{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "810c2b52",
   "metadata": {},
   "source": [
    "# zShim_Gc_split Images"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "574fc275",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "from plotly.subplots import make_subplots\n",
    "import numpy as np\n",
    "import math\n",
    "import nibabel as nib\n",
    "import matplotlib.pyplot as plt\n",
    "from math import ceil\n",
    "from scipy.interpolate import interp1d\n",
    "import time\n",
    "from ipywidgets import interactive, HBox, widgets, interact\n",
    "from plotly.offline import download_plotlyjs, init_notebook_mode, plot, iplot\n",
    "from IPython.core.display import display, HTML\n",
    "init_notebook_mode(connected=True)\n",
    "config={'showLink': False, 'displayModeBar': False}"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "e8b415ce",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "def load_image(path):\n",
    "    nii_img = nib.load(path)\n",
    "    nii_data = nii_img.get_fdata()\n",
    "\n",
    "    number_of_slices = nii_data.shape[2]\n",
    "    number_of_frames = nii_data.shape[3]\n",
    "\n",
    "    layers = []\n",
    "\n",
    "    for frame in range(number_of_frames):\n",
    "        for s in range(number_of_slices):\n",
    "                layers.append(nii_data[:,:,s,frame])\n",
    "    \n",
    "    return layers\n",
    "\n",
    "def mapp(list_value, range_1,range_2):\n",
    "    m = interp1d(range_1,range_2)\n",
    "    return m(list_value)\n",
    "\n",
    "def compare_scans(scans,nb_frames,file_name):\n",
    "    newmap = np.concatenate((scans[0],scans[1],scans[2]), axis=1)\n",
    "    new_title = \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"\n",
    "    \n",
    "    data = []\n",
    "    for i in range(nb_frames):\n",
    "        current = np.rot90(newmap[i],3)\n",
    "        data_c = go.Heatmap(z = current, \n",
    "                            visible = False,\n",
    "                            xtype = \"scaled\", \n",
    "                            ytype = \"scaled\",\n",
    "                            colorscale = \"gray\",\n",
    "                            showscale = False,\n",
    "                            hoverinfo = \"skip\"\n",
    "                            #colorbar = dict(title = dict(text = \"B<sub>0</sub> (Hz)\"))\n",
    "                           )\n",
    "        data.append(data_c)\n",
    "    data[0]['visible'] = True\n",
    "\n",
    "    # Create steps and slider\n",
    "    steps = []\n",
    "    for i in range(nb_frames):\n",
    "        step = dict(\n",
    "            method = 'restyle',  \n",
    "            args = ['visible', [False]*n],\n",
    "            label = str(i+1)\n",
    "        )\n",
    "        step['args'][1][i] = True # Toggle i'th trace to \"visible\"\n",
    "        steps.append(step)\n",
    "\n",
    "    sliders = [dict(\n",
    "        active = 0,\n",
    "        currentvalue = {'prefix':\"Current slice is: <b>\"},\n",
    "        pad = {\"t\": 50, \"b\": 10},\n",
    "        steps = steps\n",
    "    )]\n",
    "\n",
    "    # Setup the layout of the figure\n",
    "    layout = go.Layout(\n",
    "        title = new_title, \n",
    "        width=800,\n",
    "        height=500,\n",
    "        margin=go.layout.Margin(\n",
    "            l=50,\n",
    "            r=50,\n",
    "            b=60,\n",
    "            t=35,\n",
    "        ),\n",
    "        showlegend = False,\n",
    "        autosize = False,\n",
    "        sliders=sliders,\n",
    "        xaxis = dict(showgrid = False,\n",
    "                     showticklabels= False),\n",
    "        yaxis = dict(showgrid = False,\n",
    "                     showticklabels = False),\n",
    "        font = dict(family=\"Courier New, monospace\",\n",
    "                    size=14),\n",
    "    )\n",
    "    \n",
    "\n",
    "    # Plot function saves as html or with ipplot\n",
    "    fig = dict(data=data, layout=layout)\n",
    "    plot(fig, filename = file_name, config = config)\n",
    "\n",
    "    #display(HTML('fig2.html'))\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "75032738",
   "metadata": {
    "tags": [
     "remove-cell"
    ]
   },
   "outputs": [],
   "source": [
    "raw_images_path = [\"data/mag_echo1_zShim_Gc_split_alpha_60deg.nii\",\"data/mag_echo2_zShim_Gc_split_alpha_60deg.nii\",\"data/mag_echo3_zShim_Gc_split_alpha_60deg.nii\"]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "e6d08b62",
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<html>\n",
       "<head><meta charset=\"utf-8\" /></head>\n",
       "<body>\n",
       "    <div>                        <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n",
       "        <script type=\"text/javascript\">/**\n",
       "* plotly.js v1.58.4\n",
       "* Copyright 2012-2020, Plotly, Inc.\n",
       "* All rights reserved.\n",
       "* Licensed under the MIT license\n",
       "*/\n",
       "!function(t){if(\"object\"==typeof exports&&\"undefined\"!=typeof module)module.exports=t();else if(\"function\"==typeof define&&define.amd)define([],t);else{(\"undefined\"!=typeof window?window:\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:this).Plotly=t()}}((function(){return function t(e,r,n){function i(o,s){if(!r[o]){if(!e[o]){var l=\"function\"==typeof require&&require;if(!s&&l)return l(o,!0);if(a)return a(o,!0);var c=new Error(\"Cannot find module '\"+o+\"'\");throw c.code=\"MODULE_NOT_FOUND\",c}var u=r[o]={exports:{}};e[o][0].call(u.exports,(function(t){return i(e[o][1][t]||t)}),u,u.exports,t,e,r,n)}return r[o].exports}for(var a=\"function\"==typeof require&&require,o=0;o<n.length;o++)i(n[o]);return i}({1:[function(t,e,r){\"use strict\";var n=t(\"../src/lib\"),i={\"X,X div\":\"direction:ltr;font-family:'Open Sans', verdana, arial, sans-serif;margin:0;padding:0;\",\"X input,X button\":\"font-family:'Open Sans', verdana, arial, sans-serif;\",\"X input:focus,X button:focus\":\"outline:none;\",\"X a\":\"text-decoration:none;\",\"X a:hover\":\"text-decoration:none;\",\"X .crisp\":\"shape-rendering:crispEdges;\",\"X .user-select-none\":\"-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;-o-user-select:none;user-select:none;\",\"X svg\":\"overflow:hidden;\",\"X svg a\":\"fill:#447adb;\",\"X svg a:hover\":\"fill:#3c6dc5;\",\"X .main-svg\":\"position:absolute;top:0;left:0;pointer-events:none;\",\"X .main-svg .draglayer\":\"pointer-events:all;\",\"X .cursor-default\":\"cursor:default;\",\"X .cursor-pointer\":\"cursor:pointer;\",\"X .cursor-crosshair\":\"cursor:crosshair;\",\"X .cursor-move\":\"cursor:move;\",\"X .cursor-col-resize\":\"cursor:col-resize;\",\"X .cursor-row-resize\":\"cursor:row-resize;\",\"X .cursor-ns-resize\":\"cursor:ns-resize;\",\"X .cursor-ew-resize\":\"cursor:ew-resize;\",\"X .cursor-sw-resize\":\"cursor:sw-resize;\",\"X .cursor-s-resize\":\"cursor:s-resize;\",\"X .cursor-se-resize\":\"cursor:se-resize;\",\"X .cursor-w-resize\":\"cursor:w-resize;\",\"X .cursor-e-resize\":\"cursor:e-resize;\",\"X .cursor-nw-resize\":\"cursor:nw-resize;\",\"X .cursor-n-resize\":\"cursor:n-resize;\",\"X .cursor-ne-resize\":\"cursor:ne-resize;\",\"X .cursor-grab\":\"cursor:-webkit-grab;cursor:grab;\",\"X .modebar\":\"position:absolute;top:2px;right:2px;\",\"X .ease-bg\":\"-webkit-transition:background-color 0.3s ease 0s;-moz-transition:background-color 0.3s ease 0s;-ms-transition:background-color 0.3s ease 0s;-o-transition:background-color 0.3s ease 0s;transition:background-color 0.3s ease 0s;\",\"X .modebar--hover>:not(.watermark)\":\"opacity:0;-webkit-transition:opacity 0.3s ease 0s;-moz-transition:opacity 0.3s ease 0s;-ms-transition:opacity 0.3s ease 0s;-o-transition:opacity 0.3s ease 0s;transition:opacity 0.3s ease 0s;\",\"X:hover .modebar--hover .modebar-group\":\"opacity:1;\",\"X .modebar-group\":\"float:left;display:inline-block;box-sizing:border-box;padding-left:8px;position:relative;vertical-align:middle;white-space:nowrap;\",\"X .modebar-btn\":\"position:relative;font-size:16px;padding:3px 4px;height:22px;cursor:pointer;line-height:normal;box-sizing:border-box;\",\"X .modebar-btn svg\":\"position:relative;top:2px;\",\"X .modebar.vertical\":\"display:flex;flex-direction:column;flex-wrap:wrap;align-content:flex-end;max-height:100%;\",\"X .modebar.vertical svg\":\"top:-1px;\",\"X .modebar.vertical .modebar-group\":\"display:block;float:none;padding-left:0px;padding-bottom:8px;\",\"X .modebar.vertical .modebar-group .modebar-btn\":\"display:block;text-align:center;\",\"X [data-title]:before,X [data-title]:after\":\"position:absolute;-webkit-transform:translate3d(0, 0, 0);-moz-transform:translate3d(0, 0, 0);-ms-transform:translate3d(0, 0, 0);-o-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);display:none;opacity:0;z-index:1001;pointer-events:none;top:110%;right:50%;\",\"X [data-title]:hover:before,X [data-title]:hover:after\":\"display:block;opacity:1;\",\"X [data-title]:before\":\"content:'';position:absolute;background:transparent;border:6px solid transparent;z-index:1002;margin-top:-12px;border-bottom-color:#69738a;margin-right:-6px;\",\"X [data-title]:after\":\"content:attr(data-title);background:#69738a;color:white;padding:8px 10px;font-size:12px;line-height:12px;white-space:nowrap;margin-right:-18px;border-radius:2px;\",\"X .vertical [data-title]:before,X .vertical [data-title]:after\":\"top:0%;right:200%;\",\"X .vertical [data-title]:before\":\"border:6px solid transparent;border-left-color:#69738a;margin-top:8px;margin-right:-30px;\",\"X .select-outline\":\"fill:none;stroke-width:1;shape-rendering:crispEdges;\",\"X .select-outline-1\":\"stroke:white;\",\"X .select-outline-2\":\"stroke:black;stroke-dasharray:2px 2px;\",Y:\"font-family:'Open Sans', verdana, arial, sans-serif;position:fixed;top:50px;right:20px;z-index:10000;font-size:10pt;max-width:180px;\",\"Y p\":\"margin:0;\",\"Y .notifier-note\":\"min-width:180px;max-width:250px;border:1px solid #fff;z-index:3000;margin:0;background-color:#8c97af;background-color:rgba(140,151,175,0.9);color:#fff;padding:10px;overflow-wrap:break-word;word-wrap:break-word;-ms-hyphens:auto;-webkit-hyphens:auto;hyphens:auto;\",\"Y .notifier-close\":\"color:#fff;opacity:0.8;float:right;padding:0 5px;background:none;border:none;font-size:20px;font-weight:bold;line-height:20px;\",\"Y .notifier-close:hover\":\"color:#444;text-decoration:none;cursor:pointer;\"};for(var a in i){var o=a.replace(/^,/,\" ,\").replace(/X/g,\".js-plotly-plot .plotly\").replace(/Y/g,\".plotly-notifier\");n.addStyleRule(o,i[a])}},{\"../src/lib\":778}],2:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/aggregate\")},{\"../src/transforms/aggregate\":1365}],3:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/bar\")},{\"../src/traces/bar\":929}],4:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/barpolar\")},{\"../src/traces/barpolar\":942}],5:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/box\")},{\"../src/traces/box\":952}],6:[function(t,e,r){\"use strict\";e.exports=t(\"../src/components/calendars\")},{\"../src/components/calendars\":641}],7:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/candlestick\")},{\"../src/traces/candlestick\":961}],8:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/carpet\")},{\"../src/traces/carpet\":980}],9:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choropleth\")},{\"../src/traces/choropleth\":994}],10:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/choroplethmapbox\")},{\"../src/traces/choroplethmapbox\":1001}],11:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/cone\")},{\"../src/traces/cone\":1007}],12:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contour\")},{\"../src/traces/contour\":1022}],13:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/contourcarpet\")},{\"../src/traces/contourcarpet\":1033}],14:[function(t,e,r){\"use strict\";e.exports=t(\"../src/core\")},{\"../src/core\":755}],15:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/densitymapbox\")},{\"../src/traces/densitymapbox\":1041}],16:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/filter\")},{\"../src/transforms/filter\":1366}],17:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnel\")},{\"../src/traces/funnel\":1051}],18:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/funnelarea\")},{\"../src/traces/funnelarea\":1060}],19:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/groupby\")},{\"../src/transforms/groupby\":1367}],20:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmap\")},{\"../src/traces/heatmap\":1073}],21:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/heatmapgl\")},{\"../src/traces/heatmapgl\":1083}],22:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram\")},{\"../src/traces/histogram\":1095}],23:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2d\")},{\"../src/traces/histogram2d\":1101}],24:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/histogram2dcontour\")},{\"../src/traces/histogram2dcontour\":1105}],25:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/image\")},{\"../src/traces/image\":1113}],26:[function(t,e,r){\"use strict\";var n=t(\"./core\");n.register([t(\"./bar\"),t(\"./box\"),t(\"./heatmap\"),t(\"./histogram\"),t(\"./histogram2d\"),t(\"./histogram2dcontour\"),t(\"./contour\"),t(\"./scatterternary\"),t(\"./violin\"),t(\"./funnel\"),t(\"./waterfall\"),t(\"./image\"),t(\"./pie\"),t(\"./sunburst\"),t(\"./treemap\"),t(\"./funnelarea\"),t(\"./scatter3d\"),t(\"./surface\"),t(\"./isosurface\"),t(\"./volume\"),t(\"./mesh3d\"),t(\"./cone\"),t(\"./streamtube\"),t(\"./scattergeo\"),t(\"./choropleth\"),t(\"./scattergl\"),t(\"./splom\"),t(\"./pointcloud\"),t(\"./heatmapgl\"),t(\"./parcoords\"),t(\"./parcats\"),t(\"./scattermapbox\"),t(\"./choroplethmapbox\"),t(\"./densitymapbox\"),t(\"./sankey\"),t(\"./indicator\"),t(\"./table\"),t(\"./carpet\"),t(\"./scattercarpet\"),t(\"./contourcarpet\"),t(\"./ohlc\"),t(\"./candlestick\"),t(\"./scatterpolar\"),t(\"./scatterpolargl\"),t(\"./barpolar\")]),n.register([t(\"./aggregate\"),t(\"./filter\"),t(\"./groupby\"),t(\"./sort\")]),n.register([t(\"./calendars\")]),e.exports=n},{\"./aggregate\":2,\"./bar\":3,\"./barpolar\":4,\"./box\":5,\"./calendars\":6,\"./candlestick\":7,\"./carpet\":8,\"./choropleth\":9,\"./choroplethmapbox\":10,\"./cone\":11,\"./contour\":12,\"./contourcarpet\":13,\"./core\":14,\"./densitymapbox\":15,\"./filter\":16,\"./funnel\":17,\"./funnelarea\":18,\"./groupby\":19,\"./heatmap\":20,\"./heatmapgl\":21,\"./histogram\":22,\"./histogram2d\":23,\"./histogram2dcontour\":24,\"./image\":25,\"./indicator\":27,\"./isosurface\":28,\"./mesh3d\":29,\"./ohlc\":30,\"./parcats\":31,\"./parcoords\":32,\"./pie\":33,\"./pointcloud\":34,\"./sankey\":35,\"./scatter3d\":36,\"./scattercarpet\":37,\"./scattergeo\":38,\"./scattergl\":39,\"./scattermapbox\":40,\"./scatterpolar\":41,\"./scatterpolargl\":42,\"./scatterternary\":43,\"./sort\":44,\"./splom\":45,\"./streamtube\":46,\"./sunburst\":47,\"./surface\":48,\"./table\":49,\"./treemap\":50,\"./violin\":51,\"./volume\":52,\"./waterfall\":53}],27:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/indicator\")},{\"../src/traces/indicator\":1121}],28:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/isosurface\")},{\"../src/traces/isosurface\":1127}],29:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/mesh3d\")},{\"../src/traces/mesh3d\":1132}],30:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/ohlc\")},{\"../src/traces/ohlc\":1137}],31:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcats\")},{\"../src/traces/parcats\":1146}],32:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/parcoords\")},{\"../src/traces/parcoords\":1156}],33:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pie\")},{\"../src/traces/pie\":1167}],34:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/pointcloud\")},{\"../src/traces/pointcloud\":1176}],35:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sankey\")},{\"../src/traces/sankey\":1182}],36:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatter3d\")},{\"../src/traces/scatter3d\":1220}],37:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattercarpet\")},{\"../src/traces/scattercarpet\":1227}],38:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergeo\")},{\"../src/traces/scattergeo\":1235}],39:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattergl\")},{\"../src/traces/scattergl\":1248}],40:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scattermapbox\")},{\"../src/traces/scattermapbox\":1258}],41:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolar\")},{\"../src/traces/scatterpolar\":1266}],42:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterpolargl\")},{\"../src/traces/scatterpolargl\":1273}],43:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/scatterternary\")},{\"../src/traces/scatterternary\":1281}],44:[function(t,e,r){\"use strict\";e.exports=t(\"../src/transforms/sort\")},{\"../src/transforms/sort\":1369}],45:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/splom\")},{\"../src/traces/splom\":1290}],46:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/streamtube\")},{\"../src/traces/streamtube\":1298}],47:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/sunburst\")},{\"../src/traces/sunburst\":1306}],48:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/surface\")},{\"../src/traces/surface\":1315}],49:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/table\")},{\"../src/traces/table\":1323}],50:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/treemap\")},{\"../src/traces/treemap\":1332}],51:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/violin\")},{\"../src/traces/violin\":1344}],52:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/volume\")},{\"../src/traces/volume\":1352}],53:[function(t,e,r){\"use strict\";e.exports=t(\"../src/traces/waterfall\")},{\"../src/traces/waterfall\":1360}],54:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).eye||[0,0,1],r=t.center||[0,0,0],s=t.up||[0,1,0],l=t.distanceLimits||[0,1/0],c=t.mode||\"turntable\",u=n(),f=i(),h=a();return u.setDistanceLimits(l[0],l[1]),u.lookAt(0,e,r,s),f.setDistanceLimits(l[0],l[1]),f.lookAt(0,e,r,s),h.setDistanceLimits(l[0],l[1]),h.lookAt(0,e,r,s),new o({turntable:u,orbit:f,matrix:h},c)};var n=t(\"turntable-camera-controller\"),i=t(\"orbit-camera-controller\"),a=t(\"matrix-camera-controller\");function o(t,e){this._controllerNames=Object.keys(t),this._controllerList=this._controllerNames.map((function(e){return t[e]})),this._mode=e,this._active=t[e],this._active||(this._mode=\"turntable\",this._active=t.turntable),this.modes=this._controllerNames,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}var s=o.prototype;[[\"flush\",1],[\"idle\",1],[\"lookAt\",4],[\"rotate\",4],[\"pan\",4],[\"translate\",4],[\"setMatrix\",2],[\"setDistanceLimits\",2],[\"setDistance\",2]].forEach((function(t){for(var e=t[0],r=[],n=0;n<t[1];++n)r.push(\"a\"+n);var i=\"var cc=this._controllerList;for(var i=0;i<cc.length;++i){cc[i].\"+t[0]+\"(\"+r.join()+\")}\";s[e]=Function.apply(null,r.concat(i))})),s.recalcMatrix=function(t){this._active.recalcMatrix(t)},s.getDistance=function(t){return this._active.getDistance(t)},s.getDistanceLimits=function(t){return this._active.getDistanceLimits(t)},s.lastT=function(){return this._active.lastT()},s.setMode=function(t){if(t!==this._mode){var e=this._controllerNames.indexOf(t);if(!(e<0)){var r=this._active,n=this._controllerList[e],i=Math.max(r.lastT(),n.lastT());r.recalcMatrix(i),n.setMatrix(i,r.computedMatrix),this._active=n,this._mode=t,this.computedMatrix=this._active.computedMatrix,this.computedEye=this._active.computedEye,this.computedUp=this._active.computedUp,this.computedCenter=this._active.computedCenter,this.computedRadius=this._active.computedRadius}}},s.getMode=function(){return this._mode}},{\"matrix-camera-controller\":480,\"orbit-camera-controller\":501,\"turntable-camera-controller\":581}],55:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\"),t(\"elementary-circuits-directed-graph\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,null)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return t.target.depth}function o(t,e){return t.sourceLinks.length?t.depth:e-1}function s(t){return function(){return t}}i=i&&i.hasOwnProperty(\"default\")?i.default:i;var l=\"function\"==typeof Symbol&&\"symbol\"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&\"function\"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?\"symbol\":typeof t};function c(t,e){return f(t.source,e.source)||t.index-e.index}function u(t,e){return f(t.target,e.target)||t.index-e.index}function f(t,e){return t.partOfCycle===e.partOfCycle?t.y0-e.y0:\"top\"===t.circularLinkType||\"bottom\"===e.circularLinkType?-1:1}function h(t){return t.value}function p(t){return(t.y0+t.y1)/2}function d(t){return p(t.source)}function g(t){return p(t.target)}function m(t){return t.index}function v(t){return t.nodes}function y(t){return t.links}function x(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function b(t,e){return e(t)}function _(t,e,r){var n=0;if(null===r){for(var a=[],o=0;o<t.links.length;o++){var s=t.links[o],l=s.source.index,c=s.target.index;a[l]||(a[l]=[]),a[c]||(a[c]=[]),-1===a[l].indexOf(c)&&a[l].push(c)}var u=i(a);u.sort((function(t,e){return t.length-e.length}));var f={};for(o=0;o<u.length;o++){var h=u[o].slice(-2);f[h[0]]||(f[h[0]]={}),f[h[0]][h[1]]=!0}t.links.forEach((function(t){var e=t.target.index,r=t.source.index;e===r||f[r]&&f[r][e]?(t.circular=!0,t.circularLinkID=n,n+=1):t.circular=!1}))}else t.links.forEach((function(t){t.source[r]<t.target[r]?t.circular=!1:(t.circular=!0,t.circularLinkID=n,n+=1)}))}function w(t,e){var r=0,n=0;t.links.forEach((function(i){i.circular&&(i.source.circularLinkType||i.target.circularLinkType?i.circularLinkType=i.source.circularLinkType?i.source.circularLinkType:i.target.circularLinkType:i.circularLinkType=r<n?\"top\":\"bottom\",\"top\"==i.circularLinkType?r+=1:n+=1,t.nodes.forEach((function(t){b(t,e)!=b(i.source,e)&&b(t,e)!=b(i.target,e)||(t.circularLinkType=i.circularLinkType)})))})),t.links.forEach((function(t){t.circular&&(t.source.circularLinkType==t.target.circularLinkType&&(t.circularLinkType=t.source.circularLinkType),H(t,e)&&(t.circularLinkType=t.source.circularLinkType))}))}function T(t){var e=Math.abs(t.y1-t.y0),r=Math.abs(t.target.x0-t.source.x1);return Math.atan(r/e)}function k(t,e){var r=0;t.sourceLinks.forEach((function(t){r=t.circular&&!H(t,e)?r+1:r}));var n=0;return t.targetLinks.forEach((function(t){n=t.circular&&!H(t,e)?n+1:n})),r+n}function M(t){var e=t.source.sourceLinks,r=0;e.forEach((function(t){r=t.circular?r+1:r}));var n=t.target.targetLinks,i=0;return n.forEach((function(t){i=t.circular?i+1:i})),!(r>1||i>1)}function A(t,e,r){return t.sort(E),t.forEach((function(n,i){var a,o,s=0;if(H(n,r)&&M(n))n.circularPathData.verticalBuffer=s+n.width/2;else{for(var l=0;l<i;l++)if(a=t[i],o=t[l],!(a.source.column<o.target.column||a.target.column>o.source.column)){var c=t[l].circularPathData.verticalBuffer+t[l].width/2+e;s=c>s?c:s}n.circularPathData.verticalBuffer=s+n.width/2}})),t}function S(t,r,i,a){var o=e.min(t.links,(function(t){return t.source.y0}));t.links.forEach((function(t){t.circular&&(t.circularPathData={})})),A(t.links.filter((function(t){return\"top\"==t.circularLinkType})),r,a),A(t.links.filter((function(t){return\"bottom\"==t.circularLinkType})),r,a),t.links.forEach((function(e){if(e.circular){if(e.circularPathData.arcRadius=e.width+10,e.circularPathData.leftNodeBuffer=5,e.circularPathData.rightNodeBuffer=5,e.circularPathData.sourceWidth=e.source.x1-e.source.x0,e.circularPathData.sourceX=e.source.x0+e.circularPathData.sourceWidth,e.circularPathData.targetX=e.target.x0,e.circularPathData.sourceY=e.y0,e.circularPathData.targetY=e.y1,H(e,a)&&M(e))e.circularPathData.leftSmallArcRadius=10+e.width/2,e.circularPathData.leftLargeArcRadius=10+e.width/2,e.circularPathData.rightSmallArcRadius=10+e.width/2,e.circularPathData.rightLargeArcRadius=10+e.width/2,\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=e.source.y1+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=e.source.y0-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius);else{var s=e.source.column,l=e.circularLinkType,c=t.links.filter((function(t){return t.source.column==s&&t.circularLinkType==l}));\"bottom\"==e.circularLinkType?c.sort(L):c.sort(C);var u=0;c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.leftSmallArcRadius=10+e.width/2+u,e.circularPathData.leftLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),s=e.target.column,c=t.links.filter((function(t){return t.target.column==s&&t.circularLinkType==l})),\"bottom\"==e.circularLinkType?c.sort(P):c.sort(I),u=0,c.forEach((function(t,n){t.circularLinkID==e.circularLinkID&&(e.circularPathData.rightSmallArcRadius=10+e.width/2+u,e.circularPathData.rightLargeArcRadius=10+e.width/2+n*r+u),u+=t.width})),\"bottom\"==e.circularLinkType?(e.circularPathData.verticalFullExtent=Math.max(i,e.source.y1,e.target.y1)+25+e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent-e.circularPathData.rightLargeArcRadius):(e.circularPathData.verticalFullExtent=o-25-e.circularPathData.verticalBuffer,e.circularPathData.verticalLeftInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.leftLargeArcRadius,e.circularPathData.verticalRightInnerExtent=e.circularPathData.verticalFullExtent+e.circularPathData.rightLargeArcRadius)}e.circularPathData.leftInnerExtent=e.circularPathData.sourceX+e.circularPathData.leftNodeBuffer,e.circularPathData.rightInnerExtent=e.circularPathData.targetX-e.circularPathData.rightNodeBuffer,e.circularPathData.leftFullExtent=e.circularPathData.sourceX+e.circularPathData.leftLargeArcRadius+e.circularPathData.leftNodeBuffer,e.circularPathData.rightFullExtent=e.circularPathData.targetX-e.circularPathData.rightLargeArcRadius-e.circularPathData.rightNodeBuffer}if(e.circular)e.path=function(t){var e=\"\";e=\"top\"==t.circularLinkType?\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 0 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY-t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 0 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 0 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY-t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 0 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY:\"M\"+t.circularPathData.sourceX+\" \"+t.circularPathData.sourceY+\" L\"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.sourceY+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftSmallArcRadius+\" 0 0 1 \"+t.circularPathData.leftFullExtent+\" \"+(t.circularPathData.sourceY+t.circularPathData.leftSmallArcRadius)+\" L\"+t.circularPathData.leftFullExtent+\" \"+t.circularPathData.verticalLeftInnerExtent+\" A\"+t.circularPathData.leftLargeArcRadius+\" \"+t.circularPathData.leftLargeArcRadius+\" 0 0 1 \"+t.circularPathData.leftInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" L\"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.verticalFullExtent+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightLargeArcRadius+\" 0 0 1 \"+t.circularPathData.rightFullExtent+\" \"+t.circularPathData.verticalRightInnerExtent+\" L\"+t.circularPathData.rightFullExtent+\" \"+(t.circularPathData.targetY+t.circularPathData.rightSmallArcRadius)+\" A\"+t.circularPathData.rightLargeArcRadius+\" \"+t.circularPathData.rightSmallArcRadius+\" 0 0 1 \"+t.circularPathData.rightInnerExtent+\" \"+t.circularPathData.targetY+\" L\"+t.circularPathData.targetX+\" \"+t.circularPathData.targetY;return e}(e);else{var f=n.linkHorizontal().source((function(t){return[t.source.x0+(t.source.x1-t.source.x0),t.y0]})).target((function(t){return[t.target.x0,t.y1]}));e.path=f(e)}}))}function E(t,e){return z(t)==z(e)?\"bottom\"==t.circularLinkType?L(t,e):C(t,e):z(e)-z(t)}function C(t,e){return t.y0-e.y0}function L(t,e){return e.y0-t.y0}function I(t,e){return t.y1-e.y1}function P(t,e){return e.y1-t.y1}function z(t){return t.target.column-t.source.column}function O(t){return t.target.x0-t.source.x1}function D(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1+n:t.y1-n}function R(t,e){var r=T(t),n=O(e)/Math.tan(r);return\"up\"==q(t)?t.y1-n:t.y1+n}function F(t,e,r,n){t.links.forEach((function(i){if(!i.circular&&i.target.column-i.source.column>1){var a=i.source.column+1,o=i.target.column-1,s=1,l=o-a+1;for(s=1;a<=o;a++,s++)t.nodes.forEach((function(o){if(o.column==a){var c,u=s/(l+1),f=Math.pow(1-u,3),h=3*u*Math.pow(1-u,2),p=3*Math.pow(u,2)*(1-u),d=Math.pow(u,3),g=f*i.y0+h*i.y0+p*i.y1+d*i.y1,m=g-i.width/2,v=g+i.width/2;m>o.y0&&m<o.y1?(c=o.y1-m+10,c=\"bottom\"==o.circularLinkType?c:-c,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&B(o,t)&&N(t,c,e,r)}))):(v>o.y0&&v<o.y1||m<o.y0&&v>o.y1)&&(c=v-o.y0+10,o=N(o,c,e,r),t.nodes.forEach((function(t){b(t,n)!=b(o,n)&&t.column==o.column&&t.y0<o.y1&&t.y1>o.y1&&N(t,c,e,r)})))}}))}}))}function B(t,e){return t.y0>e.y0&&t.y0<e.y1||(t.y1>e.y0&&t.y1<e.y1||t.y0<e.y0&&t.y1>e.y1)}function N(t,e,r,n){return t.y0+e>=r&&t.y1+e<=n&&(t.y0=t.y0+e,t.y1=t.y1+e,t.targetLinks.forEach((function(t){t.y1=t.y1+e})),t.sourceLinks.forEach((function(t){t.y0=t.y0+e}))),t}function j(t,e,r,n){t.nodes.forEach((function(i){n&&i.y+(i.y1-i.y0)>e&&(i.y=i.y-(i.y+(i.y1-i.y0)-e));var a=t.links.filter((function(t){return b(t.source,r)==b(i,r)})),o=a.length;o>1&&a.sort((function(t,e){if(!t.circular&&!e.circular){if(t.target.column==e.target.column)return t.y1-e.y1;if(!V(t,e))return t.y1-e.y1;if(t.target.column>e.target.column){var r=R(e,t);return t.y1-r}if(e.target.column>t.target.column)return R(t,e)-e.y1}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.target.column===e.target.column?t.target.y1-e.target.y1:e.target.column-t.target.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.target.column===e.target.column?e.target.y1-t.target.y1:t.target.column-e.target.column:\"top\"==t.circularLinkType?-1:1:void 0}));var s=i.y0;a.forEach((function(t){t.y0=s+t.width/2,s+=t.width})),a.forEach((function(t,e){if(\"bottom\"==t.circularLinkType){for(var r=e+1,n=0;r<o;r++)n+=a[r].width;t.y0=i.y1-n-t.width/2}}))}))}function U(t,e,r){t.nodes.forEach((function(e){var n=t.links.filter((function(t){return b(t.target,r)==b(e,r)})),i=n.length;i>1&&n.sort((function(t,e){if(!t.circular&&!e.circular){if(t.source.column==e.source.column)return t.y0-e.y0;if(!V(t,e))return t.y0-e.y0;if(e.source.column<t.source.column){var r=D(e,t);return t.y0-r}if(t.source.column<e.source.column)return D(t,e)-e.y0}return t.circular&&!e.circular?\"top\"==t.circularLinkType?-1:1:e.circular&&!t.circular?\"top\"==e.circularLinkType?1:-1:t.circular&&e.circular?t.circularLinkType===e.circularLinkType&&\"top\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:t.source.column-e.source.column:t.circularLinkType===e.circularLinkType&&\"bottom\"==t.circularLinkType?t.source.column===e.source.column?t.source.y1-e.source.y1:e.source.column-t.source.column:\"top\"==t.circularLinkType?-1:1:void 0}));var a=e.y0;n.forEach((function(t){t.y1=a+t.width/2,a+=t.width})),n.forEach((function(t,r){if(\"bottom\"==t.circularLinkType){for(var a=r+1,o=0;a<i;a++)o+=n[a].width;t.y1=e.y1-o-t.width/2}}))}))}function V(t,e){return q(t)==q(e)}function q(t){return t.y0-t.y1>0?\"up\":\"down\"}function H(t,e){return b(t.source,e)==b(t.target,e)}function G(t,r,n){var i=t.nodes,a=t.links,o=!1,s=!1;if(a.forEach((function(t){\"top\"==t.circularLinkType?o=!0:\"bottom\"==t.circularLinkType&&(s=!0)})),0==o||0==s){var l=e.min(i,(function(t){return t.y0})),c=(n-r)/(e.max(i,(function(t){return t.y1}))-l);i.forEach((function(t){var e=(t.y1-t.y0)*c;t.y0=(t.y0-l)*c,t.y1=t.y0+e})),a.forEach((function(t){t.y0=(t.y0-l)*c,t.y1=(t.y1-l)*c,t.width=t.width*c}))}}t.sankeyCircular=function(){var t,n,i=0,a=0,b=1,T=1,M=24,A=m,E=o,C=v,L=y,I=32,P=2,z=null;function O(){var t={nodes:C.apply(null,arguments),links:L.apply(null,arguments)};D(t),_(t,A,z),R(t),B(t),w(t,A),N(t,I,A),V(t);for(var e=4,r=0;r<e;r++)j(t,T,A),U(t,T,A),F(t,a,T,A),j(t,T,A),U(t,T,A);return G(t,a,T),S(t,P,T,A),t}function D(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,A);return t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!==(\"undefined\"==typeof n?\"undefined\":l(n))&&(n=t.source=x(e,n)),\"object\"!==(\"undefined\"==typeof i?\"undefined\":l(i))&&(i=t.target=x(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)})),t}function R(t){t.nodes.forEach((function(t){t.partOfCycle=!1,t.value=Math.max(e.sum(t.sourceLinks,h),e.sum(t.targetLinks,h)),t.sourceLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)})),t.targetLinks.forEach((function(e){e.circular&&(t.partOfCycle=!0,t.circularLinkType=e.circularLinkType)}))}))}function B(t){var e,r,n;for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.depth=n,t.sourceLinks.forEach((function(t){r.indexOf(t.target)<0&&!t.circular&&r.push(t.target)}))}));for(e=t.nodes,r=[],n=0;e.length;++n,e=r,r=[])e.forEach((function(t){t.height=n,t.targetLinks.forEach((function(t){r.indexOf(t.source)<0&&!t.circular&&r.push(t.source)}))}));t.nodes.forEach((function(t){t.column=Math.floor(E.call(null,t,n))}))}function N(o,s,l){var c=r.nest().key((function(t){return t.column})).sortKeys(e.ascending).entries(o.nodes).map((function(t){return t.values}));!function(r){if(n){var s=1/0;c.forEach((function(t){var e=T*n/(t.length+1);s=e<s?e:s})),t=s}var l=e.min(c,(function(r){return(T-a-(r.length-1)*t)/e.sum(r,h)}));l*=.3,o.links.forEach((function(t){t.width=t.value*l}));var u=function(t){var r=0,n=0,i=0,a=0,o=e.max(t.nodes,(function(t){return t.column}));return t.links.forEach((function(t){t.circular&&(\"top\"==t.circularLinkType?r+=t.width:n+=t.width,0==t.target.column&&(a+=t.width),t.source.column==o&&(i+=t.width))})),{top:r=r>0?r+25+10:r,bottom:n=n>0?n+25+10:n,left:a=a>0?a+25+10:a,right:i=i>0?i+25+10:i}}(o),f=function(t,r){var n=e.max(t.nodes,(function(t){return t.column})),o=b-i,s=T-a,l=o/(o+r.right+r.left),c=s/(s+r.top+r.bottom);return i=i*l+r.left,b=0==r.right?b:b*l,a=a*c+r.top,T*=c,t.nodes.forEach((function(t){t.x0=i+t.column*((b-i-M)/n),t.x1=t.x0+M})),c}(o,u);l*=f,o.links.forEach((function(t){t.width=t.value*l})),c.forEach((function(t){var e=t.length;t.forEach((function(t,n){t.depth==c.length-1&&1==e||0==t.depth&&1==e?(t.y0=T/2-t.value*l,t.y1=t.y0+t.value*l):t.partOfCycle?0==k(t,r)?(t.y0=T/2+n,t.y1=t.y0+t.value*l):\"top\"==t.circularLinkType?(t.y0=a+n,t.y1=t.y0+t.value*l):(t.y0=T-t.value*l-n,t.y1=t.y0+t.value*l):0==u.top||0==u.bottom?(t.y0=(T-a)/e*n,t.y1=t.y0+t.value*l):(t.y0=(T-a)/2-e/2+n,t.y1=t.y0+t.value*l)}))}))}(l),y();for(var u=1,m=s;m>0;--m)v(u*=.99,l),y();function v(t,r){var n=c.length;c.forEach((function(i){var a=i.length,o=i[0].depth;i.forEach((function(i){var s;if(i.sourceLinks.length||i.targetLinks.length)if(i.partOfCycle&&k(i,r)>0);else if(0==o&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else if(o==n-1&&1==a)s=i.y1-i.y0,i.y0=T/2-s/2,i.y1=T/2+s/2;else{var l=e.mean(i.sourceLinks,g),c=e.mean(i.targetLinks,d),u=((l&&c?(l+c)/2:l||c)-p(i))*t;i.y0+=u,i.y1+=u}}))}))}function y(){c.forEach((function(e){var r,n,i,o=a,s=e.length;for(e.sort(f),i=0;i<s;++i)(n=o-(r=e[i]).y0)>0&&(r.y0+=n,r.y1+=n),o=r.y1+t;if((n=o-t-T)>0)for(o=r.y0-=n,r.y1-=n,i=s-2;i>=0;--i)(n=(r=e[i]).y1+t-o)>0&&(r.y0-=n,r.y1-=n),o=r.y0}))}}function V(t){t.nodes.forEach((function(t){t.sourceLinks.sort(u),t.targetLinks.sort(c)})),t.nodes.forEach((function(t){var e=t.y0,r=e,n=t.y1,i=n;t.sourceLinks.forEach((function(t){t.circular?(t.y0=n-t.width/2,n-=t.width):(t.y0=e+t.width/2,e+=t.width)})),t.targetLinks.forEach((function(t){t.circular?(t.y1=i-t.width/2,i-=t.width):(t.y1=r+t.width/2,r+=t.width)}))}))}return O.nodeId=function(t){return arguments.length?(A=\"function\"==typeof t?t:s(t),O):A},O.nodeAlign=function(t){return arguments.length?(E=\"function\"==typeof t?t:s(t),O):E},O.nodeWidth=function(t){return arguments.length?(M=+t,O):M},O.nodePadding=function(e){return arguments.length?(t=+e,O):t},O.nodes=function(t){return arguments.length?(C=\"function\"==typeof t?t:s(t),O):C},O.links=function(t){return arguments.length?(L=\"function\"==typeof t?t:s(t),O):L},O.size=function(t){return arguments.length?(i=a=0,b=+t[0],T=+t[1],O):[b-i,T-a]},O.extent=function(t){return arguments.length?(i=+t[0][0],b=+t[1][0],a=+t[0][1],T=+t[1][1],O):[[i,a],[b,T]]},O.iterations=function(t){return arguments.length?(I=+t,O):I},O.circularLinkGap=function(t){return arguments.length?(P=+t,O):P},O.nodePaddingRatio=function(t){return arguments.length?(n=+t,O):n},O.sortNodes=function(t){return arguments.length?(z=t,O):z},O.update=function(t){return w(t,A),V(t),t.links.forEach((function(t){t.circular&&(t.circularLinkType=t.y0+t.y1<T?\"top\":\"bottom\",t.source.circularLinkType=t.circularLinkType,t.target.circularLinkType=t.circularLinkType)})),j(t,T,A,!1),U(t,T,A),S(t,P,T,A),t},O},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,a)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=o,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165,\"elementary-circuits-directed-graph\":179}],56:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-array\"),t(\"d3-collection\"),t(\"d3-shape\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3)}(this,(function(t,e,r,n){\"use strict\";function i(t){return t.target.depth}function a(t,e){return t.sourceLinks.length?t.depth:e-1}function o(t){return function(){return t}}function s(t,e){return c(t.source,e.source)||t.index-e.index}function l(t,e){return c(t.target,e.target)||t.index-e.index}function c(t,e){return t.y0-e.y0}function u(t){return t.value}function f(t){return(t.y0+t.y1)/2}function h(t){return f(t.source)*t.value}function p(t){return f(t.target)*t.value}function d(t){return t.index}function g(t){return t.nodes}function m(t){return t.links}function v(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function y(t){return[t.source.x1,t.y0]}function x(t){return[t.target.x0,t.y1]}t.sankey=function(){var t=0,n=0,i=1,y=1,x=24,b=8,_=d,w=a,T=g,k=m,M=32;function A(){var t={nodes:T.apply(null,arguments),links:k.apply(null,arguments)};return S(t),E(t),C(t),L(t),I(t),t}function S(t){t.nodes.forEach((function(t,e){t.index=e,t.sourceLinks=[],t.targetLinks=[]}));var e=r.map(t.nodes,_);t.links.forEach((function(t,r){t.index=r;var n=t.source,i=t.target;\"object\"!=typeof n&&(n=t.source=v(e,n)),\"object\"!=typeof i&&(i=t.target=v(e,i)),n.sourceLinks.push(t),i.targetLinks.push(t)}))}function E(t){t.nodes.forEach((function(t){t.value=Math.max(e.sum(t.sourceLinks,u),e.sum(t.targetLinks,u))}))}function C(e){var r,n,a;for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.depth=a,t.sourceLinks.forEach((function(t){n.indexOf(t.target)<0&&n.push(t.target)}))}));for(r=e.nodes,n=[],a=0;r.length;++a,r=n,n=[])r.forEach((function(t){t.height=a,t.targetLinks.forEach((function(t){n.indexOf(t.source)<0&&n.push(t.source)}))}));var o=(i-t-x)/(a-1);e.nodes.forEach((function(e){e.x1=(e.x0=t+Math.max(0,Math.min(a-1,Math.floor(w.call(null,e,a))))*o)+x}))}function L(t){var i=r.nest().key((function(t){return t.x0})).sortKeys(e.ascending).entries(t.nodes).map((function(t){return t.values}));!function(){var r=e.max(i,(function(t){return t.length})),a=2/3*(y-n)/(r-1);b>a&&(b=a);var o=e.min(i,(function(t){return(y-n-(t.length-1)*b)/e.sum(t,u)}));i.forEach((function(t){t.forEach((function(t,e){t.y1=(t.y0=e)+t.value*o}))})),t.links.forEach((function(t){t.width=t.value*o}))}(),d();for(var a=1,o=M;o>0;--o)l(a*=.99),d(),s(a),d();function s(t){i.forEach((function(r){r.forEach((function(r){if(r.targetLinks.length){var n=(e.sum(r.targetLinks,h)/e.sum(r.targetLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function l(t){i.slice().reverse().forEach((function(r){r.forEach((function(r){if(r.sourceLinks.length){var n=(e.sum(r.sourceLinks,p)/e.sum(r.sourceLinks,u)-f(r))*t;r.y0+=n,r.y1+=n}}))}))}function d(){i.forEach((function(t){var e,r,i,a=n,o=t.length;for(t.sort(c),i=0;i<o;++i)(r=a-(e=t[i]).y0)>0&&(e.y0+=r,e.y1+=r),a=e.y1+b;if((r=a-b-y)>0)for(a=e.y0-=r,e.y1-=r,i=o-2;i>=0;--i)(r=(e=t[i]).y1+b-a)>0&&(e.y0-=r,e.y1-=r),a=e.y0}))}}function I(t){t.nodes.forEach((function(t){t.sourceLinks.sort(l),t.targetLinks.sort(s)})),t.nodes.forEach((function(t){var e=t.y0,r=e;t.sourceLinks.forEach((function(t){t.y0=e+t.width/2,e+=t.width})),t.targetLinks.forEach((function(t){t.y1=r+t.width/2,r+=t.width}))}))}return A.update=function(t){return I(t),t},A.nodeId=function(t){return arguments.length?(_=\"function\"==typeof t?t:o(t),A):_},A.nodeAlign=function(t){return arguments.length?(w=\"function\"==typeof t?t:o(t),A):w},A.nodeWidth=function(t){return arguments.length?(x=+t,A):x},A.nodePadding=function(t){return arguments.length?(b=+t,A):b},A.nodes=function(t){return arguments.length?(T=\"function\"==typeof t?t:o(t),A):T},A.links=function(t){return arguments.length?(k=\"function\"==typeof t?t:o(t),A):k},A.size=function(e){return arguments.length?(t=n=0,i=+e[0],y=+e[1],A):[i-t,y-n]},A.extent=function(e){return arguments.length?(t=+e[0][0],i=+e[1][0],n=+e[0][1],y=+e[1][1],A):[[t,n],[i,y]]},A.iterations=function(t){return arguments.length?(M=+t,A):M},A},t.sankeyCenter=function(t){return t.targetLinks.length?t.depth:t.sourceLinks.length?e.min(t.sourceLinks,i)-1:0},t.sankeyLeft=function(t){return t.depth},t.sankeyRight=function(t,e){return e-1-t.height},t.sankeyJustify=a,t.sankeyLinkHorizontal=function(){return n.linkHorizontal().source(y).target(x)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-array\":156,\"d3-collection\":157,\"d3-shape\":165}],57:[function(t,e,r){\"use strict\";e.exports=t(\"./quad\")},{\"./quad\":58}],58:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"clamp\"),a=t(\"parse-rect\"),o=t(\"array-bounds\"),s=t(\"pick-by-alias\"),l=t(\"defined\"),c=t(\"flatten-vertex-data\"),u=t(\"is-obj\"),f=t(\"dtype\"),h=t(\"math-log2\");function p(t,e){for(var r=e[0],n=e[1],a=1/(e[2]-r),o=1/(e[3]-n),s=new Array(t.length),l=0,c=t.length/2;l<c;l++)s[2*l]=i((t[2*l]-r)*a,0,1),s[2*l+1]=i((t[2*l+1]-n)*o,0,1);return s}e.exports=function(t,e){e||(e={}),t=c(t,\"float64\"),e=s(e,{bounds:\"range bounds dataBox databox\",maxDepth:\"depth maxDepth maxdepth level maxLevel maxlevel levels\",dtype:\"type dtype format out dst output destination\"});var r=l(e.maxDepth,255),i=l(e.bounds,o(t,2));i[0]===i[2]&&i[2]++,i[1]===i[3]&&i[3]++;var d,g=p(t,i),m=t.length>>>1;e.dtype||(e.dtype=\"array\"),\"string\"==typeof e.dtype?d=new(f(e.dtype))(m):e.dtype&&(d=e.dtype,Array.isArray(d)&&(d.length=m));for(var v=0;v<m;++v)d[v]=v;var y=[],x=[],b=[],_=[];!function t(e,n,i,a,o,s){if(!a.length)return null;var l=y[o]||(y[o]=[]),c=b[o]||(b[o]=[]),u=x[o]||(x[o]=[]),f=l.length;if(++o>r||s>1073741824){for(var h=0;h<a.length;h++)l.push(a[h]),c.push(s),u.push(null,null,null,null);return f}if(l.push(a[0]),c.push(s),a.length<=1)return u.push(null,null,null,null),f;for(var p=.5*i,d=e+p,m=n+p,v=[],_=[],w=[],T=[],k=1,M=a.length;k<M;k++){var A=a[k],S=g[2*A],E=g[2*A+1];S<d?E<m?v.push(A):_.push(A):E<m?w.push(A):T.push(A)}return s<<=2,u.push(t(e,n,p,v,o,s),t(e,m,p,_,o,s+1),t(d,n,p,w,o,s+2),t(d,m,p,T,o,s+3)),f}(0,0,1,d,0,1);for(var w=0,T=0;T<y.length;T++){var k=y[T];if(d.set)d.set(k,w);else for(var M=0,A=k.length;M<A;M++)d[M+w]=k[M];var S=w+y[T].length;_[T]=[w,S],w=S}return d.range=function(){var e,r=[],n=arguments.length;for(;n--;)r[n]=arguments[n];if(u(r[r.length-1])){var o=r.pop();r.length||null==o.x&&null==o.l&&null==o.left||(r=[o],e={}),e=s(o,{level:\"level maxLevel\",d:\"d diam diameter r radius px pxSize pixel pixelSize maxD size minSize\",lod:\"lod details ranges offsets\"})}else e={};r.length||(r=i);var c=a.apply(void 0,r),f=[Math.min(c.x,c.x+c.width),Math.min(c.y,c.y+c.height),Math.max(c.x,c.x+c.width),Math.max(c.y,c.y+c.height)],d=f[0],g=f[1],m=f[2],v=f[3],b=p([d,g,m,v],i),_=b[0],w=b[1],T=b[2],k=b[3],M=l(e.level,y.length);if(null!=e.d){var A;\"number\"==typeof e.d?A=[e.d,e.d]:e.d.length&&(A=e.d),M=Math.min(Math.max(Math.ceil(-h(Math.abs(A[0])/(i[2]-i[0]))),Math.ceil(-h(Math.abs(A[1])/(i[3]-i[1])))),M)}if(M=Math.min(M,y.length),e.lod)return E(_,w,T,k,M);var S=[];function C(e,r,n,i,a,o){if(null!==a&&null!==o&&!(_>e+n||w>r+n||T<e||k<r||i>=M||a===o)){var s=y[i];void 0===o&&(o=s.length);for(var l=a;l<o;l++){var c=s[l],u=t[2*c],f=t[2*c+1];u>=d&&u<=m&&f>=g&&f<=v&&S.push(c)}var h=x[i],p=h[4*a+0],b=h[4*a+1],A=h[4*a+2],E=h[4*a+3],I=L(h,a+1),P=.5*n,z=i+1;C(e,r,P,z,p,b||A||E||I),C(e,r+P,P,z,b,A||E||I),C(e+P,r,P,z,A,E||I),C(e+P,r+P,P,z,E,I)}}function L(t,e){for(var r=null,n=0;null===r;)if(r=t[4*e+n],++n>t.length)return null;return r}return C(0,0,1,0,0,1),S},d;function E(t,e,r,i,a){for(var o=[],s=0;s<a;s++){var l=b[s],c=_[s][0],u=C(t,e,s),f=C(r,i,s),h=n.ge(l,u),p=n.gt(l,f,h,l.length-1);o[s]=[h+c,p+c]}return o}function C(t,e,r){for(var n=1,i=.5,a=.5,o=.5,s=0;s<r;s++)n<<=2,n+=t<i?e<a?0:1:e<a?2:3,o*=.5,i+=t<i?-o:o,a+=e<a?-o:o;return n}}},{\"array-bounds\":70,\"binary-search-bounds\":96,clamp:120,defined:170,dtype:175,\"flatten-vertex-data\":244,\"is-obj\":468,\"math-log2\":479,\"parse-rect\":504,\"pick-by-alias\":511}],59:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");function i(t){var e=0;if(t&&t.length>0){e+=Math.abs(a(t[0]));for(var r=1;r<t.length;r++)e-=Math.abs(a(t[r]))}return e}function a(t){var e,r,n,i,a,s,l=0,c=t.length;if(c>2){for(s=0;s<c;s++)s===c-2?(n=c-2,i=c-1,a=0):s===c-1?(n=c-1,i=0,a=1):(n=s,i=s+1,a=s+2),e=t[n],r=t[i],l+=(o(t[a][0])-o(e[0]))*Math.sin(o(r[1]));l=6378137*l*6378137/2}return l}function o(t){return t*Math.PI/180}r.default=function(t){return n.geomReduce(t,(function(t,e){return t+function(t){var e,r=0;switch(t.type){case\"Polygon\":return i(t.coordinates);case\"MultiPolygon\":for(e=0;e<t.coordinates.length;e++)r+=i(t.coordinates[e]);return r;case\"Point\":case\"MultiPoint\":case\"LineString\":case\"MultiLineString\":return 0}return 0}(e)}),0)}},{\"@turf/meta\":63}],60:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\");r.default=function(t){var e=[1/0,1/0,-1/0,-1/0];return n.coordEach(t,(function(t){e[0]>t[0]&&(e[0]=t[0]),e[1]>t[1]&&(e[1]=t[1]),e[2]<t[0]&&(e[2]=t[0]),e[3]<t[1]&&(e[3]=t[1])})),e}},{\"@turf/meta\":63}],61:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/meta\"),i=t(\"@turf/helpers\");r.default=function(t,e){void 0===e&&(e={});var r=0,a=0,o=0;return n.coordEach(t,(function(t){r+=t[0],a+=t[1],o++})),i.point([r/o,a/o],e.properties)}},{\"@turf/helpers\":62,\"@turf/meta\":63}],62:[function(t,e,r){\"use strict\";function n(t,e,r){void 0===r&&(r={});var n={type:\"Feature\"};return(0===r.id||r.id)&&(n.id=r.id),r.bbox&&(n.bbox=r.bbox),n.properties=e||{},n.geometry=t,n}function i(t,e,r){return void 0===r&&(r={}),n({type:\"Point\",coordinates:t},e,r)}function a(t,e,r){void 0===r&&(r={});for(var i=0,a=t;i<a.length;i++){var o=a[i];if(o.length<4)throw new Error(\"Each LinearRing of a Polygon must have 4 or more Positions.\");for(var s=0;s<o[o.length-1].length;s++)if(o[o.length-1][s]!==o[0][s])throw new Error(\"First and last Position are not equivalent.\")}return n({type:\"Polygon\",coordinates:t},e,r)}function o(t,e,r){if(void 0===r&&(r={}),t.length<2)throw new Error(\"coordinates must be an array of two or more positions\");return n({type:\"LineString\",coordinates:t},e,r)}function s(t,e){void 0===e&&(e={});var r={type:\"FeatureCollection\"};return e.id&&(r.id=e.id),e.bbox&&(r.bbox=e.bbox),r.features=t,r}function l(t,e,r){return void 0===r&&(r={}),n({type:\"MultiLineString\",coordinates:t},e,r)}function c(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPoint\",coordinates:t},e,r)}function u(t,e,r){return void 0===r&&(r={}),n({type:\"MultiPolygon\",coordinates:t},e,r)}function f(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t*n}function h(t,e){void 0===e&&(e=\"kilometers\");var n=r.factors[e];if(!n)throw new Error(e+\" units is invalid\");return t/n}function p(t){return 180*(t%(2*Math.PI))/Math.PI}function d(t){return!isNaN(t)&&null!==t&&!Array.isArray(t)&&!/^\\s*$/.test(t)}Object.defineProperty(r,\"__esModule\",{value:!0}),r.earthRadius=6371008.8,r.factors={centimeters:100*r.earthRadius,centimetres:100*r.earthRadius,degrees:r.earthRadius/111325,feet:3.28084*r.earthRadius,inches:39.37*r.earthRadius,kilometers:r.earthRadius/1e3,kilometres:r.earthRadius/1e3,meters:r.earthRadius,metres:r.earthRadius,miles:r.earthRadius/1609.344,millimeters:1e3*r.earthRadius,millimetres:1e3*r.earthRadius,nauticalmiles:r.earthRadius/1852,radians:1,yards:r.earthRadius/1.0936},r.unitsFactors={centimeters:100,centimetres:100,degrees:1/111325,feet:3.28084,inches:39.37,kilometers:.001,kilometres:.001,meters:1,metres:1,miles:1/1609.344,millimeters:1e3,millimetres:1e3,nauticalmiles:1/1852,radians:1/r.earthRadius,yards:1/1.0936},r.areaFactors={acres:247105e-9,centimeters:1e4,centimetres:1e4,feet:10.763910417,inches:1550.003100006,kilometers:1e-6,kilometres:1e-6,meters:1,metres:1,miles:386e-9,millimeters:1e6,millimetres:1e6,yards:1.195990046},r.feature=n,r.geometry=function(t,e,r){switch(void 0===r&&(r={}),t){case\"Point\":return i(e).geometry;case\"LineString\":return o(e).geometry;case\"Polygon\":return a(e).geometry;case\"MultiPoint\":return c(e).geometry;case\"MultiLineString\":return l(e).geometry;case\"MultiPolygon\":return u(e).geometry;default:throw new Error(t+\" is invalid\")}},r.point=i,r.points=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return i(t,e)})),r)},r.polygon=a,r.polygons=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return a(t,e)})),r)},r.lineString=o,r.lineStrings=function(t,e,r){return void 0===r&&(r={}),s(t.map((function(t){return o(t,e)})),r)},r.featureCollection=s,r.multiLineString=l,r.multiPoint=c,r.multiPolygon=u,r.geometryCollection=function(t,e,r){return void 0===r&&(r={}),n({type:\"GeometryCollection\",geometries:t},e,r)},r.round=function(t,e){if(void 0===e&&(e=0),e&&!(e>=0))throw new Error(\"precision must be a positive number\");var r=Math.pow(10,e||0);return Math.round(t*r)/r},r.radiansToLength=f,r.lengthToRadians=h,r.lengthToDegrees=function(t,e){return p(h(t,e))},r.bearingToAzimuth=function(t){var e=t%360;return e<0&&(e+=360),e},r.radiansToDegrees=p,r.degreesToRadians=function(t){return t%360*Math.PI/180},r.convertLength=function(t,e,r){if(void 0===e&&(e=\"kilometers\"),void 0===r&&(r=\"kilometers\"),!(t>=0))throw new Error(\"length must be a positive number\");return f(h(t,e),r)},r.convertArea=function(t,e,n){if(void 0===e&&(e=\"meters\"),void 0===n&&(n=\"kilometers\"),!(t>=0))throw new Error(\"area must be a positive number\");var i=r.areaFactors[e];if(!i)throw new Error(\"invalid original units\");var a=r.areaFactors[n];if(!a)throw new Error(\"invalid final units\");return t/i*a},r.isNumber=d,r.isObject=function(t){return!!t&&t.constructor===Object},r.validateBBox=function(t){if(!t)throw new Error(\"bbox is required\");if(!Array.isArray(t))throw new Error(\"bbox must be an Array\");if(4!==t.length&&6!==t.length)throw new Error(\"bbox must be an Array of 4 or 6 numbers\");t.forEach((function(t){if(!d(t))throw new Error(\"bbox must only contain numbers\")}))},r.validateId=function(t){if(!t)throw new Error(\"id is required\");if(-1===[\"string\",\"number\"].indexOf(typeof t))throw new Error(\"id must be a number or a string\")},r.radians2degrees=function(){throw new Error(\"method has been renamed to `radiansToDegrees`\")},r.degrees2radians=function(){throw new Error(\"method has been renamed to `degreesToRadians`\")},r.distanceToDegrees=function(){throw new Error(\"method has been renamed to `lengthToDegrees`\")},r.distanceToRadians=function(){throw new Error(\"method has been renamed to `lengthToRadians`\")},r.radiansToDistance=function(){throw new Error(\"method has been renamed to `radiansToLength`\")},r.bearingToAngle=function(){throw new Error(\"method has been renamed to `bearingToAzimuth`\")},r.convertDistance=function(){throw new Error(\"method has been renamed to `convertLength`\")}},{}],63:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=t(\"@turf/helpers\");function i(t,e,r){if(null!==t)for(var n,a,o,s,l,c,u,f,h=0,p=0,d=t.type,g=\"FeatureCollection\"===d,m=\"Feature\"===d,v=g?t.features.length:1,y=0;y<v;y++){l=(f=!!(u=g?t.features[y].geometry:m?t.geometry:t)&&\"GeometryCollection\"===u.type)?u.geometries.length:1;for(var x=0;x<l;x++){var b=0,_=0;if(null!==(s=f?u.geometries[x]:u)){c=s.coordinates;var w=s.type;switch(h=!r||\"Polygon\"!==w&&\"MultiPolygon\"!==w?0:1,w){case null:break;case\"Point\":if(!1===e(c,p,y,b,_))return!1;p++,b++;break;case\"LineString\":case\"MultiPoint\":for(n=0;n<c.length;n++){if(!1===e(c[n],p,y,b,_))return!1;p++,\"MultiPoint\"===w&&b++}\"LineString\"===w&&b++;break;case\"Polygon\":case\"MultiLineString\":for(n=0;n<c.length;n++){for(a=0;a<c[n].length-h;a++){if(!1===e(c[n][a],p,y,b,_))return!1;p++}\"MultiLineString\"===w&&b++,\"Polygon\"===w&&_++}\"Polygon\"===w&&b++;break;case\"MultiPolygon\":for(n=0;n<c.length;n++){for(_=0,a=0;a<c[n].length;a++){for(o=0;o<c[n][a].length-h;o++){if(!1===e(c[n][a][o],p,y,b,_))return!1;p++}_++}b++}break;case\"GeometryCollection\":for(n=0;n<s.geometries.length;n++)if(!1===i(s.geometries[n],e,r))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}}}}}function a(t,e){var r;switch(t.type){case\"FeatureCollection\":for(r=0;r<t.features.length&&!1!==e(t.features[r].properties,r);r++);break;case\"Feature\":e(t.properties,0)}}function o(t,e){if(\"Feature\"===t.type)e(t,0);else if(\"FeatureCollection\"===t.type)for(var r=0;r<t.features.length&&!1!==e(t.features[r],r);r++);}function s(t,e){var r,n,i,a,o,s,l,c,u,f,h=0,p=\"FeatureCollection\"===t.type,d=\"Feature\"===t.type,g=p?t.features.length:1;for(r=0;r<g;r++){for(s=p?t.features[r].geometry:d?t.geometry:t,c=p?t.features[r].properties:d?t.properties:{},u=p?t.features[r].bbox:d?t.bbox:void 0,f=p?t.features[r].id:d?t.id:void 0,o=(l=!!s&&\"GeometryCollection\"===s.type)?s.geometries.length:1,i=0;i<o;i++)if(null!==(a=l?s.geometries[i]:s))switch(a.type){case\"Point\":case\"LineString\":case\"MultiPoint\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":if(!1===e(a,h,c,u,f))return!1;break;case\"GeometryCollection\":for(n=0;n<a.geometries.length;n++)if(!1===e(a.geometries[n],h,c,u,f))return!1;break;default:throw new Error(\"Unknown Geometry Type\")}else if(!1===e(null,h,c,u,f))return!1;h++}}function l(t,e){s(t,(function(t,r,i,a,o){var s,l=null===t?null:t.type;switch(l){case null:case\"Point\":case\"LineString\":case\"Polygon\":return!1!==e(n.feature(t,i,{bbox:a,id:o}),r,0)&&void 0}switch(l){case\"MultiPoint\":s=\"Point\";break;case\"MultiLineString\":s=\"LineString\";break;case\"MultiPolygon\":s=\"Polygon\"}for(var c=0;c<t.coordinates.length;c++){var u={type:s,coordinates:t.coordinates[c]};if(!1===e(n.feature(u,i),r,c))return!1}}))}function c(t,e){l(t,(function(t,r,a){var o=0;if(t.geometry){var s=t.geometry.type;if(\"Point\"!==s&&\"MultiPoint\"!==s){var l,c=0,u=0,f=0;return!1!==i(t,(function(i,s,h,p,d){if(void 0===l||r>c||p>u||d>f)return l=i,c=r,u=p,f=d,void(o=0);var g=n.lineString([l,i],t.properties);if(!1===e(g,r,a,d,o))return!1;o++,l=i}))&&void 0}}}))}function u(t,e){if(!t)throw new Error(\"geojson is required\");l(t,(function(t,r,i){if(null!==t.geometry){var a=t.geometry.type,o=t.geometry.coordinates;switch(a){case\"LineString\":if(!1===e(t,r,i,0,0))return!1;break;case\"Polygon\":for(var s=0;s<o.length;s++)if(!1===e(n.lineString(o[s],t.properties),r,i,s))return!1}}}))}r.coordEach=i,r.coordReduce=function(t,e,r,n){var a=r;return i(t,(function(t,n,i,o,s){a=0===n&&void 0===r?t:e(a,t,n,i,o,s)}),n),a},r.propEach=a,r.propReduce=function(t,e,r){var n=r;return a(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.featureEach=o,r.featureReduce=function(t,e,r){var n=r;return o(t,(function(t,i){n=0===i&&void 0===r?t:e(n,t,i)})),n},r.coordAll=function(t){var e=[];return i(t,(function(t){e.push(t)})),e},r.geomEach=s,r.geomReduce=function(t,e,r){var n=r;return s(t,(function(t,i,a,o,s){n=0===i&&void 0===r?t:e(n,t,i,a,o,s)})),n},r.flattenEach=l,r.flattenReduce=function(t,e,r){var n=r;return l(t,(function(t,i,a){n=0===i&&0===a&&void 0===r?t:e(n,t,i,a)})),n},r.segmentEach=c,r.segmentReduce=function(t,e,r){var n=r,i=!1;return c(t,(function(t,a,o,s,l){n=!1===i&&void 0===r?t:e(n,t,a,o,s,l),i=!0})),n},r.lineEach=u,r.lineReduce=function(t,e,r){var n=r;return u(t,(function(t,i,a,o){n=0===i&&void 0===r?t:e(n,t,i,a,o)})),n},r.findSegment=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.segmentIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":case\"MultiPoint\":return null;case\"LineString\":return s<0&&(s=c.length+s-1),n.lineString([c[s],c[s+1]],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s-1),n.lineString([c[o][s],c[o][s+1]],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s-1),n.lineString([c[a][s],c[a][s+1]],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s-1),n.lineString([c[a][o][s],c[a][o][s+1]],l,e)}throw new Error(\"geojson is invalid\")},r.findPoint=function(t,e){if(e=e||{},!n.isObject(e))throw new Error(\"options is invalid\");var r,i=e.featureIndex||0,a=e.multiFeatureIndex||0,o=e.geometryIndex||0,s=e.coordIndex||0,l=e.properties;switch(t.type){case\"FeatureCollection\":i<0&&(i=t.features.length+i),l=l||t.features[i].properties,r=t.features[i].geometry;break;case\"Feature\":l=l||t.properties,r=t.geometry;break;case\"Point\":case\"MultiPoint\":return null;case\"LineString\":case\"Polygon\":case\"MultiLineString\":case\"MultiPolygon\":r=t;break;default:throw new Error(\"geojson is invalid\")}if(null===r)return null;var c=r.coordinates;switch(r.type){case\"Point\":return n.point(c,l,e);case\"MultiPoint\":return a<0&&(a=c.length+a),n.point(c[a],l,e);case\"LineString\":return s<0&&(s=c.length+s),n.point(c[s],l,e);case\"Polygon\":return o<0&&(o=c.length+o),s<0&&(s=c[o].length+s),n.point(c[o][s],l,e);case\"MultiLineString\":return a<0&&(a=c.length+a),s<0&&(s=c[a].length+s),n.point(c[a][s],l,e);case\"MultiPolygon\":return a<0&&(a=c.length+a),o<0&&(o=c[a].length+o),s<0&&(s=c[a][o].length-s),n.point(c[a][o][s],l,e)}throw new Error(\"geojson is invalid\")}},{\"@turf/helpers\":62}],64:[function(t,e,r){\"use strict\";var n=\"undefined\"==typeof WeakMap?t(\"weak-map\"):WeakMap,i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=new n;e.exports=function(t){var e=o.get(t),r=e&&(e._triangleBuffer.handle||e._triangleBuffer.buffer);if(!r||!t.isBuffer(r)){var n=i(t,new Float32Array([-1,-1,-1,4,4,-1]));(e=a(t,[{buffer:n,type:t.FLOAT,size:2}]))._triangleBuffer=n,o.set(t,e)}e.bind(),t.drawArrays(t.TRIANGLES,0,3),e.unbind()}},{\"gl-buffer\":259,\"gl-vao\":358,\"weak-map\":602}],65:[function(t,e,r){e.exports=function(t){var e=0,r=0,n=0,i=0;return t.map((function(t){var a=(t=t.slice())[0],o=a.toUpperCase();if(a!=o)switch(t[0]=o,a){case\"a\":t[6]+=n,t[7]+=i;break;case\"v\":t[1]+=i;break;case\"h\":t[1]+=n;break;default:for(var s=1;s<t.length;)t[s++]+=n,t[s++]+=i}switch(o){case\"Z\":n=e,i=r;break;case\"H\":n=t[1];break;case\"V\":i=t[1];break;case\"M\":n=e=t[1],i=r=t[2];break;default:n=t[t.length-2],i=t[t.length-1]}return t}))}},{}],66:[function(t,e,r){var n=t(\"pad-left\");e.exports=function(t,e,r){e=\"number\"==typeof e?e:1,r=r||\": \";var i=t.split(/\\r?\\n/),a=String(i.length+e-1).length;return i.map((function(t,i){var o=i+e,s=String(o).length;return n(o,a-s)+r+t})).join(\"\\n\")}},{\"pad-left\":502}],67:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[0];for(var r=t[0].length,n=[t[0]],a=[0],o=1;o<e;++o)if(n.push(t[o]),i(n,r)){if(a.push(o),a.length===r+1)return a}else n.pop();return a};var n=t(\"robust-orientation\");function i(t,e){for(var r=new Array(e+1),i=0;i<t.length;++i)r[i]=t[i];for(i=0;i<=t.length;++i){for(var a=t.length;a<=e;++a){for(var o=new Array(e),s=0;s<e;++s)o[s]=Math.pow(a+1-i,s);r[a]=o}if(n.apply(void 0,r))return!0}return!1}},{\"robust-orientation\":548}],68:[function(t,e,r){\"use strict\";e.exports=function(t,e){return n(e).filter((function(r){for(var n=new Array(r.length),a=0;a<r.length;++a)n[a]=e[r[a]];return i(n)*t<1}))};var n=t(\"delaunay-triangulate\"),i=t(\"circumradius\")},{circumradius:119,\"delaunay-triangulate\":171}],69:[function(t,e,r){e.exports=function(t,e){return i(n(t,e))};var n=t(\"alpha-complex\"),i=t(\"simplicial-complex-boundary\")},{\"alpha-complex\":68,\"simplicial-complex-boundary\":555}],70:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!t||null==t.length)throw Error(\"Argument should be an array\");e=null==e?1:Math.floor(e);for(var r=Array(2*e),n=0;n<e;n++){for(var i=-1/0,a=1/0,o=n,s=t.length;o<s;o+=e)t[o]>i&&(i=t[o]),t[o]<a&&(a=t[o]);r[n]=a,r[e+n]=i}return r}},{}],71:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\");e.exports=function(t,e,r){if(!t||null==t.length)throw Error(\"Argument should be an array\");null==e&&(e=1);null==r&&(r=n(t,e));for(var i=0;i<e;i++){var a=r[e+i],o=r[i],s=i,l=t.length;if(a===1/0&&o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:t[s]===o?0:.5;else if(a===1/0)for(s=i;s<l;s+=e)t[s]=t[s]===a?1:0;else if(o===-1/0)for(s=i;s<l;s+=e)t[s]=t[s]===o?0:1;else{var c=a-o;for(s=i;s<l;s+=e)isNaN(t[s])||(t[s]=0===c?.5:(t[s]-o)/c)}}return t}},{\"array-bounds\":70}],72:[function(t,e,r){e.exports=function(t,e){var r=\"number\"==typeof t,n=\"number\"==typeof e;r&&!n?(e=t,t=0):r||n||(t=0,e=0);var i=(e|=0)-(t|=0);if(i<0)throw new Error(\"array length must be positive\");for(var a=new Array(i),o=0,s=t;o<i;o++,s++)a[o]=s;return a}},{}],73:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"object-assign\");\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>\n",
       " * @license  MIT\n",
       " */function i(t,e){if(t===e)return 0;for(var r=t.length,n=e.length,i=0,a=Math.min(r,n);i<a;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0}function a(t){return r.Buffer&&\"function\"==typeof r.Buffer.isBuffer?r.Buffer.isBuffer(t):!(null==t||!t._isBuffer)}var o=t(\"util/\"),s=Object.prototype.hasOwnProperty,l=Array.prototype.slice,c=\"foo\"===function(){}.name;function u(t){return Object.prototype.toString.call(t)}function f(t){return!a(t)&&(\"function\"==typeof r.ArrayBuffer&&(\"function\"==typeof ArrayBuffer.isView?ArrayBuffer.isView(t):!!t&&(t instanceof DataView||!!(t.buffer&&t.buffer instanceof ArrayBuffer))))}var h=e.exports=y,p=/\\s*function\\s+([^\\(\\s]*)\\s*/;function d(t){if(o.isFunction(t)){if(c)return t.name;var e=t.toString().match(p);return e&&e[1]}}function g(t,e){return\"string\"==typeof t?t.length<e?t:t.slice(0,e):t}function m(t){if(c||!o.isFunction(t))return o.inspect(t);var e=d(t);return\"[Function\"+(e?\": \"+e:\"\")+\"]\"}function v(t,e,r,n,i){throw new h.AssertionError({message:r,actual:t,expected:e,operator:n,stackStartFunction:i})}function y(t,e){t||v(t,!0,e,\"==\",h.ok)}function x(t,e,r,n){if(t===e)return!0;if(a(t)&&a(e))return 0===i(t,e);if(o.isDate(t)&&o.isDate(e))return t.getTime()===e.getTime();if(o.isRegExp(t)&&o.isRegExp(e))return t.source===e.source&&t.global===e.global&&t.multiline===e.multiline&&t.lastIndex===e.lastIndex&&t.ignoreCase===e.ignoreCase;if(null!==t&&\"object\"==typeof t||null!==e&&\"object\"==typeof e){if(f(t)&&f(e)&&u(t)===u(e)&&!(t instanceof Float32Array||t instanceof Float64Array))return 0===i(new Uint8Array(t.buffer),new Uint8Array(e.buffer));if(a(t)!==a(e))return!1;var s=(n=n||{actual:[],expected:[]}).actual.indexOf(t);return-1!==s&&s===n.expected.indexOf(e)||(n.actual.push(t),n.expected.push(e),function(t,e,r,n){if(null==t||null==e)return!1;if(o.isPrimitive(t)||o.isPrimitive(e))return t===e;if(r&&Object.getPrototypeOf(t)!==Object.getPrototypeOf(e))return!1;var i=b(t),a=b(e);if(i&&!a||!i&&a)return!1;if(i)return t=l.call(t),e=l.call(e),x(t,e,r);var s,c,u=T(t),f=T(e);if(u.length!==f.length)return!1;for(u.sort(),f.sort(),c=u.length-1;c>=0;c--)if(u[c]!==f[c])return!1;for(c=u.length-1;c>=0;c--)if(s=u[c],!x(t[s],e[s],r,n))return!1;return!0}(t,e,r,n))}return r?t===e:t==e}function b(t){return\"[object Arguments]\"==Object.prototype.toString.call(t)}function _(t,e){if(!t||!e)return!1;if(\"[object RegExp]\"==Object.prototype.toString.call(e))return e.test(t);try{if(t instanceof e)return!0}catch(t){}return!Error.isPrototypeOf(e)&&!0===e.call({},t)}function w(t,e,r,n){var i;if(\"function\"!=typeof e)throw new TypeError('\"block\" argument must be a function');\"string\"==typeof r&&(n=r,r=null),i=function(t){var e;try{t()}catch(t){e=t}return e}(e),n=(r&&r.name?\" (\"+r.name+\").\":\".\")+(n?\" \"+n:\".\"),t&&!i&&v(i,r,\"Missing expected exception\"+n);var a=\"string\"==typeof n,s=!t&&i&&!r;if((!t&&o.isError(i)&&a&&_(i,r)||s)&&v(i,r,\"Got unwanted exception\"+n),t&&i&&r&&!_(i,r)||!t&&i)throw i}h.AssertionError=function(t){this.name=\"AssertionError\",this.actual=t.actual,this.expected=t.expected,this.operator=t.operator,t.message?(this.message=t.message,this.generatedMessage=!1):(this.message=function(t){return g(m(t.actual),128)+\" \"+t.operator+\" \"+g(m(t.expected),128)}(this),this.generatedMessage=!0);var e=t.stackStartFunction||v;if(Error.captureStackTrace)Error.captureStackTrace(this,e);else{var r=new Error;if(r.stack){var n=r.stack,i=d(e),a=n.indexOf(\"\\n\"+i);if(a>=0){var o=n.indexOf(\"\\n\",a+1);n=n.substring(o+1)}this.stack=n}}},o.inherits(h.AssertionError,Error),h.fail=v,h.ok=y,h.equal=function(t,e,r){t!=e&&v(t,e,r,\"==\",h.equal)},h.notEqual=function(t,e,r){t==e&&v(t,e,r,\"!=\",h.notEqual)},h.deepEqual=function(t,e,r){x(t,e,!1)||v(t,e,r,\"deepEqual\",h.deepEqual)},h.deepStrictEqual=function(t,e,r){x(t,e,!0)||v(t,e,r,\"deepStrictEqual\",h.deepStrictEqual)},h.notDeepEqual=function(t,e,r){x(t,e,!1)&&v(t,e,r,\"notDeepEqual\",h.notDeepEqual)},h.notDeepStrictEqual=function t(e,r,n){x(e,r,!0)&&v(e,r,n,\"notDeepStrictEqual\",t)},h.strictEqual=function(t,e,r){t!==e&&v(t,e,r,\"===\",h.strictEqual)},h.notStrictEqual=function(t,e,r){t===e&&v(t,e,r,\"!==\",h.notStrictEqual)},h.throws=function(t,e,r){w(!0,t,e,r)},h.doesNotThrow=function(t,e,r){w(!1,t,e,r)},h.ifError=function(t){if(t)throw t},h.strict=n((function t(e,r){e||v(e,!0,r,\"==\",t)}),h,{equal:h.strictEqual,deepEqual:h.deepStrictEqual,notEqual:h.notStrictEqual,notDeepEqual:h.notDeepStrictEqual}),h.strict.strict=h.strict;var T=Object.keys||function(t){var e=[];for(var r in t)s.call(t,r)&&e.push(r);return e}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"object-assign\":499,\"util/\":76}],74:[function(t,e,r){\"function\"==typeof Object.create?e.exports=function(t,e){t.super_=e,t.prototype=Object.create(e.prototype,{constructor:{value:t,enumerable:!1,writable:!0,configurable:!0}})}:e.exports=function(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}},{}],75:[function(t,e,r){e.exports=function(t){return t&&\"object\"==typeof t&&\"function\"==typeof t.copy&&\"function\"==typeof t.fill&&\"function\"==typeof t.readUInt8}},{}],76:[function(t,e,r){(function(e,n){(function(){var i=/%[sdj%]/g;r.format=function(t){if(!v(t)){for(var e=[],r=0;r<arguments.length;r++)e.push(s(arguments[r]));return e.join(\" \")}r=1;for(var n=arguments,a=n.length,o=String(t).replace(i,(function(t){if(\"%%\"===t)return\"%\";if(r>=a)return t;switch(t){case\"%s\":return String(n[r++]);case\"%d\":return Number(n[r++]);case\"%j\":try{return JSON.stringify(n[r++])}catch(t){return\"[Circular]\"}default:return t}})),l=n[r];r<a;l=n[++r])g(l)||!b(l)?o+=\" \"+l:o+=\" \"+s(l);return o},r.deprecate=function(t,i){if(y(n.process))return function(){return r.deprecate(t,i).apply(this,arguments)};if(!0===e.noDeprecation)return t;var a=!1;return function(){if(!a){if(e.throwDeprecation)throw new Error(i);e.traceDeprecation?console.trace(i):console.error(i),a=!0}return t.apply(this,arguments)}};var a,o={};function s(t,e){var n={seen:[],stylize:c};return arguments.length>=3&&(n.depth=arguments[2]),arguments.length>=4&&(n.colors=arguments[3]),d(e)?n.showHidden=e:e&&r._extend(n,e),y(n.showHidden)&&(n.showHidden=!1),y(n.depth)&&(n.depth=2),y(n.colors)&&(n.colors=!1),y(n.customInspect)&&(n.customInspect=!0),n.colors&&(n.stylize=l),u(n,t,n.depth)}function l(t,e){var r=s.styles[e];return r?\"\\x1b[\"+s.colors[r][0]+\"m\"+t+\"\\x1b[\"+s.colors[r][1]+\"m\":t}function c(t,e){return t}function u(t,e,n){if(t.customInspect&&e&&T(e.inspect)&&e.inspect!==r.inspect&&(!e.constructor||e.constructor.prototype!==e)){var i=e.inspect(n,t);return v(i)||(i=u(t,i,n)),i}var a=function(t,e){if(y(e))return t.stylize(\"undefined\",\"undefined\");if(v(e)){var r=\"'\"+JSON.stringify(e).replace(/^\"|\"$/g,\"\").replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"')+\"'\";return t.stylize(r,\"string\")}if(m(e))return t.stylize(\"\"+e,\"number\");if(d(e))return t.stylize(\"\"+e,\"boolean\");if(g(e))return t.stylize(\"null\",\"null\")}(t,e);if(a)return a;var o=Object.keys(e),s=function(t){var e={};return t.forEach((function(t,r){e[t]=!0})),e}(o);if(t.showHidden&&(o=Object.getOwnPropertyNames(e)),w(e)&&(o.indexOf(\"message\")>=0||o.indexOf(\"description\")>=0))return f(e);if(0===o.length){if(T(e)){var l=e.name?\": \"+e.name:\"\";return t.stylize(\"[Function\"+l+\"]\",\"special\")}if(x(e))return t.stylize(RegExp.prototype.toString.call(e),\"regexp\");if(_(e))return t.stylize(Date.prototype.toString.call(e),\"date\");if(w(e))return f(e)}var c,b=\"\",k=!1,M=[\"{\",\"}\"];(p(e)&&(k=!0,M=[\"[\",\"]\"]),T(e))&&(b=\" [Function\"+(e.name?\": \"+e.name:\"\")+\"]\");return x(e)&&(b=\" \"+RegExp.prototype.toString.call(e)),_(e)&&(b=\" \"+Date.prototype.toUTCString.call(e)),w(e)&&(b=\" \"+f(e)),0!==o.length||k&&0!=e.length?n<0?x(e)?t.stylize(RegExp.prototype.toString.call(e),\"regexp\"):t.stylize(\"[Object]\",\"special\"):(t.seen.push(e),c=k?function(t,e,r,n,i){for(var a=[],o=0,s=e.length;o<s;++o)E(e,String(o))?a.push(h(t,e,r,n,String(o),!0)):a.push(\"\");return i.forEach((function(i){i.match(/^\\d+$/)||a.push(h(t,e,r,n,i,!0))})),a}(t,e,n,s,o):o.map((function(r){return h(t,e,n,s,r,k)})),t.seen.pop(),function(t,e,r){if(t.reduce((function(t,e){return e.indexOf(\"\\n\")>=0&&0,t+e.replace(/\\u001b\\[\\d\\d?m/g,\"\").length+1}),0)>60)return r[0]+(\"\"===e?\"\":e+\"\\n \")+\" \"+t.join(\",\\n  \")+\" \"+r[1];return r[0]+e+\" \"+t.join(\", \")+\" \"+r[1]}(c,b,M)):M[0]+b+M[1]}function f(t){return\"[\"+Error.prototype.toString.call(t)+\"]\"}function h(t,e,r,n,i,a){var o,s,l;if((l=Object.getOwnPropertyDescriptor(e,i)||{value:e[i]}).get?s=l.set?t.stylize(\"[Getter/Setter]\",\"special\"):t.stylize(\"[Getter]\",\"special\"):l.set&&(s=t.stylize(\"[Setter]\",\"special\")),E(n,i)||(o=\"[\"+i+\"]\"),s||(t.seen.indexOf(l.value)<0?(s=g(r)?u(t,l.value,null):u(t,l.value,r-1)).indexOf(\"\\n\")>-1&&(s=a?s.split(\"\\n\").map((function(t){return\"  \"+t})).join(\"\\n\").substr(2):\"\\n\"+s.split(\"\\n\").map((function(t){return\"   \"+t})).join(\"\\n\")):s=t.stylize(\"[Circular]\",\"special\")),y(o)){if(a&&i.match(/^\\d+$/))return s;(o=JSON.stringify(\"\"+i)).match(/^\"([a-zA-Z_][a-zA-Z_0-9]*)\"$/)?(o=o.substr(1,o.length-2),o=t.stylize(o,\"name\")):(o=o.replace(/'/g,\"\\\\'\").replace(/\\\\\"/g,'\"').replace(/(^\"|\"$)/g,\"'\"),o=t.stylize(o,\"string\"))}return o+\": \"+s}function p(t){return Array.isArray(t)}function d(t){return\"boolean\"==typeof t}function g(t){return null===t}function m(t){return\"number\"==typeof t}function v(t){return\"string\"==typeof t}function y(t){return void 0===t}function x(t){return b(t)&&\"[object RegExp]\"===k(t)}function b(t){return\"object\"==typeof t&&null!==t}function _(t){return b(t)&&\"[object Date]\"===k(t)}function w(t){return b(t)&&(\"[object Error]\"===k(t)||t instanceof Error)}function T(t){return\"function\"==typeof t}function k(t){return Object.prototype.toString.call(t)}function M(t){return t<10?\"0\"+t.toString(10):t.toString(10)}r.debuglog=function(t){if(y(a)&&(a=e.env.NODE_DEBUG||\"\"),t=t.toUpperCase(),!o[t])if(new RegExp(\"\\\\b\"+t+\"\\\\b\",\"i\").test(a)){var n=e.pid;o[t]=function(){var e=r.format.apply(r,arguments);console.error(\"%s %d: %s\",t,n,e)}}else o[t]=function(){};return o[t]},r.inspect=s,s.colors={bold:[1,22],italic:[3,23],underline:[4,24],inverse:[7,27],white:[37,39],grey:[90,39],black:[30,39],blue:[34,39],cyan:[36,39],green:[32,39],magenta:[35,39],red:[31,39],yellow:[33,39]},s.styles={special:\"cyan\",number:\"yellow\",boolean:\"yellow\",undefined:\"grey\",null:\"bold\",string:\"green\",date:\"magenta\",regexp:\"red\"},r.isArray=p,r.isBoolean=d,r.isNull=g,r.isNullOrUndefined=function(t){return null==t},r.isNumber=m,r.isString=v,r.isSymbol=function(t){return\"symbol\"==typeof t},r.isUndefined=y,r.isRegExp=x,r.isObject=b,r.isDate=_,r.isError=w,r.isFunction=T,r.isPrimitive=function(t){return null===t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||\"symbol\"==typeof t||\"undefined\"==typeof t},r.isBuffer=t(\"./support/isBuffer\");var A=[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"];function S(){var t=new Date,e=[M(t.getHours()),M(t.getMinutes()),M(t.getSeconds())].join(\":\");return[t.getDate(),A[t.getMonth()],e].join(\" \")}function E(t,e){return Object.prototype.hasOwnProperty.call(t,e)}r.log=function(){console.log(\"%s - %s\",S(),r.format.apply(r,arguments))},r.inherits=t(\"inherits\"),r._extend=function(t,e){if(!e||!b(e))return t;for(var r=Object.keys(e),n=r.length;n--;)t[r[n]]=e[r[n]];return t}}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./support/isBuffer\":75,_process:526,inherits:74}],77:[function(t,e,r){e.exports=function(t){return atob(t)}},{}],78:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=e.length,a=new Array(r+1),o=0;o<r;++o){for(var s=new Array(r+1),l=0;l<=r;++l)s[l]=t[l][o];a[o]=s}a[r]=new Array(r+1);for(o=0;o<=r;++o)a[r][o]=1;var c=new Array(r+1);for(o=0;o<r;++o)c[o]=e[o];c[r]=1;var u=n(a,c),f=i(u[r+1]);0===f&&(f=1);var h=new Array(r+1);for(o=0;o<=r;++o)h[o]=i(u[o])/f;return h};var n=t(\"robust-linear-solve\");function i(t){for(var e=0,r=0;r<t.length;++r)e+=t[r];return e}},{\"robust-linear-solve\":547}],79:[function(t,e,r){\"use strict\";r.byteLength=function(t){var e=c(t),r=e[0],n=e[1];return 3*(r+n)/4-n},r.toByteArray=function(t){var e,r,n=c(t),o=n[0],s=n[1],l=new a(function(t,e,r){return 3*(e+r)/4-r}(0,o,s)),u=0,f=s>0?o-4:o;for(r=0;r<f;r+=4)e=i[t.charCodeAt(r)]<<18|i[t.charCodeAt(r+1)]<<12|i[t.charCodeAt(r+2)]<<6|i[t.charCodeAt(r+3)],l[u++]=e>>16&255,l[u++]=e>>8&255,l[u++]=255&e;2===s&&(e=i[t.charCodeAt(r)]<<2|i[t.charCodeAt(r+1)]>>4,l[u++]=255&e);1===s&&(e=i[t.charCodeAt(r)]<<10|i[t.charCodeAt(r+1)]<<4|i[t.charCodeAt(r+2)]>>2,l[u++]=e>>8&255,l[u++]=255&e);return l},r.fromByteArray=function(t){for(var e,r=t.length,i=r%3,a=[],o=0,s=r-i;o<s;o+=16383)a.push(u(t,o,o+16383>s?s:o+16383));1===i?(e=t[r-1],a.push(n[e>>2]+n[e<<4&63]+\"==\")):2===i&&(e=(t[r-2]<<8)+t[r-1],a.push(n[e>>10]+n[e>>4&63]+n[e<<2&63]+\"=\"));return a.join(\"\")};for(var n=[],i=[],a=\"undefined\"!=typeof Uint8Array?Uint8Array:Array,o=\"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/\",s=0,l=o.length;s<l;++s)n[s]=o[s],i[o.charCodeAt(s)]=s;function c(t){var e=t.length;if(e%4>0)throw new Error(\"Invalid string. Length must be a multiple of 4\");var r=t.indexOf(\"=\");return-1===r&&(r=e),[r,r===e?0:4-r%4]}function u(t,e,r){for(var i,a,o=[],s=e;s<r;s+=3)i=(t[s]<<16&16711680)+(t[s+1]<<8&65280)+(255&t[s+2]),o.push(n[(a=i)>>18&63]+n[a>>12&63]+n[a>>6&63]+n[63&a]);return o.join(\"\")}i[\"-\".charCodeAt(0)]=62,i[\"_\".charCodeAt(0)]=63},{}],80:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).add(e[0].mul(t[1])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],81:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t[0].mul(e[1]).cmp(e[0].mul(t[1]))}},{}],82:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]),t[1].mul(e[0]))}},{\"./lib/rationalize\":90}],83:[function(t,e,r){\"use strict\";var n=t(\"./is-rat\"),i=t(\"./lib/is-bn\"),a=t(\"./lib/num-to-bn\"),o=t(\"./lib/str-to-bn\"),s=t(\"./lib/rationalize\"),l=t(\"./div\");e.exports=function t(e,r){if(n(e))return r?l(e,t(r)):[e[0].clone(),e[1].clone()];var c,u,f=0;if(i(e))c=e.clone();else if(\"string\"==typeof e)c=o(e);else{if(0===e)return[a(0),a(1)];if(e===Math.floor(e))c=a(e);else{for(;e!==Math.floor(e);)e*=Math.pow(2,256),f-=256;c=a(e)}}if(n(r))c.mul(r[1]),u=r[0].clone();else if(i(r))u=r.clone();else if(\"string\"==typeof r)u=o(r);else if(r)if(r===Math.floor(r))u=a(r);else{for(;r!==Math.floor(r);)r*=Math.pow(2,256),f+=256;u=a(r)}else u=a(1);f>0?c=c.ushln(f):f<0&&(u=u.ushln(-f));return s(c,u)}},{\"./div\":82,\"./is-rat\":84,\"./lib/is-bn\":88,\"./lib/num-to-bn\":89,\"./lib/rationalize\":90,\"./lib/str-to-bn\":91}],84:[function(t,e,r){\"use strict\";var n=t(\"./lib/is-bn\");e.exports=function(t){return Array.isArray(t)&&2===t.length&&n(t[0])&&n(t[1])}},{\"./lib/is-bn\":88}],85:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return t.cmp(new n(0))}},{\"bn.js\":99}],86:[function(t,e,r){\"use strict\";var n=t(\"./bn-sign\");e.exports=function(t){var e=t.length,r=t.words,i=0;if(1===e)i=r[0];else if(2===e)i=r[0]+67108864*r[1];else for(var a=0;a<e;a++){var o=r[a];i+=o*Math.pow(67108864,a)}return n(t)*i}},{\"./bn-sign\":85}],87:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=t(\"bit-twiddle\").countTrailingZeros;e.exports=function(t){var e=i(n.lo(t));if(e<32)return e;var r=i(n.hi(t));if(r>20)return 52;return r+32}},{\"bit-twiddle\":97,\"double-bits\":173}],88:[function(t,e,r){\"use strict\";t(\"bn.js\");e.exports=function(t){return t&&\"object\"==typeof t&&Boolean(t.words)}},{\"bn.js\":99}],89:[function(t,e,r){\"use strict\";var n=t(\"bn.js\"),i=t(\"double-bits\");e.exports=function(t){var e=i.exponent(t);return e<52?new n(t):new n(t*Math.pow(2,52-e)).ushln(e-52)}},{\"bn.js\":99,\"double-bits\":173}],90:[function(t,e,r){\"use strict\";var n=t(\"./num-to-bn\"),i=t(\"./bn-sign\");e.exports=function(t,e){var r=i(t),a=i(e);if(0===r)return[n(0),n(1)];if(0===a)return[n(0),n(0)];a<0&&(t=t.neg(),e=e.neg());var o=t.gcd(e);if(o.cmpn(1))return[t.div(o),e.div(o)];return[t,e]}},{\"./bn-sign\":85,\"./num-to-bn\":89}],91:[function(t,e,r){\"use strict\";var n=t(\"bn.js\");e.exports=function(t){return new n(t)}},{\"bn.js\":99}],92:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[0]),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],93:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-sign\");e.exports=function(t){return n(t[0])*n(t[1])}},{\"./lib/bn-sign\":85}],94:[function(t,e,r){\"use strict\";var n=t(\"./lib/rationalize\");e.exports=function(t,e){return n(t[0].mul(e[1]).sub(t[1].mul(e[0])),t[1].mul(e[1]))}},{\"./lib/rationalize\":90}],95:[function(t,e,r){\"use strict\";var n=t(\"./lib/bn-to-num\"),i=t(\"./lib/ctz\");e.exports=function(t){var e=t[0],r=t[1];if(0===e.cmpn(0))return 0;var a=e.abs().divmod(r.abs()),o=a.div,s=n(o),l=a.mod,c=e.negative!==r.negative?-1:1;if(0===l.cmpn(0))return c*s;if(s){var u=i(s)+4,f=n(l.ushln(u).divRound(r));return c*(s+f*Math.pow(2,-u))}var h=r.bitLength()-l.bitLength()+53;f=n(l.ushln(h).divRound(r));return h<1023?c*f*Math.pow(2,-h):(f*=Math.pow(2,-1023),c*f*Math.pow(2,1023-h))}},{\"./lib/bn-to-num\":86,\"./lib/ctz\":87}],96:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",i?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a[m]\"];return i?e.indexOf(\"c\")<0?a.push(\";if(x===y){return m}else if(x<=y){\"):a.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):a.push(\";if(\",e,\"){i=m;\"),r?a.push(\"l=m+1}else{h=m-1}\"):a.push(\"h=m-1}else{l=m+1}\"),a.push(\"}\"),i?a.push(\"return -1};\"):a.push(\"return i};\"),a.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(typeof(c)==='function'){return P(a,(l===void 0)?0:l|0,(h===void 0)?a.length-1:h|0,y,c)}else{return A(a,(c===void 0)?0:c|0,(l===void 0)?a.length-1:l|0,y)}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],97:[function(t,e,r){\"use strict\";function n(t){var e=32;return(t&=-t)&&e--,65535&t&&(e-=16),16711935&t&&(e-=8),252645135&t&&(e-=4),858993459&t&&(e-=2),1431655765&t&&(e-=1),e}r.INT_BITS=32,r.INT_MAX=2147483647,r.INT_MIN=-1<<31,r.sign=function(t){return(t>0)-(t<0)},r.abs=function(t){var e=t>>31;return(t^e)-e},r.min=function(t,e){return e^(t^e)&-(t<e)},r.max=function(t,e){return t^(t^e)&-(t<e)},r.isPow2=function(t){return!(t&t-1||!t)},r.log2=function(t){var e,r;return e=(t>65535)<<4,e|=r=((t>>>=e)>255)<<3,e|=r=((t>>>=r)>15)<<2,(e|=r=((t>>>=r)>3)<<1)|(t>>>=r)>>1},r.log10=function(t){return t>=1e9?9:t>=1e8?8:t>=1e7?7:t>=1e6?6:t>=1e5?5:t>=1e4?4:t>=1e3?3:t>=100?2:t>=10?1:0},r.popCount=function(t){return 16843009*((t=(858993459&(t-=t>>>1&1431655765))+(t>>>2&858993459))+(t>>>4)&252645135)>>>24},r.countTrailingZeros=n,r.nextPow2=function(t){return t+=0===t,--t,t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)+1},r.prevPow2=function(t){return t|=t>>>1,t|=t>>>2,t|=t>>>4,t|=t>>>8,(t|=t>>>16)-(t>>>1)},r.parity=function(t){return t^=t>>>16,t^=t>>>8,t^=t>>>4,27030>>>(t&=15)&1};var i=new Array(256);!function(t){for(var e=0;e<256;++e){var r=e,n=e,i=7;for(r>>>=1;r;r>>>=1)n<<=1,n|=1&r,--i;t[e]=n<<i&255}}(i),r.reverse=function(t){return i[255&t]<<24|i[t>>>8&255]<<16|i[t>>>16&255]<<8|i[t>>>24&255]},r.interleave2=function(t,e){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t&=65535)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e&=65535)|e<<8))|e<<4))|e<<2))|e<<1))<<1},r.deinterleave2=function(t,e){return(t=65535&((t=16711935&((t=252645135&((t=858993459&((t=t>>>e&1431655765)|t>>>1))|t>>>2))|t>>>4))|t>>>16))<<16>>16},r.interleave3=function(t,e,r){return t=1227133513&((t=3272356035&((t=251719695&((t=4278190335&((t&=1023)|t<<16))|t<<8))|t<<4))|t<<2),(t|=(e=1227133513&((e=3272356035&((e=251719695&((e=4278190335&((e&=1023)|e<<16))|e<<8))|e<<4))|e<<2))<<1)|(r=1227133513&((r=3272356035&((r=251719695&((r=4278190335&((r&=1023)|r<<16))|r<<8))|r<<4))|r<<2))<<2},r.deinterleave3=function(t,e){return(t=1023&((t=4278190335&((t=251719695&((t=3272356035&((t=t>>>e&1227133513)|t>>>2))|t>>>4))|t>>>8))|t>>>16))<<22>>22},r.nextCombination=function(t){var e=t|t-1;return e+1|(~e&-~e)-1>>>n(t)+1}},{}],98:[function(t,e,r){\"use strict\";var n=t(\"clamp\");e.exports=function(t,e){e||(e={});var r,o,s,l,c,u,f,h,p,d,g,m=null==e.cutoff?.25:e.cutoff,v=null==e.radius?8:e.radius,y=e.channel||0;if(ArrayBuffer.isView(t)||Array.isArray(t)){if(!e.width||!e.height)throw Error(\"For raw data width and height should be provided by options\");r=e.width,o=e.height,l=t,u=e.stride?e.stride:Math.floor(t.length/r/o)}else window.HTMLCanvasElement&&t instanceof window.HTMLCanvasElement?(f=(h=t).getContext(\"2d\"),r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.CanvasRenderingContext2D&&t instanceof window.CanvasRenderingContext2D?(h=t.canvas,f=t,r=h.width,o=h.height,p=f.getImageData(0,0,r,o),l=p.data,u=4):window.ImageData&&t instanceof window.ImageData&&(p=t,r=t.width,o=t.height,l=p.data,u=4);if(s=Math.max(r,o),window.Uint8ClampedArray&&l instanceof window.Uint8ClampedArray||window.Uint8Array&&l instanceof window.Uint8Array)for(c=l,l=Array(r*o),d=0,g=c.length;d<g;d++)l[d]=c[d*u+y]/255;else if(1!==u)throw Error(\"Raw data can have only 1 value per pixel\");var x=Array(r*o),b=Array(r*o),_=Array(s),w=Array(s),T=Array(s+1),k=Array(s);for(d=0,g=r*o;d<g;d++){var M=l[d];x[d]=1===M?0:0===M?i:Math.pow(Math.max(0,.5-M),2),b[d]=1===M?i:0===M?0:Math.pow(Math.max(0,M-.5),2)}a(x,r,o,_,w,k,T),a(b,r,o,_,w,k,T);var A=window.Float32Array?new Float32Array(r*o):new Array(r*o);for(d=0,g=r*o;d<g;d++)A[d]=n(1-((x[d]-b[d])/v+m),0,1);return A};var i=1e20;function a(t,e,r,n,i,a,s){for(var l=0;l<e;l++){for(var c=0;c<r;c++)n[c]=t[c*e+l];for(o(n,i,a,s,r),c=0;c<r;c++)t[c*e+l]=i[c]}for(c=0;c<r;c++){for(l=0;l<e;l++)n[l]=t[c*e+l];for(o(n,i,a,s,e),l=0;l<e;l++)t[c*e+l]=Math.sqrt(i[l])}}function o(t,e,r,n,a){r[0]=0,n[0]=-i,n[1]=+i;for(var o=1,s=0;o<a;o++){for(var l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);l<=n[s];)s--,l=(t[o]+o*o-(t[r[s]]+r[s]*r[s]))/(2*o-2*r[s]);r[++s]=o,n[s]=l,n[s+1]=+i}for(o=0,s=0;o<a;o++){for(;n[s+1]<o;)s++;e[o]=(o-r[s])*(o-r[s])+t[r[s]]}}},{clamp:120}],99:[function(t,e,r){!function(e,r){\"use strict\";function n(t,e){if(!t)throw new Error(e||\"Assertion failed\")}function i(t,e){t.super_=e;var r=function(){};r.prototype=e.prototype,t.prototype=new r,t.prototype.constructor=t}function a(t,e,r){if(a.isBN(t))return t;this.negative=0,this.words=null,this.length=0,this.red=null,null!==t&&(\"le\"!==e&&\"be\"!==e||(r=e,e=10),this._init(t||0,e||10,r||\"be\"))}var o;\"object\"==typeof e?e.exports=a:r.BN=a,a.BN=a,a.wordSize=26;try{o=t(\"buffer\").Buffer}catch(t){}function s(t,e,r){for(var n=0,i=Math.min(t.length,r),a=e;a<i;a++){var o=t.charCodeAt(a)-48;n<<=4,n|=o>=49&&o<=54?o-49+10:o>=17&&o<=22?o-17+10:15&o}return n}function l(t,e,r,n){for(var i=0,a=Math.min(t.length,r),o=e;o<a;o++){var s=t.charCodeAt(o)-48;i*=n,i+=s>=49?s-49+10:s>=17?s-17+10:s}return i}a.isBN=function(t){return t instanceof a||null!==t&&\"object\"==typeof t&&t.constructor.wordSize===a.wordSize&&Array.isArray(t.words)},a.max=function(t,e){return t.cmp(e)>0?t:e},a.min=function(t,e){return t.cmp(e)<0?t:e},a.prototype._init=function(t,e,r){if(\"number\"==typeof t)return this._initNumber(t,e,r);if(\"object\"==typeof t)return this._initArray(t,e,r);\"hex\"===e&&(e=16),n(e===(0|e)&&e>=2&&e<=36);var i=0;\"-\"===(t=t.toString().replace(/\\s+/g,\"\"))[0]&&i++,16===e?this._parseHex(t,i):this._parseBase(t,e,i),\"-\"===t[0]&&(this.negative=1),this.strip(),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initNumber=function(t,e,r){t<0&&(this.negative=1,t=-t),t<67108864?(this.words=[67108863&t],this.length=1):t<4503599627370496?(this.words=[67108863&t,t/67108864&67108863],this.length=2):(n(t<9007199254740992),this.words=[67108863&t,t/67108864&67108863,1],this.length=3),\"le\"===r&&this._initArray(this.toArray(),e,r)},a.prototype._initArray=function(t,e,r){if(n(\"number\"==typeof t.length),t.length<=0)return this.words=[0],this.length=1,this;this.length=Math.ceil(t.length/3),this.words=new Array(this.length);for(var i=0;i<this.length;i++)this.words[i]=0;var a,o,s=0;if(\"be\"===r)for(i=t.length-1,a=0;i>=0;i-=3)o=t[i]|t[i-1]<<8|t[i-2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);else if(\"le\"===r)for(i=0,a=0;i<t.length;i+=3)o=t[i]|t[i+1]<<8|t[i+2]<<16,this.words[a]|=o<<s&67108863,this.words[a+1]=o>>>26-s&67108863,(s+=24)>=26&&(s-=26,a++);return this.strip()},a.prototype._parseHex=function(t,e){this.length=Math.ceil((t.length-e)/6),this.words=new Array(this.length);for(var r=0;r<this.length;r++)this.words[r]=0;var n,i,a=0;for(r=t.length-6,n=0;r>=e;r-=6)i=s(t,r,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303,(a+=24)>=26&&(a-=26,n++);r+6!==e&&(i=s(t,e,r+6),this.words[n]|=i<<a&67108863,this.words[n+1]|=i>>>26-a&4194303),this.strip()},a.prototype._parseBase=function(t,e,r){this.words=[0],this.length=1;for(var n=0,i=1;i<=67108863;i*=e)n++;n--,i=i/e|0;for(var a=t.length-r,o=a%n,s=Math.min(a,a-o)+r,c=0,u=r;u<s;u+=n)c=l(t,u,u+n,e),this.imuln(i),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c);if(0!==o){var f=1;for(c=l(t,u,t.length,e),u=0;u<o;u++)f*=e;this.imuln(f),this.words[0]+c<67108864?this.words[0]+=c:this._iaddn(c)}},a.prototype.copy=function(t){t.words=new Array(this.length);for(var e=0;e<this.length;e++)t.words[e]=this.words[e];t.length=this.length,t.negative=this.negative,t.red=this.red},a.prototype.clone=function(){var t=new a(null);return this.copy(t),t},a.prototype._expand=function(t){for(;this.length<t;)this.words[this.length++]=0;return this},a.prototype.strip=function(){for(;this.length>1&&0===this.words[this.length-1];)this.length--;return this._normSign()},a.prototype._normSign=function(){return 1===this.length&&0===this.words[0]&&(this.negative=0),this},a.prototype.inspect=function(){return(this.red?\"<BN-R: \":\"<BN: \")+this.toString(16)+\">\"};var c=[\"\",\"0\",\"00\",\"000\",\"0000\",\"00000\",\"000000\",\"0000000\",\"00000000\",\"000000000\",\"0000000000\",\"00000000000\",\"000000000000\",\"0000000000000\",\"00000000000000\",\"000000000000000\",\"0000000000000000\",\"00000000000000000\",\"000000000000000000\",\"0000000000000000000\",\"00000000000000000000\",\"000000000000000000000\",\"0000000000000000000000\",\"00000000000000000000000\",\"000000000000000000000000\",\"0000000000000000000000000\"],u=[0,0,25,16,12,11,10,9,8,8,7,7,7,7,6,6,6,6,6,6,6,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5],f=[0,0,33554432,43046721,16777216,48828125,60466176,40353607,16777216,43046721,1e7,19487171,35831808,62748517,7529536,11390625,16777216,24137569,34012224,47045881,64e6,4084101,5153632,6436343,7962624,9765625,11881376,14348907,17210368,20511149,243e5,28629151,33554432,39135393,45435424,52521875,60466176];function h(t,e,r){r.negative=e.negative^t.negative;var n=t.length+e.length|0;r.length=n,n=n-1|0;var i=0|t.words[0],a=0|e.words[0],o=i*a,s=67108863&o,l=o/67108864|0;r.words[0]=s;for(var c=1;c<n;c++){for(var u=l>>>26,f=67108863&l,h=Math.min(c,e.length-1),p=Math.max(0,c-t.length+1);p<=h;p++){var d=c-p|0;u+=(o=(i=0|t.words[d])*(a=0|e.words[p])+f)/67108864|0,f=67108863&o}r.words[c]=0|f,l=0|u}return 0!==l?r.words[c]=0|l:r.length--,r.strip()}a.prototype.toString=function(t,e){var r;if(e=0|e||1,16===(t=t||10)||\"hex\"===t){r=\"\";for(var i=0,a=0,o=0;o<this.length;o++){var s=this.words[o],l=(16777215&(s<<i|a)).toString(16);r=0!==(a=s>>>24-i&16777215)||o!==this.length-1?c[6-l.length]+l+r:l+r,(i+=2)>=26&&(i-=26,o--)}for(0!==a&&(r=a.toString(16)+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}if(t===(0|t)&&t>=2&&t<=36){var h=u[t],p=f[t];r=\"\";var d=this.clone();for(d.negative=0;!d.isZero();){var g=d.modn(p).toString(t);r=(d=d.idivn(p)).isZero()?g+r:c[h-g.length]+g+r}for(this.isZero()&&(r=\"0\"+r);r.length%e!=0;)r=\"0\"+r;return 0!==this.negative&&(r=\"-\"+r),r}n(!1,\"Base should be between 2 and 36\")},a.prototype.toNumber=function(){var t=this.words[0];return 2===this.length?t+=67108864*this.words[1]:3===this.length&&1===this.words[2]?t+=4503599627370496+67108864*this.words[1]:this.length>2&&n(!1,\"Number can only safely store up to 53 bits\"),0!==this.negative?-t:t},a.prototype.toJSON=function(){return this.toString(16)},a.prototype.toBuffer=function(t,e){return n(\"undefined\"!=typeof o),this.toArrayLike(o,t,e)},a.prototype.toArray=function(t,e){return this.toArrayLike(Array,t,e)},a.prototype.toArrayLike=function(t,e,r){var i=this.byteLength(),a=r||Math.max(1,i);n(i<=a,\"byte array longer than desired length\"),n(a>0,\"Requested array length <= 0\"),this.strip();var o,s,l=\"le\"===e,c=new t(a),u=this.clone();if(l){for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[s]=o;for(;s<a;s++)c[s]=0}else{for(s=0;s<a-i;s++)c[s]=0;for(s=0;!u.isZero();s++)o=u.andln(255),u.iushrn(8),c[a-s-1]=o}return c},Math.clz32?a.prototype._countBits=function(t){return 32-Math.clz32(t)}:a.prototype._countBits=function(t){var e=t,r=0;return e>=4096&&(r+=13,e>>>=13),e>=64&&(r+=7,e>>>=7),e>=8&&(r+=4,e>>>=4),e>=2&&(r+=2,e>>>=2),r+e},a.prototype._zeroBits=function(t){if(0===t)return 26;var e=t,r=0;return 0==(8191&e)&&(r+=13,e>>>=13),0==(127&e)&&(r+=7,e>>>=7),0==(15&e)&&(r+=4,e>>>=4),0==(3&e)&&(r+=2,e>>>=2),0==(1&e)&&r++,r},a.prototype.bitLength=function(){var t=this.words[this.length-1],e=this._countBits(t);return 26*(this.length-1)+e},a.prototype.zeroBits=function(){if(this.isZero())return 0;for(var t=0,e=0;e<this.length;e++){var r=this._zeroBits(this.words[e]);if(t+=r,26!==r)break}return t},a.prototype.byteLength=function(){return Math.ceil(this.bitLength()/8)},a.prototype.toTwos=function(t){return 0!==this.negative?this.abs().inotn(t).iaddn(1):this.clone()},a.prototype.fromTwos=function(t){return this.testn(t-1)?this.notn(t).iaddn(1).ineg():this.clone()},a.prototype.isNeg=function(){return 0!==this.negative},a.prototype.neg=function(){return this.clone().ineg()},a.prototype.ineg=function(){return this.isZero()||(this.negative^=1),this},a.prototype.iuor=function(t){for(;this.length<t.length;)this.words[this.length++]=0;for(var e=0;e<t.length;e++)this.words[e]=this.words[e]|t.words[e];return this.strip()},a.prototype.ior=function(t){return n(0==(this.negative|t.negative)),this.iuor(t)},a.prototype.or=function(t){return this.length>t.length?this.clone().ior(t):t.clone().ior(this)},a.prototype.uor=function(t){return this.length>t.length?this.clone().iuor(t):t.clone().iuor(this)},a.prototype.iuand=function(t){var e;e=this.length>t.length?t:this;for(var r=0;r<e.length;r++)this.words[r]=this.words[r]&t.words[r];return this.length=e.length,this.strip()},a.prototype.iand=function(t){return n(0==(this.negative|t.negative)),this.iuand(t)},a.prototype.and=function(t){return this.length>t.length?this.clone().iand(t):t.clone().iand(this)},a.prototype.uand=function(t){return this.length>t.length?this.clone().iuand(t):t.clone().iuand(this)},a.prototype.iuxor=function(t){var e,r;this.length>t.length?(e=this,r=t):(e=t,r=this);for(var n=0;n<r.length;n++)this.words[n]=e.words[n]^r.words[n];if(this!==e)for(;n<e.length;n++)this.words[n]=e.words[n];return this.length=e.length,this.strip()},a.prototype.ixor=function(t){return n(0==(this.negative|t.negative)),this.iuxor(t)},a.prototype.xor=function(t){return this.length>t.length?this.clone().ixor(t):t.clone().ixor(this)},a.prototype.uxor=function(t){return this.length>t.length?this.clone().iuxor(t):t.clone().iuxor(this)},a.prototype.inotn=function(t){n(\"number\"==typeof t&&t>=0);var e=0|Math.ceil(t/26),r=t%26;this._expand(e),r>0&&e--;for(var i=0;i<e;i++)this.words[i]=67108863&~this.words[i];return r>0&&(this.words[i]=~this.words[i]&67108863>>26-r),this.strip()},a.prototype.notn=function(t){return this.clone().inotn(t)},a.prototype.setn=function(t,e){n(\"number\"==typeof t&&t>=0);var r=t/26|0,i=t%26;return this._expand(r+1),this.words[r]=e?this.words[r]|1<<i:this.words[r]&~(1<<i),this.strip()},a.prototype.iadd=function(t){var e,r,n;if(0!==this.negative&&0===t.negative)return this.negative=0,e=this.isub(t),this.negative^=1,this._normSign();if(0===this.negative&&0!==t.negative)return t.negative=0,e=this.isub(t),t.negative=1,e._normSign();this.length>t.length?(r=this,n=t):(r=t,n=this);for(var i=0,a=0;a<n.length;a++)e=(0|r.words[a])+(0|n.words[a])+i,this.words[a]=67108863&e,i=e>>>26;for(;0!==i&&a<r.length;a++)e=(0|r.words[a])+i,this.words[a]=67108863&e,i=e>>>26;if(this.length=r.length,0!==i)this.words[this.length]=i,this.length++;else if(r!==this)for(;a<r.length;a++)this.words[a]=r.words[a];return this},a.prototype.add=function(t){var e;return 0!==t.negative&&0===this.negative?(t.negative=0,e=this.sub(t),t.negative^=1,e):0===t.negative&&0!==this.negative?(this.negative=0,e=t.sub(this),this.negative=1,e):this.length>t.length?this.clone().iadd(t):t.clone().iadd(this)},a.prototype.isub=function(t){if(0!==t.negative){t.negative=0;var e=this.iadd(t);return t.negative=1,e._normSign()}if(0!==this.negative)return this.negative=0,this.iadd(t),this.negative=1,this._normSign();var r,n,i=this.cmp(t);if(0===i)return this.negative=0,this.length=1,this.words[0]=0,this;i>0?(r=this,n=t):(r=t,n=this);for(var a=0,o=0;o<n.length;o++)a=(e=(0|r.words[o])-(0|n.words[o])+a)>>26,this.words[o]=67108863&e;for(;0!==a&&o<r.length;o++)a=(e=(0|r.words[o])+a)>>26,this.words[o]=67108863&e;if(0===a&&o<r.length&&r!==this)for(;o<r.length;o++)this.words[o]=r.words[o];return this.length=Math.max(this.length,o),r!==this&&(this.negative=1),this.strip()},a.prototype.sub=function(t){return this.clone().isub(t)};var p=function(t,e,r){var n,i,a,o=t.words,s=e.words,l=r.words,c=0,u=0|o[0],f=8191&u,h=u>>>13,p=0|o[1],d=8191&p,g=p>>>13,m=0|o[2],v=8191&m,y=m>>>13,x=0|o[3],b=8191&x,_=x>>>13,w=0|o[4],T=8191&w,k=w>>>13,M=0|o[5],A=8191&M,S=M>>>13,E=0|o[6],C=8191&E,L=E>>>13,I=0|o[7],P=8191&I,z=I>>>13,O=0|o[8],D=8191&O,R=O>>>13,F=0|o[9],B=8191&F,N=F>>>13,j=0|s[0],U=8191&j,V=j>>>13,q=0|s[1],H=8191&q,G=q>>>13,Y=0|s[2],W=8191&Y,X=Y>>>13,Z=0|s[3],J=8191&Z,K=Z>>>13,Q=0|s[4],$=8191&Q,tt=Q>>>13,et=0|s[5],rt=8191&et,nt=et>>>13,it=0|s[6],at=8191&it,ot=it>>>13,st=0|s[7],lt=8191&st,ct=st>>>13,ut=0|s[8],ft=8191&ut,ht=ut>>>13,pt=0|s[9],dt=8191&pt,gt=pt>>>13;r.negative=t.negative^e.negative,r.length=19;var mt=(c+(n=Math.imul(f,U))|0)+((8191&(i=(i=Math.imul(f,V))+Math.imul(h,U)|0))<<13)|0;c=((a=Math.imul(h,V))+(i>>>13)|0)+(mt>>>26)|0,mt&=67108863,n=Math.imul(d,U),i=(i=Math.imul(d,V))+Math.imul(g,U)|0,a=Math.imul(g,V);var vt=(c+(n=n+Math.imul(f,H)|0)|0)+((8191&(i=(i=i+Math.imul(f,G)|0)+Math.imul(h,H)|0))<<13)|0;c=((a=a+Math.imul(h,G)|0)+(i>>>13)|0)+(vt>>>26)|0,vt&=67108863,n=Math.imul(v,U),i=(i=Math.imul(v,V))+Math.imul(y,U)|0,a=Math.imul(y,V),n=n+Math.imul(d,H)|0,i=(i=i+Math.imul(d,G)|0)+Math.imul(g,H)|0,a=a+Math.imul(g,G)|0;var yt=(c+(n=n+Math.imul(f,W)|0)|0)+((8191&(i=(i=i+Math.imul(f,X)|0)+Math.imul(h,W)|0))<<13)|0;c=((a=a+Math.imul(h,X)|0)+(i>>>13)|0)+(yt>>>26)|0,yt&=67108863,n=Math.imul(b,U),i=(i=Math.imul(b,V))+Math.imul(_,U)|0,a=Math.imul(_,V),n=n+Math.imul(v,H)|0,i=(i=i+Math.imul(v,G)|0)+Math.imul(y,H)|0,a=a+Math.imul(y,G)|0,n=n+Math.imul(d,W)|0,i=(i=i+Math.imul(d,X)|0)+Math.imul(g,W)|0,a=a+Math.imul(g,X)|0;var xt=(c+(n=n+Math.imul(f,J)|0)|0)+((8191&(i=(i=i+Math.imul(f,K)|0)+Math.imul(h,J)|0))<<13)|0;c=((a=a+Math.imul(h,K)|0)+(i>>>13)|0)+(xt>>>26)|0,xt&=67108863,n=Math.imul(T,U),i=(i=Math.imul(T,V))+Math.imul(k,U)|0,a=Math.imul(k,V),n=n+Math.imul(b,H)|0,i=(i=i+Math.imul(b,G)|0)+Math.imul(_,H)|0,a=a+Math.imul(_,G)|0,n=n+Math.imul(v,W)|0,i=(i=i+Math.imul(v,X)|0)+Math.imul(y,W)|0,a=a+Math.imul(y,X)|0,n=n+Math.imul(d,J)|0,i=(i=i+Math.imul(d,K)|0)+Math.imul(g,J)|0,a=a+Math.imul(g,K)|0;var bt=(c+(n=n+Math.imul(f,$)|0)|0)+((8191&(i=(i=i+Math.imul(f,tt)|0)+Math.imul(h,$)|0))<<13)|0;c=((a=a+Math.imul(h,tt)|0)+(i>>>13)|0)+(bt>>>26)|0,bt&=67108863,n=Math.imul(A,U),i=(i=Math.imul(A,V))+Math.imul(S,U)|0,a=Math.imul(S,V),n=n+Math.imul(T,H)|0,i=(i=i+Math.imul(T,G)|0)+Math.imul(k,H)|0,a=a+Math.imul(k,G)|0,n=n+Math.imul(b,W)|0,i=(i=i+Math.imul(b,X)|0)+Math.imul(_,W)|0,a=a+Math.imul(_,X)|0,n=n+Math.imul(v,J)|0,i=(i=i+Math.imul(v,K)|0)+Math.imul(y,J)|0,a=a+Math.imul(y,K)|0,n=n+Math.imul(d,$)|0,i=(i=i+Math.imul(d,tt)|0)+Math.imul(g,$)|0,a=a+Math.imul(g,tt)|0;var _t=(c+(n=n+Math.imul(f,rt)|0)|0)+((8191&(i=(i=i+Math.imul(f,nt)|0)+Math.imul(h,rt)|0))<<13)|0;c=((a=a+Math.imul(h,nt)|0)+(i>>>13)|0)+(_t>>>26)|0,_t&=67108863,n=Math.imul(C,U),i=(i=Math.imul(C,V))+Math.imul(L,U)|0,a=Math.imul(L,V),n=n+Math.imul(A,H)|0,i=(i=i+Math.imul(A,G)|0)+Math.imul(S,H)|0,a=a+Math.imul(S,G)|0,n=n+Math.imul(T,W)|0,i=(i=i+Math.imul(T,X)|0)+Math.imul(k,W)|0,a=a+Math.imul(k,X)|0,n=n+Math.imul(b,J)|0,i=(i=i+Math.imul(b,K)|0)+Math.imul(_,J)|0,a=a+Math.imul(_,K)|0,n=n+Math.imul(v,$)|0,i=(i=i+Math.imul(v,tt)|0)+Math.imul(y,$)|0,a=a+Math.imul(y,tt)|0,n=n+Math.imul(d,rt)|0,i=(i=i+Math.imul(d,nt)|0)+Math.imul(g,rt)|0,a=a+Math.imul(g,nt)|0;var wt=(c+(n=n+Math.imul(f,at)|0)|0)+((8191&(i=(i=i+Math.imul(f,ot)|0)+Math.imul(h,at)|0))<<13)|0;c=((a=a+Math.imul(h,ot)|0)+(i>>>13)|0)+(wt>>>26)|0,wt&=67108863,n=Math.imul(P,U),i=(i=Math.imul(P,V))+Math.imul(z,U)|0,a=Math.imul(z,V),n=n+Math.imul(C,H)|0,i=(i=i+Math.imul(C,G)|0)+Math.imul(L,H)|0,a=a+Math.imul(L,G)|0,n=n+Math.imul(A,W)|0,i=(i=i+Math.imul(A,X)|0)+Math.imul(S,W)|0,a=a+Math.imul(S,X)|0,n=n+Math.imul(T,J)|0,i=(i=i+Math.imul(T,K)|0)+Math.imul(k,J)|0,a=a+Math.imul(k,K)|0,n=n+Math.imul(b,$)|0,i=(i=i+Math.imul(b,tt)|0)+Math.imul(_,$)|0,a=a+Math.imul(_,tt)|0,n=n+Math.imul(v,rt)|0,i=(i=i+Math.imul(v,nt)|0)+Math.imul(y,rt)|0,a=a+Math.imul(y,nt)|0,n=n+Math.imul(d,at)|0,i=(i=i+Math.imul(d,ot)|0)+Math.imul(g,at)|0,a=a+Math.imul(g,ot)|0;var Tt=(c+(n=n+Math.imul(f,lt)|0)|0)+((8191&(i=(i=i+Math.imul(f,ct)|0)+Math.imul(h,lt)|0))<<13)|0;c=((a=a+Math.imul(h,ct)|0)+(i>>>13)|0)+(Tt>>>26)|0,Tt&=67108863,n=Math.imul(D,U),i=(i=Math.imul(D,V))+Math.imul(R,U)|0,a=Math.imul(R,V),n=n+Math.imul(P,H)|0,i=(i=i+Math.imul(P,G)|0)+Math.imul(z,H)|0,a=a+Math.imul(z,G)|0,n=n+Math.imul(C,W)|0,i=(i=i+Math.imul(C,X)|0)+Math.imul(L,W)|0,a=a+Math.imul(L,X)|0,n=n+Math.imul(A,J)|0,i=(i=i+Math.imul(A,K)|0)+Math.imul(S,J)|0,a=a+Math.imul(S,K)|0,n=n+Math.imul(T,$)|0,i=(i=i+Math.imul(T,tt)|0)+Math.imul(k,$)|0,a=a+Math.imul(k,tt)|0,n=n+Math.imul(b,rt)|0,i=(i=i+Math.imul(b,nt)|0)+Math.imul(_,rt)|0,a=a+Math.imul(_,nt)|0,n=n+Math.imul(v,at)|0,i=(i=i+Math.imul(v,ot)|0)+Math.imul(y,at)|0,a=a+Math.imul(y,ot)|0,n=n+Math.imul(d,lt)|0,i=(i=i+Math.imul(d,ct)|0)+Math.imul(g,lt)|0,a=a+Math.imul(g,ct)|0;var kt=(c+(n=n+Math.imul(f,ft)|0)|0)+((8191&(i=(i=i+Math.imul(f,ht)|0)+Math.imul(h,ft)|0))<<13)|0;c=((a=a+Math.imul(h,ht)|0)+(i>>>13)|0)+(kt>>>26)|0,kt&=67108863,n=Math.imul(B,U),i=(i=Math.imul(B,V))+Math.imul(N,U)|0,a=Math.imul(N,V),n=n+Math.imul(D,H)|0,i=(i=i+Math.imul(D,G)|0)+Math.imul(R,H)|0,a=a+Math.imul(R,G)|0,n=n+Math.imul(P,W)|0,i=(i=i+Math.imul(P,X)|0)+Math.imul(z,W)|0,a=a+Math.imul(z,X)|0,n=n+Math.imul(C,J)|0,i=(i=i+Math.imul(C,K)|0)+Math.imul(L,J)|0,a=a+Math.imul(L,K)|0,n=n+Math.imul(A,$)|0,i=(i=i+Math.imul(A,tt)|0)+Math.imul(S,$)|0,a=a+Math.imul(S,tt)|0,n=n+Math.imul(T,rt)|0,i=(i=i+Math.imul(T,nt)|0)+Math.imul(k,rt)|0,a=a+Math.imul(k,nt)|0,n=n+Math.imul(b,at)|0,i=(i=i+Math.imul(b,ot)|0)+Math.imul(_,at)|0,a=a+Math.imul(_,ot)|0,n=n+Math.imul(v,lt)|0,i=(i=i+Math.imul(v,ct)|0)+Math.imul(y,lt)|0,a=a+Math.imul(y,ct)|0,n=n+Math.imul(d,ft)|0,i=(i=i+Math.imul(d,ht)|0)+Math.imul(g,ft)|0,a=a+Math.imul(g,ht)|0;var Mt=(c+(n=n+Math.imul(f,dt)|0)|0)+((8191&(i=(i=i+Math.imul(f,gt)|0)+Math.imul(h,dt)|0))<<13)|0;c=((a=a+Math.imul(h,gt)|0)+(i>>>13)|0)+(Mt>>>26)|0,Mt&=67108863,n=Math.imul(B,H),i=(i=Math.imul(B,G))+Math.imul(N,H)|0,a=Math.imul(N,G),n=n+Math.imul(D,W)|0,i=(i=i+Math.imul(D,X)|0)+Math.imul(R,W)|0,a=a+Math.imul(R,X)|0,n=n+Math.imul(P,J)|0,i=(i=i+Math.imul(P,K)|0)+Math.imul(z,J)|0,a=a+Math.imul(z,K)|0,n=n+Math.imul(C,$)|0,i=(i=i+Math.imul(C,tt)|0)+Math.imul(L,$)|0,a=a+Math.imul(L,tt)|0,n=n+Math.imul(A,rt)|0,i=(i=i+Math.imul(A,nt)|0)+Math.imul(S,rt)|0,a=a+Math.imul(S,nt)|0,n=n+Math.imul(T,at)|0,i=(i=i+Math.imul(T,ot)|0)+Math.imul(k,at)|0,a=a+Math.imul(k,ot)|0,n=n+Math.imul(b,lt)|0,i=(i=i+Math.imul(b,ct)|0)+Math.imul(_,lt)|0,a=a+Math.imul(_,ct)|0,n=n+Math.imul(v,ft)|0,i=(i=i+Math.imul(v,ht)|0)+Math.imul(y,ft)|0,a=a+Math.imul(y,ht)|0;var At=(c+(n=n+Math.imul(d,dt)|0)|0)+((8191&(i=(i=i+Math.imul(d,gt)|0)+Math.imul(g,dt)|0))<<13)|0;c=((a=a+Math.imul(g,gt)|0)+(i>>>13)|0)+(At>>>26)|0,At&=67108863,n=Math.imul(B,W),i=(i=Math.imul(B,X))+Math.imul(N,W)|0,a=Math.imul(N,X),n=n+Math.imul(D,J)|0,i=(i=i+Math.imul(D,K)|0)+Math.imul(R,J)|0,a=a+Math.imul(R,K)|0,n=n+Math.imul(P,$)|0,i=(i=i+Math.imul(P,tt)|0)+Math.imul(z,$)|0,a=a+Math.imul(z,tt)|0,n=n+Math.imul(C,rt)|0,i=(i=i+Math.imul(C,nt)|0)+Math.imul(L,rt)|0,a=a+Math.imul(L,nt)|0,n=n+Math.imul(A,at)|0,i=(i=i+Math.imul(A,ot)|0)+Math.imul(S,at)|0,a=a+Math.imul(S,ot)|0,n=n+Math.imul(T,lt)|0,i=(i=i+Math.imul(T,ct)|0)+Math.imul(k,lt)|0,a=a+Math.imul(k,ct)|0,n=n+Math.imul(b,ft)|0,i=(i=i+Math.imul(b,ht)|0)+Math.imul(_,ft)|0,a=a+Math.imul(_,ht)|0;var St=(c+(n=n+Math.imul(v,dt)|0)|0)+((8191&(i=(i=i+Math.imul(v,gt)|0)+Math.imul(y,dt)|0))<<13)|0;c=((a=a+Math.imul(y,gt)|0)+(i>>>13)|0)+(St>>>26)|0,St&=67108863,n=Math.imul(B,J),i=(i=Math.imul(B,K))+Math.imul(N,J)|0,a=Math.imul(N,K),n=n+Math.imul(D,$)|0,i=(i=i+Math.imul(D,tt)|0)+Math.imul(R,$)|0,a=a+Math.imul(R,tt)|0,n=n+Math.imul(P,rt)|0,i=(i=i+Math.imul(P,nt)|0)+Math.imul(z,rt)|0,a=a+Math.imul(z,nt)|0,n=n+Math.imul(C,at)|0,i=(i=i+Math.imul(C,ot)|0)+Math.imul(L,at)|0,a=a+Math.imul(L,ot)|0,n=n+Math.imul(A,lt)|0,i=(i=i+Math.imul(A,ct)|0)+Math.imul(S,lt)|0,a=a+Math.imul(S,ct)|0,n=n+Math.imul(T,ft)|0,i=(i=i+Math.imul(T,ht)|0)+Math.imul(k,ft)|0,a=a+Math.imul(k,ht)|0;var Et=(c+(n=n+Math.imul(b,dt)|0)|0)+((8191&(i=(i=i+Math.imul(b,gt)|0)+Math.imul(_,dt)|0))<<13)|0;c=((a=a+Math.imul(_,gt)|0)+(i>>>13)|0)+(Et>>>26)|0,Et&=67108863,n=Math.imul(B,$),i=(i=Math.imul(B,tt))+Math.imul(N,$)|0,a=Math.imul(N,tt),n=n+Math.imul(D,rt)|0,i=(i=i+Math.imul(D,nt)|0)+Math.imul(R,rt)|0,a=a+Math.imul(R,nt)|0,n=n+Math.imul(P,at)|0,i=(i=i+Math.imul(P,ot)|0)+Math.imul(z,at)|0,a=a+Math.imul(z,ot)|0,n=n+Math.imul(C,lt)|0,i=(i=i+Math.imul(C,ct)|0)+Math.imul(L,lt)|0,a=a+Math.imul(L,ct)|0,n=n+Math.imul(A,ft)|0,i=(i=i+Math.imul(A,ht)|0)+Math.imul(S,ft)|0,a=a+Math.imul(S,ht)|0;var Ct=(c+(n=n+Math.imul(T,dt)|0)|0)+((8191&(i=(i=i+Math.imul(T,gt)|0)+Math.imul(k,dt)|0))<<13)|0;c=((a=a+Math.imul(k,gt)|0)+(i>>>13)|0)+(Ct>>>26)|0,Ct&=67108863,n=Math.imul(B,rt),i=(i=Math.imul(B,nt))+Math.imul(N,rt)|0,a=Math.imul(N,nt),n=n+Math.imul(D,at)|0,i=(i=i+Math.imul(D,ot)|0)+Math.imul(R,at)|0,a=a+Math.imul(R,ot)|0,n=n+Math.imul(P,lt)|0,i=(i=i+Math.imul(P,ct)|0)+Math.imul(z,lt)|0,a=a+Math.imul(z,ct)|0,n=n+Math.imul(C,ft)|0,i=(i=i+Math.imul(C,ht)|0)+Math.imul(L,ft)|0,a=a+Math.imul(L,ht)|0;var Lt=(c+(n=n+Math.imul(A,dt)|0)|0)+((8191&(i=(i=i+Math.imul(A,gt)|0)+Math.imul(S,dt)|0))<<13)|0;c=((a=a+Math.imul(S,gt)|0)+(i>>>13)|0)+(Lt>>>26)|0,Lt&=67108863,n=Math.imul(B,at),i=(i=Math.imul(B,ot))+Math.imul(N,at)|0,a=Math.imul(N,ot),n=n+Math.imul(D,lt)|0,i=(i=i+Math.imul(D,ct)|0)+Math.imul(R,lt)|0,a=a+Math.imul(R,ct)|0,n=n+Math.imul(P,ft)|0,i=(i=i+Math.imul(P,ht)|0)+Math.imul(z,ft)|0,a=a+Math.imul(z,ht)|0;var It=(c+(n=n+Math.imul(C,dt)|0)|0)+((8191&(i=(i=i+Math.imul(C,gt)|0)+Math.imul(L,dt)|0))<<13)|0;c=((a=a+Math.imul(L,gt)|0)+(i>>>13)|0)+(It>>>26)|0,It&=67108863,n=Math.imul(B,lt),i=(i=Math.imul(B,ct))+Math.imul(N,lt)|0,a=Math.imul(N,ct),n=n+Math.imul(D,ft)|0,i=(i=i+Math.imul(D,ht)|0)+Math.imul(R,ft)|0,a=a+Math.imul(R,ht)|0;var Pt=(c+(n=n+Math.imul(P,dt)|0)|0)+((8191&(i=(i=i+Math.imul(P,gt)|0)+Math.imul(z,dt)|0))<<13)|0;c=((a=a+Math.imul(z,gt)|0)+(i>>>13)|0)+(Pt>>>26)|0,Pt&=67108863,n=Math.imul(B,ft),i=(i=Math.imul(B,ht))+Math.imul(N,ft)|0,a=Math.imul(N,ht);var zt=(c+(n=n+Math.imul(D,dt)|0)|0)+((8191&(i=(i=i+Math.imul(D,gt)|0)+Math.imul(R,dt)|0))<<13)|0;c=((a=a+Math.imul(R,gt)|0)+(i>>>13)|0)+(zt>>>26)|0,zt&=67108863;var Ot=(c+(n=Math.imul(B,dt))|0)+((8191&(i=(i=Math.imul(B,gt))+Math.imul(N,dt)|0))<<13)|0;return c=((a=Math.imul(N,gt))+(i>>>13)|0)+(Ot>>>26)|0,Ot&=67108863,l[0]=mt,l[1]=vt,l[2]=yt,l[3]=xt,l[4]=bt,l[5]=_t,l[6]=wt,l[7]=Tt,l[8]=kt,l[9]=Mt,l[10]=At,l[11]=St,l[12]=Et,l[13]=Ct,l[14]=Lt,l[15]=It,l[16]=Pt,l[17]=zt,l[18]=Ot,0!==c&&(l[19]=c,r.length++),r};function d(t,e,r){return(new g).mulp(t,e,r)}function g(t,e){this.x=t,this.y=e}Math.imul||(p=h),a.prototype.mulTo=function(t,e){var r=this.length+t.length;return 10===this.length&&10===t.length?p(this,t,e):r<63?h(this,t,e):r<1024?function(t,e,r){r.negative=e.negative^t.negative,r.length=t.length+e.length;for(var n=0,i=0,a=0;a<r.length-1;a++){var o=i;i=0;for(var s=67108863&n,l=Math.min(a,e.length-1),c=Math.max(0,a-t.length+1);c<=l;c++){var u=a-c,f=(0|t.words[u])*(0|e.words[c]),h=67108863&f;s=67108863&(h=h+s|0),i+=(o=(o=o+(f/67108864|0)|0)+(h>>>26)|0)>>>26,o&=67108863}r.words[a]=s,n=o,o=i}return 0!==n?r.words[a]=n:r.length--,r.strip()}(this,t,e):d(this,t,e)},g.prototype.makeRBT=function(t){for(var e=new Array(t),r=a.prototype._countBits(t)-1,n=0;n<t;n++)e[n]=this.revBin(n,r,t);return e},g.prototype.revBin=function(t,e,r){if(0===t||t===r-1)return t;for(var n=0,i=0;i<e;i++)n|=(1&t)<<e-i-1,t>>=1;return n},g.prototype.permute=function(t,e,r,n,i,a){for(var o=0;o<a;o++)n[o]=e[t[o]],i[o]=r[t[o]]},g.prototype.transform=function(t,e,r,n,i,a){this.permute(a,t,e,r,n,i);for(var o=1;o<i;o<<=1)for(var s=o<<1,l=Math.cos(2*Math.PI/s),c=Math.sin(2*Math.PI/s),u=0;u<i;u+=s)for(var f=l,h=c,p=0;p<o;p++){var d=r[u+p],g=n[u+p],m=r[u+p+o],v=n[u+p+o],y=f*m-h*v;v=f*v+h*m,m=y,r[u+p]=d+m,n[u+p]=g+v,r[u+p+o]=d-m,n[u+p+o]=g-v,p!==s&&(y=l*f-c*h,h=l*h+c*f,f=y)}},g.prototype.guessLen13b=function(t,e){var r=1|Math.max(e,t),n=1&r,i=0;for(r=r/2|0;r;r>>>=1)i++;return 1<<i+1+n},g.prototype.conjugate=function(t,e,r){if(!(r<=1))for(var n=0;n<r/2;n++){var i=t[n];t[n]=t[r-n-1],t[r-n-1]=i,i=e[n],e[n]=-e[r-n-1],e[r-n-1]=-i}},g.prototype.normalize13b=function(t,e){for(var r=0,n=0;n<e/2;n++){var i=8192*Math.round(t[2*n+1]/e)+Math.round(t[2*n]/e)+r;t[n]=67108863&i,r=i<67108864?0:i/67108864|0}return t},g.prototype.convert13b=function(t,e,r,i){for(var a=0,o=0;o<e;o++)a+=0|t[o],r[2*o]=8191&a,a>>>=13,r[2*o+1]=8191&a,a>>>=13;for(o=2*e;o<i;++o)r[o]=0;n(0===a),n(0==(-8192&a))},g.prototype.stub=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=0;return e},g.prototype.mulp=function(t,e,r){var n=2*this.guessLen13b(t.length,e.length),i=this.makeRBT(n),a=this.stub(n),o=new Array(n),s=new Array(n),l=new Array(n),c=new Array(n),u=new Array(n),f=new Array(n),h=r.words;h.length=n,this.convert13b(t.words,t.length,o,n),this.convert13b(e.words,e.length,c,n),this.transform(o,a,s,l,n,i),this.transform(c,a,u,f,n,i);for(var p=0;p<n;p++){var d=s[p]*u[p]-l[p]*f[p];l[p]=s[p]*f[p]+l[p]*u[p],s[p]=d}return this.conjugate(s,l,n),this.transform(s,l,h,a,n,i),this.conjugate(h,a,n),this.normalize13b(h,n),r.negative=t.negative^e.negative,r.length=t.length+e.length,r.strip()},a.prototype.mul=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),this.mulTo(t,e)},a.prototype.mulf=function(t){var e=new a(null);return e.words=new Array(this.length+t.length),d(this,t,e)},a.prototype.imul=function(t){return this.clone().mulTo(t,this)},a.prototype.imuln=function(t){n(\"number\"==typeof t),n(t<67108864);for(var e=0,r=0;r<this.length;r++){var i=(0|this.words[r])*t,a=(67108863&i)+(67108863&e);e>>=26,e+=i/67108864|0,e+=a>>>26,this.words[r]=67108863&a}return 0!==e&&(this.words[r]=e,this.length++),this},a.prototype.muln=function(t){return this.clone().imuln(t)},a.prototype.sqr=function(){return this.mul(this)},a.prototype.isqr=function(){return this.imul(this.clone())},a.prototype.pow=function(t){var e=function(t){for(var e=new Array(t.bitLength()),r=0;r<e.length;r++){var n=r/26|0,i=r%26;e[r]=(t.words[n]&1<<i)>>>i}return e}(t);if(0===e.length)return new a(1);for(var r=this,n=0;n<e.length&&0===e[n];n++,r=r.sqr());if(++n<e.length)for(var i=r.sqr();n<e.length;n++,i=i.sqr())0!==e[n]&&(r=r.mul(i));return r},a.prototype.iushln=function(t){n(\"number\"==typeof t&&t>=0);var e,r=t%26,i=(t-r)/26,a=67108863>>>26-r<<26-r;if(0!==r){var o=0;for(e=0;e<this.length;e++){var s=this.words[e]&a,l=(0|this.words[e])-s<<r;this.words[e]=l|o,o=s>>>26-r}o&&(this.words[e]=o,this.length++)}if(0!==i){for(e=this.length-1;e>=0;e--)this.words[e+i]=this.words[e];for(e=0;e<i;e++)this.words[e]=0;this.length+=i}return this.strip()},a.prototype.ishln=function(t){return n(0===this.negative),this.iushln(t)},a.prototype.iushrn=function(t,e,r){var i;n(\"number\"==typeof t&&t>=0),i=e?(e-e%26)/26:0;var a=t%26,o=Math.min((t-a)/26,this.length),s=67108863^67108863>>>a<<a,l=r;if(i-=o,i=Math.max(0,i),l){for(var c=0;c<o;c++)l.words[c]=this.words[c];l.length=o}if(0===o);else if(this.length>o)for(this.length-=o,c=0;c<this.length;c++)this.words[c]=this.words[c+o];else this.words[0]=0,this.length=1;var u=0;for(c=this.length-1;c>=0&&(0!==u||c>=i);c--){var f=0|this.words[c];this.words[c]=u<<26-a|f>>>a,u=f&s}return l&&0!==u&&(l.words[l.length++]=u),0===this.length&&(this.words[0]=0,this.length=1),this.strip()},a.prototype.ishrn=function(t,e,r){return n(0===this.negative),this.iushrn(t,e,r)},a.prototype.shln=function(t){return this.clone().ishln(t)},a.prototype.ushln=function(t){return this.clone().iushln(t)},a.prototype.shrn=function(t){return this.clone().ishrn(t)},a.prototype.ushrn=function(t){return this.clone().iushrn(t)},a.prototype.testn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26,i=1<<e;return!(this.length<=r)&&!!(this.words[r]&i)},a.prototype.imaskn=function(t){n(\"number\"==typeof t&&t>=0);var e=t%26,r=(t-e)/26;if(n(0===this.negative,\"imaskn works only with positive numbers\"),this.length<=r)return this;if(0!==e&&r++,this.length=Math.min(r,this.length),0!==e){var i=67108863^67108863>>>e<<e;this.words[this.length-1]&=i}return this.strip()},a.prototype.maskn=function(t){return this.clone().imaskn(t)},a.prototype.iaddn=function(t){return n(\"number\"==typeof t),n(t<67108864),t<0?this.isubn(-t):0!==this.negative?1===this.length&&(0|this.words[0])<t?(this.words[0]=t-(0|this.words[0]),this.negative=0,this):(this.negative=0,this.isubn(t),this.negative=1,this):this._iaddn(t)},a.prototype._iaddn=function(t){this.words[0]+=t;for(var e=0;e<this.length&&this.words[e]>=67108864;e++)this.words[e]-=67108864,e===this.length-1?this.words[e+1]=1:this.words[e+1]++;return this.length=Math.max(this.length,e+1),this},a.prototype.isubn=function(t){if(n(\"number\"==typeof t),n(t<67108864),t<0)return this.iaddn(-t);if(0!==this.negative)return this.negative=0,this.iaddn(t),this.negative=1,this;if(this.words[0]-=t,1===this.length&&this.words[0]<0)this.words[0]=-this.words[0],this.negative=1;else for(var e=0;e<this.length&&this.words[e]<0;e++)this.words[e]+=67108864,this.words[e+1]-=1;return this.strip()},a.prototype.addn=function(t){return this.clone().iaddn(t)},a.prototype.subn=function(t){return this.clone().isubn(t)},a.prototype.iabs=function(){return this.negative=0,this},a.prototype.abs=function(){return this.clone().iabs()},a.prototype._ishlnsubmul=function(t,e,r){var i,a,o=t.length+r;this._expand(o);var s=0;for(i=0;i<t.length;i++){a=(0|this.words[i+r])+s;var l=(0|t.words[i])*e;s=((a-=67108863&l)>>26)-(l/67108864|0),this.words[i+r]=67108863&a}for(;i<this.length-r;i++)s=(a=(0|this.words[i+r])+s)>>26,this.words[i+r]=67108863&a;if(0===s)return this.strip();for(n(-1===s),s=0,i=0;i<this.length;i++)s=(a=-(0|this.words[i])+s)>>26,this.words[i]=67108863&a;return this.negative=1,this.strip()},a.prototype._wordDiv=function(t,e){var r=(this.length,t.length),n=this.clone(),i=t,o=0|i.words[i.length-1];0!==(r=26-this._countBits(o))&&(i=i.ushln(r),n.iushln(r),o=0|i.words[i.length-1]);var s,l=n.length-i.length;if(\"mod\"!==e){(s=new a(null)).length=l+1,s.words=new Array(s.length);for(var c=0;c<s.length;c++)s.words[c]=0}var u=n.clone()._ishlnsubmul(i,1,l);0===u.negative&&(n=u,s&&(s.words[l]=1));for(var f=l-1;f>=0;f--){var h=67108864*(0|n.words[i.length+f])+(0|n.words[i.length+f-1]);for(h=Math.min(h/o|0,67108863),n._ishlnsubmul(i,h,f);0!==n.negative;)h--,n.negative=0,n._ishlnsubmul(i,1,f),n.isZero()||(n.negative^=1);s&&(s.words[f]=h)}return s&&s.strip(),n.strip(),\"div\"!==e&&0!==r&&n.iushrn(r),{div:s||null,mod:n}},a.prototype.divmod=function(t,e,r){return n(!t.isZero()),this.isZero()?{div:new a(0),mod:new a(0)}:0!==this.negative&&0===t.negative?(s=this.neg().divmod(t,e),\"mod\"!==e&&(i=s.div.neg()),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.iadd(t)),{div:i,mod:o}):0===this.negative&&0!==t.negative?(s=this.divmod(t.neg(),e),\"mod\"!==e&&(i=s.div.neg()),{div:i,mod:s.mod}):0!=(this.negative&t.negative)?(s=this.neg().divmod(t.neg(),e),\"div\"!==e&&(o=s.mod.neg(),r&&0!==o.negative&&o.isub(t)),{div:s.div,mod:o}):t.length>this.length||this.cmp(t)<0?{div:new a(0),mod:this}:1===t.length?\"div\"===e?{div:this.divn(t.words[0]),mod:null}:\"mod\"===e?{div:null,mod:new a(this.modn(t.words[0]))}:{div:this.divn(t.words[0]),mod:new a(this.modn(t.words[0]))}:this._wordDiv(t,e);var i,o,s},a.prototype.div=function(t){return this.divmod(t,\"div\",!1).div},a.prototype.mod=function(t){return this.divmod(t,\"mod\",!1).mod},a.prototype.umod=function(t){return this.divmod(t,\"mod\",!0).mod},a.prototype.divRound=function(t){var e=this.divmod(t);if(e.mod.isZero())return e.div;var r=0!==e.div.negative?e.mod.isub(t):e.mod,n=t.ushrn(1),i=t.andln(1),a=r.cmp(n);return a<0||1===i&&0===a?e.div:0!==e.div.negative?e.div.isubn(1):e.div.iaddn(1)},a.prototype.modn=function(t){n(t<=67108863);for(var e=(1<<26)%t,r=0,i=this.length-1;i>=0;i--)r=(e*r+(0|this.words[i]))%t;return r},a.prototype.idivn=function(t){n(t<=67108863);for(var e=0,r=this.length-1;r>=0;r--){var i=(0|this.words[r])+67108864*e;this.words[r]=i/t|0,e=i%t}return this.strip()},a.prototype.divn=function(t){return this.clone().idivn(t)},a.prototype.egcd=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i=new a(1),o=new a(0),s=new a(0),l=new a(1),c=0;e.isEven()&&r.isEven();)e.iushrn(1),r.iushrn(1),++c;for(var u=r.clone(),f=e.clone();!e.isZero();){for(var h=0,p=1;0==(e.words[0]&p)&&h<26;++h,p<<=1);if(h>0)for(e.iushrn(h);h-- >0;)(i.isOdd()||o.isOdd())&&(i.iadd(u),o.isub(f)),i.iushrn(1),o.iushrn(1);for(var d=0,g=1;0==(r.words[0]&g)&&d<26;++d,g<<=1);if(d>0)for(r.iushrn(d);d-- >0;)(s.isOdd()||l.isOdd())&&(s.iadd(u),l.isub(f)),s.iushrn(1),l.iushrn(1);e.cmp(r)>=0?(e.isub(r),i.isub(s),o.isub(l)):(r.isub(e),s.isub(i),l.isub(o))}return{a:s,b:l,gcd:r.iushln(c)}},a.prototype._invmp=function(t){n(0===t.negative),n(!t.isZero());var e=this,r=t.clone();e=0!==e.negative?e.umod(t):e.clone();for(var i,o=new a(1),s=new a(0),l=r.clone();e.cmpn(1)>0&&r.cmpn(1)>0;){for(var c=0,u=1;0==(e.words[0]&u)&&c<26;++c,u<<=1);if(c>0)for(e.iushrn(c);c-- >0;)o.isOdd()&&o.iadd(l),o.iushrn(1);for(var f=0,h=1;0==(r.words[0]&h)&&f<26;++f,h<<=1);if(f>0)for(r.iushrn(f);f-- >0;)s.isOdd()&&s.iadd(l),s.iushrn(1);e.cmp(r)>=0?(e.isub(r),o.isub(s)):(r.isub(e),s.isub(o))}return(i=0===e.cmpn(1)?o:s).cmpn(0)<0&&i.iadd(t),i},a.prototype.gcd=function(t){if(this.isZero())return t.abs();if(t.isZero())return this.abs();var e=this.clone(),r=t.clone();e.negative=0,r.negative=0;for(var n=0;e.isEven()&&r.isEven();n++)e.iushrn(1),r.iushrn(1);for(;;){for(;e.isEven();)e.iushrn(1);for(;r.isEven();)r.iushrn(1);var i=e.cmp(r);if(i<0){var a=e;e=r,r=a}else if(0===i||0===r.cmpn(1))break;e.isub(r)}return r.iushln(n)},a.prototype.invm=function(t){return this.egcd(t).a.umod(t)},a.prototype.isEven=function(){return 0==(1&this.words[0])},a.prototype.isOdd=function(){return 1==(1&this.words[0])},a.prototype.andln=function(t){return this.words[0]&t},a.prototype.bincn=function(t){n(\"number\"==typeof t);var e=t%26,r=(t-e)/26,i=1<<e;if(this.length<=r)return this._expand(r+1),this.words[r]|=i,this;for(var a=i,o=r;0!==a&&o<this.length;o++){var s=0|this.words[o];a=(s+=a)>>>26,s&=67108863,this.words[o]=s}return 0!==a&&(this.words[o]=a,this.length++),this},a.prototype.isZero=function(){return 1===this.length&&0===this.words[0]},a.prototype.cmpn=function(t){var e,r=t<0;if(0!==this.negative&&!r)return-1;if(0===this.negative&&r)return 1;if(this.strip(),this.length>1)e=1;else{r&&(t=-t),n(t<=67108863,\"Number is too big\");var i=0|this.words[0];e=i===t?0:i<t?-1:1}return 0!==this.negative?0|-e:e},a.prototype.cmp=function(t){if(0!==this.negative&&0===t.negative)return-1;if(0===this.negative&&0!==t.negative)return 1;var e=this.ucmp(t);return 0!==this.negative?0|-e:e},a.prototype.ucmp=function(t){if(this.length>t.length)return 1;if(this.length<t.length)return-1;for(var e=0,r=this.length-1;r>=0;r--){var n=0|this.words[r],i=0|t.words[r];if(n!==i){n<i?e=-1:n>i&&(e=1);break}}return e},a.prototype.gtn=function(t){return 1===this.cmpn(t)},a.prototype.gt=function(t){return 1===this.cmp(t)},a.prototype.gten=function(t){return this.cmpn(t)>=0},a.prototype.gte=function(t){return this.cmp(t)>=0},a.prototype.ltn=function(t){return-1===this.cmpn(t)},a.prototype.lt=function(t){return-1===this.cmp(t)},a.prototype.lten=function(t){return this.cmpn(t)<=0},a.prototype.lte=function(t){return this.cmp(t)<=0},a.prototype.eqn=function(t){return 0===this.cmpn(t)},a.prototype.eq=function(t){return 0===this.cmp(t)},a.red=function(t){return new w(t)},a.prototype.toRed=function(t){return n(!this.red,\"Already a number in reduction context\"),n(0===this.negative,\"red works only with positives\"),t.convertTo(this)._forceRed(t)},a.prototype.fromRed=function(){return n(this.red,\"fromRed works only with numbers in reduction context\"),this.red.convertFrom(this)},a.prototype._forceRed=function(t){return this.red=t,this},a.prototype.forceRed=function(t){return n(!this.red,\"Already a number in reduction context\"),this._forceRed(t)},a.prototype.redAdd=function(t){return n(this.red,\"redAdd works only with red numbers\"),this.red.add(this,t)},a.prototype.redIAdd=function(t){return n(this.red,\"redIAdd works only with red numbers\"),this.red.iadd(this,t)},a.prototype.redSub=function(t){return n(this.red,\"redSub works only with red numbers\"),this.red.sub(this,t)},a.prototype.redISub=function(t){return n(this.red,\"redISub works only with red numbers\"),this.red.isub(this,t)},a.prototype.redShl=function(t){return n(this.red,\"redShl works only with red numbers\"),this.red.shl(this,t)},a.prototype.redMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.mul(this,t)},a.prototype.redIMul=function(t){return n(this.red,\"redMul works only with red numbers\"),this.red._verify2(this,t),this.red.imul(this,t)},a.prototype.redSqr=function(){return n(this.red,\"redSqr works only with red numbers\"),this.red._verify1(this),this.red.sqr(this)},a.prototype.redISqr=function(){return n(this.red,\"redISqr works only with red numbers\"),this.red._verify1(this),this.red.isqr(this)},a.prototype.redSqrt=function(){return n(this.red,\"redSqrt works only with red numbers\"),this.red._verify1(this),this.red.sqrt(this)},a.prototype.redInvm=function(){return n(this.red,\"redInvm works only with red numbers\"),this.red._verify1(this),this.red.invm(this)},a.prototype.redNeg=function(){return n(this.red,\"redNeg works only with red numbers\"),this.red._verify1(this),this.red.neg(this)},a.prototype.redPow=function(t){return n(this.red&&!t.red,\"redPow(normalNum)\"),this.red._verify1(this),this.red.pow(this,t)};var m={k256:null,p224:null,p192:null,p25519:null};function v(t,e){this.name=t,this.p=new a(e,16),this.n=this.p.bitLength(),this.k=new a(1).iushln(this.n).isub(this.p),this.tmp=this._tmp()}function y(){v.call(this,\"k256\",\"ffffffff ffffffff ffffffff ffffffff ffffffff ffffffff fffffffe fffffc2f\")}function x(){v.call(this,\"p224\",\"ffffffff ffffffff ffffffff ffffffff 00000000 00000000 00000001\")}function b(){v.call(this,\"p192\",\"ffffffff ffffffff ffffffff fffffffe ffffffff ffffffff\")}function _(){v.call(this,\"25519\",\"7fffffffffffffff ffffffffffffffff ffffffffffffffff ffffffffffffffed\")}function w(t){if(\"string\"==typeof t){var e=a._prime(t);this.m=e.p,this.prime=e}else n(t.gtn(1),\"modulus must be greater than 1\"),this.m=t,this.prime=null}function T(t){w.call(this,t),this.shift=this.m.bitLength(),this.shift%26!=0&&(this.shift+=26-this.shift%26),this.r=new a(1).iushln(this.shift),this.r2=this.imod(this.r.sqr()),this.rinv=this.r._invmp(this.m),this.minv=this.rinv.mul(this.r).isubn(1).div(this.m),this.minv=this.minv.umod(this.r),this.minv=this.r.sub(this.minv)}v.prototype._tmp=function(){var t=new a(null);return t.words=new Array(Math.ceil(this.n/13)),t},v.prototype.ireduce=function(t){var e,r=t;do{this.split(r,this.tmp),e=(r=(r=this.imulK(r)).iadd(this.tmp)).bitLength()}while(e>this.n);var n=e<this.n?-1:r.ucmp(this.p);return 0===n?(r.words[0]=0,r.length=1):n>0?r.isub(this.p):r.strip(),r},v.prototype.split=function(t,e){t.iushrn(this.n,0,e)},v.prototype.imulK=function(t){return t.imul(this.k)},i(y,v),y.prototype.split=function(t,e){for(var r=Math.min(t.length,9),n=0;n<r;n++)e.words[n]=t.words[n];if(e.length=r,t.length<=9)return t.words[0]=0,void(t.length=1);var i=t.words[9];for(e.words[e.length++]=4194303&i,n=10;n<t.length;n++){var a=0|t.words[n];t.words[n-10]=(4194303&a)<<4|i>>>22,i=a}i>>>=22,t.words[n-10]=i,0===i&&t.length>10?t.length-=10:t.length-=9},y.prototype.imulK=function(t){t.words[t.length]=0,t.words[t.length+1]=0,t.length+=2;for(var e=0,r=0;r<t.length;r++){var n=0|t.words[r];e+=977*n,t.words[r]=67108863&e,e=64*n+(e/67108864|0)}return 0===t.words[t.length-1]&&(t.length--,0===t.words[t.length-1]&&t.length--),t},i(x,v),i(b,v),i(_,v),_.prototype.imulK=function(t){for(var e=0,r=0;r<t.length;r++){var n=19*(0|t.words[r])+e,i=67108863&n;n>>>=26,t.words[r]=i,e=n}return 0!==e&&(t.words[t.length++]=e),t},a._prime=function(t){if(m[t])return m[t];var e;if(\"k256\"===t)e=new y;else if(\"p224\"===t)e=new x;else if(\"p192\"===t)e=new b;else{if(\"p25519\"!==t)throw new Error(\"Unknown prime \"+t);e=new _}return m[t]=e,e},w.prototype._verify1=function(t){n(0===t.negative,\"red works only with positives\"),n(t.red,\"red works only with red numbers\")},w.prototype._verify2=function(t,e){n(0==(t.negative|e.negative),\"red works only with positives\"),n(t.red&&t.red===e.red,\"red works only with red numbers\")},w.prototype.imod=function(t){return this.prime?this.prime.ireduce(t)._forceRed(this):t.umod(this.m)._forceRed(this)},w.prototype.neg=function(t){return t.isZero()?t.clone():this.m.sub(t)._forceRed(this)},w.prototype.add=function(t,e){this._verify2(t,e);var r=t.add(e);return r.cmp(this.m)>=0&&r.isub(this.m),r._forceRed(this)},w.prototype.iadd=function(t,e){this._verify2(t,e);var r=t.iadd(e);return r.cmp(this.m)>=0&&r.isub(this.m),r},w.prototype.sub=function(t,e){this._verify2(t,e);var r=t.sub(e);return r.cmpn(0)<0&&r.iadd(this.m),r._forceRed(this)},w.prototype.isub=function(t,e){this._verify2(t,e);var r=t.isub(e);return r.cmpn(0)<0&&r.iadd(this.m),r},w.prototype.shl=function(t,e){return this._verify1(t),this.imod(t.ushln(e))},w.prototype.imul=function(t,e){return this._verify2(t,e),this.imod(t.imul(e))},w.prototype.mul=function(t,e){return this._verify2(t,e),this.imod(t.mul(e))},w.prototype.isqr=function(t){return this.imul(t,t.clone())},w.prototype.sqr=function(t){return this.mul(t,t)},w.prototype.sqrt=function(t){if(t.isZero())return t.clone();var e=this.m.andln(3);if(n(e%2==1),3===e){var r=this.m.add(new a(1)).iushrn(2);return this.pow(t,r)}for(var i=this.m.subn(1),o=0;!i.isZero()&&0===i.andln(1);)o++,i.iushrn(1);n(!i.isZero());var s=new a(1).toRed(this),l=s.redNeg(),c=this.m.subn(1).iushrn(1),u=this.m.bitLength();for(u=new a(2*u*u).toRed(this);0!==this.pow(u,c).cmp(l);)u.redIAdd(l);for(var f=this.pow(u,i),h=this.pow(t,i.addn(1).iushrn(1)),p=this.pow(t,i),d=o;0!==p.cmp(s);){for(var g=p,m=0;0!==g.cmp(s);m++)g=g.redSqr();n(m<d);var v=this.pow(f,new a(1).iushln(d-m-1));h=h.redMul(v),f=v.redSqr(),p=p.redMul(f),d=m}return h},w.prototype.invm=function(t){var e=t._invmp(this.m);return 0!==e.negative?(e.negative=0,this.imod(e).redNeg()):this.imod(e)},w.prototype.pow=function(t,e){if(e.isZero())return new a(1).toRed(this);if(0===e.cmpn(1))return t.clone();var r=new Array(16);r[0]=new a(1).toRed(this),r[1]=t;for(var n=2;n<r.length;n++)r[n]=this.mul(r[n-1],t);var i=r[0],o=0,s=0,l=e.bitLength()%26;for(0===l&&(l=26),n=e.length-1;n>=0;n--){for(var c=e.words[n],u=l-1;u>=0;u--){var f=c>>u&1;i!==r[0]&&(i=this.sqr(i)),0!==f||0!==o?(o<<=1,o|=f,(4===++s||0===n&&0===u)&&(i=this.mul(i,r[o]),s=0,o=0)):s=0}l=26}return i},w.prototype.convertTo=function(t){var e=t.umod(this.m);return e===t?e.clone():e},w.prototype.convertFrom=function(t){var e=t.clone();return e.red=null,e},a.mont=function(t){return new T(t)},i(T,w),T.prototype.convertTo=function(t){return this.imod(t.ushln(this.shift))},T.prototype.convertFrom=function(t){var e=this.imod(t.mul(this.rinv));return e.red=null,e},T.prototype.imul=function(t,e){if(t.isZero()||e.isZero())return t.words[0]=0,t.length=1,t;var r=t.imul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),a=i;return i.cmp(this.m)>=0?a=i.isub(this.m):i.cmpn(0)<0&&(a=i.iadd(this.m)),a._forceRed(this)},T.prototype.mul=function(t,e){if(t.isZero()||e.isZero())return new a(0)._forceRed(this);var r=t.mul(e),n=r.maskn(this.shift).mul(this.minv).imaskn(this.shift).mul(this.m),i=r.isub(n).iushrn(this.shift),o=i;return i.cmp(this.m)>=0?o=i.isub(this.m):i.cmpn(0)<0&&(o=i.iadd(this.m)),o._forceRed(this)},T.prototype.invm=function(t){return this.imod(t._invmp(this.m).mul(this.r2))._forceRed(this)}}(\"undefined\"==typeof e||e,this)},{buffer:108}],100:[function(t,e,r){\"use strict\";e.exports=function(t){var e,r,n,i=t.length,a=0;for(e=0;e<i;++e)a+=t[e].length;var o=new Array(a),s=0;for(e=0;e<i;++e){var l=t[e],c=l.length;for(r=0;r<c;++r){var u=o[s++]=new Array(c-1),f=0;for(n=0;n<c;++n)n!==r&&(u[f++]=l[n]);if(1&r){var h=u[1];u[1]=u[0],u[0]=h}}}return o}},{}],101:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 1:return f(t);case 2:return\"function\"==typeof e?c(t,t,e,!0):h(t,e);case 3:return c(t,e,r,!1);default:throw new Error(\"box-intersect: Invalid arguments\")}};var n,i=t(\"typedarray-pool\"),a=t(\"./lib/sweep\"),o=t(\"./lib/intersect\");function s(t,e){for(var r=0;r<t;++r)if(!(e[r]<=e[r+t]))return!0;return!1}function l(t,e,r,n){for(var i=0,a=0,o=0,l=t.length;o<l;++o){var c=t[o];if(!s(e,c)){for(var u=0;u<2*e;++u)r[i++]=c[u];n[a++]=o}}return a}function c(t,e,r,n){var s=t.length,c=e.length;if(!(s<=0||c<=0)){var u=t[0].length>>>1;if(!(u<=0)){var f,h=i.mallocDouble(2*u*s),p=i.mallocInt32(s);if((s=l(t,u,h,p))>0){if(1===u&&n)a.init(s),f=a.sweepComplete(u,r,0,s,h,p,0,s,h,p);else{var d=i.mallocDouble(2*u*c),g=i.mallocInt32(c);(c=l(e,u,d,g))>0&&(a.init(s+c),f=1===u?a.sweepBipartite(u,r,0,s,h,p,0,c,d,g):o(u,r,n,s,h,p,c,d,g),i.free(d),i.free(g))}i.free(h),i.free(p)}return f}}}function u(t,e){n.push([t,e])}function f(t){return n=[],c(t,t,u,!0),n}function h(t,e){return n=[],c(t,e,u,!1),n}},{\"./lib/intersect\":103,\"./lib/sweep\":107,\"typedarray-pool\":595}],102:[function(t,e,r){\"use strict\";var n=[\"d\",\"ax\",\"vv\",\"rs\",\"re\",\"rb\",\"ri\",\"bs\",\"be\",\"bb\",\"bi\"];function i(t){var e=\"bruteForce\"+(t?\"Full\":\"Partial\"),r=[],i=n.slice();t||i.splice(3,0,\"fp\");var a=[\"function \"+e+\"(\"+i.join()+\"){\"];function o(e,i){var o=function(t,e,r){var i=\"bruteForce\"+(t?\"Red\":\"Blue\")+(e?\"Flip\":\"\")+(r?\"Full\":\"\"),a=[\"function \",i,\"(\",n.join(),\"){\",\"var \",\"es\",\"=2*\",\"d\",\";\"],o=\"for(var i=rs,rp=es*rs;i<re;++i,rp+=es){var x0=rb[ax+rp],x1=rb[ax+rp+d],xi=ri[i];\",s=\"for(var j=bs,bp=es*bs;j<be;++j,bp+=es){var y0=bb[ax+bp],\"+(r?\"y1=bb[ax+bp+d],\":\"\")+\"yi=bi[j];\";return t?a.push(o,\"Q\",\":\",s):a.push(s,\"Q\",\":\",o),r?a.push(\"if(y1<x0||x1<y0)continue;\"):e?a.push(\"if(y0<=x0||x1<y0)continue;\"):a.push(\"if(y0<x0||x1<y0)continue;\"),a.push(\"for(var k=ax+1;k<d;++k){var r0=rb[k+rp],r1=rb[k+d+rp],b0=bb[k+bp],b1=bb[k+d+bp];if(r1<b0||b1<r0)continue Q;}var rv=vv(\"),e?a.push(\"yi,xi\"):a.push(\"xi,yi\"),a.push(\");if(rv!==void 0)return rv;}}}\"),{name:i,code:a.join(\"\")}}(e,i,t);r.push(o.code),a.push(\"return \"+o.name+\"(\"+n.join()+\");\")}a.push(\"if(re-rs>be-bs){\"),t?(o(!0,!1),a.push(\"}else{\"),o(!1,!1)):(a.push(\"if(fp){\"),o(!0,!0),a.push(\"}else{\"),o(!0,!1),a.push(\"}}else{if(fp){\"),o(!1,!0),a.push(\"}else{\"),o(!1,!1),a.push(\"}\")),a.push(\"}}return \"+e);var s=r.join(\"\")+a.join(\"\");return new Function(s)()}r.partial=i(!1),r.full=i(!0)},{}],103:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,u,w,T,k,M){!function(t,e){var r=8*i.log2(e+1)*(t+1)|0,a=i.nextPow2(6*r);v.length<a&&(n.free(v),v=n.mallocInt32(a));var o=i.nextPow2(2*r);y.length<o&&(n.free(y),y=n.mallocDouble(o))}(t,a+T);var A,S=0,E=2*t;x(S++,0,0,a,0,T,r?16:0,-1/0,1/0),r||x(S++,0,0,T,0,a,1,-1/0,1/0);for(;S>0;){var C=6*(S-=1),L=v[C],I=v[C+1],P=v[C+2],z=v[C+3],O=v[C+4],D=v[C+5],R=2*S,F=y[R],B=y[R+1],N=1&D,j=!!(16&D),U=u,V=w,q=k,H=M;if(N&&(U=k,V=M,q=u,H=w),!(2&D&&(P=p(t,L,I,P,U,V,B),I>=P)||4&D&&(I=d(t,L,I,P,U,V,F))>=P)){var G=P-I,Y=O-z;if(j){if(t*G*(G+Y)<1<<22){if(void 0!==(A=l.scanComplete(t,L,e,I,P,U,V,z,O,q,H)))return A;continue}}else{if(t*Math.min(G,Y)<128){if(void 0!==(A=o(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}if(t*G*Y<1<<22){if(void 0!==(A=l.scanBipartite(t,L,e,N,I,P,U,V,z,O,q,H)))return A;continue}}var W=f(t,L,I,P,U,V,F,B);if(I<W)if(t*(W-I)<128){if(void 0!==(A=s(t,L+1,e,I,W,U,V,z,O,q,H)))return A}else if(L===t-2){if(void 0!==(A=N?l.sweepBipartite(t,e,z,O,q,H,I,W,U,V):l.sweepBipartite(t,e,I,W,U,V,z,O,q,H)))return A}else x(S++,L+1,I,W,z,O,N,-1/0,1/0),x(S++,L+1,z,O,I,W,1^N,-1/0,1/0);if(W<P){var X=c(t,L,z,O,q,H),Z=q[E*X+L],J=h(t,L,X,O,q,H,Z);if(J<O&&x(S++,L,W,P,J,O,(4|N)+(j?16:0),Z,B),z<X&&x(S++,L,W,P,z,X,(2|N)+(j?16:0),F,Z),X+1===J){if(void 0!==(A=j?_(t,L,e,W,P,U,V,X,q,H[X]):b(t,L,e,N,W,P,U,V,X,q,H[X])))return A}else if(X<J){var K;if(j){if(K=g(t,L,W,P,U,V,Z),W<K){var Q=h(t,L,W,K,U,V,Z);if(L===t-2){if(W<Q&&void 0!==(A=l.sweepComplete(t,e,W,Q,U,V,X,J,q,H)))return A;if(Q<K&&void 0!==(A=l.sweepBipartite(t,e,Q,K,U,V,X,J,q,H)))return A}else W<Q&&x(S++,L+1,W,Q,X,J,16,-1/0,1/0),Q<K&&(x(S++,L+1,Q,K,X,J,0,-1/0,1/0),x(S++,L+1,X,J,Q,K,1,-1/0,1/0))}}else K=N?m(t,L,W,P,U,V,Z):g(t,L,W,P,U,V,Z),W<K&&(L===t-2?A=N?l.sweepBipartite(t,e,X,J,q,H,W,K,U,V):l.sweepBipartite(t,e,W,K,U,V,X,J,q,H):(x(S++,L+1,W,K,X,J,N,-1/0,1/0),x(S++,L+1,X,J,W,K,1^N,-1/0,1/0)))}}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./brute\"),o=a.partial,s=a.full,l=t(\"./sweep\"),c=t(\"./median\"),u=t(\"./partition\"),f=u(\"!(lo>=p0)&&!(p1>=hi)\",[\"p0\",\"p1\"]),h=u(\"lo===p0\",[\"p0\"]),p=u(\"lo<p0\",[\"p0\"]),d=u(\"hi<=p0\",[\"p0\"]),g=u(\"lo<=p0&&p0<=hi\",[\"p0\"]),m=u(\"lo<p0&&p0<=hi\",[\"p0\"]),v=n.mallocInt32(1024),y=n.mallocDouble(1024);function x(t,e,r,n,i,a,o,s,l){var c=6*t;v[c]=e,v[c+1]=r,v[c+2]=n,v[c+3]=i,v[c+4]=a,v[c+5]=o;var u=2*t;y[u]=s,y[u+1]=l}function b(t,e,r,n,i,a,o,s,l,c,u){var f=2*t,h=l*f,p=c[h+e];t:for(var d=i,g=i*f;d<a;++d,g+=f){var m=o[g+e],v=o[g+e+t];if(!(p<m||v<p)&&(!n||p!==m)){for(var y,x=s[d],b=e+1;b<t;++b){m=o[g+b],v=o[g+b+t];var _=c[h+b],w=c[h+b+t];if(v<_||w<m)continue t}if(void 0!==(y=n?r(u,x):r(x,u)))return y}}}function _(t,e,r,n,i,a,o,s,l,c){var u=2*t,f=s*u,h=l[f+e];t:for(var p=n,d=n*u;p<i;++p,d+=u){var g=o[p];if(g!==c){var m=a[d+e],v=a[d+e+t];if(!(h<m||v<h)){for(var y=e+1;y<t;++y){m=a[d+y],v=a[d+y+t];var x=l[f+y],b=l[f+y+t];if(v<x||b<m)continue t}var _=r(g,c);if(void 0!==_)return _}}}}},{\"./brute\":102,\"./median\":104,\"./partition\":105,\"./sweep\":107,\"bit-twiddle\":97,\"typedarray-pool\":595}],104:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,o,s){if(a<=r+1)return r;var l=r,c=a,u=a+r>>>1,f=2*t,h=u,p=o[f*u+e];for(;l<c;){if(c-l<8){i(t,e,l,c,o,s),p=o[f*u+e];break}var d=c-l,g=Math.random()*d+l|0,m=o[f*g+e],v=Math.random()*d+l|0,y=o[f*v+e],x=Math.random()*d+l|0,b=o[f*x+e];m<=y?b>=y?(h=v,p=y):m>=b?(h=g,p=m):(h=x,p=b):y>=b?(h=v,p=y):b>=m?(h=g,p=m):(h=x,p=b);for(var _=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){var k=o[_];o[_]=o[w],o[w]=k}var M=s[c-1];s[c-1]=s[h],s[h]=M,h=n(t,e,l,c-1,o,s,p);for(_=f*(c-1),w=f*h,T=0;T<f;++T,++_,++w){k=o[_];o[_]=o[w],o[w]=k}M=s[c-1];if(s[c-1]=s[h],s[h]=M,u<h){for(c=h-1;l<c&&o[f*(c-1)+e]===p;)c-=1;c+=1}else{if(!(h<u))break;for(l=h+1;l<c&&o[f*l+e]===p;)l+=1}}return n(t,e,r,u,o,s,o[f*u+e])};var n=t(\"./partition\")(\"lo<p0\",[\"p0\"]);function i(t,e,r,n,i,a){for(var o=2*t,s=o*(r+1)+e,l=r+1;l<n;++l,s+=o)for(var c=i[s],u=l,f=o*(l-1);u>r&&i[f+e]>c;--u,f-=o){for(var h=f,p=f+o,d=0;d<o;++d,++h,++p){var g=i[h];i[h]=i[p],i[p]=g}var m=a[u];a[u]=a[u-1],a[u-1]=m}}},{\"./partition\":105}],105:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=\"abcdef\".split(\"\").concat(e),n=[];t.indexOf(\"lo\")>=0&&n.push(\"lo=e[k+n]\");t.indexOf(\"hi\")>=0&&n.push(\"hi=e[k+o]\");return r.push(\"for(var j=2*a,k=j*c,l=k,m=c,n=b,o=a+b,p=c;d>p;++p,k+=j){var _;if($)if(m===p)m+=1,l+=j;else{for(var s=0;j>s;++s){var t=e[k+s];e[k+s]=e[l],e[l++]=t}var u=f[p];f[p]=f[m],f[m++]=u}}return m\".replace(\"_\",n.join()).replace(\"$\",t)),Function.apply(void 0,r)}},{}],106:[function(t,e,r){\"use strict\";e.exports=function(t,e){e<=128?n(0,e-1,t):function t(e,r,u){var f=(r-e+1)/6|0,h=e+f,p=r-f,d=e+r>>1,g=d-f,m=d+f,v=h,y=g,x=d,b=m,_=p,w=e+1,T=r-1,k=0;l(v,y,u)&&(k=v,v=y,y=k);l(b,_,u)&&(k=b,b=_,_=k);l(v,x,u)&&(k=v,v=x,x=k);l(y,x,u)&&(k=y,y=x,x=k);l(v,b,u)&&(k=v,v=b,b=k);l(x,b,u)&&(k=x,x=b,b=k);l(y,_,u)&&(k=y,y=_,_=k);l(y,x,u)&&(k=y,y=x,x=k);l(b,_,u)&&(k=b,b=_,_=k);for(var M=u[2*y],A=u[2*y+1],S=u[2*b],E=u[2*b+1],C=2*v,L=2*x,I=2*_,P=2*h,z=2*d,O=2*p,D=0;D<2;++D){var R=u[C+D],F=u[L+D],B=u[I+D];u[P+D]=R,u[z+D]=F,u[O+D]=B}a(g,e,u),a(m,r,u);for(var N=w;N<=T;++N)if(c(N,M,A,u))N!==w&&i(N,w,u),++w;else if(!c(N,S,E,u))for(;;){if(c(T,S,E,u)){c(T,M,A,u)?(o(N,w,T,u),++w,--T):(i(N,T,u),--T);break}if(--T<N)break}s(e,w-1,M,A,u),s(r,T+1,S,E,u),w-2-e<=32?n(e,w-2,u):t(e,w-2,u);r-(T+2)<=32?n(T+2,r,u):t(T+2,r,u);T-w<=32?n(w,T,u):t(w,T,u)}(0,e-1,t)};function n(t,e,r){for(var n=2*(t+1),i=t+1;i<=e;++i){for(var a=r[n++],o=r[n++],s=i,l=n-2;s-- >t;){var c=r[l-2],u=r[l-1];if(c<a)break;if(c===a&&u<o)break;r[l]=c,r[l+1]=u,l-=2}r[l]=a,r[l+1]=o}}function i(t,e,r){e*=2;var n=r[t*=2],i=r[t+1];r[t]=r[e],r[t+1]=r[e+1],r[e]=n,r[e+1]=i}function a(t,e,r){e*=2,r[t*=2]=r[e],r[t+1]=r[e+1]}function o(t,e,r,n){e*=2,r*=2;var i=n[t*=2],a=n[t+1];n[t]=n[e],n[t+1]=n[e+1],n[e]=n[r],n[e+1]=n[r+1],n[r]=i,n[r+1]=a}function s(t,e,r,n,i){e*=2,i[t*=2]=i[e],i[e]=r,i[t+1]=i[e+1],i[e+1]=n}function l(t,e,r){e*=2;var n=r[t*=2],i=r[e];return!(n<i)&&(n!==i||r[t+1]>r[e+1])}function c(t,e,r,n){var i=n[t*=2];return i<e||i===e&&n[t+1]<r}},{}],107:[function(t,e,r){\"use strict\";e.exports={init:function(t){var e=i.nextPow2(t);o.length<e&&(n.free(o),o=n.mallocInt32(e));s.length<e&&(n.free(s),s=n.mallocInt32(e));l.length<e&&(n.free(l),l=n.mallocInt32(e));c.length<e&&(n.free(c),c=n.mallocInt32(e));u.length<e&&(n.free(u),u=n.mallocInt32(e));f.length<e&&(n.free(f),f=n.mallocInt32(e));var r=8*e;h.length<r&&(n.free(h),h=n.mallocDouble(r))},sweepBipartite:function(t,e,r,n,i,u,f,g,m,v){for(var y=0,x=2*t,b=t-1,_=x-1,w=r;w<n;++w){var T=u[w],k=x*w;h[y++]=i[k+b],h[y++]=-(T+1),h[y++]=i[k+_],h[y++]=T}for(w=f;w<g;++w){T=v[w]+(1<<28);var M=x*w;h[y++]=m[M+b],h[y++]=-T,h[y++]=m[M+_],h[y++]=T}var A=y>>>1;a(h,A);var S=0,E=0;for(w=0;w<A;++w){var C=0|h[2*w+1];if(C>=1<<28)p(l,c,E--,C=C-(1<<28)|0);else if(C>=0)p(o,s,S--,C);else if(C<=-(1<<28)){C=-C-(1<<28)|0;for(var L=0;L<S;++L){if(void 0!==(I=e(o[L],C)))return I}d(l,c,E++,C)}else{C=-C-1|0;for(L=0;L<E;++L){var I;if(void 0!==(I=e(C,l[L])))return I}d(o,s,S++,C)}}},sweepComplete:function(t,e,r,n,i,g,m,v,y,x){for(var b=0,_=2*t,w=t-1,T=_-1,k=r;k<n;++k){var M=g[k]+1<<1,A=_*k;h[b++]=i[A+w],h[b++]=-M,h[b++]=i[A+T],h[b++]=M}for(k=m;k<v;++k){M=x[k]+1<<1;var S=_*k;h[b++]=y[S+w],h[b++]=1|-M,h[b++]=y[S+T],h[b++]=1|M}var E=b>>>1;a(h,E);var C=0,L=0,I=0;for(k=0;k<E;++k){var P=0|h[2*k+1],z=1&P;if(k<E-1&&P>>1==h[2*k+3]>>1&&(z=2,k+=1),P<0){for(var O=-(P>>1)-1,D=0;D<I;++D){if(void 0!==(R=e(u[D],O)))return R}if(0!==z)for(D=0;D<C;++D){if(void 0!==(R=e(o[D],O)))return R}if(1!==z)for(D=0;D<L;++D){var R;if(void 0!==(R=e(l[D],O)))return R}0===z?d(o,s,C++,O):1===z?d(l,c,L++,O):2===z&&d(u,f,I++,O)}else{O=(P>>1)-1;0===z?p(o,s,C--,O):1===z?p(l,c,L--,O):2===z&&p(u,f,I--,O)}}},scanBipartite:function(t,e,r,n,i,l,c,u,f,g,m,v){var y=0,x=2*t,b=e,_=e+t,w=1,T=1;n?T=1<<28:w=1<<28;for(var k=i;k<l;++k){var M=k+w,A=x*k;h[y++]=c[A+b],h[y++]=-M,h[y++]=c[A+_],h[y++]=M}for(k=f;k<g;++k){M=k+T;var S=x*k;h[y++]=m[S+b],h[y++]=-M}var E=y>>>1;a(h,E);var C=0;for(k=0;k<E;++k){var L=0|h[2*k+1];if(L<0){var I=!1;if((M=-L)>=1<<28?(I=!n,M-=1<<28):(I=!!n,M-=1),I)d(o,s,C++,M);else{var P=v[M],z=x*M,O=m[z+e+1],D=m[z+e+1+t];t:for(var R=0;R<C;++R){var F=o[R],B=x*F;if(!(D<c[B+e+1]||c[B+e+1+t]<O)){for(var N=e+2;N<t;++N)if(m[z+N+t]<c[B+N]||c[B+N+t]<m[z+N])continue t;var j,U=u[F];if(void 0!==(j=n?r(P,U):r(U,P)))return j}}}}else p(o,s,C--,L-w)}},scanComplete:function(t,e,r,n,i,s,l,c,u,f,p){for(var d=0,g=2*t,m=e,v=e+t,y=n;y<i;++y){var x=y+(1<<28),b=g*y;h[d++]=s[b+m],h[d++]=-x,h[d++]=s[b+v],h[d++]=x}for(y=c;y<u;++y){x=y+1;var _=g*y;h[d++]=f[_+m],h[d++]=-x}var w=d>>>1;a(h,w);var T=0;for(y=0;y<w;++y){var k=0|h[2*y+1];if(k<0){if((x=-k)>=1<<28)o[T++]=x-(1<<28);else{var M=p[x-=1],A=g*x,S=f[A+e+1],E=f[A+e+1+t];t:for(var C=0;C<T;++C){var L=o[C],I=l[L];if(I===M)break;var P=g*L;if(!(E<s[P+e+1]||s[P+e+1+t]<S)){for(var z=e+2;z<t;++z)if(f[A+z+t]<s[P+z]||s[P+z+t]<f[A+z])continue t;var O=r(I,M);if(void 0!==O)return O}}}}else{for(x=k-(1<<28),C=T-1;C>=0;--C)if(o[C]===x){for(z=C+1;z<T;++z)o[z-1]=o[z];break}--T}}}};var n=t(\"typedarray-pool\"),i=t(\"bit-twiddle\"),a=t(\"./sort\"),o=n.mallocInt32(1024),s=n.mallocInt32(1024),l=n.mallocInt32(1024),c=n.mallocInt32(1024),u=n.mallocInt32(1024),f=n.mallocInt32(1024),h=n.mallocDouble(8192);function p(t,e,r,n){var i=e[n],a=t[r-1];t[i]=a,e[a]=i}function d(t,e,r,n){t[r]=n,e[n]=r}},{\"./sort\":106,\"bit-twiddle\":97,\"typedarray-pool\":595}],108:[function(t,e,r){},{}],109:[function(t,e,r){arguments[4][108][0].apply(r,arguments)},{dup:108}],110:[function(t,e,r){\"use strict\";var n,i=\"object\"==typeof Reflect?Reflect:null,a=i&&\"function\"==typeof i.apply?i.apply:function(t,e,r){return Function.prototype.apply.call(t,e,r)};n=i&&\"function\"==typeof i.ownKeys?i.ownKeys:Object.getOwnPropertySymbols?function(t){return Object.getOwnPropertyNames(t).concat(Object.getOwnPropertySymbols(t))}:function(t){return Object.getOwnPropertyNames(t)};var o=Number.isNaN||function(t){return t!=t};function s(){s.init.call(this)}e.exports=s,e.exports.once=function(t,e){return new Promise((function(r,n){function i(){void 0!==a&&t.removeListener(\"error\",a),r([].slice.call(arguments))}var a;\"error\"!==e&&(a=function(r){t.removeListener(e,i),n(r)},t.once(\"error\",a)),t.once(e,i)}))},s.EventEmitter=s,s.prototype._events=void 0,s.prototype._eventsCount=0,s.prototype._maxListeners=void 0;var l=10;function c(t){if(\"function\"!=typeof t)throw new TypeError('The \"listener\" argument must be of type Function. Received type '+typeof t)}function u(t){return void 0===t._maxListeners?s.defaultMaxListeners:t._maxListeners}function f(t,e,r,n){var i,a,o,s;if(c(r),void 0===(a=t._events)?(a=t._events=Object.create(null),t._eventsCount=0):(void 0!==a.newListener&&(t.emit(\"newListener\",e,r.listener?r.listener:r),a=t._events),o=a[e]),void 0===o)o=a[e]=r,++t._eventsCount;else if(\"function\"==typeof o?o=a[e]=n?[r,o]:[o,r]:n?o.unshift(r):o.push(r),(i=u(t))>0&&o.length>i&&!o.warned){o.warned=!0;var l=new Error(\"Possible EventEmitter memory leak detected. \"+o.length+\" \"+String(e)+\" listeners added. Use emitter.setMaxListeners() to increase limit\");l.name=\"MaxListenersExceededWarning\",l.emitter=t,l.type=e,l.count=o.length,s=l,console&&console.warn&&console.warn(s)}return t}function h(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,0===arguments.length?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function p(t,e,r){var n={fired:!1,wrapFn:void 0,target:t,type:e,listener:r},i=h.bind(n);return i.listener=r,n.wrapFn=i,i}function d(t,e,r){var n=t._events;if(void 0===n)return[];var i=n[e];return void 0===i?[]:\"function\"==typeof i?r?[i.listener||i]:[i]:r?function(t){for(var e=new Array(t.length),r=0;r<e.length;++r)e[r]=t[r].listener||t[r];return e}(i):m(i,i.length)}function g(t){var e=this._events;if(void 0!==e){var r=e[t];if(\"function\"==typeof r)return 1;if(void 0!==r)return r.length}return 0}function m(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t[n];return r}Object.defineProperty(s,\"defaultMaxListeners\",{enumerable:!0,get:function(){return l},set:function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"defaultMaxListeners\" is out of range. It must be a non-negative number. Received '+t+\".\");l=t}}),s.init=function(){void 0!==this._events&&this._events!==Object.getPrototypeOf(this)._events||(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},s.prototype.setMaxListeners=function(t){if(\"number\"!=typeof t||t<0||o(t))throw new RangeError('The value of \"n\" is out of range. It must be a non-negative number. Received '+t+\".\");return this._maxListeners=t,this},s.prototype.getMaxListeners=function(){return u(this)},s.prototype.emit=function(t){for(var e=[],r=1;r<arguments.length;r++)e.push(arguments[r]);var n=\"error\"===t,i=this._events;if(void 0!==i)n=n&&void 0===i.error;else if(!n)return!1;if(n){var o;if(e.length>0&&(o=e[0]),o instanceof Error)throw o;var s=new Error(\"Unhandled error.\"+(o?\" (\"+o.message+\")\":\"\"));throw s.context=o,s}var l=i[t];if(void 0===l)return!1;if(\"function\"==typeof l)a(l,this,e);else{var c=l.length,u=m(l,c);for(r=0;r<c;++r)a(u[r],this,e)}return!0},s.prototype.addListener=function(t,e){return f(this,t,e,!1)},s.prototype.on=s.prototype.addListener,s.prototype.prependListener=function(t,e){return f(this,t,e,!0)},s.prototype.once=function(t,e){return c(e),this.on(t,p(this,t,e)),this},s.prototype.prependOnceListener=function(t,e){return c(e),this.prependListener(t,p(this,t,e)),this},s.prototype.removeListener=function(t,e){var r,n,i,a,o;if(c(e),void 0===(n=this._events))return this;if(void 0===(r=n[t]))return this;if(r===e||r.listener===e)0==--this._eventsCount?this._events=Object.create(null):(delete n[t],n.removeListener&&this.emit(\"removeListener\",t,r.listener||e));else if(\"function\"!=typeof r){for(i=-1,a=r.length-1;a>=0;a--)if(r[a]===e||r[a].listener===e){o=r[a].listener,i=a;break}if(i<0)return this;0===i?r.shift():function(t,e){for(;e+1<t.length;e++)t[e]=t[e+1];t.pop()}(r,i),1===r.length&&(n[t]=r[0]),void 0!==n.removeListener&&this.emit(\"removeListener\",t,o||e)}return this},s.prototype.off=s.prototype.removeListener,s.prototype.removeAllListeners=function(t){var e,r,n;if(void 0===(r=this._events))return this;if(void 0===r.removeListener)return 0===arguments.length?(this._events=Object.create(null),this._eventsCount=0):void 0!==r[t]&&(0==--this._eventsCount?this._events=Object.create(null):delete r[t]),this;if(0===arguments.length){var i,a=Object.keys(r);for(n=0;n<a.length;++n)\"removeListener\"!==(i=a[n])&&this.removeAllListeners(i);return this.removeAllListeners(\"removeListener\"),this._events=Object.create(null),this._eventsCount=0,this}if(\"function\"==typeof(e=r[t]))this.removeListener(t,e);else if(void 0!==e)for(n=e.length-1;n>=0;n--)this.removeListener(t,e[n]);return this},s.prototype.listeners=function(t){return d(this,t,!0)},s.prototype.rawListeners=function(t){return d(this,t,!1)},s.listenerCount=function(t,e){return\"function\"==typeof t.listenerCount?t.listenerCount(e):g.call(t,e)},s.prototype.listenerCount=g,s.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]}},{}],111:[function(t,e,r){(function(e){(function(){\n",
       "/*!\n",
       " * The buffer module from node.js, for the browser.\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "\"use strict\";var e=t(\"base64-js\"),n=t(\"ieee754\");r.Buffer=a,r.SlowBuffer=function(t){+t!=t&&(t=0);return a.alloc(+t)},r.INSPECT_MAX_BYTES=50;function i(t){if(t>2147483647)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"');var e=new Uint8Array(t);return e.__proto__=a.prototype,e}function a(t,e,r){if(\"number\"==typeof t){if(\"string\"==typeof e)throw new TypeError('The \"string\" argument must be of type string. Received type number');return l(t)}return o(t,e,r)}function o(t,e,r){if(\"string\"==typeof t)return function(t,e){\"string\"==typeof e&&\"\"!==e||(e=\"utf8\");if(!a.isEncoding(e))throw new TypeError(\"Unknown encoding: \"+e);var r=0|f(t,e),n=i(r),o=n.write(t,e);o!==r&&(n=n.slice(0,o));return n}(t,e);if(ArrayBuffer.isView(t))return c(t);if(null==t)throw TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t);if(B(t,ArrayBuffer)||t&&B(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('\"offset\" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('\"length\" is outside of buffer bounds');var n;n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r);return n.__proto__=a.prototype,n}(t,e,r);if(\"number\"==typeof t)throw new TypeError('The \"value\" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return a.from(n,e,r);var o=function(t){if(a.isBuffer(t)){var e=0|u(t.length),r=i(e);return 0===r.length||t.copy(r,0,0,e),r}if(void 0!==t.length)return\"number\"!=typeof t.length||N(t.length)?i(0):c(t);if(\"Buffer\"===t.type&&Array.isArray(t.data))return c(t.data)}(t);if(o)return o;if(\"undefined\"!=typeof Symbol&&null!=Symbol.toPrimitive&&\"function\"==typeof t[Symbol.toPrimitive])return a.from(t[Symbol.toPrimitive](\"string\"),e,r);throw new TypeError(\"The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type \"+typeof t)}function s(t){if(\"number\"!=typeof t)throw new TypeError('\"size\" argument must be of type number');if(t<0)throw new RangeError('The value \"'+t+'\" is invalid for option \"size\"')}function l(t){return s(t),i(t<0?0:0|u(t))}function c(t){for(var e=t.length<0?0:0|u(t.length),r=i(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function u(t){if(t>=2147483647)throw new RangeError(\"Attempt to allocate Buffer larger than maximum size: 0x\"+2147483647..toString(16)+\" bytes\");return 0|t}function f(t,e){if(a.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||B(t,ArrayBuffer))return t.byteLength;if(\"string\"!=typeof t)throw new TypeError('The \"string\" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var i=!1;;)switch(e){case\"ascii\":case\"latin1\":case\"binary\":return r;case\"utf8\":case\"utf-8\":return D(t).length;case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return 2*r;case\"hex\":return r>>>1;case\"base64\":return R(t).length;default:if(i)return n?-1:D(t).length;e=(\"\"+e).toLowerCase(),i=!0}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return\"\";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return\"\";if((r>>>=0)<=(e>>>=0))return\"\";for(t||(t=\"utf8\");;)switch(t){case\"hex\":return A(this,e,r);case\"utf8\":case\"utf-8\":return T(this,e,r);case\"ascii\":return k(this,e,r);case\"latin1\":case\"binary\":return M(this,e,r);case\"base64\":return w(this,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return S(this,e,r);default:if(n)throw new TypeError(\"Unknown encoding: \"+t);t=(t+\"\").toLowerCase(),n=!0}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function d(t,e,r,n,i){if(0===t.length)return-1;if(\"string\"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),N(r=+r)&&(r=i?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(i)return-1;r=t.length-1}else if(r<0){if(!i)return-1;r=0}if(\"string\"==typeof e&&(e=a.from(e,n)),a.isBuffer(e))return 0===e.length?-1:g(t,e,r,n,i);if(\"number\"==typeof e)return e&=255,\"function\"==typeof Uint8Array.prototype.indexOf?i?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):g(t,[e],r,n,i);throw new TypeError(\"val must be string, number or Buffer\")}function g(t,e,r,n,i){var a,o=1,s=t.length,l=e.length;if(void 0!==n&&(\"ucs2\"===(n=String(n).toLowerCase())||\"ucs-2\"===n||\"utf16le\"===n||\"utf-16le\"===n)){if(t.length<2||e.length<2)return-1;o=2,s/=2,l/=2,r/=2}function c(t,e){return 1===o?t[e]:t.readUInt16BE(e*o)}if(i){var u=-1;for(a=r;a<s;a++)if(c(t,a)===c(e,-1===u?0:a-u)){if(-1===u&&(u=a),a-u+1===l)return u*o}else-1!==u&&(a-=a-u),u=-1}else for(r+l>s&&(r=s-l),a=r;a>=0;a--){for(var f=!0,h=0;h<l;h++)if(c(t,a+h)!==c(e,h)){f=!1;break}if(f)return a}return-1}function m(t,e,r,n){r=Number(r)||0;var i=t.length-r;n?(n=Number(n))>i&&(n=i):n=i;var a=e.length;n>a/2&&(n=a/2);for(var o=0;o<n;++o){var s=parseInt(e.substr(2*o,2),16);if(N(s))return o;t[r+o]=s}return o}function v(t,e,r,n){return F(D(e,t.length-r),t,r,n)}function y(t,e,r,n){return F(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function x(t,e,r,n){return y(t,e,r,n)}function b(t,e,r,n){return F(R(e),t,r,n)}function _(t,e,r,n){return F(function(t,e){for(var r,n,i,a=[],o=0;o<t.length&&!((e-=2)<0);++o)r=t.charCodeAt(o),n=r>>8,i=r%256,a.push(i),a.push(n);return a}(e,t.length-r),t,r,n)}function w(t,r,n){return 0===r&&n===t.length?e.fromByteArray(t):e.fromByteArray(t.slice(r,n))}function T(t,e,r){r=Math.min(t.length,r);for(var n=[],i=e;i<r;){var a,o,s,l,c=t[i],u=null,f=c>239?4:c>223?3:c>191?2:1;if(i+f<=r)switch(f){case 1:c<128&&(u=c);break;case 2:128==(192&(a=t[i+1]))&&(l=(31&c)<<6|63&a)>127&&(u=l);break;case 3:a=t[i+1],o=t[i+2],128==(192&a)&&128==(192&o)&&(l=(15&c)<<12|(63&a)<<6|63&o)>2047&&(l<55296||l>57343)&&(u=l);break;case 4:a=t[i+1],o=t[i+2],s=t[i+3],128==(192&a)&&128==(192&o)&&128==(192&s)&&(l=(15&c)<<18|(63&a)<<12|(63&o)<<6|63&s)>65535&&l<1114112&&(u=l)}null===u?(u=65533,f=1):u>65535&&(u-=65536,n.push(u>>>10&1023|55296),u=56320|1023&u),n.push(u),i+=f}return function(t){var e=t.length;if(e<=4096)return String.fromCharCode.apply(String,t);var r=\"\",n=0;for(;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=4096));return r}(n)}r.kMaxLength=2147483647,a.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1);return t.__proto__={__proto__:Uint8Array.prototype,foo:function(){return 42}},42===t.foo()}catch(t){return!1}}(),a.TYPED_ARRAY_SUPPORT||\"undefined\"==typeof console||\"function\"!=typeof console.error||console.error(\"This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support.\"),Object.defineProperty(a.prototype,\"parent\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.buffer}}),Object.defineProperty(a.prototype,\"offset\",{enumerable:!0,get:function(){if(a.isBuffer(this))return this.byteOffset}}),\"undefined\"!=typeof Symbol&&null!=Symbol.species&&a[Symbol.species]===a&&Object.defineProperty(a,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),a.poolSize=8192,a.from=function(t,e,r){return o(t,e,r)},a.prototype.__proto__=Uint8Array.prototype,a.__proto__=Uint8Array,a.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?i(t):void 0!==e?\"string\"==typeof r?i(t).fill(e,r):i(t).fill(e):i(t)}(t,e,r)},a.allocUnsafe=function(t){return l(t)},a.allocUnsafeSlow=function(t){return l(t)},a.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==a.prototype},a.compare=function(t,e){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),B(e,Uint8Array)&&(e=a.from(e,e.offset,e.byteLength)),!a.isBuffer(t)||!a.isBuffer(e))throw new TypeError('The \"buf1\", \"buf2\" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,i=0,o=Math.min(r,n);i<o;++i)if(t[i]!==e[i]){r=t[i],n=e[i];break}return r<n?-1:n<r?1:0},a.isEncoding=function(t){switch(String(t).toLowerCase()){case\"hex\":case\"utf8\":case\"utf-8\":case\"ascii\":case\"latin1\":case\"binary\":case\"base64\":case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return!0;default:return!1}},a.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('\"list\" argument must be an Array of Buffers');if(0===t.length)return a.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=a.allocUnsafe(e),i=0;for(r=0;r<t.length;++r){var o=t[r];if(B(o,Uint8Array)&&(o=a.from(o)),!a.isBuffer(o))throw new TypeError('\"list\" argument must be an Array of Buffers');o.copy(n,i),i+=o.length}return n},a.byteLength=f,a.prototype._isBuffer=!0,a.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError(\"Buffer size must be a multiple of 16-bits\");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},a.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError(\"Buffer size must be a multiple of 32-bits\");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},a.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError(\"Buffer size must be a multiple of 64-bits\");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},a.prototype.toString=function(){var t=this.length;return 0===t?\"\":0===arguments.length?T(this,0,t):h.apply(this,arguments)},a.prototype.toLocaleString=a.prototype.toString,a.prototype.equals=function(t){if(!a.isBuffer(t))throw new TypeError(\"Argument must be a Buffer\");return this===t||0===a.compare(this,t)},a.prototype.inspect=function(){var t=\"\",e=r.INSPECT_MAX_BYTES;return t=this.toString(\"hex\",0,e).replace(/(.{2})/g,\"$1 \").trim(),this.length>e&&(t+=\" ... \"),\"<Buffer \"+t+\">\"},a.prototype.compare=function(t,e,r,n,i){if(B(t,Uint8Array)&&(t=a.from(t,t.offset,t.byteLength)),!a.isBuffer(t))throw new TypeError('The \"target\" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===i&&(i=this.length),e<0||r>t.length||n<0||i>this.length)throw new RangeError(\"out of range index\");if(n>=i&&e>=r)return 0;if(n>=i)return-1;if(e>=r)return 1;if(this===t)return 0;for(var o=(i>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),l=Math.min(o,s),c=this.slice(n,i),u=t.slice(e,r),f=0;f<l;++f)if(c[f]!==u[f]){o=c[f],s=u[f];break}return o<s?-1:s<o?1:0},a.prototype.includes=function(t,e,r){return-1!==this.indexOf(t,e,r)},a.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},a.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},a.prototype.write=function(t,e,r,n){if(void 0===e)n=\"utf8\",r=this.length,e=0;else if(void 0===r&&\"string\"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error(\"Buffer.write(string, encoding, offset[, length]) is no longer supported\");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n=\"utf8\")):(n=r,r=void 0)}var i=this.length-e;if((void 0===r||r>i)&&(r=i),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError(\"Attempt to write outside buffer bounds\");n||(n=\"utf8\");for(var a=!1;;)switch(n){case\"hex\":return m(this,t,e,r);case\"utf8\":case\"utf-8\":return v(this,t,e,r);case\"ascii\":return y(this,t,e,r);case\"latin1\":case\"binary\":return x(this,t,e,r);case\"base64\":return b(this,t,e,r);case\"ucs2\":case\"ucs-2\":case\"utf16le\":case\"utf-16le\":return _(this,t,e,r);default:if(a)throw new TypeError(\"Unknown encoding: \"+n);n=(\"\"+n).toLowerCase(),a=!0}},a.prototype.toJSON=function(){return{type:\"Buffer\",data:Array.prototype.slice.call(this._arr||this,0)}};function k(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(127&t[i]);return n}function M(t,e,r){var n=\"\";r=Math.min(t.length,r);for(var i=e;i<r;++i)n+=String.fromCharCode(t[i]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var i=\"\",a=e;a<r;++a)i+=O(t[a]);return i}function S(t,e,r){for(var n=t.slice(e,r),i=\"\",a=0;a<n.length;a+=2)i+=String.fromCharCode(n[a]+256*n[a+1]);return i}function E(t,e,r){if(t%1!=0||t<0)throw new RangeError(\"offset is not uint\");if(t+e>r)throw new RangeError(\"Trying to access beyond buffer length\")}function C(t,e,r,n,i,o){if(!a.isBuffer(t))throw new TypeError('\"buffer\" argument must be a Buffer instance');if(e>i||e<o)throw new RangeError('\"value\" argument is out of bounds');if(r+n>t.length)throw new RangeError(\"Index out of range\")}function L(t,e,r,n,i,a){if(r+n>t.length)throw new RangeError(\"Index out of range\");if(r<0)throw new RangeError(\"Index out of range\")}function I(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,4),n.write(t,e,r,i,23,4),r+4}function P(t,e,r,i,a){return e=+e,r>>>=0,a||L(t,0,r,8),n.write(t,e,r,i,52,8),r+8}a.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return n.__proto__=a.prototype,n},a.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n},a.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t+--e],i=1;e>0&&(i*=256);)n+=this[t+--e]*i;return n},a.prototype.readUInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),this[t]},a.prototype.readUInt16LE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]|this[t+1]<<8},a.prototype.readUInt16BE=function(t,e){return t>>>=0,e||E(t,2,this.length),this[t]<<8|this[t+1]},a.prototype.readUInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},a.prototype.readUInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},a.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=this[t],i=1,a=0;++a<e&&(i*=256);)n+=this[t+a]*i;return n>=(i*=128)&&(n-=Math.pow(2,8*e)),n},a.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||E(t,e,this.length);for(var n=e,i=1,a=this[t+--n];n>0&&(i*=256);)a+=this[t+--n]*i;return a>=(i*=128)&&(a-=Math.pow(2,8*e)),a},a.prototype.readInt8=function(t,e){return t>>>=0,e||E(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},a.prototype.readInt16LE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt16BE=function(t,e){t>>>=0,e||E(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},a.prototype.readInt32LE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},a.prototype.readInt32BE=function(t,e){return t>>>=0,e||E(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},a.prototype.readFloatLE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!0,23,4)},a.prototype.readFloatBE=function(t,e){return t>>>=0,e||E(t,4,this.length),n.read(this,t,!1,23,4)},a.prototype.readDoubleLE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!0,52,8)},a.prototype.readDoubleBE=function(t,e){return t>>>=0,e||E(t,8,this.length),n.read(this,t,!1,52,8)},a.prototype.writeUIntLE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=1,a=0;for(this[e]=255&t;++a<r&&(i*=256);)this[e+a]=t/i&255;return e+r},a.prototype.writeUIntBE=function(t,e,r,n){(t=+t,e>>>=0,r>>>=0,n)||C(this,t,e,r,Math.pow(2,8*r)-1,0);var i=r-1,a=1;for(this[e+i]=255&t;--i>=0&&(a*=256);)this[e+i]=t/a&255;return e+r},a.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,255,0),this[e]=255&t,e+1},a.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},a.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=0,o=1,s=0;for(this[e]=255&t;++a<r&&(o*=256);)t<0&&0===s&&0!==this[e+a-1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var i=Math.pow(2,8*r-1);C(this,t,e,r,i-1,-i)}var a=r-1,o=1,s=0;for(this[e+a]=255&t;--a>=0&&(o*=256);)t<0&&0===s&&0!==this[e+a+1]&&(s=1),this[e+a]=(t/o>>0)-s&255;return e+r},a.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},a.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},a.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},a.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},a.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||C(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},a.prototype.writeFloatLE=function(t,e,r){return I(this,t,e,!0,r)},a.prototype.writeFloatBE=function(t,e,r){return I(this,t,e,!1,r)},a.prototype.writeDoubleLE=function(t,e,r){return P(this,t,e,!0,r)},a.prototype.writeDoubleBE=function(t,e,r){return P(this,t,e,!1,r)},a.prototype.copy=function(t,e,r,n){if(!a.isBuffer(t))throw new TypeError(\"argument should be a Buffer\");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError(\"targetStart out of bounds\");if(r<0||r>=this.length)throw new RangeError(\"Index out of range\");if(n<0)throw new RangeError(\"sourceEnd out of bounds\");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var i=n-r;if(this===t&&\"function\"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var o=i-1;o>=0;--o)t[o+e]=this[o+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return i},a.prototype.fill=function(t,e,r,n){if(\"string\"==typeof t){if(\"string\"==typeof e?(n=e,e=0,r=this.length):\"string\"==typeof r&&(n=r,r=this.length),void 0!==n&&\"string\"!=typeof n)throw new TypeError(\"encoding must be a string\");if(\"string\"==typeof n&&!a.isEncoding(n))throw new TypeError(\"Unknown encoding: \"+n);if(1===t.length){var i=t.charCodeAt(0);(\"utf8\"===n&&i<128||\"latin1\"===n)&&(t=i)}}else\"number\"==typeof t&&(t&=255);if(e<0||this.length<e||this.length<r)throw new RangeError(\"Out of range index\");if(r<=e)return this;var o;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),\"number\"==typeof t)for(o=e;o<r;++o)this[o]=t;else{var s=a.isBuffer(t)?t:a.from(t,n),l=s.length;if(0===l)throw new TypeError('The value \"'+t+'\" is invalid for argument \"value\"');for(o=0;o<r-e;++o)this[o+e]=s[o%l]}return this};var z=/[^+/0-9A-Za-z-_]/g;function O(t){return t<16?\"0\"+t.toString(16):t.toString(16)}function D(t,e){var r;e=e||1/0;for(var n=t.length,i=null,a=[],o=0;o<n;++o){if((r=t.charCodeAt(o))>55295&&r<57344){if(!i){if(r>56319){(e-=3)>-1&&a.push(239,191,189);continue}if(o+1===n){(e-=3)>-1&&a.push(239,191,189);continue}i=r;continue}if(r<56320){(e-=3)>-1&&a.push(239,191,189),i=r;continue}r=65536+(i-55296<<10|r-56320)}else i&&(e-=3)>-1&&a.push(239,191,189);if(i=null,r<128){if((e-=1)<0)break;a.push(r)}else if(r<2048){if((e-=2)<0)break;a.push(r>>6|192,63&r|128)}else if(r<65536){if((e-=3)<0)break;a.push(r>>12|224,r>>6&63|128,63&r|128)}else{if(!(r<1114112))throw new Error(\"Invalid code point\");if((e-=4)<0)break;a.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128)}}return a}function R(t){return e.toByteArray(function(t){if((t=(t=t.split(\"=\")[0]).trim().replace(z,\"\")).length<2)return\"\";for(;t.length%4!=0;)t+=\"=\";return t}(t))}function F(t,e,r,n){for(var i=0;i<n&&!(i+r>=e.length||i>=t.length);++i)e[i+r]=t[i];return i}function B(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function N(t){return t!=t}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"base64-js\":79,buffer:111,ieee754:442}],112:[function(t,e,r){\"use strict\";var n=t(\"./lib/monotone\"),i=t(\"./lib/triangulation\"),a=t(\"./lib/delaunay\"),o=t(\"./lib/filter\");function s(t){return[Math.min(t[0],t[1]),Math.max(t[0],t[1])]}function l(t,e){return t[0]-e[0]||t[1]-e[1]}function c(t,e,r){return e in t?t[e]:r}e.exports=function(t,e,r){Array.isArray(e)?(r=r||{},e=e||[]):(r=e||{},e=[]);var u=!!c(r,\"delaunay\",!0),f=!!c(r,\"interior\",!0),h=!!c(r,\"exterior\",!0),p=!!c(r,\"infinity\",!1);if(!f&&!h||0===t.length)return[];var d=n(t,e);if(u||f!==h||p){for(var g=i(t.length,function(t){return t.map(s).sort(l)}(e)),m=0;m<d.length;++m){var v=d[m];g.addTriangle(v[0],v[1],v[2])}return u&&a(t,g),h?f?p?o(g,0,p):g.cells():o(g,1,p):o(g,-1)}return d}},{\"./lib/delaunay\":113,\"./lib/filter\":114,\"./lib/monotone\":115,\"./lib/triangulation\":116}],113:[function(t,e,r){\"use strict\";var n=t(\"robust-in-sphere\")[4];t(\"binary-search-bounds\");function i(t,e,r,i,a,o){var s=e.opposite(i,a);if(!(s<0)){if(a<i){var l=i;i=a,a=l,l=o,o=s,s=l}e.isConstraint(i,a)||n(t[i],t[a],t[o],t[s])<0&&r.push(i,a)}}e.exports=function(t,e){for(var r=[],a=t.length,o=e.stars,s=0;s<a;++s)for(var l=o[s],c=1;c<l.length;c+=2){if(!((p=l[c])<s)&&!e.isConstraint(s,p)){for(var u=l[c-1],f=-1,h=1;h<l.length;h+=2)if(l[h-1]===p){f=l[h];break}f<0||n(t[s],t[p],t[u],t[f])<0&&r.push(s,p)}}for(;r.length>0;){for(var p=r.pop(),d=(s=r.pop(),u=-1,f=-1,l=o[s],1);d<l.length;d+=2){var g=l[d-1],m=l[d];g===p?f=m:m===p&&(u=g)}u<0||f<0||(n(t[s],t[p],t[u],t[f])>=0||(e.flip(s,p),i(t,e,r,u,s,f),i(t,e,r,s,f,u),i(t,e,r,f,p,u),i(t,e,r,p,u,f)))}}},{\"binary-search-bounds\":96,\"robust-in-sphere\":546}],114:[function(t,e,r){\"use strict\";var n,i=t(\"binary-search-bounds\");function a(t,e,r,n,i,a,o){this.cells=t,this.neighbor=e,this.flags=n,this.constraint=r,this.active=i,this.next=a,this.boundary=o}function o(t,e){return t[0]-e[0]||t[1]-e[1]||t[2]-e[2]}e.exports=function(t,e,r){var n=function(t,e){for(var r=t.cells(),n=r.length,i=0;i<n;++i){var s=(v=r[i])[0],l=v[1],c=v[2];l<c?l<s&&(v[0]=l,v[1]=c,v[2]=s):c<s&&(v[0]=c,v[1]=s,v[2]=l)}r.sort(o);var u=new Array(n);for(i=0;i<u.length;++i)u[i]=0;var f=[],h=[],p=new Array(3*n),d=new Array(3*n),g=null;e&&(g=[]);var m=new a(r,p,d,u,f,h,g);for(i=0;i<n;++i)for(var v=r[i],y=0;y<3;++y){s=v[y],l=v[(y+1)%3];var x=p[3*i+y]=m.locate(l,s,t.opposite(l,s)),b=d[3*i+y]=t.isConstraint(s,l);x<0&&(b?h.push(i):(f.push(i),u[i]=1),e&&g.push([l,s,-1]))}return m}(t,r);if(0===e)return r?n.cells.concat(n.boundary):n.cells;var i=1,s=n.active,l=n.next,c=n.flags,u=n.cells,f=n.constraint,h=n.neighbor;for(;s.length>0||l.length>0;){for(;s.length>0;){var p=s.pop();if(c[p]!==-i){c[p]=i;u[p];for(var d=0;d<3;++d){var g=h[3*p+d];g>=0&&0===c[g]&&(f[3*p+d]?l.push(g):(s.push(g),c[g]=i))}}}var m=l;l=s,s=m,l.length=0,i=-i}var v=function(t,e,r){for(var n=0,i=0;i<t.length;++i)e[i]===r&&(t[n++]=t[i]);return t.length=n,t}(u,c,e);if(r)return v.concat(n.boundary);return v},a.prototype.locate=(n=[0,0,0],function(t,e,r){var a=t,s=e,l=r;return e<r?e<t&&(a=e,s=r,l=t):r<t&&(a=r,s=t,l=e),a<0?-1:(n[0]=a,n[1]=s,n[2]=l,i.eq(this.cells,n,o))})},{\"binary-search-bounds\":96}],115:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"robust-orientation\")[3];function a(t,e,r,n,i){this.a=t,this.b=e,this.idx=r,this.lowerIds=n,this.upperIds=i}function o(t,e,r,n){this.a=t,this.b=e,this.type=r,this.idx=n}function s(t,e){var r=t.a[0]-e.a[0]||t.a[1]-e.a[1]||t.type-e.type;return r||(0!==t.type&&(r=i(t.a,t.b,e.b))?r:t.idx-e.idx)}function l(t,e){return i(t.a,t.b,e)}function c(t,e,r,a,o){for(var s=n.lt(e,a,l),c=n.gt(e,a,l),u=s;u<c;++u){for(var f=e[u],h=f.lowerIds,p=h.length;p>1&&i(r[h[p-2]],r[h[p-1]],a)>0;)t.push([h[p-1],h[p-2],o]),p-=1;h.length=p,h.push(o);var d=f.upperIds;for(p=d.length;p>1&&i(r[d[p-2]],r[d[p-1]],a)<0;)t.push([d[p-2],d[p-1],o]),p-=1;d.length=p,d.push(o)}}function u(t,e){var r;return(r=t.a[0]<e.a[0]?i(t.a,t.b,e.a):i(e.b,e.a,t.a))?r:(r=e.b[0]<t.b[0]?i(t.a,t.b,e.b):i(e.b,e.a,t.b))||t.idx-e.idx}function f(t,e,r){var i=n.le(t,r,u),o=t[i],s=o.upperIds,l=s[s.length-1];o.upperIds=[l],t.splice(i+1,0,new a(r.a,r.b,r.idx,[l],s))}function h(t,e,r){var i=r.a;r.a=r.b,r.b=i;var a=n.eq(t,r,u),o=t[a];t[a-1].upperIds=o.upperIds,t.splice(a,1)}e.exports=function(t,e){for(var r=t.length,n=e.length,i=[],l=0;l<r;++l)i.push(new o(t[l],null,0,l));for(l=0;l<n;++l){var u=e[l],p=t[u[0]],d=t[u[1]];p[0]<d[0]?i.push(new o(p,d,2,l),new o(d,p,1,l)):p[0]>d[0]&&i.push(new o(d,p,2,l),new o(p,d,1,l))}i.sort(s);for(var g=i[0].a[0]-(1+Math.abs(i[0].a[0]))*Math.pow(2,-52),m=[new a([g,1],[g,0],-1,[],[],[],[])],v=[],y=(l=0,i.length);l<y;++l){var x=i[l],b=x.type;0===b?c(v,m,t,x.a,x.idx):2===b?f(m,t,x):h(m,t,x)}return v}},{\"binary-search-bounds\":96,\"robust-orientation\":548}],116:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e){this.stars=t,this.edges=e}e.exports=function(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=[];return new i(r,e)};var a=i.prototype;function o(t,e,r){for(var n=1,i=t.length;n<i;n+=2)if(t[n-1]===e&&t[n]===r)return t[n-1]=t[i-2],t[n]=t[i-1],void(t.length=i-2)}a.isConstraint=function(){var t=[0,0];function e(t,e){return t[0]-e[0]||t[1]-e[1]}return function(r,i){return t[0]=Math.min(r,i),t[1]=Math.max(r,i),n.eq(this.edges,t,e)>=0}}(),a.removeTriangle=function(t,e,r){var n=this.stars;o(n[t],e,r),o(n[e],r,t),o(n[r],t,e)},a.addTriangle=function(t,e,r){var n=this.stars;n[t].push(e,r),n[e].push(r,t),n[r].push(t,e)},a.opposite=function(t,e){for(var r=this.stars[e],n=1,i=r.length;n<i;n+=2)if(r[n]===t)return r[n-1];return-1},a.flip=function(t,e){var r=this.opposite(t,e),n=this.opposite(e,t);this.removeTriangle(t,e,r),this.removeTriangle(e,t,n),this.addTriangle(t,n,r),this.addTriangle(e,r,n)},a.edges=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2)e.push([i[a],i[a+1]]);return e},a.cells=function(){for(var t=this.stars,e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;a+=2){var s=i[a],l=i[a+1];r<Math.min(s,l)&&e.push([r,s,l])}return e}},{\"binary-search-bounds\":96}],117:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1,r=1;r<t.length;++r)for(var n=0;n<r;++n)if(t[r]<t[n])e=-e;else if(t[n]===t[r])return 0;return e}},{}],118:[function(t,e,r){\"use strict\";var n=t(\"dup\"),i=t(\"robust-linear-solve\");function a(t,e){for(var r=0,n=t.length,i=0;i<n;++i)r+=t[i]*e[i];return r}function o(t){var e=t.length;if(0===e)return[];t[0].length;var r=n([t.length+1,t.length+1],1),o=n([t.length+1],1);r[e][e]=0;for(var s=0;s<e;++s){for(var l=0;l<=s;++l)r[l][s]=r[s][l]=2*a(t[s],t[l]);o[s]=a(t[s],t[s])}var c=i(r,o),u=0,f=c[e+1];for(s=0;s<f.length;++s)u+=f[s];var h=new Array(e);for(s=0;s<e;++s){f=c[s];var p=0;for(l=0;l<f.length;++l)p+=f[l];h[s]=p/u}return h}function s(t){if(0===t.length)return[];for(var e=t[0].length,r=n([e]),i=o(t),a=0;a<t.length;++a)for(var s=0;s<e;++s)r[s]+=t[a][s]*i[a];return r}s.barycenetric=o,e.exports=s},{dup:176,\"robust-linear-solve\":547}],119:[function(t,e,r){e.exports=function(t){for(var e=n(t),r=0,i=0;i<t.length;++i)for(var a=t[i],o=0;o<e.length;++o)r+=Math.pow(a[o]-e[o],2);return Math.sqrt(r/t.length)};var n=t(\"circumcenter\")},{circumcenter:118}],120:[function(t,e,r){e.exports=function(t,e,r){return e<r?t<e?e:t>r?r:t:t<r?r:t>e?e:t}},{}],121:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n;if(r){n=e;for(var i=new Array(e.length),a=0;a<e.length;++a){var o=e[a];i[a]=[o[0],o[1],r[a]]}e=i}var s=function(t,e,r){var n=d(t,[],p(t));return v(e,n,r),!!n}(t,e,!!r);for(;y(t,e,!!r);)s=!0;if(r&&s){n.length=0,r.length=0;for(a=0;a<e.length;++a){o=e[a];n.push([o[0],o[1]]),r.push(o[2])}}return s};var n=t(\"union-find\"),i=t(\"box-intersect\"),a=t(\"robust-segment-intersect\"),o=t(\"big-rat\"),s=t(\"big-rat/cmp\"),l=t(\"big-rat/to-float\"),c=t(\"rat-vec\"),u=t(\"nextafter\"),f=t(\"./lib/rat-seg-intersect\");function h(t){var e=l(t);return[u(e,-1/0),u(e,1/0)]}function p(t){for(var e=new Array(t.length),r=0;r<t.length;++r){var n=t[r];e[r]=[u(n[0],-1/0),u(n[1],-1/0),u(n[0],1/0),u(n[1],1/0)]}return e}function d(t,e,r){for(var a=e.length,o=new n(a),s=[],l=0;l<e.length;++l){var c=e[l],f=h(c[0]),p=h(c[1]);s.push([u(f[0],-1/0),u(p[0],-1/0),u(f[1],1/0),u(p[1],1/0)])}i(s,(function(t,e){o.link(t,e)}));var d=!0,g=new Array(a);for(l=0;l<a;++l){(v=o.find(l))!==l&&(d=!1,t[v]=[Math.min(t[l][0],t[v][0]),Math.min(t[l][1],t[v][1])])}if(d)return null;var m=0;for(l=0;l<a;++l){var v;(v=o.find(l))===l?(g[l]=m,t[m++]=t[l]):g[l]=-1}t.length=m;for(l=0;l<a;++l)g[l]<0&&(g[l]=g[o.find(l)]);return g}function g(t,e){return t[0]-e[0]||t[1]-e[1]}function m(t,e){var r=t[0]-e[0]||t[1]-e[1];return r||(t[2]<e[2]?-1:t[2]>e[2]?1:0)}function v(t,e,r){if(0!==t.length){if(e)for(var n=0;n<t.length;++n){var i=e[(o=t[n])[0]],a=e[o[1]];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}else for(n=0;n<t.length;++n){var o;i=(o=t[n])[0],a=o[1];o[0]=Math.min(i,a),o[1]=Math.max(i,a)}r?t.sort(m):t.sort(g);var s=1;for(n=1;n<t.length;++n){var l=t[n-1],c=t[n];(c[0]!==l[0]||c[1]!==l[1]||r&&c[2]!==l[2])&&(t[s++]=c)}t.length=s}}function y(t,e,r){var n=function(t,e){for(var r=new Array(e.length),n=0;n<e.length;++n){var i=e[n],a=t[i[0]],o=t[i[1]];r[n]=[u(Math.min(a[0],o[0]),-1/0),u(Math.min(a[1],o[1]),-1/0),u(Math.max(a[0],o[0]),1/0),u(Math.max(a[1],o[1]),1/0)]}return r}(t,e),h=function(t,e,r){var n=[];return i(r,(function(r,i){var o=e[r],s=e[i];if(o[0]!==s[0]&&o[0]!==s[1]&&o[1]!==s[0]&&o[1]!==s[1]){var l=t[o[0]],c=t[o[1]],u=t[s[0]],f=t[s[1]];a(l,c,u,f)&&n.push([r,i])}})),n}(t,e,n),g=p(t),m=function(t,e,r,n){var o=[];return i(r,n,(function(r,n){var i=e[r];if(i[0]!==n&&i[1]!==n){var s=t[n],l=t[i[0]],c=t[i[1]];a(l,c,s,s)&&o.push([r,n])}})),o}(t,e,n,g),y=d(t,function(t,e,r,n,i){var a,u,h=t.map((function(t){return[o(t[0]),o(t[1])]}));for(a=0;a<r.length;++a){var p=r[a];u=p[0];var d=p[1],g=e[u],m=e[d],v=f(c(t[g[0]]),c(t[g[1]]),c(t[m[0]]),c(t[m[1]]));if(v){var y=t.length;t.push([l(v[0]),l(v[1])]),h.push(v),n.push([u,y],[d,y])}}for(n.sort((function(t,e){if(t[0]!==e[0])return t[0]-e[0];var r=h[t[1]],n=h[e[1]];return s(r[0],n[0])||s(r[1],n[1])})),a=n.length-1;a>=0;--a){var x=e[u=(S=n[a])[0]],b=x[0],_=x[1],w=t[b],T=t[_];if((w[0]-T[0]||w[1]-T[1])<0){var k=b;b=_,_=k}x[0]=b;var M,A=x[1]=S[1];for(i&&(M=x[2]);a>0&&n[a-1][0]===u;){var S,E=(S=n[--a])[1];i?e.push([A,E,M]):e.push([A,E]),A=E}i?e.push([A,_,M]):e.push([A,_])}return h}(t,e,h,m,r));return v(e,y,r),!!y||(h.length>0||m.length>0)}},{\"./lib/rat-seg-intersect\":122,\"big-rat\":83,\"big-rat/cmp\":81,\"big-rat/to-float\":95,\"box-intersect\":101,nextafter:496,\"rat-vec\":530,\"robust-segment-intersect\":551,\"union-find\":596}],122:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var a=s(e,t),f=s(n,r),h=u(a,f);if(0===o(h))return null;var p=s(t,r),d=u(f,p),g=i(d,h),m=c(a,g);return l(t,m)};var n=t(\"big-rat/mul\"),i=t(\"big-rat/div\"),a=t(\"big-rat/sub\"),o=t(\"big-rat/sign\"),s=t(\"rat-vec/sub\"),l=t(\"rat-vec/add\"),c=t(\"rat-vec/muls\");function u(t,e){return a(n(t[0],e[1]),n(t[1],e[0]))}},{\"big-rat/div\":82,\"big-rat/mul\":92,\"big-rat/sign\":93,\"big-rat/sub\":94,\"rat-vec/add\":529,\"rat-vec/muls\":531,\"rat-vec/sub\":532}],123:[function(t,e,r){\"use strict\";var n=t(\"clamp\");function i(t,e){null==e&&(e=!0);var r=t[0],i=t[1],a=t[2],o=t[3];return null==o&&(o=e?1:255),e&&(r*=255,i*=255,a*=255,o*=255),16777216*(r=255&n(r,0,255))+((i=255&n(i,0,255))<<16)+((a=255&n(a,0,255))<<8)+(o=255&n(o,0,255))}e.exports=i,e.exports.to=i,e.exports.from=function(t,e){var r=(t=+t)>>>24,n=(16711680&t)>>>16,i=(65280&t)>>>8,a=255&t;return!1===e?[r,n,i,a]:[r/255,n/255,i/255,a/255]}},{clamp:120}],124:[function(t,e,r){\"use strict\";e.exports={aliceblue:[240,248,255],antiquewhite:[250,235,215],aqua:[0,255,255],aquamarine:[127,255,212],azure:[240,255,255],beige:[245,245,220],bisque:[255,228,196],black:[0,0,0],blanchedalmond:[255,235,205],blue:[0,0,255],blueviolet:[138,43,226],brown:[165,42,42],burlywood:[222,184,135],cadetblue:[95,158,160],chartreuse:[127,255,0],chocolate:[210,105,30],coral:[255,127,80],cornflowerblue:[100,149,237],cornsilk:[255,248,220],crimson:[220,20,60],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgoldenrod:[184,134,11],darkgray:[169,169,169],darkgreen:[0,100,0],darkgrey:[169,169,169],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkseagreen:[143,188,143],darkslateblue:[72,61,139],darkslategray:[47,79,79],darkslategrey:[47,79,79],darkturquoise:[0,206,209],darkviolet:[148,0,211],deeppink:[255,20,147],deepskyblue:[0,191,255],dimgray:[105,105,105],dimgrey:[105,105,105],dodgerblue:[30,144,255],firebrick:[178,34,34],floralwhite:[255,250,240],forestgreen:[34,139,34],fuchsia:[255,0,255],gainsboro:[220,220,220],ghostwhite:[248,248,255],gold:[255,215,0],goldenrod:[218,165,32],gray:[128,128,128],green:[0,128,0],greenyellow:[173,255,47],grey:[128,128,128],honeydew:[240,255,240],hotpink:[255,105,180],indianred:[205,92,92],indigo:[75,0,130],ivory:[255,255,240],khaki:[240,230,140],lavender:[230,230,250],lavenderblush:[255,240,245],lawngreen:[124,252,0],lemonchiffon:[255,250,205],lightblue:[173,216,230],lightcoral:[240,128,128],lightcyan:[224,255,255],lightgoldenrodyellow:[250,250,210],lightgray:[211,211,211],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightsalmon:[255,160,122],lightseagreen:[32,178,170],lightskyblue:[135,206,250],lightslategray:[119,136,153],lightslategrey:[119,136,153],lightsteelblue:[176,196,222],lightyellow:[255,255,224],lime:[0,255,0],limegreen:[50,205,50],linen:[250,240,230],magenta:[255,0,255],maroon:[128,0,0],mediumaquamarine:[102,205,170],mediumblue:[0,0,205],mediumorchid:[186,85,211],mediumpurple:[147,112,219],mediumseagreen:[60,179,113],mediumslateblue:[123,104,238],mediumspringgreen:[0,250,154],mediumturquoise:[72,209,204],mediumvioletred:[199,21,133],midnightblue:[25,25,112],mintcream:[245,255,250],mistyrose:[255,228,225],moccasin:[255,228,181],navajowhite:[255,222,173],navy:[0,0,128],oldlace:[253,245,230],olive:[128,128,0],olivedrab:[107,142,35],orange:[255,165,0],orangered:[255,69,0],orchid:[218,112,214],palegoldenrod:[238,232,170],palegreen:[152,251,152],paleturquoise:[175,238,238],palevioletred:[219,112,147],papayawhip:[255,239,213],peachpuff:[255,218,185],peru:[205,133,63],pink:[255,192,203],plum:[221,160,221],powderblue:[176,224,230],purple:[128,0,128],rebeccapurple:[102,51,153],red:[255,0,0],rosybrown:[188,143,143],royalblue:[65,105,225],saddlebrown:[139,69,19],salmon:[250,128,114],sandybrown:[244,164,96],seagreen:[46,139,87],seashell:[255,245,238],sienna:[160,82,45],silver:[192,192,192],skyblue:[135,206,235],slateblue:[106,90,205],slategray:[112,128,144],slategrey:[112,128,144],snow:[255,250,250],springgreen:[0,255,127],steelblue:[70,130,180],tan:[210,180,140],teal:[0,128,128],thistle:[216,191,216],tomato:[255,99,71],turquoise:[64,224,208],violet:[238,130,238],wheat:[245,222,179],white:[255,255,255],whitesmoke:[245,245,245],yellow:[255,255,0],yellowgreen:[154,205,50]}},{}],125:[function(t,e,r){\"use strict\";var n=t(\"color-rgba\"),i=t(\"clamp\"),a=t(\"dtype\");e.exports=function(t,e){\"float\"!==e&&e||(e=\"array\"),\"uint\"===e&&(e=\"uint8\"),\"uint_clamped\"===e&&(e=\"uint8_clamped\");var r=new(a(e))(4),o=\"uint8\"!==e&&\"uint8_clamped\"!==e;return t.length&&\"string\"!=typeof t||((t=n(t))[0]/=255,t[1]/=255,t[2]/=255),function(t){return t instanceof Uint8Array||t instanceof Uint8ClampedArray||!!(Array.isArray(t)&&(t[0]>1||0===t[0])&&(t[1]>1||0===t[1])&&(t[2]>1||0===t[2])&&(!t[3]||t[3]>1))}(t)?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:255,o&&(r[0]/=255,r[1]/=255,r[2]/=255,r[3]/=255),r):(o?(r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=null!=t[3]?t[3]:1):(r[0]=i(Math.floor(255*t[0]),0,255),r[1]=i(Math.floor(255*t[1]),0,255),r[2]=i(Math.floor(255*t[2]),0,255),r[3]=null==t[3]?255:i(Math.floor(255*t[3]),0,255)),r)}},{clamp:120,\"color-rgba\":127,dtype:175}],126:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"color-name\"),i=t(\"is-plain-obj\"),a=t(\"defined\");e.exports=function(t){var e,s,l=[],c=1;if(\"string\"==typeof t)if(n[t])l=n[t].slice(),s=\"rgb\";else if(\"transparent\"===t)c=0,s=\"rgb\",l=[0,0,0];else if(/^#[A-Fa-f0-9]+$/.test(t)){var u=(p=t.slice(1)).length;c=1,u<=4?(l=[parseInt(p[0]+p[0],16),parseInt(p[1]+p[1],16),parseInt(p[2]+p[2],16)],4===u&&(c=parseInt(p[3]+p[3],16)/255)):(l=[parseInt(p[0]+p[1],16),parseInt(p[2]+p[3],16),parseInt(p[4]+p[5],16)],8===u&&(c=parseInt(p[6]+p[7],16)/255)),l[0]||(l[0]=0),l[1]||(l[1]=0),l[2]||(l[2]=0),s=\"rgb\"}else if(e=/^((?:rgb|hs[lvb]|hwb|cmyk?|xy[zy]|gray|lab|lchu?v?|[ly]uv|lms)a?)\\s*\\(([^\\)]*)\\)/.exec(t)){var f=e[1],h=\"rgb\"===f,p=f.replace(/a$/,\"\");s=p;u=\"cmyk\"===p?4:\"gray\"===p?1:3;l=e[2].trim().split(/\\s*,\\s*/).map((function(t,e){if(/%$/.test(t))return e===u?parseFloat(t)/100:\"rgb\"===p?255*parseFloat(t)/100:parseFloat(t);if(\"h\"===p[e]){if(/deg$/.test(t))return parseFloat(t);if(void 0!==o[t])return o[t]}return parseFloat(t)})),f===p&&l.push(1),c=h||void 0===l[u]?1:l[u],l=l.slice(0,u)}else t.length>10&&/[0-9](?:\\s|\\/)/.test(t)&&(l=t.match(/([0-9]+)/g).map((function(t){return parseFloat(t)})),s=t.match(/([a-z])/gi).join(\"\").toLowerCase());else if(isNaN(t))if(i(t)){var d=a(t.r,t.red,t.R,null);null!==d?(s=\"rgb\",l=[d,a(t.g,t.green,t.G),a(t.b,t.blue,t.B)]):(s=\"hsl\",l=[a(t.h,t.hue,t.H),a(t.s,t.saturation,t.S),a(t.l,t.lightness,t.L,t.b,t.brightness)]),c=a(t.a,t.alpha,t.opacity,1),null!=t.opacity&&(c/=100)}else(Array.isArray(t)||r.ArrayBuffer&&ArrayBuffer.isView&&ArrayBuffer.isView(t))&&(l=[t[0],t[1],t[2]],s=\"rgb\",c=4===t.length?t[3]:1);else s=\"rgb\",l=[t>>>16,(65280&t)>>>8,255&t];return{space:s,values:l,alpha:c}};var o={red:0,orange:60,yellow:120,green:180,blue:240,purple:300}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"color-name\":124,defined:170,\"is-plain-obj\":469}],127:[function(t,e,r){\"use strict\";var n=t(\"color-parse\"),i=t(\"color-space/hsl\"),a=t(\"clamp\");e.exports=function(t){var e,r=n(t);return r.space?((e=Array(3))[0]=a(r.values[0],0,255),e[1]=a(r.values[1],0,255),e[2]=a(r.values[2],0,255),\"h\"===r.space[0]&&(e=i.rgb(e)),e.push(a(r.alpha,0,1)),e):[]}},{clamp:120,\"color-parse\":126,\"color-space/hsl\":128}],128:[function(t,e,r){\"use strict\";var n=t(\"./rgb\");e.exports={name:\"hsl\",min:[0,0,0],max:[360,100,100],channel:[\"hue\",\"saturation\",\"lightness\"],alias:[\"HSL\"],rgb:function(t){var e,r,n,i,a,o=t[0]/360,s=t[1]/100,l=t[2]/100;if(0===s)return[a=255*l,a,a];e=2*l-(r=l<.5?l*(1+s):l+s-l*s),i=[0,0,0];for(var c=0;c<3;c++)(n=o+1/3*-(c-1))<0?n++:n>1&&n--,a=6*n<1?e+6*(r-e)*n:2*n<1?r:3*n<2?e+(r-e)*(2/3-n)*6:e,i[c]=255*a;return i}},n.hsl=function(t){var e,r,n=t[0]/255,i=t[1]/255,a=t[2]/255,o=Math.min(n,i,a),s=Math.max(n,i,a),l=s-o;return s===o?e=0:n===s?e=(i-a)/l:i===s?e=2+(a-n)/l:a===s&&(e=4+(n-i)/l),(e=Math.min(60*e,360))<0&&(e+=360),r=(o+s)/2,[e,100*(s===o?0:r<=.5?l/(s+o):l/(2-s-o)),100*r]}},{\"./rgb\":129}],129:[function(t,e,r){\"use strict\";e.exports={name:\"rgb\",min:[0,0,0],max:[255,255,255],channel:[\"red\",\"green\",\"blue\"],alias:[\"RGB\"]}},{}],130:[function(t,e,r){e.exports={jet:[{index:0,rgb:[0,0,131]},{index:.125,rgb:[0,60,170]},{index:.375,rgb:[5,255,255]},{index:.625,rgb:[255,255,0]},{index:.875,rgb:[250,0,0]},{index:1,rgb:[128,0,0]}],hsv:[{index:0,rgb:[255,0,0]},{index:.169,rgb:[253,255,2]},{index:.173,rgb:[247,255,2]},{index:.337,rgb:[0,252,4]},{index:.341,rgb:[0,252,10]},{index:.506,rgb:[1,249,255]},{index:.671,rgb:[2,0,253]},{index:.675,rgb:[8,0,253]},{index:.839,rgb:[255,0,251]},{index:.843,rgb:[255,0,245]},{index:1,rgb:[255,0,6]}],hot:[{index:0,rgb:[0,0,0]},{index:.3,rgb:[230,0,0]},{index:.6,rgb:[255,210,0]},{index:1,rgb:[255,255,255]}],cool:[{index:0,rgb:[0,255,255]},{index:1,rgb:[255,0,255]}],spring:[{index:0,rgb:[255,0,255]},{index:1,rgb:[255,255,0]}],summer:[{index:0,rgb:[0,128,102]},{index:1,rgb:[255,255,102]}],autumn:[{index:0,rgb:[255,0,0]},{index:1,rgb:[255,255,0]}],winter:[{index:0,rgb:[0,0,255]},{index:1,rgb:[0,255,128]}],bone:[{index:0,rgb:[0,0,0]},{index:.376,rgb:[84,84,116]},{index:.753,rgb:[169,200,200]},{index:1,rgb:[255,255,255]}],copper:[{index:0,rgb:[0,0,0]},{index:.804,rgb:[255,160,102]},{index:1,rgb:[255,199,127]}],greys:[{index:0,rgb:[0,0,0]},{index:1,rgb:[255,255,255]}],yignbu:[{index:0,rgb:[8,29,88]},{index:.125,rgb:[37,52,148]},{index:.25,rgb:[34,94,168]},{index:.375,rgb:[29,145,192]},{index:.5,rgb:[65,182,196]},{index:.625,rgb:[127,205,187]},{index:.75,rgb:[199,233,180]},{index:.875,rgb:[237,248,217]},{index:1,rgb:[255,255,217]}],greens:[{index:0,rgb:[0,68,27]},{index:.125,rgb:[0,109,44]},{index:.25,rgb:[35,139,69]},{index:.375,rgb:[65,171,93]},{index:.5,rgb:[116,196,118]},{index:.625,rgb:[161,217,155]},{index:.75,rgb:[199,233,192]},{index:.875,rgb:[229,245,224]},{index:1,rgb:[247,252,245]}],yiorrd:[{index:0,rgb:[128,0,38]},{index:.125,rgb:[189,0,38]},{index:.25,rgb:[227,26,28]},{index:.375,rgb:[252,78,42]},{index:.5,rgb:[253,141,60]},{index:.625,rgb:[254,178,76]},{index:.75,rgb:[254,217,118]},{index:.875,rgb:[255,237,160]},{index:1,rgb:[255,255,204]}],bluered:[{index:0,rgb:[0,0,255]},{index:1,rgb:[255,0,0]}],rdbu:[{index:0,rgb:[5,10,172]},{index:.35,rgb:[106,137,247]},{index:.5,rgb:[190,190,190]},{index:.6,rgb:[220,170,132]},{index:.7,rgb:[230,145,90]},{index:1,rgb:[178,10,28]}],picnic:[{index:0,rgb:[0,0,255]},{index:.1,rgb:[51,153,255]},{index:.2,rgb:[102,204,255]},{index:.3,rgb:[153,204,255]},{index:.4,rgb:[204,204,255]},{index:.5,rgb:[255,255,255]},{index:.6,rgb:[255,204,255]},{index:.7,rgb:[255,153,255]},{index:.8,rgb:[255,102,204]},{index:.9,rgb:[255,102,102]},{index:1,rgb:[255,0,0]}],rainbow:[{index:0,rgb:[150,0,90]},{index:.125,rgb:[0,0,200]},{index:.25,rgb:[0,25,255]},{index:.375,rgb:[0,152,255]},{index:.5,rgb:[44,255,150]},{index:.625,rgb:[151,255,0]},{index:.75,rgb:[255,234,0]},{index:.875,rgb:[255,111,0]},{index:1,rgb:[255,0,0]}],portland:[{index:0,rgb:[12,51,131]},{index:.25,rgb:[10,136,186]},{index:.5,rgb:[242,211,56]},{index:.75,rgb:[242,143,56]},{index:1,rgb:[217,30,30]}],blackbody:[{index:0,rgb:[0,0,0]},{index:.2,rgb:[230,0,0]},{index:.4,rgb:[230,210,0]},{index:.7,rgb:[255,255,255]},{index:1,rgb:[160,200,255]}],earth:[{index:0,rgb:[0,0,130]},{index:.1,rgb:[0,180,180]},{index:.2,rgb:[40,210,40]},{index:.4,rgb:[230,230,50]},{index:.6,rgb:[120,70,20]},{index:1,rgb:[255,255,255]}],electric:[{index:0,rgb:[0,0,0]},{index:.15,rgb:[30,0,100]},{index:.4,rgb:[120,0,100]},{index:.6,rgb:[160,90,0]},{index:.8,rgb:[230,200,0]},{index:1,rgb:[255,250,220]}],alpha:[{index:0,rgb:[255,255,255,0]},{index:1,rgb:[255,255,255,1]}],viridis:[{index:0,rgb:[68,1,84]},{index:.13,rgb:[71,44,122]},{index:.25,rgb:[59,81,139]},{index:.38,rgb:[44,113,142]},{index:.5,rgb:[33,144,141]},{index:.63,rgb:[39,173,129]},{index:.75,rgb:[92,200,99]},{index:.88,rgb:[170,220,50]},{index:1,rgb:[253,231,37]}],inferno:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[31,12,72]},{index:.25,rgb:[85,15,109]},{index:.38,rgb:[136,34,106]},{index:.5,rgb:[186,54,85]},{index:.63,rgb:[227,89,51]},{index:.75,rgb:[249,140,10]},{index:.88,rgb:[249,201,50]},{index:1,rgb:[252,255,164]}],magma:[{index:0,rgb:[0,0,4]},{index:.13,rgb:[28,16,68]},{index:.25,rgb:[79,18,123]},{index:.38,rgb:[129,37,129]},{index:.5,rgb:[181,54,122]},{index:.63,rgb:[229,80,100]},{index:.75,rgb:[251,135,97]},{index:.88,rgb:[254,194,135]},{index:1,rgb:[252,253,191]}],plasma:[{index:0,rgb:[13,8,135]},{index:.13,rgb:[75,3,161]},{index:.25,rgb:[125,3,168]},{index:.38,rgb:[168,34,150]},{index:.5,rgb:[203,70,121]},{index:.63,rgb:[229,107,93]},{index:.75,rgb:[248,148,65]},{index:.88,rgb:[253,195,40]},{index:1,rgb:[240,249,33]}],warm:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[172,0,187]},{index:.25,rgb:[219,0,170]},{index:.38,rgb:[255,0,130]},{index:.5,rgb:[255,63,74]},{index:.63,rgb:[255,123,0]},{index:.75,rgb:[234,176,0]},{index:.88,rgb:[190,228,0]},{index:1,rgb:[147,255,0]}],cool:[{index:0,rgb:[125,0,179]},{index:.13,rgb:[116,0,218]},{index:.25,rgb:[98,74,237]},{index:.38,rgb:[68,146,231]},{index:.5,rgb:[0,204,197]},{index:.63,rgb:[0,247,146]},{index:.75,rgb:[0,255,88]},{index:.88,rgb:[40,255,8]},{index:1,rgb:[147,255,0]}],\"rainbow-soft\":[{index:0,rgb:[125,0,179]},{index:.1,rgb:[199,0,180]},{index:.2,rgb:[255,0,121]},{index:.3,rgb:[255,108,0]},{index:.4,rgb:[222,194,0]},{index:.5,rgb:[150,255,0]},{index:.6,rgb:[0,255,55]},{index:.7,rgb:[0,246,150]},{index:.8,rgb:[50,167,222]},{index:.9,rgb:[103,51,235]},{index:1,rgb:[124,0,186]}],bathymetry:[{index:0,rgb:[40,26,44]},{index:.13,rgb:[59,49,90]},{index:.25,rgb:[64,76,139]},{index:.38,rgb:[63,110,151]},{index:.5,rgb:[72,142,158]},{index:.63,rgb:[85,174,163]},{index:.75,rgb:[120,206,163]},{index:.88,rgb:[187,230,172]},{index:1,rgb:[253,254,204]}],cdom:[{index:0,rgb:[47,15,62]},{index:.13,rgb:[87,23,86]},{index:.25,rgb:[130,28,99]},{index:.38,rgb:[171,41,96]},{index:.5,rgb:[206,67,86]},{index:.63,rgb:[230,106,84]},{index:.75,rgb:[242,149,103]},{index:.88,rgb:[249,193,135]},{index:1,rgb:[254,237,176]}],chlorophyll:[{index:0,rgb:[18,36,20]},{index:.13,rgb:[25,63,41]},{index:.25,rgb:[24,91,59]},{index:.38,rgb:[13,119,72]},{index:.5,rgb:[18,148,80]},{index:.63,rgb:[80,173,89]},{index:.75,rgb:[132,196,122]},{index:.88,rgb:[175,221,162]},{index:1,rgb:[215,249,208]}],density:[{index:0,rgb:[54,14,36]},{index:.13,rgb:[89,23,80]},{index:.25,rgb:[110,45,132]},{index:.38,rgb:[120,77,178]},{index:.5,rgb:[120,113,213]},{index:.63,rgb:[115,151,228]},{index:.75,rgb:[134,185,227]},{index:.88,rgb:[177,214,227]},{index:1,rgb:[230,241,241]}],\"freesurface-blue\":[{index:0,rgb:[30,4,110]},{index:.13,rgb:[47,14,176]},{index:.25,rgb:[41,45,236]},{index:.38,rgb:[25,99,212]},{index:.5,rgb:[68,131,200]},{index:.63,rgb:[114,156,197]},{index:.75,rgb:[157,181,203]},{index:.88,rgb:[200,208,216]},{index:1,rgb:[241,237,236]}],\"freesurface-red\":[{index:0,rgb:[60,9,18]},{index:.13,rgb:[100,17,27]},{index:.25,rgb:[142,20,29]},{index:.38,rgb:[177,43,27]},{index:.5,rgb:[192,87,63]},{index:.63,rgb:[205,125,105]},{index:.75,rgb:[216,162,148]},{index:.88,rgb:[227,199,193]},{index:1,rgb:[241,237,236]}],oxygen:[{index:0,rgb:[64,5,5]},{index:.13,rgb:[106,6,15]},{index:.25,rgb:[144,26,7]},{index:.38,rgb:[168,64,3]},{index:.5,rgb:[188,100,4]},{index:.63,rgb:[206,136,11]},{index:.75,rgb:[220,174,25]},{index:.88,rgb:[231,215,44]},{index:1,rgb:[248,254,105]}],par:[{index:0,rgb:[51,20,24]},{index:.13,rgb:[90,32,35]},{index:.25,rgb:[129,44,34]},{index:.38,rgb:[159,68,25]},{index:.5,rgb:[182,99,19]},{index:.63,rgb:[199,134,22]},{index:.75,rgb:[212,171,35]},{index:.88,rgb:[221,210,54]},{index:1,rgb:[225,253,75]}],phase:[{index:0,rgb:[145,105,18]},{index:.13,rgb:[184,71,38]},{index:.25,rgb:[186,58,115]},{index:.38,rgb:[160,71,185]},{index:.5,rgb:[110,97,218]},{index:.63,rgb:[50,123,164]},{index:.75,rgb:[31,131,110]},{index:.88,rgb:[77,129,34]},{index:1,rgb:[145,105,18]}],salinity:[{index:0,rgb:[42,24,108]},{index:.13,rgb:[33,50,162]},{index:.25,rgb:[15,90,145]},{index:.38,rgb:[40,118,137]},{index:.5,rgb:[59,146,135]},{index:.63,rgb:[79,175,126]},{index:.75,rgb:[120,203,104]},{index:.88,rgb:[193,221,100]},{index:1,rgb:[253,239,154]}],temperature:[{index:0,rgb:[4,35,51]},{index:.13,rgb:[23,51,122]},{index:.25,rgb:[85,59,157]},{index:.38,rgb:[129,79,143]},{index:.5,rgb:[175,95,130]},{index:.63,rgb:[222,112,101]},{index:.75,rgb:[249,146,66]},{index:.88,rgb:[249,196,65]},{index:1,rgb:[232,250,91]}],turbidity:[{index:0,rgb:[34,31,27]},{index:.13,rgb:[65,50,41]},{index:.25,rgb:[98,69,52]},{index:.38,rgb:[131,89,57]},{index:.5,rgb:[161,112,59]},{index:.63,rgb:[185,140,66]},{index:.75,rgb:[202,174,88]},{index:.88,rgb:[216,209,126]},{index:1,rgb:[233,246,171]}],\"velocity-blue\":[{index:0,rgb:[17,32,64]},{index:.13,rgb:[35,52,116]},{index:.25,rgb:[29,81,156]},{index:.38,rgb:[31,113,162]},{index:.5,rgb:[50,144,169]},{index:.63,rgb:[87,173,176]},{index:.75,rgb:[149,196,189]},{index:.88,rgb:[203,221,211]},{index:1,rgb:[254,251,230]}],\"velocity-green\":[{index:0,rgb:[23,35,19]},{index:.13,rgb:[24,64,38]},{index:.25,rgb:[11,95,45]},{index:.38,rgb:[39,123,35]},{index:.5,rgb:[95,146,12]},{index:.63,rgb:[152,165,18]},{index:.75,rgb:[201,186,69]},{index:.88,rgb:[233,216,137]},{index:1,rgb:[255,253,205]}],cubehelix:[{index:0,rgb:[0,0,0]},{index:.07,rgb:[22,5,59]},{index:.13,rgb:[60,4,105]},{index:.2,rgb:[109,1,135]},{index:.27,rgb:[161,0,147]},{index:.33,rgb:[210,2,142]},{index:.4,rgb:[251,11,123]},{index:.47,rgb:[255,29,97]},{index:.53,rgb:[255,54,69]},{index:.6,rgb:[255,85,46]},{index:.67,rgb:[255,120,34]},{index:.73,rgb:[255,157,37]},{index:.8,rgb:[241,191,57]},{index:.87,rgb:[224,220,93]},{index:.93,rgb:[218,241,142]},{index:1,rgb:[227,253,198]}]}},{}],131:[function(t,e,r){\"use strict\";var n=t(\"./colorScale\"),i=t(\"lerp\");function a(t){return[t[0]/255,t[1]/255,t[2]/255,t[3]]}function o(t){for(var e,r=\"#\",n=0;n<3;++n)r+=(\"00\"+(e=(e=t[n]).toString(16))).substr(e.length);return r}function s(t){return\"rgba(\"+t.join(\",\")+\")\"}e.exports=function(t){var e,r,l,c,u,f,h,p,d,g;t||(t={});p=(t.nshades||72)-1,h=t.format||\"hex\",(f=t.colormap)||(f=\"jet\");if(\"string\"==typeof f){if(f=f.toLowerCase(),!n[f])throw Error(f+\" not a supported colorscale\");u=n[f]}else{if(!Array.isArray(f))throw Error(\"unsupported colormap option\",f);u=f.slice()}if(u.length>p+1)throw new Error(f+\" map requires nshades to be at least size \"+u.length);d=Array.isArray(t.alpha)?2!==t.alpha.length?[1,1]:t.alpha.slice():\"number\"==typeof t.alpha?[t.alpha,t.alpha]:[1,1];e=u.map((function(t){return Math.round(t.index*p)})),d[0]=Math.min(Math.max(d[0],0),1),d[1]=Math.min(Math.max(d[1],0),1);var m=u.map((function(t,e){var r=u[e].index,n=u[e].rgb.slice();return 4===n.length&&n[3]>=0&&n[3]<=1||(n[3]=d[0]+(d[1]-d[0])*r),n})),v=[];for(g=0;g<e.length-1;++g){c=e[g+1]-e[g],r=m[g],l=m[g+1];for(var y=0;y<c;y++){var x=y/c;v.push([Math.round(i(r[0],l[0],x)),Math.round(i(r[1],l[1],x)),Math.round(i(r[2],l[2],x)),i(r[3],l[3],x)])}}v.push(u[u.length-1].rgb.concat(d[1])),\"hex\"===h?v=v.map(o):\"rgbaString\"===h?v=v.map(s):\"float\"===h&&(v=v.map(a));return v}},{\"./colorScale\":130,lerp:472}],132:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a){var o=n(e,r,a);if(0===o){var s=i(n(t,e,r)),c=i(n(t,e,a));if(s===c){if(0===s){var u=l(t,e,r),f=l(t,e,a);return u===f?0:u?1:-1}return 0}return 0===c?s>0||l(t,e,a)?-1:1:0===s?c>0||l(t,e,r)?1:-1:i(c-s)}var h=n(t,e,r);return h>0?o>0&&n(t,e,a)>0?1:-1:h<0?o>0||n(t,e,a)>0?1:-1:n(t,e,a)>0||l(t,e,r)?1:-1};var n=t(\"robust-orientation\"),i=t(\"signum\"),a=t(\"two-sum\"),o=t(\"robust-product\"),s=t(\"robust-sum\");function l(t,e,r){var n=a(t[0],-e[0]),i=a(t[1],-e[1]),l=a(r[0],-e[0]),c=a(r[1],-e[1]),u=s(o(n,l),o(i,c));return u[u.length-1]>=0}},{\"robust-orientation\":548,\"robust-product\":549,\"robust-sum\":553,signum:554,\"two-sum\":583}],133:[function(t,e,r){e.exports=function(t,e){var r=t.length,a=t.length-e.length;if(a)return a;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return t[0]+t[1]-e[0]-e[1]||n(t[0],t[1])-n(e[0],e[1]);case 3:var o=t[0]+t[1],s=e[0]+e[1];if(a=o+t[2]-(s+e[2]))return a;var l=n(t[0],t[1]),c=n(e[0],e[1]);return n(l,t[2])-n(c,e[2])||n(l+t[2],o)-n(c+e[2],s);case 4:var u=t[0],f=t[1],h=t[2],p=t[3],d=e[0],g=e[1],m=e[2],v=e[3];return u+f+h+p-(d+g+m+v)||n(u,f,h,p)-n(d,g,m,v,d)||n(u+f,u+h,u+p,f+h,f+p,h+p)-n(d+g,d+m,d+v,g+m,g+v,m+v)||n(u+f+h,u+f+p,u+h+p,f+h+p)-n(d+g+m,d+g+v,d+m+v,g+m+v);default:for(var y=t.slice().sort(i),x=e.slice().sort(i),b=0;b<r;++b)if(a=y[b]-x[b])return a;return 0}};var n=Math.min;function i(t,e){return t-e}},{}],134:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"cell-orientation\");e.exports=function(t,e){return n(t,e)||i(t)-i(e)}},{\"cell-orientation\":117,\"compare-cell\":133}],135:[function(t,e,r){\"use strict\";var n=t(\"./lib/ch1d\"),i=t(\"./lib/ch2d\"),a=t(\"./lib/chnd\");e.exports=function(t){var e=t.length;if(0===e)return[];if(1===e)return[[0]];var r=t[0].length;if(0===r)return[];if(1===r)return n(t);if(2===r)return i(t);return a(t,r)}},{\"./lib/ch1d\":136,\"./lib/ch2d\":137,\"./lib/chnd\":138}],136:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0,r=0,n=1;n<t.length;++n)t[n][0]<t[e][0]&&(e=n),t[n][0]>t[r][0]&&(r=n);return e<r?[[e],[r]]:e>r?[[r],[e]]:[[e]]}},{}],137:[function(t,e,r){\"use strict\";e.exports=function(t){var e=n(t),r=e.length;if(r<=2)return[];for(var i=new Array(r),a=e[r-1],o=0;o<r;++o){var s=e[o];i[o]=[a,s],a=s}return i};var n=t(\"monotone-convex-hull-2d\")},{\"monotone-convex-hull-2d\":482}],138:[function(t,e,r){\"use strict\";e.exports=function(t,e){try{return n(t,!0)}catch(o){var r=i(t);if(r.length<=e)return[];var a=function(t,e){for(var r=t.length,n=new Array(r),i=0;i<e.length;++i)n[i]=t[e[i]];var a=e.length;for(i=0;i<r;++i)e.indexOf(i)<0&&(n[a++]=t[i]);return n}(t,r);return function(t,e){for(var r=t.length,n=e.length,i=0;i<r;++i)for(var a=t[i],o=0;o<a.length;++o){var s=a[o];if(s<n)a[o]=e[s];else{s-=n;for(var l=0;l<n;++l)s>=e[l]&&(s+=1);a[o]=s}}return t}(n(a,!0),r)}};var n=t(\"incremental-convex-hull\"),i=t(\"affine-hull\")},{\"affine-hull\":67,\"incremental-convex-hull\":459}],139:[function(t,e,r){e.exports={AFG:\"afghan\",ALA:\"\\\\b\\\\wland\",ALB:\"albania\",DZA:\"algeria\",ASM:\"^(?=.*americ).*samoa\",AND:\"andorra\",AGO:\"angola\",AIA:\"anguill?a\",ATA:\"antarctica\",ATG:\"antigua\",ARG:\"argentin\",ARM:\"armenia\",ABW:\"^(?!.*bonaire).*\\\\baruba\",AUS:\"australia\",AUT:\"^(?!.*hungary).*austria|\\\\baustri.*\\\\bemp\",AZE:\"azerbaijan\",BHS:\"bahamas\",BHR:\"bahrain\",BGD:\"bangladesh|^(?=.*east).*paki?stan\",BRB:\"barbados\",BLR:\"belarus|byelo\",BEL:\"^(?!.*luxem).*belgium\",BLZ:\"belize|^(?=.*british).*honduras\",BEN:\"benin|dahome\",BMU:\"bermuda\",BTN:\"bhutan\",BOL:\"bolivia\",BES:\"^(?=.*bonaire).*eustatius|^(?=.*carib).*netherlands|\\\\bbes.?islands\",BIH:\"herzegovina|bosnia\",BWA:\"botswana|bechuana\",BVT:\"bouvet\",BRA:\"brazil\",IOT:\"british.?indian.?ocean\",BRN:\"brunei\",BGR:\"bulgaria\",BFA:\"burkina|\\\\bfaso|upper.?volta\",BDI:\"burundi\",CPV:\"verde\",KHM:\"cambodia|kampuchea|khmer\",CMR:\"cameroon\",CAN:\"canada\",CYM:\"cayman\",CAF:\"\\\\bcentral.african.republic\",TCD:\"\\\\bchad\",CHL:\"\\\\bchile\",CHN:\"^(?!.*\\\\bmac)(?!.*\\\\bhong)(?!.*\\\\btai)(?!.*\\\\brep).*china|^(?=.*peo)(?=.*rep).*china\",CXR:\"christmas\",CCK:\"\\\\bcocos|keeling\",COL:\"colombia\",COM:\"comoro\",COG:\"^(?!.*\\\\bdem)(?!.*\\\\bd[\\\\.]?r)(?!.*kinshasa)(?!.*zaire)(?!.*belg)(?!.*l.opoldville)(?!.*free).*\\\\bcongo\",COK:\"\\\\bcook\",CRI:\"costa.?rica\",CIV:\"ivoire|ivory\",HRV:\"croatia\",CUB:\"\\\\bcuba\",CUW:\"^(?!.*bonaire).*\\\\bcura(c|\\xe7)ao\",CYP:\"cyprus\",CSK:\"czechoslovakia\",CZE:\"^(?=.*rep).*czech|czechia|bohemia\",COD:\"\\\\bdem.*congo|congo.*\\\\bdem|congo.*\\\\bd[\\\\.]?r|\\\\bd[\\\\.]?r.*congo|belgian.?congo|congo.?free.?state|kinshasa|zaire|l.opoldville|drc|droc|rdc\",DNK:\"denmark\",DJI:\"djibouti\",DMA:\"dominica(?!n)\",DOM:\"dominican.rep\",ECU:\"ecuador\",EGY:\"egypt\",SLV:\"el.?salvador\",GNQ:\"guine.*eq|eq.*guine|^(?=.*span).*guinea\",ERI:\"eritrea\",EST:\"estonia\",ETH:\"ethiopia|abyssinia\",FLK:\"falkland|malvinas\",FRO:\"faroe|faeroe\",FJI:\"fiji\",FIN:\"finland\",FRA:\"^(?!.*\\\\bdep)(?!.*martinique).*france|french.?republic|\\\\bgaul\",GUF:\"^(?=.*french).*guiana\",PYF:\"french.?polynesia|tahiti\",ATF:\"french.?southern\",GAB:\"gabon\",GMB:\"gambia\",GEO:\"^(?!.*south).*georgia\",DDR:\"german.?democratic.?republic|democratic.?republic.*germany|east.germany\",DEU:\"^(?!.*east).*germany|^(?=.*\\\\bfed.*\\\\brep).*german\",GHA:\"ghana|gold.?coast\",GIB:\"gibraltar\",GRC:\"greece|hellenic|hellas\",GRL:\"greenland\",GRD:\"grenada\",GLP:\"guadeloupe\",GUM:\"\\\\bguam\",GTM:\"guatemala\",GGY:\"guernsey\",GIN:\"^(?!.*eq)(?!.*span)(?!.*bissau)(?!.*portu)(?!.*new).*guinea\",GNB:\"bissau|^(?=.*portu).*guinea\",GUY:\"guyana|british.?guiana\",HTI:\"haiti\",HMD:\"heard.*mcdonald\",VAT:\"holy.?see|vatican|papal.?st\",HND:\"^(?!.*brit).*honduras\",HKG:\"hong.?kong\",HUN:\"^(?!.*austr).*hungary\",ISL:\"iceland\",IND:\"india(?!.*ocea)\",IDN:\"indonesia\",IRN:\"\\\\biran|persia\",IRQ:\"\\\\biraq|mesopotamia\",IRL:\"(^ireland)|(^republic.*ireland)\",IMN:\"^(?=.*isle).*\\\\bman\",ISR:\"israel\",ITA:\"italy\",JAM:\"jamaica\",JPN:\"japan\",JEY:\"jersey\",JOR:\"jordan\",KAZ:\"kazak\",KEN:\"kenya|british.?east.?africa|east.?africa.?prot\",KIR:\"kiribati\",PRK:\"^(?=.*democrat|people|north|d.*p.*.r).*\\\\bkorea|dprk|korea.*(d.*p.*r)\",KWT:\"kuwait\",KGZ:\"kyrgyz|kirghiz\",LAO:\"\\\\blaos?\\\\b\",LVA:\"latvia\",LBN:\"lebanon\",LSO:\"lesotho|basuto\",LBR:\"liberia\",LBY:\"libya\",LIE:\"liechtenstein\",LTU:\"lithuania\",LUX:\"^(?!.*belg).*luxem\",MAC:\"maca(o|u)\",MDG:\"madagascar|malagasy\",MWI:\"malawi|nyasa\",MYS:\"malaysia\",MDV:\"maldive\",MLI:\"\\\\bmali\\\\b\",MLT:\"\\\\bmalta\",MHL:\"marshall\",MTQ:\"martinique\",MRT:\"mauritania\",MUS:\"mauritius\",MYT:\"\\\\bmayotte\",MEX:\"\\\\bmexic\",FSM:\"fed.*micronesia|micronesia.*fed\",MCO:\"monaco\",MNG:\"mongolia\",MNE:\"^(?!.*serbia).*montenegro\",MSR:\"montserrat\",MAR:\"morocco|\\\\bmaroc\",MOZ:\"mozambique\",MMR:\"myanmar|burma\",NAM:\"namibia\",NRU:\"nauru\",NPL:\"nepal\",NLD:\"^(?!.*\\\\bant)(?!.*\\\\bcarib).*netherlands\",ANT:\"^(?=.*\\\\bant).*(nether|dutch)\",NCL:\"new.?caledonia\",NZL:\"new.?zealand\",NIC:\"nicaragua\",NER:\"\\\\bniger(?!ia)\",NGA:\"nigeria\",NIU:\"niue\",NFK:\"norfolk\",MNP:\"mariana\",NOR:\"norway\",OMN:\"\\\\boman|trucial\",PAK:\"^(?!.*east).*paki?stan\",PLW:\"palau\",PSE:\"palestin|\\\\bgaza|west.?bank\",PAN:\"panama\",PNG:\"papua|new.?guinea\",PRY:\"paraguay\",PER:\"peru\",PHL:\"philippines\",PCN:\"pitcairn\",POL:\"poland\",PRT:\"portugal\",PRI:\"puerto.?rico\",QAT:\"qatar\",KOR:\"^(?!.*d.*p.*r)(?!.*democrat)(?!.*people)(?!.*north).*\\\\bkorea(?!.*d.*p.*r)\",MDA:\"moldov|b(a|e)ssarabia\",REU:\"r(e|\\xe9)union\",ROU:\"r(o|u|ou)mania\",RUS:\"\\\\brussia|soviet.?union|u\\\\.?s\\\\.?s\\\\.?r|socialist.?republics\",RWA:\"rwanda\",BLM:\"barth(e|\\xe9)lemy\",SHN:\"helena\",KNA:\"kitts|\\\\bnevis\",LCA:\"\\\\blucia\",MAF:\"^(?=.*collectivity).*martin|^(?=.*france).*martin(?!ique)|^(?=.*french).*martin(?!ique)\",SPM:\"miquelon\",VCT:\"vincent\",WSM:\"^(?!.*amer).*samoa\",SMR:\"san.?marino\",STP:\"\\\\bs(a|\\xe3)o.?tom(e|\\xe9)\",SAU:\"\\\\bsa\\\\w*.?arabia\",SEN:\"senegal\",SRB:\"^(?!.*monte).*serbia\",SYC:\"seychell\",SLE:\"sierra\",SGP:\"singapore\",SXM:\"^(?!.*martin)(?!.*saba).*maarten\",SVK:\"^(?!.*cze).*slovak\",SVN:\"slovenia\",SLB:\"solomon\",SOM:\"somali\",ZAF:\"south.africa|s\\\\\\\\..?africa\",SGS:\"south.?georgia|sandwich\",SSD:\"\\\\bs\\\\w*.?sudan\",ESP:\"spain\",LKA:\"sri.?lanka|ceylon\",SDN:\"^(?!.*\\\\bs(?!u)).*sudan\",SUR:\"surinam|dutch.?guiana\",SJM:\"svalbard\",SWZ:\"swaziland\",SWE:\"sweden\",CHE:\"switz|swiss\",SYR:\"syria\",TWN:\"taiwan|taipei|formosa|^(?!.*peo)(?=.*rep).*china\",TJK:\"tajik\",THA:\"thailand|\\\\bsiam\",MKD:\"macedonia|fyrom\",TLS:\"^(?=.*leste).*timor|^(?=.*east).*timor\",TGO:\"togo\",TKL:\"tokelau\",TON:\"tonga\",TTO:\"trinidad|tobago\",TUN:\"tunisia\",TUR:\"turkey\",TKM:\"turkmen\",TCA:\"turks\",TUV:\"tuvalu\",UGA:\"uganda\",UKR:\"ukrain\",ARE:\"emirates|^u\\\\.?a\\\\.?e\\\\.?$|united.?arab.?em\",GBR:\"united.?kingdom|britain|^u\\\\.?k\\\\.?$\",TZA:\"tanzania\",USA:\"united.?states\\\\b(?!.*islands)|\\\\bu\\\\.?s\\\\.?a\\\\.?\\\\b|^\\\\s*u\\\\.?s\\\\.?\\\\b(?!.*islands)\",UMI:\"minor.?outlying.?is\",URY:\"uruguay\",UZB:\"uzbek\",VUT:\"vanuatu|new.?hebrides\",VEN:\"venezuela\",VNM:\"^(?!.*republic).*viet.?nam|^(?=.*socialist).*viet.?nam\",VGB:\"^(?=.*\\\\bu\\\\.?\\\\s?k).*virgin|^(?=.*brit).*virgin|^(?=.*kingdom).*virgin\",VIR:\"^(?=.*\\\\bu\\\\.?\\\\s?s).*virgin|^(?=.*states).*virgin\",WLF:\"futuna|wallis\",ESH:\"western.sahara\",YEM:\"^(?!.*arab)(?!.*north)(?!.*sana)(?!.*peo)(?!.*dem)(?!.*south)(?!.*aden)(?!.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YMD:\"^(?=.*peo).*yemen|^(?!.*rep)(?=.*dem).*yemen|^(?=.*south).*yemen|^(?=.*aden).*yemen|^(?=.*\\\\bp\\\\.?d\\\\.?r).*yemen\",YUG:\"yugoslavia\",ZMB:\"zambia|northern.?rhodesia\",EAZ:\"zanzibar\",ZWE:\"zimbabwe|^(?!.*northern).*rhodesia\"}},{}],140:[function(t,e,r){e.exports=[\"xx-small\",\"x-small\",\"small\",\"medium\",\"large\",\"x-large\",\"xx-large\",\"larger\",\"smaller\"]},{}],141:[function(t,e,r){e.exports=[\"normal\",\"condensed\",\"semi-condensed\",\"extra-condensed\",\"ultra-condensed\",\"expanded\",\"semi-expanded\",\"extra-expanded\",\"ultra-expanded\"]},{}],142:[function(t,e,r){e.exports=[\"normal\",\"italic\",\"oblique\"]},{}],143:[function(t,e,r){e.exports=[\"normal\",\"bold\",\"bolder\",\"lighter\",\"100\",\"200\",\"300\",\"400\",\"500\",\"600\",\"700\",\"800\",\"900\"]},{}],144:[function(t,e,r){\"use strict\";e.exports={parse:t(\"./parse\"),stringify:t(\"./stringify\")}},{\"./parse\":146,\"./stringify\":147}],145:[function(t,e,r){\"use strict\";var n=t(\"css-font-size-keywords\");e.exports={isSize:function(t){return/^[\\d\\.]/.test(t)||-1!==t.indexOf(\"/\")||-1!==n.indexOf(t)}}},{\"css-font-size-keywords\":140}],146:[function(t,e,r){\"use strict\";var n=t(\"unquote\"),i=t(\"css-global-keywords\"),a=t(\"css-system-font-keywords\"),o=t(\"css-font-weight-keywords\"),s=t(\"css-font-style-keywords\"),l=t(\"css-font-stretch-keywords\"),c=t(\"string-split-by\"),u=t(\"./lib/util\").isSize;e.exports=h;var f=h.cache={};function h(t){if(\"string\"!=typeof t)throw new Error(\"Font argument must be a string.\");if(f[t])return f[t];if(\"\"===t)throw new Error(\"Cannot parse an empty string.\");if(-1!==a.indexOf(t))return f[t]={system:t};for(var e,r={style:\"normal\",variant:\"normal\",weight:\"normal\",stretch:\"normal\",lineHeight:\"normal\",size:\"1rem\",family:[\"serif\"]},h=c(t,/\\s+/);e=h.shift();){if(-1!==i.indexOf(e))return[\"style\",\"variant\",\"weight\",\"stretch\"].forEach((function(t){r[t]=e})),f[t]=r;if(-1===s.indexOf(e))if(\"normal\"!==e&&\"small-caps\"!==e)if(-1===l.indexOf(e)){if(-1===o.indexOf(e)){if(u(e)){var d=c(e,\"/\");if(r.size=d[0],null!=d[1]?r.lineHeight=p(d[1]):\"/\"===h[0]&&(h.shift(),r.lineHeight=p(h.shift())),!h.length)throw new Error(\"Missing required font-family.\");return r.family=c(h.join(\" \"),/\\s*,\\s*/).map(n),f[t]=r}throw new Error(\"Unknown or unsupported font token: \"+e)}r.weight=e}else r.stretch=e;else r.variant=e;else r.style=e}throw new Error(\"Missing required font-size.\")}function p(t){var e=parseFloat(t);return e.toString()===t?e:t}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"string-split-by\":568,unquote:598}],147:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\"),i=t(\"./lib/util\").isSize,a=g(t(\"css-global-keywords\")),o=g(t(\"css-system-font-keywords\")),s=g(t(\"css-font-weight-keywords\")),l=g(t(\"css-font-style-keywords\")),c=g(t(\"css-font-stretch-keywords\")),u={normal:1,\"small-caps\":1},f={serif:1,\"sans-serif\":1,monospace:1,cursive:1,fantasy:1,\"system-ui\":1},h=\"1rem\",p=\"serif\";function d(t,e){if(t&&!e[t]&&!a[t])throw Error(\"Unknown keyword `\"+t+\"`\");return t}function g(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=1;return e}e.exports=function(t){if((t=n(t,{style:\"style fontstyle fontStyle font-style slope distinction\",variant:\"variant font-variant fontVariant fontvariant var capitalization\",weight:\"weight w font-weight fontWeight fontweight\",stretch:\"stretch font-stretch fontStretch fontstretch width\",size:\"size s font-size fontSize fontsize height em emSize\",lineHeight:\"lh line-height lineHeight lineheight leading\",family:\"font family fontFamily font-family fontfamily type typeface face\",system:\"system reserved default global\"})).system)return t.system&&d(t.system,o),t.system;if(d(t.style,l),d(t.variant,u),d(t.weight,s),d(t.stretch,c),null==t.size&&(t.size=h),\"number\"==typeof t.size&&(t.size+=\"px\"),!i)throw Error(\"Bad size value `\"+t.size+\"`\");t.family||(t.family=p),Array.isArray(t.family)&&(t.family.length||(t.family=[p]),t.family=t.family.map((function(t){return f[t]?t:'\"'+t+'\"'})).join(\", \"));var e=[];return e.push(t.style),t.variant!==t.style&&e.push(t.variant),t.weight!==t.variant&&t.weight!==t.style&&e.push(t.weight),t.stretch!==t.weight&&t.stretch!==t.variant&&t.stretch!==t.style&&e.push(t.stretch),e.push(t.size+(null==t.lineHeight||\"normal\"===t.lineHeight||t.lineHeight+\"\"==\"1\"?\"\":\"/\"+t.lineHeight)),e.push(t.family),e.filter(Boolean).join(\" \")}},{\"./lib/util\":145,\"css-font-stretch-keywords\":141,\"css-font-style-keywords\":142,\"css-font-weight-keywords\":143,\"css-global-keywords\":148,\"css-system-font-keywords\":149,\"pick-by-alias\":511}],148:[function(t,e,r){e.exports=[\"inherit\",\"initial\",\"unset\"]},{}],149:[function(t,e,r){e.exports=[\"caption\",\"icon\",\"menu\",\"message-box\",\"small-caption\",\"status-bar\"]},{}],150:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i-1,s=i*i,l=o*o,c=(1+2*i)*l,u=i*l,f=s*(3-2*i),h=s*o;if(t.length){a||(a=new Array(t.length));for(var p=t.length-1;p>=0;--p)a[p]=c*t[p]+u*e[p]+f*r[p]+h*n[p];return a}return c*t+u*e+f*r+h*n},e.exports.derivative=function(t,e,r,n,i,a){var o=6*i*i-6*i,s=3*i*i-4*i+1,l=-6*i*i+6*i,c=3*i*i-2*i;if(t.length){a||(a=new Array(t.length));for(var u=t.length-1;u>=0;--u)a[u]=o*t[u]+s*e[u]+l*r[u]+c*n[u];return a}return o*t+s*e+l*r[u]+c*n}},{}],151:[function(t,e,r){\"use strict\";var n=t(\"./lib/thunk.js\");function i(){this.argTypes=[],this.shimArgs=[],this.arrayArgs=[],this.arrayBlockIndices=[],this.scalarArgs=[],this.offsetArgs=[],this.offsetArgIndex=[],this.indexArgs=[],this.shapeArgs=[],this.funcName=\"\",this.pre=null,this.body=null,this.post=null,this.debug=!1}e.exports=function(t){var e=new i;e.pre=t.pre,e.body=t.body,e.post=t.post;var r=t.args.slice(0);e.argTypes=r;for(var a=0;a<r.length;++a){var o=r[a];if(\"array\"===o||\"object\"==typeof o&&o.blockIndices){if(e.argTypes[a]=\"array\",e.arrayArgs.push(a),e.arrayBlockIndices.push(o.blockIndices?o.blockIndices:0),e.shimArgs.push(\"array\"+a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array args\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array args\")}else if(\"scalar\"===o)e.scalarArgs.push(a),e.shimArgs.push(\"scalar\"+a);else if(\"index\"===o){if(e.indexArgs.push(a),a<e.pre.args.length&&e.pre.args[a].count>0)throw new Error(\"cwise: pre() block may not reference array index\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array index\");if(a<e.post.args.length&&e.post.args[a].count>0)throw new Error(\"cwise: post() block may not reference array index\")}else if(\"shape\"===o){if(e.shapeArgs.push(a),a<e.pre.args.length&&e.pre.args[a].lvalue)throw new Error(\"cwise: pre() block may not write to array shape\");if(a<e.body.args.length&&e.body.args[a].lvalue)throw new Error(\"cwise: body() block may not write to array shape\");if(a<e.post.args.length&&e.post.args[a].lvalue)throw new Error(\"cwise: post() block may not write to array shape\")}else{if(\"object\"!=typeof o||!o.offset)throw new Error(\"cwise: Unknown argument type \"+r[a]);e.argTypes[a]=\"offset\",e.offsetArgs.push({array:o.array,offset:o.offset}),e.offsetArgIndex.push(a)}}if(e.arrayArgs.length<=0)throw new Error(\"cwise: No array arguments specified\");if(e.pre.args.length>r.length)throw new Error(\"cwise: Too many arguments in pre() block\");if(e.body.args.length>r.length)throw new Error(\"cwise: Too many arguments in body() block\");if(e.post.args.length>r.length)throw new Error(\"cwise: Too many arguments in post() block\");return e.debug=!!t.printCode||!!t.debug,e.funcName=t.funcName||\"cwise\",e.blockSize=t.blockSize||64,n(e)}},{\"./lib/thunk.js\":153}],152:[function(t,e,r){\"use strict\";var n=t(\"uniq\");function i(t,e,r){var n,i,a=t.length,o=e.arrayArgs.length,s=e.indexArgs.length>0,l=[],c=[],u=0,f=0;for(n=0;n<a;++n)c.push([\"i\",n,\"=0\"].join(\"\"));for(i=0;i<o;++i)for(n=0;n<a;++n)f=u,u=t[n],0===n?c.push([\"d\",i,\"s\",n,\"=t\",i,\"p\",u].join(\"\")):c.push([\"d\",i,\"s\",n,\"=(t\",i,\"p\",u,\"-s\",f,\"*t\",i,\"p\",f,\")\"].join(\"\"));for(c.length>0&&l.push(\"var \"+c.join(\",\")),n=a-1;n>=0;--n)u=t[n],l.push([\"for(i\",n,\"=0;i\",n,\"<s\",u,\";++i\",n,\"){\"].join(\"\"));for(l.push(r),n=0;n<a;++n){for(f=u,u=t[n],i=0;i<o;++i)l.push([\"p\",i,\"+=d\",i,\"s\",n].join(\"\"));s&&(n>0&&l.push([\"index[\",f,\"]-=s\",f].join(\"\")),l.push([\"++index[\",u,\"]\"].join(\"\"))),l.push(\"}\")}return l.join(\"\\n\")}function a(t,e,r){for(var n=t.body,i=[],a=[],o=0;o<t.args.length;++o){var s=t.args[o];if(!(s.count<=0)){var l=new RegExp(s.name,\"g\"),c=\"\",u=e.arrayArgs.indexOf(o);switch(e.argTypes[o]){case\"offset\":var f=e.offsetArgIndex.indexOf(o);u=e.offsetArgs[f].array,c=\"+q\"+f;case\"array\":c=\"p\"+u+c;var h=\"l\"+o,p=\"a\"+u;if(0===e.arrayBlockIndices[u])1===s.count?\"generic\"===r[u]?s.lvalue?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):n=n.replace(l,[p,\".get(\",c,\")\"].join(\"\")):n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\")):\"generic\"===r[u]?(i.push([\"var \",h,\"=\",p,\".get(\",c,\")\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\".set(\",c,\",\",h,\")\"].join(\"\"))):(i.push([\"var \",h,\"=\",p,\"[\",c,\"]\"].join(\"\")),n=n.replace(l,h),s.lvalue&&a.push([p,\"[\",c,\"]=\",h].join(\"\")));else{for(var d=[s.name],g=[c],m=0;m<Math.abs(e.arrayBlockIndices[u]);m++)d.push(\"\\\\s*\\\\[([^\\\\]]+)\\\\]\"),g.push(\"$\"+(m+1)+\"*t\"+u+\"b\"+m);if(l=new RegExp(d.join(\"\"),\"g\"),c=g.join(\"+\"),\"generic\"===r[u])throw new Error(\"cwise: Generic arrays not supported in combination with blocks!\");n=n.replace(l,[p,\"[\",c,\"]\"].join(\"\"))}break;case\"scalar\":n=n.replace(l,\"Y\"+e.scalarArgs.indexOf(o));break;case\"index\":n=n.replace(l,\"index\");break;case\"shape\":n=n.replace(l,\"shape\")}}}return[i.join(\"\\n\"),n,a.join(\"\\n\")].join(\"\\n\").trim()}function o(t){for(var e=new Array(t.length),r=!0,n=0;n<t.length;++n){var i=t[n],a=i.match(/\\d+/);a=a?a[0]:\"\",0===i.charAt(0)?e[n]=\"u\"+i.charAt(1)+a:e[n]=i.charAt(0)+a,n>0&&(r=r&&e[n]===e[n-1])}return r?e[0]:e.join(\"\")}e.exports=function(t,e){for(var r=e[1].length-Math.abs(t.arrayBlockIndices[0])|0,s=new Array(t.arrayArgs.length),l=new Array(t.arrayArgs.length),c=0;c<t.arrayArgs.length;++c)l[c]=e[2*c],s[c]=e[2*c+1];var u=[],f=[],h=[],p=[],d=[];for(c=0;c<t.arrayArgs.length;++c){t.arrayBlockIndices[c]<0?(h.push(0),p.push(r),u.push(r),f.push(r+t.arrayBlockIndices[c])):(h.push(t.arrayBlockIndices[c]),p.push(t.arrayBlockIndices[c]+r),u.push(0),f.push(t.arrayBlockIndices[c]));for(var g=[],m=0;m<s[c].length;m++)h[c]<=s[c][m]&&s[c][m]<p[c]&&g.push(s[c][m]-h[c]);d.push(g)}var v=[\"SS\"],y=[\"'use strict'\"],x=[];for(m=0;m<r;++m)x.push([\"s\",m,\"=SS[\",m,\"]\"].join(\"\"));for(c=0;c<t.arrayArgs.length;++c){v.push(\"a\"+c),v.push(\"t\"+c),v.push(\"p\"+c);for(m=0;m<r;++m)x.push([\"t\",c,\"p\",m,\"=t\",c,\"[\",h[c]+m,\"]\"].join(\"\"));for(m=0;m<Math.abs(t.arrayBlockIndices[c]);++m)x.push([\"t\",c,\"b\",m,\"=t\",c,\"[\",u[c]+m,\"]\"].join(\"\"))}for(c=0;c<t.scalarArgs.length;++c)v.push(\"Y\"+c);if(t.shapeArgs.length>0&&x.push(\"shape=SS.slice(0)\"),t.indexArgs.length>0){var b=new Array(r);for(c=0;c<r;++c)b[c]=\"0\";x.push([\"index=[\",b.join(\",\"),\"]\"].join(\"\"))}for(c=0;c<t.offsetArgs.length;++c){var _=t.offsetArgs[c],w=[];for(m=0;m<_.offset.length;++m)0!==_.offset[m]&&(1===_.offset[m]?w.push([\"t\",_.array,\"p\",m].join(\"\")):w.push([_.offset[m],\"*t\",_.array,\"p\",m].join(\"\")));0===w.length?x.push(\"q\"+c+\"=0\"):x.push([\"q\",c,\"=\",w.join(\"+\")].join(\"\"))}var T=n([].concat(t.pre.thisVars).concat(t.body.thisVars).concat(t.post.thisVars));for((x=x.concat(T)).length>0&&y.push(\"var \"+x.join(\",\")),c=0;c<t.arrayArgs.length;++c)y.push(\"p\"+c+\"|=0\");t.pre.body.length>3&&y.push(a(t.pre,t,l));var k=a(t.body,t,l),M=function(t){for(var e=0,r=t[0].length;e<r;){for(var n=1;n<t.length;++n)if(t[n][e]!==t[0][e])return e;++e}return e}(d);M<r?y.push(function(t,e,r,n){for(var a=e.length,o=r.arrayArgs.length,s=r.blockSize,l=r.indexArgs.length>0,c=[],u=0;u<o;++u)c.push([\"var offset\",u,\"=p\",u].join(\"\"));for(u=t;u<a;++u)c.push([\"for(var j\"+u+\"=SS[\",e[u],\"]|0;j\",u,\">0;){\"].join(\"\")),c.push([\"if(j\",u,\"<\",s,\"){\"].join(\"\")),c.push([\"s\",e[u],\"=j\",u].join(\"\")),c.push([\"j\",u,\"=0\"].join(\"\")),c.push([\"}else{s\",e[u],\"=\",s].join(\"\")),c.push([\"j\",u,\"-=\",s,\"}\"].join(\"\")),l&&c.push([\"index[\",e[u],\"]=j\",u].join(\"\"));for(u=0;u<o;++u){for(var f=[\"offset\"+u],h=t;h<a;++h)f.push([\"j\",h,\"*t\",u,\"p\",e[h]].join(\"\"));c.push([\"p\",u,\"=(\",f.join(\"+\"),\")\"].join(\"\"))}for(c.push(i(e,r,n)),u=t;u<a;++u)c.push(\"}\");return c.join(\"\\n\")}(M,d[0],t,k)):y.push(i(d[0],t,k)),t.post.body.length>3&&y.push(a(t.post,t,l)),t.debug&&console.log(\"-----Generated cwise routine for \",e,\":\\n\"+y.join(\"\\n\")+\"\\n----------\");var A=[t.funcName||\"unnamed\",\"_cwise_loop_\",s[0].join(\"s\"),\"m\",M,o(l)].join(\"\");return new Function([\"function \",A,\"(\",v.join(\",\"),\"){\",y.join(\"\\n\"),\"} return \",A].join(\"\"))()}},{uniq:597}],153:[function(t,e,r){\"use strict\";var n=t(\"./compile.js\");e.exports=function(t){var e=[\"'use strict'\",\"var CACHED={}\"],r=[],i=t.funcName+\"_cwise_thunk\";e.push([\"return function \",i,\"(\",t.shimArgs.join(\",\"),\"){\"].join(\"\"));for(var a=[],o=[],s=[[\"array\",t.arrayArgs[0],\".shape.slice(\",Math.max(0,t.arrayBlockIndices[0]),t.arrayBlockIndices[0]<0?\",\"+t.arrayBlockIndices[0]+\")\":\")\"].join(\"\")],l=[],c=[],u=0;u<t.arrayArgs.length;++u){var f=t.arrayArgs[u];r.push([\"t\",f,\"=array\",f,\".dtype,\",\"r\",f,\"=array\",f,\".order\"].join(\"\")),a.push(\"t\"+f),a.push(\"r\"+f),o.push(\"t\"+f),o.push(\"r\"+f+\".join()\"),s.push(\"array\"+f+\".data\"),s.push(\"array\"+f+\".stride\"),s.push(\"array\"+f+\".offset|0\"),u>0&&(l.push(\"array\"+t.arrayArgs[0]+\".shape.length===array\"+f+\".shape.length+\"+(Math.abs(t.arrayBlockIndices[0])-Math.abs(t.arrayBlockIndices[u]))),c.push(\"array\"+t.arrayArgs[0]+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[0])+\"]===array\"+f+\".shape[shapeIndex+\"+Math.max(0,t.arrayBlockIndices[u])+\"]\"))}for(t.arrayArgs.length>1&&(e.push(\"if (!(\"+l.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same dimensionality!')\"),e.push(\"for(var shapeIndex=array\"+t.arrayArgs[0]+\".shape.length-\"+Math.abs(t.arrayBlockIndices[0])+\"; shapeIndex--\\x3e0;) {\"),e.push(\"if (!(\"+c.join(\" && \")+\")) throw new Error('cwise: Arrays do not all have the same shape!')\"),e.push(\"}\")),u=0;u<t.scalarArgs.length;++u)s.push(\"scalar\"+t.scalarArgs[u]);return r.push([\"type=[\",o.join(\",\"),\"].join()\"].join(\"\")),r.push(\"proc=CACHED[type]\"),e.push(\"var \"+r.join(\",\")),e.push([\"if(!proc){\",\"CACHED[type]=proc=compile([\",a.join(\",\"),\"])}\",\"return proc(\",s.join(\",\"),\")}\"].join(\"\")),t.debug&&console.log(\"-----Generated thunk:\\n\"+e.join(\"\\n\")+\"\\n----------\"),new Function(\"compile\",e.join(\"\\n\"))(n.bind(void 0,t))}},{\"./compile.js\":152}],154:[function(t,e,r){\"use strict\";var n,i=t(\"type/value/is\"),a=t(\"type/value/ensure\"),o=t(\"type/plain-function/ensure\"),s=t(\"es5-ext/object/copy\"),l=t(\"es5-ext/object/normalize-options\"),c=t(\"es5-ext/object/map\"),u=Function.prototype.bind,f=Object.defineProperty,h=Object.prototype.hasOwnProperty;n=function(t,e,r){var n,i=a(e)&&o(e.value);return delete(n=s(e)).writable,delete n.value,n.get=function(){return!r.overwriteDefinition&&h.call(this,t)?i:(e.value=u.call(i,r.resolveContext?r.resolveContext(this):this),f(this,t,e),this[t])},n},e.exports=function(t){var e=l(arguments[1]);return i(e.resolveContext)&&o(e.resolveContext),c(t,(function(t,r){return n(r,t,e)}))}},{\"es5-ext/object/copy\":196,\"es5-ext/object/map\":204,\"es5-ext/object/normalize-options\":205,\"type/plain-function/ensure\":589,\"type/value/ensure\":593,\"type/value/is\":594}],155:[function(t,e,r){\"use strict\";var n=t(\"type/value/is\"),i=t(\"type/plain-function/is\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/normalize-options\"),s=t(\"es5-ext/string/#/contains\");(e.exports=function(t,e){var r,i,l,c,u;return arguments.length<2||\"string\"!=typeof t?(c=e,e=t,t=null):c=arguments[2],n(t)?(r=s.call(t,\"c\"),i=s.call(t,\"e\"),l=s.call(t,\"w\")):(r=l=!0,i=!1),u={value:e,configurable:r,enumerable:i,writable:l},c?a(o(c),u):u}).gs=function(t,e,r){var l,c,u,f;return\"string\"!=typeof t?(u=r,r=e,e=t,t=null):u=arguments[3],n(e)?i(e)?n(r)?i(r)||(u=r,r=void 0):r=void 0:(u=e,e=r=void 0):e=void 0,n(t)?(l=s.call(t,\"c\"),c=s.call(t,\"e\")):(l=!0,c=!1),f={get:e,set:r,configurable:l,enumerable:c},u?a(o(u),f):f}},{\"es5-ext/object/assign\":193,\"es5-ext/object/normalize-options\":205,\"es5-ext/string/#/contains\":212,\"type/plain-function/is\":590,\"type/value/is\":594}],156:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function r(t){var r;return 1===t.length&&(r=t,t=function(t,n){return e(r(t),n)}),{left:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(null==n&&(n=0),null==i&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}var n=r(e),i=n.right,a=n.left;function o(t,e){return[t,e]}function s(t){return null===t?NaN:+t}function l(t,e){var r,n,i=t.length,a=0,o=-1,l=0,c=0;if(null==e)for(;++o<i;)isNaN(r=s(t[o]))||(c+=(n=r-l)*(r-(l+=n/++a)));else for(;++o<i;)isNaN(r=s(e(t[o],o,t)))||(c+=(n=r-l)*(r-(l+=n/++a)));if(a>1)return c/(a-1)}function c(t,e){var r=l(t,e);return r?Math.sqrt(r):r}function u(t,e){var r,n,i,a=t.length,o=-1;if(null==e){for(;++o<a;)if(null!=(r=t[o])&&r>=r)for(n=i=r;++o<a;)null!=(r=t[o])&&(n>r&&(n=r),i<r&&(i=r))}else for(;++o<a;)if(null!=(r=e(t[o],o,t))&&r>=r)for(n=i=r;++o<a;)null!=(r=e(t[o],o,t))&&(n>r&&(n=r),i<r&&(i=r));return[n,i]}var f=Array.prototype,h=f.slice,p=f.map;function d(t){return function(){return t}}function g(t){return t}function m(t,e,r){t=+t,e=+e,r=(i=arguments.length)<2?(e=t,t=0,1):i<3?1:+r;for(var n=-1,i=0|Math.max(0,Math.ceil((e-t)/r)),a=new Array(i);++n<i;)a[n]=t+n*r;return a}var v=Math.sqrt(50),y=Math.sqrt(10),x=Math.sqrt(2);function b(t,e,r){var n=(e-t)/Math.max(0,r),i=Math.floor(Math.log(n)/Math.LN10),a=n/Math.pow(10,i);return i>=0?(a>=v?10:a>=y?5:a>=x?2:1)*Math.pow(10,i):-Math.pow(10,-i)/(a>=v?10:a>=y?5:a>=x?2:1)}function _(t,e,r){var n=Math.abs(e-t)/Math.max(0,r),i=Math.pow(10,Math.floor(Math.log(n)/Math.LN10)),a=n/i;return a>=v?i*=10:a>=y?i*=5:a>=x&&(i*=2),e<t?-i:i}function w(t){return Math.ceil(Math.log(t.length)/Math.LN2)+1}function T(t,e,r){if(null==r&&(r=s),n=t.length){if((e=+e)<=0||n<2)return+r(t[0],0,t);if(e>=1)return+r(t[n-1],n-1,t);var n,i=(n-1)*e,a=Math.floor(i),o=+r(t[a],a,t);return o+(+r(t[a+1],a+1,t)-o)*(i-a)}}function k(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&n>r&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&n>r&&(n=r);return n}function M(t){if(!(i=t.length))return[];for(var e=-1,r=k(t,A),n=new Array(r);++e<r;)for(var i,a=-1,o=n[e]=new Array(i);++a<i;)o[a]=t[a][e];return n}function A(t){return t.length}t.bisect=i,t.bisectRight=i,t.bisectLeft=a,t.ascending=e,t.bisector=r,t.cross=function(t,e,r){var n,i,a,s,l=t.length,c=e.length,u=new Array(l*c);for(null==r&&(r=o),n=a=0;n<l;++n)for(s=t[n],i=0;i<c;++i,++a)u[a]=r(s,e[i]);return u},t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.deviation=c,t.extent=u,t.histogram=function(){var t=g,e=u,r=w;function n(n){var a,o,s=n.length,l=new Array(s);for(a=0;a<s;++a)l[a]=t(n[a],a,n);var c=e(l),u=c[0],f=c[1],h=r(l,u,f);Array.isArray(h)||(h=_(u,f,h),h=m(Math.ceil(u/h)*h,f,h));for(var p=h.length;h[0]<=u;)h.shift(),--p;for(;h[p-1]>f;)h.pop(),--p;var d,g=new Array(p+1);for(a=0;a<=p;++a)(d=g[a]=[]).x0=a>0?h[a-1]:u,d.x1=a<p?h[a]:f;for(a=0;a<s;++a)u<=(o=l[a])&&o<=f&&g[i(h,o,0,p)].push(n[a]);return g}return n.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:d(e),n):t},n.domain=function(t){return arguments.length?(e=\"function\"==typeof t?t:d([t[0],t[1]]),n):e},n.thresholds=function(t){return arguments.length?(r=\"function\"==typeof t?t:Array.isArray(t)?d(h.call(t)):d(t),n):r},n},t.thresholdFreedmanDiaconis=function(t,r,n){return t=p.call(t,s).sort(e),Math.ceil((n-r)/(2*(T(t,.75)-T(t,.25))*Math.pow(t.length,-1/3)))},t.thresholdScott=function(t,e,r){return Math.ceil((r-e)/(3.5*c(t)*Math.pow(t.length,-1/3)))},t.thresholdSturges=w,t.max=function(t,e){var r,n,i=t.length,a=-1;if(null==e){for(;++a<i;)if(null!=(r=t[a])&&r>=r)for(n=r;++a<i;)null!=(r=t[a])&&r>n&&(n=r)}else for(;++a<i;)if(null!=(r=e(t[a],a,t))&&r>=r)for(n=r;++a<i;)null!=(r=e(t[a],a,t))&&r>n&&(n=r);return n},t.mean=function(t,e){var r,n=t.length,i=n,a=-1,o=0;if(null==e)for(;++a<n;)isNaN(r=s(t[a]))?--i:o+=r;else for(;++a<n;)isNaN(r=s(e(t[a],a,t)))?--i:o+=r;if(i)return o/i},t.median=function(t,r){var n,i=t.length,a=-1,o=[];if(null==r)for(;++a<i;)isNaN(n=s(t[a]))||o.push(n);else for(;++a<i;)isNaN(n=s(r(t[a],a,t)))||o.push(n);return T(o.sort(e),.5)},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r},t.min=k,t.pairs=function(t,e){null==e&&(e=o);for(var r=0,n=t.length-1,i=t[0],a=new Array(n<0?0:n);r<n;)a[r]=e(i,i=t[++r]);return a},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.quantile=T,t.range=m,t.scan=function(t,r){if(n=t.length){var n,i,a=0,o=0,s=t[o];for(null==r&&(r=e);++a<n;)(r(i=t[a],s)<0||0!==r(s,s))&&(s=i,o=a);return 0===r(s,s)?o:void 0}},t.shuffle=function(t,e,r){for(var n,i,a=(null==r?t.length:r)-(e=null==e?0:+e);a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.sum=function(t,e){var r,n=t.length,i=-1,a=0;if(null==e)for(;++i<n;)(r=+t[i])&&(a+=r);else for(;++i<n;)(r=+e(t[i],i,t))&&(a+=r);return a},t.ticks=function(t,e,r){var n,i,a,o,s=-1;if(r=+r,(t=+t)===(e=+e)&&r>0)return[t];if((n=e<t)&&(i=t,t=e,e=i),0===(o=b(t,e,r))||!isFinite(o))return[];if(o>0)for(t=Math.ceil(t/o),e=Math.floor(e/o),a=new Array(i=Math.ceil(e-t+1));++s<i;)a[s]=(t+s)*o;else for(t=Math.floor(t*o),e=Math.ceil(e*o),a=new Array(i=Math.ceil(t-e+1));++s<i;)a[s]=(t-s)/o;return n&&a.reverse(),a},t.tickIncrement=b,t.tickStep=_,t.transpose=M,t.variance=l,t.zip=function(){return M(arguments)},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],157:[function(t,e,r){!function(t,n){n(\"object\"==typeof r&&\"undefined\"!=typeof e?r:t.d3=t.d3||{})}(this,(function(t){\"use strict\";function e(){}function r(t,r){var n=new e;if(t instanceof e)t.each((function(t,e){n.set(e,t)}));else if(Array.isArray(t)){var i,a=-1,o=t.length;if(null==r)for(;++a<o;)n.set(a,t[a]);else for(;++a<o;)n.set(r(i=t[a],a,t),i)}else if(t)for(var s in t)n.set(s,t[s]);return n}function n(){return{}}function i(t,e,r){t[e]=r}function a(){return r()}function o(t,e,r){t.set(e,r)}function s(){}e.prototype=r.prototype={constructor:e,has:function(t){return\"$\"+t in this},get:function(t){return this[\"$\"+t]},set:function(t,e){return this[\"$\"+t]=e,this},remove:function(t){var e=\"$\"+t;return e in this&&delete this[e]},clear:function(){for(var t in this)\"$\"===t[0]&&delete this[t]},keys:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(e.slice(1));return t},values:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push(this[e]);return t},entries:function(){var t=[];for(var e in this)\"$\"===e[0]&&t.push({key:e.slice(1),value:this[e]});return t},size:function(){var t=0;for(var e in this)\"$\"===e[0]&&++t;return t},empty:function(){for(var t in this)if(\"$\"===t[0])return!1;return!0},each:function(t){for(var e in this)\"$\"===e[0]&&t(this[e],e.slice(1),this)}};var l=r.prototype;function c(t,e){var r=new s;if(t instanceof s)t.each((function(t){r.add(t)}));else if(t){var n=-1,i=t.length;if(null==e)for(;++n<i;)r.add(t[n]);else for(;++n<i;)r.add(e(t[n],n,t))}return r}s.prototype=c.prototype={constructor:s,has:l.has,add:function(t){return this[\"$\"+(t+=\"\")]=t,this},remove:l.remove,clear:l.clear,values:l.keys,size:l.size,empty:l.empty,each:l.each},t.nest=function(){var t,e,s,l=[],c=[];function u(n,i,a,o){if(i>=l.length)return null!=t&&n.sort(t),null!=e?e(n):n;for(var s,c,f,h=-1,p=n.length,d=l[i++],g=r(),m=a();++h<p;)(f=g.get(s=d(c=n[h])+\"\"))?f.push(c):g.set(s,[c]);return g.each((function(t,e){o(m,e,u(t,i,a,o))})),m}return s={object:function(t){return u(t,0,n,i)},map:function(t){return u(t,0,a,o)},entries:function(t){return function t(r,n){if(++n>l.length)return r;var i,a=c[n-1];return null!=e&&n>=l.length?i=r.entries():(i=[],r.each((function(e,r){i.push({key:r,values:t(e,n)})}))),null!=a?i.sort((function(t,e){return a(t.key,e.key)})):i}(u(t,0,a,o),0)},key:function(t){return l.push(t),s},sortKeys:function(t){return c[l.length-1]=t,s},sortValues:function(e){return t=e,s},rollup:function(t){return e=t,s}}},t.set=c,t.map=r,t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],158:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r){t.prototype=e.prototype=r,r.constructor=t}function r(t,e){var r=Object.create(t.prototype);for(var n in e)r[n]=e[n];return r}function n(){}var i=\"\\\\s*([+-]?\\\\d+)\\\\s*\",a=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)\\\\s*\",o=\"\\\\s*([+-]?\\\\d*\\\\.?\\\\d+(?:[eE][+-]?\\\\d+)?)%\\\\s*\",s=/^#([0-9a-f]{3,8})$/,l=new RegExp(\"^rgb\\\\(\"+[i,i,i]+\"\\\\)$\"),c=new RegExp(\"^rgb\\\\(\"+[o,o,o]+\"\\\\)$\"),u=new RegExp(\"^rgba\\\\(\"+[i,i,i,a]+\"\\\\)$\"),f=new RegExp(\"^rgba\\\\(\"+[o,o,o,a]+\"\\\\)$\"),h=new RegExp(\"^hsl\\\\(\"+[a,o,o]+\"\\\\)$\"),p=new RegExp(\"^hsla\\\\(\"+[a,o,o,a]+\"\\\\)$\"),d={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};function g(){return this.rgb().formatHex()}function m(){return this.rgb().formatRgb()}function v(t){var e,r;return t=(t+\"\").trim().toLowerCase(),(e=s.exec(t))?(r=e[1].length,e=parseInt(e[1],16),6===r?y(e):3===r?new w(e>>8&15|e>>4&240,e>>4&15|240&e,(15&e)<<4|15&e,1):8===r?x(e>>24&255,e>>16&255,e>>8&255,(255&e)/255):4===r?x(e>>12&15|e>>8&240,e>>8&15|e>>4&240,e>>4&15|240&e,((15&e)<<4|15&e)/255):null):(e=l.exec(t))?new w(e[1],e[2],e[3],1):(e=c.exec(t))?new w(255*e[1]/100,255*e[2]/100,255*e[3]/100,1):(e=u.exec(t))?x(e[1],e[2],e[3],e[4]):(e=f.exec(t))?x(255*e[1]/100,255*e[2]/100,255*e[3]/100,e[4]):(e=h.exec(t))?A(e[1],e[2]/100,e[3]/100,1):(e=p.exec(t))?A(e[1],e[2]/100,e[3]/100,e[4]):d.hasOwnProperty(t)?y(d[t]):\"transparent\"===t?new w(NaN,NaN,NaN,0):null}function y(t){return new w(t>>16&255,t>>8&255,255&t,1)}function x(t,e,r,n){return n<=0&&(t=e=r=NaN),new w(t,e,r,n)}function b(t){return t instanceof n||(t=v(t)),t?new w((t=t.rgb()).r,t.g,t.b,t.opacity):new w}function _(t,e,r,n){return 1===arguments.length?b(t):new w(t,e,r,null==n?1:n)}function w(t,e,r,n){this.r=+t,this.g=+e,this.b=+r,this.opacity=+n}function T(){return\"#\"+M(this.r)+M(this.g)+M(this.b)}function k(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"rgb(\":\"rgba(\")+Math.max(0,Math.min(255,Math.round(this.r)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.g)||0))+\", \"+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===t?\")\":\", \"+t+\")\")}function M(t){return((t=Math.max(0,Math.min(255,Math.round(t)||0)))<16?\"0\":\"\")+t.toString(16)}function A(t,e,r,n){return n<=0?t=e=r=NaN:r<=0||r>=1?t=e=NaN:e<=0&&(t=NaN),new C(t,e,r,n)}function S(t){if(t instanceof C)return new C(t.h,t.s,t.l,t.opacity);if(t instanceof n||(t=v(t)),!t)return new C;if(t instanceof C)return t;var e=(t=t.rgb()).r/255,r=t.g/255,i=t.b/255,a=Math.min(e,r,i),o=Math.max(e,r,i),s=NaN,l=o-a,c=(o+a)/2;return l?(s=e===o?(r-i)/l+6*(r<i):r===o?(i-e)/l+2:(e-r)/l+4,l/=c<.5?o+a:2-o-a,s*=60):l=c>0&&c<1?0:s,new C(s,l,c,t.opacity)}function E(t,e,r,n){return 1===arguments.length?S(t):new C(t,e,r,null==n?1:n)}function C(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}function L(t,e,r){return 255*(t<60?e+(r-e)*t/60:t<180?r:t<240?e+(r-e)*(240-t)/60:e)}e(n,v,{copy:function(t){return Object.assign(new this.constructor,this,t)},displayable:function(){return this.rgb().displayable()},hex:g,formatHex:g,formatHsl:function(){return S(this).formatHsl()},formatRgb:m,toString:m}),e(w,_,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new w(this.r*t,this.g*t,this.b*t,this.opacity)},rgb:function(){return this},displayable:function(){return-.5<=this.r&&this.r<255.5&&-.5<=this.g&&this.g<255.5&&-.5<=this.b&&this.b<255.5&&0<=this.opacity&&this.opacity<=1},hex:T,formatHex:T,formatRgb:k,toString:k})),e(C,E,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new C(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new C(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=this.h%360+360*(this.h<0),e=isNaN(t)||isNaN(this.s)?0:this.s,r=this.l,n=r+(r<.5?r:1-r)*e,i=2*r-n;return new w(L(t>=240?t-240:t+120,i,n),L(t,i,n),L(t<120?t+240:t-120,i,n),this.opacity)},displayable:function(){return(0<=this.s&&this.s<=1||isNaN(this.s))&&0<=this.l&&this.l<=1&&0<=this.opacity&&this.opacity<=1},formatHsl:function(){var t=this.opacity;return(1===(t=isNaN(t)?1:Math.max(0,Math.min(1,t)))?\"hsl(\":\"hsla(\")+(this.h||0)+\", \"+100*(this.s||0)+\"%, \"+100*(this.l||0)+\"%\"+(1===t?\")\":\", \"+t+\")\")}}));var I=Math.PI/180,P=180/Math.PI,z=6/29,O=3*z*z;function D(t){if(t instanceof F)return new F(t.l,t.a,t.b,t.opacity);if(t instanceof H)return G(t);t instanceof w||(t=b(t));var e,r,n=U(t.r),i=U(t.g),a=U(t.b),o=B((.2225045*n+.7168786*i+.0606169*a)/1);return n===i&&i===a?e=r=o:(e=B((.4360747*n+.3850649*i+.1430804*a)/.96422),r=B((.0139322*n+.0971045*i+.7141733*a)/.82521)),new F(116*o-16,500*(e-o),200*(o-r),t.opacity)}function R(t,e,r,n){return 1===arguments.length?D(t):new F(t,e,r,null==n?1:n)}function F(t,e,r,n){this.l=+t,this.a=+e,this.b=+r,this.opacity=+n}function B(t){return t>.008856451679035631?Math.pow(t,1/3):t/O+4/29}function N(t){return t>z?t*t*t:O*(t-4/29)}function j(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function U(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function V(t){if(t instanceof H)return new H(t.h,t.c,t.l,t.opacity);if(t instanceof F||(t=D(t)),0===t.a&&0===t.b)return new H(NaN,0<t.l&&t.l<100?0:NaN,t.l,t.opacity);var e=Math.atan2(t.b,t.a)*P;return new H(e<0?e+360:e,Math.sqrt(t.a*t.a+t.b*t.b),t.l,t.opacity)}function q(t,e,r,n){return 1===arguments.length?V(t):new H(t,e,r,null==n?1:n)}function H(t,e,r,n){this.h=+t,this.c=+e,this.l=+r,this.opacity=+n}function G(t){if(isNaN(t.h))return new F(t.l,0,0,t.opacity);var e=t.h*I;return new F(t.l,Math.cos(e)*t.c,Math.sin(e)*t.c,t.opacity)}e(F,R,r(n,{brighter:function(t){return new F(this.l+18*(null==t?1:t),this.a,this.b,this.opacity)},darker:function(t){return new F(this.l-18*(null==t?1:t),this.a,this.b,this.opacity)},rgb:function(){var t=(this.l+16)/116,e=isNaN(this.a)?t:t+this.a/500,r=isNaN(this.b)?t:t-this.b/200;return new w(j(3.1338561*(e=.96422*N(e))-1.6168667*(t=1*N(t))-.4906146*(r=.82521*N(r))),j(-.9787684*e+1.9161415*t+.033454*r),j(.0719453*e-.2289914*t+1.4052427*r),this.opacity)}})),e(H,q,r(n,{brighter:function(t){return new H(this.h,this.c,this.l+18*(null==t?1:t),this.opacity)},darker:function(t){return new H(this.h,this.c,this.l-18*(null==t?1:t),this.opacity)},rgb:function(){return G(this).rgb()}}));var Y=-.14861,W=1.78277,X=-.29227,Z=-.90649,J=1.97294,K=J*Z,Q=J*W,$=W*X-Z*Y;function tt(t){if(t instanceof rt)return new rt(t.h,t.s,t.l,t.opacity);t instanceof w||(t=b(t));var e=t.r/255,r=t.g/255,n=t.b/255,i=($*n+K*e-Q*r)/($+K-Q),a=n-i,o=(J*(r-i)-X*a)/Z,s=Math.sqrt(o*o+a*a)/(J*i*(1-i)),l=s?Math.atan2(o,a)*P-120:NaN;return new rt(l<0?l+360:l,s,i,t.opacity)}function et(t,e,r,n){return 1===arguments.length?tt(t):new rt(t,e,r,null==n?1:n)}function rt(t,e,r,n){this.h=+t,this.s=+e,this.l=+r,this.opacity=+n}e(rt,et,r(n,{brighter:function(t){return t=null==t?1/.7:Math.pow(1/.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},darker:function(t){return t=null==t?.7:Math.pow(.7,t),new rt(this.h,this.s,this.l*t,this.opacity)},rgb:function(){var t=isNaN(this.h)?0:(this.h+120)*I,e=+this.l,r=isNaN(this.s)?0:this.s*e*(1-e),n=Math.cos(t),i=Math.sin(t);return new w(255*(e+r*(Y*n+W*i)),255*(e+r*(X*n+Z*i)),255*(e+r*(J*n)),this.opacity)}})),t.color=v,t.cubehelix=et,t.gray=function(t,e){return new F(t,0,0,null==e?1:e)},t.hcl=q,t.hsl=E,t.lab=R,t.lch=function(t,e,r,n){return 1===arguments.length?V(t):new H(r,e,t,null==n?1:n)},t.rgb=_,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],159:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e={value:function(){}};function r(){for(var t,e=0,r=arguments.length,i={};e<r;++e){if(!(t=arguments[e]+\"\")||t in i||/[\\s.]/.test(t))throw new Error(\"illegal type: \"+t);i[t]=[]}return new n(i)}function n(t){this._=t}function i(t,e){return t.trim().split(/^|\\s+/).map((function(t){var r=\"\",n=t.indexOf(\".\");if(n>=0&&(r=t.slice(n+1),t=t.slice(0,n)),t&&!e.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);return{type:t,name:r}}))}function a(t,e){for(var r,n=0,i=t.length;n<i;++n)if((r=t[n]).name===e)return r.value}function o(t,r,n){for(var i=0,a=t.length;i<a;++i)if(t[i].name===r){t[i]=e,t=t.slice(0,i).concat(t.slice(i+1));break}return null!=n&&t.push({name:r,value:n}),t}n.prototype=r.prototype={constructor:n,on:function(t,e){var r,n=this._,s=i(t+\"\",n),l=-1,c=s.length;if(!(arguments.length<2)){if(null!=e&&\"function\"!=typeof e)throw new Error(\"invalid callback: \"+e);for(;++l<c;)if(r=(t=s[l]).type)n[r]=o(n[r],t.name,e);else if(null==e)for(r in n)n[r]=o(n[r],t.name,null);return this}for(;++l<c;)if((r=(t=s[l]).type)&&(r=a(n[r],t.name)))return r},copy:function(){var t={},e=this._;for(var r in e)t[r]=e[r].slice();return new n(t)},call:function(t,e){if((r=arguments.length-2)>0)for(var r,n,i=new Array(r),a=0;a<r;++a)i[a]=arguments[a+2];if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(a=0,r=(n=this._[t]).length;a<r;++a)n[a].value.apply(e,i)},apply:function(t,e,r){if(!this._.hasOwnProperty(t))throw new Error(\"unknown type: \"+t);for(var n=this._[t],i=0,a=n.length;i<a;++i)n[i].value.apply(e,r)}},t.dispatch=r,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],160:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-quadtree\"),t(\"d3-collection\"),t(\"d3-dispatch\"),t(\"d3-timer\")):i(n.d3=n.d3||{},n.d3,n.d3,n.d3,n.d3)}(this,(function(t,e,r,n,i){\"use strict\";function a(t){return function(){return t}}function o(){return 1e-6*(Math.random()-.5)}function s(t){return t.x+t.vx}function l(t){return t.y+t.vy}function c(t){return t.index}function u(t,e){var r=t.get(e);if(!r)throw new Error(\"missing: \"+e);return r}function f(t){return t.x}function h(t){return t.y}var p=Math.PI*(3-Math.sqrt(5));t.forceCenter=function(t,e){var r;function n(){var n,i,a=r.length,o=0,s=0;for(n=0;n<a;++n)o+=(i=r[n]).x,s+=i.y;for(o=o/a-t,s=s/a-e,n=0;n<a;++n)(i=r[n]).x-=o,i.y-=s}return null==t&&(t=0),null==e&&(e=0),n.initialize=function(t){r=t},n.x=function(e){return arguments.length?(t=+e,n):t},n.y=function(t){return arguments.length?(e=+t,n):e},n},t.forceCollide=function(t){var r,n,i=1,c=1;function u(){for(var t,a,u,h,p,d,g,m=r.length,v=0;v<c;++v)for(a=e.quadtree(r,s,l).visitAfter(f),t=0;t<m;++t)u=r[t],d=n[u.index],g=d*d,h=u.x+u.vx,p=u.y+u.vy,a.visit(y);function y(t,e,r,n,a){var s=t.data,l=t.r,c=d+l;if(!s)return e>h+c||n<h-c||r>p+c||a<p-c;if(s.index>u.index){var f=h-s.x-s.vx,m=p-s.y-s.vy,v=f*f+m*m;v<c*c&&(0===f&&(v+=(f=o())*f),0===m&&(v+=(m=o())*m),v=(c-(v=Math.sqrt(v)))/v*i,u.vx+=(f*=v)*(c=(l*=l)/(g+l)),u.vy+=(m*=v)*c,s.vx-=f*(c=1-c),s.vy-=m*c)}}}function f(t){if(t.data)return t.r=n[t.data.index];for(var e=t.r=0;e<4;++e)t[e]&&t[e].r>t.r&&(t.r=t[e].r)}function h(){if(r){var e,i,a=r.length;for(n=new Array(a),e=0;e<a;++e)i=r[e],n[i.index]=+t(i,e,r)}}return\"function\"!=typeof t&&(t=a(null==t?1:+t)),u.initialize=function(t){r=t,h()},u.iterations=function(t){return arguments.length?(c=+t,u):c},u.strength=function(t){return arguments.length?(i=+t,u):i},u.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),h(),u):t},u},t.forceLink=function(t){var e,n,i,s,l,f=c,h=function(t){return 1/Math.min(s[t.source.index],s[t.target.index])},p=a(30),d=1;function g(r){for(var i=0,a=t.length;i<d;++i)for(var s,c,u,f,h,p,g,m=0;m<a;++m)c=(s=t[m]).source,f=(u=s.target).x+u.vx-c.x-c.vx||o(),h=u.y+u.vy-c.y-c.vy||o(),f*=p=((p=Math.sqrt(f*f+h*h))-n[m])/p*r*e[m],h*=p,u.vx-=f*(g=l[m]),u.vy-=h*g,c.vx+=f*(g=1-g),c.vy+=h*g}function m(){if(i){var a,o,c=i.length,h=t.length,p=r.map(i,f);for(a=0,s=new Array(c);a<h;++a)(o=t[a]).index=a,\"object\"!=typeof o.source&&(o.source=u(p,o.source)),\"object\"!=typeof o.target&&(o.target=u(p,o.target)),s[o.source.index]=(s[o.source.index]||0)+1,s[o.target.index]=(s[o.target.index]||0)+1;for(a=0,l=new Array(h);a<h;++a)o=t[a],l[a]=s[o.source.index]/(s[o.source.index]+s[o.target.index]);e=new Array(h),v(),n=new Array(h),y()}}function v(){if(i)for(var r=0,n=t.length;r<n;++r)e[r]=+h(t[r],r,t)}function y(){if(i)for(var e=0,r=t.length;e<r;++e)n[e]=+p(t[e],e,t)}return null==t&&(t=[]),g.initialize=function(t){i=t,m()},g.links=function(e){return arguments.length?(t=e,m(),g):t},g.id=function(t){return arguments.length?(f=t,g):f},g.iterations=function(t){return arguments.length?(d=+t,g):d},g.strength=function(t){return arguments.length?(h=\"function\"==typeof t?t:a(+t),v(),g):h},g.distance=function(t){return arguments.length?(p=\"function\"==typeof t?t:a(+t),y(),g):p},g},t.forceManyBody=function(){var t,r,n,i,s=a(-30),l=1,c=1/0,u=.81;function p(i){var a,o=t.length,s=e.quadtree(t,f,h).visitAfter(g);for(n=i,a=0;a<o;++a)r=t[a],s.visit(m)}function d(){if(t){var e,r,n=t.length;for(i=new Array(n),e=0;e<n;++e)r=t[e],i[r.index]=+s(r,e,t)}}function g(t){var e,r,n,a,o,s=0,l=0;if(t.length){for(n=a=o=0;o<4;++o)(e=t[o])&&(r=Math.abs(e.value))&&(s+=e.value,l+=r,n+=r*e.x,a+=r*e.y);t.x=n/l,t.y=a/l}else{(e=t).x=e.data.x,e.y=e.data.y;do{s+=i[e.data.index]}while(e=e.next)}t.value=s}function m(t,e,a,s){if(!t.value)return!0;var f=t.x-r.x,h=t.y-r.y,p=s-e,d=f*f+h*h;if(p*p/u<d)return d<c&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)),r.vx+=f*t.value*n/d,r.vy+=h*t.value*n/d),!0;if(!(t.length||d>=c)){(t.data!==r||t.next)&&(0===f&&(d+=(f=o())*f),0===h&&(d+=(h=o())*h),d<l&&(d=Math.sqrt(l*d)));do{t.data!==r&&(p=i[t.data.index]*n/d,r.vx+=f*p,r.vy+=h*p)}while(t=t.next)}}return p.initialize=function(e){t=e,d()},p.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),d(),p):s},p.distanceMin=function(t){return arguments.length?(l=t*t,p):Math.sqrt(l)},p.distanceMax=function(t){return arguments.length?(c=t*t,p):Math.sqrt(c)},p.theta=function(t){return arguments.length?(u=t*t,p):Math.sqrt(u)},p},t.forceRadial=function(t,e,r){var n,i,o,s=a(.1);function l(t){for(var a=0,s=n.length;a<s;++a){var l=n[a],c=l.x-e||1e-6,u=l.y-r||1e-6,f=Math.sqrt(c*c+u*u),h=(o[a]-f)*i[a]*t/f;l.vx+=c*h,l.vy+=u*h}}function c(){if(n){var e,r=n.length;for(i=new Array(r),o=new Array(r),e=0;e<r;++e)o[e]=+t(n[e],e,n),i[e]=isNaN(o[e])?0:+s(n[e],e,n)}}return\"function\"!=typeof t&&(t=a(+t)),null==e&&(e=0),null==r&&(r=0),l.initialize=function(t){n=t,c()},l.strength=function(t){return arguments.length?(s=\"function\"==typeof t?t:a(+t),c(),l):s},l.radius=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),c(),l):t},l.x=function(t){return arguments.length?(e=+t,l):e},l.y=function(t){return arguments.length?(r=+t,l):r},l},t.forceSimulation=function(t){var e,a=1,o=.001,s=1-Math.pow(o,1/300),l=0,c=.6,u=r.map(),f=i.timer(d),h=n.dispatch(\"tick\",\"end\");function d(){g(),h.call(\"tick\",e),a<o&&(f.stop(),h.call(\"end\",e))}function g(r){var n,i,o=t.length;void 0===r&&(r=1);for(var f=0;f<r;++f)for(a+=(l-a)*s,u.each((function(t){t(a)})),n=0;n<o;++n)null==(i=t[n]).fx?i.x+=i.vx*=c:(i.x=i.fx,i.vx=0),null==i.fy?i.y+=i.vy*=c:(i.y=i.fy,i.vy=0);return e}function m(){for(var e,r=0,n=t.length;r<n;++r){if((e=t[r]).index=r,null!=e.fx&&(e.x=e.fx),null!=e.fy&&(e.y=e.fy),isNaN(e.x)||isNaN(e.y)){var i=10*Math.sqrt(r),a=r*p;e.x=i*Math.cos(a),e.y=i*Math.sin(a)}(isNaN(e.vx)||isNaN(e.vy))&&(e.vx=e.vy=0)}}function v(e){return e.initialize&&e.initialize(t),e}return null==t&&(t=[]),m(),e={tick:g,restart:function(){return f.restart(d),e},stop:function(){return f.stop(),e},nodes:function(r){return arguments.length?(t=r,m(),u.each(v),e):t},alpha:function(t){return arguments.length?(a=+t,e):a},alphaMin:function(t){return arguments.length?(o=+t,e):o},alphaDecay:function(t){return arguments.length?(s=+t,e):+s},alphaTarget:function(t){return arguments.length?(l=+t,e):l},velocityDecay:function(t){return arguments.length?(c=1-t,e):1-c},force:function(t,r){return arguments.length>1?(null==r?u.remove(t):u.set(t,v(r)),e):u.get(t)},find:function(e,r,n){var i,a,o,s,l,c=0,u=t.length;for(null==n?n=1/0:n*=n,c=0;c<u;++c)(o=(i=e-(s=t[c]).x)*i+(a=r-s.y)*a)<n&&(l=s,n=o);return l},on:function(t,r){return arguments.length>1?(h.on(t,r),e):h.on(t)}}},t.forceX=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vx+=(n[a]-i.x)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},t.forceY=function(t){var e,r,n,i=a(.1);function o(t){for(var i,a=0,o=e.length;a<o;++a)(i=e[a]).vy+=(n[a]-i.y)*r[a]*t}function s(){if(e){var a,o=e.length;for(r=new Array(o),n=new Array(o),a=0;a<o;++a)r[a]=isNaN(n[a]=+t(e[a],a,e))?0:+i(e[a],a,e)}}return\"function\"!=typeof t&&(t=a(null==t?0:+t)),o.initialize=function(t){e=t,s()},o.strength=function(t){return arguments.length?(i=\"function\"==typeof t?t:a(+t),s(),o):i},o.y=function(e){return arguments.length?(t=\"function\"==typeof e?e:a(+e),s(),o):t},o},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-collection\":157,\"d3-dispatch\":159,\"d3-quadtree\":164,\"d3-timer\":168}],161:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e){return t.parent===e.parent?1:2}function r(t,e){return t+e.x}function n(t,e){return Math.max(t,e.y)}function i(t){var e=0,r=t.children,n=r&&r.length;if(n)for(;--n>=0;)e+=r[n].value;else e=1;t.value=e}function a(t,e){var r,n,i,a,s,u=new c(t),f=+t.value&&(u.value=t.value),h=[u];for(null==e&&(e=o);r=h.pop();)if(f&&(r.value=+r.data.value),(i=e(r.data))&&(s=i.length))for(r.children=new Array(s),a=s-1;a>=0;--a)h.push(n=r.children[a]=new c(i[a])),n.parent=r,n.depth=r.depth+1;return u.eachBefore(l)}function o(t){return t.children}function s(t){t.data=t.data.data}function l(t){var e=0;do{t.height=e}while((t=t.parent)&&t.height<++e)}function c(t){this.data=t,this.depth=this.height=0,this.parent=null}c.prototype=a.prototype={constructor:c,count:function(){return this.eachAfter(i)},each:function(t){var e,r,n,i,a=this,o=[a];do{for(e=o.reverse(),o=[];a=e.pop();)if(t(a),r=a.children)for(n=0,i=r.length;n<i;++n)o.push(r[n])}while(o.length);return this},eachAfter:function(t){for(var e,r,n,i=this,a=[i],o=[];i=a.pop();)if(o.push(i),e=i.children)for(r=0,n=e.length;r<n;++r)a.push(e[r]);for(;i=o.pop();)t(i);return this},eachBefore:function(t){for(var e,r,n=this,i=[n];n=i.pop();)if(t(n),e=n.children)for(r=e.length-1;r>=0;--r)i.push(e[r]);return this},sum:function(t){return this.eachAfter((function(e){for(var r=+t(e.data)||0,n=e.children,i=n&&n.length;--i>=0;)r+=n[i].value;e.value=r}))},sort:function(t){return this.eachBefore((function(e){e.children&&e.children.sort(t)}))},path:function(t){for(var e=this,r=function(t,e){if(t===e)return t;var r=t.ancestors(),n=e.ancestors(),i=null;t=r.pop(),e=n.pop();for(;t===e;)i=t,t=r.pop(),e=n.pop();return i}(e,t),n=[e];e!==r;)e=e.parent,n.push(e);for(var i=n.length;t!==r;)n.splice(i,0,t),t=t.parent;return n},ancestors:function(){for(var t=this,e=[t];t=t.parent;)e.push(t);return e},descendants:function(){var t=[];return this.each((function(e){t.push(e)})),t},leaves:function(){var t=[];return this.eachBefore((function(e){e.children||t.push(e)})),t},links:function(){var t=this,e=[];return t.each((function(r){r!==t&&e.push({source:r.parent,target:r})})),e},copy:function(){return a(this).eachBefore(s)}};var u=Array.prototype.slice;function f(t){for(var e,r,n=0,i=(t=function(t){for(var e,r,n=t.length;n;)r=Math.random()*n--|0,e=t[n],t[n]=t[r],t[r]=e;return t}(u.call(t))).length,a=[];n<i;)e=t[n],r&&d(r,e)?++n:(r=m(a=h(a,e)),n=0);return r}function h(t,e){var r,n;if(g(e,t))return[e];for(r=0;r<t.length;++r)if(p(e,t[r])&&g(v(t[r],e),t))return[t[r],e];for(r=0;r<t.length-1;++r)for(n=r+1;n<t.length;++n)if(p(v(t[r],t[n]),e)&&p(v(t[r],e),t[n])&&p(v(t[n],e),t[r])&&g(y(t[r],t[n],e),t))return[t[r],t[n],e];throw new Error}function p(t,e){var r=t.r-e.r,n=e.x-t.x,i=e.y-t.y;return r<0||r*r<n*n+i*i}function d(t,e){var r=t.r-e.r+1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function g(t,e){for(var r=0;r<e.length;++r)if(!d(t,e[r]))return!1;return!0}function m(t){switch(t.length){case 1:return{x:(e=t[0]).x,y:e.y,r:e.r};case 2:return v(t[0],t[1]);case 3:return y(t[0],t[1],t[2])}var e}function v(t,e){var r=t.x,n=t.y,i=t.r,a=e.x,o=e.y,s=e.r,l=a-r,c=o-n,u=s-i,f=Math.sqrt(l*l+c*c);return{x:(r+a+l/f*u)/2,y:(n+o+c/f*u)/2,r:(f+i+s)/2}}function y(t,e,r){var n=t.x,i=t.y,a=t.r,o=e.x,s=e.y,l=e.r,c=r.x,u=r.y,f=r.r,h=n-o,p=n-c,d=i-s,g=i-u,m=l-a,v=f-a,y=n*n+i*i-a*a,x=y-o*o-s*s+l*l,b=y-c*c-u*u+f*f,_=p*d-h*g,w=(d*b-g*x)/(2*_)-n,T=(g*m-d*v)/_,k=(p*x-h*b)/(2*_)-i,M=(h*v-p*m)/_,A=T*T+M*M-1,S=2*(a+w*T+k*M),E=w*w+k*k-a*a,C=-(A?(S+Math.sqrt(S*S-4*A*E))/(2*A):E/S);return{x:n+w+T*C,y:i+k+M*C,r:C}}function x(t,e,r){var n,i,a,o,s=t.x-e.x,l=t.y-e.y,c=s*s+l*l;c?(i=e.r+r.r,i*=i,o=t.r+r.r,i>(o*=o)?(n=(c+o-i)/(2*c),a=Math.sqrt(Math.max(0,o/c-n*n)),r.x=t.x-n*s-a*l,r.y=t.y-n*l+a*s):(n=(c+i-o)/(2*c),a=Math.sqrt(Math.max(0,i/c-n*n)),r.x=e.x+n*s-a*l,r.y=e.y+n*l+a*s)):(r.x=e.x+r.r,r.y=e.y)}function b(t,e){var r=t.r+e.r-1e-6,n=e.x-t.x,i=e.y-t.y;return r>0&&r*r>n*n+i*i}function _(t){var e=t._,r=t.next._,n=e.r+r.r,i=(e.x*r.r+r.x*e.r)/n,a=(e.y*r.r+r.y*e.r)/n;return i*i+a*a}function w(t){this._=t,this.next=null,this.previous=null}function T(t){if(!(i=t.length))return 0;var e,r,n,i,a,o,s,l,c,u,h;if((e=t[0]).x=0,e.y=0,!(i>1))return e.r;if(r=t[1],e.x=-r.r,r.x=e.r,r.y=0,!(i>2))return e.r+r.r;x(r,e,n=t[2]),e=new w(e),r=new w(r),n=new w(n),e.next=n.previous=r,r.next=e.previous=n,n.next=r.previous=e;t:for(s=3;s<i;++s){x(e._,r._,n=t[s]),n=new w(n),l=r.next,c=e.previous,u=r._.r,h=e._.r;do{if(u<=h){if(b(l._,n._)){r=l,e.next=r,r.previous=e,--s;continue t}u+=l._.r,l=l.next}else{if(b(c._,n._)){(e=c).next=r,r.previous=e,--s;continue t}h+=c._.r,c=c.previous}}while(l!==c.next);for(n.previous=e,n.next=r,e.next=r.previous=r=n,a=_(e);(n=n.next)!==r;)(o=_(n))<a&&(e=n,a=o);r=e.next}for(e=[r._],n=r;(n=n.next)!==r;)e.push(n._);for(n=f(e),s=0;s<i;++s)(e=t[s]).x-=n.x,e.y-=n.y;return n.r}function k(t){return null==t?null:M(t)}function M(t){if(\"function\"!=typeof t)throw new Error;return t}function A(){return 0}function S(t){return function(){return t}}function E(t){return Math.sqrt(t.value)}function C(t){return function(e){e.children||(e.r=Math.max(0,+t(e)||0))}}function L(t,e){return function(r){if(n=r.children){var n,i,a,o=n.length,s=t(r)*e||0;if(s)for(i=0;i<o;++i)n[i].r+=s;if(a=T(n),s)for(i=0;i<o;++i)n[i].r-=s;r.r=a+s}}}function I(t){return function(e){var r=e.parent;e.r*=t,r&&(e.x=r.x+t*e.x,e.y=r.y+t*e.y)}}function P(t){t.x0=Math.round(t.x0),t.y0=Math.round(t.y0),t.x1=Math.round(t.x1),t.y1=Math.round(t.y1)}function z(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(n-e)/t.value;++s<l;)(a=o[s]).y0=r,a.y1=i,a.x0=e,a.x1=e+=a.value*c}var O={depth:-1},D={};function R(t){return t.id}function F(t){return t.parentId}function B(t,e){return t.parent===e.parent?1:2}function N(t){var e=t.children;return e?e[0]:t.t}function j(t){var e=t.children;return e?e[e.length-1]:t.t}function U(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function V(t,e,r){return t.a.parent===e.parent?t.a:r}function q(t,e){this._=t,this.parent=null,this.children=null,this.A=null,this.a=this,this.z=0,this.m=0,this.c=0,this.s=0,this.t=null,this.i=e}function H(t,e,r,n,i){for(var a,o=t.children,s=-1,l=o.length,c=t.value&&(i-r)/t.value;++s<l;)(a=o[s]).x0=e,a.x1=n,a.y0=r,a.y1=r+=a.value*c}q.prototype=Object.create(c.prototype);var G=(1+Math.sqrt(5))/2;function Y(t,e,r,n,i,a){for(var o,s,l,c,u,f,h,p,d,g,m,v=[],y=e.children,x=0,b=0,_=y.length,w=e.value;x<_;){l=i-r,c=a-n;do{u=y[b++].value}while(!u&&b<_);for(f=h=u,m=u*u*(g=Math.max(c/l,l/c)/(w*t)),d=Math.max(h/m,m/f);b<_;++b){if(u+=s=y[b].value,s<f&&(f=s),s>h&&(h=s),m=u*u*g,(p=Math.max(h/m,m/f))>d){u-=s;break}d=p}v.push(o={value:u,dice:l<c,children:y.slice(x,b)}),o.dice?z(o,r,n,i,w?n+=c*u/w:a):H(o,r,n,w?r+=l*u/w:i,a),w-=u,x=b}return v}var W=function t(e){function r(t,r,n,i,a){Y(e,t,r,n,i,a)}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);var X=function t(e){function r(t,r,n,i,a){if((o=t._squarify)&&o.ratio===e)for(var o,s,l,c,u,f=-1,h=o.length,p=t.value;++f<h;){for(l=(s=o[f]).children,c=s.value=0,u=l.length;c<u;++c)s.value+=l[c].value;s.dice?z(s,r,n,i,n+=(a-n)*s.value/p):H(s,r,n,r+=(i-r)*s.value/p,a),p-=s.value}else t._squarify=o=Y(e,t,r,n,i,a),o.ratio=e}return r.ratio=function(e){return t((e=+e)>1?e:1)},r}(G);t.cluster=function(){var t=e,i=1,a=1,o=!1;function s(e){var s,l=0;e.eachAfter((function(e){var i=e.children;i?(e.x=function(t){return t.reduce(r,0)/t.length}(i),e.y=function(t){return 1+t.reduce(n,0)}(i)):(e.x=s?l+=t(e,s):0,e.y=0,s=e)}));var c=function(t){for(var e;e=t.children;)t=e[0];return t}(e),u=function(t){for(var e;e=t.children;)t=e[e.length-1];return t}(e),f=c.x-t(c,u)/2,h=u.x+t(u,c)/2;return e.eachAfter(o?function(t){t.x=(t.x-e.x)*i,t.y=(e.y-t.y)*a}:function(t){t.x=(t.x-f)/(h-f)*i,t.y=(1-(e.y?t.y/e.y:1))*a})}return s.separation=function(e){return arguments.length?(t=e,s):t},s.size=function(t){return arguments.length?(o=!1,i=+t[0],a=+t[1],s):o?null:[i,a]},s.nodeSize=function(t){return arguments.length?(o=!0,i=+t[0],a=+t[1],s):o?[i,a]:null},s},t.hierarchy=a,t.pack=function(){var t=null,e=1,r=1,n=A;function i(i){return i.x=e/2,i.y=r/2,t?i.eachBefore(C(t)).eachAfter(L(n,.5)).eachBefore(I(1)):i.eachBefore(C(E)).eachAfter(L(A,1)).eachAfter(L(n,i.r/Math.min(e,r))).eachBefore(I(Math.min(e,r)/(2*i.r))),i}return i.radius=function(e){return arguments.length?(t=k(e),i):t},i.size=function(t){return arguments.length?(e=+t[0],r=+t[1],i):[e,r]},i.padding=function(t){return arguments.length?(n=\"function\"==typeof t?t:S(+t),i):n},i},t.packEnclose=f,t.packSiblings=function(t){return T(t),t},t.partition=function(){var t=1,e=1,r=0,n=!1;function i(i){var a=i.height+1;return i.x0=i.y0=r,i.x1=t,i.y1=e/a,i.eachBefore(function(t,e){return function(n){n.children&&z(n,n.x0,t*(n.depth+1)/e,n.x1,t*(n.depth+2)/e);var i=n.x0,a=n.y0,o=n.x1-r,s=n.y1-r;o<i&&(i=o=(i+o)/2),s<a&&(a=s=(a+s)/2),n.x0=i,n.y0=a,n.x1=o,n.y1=s}}(e,a)),n&&i.eachBefore(P),i}return i.round=function(t){return arguments.length?(n=!!t,i):n},i.size=function(r){return arguments.length?(t=+r[0],e=+r[1],i):[t,e]},i.padding=function(t){return arguments.length?(r=+t,i):r},i},t.stratify=function(){var t=R,e=F;function r(r){var n,i,a,o,s,u,f,h=r.length,p=new Array(h),d={};for(i=0;i<h;++i)n=r[i],s=p[i]=new c(n),null!=(u=t(n,i,r))&&(u+=\"\")&&(d[f=\"$\"+(s.id=u)]=f in d?D:s);for(i=0;i<h;++i)if(s=p[i],null!=(u=e(r[i],i,r))&&(u+=\"\")){if(!(o=d[\"$\"+u]))throw new Error(\"missing: \"+u);if(o===D)throw new Error(\"ambiguous: \"+u);o.children?o.children.push(s):o.children=[s],s.parent=o}else{if(a)throw new Error(\"multiple roots\");a=s}if(!a)throw new Error(\"no root\");if(a.parent=O,a.eachBefore((function(t){t.depth=t.parent.depth+1,--h})).eachBefore(l),a.parent=null,h>0)throw new Error(\"cycle\");return a}return r.id=function(e){return arguments.length?(t=M(e),r):t},r.parentId=function(t){return arguments.length?(e=M(t),r):e},r},t.tree=function(){var t=B,e=1,r=1,n=null;function i(i){var l=function(t){for(var e,r,n,i,a,o=new q(t,0),s=[o];e=s.pop();)if(n=e._.children)for(e.children=new Array(a=n.length),i=a-1;i>=0;--i)s.push(r=e.children[i]=new q(n[i],i)),r.parent=e;return(o.parent=new q(null,0)).children=[o],o}(i);if(l.eachAfter(a),l.parent.m=-l.z,l.eachBefore(o),n)i.eachBefore(s);else{var c=i,u=i,f=i;i.eachBefore((function(t){t.x<c.x&&(c=t),t.x>u.x&&(u=t),t.depth>f.depth&&(f=t)}));var h=c===u?1:t(c,u)/2,p=h-c.x,d=e/(u.x+h+p),g=r/(f.depth||1);i.eachBefore((function(t){t.x=(t.x+p)*d,t.y=t.depth*g}))}return i}function a(e){var r=e.children,n=e.parent.children,i=e.i?n[e.i-1]:null;if(r){!function(t){for(var e,r=0,n=0,i=t.children,a=i.length;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(e);var a=(r[0].z+r[r.length-1].z)/2;i?(e.z=i.z+t(e._,i._),e.m=e.z-a):e.z=a}else i&&(e.z=i.z+t(e._,i._));e.parent.A=function(e,r,n){if(r){for(var i,a=e,o=e,s=r,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=j(s),a=N(a),s&&a;)l=N(l),(o=j(o)).a=e,(i=s.z+f-a.z-c+t(s._,a._))>0&&(U(V(s,e,n),e,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!j(o)&&(o.t=s,o.m+=f-u),a&&!N(l)&&(l.t=a,l.m+=c-h,n=e)}return n}(e,i,e.parent.A||n[0])}function o(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function s(t){t.x*=e,t.y=t.depth*r}return i.separation=function(e){return arguments.length?(t=e,i):t},i.size=function(t){return arguments.length?(n=!1,e=+t[0],r=+t[1],i):n?null:[e,r]},i.nodeSize=function(t){return arguments.length?(n=!0,e=+t[0],r=+t[1],i):n?[e,r]:null},i},t.treemap=function(){var t=W,e=!1,r=1,n=1,i=[0],a=A,o=A,s=A,l=A,c=A;function u(t){return t.x0=t.y0=0,t.x1=r,t.y1=n,t.eachBefore(f),i=[0],e&&t.eachBefore(P),t}function f(e){var r=i[e.depth],n=e.x0+r,u=e.y0+r,f=e.x1-r,h=e.y1-r;f<n&&(n=f=(n+f)/2),h<u&&(u=h=(u+h)/2),e.x0=n,e.y0=u,e.x1=f,e.y1=h,e.children&&(r=i[e.depth+1]=a(e)/2,n+=c(e)-r,u+=o(e)-r,(f-=s(e)-r)<n&&(n=f=(n+f)/2),(h-=l(e)-r)<u&&(u=h=(u+h)/2),t(e,n,u,f,h))}return u.round=function(t){return arguments.length?(e=!!t,u):e},u.size=function(t){return arguments.length?(r=+t[0],n=+t[1],u):[r,n]},u.tile=function(e){return arguments.length?(t=M(e),u):t},u.padding=function(t){return arguments.length?u.paddingInner(t).paddingOuter(t):u.paddingInner()},u.paddingInner=function(t){return arguments.length?(a=\"function\"==typeof t?t:S(+t),u):a},u.paddingOuter=function(t){return arguments.length?u.paddingTop(t).paddingRight(t).paddingBottom(t).paddingLeft(t):u.paddingTop()},u.paddingTop=function(t){return arguments.length?(o=\"function\"==typeof t?t:S(+t),u):o},u.paddingRight=function(t){return arguments.length?(s=\"function\"==typeof t?t:S(+t),u):s},u.paddingBottom=function(t){return arguments.length?(l=\"function\"==typeof t?t:S(+t),u):l},u.paddingLeft=function(t){return arguments.length?(c=\"function\"==typeof t?t:S(+t),u):c},u},t.treemapBinary=function(t,e,r,n,i){var a,o,s=t.children,l=s.length,c=new Array(l+1);for(c[0]=o=a=0;a<l;++a)c[a+1]=o+=s[a].value;!function t(e,r,n,i,a,o,l){if(e>=r-1){var u=s[e];return u.x0=i,u.y0=a,u.x1=o,void(u.y1=l)}var f=c[e],h=n/2+f,p=e+1,d=r-1;for(;p<d;){var g=p+d>>>1;c[g]<h?p=g+1:d=g}h-c[p-1]<c[p]-h&&e+1<p&&--p;var m=c[p]-f,v=n-m;if(o-i>l-a){var y=(i*v+o*m)/n;t(e,p,m,i,a,y,l),t(p,r,v,y,a,o,l)}else{var x=(a*v+l*m)/n;t(e,p,m,i,a,o,x),t(p,r,v,i,x,o,l)}}(0,l,t.value,e,r,n,i)},t.treemapDice=z,t.treemapResquarify=X,t.treemapSlice=H,t.treemapSliceDice=function(t,e,r,n,i){(1&t.depth?H:z)(t,e,r,n,i)},t.treemapSquarify=W,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],162:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-color\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t,e,r,n,i){var a=t*t,o=a*t;return((1-3*t+3*a-o)*e+(4-6*a+3*o)*r+(1+3*t+3*a-3*o)*n+o*i)/6}function n(t){var e=t.length-1;return function(n){var i=n<=0?n=0:n>=1?(n=1,e-1):Math.floor(n*e),a=t[i],o=t[i+1],s=i>0?t[i-1]:2*a-o,l=i<e-1?t[i+2]:2*o-a;return r((n-i/e)*e,s,a,o,l)}}function i(t){var e=t.length;return function(n){var i=Math.floor(((n%=1)<0?++n:n)*e),a=t[(i+e-1)%e],o=t[i%e],s=t[(i+1)%e],l=t[(i+2)%e];return r((n-i/e)*e,a,o,s,l)}}function a(t){return function(){return t}}function o(t,e){return function(r){return t+r*e}}function s(t,e){var r=e-t;return r?o(t,r>180||r<-180?r-360*Math.round(r/360):r):a(isNaN(t)?e:t)}function l(t){return 1==(t=+t)?c:function(e,r){return r-e?function(t,e,r){return t=Math.pow(t,r),e=Math.pow(e,r)-t,r=1/r,function(n){return Math.pow(t+n*e,r)}}(e,r,t):a(isNaN(e)?r:e)}}function c(t,e){var r=e-t;return r?o(t,r):a(isNaN(t)?e:t)}var u=function t(r){var n=l(r);function i(t,r){var i=n((t=e.rgb(t)).r,(r=e.rgb(r)).r),a=n(t.g,r.g),o=n(t.b,r.b),s=c(t.opacity,r.opacity);return function(e){return t.r=i(e),t.g=a(e),t.b=o(e),t.opacity=s(e),t+\"\"}}return i.gamma=t,i}(1);function f(t){return function(r){var n,i,a=r.length,o=new Array(a),s=new Array(a),l=new Array(a);for(n=0;n<a;++n)i=e.rgb(r[n]),o[n]=i.r||0,s[n]=i.g||0,l[n]=i.b||0;return o=t(o),s=t(s),l=t(l),i.opacity=1,function(t){return i.r=o(t),i.g=s(t),i.b=l(t),i+\"\"}}}var h=f(n),p=f(i);function d(t,e){e||(e=[]);var r,n=t?Math.min(e.length,t.length):0,i=e.slice();return function(a){for(r=0;r<n;++r)i[r]=t[r]*(1-a)+e[r]*a;return i}}function g(t){return ArrayBuffer.isView(t)&&!(t instanceof DataView)}function m(t,e){var r,n=e?e.length:0,i=t?Math.min(n,t.length):0,a=new Array(i),o=new Array(n);for(r=0;r<i;++r)a[r]=T(t[r],e[r]);for(;r<n;++r)o[r]=e[r];return function(t){for(r=0;r<i;++r)o[r]=a[r](t);return o}}function v(t,e){var r=new Date;return t=+t,e=+e,function(n){return r.setTime(t*(1-n)+e*n),r}}function y(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function x(t,e){var r,n={},i={};for(r in null!==t&&\"object\"==typeof t||(t={}),null!==e&&\"object\"==typeof e||(e={}),e)r in t?n[r]=T(t[r],e[r]):i[r]=e[r];return function(t){for(r in n)i[r]=n[r](t);return i}}var b=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,_=new RegExp(b.source,\"g\");function w(t,e){var r,n,i,a=b.lastIndex=_.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=b.exec(t))&&(n=_.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:y(r,n)})),a=_.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?function(t){return function(e){return t(e)+\"\"}}(l[0].x):function(t){return function(){return t}}(e):(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}function T(t,r){var n,i=typeof r;return null==r||\"boolean\"===i?a(r):(\"number\"===i?y:\"string\"===i?(n=e.color(r))?(r=n,u):w:r instanceof e.color?u:r instanceof Date?v:g(r)?d:Array.isArray(r)?m:\"function\"!=typeof r.valueOf&&\"function\"!=typeof r.toString||isNaN(r)?x:y)(t,r)}var k,M,A,S,E=180/Math.PI,C={translateX:0,translateY:0,rotate:0,skewX:0,scaleX:1,scaleY:1};function L(t,e,r,n,i,a){var o,s,l;return(o=Math.sqrt(t*t+e*e))&&(t/=o,e/=o),(l=t*r+e*n)&&(r-=t*l,n-=e*l),(s=Math.sqrt(r*r+n*n))&&(r/=s,n/=s,l/=s),t*n<e*r&&(t=-t,e=-e,l=-l,o=-o),{translateX:i,translateY:a,rotate:Math.atan2(e,t)*E,skewX:Math.atan(l)*E,scaleX:o,scaleY:s}}function I(t,e,r,n){function i(t){return t.length?t.pop()+\" \":\"\"}return function(a,o){var s=[],l=[];return a=t(a),o=t(o),function(t,n,i,a,o,s){if(t!==i||n!==a){var l=o.push(\"translate(\",null,e,null,r);s.push({i:l-4,x:y(t,i)},{i:l-2,x:y(n,a)})}else(i||a)&&o.push(\"translate(\"+i+e+a+r)}(a.translateX,a.translateY,o.translateX,o.translateY,s,l),function(t,e,r,a){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),a.push({i:r.push(i(r)+\"rotate(\",null,n)-2,x:y(t,e)})):e&&r.push(i(r)+\"rotate(\"+e+n)}(a.rotate,o.rotate,s,l),function(t,e,r,a){t!==e?a.push({i:r.push(i(r)+\"skewX(\",null,n)-2,x:y(t,e)}):e&&r.push(i(r)+\"skewX(\"+e+n)}(a.skewX,o.skewX,s,l),function(t,e,r,n,a,o){if(t!==r||e!==n){var s=a.push(i(a)+\"scale(\",null,\",\",null,\")\");o.push({i:s-4,x:y(t,r)},{i:s-2,x:y(e,n)})}else 1===r&&1===n||a.push(i(a)+\"scale(\"+r+\",\"+n+\")\")}(a.scaleX,a.scaleY,o.scaleX,o.scaleY,s,l),a=o=null,function(t){for(var e,r=-1,n=l.length;++r<n;)s[(e=l[r]).i]=e.x(t);return s.join(\"\")}}}var P=I((function(t){return\"none\"===t?C:(k||(k=document.createElement(\"DIV\"),M=document.documentElement,A=document.defaultView),k.style.transform=t,t=A.getComputedStyle(M.appendChild(k),null).getPropertyValue(\"transform\"),M.removeChild(k),L(+(t=t.slice(7,-1).split(\",\"))[0],+t[1],+t[2],+t[3],+t[4],+t[5]))}),\"px, \",\"px)\",\"deg)\"),z=I((function(t){return null==t?C:(S||(S=document.createElementNS(\"http://www.w3.org/2000/svg\",\"g\")),S.setAttribute(\"transform\",t),(t=S.transform.baseVal.consolidate())?L((t=t.matrix).a,t.b,t.c,t.d,t.e,t.f):C)}),\", \",\")\",\")\"),O=Math.SQRT2;function D(t){return((t=Math.exp(t))+1/t)/2}function R(t){return function(r,n){var i=t((r=e.hsl(r)).h,(n=e.hsl(n)).h),a=c(r.s,n.s),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.s=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var F=R(s),B=R(c);function N(t){return function(r,n){var i=t((r=e.hcl(r)).h,(n=e.hcl(n)).h),a=c(r.c,n.c),o=c(r.l,n.l),s=c(r.opacity,n.opacity);return function(t){return r.h=i(t),r.c=a(t),r.l=o(t),r.opacity=s(t),r+\"\"}}}var j=N(s),U=N(c);function V(t){return function r(n){function i(r,i){var a=t((r=e.cubehelix(r)).h,(i=e.cubehelix(i)).h),o=c(r.s,i.s),s=c(r.l,i.l),l=c(r.opacity,i.opacity);return function(t){return r.h=a(t),r.s=o(t),r.l=s(Math.pow(t,n)),r.opacity=l(t),r+\"\"}}return n=+n,i.gamma=r,i}(1)}var q=V(s),H=V(c);t.interpolate=T,t.interpolateArray=function(t,e){return(g(e)?d:m)(t,e)},t.interpolateBasis=n,t.interpolateBasisClosed=i,t.interpolateCubehelix=q,t.interpolateCubehelixLong=H,t.interpolateDate=v,t.interpolateDiscrete=function(t){var e=t.length;return function(r){return t[Math.max(0,Math.min(e-1,Math.floor(r*e)))]}},t.interpolateHcl=j,t.interpolateHclLong=U,t.interpolateHsl=F,t.interpolateHslLong=B,t.interpolateHue=function(t,e){var r=s(+t,+e);return function(t){var e=r(t);return e-360*Math.floor(e/360)}},t.interpolateLab=function(t,r){var n=c((t=e.lab(t)).l,(r=e.lab(r)).l),i=c(t.a,r.a),a=c(t.b,r.b),o=c(t.opacity,r.opacity);return function(e){return t.l=n(e),t.a=i(e),t.b=a(e),t.opacity=o(e),t+\"\"}},t.interpolateNumber=y,t.interpolateNumberArray=d,t.interpolateObject=x,t.interpolateRgb=u,t.interpolateRgbBasis=h,t.interpolateRgbBasisClosed=p,t.interpolateRound=function(t,e){return t=+t,e=+e,function(r){return Math.round(t*(1-r)+e*r)}},t.interpolateString=w,t.interpolateTransformCss=P,t.interpolateTransformSvg=z,t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<1e-12)n=Math.log(c/o)/O,r=function(t){return[i+t*u,a+t*f,o*Math.exp(O*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/O,r=function(t){var e,r=t*n,s=D(m),l=o/(2*p)*(s*(e=O*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/D(O*r+m)]}}return r.duration=1e3*n,r},t.piecewise=function(t,e){for(var r=0,n=e.length-1,i=e[0],a=new Array(n<0?0:n);r<n;)a[r]=t(i,i=e[++r]);return function(t){var e=Math.max(0,Math.min(n-1,Math.floor(t*=n)));return a[e](t-e)}},t.quantize=function(t,e){for(var r=new Array(e),n=0;n<e;++n)r[n]=t(n/(e-1));return r},Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-color\":158}],163:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=Math.PI,r=2*e,n=r-1e-6;function i(){this._x0=this._y0=this._x1=this._y1=null,this._=\"\"}function a(){return new i}i.prototype=a.prototype={constructor:i,moveTo:function(t,e){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)},closePath:function(){null!==this._x1&&(this._x1=this._x0,this._y1=this._y0,this._+=\"Z\")},lineTo:function(t,e){this._+=\"L\"+(this._x1=+t)+\",\"+(this._y1=+e)},quadraticCurveTo:function(t,e,r,n){this._+=\"Q\"+ +t+\",\"+ +e+\",\"+(this._x1=+r)+\",\"+(this._y1=+n)},bezierCurveTo:function(t,e,r,n,i,a){this._+=\"C\"+ +t+\",\"+ +e+\",\"+ +r+\",\"+ +n+\",\"+(this._x1=+i)+\",\"+(this._y1=+a)},arcTo:function(t,r,n,i,a){t=+t,r=+r,n=+n,i=+i,a=+a;var o=this._x1,s=this._y1,l=n-t,c=i-r,u=o-t,f=s-r,h=u*u+f*f;if(a<0)throw new Error(\"negative radius: \"+a);if(null===this._x1)this._+=\"M\"+(this._x1=t)+\",\"+(this._y1=r);else if(h>1e-6)if(Math.abs(f*l-c*u)>1e-6&&a){var p=n-o,d=i-s,g=l*l+c*c,m=p*p+d*d,v=Math.sqrt(g),y=Math.sqrt(h),x=a*Math.tan((e-Math.acos((g+h-m)/(2*v*y)))/2),b=x/y,_=x/v;Math.abs(b-1)>1e-6&&(this._+=\"L\"+(t+b*u)+\",\"+(r+b*f)),this._+=\"A\"+a+\",\"+a+\",0,0,\"+ +(f*p>u*d)+\",\"+(this._x1=t+_*l)+\",\"+(this._y1=r+_*c)}else this._+=\"L\"+(this._x1=t)+\",\"+(this._y1=r);else;},arc:function(t,i,a,o,s,l){t=+t,i=+i,l=!!l;var c=(a=+a)*Math.cos(o),u=a*Math.sin(o),f=t+c,h=i+u,p=1^l,d=l?o-s:s-o;if(a<0)throw new Error(\"negative radius: \"+a);null===this._x1?this._+=\"M\"+f+\",\"+h:(Math.abs(this._x1-f)>1e-6||Math.abs(this._y1-h)>1e-6)&&(this._+=\"L\"+f+\",\"+h),a&&(d<0&&(d=d%r+r),d>n?this._+=\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(t-c)+\",\"+(i-u)+\"A\"+a+\",\"+a+\",0,1,\"+p+\",\"+(this._x1=f)+\",\"+(this._y1=h):d>1e-6&&(this._+=\"A\"+a+\",\"+a+\",0,\"+ +(d>=e)+\",\"+p+\",\"+(this._x1=t+a*Math.cos(s))+\",\"+(this._y1=i+a*Math.sin(s))))},rect:function(t,e,r,n){this._+=\"M\"+(this._x0=this._x1=+t)+\",\"+(this._y0=this._y1=+e)+\"h\"+ +r+\"v\"+ +n+\"h\"+-r+\"Z\"},toString:function(){return this._}},t.path=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],164:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";function e(t,e,r,n){if(isNaN(e)||isNaN(r))return t;var i,a,o,s,l,c,u,f,h,p=t._root,d={data:n},g=t._x0,m=t._y0,v=t._x1,y=t._y1;if(!p)return t._root=d,t;for(;p.length;)if((c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o,i=p,!(p=p[f=u<<1|c]))return i[f]=d,t;if(s=+t._x.call(null,p.data),l=+t._y.call(null,p.data),e===s&&r===l)return d.next=p,i?i[f]=d:t._root=d,t;do{i=i?i[f]=new Array(4):t._root=new Array(4),(c=e>=(a=(g+v)/2))?g=a:v=a,(u=r>=(o=(m+y)/2))?m=o:y=o}while((f=u<<1|c)==(h=(l>=o)<<1|s>=a));return i[h]=p,i[f]=d,t}function r(t,e,r,n,i){this.node=t,this.x0=e,this.y0=r,this.x1=n,this.y1=i}function n(t){return t[0]}function i(t){return t[1]}function a(t,e,r){var a=new o(null==e?n:e,null==r?i:r,NaN,NaN,NaN,NaN);return null==t?a:a.addAll(t)}function o(t,e,r,n,i,a){this._x=t,this._y=e,this._x0=r,this._y0=n,this._x1=i,this._y1=a,this._root=void 0}function s(t){for(var e={data:t.data},r=e;t=t.next;)r=r.next={data:t.data};return e}var l=a.prototype=o.prototype;l.copy=function(){var t,e,r=new o(this._x,this._y,this._x0,this._y0,this._x1,this._y1),n=this._root;if(!n)return r;if(!n.length)return r._root=s(n),r;for(t=[{source:n,target:r._root=new Array(4)}];n=t.pop();)for(var i=0;i<4;++i)(e=n.source[i])&&(e.length?t.push({source:e,target:n.target[i]=new Array(4)}):n.target[i]=s(e));return r},l.add=function(t){var r=+this._x.call(null,t),n=+this._y.call(null,t);return e(this.cover(r,n),r,n,t)},l.addAll=function(t){var r,n,i,a,o=t.length,s=new Array(o),l=new Array(o),c=1/0,u=1/0,f=-1/0,h=-1/0;for(n=0;n<o;++n)isNaN(i=+this._x.call(null,r=t[n]))||isNaN(a=+this._y.call(null,r))||(s[n]=i,l[n]=a,i<c&&(c=i),i>f&&(f=i),a<u&&(u=a),a>h&&(h=a));if(c>f||u>h)return this;for(this.cover(c,u).cover(f,h),n=0;n<o;++n)e(this,s[n],l[n],t[n]);return this},l.cover=function(t,e){if(isNaN(t=+t)||isNaN(e=+e))return this;var r=this._x0,n=this._y0,i=this._x1,a=this._y1;if(isNaN(r))i=(r=Math.floor(t))+1,a=(n=Math.floor(e))+1;else{for(var o,s,l=i-r,c=this._root;r>t||t>=i||n>e||e>=a;)switch(s=(e<n)<<1|t<r,(o=new Array(4))[s]=c,c=o,l*=2,s){case 0:i=r+l,a=n+l;break;case 1:r=i-l,a=n+l;break;case 2:i=r+l,n=a-l;break;case 3:r=i-l,n=a-l}this._root&&this._root.length&&(this._root=c)}return this._x0=r,this._y0=n,this._x1=i,this._y1=a,this},l.data=function(){var t=[];return this.visit((function(e){if(!e.length)do{t.push(e.data)}while(e=e.next)})),t},l.extent=function(t){return arguments.length?this.cover(+t[0][0],+t[0][1]).cover(+t[1][0],+t[1][1]):isNaN(this._x0)?void 0:[[this._x0,this._y0],[this._x1,this._y1]]},l.find=function(t,e,n){var i,a,o,s,l,c,u,f=this._x0,h=this._y0,p=this._x1,d=this._y1,g=[],m=this._root;for(m&&g.push(new r(m,f,h,p,d)),null==n?n=1/0:(f=t-n,h=e-n,p=t+n,d=e+n,n*=n);c=g.pop();)if(!(!(m=c.node)||(a=c.x0)>p||(o=c.y0)>d||(s=c.x1)<f||(l=c.y1)<h))if(m.length){var v=(a+s)/2,y=(o+l)/2;g.push(new r(m[3],v,y,s,l),new r(m[2],a,y,v,l),new r(m[1],v,o,s,y),new r(m[0],a,o,v,y)),(u=(e>=y)<<1|t>=v)&&(c=g[g.length-1],g[g.length-1]=g[g.length-1-u],g[g.length-1-u]=c)}else{var x=t-+this._x.call(null,m.data),b=e-+this._y.call(null,m.data),_=x*x+b*b;if(_<n){var w=Math.sqrt(n=_);f=t-w,h=e-w,p=t+w,d=e+w,i=m.data}}return i},l.remove=function(t){if(isNaN(a=+this._x.call(null,t))||isNaN(o=+this._y.call(null,t)))return this;var e,r,n,i,a,o,s,l,c,u,f,h,p=this._root,d=this._x0,g=this._y0,m=this._x1,v=this._y1;if(!p)return this;if(p.length)for(;;){if((c=a>=(s=(d+m)/2))?d=s:m=s,(u=o>=(l=(g+v)/2))?g=l:v=l,e=p,!(p=p[f=u<<1|c]))return this;if(!p.length)break;(e[f+1&3]||e[f+2&3]||e[f+3&3])&&(r=e,h=f)}for(;p.data!==t;)if(n=p,!(p=p.next))return this;return(i=p.next)&&delete p.next,n?(i?n.next=i:delete n.next,this):e?(i?e[f]=i:delete e[f],(p=e[0]||e[1]||e[2]||e[3])&&p===(e[3]||e[2]||e[1]||e[0])&&!p.length&&(r?r[h]=p:this._root=p),this):(this._root=i,this)},l.removeAll=function(t){for(var e=0,r=t.length;e<r;++e)this.remove(t[e]);return this},l.root=function(){return this._root},l.size=function(){var t=0;return this.visit((function(e){if(!e.length)do{++t}while(e=e.next)})),t},l.visit=function(t){var e,n,i,a,o,s,l=[],c=this._root;for(c&&l.push(new r(c,this._x0,this._y0,this._x1,this._y1));e=l.pop();)if(!t(c=e.node,i=e.x0,a=e.y0,o=e.x1,s=e.y1)&&c.length){var u=(i+o)/2,f=(a+s)/2;(n=c[3])&&l.push(new r(n,u,f,o,s)),(n=c[2])&&l.push(new r(n,i,f,u,s)),(n=c[1])&&l.push(new r(n,u,a,o,f)),(n=c[0])&&l.push(new r(n,i,a,u,f))}return this},l.visitAfter=function(t){var e,n=[],i=[];for(this._root&&n.push(new r(this._root,this._x0,this._y0,this._x1,this._y1));e=n.pop();){var a=e.node;if(a.length){var o,s=e.x0,l=e.y0,c=e.x1,u=e.y1,f=(s+c)/2,h=(l+u)/2;(o=a[0])&&n.push(new r(o,s,l,f,h)),(o=a[1])&&n.push(new r(o,f,l,c,h)),(o=a[2])&&n.push(new r(o,s,h,f,u)),(o=a[3])&&n.push(new r(o,f,h,c,u))}i.push(e)}for(;e=i.pop();)t(e.node,e.x0,e.y0,e.x1,e.y1);return this},l.x=function(t){return arguments.length?(this._x=t,this):this._x},l.y=function(t){return arguments.length?(this._y=t,this):this._y},t.quadtree=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],165:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-path\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){return function(){return t}}var n=Math.abs,i=Math.atan2,a=Math.cos,o=Math.max,s=Math.min,l=Math.sin,c=Math.sqrt,u=Math.PI,f=u/2,h=2*u;function p(t){return t>1?0:t<-1?u:Math.acos(t)}function d(t){return t>=1?f:t<=-1?-f:Math.asin(t)}function g(t){return t.innerRadius}function m(t){return t.outerRadius}function v(t){return t.startAngle}function y(t){return t.endAngle}function x(t){return t&&t.padAngle}function b(t,e,r,n,i,a,o,s){var l=r-t,c=n-e,u=o-i,f=s-a,h=f*l-u*c;if(!(h*h<1e-12))return[t+(h=(u*(e-a)-f*(t-i))/h)*l,e+h*c]}function _(t,e,r,n,i,a,s){var l=t-r,u=e-n,f=(s?a:-a)/c(l*l+u*u),h=f*u,p=-f*l,d=t+h,g=e+p,m=r+h,v=n+p,y=(d+m)/2,x=(g+v)/2,b=m-d,_=v-g,w=b*b+_*_,T=i-a,k=d*v-m*g,M=(_<0?-1:1)*c(o(0,T*T*w-k*k)),A=(k*_-b*M)/w,S=(-k*b-_*M)/w,E=(k*_+b*M)/w,C=(-k*b+_*M)/w,L=A-y,I=S-x,P=E-y,z=C-x;return L*L+I*I>P*P+z*z&&(A=E,S=C),{cx:A,cy:S,x01:-h,y01:-p,x11:A*(i/T-1),y11:S*(i/T-1)}}function w(t){this._context=t}function T(t){return new w(t)}function k(t){return t[0]}function M(t){return t[1]}function A(){var t=k,n=M,i=r(!0),a=null,o=T,s=null;function l(r){var l,c,u,f=r.length,h=!1;for(null==a&&(s=o(u=e.path())),l=0;l<=f;++l)!(l<f&&i(c=r[l],l,r))===h&&((h=!h)?s.lineStart():s.lineEnd()),h&&s.point(+t(c,l,r),+n(c,l,r));if(u)return s=null,u+\"\"||null}return l.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),l):t},l.y=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),l):n},l.defined=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(!!t),l):i},l.curve=function(t){return arguments.length?(o=t,null!=a&&(s=o(a)),l):o},l.context=function(t){return arguments.length?(null==t?a=s=null:s=o(a=t),l):a},l}function S(){var t=k,n=null,i=r(0),a=M,o=r(!0),s=null,l=T,c=null;function u(r){var u,f,h,p,d,g=r.length,m=!1,v=new Array(g),y=new Array(g);for(null==s&&(c=l(d=e.path())),u=0;u<=g;++u){if(!(u<g&&o(p=r[u],u,r))===m)if(m=!m)f=u,c.areaStart(),c.lineStart();else{for(c.lineEnd(),c.lineStart(),h=u-1;h>=f;--h)c.point(v[h],y[h]);c.lineEnd(),c.areaEnd()}m&&(v[u]=+t(p,u,r),y[u]=+i(p,u,r),c.point(n?+n(p,u,r):v[u],a?+a(p,u,r):y[u]))}if(d)return c=null,d+\"\"||null}function f(){return A().defined(o).curve(l).context(s)}return u.x=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),n=null,u):t},u.x0=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),u):t},u.x1=function(t){return arguments.length?(n=null==t?null:\"function\"==typeof t?t:r(+t),u):n},u.y=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a=null,u):i},u.y0=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),u):i},u.y1=function(t){return arguments.length?(a=null==t?null:\"function\"==typeof t?t:r(+t),u):a},u.lineX0=u.lineY0=function(){return f().x(t).y(i)},u.lineY1=function(){return f().x(t).y(a)},u.lineX1=function(){return f().x(n).y(i)},u.defined=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(!!t),u):o},u.curve=function(t){return arguments.length?(l=t,null!=s&&(c=l(s)),u):l},u.context=function(t){return arguments.length?(null==t?s=c=null:c=l(s=t),u):s},u}function E(t,e){return e<t?-1:e>t?1:e>=t?0:NaN}function C(t){return t}w.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._point=0},lineEnd:function(){(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:this._context.lineTo(t,e)}}};var L=P(T);function I(t){this._curve=t}function P(t){function e(e){return new I(t(e))}return e._curve=t,e}function z(t){var e=t.curve;return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function O(){return z(A().curve(L))}function D(){var t=S().curve(L),e=t.curve,r=t.lineX0,n=t.lineX1,i=t.lineY0,a=t.lineY1;return t.angle=t.x,delete t.x,t.startAngle=t.x0,delete t.x0,t.endAngle=t.x1,delete t.x1,t.radius=t.y,delete t.y,t.innerRadius=t.y0,delete t.y0,t.outerRadius=t.y1,delete t.y1,t.lineStartAngle=function(){return z(r())},delete t.lineX0,t.lineEndAngle=function(){return z(n())},delete t.lineX1,t.lineInnerRadius=function(){return z(i())},delete t.lineY0,t.lineOuterRadius=function(){return z(a())},delete t.lineY1,t.curve=function(t){return arguments.length?e(P(t)):e()._curve},t}function R(t,e){return[(e=+e)*Math.cos(t-=Math.PI/2),e*Math.sin(t)]}I.prototype={areaStart:function(){this._curve.areaStart()},areaEnd:function(){this._curve.areaEnd()},lineStart:function(){this._curve.lineStart()},lineEnd:function(){this._curve.lineEnd()},point:function(t,e){this._curve.point(e*Math.sin(t),e*-Math.cos(t))}};var F=Array.prototype.slice;function B(t){return t.source}function N(t){return t.target}function j(t){var n=B,i=N,a=k,o=M,s=null;function l(){var r,l=F.call(arguments),c=n.apply(this,l),u=i.apply(this,l);if(s||(s=r=e.path()),t(s,+a.apply(this,(l[0]=c,l)),+o.apply(this,l),+a.apply(this,(l[0]=u,l)),+o.apply(this,l)),r)return s=null,r+\"\"||null}return l.source=function(t){return arguments.length?(n=t,l):n},l.target=function(t){return arguments.length?(i=t,l):i},l.x=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),l):a},l.y=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),l):o},l.context=function(t){return arguments.length?(s=null==t?null:t,l):s},l}function U(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e=(e+n)/2,r,e,i,n,i)}function V(t,e,r,n,i){t.moveTo(e,r),t.bezierCurveTo(e,r=(r+i)/2,n,r,n,i)}function q(t,e,r,n,i){var a=R(e,r),o=R(e,r=(r+i)/2),s=R(n,r),l=R(n,i);t.moveTo(a[0],a[1]),t.bezierCurveTo(o[0],o[1],s[0],s[1],l[0],l[1])}var H={draw:function(t,e){var r=Math.sqrt(e/u);t.moveTo(r,0),t.arc(0,0,r,0,h)}},G={draw:function(t,e){var r=Math.sqrt(e/5)/2;t.moveTo(-3*r,-r),t.lineTo(-r,-r),t.lineTo(-r,-3*r),t.lineTo(r,-3*r),t.lineTo(r,-r),t.lineTo(3*r,-r),t.lineTo(3*r,r),t.lineTo(r,r),t.lineTo(r,3*r),t.lineTo(-r,3*r),t.lineTo(-r,r),t.lineTo(-3*r,r),t.closePath()}},Y=Math.sqrt(1/3),W=2*Y,X={draw:function(t,e){var r=Math.sqrt(e/W),n=r*Y;t.moveTo(0,-r),t.lineTo(n,0),t.lineTo(0,r),t.lineTo(-n,0),t.closePath()}},Z=Math.sin(u/10)/Math.sin(7*u/10),J=Math.sin(h/10)*Z,K=-Math.cos(h/10)*Z,Q={draw:function(t,e){var r=Math.sqrt(.8908130915292852*e),n=J*r,i=K*r;t.moveTo(0,-r),t.lineTo(n,i);for(var a=1;a<5;++a){var o=h*a/5,s=Math.cos(o),l=Math.sin(o);t.lineTo(l*r,-s*r),t.lineTo(s*n-l*i,l*n+s*i)}t.closePath()}},$={draw:function(t,e){var r=Math.sqrt(e),n=-r/2;t.rect(n,n,r,r)}},tt=Math.sqrt(3),et={draw:function(t,e){var r=-Math.sqrt(e/(3*tt));t.moveTo(0,2*r),t.lineTo(-tt*r,-r),t.lineTo(tt*r,-r),t.closePath()}},rt=-.5,nt=Math.sqrt(3)/2,it=1/Math.sqrt(12),at=3*(it/2+1),ot={draw:function(t,e){var r=Math.sqrt(e/at),n=r/2,i=r*it,a=n,o=r*it+r,s=-a,l=o;t.moveTo(n,i),t.lineTo(a,o),t.lineTo(s,l),t.lineTo(rt*n-nt*i,nt*n+rt*i),t.lineTo(rt*a-nt*o,nt*a+rt*o),t.lineTo(rt*s-nt*l,nt*s+rt*l),t.lineTo(rt*n+nt*i,rt*i-nt*n),t.lineTo(rt*a+nt*o,rt*o-nt*a),t.lineTo(rt*s+nt*l,rt*l-nt*s),t.closePath()}},st=[H,G,X,$,Q,et,ot];function lt(){}function ct(t,e,r){t._context.bezierCurveTo((2*t._x0+t._x1)/3,(2*t._y0+t._y1)/3,(t._x0+2*t._x1)/3,(t._y0+2*t._y1)/3,(t._x0+4*t._x1+e)/6,(t._y0+4*t._y1+r)/6)}function ut(t){this._context=t}function ft(t){this._context=t}function ht(t){this._context=t}function pt(t,e){this._basis=new ut(t),this._beta=e}ut.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){switch(this._point){case 3:ct(this,this._x1,this._y1);case 2:this._context.lineTo(this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,this._context.lineTo((5*this._x0+this._x1)/6,(5*this._y0+this._y1)/6);default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ft.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._y0=this._y1=this._y2=this._y3=this._y4=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x2,this._y2),this._context.closePath();break;case 2:this._context.moveTo((this._x2+2*this._x3)/3,(this._y2+2*this._y3)/3),this._context.lineTo((this._x3+2*this._x2)/3,(this._y3+2*this._y2)/3),this._context.closePath();break;case 3:this.point(this._x2,this._y2),this.point(this._x3,this._y3),this.point(this._x4,this._y4)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x2=t,this._y2=e;break;case 1:this._point=2,this._x3=t,this._y3=e;break;case 2:this._point=3,this._x4=t,this._y4=e,this._context.moveTo((this._x0+4*this._x1+t)/6,(this._y0+4*this._y1+e)/6);break;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},ht.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3;var r=(this._x0+4*this._x1+t)/6,n=(this._y0+4*this._y1+e)/6;this._line?this._context.lineTo(r,n):this._context.moveTo(r,n);break;case 3:this._point=4;default:ct(this,t,e)}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e}},pt.prototype={lineStart:function(){this._x=[],this._y=[],this._basis.lineStart()},lineEnd:function(){var t=this._x,e=this._y,r=t.length-1;if(r>0)for(var n,i=t[0],a=e[0],o=t[r]-i,s=e[r]-a,l=-1;++l<=r;)n=l/r,this._basis.point(this._beta*t[l]+(1-this._beta)*(i+n*o),this._beta*e[l]+(1-this._beta)*(a+n*s));this._x=this._y=null,this._basis.lineEnd()},point:function(t,e){this._x.push(+t),this._y.push(+e)}};var dt=function t(e){function r(t){return 1===e?new ut(t):new pt(t,e)}return r.beta=function(e){return t(+e)},r}(.85);function gt(t,e,r){t._context.bezierCurveTo(t._x1+t._k*(t._x2-t._x0),t._y1+t._k*(t._y2-t._y0),t._x2+t._k*(t._x1-e),t._y2+t._k*(t._y1-r),t._x2,t._y2)}function mt(t,e){this._context=t,this._k=(1-e)/6}mt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:gt(this,this._x1,this._y1)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2,this._x1=t,this._y1=e;break;case 2:this._point=3;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var vt=function t(e){function r(t){return new mt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function yt(t,e){this._context=t,this._k=(1-e)/6}yt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var xt=function t(e){function r(t){return new yt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function bt(t,e){this._context=t,this._k=(1-e)/6}bt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:gt(this,t,e)}this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var _t=function t(e){function r(t){return new bt(t,e)}return r.tension=function(e){return t(+e)},r}(0);function wt(t,e,r){var n=t._x1,i=t._y1,a=t._x2,o=t._y2;if(t._l01_a>1e-12){var s=2*t._l01_2a+3*t._l01_a*t._l12_a+t._l12_2a,l=3*t._l01_a*(t._l01_a+t._l12_a);n=(n*s-t._x0*t._l12_2a+t._x2*t._l01_2a)/l,i=(i*s-t._y0*t._l12_2a+t._y2*t._l01_2a)/l}if(t._l23_a>1e-12){var c=2*t._l23_2a+3*t._l23_a*t._l12_a+t._l12_2a,u=3*t._l23_a*(t._l23_a+t._l12_a);a=(a*c+t._x1*t._l23_2a-e*t._l12_2a)/u,o=(o*c+t._y1*t._l23_2a-r*t._l12_2a)/u}t._context.bezierCurveTo(n,i,a,o,t._x2,t._y2)}function Tt(t,e){this._context=t,this._alpha=e}Tt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x2,this._y2);break;case 3:this.point(this._x2,this._y2)}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var kt=function t(e){function r(t){return e?new Tt(t,e):new mt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Mt(t,e){this._context=t,this._alpha=e}Mt.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._x0=this._x1=this._x2=this._x3=this._x4=this._x5=this._y0=this._y1=this._y2=this._y3=this._y4=this._y5=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){switch(this._point){case 1:this._context.moveTo(this._x3,this._y3),this._context.closePath();break;case 2:this._context.lineTo(this._x3,this._y3),this._context.closePath();break;case 3:this.point(this._x3,this._y3),this.point(this._x4,this._y4),this.point(this._x5,this._y5)}},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1,this._x3=t,this._y3=e;break;case 1:this._point=2,this._context.moveTo(this._x4=t,this._y4=e);break;case 2:this._point=3,this._x5=t,this._y5=e;break;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var At=function t(e){function r(t){return e?new Mt(t,e):new yt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function St(t,e){this._context=t,this._alpha=e}St.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._x2=this._y0=this._y1=this._y2=NaN,this._l01_a=this._l12_a=this._l23_a=this._l01_2a=this._l12_2a=this._l23_2a=this._point=0},lineEnd:function(){(this._line||0!==this._line&&3===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){if(t=+t,e=+e,this._point){var r=this._x2-t,n=this._y2-e;this._l23_a=Math.sqrt(this._l23_2a=Math.pow(r*r+n*n,this._alpha))}switch(this._point){case 0:this._point=1;break;case 1:this._point=2;break;case 2:this._point=3,this._line?this._context.lineTo(this._x2,this._y2):this._context.moveTo(this._x2,this._y2);break;case 3:this._point=4;default:wt(this,t,e)}this._l01_a=this._l12_a,this._l12_a=this._l23_a,this._l01_2a=this._l12_2a,this._l12_2a=this._l23_2a,this._x0=this._x1,this._x1=this._x2,this._x2=t,this._y0=this._y1,this._y1=this._y2,this._y2=e}};var Et=function t(e){function r(t){return e?new St(t,e):new bt(t,0)}return r.alpha=function(e){return t(+e)},r}(.5);function Ct(t){this._context=t}function Lt(t){return t<0?-1:1}function It(t,e,r){var n=t._x1-t._x0,i=e-t._x1,a=(t._y1-t._y0)/(n||i<0&&-0),o=(r-t._y1)/(i||n<0&&-0),s=(a*i+o*n)/(n+i);return(Lt(a)+Lt(o))*Math.min(Math.abs(a),Math.abs(o),.5*Math.abs(s))||0}function Pt(t,e){var r=t._x1-t._x0;return r?(3*(t._y1-t._y0)/r-e)/2:e}function zt(t,e,r){var n=t._x0,i=t._y0,a=t._x1,o=t._y1,s=(a-n)/3;t._context.bezierCurveTo(n+s,i+s*e,a-s,o-s*r,a,o)}function Ot(t){this._context=t}function Dt(t){this._context=new Rt(t)}function Rt(t){this._context=t}function Ft(t){this._context=t}function Bt(t){var e,r,n=t.length-1,i=new Array(n),a=new Array(n),o=new Array(n);for(i[0]=0,a[0]=2,o[0]=t[0]+2*t[1],e=1;e<n-1;++e)i[e]=1,a[e]=4,o[e]=4*t[e]+2*t[e+1];for(i[n-1]=2,a[n-1]=7,o[n-1]=8*t[n-1]+t[n],e=1;e<n;++e)r=i[e]/a[e-1],a[e]-=r,o[e]-=r*o[e-1];for(i[n-1]=o[n-1]/a[n-1],e=n-2;e>=0;--e)i[e]=(o[e]-i[e+1])/a[e];for(a[n-1]=(t[n]+i[n-1])/2,e=0;e<n-1;++e)a[e]=2*t[e+1]-i[e+1];return[i,a]}function Nt(t,e){this._context=t,this._t=e}function jt(t,e){if((i=t.length)>1)for(var r,n,i,a=1,o=t[e[0]],s=o.length;a<i;++a)for(n=o,o=t[e[a]],r=0;r<s;++r)o[r][1]+=o[r][0]=isNaN(n[r][1])?n[r][0]:n[r][1]}function Ut(t){for(var e=t.length,r=new Array(e);--e>=0;)r[e]=e;return r}function Vt(t,e){return t[e]}function qt(t){var e=t.map(Ht);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Ht(t){for(var e,r=-1,n=0,i=t.length,a=-1/0;++r<i;)(e=+t[r][1])>a&&(a=e,n=r);return n}function Gt(t){var e=t.map(Yt);return Ut(t).sort((function(t,r){return e[t]-e[r]}))}function Yt(t){for(var e,r=0,n=-1,i=t.length;++n<i;)(e=+t[n][1])&&(r+=e);return r}Ct.prototype={areaStart:lt,areaEnd:lt,lineStart:function(){this._point=0},lineEnd:function(){this._point&&this._context.closePath()},point:function(t,e){t=+t,e=+e,this._point?this._context.lineTo(t,e):(this._point=1,this._context.moveTo(t,e))}},Ot.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x0=this._x1=this._y0=this._y1=this._t0=NaN,this._point=0},lineEnd:function(){switch(this._point){case 2:this._context.lineTo(this._x1,this._y1);break;case 3:zt(this,this._t0,Pt(this,this._t0))}(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line=1-this._line},point:function(t,e){var r=NaN;if(e=+e,(t=+t)!==this._x1||e!==this._y1){switch(this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;break;case 2:this._point=3,zt(this,Pt(this,r=It(this,t,e)),r);break;default:zt(this,this._t0,r=It(this,t,e))}this._x0=this._x1,this._x1=t,this._y0=this._y1,this._y1=e,this._t0=r}}},(Dt.prototype=Object.create(Ot.prototype)).point=function(t,e){Ot.prototype.point.call(this,e,t)},Rt.prototype={moveTo:function(t,e){this._context.moveTo(e,t)},closePath:function(){this._context.closePath()},lineTo:function(t,e){this._context.lineTo(e,t)},bezierCurveTo:function(t,e,r,n,i,a){this._context.bezierCurveTo(e,t,n,r,a,i)}},Ft.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=[],this._y=[]},lineEnd:function(){var t=this._x,e=this._y,r=t.length;if(r)if(this._line?this._context.lineTo(t[0],e[0]):this._context.moveTo(t[0],e[0]),2===r)this._context.lineTo(t[1],e[1]);else for(var n=Bt(t),i=Bt(e),a=0,o=1;o<r;++a,++o)this._context.bezierCurveTo(n[0][a],i[0][a],n[1][a],i[1][a],t[o],e[o]);(this._line||0!==this._line&&1===r)&&this._context.closePath(),this._line=1-this._line,this._x=this._y=null},point:function(t,e){this._x.push(+t),this._y.push(+e)}},Nt.prototype={areaStart:function(){this._line=0},areaEnd:function(){this._line=NaN},lineStart:function(){this._x=this._y=NaN,this._point=0},lineEnd:function(){0<this._t&&this._t<1&&2===this._point&&this._context.lineTo(this._x,this._y),(this._line||0!==this._line&&1===this._point)&&this._context.closePath(),this._line>=0&&(this._t=1-this._t,this._line=1-this._line)},point:function(t,e){switch(t=+t,e=+e,this._point){case 0:this._point=1,this._line?this._context.lineTo(t,e):this._context.moveTo(t,e);break;case 1:this._point=2;default:if(this._t<=0)this._context.lineTo(this._x,e),this._context.lineTo(t,e);else{var r=this._x*(1-this._t)+t*this._t;this._context.lineTo(r,this._y),this._context.lineTo(r,e)}}this._x=t,this._y=e}},t.arc=function(){var t=g,o=m,w=r(0),T=null,k=v,M=y,A=x,S=null;function E(){var r,g,m=+t.apply(this,arguments),v=+o.apply(this,arguments),y=k.apply(this,arguments)-f,x=M.apply(this,arguments)-f,E=n(x-y),C=x>y;if(S||(S=r=e.path()),v<m&&(g=v,v=m,m=g),v>1e-12)if(E>h-1e-12)S.moveTo(v*a(y),v*l(y)),S.arc(0,0,v,y,x,!C),m>1e-12&&(S.moveTo(m*a(x),m*l(x)),S.arc(0,0,m,x,y,C));else{var L,I,P=y,z=x,O=y,D=x,R=E,F=E,B=A.apply(this,arguments)/2,N=B>1e-12&&(T?+T.apply(this,arguments):c(m*m+v*v)),j=s(n(v-m)/2,+w.apply(this,arguments)),U=j,V=j;if(N>1e-12){var q=d(N/m*l(B)),H=d(N/v*l(B));(R-=2*q)>1e-12?(O+=q*=C?1:-1,D-=q):(R=0,O=D=(y+x)/2),(F-=2*H)>1e-12?(P+=H*=C?1:-1,z-=H):(F=0,P=z=(y+x)/2)}var G=v*a(P),Y=v*l(P),W=m*a(D),X=m*l(D);if(j>1e-12){var Z,J=v*a(z),K=v*l(z),Q=m*a(O),$=m*l(O);if(E<u&&(Z=b(G,Y,Q,$,J,K,W,X))){var tt=G-Z[0],et=Y-Z[1],rt=J-Z[0],nt=K-Z[1],it=1/l(p((tt*rt+et*nt)/(c(tt*tt+et*et)*c(rt*rt+nt*nt)))/2),at=c(Z[0]*Z[0]+Z[1]*Z[1]);U=s(j,(m-at)/(it-1)),V=s(j,(v-at)/(it+1))}}F>1e-12?V>1e-12?(L=_(Q,$,G,Y,v,V,C),I=_(J,K,W,X,v,V,C),S.moveTo(L.cx+L.x01,L.cy+L.y01),V<j?S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,V,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,v,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),!C),S.arc(I.cx,I.cy,V,i(I.y11,I.x11),i(I.y01,I.x01),!C))):(S.moveTo(G,Y),S.arc(0,0,v,P,z,!C)):S.moveTo(G,Y),m>1e-12&&R>1e-12?U>1e-12?(L=_(W,X,J,K,m,-U,C),I=_(G,Y,Q,$,m,-U,C),S.lineTo(L.cx+L.x01,L.cy+L.y01),U<j?S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(I.y01,I.x01),!C):(S.arc(L.cx,L.cy,U,i(L.y01,L.x01),i(L.y11,L.x11),!C),S.arc(0,0,m,i(L.cy+L.y11,L.cx+L.x11),i(I.cy+I.y11,I.cx+I.x11),C),S.arc(I.cx,I.cy,U,i(I.y11,I.x11),i(I.y01,I.x01),!C))):S.arc(0,0,m,D,O,C):S.lineTo(W,X)}else S.moveTo(0,0);if(S.closePath(),r)return S=null,r+\"\"||null}return E.centroid=function(){var e=(+t.apply(this,arguments)+ +o.apply(this,arguments))/2,r=(+k.apply(this,arguments)+ +M.apply(this,arguments))/2-u/2;return[a(r)*e,l(r)*e]},E.innerRadius=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),E):t},E.outerRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),E):o},E.cornerRadius=function(t){return arguments.length?(w=\"function\"==typeof t?t:r(+t),E):w},E.padRadius=function(t){return arguments.length?(T=null==t?null:\"function\"==typeof t?t:r(+t),E):T},E.startAngle=function(t){return arguments.length?(k=\"function\"==typeof t?t:r(+t),E):k},E.endAngle=function(t){return arguments.length?(M=\"function\"==typeof t?t:r(+t),E):M},E.padAngle=function(t){return arguments.length?(A=\"function\"==typeof t?t:r(+t),E):A},E.context=function(t){return arguments.length?(S=null==t?null:t,E):S},E},t.area=S,t.areaRadial=D,t.curveBasis=function(t){return new ut(t)},t.curveBasisClosed=function(t){return new ft(t)},t.curveBasisOpen=function(t){return new ht(t)},t.curveBundle=dt,t.curveCardinal=vt,t.curveCardinalClosed=xt,t.curveCardinalOpen=_t,t.curveCatmullRom=kt,t.curveCatmullRomClosed=At,t.curveCatmullRomOpen=Et,t.curveLinear=T,t.curveLinearClosed=function(t){return new Ct(t)},t.curveMonotoneX=function(t){return new Ot(t)},t.curveMonotoneY=function(t){return new Dt(t)},t.curveNatural=function(t){return new Ft(t)},t.curveStep=function(t){return new Nt(t,.5)},t.curveStepAfter=function(t){return new Nt(t,1)},t.curveStepBefore=function(t){return new Nt(t,0)},t.line=A,t.lineRadial=O,t.linkHorizontal=function(){return j(U)},t.linkRadial=function(){var t=j(q);return t.angle=t.x,delete t.x,t.radius=t.y,delete t.y,t},t.linkVertical=function(){return j(V)},t.pie=function(){var t=C,e=E,n=null,i=r(0),a=r(h),o=r(0);function s(r){var s,l,c,u,f,p=r.length,d=0,g=new Array(p),m=new Array(p),v=+i.apply(this,arguments),y=Math.min(h,Math.max(-h,a.apply(this,arguments)-v)),x=Math.min(Math.abs(y)/p,o.apply(this,arguments)),b=x*(y<0?-1:1);for(s=0;s<p;++s)(f=m[g[s]=s]=+t(r[s],s,r))>0&&(d+=f);for(null!=e?g.sort((function(t,r){return e(m[t],m[r])})):null!=n&&g.sort((function(t,e){return n(r[t],r[e])})),s=0,c=d?(y-p*b)/d:0;s<p;++s,v=u)l=g[s],u=v+((f=m[l])>0?f*c:0)+b,m[l]={data:r[l],index:s,value:f,startAngle:v,endAngle:u,padAngle:x};return m}return s.value=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(+e),s):t},s.sortValues=function(t){return arguments.length?(e=t,n=null,s):e},s.sort=function(t){return arguments.length?(n=t,e=null,s):n},s.startAngle=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),s):i},s.endAngle=function(t){return arguments.length?(a=\"function\"==typeof t?t:r(+t),s):a},s.padAngle=function(t){return arguments.length?(o=\"function\"==typeof t?t:r(+t),s):o},s},t.pointRadial=R,t.radialArea=D,t.radialLine=O,t.stack=function(){var t=r([]),e=Ut,n=jt,i=Vt;function a(r){var a,o,s=t.apply(this,arguments),l=r.length,c=s.length,u=new Array(c);for(a=0;a<c;++a){for(var f,h=s[a],p=u[a]=new Array(l),d=0;d<l;++d)p[d]=f=[0,+i(r[d],h,d,r)],f.data=r[d];p.key=h}for(a=0,o=e(u);a<c;++a)u[o[a]].index=a;return n(u,o),u}return a.keys=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(F.call(e)),a):t},a.value=function(t){return arguments.length?(i=\"function\"==typeof t?t:r(+t),a):i},a.order=function(t){return arguments.length?(e=null==t?Ut:\"function\"==typeof t?t:r(F.call(t)),a):e},a.offset=function(t){return arguments.length?(n=null==t?jt:t,a):n},a},t.stackOffsetDiverging=function(t,e){if((s=t.length)>0)for(var r,n,i,a,o,s,l=0,c=t[e[0]].length;l<c;++l)for(a=o=0,r=0;r<s;++r)(i=(n=t[e[r]][l])[1]-n[0])>0?(n[0]=a,n[1]=a+=i):i<0?(n[1]=o,n[0]=o+=i):(n[0]=0,n[1]=i)},t.stackOffsetExpand=function(t,e){if((n=t.length)>0){for(var r,n,i,a=0,o=t[0].length;a<o;++a){for(i=r=0;r<n;++r)i+=t[r][a][1]||0;if(i)for(r=0;r<n;++r)t[r][a][1]/=i}jt(t,e)}},t.stackOffsetNone=jt,t.stackOffsetSilhouette=function(t,e){if((r=t.length)>0){for(var r,n=0,i=t[e[0]],a=i.length;n<a;++n){for(var o=0,s=0;o<r;++o)s+=t[o][n][1]||0;i[n][1]+=i[n][0]=-s/2}jt(t,e)}},t.stackOffsetWiggle=function(t,e){if((i=t.length)>0&&(n=(r=t[e[0]]).length)>0){for(var r,n,i,a=0,o=1;o<n;++o){for(var s=0,l=0,c=0;s<i;++s){for(var u=t[e[s]],f=u[o][1]||0,h=(f-(u[o-1][1]||0))/2,p=0;p<s;++p){var d=t[e[p]];h+=(d[o][1]||0)-(d[o-1][1]||0)}l+=f,c+=h*f}r[o-1][1]+=r[o-1][0]=a,l&&(a-=c/l)}r[o-1][1]+=r[o-1][0]=a,jt(t,e)}},t.stackOrderAppearance=qt,t.stackOrderAscending=Gt,t.stackOrderDescending=function(t){return Gt(t).reverse()},t.stackOrderInsideOut=function(t){var e,r,n=t.length,i=t.map(Yt),a=qt(t),o=0,s=0,l=[],c=[];for(e=0;e<n;++e)r=a[e],o<s?(o+=i[r],l.push(r)):(s+=i[r],c.push(r));return c.reverse().concat(l)},t.stackOrderNone=Ut,t.stackOrderReverse=function(t){return Ut(t).reverse()},t.symbol=function(){var t=r(H),n=r(64),i=null;function a(){var r;if(i||(i=r=e.path()),t.apply(this,arguments).draw(i,+n.apply(this,arguments)),r)return i=null,r+\"\"||null}return a.type=function(e){return arguments.length?(t=\"function\"==typeof e?e:r(e),a):t},a.size=function(t){return arguments.length?(n=\"function\"==typeof t?t:r(+t),a):n},a.context=function(t){return arguments.length?(i=null==t?null:t,a):i},a},t.symbolCircle=H,t.symbolCross=G,t.symbolDiamond=X,t.symbolSquare=$,t.symbolStar=Q,t.symbolTriangle=et,t.symbolWye=ot,t.symbols=st,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-path\":163}],166:[function(t,e,r){!function(n,i){\"object\"==typeof r&&\"undefined\"!=typeof e?i(r,t(\"d3-time\")):i((n=n||self).d3=n.d3||{},n.d3)}(this,(function(t,e){\"use strict\";function r(t){if(0<=t.y&&t.y<100){var e=new Date(-1,t.m,t.d,t.H,t.M,t.S,t.L);return e.setFullYear(t.y),e}return new Date(t.y,t.m,t.d,t.H,t.M,t.S,t.L)}function n(t){if(0<=t.y&&t.y<100){var e=new Date(Date.UTC(-1,t.m,t.d,t.H,t.M,t.S,t.L));return e.setUTCFullYear(t.y),e}return new Date(Date.UTC(t.y,t.m,t.d,t.H,t.M,t.S,t.L))}function i(t,e,r){return{y:t,m:e,d:r,H:0,M:0,S:0,L:0}}function a(t){var a=t.dateTime,o=t.date,l=t.time,c=t.periods,u=t.days,f=t.shortDays,h=t.months,yt=t.shortMonths,xt=p(c),bt=d(c),_t=p(u),wt=d(u),Tt=p(f),kt=d(f),Mt=p(h),At=d(h),St=p(yt),Et=d(yt),Ct={a:function(t){return f[t.getDay()]},A:function(t){return u[t.getDay()]},b:function(t){return yt[t.getMonth()]},B:function(t){return h[t.getMonth()]},c:null,d:D,e:D,f:j,H:R,I:F,j:B,L:N,m:U,M:V,p:function(t){return c[+(t.getHours()>=12)]},q:function(t){return 1+~~(t.getMonth()/3)},Q:mt,s:vt,S:q,u:H,U:G,V:Y,w:W,W:X,x:null,X:null,y:Z,Y:J,Z:K,\"%\":gt},Lt={a:function(t){return f[t.getUTCDay()]},A:function(t){return u[t.getUTCDay()]},b:function(t){return yt[t.getUTCMonth()]},B:function(t){return h[t.getUTCMonth()]},c:null,d:Q,e:Q,f:nt,H:$,I:tt,j:et,L:rt,m:it,M:at,p:function(t){return c[+(t.getUTCHours()>=12)]},q:function(t){return 1+~~(t.getUTCMonth()/3)},Q:mt,s:vt,S:ot,u:st,U:lt,V:ct,w:ut,W:ft,x:null,X:null,y:ht,Y:pt,Z:dt,\"%\":gt},It={a:function(t,e,r){var n=Tt.exec(e.slice(r));return n?(t.w=kt[n[0].toLowerCase()],r+n[0].length):-1},A:function(t,e,r){var n=_t.exec(e.slice(r));return n?(t.w=wt[n[0].toLowerCase()],r+n[0].length):-1},b:function(t,e,r){var n=St.exec(e.slice(r));return n?(t.m=Et[n[0].toLowerCase()],r+n[0].length):-1},B:function(t,e,r){var n=Mt.exec(e.slice(r));return n?(t.m=At[n[0].toLowerCase()],r+n[0].length):-1},c:function(t,e,r){return Ot(t,a,e,r)},d:M,e:M,f:I,H:S,I:S,j:A,L:L,m:k,M:E,p:function(t,e,r){var n=xt.exec(e.slice(r));return n?(t.p=bt[n[0].toLowerCase()],r+n[0].length):-1},q:T,Q:z,s:O,S:C,u:m,U:v,V:y,w:g,W:x,x:function(t,e,r){return Ot(t,o,e,r)},X:function(t,e,r){return Ot(t,l,e,r)},y:_,Y:b,Z:w,\"%\":P};function Pt(t,e){return function(r){var n,i,a,o=[],l=-1,c=0,u=t.length;for(r instanceof Date||(r=new Date(+r));++l<u;)37===t.charCodeAt(l)&&(o.push(t.slice(c,l)),null!=(i=s[n=t.charAt(++l)])?n=t.charAt(++l):i=\"e\"===n?\" \":\"0\",(a=e[n])&&(n=a(r,i)),o.push(n),c=l+1);return o.push(t.slice(c,l)),o.join(\"\")}}function zt(t,a){return function(o){var s,l,c=i(1900,void 0,1);if(Ot(c,t,o+=\"\",0)!=o.length)return null;if(\"Q\"in c)return new Date(c.Q);if(\"s\"in c)return new Date(1e3*c.s+(\"L\"in c?c.L:0));if(a&&!(\"Z\"in c)&&(c.Z=0),\"p\"in c&&(c.H=c.H%12+12*c.p),void 0===c.m&&(c.m=\"q\"in c?c.q:0),\"V\"in c){if(c.V<1||c.V>53)return null;\"w\"in c||(c.w=1),\"Z\"in c?(l=(s=n(i(c.y,0,1))).getUTCDay(),s=l>4||0===l?e.utcMonday.ceil(s):e.utcMonday(s),s=e.utcDay.offset(s,7*(c.V-1)),c.y=s.getUTCFullYear(),c.m=s.getUTCMonth(),c.d=s.getUTCDate()+(c.w+6)%7):(l=(s=r(i(c.y,0,1))).getDay(),s=l>4||0===l?e.timeMonday.ceil(s):e.timeMonday(s),s=e.timeDay.offset(s,7*(c.V-1)),c.y=s.getFullYear(),c.m=s.getMonth(),c.d=s.getDate()+(c.w+6)%7)}else(\"W\"in c||\"U\"in c)&&(\"w\"in c||(c.w=\"u\"in c?c.u%7:\"W\"in c?1:0),l=\"Z\"in c?n(i(c.y,0,1)).getUTCDay():r(i(c.y,0,1)).getDay(),c.m=0,c.d=\"W\"in c?(c.w+6)%7+7*c.W-(l+5)%7:c.w+7*c.U-(l+6)%7);return\"Z\"in c?(c.H+=c.Z/100|0,c.M+=c.Z%100,n(c)):r(c)}}function Ot(t,e,r,n){for(var i,a,o=0,l=e.length,c=r.length;o<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(o++))){if(i=e.charAt(o++),!(a=It[i in s?e.charAt(o++):i])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}return Ct.x=Pt(o,Ct),Ct.X=Pt(l,Ct),Ct.c=Pt(a,Ct),Lt.x=Pt(o,Lt),Lt.X=Pt(l,Lt),Lt.c=Pt(a,Lt),{format:function(t){var e=Pt(t+=\"\",Ct);return e.toString=function(){return t},e},parse:function(t){var e=zt(t+=\"\",!1);return e.toString=function(){return t},e},utcFormat:function(t){var e=Pt(t+=\"\",Lt);return e.toString=function(){return t},e},utcParse:function(t){var e=zt(t+=\"\",!0);return e.toString=function(){return t},e}}}var o,s={\"-\":\"\",_:\" \",0:\"0\"},l=/^\\s*\\d+/,c=/^%/,u=/[\\\\^$*+?|[\\]().{}]/g;function f(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function h(t){return t.replace(u,\"\\\\$&\")}function p(t){return new RegExp(\"^(?:\"+t.map(h).join(\"|\")+\")\",\"i\")}function d(t){for(var e={},r=-1,n=t.length;++r<n;)e[t[r].toLowerCase()]=r;return e}function g(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function m(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.u=+n[0],r+n[0].length):-1}function v(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.U=+n[0],r+n[0].length):-1}function y(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.V=+n[0],r+n[0].length):-1}function x(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.W=+n[0],r+n[0].length):-1}function b(t,e,r){var n=l.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function _(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.y=+n[0]+(+n[0]>68?1900:2e3),r+n[0].length):-1}function w(t,e,r){var n=/^(Z)|([+-]\\d\\d)(?::?(\\d\\d))?/.exec(e.slice(r,r+6));return n?(t.Z=n[1]?0:-(n[2]+(n[3]||\"00\")),r+n[0].length):-1}function T(t,e,r){var n=l.exec(e.slice(r,r+1));return n?(t.q=3*n[0]-3,r+n[0].length):-1}function k(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function M(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function A(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.m=0,t.d=+n[0],r+n[0].length):-1}function S(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function E(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function C(t,e,r){var n=l.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function L(t,e,r){var n=l.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function I(t,e,r){var n=l.exec(e.slice(r,r+6));return n?(t.L=Math.floor(n[0]/1e3),r+n[0].length):-1}function P(t,e,r){var n=c.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function z(t,e,r){var n=l.exec(e.slice(r));return n?(t.Q=+n[0],r+n[0].length):-1}function O(t,e,r){var n=l.exec(e.slice(r));return n?(t.s=+n[0],r+n[0].length):-1}function D(t,e){return f(t.getDate(),e,2)}function R(t,e){return f(t.getHours(),e,2)}function F(t,e){return f(t.getHours()%12||12,e,2)}function B(t,r){return f(1+e.timeDay.count(e.timeYear(t),t),r,3)}function N(t,e){return f(t.getMilliseconds(),e,3)}function j(t,e){return N(t,e)+\"000\"}function U(t,e){return f(t.getMonth()+1,e,2)}function V(t,e){return f(t.getMinutes(),e,2)}function q(t,e){return f(t.getSeconds(),e,2)}function H(t){var e=t.getDay();return 0===e?7:e}function G(t,r){return f(e.timeSunday.count(e.timeYear(t)-1,t),r,2)}function Y(t,r){var n=t.getDay();return t=n>=4||0===n?e.timeThursday(t):e.timeThursday.ceil(t),f(e.timeThursday.count(e.timeYear(t),t)+(4===e.timeYear(t).getDay()),r,2)}function W(t){return t.getDay()}function X(t,r){return f(e.timeMonday.count(e.timeYear(t)-1,t),r,2)}function Z(t,e){return f(t.getFullYear()%100,e,2)}function J(t,e){return f(t.getFullYear()%1e4,e,4)}function K(t){var e=t.getTimezoneOffset();return(e>0?\"-\":(e*=-1,\"+\"))+f(e/60|0,\"0\",2)+f(e%60,\"0\",2)}function Q(t,e){return f(t.getUTCDate(),e,2)}function $(t,e){return f(t.getUTCHours(),e,2)}function tt(t,e){return f(t.getUTCHours()%12||12,e,2)}function et(t,r){return f(1+e.utcDay.count(e.utcYear(t),t),r,3)}function rt(t,e){return f(t.getUTCMilliseconds(),e,3)}function nt(t,e){return rt(t,e)+\"000\"}function it(t,e){return f(t.getUTCMonth()+1,e,2)}function at(t,e){return f(t.getUTCMinutes(),e,2)}function ot(t,e){return f(t.getUTCSeconds(),e,2)}function st(t){var e=t.getUTCDay();return 0===e?7:e}function lt(t,r){return f(e.utcSunday.count(e.utcYear(t)-1,t),r,2)}function ct(t,r){var n=t.getUTCDay();return t=n>=4||0===n?e.utcThursday(t):e.utcThursday.ceil(t),f(e.utcThursday.count(e.utcYear(t),t)+(4===e.utcYear(t).getUTCDay()),r,2)}function ut(t){return t.getUTCDay()}function ft(t,r){return f(e.utcMonday.count(e.utcYear(t)-1,t),r,2)}function ht(t,e){return f(t.getUTCFullYear()%100,e,2)}function pt(t,e){return f(t.getUTCFullYear()%1e4,e,4)}function dt(){return\"+0000\"}function gt(){return\"%\"}function mt(t){return+t}function vt(t){return Math.floor(+t/1e3)}function yt(e){return o=a(e),t.timeFormat=o.format,t.timeParse=o.parse,t.utcFormat=o.utcFormat,t.utcParse=o.utcParse,o}yt({dateTime:\"%x, %X\",date:\"%-m/%-d/%Y\",time:\"%-I:%M:%S %p\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});var xt=Date.prototype.toISOString?function(t){return t.toISOString()}:t.utcFormat(\"%Y-%m-%dT%H:%M:%S.%LZ\");var bt=+new Date(\"2000-01-01T00:00:00.000Z\")?function(t){var e=new Date(t);return isNaN(e)?null:e}:t.utcParse(\"%Y-%m-%dT%H:%M:%S.%LZ\");t.isoFormat=xt,t.isoParse=bt,t.timeFormatDefaultLocale=yt,t.timeFormatLocale=a,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{\"d3-time\":167}],167:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e=new Date,r=new Date;function n(t,i,a,o){function s(e){return t(e=0===arguments.length?new Date:new Date(+e)),e}return s.floor=function(e){return t(e=new Date(+e)),e},s.ceil=function(e){return t(e=new Date(e-1)),i(e,1),t(e),e},s.round=function(t){var e=s(t),r=s.ceil(t);return t-e<r-t?e:r},s.offset=function(t,e){return i(t=new Date(+t),null==e?1:Math.floor(e)),t},s.range=function(e,r,n){var a,o=[];if(e=s.ceil(e),n=null==n?1:Math.floor(n),!(e<r&&n>0))return o;do{o.push(a=new Date(+e)),i(e,n),t(e)}while(a<e&&e<r);return o},s.filter=function(e){return n((function(r){if(r>=r)for(;t(r),!e(r);)r.setTime(r-1)}),(function(t,r){if(t>=t)if(r<0)for(;++r<=0;)for(;i(t,-1),!e(t););else for(;--r>=0;)for(;i(t,1),!e(t););}))},a&&(s.count=function(n,i){return e.setTime(+n),r.setTime(+i),t(e),t(r),Math.floor(a(e,r))},s.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?s.filter(o?function(e){return o(e)%t==0}:function(e){return s.count(0,e)%t==0}):s:null}),s}var i=n((function(){}),(function(t,e){t.setTime(+t+e)}),(function(t,e){return e-t}));i.every=function(t){return t=Math.floor(t),isFinite(t)&&t>0?t>1?n((function(e){e.setTime(Math.floor(e/t)*t)}),(function(e,r){e.setTime(+e+r*t)}),(function(e,r){return(r-e)/t})):i:null};var a=i.range,o=n((function(t){t.setTime(t-t.getMilliseconds())}),(function(t,e){t.setTime(+t+1e3*e)}),(function(t,e){return(e-t)/1e3}),(function(t){return t.getUTCSeconds()})),s=o.range,l=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds())}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getMinutes()})),c=l.range,u=n((function(t){t.setTime(t-t.getMilliseconds()-1e3*t.getSeconds()-6e4*t.getMinutes())}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getHours()})),f=u.range,h=n((function(t){t.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/864e5}),(function(t){return t.getDate()-1})),p=h.range;function d(t){return n((function(e){e.setDate(e.getDate()-(e.getDay()+7-t)%7),e.setHours(0,0,0,0)}),(function(t,e){t.setDate(t.getDate()+7*e)}),(function(t,e){return(e-t-6e4*(e.getTimezoneOffset()-t.getTimezoneOffset()))/6048e5}))}var g=d(0),m=d(1),v=d(2),y=d(3),x=d(4),b=d(5),_=d(6),w=g.range,T=m.range,k=v.range,M=y.range,A=x.range,S=b.range,E=_.range,C=n((function(t){t.setDate(1),t.setHours(0,0,0,0)}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t,e){return e.getMonth()-t.getMonth()+12*(e.getFullYear()-t.getFullYear())}),(function(t){return t.getMonth()})),L=C.range,I=n((function(t){t.setMonth(0,1),t.setHours(0,0,0,0)}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t,e){return e.getFullYear()-t.getFullYear()}),(function(t){return t.getFullYear()}));I.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setFullYear(Math.floor(e.getFullYear()/t)*t),e.setMonth(0,1),e.setHours(0,0,0,0)}),(function(e,r){e.setFullYear(e.getFullYear()+r*t)})):null};var P=I.range,z=n((function(t){t.setUTCSeconds(0,0)}),(function(t,e){t.setTime(+t+6e4*e)}),(function(t,e){return(e-t)/6e4}),(function(t){return t.getUTCMinutes()})),O=z.range,D=n((function(t){t.setUTCMinutes(0,0,0)}),(function(t,e){t.setTime(+t+36e5*e)}),(function(t,e){return(e-t)/36e5}),(function(t){return t.getUTCHours()})),R=D.range,F=n((function(t){t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+e)}),(function(t,e){return(e-t)/864e5}),(function(t){return t.getUTCDate()-1})),B=F.range;function N(t){return n((function(e){e.setUTCDate(e.getUTCDate()-(e.getUTCDay()+7-t)%7),e.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCDate(t.getUTCDate()+7*e)}),(function(t,e){return(e-t)/6048e5}))}var j=N(0),U=N(1),V=N(2),q=N(3),H=N(4),G=N(5),Y=N(6),W=j.range,X=U.range,Z=V.range,J=q.range,K=H.range,Q=G.range,$=Y.range,tt=n((function(t){t.setUTCDate(1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCMonth(t.getUTCMonth()+e)}),(function(t,e){return e.getUTCMonth()-t.getUTCMonth()+12*(e.getUTCFullYear()-t.getUTCFullYear())}),(function(t){return t.getUTCMonth()})),et=tt.range,rt=n((function(t){t.setUTCMonth(0,1),t.setUTCHours(0,0,0,0)}),(function(t,e){t.setUTCFullYear(t.getUTCFullYear()+e)}),(function(t,e){return e.getUTCFullYear()-t.getUTCFullYear()}),(function(t){return t.getUTCFullYear()}));rt.every=function(t){return isFinite(t=Math.floor(t))&&t>0?n((function(e){e.setUTCFullYear(Math.floor(e.getUTCFullYear()/t)*t),e.setUTCMonth(0,1),e.setUTCHours(0,0,0,0)}),(function(e,r){e.setUTCFullYear(e.getUTCFullYear()+r*t)})):null};var nt=rt.range;t.timeDay=h,t.timeDays=p,t.timeFriday=b,t.timeFridays=S,t.timeHour=u,t.timeHours=f,t.timeInterval=n,t.timeMillisecond=i,t.timeMilliseconds=a,t.timeMinute=l,t.timeMinutes=c,t.timeMonday=m,t.timeMondays=T,t.timeMonth=C,t.timeMonths=L,t.timeSaturday=_,t.timeSaturdays=E,t.timeSecond=o,t.timeSeconds=s,t.timeSunday=g,t.timeSundays=w,t.timeThursday=x,t.timeThursdays=A,t.timeTuesday=v,t.timeTuesdays=k,t.timeWednesday=y,t.timeWednesdays=M,t.timeWeek=g,t.timeWeeks=w,t.timeYear=I,t.timeYears=P,t.utcDay=F,t.utcDays=B,t.utcFriday=G,t.utcFridays=Q,t.utcHour=D,t.utcHours=R,t.utcMillisecond=i,t.utcMilliseconds=a,t.utcMinute=z,t.utcMinutes=O,t.utcMonday=U,t.utcMondays=X,t.utcMonth=tt,t.utcMonths=et,t.utcSaturday=Y,t.utcSaturdays=$,t.utcSecond=o,t.utcSeconds=s,t.utcSunday=j,t.utcSundays=W,t.utcThursday=H,t.utcThursdays=K,t.utcTuesday=V,t.utcTuesdays=Z,t.utcWednesday=q,t.utcWednesdays=J,t.utcWeek=j,t.utcWeeks=W,t.utcYear=rt,t.utcYears=nt,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],168:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).d3=t.d3||{})}(this,(function(t){\"use strict\";var e,r,n=0,i=0,a=0,o=0,s=0,l=0,c=\"object\"==typeof performance&&performance.now?performance:Date,u=\"object\"==typeof window&&window.requestAnimationFrame?window.requestAnimationFrame.bind(window):function(t){setTimeout(t,17)};function f(){return s||(u(h),s=c.now()+l)}function h(){s=0}function p(){this._call=this._time=this._next=null}function d(t,e,r){var n=new p;return n.restart(t,e,r),n}function g(){f(),++n;for(var t,r=e;r;)(t=s-r._time)>=0&&r._call.call(null,t),r=r._next;--n}function m(){s=(o=c.now())+l,n=i=0;try{g()}finally{n=0,function(){var t,n,i=e,a=1/0;for(;i;)i._call?(a>i._time&&(a=i._time),t=i,i=i._next):(n=i._next,i._next=null,i=t?t._next=n:e=n);r=t,y(a)}(),s=0}}function v(){var t=c.now(),e=t-o;e>1e3&&(l-=e,o=t)}function y(t){n||(i&&(i=clearTimeout(i)),t-s>24?(t<1/0&&(i=setTimeout(m,t-c.now()-l)),a&&(a=clearInterval(a))):(a||(o=c.now(),a=setInterval(v,1e3)),n=1,u(m)))}p.prototype=d.prototype={constructor:p,restart:function(t,n,i){if(\"function\"!=typeof t)throw new TypeError(\"callback is not a function\");i=(null==i?f():+i)+(null==n?0:+n),this._next||r===this||(r?r._next=this:e=this,r=this),this._call=t,this._time=i,y()},stop:function(){this._call&&(this._call=null,this._time=1/0,y())}},t.interval=function(t,e,r){var n=new p,i=e;return null==e?(n.restart(t,e,r),n):(e=+e,r=null==r?f():+r,n.restart((function a(o){o+=i,n.restart(a,i+=e,r),t(o)}),e,r),n)},t.now=f,t.timeout=function(t,e,r){var n=new p;return e=null==e?0:+e,n.restart((function(r){n.stop(),t(r+e)}),e,r),n},t.timer=d,t.timerFlush=g,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],169:[function(t,e,r){!function(){var t={version:\"3.5.17\"},r=[].slice,n=function(t){return r.call(t)},i=this.document;function a(t){return t&&(t.ownerDocument||t.document||t).documentElement}function o(t){return t&&(t.ownerDocument&&t.ownerDocument.defaultView||t.document&&t||t.defaultView)}if(i)try{n(i.documentElement.childNodes)[0].nodeType}catch(t){n=function(t){for(var e=t.length,r=new Array(e);e--;)r[e]=t[e];return r}}if(Date.now||(Date.now=function(){return+new Date}),i)try{i.createElement(\"DIV\").style.setProperty(\"opacity\",0,\"\")}catch(t){var s=this.Element.prototype,l=s.setAttribute,c=s.setAttributeNS,u=this.CSSStyleDeclaration.prototype,f=u.setProperty;s.setAttribute=function(t,e){l.call(this,t,e+\"\")},s.setAttributeNS=function(t,e,r){c.call(this,t,e,r+\"\")},u.setProperty=function(t,e,r){f.call(this,t,e+\"\",r)}}function h(t,e){return t<e?-1:t>e?1:t>=e?0:NaN}function p(t){return null===t?NaN:+t}function d(t){return!isNaN(t)}function g(t){return{left:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)<0?n=a+1:i=a}return n},right:function(e,r,n,i){for(arguments.length<3&&(n=0),arguments.length<4&&(i=e.length);n<i;){var a=n+i>>>1;t(e[a],r)>0?i=a:n=a+1}return n}}}t.ascending=h,t.descending=function(t,e){return e<t?-1:e>t?1:e>=t?0:NaN},t.min=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&r>n&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&r>n&&(r=n)}return r},t.max=function(t,e){var r,n,i=-1,a=t.length;if(1===arguments.length){for(;++i<a;)if(null!=(n=t[i])&&n>=n){r=n;break}for(;++i<a;)null!=(n=t[i])&&n>r&&(r=n)}else{for(;++i<a;)if(null!=(n=e.call(t,t[i],i))&&n>=n){r=n;break}for(;++i<a;)null!=(n=e.call(t,t[i],i))&&n>r&&(r=n)}return r},t.extent=function(t,e){var r,n,i,a=-1,o=t.length;if(1===arguments.length){for(;++a<o;)if(null!=(n=t[a])&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=t[a])&&(r>n&&(r=n),i<n&&(i=n))}else{for(;++a<o;)if(null!=(n=e.call(t,t[a],a))&&n>=n){r=i=n;break}for(;++a<o;)null!=(n=e.call(t,t[a],a))&&(r>n&&(r=n),i<n&&(i=n))}return[r,i]},t.sum=function(t,e){var r,n=0,i=t.length,a=-1;if(1===arguments.length)for(;++a<i;)d(r=+t[a])&&(n+=r);else for(;++a<i;)d(r=+e.call(t,t[a],a))&&(n+=r);return n},t.mean=function(t,e){var r,n=0,i=t.length,a=-1,o=i;if(1===arguments.length)for(;++a<i;)d(r=p(t[a]))?n+=r:--o;else for(;++a<i;)d(r=p(e.call(t,t[a],a)))?n+=r:--o;if(o)return n/o},t.quantile=function(t,e){var r=(t.length-1)*e+1,n=Math.floor(r),i=+t[n-1],a=r-n;return a?i+a*(t[n]-i):i},t.median=function(e,r){var n,i=[],a=e.length,o=-1;if(1===arguments.length)for(;++o<a;)d(n=p(e[o]))&&i.push(n);else for(;++o<a;)d(n=p(r.call(e,e[o],o)))&&i.push(n);if(i.length)return t.quantile(i.sort(h),.5)},t.variance=function(t,e){var r,n,i=t.length,a=0,o=0,s=-1,l=0;if(1===arguments.length)for(;++s<i;)d(r=p(t[s]))&&(o+=(n=r-a)*(r-(a+=n/++l)));else for(;++s<i;)d(r=p(e.call(t,t[s],s)))&&(o+=(n=r-a)*(r-(a+=n/++l)));if(l>1)return o/(l-1)},t.deviation=function(){var e=t.variance.apply(this,arguments);return e?Math.sqrt(e):e};var m=g(h);function v(t){return t.length}t.bisectLeft=m.left,t.bisect=t.bisectRight=m.right,t.bisector=function(t){return g(1===t.length?function(e,r){return h(t(e),r)}:t)},t.shuffle=function(t,e,r){(a=arguments.length)<3&&(r=t.length,a<2&&(e=0));for(var n,i,a=r-e;a;)i=Math.random()*a--|0,n=t[a+e],t[a+e]=t[i+e],t[i+e]=n;return t},t.permute=function(t,e){for(var r=e.length,n=new Array(r);r--;)n[r]=t[e[r]];return n},t.pairs=function(t){for(var e=0,r=t.length-1,n=t[0],i=new Array(r<0?0:r);e<r;)i[e]=[n,n=t[++e]];return i},t.transpose=function(e){if(!(a=e.length))return[];for(var r=-1,n=t.min(e,v),i=new Array(n);++r<n;)for(var a,o=-1,s=i[r]=new Array(a);++o<a;)s[o]=e[o][r];return i},t.zip=function(){return t.transpose(arguments)},t.keys=function(t){var e=[];for(var r in t)e.push(r);return e},t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.entries=function(t){var e=[];for(var r in t)e.push({key:r,value:t[r]});return e},t.merge=function(t){for(var e,r,n,i=t.length,a=-1,o=0;++a<i;)o+=t[a].length;for(r=new Array(o);--i>=0;)for(e=(n=t[i]).length;--e>=0;)r[--o]=n[e];return r};var y=Math.abs;function x(t){for(var e=1;t*e%1;)e*=10;return e}function b(t,e){for(var r in e)Object.defineProperty(t.prototype,r,{value:e[r],enumerable:!1})}function _(){this._=Object.create(null)}t.range=function(t,e,r){if(arguments.length<3&&(r=1,arguments.length<2&&(e=t,t=0)),(e-t)/r==1/0)throw new Error(\"infinite range\");var n,i=[],a=x(y(r)),o=-1;if(t*=a,e*=a,(r*=a)<0)for(;(n=t+r*++o)>e;)i.push(n/a);else for(;(n=t+r*++o)<e;)i.push(n/a);return i},t.map=function(t,e){var r=new _;if(t instanceof _)t.forEach((function(t,e){r.set(t,e)}));else if(Array.isArray(t)){var n,i=-1,a=t.length;if(1===arguments.length)for(;++i<a;)r.set(i,t[i]);else for(;++i<a;)r.set(e.call(t,n=t[i],i),n)}else for(var o in t)r.set(o,t[o]);return r};function w(t){return\"__proto__\"==(t+=\"\")||\"\\0\"===t[0]?\"\\0\"+t:t}function T(t){return\"\\0\"===(t+=\"\")[0]?t.slice(1):t}function k(t){return w(t)in this._}function M(t){return(t=w(t))in this._&&delete this._[t]}function A(){var t=[];for(var e in this._)t.push(T(e));return t}function S(){var t=0;for(var e in this._)++t;return t}function E(){for(var t in this._)return!1;return!0}function C(){this._=Object.create(null)}function L(t){return t}function I(t,e,r){return function(){var n=r.apply(e,arguments);return n===e?t:n}}function P(t,e){if(e in t)return e;e=e.charAt(0).toUpperCase()+e.slice(1);for(var r=0,n=z.length;r<n;++r){var i=z[r]+e;if(i in t)return i}}b(_,{has:k,get:function(t){return this._[w(t)]},set:function(t,e){return this._[w(t)]=e},remove:M,keys:A,values:function(){var t=[];for(var e in this._)t.push(this._[e]);return t},entries:function(){var t=[];for(var e in this._)t.push({key:T(e),value:this._[e]});return t},size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e),this._[e])}}),t.nest=function(){var e,r,n={},i=[],a=[];function o(t,a,s){if(s>=i.length)return r?r.call(n,a):e?a.sort(e):a;for(var l,c,u,f,h=-1,p=a.length,d=i[s++],g=new _;++h<p;)(f=g.get(l=d(c=a[h])))?f.push(c):g.set(l,[c]);return t?(c=t(),u=function(e,r){c.set(e,o(t,r,s))}):(c={},u=function(e,r){c[e]=o(t,r,s)}),g.forEach(u),c}return n.map=function(t,e){return o(e,t,0)},n.entries=function(e){return function t(e,r){if(r>=i.length)return e;var n=[],o=a[r++];return e.forEach((function(e,i){n.push({key:e,values:t(i,r)})})),o?n.sort((function(t,e){return o(t.key,e.key)})):n}(o(t.map,e,0),0)},n.key=function(t){return i.push(t),n},n.sortKeys=function(t){return a[i.length-1]=t,n},n.sortValues=function(t){return e=t,n},n.rollup=function(t){return r=t,n},n},t.set=function(t){var e=new C;if(t)for(var r=0,n=t.length;r<n;++r)e.add(t[r]);return e},b(C,{has:k,add:function(t){return this._[w(t+=\"\")]=!0,t},remove:M,values:A,size:S,empty:E,forEach:function(t){for(var e in this._)t.call(this,T(e))}}),t.behavior={},t.rebind=function(t,e){for(var r,n=1,i=arguments.length;++n<i;)t[r=arguments[n]]=I(t,e,e[r]);return t};var z=[\"webkit\",\"ms\",\"moz\",\"Moz\",\"o\",\"O\"];function O(){}function D(){}function R(t){var e=[],r=new _;function n(){for(var r,n=e,i=-1,a=n.length;++i<a;)(r=n[i].on)&&r.apply(this,arguments);return t}return n.on=function(n,i){var a,o=r.get(n);return arguments.length<2?o&&o.on:(o&&(o.on=null,e=e.slice(0,a=e.indexOf(o)).concat(e.slice(a+1)),r.remove(n)),i&&e.push(r.set(n,{on:i})),t)},n}function F(){t.event.preventDefault()}function B(){for(var e,r=t.event;e=r.sourceEvent;)r=e;return r}function N(e){for(var r=new D,n=0,i=arguments.length;++n<i;)r[arguments[n]]=R(r);return r.of=function(n,i){return function(a){try{var o=a.sourceEvent=t.event;a.target=e,t.event=a,r[a.type].apply(n,i)}finally{t.event=o}}},r}t.dispatch=function(){for(var t=new D,e=-1,r=arguments.length;++e<r;)t[arguments[e]]=R(t);return t},D.prototype.on=function(t,e){var r=t.indexOf(\".\"),n=\"\";if(r>=0&&(n=t.slice(r+1),t=t.slice(0,r)),t)return arguments.length<2?this[t].on(n):this[t].on(n,e);if(2===arguments.length){if(null==e)for(t in this)this.hasOwnProperty(t)&&this[t].on(n,null);return this}},t.event=null,t.requote=function(t){return t.replace(j,\"\\\\$&\")};var j=/[\\\\\\^\\$\\*\\+\\?\\|\\[\\]\\(\\)\\.\\{\\}]/g,U={}.__proto__?function(t,e){t.__proto__=e}:function(t,e){for(var r in e)t[r]=e[r]};function V(t){return U(t,Y),t}var q=function(t,e){return e.querySelector(t)},H=function(t,e){return e.querySelectorAll(t)},G=function(t,e){var r=t.matches||t[P(t,\"matchesSelector\")];return(G=function(t,e){return r.call(t,e)})(t,e)};\"function\"==typeof Sizzle&&(q=function(t,e){return Sizzle(t,e)[0]||null},H=Sizzle,G=Sizzle.matchesSelector),t.selection=function(){return t.select(i.documentElement)};var Y=t.selection.prototype=[];function W(t){return\"function\"==typeof t?t:function(){return q(t,this)}}function X(t){return\"function\"==typeof t?t:function(){return H(t,this)}}Y.select=function(t){var e,r,n,i,a=[];t=W(t);for(var o=-1,s=this.length;++o<s;){a.push(e=[]),e.parentNode=(n=this[o]).parentNode;for(var l=-1,c=n.length;++l<c;)(i=n[l])?(e.push(r=t.call(i,i.__data__,l,o)),r&&\"__data__\"in i&&(r.__data__=i.__data__)):e.push(null)}return V(a)},Y.selectAll=function(t){var e,r,i=[];t=X(t);for(var a=-1,o=this.length;++a<o;)for(var s=this[a],l=-1,c=s.length;++l<c;)(r=s[l])&&(i.push(e=n(t.call(r,r.__data__,l,a))),e.parentNode=r);return V(i)};var Z=\"http://www.w3.org/1999/xhtml\",J={svg:\"http://www.w3.org/2000/svg\",xhtml:Z,xlink:\"http://www.w3.org/1999/xlink\",xml:\"http://www.w3.org/XML/1998/namespace\",xmlns:\"http://www.w3.org/2000/xmlns/\"};function K(e,r){return e=t.ns.qualify(e),null==r?e.local?function(){this.removeAttributeNS(e.space,e.local)}:function(){this.removeAttribute(e)}:\"function\"==typeof r?e.local?function(){var t=r.apply(this,arguments);null==t?this.removeAttributeNS(e.space,e.local):this.setAttributeNS(e.space,e.local,t)}:function(){var t=r.apply(this,arguments);null==t?this.removeAttribute(e):this.setAttribute(e,t)}:e.local?function(){this.setAttributeNS(e.space,e.local,r)}:function(){this.setAttribute(e,r)}}function Q(t){return t.trim().replace(/\\s+/g,\" \")}function $(e){return new RegExp(\"(?:^|\\\\s+)\"+t.requote(e)+\"(?:\\\\s+|$)\",\"g\")}function tt(t){return(t+\"\").trim().split(/^|\\s+/)}function et(t,e){var r=(t=tt(t).map(rt)).length;return\"function\"==typeof e?function(){for(var n=-1,i=e.apply(this,arguments);++n<r;)t[n](this,i)}:function(){for(var n=-1;++n<r;)t[n](this,e)}}function rt(t){var e=$(t);return function(r,n){if(i=r.classList)return n?i.add(t):i.remove(t);var i=r.getAttribute(\"class\")||\"\";n?(e.lastIndex=0,e.test(i)||r.setAttribute(\"class\",Q(i+\" \"+t))):r.setAttribute(\"class\",Q(i.replace(e,\" \")))}}function nt(t,e,r){return null==e?function(){this.style.removeProperty(t)}:\"function\"==typeof e?function(){var n=e.apply(this,arguments);null==n?this.style.removeProperty(t):this.style.setProperty(t,n,r)}:function(){this.style.setProperty(t,e,r)}}function it(t,e){return null==e?function(){delete this[t]}:\"function\"==typeof e?function(){var r=e.apply(this,arguments);null==r?delete this[t]:this[t]=r}:function(){this[t]=e}}function at(e){return\"function\"==typeof e?e:(e=t.ns.qualify(e)).local?function(){return this.ownerDocument.createElementNS(e.space,e.local)}:function(){var t=this.ownerDocument,r=this.namespaceURI;return r===Z&&t.documentElement.namespaceURI===Z?t.createElement(e):t.createElementNS(r,e)}}function ot(){var t=this.parentNode;t&&t.removeChild(this)}function st(t){return{__data__:t}}function lt(t){return function(){return G(this,t)}}function ct(t){return arguments.length||(t=h),function(e,r){return e&&r?t(e.__data__,r.__data__):!e-!r}}function ut(t,e){for(var r=0,n=t.length;r<n;r++)for(var i,a=t[r],o=0,s=a.length;o<s;o++)(i=a[o])&&e(i,o,r);return t}function ft(t){return U(t,ht),t}t.ns={prefix:J,qualify:function(t){var e=t.indexOf(\":\"),r=t;return e>=0&&\"xmlns\"!==(r=t.slice(0,e))&&(t=t.slice(e+1)),J.hasOwnProperty(r)?{space:J[r],local:t}:t}},Y.attr=function(e,r){if(arguments.length<2){if(\"string\"==typeof e){var n=this.node();return(e=t.ns.qualify(e)).local?n.getAttributeNS(e.space,e.local):n.getAttribute(e)}for(r in e)this.each(K(r,e[r]));return this}return this.each(K(e,r))},Y.classed=function(t,e){if(arguments.length<2){if(\"string\"==typeof t){var r=this.node(),n=(t=tt(t)).length,i=-1;if(e=r.classList){for(;++i<n;)if(!e.contains(t[i]))return!1}else for(e=r.getAttribute(\"class\");++i<n;)if(!$(t[i]).test(e))return!1;return!0}for(e in t)this.each(et(e,t[e]));return this}return this.each(et(t,e))},Y.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.each(nt(r,t[r],e));return this}if(n<2){var i=this.node();return o(i).getComputedStyle(i,null).getPropertyValue(t)}r=\"\"}return this.each(nt(t,e,r))},Y.property=function(t,e){if(arguments.length<2){if(\"string\"==typeof t)return this.node()[t];for(e in t)this.each(it(e,t[e]));return this}return this.each(it(t,e))},Y.text=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.textContent=null==e?\"\":e}:null==t?function(){this.textContent=\"\"}:function(){this.textContent=t}):this.node().textContent},Y.html=function(t){return arguments.length?this.each(\"function\"==typeof t?function(){var e=t.apply(this,arguments);this.innerHTML=null==e?\"\":e}:null==t?function(){this.innerHTML=\"\"}:function(){this.innerHTML=t}):this.node().innerHTML},Y.append=function(t){return t=at(t),this.select((function(){return this.appendChild(t.apply(this,arguments))}))},Y.insert=function(t,e){return t=at(t),e=W(e),this.select((function(){return this.insertBefore(t.apply(this,arguments),e.apply(this,arguments)||null)}))},Y.remove=function(){return this.each(ot)},Y.data=function(t,e){var r,n,i=-1,a=this.length;if(!arguments.length){for(t=new Array(a=(r=this[0]).length);++i<a;)(n=r[i])&&(t[i]=n.__data__);return t}function o(t,r){var n,i,a,o=t.length,u=r.length,f=Math.min(o,u),h=new Array(u),p=new Array(u),d=new Array(o);if(e){var g,m=new _,v=new Array(o);for(n=-1;++n<o;)(i=t[n])&&(m.has(g=e.call(i,i.__data__,n))?d[n]=i:m.set(g,i),v[n]=g);for(n=-1;++n<u;)(i=m.get(g=e.call(r,a=r[n],n)))?!0!==i&&(h[n]=i,i.__data__=a):p[n]=st(a),m.set(g,!0);for(n=-1;++n<o;)n in v&&!0!==m.get(v[n])&&(d[n]=t[n])}else{for(n=-1;++n<f;)i=t[n],a=r[n],i?(i.__data__=a,h[n]=i):p[n]=st(a);for(;n<u;++n)p[n]=st(r[n]);for(;n<o;++n)d[n]=t[n]}p.update=h,p.parentNode=h.parentNode=d.parentNode=t.parentNode,s.push(p),l.push(h),c.push(d)}var s=ft([]),l=V([]),c=V([]);if(\"function\"==typeof t)for(;++i<a;)o(r=this[i],t.call(r,r.parentNode.__data__,i));else for(;++i<a;)o(r=this[i],t);return l.enter=function(){return s},l.exit=function(){return c},l},Y.datum=function(t){return arguments.length?this.property(\"__data__\",t):this.property(\"__data__\")},Y.filter=function(t){var e,r,n,i=[];\"function\"!=typeof t&&(t=lt(t));for(var a=0,o=this.length;a<o;a++){i.push(e=[]),e.parentNode=(r=this[a]).parentNode;for(var s=0,l=r.length;s<l;s++)(n=r[s])&&t.call(n,n.__data__,s,a)&&e.push(n)}return V(i)},Y.order=function(){for(var t=-1,e=this.length;++t<e;)for(var r,n=this[t],i=n.length-1,a=n[i];--i>=0;)(r=n[i])&&(a&&a!==r.nextSibling&&a.parentNode.insertBefore(r,a),a=r);return this},Y.sort=function(t){t=ct.apply(this,arguments);for(var e=-1,r=this.length;++e<r;)this[e].sort(t);return this.order()},Y.each=function(t){return ut(this,(function(e,r,n){t.call(e,e.__data__,r,n)}))},Y.call=function(t){var e=n(arguments);return t.apply(e[0]=this,e),this},Y.empty=function(){return!this.node()},Y.node=function(){for(var t=0,e=this.length;t<e;t++)for(var r=this[t],n=0,i=r.length;n<i;n++){var a=r[n];if(a)return a}return null},Y.size=function(){var t=0;return ut(this,(function(){++t})),t};var ht=[];function pt(t){var e,r;return function(n,i,a){var o,s=t[a].update,l=s.length;for(a!=r&&(r=a,e=0),i>=e&&(e=i+1);!(o=s[e])&&++e<l;);return o}}function dt(e,r,i){var a=\"__on\"+e,o=e.indexOf(\".\"),s=mt;o>0&&(e=e.slice(0,o));var l=gt.get(e);function c(){var t=this[a];t&&(this.removeEventListener(e,t,t.$),delete this[a])}return l&&(e=l,s=vt),o?r?function(){var t=s(r,n(arguments));c.call(this),this.addEventListener(e,this[a]=t,t.$=i),t._=r}:c:r?O:function(){var r,n=new RegExp(\"^__on([^.]+)\"+t.requote(e)+\"$\");for(var i in this)if(r=i.match(n)){var a=this[i];this.removeEventListener(r[1],a,a.$),delete this[i]}}}t.selection.enter=ft,t.selection.enter.prototype=ht,ht.append=Y.append,ht.empty=Y.empty,ht.node=Y.node,ht.call=Y.call,ht.size=Y.size,ht.select=function(t){for(var e,r,n,i,a,o=[],s=-1,l=this.length;++s<l;){n=(i=this[s]).update,o.push(e=[]),e.parentNode=i.parentNode;for(var c=-1,u=i.length;++c<u;)(a=i[c])?(e.push(n[c]=r=t.call(i.parentNode,a.__data__,c,s)),r.__data__=a.__data__):e.push(null)}return V(o)},ht.insert=function(t,e){return arguments.length<2&&(e=pt(this)),Y.insert.call(this,t,e)},t.select=function(t){var e;return\"string\"==typeof t?(e=[q(t,i)]).parentNode=i.documentElement:(e=[t]).parentNode=a(t),V([e])},t.selectAll=function(t){var e;return\"string\"==typeof t?(e=n(H(t,i))).parentNode=i.documentElement:(e=n(t)).parentNode=null,V([e])},Y.on=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=!1),t)this.each(dt(r,t[r],e));return this}if(n<2)return(n=this.node()[\"__on\"+t])&&n._;r=!1}return this.each(dt(t,e,r))};var gt=t.map({mouseenter:\"mouseover\",mouseleave:\"mouseout\"});function mt(e,r){return function(n){var i=t.event;t.event=n,r[0]=this.__data__;try{e.apply(this,r)}finally{t.event=i}}}function vt(t,e){var r=mt(t,e);return function(t){var e=t.relatedTarget;e&&(e===this||8&e.compareDocumentPosition(this))||r.call(this,t)}}i&&gt.forEach((function(t){\"on\"+t in i&&gt.remove(t)}));var yt,xt=0;function bt(e){var r=\".dragsuppress-\"+ ++xt,n=\"click\"+r,i=t.select(o(e)).on(\"touchmove\"+r,F).on(\"dragstart\"+r,F).on(\"selectstart\"+r,F);if(null==yt&&(yt=!(\"onselectstart\"in e)&&P(e.style,\"userSelect\")),yt){var s=a(e).style,l=s[yt];s[yt]=\"none\"}return function(t){if(i.on(r,null),yt&&(s[yt]=l),t){var e=function(){i.on(n,null)};i.on(n,(function(){F(),e()}),!0),setTimeout(e,0)}}}t.mouse=function(t){return wt(t,B())};var _t=this.navigator&&/WebKit/.test(this.navigator.userAgent)?-1:0;function wt(e,r){r.changedTouches&&(r=r.changedTouches[0]);var n=e.ownerSVGElement||e;if(n.createSVGPoint){var i=n.createSVGPoint();if(_t<0){var a=o(e);if(a.scrollX||a.scrollY){var s=(n=t.select(\"body\").append(\"svg\").style({position:\"absolute\",top:0,left:0,margin:0,padding:0,border:\"none\"},\"important\"))[0][0].getScreenCTM();_t=!(s.f||s.e),n.remove()}}return _t?(i.x=r.pageX,i.y=r.pageY):(i.x=r.clientX,i.y=r.clientY),[(i=i.matrixTransform(e.getScreenCTM().inverse())).x,i.y]}var l=e.getBoundingClientRect();return[r.clientX-l.left-e.clientLeft,r.clientY-l.top-e.clientTop]}function Tt(){return t.event.changedTouches[0].identifier}t.touch=function(t,e,r){if(arguments.length<3&&(r=e,e=B().changedTouches),e)for(var n,i=0,a=e.length;i<a;++i)if((n=e[i]).identifier===r)return wt(t,n)},t.behavior.drag=function(){var e=N(a,\"drag\",\"dragstart\",\"dragend\"),r=null,n=s(O,t.mouse,o,\"mousemove\",\"mouseup\"),i=s(Tt,t.touch,L,\"touchmove\",\"touchend\");function a(){this.on(\"mousedown.drag\",n).on(\"touchstart.drag\",i)}function s(n,i,a,o,s){return function(){var l,c=this,u=t.event.target.correspondingElement||t.event.target,f=c.parentNode,h=e.of(c,arguments),p=0,d=n(),g=\".drag\"+(null==d?\"\":\"-\"+d),m=t.select(a(u)).on(o+g,x).on(s+g,b),v=bt(u),y=i(f,d);function x(){var t,e,r=i(f,d);r&&(t=r[0]-y[0],e=r[1]-y[1],p|=t|e,y=r,h({type:\"drag\",x:r[0]+l[0],y:r[1]+l[1],dx:t,dy:e}))}function b(){i(f,d)&&(m.on(o+g,null).on(s+g,null),v(p),h({type:\"dragend\"}))}l=r?[(l=r.apply(c,arguments)).x-y[0],l.y-y[1]]:[0,0],h({type:\"dragstart\"})}}return a.origin=function(t){return arguments.length?(r=t,a):r},t.rebind(a,e,\"on\")},t.touches=function(t,e){return arguments.length<2&&(e=B().touches),e?n(e).map((function(e){var r=wt(t,e);return r.identifier=e.identifier,r})):[]};var kt=1e-6,Mt=1e-12,At=Math.PI,St=2*At,Et=St-kt,Ct=At/2,Lt=At/180,It=180/At;function Pt(t){return t>0?1:t<0?-1:0}function zt(t,e,r){return(e[0]-t[0])*(r[1]-t[1])-(e[1]-t[1])*(r[0]-t[0])}function Ot(t){return t>1?0:t<-1?At:Math.acos(t)}function Dt(t){return t>1?Ct:t<-1?-Ct:Math.asin(t)}function Rt(t){return((t=Math.exp(t))+1/t)/2}function Ft(t){return(t=Math.sin(t/2))*t}var Bt=Math.SQRT2;t.interpolateZoom=function(t,e){var r,n,i=t[0],a=t[1],o=t[2],s=e[0],l=e[1],c=e[2],u=s-i,f=l-a,h=u*u+f*f;if(h<Mt)n=Math.log(c/o)/Bt,r=function(t){return[i+t*u,a+t*f,o*Math.exp(Bt*t*n)]};else{var p=Math.sqrt(h),d=(c*c-o*o+4*h)/(2*o*2*p),g=(c*c-o*o-4*h)/(2*c*2*p),m=Math.log(Math.sqrt(d*d+1)-d),v=Math.log(Math.sqrt(g*g+1)-g);n=(v-m)/Bt,r=function(t){var e,r=t*n,s=Rt(m),l=o/(2*p)*(s*(e=Bt*r+m,((e=Math.exp(2*e))-1)/(e+1))-function(t){return((t=Math.exp(t))-1/t)/2}(m));return[i+l*u,a+l*f,o*s/Rt(Bt*r+m)]}}return r.duration=1e3*n,r},t.behavior.zoom=function(){var e,r,n,a,s,l,c,u,f,h={x:0,y:0,k:1},p=[960,500],d=Ut,g=250,m=0,v=\"mousedown.zoom\",y=\"mousemove.zoom\",x=\"mouseup.zoom\",b=\"touchstart.zoom\",_=N(w,\"zoomstart\",\"zoom\",\"zoomend\");function w(t){t.on(v,I).on(jt+\".zoom\",z).on(\"dblclick.zoom\",O).on(b,P)}function T(t){return[(t[0]-h.x)/h.k,(t[1]-h.y)/h.k]}function k(t){h.k=Math.max(d[0],Math.min(d[1],t))}function M(t,e){e=function(t){return[t[0]*h.k+h.x,t[1]*h.k+h.y]}(e),h.x+=t[0]-e[0],h.y+=t[1]-e[1]}function A(e,n,i,a){e.__chart__={x:h.x,y:h.y,k:h.k},k(Math.pow(2,a)),M(r=n,i),e=t.select(e),g>0&&(e=e.transition().duration(g)),e.call(w.event)}function S(){c&&c.domain(l.range().map((function(t){return(t-h.x)/h.k})).map(l.invert)),f&&f.domain(u.range().map((function(t){return(t-h.y)/h.k})).map(u.invert))}function E(t){m++||t({type:\"zoomstart\"})}function C(t){S(),t({type:\"zoom\",scale:h.k,translate:[h.x,h.y]})}function L(t){--m||(t({type:\"zoomend\"}),r=null)}function I(){var e=this,r=_.of(e,arguments),n=0,i=t.select(o(e)).on(y,l).on(x,c),a=T(t.mouse(e)),s=bt(e);function l(){n=1,M(t.mouse(e),a),C(r)}function c(){i.on(y,null).on(x,null),s(n),L(r)}vs.call(e),E(r)}function P(){var e,r=this,n=_.of(r,arguments),i={},a=0,o=\".zoom-\"+t.event.changedTouches[0].identifier,l=\"touchmove\"+o,c=\"touchend\"+o,u=[],f=t.select(r),p=bt(r);function d(){var n=t.touches(r);return e=h.k,n.forEach((function(t){t.identifier in i&&(i[t.identifier]=T(t))})),n}function g(){var e=t.event.target;t.select(e).on(l,m).on(c,y),u.push(e);for(var n=t.event.changedTouches,o=0,f=n.length;o<f;++o)i[n[o].identifier]=null;var p=d(),g=Date.now();if(1===p.length){if(g-s<500){var v=p[0];A(r,v,i[v.identifier],Math.floor(Math.log(h.k)/Math.LN2)+1),F()}s=g}else if(p.length>1){v=p[0];var x=p[1],b=v[0]-x[0],_=v[1]-x[1];a=b*b+_*_}}function m(){var o,l,c,u,f=t.touches(r);vs.call(r);for(var h=0,p=f.length;h<p;++h,u=null)if(c=f[h],u=i[c.identifier]){if(l)break;o=c,l=u}if(u){var d=(d=c[0]-o[0])*d+(d=c[1]-o[1])*d,g=a&&Math.sqrt(d/a);o=[(o[0]+c[0])/2,(o[1]+c[1])/2],l=[(l[0]+u[0])/2,(l[1]+u[1])/2],k(g*e)}s=null,M(o,l),C(n)}function y(){if(t.event.touches.length){for(var e=t.event.changedTouches,r=0,a=e.length;r<a;++r)delete i[e[r].identifier];for(var s in i)return void d()}t.selectAll(u).on(o,null),f.on(v,I).on(b,P),p(),L(n)}g(),E(n),f.on(v,null).on(b,g)}function z(){var i=_.of(this,arguments);a?clearTimeout(a):(vs.call(this),e=T(r=n||t.mouse(this)),E(i)),a=setTimeout((function(){a=null,L(i)}),50),F(),k(Math.pow(2,.002*Nt())*h.k),M(r,e),C(i)}function O(){var e=t.mouse(this),r=Math.log(h.k)/Math.LN2;A(this,e,T(e),t.event.shiftKey?Math.ceil(r)-1:Math.floor(r)+1)}return jt||(jt=\"onwheel\"in i?(Nt=function(){return-t.event.deltaY*(t.event.deltaMode?120:1)},\"wheel\"):\"onmousewheel\"in i?(Nt=function(){return t.event.wheelDelta},\"mousewheel\"):(Nt=function(){return-t.event.detail},\"MozMousePixelScroll\")),w.event=function(e){e.each((function(){var e=_.of(this,arguments),n=h;bs?t.select(this).transition().each(\"start.zoom\",(function(){h=this.__chart__||{x:0,y:0,k:1},E(e)})).tween(\"zoom:zoom\",(function(){var i=p[0],a=p[1],o=r?r[0]:i/2,s=r?r[1]:a/2,l=t.interpolateZoom([(o-h.x)/h.k,(s-h.y)/h.k,i/h.k],[(o-n.x)/n.k,(s-n.y)/n.k,i/n.k]);return function(t){var r=l(t),n=i/r[2];this.__chart__=h={x:o-r[0]*n,y:s-r[1]*n,k:n},C(e)}})).each(\"interrupt.zoom\",(function(){L(e)})).each(\"end.zoom\",(function(){L(e)})):(this.__chart__=h,E(e),C(e),L(e))}))},w.translate=function(t){return arguments.length?(h={x:+t[0],y:+t[1],k:h.k},S(),w):[h.x,h.y]},w.scale=function(t){return arguments.length?(h={x:h.x,y:h.y,k:null},k(+t),S(),w):h.k},w.scaleExtent=function(t){return arguments.length?(d=null==t?Ut:[+t[0],+t[1]],w):d},w.center=function(t){return arguments.length?(n=t&&[+t[0],+t[1]],w):n},w.size=function(t){return arguments.length?(p=t&&[+t[0],+t[1]],w):p},w.duration=function(t){return arguments.length?(g=+t,w):g},w.x=function(t){return arguments.length?(c=t,l=t.copy(),h={x:0,y:0,k:1},w):c},w.y=function(t){return arguments.length?(f=t,u=t.copy(),h={x:0,y:0,k:1},w):f},t.rebind(w,_,\"on\")};var Nt,jt,Ut=[0,1/0];function Vt(){}function qt(t,e,r){return this instanceof qt?(this.h=+t,this.s=+e,void(this.l=+r)):arguments.length<2?t instanceof qt?new qt(t.h,t.s,t.l):le(\"\"+t,ce,qt):new qt(t,e,r)}t.color=Vt,Vt.prototype.toString=function(){return this.rgb()+\"\"},t.hsl=qt;var Ht=qt.prototype=new Vt;function Gt(t,e,r){var n,i;function a(t){return Math.round(255*function(t){return t>360?t-=360:t<0&&(t+=360),t<60?n+(i-n)*t/60:t<180?i:t<240?n+(i-n)*(240-t)/60:n}(t))}return t=isNaN(t)?0:(t%=360)<0?t+360:t,e=isNaN(e)||e<0?0:e>1?1:e,n=2*(r=r<0?0:r>1?1:r)-(i=r<=.5?r*(1+e):r+e-r*e),new ne(a(t+120),a(t),a(t-120))}function Yt(e,r,n){return this instanceof Yt?(this.h=+e,this.c=+r,void(this.l=+n)):arguments.length<2?e instanceof Yt?new Yt(e.h,e.c,e.l):$t(e instanceof Zt?e.l:(e=ue((e=t.rgb(e)).r,e.g,e.b)).l,e.a,e.b):new Yt(e,r,n)}Ht.brighter=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,this.l/t)},Ht.darker=function(t){return t=Math.pow(.7,arguments.length?t:1),new qt(this.h,this.s,t*this.l)},Ht.rgb=function(){return Gt(this.h,this.s,this.l)},t.hcl=Yt;var Wt=Yt.prototype=new Vt;function Xt(t,e,r){return isNaN(t)&&(t=0),isNaN(e)&&(e=0),new Zt(r,Math.cos(t*=Lt)*e,Math.sin(t)*e)}function Zt(t,e,r){return this instanceof Zt?(this.l=+t,this.a=+e,void(this.b=+r)):arguments.length<2?t instanceof Zt?new Zt(t.l,t.a,t.b):t instanceof Yt?Xt(t.h,t.c,t.l):ue((t=ne(t)).r,t.g,t.b):new Zt(t,e,r)}Wt.brighter=function(t){return new Yt(this.h,this.c,Math.min(100,this.l+Jt*(arguments.length?t:1)))},Wt.darker=function(t){return new Yt(this.h,this.c,Math.max(0,this.l-Jt*(arguments.length?t:1)))},Wt.rgb=function(){return Xt(this.h,this.c,this.l).rgb()},t.lab=Zt;var Jt=18,Kt=Zt.prototype=new Vt;function Qt(t,e,r){var n=(t+16)/116,i=n+e/500,a=n-r/200;return new ne(re(3.2404542*(i=.95047*te(i))-1.5371385*(n=1*te(n))-.4985314*(a=1.08883*te(a))),re(-.969266*i+1.8760108*n+.041556*a),re(.0556434*i-.2040259*n+1.0572252*a))}function $t(t,e,r){return t>0?new Yt(Math.atan2(r,e)*It,Math.sqrt(e*e+r*r),t):new Yt(NaN,NaN,t)}function te(t){return t>.206893034?t*t*t:(t-4/29)/7.787037}function ee(t){return t>.008856?Math.pow(t,1/3):7.787037*t+4/29}function re(t){return Math.round(255*(t<=.00304?12.92*t:1.055*Math.pow(t,1/2.4)-.055))}function ne(t,e,r){return this instanceof ne?(this.r=~~t,this.g=~~e,void(this.b=~~r)):arguments.length<2?t instanceof ne?new ne(t.r,t.g,t.b):le(\"\"+t,ne,Gt):new ne(t,e,r)}function ie(t){return new ne(t>>16,t>>8&255,255&t)}function ae(t){return ie(t)+\"\"}Kt.brighter=function(t){return new Zt(Math.min(100,this.l+Jt*(arguments.length?t:1)),this.a,this.b)},Kt.darker=function(t){return new Zt(Math.max(0,this.l-Jt*(arguments.length?t:1)),this.a,this.b)},Kt.rgb=function(){return Qt(this.l,this.a,this.b)},t.rgb=ne;var oe=ne.prototype=new Vt;function se(t){return t<16?\"0\"+Math.max(0,t).toString(16):Math.min(255,t).toString(16)}function le(t,e,r){var n,i,a,o=0,s=0,l=0;if(n=/([a-z]+)\\((.*)\\)/.exec(t=t.toLowerCase()))switch(i=n[2].split(\",\"),n[1]){case\"hsl\":return r(parseFloat(i[0]),parseFloat(i[1])/100,parseFloat(i[2])/100);case\"rgb\":return e(he(i[0]),he(i[1]),he(i[2]))}return(a=pe.get(t))?e(a.r,a.g,a.b):(null==t||\"#\"!==t.charAt(0)||isNaN(a=parseInt(t.slice(1),16))||(4===t.length?(o=(3840&a)>>4,o|=o>>4,s=240&a,s|=s>>4,l=15&a,l|=l<<4):7===t.length&&(o=(16711680&a)>>16,s=(65280&a)>>8,l=255&a)),e(o,s,l))}function ce(t,e,r){var n,i,a=Math.min(t/=255,e/=255,r/=255),o=Math.max(t,e,r),s=o-a,l=(o+a)/2;return s?(i=l<.5?s/(o+a):s/(2-o-a),n=t==o?(e-r)/s+(e<r?6:0):e==o?(r-t)/s+2:(t-e)/s+4,n*=60):(n=NaN,i=l>0&&l<1?0:n),new qt(n,i,l)}function ue(t,e,r){var n=ee((.4124564*(t=fe(t))+.3575761*(e=fe(e))+.1804375*(r=fe(r)))/.95047),i=ee((.2126729*t+.7151522*e+.072175*r)/1);return Zt(116*i-16,500*(n-i),200*(i-ee((.0193339*t+.119192*e+.9503041*r)/1.08883)))}function fe(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function he(t){var e=parseFloat(t);return\"%\"===t.charAt(t.length-1)?Math.round(2.55*e):e}oe.brighter=function(t){t=Math.pow(.7,arguments.length?t:1);var e=this.r,r=this.g,n=this.b,i=30;return e||r||n?(e&&e<i&&(e=i),r&&r<i&&(r=i),n&&n<i&&(n=i),new ne(Math.min(255,e/t),Math.min(255,r/t),Math.min(255,n/t))):new ne(i,i,i)},oe.darker=function(t){return new ne((t=Math.pow(.7,arguments.length?t:1))*this.r,t*this.g,t*this.b)},oe.hsl=function(){return ce(this.r,this.g,this.b)},oe.toString=function(){return\"#\"+se(this.r)+se(this.g)+se(this.b)};var pe=t.map({aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074});function de(t){return\"function\"==typeof t?t:function(){return t}}function ge(t){return function(e,r,n){return 2===arguments.length&&\"function\"==typeof r&&(n=r,r=null),me(e,r,t,n)}}function me(e,r,i,a){var o={},s=t.dispatch(\"beforesend\",\"progress\",\"load\",\"error\"),l={},c=new XMLHttpRequest,u=null;function f(){var t,e=c.status;if(!e&&function(t){var e=t.responseType;return e&&\"text\"!==e?t.response:t.responseText}(c)||e>=200&&e<300||304===e){try{t=i.call(o,c)}catch(t){return void s.error.call(o,t)}s.load.call(o,t)}else s.error.call(o,c)}return this.XDomainRequest&&!(\"withCredentials\"in c)&&/^(http(s)?:)?\\/\\//.test(e)&&(c=new XDomainRequest),\"onload\"in c?c.onload=c.onerror=f:c.onreadystatechange=function(){c.readyState>3&&f()},c.onprogress=function(e){var r=t.event;t.event=e;try{s.progress.call(o,c)}finally{t.event=r}},o.header=function(t,e){return t=(t+\"\").toLowerCase(),arguments.length<2?l[t]:(null==e?delete l[t]:l[t]=e+\"\",o)},o.mimeType=function(t){return arguments.length?(r=null==t?null:t+\"\",o):r},o.responseType=function(t){return arguments.length?(u=t,o):u},o.response=function(t){return i=t,o},[\"get\",\"post\"].forEach((function(t){o[t]=function(){return o.send.apply(o,[t].concat(n(arguments)))}})),o.send=function(t,n,i){if(2===arguments.length&&\"function\"==typeof n&&(i=n,n=null),c.open(t,e,!0),null==r||\"accept\"in l||(l.accept=r+\",*/*\"),c.setRequestHeader)for(var a in l)c.setRequestHeader(a,l[a]);return null!=r&&c.overrideMimeType&&c.overrideMimeType(r),null!=u&&(c.responseType=u),null!=i&&o.on(\"error\",i).on(\"load\",(function(t){i(null,t)})),s.beforesend.call(o,c),c.send(null==n?null:n),o},o.abort=function(){return c.abort(),o},t.rebind(o,s,\"on\"),null==a?o:o.get(function(t){return 1===t.length?function(e,r){t(null==e?r:null)}:t}(a))}pe.forEach((function(t,e){pe.set(t,ie(e))})),t.functor=de,t.xhr=ge(L),t.dsv=function(t,e){var r=new RegExp('[\"'+t+\"\\n]\"),n=t.charCodeAt(0);function i(t,r,n){arguments.length<3&&(n=r,r=null);var i=me(t,e,null==r?a:o(r),n);return i.row=function(t){return arguments.length?i.response(null==(r=t)?a:o(t)):r},i}function a(t){return i.parse(t.responseText)}function o(t){return function(e){return i.parse(e.responseText,t)}}function s(e){return e.map(l).join(t)}function l(t){return r.test(t)?'\"'+t.replace(/\\\"/g,'\"\"')+'\"':t}return i.parse=function(t,e){var r;return i.parseRows(t,(function(t,n){if(r)return r(t,n-1);var i=new Function(\"d\",\"return {\"+t.map((function(t,e){return JSON.stringify(t)+\": d[\"+e+\"]\"})).join(\",\")+\"}\");r=e?function(t,r){return e(i(t),r)}:i}))},i.parseRows=function(t,e){var r,i,a={},o={},s=[],l=t.length,c=0,u=0;function f(){if(c>=l)return o;if(i)return i=!1,a;var e=c;if(34===t.charCodeAt(e)){for(var r=e;r++<l;)if(34===t.charCodeAt(r)){if(34!==t.charCodeAt(r+1))break;++r}return c=r+2,13===(s=t.charCodeAt(r+1))?(i=!0,10===t.charCodeAt(r+2)&&++c):10===s&&(i=!0),t.slice(e+1,r).replace(/\"\"/g,'\"')}for(;c<l;){var s,u=1;if(10===(s=t.charCodeAt(c++)))i=!0;else if(13===s)i=!0,10===t.charCodeAt(c)&&(++c,++u);else if(s!==n)continue;return t.slice(e,c-u)}return t.slice(e)}for(;(r=f())!==o;){for(var h=[];r!==a&&r!==o;)h.push(r),r=f();e&&null==(h=e(h,u++))||s.push(h)}return s},i.format=function(e){if(Array.isArray(e[0]))return i.formatRows(e);var r=new C,n=[];return e.forEach((function(t){for(var e in t)r.has(e)||n.push(r.add(e))})),[n.map(l).join(t)].concat(e.map((function(e){return n.map((function(t){return l(e[t])})).join(t)}))).join(\"\\n\")},i.formatRows=function(t){return t.map(s).join(\"\\n\")},i},t.csv=t.dsv(\",\",\"text/csv\"),t.tsv=t.dsv(\"\\t\",\"text/tab-separated-values\");var ve,ye,xe,be,_e=this[P(this,\"requestAnimationFrame\")]||function(t){setTimeout(t,17)};function we(t,e,r){var n=arguments.length;n<2&&(e=0),n<3&&(r=Date.now());var i=r+e,a={c:t,t:i,n:null};return ye?ye.n=a:ve=a,ye=a,xe||(be=clearTimeout(be),xe=1,_e(Te)),a}function Te(){var t=ke(),e=Me()-t;e>24?(isFinite(e)&&(clearTimeout(be),be=setTimeout(Te,e)),xe=0):(xe=1,_e(Te))}function ke(){for(var t=Date.now(),e=ve;e;)t>=e.t&&e.c(t-e.t)&&(e.c=null),e=e.n;return t}function Me(){for(var t,e=ve,r=1/0;e;)e.c?(e.t<r&&(r=e.t),e=(t=e).n):e=t?t.n=e.n:ve=e.n;return ye=t,r}function Ae(t,e){return e-(t?Math.ceil(Math.log(t)/Math.LN10):1)}t.timer=function(){we.apply(this,arguments)},t.timer.flush=function(){ke(),Me()},t.round=function(t,e){return e?Math.round(t*(e=Math.pow(10,e)))/e:Math.round(t)};var Se=[\"y\",\"z\",\"a\",\"f\",\"p\",\"n\",\"\\xb5\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\",\"P\",\"E\",\"Z\",\"Y\"].map((function(t,e){var r=Math.pow(10,3*y(8-e));return{scale:e>8?function(t){return t/r}:function(t){return t*r},symbol:t}}));function Ee(e){var r=e.decimal,n=e.thousands,i=e.grouping,a=e.currency,o=i&&n?function(t,e){for(var r=t.length,a=[],o=0,s=i[0],l=0;r>0&&s>0&&(l+s+1>e&&(s=Math.max(1,e-l)),a.push(t.substring(r-=s,r+s)),!((l+=s+1)>e));)s=i[o=(o+1)%i.length];return a.reverse().join(n)}:L;return function(e){var n=Ce.exec(e),i=n[1]||\" \",s=n[2]||\">\",l=n[3]||\"-\",c=n[4]||\"\",u=n[5],f=+n[6],h=n[7],p=n[8],d=n[9],g=1,m=\"\",v=\"\",y=!1,x=!0;switch(p&&(p=+p.substring(1)),(u||\"0\"===i&&\"=\"===s)&&(u=i=\"0\",s=\"=\"),d){case\"n\":h=!0,d=\"g\";break;case\"%\":g=100,v=\"%\",d=\"f\";break;case\"p\":g=100,v=\"%\",d=\"r\";break;case\"b\":case\"o\":case\"x\":case\"X\":\"#\"===c&&(m=\"0\"+d.toLowerCase());case\"c\":x=!1;case\"d\":y=!0,p=0;break;case\"s\":g=-1,d=\"r\"}\"$\"===c&&(m=a[0],v=a[1]),\"r\"!=d||p||(d=\"g\"),null!=p&&(\"g\"==d?p=Math.max(1,Math.min(21,p)):\"e\"!=d&&\"f\"!=d||(p=Math.max(0,Math.min(20,p)))),d=Le.get(d)||Ie;var b=u&&h;return function(e){var n=v;if(y&&e%1)return\"\";var a=e<0||0===e&&1/e<0?(e=-e,\"-\"):\"-\"===l?\"\":l;if(g<0){var c=t.formatPrefix(e,p);e=c.scale(e),n=c.symbol+v}else e*=g;var _,w,T=(e=d(e,p)).lastIndexOf(\".\");if(T<0){var k=x?e.lastIndexOf(\"e\"):-1;k<0?(_=e,w=\"\"):(_=e.substring(0,k),w=e.substring(k))}else _=e.substring(0,T),w=r+e.substring(T+1);!u&&h&&(_=o(_,1/0));var M=m.length+_.length+w.length+(b?0:a.length),A=M<f?new Array(M=f-M+1).join(i):\"\";return b&&(_=o(A+_,A.length?f-w.length:1/0)),a+=m,e=_+w,(\"<\"===s?a+e+A:\">\"===s?A+a+e:\"^\"===s?A.substring(0,M>>=1)+a+e+A.substring(M):a+(b?e:A+e))+n}}}t.formatPrefix=function(e,r){var n=0;return(e=+e)&&(e<0&&(e*=-1),r&&(e=t.round(e,Ae(e,r))),n=1+Math.floor(1e-12+Math.log(e)/Math.LN10),n=Math.max(-24,Math.min(24,3*Math.floor((n-1)/3)))),Se[8+n/3]};var Ce=/(?:([^{])?([<>=^]))?([+\\- ])?([$#])?(0)?(\\d+)?(,)?(\\.-?\\d+)?([a-z%])?/i,Le=t.map({b:function(t){return t.toString(2)},c:function(t){return String.fromCharCode(t)},o:function(t){return t.toString(8)},x:function(t){return t.toString(16)},X:function(t){return t.toString(16).toUpperCase()},g:function(t,e){return t.toPrecision(e)},e:function(t,e){return t.toExponential(e)},f:function(t,e){return t.toFixed(e)},r:function(e,r){return(e=t.round(e,Ae(e,r))).toFixed(Math.max(0,Math.min(20,Ae(e*(1+1e-15),r))))}});function Ie(t){return t+\"\"}var Pe=t.time={},ze=Date;function Oe(){this._=new Date(arguments.length>1?Date.UTC.apply(this,arguments):arguments[0])}Oe.prototype={getDate:function(){return this._.getUTCDate()},getDay:function(){return this._.getUTCDay()},getFullYear:function(){return this._.getUTCFullYear()},getHours:function(){return this._.getUTCHours()},getMilliseconds:function(){return this._.getUTCMilliseconds()},getMinutes:function(){return this._.getUTCMinutes()},getMonth:function(){return this._.getUTCMonth()},getSeconds:function(){return this._.getUTCSeconds()},getTime:function(){return this._.getTime()},getTimezoneOffset:function(){return 0},valueOf:function(){return this._.valueOf()},setDate:function(){De.setUTCDate.apply(this._,arguments)},setDay:function(){De.setUTCDay.apply(this._,arguments)},setFullYear:function(){De.setUTCFullYear.apply(this._,arguments)},setHours:function(){De.setUTCHours.apply(this._,arguments)},setMilliseconds:function(){De.setUTCMilliseconds.apply(this._,arguments)},setMinutes:function(){De.setUTCMinutes.apply(this._,arguments)},setMonth:function(){De.setUTCMonth.apply(this._,arguments)},setSeconds:function(){De.setUTCSeconds.apply(this._,arguments)},setTime:function(){De.setTime.apply(this._,arguments)}};var De=Date.prototype;function Re(t,e,r){function n(e){var r=t(e),n=a(r,1);return e-r<n-e?r:n}function i(r){return e(r=t(new ze(r-1)),1),r}function a(t,r){return e(t=new ze(+t),r),t}function o(t,n,a){var o=i(t),s=[];if(a>1)for(;o<n;)r(o)%a||s.push(new Date(+o)),e(o,1);else for(;o<n;)s.push(new Date(+o)),e(o,1);return s}t.floor=t,t.round=n,t.ceil=i,t.offset=a,t.range=o;var s=t.utc=Fe(t);return s.floor=s,s.round=Fe(n),s.ceil=Fe(i),s.offset=Fe(a),s.range=function(t,e,r){try{ze=Oe;var n=new Oe;return n._=t,o(n,e,r)}finally{ze=Date}},t}function Fe(t){return function(e,r){try{ze=Oe;var n=new Oe;return n._=e,t(n,r)._}finally{ze=Date}}}function Be(e){var r=e.dateTime,n=e.date,i=e.time,a=e.periods,o=e.days,s=e.shortDays,l=e.months,c=e.shortMonths;function u(t){var e=t.length;function r(r){for(var n,i,a,o=[],s=-1,l=0;++s<e;)37===t.charCodeAt(s)&&(o.push(t.slice(l,s)),null!=(i=Ne[n=t.charAt(++s)])&&(n=t.charAt(++s)),(a=_[n])&&(n=a(r,null==i?\"e\"===n?\" \":\"0\":i)),o.push(n),l=s+1);return o.push(t.slice(l,s)),o.join(\"\")}return r.parse=function(e){var r={y:1900,m:0,d:1,H:0,M:0,S:0,L:0,Z:null};if(f(r,t,e,0)!=e.length)return null;\"p\"in r&&(r.H=r.H%12+12*r.p);var n=null!=r.Z&&ze!==Oe,i=new(n?Oe:ze);return\"j\"in r?i.setFullYear(r.y,0,r.j):\"W\"in r||\"U\"in r?(\"w\"in r||(r.w=\"W\"in r?1:0),i.setFullYear(r.y,0,1),i.setFullYear(r.y,0,\"W\"in r?(r.w+6)%7+7*r.W-(i.getDay()+5)%7:r.w+7*r.U-(i.getDay()+6)%7)):i.setFullYear(r.y,r.m,r.d),i.setHours(r.H+(r.Z/100|0),r.M+r.Z%100,r.S,r.L),n?i._:i},r.toString=function(){return t},r}function f(t,e,r,n){for(var i,a,o,s=0,l=e.length,c=r.length;s<l;){if(n>=c)return-1;if(37===(i=e.charCodeAt(s++))){if(o=e.charAt(s++),!(a=w[o in Ne?e.charAt(s++):o])||(n=a(t,r,n))<0)return-1}else if(i!=r.charCodeAt(n++))return-1}return n}u.utc=function(t){var e=u(t);function r(t){try{var r=new(ze=Oe);return r._=t,e(r)}finally{ze=Date}}return r.parse=function(t){try{ze=Oe;var r=e.parse(t);return r&&r._}finally{ze=Date}},r.toString=e.toString,r},u.multi=u.utc.multi=or;var h=t.map(),p=qe(o),d=He(o),g=qe(s),m=He(s),v=qe(l),y=He(l),x=qe(c),b=He(c);a.forEach((function(t,e){h.set(t.toLowerCase(),e)}));var _={a:function(t){return s[t.getDay()]},A:function(t){return o[t.getDay()]},b:function(t){return c[t.getMonth()]},B:function(t){return l[t.getMonth()]},c:u(r),d:function(t,e){return Ve(t.getDate(),e,2)},e:function(t,e){return Ve(t.getDate(),e,2)},H:function(t,e){return Ve(t.getHours(),e,2)},I:function(t,e){return Ve(t.getHours()%12||12,e,2)},j:function(t,e){return Ve(1+Pe.dayOfYear(t),e,3)},L:function(t,e){return Ve(t.getMilliseconds(),e,3)},m:function(t,e){return Ve(t.getMonth()+1,e,2)},M:function(t,e){return Ve(t.getMinutes(),e,2)},p:function(t){return a[+(t.getHours()>=12)]},S:function(t,e){return Ve(t.getSeconds(),e,2)},U:function(t,e){return Ve(Pe.sundayOfYear(t),e,2)},w:function(t){return t.getDay()},W:function(t,e){return Ve(Pe.mondayOfYear(t),e,2)},x:u(n),X:u(i),y:function(t,e){return Ve(t.getFullYear()%100,e,2)},Y:function(t,e){return Ve(t.getFullYear()%1e4,e,4)},Z:ir,\"%\":function(){return\"%\"}},w={a:function(t,e,r){g.lastIndex=0;var n=g.exec(e.slice(r));return n?(t.w=m.get(n[0].toLowerCase()),r+n[0].length):-1},A:function(t,e,r){p.lastIndex=0;var n=p.exec(e.slice(r));return n?(t.w=d.get(n[0].toLowerCase()),r+n[0].length):-1},b:function(t,e,r){x.lastIndex=0;var n=x.exec(e.slice(r));return n?(t.m=b.get(n[0].toLowerCase()),r+n[0].length):-1},B:function(t,e,r){v.lastIndex=0;var n=v.exec(e.slice(r));return n?(t.m=y.get(n[0].toLowerCase()),r+n[0].length):-1},c:function(t,e,r){return f(t,_.c.toString(),e,r)},d:Qe,e:Qe,H:tr,I:tr,j:$e,L:nr,m:Ke,M:er,p:function(t,e,r){var n=h.get(e.slice(r,r+=2).toLowerCase());return null==n?-1:(t.p=n,r)},S:rr,U:Ye,w:Ge,W:We,x:function(t,e,r){return f(t,_.x.toString(),e,r)},X:function(t,e,r){return f(t,_.X.toString(),e,r)},y:Ze,Y:Xe,Z:Je,\"%\":ar};return u}Pe.year=Re((function(t){return(t=Pe.day(t)).setMonth(0,1),t}),(function(t,e){t.setFullYear(t.getFullYear()+e)}),(function(t){return t.getFullYear()})),Pe.years=Pe.year.range,Pe.years.utc=Pe.year.utc.range,Pe.day=Re((function(t){var e=new ze(2e3,0);return e.setFullYear(t.getFullYear(),t.getMonth(),t.getDate()),e}),(function(t,e){t.setDate(t.getDate()+e)}),(function(t){return t.getDate()-1})),Pe.days=Pe.day.range,Pe.days.utc=Pe.day.utc.range,Pe.dayOfYear=function(t){var e=Pe.year(t);return Math.floor((t-e-6e4*(t.getTimezoneOffset()-e.getTimezoneOffset()))/864e5)},[\"sunday\",\"monday\",\"tuesday\",\"wednesday\",\"thursday\",\"friday\",\"saturday\"].forEach((function(t,e){e=7-e;var r=Pe[t]=Re((function(t){return(t=Pe.day(t)).setDate(t.getDate()-(t.getDay()+e)%7),t}),(function(t,e){t.setDate(t.getDate()+7*Math.floor(e))}),(function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)-(r!==e)}));Pe[t+\"s\"]=r.range,Pe[t+\"s\"].utc=r.utc.range,Pe[t+\"OfYear\"]=function(t){var r=Pe.year(t).getDay();return Math.floor((Pe.dayOfYear(t)+(r+e)%7)/7)}})),Pe.week=Pe.sunday,Pe.weeks=Pe.sunday.range,Pe.weeks.utc=Pe.sunday.utc.range,Pe.weekOfYear=Pe.sundayOfYear;var Ne={\"-\":\"\",_:\" \",0:\"0\"},je=/^\\s*\\d+/,Ue=/^%/;function Ve(t,e,r){var n=t<0?\"-\":\"\",i=(n?-t:t)+\"\",a=i.length;return n+(a<r?new Array(r-a+1).join(e)+i:i)}function qe(e){return new RegExp(\"^(?:\"+e.map(t.requote).join(\"|\")+\")\",\"i\")}function He(t){for(var e=new _,r=-1,n=t.length;++r<n;)e.set(t[r].toLowerCase(),r);return e}function Ge(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+1));return n?(t.w=+n[0],r+n[0].length):-1}function Ye(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.U=+n[0],r+n[0].length):-1}function We(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r));return n?(t.W=+n[0],r+n[0].length):-1}function Xe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+4));return n?(t.y=+n[0],r+n[0].length):-1}function Ze(t,e,r){je.lastIndex=0;var n,i=je.exec(e.slice(r,r+2));return i?(t.y=(n=+i[0])+(n>68?1900:2e3),r+i[0].length):-1}function Je(t,e,r){return/^[+-]\\d{4}$/.test(e=e.slice(r,r+5))?(t.Z=-e,r+5):-1}function Ke(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.m=n[0]-1,r+n[0].length):-1}function Qe(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.d=+n[0],r+n[0].length):-1}function $e(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.j=+n[0],r+n[0].length):-1}function tr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.H=+n[0],r+n[0].length):-1}function er(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.M=+n[0],r+n[0].length):-1}function rr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+2));return n?(t.S=+n[0],r+n[0].length):-1}function nr(t,e,r){je.lastIndex=0;var n=je.exec(e.slice(r,r+3));return n?(t.L=+n[0],r+n[0].length):-1}function ir(t){var e=t.getTimezoneOffset(),r=e>0?\"-\":\"+\",n=y(e)/60|0,i=y(e)%60;return r+Ve(n,\"0\",2)+Ve(i,\"0\",2)}function ar(t,e,r){Ue.lastIndex=0;var n=Ue.exec(e.slice(r,r+1));return n?r+n[0].length:-1}function or(t){for(var e=t.length,r=-1;++r<e;)t[r][0]=this(t[r][0]);return function(e){for(var r=0,n=t[r];!n[1](e);)n=t[++r];return n[0](e)}}t.locale=function(t){return{numberFormat:Ee(t),timeFormat:Be(t)}};var sr=t.locale({decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],dateTime:\"%a %b %e %X %Y\",date:\"%m/%d/%Y\",time:\"%H:%M:%S\",periods:[\"AM\",\"PM\"],days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"]});function lr(){}t.format=sr.numberFormat,t.geo={},lr.prototype={s:0,t:0,add:function(t){ur(t,this.t,cr),ur(cr.s,this.s,this),this.s?this.t+=cr.t:this.s=cr.t},reset:function(){this.s=this.t=0},valueOf:function(){return this.s}};var cr=new lr;function ur(t,e,r){var n=r.s=t+e,i=n-t,a=n-i;r.t=t-a+(e-i)}function fr(t,e){t&&pr.hasOwnProperty(t.type)&&pr[t.type](t,e)}t.geo.stream=function(t,e){t&&hr.hasOwnProperty(t.type)?hr[t.type](t,e):fr(t,e)};var hr={Feature:function(t,e){fr(t.geometry,e)},FeatureCollection:function(t,e){for(var r=t.features,n=-1,i=r.length;++n<i;)fr(r[n].geometry,e)}},pr={Sphere:function(t,e){e.sphere()},Point:function(t,e){t=t.coordinates,e.point(t[0],t[1],t[2])},MultiPoint:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)t=r[n],e.point(t[0],t[1],t[2])},LineString:function(t,e){dr(t.coordinates,e,0)},MultiLineString:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)dr(r[n],e,0)},Polygon:function(t,e){gr(t.coordinates,e)},MultiPolygon:function(t,e){for(var r=t.coordinates,n=-1,i=r.length;++n<i;)gr(r[n],e)},GeometryCollection:function(t,e){for(var r=t.geometries,n=-1,i=r.length;++n<i;)fr(r[n],e)}};function dr(t,e,r){var n,i=-1,a=t.length-r;for(e.lineStart();++i<a;)n=t[i],e.point(n[0],n[1],n[2]);e.lineEnd()}function gr(t,e){var r=-1,n=t.length;for(e.polygonStart();++r<n;)dr(t[r],e,1);e.polygonEnd()}t.geo.area=function(e){return mr=0,t.geo.stream(e,Cr),mr};var mr,vr,yr,xr,br,_r,wr,Tr,kr,Mr,Ar,Sr,Er=new lr,Cr={sphere:function(){mr+=4*At},point:O,lineStart:O,lineEnd:O,polygonStart:function(){Er.reset(),Cr.lineStart=Lr},polygonEnd:function(){var t=2*Er;mr+=t<0?4*At+t:t,Cr.lineStart=Cr.lineEnd=Cr.point=O}};function Lr(){var t,e,r,n,i;function a(t,e){e=e*Lt/2+At/4;var a=(t*=Lt)-r,o=a>=0?1:-1,s=o*a,l=Math.cos(e),c=Math.sin(e),u=i*c,f=n*l+u*Math.cos(s),h=u*o*Math.sin(s);Er.add(Math.atan2(h,f)),r=t,n=l,i=c}Cr.point=function(o,s){Cr.point=a,r=(t=o)*Lt,n=Math.cos(s=(e=s)*Lt/2+At/4),i=Math.sin(s)},Cr.lineEnd=function(){a(t,e)}}function Ir(t){var e=t[0],r=t[1],n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}function Pr(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}function zr(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}function Or(t,e){t[0]+=e[0],t[1]+=e[1],t[2]+=e[2]}function Dr(t,e){return[t[0]*e,t[1]*e,t[2]*e]}function Rr(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]+t[2]*t[2]);t[0]/=e,t[1]/=e,t[2]/=e}function Fr(t){return[Math.atan2(t[1],t[0]),Dt(t[2])]}function Br(t,e){return y(t[0]-e[0])<kt&&y(t[1]-e[1])<kt}t.geo.bounds=function(){var e,r,n,i,a,o,s,l,c,u,f,h={point:p,lineStart:g,lineEnd:m,polygonStart:function(){h.point=v,h.lineStart=x,h.lineEnd=b,c=0,Cr.polygonStart()},polygonEnd:function(){Cr.polygonEnd(),h.point=p,h.lineStart=g,h.lineEnd=m,Er<0?(e=-(n=180),r=-(i=90)):c>kt?i=90:c<-kt&&(r=-90),f[0]=e,f[1]=n}};function p(t,a){u.push(f=[e=t,n=t]),a<r&&(r=a),a>i&&(i=a)}function d(t,o){var s=Ir([t*Lt,o*Lt]);if(l){var c=zr(l,s),u=zr([c[1],-c[0],0],c);Rr(u),u=Fr(u);var f=t-a,h=f>0?1:-1,d=u[0]*It*h,g=y(f)>180;if(g^(h*a<d&&d<h*t))(m=u[1]*It)>i&&(i=m);else if(g^(h*a<(d=(d+360)%360-180)&&d<h*t)){var m;(m=-u[1]*It)<r&&(r=m)}else o<r&&(r=o),o>i&&(i=o);g?t<a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t):n>=e?(t<e&&(e=t),t>n&&(n=t)):t>a?_(e,t)>_(e,n)&&(n=t):_(t,n)>_(e,n)&&(e=t)}else p(t,o);l=s,a=t}function g(){h.point=d}function m(){f[0]=e,f[1]=n,h.point=p,l=null}function v(t,e){if(l){var r=t-a;c+=y(r)>180?r+(r>0?360:-360):r}else o=t,s=e;Cr.point(t,e),d(t,e)}function x(){Cr.lineStart()}function b(){v(o,s),Cr.lineEnd(),y(c)>kt&&(e=-(n=180)),f[0]=e,f[1]=n,l=null}function _(t,e){return(e-=t)<0?e+360:e}function w(t,e){return t[0]-e[0]}function T(t,e){return e[0]<=e[1]?e[0]<=t&&t<=e[1]:t<e[0]||e[1]<t}return function(a){if(i=n=-(e=r=1/0),u=[],t.geo.stream(a,h),c=u.length){u.sort(w);for(var o=1,s=[g=u[0]];o<c;++o)T((p=u[o])[0],g)||T(p[1],g)?(_(g[0],p[1])>_(g[0],g[1])&&(g[1]=p[1]),_(p[0],g[1])>_(g[0],g[1])&&(g[0]=p[0])):s.push(g=p);for(var l,c,p,d=-1/0,g=(o=0,s[c=s.length-1]);o<=c;g=p,++o)p=s[o],(l=_(g[1],p[0]))>d&&(d=l,e=p[0],n=g[1])}return u=f=null,e===1/0||r===1/0?[[NaN,NaN],[NaN,NaN]]:[[e,r],[n,i]]}}(),t.geo.centroid=function(e){vr=yr=xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,Nr);var r=Mr,n=Ar,i=Sr,a=r*r+n*n+i*i;return a<Mt&&(r=wr,n=Tr,i=kr,yr<kt&&(r=xr,n=br,i=_r),(a=r*r+n*n+i*i)<Mt)?[NaN,NaN]:[Math.atan2(n,r)*It,Dt(i/Math.sqrt(a))*It]};var Nr={sphere:O,point:jr,lineStart:Vr,lineEnd:qr,polygonStart:function(){Nr.lineStart=Hr},polygonEnd:function(){Nr.lineStart=Vr}};function jr(t,e){t*=Lt;var r=Math.cos(e*=Lt);Ur(r*Math.cos(t),r*Math.sin(t),Math.sin(e))}function Ur(t,e,r){++vr,xr+=(t-xr)/vr,br+=(e-br)/vr,_r+=(r-_r)/vr}function Vr(){var t,e,r;function n(n,i){n*=Lt;var a=Math.cos(i*=Lt),o=a*Math.cos(n),s=a*Math.sin(n),l=Math.sin(i),c=Math.atan2(Math.sqrt((c=e*l-r*s)*c+(c=r*o-t*l)*c+(c=t*s-e*o)*c),t*o+e*s+r*l);yr+=c,wr+=c*(t+(t=o)),Tr+=c*(e+(e=s)),kr+=c*(r+(r=l)),Ur(t,e,r)}Nr.point=function(i,a){i*=Lt;var o=Math.cos(a*=Lt);t=o*Math.cos(i),e=o*Math.sin(i),r=Math.sin(a),Nr.point=n,Ur(t,e,r)}}function qr(){Nr.point=jr}function Hr(){var t,e,r,n,i;function a(t,e){t*=Lt;var a=Math.cos(e*=Lt),o=a*Math.cos(t),s=a*Math.sin(t),l=Math.sin(e),c=n*l-i*s,u=i*o-r*l,f=r*s-n*o,h=Math.sqrt(c*c+u*u+f*f),p=r*o+n*s+i*l,d=h&&-Ot(p)/h,g=Math.atan2(h,p);Mr+=d*c,Ar+=d*u,Sr+=d*f,yr+=g,wr+=g*(r+(r=o)),Tr+=g*(n+(n=s)),kr+=g*(i+(i=l)),Ur(r,n,i)}Nr.point=function(o,s){t=o,e=s,Nr.point=a,o*=Lt;var l=Math.cos(s*=Lt);r=l*Math.cos(o),n=l*Math.sin(o),i=Math.sin(s),Ur(r,n,i)},Nr.lineEnd=function(){a(t,e),Nr.lineEnd=qr,Nr.point=jr}}function Gr(t,e){function r(r,n){return r=t(r,n),e(r[0],r[1])}return t.invert&&e.invert&&(r.invert=function(r,n){return(r=e.invert(r,n))&&t.invert(r[0],r[1])}),r}function Yr(){return!0}function Wr(t,e,r,n,i){var a=[],o=[];if(t.forEach((function(t){if(!((e=t.length-1)<=0)){var e,r=t[0],n=t[e];if(Br(r,n)){i.lineStart();for(var s=0;s<e;++s)i.point((r=t[s])[0],r[1]);i.lineEnd()}else{var l=new Zr(r,t,null,!0),c=new Zr(r,null,l,!1);l.o=c,a.push(l),o.push(c),l=new Zr(n,t,null,!1),c=new Zr(n,null,l,!0),l.o=c,a.push(l),o.push(c)}}})),o.sort(e),Xr(a),Xr(o),a.length){for(var s=0,l=r,c=o.length;s<c;++s)o[s].e=l=!l;for(var u,f,h=a[0];;){for(var p=h,d=!0;p.v;)if((p=p.n)===h)return;u=p.z,i.lineStart();do{if(p.v=p.o.v=!0,p.e){if(d)for(s=0,c=u.length;s<c;++s)i.point((f=u[s])[0],f[1]);else n(p.x,p.n.x,1,i);p=p.n}else{if(d)for(s=(u=p.p.z).length-1;s>=0;--s)i.point((f=u[s])[0],f[1]);else n(p.x,p.p.x,-1,i);p=p.p}u=(p=p.o).z,d=!d}while(!p.v);i.lineEnd()}}}function Xr(t){if(e=t.length){for(var e,r,n=0,i=t[0];++n<e;)i.n=r=t[n],r.p=i,i=r;i.n=r=t[0],r.p=i}}function Zr(t,e,r,n){this.x=t,this.z=e,this.o=r,this.e=n,this.v=!1,this.n=this.p=null}function Jr(e,r,n,i){return function(a,o){var s,l=r(o),c=a.invert(i[0],i[1]),u={point:f,lineStart:p,lineEnd:d,polygonStart:function(){u.point=b,u.lineStart=_,u.lineEnd=w,s=[],g=[]},polygonEnd:function(){u.point=f,u.lineStart=p,u.lineEnd=d,s=t.merge(s);var e=function(t,e){var r=t[0],n=t[1],i=[Math.sin(r),-Math.cos(r),0],a=0,o=0;Er.reset();for(var s=0,l=e.length;s<l;++s){var c=e[s],u=c.length;if(u)for(var f=c[0],h=f[0],p=f[1]/2+At/4,d=Math.sin(p),g=Math.cos(p),m=1;;){m===u&&(m=0);var v=(t=c[m])[0],y=t[1]/2+At/4,x=Math.sin(y),b=Math.cos(y),_=v-h,w=_>=0?1:-1,T=w*_,k=T>At,M=d*x;if(Er.add(Math.atan2(M*w*Math.sin(T),g*b+M*Math.cos(T))),a+=k?_+w*St:_,k^h>=r^v>=r){var A=zr(Ir(f),Ir(t));Rr(A);var S=zr(i,A);Rr(S);var E=(k^_>=0?-1:1)*Dt(S[2]);(n>E||n===E&&(A[0]||A[1]))&&(o+=k^_>=0?1:-1)}if(!m++)break;h=v,d=x,g=b,f=t}}return(a<-kt||a<kt&&Er<-kt)^1&o}(c,g);s.length?(x||(o.polygonStart(),x=!0),Wr(s,$r,e,n,o)):e&&(x||(o.polygonStart(),x=!0),o.lineStart(),n(null,null,1,o),o.lineEnd()),x&&(o.polygonEnd(),x=!1),s=g=null},sphere:function(){o.polygonStart(),o.lineStart(),n(null,null,1,o),o.lineEnd(),o.polygonEnd()}};function f(t,r){var n=a(t,r);e(t=n[0],r=n[1])&&o.point(t,r)}function h(t,e){var r=a(t,e);l.point(r[0],r[1])}function p(){u.point=h,l.lineStart()}function d(){u.point=f,l.lineEnd()}var g,m,v=Qr(),y=r(v),x=!1;function b(t,e){m.push([t,e]);var r=a(t,e);y.point(r[0],r[1])}function _(){y.lineStart(),m=[]}function w(){b(m[0][0],m[0][1]),y.lineEnd();var t,e=y.clean(),r=v.buffer(),n=r.length;if(m.pop(),g.push(m),m=null,n)if(1&e){var i,a=-1;if((n=(t=r[0]).length-1)>0){for(x||(o.polygonStart(),x=!0),o.lineStart();++a<n;)o.point((i=t[a])[0],i[1]);o.lineEnd()}}else n>1&&2&e&&r.push(r.pop().concat(r.shift())),s.push(r.filter(Kr))}return u}}function Kr(t){return t.length>1}function Qr(){var t,e=[];return{lineStart:function(){e.push(t=[])},point:function(e,r){t.push([e,r])},lineEnd:O,buffer:function(){var r=e;return e=[],t=null,r},rejoin:function(){e.length>1&&e.push(e.pop().concat(e.shift()))}}}function $r(t,e){return((t=t.x)[0]<0?t[1]-Ct-kt:Ct-t[1])-((e=e.x)[0]<0?e[1]-Ct-kt:Ct-e[1])}var tn=Jr(Yr,(function(t){var e,r=NaN,n=NaN,i=NaN;return{lineStart:function(){t.lineStart(),e=1},point:function(a,o){var s=a>0?At:-At,l=y(a-r);y(l-At)<kt?(t.point(r,n=(n+o)/2>0?Ct:-Ct),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),t.point(a,n),e=0):i!==s&&l>=At&&(y(r-i)<kt&&(r-=i*kt),y(a-s)<kt&&(a-=s*kt),n=function(t,e,r,n){var i,a,o=Math.sin(t-r);return y(o)>kt?Math.atan((Math.sin(e)*(a=Math.cos(n))*Math.sin(r)-Math.sin(n)*(i=Math.cos(e))*Math.sin(t))/(i*a*o)):(e+n)/2}(r,n,a,o),t.point(i,n),t.lineEnd(),t.lineStart(),t.point(s,n),e=0),t.point(r=a,n=o),i=s},lineEnd:function(){t.lineEnd(),r=n=NaN},clean:function(){return 2-e}}}),(function(t,e,r,n){var i;if(null==t)i=r*Ct,n.point(-At,i),n.point(0,i),n.point(At,i),n.point(At,0),n.point(At,-i),n.point(0,-i),n.point(-At,-i),n.point(-At,0),n.point(-At,i);else if(y(t[0]-e[0])>kt){var a=t[0]<e[0]?At:-At;i=r*a/2,n.point(-a,i),n.point(0,i),n.point(a,i)}else n.point(e[0],e[1])}),[-At,-At/2]);function en(t){var e=Math.cos(t),r=e>0,n=y(e)>kt;return Jr(i,(function(t){var e,s,l,c,u;return{lineStart:function(){c=l=!1,u=1},point:function(f,h){var p,d=[f,h],g=i(f,h),m=r?g?0:o(f,h):g?o(f+(f<0?At:-At),h):0;if(!e&&(c=l=g)&&t.lineStart(),g!==l&&(p=a(e,d),(Br(e,p)||Br(d,p))&&(d[0]+=kt,d[1]+=kt,g=i(d[0],d[1]))),g!==l)u=0,g?(t.lineStart(),p=a(d,e),t.point(p[0],p[1])):(p=a(e,d),t.point(p[0],p[1]),t.lineEnd()),e=p;else if(n&&e&&r^g){var v;m&s||!(v=a(d,e,!0))||(u=0,r?(t.lineStart(),t.point(v[0][0],v[0][1]),t.point(v[1][0],v[1][1]),t.lineEnd()):(t.point(v[1][0],v[1][1]),t.lineEnd(),t.lineStart(),t.point(v[0][0],v[0][1])))}!g||e&&Br(e,d)||t.point(d[0],d[1]),e=d,l=g,s=m},lineEnd:function(){l&&t.lineEnd(),e=null},clean:function(){return u|(c&&l)<<1}}}),Bn(t,6*Lt),r?[0,-t]:[-At,t-At]);function i(t,r){return Math.cos(t)*Math.cos(r)>e}function a(t,r,n){var i=[1,0,0],a=zr(Ir(t),Ir(r)),o=Pr(a,a),s=a[0],l=o-s*s;if(!l)return!n&&t;var c=e*o/l,u=-e*s/l,f=zr(i,a),h=Dr(i,c);Or(h,Dr(a,u));var p=f,d=Pr(h,p),g=Pr(p,p),m=d*d-g*(Pr(h,h)-1);if(!(m<0)){var v=Math.sqrt(m),x=Dr(p,(-d-v)/g);if(Or(x,h),x=Fr(x),!n)return x;var b,_=t[0],w=r[0],T=t[1],k=r[1];w<_&&(b=_,_=w,w=b);var M=w-_,A=y(M-At)<kt;if(!A&&k<T&&(b=T,T=k,k=b),A||M<kt?A?T+k>0^x[1]<(y(x[0]-_)<kt?T:k):T<=x[1]&&x[1]<=k:M>At^(_<=x[0]&&x[0]<=w)){var S=Dr(p,(-d+v)/g);return Or(S,h),[x,Fr(S)]}}}function o(e,n){var i=r?t:At-t,a=0;return e<-i?a|=1:e>i&&(a|=2),n<-i?a|=4:n>i&&(a|=8),a}}function rn(t,e,r,n){return function(i){var a,o=i.a,s=i.b,l=o.x,c=o.y,u=0,f=1,h=s.x-l,p=s.y-c;if(a=t-l,h||!(a>0)){if(a/=h,h<0){if(a<u)return;a<f&&(f=a)}else if(h>0){if(a>f)return;a>u&&(u=a)}if(a=r-l,h||!(a<0)){if(a/=h,h<0){if(a>f)return;a>u&&(u=a)}else if(h>0){if(a<u)return;a<f&&(f=a)}if(a=e-c,p||!(a>0)){if(a/=p,p<0){if(a<u)return;a<f&&(f=a)}else if(p>0){if(a>f)return;a>u&&(u=a)}if(a=n-c,p||!(a<0)){if(a/=p,p<0){if(a>f)return;a>u&&(u=a)}else if(p>0){if(a<u)return;a<f&&(f=a)}return u>0&&(i.a={x:l+u*h,y:c+u*p}),f<1&&(i.b={x:l+f*h,y:c+f*p}),i}}}}}}function nn(e,r,n,i){return function(l){var c,u,f,h,p,d,g,m,v,y,x,b=l,_=Qr(),w=rn(e,r,n,i),T={point:A,lineStart:function(){T.point=S,u&&u.push(f=[]);y=!0,v=!1,g=m=NaN},lineEnd:function(){c&&(S(h,p),d&&v&&_.rejoin(),c.push(_.buffer()));T.point=A,v&&l.lineEnd()},polygonStart:function(){l=_,c=[],u=[],x=!0},polygonEnd:function(){l=b,c=t.merge(c);var r=function(t){for(var e=0,r=u.length,n=t[1],i=0;i<r;++i)for(var a,o=1,s=u[i],l=s.length,c=s[0];o<l;++o)a=s[o],c[1]<=n?a[1]>n&&zt(c,a,t)>0&&++e:a[1]<=n&&zt(c,a,t)<0&&--e,c=a;return 0!==e}([e,i]),n=x&&r,a=c.length;(n||a)&&(l.polygonStart(),n&&(l.lineStart(),k(null,null,1,l),l.lineEnd()),a&&Wr(c,o,r,k,l),l.polygonEnd()),c=u=f=null}};function k(t,o,l,c){var u=0,f=0;if(null==t||(u=a(t,l))!==(f=a(o,l))||s(t,o)<0^l>0)do{c.point(0===u||3===u?e:n,u>1?i:r)}while((u=(u+l+4)%4)!==f);else c.point(o[0],o[1])}function M(t,a){return e<=t&&t<=n&&r<=a&&a<=i}function A(t,e){M(t,e)&&l.point(t,e)}function S(t,e){var r=M(t=Math.max(-1e9,Math.min(1e9,t)),e=Math.max(-1e9,Math.min(1e9,e)));if(u&&f.push([t,e]),y)h=t,p=e,d=r,y=!1,r&&(l.lineStart(),l.point(t,e));else if(r&&v)l.point(t,e);else{var n={a:{x:g,y:m},b:{x:t,y:e}};w(n)?(v||(l.lineStart(),l.point(n.a.x,n.a.y)),l.point(n.b.x,n.b.y),r||l.lineEnd(),x=!1):r&&(l.lineStart(),l.point(t,e),x=!1)}g=t,m=e,v=r}return T};function a(t,i){return y(t[0]-e)<kt?i>0?0:3:y(t[0]-n)<kt?i>0?2:1:y(t[1]-r)<kt?i>0?1:0:i>0?3:2}function o(t,e){return s(t.x,e.x)}function s(t,e){var r=a(t,1),n=a(e,1);return r!==n?r-n:0===r?e[1]-t[1]:1===r?t[0]-e[0]:2===r?t[1]-e[1]:e[0]-t[0]}}function an(t){var e=0,r=At/3,n=Ln(t),i=n(e,r);return i.parallels=function(t){return arguments.length?n(e=t[0]*At/180,r=t[1]*At/180):[e/At*180,r/At*180]},i}function on(t,e){var r=Math.sin(t),n=(r+Math.sin(e))/2,i=1+r*(2*n-r),a=Math.sqrt(i)/n;function o(t,e){var r=Math.sqrt(i-2*n*Math.sin(e))/n;return[r*Math.sin(t*=n),a-r*Math.cos(t)]}return o.invert=function(t,e){var r=a-e;return[Math.atan2(t,r)/n,Dt((i-(t*t+r*r)*n*n)/(2*n))]},o}t.geo.clipExtent=function(){var t,e,r,n,i,a,o={stream:function(t){return i&&(i.valid=!1),(i=a(t)).valid=!0,i},extent:function(s){return arguments.length?(a=nn(t=+s[0][0],e=+s[0][1],r=+s[1][0],n=+s[1][1]),i&&(i.valid=!1,i=null),o):[[t,e],[r,n]]}};return o.extent([[0,0],[960,500]])},(t.geo.conicEqualArea=function(){return an(on)}).raw=on,t.geo.albers=function(){return t.geo.conicEqualArea().rotate([96,0]).center([-.6,38.7]).parallels([29.5,45.5]).scale(1070)},t.geo.albersUsa=function(){var e,r,n,i,a=t.geo.albers(),o=t.geo.conicEqualArea().rotate([154,0]).center([-2,58.5]).parallels([55,65]),s=t.geo.conicEqualArea().rotate([157,0]).center([-3,19.9]).parallels([8,18]),l={point:function(t,r){e=[t,r]}};function c(t){var a=t[0],o=t[1];return e=null,r(a,o),e||(n(a,o),e)||i(a,o),e}return c.invert=function(t){var e=a.scale(),r=a.translate(),n=(t[0]-r[0])/e,i=(t[1]-r[1])/e;return(i>=.12&&i<.234&&n>=-.425&&n<-.214?o:i>=.166&&i<.234&&n>=-.214&&n<-.115?s:a).invert(t)},c.stream=function(t){var e=a.stream(t),r=o.stream(t),n=s.stream(t);return{point:function(t,i){e.point(t,i),r.point(t,i),n.point(t,i)},sphere:function(){e.sphere(),r.sphere(),n.sphere()},lineStart:function(){e.lineStart(),r.lineStart(),n.lineStart()},lineEnd:function(){e.lineEnd(),r.lineEnd(),n.lineEnd()},polygonStart:function(){e.polygonStart(),r.polygonStart(),n.polygonStart()},polygonEnd:function(){e.polygonEnd(),r.polygonEnd(),n.polygonEnd()}}},c.precision=function(t){return arguments.length?(a.precision(t),o.precision(t),s.precision(t),c):a.precision()},c.scale=function(t){return arguments.length?(a.scale(t),o.scale(.35*t),s.scale(t),c.translate(a.translate())):a.scale()},c.translate=function(t){if(!arguments.length)return a.translate();var e=a.scale(),u=+t[0],f=+t[1];return r=a.translate(t).clipExtent([[u-.455*e,f-.238*e],[u+.455*e,f+.238*e]]).stream(l).point,n=o.translate([u-.307*e,f+.201*e]).clipExtent([[u-.425*e+kt,f+.12*e+kt],[u-.214*e-kt,f+.234*e-kt]]).stream(l).point,i=s.translate([u-.205*e,f+.212*e]).clipExtent([[u-.214*e+kt,f+.166*e+kt],[u-.115*e-kt,f+.234*e-kt]]).stream(l).point,c},c.scale(1070)};var sn,ln,cn,un,fn,hn,pn={point:O,lineStart:O,lineEnd:O,polygonStart:function(){ln=0,pn.lineStart=dn},polygonEnd:function(){pn.lineStart=pn.lineEnd=pn.point=O,sn+=y(ln/2)}};function dn(){var t,e,r,n;function i(t,e){ln+=n*t-r*e,r=t,n=e}pn.point=function(a,o){pn.point=i,t=r=a,e=n=o},pn.lineEnd=function(){i(t,e)}}var gn={point:function(t,e){t<cn&&(cn=t);t>fn&&(fn=t);e<un&&(un=e);e>hn&&(hn=e)},lineStart:O,lineEnd:O,polygonStart:O,polygonEnd:O};function mn(){var t=vn(4.5),e=[],r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(e){return t=vn(e),r},result:function(){if(e.length){var t=e.join(\"\");return e=[],t}}};function n(r,n){e.push(\"M\",r,\",\",n,t)}function i(t,n){e.push(\"M\",t,\",\",n),r.point=a}function a(t,r){e.push(\"L\",t,\",\",r)}function o(){r.point=n}function s(){e.push(\"Z\")}return r}function vn(t){return\"m0,\"+t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+-2*t+\"a\"+t+\",\"+t+\" 0 1,1 0,\"+2*t+\"z\"}var yn,xn={point:bn,lineStart:_n,lineEnd:wn,polygonStart:function(){xn.lineStart=Tn},polygonEnd:function(){xn.point=bn,xn.lineStart=_n,xn.lineEnd=wn}};function bn(t,e){xr+=t,br+=e,++_r}function _n(){var t,e;function r(r,n){var i=r-t,a=n-e,o=Math.sqrt(i*i+a*a);wr+=o*(t+r)/2,Tr+=o*(e+n)/2,kr+=o,bn(t=r,e=n)}xn.point=function(n,i){xn.point=r,bn(t=n,e=i)}}function wn(){xn.point=bn}function Tn(){var t,e,r,n;function i(t,e){var i=t-r,a=e-n,o=Math.sqrt(i*i+a*a);wr+=o*(r+t)/2,Tr+=o*(n+e)/2,kr+=o,Mr+=(o=n*t-r*e)*(r+t),Ar+=o*(n+e),Sr+=3*o,bn(r=t,n=e)}xn.point=function(a,o){xn.point=i,bn(t=r=a,e=n=o)},xn.lineEnd=function(){i(t,e)}}function kn(t){var e=4.5,r={point:n,lineStart:function(){r.point=i},lineEnd:o,polygonStart:function(){r.lineEnd=s},polygonEnd:function(){r.lineEnd=o,r.point=n},pointRadius:function(t){return e=t,r},result:O};function n(r,n){t.moveTo(r+e,n),t.arc(r,n,e,0,St)}function i(e,n){t.moveTo(e,n),r.point=a}function a(e,r){t.lineTo(e,r)}function o(){r.point=n}function s(){t.closePath()}return r}function Mn(t){var e=.5,r=Math.cos(30*Lt),n=16;function i(t){return(n?o:a)(t)}function a(e){return En(e,(function(r,n){r=t(r,n),e.point(r[0],r[1])}))}function o(e){var r,i,a,o,l,c,u,f,h,p,d,g,m={point:v,lineStart:y,lineEnd:b,polygonStart:function(){e.polygonStart(),m.lineStart=_},polygonEnd:function(){e.polygonEnd(),m.lineStart=y}};function v(r,n){r=t(r,n),e.point(r[0],r[1])}function y(){f=NaN,m.point=x,e.lineStart()}function x(r,i){var a=Ir([r,i]),o=t(r,i);s(f,h,u,p,d,g,f=o[0],h=o[1],u=r,p=a[0],d=a[1],g=a[2],n,e),e.point(f,h)}function b(){m.point=v,e.lineEnd()}function _(){y(),m.point=w,m.lineEnd=T}function w(t,e){x(r=t,e),i=f,a=h,o=p,l=d,c=g,m.point=x}function T(){s(f,h,u,p,d,g,i,a,r,o,l,c,n,e),m.lineEnd=b,b()}return m}function s(n,i,a,o,l,c,u,f,h,p,d,g,m,v){var x=u-n,b=f-i,_=x*x+b*b;if(_>4*e&&m--){var w=o+p,T=l+d,k=c+g,M=Math.sqrt(w*w+T*T+k*k),A=Math.asin(k/=M),S=y(y(k)-1)<kt||y(a-h)<kt?(a+h)/2:Math.atan2(T,w),E=t(S,A),C=E[0],L=E[1],I=C-n,P=L-i,z=b*I-x*P;(z*z/_>e||y((x*I+b*P)/_-.5)>.3||o*p+l*d+c*g<r)&&(s(n,i,a,o,l,c,C,L,S,w/=M,T/=M,k,m,v),v.point(C,L),s(C,L,S,w,T,k,u,f,h,p,d,g,m,v))}}return i.precision=function(t){return arguments.length?(n=(e=t*t)>0&&16,i):Math.sqrt(e)},i}function An(t){var e=Mn((function(e,r){return t([e*It,r*It])}));return function(t){return In(e(t))}}function Sn(t){this.stream=t}function En(t,e){return{point:e,sphere:function(){t.sphere()},lineStart:function(){t.lineStart()},lineEnd:function(){t.lineEnd()},polygonStart:function(){t.polygonStart()},polygonEnd:function(){t.polygonEnd()}}}function Cn(t){return Ln((function(){return t}))()}function Ln(e){var r,n,i,a,o,s,l=Mn((function(t,e){return[(t=r(t,e))[0]*c+a,o-t[1]*c]})),c=150,u=480,f=250,h=0,p=0,d=0,g=0,m=0,v=tn,y=L,x=null,b=null;function _(t){return[(t=i(t[0]*Lt,t[1]*Lt))[0]*c+a,o-t[1]*c]}function w(t){return(t=i.invert((t[0]-a)/c,(o-t[1])/c))&&[t[0]*It,t[1]*It]}function T(){i=Gr(n=On(d,g,m),r);var t=r(h,p);return a=u-t[0]*c,o=f+t[1]*c,k()}function k(){return s&&(s.valid=!1,s=null),_}return _.stream=function(t){return s&&(s.valid=!1),(s=In(v(n,l(y(t))))).valid=!0,s},_.clipAngle=function(t){return arguments.length?(v=null==t?(x=t,tn):en((x=+t)*Lt),k()):x},_.clipExtent=function(t){return arguments.length?(b=t,y=t?nn(t[0][0],t[0][1],t[1][0],t[1][1]):L,k()):b},_.scale=function(t){return arguments.length?(c=+t,T()):c},_.translate=function(t){return arguments.length?(u=+t[0],f=+t[1],T()):[u,f]},_.center=function(t){return arguments.length?(h=t[0]%360*Lt,p=t[1]%360*Lt,T()):[h*It,p*It]},_.rotate=function(t){return arguments.length?(d=t[0]%360*Lt,g=t[1]%360*Lt,m=t.length>2?t[2]%360*Lt:0,T()):[d*It,g*It,m*It]},t.rebind(_,l,\"precision\"),function(){return r=e.apply(this,arguments),_.invert=r.invert&&w,T()}}function In(t){return En(t,(function(e,r){t.point(e*Lt,r*Lt)}))}function Pn(t,e){return[t,e]}function zn(t,e){return[t>At?t-St:t<-At?t+St:t,e]}function On(t,e,r){return t?e||r?Gr(Rn(t),Fn(e,r)):Rn(t):e||r?Fn(e,r):zn}function Dn(t){return function(e,r){return[(e+=t)>At?e-St:e<-At?e+St:e,r]}}function Rn(t){var e=Dn(t);return e.invert=Dn(-t),e}function Fn(t,e){var r=Math.cos(t),n=Math.sin(t),i=Math.cos(e),a=Math.sin(e);function o(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*r+s*n;return[Math.atan2(l*i-u*a,s*r-c*n),Dt(u*i+l*a)]}return o.invert=function(t,e){var o=Math.cos(e),s=Math.cos(t)*o,l=Math.sin(t)*o,c=Math.sin(e),u=c*i-l*a;return[Math.atan2(l*i+c*a,s*r+u*n),Dt(u*r-s*n)]},o}function Bn(t,e){var r=Math.cos(t),n=Math.sin(t);return function(i,a,o,s){var l=o*e;null!=i?(i=Nn(r,i),a=Nn(r,a),(o>0?i<a:i>a)&&(i+=o*St)):(i=t+o*St,a=t-.5*l);for(var c,u=i;o>0?u>a:u<a;u-=l)s.point((c=Fr([r,-n*Math.cos(u),-n*Math.sin(u)]))[0],c[1])}}function Nn(t,e){var r=Ir(e);r[0]-=t,Rr(r);var n=Ot(-r[1]);return((-r[2]<0?-n:n)+2*Math.PI-kt)%(2*Math.PI)}function jn(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[t,e]}))}}function Un(e,r,n){var i=t.range(e,r-kt,n).concat(r);return function(t){return i.map((function(e){return[e,t]}))}}function Vn(t){return t.source}function qn(t){return t.target}t.geo.path=function(){var e,r,n,i,a,o=4.5;function s(e){return e&&(\"function\"==typeof o&&i.pointRadius(+o.apply(this,arguments)),a&&a.valid||(a=n(i)),t.geo.stream(e,a)),i.result()}function l(){return a=null,s}return s.area=function(e){return sn=0,t.geo.stream(e,n(pn)),sn},s.centroid=function(e){return xr=br=_r=wr=Tr=kr=Mr=Ar=Sr=0,t.geo.stream(e,n(xn)),Sr?[Mr/Sr,Ar/Sr]:kr?[wr/kr,Tr/kr]:_r?[xr/_r,br/_r]:[NaN,NaN]},s.bounds=function(e){return fn=hn=-(cn=un=1/0),t.geo.stream(e,n(gn)),[[cn,un],[fn,hn]]},s.projection=function(t){return arguments.length?(n=(e=t)?t.stream||An(t):L,l()):e},s.context=function(t){return arguments.length?(i=null==(r=t)?new mn:new kn(t),\"function\"!=typeof o&&i.pointRadius(o),l()):r},s.pointRadius=function(t){return arguments.length?(o=\"function\"==typeof t?t:(i.pointRadius(+t),+t),s):o},s.projection(t.geo.albersUsa()).context(null)},t.geo.transform=function(t){return{stream:function(e){var r=new Sn(e);for(var n in t)r[n]=t[n];return r}}},Sn.prototype={point:function(t,e){this.stream.point(t,e)},sphere:function(){this.stream.sphere()},lineStart:function(){this.stream.lineStart()},lineEnd:function(){this.stream.lineEnd()},polygonStart:function(){this.stream.polygonStart()},polygonEnd:function(){this.stream.polygonEnd()}},t.geo.projection=Cn,t.geo.projectionMutator=Ln,(t.geo.equirectangular=function(){return Cn(Pn)}).raw=Pn.invert=Pn,t.geo.rotation=function(t){function e(e){return(e=t(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e}return t=On(t[0]%360*Lt,t[1]*Lt,t.length>2?t[2]*Lt:0),e.invert=function(e){return(e=t.invert(e[0]*Lt,e[1]*Lt))[0]*=It,e[1]*=It,e},e},zn.invert=Pn,t.geo.circle=function(){var t,e,r=[0,0],n=6;function i(){var t=\"function\"==typeof r?r.apply(this,arguments):r,n=On(-t[0]*Lt,-t[1]*Lt,0).invert,i=[];return e(null,null,1,{point:function(t,e){i.push(t=n(t,e)),t[0]*=It,t[1]*=It}}),{type:\"Polygon\",coordinates:[i]}}return i.origin=function(t){return arguments.length?(r=t,i):r},i.angle=function(r){return arguments.length?(e=Bn((t=+r)*Lt,n*Lt),i):t},i.precision=function(r){return arguments.length?(e=Bn(t*Lt,(n=+r)*Lt),i):n},i.angle(90)},t.geo.distance=function(t,e){var r,n=(e[0]-t[0])*Lt,i=t[1]*Lt,a=e[1]*Lt,o=Math.sin(n),s=Math.cos(n),l=Math.sin(i),c=Math.cos(i),u=Math.sin(a),f=Math.cos(a);return Math.atan2(Math.sqrt((r=f*o)*r+(r=c*u-l*f*s)*r),l*u+c*f*s)},t.geo.graticule=function(){var e,r,n,i,a,o,s,l,c,u,f,h,p=10,d=p,g=90,m=360,v=2.5;function x(){return{type:\"MultiLineString\",coordinates:b()}}function b(){return t.range(Math.ceil(i/g)*g,n,g).map(f).concat(t.range(Math.ceil(l/m)*m,s,m).map(h)).concat(t.range(Math.ceil(r/p)*p,e,p).filter((function(t){return y(t%g)>kt})).map(c)).concat(t.range(Math.ceil(o/d)*d,a,d).filter((function(t){return y(t%m)>kt})).map(u))}return x.lines=function(){return b().map((function(t){return{type:\"LineString\",coordinates:t}}))},x.outline=function(){return{type:\"Polygon\",coordinates:[f(i).concat(h(s).slice(1),f(n).reverse().slice(1),h(l).reverse().slice(1))]}},x.extent=function(t){return arguments.length?x.majorExtent(t).minorExtent(t):x.minorExtent()},x.majorExtent=function(t){return arguments.length?(i=+t[0][0],n=+t[1][0],l=+t[0][1],s=+t[1][1],i>n&&(t=i,i=n,n=t),l>s&&(t=l,l=s,s=t),x.precision(v)):[[i,l],[n,s]]},x.minorExtent=function(t){return arguments.length?(r=+t[0][0],e=+t[1][0],o=+t[0][1],a=+t[1][1],r>e&&(t=r,r=e,e=t),o>a&&(t=o,o=a,a=t),x.precision(v)):[[r,o],[e,a]]},x.step=function(t){return arguments.length?x.majorStep(t).minorStep(t):x.minorStep()},x.majorStep=function(t){return arguments.length?(g=+t[0],m=+t[1],x):[g,m]},x.minorStep=function(t){return arguments.length?(p=+t[0],d=+t[1],x):[p,d]},x.precision=function(t){return arguments.length?(v=+t,c=jn(o,a,90),u=Un(r,e,v),f=jn(l,s,90),h=Un(i,n,v),x):v},x.majorExtent([[-180,-90+kt],[180,90-kt]]).minorExtent([[-180,-80-kt],[180,80+kt]])},t.geo.greatArc=function(){var e,r,n=Vn,i=qn;function a(){return{type:\"LineString\",coordinates:[e||n.apply(this,arguments),r||i.apply(this,arguments)]}}return a.distance=function(){return t.geo.distance(e||n.apply(this,arguments),r||i.apply(this,arguments))},a.source=function(t){return arguments.length?(n=t,e=\"function\"==typeof t?null:t,a):n},a.target=function(t){return arguments.length?(i=t,r=\"function\"==typeof t?null:t,a):i},a.precision=function(){return arguments.length?a:0},a},t.geo.interpolate=function(t,e){return r=t[0]*Lt,n=t[1]*Lt,i=e[0]*Lt,a=e[1]*Lt,o=Math.cos(n),s=Math.sin(n),l=Math.cos(a),c=Math.sin(a),u=o*Math.cos(r),f=o*Math.sin(r),h=l*Math.cos(i),p=l*Math.sin(i),d=2*Math.asin(Math.sqrt(Ft(a-n)+o*l*Ft(i-r))),g=1/Math.sin(d),(m=d?function(t){var e=Math.sin(t*=d)*g,r=Math.sin(d-t)*g,n=r*u+e*h,i=r*f+e*p,a=r*s+e*c;return[Math.atan2(i,n)*It,Math.atan2(a,Math.sqrt(n*n+i*i))*It]}:function(){return[r*It,n*It]}).distance=d,m;var r,n,i,a,o,s,l,c,u,f,h,p,d,g,m},t.geo.length=function(e){return yn=0,t.geo.stream(e,Hn),yn};var Hn={sphere:O,point:O,lineStart:function(){var t,e,r;function n(n,i){var a=Math.sin(i*=Lt),o=Math.cos(i),s=y((n*=Lt)-t),l=Math.cos(s);yn+=Math.atan2(Math.sqrt((s=o*Math.sin(s))*s+(s=r*a-e*o*l)*s),e*a+r*o*l),t=n,e=a,r=o}Hn.point=function(i,a){t=i*Lt,e=Math.sin(a*=Lt),r=Math.cos(a),Hn.point=n},Hn.lineEnd=function(){Hn.point=Hn.lineEnd=O}},lineEnd:O,polygonStart:O,polygonEnd:O};function Gn(t,e){function r(e,r){var n=Math.cos(e),i=Math.cos(r),a=t(n*i);return[a*i*Math.sin(e),a*Math.sin(r)]}return r.invert=function(t,r){var n=Math.sqrt(t*t+r*r),i=e(n),a=Math.sin(i),o=Math.cos(i);return[Math.atan2(t*a,n*o),Math.asin(n&&r*a/n)]},r}var Yn=Gn((function(t){return Math.sqrt(2/(1+t))}),(function(t){return 2*Math.asin(t/2)}));(t.geo.azimuthalEqualArea=function(){return Cn(Yn)}).raw=Yn;var Wn=Gn((function(t){var e=Math.acos(t);return e&&e/Math.sin(e)}),L);function Xn(t,e){var r=Math.cos(t),n=function(t){return Math.tan(At/4+t/2)},i=t===e?Math.sin(t):Math.log(r/Math.cos(e))/Math.log(n(e)/n(t)),a=r*Math.pow(n(t),i)/i;if(!i)return Kn;function o(t,e){a>0?e<-Ct+kt&&(e=-Ct+kt):e>Ct-kt&&(e=Ct-kt);var r=a/Math.pow(n(e),i);return[r*Math.sin(i*t),a-r*Math.cos(i*t)]}return o.invert=function(t,e){var r=a-e,n=Pt(i)*Math.sqrt(t*t+r*r);return[Math.atan2(t,r)/i,2*Math.atan(Math.pow(a/n,1/i))-Ct]},o}function Zn(t,e){var r=Math.cos(t),n=t===e?Math.sin(t):(r-Math.cos(e))/(e-t),i=r/n+t;if(y(n)<kt)return Pn;function a(t,e){var r=i-e;return[r*Math.sin(n*t),i-r*Math.cos(n*t)]}return a.invert=function(t,e){var r=i-e;return[Math.atan2(t,r)/n,i-Pt(n)*Math.sqrt(t*t+r*r)]},a}(t.geo.azimuthalEquidistant=function(){return Cn(Wn)}).raw=Wn,(t.geo.conicConformal=function(){return an(Xn)}).raw=Xn,(t.geo.conicEquidistant=function(){return an(Zn)}).raw=Zn;var Jn=Gn((function(t){return 1/t}),Math.atan);function Kn(t,e){return[t,Math.log(Math.tan(At/4+e/2))]}function Qn(t){var e,r=Cn(t),n=r.scale,i=r.translate,a=r.clipExtent;return r.scale=function(){var t=n.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.translate=function(){var t=i.apply(r,arguments);return t===r?e?r.clipExtent(null):r:t},r.clipExtent=function(t){var o=a.apply(r,arguments);if(o===r){if(e=null==t){var s=At*n(),l=i();a([[l[0]-s,l[1]-s],[l[0]+s,l[1]+s]])}}else e&&(o=null);return o},r.clipExtent(null)}(t.geo.gnomonic=function(){return Cn(Jn)}).raw=Jn,Kn.invert=function(t,e){return[t,2*Math.atan(Math.exp(e))-Ct]},(t.geo.mercator=function(){return Qn(Kn)}).raw=Kn;var $n=Gn((function(){return 1}),Math.asin);(t.geo.orthographic=function(){return Cn($n)}).raw=$n;var ti=Gn((function(t){return 1/(1+t)}),(function(t){return 2*Math.atan(t)}));function ei(t,e){return[Math.log(Math.tan(At/4+e/2)),-t]}function ri(t){return t[0]}function ni(t){return t[1]}function ii(t){for(var e=t.length,r=[0,1],n=2,i=2;i<e;i++){for(;n>1&&zt(t[r[n-2]],t[r[n-1]],t[i])<=0;)--n;r[n++]=i}return r.slice(0,n)}function ai(t,e){return t[0]-e[0]||t[1]-e[1]}(t.geo.stereographic=function(){return Cn(ti)}).raw=ti,ei.invert=function(t,e){return[-e,2*Math.atan(Math.exp(t))-Ct]},(t.geo.transverseMercator=function(){var t=Qn(ei),e=t.center,r=t.rotate;return t.center=function(t){return t?e([-t[1],t[0]]):[(t=e())[1],-t[0]]},t.rotate=function(t){return t?r([t[0],t[1],t.length>2?t[2]+90:90]):[(t=r())[0],t[1],t[2]-90]},r([0,0,90])}).raw=ei,t.geom={},t.geom.hull=function(t){var e=ri,r=ni;if(arguments.length)return n(t);function n(t){if(t.length<3)return[];var n,i=de(e),a=de(r),o=t.length,s=[],l=[];for(n=0;n<o;n++)s.push([+i.call(this,t[n],n),+a.call(this,t[n],n),n]);for(s.sort(ai),n=0;n<o;n++)l.push([s[n][0],-s[n][1]]);var c=ii(s),u=ii(l),f=u[0]===c[0],h=u[u.length-1]===c[c.length-1],p=[];for(n=c.length-1;n>=0;--n)p.push(t[s[c[n]][2]]);for(n=+f;n<u.length-h;++n)p.push(t[s[u[n]][2]]);return p}return n.x=function(t){return arguments.length?(e=t,n):e},n.y=function(t){return arguments.length?(r=t,n):r},n},t.geom.polygon=function(t){return U(t,oi),t};var oi=t.geom.polygon.prototype=[];function si(t,e,r){return(r[0]-e[0])*(t[1]-e[1])<(r[1]-e[1])*(t[0]-e[0])}function li(t,e,r,n){var i=t[0],a=r[0],o=e[0]-i,s=n[0]-a,l=t[1],c=r[1],u=e[1]-l,f=n[1]-c,h=(s*(l-c)-f*(i-a))/(f*o-s*u);return[i+h*o,l+h*u]}function ci(t){var e=t[0],r=t[t.length-1];return!(e[0]-r[0]||e[1]-r[1])}oi.area=function(){for(var t,e=-1,r=this.length,n=this[r-1],i=0;++e<r;)t=n,n=this[e],i+=t[1]*n[0]-t[0]*n[1];return.5*i},oi.centroid=function(t){var e,r,n=-1,i=this.length,a=0,o=0,s=this[i-1];for(arguments.length||(t=-1/(6*this.area()));++n<i;)e=s,s=this[n],r=e[0]*s[1]-s[0]*e[1],a+=(e[0]+s[0])*r,o+=(e[1]+s[1])*r;return[a*t,o*t]},oi.clip=function(t){for(var e,r,n,i,a,o,s=ci(t),l=-1,c=this.length-ci(this),u=this[c-1];++l<c;){for(e=t.slice(),t.length=0,i=this[l],a=e[(n=e.length-s)-1],r=-1;++r<n;)si(o=e[r],u,i)?(si(a,u,i)||t.push(li(a,o,u,i)),t.push(o)):si(a,u,i)&&t.push(li(a,o,u,i)),a=o;s&&t.push(t[0]),u=i}return t};var ui,fi,hi,pi,di,gi=[],mi=[];function vi(){Ri(this),this.edge=this.site=this.circle=null}function yi(t){var e=gi.pop()||new vi;return e.site=t,e}function xi(t){Ei(t),hi.remove(t),gi.push(t),Ri(t)}function bi(t){var e=t.circle,r=e.x,n=e.cy,i={x:r,y:n},a=t.P,o=t.N,s=[t];xi(t);for(var l=a;l.circle&&y(r-l.circle.x)<kt&&y(n-l.circle.cy)<kt;)a=l.P,s.unshift(l),xi(l),l=a;s.unshift(l),Ei(l);for(var c=o;c.circle&&y(r-c.circle.x)<kt&&y(n-c.circle.cy)<kt;)o=c.N,s.push(c),xi(c),c=o;s.push(c),Ei(c);var u,f=s.length;for(u=1;u<f;++u)c=s[u],l=s[u-1],zi(c.edge,l.site,c.site,i);l=s[0],(c=s[f-1]).edge=Ii(l.site,c.site,null,i),Si(l),Si(c)}function _i(t){for(var e,r,n,i,a=t.x,o=t.y,s=hi._;s;)if((n=wi(s,o)-a)>kt)s=s.L;else{if(!((i=a-Ti(s,o))>kt)){n>-kt?(e=s.P,r=s):i>-kt?(e=s,r=s.N):e=r=s;break}if(!s.R){e=s;break}s=s.R}var l=yi(t);if(hi.insert(e,l),e||r){if(e===r)return Ei(e),r=yi(e.site),hi.insert(l,r),l.edge=r.edge=Ii(e.site,l.site),Si(e),void Si(r);if(r){Ei(e),Ei(r);var c=e.site,u=c.x,f=c.y,h=t.x-u,p=t.y-f,d=r.site,g=d.x-u,m=d.y-f,v=2*(h*m-p*g),y=h*h+p*p,x=g*g+m*m,b={x:(m*y-p*x)/v+u,y:(h*x-g*y)/v+f};zi(r.edge,c,d,b),l.edge=Ii(c,t,null,b),r.edge=Ii(t,d,null,b),Si(e),Si(r)}else l.edge=Ii(e.site,l.site)}}function wi(t,e){var r=t.site,n=r.x,i=r.y,a=i-e;if(!a)return n;var o=t.P;if(!o)return-1/0;var s=(r=o.site).x,l=r.y,c=l-e;if(!c)return s;var u=s-n,f=1/a-1/c,h=u/c;return f?(-h+Math.sqrt(h*h-2*f*(u*u/(-2*c)-l+c/2+i-a/2)))/f+n:(n+s)/2}function Ti(t,e){var r=t.N;if(r)return wi(r,e);var n=t.site;return n.y===e?n.x:1/0}function ki(t){this.site=t,this.edges=[]}function Mi(t,e){return e.angle-t.angle}function Ai(){Ri(this),this.x=this.y=this.arc=this.site=this.cy=null}function Si(t){var e=t.P,r=t.N;if(e&&r){var n=e.site,i=t.site,a=r.site;if(n!==a){var o=i.x,s=i.y,l=n.x-o,c=n.y-s,u=a.x-o,f=2*(l*(m=a.y-s)-c*u);if(!(f>=-Mt)){var h=l*l+c*c,p=u*u+m*m,d=(m*h-c*p)/f,g=(l*p-u*h)/f,m=g+s,v=mi.pop()||new Ai;v.arc=t,v.site=i,v.x=d+o,v.y=m+Math.sqrt(d*d+g*g),v.cy=m,t.circle=v;for(var y=null,x=di._;x;)if(v.y<x.y||v.y===x.y&&v.x<=x.x){if(!x.L){y=x.P;break}x=x.L}else{if(!x.R){y=x;break}x=x.R}di.insert(y,v),y||(pi=v)}}}}function Ei(t){var e=t.circle;e&&(e.P||(pi=e.N),di.remove(e),mi.push(e),Ri(e),t.circle=null)}function Ci(t,e){var r=t.b;if(r)return!0;var n,i,a=t.a,o=e[0][0],s=e[1][0],l=e[0][1],c=e[1][1],u=t.l,f=t.r,h=u.x,p=u.y,d=f.x,g=f.y,m=(h+d)/2,v=(p+g)/2;if(g===p){if(m<o||m>=s)return;if(h>d){if(a){if(a.y>=c)return}else a={x:m,y:l};r={x:m,y:c}}else{if(a){if(a.y<l)return}else a={x:m,y:c};r={x:m,y:l}}}else if(i=v-(n=(h-d)/(g-p))*m,n<-1||n>1)if(h>d){if(a){if(a.y>=c)return}else a={x:(l-i)/n,y:l};r={x:(c-i)/n,y:c}}else{if(a){if(a.y<l)return}else a={x:(c-i)/n,y:c};r={x:(l-i)/n,y:l}}else if(p<g){if(a){if(a.x>=s)return}else a={x:o,y:n*o+i};r={x:s,y:n*s+i}}else{if(a){if(a.x<o)return}else a={x:s,y:n*s+i};r={x:o,y:n*o+i}}return t.a=a,t.b=r,!0}function Li(t,e){this.l=t,this.r=e,this.a=this.b=null}function Ii(t,e,r,n){var i=new Li(t,e);return ui.push(i),r&&zi(i,t,e,r),n&&zi(i,e,t,n),fi[t.i].edges.push(new Oi(i,t,e)),fi[e.i].edges.push(new Oi(i,e,t)),i}function Pi(t,e,r){var n=new Li(t,null);return n.a=e,n.b=r,ui.push(n),n}function zi(t,e,r,n){t.a||t.b?t.l===r?t.b=n:t.a=n:(t.a=n,t.l=e,t.r=r)}function Oi(t,e,r){var n=t.a,i=t.b;this.edge=t,this.site=e,this.angle=r?Math.atan2(r.y-e.y,r.x-e.x):t.l===e?Math.atan2(i.x-n.x,n.y-i.y):Math.atan2(n.x-i.x,i.y-n.y)}function Di(){this._=null}function Ri(t){t.U=t.C=t.L=t.R=t.P=t.N=null}function Fi(t,e){var r=e,n=e.R,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.R=n.L,r.R&&(r.R.U=r),n.L=r}function Bi(t,e){var r=e,n=e.L,i=r.U;i?i.L===r?i.L=n:i.R=n:t._=n,n.U=i,r.U=n,r.L=n.R,r.L&&(r.L.U=r),n.R=r}function Ni(t){for(;t.L;)t=t.L;return t}function ji(t,e){var r,n,i,a=t.sort(Ui).pop();for(ui=[],fi=new Array(t.length),hi=new Di,di=new Di;;)if(i=pi,a&&(!i||a.y<i.y||a.y===i.y&&a.x<i.x))a.x===r&&a.y===n||(fi[a.i]=new ki(a),_i(a),r=a.x,n=a.y),a=t.pop();else{if(!i)break;bi(i.arc)}e&&(function(t){for(var e,r=ui,n=rn(t[0][0],t[0][1],t[1][0],t[1][1]),i=r.length;i--;)(!Ci(e=r[i],t)||!n(e)||y(e.a.x-e.b.x)<kt&&y(e.a.y-e.b.y)<kt)&&(e.a=e.b=null,r.splice(i,1))}(e),function(t){for(var e,r,n,i,a,o,s,l,c,u,f=t[0][0],h=t[1][0],p=t[0][1],d=t[1][1],g=fi,m=g.length;m--;)if((a=g[m])&&a.prepare())for(l=(s=a.edges).length,o=0;o<l;)n=(u=s[o].end()).x,i=u.y,e=(c=s[++o%l].start()).x,r=c.y,(y(n-e)>kt||y(i-r)>kt)&&(s.splice(o,0,new Oi(Pi(a.site,u,y(n-f)<kt&&d-i>kt?{x:f,y:y(e-f)<kt?r:d}:y(i-d)<kt&&h-n>kt?{x:y(r-d)<kt?e:h,y:d}:y(n-h)<kt&&i-p>kt?{x:h,y:y(e-h)<kt?r:p}:y(i-p)<kt&&n-f>kt?{x:y(r-p)<kt?e:f,y:p}:null),a.site,null)),++l)}(e));var o={cells:fi,edges:ui};return hi=di=ui=fi=null,o}function Ui(t,e){return e.y-t.y||e.x-t.x}ki.prototype.prepare=function(){for(var t,e=this.edges,r=e.length;r--;)(t=e[r].edge).b&&t.a||e.splice(r,1);return e.sort(Mi),e.length},Oi.prototype={start:function(){return this.edge.l===this.site?this.edge.a:this.edge.b},end:function(){return this.edge.l===this.site?this.edge.b:this.edge.a}},Di.prototype={insert:function(t,e){var r,n,i;if(t){if(e.P=t,e.N=t.N,t.N&&(t.N.P=e),t.N=e,t.R){for(t=t.R;t.L;)t=t.L;t.L=e}else t.R=e;r=t}else this._?(t=Ni(this._),e.P=null,e.N=t,t.P=t.L=e,r=t):(e.P=e.N=null,this._=e,r=null);for(e.L=e.R=null,e.U=r,e.C=!0,t=e;r&&r.C;)r===(n=r.U).L?(i=n.R)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.R&&(Fi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Bi(this,n)):(i=n.L)&&i.C?(r.C=i.C=!1,n.C=!0,t=n):(t===r.L&&(Bi(this,r),r=(t=r).U),r.C=!1,n.C=!0,Fi(this,n)),r=t.U;this._.C=!1},remove:function(t){t.N&&(t.N.P=t.P),t.P&&(t.P.N=t.N),t.N=t.P=null;var e,r,n,i=t.U,a=t.L,o=t.R;if(r=a?o?Ni(o):a:o,i?i.L===t?i.L=r:i.R=r:this._=r,a&&o?(n=r.C,r.C=t.C,r.L=a,a.U=r,r!==o?(i=r.U,r.U=t.U,t=r.R,i.L=t,r.R=o,o.U=r):(r.U=i,i=r,t=r.R)):(n=t.C,t=r),t&&(t.U=i),!n)if(t&&t.C)t.C=!1;else{do{if(t===this._)break;if(t===i.L){if((e=i.R).C&&(e.C=!1,i.C=!0,Fi(this,i),e=i.R),e.L&&e.L.C||e.R&&e.R.C){e.R&&e.R.C||(e.L.C=!1,e.C=!0,Bi(this,e),e=i.R),e.C=i.C,i.C=e.R.C=!1,Fi(this,i),t=this._;break}}else if((e=i.L).C&&(e.C=!1,i.C=!0,Bi(this,i),e=i.L),e.L&&e.L.C||e.R&&e.R.C){e.L&&e.L.C||(e.R.C=!1,e.C=!0,Fi(this,e),e=i.L),e.C=i.C,i.C=e.L.C=!1,Bi(this,i),t=this._;break}e.C=!0,t=i,i=i.U}while(!t.C);t&&(t.C=!1)}}},t.geom.voronoi=function(t){var e=ri,r=ni,n=e,i=r,a=Vi;if(t)return o(t);function o(t){var e=new Array(t.length),r=a[0][0],n=a[0][1],i=a[1][0],o=a[1][1];return ji(s(t),a).cells.forEach((function(a,s){var l=a.edges,c=a.site;(e[s]=l.length?l.map((function(t){var e=t.start();return[e.x,e.y]})):c.x>=r&&c.x<=i&&c.y>=n&&c.y<=o?[[r,o],[i,o],[i,n],[r,n]]:[]).point=t[s]})),e}function s(t){return t.map((function(t,e){return{x:Math.round(n(t,e)/kt)*kt,y:Math.round(i(t,e)/kt)*kt,i:e}}))}return o.links=function(t){return ji(s(t)).edges.filter((function(t){return t.l&&t.r})).map((function(e){return{source:t[e.l.i],target:t[e.r.i]}}))},o.triangles=function(t){var e=[];return ji(s(t)).cells.forEach((function(r,n){for(var i,a,o,s,l=r.site,c=r.edges.sort(Mi),u=-1,f=c.length,h=c[f-1].edge,p=h.l===l?h.r:h.l;++u<f;)h,i=p,p=(h=c[u].edge).l===l?h.r:h.l,n<i.i&&n<p.i&&(o=i,s=p,((a=l).x-s.x)*(o.y-a.y)-(a.x-o.x)*(s.y-a.y)<0)&&e.push([t[n],t[i.i],t[p.i]])})),e},o.x=function(t){return arguments.length?(n=de(e=t),o):e},o.y=function(t){return arguments.length?(i=de(r=t),o):r},o.clipExtent=function(t){return arguments.length?(a=null==t?Vi:t,o):a===Vi?null:a},o.size=function(t){return arguments.length?o.clipExtent(t&&[[0,0],t]):a===Vi?null:a&&a[1]},o};var Vi=[[-1e6,-1e6],[1e6,1e6]];function qi(t){return t.x}function Hi(t){return t.y}function Gi(t,e,r,n,i,a){if(!t(e,r,n,i,a)){var o=.5*(r+i),s=.5*(n+a),l=e.nodes;l[0]&&Gi(t,l[0],r,n,o,s),l[1]&&Gi(t,l[1],o,n,i,s),l[2]&&Gi(t,l[2],r,s,o,a),l[3]&&Gi(t,l[3],o,s,i,a)}}function Yi(t,e,r,n,i,a,o){var s,l=1/0;return function t(c,u,f,h,p){if(!(u>a||f>o||h<n||p<i)){if(d=c.point){var d,g=e-c.x,m=r-c.y,v=g*g+m*m;if(v<l){var y=Math.sqrt(l=v);n=e-y,i=r-y,a=e+y,o=r+y,s=d}}for(var x=c.nodes,b=.5*(u+h),_=.5*(f+p),w=(r>=_)<<1|e>=b,T=w+4;w<T;++w)if(c=x[3&w])switch(3&w){case 0:t(c,u,f,b,_);break;case 1:t(c,b,f,h,_);break;case 2:t(c,u,_,b,p);break;case 3:t(c,b,_,h,p)}}}(t,n,i,a,o),s}function Wi(e,r){e=t.rgb(e),r=t.rgb(r);var n=e.r,i=e.g,a=e.b,o=r.r-n,s=r.g-i,l=r.b-a;return function(t){return\"#\"+se(Math.round(n+o*t))+se(Math.round(i+s*t))+se(Math.round(a+l*t))}}function Xi(t,e){var r,n={},i={};for(r in t)r in e?n[r]=$i(t[r],e[r]):i[r]=t[r];for(r in e)r in t||(i[r]=e[r]);return function(t){for(r in n)i[r]=n[r](t);return i}}function Zi(t,e){return t=+t,e=+e,function(r){return t*(1-r)+e*r}}function Ji(t,e){var r,n,i,a=Ki.lastIndex=Qi.lastIndex=0,o=-1,s=[],l=[];for(t+=\"\",e+=\"\";(r=Ki.exec(t))&&(n=Qi.exec(e));)(i=n.index)>a&&(i=e.slice(a,i),s[o]?s[o]+=i:s[++o]=i),(r=r[0])===(n=n[0])?s[o]?s[o]+=n:s[++o]=n:(s[++o]=null,l.push({i:o,x:Zi(r,n)})),a=Qi.lastIndex;return a<e.length&&(i=e.slice(a),s[o]?s[o]+=i:s[++o]=i),s.length<2?l[0]?(e=l[0].x,function(t){return e(t)+\"\"}):function(){return e}:(e=l.length,function(t){for(var r,n=0;n<e;++n)s[(r=l[n]).i]=r.x(t);return s.join(\"\")})}t.geom.delaunay=function(e){return t.geom.voronoi().triangles(e)},t.geom.quadtree=function(t,e,r,n,i){var a,o=ri,s=ni;if(a=arguments.length)return o=qi,s=Hi,3===a&&(i=r,n=e,r=e=0),l(t);function l(t){var l,c,u,f,h,p,d,g,m,v=de(o),x=de(s);if(null!=e)p=e,d=r,g=n,m=i;else if(g=m=-(p=d=1/0),c=[],u=[],h=t.length,a)for(f=0;f<h;++f)(l=t[f]).x<p&&(p=l.x),l.y<d&&(d=l.y),l.x>g&&(g=l.x),l.y>m&&(m=l.y),c.push(l.x),u.push(l.y);else for(f=0;f<h;++f){var b=+v(l=t[f],f),_=+x(l,f);b<p&&(p=b),_<d&&(d=_),b>g&&(g=b),_>m&&(m=_),c.push(b),u.push(_)}var w=g-p,T=m-d;function k(t,e,r,n,i,a,o,s){if(!isNaN(r)&&!isNaN(n))if(t.leaf){var l=t.x,c=t.y;if(null!=l)if(y(l-r)+y(c-n)<.01)M(t,e,r,n,i,a,o,s);else{var u=t.point;t.x=t.y=t.point=null,M(t,u,l,c,i,a,o,s),M(t,e,r,n,i,a,o,s)}else t.x=r,t.y=n,t.point=e}else M(t,e,r,n,i,a,o,s)}function M(t,e,r,n,i,a,o,s){var l=.5*(i+o),c=.5*(a+s),u=r>=l,f=n>=c,h=f<<1|u;t.leaf=!1,u?i=l:o=l,f?a=c:s=c,k(t=t.nodes[h]||(t.nodes[h]={leaf:!0,nodes:[],point:null,x:null,y:null}),e,r,n,i,a,o,s)}w>T?m=d+w:g=p+T;var A={leaf:!0,nodes:[],point:null,x:null,y:null,add:function(t){k(A,t,+v(t,++f),+x(t,f),p,d,g,m)},visit:function(t){Gi(t,A,p,d,g,m)},find:function(t){return Yi(A,t[0],t[1],p,d,g,m)}};if(f=-1,null==e){for(;++f<h;)k(A,t[f],c[f],u[f],p,d,g,m);--f}else t.forEach(A.add);return c=u=t=l=null,A}return l.x=function(t){return arguments.length?(o=t,l):o},l.y=function(t){return arguments.length?(s=t,l):s},l.extent=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=+t[0][0],r=+t[0][1],n=+t[1][0],i=+t[1][1]),l):null==e?null:[[e,r],[n,i]]},l.size=function(t){return arguments.length?(null==t?e=r=n=i=null:(e=r=0,n=+t[0],i=+t[1]),l):null==e?null:[n-e,i-r]},l},t.interpolateRgb=Wi,t.interpolateObject=Xi,t.interpolateNumber=Zi,t.interpolateString=Ji;var Ki=/[-+]?(?:\\d+\\.?\\d*|\\.?\\d+)(?:[eE][-+]?\\d+)?/g,Qi=new RegExp(Ki.source,\"g\");function $i(e,r){for(var n,i=t.interpolators.length;--i>=0&&!(n=t.interpolators[i](e,r)););return n}function ta(t,e){var r,n=[],i=[],a=t.length,o=e.length,s=Math.min(t.length,e.length);for(r=0;r<s;++r)n.push($i(t[r],e[r]));for(;r<a;++r)i[r]=t[r];for(;r<o;++r)i[r]=e[r];return function(t){for(r=0;r<s;++r)i[r]=n[r](t);return i}}t.interpolate=$i,t.interpolators=[function(t,e){var r=typeof e;return(\"string\"===r?pe.has(e.toLowerCase())||/^(#|rgb\\(|hsl\\()/i.test(e)?Wi:Ji:e instanceof Vt?Wi:Array.isArray(e)?ta:\"object\"===r&&isNaN(e)?Xi:Zi)(t,e)}],t.interpolateArray=ta;var ea=function(){return L},ra=t.map({linear:ea,poly:function(t){return function(e){return Math.pow(e,t)}},quad:function(){return sa},cubic:function(){return la},sin:function(){return ua},exp:function(){return fa},circle:function(){return ha},elastic:function(t,e){var r;arguments.length<2&&(e=.45);arguments.length?r=e/St*Math.asin(1/t):(t=1,r=e/4);return function(n){return 1+t*Math.pow(2,-10*n)*Math.sin((n-r)*St/e)}},back:function(t){t||(t=1.70158);return function(e){return e*e*((t+1)*e-t)}},bounce:function(){return pa}}),na=t.map({in:L,out:aa,\"in-out\":oa,\"out-in\":function(t){return oa(aa(t))}});function ia(t){return function(e){return e<=0?0:e>=1?1:t(e)}}function aa(t){return function(e){return 1-t(1-e)}}function oa(t){return function(e){return.5*(e<.5?t(2*e):2-t(2-2*e))}}function sa(t){return t*t}function la(t){return t*t*t}function ca(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}function ua(t){return 1-Math.cos(t*Ct)}function fa(t){return Math.pow(2,10*(t-1))}function ha(t){return 1-Math.sqrt(1-t*t)}function pa(t){return t<1/2.75?7.5625*t*t:t<2/2.75?7.5625*(t-=1.5/2.75)*t+.75:t<2.5/2.75?7.5625*(t-=2.25/2.75)*t+.9375:7.5625*(t-=2.625/2.75)*t+.984375}function da(t,e){return e-=t,function(r){return Math.round(t+e*r)}}function ga(t){var e,r,n,i=[t.a,t.b],a=[t.c,t.d],o=va(i),s=ma(i,a),l=va(((e=a)[0]+=(n=-s)*(r=i)[0],e[1]+=n*r[1],e))||0;i[0]*a[1]<a[0]*i[1]&&(i[0]*=-1,i[1]*=-1,o*=-1,s*=-1),this.rotate=(o?Math.atan2(i[1],i[0]):Math.atan2(-a[0],a[1]))*It,this.translate=[t.e,t.f],this.scale=[o,l],this.skew=l?Math.atan2(s,l)*It:0}function ma(t,e){return t[0]*e[0]+t[1]*e[1]}function va(t){var e=Math.sqrt(ma(t,t));return e&&(t[0]/=e,t[1]/=e),e}t.ease=function(t){var e=t.indexOf(\"-\"),n=e>=0?t.slice(0,e):t,i=e>=0?t.slice(e+1):\"in\";return n=ra.get(n)||ea,ia((i=na.get(i)||L)(n.apply(null,r.call(arguments,1))))},t.interpolateHcl=function(e,r){e=t.hcl(e),r=t.hcl(r);var n=e.h,i=e.c,a=e.l,o=r.h-n,s=r.c-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.c:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Xt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateHsl=function(e,r){e=t.hsl(e),r=t.hsl(r);var n=e.h,i=e.s,a=e.l,o=r.h-n,s=r.s-i,l=r.l-a;isNaN(s)&&(s=0,i=isNaN(i)?r.s:i);isNaN(o)?(o=0,n=isNaN(n)?r.h:n):o>180?o-=360:o<-180&&(o+=360);return function(t){return Gt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateLab=function(e,r){e=t.lab(e),r=t.lab(r);var n=e.l,i=e.a,a=e.b,o=r.l-n,s=r.a-i,l=r.b-a;return function(t){return Qt(n+o*t,i+s*t,a+l*t)+\"\"}},t.interpolateRound=da,t.transform=function(e){var r=i.createElementNS(t.ns.prefix.svg,\"g\");return(t.transform=function(t){if(null!=t){r.setAttribute(\"transform\",t);var e=r.transform.baseVal.consolidate()}return new ga(e?e.matrix:ya)})(e)},ga.prototype.toString=function(){return\"translate(\"+this.translate+\")rotate(\"+this.rotate+\")skewX(\"+this.skew+\")scale(\"+this.scale+\")\"};var ya={a:1,b:0,c:0,d:1,e:0,f:0};function xa(t){return t.length?t.pop()+\",\":\"\"}function ba(e,r){var n=[],i=[];return e=t.transform(e),r=t.transform(r),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(\"translate(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else(e[0]||e[1])&&r.push(\"translate(\"+e+\")\")}(e.translate,r.translate,n,i),function(t,e,r,n){t!==e?(t-e>180?e+=360:e-t>180&&(t+=360),n.push({i:r.push(xa(r)+\"rotate(\",null,\")\")-2,x:Zi(t,e)})):e&&r.push(xa(r)+\"rotate(\"+e+\")\")}(e.rotate,r.rotate,n,i),function(t,e,r,n){t!==e?n.push({i:r.push(xa(r)+\"skewX(\",null,\")\")-2,x:Zi(t,e)}):e&&r.push(xa(r)+\"skewX(\"+e+\")\")}(e.skew,r.skew,n,i),function(t,e,r,n){if(t[0]!==e[0]||t[1]!==e[1]){var i=r.push(xa(r)+\"scale(\",null,\",\",null,\")\");n.push({i:i-4,x:Zi(t[0],e[0])},{i:i-2,x:Zi(t[1],e[1])})}else 1===e[0]&&1===e[1]||r.push(xa(r)+\"scale(\"+e+\")\")}(e.scale,r.scale,n,i),e=r=null,function(t){for(var e,r=-1,a=i.length;++r<a;)n[(e=i[r]).i]=e.x(t);return n.join(\"\")}}function _a(t,e){return e=(e-=t=+t)||1/e,function(r){return(r-t)/e}}function wa(t,e){return e=(e-=t=+t)||1/e,function(r){return Math.max(0,Math.min(1,(r-t)/e))}}function Ta(t){for(var e=t.source,r=t.target,n=function(t,e){if(t===e)return t;var r=ka(t),n=ka(e),i=r.pop(),a=n.pop(),o=null;for(;i===a;)o=i,i=r.pop(),a=n.pop();return o}(e,r),i=[e];e!==n;)e=e.parent,i.push(e);for(var a=i.length;r!==n;)i.splice(a,0,r),r=r.parent;return i}function ka(t){for(var e=[],r=t.parent;null!=r;)e.push(t),t=r,r=r.parent;return e.push(t),e}function Ma(t){t.fixed|=2}function Aa(t){t.fixed&=-7}function Sa(t){t.fixed|=4,t.px=t.x,t.py=t.y}function Ea(t){t.fixed&=-5}t.interpolateTransform=ba,t.layout={},t.layout.bundle=function(){return function(t){for(var e=[],r=-1,n=t.length;++r<n;)e.push(Ta(t[r]));return e}},t.layout.chord=function(){var e,r,n,i,a,o,s,l={},c=0;function u(){var l,u,h,p,d,g={},m=[],v=t.range(i),y=[];for(e=[],r=[],l=0,p=-1;++p<i;){for(u=0,d=-1;++d<i;)u+=n[p][d];m.push(u),y.push(t.range(i)),l+=u}for(a&&v.sort((function(t,e){return a(m[t],m[e])})),o&&y.forEach((function(t,e){t.sort((function(t,r){return o(n[e][t],n[e][r])}))})),l=(St-c*i)/l,u=0,p=-1;++p<i;){for(h=u,d=-1;++d<i;){var x=v[p],b=y[x][d],_=n[x][b],w=u,T=u+=_*l;g[x+\"-\"+b]={index:x,subindex:b,startAngle:w,endAngle:T,value:_}}r[x]={index:x,startAngle:h,endAngle:u,value:m[x]},u+=c}for(p=-1;++p<i;)for(d=p-1;++d<i;){var k=g[p+\"-\"+d],M=g[d+\"-\"+p];(k.value||M.value)&&e.push(k.value<M.value?{source:M,target:k}:{source:k,target:M})}s&&f()}function f(){e.sort((function(t,e){return s((t.source.value+t.target.value)/2,(e.source.value+e.target.value)/2)}))}return l.matrix=function(t){return arguments.length?(i=(n=t)&&n.length,e=r=null,l):n},l.padding=function(t){return arguments.length?(c=t,e=r=null,l):c},l.sortGroups=function(t){return arguments.length?(a=t,e=r=null,l):a},l.sortSubgroups=function(t){return arguments.length?(o=t,e=null,l):o},l.sortChords=function(t){return arguments.length?(s=t,e&&f(),l):s},l.chords=function(){return e||u(),e},l.groups=function(){return r||u(),r},l},t.layout.force=function(){var e,r,n,i,a,o,s={},l=t.dispatch(\"start\",\"tick\",\"end\"),c=[1,1],u=.9,f=Ca,h=La,p=-30,d=Ia,g=.1,m=.64,v=[],y=[];function x(t){return function(e,r,n,i){if(e.point!==t){var a=e.cx-t.x,o=e.cy-t.y,s=i-r,l=a*a+o*o;if(s*s/m<l){if(l<d){var c=e.charge/l;t.px-=a*c,t.py-=o*c}return!0}if(e.point&&l&&l<d){c=e.pointCharge/l;t.px-=a*c,t.py-=o*c}}return!e.charge}}function b(e){e.px=t.event.x,e.py=t.event.y,s.resume()}return s.tick=function(){if((n*=.99)<.005)return e=null,l.end({type:\"end\",alpha:n=0}),!0;var r,s,f,h,d,m,b,_,w,T=v.length,k=y.length;for(s=0;s<k;++s)h=(f=y[s]).source,(m=(_=(d=f.target).x-h.x)*_+(w=d.y-h.y)*w)&&(_*=m=n*a[s]*((m=Math.sqrt(m))-i[s])/m,w*=m,d.x-=_*(b=h.weight+d.weight?h.weight/(h.weight+d.weight):.5),d.y-=w*b,h.x+=_*(b=1-b),h.y+=w*b);if((b=n*g)&&(_=c[0]/2,w=c[1]/2,s=-1,b))for(;++s<T;)(f=v[s]).x+=(_-f.x)*b,f.y+=(w-f.y)*b;if(p)for(!function t(e,r,n){var i=0,a=0;if(e.charge=0,!e.leaf)for(var o,s=e.nodes,l=s.length,c=-1;++c<l;)null!=(o=s[c])&&(t(o,r,n),e.charge+=o.charge,i+=o.charge*o.cx,a+=o.charge*o.cy);if(e.point){e.leaf||(e.point.x+=Math.random()-.5,e.point.y+=Math.random()-.5);var u=r*n[e.point.index];e.charge+=e.pointCharge=u,i+=u*e.point.x,a+=u*e.point.y}e.cx=i/e.charge,e.cy=a/e.charge}(r=t.geom.quadtree(v),n,o),s=-1;++s<T;)(f=v[s]).fixed||r.visit(x(f));for(s=-1;++s<T;)(f=v[s]).fixed?(f.x=f.px,f.y=f.py):(f.x-=(f.px-(f.px=f.x))*u,f.y-=(f.py-(f.py=f.y))*u);l.tick({type:\"tick\",alpha:n})},s.nodes=function(t){return arguments.length?(v=t,s):v},s.links=function(t){return arguments.length?(y=t,s):y},s.size=function(t){return arguments.length?(c=t,s):c},s.linkDistance=function(t){return arguments.length?(f=\"function\"==typeof t?t:+t,s):f},s.distance=s.linkDistance,s.linkStrength=function(t){return arguments.length?(h=\"function\"==typeof t?t:+t,s):h},s.friction=function(t){return arguments.length?(u=+t,s):u},s.charge=function(t){return arguments.length?(p=\"function\"==typeof t?t:+t,s):p},s.chargeDistance=function(t){return arguments.length?(d=t*t,s):Math.sqrt(d)},s.gravity=function(t){return arguments.length?(g=+t,s):g},s.theta=function(t){return arguments.length?(m=t*t,s):Math.sqrt(m)},s.alpha=function(t){return arguments.length?(t=+t,n?t>0?n=t:(e.c=null,e.t=NaN,e=null,l.end({type:\"end\",alpha:n=0})):t>0&&(l.start({type:\"start\",alpha:n=t}),e=we(s.tick)),s):n},s.start=function(){var t,e,r,n=v.length,l=y.length,u=c[0],d=c[1];for(t=0;t<n;++t)(r=v[t]).index=t,r.weight=0;for(t=0;t<l;++t)\"number\"==typeof(r=y[t]).source&&(r.source=v[r.source]),\"number\"==typeof r.target&&(r.target=v[r.target]),++r.source.weight,++r.target.weight;for(t=0;t<n;++t)r=v[t],isNaN(r.x)&&(r.x=g(\"x\",u)),isNaN(r.y)&&(r.y=g(\"y\",d)),isNaN(r.px)&&(r.px=r.x),isNaN(r.py)&&(r.py=r.y);if(i=[],\"function\"==typeof f)for(t=0;t<l;++t)i[t]=+f.call(this,y[t],t);else for(t=0;t<l;++t)i[t]=f;if(a=[],\"function\"==typeof h)for(t=0;t<l;++t)a[t]=+h.call(this,y[t],t);else for(t=0;t<l;++t)a[t]=h;if(o=[],\"function\"==typeof p)for(t=0;t<n;++t)o[t]=+p.call(this,v[t],t);else for(t=0;t<n;++t)o[t]=p;function g(r,i){if(!e){for(e=new Array(n),c=0;c<n;++c)e[c]=[];for(c=0;c<l;++c){var a=y[c];e[a.source.index].push(a.target),e[a.target.index].push(a.source)}}for(var o,s=e[t],c=-1,u=s.length;++c<u;)if(!isNaN(o=s[c][r]))return o;return Math.random()*i}return s.resume()},s.resume=function(){return s.alpha(.1)},s.stop=function(){return s.alpha(0)},s.drag=function(){if(r||(r=t.behavior.drag().origin(L).on(\"dragstart.force\",Ma).on(\"drag.force\",b).on(\"dragend.force\",Aa)),!arguments.length)return r;this.on(\"mouseover.force\",Sa).on(\"mouseout.force\",Ea).call(r)},t.rebind(s,l,\"on\")};var Ca=20,La=1,Ia=1/0;function Pa(e,r){return t.rebind(e,r,\"sort\",\"children\",\"value\"),e.nodes=e,e.links=Ba,e}function za(t,e){for(var r=[t];null!=(t=r.pop());)if(e(t),(i=t.children)&&(n=i.length))for(var n,i;--n>=0;)r.push(i[n])}function Oa(t,e){for(var r=[t],n=[];null!=(t=r.pop());)if(n.push(t),(a=t.children)&&(i=a.length))for(var i,a,o=-1;++o<i;)r.push(a[o]);for(;null!=(t=n.pop());)e(t)}function Da(t){return t.children}function Ra(t){return t.value}function Fa(t,e){return e.value-t.value}function Ba(e){return t.merge(e.map((function(t){return(t.children||[]).map((function(e){return{source:t,target:e}}))})))}t.layout.hierarchy=function(){var t=Fa,e=Da,r=Ra;function n(i){var a,o=[i],s=[];for(i.depth=0;null!=(a=o.pop());)if(s.push(a),(c=e.call(n,a,a.depth))&&(l=c.length)){for(var l,c,u;--l>=0;)o.push(u=c[l]),u.parent=a,u.depth=a.depth+1;r&&(a.value=0),a.children=c}else r&&(a.value=+r.call(n,a,a.depth)||0),delete a.children;return Oa(i,(function(e){var n,i;t&&(n=e.children)&&n.sort(t),r&&(i=e.parent)&&(i.value+=e.value)})),s}return n.sort=function(e){return arguments.length?(t=e,n):t},n.children=function(t){return arguments.length?(e=t,n):e},n.value=function(t){return arguments.length?(r=t,n):r},n.revalue=function(t){return r&&(za(t,(function(t){t.children&&(t.value=0)})),Oa(t,(function(t){var e;t.children||(t.value=+r.call(n,t,t.depth)||0),(e=t.parent)&&(e.value+=t.value)}))),t},n},t.layout.partition=function(){var e=t.layout.hierarchy(),r=[1,1];function n(t,n){var i=e.call(this,t,n);return function t(e,r,n,i){var a=e.children;if(e.x=r,e.y=e.depth*i,e.dx=n,e.dy=i,a&&(o=a.length)){var o,s,l,c=-1;for(n=e.value?n/e.value:0;++c<o;)t(s=a[c],r,l=s.value*n,i),r+=l}}(i[0],0,r[0],r[1]/function t(e){var r=e.children,n=0;if(r&&(i=r.length))for(var i,a=-1;++a<i;)n=Math.max(n,t(r[a]));return 1+n}(i[0])),i}return n.size=function(t){return arguments.length?(r=t,n):r},Pa(n,e)},t.layout.pie=function(){var e=Number,r=Na,n=0,i=St,a=0;function o(s){var l,c=s.length,u=s.map((function(t,r){return+e.call(o,t,r)})),f=+(\"function\"==typeof n?n.apply(this,arguments):n),h=(\"function\"==typeof i?i.apply(this,arguments):i)-f,p=Math.min(Math.abs(h)/c,+(\"function\"==typeof a?a.apply(this,arguments):a)),d=p*(h<0?-1:1),g=t.sum(u),m=g?(h-c*d)/g:0,v=t.range(c),y=[];return null!=r&&v.sort(r===Na?function(t,e){return u[e]-u[t]}:function(t,e){return r(s[t],s[e])}),v.forEach((function(t){y[t]={data:s[t],value:l=u[t],startAngle:f,endAngle:f+=l*m+d,padAngle:p}})),y}return o.value=function(t){return arguments.length?(e=t,o):e},o.sort=function(t){return arguments.length?(r=t,o):r},o.startAngle=function(t){return arguments.length?(n=t,o):n},o.endAngle=function(t){return arguments.length?(i=t,o):i},o.padAngle=function(t){return arguments.length?(a=t,o):a},o};var Na={};function ja(t){return t.x}function Ua(t){return t.y}function Va(t,e,r){t.y0=e,t.y=r}t.layout.stack=function(){var e=L,r=Ga,n=Ya,i=Va,a=ja,o=Ua;function s(l,c){if(!(p=l.length))return l;var u=l.map((function(t,r){return e.call(s,t,r)})),f=u.map((function(t){return t.map((function(t,e){return[a.call(s,t,e),o.call(s,t,e)]}))})),h=r.call(s,f,c);u=t.permute(u,h),f=t.permute(f,h);var p,d,g,m,v=n.call(s,f,c),y=u[0].length;for(g=0;g<y;++g)for(i.call(s,u[0][g],m=v[g],f[0][g][1]),d=1;d<p;++d)i.call(s,u[d][g],m+=f[d-1][g][1],f[d][g][1]);return l}return s.values=function(t){return arguments.length?(e=t,s):e},s.order=function(t){return arguments.length?(r=\"function\"==typeof t?t:qa.get(t)||Ga,s):r},s.offset=function(t){return arguments.length?(n=\"function\"==typeof t?t:Ha.get(t)||Ya,s):n},s.x=function(t){return arguments.length?(a=t,s):a},s.y=function(t){return arguments.length?(o=t,s):o},s.out=function(t){return arguments.length?(i=t,s):i},s};var qa=t.map({\"inside-out\":function(e){var r,n,i=e.length,a=e.map(Wa),o=e.map(Xa),s=t.range(i).sort((function(t,e){return a[t]-a[e]})),l=0,c=0,u=[],f=[];for(r=0;r<i;++r)n=s[r],l<c?(l+=o[n],u.push(n)):(c+=o[n],f.push(n));return f.reverse().concat(u)},reverse:function(e){return t.range(e.length).reverse()},default:Ga}),Ha=t.map({silhouette:function(t){var e,r,n,i=t.length,a=t[0].length,o=[],s=0,l=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];n>s&&(s=n),o.push(n)}for(r=0;r<a;++r)l[r]=(s-o[r])/2;return l},wiggle:function(t){var e,r,n,i,a,o,s,l,c,u=t.length,f=t[0],h=f.length,p=[];for(p[0]=l=c=0,r=1;r<h;++r){for(e=0,i=0;e<u;++e)i+=t[e][r][1];for(e=0,a=0,s=f[r][0]-f[r-1][0];e<u;++e){for(n=0,o=(t[e][r][1]-t[e][r-1][1])/(2*s);n<e;++n)o+=(t[n][r][1]-t[n][r-1][1])/s;a+=o*t[e][r][1]}p[r]=l-=i?a/i*s:0,l<c&&(c=l)}for(r=0;r<h;++r)p[r]-=c;return p},expand:function(t){var e,r,n,i=t.length,a=t[0].length,o=1/i,s=[];for(r=0;r<a;++r){for(e=0,n=0;e<i;e++)n+=t[e][r][1];if(n)for(e=0;e<i;e++)t[e][r][1]/=n;else for(e=0;e<i;e++)t[e][r][1]=o}for(r=0;r<a;++r)s[r]=0;return s},zero:Ya});function Ga(e){return t.range(e.length)}function Ya(t){for(var e=-1,r=t[0].length,n=[];++e<r;)n[e]=0;return n}function Wa(t){for(var e,r=1,n=0,i=t[0][1],a=t.length;r<a;++r)(e=t[r][1])>i&&(n=r,i=e);return n}function Xa(t){return t.reduce(Za,0)}function Za(t,e){return t+e[1]}function Ja(t,e){return Ka(t,Math.ceil(Math.log(e.length)/Math.LN2+1))}function Ka(t,e){for(var r=-1,n=+t[0],i=(t[1]-n)/e,a=[];++r<=e;)a[r]=i*r+n;return a}function Qa(e){return[t.min(e),t.max(e)]}function $a(t,e){return t.value-e.value}function to(t,e){var r=t._pack_next;t._pack_next=e,e._pack_prev=t,e._pack_next=r,r._pack_prev=e}function eo(t,e){t._pack_next=e,e._pack_prev=t}function ro(t,e){var r=e.x-t.x,n=e.y-t.y,i=t.r+e.r;return.999*i*i>r*r+n*n}function no(t){if((e=t.children)&&(l=e.length)){var e,r,n,i,a,o,s,l,c=1/0,u=-1/0,f=1/0,h=-1/0;if(e.forEach(io),(r=e[0]).x=-r.r,r.y=0,x(r),l>1&&((n=e[1]).x=n.r,n.y=0,x(n),l>2))for(oo(r,n,i=e[2]),x(i),to(r,i),r._pack_prev=i,to(i,n),n=r._pack_next,a=3;a<l;a++){oo(r,n,i=e[a]);var p=0,d=1,g=1;for(o=n._pack_next;o!==n;o=o._pack_next,d++)if(ro(o,i)){p=1;break}if(1==p)for(s=r._pack_prev;s!==o._pack_prev&&!ro(s,i);s=s._pack_prev,g++);p?(d<g||d==g&&n.r<r.r?eo(r,n=o):eo(r=s,n),a--):(to(r,i),n=i,x(i))}var m=(c+u)/2,v=(f+h)/2,y=0;for(a=0;a<l;a++)(i=e[a]).x-=m,i.y-=v,y=Math.max(y,i.r+Math.sqrt(i.x*i.x+i.y*i.y));t.r=y,e.forEach(ao)}function x(t){c=Math.min(t.x-t.r,c),u=Math.max(t.x+t.r,u),f=Math.min(t.y-t.r,f),h=Math.max(t.y+t.r,h)}}function io(t){t._pack_next=t._pack_prev=t}function ao(t){delete t._pack_next,delete t._pack_prev}function oo(t,e,r){var n=t.r+r.r,i=e.x-t.x,a=e.y-t.y;if(n&&(i||a)){var o=e.r+r.r,s=i*i+a*a,l=.5+((n*=n)-(o*=o))/(2*s),c=Math.sqrt(Math.max(0,2*o*(n+s)-(n-=s)*n-o*o))/(2*s);r.x=t.x+l*i+c*a,r.y=t.y+l*a-c*i}else r.x=t.x+n,r.y=t.y}function so(t,e){return t.parent==e.parent?1:2}function lo(t){var e=t.children;return e.length?e[0]:t.t}function co(t){var e,r=t.children;return(e=r.length)?r[e-1]:t.t}function uo(t,e,r){var n=r/(e.i-t.i);e.c-=n,e.s+=r,t.c+=n,e.z+=r,e.m+=r}function fo(t,e,r){return t.a.parent===e.parent?t.a:r}function ho(t){return{x:t.x,y:t.y,dx:t.dx,dy:t.dy}}function po(t,e){var r=t.x+e[3],n=t.y+e[0],i=t.dx-e[1]-e[3],a=t.dy-e[0]-e[2];return i<0&&(r+=i/2,i=0),a<0&&(n+=a/2,a=0),{x:r,y:n,dx:i,dy:a}}function go(t){var e=t[0],r=t[t.length-1];return e<r?[e,r]:[r,e]}function mo(t){return t.rangeExtent?t.rangeExtent():go(t.range())}function vo(t,e,r,n){var i=r(t[0],t[1]),a=n(e[0],e[1]);return function(t){return a(i(t))}}function yo(t,e){var r,n=0,i=t.length-1,a=t[n],o=t[i];return o<a&&(r=n,n=i,i=r,r=a,a=o,o=r),t[n]=e.floor(a),t[i]=e.ceil(o),t}function xo(t){return t?{floor:function(e){return Math.floor(e/t)*t},ceil:function(e){return Math.ceil(e/t)*t}}:bo}t.layout.histogram=function(){var e=!0,r=Number,n=Qa,i=Ja;function a(a,o){for(var s,l,c=[],u=a.map(r,this),f=n.call(this,u,o),h=i.call(this,f,u,o),p=(o=-1,u.length),d=h.length-1,g=e?1:1/p;++o<d;)(s=c[o]=[]).dx=h[o+1]-(s.x=h[o]),s.y=0;if(d>0)for(o=-1;++o<p;)(l=u[o])>=f[0]&&l<=f[1]&&((s=c[t.bisect(h,l,1,d)-1]).y+=g,s.push(a[o]));return c}return a.value=function(t){return arguments.length?(r=t,a):r},a.range=function(t){return arguments.length?(n=de(t),a):n},a.bins=function(t){return arguments.length?(i=\"number\"==typeof t?function(e){return Ka(e,t)}:de(t),a):i},a.frequency=function(t){return arguments.length?(e=!!t,a):e},a},t.layout.pack=function(){var e,r=t.layout.hierarchy().sort($a),n=0,i=[1,1];function a(t,a){var o=r.call(this,t,a),s=o[0],l=i[0],c=i[1],u=null==e?Math.sqrt:\"function\"==typeof e?e:function(){return e};if(s.x=s.y=0,Oa(s,(function(t){t.r=+u(t.value)})),Oa(s,no),n){var f=n*(e?1:Math.max(2*s.r/l,2*s.r/c))/2;Oa(s,(function(t){t.r+=f})),Oa(s,no),Oa(s,(function(t){t.r-=f}))}return function t(e,r,n,i){var a=e.children;if(e.x=r+=i*e.x,e.y=n+=i*e.y,e.r*=i,a)for(var o=-1,s=a.length;++o<s;)t(a[o],r,n,i)}(s,l/2,c/2,e?1:1/Math.max(2*s.r/l,2*s.r/c)),o}return a.size=function(t){return arguments.length?(i=t,a):i},a.radius=function(t){return arguments.length?(e=null==t||\"function\"==typeof t?t:+t,a):e},a.padding=function(t){return arguments.length?(n=+t,a):n},Pa(a,r)},t.layout.tree=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=null;function a(t,a){var c=e.call(this,t,a),u=c[0],f=function(t){var e,r={A:null,children:[t]},n=[r];for(;null!=(e=n.pop());)for(var i,a=e.children,o=0,s=a.length;o<s;++o)n.push((a[o]=i={_:a[o],parent:e,children:(i=a[o].children)&&i.slice()||[],A:null,a:null,z:0,m:0,c:0,s:0,t:null,i:o}).a=i);return r.children[0]}(u);if(Oa(f,o),f.parent.m=-f.z,za(f,s),i)za(u,l);else{var h=u,p=u,d=u;za(u,(function(t){t.x<h.x&&(h=t),t.x>p.x&&(p=t),t.depth>d.depth&&(d=t)}));var g=r(h,p)/2-h.x,m=n[0]/(p.x+r(p,h)/2+g),v=n[1]/(d.depth||1);za(u,(function(t){t.x=(t.x+g)*m,t.y=t.depth*v}))}return c}function o(t){var e=t.children,n=t.parent.children,i=t.i?n[t.i-1]:null;if(e.length){!function(t){var e,r=0,n=0,i=t.children,a=i.length;for(;--a>=0;)(e=i[a]).z+=r,e.m+=r,r+=e.s+(n+=e.c)}(t);var a=(e[0].z+e[e.length-1].z)/2;i?(t.z=i.z+r(t._,i._),t.m=t.z-a):t.z=a}else i&&(t.z=i.z+r(t._,i._));t.parent.A=function(t,e,n){if(e){for(var i,a=t,o=t,s=e,l=a.parent.children[0],c=a.m,u=o.m,f=s.m,h=l.m;s=co(s),a=lo(a),s&&a;)l=lo(l),(o=co(o)).a=t,(i=s.z+f-a.z-c+r(s._,a._))>0&&(uo(fo(s,t,n),t,i),c+=i,u+=i),f+=s.m,c+=a.m,h+=l.m,u+=o.m;s&&!co(o)&&(o.t=s,o.m+=f-u),a&&!lo(l)&&(l.t=a,l.m+=c-h,n=t)}return n}(t,i,t.parent.A||n[0])}function s(t){t._.x=t.z+t.parent.m,t.m+=t.parent.m}function l(t){t.x*=n[0],t.y=t.depth*n[1]}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t)?l:null,a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null==(n=t)?null:l,a):i?n:null},Pa(a,e)},t.layout.cluster=function(){var e=t.layout.hierarchy().sort(null).value(null),r=so,n=[1,1],i=!1;function a(a,o){var s,l=e.call(this,a,o),c=l[0],u=0;Oa(c,(function(e){var n=e.children;n&&n.length?(e.x=function(t){return t.reduce((function(t,e){return t+e.x}),0)/t.length}(n),e.y=function(e){return 1+t.max(e,(function(t){return t.y}))}(n)):(e.x=s?u+=r(e,s):0,e.y=0,s=e)}));var f=function t(e){var r=e.children;return r&&r.length?t(r[0]):e}(c),h=function t(e){var r,n=e.children;return n&&(r=n.length)?t(n[r-1]):e}(c),p=f.x-r(f,h)/2,d=h.x+r(h,f)/2;return Oa(c,i?function(t){t.x=(t.x-c.x)*n[0],t.y=(c.y-t.y)*n[1]}:function(t){t.x=(t.x-p)/(d-p)*n[0],t.y=(1-(c.y?t.y/c.y:1))*n[1]}),l}return a.separation=function(t){return arguments.length?(r=t,a):r},a.size=function(t){return arguments.length?(i=null==(n=t),a):i?null:n},a.nodeSize=function(t){return arguments.length?(i=null!=(n=t),a):i?n:null},Pa(a,e)},t.layout.treemap=function(){var e,r=t.layout.hierarchy(),n=Math.round,i=[1,1],a=null,o=ho,s=!1,l=\"squarify\",c=.5*(1+Math.sqrt(5));function u(t,e){for(var r,n,i=-1,a=t.length;++i<a;)n=(r=t[i]).value*(e<0?0:e),r.area=isNaN(n)||n<=0?0:n}function f(t){var e=t.children;if(e&&e.length){var r,n,i,a=o(t),s=[],c=e.slice(),h=1/0,g=\"slice\"===l?a.dx:\"dice\"===l?a.dy:\"slice-dice\"===l?1&t.depth?a.dy:a.dx:Math.min(a.dx,a.dy);for(u(c,a.dx*a.dy/t.value),s.area=0;(i=c.length)>0;)s.push(r=c[i-1]),s.area+=r.area,\"squarify\"!==l||(n=p(s,g))<=h?(c.pop(),h=n):(s.area-=s.pop().area,d(s,g,a,!1),g=Math.min(a.dx,a.dy),s.length=s.area=0,h=1/0);s.length&&(d(s,g,a,!0),s.length=s.area=0),e.forEach(f)}}function h(t){var e=t.children;if(e&&e.length){var r,n=o(t),i=e.slice(),a=[];for(u(i,n.dx*n.dy/t.value),a.area=0;r=i.pop();)a.push(r),a.area+=r.area,null!=r.z&&(d(a,r.z?n.dx:n.dy,n,!i.length),a.length=a.area=0);e.forEach(h)}}function p(t,e){for(var r,n=t.area,i=0,a=1/0,o=-1,s=t.length;++o<s;)(r=t[o].area)&&(r<a&&(a=r),r>i&&(i=r));return e*=e,(n*=n)?Math.max(e*i*c/n,n/(e*a*c)):1/0}function d(t,e,r,i){var a,o=-1,s=t.length,l=r.x,c=r.y,u=e?n(t.area/e):0;if(e==r.dx){for((i||u>r.dy)&&(u=r.dy);++o<s;)(a=t[o]).x=l,a.y=c,a.dy=u,l+=a.dx=Math.min(r.x+r.dx-l,u?n(a.area/u):0);a.z=!0,a.dx+=r.x+r.dx-l,r.y+=u,r.dy-=u}else{for((i||u>r.dx)&&(u=r.dx);++o<s;)(a=t[o]).x=l,a.y=c,a.dx=u,c+=a.dy=Math.min(r.y+r.dy-c,u?n(a.area/u):0);a.z=!1,a.dy+=r.y+r.dy-c,r.x+=u,r.dx-=u}}function g(t){var n=e||r(t),a=n[0];return a.x=a.y=0,a.value?(a.dx=i[0],a.dy=i[1]):a.dx=a.dy=0,e&&r.revalue(a),u([a],a.dx*a.dy/a.value),(e?h:f)(a),s&&(e=n),n}return g.size=function(t){return arguments.length?(i=t,g):i},g.padding=function(t){if(!arguments.length)return a;function e(e){var r=t.call(g,e,e.depth);return null==r?ho(e):po(e,\"number\"==typeof r?[r,r,r,r]:r)}function r(e){return po(e,t)}var n;return o=null==(a=t)?ho:\"function\"==(n=typeof t)?e:\"number\"===n?(t=[t,t,t,t],r):r,g},g.round=function(t){return arguments.length?(n=t?Math.round:Number,g):n!=Number},g.sticky=function(t){return arguments.length?(s=t,e=null,g):s},g.ratio=function(t){return arguments.length?(c=t,g):c},g.mode=function(t){return arguments.length?(l=t+\"\",g):l},Pa(g,r)},t.random={normal:function(t,e){var r=arguments.length;return r<2&&(e=1),r<1&&(t=0),function(){var r,n,i;do{i=(r=2*Math.random()-1)*r+(n=2*Math.random()-1)*n}while(!i||i>1);return t+e*r*Math.sqrt(-2*Math.log(i)/i)}},logNormal:function(){var e=t.random.normal.apply(t,arguments);return function(){return Math.exp(e())}},bates:function(e){var r=t.random.irwinHall(e);return function(){return r()/e}},irwinHall:function(t){return function(){for(var e=0,r=0;r<t;r++)e+=Math.random();return e}}},t.scale={};var bo={floor:L,ceil:L};function _o(e,r,n,i){var a=[],o=[],s=0,l=Math.min(e.length,r.length)-1;for(e[l]<e[0]&&(e=e.slice().reverse(),r=r.slice().reverse());++s<=l;)a.push(n(e[s-1],e[s])),o.push(i(r[s-1],r[s]));return function(r){var n=t.bisect(e,r,1,l)-1;return o[n](a[n](r))}}function wo(e,r){return t.rebind(e,r,\"range\",\"rangeRound\",\"interpolate\",\"clamp\")}function To(t,e){return yo(t,xo(ko(t,e)[2])),yo(t,xo(ko(t,e)[2])),t}function ko(t,e){null==e&&(e=10);var r=go(t),n=r[1]-r[0],i=Math.pow(10,Math.floor(Math.log(n/e)/Math.LN10)),a=e/n*i;return a<=.15?i*=10:a<=.35?i*=5:a<=.75&&(i*=2),r[0]=Math.ceil(r[0]/i)*i,r[1]=Math.floor(r[1]/i)*i+.5*i,r[2]=i,r}function Mo(e,r){return t.range.apply(t,ko(e,r))}function Ao(e,r,n){var i=ko(e,r);if(n){var a=Ce.exec(n);if(a.shift(),\"s\"===a[8]){var o=t.formatPrefix(Math.max(y(i[0]),y(i[1])));return a[7]||(a[7]=\".\"+Eo(o.scale(i[2]))),a[8]=\"f\",n=t.format(a.join(\"\")),function(t){return n(o.scale(t))+o.symbol}}a[7]||(a[7]=\".\"+function(t,e){var r=Eo(e[2]);return t in So?Math.abs(r-Eo(Math.max(y(e[0]),y(e[1]))))+ +(\"e\"!==t):r-2*(\"%\"===t)}(a[8],i)),n=a.join(\"\")}else n=\",.\"+Eo(i[2])+\"f\";return t.format(n)}t.scale.linear=function(){return function t(e,r,n,i){var a,o;function s(){var t=Math.min(e.length,r.length)>2?_o:vo,s=i?wa:_a;return a=t(e,r,s,n),o=t(r,e,s,$i),l}function l(t){return a(t)}return l.invert=function(t){return o(t)},l.domain=function(t){return arguments.length?(e=t.map(Number),s()):e},l.range=function(t){return arguments.length?(r=t,s()):r},l.rangeRound=function(t){return l.range(t).interpolate(da)},l.clamp=function(t){return arguments.length?(i=t,s()):i},l.interpolate=function(t){return arguments.length?(n=t,s()):n},l.ticks=function(t){return Mo(e,t)},l.tickFormat=function(t,r){return Ao(e,t,r)},l.nice=function(t){return To(e,t),s()},l.copy=function(){return t(e,r,n,i)},s()}([0,1],[0,1],$i,!1)};var So={s:1,g:1,p:1,r:1,e:1};function Eo(t){return-Math.floor(Math.log(t)/Math.LN10+.01)}t.scale.log=function(){return function e(r,n,i,a){function o(t){return(i?Math.log(t<0?0:t):-Math.log(t>0?0:-t))/Math.log(n)}function s(t){return i?Math.pow(n,t):-Math.pow(n,-t)}function l(t){return r(o(t))}return l.invert=function(t){return s(r.invert(t))},l.domain=function(t){return arguments.length?(i=t[0]>=0,r.domain((a=t.map(Number)).map(o)),l):a},l.base=function(t){return arguments.length?(n=+t,r.domain(a.map(o)),l):n},l.nice=function(){var t=yo(a.map(o),i?Math:Lo);return r.domain(t),a=t.map(s),l},l.ticks=function(){var t=go(a),e=[],r=t[0],l=t[1],c=Math.floor(o(r)),u=Math.ceil(o(l)),f=n%1?2:n;if(isFinite(u-c)){if(i){for(;c<u;c++)for(var h=1;h<f;h++)e.push(s(c)*h);e.push(s(c))}else for(e.push(s(c));c++<u;)for(h=f-1;h>0;h--)e.push(s(c)*h);for(c=0;e[c]<r;c++);for(u=e.length;e[u-1]>l;u--);e=e.slice(c,u)}return e},l.tickFormat=function(e,r){if(!arguments.length)return Co;arguments.length<2?r=Co:\"function\"!=typeof r&&(r=t.format(r));var i=Math.max(1,n*e/l.ticks().length);return function(t){var e=t/s(Math.round(o(t)));return e*n<n-.5&&(e*=n),e<=i?r(t):\"\"}},l.copy=function(){return e(r.copy(),n,i,a)},wo(l,r)}(t.scale.linear().domain([0,1]),10,!0,[1,10])};var Co=t.format(\".0e\"),Lo={floor:function(t){return-Math.ceil(-t)},ceil:function(t){return-Math.floor(-t)}};function Io(t){return function(e){return e<0?-Math.pow(-e,t):Math.pow(e,t)}}t.scale.pow=function(){return function t(e,r,n){var i=Io(r),a=Io(1/r);function o(t){return e(i(t))}return o.invert=function(t){return a(e.invert(t))},o.domain=function(t){return arguments.length?(e.domain((n=t.map(Number)).map(i)),o):n},o.ticks=function(t){return Mo(n,t)},o.tickFormat=function(t,e){return Ao(n,t,e)},o.nice=function(t){return o.domain(To(n,t))},o.exponent=function(t){return arguments.length?(i=Io(r=t),a=Io(1/r),e.domain(n.map(i)),o):r},o.copy=function(){return t(e.copy(),r,n)},wo(o,e)}(t.scale.linear(),1,[0,1])},t.scale.sqrt=function(){return t.scale.pow().exponent(.5)},t.scale.ordinal=function(){return function e(r,n){var i,a,o;function s(t){return a[((i.get(t)||(\"range\"===n.t?i.set(t,r.push(t)):NaN))-1)%a.length]}function l(e,n){return t.range(r.length).map((function(t){return e+n*t}))}return s.domain=function(t){if(!arguments.length)return r;r=[],i=new _;for(var e,a=-1,o=t.length;++a<o;)i.has(e=t[a])||i.set(e,r.push(e));return s[n.t].apply(s,n.a)},s.range=function(t){return arguments.length?(a=t,o=0,n={t:\"range\",a:arguments},s):a},s.rangePoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=(i+c)/2,0):(c-i)/(r.length-1+e);return a=l(i+u*e/2,u),o=0,n={t:\"rangePoints\",a:arguments},s},s.rangeRoundPoints=function(t,e){arguments.length<2&&(e=0);var i=t[0],c=t[1],u=r.length<2?(i=c=Math.round((i+c)/2),0):(c-i)/(r.length-1+e)|0;return a=l(i+Math.round(u*e/2+(c-i-(r.length-1+e)*u)/2),u),o=0,n={t:\"rangeRoundPoints\",a:arguments},s},s.rangeBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=(f-u)/(r.length-e+2*i);return a=l(u+h*i,h),c&&a.reverse(),o=h*(1-e),n={t:\"rangeBands\",a:arguments},s},s.rangeRoundBands=function(t,e,i){arguments.length<2&&(e=0),arguments.length<3&&(i=e);var c=t[1]<t[0],u=t[c-0],f=t[1-c],h=Math.floor((f-u)/(r.length-e+2*i));return a=l(u+Math.round((f-u-(r.length-e)*h)/2),h),c&&a.reverse(),o=Math.round(h*(1-e)),n={t:\"rangeRoundBands\",a:arguments},s},s.rangeBand=function(){return o},s.rangeExtent=function(){return go(n.a[0])},s.copy=function(){return e(r,n)},s.domain(r)}([],{t:\"range\",a:[[]]})},t.scale.category10=function(){return t.scale.ordinal().range(Po)},t.scale.category20=function(){return t.scale.ordinal().range(zo)},t.scale.category20b=function(){return t.scale.ordinal().range(Oo)},t.scale.category20c=function(){return t.scale.ordinal().range(Do)};var Po=[2062260,16744206,2924588,14034728,9725885,9197131,14907330,8355711,12369186,1556175].map(ae),zo=[2062260,11454440,16744206,16759672,2924588,10018698,14034728,16750742,9725885,12955861,9197131,12885140,14907330,16234194,8355711,13092807,12369186,14408589,1556175,10410725].map(ae),Oo=[3750777,5395619,7040719,10264286,6519097,9216594,11915115,13556636,9202993,12426809,15186514,15190932,8666169,11356490,14049643,15177372,8077683,10834324,13528509,14589654].map(ae),Do=[3244733,7057110,10406625,13032431,15095053,16616764,16625259,16634018,3253076,7652470,10607003,13101504,7695281,10394312,12369372,14342891,6513507,9868950,12434877,14277081].map(ae);function Ro(){return 0}t.scale.quantile=function(){return function e(r,n){var i;function a(){var e=0,a=n.length;for(i=[];++e<a;)i[e-1]=t.quantile(r,e/a);return o}function o(e){if(!isNaN(e=+e))return n[t.bisect(i,e)]}return o.domain=function(t){return arguments.length?(r=t.map(p).filter(d).sort(h),a()):r},o.range=function(t){return arguments.length?(n=t,a()):n},o.quantiles=function(){return i},o.invertExtent=function(t){return(t=n.indexOf(t))<0?[NaN,NaN]:[t>0?i[t-1]:r[0],t<i.length?i[t]:r[r.length-1]]},o.copy=function(){return e(r,n)},a()}([],[])},t.scale.quantize=function(){return function t(e,r,n){var i,a;function o(t){return n[Math.max(0,Math.min(a,Math.floor(i*(t-e))))]}function s(){return i=n.length/(r-e),a=n.length-1,o}return o.domain=function(t){return arguments.length?(e=+t[0],r=+t[t.length-1],s()):[e,r]},o.range=function(t){return arguments.length?(n=t,s()):n},o.invertExtent=function(t){return[t=(t=n.indexOf(t))<0?NaN:t/i+e,t+1/i]},o.copy=function(){return t(e,r,n)},s()}(0,1,[0,1])},t.scale.threshold=function(){return function e(r,n){function i(e){if(e<=e)return n[t.bisect(r,e)]}return i.domain=function(t){return arguments.length?(r=t,i):r},i.range=function(t){return arguments.length?(n=t,i):n},i.invertExtent=function(t){return t=n.indexOf(t),[r[t-1],r[t]]},i.copy=function(){return e(r,n)},i}([.5],[0,1])},t.scale.identity=function(){return function t(e){function r(t){return+t}return r.invert=r,r.domain=r.range=function(t){return arguments.length?(e=t.map(r),r):e},r.ticks=function(t){return Mo(e,t)},r.tickFormat=function(t,r){return Ao(e,t,r)},r.copy=function(){return t(e)},r}([0,1])},t.svg={},t.svg.arc=function(){var t=Bo,e=No,r=Ro,n=Fo,i=jo,a=Uo,o=Vo;function s(){var s=Math.max(0,+t.apply(this,arguments)),c=Math.max(0,+e.apply(this,arguments)),u=i.apply(this,arguments)-Ct,f=a.apply(this,arguments)-Ct,h=Math.abs(f-u),p=u>f?0:1;if(c<s&&(d=c,c=s,s=d),h>=Et)return l(c,p)+(s?l(s,1-p):\"\")+\"Z\";var d,g,m,v,y,x,b,_,w,T,k,M,A=0,S=0,E=[];if((v=(+o.apply(this,arguments)||0)/2)&&(m=n===Fo?Math.sqrt(s*s+c*c):+n.apply(this,arguments),p||(S*=-1),c&&(S=Dt(m/c*Math.sin(v))),s&&(A=Dt(m/s*Math.sin(v)))),c){y=c*Math.cos(u+S),x=c*Math.sin(u+S),b=c*Math.cos(f-S),_=c*Math.sin(f-S);var C=Math.abs(f-u-2*S)<=At?0:1;if(S&&qo(y,x,b,_)===p^C){var L=(u+f)/2;y=c*Math.cos(L),x=c*Math.sin(L),b=_=null}}else y=x=0;if(s){w=s*Math.cos(f-A),T=s*Math.sin(f-A),k=s*Math.cos(u+A),M=s*Math.sin(u+A);var I=Math.abs(u-f+2*A)<=At?0:1;if(A&&qo(w,T,k,M)===1-p^I){var P=(u+f)/2;w=s*Math.cos(P),T=s*Math.sin(P),k=M=null}}else w=T=0;if(h>kt&&(d=Math.min(Math.abs(c-s)/2,+r.apply(this,arguments)))>.001){g=s<c^p?0:1;var z=d,O=d;if(h<At){var D=null==k?[w,T]:null==b?[y,x]:li([y,x],[k,M],[b,_],[w,T]),R=y-D[0],F=x-D[1],B=b-D[0],N=_-D[1],j=1/Math.sin(Math.acos((R*B+F*N)/(Math.sqrt(R*R+F*F)*Math.sqrt(B*B+N*N)))/2),U=Math.sqrt(D[0]*D[0]+D[1]*D[1]);O=Math.min(d,(s-U)/(j-1)),z=Math.min(d,(c-U)/(j+1))}if(null!=b){var V=Ho(null==k?[w,T]:[k,M],[y,x],c,z,p),q=Ho([b,_],[w,T],c,z,p);d===z?E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 0,\",g,\" \",V[1],\"A\",c,\",\",c,\" 0 \",1-p^qo(V[1][0],V[1][1],q[1][0],q[1][1]),\",\",p,\" \",q[1],\"A\",z,\",\",z,\" 0 0,\",g,\" \",q[0]):E.push(\"M\",V[0],\"A\",z,\",\",z,\" 0 1,\",g,\" \",q[0])}else E.push(\"M\",y,\",\",x);if(null!=k){var H=Ho([y,x],[k,M],s,-O,p),G=Ho([w,T],null==b?[y,x]:[b,_],s,-O,p);d===O?E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",G[1],\"A\",s,\",\",s,\" 0 \",p^qo(G[1][0],G[1][1],H[1][0],H[1][1]),\",\",1-p,\" \",H[1],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0]):E.push(\"L\",G[0],\"A\",O,\",\",O,\" 0 0,\",g,\" \",H[0])}else E.push(\"L\",w,\",\",T)}else E.push(\"M\",y,\",\",x),null!=b&&E.push(\"A\",c,\",\",c,\" 0 \",C,\",\",p,\" \",b,\",\",_),E.push(\"L\",w,\",\",T),null!=k&&E.push(\"A\",s,\",\",s,\" 0 \",I,\",\",1-p,\" \",k,\",\",M);return E.push(\"Z\"),E.join(\"\")}function l(t,e){return\"M0,\"+t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+-t+\"A\"+t+\",\"+t+\" 0 1,\"+e+\" 0,\"+t}return s.innerRadius=function(e){return arguments.length?(t=de(e),s):t},s.outerRadius=function(t){return arguments.length?(e=de(t),s):e},s.cornerRadius=function(t){return arguments.length?(r=de(t),s):r},s.padRadius=function(t){return arguments.length?(n=t==Fo?Fo:de(t),s):n},s.startAngle=function(t){return arguments.length?(i=de(t),s):i},s.endAngle=function(t){return arguments.length?(a=de(t),s):a},s.padAngle=function(t){return arguments.length?(o=de(t),s):o},s.centroid=function(){var r=(+t.apply(this,arguments)+ +e.apply(this,arguments))/2,n=(+i.apply(this,arguments)+ +a.apply(this,arguments))/2-Ct;return[Math.cos(n)*r,Math.sin(n)*r]},s};var Fo=\"auto\";function Bo(t){return t.innerRadius}function No(t){return t.outerRadius}function jo(t){return t.startAngle}function Uo(t){return t.endAngle}function Vo(t){return t&&t.padAngle}function qo(t,e,r,n){return(t-r)*e-(e-n)*t>0?0:1}function Ho(t,e,r,n,i){var a=t[0]-e[0],o=t[1]-e[1],s=(i?n:-n)/Math.sqrt(a*a+o*o),l=s*o,c=-s*a,u=t[0]+l,f=t[1]+c,h=e[0]+l,p=e[1]+c,d=(u+h)/2,g=(f+p)/2,m=h-u,v=p-f,y=m*m+v*v,x=r-n,b=u*p-h*f,_=(v<0?-1:1)*Math.sqrt(Math.max(0,x*x*y-b*b)),w=(b*v-m*_)/y,T=(-b*m-v*_)/y,k=(b*v+m*_)/y,M=(-b*m+v*_)/y,A=w-d,S=T-g,E=k-d,C=M-g;return A*A+S*S>E*E+C*C&&(w=k,T=M),[[w-l,T-c],[w*r/x,T*r/x]]}function Go(t){var e=ri,r=ni,n=Yr,i=Wo,a=i.key,o=.7;function s(a){var s,l=[],c=[],u=-1,f=a.length,h=de(e),p=de(r);function d(){l.push(\"M\",i(t(c),o))}for(;++u<f;)n.call(this,s=a[u],u)?c.push([+h.call(this,s,u),+p.call(this,s,u)]):c.length&&(d(),c=[]);return c.length&&d(),l.length?l.join(\"\"):null}return s.x=function(t){return arguments.length?(e=t,s):e},s.y=function(t){return arguments.length?(r=t,s):r},s.defined=function(t){return arguments.length?(n=t,s):n},s.interpolate=function(t){return arguments.length?(a=\"function\"==typeof t?i=t:(i=Yo.get(t)||Wo).key,s):a},s.tension=function(t){return arguments.length?(o=t,s):o},s}t.svg.line=function(){return Go(L)};var Yo=t.map({linear:Wo,\"linear-closed\":Xo,step:function(t){var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];for(;++e<r;)i.push(\"H\",(n[0]+(n=t[e])[0])/2,\"V\",n[1]);r>1&&i.push(\"H\",n[0]);return i.join(\"\")},\"step-before\":Zo,\"step-after\":Jo,basis:$o,\"basis-open\":function(t){if(t.length<4)return Wo(t);var e,r=[],n=-1,i=t.length,a=[0],o=[0];for(;++n<3;)e=t[n],a.push(e[0]),o.push(e[1]);r.push(ts(ns,a)+\",\"+ts(ns,o)),--n;for(;++n<i;)e=t[n],a.shift(),a.push(e[0]),o.shift(),o.push(e[1]),is(r,a,o);return r.join(\"\")},\"basis-closed\":function(t){var e,r,n=-1,i=t.length,a=i+4,o=[],s=[];for(;++n<4;)r=t[n%i],o.push(r[0]),s.push(r[1]);e=[ts(ns,o),\",\",ts(ns,s)],--n;for(;++n<a;)r=t[n%i],o.shift(),o.push(r[0]),s.shift(),s.push(r[1]),is(e,o,s);return e.join(\"\")},bundle:function(t,e){var r=t.length-1;if(r)for(var n,i,a=t[0][0],o=t[0][1],s=t[r][0]-a,l=t[r][1]-o,c=-1;++c<=r;)n=t[c],i=c/r,n[0]=e*n[0]+(1-e)*(a+i*s),n[1]=e*n[1]+(1-e)*(o+i*l);return $o(t)},cardinal:function(t,e){return t.length<3?Wo(t):t[0]+Ko(t,Qo(t,e))},\"cardinal-open\":function(t,e){return t.length<4?Wo(t):t[1]+Ko(t.slice(1,-1),Qo(t,e))},\"cardinal-closed\":function(t,e){return t.length<3?Xo(t):t[0]+Ko((t.push(t[0]),t),Qo([t[t.length-2]].concat(t,[t[1]]),e))},monotone:function(t){return t.length<3?Wo(t):t[0]+Ko(t,function(t){var e,r,n,i,a=[],o=function(t){var e=0,r=t.length-1,n=[],i=t[0],a=t[1],o=n[0]=as(i,a);for(;++e<r;)n[e]=(o+(o=as(i=a,a=t[e+1])))/2;return n[e]=o,n}(t),s=-1,l=t.length-1;for(;++s<l;)e=as(t[s],t[s+1]),y(e)<kt?o[s]=o[s+1]=0:(r=o[s]/e,n=o[s+1]/e,(i=r*r+n*n)>9&&(i=3*e/Math.sqrt(i),o[s]=i*r,o[s+1]=i*n));s=-1;for(;++s<=l;)i=(t[Math.min(l,s+1)][0]-t[Math.max(0,s-1)][0])/(6*(1+o[s]*o[s])),a.push([i||0,o[s]*i||0]);return a}(t))}});function Wo(t){return t.length>1?t.join(\"L\"):t+\"Z\"}function Xo(t){return t.join(\"L\")+\"Z\"}function Zo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"V\",(n=t[e])[1],\"H\",n[0]);return i.join(\"\")}function Jo(t){for(var e=0,r=t.length,n=t[0],i=[n[0],\",\",n[1]];++e<r;)i.push(\"H\",(n=t[e])[0],\"V\",n[1]);return i.join(\"\")}function Ko(t,e){if(e.length<1||t.length!=e.length&&t.length!=e.length+2)return Wo(t);var r=t.length!=e.length,n=\"\",i=t[0],a=t[1],o=e[0],s=o,l=1;if(r&&(n+=\"Q\"+(a[0]-2*o[0]/3)+\",\"+(a[1]-2*o[1]/3)+\",\"+a[0]+\",\"+a[1],i=t[1],l=2),e.length>1){s=e[1],a=t[l],l++,n+=\"C\"+(i[0]+o[0])+\",\"+(i[1]+o[1])+\",\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1];for(var c=2;c<e.length;c++,l++)a=t[l],s=e[c],n+=\"S\"+(a[0]-s[0])+\",\"+(a[1]-s[1])+\",\"+a[0]+\",\"+a[1]}if(r){var u=t[l];n+=\"Q\"+(a[0]+2*s[0]/3)+\",\"+(a[1]+2*s[1]/3)+\",\"+u[0]+\",\"+u[1]}return n}function Qo(t,e){for(var r,n=[],i=(1-e)/2,a=t[0],o=t[1],s=1,l=t.length;++s<l;)r=a,a=o,o=t[s],n.push([i*(o[0]-r[0]),i*(o[1]-r[1])]);return n}function $o(t){if(t.length<3)return Wo(t);var e=1,r=t.length,n=t[0],i=n[0],a=n[1],o=[i,i,i,(n=t[1])[0]],s=[a,a,a,n[1]],l=[i,\",\",a,\"L\",ts(ns,o),\",\",ts(ns,s)];for(t.push(t[r-1]);++e<=r;)n=t[e],o.shift(),o.push(n[0]),s.shift(),s.push(n[1]),is(l,o,s);return t.pop(),l.push(\"L\",n),l.join(\"\")}function ts(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}Yo.forEach((function(t,e){e.key=t,e.closed=/-closed$/.test(t)}));var es=[0,2/3,1/3,0],rs=[0,1/3,2/3,0],ns=[0,1/6,2/3,1/6];function is(t,e,r){t.push(\"C\",ts(es,e),\",\",ts(es,r),\",\",ts(rs,e),\",\",ts(rs,r),\",\",ts(ns,e),\",\",ts(ns,r))}function as(t,e){return(e[1]-t[1])/(e[0]-t[0])}function os(t){for(var e,r,n,i=-1,a=t.length;++i<a;)r=(e=t[i])[0],n=e[1]-Ct,e[0]=r*Math.cos(n),e[1]=r*Math.sin(n);return t}function ss(t){var e=ri,r=ri,n=0,i=ni,a=Yr,o=Wo,s=o.key,l=o,c=\"L\",u=.7;function f(s){var f,h,p,d=[],g=[],m=[],v=-1,y=s.length,x=de(e),b=de(n),_=e===r?function(){return h}:de(r),w=n===i?function(){return p}:de(i);function T(){d.push(\"M\",o(t(m),u),c,l(t(g.reverse()),u),\"Z\")}for(;++v<y;)a.call(this,f=s[v],v)?(g.push([h=+x.call(this,f,v),p=+b.call(this,f,v)]),m.push([+_.call(this,f,v),+w.call(this,f,v)])):g.length&&(T(),g=[],m=[]);return g.length&&T(),d.length?d.join(\"\"):null}return f.x=function(t){return arguments.length?(e=r=t,f):r},f.x0=function(t){return arguments.length?(e=t,f):e},f.x1=function(t){return arguments.length?(r=t,f):r},f.y=function(t){return arguments.length?(n=i=t,f):i},f.y0=function(t){return arguments.length?(n=t,f):n},f.y1=function(t){return arguments.length?(i=t,f):i},f.defined=function(t){return arguments.length?(a=t,f):a},f.interpolate=function(t){return arguments.length?(s=\"function\"==typeof t?o=t:(o=Yo.get(t)||Wo).key,l=o.reverse||o,c=o.closed?\"M\":\"L\",f):s},f.tension=function(t){return arguments.length?(u=t,f):u},f}function ls(t){return t.radius}function cs(t){return[t.x,t.y]}function us(t){return function(){var e=t.apply(this,arguments),r=e[0],n=e[1]-Ct;return[r*Math.cos(n),r*Math.sin(n)]}}function fs(){return 64}function hs(){return\"circle\"}function ps(t){var e=Math.sqrt(t/At);return\"M0,\"+e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+-e+\"A\"+e+\",\"+e+\" 0 1,1 0,\"+e+\"Z\"}t.svg.line.radial=function(){var t=Go(os);return t.radius=t.x,delete t.x,t.angle=t.y,delete t.y,t},Zo.reverse=Jo,Jo.reverse=Zo,t.svg.area=function(){return ss(L)},t.svg.area.radial=function(){var t=ss(os);return t.radius=t.x,delete t.x,t.innerRadius=t.x0,delete t.x0,t.outerRadius=t.x1,delete t.x1,t.angle=t.y,delete t.y,t.startAngle=t.y0,delete t.y0,t.endAngle=t.y1,delete t.y1,t},t.svg.chord=function(){var t=Vn,e=qn,r=ls,n=jo,i=Uo;function a(r,n){var i,a,c=o(this,t,r,n),u=o(this,e,r,n);return\"M\"+c.p0+s(c.r,c.p1,c.a1-c.a0)+(a=u,((i=c).a0==a.a0&&i.a1==a.a1?l(c.r,c.p1,c.r,c.p0):l(c.r,c.p1,u.r,u.p0)+s(u.r,u.p1,u.a1-u.a0)+l(u.r,u.p1,c.r,c.p0))+\"Z\")}function o(t,e,a,o){var s=e.call(t,a,o),l=r.call(t,s,o),c=n.call(t,s,o)-Ct,u=i.call(t,s,o)-Ct;return{r:l,a0:c,a1:u,p0:[l*Math.cos(c),l*Math.sin(c)],p1:[l*Math.cos(u),l*Math.sin(u)]}}function s(t,e,r){return\"A\"+t+\",\"+t+\" 0 \"+ +(r>At)+\",1 \"+e}function l(t,e,r,n){return\"Q 0,0 \"+n}return a.radius=function(t){return arguments.length?(r=de(t),a):r},a.source=function(e){return arguments.length?(t=de(e),a):t},a.target=function(t){return arguments.length?(e=de(t),a):e},a.startAngle=function(t){return arguments.length?(n=de(t),a):n},a.endAngle=function(t){return arguments.length?(i=de(t),a):i},a},t.svg.diagonal=function(){var t=Vn,e=qn,r=cs;function n(n,i){var a=t.call(this,n,i),o=e.call(this,n,i),s=(a.y+o.y)/2,l=[a,{x:a.x,y:s},{x:o.x,y:s},o];return\"M\"+(l=l.map(r))[0]+\"C\"+l[1]+\" \"+l[2]+\" \"+l[3]}return n.source=function(e){return arguments.length?(t=de(e),n):t},n.target=function(t){return arguments.length?(e=de(t),n):e},n.projection=function(t){return arguments.length?(r=t,n):r},n},t.svg.diagonal.radial=function(){var e=t.svg.diagonal(),r=cs,n=e.projection;return e.projection=function(t){return arguments.length?n(us(r=t)):r},e},t.svg.symbol=function(){var t=hs,e=fs;function r(r,n){return(ds.get(t.call(this,r,n))||ps)(e.call(this,r,n))}return r.type=function(e){return arguments.length?(t=de(e),r):t},r.size=function(t){return arguments.length?(e=de(t),r):e},r};var ds=t.map({circle:ps,cross:function(t){var e=Math.sqrt(t/5)/2;return\"M\"+-3*e+\",\"+-e+\"H\"+-e+\"V\"+-3*e+\"H\"+e+\"V\"+-e+\"H\"+3*e+\"V\"+e+\"H\"+e+\"V\"+3*e+\"H\"+-e+\"V\"+e+\"H\"+-3*e+\"Z\"},diamond:function(t){var e=Math.sqrt(t/(2*ms)),r=e*ms;return\"M0,\"+-e+\"L\"+r+\",0 0,\"+e+\" \"+-r+\",0Z\"},square:function(t){var e=Math.sqrt(t)/2;return\"M\"+-e+\",\"+-e+\"L\"+e+\",\"+-e+\" \"+e+\",\"+e+\" \"+-e+\",\"+e+\"Z\"},\"triangle-down\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+r+\"L\"+e+\",\"+-r+\" \"+-e+\",\"+-r+\"Z\"},\"triangle-up\":function(t){var e=Math.sqrt(t/gs),r=e*gs/2;return\"M0,\"+-r+\"L\"+e+\",\"+r+\" \"+-e+\",\"+r+\"Z\"}});t.svg.symbolTypes=ds.keys();var gs=Math.sqrt(3),ms=Math.tan(30*Lt);Y.transition=function(t){for(var e,r,n=bs||++Ts,i=As(t),a=[],o=_s||{time:Date.now(),ease:ca,delay:0,duration:250},s=-1,l=this.length;++s<l;){a.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(r=c[u])&&Ss(r,u,i,n,o),e.push(r)}return xs(a,i,n)},Y.interrupt=function(t){return this.each(null==t?vs:ys(As(t)))};var vs=ys(As());function ys(t){return function(){var e,r,n;(e=this[t])&&(n=e[r=e.active])&&(n.timer.c=null,n.timer.t=NaN,--e.count?delete e[r]:delete this[t],e.active+=.5,n.event&&n.event.interrupt.call(this,this.__data__,n.index))}}function xs(t,e,r){return U(t,ws),t.namespace=e,t.id=r,t}var bs,_s,ws=[],Ts=0;function ks(t,e,r,n){var i=t.id,a=t.namespace;return ut(t,\"function\"==typeof r?function(t,o,s){t[a][i].tween.set(e,n(r.call(t,t.__data__,o,s)))}:(r=n(r),function(t){t[a][i].tween.set(e,r)}))}function Ms(t){return null==t&&(t=\"\"),function(){this.textContent=t}}function As(t){return null==t?\"__transition__\":\"__transition_\"+t+\"__\"}function Ss(t,e,r,n,i){var a,o,s,l,c,u=t[r]||(t[r]={active:0,count:0}),f=u[n];function h(r){var i=u.active,h=u[i];for(var d in h&&(h.timer.c=null,h.timer.t=NaN,--u.count,delete u[i],h.event&&h.event.interrupt.call(t,t.__data__,h.index)),u)if(+d<n){var g=u[d];g.timer.c=null,g.timer.t=NaN,--u.count,delete u[d]}o.c=p,we((function(){return o.c&&p(r||1)&&(o.c=null,o.t=NaN),1}),0,a),u.active=n,f.event&&f.event.start.call(t,t.__data__,e),c=[],f.tween.forEach((function(r,n){(n=n.call(t,t.__data__,e))&&c.push(n)})),l=f.ease,s=f.duration}function p(i){for(var a=i/s,o=l(a),h=c.length;h>0;)c[--h].call(t,o);if(a>=1)return f.event&&f.event.end.call(t,t.__data__,e),--u.count?delete u[n]:delete t[r],1}f||(a=i.time,o=we((function(t){var e=f.delay;if(o.t=e+a,e<=t)return h(t-e);o.c=h}),0,a),f=u[n]={tween:new _,time:a,timer:o,delay:i.delay,duration:i.duration,ease:i.ease,index:e},i=null,++u.count)}ws.call=Y.call,ws.empty=Y.empty,ws.node=Y.node,ws.size=Y.size,t.transition=function(e,r){return e&&e.transition?bs?e.transition(r):e:t.selection().transition(e)},t.transition.prototype=ws,ws.select=function(t){var e,r,n,i=this.id,a=this.namespace,o=[];t=W(t);for(var s=-1,l=this.length;++s<l;){o.push(e=[]);for(var c=this[s],u=-1,f=c.length;++u<f;)(n=c[u])&&(r=t.call(n,n.__data__,u,s))?(\"__data__\"in n&&(r.__data__=n.__data__),Ss(r,u,a,i,n[a][i]),e.push(r)):e.push(null)}return xs(o,a,i)},ws.selectAll=function(t){var e,r,n,i,a,o=this.id,s=this.namespace,l=[];t=X(t);for(var c=-1,u=this.length;++c<u;)for(var f=this[c],h=-1,p=f.length;++h<p;)if(n=f[h]){a=n[s][o],r=t.call(n,n.__data__,h,c),l.push(e=[]);for(var d=-1,g=r.length;++d<g;)(i=r[d])&&Ss(i,d,s,o,a),e.push(i)}return xs(l,s,o)},ws.filter=function(t){var e,r,n=[];\"function\"!=typeof t&&(t=lt(t));for(var i=0,a=this.length;i<a;i++){n.push(e=[]);for(var o,s=0,l=(o=this[i]).length;s<l;s++)(r=o[s])&&t.call(r,r.__data__,s,i)&&e.push(r)}return xs(n,this.namespace,this.id)},ws.tween=function(t,e){var r=this.id,n=this.namespace;return arguments.length<2?this.node()[n][r].tween.get(t):ut(this,null==e?function(e){e[n][r].tween.remove(t)}:function(i){i[n][r].tween.set(t,e)})},ws.attr=function(e,r){if(arguments.length<2){for(r in e)this.attr(r,e[r]);return this}var n=\"transform\"==e?ba:$i,i=t.ns.qualify(e);function a(){this.removeAttribute(i)}function o(){this.removeAttributeNS(i.space,i.local)}function s(t){return null==t?a:(t+=\"\",function(){var e,r=this.getAttribute(i);return r!==t&&(e=n(r,t),function(t){this.setAttribute(i,e(t))})})}function l(t){return null==t?o:(t+=\"\",function(){var e,r=this.getAttributeNS(i.space,i.local);return r!==t&&(e=n(r,t),function(t){this.setAttributeNS(i.space,i.local,e(t))})})}return ks(this,\"attr.\"+e,r,i.local?l:s)},ws.attrTween=function(e,r){var n=t.ns.qualify(e);return this.tween(\"attr.\"+e,n.local?function(t,e){var i=r.call(this,t,e,this.getAttributeNS(n.space,n.local));return i&&function(t){this.setAttributeNS(n.space,n.local,i(t))}}:function(t,e){var i=r.call(this,t,e,this.getAttribute(n));return i&&function(t){this.setAttribute(n,i(t))}})},ws.style=function(t,e,r){var n=arguments.length;if(n<3){if(\"string\"!=typeof t){for(r in n<2&&(e=\"\"),t)this.style(r,t[r],e);return this}r=\"\"}function i(){this.style.removeProperty(t)}function a(e){return null==e?i:(e+=\"\",function(){var n,i=o(this).getComputedStyle(this,null).getPropertyValue(t);return i!==e&&(n=$i(i,e),function(e){this.style.setProperty(t,n(e),r)})})}return ks(this,\"style.\"+t,e,a)},ws.styleTween=function(t,e,r){function n(n,i){var a=e.call(this,n,i,o(this).getComputedStyle(this,null).getPropertyValue(t));return a&&function(e){this.style.setProperty(t,a(e),r)}}return arguments.length<3&&(r=\"\"),this.tween(\"style.\"+t,n)},ws.text=function(t){return ks(this,\"text\",t,Ms)},ws.remove=function(){var t=this.namespace;return this.each(\"end.transition\",(function(){var e;this[t].count<2&&(e=this.parentNode)&&e.removeChild(this)}))},ws.ease=function(e){var r=this.id,n=this.namespace;return arguments.length<1?this.node()[n][r].ease:(\"function\"!=typeof e&&(e=t.ease.apply(t,arguments)),ut(this,(function(t){t[n][r].ease=e})))},ws.delay=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].delay:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].delay=+t.call(n,n.__data__,i,a)}:(t=+t,function(n){n[r][e].delay=t}))},ws.duration=function(t){var e=this.id,r=this.namespace;return arguments.length<1?this.node()[r][e].duration:ut(this,\"function\"==typeof t?function(n,i,a){n[r][e].duration=Math.max(1,t.call(n,n.__data__,i,a))}:(t=Math.max(1,t),function(n){n[r][e].duration=t}))},ws.each=function(e,r){var n=this.id,i=this.namespace;if(arguments.length<2){var a=_s,o=bs;try{bs=n,ut(this,(function(t,r,a){_s=t[i][n],e.call(t,t.__data__,r,a)}))}finally{_s=a,bs=o}}else ut(this,(function(a){var o=a[i][n];(o.event||(o.event=t.dispatch(\"start\",\"end\",\"interrupt\"))).on(e,r)}));return this},ws.transition=function(){for(var t,e,r,n=this.id,i=++Ts,a=this.namespace,o=[],s=0,l=this.length;s<l;s++){o.push(t=[]);for(var c,u=0,f=(c=this[s]).length;u<f;u++)(e=c[u])&&Ss(e,u,a,i,{time:(r=e[a][n]).time,ease:r.ease,delay:r.delay+r.duration,duration:r.duration}),t.push(e)}return xs(o,a,i)},t.svg.axis=function(){var e,r=t.scale.linear(),i=Es,a=6,o=6,s=3,l=[10],c=null;function u(n){n.each((function(){var n,u=t.select(this),f=this.__chart__||r,h=this.__chart__=r.copy(),p=null==c?h.ticks?h.ticks.apply(h,l):h.domain():c,d=null==e?h.tickFormat?h.tickFormat.apply(h,l):L:e,g=u.selectAll(\".tick\").data(p,h),m=g.enter().insert(\"g\",\".domain\").attr(\"class\",\"tick\").style(\"opacity\",kt),v=t.transition(g.exit()).style(\"opacity\",kt).remove(),y=t.transition(g.order()).style(\"opacity\",1),x=Math.max(a,0)+s,b=mo(h),_=u.selectAll(\".domain\").data([0]),w=(_.enter().append(\"path\").attr(\"class\",\"domain\"),t.transition(_));m.append(\"line\"),m.append(\"text\");var T,k,M,A,S=m.select(\"line\"),E=y.select(\"line\"),C=g.select(\"text\").text(d),I=m.select(\"text\"),P=y.select(\"text\"),z=\"top\"===i||\"left\"===i?-1:1;if(\"bottom\"===i||\"top\"===i?(n=Ls,T=\"x\",M=\"y\",k=\"x2\",A=\"y2\",C.attr(\"dy\",z<0?\"0em\":\".71em\").style(\"text-anchor\",\"middle\"),w.attr(\"d\",\"M\"+b[0]+\",\"+z*o+\"V0H\"+b[1]+\"V\"+z*o)):(n=Is,T=\"y\",M=\"x\",k=\"y2\",A=\"x2\",C.attr(\"dy\",\".32em\").style(\"text-anchor\",z<0?\"end\":\"start\"),w.attr(\"d\",\"M\"+z*o+\",\"+b[0]+\"H0V\"+b[1]+\"H\"+z*o)),S.attr(A,z*a),I.attr(M,z*x),E.attr(k,0).attr(A,z*a),P.attr(T,0).attr(M,z*x),h.rangeBand){var O=h,D=O.rangeBand()/2;f=h=function(t){return O(t)+D}}else f.rangeBand?f=h:v.call(n,h,f);m.call(n,f,h),y.call(n,h,h)}))}return u.scale=function(t){return arguments.length?(r=t,u):r},u.orient=function(t){return arguments.length?(i=t in Cs?t+\"\":Es,u):i},u.ticks=function(){return arguments.length?(l=n(arguments),u):l},u.tickValues=function(t){return arguments.length?(c=t,u):c},u.tickFormat=function(t){return arguments.length?(e=t,u):e},u.tickSize=function(t){var e=arguments.length;return e?(a=+t,o=+arguments[e-1],u):a},u.innerTickSize=function(t){return arguments.length?(a=+t,u):a},u.outerTickSize=function(t){return arguments.length?(o=+t,u):o},u.tickPadding=function(t){return arguments.length?(s=+t,u):s},u.tickSubdivide=function(){return arguments.length&&u},u};var Es=\"bottom\",Cs={top:1,right:1,bottom:1,left:1};function Ls(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(\"+(isFinite(n)?n:r(t))+\",0)\"}))}function Is(t,e,r){t.attr(\"transform\",(function(t){var n=e(t);return\"translate(0,\"+(isFinite(n)?n:r(t))+\")\"}))}t.svg.brush=function(){var e,r,n=N(h,\"brushstart\",\"brush\",\"brushend\"),i=null,a=null,s=[0,0],l=[0,0],c=!0,u=!0,f=zs[0];function h(e){e.each((function(){var e=t.select(this).style(\"pointer-events\",\"all\").style(\"-webkit-tap-highlight-color\",\"rgba(0,0,0,0)\").on(\"mousedown.brush\",m).on(\"touchstart.brush\",m),r=e.selectAll(\".background\").data([0]);r.enter().append(\"rect\").attr(\"class\",\"background\").style(\"visibility\",\"hidden\").style(\"cursor\",\"crosshair\"),e.selectAll(\".extent\").data([0]).enter().append(\"rect\").attr(\"class\",\"extent\").style(\"cursor\",\"move\");var n=e.selectAll(\".resize\").data(f,L);n.exit().remove(),n.enter().append(\"g\").attr(\"class\",(function(t){return\"resize \"+t})).style(\"cursor\",(function(t){return Ps[t]})).append(\"rect\").attr(\"x\",(function(t){return/[ew]$/.test(t)?-3:null})).attr(\"y\",(function(t){return/^[ns]/.test(t)?-3:null})).attr(\"width\",6).attr(\"height\",6).style(\"visibility\",\"hidden\"),n.style(\"display\",h.empty()?\"none\":null);var o,s=t.transition(e),l=t.transition(r);i&&(o=mo(i),l.attr(\"x\",o[0]).attr(\"width\",o[1]-o[0]),d(s)),a&&(o=mo(a),l.attr(\"y\",o[0]).attr(\"height\",o[1]-o[0]),g(s)),p(s)}))}function p(t){t.selectAll(\".resize\").attr(\"transform\",(function(t){return\"translate(\"+s[+/e$/.test(t)]+\",\"+l[+/^s/.test(t)]+\")\"}))}function d(t){t.select(\".extent\").attr(\"x\",s[0]),t.selectAll(\".extent,.n>rect,.s>rect\").attr(\"width\",s[1]-s[0])}function g(t){t.select(\".extent\").attr(\"y\",l[0]),t.selectAll(\".extent,.e>rect,.w>rect\").attr(\"height\",l[1]-l[0])}function m(){var f,m,v=this,y=t.select(t.event.target),x=n.of(v,arguments),b=t.select(v),_=y.datum(),w=!/^(n|s)$/.test(_)&&i,T=!/^(e|w)$/.test(_)&&a,k=y.classed(\"extent\"),M=bt(v),A=t.mouse(v),S=t.select(o(v)).on(\"keydown.brush\",L).on(\"keyup.brush\",I);if(t.event.changedTouches?S.on(\"touchmove.brush\",P).on(\"touchend.brush\",O):S.on(\"mousemove.brush\",P).on(\"mouseup.brush\",O),b.interrupt().selectAll(\"*\").interrupt(),k)A[0]=s[0]-A[0],A[1]=l[0]-A[1];else if(_){var E=+/w$/.test(_),C=+/^n/.test(_);m=[s[1-E]-A[0],l[1-C]-A[1]],A[0]=s[E],A[1]=l[C]}else t.event.altKey&&(f=A.slice());function L(){32==t.event.keyCode&&(k||(f=null,A[0]-=s[1],A[1]-=l[1],k=2),F())}function I(){32==t.event.keyCode&&2==k&&(A[0]+=s[1],A[1]+=l[1],k=0,F())}function P(){var e=t.mouse(v),r=!1;m&&(e[0]+=m[0],e[1]+=m[1]),k||(t.event.altKey?(f||(f=[(s[0]+s[1])/2,(l[0]+l[1])/2]),A[0]=s[+(e[0]<f[0])],A[1]=l[+(e[1]<f[1])]):f=null),w&&z(e,i,0)&&(d(b),r=!0),T&&z(e,a,1)&&(g(b),r=!0),r&&(p(b),x({type:\"brush\",mode:k?\"move\":\"resize\"}))}function z(t,n,i){var a,o,h=mo(n),p=h[0],d=h[1],g=A[i],m=i?l:s,v=m[1]-m[0];if(k&&(p-=g,d-=v+g),a=(i?u:c)?Math.max(p,Math.min(d,t[i])):t[i],k?o=(a+=g)+v:(f&&(g=Math.max(p,Math.min(d,2*f[i]-a))),g<a?(o=a,a=g):o=g),m[0]!=a||m[1]!=o)return i?r=null:e=null,m[0]=a,m[1]=o,!0}function O(){P(),b.style(\"pointer-events\",\"all\").selectAll(\".resize\").style(\"display\",h.empty()?\"none\":null),t.select(\"body\").style(\"cursor\",null),S.on(\"mousemove.brush\",null).on(\"mouseup.brush\",null).on(\"touchmove.brush\",null).on(\"touchend.brush\",null).on(\"keydown.brush\",null).on(\"keyup.brush\",null),M(),x({type:\"brushend\"})}b.style(\"pointer-events\",\"none\").selectAll(\".resize\").style(\"display\",null),t.select(\"body\").style(\"cursor\",y.style(\"cursor\")),x({type:\"brushstart\"}),P()}return h.event=function(i){i.each((function(){var i=n.of(this,arguments),a={x:s,y:l,i:e,j:r},o=this.__chart__||a;this.__chart__=a,bs?t.select(this).transition().each(\"start.brush\",(function(){e=o.i,r=o.j,s=o.x,l=o.y,i({type:\"brushstart\"})})).tween(\"brush:brush\",(function(){var t=ta(s,a.x),n=ta(l,a.y);return e=r=null,function(e){s=a.x=t(e),l=a.y=n(e),i({type:\"brush\",mode:\"resize\"})}})).each(\"end.brush\",(function(){e=a.i,r=a.j,i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"})})):(i({type:\"brushstart\"}),i({type:\"brush\",mode:\"resize\"}),i({type:\"brushend\"}))}))},h.x=function(t){return arguments.length?(f=zs[!(i=t)<<1|!a],h):i},h.y=function(t){return arguments.length?(f=zs[!i<<1|!(a=t)],h):a},h.clamp=function(t){return arguments.length?(i&&a?(c=!!t[0],u=!!t[1]):i?c=!!t:a&&(u=!!t),h):i&&a?[c,u]:i?c:a?u:null},h.extent=function(t){var n,o,c,u,f;return arguments.length?(i&&(n=t[0],o=t[1],a&&(n=n[0],o=o[0]),e=[n,o],i.invert&&(n=i(n),o=i(o)),o<n&&(f=n,n=o,o=f),n==s[0]&&o==s[1]||(s=[n,o])),a&&(c=t[0],u=t[1],i&&(c=c[1],u=u[1]),r=[c,u],a.invert&&(c=a(c),u=a(u)),u<c&&(f=c,c=u,u=f),c==l[0]&&u==l[1]||(l=[c,u])),h):(i&&(e?(n=e[0],o=e[1]):(n=s[0],o=s[1],i.invert&&(n=i.invert(n),o=i.invert(o)),o<n&&(f=n,n=o,o=f))),a&&(r?(c=r[0],u=r[1]):(c=l[0],u=l[1],a.invert&&(c=a.invert(c),u=a.invert(u)),u<c&&(f=c,c=u,u=f))),i&&a?[[n,c],[o,u]]:i?[n,o]:a&&[c,u])},h.clear=function(){return h.empty()||(s=[0,0],l=[0,0],e=r=null),h},h.empty=function(){return!!i&&s[0]==s[1]||!!a&&l[0]==l[1]},t.rebind(h,n,\"on\")};var Ps={n:\"ns-resize\",e:\"ew-resize\",s:\"ns-resize\",w:\"ew-resize\",nw:\"nwse-resize\",ne:\"nesw-resize\",se:\"nwse-resize\",sw:\"nesw-resize\"},zs=[[\"n\",\"e\",\"s\",\"w\",\"nw\",\"ne\",\"se\",\"sw\"],[\"e\",\"w\"],[\"n\",\"s\"],[]],Os=Pe.format=sr.timeFormat,Ds=Os.utc,Rs=Ds(\"%Y-%m-%dT%H:%M:%S.%LZ\");function Fs(t){return t.toISOString()}function Bs(e,r,n){function i(t){return e(t)}function a(e,n){var i=(e[1]-e[0])/n,a=t.bisect(js,i);return a==js.length?[r.year,ko(e.map((function(t){return t/31536e6})),n)[2]]:a?r[i/js[a-1]<js[a]/i?a-1:a]:[qs,ko(e,n)[2]]}return i.invert=function(t){return Ns(e.invert(t))},i.domain=function(t){return arguments.length?(e.domain(t),i):e.domain().map(Ns)},i.nice=function(t,e){var r=i.domain(),n=go(r),o=null==t?a(n,10):\"number\"==typeof t&&a(n,t);function s(r){return!isNaN(r)&&!t.range(r,Ns(+r+1),e).length}return o&&(t=o[0],e=o[1]),i.domain(yo(r,e>1?{floor:function(e){for(;s(e=t.floor(e));)e=Ns(e-1);return e},ceil:function(e){for(;s(e=t.ceil(e));)e=Ns(+e+1);return e}}:t))},i.ticks=function(t,e){var r=go(i.domain()),n=null==t?a(r,10):\"number\"==typeof t?a(r,t):!t.range&&[{range:t},e];return n&&(t=n[0],e=n[1]),t.range(r[0],Ns(+r[1]+1),e<1?1:e)},i.tickFormat=function(){return n},i.copy=function(){return Bs(e.copy(),r,n)},wo(i,e)}function Ns(t){return new Date(t)}Os.iso=Date.prototype.toISOString&&+new Date(\"2000-01-01T00:00:00.000Z\")?Fs:Rs,Fs.parse=function(t){var e=new Date(t);return isNaN(e)?null:e},Fs.toString=Rs.toString,Pe.second=Re((function(t){return new ze(1e3*Math.floor(t/1e3))}),(function(t,e){t.setTime(t.getTime()+1e3*Math.floor(e))}),(function(t){return t.getSeconds()})),Pe.seconds=Pe.second.range,Pe.seconds.utc=Pe.second.utc.range,Pe.minute=Re((function(t){return new ze(6e4*Math.floor(t/6e4))}),(function(t,e){t.setTime(t.getTime()+6e4*Math.floor(e))}),(function(t){return t.getMinutes()})),Pe.minutes=Pe.minute.range,Pe.minutes.utc=Pe.minute.utc.range,Pe.hour=Re((function(t){var e=t.getTimezoneOffset()/60;return new ze(36e5*(Math.floor(t/36e5-e)+e))}),(function(t,e){t.setTime(t.getTime()+36e5*Math.floor(e))}),(function(t){return t.getHours()})),Pe.hours=Pe.hour.range,Pe.hours.utc=Pe.hour.utc.range,Pe.month=Re((function(t){return(t=Pe.day(t)).setDate(1),t}),(function(t,e){t.setMonth(t.getMonth()+e)}),(function(t){return t.getMonth()})),Pe.months=Pe.month.range,Pe.months.utc=Pe.month.utc.range;var js=[1e3,5e3,15e3,3e4,6e4,3e5,9e5,18e5,36e5,108e5,216e5,432e5,864e5,1728e5,6048e5,2592e6,7776e6,31536e6],Us=[[Pe.second,1],[Pe.second,5],[Pe.second,15],[Pe.second,30],[Pe.minute,1],[Pe.minute,5],[Pe.minute,15],[Pe.minute,30],[Pe.hour,1],[Pe.hour,3],[Pe.hour,6],[Pe.hour,12],[Pe.day,1],[Pe.day,2],[Pe.week,1],[Pe.month,1],[Pe.month,3],[Pe.year,1]],Vs=Os.multi([[\".%L\",function(t){return t.getMilliseconds()}],[\":%S\",function(t){return t.getSeconds()}],[\"%I:%M\",function(t){return t.getMinutes()}],[\"%I %p\",function(t){return t.getHours()}],[\"%a %d\",function(t){return t.getDay()&&1!=t.getDate()}],[\"%b %d\",function(t){return 1!=t.getDate()}],[\"%B\",function(t){return t.getMonth()}],[\"%Y\",Yr]]),qs={range:function(e,r,n){return t.range(Math.ceil(e/n)*n,+r,n).map(Ns)},floor:L,ceil:L};Us.year=Pe.year,Pe.scale=function(){return Bs(t.scale.linear(),Us,Vs)};var Hs=Us.map((function(t){return[t[0].utc,t[1]]})),Gs=Ds.multi([[\".%L\",function(t){return t.getUTCMilliseconds()}],[\":%S\",function(t){return t.getUTCSeconds()}],[\"%I:%M\",function(t){return t.getUTCMinutes()}],[\"%I %p\",function(t){return t.getUTCHours()}],[\"%a %d\",function(t){return t.getUTCDay()&&1!=t.getUTCDate()}],[\"%b %d\",function(t){return 1!=t.getUTCDate()}],[\"%B\",function(t){return t.getUTCMonth()}],[\"%Y\",Yr]]);function Ys(t){return JSON.parse(t.responseText)}function Ws(t){var e=i.createRange();return e.selectNode(i.body),e.createContextualFragment(t.responseText)}Hs.year=Pe.year.utc,Pe.scale.utc=function(){return Bs(t.scale.linear(),Hs,Gs)},t.text=ge((function(t){return t.responseText})),t.json=function(t,e){return me(t,\"application/json\",Ys,e)},t.html=function(t,e){return me(t,\"text/html\",Ws,e)},t.xml=ge((function(t){return t.responseXML})),\"object\"==typeof e&&e.exports?e.exports=t:this.d3=t}()},{}],170:[function(t,e,r){e.exports=function(){for(var t=0;t<arguments.length;t++)if(void 0!==arguments[t])return arguments[t]}},{}],171:[function(t,e,r){\"use strict\";var n=t(\"incremental-convex-hull\"),i=t(\"uniq\");function a(t,e){this.point=t,this.index=e}function o(t,e){for(var r=t.point,n=e.point,i=r.length,a=0;a<i;++a){var o=n[a]-r[a];if(o)return o}return 0}e.exports=function(t,e){var r=t.length;if(0===r)return[];var s=t[0].length;if(s<1)return[];if(1===s)return function(t,e,r){if(1===t)return r?[[-1,0]]:[];var n=e.map((function(t,e){return[t[0],e]}));n.sort((function(t,e){return t[0]-e[0]}));for(var i=new Array(t-1),a=1;a<t;++a){var o=n[a-1],s=n[a];i[a-1]=[o[1],s[1]]}r&&i.push([-1,i[0][1]],[i[t-1][1],-1]);return i}(r,t,e);for(var l=new Array(r),c=1,u=0;u<r;++u){for(var f=t[u],h=new Array(s+1),p=0,d=0;d<s;++d){var g=f[d];h[d]=g,p+=g*g}h[s]=p,l[u]=new a(h,u),c=Math.max(p,c)}i(l,o),r=l.length;var m=new Array(r+s+1),v=new Array(r+s+1),y=(s+1)*(s+1)*c,x=new Array(s+1);for(u=0;u<=s;++u)x[u]=0;x[s]=y,m[0]=x.slice(),v[0]=-1;for(u=0;u<=s;++u){(h=x.slice())[u]=1,m[u+1]=h,v[u+1]=-1}for(u=0;u<r;++u){var b=l[u];m[u+s+1]=b.point,v[u+s+1]=b.index}var _=n(m,!1);_=e?_.filter((function(t){for(var e=0,r=0;r<=s;++r){var n=v[t[r]];if(n<0&&++e>=2)return!1;t[r]=n}return!0})):_.filter((function(t){for(var e=0;e<=s;++e){var r=v[t[e]];if(r<0)return!1;t[e]=r}return!0}));if(1&s)for(u=0;u<_.length;++u){h=(b=_[u])[0];b[0]=b[1],b[1]=h}return _}},{\"incremental-convex-hull\":459,uniq:597}],172:[function(t,e,r){\"use strict\";e.exports=a;var n=(a.canvas=document.createElement(\"canvas\")).getContext(\"2d\"),i=o([32,126]);function a(t,e){Array.isArray(t)&&(t=t.join(\", \"));var r,a={},s=16,l=.05;e&&(2===e.length&&\"number\"==typeof e[0]?r=o(e):Array.isArray(e)?r=e:(e.o?r=o(e.o):e.pairs&&(r=e.pairs),e.fontSize&&(s=e.fontSize),null!=e.threshold&&(l=e.threshold))),r||(r=i),n.font=s+\"px \"+t;for(var c=0;c<r.length;c++){var u=r[c],f=n.measureText(u[0]).width+n.measureText(u[1]).width,h=n.measureText(u).width;if(Math.abs(f-h)>s*l){var p=(h-f)/s;a[u]=1e3*p}}return a}function o(t){for(var e=[],r=t[0];r<=t[1];r++)for(var n=String.fromCharCode(r),i=t[0];i<t[1];i++){var a=n+String.fromCharCode(i);e.push(a)}return e}a.createPairs=o,a.ascii=i},{}],173:[function(t,e,r){(function(t){(function(){var r=!1;if(\"undefined\"!=typeof Float64Array){var n=new Float64Array(1),i=new Uint32Array(n.buffer);if(n[0]=1,r=!0,1072693248===i[1]){e.exports=function(t){return n[0]=t,[i[0],i[1]]},e.exports.pack=function(t,e){return i[0]=t,i[1]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[0]},e.exports.hi=function(t){return n[0]=t,i[1]}}else if(1072693248===i[0]){e.exports=function(t){return n[0]=t,[i[1],i[0]]},e.exports.pack=function(t,e){return i[1]=t,i[0]=e,n[0]},e.exports.lo=function(t){return n[0]=t,i[1]},e.exports.hi=function(t){return n[0]=t,i[0]}}else r=!1}if(!r){var a=new t(8);e.exports=function(t){return a.writeDoubleLE(t,0,!0),[a.readUInt32LE(0,!0),a.readUInt32LE(4,!0)]},e.exports.pack=function(t,e){return a.writeUInt32LE(t,0,!0),a.writeUInt32LE(e,4,!0),a.readDoubleLE(0,!0)},e.exports.lo=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(0,!0)},e.exports.hi=function(t){return a.writeDoubleLE(t,0,!0),a.readUInt32LE(4,!0)}}e.exports.sign=function(t){return e.exports.hi(t)>>>31},e.exports.exponent=function(t){return(e.exports.hi(t)<<1>>>21)-1023},e.exports.fraction=function(t){var r=e.exports.lo(t),n=e.exports.hi(t),i=1048575&n;return 2146435072&n&&(i+=1<<20),[r,i]},e.exports.denormalized=function(t){return!(2146435072&e.exports.hi(t))}}).call(this)}).call(this,t(\"buffer\").Buffer)},{buffer:111}],174:[function(t,e,r){var n=t(\"abs-svg-path\"),i=t(\"normalize-svg-path\"),a={M:\"moveTo\",C:\"bezierCurveTo\"};e.exports=function(t,e){t.beginPath(),i(n(e)).forEach((function(e){var r=e[0],n=e.slice(1);t[a[r]].apply(t,n)})),t.closePath()}},{\"abs-svg-path\":65,\"normalize-svg-path\":497}],175:[function(t,e,r){e.exports=function(t){switch(t){case\"int8\":return Int8Array;case\"int16\":return Int16Array;case\"int32\":return Int32Array;case\"uint8\":return Uint8Array;case\"uint16\":return Uint16Array;case\"uint32\":return Uint32Array;case\"float32\":return Float32Array;case\"float64\":return Float64Array;case\"array\":return Array;case\"uint8_clamped\":return Uint8ClampedArray}}},{}],176:[function(t,e,r){\"use strict\";e.exports=function(t,e){switch(\"undefined\"==typeof e&&(e=0),typeof t){case\"number\":if(t>0)return function(t,e){var r,n;for(r=new Array(t),n=0;n<t;++n)r[n]=e;return r}(0|t,e);break;case\"object\":if(\"number\"==typeof t.length)return function t(e,r,n){var i=0|e[n];if(i<=0)return[];var a,o=new Array(i);if(n===e.length-1)for(a=0;a<i;++a)o[a]=r;else for(a=0;a<i;++a)o[a]=t(e,r,n+1);return o}(t,e,0)}return[]}},{}],177:[function(t,e,r){\"use strict\";function n(t,e,r){r=r||2;var n,s,l,c,u,p,d,m=e&&e.length,v=m?e[0]*r:t.length,y=i(t,0,v,r,!0),x=[];if(!y||y.next===y.prev)return x;if(m&&(y=function(t,e,r,n){var o,s,l,c,u,p=[];for(o=0,s=e.length;o<s;o++)l=e[o]*n,c=o<s-1?e[o+1]*n:t.length,(u=i(t,l,c,n,!1))===u.next&&(u.steiner=!0),p.push(g(u));for(p.sort(f),o=0;o<p.length;o++)h(p[o],r),r=a(r,r.next);return r}(t,e,y,r)),t.length>80*r){n=l=t[0],s=c=t[1];for(var b=r;b<v;b+=r)(u=t[b])<n&&(n=u),(p=t[b+1])<s&&(s=p),u>l&&(l=u),p>c&&(c=p);d=0!==(d=Math.max(l-n,c-s))?1/d:0}return o(y,x,r,n,s,d),x}function i(t,e,r,n,i){var a,o;if(i===E(t,e,r,n)>0)for(a=e;a<r;a+=n)o=M(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=M(a,t[a],t[a+1],o);return o&&x(o,o.next)&&(A(o),o=o.next),o}function a(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!x(n,n.next)&&0!==y(n.prev,n,n.next))n=n.next;else{if(A(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function o(t,e,r,n,i,f,h){if(t){!h&&f&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=d(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,f);for(var p,g,m=t;t.prev!==t.next;)if(p=t.prev,g=t.next,f?l(t,n,i,f):s(t))e.push(p.i/r),e.push(t.i/r),e.push(g.i/r),A(t),t=g.next,m=g.next;else if((t=g)===m){h?1===h?o(t=c(a(t),e,r),e,r,n,i,f,2):2===h&&u(t,e,r,n,i,f):o(a(t),e,r,n,i,f,1);break}}}function s(t){var e=t.prev,r=t,n=t.next;if(y(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(m(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&y(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function l(t,e,r,n){var i=t.prev,a=t,o=t.next;if(y(i,a,o)>=0)return!1;for(var s=i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,l=i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,c=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,u=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,f=d(s,l,e,r,n),h=d(c,u,e,r,n),p=t.prevZ,g=t.nextZ;p&&p.z>=f&&g&&g.z<=h;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;if(p=p.prevZ,g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}for(;p&&p.z>=f;){if(p!==t.prev&&p!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,p.x,p.y)&&y(p.prev,p,p.next)>=0)return!1;p=p.prevZ}for(;g&&g.z<=h;){if(g!==t.prev&&g!==t.next&&m(i.x,i.y,a.x,a.y,o.x,o.y,g.x,g.y)&&y(g.prev,g,g.next)>=0)return!1;g=g.nextZ}return!0}function c(t,e,r){var n=t;do{var i=n.prev,o=n.next.next;!x(i,o)&&b(i,n,n.next,o)&&T(i,o)&&T(o,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(o.i/r),A(n),A(n.next),n=t=o),n=n.next}while(n!==t);return a(n)}function u(t,e,r,n,i,s){var l=t;do{for(var c=l.next.next;c!==l.prev;){if(l.i!==c.i&&v(l,c)){var u=k(l,c);return l=a(l,l.next),u=a(u,u.next),o(l,e,r,n,i,s),void o(u,e,r,n,i,s)}c=c.next}l=l.next}while(l!==t)}function f(t,e){return t.x-e.x}function h(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&m(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),T(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&p(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=k(e,t);a(e,e.next),a(r,r.next)}}function p(t,e){return y(t.prev,t,e.prev)<0&&y(e.next,t,t.next)<0}function d(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function g(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function m(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function v(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&b(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(T(t,e)&&T(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(y(t.prev,t,e.prev)||y(t,e.prev,e))||x(t,e)&&y(t.prev,t,t.next)>0&&y(e.prev,e,e.next)>0)}function y(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function x(t,e){return t.x===e.x&&t.y===e.y}function b(t,e,r,n){var i=w(y(t,e,r)),a=w(y(t,e,n)),o=w(y(r,n,t)),s=w(y(r,n,e));return i!==a&&o!==s||(!(0!==i||!_(t,r,e))||(!(0!==a||!_(t,n,e))||(!(0!==o||!_(r,t,n))||!(0!==s||!_(r,e,n)))))}function _(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function w(t){return t>0?1:t<0?-1:0}function T(t,e){return y(t.prev,t,t.next)<0?y(t,e,t.next)>=0&&y(t,t.prev,e)>=0:y(t,e,t.prev)<0||y(t,t.next,e)<0}function k(t,e){var r=new S(t.i,t.x,t.y),n=new S(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function M(t,e,r,n){var i=new S(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function A(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function S(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function E(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}e.exports=n,e.exports.default=n,n.deviation=function(t,e,r,n){var i=e&&e.length,a=i?e[0]*r:t.length,o=Math.abs(E(t,0,a,r));if(i)for(var s=0,l=e.length;s<l;s++){var c=e[s]*r,u=s<l-1?e[s+1]*r:t.length;o-=Math.abs(E(t,c,u,r))}var f=0;for(s=0;s<n.length;s+=3){var h=n[s]*r,p=n[s+1]*r,d=n[s+2]*r;f+=Math.abs((t[h]-t[d])*(t[p+1]-t[h+1])-(t[h]-t[p])*(t[d+1]-t[h+1]))}return 0===o&&0===f?0:Math.abs((f-o)/o)},n.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&(n+=t[i-1].length,r.holes.push(n))}return r}},{}],178:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(\"number\"!=typeof e){e=0;for(var i=0;i<r;++i){var a=t[i];e=Math.max(e,a[0],a[1])}e=1+(0|e)}e|=0;var o=new Array(e);for(i=0;i<e;++i)o[i]=[];for(i=0;i<r;++i){a=t[i];o[a[0]].push(a[1]),o[a[1]].push(a[0])}for(var s=0;s<e;++s)n(o[s],(function(t,e){return t-e}));return o};var n=t(\"uniq\")},{uniq:597}],179:[function(t,e,r){var n=t(\"strongly-connected-components\");e.exports=function(t,e){var r,i=[],a=[],o=[],s={},l=[];function c(t){var e,n,i=!1;for(a.push(t),o[t]=!0,e=0;e<l[t].length;e++)(n=l[t][e])===r?(u(r,a),i=!0):o[n]||(i=c(n));if(i)!function t(e){o[e]=!1,s.hasOwnProperty(e)&&Object.keys(s[e]).forEach((function(r){delete s[e][r],o[r]&&t(r)}))}(t);else for(e=0;e<l[t].length;e++){n=l[t][e];var f=s[n];f||(f={},s[n]=f),f[n]=!0}return a.pop(),i}function u(t,r){var n=[].concat(r).concat(t);e?e(c):i.push(n)}function f(e){!function(e){for(var r=0;r<t.length;r++)r<e&&(t[r]=[]),t[r]=t[r].filter((function(t){return t>=e}))}(e);for(var r,i=n(t).components.filter((function(t){return t.length>1})),a=1/0,o=0;o<i.length;o++)for(var s=0;s<i[o].length;s++)i[o][s]<a&&(a=i[o][s],r=o);var l=i[r];return!!l&&{leastVertex:a,adjList:t.map((function(t,e){return-1===l.indexOf(e)?[]:t.filter((function(t){return-1!==l.indexOf(t)}))}))}}r=0;for(var h=t.length;r<h;){var p=f(r);if(r=p.leastVertex,l=p.adjList){for(var d=0;d<l.length;d++)for(var g=0;g<l[d].length;g++){var m=l[d][g];o[+m]=!1,s[m]={}}c(r),r+=1}else r=h}return e?void 0:i}},{\"strongly-connected-components\":569}],180:[function(t,e,r){\"use strict\";var n=t(\"../../object/valid-value\");e.exports=function(){return n(this).length=0,this}},{\"../../object/valid-value\":211}],181:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Array.from:t(\"./shim\")},{\"./is-implemented\":182,\"./shim\":183}],182:[function(t,e,r){\"use strict\";e.exports=function(){var t,e,r=Array.from;return\"function\"==typeof r&&(e=r(t=[\"raz\",\"dwa\"]),Boolean(e&&e!==t&&\"dwa\"===e[1]))}},{}],183:[function(t,e,r){\"use strict\";var n=t(\"es6-symbol\").iterator,i=t(\"../../function/is-arguments\"),a=t(\"../../function/is-function\"),o=t(\"../../number/to-pos-integer\"),s=t(\"../../object/valid-callable\"),l=t(\"../../object/valid-value\"),c=t(\"../../object/is-value\"),u=t(\"../../string/is-string\"),f=Array.isArray,h=Function.prototype.call,p={configurable:!0,enumerable:!0,writable:!0,value:null},d=Object.defineProperty;e.exports=function(t){var e,r,g,m,v,y,x,b,_,w,T=arguments[1],k=arguments[2];if(t=Object(l(t)),c(T)&&s(T),this&&this!==Array&&a(this))e=this;else{if(!T){if(i(t))return 1!==(v=t.length)?Array.apply(null,t):((m=new Array(1))[0]=t[0],m);if(f(t)){for(m=new Array(v=t.length),r=0;r<v;++r)m[r]=t[r];return m}}m=[]}if(!f(t))if(void 0!==(_=t[n])){for(x=s(_).call(t),e&&(m=new e),b=x.next(),r=0;!b.done;)w=T?h.call(T,k,b.value,r):b.value,e?(p.value=w,d(m,r,p)):m[r]=w,b=x.next(),++r;v=r}else if(u(t)){for(v=t.length,e&&(m=new e),r=0,g=0;r<v;++r)w=t[r],r+1<v&&(y=w.charCodeAt(0))>=55296&&y<=56319&&(w+=t[++r]),w=T?h.call(T,k,w,g):w,e?(p.value=w,d(m,g,p)):m[g]=w,++g;v=g}if(void 0===v)for(v=o(t.length),e&&(m=new e(v)),r=0;r<v;++r)w=T?h.call(T,k,t[r],r):t[r],e?(p.value=w,d(m,r,p)):m[r]=w;return e&&(p.value=null,m.length=v),m}},{\"../../function/is-arguments\":184,\"../../function/is-function\":185,\"../../number/to-pos-integer\":191,\"../../object/is-value\":200,\"../../object/valid-callable\":209,\"../../object/valid-value\":211,\"../../string/is-string\":215,\"es6-symbol\":225}],184:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(function(){return arguments}());e.exports=function(t){return n.call(t)===i}},{}],185:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=RegExp.prototype.test.bind(/^[object [A-Za-z0-9]*Function]$/);e.exports=function(t){return\"function\"==typeof t&&i(n.call(t))}},{}],186:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],187:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Math.sign:t(\"./shim\")},{\"./is-implemented\":188,\"./shim\":189}],188:[function(t,e,r){\"use strict\";e.exports=function(){var t=Math.sign;return\"function\"==typeof t&&(1===t(10)&&-1===t(-20))}},{}],189:[function(t,e,r){\"use strict\";e.exports=function(t){return t=Number(t),isNaN(t)||0===t?t:t>0?1:-1}},{}],190:[function(t,e,r){\"use strict\";var n=t(\"../math/sign\"),i=Math.abs,a=Math.floor;e.exports=function(t){return isNaN(t)?0:0!==(t=Number(t))&&isFinite(t)?n(t)*a(i(t)):t}},{\"../math/sign\":187}],191:[function(t,e,r){\"use strict\";var n=t(\"./to-integer\"),i=Math.max;e.exports=function(t){return i(0,n(t))}},{\"./to-integer\":190}],192:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./valid-value\"),a=Function.prototype.bind,o=Function.prototype.call,s=Object.keys,l=Object.prototype.propertyIsEnumerable;e.exports=function(t,e){return function(r,c){var u,f=arguments[2],h=arguments[3];return r=Object(i(r)),n(c),u=s(r),h&&u.sort(\"function\"==typeof h?a.call(h,r):void 0),\"function\"!=typeof t&&(t=u[t]),o.call(t,u,(function(t,n){return l.call(r,t)?o.call(c,f,r[t],t,r,n):e}))}}},{\"./valid-callable\":209,\"./valid-value\":211}],193:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.assign:t(\"./shim\")},{\"./is-implemented\":194,\"./shim\":195}],194:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=Object.assign;return\"function\"==typeof e&&(e(t={foo:\"raz\"},{bar:\"dwa\"},{trzy:\"trzy\"}),t.foo+t.bar+t.trzy===\"razdwatrzy\")}},{}],195:[function(t,e,r){\"use strict\";var n=t(\"../keys\"),i=t(\"../valid-value\"),a=Math.max;e.exports=function(t,e){var r,o,s,l=a(arguments.length,2);for(t=Object(i(t)),s=function(n){try{t[n]=e[n]}catch(t){r||(r=t)}},o=1;o<l;++o)n(e=arguments[o]).forEach(s);if(void 0!==r)throw r;return t}},{\"../keys\":201,\"../valid-value\":211}],196:[function(t,e,r){\"use strict\";var n=t(\"../array/from\"),i=t(\"./assign\"),a=t(\"./valid-value\");e.exports=function(t){var e=Object(a(t)),r=arguments[1],o=Object(arguments[2]);if(e!==t&&!r)return e;var s={};return r?n(r,(function(e){(o.ensure||e in t)&&(s[e]=t[e])})):i(s,t),s}},{\"../array/from\":181,\"./assign\":193,\"./valid-value\":211}],197:[function(t,e,r){\"use strict\";var n,i,a,o,s=Object.create;t(\"./set-prototype-of/is-implemented\")()||(n=t(\"./set-prototype-of/shim\")),e.exports=n?1!==n.level?s:(i={},a={},o={configurable:!1,enumerable:!1,writable:!0,value:void 0},Object.getOwnPropertyNames(Object.prototype).forEach((function(t){a[t]=\"__proto__\"!==t?o:{configurable:!0,enumerable:!1,writable:!0,value:void 0}})),Object.defineProperties(i,a),Object.defineProperty(n,\"nullPolyfill\",{configurable:!1,enumerable:!1,writable:!1,value:i}),function(t,e){return s(null===t?i:t,e)}):s},{\"./set-prototype-of/is-implemented\":207,\"./set-prototype-of/shim\":208}],198:[function(t,e,r){\"use strict\";e.exports=t(\"./_iterate\")(\"forEach\")},{\"./_iterate\":192}],199:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i={function:!0,object:!0};e.exports=function(t){return n(t)&&i[typeof t]||!1}},{\"./is-value\":200}],200:[function(t,e,r){\"use strict\";var n=t(\"../function/noop\")();e.exports=function(t){return t!==n&&null!==t}},{\"../function/noop\":186}],201:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.keys:t(\"./shim\")},{\"./is-implemented\":202,\"./shim\":203}],202:[function(t,e,r){\"use strict\";e.exports=function(){try{return Object.keys(\"primitive\"),!0}catch(t){return!1}}},{}],203:[function(t,e,r){\"use strict\";var n=t(\"../is-value\"),i=Object.keys;e.exports=function(t){return i(n(t)?Object(t):t)}},{\"../is-value\":200}],204:[function(t,e,r){\"use strict\";var n=t(\"./valid-callable\"),i=t(\"./for-each\"),a=Function.prototype.call;e.exports=function(t,e){var r={},o=arguments[2];return n(e),i(t,(function(t,n,i,s){r[n]=a.call(e,o,t,n,i,s)})),r}},{\"./for-each\":198,\"./valid-callable\":209}],205:[function(t,e,r){\"use strict\";var n=t(\"./is-value\"),i=Array.prototype.forEach,a=Object.create,o=function(t,e){var r;for(r in t)e[r]=t[r]};e.exports=function(t){var e=a(null);return i.call(arguments,(function(t){n(t)&&o(Object(t),e)})),e}},{\"./is-value\":200}],206:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?Object.setPrototypeOf:t(\"./shim\")},{\"./is-implemented\":207,\"./shim\":208}],207:[function(t,e,r){\"use strict\";var n=Object.create,i=Object.getPrototypeOf,a={};e.exports=function(){var t=Object.setPrototypeOf,e=arguments[0]||n;return\"function\"==typeof t&&i(t(e(null),a))===a}},{}],208:[function(t,e,r){\"use strict\";var n,i=t(\"../is-object\"),a=t(\"../valid-value\"),o=Object.prototype.isPrototypeOf,s=Object.defineProperty,l={configurable:!0,enumerable:!1,writable:!0,value:void 0};n=function(t,e){if(a(t),null===e||i(e))return t;throw new TypeError(\"Prototype must be null or an object\")},e.exports=function(t){var e,r;return t?(2===t.level?t.set?(r=t.set,e=function(t,e){return r.call(n(t,e),e),t}):e=function(t,e){return n(t,e).__proto__=e,t}:e=function t(e,r){var i;return n(e,r),(i=o.call(t.nullPolyfill,e))&&delete t.nullPolyfill.__proto__,null===r&&(r=t.nullPolyfill),e.__proto__=r,i&&s(t.nullPolyfill,\"__proto__\",l),e},Object.defineProperty(e,\"level\",{configurable:!1,enumerable:!1,writable:!1,value:t.level})):null}(function(){var t,e=Object.create(null),r={},n=Object.getOwnPropertyDescriptor(Object.prototype,\"__proto__\");if(n){try{(t=n.set).call(e,r)}catch(t){}if(Object.getPrototypeOf(e)===r)return{set:t,level:2}}return e.__proto__=r,Object.getPrototypeOf(e)===r?{level:2}:((e={}).__proto__=r,Object.getPrototypeOf(e)===r&&{level:1})}()),t(\"../create\")},{\"../create\":197,\"../is-object\":199,\"../valid-value\":211}],209:[function(t,e,r){\"use strict\";e.exports=function(t){if(\"function\"!=typeof t)throw new TypeError(t+\" is not a function\");return t}},{}],210:[function(t,e,r){\"use strict\";var n=t(\"./is-object\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not an Object\");return t}},{\"./is-object\":199}],211:[function(t,e,r){\"use strict\";var n=t(\"./is-value\");e.exports=function(t){if(!n(t))throw new TypeError(\"Cannot use null or undefined\");return t}},{\"./is-value\":200}],212:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?String.prototype.contains:t(\"./shim\")},{\"./is-implemented\":213,\"./shim\":214}],213:[function(t,e,r){\"use strict\";var n=\"razdwatrzy\";e.exports=function(){return\"function\"==typeof n.contains&&(!0===n.contains(\"dwa\")&&!1===n.contains(\"foo\"))}},{}],214:[function(t,e,r){\"use strict\";var n=String.prototype.indexOf;e.exports=function(t){return n.call(this,t,arguments[1])>-1}},{}],215:[function(t,e,r){\"use strict\";var n=Object.prototype.toString,i=n.call(\"\");e.exports=function(t){return\"string\"==typeof t||t&&\"object\"==typeof t&&(t instanceof String||n.call(t)===i)||!1}},{}],216:[function(t,e,r){\"use strict\";var n=Object.create(null),i=Math.random;e.exports=function(){var t;do{t=i().toString(36).slice(2)}while(n[t]);return t}},{}],217:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"es5-ext/string/#/contains\"),o=t(\"d\"),s=t(\"es6-symbol\"),l=t(\"./\"),c=Object.defineProperty;n=e.exports=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");l.call(this,t),e=e?a.call(e,\"key+value\")?\"key+value\":a.call(e,\"key\")?\"key\":\"value\":\"value\",c(this,\"__kind__\",o(\"\",e))},i&&i(n,l),delete n.prototype.constructor,n.prototype=Object.create(l.prototype,{_resolve:o((function(t){return\"value\"===this.__kind__?this.__list__[t]:\"key+value\"===this.__kind__?[t,this.__list__[t]]:t}))}),c(n.prototype,s.toStringTag,o(\"c\",\"Array Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/string/#/contains\":212,\"es6-symbol\":225}],218:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/valid-callable\"),a=t(\"es5-ext/string/is-string\"),o=t(\"./get\"),s=Array.isArray,l=Function.prototype.call,c=Array.prototype.some;e.exports=function(t,e){var r,u,f,h,p,d,g,m,v=arguments[2];if(s(t)||n(t)?r=\"array\":a(t)?r=\"string\":t=o(t),i(e),f=function(){h=!0},\"array\"!==r)if(\"string\"!==r)for(u=t.next();!u.done;){if(l.call(e,v,u.value,f),h)return;u=t.next()}else for(d=t.length,p=0;p<d&&(g=t[p],p+1<d&&(m=g.charCodeAt(0))>=55296&&m<=56319&&(g+=t[++p]),l.call(e,v,g,f),!h);++p);else c.call(t,(function(t){return l.call(e,v,t,f),h}))}},{\"./get\":219,\"es5-ext/function/is-arguments\":184,\"es5-ext/object/valid-callable\":209,\"es5-ext/string/is-string\":215}],219:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/string/is-string\"),a=t(\"./array\"),o=t(\"./string\"),s=t(\"./valid-iterable\"),l=t(\"es6-symbol\").iterator;e.exports=function(t){return\"function\"==typeof s(t)[l]?t[l]():n(t)?new a(t):i(t)?new o(t):new a(t)}},{\"./array\":217,\"./string\":222,\"./valid-iterable\":223,\"es5-ext/function/is-arguments\":184,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],220:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/array/#/clear\"),a=t(\"es5-ext/object/assign\"),o=t(\"es5-ext/object/valid-callable\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"d\"),c=t(\"d/auto-bind\"),u=t(\"es6-symbol\"),f=Object.defineProperty,h=Object.defineProperties;e.exports=n=function(t,e){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");h(this,{__list__:l(\"w\",s(t)),__context__:l(\"w\",e),__nextIndex__:l(\"w\",0)}),e&&(o(e.on),e.on(\"_add\",this._onAdd),e.on(\"_delete\",this._onDelete),e.on(\"_clear\",this._onClear))},delete n.prototype.constructor,h(n.prototype,a({_next:l((function(){var t;if(this.__list__)return this.__redo__&&void 0!==(t=this.__redo__.shift())?t:this.__nextIndex__<this.__list__.length?this.__nextIndex__++:void this._unBind()})),next:l((function(){return this._createResult(this._next())})),_createResult:l((function(t){return void 0===t?{done:!0,value:void 0}:{done:!1,value:this._resolve(t)}})),_resolve:l((function(t){return this.__list__[t]})),_unBind:l((function(){this.__list__=null,delete this.__redo__,this.__context__&&(this.__context__.off(\"_add\",this._onAdd),this.__context__.off(\"_delete\",this._onDelete),this.__context__.off(\"_clear\",this._onClear),this.__context__=null)})),toString:l((function(){return\"[object \"+(this[u.toStringTag]||\"Object\")+\"]\"}))},c({_onAdd:l((function(t){t>=this.__nextIndex__||(++this.__nextIndex__,this.__redo__?(this.__redo__.forEach((function(e,r){e>=t&&(this.__redo__[r]=++e)}),this),this.__redo__.push(t)):f(this,\"__redo__\",l(\"c\",[t])))})),_onDelete:l((function(t){var e;t>=this.__nextIndex__||(--this.__nextIndex__,this.__redo__&&(-1!==(e=this.__redo__.indexOf(t))&&this.__redo__.splice(e,1),this.__redo__.forEach((function(e,r){e>t&&(this.__redo__[r]=--e)}),this)))})),_onClear:l((function(){this.__redo__&&i.call(this.__redo__),this.__nextIndex__=0}))}))),f(n.prototype,u.iterator,l((function(){return this})))},{d:155,\"d/auto-bind\":154,\"es5-ext/array/#/clear\":180,\"es5-ext/object/assign\":193,\"es5-ext/object/valid-callable\":209,\"es5-ext/object/valid-value\":211,\"es6-symbol\":225}],221:[function(t,e,r){\"use strict\";var n=t(\"es5-ext/function/is-arguments\"),i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/string/is-string\"),o=t(\"es6-symbol\").iterator,s=Array.isArray;e.exports=function(t){return!!i(t)&&(!!s(t)||(!!a(t)||(!!n(t)||\"function\"==typeof t[o])))}},{\"es5-ext/function/is-arguments\":184,\"es5-ext/object/is-value\":200,\"es5-ext/string/is-string\":215,\"es6-symbol\":225}],222:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/set-prototype-of\"),a=t(\"d\"),o=t(\"es6-symbol\"),s=t(\"./\"),l=Object.defineProperty;n=e.exports=function(t){if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");t=String(t),s.call(this,t),l(this,\"__length__\",a(\"\",t.length))},i&&i(n,s),delete n.prototype.constructor,n.prototype=Object.create(s.prototype,{_next:a((function(){if(this.__list__)return this.__nextIndex__<this.__length__?this.__nextIndex__++:void this._unBind()})),_resolve:a((function(t){var e,r=this.__list__[t];return this.__nextIndex__===this.__length__?r:(e=r.charCodeAt(0))>=55296&&e<=56319?r+this.__list__[this.__nextIndex__++]:r}))}),l(n.prototype,o.toStringTag,a(\"c\",\"String Iterator\"))},{\"./\":220,d:155,\"es5-ext/object/set-prototype-of\":206,\"es6-symbol\":225}],223:[function(t,e,r){\"use strict\";var n=t(\"./is-iterable\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not iterable\");return t}},{\"./is-iterable\":221}],224:[function(t,e,r){(function(n,i){(function(){\n",
       "/*!\n",
       " * @overview es6-promise - a tiny implementation of Promises/A+.\n",
       " * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)\n",
       " * @license   Licensed under MIT license\n",
       " *            See https://raw.githubusercontent.com/stefanpenner/es6-promise/master/LICENSE\n",
       " * @version   v4.2.8+1e68dce6\n",
       " */\n",
       "!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.ES6Promise=n()}(this,(function(){\"use strict\";function e(t){return\"function\"==typeof t}var r=Array.isArray?Array.isArray:function(t){return\"[object Array]\"===Object.prototype.toString.call(t)},a=0,o=void 0,s=void 0,l=function(t,e){g[a]=t,g[a+1]=e,2===(a+=2)&&(s?s(m):_())};var c=\"undefined\"!=typeof window?window:void 0,u=c||{},f=u.MutationObserver||u.WebKitMutationObserver,h=\"undefined\"==typeof self&&\"undefined\"!=typeof n&&\"[object process]\"==={}.toString.call(n),p=\"undefined\"!=typeof Uint8ClampedArray&&\"undefined\"!=typeof importScripts&&\"undefined\"!=typeof MessageChannel;function d(){var t=setTimeout;return function(){return t(m,1)}}var g=new Array(1e3);function m(){for(var t=0;t<a;t+=2){(0,g[t])(g[t+1]),g[t]=void 0,g[t+1]=void 0}a=0}var v,y,x,b,_=void 0;function w(t,e){var r=this,n=new this.constructor(M);void 0===n[k]&&D(n);var i=r._state;if(i){var a=arguments[i-1];l((function(){return z(i,n,a,r._result)}))}else I(r,n,t,e);return n}function T(t){if(t&&\"object\"==typeof t&&t.constructor===this)return t;var e=new this(M);return S(e,t),e}h?_=function(){return n.nextTick(m)}:f?(y=0,x=new f(m),b=document.createTextNode(\"\"),x.observe(b,{characterData:!0}),_=function(){b.data=y=++y%2}):p?((v=new MessageChannel).port1.onmessage=m,_=function(){return v.port2.postMessage(0)}):_=void 0===c&&\"function\"==typeof t?function(){try{var t=Function(\"return this\")().require(\"vertx\");return\"undefined\"!=typeof(o=t.runOnLoop||t.runOnContext)?function(){o(m)}:d()}catch(t){return d()}}():d();var k=Math.random().toString(36).substring(2);function M(){}function A(t,r,n){r.constructor===t.constructor&&n===w&&r.constructor.resolve===T?function(t,e){1===e._state?C(t,e._result):2===e._state?L(t,e._result):I(e,void 0,(function(e){return S(t,e)}),(function(e){return L(t,e)}))}(t,r):void 0===n?C(t,r):e(n)?function(t,e,r){l((function(t){var n=!1,i=function(t,e,r,n){try{t.call(e,r,n)}catch(t){return t}}(r,e,(function(r){n||(n=!0,e!==r?S(t,r):C(t,r))}),(function(e){n||(n=!0,L(t,e))}),t._label);!n&&i&&(n=!0,L(t,i))}),t)}(t,r,n):C(t,r)}function S(t,e){if(t===e)L(t,new TypeError(\"You cannot resolve a promise with itself\"));else if(i=typeof(n=e),null===n||\"object\"!==i&&\"function\"!==i)C(t,e);else{var r=void 0;try{r=e.then}catch(e){return void L(t,e)}A(t,e,r)}var n,i}function E(t){t._onerror&&t._onerror(t._result),P(t)}function C(t,e){void 0===t._state&&(t._result=e,t._state=1,0!==t._subscribers.length&&l(P,t))}function L(t,e){void 0===t._state&&(t._state=2,t._result=e,l(E,t))}function I(t,e,r,n){var i=t._subscribers,a=i.length;t._onerror=null,i[a]=e,i[a+1]=r,i[a+2]=n,0===a&&t._state&&l(P,t)}function P(t){var e=t._subscribers,r=t._state;if(0!==e.length){for(var n=void 0,i=void 0,a=t._result,o=0;o<e.length;o+=3)n=e[o],i=e[o+r],n?z(r,n,i,a):i(a);t._subscribers.length=0}}function z(t,r,n,i){var a=e(n),o=void 0,s=void 0,l=!0;if(a){try{o=n(i)}catch(t){l=!1,s=t}if(r===o)return void L(r,new TypeError(\"A promises callback cannot return that same promise.\"))}else o=i;void 0!==r._state||(a&&l?S(r,o):!1===l?L(r,s):1===t?C(r,o):2===t&&L(r,o))}var O=0;function D(t){t[k]=O++,t._state=void 0,t._result=void 0,t._subscribers=[]}var R=function(){function t(t,e){this._instanceConstructor=t,this.promise=new t(M),this.promise[k]||D(this.promise),r(e)?(this.length=e.length,this._remaining=e.length,this._result=new Array(this.length),0===this.length?C(this.promise,this._result):(this.length=this.length||0,this._enumerate(e),0===this._remaining&&C(this.promise,this._result))):L(this.promise,new Error(\"Array Methods must be provided an Array\"))}return t.prototype._enumerate=function(t){for(var e=0;void 0===this._state&&e<t.length;e++)this._eachEntry(t[e],e)},t.prototype._eachEntry=function(t,e){var r=this._instanceConstructor,n=r.resolve;if(n===T){var i=void 0,a=void 0,o=!1;try{i=t.then}catch(t){o=!0,a=t}if(i===w&&void 0!==t._state)this._settledAt(t._state,e,t._result);else if(\"function\"!=typeof i)this._remaining--,this._result[e]=t;else if(r===F){var s=new r(M);o?L(s,a):A(s,t,i),this._willSettleAt(s,e)}else this._willSettleAt(new r((function(e){return e(t)})),e)}else this._willSettleAt(n(t),e)},t.prototype._settledAt=function(t,e,r){var n=this.promise;void 0===n._state&&(this._remaining--,2===t?L(n,r):this._result[e]=r),0===this._remaining&&C(n,this._result)},t.prototype._willSettleAt=function(t,e){var r=this;I(t,void 0,(function(t){return r._settledAt(1,e,t)}),(function(t){return r._settledAt(2,e,t)}))},t}();var F=function(){function t(e){this[k]=O++,this._result=this._state=void 0,this._subscribers=[],M!==e&&(\"function\"!=typeof e&&function(){throw new TypeError(\"You must pass a resolver function as the first argument to the promise constructor\")}(),this instanceof t?function(t,e){try{e((function(e){S(t,e)}),(function(e){L(t,e)}))}catch(e){L(t,e)}}(this,e):function(){throw new TypeError(\"Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.\")}())}return t.prototype.catch=function(t){return this.then(null,t)},t.prototype.finally=function(t){var r=this.constructor;return e(t)?this.then((function(e){return r.resolve(t()).then((function(){return e}))}),(function(e){return r.resolve(t()).then((function(){throw e}))})):this.then(t,t)},t}();return F.prototype.then=w,F.all=function(t){return new R(this,t).promise},F.race=function(t){var e=this;return r(t)?new e((function(r,n){for(var i=t.length,a=0;a<i;a++)e.resolve(t[a]).then(r,n)})):new e((function(t,e){return e(new TypeError(\"You must pass an array to race.\"))}))},F.resolve=T,F.reject=function(t){var e=new this(M);return L(e,t),e},F._setScheduler=function(t){s=t},F._setAsap=function(t){l=t},F._asap=l,F.polyfill=function(){var t=void 0;if(\"undefined\"!=typeof i)t=i;else if(\"undefined\"!=typeof self)t=self;else try{t=Function(\"return this\")()}catch(t){throw new Error(\"polyfill failed because global object is unavailable in this environment\")}var e=t.Promise;if(e){var r=null;try{r=Object.prototype.toString.call(e.resolve())}catch(t){}if(\"[object Promise]\"===r&&!e.cast)return}t.Promise=F},F.Promise=F,F}))}).call(this)}).call(this,t(\"_process\"),\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{_process:526}],225:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?t(\"ext/global-this\").Symbol:t(\"./polyfill\")},{\"./is-implemented\":226,\"./polyfill\":231,\"ext/global-this\":238}],226:[function(t,e,r){\"use strict\";var n=t(\"ext/global-this\"),i={object:!0,symbol:!0};e.exports=function(){var t,e=n.Symbol;if(\"function\"!=typeof e)return!1;t=e(\"test symbol\");try{String(t)}catch(t){return!1}return!!i[typeof e.iterator]&&(!!i[typeof e.toPrimitive]&&!!i[typeof e.toStringTag])}},{\"ext/global-this\":238}],227:[function(t,e,r){\"use strict\";e.exports=function(t){return!!t&&(\"symbol\"==typeof t||!!t.constructor&&(\"Symbol\"===t.constructor.name&&\"Symbol\"===t[t.constructor.toStringTag]))}},{}],228:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=Object.create,a=Object.defineProperty,o=Object.prototype,s=i(null);e.exports=function(t){for(var e,r,i=0;s[t+(i||\"\")];)++i;return s[t+=i||\"\"]=!0,a(o,e=\"@@\"+t,n.gs(null,(function(t){r||(r=!0,a(this,e,n(t)),r=!1)}))),e}},{d:155}],229:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"ext/global-this\").Symbol;e.exports=function(t){return Object.defineProperties(t,{hasInstance:n(\"\",i&&i.hasInstance||t(\"hasInstance\")),isConcatSpreadable:n(\"\",i&&i.isConcatSpreadable||t(\"isConcatSpreadable\")),iterator:n(\"\",i&&i.iterator||t(\"iterator\")),match:n(\"\",i&&i.match||t(\"match\")),replace:n(\"\",i&&i.replace||t(\"replace\")),search:n(\"\",i&&i.search||t(\"search\")),species:n(\"\",i&&i.species||t(\"species\")),split:n(\"\",i&&i.split||t(\"split\")),toPrimitive:n(\"\",i&&i.toPrimitive||t(\"toPrimitive\")),toStringTag:n(\"\",i&&i.toStringTag||t(\"toStringTag\")),unscopables:n(\"\",i&&i.unscopables||t(\"unscopables\"))})}},{d:155,\"ext/global-this\":238}],230:[function(t,e,r){\"use strict\";var n=t(\"d\"),i=t(\"../../../validate-symbol\"),a=Object.create(null);e.exports=function(t){return Object.defineProperties(t,{for:n((function(e){return a[e]?a[e]:a[e]=t(String(e))})),keyFor:n((function(t){var e;for(e in i(t),a)if(a[e]===t)return e}))})}},{\"../../../validate-symbol\":232,d:155}],231:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"d\"),s=t(\"./validate-symbol\"),l=t(\"ext/global-this\").Symbol,c=t(\"./lib/private/generate-name\"),u=t(\"./lib/private/setup/standard-symbols\"),f=t(\"./lib/private/setup/symbol-registry\"),h=Object.create,p=Object.defineProperties,d=Object.defineProperty;if(\"function\"==typeof l)try{String(l()),a=!0}catch(t){}else l=null;i=function(t){if(this instanceof i)throw new TypeError(\"Symbol is not a constructor\");return n(t)},e.exports=n=function t(e){var r;if(this instanceof t)throw new TypeError(\"Symbol is not a constructor\");return a?l(e):(r=h(i.prototype),e=void 0===e?\"\":String(e),p(r,{__description__:o(\"\",e),__name__:o(\"\",c(e))}))},u(n),f(n),p(i.prototype,{constructor:o(n),toString:o(\"\",(function(){return this.__name__}))}),p(n.prototype,{toString:o((function(){return\"Symbol (\"+s(this).__description__+\")\"})),valueOf:o((function(){return s(this)}))}),d(n.prototype,n.toPrimitive,o(\"\",(function(){var t=s(this);return\"symbol\"==typeof t?t:t.toString()}))),d(n.prototype,n.toStringTag,o(\"c\",\"Symbol\")),d(i.prototype,n.toStringTag,o(\"c\",n.prototype[n.toStringTag])),d(i.prototype,n.toPrimitive,o(\"c\",n.prototype[n.toPrimitive]))},{\"./lib/private/generate-name\":228,\"./lib/private/setup/standard-symbols\":229,\"./lib/private/setup/symbol-registry\":230,\"./validate-symbol\":232,d:155,\"ext/global-this\":238}],232:[function(t,e,r){\"use strict\";var n=t(\"./is-symbol\");e.exports=function(t){if(!n(t))throw new TypeError(t+\" is not a symbol\");return t}},{\"./is-symbol\":227}],233:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?WeakMap:t(\"./polyfill\")},{\"./is-implemented\":234,\"./polyfill\":236}],234:[function(t,e,r){\"use strict\";e.exports=function(){var t,e;if(\"function\"!=typeof WeakMap)return!1;try{t=new WeakMap([[e={},\"one\"],[{},\"two\"],[{},\"three\"]])}catch(t){return!1}return\"[object WeakMap]\"===String(t)&&(\"function\"==typeof t.set&&(t.set({},1)===t&&(\"function\"==typeof t.delete&&(\"function\"==typeof t.has&&\"one\"===t.get(e)))))}},{}],235:[function(t,e,r){\"use strict\";e.exports=\"function\"==typeof WeakMap&&\"[object WeakMap]\"===Object.prototype.toString.call(new WeakMap)},{}],236:[function(t,e,r){\"use strict\";var n,i=t(\"es5-ext/object/is-value\"),a=t(\"es5-ext/object/set-prototype-of\"),o=t(\"es5-ext/object/valid-object\"),s=t(\"es5-ext/object/valid-value\"),l=t(\"es5-ext/string/random-uniq\"),c=t(\"d\"),u=t(\"es6-iterator/get\"),f=t(\"es6-iterator/for-of\"),h=t(\"es6-symbol\").toStringTag,p=t(\"./is-native-implemented\"),d=Array.isArray,g=Object.defineProperty,m=Object.prototype.hasOwnProperty,v=Object.getPrototypeOf;e.exports=n=function(){var t,e=arguments[0];if(!(this instanceof n))throw new TypeError(\"Constructor requires 'new'\");return t=p&&a&&WeakMap!==n?a(new WeakMap,v(this)):this,i(e)&&(d(e)||(e=u(e))),g(t,\"__weakMapData__\",c(\"c\",\"$weakMap$\"+l())),e?(f(e,(function(e){s(e),t.set(e[0],e[1])})),t):t},p&&(a&&a(n,WeakMap),n.prototype=Object.create(WeakMap.prototype,{constructor:c(n)})),Object.defineProperties(n.prototype,{delete:c((function(t){return!!m.call(o(t),this.__weakMapData__)&&(delete t[this.__weakMapData__],!0)})),get:c((function(t){if(m.call(o(t),this.__weakMapData__))return t[this.__weakMapData__]})),has:c((function(t){return m.call(o(t),this.__weakMapData__)})),set:c((function(t,e){return g(o(t),this.__weakMapData__,c(\"c\",e)),this})),toString:c((function(){return\"[object WeakMap]\"}))}),g(n.prototype,h,c(\"c\",\"WeakMap\"))},{\"./is-native-implemented\":235,d:155,\"es5-ext/object/is-value\":200,\"es5-ext/object/set-prototype-of\":206,\"es5-ext/object/valid-object\":210,\"es5-ext/object/valid-value\":211,\"es5-ext/string/random-uniq\":216,\"es6-iterator/for-of\":218,\"es6-iterator/get\":219,\"es6-symbol\":225}],237:[function(t,e,r){var n=function(){if(\"object\"==typeof self&&self)return self;if(\"object\"==typeof window&&window)return window;throw new Error(\"Unable to resolve global `this`\")};e.exports=function(){if(this)return this;try{Object.defineProperty(Object.prototype,\"__global__\",{get:function(){return this},configurable:!0})}catch(t){return n()}try{return __global__||n()}finally{delete Object.prototype.__global__}}()},{}],238:[function(t,e,r){\"use strict\";e.exports=t(\"./is-implemented\")()?globalThis:t(\"./implementation\")},{\"./implementation\":237,\"./is-implemented\":239}],239:[function(t,e,r){\"use strict\";e.exports=function(){return\"object\"==typeof globalThis&&(!!globalThis&&globalThis.Array===Array)}},{}],240:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=e||0,i=r||1;return[[t[12]+t[0],t[13]+t[1],t[14]+t[2],t[15]+t[3]],[t[12]-t[0],t[13]-t[1],t[14]-t[2],t[15]-t[3]],[t[12]+t[4],t[13]+t[5],t[14]+t[6],t[15]+t[7]],[t[12]-t[4],t[13]-t[5],t[14]-t[6],t[15]-t[7]],[n*t[12]+t[8],n*t[13]+t[9],n*t[14]+t[10],n*t[15]+t[11]],[i*t[12]-t[8],i*t[13]-t[9],i*t[14]-t[10],i*t[15]-t[11]]]}},{}],241:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\");e.exports=function(t){var e=typeof t;if(\"string\"===e){var r=t;if(0===(t=+t)&&n(r))return!1}else if(\"number\"!==e)return!1;return t-t<1}},{\"is-string-blank\":470}],242:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){switch(arguments.length){case 0:return new o([0],[0],0);case 1:return\"number\"==typeof t?new o(n=l(t),n,0):new o(t,l(t.length),0);case 2:if(\"number\"==typeof e){var n=l(t.length);return new o(t,n,+e)}r=0;case 3:if(t.length!==e.length)throw new Error(\"state and velocity lengths must match\");return new o(t,e,r)}};var n=t(\"cubic-hermite\"),i=t(\"binary-search-bounds\");function a(t,e,r){return Math.min(e,Math.max(t,r))}function o(t,e,r){this.dimension=t.length,this.bounds=[new Array(this.dimension),new Array(this.dimension)];for(var n=0;n<this.dimension;++n)this.bounds[0][n]=-1/0,this.bounds[1][n]=1/0;this._state=t.slice().reverse(),this._velocity=e.slice().reverse(),this._time=[r],this._scratch=[t.slice(),t.slice(),t.slice(),t.slice(),t.slice()]}var s=o.prototype;function l(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=0;return e}s.flush=function(t){var e=i.gt(this._time,t)-1;e<=0||(this._time.splice(0,e),this._state.splice(0,e*this.dimension),this._velocity.splice(0,e*this.dimension))},s.curve=function(t){var e=this._time,r=e.length,o=i.le(e,t),s=this._scratch[0],l=this._state,c=this._velocity,u=this.dimension,f=this.bounds;if(o<0)for(var h=u-1,p=0;p<u;++p,--h)s[p]=l[h];else if(o>=r-1){h=l.length-1;var d=t-e[r-1];for(p=0;p<u;++p,--h)s[p]=l[h]+d*c[h]}else{h=u*(o+1)-1;var g=e[o],m=e[o+1]-g||1,v=this._scratch[1],y=this._scratch[2],x=this._scratch[3],b=this._scratch[4],_=!0;for(p=0;p<u;++p,--h)v[p]=l[h],x[p]=c[h]*m,y[p]=l[h+u],b[p]=c[h+u]*m,_=_&&v[p]===y[p]&&x[p]===b[p]&&0===x[p];if(_)for(p=0;p<u;++p)s[p]=v[p];else n(v,x,y,b,(t-g)/m,s)}var w=f[0],T=f[1];for(p=0;p<u;++p)s[p]=a(w[p],T[p],s[p]);return s},s.dcurve=function(t){var e=this._time,r=e.length,a=i.le(e,t),o=this._scratch[0],s=this._state,l=this._velocity,c=this.dimension;if(a>=r-1)for(var u=s.length-1,f=(e[r-1],0);f<c;++f,--u)o[f]=l[u];else{u=c*(a+1)-1;var h=e[a],p=e[a+1]-h||1,d=this._scratch[1],g=this._scratch[2],m=this._scratch[3],v=this._scratch[4],y=!0;for(f=0;f<c;++f,--u)d[f]=s[u],m[f]=l[u]*p,g[f]=s[u+c],v[f]=l[u+c]*p,y=y&&d[f]===g[f]&&m[f]===v[f]&&0===m[f];if(y)for(f=0;f<c;++f)o[f]=0;else{n.derivative(d,m,g,v,(t-h)/p,o);for(f=0;f<c;++f)o[f]/=p}}return o},s.lastT=function(){var t=this._time;return t[t.length-1]},s.stable=function(){for(var t=this._velocity,e=t.length,r=this.dimension-1;r>=0;--r)if(t[--e])return!1;return!0},s.jump=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1];this._time.push(e,t);for(var u=0;u<2;++u)for(var f=0;f<r;++f)n.push(n[o++]),i.push(0);this._time.push(t);for(f=r;f>0;--f)n.push(a(l[f-1],c[f-1],arguments[f])),i.push(0)}},s.push=function(t){var e=this.lastT(),r=this.dimension;if(!(t<e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=t-e,l=this.bounds,c=l[0],u=l[1],f=s>1e-6?1/s:0;this._time.push(t);for(var h=r;h>0;--h){var p=a(c[h-1],u[h-1],arguments[h]);n.push(p),i.push((p-n[o++])*f)}}},s.set=function(t){var e=this.dimension;if(!(t<this.lastT()||arguments.length!==e+1)){var r=this._state,n=this._velocity,i=this.bounds,o=i[0],s=i[1];this._time.push(t);for(var l=e;l>0;--l)r.push(a(o[l-1],s[l-1],arguments[l])),n.push(0)}},s.move=function(t){var e=this.lastT(),r=this.dimension;if(!(t<=e||arguments.length!==r+1)){var n=this._state,i=this._velocity,o=n.length-this.dimension,s=this.bounds,l=s[0],c=s[1],u=t-e,f=u>1e-6?1/u:0;this._time.push(t);for(var h=r;h>0;--h){var p=arguments[h];n.push(a(l[h-1],c[h-1],n[o++]+p)),i.push(p*f)}}},s.idle=function(t){var e=this.lastT();if(!(t<e)){var r=this.dimension,n=this._state,i=this._velocity,o=n.length-r,s=this.bounds,l=s[0],c=s[1],u=t-e;this._time.push(t);for(var f=r-1;f>=0;--f)n.push(a(l[f],c[f],n[o]+u*i[o])),i.push(0),o+=1}}},{\"binary-search-bounds\":243,\"cubic-hermite\":150}],243:[function(t,e,r){\"use strict\";function n(t,e,r,n,i,a){var o=[\"function \",t,\"(a,l,h,\",n.join(\",\"),\"){\",a?\"\":\"var i=\",r?\"l-1\":\"h+1\",\";while(l<=h){var m=(l+h)>>>1,x=a\",i?\".get(m)\":\"[m]\"];return a?e.indexOf(\"c\")<0?o.push(\";if(x===y){return m}else if(x<=y){\"):o.push(\";var p=c(x,y);if(p===0){return m}else if(p<=0){\"):o.push(\";if(\",e,\"){i=m;\"),r?o.push(\"l=m+1}else{h=m-1}\"):o.push(\"h=m-1}else{l=m+1}\"),o.push(\"}\"),a?o.push(\"return -1};\"):o.push(\"return i};\"),o.join(\"\")}function i(t,e,r,i){return new Function([n(\"A\",\"x\"+t+\"y\",e,[\"y\"],!1,i),n(\"B\",\"x\"+t+\"y\",e,[\"y\"],!0,i),n(\"P\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!1,i),n(\"Q\",\"c(x,y)\"+t+\"0\",e,[\"y\",\"c\"],!0,i),\"function dispatchBsearch\",r,\"(a,y,c,l,h){if(a.shape){if(typeof(c)==='function'){return Q(a,(l===undefined)?0:l|0,(h===undefined)?a.shape[0]-1:h|0,y,c)}else{return B(a,(c===undefined)?0:c|0,(l===undefined)?a.shape[0]-1:l|0,y)}}else{if(typeof(c)==='function'){return P(a,(l===undefined)?0:l|0,(h===undefined)?a.length-1:h|0,y,c)}else{return A(a,(c===undefined)?0:c|0,(l===undefined)?a.length-1:l|0,y)}}}return dispatchBsearch\",r].join(\"\"))()}e.exports={ge:i(\">=\",!1,\"GE\"),gt:i(\">\",!1,\"GT\"),lt:i(\"<\",!0,\"LT\"),le:i(\"<=\",!0,\"LE\"),eq:i(\"-\",!0,\"EQ\",!0)}},{}],244:[function(t,e,r){var n=t(\"dtype\");e.exports=function(t,e,r){if(!t)throw new TypeError(\"must specify data as first parameter\");if(r=0|+(r||0),Array.isArray(t)&&t[0]&&\"number\"==typeof t[0][0]){var i,a,o,s,l=t[0].length,c=t.length*l;e&&\"string\"!=typeof e||(e=new(n(e||\"float32\"))(c+r));var u=e.length-r;if(c!==u)throw new Error(\"source length \"+c+\" (\"+l+\"x\"+t.length+\") does not match destination length \"+u);for(i=0,o=r;i<t.length;i++)for(a=0;a<l;a++)e[o++]=null===t[i][a]?NaN:t[i][a]}else if(e&&\"string\"!=typeof e)e.set(t,r);else{var f=n(e||\"float32\");if(Array.isArray(t)||\"array\"===e)for(e=new f(t.length+r),i=0,o=r,s=e.length;o<s;o++,i++)e[o]=null===t[i]?NaN:t[i];else 0===r?e=new f(t):(e=new f(t.length+r)).set(t,r)}return e}},{dtype:175}],245:[function(t,e,r){\"use strict\";var n=t(\"css-font/stringify\"),i=[32,126];e.exports=function(t){var e=(t=t||{}).shape?t.shape:t.canvas?[t.canvas.width,t.canvas.height]:[512,512],r=t.canvas||document.createElement(\"canvas\"),a=t.font,o=\"number\"==typeof t.step?[t.step,t.step]:t.step||[32,32],s=t.chars||i;a&&\"string\"!=typeof a&&(a=n(a));if(Array.isArray(s)){if(2===s.length&&\"number\"==typeof s[0]&&\"number\"==typeof s[1]){for(var l=[],c=s[0],u=0;c<=s[1];c++)l[u++]=String.fromCharCode(c);s=l}}else s=String(s).split(\"\");e=e.slice(),r.width=e[0],r.height=e[1];var f=r.getContext(\"2d\");f.fillStyle=\"#000\",f.fillRect(0,0,r.width,r.height),f.font=a,f.textAlign=\"center\",f.textBaseline=\"middle\",f.fillStyle=\"#fff\";var h=o[0]/2,p=o[1]/2;for(c=0;c<s.length;c++)f.fillText(s[c],h,p),(h+=o[0])>e[0]-o[0]/2&&(h=o[0]/2,p+=o[1]);return r}},{\"css-font/stringify\":147}],246:[function(t,e,r){\"use strict\";function n(t,e){e||(e={}),(\"string\"==typeof t||Array.isArray(t))&&(e.family=t);var r=Array.isArray(e.family)?e.family.join(\", \"):e.family;if(!r)throw Error(\"`family` must be defined\");var s=e.size||e.fontSize||e.em||48,l=e.weight||e.fontWeight||\"\",c=(t=[e.style||e.fontStyle||\"\",l,s].join(\" \")+\"px \"+r,e.origin||\"top\");if(n.cache[r]&&s<=n.cache[r].em)return i(n.cache[r],c);var u=e.canvas||n.canvas,f=u.getContext(\"2d\"),h={upper:void 0!==e.upper?e.upper:\"H\",lower:void 0!==e.lower?e.lower:\"x\",descent:void 0!==e.descent?e.descent:\"p\",ascent:void 0!==e.ascent?e.ascent:\"h\",tittle:void 0!==e.tittle?e.tittle:\"i\",overshoot:void 0!==e.overshoot?e.overshoot:\"O\"},p=Math.ceil(1.5*s);u.height=p,u.width=.5*p,f.font=t;var d={top:0};f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillStyle=\"black\",f.fillText(\"H\",0,0);var g=a(f.getImageData(0,0,p,p));f.clearRect(0,0,p,p),f.textBaseline=\"bottom\",f.fillText(\"H\",0,p);var m=a(f.getImageData(0,0,p,p));d.lineHeight=d.bottom=p-m+g,f.clearRect(0,0,p,p),f.textBaseline=\"alphabetic\",f.fillText(\"H\",0,p);var v=p-a(f.getImageData(0,0,p,p))-1+g;d.baseline=d.alphabetic=v,f.clearRect(0,0,p,p),f.textBaseline=\"middle\",f.fillText(\"H\",0,.5*p);var y=a(f.getImageData(0,0,p,p));d.median=d.middle=p-y-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"hanging\",f.fillText(\"H\",0,.5*p);var x=a(f.getImageData(0,0,p,p));d.hanging=p-x-1+g-.5*p,f.clearRect(0,0,p,p),f.textBaseline=\"ideographic\",f.fillText(\"H\",0,p);var b=a(f.getImageData(0,0,p,p));if(d.ideographic=p-b-1+g,h.upper&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.upper,0,0),d.upper=a(f.getImageData(0,0,p,p)),d.capHeight=d.baseline-d.upper),h.lower&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.lower,0,0),d.lower=a(f.getImageData(0,0,p,p)),d.xHeight=d.baseline-d.lower),h.tittle&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.tittle,0,0),d.tittle=a(f.getImageData(0,0,p,p))),h.ascent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.ascent,0,0),d.ascent=a(f.getImageData(0,0,p,p))),h.descent&&(f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.descent,0,0),d.descent=o(f.getImageData(0,0,p,p))),h.overshoot){f.clearRect(0,0,p,p),f.textBaseline=\"top\",f.fillText(h.overshoot,0,0);var _=o(f.getImageData(0,0,p,p));d.overshoot=_-v}for(var w in d)d[w]/=s;return d.em=s,n.cache[r]=d,i(d,c)}function i(t,e){var r={};for(var n in\"string\"==typeof e&&(e=t[e]),t)\"em\"!==n&&(r[n]=t[n]-e);return r}function a(t){for(var e=t.height,r=t.data,n=3;n<r.length;n+=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}function o(t){for(var e=t.height,r=t.data,n=r.length-1;n>0;n-=4)if(0!==r[n])return Math.floor(.25*(n-3)/e)}e.exports=n,n.canvas=document.createElement(\"canvas\"),n.cache={}},{}],247:[function(t,e,r){\"use strict\";e.exports=function(t){return new s(t||g,null)};function n(t,e,r,n,i,a){this._color=t,this.key=e,this.value=r,this.left=n,this.right=i,this._count=a}function i(t){return new n(t._color,t.key,t.value,t.left,t.right,t._count)}function a(t,e){return new n(t,e.key,e.value,e.left,e.right,e._count)}function o(t){t._count=1+(t.left?t.left._count:0)+(t.right?t.right._count:0)}function s(t,e){this._compare=t,this.root=e}var l=s.prototype;function c(t,e){var r;if(e.left&&(r=c(t,e.left)))return r;return(r=t(e.key,e.value))||(e.right?c(t,e.right):void 0)}function u(t,e,r,n){if(e(t,n.key)<=0){var i;if(n.left)if(i=u(t,e,r,n.left))return i;if(i=r(n.key,n.value))return i}if(n.right)return u(t,e,r,n.right)}function f(t,e,r,n,i){var a,o=r(t,i.key),s=r(e,i.key);if(o<=0){if(i.left&&(a=f(t,e,r,n,i.left)))return a;if(s>0&&(a=n(i.key,i.value)))return a}if(s>0&&i.right)return f(t,e,r,n,i.right)}function h(t,e){this.tree=t,this._stack=e}Object.defineProperty(l,\"keys\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(e)})),t}}),Object.defineProperty(l,\"values\",{get:function(){var t=[];return this.forEach((function(e,r){t.push(r)})),t}}),Object.defineProperty(l,\"length\",{get:function(){return this.root?this.root._count:0}}),l.insert=function(t,e){for(var r=this._compare,i=this.root,l=[],c=[];i;){var u=r(t,i.key);l.push(i),c.push(u),i=u<=0?i.left:i.right}l.push(new n(0,t,e,null,null,1));for(var f=l.length-2;f>=0;--f){i=l[f];c[f]<=0?l[f]=new n(i._color,i.key,i.value,l[f+1],i.right,i._count+1):l[f]=new n(i._color,i.key,i.value,i.left,l[f+1],i._count+1)}for(f=l.length-1;f>1;--f){var h=l[f-1];i=l[f];if(1===h._color||1===i._color)break;var p=l[f-2];if(p.left===h)if(h.left===i){if(!(d=p.right)||0!==d._color){if(p._color=0,p.left=h.right,h._color=1,h.right=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).left===p?g.left=h:g.right=h;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else{if(!(d=p.right)||0!==d._color){if(h.right=i.left,p._color=0,p.left=i.right,i._color=1,i.left=h,i.right=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).left===p?g.left=i:g.right=i;break}h._color=1,p.right=a(1,d),p._color=0,f-=1}else if(h.right===i){if(!(d=p.left)||0!==d._color){if(p._color=0,p.right=h.left,h._color=1,h.left=p,l[f-2]=h,l[f-1]=i,o(p),o(h),f>=3)(g=l[f-3]).right===p?g.right=h:g.left=h;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}else{var d;if(!(d=p.left)||0!==d._color){var g;if(h.left=i.right,p._color=0,p.right=i.left,i._color=1,i.right=h,i.left=p,l[f-2]=i,l[f-1]=h,o(p),o(h),o(i),f>=3)(g=l[f-3]).right===p?g.right=i:g.left=i;break}h._color=1,p.left=a(1,d),p._color=0,f-=1}}return l[0]._color=1,new s(r,l[0])},l.forEach=function(t,e,r){if(this.root)switch(arguments.length){case 1:return c(t,this.root);case 2:return u(e,this._compare,t,this.root);case 3:if(this._compare(e,r)>=0)return;return f(e,r,this._compare,t,this.root)}},Object.defineProperty(l,\"begin\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.left;return new h(this,t)}}),Object.defineProperty(l,\"end\",{get:function(){for(var t=[],e=this.root;e;)t.push(e),e=e.right;return new h(this,t)}}),l.at=function(t){if(t<0)return new h(this,[]);for(var e=this.root,r=[];;){if(r.push(e),e.left){if(t<e.left._count){e=e.left;continue}t-=e.left._count}if(!t)return new h(this,r);if(t-=1,!e.right)break;if(t>=e.right._count)break;e=e.right}return new h(this,[])},l.ge=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<=0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.gt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a<0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.lt=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>0&&(i=n.length),r=a<=0?r.left:r.right}return n.length=i,new h(this,n)},l.le=function(t){for(var e=this._compare,r=this.root,n=[],i=0;r;){var a=e(t,r.key);n.push(r),a>=0&&(i=n.length),r=a<0?r.left:r.right}return n.length=i,new h(this,n)},l.find=function(t){for(var e=this._compare,r=this.root,n=[];r;){var i=e(t,r.key);if(n.push(r),0===i)return new h(this,n);r=i<=0?r.left:r.right}return new h(this,[])},l.remove=function(t){var e=this.find(t);return e?e.remove():this},l.get=function(t){for(var e=this._compare,r=this.root;r;){var n=e(t,r.key);if(0===n)return r.value;r=n<=0?r.left:r.right}};var p=h.prototype;function d(t,e){t.key=e.key,t.value=e.value,t.left=e.left,t.right=e.right,t._color=e._color,t._count=e._count}function g(t,e){return t<e?-1:t>e?1:0}Object.defineProperty(p,\"valid\",{get:function(){return this._stack.length>0}}),Object.defineProperty(p,\"node\",{get:function(){return this._stack.length>0?this._stack[this._stack.length-1]:null},enumerable:!0}),p.clone=function(){return new h(this.tree,this._stack.slice())},p.remove=function(){var t=this._stack;if(0===t.length)return this.tree;var e=new Array(t.length),r=t[t.length-1];e[e.length-1]=new n(r._color,r.key,r.value,r.left,r.right,r._count);for(var l=t.length-2;l>=0;--l){(r=t[l]).left===t[l+1]?e[l]=new n(r._color,r.key,r.value,e[l+1],r.right,r._count):e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count)}if((r=e[e.length-1]).left&&r.right){var c=e.length;for(r=r.left;r.right;)e.push(r),r=r.right;var u=e[c-1];e.push(new n(r._color,u.key,u.value,r.left,r.right,r._count)),e[c-1].key=r.key,e[c-1].value=r.value;for(l=e.length-2;l>=c;--l)r=e[l],e[l]=new n(r._color,r.key,r.value,r.left,e[l+1],r._count);e[c-1].left=e[c]}if(0===(r=e[e.length-1])._color){var f=e[e.length-2];f.left===r?f.left=null:f.right===r&&(f.right=null),e.pop();for(l=0;l<e.length;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(r.left||r.right){r.left?d(r,r.left):r.right&&d(r,r.right),r._color=1;for(l=0;l<e.length-1;++l)e[l]._count--;return new s(this.tree._compare,e[0])}if(1===e.length)return new s(this.tree._compare,null);for(l=0;l<e.length;++l)e[l]._count--;var h=e[e.length-2];return function(t){for(var e,r,n,s,l=t.length-1;l>=0;--l){if(e=t[l],0===l)return void(e._color=1);if((r=t[l-1]).left===e){if((n=r.right).right&&0===n.right._color){if(s=(n=r.right=i(n)).right=i(n.right),r.right=n.left,n.left=r,n.right=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).left===r?c.left=n:c.right=n;return void(t[l-1]=n)}if(n.left&&0===n.left._color){if(s=(n=r.right=i(n)).left=i(n.left),r.right=s.left,n.left=s.right,s.left=r,s.right=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).left===r?c.left=s:c.right=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.right=a(0,n));r.right=a(0,n);continue}n=i(n),r.right=n.left,n.left=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).left===r?c.left=n:c.right=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}else{if((n=r.left).left&&0===n.left._color){if(s=(n=r.left=i(n)).left=i(n.left),r.left=n.right,n.right=r,n.left=s,n._color=r._color,e._color=1,r._color=1,s._color=1,o(r),o(n),l>1)(c=t[l-2]).right===r?c.right=n:c.left=n;return void(t[l-1]=n)}if(n.right&&0===n.right._color){if(s=(n=r.left=i(n)).right=i(n.right),r.left=s.right,n.right=s.left,s.right=r,s.left=n,s._color=r._color,r._color=1,n._color=1,e._color=1,o(r),o(n),o(s),l>1)(c=t[l-2]).right===r?c.right=s:c.left=s;return void(t[l-1]=s)}if(1===n._color){if(0===r._color)return r._color=1,void(r.left=a(0,n));r.left=a(0,n);continue}var c;n=i(n),r.left=n.right,n.right=r,n._color=r._color,r._color=0,o(r),o(n),l>1&&((c=t[l-2]).right===r?c.right=n:c.left=n),t[l-1]=n,t[l]=r,l+1<t.length?t[l+1]=e:t.push(e),l+=2}}}(e),h.left===r?h.left=null:h.right=null,new s(this.tree._compare,e[0])},Object.defineProperty(p,\"key\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].key},enumerable:!0}),Object.defineProperty(p,\"value\",{get:function(){if(this._stack.length>0)return this._stack[this._stack.length-1].value},enumerable:!0}),Object.defineProperty(p,\"index\",{get:function(){var t=0,e=this._stack;if(0===e.length){var r=this.tree.root;return r?r._count:0}e[e.length-1].left&&(t=e[e.length-1].left._count);for(var n=e.length-2;n>=0;--n)e[n+1]===e[n].right&&(++t,e[n].left&&(t+=e[n].left._count));return t},enumerable:!0}),p.next=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.right)for(e=e.right;e;)t.push(e),e=e.left;else for(t.pop();t.length>0&&t[t.length-1].right===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasNext\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].right)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].left===t[e])return!0;return!1}}),p.update=function(t){var e=this._stack;if(0===e.length)throw new Error(\"Can't update empty node!\");var r=new Array(e.length),i=e[e.length-1];r[r.length-1]=new n(i._color,i.key,t,i.left,i.right,i._count);for(var a=e.length-2;a>=0;--a)(i=e[a]).left===e[a+1]?r[a]=new n(i._color,i.key,i.value,r[a+1],i.right,i._count):r[a]=new n(i._color,i.key,i.value,i.left,r[a+1],i._count);return new s(this.tree._compare,r[0])},p.prev=function(){var t=this._stack;if(0!==t.length){var e=t[t.length-1];if(e.left)for(e=e.left;e;)t.push(e),e=e.right;else for(t.pop();t.length>0&&t[t.length-1].left===e;)e=t[t.length-1],t.pop()}},Object.defineProperty(p,\"hasPrev\",{get:function(){var t=this._stack;if(0===t.length)return!1;if(t[t.length-1].left)return!0;for(var e=t.length-1;e>0;--e)if(t[e-1].right===t[e])return!0;return!1}})},{}],248:[function(t,e,r){var n=[.9999999999998099,676.5203681218851,-1259.1392167224028,771.3234287776531,-176.6150291621406,12.507343278686905,-.13857109526572012,9984369578019572e-21,1.5056327351493116e-7],i=[.9999999999999971,57.15623566586292,-59.59796035547549,14.136097974741746,-.4919138160976202,3399464998481189e-20,4652362892704858e-20,-9837447530487956e-20,.0001580887032249125,-.00021026444172410488,.00021743961811521265,-.0001643181065367639,8441822398385275e-20,-26190838401581408e-21,36899182659531625e-22];function a(t){if(t<0)return Number(\"0/0\");for(var e=i[0],r=i.length-1;r>0;--r)e+=i[r]/(t+r);var n=t+607/128+.5;return.5*Math.log(2*Math.PI)+(t+.5)*Math.log(n)-n+Math.log(e)-Math.log(t)}e.exports=function t(e){if(e<.5)return Math.PI/(Math.sin(Math.PI*e)*t(1-e));if(e>100)return Math.exp(a(e));e-=1;for(var r=n[0],i=1;i<9;i++)r+=n[i]/(e+i);var o=e+7+.5;return Math.sqrt(2*Math.PI)*Math.pow(o,e+.5)*Math.exp(-o)*r},e.exports.log=a},{}],249:[function(t,e,r){e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"must specify type string\");if(e=e||{},\"undefined\"==typeof document&&!e.canvas)return null;var r=e.canvas||document.createElement(\"canvas\");\"number\"==typeof e.width&&(r.width=e.width);\"number\"==typeof e.height&&(r.height=e.height);var n,i=e;try{var a=[t];0===t.indexOf(\"webgl\")&&a.push(\"experimental-\"+t);for(var o=0;o<a.length;o++)if(n=r.getContext(a[o],i))return n}catch(t){n=null}return n||null}},{}],250:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=new u(t);return r.update(e),r};var n=t(\"./lib/text.js\"),i=t(\"./lib/lines.js\"),a=t(\"./lib/background.js\"),o=t(\"./lib/cube.js\"),s=t(\"./lib/ticks.js\"),l=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]);function c(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function u(t){this.gl=t,this.pixelRatio=1,this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.autoTicks=!0,this.tickSpacing=[1,1,1],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickAlign=[\"auto\",\"auto\",\"auto\"],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[10,10,10],this.lastCubeProps={cubeEdges:[0,0,0],axis:[0,0,0]},this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=\"sans-serif\",this.labelSize=[20,20,20],this.labelAngle=[0,0,0],this.labelAlign=[\"auto\",\"auto\",\"auto\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[10,10,10],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[0,0,0],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!1,!1,!1],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._firstInit=!0,this._text=null,this._lines=null,this._background=a(t)}var f=u.prototype;function h(){this.primalOffset=[0,0,0],this.primalMinor=[0,0,0],this.mirrorOffset=[0,0,0],this.mirrorMinor=[0,0,0]}f.update=function(t){function e(e,r,n){if(n in t){var i,a=t[n],o=this[n];(e?Array.isArray(a)&&Array.isArray(a[0]):Array.isArray(a))?this[n]=i=[r(a[0]),r(a[1]),r(a[2])]:this[n]=i=[r(a),r(a),r(a)];for(var s=0;s<3;++s)if(i[s]!==o[s])return!0}return!1}t=t||{};var r,a=e.bind(this,!1,Number),o=e.bind(this,!1,Boolean),l=e.bind(this,!1,String),c=e.bind(this,!0,(function(t){if(Array.isArray(t)){if(3===t.length)return[+t[0],+t[1],+t[2],1];if(4===t.length)return[+t[0],+t[1],+t[2],+t[3]]}return[0,0,0,1]})),u=!1,f=!1;if(\"bounds\"in t)for(var h=t.bounds,p=0;p<2;++p)for(var d=0;d<3;++d)h[p][d]!==this.bounds[p][d]&&(f=!0),this.bounds[p][d]=h[p][d];if(\"ticks\"in t){r=t.ticks,u=!0,this.autoTicks=!1;for(p=0;p<3;++p)this.tickSpacing[p]=0}else a(\"tickSpacing\")&&(this.autoTicks=!0,f=!0);if(this._firstInit&&(\"ticks\"in t||\"tickSpacing\"in t||(this.autoTicks=!0),f=!0,u=!0,this._firstInit=!1),f&&this.autoTicks&&(r=s.create(this.bounds,this.tickSpacing),u=!0),u){for(p=0;p<3;++p)r[p].sort((function(t,e){return t.x-e.x}));s.equal(r,this.ticks)?u=!1:this.ticks=r}o(\"tickEnable\"),l(\"tickFont\")&&(u=!0),a(\"tickSize\"),a(\"tickAngle\"),a(\"tickPad\"),c(\"tickColor\");var g=l(\"labels\");l(\"labelFont\")&&(g=!0),o(\"labelEnable\"),a(\"labelSize\"),a(\"labelPad\"),c(\"labelColor\"),o(\"lineEnable\"),o(\"lineMirror\"),a(\"lineWidth\"),c(\"lineColor\"),o(\"lineTickEnable\"),o(\"lineTickMirror\"),a(\"lineTickLength\"),a(\"lineTickWidth\"),c(\"lineTickColor\"),o(\"gridEnable\"),a(\"gridWidth\"),c(\"gridColor\"),o(\"zeroEnable\"),c(\"zeroLineColor\"),a(\"zeroLineWidth\"),o(\"backgroundEnable\"),c(\"backgroundColor\"),this._text?this._text&&(g||u)&&this._text.update(this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont):this._text=n(this.gl,this.bounds,this.labels,this.labelFont,this.ticks,this.tickFont),this._lines&&u&&(this._lines.dispose(),this._lines=null),this._lines||(this._lines=i(this.gl,this.bounds,this.ticks))};var p=[new h,new h,new h];function d(t,e,r,n,i){for(var a=t.primalOffset,o=t.primalMinor,s=t.mirrorOffset,l=t.mirrorMinor,c=n[e],u=0;u<3;++u)if(e!==u){var f=a,h=s,p=o,d=l;c&1<<u&&(f=s,h=a,p=l,d=o),f[u]=r[0][u],h[u]=r[1][u],i[u]>0?(p[u]=-1,d[u]=0):(p[u]=0,d[u]=1)}}var g=[0,0,0],m={model:l,view:l,projection:l,_ortho:!1};f.isOpaque=function(){return!0},f.isTransparent=function(){return!1},f.drawTransparent=function(t){};var v=[0,0,0],y=[0,0,0],x=[0,0,0];f.draw=function(t){t=t||m;for(var e=this.gl,r=t.model||l,n=t.view||l,i=t.projection||l,a=this.bounds,s=t._ortho||!1,u=o(r,n,i,a,s),f=u.cubeEdges,h=u.axis,b=n[12],_=n[13],w=n[14],T=n[15],k=(s?2:1)*this.pixelRatio*(i[3]*b+i[7]*_+i[11]*w+i[15]*T)/e.drawingBufferHeight,M=0;M<3;++M)this.lastCubeProps.cubeEdges[M]=f[M],this.lastCubeProps.axis[M]=h[M];var A=p;for(M=0;M<3;++M)d(p[M],M,this.bounds,f,h);e=this.gl;var S,E=g;for(M=0;M<3;++M)this.backgroundEnable[M]?E[M]=h[M]:E[M]=0;this._background.draw(r,n,i,a,E,this.backgroundColor),this._lines.bind(r,n,i,this);for(M=0;M<3;++M){var C=[0,0,0];h[M]>0?C[M]=a[1][M]:C[M]=a[0][M];for(var L=0;L<2;++L){var I=(M+1+L)%3,P=(M+1+(1^L))%3;this.gridEnable[I]&&this._lines.drawGrid(I,P,this.bounds,C,this.gridColor[I],this.gridWidth[I]*this.pixelRatio)}for(L=0;L<2;++L){I=(M+1+L)%3,P=(M+1+(1^L))%3;this.zeroEnable[P]&&Math.min(a[0][P],a[1][P])<=0&&Math.max(a[0][P],a[1][P])>=0&&this._lines.drawZero(I,P,this.bounds,C,this.zeroLineColor[P],this.zeroLineWidth[P]*this.pixelRatio)}}for(M=0;M<3;++M){this.lineEnable[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].primalOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio),this.lineMirror[M]&&this._lines.drawAxisLine(M,this.bounds,A[M].mirrorOffset,this.lineColor[M],this.lineWidth[M]*this.pixelRatio);var z=c(v,A[M].primalMinor),O=c(y,A[M].mirrorMinor),D=this.lineTickLength;for(L=0;L<3;++L){var R=k/r[5*L];z[L]*=D[L]*R,O[L]*=D[L]*R}this.lineTickEnable[M]&&this._lines.drawAxisTicks(M,A[M].primalOffset,z,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio),this.lineTickMirror[M]&&this._lines.drawAxisTicks(M,A[M].mirrorOffset,O,this.lineTickColor[M],this.lineTickWidth[M]*this.pixelRatio)}this._lines.unbind(),this._text.bind(r,n,i,this.pixelRatio);var F,B;function N(t){(B=[0,0,0])[t]=1}function j(t,e,r){var n=(t+1)%3,i=(t+2)%3,a=e[n],o=e[i],s=r[n],l=r[i];a>0&&l>0||a>0&&l<0||a<0&&l>0||a<0&&l<0?N(n):(o>0&&s>0||o>0&&s<0||o<0&&s>0||o<0&&s<0)&&N(i)}for(M=0;M<3;++M){var U=A[M].primalMinor,V=A[M].mirrorMinor,q=c(x,A[M].primalOffset);for(L=0;L<3;++L)this.lineTickEnable[M]&&(q[L]+=k*U[L]*Math.max(this.lineTickLength[L],0)/r[5*L]);var H=[0,0,0];if(H[M]=1,this.tickEnable[M]){-3600===this.tickAngle[M]?(this.tickAngle[M]=0,this.tickAlign[M]=\"auto\"):this.tickAlign[M]=-1,F=1,\"auto\"===(S=[this.tickAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]),B=[0,0,0],j(M,U,V);for(L=0;L<3;++L)q[L]+=k*U[L]*this.tickPad[L]/r[5*L];this._text.drawTicks(M,this.tickSize[M],this.tickAngle[M],q,this.tickColor[M],H,B,S)}if(this.labelEnable[M]){F=0,B=[0,0,0],this.labels[M].length>4&&(N(M),F=1),\"auto\"===(S=[this.labelAlign[M],.5,F])[0]?S[0]=0:S[0]=parseInt(\"\"+S[0]);for(L=0;L<3;++L)q[L]+=k*U[L]*this.labelPad[L]/r[5*L];q[M]+=.5*(a[0][M]+a[1][M]),this._text.drawLabel(M,this.labelSize[M],this.labelAngle[M],q,this.labelColor[M],[0,0,0],B,S)}}this._text.unbind()},f.dispose=function(){this._text.dispose(),this._lines.dispose(),this._background.dispose(),this._lines=null,this._text=null,this._background=null,this.gl=null}},{\"./lib/background.js\":251,\"./lib/cube.js\":252,\"./lib/lines.js\":253,\"./lib/text.js\":255,\"./lib/ticks.js\":256}],251:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=[],r=[],s=0,l=0;l<3;++l)for(var c=(l+1)%3,u=(l+2)%3,f=[0,0,0],h=[0,0,0],p=-1;p<=1;p+=2){r.push(s,s+2,s+1,s+1,s+2,s+3),f[l]=p,h[l]=p;for(var d=-1;d<=1;d+=2){f[c]=d;for(var g=-1;g<=1;g+=2)f[u]=g,e.push(f[0],f[1],f[2],h[0],h[1],h[2]),s+=1}var m=c;c=u,u=m}var v=n(t,new Float32Array(e)),y=n(t,new Uint16Array(r),t.ELEMENT_ARRAY_BUFFER),x=i(t,[{buffer:v,type:t.FLOAT,size:3,offset:0,stride:24},{buffer:v,type:t.FLOAT,size:3,offset:12,stride:24}],y),b=a(t);return b.attributes.position.location=0,b.attributes.normal.location=1,new o(t,v,x,b)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").bg;function o(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n}var s=o.prototype;s.draw=function(t,e,r,n,i,a){for(var o=!1,s=0;s<3;++s)o=o||i[s];if(o){var l=this.gl;l.enable(l.POLYGON_OFFSET_FILL),l.polygonOffset(1,2),this.shader.bind(),this.shader.uniforms={model:t,view:e,projection:r,bounds:n,enable:i,colors:a},this.vao.bind(),this.vao.draw(this.gl.TRIANGLES,36),this.vao.unbind(),l.disable(l.POLYGON_OFFSET_FILL)}},s.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],252:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,a,p){i(s,e,t),i(s,r,s);for(var y=0,x=0;x<2;++x){u[2]=a[x][2];for(var b=0;b<2;++b){u[1]=a[b][1];for(var _=0;_<2;++_)u[0]=a[_][0],h(l[y],u,s),y+=1}}var w=-1;for(x=0;x<8;++x){for(var T=l[x][3],k=0;k<3;++k)c[x][k]=l[x][k]/T;p&&(c[x][2]*=-1),T<0&&(w<0||c[x][2]<c[w][2])&&(w=x)}if(w<0){w=0;for(var M=0;M<3;++M){for(var A=(M+2)%3,S=(M+1)%3,E=-1,C=-1,L=0;L<2;++L){var I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);o(c[z],c[I],c[P],f)<0||(L?E=1:C=1)}if(E<0||C<0)C>E&&(w|=1<<M);else{for(L=0;L<2;++L){I=(z=L<<M)+(L<<A)+(1-L<<S),P=z+(1-L<<A)+(L<<S);var z,O=d([l[z],l[I],l[P],l[z+(1<<A)+(1<<S)]]);L?E=O:C=O}C>E&&(w|=1<<M)}}}var D=7^w,R=-1;for(x=0;x<8;++x)x!==w&&x!==D&&(R<0||c[R][1]>c[x][1])&&(R=x);var F=-1;for(x=0;x<3;++x){if((N=R^1<<x)!==w&&N!==D)F<0&&(F=N),(S=c[N])[0]<c[F][0]&&(F=N)}var B=-1;for(x=0;x<3;++x){var N;if((N=R^1<<x)!==w&&N!==D&&N!==F)B<0&&(B=N),(S=c[N])[0]>c[B][0]&&(B=N)}var j=g;j[0]=j[1]=j[2]=0,j[n.log2(F^R)]=R&F,j[n.log2(R^B)]=R&B;var U=7^B;U===w||U===D?(U=7^F,j[n.log2(B^U)]=U&B):j[n.log2(F^U)]=U&F;var V=m,q=w;for(M=0;M<3;++M)V[M]=q&1<<M?-1:1;return v};var n=t(\"bit-twiddle\"),i=t(\"gl-mat4/multiply\"),a=t(\"split-polygon\"),o=t(\"robust-orientation\"),s=new Array(16),l=new Array(8),c=new Array(8),u=new Array(3),f=[0,0,0];function h(t,e,r){for(var n=0;n<4;++n){t[n]=r[12+n];for(var i=0;i<3;++i)t[n]+=e[i]*r[4*i+n]}}!function(){for(var t=0;t<8;++t)l[t]=[1,1,1,1],c[t]=[1,1,1]}();var p=[[0,0,1,0,0],[0,0,-1,1,0],[0,-1,0,1,0],[0,1,0,1,0],[-1,0,0,1,0],[1,0,0,1,0]];function d(t){for(var e=0;e<p.length;++e)if((t=a.positive(t,p[e])).length<3)return 0;var r=t[0],n=r[0]/r[3],i=r[1]/r[3],o=0;for(e=1;e+1<t.length;++e){var s=t[e],l=t[e+1],c=s[0]/s[3]-n,u=s[1]/s[3]-i,f=l[0]/l[3]-n,h=l[1]/l[3]-i;o+=Math.abs(c*h-u*f)}return o}var g=[1,1,1],m=[0,0,0],v={cubeEdges:g,axis:m}},{\"bit-twiddle\":97,\"gl-mat4/multiply\":295,\"robust-orientation\":548,\"split-polygon\":566}],253:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var o=[],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[0,0,0];o.push(0,0,1,0,1,1,0,0,-1,0,0,-1,0,1,1,0,1,-1);for(var f=0;f<3;++f){for(var h=o.length/3|0,d=0;d<r[f].length;++d){var g=+r[f][d].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}var m=o.length/3|0;s[f]=h,l[f]=m-h;h=o.length/3|0;for(var v=0;v<r[f].length;++v){g=+r[f][v].x;o.push(g,0,1,g,1,1,g,0,-1,g,0,-1,g,1,1,g,1,-1)}m=o.length/3|0;c[f]=h,u[f]=m-h}var y=n(t,new Float32Array(o)),x=i(t,[{buffer:y,type:t.FLOAT,size:3,stride:0,offset:0}]),b=a(t);return b.attributes.position.location=0,new p(t,y,x,b,l,s,u,c)};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders\").line,o=[0,0,0],s=[0,0,0],l=[0,0,0],c=[0,0,0],u=[1,1];function f(t){return t[0]=t[1]=t[2]=0,t}function h(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}function p(t,e,r,n,i,a,o,s){this.gl=t,this.vertBuffer=e,this.vao=r,this.shader=n,this.tickCount=i,this.tickOffset=a,this.gridCount=o,this.gridOffset=s}var d=p.prototype;d.bind=function(t,e,r){this.shader.bind(),this.shader.uniforms.model=t,this.shader.uniforms.view=e,this.shader.uniforms.projection=r,u[0]=this.gl.drawingBufferWidth,u[1]=this.gl.drawingBufferHeight,this.shader.uniforms.screenShape=u,this.vao.bind()},d.unbind=function(){this.vao.unbind()},d.drawAxisLine=function(t,e,r,n,i){var a=f(s);this.shader.uniforms.majorAxis=s,a[t]=e[1][t]-e[0][t],this.shader.uniforms.minorAxis=a;var o,u=h(c,r);u[t]+=e[0][t],this.shader.uniforms.offset=u,this.shader.uniforms.lineWidth=i,this.shader.uniforms.color=n,(o=f(l))[(t+2)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6),(o=f(l))[(t+1)%3]=1,this.shader.uniforms.screenAxis=o,this.vao.draw(this.gl.TRIANGLES,6)},d.drawAxisTicks=function(t,e,r,n,i){if(this.tickCount[t]){var a=f(o);a[t]=1,this.shader.uniforms.majorAxis=a,this.shader.uniforms.offset=e,this.shader.uniforms.minorAxis=r,this.shader.uniforms.color=n,this.shader.uniforms.lineWidth=i;var s=f(l);s[t]=1,this.shader.uniforms.screenAxis=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t])}},d.drawGrid=function(t,e,r,n,i,a){if(this.gridCount[t]){var u=f(s);u[e]=r[1][e]-r[0][e],this.shader.uniforms.minorAxis=u;var p=h(c,n);p[e]+=r[0][e],this.shader.uniforms.offset=p;var d=f(o);d[t]=1,this.shader.uniforms.majorAxis=d;var g=f(l);g[t]=1,this.shader.uniforms.screenAxis=g,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,this.gridCount[t],this.gridOffset[t])}},d.drawZero=function(t,e,r,n,i,a){var o=f(s);this.shader.uniforms.majorAxis=o,o[t]=r[1][t]-r[0][t],this.shader.uniforms.minorAxis=o;var u=h(c,n);u[t]+=r[0][t],this.shader.uniforms.offset=u;var p=f(l);p[e]=1,this.shader.uniforms.screenAxis=p,this.shader.uniforms.lineWidth=a,this.shader.uniforms.color=i,this.vao.draw(this.gl.TRIANGLES,6)},d.dispose=function(){this.vao.dispose(),this.vertBuffer.dispose(),this.shader.dispose()}},{\"./shaders\":254,\"gl-buffer\":259,\"gl-vao\":358}],254:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, majorAxis, minorAxis, screenAxis;\\nuniform float lineWidth;\\nuniform vec2 screenShape;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nvoid main() {\\n  vec3 major = position.x * majorAxis;\\n  vec3 minor = position.y * minorAxis;\\n\\n  vec3 vPosition = major + minor + offset;\\n  vec3 pPosition = project(vPosition);\\n  vec3 offset = project(vPosition + screenAxis * position.z);\\n\\n  vec2 screen = normalize((offset - pPosition).xy * screenShape) / screenShape;\\n\\n  gl_Position = vec4(pPosition + vec3(0.5 * screen * lineWidth, 0), 1.0);\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.line=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"}])};var s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 offset, axis, alignDir, alignOpt;\\nuniform float scale, angle, pixelScale;\\nuniform vec2 resolution;\\n\\nvec3 project(vec3 p) {\\n  vec4 pp = projection * view * model * vec4(p, 1.0);\\n  return pp.xyz / max(pp.w, 0.0001);\\n}\\n\\nfloat computeViewAngle(vec3 a, vec3 b) {\\n  vec3 A = project(a);\\n  vec3 B = project(b);\\n\\n  return atan(\\n    (B.y - A.y) * resolution.y,\\n    (B.x - A.x) * resolution.x\\n  );\\n}\\n\\nconst float PI = 3.141592;\\nconst float TWO_PI = 2.0 * PI;\\nconst float HALF_PI = 0.5 * PI;\\nconst float ONE_AND_HALF_PI = 1.5 * PI;\\n\\nint option = int(floor(alignOpt.x + 0.001));\\nfloat hv_ratio =       alignOpt.y;\\nbool enableAlign =    (alignOpt.z != 0.0);\\n\\nfloat mod_angle(float a) {\\n  return mod(a, PI);\\n}\\n\\nfloat positive_angle(float a) {\\n  return mod_angle((a < 0.0) ?\\n    a + TWO_PI :\\n    a\\n  );\\n}\\n\\nfloat look_upwards(float a) {\\n  float b = positive_angle(a);\\n  return ((b > HALF_PI) && (b <= ONE_AND_HALF_PI)) ?\\n    b - PI :\\n    b;\\n}\\n\\nfloat look_horizontal_or_vertical(float a, float ratio) {\\n  // ratio controls the ratio between being horizontal to (vertical + horizontal)\\n  // if ratio is set to 0.5 then it is 50%, 50%.\\n  // when using a higher ratio e.g. 0.75 the result would\\n  // likely be more horizontal than vertical.\\n\\n  float b = positive_angle(a);\\n\\n  return\\n    (b < (      ratio) * HALF_PI) ? 0.0 :\\n    (b < (2.0 - ratio) * HALF_PI) ? -HALF_PI :\\n    (b < (2.0 + ratio) * HALF_PI) ? 0.0 :\\n    (b < (4.0 - ratio) * HALF_PI) ? HALF_PI :\\n                                    0.0;\\n}\\n\\nfloat roundTo(float a, float b) {\\n  return float(b * floor((a + 0.5 * b) / b));\\n}\\n\\nfloat look_round_n_directions(float a, int n) {\\n  float b = positive_angle(a);\\n  float div = TWO_PI / float(n);\\n  float c = roundTo(b, div);\\n  return look_upwards(c);\\n}\\n\\nfloat applyAlignOption(float rawAngle, float delta) {\\n  return\\n    (option >  2) ? look_round_n_directions(rawAngle + delta, option) :       // option 3-n: round to n directions\\n    (option == 2) ? look_horizontal_or_vertical(rawAngle + delta, hv_ratio) : // horizontal or vertical\\n    (option == 1) ? rawAngle + delta :       // use free angle, and flip to align with one direction of the axis\\n    (option == 0) ? look_upwards(rawAngle) : // use free angle, and stay upwards\\n    (option ==-1) ? 0.0 :                    // useful for backward compatibility, all texts remains horizontal\\n                    rawAngle;                // otherwise return back raw input angle\\n}\\n\\nbool isAxisTitle = (axis.x == 0.0) &&\\n                   (axis.y == 0.0) &&\\n                   (axis.z == 0.0);\\n\\nvoid main() {\\n  //Compute world offset\\n  float axisDistance = position.z;\\n  vec3 dataPosition = axisDistance * axis + offset;\\n\\n  float beta = angle; // i.e. user defined attributes for each tick\\n\\n  float axisAngle;\\n  float clipAngle;\\n  float flip;\\n\\n  if (enableAlign) {\\n    axisAngle = (isAxisTitle) ? HALF_PI :\\n                      computeViewAngle(dataPosition, dataPosition + axis);\\n    clipAngle = computeViewAngle(dataPosition, dataPosition + alignDir);\\n\\n    axisAngle += (sin(axisAngle) < 0.0) ? PI : 0.0;\\n    clipAngle += (sin(clipAngle) < 0.0) ? PI : 0.0;\\n\\n    flip = (dot(vec2(cos(axisAngle), sin(axisAngle)),\\n                vec2(sin(clipAngle),-cos(clipAngle))) > 0.0) ? 1.0 : 0.0;\\n\\n    beta += applyAlignOption(clipAngle, flip * PI);\\n  }\\n\\n  //Compute plane offset\\n  vec2 planeCoord = position.xy * pixelScale;\\n\\n  mat2 planeXform = scale * mat2(\\n     cos(beta), sin(beta),\\n    -sin(beta), cos(beta)\\n  );\\n\\n  vec2 viewOffset = 2.0 * planeXform * planeCoord / resolution;\\n\\n  //Compute clip position\\n  vec3 clipPosition = project(dataPosition);\\n\\n  //Apply text offset in clip coordinates\\n  clipPosition += vec3(viewOffset, 0.0);\\n\\n  //Done\\n  gl_Position = vec4(clipPosition, 1.0);\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = color;\\n}\"]);r.text=function(t){return i(t,s,l,null,[{name:\"position\",type:\"vec3\"}])};var c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec3 normal;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 enable;\\nuniform vec3 bounds[2];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n\\n  vec3 signAxis = sign(bounds[1] - bounds[0]);\\n\\n  vec3 realNormal = signAxis * normal;\\n\\n  if(dot(realNormal, enable) > 0.0) {\\n    vec3 minRange = min(bounds[0], bounds[1]);\\n    vec3 maxRange = max(bounds[0], bounds[1]);\\n    vec3 nPosition = mix(minRange, maxRange, 0.5 * (position + 1.0));\\n    gl_Position = projection * view * model * vec4(nPosition, 1.0);\\n  } else {\\n    gl_Position = vec4(0,0,0,0);\\n  }\\n\\n  colorChannel = abs(realNormal);\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec4 colors[3];\\n\\nvarying vec3 colorChannel;\\n\\nvoid main() {\\n  gl_FragColor = colorChannel.x * colors[0] +\\n                 colorChannel.y * colors[1] +\\n                 colorChannel.z * colors[2];\\n}\"]);r.bg=function(t){return i(t,c,u,null,[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:257}],255:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function(t,e,r,a,s,l){var u=n(t),f=i(t,[{buffer:u,size:3}]),h=o(t);h.attributes.position.location=0;var p=new c(t,h,u,f);return p.update(e,r,a,s,l),p};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"vectorize-text\"),o=t(\"./shaders\").text,s=window||r.global||{},l=s.__TEXT_CACHE||{};s.__TEXT_CACHE={};function c(t,e,r,n){this.gl=t,this.shader=e,this.buffer=r,this.vao=n,this.tickOffset=this.tickCount=this.labelOffset=this.labelCount=null}var u=c.prototype,f=[0,0];u.bind=function(t,e,r,n){this.vao.bind(),this.shader.bind();var i=this.shader.uniforms;i.model=t,i.view=e,i.projection=r,i.pixelScale=n,f[0]=this.gl.drawingBufferWidth,f[1]=this.gl.drawingBufferHeight,this.shader.uniforms.resolution=f},u.unbind=function(){this.vao.unbind()},u.update=function(t,e,r,n,i){var o=[];function s(t,e,r,n,i,s){var c=l[r];c||(c=l[r]={});var u=c[e];u||(u=c[e]=function(t,e){try{return a(t,e)}catch(e){return console.warn('error vectorizing text:\"'+t+'\" error:',e),{cells:[],positions:[]}}}(e,{triangles:!0,font:r,textAlign:\"center\",textBaseline:\"middle\",lineSpacing:i,styletags:s}));for(var f=(n||12)/12,h=u.positions,p=u.cells,d=0,g=p.length;d<g;++d)for(var m=p[d],v=2;v>=0;--v){var y=h[m[v]];o.push(f*y[0],-f*y[1],t)}}for(var c=[0,0,0],u=[0,0,0],f=[0,0,0],h=[0,0,0],p={breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},d=0;d<3;++d){f[d]=o.length/3|0,s(.5*(t[0][d]+t[1][d]),e[d],r[d],12,1.25,p),h[d]=(o.length/3|0)-f[d],c[d]=o.length/3|0;for(var g=0;g<n[d].length;++g)n[d][g].text&&s(n[d][g].x,n[d][g].text,n[d][g].font||i,n[d][g].fontSize||12,1.25,p);u[d]=(o.length/3|0)-c[d]}this.buffer.update(o),this.tickOffset=c,this.tickCount=u,this.labelOffset=f,this.labelCount=h},u.drawTicks=function(t,e,r,n,i,a,o,s){this.tickCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.tickCount[t],this.tickOffset[t]))},u.drawLabel=function(t,e,r,n,i,a,o,s){this.labelCount[t]&&(this.shader.uniforms.axis=a,this.shader.uniforms.color=i,this.shader.uniforms.angle=r,this.shader.uniforms.scale=e,this.shader.uniforms.offset=n,this.shader.uniforms.alignDir=o,this.shader.uniforms.alignOpt=s,this.vao.draw(this.gl.TRIANGLES,this.labelCount[t],this.labelOffset[t]))},u.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()}}).call(this)}).call(this,t(\"_process\"))},{\"./shaders\":254,_process:526,\"gl-buffer\":259,\"gl-vao\":358,\"vectorize-text\":600}],256:[function(t,e,r){\"use strict\";function n(t,e){var r=t+\"\",n=r.indexOf(\".\"),i=0;n>=0&&(i=r.length-n-1);var a=Math.pow(10,i),o=Math.round(t*e*a),s=o+\"\";if(s.indexOf(\"e\")>=0)return s;var l=o/a,c=o%a;o<0?(l=0|-Math.ceil(l),c=0|-c):(l=0|Math.floor(l),c|=0);var u=\"\"+l;if(o<0&&(u=\"-\"+u),i){for(var f=\"\"+c;f.length<i;)f=\"0\"+f;return u+\".\"+f}return u}r.create=function(t,e){for(var r=[],i=0;i<3;++i){for(var a=[],o=(t[0][i],t[1][i],0);o*e[i]<=t[1][i];++o)a.push({x:o*e[i],text:n(e[i],o)});for(o=-1;o*e[i]>=t[0][i];--o)a.push({x:o*e[i],text:n(e[i],o)});r.push(a)}return r},r.equal=function(t,e){for(var r=0;r<3;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;++n){var i=t[r][n],a=e[r][n];if(i.x!==a.x||i.text!==a.text||i.font!==a.font||i.fontColor!==a.fontColor||i.fontSize!==a.fontSize||i.dx!==a.dx||i.dy!==a.dy)return!1}}return!0}},{}],257:[function(t,e,r){e.exports=function(t){\"string\"==typeof t&&(t=[t]);for(var e=[].slice.call(arguments,1),r=[],n=0;n<t.length-1;n++)r.push(t[n],e[n]||\"\");return r.push(t[n]),r.join(\"\")}},{}],258:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,l,f){var h=e.model||c,p=e.view||c,v=e.projection||c,y=e._ortho||!1,x=t.bounds,b=(f=f||a(h,p,v,x,y)).axis;o(u,p,h),o(u,v,u);for(var _=g,w=0;w<3;++w)_[w].lo=1/0,_[w].hi=-1/0,_[w].pixelsPerDataUnit=1/0;var T=n(s(u,u));s(u,u);for(var k=0;k<3;++k){var M=(k+1)%3,A=(k+2)%3,S=m;t:for(w=0;w<2;++w){var E=[];if(b[k]<0!=!!w){S[k]=x[w][k];for(var C=0;C<2;++C){S[M]=x[C^w][M];for(var L=0;L<2;++L)S[A]=x[L^C^w][A],E.push(S.slice())}var I=y?5:4;for(C=I;C===I;++C){if(0===E.length)continue t;E=i.positive(E,T[C])}for(C=0;C<E.length;++C){A=E[C];var P=d(m,u,A,r,l);for(L=0;L<3;++L)_[L].lo=Math.min(_[L].lo,A[L]),_[L].hi=Math.max(_[L].hi,A[L]),L!==k&&(_[L].pixelsPerDataUnit=Math.min(_[L].pixelsPerDataUnit,Math.abs(P[L])))}}}}return _};var n=t(\"extract-frustum-planes\"),i=t(\"split-polygon\"),a=t(\"./lib/cube.js\"),o=t(\"gl-mat4/multiply\"),s=t(\"gl-mat4/transpose\"),l=t(\"gl-vec4/transformMat4\"),c=new Float32Array([1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]),u=new Float32Array(16);function f(t,e,r){this.lo=t,this.hi=e,this.pixelsPerDataUnit=r}var h=[0,0,0,1],p=[0,0,0,1];function d(t,e,r,n,i){for(var a=0;a<3;++a){for(var o=h,s=p,c=0;c<3;++c)s[c]=o[c]=r[c];s[3]=o[3]=1,s[a]+=1,l(s,s,e),s[3]<0&&(t[a]=1/0),o[a]-=1,l(o,o,e),o[3]<0&&(t[a]=1/0);var u=(o[0]/o[3]-s[0]/s[3])*n,f=(o[1]/o[3]-s[1]/s[3])*i;t[a]=.25*Math.sqrt(u*u+f*f)}return t}var g=[new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0),new f(1/0,-1/0,1/0)],m=[0,0,0]},{\"./lib/cube.js\":252,\"extract-frustum-planes\":240,\"gl-mat4/multiply\":295,\"gl-mat4/transpose\":306,\"gl-vec4/transformMat4\":429,\"split-polygon\":566}],259:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"ndarray-ops\"),a=t(\"ndarray\"),o=[\"uint8\",\"uint8_clamped\",\"uint16\",\"uint32\",\"int8\",\"int16\",\"int32\",\"float32\"];function s(t,e,r,n,i){this.gl=t,this.type=e,this.handle=r,this.length=n,this.usage=i}var l=s.prototype;function c(t,e,r,n,i,a){var o=i.length*i.BYTES_PER_ELEMENT;if(a<0)return t.bufferData(e,i,n),o;if(o+a>r)throw new Error(\"gl-buffer: If resizing buffer, must not specify offset\");return t.bufferSubData(e,a,i),r}function u(t,e){for(var r=n.malloc(t.length,e),i=t.length,a=0;a<i;++a)r[a]=t[a];return r}l.bind=function(){this.gl.bindBuffer(this.type,this.handle)},l.unbind=function(){this.gl.bindBuffer(this.type,null)},l.dispose=function(){this.gl.deleteBuffer(this.handle)},l.update=function(t,e){if(\"number\"!=typeof e&&(e=-1),this.bind(),\"object\"==typeof t&&\"undefined\"!=typeof t.shape){var r=t.dtype;if(o.indexOf(r)<0&&(r=\"float32\"),this.type===this.gl.ELEMENT_ARRAY_BUFFER)r=gl.getExtension(\"OES_element_index_uint\")&&\"uint16\"!==r?\"uint32\":\"uint16\";if(r===t.dtype&&function(t,e){for(var r=1,n=e.length-1;n>=0;--n){if(e[n]!==r)return!1;r*=t[n]}return!0}(t.shape,t.stride))0===t.offset&&t.data.length===t.shape[0]?this.length=c(this.gl,this.type,this.length,this.usage,t.data,e):this.length=c(this.gl,this.type,this.length,this.usage,t.data.subarray(t.offset,t.shape[0]),e);else{var s=n.malloc(t.size,r),l=a(s,t.shape);i.assign(l,t),this.length=c(this.gl,this.type,this.length,this.usage,e<0?s:s.subarray(0,t.size),e),n.free(s)}}else if(Array.isArray(t)){var f;f=this.type===this.gl.ELEMENT_ARRAY_BUFFER?u(t,\"uint16\"):u(t,\"float32\"),this.length=c(this.gl,this.type,this.length,this.usage,e<0?f:f.subarray(0,t.length),e),n.free(f)}else if(\"object\"==typeof t&&\"number\"==typeof t.length)this.length=c(this.gl,this.type,this.length,this.usage,t,e);else{if(\"number\"!=typeof t&&void 0!==t)throw new Error(\"gl-buffer: Invalid data type\");if(e>=0)throw new Error(\"gl-buffer: Cannot specify offset when resizing buffer\");(t|=0)<=0&&(t=1),this.gl.bufferData(this.type,0|t,this.usage),this.length=t}},e.exports=function(t,e,r,n){if(r=r||t.ARRAY_BUFFER,n=n||t.DYNAMIC_DRAW,r!==t.ARRAY_BUFFER&&r!==t.ELEMENT_ARRAY_BUFFER)throw new Error(\"gl-buffer: Invalid type for webgl buffer, must be either gl.ARRAY_BUFFER or gl.ELEMENT_ARRAY_BUFFER\");if(n!==t.DYNAMIC_DRAW&&n!==t.STATIC_DRAW&&n!==t.STREAM_DRAW)throw new Error(\"gl-buffer: Invalid usage for buffer, must be either gl.DYNAMIC_DRAW, gl.STATIC_DRAW or gl.STREAM_DRAW\");var i=t.createBuffer(),a=new s(t,r,i,0,n);return a.update(e),a}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],260:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\");e.exports=function(t,e){var r=t.positions,i=t.vectors,a={positions:[],vertexIntensity:[],vertexIntensityBounds:t.vertexIntensityBounds,vectors:[],cells:[],coneOffset:t.coneOffset,colormap:t.colormap};if(0===t.positions.length)return e&&(e[0]=[0,0,0],e[1]=[0,0,0]),a;for(var o=0,s=1/0,l=-1/0,c=1/0,u=-1/0,f=1/0,h=-1/0,p=null,d=null,g=[],m=1/0,v=!1,y=0;y<r.length;y++){var x=r[y];s=Math.min(x[0],s),l=Math.max(x[0],l),c=Math.min(x[1],c),u=Math.max(x[1],u),f=Math.min(x[2],f),h=Math.max(x[2],h);var b=i[y];if(n.length(b)>o&&(o=n.length(b)),y){var _=2*n.distance(p,x)/(n.length(d)+n.length(b));_?(m=Math.min(m,_),v=!1):v=!0}v||(p=x,d=b),g.push(b)}var w=[s,c,f],T=[l,u,h];e&&(e[0]=w,e[1]=T),0===o&&(o=1);var k=1/o;isFinite(m)||(m=1),a.vectorScale=m;var M=t.coneSize||.5;t.absoluteConeSize&&(M=t.absoluteConeSize*k),a.coneScale=M;y=0;for(var A=0;y<r.length;y++)for(var S=(x=r[y])[0],E=x[1],C=x[2],L=g[y],I=n.length(L)*k,P=0;P<8;P++){a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.positions.push([S,E,C,A++]),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vectors.push(L),a.vertexIntensity.push(I,I,I),a.vertexIntensity.push(I,I,I);var z=a.positions.length;a.cells.push([z-6,z-5,z-4],[z-3,z-2,z-1])}return a};var i=t(\"./lib/shaders\");e.exports.createMesh=t(\"./create_mesh\"),e.exports.createConeMesh=function(t,r){return e.exports.createMesh(t,r,{shaders:i,traceType:\"cone\"})}},{\"./create_mesh\":261,\"./lib/shaders\":262,\"gl-vec3\":377}],261:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"gl-mat4/multiply\"),l=t(\"gl-mat4/invert\"),c=t(\"ndarray\"),u=t(\"colormap\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e,r,n,i,a,o,s,l,c,u){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.pickShader=n,this.trianglePositions=i,this.triangleVectors=a,this.triangleColors=s,this.triangleUVs=l,this.triangleIds=o,this.triangleVAO=c,this.triangleCount=0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.traceType=u,this.tubeScale=1,this.coneScale=2,this.vectorScale=1,this.coneOffset=.25,this._model=f,this._view=f,this._projection=f,this._resolution=[1,1]}var p=h.prototype;function d(t,e){var r=n(t,e.meshShader.vertex,e.meshShader.fragment,null,e.meshShader.attributes);return r.attributes.position.location=0,r.attributes.color.location=2,r.attributes.uv.location=3,r.attributes.vector.location=4,r}function g(t,e){var r=n(t,e.pickShader.vertex,e.pickShader.fragment,null,e.pickShader.attributes);return r.attributes.position.location=0,r.attributes.id.location=1,r.attributes.vector.location=4,r}p.isOpaque=function(){return this.opacity>=1},p.isTransparent=function(){return this.opacity<1},p.pickSlots=1,p.setPickBase=function(t){this.pickId=t},p.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),\"opacity\"in t&&(this.opacity=t.opacity),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),void 0!==t.tubeScale&&(this.tubeScale=t.tubeScale),void 0!==t.vectorScale&&(this.vectorScale=t.vectorScale),void 0!==t.coneScale&&(this.coneScale=t.coneScale),void 0!==t.coneOffset&&(this.coneOffset=t.coneOffset),t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t){for(var e=u({colormap:t,nshades:256,format:\"rgba\"}),r=new Uint8Array(1024),n=0;n<256;++n){for(var i=e[n],a=0;a<3;++a)r[4*n+a]=i[a];r[4*n+3]=255*i[3]}return c(r,[256,256,4],[4,0,1])}(t.colormap)),this.texture.generateMipmap());var r=t.cells,n=t.positions,i=t.vectors;if(n&&r&&i){var a=[],o=[],s=[],l=[],f=[];this.cells=r,this.positions=n,this.vectors=i;var h=t.meshColor||[1,1,1,1],p=t.vertexIntensity,d=1/0,g=-1/0;if(p)if(t.vertexIntensityBounds)d=+t.vertexIntensityBounds[0],g=+t.vertexIntensityBounds[1];else for(var m=0;m<p.length;++m){var v=p[m];d=Math.min(d,v),g=Math.max(g,v)}else for(m=0;m<n.length;++m){v=n[m][2];d=Math.min(d,v),g=Math.max(g,v)}this.intensity=p||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n),this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(m=0;m<n.length;++m)for(var y=n[m],x=0;x<3;++x)!isNaN(y[x])&&isFinite(y[x])&&(this.bounds[0][x]=Math.min(this.bounds[0][x],y[x]),this.bounds[1][x]=Math.max(this.bounds[1][x],y[x]));var b=0;t:for(m=0;m<r.length;++m){var _=r[m];switch(_.length){case 3:for(x=0;x<3;++x){y=n[T=_[x]];for(var w=0;w<3;++w)if(isNaN(y[w])||!isFinite(y[w]))continue t}for(x=0;x<3;++x){var T;y=n[T=_[2-x]];a.push(y[0],y[1],y[2],y[3]);var k=i[T];o.push(k[0],k[1],k[2],k[3]||0);var M,A=h;3===A.length?s.push(A[0],A[1],A[2],1):s.push(A[0],A[1],A[2],A[3]),M=p?[(p[T]-d)/(g-d),0]:[(y[2]-d)/(g-d),0],l.push(M[0],M[1]),f.push(m)}b+=1}}this.triangleCount=b,this.trianglePositions.update(a),this.triangleVectors.update(o),this.triangleColors.update(s),this.triangleUVs.update(l),this.triangleIds.update(new Uint32Array(f))}},p.drawTransparent=p.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var c={model:r,view:n,projection:i,inverseModel:f.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],opacity:this.opacity,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,texture:0};c.inverseModel=l(c.inverseModel,c.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);s(u,c.view,c.model),s(u,c.projection,u),l(u,u);for(o=0;o<3;++o)c.eyePosition[o]=u[12+o]/u[15];var h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];c.lightPosition[o]=p/h}if(this.triangleCount>0){var g=this.triShader;g.bind(),g.uniforms=c,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()}},p.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||f,n=t.view||f,i=t.projection||f,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s={model:r,view:n,projection:i,clipBounds:a,tubeScale:this.tubeScale,vectorScale:this.vectorScale,coneScale:this.coneScale,coneOffset:this.coneOffset,pickId:this.pickId/255},l=this.pickShader;l.bind(),l.uniforms=s,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind())},p.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions[r[1]].slice(0,3),i={position:n,dataCoordinate:n,index:Math.floor(r[1]/48)};return\"cone\"===this.traceType?i.index=Math.floor(r[1]/48):\"streamtube\"===this.traceType&&(i.intensity=this.intensity[r[1]],i.velocity=this.vectors[r[1]].slice(0,3),i.divergence=this.vectors[r[1]][3],i.index=e),i},p.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.pickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleVectors.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleIds.dispose()},e.exports=function(t,e,r){var n=r.shaders;1===arguments.length&&(t=(e=t).gl);var s=d(t,n),l=g(t,n),u=o(t,c(new Uint8Array([255,255,255,255]),[1,1,4]));u.generateMipmap(),u.minFilter=t.LINEAR_MIPMAP_LINEAR,u.magFilter=t.LINEAR;var f=i(t),p=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:f,type:t.FLOAT,size:4},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:m,type:t.FLOAT,size:4},{buffer:v,type:t.FLOAT,size:2},{buffer:p,type:t.FLOAT,size:4}]),b=new h(t,u,s,l,f,p,y,m,v,x,r.traceType||\"cone\");return b.update(e),b}},{colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],262:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec3 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, coneScale, coneOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * conePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(conePosition, 1.0);\\n  vec4 t_position  = view * conePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = conePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the cone vertex and normal at the given index.\\n//\\n// The returned vertex is for a cone with its top at origin and height of 1.0,\\n// pointing in the direction of the vector attribute.\\n//\\n// Each cone is made up of a top vertex, a center base vertex and base perimeter vertices.\\n// These vertices are used to make up the triangles of the cone by the following:\\n//   segment + 0 top vertex\\n//   segment + 1 perimeter vertex a+1\\n//   segment + 2 perimeter vertex a\\n//   segment + 3 center base vertex\\n//   segment + 4 perimeter vertex a\\n//   segment + 5 perimeter vertex a+1\\n// Where segment is the number of the radial segment * 6 and a is the angle at that radial segment.\\n// To go from index to segment, floor(index / 6)\\n// To go from segment to angle, 2*pi * (segment/segmentCount)\\n// To go from index to segment index, index - (segment*6)\\n//\\nvec3 getConePosition(vec3 d, float rawIndex, float coneOffset, out vec3 normal) {\\n\\n  const float segmentCount = 8.0;\\n\\n  float index = rawIndex - floor(rawIndex /\\n    (segmentCount * 6.0)) *\\n    (segmentCount * 6.0);\\n\\n  float segment = floor(0.001 + index/6.0);\\n  float segmentIndex = index - (segment*6.0);\\n\\n  normal = -normalize(d);\\n\\n  if (segmentIndex > 2.99 && segmentIndex < 3.01) {\\n    return mix(vec3(0.0), -d, coneOffset);\\n  }\\n\\n  float nextAngle = (\\n    (segmentIndex > 0.99 &&  segmentIndex < 1.01) ||\\n    (segmentIndex > 4.99 &&  segmentIndex < 5.01)\\n  ) ? 1.0 : 0.0;\\n  float angle = 2.0 * 3.14159 * ((segment + nextAngle) / segmentCount);\\n\\n  vec3 v1 = mix(d, vec3(0.0), coneOffset);\\n  vec3 v2 = v1 - d;\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d)*0.25;\\n  vec3 y = v * sin(angle) * length(d)*0.25;\\n  vec3 v3 = v2 + x + y;\\n  if (segmentIndex < 3.0) {\\n    vec3 tx = u * sin(angle);\\n    vec3 ty = v * -cos(angle);\\n    vec3 tangent = tx + ty;\\n    normal = normalize(cross(v3 - v1, tangent));\\n  }\\n\\n  if (segmentIndex == 0.0) {\\n    return mix(d, vec3(0.0), coneOffset);\\n  }\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float vectorScale, coneScale, coneOffset;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getConePosition(mat3(model) * ((vectorScale * coneScale) * vector.xyz), position.w, coneOffset, normal);\\n  vec4 conePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n  gl_Position = projection * view * conePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec3\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec3\"}]}},{glslify:263}],263:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],264:[function(t,e,r){e.exports={0:\"NONE\",1:\"ONE\",2:\"LINE_LOOP\",3:\"LINE_STRIP\",4:\"TRIANGLES\",5:\"TRIANGLE_STRIP\",6:\"TRIANGLE_FAN\",256:\"DEPTH_BUFFER_BIT\",512:\"NEVER\",513:\"LESS\",514:\"EQUAL\",515:\"LEQUAL\",516:\"GREATER\",517:\"NOTEQUAL\",518:\"GEQUAL\",519:\"ALWAYS\",768:\"SRC_COLOR\",769:\"ONE_MINUS_SRC_COLOR\",770:\"SRC_ALPHA\",771:\"ONE_MINUS_SRC_ALPHA\",772:\"DST_ALPHA\",773:\"ONE_MINUS_DST_ALPHA\",774:\"DST_COLOR\",775:\"ONE_MINUS_DST_COLOR\",776:\"SRC_ALPHA_SATURATE\",1024:\"STENCIL_BUFFER_BIT\",1028:\"FRONT\",1029:\"BACK\",1032:\"FRONT_AND_BACK\",1280:\"INVALID_ENUM\",1281:\"INVALID_VALUE\",1282:\"INVALID_OPERATION\",1285:\"OUT_OF_MEMORY\",1286:\"INVALID_FRAMEBUFFER_OPERATION\",2304:\"CW\",2305:\"CCW\",2849:\"LINE_WIDTH\",2884:\"CULL_FACE\",2885:\"CULL_FACE_MODE\",2886:\"FRONT_FACE\",2928:\"DEPTH_RANGE\",2929:\"DEPTH_TEST\",2930:\"DEPTH_WRITEMASK\",2931:\"DEPTH_CLEAR_VALUE\",2932:\"DEPTH_FUNC\",2960:\"STENCIL_TEST\",2961:\"STENCIL_CLEAR_VALUE\",2962:\"STENCIL_FUNC\",2963:\"STENCIL_VALUE_MASK\",2964:\"STENCIL_FAIL\",2965:\"STENCIL_PASS_DEPTH_FAIL\",2966:\"STENCIL_PASS_DEPTH_PASS\",2967:\"STENCIL_REF\",2968:\"STENCIL_WRITEMASK\",2978:\"VIEWPORT\",3024:\"DITHER\",3042:\"BLEND\",3088:\"SCISSOR_BOX\",3089:\"SCISSOR_TEST\",3106:\"COLOR_CLEAR_VALUE\",3107:\"COLOR_WRITEMASK\",3317:\"UNPACK_ALIGNMENT\",3333:\"PACK_ALIGNMENT\",3379:\"MAX_TEXTURE_SIZE\",3386:\"MAX_VIEWPORT_DIMS\",3408:\"SUBPIXEL_BITS\",3410:\"RED_BITS\",3411:\"GREEN_BITS\",3412:\"BLUE_BITS\",3413:\"ALPHA_BITS\",3414:\"DEPTH_BITS\",3415:\"STENCIL_BITS\",3553:\"TEXTURE_2D\",4352:\"DONT_CARE\",4353:\"FASTEST\",4354:\"NICEST\",5120:\"BYTE\",5121:\"UNSIGNED_BYTE\",5122:\"SHORT\",5123:\"UNSIGNED_SHORT\",5124:\"INT\",5125:\"UNSIGNED_INT\",5126:\"FLOAT\",5386:\"INVERT\",5890:\"TEXTURE\",6401:\"STENCIL_INDEX\",6402:\"DEPTH_COMPONENT\",6406:\"ALPHA\",6407:\"RGB\",6408:\"RGBA\",6409:\"LUMINANCE\",6410:\"LUMINANCE_ALPHA\",7680:\"KEEP\",7681:\"REPLACE\",7682:\"INCR\",7683:\"DECR\",7936:\"VENDOR\",7937:\"RENDERER\",7938:\"VERSION\",9728:\"NEAREST\",9729:\"LINEAR\",9984:\"NEAREST_MIPMAP_NEAREST\",9985:\"LINEAR_MIPMAP_NEAREST\",9986:\"NEAREST_MIPMAP_LINEAR\",9987:\"LINEAR_MIPMAP_LINEAR\",10240:\"TEXTURE_MAG_FILTER\",10241:\"TEXTURE_MIN_FILTER\",10242:\"TEXTURE_WRAP_S\",10243:\"TEXTURE_WRAP_T\",10497:\"REPEAT\",10752:\"POLYGON_OFFSET_UNITS\",16384:\"COLOR_BUFFER_BIT\",32769:\"CONSTANT_COLOR\",32770:\"ONE_MINUS_CONSTANT_COLOR\",32771:\"CONSTANT_ALPHA\",32772:\"ONE_MINUS_CONSTANT_ALPHA\",32773:\"BLEND_COLOR\",32774:\"FUNC_ADD\",32777:\"BLEND_EQUATION_RGB\",32778:\"FUNC_SUBTRACT\",32779:\"FUNC_REVERSE_SUBTRACT\",32819:\"UNSIGNED_SHORT_4_4_4_4\",32820:\"UNSIGNED_SHORT_5_5_5_1\",32823:\"POLYGON_OFFSET_FILL\",32824:\"POLYGON_OFFSET_FACTOR\",32854:\"RGBA4\",32855:\"RGB5_A1\",32873:\"TEXTURE_BINDING_2D\",32926:\"SAMPLE_ALPHA_TO_COVERAGE\",32928:\"SAMPLE_COVERAGE\",32936:\"SAMPLE_BUFFERS\",32937:\"SAMPLES\",32938:\"SAMPLE_COVERAGE_VALUE\",32939:\"SAMPLE_COVERAGE_INVERT\",32968:\"BLEND_DST_RGB\",32969:\"BLEND_SRC_RGB\",32970:\"BLEND_DST_ALPHA\",32971:\"BLEND_SRC_ALPHA\",33071:\"CLAMP_TO_EDGE\",33170:\"GENERATE_MIPMAP_HINT\",33189:\"DEPTH_COMPONENT16\",33306:\"DEPTH_STENCIL_ATTACHMENT\",33635:\"UNSIGNED_SHORT_5_6_5\",33648:\"MIRRORED_REPEAT\",33901:\"ALIASED_POINT_SIZE_RANGE\",33902:\"ALIASED_LINE_WIDTH_RANGE\",33984:\"TEXTURE0\",33985:\"TEXTURE1\",33986:\"TEXTURE2\",33987:\"TEXTURE3\",33988:\"TEXTURE4\",33989:\"TEXTURE5\",33990:\"TEXTURE6\",33991:\"TEXTURE7\",33992:\"TEXTURE8\",33993:\"TEXTURE9\",33994:\"TEXTURE10\",33995:\"TEXTURE11\",33996:\"TEXTURE12\",33997:\"TEXTURE13\",33998:\"TEXTURE14\",33999:\"TEXTURE15\",34e3:\"TEXTURE16\",34001:\"TEXTURE17\",34002:\"TEXTURE18\",34003:\"TEXTURE19\",34004:\"TEXTURE20\",34005:\"TEXTURE21\",34006:\"TEXTURE22\",34007:\"TEXTURE23\",34008:\"TEXTURE24\",34009:\"TEXTURE25\",34010:\"TEXTURE26\",34011:\"TEXTURE27\",34012:\"TEXTURE28\",34013:\"TEXTURE29\",34014:\"TEXTURE30\",34015:\"TEXTURE31\",34016:\"ACTIVE_TEXTURE\",34024:\"MAX_RENDERBUFFER_SIZE\",34041:\"DEPTH_STENCIL\",34055:\"INCR_WRAP\",34056:\"DECR_WRAP\",34067:\"TEXTURE_CUBE_MAP\",34068:\"TEXTURE_BINDING_CUBE_MAP\",34069:\"TEXTURE_CUBE_MAP_POSITIVE_X\",34070:\"TEXTURE_CUBE_MAP_NEGATIVE_X\",34071:\"TEXTURE_CUBE_MAP_POSITIVE_Y\",34072:\"TEXTURE_CUBE_MAP_NEGATIVE_Y\",34073:\"TEXTURE_CUBE_MAP_POSITIVE_Z\",34074:\"TEXTURE_CUBE_MAP_NEGATIVE_Z\",34076:\"MAX_CUBE_MAP_TEXTURE_SIZE\",34338:\"VERTEX_ATTRIB_ARRAY_ENABLED\",34339:\"VERTEX_ATTRIB_ARRAY_SIZE\",34340:\"VERTEX_ATTRIB_ARRAY_STRIDE\",34341:\"VERTEX_ATTRIB_ARRAY_TYPE\",34342:\"CURRENT_VERTEX_ATTRIB\",34373:\"VERTEX_ATTRIB_ARRAY_POINTER\",34466:\"NUM_COMPRESSED_TEXTURE_FORMATS\",34467:\"COMPRESSED_TEXTURE_FORMATS\",34660:\"BUFFER_SIZE\",34661:\"BUFFER_USAGE\",34816:\"STENCIL_BACK_FUNC\",34817:\"STENCIL_BACK_FAIL\",34818:\"STENCIL_BACK_PASS_DEPTH_FAIL\",34819:\"STENCIL_BACK_PASS_DEPTH_PASS\",34877:\"BLEND_EQUATION_ALPHA\",34921:\"MAX_VERTEX_ATTRIBS\",34922:\"VERTEX_ATTRIB_ARRAY_NORMALIZED\",34930:\"MAX_TEXTURE_IMAGE_UNITS\",34962:\"ARRAY_BUFFER\",34963:\"ELEMENT_ARRAY_BUFFER\",34964:\"ARRAY_BUFFER_BINDING\",34965:\"ELEMENT_ARRAY_BUFFER_BINDING\",34975:\"VERTEX_ATTRIB_ARRAY_BUFFER_BINDING\",35040:\"STREAM_DRAW\",35044:\"STATIC_DRAW\",35048:\"DYNAMIC_DRAW\",35632:\"FRAGMENT_SHADER\",35633:\"VERTEX_SHADER\",35660:\"MAX_VERTEX_TEXTURE_IMAGE_UNITS\",35661:\"MAX_COMBINED_TEXTURE_IMAGE_UNITS\",35663:\"SHADER_TYPE\",35664:\"FLOAT_VEC2\",35665:\"FLOAT_VEC3\",35666:\"FLOAT_VEC4\",35667:\"INT_VEC2\",35668:\"INT_VEC3\",35669:\"INT_VEC4\",35670:\"BOOL\",35671:\"BOOL_VEC2\",35672:\"BOOL_VEC3\",35673:\"BOOL_VEC4\",35674:\"FLOAT_MAT2\",35675:\"FLOAT_MAT3\",35676:\"FLOAT_MAT4\",35678:\"SAMPLER_2D\",35680:\"SAMPLER_CUBE\",35712:\"DELETE_STATUS\",35713:\"COMPILE_STATUS\",35714:\"LINK_STATUS\",35715:\"VALIDATE_STATUS\",35716:\"INFO_LOG_LENGTH\",35717:\"ATTACHED_SHADERS\",35718:\"ACTIVE_UNIFORMS\",35719:\"ACTIVE_UNIFORM_MAX_LENGTH\",35720:\"SHADER_SOURCE_LENGTH\",35721:\"ACTIVE_ATTRIBUTES\",35722:\"ACTIVE_ATTRIBUTE_MAX_LENGTH\",35724:\"SHADING_LANGUAGE_VERSION\",35725:\"CURRENT_PROGRAM\",36003:\"STENCIL_BACK_REF\",36004:\"STENCIL_BACK_VALUE_MASK\",36005:\"STENCIL_BACK_WRITEMASK\",36006:\"FRAMEBUFFER_BINDING\",36007:\"RENDERBUFFER_BINDING\",36048:\"FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE\",36049:\"FRAMEBUFFER_ATTACHMENT_OBJECT_NAME\",36050:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL\",36051:\"FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE\",36053:\"FRAMEBUFFER_COMPLETE\",36054:\"FRAMEBUFFER_INCOMPLETE_ATTACHMENT\",36055:\"FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT\",36057:\"FRAMEBUFFER_INCOMPLETE_DIMENSIONS\",36061:\"FRAMEBUFFER_UNSUPPORTED\",36064:\"COLOR_ATTACHMENT0\",36096:\"DEPTH_ATTACHMENT\",36128:\"STENCIL_ATTACHMENT\",36160:\"FRAMEBUFFER\",36161:\"RENDERBUFFER\",36162:\"RENDERBUFFER_WIDTH\",36163:\"RENDERBUFFER_HEIGHT\",36164:\"RENDERBUFFER_INTERNAL_FORMAT\",36168:\"STENCIL_INDEX8\",36176:\"RENDERBUFFER_RED_SIZE\",36177:\"RENDERBUFFER_GREEN_SIZE\",36178:\"RENDERBUFFER_BLUE_SIZE\",36179:\"RENDERBUFFER_ALPHA_SIZE\",36180:\"RENDERBUFFER_DEPTH_SIZE\",36181:\"RENDERBUFFER_STENCIL_SIZE\",36194:\"RGB565\",36336:\"LOW_FLOAT\",36337:\"MEDIUM_FLOAT\",36338:\"HIGH_FLOAT\",36339:\"LOW_INT\",36340:\"MEDIUM_INT\",36341:\"HIGH_INT\",36346:\"SHADER_COMPILER\",36347:\"MAX_VERTEX_UNIFORM_VECTORS\",36348:\"MAX_VARYING_VECTORS\",36349:\"MAX_FRAGMENT_UNIFORM_VECTORS\",37440:\"UNPACK_FLIP_Y_WEBGL\",37441:\"UNPACK_PREMULTIPLY_ALPHA_WEBGL\",37442:\"CONTEXT_LOST_WEBGL\",37443:\"UNPACK_COLORSPACE_CONVERSION_WEBGL\",37444:\"BROWSER_DEFAULT_WEBGL\"}},{}],265:[function(t,e,r){var n=t(\"./1.0/numbers\");e.exports=function(t){return n[t]}},{\"./1.0/numbers\":264}],266:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),o=i(e,[{buffer:r,type:e.FLOAT,size:3,offset:0,stride:40},{buffer:r,type:e.FLOAT,size:4,offset:12,stride:40},{buffer:r,type:e.FLOAT,size:3,offset:28,stride:40}]),l=a(e);l.attributes.position.location=0,l.attributes.color.location=1,l.attributes.offset.location=2;var c=new s(e,r,o,l);return c.update(t),c};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\"),o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.shader=n,this.buffer=e,this.vao=r,this.pixelRatio=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lineWidth=[1,1,1],this.capSize=[10,10,10],this.lineCount=[0,0,0],this.lineOffset=[0,0,0],this.opacity=1,this.hasAlpha=!1}var l=s.prototype;function c(t,e){for(var r=0;r<3;++r)t[0][r]=Math.min(t[0][r],e[r]),t[1][r]=Math.max(t[1][r],e[r])}l.isOpaque=function(){return!this.hasAlpha},l.isTransparent=function(){return this.hasAlpha},l.drawTransparent=l.draw=function(t){var e=this.gl,r=this.shader.uniforms;this.shader.bind();var n=r.view=t.view||o,i=r.projection=t.projection||o;r.model=t.model||o,r.clipBounds=this.clipBounds,r.opacity=this.opacity;var a=n[12],s=n[13],l=n[14],c=n[15],u=(t._ortho||!1?2:1)*this.pixelRatio*(i[3]*a+i[7]*s+i[11]*l+i[15]*c)/e.drawingBufferHeight;this.vao.bind();for(var f=0;f<3;++f)e.lineWidth(this.lineWidth[f]*this.pixelRatio),r.capSize=this.capSize[f]*u,this.lineCount[f]&&e.drawArrays(e.LINES,this.lineOffset[f],this.lineCount[f]);this.vao.unbind()};var u=function(){for(var t=new Array(3),e=0;e<3;++e){for(var r=[],n=1;n<=2;++n)for(var i=-1;i<=1;i+=2){var a=[0,0,0];a[(n+e)%3]=i,r.push(a)}t[e]=r}return t}();function f(t,e,r,n){for(var i=u[n],a=0;a<i.length;++a){var o=i[a];t.push(e[0],e[1],e[2],r[0],r[1],r[2],r[3],o[0],o[1],o[2])}return i.length}l.update=function(t){\"lineWidth\"in(t=t||{})&&(this.lineWidth=t.lineWidth,Array.isArray(this.lineWidth)||(this.lineWidth=[this.lineWidth,this.lineWidth,this.lineWidth])),\"capSize\"in t&&(this.capSize=t.capSize,Array.isArray(this.capSize)||(this.capSize=[this.capSize,this.capSize,this.capSize])),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var e=t.color||[[0,0,0],[0,0,0],[0,0,0]],r=t.position,n=t.error;if(Array.isArray(e[0])||(e=[e,e,e]),r&&n){var i=[],a=r.length,o=0;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.lineCount=[0,0,0];for(var s=0;s<3;++s){this.lineOffset[s]=o;t:for(var l=0;l<a;++l){for(var u=r[l],h=0;h<3;++h)if(isNaN(u[h])||!isFinite(u[h]))continue t;var p=n[l],d=e[s];if(Array.isArray(d[0])&&(d=e[l]),3===d.length?d=[d[0],d[1],d[2],1]:4===d.length&&(d=[d[0],d[1],d[2],d[3]],!this.hasAlpha&&d[3]<1&&(this.hasAlpha=!0)),!isNaN(p[0][s])&&!isNaN(p[1][s])){var g;if(p[0][s]<0)(g=u.slice())[s]+=p[0][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s);if(p[1][s]>0)(g=u.slice())[s]+=p[1][s],i.push(u[0],u[1],u[2],d[0],d[1],d[2],d[3],0,0,0,g[0],g[1],g[2],d[0],d[1],d[2],d[3],0,0,0),c(this.bounds,g),o+=2+f(i,g,d,s)}}this.lineCount[s]=o-this.lineOffset[s]}this.buffer.update(i)}},l.dispose=function(){this.shader.dispose(),this.buffer.dispose(),this.vao.dispose()}},{\"./shaders/index\":268,\"gl-buffer\":259,\"gl-vao\":358}],267:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],268:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, offset;\\nattribute vec4 color;\\nuniform mat4 model, view, projection;\\nuniform float capSize;\\nvarying vec4 fragColor;\\nvarying vec3 fragPosition;\\n\\nvoid main() {\\n  vec4 worldPosition  = model * vec4(position, 1.0);\\n  worldPosition       = (worldPosition / worldPosition.w) + vec4(capSize * offset, 0.0);\\n  gl_Position         = projection * view * worldPosition;\\n  fragColor           = color;\\n  fragPosition        = position;\\n}\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float opacity;\\nvarying vec3 fragPosition;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], fragPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  gl_FragColor = opacity * fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"offset\",type:\"vec3\"}])}},{\"gl-shader\":335,glslify:267}],269:[function(t,e,r){\"use strict\";var n=t(\"gl-texture2d\");e.exports=function(t,e,r,n){i||(i=t.FRAMEBUFFER_UNSUPPORTED,a=t.FRAMEBUFFER_INCOMPLETE_ATTACHMENT,o=t.FRAMEBUFFER_INCOMPLETE_DIMENSIONS,s=t.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT);var c=t.getExtension(\"WEBGL_draw_buffers\");!l&&c&&function(t,e){var r=t.getParameter(e.MAX_COLOR_ATTACHMENTS_WEBGL);l=new Array(r+1);for(var n=0;n<=r;++n){for(var i=new Array(r),a=0;a<n;++a)i[a]=t.COLOR_ATTACHMENT0+a;for(a=n;a<r;++a)i[a]=t.NONE;l[n]=i}}(t,c);Array.isArray(e)&&(n=r,r=0|e[1],e=0|e[0]);if(\"number\"!=typeof e)throw new Error(\"gl-fbo: Missing shape parameter\");var u=t.getParameter(t.MAX_RENDERBUFFER_SIZE);if(e<0||e>u||r<0||r>u)throw new Error(\"gl-fbo: Parameters are too large for FBO\");var f=1;if(\"color\"in(n=n||{})){if((f=Math.max(0|n.color,0))<0)throw new Error(\"gl-fbo: Must specify a nonnegative number of colors\");if(f>1){if(!c)throw new Error(\"gl-fbo: Multiple draw buffer extension not supported\");if(f>t.getParameter(c.MAX_COLOR_ATTACHMENTS_WEBGL))throw new Error(\"gl-fbo: Context does not support \"+f+\" draw buffers\")}}var h=t.UNSIGNED_BYTE,p=t.getExtension(\"OES_texture_float\");if(n.float&&f>0){if(!p)throw new Error(\"gl-fbo: Context does not support floating point textures\");h=t.FLOAT}else n.preferFloat&&f>0&&p&&(h=t.FLOAT);var g=!0;\"depth\"in n&&(g=!!n.depth);var m=!1;\"stencil\"in n&&(m=!!n.stencil);return new d(t,e,r,h,f,g,m,c)};var i,a,o,s,l=null;function c(t){return[t.getParameter(t.FRAMEBUFFER_BINDING),t.getParameter(t.RENDERBUFFER_BINDING),t.getParameter(t.TEXTURE_BINDING_2D)]}function u(t,e){t.bindFramebuffer(t.FRAMEBUFFER,e[0]),t.bindRenderbuffer(t.RENDERBUFFER,e[1]),t.bindTexture(t.TEXTURE_2D,e[2])}function f(t){switch(t){case i:throw new Error(\"gl-fbo: Framebuffer unsupported\");case a:throw new Error(\"gl-fbo: Framebuffer incomplete attachment\");case o:throw new Error(\"gl-fbo: Framebuffer incomplete dimensions\");case s:throw new Error(\"gl-fbo: Framebuffer incomplete missing attachment\");default:throw new Error(\"gl-fbo: Framebuffer failed for unspecified reason\")}}function h(t,e,r,i,a,o){if(!i)return null;var s=n(t,e,r,a,i);return s.magFilter=t.NEAREST,s.minFilter=t.NEAREST,s.mipSamples=1,s.bind(),t.framebufferTexture2D(t.FRAMEBUFFER,o,t.TEXTURE_2D,s.handle,0),s}function p(t,e,r,n,i){var a=t.createRenderbuffer();return t.bindRenderbuffer(t.RENDERBUFFER,a),t.renderbufferStorage(t.RENDERBUFFER,n,e,r),t.framebufferRenderbuffer(t.FRAMEBUFFER,i,t.RENDERBUFFER,a),a}function d(t,e,r,n,i,a,o,s){this.gl=t,this._shape=[0|e,0|r],this._destroyed=!1,this._ext=s,this.color=new Array(i);for(var d=0;d<i;++d)this.color[d]=null;this._color_rb=null,this.depth=null,this._depth_rb=null,this._colorType=n,this._useDepth=a,this._useStencil=o;var g=this,m=[0|e,0|r];Object.defineProperties(m,{0:{get:function(){return g._shape[0]},set:function(t){return g.width=t}},1:{get:function(){return g._shape[1]},set:function(t){return g.height=t}}}),this._shapeVector=m,function(t){var e=c(t.gl),r=t.gl,n=t.handle=r.createFramebuffer(),i=t._shape[0],a=t._shape[1],o=t.color.length,s=t._ext,d=t._useStencil,g=t._useDepth,m=t._colorType;r.bindFramebuffer(r.FRAMEBUFFER,n);for(var v=0;v<o;++v)t.color[v]=h(r,i,a,m,r.RGBA,r.COLOR_ATTACHMENT0+v);0===o?(t._color_rb=p(r,i,a,r.RGBA4,r.COLOR_ATTACHMENT0),s&&s.drawBuffersWEBGL(l[0])):o>1&&s.drawBuffersWEBGL(l[o]);var y=r.getExtension(\"WEBGL_depth_texture\");y?d?t.depth=h(r,i,a,y.UNSIGNED_INT_24_8_WEBGL,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g&&(t.depth=h(r,i,a,r.UNSIGNED_SHORT,r.DEPTH_COMPONENT,r.DEPTH_ATTACHMENT)):g&&d?t._depth_rb=p(r,i,a,r.DEPTH_STENCIL,r.DEPTH_STENCIL_ATTACHMENT):g?t._depth_rb=p(r,i,a,r.DEPTH_COMPONENT16,r.DEPTH_ATTACHMENT):d&&(t._depth_rb=p(r,i,a,r.STENCIL_INDEX,r.STENCIL_ATTACHMENT));var x=r.checkFramebufferStatus(r.FRAMEBUFFER);if(x!==r.FRAMEBUFFER_COMPLETE){t._destroyed=!0,r.bindFramebuffer(r.FRAMEBUFFER,null),r.deleteFramebuffer(t.handle),t.handle=null,t.depth&&(t.depth.dispose(),t.depth=null),t._depth_rb&&(r.deleteRenderbuffer(t._depth_rb),t._depth_rb=null);for(v=0;v<t.color.length;++v)t.color[v].dispose(),t.color[v]=null;t._color_rb&&(r.deleteRenderbuffer(t._color_rb),t._color_rb=null),u(r,e),f(x)}u(r,e)}(this)}var g=d.prototype;function m(t,e,r){if(t._destroyed)throw new Error(\"gl-fbo: Can't resize destroyed FBO\");if(t._shape[0]!==e||t._shape[1]!==r){var n=t.gl,i=n.getParameter(n.MAX_RENDERBUFFER_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-fbo: Can't resize FBO, invalid dimensions\");t._shape[0]=e,t._shape[1]=r;for(var a=c(n),o=0;o<t.color.length;++o)t.color[o].shape=t._shape;t._color_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._color_rb),n.renderbufferStorage(n.RENDERBUFFER,n.RGBA4,t._shape[0],t._shape[1])),t.depth&&(t.depth.shape=t._shape),t._depth_rb&&(n.bindRenderbuffer(n.RENDERBUFFER,t._depth_rb),t._useDepth&&t._useStencil?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_STENCIL,t._shape[0],t._shape[1]):t._useDepth?n.renderbufferStorage(n.RENDERBUFFER,n.DEPTH_COMPONENT16,t._shape[0],t._shape[1]):t._useStencil&&n.renderbufferStorage(n.RENDERBUFFER,n.STENCIL_INDEX,t._shape[0],t._shape[1])),n.bindFramebuffer(n.FRAMEBUFFER,t.handle);var s=n.checkFramebufferStatus(n.FRAMEBUFFER);s!==n.FRAMEBUFFER_COMPLETE&&(t.dispose(),u(n,a),f(s)),u(n,a)}}Object.defineProperties(g,{shape:{get:function(){return this._destroyed?[0,0]:this._shapeVector},set:function(t){if(Array.isArray(t)||(t=[0|t,0|t]),2!==t.length)throw new Error(\"gl-fbo: Shape vector must be length 2\");var e=0|t[0],r=0|t[1];return m(this,e,r),[e,r]},enumerable:!1},width:{get:function(){return this._destroyed?0:this._shape[0]},set:function(t){return m(this,t|=0,this._shape[1]),t},enumerable:!1},height:{get:function(){return this._destroyed?0:this._shape[1]},set:function(t){return t|=0,m(this,this._shape[0],t),t},enumerable:!1}}),g.bind=function(){if(!this._destroyed){var t=this.gl;t.bindFramebuffer(t.FRAMEBUFFER,this.handle),t.viewport(0,0,this._shape[0],this._shape[1])}},g.dispose=function(){if(!this._destroyed){this._destroyed=!0;var t=this.gl;t.deleteFramebuffer(this.handle),this.handle=null,this.depth&&(this.depth.dispose(),this.depth=null),this._depth_rb&&(t.deleteRenderbuffer(this._depth_rb),this._depth_rb=null);for(var e=0;e<this.color.length;++e)this.color[e].dispose(),this.color[e]=null;this._color_rb&&(t.deleteRenderbuffer(this._color_rb),this._color_rb=null)}}},{\"gl-texture2d\":353}],270:[function(t,e,r){var n=t(\"sprintf-js\").sprintf,i=t(\"gl-constants/lookup\"),a=t(\"glsl-shader-name\"),o=t(\"add-line-numbers\");e.exports=function(t,e,r){\"use strict\";var s=a(e)||\"of unknown name (see npm glsl-shader-name)\",l=\"unknown type\";void 0!==r&&(l=r===i.FRAGMENT_SHADER?\"fragment\":\"vertex\");for(var c=n(\"Error compiling %s shader %s:\\n\",l,s),u=n(\"%s%s\",c,t),f=t.split(\"\\n\"),h={},p=0;p<f.length;p++){var d=f[p];if(\"\"!==d&&\"\\0\"!==d){var g=parseInt(d.split(\":\")[2]);if(isNaN(g))throw new Error(n(\"Could not parse error: %s\",d));h[g]=d}}var m=o(e).split(\"\\n\");for(p=0;p<m.length;p++)if(h[p+3]||h[p+2]||h[p+1]){var v=m[p];if(c+=v+\"\\n\",h[p+1]){var y=h[p+1];y=y.substr(y.split(\":\",3).join(\":\").length+1).trim(),c+=n(\"^^^ %s\\n\\n\",y)}}return{long:c.trim(),short:u.trim()}}},{\"add-line-numbers\":66,\"gl-constants/lookup\":265,\"glsl-shader-name\":431,\"sprintf-js\":567}],271:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.gl,n=o(r,l.vertex,l.fragment),i=o(r,l.pickVertex,l.pickFragment),a=s(r),u=s(r),f=s(r),h=s(r),p=new c(t,n,i,a,u,f,h);return p.update(e),t.addObject(p),p};var n=t(\"binary-search-bounds\"),i=t(\"iota-array\"),a=t(\"typedarray-pool\"),o=t(\"gl-shader\"),s=t(\"gl-buffer\"),l=t(\"./lib/shaders\");function c(t,e,r,n,i,a,o){this.plot=t,this.shader=e,this.pickShader=r,this.positionBuffer=n,this.weightBuffer=i,this.colorBuffer=a,this.idBuffer=o,this.xData=[],this.yData=[],this.shape=[0,0],this.bounds=[1/0,1/0,-1/0,-1/0],this.pickOffset=0}var u,f=c.prototype,h=[0,0,1,0,0,1,1,0,1,1,0,1];f.draw=(u=[1,0,0,0,1,0,0,0,1],function(){var t=this.plot,e=this.shader,r=this.bounds,n=this.numVertices;if(!(n<=0)){var i=t.gl,a=t.dataBox,o=r[2]-r[0],s=r[3]-r[1],l=a[2]-a[0],c=a[3]-a[1];u[0]=2*o/l,u[4]=2*s/c,u[6]=2*(r[0]-a[0])/l-1,u[7]=2*(r[1]-a[1])/c-1,e.bind();var f=e.uniforms;f.viewTransform=u,f.shape=this.shape;var h=e.attributes;this.positionBuffer.bind(),h.position.pointer(),this.weightBuffer.bind(),h.weight.pointer(i.UNSIGNED_BYTE,!1),this.colorBuffer.bind(),h.color.pointer(i.UNSIGNED_BYTE,!0),i.drawArrays(i.TRIANGLES,0,n)}}),f.drawPick=function(){var t=[1,0,0,0,1,0,0,0,1],e=[0,0,0,0];return function(r){var n=this.plot,i=this.pickShader,a=this.bounds,o=this.numVertices;if(!(o<=0)){var s=n.gl,l=n.dataBox,c=a[2]-a[0],u=a[3]-a[1],f=l[2]-l[0],h=l[3]-l[1];t[0]=2*c/f,t[4]=2*u/h,t[6]=2*(a[0]-l[0])/f-1,t[7]=2*(a[1]-l[1])/h-1;for(var p=0;p<4;++p)e[p]=r>>8*p&255;this.pickOffset=r,i.bind();var d=i.uniforms;d.viewTransform=t,d.pickOffset=e,d.shape=this.shape;var g=i.attributes;return this.positionBuffer.bind(),g.position.pointer(),this.weightBuffer.bind(),g.weight.pointer(s.UNSIGNED_BYTE,!1),this.idBuffer.bind(),g.pickId.pointer(s.UNSIGNED_BYTE,!1),s.drawArrays(s.TRIANGLES,0,o),r+this.shape[0]*this.shape[1]}}}(),f.pick=function(t,e,r){var n=this.pickOffset,i=this.shape[0]*this.shape[1];if(r<n||r>=n+i)return null;var a=r-n,o=this.xData,s=this.yData;return{object:this,pointId:a,dataCoord:[o[a%this.shape[0]],s[a/this.shape[0]|0]]}},f.update=function(t){var e=(t=t||{}).shape||[0,0],r=t.x||i(e[0]),o=t.y||i(e[1]),s=t.z||new Float32Array(e[0]*e[1]),l=!1!==t.zsmooth;this.xData=r,this.yData=o;var c,u,f,p,d=t.colorLevels||[0],g=t.colorValues||[0,0,0,1],m=d.length,v=this.bounds;l?(c=v[0]=r[0],u=v[1]=o[0],f=v[2]=r[r.length-1],p=v[3]=o[o.length-1]):(c=v[0]=r[0]+(r[1]-r[0])/2,u=v[1]=o[0]+(o[1]-o[0])/2,f=v[2]=r[r.length-1]+(r[r.length-1]-r[r.length-2])/2,p=v[3]=o[o.length-1]+(o[o.length-1]-o[o.length-2])/2);var y=1/(f-c),x=1/(p-u),b=e[0],_=e[1];this.shape=[b,_];var w=(l?(b-1)*(_-1):b*_)*(h.length>>>1);this.numVertices=w;for(var T=a.mallocUint8(4*w),k=a.mallocFloat32(2*w),M=a.mallocUint8(2*w),A=a.mallocUint32(w),S=0,E=l?b-1:b,C=l?_-1:_,L=0;L<C;++L){var I,P;l?(I=x*(o[L]-u),P=x*(o[L+1]-u)):(I=L<_-1?x*(o[L]-(o[L+1]-o[L])/2-u):x*(o[L]-(o[L]-o[L-1])/2-u),P=L<_-1?x*(o[L]+(o[L+1]-o[L])/2-u):x*(o[L]+(o[L]-o[L-1])/2-u));for(var z=0;z<E;++z){var O,D;l?(O=y*(r[z]-c),D=y*(r[z+1]-c)):(O=z<b-1?y*(r[z]-(r[z+1]-r[z])/2-c):y*(r[z]-(r[z]-r[z-1])/2-c),D=z<b-1?y*(r[z]+(r[z+1]-r[z])/2-c):y*(r[z]+(r[z]-r[z-1])/2-c));for(var R=0;R<h.length;R+=2){var F,B,N,j,U=h[R],V=h[R+1],q=s[l?(L+V)*b+(z+U):L*b+z],H=n.le(d,q);if(H<0)F=g[0],B=g[1],N=g[2],j=g[3];else if(H===m-1)F=g[4*m-4],B=g[4*m-3],N=g[4*m-2],j=g[4*m-1];else{var G=(q-d[H])/(d[H+1]-d[H]),Y=1-G,W=4*H,X=4*(H+1);F=Y*g[W]+G*g[X],B=Y*g[W+1]+G*g[X+1],N=Y*g[W+2]+G*g[X+2],j=Y*g[W+3]+G*g[X+3]}T[4*S]=255*F,T[4*S+1]=255*B,T[4*S+2]=255*N,T[4*S+3]=255*j,k[2*S]=.5*O+.5*D,k[2*S+1]=.5*I+.5*P,M[2*S]=U,M[2*S+1]=V,A[S]=L*b+z,S+=1}}}this.positionBuffer.update(k),this.weightBuffer.update(M),this.colorBuffer.update(T),this.idBuffer.update(A),a.free(k),a.free(T),a.free(M),a.free(A)},f.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.positionBuffer.dispose(),this.weightBuffer.dispose(),this.colorBuffer.dispose(),this.idBuffer.dispose(),this.plot.removeObject(this)}},{\"./lib/shaders\":272,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"iota-array\":463,\"typedarray-pool\":595}],272:[function(t,e,r){\"use strict\";var n=t(\"glslify\");e.exports={fragment:n([\"precision lowp float;\\n#define GLSLIFY 1\\nvarying vec4 fragColor;\\nvoid main() {\\n  gl_FragColor = vec4(fragColor.rgb * fragColor.a, fragColor.a);\\n}\\n\"]),vertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 color;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  fragColor = color;\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"]),pickFragment:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nuniform vec2 shape;\\nuniform vec4 pickOffset;\\n\\nvoid main() {\\n  vec2 d = step(.5, vWeight);\\n  vec4 id = fragId + pickOffset;\\n  id.x += d.x + d.y*shape.x;\\n\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  gl_FragColor = id/255.;\\n}\\n\"]),pickVertex:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\nattribute vec2 weight;\\n\\nuniform vec2 shape;\\nuniform mat3 viewTransform;\\n\\nvarying vec4 fragId;\\nvarying vec2 vWeight;\\n\\nvoid main() {\\n  vWeight = weight;\\n\\n  fragId = pickId;\\n\\n  vec3 vPosition = viewTransform * vec3( position + (weight-.5)/(shape-1.) , 1.0);\\n  gl_Position = vec4(vPosition.xy, 0, vPosition.z);\\n}\\n\"])}},{glslify:273}],273:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],274:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, nextPosition;\\nattribute float arcLength, lineWidth;\\nattribute vec4 color;\\n\\nuniform vec2 screenShape;\\nuniform float pixelRatio;\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 fragColor;\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  vec4 startPoint = project(position);\\n  vec4 endPoint   = project(nextPosition);\\n\\n  vec2 A = startPoint.xy / startPoint.w;\\n  vec2 B =   endPoint.xy /   endPoint.w;\\n\\n  float clipAngle = atan(\\n    (B.y - A.y) * screenShape.y,\\n    (B.x - A.x) * screenShape.x\\n  );\\n\\n  vec2 offset = 0.5 * pixelRatio * lineWidth * vec2(\\n    sin(clipAngle),\\n    -cos(clipAngle)\\n  ) / screenShape;\\n\\n  gl_Position = vec4(startPoint.xy + startPoint.w * offset, startPoint.zw);\\n\\n  worldPosition = position;\\n  pixelArcLength = arcLength;\\n  fragColor = color;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3      clipBounds[2];\\nuniform sampler2D dashTexture;\\nuniform float     dashScale;\\nuniform float     opacity;\\n\\nvarying vec3    worldPosition;\\nvarying float   pixelArcLength;\\nvarying vec4    fragColor;\\n\\nvoid main() {\\n  if (\\n    outOfRange(clipBounds[0], clipBounds[1], worldPosition) ||\\n    fragColor.a * opacity == 0.\\n  ) discard;\\n\\n  float dashWeight = texture2D(dashTexture, vec2(dashScale * pixelArcLength, 0)).r;\\n  if(dashWeight < 0.5) {\\n    discard;\\n  }\\n  gl_FragColor = fragColor * opacity;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\n#define FLOAT_MAX  1.70141184e38\\n#define FLOAT_MIN  1.17549435e-38\\n\\n// https://github.com/mikolalysenko/glsl-read-float/blob/master/index.glsl\\nvec4 packFloat(float v) {\\n  float av = abs(v);\\n\\n  //Handle special cases\\n  if(av < FLOAT_MIN) {\\n    return vec4(0.0, 0.0, 0.0, 0.0);\\n  } else if(v > FLOAT_MAX) {\\n    return vec4(127.0, 128.0, 0.0, 0.0) / 255.0;\\n  } else if(v < -FLOAT_MAX) {\\n    return vec4(255.0, 128.0, 0.0, 0.0) / 255.0;\\n  }\\n\\n  vec4 c = vec4(0,0,0,0);\\n\\n  //Compute exponent and mantissa\\n  float e = floor(log2(av));\\n  float m = av * pow(2.0, -e) - 1.0;\\n\\n  //Unpack mantissa\\n  c[1] = floor(128.0 * m);\\n  m -= c[1] / 128.0;\\n  c[2] = floor(32768.0 * m);\\n  m -= c[2] / 32768.0;\\n  c[3] = floor(8388608.0 * m);\\n\\n  //Unpack exponent\\n  float ebias = e + 127.0;\\n  c[0] = floor(ebias / 2.0);\\n  ebias -= c[0] * 2.0;\\n  c[1] += floor(ebias) * 128.0;\\n\\n  //Unpack sign bit\\n  c[0] += 128.0 * step(0.0, -v);\\n\\n  //Scale back to range\\n  return c / 255.0;\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform float pickId;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 worldPosition;\\nvarying float pixelArcLength;\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], worldPosition)) discard;\\n\\n  gl_FragColor = vec4(pickId/255.0, packFloat(pixelArcLength).xyz);\\n}\"]),l=[{name:\"position\",type:\"vec3\"},{name:\"nextPosition\",type:\"vec3\"},{name:\"arcLength\",type:\"float\"},{name:\"lineWidth\",type:\"float\"},{name:\"color\",type:\"vec4\"}];r.createShader=function(t){return i(t,a,o,null,l)},r.createPickShader=function(t){return i(t,a,s,null,l)}},{\"gl-shader\":335,glslify:276}],275:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl||t.scene&&t.scene.gl,r=f(e);r.attributes.position.location=0,r.attributes.nextPosition.location=1,r.attributes.arcLength.location=2,r.attributes.lineWidth.location=3,r.attributes.color.location=4;var o=h(e);o.attributes.position.location=0,o.attributes.nextPosition.location=1,o.attributes.arcLength.location=2,o.attributes.lineWidth.location=3,o.attributes.color.location=4;for(var s=n(e),l=i(e,[{buffer:s,size:3,offset:0,stride:48},{buffer:s,size:3,offset:12,stride:48},{buffer:s,size:1,offset:24,stride:48},{buffer:s,size:1,offset:28,stride:48},{buffer:s,size:4,offset:32,stride:48}]),u=c(new Array(1024),[256,1,4]),p=0;p<1024;++p)u.data[p]=255;var d=a(e,u);d.wrap=e.REPEAT;var g=new v(e,r,o,s,l,d);return g.update(t),g};var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"gl-texture2d\"),o=new Uint8Array(4),s=new Float32Array(o.buffer);var l=t(\"binary-search-bounds\"),c=t(\"ndarray\"),u=t(\"./lib/shaders\"),f=u.createShader,h=u.createPickShader,p=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function d(t,e){for(var r=0,n=0;n<3;++n){var i=t[n]-e[n];r+=i*i}return Math.sqrt(r)}function g(t){for(var e=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],r=0;r<3;++r)e[0][r]=Math.max(t[0][r],e[0][r]),e[1][r]=Math.min(t[1][r],e[1][r]);return e}function m(t,e,r,n){this.arcLength=t,this.position=e,this.index=r,this.dataCoordinate=n}function v(t,e,r,n,i,a){this.gl=t,this.shader=e,this.pickShader=r,this.buffer=n,this.vao=i,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.points=[],this.arcLength=[],this.vertexCount=0,this.bounds=[[0,0,0],[0,0,0]],this.pickId=0,this.lineWidth=1,this.texture=a,this.dashScale=1,this.opacity=1,this.hasAlpha=!1,this.dirty=!0,this.pixelRatio=1}var y=v.prototype;y.isTransparent=function(){return this.hasAlpha},y.isOpaque=function(){return!this.hasAlpha},y.pickSlots=1,y.setPickBase=function(t){this.pickId=t},y.drawTransparent=y.draw=function(t){if(this.vertexCount){var e=this.gl,r=this.shader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,clipBounds:g(this.clipBounds),dashTexture:this.texture.bind(),dashScale:this.dashScale/this.arcLength[this.arcLength.length-1],opacity:this.opacity,screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.drawPick=function(t){if(this.vertexCount){var e=this.gl,r=this.pickShader,n=this.vao;r.bind(),r.uniforms={model:t.model||p,view:t.view||p,projection:t.projection||p,pickId:this.pickId,clipBounds:g(this.clipBounds),screenShape:[e.drawingBufferWidth,e.drawingBufferHeight],pixelRatio:this.pixelRatio},n.bind(),n.draw(e.TRIANGLE_STRIP,this.vertexCount),n.unbind()}},y.update=function(t){var e,r;this.dirty=!0;var n=!!t.connectGaps;\"dashScale\"in t&&(this.dashScale=t.dashScale),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=+t.opacity,this.opacity<1&&(this.hasAlpha=!0));var i=[],a=[],o=[],s=0,u=0,f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],h=t.position||t.positions;if(h){var p=t.color||t.colors||[0,0,0,1],g=t.lineWidth||1,m=!1;t:for(e=1;e<h.length;++e){var v,y,x,b=h[e-1],_=h[e];for(a.push(s),o.push(b.slice()),r=0;r<3;++r){if(isNaN(b[r])||isNaN(_[r])||!isFinite(b[r])||!isFinite(_[r])){if(!n&&i.length>0){for(var w=0;w<24;++w)i.push(i[i.length-12]);u+=2,m=!0}continue t}f[0][r]=Math.min(f[0][r],b[r],_[r]),f[1][r]=Math.max(f[1][r],b[r],_[r])}Array.isArray(p[0])?(v=p.length>e-1?p[e-1]:p.length>0?p[p.length-1]:[0,0,0,1],y=p.length>e?p[e]:p.length>0?p[p.length-1]:[0,0,0,1]):v=y=p,3===v.length&&(v=[v[0],v[1],v[2],1]),3===y.length&&(y=[y[0],y[1],y[2],1]),!this.hasAlpha&&v[3]<1&&(this.hasAlpha=!0),x=Array.isArray(g)?g.length>e-1?g[e-1]:g.length>0?g[g.length-1]:[0,0,0,1]:g;var T=s;if(s+=d(b,_),m){for(r=0;r<2;++r)i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3]);u+=2,m=!1}i.push(b[0],b[1],b[2],_[0],_[1],_[2],T,x,v[0],v[1],v[2],v[3],b[0],b[1],b[2],_[0],_[1],_[2],T,-x,v[0],v[1],v[2],v[3],_[0],_[1],_[2],b[0],b[1],b[2],s,-x,y[0],y[1],y[2],y[3],_[0],_[1],_[2],b[0],b[1],b[2],s,x,y[0],y[1],y[2],y[3]),u+=4}}if(this.buffer.update(i),a.push(s),o.push(h[h.length-1].slice()),this.bounds=f,this.vertexCount=u,this.points=o,this.arcLength=a,\"dashes\"in t){var k=t.dashes.slice();for(k.unshift(0),e=1;e<k.length;++e)k[e]=k[e-1]+k[e];var M=c(new Array(1024),[256,1,4]);for(e=0;e<256;++e){for(r=0;r<4;++r)M.set(e,0,r,0);1&l.le(k,k[k.length-1]*e/255)?M.set(e,0,0,0):M.set(e,0,0,255)}this.texture.setPixels(M)}},y.dispose=function(){this.shader.dispose(),this.vao.dispose(),this.buffer.dispose()},y.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=function(t,e,r,n){return o[0]=n,o[1]=r,o[2]=e,o[3]=t,s[0]}(t.value[0],t.value[1],t.value[2],0),r=l.le(this.arcLength,e);if(r<0)return null;if(r===this.arcLength.length-1)return new m(this.arcLength[this.arcLength.length-1],this.points[this.points.length-1].slice(),r);for(var n=this.points[r],i=this.points[Math.min(r+1,this.points.length-1)],a=(e-this.arcLength[r])/(this.arcLength[r+1]-this.arcLength[r]),c=1-a,u=[0,0,0],f=0;f<3;++f)u[f]=c*n[f]+a*i[f];var h=Math.min(a<.5?r:r+1,this.points.length-1);return new m(e,u,h,this.points[h])}},{\"./lib/shaders\":274,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495}],276:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],277:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15];return t[0]=s*(h*v-p*m)-f*(l*v-c*m)+g*(l*p-c*h),t[1]=-(n*(h*v-p*m)-f*(i*v-a*m)+g*(i*p-a*h)),t[2]=n*(l*v-c*m)-s*(i*v-a*m)+g*(i*c-a*l),t[3]=-(n*(l*p-c*h)-s*(i*p-a*h)+f*(i*c-a*l)),t[4]=-(o*(h*v-p*m)-u*(l*v-c*m)+d*(l*p-c*h)),t[5]=r*(h*v-p*m)-u*(i*v-a*m)+d*(i*p-a*h),t[6]=-(r*(l*v-c*m)-o*(i*v-a*m)+d*(i*c-a*l)),t[7]=r*(l*p-c*h)-o*(i*p-a*h)+u*(i*c-a*l),t[8]=o*(f*v-p*g)-u*(s*v-c*g)+d*(s*p-c*f),t[9]=-(r*(f*v-p*g)-u*(n*v-a*g)+d*(n*p-a*f)),t[10]=r*(s*v-c*g)-o*(n*v-a*g)+d*(n*c-a*s),t[11]=-(r*(s*p-c*f)-o*(n*p-a*f)+u*(n*c-a*s)),t[12]=-(o*(f*m-h*g)-u*(s*m-l*g)+d*(s*h-l*f)),t[13]=r*(f*m-h*g)-u*(n*m-i*g)+d*(n*h-i*f),t[14]=-(r*(s*m-l*g)-o*(n*m-i*g)+d*(n*l-i*s)),t[15]=r*(s*h-l*f)-o*(n*h-i*f)+u*(n*l-i*s),t}},{}],278:[function(t,e,r){e.exports=function(t){var e=new Float32Array(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e}},{}],279:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],280:[function(t,e,r){e.exports=function(){var t=new Float32Array(16);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],281:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3],a=t[4],o=t[5],s=t[6],l=t[7],c=t[8],u=t[9],f=t[10],h=t[11],p=t[12],d=t[13],g=t[14],m=t[15];return(e*o-r*a)*(f*m-h*g)-(e*s-n*a)*(u*m-h*d)+(e*l-i*a)*(u*g-f*d)+(r*s-n*o)*(c*m-h*p)-(r*l-i*o)*(c*g-f*p)+(n*l-i*s)*(c*d-u*p)}},{}],282:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r+r,s=n+n,l=i+i,c=r*o,u=n*o,f=n*s,h=i*o,p=i*s,d=i*l,g=a*o,m=a*s,v=a*l;return t[0]=1-f-d,t[1]=u+v,t[2]=h-m,t[3]=0,t[4]=u-v,t[5]=1-c-d,t[6]=p+g,t[7]=0,t[8]=h+m,t[9]=p-g,t[10]=1-c-f,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],283:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o=r[0],s=r[1],l=r[2],c=Math.sqrt(o*o+s*s+l*l);if(Math.abs(c)<1e-6)return null;return o*=c=1/c,s*=c,l*=c,n=Math.sin(e),i=Math.cos(e),a=1-i,t[0]=o*o*a+i,t[1]=s*o*a+l*n,t[2]=l*o*a-s*n,t[3]=0,t[4]=o*s*a-l*n,t[5]=s*s*a+i,t[6]=l*s*a+o*n,t[7]=0,t[8]=o*l*a+s*n,t[9]=s*l*a-o*n,t[10]=l*l*a+i,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],284:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=n+n,l=i+i,c=a+a,u=n*s,f=n*l,h=n*c,p=i*l,d=i*c,g=a*c,m=o*s,v=o*l,y=o*c;return t[0]=1-(p+g),t[1]=f+y,t[2]=h-v,t[3]=0,t[4]=f-y,t[5]=1-(u+g),t[6]=d+m,t[7]=0,t[8]=h+v,t[9]=d-m,t[10]=1-(u+p),t[11]=0,t[12]=r[0],t[13]=r[1],t[14]=r[2],t[15]=1,t}},{}],285:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=e[1],t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=e[2],t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],286:[function(t,e,r){e.exports=function(t,e){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=e[0],t[13]=e[1],t[14]=e[2],t[15]=1,t}},{}],287:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=n,t[6]=r,t[7]=0,t[8]=0,t[9]=-r,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],288:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=0,t[2]=-r,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=r,t[9]=0,t[10]=n,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],289:[function(t,e,r){e.exports=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=0,t[4]=-r,t[5]=n,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],290:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(r-e),l=1/(i-n),c=1/(a-o);return t[0]=2*a*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=2*a*l,t[6]=0,t[7]=0,t[8]=(r+e)*s,t[9]=(i+n)*l,t[10]=(o+a)*c,t[11]=-1,t[12]=0,t[13]=0,t[14]=o*a*2*c,t[15]=0,t}},{}],291:[function(t,e,r){e.exports=function(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}},{}],292:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),copy:t(\"./copy\"),identity:t(\"./identity\"),transpose:t(\"./transpose\"),invert:t(\"./invert\"),adjoint:t(\"./adjoint\"),determinant:t(\"./determinant\"),multiply:t(\"./multiply\"),translate:t(\"./translate\"),scale:t(\"./scale\"),rotate:t(\"./rotate\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),fromRotation:t(\"./fromRotation\"),fromRotationTranslation:t(\"./fromRotationTranslation\"),fromScaling:t(\"./fromScaling\"),fromTranslation:t(\"./fromTranslation\"),fromXRotation:t(\"./fromXRotation\"),fromYRotation:t(\"./fromYRotation\"),fromZRotation:t(\"./fromZRotation\"),fromQuat:t(\"./fromQuat\"),frustum:t(\"./frustum\"),perspective:t(\"./perspective\"),perspectiveFromFieldOfView:t(\"./perspectiveFromFieldOfView\"),ortho:t(\"./ortho\"),lookAt:t(\"./lookAt\"),str:t(\"./str\")}},{\"./adjoint\":277,\"./clone\":278,\"./copy\":279,\"./create\":280,\"./determinant\":281,\"./fromQuat\":282,\"./fromRotation\":283,\"./fromRotationTranslation\":284,\"./fromScaling\":285,\"./fromTranslation\":286,\"./fromXRotation\":287,\"./fromYRotation\":288,\"./fromZRotation\":289,\"./frustum\":290,\"./identity\":291,\"./invert\":293,\"./lookAt\":294,\"./multiply\":295,\"./ortho\":296,\"./perspective\":297,\"./perspectiveFromFieldOfView\":298,\"./rotate\":299,\"./rotateX\":300,\"./rotateY\":301,\"./rotateZ\":302,\"./scale\":303,\"./str\":304,\"./translate\":305,\"./transpose\":306}],293:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;if(!L)return null;return L=1/L,t[0]=(s*C-l*E+c*S)*L,t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t}},{}],294:[function(t,e,r){var n=t(\"./identity\");e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g=e[0],m=e[1],v=e[2],y=i[0],x=i[1],b=i[2],_=r[0],w=r[1],T=r[2];if(Math.abs(g-_)<1e-6&&Math.abs(m-w)<1e-6&&Math.abs(v-T)<1e-6)return n(t);f=g-_,h=m-w,p=v-T,d=1/Math.sqrt(f*f+h*h+p*p),a=x*(p*=d)-b*(h*=d),o=b*(f*=d)-y*p,s=y*h-x*f,(d=Math.sqrt(a*a+o*o+s*s))?(a*=d=1/d,o*=d,s*=d):(a=0,o=0,s=0);l=h*s-p*o,c=p*a-f*s,u=f*o-h*a,(d=Math.sqrt(l*l+c*c+u*u))?(l*=d=1/d,c*=d,u*=d):(l=0,c=0,u=0);return t[0]=a,t[1]=l,t[2]=f,t[3]=0,t[4]=o,t[5]=c,t[6]=h,t[7]=0,t[8]=s,t[9]=u,t[10]=p,t[11]=0,t[12]=-(a*g+o*m+s*v),t[13]=-(l*g+c*m+u*v),t[14]=-(f*g+h*m+p*v),t[15]=1,t}},{\"./identity\":291}],295:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,x=r[4],b=r[5],_=r[6],w=r[7],t[4]=x*n+b*s+_*f+w*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,x=r[8],b=r[9],_=r[10],w=r[11],t[8]=x*n+b*s+_*f+w*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,x=r[12],b=r[13],_=r[14],w=r[15],t[12]=x*n+b*s+_*f+w*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}},{}],296:[function(t,e,r){e.exports=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t}},{}],297:[function(t,e,r){e.exports=function(t,e,r,n,i){var a=1/Math.tan(e/2),o=1/(n-i);return t[0]=a/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=a,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=(i+n)*o,t[11]=-1,t[12]=0,t[13]=0,t[14]=2*i*n*o,t[15]=0,t}},{}],298:[function(t,e,r){e.exports=function(t,e,r,n){var i=Math.tan(e.upDegrees*Math.PI/180),a=Math.tan(e.downDegrees*Math.PI/180),o=Math.tan(e.leftDegrees*Math.PI/180),s=Math.tan(e.rightDegrees*Math.PI/180),l=2/(o+s),c=2/(i+a);return t[0]=l,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=c,t[6]=0,t[7]=0,t[8]=-(o-s)*l*.5,t[9]=(i-a)*c*.5,t[10]=n/(r-n),t[11]=-1,t[12]=0,t[13]=0,t[14]=n*r/(r-n),t[15]=0,t}},{}],299:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E=n[0],C=n[1],L=n[2],I=Math.sqrt(E*E+C*C+L*L);if(Math.abs(I)<1e-6)return null;E*=I=1/I,C*=I,L*=I,i=Math.sin(r),a=Math.cos(r),o=1-a,s=e[0],l=e[1],c=e[2],u=e[3],f=e[4],h=e[5],p=e[6],d=e[7],g=e[8],m=e[9],v=e[10],y=e[11],x=E*E*o+a,b=C*E*o+L*i,_=L*E*o-C*i,w=E*C*o-L*i,T=C*C*o+a,k=L*C*o+E*i,M=E*L*o+C*i,A=C*L*o-E*i,S=L*L*o+a,t[0]=s*x+f*b+g*_,t[1]=l*x+h*b+m*_,t[2]=c*x+p*b+v*_,t[3]=u*x+d*b+y*_,t[4]=s*w+f*T+g*k,t[5]=l*w+h*T+m*k,t[6]=c*w+p*T+v*k,t[7]=u*w+d*T+y*k,t[8]=s*M+f*A+g*S,t[9]=l*M+h*A+m*S,t[10]=c*M+p*A+v*S,t[11]=u*M+d*A+y*S,e!==t&&(t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t}},{}],300:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t}},{}],301:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[8],u=e[9],f=e[10],h=e[11];e!==t&&(t[4]=e[4],t[5]=e[5],t[6]=e[6],t[7]=e[7],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i-c*n,t[1]=o*i-u*n,t[2]=s*i-f*n,t[3]=l*i-h*n,t[8]=a*n+c*i,t[9]=o*n+u*i,t[10]=s*n+f*i,t[11]=l*n+h*i,t}},{}],302:[function(t,e,r){e.exports=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]);return t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t}},{}],303:[function(t,e,r){e.exports=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t}},{}],304:[function(t,e,r){e.exports=function(t){return\"mat4(\"+t[0]+\", \"+t[1]+\", \"+t[2]+\", \"+t[3]+\", \"+t[4]+\", \"+t[5]+\", \"+t[6]+\", \"+t[7]+\", \"+t[8]+\", \"+t[9]+\", \"+t[10]+\", \"+t[11]+\", \"+t[12]+\", \"+t[13]+\", \"+t[14]+\", \"+t[15]+\")\"}},{}],305:[function(t,e,r){e.exports=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n,t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]);return t}},{}],306:[function(t,e,r){e.exports=function(t,e){if(t===e){var r=e[1],n=e[2],i=e[3],a=e[6],o=e[7],s=e[11];t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=r,t[6]=e[9],t[7]=e[13],t[8]=n,t[9]=a,t[11]=e[14],t[12]=i,t[13]=o,t[14]=s}else t[0]=e[0],t[1]=e[4],t[2]=e[8],t[3]=e[12],t[4]=e[1],t[5]=e[5],t[6]=e[9],t[7]=e[13],t[8]=e[2],t[9]=e[6],t[10]=e[10],t[11]=e[14],t[12]=e[3],t[13]=e[7],t[14]=e[11],t[15]=e[15];return t}},{}],307:[function(t,e,r){\"use strict\";var n=t(\"barycentric\"),i=t(\"polytope-closest-point/lib/closest_point_2d.js\");function a(t,e){for(var r=[0,0,0,0],n=0;n<4;++n)for(var i=0;i<4;++i)r[i]+=t[4*n+i]*e[n];return r}function o(t,e,r,n,i){for(var o=a(n,a(r,a(e,[t[0],t[1],t[2],1]))),s=0;s<3;++s)o[s]/=o[3];return[.5*i[0]*(1+o[0]),.5*i[1]*(1-o[1])]}function s(t,e){for(var r=[0,0,0],n=0;n<t.length;++n)for(var i=t[n],a=e[n],o=0;o<3;++o)r[o]+=a*i[o];return r}e.exports=function(t,e,r,a,l,c){if(1===t.length)return[0,t[0].slice()];for(var u=new Array(t.length),f=0;f<t.length;++f)u[f]=o(t[f],r,a,l,c);var h=0,p=1/0;for(f=0;f<u.length;++f){for(var d=0,g=0;g<2;++g)d+=Math.pow(u[f][g]-e[g],2);d<p&&(p=d,h=f)}var m=function(t,e){if(2===t.length){for(var r=0,a=0,o=0;o<2;++o)r+=Math.pow(e[o]-t[0][o],2),a+=Math.pow(e[o]-t[1][o],2);return r=Math.sqrt(r),a=Math.sqrt(a),r+a<1e-6?[1,0]:[a/(r+a),r/(a+r)]}if(3===t.length){var s=[0,0];return i(t[0],t[1],t[2],e,s),n(t,s)}return[]}(u,e),v=0;for(f=0;f<3;++f){if(m[f]<-.001||m[f]>1.0001)return null;v+=m[f]}if(Math.abs(v-1)>.001)return null;return[h,s(t,m),m]}},{barycentric:78,\"polytope-closest-point/lib/closest_point_2d.js\":525}],308:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, normal;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model\\n           , view\\n           , projection\\n           , inverseModel;\\nuniform vec3 eyePosition\\n           , lightPosition;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvec4 project(vec3 p) {\\n  return projection * view * model * vec4(p, 1.0);\\n}\\n\\nvoid main() {\\n  gl_Position      = project(position);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * vec4(position , 1.0);\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal  = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  f_color          = color;\\n  f_data           = position;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\n//#pragma glslify: beckmann = require(glsl-specular-beckmann) // used in gl-surface3d\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness\\n            , fresnel\\n            , kambient\\n            , kdiffuse\\n            , kspecular;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal\\n           , f_lightDirection\\n           , f_eyeDirection\\n           , f_data;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (f_color.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], f_data)\\n  ) discard;\\n\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  //float specular = max(0.0, beckmann(L, V, N, roughness)); // used in gl-surface3d\\n\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = vec4(f_color.rgb, 1.0) * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * f_color.a;\\n}\\n\"]),o=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_color = color;\\n  f_data  = position;\\n  f_uv    = uv;\\n}\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec3 f_data;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_data)) discard;\\n\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),l=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 uv;\\nattribute float pointSize;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0 ,0.0 ,0.0);\\n  } else {\\n    gl_Position = projection * view * model * vec4(position, 1.0);\\n  }\\n  gl_PointSize = pointSize;\\n  f_color = color;\\n  f_uv = uv;\\n}\"]),c=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D texture;\\nuniform float opacity;\\n\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  vec2 pointR = gl_PointCoord.xy - vec2(0.5, 0.5);\\n  if(dot(pointR, pointR) > 0.25) {\\n    discard;\\n  }\\n  gl_FragColor = f_color * texture2D(texture, f_uv) * opacity;\\n}\"]),u=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n  f_id        = id;\\n  f_position  = position;\\n}\"]),f=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]),h=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3  position;\\nattribute float pointSize;\\nattribute vec4  id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0.0, 0.0, 0.0, 0.0);\\n  } else {\\n    gl_Position  = projection * view * model * vec4(position, 1.0);\\n    gl_PointSize = pointSize;\\n  }\\n  f_id         = id;\\n  f_position   = position;\\n}\"]),p=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position;\\n\\nuniform mat4 model, view, projection;\\n\\nvoid main() {\\n  gl_Position = projection * view * model * vec4(position, 1.0);\\n}\"]),d=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform vec3 contourColor;\\n\\nvoid main() {\\n  gl_FragColor = vec4(contourColor, 1.0);\\n}\\n\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.wireShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"}]},r.pointShader={vertex:l,fragment:c,attributes:[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"pointSize\",type:\"float\"}]},r.pickShader={vertex:u,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"id\",type:\"vec4\"}]},r.pointPickShader={vertex:h,fragment:f,attributes:[{name:\"position\",type:\"vec3\"},{name:\"pointSize\",type:\"float\"},{name:\"id\",type:\"vec4\"}]},r.contourShader={vertex:p,fragment:d,attributes:[{name:\"position\",type:\"vec3\"}]}},{glslify:310}],309:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"normals\"),l=t(\"gl-mat4/multiply\"),c=t(\"gl-mat4/invert\"),u=t(\"ndarray\"),f=t(\"colormap\"),h=t(\"simplicial-complex-contour\"),p=t(\"typedarray-pool\"),d=t(\"./lib/shaders\"),g=t(\"./lib/closest-point\"),m=d.meshShader,v=d.wireShader,y=d.pointShader,x=d.pickShader,b=d.pointPickShader,_=d.contourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function T(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,T,k,M,A,S){this.gl=t,this.pixelRatio=1,this.cells=[],this.positions=[],this.intensity=[],this.texture=e,this.dirty=!0,this.triShader=r,this.lineShader=n,this.pointShader=i,this.pickShader=a,this.pointPickShader=o,this.contourShader=s,this.trianglePositions=l,this.triangleColors=u,this.triangleNormals=h,this.triangleUVs=f,this.triangleIds=c,this.triangleVAO=p,this.triangleCount=0,this.lineWidth=1,this.edgePositions=d,this.edgeColors=m,this.edgeUVs=v,this.edgeIds=g,this.edgeVAO=y,this.edgeCount=0,this.pointPositions=x,this.pointColors=_,this.pointUVs=T,this.pointSizes=k,this.pointIds=b,this.pointVAO=M,this.pointCount=0,this.contourLineWidth=1,this.contourPositions=A,this.contourVAO=S,this.contourCount=0,this.contourColor=[0,0,0],this.contourEnable=!0,this.pickVertex=!0,this.pickId=1,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.lightPosition=[1e5,1e5,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.opacity=1,this.hasAlpha=!1,this.opacityscale=!1,this._model=w,this._view=w,this._projection=w,this._resolution=[1,1]}var k=T.prototype;function M(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}function A(t){var e=n(t,m.vertex,m.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.normal.location=4,e}function S(t){var e=n(t,v.vertex,v.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e}function E(t){var e=n(t,y.vertex,y.fragment);return e.attributes.position.location=0,e.attributes.color.location=2,e.attributes.uv.location=3,e.attributes.pointSize.location=4,e}function C(t){var e=n(t,x.vertex,x.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e}function L(t){var e=n(t,b.vertex,b.fragment);return e.attributes.position.location=0,e.attributes.id.location=1,e.attributes.pointSize.location=4,e}function I(t){var e=n(t,_.vertex,_.fragment);return e.attributes.position.location=0,e}k.isOpaque=function(){return!this.hasAlpha},k.isTransparent=function(){return this.hasAlpha},k.pickSlots=1,k.setPickBase=function(t){this.pickId=t},k.highlight=function(t){if(t&&this.contourEnable){for(var e=h(this.cells,this.intensity,t.intensity),r=e.cells,n=e.vertexIds,i=e.vertexWeights,a=r.length,o=p.mallocFloat32(6*a),s=0,l=0;l<a;++l)for(var c=r[l],u=0;u<2;++u){var f=c[0];2===c.length&&(f=c[u]);for(var d=n[f][0],g=n[f][1],m=i[f],v=1-m,y=this.positions[d],x=this.positions[g],b=0;b<3;++b)o[s++]=m*y[b]+v*x[b]}this.contourCount=s/3|0,this.contourPositions.update(o.subarray(0,s)),p.free(o)}else this.contourCount=0},k.update=function(t){t=t||{};var e=this.gl;this.dirty=!0,\"contourEnable\"in t&&(this.contourEnable=t.contourEnable),\"contourColor\"in t&&(this.contourColor=t.contourColor),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"lightPosition\"in t&&(this.lightPosition=t.lightPosition),this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=t.opacity,this.opacity<1&&(this.hasAlpha=!0)),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale,this.hasAlpha=!0),\"ambient\"in t&&(this.ambientLight=t.ambient),\"diffuse\"in t&&(this.diffuseLight=t.diffuse),\"specular\"in t&&(this.specularLight=t.specular),\"roughness\"in t&&(this.roughness=t.roughness),\"fresnel\"in t&&(this.fresnel=t.fresnel),t.texture?(this.texture.dispose(),this.texture=o(e,t.texture)):t.colormap&&(this.texture.shape=[256,256],this.texture.minFilter=e.LINEAR_MIPMAP_LINEAR,this.texture.magFilter=e.LINEAR,this.texture.setPixels(function(t,e){for(var r=f({colormap:t,nshades:256,format:\"rgba\"}),n=new Uint8Array(1024),i=0;i<256;++i){for(var a=r[i],o=0;o<3;++o)n[4*i+o]=a[o];n[4*i+3]=e?255*M(i/255,e):255*a[3]}return u(n,[256,256,4],[4,0,1])}(t.colormap,this.opacityscale)),this.texture.generateMipmap());var r=t.cells,n=t.positions;if(n&&r){var i=[],a=[],l=[],c=[],h=[],p=[],d=[],g=[],m=[],v=[],y=[],x=[],b=[],_=[];this.cells=r,this.positions=n;var w=t.vertexNormals,T=t.cellNormals,k=void 0===t.vertexNormalsEpsilon?1e-6:t.vertexNormalsEpsilon,A=void 0===t.faceNormalsEpsilon?1e-6:t.faceNormalsEpsilon;t.useFacetNormals&&!T&&(T=s.faceNormals(r,n,A)),T||w||(w=s.vertexNormals(r,n,k));var S=t.vertexColors,E=t.cellColors,C=t.meshColor||[1,1,1,1],L=t.vertexUVs,I=t.vertexIntensity,P=t.cellUVs,z=t.cellIntensity,O=1/0,D=-1/0;if(!L&&!P)if(I)if(t.vertexIntensityBounds)O=+t.vertexIntensityBounds[0],D=+t.vertexIntensityBounds[1];else for(var R=0;R<I.length;++R){var F=I[R];O=Math.min(O,F),D=Math.max(D,F)}else if(z)if(t.cellIntensityBounds)O=+t.cellIntensityBounds[0],D=+t.cellIntensityBounds[1];else for(R=0;R<z.length;++R){F=z[R];O=Math.min(O,F),D=Math.max(D,F)}else for(R=0;R<n.length;++R){F=n[R][2];O=Math.min(O,F),D=Math.max(D,F)}this.intensity=I||(z||function(t){for(var e=t.length,r=new Array(e),n=0;n<e;++n)r[n]=t[n][2];return r}(n)),this.pickVertex=!(z||E);var B=t.pointSizes,N=t.pointSize||1;this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(R=0;R<n.length;++R)for(var j=n[R],U=0;U<3;++U)!isNaN(j[U])&&isFinite(j[U])&&(this.bounds[0][U]=Math.min(this.bounds[0][U],j[U]),this.bounds[1][U]=Math.max(this.bounds[1][U],j[U]));var V=0,q=0,H=0;t:for(R=0;R<r.length;++R){var G=r[R];switch(G.length){case 1:for(j=n[W=G[0]],U=0;U<3;++U)if(isNaN(j[U])||!isFinite(j[U]))continue t;v.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?y.push(X[0],X[1],X[2],this.opacity):(y.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],x.push(Z[0],Z[1]),B?b.push(B[W]):b.push(N),_.push(R),H+=1;break;case 2:for(U=0;U<2;++U){j=n[W=G[U]];for(var Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t}for(U=0;U<2;++U){j=n[W=G[U]];p.push(j[0],j[1],j[2]),X=S?S[W]:E?E[R]:C,this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?d.push(X[0],X[1],X[2],this.opacity):(d.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],g.push(Z[0],Z[1]),m.push(R)}q+=1;break;case 3:for(U=0;U<3;++U)for(j=n[W=G[U]],Y=0;Y<3;++Y)if(isNaN(j[Y])||!isFinite(j[Y]))continue t;for(U=0;U<3;++U){var W,X,Z,J;j=n[W=G[2-U]];i.push(j[0],j[1],j[2]),(X=S?S[W]:E?E[R]:C)?this.opacityscale&&I?a.push(X[0],X[1],X[2],this.opacity*M((I[W]-O)/(D-O),this.opacityscale)):3===X.length?a.push(X[0],X[1],X[2],this.opacity):(a.push(X[0],X[1],X[2],X[3]*this.opacity),X[3]<1&&(this.hasAlpha=!0)):a.push(.5,.5,.5,1),Z=L?L[W]:I?[(I[W]-O)/(D-O),0]:P?P[R]:z?[(z[R]-O)/(D-O),0]:[(j[2]-O)/(D-O),0],c.push(Z[0],Z[1]),J=w?w[W]:T[R],l.push(J[0],J[1],J[2]),h.push(R)}V+=1}}this.pointCount=H,this.edgeCount=q,this.triangleCount=V,this.pointPositions.update(v),this.pointColors.update(y),this.pointUVs.update(x),this.pointSizes.update(b),this.pointIds.update(new Uint32Array(_)),this.edgePositions.update(p),this.edgeColors.update(d),this.edgeUVs.update(g),this.edgeIds.update(new Uint32Array(m)),this.trianglePositions.update(i),this.triangleColors.update(a),this.triangleUVs.update(c),this.triangleNormals.update(l),this.triangleIds.update(new Uint32Array(h))}},k.drawTransparent=k.draw=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);var s={model:r,view:n,projection:i,inverseModel:w.slice(),clipBounds:a,kambient:this.ambientLight,kdiffuse:this.diffuseLight,kspecular:this.specularLight,roughness:this.roughness,fresnel:this.fresnel,eyePosition:[0,0,0],lightPosition:[0,0,0],contourColor:this.contourColor,texture:0};s.inverseModel=c(s.inverseModel,s.model),e.disable(e.CULL_FACE),this.texture.bind(0);var u=new Array(16);l(u,s.view,s.model),l(u,s.projection,u),c(u,u);for(o=0;o<3;++o)s.eyePosition[o]=u[12+o]/u[15];var f,h=u[15];for(o=0;o<3;++o)h+=this.lightPosition[o]*u[4*o+3];for(o=0;o<3;++o){for(var p=u[12+o],d=0;d<3;++d)p+=u[4*d+o]*this.lightPosition[d];s.lightPosition[o]=p/h}this.triangleCount>0&&((f=this.triShader).bind(),f.uniforms=s,this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind());this.edgeCount>0&&this.lineWidth>0&&((f=this.lineShader).bind(),f.uniforms=s,this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind());this.pointCount>0&&((f=this.pointShader).bind(),f.uniforms=s,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind());this.contourEnable&&this.contourCount>0&&this.contourLineWidth>0&&((f=this.contourShader).bind(),f.uniforms=s,this.contourVAO.bind(),e.drawArrays(e.LINES,0,this.contourCount),this.contourVAO.unbind())},k.drawPick=function(t){t=t||{};for(var e=this.gl,r=t.model||w,n=t.view||w,i=t.projection||w,a=[[-1e6,-1e6,-1e6],[1e6,1e6,1e6]],o=0;o<3;++o)a[0][o]=Math.max(a[0][o],this.clipBounds[0][o]),a[1][o]=Math.min(a[1][o],this.clipBounds[1][o]);this._model=[].slice.call(r),this._view=[].slice.call(n),this._projection=[].slice.call(i),this._resolution=[e.drawingBufferWidth,e.drawingBufferHeight];var s,l={model:r,view:n,projection:i,clipBounds:a,pickId:this.pickId/255};((s=this.pickShader).bind(),s.uniforms=l,this.triangleCount>0&&(this.triangleVAO.bind(),e.drawArrays(e.TRIANGLES,0,3*this.triangleCount),this.triangleVAO.unbind()),this.edgeCount>0&&(this.edgeVAO.bind(),e.lineWidth(this.lineWidth*this.pixelRatio),e.drawArrays(e.LINES,0,2*this.edgeCount),this.edgeVAO.unbind()),this.pointCount>0)&&((s=this.pointPickShader).bind(),s.uniforms=l,this.pointVAO.bind(),e.drawArrays(e.POINTS,0,this.pointCount),this.pointVAO.unbind())},k.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;for(var e=t.value[0]+256*t.value[1]+65536*t.value[2],r=this.cells[e],n=this.positions,i=new Array(r.length),a=0;a<r.length;++a)i[a]=n[r[a]];var o=t.coord[0],s=t.coord[1];if(!this.pickVertex){var l=this.positions[r[0]],c=this.positions[r[1]],u=this.positions[r[2]],f=[(l[0]+c[0]+u[0])/3,(l[1]+c[1]+u[1])/3,(l[2]+c[2]+u[2])/3];return{_cellCenter:!0,position:[o,s],index:e,cell:r,cellId:e,intensity:this.intensity[e],dataCoordinate:f}}var h=g(i,[o*this.pixelRatio,this._resolution[1]-s*this.pixelRatio],this._model,this._view,this._projection,this._resolution);if(!h)return null;var p=h[2],d=0;for(a=0;a<r.length;++a)d+=p[a]*this.intensity[r[a]];return{position:h[1],index:r[h[0]],cell:r,cellId:e,intensity:d,dataCoordinate:this.positions[r[h[0]]]}},k.dispose=function(){this.texture.dispose(),this.triShader.dispose(),this.lineShader.dispose(),this.pointShader.dispose(),this.pickShader.dispose(),this.pointPickShader.dispose(),this.triangleVAO.dispose(),this.trianglePositions.dispose(),this.triangleColors.dispose(),this.triangleUVs.dispose(),this.triangleNormals.dispose(),this.triangleIds.dispose(),this.edgeVAO.dispose(),this.edgePositions.dispose(),this.edgeColors.dispose(),this.edgeUVs.dispose(),this.edgeIds.dispose(),this.pointVAO.dispose(),this.pointPositions.dispose(),this.pointColors.dispose(),this.pointUVs.dispose(),this.pointSizes.dispose(),this.pointIds.dispose(),this.contourVAO.dispose(),this.contourPositions.dispose(),this.contourShader.dispose()},e.exports=function(t,e){1===arguments.length&&(t=(e=t).gl);var r=t.getExtension(\"OES_standard_derivatives\")||t.getExtension(\"MOZ_OES_standard_derivatives\")||t.getExtension(\"WEBKIT_OES_standard_derivatives\");if(!r)throw new Error(\"derivatives not supported\");var n=A(t),s=S(t),l=E(t),c=C(t),f=L(t),h=I(t),p=o(t,u(new Uint8Array([255,255,255,255]),[1,1,4]));p.generateMipmap(),p.minFilter=t.LINEAR_MIPMAP_LINEAR,p.magFilter=t.LINEAR;var d=i(t),g=i(t),m=i(t),v=i(t),y=i(t),x=a(t,[{buffer:d,type:t.FLOAT,size:3},{buffer:y,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:g,type:t.FLOAT,size:4},{buffer:m,type:t.FLOAT,size:2},{buffer:v,type:t.FLOAT,size:3}]),b=i(t),_=i(t),w=i(t),k=i(t),M=a(t,[{buffer:b,type:t.FLOAT,size:3},{buffer:k,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:_,type:t.FLOAT,size:4},{buffer:w,type:t.FLOAT,size:2}]),P=i(t),z=i(t),O=i(t),D=i(t),R=i(t),F=a(t,[{buffer:P,type:t.FLOAT,size:3},{buffer:R,type:t.UNSIGNED_BYTE,size:4,normalized:!0},{buffer:z,type:t.FLOAT,size:4},{buffer:O,type:t.FLOAT,size:2},{buffer:D,type:t.FLOAT,size:1}]),B=i(t),N=a(t,[{buffer:B,type:t.FLOAT,size:3}]),j=new T(t,p,n,s,l,c,f,h,d,y,g,m,v,x,b,k,_,w,M,P,R,z,O,D,F,B,N);return j.update(e),j}},{\"./lib/closest-point\":307,\"./lib/shaders\":308,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-shader\":335,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,normals:498,\"simplicial-complex-contour\":556,\"typedarray-pool\":595}],310:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],311:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[0,0,0,1,1,0,1,1]),s=i(e,a.boxVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawBox=(s=[0,0],l=[0,0],function(t,e,r,n,i){var a=this.plot,o=this.shader,c=a.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,o.uniforms.lo=s,o.uniforms.hi=l,o.uniforms.color=i,c.drawArrays(c.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],312:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,o.gridVert,o.gridFrag),l=i(e,o.tickVert,o.gridFrag);return new s(t,r,a,l)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"binary-search-bounds\"),o=t(\"./shaders\");function s(t,e,r,n){this.plot=t,this.vbo=e,this.shader=r,this.tickShader=n,this.ticks=[[],[]]}function l(t,e){return t-e}var c,u,f,h,p,d=s.prototype;d.draw=(c=[0,0],u=[0,0],f=[0,0],function(){for(var t=this.plot,e=this.vbo,r=this.shader,n=this.ticks,i=t.gl,a=t._tickBounds,o=t.dataBox,s=t.viewBox,l=t.gridLineWidth,h=t.gridLineColor,p=t.gridLineEnable,d=t.pixelRatio,g=0;g<2;++g){var m=a[g],v=a[g+2]-m,y=.5*(o[g+2]+o[g]),x=o[g+2]-o[g];u[g]=2*v/x,c[g]=2*(m-y)/x}r.bind(),e.bind(),r.attributes.dataCoord.pointer(),r.uniforms.dataShift=c,r.uniforms.dataScale=u;var b=0;for(g=0;g<2;++g){f[0]=f[1]=0,f[g]=1,r.uniforms.dataAxis=f,r.uniforms.lineWidth=l[g]/(s[g+2]-s[g])*d,r.uniforms.color=h[g];var _=6*n[g].length;p[g]&&_&&i.drawArrays(i.TRIANGLES,b,_),b+=_}}),d.drawTickMarks=function(){var t=[0,0],e=[0,0],r=[1,0],n=[0,1],i=[0,0],o=[0,0];return function(){for(var s=this.plot,c=this.vbo,u=this.tickShader,f=this.ticks,h=s.gl,p=s._tickBounds,d=s.dataBox,g=s.viewBox,m=s.pixelRatio,v=s.screenBox,y=v[2]-v[0],x=v[3]-v[1],b=g[2]-g[0],_=g[3]-g[1],w=0;w<2;++w){var T=p[w],k=p[w+2]-T,M=.5*(d[w+2]+d[w]),A=d[w+2]-d[w];e[w]=2*k/A,t[w]=2*(T-M)/A}e[0]*=b/y,t[0]*=b/y,e[1]*=_/x,t[1]*=_/x,u.bind(),c.bind(),u.attributes.dataCoord.pointer();var S=u.uniforms;S.dataShift=t,S.dataScale=e;var E=s.tickMarkLength,C=s.tickMarkWidth,L=s.tickMarkColor,I=6*f[0].length,P=Math.min(a.ge(f[0],(d[0]-p[0])/(p[2]-p[0]),l),f[0].length),z=Math.min(a.gt(f[0],(d[2]-p[0])/(p[2]-p[0]),l),f[0].length),O=0+6*P,D=6*Math.max(0,z-P),R=Math.min(a.ge(f[1],(d[1]-p[1])/(p[3]-p[1]),l),f[1].length),F=Math.min(a.gt(f[1],(d[3]-p[1])/(p[3]-p[1]),l),f[1].length),B=I+6*R,N=6*Math.max(0,F-R);i[0]=2*(g[0]-E[1])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[1]*m/y,o[1]=C[1]*m/x,N&&(S.color=L[1],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[1]-E[0])/x-1,o[0]=C[0]*m/y,o[1]=E[0]*m/x,D&&(S.color=L[0],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D)),i[0]=2*(g[2]+E[3])/y-1,i[1]=(g[3]+g[1])/x-1,o[0]=E[3]*m/y,o[1]=C[3]*m/x,N&&(S.color=L[3],S.tickScale=o,S.dataAxis=n,S.screenOffset=i,h.drawArrays(h.TRIANGLES,B,N)),i[0]=(g[2]+g[0])/y-1,i[1]=2*(g[3]+E[2])/x-1,o[0]=C[2]*m/y,o[1]=E[2]*m/x,D&&(S.color=L[2],S.tickScale=o,S.dataAxis=r,S.screenOffset=i,h.drawArrays(h.TRIANGLES,O,D))}}(),d.update=(h=[1,1,-1,-1,1,-1],p=[1,-1,1,1,-1,-1],function(t){for(var e=t.ticks,r=t.bounds,n=new Float32Array(18*(e[0].length+e[1].length)),i=(this.plot.zeroLineEnable,0),a=[[],[]],o=0;o<2;++o)for(var s=a[o],l=e[o],c=r[o],u=r[o+2],f=0;f<l.length;++f){var d=(l[f].x-c)/(u-c);s.push(d);for(var g=0;g<6;++g)n[i++]=d,n[i++]=h[g],n[i++]=p[g]}this.ticks=a,this.vbo.update(n)}),d.dispose=function(){this.vbo.dispose(),this.shader.dispose(),this.tickShader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335}],313:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[-1,-1,-1,1,1,-1,1,1]),s=i(e,a.lineVert,a.lineFrag);return new o(t,r,s)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"./shaders\");function o(t,e,r){this.plot=t,this.vbo=e,this.shader=r}var s,l,c=o.prototype;c.bind=function(){var t=this.shader;this.vbo.bind(),this.shader.bind(),t.attributes.coord.pointer(),t.uniforms.screenBox=this.plot.screenBox},c.drawLine=(s=[0,0],l=[0,0],function(t,e,r,n,i,a){var o=this.plot,c=this.shader,u=o.gl;s[0]=t,s[1]=e,l[0]=r,l[1]=n,c.uniforms.start=s,c.uniforms.end=l,c.uniforms.width=i*o.pixelRatio,c.uniforms.color=a,u.drawArrays(u.TRIANGLE_STRIP,0,4)}),c.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"gl-buffer\":259,\"gl-shader\":335}],314:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision lowp float;\\n#define GLSLIFY 1\\nuniform vec4 color;\\nvoid main() {\\n  gl_FragColor = vec4(color.xyz * color.w, color.w);\\n}\\n\"]);e.exports={lineVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 start, end;\\nuniform float width;\\n\\nvec2 perp(vec2 v) {\\n  return vec2(v.y, -v.x);\\n}\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  vec2 delta = normalize(perp(start - end));\\n  vec2 offset = mix(start, end, 0.5 * (coord.y+1.0));\\n  gl_Position = vec4(screen(offset + 0.5 * width * delta * coord.x), 0, 1);\\n}\\n\"]),lineFrag:i,textVert:n([\"#define GLSLIFY 1\\nattribute vec3 textCoordinate;\\n\\nuniform vec2 dataScale, dataShift, dataAxis, screenOffset, textScale;\\nuniform float angle;\\n\\nvoid main() {\\n  float dataOffset  = textCoordinate.z;\\n  vec2 glyphOffset  = textCoordinate.xy;\\n  mat2 glyphMatrix = mat2(cos(angle), sin(angle), -sin(angle), cos(angle));\\n  vec2 screenCoordinate = dataAxis * (dataScale * dataOffset + dataShift) +\\n    glyphMatrix * glyphOffset * textScale + screenOffset;\\n  gl_Position = vec4(screenCoordinate, 0, 1);\\n}\\n\"]),textFrag:i,gridVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale;\\nuniform float lineWidth;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  pos += 10.0 * dataCoord.y * vec2(dataAxis.y, -dataAxis.x) + dataCoord.z * lineWidth;\\n  gl_Position = vec4(pos, 0, 1);\\n}\\n\"]),gridFrag:i,boxVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 coord;\\n\\nuniform vec4 screenBox;\\nuniform vec2 lo, hi;\\n\\nvec2 screen(vec2 v) {\\n  return 2.0 * (v - screenBox.xy) / (screenBox.zw - screenBox.xy) - 1.0;\\n}\\n\\nvoid main() {\\n  gl_Position = vec4(screen(mix(lo, hi, coord)), 0, 1);\\n}\\n\"]),tickVert:n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 dataCoord;\\n\\nuniform vec2 dataAxis, dataShift, dataScale, screenOffset, tickScale;\\n\\nvoid main() {\\n  vec2 pos = dataAxis * (dataScale * dataCoord.x + dataShift);\\n  gl_Position = vec4(pos + tickScale*dataCoord.yz + screenOffset, 0, 1);\\n}\\n\"])}},{glslify:316}],315:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e),a=i(e,s.textVert,s.textFrag);return new l(t,r,a)};var n=t(\"gl-buffer\"),i=t(\"gl-shader\"),a=t(\"text-cache\"),o=t(\"binary-search-bounds\"),s=t(\"./shaders\");function l(t,e,r){this.plot=t,this.vbo=e,this.shader=r,this.tickOffset=[[],[]],this.tickX=[[],[]],this.labelOffset=[0,0],this.labelCount=[0,0]}var c,u,f,h,p,d,g=l.prototype;g.drawTicks=(c=[0,0],u=[0,0],f=[0,0],function(t){var e=this.plot,r=this.shader,n=this.tickX[t],i=this.tickOffset[t],a=e.gl,s=e.viewBox,l=e.dataBox,h=e.screenBox,p=e.pixelRatio,d=e.tickEnable,g=e.tickPad,m=e.tickColor,v=e.tickAngle,y=e.labelEnable,x=e.labelPad,b=e.labelColor,_=e.labelAngle,w=this.labelOffset[t],T=this.labelCount[t],k=o.lt(n,l[t]),M=o.le(n,l[t+2]);c[0]=c[1]=0,c[t]=1,u[t]=(s[2+t]+s[t])/(h[2+t]-h[t])-1;var A=2/h[2+(1^t)]-h[1^t];u[1^t]=A*s[1^t]-1,d[t]&&(u[1^t]-=A*p*g[t],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t],r.uniforms.angle=v[t],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t]&&T&&(u[1^t]-=A*p*x[t],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t],r.uniforms.angle=_[t],a.drawArrays(a.TRIANGLES,w,T)),u[1^t]=A*s[2+(1^t)]-1,d[t+2]&&(u[1^t]+=A*p*g[t+2],k<M&&i[M]>i[k]&&(r.uniforms.dataAxis=c,r.uniforms.screenOffset=u,r.uniforms.color=m[t+2],r.uniforms.angle=v[t+2],a.drawArrays(a.TRIANGLES,i[k],i[M]-i[k]))),y[t+2]&&T&&(u[1^t]+=A*p*x[t+2],r.uniforms.dataAxis=f,r.uniforms.screenOffset=u,r.uniforms.color=b[t+2],r.uniforms.angle=_[t+2],a.drawArrays(a.TRIANGLES,w,T))}),g.drawTitle=function(){var t=[0,0],e=[0,0];return function(){var r=this.plot,n=this.shader,i=r.gl,a=r.screenBox,o=r.titleCenter,s=r.titleAngle,l=r.titleColor,c=r.pixelRatio;if(this.titleCount){for(var u=0;u<2;++u)e[u]=2*(o[u]*c-a[u])/(a[2+u]-a[u])-1;n.bind(),n.uniforms.dataAxis=t,n.uniforms.screenOffset=e,n.uniforms.angle=s,n.uniforms.color=l,i.drawArrays(i.TRIANGLES,this.titleOffset,this.titleCount)}}}(),g.bind=(h=[0,0],p=[0,0],d=[0,0],function(){var t=this.plot,e=this.shader,r=t._tickBounds,n=t.dataBox,i=t.screenBox,a=t.viewBox;e.bind();for(var o=0;o<2;++o){var s=r[o],l=r[o+2]-s,c=.5*(n[o+2]+n[o]),u=n[o+2]-n[o],f=a[o],g=a[o+2]-f,m=i[o],v=i[o+2]-m;p[o]=2*l/u*g/v,h[o]=2*(s-c)/u*g/v}d[1]=2*t.pixelRatio/(i[3]-i[1]),d[0]=d[1]*(i[3]-i[1])/(i[2]-i[0]),e.uniforms.dataScale=p,e.uniforms.dataShift=h,e.uniforms.textScale=d,this.vbo.bind(),e.attributes.textCoordinate.pointer()}),g.update=function(t){var e,r,n,i,o,s=[],l=t.ticks,c=t.bounds;for(o=0;o<2;++o){var u=[Math.floor(s.length/3)],f=[-1/0],h=l[o];for(e=0;e<h.length;++e){var p=h[e],d=p.x,g=p.text,m=p.font||\"sans-serif\";i=p.fontSize||12;for(var v=1/(c[o+2]-c[o]),y=c[o],x=g.split(\"\\n\"),b=0;b<x.length;b++)for(n=a(m,x[b]).data,r=0;r<n.length;r+=2)s.push(n[r]*i,-n[r+1]*i-b*i*1.2,(d-y)*v);u.push(Math.floor(s.length/3)),f.push(d)}this.tickOffset[o]=u,this.tickX[o]=f}for(o=0;o<2;++o){for(this.labelOffset[o]=Math.floor(s.length/3),n=a(t.labelFont[o],t.labels[o],{textAlign:\"center\"}).data,i=t.labelSize[o],e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.labelCount[o]=Math.floor(s.length/3)-this.labelOffset[o]}for(this.titleOffset=Math.floor(s.length/3),n=a(t.titleFont,t.title).data,i=t.titleSize,e=0;e<n.length;e+=2)s.push(n[e]*i,-n[e+1]*i,0);this.titleCount=Math.floor(s.length/3)-this.titleOffset,this.vbo.update(s)},g.dispose=function(){this.vbo.dispose(),this.shader.dispose()}},{\"./shaders\":314,\"binary-search-bounds\":96,\"gl-buffer\":259,\"gl-shader\":335,\"text-cache\":575}],316:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],317:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=n(e,[e.drawingBufferWidth,e.drawingBufferHeight]),c=new l(e,r);return c.grid=i(c),c.text=a(c),c.line=o(c),c.box=s(c),c.update(t),c};var n=t(\"gl-select-static\"),i=t(\"./lib/grid\"),a=t(\"./lib/text\"),o=t(\"./lib/line\"),s=t(\"./lib/box\");function l(t,e){this.gl=t,this.pickBuffer=e,this.screenBox=[0,0,t.drawingBufferWidth,t.drawingBufferHeight],this.viewBox=[0,0,0,0],this.dataBox=[-10,-10,10,10],this.gridLineEnable=[!0,!0],this.gridLineWidth=[1,1],this.gridLineColor=[[0,0,0,1],[0,0,0,1]],this.pixelRatio=1,this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickEnable=[!0,!0,!0,!0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[15,15,15,15],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelEnable=[!0,!0,!0,!0],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.titleCenter=[0,0],this.titleEnable=!0,this.titleAngle=0,this.titleColor=[0,0,0,1],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[4,4],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderLineEnable=[!0,!0,!0,!0],this.borderLineWidth=[2,2,2,2],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.grid=null,this.text=null,this.line=null,this.box=null,this.objects=[],this.overlays=[],this._tickBounds=[1/0,1/0,-1/0,-1/0],this.static=!1,this.dirty=!1,this.pickDirty=!1,this.pickDelay=120,this.pickRadius=10,this._pickTimeout=null,this._drawPick=this.drawPick.bind(this),this._depthCounter=0}var c=l.prototype;function u(t){for(var e=t.slice(),r=0;r<e.length;++r)e[r]=e[r].slice();return e}function f(t,e){return t.x-e.x}c.setDirty=function(){this.dirty=this.pickDirty=!0},c.setOverlayDirty=function(){this.dirty=!0},c.nextDepthValue=function(){return this._depthCounter++/65536},c.draw=function(){var t=this.gl,e=this.screenBox,r=this.viewBox,n=this.dataBox,i=this.pixelRatio,a=this.grid,o=this.line,s=this.text,l=this.objects;if(this._depthCounter=0,this.pickDirty&&(this._pickTimeout&&clearTimeout(this._pickTimeout),this.pickDirty=!1,this._pickTimeout=setTimeout(this._drawPick,this.pickDelay)),this.dirty){if(this.dirty=!1,t.bindFramebuffer(t.FRAMEBUFFER,null),t.enable(t.SCISSOR_TEST),t.disable(t.DEPTH_TEST),t.depthFunc(t.LESS),t.depthMask(!1),t.enable(t.BLEND),t.blendEquation(t.FUNC_ADD,t.FUNC_ADD),t.blendFunc(t.ONE,t.ONE_MINUS_SRC_ALPHA),this.borderColor){t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]);var c=this.borderColor;t.clearColor(c[0]*c[3],c[1]*c[3],c[2]*c[3],c[3]),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT)}t.scissor(r[0],r[1],r[2]-r[0],r[3]-r[1]),t.viewport(r[0],r[1],r[2]-r[0],r[3]-r[1]);var u=this.backgroundColor;t.clearColor(u[0]*u[3],u[1]*u[3],u[2]*u[3],u[3]),t.clear(t.COLOR_BUFFER_BIT),a.draw();var f=this.zeroLineEnable,h=this.zeroLineColor,p=this.zeroLineWidth;if(f[0]||f[1]){o.bind();for(var d=0;d<2;++d)if(f[d]&&n[d]<=0&&n[d+2]>=0){var g=e[d]-n[d]*(e[d+2]-e[d])/(n[d+2]-n[d]);0===d?o.drawLine(g,e[1],g,e[3],p[d],h[d]):o.drawLine(e[0],g,e[2],g,p[d],h[d])}}for(d=0;d<l.length;++d)l[d].draw();t.viewport(e[0],e[1],e[2]-e[0],e[3]-e[1]),t.scissor(e[0],e[1],e[2]-e[0],e[3]-e[1]),this.grid.drawTickMarks(),o.bind();var m=this.borderLineEnable,v=this.borderLineWidth,y=this.borderLineColor;for(m[1]&&o.drawLine(r[0],r[1]-.5*v[1]*i,r[0],r[3]+.5*v[3]*i,v[1],y[1]),m[0]&&o.drawLine(r[0]-.5*v[0]*i,r[1],r[2]+.5*v[2]*i,r[1],v[0],y[0]),m[3]&&o.drawLine(r[2],r[1]-.5*v[1]*i,r[2],r[3]+.5*v[3]*i,v[3],y[3]),m[2]&&o.drawLine(r[0]-.5*v[0]*i,r[3],r[2]+.5*v[2]*i,r[3],v[2],y[2]),s.bind(),d=0;d<2;++d)s.drawTicks(d);this.titleEnable&&s.drawTitle();var x=this.overlays;for(d=0;d<x.length;++d)x[d].draw();t.disable(t.SCISSOR_TEST),t.disable(t.BLEND),t.depthMask(!0)}},c.drawPick=function(){if(!this.static){var t=this.pickBuffer;this.gl,this._pickTimeout=null,t.begin();for(var e=1,r=this.objects,n=0;n<r.length;++n)e=r[n].drawPick(e);t.end()}},c.pick=function(t,e){if(!this.static){var r=this.pixelRatio,n=this.pickPixelRatio,i=this.viewBox,a=0|Math.round((t-i[0]/r)*n),o=0|Math.round((e-i[1]/r)*n),s=this.pickBuffer.query(a,o,this.pickRadius);if(!s)return null;for(var l=s.id+(s.value[0]<<8)+(s.value[1]<<16)+(s.value[2]<<24),c=this.objects,u=0;u<c.length;++u){var f=c[u].pick(a,o,l);if(f)return f}return null}},c.setScreenBox=function(t){var e=this.screenBox,r=this.pixelRatio;e[0]=0|Math.round(t[0]*r),e[1]=0|Math.round(t[1]*r),e[2]=0|Math.round(t[2]*r),e[3]=0|Math.round(t[3]*r),this.setDirty()},c.setDataBox=function(t){var e=this.dataBox;(e[0]!==t[0]||e[1]!==t[1]||e[2]!==t[2]||e[3]!==t[3])&&(e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],this.setDirty())},c.setViewBox=function(t){var e=this.pixelRatio,r=this.viewBox;r[0]=0|Math.round(t[0]*e),r[1]=0|Math.round(t[1]*e),r[2]=0|Math.round(t[2]*e),r[3]=0|Math.round(t[3]*e);var n=this.pickPixelRatio;this.pickBuffer.shape=[0|Math.round((t[2]-t[0])*n),0|Math.round((t[3]-t[1])*n)],this.setDirty()},c.update=function(t){t=t||{};var e=this.gl;this.pixelRatio=t.pixelRatio||1;var r=this.pixelRatio;this.pickPixelRatio=Math.max(r,1),this.setScreenBox(t.screenBox||[0,0,e.drawingBufferWidth/r,e.drawingBufferHeight/r]);this.screenBox;this.setViewBox(t.viewBox||[.125*(this.screenBox[2]-this.screenBox[0])/r,.125*(this.screenBox[3]-this.screenBox[1])/r,.875*(this.screenBox[2]-this.screenBox[0])/r,.875*(this.screenBox[3]-this.screenBox[1])/r]);var n=this.viewBox,i=(n[2]-n[0])/(n[3]-n[1]);this.setDataBox(t.dataBox||[-10,-10/i,10,10/i]),this.borderColor=!1!==t.borderColor&&(t.borderColor||[0,0,0,0]).slice(),this.backgroundColor=(t.backgroundColor||[0,0,0,0]).slice(),this.gridLineEnable=(t.gridLineEnable||[!0,!0]).slice(),this.gridLineWidth=(t.gridLineWidth||[1,1]).slice(),this.gridLineColor=u(t.gridLineColor||[[.5,.5,.5,1],[.5,.5,.5,1]]),this.zeroLineEnable=(t.zeroLineEnable||[!0,!0]).slice(),this.zeroLineWidth=(t.zeroLineWidth||[4,4]).slice(),this.zeroLineColor=u(t.zeroLineColor||[[0,0,0,1],[0,0,0,1]]),this.tickMarkLength=(t.tickMarkLength||[0,0,0,0]).slice(),this.tickMarkWidth=(t.tickMarkWidth||[0,0,0,0]).slice(),this.tickMarkColor=u(t.tickMarkColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.titleCenter=(t.titleCenter||[.5*(n[0]+n[2])/r,(n[3]+120)/r]).slice(),this.titleEnable=!(\"titleEnable\"in t)||!!t.titleEnable,this.titleAngle=t.titleAngle||0,this.titleColor=(t.titleColor||[0,0,0,1]).slice(),this.labelPad=(t.labelPad||[15,15,15,15]).slice(),this.labelAngle=(t.labelAngle||[0,Math.PI/2,0,3*Math.PI/2]).slice(),this.labelEnable=(t.labelEnable||[!0,!0,!0,!0]).slice(),this.labelColor=u(t.labelColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.tickPad=(t.tickPad||[15,15,15,15]).slice(),this.tickAngle=(t.tickAngle||[0,0,0,0]).slice(),this.tickEnable=(t.tickEnable||[!0,!0,!0,!0]).slice(),this.tickColor=u(t.tickColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]),this.borderLineEnable=(t.borderLineEnable||[!0,!0,!0,!0]).slice(),this.borderLineWidth=(t.borderLineWidth||[2,2,2,2]).slice(),this.borderLineColor=u(t.borderLineColor||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]);var a=t.ticks||[[],[]],o=this._tickBounds;o[0]=o[1]=1/0,o[2]=o[3]=-1/0;for(var s=0;s<2;++s){var l=a[s].slice(0);0!==l.length&&(l.sort(f),o[s]=Math.min(o[s],l[0].x),o[s+2]=Math.max(o[s+2],l[l.length-1].x))}this.grid.update({bounds:o,ticks:a}),this.text.update({bounds:o,ticks:a,labels:t.labels||[\"x\",\"y\"],labelSize:t.labelSize||[12,12],labelFont:t.labelFont||[\"sans-serif\",\"sans-serif\"],title:t.title||\"\",titleSize:t.titleSize||18,titleFont:t.titleFont||\"sans-serif\"}),this.static=!!t.static,this.setDirty()},c.dispose=function(){this.box.dispose(),this.grid.dispose(),this.text.dispose(),this.line.dispose();for(var t=this.objects.length-1;t>=0;--t)this.objects[t].dispose();this.objects.length=0;for(t=this.overlays.length-1;t>=0;--t)this.overlays[t].dispose();this.overlays.length=0,this.gl=null},c.addObject=function(t){this.objects.indexOf(t)<0&&(this.objects.push(t),this.setDirty())},c.removeObject=function(t){for(var e=this.objects,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setDirty();break}},c.addOverlay=function(t){this.overlays.indexOf(t)<0&&(this.overlays.push(t),this.setOverlayDirty())},c.removeOverlay=function(t){for(var e=this.overlays,r=0;r<e.length;++r)if(e[r]===t){e.splice(r,1),this.setOverlayDirty();break}}},{\"./lib/box\":311,\"./lib/grid\":312,\"./lib/line\":313,\"./lib/text\":315,\"gl-select-static\":334}],318:[function(t,e,r){\"use strict\";e.exports=function(t,e){t=t||document.body,e=e||{};var r=[.01,1/0];\"distanceLimits\"in e&&(r[0]=e.distanceLimits[0],r[1]=e.distanceLimits[1]);\"zoomMin\"in e&&(r[0]=e.zoomMin);\"zoomMax\"in e&&(r[1]=e.zoomMax);var c=i({center:e.center||[0,0,0],up:e.up||[0,1,0],eye:e.eye||[0,0,10],mode:e.mode||\"orbit\",distanceLimits:r}),u=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],f=0,h=t.clientWidth,p=t.clientHeight,d={keyBindingMode:\"rotate\",enableWheel:!0,view:c,element:t,delay:e.delay||16,rotateSpeed:e.rotateSpeed||1,zoomSpeed:e.zoomSpeed||1,translateSpeed:e.translateSpeed||1,flipX:!!e.flipX,flipY:!!e.flipY,modes:c.modes,_ortho:e._ortho||e.projection&&\"orthographic\"===e.projection.type||!1,tick:function(){var e=n(),r=this.delay,i=e-2*r;c.idle(e-r),c.recalcMatrix(i),c.flush(e-(100+2*r));for(var a=!0,o=c.computedMatrix,s=0;s<16;++s)a=a&&u[s]===o[s],u[s]=o[s];var l=t.clientWidth===h&&t.clientHeight===p;return h=t.clientWidth,p=t.clientHeight,a?!l:(f=Math.exp(c.computedRadius[0]),!0)},lookAt:function(t,e,r){c.lookAt(c.lastT(),t,e,r)},rotate:function(t,e,r){c.rotate(c.lastT(),t,e,r)},pan:function(t,e,r){c.pan(c.lastT(),t,e,r)},translate:function(t,e,r){c.translate(c.lastT(),t,e,r)}};return Object.defineProperties(d,{matrix:{get:function(){return c.computedMatrix},set:function(t){return c.setMatrix(c.lastT(),t),c.computedMatrix},enumerable:!0},mode:{get:function(){return c.getMode()},set:function(t){var e=c.computedUp.slice(),r=c.computedEye.slice(),i=c.computedCenter.slice();if(c.setMode(t),\"turntable\"===t){var a=n();c._active.lookAt(a,r,i,e),c._active.lookAt(a+500,r,i,[0,0,1]),c._active.flush(a)}return c.getMode()},enumerable:!0},center:{get:function(){return c.computedCenter},set:function(t){return c.lookAt(c.lastT(),null,t),c.computedCenter},enumerable:!0},eye:{get:function(){return c.computedEye},set:function(t){return c.lookAt(c.lastT(),t),c.computedEye},enumerable:!0},up:{get:function(){return c.computedUp},set:function(t){return c.lookAt(c.lastT(),null,null,t),c.computedUp},enumerable:!0},distance:{get:function(){return f},set:function(t){return c.setDistance(c.lastT(),t),t},enumerable:!0},distanceLimits:{get:function(){return c.getDistanceLimits(r)},set:function(t){return c.setDistanceLimits(t),t},enumerable:!0}}),t.addEventListener(\"contextmenu\",(function(t){return t.preventDefault(),!1})),d._lastX=-1,d._lastY=-1,d._lastMods={shift:!1,control:!1,alt:!1,meta:!1},d.enableMouseListeners=function(){function e(e,r,i,a){var o=d.keyBindingMode;if(!1!==o){var s=\"rotate\"===o,l=\"pan\"===o,u=\"zoom\"===o,h=!!a.control,p=!!a.alt,g=!!a.shift,m=!!(1&e),v=!!(2&e),y=!!(4&e),x=1/t.clientHeight,b=x*(r-d._lastX),_=x*(i-d._lastY),w=d.flipX?1:-1,T=d.flipY?1:-1,k=Math.PI*d.rotateSpeed,M=n();if(-1!==d._lastX&&-1!==d._lastY&&((s&&m&&!h&&!p&&!g||m&&!h&&!p&&g)&&c.rotate(M,w*k*b,-T*k*_,0),(l&&m&&!h&&!p&&!g||v||m&&h&&!p&&!g)&&c.pan(M,-d.translateSpeed*b*f,d.translateSpeed*_*f,0),u&&m&&!h&&!p&&!g||y||m&&!h&&p&&!g)){var A=-d.zoomSpeed*_/window.innerHeight*(M-c.lastT())*100;c.pan(M,0,0,f*(Math.exp(A)-1))}return d._lastX=r,d._lastY=i,d._lastMods=a,!0}}d.mouseListener=a(t,e),t.addEventListener(\"touchstart\",(function(r){var n=s(r.changedTouches[0],t);e(0,n[0],n[1],d._lastMods),e(1,n[0],n[1],d._lastMods)}),!!l&&{passive:!0}),t.addEventListener(\"touchmove\",(function(r){var n=s(r.changedTouches[0],t);e(1,n[0],n[1],d._lastMods),r.preventDefault()}),!!l&&{passive:!1}),t.addEventListener(\"touchend\",(function(t){e(0,d._lastX,d._lastY,d._lastMods)}),!!l&&{passive:!0}),d.wheelListener=o(t,(function(t,e){if(!1!==d.keyBindingMode&&d.enableWheel){var r=d.flipX?1:-1,i=d.flipY?1:-1,a=n();if(Math.abs(t)>Math.abs(e))c.rotate(a,0,0,-t*r*Math.PI*d.rotateSpeed/window.innerWidth);else if(!d._ortho){var o=-d.zoomSpeed*i*e/window.innerHeight*(a-c.lastT())/20;c.pan(a,0,0,f*(Math.exp(o)-1))}}}),!0)},d.enableMouseListeners(),d};var n=t(\"right-now\"),i=t(\"3d-view\"),a=t(\"mouse-change\"),o=t(\"mouse-wheel\"),s=t(\"mouse-event-offset\"),l=t(\"has-passive-events\")},{\"3d-view\":54,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486,\"right-now\":542}],319:[function(t,e,r){var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\nattribute vec2 position;\\nvarying vec2 uv;\\nvoid main() {\\n  uv = position;\\n  gl_Position = vec4(position, 0, 1);\\n}\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D accumBuffer;\\nvarying vec2 uv;\\n\\nvoid main() {\\n  vec4 accum = texture2D(accumBuffer, 0.5 * (uv + 1.0));\\n  gl_FragColor = min(vec4(1,1,1,1), accum);\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec2\"}])}},{\"gl-shader\":335,glslify:320}],320:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],321:[function(t,e,r){\"use strict\";var n=t(\"./camera.js\"),i=t(\"gl-axes3d\"),a=t(\"gl-axes3d/properties\"),o=t(\"gl-spikes3d\"),s=t(\"gl-select-static\"),l=t(\"gl-fbo\"),c=t(\"a-big-triangle\"),u=t(\"mouse-change\"),f=t(\"gl-mat4/perspective\"),h=t(\"gl-mat4/ortho\"),p=t(\"./lib/shader\"),d=t(\"is-mobile\")({tablet:!0,featureDetect:!0});function g(){this.mouse=[-1,-1],this.screen=null,this.distance=1/0,this.index=null,this.dataCoordinate=null,this.dataPosition=null,this.object=null,this.data=null}function m(t){var e=Math.round(Math.log(Math.abs(t))/Math.log(10));if(e<0){var r=Math.round(Math.pow(10,-e));return Math.ceil(t*r)/r}if(e>0){r=Math.round(Math.pow(10,e));return Math.ceil(t/r)*r}return Math.ceil(t)}function v(t){return\"boolean\"!=typeof t||t}e.exports={createScene:function(t){(t=t||{}).camera=t.camera||{};var e=t.canvas;if(!e){if(e=document.createElement(\"canvas\"),t.container)t.container.appendChild(e);else document.body.appendChild(e)}var r=t.gl;r||(t.glOptions&&(d=!!t.glOptions.preserveDrawingBuffer),r=function(t,e){var r=null;try{(r=t.getContext(\"webgl\",e))||(r=t.getContext(\"experimental-webgl\",e))}catch(t){return null}return r}(e,t.glOptions||{premultipliedAlpha:!0,antialias:!0,preserveDrawingBuffer:d}));if(!r)throw new Error(\"webgl not supported\");var y=t.bounds||[[-10,-10,-10],[10,10,10]],x=new g,b=l(r,r.drawingBufferWidth,r.drawingBufferHeight,{preferFloat:!d}),_=p(r),w=t.cameraObject&&!0===t.cameraObject._ortho||t.camera.projection&&\"orthographic\"===t.camera.projection.type||!1,T={eye:t.camera.eye||[2,0,0],center:t.camera.center||[0,0,0],up:t.camera.up||[0,1,0],zoomMin:t.camera.zoomMax||.1,zoomMax:t.camera.zoomMin||100,mode:t.camera.mode||\"turntable\",_ortho:w},k=t.axes||{},M=i(r,k);M.enable=!k.disable;var A=t.spikes||{},S=o(r,A),E=[],C=[],L=[],I=[],P=!0,z=!0,O=new Array(16),D=new Array(16),R={view:null,projection:O,model:D,_ortho:!1},F=(z=!0,[r.drawingBufferWidth,r.drawingBufferHeight]),B=t.cameraObject||n(e,T),N={gl:r,contextLost:!1,pixelRatio:t.pixelRatio||1,canvas:e,selection:x,camera:B,axes:M,axesPixels:null,spikes:S,bounds:y,objects:E,shape:F,aspect:t.aspectRatio||[1,1,1],pickRadius:t.pickRadius||10,zNear:t.zNear||.01,zFar:t.zFar||1e3,fovy:t.fovy||Math.PI/4,clearColor:t.clearColor||[0,0,0,0],autoResize:v(t.autoResize),autoBounds:v(t.autoBounds),autoScale:!!t.autoScale,autoCenter:v(t.autoCenter),clipToBounds:v(t.clipToBounds),snapToData:!!t.snapToData,onselect:t.onselect||null,onrender:t.onrender||null,onclick:t.onclick||null,cameraParams:R,oncontextloss:null,mouseListener:null,_stopped:!1,getAspectratio:function(){return{x:this.aspect[0],y:this.aspect[1],z:this.aspect[2]}},setAspectratio:function(t){this.aspect[0]=t.x,this.aspect[1]=t.y,this.aspect[2]=t.z,z=!0},setBounds:function(t,e){this.bounds[0][t]=e.min,this.bounds[1][t]=e.max},setClearColor:function(t){this.clearColor=t},clearRGBA:function(){this.gl.clearColor(this.clearColor[0],this.clearColor[1],this.clearColor[2],this.clearColor[3]),this.gl.clear(this.gl.COLOR_BUFFER_BIT|this.gl.DEPTH_BUFFER_BIT)}},j=[r.drawingBufferWidth/N.pixelRatio|0,r.drawingBufferHeight/N.pixelRatio|0];function U(){if(!N._stopped&&N.autoResize){var t=e.parentNode,r=1,n=1;t&&t!==document.body?(r=t.clientWidth,n=t.clientHeight):(r=window.innerWidth,n=window.innerHeight);var i=0|Math.ceil(r*N.pixelRatio),a=0|Math.ceil(n*N.pixelRatio);if(i!==e.width||a!==e.height){e.width=i,e.height=a;var o=e.style;o.position=o.position||\"absolute\",o.left=\"0px\",o.top=\"0px\",o.width=r+\"px\",o.height=n+\"px\",P=!0}}}N.autoResize&&U();function V(){for(var t=E.length,e=I.length,n=0;n<e;++n)L[n]=0;t:for(n=0;n<t;++n){var i=E[n],a=i.pickSlots;if(a){for(var o=0;o<e;++o)if(L[o]+a<255){C[n]=o,i.setPickBase(L[o]+1),L[o]+=a;continue t}var l=s(r,F);C[n]=e,I.push(l),L.push(a),i.setPickBase(1),e+=1}else C[n]=-1}for(;e>0&&0===L[e-1];)L.pop(),I.pop().dispose()}function q(){if(N.contextLost)return!0;r.isContextLost()&&(N.contextLost=!0,N.mouseListener.enabled=!1,N.selection.object=null,N.oncontextloss&&N.oncontextloss())}window.addEventListener(\"resize\",U),N.update=function(t){N._stopped||(t=t||{},P=!0,z=!0)},N.add=function(t){N._stopped||(t.axes=M,E.push(t),C.push(-1),P=!0,z=!0,V())},N.remove=function(t){if(!N._stopped){var e=E.indexOf(t);e<0||(E.splice(e,1),C.pop(),P=!0,z=!0,V())}},N.dispose=function(){if(!N._stopped&&(N._stopped=!0,window.removeEventListener(\"resize\",U),e.removeEventListener(\"webglcontextlost\",q),N.mouseListener.enabled=!1,!N.contextLost)){M.dispose(),S.dispose();for(var t=0;t<E.length;++t)E[t].dispose();b.dispose();for(t=0;t<I.length;++t)I[t].dispose();_.dispose(),r=null,M=null,S=null,E=[]}},N._mouseRotating=!1,N._prevButtons=0,N.enableMouseListeners=function(){N.mouseListener=u(e,(function(t,e,r){if(!N._stopped){var n=I.length,i=E.length,a=x.object;x.distance=1/0,x.mouse[0]=e,x.mouse[1]=r,x.object=null,x.screen=null,x.dataCoordinate=x.dataPosition=null;var o=!1;if(t&&N._prevButtons)N._mouseRotating=!0;else{N._mouseRotating&&(z=!0),N._mouseRotating=!1;for(var s=0;s<n;++s){var l=I[s].query(e,j[1]-r-1,N.pickRadius);if(l){if(l.distance>x.distance)continue;for(var c=0;c<i;++c){var u=E[c];if(C[c]===s){var f=u.pick(l);f&&(x.buttons=t,x.screen=l.coord,x.distance=l.distance,x.object=u,x.index=f.distance,x.dataPosition=f.position,x.dataCoordinate=f.dataCoordinate,x.data=f,o=!0)}}}}}a&&a!==x.object&&(a.highlight&&a.highlight(null),P=!0),x.object&&(x.object.highlight&&x.object.highlight(x.data),P=!0),(o=o||x.object!==a)&&N.onselect&&N.onselect(x),1&t&&!(1&N._prevButtons)&&N.onclick&&N.onclick(x),N._prevButtons=t}}))},e.addEventListener(\"webglcontextlost\",q);var H=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],G=[H[0].slice(),H[1].slice()];function Y(){if(!q()){U();var t=N.camera.tick();R.view=N.camera.matrix,P=P||t,z=z||t,M.pixelRatio=N.pixelRatio,S.pixelRatio=N.pixelRatio;var e=E.length,n=H[0],i=H[1];n[0]=n[1]=n[2]=1/0,i[0]=i[1]=i[2]=-1/0;for(var o=0;o<e;++o){(L=E[o]).pixelRatio=N.pixelRatio,L.axes=N.axes,P=P||!!L.dirty,z=z||!!L.dirty;var s=L.bounds;if(s)for(var l=s[0],u=s[1],p=0;p<3;++p)n[p]=Math.min(n[p],l[p]),i[p]=Math.max(i[p],u[p])}var d=N.bounds;if(N.autoBounds)for(p=0;p<3;++p){if(i[p]<n[p])n[p]=-1,i[p]=1;else{n[p]===i[p]&&(n[p]-=1,i[p]+=1);var g=.05*(i[p]-n[p]);n[p]=n[p]-g,i[p]=i[p]+g}d[0][p]=n[p],d[1][p]=i[p]}var v=!1;for(p=0;p<3;++p)v=v||G[0][p]!==d[0][p]||G[1][p]!==d[1][p],G[0][p]=d[0][p],G[1][p]=d[1][p];if(z=z||v,P=P||v){if(v){var y=[0,0,0];for(o=0;o<3;++o)y[o]=m((d[1][o]-d[0][o])/10);M.autoTicks?M.update({bounds:d,tickSpacing:y}):M.update({bounds:d})}var T=r.drawingBufferWidth,k=r.drawingBufferHeight;F[0]=T,F[1]=k,j[0]=0|Math.max(T/N.pixelRatio,1),j[1]=0|Math.max(k/N.pixelRatio,1),function(t,e){var r=t.bounds,n=t.cameraParams,i=n.projection,a=n.model,o=t.gl.drawingBufferWidth,s=t.gl.drawingBufferHeight,l=t.zNear,c=t.zFar,u=t.fovy,p=o/s;e?(h(i,-p,p,-1,1,l,c),n._ortho=!0):(f(i,u,p,l,c),n._ortho=!1);for(var d=0;d<16;++d)a[d]=0;a[15]=1;var g=0;for(d=0;d<3;++d)g=Math.max(g,r[1][d]-r[0][d]);for(d=0;d<3;++d)t.autoScale?a[5*d]=t.aspect[d]/(r[1][d]-r[0][d]):a[5*d]=1/g,t.autoCenter&&(a[12+d]=.5*-a[5*d]*(r[0][d]+r[1][d]))}(N,w);for(o=0;o<e;++o){(L=E[o]).axesBounds=d,N.clipToBounds&&(L.clipBounds=d)}x.object&&(N.snapToData?S.position=x.dataCoordinate:S.position=x.dataPosition,S.bounds=d),z&&(z=!1,function(){if(!q()){r.colorMask(!0,!0,!0,!0),r.depthMask(!0),r.disable(r.BLEND),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL);for(var t=E.length,e=I.length,n=0;n<e;++n){var i=I[n];i.shape=j,i.begin();for(var a=0;a<t;++a)if(C[a]===n){var o=E[a];o.drawPick&&(o.pixelRatio=1,o.drawPick(R))}i.end()}}}()),N.axesPixels=a(N.axes,R,T,k),N.onrender&&N.onrender(),r.bindFramebuffer(r.FRAMEBUFFER,null),r.viewport(0,0,T,k),N.clearRGBA(),r.depthMask(!0),r.colorMask(!0,!0,!0,!0),r.enable(r.DEPTH_TEST),r.depthFunc(r.LEQUAL),r.disable(r.BLEND),r.disable(r.CULL_FACE);var A=!1;M.enable&&(A=A||M.isTransparent(),M.draw(R)),S.axes=M,x.object&&S.draw(R),r.disable(r.CULL_FACE);for(o=0;o<e;++o){(L=E[o]).axes=M,L.pixelRatio=N.pixelRatio,L.isOpaque&&L.isOpaque()&&L.draw(R),L.isTransparent&&L.isTransparent()&&(A=!0)}if(A){b.shape=F,b.bind(),r.clear(r.DEPTH_BUFFER_BIT),r.colorMask(!1,!1,!1,!1),r.depthMask(!0),r.depthFunc(r.LESS),M.enable&&M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){(L=E[o]).isOpaque&&L.isOpaque()&&L.draw(R)}r.enable(r.BLEND),r.blendEquation(r.FUNC_ADD),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.colorMask(!0,!0,!0,!0),r.depthMask(!1),r.clearColor(0,0,0,0),r.clear(r.COLOR_BUFFER_BIT),M.isTransparent()&&M.drawTransparent(R);for(o=0;o<e;++o){var L;(L=E[o]).isTransparent&&L.isTransparent()&&L.drawTransparent(R)}r.bindFramebuffer(r.FRAMEBUFFER,null),r.blendFunc(r.ONE,r.ONE_MINUS_SRC_ALPHA),r.disable(r.DEPTH_TEST),_.bind(),b.color[0].bind(0),_.uniforms.accumBuffer=0,c(r),r.disable(r.BLEND)}P=!1;for(o=0;o<e;++o)E[o].dirty=!1}}}return N.enableMouseListeners(),function t(){if(N._stopped||N.contextLost)return;Y(),requestAnimationFrame(t)}(),N.redraw=function(){N._stopped||(P=!0,Y())},N},createCamera:n}},{\"./camera.js\":318,\"./lib/shader\":319,\"a-big-triangle\":64,\"gl-axes3d\":250,\"gl-axes3d/properties\":258,\"gl-fbo\":269,\"gl-mat4/ortho\":296,\"gl-mat4/perspective\":297,\"gl-select-static\":334,\"gl-spikes3d\":345,\"is-mobile\":467,\"mouse-change\":483}],322:[function(t,e,r){var n=t(\"glslify\");r.pointVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform float pointCloud;\\n\\nhighp float rand(vec2 co) {\\n  highp float a = 12.9898;\\n  highp float b = 78.233;\\n  highp float c = 43758.5453;\\n  highp float d = dot(co.xy, vec2(a, b));\\n  highp float e = mod(d, 3.14);\\n  return fract(sin(e) * c);\\n}\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n    // if we don't jitter the point size a bit, overall point cloud\\n    // saturation 'jumps' on zooming, which is disturbing and confusing\\n  gl_PointSize = pointSize * ((19.5 + rand(position)) / 20.0);\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    // get the same square surface as circle would be\\n    gl_PointSize *= 0.886;\\n  }\\n}\"]),r.pointFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color, borderColor;\\nuniform float centerFraction;\\nuniform float pointCloud;\\n\\nvoid main() {\\n  float radius;\\n  vec4 baseColor;\\n  if(pointCloud != 0.0) { // pointCloud is truthy\\n    if(centerFraction == 1.0) {\\n      gl_FragColor = color;\\n    } else {\\n      gl_FragColor = mix(borderColor, color, centerFraction);\\n    }\\n  } else {\\n    radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n    if(radius > 1.0) {\\n      discard;\\n    }\\n    baseColor = mix(borderColor, color, step(radius, centerFraction));\\n    gl_FragColor = vec4(baseColor.rgb * baseColor.a, baseColor.a);\\n  }\\n}\\n\"]),r.pickVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position;\\nattribute vec4 pickId;\\n\\nuniform mat3 matrix;\\nuniform float pointSize;\\nuniform vec4 pickOffset;\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  vec3 hgPosition = matrix * vec3(position, 1);\\n  gl_Position  = vec4(hgPosition.xy, 0, hgPosition.z);\\n  gl_PointSize = pointSize;\\n\\n  vec4 id = pickId + pickOffset;\\n  id.y += floor(id.x / 256.0);\\n  id.x -= floor(id.x / 256.0) * 256.0;\\n\\n  id.z += floor(id.y / 256.0);\\n  id.y -= floor(id.y / 256.0) * 256.0;\\n\\n  id.w += floor(id.z / 256.0);\\n  id.z -= floor(id.z / 256.0) * 256.0;\\n\\n  fragId = id;\\n}\\n\"]),r.pickFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragId;\\n\\nvoid main() {\\n  float radius = length(2.0 * gl_PointCoord.xy - 1.0);\\n  if(radius > 1.0) {\\n    discard;\\n  }\\n  gl_FragColor = fragId / 255.0;\\n}\\n\"])},{glslify:323}],323:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],324:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"typedarray-pool\"),o=t(\"./lib/shader\");function s(t,e,r,n,i){this.plot=t,this.offsetBuffer=e,this.pickBuffer=r,this.shader=n,this.pickShader=i,this.sizeMin=.5,this.sizeMinCap=2,this.sizeMax=20,this.areaRatio=1,this.pointCount=0,this.color=[1,0,0,1],this.borderColor=[0,0,0,1],this.blend=!1,this.pickOffset=0,this.points=null}e.exports=function(t,e){var r=t.gl,a=i(r),l=i(r),c=n(r,o.pointVertex,o.pointFragment),u=n(r,o.pickVertex,o.pickFragment),f=new s(t,a,l,c,u);return f.update(e),t.addObject(f),f};var l,c,u=s.prototype;u.dispose=function(){this.shader.dispose(),this.pickShader.dispose(),this.offsetBuffer.dispose(),this.pickBuffer.dispose(),this.plot.removeObject(this)},u.update=function(t){var e;function r(e,r){return e in t?t[e]:r}t=t||{},this.sizeMin=r(\"sizeMin\",.5),this.sizeMax=r(\"sizeMax\",20),this.color=r(\"color\",[1,0,0,1]).slice(),this.areaRatio=r(\"areaRatio\",1),this.borderColor=r(\"borderColor\",[0,0,0,1]).slice(),this.blend=r(\"blend\",!1);var n=t.positions.length>>>1,i=t.positions instanceof Float32Array,o=t.idToIndex instanceof Int32Array&&t.idToIndex.length>=n,s=t.positions,l=i?s:a.mallocFloat32(s.length),c=o?t.idToIndex:a.mallocInt32(n);if(i||l.set(s),!o)for(l.set(s),e=0;e<n;e++)c[e]=e;this.points=s,this.offsetBuffer.update(l),this.pickBuffer.update(c),i||a.free(l),o||a.free(c),this.pointCount=n,this.pickOffset=0},u.unifiedDraw=(l=[1,0,0,0,1,0,0,0,1],c=[0,0,0,0],function(t){var e=void 0!==t,r=e?this.pickShader:this.shader,n=this.plot.gl,i=this.plot.dataBox;if(0===this.pointCount)return t;var a=i[2]-i[0],o=i[3]-i[1],s=function(t,e){var r,n=0,i=t.length>>>1;for(r=0;r<i;r++){var a=t[2*r],o=t[2*r+1];a>=e[0]&&a<=e[2]&&o>=e[1]&&o<=e[3]&&n++}return n}(this.points,i),u=this.plot.pickPixelRatio*Math.max(Math.min(this.sizeMinCap,this.sizeMin),Math.min(this.sizeMax,this.sizeMax/Math.pow(s,.33333)));l[0]=2/a,l[4]=2/o,l[6]=-2*i[0]/a-1,l[7]=-2*i[1]/o-1,this.offsetBuffer.bind(),r.bind(),r.attributes.position.pointer(),r.uniforms.matrix=l,r.uniforms.color=this.color,r.uniforms.borderColor=this.borderColor,r.uniforms.pointCloud=u<5,r.uniforms.pointSize=u,r.uniforms.centerFraction=Math.min(1,Math.max(0,Math.sqrt(1-this.areaRatio))),e&&(c[0]=255&t,c[1]=t>>8&255,c[2]=t>>16&255,c[3]=t>>24&255,this.pickBuffer.bind(),r.attributes.pickId.pointer(n.UNSIGNED_BYTE),r.uniforms.pickOffset=c,this.pickOffset=t);var f=n.getParameter(n.BLEND),h=n.getParameter(n.DITHER);return f&&!this.blend&&n.disable(n.BLEND),h&&n.disable(n.DITHER),n.drawArrays(n.POINTS,0,this.pointCount),f&&!this.blend&&n.enable(n.BLEND),h&&n.enable(n.DITHER),t+this.pointCount}),u.draw=u.unifiedDraw,u.drawPick=u.unifiedDraw,u.pick=function(t,e,r){var n=this.pickOffset,i=this.pointCount;if(r<n||r>=n+i)return null;var a=r-n,o=this.points;return{object:this,pointId:a,dataCoord:[o[2*a],o[2*a+1]]}}},{\"./lib/shader\":322,\"gl-buffer\":259,\"gl-shader\":335,\"typedarray-pool\":595}],325:[function(t,e,r){e.exports=function(t,e,r,n){var i,a,o,s,l,c=e[0],u=e[1],f=e[2],h=e[3],p=r[0],d=r[1],g=r[2],m=r[3];(a=c*p+u*d+f*g+h*m)<0&&(a=-a,p=-p,d=-d,g=-g,m=-m);1-a>1e-6?(i=Math.acos(a),o=Math.sin(i),s=Math.sin((1-n)*i)/o,l=Math.sin(n*i)/o):(s=1-n,l=n);return t[0]=s*c+l*p,t[1]=s*u+l*d,t[2]=s*f+l*g,t[3]=s*h+l*m,t}},{}],326:[function(t,e,r){\"use strict\";e.exports=function(t){return t||0===t?t.toString():\"\"}},{}],327:[function(t,e,r){\"use strict\";var n=t(\"vectorize-text\");e.exports=function(t,e,r){var a=i[e];a||(a=i[e]={});if(t in a)return a[t];var o={textAlign:\"center\",textBaseline:\"middle\",lineHeight:1,font:e,lineSpacing:1.25,styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0},triangles:!0},s=n(t,o);o.triangles=!1;var l,c,u=n(t,o);if(r&&1!==r){for(l=0;l<s.positions.length;++l)for(c=0;c<s.positions[l].length;++c)s.positions[l][c]/=r;for(l=0;l<u.positions.length;++l)for(c=0;c<u.positions[l].length;++c)u.positions[l][c]/=r}var f=[[1/0,1/0],[-1/0,-1/0]],h=u.positions.length;for(l=0;l<h;++l){var p=u.positions[l];for(c=0;c<2;++c)f[0][c]=Math.min(f[0][c],p[c]),f[1][c]=Math.max(f[1][c],p[c])}return a[t]=[s,u,f]};var i={}},{\"vectorize-text\":600}],328:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform vec4 highlightId;\\nuniform float highlightScale;\\nuniform mat4 model, view, projection;\\nuniform vec3 clipBounds[2];\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = 1.0;\\n    if(distance(highlightId, id) < 0.0001) {\\n      scale = highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1);\\n    vec4 viewPosition = view * worldPosition;\\n    viewPosition = viewPosition / viewPosition.w;\\n    vec4 clipPosition = projection * (viewPosition + scale * vec4(glyph.x, -glyph.y, 0, 0));\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float highlightScale, pixelRatio;\\nuniform vec4 highlightId;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float scale = pixelRatio;\\n    if(distance(highlightId.bgr, id.bgr) < 0.001) {\\n      scale *= highlightScale;\\n    }\\n\\n    vec4 worldPosition = model * vec4(position, 1.0);\\n    vec4 viewPosition = view * worldPosition;\\n    vec4 clipPosition = projection * viewPosition;\\n    clipPosition /= clipPosition.w;\\n\\n    gl_Position = clipPosition + vec4(screenSize * scale * vec2(glyph.x, -glyph.y), 0.0, 0.0);\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = position;\\n  }\\n}\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nattribute vec3 position;\\nattribute vec4 color;\\nattribute vec2 glyph;\\nattribute vec4 id;\\n\\nuniform float highlightScale;\\nuniform vec4 highlightId;\\nuniform vec3 axes[2];\\nuniform mat4 model, view, projection;\\nuniform vec2 screenSize;\\nuniform vec3 clipBounds[2];\\nuniform float scale, pixelRatio;\\n\\nvarying vec4 interpColor;\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], position)) {\\n\\n    gl_Position = vec4(0,0,0,0);\\n  } else {\\n    float lscale = pixelRatio * scale;\\n    if(distance(highlightId, id) < 0.0001) {\\n      lscale *= highlightScale;\\n    }\\n\\n    vec4 clipCenter   = projection * view * model * vec4(position, 1);\\n    vec3 dataPosition = position + 0.5*lscale*(axes[0] * glyph.x + axes[1] * glyph.y) * clipCenter.w * screenSize.y;\\n    vec4 clipPosition = projection * view * model * vec4(dataPosition, 1);\\n\\n    gl_Position = clipPosition;\\n    interpColor = color;\\n    pickId = id;\\n    dataCoordinate = dataPosition;\\n  }\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float opacity;\\n\\nvarying vec4 interpColor;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (\\n    outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate) ||\\n    interpColor.a * opacity == 0.\\n  ) discard;\\n  gl_FragColor = interpColor * opacity;\\n}\\n\"]),c=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 fragClipBounds[2];\\nuniform float pickGroup;\\n\\nvarying vec4 pickId;\\nvarying vec3 dataCoordinate;\\n\\nvoid main() {\\n  if (outOfRange(fragClipBounds[0], fragClipBounds[1], dataCoordinate)) discard;\\n\\n  gl_FragColor = vec4(pickGroup, pickId.bgr);\\n}\"]),u=[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec4\"},{name:\"glyph\",type:\"vec2\"},{name:\"id\",type:\"vec4\"}],f={vertex:a,fragment:l,attributes:u},h={vertex:o,fragment:l,attributes:u},p={vertex:s,fragment:l,attributes:u},d={vertex:a,fragment:c,attributes:u},g={vertex:o,fragment:c,attributes:u},m={vertex:s,fragment:c,attributes:u};function v(t,e){var r=n(t,e),i=r.attributes;return i.position.location=0,i.color.location=1,i.glyph.location=2,i.id.location=3,r}r.createPerspective=function(t){return v(t,f)},r.createOrtho=function(t){return v(t,h)},r.createProject=function(t){return v(t,p)},r.createPickPerspective=function(t){return v(t,d)},r.createPickOrtho=function(t){return v(t,g)},r.createPickProject=function(t){return v(t,m)}},{\"gl-shader\":335,glslify:329}],329:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],330:[function(t,e,r){\"use strict\";var n=t(\"is-string-blank\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"typedarray-pool\"),s=t(\"gl-mat4/multiply\"),l=t(\"./lib/shaders\"),c=t(\"./lib/glyphs\"),u=t(\"./lib/get-simple-string\"),f=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function h(t,e){var r=t[0],n=t[1],i=t[2],a=t[3];return t[0]=e[0]*r+e[4]*n+e[8]*i+e[12]*a,t[1]=e[1]*r+e[5]*n+e[9]*i+e[13]*a,t[2]=e[2]*r+e[6]*n+e[10]*i+e[14]*a,t[3]=e[3]*r+e[7]*n+e[11]*i+e[15]*a,t}function p(t,e,r,n){return h(n,n),h(n,n),h(n,n)}function d(t,e){this.index=t,this.dataCoordinate=this.position=e}function g(t){return!0===t||t>1?1:t}function m(t,e,r,n,i,a,o,s,l,c,u,f){this.gl=t,this.pixelRatio=1,this.shader=e,this.orthoShader=r,this.projectShader=n,this.pointBuffer=i,this.colorBuffer=a,this.glyphBuffer=o,this.idBuffer=s,this.vao=l,this.vertexCount=0,this.lineVertexCount=0,this.opacity=1,this.hasAlpha=!1,this.lineWidth=0,this.projectScale=[2/3,2/3,2/3],this.projectOpacity=[1,1,1],this.projectHasAlpha=!1,this.pickId=0,this.pickPerspectiveShader=c,this.pickOrthoShader=u,this.pickProjectShader=f,this.points=[],this._selectResult=new d(0,[0,0,0]),this.useOrtho=!0,this.bounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.axesProject=[!0,!0,!0],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.highlightId=[1,1,1,1],this.highlightScale=2,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.dirty=!0}e.exports=function(t){var e=t.gl,r=l.createPerspective(e),n=l.createOrtho(e),o=l.createProject(e),s=l.createPickPerspective(e),c=l.createPickOrtho(e),u=l.createPickProject(e),f=i(e),h=i(e),p=i(e),d=i(e),g=a(e,[{buffer:f,size:3,type:e.FLOAT},{buffer:h,size:4,type:e.FLOAT},{buffer:p,size:2,type:e.FLOAT},{buffer:d,size:4,type:e.UNSIGNED_BYTE,normalized:!0}]),v=new m(e,r,n,o,f,h,p,d,g,s,c,u);return v.update(t),v};var v=m.prototype;v.pickSlots=1,v.setPickBase=function(t){this.pickId=t},v.isTransparent=function(){if(this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&this.projectHasAlpha)return!0;return!1},v.isOpaque=function(){if(!this.hasAlpha)return!0;for(var t=0;t<3;++t)if(this.axesProject[t]&&!this.projectHasAlpha)return!0;return!1};var y=[0,0],x=[0,0,0],b=[0,0,0],_=[0,0,0,1],w=[0,0,0,1],T=f.slice(),k=[0,0,0],M=[[0,0,0],[0,0,0]];function A(t){return t[0]=t[1]=t[2]=0,t}function S(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=1,t}function E(t,e,r,n){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[r]=n,t}function C(t,e,r,n){var i,a=e.axesProject,o=e.gl,l=t.uniforms,c=r.model||f,u=r.view||f,h=r.projection||f,d=e.axesBounds,g=function(t){for(var e=M,r=0;r<2;++r)for(var n=0;n<3;++n)e[r][n]=Math.max(Math.min(t[r][n],1e8),-1e8);return e}(e.clipBounds);i=e.axes&&e.axes.lastCubeProps?e.axes.lastCubeProps.axis:[1,1,1],y[0]=2/o.drawingBufferWidth,y[1]=2/o.drawingBufferHeight,t.bind(),l.view=u,l.projection=h,l.screenSize=y,l.highlightId=e.highlightId,l.highlightScale=e.highlightScale,l.clipBounds=g,l.pickGroup=e.pickId/255,l.pixelRatio=n;for(var m=0;m<3;++m)if(a[m]){l.scale=e.projectScale[m],l.opacity=e.projectOpacity[m];for(var v=T,C=0;C<16;++C)v[C]=0;for(C=0;C<4;++C)v[5*C]=1;v[5*m]=0,i[m]<0?v[12+m]=d[0][m]:v[12+m]=d[1][m],s(v,c,v),l.model=v;var L=(m+1)%3,I=(m+2)%3,P=A(x),z=A(b);P[L]=1,z[I]=1;var O=p(0,0,0,S(_,P)),D=p(0,0,0,S(w,z));if(Math.abs(O[1])>Math.abs(D[1])){var R=O;O=D,D=R,R=P,P=z,z=R;var F=L;L=I,I=F}O[0]<0&&(P[L]=-1),D[1]>0&&(z[I]=-1);var B=0,N=0;for(C=0;C<4;++C)B+=Math.pow(c[4*L+C],2),N+=Math.pow(c[4*I+C],2);P[L]/=Math.sqrt(B),z[I]/=Math.sqrt(N),l.axes[0]=P,l.axes[1]=z,l.fragClipBounds[0]=E(k,g[0],m,-1e8),l.fragClipBounds[1]=E(k,g[1],m,1e8),e.vao.bind(),e.vao.draw(o.TRIANGLES,e.vertexCount),e.lineWidth>0&&(o.lineWidth(e.lineWidth*n),e.vao.draw(o.LINES,e.lineVertexCount,e.vertexCount)),e.vao.unbind()}}var L=[[-1e8,-1e8,-1e8],[1e8,1e8,1e8]];function I(t,e,r,n,i,a,o){var s=r.gl;if((a===r.projectHasAlpha||o)&&C(e,r,n,i),a===r.hasAlpha||o){t.bind();var l=t.uniforms;l.model=n.model||f,l.view=n.view||f,l.projection=n.projection||f,y[0]=2/s.drawingBufferWidth,y[1]=2/s.drawingBufferHeight,l.screenSize=y,l.highlightId=r.highlightId,l.highlightScale=r.highlightScale,l.fragClipBounds=L,l.clipBounds=r.axes.bounds,l.opacity=r.opacity,l.pickGroup=r.pickId/255,l.pixelRatio=i,r.vao.bind(),r.vao.draw(s.TRIANGLES,r.vertexCount),r.lineWidth>0&&(s.lineWidth(r.lineWidth*i),r.vao.draw(s.LINES,r.lineVertexCount,r.vertexCount)),r.vao.unbind()}}function P(t,e,r,i){var a;a=Array.isArray(t)?e<t.length?t[e]:void 0:t,a=u(a);var o=!0;n(a)&&(a=\"\\u25bc\",o=!1);var s=c(a,r,i);return{mesh:s[0],lines:s[1],bounds:s[2],visible:o}}v.draw=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!1,!1)},v.drawTransparent=function(t){I(this.useOrtho?this.orthoShader:this.shader,this.projectShader,this,t,this.pixelRatio,!0,!1)},v.drawPick=function(t){I(this.useOrtho?this.pickOrthoShader:this.pickPerspectiveShader,this.pickProjectShader,this,t,1,!0,!0)},v.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=t.value[2]+(t.value[1]<<8)+(t.value[0]<<16);if(e>=this.pointCount||e<0)return null;var r=this.points[e],n=this._selectResult;n.index=e;for(var i=0;i<3;++i)n.position[i]=n.dataCoordinate[i]=r[i];return n},v.highlight=function(t){if(t){var e=t.index,r=255&e,n=e>>8&255,i=e>>16&255;this.highlightId=[r/255,n/255,i/255,0]}else this.highlightId=[1,1,1,1]},v.update=function(t){if(\"perspective\"in(t=t||{})&&(this.useOrtho=!t.perspective),\"orthographic\"in t&&(this.useOrtho=!!t.orthographic),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"project\"in t)if(Array.isArray(t.project))this.axesProject=t.project;else{var e=!!t.project;this.axesProject=[e,e,e]}if(\"projectScale\"in t)if(Array.isArray(t.projectScale))this.projectScale=t.projectScale.slice();else{var r=+t.projectScale;this.projectScale=[r,r,r]}if(this.projectHasAlpha=!1,\"projectOpacity\"in t){if(Array.isArray(t.projectOpacity))this.projectOpacity=t.projectOpacity.slice();else{r=+t.projectOpacity;this.projectOpacity=[r,r,r]}for(var n=0;n<3;++n)this.projectOpacity[n]=g(this.projectOpacity[n]),this.projectOpacity[n]<1&&(this.projectHasAlpha=!0)}this.hasAlpha=!1,\"opacity\"in t&&(this.opacity=g(t.opacity),this.opacity<1&&(this.hasAlpha=!0)),this.dirty=!0;var i,a,s=t.position,l=t.font||\"normal\",c=t.alignment||[0,0];if(2===c.length)i=c[0],a=c[1];else{i=[],a=[];for(n=0;n<c.length;++n)i[n]=c[n][0],a[n]=c[n][1]}var u=[1/0,1/0,1/0],f=[-1/0,-1/0,-1/0],h=t.glyph,p=t.color,d=t.size,m=t.angle,v=t.lineColor,y=-1,x=0,b=0,_=0;if(s.length){_=s.length;t:for(n=0;n<_;++n){for(var w=s[n],T=0;T<3;++T)if(isNaN(w[T])||!isFinite(w[T]))continue t;var k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;x+=3*k.cells.length,b+=2*M.edges.length}}var S=x+b,E=o.mallocFloat(3*S),C=o.mallocFloat(4*S),L=o.mallocFloat(2*S),I=o.mallocUint32(S);if(S>0){var z=0,O=x,D=[0,0,0,1],R=[0,0,0,1],F=Array.isArray(p)&&Array.isArray(p[0]),B=Array.isArray(v)&&Array.isArray(v[0]);t:for(n=0;n<_;++n){y+=1;for(w=s[n],T=0;T<3;++T){if(isNaN(w[T])||!isFinite(w[T]))continue t;f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T])}k=(N=P(h,n,l,this.pixelRatio)).mesh,M=N.lines,A=N.bounds;var N,j=N.visible;if(j)if(Array.isArray(p)){if(3===(U=F?n<p.length?p[n]:[0,0,0,0]:p).length){for(T=0;T<3;++T)D[T]=U[T];D[3]=1}else if(4===U.length){for(T=0;T<4;++T)D[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else D[0]=D[1]=D[2]=0,D[3]=1;else D=[1,1,1,0];if(j)if(Array.isArray(v)){var U;if(3===(U=B?n<v.length?v[n]:[0,0,0,0]:v).length){for(T=0;T<3;++T)R[T]=U[T];R[T]=1}else if(4===U.length){for(T=0;T<4;++T)R[T]=U[T];!this.hasAlpha&&U[3]<1&&(this.hasAlpha=!0)}}else R[0]=R[1]=R[2]=0,R[3]=1;else R=[1,1,1,0];var V=.5;j?Array.isArray(d)?V=n<d.length?+d[n]:12:d?V=+d:this.useOrtho&&(V=12):V=0;var q=0;Array.isArray(m)?q=n<m.length?+m[n]:0:m&&(q=+m);var H=Math.cos(q),G=Math.sin(q);for(w=s[n],T=0;T<3;++T)f[T]=Math.max(f[T],w[T]),u[T]=Math.min(u[T],w[T]);var Y=i,W=a;Y=0;Array.isArray(i)?Y=n<i.length?i[n]:0:i&&(Y=i);W=0;Array.isArray(a)?W=n<a.length?a[n]:0:a&&(W=a);var X=[Y*=Y>0?1-A[0][0]:Y<0?1+A[1][0]:1,W*=W>0?1-A[0][1]:W<0?1+A[1][1]:1],Z=k.cells||[],J=k.positions||[];for(T=0;T<Z.length;++T)for(var K=Z[T],Q=0;Q<3;++Q){for(var $=0;$<3;++$)E[3*z+$]=w[$];for($=0;$<4;++$)C[4*z+$]=D[$];I[z]=y;var tt=J[K[Q]];L[2*z]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*z+1]=V*(G*tt[0]+H*tt[1]+X[1]),z+=1}for(Z=M.edges,J=M.positions,T=0;T<Z.length;++T)for(K=Z[T],Q=0;Q<2;++Q){for($=0;$<3;++$)E[3*O+$]=w[$];for($=0;$<4;++$)C[4*O+$]=R[$];I[O]=y;tt=J[K[Q]];L[2*O]=V*(H*tt[0]-G*tt[1]+X[0]),L[2*O+1]=V*(G*tt[0]+H*tt[1]+X[1]),O+=1}}}this.bounds=[u,f],this.points=s,this.pointCount=s.length,this.vertexCount=x,this.lineVertexCount=b,this.pointBuffer.update(E),this.colorBuffer.update(C),this.glyphBuffer.update(L),this.idBuffer.update(I),o.free(E),o.free(C),o.free(L),o.free(I)},v.dispose=function(){this.shader.dispose(),this.orthoShader.dispose(),this.pickPerspectiveShader.dispose(),this.pickOrthoShader.dispose(),this.vao.dispose(),this.pointBuffer.dispose(),this.colorBuffer.dispose(),this.glyphBuffer.dispose(),this.idBuffer.dispose()}},{\"./lib/get-simple-string\":326,\"./lib/glyphs\":327,\"./lib/shaders\":328,\"gl-buffer\":259,\"gl-mat4/multiply\":295,\"gl-vao\":358,\"is-string-blank\":470,\"typedarray-pool\":595}],331:[function(t,e,r){\"use strict\";var n=t(\"glslify\");r.boxVertex=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec2 vertex;\\n\\nuniform vec2 cornerA, cornerB;\\n\\nvoid main() {\\n  gl_Position = vec4(mix(cornerA, cornerB, vertex), 0, 1);\\n}\\n\"]),r.boxFragment=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nuniform vec4 color;\\n\\nvoid main() {\\n  gl_FragColor = color;\\n}\\n\"])},{glslify:332}],332:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],333:[function(t,e,r){\"use strict\";var n=t(\"gl-shader\"),i=t(\"gl-buffer\"),a=t(\"./lib/shaders\");function o(t,e,r){this.plot=t,this.boxBuffer=e,this.boxShader=r,this.enabled=!0,this.selectBox=[1/0,1/0,-1/0,-1/0],this.borderColor=[0,0,0,1],this.innerFill=!1,this.innerColor=[0,0,0,.25],this.outerFill=!0,this.outerColor=[0,0,0,.5],this.borderWidth=10}e.exports=function(t,e){var r=t.gl,s=i(r,[0,0,0,1,1,0,1,1]),l=n(r,a.boxVertex,a.boxFragment),c=new o(t,s,l);return c.update(e),t.addOverlay(c),c};var s=o.prototype;s.draw=function(){if(this.enabled){var t=this.plot,e=this.selectBox,r=this.borderWidth,n=(this.innerFill,this.innerColor),i=(this.outerFill,this.outerColor),a=this.borderColor,o=t.box,s=t.screenBox,l=t.dataBox,c=t.viewBox,u=t.pixelRatio,f=(e[0]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],h=(e[1]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1],p=(e[2]-l[0])*(c[2]-c[0])/(l[2]-l[0])+c[0],d=(e[3]-l[1])*(c[3]-c[1])/(l[3]-l[1])+c[1];if(f=Math.max(f,c[0]),h=Math.max(h,c[1]),p=Math.min(p,c[2]),d=Math.min(d,c[3]),!(p<f||d<h)){o.bind();var g=s[2]-s[0],m=s[3]-s[1];if(this.outerFill&&(o.drawBox(0,0,g,h,i),o.drawBox(0,h,f,d,i),o.drawBox(0,d,g,m,i),o.drawBox(p,h,g,d,i)),this.innerFill&&o.drawBox(f,h,p,d,n),r>0){var v=r*u;o.drawBox(f-v,h-v,p+v,h+v,a),o.drawBox(f-v,d-v,p+v,d+v,a),o.drawBox(f-v,h-v,f+v,d+v,a),o.drawBox(p-v,h-v,p+v,d+v,a)}}}},s.update=function(t){t=t||{},this.innerFill=!!t.innerFill,this.outerFill=!!t.outerFill,this.innerColor=(t.innerColor||[0,0,0,.5]).slice(),this.outerColor=(t.outerColor||[0,0,0,.5]).slice(),this.borderColor=(t.borderColor||[0,0,0,1]).slice(),this.borderWidth=t.borderWidth||0,this.selectBox=(t.selectBox||this.selectBox).slice()},s.dispose=function(){this.boxBuffer.dispose(),this.boxShader.dispose(),this.plot.removeOverlay(this)}},{\"./lib/shaders\":331,\"gl-buffer\":259,\"gl-shader\":335}],334:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=e[0],a=e[1],o=n(t,r,a,{}),s=i.mallocUint8(r*a*4);return new l(t,o,s)};var n=t(\"gl-fbo\"),i=t(\"typedarray-pool\"),a=t(\"ndarray\"),o=t(\"bit-twiddle\").nextPow2;function s(t,e,r,n,i){this.coord=[t,e],this.id=r,this.value=n,this.distance=i}function l(t,e,r){this.gl=t,this.fbo=e,this.buffer=r,this._readTimeout=null;var n=this;this._readCallback=function(){n.gl&&(e.bind(),t.readPixels(0,0,e.shape[0],e.shape[1],t.RGBA,t.UNSIGNED_BYTE,n.buffer),n._readTimeout=null)}}var c=l.prototype;Object.defineProperty(c,\"shape\",{get:function(){return this.gl?this.fbo.shape.slice():[0,0]},set:function(t){if(this.gl){this.fbo.shape=t;var e=this.fbo.shape[0],r=this.fbo.shape[1];if(r*e*4>this.buffer.length){i.free(this.buffer);for(var n=this.buffer=i.mallocUint8(o(r*e*4)),a=0;a<r*e*4;++a)n[a]=255}return t}}}),c.begin=function(){var t=this.gl;this.shape;t&&(this.fbo.bind(),t.clearColor(1,1,1,1),t.clear(t.COLOR_BUFFER_BIT|t.DEPTH_BUFFER_BIT))},c.end=function(){var t=this.gl;t&&(t.bindFramebuffer(t.FRAMEBUFFER,null),this._readTimeout||clearTimeout(this._readTimeout),this._readTimeout=setTimeout(this._readCallback,1))},c.query=function(t,e,r){if(!this.gl)return null;var n=this.fbo.shape.slice();t|=0,e|=0,\"number\"!=typeof r&&(r=1);var i=0|Math.min(Math.max(t-r,0),n[0]),o=0|Math.min(Math.max(t+r,0),n[0]),l=0|Math.min(Math.max(e-r,0),n[1]),c=0|Math.min(Math.max(e+r,0),n[1]);if(o<=i||c<=l)return null;var u=[o-i,c-l],f=a(this.buffer,[u[0],u[1],4],[4,4*n[0],1],4*(i+n[0]*l)),h=function(t,e,r){for(var n=1e8,i=-1,a=-1,o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++){var u=t.get(l,c,0),f=t.get(l,c,1),h=t.get(l,c,2),p=t.get(l,c,3);if(u<255||f<255||h<255||p<255){var d=e-l,g=r-c,m=d*d+g*g;m<n&&(n=m,i=l,a=c)}}return[i,a,n]}(f.hi(u[0],u[1],1),r,r),p=h[0],d=h[1];return p<0||Math.pow(this.radius,2)<h[2]?null:new s(p+i|0,d+l|0,f.get(p,d,0),[f.get(p,d,1),f.get(p,d,2),f.get(p,d,3)],Math.sqrt(h[2]))},c.dispose=function(){this.gl&&(this.fbo.dispose(),i.free(this.buffer),this.gl=null,this._readTimeout&&clearTimeout(this._readTimeout))}},{\"bit-twiddle\":97,\"gl-fbo\":269,ndarray:495,\"typedarray-pool\":595}],335:[function(t,e,r){\"use strict\";var n=t(\"./lib/create-uniforms\"),i=t(\"./lib/create-attributes\"),a=t(\"./lib/reflect\"),o=t(\"./lib/shader-cache\"),s=t(\"./lib/runtime-reflect\"),l=t(\"./lib/GLError\");function c(t){this.gl=t,this.gl.lastAttribCount=0,this._vref=this._fref=this._relink=this.vertShader=this.fragShader=this.program=this.attributes=this.uniforms=this.types=null}var u=c.prototype;function f(t,e){return t.name<e.name?-1:1}u.bind=function(){var t;this.program||this._relink();var e=this.gl.getProgramParameter(this.program,this.gl.ACTIVE_ATTRIBUTES),r=this.gl.lastAttribCount;if(e>r)for(t=r;t<e;t++)this.gl.enableVertexAttribArray(t);else if(r>e)for(t=e;t<r;t++)this.gl.disableVertexAttribArray(t);this.gl.lastAttribCount=e,this.gl.useProgram(this.program)},u.dispose=function(){for(var t=this.gl.lastAttribCount,e=0;e<t;e++)this.gl.disableVertexAttribArray(e);this.gl.lastAttribCount=0,this._fref&&this._fref.dispose(),this._vref&&this._vref.dispose(),this.attributes=this.types=this.vertShader=this.fragShader=this.program=this._relink=this._fref=this._vref=null},u.update=function(t,e,r,c){if(!e||1===arguments.length){var u=t;t=u.vertex,e=u.fragment,r=u.uniforms,c=u.attributes}var h=this,p=h.gl,d=h._vref;h._vref=o.shader(p,p.VERTEX_SHADER,t),d&&d.dispose(),h.vertShader=h._vref.shader;var g=this._fref;if(h._fref=o.shader(p,p.FRAGMENT_SHADER,e),g&&g.dispose(),h.fragShader=h._fref.shader,!r||!c){var m=p.createProgram();if(p.attachShader(m,h.fragShader),p.attachShader(m,h.vertShader),p.linkProgram(m),!p.getProgramParameter(m,p.LINK_STATUS)){var v=p.getProgramInfoLog(m);throw new l(v,\"Error linking program:\"+v)}r=r||s.uniforms(p,m),c=c||s.attributes(p,m),p.deleteProgram(m)}(c=c.slice()).sort(f);var y,x=[],b=[],_=[];for(y=0;y<c.length;++y){var w=c[y];if(w.type.indexOf(\"mat\")>=0){for(var T=0|w.type.charAt(w.type.length-1),k=new Array(T),M=0;M<T;++M)k[M]=_.length,b.push(w.name+\"[\"+M+\"]\"),\"number\"==typeof w.location?_.push(w.location+M):Array.isArray(w.location)&&w.location.length===T&&\"number\"==typeof w.location[M]?_.push(0|w.location[M]):_.push(-1);x.push({name:w.name,type:w.type,locations:k})}else x.push({name:w.name,type:w.type,locations:[_.length]}),b.push(w.name),\"number\"==typeof w.location?_.push(0|w.location):_.push(-1)}var A=0;for(y=0;y<_.length;++y)if(_[y]<0){for(;_.indexOf(A)>=0;)A+=1;_[y]=A}var S=new Array(r.length);function E(){h.program=o.program(p,h._vref,h._fref,b,_);for(var t=0;t<r.length;++t)S[t]=p.getUniformLocation(h.program,r[t].name)}E(),h._relink=E,h.types={uniforms:a(r),attributes:a(c)},h.attributes=i(p,h,x,_),Object.defineProperty(h,\"uniforms\",n(p,h,r,S))},e.exports=function(t,e,r,n,i){var a=new c(t);return a.update(e,r,n,i),a}},{\"./lib/GLError\":336,\"./lib/create-attributes\":337,\"./lib/create-uniforms\":338,\"./lib/reflect\":339,\"./lib/runtime-reflect\":340,\"./lib/shader-cache\":341}],336:[function(t,e,r){function n(t,e,r){this.shortMessage=e||\"\",this.longMessage=r||\"\",this.rawError=t||\"\",this.message=\"gl-shader: \"+(e||t||\"\")+(r?\"\\n\"+r:\"\"),this.stack=(new Error).stack}n.prototype=new Error,n.prototype.name=\"GLError\",n.prototype.constructor=n,e.exports=n},{}],337:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){for(var a={},l=0,c=r.length;l<c;++l){var u=r[l],f=u.name,h=u.type,p=u.locations;switch(h){case\"bool\":case\"int\":case\"float\":o(t,e,p[0],i,1,a,f);break;default:if(h.indexOf(\"vec\")>=0){if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);o(t,e,p[0],i,d,a,f)}else{if(!(h.indexOf(\"mat\")>=0))throw new n(\"\",\"Unknown data type for attribute \"+f+\": \"+h);var d;if((d=h.charCodeAt(h.length-1)-48)<2||d>4)throw new n(\"\",\"Invalid data type for attribute \"+f+\": \"+h);s(t,e,p,i,d,a,f)}}}return a};var n=t(\"./GLError\");function i(t,e,r,n,i,a){this._gl=t,this._wrapper=e,this._index=r,this._locations=n,this._dimension=i,this._constFunc=a}var a=i.prototype;function o(t,e,r,n,a,o,s){for(var l=[\"gl\",\"v\"],c=[],u=0;u<a;++u)l.push(\"x\"+u),c.push(\"x\"+u);l.push(\"if(x0.length===void 0){return gl.vertexAttrib\"+a+\"f(v,\"+c.join()+\")}else{return gl.vertexAttrib\"+a+\"fv(v,x0)}\");var f=Function.apply(null,l),h=new i(t,e,r,n,a,f);Object.defineProperty(o,s,{set:function(e){return t.disableVertexAttribArray(n[r]),f(t,n[r],e),e},get:function(){return h},enumerable:!0})}function s(t,e,r,n,i,a,s){for(var l=new Array(i),c=new Array(i),u=0;u<i;++u)o(t,e,r[u],n,i,l,u),c[u]=l[u];Object.defineProperty(l,\"location\",{set:function(t){if(Array.isArray(t))for(var e=0;e<i;++e)c[e].location=t[e];else for(e=0;e<i;++e)c[e].location=t+e;return t},get:function(){for(var t=new Array(i),e=0;e<i;++e)t[e]=n[r[e]];return t},enumerable:!0}),l.pointer=function(e,a,o,s){e=e||t.FLOAT,a=!!a,o=o||i*i,s=s||0;for(var l=0;l<i;++l){var c=n[r[l]];t.vertexAttribPointer(c,i,e,a,o,s+l*i),t.enableVertexAttribArray(c)}};var f=new Array(i),h=t[\"vertexAttrib\"+i+\"fv\"];Object.defineProperty(a,s,{set:function(e){for(var a=0;a<i;++a){var o=n[r[a]];if(t.disableVertexAttribArray(o),Array.isArray(e[0]))h.call(t,o,e[a]);else{for(var s=0;s<i;++s)f[s]=e[i*a+s];h.call(t,o,f)}}return e},get:function(){return l},enumerable:!0})}a.pointer=function(t,e,r,n){var i=this._gl,a=this._locations[this._index];i.vertexAttribPointer(a,this._dimension,t||i.FLOAT,!!e,r||0,n||0),i.enableVertexAttribArray(a)},a.set=function(t,e,r,n){return this._constFunc(this._locations[this._index],t,e,r,n)},Object.defineProperty(a,\"location\",{get:function(){return this._locations[this._index]},set:function(t){return t!==this._locations[this._index]&&(this._locations[this._index]=0|t,this._wrapper.program=null),0|t}})},{\"./GLError\":336}],338:[function(t,e,r){\"use strict\";var n=t(\"./reflect\"),i=t(\"./GLError\");function a(t){return new Function(\"y\",\"return function(){return y}\")(t)}function o(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}e.exports=function(t,e,r,s){function l(t,e,r){switch(r){case\"bool\":case\"int\":case\"sampler2D\":case\"samplerCube\":return\"gl.uniform1i(locations[\"+e+\"],obj\"+t+\")\";case\"float\":return\"gl.uniform1f(locations[\"+e+\"],obj\"+t+\")\";default:var n=r.indexOf(\"vec\");if(!(0<=n&&n<=1&&r.length===4+n)){if(0===r.indexOf(\"mat\")&&4===r.length){var a;if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+r);return\"gl.uniformMatrix\"+a+\"fv(locations[\"+e+\"],false,obj\"+t+\")\"}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+r)}if((a=r.charCodeAt(r.length-1)-48)<2||a>4)throw new i(\"\",\"Invalid data type\");switch(r.charAt(0)){case\"b\":case\"i\":return\"gl.uniform\"+a+\"iv(locations[\"+e+\"],obj\"+t+\")\";case\"v\":return\"gl.uniform\"+a+\"fv(locations[\"+e+\"],obj\"+t+\")\";default:throw new i(\"\",\"Unrecognized data type for vector \"+name+\": \"+r)}}}function c(e){for(var n=[\"return function updateProperty(obj){\"],i=function t(e,r){if(\"object\"!=typeof r)return[[e,r]];var n=[];for(var i in r){var a=r[i],o=e;parseInt(i)+\"\"===i?o+=\"[\"+i+\"]\":o+=\".\"+i,\"object\"==typeof a?n.push.apply(n,t(o,a)):n.push([o,a])}return n}(\"\",e),a=0;a<i.length;++a){var o=i[a],c=o[0],u=o[1];s[u]&&n.push(l(c,u,r[u].type))}return n.push(\"return obj}\"),new Function(\"gl\",\"locations\",n.join(\"\\n\"))(t,s)}function u(n,l,u){if(\"object\"==typeof u){var h=f(u);Object.defineProperty(n,l,{get:a(h),set:c(u),enumerable:!0,configurable:!1})}else s[u]?Object.defineProperty(n,l,{get:(p=u,new Function(\"gl\",\"wrapper\",\"locations\",\"return function(){return gl.getUniform(wrapper.program,locations[\"+p+\"])}\")(t,e,s)),set:c(u),enumerable:!0,configurable:!1}):n[l]=function(t){switch(t){case\"bool\":return!1;case\"int\":case\"sampler2D\":case\"samplerCube\":case\"float\":return 0;default:var e=t.indexOf(\"vec\");if(0<=e&&e<=1&&t.length===4+e){if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid data type\");return\"b\"===t.charAt(0)?o(r,!1):o(r,0)}if(0===t.indexOf(\"mat\")&&4===t.length){var r;if((r=t.charCodeAt(t.length-1)-48)<2||r>4)throw new i(\"\",\"Invalid uniform dimension type for matrix \"+name+\": \"+t);return o(r*r,0)}throw new i(\"\",\"Unknown uniform data type for \"+name+\": \"+t)}}(r[u].type);var p}function f(t){var e;if(Array.isArray(t)){e=new Array(t.length);for(var r=0;r<t.length;++r)u(e,r,t[r])}else for(var n in e={},t)u(e,n,t[n]);return e}var h=n(r,!0);return{get:a(f(h)),set:c(h),enumerable:!0,configurable:!0}}},{\"./GLError\":336,\"./reflect\":339}],339:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r={},n=0;n<t.length;++n)for(var i=t[n].name.split(\".\"),a=r,o=0;o<i.length;++o){var s=i[o].split(\"[\");if(s.length>1){s[0]in a||(a[s[0]]=[]),a=a[s[0]];for(var l=1;l<s.length;++l){var c=parseInt(s[l]);l<s.length-1||o<i.length-1?(c in a||(l<s.length-1?a[c]=[]:a[c]={}),a=a[c]):a[c]=e?n:t[n].type}}else o<i.length-1?(s[0]in a||(a[s[0]]={}),a=a[s[0]]):a[s[0]]=e?n:t[n].type}return r}},{}],340:[function(t,e,r){\"use strict\";r.uniforms=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_UNIFORMS),n=[],i=0;i<r;++i){var o=t.getActiveUniform(e,i);if(o){var s=a(t,o.type);if(o.size>1)for(var l=0;l<o.size;++l)n.push({name:o.name.replace(\"[0]\",\"[\"+l+\"]\"),type:s});else n.push({name:o.name,type:s})}}return n},r.attributes=function(t,e){for(var r=t.getProgramParameter(e,t.ACTIVE_ATTRIBUTES),n=[],i=0;i<r;++i){var o=t.getActiveAttrib(e,i);o&&n.push({name:o.name,type:a(t,o.type)})}return n};var n={FLOAT:\"float\",FLOAT_VEC2:\"vec2\",FLOAT_VEC3:\"vec3\",FLOAT_VEC4:\"vec4\",INT:\"int\",INT_VEC2:\"ivec2\",INT_VEC3:\"ivec3\",INT_VEC4:\"ivec4\",BOOL:\"bool\",BOOL_VEC2:\"bvec2\",BOOL_VEC3:\"bvec3\",BOOL_VEC4:\"bvec4\",FLOAT_MAT2:\"mat2\",FLOAT_MAT3:\"mat3\",FLOAT_MAT4:\"mat4\",SAMPLER_2D:\"sampler2D\",SAMPLER_CUBE:\"samplerCube\"},i=null;function a(t,e){if(!i){var r=Object.keys(n);i={};for(var a=0;a<r.length;++a){var o=r[a];i[t[o]]=n[o]}}return i[e]}},{}],341:[function(t,e,r){\"use strict\";r.shader=function(t,e,r){return u(t).getShaderReference(e,r)},r.program=function(t,e,r,n,i){return u(t).getProgram(e,r,n,i)};var n=t(\"./GLError\"),i=t(\"gl-format-compiler-error\"),a=new(\"undefined\"==typeof WeakMap?t(\"weakmap-shim\"):WeakMap),o=0;function s(t,e,r,n,i,a,o){this.id=t,this.src=e,this.type=r,this.shader=n,this.count=a,this.programs=[],this.cache=o}function l(t){this.gl=t,this.shaders=[{},{}],this.programs={}}s.prototype.dispose=function(){if(0==--this.count){for(var t=this.cache,e=t.gl,r=this.programs,n=0,i=r.length;n<i;++n){var a=t.programs[r[n]];a&&(delete t.programs[n],e.deleteProgram(a))}e.deleteShader(this.shader),delete t.shaders[this.type===e.FRAGMENT_SHADER|0][this.src]}};var c=l.prototype;function u(t){var e=a.get(t);return e||(e=new l(t),a.set(t,e)),e}c.getShaderReference=function(t,e){var r=this.gl,a=this.shaders[t===r.FRAGMENT_SHADER|0],l=a[e];if(l&&r.isShader(l.shader))l.count+=1;else{var c=function(t,e,r){var a=t.createShader(e);if(t.shaderSource(a,r),t.compileShader(a),!t.getShaderParameter(a,t.COMPILE_STATUS)){var o=t.getShaderInfoLog(a);try{var s=i(o,r,e)}catch(t){throw console.warn(\"Failed to format compiler error: \"+t),new n(o,\"Error compiling shader:\\n\"+o)}throw new n(o,s.short,s.long)}return a}(r,t,e);l=a[e]=new s(o++,e,t,c,[],1,this)}return l},c.getProgram=function(t,e,r,i){var a=[t.id,e.id,r.join(\":\"),i.join(\":\")].join(\"@\"),o=this.programs[a];return o&&this.gl.isProgram(o)||(this.programs[a]=o=function(t,e,r,i,a){var o=t.createProgram();t.attachShader(o,e),t.attachShader(o,r);for(var s=0;s<i.length;++s)t.bindAttribLocation(o,a[s],i[s]);if(t.linkProgram(o),!t.getProgramParameter(o,t.LINK_STATUS)){var l=t.getProgramInfoLog(o);throw new n(l,\"Error linking program: \"+l)}return o}(this.gl,t.shader,e.shader,r,i),t.programs.push(a),e.programs.push(a)),o}},{\"./GLError\":336,\"gl-format-compiler-error\":270,\"weakmap-shim\":605}],342:[function(t,e,r){\"use strict\";function n(t){this.plot=t,this.enable=[!0,!0,!1,!1],this.width=[1,1,1,1],this.color=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.center=[1/0,1/0]}e.exports=function(t,e){var r=new n(t);return r.update(e),t.addOverlay(r),r};var i=n.prototype;i.update=function(t){t=t||{},this.enable=(t.enable||[!0,!0,!1,!1]).slice(),this.width=(t.width||[1,1,1,1]).slice(),this.color=(t.color||[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]]).map((function(t){return t.slice()})),this.center=(t.center||[1/0,1/0]).slice(),this.plot.setOverlayDirty()},i.draw=function(){var t=this.enable,e=this.width,r=this.color,n=this.center,i=this.plot,a=i.line,o=i.dataBox,s=i.viewBox;if(a.bind(),o[0]<=n[0]&&n[0]<=o[2]&&o[1]<=n[1]&&n[1]<=o[3]){var l=s[0]+(n[0]-o[0])/(o[2]-o[0])*(s[2]-s[0]),c=s[1]+(n[1]-o[1])/(o[3]-o[1])*(s[3]-s[1]);t[0]&&a.drawLine(l,c,s[0],c,e[0],r[0]),t[1]&&a.drawLine(l,c,l,s[1],e[1],r[1]),t[2]&&a.drawLine(l,c,s[2],c,e[2],r[2]),t[3]&&a.drawLine(l,c,l,s[3],e[3],r[3])}},i.dispose=function(){this.plot.removeOverlay(this)}},{}],343:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],344:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=t(\"gl-shader\"),a=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nattribute vec3 position, color;\\nattribute float weight;\\n\\nuniform mat4 model, view, projection;\\nuniform vec3 coordinates[3];\\nuniform vec4 colors[3];\\nuniform vec2 screenShape;\\nuniform float lineWidth;\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  vec3 vertexPosition = mix(coordinates[0],\\n    mix(coordinates[2], coordinates[1], 0.5 * (position + 1.0)), abs(position));\\n\\n  vec4 clipPos = projection * view * model * vec4(vertexPosition, 1.0);\\n  vec2 clipOffset = (projection * view * model * vec4(color, 0.0)).xy;\\n  vec2 delta = weight * clipOffset * screenShape;\\n  vec2 lineOffset = normalize(vec2(delta.y, -delta.x)) / screenShape;\\n\\n  gl_Position   = vec4(clipPos.xy + clipPos.w * 0.5 * lineWidth * lineOffset, clipPos.z, clipPos.w);\\n  fragColor     = color.x * colors[0] + color.y * colors[1] + color.z * colors[2];\\n}\\n\"]),o=n([\"precision mediump float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n  gl_FragColor = fragColor;\\n}\"]);e.exports=function(t){return i(t,a,o,null,[{name:\"position\",type:\"vec3\"},{name:\"color\",type:\"vec3\"},{name:\"weight\",type:\"float\"}])}},{\"gl-shader\":335,glslify:343}],345:[function(t,e,r){\"use strict\";var n=t(\"gl-buffer\"),i=t(\"gl-vao\"),a=t(\"./shaders/index\");e.exports=function(t,e){var r=[];function o(t,e,n,i,a,o){var s=[t,e,n,0,0,0,1];s[i+3]=1,s[i]=a,r.push.apply(r,s),s[6]=-1,r.push.apply(r,s),s[i]=o,r.push.apply(r,s),r.push.apply(r,s),s[6]=1,r.push.apply(r,s),s[i]=a,r.push.apply(r,s)}o(0,0,0,0,0,1),o(0,0,0,1,0,1),o(0,0,0,2,0,1),o(1,0,0,1,-1,1),o(1,0,0,2,-1,1),o(0,1,0,0,-1,1),o(0,1,0,2,-1,1),o(0,0,1,0,-1,1),o(0,0,1,1,-1,1);var l=n(t,r),c=i(t,[{type:t.FLOAT,buffer:l,size:3,offset:0,stride:28},{type:t.FLOAT,buffer:l,size:3,offset:12,stride:28},{type:t.FLOAT,buffer:l,size:1,offset:24,stride:28}]),u=a(t);u.attributes.position.location=0,u.attributes.color.location=1,u.attributes.weight.location=2;var f=new s(t,l,c,u);return f.update(e),f};var o=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];function s(t,e,r,n){this.gl=t,this.buffer=e,this.vao=r,this.shader=n,this.pixelRatio=1,this.bounds=[[-1e3,-1e3,-1e3],[1e3,1e3,1e3]],this.position=[0,0,0],this.lineWidth=[2,2,2],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.enabled=[!0,!0,!0],this.drawSides=[!0,!0,!0],this.axes=null}var l=s.prototype,c=[0,0,0],u=[0,0,0],f=[0,0];l.isTransparent=function(){return!1},l.drawTransparent=function(t){},l.draw=function(t){var e=this.gl,r=this.vao,n=this.shader;r.bind(),n.bind();var i,a=t.model||o,s=t.view||o,l=t.projection||o;this.axes&&(i=this.axes.lastCubeProps.axis);for(var h=c,p=u,d=0;d<3;++d)i&&i[d]<0?(h[d]=this.bounds[0][d],p[d]=this.bounds[1][d]):(h[d]=this.bounds[1][d],p[d]=this.bounds[0][d]);f[0]=e.drawingBufferWidth,f[1]=e.drawingBufferHeight,n.uniforms.model=a,n.uniforms.view=s,n.uniforms.projection=l,n.uniforms.coordinates=[this.position,h,p],n.uniforms.colors=this.colors,n.uniforms.screenShape=f;for(d=0;d<3;++d)n.uniforms.lineWidth=this.lineWidth[d]*this.pixelRatio,this.enabled[d]&&(r.draw(e.TRIANGLES,6,6*d),this.drawSides[d]&&r.draw(e.TRIANGLES,12,18+12*d));r.unbind()},l.update=function(t){t&&(\"bounds\"in t&&(this.bounds=t.bounds),\"position\"in t&&(this.position=t.position),\"lineWidth\"in t&&(this.lineWidth=t.lineWidth),\"colors\"in t&&(this.colors=t.colors),\"enabled\"in t&&(this.enabled=t.enabled),\"drawSides\"in t&&(this.drawSides=t.drawSides))},l.dispose=function(){this.vao.dispose(),this.buffer.dispose(),this.shader.dispose()}},{\"./shaders/index\":344,\"gl-buffer\":259,\"gl-vao\":358}],346:[function(t,e,r){var n=t(\"glslify\"),i=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 color, position;\\nattribute vec2 uv;\\n\\nuniform float vectorScale, tubeScale;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 eyePosition, lightPosition;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  // Scale the vector magnitude to stay constant with\\n  // model & view changes.\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * tubePosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  f_lightDirection = lightPosition - cameraCoordinate.xyz;\\n  f_eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  f_normal = normalize((vec4(normal, 0.0) * inverseModel).xyz);\\n\\n  // vec4 m_position  = model * vec4(tubePosition, 1.0);\\n  vec4 t_position  = view * tubePosition;\\n  gl_Position      = projection * t_position;\\n\\n  f_color          = color;\\n  f_data           = tubePosition.xyz;\\n  f_position       = position.xyz;\\n  f_uv             = uv;\\n}\\n\"]),a=n([\"#extension GL_OES_standard_derivatives : enable\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat cookTorranceSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness,\\n  float fresnel) {\\n\\n  float VdotN = max(dot(viewDirection, surfaceNormal), 0.0);\\n  float LdotN = max(dot(lightDirection, surfaceNormal), 0.0);\\n\\n  //Half angle vector\\n  vec3 H = normalize(lightDirection + viewDirection);\\n\\n  //Geometric term\\n  float NdotH = max(dot(surfaceNormal, H), 0.0);\\n  float VdotH = max(dot(viewDirection, H), 0.000001);\\n  float LdotH = max(dot(lightDirection, H), 0.000001);\\n  float G1 = (2.0 * NdotH * VdotN) / VdotH;\\n  float G2 = (2.0 * NdotH * LdotN) / LdotH;\\n  float G = min(1.0, min(G1, G2));\\n  \\n  //Distribution term\\n  float D = beckmannDistribution(NdotH, roughness);\\n\\n  //Fresnel term\\n  float F = pow(1.0 - VdotN, fresnel);\\n\\n  //Multiply terms and done\\n  return  G * F * D / max(3.14159265 * VdotN, 0.000001);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform sampler2D texture;\\n\\nvarying vec3 f_normal, f_lightDirection, f_eyeDirection, f_data, f_position;\\nvarying vec4 f_color;\\nvarying vec2 f_uv;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n  vec3 N = normalize(f_normal);\\n  vec3 L = normalize(f_lightDirection);\\n  vec3 V = normalize(f_eyeDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = min(1.0, max(0.0, cookTorranceSpecular(L, V, N, roughness, fresnel)));\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  vec4 surfaceColor = f_color * texture2D(texture, f_uv);\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = litColor * opacity;\\n}\\n\"]),o=n([\"precision highp float;\\n\\nprecision highp float;\\n#define GLSLIFY 1\\n\\nvec3 getOrthogonalVector(vec3 v) {\\n  // Return up-vector for only-z vector.\\n  // Return ax + by + cz = 0, a point that lies on the plane that has v as a normal and that isn't (0,0,0).\\n  // From the above if-statement we have ||a|| > 0  U  ||b|| > 0.\\n  // Assign z = 0, x = -b, y = a:\\n  // a*-b + b*a + c*0 = -ba + ba + 0 = 0\\n  if (v.x*v.x > v.z*v.z || v.y*v.y > v.z*v.z) {\\n    return normalize(vec3(-v.y, v.x, 0.0));\\n  } else {\\n    return normalize(vec3(0.0, v.z, -v.y));\\n  }\\n}\\n\\n// Calculate the tube vertex and normal at the given index.\\n//\\n// The returned vertex is for a tube ring with its center at origin, radius of length(d), pointing in the direction of d.\\n//\\n// Each tube segment is made up of a ring of vertices.\\n// These vertices are used to make up the triangles of the tube by connecting them together in the vertex array.\\n// The indexes of tube segments run from 0 to 8.\\n//\\nvec3 getTubePosition(vec3 d, float index, out vec3 normal) {\\n  float segmentCount = 8.0;\\n\\n  float angle = 2.0 * 3.14159 * (index / segmentCount);\\n\\n  vec3 u = getOrthogonalVector(d);\\n  vec3 v = normalize(cross(u, d));\\n\\n  vec3 x = u * cos(angle) * length(d);\\n  vec3 y = v * sin(angle) * length(d);\\n  vec3 v3 = x + y;\\n\\n  normal = normalize(v3);\\n\\n  return v3;\\n}\\n\\nattribute vec4 vector;\\nattribute vec4 position;\\nattribute vec4 id;\\n\\nuniform mat4 model, view, projection;\\nuniform float tubeScale;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  vec3 normal;\\n  vec3 XYZ = getTubePosition(mat3(model) * (tubeScale * vector.w * normalize(vector.xyz)), position.w, normal);\\n  vec4 tubePosition = model * vec4(position.xyz, 1.0) + vec4(XYZ, 0.0);\\n\\n  gl_Position = projection * view * tubePosition;\\n  f_id        = id;\\n  f_position  = position.xyz;\\n}\\n\"]),s=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3  clipBounds[2];\\nuniform float pickId;\\n\\nvarying vec3 f_position;\\nvarying vec4 f_id;\\n\\nvoid main() {\\n  if (outOfRange(clipBounds[0], clipBounds[1], f_position)) discard;\\n\\n  gl_FragColor = vec4(pickId, f_id.xyz);\\n}\"]);r.meshShader={vertex:i,fragment:a,attributes:[{name:\"position\",type:\"vec4\"},{name:\"color\",type:\"vec4\"},{name:\"uv\",type:\"vec2\"},{name:\"vector\",type:\"vec4\"}]},r.pickShader={vertex:o,fragment:s,attributes:[{name:\"position\",type:\"vec4\"},{name:\"id\",type:\"vec4\"},{name:\"vector\",type:\"vec4\"}]}},{glslify:347}],347:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],348:[function(t,e,r){\"use strict\";var n=t(\"gl-vec3\"),i=t(\"gl-vec4\"),a=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"],o=function(t,e,r,a){for(var o=0,s=0;s<t.length;s++)for(var l=t[s].velocities,c=0;c<l.length;c++)o=Math.max(o,n.length(l[c]));var u=t.map((function(t){return function(t,e,r,a){for(var o=t.points,s=t.velocities,l=t.divergences,c=[],u=[],f=[],h=[],p=[],d=[],g=0,m=0,v=i.create(),y=i.create(),x=0;x<o.length;x++){var b=o[x],_=s[x],w=l[x];0===e&&(w=.05*r),m=n.length(_)/a,v=i.create(),n.copy(v,_),v[3]=w;for(var T=0;T<8;T++)p[T]=[b[0],b[1],b[2],T];if(h.length>0)for(T=0;T<8;T++){var k=(T+1)%8;c.push(h[T],p[T],p[k],p[k],h[k],h[T]),f.push(y,v,v,v,y,y),d.push(g,m,m,m,g,g);var M=c.length;u.push([M-6,M-5,M-4],[M-3,M-2,M-1])}var A=h;h=p,p=A;var S=y;y=v,v=S;var E=g;g=m,m=E}return{positions:c,cells:u,vectors:f,vertexIntensity:d}}(t,r,a,o)})),f=[],h=[],p=[],d=[];for(s=0;s<u.length;s++){var g=u[s],m=f.length;f=f.concat(g.positions),p=p.concat(g.vectors),d=d.concat(g.vertexIntensity);for(c=0;c<g.cells.length;c++){var v=g.cells[c],y=[];h.push(y);for(var x=0;x<v.length;x++)y.push(v[x]+m)}}return{positions:f,cells:h,vectors:p,vertexIntensity:d,colormap:e}},s=function(t,e){var r,n=t.length;for(r=0;r<n;r++){var i=t[r];if(i===e)return r;if(i>e)return r-1}return r},l=function(t,e,r){return t<e?e:t>r?r:t},c=function(t){var e=1/0;t.sort((function(t,e){return t-e}));for(var r=t.length,n=1;n<r;n++){var i=Math.abs(t[n]-t[n-1]);i<e&&(e=i)}return e};e.exports=function(t,e){var r=t.startingPositions,i=t.maxLength||1e3,u=t.tubeSize||1,f=t.absoluteTubeSize,h=t.gridFill||\"+x+y+z\",p={};-1!==h.indexOf(\"-x\")&&(p.reversedX=!0),-1!==h.indexOf(\"-y\")&&(p.reversedY=!0),-1!==h.indexOf(\"-z\")&&(p.reversedZ=!0),p.filled=a.indexOf(h.replace(/-/g,\"\").replace(/\\+/g,\"\"));var d=t.getVelocity||function(e){return function(t,e,r){var i=e.vectors,a=e.meshgrid,o=t[0],c=t[1],u=t[2],f=a[0].length,h=a[1].length,p=a[2].length,d=s(a[0],o),g=s(a[1],c),m=s(a[2],u),v=d+1,y=g+1,x=m+1;if(d=l(d,0,f-1),v=l(v,0,f-1),g=l(g,0,h-1),y=l(y,0,h-1),m=l(m,0,p-1),x=l(x,0,p-1),d<0||g<0||m<0||v>f-1||y>h-1||x>p-1)return n.create();var b,_,w,T,k,M,A=a[0][d],S=a[0][v],E=a[1][g],C=a[1][y],L=a[2][m],I=(o-A)/(S-A),P=(c-E)/(C-E),z=(u-L)/(a[2][x]-L);switch(isFinite(I)||(I=.5),isFinite(P)||(P=.5),isFinite(z)||(z=.5),r.reversedX&&(d=f-1-d,v=f-1-v),r.reversedY&&(g=h-1-g,y=h-1-y),r.reversedZ&&(m=p-1-m,x=p-1-x),r.filled){case 5:k=m,M=x,w=g*p,T=y*p,b=d*p*h,_=v*p*h;break;case 4:k=m,M=x,b=d*p,_=v*p,w=g*p*f,T=y*p*f;break;case 3:w=g,T=y,k=m*h,M=x*h,b=d*h*p,_=v*h*p;break;case 2:w=g,T=y,b=d*h,_=v*h,k=m*h*f,M=x*h*f;break;case 1:b=d,_=v,k=m*f,M=x*f,w=g*f*p,T=y*f*p;break;default:b=d,_=v,w=g*f,T=y*f,k=m*f*h,M=x*f*h}var O=i[b+w+k],D=i[b+w+M],R=i[b+T+k],F=i[b+T+M],B=i[_+w+k],N=i[_+w+M],j=i[_+T+k],U=i[_+T+M],V=n.create(),q=n.create(),H=n.create(),G=n.create();n.lerp(V,O,B,I),n.lerp(q,D,N,I),n.lerp(H,R,j,I),n.lerp(G,F,U,I);var Y=n.create(),W=n.create();n.lerp(Y,V,H,P),n.lerp(W,q,G,P);var X=n.create();return n.lerp(X,Y,W,z),X}(e,t,p)},g=t.getDivergence||function(t,e){var r=n.create(),i=1e-4;n.add(r,t,[i,0,0]);var a=d(r);n.subtract(a,a,e),n.scale(a,a,1/i),n.add(r,t,[0,i,0]);var o=d(r);n.subtract(o,o,e),n.scale(o,o,1/i),n.add(r,t,[0,0,i]);var s=d(r);return n.subtract(s,s,e),n.scale(s,s,1/i),n.add(r,a,o),n.add(r,r,s),r},m=[],v=e[0][0],y=e[0][1],x=e[0][2],b=e[1][0],_=e[1][1],w=e[1][2],T=function(t){var e=t[0],r=t[1],n=t[2];return!(e<v||e>b||r<y||r>_||n<x||n>w)},k=10*n.distance(e[0],e[1])/i,M=k*k,A=1,S=0,E=r.length;E>1&&(A=function(t){for(var e=[],r=[],n=[],i={},a={},o={},s=t.length,l=0;l<s;l++){var u=t[l],f=u[0],h=u[1],p=u[2];i[f]||(e.push(f),i[f]=!0),a[h]||(r.push(h),a[h]=!0),o[p]||(n.push(p),o[p]=!0)}var d=c(e),g=c(r),m=c(n),v=Math.min(d,g,m);return isFinite(v)?v:1}(r));for(var C=0;C<E;C++){var L=n.create();n.copy(L,r[C]);var I=[L],P=[],z=d(L),O=L;P.push(z);var D=[],R=g(L,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F),m.push({points:I,velocities:P,divergences:D});for(var B=0;B<100*i&&I.length<i&&T(L);){B++;var N=n.clone(z),j=n.squaredLength(N);if(0===j)break;if(j>M&&n.scale(N,N,k/Math.sqrt(j)),n.add(N,N,L),z=d(N),n.squaredDistance(O,N)-M>-1e-4*M){I.push(N),O=N,P.push(z);R=g(N,z),F=n.length(R);isFinite(F)&&F>S&&(S=F),D.push(F)}L=N}}var U=o(m,t.colormap,S,A);return f?U.tubeScale=f:(0===S&&(S=1),U.tubeScale=.5*u*A/S),U};var u=t(\"./lib/shaders\"),f=t(\"gl-cone3d\").createMesh;e.exports.createTubeMesh=function(t,e){return f(t,e,{shaders:u,traceType:\"streamtube\"})}},{\"./lib/shaders\":346,\"gl-cone3d\":260,\"gl-vec3\":377,\"gl-vec4\":413}],349:[function(t,e,r){var n=t(\"gl-shader\"),i=t(\"glslify\"),a=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute vec3 f;\\nattribute vec3 normal;\\n\\nuniform vec3 objectOffset;\\nuniform mat4 model, view, projection, inverseModel;\\nuniform vec3 lightPosition, eyePosition;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 localCoordinate = vec3(uv.zw, f.x);\\n  worldCoordinate = objectOffset + localCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n  vec4 clipPosition = projection * view * worldPosition;\\n  gl_Position = clipPosition;\\n  kill = f.y;\\n  value = f.z;\\n  planeCoordinate = uv.xy;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Lighting geometry parameters\\n  vec4 cameraCoordinate = view * worldPosition;\\n  cameraCoordinate.xyz /= cameraCoordinate.w;\\n  lightDirection = lightPosition - cameraCoordinate.xyz;\\n  eyeDirection   = eyePosition - cameraCoordinate.xyz;\\n  surfaceNormal  = normalize((vec4(normal,0) * inverseModel).xyz);\\n}\\n\"]),o=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nfloat beckmannDistribution(float x, float roughness) {\\n  float NdotH = max(x, 0.0001);\\n  float cos2Alpha = NdotH * NdotH;\\n  float tan2Alpha = (cos2Alpha - 1.0) / cos2Alpha;\\n  float roughness2 = roughness * roughness;\\n  float denom = 3.141592653589793 * roughness2 * cos2Alpha * cos2Alpha;\\n  return exp(tan2Alpha / roughness2) / denom;\\n}\\n\\nfloat beckmannSpecular(\\n  vec3 lightDirection,\\n  vec3 viewDirection,\\n  vec3 surfaceNormal,\\n  float roughness) {\\n  return beckmannDistribution(dot(surfaceNormal, normalize(lightDirection + viewDirection)), roughness);\\n}\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec3 lowerBound, upperBound;\\nuniform float contourTint;\\nuniform vec4 contourColor;\\nuniform sampler2D colormap;\\nuniform vec3 clipBounds[2];\\nuniform float roughness, fresnel, kambient, kdiffuse, kspecular, opacity;\\nuniform float vertexColor;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  if (\\n    kill > 0.0 ||\\n    vColor.a == 0.0 ||\\n    outOfRange(clipBounds[0], clipBounds[1], worldCoordinate)\\n  ) discard;\\n\\n  vec3 N = normalize(surfaceNormal);\\n  vec3 V = normalize(eyeDirection);\\n  vec3 L = normalize(lightDirection);\\n\\n  if(gl_FrontFacing) {\\n    N = -N;\\n  }\\n\\n  float specular = max(beckmannSpecular(L, V, N, roughness), 0.);\\n  float diffuse  = min(kambient + kdiffuse * max(dot(N, L), 0.0), 1.0);\\n\\n  //decide how to interpolate color \\u2014 in vertex or in fragment\\n  vec4 surfaceColor =\\n    step(vertexColor, .5) * texture2D(colormap, vec2(value, value)) +\\n    step(.5, vertexColor) * vColor;\\n\\n  vec4 litColor = surfaceColor.a * vec4(diffuse * surfaceColor.rgb + kspecular * vec3(1,1,1) * specular,  1.0);\\n\\n  gl_FragColor = mix(litColor, contourColor, contourTint) * opacity;\\n}\\n\"]),s=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec4 uv;\\nattribute float f;\\n\\nuniform vec3 objectOffset;\\nuniform mat3 permutation;\\nuniform mat4 model, view, projection;\\nuniform float height, zOffset;\\nuniform sampler2D colormap;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 lightDirection, eyeDirection, surfaceNormal;\\nvarying vec4 vColor;\\n\\nvoid main() {\\n  vec3 dataCoordinate = permutation * vec3(uv.xy, height);\\n  worldCoordinate = objectOffset + dataCoordinate;\\n  vec4 worldPosition = model * vec4(worldCoordinate, 1.0);\\n\\n  vec4 clipPosition = projection * view * worldPosition;\\n  clipPosition.z += zOffset;\\n\\n  gl_Position = clipPosition;\\n  value = f + objectOffset.z;\\n  kill = -1.0;\\n  planeCoordinate = uv.zw;\\n\\n  vColor = texture2D(colormap, vec2(value, value));\\n\\n  //Don't do lighting for contours\\n  surfaceNormal   = vec3(1,0,0);\\n  eyeDirection    = vec3(0,1,0);\\n  lightDirection  = vec3(0,0,1);\\n}\\n\"]),l=i([\"precision highp float;\\n#define GLSLIFY 1\\n\\nbool outOfRange(float a, float b, float p) {\\n  return ((p > max(a, b)) || \\n          (p < min(a, b)));\\n}\\n\\nbool outOfRange(vec2 a, vec2 b, vec2 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y));\\n}\\n\\nbool outOfRange(vec3 a, vec3 b, vec3 p) {\\n  return (outOfRange(a.x, b.x, p.x) ||\\n          outOfRange(a.y, b.y, p.y) ||\\n          outOfRange(a.z, b.z, p.z));\\n}\\n\\nbool outOfRange(vec4 a, vec4 b, vec4 p) {\\n  return outOfRange(a.xyz, b.xyz, p.xyz);\\n}\\n\\nuniform vec2 shape;\\nuniform vec3 clipBounds[2];\\nuniform float pickId;\\n\\nvarying float value, kill;\\nvarying vec3 worldCoordinate;\\nvarying vec2 planeCoordinate;\\nvarying vec3 surfaceNormal;\\n\\nvec2 splitFloat(float v) {\\n  float vh = 255.0 * v;\\n  float upper = floor(vh);\\n  float lower = fract(vh);\\n  return vec2(upper / 255.0, floor(lower * 16.0) / 16.0);\\n}\\n\\nvoid main() {\\n  if ((kill > 0.0) ||\\n      (outOfRange(clipBounds[0], clipBounds[1], worldCoordinate))) discard;\\n\\n  vec2 ux = splitFloat(planeCoordinate.x / shape.x);\\n  vec2 uy = splitFloat(planeCoordinate.y / shape.y);\\n  gl_FragColor = vec4(pickId, ux.x, uy.x, ux.y + (uy.y/16.0));\\n}\\n\"]);r.createShader=function(t){var e=n(t,a,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createPickShader=function(t){var e=n(t,a,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"vec3\"},{name:\"normal\",type:\"vec3\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e.attributes.normal.location=2,e},r.createContourShader=function(t){var e=n(t,s,o,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e},r.createPickContourShader=function(t){var e=n(t,s,l,null,[{name:\"uv\",type:\"vec4\"},{name:\"f\",type:\"float\"}]);return e.attributes.uv.location=0,e.attributes.f.location=1,e}},{\"gl-shader\":335,glslify:350}],350:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],351:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.gl,r=y(e),n=b(e),s=x(e),l=_(e),c=i(e),u=a(e,[{buffer:c,size:4,stride:40,offset:0},{buffer:c,size:3,stride:40,offset:16},{buffer:c,size:3,stride:40,offset:28}]),f=i(e),h=a(e,[{buffer:f,size:4,stride:20,offset:0},{buffer:f,size:1,stride:20,offset:16}]),p=i(e),d=a(e,[{buffer:p,size:2,type:e.FLOAT}]),g=o(e,1,256,e.RGBA,e.UNSIGNED_BYTE);g.minFilter=e.LINEAR,g.magFilter=e.LINEAR;var m=new A(e,[0,0],[[0,0,0],[0,0,0]],r,n,c,u,g,s,l,f,h,p,d,[0,0,0]),v={levels:[[],[],[]]};for(var w in t)v[w]=t[w];return v.colormap=v.colormap||\"jet\",m.update(v),m};var n=t(\"bit-twiddle\"),i=t(\"gl-buffer\"),a=t(\"gl-vao\"),o=t(\"gl-texture2d\"),s=t(\"typedarray-pool\"),l=t(\"colormap\"),c=t(\"ndarray-ops\"),u=t(\"ndarray-pack\"),f=t(\"ndarray\"),h=t(\"surface-nets\"),p=t(\"gl-mat4/multiply\"),d=t(\"gl-mat4/invert\"),g=t(\"binary-search-bounds\"),m=t(\"ndarray-gradient\"),v=t(\"./lib/shaders\"),y=v.createShader,x=v.createContourShader,b=v.createPickShader,_=v.createPickContourShader,w=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1],T=[[0,0],[0,1],[1,0],[1,1],[1,0],[0,1]],k=[[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0,0]];function M(t,e,r,n,i){this.position=t,this.index=e,this.uv=r,this.level=n,this.dataCoordinate=i}!function(){for(var t=0;t<3;++t){var e=k[t],r=(t+2)%3;e[(t+1)%3+0]=1,e[r+3]=1,e[t+6]=1}}();function A(t,e,r,n,i,a,o,l,c,u,h,p,d,g,m){this.gl=t,this.shape=e,this.bounds=r,this.objectOffset=m,this.intensityBounds=[],this._shader=n,this._pickShader=i,this._coordinateBuffer=a,this._vao=o,this._colorMap=l,this._contourShader=c,this._contourPickShader=u,this._contourBuffer=h,this._contourVAO=p,this._contourOffsets=[[],[],[]],this._contourCounts=[[],[],[]],this._vertexCount=0,this._pickResult=new M([0,0,0],[0,0],[0,0],[0,0,0],[0,0,0]),this._dynamicBuffer=d,this._dynamicVAO=g,this._dynamicOffsets=[0,0,0],this._dynamicCounts=[0,0,0],this.contourWidth=[1,1,1],this.contourLevels=[[1],[1],[1]],this.contourTint=[0,0,0],this.contourColor=[[.5,.5,.5,1],[.5,.5,.5,1],[.5,.5,.5,1]],this.showContour=!0,this.showSurface=!0,this.enableHighlight=[!0,!0,!0],this.highlightColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.highlightTint=[1,1,1],this.highlightLevel=[-1,-1,-1],this.enableDynamic=[!0,!0,!0],this.dynamicLevel=[NaN,NaN,NaN],this.dynamicColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.dynamicTint=[1,1,1],this.dynamicWidth=[1,1,1],this.axesBounds=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]],this.surfaceProject=[!1,!1,!1],this.contourProject=[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],this.colorBounds=[!1,!1],this._field=[f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0]),f(s.mallocFloat(1024),[0,0])],this.pickId=1,this.clipBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.snapToData=!1,this.pixelRatio=1,this.opacity=1,this.lightPosition=[10,1e4,0],this.ambientLight=.8,this.diffuseLight=.8,this.specularLight=2,this.roughness=.5,this.fresnel=1.5,this.vertexColor=0,this.dirty=!0}var S=A.prototype;S.genColormap=function(t,e){var r=!1,n=u([l({colormap:t,nshades:256,format:\"rgba\"}).map((function(t,n){var i=e?function(t,e){if(!e)return 1;if(!e.length)return 1;for(var r=0;r<e.length;++r){if(e.length<2)return 1;if(e[r][0]===t)return e[r][1];if(e[r][0]>t&&r>0){var n=(e[r][0]-t)/(e[r][0]-e[r-1][0]);return e[r][1]*(1-n)+n*e[r-1][1]}}return 1}(n/255,e):t[3];return i<1&&(r=!0),[t[0],t[1],t[2],255*i]}))]);return c.divseq(n,255),this.hasAlphaScale=r,n},S.isTransparent=function(){return this.opacity<1||this.hasAlphaScale},S.isOpaque=function(){return!this.isTransparent()},S.pickSlots=1,S.setPickBase=function(t){this.pickId=t};var E=[0,0,0],C={showSurface:!1,showContour:!1,projections:[w.slice(),w.slice(),w.slice()],clipBounds:[[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]],[[0,0,0],[0,0,0]]]};function L(t,e){var r,n,i,a=e.axes&&e.axes.lastCubeProps.axis||E,o=e.showSurface,s=e.showContour;for(r=0;r<3;++r)for(o=o||e.surfaceProject[r],n=0;n<3;++n)s=s||e.contourProject[r][n];for(r=0;r<3;++r){var l=C.projections[r];for(n=0;n<16;++n)l[n]=0;for(n=0;n<4;++n)l[5*n]=1;l[5*r]=0,l[12+r]=e.axesBounds[+(a[r]>0)][r],p(l,t.model,l);var c=C.clipBounds[r];for(i=0;i<2;++i)for(n=0;n<3;++n)c[i][n]=t.clipBounds[i][n];c[0][r]=-1e8,c[1][r]=1e8}return C.showSurface=o,C.showContour=s,C}var I={model:w,view:w,projection:w,inverseModel:w.slice(),lowerBound:[0,0,0],upperBound:[0,0,0],colorMap:0,clipBounds:[[0,0,0],[0,0,0]],height:0,contourTint:0,contourColor:[0,0,0,1],permutation:[1,0,0,0,1,0,0,0,1],zOffset:-1e-4,objectOffset:[0,0,0],kambient:1,kdiffuse:1,kspecular:1,lightPosition:[1e3,1e3,1e3],eyePosition:[0,0,0],roughness:1,fresnel:1,opacity:1,vertexColor:0},P=w.slice(),z=[1,0,0,0,1,0,0,0,1];function O(t,e){t=t||{};var r=this.gl;r.disable(r.CULL_FACE),this._colorMap.bind(0);var n=I;n.model=t.model||w,n.view=t.view||w,n.projection=t.projection||w,n.lowerBound=[this.bounds[0][0],this.bounds[0][1],this.colorBounds[0]||this.bounds[0][2]],n.upperBound=[this.bounds[1][0],this.bounds[1][1],this.colorBounds[1]||this.bounds[1][2]],n.objectOffset=this.objectOffset,n.contourColor=this.contourColor[0],n.inverseModel=d(n.inverseModel,n.model);for(var i=0;i<2;++i)for(var a=n.clipBounds[i],o=0;o<3;++o)a[o]=Math.min(Math.max(this.clipBounds[i][o],-1e8),1e8);n.kambient=this.ambientLight,n.kdiffuse=this.diffuseLight,n.kspecular=this.specularLight,n.roughness=this.roughness,n.fresnel=this.fresnel,n.opacity=this.opacity,n.height=0,n.permutation=z,n.vertexColor=this.vertexColor;var s=P;for(p(s,n.view,n.model),p(s,n.projection,s),d(s,s),i=0;i<3;++i)n.eyePosition[i]=s[12+i]/s[15];var l=s[15];for(i=0;i<3;++i)l+=this.lightPosition[i]*s[4*i+3];for(i=0;i<3;++i){var c=s[12+i];for(o=0;o<3;++o)c+=s[4*o+i]*this.lightPosition[o];n.lightPosition[i]=c/l}var u=L(n,this);if(u.showSurface){for(this._shader.bind(),this._shader.uniforms=n,this._vao.bind(),this.showSurface&&this._vertexCount&&this._vao.draw(r.TRIANGLES,this._vertexCount),i=0;i<3;++i)this.surfaceProject[i]&&this.vertexCount&&(this._shader.uniforms.model=u.projections[i],this._shader.uniforms.clipBounds=u.clipBounds[i],this._vao.draw(r.TRIANGLES,this._vertexCount));this._vao.unbind()}if(u.showContour){var f=this._contourShader;n.kambient=1,n.kdiffuse=0,n.kspecular=0,n.opacity=1,f.bind(),f.uniforms=n;var h=this._contourVAO;for(h.bind(),i=0;i<3;++i)for(f.uniforms.permutation=k[i],r.lineWidth(this.contourWidth[i]*this.pixelRatio),o=0;o<this.contourLevels[i].length;++o)o===this.highlightLevel[i]?(f.uniforms.contourColor=this.highlightColor[i],f.uniforms.contourTint=this.highlightTint[i]):0!==o&&o-1!==this.highlightLevel[i]||(f.uniforms.contourColor=this.contourColor[i],f.uniforms.contourTint=this.contourTint[i]),this._contourCounts[i][o]&&(f.uniforms.height=this.contourLevels[i][o],h.draw(r.LINES,this._contourCounts[i][o],this._contourOffsets[i][o]));for(i=0;i<3;++i)for(f.uniforms.model=u.projections[i],f.uniforms.clipBounds=u.clipBounds[i],o=0;o<3;++o)if(this.contourProject[i][o]){f.uniforms.permutation=k[o],r.lineWidth(this.contourWidth[o]*this.pixelRatio);for(var g=0;g<this.contourLevels[o].length;++g)g===this.highlightLevel[o]?(f.uniforms.contourColor=this.highlightColor[o],f.uniforms.contourTint=this.highlightTint[o]):0!==g&&g-1!==this.highlightLevel[o]||(f.uniforms.contourColor=this.contourColor[o],f.uniforms.contourTint=this.contourTint[o]),this._contourCounts[o][g]&&(f.uniforms.height=this.contourLevels[o][g],h.draw(r.LINES,this._contourCounts[o][g],this._contourOffsets[o][g]))}for(h.unbind(),(h=this._dynamicVAO).bind(),i=0;i<3;++i)if(0!==this._dynamicCounts[i])for(f.uniforms.model=n.model,f.uniforms.clipBounds=n.clipBounds,f.uniforms.permutation=k[i],r.lineWidth(this.dynamicWidth[i]*this.pixelRatio),f.uniforms.contourColor=this.dynamicColor[i],f.uniforms.contourTint=this.dynamicTint[i],f.uniforms.height=this.dynamicLevel[i],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]),o=0;o<3;++o)this.contourProject[o][i]&&(f.uniforms.model=u.projections[o],f.uniforms.clipBounds=u.clipBounds[o],h.draw(r.LINES,this._dynamicCounts[i],this._dynamicOffsets[i]));h.unbind()}}S.draw=function(t){return O.call(this,t,!1)},S.drawTransparent=function(t){return O.call(this,t,!0)};var D={model:w,view:w,projection:w,inverseModel:w,clipBounds:[[0,0,0],[0,0,0]],height:0,shape:[0,0],pickId:0,lowerBound:[0,0,0],upperBound:[0,0,0],zOffset:0,objectOffset:[0,0,0],permutation:[1,0,0,0,1,0,0,0,1],lightPosition:[0,0,0],eyePosition:[0,0,0]};function R(t,e){return Array.isArray(t)?[e(t[0]),e(t[1]),e(t[2])]:[e(t),e(t),e(t)]}function F(t){return Array.isArray(t)?3===t.length?[t[0],t[1],t[2],1]:[t[0],t[1],t[2],t[3]]:[0,0,0,1]}function B(t){if(Array.isArray(t)){if(Array.isArray(t))return[F(t[0]),F(t[1]),F(t[2])];var e=F(t);return[e.slice(),e.slice(),e.slice()]}}S.drawPick=function(t){t=t||{};var e=this.gl;e.disable(e.CULL_FACE);var r=D;r.model=t.model||w,r.view=t.view||w,r.projection=t.projection||w,r.shape=this._field[2].shape,r.pickId=this.pickId/255,r.lowerBound=this.bounds[0],r.upperBound=this.bounds[1],r.objectOffset=this.objectOffset,r.permutation=z;for(var n=0;n<2;++n)for(var i=r.clipBounds[n],a=0;a<3;++a)i[a]=Math.min(Math.max(this.clipBounds[n][a],-1e8),1e8);var o=L(r,this);if(o.showSurface){for(this._pickShader.bind(),this._pickShader.uniforms=r,this._vao.bind(),this._vao.draw(e.TRIANGLES,this._vertexCount),n=0;n<3;++n)this.surfaceProject[n]&&(this._pickShader.uniforms.model=o.projections[n],this._pickShader.uniforms.clipBounds=o.clipBounds[n],this._vao.draw(e.TRIANGLES,this._vertexCount));this._vao.unbind()}if(o.showContour){var s=this._contourPickShader;s.bind(),s.uniforms=r;var l=this._contourVAO;for(l.bind(),a=0;a<3;++a)for(e.lineWidth(this.contourWidth[a]*this.pixelRatio),s.uniforms.permutation=k[a],n=0;n<this.contourLevels[a].length;++n)this._contourCounts[a][n]&&(s.uniforms.height=this.contourLevels[a][n],l.draw(e.LINES,this._contourCounts[a][n],this._contourOffsets[a][n]));for(n=0;n<3;++n)for(s.uniforms.model=o.projections[n],s.uniforms.clipBounds=o.clipBounds[n],a=0;a<3;++a)if(this.contourProject[n][a]){s.uniforms.permutation=k[a],e.lineWidth(this.contourWidth[a]*this.pixelRatio);for(var c=0;c<this.contourLevels[a].length;++c)this._contourCounts[a][c]&&(s.uniforms.height=this.contourLevels[a][c],l.draw(e.LINES,this._contourCounts[a][c],this._contourOffsets[a][c]))}l.unbind()}},S.pick=function(t){if(!t)return null;if(t.id!==this.pickId)return null;var e=this._field[2].shape,r=this._pickResult,n=e[0]*(t.value[0]+(t.value[2]>>4)/16)/255,i=Math.floor(n),a=n-i,o=e[1]*(t.value[1]+(15&t.value[2])/16)/255,s=Math.floor(o),l=o-s;i+=1,s+=1;var c=r.position;c[0]=c[1]=c[2]=0;for(var u=0;u<2;++u)for(var f=u?a:1-a,h=0;h<2;++h)for(var p=i+u,d=s+h,m=f*(h?l:1-l),v=0;v<3;++v)c[v]+=this._field[v].get(p,d)*m;for(var y=this._pickResult.level,x=0;x<3;++x)if(y[x]=g.le(this.contourLevels[x],c[x]),y[x]<0)this.contourLevels[x].length>0&&(y[x]=0);else if(y[x]<this.contourLevels[x].length-1){var b=this.contourLevels[x][y[x]],_=this.contourLevels[x][y[x]+1];Math.abs(b-c[x])>Math.abs(_-c[x])&&(y[x]+=1)}for(r.index[0]=a<.5?i:i+1,r.index[1]=l<.5?s:s+1,r.uv[0]=n/e[0],r.uv[1]=o/e[1],v=0;v<3;++v)r.dataCoordinate[v]=this._field[v].get(r.index[0],r.index[1]);return r},S.padField=function(t,e){var r=e.shape.slice(),n=t.shape.slice();c.assign(t.lo(1,1).hi(r[0],r[1]),e),c.assign(t.lo(1).hi(r[0],1),e.hi(r[0],1)),c.assign(t.lo(1,n[1]-1).hi(r[0],1),e.lo(0,r[1]-1).hi(r[0],1)),c.assign(t.lo(0,1).hi(1,r[1]),e.hi(1)),c.assign(t.lo(n[0]-1,1).hi(1,r[1]),e.lo(r[0]-1)),t.set(0,0,e.get(0,0)),t.set(0,n[1]-1,e.get(0,r[1]-1)),t.set(n[0]-1,0,e.get(r[0]-1,0)),t.set(n[0]-1,n[1]-1,e.get(r[0]-1,r[1]-1))},S.update=function(t){t=t||{},this.objectOffset=t.objectOffset||this.objectOffset,this.dirty=!0,\"contourWidth\"in t&&(this.contourWidth=R(t.contourWidth,Number)),\"showContour\"in t&&(this.showContour=R(t.showContour,Boolean)),\"showSurface\"in t&&(this.showSurface=!!t.showSurface),\"contourTint\"in t&&(this.contourTint=R(t.contourTint,Boolean)),\"contourColor\"in t&&(this.contourColor=B(t.contourColor)),\"contourProject\"in t&&(this.contourProject=R(t.contourProject,(function(t){return R(t,Boolean)}))),\"surfaceProject\"in t&&(this.surfaceProject=t.surfaceProject),\"dynamicColor\"in t&&(this.dynamicColor=B(t.dynamicColor)),\"dynamicTint\"in t&&(this.dynamicTint=R(t.dynamicTint,Number)),\"dynamicWidth\"in t&&(this.dynamicWidth=R(t.dynamicWidth,Number)),\"opacity\"in t&&(this.opacity=t.opacity),\"opacityscale\"in t&&(this.opacityscale=t.opacityscale),\"colorBounds\"in t&&(this.colorBounds=t.colorBounds),\"vertexColor\"in t&&(this.vertexColor=t.vertexColor?1:0),\"colormap\"in t&&this._colorMap.setPixels(this.genColormap(t.colormap,this.opacityscale));var e=t.field||t.coords&&t.coords[2]||null,r=!1;if(e||(e=this._field[2].shape[0]||this._field[2].shape[2]?this._field[2].lo(1,1).hi(this._field[2].shape[0]-2,this._field[2].shape[1]-2):this._field[2].hi(0,0)),\"field\"in t||\"coords\"in t){var i=(e.shape[0]+2)*(e.shape[1]+2);i>this._field[2].data.length&&(s.freeFloat(this._field[2].data),this._field[2].data=s.mallocFloat(n.nextPow2(i))),this._field[2]=f(this._field[2].data,[e.shape[0]+2,e.shape[1]+2]),this.padField(this._field[2],e),this.shape=e.shape.slice();for(var a=this.shape,o=0;o<2;++o)this._field[2].size>this._field[o].data.length&&(s.freeFloat(this._field[o].data),this._field[o].data=s.mallocFloat(this._field[2].size)),this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2]);if(t.coords){var l=t.coords;if(!Array.isArray(l)||3!==l.length)throw new Error(\"gl-surface: invalid coordinates for x/y\");for(o=0;o<2;++o){var c=l[o];for(v=0;v<2;++v)if(c.shape[v]!==a[v])throw new Error(\"gl-surface: coords have incorrect shape\");this.padField(this._field[o],c)}}else if(t.ticks){var u=t.ticks;if(!Array.isArray(u)||2!==u.length)throw new Error(\"gl-surface: invalid ticks\");for(o=0;o<2;++o){var p=u[o];if((Array.isArray(p)||p.length)&&(p=f(p)),p.shape[0]!==a[o])throw new Error(\"gl-surface: invalid tick length\");var d=f(p.data,a);d.stride[o]=p.stride[0],d.stride[1^o]=0,this.padField(this._field[o],d)}}else{for(o=0;o<2;++o){var g=[0,0];g[o]=1,this._field[o]=f(this._field[o].data,[a[0]+2,a[1]+2],g,0)}this._field[0].set(0,0,0);for(var v=0;v<a[0];++v)this._field[0].set(v+1,0,v);for(this._field[0].set(a[0]+1,0,a[0]-1),this._field[1].set(0,0,0),v=0;v<a[1];++v)this._field[1].set(0,v+1,v);this._field[1].set(0,a[1]+1,a[1]-1)}var y=this._field,x=f(s.mallocFloat(3*y[2].size*2),[3,a[0]+2,a[1]+2,2]);for(o=0;o<3;++o)m(x.pick(o),y[o],\"mirror\");var b=f(s.mallocFloat(3*y[2].size),[a[0]+2,a[1]+2,3]);for(o=0;o<a[0]+2;++o)for(v=0;v<a[1]+2;++v){var _=x.get(0,o,v,0),w=x.get(0,o,v,1),k=x.get(1,o,v,0),M=x.get(1,o,v,1),A=x.get(2,o,v,0),S=x.get(2,o,v,1),E=k*S-M*A,C=A*w-S*_,L=_*M-w*k,I=Math.sqrt(E*E+C*C+L*L);I<1e-8?(I=Math.max(Math.abs(E),Math.abs(C),Math.abs(L)))<1e-8?(L=1,C=E=0,I=1):I=1/I:I=1/Math.sqrt(I),b.set(o,v,0,E*I),b.set(o,v,1,C*I),b.set(o,v,2,L*I)}s.free(x.data);var P=[1/0,1/0,1/0],z=[-1/0,-1/0,-1/0],O=1/0,D=-1/0,F=(a[0]-1)*(a[1]-1)*6,N=s.mallocFloat(n.nextPow2(10*F)),j=0,U=0;for(o=0;o<a[0]-1;++o)t:for(v=0;v<a[1]-1;++v){for(var V=0;V<2;++V)for(var q=0;q<2;++q)for(var H=0;H<3;++H){var G=this._field[H].get(1+o+V,1+v+q);if(isNaN(G)||!isFinite(G))continue t}for(H=0;H<6;++H){var Y=o+T[H][0],W=v+T[H][1],X=this._field[0].get(Y+1,W+1),Z=this._field[1].get(Y+1,W+1);G=this._field[2].get(Y+1,W+1),E=b.get(Y+1,W+1,0),C=b.get(Y+1,W+1,1),L=b.get(Y+1,W+1,2),t.intensity&&(J=t.intensity.get(Y,W));var J=t.intensity?t.intensity.get(Y,W):G+this.objectOffset[2];N[j++]=Y,N[j++]=W,N[j++]=X,N[j++]=Z,N[j++]=G,N[j++]=0,N[j++]=J,N[j++]=E,N[j++]=C,N[j++]=L,P[0]=Math.min(P[0],X+this.objectOffset[0]),P[1]=Math.min(P[1],Z+this.objectOffset[1]),P[2]=Math.min(P[2],G+this.objectOffset[2]),O=Math.min(O,J),z[0]=Math.max(z[0],X+this.objectOffset[0]),z[1]=Math.max(z[1],Z+this.objectOffset[1]),z[2]=Math.max(z[2],G+this.objectOffset[2]),D=Math.max(D,J),U+=1}}for(t.intensityBounds&&(O=+t.intensityBounds[0],D=+t.intensityBounds[1]),o=6;o<j;o+=10)N[o]=(N[o]-O)/(D-O);this._vertexCount=U,this._coordinateBuffer.update(N.subarray(0,j)),s.freeFloat(N),s.free(b.data),this.bounds=[P,z],this.intensity=t.intensity||this._field[2],this.intensityBounds[0]===O&&this.intensityBounds[1]===D||(r=!0),this.intensityBounds=[O,D]}if(\"levels\"in t){var K=t.levels;for(K=Array.isArray(K[0])?K.slice():[[],[],K],o=0;o<3;++o)K[o]=K[o].slice(),K[o].sort((function(t,e){return t-e}));for(o=0;o<3;++o)for(v=0;v<K[o].length;++v)K[o][v]-=this.objectOffset[o];t:for(o=0;o<3;++o){if(K[o].length!==this.contourLevels[o].length){r=!0;break}for(v=0;v<K[o].length;++v)if(K[o][v]!==this.contourLevels[o][v]){r=!0;break t}}this.contourLevels=K}if(r){y=this._field,a=this.shape;for(var Q=[],$=0;$<3;++$){var tt=this.contourLevels[$],et=[],rt=[],nt=[0,0,0];for(o=0;o<tt.length;++o){var it=h(this._field[$],tt[o]);et.push(Q.length/5|0),U=0;t:for(v=0;v<it.cells.length;++v){var at=it.cells[v];for(H=0;H<2;++H){var ot=it.positions[at[H]],st=ot[0],lt=0|Math.floor(st),ct=st-lt,ut=ot[1],ft=0|Math.floor(ut),ht=ut-ft,pt=!1;e:for(var dt=0;dt<3;++dt){nt[dt]=0;var gt=($+dt+1)%3;for(V=0;V<2;++V){var mt=V?ct:1-ct;for(Y=0|Math.min(Math.max(lt+V,0),a[0]),q=0;q<2;++q){var vt=q?ht:1-ht;if(W=0|Math.min(Math.max(ft+q,0),a[1]),G=dt<2?this._field[gt].get(Y,W):(this.intensity.get(Y,W)-this.intensityBounds[0])/(this.intensityBounds[1]-this.intensityBounds[0]),!isFinite(G)||isNaN(G)){pt=!0;break e}var yt=mt*vt;nt[dt]+=yt*G}}}if(pt){if(H>0){for(var xt=0;xt<5;++xt)Q.pop();U-=1}continue t}Q.push(nt[0],nt[1],ot[0],ot[1],nt[2]),U+=1}}rt.push(U)}this._contourOffsets[$]=et,this._contourCounts[$]=rt}var bt=s.mallocFloat(Q.length);for(o=0;o<Q.length;++o)bt[o]=Q[o];this._contourBuffer.update(bt),s.freeFloat(bt)}},S.dispose=function(){this._shader.dispose(),this._vao.dispose(),this._coordinateBuffer.dispose(),this._colorMap.dispose(),this._contourBuffer.dispose(),this._contourVAO.dispose(),this._contourShader.dispose(),this._contourPickShader.dispose(),this._dynamicBuffer.dispose(),this._dynamicVAO.dispose();for(var t=0;t<3;++t)s.freeFloat(this._field[t].data)},S.highlight=function(t){var e,r;if(!t)return this._dynamicCounts=[0,0,0],this.dyanamicLevel=[NaN,NaN,NaN],void(this.highlightLevel=[-1,-1,-1]);for(e=0;e<3;++e)this.enableHighlight[e]?this.highlightLevel[e]=t.level[e]:this.highlightLevel[e]=-1;for(r=this.snapToData?t.dataCoordinate:t.position,e=0;e<3;++e)r[e]-=this.objectOffset[e];if(this.enableDynamic[0]&&r[0]!==this.dynamicLevel[0]||this.enableDynamic[1]&&r[1]!==this.dynamicLevel[1]||this.enableDynamic[2]&&r[2]!==this.dynamicLevel[2]){for(var n=0,i=this.shape,a=s.mallocFloat(12*i[0]*i[1]),o=0;o<3;++o)if(this.enableDynamic[o]){this.dynamicLevel[o]=r[o];var l=(o+1)%3,c=(o+2)%3,u=this._field[o],f=this._field[l],p=this._field[c],d=h(u,r[o]),g=d.cells,m=d.positions;for(this._dynamicOffsets[o]=n,e=0;e<g.length;++e)for(var v=g[e],y=0;y<2;++y){var x=m[v[y]],b=+x[0],_=0|b,w=0|Math.min(_+1,i[0]),T=b-_,k=1-T,M=+x[1],A=0|M,S=0|Math.min(A+1,i[1]),E=M-A,C=1-E,L=k*C,I=k*E,P=T*C,z=T*E,O=L*f.get(_,A)+I*f.get(_,S)+P*f.get(w,A)+z*f.get(w,S),D=L*p.get(_,A)+I*p.get(_,S)+P*p.get(w,A)+z*p.get(w,S);if(isNaN(O)||isNaN(D)){y&&(n-=1);break}a[2*n+0]=O,a[2*n+1]=D,n+=1}this._dynamicCounts[o]=n-this._dynamicOffsets[o]}else this.dynamicLevel[o]=NaN,this._dynamicCounts[o]=0;this._dynamicBuffer.update(a.subarray(0,2*n)),s.freeFloat(a)}}},{\"./lib/shaders\":349,\"binary-search-bounds\":96,\"bit-twiddle\":97,colormap:131,\"gl-buffer\":259,\"gl-mat4/invert\":293,\"gl-mat4/multiply\":295,\"gl-texture2d\":353,\"gl-vao\":358,ndarray:495,\"ndarray-gradient\":488,\"ndarray-ops\":490,\"ndarray-pack\":491,\"surface-nets\":570,\"typedarray-pool\":595}],352:[function(t,e,r){\"use strict\";var n=t(\"css-font\"),i=t(\"pick-by-alias\"),a=t(\"regl\"),o=t(\"gl-util/context\"),s=t(\"es6-weak-map\"),l=t(\"color-normalize\"),c=t(\"font-atlas\"),u=t(\"typedarray-pool\"),f=t(\"parse-rect\"),h=t(\"is-plain-obj\"),p=t(\"parse-unit\"),d=t(\"to-px\"),g=t(\"detect-kerning\"),m=t(\"object-assign\"),v=t(\"font-measure\"),y=t(\"flatten-vertex-data\"),x=t(\"bit-twiddle\").nextPow2,b=new s,_=!1;if(document.body){var w=document.body.appendChild(document.createElement(\"div\"));w.style.font=\"italic small-caps bold condensed 16px/2 cursive\",getComputedStyle(w).fontStretch&&(_=!0),document.body.removeChild(w)}var T=function(t){!function(t){return\"function\"==typeof t&&t._gl&&t.prop&&t.texture&&t.buffer}(t)?this.gl=o(t):(t={regl:t},this.gl=t.regl._gl),this.shader=b.get(this.gl),this.shader?this.regl=this.shader.regl:this.regl=t.regl||a({gl:this.gl}),this.charBuffer=this.regl.buffer({type:\"uint8\",usage:\"stream\"}),this.sizeBuffer=this.regl.buffer({type:\"float\",usage:\"stream\"}),this.shader||(this.shader=this.createShader(),b.set(this.gl,this.shader)),this.batch=[],this.fontSize=[],this.font=[],this.fontAtlas=[],this.draw=this.shader.draw.bind(this),this.render=function(){this.regl._refresh(),this.draw(this.batch)},this.canvas=this.gl.canvas,this.update(h(t)?t:{})};T.prototype.createShader=function(){var t=this.regl,e=t({blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},stencil:{enable:!1},depth:{enable:!1},count:t.prop(\"count\"),offset:t.prop(\"offset\"),attributes:{charOffset:{offset:4,stride:8,buffer:t.this(\"sizeBuffer\")},width:{offset:0,stride:8,buffer:t.this(\"sizeBuffer\")},char:t.this(\"charBuffer\"),position:t.this(\"position\")},uniforms:{atlasSize:function(t,e){return[e.atlas.width,e.atlas.height]},atlasDim:function(t,e){return[e.atlas.cols,e.atlas.rows]},atlas:function(t,e){return e.atlas.texture},charStep:function(t,e){return e.atlas.step},em:function(t,e){return e.atlas.em},color:t.prop(\"color\"),opacity:t.prop(\"opacity\"),viewport:t.this(\"viewportArray\"),scale:t.this(\"scale\"),align:t.prop(\"align\"),baseline:t.prop(\"baseline\"),translate:t.this(\"translate\"),positionOffset:t.prop(\"positionOffset\")},primitive:\"points\",viewport:t.this(\"viewport\"),vert:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tattribute float width, charOffset, char;\\n\\t\\t\\tattribute vec2 position;\\n\\t\\t\\tuniform float fontSize, charStep, em, align, baseline;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tuniform vec4 color;\\n\\t\\t\\tuniform vec2 atlasSize, atlasDim, scale, translate, positionOffset;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\t\"+(T.normalViewport?\"\":\"vec2 positionOffset = vec2(positionOffset.x,- positionOffset.y);\")+\"\\n\\n\\t\\t\\t\\tvec2 offset = floor(em * (vec2(align + charOffset, baseline)\\n\\t\\t\\t\\t\\t+ positionOffset))\\n\\t\\t\\t\\t\\t/ (viewport.zw * scale.xy);\\n\\n\\t\\t\\t\\tvec2 position = (position + translate) * scale;\\n\\t\\t\\t\\tposition += offset * scale;\\n\\n\\t\\t\\t\\t\"+(T.normalViewport?\"position.y = 1. - position.y;\":\"\")+\"\\n\\n\\t\\t\\t\\tcharCoord = position * viewport.zw + viewport.xy;\\n\\n\\t\\t\\t\\tgl_Position = vec4(position * 2. - 1., 0, 1);\\n\\n\\t\\t\\t\\tgl_PointSize = charStep;\\n\\n\\t\\t\\t\\tcharId.x = mod(char, atlasDim.x);\\n\\t\\t\\t\\tcharId.y = floor(char / atlasDim.x);\\n\\n\\t\\t\\t\\tcharWidth = width * em;\\n\\n\\t\\t\\t\\tfontColor = color / 255.;\\n\\t\\t\\t}\",frag:\"\\n\\t\\t\\tprecision highp float;\\n\\t\\t\\tuniform sampler2D atlas;\\n\\t\\t\\tuniform float fontSize, charStep, opacity;\\n\\t\\t\\tuniform vec2 atlasSize;\\n\\t\\t\\tuniform vec4 viewport;\\n\\t\\t\\tvarying vec4 fontColor;\\n\\t\\t\\tvarying vec2 charCoord, charId;\\n\\t\\t\\tvarying float charWidth;\\n\\n\\t\\t\\tfloat lightness(vec4 color) {\\n\\t\\t\\t\\treturn color.r * 0.299 + color.g * 0.587 + color.b * 0.114;\\n\\t\\t\\t}\\n\\n\\t\\t\\tvoid main () {\\n\\t\\t\\t\\tvec2 uv = gl_FragCoord.xy - charCoord + charStep * .5;\\n\\t\\t\\t\\tfloat halfCharStep = floor(charStep * .5 + .5);\\n\\n\\t\\t\\t\\t// invert y and shift by 1px (FF expecially needs that)\\n\\t\\t\\t\\tuv.y = charStep - uv.y;\\n\\n\\t\\t\\t\\t// ignore points outside of character bounding box\\n\\t\\t\\t\\tfloat halfCharWidth = ceil(charWidth * .5);\\n\\t\\t\\t\\tif (floor(uv.x) > halfCharStep + halfCharWidth ||\\n\\t\\t\\t\\t\\tfloor(uv.x) < halfCharStep - halfCharWidth) return;\\n\\n\\t\\t\\t\\tuv += charId * charStep;\\n\\t\\t\\t\\tuv = uv / atlasSize;\\n\\n\\t\\t\\t\\tvec4 color = fontColor;\\n\\t\\t\\t\\tvec4 mask = texture2D(atlas, uv);\\n\\n\\t\\t\\t\\tfloat maskY = lightness(mask);\\n\\t\\t\\t\\t// float colorY = lightness(color);\\n\\t\\t\\t\\tcolor.a *= maskY;\\n\\t\\t\\t\\tcolor.a *= opacity;\\n\\n\\t\\t\\t\\t// color.a += .1;\\n\\n\\t\\t\\t\\t// antialiasing, see yiq color space y-channel formula\\n\\t\\t\\t\\t// color.rgb += (1. - color.rgb) * (1. - mask.rgb);\\n\\n\\t\\t\\t\\tgl_FragColor = color;\\n\\t\\t\\t}\"});return{regl:t,draw:e,atlas:{}}},T.prototype.update=function(t){var e=this;if(\"string\"==typeof t)t={text:t};else if(!t)return;null!=(t=i(t,{position:\"position positions coord coords coordinates\",font:\"font fontFace fontface typeface cssFont css-font family fontFamily\",fontSize:\"fontSize fontsize size font-size\",text:\"text texts chars characters value values symbols\",align:\"align alignment textAlign textbaseline\",baseline:\"baseline textBaseline textbaseline\",direction:\"dir direction textDirection\",color:\"color colour fill fill-color fillColor textColor textcolor\",kerning:\"kerning kern\",range:\"range dataBox\",viewport:\"vp viewport viewBox viewbox viewPort\",opacity:\"opacity alpha transparency visible visibility opaque\",offset:\"offset positionOffset padding shift indent indentation\"},!0)).opacity&&(Array.isArray(t.opacity)?this.opacity=t.opacity.map((function(t){return parseFloat(t)})):this.opacity=parseFloat(t.opacity)),null!=t.viewport&&(this.viewport=f(t.viewport),T.normalViewport&&(this.viewport.y=this.canvas.height-this.viewport.y-this.viewport.height),this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null==this.viewport&&(this.viewport={x:0,y:0,width:this.gl.drawingBufferWidth,height:this.gl.drawingBufferHeight},this.viewportArray=[this.viewport.x,this.viewport.y,this.viewport.width,this.viewport.height]),null!=t.kerning&&(this.kerning=t.kerning),null!=t.offset&&(\"number\"==typeof t.offset&&(t.offset=[t.offset,0]),this.positionOffset=y(t.offset)),t.direction&&(this.direction=t.direction),t.range&&(this.range=t.range,this.scale=[1/(t.range[2]-t.range[0]),1/(t.range[3]-t.range[1])],this.translate=[-t.range[0],-t.range[1]]),t.scale&&(this.scale=t.scale),t.translate&&(this.translate=t.translate),this.scale||(this.scale=[1/this.viewport.width,1/this.viewport.height]),this.translate||(this.translate=[0,0]),this.font.length||t.font||(t.font=T.baseFontSize+\"px sans-serif\");var r,a=!1,o=!1;if(t.font&&(Array.isArray(t.font)?t.font:[t.font]).forEach((function(t,r){if(\"string\"==typeof t)try{t=n.parse(t)}catch(e){t=n.parse(T.baseFontSize+\"px \"+t)}else t=n.parse(n.stringify(t));var i=n.stringify({size:T.baseFontSize,family:t.family,stretch:_?t.stretch:void 0,variant:t.variant,weight:t.weight,style:t.style}),s=p(t.size),l=Math.round(s[0]*d(s[1]));if(l!==e.fontSize[r]&&(o=!0,e.fontSize[r]=l),!(e.font[r]&&i==e.font[r].baseString||(a=!0,e.font[r]=T.fonts[i],e.font[r]))){var c=t.family.join(\", \"),u=[t.style];t.style!=t.variant&&u.push(t.variant),t.variant!=t.weight&&u.push(t.weight),_&&t.weight!=t.stretch&&u.push(t.stretch),e.font[r]={baseString:i,family:c,weight:t.weight,stretch:t.stretch,style:t.style,variant:t.variant,width:{},kerning:{},metrics:v(c,{origin:\"top\",fontSize:T.baseFontSize,fontStyle:u.join(\" \")})},T.fonts[i]=e.font[r]}})),(a||o)&&this.font.forEach((function(r,i){var a=n.stringify({size:e.fontSize[i],family:r.family,stretch:_?r.stretch:void 0,variant:r.variant,weight:r.weight,style:r.style});if(e.fontAtlas[i]=e.shader.atlas[a],!e.fontAtlas[i]){var o=r.metrics;e.shader.atlas[a]=e.fontAtlas[i]={fontString:a,step:2*Math.ceil(e.fontSize[i]*o.bottom*.5),em:e.fontSize[i],cols:0,rows:0,height:0,width:0,chars:[],ids:{},texture:e.regl.texture()}}null==t.text&&(t.text=e.text)})),\"string\"==typeof t.text&&t.position&&t.position.length>2){for(var s=Array(.5*t.position.length),h=0;h<s.length;h++)s[h]=t.text;t.text=s}if(null!=t.text||a){if(this.textOffsets=[0],Array.isArray(t.text)){this.count=t.text[0].length,this.counts=[this.count];for(var b=1;b<t.text.length;b++)this.textOffsets[b]=this.textOffsets[b-1]+t.text[b-1].length,this.count+=t.text[b].length,this.counts.push(t.text[b].length);this.text=t.text.join(\"\")}else this.text=t.text,this.count=this.text.length,this.counts=[this.count];r=[],this.font.forEach((function(t,n){T.atlasContext.font=t.baseString;for(var i=e.fontAtlas[n],a=0;a<e.text.length;a++){var o=e.text.charAt(a);if(null==i.ids[o]&&(i.ids[o]=i.chars.length,i.chars.push(o),r.push(o)),null==t.width[o]&&(t.width[o]=T.atlasContext.measureText(o).width/T.baseFontSize,e.kerning)){var s=[];for(var l in t.width)s.push(l+o,o+l);m(t.kerning,g(t.family,{pairs:s}))}}}))}if(t.position)if(t.position.length>2){for(var w=!t.position[0].length,k=u.mallocFloat(2*this.count),M=0,A=0;M<this.counts.length;M++){var S=this.counts[M];if(w)for(var E=0;E<S;E++)k[A++]=t.position[2*M],k[A++]=t.position[2*M+1];else for(var C=0;C<S;C++)k[A++]=t.position[M][0],k[A++]=t.position[M][1]}this.position.call?this.position({type:\"float\",data:k}):this.position=this.regl.buffer({type:\"float\",data:k}),u.freeFloat(k)}else this.position.destroy&&this.position.destroy(),this.position={constant:t.position};if(t.text||a){var L=u.mallocUint8(this.count),I=u.mallocFloat(2*this.count);this.textWidth=[];for(var P=0,z=0;P<this.counts.length;P++){for(var O=this.counts[P],D=this.font[P]||this.font[0],R=this.fontAtlas[P]||this.fontAtlas[0],F=0;F<O;F++){var B=this.text.charAt(z),N=this.text.charAt(z-1);if(L[z]=R.ids[B],I[2*z]=D.width[B],F){var j=I[2*z-2],U=I[2*z],V=I[2*z-1]+.5*j+.5*U;if(this.kerning){var q=D.kerning[N+B];q&&(V+=.001*q)}I[2*z+1]=V}else I[2*z+1]=.5*I[2*z];z++}this.textWidth.push(I.length?.5*I[2*z-2]+I[2*z-1]:0)}t.align||(t.align=this.align),this.charBuffer({data:L,type:\"uint8\",usage:\"stream\"}),this.sizeBuffer({data:I,type:\"float\",usage:\"stream\"}),u.freeUint8(L),u.freeFloat(I),r.length&&this.font.forEach((function(t,r){var n=e.fontAtlas[r],i=n.step,a=Math.floor(T.maxAtlasSize/i),o=Math.min(a,n.chars.length),s=Math.ceil(n.chars.length/o),l=x(o*i),u=x(s*i);n.width=l,n.height=u,n.rows=s,n.cols=o,n.em&&n.texture({data:c({canvas:T.atlasCanvas,font:n.fontString,chars:n.chars,shape:[l,u],step:[i,i]})})}))}if(t.align&&(this.align=t.align,this.alignOffset=this.textWidth.map((function(t,r){var n=Array.isArray(e.align)?e.align.length>1?e.align[r]:e.align[0]:e.align;if(\"number\"==typeof n)return n;switch(n){case\"right\":case\"end\":return-t;case\"center\":case\"centre\":case\"middle\":return.5*-t}return 0}))),null==this.baseline&&null==t.baseline&&(t.baseline=0),null!=t.baseline&&(this.baseline=t.baseline,Array.isArray(this.baseline)||(this.baseline=[this.baseline]),this.baselineOffset=this.baseline.map((function(t,r){var n=(e.font[r]||e.font[0]).metrics,i=0;return i+=.5*n.bottom,i+=\"number\"==typeof t?t-n.baseline:-n[t],T.normalViewport||(i*=-1),i}))),null!=t.color)if(t.color||(t.color=\"transparent\"),\"string\"!=typeof t.color&&isNaN(t.color)){var H;if(\"number\"==typeof t.color[0]&&t.color.length>this.counts.length){var G=t.color.length;H=u.mallocUint8(G);for(var Y=(t.color.subarray||t.color.slice).bind(t.color),W=0;W<G;W+=4)H.set(l(Y(W,W+4),\"uint8\"),W)}else{var X=t.color.length;H=u.mallocUint8(4*X);for(var Z=0;Z<X;Z++)H.set(l(t.color[Z]||0,\"uint8\"),4*Z)}this.color=H}else this.color=l(t.color,\"uint8\");if(t.position||t.text||t.color||t.baseline||t.align||t.font||t.offset||t.opacity)if(this.color.length>4||this.baselineOffset.length>1||this.align&&this.align.length>1||this.fontAtlas.length>1||this.positionOffset.length>2){var J=Math.max(.5*this.position.length||0,.25*this.color.length||0,this.baselineOffset.length||0,this.alignOffset.length||0,this.font.length||0,this.opacity.length||0,.5*this.positionOffset.length||0);this.batch=Array(J);for(var K=0;K<this.batch.length;K++)this.batch[K]={count:this.counts.length>1?this.counts[K]:this.counts[0],offset:this.textOffsets.length>1?this.textOffsets[K]:this.textOffsets[0],color:this.color?this.color.length<=4?this.color:this.color.subarray(4*K,4*K+4):[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[K]:this.opacity,baseline:null!=this.baselineOffset[K]?this.baselineOffset[K]:this.baselineOffset[0],align:this.align?null!=this.alignOffset[K]?this.alignOffset[K]:this.alignOffset[0]:0,atlas:this.fontAtlas[K]||this.fontAtlas[0],positionOffset:this.positionOffset.length>2?this.positionOffset.subarray(2*K,2*K+2):this.positionOffset}}else this.count?this.batch=[{count:this.count,offset:0,color:this.color||[0,0,0,255],opacity:Array.isArray(this.opacity)?this.opacity[0]:this.opacity,baseline:this.baselineOffset[0],align:this.alignOffset?this.alignOffset[0]:0,atlas:this.fontAtlas[0],positionOffset:this.positionOffset}]:this.batch=[]},T.prototype.destroy=function(){},T.prototype.kerning=!0,T.prototype.position={constant:new Float32Array(2)},T.prototype.translate=null,T.prototype.scale=null,T.prototype.font=null,T.prototype.text=\"\",T.prototype.positionOffset=[0,0],T.prototype.opacity=1,T.prototype.color=new Uint8Array([0,0,0,255]),T.prototype.alignOffset=[0,0],T.normalViewport=!1,T.maxAtlasSize=1024,T.atlasCanvas=document.createElement(\"canvas\"),T.atlasContext=T.atlasCanvas.getContext(\"2d\",{alpha:!1}),T.baseFontSize=64,T.fonts={},e.exports=T},{\"bit-twiddle\":97,\"color-normalize\":125,\"css-font\":144,\"detect-kerning\":172,\"es6-weak-map\":233,\"flatten-vertex-data\":244,\"font-atlas\":245,\"font-measure\":246,\"gl-util/context\":354,\"is-plain-obj\":469,\"object-assign\":499,\"parse-rect\":504,\"parse-unit\":506,\"pick-by-alias\":511,regl:540,\"to-px\":578,\"typedarray-pool\":595}],353:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"ndarray-ops\"),a=t(\"typedarray-pool\");e.exports=function(t){if(arguments.length<=1)throw new Error(\"gl-texture2d: Missing arguments for texture2d constructor\");o||c(t);if(\"number\"==typeof arguments[1])return v(t,arguments[1],arguments[2],arguments[3]||t.RGBA,arguments[4]||t.UNSIGNED_BYTE);if(Array.isArray(arguments[1]))return v(t,0|arguments[1][0],0|arguments[1][1],arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(\"object\"==typeof arguments[1]){var e=arguments[1],r=u(e)?e:e.raw;if(r)return y(t,r,0|e.width,0|e.height,arguments[2]||t.RGBA,arguments[3]||t.UNSIGNED_BYTE);if(e.shape&&e.data&&e.stride)return x(t,e)}throw new Error(\"gl-texture2d: Invalid arguments for texture2d constructor\")};var o=null,s=null,l=null;function c(t){o=[t.LINEAR,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_NEAREST],s=[t.NEAREST,t.LINEAR,t.NEAREST_MIPMAP_NEAREST,t.NEAREST_MIPMAP_LINEAR,t.LINEAR_MIPMAP_NEAREST,t.LINEAR_MIPMAP_LINEAR],l=[t.REPEAT,t.CLAMP_TO_EDGE,t.MIRRORED_REPEAT]}function u(t){return\"undefined\"!=typeof HTMLCanvasElement&&t instanceof HTMLCanvasElement||\"undefined\"!=typeof HTMLImageElement&&t instanceof HTMLImageElement||\"undefined\"!=typeof HTMLVideoElement&&t instanceof HTMLVideoElement||\"undefined\"!=typeof ImageData&&t instanceof ImageData}var f=function(t,e){i.muls(t,e,255)};function h(t,e,r){var n=t.gl,i=n.getParameter(n.MAX_TEXTURE_SIZE);if(e<0||e>i||r<0||r>i)throw new Error(\"gl-texture2d: Invalid texture size\");return t._shape=[e,r],t.bind(),n.texImage2D(n.TEXTURE_2D,0,t.format,e,r,0,t.format,t.type,null),t._mipLevels=[0],t}function p(t,e,r,n,i,a){this.gl=t,this.handle=e,this.format=i,this.type=a,this._shape=[r,n],this._mipLevels=[0],this._magFilter=t.NEAREST,this._minFilter=t.NEAREST,this._wrapS=t.CLAMP_TO_EDGE,this._wrapT=t.CLAMP_TO_EDGE,this._anisoSamples=1;var o=this,s=[this._wrapS,this._wrapT];Object.defineProperties(s,[{get:function(){return o._wrapS},set:function(t){return o.wrapS=t}},{get:function(){return o._wrapT},set:function(t){return o.wrapT=t}}]),this._wrapVector=s;var l=[this._shape[0],this._shape[1]];Object.defineProperties(l,[{get:function(){return o._shape[0]},set:function(t){return o.width=t}},{get:function(){return o._shape[1]},set:function(t){return o.height=t}}]),this._shapeVector=l}var d=p.prototype;function g(t,e){return 3===t.length?1===e[2]&&e[1]===t[0]*t[2]&&e[0]===t[2]:1===e[0]&&e[1]===t[0]}function m(t){var e=t.createTexture();return t.bindTexture(t.TEXTURE_2D,e),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MIN_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_MAG_FILTER,t.NEAREST),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_S,t.CLAMP_TO_EDGE),t.texParameteri(t.TEXTURE_2D,t.TEXTURE_WRAP_T,t.CLAMP_TO_EDGE),e}function v(t,e,r,n,i){var a=t.getParameter(t.MAX_TEXTURE_SIZE);if(e<0||e>a||r<0||r>a)throw new Error(\"gl-texture2d: Invalid texture shape\");if(i===t.FLOAT&&!t.getExtension(\"OES_texture_float\"))throw new Error(\"gl-texture2d: Floating point textures not supported on this platform\");var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,n,e,r,0,n,i,null),new p(t,o,e,r,n,i)}function y(t,e,r,n,i,a){var o=m(t);return t.texImage2D(t.TEXTURE_2D,0,i,i,a,e),new p(t,o,r,n,i,a)}function x(t,e){var r=e.dtype,o=e.shape.slice(),s=t.getParameter(t.MAX_TEXTURE_SIZE);if(o[0]<0||o[0]>s||o[1]<0||o[1]>s)throw new Error(\"gl-texture2d: Invalid texture size\");var l=g(o,e.stride.slice()),c=0;\"float32\"===r?c=t.FLOAT:\"float64\"===r?(c=t.FLOAT,l=!1,r=\"float32\"):\"uint8\"===r?c=t.UNSIGNED_BYTE:(c=t.UNSIGNED_BYTE,l=!1,r=\"uint8\");var u,h,d=0;if(2===o.length)d=t.LUMINANCE,o=[o[0],o[1],1],e=n(e.data,o,[e.stride[0],e.stride[1],1],e.offset);else{if(3!==o.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===o[2])d=t.ALPHA;else if(2===o[2])d=t.LUMINANCE_ALPHA;else if(3===o[2])d=t.RGB;else{if(4!==o[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");d=t.RGBA}}c!==t.FLOAT||t.getExtension(\"OES_texture_float\")||(c=t.UNSIGNED_BYTE,l=!1);var v=e.size;if(l)u=0===e.offset&&e.data.length===v?e.data:e.data.subarray(e.offset,e.offset+v);else{var y=[o[2],o[2]*o[0],1];h=a.malloc(v,r);var x=n(h,o,y,0);\"float32\"!==r&&\"float64\"!==r||c!==t.UNSIGNED_BYTE?i.assign(x,e):f(x,e),u=h.subarray(0,v)}var b=m(t);return t.texImage2D(t.TEXTURE_2D,0,d,o[0],o[1],0,d,c,u),l||a.free(h),new p(t,b,o[0],o[1],d,c)}Object.defineProperties(d,{minFilter:{get:function(){return this._minFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,t),this._minFilter=t}},magFilter:{get:function(){return this._magFilter},set:function(t){this.bind();var e=this.gl;if(this.type===e.FLOAT&&o.indexOf(t)>=0&&(e.getExtension(\"OES_texture_float_linear\")||(t=e.NEAREST)),s.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown filter mode \"+t);return e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,t),this._magFilter=t}},mipSamples:{get:function(){return this._anisoSamples},set:function(t){var e=this._anisoSamples;if(this._anisoSamples=0|Math.max(t,1),e!==this._anisoSamples){var r=this.gl.getExtension(\"EXT_texture_filter_anisotropic\");r&&this.gl.texParameterf(this.gl.TEXTURE_2D,r.TEXTURE_MAX_ANISOTROPY_EXT,this._anisoSamples)}return this._anisoSamples}},wrapS:{get:function(){return this._wrapS},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_S,t),this._wrapS=t}},wrapT:{get:function(){return this._wrapT},set:function(t){if(this.bind(),l.indexOf(t)<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);return this.gl.texParameteri(this.gl.TEXTURE_2D,this.gl.TEXTURE_WRAP_T,t),this._wrapT=t}},wrap:{get:function(){return this._wrapVector},set:function(t){if(Array.isArray(t)||(t=[t,t]),2!==t.length)throw new Error(\"gl-texture2d: Must specify wrap mode for rows and columns\");for(var e=0;e<2;++e)if(l.indexOf(t[e])<0)throw new Error(\"gl-texture2d: Unknown wrap mode \"+t);this._wrapS=t[0],this._wrapT=t[1];var r=this.gl;return this.bind(),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_S,this._wrapS),r.texParameteri(r.TEXTURE_2D,r.TEXTURE_WRAP_T,this._wrapT),t}},shape:{get:function(){return this._shapeVector},set:function(t){if(Array.isArray(t)){if(2!==t.length)throw new Error(\"gl-texture2d: Invalid texture shape\")}else t=[0|t,0|t];return h(this,0|t[0],0|t[1]),[0|t[0],0|t[1]]}},width:{get:function(){return this._shape[0]},set:function(t){return h(this,t|=0,this._shape[1]),t}},height:{get:function(){return this._shape[1]},set:function(t){return t|=0,h(this,this._shape[0],t),t}}}),d.bind=function(t){var e=this.gl;return void 0!==t&&e.activeTexture(e.TEXTURE0+(0|t)),e.bindTexture(e.TEXTURE_2D,this.handle),void 0!==t?0|t:e.getParameter(e.ACTIVE_TEXTURE)-e.TEXTURE0},d.dispose=function(){this.gl.deleteTexture(this.handle)},d.generateMipmap=function(){this.bind(),this.gl.generateMipmap(this.gl.TEXTURE_2D);for(var t=Math.min(this._shape[0],this._shape[1]),e=0;t>0;++e,t>>>=1)this._mipLevels.indexOf(e)<0&&this._mipLevels.push(e)},d.setPixels=function(t,e,r,o){var s=this.gl;this.bind(),Array.isArray(e)?(o=r,r=0|e[1],e=0|e[0]):(e=e||0,r=r||0),o=o||0;var l=u(t)?t:t.raw;if(l){this._mipLevels.indexOf(o)<0?(s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,this.type,l),this._mipLevels.push(o)):s.texSubImage2D(s.TEXTURE_2D,o,e,r,this.format,this.type,l)}else{if(!(t.shape&&t.stride&&t.data))throw new Error(\"gl-texture2d: Unsupported data type\");if(t.shape.length<2||e+t.shape[1]>this._shape[1]>>>o||r+t.shape[0]>this._shape[0]>>>o||e<0||r<0)throw new Error(\"gl-texture2d: Texture dimensions are out of bounds\");!function(t,e,r,o,s,l,c,u){var h=u.dtype,p=u.shape.slice();if(p.length<2||p.length>3)throw new Error(\"gl-texture2d: Invalid ndarray, must be 2d or 3d\");var d=0,m=0,v=g(p,u.stride.slice());\"float32\"===h?d=t.FLOAT:\"float64\"===h?(d=t.FLOAT,v=!1,h=\"float32\"):\"uint8\"===h?d=t.UNSIGNED_BYTE:(d=t.UNSIGNED_BYTE,v=!1,h=\"uint8\");if(2===p.length)m=t.LUMINANCE,p=[p[0],p[1],1],u=n(u.data,p,[u.stride[0],u.stride[1],1],u.offset);else{if(3!==p.length)throw new Error(\"gl-texture2d: Invalid shape for texture\");if(1===p[2])m=t.ALPHA;else if(2===p[2])m=t.LUMINANCE_ALPHA;else if(3===p[2])m=t.RGB;else{if(4!==p[2])throw new Error(\"gl-texture2d: Invalid shape for pixel coords\");m=t.RGBA}p[2]}m!==t.LUMINANCE&&m!==t.ALPHA||s!==t.LUMINANCE&&s!==t.ALPHA||(m=s);if(m!==s)throw new Error(\"gl-texture2d: Incompatible texture format for setPixels\");var y=u.size,x=c.indexOf(o)<0;x&&c.push(o);if(d===l&&v)0===u.offset&&u.data.length===y?x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data):x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,u.data.subarray(u.offset,u.offset+y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,u.data.subarray(u.offset,u.offset+y));else{var b;b=l===t.FLOAT?a.mallocFloat32(y):a.mallocUint8(y);var _=n(b,p,[p[2],p[2]*p[0],1]);d===t.FLOAT&&l===t.UNSIGNED_BYTE?f(_,u):i.assign(_,u),x?t.texImage2D(t.TEXTURE_2D,o,s,p[0],p[1],0,s,l,b.subarray(0,y)):t.texSubImage2D(t.TEXTURE_2D,o,e,r,p[0],p[1],s,l,b.subarray(0,y)),l===t.FLOAT?a.freeFloat32(b):a.freeUint8(b)}}(s,e,r,o,this.format,this.type,this._mipLevels,t)}}},{ndarray:495,\"ndarray-ops\":490,\"typedarray-pool\":595}],354:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"pick-by-alias\");function i(t){if(t.container)if(t.container==document.body)document.body.style.width||(t.canvas.width=t.width||t.pixelRatio*r.innerWidth),document.body.style.height||(t.canvas.height=t.height||t.pixelRatio*r.innerHeight);else{var e=t.container.getBoundingClientRect();t.canvas.width=t.width||e.right-e.left,t.canvas.height=t.height||e.bottom-e.top}}function a(t){return\"function\"==typeof t.getContext&&\"width\"in t&&\"height\"in t}function o(){var t=document.createElement(\"canvas\");return t.style.position=\"absolute\",t.style.top=0,t.style.left=0,t}e.exports=function(t){var e;if(t?\"string\"==typeof t&&(t={container:t}):t={},a(t)?t={container:t}:t=\"string\"==typeof(e=t).nodeName&&\"function\"==typeof e.appendChild&&\"function\"==typeof e.getBoundingClientRect?{container:t}:function(t){return\"function\"==typeof t.drawArrays||\"function\"==typeof t.drawElements}(t)?{gl:t}:n(t,{container:\"container target element el canvas holder parent parentNode wrapper use ref root node\",gl:\"gl context webgl glContext\",attrs:\"attributes attrs contextAttributes\",pixelRatio:\"pixelRatio pxRatio px ratio pxratio pixelratio\",width:\"w width\",height:\"h height\"},!0),t.pixelRatio||(t.pixelRatio=r.pixelRatio||1),t.gl)return t.gl;if(t.canvas&&(t.container=t.canvas.parentNode),t.container){if(\"string\"==typeof t.container){var s=document.querySelector(t.container);if(!s)throw Error(\"Element \"+t.container+\" is not found\");t.container=s}a(t.container)?(t.canvas=t.container,t.container=t.canvas.parentNode):t.canvas||(t.canvas=o(),t.container.appendChild(t.canvas),i(t))}else if(!t.canvas){if(\"undefined\"==typeof document)throw Error(\"Not DOM environment. Use headless-gl.\");t.container=document.body||document.documentElement,t.canvas=o(),t.container.appendChild(t.canvas),i(t)}if(!t.gl)try{t.gl=t.canvas.getContext(\"webgl\",t.attrs)}catch(e){try{t.gl=t.canvas.getContext(\"experimental-webgl\",t.attrs)}catch(e){t.gl=t.canvas.getContext(\"webgl-experimental\",t.attrs)}}return t.gl}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"pick-by-alias\":511}],355:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){e?e.bind():t.bindBuffer(t.ELEMENT_ARRAY_BUFFER,null);var n=0|t.getParameter(t.MAX_VERTEX_ATTRIBS);if(r){if(r.length>n)throw new Error(\"gl-vao: Too many vertex attributes\");for(var i=0;i<r.length;++i){var a=r[i];if(a.buffer){var o=a.buffer,s=a.size||4,l=a.type||t.FLOAT,c=!!a.normalized,u=a.stride||0,f=a.offset||0;o.bind(),t.enableVertexAttribArray(i),t.vertexAttribPointer(i,s,l,c,u,f)}else{if(\"number\"==typeof a)t.vertexAttrib1f(i,a);else if(1===a.length)t.vertexAttrib1f(i,a[0]);else if(2===a.length)t.vertexAttrib2f(i,a[0],a[1]);else if(3===a.length)t.vertexAttrib3f(i,a[0],a[1],a[2]);else{if(4!==a.length)throw new Error(\"gl-vao: Invalid vertex attribute\");t.vertexAttrib4f(i,a[0],a[1],a[2],a[3])}t.disableVertexAttribArray(i)}}for(;i<n;++i)t.disableVertexAttribArray(i)}else{t.bindBuffer(t.ARRAY_BUFFER,null);for(i=0;i<n;++i)t.disableVertexAttribArray(i)}}},{}],356:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t){this.gl=t,this._elements=null,this._attributes=null,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(){n(this.gl,this._elements,this._attributes)},i.prototype.update=function(t,e,r){this._elements=e,this._attributes=t,this._elementsType=r||this.gl.UNSIGNED_SHORT},i.prototype.dispose=function(){},i.prototype.unbind=function(){},i.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._elements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t){return new i(t)}},{\"./do-bind.js\":355}],357:[function(t,e,r){\"use strict\";var n=t(\"./do-bind.js\");function i(t,e,r,n,i,a){this.location=t,this.dimension=e,this.a=r,this.b=n,this.c=i,this.d=a}function a(t,e,r){this.gl=t,this._ext=e,this.handle=r,this._attribs=[],this._useElements=!1,this._elementsType=t.UNSIGNED_SHORT}i.prototype.bind=function(t){switch(this.dimension){case 1:t.vertexAttrib1f(this.location,this.a);break;case 2:t.vertexAttrib2f(this.location,this.a,this.b);break;case 3:t.vertexAttrib3f(this.location,this.a,this.b,this.c);break;case 4:t.vertexAttrib4f(this.location,this.a,this.b,this.c,this.d)}},a.prototype.bind=function(){this._ext.bindVertexArrayOES(this.handle);for(var t=0;t<this._attribs.length;++t)this._attribs[t].bind(this.gl)},a.prototype.unbind=function(){this._ext.bindVertexArrayOES(null)},a.prototype.dispose=function(){this._ext.deleteVertexArrayOES(this.handle)},a.prototype.update=function(t,e,r){if(this.bind(),n(this.gl,e,t),this.unbind(),this._attribs.length=0,t)for(var a=0;a<t.length;++a){var o=t[a];\"number\"==typeof o?this._attribs.push(new i(a,1,o)):Array.isArray(o)&&this._attribs.push(new i(a,o.length,o[0],o[1],o[2],o[3]))}this._useElements=!!e,this._elementsType=r||this.gl.UNSIGNED_SHORT},a.prototype.draw=function(t,e,r){r=r||0;var n=this.gl;this._useElements?n.drawElements(t,e,this._elementsType,r):n.drawArrays(t,r,e)},e.exports=function(t,e){return new a(t,e,e.createVertexArrayOES())}},{\"./do-bind.js\":355}],358:[function(t,e,r){\"use strict\";var n=t(\"./lib/vao-native.js\"),i=t(\"./lib/vao-emulated.js\");function a(t){this.bindVertexArrayOES=t.bindVertexArray.bind(t),this.createVertexArrayOES=t.createVertexArray.bind(t),this.deleteVertexArrayOES=t.deleteVertexArray.bind(t)}e.exports=function(t,e,r,o){var s,l=t.createVertexArray?new a(t):t.getExtension(\"OES_vertex_array_object\");return(s=l?n(t,l):i(t)).update(e,r,o),s}},{\"./lib/vao-emulated.js\":356,\"./lib/vao-native.js\":357}],359:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t}},{}],360:[function(t,e,r){e.exports=function(t,e){var r=n(t[0],t[1],t[2]),o=n(e[0],e[1],e[2]);i(r,r),i(o,o);var s=a(r,o);return s>1?0:Math.acos(s)};var n=t(\"./fromValues\"),i=t(\"./normalize\"),a=t(\"./dot\")},{\"./dot\":370,\"./fromValues\":376,\"./normalize\":387}],361:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.ceil(e[0]),t[1]=Math.ceil(e[1]),t[2]=Math.ceil(e[2]),t}},{}],362:[function(t,e,r){e.exports=function(t){var e=new Float32Array(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e}},{}],363:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t}},{}],364:[function(t,e,r){e.exports=function(){var t=new Float32Array(3);return t[0]=0,t[1]=0,t[2]=0,t}},{}],365:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t}},{}],366:[function(t,e,r){e.exports=t(\"./distance\")},{\"./distance\":367}],367:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return Math.sqrt(r*r+n*n+i*i)}},{}],368:[function(t,e,r){e.exports=t(\"./divide\")},{\"./divide\":369}],369:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t}},{}],370:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]}},{}],371:[function(t,e,r){e.exports=1e-6},{}],372:[function(t,e,r){e.exports=function(t,e){var r=t[0],i=t[1],a=t[2],o=e[0],s=e[1],l=e[2];return Math.abs(r-o)<=n*Math.max(1,Math.abs(r),Math.abs(o))&&Math.abs(i-s)<=n*Math.max(1,Math.abs(i),Math.abs(s))&&Math.abs(a-l)<=n*Math.max(1,Math.abs(a),Math.abs(l))};var n=t(\"./epsilon\")},{\"./epsilon\":371}],373:[function(t,e,r){e.exports=function(t,e){return t[0]===e[0]&&t[1]===e[1]&&t[2]===e[2]}},{}],374:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.floor(e[0]),t[1]=Math.floor(e[1]),t[2]=Math.floor(e[2]),t}},{}],375:[function(t,e,r){e.exports=function(t,e,r,i,a,o){var s,l;e||(e=3);r||(r=0);l=i?Math.min(i*e+r,t.length):t.length;for(s=r;s<l;s+=e)n[0]=t[s],n[1]=t[s+1],n[2]=t[s+2],a(n,n,o),t[s]=n[0],t[s+1]=n[1],t[s+2]=n[2];return t};var n=t(\"./create\")()},{\"./create\":364}],376:[function(t,e,r){e.exports=function(t,e,r){var n=new Float32Array(3);return n[0]=t,n[1]=e,n[2]=r,n}},{}],377:[function(t,e,r){e.exports={EPSILON:t(\"./epsilon\"),create:t(\"./create\"),clone:t(\"./clone\"),angle:t(\"./angle\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),equals:t(\"./equals\"),exactEquals:t(\"./exactEquals\"),add:t(\"./add\"),subtract:t(\"./subtract\"),sub:t(\"./sub\"),multiply:t(\"./multiply\"),mul:t(\"./mul\"),divide:t(\"./divide\"),div:t(\"./div\"),min:t(\"./min\"),max:t(\"./max\"),floor:t(\"./floor\"),ceil:t(\"./ceil\"),round:t(\"./round\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),dist:t(\"./dist\"),squaredDistance:t(\"./squaredDistance\"),sqrDist:t(\"./sqrDist\"),length:t(\"./length\"),len:t(\"./len\"),squaredLength:t(\"./squaredLength\"),sqrLen:t(\"./sqrLen\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),cross:t(\"./cross\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformMat3:t(\"./transformMat3\"),transformQuat:t(\"./transformQuat\"),rotateX:t(\"./rotateX\"),rotateY:t(\"./rotateY\"),rotateZ:t(\"./rotateZ\"),forEach:t(\"./forEach\")}},{\"./add\":359,\"./angle\":360,\"./ceil\":361,\"./clone\":362,\"./copy\":363,\"./create\":364,\"./cross\":365,\"./dist\":366,\"./distance\":367,\"./div\":368,\"./divide\":369,\"./dot\":370,\"./epsilon\":371,\"./equals\":372,\"./exactEquals\":373,\"./floor\":374,\"./forEach\":375,\"./fromValues\":376,\"./inverse\":378,\"./len\":379,\"./length\":380,\"./lerp\":381,\"./max\":382,\"./min\":383,\"./mul\":384,\"./multiply\":385,\"./negate\":386,\"./normalize\":387,\"./random\":388,\"./rotateX\":389,\"./rotateY\":390,\"./rotateZ\":391,\"./round\":392,\"./scale\":393,\"./scaleAndAdd\":394,\"./set\":395,\"./sqrDist\":396,\"./sqrLen\":397,\"./squaredDistance\":398,\"./squaredLength\":399,\"./sub\":400,\"./subtract\":401,\"./transformMat3\":402,\"./transformMat4\":403,\"./transformQuat\":404}],378:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t}},{}],379:[function(t,e,r){e.exports=t(\"./length\")},{\"./length\":380}],380:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return Math.sqrt(e*e+r*r+n*n)}},{}],381:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t}},{}],382:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t}},{}],383:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t}},{}],384:[function(t,e,r){e.exports=t(\"./multiply\")},{\"./multiply\":385}],385:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t}},{}],386:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t}},{}],387:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;a>0&&(a=1/Math.sqrt(a),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a);return t}},{}],388:[function(t,e,r){e.exports=function(t,e){e=e||1;var r=2*Math.random()*Math.PI,n=2*Math.random()-1,i=Math.sqrt(1-n*n)*e;return t[0]=Math.cos(r)*i,t[1]=Math.sin(r)*i,t[2]=n*e,t}},{}],389:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[1],a=r[2],o=e[1]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=e[0],t[1]=i+o*c-s*l,t[2]=a+o*l+s*c,t}},{}],390:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[2],o=e[0]-i,s=e[2]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+s*l+o*c,t[1]=e[1],t[2]=a+s*c-o*l,t}},{}],391:[function(t,e,r){e.exports=function(t,e,r,n){var i=r[0],a=r[1],o=e[0]-i,s=e[1]-a,l=Math.sin(n),c=Math.cos(n);return t[0]=i+o*c-s*l,t[1]=a+o*l+s*c,t[2]=e[2],t}},{}],392:[function(t,e,r){e.exports=function(t,e){return t[0]=Math.round(e[0]),t[1]=Math.round(e[1]),t[2]=Math.round(e[2]),t}},{}],393:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t}},{}],394:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t}},{}],395:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e,t[1]=r,t[2]=n,t}},{}],396:[function(t,e,r){e.exports=t(\"./squaredDistance\")},{\"./squaredDistance\":398}],397:[function(t,e,r){e.exports=t(\"./squaredLength\")},{\"./squaredLength\":399}],398:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2];return r*r+n*n+i*i}},{}],399:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2];return e*e+r*r+n*n}},{}],400:[function(t,e,r){e.exports=t(\"./subtract\")},{\"./subtract\":401}],401:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t}},{}],402:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t}},{}],403:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[3]*n+r[7]*i+r[11]*a+r[15];return o=o||1,t[0]=(r[0]*n+r[4]*i+r[8]*a+r[12])/o,t[1]=(r[1]*n+r[5]*i+r[9]*a+r[13])/o,t[2]=(r[2]*n+r[6]*i+r[10]*a+r[14])/o,t}},{}],404:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t}},{}],405:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t[3]=e[3]+r[3],t}},{}],406:[function(t,e,r){e.exports=function(t){var e=new Float32Array(4);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e}},{}],407:[function(t,e,r){e.exports=function(t,e){return t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t}},{}],408:[function(t,e,r){e.exports=function(){var t=new Float32Array(4);return t[0]=0,t[1]=0,t[2]=0,t[3]=0,t}},{}],409:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return Math.sqrt(r*r+n*n+i*i+a*a)}},{}],410:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]/r[0],t[1]=e[1]/r[1],t[2]=e[2]/r[2],t[3]=e[3]/r[3],t}},{}],411:[function(t,e,r){e.exports=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]}},{}],412:[function(t,e,r){e.exports=function(t,e,r,n){var i=new Float32Array(4);return i[0]=t,i[1]=e,i[2]=r,i[3]=n,i}},{}],413:[function(t,e,r){e.exports={create:t(\"./create\"),clone:t(\"./clone\"),fromValues:t(\"./fromValues\"),copy:t(\"./copy\"),set:t(\"./set\"),add:t(\"./add\"),subtract:t(\"./subtract\"),multiply:t(\"./multiply\"),divide:t(\"./divide\"),min:t(\"./min\"),max:t(\"./max\"),scale:t(\"./scale\"),scaleAndAdd:t(\"./scaleAndAdd\"),distance:t(\"./distance\"),squaredDistance:t(\"./squaredDistance\"),length:t(\"./length\"),squaredLength:t(\"./squaredLength\"),negate:t(\"./negate\"),inverse:t(\"./inverse\"),normalize:t(\"./normalize\"),dot:t(\"./dot\"),lerp:t(\"./lerp\"),random:t(\"./random\"),transformMat4:t(\"./transformMat4\"),transformQuat:t(\"./transformQuat\")}},{\"./add\":405,\"./clone\":406,\"./copy\":407,\"./create\":408,\"./distance\":409,\"./divide\":410,\"./dot\":411,\"./fromValues\":412,\"./inverse\":414,\"./length\":415,\"./lerp\":416,\"./max\":417,\"./min\":418,\"./multiply\":419,\"./negate\":420,\"./normalize\":421,\"./random\":422,\"./scale\":423,\"./scaleAndAdd\":424,\"./set\":425,\"./squaredDistance\":426,\"./squaredLength\":427,\"./subtract\":428,\"./transformMat4\":429,\"./transformQuat\":430}],414:[function(t,e,r){e.exports=function(t,e){return t[0]=1/e[0],t[1]=1/e[1],t[2]=1/e[2],t[3]=1/e[3],t}},{}],415:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return Math.sqrt(e*e+r*r+n*n+i*i)}},{}],416:[function(t,e,r){e.exports=function(t,e,r,n){var i=e[0],a=e[1],o=e[2],s=e[3];return t[0]=i+n*(r[0]-i),t[1]=a+n*(r[1]-a),t[2]=o+n*(r[2]-o),t[3]=s+n*(r[3]-s),t}},{}],417:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.max(e[0],r[0]),t[1]=Math.max(e[1],r[1]),t[2]=Math.max(e[2],r[2]),t[3]=Math.max(e[3],r[3]),t}},{}],418:[function(t,e,r){e.exports=function(t,e,r){return t[0]=Math.min(e[0],r[0]),t[1]=Math.min(e[1],r[1]),t[2]=Math.min(e[2],r[2]),t[3]=Math.min(e[3],r[3]),t}},{}],419:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r[0],t[1]=e[1]*r[1],t[2]=e[2]*r[2],t[3]=e[3]*r[3],t}},{}],420:[function(t,e,r){e.exports=function(t,e){return t[0]=-e[0],t[1]=-e[1],t[2]=-e[2],t[3]=-e[3],t}},{}],421:[function(t,e,r){e.exports=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=r*r+n*n+i*i+a*a;o>0&&(o=1/Math.sqrt(o),t[0]=r*o,t[1]=n*o,t[2]=i*o,t[3]=a*o);return t}},{}],422:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"./scale\");e.exports=function(t,e){return e=e||1,t[0]=Math.random(),t[1]=Math.random(),t[2]=Math.random(),t[3]=Math.random(),n(t,t),i(t,t,e),t}},{\"./normalize\":421,\"./scale\":423}],423:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t}},{}],424:[function(t,e,r){e.exports=function(t,e,r,n){return t[0]=e[0]+r[0]*n,t[1]=e[1]+r[1]*n,t[2]=e[2]+r[2]*n,t[3]=e[3]+r[3]*n,t}},{}],425:[function(t,e,r){e.exports=function(t,e,r,n,i){return t[0]=e,t[1]=r,t[2]=n,t[3]=i,t}},{}],426:[function(t,e,r){e.exports=function(t,e){var r=e[0]-t[0],n=e[1]-t[1],i=e[2]-t[2],a=e[3]-t[3];return r*r+n*n+i*i+a*a}},{}],427:[function(t,e,r){e.exports=function(t){var e=t[0],r=t[1],n=t[2],i=t[3];return e*e+r*r+n*n+i*i}},{}],428:[function(t,e,r){e.exports=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t[3]=e[3]-r[3],t}},{}],429:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}},{}],430:[function(t,e,r){e.exports=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2],c=r[3],u=c*n+s*a-l*i,f=c*i+l*n-o*a,h=c*a+o*i-s*n,p=-o*n-s*i-l*a;return t[0]=u*c+p*-o+f*-l-h*-s,t[1]=f*c+p*-s+h*-o-u*-l,t[2]=h*c+p*-l+u*-s-f*-o,t[3]=e[3],t}},{}],431:[function(t,e,r){var n=t(\"glsl-tokenizer\"),i=t(\"atob-lite\");e.exports=function(t){for(var e=Array.isArray(t)?t:n(t),r=0;r<e.length;r++){var a=e[r];if(\"preprocessor\"===a.type){var o=a.data.match(/\\#define\\s+SHADER_NAME(_B64)?\\s+(.+)$/);if(o&&o[2]){var s=o[1],l=o[2];return(s?i(l):l).trim()}}}}},{\"atob-lite\":77,\"glsl-tokenizer\":438}],432:[function(t,e,r){e.exports=function(t){var e,r,c,u=0,f=0,h=999,p=[],d=[],g=1,m=0,v=0,y=!1,x=!1,b=\"\",_=a,w=n;\"300 es\"===(t=t||{}).version&&(_=s,w=o);var T={},k={};for(u=0;u<_.length;u++)T[_[u]]=!0;for(u=0;u<w.length;u++)k[w[u]]=!0;return function(t){return d=[],null!==t?function(t){u=0,t.toString&&(t=t.toString());var r;b+=t.replace(/\\r\\n/g,\"\\n\"),c=b.length;for(;e=b[u],u<c;){switch(r=u,h){case 0:u=C();break;case 1:case 2:u=E();break;case 3:u=L();break;case 4:u=z();break;case 11:u=P();break;case 5:u=O();break;case 9999:u=D();break;case 9:u=S();break;case 999:u=A()}if(r!==u)switch(b[r]){case\"\\n\":m=0,++g;break;default:++m}}return f+=u,b=b.slice(u),d}(t):function(t){p.length&&M(p.join(\"\"));return h=10,M(\"(eof)\"),d}()};function M(t){t.length&&d.push({type:l[h],data:t,position:v,line:g,column:m})}function A(){return p=p.length?[]:p,\"/\"===r&&\"*\"===e?(v=f+u-1,h=0,r=e,u+1):\"/\"===r&&\"/\"===e?(v=f+u-1,h=1,r=e,u+1):\"#\"===e?(h=2,v=f+u,u):/\\s/.test(e)?(h=9,v=f+u,u):(y=/\\d/.test(e),x=/[^\\w_]/.test(e),v=f+u,h=y?4:x?3:9999,u)}function S(){return/[^\\s]/g.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function E(){return\"\\r\"!==e&&\"\\n\"!==e||\"\\\\\"===r?(p.push(e),r=e,u+1):(M(p.join(\"\")),h=999,u)}function C(){return\"/\"===e&&\"*\"===r?(p.push(e),M(p.join(\"\")),h=999,u+1):(p.push(e),r=e,u+1)}function L(){if(\".\"===r&&/\\d/.test(e))return h=5,u;if(\"/\"===r&&\"*\"===e)return h=0,u;if(\"/\"===r&&\"/\"===e)return h=1,u;if(\".\"===e&&p.length){for(;I(p););return h=5,u}if(\";\"===e||\")\"===e||\"(\"===e){if(p.length)for(;I(p););return M(e),h=999,u+1}var t=2===p.length&&\"=\"!==e;if(/[\\w_\\d\\s]/.test(e)||t){for(;I(p););return h=999,u}return p.push(e),r=e,u+1}function I(t){for(var e,r,n=0;;){if(e=i.indexOf(t.slice(0,t.length+n).join(\"\")),r=i[e],-1===e){if(n--+t.length>0)continue;r=t.slice(0,1).join(\"\")}return M(r),v+=r.length,(p=p.slice(r.length)).length}}function P(){return/[^a-fA-F0-9]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function z(){return\".\"===e||/[eE]/.test(e)?(p.push(e),h=5,r=e,u+1):\"x\"===e&&1===p.length&&\"0\"===p[0]?(h=11,p.push(e),r=e,u+1):/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function O(){return\"f\"===e&&(p.push(e),r=e,u+=1),/[eE]/.test(e)?(p.push(e),r=e,u+1):(\"-\"!==e&&\"+\"!==e||!/[eE]/.test(r))&&/[^\\d]/.test(e)?(M(p.join(\"\")),h=999,u):(p.push(e),r=e,u+1)}function D(){if(/[^\\d\\w_]/.test(e)){var t=p.join(\"\");return h=k[t]?8:T[t]?7:6,M(p.join(\"\")),h=999,u}return p.push(e),r=e,u+1}};var n=t(\"./lib/literals\"),i=t(\"./lib/operators\"),a=t(\"./lib/builtins\"),o=t(\"./lib/literals-300es\"),s=t(\"./lib/builtins-300es\"),l=[\"block-comment\",\"line-comment\",\"preprocessor\",\"operator\",\"integer\",\"float\",\"ident\",\"builtin\",\"keyword\",\"whitespace\",\"eof\",\"integer\"]},{\"./lib/builtins\":434,\"./lib/builtins-300es\":433,\"./lib/literals\":436,\"./lib/literals-300es\":435,\"./lib/operators\":437}],433:[function(t,e,r){var n=t(\"./builtins\");n=n.slice().filter((function(t){return!/^(gl\\_|texture)/.test(t)})),e.exports=n.concat([\"gl_VertexID\",\"gl_InstanceID\",\"gl_Position\",\"gl_PointSize\",\"gl_FragCoord\",\"gl_FrontFacing\",\"gl_FragDepth\",\"gl_PointCoord\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexUniformVectors\",\"gl_MaxVertexOutputVectors\",\"gl_MaxFragmentInputVectors\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxTextureImageUnits\",\"gl_MaxFragmentUniformVectors\",\"gl_MaxDrawBuffers\",\"gl_MinProgramTexelOffset\",\"gl_MaxProgramTexelOffset\",\"gl_DepthRangeParameters\",\"gl_DepthRange\",\"trunc\",\"round\",\"roundEven\",\"isnan\",\"isinf\",\"floatBitsToInt\",\"floatBitsToUint\",\"intBitsToFloat\",\"uintBitsToFloat\",\"packSnorm2x16\",\"unpackSnorm2x16\",\"packUnorm2x16\",\"unpackUnorm2x16\",\"packHalf2x16\",\"unpackHalf2x16\",\"outerProduct\",\"transpose\",\"determinant\",\"inverse\",\"texture\",\"textureSize\",\"textureProj\",\"textureLod\",\"textureOffset\",\"texelFetch\",\"texelFetchOffset\",\"textureProjOffset\",\"textureLodOffset\",\"textureProjLod\",\"textureProjLodOffset\",\"textureGrad\",\"textureGradOffset\",\"textureProjGrad\",\"textureProjGradOffset\"])},{\"./builtins\":434}],434:[function(t,e,r){e.exports=[\"abs\",\"acos\",\"all\",\"any\",\"asin\",\"atan\",\"ceil\",\"clamp\",\"cos\",\"cross\",\"dFdx\",\"dFdy\",\"degrees\",\"distance\",\"dot\",\"equal\",\"exp\",\"exp2\",\"faceforward\",\"floor\",\"fract\",\"gl_BackColor\",\"gl_BackLightModelProduct\",\"gl_BackLightProduct\",\"gl_BackMaterial\",\"gl_BackSecondaryColor\",\"gl_ClipPlane\",\"gl_ClipVertex\",\"gl_Color\",\"gl_DepthRange\",\"gl_DepthRangeParameters\",\"gl_EyePlaneQ\",\"gl_EyePlaneR\",\"gl_EyePlaneS\",\"gl_EyePlaneT\",\"gl_Fog\",\"gl_FogCoord\",\"gl_FogFragCoord\",\"gl_FogParameters\",\"gl_FragColor\",\"gl_FragCoord\",\"gl_FragData\",\"gl_FragDepth\",\"gl_FragDepthEXT\",\"gl_FrontColor\",\"gl_FrontFacing\",\"gl_FrontLightModelProduct\",\"gl_FrontLightProduct\",\"gl_FrontMaterial\",\"gl_FrontSecondaryColor\",\"gl_LightModel\",\"gl_LightModelParameters\",\"gl_LightModelProducts\",\"gl_LightProducts\",\"gl_LightSource\",\"gl_LightSourceParameters\",\"gl_MaterialParameters\",\"gl_MaxClipPlanes\",\"gl_MaxCombinedTextureImageUnits\",\"gl_MaxDrawBuffers\",\"gl_MaxFragmentUniformComponents\",\"gl_MaxLights\",\"gl_MaxTextureCoords\",\"gl_MaxTextureImageUnits\",\"gl_MaxTextureUnits\",\"gl_MaxVaryingFloats\",\"gl_MaxVertexAttribs\",\"gl_MaxVertexTextureImageUnits\",\"gl_MaxVertexUniformComponents\",\"gl_ModelViewMatrix\",\"gl_ModelViewMatrixInverse\",\"gl_ModelViewMatrixInverseTranspose\",\"gl_ModelViewMatrixTranspose\",\"gl_ModelViewProjectionMatrix\",\"gl_ModelViewProjectionMatrixInverse\",\"gl_ModelViewProjectionMatrixInverseTranspose\",\"gl_ModelViewProjectionMatrixTranspose\",\"gl_MultiTexCoord0\",\"gl_MultiTexCoord1\",\"gl_MultiTexCoord2\",\"gl_MultiTexCoord3\",\"gl_MultiTexCoord4\",\"gl_MultiTexCoord5\",\"gl_MultiTexCoord6\",\"gl_MultiTexCoord7\",\"gl_Normal\",\"gl_NormalMatrix\",\"gl_NormalScale\",\"gl_ObjectPlaneQ\",\"gl_ObjectPlaneR\",\"gl_ObjectPlaneS\",\"gl_ObjectPlaneT\",\"gl_Point\",\"gl_PointCoord\",\"gl_PointParameters\",\"gl_PointSize\",\"gl_Position\",\"gl_ProjectionMatrix\",\"gl_ProjectionMatrixInverse\",\"gl_ProjectionMatrixInverseTranspose\",\"gl_ProjectionMatrixTranspose\",\"gl_SecondaryColor\",\"gl_TexCoord\",\"gl_TextureEnvColor\",\"gl_TextureMatrix\",\"gl_TextureMatrixInverse\",\"gl_TextureMatrixInverseTranspose\",\"gl_TextureMatrixTranspose\",\"gl_Vertex\",\"greaterThan\",\"greaterThanEqual\",\"inversesqrt\",\"length\",\"lessThan\",\"lessThanEqual\",\"log\",\"log2\",\"matrixCompMult\",\"max\",\"min\",\"mix\",\"mod\",\"normalize\",\"not\",\"notEqual\",\"pow\",\"radians\",\"reflect\",\"refract\",\"sign\",\"sin\",\"smoothstep\",\"sqrt\",\"step\",\"tan\",\"texture2D\",\"texture2DLod\",\"texture2DProj\",\"texture2DProjLod\",\"textureCube\",\"textureCubeLod\",\"texture2DLodEXT\",\"texture2DProjLodEXT\",\"textureCubeLodEXT\",\"texture2DGradEXT\",\"texture2DProjGradEXT\",\"textureCubeGradEXT\"]},{}],435:[function(t,e,r){var n=t(\"./literals\");e.exports=n.slice().concat([\"layout\",\"centroid\",\"smooth\",\"case\",\"mat2x2\",\"mat2x3\",\"mat2x4\",\"mat3x2\",\"mat3x3\",\"mat3x4\",\"mat4x2\",\"mat4x3\",\"mat4x4\",\"uvec2\",\"uvec3\",\"uvec4\",\"samplerCubeShadow\",\"sampler2DArray\",\"sampler2DArrayShadow\",\"isampler2D\",\"isampler3D\",\"isamplerCube\",\"isampler2DArray\",\"usampler2D\",\"usampler3D\",\"usamplerCube\",\"usampler2DArray\",\"coherent\",\"restrict\",\"readonly\",\"writeonly\",\"resource\",\"atomic_uint\",\"noperspective\",\"patch\",\"sample\",\"subroutine\",\"common\",\"partition\",\"active\",\"filter\",\"image1D\",\"image2D\",\"image3D\",\"imageCube\",\"iimage1D\",\"iimage2D\",\"iimage3D\",\"iimageCube\",\"uimage1D\",\"uimage2D\",\"uimage3D\",\"uimageCube\",\"image1DArray\",\"image2DArray\",\"iimage1DArray\",\"iimage2DArray\",\"uimage1DArray\",\"uimage2DArray\",\"image1DShadow\",\"image2DShadow\",\"image1DArrayShadow\",\"image2DArrayShadow\",\"imageBuffer\",\"iimageBuffer\",\"uimageBuffer\",\"sampler1DArray\",\"sampler1DArrayShadow\",\"isampler1D\",\"isampler1DArray\",\"usampler1D\",\"usampler1DArray\",\"isampler2DRect\",\"usampler2DRect\",\"samplerBuffer\",\"isamplerBuffer\",\"usamplerBuffer\",\"sampler2DMS\",\"isampler2DMS\",\"usampler2DMS\",\"sampler2DMSArray\",\"isampler2DMSArray\",\"usampler2DMSArray\"])},{\"./literals\":436}],436:[function(t,e,r){e.exports=[\"precision\",\"highp\",\"mediump\",\"lowp\",\"attribute\",\"const\",\"uniform\",\"varying\",\"break\",\"continue\",\"do\",\"for\",\"while\",\"if\",\"else\",\"in\",\"out\",\"inout\",\"float\",\"int\",\"uint\",\"void\",\"bool\",\"true\",\"false\",\"discard\",\"return\",\"mat2\",\"mat3\",\"mat4\",\"vec2\",\"vec3\",\"vec4\",\"ivec2\",\"ivec3\",\"ivec4\",\"bvec2\",\"bvec3\",\"bvec4\",\"sampler1D\",\"sampler2D\",\"sampler3D\",\"samplerCube\",\"sampler1DShadow\",\"sampler2DShadow\",\"struct\",\"asm\",\"class\",\"union\",\"enum\",\"typedef\",\"template\",\"this\",\"packed\",\"goto\",\"switch\",\"default\",\"inline\",\"noinline\",\"volatile\",\"public\",\"static\",\"extern\",\"external\",\"interface\",\"long\",\"short\",\"double\",\"half\",\"fixed\",\"unsigned\",\"input\",\"output\",\"hvec2\",\"hvec3\",\"hvec4\",\"dvec2\",\"dvec3\",\"dvec4\",\"fvec2\",\"fvec3\",\"fvec4\",\"sampler2DRect\",\"sampler3DRect\",\"sampler2DRectShadow\",\"sizeof\",\"cast\",\"namespace\",\"using\"]},{}],437:[function(t,e,r){e.exports=[\"<<=\",\">>=\",\"++\",\"--\",\"<<\",\">>\",\"<=\",\">=\",\"==\",\"!=\",\"&&\",\"||\",\"+=\",\"-=\",\"*=\",\"/=\",\"%=\",\"&=\",\"^^\",\"^=\",\"|=\",\"(\",\")\",\"[\",\"]\",\".\",\"!\",\"~\",\"*\",\"/\",\"%\",\"+\",\"-\",\"<\",\">\",\"&\",\"^\",\"|\",\"?\",\":\",\"=\",\",\",\";\",\"{\",\"}\"]},{}],438:[function(t,e,r){var n=t(\"./index\");e.exports=function(t,e){var r=n(e),i=[];return i=(i=i.concat(r(t))).concat(r(null))}},{\"./index\":432}],439:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],440:[function(t,e,r){(function(r){(function(){\"use strict\";var n,i=t(\"is-browser\");n=\"function\"==typeof r.matchMedia?!r.matchMedia(\"(hover: none)\").matches:i,e.exports=n}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"is-browser\":464}],441:[function(t,e,r){\"use strict\";var n=t(\"is-browser\");e.exports=n&&function(){var t=!1;try{var e=Object.defineProperty({},\"passive\",{get:function(){t=!0}});window.addEventListener(\"test\",null,e),window.removeEventListener(\"test\",null,e)}catch(e){t=!1}return t}()},{\"is-browser\":464}],442:[function(t,e,r){r.read=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},r.write=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g}},{}],443:[function(t,e,r){\"use strict\";var n=t(\"./types\");e.exports=function(t,e){var r;for(r in n)if(n[r].detect(t,e))return r}},{\"./types\":446}],444:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"path\"),a=t(\"./types\"),o=t(\"./detector\");function s(t,e){var r=o(t,e);if(r in a){var n=a[r].calculate(t,e);if(!1!==n)return n.type=r,n}throw new TypeError(\"unsupported file type: \"+r+\" (file: \"+e+\")\")}e.exports=function(t,e){if(r.isBuffer(t))return s(t);if(\"string\"!=typeof t)throw new TypeError(\"invalid invocation\");var a=i.resolve(t);if(\"function\"!=typeof e)return s(function(t){var e=n.openSync(t,\"r\"),i=n.fstatSync(e).size,a=Math.min(i,524288),o=r.alloc(a);return n.readSync(e,o,0,a,0),n.closeSync(e),o}(a),a);!function(t,e){n.open(t,\"r\",(function(i,a){if(i)return e(i);n.fstat(a,(function(i,o){if(i)return e(i);var s=o.size;if(s<=0)return e(new Error(\"File size is not greater than 0 \\u2014\\u2014 \"+t));var l=Math.min(s,524288),c=r.alloc(l);n.read(a,c,0,l,0,(function(t){if(t)return e(t);n.close(a,(function(t){e(t,c)}))}))}))}))}(a,(function(t,r){if(t)return e(t);var n;try{n=s(r,a)}catch(e){t=e}e(t,n)}))},e.exports.types=Object.keys(a)}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"./detector\":443,\"./types\":446,buffer:111,fs:109,path:507}],445:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){return r=r||0,t[\"readUInt\"+e+(n?\"BE\":\"LE\")].call(t,r)}},{}],446:[function(t,e,r){\"use strict\";var n={bmp:t(\"./types/bmp\"),cur:t(\"./types/cur\"),dds:t(\"./types/dds\"),gif:t(\"./types/gif\"),icns:t(\"./types/icns\"),ico:t(\"./types/ico\"),jpg:t(\"./types/jpg\"),png:t(\"./types/png\"),psd:t(\"./types/psd\"),svg:t(\"./types/svg\"),tiff:t(\"./types/tiff\"),webp:t(\"./types/webp\")};e.exports=n},{\"./types/bmp\":447,\"./types/cur\":448,\"./types/dds\":449,\"./types/gif\":450,\"./types/icns\":451,\"./types/ico\":452,\"./types/jpg\":453,\"./types/png\":454,\"./types/psd\":455,\"./types/svg\":456,\"./types/tiff\":457,\"./types/webp\":458}],447:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"BM\"===t.toString(\"ascii\",0,2)},calculate:function(t){return{width:t.readUInt32LE(18),height:Math.abs(t.readInt32LE(22))}}}},{}],448:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&2===t.readUInt16LE(2)},calculate:t(\"./ico\").calculate}},{\"./ico\":452}],449:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return 542327876===t.readUInt32LE(0)},calculate:function(t){return{height:t.readUInt32LE(12),width:t.readUInt32LE(16)}}}},{}],450:[function(t,e,r){\"use strict\";var n=/^GIF8[79]a/;e.exports={detect:function(t){var e=t.toString(\"ascii\",0,6);return n.test(e)},calculate:function(t){return{width:t.readUInt16LE(6),height:t.readUInt16LE(8)}}}},{}],451:[function(t,e,r){\"use strict\";var n={ICON:32,\"ICN#\":32,\"icm#\":16,icm4:16,icm8:16,\"ics#\":16,ics4:16,ics8:16,is32:16,s8mk:16,icp4:16,icl4:32,icl8:32,il32:32,l8mk:32,icp5:32,ic11:32,ich4:48,ich8:48,ih32:48,h8mk:48,icp6:64,ic12:32,it32:128,t8mk:128,ic07:128,ic08:256,ic13:256,ic09:512,ic14:512,ic10:1024};function i(t,e){var r=e+4;return[t.toString(\"ascii\",e,r),t.readUInt32BE(r)]}function a(t){var e=n[t];return{width:e,height:e,type:t}}e.exports={detect:function(t){return\"icns\"===t.toString(\"ascii\",0,4)},calculate:function(t){var e,r,n,o=t.length,s=8,l=t.readUInt32BE(4);if(r=a((e=i(t,s))[0]),(s+=e[1])===l)return r;for(n={width:r.width,height:r.height,images:[r]};s<l&&s<o;)r=a((e=i(t,s))[0]),s+=e[1],n.images.push(r);return n}}},{}],452:[function(t,e,r){\"use strict\";function n(t,e){var r=t.readUInt8(e);return 0===r?256:r}function i(t,e){var r=6+16*e;return{width:n(t,r),height:n(t,r+1)}}e.exports={detect:function(t){return 0===t.readUInt16LE(0)&&1===t.readUInt16LE(2)},calculate:function(t){var e,r=t.readUInt16LE(4),n=i(t,0);if(1===r)return n;for(n.images=[{width:n.width,height:n.height}],e=1;e<r;e+=1)n.images.push(i(t,e));return n}}},{}],453:[function(t,e,r){\"use strict\";var n=t(\"../readUInt\");function i(t){return\"45786966\"===t.toString(\"hex\",2,6)}function a(t,e){return{height:t.readUInt16BE(e),width:t.readUInt16BE(e+2)}}function o(t,e){var r=t.slice(2,e),i=r.toString(\"hex\",6,8),a=\"4d4d\"===i;if(a||\"4949\"===i)return function(t,e){for(var r,i,a=n(t,16,14,e),o=0;o<a;o++){if(i=(r=16+12*o)+12,r>t.length)return;var s=t.slice(r,i);if(274===n(s,16,0,e)){if(3!==n(s,16,2,e))return;if(1!==n(s,32,4,e))return;return n(s,16,8,e)}}}(r,a)}function s(t,e){if(e>t.length)throw new TypeError(\"Corrupt JPG, exceeded buffer limits\");if(255!==t[e])throw new TypeError(\"Invalid JPG, marker table corrupted\")}e.exports={detect:function(t){return\"ffd8\"===t.toString(\"hex\",0,2)},calculate:function(t){var e,r,n;for(t=t.slice(4);t.length;){if(r=t.readUInt16BE(0),i(t)&&(e=o(t,r)),s(t,r),192===(n=t[r+1])||193===n||194===n){var l=a(t,r+5);return e?{width:l.width,height:l.height,orientation:e}:l}t=t.slice(r+2)}throw new TypeError(\"Invalid JPG, no size found\")}}},{\"../readUInt\":445}],454:[function(t,e,r){\"use strict\";e.exports={detect:function(t){if(\"PNG\\r\\n\\x1a\\n\"===t.toString(\"ascii\",1,8)){var e=t.toString(\"ascii\",12,16);if(\"CgBI\"===e&&(e=t.toString(\"ascii\",28,32)),\"IHDR\"!==e)throw new TypeError(\"invalid png\");return!0}},calculate:function(t){return\"CgBI\"===t.toString(\"ascii\",12,16)?{width:t.readUInt32BE(32),height:t.readUInt32BE(36)}:{width:t.readUInt32BE(16),height:t.readUInt32BE(20)}}}},{}],455:[function(t,e,r){\"use strict\";e.exports={detect:function(t){return\"8BPS\"===t.toString(\"ascii\",0,4)},calculate:function(t){return{width:t.readUInt32BE(18),height:t.readUInt32BE(14)}}}},{}],456:[function(t,e,r){\"use strict\";var n=/<svg\\s([^>\"']|\"[^\"]*\"|'[^']*')*>/;var i={root:n,width:/\\swidth=(['\"])([^%]+?)\\1/,height:/\\sheight=(['\"])([^%]+?)\\1/,viewbox:/\\sviewBox=(['\"])(.+?)\\1/},a={cm:96/2.54,mm:96/2.54/10,m:96/2.54*100,pt:96/72,pc:96/72/12,em:16,ex:8};function o(t){var e=/([0-9.]+)([a-z]*)/.exec(t);if(e)return Math.round(parseFloat(e[1])*(a[e[2]]||1))}function s(t){var e=t.split(\" \");return{width:o(e[2]),height:o(e[3])}}e.exports={detect:function(t){return n.test(t)},calculate:function(t){var e=t.toString(\"utf8\").match(i.root);if(e){var r=function(t){var e=t.match(i.width),r=t.match(i.height),n=t.match(i.viewbox);return{width:e&&o(e[2]),height:r&&o(r[2]),viewbox:n&&s(n[2])}}(e[0]);if(r.width&&r.height)return function(t){return{width:t.width,height:t.height}}(r);if(r.viewbox)return function(t){var e=t.viewbox.width/t.viewbox.height;return t.width?{width:t.width,height:Math.floor(t.width/e)}:t.height?{width:Math.floor(t.height*e),height:t.height}:{width:t.viewbox.width,height:t.viewbox.height}}(r)}throw new TypeError(\"invalid svg\")}}},{}],457:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"fs\"),i=t(\"../readUInt\");function a(t,e){var r=i(t,16,8,e);return(i(t,16,10,e)<<16)+r}function o(t){if(t.length>24)return t.slice(12)}e.exports={detect:function(t){var e=t.toString(\"hex\",0,4);return\"49492a00\"===e||\"4d4d002a\"===e},calculate:function(t,e){if(!e)throw new TypeError(\"Tiff doesn't support buffer\");var s=\"BE\"===function(t){var e=t.toString(\"ascii\",0,2);return\"II\"===e?\"LE\":\"MM\"===e?\"BE\":void 0}(t),l=function(t,e){for(var r,n,s,l={};t&&t.length&&(r=i(t,16,0,e),n=i(t,16,2,e),s=i(t,32,4,e),0!==r);)1!==s||3!==n&&4!==n||(l[r]=a(t,e)),t=o(t);return l}(function(t,e,a){var o=i(t,32,4,a),s=1024,l=n.statSync(e).size;o+s>l&&(s=l-o-10);var c=r.alloc(s),u=n.openSync(e,\"r\");return n.readSync(u,c,0,s,o),c.slice(2)}(t,e,s),s),c=l[256],u=l[257];if(!c||!u)throw new TypeError(\"Invalid Tiff, missing tags\");return{width:c,height:u}}}}).call(this)}).call(this,t(\"buffer\").Buffer)},{\"../readUInt\":445,buffer:111,fs:109}],458:[function(t,e,r){\"use strict\";e.exports={detect:function(t){var e=\"RIFF\"===t.toString(\"ascii\",0,4),r=\"WEBP\"===t.toString(\"ascii\",8,12),n=\"VP8\"===t.toString(\"ascii\",12,15);return e&&r&&n},calculate:function(t){var e=t.toString(\"ascii\",12,16);if(t=t.slice(20,30),\"VP8X\"===e){var r=t[0];return!(!(0==(192&r))||!(0==(1&r)))&&function(t){return{width:1+t.readUIntLE(4,3),height:1+t.readUIntLE(7,3)}}(t)}if(\"VP8 \"===e&&47!==t[0])return function(t){return{width:16383&t.readInt16LE(6),height:16383&t.readInt16LE(8)}}(t);var n=t.toString(\"hex\",3,6);return\"VP8L\"===e&&\"9d012a\"!==n&&function(t){return{width:1+((63&t[2])<<8|t[1]),height:1+((15&t[4])<<10|t[3]<<2|(192&t[2])>>6)}}(t)}}},{}],459:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=t.length;if(0===r)throw new Error(\"Must have at least d+1 points\");var i=t[0].length;if(r<=i)throw new Error(\"Must input at least d+1 points\");var o=t.slice(0,i+1),s=n.apply(void 0,o);if(0===s)throw new Error(\"Input not in general position\");for(var l=new Array(i+1),u=0;u<=i;++u)l[u]=u;s<0&&(l[0]=1,l[1]=0);var f=new a(l,new Array(i+1),!1),h=f.adjacent,p=new Array(i+2);for(u=0;u<=i;++u){for(var d=l.slice(),g=0;g<=i;++g)g===u&&(d[g]=-1);var m=d[0];d[0]=d[1],d[1]=m;var v=new a(d,new Array(i+1),!0);h[u]=v,p[u]=v}p[i+1]=f;for(u=0;u<=i;++u){d=h[u].vertices;var y=h[u].adjacent;for(g=0;g<=i;++g){var x=d[g];if(x<0)y[g]=f;else for(var b=0;b<=i;++b)h[b].vertices.indexOf(x)<0&&(y[g]=h[b])}}var _=new c(i,o,p),w=!!e;for(u=i+1;u<r;++u)_.insert(t[u],w);return _.boundary()};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\").compareCells;function a(t,e,r){this.vertices=t,this.adjacent=e,this.boundary=r,this.lastVisited=-1}function o(t,e,r){this.vertices=t,this.cell=e,this.index=r}function s(t,e){return i(t.vertices,e.vertices)}a.prototype.flip=function(){var t=this.vertices[0];this.vertices[0]=this.vertices[1],this.vertices[1]=t;var e=this.adjacent[0];this.adjacent[0]=this.adjacent[1],this.adjacent[1]=e};var l=[];function c(t,e,r){this.dimension=t,this.vertices=e,this.simplices=r,this.interior=r.filter((function(t){return!t.boundary})),this.tuple=new Array(t+1);for(var i=0;i<=t;++i)this.tuple[i]=this.vertices[i];var a=l[t];a||(a=l[t]=function(t){for(var e=[\"function orient(){var tuple=this.tuple;return test(\"],r=0;r<=t;++r)r>0&&e.push(\",\"),e.push(\"tuple[\",r,\"]\");e.push(\")}return orient\");var i=new Function(\"test\",e.join(\"\")),a=n[t+1];return a||(a=n),i(a)}(t)),this.orient=a}var u=c.prototype;u.handleBoundaryDegeneracy=function(t,e){var r=this.dimension,n=this.vertices.length-1,i=this.tuple,a=this.vertices,o=[t];for(t.lastVisited=-n;o.length>0;){(t=o.pop()).vertices;for(var s=t.adjacent,l=0;l<=r;++l){var c=s[l];if(c.boundary&&!(c.lastVisited<=-n)){for(var u=c.vertices,f=0;f<=r;++f){var h=u[f];i[f]=h<0?e:a[h]}var p=this.orient();if(p>0)return c;c.lastVisited=-n,0===p&&o.push(c)}}}return null},u.walk=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,a=this.tuple,o=e?this.interior.length*Math.random()|0:this.interior.length-1,s=this.interior[o];t:for(;!s.boundary;){for(var l=s.vertices,c=s.adjacent,u=0;u<=n;++u)a[u]=i[l[u]];s.lastVisited=r;for(u=0;u<=n;++u){var f=c[u];if(!(f.lastVisited>=r)){var h=a[u];a[u]=t;var p=this.orient();if(a[u]=h,p<0){s=f;continue t}f.boundary?f.lastVisited=-r:f.lastVisited=r}}return}return s},u.addPeaks=function(t,e){var r=this.vertices.length-1,n=this.dimension,i=this.vertices,l=this.tuple,c=this.interior,u=this.simplices,f=[e];e.lastVisited=r,e.vertices[e.vertices.indexOf(-1)]=r,e.boundary=!1,c.push(e);for(var h=[];f.length>0;){var p=(e=f.pop()).vertices,d=e.adjacent,g=p.indexOf(r);if(!(g<0))for(var m=0;m<=n;++m)if(m!==g){var v=d[m];if(v.boundary&&!(v.lastVisited>=r)){var y=v.vertices;if(v.lastVisited!==-r){for(var x=0,b=0;b<=n;++b)y[b]<0?(x=b,l[b]=t):l[b]=i[y[b]];if(this.orient()>0){y[x]=r,v.boundary=!1,c.push(v),f.push(v),v.lastVisited=r;continue}v.lastVisited=-r}var _=v.adjacent,w=p.slice(),T=d.slice(),k=new a(w,T,!0);u.push(k);var M=_.indexOf(e);if(!(M<0)){_[M]=k,T[g]=v,w[m]=-1,T[m]=e,d[m]=k,k.flip();for(b=0;b<=n;++b){var A=w[b];if(!(A<0||A===r)){for(var S=new Array(n-1),E=0,C=0;C<=n;++C){var L=w[C];L<0||C===b||(S[E++]=L)}h.push(new o(S,k,b))}}}}}}h.sort(s);for(m=0;m+1<h.length;m+=2){var I=h[m],P=h[m+1],z=I.index,O=P.index;z<0||O<0||(I.cell.adjacent[I.index]=P.cell,P.cell.adjacent[P.index]=I.cell)}},u.insert=function(t,e){var r=this.vertices;r.push(t);var n=this.walk(t,e);if(n){for(var i=this.dimension,a=this.tuple,o=0;o<=i;++o){var s=n.vertices[o];a[o]=s<0?t:r[s]}var l=this.orient(a);l<0||(0!==l||(n=this.handleBoundaryDegeneracy(n,t)))&&this.addPeaks(t,n)}},u.boundary=function(){for(var t=this.dimension,e=[],r=this.simplices,n=r.length,i=0;i<n;++i){var a=r[i];if(a.boundary){for(var o=new Array(t),s=a.vertices,l=0,c=0,u=0;u<=t;++u)s[u]>=0?o[l++]=s[u]:c=1&u;if(c===(1&t)){var f=o[0];o[0]=o[1],o[1]=f}e.push(o)}}return e}},{\"robust-orientation\":548,\"simplicial-complex\":558}],460:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\");function i(t,e,r,n,i){this.mid=t,this.left=e,this.right=r,this.leftPoints=n,this.rightPoints=i,this.count=(e?e.count:0)+(r?r.count:0)+n.length}e.exports=function(t){if(!t||0===t.length)return new v(null);return new v(m(t))};var a=i.prototype;function o(t,e){t.mid=e.mid,t.left=e.left,t.right=e.right,t.leftPoints=e.leftPoints,t.rightPoints=e.rightPoints,t.count=e.count}function s(t,e){var r=m(e);t.mid=r.mid,t.left=r.left,t.right=r.right,t.leftPoints=r.leftPoints,t.rightPoints=r.rightPoints,t.count=r.count}function l(t,e){var r=t.intervals([]);r.push(e),s(t,r)}function c(t,e){var r=t.intervals([]),n=r.indexOf(e);return n<0?0:(r.splice(n,1),s(t,r),1)}function u(t,e,r){for(var n=0;n<t.length&&t[n][0]<=e;++n){var i=r(t[n]);if(i)return i}}function f(t,e,r){for(var n=t.length-1;n>=0&&t[n][1]>=e;--n){var i=r(t[n]);if(i)return i}}function h(t,e){for(var r=0;r<t.length;++r){var n=e(t[r]);if(n)return n}}function p(t,e){return t-e}function d(t,e){var r=t[0]-e[0];return r||t[1]-e[1]}function g(t,e){var r=t[1]-e[1];return r||t[0]-e[0]}function m(t){if(0===t.length)return null;for(var e=[],r=0;r<t.length;++r)e.push(t[r][0],t[r][1]);e.sort(p);var n=e[e.length>>1],a=[],o=[],s=[];for(r=0;r<t.length;++r){var l=t[r];l[1]<n?a.push(l):n<l[0]?o.push(l):s.push(l)}var c=s,u=s.slice();return c.sort(d),u.sort(g),new i(n,m(a),m(o),c,u)}function v(t){this.root=t}a.intervals=function(t){return t.push.apply(t,this.leftPoints),this.left&&this.left.intervals(t),this.right&&this.right.intervals(t),t},a.insert=function(t){var e=this.count-this.leftPoints.length;if(this.count+=1,t[1]<this.mid)this.left?4*(this.left.count+1)>3*(e+1)?l(this,t):this.left.insert(t):this.left=m([t]);else if(t[0]>this.mid)this.right?4*(this.right.count+1)>3*(e+1)?l(this,t):this.right.insert(t):this.right=m([t]);else{var r=n.ge(this.leftPoints,t,d),i=n.ge(this.rightPoints,t,g);this.leftPoints.splice(r,0,t),this.rightPoints.splice(i,0,t)}},a.remove=function(t){var e=this.count-this.leftPoints;if(t[1]<this.mid)return this.left?4*(this.right?this.right.count:0)>3*(e-1)?c(this,t):2===(s=this.left.remove(t))?(this.left=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(t[0]>this.mid)return this.right?4*(this.left?this.left.count:0)>3*(e-1)?c(this,t):2===(s=this.right.remove(t))?(this.right=null,this.count-=1,1):(1===s&&(this.count-=1),s):0;if(1===this.count)return this.leftPoints[0]===t?2:0;if(1===this.leftPoints.length&&this.leftPoints[0]===t){if(this.left&&this.right){for(var r=this,i=this.left;i.right;)r=i,i=i.right;if(r===this)i.right=this.right;else{var a=this.left,s=this.right;r.count-=i.count,r.right=i.left,i.left=a,i.right=s}o(this,i),this.count=(this.left?this.left.count:0)+(this.right?this.right.count:0)+this.leftPoints.length}else this.left?o(this,this.left):o(this,this.right);return 1}for(a=n.ge(this.leftPoints,t,d);a<this.leftPoints.length&&this.leftPoints[a][0]===t[0];++a)if(this.leftPoints[a]===t){this.count-=1,this.leftPoints.splice(a,1);for(s=n.ge(this.rightPoints,t,g);s<this.rightPoints.length&&this.rightPoints[s][1]===t[1];++s)if(this.rightPoints[s]===t)return this.rightPoints.splice(s,1),1}return 0},a.queryPoint=function(t,e){if(t<this.mid){if(this.left)if(r=this.left.queryPoint(t,e))return r;return u(this.leftPoints,t,e)}if(t>this.mid){var r;if(this.right)if(r=this.right.queryPoint(t,e))return r;return f(this.rightPoints,t,e)}return h(this.leftPoints,e)},a.queryInterval=function(t,e,r){var n;if(t<this.mid&&this.left&&(n=this.left.queryInterval(t,e,r)))return n;if(e>this.mid&&this.right&&(n=this.right.queryInterval(t,e,r)))return n;return e<this.mid?u(this.leftPoints,e,r):t>this.mid?f(this.rightPoints,t,r):h(this.leftPoints,r)};var y=v.prototype;y.insert=function(t){this.root?this.root.insert(t):this.root=new i(t[0],null,null,[t],[t])},y.remove=function(t){if(this.root){var e=this.root.remove(t);return 2===e&&(this.root=null),0!==e}return!1},y.queryPoint=function(t,e){if(this.root)return this.root.queryPoint(t,e)},y.queryInterval=function(t,e,r){if(t<=e&&this.root)return this.root.queryInterval(t,e,r)},Object.defineProperty(y,\"count\",{get:function(){return this.root?this.root.count:0}}),Object.defineProperty(y,\"intervals\",{get:function(){return this.root?this.root.intervals([]):[]}})},{\"binary-search-bounds\":461}],461:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],462:[function(t,e,r){\"use strict\";e.exports=function(t,e){e=e||new Array(t.length);for(var r=0;r<t.length;++r)e[t[r]]=r;return e}},{}],463:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=r;return e}},{}],464:[function(t,e,r){e.exports=!0},{}],465:[function(t,e,r){function n(t){return!!t.constructor&&\"function\"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}\n",
       "/*!\n",
       " * Determine if an object is a Buffer\n",
       " *\n",
       " * @author   Feross Aboukhadijeh <https://feross.org>\n",
       " * @license  MIT\n",
       " */\n",
       "e.exports=function(t){return null!=t&&(n(t)||function(t){return\"function\"==typeof t.readFloatLE&&\"function\"==typeof t.slice&&n(t.slice(0,0))}(t)||!!t._isBuffer)}},{}],466:[function(t,e,r){\"use strict\";e.exports=\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion))},{}],467:[function(t,e,r){\"use strict\";e.exports=a,e.exports.isMobile=a,e.exports.default=a;var n=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i,i=/(android|bb\\d+|meego).+mobile|avantgo|bada\\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\\/|plucker|pocket|psp|series[46]0|symbian|treo|up\\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino|android|ipad|playbook|silk/i;function a(t){t||(t={});var e=t.ua;if(e||\"undefined\"==typeof navigator||(e=navigator.userAgent),e&&e.headers&&\"string\"==typeof e.headers[\"user-agent\"]&&(e=e.headers[\"user-agent\"]),\"string\"!=typeof e)return!1;var r=t.tablet?i.test(e):n.test(e);return!r&&t.tablet&&t.featureDetect&&navigator&&navigator.maxTouchPoints>1&&-1!==e.indexOf(\"Macintosh\")&&-1!==e.indexOf(\"Safari\")&&(r=!0),r}},{}],468:[function(t,e,r){\"use strict\";e.exports=function(t){var e=typeof t;return null!==t&&(\"object\"===e||\"function\"===e)}},{}],469:[function(t,e,r){\"use strict\";var n=Object.prototype.toString;e.exports=function(t){var e;return\"[object Object]\"===n.call(t)&&(null===(e=Object.getPrototypeOf(t))||e===Object.getPrototypeOf({}))}},{}],470:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=t.length,n=0;n<r;n++)if(((e=t.charCodeAt(n))<9||e>13)&&32!==e&&133!==e&&160!==e&&5760!==e&&6158!==e&&(e<8192||e>8205)&&8232!==e&&8233!==e&&8239!==e&&8287!==e&&8288!==e&&12288!==e&&65279!==e)return!1;return!0}},{}],471:[function(t,e,r){\"use strict\";e.exports=function(t){return\"string\"==typeof t&&(t=t.trim(),!!(/^[mzlhvcsqta]\\s*[-+.0-9][^mlhvzcsqta]+/i.test(t)&&/[\\dz]$/i.test(t)&&t.length>4))}},{}],472:[function(t,e,r){e.exports=function(t,e,r){return t*(1-r)+e*r}},{}],473:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():(t=t||self).mapboxgl=n()}(this,(function(){\"use strict\";var t,e,r;function n(n,i){if(t)if(e){var a=\"var sharedChunk = {}; (\"+t+\")(sharedChunk); (\"+e+\")(sharedChunk);\",o={};t(o),(r=i(o)).workerUrl=window.URL.createObjectURL(new Blob([a],{type:\"text/javascript\"}))}else e=i;else t=i}return n(0,(function(t){function e(t,e){return t(e={exports:{}},e.exports),e.exports}var r=n;function n(t,e,r,n){this.cx=3*t,this.bx=3*(r-t)-this.cx,this.ax=1-this.cx-this.bx,this.cy=3*e,this.by=3*(n-e)-this.cy,this.ay=1-this.cy-this.by,this.p1x=t,this.p1y=n,this.p2x=r,this.p2y=n}n.prototype.sampleCurveX=function(t){return((this.ax*t+this.bx)*t+this.cx)*t},n.prototype.sampleCurveY=function(t){return((this.ay*t+this.by)*t+this.cy)*t},n.prototype.sampleCurveDerivativeX=function(t){return(3*this.ax*t+2*this.bx)*t+this.cx},n.prototype.solveCurveX=function(t,e){var r,n,i,a,o;for(void 0===e&&(e=1e-6),i=t,o=0;o<8;o++){if(a=this.sampleCurveX(i)-t,Math.abs(a)<e)return i;var s=this.sampleCurveDerivativeX(i);if(Math.abs(s)<1e-6)break;i-=a/s}if((i=t)<(r=0))return r;if(i>(n=1))return n;for(;r<n;){if(a=this.sampleCurveX(i),Math.abs(a-t)<e)return i;t>a?r=i:n=i,i=.5*(n-r)+r}return i},n.prototype.solve=function(t,e){return this.sampleCurveY(this.solveCurveX(t,e))};var i=a;function a(t,e){this.x=t,this.y=e}function o(t,e,n,i){var a=new r(t,e,n,i);return function(t){return a.solve(t)}}a.prototype={clone:function(){return new a(this.x,this.y)},add:function(t){return this.clone()._add(t)},sub:function(t){return this.clone()._sub(t)},multByPoint:function(t){return this.clone()._multByPoint(t)},divByPoint:function(t){return this.clone()._divByPoint(t)},mult:function(t){return this.clone()._mult(t)},div:function(t){return this.clone()._div(t)},rotate:function(t){return this.clone()._rotate(t)},rotateAround:function(t,e){return this.clone()._rotateAround(t,e)},matMult:function(t){return this.clone()._matMult(t)},unit:function(){return this.clone()._unit()},perp:function(){return this.clone()._perp()},round:function(){return this.clone()._round()},mag:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},equals:function(t){return this.x===t.x&&this.y===t.y},dist:function(t){return Math.sqrt(this.distSqr(t))},distSqr:function(t){var e=t.x-this.x,r=t.y-this.y;return e*e+r*r},angle:function(){return Math.atan2(this.y,this.x)},angleTo:function(t){return Math.atan2(this.y-t.y,this.x-t.x)},angleWith:function(t){return this.angleWithSep(t.x,t.y)},angleWithSep:function(t,e){return Math.atan2(this.x*e-this.y*t,this.x*t+this.y*e)},_matMult:function(t){var e=t[2]*this.x+t[3]*this.y;return this.x=t[0]*this.x+t[1]*this.y,this.y=e,this},_add:function(t){return this.x+=t.x,this.y+=t.y,this},_sub:function(t){return this.x-=t.x,this.y-=t.y,this},_mult:function(t){return this.x*=t,this.y*=t,this},_div:function(t){return this.x/=t,this.y/=t,this},_multByPoint:function(t){return this.x*=t.x,this.y*=t.y,this},_divByPoint:function(t){return this.x/=t.x,this.y/=t.y,this},_unit:function(){return this._div(this.mag()),this},_perp:function(){var t=this.y;return this.y=this.x,this.x=-t,this},_rotate:function(t){var e=Math.cos(t),r=Math.sin(t),n=r*this.x+e*this.y;return this.x=e*this.x-r*this.y,this.y=n,this},_rotateAround:function(t,e){var r=Math.cos(t),n=Math.sin(t),i=e.y+n*(this.x-e.x)+r*(this.y-e.y);return this.x=e.x+r*(this.x-e.x)-n*(this.y-e.y),this.y=i,this},_round:function(){return this.x=Math.round(this.x),this.y=Math.round(this.y),this}},a.convert=function(t){return t instanceof a?t:Array.isArray(t)?new a(t[0],t[1]):t};var s=o(.25,.1,.25,1);function l(t,e,r){return Math.min(r,Math.max(e,t))}function c(t,e,r){var n=r-e,i=((t-e)%n+n)%n+e;return i===e?r:i}function u(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}var f=1;function h(){return f++}function p(){return function t(e){return e?(e^16*Math.random()>>e/4).toString(16):([1e7]+-[1e3]+-4e3+-8e3+-1e11).replace(/[018]/g,t)}()}function d(t){return!!t&&/^[0-9a-f]{8}-[0-9a-f]{4}-[4][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$/i.test(t)}function g(t,e){t.forEach((function(t){e[t]&&(e[t]=e[t].bind(e))}))}function m(t,e){return-1!==t.indexOf(e,t.length-e.length)}function v(t,e,r){var n={};for(var i in t)n[i]=e.call(r||this,t[i],i,t);return n}function y(t,e,r){var n={};for(var i in t)e.call(r||this,t[i],i,t)&&(n[i]=t[i]);return n}function x(t){return Array.isArray(t)?t.map(x):\"object\"==typeof t&&t?v(t,x):t}var b={};function _(t){b[t]||(\"undefined\"!=typeof console&&console.warn(t),b[t]=!0)}function w(t,e,r){return(r.y-t.y)*(e.x-t.x)>(e.y-t.y)*(r.x-t.x)}function T(t){for(var e=0,r=0,n=t.length,i=n-1,a=void 0,o=void 0;r<n;i=r++)e+=((o=t[i]).x-(a=t[r]).x)*(a.y+o.y);return e}function k(){return\"undefined\"!=typeof WorkerGlobalScope&&\"undefined\"!=typeof self&&self instanceof WorkerGlobalScope}function M(t){var e={};if(t.replace(/(?:^|(?:\\s*\\,\\s*))([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)(?:\\=(?:([^\\x00-\\x20\\(\\)<>@\\,;\\:\\\\\"\\/\\[\\]\\?\\=\\{\\}\\x7F]+)|(?:\\\"((?:[^\"\\\\]|\\\\.)*)\\\")))?/g,(function(t,r,n,i){var a=n||i;return e[r]=!a||a.toLowerCase(),\"\"})),e[\"max-age\"]){var r=parseInt(e[\"max-age\"],10);isNaN(r)?delete e[\"max-age\"]:e[\"max-age\"]=r}return e}var A=null;function S(t){if(null==A){var e=t.navigator?t.navigator.userAgent:null;A=!!t.safari||!(!e||!(/\\b(iPad|iPhone|iPod)\\b/.test(e)||e.match(\"Safari\")&&!e.match(\"Chrome\")))}return A}function E(t){try{var e=self[t];return e.setItem(\"_mapbox_test_\",1),e.removeItem(\"_mapbox_test_\"),!0}catch(t){return!1}}var C,L,I,P,z=self.performance&&self.performance.now?self.performance.now.bind(self.performance):Date.now.bind(Date),O=self.requestAnimationFrame||self.mozRequestAnimationFrame||self.webkitRequestAnimationFrame||self.msRequestAnimationFrame,D=self.cancelAnimationFrame||self.mozCancelAnimationFrame||self.webkitCancelAnimationFrame||self.msCancelAnimationFrame,R={now:z,frame:function(t){var e=O(t);return{cancel:function(){return D(e)}}},getImageData:function(t,e){void 0===e&&(e=0);var r=self.document.createElement(\"canvas\"),n=r.getContext(\"2d\");if(!n)throw new Error(\"failed to create canvas 2d context\");return r.width=t.width,r.height=t.height,n.drawImage(t,0,0,t.width,t.height),n.getImageData(-e,-e,t.width+2*e,t.height+2*e)},resolveURL:function(t){return C||(C=self.document.createElement(\"a\")),C.href=t,C.href},hardwareConcurrency:self.navigator.hardwareConcurrency||4,get devicePixelRatio(){return self.devicePixelRatio},get prefersReducedMotion(){return!!self.matchMedia&&(null==L&&(L=self.matchMedia(\"(prefers-reduced-motion: reduce)\")),L.matches)}},F={API_URL:\"https://api.mapbox.com\",get EVENTS_URL(){return this.API_URL?0===this.API_URL.indexOf(\"https://api.mapbox.cn\")?\"https://events.mapbox.cn/events/v2\":0===this.API_URL.indexOf(\"https://api.mapbox.com\")?\"https://events.mapbox.com/events/v2\":null:null},FEEDBACK_URL:\"https://apps.mapbox.com/feedback\",REQUIRE_ACCESS_TOKEN:!0,ACCESS_TOKEN:null,MAX_PARALLEL_IMAGE_REQUESTS:16},B={supported:!1,testSupport:function(t){!N&&P&&(j?U(t):I=t)}},N=!1,j=!1;function U(t){var e=t.createTexture();t.bindTexture(t.TEXTURE_2D,e);try{if(t.texImage2D(t.TEXTURE_2D,0,t.RGBA,t.RGBA,t.UNSIGNED_BYTE,P),t.isContextLost())return;B.supported=!0}catch(t){}t.deleteTexture(e),N=!0}self.document&&((P=self.document.createElement(\"img\")).onload=function(){I&&U(I),I=null,j=!0},P.onerror=function(){N=!0,I=null},P.src=\"data:image/webp;base64,UklGRh4AAABXRUJQVlA4TBEAAAAvAQAAAAfQ//73v/+BiOh/AAA=\");var V=\"01\",q=function(t,e){this._transformRequestFn=t,this._customAccessToken=e,this._createSkuToken()};function H(t){return 0===t.indexOf(\"mapbox:\")}q.prototype._createSkuToken=function(){var t=function(){for(var t=\"\",e=0;e<10;e++)t+=\"0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ\"[Math.floor(62*Math.random())];return{token:[\"1\",V,t].join(\"\"),tokenExpiresAt:Date.now()+432e5}}();this._skuToken=t.token,this._skuTokenExpiresAt=t.tokenExpiresAt},q.prototype._isSkuTokenExpired=function(){return Date.now()>this._skuTokenExpiresAt},q.prototype.transformRequest=function(t,e){return this._transformRequestFn&&this._transformRequestFn(t,e)||{url:t}},q.prototype.normalizeStyleURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/styles/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeGlyphsURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/fonts/v1\"+r.path,this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSourceURL=function(t,e){if(!H(t))return t;var r=X(t);return r.path=\"/v4/\"+r.authority+\".json\",r.params.push(\"secure\"),this._makeAPIURL(r,this._customAccessToken||e)},q.prototype.normalizeSpriteURL=function(t,e,r,n){var i=X(t);return H(t)?(i.path=\"/styles/v1\"+i.path+\"/sprite\"+e+r,this._makeAPIURL(i,this._customAccessToken||n)):(i.path+=\"\"+e+r,Z(i))},q.prototype.normalizeTileURL=function(t,e){if(this._isSkuTokenExpired()&&this._createSkuToken(),t&&!H(t))return t;var r=X(t);r.path=r.path.replace(/(\\.(png|jpg)\\d*)(?=$)/,(R.devicePixelRatio>=2||512===e?\"@2x\":\"\")+(B.supported?\".webp\":\"$1\")),r.path=r.path.replace(/^.+\\/v4\\//,\"/\"),r.path=\"/v4\"+r.path;var n=this._customAccessToken||function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e].match(/^access_token=(.*)$/);if(n)return n[1]}return null}(r.params)||F.ACCESS_TOKEN;return F.REQUIRE_ACCESS_TOKEN&&n&&this._skuToken&&r.params.push(\"sku=\"+this._skuToken),this._makeAPIURL(r,n)},q.prototype.canonicalizeTileURL=function(t,e){var r=X(t);if(!r.path.match(/(^\\/v4\\/)/)||!r.path.match(/\\.[\\w]+$/))return t;var n=\"mapbox://tiles/\";n+=r.path.replace(\"/v4/\",\"\");var i=r.params;return e&&(i=i.filter((function(t){return!t.match(/^access_token=/)}))),i.length&&(n+=\"?\"+i.join(\"&\")),n},q.prototype.canonicalizeTileset=function(t,e){for(var r=!!e&&H(e),n=[],i=0,a=t.tiles||[];i<a.length;i+=1){var o=a[i];Y(o)?n.push(this.canonicalizeTileURL(o,r)):n.push(o)}return n},q.prototype._makeAPIURL=function(t,e){var r=\"See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\",n=X(F.API_URL);if(t.protocol=n.protocol,t.authority=n.authority,\"/\"!==n.path&&(t.path=\"\"+n.path+t.path),!F.REQUIRE_ACCESS_TOKEN)return Z(t);if(!(e=e||F.ACCESS_TOKEN))throw new Error(\"An API access token is required to use Mapbox GL. \"+r);if(\"s\"===e[0])throw new Error(\"Use a public access token (pk.*) with Mapbox GL, not a secret access token (sk.*). \"+r);return t.params=t.params.filter((function(t){return-1===t.indexOf(\"access_token\")})),t.params.push(\"access_token=\"+e),Z(t)};var G=/^((https?:)?\\/\\/)?([^\\/]+\\.)?mapbox\\.c(n|om)(\\/|\\?|$)/i;function Y(t){return G.test(t)}var W=/^(\\w+):\\/\\/([^/?]*)(\\/[^?]+)?\\??(.+)?/;function X(t){var e=t.match(W);if(!e)throw new Error(\"Unable to parse URL object\");return{protocol:e[1],authority:e[2],path:e[3]||\"/\",params:e[4]?e[4].split(\"&\"):[]}}function Z(t){var e=t.params.length?\"?\"+t.params.join(\"&\"):\"\";return t.protocol+\"://\"+t.authority+t.path+e}function J(t){if(!t)return null;var e=t.split(\".\");if(!e||3!==e.length)return null;try{return JSON.parse(decodeURIComponent(self.atob(e[1]).split(\"\").map((function(t){return\"%\"+(\"00\"+t.charCodeAt(0).toString(16)).slice(-2)})).join(\"\")))}catch(t){return null}}var K=function(t){this.type=t,this.anonId=null,this.eventData={},this.queue=[],this.pendingRequest=null};K.prototype.getStorageKey=function(t){var e,r=J(F.ACCESS_TOKEN);return e=r&&r.u?self.btoa(encodeURIComponent(r.u).replace(/%([0-9A-F]{2})/g,(function(t,e){return String.fromCharCode(Number(\"0x\"+e))}))):F.ACCESS_TOKEN||\"\",t?\"mapbox.eventData.\"+t+\":\"+e:\"mapbox.eventData:\"+e},K.prototype.fetchEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{var n=self.localStorage.getItem(e);n&&(this.eventData=JSON.parse(n));var i=self.localStorage.getItem(r);i&&(this.anonId=i)}catch(t){_(\"Unable to read from LocalStorage\")}},K.prototype.saveEventData=function(){var t=E(\"localStorage\"),e=this.getStorageKey(),r=this.getStorageKey(\"uuid\");if(t)try{self.localStorage.setItem(r,this.anonId),Object.keys(this.eventData).length>=1&&self.localStorage.setItem(e,JSON.stringify(this.eventData))}catch(t){_(\"Unable to write to LocalStorage\")}},K.prototype.processRequests=function(t){},K.prototype.postEvent=function(t,e,r,n){var i=this;if(F.EVENTS_URL){var a=X(F.EVENTS_URL);a.params.push(\"access_token=\"+(n||F.ACCESS_TOKEN||\"\"));var o={event:this.type,created:new Date(t).toISOString(),sdkIdentifier:\"mapbox-gl-js\",sdkVersion:\"1.10.1\",skuId:V,userId:this.anonId},s=e?u(o,e):o,l={url:Z(a),headers:{\"Content-Type\":\"text/plain\"},body:JSON.stringify([s])};this.pendingRequest=xt(l,(function(t){i.pendingRequest=null,r(t),i.saveEventData(),i.processRequests(n)}))}},K.prototype.queueRequest=function(t,e){this.queue.push(t),this.processRequests(e)};var Q,$,tt=function(t){function e(){t.call(this,\"map.load\"),this.success={},this.skuToken=\"\"}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postMapLoadEvent=function(t,e,r,n){this.skuToken=r,(F.EVENTS_URL&&n||F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)})))&&this.queueRequest({id:e,timestamp:Date.now()},n)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){var r=this.queue.shift(),n=r.id,i=r.timestamp;n&&this.success[n]||(this.anonId||this.fetchEventData(),d(this.anonId)||(this.anonId=p()),this.postEvent(i,{skuToken:this.skuToken},(function(t){t||n&&(e.success[n]=!0)}),t))}},e}(K),et=new(function(t){function e(e){t.call(this,\"appUserTurnstile\"),this._customAccessToken=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.postTurnstileEvent=function(t,e){F.EVENTS_URL&&F.ACCESS_TOKEN&&Array.isArray(t)&&t.some((function(t){return H(t)||Y(t)}))&&this.queueRequest(Date.now(),e)},e.prototype.processRequests=function(t){var e=this;if(!this.pendingRequest&&0!==this.queue.length){this.anonId&&this.eventData.lastSuccess&&this.eventData.tokenU||this.fetchEventData();var r=J(F.ACCESS_TOKEN),n=r?r.u:F.ACCESS_TOKEN,i=n!==this.eventData.tokenU;d(this.anonId)||(this.anonId=p(),i=!0);var a=this.queue.shift();if(this.eventData.lastSuccess){var o=new Date(this.eventData.lastSuccess),s=new Date(a),l=(a-this.eventData.lastSuccess)/864e5;i=i||l>=1||l<-1||o.getDate()!==s.getDate()}else i=!0;if(!i)return this.processRequests();this.postEvent(a,{\"enabled.telemetry\":!1},(function(t){t||(e.eventData.lastSuccess=a,e.eventData.tokenU=n)}),t)}},e}(K)),rt=et.postTurnstileEvent.bind(et),nt=new tt,it=nt.postMapLoadEvent.bind(nt),at=500,ot=50;function st(){self.caches&&!Q&&(Q=self.caches.open(\"mapbox-tiles\"))}function lt(t){var e=t.indexOf(\"?\");return e<0?t:t.slice(0,e)}var ct,ut=1/0;function ft(){return null==ct&&(ct=self.OffscreenCanvas&&new self.OffscreenCanvas(1,1).getContext(\"2d\")&&\"function\"==typeof self.createImageBitmap),ct}var ht={Unknown:\"Unknown\",Style:\"Style\",Source:\"Source\",Tile:\"Tile\",Glyphs:\"Glyphs\",SpriteImage:\"SpriteImage\",SpriteJSON:\"SpriteJSON\",Image:\"Image\"};\"function\"==typeof Object.freeze&&Object.freeze(ht);var pt,dt,gt=function(t){function e(e,r,n){401===r&&Y(n)&&(e+=\": you may have provided an invalid Mapbox access token. See https://www.mapbox.com/api-documentation/#access-tokens-and-token-scopes\"),t.call(this,e),this.status=r,this.url=n,this.name=this.constructor.name,this.message=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.toString=function(){return this.name+\": \"+this.message+\" (\"+this.status+\"): \"+this.url},e}(Error),mt=k()?function(){return self.worker&&self.worker.referrer}:function(){return(\"blob:\"===self.location.protocol?self.parent:self).location.href},vt=function(t,e){if(!(/^file:/.test(r=t.url)||/^file:/.test(mt())&&!/^\\w+:/.test(r))){if(self.fetch&&self.Request&&self.AbortController&&self.Request.prototype.hasOwnProperty(\"signal\"))return function(t,e){var r,n=new self.AbortController,i=new self.Request(t.url,{method:t.method||\"GET\",body:t.body,credentials:t.credentials,headers:t.headers,referrer:mt(),signal:n.signal}),a=!1,o=!1,s=(r=i.url).indexOf(\"sku=\")>0&&Y(r);\"json\"===t.type&&i.headers.set(\"Accept\",\"application/json\");var l=function(r,n,a){if(!o){if(r&&\"SecurityError\"!==r.message&&_(r),n&&a)return c(n);var l=Date.now();self.fetch(i).then((function(r){if(r.ok){var n=s?r.clone():null;return c(r,n,l)}return e(new gt(r.statusText,r.status,t.url))})).catch((function(t){20!==t.code&&e(new Error(t.message))}))}},c=function(r,n,s){(\"arrayBuffer\"===t.type?r.arrayBuffer():\"json\"===t.type?r.json():r.text()).then((function(t){o||(n&&s&&function(t,e,r){if(st(),Q){var n={status:e.status,statusText:e.statusText,headers:new self.Headers};e.headers.forEach((function(t,e){return n.headers.set(e,t)}));var i=M(e.headers.get(\"Cache-Control\")||\"\");i[\"no-store\"]||(i[\"max-age\"]&&n.headers.set(\"Expires\",new Date(r+1e3*i[\"max-age\"]).toUTCString()),new Date(n.headers.get(\"Expires\")).getTime()-r<42e4||function(t,e){if(void 0===$)try{new Response(new ReadableStream),$=!0}catch(t){$=!1}$?e(t.body):t.blob().then(e)}(e,(function(e){var r=new self.Response(e,n);st(),Q&&Q.then((function(e){return e.put(lt(t.url),r)})).catch((function(t){return _(t.message)}))})))}}(i,n,s),a=!0,e(null,t,r.headers.get(\"Cache-Control\"),r.headers.get(\"Expires\")))})).catch((function(t){o||e(new Error(t.message))}))};return s?function(t,e){if(st(),!Q)return e(null);var r=lt(t.url);Q.then((function(t){t.match(r).then((function(n){var i=function(t){if(!t)return!1;var e=new Date(t.headers.get(\"Expires\")||0),r=M(t.headers.get(\"Cache-Control\")||\"\");return e>Date.now()&&!r[\"no-cache\"]}(n);t.delete(r),i&&t.put(r,n.clone()),e(null,n,i)})).catch(e)})).catch(e)}(i,l):l(null,null),{cancel:function(){o=!0,a||n.abort()}}}(t,e);if(k()&&self.worker&&self.worker.actor)return self.worker.actor.send(\"getResource\",t,e,void 0,!0)}var r;return function(t,e){var r=new self.XMLHttpRequest;for(var n in r.open(t.method||\"GET\",t.url,!0),\"arrayBuffer\"===t.type&&(r.responseType=\"arraybuffer\"),t.headers)r.setRequestHeader(n,t.headers[n]);return\"json\"===t.type&&(r.responseType=\"text\",r.setRequestHeader(\"Accept\",\"application/json\")),r.withCredentials=\"include\"===t.credentials,r.onerror=function(){e(new Error(r.statusText))},r.onload=function(){if((r.status>=200&&r.status<300||0===r.status)&&null!==r.response){var n=r.response;if(\"json\"===t.type)try{n=JSON.parse(r.response)}catch(t){return e(t)}e(null,n,r.getResponseHeader(\"Cache-Control\"),r.getResponseHeader(\"Expires\"))}else e(new gt(r.statusText,r.status,t.url))},r.send(t.body),{cancel:function(){return r.abort()}}}(t,e)},yt=function(t,e){return vt(u(t,{type:\"arrayBuffer\"}),e)},xt=function(t,e){return vt(u(t,{method:\"POST\"}),e)};pt=[],dt=0;var bt=function(t,e){if(B.supported&&(t.headers||(t.headers={}),t.headers.accept=\"image/webp,*/*\"),dt>=F.MAX_PARALLEL_IMAGE_REQUESTS){var r={requestParameters:t,callback:e,cancelled:!1,cancel:function(){this.cancelled=!0}};return pt.push(r),r}dt++;var n=!1,i=function(){if(!n)for(n=!0,dt--;pt.length&&dt<F.MAX_PARALLEL_IMAGE_REQUESTS;){var t=pt.shift();t.cancelled||(t.cancel=bt(t.requestParameters,t.callback).cancel)}},a=yt(t,(function(t,r,n,a){i(),t?e(t):r&&(ft()?function(t,e){var r=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});self.createImageBitmap(r).then((function(t){e(null,t)})).catch((function(t){e(new Error(\"Could not load image because of \"+t.message+\". Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))}))}(r,e):function(t,e,r,n){var i=new self.Image,a=self.URL;i.onload=function(){e(null,i),a.revokeObjectURL(i.src)},i.onerror=function(){return e(new Error(\"Could not load image. Please make sure to use a supported image type such as PNG or JPEG. Note that SVGs are not supported.\"))};var o=new self.Blob([new Uint8Array(t)],{type:\"image/png\"});i.cacheControl=r,i.expires=n,i.src=t.byteLength?a.createObjectURL(o):\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAC0lEQVQYV2NgAAIAAAUAAarVyFEAAAAASUVORK5CYII=\"}(r,e,n,a))}));return{cancel:function(){a.cancel(),i()}}};function _t(t,e,r){r[t]&&-1!==r[t].indexOf(e)||(r[t]=r[t]||[],r[t].push(e))}function wt(t,e,r){if(r&&r[t]){var n=r[t].indexOf(e);-1!==n&&r[t].splice(n,1)}}var Tt=function(t,e){void 0===e&&(e={}),u(this,e),this.type=t},kt=function(t){function e(e,r){void 0===r&&(r={}),t.call(this,\"error\",u({error:e},r))}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Tt),Mt=function(){};Mt.prototype.on=function(t,e){return this._listeners=this._listeners||{},_t(t,e,this._listeners),this},Mt.prototype.off=function(t,e){return wt(t,e,this._listeners),wt(t,e,this._oneTimeListeners),this},Mt.prototype.once=function(t,e){return this._oneTimeListeners=this._oneTimeListeners||{},_t(t,e,this._oneTimeListeners),this},Mt.prototype.fire=function(t,e){\"string\"==typeof t&&(t=new Tt(t,e||{}));var r=t.type;if(this.listens(r)){t.target=this;for(var n=0,i=this._listeners&&this._listeners[r]?this._listeners[r].slice():[];n<i.length;n+=1)i[n].call(this,t);for(var a=0,o=this._oneTimeListeners&&this._oneTimeListeners[r]?this._oneTimeListeners[r].slice():[];a<o.length;a+=1){var s=o[a];wt(r,s,this._oneTimeListeners),s.call(this,t)}var l=this._eventedParent;l&&(u(t,\"function\"==typeof this._eventedParentData?this._eventedParentData():this._eventedParentData),l.fire(t))}else t instanceof kt&&console.error(t.error);return this},Mt.prototype.listens=function(t){return this._listeners&&this._listeners[t]&&this._listeners[t].length>0||this._oneTimeListeners&&this._oneTimeListeners[t]&&this._oneTimeListeners[t].length>0||this._eventedParent&&this._eventedParent.listens(t)},Mt.prototype.setEventedParent=function(t,e){return this._eventedParent=t,this._eventedParentData=e,this};var At={$version:8,$root:{version:{required:!0,type:\"enum\",values:[8]},name:{type:\"string\"},metadata:{type:\"*\"},center:{type:\"array\",value:\"number\"},zoom:{type:\"number\"},bearing:{type:\"number\",default:0,period:360,units:\"degrees\"},pitch:{type:\"number\",default:0,units:\"degrees\"},light:{type:\"light\"},sources:{required:!0,type:\"sources\"},sprite:{type:\"string\"},glyphs:{type:\"string\"},transition:{type:\"transition\"},layers:{required:!0,type:\"array\",value:\"layer\"}},sources:{\"*\":{type:\"source\"}},source:[\"source_vector\",\"source_raster\",\"source_raster_dem\",\"source_geojson\",\"source_video\",\"source_image\"],source_vector:{type:{required:!0,type:\"enum\",values:{vector:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},attribution:{type:\"string\"},promoteId:{type:\"promoteId\"},\"*\":{type:\"*\"}},source_raster:{type:{required:!0,type:\"enum\",values:{raster:{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},scheme:{type:\"enum\",values:{xyz:{},tms:{}},default:\"xyz\"},attribution:{type:\"string\"},\"*\":{type:\"*\"}},source_raster_dem:{type:{required:!0,type:\"enum\",values:{\"raster-dem\":{}}},url:{type:\"string\"},tiles:{type:\"array\",value:\"string\"},bounds:{type:\"array\",value:\"number\",length:4,default:[-180,-85.051129,180,85.051129]},minzoom:{type:\"number\",default:0},maxzoom:{type:\"number\",default:22},tileSize:{type:\"number\",default:512,units:\"pixels\"},attribution:{type:\"string\"},encoding:{type:\"enum\",values:{terrarium:{},mapbox:{}},default:\"mapbox\"},\"*\":{type:\"*\"}},source_geojson:{type:{required:!0,type:\"enum\",values:{geojson:{}}},data:{type:\"*\"},maxzoom:{type:\"number\",default:18},attribution:{type:\"string\"},buffer:{type:\"number\",default:128,maximum:512,minimum:0},tolerance:{type:\"number\",default:.375},cluster:{type:\"boolean\",default:!1},clusterRadius:{type:\"number\",default:50,minimum:0},clusterMaxZoom:{type:\"number\"},clusterProperties:{type:\"*\"},lineMetrics:{type:\"boolean\",default:!1},generateId:{type:\"boolean\",default:!1},promoteId:{type:\"promoteId\"}},source_video:{type:{required:!0,type:\"enum\",values:{video:{}}},urls:{required:!0,type:\"array\",value:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},source_image:{type:{required:!0,type:\"enum\",values:{image:{}}},url:{required:!0,type:\"string\"},coordinates:{required:!0,type:\"array\",length:4,value:{type:\"array\",length:2,value:\"number\"}}},layer:{id:{type:\"string\",required:!0},type:{type:\"enum\",values:{fill:{},line:{},symbol:{},circle:{},heatmap:{},\"fill-extrusion\":{},raster:{},hillshade:{},background:{}},required:!0},metadata:{type:\"*\"},source:{type:\"string\"},\"source-layer\":{type:\"string\"},minzoom:{type:\"number\",minimum:0,maximum:24},maxzoom:{type:\"number\",minimum:0,maximum:24},filter:{type:\"filter\"},layout:{type:\"layout\"},paint:{type:\"paint\"}},layout:[\"layout_fill\",\"layout_line\",\"layout_circle\",\"layout_heatmap\",\"layout_fill-extrusion\",\"layout_symbol\",\"layout_raster\",\"layout_hillshade\",\"layout_background\"],layout_background:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_fill:{\"fill-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_circle:{\"circle-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_heatmap:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},\"layout_fill-extrusion\":{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_line:{\"line-cap\":{type:\"enum\",values:{butt:{},round:{},square:{}},default:\"butt\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-join\":{type:\"enum\",values:{bevel:{},round:{},miter:{}},default:\"miter\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"line-miter-limit\":{type:\"number\",default:2,requires:[{\"line-join\":\"miter\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-round-limit\":{type:\"number\",default:1.05,requires:[{\"line-join\":\"round\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_symbol:{\"symbol-placement\":{type:\"enum\",values:{point:{},line:{},\"line-center\":{}},default:\"point\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-spacing\":{type:\"number\",default:250,minimum:1,units:\"pixels\",requires:[{\"symbol-placement\":\"line\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-avoid-edges\":{type:\"boolean\",default:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"symbol-sort-key\":{type:\"number\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"symbol-z-order\":{type:\"enum\",values:{auto:{},\"viewport-y\":{},source:{}},default:\"auto\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-optional\":{type:\"boolean\",default:!1,requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-size\":{type:\"number\",default:1,minimum:0,units:\"factor of the original icon size\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-text-fit\":{type:\"enum\",values:{none:{},width:{},height:{},both:{}},default:\"none\",requires:[\"icon-image\",\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-text-fit-padding\":{type:\"array\",value:\"number\",length:4,default:[0,0,0,0],units:\"pixels\",requires:[\"icon-image\",\"text-field\",{\"icon-text-fit\":[\"both\",\"width\",\"height\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-image\":{type:\"resolvedImage\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-keep-upright\":{type:\"boolean\",default:!1,requires:[\"icon-image\",{\"icon-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-offset\":{type:\"array\",value:\"number\",length:2,default:[0,0],requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"icon-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotation-alignment\":{type:\"enum\",values:{map:{},viewport:{},auto:{}},default:\"auto\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-field\":{type:\"formatted\",default:\"\",tokens:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-font\":{type:\"array\",value:\"string\",default:[\"Open Sans Regular\",\"Arial Unicode MS Regular\"],requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-size\":{type:\"number\",default:16,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-width\":{type:\"number\",default:10,minimum:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-line-height\":{type:\"number\",default:1.2,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-letter-spacing\":{type:\"number\",default:0,units:\"ems\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-justify\":{type:\"enum\",values:{auto:{},left:{},center:{},right:{}},default:\"center\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-radial-offset\":{type:\"number\",units:\"ems\",default:0,requires:[\"text-field\"],\"property-type\":\"data-driven\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]}},\"text-variable-anchor\":{type:\"array\",value:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-anchor\":{type:\"enum\",values:{center:{},left:{},right:{},top:{},bottom:{},\"top-left\":{},\"top-right\":{},\"bottom-left\":{},\"bottom-right\":{}},default:\"center\",requires:[\"text-field\",{\"!\":\"text-variable-anchor\"}],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-max-angle\":{type:\"number\",default:45,units:\"degrees\",requires:[\"text-field\",{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-writing-mode\":{type:\"array\",value:\"enum\",values:{horizontal:{},vertical:{}},requires:[\"text-field\",{\"symbol-placement\":[\"point\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-rotate\":{type:\"number\",default:0,period:360,units:\"degrees\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-padding\":{type:\"number\",default:2,minimum:0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-keep-upright\":{type:\"boolean\",default:!0,requires:[\"text-field\",{\"text-rotation-alignment\":\"map\"},{\"symbol-placement\":[\"line\",\"line-center\"]}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-transform\":{type:\"enum\",values:{none:{},uppercase:{},lowercase:{}},default:\"none\",requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-offset\":{type:\"array\",value:\"number\",units:\"ems\",length:2,default:[0,0],requires:[\"text-field\",{\"!\":\"text-radial-offset\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"data-driven\"},\"text-allow-overlap\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-ignore-placement\":{type:\"boolean\",default:!1,requires:[\"text-field\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-optional\":{type:\"boolean\",default:!1,requires:[\"text-field\",\"icon-image\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_raster:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},layout_hillshade:{visibility:{type:\"enum\",values:{visible:{},none:{}},default:\"visible\",\"property-type\":\"constant\"}},filter:{type:\"array\",value:\"*\"},filter_operator:{type:\"enum\",values:{\"==\":{},\"!=\":{},\">\":{},\">=\":{},\"<\":{},\"<=\":{},in:{},\"!in\":{},all:{},any:{},none:{},has:{},\"!has\":{},within:{}}},geometry_type:{type:\"enum\",values:{Point:{},LineString:{},Polygon:{}}},function:{expression:{type:\"expression\"},stops:{type:\"array\",value:\"function_stop\"},base:{type:\"number\",default:1,minimum:0},property:{type:\"string\",default:\"$zoom\"},type:{type:\"enum\",values:{identity:{},exponential:{},interval:{},categorical:{}},default:\"exponential\"},colorSpace:{type:\"enum\",values:{rgb:{},lab:{},hcl:{}},default:\"rgb\"},default:{type:\"*\",required:!1}},function_stop:{type:\"array\",minimum:0,maximum:24,value:[\"number\",\"color\"],length:2},expression:{type:\"array\",value:\"*\",minimum:1},expression_name:{type:\"enum\",values:{let:{group:\"Variable binding\"},var:{group:\"Variable binding\"},literal:{group:\"Types\"},array:{group:\"Types\"},at:{group:\"Lookup\"},in:{group:\"Lookup\"},\"index-of\":{group:\"Lookup\"},slice:{group:\"Lookup\"},case:{group:\"Decision\"},match:{group:\"Decision\"},coalesce:{group:\"Decision\"},step:{group:\"Ramps, scales, curves\"},interpolate:{group:\"Ramps, scales, curves\"},\"interpolate-hcl\":{group:\"Ramps, scales, curves\"},\"interpolate-lab\":{group:\"Ramps, scales, curves\"},ln2:{group:\"Math\"},pi:{group:\"Math\"},e:{group:\"Math\"},typeof:{group:\"Types\"},string:{group:\"Types\"},number:{group:\"Types\"},boolean:{group:\"Types\"},object:{group:\"Types\"},collator:{group:\"Types\"},format:{group:\"Types\"},image:{group:\"Types\"},\"number-format\":{group:\"Types\"},\"to-string\":{group:\"Types\"},\"to-number\":{group:\"Types\"},\"to-boolean\":{group:\"Types\"},\"to-rgba\":{group:\"Color\"},\"to-color\":{group:\"Types\"},rgb:{group:\"Color\"},rgba:{group:\"Color\"},get:{group:\"Lookup\"},has:{group:\"Lookup\"},length:{group:\"Lookup\"},properties:{group:\"Feature data\"},\"feature-state\":{group:\"Feature data\"},\"geometry-type\":{group:\"Feature data\"},id:{group:\"Feature data\"},zoom:{group:\"Zoom\"},\"heatmap-density\":{group:\"Heatmap\"},\"line-progress\":{group:\"Feature data\"},accumulated:{group:\"Feature data\"},\"+\":{group:\"Math\"},\"*\":{group:\"Math\"},\"-\":{group:\"Math\"},\"/\":{group:\"Math\"},\"%\":{group:\"Math\"},\"^\":{group:\"Math\"},sqrt:{group:\"Math\"},log10:{group:\"Math\"},ln:{group:\"Math\"},log2:{group:\"Math\"},sin:{group:\"Math\"},cos:{group:\"Math\"},tan:{group:\"Math\"},asin:{group:\"Math\"},acos:{group:\"Math\"},atan:{group:\"Math\"},min:{group:\"Math\"},max:{group:\"Math\"},round:{group:\"Math\"},abs:{group:\"Math\"},ceil:{group:\"Math\"},floor:{group:\"Math\"},distance:{group:\"Math\"},\"==\":{group:\"Decision\"},\"!=\":{group:\"Decision\"},\">\":{group:\"Decision\"},\"<\":{group:\"Decision\"},\">=\":{group:\"Decision\"},\"<=\":{group:\"Decision\"},all:{group:\"Decision\"},any:{group:\"Decision\"},\"!\":{group:\"Decision\"},within:{group:\"Decision\"},\"is-supported-script\":{group:\"String\"},upcase:{group:\"String\"},downcase:{group:\"String\"},concat:{group:\"String\"},\"resolved-locale\":{group:\"String\"}}},light:{anchor:{type:\"enum\",default:\"viewport\",values:{map:{},viewport:{}},\"property-type\":\"data-constant\",transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]}},position:{type:\"array\",default:[1.15,210,30],length:3,value:\"number\",\"property-type\":\"data-constant\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]}},color:{type:\"color\",\"property-type\":\"data-constant\",default:\"#ffffff\",expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0},intensity:{type:\"number\",\"property-type\":\"data-constant\",default:.5,minimum:0,maximum:1,expression:{interpolated:!0,parameters:[\"zoom\"]},transition:!0}},paint:[\"paint_fill\",\"paint_line\",\"paint_circle\",\"paint_heatmap\",\"paint_fill-extrusion\",\"paint_symbol\",\"paint_raster\",\"paint_hillshade\",\"paint_background\"],paint_fill:{\"fill-antialias\":{type:\"boolean\",default:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-outline-color\":{type:\"color\",transition:!0,requires:[{\"!\":\"fill-pattern\"},{\"fill-antialias\":!0}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"}},\"paint_fill-extrusion\":{\"fill-extrusion-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"fill-extrusion-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"fill-extrusion-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"fill-extrusion-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"fill-extrusion-height\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-base\":{type:\"number\",default:0,minimum:0,units:\"meters\",transition:!0,requires:[\"fill-extrusion-height\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"fill-extrusion-vertical-gradient\":{type:\"boolean\",default:!0,transition:!1,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_line:{\"line-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"line-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"line-width\":{type:\"number\",default:1,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-gap-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-offset\":{type:\"number\",default:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"line-dasharray\":{type:\"array\",value:\"number\",minimum:0,transition:!0,units:\"line widths\",requires:[{\"!\":\"line-pattern\"}],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"line-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]},\"property-type\":\"cross-faded-data-driven\"},\"line-gradient\":{type:\"color\",transition:!1,requires:[{\"!\":\"line-dasharray\"},{\"!\":\"line-pattern\"},{source:\"geojson\",has:{lineMetrics:!0}}],expression:{interpolated:!0,parameters:[\"line-progress\"]},\"property-type\":\"color-ramp\"}},paint_circle:{\"circle-radius\":{type:\"number\",default:5,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-blur\":{type:\"number\",default:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"circle-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-scale\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-pitch-alignment\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"circle-stroke-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"circle-stroke-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"}},paint_heatmap:{\"heatmap-radius\":{type:\"number\",default:30,minimum:1,transition:!0,units:\"pixels\",expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-weight\":{type:\"number\",default:1,minimum:0,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"heatmap-intensity\":{type:\"number\",default:1,minimum:0,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"heatmap-color\":{type:\"color\",default:[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,\"rgba(0, 0, 255, 0)\",.1,\"royalblue\",.3,\"cyan\",.5,\"lime\",.7,\"yellow\",1,\"red\"],transition:!1,expression:{interpolated:!0,parameters:[\"heatmap-density\"]},\"property-type\":\"color-ramp\"},\"heatmap-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_symbol:{\"icon-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"icon-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"icon-image\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"icon-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"icon-image\",\"icon-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-color\":{type:\"color\",default:\"#000000\",transition:!0,overridable:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-color\":{type:\"color\",default:\"rgba(0, 0, 0, 0)\",transition:!0,requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-width\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-halo-blur\":{type:\"number\",default:0,minimum:0,transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\",\"feature\",\"feature-state\"]},\"property-type\":\"data-driven\"},\"text-translate\":{type:\"array\",value:\"number\",length:2,default:[0,0],transition:!0,units:\"pixels\",requires:[\"text-field\"],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"text-translate-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"map\",requires:[\"text-field\",\"text-translate\"],expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_raster:{\"raster-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-hue-rotate\":{type:\"number\",default:0,period:360,transition:!0,units:\"degrees\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-min\":{type:\"number\",default:0,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-brightness-max\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-saturation\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-contrast\":{type:\"number\",default:0,minimum:-1,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-resampling\":{type:\"enum\",values:{linear:{},nearest:{}},default:\"linear\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"raster-fade-duration\":{type:\"number\",default:300,minimum:0,transition:!1,units:\"milliseconds\",expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_hillshade:{\"hillshade-illumination-direction\":{type:\"number\",default:335,minimum:0,maximum:359,transition:!1,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-illumination-anchor\":{type:\"enum\",values:{map:{},viewport:{}},default:\"viewport\",expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-exaggeration\":{type:\"number\",default:.5,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-shadow-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-highlight-color\":{type:\"color\",default:\"#FFFFFF\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"hillshade-accent-color\":{type:\"color\",default:\"#000000\",transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},paint_background:{\"background-color\":{type:\"color\",default:\"#000000\",transition:!0,requires:[{\"!\":\"background-pattern\"}],expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"},\"background-pattern\":{type:\"resolvedImage\",transition:!0,expression:{interpolated:!1,parameters:[\"zoom\"]},\"property-type\":\"cross-faded\"},\"background-opacity\":{type:\"number\",default:1,minimum:0,maximum:1,transition:!0,expression:{interpolated:!0,parameters:[\"zoom\"]},\"property-type\":\"data-constant\"}},transition:{duration:{type:\"number\",default:300,minimum:0,units:\"milliseconds\"},delay:{type:\"number\",default:0,minimum:0,units:\"milliseconds\"}},\"property-type\":{\"data-driven\":{type:\"property-type\"},\"cross-faded\":{type:\"property-type\"},\"cross-faded-data-driven\":{type:\"property-type\"},\"color-ramp\":{type:\"property-type\"},\"data-constant\":{type:\"property-type\"},constant:{type:\"property-type\"}},promoteId:{\"*\":{type:\"string\"}}},St=function(t,e,r,n){this.message=(t?t+\": \":\"\")+r,n&&(this.identifier=n),null!=e&&e.__line__&&(this.line=e.__line__)};function Et(t){var e=t.value;return e?[new St(t.key,e,\"constants have been deprecated as of v8\")]:[]}function Ct(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];for(var n=0,i=e;n<i.length;n+=1){var a=i[n];for(var o in a)t[o]=a[o]}return t}function Lt(t){return t instanceof Number||t instanceof String||t instanceof Boolean?t.valueOf():t}function It(t){if(Array.isArray(t))return t.map(It);if(t instanceof Object&&!(t instanceof Number||t instanceof String||t instanceof Boolean)){var e={};for(var r in t)e[r]=It(t[r]);return e}return Lt(t)}var Pt=function(t){function e(e,r){t.call(this,r),this.message=r,this.key=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Error),zt=function(t,e){void 0===e&&(e=[]),this.parent=t,this.bindings={};for(var r=0,n=e;r<n.length;r+=1){var i=n[r];this.bindings[i[0]]=i[1]}};zt.prototype.concat=function(t){return new zt(this,t)},zt.prototype.get=function(t){if(this.bindings[t])return this.bindings[t];if(this.parent)return this.parent.get(t);throw new Error(t+\" not found in scope.\")},zt.prototype.has=function(t){return!!this.bindings[t]||!!this.parent&&this.parent.has(t)};var Ot={kind:\"null\"},Dt={kind:\"number\"},Rt={kind:\"string\"},Ft={kind:\"boolean\"},Bt={kind:\"color\"},Nt={kind:\"object\"},jt={kind:\"value\"},Ut={kind:\"collator\"},Vt={kind:\"formatted\"},qt={kind:\"resolvedImage\"};function Ht(t,e){return{kind:\"array\",itemType:t,N:e}}function Gt(t){if(\"array\"===t.kind){var e=Gt(t.itemType);return\"number\"==typeof t.N?\"array<\"+e+\", \"+t.N+\">\":\"value\"===t.itemType.kind?\"array\":\"array<\"+e+\">\"}return t.kind}var Yt=[Ot,Dt,Rt,Ft,Bt,Vt,Nt,Ht(jt),qt];function Wt(t,e){if(\"error\"===e.kind)return null;if(\"array\"===t.kind){if(\"array\"===e.kind&&(0===e.N&&\"value\"===e.itemType.kind||!Wt(t.itemType,e.itemType))&&(\"number\"!=typeof t.N||t.N===e.N))return null}else{if(t.kind===e.kind)return null;if(\"value\"===t.kind)for(var r=0,n=Yt;r<n.length;r+=1)if(!Wt(n[r],e))return null}return\"Expected \"+Gt(t)+\" but found \"+Gt(e)+\" instead.\"}function Xt(t,e){return e.some((function(e){return e.kind===t.kind}))}function Zt(t,e){return e.some((function(e){return\"null\"===e?null===t:\"array\"===e?Array.isArray(t):\"object\"===e?t&&!Array.isArray(t)&&\"object\"==typeof t:e===typeof t}))}var Jt=e((function(t,e){var r={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],rebeccapurple:[102,51,153,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function n(t){return(t=Math.round(t))<0?0:t>255?255:t}function i(t){return n(\"%\"===t[t.length-1]?parseFloat(t)/100*255:parseInt(t))}function a(t){return(e=\"%\"===t[t.length-1]?parseFloat(t)/100:parseFloat(t))<0?0:e>1?1:e;var e}function o(t,e,r){return r<0?r+=1:r>1&&(r-=1),6*r<1?t+(e-t)*r*6:2*r<1?e:3*r<2?t+(e-t)*(2/3-r)*6:t}try{e.parseCSSColor=function(t){var e,s=t.replace(/ /g,\"\").toLowerCase();if(s in r)return r[s].slice();if(\"#\"===s[0])return 4===s.length?(e=parseInt(s.substr(1),16))>=0&&e<=4095?[(3840&e)>>4|(3840&e)>>8,240&e|(240&e)>>4,15&e|(15&e)<<4,1]:null:7===s.length&&(e=parseInt(s.substr(1),16))>=0&&e<=16777215?[(16711680&e)>>16,(65280&e)>>8,255&e,1]:null;var l=s.indexOf(\"(\"),c=s.indexOf(\")\");if(-1!==l&&c+1===s.length){var u=s.substr(0,l),f=s.substr(l+1,c-(l+1)).split(\",\"),h=1;switch(u){case\"rgba\":if(4!==f.length)return null;h=a(f.pop());case\"rgb\":return 3!==f.length?null:[i(f[0]),i(f[1]),i(f[2]),h];case\"hsla\":if(4!==f.length)return null;h=a(f.pop());case\"hsl\":if(3!==f.length)return null;var p=(parseFloat(f[0])%360+360)%360/360,d=a(f[1]),g=a(f[2]),m=g<=.5?g*(d+1):g+d-g*d,v=2*g-m;return[n(255*o(v,m,p+1/3)),n(255*o(v,m,p)),n(255*o(v,m,p-1/3)),h];default:return null}}return null}}catch(t){}})).parseCSSColor,Kt=function(t,e,r,n){void 0===n&&(n=1),this.r=t,this.g=e,this.b=r,this.a=n};Kt.parse=function(t){if(t){if(t instanceof Kt)return t;if(\"string\"==typeof t){var e=Jt(t);if(e)return new Kt(e[0]/255*e[3],e[1]/255*e[3],e[2]/255*e[3],e[3])}}},Kt.prototype.toString=function(){var t=this.toArray(),e=t[1],r=t[2],n=t[3];return\"rgba(\"+Math.round(t[0])+\",\"+Math.round(e)+\",\"+Math.round(r)+\",\"+n+\")\"},Kt.prototype.toArray=function(){var t=this.a;return 0===t?[0,0,0,0]:[255*this.r/t,255*this.g/t,255*this.b/t,t]},Kt.black=new Kt(0,0,0,1),Kt.white=new Kt(1,1,1,1),Kt.transparent=new Kt(0,0,0,0),Kt.red=new Kt(1,0,0,1);var Qt=function(t,e,r){this.sensitivity=t?e?\"variant\":\"case\":e?\"accent\":\"base\",this.locale=r,this.collator=new Intl.Collator(this.locale?this.locale:[],{sensitivity:this.sensitivity,usage:\"search\"})};Qt.prototype.compare=function(t,e){return this.collator.compare(t,e)},Qt.prototype.resolvedLocale=function(){return new Intl.Collator(this.locale?this.locale:[]).resolvedOptions().locale};var $t=function(t,e,r,n,i){this.text=t,this.image=e,this.scale=r,this.fontStack=n,this.textColor=i},te=function(t){this.sections=t};te.fromString=function(t){return new te([new $t(t,null,null,null,null)])},te.prototype.isEmpty=function(){return 0===this.sections.length||!this.sections.some((function(t){return 0!==t.text.length||t.image&&0!==t.image.name.length}))},te.factory=function(t){return t instanceof te?t:te.fromString(t)},te.prototype.toString=function(){return 0===this.sections.length?\"\":this.sections.map((function(t){return t.text})).join(\"\")},te.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];if(n.image)t.push([\"image\",n.image.name]);else{t.push(n.text);var i={};n.fontStack&&(i[\"text-font\"]=[\"literal\",n.fontStack.split(\",\")]),n.scale&&(i[\"font-scale\"]=n.scale),n.textColor&&(i[\"text-color\"]=[\"rgba\"].concat(n.textColor.toArray())),t.push(i)}}return t};var ee=function(t){this.name=t.name,this.available=t.available};function re(t,e,r,n){return\"number\"==typeof t&&t>=0&&t<=255&&\"number\"==typeof e&&e>=0&&e<=255&&\"number\"==typeof r&&r>=0&&r<=255?void 0===n||\"number\"==typeof n&&n>=0&&n<=1?null:\"Invalid rgba value [\"+[t,e,r,n].join(\", \")+\"]: 'a' must be between 0 and 1.\":\"Invalid rgba value [\"+(\"number\"==typeof n?[t,e,r,n]:[t,e,r]).join(\", \")+\"]: 'r', 'g', and 'b' must be between 0 and 255.\"}function ne(t){if(null===t)return!0;if(\"string\"==typeof t)return!0;if(\"boolean\"==typeof t)return!0;if(\"number\"==typeof t)return!0;if(t instanceof Kt)return!0;if(t instanceof Qt)return!0;if(t instanceof te)return!0;if(t instanceof ee)return!0;if(Array.isArray(t)){for(var e=0,r=t;e<r.length;e+=1)if(!ne(r[e]))return!1;return!0}if(\"object\"==typeof t){for(var n in t)if(!ne(t[n]))return!1;return!0}return!1}function ie(t){if(null===t)return Ot;if(\"string\"==typeof t)return Rt;if(\"boolean\"==typeof t)return Ft;if(\"number\"==typeof t)return Dt;if(t instanceof Kt)return Bt;if(t instanceof Qt)return Ut;if(t instanceof te)return Vt;if(t instanceof ee)return qt;if(Array.isArray(t)){for(var e,r=t.length,n=0,i=t;n<i.length;n+=1){var a=ie(i[n]);if(e){if(e===a)continue;e=jt;break}e=a}return Ht(e||jt,r)}return Nt}function ae(t){var e=typeof t;return null===t?\"\":\"string\"===e||\"number\"===e||\"boolean\"===e?String(t):t instanceof Kt||t instanceof te||t instanceof ee?t.toString():JSON.stringify(t)}ee.prototype.toString=function(){return this.name},ee.fromString=function(t){return t?new ee({name:t,available:!1}):null},ee.prototype.serialize=function(){return[\"image\",this.name]};var oe=function(t,e){this.type=t,this.value=e};oe.parse=function(t,e){if(2!==t.length)return e.error(\"'literal' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(!ne(t[1]))return e.error(\"invalid value\");var r=t[1],n=ie(r),i=e.expectedType;return\"array\"!==n.kind||0!==n.N||!i||\"array\"!==i.kind||\"number\"==typeof i.N&&0!==i.N||(n=i),new oe(n,r)},oe.prototype.evaluate=function(){return this.value},oe.prototype.eachChild=function(){},oe.prototype.outputDefined=function(){return!0},oe.prototype.serialize=function(){return\"array\"===this.type.kind||\"object\"===this.type.kind?[\"literal\",this.value]:this.value instanceof Kt?[\"rgba\"].concat(this.value.toArray()):this.value instanceof te?this.value.serialize():this.value};var se=function(t){this.name=\"ExpressionEvaluationError\",this.message=t};se.prototype.toJSON=function(){return this.message};var le={string:Rt,number:Dt,boolean:Ft,object:Nt},ce=function(t,e){this.type=t,this.args=e};ce.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r,n=1,i=t[0];if(\"array\"===i){var a,o;if(t.length>2){var s=t[1];if(\"string\"!=typeof s||!(s in le)||\"object\"===s)return e.error('The item type argument of \"array\" must be one of string, number, boolean',1);a=le[s],n++}else a=jt;if(t.length>3){if(null!==t[2]&&(\"number\"!=typeof t[2]||t[2]<0||t[2]!==Math.floor(t[2])))return e.error('The length argument to \"array\" must be a positive integer literal',2);o=t[2],n++}r=Ht(a,o)}else r=le[i];for(var l=[];n<t.length;n++){var c=e.parse(t[n],n,jt);if(!c)return null;l.push(c)}return new ce(r,l)},ce.prototype.evaluate=function(t){for(var e=0;e<this.args.length;e++){var r=this.args[e].evaluate(t);if(!Wt(this.type,ie(r)))return r;if(e===this.args.length-1)throw new se(\"Expected value to be of type \"+Gt(this.type)+\", but found \"+Gt(ie(r))+\" instead.\")}return null},ce.prototype.eachChild=function(t){this.args.forEach(t)},ce.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ce.prototype.serialize=function(){var t=this.type,e=[t.kind];if(\"array\"===t.kind){var r=t.itemType;if(\"string\"===r.kind||\"number\"===r.kind||\"boolean\"===r.kind){e.push(r.kind);var n=t.N;(\"number\"==typeof n||this.args.length>1)&&e.push(n)}}return e.concat(this.args.map((function(t){return t.serialize()})))};var ue=function(t){this.type=Vt,this.sections=t};ue.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[1];if(!Array.isArray(r)&&\"object\"==typeof r)return e.error(\"First argument must be an image or text section.\");for(var n=[],i=!1,a=1;a<=t.length-1;++a){var o=t[a];if(i&&\"object\"==typeof o&&!Array.isArray(o)){i=!1;var s=null;if(o[\"font-scale\"]&&!(s=e.parse(o[\"font-scale\"],1,Dt)))return null;var l=null;if(o[\"text-font\"]&&!(l=e.parse(o[\"text-font\"],1,Ht(Rt))))return null;var c=null;if(o[\"text-color\"]&&!(c=e.parse(o[\"text-color\"],1,Bt)))return null;var u=n[n.length-1];u.scale=s,u.font=l,u.textColor=c}else{var f=e.parse(t[a],1,jt);if(!f)return null;var h=f.type.kind;if(\"string\"!==h&&\"value\"!==h&&\"null\"!==h&&\"resolvedImage\"!==h)return e.error(\"Formatted text type must be 'string', 'value', 'image' or 'null'.\");i=!0,n.push({content:f,scale:null,font:null,textColor:null})}}return new ue(n)},ue.prototype.evaluate=function(t){return new te(this.sections.map((function(e){var r=e.content.evaluate(t);return ie(r)===qt?new $t(\"\",r,null,null,null):new $t(ae(r),null,e.scale?e.scale.evaluate(t):null,e.font?e.font.evaluate(t).join(\",\"):null,e.textColor?e.textColor.evaluate(t):null)})))},ue.prototype.eachChild=function(t){for(var e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t(n.content),n.scale&&t(n.scale),n.font&&t(n.font),n.textColor&&t(n.textColor)}},ue.prototype.outputDefined=function(){return!1},ue.prototype.serialize=function(){for(var t=[\"format\"],e=0,r=this.sections;e<r.length;e+=1){var n=r[e];t.push(n.content.serialize());var i={};n.scale&&(i[\"font-scale\"]=n.scale.serialize()),n.font&&(i[\"text-font\"]=n.font.serialize()),n.textColor&&(i[\"text-color\"]=n.textColor.serialize()),t.push(i)}return t};var fe=function(t){this.type=qt,this.input=t};fe.parse=function(t,e){if(2!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Rt);return r?new fe(r):e.error(\"No image name provided.\")},fe.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=ee.fromString(e);return r&&t.availableImages&&(r.available=t.availableImages.indexOf(e)>-1),r},fe.prototype.eachChild=function(t){t(this.input)},fe.prototype.outputDefined=function(){return!1},fe.prototype.serialize=function(){return[\"image\",this.input.serialize()]};var he={\"to-boolean\":Ft,\"to-color\":Bt,\"to-number\":Dt,\"to-string\":Rt},pe=function(t,e){this.type=t,this.args=e};pe.parse=function(t,e){if(t.length<2)return e.error(\"Expected at least one argument.\");var r=t[0];if((\"to-boolean\"===r||\"to-string\"===r)&&2!==t.length)return e.error(\"Expected one argument.\");for(var n=he[r],i=[],a=1;a<t.length;a++){var o=e.parse(t[a],a,jt);if(!o)return null;i.push(o)}return new pe(n,i)},pe.prototype.evaluate=function(t){if(\"boolean\"===this.type.kind)return Boolean(this.args[0].evaluate(t));if(\"color\"===this.type.kind){for(var e,r,n=0,i=this.args;n<i.length;n+=1){if(r=null,(e=i[n].evaluate(t))instanceof Kt)return e;if(\"string\"==typeof e){var a=t.parseColor(e);if(a)return a}else if(Array.isArray(e)&&!(r=e.length<3||e.length>4?\"Invalid rbga value \"+JSON.stringify(e)+\": expected an array containing either three or four numeric values.\":re(e[0],e[1],e[2],e[3])))return new Kt(e[0]/255,e[1]/255,e[2]/255,e[3])}throw new se(r||\"Could not parse color from value '\"+(\"string\"==typeof e?e:String(JSON.stringify(e)))+\"'\")}if(\"number\"===this.type.kind){for(var o=null,s=0,l=this.args;s<l.length;s+=1){if(null===(o=l[s].evaluate(t)))return 0;var c=Number(o);if(!isNaN(c))return c}throw new se(\"Could not convert \"+JSON.stringify(o)+\" to number.\")}return\"formatted\"===this.type.kind?te.fromString(ae(this.args[0].evaluate(t))):\"resolvedImage\"===this.type.kind?ee.fromString(ae(this.args[0].evaluate(t))):ae(this.args[0].evaluate(t))},pe.prototype.eachChild=function(t){this.args.forEach(t)},pe.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},pe.prototype.serialize=function(){if(\"formatted\"===this.type.kind)return new ue([{content:this.args[0],scale:null,font:null,textColor:null}]).serialize();if(\"resolvedImage\"===this.type.kind)return new fe(this.args[0]).serialize();var t=[\"to-\"+this.type.kind];return this.eachChild((function(e){t.push(e.serialize())})),t};var de=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ge=function(){this.globals=null,this.feature=null,this.featureState=null,this.formattedSection=null,this._parseColorCache={},this.availableImages=null,this.canonical=null};ge.prototype.id=function(){return this.feature&&\"id\"in this.feature?this.feature.id:null},ge.prototype.geometryType=function(){return this.feature?\"number\"==typeof this.feature.type?de[this.feature.type]:this.feature.type:null},ge.prototype.geometry=function(){return this.feature&&\"geometry\"in this.feature?this.feature.geometry:null},ge.prototype.canonicalID=function(){return this.canonical},ge.prototype.properties=function(){return this.feature&&this.feature.properties||{}},ge.prototype.parseColor=function(t){var e=this._parseColorCache[t];return e||(e=this._parseColorCache[t]=Kt.parse(t)),e};var me=function(t,e,r,n){this.name=t,this.type=e,this._evaluate=r,this.args=n};me.prototype.evaluate=function(t){return this._evaluate(t,this.args)},me.prototype.eachChild=function(t){this.args.forEach(t)},me.prototype.outputDefined=function(){return!1},me.prototype.serialize=function(){return[this.name].concat(this.args.map((function(t){return t.serialize()})))},me.parse=function(t,e){var r,n=t[0],i=me.definitions[n];if(!i)return e.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0);for(var a=Array.isArray(i)?i[0]:i.type,o=Array.isArray(i)?[[i[1],i[2]]]:i.overloads,s=o.filter((function(e){var r=e[0];return!Array.isArray(r)||r.length===t.length-1})),l=null,c=0,u=s;c<u.length;c+=1){var f=u[c],h=f[0],p=f[1];l=new Be(e.registry,e.path,null,e.scope);for(var d=[],g=!1,m=1;m<t.length;m++){var v=t[m],y=Array.isArray(h)?h[m-1]:h.type,x=l.parse(v,1+d.length,y);if(!x){g=!0;break}d.push(x)}if(!g)if(Array.isArray(h)&&h.length!==d.length)l.error(\"Expected \"+h.length+\" arguments, but found \"+d.length+\" instead.\");else{for(var b=0;b<d.length;b++){var _=Array.isArray(h)?h[b]:h.type,w=d[b];l.concat(b+1).checkSubtype(_,w.type)}if(0===l.errors.length)return new me(n,a,p,d)}}if(1===s.length)(r=e.errors).push.apply(r,l.errors);else{for(var T=(s.length?s:o).map((function(t){var e;return e=t[0],Array.isArray(e)?\"(\"+e.map(Gt).join(\", \")+\")\":\"(\"+Gt(e.type)+\"...)\"})).join(\" | \"),k=[],M=1;M<t.length;M++){var A=e.parse(t[M],1+k.length);if(!A)return null;k.push(Gt(A.type))}e.error(\"Expected arguments of type \"+T+\", but found (\"+k.join(\", \")+\") instead.\")}return null},me.register=function(t,e){for(var r in me.definitions=e,e)t[r]=me};var ve=function(t,e,r){this.type=Ut,this.locale=r,this.caseSensitive=t,this.diacriticSensitive=e};function ye(t,e){t[0]=Math.min(t[0],e[0]),t[1]=Math.min(t[1],e[1]),t[2]=Math.max(t[2],e[0]),t[3]=Math.max(t[3],e[1])}function xe(t,e){return!(t[0]<=e[0]||t[2]>=e[2]||t[1]<=e[1]||t[3]>=e[3])}function be(t,e){var r=(180+t[0])/360,n=(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t[1]*Math.PI/360)))/360,i=Math.pow(2,e.z);return[Math.round(r*i*8192),Math.round(n*i*8192)]}function _e(t,e,r){return e[1]>t[1]!=r[1]>t[1]&&t[0]<(r[0]-e[0])*(t[1]-e[1])/(r[1]-e[1])+e[0]}function we(t,e){for(var r,n,i,a,o,s,l,c=!1,u=0,f=e.length;u<f;u++)for(var h=e[u],p=0,d=h.length;p<d-1;p++){if((a=(r=t)[0]-(n=h[p])[0])*(l=r[1]-(i=h[p+1])[1])-(s=r[0]-i[0])*(o=r[1]-n[1])==0&&a*s<=0&&o*l<=0)return!1;_e(t,h[p],h[p+1])&&(c=!c)}return c}function Te(t,e){for(var r=0;r<e.length;r++)if(we(t,e[r]))return!0;return!1}function ke(t,e,r,n){var i=n[0]-r[0],a=n[1]-r[1],o=(t[0]-r[0])*a-i*(t[1]-r[1]),s=(e[0]-r[0])*a-i*(e[1]-r[1]);return o>0&&s<0||o<0&&s>0}function Me(t,e,r){for(var n=0,i=r;n<i.length;n+=1)for(var a=i[n],o=0;o<a.length-1;++o)if(0!=(f=[(u=a[o+1])[0]-(c=a[o])[0],u[1]-c[1]])[0]*(h=[(l=e)[0]-(s=t)[0],l[1]-s[1]])[1]-f[1]*h[0]&&ke(s,l,c,u)&&ke(c,u,s,l))return!0;var s,l,c,u,f,h;return!1}function Ae(t,e){for(var r=0;r<t.length;++r)if(!we(t[r],e))return!1;for(var n=0;n<t.length-1;++n)if(Me(t[n],t[n+1],e))return!1;return!0}function Se(t,e){for(var r=0;r<e.length;r++)if(Ae(t,e[r]))return!0;return!1}function Ee(t,e,r){for(var n=[],i=0;i<t.length;i++){for(var a=[],o=0;o<t[i].length;o++){var s=be(t[i][o],r);ye(e,s),a.push(s)}n.push(a)}return n}function Ce(t,e,r){for(var n=[],i=0;i<t.length;i++){var a=Ee(t[i],e,r);n.push(a)}return n}function Le(t,e,r,n){if(t[0]<r[0]||t[0]>r[2]){var i=.5*n,a=t[0]-r[0]>i?-n:r[0]-t[0]>i?n:0;0===a&&(a=t[0]-r[2]>i?-n:r[2]-t[0]>i?n:0),t[0]+=a}ye(e,t)}function Ie(t,e,r,n){for(var i=8192*Math.pow(2,n.z),a=[8192*n.x,8192*n.y],o=[],s=0,l=t;s<l.length;s+=1)for(var c=0,u=l[s];c<u.length;c+=1){var f=u[c],h=[f.x+a[0],f.y+a[1]];Le(h,e,r,i),o.push(h)}return o}function Pe(t,e,r,n){for(var i,a=8192*Math.pow(2,n.z),o=[8192*n.x,8192*n.y],s=[],l=0,c=t;l<c.length;l+=1){for(var u=[],f=0,h=c[l];f<h.length;f+=1){var p=h[f],d=[p.x+o[0],p.y+o[1]];ye(e,d),u.push(d)}s.push(u)}if(e[2]-e[0]<=a/2){(i=e)[0]=i[1]=1/0,i[2]=i[3]=-1/0;for(var g=0,m=s;g<m.length;g+=1)for(var v=0,y=m[g];v<y.length;v+=1)Le(y[v],e,r,a)}return s}ve.parse=function(t,e){if(2!==t.length)return e.error(\"Expected one argument.\");var r=t[1];if(\"object\"!=typeof r||Array.isArray(r))return e.error(\"Collator options argument must be an object.\");var n=e.parse(void 0!==r[\"case-sensitive\"]&&r[\"case-sensitive\"],1,Ft);if(!n)return null;var i=e.parse(void 0!==r[\"diacritic-sensitive\"]&&r[\"diacritic-sensitive\"],1,Ft);if(!i)return null;var a=null;return r.locale&&!(a=e.parse(r.locale,1,Rt))?null:new ve(n,i,a)},ve.prototype.evaluate=function(t){return new Qt(this.caseSensitive.evaluate(t),this.diacriticSensitive.evaluate(t),this.locale?this.locale.evaluate(t):null)},ve.prototype.eachChild=function(t){t(this.caseSensitive),t(this.diacriticSensitive),this.locale&&t(this.locale)},ve.prototype.outputDefined=function(){return!1},ve.prototype.serialize=function(){var t={};return t[\"case-sensitive\"]=this.caseSensitive.serialize(),t[\"diacritic-sensitive\"]=this.diacriticSensitive.serialize(),this.locale&&(t.locale=this.locale.serialize()),[\"collator\",t]};var ze=function(t,e){this.type=Ft,this.geojson=t,this.geometries=e};function Oe(t){if(t instanceof me){if(\"get\"===t.name&&1===t.args.length)return!1;if(\"feature-state\"===t.name)return!1;if(\"has\"===t.name&&1===t.args.length)return!1;if(\"properties\"===t.name||\"geometry-type\"===t.name||\"id\"===t.name)return!1;if(/^filter-/.test(t.name))return!1}if(t instanceof ze)return!1;var e=!0;return t.eachChild((function(t){e&&!Oe(t)&&(e=!1)})),e}function De(t){if(t instanceof me&&\"feature-state\"===t.name)return!1;var e=!0;return t.eachChild((function(t){e&&!De(t)&&(e=!1)})),e}function Re(t,e){if(t instanceof me&&e.indexOf(t.name)>=0)return!1;var r=!0;return t.eachChild((function(t){r&&!Re(t,e)&&(r=!1)})),r}ze.parse=function(t,e){if(2!==t.length)return e.error(\"'within' expression requires exactly one argument, but found \"+(t.length-1)+\" instead.\");if(ne(t[1])){var r=t[1];if(\"FeatureCollection\"===r.type)for(var n=0;n<r.features.length;++n){var i=r.features[n].geometry.type;if(\"Polygon\"===i||\"MultiPolygon\"===i)return new ze(r,r.features[n].geometry)}else if(\"Feature\"===r.type){var a=r.geometry.type;if(\"Polygon\"===a||\"MultiPolygon\"===a)return new ze(r,r.geometry)}else if(\"Polygon\"===r.type||\"MultiPolygon\"===r.type)return new ze(r,r)}return e.error(\"'within' expression requires valid geojson object that contains polygon geometry type.\")},ze.prototype.evaluate=function(t){if(null!=t.geometry()&&null!=t.canonicalID()){if(\"Point\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!we(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Ie(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Te(h[f],c))return!1}return!0}(t,this.geometries);if(\"LineString\"===t.geometryType())return function(t,e){var r=[1/0,1/0,-1/0,-1/0],n=[1/0,1/0,-1/0,-1/0],i=t.canonicalID();if(\"Polygon\"===e.type){var a=Ee(e.coordinates,n,i),o=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var s=0,l=o;s<l.length;s+=1)if(!Ae(l[s],a))return!1}if(\"MultiPolygon\"===e.type){var c=Ce(e.coordinates,n,i),u=Pe(t.geometry(),r,n,i);if(!xe(r,n))return!1;for(var f=0,h=u;f<h.length;f+=1)if(!Se(h[f],c))return!1}return!0}(t,this.geometries)}return!1},ze.prototype.eachChild=function(){},ze.prototype.outputDefined=function(){return!0},ze.prototype.serialize=function(){return[\"within\",this.geojson]};var Fe=function(t,e){this.type=e.type,this.name=t,this.boundExpression=e};Fe.parse=function(t,e){if(2!==t.length||\"string\"!=typeof t[1])return e.error(\"'var' expression requires exactly one string literal argument.\");var r=t[1];return e.scope.has(r)?new Fe(r,e.scope.get(r)):e.error('Unknown variable \"'+r+'\". Make sure \"'+r+'\" has been bound in an enclosing \"let\" expression before using it.',1)},Fe.prototype.evaluate=function(t){return this.boundExpression.evaluate(t)},Fe.prototype.eachChild=function(){},Fe.prototype.outputDefined=function(){return!1},Fe.prototype.serialize=function(){return[\"var\",this.name]};var Be=function(t,e,r,n,i){void 0===e&&(e=[]),void 0===n&&(n=new zt),void 0===i&&(i=[]),this.registry=t,this.path=e,this.key=e.map((function(t){return\"[\"+t+\"]\"})).join(\"\"),this.scope=n,this.errors=i,this.expectedType=r};function Ne(t,e){for(var r,n=t.length-1,i=0,a=n,o=0;i<=a;)if((r=t[o=Math.floor((i+a)/2)])<=e){if(o===n||e<t[o+1])return o;i=o+1}else{if(!(r>e))throw new se(\"Input is not a number.\");a=o-1}return 0}Be.prototype.parse=function(t,e,r,n,i){return void 0===i&&(i={}),e?this.concat(e,r,n)._parse(t,i):this._parse(t,i)},Be.prototype._parse=function(t,e){function r(t,e,r){return\"assert\"===r?new ce(e,[t]):\"coerce\"===r?new pe(e,[t]):t}if(null!==t&&\"string\"!=typeof t&&\"boolean\"!=typeof t&&\"number\"!=typeof t||(t=[\"literal\",t]),Array.isArray(t)){if(0===t.length)return this.error('Expected an array with at least one element. If you wanted a literal array, use [\"literal\", []].');var n=t[0];if(\"string\"!=typeof n)return this.error(\"Expression name must be a string, but found \"+typeof n+' instead. If you wanted a literal array, use [\"literal\", [...]].',0),null;var i=this.registry[n];if(i){var a=i.parse(t,this);if(!a)return null;if(this.expectedType){var o=this.expectedType,s=a.type;if(\"string\"!==o.kind&&\"number\"!==o.kind&&\"boolean\"!==o.kind&&\"object\"!==o.kind&&\"array\"!==o.kind||\"value\"!==s.kind)if(\"color\"!==o.kind&&\"formatted\"!==o.kind&&\"resolvedImage\"!==o.kind||\"value\"!==s.kind&&\"string\"!==s.kind){if(this.checkSubtype(o,s))return null}else a=r(a,o,e.typeAnnotation||\"coerce\");else a=r(a,o,e.typeAnnotation||\"assert\")}if(!(a instanceof oe)&&\"resolvedImage\"!==a.type.kind&&function t(e){if(e instanceof Fe)return t(e.boundExpression);if(e instanceof me&&\"error\"===e.name)return!1;if(e instanceof ve)return!1;if(e instanceof ze)return!1;var r=e instanceof pe||e instanceof ce,n=!0;return e.eachChild((function(e){n=r?n&&t(e):n&&e instanceof oe})),!!n&&Oe(e)&&Re(e,[\"zoom\",\"heatmap-density\",\"line-progress\",\"accumulated\",\"is-supported-script\"])}(a)){var l=new ge;try{a=new oe(a.type,a.evaluate(l))}catch(t){return this.error(t.message),null}}return a}return this.error('Unknown expression \"'+n+'\". If you wanted a literal array, use [\"literal\", [...]].',0)}return this.error(void 0===t?\"'undefined' value invalid. Use null instead.\":\"object\"==typeof t?'Bare objects invalid. Use [\"literal\", {...}] instead.':\"Expected an array, but found \"+typeof t+\" instead.\")},Be.prototype.concat=function(t,e,r){var n=\"number\"==typeof t?this.path.concat(t):this.path,i=r?this.scope.concat(r):this.scope;return new Be(this.registry,n,e||null,i,this.errors)},Be.prototype.error=function(t){for(var e=[],r=arguments.length-1;r-- >0;)e[r]=arguments[r+1];var n=\"\"+this.key+e.map((function(t){return\"[\"+t+\"]\"})).join(\"\");this.errors.push(new Pt(n,t))},Be.prototype.checkSubtype=function(t,e){var r=Wt(t,e);return r&&this.error(r),r};var je=function(t,e,r){this.type=t,this.input=e,this.labels=[],this.outputs=[];for(var n=0,i=r;n<i.length;n+=1){var a=i[n],o=a[1];this.labels.push(a[0]),this.outputs.push(o)}};function Ue(t,e,r){return t*(1-r)+e*r}je.parse=function(t,e){if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=[],i=null;e.expectedType&&\"value\"!==e.expectedType.kind&&(i=e.expectedType);for(var a=1;a<t.length;a+=2){var o=1===a?-1/0:t[a],s=t[a+1],l=a,c=a+1;if(\"number\"!=typeof o)return e.error('Input/output pairs for \"step\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',l);if(n.length&&n[n.length-1][0]>=o)return e.error('Input/output pairs for \"step\" expressions must be arranged with input values in strictly ascending order.',l);var u=e.parse(s,c,i);if(!u)return null;i=i||u.type,n.push([o,u])}return new je(i,r,n)},je.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;return n>=e[i-1]?r[i-1].evaluate(t):r[Ne(e,n)].evaluate(t)},je.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},je.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},je.prototype.serialize=function(){for(var t=[\"step\",this.input.serialize()],e=0;e<this.labels.length;e++)e>0&&t.push(this.labels[e]),t.push(this.outputs[e].serialize());return t};var Ve=Object.freeze({__proto__:null,number:Ue,color:function(t,e,r){return new Kt(Ue(t.r,e.r,r),Ue(t.g,e.g,r),Ue(t.b,e.b,r),Ue(t.a,e.a,r))},array:function(t,e,r){return t.map((function(t,n){return Ue(t,e[n],r)}))}}),qe=6/29*3*(6/29),He=Math.PI/180,Ge=180/Math.PI;function Ye(t){return t>.008856451679035631?Math.pow(t,1/3):t/qe+4/29}function We(t){return t>6/29?t*t*t:qe*(t-4/29)}function Xe(t){return 255*(t<=.0031308?12.92*t:1.055*Math.pow(t,1/2.4)-.055)}function Ze(t){return(t/=255)<=.04045?t/12.92:Math.pow((t+.055)/1.055,2.4)}function Je(t){var e=Ze(t.r),r=Ze(t.g),n=Ze(t.b),i=Ye((.4124564*e+.3575761*r+.1804375*n)/.95047),a=Ye((.2126729*e+.7151522*r+.072175*n)/1);return{l:116*a-16,a:500*(i-a),b:200*(a-Ye((.0193339*e+.119192*r+.9503041*n)/1.08883)),alpha:t.a}}function Ke(t){var e=(t.l+16)/116,r=isNaN(t.a)?e:e+t.a/500,n=isNaN(t.b)?e:e-t.b/200;return e=1*We(e),r=.95047*We(r),n=1.08883*We(n),new Kt(Xe(3.2404542*r-1.5371385*e-.4985314*n),Xe(-.969266*r+1.8760108*e+.041556*n),Xe(.0556434*r-.2040259*e+1.0572252*n),t.alpha)}function Qe(t,e,r){var n=e-t;return t+r*(n>180||n<-180?n-360*Math.round(n/360):n)}var $e={forward:Je,reverse:Ke,interpolate:function(t,e,r){return{l:Ue(t.l,e.l,r),a:Ue(t.a,e.a,r),b:Ue(t.b,e.b,r),alpha:Ue(t.alpha,e.alpha,r)}}},tr={forward:function(t){var e=Je(t),r=e.l,n=e.a,i=e.b,a=Math.atan2(i,n)*Ge;return{h:a<0?a+360:a,c:Math.sqrt(n*n+i*i),l:r,alpha:t.a}},reverse:function(t){var e=t.h*He,r=t.c;return Ke({l:t.l,a:Math.cos(e)*r,b:Math.sin(e)*r,alpha:t.alpha})},interpolate:function(t,e,r){return{h:Qe(t.h,e.h,r),c:Ue(t.c,e.c,r),l:Ue(t.l,e.l,r),alpha:Ue(t.alpha,e.alpha,r)}}},er=Object.freeze({__proto__:null,lab:$e,hcl:tr}),rr=function(t,e,r,n,i){this.type=t,this.operator=e,this.interpolation=r,this.input=n,this.labels=[],this.outputs=[];for(var a=0,o=i;a<o.length;a+=1){var s=o[a],l=s[1];this.labels.push(s[0]),this.outputs.push(l)}};function nr(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}rr.interpolationFactor=function(t,e,n,i){var a=0;if(\"exponential\"===t.name)a=nr(e,t.base,n,i);else if(\"linear\"===t.name)a=nr(e,1,n,i);else if(\"cubic-bezier\"===t.name){var o=t.controlPoints;a=new r(o[0],o[1],o[2],o[3]).solve(nr(e,1,n,i))}return a},rr.parse=function(t,e){var r=t[0],n=t[1],i=t[2],a=t.slice(3);if(!Array.isArray(n)||0===n.length)return e.error(\"Expected an interpolation type expression.\",1);if(\"linear\"===n[0])n={name:\"linear\"};else if(\"exponential\"===n[0]){var o=n[1];if(\"number\"!=typeof o)return e.error(\"Exponential interpolation requires a numeric base.\",1,1);n={name:\"exponential\",base:o}}else{if(\"cubic-bezier\"!==n[0])return e.error(\"Unknown interpolation type \"+String(n[0]),1,0);var s=n.slice(1);if(4!==s.length||s.some((function(t){return\"number\"!=typeof t||t<0||t>1})))return e.error(\"Cubic bezier interpolation requires four numeric arguments with values between 0 and 1.\",1);n={name:\"cubic-bezier\",controlPoints:s}}if(t.length-1<4)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if((t.length-1)%2!=0)return e.error(\"Expected an even number of arguments.\");if(!(i=e.parse(i,2,Dt)))return null;var l=[],c=null;\"interpolate-hcl\"===r||\"interpolate-lab\"===r?c=Bt:e.expectedType&&\"value\"!==e.expectedType.kind&&(c=e.expectedType);for(var u=0;u<a.length;u+=2){var f=a[u],h=a[u+1],p=u+3,d=u+4;if(\"number\"!=typeof f)return e.error('Input/output pairs for \"interpolate\" expressions must be defined using literal numeric values (not computed expressions) for the input values.',p);if(l.length&&l[l.length-1][0]>=f)return e.error('Input/output pairs for \"interpolate\" expressions must be arranged with input values in strictly ascending order.',p);var g=e.parse(h,d,c);if(!g)return null;c=c||g.type,l.push([f,g])}return\"number\"===c.kind||\"color\"===c.kind||\"array\"===c.kind&&\"number\"===c.itemType.kind&&\"number\"==typeof c.N?new rr(c,r,n,i,l):e.error(\"Type \"+Gt(c)+\" is not interpolatable.\")},rr.prototype.evaluate=function(t){var e=this.labels,r=this.outputs;if(1===e.length)return r[0].evaluate(t);var n=this.input.evaluate(t);if(n<=e[0])return r[0].evaluate(t);var i=e.length;if(n>=e[i-1])return r[i-1].evaluate(t);var a=Ne(e,n),o=rr.interpolationFactor(this.interpolation,n,e[a],e[a+1]),s=r[a].evaluate(t),l=r[a+1].evaluate(t);return\"interpolate\"===this.operator?Ve[this.type.kind.toLowerCase()](s,l,o):\"interpolate-hcl\"===this.operator?tr.reverse(tr.interpolate(tr.forward(s),tr.forward(l),o)):$e.reverse($e.interpolate($e.forward(s),$e.forward(l),o))},rr.prototype.eachChild=function(t){t(this.input);for(var e=0,r=this.outputs;e<r.length;e+=1)t(r[e])},rr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))},rr.prototype.serialize=function(){var t;t=\"linear\"===this.interpolation.name?[\"linear\"]:\"exponential\"===this.interpolation.name?1===this.interpolation.base?[\"linear\"]:[\"exponential\",this.interpolation.base]:[\"cubic-bezier\"].concat(this.interpolation.controlPoints);for(var e=[this.operator,t,this.input.serialize()],r=0;r<this.labels.length;r++)e.push(this.labels[r],this.outputs[r].serialize());return e};var ir=function(t,e){this.type=t,this.args=e};ir.parse=function(t,e){if(t.length<2)return e.error(\"Expectected at least one argument.\");var r=null,n=e.expectedType;n&&\"value\"!==n.kind&&(r=n);for(var i=[],a=0,o=t.slice(1);a<o.length;a+=1){var s=e.parse(o[a],1+i.length,r,void 0,{typeAnnotation:\"omit\"});if(!s)return null;r=r||s.type,i.push(s)}var l=n&&i.some((function(t){return Wt(n,t.type)}));return new ir(l?jt:r,i)},ir.prototype.evaluate=function(t){for(var e,r=null,n=0,i=0,a=this.args;i<a.length&&(n++,(r=a[i].evaluate(t))&&r instanceof ee&&!r.available&&(e||(e=r.name),r=null,n===this.args.length&&(r=e)),null===r);i+=1);return r},ir.prototype.eachChild=function(t){this.args.forEach(t)},ir.prototype.outputDefined=function(){return this.args.every((function(t){return t.outputDefined()}))},ir.prototype.serialize=function(){var t=[\"coalesce\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var ar=function(t,e){this.type=e.type,this.bindings=[].concat(t),this.result=e};ar.prototype.evaluate=function(t){return this.result.evaluate(t)},ar.prototype.eachChild=function(t){for(var e=0,r=this.bindings;e<r.length;e+=1)t(r[e][1]);t(this.result)},ar.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found \"+(t.length-1)+\" instead.\");for(var r=[],n=1;n<t.length-1;n+=2){var i=t[n];if(\"string\"!=typeof i)return e.error(\"Expected string, but found \"+typeof i+\" instead.\",n);if(/[^a-zA-Z0-9_]/.test(i))return e.error(\"Variable names must contain only alphanumeric characters or '_'.\",n);var a=e.parse(t[n+1],n+1);if(!a)return null;r.push([i,a])}var o=e.parse(t[t.length-1],t.length-1,e.expectedType,r);return o?new ar(r,o):null},ar.prototype.outputDefined=function(){return this.result.outputDefined()},ar.prototype.serialize=function(){for(var t=[\"let\"],e=0,r=this.bindings;e<r.length;e+=1){var n=r[e];t.push(n[0],n[1].serialize())}return t.push(this.result.serialize()),t};var or=function(t,e,r){this.type=t,this.index=e,this.input=r};or.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,Dt),n=e.parse(t[2],2,Ht(e.expectedType||jt));return r&&n?new or(n.type.itemType,r,n):null},or.prototype.evaluate=function(t){var e=this.index.evaluate(t),r=this.input.evaluate(t);if(e<0)throw new se(\"Array index out of bounds: \"+e+\" < 0.\");if(e>=r.length)throw new se(\"Array index out of bounds: \"+e+\" > \"+(r.length-1)+\".\");if(e!==Math.floor(e))throw new se(\"Array index must be an integer, but found \"+e+\" instead.\");return r[e]},or.prototype.eachChild=function(t){t(this.index),t(this.input)},or.prototype.outputDefined=function(){return!1},or.prototype.serialize=function(){return[\"at\",this.index.serialize(),this.input.serialize()]};var sr=function(t,e){this.type=Ft,this.needle=t,this.haystack=e};sr.parse=function(t,e){if(3!==t.length)return e.error(\"Expected 2 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);return r&&n?Xt(r.type,[Ft,Rt,Dt,Ot,jt])?new sr(r,n):e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\"):null},sr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!r)return!1;if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");return r.indexOf(e)>=0},sr.prototype.eachChild=function(t){t(this.needle),t(this.haystack)},sr.prototype.outputDefined=function(){return!0},sr.prototype.serialize=function(){return[\"in\",this.needle.serialize(),this.haystack.serialize()]};var lr=function(t,e,r){this.type=Dt,this.needle=t,this.haystack=e,this.fromIndex=r};lr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,jt);if(!r||!n)return null;if(!Xt(r.type,[Ft,Rt,Dt,Ot,jt]))return e.error(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new lr(r,n,i):null}return new lr(r,n)},lr.prototype.evaluate=function(t){var e=this.needle.evaluate(t),r=this.haystack.evaluate(t);if(!Zt(e,[\"boolean\",\"string\",\"number\",\"null\"]))throw new se(\"Expected first argument to be of type boolean, string, number or null, but found \"+Gt(ie(e))+\" instead.\");if(!Zt(r,[\"string\",\"array\"]))throw new se(\"Expected second argument to be of type array or string, but found \"+Gt(ie(r))+\" instead.\");if(this.fromIndex){var n=this.fromIndex.evaluate(t);return r.indexOf(e,n)}return r.indexOf(e)},lr.prototype.eachChild=function(t){t(this.needle),t(this.haystack),this.fromIndex&&t(this.fromIndex)},lr.prototype.outputDefined=function(){return!1},lr.prototype.serialize=function(){if(null!=this.fromIndex&&void 0!==this.fromIndex){var t=this.fromIndex.serialize();return[\"index-of\",this.needle.serialize(),this.haystack.serialize(),t]}return[\"index-of\",this.needle.serialize(),this.haystack.serialize()]};var cr=function(t,e,r,n,i,a){this.inputType=t,this.type=e,this.input=r,this.cases=n,this.outputs=i,this.otherwise=a};cr.parse=function(t,e){if(t.length<5)return e.error(\"Expected at least 4 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=1)return e.error(\"Expected an even number of arguments.\");var r,n;e.expectedType&&\"value\"!==e.expectedType.kind&&(n=e.expectedType);for(var i={},a=[],o=2;o<t.length-1;o+=2){var s=t[o],l=t[o+1];Array.isArray(s)||(s=[s]);var c=e.concat(o);if(0===s.length)return c.error(\"Expected at least one branch label.\");for(var u=0,f=s;u<f.length;u+=1){var h=f[u];if(\"number\"!=typeof h&&\"string\"!=typeof h)return c.error(\"Branch labels must be numbers or strings.\");if(\"number\"==typeof h&&Math.abs(h)>Number.MAX_SAFE_INTEGER)return c.error(\"Branch labels must be integers no larger than \"+Number.MAX_SAFE_INTEGER+\".\");if(\"number\"==typeof h&&Math.floor(h)!==h)return c.error(\"Numeric branch labels must be integer values.\");if(r){if(c.checkSubtype(r,ie(h)))return null}else r=ie(h);if(void 0!==i[String(h)])return c.error(\"Branch labels must be unique.\");i[String(h)]=a.length}var p=e.parse(l,o,n);if(!p)return null;n=n||p.type,a.push(p)}var d=e.parse(t[1],1,jt);if(!d)return null;var g=e.parse(t[t.length-1],t.length-1,n);return g?\"value\"!==d.type.kind&&e.concat(1).checkSubtype(r,d.type)?null:new cr(r,n,d,i,a,g):null},cr.prototype.evaluate=function(t){var e=this.input.evaluate(t);return(ie(e)===this.inputType&&this.outputs[this.cases[e]]||this.otherwise).evaluate(t)},cr.prototype.eachChild=function(t){t(this.input),this.outputs.forEach(t),t(this.otherwise)},cr.prototype.outputDefined=function(){return this.outputs.every((function(t){return t.outputDefined()}))&&this.otherwise.outputDefined()},cr.prototype.serialize=function(){for(var t=this,e=[\"match\",this.input.serialize()],r=[],n={},i=0,a=Object.keys(this.cases).sort();i<a.length;i+=1){var o=a[i];void 0===(f=n[this.cases[o]])?(n[this.cases[o]]=r.length,r.push([this.cases[o],[o]])):r[f][1].push(o)}for(var s=function(e){return\"number\"===t.inputType.kind?Number(e):e},l=0,c=r;l<c.length;l+=1){var u=c[l],f=u[0],h=u[1];e.push(1===h.length?s(h[0]):h.map(s)),e.push(this.outputs[outputIndex$1].serialize())}return e.push(this.otherwise.serialize()),e};var ur=function(t,e,r){this.type=t,this.branches=e,this.otherwise=r};ur.parse=function(t,e){if(t.length<4)return e.error(\"Expected at least 3 arguments, but found only \"+(t.length-1)+\".\");if(t.length%2!=0)return e.error(\"Expected an odd number of arguments.\");var r;e.expectedType&&\"value\"!==e.expectedType.kind&&(r=e.expectedType);for(var n=[],i=1;i<t.length-1;i+=2){var a=e.parse(t[i],i,Ft);if(!a)return null;var o=e.parse(t[i+1],i+1,r);if(!o)return null;n.push([a,o]),r=r||o.type}var s=e.parse(t[t.length-1],t.length-1,r);return s?new ur(r,n,s):null},ur.prototype.evaluate=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];if(n[0].evaluate(t))return i.evaluate(t)}return this.otherwise.evaluate(t)},ur.prototype.eachChild=function(t){for(var e=0,r=this.branches;e<r.length;e+=1){var n=r[e],i=n[1];t(n[0]),t(i)}t(this.otherwise)},ur.prototype.outputDefined=function(){return this.branches.every((function(t){return t[1].outputDefined()}))&&this.otherwise.outputDefined()},ur.prototype.serialize=function(){var t=[\"case\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var fr=function(t,e,r,n){this.type=t,this.input=e,this.beginIndex=r,this.endIndex=n};function hr(t,e){return\"==\"===t||\"!=\"===t?\"boolean\"===e.kind||\"string\"===e.kind||\"number\"===e.kind||\"null\"===e.kind||\"value\"===e.kind:\"string\"===e.kind||\"number\"===e.kind||\"value\"===e.kind}function pr(t,e,r,n){return 0===n.compare(e,r)}function dr(t,e,r){var n=\"==\"!==t&&\"!=\"!==t;return function(){function i(t,e,r){this.type=Ft,this.lhs=t,this.rhs=e,this.collator=r,this.hasUntypedArgument=\"value\"===t.type.kind||\"value\"===e.type.kind}return i.parse=function(t,e){if(3!==t.length&&4!==t.length)return e.error(\"Expected two or three arguments.\");var r=t[0],a=e.parse(t[1],1,jt);if(!a)return null;if(!hr(r,a.type))return e.concat(1).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(a.type)+\"'.\");var o=e.parse(t[2],2,jt);if(!o)return null;if(!hr(r,o.type))return e.concat(2).error('\"'+r+\"\\\" comparisons are not supported for type '\"+Gt(o.type)+\"'.\");if(a.type.kind!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot compare types '\"+Gt(a.type)+\"' and '\"+Gt(o.type)+\"'.\");n&&(\"value\"===a.type.kind&&\"value\"!==o.type.kind?a=new ce(o.type,[a]):\"value\"!==a.type.kind&&\"value\"===o.type.kind&&(o=new ce(a.type,[o])));var s=null;if(4===t.length){if(\"string\"!==a.type.kind&&\"string\"!==o.type.kind&&\"value\"!==a.type.kind&&\"value\"!==o.type.kind)return e.error(\"Cannot use collator to compare non-string types.\");if(!(s=e.parse(t[3],3,Ut)))return null}return new i(a,o,s)},i.prototype.evaluate=function(i){var a=this.lhs.evaluate(i),o=this.rhs.evaluate(i);if(n&&this.hasUntypedArgument){var s=ie(a),l=ie(o);if(s.kind!==l.kind||\"string\"!==s.kind&&\"number\"!==s.kind)throw new se('Expected arguments for \"'+t+'\" to be (string, string) or (number, number), but found ('+s.kind+\", \"+l.kind+\") instead.\")}if(this.collator&&!n&&this.hasUntypedArgument){var c=ie(a),u=ie(o);if(\"string\"!==c.kind||\"string\"!==u.kind)return e(i,a,o)}return this.collator?r(i,a,o,this.collator.evaluate(i)):e(i,a,o)},i.prototype.eachChild=function(t){t(this.lhs),t(this.rhs),this.collator&&t(this.collator)},i.prototype.outputDefined=function(){return!0},i.prototype.serialize=function(){var e=[t];return this.eachChild((function(t){e.push(t.serialize())})),e},i}()}fr.parse=function(t,e){if(t.length<=2||t.length>=5)return e.error(\"Expected 3 or 4 arguments, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1,jt),n=e.parse(t[2],2,Dt);if(!r||!n)return null;if(!Xt(r.type,[Ht(jt),Rt,jt]))return e.error(\"Expected first argument to be of type array or string, but found \"+Gt(r.type)+\" instead\");if(4===t.length){var i=e.parse(t[3],3,Dt);return i?new fr(r.type,r,n,i):null}return new fr(r.type,r,n)},fr.prototype.evaluate=function(t){var e=this.input.evaluate(t),r=this.beginIndex.evaluate(t);if(!Zt(e,[\"string\",\"array\"]))throw new se(\"Expected first argument to be of type array or string, but found \"+Gt(ie(e))+\" instead.\");if(this.endIndex){var n=this.endIndex.evaluate(t);return e.slice(r,n)}return e.slice(r)},fr.prototype.eachChild=function(t){t(this.input),t(this.beginIndex),this.endIndex&&t(this.endIndex)},fr.prototype.outputDefined=function(){return!1},fr.prototype.serialize=function(){if(null!=this.endIndex&&void 0!==this.endIndex){var t=this.endIndex.serialize();return[\"slice\",this.input.serialize(),this.beginIndex.serialize(),t]}return[\"slice\",this.input.serialize(),this.beginIndex.serialize()]};var gr=dr(\"==\",(function(t,e,r){return e===r}),pr),mr=dr(\"!=\",(function(t,e,r){return e!==r}),(function(t,e,r,n){return!pr(0,e,r,n)})),vr=dr(\"<\",(function(t,e,r){return e<r}),(function(t,e,r,n){return n.compare(e,r)<0})),yr=dr(\">\",(function(t,e,r){return e>r}),(function(t,e,r,n){return n.compare(e,r)>0})),xr=dr(\"<=\",(function(t,e,r){return e<=r}),(function(t,e,r,n){return n.compare(e,r)<=0})),br=dr(\">=\",(function(t,e,r){return e>=r}),(function(t,e,r,n){return n.compare(e,r)>=0})),_r=function(t,e,r,n,i){this.type=Rt,this.number=t,this.locale=e,this.currency=r,this.minFractionDigits=n,this.maxFractionDigits=i};_r.parse=function(t,e){if(3!==t.length)return e.error(\"Expected two arguments.\");var r=e.parse(t[1],1,Dt);if(!r)return null;var n=t[2];if(\"object\"!=typeof n||Array.isArray(n))return e.error(\"NumberFormat options argument must be an object.\");var i=null;if(n.locale&&!(i=e.parse(n.locale,1,Rt)))return null;var a=null;if(n.currency&&!(a=e.parse(n.currency,1,Rt)))return null;var o=null;if(n[\"min-fraction-digits\"]&&!(o=e.parse(n[\"min-fraction-digits\"],1,Dt)))return null;var s=null;return n[\"max-fraction-digits\"]&&!(s=e.parse(n[\"max-fraction-digits\"],1,Dt))?null:new _r(r,i,a,o,s)},_r.prototype.evaluate=function(t){return new Intl.NumberFormat(this.locale?this.locale.evaluate(t):[],{style:this.currency?\"currency\":\"decimal\",currency:this.currency?this.currency.evaluate(t):void 0,minimumFractionDigits:this.minFractionDigits?this.minFractionDigits.evaluate(t):void 0,maximumFractionDigits:this.maxFractionDigits?this.maxFractionDigits.evaluate(t):void 0}).format(this.number.evaluate(t))},_r.prototype.eachChild=function(t){t(this.number),this.locale&&t(this.locale),this.currency&&t(this.currency),this.minFractionDigits&&t(this.minFractionDigits),this.maxFractionDigits&&t(this.maxFractionDigits)},_r.prototype.outputDefined=function(){return!1},_r.prototype.serialize=function(){var t={};return this.locale&&(t.locale=this.locale.serialize()),this.currency&&(t.currency=this.currency.serialize()),this.minFractionDigits&&(t[\"min-fraction-digits\"]=this.minFractionDigits.serialize()),this.maxFractionDigits&&(t[\"max-fraction-digits\"]=this.maxFractionDigits.serialize()),[\"number-format\",this.number.serialize(),t]};var wr=function(t){this.type=Dt,this.input=t};wr.parse=function(t,e){if(2!==t.length)return e.error(\"Expected 1 argument, but found \"+(t.length-1)+\" instead.\");var r=e.parse(t[1],1);return r?\"array\"!==r.type.kind&&\"string\"!==r.type.kind&&\"value\"!==r.type.kind?e.error(\"Expected argument of type string or array, but found \"+Gt(r.type)+\" instead.\"):new wr(r):null},wr.prototype.evaluate=function(t){var e=this.input.evaluate(t);if(\"string\"==typeof e)return e.length;if(Array.isArray(e))return e.length;throw new se(\"Expected value to be of type string or array, but found \"+Gt(ie(e))+\" instead.\")},wr.prototype.eachChild=function(t){t(this.input)},wr.prototype.outputDefined=function(){return!1},wr.prototype.serialize=function(){var t=[\"length\"];return this.eachChild((function(e){t.push(e.serialize())})),t};var Tr={\"==\":gr,\"!=\":mr,\">\":yr,\"<\":vr,\">=\":br,\"<=\":xr,array:ce,at:or,boolean:ce,case:ur,coalesce:ir,collator:ve,format:ue,image:fe,in:sr,\"index-of\":lr,interpolate:rr,\"interpolate-hcl\":rr,\"interpolate-lab\":rr,length:wr,let:ar,literal:oe,match:cr,number:ce,\"number-format\":_r,object:ce,slice:fr,step:je,string:ce,\"to-boolean\":pe,\"to-color\":pe,\"to-number\":pe,\"to-string\":pe,var:Fe,within:ze};function kr(t,e){var r=e[0],n=e[1],i=e[2],a=e[3];r=r.evaluate(t),n=n.evaluate(t),i=i.evaluate(t);var o=a?a.evaluate(t):1,s=re(r,n,i,o);if(s)throw new se(s);return new Kt(r/255*o,n/255*o,i/255*o,o)}function Mr(t,e){return t in e}function Ar(t,e){var r=e[t];return void 0===r?null:r}function Sr(t){return{type:t}}function Er(t){return{result:\"success\",value:t}}function Cr(t){return{result:\"error\",value:t}}function Lr(t){return\"data-driven\"===t[\"property-type\"]||\"cross-faded-data-driven\"===t[\"property-type\"]}function Ir(t){return!!t.expression&&t.expression.parameters.indexOf(\"zoom\")>-1}function Pr(t){return!!t.expression&&t.expression.interpolated}function zr(t){return t instanceof Number?\"number\":t instanceof String?\"string\":t instanceof Boolean?\"boolean\":Array.isArray(t)?\"array\":null===t?\"null\":typeof t}function Or(t){return\"object\"==typeof t&&null!==t&&!Array.isArray(t)}function Dr(t){return t}function Rr(t,e,r){return void 0!==t?t:void 0!==e?e:void 0!==r?r:void 0}function Fr(t,e,r,n,i){return Rr(typeof r===i?n[r]:void 0,t.default,e.default)}function Br(t,e,r){if(\"number\"!==zr(r))return Rr(t.default,e.default);var n=t.stops.length;if(1===n)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[n-1][0])return t.stops[n-1][1];var i=Ne(t.stops.map((function(t){return t[0]})),r);return t.stops[i][1]}function Nr(t,e,r){var n=void 0!==t.base?t.base:1;if(\"number\"!==zr(r))return Rr(t.default,e.default);var i=t.stops.length;if(1===i)return t.stops[0][1];if(r<=t.stops[0][0])return t.stops[0][1];if(r>=t.stops[i-1][0])return t.stops[i-1][1];var a=Ne(t.stops.map((function(t){return t[0]})),r),o=function(t,e,r,n){var i=n-r,a=t-r;return 0===i?0:1===e?a/i:(Math.pow(e,a)-1)/(Math.pow(e,i)-1)}(r,n,t.stops[a][0],t.stops[a+1][0]),s=t.stops[a][1],l=t.stops[a+1][1],c=Ve[e.type]||Dr;if(t.colorSpace&&\"rgb\"!==t.colorSpace){var u=er[t.colorSpace];c=function(t,e){return u.reverse(u.interpolate(u.forward(t),u.forward(e),o))}}return\"function\"==typeof s.evaluate?{evaluate:function(){for(var t=[],e=arguments.length;e--;)t[e]=arguments[e];var r=s.evaluate.apply(void 0,t),n=l.evaluate.apply(void 0,t);if(void 0!==r&&void 0!==n)return c(r,n,o)}}:c(s,l,o)}function jr(t,e,r){return\"color\"===e.type?r=Kt.parse(r):\"formatted\"===e.type?r=te.fromString(r.toString()):\"resolvedImage\"===e.type?r=ee.fromString(r.toString()):zr(r)===e.type||\"enum\"===e.type&&e.values[r]||(r=void 0),Rr(r,t.default,e.default)}me.register(Tr,{error:[{kind:\"error\"},[Rt],function(t,e){throw new se(e[0].evaluate(t))}],typeof:[Rt,[jt],function(t,e){return Gt(ie(e[0].evaluate(t)))}],\"to-rgba\":[Ht(Dt,4),[Bt],function(t,e){return e[0].evaluate(t).toArray()}],rgb:[Bt,[Dt,Dt,Dt],kr],rgba:[Bt,[Dt,Dt,Dt,Dt],kr],has:{type:Ft,overloads:[[[Rt],function(t,e){return Mr(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Mr(e[0].evaluate(t),r.evaluate(t))}]]},get:{type:jt,overloads:[[[Rt],function(t,e){return Ar(e[0].evaluate(t),t.properties())}],[[Rt,Nt],function(t,e){var r=e[1];return Ar(e[0].evaluate(t),r.evaluate(t))}]]},\"feature-state\":[jt,[Rt],function(t,e){return Ar(e[0].evaluate(t),t.featureState||{})}],properties:[Nt,[],function(t){return t.properties()}],\"geometry-type\":[Rt,[],function(t){return t.geometryType()}],id:[jt,[],function(t){return t.id()}],zoom:[Dt,[],function(t){return t.globals.zoom}],\"heatmap-density\":[Dt,[],function(t){return t.globals.heatmapDensity||0}],\"line-progress\":[Dt,[],function(t){return t.globals.lineProgress||0}],accumulated:[jt,[],function(t){return void 0===t.globals.accumulated?null:t.globals.accumulated}],\"+\":[Dt,Sr(Dt),function(t,e){for(var r=0,n=0,i=e;n<i.length;n+=1)r+=i[n].evaluate(t);return r}],\"*\":[Dt,Sr(Dt),function(t,e){for(var r=1,n=0,i=e;n<i.length;n+=1)r*=i[n].evaluate(t);return r}],\"-\":{type:Dt,overloads:[[[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)-r.evaluate(t)}],[[Dt],function(t,e){return-e[0].evaluate(t)}]]},\"/\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)/r.evaluate(t)}],\"%\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return e[0].evaluate(t)%r.evaluate(t)}],ln2:[Dt,[],function(){return Math.LN2}],pi:[Dt,[],function(){return Math.PI}],e:[Dt,[],function(){return Math.E}],\"^\":[Dt,[Dt,Dt],function(t,e){var r=e[1];return Math.pow(e[0].evaluate(t),r.evaluate(t))}],sqrt:[Dt,[Dt],function(t,e){return Math.sqrt(e[0].evaluate(t))}],log10:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN10}],ln:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))}],log2:[Dt,[Dt],function(t,e){return Math.log(e[0].evaluate(t))/Math.LN2}],sin:[Dt,[Dt],function(t,e){return Math.sin(e[0].evaluate(t))}],cos:[Dt,[Dt],function(t,e){return Math.cos(e[0].evaluate(t))}],tan:[Dt,[Dt],function(t,e){return Math.tan(e[0].evaluate(t))}],asin:[Dt,[Dt],function(t,e){return Math.asin(e[0].evaluate(t))}],acos:[Dt,[Dt],function(t,e){return Math.acos(e[0].evaluate(t))}],atan:[Dt,[Dt],function(t,e){return Math.atan(e[0].evaluate(t))}],min:[Dt,Sr(Dt),function(t,e){return Math.min.apply(Math,e.map((function(e){return e.evaluate(t)})))}],max:[Dt,Sr(Dt),function(t,e){return Math.max.apply(Math,e.map((function(e){return e.evaluate(t)})))}],abs:[Dt,[Dt],function(t,e){return Math.abs(e[0].evaluate(t))}],round:[Dt,[Dt],function(t,e){var r=e[0].evaluate(t);return r<0?-Math.round(-r):Math.round(r)}],floor:[Dt,[Dt],function(t,e){return Math.floor(e[0].evaluate(t))}],ceil:[Dt,[Dt],function(t,e){return Math.ceil(e[0].evaluate(t))}],\"filter-==\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1];return t.properties()[r.value]===n.value}],\"filter-id-==\":[Ft,[jt],function(t,e){var r=e[0];return t.id()===r.value}],\"filter-type-==\":[Ft,[Rt],function(t,e){var r=e[0];return t.geometryType()===r.value}],\"filter-<\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<a}],\"filter-id-<\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<i}],\"filter->\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>a}],\"filter-id->\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>i}],\"filter-<=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i<=a}],\"filter-id-<=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n<=i}],\"filter->=\":[Ft,[Rt,jt],function(t,e){var r=e[0],n=e[1],i=t.properties()[r.value],a=n.value;return typeof i==typeof a&&i>=a}],\"filter-id->=\":[Ft,[jt],function(t,e){var r=e[0],n=t.id(),i=r.value;return typeof n==typeof i&&n>=i}],\"filter-has\":[Ft,[jt],function(t,e){return e[0].value in t.properties()}],\"filter-has-id\":[Ft,[],function(t){return null!==t.id()&&void 0!==t.id()}],\"filter-type-in\":[Ft,[Ht(Rt)],function(t,e){return e[0].value.indexOf(t.geometryType())>=0}],\"filter-id-in\":[Ft,[Ht(jt)],function(t,e){return e[0].value.indexOf(t.id())>=0}],\"filter-in-small\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0];return e[1].value.indexOf(t.properties()[r.value])>=0}],\"filter-in-large\":[Ft,[Rt,Ht(jt)],function(t,e){var r=e[0],n=e[1];return function(t,e,r,n){for(;r<=n;){var i=r+n>>1;if(e[i]===t)return!0;e[i]>t?n=i-1:r=i+1}return!1}(t.properties()[r.value],n.value,0,n.value.length-1)}],all:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)&&r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(!n[r].evaluate(t))return!1;return!0}]]},any:{type:Ft,overloads:[[[Ft,Ft],function(t,e){var r=e[1];return e[0].evaluate(t)||r.evaluate(t)}],[Sr(Ft),function(t,e){for(var r=0,n=e;r<n.length;r+=1)if(n[r].evaluate(t))return!0;return!1}]]},\"!\":[Ft,[Ft],function(t,e){return!e[0].evaluate(t)}],\"is-supported-script\":[Ft,[Rt],function(t,e){var r=t.globals&&t.globals.isSupportedScript;return!r||r(e[0].evaluate(t))}],upcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toUpperCase()}],downcase:[Rt,[Rt],function(t,e){return e[0].evaluate(t).toLowerCase()}],concat:[Rt,Sr(jt),function(t,e){return e.map((function(e){return ae(e.evaluate(t))})).join(\"\")}],\"resolved-locale\":[Rt,[Ut],function(t,e){return e[0].evaluate(t).resolvedLocale()}]});var Ur=function(t,e){this.expression=t,this._warningHistory={},this._evaluator=new ge,this._defaultValue=e?function(t){return\"color\"===t.type&&Or(t.default)?new Kt(0,0,0,0):\"color\"===t.type?Kt.parse(t.default)||null:void 0===t.default?null:t.default}(e):null,this._enumValues=e&&\"enum\"===e.type?e.values:null};function Vr(t){return Array.isArray(t)&&t.length>0&&\"string\"==typeof t[0]&&t[0]in Tr}function qr(t,e){var r=new Be(Tr,[],e?function(t){var e={color:Bt,string:Rt,number:Dt,enum:Rt,boolean:Ft,formatted:Vt,resolvedImage:qt};return\"array\"===t.type?Ht(e[t.value]||jt,t.length):e[t.type]}(e):void 0),n=r.parse(t,void 0,void 0,void 0,e&&\"string\"===e.type?{typeAnnotation:\"coerce\"}:void 0);return n?Er(new Ur(n,e)):Cr(r.errors)}Ur.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._evaluator.globals=t,this._evaluator.feature=e,this._evaluator.featureState=r,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a,this.expression.evaluate(this._evaluator)},Ur.prototype.evaluate=function(t,e,r,n,i,a){this._evaluator.globals=t,this._evaluator.feature=e||null,this._evaluator.featureState=r||null,this._evaluator.canonical=n,this._evaluator.availableImages=i||null,this._evaluator.formattedSection=a||null;try{var o=this.expression.evaluate(this._evaluator);if(null==o||\"number\"==typeof o&&o!=o)return this._defaultValue;if(this._enumValues&&!(o in this._enumValues))throw new se(\"Expected value to be one of \"+Object.keys(this._enumValues).map((function(t){return JSON.stringify(t)})).join(\", \")+\", but found \"+JSON.stringify(o)+\" instead.\");return o}catch(t){return this._warningHistory[t.message]||(this._warningHistory[t.message]=!0,\"undefined\"!=typeof console&&console.warn(t.message)),this._defaultValue}};var Hr=function(t,e){this.kind=t,this._styleExpression=e,this.isStateDependent=\"constant\"!==t&&!De(e.expression)};Hr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Hr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)};var Gr=function(t,e,r,n){this.kind=t,this.zoomStops=r,this._styleExpression=e,this.isStateDependent=\"camera\"!==t&&!De(e.expression),this.interpolationType=n};function Yr(t,e){if(\"error\"===(t=qr(t,e)).result)return t;var r=t.value.expression,n=Oe(r);if(!n&&!Lr(e))return Cr([new Pt(\"\",\"data expressions not supported\")]);var i=Re(r,[\"zoom\"]);if(!i&&!Ir(e))return Cr([new Pt(\"\",\"zoom expressions not supported\")]);var a=function t(e){var r=null;if(e instanceof ar)r=t(e.result);else if(e instanceof ir)for(var n=0,i=e.args;n<i.length&&!(r=t(i[n]));n+=1);else(e instanceof je||e instanceof rr)&&e.input instanceof me&&\"zoom\"===e.input.name&&(r=e);return r instanceof Pt||e.eachChild((function(e){var n=t(e);n instanceof Pt?r=n:!r&&n?r=new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.'):r&&n&&r!==n&&(r=new Pt(\"\",'Only one zoom-based \"step\" or \"interpolate\" subexpression may be used in an expression.'))})),r}(r);return a||i?a instanceof Pt?Cr([a]):a instanceof rr&&!Pr(e)?Cr([new Pt(\"\",'\"interpolate\" expressions cannot be used with this property')]):Er(a?new Gr(n?\"camera\":\"composite\",t.value,a.labels,a instanceof rr?a.interpolation:void 0):new Hr(n?\"constant\":\"source\",t.value)):Cr([new Pt(\"\",'\"zoom\" expression may only be used as input to a top-level \"step\" or \"interpolate\" expression.')])}Gr.prototype.evaluateWithoutErrorHandling=function(t,e,r,n,i,a){return this._styleExpression.evaluateWithoutErrorHandling(t,e,r,n,i,a)},Gr.prototype.evaluate=function(t,e,r,n,i,a){return this._styleExpression.evaluate(t,e,r,n,i,a)},Gr.prototype.interpolationFactor=function(t,e,r){return this.interpolationType?rr.interpolationFactor(this.interpolationType,t,e,r):0};var Wr=function(t,e){this._parameters=t,this._specification=e,Ct(this,function t(e,r){var n,i,a,o=\"color\"===r.type,s=e.stops&&\"object\"==typeof e.stops[0][0],l=s||!(s||void 0!==e.property),c=e.type||(Pr(r)?\"exponential\":\"interval\");if(o&&((e=Ct({},e)).stops&&(e.stops=e.stops.map((function(t){return[t[0],Kt.parse(t[1])]}))),e.default=Kt.parse(e.default?e.default:r.default)),e.colorSpace&&\"rgb\"!==e.colorSpace&&!er[e.colorSpace])throw new Error(\"Unknown color space: \"+e.colorSpace);if(\"exponential\"===c)n=Nr;else if(\"interval\"===c)n=Br;else if(\"categorical\"===c){n=Fr,i=Object.create(null);for(var u=0,f=e.stops;u<f.length;u+=1){var h=f[u];i[h[0]]=h[1]}a=typeof e.stops[0][0]}else{if(\"identity\"!==c)throw new Error('Unknown function type \"'+c+'\"');n=jr}if(s){for(var p={},d=[],g=0;g<e.stops.length;g++){var m=e.stops[g],v=m[0].zoom;void 0===p[v]&&(p[v]={zoom:v,type:e.type,property:e.property,default:e.default,stops:[]},d.push(v)),p[v].stops.push([m[0].value,m[1]])}for(var y=[],x=0,b=d;x<b.length;x+=1){var _=b[x];y.push([p[_].zoom,t(p[_],r)])}var w={name:\"linear\"};return{kind:\"composite\",interpolationType:w,interpolationFactor:rr.interpolationFactor.bind(void 0,w),zoomStops:y.map((function(t){return t[0]})),evaluate:function(t,n){var i=t.zoom;return Nr({stops:y,base:e.base},r,i).evaluate(i,n)}}}if(l){var T=\"exponential\"===c?{name:\"exponential\",base:void 0!==e.base?e.base:1}:null;return{kind:\"camera\",interpolationType:T,interpolationFactor:rr.interpolationFactor.bind(void 0,T),zoomStops:e.stops.map((function(t){return t[0]})),evaluate:function(t){return n(e,r,t.zoom,i,a)}}}return{kind:\"source\",evaluate:function(t,o){var s=o&&o.properties?o.properties[e.property]:void 0;return void 0===s?Rr(e.default,r.default):n(e,r,s,i,a)}}}(this._parameters,this._specification))};function Xr(t){var e=t.key,r=t.value,n=t.valueSpec||{},i=t.objectElementValidators||{},a=t.style,o=t.styleSpec,s=[],l=zr(r);if(\"object\"!==l)return[new St(e,r,\"object expected, \"+l+\" found\")];for(var c in r){var u=c.split(\".\")[0],f=n[u]||n[\"*\"],h=void 0;if(i[u])h=i[u];else if(n[u])h=bn;else if(i[\"*\"])h=i[\"*\"];else{if(!n[\"*\"]){s.push(new St(e,r[c],'unknown property \"'+c+'\"'));continue}h=bn}s=s.concat(h({key:(e?e+\".\":e)+c,value:r[c],valueSpec:f,style:a,styleSpec:o,object:r,objectKey:c},r))}for(var p in n)i[p]||n[p].required&&void 0===n[p].default&&void 0===r[p]&&s.push(new St(e,r,'missing required property \"'+p+'\"'));return s}function Zr(t){var e=t.value,r=t.valueSpec,n=t.style,i=t.styleSpec,a=t.key,o=t.arrayElementValidator||bn;if(\"array\"!==zr(e))return[new St(a,e,\"array expected, \"+zr(e)+\" found\")];if(r.length&&e.length!==r.length)return[new St(a,e,\"array length \"+r.length+\" expected, length \"+e.length+\" found\")];if(r[\"min-length\"]&&e.length<r[\"min-length\"])return[new St(a,e,\"array length at least \"+r[\"min-length\"]+\" expected, length \"+e.length+\" found\")];var s={type:r.value,values:r.values};i.$version<7&&(s.function=r.function),\"object\"===zr(r.value)&&(s=r.value);for(var l=[],c=0;c<e.length;c++)l=l.concat(o({array:e,arrayIndex:c,value:e[c],valueSpec:s,style:n,styleSpec:i,key:a+\"[\"+c+\"]\"}));return l}function Jr(t){var e=t.key,r=t.value,n=t.valueSpec,i=zr(r);return\"number\"===i&&r!=r&&(i=\"NaN\"),\"number\"!==i?[new St(e,r,\"number expected, \"+i+\" found\")]:\"minimum\"in n&&r<n.minimum?[new St(e,r,r+\" is less than the minimum value \"+n.minimum)]:\"maximum\"in n&&r>n.maximum?[new St(e,r,r+\" is greater than the maximum value \"+n.maximum)]:[]}function Kr(t){var e,r,n,i=t.valueSpec,a=Lt(t.value.type),o={},s=\"categorical\"!==a&&void 0===t.value.property,l=!s,c=\"array\"===zr(t.value.stops)&&\"array\"===zr(t.value.stops[0])&&\"object\"===zr(t.value.stops[0][0]),u=Xr({key:t.key,value:t.value,valueSpec:t.styleSpec.function,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{stops:function(t){if(\"identity\"===a)return[new St(t.key,t.value,'identity function may not have a \"stops\" property')];var e=[],r=t.value;return e=e.concat(Zr({key:t.key,value:r,valueSpec:t.valueSpec,style:t.style,styleSpec:t.styleSpec,arrayElementValidator:f})),\"array\"===zr(r)&&0===r.length&&e.push(new St(t.key,r,\"array must have at least one stop\")),e},default:function(t){return bn({key:t.key,value:t.value,valueSpec:i,style:t.style,styleSpec:t.styleSpec})}}});return\"identity\"===a&&s&&u.push(new St(t.key,t.value,'missing required property \"property\"')),\"identity\"===a||t.value.stops||u.push(new St(t.key,t.value,'missing required property \"stops\"')),\"exponential\"===a&&t.valueSpec.expression&&!Pr(t.valueSpec)&&u.push(new St(t.key,t.value,\"exponential functions not supported\")),t.styleSpec.$version>=8&&(l&&!Lr(t.valueSpec)?u.push(new St(t.key,t.value,\"property functions not supported\")):s&&!Ir(t.valueSpec)&&u.push(new St(t.key,t.value,\"zoom functions not supported\"))),\"categorical\"!==a&&!c||void 0!==t.value.property||u.push(new St(t.key,t.value,'\"property\" property is required')),u;function f(t){var e=[],a=t.value,s=t.key;if(\"array\"!==zr(a))return[new St(s,a,\"array expected, \"+zr(a)+\" found\")];if(2!==a.length)return[new St(s,a,\"array length 2 expected, length \"+a.length+\" found\")];if(c){if(\"object\"!==zr(a[0]))return[new St(s,a,\"object expected, \"+zr(a[0])+\" found\")];if(void 0===a[0].zoom)return[new St(s,a,\"object stop key must have zoom\")];if(void 0===a[0].value)return[new St(s,a,\"object stop key must have value\")];if(n&&n>Lt(a[0].zoom))return[new St(s,a[0].zoom,\"stop zoom values must appear in ascending order\")];Lt(a[0].zoom)!==n&&(n=Lt(a[0].zoom),r=void 0,o={}),e=e.concat(Xr({key:s+\"[0]\",value:a[0],valueSpec:{zoom:{}},style:t.style,styleSpec:t.styleSpec,objectElementValidators:{zoom:Jr,value:h}}))}else e=e.concat(h({key:s+\"[0]\",value:a[0],valueSpec:{},style:t.style,styleSpec:t.styleSpec},a));return Vr(It(a[1]))?e.concat([new St(s+\"[1]\",a[1],\"expressions are not allowed in function stops.\")]):e.concat(bn({key:s+\"[1]\",value:a[1],valueSpec:i,style:t.style,styleSpec:t.styleSpec}))}function h(t,n){var s=zr(t.value),l=Lt(t.value),c=null!==t.value?t.value:n;if(e){if(s!==e)return[new St(t.key,c,s+\" stop domain type must match previous stop domain type \"+e)]}else e=s;if(\"number\"!==s&&\"string\"!==s&&\"boolean\"!==s)return[new St(t.key,c,\"stop domain value must be a number, string, or boolean\")];if(\"number\"!==s&&\"categorical\"!==a){var u=\"number expected, \"+s+\" found\";return Lr(i)&&void 0===a&&(u+='\\nIf you intended to use a categorical function, specify `\"type\": \"categorical\"`.'),[new St(t.key,c,u)]}return\"categorical\"!==a||\"number\"!==s||isFinite(l)&&Math.floor(l)===l?\"categorical\"!==a&&\"number\"===s&&void 0!==r&&l<r?[new St(t.key,c,\"stop domain values must appear in ascending order\")]:(r=l,\"categorical\"===a&&l in o?[new St(t.key,c,\"stop domain values must be unique\")]:(o[l]=!0,[])):[new St(t.key,c,\"integer expected, found \"+l)]}}function Qr(t){var e=(\"property\"===t.expressionContext?Yr:qr)(It(t.value),t.valueSpec);if(\"error\"===e.result)return e.value.map((function(e){return new St(\"\"+t.key+e.key,t.value,e.message)}));var r=e.value.expression||e.value._styleExpression.expression;if(\"property\"===t.expressionContext&&\"text-font\"===t.propertyKey&&!r.outputDefined())return[new St(t.key,t.value,'Invalid data expression for \"'+t.propertyKey+'\". Output values must be contained as literals within the expression.')];if(\"property\"===t.expressionContext&&\"layout\"===t.propertyType&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with layout properties.')];if(\"filter\"===t.expressionContext&&!De(r))return[new St(t.key,t.value,'\"feature-state\" data expressions are not supported with filters.')];if(t.expressionContext&&0===t.expressionContext.indexOf(\"cluster\")){if(!Re(r,[\"zoom\",\"feature-state\"]))return[new St(t.key,t.value,'\"zoom\" and \"feature-state\" expressions are not supported with cluster properties.')];if(\"cluster-initial\"===t.expressionContext&&!Oe(r))return[new St(t.key,t.value,\"Feature data expressions are not supported with initial expression part of cluster properties.\")]}return[]}function $r(t){var e=t.key,r=t.value,n=t.valueSpec,i=[];return Array.isArray(n.values)?-1===n.values.indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+n.values.join(\", \")+\"], \"+JSON.stringify(r)+\" found\")):-1===Object.keys(n.values).indexOf(Lt(r))&&i.push(new St(e,r,\"expected one of [\"+Object.keys(n.values).join(\", \")+\"], \"+JSON.stringify(r)+\" found\")),i}function tn(t){if(!0===t||!1===t)return!0;if(!Array.isArray(t)||0===t.length)return!1;switch(t[0]){case\"has\":return t.length>=2&&\"$id\"!==t[1]&&\"$type\"!==t[1];case\"in\":return t.length>=3&&(\"string\"!=typeof t[1]||Array.isArray(t[2]));case\"!in\":case\"!has\":case\"none\":return!1;case\"==\":case\"!=\":case\">\":case\">=\":case\"<\":case\"<=\":return 3!==t.length||Array.isArray(t[1])||Array.isArray(t[2]);case\"any\":case\"all\":for(var e=0,r=t.slice(1);e<r.length;e+=1){var n=r[e];if(!tn(n)&&\"boolean\"!=typeof n)return!1}return!0;default:return!0}}Wr.deserialize=function(t){return new Wr(t._parameters,t._specification)},Wr.serialize=function(t){return{_parameters:t._parameters,_specification:t._specification}};var en={type:\"boolean\",default:!1,transition:!1,\"property-type\":\"data-driven\",expression:{interpolated:!1,parameters:[\"zoom\",\"feature\"]}};function rn(t){if(null==t)return{filter:function(){return!0},needGeometry:!1};tn(t)||(t=an(t));var e=qr(t,en);if(\"error\"===e.result)throw new Error(e.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return{filter:function(t,r,n){return e.value.evaluate(t,r,{},n)},needGeometry:function t(e){if(!Array.isArray(e))return!1;if(\"within\"===e[0])return!0;for(var r=1;r<e.length;r++)if(t(e[r]))return!0;return!1}(t)}}function nn(t,e){return t<e?-1:t>e?1:0}function an(t){if(!t)return!0;var e,r=t[0];return t.length<=1?\"any\"!==r:\"==\"===r?on(t[1],t[2],\"==\"):\"!=\"===r?cn(on(t[1],t[2],\"==\")):\"<\"===r||\">\"===r||\"<=\"===r||\">=\"===r?on(t[1],t[2],r):\"any\"===r?(e=t.slice(1),[\"any\"].concat(e.map(an))):\"all\"===r?[\"all\"].concat(t.slice(1).map(an)):\"none\"===r?[\"all\"].concat(t.slice(1).map(an).map(cn)):\"in\"===r?sn(t[1],t.slice(2)):\"!in\"===r?cn(sn(t[1],t.slice(2))):\"has\"===r?ln(t[1]):\"!has\"===r?cn(ln(t[1])):\"within\"!==r||t}function on(t,e,r){switch(t){case\"$type\":return[\"filter-type-\"+r,e];case\"$id\":return[\"filter-id-\"+r,e];default:return[\"filter-\"+r,t,e]}}function sn(t,e){if(0===e.length)return!1;switch(t){case\"$type\":return[\"filter-type-in\",[\"literal\",e]];case\"$id\":return[\"filter-id-in\",[\"literal\",e]];default:return e.length>200&&!e.some((function(t){return typeof t!=typeof e[0]}))?[\"filter-in-large\",t,[\"literal\",e.sort(nn)]]:[\"filter-in-small\",t,[\"literal\",e]]}}function ln(t){switch(t){case\"$type\":return!0;case\"$id\":return[\"filter-has-id\"];default:return[\"filter-has\",t]}}function cn(t){return[\"!\",t]}function un(t){return tn(It(t.value))?Qr(Ct({},t,{expressionContext:\"filter\",valueSpec:{value:\"boolean\"}})):function t(e){var r=e.value,n=e.key;if(\"array\"!==zr(r))return[new St(n,r,\"array expected, \"+zr(r)+\" found\")];var i,a=e.styleSpec,o=[];if(r.length<1)return[new St(n,r,\"filter array must have at least 1 element\")];switch(o=o.concat($r({key:n+\"[0]\",value:r[0],valueSpec:a.filter_operator,style:e.style,styleSpec:e.styleSpec})),Lt(r[0])){case\"<\":case\"<=\":case\">\":case\">=\":r.length>=2&&\"$type\"===Lt(r[1])&&o.push(new St(n,r,'\"$type\" cannot be use with operator \"'+r[0]+'\"'));case\"==\":case\"!=\":3!==r.length&&o.push(new St(n,r,'filter array for operator \"'+r[0]+'\" must have 3 elements'));case\"in\":case\"!in\":r.length>=2&&\"string\"!==(i=zr(r[1]))&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));for(var s=2;s<r.length;s++)i=zr(r[s]),\"$type\"===Lt(r[1])?o=o.concat($r({key:n+\"[\"+s+\"]\",value:r[s],valueSpec:a.geometry_type,style:e.style,styleSpec:e.styleSpec})):\"string\"!==i&&\"number\"!==i&&\"boolean\"!==i&&o.push(new St(n+\"[\"+s+\"]\",r[s],\"string, number, or boolean expected, \"+i+\" found\"));break;case\"any\":case\"all\":case\"none\":for(var l=1;l<r.length;l++)o=o.concat(t({key:n+\"[\"+l+\"]\",value:r[l],style:e.style,styleSpec:e.styleSpec}));break;case\"has\":case\"!has\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"string\"!==i&&o.push(new St(n+\"[1]\",r[1],\"string expected, \"+i+\" found\"));break;case\"within\":i=zr(r[1]),2!==r.length?o.push(new St(n,r,'filter array for \"'+r[0]+'\" operator must have 2 elements')):\"object\"!==i&&o.push(new St(n+\"[1]\",r[1],\"object expected, \"+i+\" found\"))}return o}(t)}function fn(t,e){var r=t.key,n=t.style,i=t.styleSpec,a=t.value,o=t.objectKey,s=i[e+\"_\"+t.layerType];if(!s)return[];var l=o.match(/^(.*)-transition$/);if(\"paint\"===e&&l&&s[l[1]]&&s[l[1]].transition)return bn({key:r,value:a,valueSpec:i.transition,style:n,styleSpec:i});var c,u=t.valueSpec||s[o];if(!u)return[new St(r,a,'unknown property \"'+o+'\"')];if(\"string\"===zr(a)&&Lr(u)&&!u.tokens&&(c=/^{([^}]+)}$/.exec(a)))return[new St(r,a,'\"'+o+'\" does not support interpolation syntax\\nUse an identity property function instead: `{ \"type\": \"identity\", \"property\": '+JSON.stringify(c[1])+\" }`.\")];var f=[];return\"symbol\"===t.layerType&&(\"text-field\"===o&&n&&!n.glyphs&&f.push(new St(r,a,'use of \"text-field\" requires a style \"glyphs\" property')),\"text-font\"===o&&Or(It(a))&&\"identity\"===Lt(a.type)&&f.push(new St(r,a,'\"text-font\" does not support identity functions'))),f.concat(bn({key:t.key,value:a,valueSpec:u,style:n,styleSpec:i,expressionContext:\"property\",propertyType:e,propertyKey:o}))}function hn(t){return fn(t,\"paint\")}function pn(t){return fn(t,\"layout\")}function dn(t){var e=[],r=t.value,n=t.key,i=t.style,a=t.styleSpec;r.type||r.ref||e.push(new St(n,r,'either \"type\" or \"ref\" is required'));var o,s=Lt(r.type),l=Lt(r.ref);if(r.id)for(var c=Lt(r.id),u=0;u<t.arrayIndex;u++){var f=i.layers[u];Lt(f.id)===c&&e.push(new St(n,r.id,'duplicate layer id \"'+r.id+'\", previously used at line '+f.id.__line__))}if(\"ref\"in r)[\"type\",\"source\",\"source-layer\",\"filter\",\"layout\"].forEach((function(t){t in r&&e.push(new St(n,r[t],'\"'+t+'\" is prohibited for ref layers'))})),i.layers.forEach((function(t){Lt(t.id)===l&&(o=t)})),o?o.ref?e.push(new St(n,r.ref,\"ref cannot reference another ref layer\")):s=Lt(o.type):e.push(new St(n,r.ref,'ref layer \"'+l+'\" not found'));else if(\"background\"!==s)if(r.source){var h=i.sources&&i.sources[r.source],p=h&&Lt(h.type);h?\"vector\"===p&&\"raster\"===s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a raster source')):\"raster\"===p&&\"raster\"!==s?e.push(new St(n,r.source,'layer \"'+r.id+'\" requires a vector source')):\"vector\"!==p||r[\"source-layer\"]?\"raster-dem\"===p&&\"hillshade\"!==s?e.push(new St(n,r.source,\"raster-dem source can only be used with layer type 'hillshade'.\")):\"line\"!==s||!r.paint||!r.paint[\"line-gradient\"]||\"geojson\"===p&&h.lineMetrics||e.push(new St(n,r,'layer \"'+r.id+'\" specifies a line-gradient, which requires a GeoJSON source with `lineMetrics` enabled.')):e.push(new St(n,r,'layer \"'+r.id+'\" must specify a \"source-layer\"')):e.push(new St(n,r.source,'source \"'+r.source+'\" not found'))}else e.push(new St(n,r,'missing required property \"source\"'));return e=e.concat(Xr({key:n,value:r,valueSpec:a.layer,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(){return[]},type:function(){return bn({key:n+\".type\",value:r.type,valueSpec:a.layer.type,style:t.style,styleSpec:t.styleSpec,object:r,objectKey:\"type\"})},filter:un,layout:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return pn(Ct({layerType:s},t))}}})},paint:function(t){return Xr({layer:r,key:t.key,value:t.value,style:t.style,styleSpec:t.styleSpec,objectElementValidators:{\"*\":function(t){return hn(Ct({layerType:s},t))}}})}}}))}function gn(t){var e=t.value,r=t.key,n=zr(e);return\"string\"!==n?[new St(r,e,\"string expected, \"+n+\" found\")]:[]}var mn={promoteId:function(t){var e=t.key,r=t.value;if(\"string\"===zr(r))return gn({key:e,value:r});var n=[];for(var i in r)n.push.apply(n,gn({key:e+\".\"+i,value:r[i]}));return n}};function vn(t){var e=t.value,r=t.key,n=t.styleSpec,i=t.style;if(!e.type)return[new St(r,e,'\"type\" is required')];var a,o=Lt(e.type);switch(o){case\"vector\":case\"raster\":case\"raster-dem\":return Xr({key:r,value:e,valueSpec:n[\"source_\"+o.replace(\"-\",\"_\")],style:t.style,styleSpec:n,objectElementValidators:mn});case\"geojson\":if(a=Xr({key:r,value:e,valueSpec:n.source_geojson,style:i,styleSpec:n,objectElementValidators:mn}),e.cluster)for(var s in e.clusterProperties){var l=e.clusterProperties[s],c=l[0],u=\"string\"==typeof c?[c,[\"accumulated\"],[\"get\",s]]:c;a.push.apply(a,Qr({key:r+\".\"+s+\".map\",value:l[1],expressionContext:\"cluster-map\"})),a.push.apply(a,Qr({key:r+\".\"+s+\".reduce\",value:u,expressionContext:\"cluster-reduce\"}))}return a;case\"video\":return Xr({key:r,value:e,valueSpec:n.source_video,style:i,styleSpec:n});case\"image\":return Xr({key:r,value:e,valueSpec:n.source_image,style:i,styleSpec:n});case\"canvas\":return[new St(r,null,\"Please use runtime APIs to add canvas sources, rather than including them in stylesheets.\",\"source.canvas\")];default:return $r({key:r+\".type\",value:e.type,valueSpec:{values:[\"vector\",\"raster\",\"raster-dem\",\"geojson\",\"video\",\"image\"]},style:i,styleSpec:n})}}function yn(t){var e=t.value,r=t.styleSpec,n=r.light,i=t.style,a=[],o=zr(e);if(void 0===e)return a;if(\"object\"!==o)return a.concat([new St(\"light\",e,\"object expected, \"+o+\" found\")]);for(var s in e){var l=s.match(/^(.*)-transition$/);a=a.concat(l&&n[l[1]]&&n[l[1]].transition?bn({key:s,value:e[s],valueSpec:r.transition,style:i,styleSpec:r}):n[s]?bn({key:s,value:e[s],valueSpec:n[s],style:i,styleSpec:r}):[new St(s,e[s],'unknown property \"'+s+'\"')])}return a}var xn={\"*\":function(){return[]},array:Zr,boolean:function(t){var e=t.value,r=t.key,n=zr(e);return\"boolean\"!==n?[new St(r,e,\"boolean expected, \"+n+\" found\")]:[]},number:Jr,color:function(t){var e=t.key,r=t.value,n=zr(r);return\"string\"!==n?[new St(e,r,\"color expected, \"+n+\" found\")]:null===Jt(r)?[new St(e,r,'color expected, \"'+r+'\" found')]:[]},constants:Et,enum:$r,filter:un,function:Kr,layer:dn,object:Xr,source:vn,light:yn,string:gn,formatted:function(t){return 0===gn(t).length?[]:Qr(t)},resolvedImage:function(t){return 0===gn(t).length?[]:Qr(t)}};function bn(t){var e=t.value,r=t.valueSpec,n=t.styleSpec;return r.expression&&Or(Lt(e))?Kr(t):r.expression&&Vr(It(e))?Qr(t):r.type&&xn[r.type]?xn[r.type](t):Xr(Ct({},t,{valueSpec:r.type?n[r.type]:r}))}function _n(t){var e=t.value,r=t.key,n=gn(t);return n.length||(-1===e.indexOf(\"{fontstack}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{fontstack}\" token')),-1===e.indexOf(\"{range}\")&&n.push(new St(r,e,'\"glyphs\" url must include a \"{range}\" token'))),n}function wn(t,e){void 0===e&&(e=At);var r=[];return r=r.concat(bn({key:\"\",value:t,valueSpec:e.$root,styleSpec:e,style:t,objectElementValidators:{glyphs:_n,\"*\":function(){return[]}}})),t.constants&&(r=r.concat(Et({key:\"constants\",value:t.constants,style:t,styleSpec:e}))),Tn(r)}function Tn(t){return[].concat(t).sort((function(t,e){return t.line-e.line}))}function kn(t){return function(){for(var e=[],r=arguments.length;r--;)e[r]=arguments[r];return Tn(t.apply(this,e))}}wn.source=kn(vn),wn.light=kn(yn),wn.layer=kn(dn),wn.filter=kn(un),wn.paintProperty=kn(hn),wn.layoutProperty=kn(pn);var Mn=wn,An=Mn.light,Sn=Mn.paintProperty,En=Mn.layoutProperty;function Cn(t,e){var r=!1;if(e&&e.length)for(var n=0,i=e;n<i.length;n+=1)t.fire(new kt(new Error(i[n].message))),r=!0;return r}var Ln=In;function In(t,e,r){var n=this.cells=[];if(t instanceof ArrayBuffer){this.arrayBuffer=t;var i=new Int32Array(this.arrayBuffer);t=i[0],this.d=(e=i[1])+2*(r=i[2]);for(var a=0;a<this.d*this.d;a++){var o=i[3+a],s=i[3+a+1];n.push(o===s?null:i.subarray(o,s))}var l=i[3+n.length+1];this.keys=i.subarray(i[3+n.length],l),this.bboxes=i.subarray(l),this.insert=this._insertReadonly}else{this.d=e+2*r;for(var c=0;c<this.d*this.d;c++)n.push([]);this.keys=[],this.bboxes=[]}this.n=e,this.extent=t,this.padding=r,this.scale=e/t,this.uid=0;var u=r/e*t;this.min=-u,this.max=t+u}In.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertCell,this.uid++),this.keys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},In.prototype._insertReadonly=function(){throw\"Cannot insert into a GridIndex created from an ArrayBuffer.\"},In.prototype._insertCell=function(t,e,r,n,i,a){this.cells[i].push(a)},In.prototype.query=function(t,e,r,n,i){var a=this.min,o=this.max;if(t<=a&&e<=a&&o<=r&&o<=n&&!i)return Array.prototype.slice.call(this.keys);var s=[];return this._forEachCell(t,e,r,n,this._queryCell,s,{},i),s},In.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=this.cells[i];if(null!==l)for(var c=this.keys,u=this.bboxes,f=0;f<l.length;f++){var h=l[f];if(void 0===o[h]){var p=4*h;(s?s(u[p+0],u[p+1],u[p+2],u[p+3]):t<=u[p+2]&&e<=u[p+3]&&r>=u[p+0]&&n>=u[p+1])?(o[h]=!0,a.push(c[h])):o[h]=!1}}},In.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToCellCoord(t),c=this._convertToCellCoord(e),u=this._convertToCellCoord(r),f=this._convertToCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++){var d=this.d*p+h;if((!s||s(this._convertFromCellCoord(h),this._convertFromCellCoord(p),this._convertFromCellCoord(h+1),this._convertFromCellCoord(p+1)))&&i.call(this,t,e,r,n,d,a,o,s))return}},In.prototype._convertFromCellCoord=function(t){return(t-this.padding)/this.scale},In.prototype._convertToCellCoord=function(t){return Math.max(0,Math.min(this.d-1,Math.floor(t*this.scale)+this.padding))},In.prototype.toArrayBuffer=function(){if(this.arrayBuffer)return this.arrayBuffer;for(var t=this.cells,e=3+this.cells.length+1+1,r=0,n=0;n<this.cells.length;n++)r+=this.cells[n].length;var i=new Int32Array(e+r+this.keys.length+this.bboxes.length);i[0]=this.extent,i[1]=this.n,i[2]=this.padding;for(var a=e,o=0;o<t.length;o++){var s=t[o];i[3+o]=a,i.set(s,a),a+=s.length}return i[3+t.length]=a,i.set(this.keys,a),i[3+t.length+1]=a+=this.keys.length,i.set(this.bboxes,a),a+=this.bboxes.length,i.buffer};var Pn=self.ImageData,zn=self.ImageBitmap,On={};function Dn(t,e,r){void 0===r&&(r={}),Object.defineProperty(e,\"_classRegistryKey\",{value:t,writeable:!1}),On[t]={klass:e,omit:r.omit||[],shallow:r.shallow||[]}}for(var Rn in Dn(\"Object\",Object),Ln.serialize=function(t,e){var r=t.toArrayBuffer();return e&&e.push(r),{buffer:r}},Ln.deserialize=function(t){return new Ln(t.buffer)},Dn(\"Grid\",Ln),Dn(\"Color\",Kt),Dn(\"Error\",Error),Dn(\"ResolvedImage\",ee),Dn(\"StylePropertyFunction\",Wr),Dn(\"StyleExpression\",Ur,{omit:[\"_evaluator\"]}),Dn(\"ZoomDependentExpression\",Gr),Dn(\"ZoomConstantExpression\",Hr),Dn(\"CompoundExpression\",me,{omit:[\"_evaluate\"]}),Tr)Tr[Rn]._classRegistryKey||Dn(\"Expression_\"+Rn,Tr[Rn]);function Fn(t){return t&&\"undefined\"!=typeof ArrayBuffer&&(t instanceof ArrayBuffer||t.constructor&&\"ArrayBuffer\"===t.constructor.name)}function Bn(t){return zn&&t instanceof zn}function Nn(t,e){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp)return t;if(Fn(t)||Bn(t))return e&&e.push(t),t;if(ArrayBuffer.isView(t)){var r=t;return e&&e.push(r.buffer),r}if(t instanceof Pn)return e&&e.push(t.data.buffer),t;if(Array.isArray(t)){for(var n=[],i=0,a=t;i<a.length;i+=1)n.push(Nn(a[i],e));return n}if(\"object\"==typeof t){var o=t.constructor,s=o._classRegistryKey;if(!s)throw new Error(\"can't serialize object of unregistered class\");var l=o.serialize?o.serialize(t,e):{};if(!o.serialize){for(var c in t)if(t.hasOwnProperty(c)&&!(On[s].omit.indexOf(c)>=0)){var u=t[c];l[c]=On[s].shallow.indexOf(c)>=0?u:Nn(u,e)}t instanceof Error&&(l.message=t.message)}if(l.$name)throw new Error(\"$name property is reserved for worker serialization logic.\");return\"Object\"!==s&&(l.$name=s),l}throw new Error(\"can't serialize object of type \"+typeof t)}function jn(t){if(null==t||\"boolean\"==typeof t||\"number\"==typeof t||\"string\"==typeof t||t instanceof Boolean||t instanceof Number||t instanceof String||t instanceof Date||t instanceof RegExp||Fn(t)||Bn(t)||ArrayBuffer.isView(t)||t instanceof Pn)return t;if(Array.isArray(t))return t.map(jn);if(\"object\"==typeof t){var e=t.$name||\"Object\",r=On[e].klass;if(!r)throw new Error(\"can't deserialize unregistered class \"+e);if(r.deserialize)return r.deserialize(t);for(var n=Object.create(r.prototype),i=0,a=Object.keys(t);i<a.length;i+=1){var o=a[i];if(\"$name\"!==o){var s=t[o];n[o]=On[e].shallow.indexOf(o)>=0?s:jn(s)}}return n}throw new Error(\"can't deserialize object of type \"+typeof t)}var Un=function(){this.first=!0};Un.prototype.update=function(t,e){var r=Math.floor(t);return this.first?(this.first=!1,this.lastIntegerZoom=r,this.lastIntegerZoomTime=0,this.lastZoom=t,this.lastFloorZoom=r,!0):(this.lastFloorZoom>r?(this.lastIntegerZoom=r+1,this.lastIntegerZoomTime=e):this.lastFloorZoom<r&&(this.lastIntegerZoom=r,this.lastIntegerZoomTime=e),t!==this.lastZoom&&(this.lastZoom=t,this.lastFloorZoom=r,!0))};var Vn={\"Latin-1 Supplement\":function(t){return t>=128&&t<=255},Arabic:function(t){return t>=1536&&t<=1791},\"Arabic Supplement\":function(t){return t>=1872&&t<=1919},\"Arabic Extended-A\":function(t){return t>=2208&&t<=2303},\"Hangul Jamo\":function(t){return t>=4352&&t<=4607},\"Unified Canadian Aboriginal Syllabics\":function(t){return t>=5120&&t<=5759},Khmer:function(t){return t>=6016&&t<=6143},\"Unified Canadian Aboriginal Syllabics Extended\":function(t){return t>=6320&&t<=6399},\"General Punctuation\":function(t){return t>=8192&&t<=8303},\"Letterlike Symbols\":function(t){return t>=8448&&t<=8527},\"Number Forms\":function(t){return t>=8528&&t<=8591},\"Miscellaneous Technical\":function(t){return t>=8960&&t<=9215},\"Control Pictures\":function(t){return t>=9216&&t<=9279},\"Optical Character Recognition\":function(t){return t>=9280&&t<=9311},\"Enclosed Alphanumerics\":function(t){return t>=9312&&t<=9471},\"Geometric Shapes\":function(t){return t>=9632&&t<=9727},\"Miscellaneous Symbols\":function(t){return t>=9728&&t<=9983},\"Miscellaneous Symbols and Arrows\":function(t){return t>=11008&&t<=11263},\"CJK Radicals Supplement\":function(t){return t>=11904&&t<=12031},\"Kangxi Radicals\":function(t){return t>=12032&&t<=12255},\"Ideographic Description Characters\":function(t){return t>=12272&&t<=12287},\"CJK Symbols and Punctuation\":function(t){return t>=12288&&t<=12351},Hiragana:function(t){return t>=12352&&t<=12447},Katakana:function(t){return t>=12448&&t<=12543},Bopomofo:function(t){return t>=12544&&t<=12591},\"Hangul Compatibility Jamo\":function(t){return t>=12592&&t<=12687},Kanbun:function(t){return t>=12688&&t<=12703},\"Bopomofo Extended\":function(t){return t>=12704&&t<=12735},\"CJK Strokes\":function(t){return t>=12736&&t<=12783},\"Katakana Phonetic Extensions\":function(t){return t>=12784&&t<=12799},\"Enclosed CJK Letters and Months\":function(t){return t>=12800&&t<=13055},\"CJK Compatibility\":function(t){return t>=13056&&t<=13311},\"CJK Unified Ideographs Extension A\":function(t){return t>=13312&&t<=19903},\"Yijing Hexagram Symbols\":function(t){return t>=19904&&t<=19967},\"CJK Unified Ideographs\":function(t){return t>=19968&&t<=40959},\"Yi Syllables\":function(t){return t>=40960&&t<=42127},\"Yi Radicals\":function(t){return t>=42128&&t<=42191},\"Hangul Jamo Extended-A\":function(t){return t>=43360&&t<=43391},\"Hangul Syllables\":function(t){return t>=44032&&t<=55215},\"Hangul Jamo Extended-B\":function(t){return t>=55216&&t<=55295},\"Private Use Area\":function(t){return t>=57344&&t<=63743},\"CJK Compatibility Ideographs\":function(t){return t>=63744&&t<=64255},\"Arabic Presentation Forms-A\":function(t){return t>=64336&&t<=65023},\"Vertical Forms\":function(t){return t>=65040&&t<=65055},\"CJK Compatibility Forms\":function(t){return t>=65072&&t<=65103},\"Small Form Variants\":function(t){return t>=65104&&t<=65135},\"Arabic Presentation Forms-B\":function(t){return t>=65136&&t<=65279},\"Halfwidth and Fullwidth Forms\":function(t){return t>=65280&&t<=65519}};function qn(t){for(var e=0,r=t;e<r.length;e+=1)if(Hn(r[e].charCodeAt(0)))return!0;return!1}function Hn(t){return!(746!==t&&747!==t&&(t<4352||!(Vn[\"Bopomofo Extended\"](t)||Vn.Bopomofo(t)||Vn[\"CJK Compatibility Forms\"](t)&&!(t>=65097&&t<=65103)||Vn[\"CJK Compatibility Ideographs\"](t)||Vn[\"CJK Compatibility\"](t)||Vn[\"CJK Radicals Supplement\"](t)||Vn[\"CJK Strokes\"](t)||!(!Vn[\"CJK Symbols and Punctuation\"](t)||t>=12296&&t<=12305||t>=12308&&t<=12319||12336===t)||Vn[\"CJK Unified Ideographs Extension A\"](t)||Vn[\"CJK Unified Ideographs\"](t)||Vn[\"Enclosed CJK Letters and Months\"](t)||Vn[\"Hangul Compatibility Jamo\"](t)||Vn[\"Hangul Jamo Extended-A\"](t)||Vn[\"Hangul Jamo Extended-B\"](t)||Vn[\"Hangul Jamo\"](t)||Vn[\"Hangul Syllables\"](t)||Vn.Hiragana(t)||Vn[\"Ideographic Description Characters\"](t)||Vn.Kanbun(t)||Vn[\"Kangxi Radicals\"](t)||Vn[\"Katakana Phonetic Extensions\"](t)||Vn.Katakana(t)&&12540!==t||!(!Vn[\"Halfwidth and Fullwidth Forms\"](t)||65288===t||65289===t||65293===t||t>=65306&&t<=65310||65339===t||65341===t||65343===t||t>=65371&&t<=65503||65507===t||t>=65512&&t<=65519)||!(!Vn[\"Small Form Variants\"](t)||t>=65112&&t<=65118||t>=65123&&t<=65126)||Vn[\"Unified Canadian Aboriginal Syllabics\"](t)||Vn[\"Unified Canadian Aboriginal Syllabics Extended\"](t)||Vn[\"Vertical Forms\"](t)||Vn[\"Yijing Hexagram Symbols\"](t)||Vn[\"Yi Syllables\"](t)||Vn[\"Yi Radicals\"](t))))}function Gn(t){return!(Hn(t)||function(t){return!!(Vn[\"Latin-1 Supplement\"](t)&&(167===t||169===t||174===t||177===t||188===t||189===t||190===t||215===t||247===t)||Vn[\"General Punctuation\"](t)&&(8214===t||8224===t||8225===t||8240===t||8241===t||8251===t||8252===t||8258===t||8263===t||8264===t||8265===t||8273===t)||Vn[\"Letterlike Symbols\"](t)||Vn[\"Number Forms\"](t)||Vn[\"Miscellaneous Technical\"](t)&&(t>=8960&&t<=8967||t>=8972&&t<=8991||t>=8996&&t<=9e3||9003===t||t>=9085&&t<=9114||t>=9150&&t<=9165||9167===t||t>=9169&&t<=9179||t>=9186&&t<=9215)||Vn[\"Control Pictures\"](t)&&9251!==t||Vn[\"Optical Character Recognition\"](t)||Vn[\"Enclosed Alphanumerics\"](t)||Vn[\"Geometric Shapes\"](t)||Vn[\"Miscellaneous Symbols\"](t)&&!(t>=9754&&t<=9759)||Vn[\"Miscellaneous Symbols and Arrows\"](t)&&(t>=11026&&t<=11055||t>=11088&&t<=11097||t>=11192&&t<=11243)||Vn[\"CJK Symbols and Punctuation\"](t)||Vn.Katakana(t)||Vn[\"Private Use Area\"](t)||Vn[\"CJK Compatibility Forms\"](t)||Vn[\"Small Form Variants\"](t)||Vn[\"Halfwidth and Fullwidth Forms\"](t)||8734===t||8756===t||8757===t||t>=9984&&t<=10087||t>=10102&&t<=10131||65532===t||65533===t)}(t))}function Yn(t){return t>=1424&&t<=2303||Vn[\"Arabic Presentation Forms-A\"](t)||Vn[\"Arabic Presentation Forms-B\"](t)}function Wn(t,e){return!(!e&&Yn(t)||t>=2304&&t<=3583||t>=3840&&t<=4255||Vn.Khmer(t))}function Xn(t){for(var e=0,r=t;e<r.length;e+=1)if(Yn(r[e].charCodeAt(0)))return!0;return!1}var Zn=null,Jn=\"unavailable\",Kn=null,Qn=function(t){t&&\"string\"==typeof t&&t.indexOf(\"NetworkError\")>-1&&(Jn=\"error\"),Zn&&Zn(t)};function $n(){ti.fire(new Tt(\"pluginStateChange\",{pluginStatus:Jn,pluginURL:Kn}))}var ti=new Mt,ei=function(){return Jn},ri=function(){if(\"deferred\"!==Jn||!Kn)throw new Error(\"rtl-text-plugin cannot be downloaded unless a pluginURL is specified\");Jn=\"loading\",$n(),Kn&&yt({url:Kn},(function(t){t?Qn(t):(Jn=\"loaded\",$n())}))},ni={applyArabicShaping:null,processBidirectionalText:null,processStyledBidirectionalText:null,isLoaded:function(){return\"loaded\"===Jn||null!=ni.applyArabicShaping},isLoading:function(){return\"loading\"===Jn},setState:function(t){Jn=t.pluginStatus,Kn=t.pluginURL},isParsed:function(){return null!=ni.applyArabicShaping&&null!=ni.processBidirectionalText&&null!=ni.processStyledBidirectionalText},getPluginURL:function(){return Kn}},ii=function(t,e){this.zoom=t,e?(this.now=e.now,this.fadeDuration=e.fadeDuration,this.zoomHistory=e.zoomHistory,this.transition=e.transition):(this.now=0,this.fadeDuration=0,this.zoomHistory=new Un,this.transition={})};ii.prototype.isSupportedScript=function(t){return function(t,e){for(var r=0,n=t;r<n.length;r+=1)if(!Wn(n[r].charCodeAt(0),e))return!1;return!0}(t,ni.isLoaded())},ii.prototype.crossFadingFactor=function(){return 0===this.fadeDuration?1:Math.min((this.now-this.zoomHistory.lastIntegerZoomTime)/this.fadeDuration,1)},ii.prototype.getCrossfadeParameters=function(){var t=this.zoom,e=t-Math.floor(t),r=this.crossFadingFactor();return t>this.zoomHistory.lastIntegerZoom?{fromScale:2,toScale:1,t:e+(1-e)*r}:{fromScale:.5,toScale:1,t:1-(1-r)*e}};var ai=function(t,e){this.property=t,this.value=e,this.expression=function(t,e){if(Or(t))return new Wr(t,e);if(Vr(t)){var r=Yr(t,e);if(\"error\"===r.result)throw new Error(r.value.map((function(t){return t.key+\": \"+t.message})).join(\", \"));return r.value}var n=t;return\"string\"==typeof t&&\"color\"===e.type&&(n=Kt.parse(t)),{kind:\"constant\",evaluate:function(){return n}}}(void 0===e?t.specification.default:e,t.specification)};ai.prototype.isDataDriven=function(){return\"source\"===this.expression.kind||\"composite\"===this.expression.kind},ai.prototype.possiblyEvaluate=function(t,e,r){return this.property.possiblyEvaluate(this,t,e,r)};var oi=function(t){this.property=t,this.value=new ai(t,void 0)};oi.prototype.transitioned=function(t,e){return new li(this.property,this.value,e,u({},t.transition,this.transition),t.now)},oi.prototype.untransitioned=function(){return new li(this.property,this.value,null,{},0)};var si=function(t){this._properties=t,this._values=Object.create(t.defaultTransitionablePropertyValues)};si.prototype.getValue=function(t){return x(this._values[t].value.value)},si.prototype.setValue=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].value=new ai(this._values[t].property,null===e?void 0:x(e))},si.prototype.getTransition=function(t){return x(this._values[t].transition)},si.prototype.setTransition=function(t,e){this._values.hasOwnProperty(t)||(this._values[t]=new oi(this._values[t].property)),this._values[t].transition=x(e)||void 0},si.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i);var a=this.getTransition(n);void 0!==a&&(t[n+\"-transition\"]=a)}return t},si.prototype.transitioned=function(t,e){for(var r=new ci(this._properties),n=0,i=Object.keys(this._values);n<i.length;n+=1){var a=i[n];r._values[a]=this._values[a].transitioned(t,e._values[a])}return r},si.prototype.untransitioned=function(){for(var t=new ci(this._properties),e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e];t._values[n]=this._values[n].untransitioned()}return t};var li=function(t,e,r,n,i){this.property=t,this.value=e,this.begin=i+n.delay||0,this.end=this.begin+n.duration||0,t.specification.transition&&(n.delay||n.duration)&&(this.prior=r)};li.prototype.possiblyEvaluate=function(t,e,r){var n=t.now||0,i=this.value.possiblyEvaluate(t,e,r),a=this.prior;if(a){if(n>this.end)return this.prior=null,i;if(this.value.isDataDriven())return this.prior=null,i;if(n<this.begin)return a.possiblyEvaluate(t,e,r);var o=(n-this.begin)/(this.end-this.begin);return this.property.interpolate(a.possiblyEvaluate(t,e,r),i,function(t){if(t<=0)return 0;if(t>=1)return 1;var e=t*t,r=e*t;return 4*(t<.5?r:3*(t-e)+r-.75)}(o))}return i};var ci=function(t){this._properties=t,this._values=Object.create(t.defaultTransitioningPropertyValues)};ci.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n},ci.prototype.hasTransition=function(){for(var t=0,e=Object.keys(this._values);t<e.length;t+=1)if(this._values[e[t]].prior)return!0;return!1};var ui=function(t){this._properties=t,this._values=Object.create(t.defaultPropertyValues)};ui.prototype.getValue=function(t){return x(this._values[t].value)},ui.prototype.setValue=function(t,e){this._values[t]=new ai(this._values[t].property,null===e?void 0:x(e))},ui.prototype.serialize=function(){for(var t={},e=0,r=Object.keys(this._values);e<r.length;e+=1){var n=r[e],i=this.getValue(n);void 0!==i&&(t[n]=i)}return t},ui.prototype.possiblyEvaluate=function(t,e,r){for(var n=new hi(this._properties),i=0,a=Object.keys(this._values);i<a.length;i+=1){var o=a[i];n._values[o]=this._values[o].possiblyEvaluate(t,e,r)}return n};var fi=function(t,e,r){this.property=t,this.value=e,this.parameters=r};fi.prototype.isConstant=function(){return\"constant\"===this.value.kind},fi.prototype.constantOr=function(t){return\"constant\"===this.value.kind?this.value.value:t},fi.prototype.evaluate=function(t,e,r,n){return this.property.evaluate(this.value,this.parameters,t,e,r,n)};var hi=function(t){this._properties=t,this._values=Object.create(t.defaultPossiblyEvaluatedValues)};hi.prototype.get=function(t){return this._values[t]};var pi=function(t){this.specification=t};pi.prototype.possiblyEvaluate=function(t,e){return t.expression.evaluate(e)},pi.prototype.interpolate=function(t,e,r){var n=Ve[this.specification.type];return n?n(t,e,r):t};var di=function(t,e){this.specification=t,this.overrides=e};di.prototype.possiblyEvaluate=function(t,e,r,n){return new fi(this,\"constant\"===t.expression.kind||\"camera\"===t.expression.kind?{kind:\"constant\",value:t.expression.evaluate(e,null,{},r,n)}:t.expression,e)},di.prototype.interpolate=function(t,e,r){if(\"constant\"!==t.value.kind||\"constant\"!==e.value.kind)return t;if(void 0===t.value.value||void 0===e.value.value)return new fi(this,{kind:\"constant\",value:void 0},t.parameters);var n=Ve[this.specification.type];return n?new fi(this,{kind:\"constant\",value:n(t.value.value,e.value.value,r)},t.parameters):t},di.prototype.evaluate=function(t,e,r,n,i,a){return\"constant\"===t.kind?t.value:t.evaluate(e,r,n,i,a)};var gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0===t.value)return new fi(this,{kind:\"constant\",value:void 0},e);if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n),a=\"resolvedImage\"===t.property.specification.type&&\"string\"!=typeof i?i.name:i,o=this._calculate(a,a,a,e);return new fi(this,{kind:\"constant\",value:o},e)}if(\"camera\"===t.expression.kind){var s=this._calculate(t.expression.evaluate({zoom:e.zoom-1}),t.expression.evaluate({zoom:e.zoom}),t.expression.evaluate({zoom:e.zoom+1}),e);return new fi(this,{kind:\"constant\",value:s},e)}return new fi(this,t.expression,e)},e.prototype.evaluate=function(t,e,r,n,i,a){if(\"source\"===t.kind){var o=t.evaluate(e,r,n,i,a);return this._calculate(o,o,o,e)}return\"composite\"===t.kind?this._calculate(t.evaluate({zoom:Math.floor(e.zoom)-1},r,n),t.evaluate({zoom:Math.floor(e.zoom)},r,n),t.evaluate({zoom:Math.floor(e.zoom)+1},r,n),e):t.value},e.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},e.prototype.interpolate=function(t){return t},e}(di),mi=function(t){this.specification=t};mi.prototype.possiblyEvaluate=function(t,e,r,n){if(void 0!==t.value){if(\"constant\"===t.expression.kind){var i=t.expression.evaluate(e,null,{},r,n);return this._calculate(i,i,i,e)}return this._calculate(t.expression.evaluate(new ii(Math.floor(e.zoom-1),e)),t.expression.evaluate(new ii(Math.floor(e.zoom),e)),t.expression.evaluate(new ii(Math.floor(e.zoom+1),e)),e)}},mi.prototype._calculate=function(t,e,r,n){return n.zoom>n.zoomHistory.lastIntegerZoom?{from:t,to:e}:{from:r,to:e}},mi.prototype.interpolate=function(t){return t};var vi=function(t){this.specification=t};vi.prototype.possiblyEvaluate=function(t,e,r,n){return!!t.expression.evaluate(e,null,{},r,n)},vi.prototype.interpolate=function(){return!1};var yi=function(t){for(var e in this.properties=t,this.defaultPropertyValues={},this.defaultTransitionablePropertyValues={},this.defaultTransitioningPropertyValues={},this.defaultPossiblyEvaluatedValues={},this.overridableProperties=[],t){var r=t[e];r.specification.overridable&&this.overridableProperties.push(e);var n=this.defaultPropertyValues[e]=new ai(r,void 0),i=this.defaultTransitionablePropertyValues[e]=new oi(r);this.defaultTransitioningPropertyValues[e]=i.untransitioned(),this.defaultPossiblyEvaluatedValues[e]=n.possiblyEvaluate({})}};Dn(\"DataDrivenProperty\",di),Dn(\"DataConstantProperty\",pi),Dn(\"CrossFadedDataDrivenProperty\",gi),Dn(\"CrossFadedProperty\",mi),Dn(\"ColorRampProperty\",vi);var xi=function(t){function e(e,r){if(t.call(this),this.id=e.id,this.type=e.type,this._featureFilter={filter:function(){return!0},needGeometry:!1},\"custom\"!==e.type&&(this.metadata=(e=e).metadata,this.minzoom=e.minzoom,this.maxzoom=e.maxzoom,\"background\"!==e.type&&(this.source=e.source,this.sourceLayer=e[\"source-layer\"],this.filter=e.filter),r.layout&&(this._unevaluatedLayout=new ui(r.layout)),r.paint)){for(var n in this._transitionablePaint=new si(r.paint),e.paint)this.setPaintProperty(n,e.paint[n],{validate:!1});for(var i in e.layout)this.setLayoutProperty(i,e.layout[i],{validate:!1});this._transitioningPaint=this._transitionablePaint.untransitioned(),this.paint=new hi(r.paint)}}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getCrossfadeParameters=function(){return this._crossfadeParameters},e.prototype.getLayoutProperty=function(t){return\"visibility\"===t?this.visibility:this._unevaluatedLayout.getValue(t)},e.prototype.setLayoutProperty=function(t,e,r){void 0===r&&(r={}),null!=e&&this._validate(En,\"layers.\"+this.id+\".layout.\"+t,t,e,r)||(\"visibility\"!==t?this._unevaluatedLayout.setValue(t,e):this.visibility=e)},e.prototype.getPaintProperty=function(t){return m(t,\"-transition\")?this._transitionablePaint.getTransition(t.slice(0,-\"-transition\".length)):this._transitionablePaint.getValue(t)},e.prototype.setPaintProperty=function(t,e,r){if(void 0===r&&(r={}),null!=e&&this._validate(Sn,\"layers.\"+this.id+\".paint.\"+t,t,e,r))return!1;if(m(t,\"-transition\"))return this._transitionablePaint.setTransition(t.slice(0,-\"-transition\".length),e||void 0),!1;var n=this._transitionablePaint._values[t],i=\"cross-faded-data-driven\"===n.property.specification[\"property-type\"],a=n.value.isDataDriven(),o=n.value;this._transitionablePaint.setValue(t,e),this._handleSpecialPaintPropertyUpdate(t);var s=this._transitionablePaint._values[t].value;return s.isDataDriven()||a||i||this._handleOverridablePaintPropertyUpdate(t,o,s)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){},e.prototype._handleOverridablePaintPropertyUpdate=function(t,e,r){return!1},e.prototype.isHidden=function(t){return!!(this.minzoom&&t<this.minzoom)||!!(this.maxzoom&&t>=this.maxzoom)||\"none\"===this.visibility},e.prototype.updateTransitions=function(t){this._transitioningPaint=this._transitionablePaint.transitioned(t,this._transitioningPaint)},e.prototype.hasTransition=function(){return this._transitioningPaint.hasTransition()},e.prototype.recalculate=function(t,e){t.getCrossfadeParameters&&(this._crossfadeParameters=t.getCrossfadeParameters()),this._unevaluatedLayout&&(this.layout=this._unevaluatedLayout.possiblyEvaluate(t,void 0,e)),this.paint=this._transitioningPaint.possiblyEvaluate(t,void 0,e)},e.prototype.serialize=function(){var t={id:this.id,type:this.type,source:this.source,\"source-layer\":this.sourceLayer,metadata:this.metadata,minzoom:this.minzoom,maxzoom:this.maxzoom,filter:this.filter,layout:this._unevaluatedLayout&&this._unevaluatedLayout.serialize(),paint:this._transitionablePaint&&this._transitionablePaint.serialize()};return this.visibility&&(t.layout=t.layout||{},t.layout.visibility=this.visibility),y(t,(function(t,e){return!(void 0===t||\"layout\"===e&&!Object.keys(t).length||\"paint\"===e&&!Object.keys(t).length)}))},e.prototype._validate=function(t,e,r,n,i){return void 0===i&&(i={}),(!i||!1!==i.validate)&&Cn(this,t.call(Mn,{key:e,layerType:this.type,objectKey:r,value:n,styleSpec:At,style:{glyphs:!0,sprite:!0}}))},e.prototype.is3D=function(){return!1},e.prototype.isTileClipped=function(){return!1},e.prototype.hasOffscreenPass=function(){return!1},e.prototype.resize=function(){},e.prototype.isStateDependent=function(){for(var t in this.paint._values){var e=this.paint.get(t);if(e instanceof fi&&Lr(e.property.specification)&&(\"source\"===e.value.kind||\"composite\"===e.value.kind)&&e.value.isStateDependent)return!0}return!1},e}(Mt),bi={Int8:Int8Array,Uint8:Uint8Array,Int16:Int16Array,Uint16:Uint16Array,Int32:Int32Array,Uint32:Uint32Array,Float32:Float32Array},_i=function(t,e){this._structArray=t,this._pos1=e*this.size,this._pos2=this._pos1/2,this._pos4=this._pos1/4,this._pos8=this._pos1/8},wi=function(){this.isTransferred=!1,this.capacity=-1,this.resize(0)};function Ti(t,e){void 0===e&&(e=1);var r=0,n=0;return{members:t.map((function(t){var i=bi[t.type].BYTES_PER_ELEMENT,a=r=ki(r,Math.max(e,i)),o=t.components||1;return n=Math.max(n,i),r+=i*o,{name:t.name,type:t.type,components:o,offset:a}})),size:ki(r,Math.max(n,e)),alignment:e}}function ki(t,e){return Math.ceil(t/e)*e}wi.serialize=function(t,e){return t._trim(),e&&(t.isTransferred=!0,e.push(t.arrayBuffer)),{length:t.length,arrayBuffer:t.arrayBuffer}},wi.deserialize=function(t){var e=Object.create(this.prototype);return e.arrayBuffer=t.arrayBuffer,e.length=t.length,e.capacity=t.arrayBuffer.byteLength/e.bytesPerElement,e._refreshViews(),e},wi.prototype._trim=function(){this.length!==this.capacity&&(this.capacity=this.length,this.arrayBuffer=this.arrayBuffer.slice(0,this.length*this.bytesPerElement),this._refreshViews())},wi.prototype.clear=function(){this.length=0},wi.prototype.resize=function(t){this.reserve(t),this.length=t},wi.prototype.reserve=function(t){if(t>this.capacity){this.capacity=Math.max(t,Math.floor(5*this.capacity),128),this.arrayBuffer=new ArrayBuffer(this.capacity*this.bytesPerElement);var e=this.uint8;this._refreshViews(),e&&this.uint8.set(e)}},wi.prototype._refreshViews=function(){throw new Error(\"_refreshViews() must be implemented by each concrete StructArray layout\")};var Mi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.int16[n+0]=e,this.int16[n+1]=r,t},e}(wi);Mi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2i4\",Mi);var Ai=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.int16[a+0]=e,this.int16[a+1]=r,this.int16[a+2]=n,this.int16[a+3]=i,t},e}(wi);Ai.prototype.bytesPerElement=8,Dn(\"StructArrayLayout4i8\",Ai);var Si=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Si.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i4i12\",Si);var Ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=4*t,l=8*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.uint8[l+4]=n,this.uint8[l+5]=i,this.uint8[l+6]=a,this.uint8[l+7]=o,t},e}(wi);Ei.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2i4ub8\",Ei);var Ci=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c){var u=this.length;return this.resize(u+1),this.emplace(u,t,e,r,n,i,a,o,s,l,c)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u){var f=9*t,h=18*t;return this.uint16[f+0]=e,this.uint16[f+1]=r,this.uint16[f+2]=n,this.uint16[f+3]=i,this.uint16[f+4]=a,this.uint16[f+5]=o,this.uint16[f+6]=s,this.uint16[f+7]=l,this.uint8[h+16]=c,this.uint8[h+17]=u,t},e}(wi);Ci.prototype.bytesPerElement=18,Dn(\"StructArrayLayout8ui2ub18\",Ci);var Li=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f){var h=this.length;return this.resize(h+1),this.emplace(h,t,e,r,n,i,a,o,s,l,c,u,f)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=12*t;return this.int16[p+0]=e,this.int16[p+1]=r,this.int16[p+2]=n,this.int16[p+3]=i,this.uint16[p+4]=a,this.uint16[p+5]=o,this.uint16[p+6]=s,this.uint16[p+7]=l,this.int16[p+8]=c,this.int16[p+9]=u,this.int16[p+10]=f,this.int16[p+11]=h,t},e}(wi);Li.prototype.bytesPerElement=24,Dn(\"StructArrayLayout4i4ui4i24\",Li);var Ii=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.float32[i+0]=e,this.float32[i+1]=r,this.float32[i+2]=n,t},e}(wi);Ii.prototype.bytesPerElement=12,Dn(\"StructArrayLayout3f12\",Ii);var Pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint32[1*t+0]=e,t},e}(wi);Pi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1ul4\",Pi);var zi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l){var c=this.length;return this.resize(c+1),this.emplace(c,t,e,r,n,i,a,o,s,l)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c){var u=10*t,f=5*t;return this.int16[u+0]=e,this.int16[u+1]=r,this.int16[u+2]=n,this.int16[u+3]=i,this.int16[u+4]=a,this.int16[u+5]=o,this.uint32[f+3]=s,this.uint16[u+8]=l,this.uint16[u+9]=c,t},e}(wi);zi.prototype.bytesPerElement=20,Dn(\"StructArrayLayout6i1ul2ui20\",zi);var Oi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a){var o=this.length;return this.resize(o+1),this.emplace(o,t,e,r,n,i,a)},e.prototype.emplace=function(t,e,r,n,i,a,o){var s=6*t;return this.int16[s+0]=e,this.int16[s+1]=r,this.int16[s+2]=n,this.int16[s+3]=i,this.int16[s+4]=a,this.int16[s+5]=o,t},e}(wi);Oi.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2i2i2i12\",Oi);var Di=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i){var a=this.length;return this.resize(a+1),this.emplace(a,t,e,r,n,i)},e.prototype.emplace=function(t,e,r,n,i,a){var o=4*t,s=8*t;return this.float32[o+0]=e,this.float32[o+1]=r,this.float32[o+2]=n,this.int16[s+6]=i,this.int16[s+7]=a,t},e}(wi);Di.prototype.bytesPerElement=16,Dn(\"StructArrayLayout2f1f2i16\",Di);var Ri=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=12*t,o=3*t;return this.uint8[a+0]=e,this.uint8[a+1]=r,this.float32[o+1]=n,this.float32[o+2]=i,t},e}(wi);Ri.prototype.bytesPerElement=12,Dn(\"StructArrayLayout2ub2f12\",Ri);var Fi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.uint16[i+0]=e,this.uint16[i+1]=r,this.uint16[i+2]=n,t},e}(wi);Fi.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3ui6\",Fi);var Bi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m){var v=this.length;return this.resize(v+1),this.emplace(v,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v){var y=24*t,x=12*t,b=48*t;return this.int16[y+0]=e,this.int16[y+1]=r,this.uint16[y+2]=n,this.uint16[y+3]=i,this.uint32[x+2]=a,this.uint32[x+3]=o,this.uint32[x+4]=s,this.uint16[y+10]=l,this.uint16[y+11]=c,this.uint16[y+12]=u,this.float32[x+7]=f,this.float32[x+8]=h,this.uint8[b+36]=p,this.uint8[b+37]=d,this.uint8[b+38]=g,this.uint32[x+10]=m,this.int16[y+22]=v,t},e}(wi);Bi.prototype.bytesPerElement=48,Dn(\"StructArrayLayout2i2ui3ul3ui2f3ub1ul1i48\",Bi);var Ni=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S){var E=this.length;return this.resize(E+1),this.emplace(E,t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S)},e.prototype.emplace=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S,E){var C=34*t,L=17*t;return this.int16[C+0]=e,this.int16[C+1]=r,this.int16[C+2]=n,this.int16[C+3]=i,this.int16[C+4]=a,this.int16[C+5]=o,this.int16[C+6]=s,this.int16[C+7]=l,this.uint16[C+8]=c,this.uint16[C+9]=u,this.uint16[C+10]=f,this.uint16[C+11]=h,this.uint16[C+12]=p,this.uint16[C+13]=d,this.uint16[C+14]=g,this.uint16[C+15]=m,this.uint16[C+16]=v,this.uint16[C+17]=y,this.uint16[C+18]=x,this.uint16[C+19]=b,this.uint16[C+20]=_,this.uint16[C+21]=w,this.uint16[C+22]=T,this.uint32[L+12]=k,this.float32[L+13]=M,this.float32[L+14]=A,this.float32[L+15]=S,this.float32[L+16]=E,t},e}(wi);Ni.prototype.bytesPerElement=68,Dn(\"StructArrayLayout8i15ui1ul4f68\",Ni);var ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.float32[1*t+0]=e,t},e}(wi);ji.prototype.bytesPerElement=4,Dn(\"StructArrayLayout1f4\",ji);var Ui=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.int16=new Int16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=3*t;return this.int16[i+0]=e,this.int16[i+1]=r,this.int16[i+2]=n,t},e}(wi);Ui.prototype.bytesPerElement=6,Dn(\"StructArrayLayout3i6\",Ui);var Vi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint32=new Uint32Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r){var n=this.length;return this.resize(n+1),this.emplace(n,t,e,r)},e.prototype.emplace=function(t,e,r,n){var i=4*t;return this.uint32[2*t+0]=e,this.uint16[i+2]=r,this.uint16[i+3]=n,t},e}(wi);Vi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout1ul2ui8\",Vi);var qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.uint16[n+0]=e,this.uint16[n+1]=r,t},e}(wi);qi.prototype.bytesPerElement=4,Dn(\"StructArrayLayout2ui4\",qi);var Hi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.uint16=new Uint16Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t){var e=this.length;return this.resize(e+1),this.emplace(e,t)},e.prototype.emplace=function(t,e){return this.uint16[1*t+0]=e,t},e}(wi);Hi.prototype.bytesPerElement=2,Dn(\"StructArrayLayout1ui2\",Hi);var Gi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e){var r=this.length;return this.resize(r+1),this.emplace(r,t,e)},e.prototype.emplace=function(t,e,r){var n=2*t;return this.float32[n+0]=e,this.float32[n+1]=r,t},e}(wi);Gi.prototype.bytesPerElement=8,Dn(\"StructArrayLayout2f8\",Gi);var Yi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._refreshViews=function(){this.uint8=new Uint8Array(this.arrayBuffer),this.float32=new Float32Array(this.arrayBuffer)},e.prototype.emplaceBack=function(t,e,r,n){var i=this.length;return this.resize(i+1),this.emplace(i,t,e,r,n)},e.prototype.emplace=function(t,e,r,n,i){var a=4*t;return this.float32[a+0]=e,this.float32[a+1]=r,this.float32[a+2]=n,this.float32[a+3]=i,t},e}(wi);Yi.prototype.bytesPerElement=16,Dn(\"StructArrayLayout4f16\",Yi);var Wi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorPointX:{configurable:!0},anchorPointY:{configurable:!0},x1:{configurable:!0},y1:{configurable:!0},x2:{configurable:!0},y2:{configurable:!0},featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0},anchorPoint:{configurable:!0}};return r.anchorPointX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorPointY.get=function(){return this._structArray.int16[this._pos2+1]},r.x1.get=function(){return this._structArray.int16[this._pos2+2]},r.y1.get=function(){return this._structArray.int16[this._pos2+3]},r.x2.get=function(){return this._structArray.int16[this._pos2+4]},r.y2.get=function(){return this._structArray.int16[this._pos2+5]},r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+8]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.anchorPoint.get=function(){return new i(this.anchorPointX,this.anchorPointY)},Object.defineProperties(e.prototype,r),e}(_i);Wi.prototype.size=20;var Xi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Wi(this,t)},e}(zi);Dn(\"CollisionBoxArray\",Xi);var Zi=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},glyphStartIndex:{configurable:!0},numGlyphs:{configurable:!0},vertexStartIndex:{configurable:!0},lineStartIndex:{configurable:!0},lineLength:{configurable:!0},segment:{configurable:!0},lowerSize:{configurable:!0},upperSize:{configurable:!0},lineOffsetX:{configurable:!0},lineOffsetY:{configurable:!0},writingMode:{configurable:!0},placedOrientation:{configurable:!0},hidden:{configurable:!0},crossTileID:{configurable:!0},associatedIconIndex:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.glyphStartIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.numGlyphs.get=function(){return this._structArray.uint16[this._pos2+3]},r.vertexStartIndex.get=function(){return this._structArray.uint32[this._pos4+2]},r.lineStartIndex.get=function(){return this._structArray.uint32[this._pos4+3]},r.lineLength.get=function(){return this._structArray.uint32[this._pos4+4]},r.segment.get=function(){return this._structArray.uint16[this._pos2+10]},r.lowerSize.get=function(){return this._structArray.uint16[this._pos2+11]},r.upperSize.get=function(){return this._structArray.uint16[this._pos2+12]},r.lineOffsetX.get=function(){return this._structArray.float32[this._pos4+7]},r.lineOffsetY.get=function(){return this._structArray.float32[this._pos4+8]},r.writingMode.get=function(){return this._structArray.uint8[this._pos1+36]},r.placedOrientation.get=function(){return this._structArray.uint8[this._pos1+37]},r.placedOrientation.set=function(t){this._structArray.uint8[this._pos1+37]=t},r.hidden.get=function(){return this._structArray.uint8[this._pos1+38]},r.hidden.set=function(t){this._structArray.uint8[this._pos1+38]=t},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+10]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+10]=t},r.associatedIconIndex.get=function(){return this._structArray.int16[this._pos2+22]},Object.defineProperties(e.prototype,r),e}(_i);Zi.prototype.size=48;var Ji=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Zi(this,t)},e}(Bi);Dn(\"PlacedSymbolArray\",Ji);var Ki=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={anchorX:{configurable:!0},anchorY:{configurable:!0},rightJustifiedTextSymbolIndex:{configurable:!0},centerJustifiedTextSymbolIndex:{configurable:!0},leftJustifiedTextSymbolIndex:{configurable:!0},verticalPlacedTextSymbolIndex:{configurable:!0},placedIconSymbolIndex:{configurable:!0},verticalPlacedIconSymbolIndex:{configurable:!0},key:{configurable:!0},textBoxStartIndex:{configurable:!0},textBoxEndIndex:{configurable:!0},verticalTextBoxStartIndex:{configurable:!0},verticalTextBoxEndIndex:{configurable:!0},iconBoxStartIndex:{configurable:!0},iconBoxEndIndex:{configurable:!0},verticalIconBoxStartIndex:{configurable:!0},verticalIconBoxEndIndex:{configurable:!0},featureIndex:{configurable:!0},numHorizontalGlyphVertices:{configurable:!0},numVerticalGlyphVertices:{configurable:!0},numIconVertices:{configurable:!0},numVerticalIconVertices:{configurable:!0},useRuntimeCollisionCircles:{configurable:!0},crossTileID:{configurable:!0},textBoxScale:{configurable:!0},textOffset0:{configurable:!0},textOffset1:{configurable:!0},collisionCircleDiameter:{configurable:!0}};return r.anchorX.get=function(){return this._structArray.int16[this._pos2+0]},r.anchorY.get=function(){return this._structArray.int16[this._pos2+1]},r.rightJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+2]},r.centerJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+3]},r.leftJustifiedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+4]},r.verticalPlacedTextSymbolIndex.get=function(){return this._structArray.int16[this._pos2+5]},r.placedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+6]},r.verticalPlacedIconSymbolIndex.get=function(){return this._structArray.int16[this._pos2+7]},r.key.get=function(){return this._structArray.uint16[this._pos2+8]},r.textBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+9]},r.textBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+10]},r.verticalTextBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+11]},r.verticalTextBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+12]},r.iconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+13]},r.iconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+14]},r.verticalIconBoxStartIndex.get=function(){return this._structArray.uint16[this._pos2+15]},r.verticalIconBoxEndIndex.get=function(){return this._structArray.uint16[this._pos2+16]},r.featureIndex.get=function(){return this._structArray.uint16[this._pos2+17]},r.numHorizontalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+18]},r.numVerticalGlyphVertices.get=function(){return this._structArray.uint16[this._pos2+19]},r.numIconVertices.get=function(){return this._structArray.uint16[this._pos2+20]},r.numVerticalIconVertices.get=function(){return this._structArray.uint16[this._pos2+21]},r.useRuntimeCollisionCircles.get=function(){return this._structArray.uint16[this._pos2+22]},r.crossTileID.get=function(){return this._structArray.uint32[this._pos4+12]},r.crossTileID.set=function(t){this._structArray.uint32[this._pos4+12]=t},r.textBoxScale.get=function(){return this._structArray.float32[this._pos4+13]},r.textOffset0.get=function(){return this._structArray.float32[this._pos4+14]},r.textOffset1.get=function(){return this._structArray.float32[this._pos4+15]},r.collisionCircleDiameter.get=function(){return this._structArray.float32[this._pos4+16]},Object.defineProperties(e.prototype,r),e}(_i);Ki.prototype.size=68;var Qi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new Ki(this,t)},e}(Ni);Dn(\"SymbolInstanceArray\",Qi);var $i=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getoffsetX=function(t){return this.float32[1*t+0]},e}(ji);Dn(\"GlyphOffsetArray\",$i);var ta=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getx=function(t){return this.int16[3*t+0]},e.prototype.gety=function(t){return this.int16[3*t+1]},e.prototype.gettileUnitDistanceFromAnchor=function(t){return this.int16[3*t+2]},e}(Ui);Dn(\"SymbolLineVertexArray\",ta);var ea=function(t){function e(){t.apply(this,arguments)}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={featureIndex:{configurable:!0},sourceLayerIndex:{configurable:!0},bucketIndex:{configurable:!0}};return r.featureIndex.get=function(){return this._structArray.uint32[this._pos4+0]},r.sourceLayerIndex.get=function(){return this._structArray.uint16[this._pos2+2]},r.bucketIndex.get=function(){return this._structArray.uint16[this._pos2+3]},Object.defineProperties(e.prototype,r),e}(_i);ea.prototype.size=8;var ra=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.get=function(t){return new ea(this,t)},e}(Vi);Dn(\"FeatureIndexArray\",ra);var na=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,ia=function(t){void 0===t&&(t=[]),this.segments=t};function aa(t,e){return 256*(t=l(Math.floor(t),0,255))+l(Math.floor(e),0,255)}ia.prototype.prepareSegment=function(t,e,r,n){var i=this.segments[this.segments.length-1];return t>ia.MAX_VERTEX_ARRAY_LENGTH&&_(\"Max vertices per segment is \"+ia.MAX_VERTEX_ARRAY_LENGTH+\": bucket requested \"+t),(!i||i.vertexLength+t>ia.MAX_VERTEX_ARRAY_LENGTH||i.sortKey!==n)&&(i={vertexOffset:e.length,primitiveOffset:r.length,vertexLength:0,primitiveLength:0},void 0!==n&&(i.sortKey=n),this.segments.push(i)),i},ia.prototype.get=function(){return this.segments},ia.prototype.destroy=function(){for(var t=0,e=this.segments;t<e.length;t+=1){var r=e[t];for(var n in r.vaos)r.vaos[n].destroy()}},ia.simpleSegment=function(t,e,r,n){return new ia([{vertexOffset:t,primitiveOffset:e,vertexLength:r,primitiveLength:n,vaos:{},sortKey:0}])},ia.MAX_VERTEX_ARRAY_LENGTH=Math.pow(2,16)-1,Dn(\"SegmentVector\",ia);var oa=Ti([{name:\"a_pattern_from\",components:4,type:\"Uint16\"},{name:\"a_pattern_to\",components:4,type:\"Uint16\"},{name:\"a_pixel_ratio_from\",components:1,type:\"Uint8\"},{name:\"a_pixel_ratio_to\",components:1,type:\"Uint8\"}]),sa=e((function(t){t.exports=function(t,e){var r,n,i,a,o,s,l,c;for(n=t.length-(r=3&t.length),i=e,o=3432918353,s=461845907,c=0;c<n;)l=255&t.charCodeAt(c)|(255&t.charCodeAt(++c))<<8|(255&t.charCodeAt(++c))<<16|(255&t.charCodeAt(++c))<<24,++c,i=27492+(65535&(a=5*(65535&(i=(i^=l=(65535&(l=(l=(65535&l)*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295)<<13|i>>>19))+((5*(i>>>16)&65535)<<16)&4294967295))+((58964+(a>>>16)&65535)<<16);switch(l=0,r){case 3:l^=(255&t.charCodeAt(c+2))<<16;case 2:l^=(255&t.charCodeAt(c+1))<<8;case 1:i^=l=(65535&(l=(l=(65535&(l^=255&t.charCodeAt(c)))*o+(((l>>>16)*o&65535)<<16)&4294967295)<<15|l>>>17))*s+(((l>>>16)*s&65535)<<16)&4294967295}return i^=t.length,i=2246822507*(65535&(i^=i>>>16))+((2246822507*(i>>>16)&65535)<<16)&4294967295,i=3266489909*(65535&(i^=i>>>13))+((3266489909*(i>>>16)&65535)<<16)&4294967295,(i^=i>>>16)>>>0}})),la=e((function(t){t.exports=function(t,e){for(var r,n=t.length,i=e^n,a=0;n>=4;)r=1540483477*(65535&(r=255&t.charCodeAt(a)|(255&t.charCodeAt(++a))<<8|(255&t.charCodeAt(++a))<<16|(255&t.charCodeAt(++a))<<24))+((1540483477*(r>>>16)&65535)<<16),i=1540483477*(65535&i)+((1540483477*(i>>>16)&65535)<<16)^(r=1540483477*(65535&(r^=r>>>24))+((1540483477*(r>>>16)&65535)<<16)),n-=4,++a;switch(n){case 3:i^=(255&t.charCodeAt(a+2))<<16;case 2:i^=(255&t.charCodeAt(a+1))<<8;case 1:i=1540483477*(65535&(i^=255&t.charCodeAt(a)))+((1540483477*(i>>>16)&65535)<<16)}return i=1540483477*(65535&(i^=i>>>13))+((1540483477*(i>>>16)&65535)<<16),(i^=i>>>15)>>>0}})),ca=sa,ua=la;ca.murmur3=sa,ca.murmur2=ua;var fa=function(){this.ids=[],this.positions=[],this.indexed=!1};fa.prototype.add=function(t,e,r,n){this.ids.push(pa(t)),this.positions.push(e,r,n)},fa.prototype.getPositions=function(t){for(var e=pa(t),r=0,n=this.ids.length-1;r<n;){var i=r+n>>1;this.ids[i]>=e?n=i:r=i+1}for(var a=[];this.ids[r]===e;)a.push({index:this.positions[3*r],start:this.positions[3*r+1],end:this.positions[3*r+2]}),r++;return a},fa.serialize=function(t,e){var r=new Float64Array(t.ids),n=new Uint32Array(t.positions);return function t(e,r,n,i){for(;n<i;){for(var a=e[n+i>>1],o=n-1,s=i+1;;){do{o++}while(e[o]<a);do{s--}while(e[s]>a);if(o>=s)break;da(e,o,s),da(r,3*o,3*s),da(r,3*o+1,3*s+1),da(r,3*o+2,3*s+2)}s-n<i-s?(t(e,r,n,s),n=s+1):(t(e,r,s+1,i),i=s)}}(r,n,0,r.length-1),e&&e.push(r.buffer,n.buffer),{ids:r,positions:n}},fa.deserialize=function(t){var e=new fa;return e.ids=t.ids,e.positions=t.positions,e.indexed=!0,e};var ha=Math.pow(2,53)-1;function pa(t){var e=+t;return!isNaN(e)&&e<=ha?e:ca(String(t))}function da(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}Dn(\"FeaturePositionMap\",fa);var ga=function(t,e){this.gl=t.gl,this.location=e},ma=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1i(this.location,t))},e}(ga),va=function(t){function e(e,r){t.call(this,e,r),this.current=0}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){this.current!==t&&(this.current=t,this.gl.uniform1f(this.location,t))},e}(ga),ya=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]||(this.current=t,this.gl.uniform2f(this.location,t[0],t[1]))},e}(ga),xa=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]||(this.current=t,this.gl.uniform3f(this.location,t[0],t[1],t[2]))},e}(ga),ba=function(t){function e(e,r){t.call(this,e,r),this.current=[0,0,0,0]}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t[0]===this.current[0]&&t[1]===this.current[1]&&t[2]===this.current[2]&&t[3]===this.current[3]||(this.current=t,this.gl.uniform4f(this.location,t[0],t[1],t[2],t[3]))},e}(ga),_a=function(t){function e(e,r){t.call(this,e,r),this.current=Kt.transparent}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){t.r===this.current.r&&t.g===this.current.g&&t.b===this.current.b&&t.a===this.current.a||(this.current=t,this.gl.uniform4f(this.location,t.r,t.g,t.b,t.a))},e}(ga),wa=new Float32Array(16),Ta=function(t){function e(e,r){t.call(this,e,r),this.current=wa}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t[12]!==this.current[12]||t[0]!==this.current[0])return this.current=t,void this.gl.uniformMatrix4fv(this.location,!1,t);for(var e=1;e<16;e++)if(t[e]!==this.current[e]){this.current=t,this.gl.uniformMatrix4fv(this.location,!1,t);break}},e}(ga);function ka(t){return[aa(255*t.r,255*t.g),aa(255*t.b,255*t.a)]}var Ma=function(t,e,r){this.value=t,this.uniformNames=e.map((function(t){return\"u_\"+t})),this.type=r};Ma.prototype.setUniform=function(t,e,r){t.set(r.constantOr(this.value))},Ma.prototype.getBinding=function(t,e,r){return\"color\"===this.type?new _a(t,e):new va(t,e)};var Aa=function(t,e){this.uniformNames=e.map((function(t){return\"u_\"+t})),this.patternFrom=null,this.patternTo=null,this.pixelRatioFrom=1,this.pixelRatioTo=1};Aa.prototype.setConstantPatternPositions=function(t,e){this.pixelRatioFrom=e.pixelRatio,this.pixelRatioTo=t.pixelRatio,this.patternFrom=e.tlbr,this.patternTo=t.tlbr},Aa.prototype.setUniform=function(t,e,r,n){var i=\"u_pattern_to\"===n?this.patternTo:\"u_pattern_from\"===n?this.patternFrom:\"u_pixel_ratio_to\"===n?this.pixelRatioTo:\"u_pixel_ratio_from\"===n?this.pixelRatioFrom:null;i&&t.set(i)},Aa.prototype.getBinding=function(t,e,r){return\"u_pattern\"===r.substr(0,9)?new ba(t,e):new va(t,e)};var Sa=function(t,e,r,n){this.expression=t,this.type=r,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?2:1,offset:0}})),this.paintVertexArray=new n};Sa.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.paintVertexArray.length,o=this.expression.evaluate(new ii(0),e,{},n,[],i);this.paintVertexArray.resize(t),this._setPaintValue(a,t,o)},Sa.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:0},r,n);this._setPaintValue(t,e,i)},Sa.prototype._setPaintValue=function(t,e,r){if(\"color\"===this.type)for(var n=ka(r),i=t;i<e;i++)this.paintVertexArray.emplace(i,n[0],n[1]);else{for(var a=t;a<e;a++)this.paintVertexArray.emplace(a,r);this.maxValue=Math.max(this.maxValue,Math.abs(r))}},Sa.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Sa.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()};var Ea=function(t,e,r,n,i,a){this.expression=t,this.uniformNames=e.map((function(t){return\"u_\"+t+\"_t\"})),this.type=r,this.useIntegerZoom=n,this.zoom=i,this.maxValue=0,this.paintVertexAttributes=e.map((function(t){return{name:\"a_\"+t,type:\"Float32\",components:\"color\"===r?4:2,offset:0}})),this.paintVertexArray=new a};Ea.prototype.populatePaintArray=function(t,e,r,n,i){var a=this.expression.evaluate(new ii(this.zoom),e,{},n,[],i),o=this.expression.evaluate(new ii(this.zoom+1),e,{},n,[],i),s=this.paintVertexArray.length;this.paintVertexArray.resize(t),this._setPaintValue(s,t,a,o)},Ea.prototype.updatePaintArray=function(t,e,r,n){var i=this.expression.evaluate({zoom:this.zoom},r,n),a=this.expression.evaluate({zoom:this.zoom+1},r,n);this._setPaintValue(t,e,i,a)},Ea.prototype._setPaintValue=function(t,e,r,n){if(\"color\"===this.type)for(var i=ka(r),a=ka(n),o=t;o<e;o++)this.paintVertexArray.emplace(o,i[0],i[1],a[0],a[1]);else{for(var s=t;s<e;s++)this.paintVertexArray.emplace(s,r,n);this.maxValue=Math.max(this.maxValue,Math.abs(r),Math.abs(n))}},Ea.prototype.upload=function(t){this.paintVertexArray&&this.paintVertexArray.arrayBuffer&&(this.paintVertexBuffer&&this.paintVertexBuffer.buffer?this.paintVertexBuffer.updateData(this.paintVertexArray):this.paintVertexBuffer=t.createVertexBuffer(this.paintVertexArray,this.paintVertexAttributes,this.expression.isStateDependent))},Ea.prototype.destroy=function(){this.paintVertexBuffer&&this.paintVertexBuffer.destroy()},Ea.prototype.setUniform=function(t,e){var r=this.useIntegerZoom?Math.floor(e.zoom):e.zoom,n=l(this.expression.interpolationFactor(r,this.zoom,this.zoom+1),0,1);t.set(n)},Ea.prototype.getBinding=function(t,e,r){return new va(t,e)};var Ca=function(t,e,r,n,i,a){this.expression=t,this.type=e,this.useIntegerZoom=r,this.zoom=n,this.layerId=a,this.zoomInPaintVertexArray=new i,this.zoomOutPaintVertexArray=new i};Ca.prototype.populatePaintArray=function(t,e,r){var n=this.zoomInPaintVertexArray.length;this.zoomInPaintVertexArray.resize(t),this.zoomOutPaintVertexArray.resize(t),this._setPaintValues(n,t,e.patterns&&e.patterns[this.layerId],r)},Ca.prototype.updatePaintArray=function(t,e,r,n,i){this._setPaintValues(t,e,r.patterns&&r.patterns[this.layerId],i)},Ca.prototype._setPaintValues=function(t,e,r,n){if(n&&r){var i=n[r.min],a=n[r.mid],o=n[r.max];if(i&&a&&o)for(var s=t;s<e;s++)this.zoomInPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],i.tl[0],i.tl[1],i.br[0],i.br[1],a.pixelRatio,i.pixelRatio),this.zoomOutPaintVertexArray.emplace(s,a.tl[0],a.tl[1],a.br[0],a.br[1],o.tl[0],o.tl[1],o.br[0],o.br[1],a.pixelRatio,o.pixelRatio)}},Ca.prototype.upload=function(t){this.zoomInPaintVertexArray&&this.zoomInPaintVertexArray.arrayBuffer&&this.zoomOutPaintVertexArray&&this.zoomOutPaintVertexArray.arrayBuffer&&(this.zoomInPaintVertexBuffer=t.createVertexBuffer(this.zoomInPaintVertexArray,oa.members,this.expression.isStateDependent),this.zoomOutPaintVertexBuffer=t.createVertexBuffer(this.zoomOutPaintVertexArray,oa.members,this.expression.isStateDependent))},Ca.prototype.destroy=function(){this.zoomOutPaintVertexBuffer&&this.zoomOutPaintVertexBuffer.destroy(),this.zoomInPaintVertexBuffer&&this.zoomInPaintVertexBuffer.destroy()};var La=function(t,e,r,n){this.binders={},this.layoutAttributes=n,this._buffers=[];var i=[];for(var a in t.paint._values)if(r(a)){var o=t.paint.get(a);if(o instanceof fi&&Lr(o.property.specification)){var s=Pa(a,t.type),l=o.value,c=o.property.specification.type,u=o.property.useIntegerZoom,f=o.property.specification[\"property-type\"],h=\"cross-faded\"===f||\"cross-faded-data-driven\"===f;if(\"constant\"===l.kind)this.binders[a]=h?new Aa(l.value,s):new Ma(l.value,s,c),i.push(\"/u_\"+a);else if(\"source\"===l.kind||h){var p=za(a,c,\"source\");this.binders[a]=h?new Ca(l,c,u,e,p,t.id):new Sa(l,s,c,p),i.push(\"/a_\"+a)}else{var d=za(a,c,\"composite\");this.binders[a]=new Ea(l,s,c,u,e,d),i.push(\"/z_\"+a)}}}this.cacheKey=i.sort().join(\"\")};La.prototype.getMaxValue=function(t){var e=this.binders[t];return e instanceof Sa||e instanceof Ea?e.maxValue:0},La.prototype.populatePaintArrays=function(t,e,r,n,i){for(var a in this.binders){var o=this.binders[a];(o instanceof Sa||o instanceof Ea||o instanceof Ca)&&o.populatePaintArray(t,e,r,n,i)}},La.prototype.setConstantPatternPositions=function(t,e){for(var r in this.binders){var n=this.binders[r];n instanceof Aa&&n.setConstantPatternPositions(t,e)}},La.prototype.updatePaintArrays=function(t,e,r,n,i){var a=!1;for(var o in t)for(var s=0,l=e.getPositions(o);s<l.length;s+=1){var c=l[s],u=r.feature(c.index);for(var f in this.binders){var h=this.binders[f];if((h instanceof Sa||h instanceof Ea||h instanceof Ca)&&!0===h.expression.isStateDependent){var p=n.paint.get(f);h.expression=p.value,h.updatePaintArray(c.start,c.end,u,t[o],i),a=!0}}}return a},La.prototype.defines=function(){var t=[];for(var e in this.binders){var r=this.binders[e];(r instanceof Ma||r instanceof Aa)&&t.push.apply(t,r.uniformNames.map((function(t){return\"#define HAS_UNIFORM_\"+t})))}return t},La.prototype.getPaintVertexBuffers=function(){return this._buffers},La.prototype.getUniforms=function(t,e){var r=[];for(var n in this.binders){var i=this.binders[n];if(i instanceof Ma||i instanceof Aa||i instanceof Ea)for(var a=0,o=i.uniformNames;a<o.length;a+=1){var s=o[a];if(e[s]){var l=i.getBinding(t,e[s],s);r.push({name:s,property:n,binding:l})}}}return r},La.prototype.setUniforms=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.name,l=o.property;this.binders[l].setUniform(o.binding,n,r.get(l),s)}},La.prototype.updatePaintBuffers=function(t){for(var e in this._buffers=[],this.binders){var r=this.binders[e];if(t&&r instanceof Ca){var n=2===t.fromScale?r.zoomInPaintVertexBuffer:r.zoomOutPaintVertexBuffer;n&&this._buffers.push(n)}else(r instanceof Sa||r instanceof Ea)&&r.paintVertexBuffer&&this._buffers.push(r.paintVertexBuffer)}},La.prototype.upload=function(t){for(var e in this.binders){var r=this.binders[e];(r instanceof Sa||r instanceof Ea||r instanceof Ca)&&r.upload(t)}this.updatePaintBuffers()},La.prototype.destroy=function(){for(var t in this.binders){var e=this.binders[t];(e instanceof Sa||e instanceof Ea||e instanceof Ca)&&e.destroy()}};var Ia=function(t,e,r,n){void 0===n&&(n=function(){return!0}),this.programConfigurations={};for(var i=0,a=e;i<a.length;i+=1){var o=a[i];this.programConfigurations[o.id]=new La(o,r,n,t)}this.needsUpload=!1,this._featureMap=new fa,this._bufferOffset=0};function Pa(t,e){return{\"text-opacity\":[\"opacity\"],\"icon-opacity\":[\"opacity\"],\"text-color\":[\"fill_color\"],\"icon-color\":[\"fill_color\"],\"text-halo-color\":[\"halo_color\"],\"icon-halo-color\":[\"halo_color\"],\"text-halo-blur\":[\"halo_blur\"],\"icon-halo-blur\":[\"halo_blur\"],\"text-halo-width\":[\"halo_width\"],\"icon-halo-width\":[\"halo_width\"],\"line-gap-width\":[\"gapwidth\"],\"line-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"],\"fill-extrusion-pattern\":[\"pattern_to\",\"pattern_from\",\"pixel_ratio_to\",\"pixel_ratio_from\"]}[t]||[t.replace(e+\"-\",\"\").replace(/-/g,\"_\")]}function za(t,e,r){var n={color:{source:Gi,composite:Yi},number:{source:ji,composite:Gi}},i=function(t){return{\"line-pattern\":{source:Ci,composite:Ci},\"fill-pattern\":{source:Ci,composite:Ci},\"fill-extrusion-pattern\":{source:Ci,composite:Ci}}[t]}(t);return i&&i[r]||n[e][r]}Ia.prototype.populatePaintArrays=function(t,e,r,n,i,a){for(var o in this.programConfigurations)this.programConfigurations[o].populatePaintArrays(t,e,n,i,a);void 0!==e.id&&this._featureMap.add(e.id,r,this._bufferOffset,t),this._bufferOffset=t,this.needsUpload=!0},Ia.prototype.updatePaintArrays=function(t,e,r,n){for(var i=0,a=r;i<a.length;i+=1){var o=a[i];this.needsUpload=this.programConfigurations[o.id].updatePaintArrays(t,this._featureMap,e,o,n)||this.needsUpload}},Ia.prototype.get=function(t){return this.programConfigurations[t]},Ia.prototype.upload=function(t){if(this.needsUpload){for(var e in this.programConfigurations)this.programConfigurations[e].upload(t);this.needsUpload=!1}},Ia.prototype.destroy=function(){for(var t in this.programConfigurations)this.programConfigurations[t].destroy()},Dn(\"ConstantBinder\",Ma),Dn(\"CrossFadedConstantBinder\",Aa),Dn(\"SourceExpressionBinder\",Sa),Dn(\"CrossFadedCompositeBinder\",Ca),Dn(\"CompositeExpressionBinder\",Ea),Dn(\"ProgramConfiguration\",La,{omit:[\"_buffers\"]}),Dn(\"ProgramConfigurationSet\",Ia);var Oa={min:-1*Math.pow(2,14),max:Math.pow(2,14)-1};function Da(t){for(var e=8192/t.extent,r=t.loadGeometry(),n=0;n<r.length;n++)for(var i=r[n],a=0;a<i.length;a++){var o=i[a];o.x=Math.round(o.x*e),o.y=Math.round(o.y*e),(o.x<Oa.min||o.x>Oa.max||o.y<Oa.min||o.y>Oa.max)&&(_(\"Geometry exceeds allowed extent, reduce your vector tile buffer size\"),o.x=l(o.x,Oa.min,Oa.max),o.y=l(o.y,Oa.min,Oa.max))}return r}function Ra(t,e,r,n,i){t.emplaceBack(2*e+(n+1)/2,2*r+(i+1)/2)}var Fa=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.segments=new ia,this.programConfigurations=new Ia(na,t.layers,t.zoom),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function Ba(t,e){for(var r=0;r<t.length;r++)if(Wa(e,t[r]))return!0;for(var n=0;n<e.length;n++)if(Wa(t,e[n]))return!0;return!!Va(t,e)}function Na(t,e,r){return!!Wa(t,e)||!!Ha(e,t,r)}function ja(t,e){if(1===t.length)return Ya(e,t[0]);for(var r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++)if(Wa(t,n[i]))return!0;for(var a=0;a<t.length;a++)if(Ya(e,t[a]))return!0;for(var o=0;o<e.length;o++)if(Va(t,e[o]))return!0;return!1}function Ua(t,e,r){if(t.length>1){if(Va(t,e))return!0;for(var n=0;n<e.length;n++)if(Ha(e[n],t,r))return!0}for(var i=0;i<t.length;i++)if(Ha(t[i],e,r))return!0;return!1}function Va(t,e){if(0===t.length||0===e.length)return!1;for(var r=0;r<t.length-1;r++)for(var n=t[r],i=t[r+1],a=0;a<e.length-1;a++)if(qa(n,i,e[a],e[a+1]))return!0;return!1}function qa(t,e,r,n){return w(t,r,n)!==w(e,r,n)&&w(t,e,r)!==w(t,e,n)}function Ha(t,e,r){var n=r*r;if(1===e.length)return t.distSqr(e[0])<n;for(var i=1;i<e.length;i++)if(Ga(t,e[i-1],e[i])<n)return!0;return!1}function Ga(t,e,r){var n=e.distSqr(r);if(0===n)return t.distSqr(e);var i=((t.x-e.x)*(r.x-e.x)+(t.y-e.y)*(r.y-e.y))/n;return t.distSqr(i<0?e:i>1?r:r.sub(e)._mult(i)._add(e))}function Ya(t,e){for(var r,n,i,a=!1,o=0;o<t.length;o++)for(var s=0,l=(r=t[o]).length-1;s<r.length;l=s++)(n=r[s]).y>e.y!=(i=r[l]).y>e.y&&e.x<(i.x-n.x)*(e.y-n.y)/(i.y-n.y)+n.x&&(a=!a);return a}function Wa(t,e){for(var r=!1,n=0,i=t.length-1;n<t.length;i=n++){var a=t[n],o=t[i];a.y>e.y!=o.y>e.y&&e.x<(o.x-a.x)*(e.y-a.y)/(o.y-a.y)+a.x&&(r=!r)}return r}function Xa(t,e,r){var n=r[0],i=r[2];if(t.x<n.x&&e.x<n.x||t.x>i.x&&e.x>i.x||t.y<n.y&&e.y<n.y||t.y>i.y&&e.y>i.y)return!1;var a=w(t,e,r[0]);return a!==w(t,e,r[1])||a!==w(t,e,r[2])||a!==w(t,e,r[3])}function Za(t,e,r){var n=e.paint.get(t).value;return\"constant\"===n.kind?n.value:r.programConfigurations.get(e.id).getMaxValue(t)}function Ja(t){return Math.sqrt(t[0]*t[0]+t[1]*t[1])}function Ka(t,e,r,n,a){if(!e[0]&&!e[1])return t;var o=i.convert(e)._mult(a);\"viewport\"===r&&o._rotate(-n);for(var s=[],l=0;l<t.length;l++)s.push(t[l].sub(o));return s}Fa.prototype.populate=function(t,e,r){var n=this.layers[0],i=[],a=null;\"circle\"===n.type&&(a=n.layout.get(\"circle-sort-key\"));for(var o=0,s=t;o<s.length;o+=1){var l=s[o],c=l.feature,u=l.id,f=l.index,h=l.sourceLayerIndex,p=this.layers[0]._featureFilter.needGeometry,d={type:c.type,id:u,properties:c.properties,geometry:p?Da(c):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),d,r)){p||(d.geometry=Da(c));var g=a?a.evaluate(d,{},r):void 0;i.push({id:u,properties:c.properties,type:c.type,sourceLayerIndex:h,index:f,geometry:d.geometry,patterns:{},sortKey:g})}}a&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var m=0,v=i;m<v.length;m+=1){var y=v[m],x=y.geometry,b=y.index,_=y.sourceLayerIndex,w=t[b].feature;this.addFeature(y,x,b,r),e.featureIndex.insert(w,x,b,_,this.index)}},Fa.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Fa.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Fa.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Fa.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,na),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Fa.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Fa.prototype.addFeature=function(t,e,r,n){for(var i=0,a=e;i<a.length;i+=1)for(var o=0,s=a[i];o<s.length;o+=1){var l=s[o],c=l.x,u=l.y;if(!(c<0||c>=8192||u<0||u>=8192)){var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray,t.sortKey),h=f.vertexLength;Ra(this.layoutVertexArray,c,u,-1,-1),Ra(this.layoutVertexArray,c,u,1,-1),Ra(this.layoutVertexArray,c,u,1,1),Ra(this.layoutVertexArray,c,u,-1,1),this.indexArray.emplaceBack(h,h+1,h+2),this.indexArray.emplaceBack(h,h+3,h+2),f.vertexLength+=4,f.primitiveLength+=2}}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,{},n)},Dn(\"CircleBucket\",Fa,{omit:[\"layers\"]});var Qa=new yi({\"circle-sort-key\":new di(At.layout_circle[\"circle-sort-key\"])}),$a={paint:new yi({\"circle-radius\":new di(At.paint_circle[\"circle-radius\"]),\"circle-color\":new di(At.paint_circle[\"circle-color\"]),\"circle-blur\":new di(At.paint_circle[\"circle-blur\"]),\"circle-opacity\":new di(At.paint_circle[\"circle-opacity\"]),\"circle-translate\":new pi(At.paint_circle[\"circle-translate\"]),\"circle-translate-anchor\":new pi(At.paint_circle[\"circle-translate-anchor\"]),\"circle-pitch-scale\":new pi(At.paint_circle[\"circle-pitch-scale\"]),\"circle-pitch-alignment\":new pi(At.paint_circle[\"circle-pitch-alignment\"]),\"circle-stroke-width\":new di(At.paint_circle[\"circle-stroke-width\"]),\"circle-stroke-color\":new di(At.paint_circle[\"circle-stroke-color\"]),\"circle-stroke-opacity\":new di(At.paint_circle[\"circle-stroke-opacity\"])}),layout:Qa},to=\"undefined\"!=typeof Float32Array?Float32Array:Array;function eo(t){return t[0]=1,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=1,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=1,t[11]=0,t[12]=0,t[13]=0,t[14]=0,t[15]=1,t}function ro(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],g=e[12],m=e[13],v=e[14],y=e[15],x=r[0],b=r[1],_=r[2],w=r[3];return t[0]=x*n+b*s+_*f+w*g,t[1]=x*i+b*l+_*h+w*m,t[2]=x*a+b*c+_*p+w*v,t[3]=x*o+b*u+_*d+w*y,t[4]=(x=r[4])*n+(b=r[5])*s+(_=r[6])*f+(w=r[7])*g,t[5]=x*i+b*l+_*h+w*m,t[6]=x*a+b*c+_*p+w*v,t[7]=x*o+b*u+_*d+w*y,t[8]=(x=r[8])*n+(b=r[9])*s+(_=r[10])*f+(w=r[11])*g,t[9]=x*i+b*l+_*h+w*m,t[10]=x*a+b*c+_*p+w*v,t[11]=x*o+b*u+_*d+w*y,t[12]=(x=r[12])*n+(b=r[13])*s+(_=r[14])*f+(w=r[15])*g,t[13]=x*i+b*l+_*h+w*m,t[14]=x*a+b*c+_*p+w*v,t[15]=x*o+b*u+_*d+w*y,t}Math.hypot||(Math.hypot=function(){for(var t=arguments,e=0,r=arguments.length;r--;)e+=t[r]*t[r];return Math.sqrt(e)});var no,io=ro;function ao(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3];return t[0]=r[0]*n+r[4]*i+r[8]*a+r[12]*o,t[1]=r[1]*n+r[5]*i+r[9]*a+r[13]*o,t[2]=r[2]*n+r[6]*i+r[10]*a+r[14]*o,t[3]=r[3]*n+r[7]*i+r[11]*a+r[15]*o,t}no=new to(3),to!=Float32Array&&(no[0]=0,no[1]=0,no[2]=0),function(){var t=new to(4);to!=Float32Array&&(t[0]=0,t[1]=0,t[2]=0,t[3]=0)}();var oo=(function(){var t=new to(2);to!=Float32Array&&(t[0]=0,t[1]=0)}(),function(t){function e(e){t.call(this,e,$a)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new Fa(t)},e.prototype.queryRadius=function(t){var e=t;return Za(\"circle-radius\",this,e)+Za(\"circle-stroke-width\",this,e)+Ja(this.paint.get(\"circle-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o,s){for(var l=Ka(t,this.paint.get(\"circle-translate\"),this.paint.get(\"circle-translate-anchor\"),a.angle,o),c=this.paint.get(\"circle-radius\").evaluate(e,r)+this.paint.get(\"circle-stroke-width\").evaluate(e,r),u=\"map\"===this.paint.get(\"circle-pitch-alignment\"),f=u?l:function(t,e){return t.map((function(t){return so(t,e)}))}(l,s),h=u?c*o:c,p=0,d=n;p<d.length;p+=1)for(var g=0,m=d[p];g<m.length;g+=1){var v=m[g],y=u?v:so(v,s),x=h,b=ao([],[v.x,v.y,0,1],s);if(\"viewport\"===this.paint.get(\"circle-pitch-scale\")&&\"map\"===this.paint.get(\"circle-pitch-alignment\")?x*=b[3]/a.cameraToCenterDistance:\"map\"===this.paint.get(\"circle-pitch-scale\")&&\"viewport\"===this.paint.get(\"circle-pitch-alignment\")&&(x*=a.cameraToCenterDistance/b[3]),Na(f,y,x))return!0}return!1},e}(xi));function so(t,e){var r=ao([],[t.x,t.y,0,1],e);return new i(r[0]/r[3],r[1]/r[3])}var lo=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(Fa);function co(t,e,r,n){var i=e.width,a=e.height;if(n){if(n instanceof Uint8ClampedArray)n=new Uint8Array(n.buffer);else if(n.length!==i*a*r)throw new RangeError(\"mismatched image size\")}else n=new Uint8Array(i*a*r);return t.width=i,t.height=a,t.data=n,t}function uo(t,e,r){var n=e.width,i=e.height;if(n!==t.width||i!==t.height){var a=co({},{width:n,height:i},r);fo(t,a,{x:0,y:0},{x:0,y:0},{width:Math.min(t.width,n),height:Math.min(t.height,i)},r),t.width=n,t.height=i,t.data=a.data}}function fo(t,e,r,n,i,a){if(0===i.width||0===i.height)return e;if(i.width>t.width||i.height>t.height||r.x>t.width-i.width||r.y>t.height-i.height)throw new RangeError(\"out of range source coordinates for image copy\");if(i.width>e.width||i.height>e.height||n.x>e.width-i.width||n.y>e.height-i.height)throw new RangeError(\"out of range destination coordinates for image copy\");for(var o=t.data,s=e.data,l=0;l<i.height;l++)for(var c=((r.y+l)*t.width+r.x)*a,u=((n.y+l)*e.width+n.x)*a,f=0;f<i.width*a;f++)s[u+f]=o[c+f];return e}Dn(\"HeatmapBucket\",lo,{omit:[\"layers\"]});var ho=function(t,e){co(this,t,1,e)};ho.prototype.resize=function(t){uo(this,t,1)},ho.prototype.clone=function(){return new ho({width:this.width,height:this.height},new Uint8Array(this.data))},ho.copy=function(t,e,r,n,i){fo(t,e,r,n,i,1)};var po=function(t,e){co(this,t,4,e)};po.prototype.resize=function(t){uo(this,t,4)},po.prototype.replace=function(t,e){e?this.data.set(t):this.data=t instanceof Uint8ClampedArray?new Uint8Array(t.buffer):t},po.prototype.clone=function(){return new po({width:this.width,height:this.height},new Uint8Array(this.data))},po.copy=function(t,e,r,n,i){fo(t,e,r,n,i,4)},Dn(\"AlphaImage\",ho),Dn(\"RGBAImage\",po);var go={paint:new yi({\"heatmap-radius\":new di(At.paint_heatmap[\"heatmap-radius\"]),\"heatmap-weight\":new di(At.paint_heatmap[\"heatmap-weight\"]),\"heatmap-intensity\":new pi(At.paint_heatmap[\"heatmap-intensity\"]),\"heatmap-color\":new vi(At.paint_heatmap[\"heatmap-color\"]),\"heatmap-opacity\":new pi(At.paint_heatmap[\"heatmap-opacity\"])})};function mo(t,e){for(var r=new Uint8Array(1024),n={},i=0,a=0;i<256;i++,a+=4){n[e]=i/255;var o=t.evaluate(n);r[a+0]=Math.floor(255*o.r/o.a),r[a+1]=Math.floor(255*o.g/o.a),r[a+2]=Math.floor(255*o.b/o.a),r[a+3]=Math.floor(255*o.a)}return new po({width:256,height:1},r)}var vo=function(t){function e(e){t.call(this,e,go),this._updateColorRamp()}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new lo(t)},e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"heatmap-color\"===t&&this._updateColorRamp()},e.prototype._updateColorRamp=function(){this.colorRamp=mo(this._transitionablePaint._values[\"heatmap-color\"].value.expression,\"heatmapDensity\"),this.colorRampTexture=null},e.prototype.resize=function(){this.heatmapFbo&&(this.heatmapFbo.destroy(),this.heatmapFbo=null)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"heatmap-opacity\")&&\"none\"!==this.visibility},e}(xi),yo={paint:new yi({\"hillshade-illumination-direction\":new pi(At.paint_hillshade[\"hillshade-illumination-direction\"]),\"hillshade-illumination-anchor\":new pi(At.paint_hillshade[\"hillshade-illumination-anchor\"]),\"hillshade-exaggeration\":new pi(At.paint_hillshade[\"hillshade-exaggeration\"]),\"hillshade-shadow-color\":new pi(At.paint_hillshade[\"hillshade-shadow-color\"]),\"hillshade-highlight-color\":new pi(At.paint_hillshade[\"hillshade-highlight-color\"]),\"hillshade-accent-color\":new pi(At.paint_hillshade[\"hillshade-accent-color\"])})},xo=function(t){function e(e){t.call(this,e,yo)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.hasOffscreenPass=function(){return 0!==this.paint.get(\"hillshade-exaggeration\")&&\"none\"!==this.visibility},e}(xi),bo=Ti([{name:\"a_pos\",components:2,type:\"Int16\"}],4).members,_o=To,wo=To;function To(t,e,r){r=r||2;var n,i,a,o,s,l,c,u=e&&e.length,f=u?e[0]*r:t.length,h=ko(t,0,f,r,!0),p=[];if(!h||h.next===h.prev)return p;if(u&&(h=function(t,e,r,n){var i,a,o,s=[];for(i=0,a=e.length;i<a;i++)(o=ko(t,e[i]*n,i<a-1?e[i+1]*n:t.length,n,!1))===o.next&&(o.steiner=!0),s.push(Do(o));for(s.sort(Io),i=0;i<s.length;i++)Po(s[i],r),r=Mo(r,r.next);return r}(t,e,h,r)),t.length>80*r){n=a=t[0],i=o=t[1];for(var d=r;d<f;d+=r)(s=t[d])<n&&(n=s),(l=t[d+1])<i&&(i=l),s>a&&(a=s),l>o&&(o=l);c=0!==(c=Math.max(a-n,o-i))?1/c:0}return Ao(h,p,r,n,i,c),p}function ko(t,e,r,n,i){var a,o;if(i===Xo(t,e,r,n)>0)for(a=e;a<r;a+=n)o=Go(a,t[a],t[a+1],o);else for(a=r-n;a>=e;a-=n)o=Go(a,t[a],t[a+1],o);return o&&No(o,o.next)&&(Yo(o),o=o.next),o}function Mo(t,e){if(!t)return t;e||(e=t);var r,n=t;do{if(r=!1,n.steiner||!No(n,n.next)&&0!==Bo(n.prev,n,n.next))n=n.next;else{if(Yo(n),(n=e=n.prev)===n.next)break;r=!0}}while(r||n!==e);return e}function Ao(t,e,r,n,i,a,o){if(t){!o&&a&&function(t,e,r,n){var i=t;do{null===i.z&&(i.z=Oo(i.x,i.y,e,r,n)),i.prevZ=i.prev,i.nextZ=i.next,i=i.next}while(i!==t);i.prevZ.nextZ=null,i.prevZ=null,function(t){var e,r,n,i,a,o,s,l,c=1;do{for(r=t,t=null,a=null,o=0;r;){for(o++,n=r,s=0,e=0;e<c&&(s++,n=n.nextZ);e++);for(l=c;s>0||l>0&&n;)0!==s&&(0===l||!n||r.z<=n.z)?(i=r,r=r.nextZ,s--):(i=n,n=n.nextZ,l--),a?a.nextZ=i:t=i,i.prevZ=a,a=i;r=n}a.nextZ=null,c*=2}while(o>1)}(i)}(t,n,i,a);for(var s,l,c=t;t.prev!==t.next;)if(s=t.prev,l=t.next,a?Eo(t,n,i,a):So(t))e.push(s.i/r),e.push(t.i/r),e.push(l.i/r),Yo(t),t=l.next,c=l.next;else if((t=l)===c){o?1===o?Ao(t=Co(Mo(t),e,r),e,r,n,i,a,2):2===o&&Lo(t,e,r,n,i,a):Ao(Mo(t),e,r,n,i,a,1);break}}}function So(t){var e=t.prev,r=t,n=t.next;if(Bo(e,r,n)>=0)return!1;for(var i=t.next.next;i!==t.prev;){if(Ro(e.x,e.y,r.x,r.y,n.x,n.y,i.x,i.y)&&Bo(i.prev,i,i.next)>=0)return!1;i=i.next}return!0}function Eo(t,e,r,n){var i=t.prev,a=t,o=t.next;if(Bo(i,a,o)>=0)return!1;for(var s=i.x>a.x?i.x>o.x?i.x:o.x:a.x>o.x?a.x:o.x,l=i.y>a.y?i.y>o.y?i.y:o.y:a.y>o.y?a.y:o.y,c=Oo(i.x<a.x?i.x<o.x?i.x:o.x:a.x<o.x?a.x:o.x,i.y<a.y?i.y<o.y?i.y:o.y:a.y<o.y?a.y:o.y,e,r,n),u=Oo(s,l,e,r,n),f=t.prevZ,h=t.nextZ;f&&f.z>=c&&h&&h.z<=u;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;if(f=f.prevZ,h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}for(;f&&f.z>=c;){if(f!==t.prev&&f!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,f.x,f.y)&&Bo(f.prev,f,f.next)>=0)return!1;f=f.prevZ}for(;h&&h.z<=u;){if(h!==t.prev&&h!==t.next&&Ro(i.x,i.y,a.x,a.y,o.x,o.y,h.x,h.y)&&Bo(h.prev,h,h.next)>=0)return!1;h=h.nextZ}return!0}function Co(t,e,r){var n=t;do{var i=n.prev,a=n.next.next;!No(i,a)&&jo(i,n,n.next,a)&&qo(i,a)&&qo(a,i)&&(e.push(i.i/r),e.push(n.i/r),e.push(a.i/r),Yo(n),Yo(n.next),n=t=a),n=n.next}while(n!==t);return Mo(n)}function Lo(t,e,r,n,i,a){var o=t;do{for(var s=o.next.next;s!==o.prev;){if(o.i!==s.i&&Fo(o,s)){var l=Ho(o,s);return o=Mo(o,o.next),l=Mo(l,l.next),Ao(o,e,r,n,i,a),void Ao(l,e,r,n,i,a)}s=s.next}o=o.next}while(o!==t)}function Io(t,e){return t.x-e.x}function Po(t,e){if(e=function(t,e){var r,n=e,i=t.x,a=t.y,o=-1/0;do{if(a<=n.y&&a>=n.next.y&&n.next.y!==n.y){var s=n.x+(a-n.y)*(n.next.x-n.x)/(n.next.y-n.y);if(s<=i&&s>o){if(o=s,s===i){if(a===n.y)return n;if(a===n.next.y)return n.next}r=n.x<n.next.x?n:n.next}}n=n.next}while(n!==e);if(!r)return null;if(i===o)return r;var l,c=r,u=r.x,f=r.y,h=1/0;n=r;do{i>=n.x&&n.x>=u&&i!==n.x&&Ro(a<f?i:o,a,u,f,a<f?o:i,a,n.x,n.y)&&(l=Math.abs(a-n.y)/(i-n.x),qo(n,t)&&(l<h||l===h&&(n.x>r.x||n.x===r.x&&zo(r,n)))&&(r=n,h=l)),n=n.next}while(n!==c);return r}(t,e)){var r=Ho(e,t);Mo(e,e.next),Mo(r,r.next)}}function zo(t,e){return Bo(t.prev,t,e.prev)<0&&Bo(e.next,t,t.next)<0}function Oo(t,e,r,n,i){return(t=1431655765&((t=858993459&((t=252645135&((t=16711935&((t=32767*(t-r)*i)|t<<8))|t<<4))|t<<2))|t<<1))|(e=1431655765&((e=858993459&((e=252645135&((e=16711935&((e=32767*(e-n)*i)|e<<8))|e<<4))|e<<2))|e<<1))<<1}function Do(t){var e=t,r=t;do{(e.x<r.x||e.x===r.x&&e.y<r.y)&&(r=e),e=e.next}while(e!==t);return r}function Ro(t,e,r,n,i,a,o,s){return(i-o)*(e-s)-(t-o)*(a-s)>=0&&(t-o)*(n-s)-(r-o)*(e-s)>=0&&(r-o)*(a-s)-(i-o)*(n-s)>=0}function Fo(t,e){return t.next.i!==e.i&&t.prev.i!==e.i&&!function(t,e){var r=t;do{if(r.i!==t.i&&r.next.i!==t.i&&r.i!==e.i&&r.next.i!==e.i&&jo(r,r.next,t,e))return!0;r=r.next}while(r!==t);return!1}(t,e)&&(qo(t,e)&&qo(e,t)&&function(t,e){var r=t,n=!1,i=(t.x+e.x)/2,a=(t.y+e.y)/2;do{r.y>a!=r.next.y>a&&r.next.y!==r.y&&i<(r.next.x-r.x)*(a-r.y)/(r.next.y-r.y)+r.x&&(n=!n),r=r.next}while(r!==t);return n}(t,e)&&(Bo(t.prev,t,e.prev)||Bo(t,e.prev,e))||No(t,e)&&Bo(t.prev,t,t.next)>0&&Bo(e.prev,e,e.next)>0)}function Bo(t,e,r){return(e.y-t.y)*(r.x-e.x)-(e.x-t.x)*(r.y-e.y)}function No(t,e){return t.x===e.x&&t.y===e.y}function jo(t,e,r,n){var i=Vo(Bo(t,e,r)),a=Vo(Bo(t,e,n)),o=Vo(Bo(r,n,t)),s=Vo(Bo(r,n,e));return i!==a&&o!==s||!(0!==i||!Uo(t,r,e))||!(0!==a||!Uo(t,n,e))||!(0!==o||!Uo(r,t,n))||!(0!==s||!Uo(r,e,n))}function Uo(t,e,r){return e.x<=Math.max(t.x,r.x)&&e.x>=Math.min(t.x,r.x)&&e.y<=Math.max(t.y,r.y)&&e.y>=Math.min(t.y,r.y)}function Vo(t){return t>0?1:t<0?-1:0}function qo(t,e){return Bo(t.prev,t,t.next)<0?Bo(t,e,t.next)>=0&&Bo(t,t.prev,e)>=0:Bo(t,e,t.prev)<0||Bo(t,t.next,e)<0}function Ho(t,e){var r=new Wo(t.i,t.x,t.y),n=new Wo(e.i,e.x,e.y),i=t.next,a=e.prev;return t.next=e,e.prev=t,r.next=i,i.prev=r,n.next=r,r.prev=n,a.next=n,n.prev=a,n}function Go(t,e,r,n){var i=new Wo(t,e,r);return n?(i.next=n.next,i.prev=n,n.next.prev=i,n.next=i):(i.prev=i,i.next=i),i}function Yo(t){t.next.prev=t.prev,t.prev.next=t.next,t.prevZ&&(t.prevZ.nextZ=t.nextZ),t.nextZ&&(t.nextZ.prevZ=t.prevZ)}function Wo(t,e,r){this.i=t,this.x=e,this.y=r,this.prev=null,this.next=null,this.z=null,this.prevZ=null,this.nextZ=null,this.steiner=!1}function Xo(t,e,r,n){for(var i=0,a=e,o=r-n;a<r;a+=n)i+=(t[o]-t[a])*(t[a+1]+t[o+1]),o=a;return i}function Zo(t,e,r,n,i){!function t(e,r,n,i,a){for(;i>n;){if(i-n>600){var o=i-n+1,s=r-n+1,l=Math.log(o),c=.5*Math.exp(2*l/3),u=.5*Math.sqrt(l*c*(o-c)/o)*(s-o/2<0?-1:1);t(e,r,Math.max(n,Math.floor(r-s*c/o+u)),Math.min(i,Math.floor(r+(o-s)*c/o+u)),a)}var f=e[r],h=n,p=i;for(Jo(e,n,r),a(e[i],f)>0&&Jo(e,n,i);h<p;){for(Jo(e,h,p),h++,p--;a(e[h],f)<0;)h++;for(;a(e[p],f)>0;)p--}0===a(e[n],f)?Jo(e,n,p):Jo(e,++p,i),p<=r&&(n=p+1),r<=p&&(i=p-1)}}(t,e,r||0,n||t.length-1,i||Ko)}function Jo(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function Ko(t,e){return t<e?-1:t>e?1:0}function Qo(t,e){var r=t.length;if(r<=1)return[t];for(var n,i,a=[],o=0;o<r;o++){var s=T(t[o]);0!==s&&(t[o].area=Math.abs(s),void 0===i&&(i=s<0),i===s<0?(n&&a.push(n),n=[t[o]]):n.push(t[o]))}if(n&&a.push(n),e>1)for(var l=0;l<a.length;l++)a[l].length<=e||(Zo(a[l],e,1,a[l].length-1,$o),a[l]=a[l].slice(0,e));return a}function $o(t,e){return e.area-t.area}function ts(t,e,r){for(var n=r.patternDependencies,i=!1,a=0,o=e;a<o.length;a+=1){var s=o[a].paint.get(t+\"-pattern\");s.isConstant()||(i=!0);var l=s.constantOr(null);l&&(i=!0,n[l.to]=!0,n[l.from]=!0)}return i}function es(t,e,r,n,i){for(var a=i.patternDependencies,o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.paint.get(t+\"-pattern\").value;if(\"constant\"!==c.kind){var u=c.evaluate({zoom:n-1},r,{},i.availableImages),f=c.evaluate({zoom:n},r,{},i.availableImages),h=c.evaluate({zoom:n+1},r,{},i.availableImages);f=f&&f.name?f.name:f,h=h&&h.name?h.name:h,a[u=u&&u.name?u.name:u]=!0,a[f]=!0,a[h]=!0,r.patterns[l.id]={min:u,mid:f,max:h}}}return r}To.deviation=function(t,e,r,n){var i=e&&e.length,a=Math.abs(Xo(t,0,i?e[0]*r:t.length,r));if(i)for(var o=0,s=e.length;o<s;o++)a-=Math.abs(Xo(t,e[o]*r,o<s-1?e[o+1]*r:t.length,r));var l=0;for(o=0;o<n.length;o+=3){var c=n[o]*r,u=n[o+1]*r,f=n[o+2]*r;l+=Math.abs((t[c]-t[f])*(t[u+1]-t[c+1])-(t[c]-t[u])*(t[f+1]-t[c+1]))}return 0===a&&0===l?0:Math.abs((l-a)/a)},To.flatten=function(t){for(var e=t[0][0].length,r={vertices:[],holes:[],dimensions:e},n=0,i=0;i<t.length;i++){for(var a=0;a<t[i].length;a++)for(var o=0;o<e;o++)r.vertices.push(t[i][a][o]);i>0&&r.holes.push(n+=t[i-1].length)}return r},_o.default=wo;var rs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Mi,this.indexArray=new Fi,this.indexArray2=new qi,this.programConfigurations=new Ia(bo,t.layers,t.zoom),this.segments=new ia,this.segments2=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};rs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"fill\",this.layers,e);for(var n=this.layers[0].layout.get(\"fill-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r,e.availableImages):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"fill\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},rs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},rs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},rs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},rs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},rs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,bo),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.indexBuffer2=t.createIndexBuffer(this.indexArray2)),this.programConfigurations.upload(t),this.uploaded=!0},rs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.indexBuffer2.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.segments2.destroy())},rs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray),h=f.vertexLength,p=[],d=[],g=0,m=s;g<m.length;g+=1){var v=m[g];if(0!==v.length){v!==s[0]&&d.push(p.length/2);var y=this.segments2.prepareSegment(v.length,this.layoutVertexArray,this.indexArray2),x=y.vertexLength;this.layoutVertexArray.emplaceBack(v[0].x,v[0].y),this.indexArray2.emplaceBack(x+v.length-1,x),p.push(v[0].x),p.push(v[0].y);for(var b=1;b<v.length;b++)this.layoutVertexArray.emplaceBack(v[b].x,v[b].y),this.indexArray2.emplaceBack(x+b-1,x+b),p.push(v[b].x),p.push(v[b].y);y.vertexLength+=v.length,y.primitiveLength+=v.length}}for(var _=_o(p,d),w=0;w<_.length;w+=3)this.indexArray.emplaceBack(h+_[w],h+_[w+1],h+_[w+2]);f.vertexLength+=l,f.primitiveLength+=_.length/3}this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillBucket\",rs,{omit:[\"layers\",\"patternFeatures\"]});var ns=new yi({\"fill-sort-key\":new di(At.layout_fill[\"fill-sort-key\"])}),is={paint:new yi({\"fill-antialias\":new pi(At.paint_fill[\"fill-antialias\"]),\"fill-opacity\":new di(At.paint_fill[\"fill-opacity\"]),\"fill-color\":new di(At.paint_fill[\"fill-color\"]),\"fill-outline-color\":new di(At.paint_fill[\"fill-outline-color\"]),\"fill-translate\":new pi(At.paint_fill[\"fill-translate\"]),\"fill-translate-anchor\":new pi(At.paint_fill[\"fill-translate-anchor\"]),\"fill-pattern\":new gi(At.paint_fill[\"fill-pattern\"])}),layout:ns},as=function(t){function e(e){t.call(this,e,is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r);var n=this.paint._values[\"fill-outline-color\"];\"constant\"===n.value.kind&&void 0===n.value.value&&(this.paint._values[\"fill-outline-color\"]=this.paint._values[\"fill-color\"])},e.prototype.createBucket=function(t){return new rs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,i,a,o){return ja(Ka(t,this.paint.get(\"fill-translate\"),this.paint.get(\"fill-translate-anchor\"),a.angle,o),n)},e.prototype.isTileClipped=function(){return!0},e}(xi),os=Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_normal_ed\",components:4,type:\"Int16\"}],4).members,ss=ls;function ls(t,e,r,n,i){this.properties={},this.extent=r,this.type=0,this._pbf=t,this._geometry=-1,this._keys=n,this._values=i,t.readFields(cs,this,e)}function cs(t,e,r){1==t?e.id=r.readVarint():2==t?function(t,e){for(var r=t.readVarint()+t.pos;t.pos<r;){var n=e._keys[t.readVarint()],i=e._values[t.readVarint()];e.properties[n]=i}}(r,e):3==t?e.type=r.readVarint():4==t&&(e._geometry=r.pos)}function us(t){for(var e,r,n=0,i=0,a=t.length,o=a-1;i<a;o=i++)n+=((r=t[o]).x-(e=t[i]).x)*(e.y+r.y);return n}ls.types=[\"Unknown\",\"Point\",\"LineString\",\"Polygon\"],ls.prototype.loadGeometry=function(){var t=this._pbf;t.pos=this._geometry;for(var e,r=t.readVarint()+t.pos,n=1,a=0,o=0,s=0,l=[];t.pos<r;){if(a<=0){var c=t.readVarint();n=7&c,a=c>>3}if(a--,1===n||2===n)o+=t.readSVarint(),s+=t.readSVarint(),1===n&&(e&&l.push(e),e=[]),e.push(new i(o,s));else{if(7!==n)throw new Error(\"unknown command \"+n);e&&e.push(e[0].clone())}}return e&&l.push(e),l},ls.prototype.bbox=function(){var t=this._pbf;t.pos=this._geometry;for(var e=t.readVarint()+t.pos,r=1,n=0,i=0,a=0,o=1/0,s=-1/0,l=1/0,c=-1/0;t.pos<e;){if(n<=0){var u=t.readVarint();r=7&u,n=u>>3}if(n--,1===r||2===r)(i+=t.readSVarint())<o&&(o=i),i>s&&(s=i),(a+=t.readSVarint())<l&&(l=a),a>c&&(c=a);else if(7!==r)throw new Error(\"unknown command \"+r)}return[o,l,s,c]},ls.prototype.toGeoJSON=function(t,e,r){var n,i,a=this.extent*Math.pow(2,r),o=this.extent*t,s=this.extent*e,l=this.loadGeometry(),c=ls.types[this.type];function u(t){for(var e=0;e<t.length;e++){var r=t[e];t[e]=[360*(r.x+o)/a-180,360/Math.PI*Math.atan(Math.exp((180-360*(r.y+s)/a)*Math.PI/180))-90]}}switch(this.type){case 1:var f=[];for(n=0;n<l.length;n++)f[n]=l[n][0];u(l=f);break;case 2:for(n=0;n<l.length;n++)u(l[n]);break;case 3:for(l=function(t){var e=t.length;if(e<=1)return[t];for(var r,n,i=[],a=0;a<e;a++){var o=us(t[a]);0!==o&&(void 0===n&&(n=o<0),n===o<0?(r&&i.push(r),r=[t[a]]):r.push(t[a]))}return r&&i.push(r),i}(l),n=0;n<l.length;n++)for(i=0;i<l[n].length;i++)u(l[n][i])}1===l.length?l=l[0]:c=\"Multi\"+c;var h={type:\"Feature\",geometry:{type:c,coordinates:l},properties:this.properties};return\"id\"in this&&(h.id=this.id),h};var fs=hs;function hs(t,e){this.version=1,this.name=null,this.extent=4096,this.length=0,this._pbf=t,this._keys=[],this._values=[],this._features=[],t.readFields(ps,this,e),this.length=this._features.length}function ps(t,e,r){15===t?e.version=r.readVarint():1===t?e.name=r.readString():5===t?e.extent=r.readVarint():2===t?e._features.push(r.pos):3===t?e._keys.push(r.readString()):4===t&&e._values.push(function(t){for(var e=null,r=t.readVarint()+t.pos;t.pos<r;){var n=t.readVarint()>>3;e=1===n?t.readString():2===n?t.readFloat():3===n?t.readDouble():4===n?t.readVarint64():5===n?t.readVarint():6===n?t.readSVarint():7===n?t.readBoolean():null}return e}(r))}function ds(t,e,r){if(3===t){var n=new fs(r,r.readVarint()+r.pos);n.length&&(e[n.name]=n)}}hs.prototype.feature=function(t){if(t<0||t>=this._features.length)throw new Error(\"feature index out of bounds\");this._pbf.pos=this._features[t];var e=this._pbf.readVarint()+this._pbf.pos;return new ss(this._pbf,e,this.extent,this._keys,this._values)};var gs={VectorTile:function(t,e){this.layers=t.readFields(ds,{},e)},VectorTileFeature:ss,VectorTileLayer:fs},ms=gs.VectorTileFeature.types,vs=Math.pow(2,13);function ys(t,e,r,n,i,a,o,s){t.emplaceBack(e,r,2*Math.floor(n*vs)+o,i*vs*2,a*vs*2,Math.round(s))}var xs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.layoutVertexArray=new Si,this.indexArray=new Fi,this.programConfigurations=new Ia(os,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};function bs(t,e){return t.x===e.x&&(t.x<0||t.x>8192)||t.y===e.y&&(t.y<0||t.y>8192)}xs.prototype.populate=function(t,e,r){this.features=[],this.hasPattern=ts(\"fill-extrusion\",this.layers,e);for(var n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.feature,s=a.id,l=a.index,c=a.sourceLayerIndex,u=this.layers[0]._featureFilter.needGeometry,f={type:o.type,id:s,properties:o.properties,geometry:u?Da(o):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),f,r)){var h={id:s,sourceLayerIndex:c,index:l,geometry:u?f.geometry:Da(o),properties:o.properties,type:o.type,patterns:{}};void 0!==o.id&&(h.id=o.id),this.hasPattern?this.features.push(es(\"fill-extrusion\",this.layers,h,this.zoom,e)):this.addFeature(h,h.geometry,l,r,{}),e.featureIndex.insert(o,h.geometry,l,c,this.index,!0)}}},xs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.features;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},xs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},xs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},xs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},xs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,os),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},xs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},xs.prototype.addFeature=function(t,e,r,n,i){for(var a=0,o=Qo(e,500);a<o.length;a+=1){for(var s=o[a],l=0,c=0,u=s;c<u.length;c+=1)l+=u[c].length;for(var f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray),h=0,p=s;h<p.length;h+=1){var d=p[h];if(0!==d.length&&!((P=d).every((function(t){return t.x<0}))||P.every((function(t){return t.x>8192}))||P.every((function(t){return t.y<0}))||P.every((function(t){return t.y>8192}))))for(var g=0,m=0;m<d.length;m++){var v=d[m];if(m>=1){var y=d[m-1];if(!bs(v,y)){f.vertexLength+4>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(4,this.layoutVertexArray,this.indexArray));var x=v.sub(y)._perp()._unit(),b=y.dist(v);g+b>32768&&(g=0),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,0,g),ys(this.layoutVertexArray,v.x,v.y,x.x,x.y,0,1,g),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,0,g+=b),ys(this.layoutVertexArray,y.x,y.y,x.x,x.y,0,1,g);var _=f.vertexLength;this.indexArray.emplaceBack(_,_+2,_+1),this.indexArray.emplaceBack(_+1,_+2,_+3),f.vertexLength+=4,f.primitiveLength+=2}}}}if(f.vertexLength+l>ia.MAX_VERTEX_ARRAY_LENGTH&&(f=this.segments.prepareSegment(l,this.layoutVertexArray,this.indexArray)),\"Polygon\"===ms[t.type]){for(var w=[],T=[],k=f.vertexLength,M=0,A=s;M<A.length;M+=1){var S=A[M];if(0!==S.length){S!==s[0]&&T.push(w.length/2);for(var E=0;E<S.length;E++){var C=S[E];ys(this.layoutVertexArray,C.x,C.y,0,0,1,1,0),w.push(C.x),w.push(C.y)}}}for(var L=_o(w,T),I=0;I<L.length;I+=3)this.indexArray.emplaceBack(k+L[I],k+L[I+2],k+L[I+1]);f.primitiveLength+=L.length/3,f.vertexLength+=l}}var P;this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Dn(\"FillExtrusionBucket\",xs,{omit:[\"layers\",\"features\"]});var _s={paint:new yi({\"fill-extrusion-opacity\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-opacity\"]),\"fill-extrusion-color\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-color\"]),\"fill-extrusion-translate\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate\"]),\"fill-extrusion-translate-anchor\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-translate-anchor\"]),\"fill-extrusion-pattern\":new gi(At[\"paint_fill-extrusion\"][\"fill-extrusion-pattern\"]),\"fill-extrusion-height\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-height\"]),\"fill-extrusion-base\":new di(At[\"paint_fill-extrusion\"][\"fill-extrusion-base\"]),\"fill-extrusion-vertical-gradient\":new pi(At[\"paint_fill-extrusion\"][\"fill-extrusion-vertical-gradient\"])})},ws=function(t){function e(e){t.call(this,e,_s)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.createBucket=function(t){return new xs(t)},e.prototype.queryRadius=function(){return Ja(this.paint.get(\"fill-extrusion-translate\"))},e.prototype.is3D=function(){return!0},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s,l){var c=Ka(t,this.paint.get(\"fill-extrusion-translate\"),this.paint.get(\"fill-extrusion-translate-anchor\"),o.angle,s),u=this.paint.get(\"fill-extrusion-height\").evaluate(e,r),f=this.paint.get(\"fill-extrusion-base\").evaluate(e,r),h=function(t,e,r,n){for(var a=[],o=0,s=t;o<s.length;o+=1){var l=s[o],c=[l.x,l.y,0,1];ao(c,c,e),a.push(new i(c[0]/c[3],c[1]/c[3]))}return a}(c,l),p=function(t,e,r,n){for(var a=[],o=[],s=n[8]*e,l=n[9]*e,c=n[10]*e,u=n[11]*e,f=n[8]*r,h=n[9]*r,p=n[10]*r,d=n[11]*r,g=0,m=t;g<m.length;g+=1){for(var v=[],y=[],x=0,b=m[g];x<b.length;x+=1){var _=b[x],w=_.x,T=_.y,k=n[0]*w+n[4]*T+n[12],M=n[1]*w+n[5]*T+n[13],A=n[2]*w+n[6]*T+n[14],S=n[3]*w+n[7]*T+n[15],E=A+c,C=S+u,L=k+f,I=M+h,P=A+p,z=S+d,O=new i((k+s)/C,(M+l)/C);O.z=E/C,v.push(O);var D=new i(L/z,I/z);D.z=P/z,y.push(D)}a.push(v),o.push(y)}return[a,o]}(n,f,u,l);return function(t,e,r){var n=1/0;ja(r,e)&&(n=ks(r,e[0]));for(var i=0;i<e.length;i++)for(var a=e[i],o=t[i],s=0;s<a.length-1;s++){var l=a[s],c=[l,a[s+1],o[s+1],o[s],l];Ba(r,c)&&(n=Math.min(n,ks(r,c)))}return n!==1/0&&n}(p[0],p[1],h)},e}(xi);function Ts(t,e){return t.x*e.x+t.y*e.y}function ks(t,e){if(1===t.length){for(var r,n=0,i=e[n++];!r||i.equals(r);)if(!(r=e[n++]))return 1/0;for(;n<e.length;n++){var a=e[n],o=t[0],s=r.sub(i),l=a.sub(i),c=o.sub(i),u=Ts(s,s),f=Ts(s,l),h=Ts(l,l),p=Ts(c,s),d=Ts(c,l),g=u*h-f*f,m=(h*p-f*d)/g,v=(u*d-f*p)/g,y=i.z*(1-m-v)+r.z*m+a.z*v;if(isFinite(y))return y}return 1/0}for(var x=1/0,b=0,_=e;b<_.length;b+=1)x=Math.min(x,_[b].z);return x}var Ms=Ti([{name:\"a_pos_normal\",components:2,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint8\"}],4).members,As=gs.VectorTileFeature.types,Ss=Math.cos(Math.PI/180*37.5),Es=Math.pow(2,14)/.5,Cs=function(t){this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.hasPattern=!1,this.patternFeatures=[],this.layoutVertexArray=new Ei,this.indexArray=new Fi,this.programConfigurations=new Ia(Ms,t.layers,t.zoom),this.segments=new ia,this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id}))};Cs.prototype.populate=function(t,e,r){this.hasPattern=ts(\"line\",this.layers,e);for(var n=this.layers[0].layout.get(\"line-sort-key\"),i=[],a=0,o=t;a<o.length;a+=1){var s=o[a],l=s.feature,c=s.id,u=s.index,f=s.sourceLayerIndex,h=this.layers[0]._featureFilter.needGeometry,p={type:l.type,id:c,properties:l.properties,geometry:h?Da(l):[]};if(this.layers[0]._featureFilter.filter(new ii(this.zoom),p,r)){h||(p.geometry=Da(l));var d=n?n.evaluate(p,{},r):void 0;i.push({id:c,properties:l.properties,type:l.type,sourceLayerIndex:f,index:u,geometry:p.geometry,patterns:{},sortKey:d})}}n&&i.sort((function(t,e){return t.sortKey-e.sortKey}));for(var g=0,m=i;g<m.length;g+=1){var v=m[g],y=v.geometry,x=v.index,b=v.sourceLayerIndex;if(this.hasPattern){var _=es(\"line\",this.layers,v,this.zoom,e);this.patternFeatures.push(_)}else this.addFeature(v,y,x,r,{});e.featureIndex.insert(t[x].feature,y,x,b,this.index)}},Cs.prototype.update=function(t,e,r){this.stateDependentLayers.length&&this.programConfigurations.updatePaintArrays(t,e,this.stateDependentLayers,r)},Cs.prototype.addFeatures=function(t,e,r){for(var n=0,i=this.patternFeatures;n<i.length;n+=1){var a=i[n];this.addFeature(a,a.geometry,a.index,e,r)}},Cs.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length},Cs.prototype.uploadPending=function(){return!this.uploaded||this.programConfigurations.needsUpload},Cs.prototype.upload=function(t){this.uploaded||(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ms),this.indexBuffer=t.createIndexBuffer(this.indexArray)),this.programConfigurations.upload(t),this.uploaded=!0},Cs.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy())},Cs.prototype.addFeature=function(t,e,r,n,i){for(var a=this.layers[0].layout,o=a.get(\"line-join\").evaluate(t,{}),s=a.get(\"line-cap\"),l=a.get(\"line-miter-limit\"),c=a.get(\"line-round-limit\"),u=0,f=e;u<f.length;u+=1)this.addLine(f[u],t,o,s,l,c);this.programConfigurations.populatePaintArrays(this.layoutVertexArray.length,t,r,i,n)},Cs.prototype.addLine=function(t,e,r,n,i,a){if(this.distance=0,this.scaledDistance=0,this.totalDistance=0,e.properties&&e.properties.hasOwnProperty(\"mapbox_clip_start\")&&e.properties.hasOwnProperty(\"mapbox_clip_end\")){this.clipStart=+e.properties.mapbox_clip_start,this.clipEnd=+e.properties.mapbox_clip_end;for(var o=0;o<t.length-1;o++)this.totalDistance+=t[o].dist(t[o+1]);this.updateScaledDistance()}for(var s=\"Polygon\"===As[e.type],l=t.length;l>=2&&t[l-1].equals(t[l-2]);)l--;for(var c=0;c<l-1&&t[c].equals(t[c+1]);)c++;if(!(l<(s?3:2))){\"bevel\"===r&&(i=1.05);var u,f=this.overscaling<=16?122880/(512*this.overscaling):0,h=this.segments.prepareSegment(10*l,this.layoutVertexArray,this.indexArray),p=void 0,d=void 0,g=void 0,m=void 0;this.e1=this.e2=-1,s&&(m=t[c].sub(u=t[l-2])._unit()._perp());for(var v=c;v<l;v++)if(!(d=v===l-1?s?t[c+1]:void 0:t[v+1])||!t[v].equals(d)){m&&(g=m),u&&(p=u),u=t[v],m=d?d.sub(u)._unit()._perp():g;var y=(g=g||m).add(m);0===y.x&&0===y.y||y._unit();var x=g.x*m.x+g.y*m.y,b=y.x*m.x+y.y*m.y,_=0!==b?1/b:1/0,w=2*Math.sqrt(2-2*b),T=b<Ss&&p&&d,k=g.x*m.y-g.y*m.x>0;if(T&&v>c){var M=u.dist(p);if(M>2*f){var A=u.sub(u.sub(p)._mult(f/M)._round());this.updateDistance(p,A),this.addCurrentVertex(A,g,0,0,h),p=A}}var S=p&&d,E=S?r:s?\"butt\":n;if(S&&\"round\"===E&&(_<a?E=\"miter\":_<=2&&(E=\"fakeround\")),\"miter\"===E&&_>i&&(E=\"bevel\"),\"bevel\"===E&&(_>2&&(E=\"flipbevel\"),_<i&&(E=\"miter\")),p&&this.updateDistance(p,u),\"miter\"===E)y._mult(_),this.addCurrentVertex(u,y,0,0,h);else if(\"flipbevel\"===E){if(_>100)y=m.mult(-1);else{var C=_*g.add(m).mag()/g.sub(m).mag();y._perp()._mult(C*(k?-1:1))}this.addCurrentVertex(u,y,0,0,h),this.addCurrentVertex(u,y.mult(-1),0,0,h)}else if(\"bevel\"===E||\"fakeround\"===E){var L=-Math.sqrt(_*_-1),I=k?L:0,P=k?0:L;if(p&&this.addCurrentVertex(u,g,I,P,h),\"fakeround\"===E)for(var z=Math.round(180*w/Math.PI/20),O=1;O<z;O++){var D=O/z;if(.5!==D){var R=D-.5;D+=D*R*(D-1)*((1.0904+x*(x*(3.55645-1.43519*x)-3.2452))*R*R+(.848013+x*(.215638*x-1.06021)))}var F=m.sub(g)._mult(D)._add(g)._unit()._mult(k?-1:1);this.addHalfVertex(u,F.x,F.y,!1,k,0,h)}d&&this.addCurrentVertex(u,m,-I,-P,h)}else if(\"butt\"===E)this.addCurrentVertex(u,y,0,0,h);else if(\"square\"===E){var B=p?1:-1;this.addCurrentVertex(u,y,B,B,h)}else\"round\"===E&&(p&&(this.addCurrentVertex(u,g,0,0,h),this.addCurrentVertex(u,g,1,1,h,!0)),d&&(this.addCurrentVertex(u,m,-1,-1,h,!0),this.addCurrentVertex(u,m,0,0,h)));if(T&&v<l-1){var N=u.dist(d);if(N>2*f){var j=u.add(d.sub(u)._mult(f/N)._round());this.updateDistance(u,j),this.addCurrentVertex(j,m,0,0,h),u=j}}}}},Cs.prototype.addCurrentVertex=function(t,e,r,n,i,a){void 0===a&&(a=!1);var o=e.y*n-e.x,s=-e.y-e.x*n;this.addHalfVertex(t,e.x+e.y*r,e.y-e.x*r,a,!1,r,i),this.addHalfVertex(t,o,s,a,!0,-n,i),this.distance>Es/2&&0===this.totalDistance&&(this.distance=0,this.addCurrentVertex(t,e,r,n,i,a))},Cs.prototype.addHalfVertex=function(t,e,r,n,i,a,o){var s=.5*this.scaledDistance;this.layoutVertexArray.emplaceBack((t.x<<1)+(n?1:0),(t.y<<1)+(i?1:0),Math.round(63*e)+128,Math.round(63*r)+128,1+(0===a?0:a<0?-1:1)|(63&s)<<2,s>>6);var l=o.vertexLength++;this.e1>=0&&this.e2>=0&&(this.indexArray.emplaceBack(this.e1,this.e2,l),o.primitiveLength++),i?this.e2=l:this.e1=l},Cs.prototype.updateScaledDistance=function(){this.scaledDistance=this.totalDistance>0?(this.clipStart+(this.clipEnd-this.clipStart)*this.distance/this.totalDistance)*(Es-1):this.distance},Cs.prototype.updateDistance=function(t,e){this.distance+=t.dist(e),this.updateScaledDistance()},Dn(\"LineBucket\",Cs,{omit:[\"layers\",\"patternFeatures\"]});var Ls=new yi({\"line-cap\":new pi(At.layout_line[\"line-cap\"]),\"line-join\":new di(At.layout_line[\"line-join\"]),\"line-miter-limit\":new pi(At.layout_line[\"line-miter-limit\"]),\"line-round-limit\":new pi(At.layout_line[\"line-round-limit\"]),\"line-sort-key\":new di(At.layout_line[\"line-sort-key\"])}),Is={paint:new yi({\"line-opacity\":new di(At.paint_line[\"line-opacity\"]),\"line-color\":new di(At.paint_line[\"line-color\"]),\"line-translate\":new pi(At.paint_line[\"line-translate\"]),\"line-translate-anchor\":new pi(At.paint_line[\"line-translate-anchor\"]),\"line-width\":new di(At.paint_line[\"line-width\"]),\"line-gap-width\":new di(At.paint_line[\"line-gap-width\"]),\"line-offset\":new di(At.paint_line[\"line-offset\"]),\"line-blur\":new di(At.paint_line[\"line-blur\"]),\"line-dasharray\":new mi(At.paint_line[\"line-dasharray\"]),\"line-pattern\":new gi(At.paint_line[\"line-pattern\"]),\"line-gradient\":new vi(At.paint_line[\"line-gradient\"])}),layout:Ls},Ps=new(function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.possiblyEvaluate=function(e,r){return r=new ii(Math.floor(r.zoom),{now:r.now,fadeDuration:r.fadeDuration,zoomHistory:r.zoomHistory,transition:r.transition}),t.prototype.possiblyEvaluate.call(this,e,r)},e.prototype.evaluate=function(e,r,n,i){return r=u({},r,{zoom:Math.floor(r.zoom)}),t.prototype.evaluate.call(this,e,r,n,i)},e}(di))(Is.paint.properties[\"line-width\"].specification);Ps.useIntegerZoom=!0;var zs=function(t){function e(e){t.call(this,e,Is)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._handleSpecialPaintPropertyUpdate=function(t){\"line-gradient\"===t&&this._updateGradient()},e.prototype._updateGradient=function(){this.gradient=mo(this._transitionablePaint._values[\"line-gradient\"].value.expression,\"lineProgress\"),this.gradientTexture=null},e.prototype.recalculate=function(e,r){t.prototype.recalculate.call(this,e,r),this.paint._values[\"line-floorwidth\"]=Ps.possiblyEvaluate(this._transitioningPaint._values[\"line-width\"].value,e)},e.prototype.createBucket=function(t){return new Cs(t)},e.prototype.queryRadius=function(t){var e=t,r=Os(Za(\"line-width\",this,e),Za(\"line-gap-width\",this,e)),n=Za(\"line-offset\",this,e);return r/2+Math.abs(n)+Ja(this.paint.get(\"line-translate\"))},e.prototype.queryIntersectsFeature=function(t,e,r,n,a,o,s){var l=Ka(t,this.paint.get(\"line-translate\"),this.paint.get(\"line-translate-anchor\"),o.angle,s),c=s/2*Os(this.paint.get(\"line-width\").evaluate(e,r),this.paint.get(\"line-gap-width\").evaluate(e,r)),u=this.paint.get(\"line-offset\").evaluate(e,r);return u&&(n=function(t,e){for(var r=[],n=new i(0,0),a=0;a<t.length;a++){for(var o=t[a],s=[],l=0;l<o.length;l++){var c=o[l],u=o[l+1],f=0===l?n:c.sub(o[l-1])._unit()._perp(),h=l===o.length-1?n:u.sub(c)._unit()._perp(),p=f._add(h)._unit();p._mult(1/(p.x*h.x+p.y*h.y)),s.push(p._mult(e)._add(c))}r.push(s)}return r}(n,u*s)),function(t,e,r){for(var n=0;n<e.length;n++){var i=e[n];if(t.length>=3)for(var a=0;a<i.length;a++)if(Wa(t,i[a]))return!0;if(Ua(t,i,r))return!0}return!1}(l,n,c)},e.prototype.isTileClipped=function(){return!0},e}(xi);function Os(t,e){return e>0?e+2*t:t}var Ds=Ti([{name:\"a_pos_offset\",components:4,type:\"Int16\"},{name:\"a_data\",components:4,type:\"Uint16\"},{name:\"a_pixeloffset\",components:4,type:\"Int16\"}],4),Rs=Ti([{name:\"a_projected_pos\",components:3,type:\"Float32\"}],4),Fs=(Ti([{name:\"a_fade_opacity\",components:1,type:\"Uint32\"}],4),Ti([{name:\"a_placed\",components:2,type:\"Uint8\"},{name:\"a_shift\",components:2,type:\"Float32\"}])),Bs=(Ti([{type:\"Int16\",name:\"anchorPointX\"},{type:\"Int16\",name:\"anchorPointY\"},{type:\"Int16\",name:\"x1\"},{type:\"Int16\",name:\"y1\"},{type:\"Int16\",name:\"x2\"},{type:\"Int16\",name:\"y2\"},{type:\"Uint32\",name:\"featureIndex\"},{type:\"Uint16\",name:\"sourceLayerIndex\"},{type:\"Uint16\",name:\"bucketIndex\"}]),Ti([{name:\"a_pos\",components:2,type:\"Int16\"},{name:\"a_anchor_pos\",components:2,type:\"Int16\"},{name:\"a_extrude\",components:2,type:\"Int16\"}],4)),Ns=Ti([{name:\"a_pos\",components:2,type:\"Float32\"},{name:\"a_radius\",components:1,type:\"Float32\"},{name:\"a_flags\",components:2,type:\"Int16\"}],4);function js(t,e,r){return t.sections.forEach((function(t){t.text=function(t,e,r){var n=e.layout.get(\"text-transform\").evaluate(r,{});return\"uppercase\"===n?t=t.toLocaleUpperCase():\"lowercase\"===n&&(t=t.toLocaleLowerCase()),ni.applyArabicShaping&&(t=ni.applyArabicShaping(t)),t}(t.text,e,r)})),t}Ti([{name:\"triangle\",components:3,type:\"Uint16\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Uint16\",name:\"glyphStartIndex\"},{type:\"Uint16\",name:\"numGlyphs\"},{type:\"Uint32\",name:\"vertexStartIndex\"},{type:\"Uint32\",name:\"lineStartIndex\"},{type:\"Uint32\",name:\"lineLength\"},{type:\"Uint16\",name:\"segment\"},{type:\"Uint16\",name:\"lowerSize\"},{type:\"Uint16\",name:\"upperSize\"},{type:\"Float32\",name:\"lineOffsetX\"},{type:\"Float32\",name:\"lineOffsetY\"},{type:\"Uint8\",name:\"writingMode\"},{type:\"Uint8\",name:\"placedOrientation\"},{type:\"Uint8\",name:\"hidden\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Int16\",name:\"associatedIconIndex\"}]),Ti([{type:\"Int16\",name:\"anchorX\"},{type:\"Int16\",name:\"anchorY\"},{type:\"Int16\",name:\"rightJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"centerJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"leftJustifiedTextSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedTextSymbolIndex\"},{type:\"Int16\",name:\"placedIconSymbolIndex\"},{type:\"Int16\",name:\"verticalPlacedIconSymbolIndex\"},{type:\"Uint16\",name:\"key\"},{type:\"Uint16\",name:\"textBoxStartIndex\"},{type:\"Uint16\",name:\"textBoxEndIndex\"},{type:\"Uint16\",name:\"verticalTextBoxStartIndex\"},{type:\"Uint16\",name:\"verticalTextBoxEndIndex\"},{type:\"Uint16\",name:\"iconBoxStartIndex\"},{type:\"Uint16\",name:\"iconBoxEndIndex\"},{type:\"Uint16\",name:\"verticalIconBoxStartIndex\"},{type:\"Uint16\",name:\"verticalIconBoxEndIndex\"},{type:\"Uint16\",name:\"featureIndex\"},{type:\"Uint16\",name:\"numHorizontalGlyphVertices\"},{type:\"Uint16\",name:\"numVerticalGlyphVertices\"},{type:\"Uint16\",name:\"numIconVertices\"},{type:\"Uint16\",name:\"numVerticalIconVertices\"},{type:\"Uint16\",name:\"useRuntimeCollisionCircles\"},{type:\"Uint32\",name:\"crossTileID\"},{type:\"Float32\",name:\"textBoxScale\"},{type:\"Float32\",components:2,name:\"textOffset\"},{type:\"Float32\",name:\"collisionCircleDiameter\"}]),Ti([{type:\"Float32\",name:\"offsetX\"}]),Ti([{type:\"Int16\",name:\"x\"},{type:\"Int16\",name:\"y\"},{type:\"Int16\",name:\"tileUnitDistanceFromAnchor\"}]);var Us={\"!\":\"\\ufe15\",\"#\":\"\\uff03\",$:\"\\uff04\",\"%\":\"\\uff05\",\"&\":\"\\uff06\",\"(\":\"\\ufe35\",\")\":\"\\ufe36\",\"*\":\"\\uff0a\",\"+\":\"\\uff0b\",\",\":\"\\ufe10\",\"-\":\"\\ufe32\",\".\":\"\\u30fb\",\"/\":\"\\uff0f\",\":\":\"\\ufe13\",\";\":\"\\ufe14\",\"<\":\"\\ufe3f\",\"=\":\"\\uff1d\",\">\":\"\\ufe40\",\"?\":\"\\ufe16\",\"@\":\"\\uff20\",\"[\":\"\\ufe47\",\"\\\\\":\"\\uff3c\",\"]\":\"\\ufe48\",\"^\":\"\\uff3e\",_:\"\\ufe33\",\"`\":\"\\uff40\",\"{\":\"\\ufe37\",\"|\":\"\\u2015\",\"}\":\"\\ufe38\",\"~\":\"\\uff5e\",\"\\xa2\":\"\\uffe0\",\"\\xa3\":\"\\uffe1\",\"\\xa5\":\"\\uffe5\",\"\\xa6\":\"\\uffe4\",\"\\xac\":\"\\uffe2\",\"\\xaf\":\"\\uffe3\",\"\\u2013\":\"\\ufe32\",\"\\u2014\":\"\\ufe31\",\"\\u2018\":\"\\ufe43\",\"\\u2019\":\"\\ufe44\",\"\\u201c\":\"\\ufe41\",\"\\u201d\":\"\\ufe42\",\"\\u2026\":\"\\ufe19\",\"\\u2027\":\"\\u30fb\",\"\\u20a9\":\"\\uffe6\",\"\\u3001\":\"\\ufe11\",\"\\u3002\":\"\\ufe12\",\"\\u3008\":\"\\ufe3f\",\"\\u3009\":\"\\ufe40\",\"\\u300a\":\"\\ufe3d\",\"\\u300b\":\"\\ufe3e\",\"\\u300c\":\"\\ufe41\",\"\\u300d\":\"\\ufe42\",\"\\u300e\":\"\\ufe43\",\"\\u300f\":\"\\ufe44\",\"\\u3010\":\"\\ufe3b\",\"\\u3011\":\"\\ufe3c\",\"\\u3014\":\"\\ufe39\",\"\\u3015\":\"\\ufe3a\",\"\\u3016\":\"\\ufe17\",\"\\u3017\":\"\\ufe18\",\"\\uff01\":\"\\ufe15\",\"\\uff08\":\"\\ufe35\",\"\\uff09\":\"\\ufe36\",\"\\uff0c\":\"\\ufe10\",\"\\uff0d\":\"\\ufe32\",\"\\uff0e\":\"\\u30fb\",\"\\uff1a\":\"\\ufe13\",\"\\uff1b\":\"\\ufe14\",\"\\uff1c\":\"\\ufe3f\",\"\\uff1e\":\"\\ufe40\",\"\\uff1f\":\"\\ufe16\",\"\\uff3b\":\"\\ufe47\",\"\\uff3d\":\"\\ufe48\",\"\\uff3f\":\"\\ufe33\",\"\\uff5b\":\"\\ufe37\",\"\\uff5c\":\"\\u2015\",\"\\uff5d\":\"\\ufe38\",\"\\uff5f\":\"\\ufe35\",\"\\uff60\":\"\\ufe36\",\"\\uff61\":\"\\ufe12\",\"\\uff62\":\"\\ufe41\",\"\\uff63\":\"\\ufe42\"},Vs=function(t,e,r,n,i){var a,o,s=8*i-n-1,l=(1<<s)-1,c=l>>1,u=-7,f=r?i-1:0,h=r?-1:1,p=t[e+f];for(f+=h,a=p&(1<<-u)-1,p>>=-u,u+=s;u>0;a=256*a+t[e+f],f+=h,u-=8);for(o=a&(1<<-u)-1,a>>=-u,u+=n;u>0;o=256*o+t[e+f],f+=h,u-=8);if(0===a)a=1-c;else{if(a===l)return o?NaN:1/0*(p?-1:1);o+=Math.pow(2,n),a-=c}return(p?-1:1)*o*Math.pow(2,a-n)},qs=function(t,e,r,n,i,a){var o,s,l,c=8*a-i-1,u=(1<<c)-1,f=u>>1,h=23===i?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:a-1,d=n?1:-1,g=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,o=u):(o=Math.floor(Math.log(e)/Math.LN2),e*(l=Math.pow(2,-o))<1&&(o--,l*=2),(e+=o+f>=1?h/l:h*Math.pow(2,1-f))*l>=2&&(o++,l/=2),o+f>=u?(s=0,o=u):o+f>=1?(s=(e*l-1)*Math.pow(2,i),o+=f):(s=e*Math.pow(2,f-1)*Math.pow(2,i),o=0));i>=8;t[r+p]=255&s,p+=d,s/=256,i-=8);for(o=o<<i|s,c+=i;c>0;t[r+p]=255&o,p+=d,o/=256,c-=8);t[r+p-d]|=128*g},Hs=Gs;function Gs(t){this.buf=ArrayBuffer.isView&&ArrayBuffer.isView(t)?t:new Uint8Array(t||0),this.pos=0,this.type=0,this.length=this.buf.length}Gs.Varint=0,Gs.Fixed64=1,Gs.Bytes=2,Gs.Fixed32=5;var Ys=\"undefined\"==typeof TextDecoder?null:new TextDecoder(\"utf8\");function Ws(t){return t.type===Gs.Bytes?t.readVarint()+t.pos:t.pos+1}function Xs(t,e,r){return r?4294967296*e+(t>>>0):4294967296*(e>>>0)+(t>>>0)}function Zs(t,e,r){var n=e<=16383?1:e<=2097151?2:e<=268435455?3:Math.floor(Math.log(e)/(7*Math.LN2));r.realloc(n);for(var i=r.pos-1;i>=t;i--)r.buf[i+n]=r.buf[i]}function Js(t,e){for(var r=0;r<t.length;r++)e.writeVarint(t[r])}function Ks(t,e){for(var r=0;r<t.length;r++)e.writeSVarint(t[r])}function Qs(t,e){for(var r=0;r<t.length;r++)e.writeFloat(t[r])}function $s(t,e){for(var r=0;r<t.length;r++)e.writeDouble(t[r])}function tl(t,e){for(var r=0;r<t.length;r++)e.writeBoolean(t[r])}function el(t,e){for(var r=0;r<t.length;r++)e.writeFixed32(t[r])}function rl(t,e){for(var r=0;r<t.length;r++)e.writeSFixed32(t[r])}function nl(t,e){for(var r=0;r<t.length;r++)e.writeFixed64(t[r])}function il(t,e){for(var r=0;r<t.length;r++)e.writeSFixed64(t[r])}function al(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+16777216*t[e+3]}function ol(t,e,r){t[r]=e,t[r+1]=e>>>8,t[r+2]=e>>>16,t[r+3]=e>>>24}function sl(t,e){return(t[e]|t[e+1]<<8|t[e+2]<<16)+(t[e+3]<<24)}function ll(t,e,r){1===t&&r.readMessage(cl,e)}function cl(t,e,r){if(3===t){var n=r.readMessage(ul,{}),i=n.width,a=n.height,o=n.left,s=n.top,l=n.advance;e.push({id:n.id,bitmap:new ho({width:i+6,height:a+6},n.bitmap),metrics:{width:i,height:a,left:o,top:s,advance:l}})}}function ul(t,e,r){1===t?e.id=r.readVarint():2===t?e.bitmap=r.readBytes():3===t?e.width=r.readVarint():4===t?e.height=r.readVarint():5===t?e.left=r.readSVarint():6===t?e.top=r.readSVarint():7===t&&(e.advance=r.readVarint())}function fl(t){for(var e=0,r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];e+=a.w*a.h,r=Math.max(r,a.w)}t.sort((function(t,e){return e.h-t.h}));for(var o=[{x:0,y:0,w:Math.max(Math.ceil(Math.sqrt(e/.95)),r),h:1/0}],s=0,l=0,c=0,u=t;c<u.length;c+=1)for(var f=u[c],h=o.length-1;h>=0;h--){var p=o[h];if(!(f.w>p.w||f.h>p.h)){if(f.x=p.x,f.y=p.y,l=Math.max(l,f.y+f.h),s=Math.max(s,f.x+f.w),f.w===p.w&&f.h===p.h){var d=o.pop();h<o.length&&(o[h]=d)}else f.h===p.h?(p.x+=f.w,p.w-=f.w):f.w===p.w?(p.y+=f.h,p.h-=f.h):(o.push({x:p.x+f.w,y:p.y,w:p.w-f.w,h:f.h}),p.y+=f.h,p.h-=f.h);break}}return{w:s,h:l,fill:e/(s*l)||0}}Gs.prototype={destroy:function(){this.buf=null},readFields:function(t,e,r){for(r=r||this.length;this.pos<r;){var n=this.readVarint(),i=n>>3,a=this.pos;this.type=7&n,t(i,e,this),this.pos===a&&this.skip(n)}return e},readMessage:function(t,e){return this.readFields(t,e,this.readVarint()+this.pos)},readFixed32:function(){var t=al(this.buf,this.pos);return this.pos+=4,t},readSFixed32:function(){var t=sl(this.buf,this.pos);return this.pos+=4,t},readFixed64:function(){var t=al(this.buf,this.pos)+4294967296*al(this.buf,this.pos+4);return this.pos+=8,t},readSFixed64:function(){var t=al(this.buf,this.pos)+4294967296*sl(this.buf,this.pos+4);return this.pos+=8,t},readFloat:function(){var t=Vs(this.buf,this.pos,!0,23,4);return this.pos+=4,t},readDouble:function(){var t=Vs(this.buf,this.pos,!0,52,8);return this.pos+=8,t},readVarint:function(t){var e,r,n=this.buf;return e=127&(r=n[this.pos++]),r<128?e:(e|=(127&(r=n[this.pos++]))<<7,r<128?e:(e|=(127&(r=n[this.pos++]))<<14,r<128?e:(e|=(127&(r=n[this.pos++]))<<21,r<128?e:function(t,e,r){var n,i,a=r.buf;if(n=(112&(i=a[r.pos++]))>>4,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<3,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<10,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<17,i<128)return Xs(t,n,e);if(n|=(127&(i=a[r.pos++]))<<24,i<128)return Xs(t,n,e);if(n|=(1&(i=a[r.pos++]))<<31,i<128)return Xs(t,n,e);throw new Error(\"Expected varint not more than 10 bytes\")}(e|=(15&(r=n[this.pos]))<<28,t,this))))},readVarint64:function(){return this.readVarint(!0)},readSVarint:function(){var t=this.readVarint();return t%2==1?(t+1)/-2:t/2},readBoolean:function(){return Boolean(this.readVarint())},readString:function(){var t=this.readVarint()+this.pos,e=this.pos;return this.pos=t,t-e>=12&&Ys?function(t,e,r){return Ys.decode(t.subarray(e,r))}(this.buf,e,t):function(t,e,r){for(var n=\"\",i=e;i<r;){var a,o,s,l=t[i],c=null,u=l>239?4:l>223?3:l>191?2:1;if(i+u>r)break;1===u?l<128&&(c=l):2===u?128==(192&(a=t[i+1]))&&(c=(31&l)<<6|63&a)<=127&&(c=null):3===u?(o=t[i+2],128==(192&(a=t[i+1]))&&128==(192&o)&&((c=(15&l)<<12|(63&a)<<6|63&o)<=2047||c>=55296&&c<=57343)&&(c=null)):4===u&&(o=t[i+2],s=t[i+3],128==(192&(a=t[i+1]))&&128==(192&o)&&128==(192&s)&&((c=(15&l)<<18|(63&a)<<12|(63&o)<<6|63&s)<=65535||c>=1114112)&&(c=null)),null===c?(c=65533,u=1):c>65535&&(c-=65536,n+=String.fromCharCode(c>>>10&1023|55296),c=56320|1023&c),n+=String.fromCharCode(c),i+=u}return n}(this.buf,e,t)},readBytes:function(){var t=this.readVarint()+this.pos,e=this.buf.subarray(this.pos,t);return this.pos=t,e},readPackedVarint:function(t,e){if(this.type!==Gs.Bytes)return t.push(this.readVarint(e));var r=Ws(this);for(t=t||[];this.pos<r;)t.push(this.readVarint(e));return t},readPackedSVarint:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSVarint());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSVarint());return t},readPackedBoolean:function(t){if(this.type!==Gs.Bytes)return t.push(this.readBoolean());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readBoolean());return t},readPackedFloat:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFloat());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFloat());return t},readPackedDouble:function(t){if(this.type!==Gs.Bytes)return t.push(this.readDouble());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readDouble());return t},readPackedFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed32());return t},readPackedSFixed32:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed32());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed32());return t},readPackedFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readFixed64());return t},readPackedSFixed64:function(t){if(this.type!==Gs.Bytes)return t.push(this.readSFixed64());var e=Ws(this);for(t=t||[];this.pos<e;)t.push(this.readSFixed64());return t},skip:function(t){var e=7&t;if(e===Gs.Varint)for(;this.buf[this.pos++]>127;);else if(e===Gs.Bytes)this.pos=this.readVarint()+this.pos;else if(e===Gs.Fixed32)this.pos+=4;else{if(e!==Gs.Fixed64)throw new Error(\"Unimplemented type: \"+e);this.pos+=8}},writeTag:function(t,e){this.writeVarint(t<<3|e)},realloc:function(t){for(var e=this.length||16;e<this.pos+t;)e*=2;if(e!==this.length){var r=new Uint8Array(e);r.set(this.buf),this.buf=r,this.length=e}},finish:function(){return this.length=this.pos,this.pos=0,this.buf.subarray(0,this.length)},writeFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeSFixed32:function(t){this.realloc(4),ol(this.buf,t,this.pos),this.pos+=4},writeFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeSFixed64:function(t){this.realloc(8),ol(this.buf,-1&t,this.pos),ol(this.buf,Math.floor(t*(1/4294967296)),this.pos+4),this.pos+=8},writeVarint:function(t){(t=+t||0)>268435455||t<0?function(t,e){var r,n;if(t>=0?(r=t%4294967296|0,n=t/4294967296|0):(n=~(-t/4294967296),4294967295^(r=~(-t%4294967296))?r=r+1|0:(r=0,n=n+1|0)),t>=0x10000000000000000||t<-0x10000000000000000)throw new Error(\"Given varint doesn't fit into 10 bytes\");e.realloc(10),function(t,e,r){r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,t>>>=7,r.buf[r.pos++]=127&t|128,r.buf[r.pos]=127&(t>>>=7)}(r,0,e),function(t,e){var r=(7&t)<<4;e.buf[e.pos++]|=r|((t>>>=3)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t|((t>>>=7)?128:0),t&&(e.buf[e.pos++]=127&t)))))}(n,e)}(t,this):(this.realloc(4),this.buf[this.pos++]=127&t|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=127&(t>>>=7)|(t>127?128:0),t<=127||(this.buf[this.pos++]=t>>>7&127))))},writeSVarint:function(t){this.writeVarint(t<0?2*-t-1:2*t)},writeBoolean:function(t){this.writeVarint(Boolean(t))},writeString:function(t){t=String(t),this.realloc(4*t.length),this.pos++;var e=this.pos;this.pos=function(t,e,r){for(var n,i,a=0;a<e.length;a++){if((n=e.charCodeAt(a))>55295&&n<57344){if(!i){n>56319||a+1===e.length?(t[r++]=239,t[r++]=191,t[r++]=189):i=n;continue}if(n<56320){t[r++]=239,t[r++]=191,t[r++]=189,i=n;continue}n=i-55296<<10|n-56320|65536,i=null}else i&&(t[r++]=239,t[r++]=191,t[r++]=189,i=null);n<128?t[r++]=n:(n<2048?t[r++]=n>>6|192:(n<65536?t[r++]=n>>12|224:(t[r++]=n>>18|240,t[r++]=n>>12&63|128),t[r++]=n>>6&63|128),t[r++]=63&n|128)}return r}(this.buf,t,this.pos);var r=this.pos-e;r>=128&&Zs(e,r,this),this.pos=e-1,this.writeVarint(r),this.pos+=r},writeFloat:function(t){this.realloc(4),qs(this.buf,t,this.pos,!0,23,4),this.pos+=4},writeDouble:function(t){this.realloc(8),qs(this.buf,t,this.pos,!0,52,8),this.pos+=8},writeBytes:function(t){var e=t.length;this.writeVarint(e),this.realloc(e);for(var r=0;r<e;r++)this.buf[this.pos++]=t[r]},writeRawMessage:function(t,e){this.pos++;var r=this.pos;t(e,this);var n=this.pos-r;n>=128&&Zs(r,n,this),this.pos=r-1,this.writeVarint(n),this.pos+=n},writeMessage:function(t,e,r){this.writeTag(t,Gs.Bytes),this.writeRawMessage(e,r)},writePackedVarint:function(t,e){e.length&&this.writeMessage(t,Js,e)},writePackedSVarint:function(t,e){e.length&&this.writeMessage(t,Ks,e)},writePackedBoolean:function(t,e){e.length&&this.writeMessage(t,tl,e)},writePackedFloat:function(t,e){e.length&&this.writeMessage(t,Qs,e)},writePackedDouble:function(t,e){e.length&&this.writeMessage(t,$s,e)},writePackedFixed32:function(t,e){e.length&&this.writeMessage(t,el,e)},writePackedSFixed32:function(t,e){e.length&&this.writeMessage(t,rl,e)},writePackedFixed64:function(t,e){e.length&&this.writeMessage(t,nl,e)},writePackedSFixed64:function(t,e){e.length&&this.writeMessage(t,il,e)},writeBytesField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeBytes(e)},writeFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFixed32(e)},writeSFixed32Field:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeSFixed32(e)},writeFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeFixed64(e)},writeSFixed64Field:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeSFixed64(e)},writeVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeVarint(e)},writeSVarintField:function(t,e){this.writeTag(t,Gs.Varint),this.writeSVarint(e)},writeStringField:function(t,e){this.writeTag(t,Gs.Bytes),this.writeString(e)},writeFloatField:function(t,e){this.writeTag(t,Gs.Fixed32),this.writeFloat(e)},writeDoubleField:function(t,e){this.writeTag(t,Gs.Fixed64),this.writeDouble(e)},writeBooleanField:function(t,e){this.writeVarintField(t,Boolean(e))}};var hl=function(t,e){var r=e.pixelRatio,n=e.version,i=e.stretchX,a=e.stretchY,o=e.content;this.paddedRect=t,this.pixelRatio=r,this.stretchX=i,this.stretchY=a,this.content=o,this.version=n},pl={tl:{configurable:!0},br:{configurable:!0},tlbr:{configurable:!0},displaySize:{configurable:!0}};pl.tl.get=function(){return[this.paddedRect.x+1,this.paddedRect.y+1]},pl.br.get=function(){return[this.paddedRect.x+this.paddedRect.w-1,this.paddedRect.y+this.paddedRect.h-1]},pl.tlbr.get=function(){return this.tl.concat(this.br)},pl.displaySize.get=function(){return[(this.paddedRect.w-2)/this.pixelRatio,(this.paddedRect.h-2)/this.pixelRatio]},Object.defineProperties(hl.prototype,pl);var dl=function(t,e){var r={},n={};this.haveRenderCallbacks=[];var i=[];this.addImages(t,r,i),this.addImages(e,n,i);var a=fl(i),o=new po({width:a.w||1,height:a.h||1});for(var s in t){var l=t[s],c=r[s].paddedRect;po.copy(l.data,o,{x:0,y:0},{x:c.x+1,y:c.y+1},l.data)}for(var u in e){var f=e[u],h=n[u].paddedRect,p=h.x+1,d=h.y+1,g=f.data.width,m=f.data.height;po.copy(f.data,o,{x:0,y:0},{x:p,y:d},f.data),po.copy(f.data,o,{x:0,y:m-1},{x:p,y:d-1},{width:g,height:1}),po.copy(f.data,o,{x:0,y:0},{x:p,y:d+m},{width:g,height:1}),po.copy(f.data,o,{x:g-1,y:0},{x:p-1,y:d},{width:1,height:m}),po.copy(f.data,o,{x:0,y:0},{x:p+g,y:d},{width:1,height:m})}this.image=o,this.iconPositions=r,this.patternPositions=n};dl.prototype.addImages=function(t,e,r){for(var n in t){var i=t[n],a={x:0,y:0,w:i.data.width+2,h:i.data.height+2};r.push(a),e[n]=new hl(a,i),i.hasRenderCallback&&this.haveRenderCallbacks.push(n)}},dl.prototype.patchUpdatedImages=function(t,e){for(var r in t.dispatchRenderCallbacks(this.haveRenderCallbacks),t.updatedImages)this.patchUpdatedImage(this.iconPositions[r],t.getImage(r),e),this.patchUpdatedImage(this.patternPositions[r],t.getImage(r),e)},dl.prototype.patchUpdatedImage=function(t,e,r){if(t&&e&&t.version!==e.version){t.version=e.version;var n=t.tl;r.update(e.data,void 0,{x:n[0],y:n[1]})}},Dn(\"ImagePosition\",hl),Dn(\"ImageAtlas\",dl);var gl={horizontal:1,vertical:2,horizontalOnly:3},ml=function(){this.scale=1,this.fontStack=\"\",this.imageName=null};ml.forText=function(t,e){var r=new ml;return r.scale=t||1,r.fontStack=e,r},ml.forImage=function(t){var e=new ml;return e.imageName=t,e};var vl=function(){this.text=\"\",this.sectionIndex=[],this.sections=[],this.imageSectionID=null};function yl(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=vl.fromFeature(t,i);f===gl.vertical&&v.verticalizePunctuation();var y=ni.processBidirectionalText,x=ni.processStyledBidirectionalText;if(y&&1===v.sections.length){m=[];for(var b=0,_=y(v.toString(),Ml(v,c,a,e,n,p,d));b<_.length;b+=1){var w=_[b],T=new vl;T.text=w,T.sections=v.sections;for(var k=0;k<w.length;k++)T.sectionIndex.push(0);m.push(T)}}else if(x){m=[];for(var M=0,A=x(v.text,v.sectionIndex,Ml(v,c,a,e,n,p,d));M<A.length;M+=1){var S=A[M],E=new vl;E.text=S[0],E.sectionIndex=S[1],E.sections=v.sections,m.push(E)}}else m=function(t,e){for(var r=[],n=t.text,i=0,a=0,o=e;a<o.length;a+=1){var s=o[a];r.push(t.substring(i,s)),i=s}return i<n.length&&r.push(t.substring(i,n.length)),r}(v,Ml(v,c,a,e,n,p,d));var C=[],L={positionedLines:C,text:v.toString(),top:u[1],bottom:u[1],left:u[0],right:u[0],writingMode:f,iconsInText:!1,verticalizable:!1};return function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=0,p=-17,d=0,g=0,m=\"right\"===s?1:\"left\"===s?0:.5,v=0,y=0,x=i;y<x.length;y+=1){var b=x[y];b.trim();var _=b.getMaxScale(),w=24*(_-1),T={positionedGlyphs:[],lineOffset:0};t.positionedLines[v]=T;var k=T.positionedGlyphs,M=0;if(b.length()){for(var A=0;A<b.length();A++){var S=b.getSection(A),E=b.getSectionIndex(A),C=b.getCharCode(A),L=0,I=null,P=null,z=null,O=24,D=!(l===gl.horizontal||!u&&!Hn(C)||u&&(xl[C]||(H=C,Vn.Arabic(H)||Vn[\"Arabic Supplement\"](H)||Vn[\"Arabic Extended-A\"](H)||Vn[\"Arabic Presentation Forms-A\"](H)||Vn[\"Arabic Presentation Forms-B\"](H))));if(S.imageName){var R=n[S.imageName];if(!R)continue;z=S.imageName,t.iconsInText=t.iconsInText||!0,P=R.paddedRect;var F=R.displaySize;S.scale=24*S.scale/f,L=w+(24-F[1]*S.scale),O=(I={width:F[0],height:F[1],left:1,top:-3,advance:D?F[1]:F[0]}).advance;var B=D?F[0]*S.scale-24*_:F[1]*S.scale-24*_;B>0&&B>M&&(M=B)}else{var N=r[S.fontStack],j=N&&N[C];if(j&&j.rect)P=j.rect,I=j.metrics;else{var U=e[S.fontStack],V=U&&U[C];if(!V)continue;I=V.metrics}L=24*(_-S.scale)}D?(t.verticalizable=!0,k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=O*S.scale+c):(k.push({glyph:C,imageName:z,x:h,y:p+L,vertical:D,scale:S.scale,fontStack:S.fontStack,sectionIndex:E,metrics:I,rect:P}),h+=I.advance*S.scale+c)}0!==k.length&&(d=Math.max(h-c,d),Sl(k,0,k.length-1,m,M)),h=0;var q=a*_+M;T.lineOffset=Math.max(M,w),p+=q,g=Math.max(q,g),++v}else p+=a,++v}var H,G=p- -17,Y=Al(o),W=Y.horizontalAlign,X=Y.verticalAlign;(function(t,e,r,n,i,a,o,s,l){var c,u=(e-r)*i;c=a!==o?-s*n- -17:(-n*l+.5)*o;for(var f=0,h=t;f<h.length;f+=1)for(var p=0,d=h[f].positionedGlyphs;p<d.length;p+=1){var g=d[p];g.x+=u,g.y+=c}})(t.positionedLines,m,W,X,d,g,a,G,i.length),t.top+=-X*G,t.bottom=t.top+G,t.left+=-W*d,t.right=t.left+d}(L,e,r,n,m,o,s,l,f,c,h,g),!function(t){for(var e=0,r=t;e<r.length;e+=1)if(0!==r[e].positionedGlyphs.length)return!1;return!0}(C)&&L}vl.fromFeature=function(t,e){for(var r=new vl,n=0;n<t.sections.length;n++){var i=t.sections[n];i.image?r.addImageSection(i):r.addTextSection(i,e)}return r},vl.prototype.length=function(){return this.text.length},vl.prototype.getSection=function(t){return this.sections[this.sectionIndex[t]]},vl.prototype.getSectionIndex=function(t){return this.sectionIndex[t]},vl.prototype.getCharCode=function(t){return this.text.charCodeAt(t)},vl.prototype.verticalizePunctuation=function(){this.text=function(t){for(var e=\"\",r=0;r<t.length;r++){var n=t.charCodeAt(r+1)||null,i=t.charCodeAt(r-1)||null;e+=n&&Gn(n)&&!Us[t[r+1]]||i&&Gn(i)&&!Us[t[r-1]]||!Us[t[r]]?t[r]:Us[t[r]]}return e}(this.text)},vl.prototype.trim=function(){for(var t=0,e=0;e<this.text.length&&xl[this.text.charCodeAt(e)];e++)t++;for(var r=this.text.length,n=this.text.length-1;n>=0&&n>=t&&xl[this.text.charCodeAt(n)];n--)r--;this.text=this.text.substring(t,r),this.sectionIndex=this.sectionIndex.slice(t,r)},vl.prototype.substring=function(t,e){var r=new vl;return r.text=this.text.substring(t,e),r.sectionIndex=this.sectionIndex.slice(t,e),r.sections=this.sections,r},vl.prototype.toString=function(){return this.text},vl.prototype.getMaxScale=function(){var t=this;return this.sectionIndex.reduce((function(e,r){return Math.max(e,t.sections[r].scale)}),0)},vl.prototype.addTextSection=function(t,e){this.text+=t.text,this.sections.push(ml.forText(t.scale,t.fontStack||e));for(var r=this.sections.length-1,n=0;n<t.text.length;++n)this.sectionIndex.push(r)},vl.prototype.addImageSection=function(t){var e=t.image?t.image.name:\"\";if(0!==e.length){var r=this.getNextImageSectionCharCode();r?(this.text+=String.fromCharCode(r),this.sections.push(ml.forImage(e)),this.sectionIndex.push(this.sections.length-1)):_(\"Reached maximum number of images 6401\")}else _(\"Can't add FormattedSection with an empty image.\")},vl.prototype.getNextImageSectionCharCode=function(){return this.imageSectionID?this.imageSectionID>=63743?null:++this.imageSectionID:(this.imageSectionID=57344,this.imageSectionID)};var xl={9:!0,10:!0,11:!0,12:!0,13:!0,32:!0},bl={};function _l(t,e,r,n,i,a){if(e.imageName){var o=n[e.imageName];return o?o.displaySize[0]*e.scale*24/a+i:0}var s=r[e.fontStack],l=s&&s[t];return l?l.metrics.advance*e.scale+i:0}function wl(t,e,r,n){var i=Math.pow(t-e,2);return n?t<e?i/2:2*i:i+Math.abs(r)*r}function Tl(t,e,r){var n=0;return 10===t&&(n-=1e4),r&&(n+=150),40!==t&&65288!==t||(n+=50),41!==e&&65289!==e||(n+=50),n}function kl(t,e,r,n,i,a){for(var o=null,s=wl(e,r,i,a),l=0,c=n;l<c.length;l+=1){var u=c[l],f=wl(e-u.x,r,i,a)+u.badness;f<=s&&(o=u,s=f)}return{index:t,x:e,priorBreak:o,badness:s}}function Ml(t,e,r,n,i,a,o){if(\"point\"!==a)return[];if(!t)return[];for(var s,l=[],c=function(t,e,r,n,i,a){for(var o=0,s=0;s<t.length();s++){var l=t.getSection(s);o+=_l(t.getCharCode(s),l,n,i,e,a)}return o/Math.max(1,Math.ceil(o/r))}(t,e,r,n,i,o),u=t.text.indexOf(\"\\u200b\")>=0,f=0,h=0;h<t.length();h++){var p=t.getSection(h),d=t.getCharCode(h);if(xl[d]||(f+=_l(d,p,n,i,e,o)),h<t.length()-1){var g=!((s=d)<11904||!(Vn[\"Bopomofo Extended\"](s)||Vn.Bopomofo(s)||Vn[\"CJK Compatibility Forms\"](s)||Vn[\"CJK Compatibility Ideographs\"](s)||Vn[\"CJK Compatibility\"](s)||Vn[\"CJK Radicals Supplement\"](s)||Vn[\"CJK Strokes\"](s)||Vn[\"CJK Symbols and Punctuation\"](s)||Vn[\"CJK Unified Ideographs Extension A\"](s)||Vn[\"CJK Unified Ideographs\"](s)||Vn[\"Enclosed CJK Letters and Months\"](s)||Vn[\"Halfwidth and Fullwidth Forms\"](s)||Vn.Hiragana(s)||Vn[\"Ideographic Description Characters\"](s)||Vn[\"Kangxi Radicals\"](s)||Vn[\"Katakana Phonetic Extensions\"](s)||Vn.Katakana(s)||Vn[\"Vertical Forms\"](s)||Vn[\"Yi Radicals\"](s)||Vn[\"Yi Syllables\"](s)));(bl[d]||g||p.imageName)&&l.push(kl(h+1,f,c,l,Tl(d,t.getCharCode(h+1),g&&u),!1))}}return function t(e){return e?t(e.priorBreak).concat(e.index):[]}(kl(t.length(),f,c,l,0,!0))}function Al(t){var e=.5,r=.5;switch(t){case\"right\":case\"top-right\":case\"bottom-right\":e=1;break;case\"left\":case\"top-left\":case\"bottom-left\":e=0}switch(t){case\"bottom\":case\"bottom-right\":case\"bottom-left\":r=1;break;case\"top\":case\"top-right\":case\"top-left\":r=0}return{horizontalAlign:e,verticalAlign:r}}function Sl(t,e,r,n,i){if(n||i)for(var a=t[r],o=(t[r].x+a.metrics.advance*a.scale)*n,s=e;s<=r;s++)t[s].x-=o,t[s].y+=i}function El(t,e,r,n,i,a){var o,s=t.image;if(s.content){var l=s.content,c=s.pixelRatio||1;o=[l[0]/c,l[1]/c,s.displaySize[0]-l[2]/c,s.displaySize[1]-l[3]/c]}var u,f,h,p,d=e.left*a,g=e.right*a;\"width\"===r||\"both\"===r?(p=i[0]+d-n[3],f=i[0]+g+n[1]):f=(p=i[0]+(d+g-s.displaySize[0])/2)+s.displaySize[0];var m=e.top*a,v=e.bottom*a;return\"height\"===r||\"both\"===r?(u=i[1]+m-n[0],h=i[1]+v+n[2]):h=(u=i[1]+(m+v-s.displaySize[1])/2)+s.displaySize[1],{image:s,top:u,right:f,bottom:h,left:p,collisionPadding:o}}bl[10]=!0,bl[32]=!0,bl[38]=!0,bl[40]=!0,bl[41]=!0,bl[43]=!0,bl[45]=!0,bl[47]=!0,bl[173]=!0,bl[183]=!0,bl[8203]=!0,bl[8208]=!0,bl[8211]=!0,bl[8231]=!0;var Cl=function(t){function e(e,r,n,i){t.call(this,e,r),this.angle=n,void 0!==i&&(this.segment=i)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.clone=function(){return new e(this.x,this.y,this.angle,this.segment)},e}(i);function Ll(t,e){var r=e.expression;if(\"constant\"===r.kind)return{kind:\"constant\",layoutSize:r.evaluate(new ii(t+1))};if(\"source\"===r.kind)return{kind:\"source\"};for(var n=r.zoomStops,i=r.interpolationType,a=0;a<n.length&&n[a]<=t;)a++;for(var o=a=Math.max(0,a-1);o<n.length&&n[o]<t+1;)o++;o=Math.min(n.length-1,o);var s=n[a],l=n[o];return\"composite\"===r.kind?{kind:\"composite\",minZoom:s,maxZoom:l,interpolationType:i}:{kind:\"camera\",minZoom:s,maxZoom:l,minSize:r.evaluate(new ii(s)),maxSize:r.evaluate(new ii(l)),interpolationType:i}}function Il(t,e,r){var n=e.uSize,i=r.lowerSize;return\"source\"===t.kind?i/128:\"composite\"===t.kind?Ue(i/128,r.upperSize/128,e.uSizeT):n}function Pl(t,e){var r=0,n=0;if(\"constant\"===t.kind)n=t.layoutSize;else if(\"source\"!==t.kind){var i=t.interpolationType,a=i?l(rr.interpolationFactor(i,e,t.minZoom,t.maxZoom),0,1):0;\"camera\"===t.kind?n=Ue(t.minSize,t.maxSize,a):r=a}return{uSizeT:r,uSize:n}}Dn(\"Anchor\",Cl);var zl=Object.freeze({__proto__:null,getSizeData:Ll,evaluateSizeForFeature:Il,evaluateSizeForZoom:Pl,SIZE_PACK_FACTOR:128});function Ol(t,e,r,n,i){if(void 0===e.segment)return!0;for(var a=e,o=e.segment+1,s=0;s>-r/2;){if(--o<0)return!1;s-=t[o].dist(a),a=t[o]}s+=t[o].dist(t[o+1]),o++;for(var l=[],c=0;s<r/2;){var u=t[o],f=t[o+1];if(!f)return!1;var h=t[o-1].angleTo(u)-u.angleTo(f);for(h=Math.abs((h+3*Math.PI)%(2*Math.PI)-Math.PI),l.push({distance:s,angleDelta:h}),c+=h;s-l[0].distance>n;)c-=l.shift().angleDelta;if(c>i)return!1;o++,s+=u.dist(f)}return!0}function Dl(t){for(var e=0,r=0;r<t.length-1;r++)e+=t[r].dist(t[r+1]);return e}function Rl(t,e,r){return t?.6*e*r:0}function Fl(t,e){return Math.max(t?t.right-t.left:0,e?e.right-e.left:0)}function Bl(t,e,r,n,i,a){for(var o=Rl(r,i,a),s=Fl(r,n)*a,l=0,c=Dl(t)/2,u=0;u<t.length-1;u++){var f=t[u],h=t[u+1],p=f.dist(h);if(l+p>c){var d=(c-l)/p,g=Ue(f.x,h.x,d),m=Ue(f.y,h.y,d),v=new Cl(g,m,h.angleTo(f),u);return v._round(),!o||Ol(t,v,s,o,e)?v:void 0}l+=p}}function Nl(t,e,r,n,i,a,o,s,l){var c=Rl(n,a,o),u=Fl(n,i),f=u*o,h=0===t[0].x||t[0].x===l||0===t[0].y||t[0].y===l;return e-f<e/4&&(e=f+e/4),function t(e,r,n,i,a,o,s,l,c){for(var u=o/2,f=Dl(e),h=0,p=r-n,d=[],g=0;g<e.length-1;g++){for(var m=e[g],v=e[g+1],y=m.dist(v),x=v.angleTo(m);p+n<h+y;){var b=((p+=n)-h)/y,_=Ue(m.x,v.x,b),w=Ue(m.y,v.y,b);if(_>=0&&_<c&&w>=0&&w<c&&p-u>=0&&p+u<=f){var T=new Cl(_,w,x,g);T._round(),i&&!Ol(e,T,o,i,a)||d.push(T)}}h+=y}return l||d.length||s||(d=t(e,h/2,n,i,a,o,s,!0,c)),d}(t,h?e/2*s%e:(u/2+2*a)*o*s%e,e,c,r,f,h,!1,l)}function jl(t,e,r,n,a){for(var o=[],s=0;s<t.length;s++)for(var l=t[s],c=void 0,u=0;u<l.length-1;u++){var f=l[u],h=l[u+1];f.x<e&&h.x<e||(f.x<e?f=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x<e&&(h=new i(e,f.y+(e-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y<r&&h.y<r||(f.y<r?f=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round():h.y<r&&(h=new i(f.x+(r-f.y)/(h.y-f.y)*(h.x-f.x),r)._round()),f.x>=n&&h.x>=n||(f.x>=n?f=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round():h.x>=n&&(h=new i(n,f.y+(n-f.x)/(h.x-f.x)*(h.y-f.y))._round()),f.y>=a&&h.y>=a||(f.y>=a?f=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round():h.y>=a&&(h=new i(f.x+(a-f.y)/(h.y-f.y)*(h.x-f.x),a)._round()),c&&f.equals(c[c.length-1])||o.push(c=[f]),c.push(h)))))}return o}function Ul(t,e,r,n){var a=[],o=t.image,s=o.pixelRatio,l=o.paddedRect.w-2,c=o.paddedRect.h-2,u=t.right-t.left,f=t.bottom-t.top,h=o.stretchX||[[0,l]],p=o.stretchY||[[0,c]],d=function(t,e){return t+e[1]-e[0]},g=h.reduce(d,0),m=p.reduce(d,0),v=l-g,y=c-m,x=0,b=g,_=0,w=m,T=0,k=v,M=0,A=y;if(o.content&&n){var S=o.content;x=Vl(h,0,S[0]),_=Vl(p,0,S[1]),b=Vl(h,S[0],S[2]),w=Vl(p,S[1],S[3]),T=S[0]-x,M=S[1]-_,k=S[2]-S[0]-b,A=S[3]-S[1]-w}var E=function(n,a,l,c){var h=Hl(n.stretch-x,b,u,t.left),p=Gl(n.fixed-T,k,n.stretch,g),d=Hl(a.stretch-_,w,f,t.top),v=Gl(a.fixed-M,A,a.stretch,m),y=Hl(l.stretch-x,b,u,t.left),S=Gl(l.fixed-T,k,l.stretch,g),E=Hl(c.stretch-_,w,f,t.top),C=Gl(c.fixed-M,A,c.stretch,m),L=new i(h,d),I=new i(y,d),P=new i(y,E),z=new i(h,E),O=new i(p/s,v/s),D=new i(S/s,C/s),R=e*Math.PI/180;if(R){var F=Math.sin(R),B=Math.cos(R),N=[B,-F,F,B];L._matMult(N),I._matMult(N),z._matMult(N),P._matMult(N)}var j=n.stretch+n.fixed,U=a.stretch+a.fixed;return{tl:L,tr:I,bl:z,br:P,tex:{x:o.paddedRect.x+1+j,y:o.paddedRect.y+1+U,w:l.stretch+l.fixed-j,h:c.stretch+c.fixed-U},writingMode:void 0,glyphOffset:[0,0],sectionIndex:0,pixelOffsetTL:O,pixelOffsetBR:D,minFontScaleX:k/s/u,minFontScaleY:A/s/f,isSDF:r}};if(n&&(o.stretchX||o.stretchY))for(var C=ql(h,v,g),L=ql(p,y,m),I=0;I<C.length-1;I++)for(var P=C[I],z=C[I+1],O=0;O<L.length-1;O++)a.push(E(P,L[O],z,L[O+1]));else a.push(E({fixed:0,stretch:-1},{fixed:0,stretch:-1},{fixed:0,stretch:l+1},{fixed:0,stretch:c+1}));return a}function Vl(t,e,r){for(var n=0,i=0,a=t;i<a.length;i+=1){var o=a[i];n+=Math.max(e,Math.min(r,o[1]))-Math.max(e,Math.min(r,o[0]))}return n}function ql(t,e,r){for(var n=[{fixed:-1,stretch:0}],i=0,a=t;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=n[n.length-1];n.push({fixed:s-c.stretch,stretch:c.stretch}),n.push({fixed:s-c.stretch,stretch:c.stretch+(l-s)})}return n.push({fixed:e+1,stretch:r}),n}function Hl(t,e,r,n){return t/e*r+n}function Gl(t,e,r,n){return t-e*r/n}var Yl=function(t,e,r,n,a,o,s,l,c,u){if(this.boxStartIndex=t.length,c){var f=o.top,h=o.bottom,p=o.collisionPadding;p&&(f-=p[1],h+=p[3]);var d=h-f;d>0&&(d=Math.max(10,d),this.circleDiameter=d)}else{var g=o.top*s-l,m=o.bottom*s+l,v=o.left*s-l,y=o.right*s+l,x=o.collisionPadding;if(x&&(v-=x[0]*s,g-=x[1]*s,y+=x[2]*s,m+=x[3]*s),u){var b=new i(v,g),_=new i(y,g),w=new i(v,m),T=new i(y,m),k=u*Math.PI/180;b._rotate(k),_._rotate(k),w._rotate(k),T._rotate(k),v=Math.min(b.x,_.x,w.x,T.x),y=Math.max(b.x,_.x,w.x,T.x),g=Math.min(b.y,_.y,w.y,T.y),m=Math.max(b.y,_.y,w.y,T.y)}t.emplaceBack(e.x,e.y,v,g,y,m,r,n,a)}this.boxEndIndex=t.length},Wl=function(t,e){if(void 0===t&&(t=[]),void 0===e&&(e=Xl),this.data=t,this.length=this.data.length,this.compare=e,this.length>0)for(var r=(this.length>>1)-1;r>=0;r--)this._down(r)};function Xl(t,e){return t<e?-1:t>e?1:0}function Zl(t,e,r){void 0===e&&(e=1),void 0===r&&(r=!1);for(var n=1/0,a=1/0,o=-1/0,s=-1/0,l=t[0],c=0;c<l.length;c++){var u=l[c];(!c||u.x<n)&&(n=u.x),(!c||u.y<a)&&(a=u.y),(!c||u.x>o)&&(o=u.x),(!c||u.y>s)&&(s=u.y)}var f=Math.min(o-n,s-a),h=f/2,p=new Wl([],Jl);if(0===f)return new i(n,a);for(var d=n;d<o;d+=f)for(var g=a;g<s;g+=f)p.push(new Kl(d+h,g+h,h,t));for(var m=function(t){for(var e=0,r=0,n=0,i=t[0],a=0,o=i.length,s=o-1;a<o;s=a++){var l=i[a],c=i[s],u=l.x*c.y-c.x*l.y;r+=(l.x+c.x)*u,n+=(l.y+c.y)*u,e+=3*u}return new Kl(r/e,n/e,0,t)}(t),v=p.length;p.length;){var y=p.pop();(y.d>m.d||!m.d)&&(m=y,r&&console.log(\"found best %d after %d probes\",Math.round(1e4*y.d)/1e4,v)),y.max-m.d<=e||(p.push(new Kl(y.p.x-(h=y.h/2),y.p.y-h,h,t)),p.push(new Kl(y.p.x+h,y.p.y-h,h,t)),p.push(new Kl(y.p.x-h,y.p.y+h,h,t)),p.push(new Kl(y.p.x+h,y.p.y+h,h,t)),v+=4)}return r&&(console.log(\"num probes: \"+v),console.log(\"best distance: \"+m.d)),m.p}function Jl(t,e){return e.max-t.max}function Kl(t,e,r,n){this.p=new i(t,e),this.h=r,this.d=function(t,e){for(var r=!1,n=1/0,i=0;i<e.length;i++)for(var a=e[i],o=0,s=a.length,l=s-1;o<s;l=o++){var c=a[o],u=a[l];c.y>t.y!=u.y>t.y&&t.x<(u.x-c.x)*(t.y-c.y)/(u.y-c.y)+c.x&&(r=!r),n=Math.min(n,Ga(t,c,u))}return(r?1:-1)*Math.sqrt(n)}(this.p,n),this.max=this.d+this.h*Math.SQRT2}Wl.prototype.push=function(t){this.data.push(t),this.length++,this._up(this.length-1)},Wl.prototype.pop=function(){if(0!==this.length){var t=this.data[0],e=this.data.pop();return this.length--,this.length>0&&(this.data[0]=e,this._down(0)),t}},Wl.prototype.peek=function(){return this.data[0]},Wl.prototype._up=function(t){for(var e=this.data,r=this.compare,n=e[t];t>0;){var i=t-1>>1,a=e[i];if(r(n,a)>=0)break;e[t]=a,t=i}e[t]=n},Wl.prototype._down=function(t){for(var e=this.data,r=this.compare,n=this.length>>1,i=e[t];t<n;){var a=1+(t<<1),o=e[a],s=a+1;if(s<this.length&&r(e[s],o)<0&&(a=s,o=e[s]),r(o,i)>=0)break;e[t]=o,t=a}e[t]=i};var Ql=Number.POSITIVE_INFINITY;function $l(t,e){return e[1]!==Ql?function(t,e,r){var n=0,i=0;switch(e=Math.abs(e),r=Math.abs(r),t){case\"top-right\":case\"top-left\":case\"top\":i=r-7;break;case\"bottom-right\":case\"bottom-left\":case\"bottom\":i=7-r}switch(t){case\"top-right\":case\"bottom-right\":case\"right\":n=-e;break;case\"top-left\":case\"bottom-left\":case\"left\":n=e}return[n,i]}(t,e[0],e[1]):function(t,e){var r=0,n=0;e<0&&(e=0);var i=e/Math.sqrt(2);switch(t){case\"top-right\":case\"top-left\":n=i-7;break;case\"bottom-right\":case\"bottom-left\":n=7-i;break;case\"bottom\":n=7-e;break;case\"top\":n=e-7}switch(t){case\"top-right\":case\"bottom-right\":r=-i;break;case\"top-left\":case\"bottom-left\":r=i;break;case\"left\":r=e;break;case\"right\":r=-e}return[r,n]}(t,e[0])}function tc(t){switch(t){case\"right\":case\"top-right\":case\"bottom-right\":return\"right\";case\"left\":case\"top-left\":case\"bottom-left\":return\"left\"}return\"center\"}function ec(t,e,r,n,a,o,s,l,c,u,f,h,p,d,g){var m=function(t,e,r,n,a,o,s,l){for(var c=n.layout.get(\"text-rotate\").evaluate(o,{})*Math.PI/180,u=[],f=0,h=e.positionedLines;f<h.length;f+=1)for(var p=h[f],d=0,g=p.positionedGlyphs;d<g.length;d+=1){var m=g[d];if(m.rect){var v=m.rect||{},y=4,x=!0,b=1,_=0,w=(a||l)&&m.vertical,T=m.metrics.advance*m.scale/2;if(l&&e.verticalizable&&(_=p.lineOffset/2-(m.imageName?-(24-m.metrics.width*m.scale)/2:24*(m.scale-1))),m.imageName){var k=s[m.imageName];x=k.sdf,y=1/(b=k.pixelRatio)}var M=a?[m.x+T,m.y]:[0,0],A=a?[0,0]:[m.x+T+r[0],m.y+r[1]-_],S=[0,0];w&&(S=A,A=[0,0]);var E=(m.metrics.left-y)*m.scale-T+A[0],C=(-m.metrics.top-y)*m.scale+A[1],L=E+v.w*m.scale/b,I=C+v.h*m.scale/b,P=new i(E,C),z=new i(L,C),O=new i(E,I),D=new i(L,I);if(w){var R=new i(-T,T- -17),F=-Math.PI/2,B=12-T,N=new i(22-B,-(m.imageName?B:0)),j=new(Function.prototype.bind.apply(i,[null].concat(S)));P._rotateAround(F,R)._add(N)._add(j),z._rotateAround(F,R)._add(N)._add(j),O._rotateAround(F,R)._add(N)._add(j),D._rotateAround(F,R)._add(N)._add(j)}if(c){var U=Math.sin(c),V=Math.cos(c),q=[V,-U,U,V];P._matMult(q),z._matMult(q),O._matMult(q),D._matMult(q)}var H=new i(0,0),G=new i(0,0);u.push({tl:P,tr:z,bl:O,br:D,tex:v,writingMode:e.writingMode,glyphOffset:M,sectionIndex:m.sectionIndex,isSDF:x,pixelOffsetTL:H,pixelOffsetBR:G,minFontScaleX:0,minFontScaleY:0})}}return u}(0,r,l,a,o,s,n,t.allowVerticalPlacement),v=t.textSizeData,y=null;\"source\"===v.kind?(y=[128*a.layout.get(\"text-size\").evaluate(s,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'):\"composite\"===v.kind&&((y=[128*d.compositeTextSizes[0].evaluate(s,{},g),128*d.compositeTextSizes[1].evaluate(s,{},g)])[0]>32640||y[1]>32640)&&_(t.layerIds[0]+': Value for \"text-size\" is >= 255. Reduce your \"text-size\".'),t.addSymbols(t.text,m,y,l,o,s,u,e,c.lineStartIndex,c.lineLength,p,g);for(var x=0,b=f;x<b.length;x+=1)h[b[x]]=t.text.placedSymbolArray.length-1;return 4*m.length}function rc(t){for(var e in t)return t[e];return null}function nc(t,e,r,n){var i=t.compareText;if(e in i){for(var a=i[e],o=a.length-1;o>=0;o--)if(n.dist(a[o])<r)return!0}else i[e]=[];return i[e].push(n),!1}var ic=gs.VectorTileFeature.types,ac=[{name:\"a_fade_opacity\",components:1,type:\"Uint8\",offset:0}];function oc(t,e,r,n,i,a,o,s,l,c,u,f,h){var p=s?Math.min(32640,Math.round(s[0])):0,d=s?Math.min(32640,Math.round(s[1])):0;t.emplaceBack(e,r,Math.round(32*n),Math.round(32*i),a,o,(p<<1)+(l?1:0),d,16*c,16*u,256*f,256*h)}function sc(t,e,r){t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r),t.emplaceBack(e.x,e.y,r)}function lc(t){for(var e=0,r=t.sections;e<r.length;e+=1)if(Xn(r[e].text))return!0;return!1}var cc=function(t){this.layoutVertexArray=new Li,this.indexArray=new Fi,this.programConfigurations=t,this.segments=new ia,this.dynamicLayoutVertexArray=new Ii,this.opacityVertexArray=new Pi,this.placedSymbolArray=new Ji};cc.prototype.isEmpty=function(){return 0===this.layoutVertexArray.length&&0===this.indexArray.length&&0===this.dynamicLayoutVertexArray.length&&0===this.opacityVertexArray.length},cc.prototype.upload=function(t,e,r,n){this.isEmpty()||(r&&(this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,Ds.members),this.indexBuffer=t.createIndexBuffer(this.indexArray,e),this.dynamicLayoutVertexBuffer=t.createVertexBuffer(this.dynamicLayoutVertexArray,Rs.members,!0),this.opacityVertexBuffer=t.createVertexBuffer(this.opacityVertexArray,ac,!0),this.opacityVertexBuffer.itemSize=1),(r||n)&&this.programConfigurations.upload(t))},cc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.programConfigurations.destroy(),this.segments.destroy(),this.dynamicLayoutVertexBuffer.destroy(),this.opacityVertexBuffer.destroy())},Dn(\"SymbolBuffers\",cc);var uc=function(t,e,r){this.layoutVertexArray=new t,this.layoutAttributes=e,this.indexArray=new r,this.segments=new ia,this.collisionVertexArray=new Ri};uc.prototype.upload=function(t){this.layoutVertexBuffer=t.createVertexBuffer(this.layoutVertexArray,this.layoutAttributes),this.indexBuffer=t.createIndexBuffer(this.indexArray),this.collisionVertexBuffer=t.createVertexBuffer(this.collisionVertexArray,Fs.members,!0)},uc.prototype.destroy=function(){this.layoutVertexBuffer&&(this.layoutVertexBuffer.destroy(),this.indexBuffer.destroy(),this.segments.destroy(),this.collisionVertexBuffer.destroy())},Dn(\"CollisionBuffers\",uc);var fc=function(t){this.collisionBoxArray=t.collisionBoxArray,this.zoom=t.zoom,this.overscaling=t.overscaling,this.layers=t.layers,this.layerIds=this.layers.map((function(t){return t.id})),this.index=t.index,this.pixelRatio=t.pixelRatio,this.sourceLayerIndex=t.sourceLayerIndex,this.hasPattern=!1,this.hasRTLText=!1,this.sortKeyRanges=[],this.collisionCircleArray=[],this.placementInvProjMatrix=eo([]),this.placementViewportMatrix=eo([]);var e=this.layers[0]._unevaluatedLayout._values;this.textSizeData=Ll(this.zoom,e[\"text-size\"]),this.iconSizeData=Ll(this.zoom,e[\"icon-size\"]);var r=this.layers[0].layout,n=r.get(\"symbol-sort-key\"),i=r.get(\"symbol-z-order\");this.sortFeaturesByKey=\"viewport-y\"!==i&&void 0!==n.constantOr(1),this.sortFeaturesByY=(\"viewport-y\"===i||\"auto\"===i&&!this.sortFeaturesByKey)&&(r.get(\"text-allow-overlap\")||r.get(\"icon-allow-overlap\")||r.get(\"text-ignore-placement\")||r.get(\"icon-ignore-placement\")),\"point\"===r.get(\"symbol-placement\")&&(this.writingModes=r.get(\"text-writing-mode\").map((function(t){return gl[t]}))),this.stateDependentLayerIds=this.layers.filter((function(t){return t.isStateDependent()})).map((function(t){return t.id})),this.sourceID=t.sourceID};fc.prototype.createArrays=function(){this.text=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^text/.test(t)}))),this.icon=new cc(new Ia(Ds.members,this.layers,this.zoom,(function(t){return/^icon/.test(t)}))),this.glyphOffsetArray=new $i,this.lineVertexArray=new ta,this.symbolInstances=new Qi},fc.prototype.calculateGlyphDependencies=function(t,e,r,n,i){for(var a=0;a<t.length;a++)if(e[t.charCodeAt(a)]=!0,(r||n)&&i){var o=Us[t.charAt(a)];o&&(e[o.charCodeAt(0)]=!0)}},fc.prototype.populate=function(t,e,r){var n=this.layers[0],i=n.layout,a=i.get(\"text-font\"),o=i.get(\"text-field\"),s=i.get(\"icon-image\"),l=(\"constant\"!==o.value.kind||o.value.value instanceof te&&!o.value.value.isEmpty()||o.value.value.toString().length>0)&&(\"constant\"!==a.value.kind||a.value.value.length>0),c=\"constant\"!==s.value.kind||!!s.value.value||Object.keys(s.parameters).length>0,u=i.get(\"symbol-sort-key\");if(this.features=[],l||c){for(var f=e.iconDependencies,h=e.glyphDependencies,p=e.availableImages,d=new ii(this.zoom),g=0,m=t;g<m.length;g+=1){var v=m[g],y=v.feature,x=v.id,b=v.index,_=v.sourceLayerIndex,w=n._featureFilter.needGeometry,T={type:y.type,id:x,properties:y.properties,geometry:w?Da(y):[]};if(n._featureFilter.filter(d,T,r)){w||(T.geometry=Da(y));var k=void 0;if(l){var M=n.getValueAndResolveTokens(\"text-field\",T,r,p),A=te.factory(M);lc(A)&&(this.hasRTLText=!0),(!this.hasRTLText||\"unavailable\"===ei()||this.hasRTLText&&ni.isParsed())&&(k=js(A,n,T))}var S=void 0;if(c){var E=n.getValueAndResolveTokens(\"icon-image\",T,r,p);S=E instanceof ee?E:ee.fromString(E)}if(k||S){var C=this.sortFeaturesByKey?u.evaluate(T,{},r):void 0,L={id:x,text:k,icon:S,index:b,sourceLayerIndex:_,geometry:Da(y),properties:y.properties,type:ic[y.type],sortKey:C};if(this.features.push(L),S&&(f[S.name]=!0),k){var I=a.evaluate(T,{},r).join(\",\"),P=\"map\"===i.get(\"text-rotation-alignment\")&&\"point\"!==i.get(\"symbol-placement\");this.allowVerticalPlacement=this.writingModes&&this.writingModes.indexOf(gl.vertical)>=0;for(var z=0,O=k.sections;z<O.length;z+=1){var D=O[z];if(D.image)f[D.image.name]=!0;else{var R=qn(k.toString()),F=D.fontStack||I,B=h[F]=h[F]||{};this.calculateGlyphDependencies(D.text,B,P,this.allowVerticalPlacement,R)}}}}}}\"line\"===i.get(\"symbol-placement\")&&(this.features=function(t){var e={},r={},n=[],i=0;function a(e){n.push(t[e]),i++}function o(t,e,i){var a=r[t];return delete r[t],r[e]=a,n[a].geometry[0].pop(),n[a].geometry[0]=n[a].geometry[0].concat(i[0]),a}function s(t,r,i){var a=e[r];return delete e[r],e[t]=a,n[a].geometry[0].shift(),n[a].geometry[0]=i[0].concat(n[a].geometry[0]),a}function l(t,e,r){var n=r?e[0][e[0].length-1]:e[0][0];return t+\":\"+n.x+\":\"+n.y}for(var c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.text?u.text.toString():null;if(h){var p=l(h,f),d=l(h,f,!0);if(p in r&&d in e&&r[p]!==e[d]){var g=s(p,d,f),m=o(p,d,n[g].geometry);delete e[p],delete r[d],r[l(h,n[m].geometry,!0)]=m,n[g].geometry=null}else p in r?o(p,d,f):d in e?s(p,d,f):(a(c),e[p]=i-1,r[d]=i-1)}else a(c)}return n.filter((function(t){return t.geometry}))}(this.features)),this.sortFeaturesByKey&&this.features.sort((function(t,e){return t.sortKey-e.sortKey}))}},fc.prototype.update=function(t,e,r){this.stateDependentLayers.length&&(this.text.programConfigurations.updatePaintArrays(t,e,this.layers,r),this.icon.programConfigurations.updatePaintArrays(t,e,this.layers,r))},fc.prototype.isEmpty=function(){return 0===this.symbolInstances.length&&!this.hasRTLText},fc.prototype.uploadPending=function(){return!this.uploaded||this.text.programConfigurations.needsUpload||this.icon.programConfigurations.needsUpload},fc.prototype.upload=function(t){!this.uploaded&&this.hasDebugData()&&(this.textCollisionBox.upload(t),this.iconCollisionBox.upload(t)),this.text.upload(t,this.sortFeaturesByY,!this.uploaded,this.text.programConfigurations.needsUpload),this.icon.upload(t,this.sortFeaturesByY,!this.uploaded,this.icon.programConfigurations.needsUpload),this.uploaded=!0},fc.prototype.destroyDebugData=function(){this.textCollisionBox.destroy(),this.iconCollisionBox.destroy()},fc.prototype.destroy=function(){this.text.destroy(),this.icon.destroy(),this.hasDebugData()&&this.destroyDebugData()},fc.prototype.addToLineVertexArray=function(t,e){var r=this.lineVertexArray.length;if(void 0!==t.segment){for(var n=t.dist(e[t.segment+1]),i=t.dist(e[t.segment]),a={},o=t.segment+1;o<e.length;o++)a[o]={x:e[o].x,y:e[o].y,tileUnitDistanceFromAnchor:n},o<e.length-1&&(n+=e[o+1].dist(e[o]));for(var s=t.segment||0;s>=0;s--)a[s]={x:e[s].x,y:e[s].y,tileUnitDistanceFromAnchor:i},s>0&&(i+=e[s-1].dist(e[s]));for(var l=0;l<e.length;l++){var c=a[l];this.lineVertexArray.emplaceBack(c.x,c.y,c.tileUnitDistanceFromAnchor)}}return{lineStartIndex:r,lineLength:this.lineVertexArray.length-r}},fc.prototype.addSymbols=function(t,e,r,n,i,a,o,s,l,c,u,f){for(var h=t.indexArray,p=t.layoutVertexArray,d=t.segments.prepareSegment(4*e.length,p,h,a.sortKey),g=this.glyphOffsetArray.length,m=d.vertexLength,v=this.allowVerticalPlacement&&o===gl.vertical?Math.PI/2:0,y=a.text&&a.text.sections,x=0;x<e.length;x++){var b=e[x],_=b.tl,w=b.tr,T=b.bl,k=b.br,M=b.tex,A=b.pixelOffsetTL,S=b.pixelOffsetBR,E=b.minFontScaleX,C=b.minFontScaleY,L=b.glyphOffset,I=b.isSDF,P=b.sectionIndex,z=d.vertexLength,O=L[1];oc(p,s.x,s.y,_.x,O+_.y,M.x,M.y,r,I,A.x,A.y,E,C),oc(p,s.x,s.y,w.x,O+w.y,M.x+M.w,M.y,r,I,S.x,A.y,E,C),oc(p,s.x,s.y,T.x,O+T.y,M.x,M.y+M.h,r,I,A.x,S.y,E,C),oc(p,s.x,s.y,k.x,O+k.y,M.x+M.w,M.y+M.h,r,I,S.x,S.y,E,C),sc(t.dynamicLayoutVertexArray,s,v),h.emplaceBack(z,z+1,z+2),h.emplaceBack(z+1,z+2,z+3),d.vertexLength+=4,d.primitiveLength+=2,this.glyphOffsetArray.emplaceBack(L[0]),x!==e.length-1&&P===e[x+1].sectionIndex||t.programConfigurations.populatePaintArrays(p.length,a,a.index,{},f,y&&y[P])}t.placedSymbolArray.emplaceBack(s.x,s.y,g,this.glyphOffsetArray.length-g,m,l,c,s.segment,r?r[0]:0,r?r[1]:0,n[0],n[1],o,0,!1,0,u)},fc.prototype._addCollisionDebugVertex=function(t,e,r,n,i,a){return e.emplaceBack(0,0),t.emplaceBack(r.x,r.y,n,i,Math.round(a.x),Math.round(a.y))},fc.prototype.addCollisionDebugVertices=function(t,e,r,n,a,o,s){var l=a.segments.prepareSegment(4,a.layoutVertexArray,a.indexArray),c=l.vertexLength,u=a.layoutVertexArray,f=a.collisionVertexArray,h=s.anchorX,p=s.anchorY;this._addCollisionDebugVertex(u,f,o,h,p,new i(t,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,e)),this._addCollisionDebugVertex(u,f,o,h,p,new i(r,n)),this._addCollisionDebugVertex(u,f,o,h,p,new i(t,n)),l.vertexLength+=4;var d=a.indexArray;d.emplaceBack(c,c+1),d.emplaceBack(c+1,c+2),d.emplaceBack(c+2,c+3),d.emplaceBack(c+3,c),l.primitiveLength+=4},fc.prototype.addDebugCollisionBoxes=function(t,e,r,n){for(var i=t;i<e;i++){var a=this.collisionBoxArray.get(i);this.addCollisionDebugVertices(a.x1,a.y1,a.x2,a.y2,n?this.textCollisionBox:this.iconCollisionBox,a.anchorPoint,r)}},fc.prototype.generateCollisionDebugBuffers=function(){this.hasDebugData()&&this.destroyDebugData(),this.textCollisionBox=new uc(Oi,Bs.members,qi),this.iconCollisionBox=new uc(Oi,Bs.members,qi);for(var t=0;t<this.symbolInstances.length;t++){var e=this.symbolInstances.get(t);this.addDebugCollisionBoxes(e.textBoxStartIndex,e.textBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.verticalTextBoxStartIndex,e.verticalTextBoxEndIndex,e,!0),this.addDebugCollisionBoxes(e.iconBoxStartIndex,e.iconBoxEndIndex,e,!1),this.addDebugCollisionBoxes(e.verticalIconBoxStartIndex,e.verticalIconBoxEndIndex,e,!1)}},fc.prototype._deserializeCollisionBoxesForSymbol=function(t,e,r,n,i,a,o,s,l){for(var c={},u=e;u<r;u++){var f=t.get(u);c.textBox={x1:f.x1,y1:f.y1,x2:f.x2,y2:f.y2,anchorPointX:f.anchorPointX,anchorPointY:f.anchorPointY},c.textFeatureIndex=f.featureIndex;break}for(var h=n;h<i;h++){var p=t.get(h);c.verticalTextBox={x1:p.x1,y1:p.y1,x2:p.x2,y2:p.y2,anchorPointX:p.anchorPointX,anchorPointY:p.anchorPointY},c.verticalTextFeatureIndex=p.featureIndex;break}for(var d=a;d<o;d++){var g=t.get(d);c.iconBox={x1:g.x1,y1:g.y1,x2:g.x2,y2:g.y2,anchorPointX:g.anchorPointX,anchorPointY:g.anchorPointY},c.iconFeatureIndex=g.featureIndex;break}for(var m=s;m<l;m++){var v=t.get(m);c.verticalIconBox={x1:v.x1,y1:v.y1,x2:v.x2,y2:v.y2,anchorPointX:v.anchorPointX,anchorPointY:v.anchorPointY},c.verticalIconFeatureIndex=v.featureIndex;break}return c},fc.prototype.deserializeCollisionBoxes=function(t){this.collisionArrays=[];for(var e=0;e<this.symbolInstances.length;e++){var r=this.symbolInstances.get(e);this.collisionArrays.push(this._deserializeCollisionBoxesForSymbol(t,r.textBoxStartIndex,r.textBoxEndIndex,r.verticalTextBoxStartIndex,r.verticalTextBoxEndIndex,r.iconBoxStartIndex,r.iconBoxEndIndex,r.verticalIconBoxStartIndex,r.verticalIconBoxEndIndex))}},fc.prototype.hasTextData=function(){return this.text.segments.get().length>0},fc.prototype.hasIconData=function(){return this.icon.segments.get().length>0},fc.prototype.hasDebugData=function(){return this.textCollisionBox&&this.iconCollisionBox},fc.prototype.hasTextCollisionBoxData=function(){return this.hasDebugData()&&this.textCollisionBox.segments.get().length>0},fc.prototype.hasIconCollisionBoxData=function(){return this.hasDebugData()&&this.iconCollisionBox.segments.get().length>0},fc.prototype.addIndicesForPlacedSymbol=function(t,e){for(var r=t.placedSymbolArray.get(e),n=r.vertexStartIndex+4*r.numGlyphs,i=r.vertexStartIndex;i<n;i+=4)t.indexArray.emplaceBack(i,i+1,i+2),t.indexArray.emplaceBack(i+1,i+2,i+3)},fc.prototype.getSortedSymbolIndexes=function(t){if(this.sortedAngle===t&&void 0!==this.symbolInstanceIndexes)return this.symbolInstanceIndexes;for(var e=Math.sin(t),r=Math.cos(t),n=[],i=[],a=[],o=0;o<this.symbolInstances.length;++o){a.push(o);var s=this.symbolInstances.get(o);n.push(0|Math.round(e*s.anchorX+r*s.anchorY)),i.push(s.featureIndex)}return a.sort((function(t,e){return n[t]-n[e]||i[e]-i[t]})),a},fc.prototype.addToSortKeyRanges=function(t,e){var r=this.sortKeyRanges[this.sortKeyRanges.length-1];r&&r.sortKey===e?r.symbolInstanceEnd=t+1:this.sortKeyRanges.push({sortKey:e,symbolInstanceStart:t,symbolInstanceEnd:t+1})},fc.prototype.sortFeatures=function(t){var e=this;if(this.sortFeaturesByY&&this.sortedAngle!==t&&!(this.text.segments.get().length>1||this.icon.segments.get().length>1)){this.symbolInstanceIndexes=this.getSortedSymbolIndexes(t),this.sortedAngle=t,this.text.indexArray.clear(),this.icon.indexArray.clear(),this.featureSortOrder=[];for(var r=0,n=this.symbolInstanceIndexes;r<n.length;r+=1){var i=this.symbolInstances.get(n[r]);this.featureSortOrder.push(i.featureIndex),[i.rightJustifiedTextSymbolIndex,i.centerJustifiedTextSymbolIndex,i.leftJustifiedTextSymbolIndex].forEach((function(t,r,n){t>=0&&n.indexOf(t)===r&&e.addIndicesForPlacedSymbol(e.text,t)})),i.verticalPlacedTextSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.text,i.verticalPlacedTextSymbolIndex),i.placedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.placedIconSymbolIndex),i.verticalPlacedIconSymbolIndex>=0&&this.addIndicesForPlacedSymbol(this.icon,i.verticalPlacedIconSymbolIndex)}this.text.indexBuffer&&this.text.indexBuffer.updateData(this.text.indexArray),this.icon.indexBuffer&&this.icon.indexBuffer.updateData(this.icon.indexArray)}},Dn(\"SymbolBucket\",fc,{omit:[\"layers\",\"collisionBoxArray\",\"features\",\"compareText\"]}),fc.MAX_GLYPHS=65535,fc.addDynamicAttributes=sc;var hc=new yi({\"symbol-placement\":new pi(At.layout_symbol[\"symbol-placement\"]),\"symbol-spacing\":new pi(At.layout_symbol[\"symbol-spacing\"]),\"symbol-avoid-edges\":new pi(At.layout_symbol[\"symbol-avoid-edges\"]),\"symbol-sort-key\":new di(At.layout_symbol[\"symbol-sort-key\"]),\"symbol-z-order\":new pi(At.layout_symbol[\"symbol-z-order\"]),\"icon-allow-overlap\":new pi(At.layout_symbol[\"icon-allow-overlap\"]),\"icon-ignore-placement\":new pi(At.layout_symbol[\"icon-ignore-placement\"]),\"icon-optional\":new pi(At.layout_symbol[\"icon-optional\"]),\"icon-rotation-alignment\":new pi(At.layout_symbol[\"icon-rotation-alignment\"]),\"icon-size\":new di(At.layout_symbol[\"icon-size\"]),\"icon-text-fit\":new pi(At.layout_symbol[\"icon-text-fit\"]),\"icon-text-fit-padding\":new pi(At.layout_symbol[\"icon-text-fit-padding\"]),\"icon-image\":new di(At.layout_symbol[\"icon-image\"]),\"icon-rotate\":new di(At.layout_symbol[\"icon-rotate\"]),\"icon-padding\":new pi(At.layout_symbol[\"icon-padding\"]),\"icon-keep-upright\":new pi(At.layout_symbol[\"icon-keep-upright\"]),\"icon-offset\":new di(At.layout_symbol[\"icon-offset\"]),\"icon-anchor\":new di(At.layout_symbol[\"icon-anchor\"]),\"icon-pitch-alignment\":new pi(At.layout_symbol[\"icon-pitch-alignment\"]),\"text-pitch-alignment\":new pi(At.layout_symbol[\"text-pitch-alignment\"]),\"text-rotation-alignment\":new pi(At.layout_symbol[\"text-rotation-alignment\"]),\"text-field\":new di(At.layout_symbol[\"text-field\"]),\"text-font\":new di(At.layout_symbol[\"text-font\"]),\"text-size\":new di(At.layout_symbol[\"text-size\"]),\"text-max-width\":new di(At.layout_symbol[\"text-max-width\"]),\"text-line-height\":new pi(At.layout_symbol[\"text-line-height\"]),\"text-letter-spacing\":new di(At.layout_symbol[\"text-letter-spacing\"]),\"text-justify\":new di(At.layout_symbol[\"text-justify\"]),\"text-radial-offset\":new di(At.layout_symbol[\"text-radial-offset\"]),\"text-variable-anchor\":new pi(At.layout_symbol[\"text-variable-anchor\"]),\"text-anchor\":new di(At.layout_symbol[\"text-anchor\"]),\"text-max-angle\":new pi(At.layout_symbol[\"text-max-angle\"]),\"text-writing-mode\":new pi(At.layout_symbol[\"text-writing-mode\"]),\"text-rotate\":new di(At.layout_symbol[\"text-rotate\"]),\"text-padding\":new pi(At.layout_symbol[\"text-padding\"]),\"text-keep-upright\":new pi(At.layout_symbol[\"text-keep-upright\"]),\"text-transform\":new di(At.layout_symbol[\"text-transform\"]),\"text-offset\":new di(At.layout_symbol[\"text-offset\"]),\"text-allow-overlap\":new pi(At.layout_symbol[\"text-allow-overlap\"]),\"text-ignore-placement\":new pi(At.layout_symbol[\"text-ignore-placement\"]),\"text-optional\":new pi(At.layout_symbol[\"text-optional\"])}),pc={paint:new yi({\"icon-opacity\":new di(At.paint_symbol[\"icon-opacity\"]),\"icon-color\":new di(At.paint_symbol[\"icon-color\"]),\"icon-halo-color\":new di(At.paint_symbol[\"icon-halo-color\"]),\"icon-halo-width\":new di(At.paint_symbol[\"icon-halo-width\"]),\"icon-halo-blur\":new di(At.paint_symbol[\"icon-halo-blur\"]),\"icon-translate\":new pi(At.paint_symbol[\"icon-translate\"]),\"icon-translate-anchor\":new pi(At.paint_symbol[\"icon-translate-anchor\"]),\"text-opacity\":new di(At.paint_symbol[\"text-opacity\"]),\"text-color\":new di(At.paint_symbol[\"text-color\"],{runtimeType:Bt,getOverride:function(t){return t.textColor},hasOverride:function(t){return!!t.textColor}}),\"text-halo-color\":new di(At.paint_symbol[\"text-halo-color\"]),\"text-halo-width\":new di(At.paint_symbol[\"text-halo-width\"]),\"text-halo-blur\":new di(At.paint_symbol[\"text-halo-blur\"]),\"text-translate\":new pi(At.paint_symbol[\"text-translate\"]),\"text-translate-anchor\":new pi(At.paint_symbol[\"text-translate-anchor\"])}),layout:hc},dc=function(t){this.type=t.property.overrides?t.property.overrides.runtimeType:Ot,this.defaultValue=t};dc.prototype.evaluate=function(t){if(t.formattedSection){var e=this.defaultValue.property.overrides;if(e&&e.hasOverride(t.formattedSection))return e.getOverride(t.formattedSection)}return t.feature&&t.featureState?this.defaultValue.evaluate(t.feature,t.featureState):this.defaultValue.property.specification.default},dc.prototype.eachChild=function(t){this.defaultValue.isConstant()||t(this.defaultValue.value._styleExpression.expression)},dc.prototype.outputDefined=function(){return!1},dc.prototype.serialize=function(){return null},Dn(\"FormatSectionOverride\",dc,{omit:[\"defaultValue\"]});var gc=function(t){function e(e){t.call(this,e,pc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.recalculate=function(e,r){if(t.prototype.recalculate.call(this,e,r),\"auto\"===this.layout.get(\"icon-rotation-alignment\")&&(this.layout._values[\"icon-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-rotation-alignment\")&&(this.layout._values[\"text-rotation-alignment\"]=\"point\"!==this.layout.get(\"symbol-placement\")?\"map\":\"viewport\"),\"auto\"===this.layout.get(\"text-pitch-alignment\")&&(this.layout._values[\"text-pitch-alignment\"]=this.layout.get(\"text-rotation-alignment\")),\"auto\"===this.layout.get(\"icon-pitch-alignment\")&&(this.layout._values[\"icon-pitch-alignment\"]=this.layout.get(\"icon-rotation-alignment\")),\"point\"===this.layout.get(\"symbol-placement\")){var n=this.layout.get(\"text-writing-mode\");if(n){for(var i=[],a=0,o=n;a<o.length;a+=1){var s=o[a];i.indexOf(s)<0&&i.push(s)}this.layout._values[\"text-writing-mode\"]=i}else this.layout._values[\"text-writing-mode\"]=[\"horizontal\"]}this._setPaintOverrides()},e.prototype.getValueAndResolveTokens=function(t,e,r,n){var i=this.layout.get(t).evaluate(e,{},r,n),a=this._unevaluatedLayout._values[t];return a.isDataDriven()||Vr(a.value)||!i?i:function(t,e){return e.replace(/{([^{}]+)}/g,(function(e,r){return r in t?String(t[r]):\"\"}))}(e.properties,i)},e.prototype.createBucket=function(t){return new fc(t)},e.prototype.queryRadius=function(){return 0},e.prototype.queryIntersectsFeature=function(){return!1},e.prototype._setPaintOverrides=function(){for(var t=0,r=pc.paint.overridableProperties;t<r.length;t+=1){var n=r[t];if(e.hasPaintOverride(this.layout,n)){var i,a=this.paint.get(n),o=new dc(a),s=new Ur(o,a.property.specification);i=\"constant\"===a.value.kind||\"source\"===a.value.kind?new Hr(\"source\",s):new Gr(\"composite\",s,a.value.zoomStops,a.value._interpolationType),this.paint._values[n]=new fi(a.property,i,a.parameters)}}},e.prototype._handleOverridablePaintPropertyUpdate=function(t,r,n){return!(!this.layout||r.isDataDriven()||n.isDataDriven())&&e.hasPaintOverride(this.layout,t)},e.hasPaintOverride=function(t,e){var r=t.get(\"text-field\"),n=pc.paint.properties[e],i=!1,a=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n.overrides&&n.overrides.hasOverride(r[e]))return void(i=!0)};if(\"constant\"===r.value.kind&&r.value.value instanceof te)a(r.value.value.sections);else if(\"source\"===r.value.kind){var o=function(t){i||(t instanceof oe&&ie(t.value)===Vt?a(t.value.sections):t instanceof ue?a(t.sections):t.eachChild(o))},s=r.value;s._styleExpression&&o(s._styleExpression.expression)}return i},e}(xi),mc={paint:new yi({\"background-color\":new pi(At.paint_background[\"background-color\"]),\"background-pattern\":new mi(At.paint_background[\"background-pattern\"]),\"background-opacity\":new pi(At.paint_background[\"background-opacity\"])})},vc=function(t){function e(e){t.call(this,e,mc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),yc={paint:new yi({\"raster-opacity\":new pi(At.paint_raster[\"raster-opacity\"]),\"raster-hue-rotate\":new pi(At.paint_raster[\"raster-hue-rotate\"]),\"raster-brightness-min\":new pi(At.paint_raster[\"raster-brightness-min\"]),\"raster-brightness-max\":new pi(At.paint_raster[\"raster-brightness-max\"]),\"raster-saturation\":new pi(At.paint_raster[\"raster-saturation\"]),\"raster-contrast\":new pi(At.paint_raster[\"raster-contrast\"]),\"raster-resampling\":new pi(At.paint_raster[\"raster-resampling\"]),\"raster-fade-duration\":new pi(At.paint_raster[\"raster-fade-duration\"])})},xc=function(t){function e(e){t.call(this,e,yc)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(xi),bc=function(t){function e(e){t.call(this,e,{}),this.implementation=e}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.is3D=function(){return\"3d\"===this.implementation.renderingMode},e.prototype.hasOffscreenPass=function(){return void 0!==this.implementation.prerender},e.prototype.recalculate=function(){},e.prototype.updateTransitions=function(){},e.prototype.hasTransition=function(){},e.prototype.serialize=function(){},e.prototype.onAdd=function(t){this.implementation.onAdd&&this.implementation.onAdd(t,t.painter.context.gl)},e.prototype.onRemove=function(t){this.implementation.onRemove&&this.implementation.onRemove(t,t.painter.context.gl)},e}(xi),_c={circle:oo,heatmap:vo,hillshade:xo,fill:as,\"fill-extrusion\":ws,line:zs,symbol:gc,background:vc,raster:xc},wc=self.HTMLImageElement,Tc=self.HTMLCanvasElement,kc=self.HTMLVideoElement,Mc=self.ImageData,Ac=self.ImageBitmap,Sc=function(t,e,r,n){this.context=t,this.format=r,this.texture=t.gl.createTexture(),this.update(e,n)};Sc.prototype.update=function(t,e,r){var n=t.width,i=t.height,a=!(this.size&&this.size[0]===n&&this.size[1]===i||r),o=this.context,s=o.gl;if(this.useMipmap=Boolean(e&&e.useMipmap),s.bindTexture(s.TEXTURE_2D,this.texture),o.pixelStoreUnpackFlipY.set(!1),o.pixelStoreUnpack.set(1),o.pixelStoreUnpackPremultiplyAlpha.set(this.format===s.RGBA&&(!e||!1!==e.premultiply)),a)this.size=[n,i],t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texImage2D(s.TEXTURE_2D,0,this.format,this.format,s.UNSIGNED_BYTE,t):s.texImage2D(s.TEXTURE_2D,0,this.format,n,i,0,this.format,s.UNSIGNED_BYTE,t.data);else{var l=r||{x:0,y:0},c=l.x,u=l.y;t instanceof wc||t instanceof Tc||t instanceof kc||t instanceof Mc||Ac&&t instanceof Ac?s.texSubImage2D(s.TEXTURE_2D,0,c,u,s.RGBA,s.UNSIGNED_BYTE,t):s.texSubImage2D(s.TEXTURE_2D,0,c,u,n,i,s.RGBA,s.UNSIGNED_BYTE,t.data)}this.useMipmap&&this.isSizePowerOfTwo()&&s.generateMipmap(s.TEXTURE_2D)},Sc.prototype.bind=function(t,e,r){var n=this.context.gl;n.bindTexture(n.TEXTURE_2D,this.texture),r!==n.LINEAR_MIPMAP_NEAREST||this.isSizePowerOfTwo()||(r=n.LINEAR),t!==this.filter&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,t),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,r||t),this.filter=t),e!==this.wrap&&(n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,e),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,e),this.wrap=e)},Sc.prototype.isSizePowerOfTwo=function(){return this.size[0]===this.size[1]&&Math.log(this.size[0])/Math.LN2%1==0},Sc.prototype.destroy=function(){this.context.gl.deleteTexture(this.texture),this.texture=null};var Ec=function(t){var e=this;this._callback=t,this._triggered=!1,\"undefined\"!=typeof MessageChannel&&(this._channel=new MessageChannel,this._channel.port2.onmessage=function(){e._triggered=!1,e._callback()})};Ec.prototype.trigger=function(){var t=this;this._triggered||(this._triggered=!0,this._channel?this._channel.port1.postMessage(!0):setTimeout((function(){t._triggered=!1,t._callback()}),0))},Ec.prototype.remove=function(){delete this._channel,this._callback=function(){}};var Cc=function(t,e,r){this.target=t,this.parent=e,this.mapId=r,this.callbacks={},this.tasks={},this.taskQueue=[],this.cancelCallbacks={},g([\"receive\",\"process\"],this),this.invoker=new Ec(this.process),this.target.addEventListener(\"message\",this.receive,!1),this.globalScope=k()?t:self};function Lc(t,e,r){var n=2*Math.PI*6378137/256/Math.pow(2,r);return[t*n-2*Math.PI*6378137/2,e*n-2*Math.PI*6378137/2]}Cc.prototype.send=function(t,e,r,n,i){var a=this;void 0===i&&(i=!1);var o=Math.round(1e18*Math.random()).toString(36).substring(0,10);r&&(this.callbacks[o]=r);var s=S(this.globalScope)?void 0:[];return this.target.postMessage({id:o,type:t,hasCallback:!!r,targetMapId:n,mustQueue:i,sourceMapId:this.mapId,data:Nn(e,s)},s),{cancel:function(){r&&delete a.callbacks[o],a.target.postMessage({id:o,type:\"<cancel>\",targetMapId:n,sourceMapId:a.mapId})}}},Cc.prototype.receive=function(t){var e=t.data,r=e.id;if(r&&(!e.targetMapId||this.mapId===e.targetMapId))if(\"<cancel>\"===e.type){delete this.tasks[r];var n=this.cancelCallbacks[r];delete this.cancelCallbacks[r],n&&n()}else k()||e.mustQueue?(this.tasks[r]=e,this.taskQueue.push(r),this.invoker.trigger()):this.processTask(r,e)},Cc.prototype.process=function(){if(this.taskQueue.length){var t=this.taskQueue.shift(),e=this.tasks[t];delete this.tasks[t],this.taskQueue.length&&this.invoker.trigger(),e&&this.processTask(t,e)}},Cc.prototype.processTask=function(t,e){var r=this;if(\"<response>\"===e.type){var n=this.callbacks[t];delete this.callbacks[t],n&&(e.error?n(jn(e.error)):n(null,jn(e.data)))}else{var i=!1,a=S(this.globalScope)?void 0:[],o=e.hasCallback?function(e,n){i=!0,delete r.cancelCallbacks[t],r.target.postMessage({id:t,type:\"<response>\",sourceMapId:r.mapId,error:e?Nn(e):null,data:Nn(n,a)},a)}:function(t){i=!0},s=null,l=jn(e.data);if(this.parent[e.type])s=this.parent[e.type](e.sourceMapId,l,o);else if(this.parent.getWorkerSource){var c=e.type.split(\".\");s=this.parent.getWorkerSource(e.sourceMapId,c[0],l.source)[c[1]](l,o)}else o(new Error(\"Could not find function \"+e.type));!i&&s&&s.cancel&&(this.cancelCallbacks[t]=s.cancel)}},Cc.prototype.remove=function(){this.invoker.remove(),this.target.removeEventListener(\"message\",this.receive,!1)};var Ic=function(t,e){t&&(e?this.setSouthWest(t).setNorthEast(e):4===t.length?this.setSouthWest([t[0],t[1]]).setNorthEast([t[2],t[3]]):this.setSouthWest(t[0]).setNorthEast(t[1]))};Ic.prototype.setNorthEast=function(t){return this._ne=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.setSouthWest=function(t){return this._sw=t instanceof Pc?new Pc(t.lng,t.lat):Pc.convert(t),this},Ic.prototype.extend=function(t){var e,r,n=this._sw,i=this._ne;if(t instanceof Pc)e=t,r=t;else{if(!(t instanceof Ic))return Array.isArray(t)?4===t.length||t.every(Array.isArray)?this.extend(Ic.convert(t)):this.extend(Pc.convert(t)):this;if(r=t._ne,!(e=t._sw)||!r)return this}return n||i?(n.lng=Math.min(e.lng,n.lng),n.lat=Math.min(e.lat,n.lat),i.lng=Math.max(r.lng,i.lng),i.lat=Math.max(r.lat,i.lat)):(this._sw=new Pc(e.lng,e.lat),this._ne=new Pc(r.lng,r.lat)),this},Ic.prototype.getCenter=function(){return new Pc((this._sw.lng+this._ne.lng)/2,(this._sw.lat+this._ne.lat)/2)},Ic.prototype.getSouthWest=function(){return this._sw},Ic.prototype.getNorthEast=function(){return this._ne},Ic.prototype.getNorthWest=function(){return new Pc(this.getWest(),this.getNorth())},Ic.prototype.getSouthEast=function(){return new Pc(this.getEast(),this.getSouth())},Ic.prototype.getWest=function(){return this._sw.lng},Ic.prototype.getSouth=function(){return this._sw.lat},Ic.prototype.getEast=function(){return this._ne.lng},Ic.prototype.getNorth=function(){return this._ne.lat},Ic.prototype.toArray=function(){return[this._sw.toArray(),this._ne.toArray()]},Ic.prototype.toString=function(){return\"LngLatBounds(\"+this._sw.toString()+\", \"+this._ne.toString()+\")\"},Ic.prototype.isEmpty=function(){return!(this._sw&&this._ne)},Ic.prototype.contains=function(t){var e=Pc.convert(t),r=e.lng,n=e.lat,i=this._sw.lng<=r&&r<=this._ne.lng;return this._sw.lng>this._ne.lng&&(i=this._sw.lng>=r&&r>=this._ne.lng),this._sw.lat<=n&&n<=this._ne.lat&&i},Ic.convert=function(t){return!t||t instanceof Ic?t:new Ic(t)};var Pc=function(t,e){if(isNaN(t)||isNaN(e))throw new Error(\"Invalid LngLat object: (\"+t+\", \"+e+\")\");if(this.lng=+t,this.lat=+e,this.lat>90||this.lat<-90)throw new Error(\"Invalid LngLat latitude value: must be between -90 and 90\")};Pc.prototype.wrap=function(){return new Pc(c(this.lng,-180,180),this.lat)},Pc.prototype.toArray=function(){return[this.lng,this.lat]},Pc.prototype.toString=function(){return\"LngLat(\"+this.lng+\", \"+this.lat+\")\"},Pc.prototype.distanceTo=function(t){var e=Math.PI/180,r=this.lat*e,n=t.lat*e,i=Math.sin(r)*Math.sin(n)+Math.cos(r)*Math.cos(n)*Math.cos((t.lng-this.lng)*e);return 6371008.8*Math.acos(Math.min(i,1))},Pc.prototype.toBounds=function(t){void 0===t&&(t=0);var e=360*t/40075017,r=e/Math.cos(Math.PI/180*this.lat);return new Ic(new Pc(this.lng-r,this.lat-e),new Pc(this.lng+r,this.lat+e))},Pc.convert=function(t){if(t instanceof Pc)return t;if(Array.isArray(t)&&(2===t.length||3===t.length))return new Pc(Number(t[0]),Number(t[1]));if(!Array.isArray(t)&&\"object\"==typeof t&&null!==t)return new Pc(Number(\"lng\"in t?t.lng:t.lon),Number(t.lat));throw new Error(\"`LngLatLike` argument must be specified as a LngLat instance, an object {lng: <lng>, lat: <lat>}, an object {lon: <lng>, lat: <lat>}, or an array of [<lng>, <lat>]\")};var zc=2*Math.PI*6371008.8;function Oc(t){return zc*Math.cos(t*Math.PI/180)}function Dc(t){return(180+t)/360}function Rc(t){return(180-180/Math.PI*Math.log(Math.tan(Math.PI/4+t*Math.PI/360)))/360}function Fc(t,e){return t/Oc(e)}function Bc(t){return 360/Math.PI*Math.atan(Math.exp((180-360*t)*Math.PI/180))-90}var Nc=function(t,e,r){void 0===r&&(r=0),this.x=+t,this.y=+e,this.z=+r};Nc.fromLngLat=function(t,e){void 0===e&&(e=0);var r=Pc.convert(t);return new Nc(Dc(r.lng),Rc(r.lat),Fc(e,r.lat))},Nc.prototype.toLngLat=function(){return new Pc(360*this.x-180,Bc(this.y))},Nc.prototype.toAltitude=function(){return this.z*Oc(Bc(this.y))},Nc.prototype.meterInMercatorCoordinateUnits=function(){return 1/zc*(t=Bc(this.y),1/Math.cos(t*Math.PI/180));var t};var jc=function(t,e,r){this.z=t,this.x=e,this.y=r,this.key=qc(0,t,t,e,r)};jc.prototype.equals=function(t){return this.z===t.z&&this.x===t.x&&this.y===t.y},jc.prototype.url=function(t,e){var r,n,i,a,o,s=(n=this.y,i=this.z,a=Lc(256*(r=this.x),256*(n=Math.pow(2,i)-n-1),i),o=Lc(256*(r+1),256*(n+1),i),a[0]+\",\"+a[1]+\",\"+o[0]+\",\"+o[1]),l=function(t,e,r){for(var n,i=\"\",a=t;a>0;a--)i+=(e&(n=1<<a-1)?1:0)+(r&n?2:0);return i}(this.z,this.x,this.y);return t[(this.x+this.y)%t.length].replace(\"{prefix}\",(this.x%16).toString(16)+(this.y%16).toString(16)).replace(\"{z}\",String(this.z)).replace(\"{x}\",String(this.x)).replace(\"{y}\",String(\"tms\"===e?Math.pow(2,this.z)-this.y-1:this.y)).replace(\"{quadkey}\",l).replace(\"{bbox-epsg-3857}\",s)},jc.prototype.getTilePoint=function(t){var e=Math.pow(2,this.z);return new i(8192*(t.x*e-this.x),8192*(t.y*e-this.y))},jc.prototype.toString=function(){return this.z+\"/\"+this.x+\"/\"+this.y};var Uc=function(t,e){this.wrap=t,this.canonical=e,this.key=qc(t,e.z,e.z,e.x,e.y)},Vc=function(t,e,r,n,i){this.overscaledZ=t,this.wrap=e,this.canonical=new jc(r,+n,+i),this.key=qc(e,t,r,n,i)};function qc(t,e,r,n,i){(t*=2)<0&&(t=-1*t-1);var a=1<<r;return(a*a*t+a*i+n).toString(36)+r.toString(36)+e.toString(36)}Vc.prototype.equals=function(t){return this.overscaledZ===t.overscaledZ&&this.wrap===t.wrap&&this.canonical.equals(t.canonical)},Vc.prototype.scaledTo=function(t){var e=this.canonical.z-t;return t>this.canonical.z?new Vc(t,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y):new Vc(t,this.wrap,t,this.canonical.x>>e,this.canonical.y>>e)},Vc.prototype.calculateScaledKey=function(t,e){var r=this.canonical.z-t;return t>this.canonical.z?qc(this.wrap*+e,t,this.canonical.z,this.canonical.x,this.canonical.y):qc(this.wrap*+e,t,t,this.canonical.x>>r,this.canonical.y>>r)},Vc.prototype.isChildOf=function(t){if(t.wrap!==this.wrap)return!1;var e=this.canonical.z-t.canonical.z;return 0===t.overscaledZ||t.overscaledZ<this.overscaledZ&&t.canonical.x===this.canonical.x>>e&&t.canonical.y===this.canonical.y>>e},Vc.prototype.children=function(t){if(this.overscaledZ>=t)return[new Vc(this.overscaledZ+1,this.wrap,this.canonical.z,this.canonical.x,this.canonical.y)];var e=this.canonical.z+1,r=2*this.canonical.x,n=2*this.canonical.y;return[new Vc(e,this.wrap,e,r,n),new Vc(e,this.wrap,e,r+1,n),new Vc(e,this.wrap,e,r,n+1),new Vc(e,this.wrap,e,r+1,n+1)]},Vc.prototype.isLessThan=function(t){return this.wrap<t.wrap||!(this.wrap>t.wrap)&&(this.overscaledZ<t.overscaledZ||!(this.overscaledZ>t.overscaledZ)&&(this.canonical.x<t.canonical.x||!(this.canonical.x>t.canonical.x)&&this.canonical.y<t.canonical.y))},Vc.prototype.wrapped=function(){return new Vc(this.overscaledZ,0,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.unwrapTo=function(t){return new Vc(this.overscaledZ,t,this.canonical.z,this.canonical.x,this.canonical.y)},Vc.prototype.overscaleFactor=function(){return Math.pow(2,this.overscaledZ-this.canonical.z)},Vc.prototype.toUnwrapped=function(){return new Uc(this.wrap,this.canonical)},Vc.prototype.toString=function(){return this.overscaledZ+\"/\"+this.canonical.x+\"/\"+this.canonical.y},Vc.prototype.getTilePoint=function(t){return this.canonical.getTilePoint(new Nc(t.x-this.wrap,t.y))},Dn(\"CanonicalTileID\",jc),Dn(\"OverscaledTileID\",Vc,{omit:[\"posMatrix\"]});var Hc=function(t,e,r){if(this.uid=t,e.height!==e.width)throw new RangeError(\"DEM tiles must be square\");if(r&&\"mapbox\"!==r&&\"terrarium\"!==r)return _('\"'+r+'\" is not a valid encoding type. Valid types include \"mapbox\" and \"terrarium\".');this.stride=e.height;var n=this.dim=e.height-2;this.data=new Uint32Array(e.data.buffer),this.encoding=r||\"mapbox\";for(var i=0;i<n;i++)this.data[this._idx(-1,i)]=this.data[this._idx(0,i)],this.data[this._idx(n,i)]=this.data[this._idx(n-1,i)],this.data[this._idx(i,-1)]=this.data[this._idx(i,0)],this.data[this._idx(i,n)]=this.data[this._idx(i,n-1)];this.data[this._idx(-1,-1)]=this.data[this._idx(0,0)],this.data[this._idx(n,-1)]=this.data[this._idx(n-1,0)],this.data[this._idx(-1,n)]=this.data[this._idx(0,n-1)],this.data[this._idx(n,n)]=this.data[this._idx(n-1,n-1)]};Hc.prototype.get=function(t,e){var r=new Uint8Array(this.data.buffer),n=4*this._idx(t,e);return(\"terrarium\"===this.encoding?this._unpackTerrarium:this._unpackMapbox)(r[n],r[n+1],r[n+2])},Hc.prototype.getUnpackVector=function(){return\"terrarium\"===this.encoding?[256,1,1/256,32768]:[6553.6,25.6,.1,1e4]},Hc.prototype._idx=function(t,e){if(t<-1||t>=this.dim+1||e<-1||e>=this.dim+1)throw new RangeError(\"out of range source coordinates for DEM data\");return(e+1)*this.stride+(t+1)},Hc.prototype._unpackMapbox=function(t,e,r){return(256*t*256+256*e+r)/10-1e4},Hc.prototype._unpackTerrarium=function(t,e,r){return 256*t+e+r/256-32768},Hc.prototype.getPixels=function(){return new po({width:this.stride,height:this.stride},new Uint8Array(this.data.buffer))},Hc.prototype.backfillBorder=function(t,e,r){if(this.dim!==t.dim)throw new Error(\"dem dimension mismatch\");var n=e*this.dim,i=e*this.dim+this.dim,a=r*this.dim,o=r*this.dim+this.dim;switch(e){case-1:n=i-1;break;case 1:i=n+1}switch(r){case-1:a=o-1;break;case 1:o=a+1}for(var s=-e*this.dim,l=-r*this.dim,c=a;c<o;c++)for(var u=n;u<i;u++)this.data[this._idx(u,c)]=t.data[this._idx(u+s,c+l)]},Dn(\"DEMData\",Hc);var Gc=function(t){this._stringToNumber={},this._numberToString=[];for(var e=0;e<t.length;e++){var r=t[e];this._stringToNumber[r]=e,this._numberToString[e]=r}};Gc.prototype.encode=function(t){return this._stringToNumber[t]},Gc.prototype.decode=function(t){return this._numberToString[t]};var Yc=function(t,e,r,n,i){this.type=\"Feature\",this._vectorTileFeature=t,t._z=e,t._x=r,t._y=n,this.properties=t.properties,this.id=i},Wc={geometry:{configurable:!0}};Wc.geometry.get=function(){return void 0===this._geometry&&(this._geometry=this._vectorTileFeature.toGeoJSON(this._vectorTileFeature._x,this._vectorTileFeature._y,this._vectorTileFeature._z).geometry),this._geometry},Wc.geometry.set=function(t){this._geometry=t},Yc.prototype.toJSON=function(){var t={geometry:this.geometry};for(var e in this)\"_geometry\"!==e&&\"_vectorTileFeature\"!==e&&(t[e]=this[e]);return t},Object.defineProperties(Yc.prototype,Wc);var Xc=function(){this.state={},this.stateChanges={},this.deletedStates={}};Xc.prototype.updateState=function(t,e,r){var n=String(e);if(this.stateChanges[t]=this.stateChanges[t]||{},this.stateChanges[t][n]=this.stateChanges[t][n]||{},u(this.stateChanges[t][n],r),null===this.deletedStates[t])for(var i in this.deletedStates[t]={},this.state[t])i!==n&&(this.deletedStates[t][i]=null);else if(this.deletedStates[t]&&null===this.deletedStates[t][n])for(var a in this.deletedStates[t][n]={},this.state[t][n])r[a]||(this.deletedStates[t][n][a]=null);else for(var o in r)this.deletedStates[t]&&this.deletedStates[t][n]&&null===this.deletedStates[t][n][o]&&delete this.deletedStates[t][n][o]},Xc.prototype.removeFeatureState=function(t,e,r){if(null!==this.deletedStates[t]){var n=String(e);if(this.deletedStates[t]=this.deletedStates[t]||{},r&&void 0!==e)null!==this.deletedStates[t][n]&&(this.deletedStates[t][n]=this.deletedStates[t][n]||{},this.deletedStates[t][n][r]=null);else if(void 0!==e)if(this.stateChanges[t]&&this.stateChanges[t][n])for(r in this.deletedStates[t][n]={},this.stateChanges[t][n])this.deletedStates[t][n][r]=null;else this.deletedStates[t][n]=null;else this.deletedStates[t]=null}},Xc.prototype.getState=function(t,e){var r=String(e),n=u({},(this.state[t]||{})[r],(this.stateChanges[t]||{})[r]);if(null===this.deletedStates[t])return{};if(this.deletedStates[t]){var i=this.deletedStates[t][e];if(null===i)return{};for(var a in i)delete n[a]}return n},Xc.prototype.initializeTileState=function(t,e){t.setFeatureState(this.state,e)},Xc.prototype.coalesceChanges=function(t,e){var r={};for(var n in this.stateChanges){this.state[n]=this.state[n]||{};var i={};for(var a in this.stateChanges[n])this.state[n][a]||(this.state[n][a]={}),u(this.state[n][a],this.stateChanges[n][a]),i[a]=this.state[n][a];r[n]=i}for(var o in this.deletedStates){this.state[o]=this.state[o]||{};var s={};if(null===this.deletedStates[o])for(var l in this.state[o])s[l]={},this.state[o][l]={};else for(var c in this.deletedStates[o]){if(null===this.deletedStates[o][c])this.state[o][c]={};else for(var f=0,h=Object.keys(this.deletedStates[o][c]);f<h.length;f+=1)delete this.state[o][c][h[f]];s[c]=this.state[o][c]}r[o]=r[o]||{},u(r[o],s)}if(this.stateChanges={},this.deletedStates={},0!==Object.keys(r).length)for(var p in t)t[p].setFeatureState(r,e)};var Zc=function(t,e){this.tileID=t,this.x=t.canonical.x,this.y=t.canonical.y,this.z=t.canonical.z,this.grid=new Ln(8192,16,0),this.grid3D=new Ln(8192,16,0),this.featureIndexArray=new ra,this.promoteId=e};function Jc(t,e,r,n,i){return v(t,(function(t,a){var o=e instanceof hi?e.get(a):null;return o&&o.evaluate?o.evaluate(r,n,i):o}))}function Kc(t){for(var e=1/0,r=1/0,n=-1/0,i=-1/0,a=0,o=t;a<o.length;a+=1){var s=o[a];e=Math.min(e,s.x),r=Math.min(r,s.y),n=Math.max(n,s.x),i=Math.max(i,s.y)}return{minX:e,minY:r,maxX:n,maxY:i}}function Qc(t,e){return e-t}Zc.prototype.insert=function(t,e,r,n,i,a){var o=this.featureIndexArray.length;this.featureIndexArray.emplaceBack(r,n,i);for(var s=a?this.grid3D:this.grid,l=0;l<e.length;l++){for(var c=e[l],u=[1/0,1/0,-1/0,-1/0],f=0;f<c.length;f++){var h=c[f];u[0]=Math.min(u[0],h.x),u[1]=Math.min(u[1],h.y),u[2]=Math.max(u[2],h.x),u[3]=Math.max(u[3],h.y)}u[0]<8192&&u[1]<8192&&u[2]>=0&&u[3]>=0&&s.insert(o,u[0],u[1],u[2],u[3])}},Zc.prototype.loadVTLayers=function(){return this.vtLayers||(this.vtLayers=new gs.VectorTile(new Hs(this.rawTileData)).layers,this.sourceLayerCoder=new Gc(this.vtLayers?Object.keys(this.vtLayers).sort():[\"_geojsonTileLayer\"])),this.vtLayers},Zc.prototype.query=function(t,e,r,n){var a=this;this.loadVTLayers();for(var o=t.params||{},s=8192/t.tileSize/t.scale,l=rn(o.filter),c=t.queryGeometry,u=t.queryPadding*s,f=Kc(c),h=this.grid.query(f.minX-u,f.minY-u,f.maxX+u,f.maxY+u),p=Kc(t.cameraQueryGeometry),d=0,g=this.grid3D.query(p.minX-u,p.minY-u,p.maxX+u,p.maxY+u,(function(e,r,n,a){return function(t,e,r,n,a){for(var o=0,s=t;o<s.length;o+=1){var l=s[o];if(e<=l.x&&r<=l.y&&n>=l.x&&a>=l.y)return!0}var c=[new i(e,r),new i(e,a),new i(n,a),new i(n,r)];if(t.length>2)for(var u=0,f=c;u<f.length;u+=1)if(Wa(t,f[u]))return!0;for(var h=0;h<t.length-1;h++)if(Xa(t[h],t[h+1],c))return!0;return!1}(t.cameraQueryGeometry,e-u,r-u,n+u,a+u)}));d<g.length;d+=1)h.push(g[d]);h.sort(Qc);for(var m,v={},y=function(i){var u=h[i];if(u!==m){m=u;var f=a.featureIndexArray.get(u),p=null;a.loadMatchingFeature(v,f.bucketIndex,f.sourceLayerIndex,f.featureIndex,l,o.layers,o.availableImages,e,r,n,(function(e,r,n){return p||(p=Da(e)),r.queryIntersectsFeature(c,e,n,p,a.z,t.transform,s,t.pixelPosMatrix)}))}},x=0;x<h.length;x++)y(x);return v},Zc.prototype.loadMatchingFeature=function(t,e,r,n,i,a,o,s,l,c,u){var f=this.bucketLayerIDs[e];if(!a||function(t,e){for(var r=0;r<t.length;r++)if(e.indexOf(t[r])>=0)return!0;return!1}(a,f)){var h=this.sourceLayerCoder.decode(r),p=this.vtLayers[h].feature(n);if(i.filter(new ii(this.tileID.overscaledZ),p))for(var d=this.getId(p,h),g=0;g<f.length;g++){var m=f[g];if(!(a&&a.indexOf(m)<0)){var v=s[m];if(v){var y={};void 0!==d&&c&&(y=c.getState(v.sourceLayer||\"_geojsonTileLayer\",d));var x=l[m];x.paint=Jc(x.paint,v.paint,p,y,o),x.layout=Jc(x.layout,v.layout,p,y,o);var b=!u||u(p,v,y);if(b){var _=new Yc(p,this.z,this.x,this.y,d);_.layer=x;var w=t[m];void 0===w&&(w=t[m]=[]),w.push({featureIndex:n,feature:_,intersectionZ:b})}}}}}},Zc.prototype.lookupSymbolFeatures=function(t,e,r,n,i,a,o,s){var l={};this.loadVTLayers();for(var c=rn(i),u=0,f=t;u<f.length;u+=1)this.loadMatchingFeature(l,r,n,f[u],c,a,o,s,e);return l},Zc.prototype.hasLayer=function(t){for(var e=0,r=this.bucketLayerIDs;e<r.length;e+=1)for(var n=0,i=r[e];n<i.length;n+=1)if(t===i[n])return!0;return!1},Zc.prototype.getId=function(t,e){var r=t.id;return this.promoteId&&\"boolean\"==typeof(r=t.properties[\"string\"==typeof this.promoteId?this.promoteId:this.promoteId[e]])&&(r=Number(r)),r},Dn(\"FeatureIndex\",Zc,{omit:[\"rawTileData\",\"sourceLayerCoder\"]});var $c=function(t,e){this.tileID=t,this.uid=h(),this.uses=0,this.tileSize=e,this.buckets={},this.expirationTime=null,this.queryPadding=0,this.hasSymbolBuckets=!1,this.hasRTLText=!1,this.dependencies={},this.expiredRequestCount=0,this.state=\"loading\"};$c.prototype.registerFadeDuration=function(t){var e=t+this.timeAdded;e<R.now()||this.fadeEndTime&&e<this.fadeEndTime||(this.fadeEndTime=e)},$c.prototype.wasRequested=function(){return\"errored\"===this.state||\"loaded\"===this.state||\"reloading\"===this.state},$c.prototype.loadVectorData=function(t,e,r){if(this.hasData()&&this.unloadVectorData(),this.state=\"loaded\",t){for(var n in t.featureIndex&&(this.latestFeatureIndex=t.featureIndex,t.rawTileData?(this.latestRawTileData=t.rawTileData,this.latestFeatureIndex.rawTileData=t.rawTileData):this.latestRawTileData&&(this.latestFeatureIndex.rawTileData=this.latestRawTileData)),this.collisionBoxArray=t.collisionBoxArray,this.buckets=function(t,e){var r={};if(!e)return r;for(var n=function(){var t=a[i],n=t.layerIds.map((function(t){return e.getLayer(t)})).filter(Boolean);if(0!==n.length){t.layers=n,t.stateDependentLayerIds&&(t.stateDependentLayers=t.stateDependentLayerIds.map((function(t){return n.filter((function(e){return e.id===t}))[0]})));for(var o=0,s=n;o<s.length;o+=1)r[s[o].id]=t}},i=0,a=t;i<a.length;i+=1)n();return r}(t.buckets,e.style),this.hasSymbolBuckets=!1,this.buckets){var i=this.buckets[n];if(i instanceof fc){if(this.hasSymbolBuckets=!0,!r)break;i.justReloaded=!0}}if(this.hasRTLText=!1,this.hasSymbolBuckets)for(var a in this.buckets){var o=this.buckets[a];if(o instanceof fc&&o.hasRTLText){this.hasRTLText=!0,ni.isLoading()||ni.isLoaded()||\"deferred\"!==ei()||ri();break}}for(var s in this.queryPadding=0,this.buckets){var l=this.buckets[s];this.queryPadding=Math.max(this.queryPadding,e.style.getLayer(s).queryRadius(l))}t.imageAtlas&&(this.imageAtlas=t.imageAtlas),t.glyphAtlasImage&&(this.glyphAtlasImage=t.glyphAtlasImage)}else this.collisionBoxArray=new Xi},$c.prototype.unloadVectorData=function(){for(var t in this.buckets)this.buckets[t].destroy();this.buckets={},this.imageAtlasTexture&&this.imageAtlasTexture.destroy(),this.imageAtlas&&(this.imageAtlas=null),this.glyphAtlasTexture&&this.glyphAtlasTexture.destroy(),this.latestFeatureIndex=null,this.state=\"unloaded\"},$c.prototype.getBucket=function(t){return this.buckets[t.id]},$c.prototype.upload=function(t){for(var e in this.buckets){var r=this.buckets[e];r.uploadPending()&&r.upload(t)}var n=t.gl;this.imageAtlas&&!this.imageAtlas.uploaded&&(this.imageAtlasTexture=new Sc(t,this.imageAtlas.image,n.RGBA),this.imageAtlas.uploaded=!0),this.glyphAtlasImage&&(this.glyphAtlasTexture=new Sc(t,this.glyphAtlasImage,n.ALPHA),this.glyphAtlasImage=null)},$c.prototype.prepare=function(t){this.imageAtlas&&this.imageAtlas.patchUpdatedImages(t,this.imageAtlasTexture)},$c.prototype.queryRenderedFeatures=function(t,e,r,n,i,a,o,s,l,c){return this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData?this.latestFeatureIndex.query({queryGeometry:n,cameraQueryGeometry:i,scale:a,tileSize:this.tileSize,pixelPosMatrix:c,transform:s,params:o,queryPadding:this.queryPadding*l},t,e,r):{}},$c.prototype.querySourceFeatures=function(t,e){var r=this.latestFeatureIndex;if(r&&r.rawTileData){var n=r.loadVTLayers(),i=e?e.sourceLayer:\"\",a=n._geojsonTileLayer||n[i];if(a)for(var o=rn(e&&e.filter),s=this.tileID.canonical,l=s.z,c=s.x,u=s.y,f={z:l,x:c,y:u},h=0;h<a.length;h++){var p=a.feature(h);if(o.filter(new ii(this.tileID.overscaledZ),p)){var d=r.getId(p,i),g=new Yc(p,l,c,u,d);g.tile=f,t.push(g)}}}},$c.prototype.hasData=function(){return\"loaded\"===this.state||\"reloading\"===this.state||\"expired\"===this.state},$c.prototype.patternsLoaded=function(){return this.imageAtlas&&!!Object.keys(this.imageAtlas.patternPositions).length},$c.prototype.setExpiryData=function(t){var e=this.expirationTime;if(t.cacheControl){var r=M(t.cacheControl);r[\"max-age\"]&&(this.expirationTime=Date.now()+1e3*r[\"max-age\"])}else t.expires&&(this.expirationTime=new Date(t.expires).getTime());if(this.expirationTime){var n=Date.now(),i=!1;if(this.expirationTime>n)i=!1;else if(e)if(this.expirationTime<e)i=!0;else{var a=this.expirationTime-e;a?this.expirationTime=n+Math.max(a,3e4):i=!0}else i=!0;i?(this.expiredRequestCount++,this.state=\"expired\"):this.expiredRequestCount=0}},$c.prototype.getExpiryTimeout=function(){if(this.expirationTime)return this.expiredRequestCount?1e3*(1<<Math.min(this.expiredRequestCount-1,31)):Math.min(this.expirationTime-(new Date).getTime(),Math.pow(2,31)-1)},$c.prototype.setFeatureState=function(t,e){if(this.latestFeatureIndex&&this.latestFeatureIndex.rawTileData&&0!==Object.keys(t).length){var r=this.latestFeatureIndex.loadVTLayers();for(var n in this.buckets)if(e.style.hasLayer(n)){var i=this.buckets[n],a=i.layers[0].sourceLayer||\"_geojsonTileLayer\",o=r[a],s=t[a];if(o&&s&&0!==Object.keys(s).length){i.update(s,o,this.imageAtlas&&this.imageAtlas.patternPositions||{});var l=e&&e.style&&e.style.getLayer(n);l&&(this.queryPadding=Math.max(this.queryPadding,l.queryRadius(i)))}}}},$c.prototype.holdingForFade=function(){return void 0!==this.symbolFadeHoldUntil},$c.prototype.symbolFadeFinished=function(){return!this.symbolFadeHoldUntil||this.symbolFadeHoldUntil<R.now()},$c.prototype.clearFadeHold=function(){this.symbolFadeHoldUntil=void 0},$c.prototype.setHoldDuration=function(t){this.symbolFadeHoldUntil=R.now()+t},$c.prototype.setDependencies=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1)r[i[n]]=!0;this.dependencies[t]=r},$c.prototype.hasDependency=function(t,e){for(var r=0,n=t;r<n.length;r+=1){var i=this.dependencies[n[r]];if(i)for(var a=0,o=e;a<o.length;a+=1)if(i[o[a]])return!0}return!1};var tu=self.performance,eu=function(t){this._marks={start:[t.url,\"start\"].join(\"#\"),end:[t.url,\"end\"].join(\"#\"),measure:t.url.toString()},tu.mark(this._marks.start)};eu.prototype.finish=function(){tu.mark(this._marks.end);var t=tu.getEntriesByName(this._marks.measure);return 0===t.length&&(tu.measure(this._marks.measure,this._marks.start,this._marks.end),t=tu.getEntriesByName(this._marks.measure),tu.clearMarks(this._marks.start),tu.clearMarks(this._marks.end),tu.clearMeasures(this._marks.measure)),t},t.Actor=Cc,t.AlphaImage=ho,t.CanonicalTileID=jc,t.CollisionBoxArray=Xi,t.Color=Kt,t.DEMData=Hc,t.DataConstantProperty=pi,t.DictionaryCoder=Gc,t.EXTENT=8192,t.ErrorEvent=kt,t.EvaluationParameters=ii,t.Event=Tt,t.Evented=Mt,t.FeatureIndex=Zc,t.FillBucket=rs,t.FillExtrusionBucket=xs,t.ImageAtlas=dl,t.ImagePosition=hl,t.LineBucket=Cs,t.LngLat=Pc,t.LngLatBounds=Ic,t.MercatorCoordinate=Nc,t.ONE_EM=24,t.OverscaledTileID=Vc,t.Point=i,t.Point$1=i,t.Properties=yi,t.Protobuf=Hs,t.RGBAImage=po,t.RequestManager=q,t.RequestPerformance=eu,t.ResourceType=ht,t.SegmentVector=ia,t.SourceFeatureState=Xc,t.StructArrayLayout1ui2=Hi,t.StructArrayLayout2f1f2i16=Di,t.StructArrayLayout2i4=Mi,t.StructArrayLayout3ui6=Fi,t.StructArrayLayout4i8=Ai,t.SymbolBucket=fc,t.Texture=Sc,t.Tile=$c,t.Transitionable=si,t.Uniform1f=va,t.Uniform1i=ma,t.Uniform2f=ya,t.Uniform3f=xa,t.Uniform4f=ba,t.UniformColor=_a,t.UniformMatrix4f=Ta,t.UnwrappedTileID=Uc,t.ValidationError=St,t.WritingMode=gl,t.ZoomHistory=Un,t.add=function(t,e,r){return t[0]=e[0]+r[0],t[1]=e[1]+r[1],t[2]=e[2]+r[2],t},t.addDynamicAttributes=sc,t.asyncAll=function(t,e,r){if(!t.length)return r(null,[]);var n=t.length,i=new Array(t.length),a=null;t.forEach((function(t,o){e(t,(function(t,e){t&&(a=t),i[o]=e,0==--n&&r(a,i)}))}))},t.bezier=o,t.bindAll=g,t.browser=R,t.cacheEntryPossiblyAdded=function(t){++ut>ot&&(t.getActor().send(\"enforceCacheSizeLimit\",at),ut=0)},t.clamp=l,t.clearTileCache=function(t){var e=self.caches.delete(\"mapbox-tiles\");t&&e.catch(t).then((function(){return t()}))},t.clipLine=jl,t.clone=function(t){var e=new to(16);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e[3]=t[3],e[4]=t[4],e[5]=t[5],e[6]=t[6],e[7]=t[7],e[8]=t[8],e[9]=t[9],e[10]=t[10],e[11]=t[11],e[12]=t[12],e[13]=t[13],e[14]=t[14],e[15]=t[15],e},t.clone$1=x,t.clone$2=function(t){var e=new to(3);return e[0]=t[0],e[1]=t[1],e[2]=t[2],e},t.collisionCircleLayout=Ns,t.config=F,t.create=function(){var t=new to(16);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=0,t[12]=0,t[13]=0,t[14]=0),t[0]=1,t[5]=1,t[10]=1,t[15]=1,t},t.create$1=function(){var t=new to(9);return to!=Float32Array&&(t[1]=0,t[2]=0,t[3]=0,t[5]=0,t[6]=0,t[7]=0),t[0]=1,t[4]=1,t[8]=1,t},t.create$2=function(){var t=new to(4);return to!=Float32Array&&(t[1]=0,t[2]=0),t[0]=1,t[3]=1,t},t.createCommonjsModule=e,t.createExpression=qr,t.createLayout=Ti,t.createStyleLayer=function(t){return\"custom\"===t.type?new bc(t):new _c[t.type](t)},t.cross=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=r[0],s=r[1],l=r[2];return t[0]=i*l-a*s,t[1]=a*o-n*l,t[2]=n*s-i*o,t},t.deepEqual=function t(e,r){if(Array.isArray(e)){if(!Array.isArray(r)||e.length!==r.length)return!1;for(var n=0;n<e.length;n++)if(!t(e[n],r[n]))return!1;return!0}if(\"object\"==typeof e&&null!==e&&null!==r){if(\"object\"!=typeof r)return!1;if(Object.keys(e).length!==Object.keys(r).length)return!1;for(var i in e)if(!t(e[i],r[i]))return!1;return!0}return e===r},t.dot=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]},t.dot$1=function(t,e){return t[0]*e[0]+t[1]*e[1]+t[2]*e[2]+t[3]*e[3]},t.ease=s,t.emitValidationErrors=Cn,t.endsWith=m,t.enforceCacheSizeLimit=function(t){st(),Q&&Q.then((function(e){e.keys().then((function(r){for(var n=0;n<r.length-t;n++)e.delete(r[n])}))}))},t.evaluateSizeForFeature=Il,t.evaluateSizeForZoom=Pl,t.evaluateVariableOffset=$l,t.evented=ti,t.extend=u,t.featureFilter=rn,t.filterObject=y,t.fromRotation=function(t,e){var r=Math.sin(e),n=Math.cos(e);return t[0]=n,t[1]=r,t[2]=0,t[3]=-r,t[4]=n,t[5]=0,t[6]=0,t[7]=0,t[8]=1,t},t.getAnchorAlignment=Al,t.getAnchorJustification=tc,t.getArrayBuffer=yt,t.getImage=bt,t.getJSON=function(t,e){return vt(u(t,{type:\"json\"}),e)},t.getRTLTextPluginStatus=ei,t.getReferrer=mt,t.getVideo=function(t,e){var r,n,i=self.document.createElement(\"video\");i.muted=!0,i.onloadstart=function(){e(null,i)};for(var a=0;a<t.length;a++){var o=self.document.createElement(\"source\");r=t[a],n=void 0,(n=self.document.createElement(\"a\")).href=r,(n.protocol!==self.document.location.protocol||n.host!==self.document.location.host)&&(i.crossOrigin=\"Anonymous\"),o.src=t[a],i.appendChild(o)}return{cancel:function(){}}},t.identity=eo,t.invert=function(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=e[4],s=e[5],l=e[6],c=e[7],u=e[8],f=e[9],h=e[10],p=e[11],d=e[12],g=e[13],m=e[14],v=e[15],y=r*s-n*o,x=r*l-i*o,b=r*c-a*o,_=n*l-i*s,w=n*c-a*s,T=i*c-a*l,k=u*g-f*d,M=u*m-h*d,A=u*v-p*d,S=f*m-h*g,E=f*v-p*g,C=h*v-p*m,L=y*C-x*E+b*S+_*A-w*M+T*k;return L?(t[0]=(s*C-l*E+c*S)*(L=1/L),t[1]=(i*E-n*C-a*S)*L,t[2]=(g*T-m*w+v*_)*L,t[3]=(h*w-f*T-p*_)*L,t[4]=(l*A-o*C-c*M)*L,t[5]=(r*C-i*A+a*M)*L,t[6]=(m*b-d*T-v*x)*L,t[7]=(u*T-h*b+p*x)*L,t[8]=(o*E-s*A+c*k)*L,t[9]=(n*A-r*E-a*k)*L,t[10]=(d*w-g*b+v*y)*L,t[11]=(f*b-u*w-p*y)*L,t[12]=(s*M-o*S-l*k)*L,t[13]=(r*S-n*M+i*k)*L,t[14]=(g*x-d*_-m*y)*L,t[15]=(u*_-f*x+h*y)*L,t):null},t.isChar=Vn,t.isMapboxURL=H,t.keysDifference=function(t,e){var r=[];for(var n in t)n in e||r.push(n);return r},t.makeRequest=vt,t.mapObject=v,t.mercatorXfromLng=Dc,t.mercatorYfromLat=Rc,t.mercatorZfromAltitude=Fc,t.mul=io,t.multiply=ro,t.mvt=gs,t.normalize=function(t,e){var r=e[0],n=e[1],i=e[2],a=r*r+n*n+i*i;return a>0&&(a=1/Math.sqrt(a)),t[0]=e[0]*a,t[1]=e[1]*a,t[2]=e[2]*a,t},t.number=Ue,t.offscreenCanvasSupported=ft,t.ortho=function(t,e,r,n,i,a,o){var s=1/(e-r),l=1/(n-i),c=1/(a-o);return t[0]=-2*s,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=-2*l,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[10]=2*c,t[11]=0,t[12]=(e+r)*s,t[13]=(i+n)*l,t[14]=(o+a)*c,t[15]=1,t},t.parseGlyphPBF=function(t){return new Hs(t).readFields(ll,[])},t.pbf=Hs,t.performSymbolLayout=function(t,e,r,n,i,a,o){t.createArrays(),t.tilePixelRatio=8192/(512*t.overscaling),t.compareText={},t.iconsNeedLinear=!1;var s=t.layers[0].layout,l=t.layers[0]._unevaluatedLayout._values,c={};if(\"composite\"===t.textSizeData.kind){var u=t.textSizeData,f=u.maxZoom;c.compositeTextSizes=[l[\"text-size\"].possiblyEvaluate(new ii(u.minZoom),o),l[\"text-size\"].possiblyEvaluate(new ii(f),o)]}if(\"composite\"===t.iconSizeData.kind){var h=t.iconSizeData,p=h.maxZoom;c.compositeIconSizes=[l[\"icon-size\"].possiblyEvaluate(new ii(h.minZoom),o),l[\"icon-size\"].possiblyEvaluate(new ii(p),o)]}c.layoutTextSize=l[\"text-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.layoutIconSize=l[\"icon-size\"].possiblyEvaluate(new ii(t.zoom+1),o),c.textMaxSize=l[\"text-size\"].possiblyEvaluate(new ii(18));for(var d=24*s.get(\"text-line-height\"),g=\"map\"===s.get(\"text-rotation-alignment\")&&\"point\"!==s.get(\"symbol-placement\"),m=s.get(\"text-keep-upright\"),v=s.get(\"text-size\"),y=function(){var a=b[x],l=s.get(\"text-font\").evaluate(a,{},o).join(\",\"),u=v.evaluate(a,{},o),f=c.layoutTextSize.evaluate(a,{},o),h=c.layoutIconSize.evaluate(a,{},o),p={horizontal:{},vertical:void 0},y=a.text,w=[0,0];if(y){var T=y.toString(),k=24*s.get(\"text-letter-spacing\").evaluate(a,{},o),M=function(t){for(var e=0,r=t;e<r.length;e+=1)if(n=r[e].charCodeAt(0),Vn.Arabic(n)||Vn[\"Arabic Supplement\"](n)||Vn[\"Arabic Extended-A\"](n)||Vn[\"Arabic Presentation Forms-A\"](n)||Vn[\"Arabic Presentation Forms-B\"](n))return!1;var n;return!0}(T)?k:0,A=s.get(\"text-anchor\").evaluate(a,{},o),S=s.get(\"text-variable-anchor\");if(!S){var E=s.get(\"text-radial-offset\").evaluate(a,{},o);w=E?$l(A,[24*E,Ql]):s.get(\"text-offset\").evaluate(a,{},o).map((function(t){return 24*t}))}var C=g?\"center\":s.get(\"text-justify\").evaluate(a,{},o),L=s.get(\"symbol-placement\"),I=\"point\"===L?24*s.get(\"text-max-width\").evaluate(a,{},o):0,P=function(){t.allowVerticalPlacement&&qn(T)&&(p.vertical=yl(y,e,r,i,l,I,d,A,\"left\",M,w,gl.vertical,!0,L,f,u))};if(!g&&S){for(var z=\"auto\"===C?S.map((function(t){return tc(t)})):[C],O=!1,D=0;D<z.length;D++){var R=z[D];if(!p.horizontal[R])if(O)p.horizontal[R]=p.horizontal[0];else{var F=yl(y,e,r,i,l,I,d,\"center\",R,M,w,gl.horizontal,!1,L,f,u);F&&(p.horizontal[R]=F,O=1===F.positionedLines.length)}}P()}else{\"auto\"===C&&(C=tc(A));var B=yl(y,e,r,i,l,I,d,A,C,M,w,gl.horizontal,!1,L,f,u);B&&(p.horizontal[C]=B),P(),qn(T)&&g&&m&&(p.vertical=yl(y,e,r,i,l,I,d,A,C,M,w,gl.vertical,!1,L,f,u))}}var N=void 0,j=!1;if(a.icon&&a.icon.name){var U=n[a.icon.name];U&&(N=function(t,e,r){var n=Al(r),i=e[0]-t.displaySize[0]*n.horizontalAlign,a=e[1]-t.displaySize[1]*n.verticalAlign;return{image:t,top:a,bottom:a+t.displaySize[1],left:i,right:i+t.displaySize[0]}}(i[a.icon.name],s.get(\"icon-offset\").evaluate(a,{},o),s.get(\"icon-anchor\").evaluate(a,{},o)),j=U.sdf,void 0===t.sdfIcons?t.sdfIcons=U.sdf:t.sdfIcons!==U.sdf&&_(\"Style sheet warning: Cannot mix SDF and non-SDF icons in one buffer\"),(U.pixelRatio!==t.pixelRatio||0!==s.get(\"icon-rotate\").constantOr(1))&&(t.iconsNeedLinear=!0))}var V=rc(p.horizontal)||p.vertical;t.iconsInText=!!V&&V.iconsInText,(V||N)&&function(t,e,r,n,i,a,o,s,l,c,u){var f=a.textMaxSize.evaluate(e,{});void 0===f&&(f=o);var h,p=t.layers[0].layout,d=p.get(\"icon-offset\").evaluate(e,{},u),g=rc(r.horizontal),m=o/24,v=t.tilePixelRatio*m,y=t.tilePixelRatio*f/24,x=t.tilePixelRatio*s,b=t.tilePixelRatio*p.get(\"symbol-spacing\"),w=p.get(\"text-padding\")*t.tilePixelRatio,T=p.get(\"icon-padding\")*t.tilePixelRatio,k=p.get(\"text-max-angle\")/180*Math.PI,M=\"map\"===p.get(\"text-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),A=\"map\"===p.get(\"icon-rotation-alignment\")&&\"point\"!==p.get(\"symbol-placement\"),S=p.get(\"symbol-placement\"),E=b/2,C=p.get(\"icon-text-fit\");n&&\"none\"!==C&&(t.allowVerticalPlacement&&r.vertical&&(h=El(n,r.vertical,C,p.get(\"icon-text-fit-padding\"),d,m)),g&&(n=El(n,g,C,p.get(\"icon-text-fit-padding\"),d,m)));var L=function(s,f){f.x<0||f.x>=8192||f.y<0||f.y>=8192||function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g,m,v,y,x,b,w,T,k,M){var A,S,E,C,L,I=t.addToLineVertexArray(e,r),P=0,z=0,O=0,D=0,R=-1,F=-1,B={},N=ca(\"\"),j=0,U=0;if(void 0===s._unevaluatedLayout.getValue(\"text-radial-offset\")?(j=(A=s.layout.get(\"text-offset\").evaluate(b,{},k).map((function(t){return 24*t})))[0],U=A[1]):(j=24*s.layout.get(\"text-radial-offset\").evaluate(b,{},k),U=Ql),t.allowVerticalPlacement&&n.vertical){var V=s.layout.get(\"text-rotate\").evaluate(b,{},k)+90;C=new Yl(l,e,c,u,f,n.vertical,h,p,d,V),o&&(L=new Yl(l,e,c,u,f,o,m,v,d,V))}if(i){var q=s.layout.get(\"icon-rotate\").evaluate(b,{}),H=\"none\"!==s.layout.get(\"icon-text-fit\"),G=Ul(i,q,T,H),Y=o?Ul(o,q,T,H):void 0;E=new Yl(l,e,c,u,f,i,m,v,!1,q),P=4*G.length;var W=t.iconSizeData,X=null;\"source\"===W.kind?(X=[128*s.layout.get(\"icon-size\").evaluate(b,{})])[0]>32640&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'):\"composite\"===W.kind&&((X=[128*w.compositeIconSizes[0].evaluate(b,{},k),128*w.compositeIconSizes[1].evaluate(b,{},k)])[0]>32640||X[1]>32640)&&_(t.layerIds[0]+': Value for \"icon-size\" is >= 255. Reduce your \"icon-size\".'),t.addSymbols(t.icon,G,X,x,y,b,!1,e,I.lineStartIndex,I.lineLength,-1,k),R=t.icon.placedSymbolArray.length-1,Y&&(z=4*Y.length,t.addSymbols(t.icon,Y,X,x,y,b,gl.vertical,e,I.lineStartIndex,I.lineLength,-1,k),F=t.icon.placedSymbolArray.length-1)}for(var Z in n.horizontal){var J=n.horizontal[Z];if(!S){N=ca(J.text);var K=s.layout.get(\"text-rotate\").evaluate(b,{},k);S=new Yl(l,e,c,u,f,J,h,p,d,K)}var Q=1===J.positionedLines.length;if(O+=ec(t,e,J,a,s,d,b,g,I,n.vertical?gl.horizontal:gl.horizontalOnly,Q?Object.keys(n.horizontal):[Z],B,R,w,k),Q)break}n.vertical&&(D+=ec(t,e,n.vertical,a,s,d,b,g,I,gl.vertical,[\"vertical\"],B,F,w,k));var $=S?S.boxStartIndex:t.collisionBoxArray.length,tt=S?S.boxEndIndex:t.collisionBoxArray.length,et=C?C.boxStartIndex:t.collisionBoxArray.length,rt=C?C.boxEndIndex:t.collisionBoxArray.length,nt=E?E.boxStartIndex:t.collisionBoxArray.length,it=E?E.boxEndIndex:t.collisionBoxArray.length,at=L?L.boxStartIndex:t.collisionBoxArray.length,ot=L?L.boxEndIndex:t.collisionBoxArray.length,st=-1,lt=function(t,e){return t&&t.circleDiameter?Math.max(t.circleDiameter,e):e};st=lt(S,st),st=lt(C,st),st=lt(E,st);var ct=(st=lt(L,st))>-1?1:0;ct&&(st*=M/24),t.glyphOffsetArray.length>=fc.MAX_GLYPHS&&_(\"Too many glyphs being rendered in a tile. See https://github.com/mapbox/mapbox-gl-js/issues/2907\"),void 0!==b.sortKey&&t.addToSortKeyRanges(t.symbolInstances.length,b.sortKey),t.symbolInstances.emplaceBack(e.x,e.y,B.right>=0?B.right:-1,B.center>=0?B.center:-1,B.left>=0?B.left:-1,B.vertical||-1,R,F,N,$,tt,et,rt,nt,it,at,ot,c,O,D,P,z,ct,0,h,j,U,st)}(t,f,s,r,n,i,h,t.layers[0],t.collisionBoxArray,e.index,e.sourceLayerIndex,t.index,v,w,M,l,x,T,A,d,e,a,c,u,o)};if(\"line\"===S)for(var I=0,P=jl(e.geometry,0,0,8192,8192);I<P.length;I+=1)for(var z=P[I],O=0,D=Nl(z,b,k,r.vertical||g,n,24,y,t.overscaling,8192);O<D.length;O+=1){var R=D[O];g&&nc(t,g.text,E,R)||L(z,R)}else if(\"line-center\"===S)for(var F=0,B=e.geometry;F<B.length;F+=1){var N=B[F];if(N.length>1){var j=Bl(N,k,r.vertical||g,n,24,y);j&&L(N,j)}}else if(\"Polygon\"===e.type)for(var U=0,V=Qo(e.geometry,0);U<V.length;U+=1){var q=V[U],H=Zl(q,16);L(q[0],new Cl(H.x,H.y,0))}else if(\"LineString\"===e.type)for(var G=0,Y=e.geometry;G<Y.length;G+=1){var W=Y[G];L(W,new Cl(W[0].x,W[0].y,0))}else if(\"Point\"===e.type)for(var X=0,Z=e.geometry;X<Z.length;X+=1)for(var J=0,K=Z[X];J<K.length;J+=1){var Q=K[J];L([Q],new Cl(Q.x,Q.y,0))}}(t,a,p,N,n,c,f,h,w,j,o)},x=0,b=t.features;x<b.length;x+=1)y();a&&t.generateCollisionDebugBuffers()},t.perspective=function(t,e,r,n,i){var a,o=1/Math.tan(e/2);return t[0]=o/r,t[1]=0,t[2]=0,t[3]=0,t[4]=0,t[5]=o,t[6]=0,t[7]=0,t[8]=0,t[9]=0,t[11]=-1,t[12]=0,t[13]=0,t[15]=0,null!=i&&i!==1/0?(t[10]=(i+n)*(a=1/(n-i)),t[14]=2*i*n*a):(t[10]=-1,t[14]=-2*n),t},t.pick=function(t,e){for(var r={},n=0;n<e.length;n++){var i=e[n];i in t&&(r[i]=t[i])}return r},t.plugin=ni,t.polygonIntersectsPolygon=Ba,t.postMapLoadEvent=it,t.postTurnstileEvent=rt,t.potpack=fl,t.refProperties=[\"type\",\"source\",\"source-layer\",\"minzoom\",\"maxzoom\",\"filter\",\"layout\"],t.register=Dn,t.registerForPluginStateChange=function(t){return t({pluginStatus:Jn,pluginURL:Kn}),ti.on(\"pluginStateChange\",t),t},t.rotate=function(t,e,r){var n=e[0],i=e[1],a=e[2],o=e[3],s=Math.sin(r),l=Math.cos(r);return t[0]=n*l+a*s,t[1]=i*l+o*s,t[2]=n*-s+a*l,t[3]=i*-s+o*l,t},t.rotateX=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[4],o=e[5],s=e[6],l=e[7],c=e[8],u=e[9],f=e[10],h=e[11];return e!==t&&(t[0]=e[0],t[1]=e[1],t[2]=e[2],t[3]=e[3],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[4]=a*i+c*n,t[5]=o*i+u*n,t[6]=s*i+f*n,t[7]=l*i+h*n,t[8]=c*i-a*n,t[9]=u*i-o*n,t[10]=f*i-s*n,t[11]=h*i-l*n,t},t.rotateZ=function(t,e,r){var n=Math.sin(r),i=Math.cos(r),a=e[0],o=e[1],s=e[2],l=e[3],c=e[4],u=e[5],f=e[6],h=e[7];return e!==t&&(t[8]=e[8],t[9]=e[9],t[10]=e[10],t[11]=e[11],t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15]),t[0]=a*i+c*n,t[1]=o*i+u*n,t[2]=s*i+f*n,t[3]=l*i+h*n,t[4]=c*i-a*n,t[5]=u*i-o*n,t[6]=f*i-s*n,t[7]=h*i-l*n,t},t.scale=function(t,e,r){var n=r[0],i=r[1],a=r[2];return t[0]=e[0]*n,t[1]=e[1]*n,t[2]=e[2]*n,t[3]=e[3]*n,t[4]=e[4]*i,t[5]=e[5]*i,t[6]=e[6]*i,t[7]=e[7]*i,t[8]=e[8]*a,t[9]=e[9]*a,t[10]=e[10]*a,t[11]=e[11]*a,t[12]=e[12],t[13]=e[13],t[14]=e[14],t[15]=e[15],t},t.scale$1=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t[3]=e[3]*r,t},t.scale$2=function(t,e,r){return t[0]=e[0]*r,t[1]=e[1]*r,t[2]=e[2]*r,t},t.setCacheLimits=function(t,e){at=t,ot=e},t.setRTLTextPlugin=function(t,e,r){if(void 0===r&&(r=!1),\"deferred\"===Jn||\"loading\"===Jn||\"loaded\"===Jn)throw new Error(\"setRTLTextPlugin cannot be called multiple times.\");Kn=R.resolveURL(t),Jn=\"deferred\",Zn=e,$n(),r||ri()},t.sphericalToCartesian=function(t){var e=t[0],r=t[1],n=t[2];return r+=90,r*=Math.PI/180,n*=Math.PI/180,{x:e*Math.cos(r)*Math.sin(n),y:e*Math.sin(r)*Math.sin(n),z:e*Math.cos(n)}},t.sqrLen=function(t){var e=t[0],r=t[1];return e*e+r*r},t.styleSpec=At,t.sub=function(t,e,r){return t[0]=e[0]-r[0],t[1]=e[1]-r[1],t[2]=e[2]-r[2],t},t.symbolSize=zl,t.transformMat3=function(t,e,r){var n=e[0],i=e[1],a=e[2];return t[0]=n*r[0]+i*r[3]+a*r[6],t[1]=n*r[1]+i*r[4]+a*r[7],t[2]=n*r[2]+i*r[5]+a*r[8],t},t.transformMat4=ao,t.translate=function(t,e,r){var n,i,a,o,s,l,c,u,f,h,p,d,g=r[0],m=r[1],v=r[2];return e===t?(t[12]=e[0]*g+e[4]*m+e[8]*v+e[12],t[13]=e[1]*g+e[5]*m+e[9]*v+e[13],t[14]=e[2]*g+e[6]*m+e[10]*v+e[14],t[15]=e[3]*g+e[7]*m+e[11]*v+e[15]):(i=e[1],a=e[2],o=e[3],s=e[4],l=e[5],c=e[6],u=e[7],f=e[8],h=e[9],p=e[10],d=e[11],t[0]=n=e[0],t[1]=i,t[2]=a,t[3]=o,t[4]=s,t[5]=l,t[6]=c,t[7]=u,t[8]=f,t[9]=h,t[10]=p,t[11]=d,t[12]=n*g+s*m+f*v+e[12],t[13]=i*g+l*m+h*v+e[13],t[14]=a*g+c*m+p*v+e[14],t[15]=o*g+u*m+d*v+e[15]),t},t.triggerPluginCompletionEvent=Qn,t.uniqueId=h,t.validateCustomStyleLayer=function(t){var e=[],r=t.id;return void 0===r&&e.push({message:\"layers.\"+r+': missing required property \"id\"'}),void 0===t.render&&e.push({message:\"layers.\"+r+': missing required method \"render\"'}),t.renderingMode&&\"2d\"!==t.renderingMode&&\"3d\"!==t.renderingMode&&e.push({message:\"layers.\"+r+': property \"renderingMode\" must be either \"2d\" or \"3d\"'}),e},t.validateLight=An,t.validateStyle=Mn,t.values=function(t){var e=[];for(var r in t)e.push(t[r]);return e},t.vectorTile=gs,t.version=\"1.10.1\",t.warnOnce=_,t.webpSupported=B,t.window=self,t.wrap=c})),n(0,(function(t){function e(t){var r=typeof t;if(\"number\"===r||\"boolean\"===r||\"string\"===r||null==t)return JSON.stringify(t);if(Array.isArray(t)){for(var n=\"[\",i=0,a=t;i<a.length;i+=1)n+=e(a[i])+\",\";return n+\"]\"}for(var o=Object.keys(t).sort(),s=\"{\",l=0;l<o.length;l++)s+=JSON.stringify(o[l])+\":\"+e(t[o[l]])+\",\";return s+\"}\"}function r(r){for(var n=\"\",i=0,a=t.refProperties;i<a.length;i+=1)n+=\"/\"+e(r[a[i]]);return n}var n=function(t){this.keyCache={},t&&this.replace(t)};n.prototype.replace=function(t){this._layerConfigs={},this._layers={},this.update(t,[])},n.prototype.update=function(e,n){for(var i=this,a=0,o=e;a<o.length;a+=1){var s=o[a];this._layerConfigs[s.id]=s;var l=this._layers[s.id]=t.createStyleLayer(s);l._featureFilter=t.featureFilter(l.filter),this.keyCache[s.id]&&delete this.keyCache[s.id]}for(var c=0,u=n;c<u.length;c+=1){var f=u[c];delete this.keyCache[f],delete this._layerConfigs[f],delete this._layers[f]}this.familiesBySource={};for(var h=0,p=function(t,e){for(var n={},i=0;i<t.length;i++){var a=e&&e[t[i].id]||r(t[i]);e&&(e[t[i].id]=a);var o=n[a];o||(o=n[a]=[]),o.push(t[i])}var s=[];for(var l in n)s.push(n[l]);return s}(t.values(this._layerConfigs),this.keyCache);h<p.length;h+=1){var d=p[h].map((function(t){return i._layers[t.id]})),g=d[0];if(\"none\"!==g.visibility){var m=g.source||\"\",v=this.familiesBySource[m];v||(v=this.familiesBySource[m]={});var y=g.sourceLayer||\"_geojsonTileLayer\",x=v[y];x||(x=v[y]=[]),x.push(d)}}};var i=function(e){var r={},n=[];for(var i in e){var a=e[i],o=r[i]={};for(var s in a){var l=a[+s];if(l&&0!==l.bitmap.width&&0!==l.bitmap.height){var c={x:0,y:0,w:l.bitmap.width+2,h:l.bitmap.height+2};n.push(c),o[s]={rect:c,metrics:l.metrics}}}}var u=t.potpack(n),f=new t.AlphaImage({width:u.w||1,height:u.h||1});for(var h in e){var p=e[h];for(var d in p){var g=p[+d];if(g&&0!==g.bitmap.width&&0!==g.bitmap.height){var m=r[h][d].rect;t.AlphaImage.copy(g.bitmap,f,{x:0,y:0},{x:m.x+1,y:m.y+1},g.bitmap)}}}this.image=f,this.positions=r};t.register(\"GlyphAtlas\",i);var a=function(e){this.tileID=new t.OverscaledTileID(e.tileID.overscaledZ,e.tileID.wrap,e.tileID.canonical.z,e.tileID.canonical.x,e.tileID.canonical.y),this.uid=e.uid,this.zoom=e.zoom,this.pixelRatio=e.pixelRatio,this.tileSize=e.tileSize,this.source=e.source,this.overscaling=this.tileID.overscaleFactor(),this.showCollisionBoxes=e.showCollisionBoxes,this.collectResourceTiming=!!e.collectResourceTiming,this.returnDependencies=!!e.returnDependencies,this.promoteId=e.promoteId};function o(e,r,n){for(var i=new t.EvaluationParameters(r),a=0,o=e;a<o.length;a+=1)o[a].recalculate(i,n)}function s(e,r){var n=t.getArrayBuffer(e.request,(function(e,n,i,a){e?r(e):n&&r(null,{vectorTile:new t.vectorTile.VectorTile(new t.pbf(n)),rawData:n,cacheControl:i,expires:a})}));return function(){n.cancel(),r()}}a.prototype.parse=function(e,r,n,a,s){var l=this;this.status=\"parsing\",this.data=e,this.collisionBoxArray=new t.CollisionBoxArray;var c=new t.DictionaryCoder(Object.keys(e.layers).sort()),u=new t.FeatureIndex(this.tileID,this.promoteId);u.bucketLayerIDs=[];var f,h,p,d,g={},m={featureIndex:u,iconDependencies:{},patternDependencies:{},glyphDependencies:{},availableImages:n},v=r.familiesBySource[this.source];for(var y in v){var x=e.layers[y];if(x){1===x.version&&t.warnOnce('Vector tile source \"'+this.source+'\" layer \"'+y+'\" does not use vector tile spec v2 and therefore may have some rendering errors.');for(var b=c.encode(y),_=[],w=0;w<x.length;w++){var T=x.feature(w),k=u.getId(T,y);_.push({feature:T,id:k,index:w,sourceLayerIndex:b})}for(var M=0,A=v[y];M<A.length;M+=1){var S=A[M],E=S[0];E.minzoom&&this.zoom<Math.floor(E.minzoom)||E.maxzoom&&this.zoom>=E.maxzoom||\"none\"!==E.visibility&&(o(S,this.zoom,n),(g[E.id]=E.createBucket({index:u.bucketLayerIDs.length,layers:S,zoom:this.zoom,pixelRatio:this.pixelRatio,overscaling:this.overscaling,collisionBoxArray:this.collisionBoxArray,sourceLayerIndex:b,sourceID:this.source})).populate(_,m,this.tileID.canonical),u.bucketLayerIDs.push(S.map((function(t){return t.id}))))}}}var C=t.mapObject(m.glyphDependencies,(function(t){return Object.keys(t).map(Number)}));Object.keys(C).length?a.send(\"getGlyphs\",{uid:this.uid,stacks:C},(function(t,e){f||(f=t,h=e,P.call(l))})):h={};var L=Object.keys(m.iconDependencies);L.length?a.send(\"getImages\",{icons:L,source:this.source,tileID:this.tileID,type:\"icons\"},(function(t,e){f||(f=t,p=e,P.call(l))})):p={};var I=Object.keys(m.patternDependencies);function P(){if(f)return s(f);if(h&&p&&d){var e=new i(h),r=new t.ImageAtlas(p,d);for(var a in g){var l=g[a];l instanceof t.SymbolBucket?(o(l.layers,this.zoom,n),t.performSymbolLayout(l,h,e.positions,p,r.iconPositions,this.showCollisionBoxes,this.tileID.canonical)):l.hasPattern&&(l instanceof t.LineBucket||l instanceof t.FillBucket||l instanceof t.FillExtrusionBucket)&&(o(l.layers,this.zoom,n),l.addFeatures(m,this.tileID.canonical,r.patternPositions))}this.status=\"done\",s(null,{buckets:t.values(g).filter((function(t){return!t.isEmpty()})),featureIndex:u,collisionBoxArray:this.collisionBoxArray,glyphAtlasImage:e.image,imageAtlas:r,glyphMap:this.returnDependencies?h:null,iconMap:this.returnDependencies?p:null,glyphPositions:this.returnDependencies?e.positions:null})}}I.length?a.send(\"getImages\",{icons:I,source:this.source,tileID:this.tileID,type:\"patterns\"},(function(t,e){f||(f=t,d=e,P.call(l))})):d={},P.call(this)};var l=function(t,e,r,n){this.actor=t,this.layerIndex=e,this.availableImages=r,this.loadVectorData=n||s,this.loading={},this.loaded={}};l.prototype.loadTile=function(e,r){var n=this,i=e.uid;this.loading||(this.loading={});var o=!!(e&&e.request&&e.request.collectResourceTiming)&&new t.RequestPerformance(e.request),s=this.loading[i]=new a(e);s.abort=this.loadVectorData(e,(function(e,a){if(delete n.loading[i],e||!a)return s.status=\"done\",n.loaded[i]=s,r(e);var l=a.rawData,c={};a.expires&&(c.expires=a.expires),a.cacheControl&&(c.cacheControl=a.cacheControl);var u={};if(o){var f=o.finish();f&&(u.resourceTiming=JSON.parse(JSON.stringify(f)))}s.vectorTile=a.vectorTile,s.parse(a.vectorTile,n.layerIndex,n.availableImages,n.actor,(function(e,n){if(e||!n)return r(e);r(null,t.extend({rawTileData:l.slice(0)},n,c,u))})),n.loaded=n.loaded||{},n.loaded[i]=s}))},l.prototype.reloadTile=function(t,e){var r=this,n=this.loaded,i=t.uid,a=this;if(n&&n[i]){var o=n[i];o.showCollisionBoxes=t.showCollisionBoxes;var s=function(t,n){var i=o.reloadCallback;i&&(delete o.reloadCallback,o.parse(o.vectorTile,a.layerIndex,r.availableImages,a.actor,i)),e(t,n)};\"parsing\"===o.status?o.reloadCallback=s:\"done\"===o.status&&(o.vectorTile?o.parse(o.vectorTile,this.layerIndex,this.availableImages,this.actor,s):s())}},l.prototype.abortTile=function(t,e){var r=this.loading,n=t.uid;r&&r[n]&&r[n].abort&&(r[n].abort(),delete r[n]),e()},l.prototype.removeTile=function(t,e){var r=this.loaded,n=t.uid;r&&r[n]&&delete r[n],e()};var c=t.window.ImageBitmap,u=function(){this.loaded={}};function f(t,e){if(0!==t.length){h(t[0],e);for(var r=1;r<t.length;r++)h(t[r],!e)}}function h(t,e){for(var r=0,n=0,i=t.length,a=i-1;n<i;a=n++)r+=(t[n][0]-t[a][0])*(t[a][1]+t[n][1]);r>=0!=!!e&&t.reverse()}u.prototype.loadTile=function(e,r){var n=e.uid,i=e.encoding,a=e.rawImageData,o=c&&a instanceof c?this.getImageData(a):a,s=new t.DEMData(n,o,i);this.loaded=this.loaded||{},this.loaded[n]=s,r(null,s)},u.prototype.getImageData=function(e){this.offscreenCanvas&&this.offscreenCanvasContext||(this.offscreenCanvas=new OffscreenCanvas(e.width,e.height),this.offscreenCanvasContext=this.offscreenCanvas.getContext(\"2d\")),this.offscreenCanvas.width=e.width,this.offscreenCanvas.height=e.height,this.offscreenCanvasContext.drawImage(e,0,0,e.width,e.height);var r=this.offscreenCanvasContext.getImageData(-1,-1,e.width+2,e.height+2);return this.offscreenCanvasContext.clearRect(0,0,this.offscreenCanvas.width,this.offscreenCanvas.height),new t.RGBAImage({width:r.width,height:r.height},r.data)},u.prototype.removeTile=function(t){var e=this.loaded,r=t.uid;e&&e[r]&&delete e[r]};var p=t.vectorTile.VectorTileFeature.prototype.toGeoJSON,d=function(e){this._feature=e,this.extent=t.EXTENT,this.type=e.type,this.properties=e.tags,\"id\"in e&&!isNaN(e.id)&&(this.id=parseInt(e.id,10))};d.prototype.loadGeometry=function(){if(1===this._feature.type){for(var e=[],r=0,n=this._feature.geometry;r<n.length;r+=1){var i=n[r];e.push([new t.Point$1(i[0],i[1])])}return e}for(var a=[],o=0,s=this._feature.geometry;o<s.length;o+=1){for(var l=[],c=0,u=s[o];c<u.length;c+=1){var f=u[c];l.push(new t.Point$1(f[0],f[1]))}a.push(l)}return a},d.prototype.toGeoJSON=function(t,e,r){return p.call(this,t,e,r)};var g=function(e){this.layers={_geojsonTileLayer:this},this.name=\"_geojsonTileLayer\",this.extent=t.EXTENT,this.length=e.length,this._features=e};g.prototype.feature=function(t){return new d(this._features[t])};var m=t.vectorTile.VectorTileFeature,v=y;function y(t,e){this.options=e||{},this.features=t,this.length=t.length}function x(t,e){this.id=\"number\"==typeof t.id?t.id:void 0,this.type=t.type,this.rawGeometry=1===t.type?[t.geometry]:t.geometry,this.properties=t.tags,this.extent=e||4096}y.prototype.feature=function(t){return new x(this.features[t],this.options.extent)},x.prototype.loadGeometry=function(){var e=this.rawGeometry;this.geometry=[];for(var r=0;r<e.length;r++){for(var n=e[r],i=[],a=0;a<n.length;a++)i.push(new t.Point$1(n[a][0],n[a][1]));this.geometry.push(i)}return this.geometry},x.prototype.bbox=function(){this.geometry||this.loadGeometry();for(var t=this.geometry,e=1/0,r=-1/0,n=1/0,i=-1/0,a=0;a<t.length;a++)for(var o=t[a],s=0;s<o.length;s++){var l=o[s];e=Math.min(e,l.x),r=Math.max(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.y)}return[e,n,r,i]},x.prototype.toGeoJSON=m.prototype.toGeoJSON;var b=w,_=v;function w(e){var r=new t.pbf;return function(t,e){for(var r in t.layers)e.writeMessage(3,T,t.layers[r])}(e,r),r.finish()}function T(t,e){var r;e.writeVarintField(15,t.version||1),e.writeStringField(1,t.name||\"\"),e.writeVarintField(5,t.extent||4096);var n={keys:[],values:[],keycache:{},valuecache:{}};for(r=0;r<t.length;r++)n.feature=t.feature(r),e.writeMessage(2,k,n);var i=n.keys;for(r=0;r<i.length;r++)e.writeStringField(3,i[r]);var a=n.values;for(r=0;r<a.length;r++)e.writeMessage(4,C,a[r])}function k(t,e){var r=t.feature;void 0!==r.id&&e.writeVarintField(1,r.id),e.writeMessage(2,M,t),e.writeVarintField(3,r.type),e.writeMessage(4,E,r)}function M(t,e){var r=t.feature,n=t.keys,i=t.values,a=t.keycache,o=t.valuecache;for(var s in r.properties){var l=a[s];void 0===l&&(n.push(s),a[s]=l=n.length-1),e.writeVarint(l);var c=r.properties[s],u=typeof c;\"string\"!==u&&\"boolean\"!==u&&\"number\"!==u&&(c=JSON.stringify(c));var f=u+\":\"+c,h=o[f];void 0===h&&(i.push(c),o[f]=h=i.length-1),e.writeVarint(h)}}function A(t,e){return(e<<3)+(7&t)}function S(t){return t<<1^t>>31}function E(t,e){for(var r=t.loadGeometry(),n=t.type,i=0,a=0,o=r.length,s=0;s<o;s++){var l=r[s],c=1;1===n&&(c=l.length),e.writeVarint(A(1,c));for(var u=3===n?l.length-1:l.length,f=0;f<u;f++){1===f&&1!==n&&e.writeVarint(A(2,u-1));var h=l[f].x-i,p=l[f].y-a;e.writeVarint(S(h)),e.writeVarint(S(p)),i+=h,a+=p}3===n&&e.writeVarint(A(7,1))}}function C(t,e){var r=typeof t;\"string\"===r?e.writeStringField(1,t):\"boolean\"===r?e.writeBooleanField(7,t):\"number\"===r&&(t%1!=0?e.writeDoubleField(3,t):t<0?e.writeSVarintField(6,t):e.writeVarintField(5,t))}function L(t,e,r,n){I(t,r,n),I(e,2*r,2*n),I(e,2*r+1,2*n+1)}function I(t,e,r){var n=t[e];t[e]=t[r],t[r]=n}function P(t,e,r,n){var i=t-r,a=e-n;return i*i+a*a}b.fromVectorTileJs=w,b.fromGeojsonVt=function(t,e){e=e||{};var r={};for(var n in t)r[n]=new v(t[n].features,e),r[n].name=n,r[n].version=e.version,r[n].extent=e.extent;return w({layers:r})},b.GeoJSONWrapper=_;var z=function(t){return t[0]},O=function(t){return t[1]},D=function(t,e,r,n,i){void 0===e&&(e=z),void 0===r&&(r=O),void 0===n&&(n=64),void 0===i&&(i=Float64Array),this.nodeSize=n,this.points=t;for(var a=t.length<65536?Uint16Array:Uint32Array,o=this.ids=new a(t.length),s=this.coords=new i(2*t.length),l=0;l<t.length;l++)o[l]=l,s[2*l]=e(t[l]),s[2*l+1]=r(t[l]);!function t(e,r,n,i,a,o){if(!(a-i<=n)){var s=i+a>>1;!function t(e,r,n,i,a,o){for(;a>i;){if(a-i>600){var s=a-i+1,l=n-i+1,c=Math.log(s),u=.5*Math.exp(2*c/3),f=.5*Math.sqrt(c*u*(s-u)/s)*(l-s/2<0?-1:1);t(e,r,n,Math.max(i,Math.floor(n-l*u/s+f)),Math.min(a,Math.floor(n+(s-l)*u/s+f)),o)}var h=r[2*n+o],p=i,d=a;for(L(e,r,i,n),r[2*a+o]>h&&L(e,r,i,a);p<d;){for(L(e,r,p,d),p++,d--;r[2*p+o]<h;)p++;for(;r[2*d+o]>h;)d--}r[2*i+o]===h?L(e,r,i,d):L(e,r,++d,a),d<=n&&(i=d+1),n<=d&&(a=d-1)}}(e,r,s,i,a,o%2),t(e,r,n,i,s-1,o+1),t(e,r,n,s+1,a,o+1)}}(o,s,n,0,o.length-1,0)};D.prototype.range=function(t,e,r,n){return function(t,e,r,n,i,a,o){for(var s,l,c=[0,t.length-1,0],u=[];c.length;){var f=c.pop(),h=c.pop(),p=c.pop();if(h-p<=o)for(var d=p;d<=h;d++)l=e[2*d+1],(s=e[2*d])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[d]);else{var g=Math.floor((p+h)/2);l=e[2*g+1],(s=e[2*g])>=r&&s<=i&&l>=n&&l<=a&&u.push(t[g]);var m=(f+1)%2;(0===f?r<=s:n<=l)&&(c.push(p),c.push(g-1),c.push(m)),(0===f?i>=s:a>=l)&&(c.push(g+1),c.push(h),c.push(m))}}return u}(this.ids,this.coords,t,e,r,n,this.nodeSize)},D.prototype.within=function(t,e,r){return function(t,e,r,n,i,a){for(var o=[0,t.length-1,0],s=[],l=i*i;o.length;){var c=o.pop(),u=o.pop(),f=o.pop();if(u-f<=a)for(var h=f;h<=u;h++)P(e[2*h],e[2*h+1],r,n)<=l&&s.push(t[h]);else{var p=Math.floor((f+u)/2),d=e[2*p],g=e[2*p+1];P(d,g,r,n)<=l&&s.push(t[p]);var m=(c+1)%2;(0===c?r-i<=d:n-i<=g)&&(o.push(f),o.push(p-1),o.push(m)),(0===c?r+i>=d:n+i>=g)&&(o.push(p+1),o.push(u),o.push(m))}}return s}(this.ids,this.coords,t,e,r,this.nodeSize)};var R={minZoom:0,maxZoom:16,radius:40,extent:512,nodeSize:64,log:!1,generateId:!1,reduce:null,map:function(t){return t}},F=function(t){this.options=H(Object.create(R),t),this.trees=new Array(this.options.maxZoom+1)};function B(t,e,r,n,i){return{x:t,y:e,zoom:1/0,id:r,parentId:-1,numPoints:n,properties:i}}function N(t,e){var r=t.geometry.coordinates,n=r[1];return{x:V(r[0]),y:q(n),zoom:1/0,index:e,parentId:-1}}function j(t){return{type:\"Feature\",id:t.id,properties:U(t),geometry:{type:\"Point\",coordinates:[(n=t.x,360*(n-.5)),(e=t.y,r=(180-360*e)*Math.PI/180,360*Math.atan(Math.exp(r))/Math.PI-90)]}};var e,r,n}function U(t){var e=t.numPoints,r=e>=1e4?Math.round(e/1e3)+\"k\":e>=1e3?Math.round(e/100)/10+\"k\":e;return H(H({},t.properties),{cluster:!0,cluster_id:t.id,point_count:e,point_count_abbreviated:r})}function V(t){return t/360+.5}function q(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function H(t,e){for(var r in e)t[r]=e[r];return t}function G(t){return t.x}function Y(t){return t.y}function W(t,e,r,n,i,a){var o=i-r,s=a-n;if(0!==o||0!==s){var l=((t-r)*o+(e-n)*s)/(o*o+s*s);l>1?(r=i,n=a):l>0&&(r+=o*l,n+=s*l)}return(o=t-r)*o+(s=e-n)*s}function X(t,e,r,n){var i={id:void 0===t?null:t,type:e,geometry:r,tags:n,minX:1/0,minY:1/0,maxX:-1/0,maxY:-1/0};return function(t){var e=t.geometry,r=t.type;if(\"Point\"===r||\"MultiPoint\"===r||\"LineString\"===r)Z(t,e);else if(\"Polygon\"===r||\"MultiLineString\"===r)for(var n=0;n<e.length;n++)Z(t,e[n]);else if(\"MultiPolygon\"===r)for(n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)Z(t,e[n][i])}(i),i}function Z(t,e){for(var r=0;r<e.length;r+=3)t.minX=Math.min(t.minX,e[r]),t.minY=Math.min(t.minY,e[r+1]),t.maxX=Math.max(t.maxX,e[r]),t.maxY=Math.max(t.maxY,e[r+1])}function J(t,e,r,n){if(e.geometry){var i=e.geometry.coordinates,a=e.geometry.type,o=Math.pow(r.tolerance/((1<<r.maxZoom)*r.extent),2),s=[],l=e.id;if(r.promoteId?l=e.properties[r.promoteId]:r.generateId&&(l=n||0),\"Point\"===a)K(i,s);else if(\"MultiPoint\"===a)for(var c=0;c<i.length;c++)K(i[c],s);else if(\"LineString\"===a)Q(i,s,o,!1);else if(\"MultiLineString\"===a){if(r.lineMetrics){for(c=0;c<i.length;c++)Q(i[c],s=[],o,!1),t.push(X(l,\"LineString\",s,e.properties));return}$(i,s,o,!1)}else if(\"Polygon\"===a)$(i,s,o,!0);else{if(\"MultiPolygon\"!==a){if(\"GeometryCollection\"===a){for(c=0;c<e.geometry.geometries.length;c++)J(t,{id:l,geometry:e.geometry.geometries[c],properties:e.properties},r,n);return}throw new Error(\"Input data is not a valid GeoJSON object.\")}for(c=0;c<i.length;c++){var u=[];$(i[c],u,o,!0),s.push(u)}}t.push(X(l,a,s,e.properties))}}function K(t,e){e.push(tt(t[0])),e.push(et(t[1])),e.push(0)}function Q(t,e,r,n){for(var i,a,o=0,s=0;s<t.length;s++){var l=tt(t[s][0]),c=et(t[s][1]);e.push(l),e.push(c),e.push(0),s>0&&(o+=n?(i*c-l*a)/2:Math.sqrt(Math.pow(l-i,2)+Math.pow(c-a,2))),i=l,a=c}var u=e.length-3;e[2]=1,function t(e,r,n,i){for(var a,o=i,s=n-r>>1,l=n-r,c=e[r],u=e[r+1],f=e[n],h=e[n+1],p=r+3;p<n;p+=3){var d=W(e[p],e[p+1],c,u,f,h);if(d>o)a=p,o=d;else if(d===o){var g=Math.abs(p-s);g<l&&(a=p,l=g)}}o>i&&(a-r>3&&t(e,r,a,i),e[a+2]=o,n-a>3&&t(e,a,n,i))}(e,0,u,r),e[u+2]=1,e.size=Math.abs(o),e.start=0,e.end=e.size}function $(t,e,r,n){for(var i=0;i<t.length;i++){var a=[];Q(t[i],a,r,n),e.push(a)}}function tt(t){return t/360+.5}function et(t){var e=Math.sin(t*Math.PI/180),r=.5-.25*Math.log((1+e)/(1-e))/Math.PI;return r<0?0:r>1?1:r}function rt(t,e,r,n,i,a,o,s){if(n/=e,a>=(r/=e)&&o<n)return t;if(o<r||a>=n)return null;for(var l=[],c=0;c<t.length;c++){var u=t[c],f=u.geometry,h=u.type,p=0===i?u.minX:u.minY,d=0===i?u.maxX:u.maxY;if(p>=r&&d<n)l.push(u);else if(!(d<r||p>=n)){var g=[];if(\"Point\"===h||\"MultiPoint\"===h)nt(f,g,r,n,i);else if(\"LineString\"===h)it(f,g,r,n,i,!1,s.lineMetrics);else if(\"MultiLineString\"===h)ot(f,g,r,n,i,!1);else if(\"Polygon\"===h)ot(f,g,r,n,i,!0);else if(\"MultiPolygon\"===h)for(var m=0;m<f.length;m++){var v=[];ot(f[m],v,r,n,i,!0),v.length&&g.push(v)}if(g.length){if(s.lineMetrics&&\"LineString\"===h){for(m=0;m<g.length;m++)l.push(X(u.id,h,g[m],u.tags));continue}\"LineString\"!==h&&\"MultiLineString\"!==h||(1===g.length?(h=\"LineString\",g=g[0]):h=\"MultiLineString\"),\"Point\"!==h&&\"MultiPoint\"!==h||(h=3===g.length?\"Point\":\"MultiPoint\"),l.push(X(u.id,h,g,u.tags))}}}return l.length?l:null}function nt(t,e,r,n,i){for(var a=0;a<t.length;a+=3){var o=t[a+i];o>=r&&o<=n&&(e.push(t[a]),e.push(t[a+1]),e.push(t[a+2]))}}function it(t,e,r,n,i,a,o){for(var s,l,c=at(t),u=0===i?lt:ct,f=t.start,h=0;h<t.length-3;h+=3){var p=t[h],d=t[h+1],g=t[h+2],m=t[h+3],v=t[h+4],y=0===i?p:d,x=0===i?m:v,b=!1;o&&(s=Math.sqrt(Math.pow(p-m,2)+Math.pow(d-v,2))),y<r?x>r&&(l=u(c,p,d,m,v,r),o&&(c.start=f+s*l)):y>n?x<n&&(l=u(c,p,d,m,v,n),o&&(c.start=f+s*l)):st(c,p,d,g),x<r&&y>=r&&(l=u(c,p,d,m,v,r),b=!0),x>n&&y<=n&&(l=u(c,p,d,m,v,n),b=!0),!a&&b&&(o&&(c.end=f+s*l),e.push(c),c=at(t)),o&&(f+=s)}var _=t.length-3;p=t[_],d=t[_+1],g=t[_+2],(y=0===i?p:d)>=r&&y<=n&&st(c,p,d,g),_=c.length-3,a&&_>=3&&(c[_]!==c[0]||c[_+1]!==c[1])&&st(c,c[0],c[1],c[2]),c.length&&e.push(c)}function at(t){var e=[];return e.size=t.size,e.start=t.start,e.end=t.end,e}function ot(t,e,r,n,i,a){for(var o=0;o<t.length;o++)it(t[o],e,r,n,i,a,!1)}function st(t,e,r,n){t.push(e),t.push(r),t.push(n)}function lt(t,e,r,n,i,a){var o=(a-e)/(n-e);return t.push(a),t.push(r+(i-r)*o),t.push(1),o}function ct(t,e,r,n,i,a){var o=(a-r)/(i-r);return t.push(e+(n-e)*o),t.push(a),t.push(1),o}function ut(t,e){for(var r=[],n=0;n<t.length;n++){var i,a=t[n],o=a.type;if(\"Point\"===o||\"MultiPoint\"===o||\"LineString\"===o)i=ft(a.geometry,e);else if(\"MultiLineString\"===o||\"Polygon\"===o){i=[];for(var s=0;s<a.geometry.length;s++)i.push(ft(a.geometry[s],e))}else if(\"MultiPolygon\"===o)for(i=[],s=0;s<a.geometry.length;s++){for(var l=[],c=0;c<a.geometry[s].length;c++)l.push(ft(a.geometry[s][c],e));i.push(l)}r.push(X(a.id,o,i,a.tags))}return r}function ft(t,e){var r=[];r.size=t.size,void 0!==t.start&&(r.start=t.start,r.end=t.end);for(var n=0;n<t.length;n+=3)r.push(t[n]+e,t[n+1],t[n+2]);return r}function ht(t,e){if(t.transformed)return t;var r,n,i,a=1<<t.z,o=t.x,s=t.y;for(r=0;r<t.features.length;r++){var l=t.features[r],c=l.geometry,u=l.type;if(l.geometry=[],1===u)for(n=0;n<c.length;n+=2)l.geometry.push(pt(c[n],c[n+1],e,a,o,s));else for(n=0;n<c.length;n++){var f=[];for(i=0;i<c[n].length;i+=2)f.push(pt(c[n][i],c[n][i+1],e,a,o,s));l.geometry.push(f)}}return t.transformed=!0,t}function pt(t,e,r,n,i,a){return[Math.round(r*(t*n-i)),Math.round(r*(e*n-a))]}function dt(t,e,r,n,i){for(var a=e===i.maxZoom?0:i.tolerance/((1<<e)*i.extent),o={features:[],numPoints:0,numSimplified:0,numFeatures:0,source:null,x:r,y:n,z:e,transformed:!1,minX:2,minY:1,maxX:-1,maxY:0},s=0;s<t.length;s++){o.numFeatures++,gt(o,t[s],a,i);var l=t[s].minX,c=t[s].minY,u=t[s].maxX,f=t[s].maxY;l<o.minX&&(o.minX=l),c<o.minY&&(o.minY=c),u>o.maxX&&(o.maxX=u),f>o.maxY&&(o.maxY=f)}return o}function gt(t,e,r,n){var i=e.geometry,a=e.type,o=[];if(\"Point\"===a||\"MultiPoint\"===a)for(var s=0;s<i.length;s+=3)o.push(i[s]),o.push(i[s+1]),t.numPoints++,t.numSimplified++;else if(\"LineString\"===a)mt(o,i,t,r,!1,!1);else if(\"MultiLineString\"===a||\"Polygon\"===a)for(s=0;s<i.length;s++)mt(o,i[s],t,r,\"Polygon\"===a,0===s);else if(\"MultiPolygon\"===a)for(var l=0;l<i.length;l++){var c=i[l];for(s=0;s<c.length;s++)mt(o,c[s],t,r,!0,0===s)}if(o.length){var u=e.tags||null;if(\"LineString\"===a&&n.lineMetrics){for(var f in u={},e.tags)u[f]=e.tags[f];u.mapbox_clip_start=i.start/i.size,u.mapbox_clip_end=i.end/i.size}var h={geometry:o,type:\"Polygon\"===a||\"MultiPolygon\"===a?3:\"LineString\"===a||\"MultiLineString\"===a?2:1,tags:u};null!==e.id&&(h.id=e.id),t.features.push(h)}}function mt(t,e,r,n,i,a){var o=n*n;if(n>0&&e.size<(i?o:n))r.numPoints+=e.length/3;else{for(var s=[],l=0;l<e.length;l+=3)(0===n||e[l+2]>o)&&(r.numSimplified++,s.push(e[l]),s.push(e[l+1])),r.numPoints++;i&&function(t,e){for(var r=0,n=0,i=t.length,a=i-2;n<i;a=n,n+=2)r+=(t[n]-t[a])*(t[n+1]+t[a+1]);if(r>0===e)for(n=0,i=t.length;n<i/2;n+=2){var o=t[n],s=t[n+1];t[n]=t[i-2-n],t[n+1]=t[i-1-n],t[i-2-n]=o,t[i-1-n]=s}}(s,a),t.push(s)}}function vt(t,e){var r=(e=this.options=function(t,e){for(var r in e)t[r]=e[r];return t}(Object.create(this.options),e)).debug;if(r&&console.time(\"preprocess data\"),e.maxZoom<0||e.maxZoom>24)throw new Error(\"maxZoom should be in the 0-24 range\");if(e.promoteId&&e.generateId)throw new Error(\"promoteId and generateId cannot be used together.\");var n=function(t,e){var r=[];if(\"FeatureCollection\"===t.type)for(var n=0;n<t.features.length;n++)J(r,t.features[n],e,n);else J(r,\"Feature\"===t.type?t:{geometry:t},e);return r}(t,e);this.tiles={},this.tileCoords=[],r&&(console.timeEnd(\"preprocess data\"),console.log(\"index: maxZoom: %d, maxPoints: %d\",e.indexMaxZoom,e.indexMaxPoints),console.time(\"generate tiles\"),this.stats={},this.total=0),(n=function(t,e){var r=e.buffer/e.extent,n=t,i=rt(t,1,-1-r,r,0,-1,2,e),a=rt(t,1,1-r,2+r,0,-1,2,e);return(i||a)&&(n=rt(t,1,-r,1+r,0,-1,2,e)||[],i&&(n=ut(i,1).concat(n)),a&&(n=n.concat(ut(a,-1)))),n}(n,e)).length&&this.splitTile(n,0,0,0),r&&(n.length&&console.log(\"features: %d, points: %d\",this.tiles[0].numFeatures,this.tiles[0].numPoints),console.timeEnd(\"generate tiles\"),console.log(\"tiles generated:\",this.total,JSON.stringify(this.stats)))}function yt(t,e,r){return 32*((1<<t)*r+e)+t}function xt(t,e){var r=t.tileID.canonical;if(!this._geoJSONIndex)return e(null,null);var n=this._geoJSONIndex.getTile(r.z,r.x,r.y);if(!n)return e(null,null);var i=new g(n.features),a=b(i);0===a.byteOffset&&a.byteLength===a.buffer.byteLength||(a=new Uint8Array(a)),e(null,{vectorTile:i,rawData:a.buffer})}F.prototype.load=function(t){var e=this.options,r=e.log,n=e.minZoom,i=e.maxZoom,a=e.nodeSize;r&&console.time(\"total time\");var o=\"prepare \"+t.length+\" points\";r&&console.time(o),this.points=t;for(var s=[],l=0;l<t.length;l++)t[l].geometry&&s.push(N(t[l],l));this.trees[i+1]=new D(s,G,Y,a,Float32Array),r&&console.timeEnd(o);for(var c=i;c>=n;c--){var u=+Date.now();s=this._cluster(s,c),this.trees[c]=new D(s,G,Y,a,Float32Array),r&&console.log(\"z%d: %d clusters in %dms\",c,s.length,+Date.now()-u)}return r&&console.timeEnd(\"total time\"),this},F.prototype.getClusters=function(t,e){var r=((t[0]+180)%360+360)%360-180,n=Math.max(-90,Math.min(90,t[1])),i=180===t[2]?180:((t[2]+180)%360+360)%360-180,a=Math.max(-90,Math.min(90,t[3]));if(t[2]-t[0]>=360)r=-180,i=180;else if(r>i){var o=this.getClusters([r,n,180,a],e),s=this.getClusters([-180,n,i,a],e);return o.concat(s)}for(var l=this.trees[this._limitZoom(e)],c=[],u=0,f=l.range(V(r),q(a),V(i),q(n));u<f.length;u+=1){var h=l.points[f[u]];c.push(h.numPoints?j(h):this.points[h.index])}return c},F.prototype.getChildren=function(t){var e=this._getOriginId(t),r=this._getOriginZoom(t),n=\"No cluster with the specified id.\",i=this.trees[r];if(!i)throw new Error(n);var a=i.points[e];if(!a)throw new Error(n);for(var o=this.options.radius/(this.options.extent*Math.pow(2,r-1)),s=[],l=0,c=i.within(a.x,a.y,o);l<c.length;l+=1){var u=i.points[c[l]];u.parentId===t&&s.push(u.numPoints?j(u):this.points[u.index])}if(0===s.length)throw new Error(n);return s},F.prototype.getLeaves=function(t,e,r){var n=[];return this._appendLeaves(n,t,e=e||10,r=r||0,0),n},F.prototype.getTile=function(t,e,r){var n=this.trees[this._limitZoom(t)],i=Math.pow(2,t),a=this.options,o=a.radius/a.extent,s=(r-o)/i,l=(r+1+o)/i,c={features:[]};return this._addTileFeatures(n.range((e-o)/i,s,(e+1+o)/i,l),n.points,e,r,i,c),0===e&&this._addTileFeatures(n.range(1-o/i,s,1,l),n.points,i,r,i,c),e===i-1&&this._addTileFeatures(n.range(0,s,o/i,l),n.points,-1,r,i,c),c.features.length?c:null},F.prototype.getClusterExpansionZoom=function(t){for(var e=this._getOriginZoom(t)-1;e<=this.options.maxZoom;){var r=this.getChildren(t);if(e++,1!==r.length)break;t=r[0].properties.cluster_id}return e},F.prototype._appendLeaves=function(t,e,r,n,i){for(var a=0,o=this.getChildren(e);a<o.length;a+=1){var s=o[a],l=s.properties;if(l&&l.cluster?i+l.point_count<=n?i+=l.point_count:i=this._appendLeaves(t,l.cluster_id,r,n,i):i<n?i++:t.push(s),t.length===r)break}return i},F.prototype._addTileFeatures=function(t,e,r,n,i,a){for(var o=0,s=t;o<s.length;o+=1){var l=e[s[o]],c=l.numPoints,u={type:1,geometry:[[Math.round(this.options.extent*(l.x*i-r)),Math.round(this.options.extent*(l.y*i-n))]],tags:c?U(l):this.points[l.index].properties},f=void 0;c?f=l.id:this.options.generateId?f=l.index:this.points[l.index].id&&(f=this.points[l.index].id),void 0!==f&&(u.id=f),a.features.push(u)}},F.prototype._limitZoom=function(t){return Math.max(this.options.minZoom,Math.min(t,this.options.maxZoom+1))},F.prototype._cluster=function(t,e){for(var r=[],n=this.options,i=n.reduce,a=n.radius/(n.extent*Math.pow(2,e)),o=0;o<t.length;o++){var s=t[o];if(!(s.zoom<=e)){s.zoom=e;for(var l=this.trees[e+1],c=l.within(s.x,s.y,a),u=s.numPoints||1,f=s.x*u,h=s.y*u,p=i&&u>1?this._map(s,!0):null,d=(o<<5)+(e+1)+this.points.length,g=0,m=c;g<m.length;g+=1){var v=l.points[m[g]];if(!(v.zoom<=e)){v.zoom=e;var y=v.numPoints||1;f+=v.x*y,h+=v.y*y,u+=y,v.parentId=d,i&&(p||(p=this._map(s,!0)),i(p,this._map(v)))}}1===u?r.push(s):(s.parentId=d,r.push(B(f/u,h/u,d,u,p)))}}return r},F.prototype._getOriginId=function(t){return t-this.points.length>>5},F.prototype._getOriginZoom=function(t){return(t-this.points.length)%32},F.prototype._map=function(t,e){if(t.numPoints)return e?H({},t.properties):t.properties;var r=this.points[t.index].properties,n=this.options.map(r);return e&&n===r?H({},n):n},vt.prototype.options={maxZoom:14,indexMaxZoom:5,indexMaxPoints:1e5,tolerance:3,extent:4096,buffer:64,lineMetrics:!1,promoteId:null,generateId:!1,debug:0},vt.prototype.splitTile=function(t,e,r,n,i,a,o){for(var s=[t,e,r,n],l=this.options,c=l.debug;s.length;){n=s.pop(),r=s.pop(),e=s.pop(),t=s.pop();var u=1<<e,f=yt(e,r,n),h=this.tiles[f];if(!h&&(c>1&&console.time(\"creation\"),h=this.tiles[f]=dt(t,e,r,n,l),this.tileCoords.push({z:e,x:r,y:n}),c)){c>1&&(console.log(\"tile z%d-%d-%d (features: %d, points: %d, simplified: %d)\",e,r,n,h.numFeatures,h.numPoints,h.numSimplified),console.timeEnd(\"creation\"));var p=\"z\"+e;this.stats[p]=(this.stats[p]||0)+1,this.total++}if(h.source=t,i){if(e===l.maxZoom||e===i)continue;var d=1<<i-e;if(r!==Math.floor(a/d)||n!==Math.floor(o/d))continue}else if(e===l.indexMaxZoom||h.numPoints<=l.indexMaxPoints)continue;if(h.source=null,0!==t.length){c>1&&console.time(\"clipping\");var g,m,v,y,x,b,_=.5*l.buffer/l.extent,w=.5-_,T=.5+_,k=1+_;g=m=v=y=null,x=rt(t,u,r-_,r+T,0,h.minX,h.maxX,l),b=rt(t,u,r+w,r+k,0,h.minX,h.maxX,l),t=null,x&&(g=rt(x,u,n-_,n+T,1,h.minY,h.maxY,l),m=rt(x,u,n+w,n+k,1,h.minY,h.maxY,l),x=null),b&&(v=rt(b,u,n-_,n+T,1,h.minY,h.maxY,l),y=rt(b,u,n+w,n+k,1,h.minY,h.maxY,l),b=null),c>1&&console.timeEnd(\"clipping\"),s.push(g||[],e+1,2*r,2*n),s.push(m||[],e+1,2*r,2*n+1),s.push(v||[],e+1,2*r+1,2*n),s.push(y||[],e+1,2*r+1,2*n+1)}}},vt.prototype.getTile=function(t,e,r){var n=this.options,i=n.extent,a=n.debug;if(t<0||t>24)return null;var o=1<<t,s=yt(t,e=(e%o+o)%o,r);if(this.tiles[s])return ht(this.tiles[s],i);a>1&&console.log(\"drilling down to z%d-%d-%d\",t,e,r);for(var l,c=t,u=e,f=r;!l&&c>0;)c--,u=Math.floor(u/2),f=Math.floor(f/2),l=this.tiles[yt(c,u,f)];return l&&l.source?(a>1&&console.log(\"found parent tile z%d-%d-%d\",c,u,f),a>1&&console.time(\"drilling down\"),this.splitTile(l.source,c,u,f,t,e,r),a>1&&console.timeEnd(\"drilling down\"),this.tiles[s]?ht(this.tiles[s],i):null):null};var bt=function(e){function r(t,r,n,i){e.call(this,t,r,n,xt),i&&(this.loadGeoJSON=i)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadData=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),this._pendingCallback=e,this._pendingLoadDataParams=t,this._state&&\"Idle\"!==this._state?this._state=\"NeedsLoadData\":(this._state=\"Coalescing\",this._loadData())},r.prototype._loadData=function(){var e=this;if(this._pendingCallback&&this._pendingLoadDataParams){var r=this._pendingCallback,n=this._pendingLoadDataParams;delete this._pendingCallback,delete this._pendingLoadDataParams;var i=!!(n&&n.request&&n.request.collectResourceTiming)&&new t.RequestPerformance(n.request);this.loadGeoJSON(n,(function(a,o){if(a||!o)return r(a);if(\"object\"!=typeof o)return r(new Error(\"Input data given to '\"+n.source+\"' is not a valid GeoJSON object.\"));!function t(e,r){var n,i=e&&e.type;if(\"FeatureCollection\"===i)for(n=0;n<e.features.length;n++)t(e.features[n],r);else if(\"GeometryCollection\"===i)for(n=0;n<e.geometries.length;n++)t(e.geometries[n],r);else if(\"Feature\"===i)t(e.geometry,r);else if(\"Polygon\"===i)f(e.coordinates,r);else if(\"MultiPolygon\"===i)for(n=0;n<e.coordinates.length;n++)f(e.coordinates[n],r);return e}(o,!0);try{e._geoJSONIndex=n.cluster?new F(function(e){var r=e.superclusterOptions,n=e.clusterProperties;if(!n||!r)return r;for(var i={},a={},o={accumulated:null,zoom:0},s={properties:null},l=Object.keys(n),c=0,u=l;c<u.length;c+=1){var f=u[c],h=n[f],p=h[0],d=t.createExpression(h[1]),g=t.createExpression(\"string\"==typeof p?[p,[\"accumulated\"],[\"get\",f]]:p);i[f]=d.value,a[f]=g.value}return r.map=function(t){s.properties=t;for(var e={},r=0,n=l;r<n.length;r+=1){var a=n[r];e[a]=i[a].evaluate(o,s)}return e},r.reduce=function(t,e){s.properties=e;for(var r=0,n=l;r<n.length;r+=1){var i=n[r];o.accumulated=t[i],t[i]=a[i].evaluate(o,s)}},r}(n)).load(o.features):function(t,e){return new vt(t,e)}(o,n.geojsonVtOptions)}catch(a){return r(a)}e.loaded={};var s={};if(i){var l=i.finish();l&&(s.resourceTiming={},s.resourceTiming[n.source]=JSON.parse(JSON.stringify(l)))}r(null,s)}))}},r.prototype.coalesce=function(){\"Coalescing\"===this._state?this._state=\"Idle\":\"NeedsLoadData\"===this._state&&(this._state=\"Coalescing\",this._loadData())},r.prototype.reloadTile=function(t,r){var n=this.loaded;return n&&n[t.uid]?e.prototype.reloadTile.call(this,t,r):this.loadTile(t,r)},r.prototype.loadGeoJSON=function(e,r){if(e.request)t.getJSON(e.request,r);else{if(\"string\"!=typeof e.data)return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"));try{return r(null,JSON.parse(e.data))}catch(t){return r(new Error(\"Input data given to '\"+e.source+\"' is not a valid GeoJSON object.\"))}}},r.prototype.removeSource=function(t,e){this._pendingCallback&&this._pendingCallback(null,{abandoned:!0}),e()},r.prototype.getClusterExpansionZoom=function(t,e){try{e(null,this._geoJSONIndex.getClusterExpansionZoom(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterChildren=function(t,e){try{e(null,this._geoJSONIndex.getChildren(t.clusterId))}catch(t){e(t)}},r.prototype.getClusterLeaves=function(t,e){try{e(null,this._geoJSONIndex.getLeaves(t.clusterId,t.limit,t.offset))}catch(t){e(t)}},r}(l),_t=function(e){var r=this;this.self=e,this.actor=new t.Actor(e,this),this.layerIndexes={},this.availableImages={},this.workerSourceTypes={vector:l,geojson:bt},this.workerSources={},this.demWorkerSources={},this.self.registerWorkerSource=function(t,e){if(r.workerSourceTypes[t])throw new Error('Worker source with name \"'+t+'\" already registered.');r.workerSourceTypes[t]=e},this.self.registerRTLTextPlugin=function(e){if(t.plugin.isParsed())throw new Error(\"RTL text plugin already registered.\");t.plugin.applyArabicShaping=e.applyArabicShaping,t.plugin.processBidirectionalText=e.processBidirectionalText,t.plugin.processStyledBidirectionalText=e.processStyledBidirectionalText}};return _t.prototype.setReferrer=function(t,e){this.referrer=e},_t.prototype.setImages=function(t,e,r){for(var n in this.availableImages[t]=e,this.workerSources[t]){var i=this.workerSources[t][n];for(var a in i)i[a].availableImages=e}r()},_t.prototype.setLayers=function(t,e,r){this.getLayerIndex(t).replace(e),r()},_t.prototype.updateLayers=function(t,e,r){this.getLayerIndex(t).update(e.layers,e.removedIds),r()},_t.prototype.loadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).loadTile(e,r)},_t.prototype.loadDEMTile=function(t,e,r){this.getDEMWorkerSource(t,e.source).loadTile(e,r)},_t.prototype.reloadTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).reloadTile(e,r)},_t.prototype.abortTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).abortTile(e,r)},_t.prototype.removeTile=function(t,e,r){this.getWorkerSource(t,e.type,e.source).removeTile(e,r)},_t.prototype.removeDEMTile=function(t,e){this.getDEMWorkerSource(t,e.source).removeTile(e)},_t.prototype.removeSource=function(t,e,r){if(this.workerSources[t]&&this.workerSources[t][e.type]&&this.workerSources[t][e.type][e.source]){var n=this.workerSources[t][e.type][e.source];delete this.workerSources[t][e.type][e.source],void 0!==n.removeSource?n.removeSource(e,r):r()}},_t.prototype.loadWorkerSource=function(t,e,r){try{this.self.importScripts(e.url),r()}catch(t){r(t.toString())}},_t.prototype.syncRTLPluginState=function(e,r,n){try{t.plugin.setState(r);var i=t.plugin.getPluginURL();if(t.plugin.isLoaded()&&!t.plugin.isParsed()&&null!=i){this.self.importScripts(i);var a=t.plugin.isParsed();n(a?void 0:new Error(\"RTL Text Plugin failed to import scripts from \"+i),a)}}catch(t){n(t.toString())}},_t.prototype.getAvailableImages=function(t){var e=this.availableImages[t];return e||(e=[]),e},_t.prototype.getLayerIndex=function(t){var e=this.layerIndexes[t];return e||(e=this.layerIndexes[t]=new n),e},_t.prototype.getWorkerSource=function(t,e,r){var n=this;return this.workerSources[t]||(this.workerSources[t]={}),this.workerSources[t][e]||(this.workerSources[t][e]={}),this.workerSources[t][e][r]||(this.workerSources[t][e][r]=new this.workerSourceTypes[e]({send:function(e,r,i){n.actor.send(e,r,i,t)}},this.getLayerIndex(t),this.getAvailableImages(t))),this.workerSources[t][e][r]},_t.prototype.getDEMWorkerSource=function(t,e){return this.demWorkerSources[t]||(this.demWorkerSources[t]={}),this.demWorkerSources[t][e]||(this.demWorkerSources[t][e]=new u),this.demWorkerSources[t][e]},_t.prototype.enforceCacheSizeLimit=function(e,r){t.enforceCacheSizeLimit(r)},\"undefined\"!=typeof WorkerGlobalScope&&void 0!==t.window&&t.window instanceof WorkerGlobalScope&&(t.window.worker=new _t(t.window)),_t})),n(0,(function(t){var e=t.createCommonjsModule((function(t){function e(t){return!r(t)}function r(t){return\"undefined\"==typeof window||\"undefined\"==typeof document?\"not a browser\":Array.prototype&&Array.prototype.every&&Array.prototype.filter&&Array.prototype.forEach&&Array.prototype.indexOf&&Array.prototype.lastIndexOf&&Array.prototype.map&&Array.prototype.some&&Array.prototype.reduce&&Array.prototype.reduceRight&&Array.isArray?Function.prototype&&Function.prototype.bind?Object.keys&&Object.create&&Object.getPrototypeOf&&Object.getOwnPropertyNames&&Object.isSealed&&Object.isFrozen&&Object.isExtensible&&Object.getOwnPropertyDescriptor&&Object.defineProperty&&Object.defineProperties&&Object.seal&&Object.freeze&&Object.preventExtensions?\"JSON\"in window&&\"parse\"in JSON&&\"stringify\"in JSON?function(){if(!(\"Worker\"in window&&\"Blob\"in window&&\"URL\"in window))return!1;var t,e,r=new Blob([\"\"],{type:\"text/javascript\"}),n=URL.createObjectURL(r);try{e=new Worker(n),t=!0}catch(e){t=!1}return e&&e.terminate(),URL.revokeObjectURL(n),t}()?\"Uint8ClampedArray\"in window?ArrayBuffer.isView?function(){var t=document.createElement(\"canvas\");t.width=t.height=1;var e=t.getContext(\"2d\");if(!e)return!1;var r=e.getImageData(0,0,1,1);return r&&r.width===t.width}()?(void 0===n[r=t&&t.failIfMajorPerformanceCaveat]&&(n[r]=function(t){var r=function(t){var r=document.createElement(\"canvas\"),n=Object.create(e.webGLContextAttributes);return n.failIfMajorPerformanceCaveat=t,r.probablySupportsContext?r.probablySupportsContext(\"webgl\",n)||r.probablySupportsContext(\"experimental-webgl\",n):r.supportsContext?r.supportsContext(\"webgl\",n)||r.supportsContext(\"experimental-webgl\",n):r.getContext(\"webgl\",n)||r.getContext(\"experimental-webgl\",n)}(t);if(!r)return!1;var n=r.createShader(r.VERTEX_SHADER);return!(!n||r.isContextLost())&&(r.shaderSource(n,\"void main() {}\"),r.compileShader(n),!0===r.getShaderParameter(n,r.COMPILE_STATUS))}(r)),n[r]?void 0:\"insufficient WebGL support\"):\"insufficient Canvas/getImageData support\":\"insufficient ArrayBuffer support\":\"insufficient Uint8ClampedArray support\":\"insufficient worker support\":\"insufficient JSON support\":\"insufficient Object support\":\"insufficient Function support\":\"insufficent Array support\";var r}t.exports?t.exports=e:window&&(window.mapboxgl=window.mapboxgl||{},window.mapboxgl.supported=e,window.mapboxgl.notSupportedReason=r);var n={};e.webGLContextAttributes={antialias:!1,alpha:!0,stencil:!0,depth:!0}})),r={create:function(e,r,n){var i=t.window.document.createElement(e);return void 0!==r&&(i.className=r),n&&n.appendChild(i),i},createNS:function(e,r){return t.window.document.createElementNS(e,r)}},n=t.window.document.documentElement.style;function i(t){if(!n)return t[0];for(var e=0;e<t.length;e++)if(t[e]in n)return t[e];return t[0]}var a,o=i([\"userSelect\",\"MozUserSelect\",\"WebkitUserSelect\",\"msUserSelect\"]);r.disableDrag=function(){n&&o&&(a=n[o],n[o]=\"none\")},r.enableDrag=function(){n&&o&&(n[o]=a)};var s=i([\"transform\",\"WebkitTransform\"]);r.setTransform=function(t,e){t.style[s]=e};var l=!1;try{var c=Object.defineProperty({},\"passive\",{get:function(){l=!0}});t.window.addEventListener(\"test\",c,c),t.window.removeEventListener(\"test\",c,c)}catch(t){l=!1}r.addEventListener=function(t,e,r,n){void 0===n&&(n={}),t.addEventListener(e,r,\"passive\"in n&&l?n:n.capture)},r.removeEventListener=function(t,e,r,n){void 0===n&&(n={}),t.removeEventListener(e,r,\"passive\"in n&&l?n:n.capture)};var u=function(e){e.preventDefault(),e.stopPropagation(),t.window.removeEventListener(\"click\",u,!0)};function f(t){var e=t.userImage;return!!(e&&e.render&&e.render())&&(t.data.replace(new Uint8Array(e.data.buffer)),!0)}r.suppressClick=function(){t.window.addEventListener(\"click\",u,!0),t.window.setTimeout((function(){t.window.removeEventListener(\"click\",u,!0)}),0)},r.mousePos=function(e,r){var n=e.getBoundingClientRect();return new t.Point(r.clientX-n.left-e.clientLeft,r.clientY-n.top-e.clientTop)},r.touchPos=function(e,r){for(var n=e.getBoundingClientRect(),i=[],a=0;a<r.length;a++)i.push(new t.Point(r[a].clientX-n.left-e.clientLeft,r[a].clientY-n.top-e.clientTop));return i},r.mouseButton=function(e){return void 0!==t.window.InstallTrigger&&2===e.button&&e.ctrlKey&&t.window.navigator.platform.toUpperCase().indexOf(\"MAC\")>=0?0:e.button},r.remove=function(t){t.parentNode&&t.parentNode.removeChild(t)};var h=function(e){function r(){e.call(this),this.images={},this.updatedImages={},this.callbackDispatchedThisFrame={},this.loaded=!1,this.requestors=[],this.patterns={},this.atlasImage=new t.RGBAImage({width:1,height:1}),this.dirty=!0}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.isLoaded=function(){return this.loaded},r.prototype.setLoaded=function(t){if(this.loaded!==t&&(this.loaded=t,t)){for(var e=0,r=this.requestors;e<r.length;e+=1){var n=r[e];this._notify(n.ids,n.callback)}this.requestors=[]}},r.prototype.getImage=function(t){return this.images[t]},r.prototype.addImage=function(t,e){this._validate(t,e)&&(this.images[t]=e)},r.prototype._validate=function(e,r){var n=!0;return this._validateStretch(r.stretchX,r.data&&r.data.width)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchX\" value'))),n=!1),this._validateStretch(r.stretchY,r.data&&r.data.height)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"stretchY\" value'))),n=!1),this._validateContent(r.content,r)||(this.fire(new t.ErrorEvent(new Error('Image \"'+e+'\" has invalid \"content\" value'))),n=!1),n},r.prototype._validateStretch=function(t,e){if(!t)return!0;for(var r=0,n=0,i=t;n<i.length;n+=1){var a=i[n];if(a[0]<r||a[1]<a[0]||e<a[1])return!1;r=a[1]}return!0},r.prototype._validateContent=function(t,e){return!(t&&(4!==t.length||t[0]<0||e.data.width<t[0]||t[1]<0||e.data.height<t[1]||t[2]<0||e.data.width<t[2]||t[3]<0||e.data.height<t[3]||t[2]<t[0]||t[3]<t[1]))},r.prototype.updateImage=function(t,e){e.version=this.images[t].version+1,this.images[t]=e,this.updatedImages[t]=!0},r.prototype.removeImage=function(t){var e=this.images[t];delete this.images[t],delete this.patterns[t],e.userImage&&e.userImage.onRemove&&e.userImage.onRemove()},r.prototype.listImages=function(){return Object.keys(this.images)},r.prototype.getImages=function(t,e){var r=!0;if(!this.isLoaded())for(var n=0,i=t;n<i.length;n+=1)this.images[i[n]]||(r=!1);this.isLoaded()||r?this._notify(t,e):this.requestors.push({ids:t,callback:e})},r.prototype._notify=function(e,r){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i];this.images[o]||this.fire(new t.Event(\"styleimagemissing\",{id:o}));var s=this.images[o];s?n[o]={data:s.data.clone(),pixelRatio:s.pixelRatio,sdf:s.sdf,version:s.version,stretchX:s.stretchX,stretchY:s.stretchY,content:s.content,hasRenderCallback:Boolean(s.userImage&&s.userImage.render)}:t.warnOnce('Image \"'+o+'\" could not be loaded. Please make sure you have added the image with map.addImage() or a \"sprite\" property in your style. You can provide missing images by listening for the \"styleimagemissing\" map event.')}r(null,n)},r.prototype.getPixelSize=function(){var t=this.atlasImage;return{width:t.width,height:t.height}},r.prototype.getPattern=function(e){var r=this.patterns[e],n=this.getImage(e);if(!n)return null;if(r&&r.position.version===n.version)return r.position;if(r)r.position.version=n.version;else{var i={w:n.data.width+2,h:n.data.height+2,x:0,y:0},a=new t.ImagePosition(i,n);this.patterns[e]={bin:i,position:a}}return this._updatePatternAtlas(),this.patterns[e].position},r.prototype.bind=function(e){var r=e.gl;this.atlasTexture?this.dirty&&(this.atlasTexture.update(this.atlasImage),this.dirty=!1):this.atlasTexture=new t.Texture(e,this.atlasImage,r.RGBA),this.atlasTexture.bind(r.LINEAR,r.CLAMP_TO_EDGE)},r.prototype._updatePatternAtlas=function(){var e=[];for(var r in this.patterns)e.push(this.patterns[r].bin);var n=t.potpack(e),i=n.w,a=n.h,o=this.atlasImage;for(var s in o.resize({width:i||1,height:a||1}),this.patterns){var l=this.patterns[s].bin,c=l.x+1,u=l.y+1,f=this.images[s].data,h=f.width,p=f.height;t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u},{width:h,height:p}),t.RGBAImage.copy(f,o,{x:0,y:p-1},{x:c,y:u-1},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c,y:u+p},{width:h,height:1}),t.RGBAImage.copy(f,o,{x:h-1,y:0},{x:c-1,y:u},{width:1,height:p}),t.RGBAImage.copy(f,o,{x:0,y:0},{x:c+h,y:u},{width:1,height:p})}this.dirty=!0},r.prototype.beginFrame=function(){this.callbackDispatchedThisFrame={}},r.prototype.dispatchRenderCallbacks=function(t){for(var e=0,r=t;e<r.length;e+=1){var n=r[e];if(!this.callbackDispatchedThisFrame[n]){this.callbackDispatchedThisFrame[n]=!0;var i=this.images[n];f(i)&&this.updateImage(n,i)}}},r}(t.Evented),p=m,d=m,g=1e20;function m(t,e,r,n,i,a){this.fontSize=t||24,this.buffer=void 0===e?3:e,this.cutoff=n||.25,this.fontFamily=i||\"sans-serif\",this.fontWeight=a||\"normal\",this.radius=r||8;var o=this.size=this.fontSize+2*this.buffer;this.canvas=document.createElement(\"canvas\"),this.canvas.width=this.canvas.height=o,this.ctx=this.canvas.getContext(\"2d\"),this.ctx.font=this.fontWeight+\" \"+this.fontSize+\"px \"+this.fontFamily,this.ctx.textBaseline=\"middle\",this.ctx.fillStyle=\"black\",this.gridOuter=new Float64Array(o*o),this.gridInner=new Float64Array(o*o),this.f=new Float64Array(o),this.d=new Float64Array(o),this.z=new Float64Array(o+1),this.v=new Int16Array(o),this.middle=Math.round(o/2*(navigator.userAgent.indexOf(\"Gecko/\")>=0?1.2:1))}function v(t,e,r,n,i,a,o){for(var s=0;s<e;s++){for(var l=0;l<r;l++)n[l]=t[l*e+s];for(y(n,i,a,o,r),l=0;l<r;l++)t[l*e+s]=i[l]}for(l=0;l<r;l++){for(s=0;s<e;s++)n[s]=t[l*e+s];for(y(n,i,a,o,e),s=0;s<e;s++)t[l*e+s]=Math.sqrt(i[s])}}function y(t,e,r,n,i){r[0]=0,n[0]=-g,n[1]=+g;for(var a=1,o=0;a<i;a++){for(var s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);s<=n[o];)o--,s=(t[a]+a*a-(t[r[o]]+r[o]*r[o]))/(2*a-2*r[o]);r[++o]=a,n[o]=s,n[o+1]=+g}for(a=0,o=0;a<i;a++){for(;n[o+1]<a;)o++;e[a]=(a-r[o])*(a-r[o])+t[r[o]]}}m.prototype.draw=function(t){this.ctx.clearRect(0,0,this.size,this.size),this.ctx.fillText(t,this.buffer,this.middle);for(var e=this.ctx.getImageData(0,0,this.size,this.size),r=new Uint8ClampedArray(this.size*this.size),n=0;n<this.size*this.size;n++){var i=e.data[4*n+3]/255;this.gridOuter[n]=1===i?0:0===i?g:Math.pow(Math.max(0,.5-i),2),this.gridInner[n]=1===i?g:0===i?0:Math.pow(Math.max(0,i-.5),2)}for(v(this.gridOuter,this.size,this.size,this.f,this.d,this.v,this.z),v(this.gridInner,this.size,this.size,this.f,this.d,this.v,this.z),n=0;n<this.size*this.size;n++)r[n]=Math.max(0,Math.min(255,Math.round(255-255*((this.gridOuter[n]-this.gridInner[n])/this.radius+this.cutoff))));return r},p.default=d;var x=function(t,e){this.requestManager=t,this.localIdeographFontFamily=e,this.entries={}};x.prototype.setURL=function(t){this.url=t},x.prototype.getGlyphs=function(e,r){var n=this,i=[];for(var a in e)for(var o=0,s=e[a];o<s.length;o+=1)i.push({stack:a,id:s[o]});t.asyncAll(i,(function(t,e){var r=t.stack,i=t.id,a=n.entries[r];a||(a=n.entries[r]={glyphs:{},requests:{},ranges:{}});var o=a.glyphs[i];if(void 0===o){if(o=n._tinySDF(a,r,i))return a.glyphs[i]=o,void e(null,{stack:r,id:i,glyph:o});var s=Math.floor(i/256);if(256*s>65535)e(new Error(\"glyphs > 65535 not supported\"));else if(a.ranges[s])e(null,{stack:r,id:i,glyph:o});else{var l=a.requests[s];l||(l=a.requests[s]=[],x.loadGlyphRange(r,s,n.url,n.requestManager,(function(t,e){if(e){for(var r in e)n._doesCharSupportLocalGlyph(+r)||(a.glyphs[+r]=e[+r]);a.ranges[s]=!0}for(var i=0,o=l;i<o.length;i+=1)(0,o[i])(t,e);delete a.requests[s]}))),l.push((function(t,n){t?e(t):n&&e(null,{stack:r,id:i,glyph:n[i]||null})}))}}else e(null,{stack:r,id:i,glyph:o})}),(function(t,e){if(t)r(t);else if(e){for(var n={},i=0,a=e;i<a.length;i+=1){var o=a[i],s=o.stack,l=o.id,c=o.glyph;(n[s]||(n[s]={}))[l]=c&&{id:c.id,bitmap:c.bitmap.clone(),metrics:c.metrics}}r(null,n)}}))},x.prototype._doesCharSupportLocalGlyph=function(e){return!!this.localIdeographFontFamily&&(t.isChar[\"CJK Unified Ideographs\"](e)||t.isChar[\"Hangul Syllables\"](e)||t.isChar.Hiragana(e)||t.isChar.Katakana(e))},x.prototype._tinySDF=function(e,r,n){var i=this.localIdeographFontFamily;if(i&&this._doesCharSupportLocalGlyph(n)){var a=e.tinySDF;if(!a){var o=\"400\";/bold/i.test(r)?o=\"900\":/medium/i.test(r)?o=\"500\":/light/i.test(r)&&(o=\"200\"),a=e.tinySDF=new x.TinySDF(24,3,8,.25,i,o)}return{id:n,bitmap:new t.AlphaImage({width:30,height:30},a.draw(String.fromCharCode(n))),metrics:{width:24,height:24,left:0,top:-8,advance:24}}}},x.loadGlyphRange=function(e,r,n,i,a){var o=256*r,s=o+255,l=i.transformRequest(i.normalizeGlyphsURL(n).replace(\"{fontstack}\",e).replace(\"{range}\",o+\"-\"+s),t.ResourceType.Glyphs);t.getArrayBuffer(l,(function(e,r){if(e)a(e);else if(r){for(var n={},i=0,o=t.parseGlyphPBF(r);i<o.length;i+=1){var s=o[i];n[s.id]=s}a(null,n)}}))},x.TinySDF=p;var b=function(){this.specification=t.styleSpec.light.position};b.prototype.possiblyEvaluate=function(e,r){return t.sphericalToCartesian(e.expression.evaluate(r))},b.prototype.interpolate=function(e,r,n){return{x:t.number(e.x,r.x,n),y:t.number(e.y,r.y,n),z:t.number(e.z,r.z,n)}};var _=new t.Properties({anchor:new t.DataConstantProperty(t.styleSpec.light.anchor),position:new b,color:new t.DataConstantProperty(t.styleSpec.light.color),intensity:new t.DataConstantProperty(t.styleSpec.light.intensity)}),w=function(e){function r(r){e.call(this),this._transitionable=new t.Transitionable(_),this.setLight(r),this._transitioning=this._transitionable.untransitioned()}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getLight=function(){return this._transitionable.serialize()},r.prototype.setLight=function(e,r){if(void 0===r&&(r={}),!this._validate(t.validateLight,e,r))for(var n in e){var i=e[n];t.endsWith(n,\"-transition\")?this._transitionable.setTransition(n.slice(0,-\"-transition\".length),i):this._transitionable.setValue(n,i)}},r.prototype.updateTransitions=function(t){this._transitioning=this._transitionable.transitioned(t,this._transitioning)},r.prototype.hasTransition=function(){return this._transitioning.hasTransition()},r.prototype.recalculate=function(t){this.properties=this._transitioning.possiblyEvaluate(t)},r.prototype._validate=function(e,r,n){return(!n||!1!==n.validate)&&t.emitValidationErrors(this,e.call(t.validateStyle,t.extend({value:r,style:{glyphs:!0,sprite:!0},styleSpec:t.styleSpec})))},r}(t.Evented),T=function(t,e){this.width=t,this.height=e,this.nextRow=0,this.data=new Uint8Array(this.width*this.height),this.dashEntry={}};T.prototype.getDash=function(t,e){var r=t.join(\",\")+String(e);return this.dashEntry[r]||(this.dashEntry[r]=this.addDash(t,e)),this.dashEntry[r]},T.prototype.getDashRanges=function(t,e,r){var n=[],i=t.length%2==1?-t[t.length-1]*r:0,a=t[0]*r,o=!0;n.push({left:i,right:a,isDash:o,zeroLength:0===t[0]});for(var s=t[0],l=1;l<t.length;l++){var c=t[l];n.push({left:i=s*r,right:a=(s+=c)*r,isDash:o=!o,zeroLength:0===c})}return n},T.prototype.addRoundDash=function(t,e,r){for(var n=e/2,i=-r;i<=r;i++)for(var a=this.width*(this.nextRow+r+i),o=0,s=t[o],l=0;l<this.width;l++){l/s.right>1&&(s=t[++o]);var c=Math.abs(l-s.left),u=Math.abs(l-s.right),f=Math.min(c,u),h=void 0,p=i/r*(n+1);if(s.isDash){var d=n-Math.abs(p);h=Math.sqrt(f*f+d*d)}else h=n-Math.sqrt(f*f+p*p);this.data[a+l]=Math.max(0,Math.min(255,h+128))}},T.prototype.addRegularDash=function(t){for(var e=t.length-1;e>=0;--e){var r=t[e],n=t[e+1];r.zeroLength?t.splice(e,1):n&&n.isDash===r.isDash&&(n.left=r.left,t.splice(e,1))}var i=t[0],a=t[t.length-1];i.isDash===a.isDash&&(i.left=a.left-this.width,a.right=i.right+this.width);for(var o=this.width*this.nextRow,s=0,l=t[s],c=0;c<this.width;c++){c/l.right>1&&(l=t[++s]);var u=Math.abs(c-l.left),f=Math.abs(c-l.right),h=Math.min(u,f);this.data[o+c]=Math.max(0,Math.min(255,(l.isDash?h:-h)+128))}},T.prototype.addDash=function(e,r){var n=r?7:0,i=2*n+1;if(this.nextRow+i>this.height)return t.warnOnce(\"LineAtlas out of space\"),null;for(var a=0,o=0;o<e.length;o++)a+=e[o];if(0!==a){var s=this.width/a,l=this.getDashRanges(e,this.width,s);r?this.addRoundDash(l,s,n):this.addRegularDash(l)}var c={y:(this.nextRow+n+.5)/this.height,height:2*n/this.height,width:a};return this.nextRow+=i,this.dirty=!0,c},T.prototype.bind=function(t){var e=t.gl;this.texture?(e.bindTexture(e.TEXTURE_2D,this.texture),this.dirty&&(this.dirty=!1,e.texSubImage2D(e.TEXTURE_2D,0,0,0,this.width,this.height,e.ALPHA,e.UNSIGNED_BYTE,this.data))):(this.texture=e.createTexture(),e.bindTexture(e.TEXTURE_2D,this.texture),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.REPEAT),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.LINEAR),e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.LINEAR),e.texImage2D(e.TEXTURE_2D,0,e.ALPHA,this.width,this.height,0,e.ALPHA,e.UNSIGNED_BYTE,this.data))};var k=function e(r,n){this.workerPool=r,this.actors=[],this.currentActor=0,this.id=t.uniqueId();for(var i=this.workerPool.acquire(this.id),a=0;a<i.length;a++){var o=new e.Actor(i[a],n,this.id);o.name=\"Worker \"+a,this.actors.push(o)}};function M(e,r,n){var i=function(i,a){if(i)return n(i);if(a){var o=t.pick(t.extend(a,e),[\"tiles\",\"minzoom\",\"maxzoom\",\"attribution\",\"mapbox_logo\",\"bounds\",\"scheme\",\"tileSize\",\"encoding\"]);a.vector_layers&&(o.vectorLayers=a.vector_layers,o.vectorLayerIds=o.vectorLayers.map((function(t){return t.id}))),o.tiles=r.canonicalizeTileset(o,e.url),n(null,o)}};return e.url?t.getJSON(r.transformRequest(r.normalizeSourceURL(e.url),t.ResourceType.Source),i):t.browser.frame((function(){return i(null,e)}))}k.prototype.broadcast=function(e,r,n){t.asyncAll(this.actors,(function(t,n){t.send(e,r,n)}),n=n||function(){})},k.prototype.getActor=function(){return this.currentActor=(this.currentActor+1)%this.actors.length,this.actors[this.currentActor]},k.prototype.remove=function(){this.actors.forEach((function(t){t.remove()})),this.actors=[],this.workerPool.release(this.id)},k.Actor=t.Actor;var A=function(e,r,n){this.bounds=t.LngLatBounds.convert(this.validateBounds(e)),this.minzoom=r||0,this.maxzoom=n||24};A.prototype.validateBounds=function(t){return Array.isArray(t)&&4===t.length?[Math.max(-180,t[0]),Math.max(-90,t[1]),Math.min(180,t[2]),Math.min(90,t[3])]:[-180,-90,180,90]},A.prototype.contains=function(e){var r=Math.pow(2,e.z),n=Math.floor(t.mercatorXfromLng(this.bounds.getWest())*r),i=Math.floor(t.mercatorYfromLat(this.bounds.getNorth())*r),a=Math.ceil(t.mercatorXfromLng(this.bounds.getEast())*r),o=Math.ceil(t.mercatorYfromLat(this.bounds.getSouth())*r);return e.x>=n&&e.x<a&&e.y>=i&&e.y<o};var S=function(e){function r(r,n,i,a){if(e.call(this),this.id=r,this.dispatcher=i,this.type=\"vector\",this.minzoom=0,this.maxzoom=22,this.scheme=\"xyz\",this.tileSize=512,this.reparseOverscaled=!0,this.isTileClipped=!0,this._loaded=!1,t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\",\"promoteId\"])),this._options=t.extend({type:\"vector\"},n),this._collectResourceTiming=n.collectResourceTiming,512!==this.tileSize)throw new Error(\"vector tile sources must have a tileSize of 512\");this.setEventedParent(a)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles,e.map._requestManager._customAccessToken),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken,e.map._requestManager._customAccessToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme)),i={request:this.map._requestManager.transformRequest(n,t.ResourceType.Tile),uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,tileSize:this.tileSize*e.tileID.overscaleFactor(),type:this.type,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId};function a(n,i){return delete e.request,e.aborted?r(null):n&&404!==n.status?r(n):(i&&i.resourceTiming&&(e.resourceTiming=i.resourceTiming),this.map._refreshExpiredTiles&&i&&e.setExpiryData(i),e.loadVectorData(i,this.map.painter),t.cacheEntryPossiblyAdded(this.dispatcher),r(null),void(e.reloadCallback&&(this.loadTile(e,e.reloadCallback),e.reloadCallback=null)))}i.request.collectResourceTiming=this._collectResourceTiming,e.actor&&\"expired\"!==e.state?\"loading\"===e.state?e.reloadCallback=r:e.request=e.actor.send(\"reloadTile\",i,a.bind(this)):(e.actor=this.dispatcher.getActor(),e.request=e.actor.send(\"loadTile\",i,a.bind(this)))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.actor&&t.actor.send(\"abortTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.unloadTile=function(t){t.unloadVectorData(),t.actor&&t.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id},void 0)},r.prototype.hasTransition=function(){return!1},r}(t.Evented),E=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.dispatcher=i,this.setEventedParent(a),this.type=\"raster\",this.minzoom=0,this.maxzoom=22,this.roundZoom=!0,this.scheme=\"xyz\",this.tileSize=512,this._loaded=!1,this._options=t.extend({type:\"raster\"},n),t.extend(this,t.pick(n,[\"url\",\"scheme\",\"tileSize\"]))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._tileJSONRequest=M(this._options,this.map._requestManager,(function(r,n){e._tileJSONRequest=null,e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(t.extend(e,n),n.bounds&&(e.tileBounds=new A(n.bounds,e.minzoom,e.maxzoom)),t.postTurnstileEvent(n.tiles),t.postMapLoadEvent(n.tiles,e.map._getMapId(),e.map._requestManager._skuToken),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})),e.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.onRemove=function(){this._tileJSONRequest&&(this._tileJSONRequest.cancel(),this._tileJSONRequest=null)},r.prototype.serialize=function(){return t.extend({},this._options)},r.prototype.hasTile=function(t){return!this.tileBounds||this.tileBounds.contains(t.canonical)},r.prototype.loadTile=function(e,r){var n=this,i=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);e.request=t.getImage(this.map._requestManager.transformRequest(i,t.ResourceType.Tile),(function(i,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(i)e.state=\"errored\",r(i);else if(a){n.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=n.map.painter.context,s=o.gl;e.texture=n.map.painter.getTileTexture(a.width),e.texture?e.texture.update(a,{useMipmap:!0}):(e.texture=new t.Texture(o,a,s.RGBA,{useMipmap:!0}),e.texture.bind(s.LINEAR,s.CLAMP_TO_EDGE,s.LINEAR_MIPMAP_NEAREST),o.extTextureFilterAnisotropic&&s.texParameterf(s.TEXTURE_2D,o.extTextureFilterAnisotropic.TEXTURE_MAX_ANISOTROPY_EXT,o.extTextureFilterAnisotropicMax)),e.state=\"loaded\",t.cacheEntryPossiblyAdded(n.dispatcher),r(null)}}))},r.prototype.abortTile=function(t,e){t.request&&(t.request.cancel(),delete t.request),e()},r.prototype.unloadTile=function(t,e){t.texture&&this.map.painter.saveTileTexture(t.texture),e()},r.prototype.hasTransition=function(){return!1},r}(t.Evented),C=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),this.type=\"raster-dem\",this.maxzoom=22,this._options=t.extend({type:\"raster-dem\"},n),this.encoding=n.encoding||\"mapbox\"}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.serialize=function(){return{type:\"raster-dem\",url:this.url,tileSize:this.tileSize,tiles:this.tiles,bounds:this.bounds,encoding:this.encoding}},r.prototype.loadTile=function(e,r){var n=this.map._requestManager.normalizeTileURL(e.tileID.canonical.url(this.tiles,this.scheme),this.tileSize);function i(t,n){t&&(e.state=\"errored\",r(t)),n&&(e.dem=n,e.needsHillshadePrepare=!0,e.state=\"loaded\",r(null))}e.request=t.getImage(this.map._requestManager.transformRequest(n,t.ResourceType.Tile),function(n,a){if(delete e.request,e.aborted)e.state=\"unloaded\",r(null);else if(n)e.state=\"errored\",r(n);else if(a){this.map._refreshExpiredTiles&&e.setExpiryData(a),delete a.cacheControl,delete a.expires;var o=t.window.ImageBitmap&&a instanceof t.window.ImageBitmap&&t.offscreenCanvasSupported()?a:t.browser.getImageData(a,1),s={uid:e.uid,coord:e.tileID,source:this.id,rawImageData:o,encoding:this.encoding};e.actor&&\"expired\"!==e.state||(e.actor=this.dispatcher.getActor(),e.actor.send(\"loadDEMTile\",s,i.bind(this)))}}.bind(this)),e.neighboringTiles=this._getNeighboringTiles(e.tileID)},r.prototype._getNeighboringTiles=function(e){var r=e.canonical,n=Math.pow(2,r.z),i=(r.x-1+n)%n,a=0===r.x?e.wrap-1:e.wrap,o=(r.x+1+n)%n,s=r.x+1===n?e.wrap+1:e.wrap,l={};return l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y).key]={backfilled:!1},r.y>0&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y-1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y-1).key]={backfilled:!1}),r.y+1<n&&(l[new t.OverscaledTileID(e.overscaledZ,a,r.z,i,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,e.wrap,r.z,r.x,r.y+1).key]={backfilled:!1},l[new t.OverscaledTileID(e.overscaledZ,s,r.z,o,r.y+1).key]={backfilled:!1}),l},r.prototype.unloadTile=function(t){t.demTexture&&this.map.painter.saveTileTexture(t.demTexture),t.fbo&&(t.fbo.destroy(),delete t.fbo),t.dem&&delete t.dem,delete t.neighboringTiles,t.state=\"unloaded\",t.actor&&t.actor.send(\"removeDEMTile\",{uid:t.uid,source:this.id})},r}(E),L=function(e){function r(r,n,i,a){e.call(this),this.id=r,this.type=\"geojson\",this.minzoom=0,this.maxzoom=18,this.tileSize=512,this.isTileClipped=!0,this.reparseOverscaled=!0,this._removed=!1,this._loaded=!1,this.actor=i.getActor(),this.setEventedParent(a),this._data=n.data,this._options=t.extend({},n),this._collectResourceTiming=n.collectResourceTiming,this._resourceTiming=[],void 0!==n.maxzoom&&(this.maxzoom=n.maxzoom),n.type&&(this.type=n.type),n.attribution&&(this.attribution=n.attribution),this.promoteId=n.promoteId;var o=t.EXTENT/this.tileSize;this.workerOptions=t.extend({source:this.id,cluster:n.cluster||!1,geojsonVtOptions:{buffer:(void 0!==n.buffer?n.buffer:128)*o,tolerance:(void 0!==n.tolerance?n.tolerance:.375)*o,extent:t.EXTENT,maxZoom:this.maxzoom,lineMetrics:n.lineMetrics||!1,generateId:n.generateId||!1},superclusterOptions:{maxZoom:void 0!==n.clusterMaxZoom?Math.min(n.clusterMaxZoom,this.maxzoom-1):this.maxzoom-1,extent:t.EXTENT,radius:(n.clusterRadius||50)*o,log:!1,generateId:n.generateId||!1},clusterProperties:n.clusterProperties},n.workerOptions)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(r){if(r)e.fire(new t.ErrorEvent(r));else{var n={dataType:\"source\",sourceDataType:\"metadata\"};e._collectResourceTiming&&e._resourceTiming&&e._resourceTiming.length>0&&(n.resourceTiming=e._resourceTiming,e._resourceTiming=[]),e.fire(new t.Event(\"data\",n))}}))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setData=function(e){var r=this;return this._data=e,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this._updateWorkerData((function(e){if(e)r.fire(new t.ErrorEvent(e));else{var n={dataType:\"source\",sourceDataType:\"content\"};r._collectResourceTiming&&r._resourceTiming&&r._resourceTiming.length>0&&(n.resourceTiming=r._resourceTiming,r._resourceTiming=[]),r.fire(new t.Event(\"data\",n))}})),this},r.prototype.getClusterExpansionZoom=function(t,e){return this.actor.send(\"geojson.getClusterExpansionZoom\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterChildren=function(t,e){return this.actor.send(\"geojson.getClusterChildren\",{clusterId:t,source:this.id},e),this},r.prototype.getClusterLeaves=function(t,e,r,n){return this.actor.send(\"geojson.getClusterLeaves\",{source:this.id,clusterId:t,limit:e,offset:r},n),this},r.prototype._updateWorkerData=function(e){var r=this;this._loaded=!1;var n=t.extend({},this.workerOptions),i=this._data;\"string\"==typeof i?(n.request=this.map._requestManager.transformRequest(t.browser.resolveURL(i),t.ResourceType.Source),n.request.collectResourceTiming=this._collectResourceTiming):n.data=JSON.stringify(i),this.actor.send(this.type+\".loadData\",n,(function(t,i){r._removed||i&&i.abandoned||(r._loaded=!0,i&&i.resourceTiming&&i.resourceTiming[r.id]&&(r._resourceTiming=i.resourceTiming[r.id].slice(0)),r.actor.send(r.type+\".coalesce\",{source:n.source},null),e(t))}))},r.prototype.loaded=function(){return this._loaded},r.prototype.loadTile=function(e,r){var n=this,i=e.actor?\"reloadTile\":\"loadTile\";e.actor=this.actor,e.request=this.actor.send(i,{type:this.type,uid:e.uid,tileID:e.tileID,zoom:e.tileID.overscaledZ,maxZoom:this.maxzoom,tileSize:this.tileSize,source:this.id,pixelRatio:t.browser.devicePixelRatio,showCollisionBoxes:this.map.showCollisionBoxes,promoteId:this.promoteId},(function(t,a){return delete e.request,e.unloadVectorData(),e.aborted?r(null):t?r(t):(e.loadVectorData(a,n.map.painter,\"reloadTile\"===i),r(null))}))},r.prototype.abortTile=function(t){t.request&&(t.request.cancel(),delete t.request),t.aborted=!0},r.prototype.unloadTile=function(t){t.unloadVectorData(),this.actor.send(\"removeTile\",{uid:t.uid,type:this.type,source:this.id})},r.prototype.onRemove=function(){this._removed=!0,this.actor.send(\"removeSource\",{type:this.type,source:this.id})},r.prototype.serialize=function(){return t.extend({},this._options,{type:this.type,data:this._data})},r.prototype.hasTransition=function(){return!1},r}(t.Evented),I=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2},{name:\"a_texture_pos\",type:\"Int16\",components:2}]),P=function(e){function r(t,r,n,i){e.call(this),this.id=t,this.dispatcher=n,this.coordinates=r.coordinates,this.type=\"image\",this.minzoom=0,this.maxzoom=22,this.tileSize=512,this.tiles={},this._loaded=!1,this.setEventedParent(i),this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(e,r){var n=this;this._loaded=!1,this.fire(new t.Event(\"dataloading\",{dataType:\"source\"})),this.url=this.options.url,t.getImage(this.map._requestManager.transformRequest(this.url,t.ResourceType.Image),(function(i,a){n._loaded=!0,i?n.fire(new t.ErrorEvent(i)):a&&(n.image=a,e&&(n.coordinates=e),r&&r(),n._finishLoading())}))},r.prototype.loaded=function(){return this._loaded},r.prototype.updateImage=function(t){var e=this;return this.image&&t.url?(this.options.url=t.url,this.load(t.coordinates,(function(){e.texture=null})),this):this},r.prototype._finishLoading=function(){this.map&&(this.setCoordinates(this.coordinates),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"metadata\"})))},r.prototype.onAdd=function(t){this.map=t,this.load()},r.prototype.setCoordinates=function(e){var r=this;this.coordinates=e;var n=e.map(t.MercatorCoordinate.fromLngLat);this.tileID=function(e){for(var r=1/0,n=1/0,i=-1/0,a=-1/0,o=0,s=e;o<s.length;o+=1){var l=s[o];r=Math.min(r,l.x),n=Math.min(n,l.y),i=Math.max(i,l.x),a=Math.max(a,l.y)}var c=Math.max(i-r,a-n),u=Math.max(0,Math.floor(-Math.log(c)/Math.LN2)),f=Math.pow(2,u);return new t.CanonicalTileID(u,Math.floor((r+i)/2*f),Math.floor((n+a)/2*f))}(n),this.minzoom=this.maxzoom=this.tileID.z;var i=n.map((function(t){return r.tileID.getTilePoint(t)._round()}));return this._boundsArray=new t.StructArrayLayout4i8,this._boundsArray.emplaceBack(i[0].x,i[0].y,0,0),this._boundsArray.emplaceBack(i[1].x,i[1].y,t.EXTENT,0),this._boundsArray.emplaceBack(i[3].x,i[3].y,0,t.EXTENT),this._boundsArray.emplaceBack(i[2].x,i[2].y,t.EXTENT,t.EXTENT),this.boundsBuffer&&(this.boundsBuffer.destroy(),delete this.boundsBuffer),this.fire(new t.Event(\"data\",{dataType:\"source\",sourceDataType:\"content\"})),this},r.prototype.prepare=function(){if(0!==Object.keys(this.tiles).length&&this.image){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture||(this.texture=new t.Texture(e,this.image,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.loadTile=function(t,e){this.tileID&&this.tileID.equals(t.tileID.canonical)?(this.tiles[String(t.tileID.wrap)]=t,t.buckets={},e(null)):(t.state=\"errored\",e(null))},r.prototype.serialize=function(){return{type:\"image\",url:this.options.url,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return!1},r}(t.Evented),z=function(e){function r(t,r,n,i){e.call(this,t,r,n,i),this.roundZoom=!0,this.type=\"video\",this.options=r}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){var e=this;this._loaded=!1;var r=this.options;this.urls=[];for(var n=0,i=r.urls;n<i.length;n+=1)this.urls.push(this.map._requestManager.transformRequest(i[n],t.ResourceType.Source).url);t.getVideo(this.urls,(function(r,n){e._loaded=!0,r?e.fire(new t.ErrorEvent(r)):n&&(e.video=n,e.video.loop=!0,e.video.addEventListener(\"playing\",(function(){e.map.triggerRepaint()})),e.map&&e.video.play(),e._finishLoading())}))},r.prototype.pause=function(){this.video&&this.video.pause()},r.prototype.play=function(){this.video&&this.video.play()},r.prototype.seek=function(e){if(this.video){var r=this.video.seekable;e<r.start(0)||e>r.end(0)?this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+this.id,null,\"Playback for this video can be set only between the \"+r.start(0)+\" and \"+r.end(0)+\"-second mark.\"))):this.video.currentTime=e}},r.prototype.getVideo=function(){return this.video},r.prototype.onAdd=function(t){this.map||(this.map=t,this.load(),this.video&&(this.video.play(),this.setCoordinates(this.coordinates)))},r.prototype.prepare=function(){if(!(0===Object.keys(this.tiles).length||this.video.readyState<2)){var e=this.map.painter.context,r=e.gl;for(var n in this.boundsBuffer||(this.boundsBuffer=e.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?this.video.paused||(this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE),r.texSubImage2D(r.TEXTURE_2D,0,0,0,r.RGBA,r.UNSIGNED_BYTE,this.video)):(this.texture=new t.Texture(e,this.video,r.RGBA),this.texture.bind(r.LINEAR,r.CLAMP_TO_EDGE)),this.tiles){var i=this.tiles[n];\"loaded\"!==i.state&&(i.state=\"loaded\",i.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"video\",urls:this.urls,coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this.video&&!this.video.paused},r}(P),O=function(e){function r(r,n,i,a){e.call(this,r,n,i,a),n.coordinates?Array.isArray(n.coordinates)&&4===n.coordinates.length&&!n.coordinates.some((function(t){return!Array.isArray(t)||2!==t.length||t.some((function(t){return\"number\"!=typeof t}))}))||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"coordinates\" property must be an array of 4 longitude/latitude array pairs'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"coordinates\"'))),n.animate&&\"boolean\"!=typeof n.animate&&this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'optional \"animate\" property must be a boolean value'))),n.canvas?\"string\"==typeof n.canvas||n.canvas instanceof t.window.HTMLCanvasElement||this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'\"canvas\" must be either a string representing the ID of the canvas element from which to read, or an HTMLCanvasElement instance'))):this.fire(new t.ErrorEvent(new t.ValidationError(\"sources.\"+r,null,'missing required property \"canvas\"'))),this.options=n,this.animate=void 0===n.animate||n.animate}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.load=function(){this._loaded=!0,this.canvas||(this.canvas=this.options.canvas instanceof t.window.HTMLCanvasElement?this.options.canvas:t.window.document.getElementById(this.options.canvas)),this.width=this.canvas.width,this.height=this.canvas.height,this._hasInvalidDimensions()?this.fire(new t.ErrorEvent(new Error(\"Canvas dimensions cannot be less than or equal to zero.\"))):(this.play=function(){this._playing=!0,this.map.triggerRepaint()},this.pause=function(){this._playing&&(this.prepare(),this._playing=!1)},this._finishLoading())},r.prototype.getCanvas=function(){return this.canvas},r.prototype.onAdd=function(t){this.map=t,this.load(),this.canvas&&this.animate&&this.play()},r.prototype.onRemove=function(){this.pause()},r.prototype.prepare=function(){var e=!1;if(this.canvas.width!==this.width&&(this.width=this.canvas.width,e=!0),this.canvas.height!==this.height&&(this.height=this.canvas.height,e=!0),!this._hasInvalidDimensions()&&0!==Object.keys(this.tiles).length){var r=this.map.painter.context,n=r.gl;for(var i in this.boundsBuffer||(this.boundsBuffer=r.createVertexBuffer(this._boundsArray,I.members)),this.boundsSegments||(this.boundsSegments=t.SegmentVector.simpleSegment(0,0,4,2)),this.texture?(e||this._playing)&&this.texture.update(this.canvas,{premultiply:!0}):this.texture=new t.Texture(r,this.canvas,n.RGBA,{premultiply:!0}),this.tiles){var a=this.tiles[i];\"loaded\"!==a.state&&(a.state=\"loaded\",a.texture=this.texture)}}},r.prototype.serialize=function(){return{type:\"canvas\",coordinates:this.coordinates}},r.prototype.hasTransition=function(){return this._playing},r.prototype._hasInvalidDimensions=function(){for(var t=0,e=[this.canvas.width,this.canvas.height];t<e.length;t+=1){var r=e[t];if(isNaN(r)||r<=0)return!0}return!1},r}(P),D={vector:S,raster:E,\"raster-dem\":C,geojson:L,video:z,image:P,canvas:O};function R(e,r){var n=t.identity([]);return t.translate(n,n,[1,1,0]),t.scale(n,n,[.5*e.width,.5*e.height,1]),t.multiply(n,n,e.calculatePosMatrix(r.toUnwrapped()))}function F(t,e,r,n,i,a){var o=function(t,e,r){if(t)for(var n=0,i=t;n<i.length;n+=1){var a=e[i[n]];if(a&&a.source===r&&\"fill-extrusion\"===a.type)return!0}else for(var o in e){var s=e[o];if(s.source===r&&\"fill-extrusion\"===s.type)return!0}return!1}(i&&i.layers,e,t.id),s=a.maxPitchScaleFactor(),l=t.tilesIn(n,s,o);l.sort(B);for(var c=[],u=0,f=l;u<f.length;u+=1){var h=f[u];c.push({wrappedTileID:h.tileID.wrapped().key,queryResults:h.tile.queryRenderedFeatures(e,r,t._state,h.queryGeometry,h.cameraQueryGeometry,h.scale,i,a,s,R(t.transform,h.tileID))})}var p=function(t){for(var e={},r={},n=0,i=t;n<i.length;n+=1){var a=i[n],o=a.queryResults,s=a.wrappedTileID,l=r[s]=r[s]||{};for(var c in o)for(var u=o[c],f=l[c]=l[c]||{},h=e[c]=e[c]||[],p=0,d=u;p<d.length;p+=1){var g=d[p];f[g.featureIndex]||(f[g.featureIndex]=!0,h.push(g))}}return e}(c);for(var d in p)p[d].forEach((function(e){var r=e.feature,n=t.getFeatureState(r.layer[\"source-layer\"],r.id);r.source=r.layer.source,r.layer[\"source-layer\"]&&(r.sourceLayer=r.layer[\"source-layer\"]),r.state=n}));return p}function B(t,e){var r=t.tileID,n=e.tileID;return r.overscaledZ-n.overscaledZ||r.canonical.y-n.canonical.y||r.wrap-n.wrap||r.canonical.x-n.canonical.x}var N=function(t,e){this.max=t,this.onRemove=e,this.reset()};N.prototype.reset=function(){for(var t in this.data)for(var e=0,r=this.data[t];e<r.length;e+=1){var n=r[e];n.timeout&&clearTimeout(n.timeout),this.onRemove(n.value)}return this.data={},this.order=[],this},N.prototype.add=function(t,e,r){var n=this,i=t.wrapped().key;void 0===this.data[i]&&(this.data[i]=[]);var a={value:e,timeout:void 0};if(void 0!==r&&(a.timeout=setTimeout((function(){n.remove(t,a)}),r)),this.data[i].push(a),this.order.push(i),this.order.length>this.max){var o=this._getAndRemoveByKey(this.order[0]);o&&this.onRemove(o)}return this},N.prototype.has=function(t){return t.wrapped().key in this.data},N.prototype.getAndRemove=function(t){return this.has(t)?this._getAndRemoveByKey(t.wrapped().key):null},N.prototype._getAndRemoveByKey=function(t){var e=this.data[t].shift();return e.timeout&&clearTimeout(e.timeout),0===this.data[t].length&&delete this.data[t],this.order.splice(this.order.indexOf(t),1),e.value},N.prototype.getByKey=function(t){var e=this.data[t];return e?e[0].value:null},N.prototype.get=function(t){return this.has(t)?this.data[t.wrapped().key][0].value:null},N.prototype.remove=function(t,e){if(!this.has(t))return this;var r=t.wrapped().key,n=void 0===e?0:this.data[r].indexOf(e),i=this.data[r][n];return this.data[r].splice(n,1),i.timeout&&clearTimeout(i.timeout),0===this.data[r].length&&delete this.data[r],this.onRemove(i.value),this.order.splice(this.order.indexOf(r),1),this},N.prototype.setMaxSize=function(t){for(this.max=t;this.order.length>this.max;){var e=this._getAndRemoveByKey(this.order[0]);e&&this.onRemove(e)}return this},N.prototype.filter=function(t){var e=[];for(var r in this.data)for(var n=0,i=this.data[r];n<i.length;n+=1){var a=i[n];t(a.value)||e.push(a)}for(var o=0,s=e;o<s.length;o+=1){var l=s[o];this.remove(l.value.tileID,l)}};var j=function(t,e,r){this.context=t;var n=t.gl;this.buffer=n.createBuffer(),this.dynamicDraw=Boolean(r),this.context.unbindVAO(),t.bindElementBuffer.set(this.buffer),n.bufferData(n.ELEMENT_ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?n.DYNAMIC_DRAW:n.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};j.prototype.bind=function(){this.context.bindElementBuffer.set(this.buffer)},j.prototype.updateData=function(t){var e=this.context.gl;this.context.unbindVAO(),this.bind(),e.bufferSubData(e.ELEMENT_ARRAY_BUFFER,0,t.arrayBuffer)},j.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var U={Int8:\"BYTE\",Uint8:\"UNSIGNED_BYTE\",Int16:\"SHORT\",Uint16:\"UNSIGNED_SHORT\",Int32:\"INT\",Uint32:\"UNSIGNED_INT\",Float32:\"FLOAT\"},V=function(t,e,r,n){this.length=e.length,this.attributes=r,this.itemSize=e.bytesPerElement,this.dynamicDraw=n,this.context=t;var i=t.gl;this.buffer=i.createBuffer(),t.bindVertexBuffer.set(this.buffer),i.bufferData(i.ARRAY_BUFFER,e.arrayBuffer,this.dynamicDraw?i.DYNAMIC_DRAW:i.STATIC_DRAW),this.dynamicDraw||delete e.arrayBuffer};V.prototype.bind=function(){this.context.bindVertexBuffer.set(this.buffer)},V.prototype.updateData=function(t){var e=this.context.gl;this.bind(),e.bufferSubData(e.ARRAY_BUFFER,0,t.arrayBuffer)},V.prototype.enableAttributes=function(t,e){for(var r=0;r<this.attributes.length;r++){var n=e.attributes[this.attributes[r].name];void 0!==n&&t.enableVertexAttribArray(n)}},V.prototype.setVertexAttribPointers=function(t,e,r){for(var n=0;n<this.attributes.length;n++){var i=this.attributes[n],a=e.attributes[i.name];void 0!==a&&t.vertexAttribPointer(a,i.components,t[U[i.type]],!1,this.itemSize,i.offset+this.itemSize*(r||0))}},V.prototype.destroy=function(){this.buffer&&(this.context.gl.deleteBuffer(this.buffer),delete this.buffer)};var q=function(t){this.gl=t.gl,this.default=this.getDefault(),this.current=this.default,this.dirty=!1};q.prototype.get=function(){return this.current},q.prototype.set=function(t){},q.prototype.getDefault=function(){return this.default},q.prototype.setDefault=function(){this.set(this.default)};var H=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.clearColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),G=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 1},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearDepth(t),this.current=t,this.dirty=!1)},e}(q),Y=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.clearStencil(t),this.current=t,this.dirty=!1)},e}(q),W=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[!0,!0,!0,!0]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.colorMask(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),X=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthMask(t),this.current=t,this.dirty=!1)},e}(q),Z=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 255},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.stencilMask(t),this.current=t,this.dirty=!1)},e}(q),J=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return{func:this.gl.ALWAYS,ref:0,mask:255}},e.prototype.set=function(t){var e=this.current;(t.func!==e.func||t.ref!==e.ref||t.mask!==e.mask||this.dirty)&&(this.gl.stencilFunc(t.func,t.ref,t.mask),this.current=t,this.dirty=!1)},e}(q),K=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.KEEP,t.KEEP,t.KEEP]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||this.dirty)&&(this.gl.stencilOp(t[0],t[1],t[2]),this.current=t,this.dirty=!1)},e}(q),Q=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.STENCIL_TEST):e.disable(e.STENCIL_TEST),this.current=t,this.dirty=!1}},e}(q),$=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return[0,1]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.depthRange(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.DEPTH_TEST):e.disable(e.DEPTH_TEST),this.current=t,this.dirty=!1}},e}(q),et=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.LESS},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.depthFunc(t),this.current=t,this.dirty=!1)},e}(q),rt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.BLEND):e.disable(e.BLEND),this.current=t,this.dirty=!1}},e}(q),nt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[t.ONE,t.ZERO]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||this.dirty)&&(this.gl.blendFunc(t[0],t[1]),this.current=t,this.dirty=!1)},e}(q),it=function(e){function r(){e.apply(this,arguments)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getDefault=function(){return t.Color.transparent},r.prototype.set=function(t){var e=this.current;(t.r!==e.r||t.g!==e.g||t.b!==e.b||t.a!==e.a||this.dirty)&&(this.gl.blendColor(t.r,t.g,t.b,t.a),this.current=t,this.dirty=!1)},r}(q),at=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.FUNC_ADD},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.blendEquation(t),this.current=t,this.dirty=!1)},e}(q),ot=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;t?e.enable(e.CULL_FACE):e.disable(e.CULL_FACE),this.current=t,this.dirty=!1}},e}(q),st=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.BACK},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.cullFace(t),this.current=t,this.dirty=!1)},e}(q),lt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.CCW},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.frontFace(t),this.current=t,this.dirty=!1)},e}(q),ct=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.useProgram(t),this.current=t,this.dirty=!1)},e}(q),ut=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return this.gl.TEXTURE0},e.prototype.set=function(t){(t!==this.current||this.dirty)&&(this.gl.activeTexture(t),this.current=t,this.dirty=!1)},e}(q),ft=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){var t=this.gl;return[0,0,t.drawingBufferWidth,t.drawingBufferHeight]},e.prototype.set=function(t){var e=this.current;(t[0]!==e[0]||t[1]!==e[1]||t[2]!==e[2]||t[3]!==e[3]||this.dirty)&&(this.gl.viewport(t[0],t[1],t[2],t[3]),this.current=t,this.dirty=!1)},e}(q),ht=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindFramebuffer(e.FRAMEBUFFER,t),this.current=t,this.dirty=!1}},e}(q),pt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindRenderbuffer(e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(q),dt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindTexture(e.TEXTURE_2D,t),this.current=t,this.dirty=!1}},e}(q),gt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.bindBuffer(e.ARRAY_BUFFER,t),this.current=t,this.dirty=!1}},e}(q),mt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){var e=this.gl;e.bindBuffer(e.ELEMENT_ARRAY_BUFFER,t),this.current=t,this.dirty=!1},e}(q),vt=function(t){function e(e){t.call(this,e),this.vao=e.extVertexArrayObject}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e.prototype.set=function(t){this.vao&&(t!==this.current||this.dirty)&&(this.vao.bindVertexArrayOES(t),this.current=t,this.dirty=!1)},e}(q),yt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return 4},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_ALIGNMENT,t),this.current=t,this.dirty=!1}},e}(q),xt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_PREMULTIPLY_ALPHA_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),bt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return!1},e.prototype.set=function(t){if(t!==this.current||this.dirty){var e=this.gl;e.pixelStorei(e.UNPACK_FLIP_Y_WEBGL,t),this.current=t,this.dirty=!1}},e}(q),_t=function(t){function e(e,r){t.call(this,e),this.context=e,this.parent=r}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.getDefault=function(){return null},e}(q),wt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.setDirty=function(){this.dirty=!0},e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferTexture2D(e.FRAMEBUFFER,e.COLOR_ATTACHMENT0,e.TEXTURE_2D,t,0),this.current=t,this.dirty=!1}},e}(_t),Tt=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.set=function(t){if(t!==this.current||this.dirty){this.context.bindFramebuffer.set(this.parent);var e=this.gl;e.framebufferRenderbuffer(e.FRAMEBUFFER,e.DEPTH_ATTACHMENT,e.RENDERBUFFER,t),this.current=t,this.dirty=!1}},e}(_t),kt=function(t,e,r,n){this.context=t,this.width=e,this.height=r;var i=this.framebuffer=t.gl.createFramebuffer();this.colorAttachment=new wt(t,i),n&&(this.depthAttachment=new Tt(t,i))};kt.prototype.destroy=function(){var t=this.context.gl,e=this.colorAttachment.get();if(e&&t.deleteTexture(e),this.depthAttachment){var r=this.depthAttachment.get();r&&t.deleteRenderbuffer(r)}t.deleteFramebuffer(this.framebuffer)};var Mt=function(t,e,r){this.func=t,this.mask=e,this.range=r};Mt.ReadOnly=!1,Mt.ReadWrite=!0,Mt.disabled=new Mt(519,Mt.ReadOnly,[0,1]);var At=function(t,e,r,n,i,a){this.test=t,this.ref=e,this.mask=r,this.fail=n,this.depthFail=i,this.pass=a};At.disabled=new At({func:519,mask:0},0,0,7680,7680,7680);var St=function(t,e,r){this.blendFunction=t,this.blendColor=e,this.mask=r};St.disabled=new St(St.Replace=[1,0],t.Color.transparent,[!1,!1,!1,!1]),St.unblended=new St(St.Replace,t.Color.transparent,[!0,!0,!0,!0]),St.alphaBlended=new St([1,771],t.Color.transparent,[!0,!0,!0,!0]);var Et=function(t,e,r){this.enable=t,this.mode=e,this.frontFace=r};Et.disabled=new Et(!1,1029,2305),Et.backCCW=new Et(!0,1029,2305);var Ct=function(t){this.gl=t,this.extVertexArrayObject=this.gl.getExtension(\"OES_vertex_array_object\"),this.clearColor=new H(this),this.clearDepth=new G(this),this.clearStencil=new Y(this),this.colorMask=new W(this),this.depthMask=new X(this),this.stencilMask=new Z(this),this.stencilFunc=new J(this),this.stencilOp=new K(this),this.stencilTest=new Q(this),this.depthRange=new $(this),this.depthTest=new tt(this),this.depthFunc=new et(this),this.blend=new rt(this),this.blendFunc=new nt(this),this.blendColor=new it(this),this.blendEquation=new at(this),this.cullFace=new ot(this),this.cullFaceSide=new st(this),this.frontFace=new lt(this),this.program=new ct(this),this.activeTexture=new ut(this),this.viewport=new ft(this),this.bindFramebuffer=new ht(this),this.bindRenderbuffer=new pt(this),this.bindTexture=new dt(this),this.bindVertexBuffer=new gt(this),this.bindElementBuffer=new mt(this),this.bindVertexArrayOES=this.extVertexArrayObject&&new vt(this),this.pixelStoreUnpack=new yt(this),this.pixelStoreUnpackPremultiplyAlpha=new xt(this),this.pixelStoreUnpackFlipY=new bt(this),this.extTextureFilterAnisotropic=t.getExtension(\"EXT_texture_filter_anisotropic\")||t.getExtension(\"MOZ_EXT_texture_filter_anisotropic\")||t.getExtension(\"WEBKIT_EXT_texture_filter_anisotropic\"),this.extTextureFilterAnisotropic&&(this.extTextureFilterAnisotropicMax=t.getParameter(this.extTextureFilterAnisotropic.MAX_TEXTURE_MAX_ANISOTROPY_EXT)),this.extTextureHalfFloat=t.getExtension(\"OES_texture_half_float\"),this.extTextureHalfFloat&&(t.getExtension(\"OES_texture_half_float_linear\"),this.extRenderToTextureHalfFloat=t.getExtension(\"EXT_color_buffer_half_float\")),this.extTimerQuery=t.getExtension(\"EXT_disjoint_timer_query\")};Ct.prototype.setDefault=function(){this.unbindVAO(),this.clearColor.setDefault(),this.clearDepth.setDefault(),this.clearStencil.setDefault(),this.colorMask.setDefault(),this.depthMask.setDefault(),this.stencilMask.setDefault(),this.stencilFunc.setDefault(),this.stencilOp.setDefault(),this.stencilTest.setDefault(),this.depthRange.setDefault(),this.depthTest.setDefault(),this.depthFunc.setDefault(),this.blend.setDefault(),this.blendFunc.setDefault(),this.blendColor.setDefault(),this.blendEquation.setDefault(),this.cullFace.setDefault(),this.cullFaceSide.setDefault(),this.frontFace.setDefault(),this.program.setDefault(),this.activeTexture.setDefault(),this.bindFramebuffer.setDefault(),this.pixelStoreUnpack.setDefault(),this.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.pixelStoreUnpackFlipY.setDefault()},Ct.prototype.setDirty=function(){this.clearColor.dirty=!0,this.clearDepth.dirty=!0,this.clearStencil.dirty=!0,this.colorMask.dirty=!0,this.depthMask.dirty=!0,this.stencilMask.dirty=!0,this.stencilFunc.dirty=!0,this.stencilOp.dirty=!0,this.stencilTest.dirty=!0,this.depthRange.dirty=!0,this.depthTest.dirty=!0,this.depthFunc.dirty=!0,this.blend.dirty=!0,this.blendFunc.dirty=!0,this.blendColor.dirty=!0,this.blendEquation.dirty=!0,this.cullFace.dirty=!0,this.cullFaceSide.dirty=!0,this.frontFace.dirty=!0,this.program.dirty=!0,this.activeTexture.dirty=!0,this.viewport.dirty=!0,this.bindFramebuffer.dirty=!0,this.bindRenderbuffer.dirty=!0,this.bindTexture.dirty=!0,this.bindVertexBuffer.dirty=!0,this.bindElementBuffer.dirty=!0,this.extVertexArrayObject&&(this.bindVertexArrayOES.dirty=!0),this.pixelStoreUnpack.dirty=!0,this.pixelStoreUnpackPremultiplyAlpha.dirty=!0,this.pixelStoreUnpackFlipY.dirty=!0},Ct.prototype.createIndexBuffer=function(t,e){return new j(this,t,e)},Ct.prototype.createVertexBuffer=function(t,e,r){return new V(this,t,e,r)},Ct.prototype.createRenderbuffer=function(t,e,r){var n=this.gl,i=n.createRenderbuffer();return this.bindRenderbuffer.set(i),n.renderbufferStorage(n.RENDERBUFFER,t,e,r),this.bindRenderbuffer.set(null),i},Ct.prototype.createFramebuffer=function(t,e,r){return new kt(this,t,e,r)},Ct.prototype.clear=function(t){var e=t.color,r=t.depth,n=this.gl,i=0;e&&(i|=n.COLOR_BUFFER_BIT,this.clearColor.set(e),this.colorMask.set([!0,!0,!0,!0])),void 0!==r&&(i|=n.DEPTH_BUFFER_BIT,this.depthRange.set([0,1]),this.clearDepth.set(r),this.depthMask.set(!0)),n.clear(i)},Ct.prototype.setCullFace=function(t){!1===t.enable?this.cullFace.set(!1):(this.cullFace.set(!0),this.cullFaceSide.set(t.mode),this.frontFace.set(t.frontFace))},Ct.prototype.setDepthMode=function(t){t.func!==this.gl.ALWAYS||t.mask?(this.depthTest.set(!0),this.depthFunc.set(t.func),this.depthMask.set(t.mask),this.depthRange.set(t.range)):this.depthTest.set(!1)},Ct.prototype.setStencilMode=function(t){t.test.func!==this.gl.ALWAYS||t.mask?(this.stencilTest.set(!0),this.stencilMask.set(t.mask),this.stencilOp.set([t.fail,t.depthFail,t.pass]),this.stencilFunc.set({func:t.test.func,ref:t.ref,mask:t.test.mask})):this.stencilTest.set(!1)},Ct.prototype.setColorMode=function(e){t.deepEqual(e.blendFunction,St.Replace)?this.blend.set(!1):(this.blend.set(!0),this.blendFunc.set(e.blendFunction),this.blendColor.set(e.blendColor)),this.colorMask.set(e.mask)},Ct.prototype.unbindVAO=function(){this.extVertexArrayObject&&this.bindVertexArrayOES.set(null)};var Lt=function(e){function r(r,n,i){var a=this;e.call(this),this.id=r,this.dispatcher=i,this.on(\"data\",(function(t){\"source\"===t.dataType&&\"metadata\"===t.sourceDataType&&(a._sourceLoaded=!0),a._sourceLoaded&&!a._paused&&\"source\"===t.dataType&&\"content\"===t.sourceDataType&&(a.reload(),a.transform&&a.update(a.transform))})),this.on(\"error\",(function(){a._sourceErrored=!0})),this._source=function(e,r,n,i){var a=new D[r.type](e,r,n,i);if(a.id!==e)throw new Error(\"Expected Source id to be \"+e+\" instead of \"+a.id);return t.bindAll([\"load\",\"abort\",\"unload\",\"serialize\",\"prepare\"],a),a}(r,n,i,this),this._tiles={},this._cache=new N(0,this._unloadTile.bind(this)),this._timers={},this._cacheTimers={},this._maxTileCacheSize=null,this._loadedParentTiles={},this._coveredTiles={},this._state=new t.SourceFeatureState}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.onAdd=function(t){this.map=t,this._maxTileCacheSize=t?t._maxTileCacheSize:null,this._source&&this._source.onAdd&&this._source.onAdd(t)},r.prototype.onRemove=function(t){this._source&&this._source.onRemove&&this._source.onRemove(t)},r.prototype.loaded=function(){if(this._sourceErrored)return!0;if(!this._sourceLoaded)return!1;if(!this._source.loaded())return!1;for(var t in this._tiles){var e=this._tiles[t];if(\"loaded\"!==e.state&&\"errored\"!==e.state)return!1}return!0},r.prototype.getSource=function(){return this._source},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){if(this._paused){var t=this._shouldReloadOnResume;this._paused=!1,this._shouldReloadOnResume=!1,t&&this.reload(),this.transform&&this.update(this.transform)}},r.prototype._loadTile=function(t,e){return this._source.loadTile(t,e)},r.prototype._unloadTile=function(t){if(this._source.unloadTile)return this._source.unloadTile(t,(function(){}))},r.prototype._abortTile=function(t){if(this._source.abortTile)return this._source.abortTile(t,(function(){}))},r.prototype.serialize=function(){return this._source.serialize()},r.prototype.prepare=function(t){for(var e in this._source.prepare&&this._source.prepare(),this._state.coalesceChanges(this._tiles,this.map?this.map.painter:null),this._tiles){var r=this._tiles[e];r.upload(t),r.prepare(this.map.style.imageManager)}},r.prototype.getIds=function(){return t.values(this._tiles).map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.getRenderableIds=function(e){var r=this,n=[];for(var i in this._tiles)this._isIdRenderable(i,e)&&n.push(this._tiles[i]);return e?n.sort((function(e,n){var i=e.tileID,a=n.tileID,o=new t.Point(i.canonical.x,i.canonical.y)._rotate(r.transform.angle),s=new t.Point(a.canonical.x,a.canonical.y)._rotate(r.transform.angle);return i.overscaledZ-a.overscaledZ||s.y-o.y||s.x-o.x})).map((function(t){return t.tileID.key})):n.map((function(t){return t.tileID})).sort(It).map((function(t){return t.key}))},r.prototype.hasRenderableParent=function(t){var e=this.findLoadedParent(t,0);return!!e&&this._isIdRenderable(e.tileID.key)},r.prototype._isIdRenderable=function(t,e){return this._tiles[t]&&this._tiles[t].hasData()&&!this._coveredTiles[t]&&(e||!this._tiles[t].holdingForFade())},r.prototype.reload=function(){if(this._paused)this._shouldReloadOnResume=!0;else for(var t in this._cache.reset(),this._tiles)\"errored\"!==this._tiles[t].state&&this._reloadTile(t,\"reloading\")},r.prototype._reloadTile=function(t,e){var r=this._tiles[t];r&&(\"loading\"!==r.state&&(r.state=e),this._loadTile(r,this._tileLoaded.bind(this,r,t,e)))},r.prototype._tileLoaded=function(e,r,n,i){if(i)return e.state=\"errored\",void(404!==i.status?this._source.fire(new t.ErrorEvent(i,{tile:e})):this.update(this.transform));e.timeAdded=t.browser.now(),\"expired\"===n&&(e.refreshedUponExpiration=!0),this._setTileReloadTimer(r,e),\"raster-dem\"===this.getSource().type&&e.dem&&this._backfillDEM(e),this._state.initializeTileState(e,this.map?this.map.painter:null),this._source.fire(new t.Event(\"data\",{dataType:\"source\",tile:e,coord:e.tileID}))},r.prototype._backfillDEM=function(t){for(var e=this.getRenderableIds(),r=0;r<e.length;r++){var n=e[r];if(t.neighboringTiles&&t.neighboringTiles[n]){var i=this.getTileByID(n);a(t,i),a(i,t)}}function a(t,e){t.needsHillshadePrepare=!0;var r=e.tileID.canonical.x-t.tileID.canonical.x,n=e.tileID.canonical.y-t.tileID.canonical.y,i=Math.pow(2,t.tileID.canonical.z),a=e.tileID.key;0===r&&0===n||Math.abs(n)>1||(Math.abs(r)>1&&(1===Math.abs(r+i)?r+=i:1===Math.abs(r-i)&&(r-=i)),e.dem&&t.dem&&(t.dem.backfillBorder(e.dem,r,n),t.neighboringTiles&&t.neighboringTiles[a]&&(t.neighboringTiles[a].backfilled=!0)))}},r.prototype.getTile=function(t){return this.getTileByID(t.key)},r.prototype.getTileByID=function(t){return this._tiles[t]},r.prototype._retainLoadedChildren=function(t,e,r,n){for(var i in this._tiles){var a=this._tiles[i];if(!(n[i]||!a.hasData()||a.tileID.overscaledZ<=e||a.tileID.overscaledZ>r)){for(var o=a.tileID;a&&a.tileID.overscaledZ>e+1;){var s=a.tileID.scaledTo(a.tileID.overscaledZ-1);(a=this._tiles[s.key])&&a.hasData()&&(o=s)}for(var l=o;l.overscaledZ>e;)if(t[(l=l.scaledTo(l.overscaledZ-1)).key]){n[o.key]=o;break}}}},r.prototype.findLoadedParent=function(t,e){if(t.key in this._loadedParentTiles){var r=this._loadedParentTiles[t.key];return r&&r.tileID.overscaledZ>=e?r:null}for(var n=t.overscaledZ-1;n>=e;n--){var i=t.scaledTo(n),a=this._getLoadedTile(i);if(a)return a}},r.prototype._getLoadedTile=function(t){var e=this._tiles[t.key];return e&&e.hasData()?e:this._cache.getByKey(t.wrapped().key)},r.prototype.updateCacheSize=function(t){var e=Math.ceil(t.width/this._source.tileSize)+1,r=Math.ceil(t.height/this._source.tileSize)+1,n=Math.floor(e*r*5),i=\"number\"==typeof this._maxTileCacheSize?Math.min(this._maxTileCacheSize,n):n;this._cache.setMaxSize(i)},r.prototype.handleWrapJump=function(t){var e=Math.round((t-(void 0===this._prevLng?t:this._prevLng))/360);if(this._prevLng=t,e){var r={};for(var n in this._tiles){var i=this._tiles[n];i.tileID=i.tileID.unwrapTo(i.tileID.wrap+e),r[i.tileID.key]=i}for(var a in this._tiles=r,this._timers)clearTimeout(this._timers[a]),delete this._timers[a];for(var o in this._tiles)this._setTileReloadTimer(o,this._tiles[o])}},r.prototype.update=function(e){var n=this;if(this.transform=e,this._sourceLoaded&&!this._paused){var i;this.updateCacheSize(e),this.handleWrapJump(this.transform.center.lng),this._coveredTiles={},this.used?this._source.tileID?i=e.getVisibleUnwrappedCoordinates(this._source.tileID).map((function(e){return new t.OverscaledTileID(e.canonical.z,e.wrap,e.canonical.z,e.canonical.x,e.canonical.y)})):(i=e.coveringTiles({tileSize:this._source.tileSize,minzoom:this._source.minzoom,maxzoom:this._source.maxzoom,roundZoom:this._source.roundZoom,reparseOverscaled:this._source.reparseOverscaled}),this._source.hasTile&&(i=i.filter((function(t){return n._source.hasTile(t)})))):i=[];var a=e.coveringZoomLevel(this._source),o=Math.max(a-r.maxOverzooming,this._source.minzoom),s=Math.max(a+r.maxUnderzooming,this._source.minzoom),l=this._updateRetainedTiles(i,a);if(Pt(this._source.type)){for(var c={},u={},f=0,h=Object.keys(l);f<h.length;f+=1){var p=h[f],d=l[p],g=this._tiles[p];if(g&&!(g.fadeEndTime&&g.fadeEndTime<=t.browser.now())){var m=this.findLoadedParent(d,o);m&&(this._addTile(m.tileID),c[m.tileID.key]=m.tileID),u[p]=d}}for(var v in this._retainLoadedChildren(u,a,s,l),c)l[v]||(this._coveredTiles[v]=!0,l[v]=c[v])}for(var y in l)this._tiles[y].clearFadeHold();for(var x=0,b=t.keysDifference(this._tiles,l);x<b.length;x+=1){var _=b[x],w=this._tiles[_];w.hasSymbolBuckets&&!w.holdingForFade()?w.setHoldDuration(this.map._fadeDuration):w.hasSymbolBuckets&&!w.symbolFadeFinished()||this._removeTile(_)}this._updateLoadedParentTileCache()}},r.prototype.releaseSymbolFadeTiles=function(){for(var t in this._tiles)this._tiles[t].holdingForFade()&&this._removeTile(t)},r.prototype._updateRetainedTiles=function(t,e){for(var n={},i={},a=Math.max(e-r.maxOverzooming,this._source.minzoom),o=Math.max(e+r.maxUnderzooming,this._source.minzoom),s={},l=0,c=t;l<c.length;l+=1){var u=c[l],f=this._addTile(u);n[u.key]=u,f.hasData()||e<this._source.maxzoom&&(s[u.key]=u)}this._retainLoadedChildren(s,e,o,n);for(var h=0,p=t;h<p.length;h+=1){var d=p[h],g=this._tiles[d.key];if(!g.hasData()){if(e+1>this._source.maxzoom){var m=d.children(this._source.maxzoom)[0],v=this.getTile(m);if(v&&v.hasData()){n[m.key]=m;continue}}else{var y=d.children(this._source.maxzoom);if(n[y[0].key]&&n[y[1].key]&&n[y[2].key]&&n[y[3].key])continue}for(var x=g.wasRequested(),b=d.overscaledZ-1;b>=a;--b){var _=d.scaledTo(b);if(i[_.key])break;if(i[_.key]=!0,!(g=this.getTile(_))&&x&&(g=this._addTile(_)),g&&(n[_.key]=_,x=g.wasRequested(),g.hasData()))break}}}return n},r.prototype._updateLoadedParentTileCache=function(){for(var t in this._loadedParentTiles={},this._tiles){for(var e=[],r=void 0,n=this._tiles[t].tileID;n.overscaledZ>0;){if(n.key in this._loadedParentTiles){r=this._loadedParentTiles[n.key];break}e.push(n.key);var i=n.scaledTo(n.overscaledZ-1);if(r=this._getLoadedTile(i))break;n=i}for(var a=0,o=e;a<o.length;a+=1)this._loadedParentTiles[o[a]]=r}},r.prototype._addTile=function(e){var r=this._tiles[e.key];if(r)return r;(r=this._cache.getAndRemove(e))&&(this._setTileReloadTimer(e.key,r),r.tileID=e,this._state.initializeTileState(r,this.map?this.map.painter:null),this._cacheTimers[e.key]&&(clearTimeout(this._cacheTimers[e.key]),delete this._cacheTimers[e.key],this._setTileReloadTimer(e.key,r)));var n=Boolean(r);return n||(r=new t.Tile(e,this._source.tileSize*e.overscaleFactor()),this._loadTile(r,this._tileLoaded.bind(this,r,e.key,r.state))),r?(r.uses++,this._tiles[e.key]=r,n||this._source.fire(new t.Event(\"dataloading\",{tile:r,coord:r.tileID,dataType:\"source\"})),r):null},r.prototype._setTileReloadTimer=function(t,e){var r=this;t in this._timers&&(clearTimeout(this._timers[t]),delete this._timers[t]);var n=e.getExpiryTimeout();n&&(this._timers[t]=setTimeout((function(){r._reloadTile(t,\"expired\"),delete r._timers[t]}),n))},r.prototype._removeTile=function(t){var e=this._tiles[t];e&&(e.uses--,delete this._tiles[t],this._timers[t]&&(clearTimeout(this._timers[t]),delete this._timers[t]),e.uses>0||(e.hasData()&&\"reloading\"!==e.state?this._cache.add(e.tileID,e,e.getExpiryTimeout()):(e.aborted=!0,this._abortTile(e),this._unloadTile(e))))},r.prototype.clearTiles=function(){for(var t in this._shouldReloadOnResume=!1,this._paused=!1,this._tiles)this._removeTile(t);this._cache.reset()},r.prototype.tilesIn=function(e,r,n){var i=this,a=[],o=this.transform;if(!o)return a;for(var s=n?o.getCameraQueryGeometry(e):e,l=e.map((function(t){return o.pointCoordinate(t)})),c=s.map((function(t){return o.pointCoordinate(t)})),u=this.getIds(),f=1/0,h=1/0,p=-1/0,d=-1/0,g=0,m=c;g<m.length;g+=1){var v=m[g];f=Math.min(f,v.x),h=Math.min(h,v.y),p=Math.max(p,v.x),d=Math.max(d,v.y)}for(var y=function(e){var n=i._tiles[u[e]];if(!n.holdingForFade()){var s=n.tileID,g=Math.pow(2,o.zoom-n.tileID.overscaledZ),m=r*n.queryPadding*t.EXTENT/n.tileSize/g,v=[s.getTilePoint(new t.MercatorCoordinate(f,h)),s.getTilePoint(new t.MercatorCoordinate(p,d))];if(v[0].x-m<t.EXTENT&&v[0].y-m<t.EXTENT&&v[1].x+m>=0&&v[1].y+m>=0){var y=l.map((function(t){return s.getTilePoint(t)})),x=c.map((function(t){return s.getTilePoint(t)}));a.push({tile:n,tileID:s,queryGeometry:y,cameraQueryGeometry:x,scale:g})}}},x=0;x<u.length;x++)y(x);return a},r.prototype.getVisibleCoordinates=function(t){for(var e=this,r=this.getRenderableIds(t).map((function(t){return e._tiles[t].tileID})),n=0,i=r;n<i.length;n+=1){var a=i[n];a.posMatrix=this.transform.calculatePosMatrix(a.toUnwrapped())}return r},r.prototype.hasTransition=function(){if(this._source.hasTransition())return!0;if(Pt(this._source.type))for(var e in this._tiles){var r=this._tiles[e];if(void 0!==r.fadeEndTime&&r.fadeEndTime>=t.browser.now())return!0}return!1},r.prototype.setFeatureState=function(t,e,r){this._state.updateState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.removeFeatureState=function(t,e,r){this._state.removeFeatureState(t=t||\"_geojsonTileLayer\",e,r)},r.prototype.getFeatureState=function(t,e){return this._state.getState(t=t||\"_geojsonTileLayer\",e)},r.prototype.setDependencies=function(t,e,r){var n=this._tiles[t];n&&n.setDependencies(e,r)},r.prototype.reloadTilesForDependencies=function(t,e){for(var r in this._tiles)this._tiles[r].hasDependency(t,e)&&this._reloadTile(r,\"reloading\");this._cache.filter((function(r){return!r.hasDependency(t,e)}))},r}(t.Evented);function It(t,e){var r=Math.abs(2*t.wrap)-+(t.wrap<0),n=Math.abs(2*e.wrap)-+(e.wrap<0);return t.overscaledZ-e.overscaledZ||n-r||e.canonical.y-t.canonical.y||e.canonical.x-t.canonical.x}function Pt(t){return\"raster\"===t||\"image\"===t||\"video\"===t}function zt(){return new t.window.Worker(Yi.workerUrl)}Lt.maxOverzooming=10,Lt.maxUnderzooming=3;var Ot=\"mapboxgl_preloaded_worker_pool\",Dt=function(){this.active={}};Dt.prototype.acquire=function(t){if(!this.workers)for(this.workers=[];this.workers.length<Dt.workerCount;)this.workers.push(new zt);return this.active[t]=!0,this.workers.slice()},Dt.prototype.release=function(t){delete this.active[t],0===this.numActive()&&(this.workers.forEach((function(t){t.terminate()})),this.workers=null)},Dt.prototype.isPreloaded=function(){return!!this.active[Ot]},Dt.prototype.numActive=function(){return Object.keys(this.active).length};var Rt,Ft=Math.floor(t.browser.hardwareConcurrency/2);function Bt(){return Rt||(Rt=new Dt),Rt}function Nt(e,r){var n={};for(var i in e)\"ref\"!==i&&(n[i]=e[i]);return t.refProperties.forEach((function(t){t in r&&(n[t]=r[t])})),n}function jt(t){t=t.slice();for(var e=Object.create(null),r=0;r<t.length;r++)e[t[r].id]=t[r];for(var n=0;n<t.length;n++)\"ref\"in t[n]&&(t[n]=Nt(t[n],e[t[n].ref]));return t}Dt.workerCount=Math.max(Math.min(Ft,6),1);var Ut={setStyle:\"setStyle\",addLayer:\"addLayer\",removeLayer:\"removeLayer\",setPaintProperty:\"setPaintProperty\",setLayoutProperty:\"setLayoutProperty\",setFilter:\"setFilter\",addSource:\"addSource\",removeSource:\"removeSource\",setGeoJSONSourceData:\"setGeoJSONSourceData\",setLayerZoomRange:\"setLayerZoomRange\",setLayerProperty:\"setLayerProperty\",setCenter:\"setCenter\",setZoom:\"setZoom\",setBearing:\"setBearing\",setPitch:\"setPitch\",setSprite:\"setSprite\",setGlyphs:\"setGlyphs\",setTransition:\"setTransition\",setLight:\"setLight\"};function Vt(t,e,r){r.push({command:Ut.addSource,args:[t,e[t]]})}function qt(t,e,r){e.push({command:Ut.removeSource,args:[t]}),r[t]=!0}function Ht(t,e,r,n){qt(t,r,n),Vt(t,e,r)}function Gt(e,r,n){var i;for(i in e[n])if(e[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;for(i in r[n])if(r[n].hasOwnProperty(i)&&\"data\"!==i&&!t.deepEqual(e[n][i],r[n][i]))return!1;return!0}function Yt(e,r,n,i,a,o){var s;for(s in r=r||{},e=e||{})e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}));for(s in r)r.hasOwnProperty(s)&&!e.hasOwnProperty(s)&&(t.deepEqual(e[s],r[s])||n.push({command:o,args:[i,s,r[s],a]}))}function Wt(t){return t.id}function Xt(t,e){return t[e.id]=e,t}var Zt=function(t,e){this.reset(t,e)};Zt.prototype.reset=function(t,e){this.points=t||[],this._distances=[0];for(var r=1;r<this.points.length;r++)this._distances[r]=this._distances[r-1]+this.points[r].dist(this.points[r-1]);this.length=this._distances[this._distances.length-1],this.padding=Math.min(e||0,.5*this.length),this.paddedLength=this.length-2*this.padding},Zt.prototype.lerp=function(e){if(1===this.points.length)return this.points[0];e=t.clamp(e,0,1);for(var r=1,n=this._distances[r],i=e*this.paddedLength+this.padding;n<i&&r<this._distances.length;)n=this._distances[++r];var a=r-1,o=this._distances[a],s=n-o,l=s>0?(i-o)/s:0;return this.points[a].mult(1-l).add(this.points[r].mult(l))};var Jt=function(t,e,r){var n=this.boxCells=[],i=this.circleCells=[];this.xCellCount=Math.ceil(t/r),this.yCellCount=Math.ceil(e/r);for(var a=0;a<this.xCellCount*this.yCellCount;a++)n.push([]),i.push([]);this.circleKeys=[],this.boxKeys=[],this.bboxes=[],this.circles=[],this.width=t,this.height=e,this.xScale=this.xCellCount/t,this.yScale=this.yCellCount/e,this.boxUid=0,this.circleUid=0};function Kt(e,r,n,i,a){var o=t.create();return r?(t.scale(o,o,[1/a,1/a,1]),n||t.rotateZ(o,o,i.angle)):t.multiply(o,i.labelPlaneMatrix,e),o}function Qt(e,r,n,i,a){if(r){var o=t.clone(e);return t.scale(o,o,[a,a,1]),n||t.rotateZ(o,o,-i.angle),o}return i.glCoordMatrix}function $t(e,r){var n=[e.x,e.y,0,1];ue(n,n,r);var i=n[3];return{point:new t.Point(n[0]/i,n[1]/i),signedDistanceFromCamera:i}}function te(t,e){return.5+t/e*.5}function ee(t,e){var r=t[0]/t[3],n=t[1]/t[3];return r>=-e[0]&&r<=e[0]&&n>=-e[1]&&n<=e[1]}function re(e,r,n,i,a,o,s,l){var c=i?e.textSizeData:e.iconSizeData,u=t.evaluateSizeForZoom(c,n.transform.zoom),f=[256/n.width*2+1,256/n.height*2+1],h=i?e.text.dynamicLayoutVertexArray:e.icon.dynamicLayoutVertexArray;h.clear();for(var p=e.lineVertexArray,d=i?e.text.placedSymbolArray:e.icon.placedSymbolArray,g=n.transform.width/n.transform.height,m=!1,v=0;v<d.length;v++){var y=d.get(v);if(y.hidden||y.writingMode===t.WritingMode.vertical&&!m)ce(y.numGlyphs,h);else{m=!1;var x=[y.anchorX,y.anchorY,0,1];if(t.transformMat4(x,x,r),ee(x,f)){var b=te(n.transform.cameraToCenterDistance,x[3]),_=t.evaluateSizeForFeature(c,u,y),w=s?_/b:_*b,T=new t.Point(y.anchorX,y.anchorY),k=$t(T,a).point,M={},A=ae(y,w,!1,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g);m=A.useVertical,(A.notEnoughRoom||m||A.needsFlipping&&ae(y,w,!0,l,r,a,o,e.glyphOffsetArray,p,h,k,T,M,g).notEnoughRoom)&&ce(y.numGlyphs,h)}else ce(y.numGlyphs,h)}}i?e.text.dynamicLayoutVertexBuffer.updateData(h):e.icon.dynamicLayoutVertexBuffer.updateData(h)}function ne(t,e,r,n,i,a,o,s,l,c,u){var f=s.glyphStartIndex+s.numGlyphs,h=s.lineStartIndex,p=s.lineStartIndex+s.lineLength,d=e.getoffsetX(s.glyphStartIndex),g=e.getoffsetX(f-1),m=se(t*d,r,n,i,a,o,s.segment,h,p,l,c,u);if(!m)return null;var v=se(t*g,r,n,i,a,o,s.segment,h,p,l,c,u);return v?{first:m,last:v}:null}function ie(e,r,n,i){return e===t.WritingMode.horizontal&&Math.abs(n.y-r.y)>Math.abs(n.x-r.x)*i?{useVertical:!0}:(e===t.WritingMode.vertical?r.y<n.y:r.x>n.x)?{needsFlipping:!0}:null}function ae(e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=r/24,v=e.lineOffsetX*m,y=e.lineOffsetY*m;if(e.numGlyphs>1){var x=e.glyphStartIndex+e.numGlyphs,b=e.lineStartIndex,_=e.lineStartIndex+e.lineLength,w=ne(m,l,v,y,n,f,h,e,c,o,p);if(!w)return{notEnoughRoom:!0};var T=$t(w.first.point,s).point,k=$t(w.last.point,s).point;if(i&&!n){var M=ie(e.writingMode,T,k,d);if(M)return M}g=[w.first];for(var A=e.glyphStartIndex+1;A<x-1;A++)g.push(se(m*l.getoffsetX(A),v,y,n,f,h,e.segment,b,_,c,o,p));g.push(w.last)}else{if(i&&!n){var S=$t(h,a).point,E=e.lineStartIndex+e.segment+1,C=new t.Point(c.getx(E),c.gety(E)),L=$t(C,a),I=L.signedDistanceFromCamera>0?L.point:oe(h,C,S,1,a),P=ie(e.writingMode,S,I,d);if(P)return P}var z=se(m*l.getoffsetX(e.glyphStartIndex),v,y,n,f,h,e.segment,e.lineStartIndex,e.lineStartIndex+e.lineLength,c,o,p);if(!z)return{notEnoughRoom:!0};g=[z]}for(var O=0,D=g;O<D.length;O+=1){var R=D[O];t.addDynamicAttributes(u,R.point,R.angle)}return{}}function oe(t,e,r,n,i){var a=$t(t.add(t.sub(e)._unit()),i).point,o=r.sub(a);return r.add(o._mult(n/o.mag()))}function se(e,r,n,i,a,o,s,l,c,u,f,h){var p=i?e-r:e+r,d=p>0?1:-1,g=0;i&&(d*=-1,g=Math.PI),d<0&&(g+=Math.PI);for(var m=d>0?l+s:l+s+1,v=a,y=a,x=0,b=0,_=Math.abs(p),w=[];x+b<=_;){if((m+=d)<l||m>=c)return null;if(y=v,w.push(v),void 0===(v=h[m])){var T=new t.Point(u.getx(m),u.gety(m)),k=$t(T,f);if(k.signedDistanceFromCamera>0)v=h[m]=k.point;else{var M=m-d;v=oe(0===x?o:new t.Point(u.getx(M),u.gety(M)),T,y,_-x+1,f)}}x+=b,b=y.dist(v)}var A=(_-x)/b,S=v.sub(y),E=S.mult(A)._add(y);E._add(S._unit()._perp()._mult(n*d));var C=g+Math.atan2(v.y-y.y,v.x-y.x);return w.push(E),{point:E,angle:C,path:w}}Jt.prototype.keysLength=function(){return this.boxKeys.length+this.circleKeys.length},Jt.prototype.insert=function(t,e,r,n,i){this._forEachCell(e,r,n,i,this._insertBoxCell,this.boxUid++),this.boxKeys.push(t),this.bboxes.push(e),this.bboxes.push(r),this.bboxes.push(n),this.bboxes.push(i)},Jt.prototype.insertCircle=function(t,e,r,n){this._forEachCell(e-n,r-n,e+n,r+n,this._insertCircleCell,this.circleUid++),this.circleKeys.push(t),this.circles.push(e),this.circles.push(r),this.circles.push(n)},Jt.prototype._insertBoxCell=function(t,e,r,n,i,a){this.boxCells[i].push(a)},Jt.prototype._insertCircleCell=function(t,e,r,n,i,a){this.circleCells[i].push(a)},Jt.prototype._query=function(t,e,r,n,i,a){if(r<0||t>this.width||n<0||e>this.height)return!i&&[];var o=[];if(t<=0&&e<=0&&this.width<=r&&this.height<=n){if(i)return!0;for(var s=0;s<this.boxKeys.length;s++)o.push({key:this.boxKeys[s],x1:this.bboxes[4*s],y1:this.bboxes[4*s+1],x2:this.bboxes[4*s+2],y2:this.bboxes[4*s+3]});for(var l=0;l<this.circleKeys.length;l++){var c=this.circles[3*l],u=this.circles[3*l+1],f=this.circles[3*l+2];o.push({key:this.circleKeys[l],x1:c-f,y1:u-f,x2:c+f,y2:u+f})}return a?o.filter(a):o}return this._forEachCell(t,e,r,n,this._queryCell,o,{hitTest:i,seenUids:{box:{},circle:{}}},a),i?o.length>0:o},Jt.prototype._queryCircle=function(t,e,r,n,i){var a=t-r,o=t+r,s=e-r,l=e+r;if(o<0||a>this.width||l<0||s>this.height)return!n&&[];var c=[];return this._forEachCell(a,s,o,l,this._queryCellCircle,c,{hitTest:n,circle:{x:t,y:e,radius:r},seenUids:{box:{},circle:{}}},i),n?c.length>0:c},Jt.prototype.query=function(t,e,r,n,i){return this._query(t,e,r,n,!1,i)},Jt.prototype.hitTest=function(t,e,r,n,i){return this._query(t,e,r,n,!0,i)},Jt.prototype.hitTestCircle=function(t,e,r,n){return this._queryCircle(t,e,r,!0,n)},Jt.prototype._queryCell=function(t,e,r,n,i,a,o,s){var l=o.seenUids,c=this.boxCells[i];if(null!==c)for(var u=this.bboxes,f=0,h=c;f<h.length;f+=1){var p=h[f];if(!l.box[p]){l.box[p]=!0;var d=4*p;if(t<=u[d+2]&&e<=u[d+3]&&r>=u[d+0]&&n>=u[d+1]&&(!s||s(this.boxKeys[p]))){if(o.hitTest)return a.push(!0),!0;a.push({key:this.boxKeys[p],x1:u[d],y1:u[d+1],x2:u[d+2],y2:u[d+3]})}}}var g=this.circleCells[i];if(null!==g)for(var m=this.circles,v=0,y=g;v<y.length;v+=1){var x=y[v];if(!l.circle[x]){l.circle[x]=!0;var b=3*x;if(this._circleAndRectCollide(m[b],m[b+1],m[b+2],t,e,r,n)&&(!s||s(this.circleKeys[x]))){if(o.hitTest)return a.push(!0),!0;var _=m[b],w=m[b+1],T=m[b+2];a.push({key:this.circleKeys[x],x1:_-T,y1:w-T,x2:_+T,y2:w+T})}}}},Jt.prototype._queryCellCircle=function(t,e,r,n,i,a,o,s){var l=o.circle,c=o.seenUids,u=this.boxCells[i];if(null!==u)for(var f=this.bboxes,h=0,p=u;h<p.length;h+=1){var d=p[h];if(!c.box[d]){c.box[d]=!0;var g=4*d;if(this._circleAndRectCollide(l.x,l.y,l.radius,f[g+0],f[g+1],f[g+2],f[g+3])&&(!s||s(this.boxKeys[d])))return a.push(!0),!0}}var m=this.circleCells[i];if(null!==m)for(var v=this.circles,y=0,x=m;y<x.length;y+=1){var b=x[y];if(!c.circle[b]){c.circle[b]=!0;var _=3*b;if(this._circlesCollide(v[_],v[_+1],v[_+2],l.x,l.y,l.radius)&&(!s||s(this.circleKeys[b])))return a.push(!0),!0}}},Jt.prototype._forEachCell=function(t,e,r,n,i,a,o,s){for(var l=this._convertToXCellCoord(t),c=this._convertToYCellCoord(e),u=this._convertToXCellCoord(r),f=this._convertToYCellCoord(n),h=l;h<=u;h++)for(var p=c;p<=f;p++)if(i.call(this,t,e,r,n,this.xCellCount*p+h,a,o,s))return},Jt.prototype._convertToXCellCoord=function(t){return Math.max(0,Math.min(this.xCellCount-1,Math.floor(t*this.xScale)))},Jt.prototype._convertToYCellCoord=function(t){return Math.max(0,Math.min(this.yCellCount-1,Math.floor(t*this.yScale)))},Jt.prototype._circlesCollide=function(t,e,r,n,i,a){var o=n-t,s=i-e,l=r+a;return l*l>o*o+s*s},Jt.prototype._circleAndRectCollide=function(t,e,r,n,i,a,o){var s=(a-n)/2,l=Math.abs(t-(n+s));if(l>s+r)return!1;var c=(o-i)/2,u=Math.abs(e-(i+c));if(u>c+r)return!1;if(l<=s||u<=c)return!0;var f=l-s,h=u-c;return f*f+h*h<=r*r};var le=new Float32Array([-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0,-1/0,-1/0,0]);function ce(t,e){for(var r=0;r<t;r++){var n=e.length;e.resize(n+4),e.float32.set(le,3*n)}}function ue(t,e,r){var n=e[0],i=e[1];return t[0]=r[0]*n+r[4]*i+r[12],t[1]=r[1]*n+r[5]*i+r[13],t[3]=r[3]*n+r[7]*i+r[15],t}var fe=function(t,e,r){void 0===e&&(e=new Jt(t.width+200,t.height+200,25)),void 0===r&&(r=new Jt(t.width+200,t.height+200,25)),this.transform=t,this.grid=e,this.ignoredGrid=r,this.pitchfactor=Math.cos(t._pitch)*t.cameraToCenterDistance,this.screenRightBoundary=t.width+100,this.screenBottomBoundary=t.height+100,this.gridRightBoundary=t.width+200,this.gridBottomBoundary=t.height+200};function he(e,r,n){return r*(t.EXTENT/(e.tileSize*Math.pow(2,n-e.tileID.overscaledZ)))}fe.prototype.placeCollisionBox=function(t,e,r,n,i){var a=this.projectAndGetPerspectiveRatio(n,t.anchorPointX,t.anchorPointY),o=r*a.perspectiveRatio,s=t.x1*o+a.point.x,l=t.y1*o+a.point.y,c=t.x2*o+a.point.x,u=t.y2*o+a.point.y;return!this.isInsideGrid(s,l,c,u)||!e&&this.grid.hitTest(s,l,c,u,i)?{box:[],offscreen:!1}:{box:[s,l,c,u],offscreen:this.isOffscreen(s,l,c,u)}},fe.prototype.placeCollisionCircles=function(e,r,n,i,a,o,s,l,c,u,f,h,p){var d=[],g=new t.Point(r.anchorX,r.anchorY),m=$t(g,o),v=te(this.transform.cameraToCenterDistance,m.signedDistanceFromCamera),y=(u?a/v:a*v)/t.ONE_EM,x=$t(g,s).point,b=ne(y,i,r.lineOffsetX*y,r.lineOffsetY*y,!1,x,g,r,n,s,{}),_=!1,w=!1,T=!0;if(b){for(var k=.5*h*v+p,M=new t.Point(-100,-100),A=new t.Point(this.screenRightBoundary,this.screenBottomBoundary),S=new Zt,E=b.first,C=b.last,L=[],I=E.path.length-1;I>=1;I--)L.push(E.path[I]);for(var P=1;P<C.path.length;P++)L.push(C.path[P]);var z=2.5*k;if(l){var O=L.map((function(t){return $t(t,l)}));L=O.some((function(t){return t.signedDistanceFromCamera<=0}))?[]:O.map((function(t){return t.point}))}var D=[];if(L.length>0){for(var R=L[0].clone(),F=L[0].clone(),B=1;B<L.length;B++)R.x=Math.min(R.x,L[B].x),R.y=Math.min(R.y,L[B].y),F.x=Math.max(F.x,L[B].x),F.y=Math.max(F.y,L[B].y);D=R.x>=M.x&&F.x<=A.x&&R.y>=M.y&&F.y<=A.y?[L]:F.x<M.x||R.x>A.x||F.y<M.y||R.y>A.y?[]:t.clipLine([L],M.x,M.y,A.x,A.y)}for(var N=0,j=D;N<j.length;N+=1){var U;S.reset(j[N],.25*k),U=S.length<=.5*k?1:Math.ceil(S.paddedLength/z)+1;for(var V=0;V<U;V++){var q=V/Math.max(U-1,1),H=S.lerp(q),G=H.x+100,Y=H.y+100;d.push(G,Y,k,0);var W=G-k,X=Y-k,Z=G+k,J=Y+k;if(T=T&&this.isOffscreen(W,X,Z,J),w=w||this.isInsideGrid(W,X,Z,J),!e&&this.grid.hitTestCircle(G,Y,k,f)&&(_=!0,!c))return{circles:[],offscreen:!1,collisionDetected:_}}}}return{circles:!c&&_||!w?[]:d,offscreen:T,collisionDetected:_}},fe.prototype.queryRenderedSymbols=function(e){if(0===e.length||0===this.grid.keysLength()&&0===this.ignoredGrid.keysLength())return{};for(var r=[],n=1/0,i=1/0,a=-1/0,o=-1/0,s=0,l=e;s<l.length;s+=1){var c=l[s],u=new t.Point(c.x+100,c.y+100);n=Math.min(n,u.x),i=Math.min(i,u.y),a=Math.max(a,u.x),o=Math.max(o,u.y),r.push(u)}for(var f={},h={},p=0,d=this.grid.query(n,i,a,o).concat(this.ignoredGrid.query(n,i,a,o));p<d.length;p+=1){var g=d[p],m=g.key;if(void 0===f[m.bucketInstanceId]&&(f[m.bucketInstanceId]={}),!f[m.bucketInstanceId][m.featureIndex]){var v=[new t.Point(g.x1,g.y1),new t.Point(g.x2,g.y1),new t.Point(g.x2,g.y2),new t.Point(g.x1,g.y2)];t.polygonIntersectsPolygon(r,v)&&(f[m.bucketInstanceId][m.featureIndex]=!0,void 0===h[m.bucketInstanceId]&&(h[m.bucketInstanceId]=[]),h[m.bucketInstanceId].push(m.featureIndex))}}return h},fe.prototype.insertCollisionBox=function(t,e,r,n,i){(e?this.ignoredGrid:this.grid).insert({bucketInstanceId:r,featureIndex:n,collisionGroupID:i},t[0],t[1],t[2],t[3])},fe.prototype.insertCollisionCircles=function(t,e,r,n,i){for(var a=e?this.ignoredGrid:this.grid,o={bucketInstanceId:r,featureIndex:n,collisionGroupID:i},s=0;s<t.length;s+=4)a.insertCircle(o,t[s],t[s+1],t[s+2])},fe.prototype.projectAndGetPerspectiveRatio=function(e,r,n){var i=[r,n,0,1];return ue(i,i,e),{point:new t.Point((i[0]/i[3]+1)/2*this.transform.width+100,(-i[1]/i[3]+1)/2*this.transform.height+100),perspectiveRatio:.5+this.transform.cameraToCenterDistance/i[3]*.5}},fe.prototype.isOffscreen=function(t,e,r,n){return r<100||t>=this.screenRightBoundary||n<100||e>this.screenBottomBoundary},fe.prototype.isInsideGrid=function(t,e,r,n){return r>=0&&t<this.gridRightBoundary&&n>=0&&e<this.gridBottomBoundary},fe.prototype.getViewportMatrix=function(){var e=t.identity([]);return t.translate(e,e,[-100,-100,0]),e};var pe=function(t,e,r,n){this.opacity=t?Math.max(0,Math.min(1,t.opacity+(t.placed?e:-e))):n&&r?1:0,this.placed=r};pe.prototype.isHidden=function(){return 0===this.opacity&&!this.placed};var de=function(t,e,r,n,i){this.text=new pe(t?t.text:null,e,r,i),this.icon=new pe(t?t.icon:null,e,n,i)};de.prototype.isHidden=function(){return this.text.isHidden()&&this.icon.isHidden()};var ge=function(t,e,r){this.text=t,this.icon=e,this.skipFade=r},me=function(){this.invProjMatrix=t.create(),this.viewportMatrix=t.create(),this.circles=[]},ve=function(t,e,r,n,i){this.bucketInstanceId=t,this.featureIndex=e,this.sourceLayerIndex=r,this.bucketIndex=n,this.tileID=i},ye=function(t){this.crossSourceCollisions=t,this.maxGroupID=0,this.collisionGroups={}};function xe(e,r,n,i,a){var o=t.getAnchorAlignment(e),s=-(o.horizontalAlign-.5)*r,l=-(o.verticalAlign-.5)*n,c=t.evaluateVariableOffset(e,i);return new t.Point(s+c[0]*a,l+c[1]*a)}function be(e,r,n,i,a,o){var s=e.x1,l=e.x2,c=e.y1,u=e.y2,f=e.anchorPointX,h=e.anchorPointY,p=new t.Point(r,n);return i&&p._rotate(a?o:-o),{x1:s+p.x,y1:c+p.y,x2:l+p.x,y2:u+p.y,anchorPointX:f,anchorPointY:h}}ye.prototype.get=function(t){if(this.crossSourceCollisions)return{ID:0,predicate:null};if(!this.collisionGroups[t]){var e=++this.maxGroupID;this.collisionGroups[t]={ID:e,predicate:function(t){return t.collisionGroupID===e}}}return this.collisionGroups[t]};var _e=function(t,e,r,n){this.transform=t.clone(),this.collisionIndex=new fe(this.transform),this.placements={},this.opacities={},this.variableOffsets={},this.stale=!1,this.commitTime=0,this.fadeDuration=e,this.retainedQueryData={},this.collisionGroups=new ye(r),this.collisionCircleArrays={},this.prevPlacement=n,n&&(n.prevPlacement=void 0),this.placedOrientations={}};function we(t,e,r,n,i){t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0),t.emplaceBack(e?1:0,r?1:0,n||0,i||0)}_e.prototype.getBucketParts=function(e,r,n,i){var a=n.getBucket(r),o=n.latestFeatureIndex;if(a&&o&&r.id===a.layerIds[0]){var s=n.collisionBoxArray,l=a.layers[0].layout,c=Math.pow(2,this.transform.zoom-n.tileID.overscaledZ),u=n.tileSize/t.EXTENT,f=this.transform.calculatePosMatrix(n.tileID.toUnwrapped()),h=\"map\"===l.get(\"text-pitch-alignment\"),p=\"map\"===l.get(\"text-rotation-alignment\"),d=he(n,1,this.transform.zoom),g=Kt(f,h,p,this.transform,d),m=null;if(h){var v=Qt(f,h,p,this.transform,d);m=t.multiply([],this.transform.labelPlaneMatrix,v)}this.retainedQueryData[a.bucketInstanceId]=new ve(a.bucketInstanceId,o,a.sourceLayerIndex,a.index,n.tileID);var y={bucket:a,layout:l,posMatrix:f,textLabelPlaneMatrix:g,labelToScreenMatrix:m,scale:c,textPixelRatio:u,holdingForFade:n.holdingForFade(),collisionBoxArray:s,partiallyEvaluatedTextSize:t.evaluateSizeForZoom(a.textSizeData,this.transform.zoom),collisionGroup:this.collisionGroups.get(a.sourceID)};if(i)for(var x=0,b=a.sortKeyRanges;x<b.length;x+=1){var _=b[x];e.push({sortKey:_.sortKey,symbolInstanceStart:_.symbolInstanceStart,symbolInstanceEnd:_.symbolInstanceEnd,parameters:y})}else e.push({symbolInstanceStart:0,symbolInstanceEnd:a.symbolInstances.length,parameters:y})}},_e.prototype.attemptAnchorPlacement=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d){var g,m=[f.textOffset0,f.textOffset1],v=xe(t,r,n,m,i),y=this.collisionIndex.placeCollisionBox(be(e,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate);if(!d||0!==this.collisionIndex.placeCollisionBox(be(d,v.x,v.y,a,o,this.transform.angle),u,s,l,c.predicate).box.length)return y.box.length>0?(this.prevPlacement&&this.prevPlacement.variableOffsets[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID]&&this.prevPlacement.placements[f.crossTileID].text&&(g=this.prevPlacement.variableOffsets[f.crossTileID].anchor),this.variableOffsets[f.crossTileID]={textOffset:m,width:r,height:n,anchor:t,textBoxScale:i,prevAnchor:g},this.markUsedJustification(h,t,f,p),h.allowVerticalPlacement&&(this.markUsedOrientation(h,p,f),this.placedOrientations[f.crossTileID]=p),{shift:v,placedGlyphBoxes:y}):void 0},_e.prototype.placeLayerBucketPart=function(e,r,n){var i=this,a=e.parameters,o=a.bucket,s=a.layout,l=a.posMatrix,c=a.textLabelPlaneMatrix,u=a.labelToScreenMatrix,f=a.textPixelRatio,h=a.holdingForFade,p=a.collisionBoxArray,d=a.partiallyEvaluatedTextSize,g=a.collisionGroup,m=s.get(\"text-optional\"),v=s.get(\"icon-optional\"),y=s.get(\"text-allow-overlap\"),x=s.get(\"icon-allow-overlap\"),b=\"map\"===s.get(\"text-rotation-alignment\"),_=\"map\"===s.get(\"text-pitch-alignment\"),w=\"none\"!==s.get(\"icon-text-fit\"),T=\"viewport-y\"===s.get(\"symbol-z-order\"),k=y&&(x||!o.hasIconData()||v),M=x&&(y||!o.hasTextData()||m);!o.collisionArrays&&p&&o.deserializeCollisionBoxes(p);var A=function(e,a){if(!r[e.crossTileID])if(h)i.placements[e.crossTileID]=new ge(!1,!1,!1);else{var p,T=!1,A=!1,S=!0,E=null,C={box:null,offscreen:null},L={box:null,offscreen:null},I=null,P=null,z=0,O=0,D=0;a.textFeatureIndex?z=a.textFeatureIndex:e.useRuntimeCollisionCircles&&(z=e.featureIndex),a.verticalTextFeatureIndex&&(O=a.verticalTextFeatureIndex);var R=a.textBox;if(R){var F=function(r){var n=t.WritingMode.horizontal;if(o.allowVerticalPlacement&&!r&&i.prevPlacement){var a=i.prevPlacement.placedOrientations[e.crossTileID];a&&(i.placedOrientations[e.crossTileID]=a,i.markUsedOrientation(o,n=a,e))}return n},B=function(r,n){if(o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&a.verticalTextBox)for(var i=0,s=o.writingModes;i<s.length&&(s[i]===t.WritingMode.vertical?(C=n(),L=C):C=r(),!(C&&C.box&&C.box.length));i+=1);else C=r()};if(s.get(\"text-variable-anchor\")){var N=s.get(\"text-variable-anchor\");if(i.prevPlacement&&i.prevPlacement.variableOffsets[e.crossTileID]){var j=i.prevPlacement.variableOffsets[e.crossTileID];N.indexOf(j.anchor)>0&&(N=N.filter((function(t){return t!==j.anchor}))).unshift(j.anchor)}var U=function(t,r,n){for(var a=t.x2-t.x1,s=t.y2-t.y1,c=e.textBoxScale,u=w&&!x?r:null,h={box:[],offscreen:!1},p=y?2*N.length:N.length,d=0;d<p;++d){var m=i.attemptAnchorPlacement(N[d%N.length],t,a,s,c,b,_,f,l,g,d>=N.length,e,o,n,u);if(m&&(h=m.placedGlyphBoxes)&&h.box&&h.box.length){T=!0,E=m.shift;break}}return h};B((function(){return U(R,a.iconBox,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&!(C&&C.box&&C.box.length)&&e.numVerticalGlyphVertices>0&&r?U(r,a.verticalIconBox,t.WritingMode.vertical):{box:null,offscreen:null}})),C&&(T=C.box,S=C.offscreen);var V=F(C&&C.box);if(!T&&i.prevPlacement){var q=i.prevPlacement.variableOffsets[e.crossTileID];q&&(i.variableOffsets[e.crossTileID]=q,i.markUsedJustification(o,q.anchor,e,V))}}else{var H=function(t,r){var n=i.collisionIndex.placeCollisionBox(t,y,f,l,g.predicate);return n&&n.box&&n.box.length&&(i.markUsedOrientation(o,r,e),i.placedOrientations[e.crossTileID]=r),n};B((function(){return H(R,t.WritingMode.horizontal)}),(function(){var r=a.verticalTextBox;return o.allowVerticalPlacement&&e.numVerticalGlyphVertices>0&&r?H(r,t.WritingMode.vertical):{box:null,offscreen:null}})),F(C&&C.box&&C.box.length)}}if(T=(p=C)&&p.box&&p.box.length>0,S=p&&p.offscreen,e.useRuntimeCollisionCircles){var G=o.text.placedSymbolArray.get(e.centerJustifiedTextSymbolIndex),Y=t.evaluateSizeForFeature(o.textSizeData,d,G),W=s.get(\"text-padding\");I=i.collisionIndex.placeCollisionCircles(y,G,o.lineVertexArray,o.glyphOffsetArray,Y,l,c,u,n,_,g.predicate,e.collisionCircleDiameter,W),T=y||I.circles.length>0&&!I.collisionDetected,S=S&&I.offscreen}if(a.iconFeatureIndex&&(D=a.iconFeatureIndex),a.iconBox){var X=function(t){var e=w&&E?be(t,E.x,E.y,b,_,i.transform.angle):t;return i.collisionIndex.placeCollisionBox(e,x,f,l,g.predicate)};A=L&&L.box&&L.box.length&&a.verticalIconBox?(P=X(a.verticalIconBox)).box.length>0:(P=X(a.iconBox)).box.length>0,S=S&&P.offscreen}var Z=m||0===e.numHorizontalGlyphVertices&&0===e.numVerticalGlyphVertices,J=v||0===e.numIconVertices;if(Z||J?J?Z||(A=A&&T):T=A&&T:A=T=A&&T,T&&p&&p.box&&i.collisionIndex.insertCollisionBox(p.box,s.get(\"text-ignore-placement\"),o.bucketInstanceId,L&&L.box&&O?O:z,g.ID),A&&P&&i.collisionIndex.insertCollisionBox(P.box,s.get(\"icon-ignore-placement\"),o.bucketInstanceId,D,g.ID),I&&(T&&i.collisionIndex.insertCollisionCircles(I.circles,s.get(\"text-ignore-placement\"),o.bucketInstanceId,z,g.ID),n)){var K=o.bucketInstanceId,Q=i.collisionCircleArrays[K];void 0===Q&&(Q=i.collisionCircleArrays[K]=new me);for(var $=0;$<I.circles.length;$+=4)Q.circles.push(I.circles[$+0]),Q.circles.push(I.circles[$+1]),Q.circles.push(I.circles[$+2]),Q.circles.push(I.collisionDetected?1:0)}i.placements[e.crossTileID]=new ge(T||k,A||M,S||o.justReloaded),r[e.crossTileID]=!0}};if(T)for(var S=o.getSortedSymbolIndexes(this.transform.angle),E=S.length-1;E>=0;--E){var C=S[E];A(o.symbolInstances.get(C),o.collisionArrays[C])}else for(var L=e.symbolInstanceStart;L<e.symbolInstanceEnd;L++)A(o.symbolInstances.get(L),o.collisionArrays[L]);if(n&&o.bucketInstanceId in this.collisionCircleArrays){var I=this.collisionCircleArrays[o.bucketInstanceId];t.invert(I.invProjMatrix,l),I.viewportMatrix=this.collisionIndex.getViewportMatrix()}o.justReloaded=!1},_e.prototype.markUsedJustification=function(e,r,n,i){var a;a=i===t.WritingMode.vertical?n.verticalPlacedTextSymbolIndex:{left:n.leftJustifiedTextSymbolIndex,center:n.centerJustifiedTextSymbolIndex,right:n.rightJustifiedTextSymbolIndex}[t.getAnchorJustification(r)];for(var o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex,n.verticalPlacedTextSymbolIndex];o<s.length;o+=1){var l=s[o];l>=0&&(e.text.placedSymbolArray.get(l).crossTileID=a>=0&&l!==a?0:n.crossTileID)}},_e.prototype.markUsedOrientation=function(e,r,n){for(var i=r===t.WritingMode.horizontal||r===t.WritingMode.horizontalOnly?r:0,a=r===t.WritingMode.vertical?r:0,o=0,s=[n.leftJustifiedTextSymbolIndex,n.centerJustifiedTextSymbolIndex,n.rightJustifiedTextSymbolIndex];o<s.length;o+=1)e.text.placedSymbolArray.get(s[o]).placedOrientation=i;n.verticalPlacedTextSymbolIndex&&(e.text.placedSymbolArray.get(n.verticalPlacedTextSymbolIndex).placedOrientation=a)},_e.prototype.commit=function(t){this.commitTime=t,this.zoomAtLastRecencyCheck=this.transform.zoom;var e=this.prevPlacement,r=!1;this.prevZoomAdjustment=e?e.zoomAdjustment(this.transform.zoom):0;var n=e?e.symbolFadeChange(t):1,i=e?e.opacities:{},a=e?e.variableOffsets:{},o=e?e.placedOrientations:{};for(var s in this.placements){var l=this.placements[s],c=i[s];c?(this.opacities[s]=new de(c,n,l.text,l.icon),r=r||l.text!==c.text.placed||l.icon!==c.icon.placed):(this.opacities[s]=new de(null,n,l.text,l.icon,l.skipFade),r=r||l.text||l.icon)}for(var u in i){var f=i[u];if(!this.opacities[u]){var h=new de(f,n,!1,!1);h.isHidden()||(this.opacities[u]=h,r=r||f.text.placed||f.icon.placed)}}for(var p in a)this.variableOffsets[p]||!this.opacities[p]||this.opacities[p].isHidden()||(this.variableOffsets[p]=a[p]);for(var d in o)this.placedOrientations[d]||!this.opacities[d]||this.opacities[d].isHidden()||(this.placedOrientations[d]=o[d]);r?this.lastPlacementChangeTime=t:\"number\"!=typeof this.lastPlacementChangeTime&&(this.lastPlacementChangeTime=e?e.lastPlacementChangeTime:t)},_e.prototype.updateLayerOpacities=function(t,e){for(var r={},n=0,i=e;n<i.length;n+=1){var a=i[n],o=a.getBucket(t);o&&a.latestFeatureIndex&&t.id===o.layerIds[0]&&this.updateBucketOpacities(o,r,a.collisionBoxArray)}},_e.prototype.updateBucketOpacities=function(e,r,n){var i=this;e.hasTextData()&&e.text.opacityVertexArray.clear(),e.hasIconData()&&e.icon.opacityVertexArray.clear(),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexArray.clear(),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexArray.clear();var a=e.layers[0].layout,o=new de(null,0,!1,!1,!0),s=a.get(\"text-allow-overlap\"),l=a.get(\"icon-allow-overlap\"),c=a.get(\"text-variable-anchor\"),u=\"map\"===a.get(\"text-rotation-alignment\"),f=\"map\"===a.get(\"text-pitch-alignment\"),h=\"none\"!==a.get(\"icon-text-fit\"),p=new de(null,0,s&&(l||!e.hasIconData()||a.get(\"icon-optional\")),l&&(s||!e.hasTextData()||a.get(\"text-optional\")),!0);!e.collisionArrays&&n&&(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData())&&e.deserializeCollisionBoxes(n);for(var d=function(t,e,r){for(var n=0;n<e/4;n++)t.opacityVertexArray.emplaceBack(r)},g=function(n){var a=e.symbolInstances.get(n),s=a.numHorizontalGlyphVertices,l=a.numVerticalGlyphVertices,g=a.crossTileID,m=i.opacities[g];r[g]?m=o:m||(i.opacities[g]=m=p),r[g]=!0;var v=a.numIconVertices>0,y=i.placedOrientations[a.crossTileID],x=y===t.WritingMode.vertical,b=y===t.WritingMode.horizontal||y===t.WritingMode.horizontalOnly;if(s>0||l>0){var _=Le(m.text);d(e.text,s,x?Ie:_),d(e.text,l,b?Ie:_);var w=m.text.isHidden();[a.rightJustifiedTextSymbolIndex,a.centerJustifiedTextSymbolIndex,a.leftJustifiedTextSymbolIndex].forEach((function(t){t>=0&&(e.text.placedSymbolArray.get(t).hidden=w||x?1:0)})),a.verticalPlacedTextSymbolIndex>=0&&(e.text.placedSymbolArray.get(a.verticalPlacedTextSymbolIndex).hidden=w||b?1:0);var T=i.variableOffsets[a.crossTileID];T&&i.markUsedJustification(e,T.anchor,a,y);var k=i.placedOrientations[a.crossTileID];k&&(i.markUsedJustification(e,\"left\",a,k),i.markUsedOrientation(e,k,a))}if(v){var M=Le(m.icon),A=!(h&&a.verticalPlacedIconSymbolIndex&&x);a.placedIconSymbolIndex>=0&&(d(e.icon,a.numIconVertices,A?M:Ie),e.icon.placedSymbolArray.get(a.placedIconSymbolIndex).hidden=m.icon.isHidden()),a.verticalPlacedIconSymbolIndex>=0&&(d(e.icon,a.numVerticalIconVertices,A?Ie:M),e.icon.placedSymbolArray.get(a.verticalPlacedIconSymbolIndex).hidden=m.icon.isHidden())}if(e.hasIconCollisionBoxData()||e.hasTextCollisionBoxData()){var S=e.collisionArrays[n];if(S){var E=new t.Point(0,0);if(S.textBox||S.verticalTextBox){var C=!0;if(c){var L=i.variableOffsets[g];L?(E=xe(L.anchor,L.width,L.height,L.textOffset,L.textBoxScale),u&&E._rotate(f?i.transform.angle:-i.transform.angle)):C=!1}S.textBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||x,E.x,E.y),S.verticalTextBox&&we(e.textCollisionBox.collisionVertexArray,m.text.placed,!C||b,E.x,E.y)}var I=Boolean(!b&&S.verticalIconBox);S.iconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,I,h?E.x:0,h?E.y:0),S.verticalIconBox&&we(e.iconCollisionBox.collisionVertexArray,m.icon.placed,!I,h?E.x:0,h?E.y:0)}}},m=0;m<e.symbolInstances.length;m++)g(m);if(e.sortFeatures(this.transform.angle),this.retainedQueryData[e.bucketInstanceId]&&(this.retainedQueryData[e.bucketInstanceId].featureSortOrder=e.featureSortOrder),e.hasTextData()&&e.text.opacityVertexBuffer&&e.text.opacityVertexBuffer.updateData(e.text.opacityVertexArray),e.hasIconData()&&e.icon.opacityVertexBuffer&&e.icon.opacityVertexBuffer.updateData(e.icon.opacityVertexArray),e.hasIconCollisionBoxData()&&e.iconCollisionBox.collisionVertexBuffer&&e.iconCollisionBox.collisionVertexBuffer.updateData(e.iconCollisionBox.collisionVertexArray),e.hasTextCollisionBoxData()&&e.textCollisionBox.collisionVertexBuffer&&e.textCollisionBox.collisionVertexBuffer.updateData(e.textCollisionBox.collisionVertexArray),e.bucketInstanceId in this.collisionCircleArrays){var v=this.collisionCircleArrays[e.bucketInstanceId];e.placementInvProjMatrix=v.invProjMatrix,e.placementViewportMatrix=v.viewportMatrix,e.collisionCircleArray=v.circles,delete this.collisionCircleArrays[e.bucketInstanceId]}},_e.prototype.symbolFadeChange=function(t){return 0===this.fadeDuration?1:(t-this.commitTime)/this.fadeDuration+this.prevZoomAdjustment},_e.prototype.zoomAdjustment=function(t){return Math.max(0,(this.transform.zoom-t)/1.5)},_e.prototype.hasTransitions=function(t){return this.stale||t-this.lastPlacementChangeTime<this.fadeDuration},_e.prototype.stillRecent=function(t,e){var r=this.zoomAtLastRecencyCheck===e?1-this.zoomAdjustment(e):1;return this.zoomAtLastRecencyCheck=e,this.commitTime+this.fadeDuration*r>t},_e.prototype.setStale=function(){this.stale=!0};var Te=Math.pow(2,25),ke=Math.pow(2,24),Me=Math.pow(2,17),Ae=Math.pow(2,16),Se=Math.pow(2,9),Ee=Math.pow(2,8),Ce=Math.pow(2,1);function Le(t){if(0===t.opacity&&!t.placed)return 0;if(1===t.opacity&&t.placed)return 4294967295;var e=t.placed?1:0,r=Math.floor(127*t.opacity);return r*Te+e*ke+r*Me+e*Ae+r*Se+e*Ee+r*Ce+e}var Ie=0,Pe=function(t){this._sortAcrossTiles=\"viewport-y\"!==t.layout.get(\"symbol-z-order\")&&void 0!==t.layout.get(\"symbol-sort-key\").constantOr(1),this._currentTileIndex=0,this._currentPartIndex=0,this._seenCrossTileIDs={},this._bucketParts=[]};Pe.prototype.continuePlacement=function(t,e,r,n,i){for(var a=this._bucketParts;this._currentTileIndex<t.length;)if(e.getBucketParts(a,n,t[this._currentTileIndex],this._sortAcrossTiles),this._currentTileIndex++,i())return!0;for(this._sortAcrossTiles&&(this._sortAcrossTiles=!1,a.sort((function(t,e){return t.sortKey-e.sortKey})));this._currentPartIndex<a.length;)if(e.placeLayerBucketPart(a[this._currentPartIndex],this._seenCrossTileIDs,r),this._currentPartIndex++,i())return!0;return!1};var ze=function(t,e,r,n,i,a,o){this.placement=new _e(t,i,a,o),this._currentPlacementIndex=e.length-1,this._forceFullPlacement=r,this._showCollisionBoxes=n,this._done=!1};ze.prototype.isDone=function(){return this._done},ze.prototype.continuePlacement=function(e,r,n){for(var i=this,a=t.browser.now(),o=function(){var e=t.browser.now()-a;return!i._forceFullPlacement&&e>2};this._currentPlacementIndex>=0;){var s=r[e[this._currentPlacementIndex]],l=this.placement.collisionIndex.transform.zoom;if(\"symbol\"===s.type&&(!s.minzoom||s.minzoom<=l)&&(!s.maxzoom||s.maxzoom>l)){if(this._inProgressLayer||(this._inProgressLayer=new Pe(s)),this._inProgressLayer.continuePlacement(n[s.source],this.placement,this._showCollisionBoxes,s,o))return;delete this._inProgressLayer}this._currentPlacementIndex--}this._done=!0},ze.prototype.commit=function(t){return this.placement.commit(t),this.placement};var Oe=512/t.EXTENT/2,De=function(t,e,r){this.tileID=t,this.indexedSymbolInstances={},this.bucketInstanceId=r;for(var n=0;n<e.length;n++){var i=e.get(n),a=i.key;this.indexedSymbolInstances[a]||(this.indexedSymbolInstances[a]=[]),this.indexedSymbolInstances[a].push({crossTileID:i.crossTileID,coord:this.getScaledCoordinates(i,t)})}};De.prototype.getScaledCoordinates=function(e,r){var n=Oe/Math.pow(2,r.canonical.z-this.tileID.canonical.z);return{x:Math.floor((r.canonical.x*t.EXTENT+e.anchorX)*n),y:Math.floor((r.canonical.y*t.EXTENT+e.anchorY)*n)}},De.prototype.findMatches=function(t,e,r){for(var n=this.tileID.canonical.z<e.canonical.z?1:Math.pow(2,this.tileID.canonical.z-e.canonical.z),i=0;i<t.length;i++){var a=t.get(i);if(!a.crossTileID){var o=this.indexedSymbolInstances[a.key];if(o)for(var s=this.getScaledCoordinates(a,e),l=0,c=o;l<c.length;l+=1){var u=c[l];if(Math.abs(u.coord.x-s.x)<=n&&Math.abs(u.coord.y-s.y)<=n&&!r[u.crossTileID]){r[u.crossTileID]=!0,a.crossTileID=u.crossTileID;break}}}}};var Re=function(){this.maxCrossTileID=0};Re.prototype.generate=function(){return++this.maxCrossTileID};var Fe=function(){this.indexes={},this.usedCrossTileIDs={},this.lng=0};Fe.prototype.handleWrapJump=function(t){var e=Math.round((t-this.lng)/360);if(0!==e)for(var r in this.indexes){var n=this.indexes[r],i={};for(var a in n){var o=n[a];o.tileID=o.tileID.unwrapTo(o.tileID.wrap+e),i[o.tileID.key]=o}this.indexes[r]=i}this.lng=t},Fe.prototype.addBucket=function(t,e,r){if(this.indexes[t.overscaledZ]&&this.indexes[t.overscaledZ][t.key]){if(this.indexes[t.overscaledZ][t.key].bucketInstanceId===e.bucketInstanceId)return!1;this.removeBucketCrossTileIDs(t.overscaledZ,this.indexes[t.overscaledZ][t.key])}for(var n=0;n<e.symbolInstances.length;n++)e.symbolInstances.get(n).crossTileID=0;this.usedCrossTileIDs[t.overscaledZ]||(this.usedCrossTileIDs[t.overscaledZ]={});var i=this.usedCrossTileIDs[t.overscaledZ];for(var a in this.indexes){var o=this.indexes[a];if(Number(a)>t.overscaledZ)for(var s in o){var l=o[s];l.tileID.isChildOf(t)&&l.findMatches(e.symbolInstances,t,i)}else{var c=o[t.scaledTo(Number(a)).key];c&&c.findMatches(e.symbolInstances,t,i)}}for(var u=0;u<e.symbolInstances.length;u++){var f=e.symbolInstances.get(u);f.crossTileID||(f.crossTileID=r.generate(),i[f.crossTileID]=!0)}return void 0===this.indexes[t.overscaledZ]&&(this.indexes[t.overscaledZ]={}),this.indexes[t.overscaledZ][t.key]=new De(t,e.symbolInstances,e.bucketInstanceId),!0},Fe.prototype.removeBucketCrossTileIDs=function(t,e){for(var r in e.indexedSymbolInstances)for(var n=0,i=e.indexedSymbolInstances[r];n<i.length;n+=1)delete this.usedCrossTileIDs[t][i[n].crossTileID]},Fe.prototype.removeStaleBuckets=function(t){var e=!1;for(var r in this.indexes){var n=this.indexes[r];for(var i in n)t[n[i].bucketInstanceId]||(this.removeBucketCrossTileIDs(r,n[i]),delete n[i],e=!0)}return e};var Be=function(){this.layerIndexes={},this.crossTileIDs=new Re,this.maxBucketInstanceId=0,this.bucketsInCurrentPlacement={}};Be.prototype.addLayer=function(t,e,r){var n=this.layerIndexes[t.id];void 0===n&&(n=this.layerIndexes[t.id]=new Fe);var i=!1,a={};n.handleWrapJump(r);for(var o=0,s=e;o<s.length;o+=1){var l=s[o],c=l.getBucket(t);c&&t.id===c.layerIds[0]&&(c.bucketInstanceId||(c.bucketInstanceId=++this.maxBucketInstanceId),n.addBucket(l.tileID,c,this.crossTileIDs)&&(i=!0),a[c.bucketInstanceId]=!0)}return n.removeStaleBuckets(a)&&(i=!0),i},Be.prototype.pruneUnusedLayers=function(t){var e={};for(var r in t.forEach((function(t){e[t]=!0})),this.layerIndexes)e[r]||delete this.layerIndexes[r]};var Ne=function(e,r){return t.emitValidationErrors(e,r&&r.filter((function(t){return\"source.canvas\"!==t.identifier})))},je=t.pick(Ut,[\"addLayer\",\"removeLayer\",\"setPaintProperty\",\"setLayoutProperty\",\"setFilter\",\"addSource\",\"removeSource\",\"setLayerZoomRange\",\"setLight\",\"setTransition\",\"setGeoJSONSourceData\"]),Ue=t.pick(Ut,[\"setCenter\",\"setZoom\",\"setBearing\",\"setPitch\"]),Ve=function(){var e={},r=t.styleSpec.$version;for(var n in t.styleSpec.$root){var i,a=t.styleSpec.$root[n];a.required&&null!=(i=\"version\"===n?r:\"array\"===a.type?[]:{})&&(e[n]=i)}return e}(),qe=function(e){function r(n,i){var a=this;void 0===i&&(i={}),e.call(this),this.map=n,this.dispatcher=new k(Bt(),this),this.imageManager=new h,this.imageManager.setEventedParent(this),this.glyphManager=new x(n._requestManager,i.localIdeographFontFamily),this.lineAtlas=new T(256,512),this.crossTileSymbolIndex=new Be,this._layers={},this._serializedLayers={},this._order=[],this.sourceCaches={},this.zoomHistory=new t.ZoomHistory,this._loaded=!1,this._availableImages=[],this._resetUpdates(),this.dispatcher.broadcast(\"setReferrer\",t.getReferrer());var o=this;this._rtlTextPluginCallback=r.registerForPluginStateChange((function(e){o.dispatcher.broadcast(\"syncRTLPluginState\",{pluginStatus:e.pluginStatus,pluginURL:e.pluginURL},(function(e,r){if(t.triggerPluginCompletionEvent(e),r&&r.every((function(t){return t})))for(var n in o.sourceCaches)o.sourceCaches[n].reload()}))})),this.on(\"data\",(function(t){if(\"source\"===t.dataType&&\"metadata\"===t.sourceDataType){var e=a.sourceCaches[t.sourceId];if(e){var r=e.getSource();if(r&&r.vectorLayerIds)for(var n in a._layers){var i=a._layers[n];i.source===r.id&&a._validateLayer(i)}}}}))}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.loadURL=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"}));var i=\"boolean\"==typeof r.validate?r.validate:!t.isMapboxURL(e);e=this.map._requestManager.normalizeStyleURL(e,r.accessToken);var a=this.map._requestManager.transformRequest(e,t.ResourceType.Style);this._request=t.getJSON(a,(function(e,r){n._request=null,e?n.fire(new t.ErrorEvent(e)):r&&n._load(r,i)}))},r.prototype.loadJSON=function(e,r){var n=this;void 0===r&&(r={}),this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._request=t.browser.frame((function(){n._request=null,n._load(e,!1!==r.validate)}))},r.prototype.loadEmpty=function(){this.fire(new t.Event(\"dataloading\",{dataType:\"style\"})),this._load(Ve,!1)},r.prototype._load=function(e,r){if(!r||!Ne(this,t.validateStyle(e))){for(var n in this._loaded=!0,this.stylesheet=e,e.sources)this.addSource(n,e.sources[n],{validate:!1});e.sprite?this._loadSprite(e.sprite):this.imageManager.setLoaded(!0),this.glyphManager.setURL(e.glyphs);var i=jt(this.stylesheet.layers);this._order=i.map((function(t){return t.id})),this._layers={},this._serializedLayers={};for(var a=0,o=i;a<o.length;a+=1){var s=o[a];(s=t.createStyleLayer(s)).setEventedParent(this,{layer:{id:s.id}}),this._layers[s.id]=s,this._serializedLayers[s.id]=s.serialize()}this.dispatcher.broadcast(\"setLayers\",this._serializeLayers(this._order)),this.light=new w(this.stylesheet.light),this.fire(new t.Event(\"data\",{dataType:\"style\"})),this.fire(new t.Event(\"style.load\"))}},r.prototype._loadSprite=function(e){var r=this;this._spriteRequest=function(e,r,n){var i,a,o,s=t.browser.devicePixelRatio>1?\"@2x\":\"\",l=t.getJSON(r.transformRequest(r.normalizeSpriteURL(e,s,\".json\"),t.ResourceType.SpriteJSON),(function(t,e){l=null,o||(o=t,i=e,u())})),c=t.getImage(r.transformRequest(r.normalizeSpriteURL(e,s,\".png\"),t.ResourceType.SpriteImage),(function(t,e){c=null,o||(o=t,a=e,u())}));function u(){if(o)n(o);else if(i&&a){var e=t.browser.getImageData(a),r={};for(var s in i){var l=i[s],c=l.width,u=l.height,f=l.x,h=l.y,p=l.sdf,d=l.pixelRatio,g=l.stretchX,m=l.stretchY,v=l.content,y=new t.RGBAImage({width:c,height:u});t.RGBAImage.copy(e,y,{x:f,y:h},{x:0,y:0},{width:c,height:u}),r[s]={data:y,pixelRatio:d,sdf:p,stretchX:g,stretchY:m,content:v}}n(null,r)}}return{cancel:function(){l&&(l.cancel(),l=null),c&&(c.cancel(),c=null)}}}(e,this.map._requestManager,(function(e,n){if(r._spriteRequest=null,e)r.fire(new t.ErrorEvent(e));else if(n)for(var i in n)r.imageManager.addImage(i,n[i]);r.imageManager.setLoaded(!0),r._availableImages=r.imageManager.listImages(),r.dispatcher.broadcast(\"setImages\",r._availableImages),r.fire(new t.Event(\"data\",{dataType:\"style\"}))}))},r.prototype._validateLayer=function(e){var r=this.sourceCaches[e.source];if(r){var n=e.sourceLayer;if(n){var i=r.getSource();(\"geojson\"===i.type||i.vectorLayerIds&&-1===i.vectorLayerIds.indexOf(n))&&this.fire(new t.ErrorEvent(new Error('Source layer \"'+n+'\" does not exist on source \"'+i.id+'\" as specified by style layer \"'+e.id+'\"')))}}},r.prototype.loaded=function(){if(!this._loaded)return!1;if(Object.keys(this._updatedSources).length)return!1;for(var t in this.sourceCaches)if(!this.sourceCaches[t].loaded())return!1;return!!this.imageManager.isLoaded()},r.prototype._serializeLayers=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=this._layers[n[r]];\"custom\"!==i.type&&e.push(i.serialize())}return e},r.prototype.hasTransitions=function(){if(this.light&&this.light.hasTransition())return!0;for(var t in this.sourceCaches)if(this.sourceCaches[t].hasTransition())return!0;for(var e in this._layers)if(this._layers[e].hasTransition())return!0;return!1},r.prototype._checkLoaded=function(){if(!this._loaded)throw new Error(\"Style is not done loading\")},r.prototype.update=function(e){if(this._loaded){var r=this._changed;if(this._changed){var n=Object.keys(this._updatedLayers),i=Object.keys(this._removedLayers);for(var a in(n.length||i.length)&&this._updateWorkerLayers(n,i),this._updatedSources){var o=this._updatedSources[a];\"reload\"===o?this._reloadSource(a):\"clear\"===o&&this._clearSource(a)}for(var s in this._updateTilesForChangedImages(),this._updatedPaintProps)this._layers[s].updateTransitions(e);this.light.updateTransitions(e),this._resetUpdates()}for(var l in this.sourceCaches)this.sourceCaches[l].used=!1;for(var c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];f.recalculate(e,this._availableImages),!f.isHidden(e.zoom)&&f.source&&(this.sourceCaches[f.source].used=!0)}this.light.recalculate(e),this.z=e.zoom,r&&this.fire(new t.Event(\"data\",{dataType:\"style\"}))}},r.prototype._updateTilesForChangedImages=function(){var t=Object.keys(this._changedImages);if(t.length){for(var e in this.sourceCaches)this.sourceCaches[e].reloadTilesForDependencies([\"icons\",\"patterns\"],t);this._changedImages={}}},r.prototype._updateWorkerLayers=function(t,e){this.dispatcher.broadcast(\"updateLayers\",{layers:this._serializeLayers(t),removedIds:e})},r.prototype._resetUpdates=function(){this._changed=!1,this._updatedLayers={},this._removedLayers={},this._updatedSources={},this._updatedPaintProps={},this._changedImages={}},r.prototype.setState=function(e){var r=this;if(this._checkLoaded(),Ne(this,t.validateStyle(e)))return!1;(e=t.clone$1(e)).layers=jt(e.layers);var n=function(e,r){if(!e)return[{command:Ut.setStyle,args:[r]}];var n=[];try{if(!t.deepEqual(e.version,r.version))return[{command:Ut.setStyle,args:[r]}];t.deepEqual(e.center,r.center)||n.push({command:Ut.setCenter,args:[r.center]}),t.deepEqual(e.zoom,r.zoom)||n.push({command:Ut.setZoom,args:[r.zoom]}),t.deepEqual(e.bearing,r.bearing)||n.push({command:Ut.setBearing,args:[r.bearing]}),t.deepEqual(e.pitch,r.pitch)||n.push({command:Ut.setPitch,args:[r.pitch]}),t.deepEqual(e.sprite,r.sprite)||n.push({command:Ut.setSprite,args:[r.sprite]}),t.deepEqual(e.glyphs,r.glyphs)||n.push({command:Ut.setGlyphs,args:[r.glyphs]}),t.deepEqual(e.transition,r.transition)||n.push({command:Ut.setTransition,args:[r.transition]}),t.deepEqual(e.light,r.light)||n.push({command:Ut.setLight,args:[r.light]});var i={},a=[];!function(e,r,n,i){var a;for(a in r=r||{},e=e||{})e.hasOwnProperty(a)&&(r.hasOwnProperty(a)||qt(a,n,i));for(a in r)r.hasOwnProperty(a)&&(e.hasOwnProperty(a)?t.deepEqual(e[a],r[a])||(\"geojson\"===e[a].type&&\"geojson\"===r[a].type&&Gt(e,r,a)?n.push({command:Ut.setGeoJSONSourceData,args:[a,r[a].data]}):Ht(a,r,n,i)):Vt(a,r,n))}(e.sources,r.sources,a,i);var o=[];e.layers&&e.layers.forEach((function(t){i[t.source]?n.push({command:Ut.removeLayer,args:[t.id]}):o.push(t)})),n=n.concat(a),function(e,r,n){r=r||[];var i,a,o,s,l,c,u,f=(e=e||[]).map(Wt),h=r.map(Wt),p=e.reduce(Xt,{}),d=r.reduce(Xt,{}),g=f.slice(),m=Object.create(null);for(i=0,a=0;i<f.length;i++)d.hasOwnProperty(o=f[i])?a++:(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.indexOf(o,a),1));for(i=0,a=0;i<h.length;i++)g[g.length-1-i]!==(o=h[h.length-1-i])&&(p.hasOwnProperty(o)?(n.push({command:Ut.removeLayer,args:[o]}),g.splice(g.lastIndexOf(o,g.length-a),1)):a++,n.push({command:Ut.addLayer,args:[d[o],c=g[g.length-i]]}),g.splice(g.length-i,0,o),m[o]=!0);for(i=0;i<h.length;i++)if(s=p[o=h[i]],l=d[o],!m[o]&&!t.deepEqual(s,l))if(t.deepEqual(s.source,l.source)&&t.deepEqual(s[\"source-layer\"],l[\"source-layer\"])&&t.deepEqual(s.type,l.type)){for(u in Yt(s.layout,l.layout,n,o,null,Ut.setLayoutProperty),Yt(s.paint,l.paint,n,o,null,Ut.setPaintProperty),t.deepEqual(s.filter,l.filter)||n.push({command:Ut.setFilter,args:[o,l.filter]}),t.deepEqual(s.minzoom,l.minzoom)&&t.deepEqual(s.maxzoom,l.maxzoom)||n.push({command:Ut.setLayerZoomRange,args:[o,l.minzoom,l.maxzoom]}),s)s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}));for(u in l)l.hasOwnProperty(u)&&!s.hasOwnProperty(u)&&\"layout\"!==u&&\"paint\"!==u&&\"filter\"!==u&&\"metadata\"!==u&&\"minzoom\"!==u&&\"maxzoom\"!==u&&(0===u.indexOf(\"paint.\")?Yt(s[u],l[u],n,o,u.slice(6),Ut.setPaintProperty):t.deepEqual(s[u],l[u])||n.push({command:Ut.setLayerProperty,args:[o,u,l[u]]}))}else n.push({command:Ut.removeLayer,args:[o]}),c=g[g.lastIndexOf(o)+1],n.push({command:Ut.addLayer,args:[l,c]})}(o,r.layers,n)}catch(t){console.warn(\"Unable to compute style diff:\",t),n=[{command:Ut.setStyle,args:[r]}]}return n}(this.serialize(),e).filter((function(t){return!(t.command in Ue)}));if(0===n.length)return!1;var i=n.filter((function(t){return!(t.command in je)}));if(i.length>0)throw new Error(\"Unimplemented: \"+i.map((function(t){return t.command})).join(\", \")+\".\");return n.forEach((function(t){\"setTransition\"!==t.command&&r[t.command].apply(r,t.args)})),this.stylesheet=e,!0},r.prototype.addImage=function(e,r){if(this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"An image with this name already exists.\")));this.imageManager.addImage(e,r),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.updateImage=function(t,e){this.imageManager.updateImage(t,e)},r.prototype.getImage=function(t){return this.imageManager.getImage(t)},r.prototype.removeImage=function(e){if(!this.getImage(e))return this.fire(new t.ErrorEvent(new Error(\"No image with this name exists.\")));this.imageManager.removeImage(e),this._availableImages=this.imageManager.listImages(),this._changedImages[e]=!0,this._changed=!0,this.fire(new t.Event(\"data\",{dataType:\"style\"}))},r.prototype.listImages=function(){return this._checkLoaded(),this.imageManager.listImages()},r.prototype.addSource=function(e,r,n){var i=this;if(void 0===n&&(n={}),this._checkLoaded(),void 0!==this.sourceCaches[e])throw new Error(\"There is already a source with this ID\");if(!r.type)throw new Error(\"The type property must be defined, but the only the following properties were given: \"+Object.keys(r).join(\", \")+\".\");if(!([\"vector\",\"raster\",\"geojson\",\"video\",\"image\"].indexOf(r.type)>=0&&this._validate(t.validateStyle.source,\"sources.\"+e,r,null,n))){this.map&&this.map._collectResourceTiming&&(r.collectResourceTiming=!0);var a=this.sourceCaches[e]=new Lt(e,r,this.dispatcher);a.style=this,a.setEventedParent(this,(function(){return{isSourceLoaded:i.loaded(),source:a.serialize(),sourceId:e}})),a.onAdd(this.map),this._changed=!0}},r.prototype.removeSource=function(e){if(this._checkLoaded(),void 0===this.sourceCaches[e])throw new Error(\"There is no source with this ID\");for(var r in this._layers)if(this._layers[r].source===e)return this.fire(new t.ErrorEvent(new Error('Source \"'+e+'\" cannot be removed while layer \"'+r+'\" is using it.')));var n=this.sourceCaches[e];delete this.sourceCaches[e],delete this._updatedSources[e],n.fire(new t.Event(\"data\",{sourceDataType:\"metadata\",dataType:\"source\",sourceId:e})),n.setEventedParent(null),n.clearTiles(),n.onRemove&&n.onRemove(this.map),this._changed=!0},r.prototype.setGeoJSONSourceData=function(t,e){this._checkLoaded(),this.sourceCaches[t].getSource().setData(e),this._changed=!0},r.prototype.getSource=function(t){return this.sourceCaches[t]&&this.sourceCaches[t].getSource()},r.prototype.addLayer=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=e.id;if(this.getLayer(i))this.fire(new t.ErrorEvent(new Error('Layer with id \"'+i+'\" already exists on this map')));else{var a;if(\"custom\"===e.type){if(Ne(this,t.validateCustomStyleLayer(e)))return;a=t.createStyleLayer(e)}else{if(\"object\"==typeof e.source&&(this.addSource(i,e.source),e=t.clone$1(e),e=t.extend(e,{source:i})),this._validate(t.validateStyle.layer,\"layers.\"+i,e,{arrayIndex:-1},n))return;a=t.createStyleLayer(e),this._validateLayer(a),a.setEventedParent(this,{layer:{id:i}}),this._serializedLayers[a.id]=a.serialize()}var o=r?this._order.indexOf(r):this._order.length;if(r&&-1===o)this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.')));else{if(this._order.splice(o,0,i),this._layerOrderChanged=!0,this._layers[i]=a,this._removedLayers[i]&&a.source&&\"custom\"!==a.type){var s=this._removedLayers[i];delete this._removedLayers[i],s.type!==a.type?this._updatedSources[a.source]=\"clear\":(this._updatedSources[a.source]=\"reload\",this.sourceCaches[a.source].pause())}this._updateLayer(a),a.onAdd&&a.onAdd(this.map)}}},r.prototype.moveLayer=function(e,r){if(this._checkLoaded(),this._changed=!0,this._layers[e]){if(e!==r){var n=this._order.indexOf(e);this._order.splice(n,1);var i=r?this._order.indexOf(r):this._order.length;r&&-1===i?this.fire(new t.ErrorEvent(new Error('Layer with id \"'+r+'\" does not exist on this map.'))):(this._order.splice(i,0,e),this._layerOrderChanged=!0)}}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be moved.\")))},r.prototype.removeLayer=function(e){this._checkLoaded();var r=this._layers[e];if(r){r.setEventedParent(null);var n=this._order.indexOf(e);this._order.splice(n,1),this._layerOrderChanged=!0,this._changed=!0,this._removedLayers[e]=r,delete this._layers[e],delete this._serializedLayers[e],delete this._updatedLayers[e],delete this._updatedPaintProps[e],r.onRemove&&r.onRemove(this.map)}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be removed.\")))},r.prototype.getLayer=function(t){return this._layers[t]},r.prototype.hasLayer=function(t){return t in this._layers},r.prototype.setLayerZoomRange=function(e,r,n){this._checkLoaded();var i=this.getLayer(e);i?i.minzoom===r&&i.maxzoom===n||(null!=r&&(i.minzoom=r),null!=n&&(i.maxzoom=n),this._updateLayer(i)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot have zoom extent.\")))},r.prototype.setFilter=function(e,r,n){void 0===n&&(n={}),this._checkLoaded();var i=this.getLayer(e);if(i){if(!t.deepEqual(i.filter,r))return null==r?(i.filter=void 0,void this._updateLayer(i)):void(this._validate(t.validateStyle.filter,\"layers.\"+i.id+\".filter\",r,null,n)||(i.filter=t.clone$1(r),this._updateLayer(i)))}else this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be filtered.\")))},r.prototype.getFilter=function(e){return t.clone$1(this.getLayer(e).filter)},r.prototype.setLayoutProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getLayoutProperty(r),n)||(a.setLayoutProperty(r,n,i),this._updateLayer(a)):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getLayoutProperty=function(e,r){var n=this.getLayer(e);if(n)return n.getLayoutProperty(r);this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style.\")))},r.prototype.setPaintProperty=function(e,r,n,i){void 0===i&&(i={}),this._checkLoaded();var a=this.getLayer(e);a?t.deepEqual(a.getPaintProperty(r),n)||(a.setPaintProperty(r,n,i)&&this._updateLayer(a),this._changed=!0,this._updatedPaintProps[e]=!0):this.fire(new t.ErrorEvent(new Error(\"The layer '\"+e+\"' does not exist in the map's style and cannot be styled.\")))},r.prototype.getPaintProperty=function(t,e){return this.getLayer(t).getPaintProperty(e)},r.prototype.setFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=e.sourceLayer,a=this.sourceCaches[n];if(void 0!==a){var o=a.getSource().type;\"geojson\"===o&&i?this.fire(new t.ErrorEvent(new Error(\"GeoJSON sources cannot have a sourceLayer parameter.\"))):\"vector\"!==o||i?(void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),a.setFeatureState(i,e.id,r)):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.removeFeatureState=function(e,r){this._checkLoaded();var n=e.source,i=this.sourceCaches[n];if(void 0!==i){var a=i.getSource().type,o=\"vector\"===a?e.sourceLayer:void 0;\"vector\"!==a||o?r&&\"string\"!=typeof e.id&&\"number\"!=typeof e.id?this.fire(new t.ErrorEvent(new Error(\"A feature id is requred to remove its specific state property.\"))):i.removeFeatureState(o,e.id,r):this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+n+\"' does not exist in the map's style.\")))},r.prototype.getFeatureState=function(e){this._checkLoaded();var r=e.source,n=e.sourceLayer,i=this.sourceCaches[r];if(void 0!==i){if(\"vector\"!==i.getSource().type||n)return void 0===e.id&&this.fire(new t.ErrorEvent(new Error(\"The feature id parameter must be provided.\"))),i.getFeatureState(n,e.id);this.fire(new t.ErrorEvent(new Error(\"The sourceLayer parameter must be provided for vector source types.\")))}else this.fire(new t.ErrorEvent(new Error(\"The source '\"+r+\"' does not exist in the map's style.\")))},r.prototype.getTransition=function(){return t.extend({duration:300,delay:0},this.stylesheet&&this.stylesheet.transition)},r.prototype.serialize=function(){return t.filterObject({version:this.stylesheet.version,name:this.stylesheet.name,metadata:this.stylesheet.metadata,light:this.stylesheet.light,center:this.stylesheet.center,zoom:this.stylesheet.zoom,bearing:this.stylesheet.bearing,pitch:this.stylesheet.pitch,sprite:this.stylesheet.sprite,glyphs:this.stylesheet.glyphs,transition:this.stylesheet.transition,sources:t.mapObject(this.sourceCaches,(function(t){return t.serialize()})),layers:this._serializeLayers(this._order)},(function(t){return void 0!==t}))},r.prototype._updateLayer=function(t){this._updatedLayers[t.id]=!0,t.source&&!this._updatedSources[t.source]&&\"raster\"!==this.sourceCaches[t.source].getSource().type&&(this._updatedSources[t.source]=\"reload\",this.sourceCaches[t.source].pause()),this._changed=!0},r.prototype._flattenAndSortRenderedFeatures=function(t){for(var e=this,r=function(t){return\"fill-extrusion\"===e._layers[t].type},n={},i=[],a=this._order.length-1;a>=0;a--){var o=this._order[a];if(r(o)){n[o]=a;for(var s=0,l=t;s<l.length;s+=1){var c=l[s][o];if(c)for(var u=0,f=c;u<f.length;u+=1)i.push(f[u])}}}i.sort((function(t,e){return e.intersectionZ-t.intersectionZ}));for(var h=[],p=this._order.length-1;p>=0;p--){var d=this._order[p];if(r(d))for(var g=i.length-1;g>=0;g--){var m=i[g].feature;if(n[m.layer.id]<p)break;h.push(m),i.pop()}else for(var v=0,y=t;v<y.length;v+=1){var x=y[v][d];if(x)for(var b=0,_=x;b<_.length;b+=1)h.push(_[b].feature)}}return h},r.prototype.queryRenderedFeatures=function(e,r,n){r&&r.filter&&this._validate(t.validateStyle.filter,\"queryRenderedFeatures.filter\",r.filter,null,r);var i={};if(r&&r.layers){if(!Array.isArray(r.layers))return this.fire(new t.ErrorEvent(new Error(\"parameters.layers must be an Array.\"))),[];for(var a=0,o=r.layers;a<o.length;a+=1){var s=o[a],l=this._layers[s];if(!l)return this.fire(new t.ErrorEvent(new Error(\"The layer '\"+s+\"' does not exist in the map's style and cannot be queried for features.\"))),[];i[l.source]=!0}}var c=[];for(var u in r.availableImages=this._availableImages,this.sourceCaches)r.layers&&!i[u]||c.push(F(this.sourceCaches[u],this._layers,this._serializedLayers,e,r,n));return this.placement&&c.push(function(t,e,r,n,i,a,o){for(var s={},l=a.queryRenderedSymbols(n),c=[],u=0,f=Object.keys(l).map(Number);u<f.length;u+=1)c.push(o[f[u]]);c.sort(B);for(var h=function(){var r=d[p],n=r.featureIndex.lookupSymbolFeatures(l[r.bucketInstanceId],e,r.bucketIndex,r.sourceLayerIndex,i.filter,i.layers,i.availableImages,t);for(var a in n){var o=s[a]=s[a]||[],c=n[a];c.sort((function(t,e){var n=r.featureSortOrder;if(n){var i=n.indexOf(t.featureIndex);return n.indexOf(e.featureIndex)-i}return e.featureIndex-t.featureIndex}));for(var u=0,f=c;u<f.length;u+=1)o.push(f[u])}},p=0,d=c;p<d.length;p+=1)h();var g=function(e){s[e].forEach((function(n){var i=n.feature,a=r[t[e].source].getFeatureState(i.layer[\"source-layer\"],i.id);i.source=i.layer.source,i.layer[\"source-layer\"]&&(i.sourceLayer=i.layer[\"source-layer\"]),i.state=a}))};for(var m in s)g(m);return s}(this._layers,this._serializedLayers,this.sourceCaches,e,r,this.placement.collisionIndex,this.placement.retainedQueryData)),this._flattenAndSortRenderedFeatures(c)},r.prototype.querySourceFeatures=function(e,r){r&&r.filter&&this._validate(t.validateStyle.filter,\"querySourceFeatures.filter\",r.filter,null,r);var n=this.sourceCaches[e];return n?function(t,e){for(var r=t.getRenderableIds().map((function(e){return t.getTileByID(e)})),n=[],i={},a=0;a<r.length;a++){var o=r[a],s=o.tileID.canonical.key;i[s]||(i[s]=!0,o.querySourceFeatures(n,e))}return n}(n,r):[]},r.prototype.addSourceType=function(t,e,n){return r.getSourceType(t)?n(new Error('A source type called \"'+t+'\" already exists.')):(r.setSourceType(t,e),e.workerSourceURL?void this.dispatcher.broadcast(\"loadWorkerSource\",{name:t,url:e.workerSourceURL},n):n(null,null))},r.prototype.getLight=function(){return this.light.getLight()},r.prototype.setLight=function(e,r){void 0===r&&(r={}),this._checkLoaded();var n=this.light.getLight(),i=!1;for(var a in e)if(!t.deepEqual(e[a],n[a])){i=!0;break}if(i){var o={now:t.browser.now(),transition:t.extend({duration:300,delay:0},this.stylesheet.transition)};this.light.setLight(e,r),this.light.updateTransitions(o)}},r.prototype._validate=function(e,r,n,i,a){return void 0===a&&(a={}),(!a||!1!==a.validate)&&Ne(this,e.call(t.validateStyle,t.extend({key:r,style:this.serialize(),value:n,styleSpec:t.styleSpec},i)))},r.prototype._remove=function(){for(var e in this._request&&(this._request.cancel(),this._request=null),this._spriteRequest&&(this._spriteRequest.cancel(),this._spriteRequest=null),t.evented.off(\"pluginStateChange\",this._rtlTextPluginCallback),this._layers)this._layers[e].setEventedParent(null);for(var r in this.sourceCaches)this.sourceCaches[r].clearTiles(),this.sourceCaches[r].setEventedParent(null);this.imageManager.setEventedParent(null),this.setEventedParent(null),this.dispatcher.remove()},r.prototype._clearSource=function(t){this.sourceCaches[t].clearTiles()},r.prototype._reloadSource=function(t){this.sourceCaches[t].resume(),this.sourceCaches[t].reload()},r.prototype._updateSources=function(t){for(var e in this.sourceCaches)this.sourceCaches[e].update(t)},r.prototype._generateCollisionBoxes=function(){for(var t in this.sourceCaches)this._reloadSource(t)},r.prototype._updatePlacement=function(e,r,n,i,a){void 0===a&&(a=!1);for(var o=!1,s=!1,l={},c=0,u=this._order;c<u.length;c+=1){var f=this._layers[u[c]];if(\"symbol\"===f.type){if(!l[f.source]){var h=this.sourceCaches[f.source];l[f.source]=h.getRenderableIds(!0).map((function(t){return h.getTileByID(t)})).sort((function(t,e){return e.tileID.overscaledZ-t.tileID.overscaledZ||(t.tileID.isLessThan(e.tileID)?-1:1)}))}var p=this.crossTileSymbolIndex.addLayer(f,l[f.source],e.center.lng);o=o||p}}if(this.crossTileSymbolIndex.pruneUnusedLayers(this._order),((a=a||this._layerOrderChanged||0===n)||!this.pauseablePlacement||this.pauseablePlacement.isDone()&&!this.placement.stillRecent(t.browser.now(),e.zoom))&&(this.pauseablePlacement=new ze(e,this._order,a,r,n,i,this.placement),this._layerOrderChanged=!1),this.pauseablePlacement.isDone()?this.placement.setStale():(this.pauseablePlacement.continuePlacement(this._order,this._layers,l),this.pauseablePlacement.isDone()&&(this.placement=this.pauseablePlacement.commit(t.browser.now()),s=!0),o&&this.pauseablePlacement.placement.setStale()),s||o)for(var d=0,g=this._order;d<g.length;d+=1){var m=this._layers[g[d]];\"symbol\"===m.type&&this.placement.updateLayerOpacities(m,l[m.source])}return!this.pauseablePlacement.isDone()||this.placement.hasTransitions(t.browser.now())},r.prototype._releaseSymbolFadeTiles=function(){for(var t in this.sourceCaches)this.sourceCaches[t].releaseSymbolFadeTiles()},r.prototype.getImages=function(t,e,r){this.imageManager.getImages(e.icons,r),this._updateTilesForChangedImages();var n=this.sourceCaches[e.source];n&&n.setDependencies(e.tileID.key,e.type,e.icons)},r.prototype.getGlyphs=function(t,e,r){this.glyphManager.getGlyphs(e.stacks,r)},r.prototype.getResource=function(e,r,n){return t.makeRequest(r,n)},r}(t.Evented);qe.getSourceType=function(t){return D[t]},qe.setSourceType=function(t,e){D[t]=e},qe.registerForPluginStateChange=t.registerForPluginStateChange;var He=t.createLayout([{name:\"a_pos\",type:\"Int16\",components:2}]),Ge=vr(\"#ifdef GL_ES\\nprecision mediump float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\",\"#ifdef GL_ES\\nprecision highp float;\\n#else\\n#if !defined(lowp)\\n#define lowp\\n#endif\\n#if !defined(mediump)\\n#define mediump\\n#endif\\n#if !defined(highp)\\n#define highp\\n#endif\\n#endif\\nvec2 unpack_float(const float packedValue) {int packedIntValue=int(packedValue);int v0=packedIntValue/256;return vec2(v0,packedIntValue-v0*256);}vec2 unpack_opacity(const float packedOpacity) {int intOpacity=int(packedOpacity)/2;return vec2(float(intOpacity)/127.0,mod(packedOpacity,2.0));}vec4 decode_color(const vec2 encodedColor) {return vec4(unpack_float(encodedColor[0])/255.0,unpack_float(encodedColor[1])/255.0\\n);}float unpack_mix_vec2(const vec2 packedValue,const float t) {return mix(packedValue[0],packedValue[1],t);}vec4 unpack_mix_color(const vec4 packedColors,const float t) {vec4 minColor=decode_color(vec2(packedColors[0],packedColors[1]));vec4 maxColor=decode_color(vec2(packedColors[2],packedColors[3]));return mix(minColor,maxColor,t);}vec2 get_pattern_pos(const vec2 pixel_coord_upper,const vec2 pixel_coord_lower,const vec2 pattern_size,const float tile_units_to_pixels,const vec2 pos) {vec2 offset=mod(mod(mod(pixel_coord_upper,pattern_size)*256.0,pattern_size)*256.0+pixel_coord_lower,pattern_size);return (tile_units_to_pixels*pos+offset)/pattern_size;}\"),Ye=vr(\"uniform vec4 u_color;uniform float u_opacity;void main() {gl_FragColor=u_color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),We=vr(\"uniform vec2 u_pattern_tl_a;uniform vec2 u_pattern_br_a;uniform vec2 u_pattern_tl_b;uniform vec2 u_pattern_br_b;uniform vec2 u_texsize;uniform float u_mix;uniform float u_opacity;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(u_pattern_tl_a/u_texsize,u_pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(u_pattern_tl_b/u_texsize,u_pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_mix)*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pattern_size_a;uniform vec2 u_pattern_size_b;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_scale_a;uniform float u_scale_b;uniform float u_tile_units_to_pixels;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_a*u_pattern_size_a,u_tile_units_to_pixels,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,u_scale_b*u_pattern_size_b,u_tile_units_to_pixels,a_pos);}\"),Xe=vr(\"varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=v_data.xy;float extrude_length=length(extrude);lowp float antialiasblur=v_data.z;float antialiased_blur=-max(blur,antialiasblur);float opacity_t=smoothstep(0.0,antialiased_blur,extrude_length-1.0);float color_t=stroke_width < 0.01 ? 0.0 : smoothstep(antialiased_blur,0.0,extrude_length-radius/(radius+stroke_width));gl_FragColor=opacity_t*mix(color*opacity,stroke_color*stroke_opacity,color_t);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform bool u_scale_with_map;uniform bool u_pitch_with_map;uniform vec2 u_extrude_scale;uniform lowp float u_device_pixel_ratio;uniform highp float u_camera_to_center_distance;attribute vec2 a_pos;varying vec3 v_data;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define mediump float radius\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define highp vec4 stroke_color\\n#pragma mapbox: define mediump float stroke_width\\n#pragma mapbox: define lowp float stroke_opacity\\nvoid main(void) {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize mediump float radius\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize highp vec4 stroke_color\\n#pragma mapbox: initialize mediump float stroke_width\\n#pragma mapbox: initialize lowp float stroke_opacity\\nvec2 extrude=vec2(mod(a_pos,2.0)*2.0-1.0);vec2 circle_center=floor(a_pos*0.5);if (u_pitch_with_map) {vec2 corner_position=circle_center;if (u_scale_with_map) {corner_position+=extrude*(radius+stroke_width)*u_extrude_scale;} else {vec4 projected_center=u_matrix*vec4(circle_center,0,1);corner_position+=extrude*(radius+stroke_width)*u_extrude_scale*(projected_center.w/u_camera_to_center_distance);}gl_Position=u_matrix*vec4(corner_position,0,1);} else {gl_Position=u_matrix*vec4(circle_center,0,1);if (u_scale_with_map) {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*u_camera_to_center_distance;} else {gl_Position.xy+=extrude*(radius+stroke_width)*u_extrude_scale*gl_Position.w;}}lowp float antialiasblur=1.0/u_device_pixel_ratio/(radius+stroke_width);v_data=vec3(extrude.x,extrude.y,antialiasblur);}\"),Ze=vr(\"void main() {gl_FragColor=vec4(1.0);}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);}\"),Je=vr(\"uniform highp float u_intensity;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main() {\\n#pragma mapbox: initialize highp float weight\\nfloat d=-0.5*3.0*3.0*dot(v_extrude,v_extrude);float val=weight*u_intensity*GAUSS_COEF*exp(d);gl_FragColor=vec4(val,1.0,1.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform float u_extrude_scale;uniform float u_opacity;uniform float u_intensity;attribute vec2 a_pos;varying vec2 v_extrude;\\n#pragma mapbox: define highp float weight\\n#pragma mapbox: define mediump float radius\\nconst highp float ZERO=1.0/255.0/16.0;\\n#define GAUSS_COEF 0.3989422804014327\\nvoid main(void) {\\n#pragma mapbox: initialize highp float weight\\n#pragma mapbox: initialize mediump float radius\\nvec2 unscaled_extrude=vec2(mod(a_pos,2.0)*2.0-1.0);float S=sqrt(-2.0*log(ZERO/weight/u_intensity/GAUSS_COEF))/3.0;v_extrude=S*unscaled_extrude;vec2 extrude=v_extrude*radius*u_extrude_scale;vec4 pos=vec4(floor(a_pos*0.5)+extrude,0,1);gl_Position=u_matrix*pos;}\"),Ke=vr(\"uniform sampler2D u_image;uniform sampler2D u_color_ramp;uniform float u_opacity;varying vec2 v_pos;void main() {float t=texture2D(u_image,v_pos).r;vec4 color=texture2D(u_color_ramp,vec2(t,0.5));gl_FragColor=color*u_opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(0.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;attribute vec2 a_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos*u_world,0,1);v_pos.x=a_pos.x;v_pos.y=1.0-a_pos.y;}\"),Qe=vr(\"varying float v_placed;varying float v_notUsed;void main() {float alpha=0.5;gl_FragColor=vec4(1.0,0.0,0.0,1.0)*alpha;if (v_placed > 0.5) {gl_FragColor=vec4(0.0,0.0,1.0,0.5)*alpha;}if (v_notUsed > 0.5) {gl_FragColor*=.1;}}\",\"attribute vec2 a_pos;attribute vec2 a_anchor_pos;attribute vec2 a_extrude;attribute vec2 a_placed;attribute vec2 a_shift;uniform mat4 u_matrix;uniform vec2 u_extrude_scale;uniform float u_camera_to_center_distance;varying float v_placed;varying float v_notUsed;void main() {vec4 projectedPoint=u_matrix*vec4(a_anchor_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);gl_Position=u_matrix*vec4(a_pos,0.0,1.0);gl_Position.xy+=(a_extrude+a_shift)*u_extrude_scale*gl_Position.w*collision_perspective_ratio;v_placed=a_placed.x;v_notUsed=a_placed.y;}\"),$e=vr(\"varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;void main() {float alpha=0.5*min(v_perspective_ratio,1.0);float stroke_radius=0.9*max(v_perspective_ratio,1.0);float distance_to_center=length(v_extrude);float distance_to_edge=abs(distance_to_center-v_radius);float opacity_t=smoothstep(-stroke_radius,0.0,-distance_to_edge);vec4 color=mix(vec4(0.0,0.0,1.0,0.5),vec4(1.0,0.0,0.0,1.0),v_collision);gl_FragColor=color*alpha*opacity_t;}\",\"attribute vec2 a_pos;attribute float a_radius;attribute vec2 a_flags;uniform mat4 u_matrix;uniform mat4 u_inv_matrix;uniform vec2 u_viewport_size;uniform float u_camera_to_center_distance;varying float v_radius;varying vec2 v_extrude;varying float v_perspective_ratio;varying float v_collision;vec3 toTilePosition(vec2 screenPos) {vec4 rayStart=u_inv_matrix*vec4(screenPos,-1.0,1.0);vec4 rayEnd  =u_inv_matrix*vec4(screenPos, 1.0,1.0);rayStart.xyz/=rayStart.w;rayEnd.xyz  /=rayEnd.w;highp float t=(0.0-rayStart.z)/(rayEnd.z-rayStart.z);return mix(rayStart.xyz,rayEnd.xyz,t);}void main() {vec2 quadCenterPos=a_pos;float radius=a_radius;float collision=a_flags.x;float vertexIdx=a_flags.y;vec2 quadVertexOffset=vec2(mix(-1.0,1.0,float(vertexIdx >=2.0)),mix(-1.0,1.0,float(vertexIdx >=1.0 && vertexIdx <=2.0)));vec2 quadVertexExtent=quadVertexOffset*radius;vec3 tilePos=toTilePosition(quadCenterPos);vec4 clipPos=u_matrix*vec4(tilePos,1.0);highp float camera_to_anchor_distance=clipPos.w;highp float collision_perspective_ratio=clamp(0.5+0.5*(u_camera_to_center_distance/camera_to_anchor_distance),0.0,4.0);float padding_factor=1.2;v_radius=radius;v_extrude=quadVertexExtent*padding_factor;v_perspective_ratio=collision_perspective_ratio;v_collision=collision;gl_Position=vec4(clipPos.xyz/clipPos.w,1.0)+vec4(quadVertexExtent*padding_factor/u_viewport_size*2.0,0.0,0.0);}\"),tr=vr(\"uniform highp vec4 u_color;uniform sampler2D u_overlay;varying vec2 v_uv;void main() {vec4 overlay_color=texture2D(u_overlay,v_uv);gl_FragColor=mix(u_color,overlay_color,overlay_color.a);}\",\"attribute vec2 a_pos;varying vec2 v_uv;uniform mat4 u_matrix;uniform float u_overlay_scale;void main() {v_uv=a_pos/8192.0;gl_Position=u_matrix*vec4(a_pos*u_overlay_scale,0,1);}\"),er=vr(\"#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_FragColor=color*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);}\"),rr=vr(\"varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=outline_color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"attribute vec2 a_pos;uniform mat4 u_matrix;uniform vec2 u_world;varying vec2 v_pos;\\n#pragma mapbox: define highp vec4 outline_color\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 outline_color\\n#pragma mapbox: initialize lowp float opacity\\ngl_Position=u_matrix*vec4(a_pos,0,1);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),nr=vr(\"uniform vec2 u_texsize;uniform sampler2D u_image;uniform float u_fade;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);float dist=length(v_pos-gl_FragCoord.xy);float alpha=1.0-smoothstep(0.0,1.0,dist);gl_FragColor=mix(color1,color2,u_fade)*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_world;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec2 v_pos;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;gl_Position=u_matrix*vec4(a_pos,0,1);vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,a_pos);v_pos=(gl_Position.xy/gl_Position.w+1.0)/2.0*u_world;}\"),ir=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);gl_FragColor=mix(color1,color2,u_fade)*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform vec3 u_scale;attribute vec2 a_pos;varying vec2 v_pos_a;varying vec2 v_pos_b;\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;gl_Position=u_matrix*vec4(a_pos,0,1);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileZoomRatio,a_pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileZoomRatio,a_pos);}\"),ar=vr(\"varying vec4 v_color;void main() {gl_FragColor=v_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;uniform float u_vertical_gradient;uniform lowp float u_opacity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec4 v_color;\\n#pragma mapbox: define highp float base\\n#pragma mapbox: define highp float height\\n#pragma mapbox: define highp vec4 color\\nvoid main() {\\n#pragma mapbox: initialize highp float base\\n#pragma mapbox: initialize highp float height\\n#pragma mapbox: initialize highp vec4 color\\nvec3 normal=a_normal_ed.xyz;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);gl_Position=u_matrix*vec4(a_pos,t > 0.0 ? height : base,1);float colorvalue=color.r*0.2126+color.g*0.7152+color.b*0.0722;v_color=vec4(0.0,0.0,0.0,1.0);vec4 ambientlight=vec4(0.03,0.03,0.03,1.0);color+=ambientlight;float directional=clamp(dot(normal/16384.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((1.0-colorvalue+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_color.r+=clamp(color.r*directional*u_lightcolor.r,mix(0.0,0.3,1.0-u_lightcolor.r),1.0);v_color.g+=clamp(color.g*directional*u_lightcolor.g,mix(0.0,0.3,1.0-u_lightcolor.g),1.0);v_color.b+=clamp(color.b*directional*u_lightcolor.b,mix(0.0,0.3,1.0-u_lightcolor.b),1.0);v_color*=u_opacity;}\"),or=vr(\"uniform vec2 u_texsize;uniform float u_fade;uniform sampler2D u_image;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;vec2 imagecoord=mod(v_pos_a,1.0);vec2 pos=mix(pattern_tl_a/u_texsize,pattern_br_a/u_texsize,imagecoord);vec4 color1=texture2D(u_image,pos);vec2 imagecoord_b=mod(v_pos_b,1.0);vec2 pos2=mix(pattern_tl_b/u_texsize,pattern_br_b/u_texsize,imagecoord_b);vec4 color2=texture2D(u_image,pos2);vec4 mixedColor=mix(color1,color2,u_fade);gl_FragColor=mixedColor*v_lighting;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_pixel_coord_upper;uniform vec2 u_pixel_coord_lower;uniform float u_height_factor;uniform vec3 u_scale;uniform float u_vertical_gradient;uniform lowp float u_opacity;uniform vec3 u_lightcolor;uniform lowp vec3 u_lightpos;uniform lowp float u_lightintensity;attribute vec2 a_pos;attribute vec4 a_normal_ed;varying vec2 v_pos_a;varying vec2 v_pos_b;varying vec4 v_lighting;\\n#pragma mapbox: define lowp float base\\n#pragma mapbox: define lowp float height\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float base\\n#pragma mapbox: initialize lowp float height\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec3 normal=a_normal_ed.xyz;float edgedistance=a_normal_ed.w;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;base=max(0.0,base);height=max(0.0,height);float t=mod(normal.x,2.0);float z=t > 0.0 ? height : base;gl_Position=u_matrix*vec4(a_pos,z,1);vec2 pos=normal.x==1.0 && normal.y==0.0 && normal.z==16384.0\\n? a_pos\\n: vec2(edgedistance,z*u_height_factor);v_pos_a=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,fromScale*display_size_a,tileRatio,pos);v_pos_b=get_pattern_pos(u_pixel_coord_upper,u_pixel_coord_lower,toScale*display_size_b,tileRatio,pos);v_lighting=vec4(0.0,0.0,0.0,1.0);float directional=clamp(dot(normal/16383.0,u_lightpos),0.0,1.0);directional=mix((1.0-u_lightintensity),max((0.5+u_lightintensity),1.0),directional);if (normal.y !=0.0) {directional*=((1.0-u_vertical_gradient)+(u_vertical_gradient*clamp((t+base)*pow(height/150.0,0.5),mix(0.7,0.98,1.0-u_lightintensity),1.0)));}v_lighting.rgb+=clamp(directional*u_lightcolor,mix(vec3(0.0),vec3(0.3),1.0-u_lightcolor),vec3(1.0));v_lighting*=u_opacity;}\"),sr=vr(\"#ifdef GL_ES\\nprecision highp float;\\n#endif\\nuniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_dimension;uniform float u_zoom;uniform float u_maxzoom;uniform vec4 u_unpack;float getElevation(vec2 coord,float bias) {vec4 data=texture2D(u_image,coord)*255.0;data.a=-1.0;return dot(data,u_unpack)/4.0;}void main() {vec2 epsilon=1.0/u_dimension;float a=getElevation(v_pos+vec2(-epsilon.x,-epsilon.y),0.0);float b=getElevation(v_pos+vec2(0,-epsilon.y),0.0);float c=getElevation(v_pos+vec2(epsilon.x,-epsilon.y),0.0);float d=getElevation(v_pos+vec2(-epsilon.x,0),0.0);float e=getElevation(v_pos,0.0);float f=getElevation(v_pos+vec2(epsilon.x,0),0.0);float g=getElevation(v_pos+vec2(-epsilon.x,epsilon.y),0.0);float h=getElevation(v_pos+vec2(0,epsilon.y),0.0);float i=getElevation(v_pos+vec2(epsilon.x,epsilon.y),0.0);float exaggeration=u_zoom < 2.0 ? 0.4 : u_zoom < 4.5 ? 0.35 : 0.3;vec2 deriv=vec2((c+f+f+i)-(a+d+d+g),(g+h+h+i)-(a+b+b+c))/ pow(2.0,(u_zoom-u_maxzoom)*exaggeration+19.2562-u_zoom);gl_FragColor=clamp(vec4(deriv.x/2.0+0.5,deriv.y/2.0+0.5,1.0,1.0),0.0,1.0);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_dimension;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);highp vec2 epsilon=1.0/u_dimension;float scale=(u_dimension.x-2.0)/u_dimension.x;v_pos=(a_texture_pos/8192.0)*scale+epsilon;}\"),lr=vr(\"uniform sampler2D u_image;varying vec2 v_pos;uniform vec2 u_latrange;uniform vec2 u_light;uniform vec4 u_shadow;uniform vec4 u_highlight;uniform vec4 u_accent;\\n#define PI 3.141592653589793\\nvoid main() {vec4 pixel=texture2D(u_image,v_pos);vec2 deriv=((pixel.rg*2.0)-1.0);float scaleFactor=cos(radians((u_latrange[0]-u_latrange[1])*(1.0-v_pos.y)+u_latrange[1]));float slope=atan(1.25*length(deriv)/scaleFactor);float aspect=deriv.x !=0.0 ? atan(deriv.y,-deriv.x) : PI/2.0*(deriv.y > 0.0 ? 1.0 :-1.0);float intensity=u_light.x;float azimuth=u_light.y+PI;float base=1.875-intensity*1.75;float maxValue=0.5*PI;float scaledSlope=intensity !=0.5 ? ((pow(base,slope)-1.0)/(pow(base,maxValue)-1.0))*maxValue : slope;float accent=cos(scaledSlope);vec4 accent_color=(1.0-accent)*u_accent*clamp(intensity*2.0,0.0,1.0);float shade=abs(mod((aspect+azimuth)/PI+0.5,2.0)-1.0);vec4 shade_color=mix(u_shadow,u_highlight,shade)*sin(scaledSlope)*clamp(intensity*2.0,0.0,1.0);gl_FragColor=accent_color*(1.0-shade_color.a)+shade_color;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos=a_texture_pos/8192.0;}\"),cr=vr(\"uniform lowp float u_device_pixel_ratio;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform vec2 u_units_to_pixels;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_linesofar;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),ur=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;varying vec2 v_width2;varying vec2 v_normal;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);vec4 color=texture2D(u_image,vec2(v_lineprogress,0.5));gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define MAX_LINE_DISTANCE 32767.0\\n#define scale 0.015873016\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying float v_gamma_scale;varying highp float v_lineprogress;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;v_lineprogress=(floor(a_data.z/4.0)+a_data.w*64.0)*2.0/MAX_LINE_DISTANCE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_width2=vec2(outset,inset);}\"),fr=vr(\"uniform lowp float u_device_pixel_ratio;uniform vec2 u_texsize;uniform float u_fade;uniform mediump vec3 u_scale;uniform sampler2D u_image;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\nvec2 pattern_tl_a=pattern_from.xy;vec2 pattern_br_a=pattern_from.zw;vec2 pattern_tl_b=pattern_to.xy;vec2 pattern_br_b=pattern_to.zw;float tileZoomRatio=u_scale.x;float fromScale=u_scale.y;float toScale=u_scale.z;vec2 display_size_a=(pattern_br_a-pattern_tl_a)/pixel_ratio_from;vec2 display_size_b=(pattern_br_b-pattern_tl_b)/pixel_ratio_to;vec2 pattern_size_a=vec2(display_size_a.x*fromScale/tileZoomRatio,display_size_a.y);vec2 pattern_size_b=vec2(display_size_b.x*toScale/tileZoomRatio,display_size_b.y);float aspect_a=display_size_a.y/v_width;float aspect_b=display_size_b.y/v_width;float dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float x_a=mod(v_linesofar/pattern_size_a.x*aspect_a,1.0);float x_b=mod(v_linesofar/pattern_size_b.x*aspect_b,1.0);float y=0.5*v_normal.y+0.5;vec2 texel_size=1.0/u_texsize;vec2 pos_a=mix(pattern_tl_a*texel_size-texel_size,pattern_br_a*texel_size+texel_size,vec2(x_a,y));vec2 pos_b=mix(pattern_tl_b*texel_size-texel_size,pattern_br_b*texel_size+texel_size,vec2(x_b,y));vec4 color=mix(texture2D(u_image,pos_a),texture2D(u_image,pos_b),u_fade);gl_FragColor=color*alpha*opacity;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform vec2 u_units_to_pixels;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;varying vec2 v_normal;varying vec2 v_width2;varying float v_linesofar;varying float v_gamma_scale;varying float v_width;\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\n#pragma mapbox: define lowp vec4 pattern_from\\n#pragma mapbox: define lowp vec4 pattern_to\\n#pragma mapbox: define lowp float pixel_ratio_from\\n#pragma mapbox: define lowp float pixel_ratio_to\\nvoid main() {\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\n#pragma mapbox: initialize mediump vec4 pattern_from\\n#pragma mapbox: initialize mediump vec4 pattern_to\\n#pragma mapbox: initialize lowp float pixel_ratio_from\\n#pragma mapbox: initialize lowp float pixel_ratio_to\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_linesofar=a_linesofar;v_width2=vec2(outset,inset);v_width=floorwidth;}\"),hr=vr(\"uniform lowp float u_device_pixel_ratio;uniform sampler2D u_image;uniform float u_sdfgamma;uniform float u_mix;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat dist=length(v_normal)*v_width2.s;float blur2=(blur+1.0/u_device_pixel_ratio)*v_gamma_scale;float alpha=clamp(min(dist-(v_width2.t-blur2),v_width2.s-dist)/blur2,0.0,1.0);float sdfdist_a=texture2D(u_image,v_tex_a).a;float sdfdist_b=texture2D(u_image,v_tex_b).a;float sdfdist=mix(sdfdist_a,sdfdist_b,u_mix);alpha*=smoothstep(0.5-u_sdfgamma/floorwidth,0.5+u_sdfgamma/floorwidth,sdfdist);gl_FragColor=color*(alpha*opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"\\n#define scale 0.015873016\\n#define LINE_DISTANCE_SCALE 2.0\\nattribute vec2 a_pos_normal;attribute vec4 a_data;uniform mat4 u_matrix;uniform mediump float u_ratio;uniform lowp float u_device_pixel_ratio;uniform vec2 u_patternscale_a;uniform float u_tex_y_a;uniform vec2 u_patternscale_b;uniform float u_tex_y_b;uniform vec2 u_units_to_pixels;varying vec2 v_normal;varying vec2 v_width2;varying vec2 v_tex_a;varying vec2 v_tex_b;varying float v_gamma_scale;\\n#pragma mapbox: define highp vec4 color\\n#pragma mapbox: define lowp float blur\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define mediump float gapwidth\\n#pragma mapbox: define lowp float offset\\n#pragma mapbox: define mediump float width\\n#pragma mapbox: define lowp float floorwidth\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 color\\n#pragma mapbox: initialize lowp float blur\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize mediump float gapwidth\\n#pragma mapbox: initialize lowp float offset\\n#pragma mapbox: initialize mediump float width\\n#pragma mapbox: initialize lowp float floorwidth\\nfloat ANTIALIASING=1.0/u_device_pixel_ratio/2.0;vec2 a_extrude=a_data.xy-128.0;float a_direction=mod(a_data.z,4.0)-1.0;float a_linesofar=(floor(a_data.z/4.0)+a_data.w*64.0)*LINE_DISTANCE_SCALE;vec2 pos=floor(a_pos_normal*0.5);mediump vec2 normal=a_pos_normal-2.0*pos;normal.y=normal.y*2.0-1.0;v_normal=normal;gapwidth=gapwidth/2.0;float halfwidth=width/2.0;offset=-1.0*offset;float inset=gapwidth+(gapwidth > 0.0 ? ANTIALIASING : 0.0);float outset=gapwidth+halfwidth*(gapwidth > 0.0 ? 2.0 : 1.0)+(halfwidth==0.0 ? 0.0 : ANTIALIASING);mediump vec2 dist=outset*a_extrude*scale;mediump float u=0.5*a_direction;mediump float t=1.0-abs(u);mediump vec2 offset2=offset*a_extrude*scale*normal.y*mat2(t,-u,u,t);vec4 projected_extrude=u_matrix*vec4(dist/u_ratio,0.0,0.0);gl_Position=u_matrix*vec4(pos+offset2/u_ratio,0.0,1.0)+projected_extrude;float extrude_length_without_perspective=length(dist);float extrude_length_with_perspective=length(projected_extrude.xy/gl_Position.w*u_units_to_pixels);v_gamma_scale=extrude_length_without_perspective/extrude_length_with_perspective;v_tex_a=vec2(a_linesofar*u_patternscale_a.x/floorwidth,normal.y*u_patternscale_a.y+u_tex_y_a);v_tex_b=vec2(a_linesofar*u_patternscale_b.x/floorwidth,normal.y*u_patternscale_b.y+u_tex_y_b);v_width2=vec2(outset,inset);}\"),pr=vr(\"uniform float u_fade_t;uniform float u_opacity;uniform sampler2D u_image0;uniform sampler2D u_image1;varying vec2 v_pos0;varying vec2 v_pos1;uniform float u_brightness_low;uniform float u_brightness_high;uniform float u_saturation_factor;uniform float u_contrast_factor;uniform vec3 u_spin_weights;void main() {vec4 color0=texture2D(u_image0,v_pos0);vec4 color1=texture2D(u_image1,v_pos1);if (color0.a > 0.0) {color0.rgb=color0.rgb/color0.a;}if (color1.a > 0.0) {color1.rgb=color1.rgb/color1.a;}vec4 color=mix(color0,color1,u_fade_t);color.a*=u_opacity;vec3 rgb=color.rgb;rgb=vec3(dot(rgb,u_spin_weights.xyz),dot(rgb,u_spin_weights.zxy),dot(rgb,u_spin_weights.yzx));float average=(color.r+color.g+color.b)/3.0;rgb+=(average-rgb)*u_saturation_factor;rgb=(rgb-0.5)*u_contrast_factor+0.5;vec3 u_high_vec=vec3(u_brightness_low,u_brightness_low,u_brightness_low);vec3 u_low_vec=vec3(u_brightness_high,u_brightness_high,u_brightness_high);gl_FragColor=vec4(mix(u_high_vec,u_low_vec,rgb)*color.a,color.a);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"uniform mat4 u_matrix;uniform vec2 u_tl_parent;uniform float u_scale_parent;uniform float u_buffer_scale;attribute vec2 a_pos;attribute vec2 a_texture_pos;varying vec2 v_pos0;varying vec2 v_pos1;void main() {gl_Position=u_matrix*vec4(a_pos,0,1);v_pos0=(((a_texture_pos/8192.0)-0.5)/u_buffer_scale )+0.5;v_pos1=(v_pos0*u_scale_parent)+u_tl_parent;}\"),dr=vr(\"uniform sampler2D u_texture;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nlowp float alpha=opacity*v_fade_opacity;gl_FragColor=texture2D(u_texture,v_tex)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform highp float u_camera_to_center_distance;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform float u_fade_change;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform vec2 u_texsize;varying vec2 v_tex;varying float v_fade_opacity;\\n#pragma mapbox: define lowp float opacity\\nvoid main() {\\n#pragma mapbox: initialize lowp float opacity\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;vec2 a_minFontScale=a_pixeloffset.zw/256.0;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*max(a_minFontScale,fontScale)+a_pxoffset/16.0),0.0,1.0);v_tex=a_tex/u_texsize;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;v_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));}\"),gr=vr(\"#define SDF_PX 8.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;uniform bool u_is_text;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat EDGE_GAMMA=0.105/u_device_pixel_ratio;vec2 tex=v_data0.xy;float gamma_scale=v_data1.x;float size=v_data1.y;float fade_opacity=v_data1[2];float fontScale=u_is_text ? size/24.0 : size;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec4 a_pixeloffset;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;varying vec2 v_data0;varying vec3 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);vec2 a_pxoffset=a_pixeloffset.xy;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=u_is_text ? size/24.0 : size;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale+a_pxoffset),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0=a_tex/u_texsize;v_data1=vec3(gamma_scale,size,interpolated_fade_opacity);}\"),mr=vr(\"#define SDF_PX 8.0\\n#define SDF 1.0\\n#define ICON 0.0\\nuniform bool u_is_halo;uniform sampler2D u_texture;uniform sampler2D u_texture_icon;uniform highp float u_gamma_scale;uniform lowp float u_device_pixel_ratio;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nfloat fade_opacity=v_data1[2];if (v_data1.w==ICON) {vec2 tex_icon=v_data0.zw;lowp float alpha=opacity*fade_opacity;gl_FragColor=texture2D(u_texture_icon,tex_icon)*alpha;\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\nreturn;}vec2 tex=v_data0.xy;float EDGE_GAMMA=0.105/u_device_pixel_ratio;float gamma_scale=v_data1.x;float size=v_data1.y;float fontScale=size/24.0;lowp vec4 color=fill_color;highp float gamma=EDGE_GAMMA/(fontScale*u_gamma_scale);lowp float buff=(256.0-64.0)/256.0;if (u_is_halo) {color=halo_color;gamma=(halo_blur*1.19/SDF_PX+EDGE_GAMMA)/(fontScale*u_gamma_scale);buff=(6.0-halo_width/fontScale)/SDF_PX;}lowp float dist=texture2D(u_texture,tex).a;highp float gamma_scaled=gamma*gamma_scale;highp float alpha=smoothstep(buff-gamma_scaled,buff+gamma_scaled,dist);gl_FragColor=color*(alpha*opacity*fade_opacity);\\n#ifdef OVERDRAW_INSPECTOR\\ngl_FragColor=vec4(1.0);\\n#endif\\n}\",\"const float PI=3.141592653589793;attribute vec4 a_pos_offset;attribute vec4 a_data;attribute vec3 a_projected_pos;attribute float a_fade_opacity;uniform bool u_is_size_zoom_constant;uniform bool u_is_size_feature_constant;uniform highp float u_size_t;uniform highp float u_size;uniform mat4 u_matrix;uniform mat4 u_label_plane_matrix;uniform mat4 u_coord_matrix;uniform bool u_is_text;uniform bool u_pitch_with_map;uniform highp float u_pitch;uniform bool u_rotate_symbol;uniform highp float u_aspect_ratio;uniform highp float u_camera_to_center_distance;uniform float u_fade_change;uniform vec2 u_texsize;uniform vec2 u_texsize_icon;varying vec4 v_data0;varying vec4 v_data1;\\n#pragma mapbox: define highp vec4 fill_color\\n#pragma mapbox: define highp vec4 halo_color\\n#pragma mapbox: define lowp float opacity\\n#pragma mapbox: define lowp float halo_width\\n#pragma mapbox: define lowp float halo_blur\\nvoid main() {\\n#pragma mapbox: initialize highp vec4 fill_color\\n#pragma mapbox: initialize highp vec4 halo_color\\n#pragma mapbox: initialize lowp float opacity\\n#pragma mapbox: initialize lowp float halo_width\\n#pragma mapbox: initialize lowp float halo_blur\\nvec2 a_pos=a_pos_offset.xy;vec2 a_offset=a_pos_offset.zw;vec2 a_tex=a_data.xy;vec2 a_size=a_data.zw;float a_size_min=floor(a_size[0]*0.5);float is_sdf=a_size[0]-2.0*a_size_min;highp float segment_angle=-a_projected_pos[2];float size;if (!u_is_size_zoom_constant && !u_is_size_feature_constant) {size=mix(a_size_min,a_size[1],u_size_t)/128.0;} else if (u_is_size_zoom_constant && !u_is_size_feature_constant) {size=a_size_min/128.0;} else {size=u_size;}vec4 projectedPoint=u_matrix*vec4(a_pos,0,1);highp float camera_to_anchor_distance=projectedPoint.w;highp float distance_ratio=u_pitch_with_map ?\\ncamera_to_anchor_distance/u_camera_to_center_distance :\\nu_camera_to_center_distance/camera_to_anchor_distance;highp float perspective_ratio=clamp(0.5+0.5*distance_ratio,0.0,4.0);size*=perspective_ratio;float fontScale=size/24.0;highp float symbol_rotation=0.0;if (u_rotate_symbol) {vec4 offsetProjectedPoint=u_matrix*vec4(a_pos+vec2(1,0),0,1);vec2 a=projectedPoint.xy/projectedPoint.w;vec2 b=offsetProjectedPoint.xy/offsetProjectedPoint.w;symbol_rotation=atan((b.y-a.y)/u_aspect_ratio,b.x-a.x);}highp float angle_sin=sin(segment_angle+symbol_rotation);highp float angle_cos=cos(segment_angle+symbol_rotation);mat2 rotation_matrix=mat2(angle_cos,-1.0*angle_sin,angle_sin,angle_cos);vec4 projected_pos=u_label_plane_matrix*vec4(a_projected_pos.xy,0.0,1.0);gl_Position=u_coord_matrix*vec4(projected_pos.xy/projected_pos.w+rotation_matrix*(a_offset/32.0*fontScale),0.0,1.0);float gamma_scale=gl_Position.w;vec2 fade_opacity=unpack_opacity(a_fade_opacity);float fade_change=fade_opacity[1] > 0.5 ? u_fade_change :-u_fade_change;float interpolated_fade_opacity=max(0.0,min(1.0,fade_opacity[0]+fade_change));v_data0.xy=a_tex/u_texsize;v_data0.zw=a_tex/u_texsize_icon;v_data1=vec4(gamma_scale,size,interpolated_fade_opacity,is_sdf);}\");function vr(t,e){var r=/#pragma mapbox: ([\\w]+) ([\\w]+) ([\\w]+) ([\\w]+)/g,n={};return{fragmentSource:t=t.replace(r,(function(t,e,r,i,a){return n[a]=!0,\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"\\n#ifdef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"})),vertexSource:e=e.replace(r,(function(t,e,r,i,a){var o=\"float\"===i?\"vec2\":\"vec4\",s=a.match(/color/)?\"color\":o;return n[a]?\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\nvarying \"+r+\" \"+i+\" \"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"define\"===e?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\nuniform lowp float u_\"+a+\"_t;\\nattribute \"+r+\" \"+o+\" a_\"+a+\";\\n#else\\nuniform \"+r+\" \"+i+\" u_\"+a+\";\\n#endif\\n\":\"vec4\"===s?\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = a_\"+a+\";\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\":\"\\n#ifndef HAS_UNIFORM_u_\"+a+\"\\n    \"+r+\" \"+i+\" \"+a+\" = unpack_mix_\"+s+\"(a_\"+a+\", u_\"+a+\"_t);\\n#else\\n    \"+r+\" \"+i+\" \"+a+\" = u_\"+a+\";\\n#endif\\n\"}))}}var yr=Object.freeze({__proto__:null,prelude:Ge,background:Ye,backgroundPattern:We,circle:Xe,clippingMask:Ze,heatmap:Je,heatmapTexture:Ke,collisionBox:Qe,collisionCircle:$e,debug:tr,fill:er,fillOutline:rr,fillOutlinePattern:nr,fillPattern:ir,fillExtrusion:ar,fillExtrusionPattern:or,hillshadePrepare:sr,hillshade:lr,line:cr,lineGradient:ur,linePattern:fr,lineSDF:hr,raster:pr,symbolIcon:dr,symbolSDF:gr,symbolTextAndIcon:mr}),xr=function(){this.boundProgram=null,this.boundLayoutVertexBuffer=null,this.boundPaintVertexBuffers=[],this.boundIndexBuffer=null,this.boundVertexOffset=null,this.boundDynamicVertexBuffer=null,this.vao=null};xr.prototype.bind=function(t,e,r,n,i,a,o,s){this.context=t;for(var l=this.boundPaintVertexBuffers.length!==n.length,c=0;!l&&c<n.length;c++)this.boundPaintVertexBuffers[c]!==n[c]&&(l=!0);t.extVertexArrayObject&&this.vao&&this.boundProgram===e&&this.boundLayoutVertexBuffer===r&&!l&&this.boundIndexBuffer===i&&this.boundVertexOffset===a&&this.boundDynamicVertexBuffer===o&&this.boundDynamicVertexBuffer2===s?(t.bindVertexArrayOES.set(this.vao),o&&o.bind(),i&&i.dynamicDraw&&i.bind(),s&&s.bind()):this.freshBind(e,r,n,i,a,o,s)},xr.prototype.freshBind=function(t,e,r,n,i,a,o){var s,l=t.numAttributes,c=this.context,u=c.gl;if(c.extVertexArrayObject)this.vao&&this.destroy(),this.vao=c.extVertexArrayObject.createVertexArrayOES(),c.bindVertexArrayOES.set(this.vao),s=0,this.boundProgram=t,this.boundLayoutVertexBuffer=e,this.boundPaintVertexBuffers=r,this.boundIndexBuffer=n,this.boundVertexOffset=i,this.boundDynamicVertexBuffer=a,this.boundDynamicVertexBuffer2=o;else{s=c.currentNumAttributes||0;for(var f=l;f<s;f++)u.disableVertexAttribArray(f)}e.enableAttributes(u,t);for(var h=0,p=r;h<p.length;h+=1)p[h].enableAttributes(u,t);a&&a.enableAttributes(u,t),o&&o.enableAttributes(u,t),e.bind(),e.setVertexAttribPointers(u,t,i);for(var d=0,g=r;d<g.length;d+=1){var m=g[d];m.bind(),m.setVertexAttribPointers(u,t,i)}a&&(a.bind(),a.setVertexAttribPointers(u,t,i)),n&&n.bind(),o&&(o.bind(),o.setVertexAttribPointers(u,t,i)),c.currentNumAttributes=l},xr.prototype.destroy=function(){this.vao&&(this.context.extVertexArrayObject.deleteVertexArrayOES(this.vao),this.vao=null)};var br=function(t,e,r,n,i){var a=t.gl;this.program=a.createProgram();var o=r?r.defines():[];i&&o.push(\"#define OVERDRAW_INSPECTOR;\");var s=o.concat(Ge.fragmentSource,e.fragmentSource).join(\"\\n\"),l=o.concat(Ge.vertexSource,e.vertexSource).join(\"\\n\"),c=a.createShader(a.FRAGMENT_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(c,s),a.compileShader(c),a.attachShader(this.program,c);var u=a.createShader(a.VERTEX_SHADER);if(a.isContextLost())this.failedToCreate=!0;else{a.shaderSource(u,l),a.compileShader(u),a.attachShader(this.program,u);for(var f=r?r.layoutAttributes:[],h=0;h<f.length;h++)a.bindAttribLocation(this.program,h,f[h].name);a.linkProgram(this.program),a.deleteShader(u),a.deleteShader(c),this.numAttributes=a.getProgramParameter(this.program,a.ACTIVE_ATTRIBUTES),this.attributes={};for(var p={},d=0;d<this.numAttributes;d++){var g=a.getActiveAttrib(this.program,d);g&&(this.attributes[g.name]=a.getAttribLocation(this.program,g.name))}for(var m=a.getProgramParameter(this.program,a.ACTIVE_UNIFORMS),v=0;v<m;v++){var y=a.getActiveUniform(this.program,v);y&&(p[y.name]=a.getUniformLocation(this.program,y.name))}this.fixedUniforms=n(t,p),this.binderUniforms=r?r.getUniforms(t,p):[]}}};function _r(t,e,r){var n=1/he(r,1,e.transform.tileZoom),i=Math.pow(2,r.tileID.overscaledZ),a=r.tileSize*Math.pow(2,e.transform.tileZoom)/i,o=a*(r.tileID.canonical.x+r.tileID.wrap*i),s=a*r.tileID.canonical.y;return{u_image:0,u_texsize:r.imageAtlasTexture.size,u_scale:[n,t.fromScale,t.toScale],u_fade:t.t,u_pixel_coord_upper:[o>>16,s>>16],u_pixel_coord_lower:[65535&o,65535&s]}}br.prototype.draw=function(t,e,r,n,i,a,o,s,l,c,u,f,h,p,d,g){var m,v=t.gl;if(!this.failedToCreate){for(var y in t.program.set(this.program),t.setDepthMode(r),t.setStencilMode(n),t.setColorMode(i),t.setCullFace(a),this.fixedUniforms)this.fixedUniforms[y].set(o[y]);p&&p.setUniforms(t,this.binderUniforms,f,{zoom:h});for(var x=(m={},m[v.LINES]=2,m[v.TRIANGLES]=3,m[v.LINE_STRIP]=1,m)[e],b=0,_=u.get();b<_.length;b+=1){var w=_[b],T=w.vaos||(w.vaos={});(T[s]||(T[s]=new xr)).bind(t,this,l,p?p.getPaintVertexBuffers():[],c,w.vertexOffset,d,g),v.drawElements(e,w.primitiveLength*x,v.UNSIGNED_SHORT,w.primitiveOffset*x*2)}}};var wr=function(e,r,n,i){var a=r.style.light,o=a.properties.get(\"position\"),s=[o.x,o.y,o.z],l=t.create$1();\"viewport\"===a.properties.get(\"anchor\")&&t.fromRotation(l,-r.transform.angle),t.transformMat3(s,s,l);var c=a.properties.get(\"color\");return{u_matrix:e,u_lightpos:s,u_lightintensity:a.properties.get(\"intensity\"),u_lightcolor:[c.r,c.g,c.b],u_vertical_gradient:+n,u_opacity:i}},Tr=function(e,r,n,i,a,o,s){return t.extend(wr(e,r,n,i),_r(o,r,s),{u_height_factor:-Math.pow(2,a.overscaledZ)/s.tileSize/8})},kr=function(t){return{u_matrix:t}},Mr=function(e,r,n,i){return t.extend(kr(e),_r(n,r,i))},Ar=function(t,e){return{u_matrix:t,u_world:e}},Sr=function(e,r,n,i,a){return t.extend(Mr(e,r,n,i),{u_world:a})},Er=function(e,r,n,i){var a,o,s=e.transform;if(\"map\"===i.paint.get(\"circle-pitch-alignment\")){var l=he(n,1,s.zoom);a=!0,o=[l,l]}else a=!1,o=s.pixelsToGLUnits;return{u_camera_to_center_distance:s.cameraToCenterDistance,u_scale_with_map:+(\"map\"===i.paint.get(\"circle-pitch-scale\")),u_matrix:e.translatePosMatrix(r.posMatrix,n,i.paint.get(\"circle-translate\"),i.paint.get(\"circle-translate-anchor\")),u_pitch_with_map:+a,u_device_pixel_ratio:t.browser.devicePixelRatio,u_extrude_scale:o}},Cr=function(t,e,r){var n=he(r,1,e.zoom),i=Math.pow(2,e.zoom-r.tileID.overscaledZ),a=r.tileID.overscaleFactor();return{u_matrix:t,u_camera_to_center_distance:e.cameraToCenterDistance,u_pixels_to_tile_units:n,u_extrude_scale:[e.pixelsToGLUnits[0]/(n*i),e.pixelsToGLUnits[1]/(n*i)],u_overscale_factor:a}},Lr=function(t,e,r){return{u_matrix:t,u_inv_matrix:e,u_camera_to_center_distance:r.cameraToCenterDistance,u_viewport_size:[r.width,r.height]}},Ir=function(t,e,r){return void 0===r&&(r=1),{u_matrix:t,u_color:e,u_overlay:0,u_overlay_scale:r}},Pr=function(t){return{u_matrix:t}},zr=function(t,e,r,n){return{u_matrix:t,u_extrude_scale:he(e,1,r),u_intensity:n}},Or=function(e,r,n){var i=e.transform;return{u_matrix:Nr(e,r,n),u_ratio:1/he(r,1,i.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_units_to_pixels:[1/i.pixelsToGLUnits[0],1/i.pixelsToGLUnits[1]]}},Dr=function(e,r,n){return t.extend(Or(e,r,n),{u_image:0})},Rr=function(e,r,n,i){var a=e.transform,o=Br(r,a);return{u_matrix:Nr(e,r,n),u_texsize:r.imageAtlasTexture.size,u_ratio:1/he(r,1,a.zoom),u_device_pixel_ratio:t.browser.devicePixelRatio,u_image:0,u_scale:[o,i.fromScale,i.toScale],u_fade:i.t,u_units_to_pixels:[1/a.pixelsToGLUnits[0],1/a.pixelsToGLUnits[1]]}},Fr=function(e,r,n,i,a){var o=e.lineAtlas,s=Br(r,e.transform),l=\"round\"===n.layout.get(\"line-cap\"),c=o.getDash(i.from,l),u=o.getDash(i.to,l),f=c.width*a.fromScale,h=u.width*a.toScale;return t.extend(Or(e,r,n),{u_patternscale_a:[s/f,-c.height/2],u_patternscale_b:[s/h,-u.height/2],u_sdfgamma:o.width/(256*Math.min(f,h)*t.browser.devicePixelRatio)/2,u_image:0,u_tex_y_a:c.y,u_tex_y_b:u.y,u_mix:a.t})};function Br(t,e){return 1/he(t,1,e.tileZoom)}function Nr(t,e,r){return t.translatePosMatrix(e.tileID.posMatrix,e,r.paint.get(\"line-translate\"),r.paint.get(\"line-translate-anchor\"))}var jr=function(t,e,r,n,i){return{u_matrix:t,u_tl_parent:e,u_scale_parent:r,u_buffer_scale:1,u_fade_t:n.mix,u_opacity:n.opacity*i.paint.get(\"raster-opacity\"),u_image0:0,u_image1:1,u_brightness_low:i.paint.get(\"raster-brightness-min\"),u_brightness_high:i.paint.get(\"raster-brightness-max\"),u_saturation_factor:(o=i.paint.get(\"raster-saturation\"),o>0?1-1/(1.001-o):-o),u_contrast_factor:(a=i.paint.get(\"raster-contrast\"),a>0?1/(1-a):1+a),u_spin_weights:Ur(i.paint.get(\"raster-hue-rotate\"))};var a,o};function Ur(t){t*=Math.PI/180;var e=Math.sin(t),r=Math.cos(t);return[(2*r+1)/3,(-Math.sqrt(3)*e-r+1)/3,(Math.sqrt(3)*e-r+1)/3]}var Vr,qr=function(t,e,r,n,i,a,o,s,l,c){var u=i.transform;return{u_is_size_zoom_constant:+(\"constant\"===t||\"source\"===t),u_is_size_feature_constant:+(\"constant\"===t||\"camera\"===t),u_size_t:e?e.uSizeT:0,u_size:e?e.uSize:0,u_camera_to_center_distance:u.cameraToCenterDistance,u_pitch:u.pitch/360*2*Math.PI,u_rotate_symbol:+r,u_aspect_ratio:u.width/u.height,u_fade_change:i.options.fadeDuration?i.symbolFadeChange:1,u_matrix:a,u_label_plane_matrix:o,u_coord_matrix:s,u_is_text:+l,u_pitch_with_map:+n,u_texsize:c,u_texture:0}},Hr=function(e,r,n,i,a,o,s,l,c,u,f){var h=a.transform;return t.extend(qr(e,r,n,i,a,o,s,l,c,u),{u_gamma_scale:i?Math.cos(h._pitch)*h.cameraToCenterDistance:1,u_device_pixel_ratio:t.browser.devicePixelRatio,u_is_halo:+f})},Gr=function(e,r,n,i,a,o,s,l,c,u){return t.extend(Hr(e,r,n,i,a,o,s,l,!0,c,!0),{u_texsize_icon:u,u_texture_icon:1})},Yr=function(t,e,r){return{u_matrix:t,u_opacity:e,u_color:r}},Wr=function(e,r,n,i,a,o){return t.extend(function(t,e,r,n){var i=r.imageManager.getPattern(t.from.toString()),a=r.imageManager.getPattern(t.to.toString()),o=r.imageManager.getPixelSize(),s=o.width,l=o.height,c=Math.pow(2,n.tileID.overscaledZ),u=n.tileSize*Math.pow(2,r.transform.tileZoom)/c,f=u*(n.tileID.canonical.x+n.tileID.wrap*c),h=u*n.tileID.canonical.y;return{u_image:0,u_pattern_tl_a:i.tl,u_pattern_br_a:i.br,u_pattern_tl_b:a.tl,u_pattern_br_b:a.br,u_texsize:[s,l],u_mix:e.t,u_pattern_size_a:i.displaySize,u_pattern_size_b:a.displaySize,u_scale_a:e.fromScale,u_scale_b:e.toScale,u_tile_units_to_pixels:1/he(n,1,r.transform.tileZoom),u_pixel_coord_upper:[f>>16,h>>16],u_pixel_coord_lower:[65535&f,65535&h]}}(i,o,n,a),{u_matrix:e,u_opacity:r})},Xr={fillExtrusion:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fillExtrusionPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_lightpos:new t.Uniform3f(e,r.u_lightpos),u_lightintensity:new t.Uniform1f(e,r.u_lightintensity),u_lightcolor:new t.Uniform3f(e,r.u_lightcolor),u_vertical_gradient:new t.Uniform1f(e,r.u_vertical_gradient),u_height_factor:new t.Uniform1f(e,r.u_height_factor),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade),u_opacity:new t.Uniform1f(e,r.u_opacity)}},fill:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},fillPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},fillOutline:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world)}},fillOutlinePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_texsize:new t.Uniform2f(e,r.u_texsize),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},circle:function(e,r){return{u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_scale_with_map:new t.Uniform1i(e,r.u_scale_with_map),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},collisionBox:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pixels_to_tile_units:new t.Uniform1f(e,r.u_pixels_to_tile_units),u_extrude_scale:new t.Uniform2f(e,r.u_extrude_scale),u_overscale_factor:new t.Uniform1f(e,r.u_overscale_factor)}},collisionCircle:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_inv_matrix:new t.UniformMatrix4f(e,r.u_inv_matrix),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_viewport_size:new t.Uniform2f(e,r.u_viewport_size)}},debug:function(e,r){return{u_color:new t.UniformColor(e,r.u_color),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_overlay:new t.Uniform1i(e,r.u_overlay),u_overlay_scale:new t.Uniform1f(e,r.u_overlay_scale)}},clippingMask:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmap:function(e,r){return{u_extrude_scale:new t.Uniform1f(e,r.u_extrude_scale),u_intensity:new t.Uniform1f(e,r.u_intensity),u_matrix:new t.UniformMatrix4f(e,r.u_matrix)}},heatmapTexture:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_world:new t.Uniform2f(e,r.u_world),u_image:new t.Uniform1i(e,r.u_image),u_color_ramp:new t.Uniform1i(e,r.u_color_ramp),u_opacity:new t.Uniform1f(e,r.u_opacity)}},hillshade:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_latrange:new t.Uniform2f(e,r.u_latrange),u_light:new t.Uniform2f(e,r.u_light),u_shadow:new t.UniformColor(e,r.u_shadow),u_highlight:new t.UniformColor(e,r.u_highlight),u_accent:new t.UniformColor(e,r.u_accent)}},hillshadePrepare:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_image:new t.Uniform1i(e,r.u_image),u_dimension:new t.Uniform2f(e,r.u_dimension),u_zoom:new t.Uniform1f(e,r.u_zoom),u_maxzoom:new t.Uniform1f(e,r.u_maxzoom),u_unpack:new t.Uniform4f(e,r.u_unpack)}},line:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels)}},lineGradient:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_image:new t.Uniform1i(e,r.u_image)}},linePattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_texsize:new t.Uniform2f(e,r.u_texsize),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_image:new t.Uniform1i(e,r.u_image),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_scale:new t.Uniform3f(e,r.u_scale),u_fade:new t.Uniform1f(e,r.u_fade)}},lineSDF:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_ratio:new t.Uniform1f(e,r.u_ratio),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_units_to_pixels:new t.Uniform2f(e,r.u_units_to_pixels),u_patternscale_a:new t.Uniform2f(e,r.u_patternscale_a),u_patternscale_b:new t.Uniform2f(e,r.u_patternscale_b),u_sdfgamma:new t.Uniform1f(e,r.u_sdfgamma),u_image:new t.Uniform1i(e,r.u_image),u_tex_y_a:new t.Uniform1f(e,r.u_tex_y_a),u_tex_y_b:new t.Uniform1f(e,r.u_tex_y_b),u_mix:new t.Uniform1f(e,r.u_mix)}},raster:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_tl_parent:new t.Uniform2f(e,r.u_tl_parent),u_scale_parent:new t.Uniform1f(e,r.u_scale_parent),u_buffer_scale:new t.Uniform1f(e,r.u_buffer_scale),u_fade_t:new t.Uniform1f(e,r.u_fade_t),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image0:new t.Uniform1i(e,r.u_image0),u_image1:new t.Uniform1i(e,r.u_image1),u_brightness_low:new t.Uniform1f(e,r.u_brightness_low),u_brightness_high:new t.Uniform1f(e,r.u_brightness_high),u_saturation_factor:new t.Uniform1f(e,r.u_saturation_factor),u_contrast_factor:new t.Uniform1f(e,r.u_contrast_factor),u_spin_weights:new t.Uniform3f(e,r.u_spin_weights)}},symbolIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture)}},symbolSDF:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texture:new t.Uniform1i(e,r.u_texture),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},symbolTextAndIcon:function(e,r){return{u_is_size_zoom_constant:new t.Uniform1i(e,r.u_is_size_zoom_constant),u_is_size_feature_constant:new t.Uniform1i(e,r.u_is_size_feature_constant),u_size_t:new t.Uniform1f(e,r.u_size_t),u_size:new t.Uniform1f(e,r.u_size),u_camera_to_center_distance:new t.Uniform1f(e,r.u_camera_to_center_distance),u_pitch:new t.Uniform1f(e,r.u_pitch),u_rotate_symbol:new t.Uniform1i(e,r.u_rotate_symbol),u_aspect_ratio:new t.Uniform1f(e,r.u_aspect_ratio),u_fade_change:new t.Uniform1f(e,r.u_fade_change),u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_label_plane_matrix:new t.UniformMatrix4f(e,r.u_label_plane_matrix),u_coord_matrix:new t.UniformMatrix4f(e,r.u_coord_matrix),u_is_text:new t.Uniform1i(e,r.u_is_text),u_pitch_with_map:new t.Uniform1i(e,r.u_pitch_with_map),u_texsize:new t.Uniform2f(e,r.u_texsize),u_texsize_icon:new t.Uniform2f(e,r.u_texsize_icon),u_texture:new t.Uniform1i(e,r.u_texture),u_texture_icon:new t.Uniform1i(e,r.u_texture_icon),u_gamma_scale:new t.Uniform1f(e,r.u_gamma_scale),u_device_pixel_ratio:new t.Uniform1f(e,r.u_device_pixel_ratio),u_is_halo:new t.Uniform1i(e,r.u_is_halo)}},background:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_color:new t.UniformColor(e,r.u_color)}},backgroundPattern:function(e,r){return{u_matrix:new t.UniformMatrix4f(e,r.u_matrix),u_opacity:new t.Uniform1f(e,r.u_opacity),u_image:new t.Uniform1i(e,r.u_image),u_pattern_tl_a:new t.Uniform2f(e,r.u_pattern_tl_a),u_pattern_br_a:new t.Uniform2f(e,r.u_pattern_br_a),u_pattern_tl_b:new t.Uniform2f(e,r.u_pattern_tl_b),u_pattern_br_b:new t.Uniform2f(e,r.u_pattern_br_b),u_texsize:new t.Uniform2f(e,r.u_texsize),u_mix:new t.Uniform1f(e,r.u_mix),u_pattern_size_a:new t.Uniform2f(e,r.u_pattern_size_a),u_pattern_size_b:new t.Uniform2f(e,r.u_pattern_size_b),u_scale_a:new t.Uniform1f(e,r.u_scale_a),u_scale_b:new t.Uniform1f(e,r.u_scale_b),u_pixel_coord_upper:new t.Uniform2f(e,r.u_pixel_coord_upper),u_pixel_coord_lower:new t.Uniform2f(e,r.u_pixel_coord_lower),u_tile_units_to_pixels:new t.Uniform1f(e,r.u_tile_units_to_pixels)}}};function Zr(e,r,n,i,a,o,s){for(var l=e.context,c=l.gl,u=e.useProgram(\"collisionBox\"),f=[],h=0,p=0,d=0;d<i.length;d++){var g=i[d],m=r.getTile(g),v=m.getBucket(n);if(v){var y=g.posMatrix;0===a[0]&&0===a[1]||(y=e.translatePosMatrix(g.posMatrix,m,a,o));var x=s?v.textCollisionBox:v.iconCollisionBox,b=v.collisionCircleArray;if(b.length>0){var _=t.create(),w=y;t.mul(_,v.placementInvProjMatrix,e.transform.glCoordMatrix),t.mul(_,_,v.placementViewportMatrix),f.push({circleArray:b,circleOffset:p,transform:w,invTransform:_}),p=h+=b.length/4}x&&u.draw(l,c.LINES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,Cr(y,e.transform,m),n.id,x.layoutVertexBuffer,x.indexBuffer,x.segments,null,e.transform.zoom,null,null,x.collisionVertexBuffer)}}if(s&&f.length){var T=e.useProgram(\"collisionCircle\"),k=new t.StructArrayLayout2f1f2i16;k.resize(4*h),k._trim();for(var M=0,A=0,S=f;A<S.length;A+=1)for(var E=S[A],C=0;C<E.circleArray.length/4;C++){var L=4*C,I=E.circleArray[L+0],P=E.circleArray[L+1],z=E.circleArray[L+2],O=E.circleArray[L+3];k.emplace(M++,I,P,z,O,0),k.emplace(M++,I,P,z,O,1),k.emplace(M++,I,P,z,O,2),k.emplace(M++,I,P,z,O,3)}(!Vr||Vr.length<2*h)&&(Vr=function(e){var r=2*e,n=new t.StructArrayLayout3ui6;n.resize(r),n._trim();for(var i=0;i<r;i++){var a=6*i;n.uint16[a+0]=4*i+0,n.uint16[a+1]=4*i+1,n.uint16[a+2]=4*i+2,n.uint16[a+3]=4*i+2,n.uint16[a+4]=4*i+3,n.uint16[a+5]=4*i+0}return n}(h));for(var D=l.createIndexBuffer(Vr,!0),R=l.createVertexBuffer(k,t.collisionCircleLayout.members,!0),F=0,B=f;F<B.length;F+=1){var N=B[F],j=Lr(N.transform,N.invTransform,e.transform);T.draw(l,c.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,j,n.id,R,D,t.SegmentVector.simpleSegment(0,2*N.circleOffset,N.circleArray.length,N.circleArray.length/2),null,e.transform.zoom,null,null,null)}R.destroy(),D.destroy()}}var Jr=t.identity(new Float32Array(16));function Kr(e,r,n,i,a,o){var s=t.getAnchorAlignment(e),l=-(s.horizontalAlign-.5)*r,c=-(s.verticalAlign-.5)*n,u=t.evaluateVariableOffset(e,i);return new t.Point((l/a+u[0])*o,(c/a+u[1])*o)}function Qr(e,r,n,i,a,o,s,l,c,u,f){var h=e.text.placedSymbolArray,p=e.text.dynamicLayoutVertexArray,d=e.icon.dynamicLayoutVertexArray,g={};p.clear();for(var m=0;m<h.length;m++){var v=h.get(m),y=v.hidden||!v.crossTileID||e.allowVerticalPlacement&&!v.placedOrientation?null:i[v.crossTileID];if(y){var x=new t.Point(v.anchorX,v.anchorY),b=$t(x,n?l:s),_=te(o.cameraToCenterDistance,b.signedDistanceFromCamera),w=a.evaluateSizeForFeature(e.textSizeData,u,v)*_/t.ONE_EM;n&&(w*=e.tilePixelRatio/c);for(var T=Kr(y.anchor,y.width,y.height,y.textOffset,y.textBoxScale,w),k=n?$t(x.add(T),s).point:b.point.add(r?T.rotate(-o.angle):T),M=e.allowVerticalPlacement&&v.placedOrientation===t.WritingMode.vertical?Math.PI/2:0,A=0;A<v.numGlyphs;A++)t.addDynamicAttributes(p,k,M);f&&v.associatedIconIndex>=0&&(g[v.associatedIconIndex]={shiftedAnchor:k,angle:M})}else ce(v.numGlyphs,p)}if(f){d.clear();for(var S=e.icon.placedSymbolArray,E=0;E<S.length;E++){var C=S.get(E);if(C.hidden)ce(C.numGlyphs,d);else{var L=g[E];if(L)for(var I=0;I<C.numGlyphs;I++)t.addDynamicAttributes(d,L.shiftedAnchor,L.angle);else ce(C.numGlyphs,d)}}e.icon.dynamicLayoutVertexBuffer.updateData(d)}e.text.dynamicLayoutVertexBuffer.updateData(p)}function $r(t,e,r){return r.iconsInText&&e?\"symbolTextAndIcon\":t?\"symbolSDF\":\"symbolIcon\"}function tn(e,r,n,i,a,o,s,l,c,u,f,h){for(var p=e.context,d=p.gl,g=e.transform,m=\"map\"===l,v=\"map\"===c,y=m&&\"point\"!==n.layout.get(\"symbol-placement\"),x=m&&!v&&!y,b=void 0!==n.layout.get(\"symbol-sort-key\").constantOr(1),_=e.depthModeForSublayer(0,Mt.ReadOnly),w=n.layout.get(\"text-variable-anchor\"),T=[],k=0,M=i;k<M.length;k+=1){var A=M[k],S=r.getTile(A),E=S.getBucket(n);if(E){var C=a?E.text:E.icon;if(C&&C.segments.get().length){var L=C.programConfigurations.get(n.id),I=a||E.sdfIcons,P=a?E.textSizeData:E.iconSizeData,z=v||0!==g.pitch,O=e.useProgram($r(I,a,E),L),D=t.evaluateSizeForZoom(P,g.zoom),R=void 0,F=[0,0],B=void 0,N=void 0,j=null,U=void 0;if(a)B=S.glyphAtlasTexture,N=d.LINEAR,R=S.glyphAtlasTexture.size,E.iconsInText&&(F=S.imageAtlasTexture.size,j=S.imageAtlasTexture,U=z||e.options.rotating||e.options.zooming||\"composite\"===P.kind||\"camera\"===P.kind?d.LINEAR:d.NEAREST);else{var V=1!==n.layout.get(\"icon-size\").constantOr(0)||E.iconsNeedLinear;B=S.imageAtlasTexture,N=I||e.options.rotating||e.options.zooming||V||z?d.LINEAR:d.NEAREST,R=S.imageAtlasTexture.size}var q=he(S,1,e.transform.zoom),H=Kt(A.posMatrix,v,m,e.transform,q),G=Qt(A.posMatrix,v,m,e.transform,q),Y=w&&E.hasTextData(),W=\"none\"!==n.layout.get(\"icon-text-fit\")&&Y&&E.hasIconData();y&&re(E,A.posMatrix,e,a,H,G,v,u);var X=e.translatePosMatrix(A.posMatrix,S,o,s),Z=y||a&&w||W?Jr:H,J=e.translatePosMatrix(G,S,o,s,!0),K=I&&0!==n.paint.get(a?\"text-halo-width\":\"icon-halo-width\").constantOr(1),Q={program:O,buffers:C,uniformValues:I?E.iconsInText?Gr(P.kind,D,x,v,e,X,Z,J,R,F):Hr(P.kind,D,x,v,e,X,Z,J,a,R,!0):qr(P.kind,D,x,v,e,X,Z,J,a,R),atlasTexture:B,atlasTextureIcon:j,atlasInterpolation:N,atlasInterpolationIcon:U,isSDF:I,hasHalo:K};if(b)for(var $=0,tt=C.segments.get();$<tt.length;$+=1){var et=tt[$];T.push({segments:new t.SegmentVector([et]),sortKey:et.sortKey,state:Q})}else T.push({segments:C.segments,sortKey:0,state:Q})}}}b&&T.sort((function(t,e){return t.sortKey-e.sortKey}));for(var rt=0,nt=T;rt<nt.length;rt+=1){var it=nt[rt],at=it.state;if(p.activeTexture.set(d.TEXTURE0),at.atlasTexture.bind(at.atlasInterpolation,d.CLAMP_TO_EDGE),at.atlasTextureIcon&&(p.activeTexture.set(d.TEXTURE1),at.atlasTextureIcon&&at.atlasTextureIcon.bind(at.atlasInterpolationIcon,d.CLAMP_TO_EDGE)),at.isSDF){var ot=at.uniformValues;at.hasHalo&&(ot.u_is_halo=1,en(at.buffers,it.segments,n,e,at.program,_,f,h,ot)),ot.u_is_halo=0}en(at.buffers,it.segments,n,e,at.program,_,f,h,at.uniformValues)}}function en(t,e,r,n,i,a,o,s,l){var c=n.context;i.draw(c,c.gl.TRIANGLES,a,o,s,Et.disabled,l,r.id,t.layoutVertexBuffer,t.indexBuffer,e,r.paint,n.transform.zoom,t.programConfigurations.get(r.id),t.dynamicLayoutVertexBuffer,t.opacityVertexBuffer)}function rn(t,e,r,n,i,a,o){var s,l,c,u,f,h=t.context.gl,p=r.paint.get(\"fill-pattern\"),d=p&&p.constantOr(1),g=r.getCrossfadeParameters();o?(l=d&&!r.getPaintProperty(\"fill-outline-color\")?\"fillOutlinePattern\":\"fillOutline\",s=h.LINES):(l=d?\"fillPattern\":\"fill\",s=h.TRIANGLES);for(var m=0,v=n;m<v.length;m+=1){var y=v[m],x=e.getTile(y);if(!d||x.patternsLoaded()){var b=x.getBucket(r);if(b){var _=b.programConfigurations.get(r.id),w=t.useProgram(l,_);d&&(t.context.activeTexture.set(h.TEXTURE0),x.imageAtlasTexture.bind(h.LINEAR,h.CLAMP_TO_EDGE),_.updatePaintBuffers(g));var T=p.constantOr(null);if(T&&x.imageAtlas){var k=x.imageAtlas,M=k.patternPositions[T.to.toString()],A=k.patternPositions[T.from.toString()];M&&A&&_.setConstantPatternPositions(M,A)}var S=t.translatePosMatrix(y.posMatrix,x,r.paint.get(\"fill-translate\"),r.paint.get(\"fill-translate-anchor\"));if(o){u=b.indexBuffer2,f=b.segments2;var E=[h.drawingBufferWidth,h.drawingBufferHeight];c=\"fillOutlinePattern\"===l&&d?Sr(S,t,g,x,E):Ar(S,E)}else u=b.indexBuffer,f=b.segments,c=d?Mr(S,t,g,x):kr(S);w.draw(t.context,s,i,t.stencilModeForClipping(y),a,Et.disabled,c,r.id,b.layoutVertexBuffer,u,f,r.paint,t.transform.zoom,_)}}}}function nn(t,e,r,n,i,a,o){for(var s=t.context,l=s.gl,c=r.paint.get(\"fill-extrusion-pattern\"),u=c.constantOr(1),f=r.getCrossfadeParameters(),h=r.paint.get(\"fill-extrusion-opacity\"),p=0,d=n;p<d.length;p+=1){var g=d[p],m=e.getTile(g),v=m.getBucket(r);if(v){var y=v.programConfigurations.get(r.id),x=t.useProgram(u?\"fillExtrusionPattern\":\"fillExtrusion\",y);u&&(t.context.activeTexture.set(l.TEXTURE0),m.imageAtlasTexture.bind(l.LINEAR,l.CLAMP_TO_EDGE),y.updatePaintBuffers(f));var b=c.constantOr(null);if(b&&m.imageAtlas){var _=m.imageAtlas,w=_.patternPositions[b.to.toString()],T=_.patternPositions[b.from.toString()];w&&T&&y.setConstantPatternPositions(w,T)}var k=t.translatePosMatrix(g.posMatrix,m,r.paint.get(\"fill-extrusion-translate\"),r.paint.get(\"fill-extrusion-translate-anchor\")),M=r.paint.get(\"fill-extrusion-vertical-gradient\"),A=u?Tr(k,t,M,h,g,f,m):wr(k,t,M,h);x.draw(s,s.gl.TRIANGLES,i,a,o,Et.backCCW,A,r.id,v.layoutVertexBuffer,v.indexBuffer,v.segments,r.paint,t.transform.zoom,y)}}}function an(e,r,n,i,a,o){var s=e.context,l=s.gl,c=r.fbo;if(c){var u=e.useProgram(\"hillshade\");s.activeTexture.set(l.TEXTURE0),l.bindTexture(l.TEXTURE_2D,c.colorAttachment.get());var f=function(e,r,n){var i=n.paint.get(\"hillshade-shadow-color\"),a=n.paint.get(\"hillshade-highlight-color\"),o=n.paint.get(\"hillshade-accent-color\"),s=n.paint.get(\"hillshade-illumination-direction\")*(Math.PI/180);\"viewport\"===n.paint.get(\"hillshade-illumination-anchor\")&&(s-=e.transform.angle);var l,c,u,f=!e.options.moving;return{u_matrix:e.transform.calculatePosMatrix(r.tileID.toUnwrapped(),f),u_image:0,u_latrange:(l=r.tileID,c=Math.pow(2,l.canonical.z),u=l.canonical.y,[new t.MercatorCoordinate(0,u/c).toLngLat().lat,new t.MercatorCoordinate(0,(u+1)/c).toLngLat().lat]),u_light:[n.paint.get(\"hillshade-exaggeration\"),s],u_shadow:i,u_highlight:a,u_accent:o}}(e,r,n);u.draw(s,l.TRIANGLES,i,a,o,Et.disabled,f,n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments)}}function on(e,r,n,i,a,o,s){var l=e.context,c=l.gl,u=r.dem;if(u&&u.data){var f=u.dim,h=u.stride,p=u.getPixels();if(l.activeTexture.set(c.TEXTURE1),l.pixelStoreUnpackPremultiplyAlpha.set(!1),r.demTexture=r.demTexture||e.getTileTexture(h),r.demTexture){var d=r.demTexture;d.update(p,{premultiply:!1}),d.bind(c.NEAREST,c.CLAMP_TO_EDGE)}else r.demTexture=new t.Texture(l,p,c.RGBA,{premultiply:!1}),r.demTexture.bind(c.NEAREST,c.CLAMP_TO_EDGE);l.activeTexture.set(c.TEXTURE0);var g=r.fbo;if(!g){var m=new t.Texture(l,{width:f,height:f,data:null},c.RGBA);m.bind(c.LINEAR,c.CLAMP_TO_EDGE),(g=r.fbo=l.createFramebuffer(f,f,!0)).colorAttachment.set(m.texture)}l.bindFramebuffer.set(g.framebuffer),l.viewport.set([0,0,f,f]),e.useProgram(\"hillshadePrepare\").draw(l,c.TRIANGLES,a,o,s,Et.disabled,function(e,r,n){var i=r.stride,a=t.create();return t.ortho(a,0,t.EXTENT,-t.EXTENT,0,0,1),t.translate(a,a,[0,-t.EXTENT,0]),{u_matrix:a,u_image:1,u_dimension:[i,i],u_zoom:e.overscaledZ,u_maxzoom:n,u_unpack:r.getUnpackVector()}}(r.tileID,u,i),n.id,e.rasterBoundsBuffer,e.quadTriangleIndexBuffer,e.rasterBoundsSegments),r.needsHillshadePrepare=!1}}function sn(e,r,n,i,a){var o=i.paint.get(\"raster-fade-duration\");if(o>0){var s=t.browser.now(),l=(s-e.timeAdded)/o,c=r?(s-r.timeAdded)/o:-1,u=n.getSource(),f=a.coveringZoomLevel({tileSize:u.tileSize,roundZoom:u.roundZoom}),h=!r||Math.abs(r.tileID.overscaledZ-f)>Math.abs(e.tileID.overscaledZ-f),p=h&&e.refreshedUponExpiration?1:t.clamp(h?l:1-c,0,1);return e.refreshedUponExpiration&&l>=1&&(e.refreshedUponExpiration=!1),r?{opacity:1,mix:1-p}:{opacity:p,mix:0}}return{opacity:1,mix:0}}var ln=new t.Color(1,0,0,1),cn=new t.Color(0,1,0,1),un=new t.Color(0,0,1,1),fn=new t.Color(1,0,1,1),hn=new t.Color(0,1,1,1);function pn(t,e,r,n){gn(t,0,e+r/2,t.transform.width,r,n)}function dn(t,e,r,n){gn(t,e-r/2,0,r,t.transform.height,n)}function gn(e,r,n,i,a,o){var s=e.context,l=s.gl;l.enable(l.SCISSOR_TEST),l.scissor(r*t.browser.devicePixelRatio,n*t.browser.devicePixelRatio,i*t.browser.devicePixelRatio,a*t.browser.devicePixelRatio),s.clear({color:o}),l.disable(l.SCISSOR_TEST)}function mn(e,r,n){var i=e.context,a=i.gl,o=n.posMatrix,s=e.useProgram(\"debug\"),l=Mt.disabled,c=At.disabled,u=e.colorModeForRenderPass();i.activeTexture.set(a.TEXTURE0),e.emptyTexture.bind(a.LINEAR,a.CLAMP_TO_EDGE),s.draw(i,a.LINE_STRIP,l,c,u,Et.disabled,Ir(o,t.Color.red),\"$debug\",e.debugBuffer,e.tileBorderIndexBuffer,e.debugSegments);var f=r.getTileByID(n.key).latestRawTileData,h=Math.floor((f&&f.byteLength||0)/1024),p=r.getTile(n).tileSize,d=512/Math.min(p,512)*(n.overscaledZ/e.transform.zoom)*.5,g=n.canonical.toString();n.overscaledZ!==n.canonical.z&&(g+=\" => \"+n.overscaledZ),function(t,e){t.initDebugOverlayCanvas();var r=t.debugOverlayCanvas,n=t.context.gl,i=t.debugOverlayCanvas.getContext(\"2d\");i.clearRect(0,0,r.width,r.height),i.shadowColor=\"white\",i.shadowBlur=2,i.lineWidth=1.5,i.strokeStyle=\"white\",i.textBaseline=\"top\",i.font=\"bold 36px Open Sans, sans-serif\",i.fillText(e,5,5),i.strokeText(e,5,5),t.debugOverlayTexture.update(r),t.debugOverlayTexture.bind(n.LINEAR,n.CLAMP_TO_EDGE)}(e,g+\" \"+h+\"kb\"),s.draw(i,a.TRIANGLES,l,c,St.alphaBlended,Et.disabled,Ir(o,t.Color.transparent,d),\"$debug\",e.debugBuffer,e.quadTriangleIndexBuffer,e.debugSegments)}var vn={symbol:function(e,r,n,i,a){if(\"translucent\"===e.renderPass){var o=At.disabled,s=e.colorModeForRenderPass();n.layout.get(\"text-variable-anchor\")&&function(e,r,n,i,a,o,s){for(var l=r.transform,c=\"map\"===a,u=\"map\"===o,f=0,h=e;f<h.length;f+=1){var p=h[f],d=i.getTile(p),g=d.getBucket(n);if(g&&g.text&&g.text.segments.get().length){var m=t.evaluateSizeForZoom(g.textSizeData,l.zoom),v=he(d,1,r.transform.zoom),y=Kt(p.posMatrix,u,c,r.transform,v),x=\"none\"!==n.layout.get(\"icon-text-fit\")&&g.hasIconData();if(m){var b=Math.pow(2,l.zoom-d.tileID.overscaledZ);Qr(g,c,u,s,t.symbolSize,l,y,p.posMatrix,b,m,x)}}}}(i,e,n,r,n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),a),0!==n.paint.get(\"icon-opacity\").constantOr(1)&&tn(e,r,n,i,!1,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),n.layout.get(\"icon-rotation-alignment\"),n.layout.get(\"icon-pitch-alignment\"),n.layout.get(\"icon-keep-upright\"),o,s),0!==n.paint.get(\"text-opacity\").constantOr(1)&&tn(e,r,n,i,!0,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),n.layout.get(\"text-rotation-alignment\"),n.layout.get(\"text-pitch-alignment\"),n.layout.get(\"text-keep-upright\"),o,s),r.map.showCollisionBoxes&&(Zr(e,r,n,i,n.paint.get(\"text-translate\"),n.paint.get(\"text-translate-anchor\"),!0),Zr(e,r,n,i,n.paint.get(\"icon-translate\"),n.paint.get(\"icon-translate-anchor\"),!1))}},circle:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"circle-opacity\"),o=n.paint.get(\"circle-stroke-width\"),s=n.paint.get(\"circle-stroke-opacity\"),l=void 0!==n.layout.get(\"circle-sort-key\").constantOr(1);if(0!==a.constantOr(1)||0!==o.constantOr(1)&&0!==s.constantOr(1)){for(var c=e.context,u=c.gl,f=e.depthModeForSublayer(0,Mt.ReadOnly),h=At.disabled,p=e.colorModeForRenderPass(),d=[],g=0;g<i.length;g++){var m=i[g],v=r.getTile(m),y=v.getBucket(n);if(y){var x=y.programConfigurations.get(n.id),b={programConfiguration:x,program:e.useProgram(\"circle\",x),layoutVertexBuffer:y.layoutVertexBuffer,indexBuffer:y.indexBuffer,uniformValues:Er(e,m,v,n)};if(l)for(var _=0,w=y.segments.get();_<w.length;_+=1){var T=w[_];d.push({segments:new t.SegmentVector([T]),sortKey:T.sortKey,state:b})}else d.push({segments:y.segments,sortKey:0,state:b})}}l&&d.sort((function(t,e){return t.sortKey-e.sortKey}));for(var k=0,M=d;k<M.length;k+=1){var A=M[k],S=A.state;S.program.draw(c,u.TRIANGLES,f,h,p,Et.disabled,S.uniformValues,n.id,S.layoutVertexBuffer,S.indexBuffer,A.segments,n.paint,e.transform.zoom,S.programConfiguration)}}}},heatmap:function(e,r,n,i){if(0!==n.paint.get(\"heatmap-opacity\"))if(\"offscreen\"===e.renderPass){var a=e.context,o=a.gl,s=At.disabled,l=new St([o.ONE,o.ONE],t.Color.transparent,[!0,!0,!0,!0]);!function(t,e,r){var n=t.gl;t.activeTexture.set(n.TEXTURE1),t.viewport.set([0,0,e.width/4,e.height/4]);var i=r.heatmapFbo;if(i)n.bindTexture(n.TEXTURE_2D,i.colorAttachment.get()),t.bindFramebuffer.set(i.framebuffer);else{var a=n.createTexture();n.bindTexture(n.TEXTURE_2D,a),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_S,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_WRAP_T,n.CLAMP_TO_EDGE),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MIN_FILTER,n.LINEAR),n.texParameteri(n.TEXTURE_2D,n.TEXTURE_MAG_FILTER,n.LINEAR),i=r.heatmapFbo=t.createFramebuffer(e.width/4,e.height/4,!1),function(t,e,r,n){var i=t.gl;i.texImage2D(i.TEXTURE_2D,0,i.RGBA,e.width/4,e.height/4,0,i.RGBA,t.extRenderToTextureHalfFloat?t.extTextureHalfFloat.HALF_FLOAT_OES:i.UNSIGNED_BYTE,null),n.colorAttachment.set(r)}(t,e,a,i)}}(a,e,n),a.clear({color:t.Color.transparent});for(var c=0;c<i.length;c++){var u=i[c];if(!r.hasRenderableParent(u)){var f=r.getTile(u),h=f.getBucket(n);if(h){var p=h.programConfigurations.get(n.id);e.useProgram(\"heatmap\",p).draw(a,o.TRIANGLES,Mt.disabled,s,l,Et.disabled,zr(u.posMatrix,f,e.transform.zoom,n.paint.get(\"heatmap-intensity\")),n.id,h.layoutVertexBuffer,h.indexBuffer,h.segments,n.paint,e.transform.zoom,p)}}}a.viewport.set([0,0,e.width,e.height])}else\"translucent\"===e.renderPass&&(e.context.setColorMode(e.colorModeForRenderPass()),function(e,r){var n=e.context,i=n.gl,a=r.heatmapFbo;if(a){n.activeTexture.set(i.TEXTURE0),i.bindTexture(i.TEXTURE_2D,a.colorAttachment.get()),n.activeTexture.set(i.TEXTURE1);var o=r.colorRampTexture;o||(o=r.colorRampTexture=new t.Texture(n,r.colorRamp,i.RGBA)),o.bind(i.LINEAR,i.CLAMP_TO_EDGE),e.useProgram(\"heatmapTexture\").draw(n,i.TRIANGLES,Mt.disabled,At.disabled,e.colorModeForRenderPass(),Et.disabled,function(e,r,n,i){var a=t.create();t.ortho(a,0,e.width,e.height,0,0,1);var o=e.context.gl;return{u_matrix:a,u_world:[o.drawingBufferWidth,o.drawingBufferHeight],u_image:0,u_color_ramp:1,u_opacity:r.paint.get(\"heatmap-opacity\")}}(e,r),r.id,e.viewportBuffer,e.quadTriangleIndexBuffer,e.viewportSegments,r.paint,e.transform.zoom)}}(e,n))},line:function(e,r,n,i){if(\"translucent\"===e.renderPass){var a=n.paint.get(\"line-opacity\"),o=n.paint.get(\"line-width\");if(0!==a.constantOr(1)&&0!==o.constantOr(1)){var s=e.depthModeForSublayer(0,Mt.ReadOnly),l=e.colorModeForRenderPass(),c=n.paint.get(\"line-dasharray\"),u=n.paint.get(\"line-pattern\"),f=u.constantOr(1),h=n.paint.get(\"line-gradient\"),p=n.getCrossfadeParameters(),d=f?\"linePattern\":c?\"lineSDF\":h?\"lineGradient\":\"line\",g=e.context,m=g.gl,v=!0;if(h){g.activeTexture.set(m.TEXTURE0);var y=n.gradientTexture;if(!n.gradient)return;y||(y=n.gradientTexture=new t.Texture(g,n.gradient,m.RGBA)),y.bind(m.LINEAR,m.CLAMP_TO_EDGE)}for(var x=0,b=i;x<b.length;x+=1){var _=b[x],w=r.getTile(_);if(!f||w.patternsLoaded()){var T=w.getBucket(n);if(T){var k=T.programConfigurations.get(n.id),M=e.context.program.get(),A=e.useProgram(d,k),S=v||A.program!==M,E=u.constantOr(null);if(E&&w.imageAtlas){var C=w.imageAtlas,L=C.patternPositions[E.to.toString()],I=C.patternPositions[E.from.toString()];L&&I&&k.setConstantPatternPositions(L,I)}var P=f?Rr(e,w,n,p):c?Fr(e,w,n,c,p):h?Dr(e,w,n):Or(e,w,n);f?(g.activeTexture.set(m.TEXTURE0),w.imageAtlasTexture.bind(m.LINEAR,m.CLAMP_TO_EDGE),k.updatePaintBuffers(p)):c&&(S||e.lineAtlas.dirty)&&(g.activeTexture.set(m.TEXTURE0),e.lineAtlas.bind(g)),A.draw(g,m.TRIANGLES,s,e.stencilModeForClipping(_),l,Et.disabled,P,n.id,T.layoutVertexBuffer,T.indexBuffer,T.segments,n.paint,e.transform.zoom,k),v=!1}}}}}},fill:function(e,r,n,i){var a=n.paint.get(\"fill-color\"),o=n.paint.get(\"fill-opacity\");if(0!==o.constantOr(1)){var s=e.colorModeForRenderPass(),l=n.paint.get(\"fill-pattern\"),c=e.opaquePassEnabledForLayer()&&!l.constantOr(1)&&1===a.constantOr(t.Color.transparent).a&&1===o.constantOr(0)?\"opaque\":\"translucent\";if(e.renderPass===c){var u=e.depthModeForSublayer(1,\"opaque\"===e.renderPass?Mt.ReadWrite:Mt.ReadOnly);rn(e,r,n,i,u,s,!1)}if(\"translucent\"===e.renderPass&&n.paint.get(\"fill-antialias\")){var f=e.depthModeForSublayer(n.getPaintProperty(\"fill-outline-color\")?2:0,Mt.ReadOnly);rn(e,r,n,i,f,s,!0)}}},\"fill-extrusion\":function(t,e,r,n){var i=r.paint.get(\"fill-extrusion-opacity\");if(0!==i&&\"translucent\"===t.renderPass){var a=new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D);if(1!==i||r.paint.get(\"fill-extrusion-pattern\").constantOr(1))nn(t,e,r,n,a,At.disabled,St.disabled),nn(t,e,r,n,a,t.stencilModeFor3D(),t.colorModeForRenderPass());else{var o=t.colorModeForRenderPass();nn(t,e,r,n,a,At.disabled,o)}}},hillshade:function(t,e,r,n){if(\"offscreen\"===t.renderPass||\"translucent\"===t.renderPass){for(var i=t.context,a=e.getSource().maxzoom,o=t.depthModeForSublayer(0,Mt.ReadOnly),s=t.colorModeForRenderPass(),l=\"translucent\"===t.renderPass?t.stencilConfigForOverlap(n):[{},n],c=l[0],u=0,f=l[1];u<f.length;u+=1){var h=f[u],p=e.getTile(h);p.needsHillshadePrepare&&\"offscreen\"===t.renderPass?on(t,p,r,a,o,At.disabled,s):\"translucent\"===t.renderPass&&an(t,p,r,o,c[h.overscaledZ],s)}i.viewport.set([0,0,t.width,t.height])}},raster:function(t,e,r,n){if(\"translucent\"===t.renderPass&&0!==r.paint.get(\"raster-opacity\")&&n.length)for(var i=t.context,a=i.gl,o=e.getSource(),s=t.useProgram(\"raster\"),l=t.colorModeForRenderPass(),c=o instanceof P?[{},n]:t.stencilConfigForOverlap(n),u=c[0],f=c[1],h=f[f.length-1].overscaledZ,p=!t.options.moving,d=0,g=f;d<g.length;d+=1){var m=g[d],v=t.depthModeForSublayer(m.overscaledZ-h,1===r.paint.get(\"raster-opacity\")?Mt.ReadWrite:Mt.ReadOnly,a.LESS),y=e.getTile(m),x=t.transform.calculatePosMatrix(m.toUnwrapped(),p);y.registerFadeDuration(r.paint.get(\"raster-fade-duration\"));var b=e.findLoadedParent(m,0),_=sn(y,b,e,r,t.transform),w=void 0,T=void 0,k=\"nearest\"===r.paint.get(\"raster-resampling\")?a.NEAREST:a.LINEAR;i.activeTexture.set(a.TEXTURE0),y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),i.activeTexture.set(a.TEXTURE1),b?(b.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST),w=Math.pow(2,b.tileID.overscaledZ-y.tileID.overscaledZ),T=[y.tileID.canonical.x*w%1,y.tileID.canonical.y*w%1]):y.texture.bind(k,a.CLAMP_TO_EDGE,a.LINEAR_MIPMAP_NEAREST);var M=jr(x,T||[0,0],w||1,_,r);o instanceof P?s.draw(i,a.TRIANGLES,v,At.disabled,l,Et.disabled,M,r.id,o.boundsBuffer,t.quadTriangleIndexBuffer,o.boundsSegments):s.draw(i,a.TRIANGLES,v,u[m.overscaledZ],l,Et.disabled,M,r.id,t.rasterBoundsBuffer,t.quadTriangleIndexBuffer,t.rasterBoundsSegments)}},background:function(t,e,r){var n=r.paint.get(\"background-color\"),i=r.paint.get(\"background-opacity\");if(0!==i){var a=t.context,o=a.gl,s=t.transform,l=s.tileSize,c=r.paint.get(\"background-pattern\");if(!t.isPatternMissing(c)){var u=!c&&1===n.a&&1===i&&t.opaquePassEnabledForLayer()?\"opaque\":\"translucent\";if(t.renderPass===u){var f=At.disabled,h=t.depthModeForSublayer(0,\"opaque\"===u?Mt.ReadWrite:Mt.ReadOnly),p=t.colorModeForRenderPass(),d=t.useProgram(c?\"backgroundPattern\":\"background\"),g=s.coveringTiles({tileSize:l});c&&(a.activeTexture.set(o.TEXTURE0),t.imageManager.bind(t.context));for(var m=r.getCrossfadeParameters(),v=0,y=g;v<y.length;v+=1){var x=y[v],b=t.transform.calculatePosMatrix(x.toUnwrapped()),_=c?Wr(b,i,t,c,{tileID:x,tileSize:l},m):Yr(b,i,n);d.draw(a,o.TRIANGLES,h,f,p,Et.disabled,_,r.id,t.tileExtentBuffer,t.quadTriangleIndexBuffer,t.tileExtentSegments)}}}}},debug:function(t,e,r){for(var n=0;n<r.length;n++)mn(t,e,r[n])},custom:function(t,e,r){var n=t.context,i=r.implementation;if(\"offscreen\"===t.renderPass){var a=i.prerender;a&&(t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),a.call(i,n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState())}else if(\"translucent\"===t.renderPass){t.setCustomLayerDefaults(),n.setColorMode(t.colorModeForRenderPass()),n.setStencilMode(At.disabled);var o=\"3d\"===i.renderingMode?new Mt(t.context.gl.LEQUAL,Mt.ReadWrite,t.depthRangeFor3D):t.depthModeForSublayer(0,Mt.ReadOnly);n.setDepthMode(o),i.render(n.gl,t.transform.customLayerMatrix()),n.setDirty(),t.setBaseState(),n.bindFramebuffer.set(null)}}},yn=function(t,e){this.context=new Ct(t),this.transform=e,this._tileTextures={},this.setup(),this.numSublayers=Lt.maxUnderzooming+Lt.maxOverzooming+1,this.depthEpsilon=1/Math.pow(2,16),this.crossTileSymbolIndex=new Be,this.gpuTimers={}};yn.prototype.resize=function(e,r){if(this.width=e*t.browser.devicePixelRatio,this.height=r*t.browser.devicePixelRatio,this.context.viewport.set([0,0,this.width,this.height]),this.style)for(var n=0,i=this.style._order;n<i.length;n+=1)this.style._layers[i[n]].resize()},yn.prototype.setup=function(){var e=this.context,r=new t.StructArrayLayout2i4;r.emplaceBack(0,0),r.emplaceBack(t.EXTENT,0),r.emplaceBack(0,t.EXTENT),r.emplaceBack(t.EXTENT,t.EXTENT),this.tileExtentBuffer=e.createVertexBuffer(r,He.members),this.tileExtentSegments=t.SegmentVector.simpleSegment(0,0,4,2);var n=new t.StructArrayLayout2i4;n.emplaceBack(0,0),n.emplaceBack(t.EXTENT,0),n.emplaceBack(0,t.EXTENT),n.emplaceBack(t.EXTENT,t.EXTENT),this.debugBuffer=e.createVertexBuffer(n,He.members),this.debugSegments=t.SegmentVector.simpleSegment(0,0,4,5);var i=new t.StructArrayLayout4i8;i.emplaceBack(0,0,0,0),i.emplaceBack(t.EXTENT,0,t.EXTENT,0),i.emplaceBack(0,t.EXTENT,0,t.EXTENT),i.emplaceBack(t.EXTENT,t.EXTENT,t.EXTENT,t.EXTENT),this.rasterBoundsBuffer=e.createVertexBuffer(i,I.members),this.rasterBoundsSegments=t.SegmentVector.simpleSegment(0,0,4,2);var a=new t.StructArrayLayout2i4;a.emplaceBack(0,0),a.emplaceBack(1,0),a.emplaceBack(0,1),a.emplaceBack(1,1),this.viewportBuffer=e.createVertexBuffer(a,He.members),this.viewportSegments=t.SegmentVector.simpleSegment(0,0,4,2);var o=new t.StructArrayLayout1ui2;o.emplaceBack(0),o.emplaceBack(1),o.emplaceBack(3),o.emplaceBack(2),o.emplaceBack(0),this.tileBorderIndexBuffer=e.createIndexBuffer(o);var s=new t.StructArrayLayout3ui6;s.emplaceBack(0,1,2),s.emplaceBack(2,1,3),this.quadTriangleIndexBuffer=e.createIndexBuffer(s),this.emptyTexture=new t.Texture(e,{width:1,height:1,data:new Uint8Array([0,0,0,0])},e.gl.RGBA);var l=this.context.gl;this.stencilClearMode=new At({func:l.ALWAYS,mask:0},0,255,l.ZERO,l.ZERO,l.ZERO)},yn.prototype.clearStencil=function(){var e=this.context,r=e.gl;this.nextStencilID=1,this.currentStencilSource=void 0;var n=t.create();t.ortho(n,0,this.width,this.height,0,0,1),t.scale(n,n,[r.drawingBufferWidth,r.drawingBufferHeight,0]),this.useProgram(\"clippingMask\").draw(e,r.TRIANGLES,Mt.disabled,this.stencilClearMode,St.disabled,Et.disabled,Pr(n),\"$clipping\",this.viewportBuffer,this.quadTriangleIndexBuffer,this.viewportSegments)},yn.prototype._renderTileClippingMasks=function(t,e){if(this.currentStencilSource!==t.source&&t.isTileClipped()&&e&&e.length){this.currentStencilSource=t.source;var r=this.context,n=r.gl;this.nextStencilID+e.length>256&&this.clearStencil(),r.setColorMode(St.disabled),r.setDepthMode(Mt.disabled);var i=this.useProgram(\"clippingMask\");this._tileClippingMaskIDs={};for(var a=0,o=e;a<o.length;a+=1){var s=o[a],l=this._tileClippingMaskIDs[s.key]=this.nextStencilID++;i.draw(r,n.TRIANGLES,Mt.disabled,new At({func:n.ALWAYS,mask:0},l,255,n.KEEP,n.KEEP,n.REPLACE),St.disabled,Et.disabled,Pr(s.posMatrix),\"$clipping\",this.tileExtentBuffer,this.quadTriangleIndexBuffer,this.tileExtentSegments)}}},yn.prototype.stencilModeFor3D=function(){this.currentStencilSource=void 0,this.nextStencilID+1>256&&this.clearStencil();var t=this.nextStencilID++,e=this.context.gl;return new At({func:e.NOTEQUAL,mask:255},t,255,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilModeForClipping=function(t){var e=this.context.gl;return new At({func:e.EQUAL,mask:255},this._tileClippingMaskIDs[t.key],0,e.KEEP,e.KEEP,e.REPLACE)},yn.prototype.stencilConfigForOverlap=function(t){var e,r=this.context.gl,n=t.sort((function(t,e){return e.overscaledZ-t.overscaledZ})),i=n[n.length-1].overscaledZ,a=n[0].overscaledZ-i+1;if(a>1){this.currentStencilSource=void 0,this.nextStencilID+a>256&&this.clearStencil();for(var o={},s=0;s<a;s++)o[s+i]=new At({func:r.GEQUAL,mask:255},s+this.nextStencilID,255,r.KEEP,r.KEEP,r.REPLACE);return this.nextStencilID+=a,[o,n]}return[(e={},e[i]=At.disabled,e),n]},yn.prototype.colorModeForRenderPass=function(){var e=this.context.gl;return this._showOverdrawInspector?new St([e.CONSTANT_COLOR,e.ONE],new t.Color(1/8,1/8,1/8,0),[!0,!0,!0,!0]):\"opaque\"===this.renderPass?St.unblended:St.alphaBlended},yn.prototype.depthModeForSublayer=function(t,e,r){if(!this.opaquePassEnabledForLayer())return Mt.disabled;var n=1-((1+this.currentLayer)*this.numSublayers+t)*this.depthEpsilon;return new Mt(r||this.context.gl.LEQUAL,e,[n,n])},yn.prototype.opaquePassEnabledForLayer=function(){return this.currentLayer<this.opaquePassCutoff},yn.prototype.render=function(e,r){var n=this;this.style=e,this.options=r,this.lineAtlas=e.lineAtlas,this.imageManager=e.imageManager,this.glyphManager=e.glyphManager,this.symbolFadeChange=e.placement.symbolFadeChange(t.browser.now()),this.imageManager.beginFrame();var i=this.style._order,a=this.style.sourceCaches;for(var o in a){var s=a[o];s.used&&s.prepare(this.context)}var l,c,u={},f={},h={};for(var p in a){var d=a[p];u[p]=d.getVisibleCoordinates(),f[p]=u[p].slice().reverse(),h[p]=d.getVisibleCoordinates(!0).reverse()}this.opaquePassCutoff=1/0;for(var g=0;g<i.length;g++)if(this.style._layers[i[g]].is3D()){this.opaquePassCutoff=g;break}this.renderPass=\"offscreen\";for(var m=0,v=i;m<v.length;m+=1){var y=this.style._layers[v[m]];if(y.hasOffscreenPass()&&!y.isHidden(this.transform.zoom)){var x=f[y.source];(\"custom\"===y.type||x.length)&&this.renderLayer(this,a[y.source],y,x)}}for(this.context.bindFramebuffer.set(null),this.context.clear({color:r.showOverdrawInspector?t.Color.black:t.Color.transparent,depth:1}),this.clearStencil(),this._showOverdrawInspector=r.showOverdrawInspector,this.depthRangeFor3D=[0,1-(e._order.length+2)*this.numSublayers*this.depthEpsilon],this.renderPass=\"opaque\",this.currentLayer=i.length-1;this.currentLayer>=0;this.currentLayer--){var b=this.style._layers[i[this.currentLayer]],_=a[b.source],w=u[b.source];this._renderTileClippingMasks(b,w),this.renderLayer(this,_,b,w)}for(this.renderPass=\"translucent\",this.currentLayer=0;this.currentLayer<i.length;this.currentLayer++){var T=this.style._layers[i[this.currentLayer]],k=a[T.source],M=(\"symbol\"===T.type?h:f)[T.source];this._renderTileClippingMasks(T,u[T.source]),this.renderLayer(this,k,T,M)}this.options.showTileBoundaries&&(t.values(this.style._layers).forEach((function(t){t.source&&!t.isHidden(n.transform.zoom)&&(t.source!==(c&&c.id)&&(c=n.style.sourceCaches[t.source]),(!l||l.getSource().maxzoom<c.getSource().maxzoom)&&(l=c))})),l&&vn.debug(this,l,l.getVisibleCoordinates())),this.options.showPadding&&function(t){var e=t.transform.padding;pn(t,t.transform.height-(e.top||0),3,ln),pn(t,e.bottom||0,3,cn),dn(t,e.left||0,3,un),dn(t,t.transform.width-(e.right||0),3,fn);var r=t.transform.centerPoint;!function(t,e,r,n){gn(t,e-1,r-10,2,20,n),gn(t,e-10,r-1,20,2,n)}(t,r.x,t.transform.height-r.y,hn)}(this),this.context.setDefault()},yn.prototype.renderLayer=function(t,e,r,n){r.isHidden(this.transform.zoom)||(\"background\"===r.type||\"custom\"===r.type||n.length)&&(this.id=r.id,this.gpuTimingStart(r),vn[r.type](t,e,r,n,this.style.placement.variableOffsets),this.gpuTimingEnd())},yn.prototype.gpuTimingStart=function(t){if(this.options.gpuTiming){var e=this.context.extTimerQuery,r=this.gpuTimers[t.id];r||(r=this.gpuTimers[t.id]={calls:0,cpuTime:0,query:e.createQueryEXT()}),r.calls++,e.beginQueryEXT(e.TIME_ELAPSED_EXT,r.query)}},yn.prototype.gpuTimingEnd=function(){if(this.options.gpuTiming){var t=this.context.extTimerQuery;t.endQueryEXT(t.TIME_ELAPSED_EXT)}},yn.prototype.collectGpuTimers=function(){var t=this.gpuTimers;return this.gpuTimers={},t},yn.prototype.queryGpuTimers=function(t){var e={};for(var r in t){var n=t[r],i=this.context.extTimerQuery,a=i.getQueryObjectEXT(n.query,i.QUERY_RESULT_EXT)/1e6;i.deleteQueryEXT(n.query),e[r]=a}return e},yn.prototype.translatePosMatrix=function(e,r,n,i,a){if(!n[0]&&!n[1])return e;var o=a?\"map\"===i?this.transform.angle:0:\"viewport\"===i?-this.transform.angle:0;if(o){var s=Math.sin(o),l=Math.cos(o);n=[n[0]*l-n[1]*s,n[0]*s+n[1]*l]}var c=[a?n[0]:he(r,n[0],this.transform.zoom),a?n[1]:he(r,n[1],this.transform.zoom),0],u=new Float32Array(16);return t.translate(u,e,c),u},yn.prototype.saveTileTexture=function(t){var e=this._tileTextures[t.size[0]];e?e.push(t):this._tileTextures[t.size[0]]=[t]},yn.prototype.getTileTexture=function(t){var e=this._tileTextures[t];return e&&e.length>0?e.pop():null},yn.prototype.isPatternMissing=function(t){if(!t)return!1;if(!t.from||!t.to)return!0;var e=this.imageManager.getPattern(t.from.toString()),r=this.imageManager.getPattern(t.to.toString());return!e||!r},yn.prototype.useProgram=function(t,e){this.cache=this.cache||{};var r=\"\"+t+(e?e.cacheKey:\"\")+(this._showOverdrawInspector?\"/overdraw\":\"\");return this.cache[r]||(this.cache[r]=new br(this.context,yr[t],e,Xr[t],this._showOverdrawInspector)),this.cache[r]},yn.prototype.setCustomLayerDefaults=function(){this.context.unbindVAO(),this.context.cullFace.setDefault(),this.context.activeTexture.setDefault(),this.context.pixelStoreUnpack.setDefault(),this.context.pixelStoreUnpackPremultiplyAlpha.setDefault(),this.context.pixelStoreUnpackFlipY.setDefault()},yn.prototype.setBaseState=function(){var t=this.context.gl;this.context.cullFace.set(!1),this.context.viewport.set([0,0,this.width,this.height]),this.context.blendEquation.set(t.FUNC_ADD)},yn.prototype.initDebugOverlayCanvas=function(){null==this.debugOverlayCanvas&&(this.debugOverlayCanvas=t.window.document.createElement(\"canvas\"),this.debugOverlayCanvas.width=512,this.debugOverlayCanvas.height=512,this.debugOverlayTexture=new t.Texture(this.context,this.debugOverlayCanvas,this.context.gl.RGBA))},yn.prototype.destroy=function(){this.emptyTexture.destroy(),this.debugOverlayTexture&&this.debugOverlayTexture.destroy()};var xn=function(t,e){this.points=t,this.planes=e};xn.fromInvProjectionMatrix=function(e,r,n){var i=Math.pow(2,n),a=[[-1,1,-1,1],[1,1,-1,1],[1,-1,-1,1],[-1,-1,-1,1],[-1,1,1,1],[1,1,1,1],[1,-1,1,1],[-1,-1,1,1]].map((function(r){return t.transformMat4([],r,e)})).map((function(e){return t.scale$1([],e,1/e[3]/r*i)})),o=[[0,1,2],[6,5,4],[0,3,7],[2,1,5],[3,2,6],[0,4,5]].map((function(e){var r=t.sub([],a[e[0]],a[e[1]]),n=t.sub([],a[e[2]],a[e[1]]),i=t.normalize([],t.cross([],r,n)),o=-t.dot(i,a[e[1]]);return i.concat(o)}));return new xn(a,o)};var bn=function(e,r){this.min=e,this.max=r,this.center=t.scale$2([],t.add([],this.min,this.max),.5)};bn.prototype.quadrant=function(e){for(var r=[e%2==0,e<2],n=t.clone$2(this.min),i=t.clone$2(this.max),a=0;a<r.length;a++)n[a]=r[a]?this.min[a]:this.center[a],i[a]=r[a]?this.center[a]:this.max[a];return i[2]=this.max[2],new bn(n,i)},bn.prototype.distanceX=function(t){return Math.max(Math.min(this.max[0],t[0]),this.min[0])-t[0]},bn.prototype.distanceY=function(t){return Math.max(Math.min(this.max[1],t[1]),this.min[1])-t[1]},bn.prototype.intersects=function(e){for(var r=[[this.min[0],this.min[1],0,1],[this.max[0],this.min[1],0,1],[this.max[0],this.max[1],0,1],[this.min[0],this.max[1],0,1]],n=!0,i=0;i<e.planes.length;i++){for(var a=e.planes[i],o=0,s=0;s<r.length;s++)o+=t.dot$1(a,r[s])>=0;if(0===o)return 0;o!==r.length&&(n=!1)}if(n)return 2;for(var l=0;l<3;l++){for(var c=Number.MAX_VALUE,u=-Number.MAX_VALUE,f=0;f<e.points.length;f++){var h=e.points[f][l]-this.min[l];c=Math.min(c,h),u=Math.max(u,h)}if(u<0||c>this.max[l]-this.min[l])return 0}return 1};var _n=function(t,e,r,n){if(void 0===t&&(t=0),void 0===e&&(e=0),void 0===r&&(r=0),void 0===n&&(n=0),isNaN(t)||t<0||isNaN(e)||e<0||isNaN(r)||r<0||isNaN(n)||n<0)throw new Error(\"Invalid value for edge-insets, top, bottom, left and right must all be numbers\");this.top=t,this.bottom=e,this.left=r,this.right=n};_n.prototype.interpolate=function(e,r,n){return null!=r.top&&null!=e.top&&(this.top=t.number(e.top,r.top,n)),null!=r.bottom&&null!=e.bottom&&(this.bottom=t.number(e.bottom,r.bottom,n)),null!=r.left&&null!=e.left&&(this.left=t.number(e.left,r.left,n)),null!=r.right&&null!=e.right&&(this.right=t.number(e.right,r.right,n)),this},_n.prototype.getCenter=function(e,r){var n=t.clamp((this.left+e-this.right)/2,0,e),i=t.clamp((this.top+r-this.bottom)/2,0,r);return new t.Point(n,i)},_n.prototype.equals=function(t){return this.top===t.top&&this.bottom===t.bottom&&this.left===t.left&&this.right===t.right},_n.prototype.clone=function(){return new _n(this.top,this.bottom,this.left,this.right)},_n.prototype.toJSON=function(){return{top:this.top,bottom:this.bottom,left:this.left,right:this.right}};var wn=function(e,r,n,i,a){this.tileSize=512,this.maxValidLatitude=85.051129,this._renderWorldCopies=void 0===a||a,this._minZoom=e||0,this._maxZoom=r||22,this._minPitch=null==n?0:n,this._maxPitch=null==i?60:i,this.setMaxBounds(),this.width=0,this.height=0,this._center=new t.LngLat(0,0),this.zoom=0,this.angle=0,this._fov=.6435011087932844,this._pitch=0,this._unmodified=!0,this._edgeInsets=new _n,this._posMatrixCache={},this._alignedPosMatrixCache={}},Tn={minZoom:{configurable:!0},maxZoom:{configurable:!0},minPitch:{configurable:!0},maxPitch:{configurable:!0},renderWorldCopies:{configurable:!0},worldSize:{configurable:!0},centerOffset:{configurable:!0},size:{configurable:!0},bearing:{configurable:!0},pitch:{configurable:!0},fov:{configurable:!0},zoom:{configurable:!0},center:{configurable:!0},padding:{configurable:!0},centerPoint:{configurable:!0},unmodified:{configurable:!0},point:{configurable:!0}};wn.prototype.clone=function(){var t=new wn(this._minZoom,this._maxZoom,this._minPitch,this.maxPitch,this._renderWorldCopies);return t.tileSize=this.tileSize,t.latRange=this.latRange,t.width=this.width,t.height=this.height,t._center=this._center,t.zoom=this.zoom,t.angle=this.angle,t._fov=this._fov,t._pitch=this._pitch,t._unmodified=this._unmodified,t._edgeInsets=this._edgeInsets.clone(),t._calcMatrices(),t},Tn.minZoom.get=function(){return this._minZoom},Tn.minZoom.set=function(t){this._minZoom!==t&&(this._minZoom=t,this.zoom=Math.max(this.zoom,t))},Tn.maxZoom.get=function(){return this._maxZoom},Tn.maxZoom.set=function(t){this._maxZoom!==t&&(this._maxZoom=t,this.zoom=Math.min(this.zoom,t))},Tn.minPitch.get=function(){return this._minPitch},Tn.minPitch.set=function(t){this._minPitch!==t&&(this._minPitch=t,this.pitch=Math.max(this.pitch,t))},Tn.maxPitch.get=function(){return this._maxPitch},Tn.maxPitch.set=function(t){this._maxPitch!==t&&(this._maxPitch=t,this.pitch=Math.min(this.pitch,t))},Tn.renderWorldCopies.get=function(){return this._renderWorldCopies},Tn.renderWorldCopies.set=function(t){void 0===t?t=!0:null===t&&(t=!1),this._renderWorldCopies=t},Tn.worldSize.get=function(){return this.tileSize*this.scale},Tn.centerOffset.get=function(){return this.centerPoint._sub(this.size._div(2))},Tn.size.get=function(){return new t.Point(this.width,this.height)},Tn.bearing.get=function(){return-this.angle/Math.PI*180},Tn.bearing.set=function(e){var r=-t.wrap(e,-180,180)*Math.PI/180;this.angle!==r&&(this._unmodified=!1,this.angle=r,this._calcMatrices(),this.rotationMatrix=t.create$2(),t.rotate(this.rotationMatrix,this.rotationMatrix,this.angle))},Tn.pitch.get=function(){return this._pitch/Math.PI*180},Tn.pitch.set=function(e){var r=t.clamp(e,this.minPitch,this.maxPitch)/180*Math.PI;this._pitch!==r&&(this._unmodified=!1,this._pitch=r,this._calcMatrices())},Tn.fov.get=function(){return this._fov/Math.PI*180},Tn.fov.set=function(t){t=Math.max(.01,Math.min(60,t)),this._fov!==t&&(this._unmodified=!1,this._fov=t/180*Math.PI,this._calcMatrices())},Tn.zoom.get=function(){return this._zoom},Tn.zoom.set=function(t){var e=Math.min(Math.max(t,this.minZoom),this.maxZoom);this._zoom!==e&&(this._unmodified=!1,this._zoom=e,this.scale=this.zoomScale(e),this.tileZoom=Math.floor(e),this.zoomFraction=e-this.tileZoom,this._constrain(),this._calcMatrices())},Tn.center.get=function(){return this._center},Tn.center.set=function(t){t.lat===this._center.lat&&t.lng===this._center.lng||(this._unmodified=!1,this._center=t,this._constrain(),this._calcMatrices())},Tn.padding.get=function(){return this._edgeInsets.toJSON()},Tn.padding.set=function(t){this._edgeInsets.equals(t)||(this._unmodified=!1,this._edgeInsets.interpolate(this._edgeInsets,t,1),this._calcMatrices())},Tn.centerPoint.get=function(){return this._edgeInsets.getCenter(this.width,this.height)},wn.prototype.isPaddingEqual=function(t){return this._edgeInsets.equals(t)},wn.prototype.interpolatePadding=function(t,e,r){this._unmodified=!1,this._edgeInsets.interpolate(t,e,r),this._constrain(),this._calcMatrices()},wn.prototype.coveringZoomLevel=function(t){var e=(t.roundZoom?Math.round:Math.floor)(this.zoom+this.scaleZoom(this.tileSize/t.tileSize));return Math.max(0,e)},wn.prototype.getVisibleUnwrappedCoordinates=function(e){var r=[new t.UnwrappedTileID(0,e)];if(this._renderWorldCopies)for(var n=this.pointCoordinate(new t.Point(0,0)),i=this.pointCoordinate(new t.Point(this.width,0)),a=this.pointCoordinate(new t.Point(this.width,this.height)),o=this.pointCoordinate(new t.Point(0,this.height)),s=Math.floor(Math.min(n.x,i.x,a.x,o.x)),l=Math.floor(Math.max(n.x,i.x,a.x,o.x)),c=s-1;c<=l+1;c++)0!==c&&r.push(new t.UnwrappedTileID(c,e));return r},wn.prototype.coveringTiles=function(e){var r=this.coveringZoomLevel(e),n=r;if(void 0!==e.minzoom&&r<e.minzoom)return[];void 0!==e.maxzoom&&r>e.maxzoom&&(r=e.maxzoom);var i=t.MercatorCoordinate.fromLngLat(this.center),a=Math.pow(2,r),o=[a*i.x,a*i.y,0],s=xn.fromInvProjectionMatrix(this.invProjMatrix,this.worldSize,r),l=e.minzoom||0;this.pitch<=60&&this._edgeInsets.top<.1&&(l=r);var c=function(t){return{aabb:new bn([t*a,0,0],[(t+1)*a,a,0]),zoom:0,x:0,y:0,wrap:t,fullyVisible:!1}},u=[],f=[],h=r,p=e.reparseOverscaled?n:r;if(this._renderWorldCopies)for(var d=1;d<=3;d++)u.push(c(-d)),u.push(c(d));for(u.push(c(0));u.length>0;){var g=u.pop(),m=g.x,v=g.y,y=g.fullyVisible;if(!y){var x=g.aabb.intersects(s);if(0===x)continue;y=2===x}var b=g.aabb.distanceX(o),_=g.aabb.distanceY(o),w=Math.max(Math.abs(b),Math.abs(_));if(g.zoom===h||w>3+(1<<h-g.zoom)-2&&g.zoom>=l)f.push({tileID:new t.OverscaledTileID(g.zoom===h?p:g.zoom,g.wrap,g.zoom,m,v),distanceSq:t.sqrLen([o[0]-.5-m,o[1]-.5-v])});else for(var T=0;T<4;T++){var k=(m<<1)+T%2,M=(v<<1)+(T>>1);u.push({aabb:g.aabb.quadrant(T),zoom:g.zoom+1,x:k,y:M,wrap:g.wrap,fullyVisible:y})}}return f.sort((function(t,e){return t.distanceSq-e.distanceSq})).map((function(t){return t.tileID}))},wn.prototype.resize=function(t,e){this.width=t,this.height=e,this.pixelsToGLUnits=[2/t,-2/e],this._constrain(),this._calcMatrices()},Tn.unmodified.get=function(){return this._unmodified},wn.prototype.zoomScale=function(t){return Math.pow(2,t)},wn.prototype.scaleZoom=function(t){return Math.log(t)/Math.LN2},wn.prototype.project=function(e){var r=t.clamp(e.lat,-this.maxValidLatitude,this.maxValidLatitude);return new t.Point(t.mercatorXfromLng(e.lng)*this.worldSize,t.mercatorYfromLat(r)*this.worldSize)},wn.prototype.unproject=function(e){return new t.MercatorCoordinate(e.x/this.worldSize,e.y/this.worldSize).toLngLat()},Tn.point.get=function(){return this.project(this.center)},wn.prototype.setLocationAtPoint=function(e,r){var n=this.pointCoordinate(r),i=this.pointCoordinate(this.centerPoint),a=this.locationCoordinate(e),o=new t.MercatorCoordinate(a.x-(n.x-i.x),a.y-(n.y-i.y));this.center=this.coordinateLocation(o),this._renderWorldCopies&&(this.center=this.center.wrap())},wn.prototype.locationPoint=function(t){return this.coordinatePoint(this.locationCoordinate(t))},wn.prototype.pointLocation=function(t){return this.coordinateLocation(this.pointCoordinate(t))},wn.prototype.locationCoordinate=function(e){return t.MercatorCoordinate.fromLngLat(e)},wn.prototype.coordinateLocation=function(t){return t.toLngLat()},wn.prototype.pointCoordinate=function(e){var r=[e.x,e.y,0,1],n=[e.x,e.y,1,1];t.transformMat4(r,r,this.pixelMatrixInverse),t.transformMat4(n,n,this.pixelMatrixInverse);var i=r[3],a=n[3],o=r[1]/i,s=n[1]/a,l=r[2]/i,c=n[2]/a,u=l===c?0:(0-l)/(c-l);return new t.MercatorCoordinate(t.number(r[0]/i,n[0]/a,u)/this.worldSize,t.number(o,s,u)/this.worldSize)},wn.prototype.coordinatePoint=function(e){var r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix),new t.Point(r[0]/r[3],r[1]/r[3])},wn.prototype.getBounds=function(){return(new t.LngLatBounds).extend(this.pointLocation(new t.Point(0,0))).extend(this.pointLocation(new t.Point(this.width,0))).extend(this.pointLocation(new t.Point(this.width,this.height))).extend(this.pointLocation(new t.Point(0,this.height)))},wn.prototype.getMaxBounds=function(){return this.latRange&&2===this.latRange.length&&this.lngRange&&2===this.lngRange.length?new t.LngLatBounds([this.lngRange[0],this.latRange[0]],[this.lngRange[1],this.latRange[1]]):null},wn.prototype.setMaxBounds=function(t){t?(this.lngRange=[t.getWest(),t.getEast()],this.latRange=[t.getSouth(),t.getNorth()],this._constrain()):(this.lngRange=null,this.latRange=[-this.maxValidLatitude,this.maxValidLatitude])},wn.prototype.calculatePosMatrix=function(e,r){void 0===r&&(r=!1);var n=e.key,i=r?this._alignedPosMatrixCache:this._posMatrixCache;if(i[n])return i[n];var a=e.canonical,o=this.worldSize/this.zoomScale(a.z),s=a.x+Math.pow(2,a.z)*e.wrap,l=t.identity(new Float64Array(16));return t.translate(l,l,[s*o,a.y*o,0]),t.scale(l,l,[o/t.EXTENT,o/t.EXTENT,1]),t.multiply(l,r?this.alignedProjMatrix:this.projMatrix,l),i[n]=new Float32Array(l),i[n]},wn.prototype.customLayerMatrix=function(){return this.mercatorMatrix.slice()},wn.prototype._constrain=function(){if(this.center&&this.width&&this.height&&!this._constraining){this._constraining=!0;var e,r,n,i,a=-90,o=90,s=-180,l=180,c=this.size,u=this._unmodified;if(this.latRange){var f=this.latRange;a=t.mercatorYfromLat(f[1])*this.worldSize,e=(o=t.mercatorYfromLat(f[0])*this.worldSize)-a<c.y?c.y/(o-a):0}if(this.lngRange){var h=this.lngRange;s=t.mercatorXfromLng(h[0])*this.worldSize,r=(l=t.mercatorXfromLng(h[1])*this.worldSize)-s<c.x?c.x/(l-s):0}var p=this.point,d=Math.max(r||0,e||0);if(d)return this.center=this.unproject(new t.Point(r?(l+s)/2:p.x,e?(o+a)/2:p.y)),this.zoom+=this.scaleZoom(d),this._unmodified=u,void(this._constraining=!1);if(this.latRange){var g=p.y,m=c.y/2;g-m<a&&(i=a+m),g+m>o&&(i=o-m)}if(this.lngRange){var v=p.x,y=c.x/2;v-y<s&&(n=s+y),v+y>l&&(n=l-y)}void 0===n&&void 0===i||(this.center=this.unproject(new t.Point(void 0!==n?n:p.x,void 0!==i?i:p.y))),this._unmodified=u,this._constraining=!1}},wn.prototype._calcMatrices=function(){if(this.height){var e=this.centerOffset;this.cameraToCenterDistance=.5/Math.tan(this._fov/2)*this.height;var r=Math.PI/2+this._pitch,n=this._fov*(.5+e.y/this.height),i=Math.sin(n)*this.cameraToCenterDistance/Math.sin(t.clamp(Math.PI-r-n,.01,Math.PI-.01)),a=this.point,o=a.x,s=a.y,l=1.01*(Math.cos(Math.PI/2-this._pitch)*i+this.cameraToCenterDistance),c=this.height/50,u=new Float64Array(16);t.perspective(u,this._fov,this.width/this.height,c,l),u[8]=2*-e.x/this.width,u[9]=2*e.y/this.height,t.scale(u,u,[1,-1,1]),t.translate(u,u,[0,0,-this.cameraToCenterDistance]),t.rotateX(u,u,this._pitch),t.rotateZ(u,u,this.angle),t.translate(u,u,[-o,-s,0]),this.mercatorMatrix=t.scale([],u,[this.worldSize,this.worldSize,this.worldSize]),t.scale(u,u,[1,1,t.mercatorZfromAltitude(1,this.center.lat)*this.worldSize,1]),this.projMatrix=u,this.invProjMatrix=t.invert([],this.projMatrix);var f=this.width%2/2,h=this.height%2/2,p=Math.cos(this.angle),d=Math.sin(this.angle),g=o-Math.round(o)+p*f+d*h,m=s-Math.round(s)+p*h+d*f,v=new Float64Array(u);if(t.translate(v,v,[g>.5?g-1:g,m>.5?m-1:m,0]),this.alignedProjMatrix=v,u=t.create(),t.scale(u,u,[this.width/2,-this.height/2,1]),t.translate(u,u,[1,-1,0]),this.labelPlaneMatrix=u,u=t.create(),t.scale(u,u,[1,-1,1]),t.translate(u,u,[-1,-1,0]),t.scale(u,u,[2/this.width,2/this.height,1]),this.glCoordMatrix=u,this.pixelMatrix=t.multiply(new Float64Array(16),this.labelPlaneMatrix,this.projMatrix),!(u=t.invert(new Float64Array(16),this.pixelMatrix)))throw new Error(\"failed to invert matrix\");this.pixelMatrixInverse=u,this._posMatrixCache={},this._alignedPosMatrixCache={}}},wn.prototype.maxPitchScaleFactor=function(){if(!this.pixelMatrixInverse)return 1;var e=this.pointCoordinate(new t.Point(0,0)),r=[e.x*this.worldSize,e.y*this.worldSize,0,1];return t.transformMat4(r,r,this.pixelMatrix)[3]/this.cameraToCenterDistance},wn.prototype.getCameraPoint=function(){var e=Math.tan(this._pitch)*(this.cameraToCenterDistance||1);return this.centerPoint.add(new t.Point(0,e))},wn.prototype.getCameraQueryGeometry=function(e){var r=this.getCameraPoint();if(1===e.length)return[e[0],r];for(var n=r.x,i=r.y,a=r.x,o=r.y,s=0,l=e;s<l.length;s+=1){var c=l[s];n=Math.min(n,c.x),i=Math.min(i,c.y),a=Math.max(a,c.x),o=Math.max(o,c.y)}return[new t.Point(n,i),new t.Point(a,i),new t.Point(a,o),new t.Point(n,o),new t.Point(n,i)]},Object.defineProperties(wn.prototype,Tn);var kn=function(e){var r,n,i,a;this._hashName=e&&encodeURIComponent(e),t.bindAll([\"_getCurrentHash\",\"_onHashChange\",\"_updateHash\"],this),this._updateHash=(r=this._updateHashUnthrottled.bind(this),n=!1,i=null,a=function(){i=null,n&&(r(),i=setTimeout(a,300),n=!1)},function(){return n=!0,i||a(),i})};kn.prototype.addTo=function(e){return this._map=e,t.window.addEventListener(\"hashchange\",this._onHashChange,!1),this._map.on(\"moveend\",this._updateHash),this},kn.prototype.remove=function(){return t.window.removeEventListener(\"hashchange\",this._onHashChange,!1),this._map.off(\"moveend\",this._updateHash),clearTimeout(this._updateHash()),delete this._map,this},kn.prototype.getHashString=function(e){var r=this._map.getCenter(),n=Math.round(100*this._map.getZoom())/100,i=Math.ceil((n*Math.LN2+Math.log(512/360/.5))/Math.LN10),a=Math.pow(10,i),o=Math.round(r.lng*a)/a,s=Math.round(r.lat*a)/a,l=this._map.getBearing(),c=this._map.getPitch(),u=\"\";if(u+=e?\"/\"+o+\"/\"+s+\"/\"+n:n+\"/\"+s+\"/\"+o,(l||c)&&(u+=\"/\"+Math.round(10*l)/10),c&&(u+=\"/\"+Math.round(c)),this._hashName){var f=this._hashName,h=!1,p=t.window.location.hash.slice(1).split(\"&\").map((function(t){var e=t.split(\"=\")[0];return e===f?(h=!0,e+\"=\"+u):t})).filter((function(t){return t}));return h||p.push(f+\"=\"+u),\"#\"+p.join(\"&\")}return\"#\"+u},kn.prototype._getCurrentHash=function(){var e,r=this,n=t.window.location.hash.replace(\"#\",\"\");return this._hashName?(n.split(\"&\").map((function(t){return t.split(\"=\")})).forEach((function(t){t[0]===r._hashName&&(e=t)})),(e&&e[1]||\"\").split(\"/\")):n.split(\"/\")},kn.prototype._onHashChange=function(){var t=this._getCurrentHash();if(t.length>=3&&!t.some((function(t){return isNaN(t)}))){var e=this._map.dragRotate.isEnabled()&&this._map.touchZoomRotate.isEnabled()?+(t[3]||0):this._map.getBearing();return this._map.jumpTo({center:[+t[2],+t[1]],zoom:+t[0],bearing:e,pitch:+(t[4]||0)}),!0}return!1},kn.prototype._updateHashUnthrottled=function(){var e=this.getHashString();try{t.window.history.replaceState(t.window.history.state,\"\",e)}catch(t){}};var Mn={linearity:.3,easing:t.bezier(0,0,.3,1)},An=t.extend({deceleration:2500,maxSpeed:1400},Mn),Sn=t.extend({deceleration:20,maxSpeed:1400},Mn),En=t.extend({deceleration:1e3,maxSpeed:360},Mn),Cn=t.extend({deceleration:1e3,maxSpeed:90},Mn),Ln=function(t){this._map=t,this.clear()};function In(t,e){(!t.duration||t.duration<e.duration)&&(t.duration=e.duration,t.easing=e.easing)}function Pn(e,r,n){var i=n.maxSpeed,a=n.linearity,o=n.deceleration,s=t.clamp(e*a/(r/1e3),-i,i),l=Math.abs(s)/(o*a);return{easing:n.easing,duration:1e3*l,amount:s*(l/2)}}Ln.prototype.clear=function(){this._inertiaBuffer=[]},Ln.prototype.record=function(e){this._drainInertiaBuffer(),this._inertiaBuffer.push({time:t.browser.now(),settings:e})},Ln.prototype._drainInertiaBuffer=function(){for(var e=this._inertiaBuffer,r=t.browser.now();e.length>0&&r-e[0].time>160;)e.shift()},Ln.prototype._onMoveEnd=function(e){if(this._drainInertiaBuffer(),!(this._inertiaBuffer.length<2)){for(var r={zoom:0,bearing:0,pitch:0,pan:new t.Point(0,0),pinchAround:void 0,around:void 0},n=0,i=this._inertiaBuffer;n<i.length;n+=1){var a=i[n].settings;r.zoom+=a.zoomDelta||0,r.bearing+=a.bearingDelta||0,r.pitch+=a.pitchDelta||0,a.panDelta&&r.pan._add(a.panDelta),a.around&&(r.around=a.around),a.pinchAround&&(r.pinchAround=a.pinchAround)}var o=this._inertiaBuffer[this._inertiaBuffer.length-1].time-this._inertiaBuffer[0].time,s={};if(r.pan.mag()){var l=Pn(r.pan.mag(),o,t.extend({},An,e||{}));s.offset=r.pan.mult(l.amount/r.pan.mag()),s.center=this._map.transform.center,In(s,l)}if(r.zoom){var c=Pn(r.zoom,o,Sn);s.zoom=this._map.transform.zoom+c.amount,In(s,c)}if(r.bearing){var u=Pn(r.bearing,o,En);s.bearing=this._map.transform.bearing+t.clamp(u.amount,-179,179),In(s,u)}if(r.pitch){var f=Pn(r.pitch,o,Cn);s.pitch=this._map.transform.pitch+f.amount,In(s,f)}if(s.zoom||s.bearing){var h=void 0===r.pinchAround?r.around:r.pinchAround;s.around=h?this._map.unproject(h):this._map.getCenter()}return this.clear(),t.extend(s,{noMoveStart:!0})}};var zn=function(e){function n(n,i,a,o){void 0===o&&(o={});var s=r.mousePos(i.getCanvasContainer(),a),l=i.unproject(s);e.call(this,n,t.extend({point:s,lngLat:l,originalEvent:a},o)),this._defaultPrevented=!1,this.target=i}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),On=function(e){function n(n,i,a){var o=\"touchend\"===n?a.changedTouches:a.touches,s=r.touchPos(i.getCanvasContainer(),o),l=s.map((function(t){return i.unproject(t)})),c=s.reduce((function(t,e,r,n){return t.add(e.div(n.length))}),new t.Point(0,0)),u=i.unproject(c);e.call(this,n,{points:s,point:c,lngLats:l,lngLat:u,originalEvent:a}),this._defaultPrevented=!1}e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n;var i={defaultPrevented:{configurable:!0}};return n.prototype.preventDefault=function(){this._defaultPrevented=!0},i.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(n.prototype,i),n}(t.Event),Dn=function(t){function e(e,r,n){t.call(this,e,{originalEvent:n}),this._defaultPrevented=!1}t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e;var r={defaultPrevented:{configurable:!0}};return e.prototype.preventDefault=function(){this._defaultPrevented=!0},r.defaultPrevented.get=function(){return this._defaultPrevented},Object.defineProperties(e.prototype,r),e}(t.Event),Rn=function(t,e){this._map=t,this._clickTolerance=e.clickTolerance};Rn.prototype.reset=function(){delete this._mousedownPos},Rn.prototype.wheel=function(t){return this._firePreventable(new Dn(t.type,this._map,t))},Rn.prototype.mousedown=function(t,e){return this._mousedownPos=e,this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseup=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.click=function(t,e){this._mousedownPos&&this._mousedownPos.dist(e)>=this._clickTolerance||this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.dblclick=function(t){return this._firePreventable(new zn(t.type,this._map,t))},Rn.prototype.mouseover=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.mouseout=function(t){this._map.fire(new zn(t.type,this._map,t))},Rn.prototype.touchstart=function(t){return this._firePreventable(new On(t.type,this._map,t))},Rn.prototype.touchmove=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchend=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype.touchcancel=function(t){this._map.fire(new On(t.type,this._map,t))},Rn.prototype._firePreventable=function(t){if(this._map.fire(t),t.defaultPrevented)return{}},Rn.prototype.isEnabled=function(){return!0},Rn.prototype.isActive=function(){return!1},Rn.prototype.enable=function(){},Rn.prototype.disable=function(){};var Fn=function(t){this._map=t};Fn.prototype.reset=function(){this._delayContextMenu=!1,delete this._contextMenuEvent},Fn.prototype.mousemove=function(t){this._map.fire(new zn(t.type,this._map,t))},Fn.prototype.mousedown=function(){this._delayContextMenu=!0},Fn.prototype.mouseup=function(){this._delayContextMenu=!1,this._contextMenuEvent&&(this._map.fire(new zn(\"contextmenu\",this._map,this._contextMenuEvent)),delete this._contextMenuEvent)},Fn.prototype.contextmenu=function(t){this._delayContextMenu?this._contextMenuEvent=t:this._map.fire(new zn(t.type,this._map,t)),this._map.listens(\"contextmenu\")&&t.preventDefault()},Fn.prototype.isEnabled=function(){return!0},Fn.prototype.isActive=function(){return!1},Fn.prototype.enable=function(){},Fn.prototype.disable=function(){};var Bn=function(t,e){this._map=t,this._el=t.getCanvasContainer(),this._container=t.getContainer(),this._clickTolerance=e.clickTolerance||1};function Nn(t,e){for(var r={},n=0;n<t.length;n++)r[t[n].identifier]=e[n];return r}Bn.prototype.isEnabled=function(){return!!this._enabled},Bn.prototype.isActive=function(){return!!this._active},Bn.prototype.enable=function(){this.isEnabled()||(this._enabled=!0)},Bn.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},Bn.prototype.mousedown=function(t,e){this.isEnabled()&&t.shiftKey&&0===t.button&&(r.disableDrag(),this._startPos=this._lastPos=e,this._active=!0)},Bn.prototype.mousemoveWindow=function(t,e){if(this._active){var n=e;if(!(this._lastPos.equals(n)||!this._box&&n.dist(this._startPos)<this._clickTolerance)){var i=this._startPos;this._lastPos=n,this._box||(this._box=r.create(\"div\",\"mapboxgl-boxzoom\",this._container),this._container.classList.add(\"mapboxgl-crosshair\"),this._fireEvent(\"boxzoomstart\",t));var a=Math.min(i.x,n.x),o=Math.max(i.x,n.x),s=Math.min(i.y,n.y),l=Math.max(i.y,n.y);r.setTransform(this._box,\"translate(\"+a+\"px,\"+s+\"px)\"),this._box.style.width=o-a+\"px\",this._box.style.height=l-s+\"px\"}}},Bn.prototype.mouseupWindow=function(e,n){var i=this;if(this._active&&0===e.button){var a=this._startPos,o=n;if(this.reset(),r.suppressClick(),a.x!==o.x||a.y!==o.y)return this._map.fire(new t.Event(\"boxzoomend\",{originalEvent:e})),{cameraAnimation:function(t){return t.fitScreenCoordinates(a,o,i._map.getBearing(),{linear:!0})}};this._fireEvent(\"boxzoomcancel\",e)}},Bn.prototype.keydown=function(t){this._active&&27===t.keyCode&&(this.reset(),this._fireEvent(\"boxzoomcancel\",t))},Bn.prototype.reset=function(){this._active=!1,this._container.classList.remove(\"mapboxgl-crosshair\"),this._box&&(r.remove(this._box),this._box=null),r.enableDrag(),delete this._startPos,delete this._lastPos},Bn.prototype._fireEvent=function(e,r){return this._map.fire(new t.Event(e,{originalEvent:r}))};var jn=function(t){this.reset(),this.numTouches=t.numTouches};jn.prototype.reset=function(){delete this.centroid,delete this.startTime,delete this.touches,this.aborted=!1},jn.prototype.touchstart=function(e,r,n){(this.centroid||n.length>this.numTouches)&&(this.aborted=!0),this.aborted||(void 0===this.startTime&&(this.startTime=e.timeStamp),n.length===this.numTouches&&(this.centroid=function(e){for(var r=new t.Point(0,0),n=0,i=e;n<i.length;n+=1)r._add(i[n]);return r.div(e.length)}(r),this.touches=Nn(n,r)))},jn.prototype.touchmove=function(t,e,r){if(!this.aborted&&this.centroid){var n=Nn(r,e);for(var i in this.touches){var a=n[i];(!a||a.dist(this.touches[i])>30)&&(this.aborted=!0)}}},jn.prototype.touchend=function(t,e,r){if((!this.centroid||t.timeStamp-this.startTime>500)&&(this.aborted=!0),0===r.length){var n=!this.aborted&&this.centroid;if(this.reset(),n)return n}};var Un=function(t){this.singleTap=new jn(t),this.numTaps=t.numTaps,this.reset()};Un.prototype.reset=function(){this.lastTime=1/0,delete this.lastTap,this.count=0,this.singleTap.reset()},Un.prototype.touchstart=function(t,e,r){this.singleTap.touchstart(t,e,r)},Un.prototype.touchmove=function(t,e,r){this.singleTap.touchmove(t,e,r)},Un.prototype.touchend=function(t,e,r){var n=this.singleTap.touchend(t,e,r);if(n){var i=t.timeStamp-this.lastTime<500,a=!this.lastTap||this.lastTap.dist(n)<30;if(i&&a||this.reset(),this.count++,this.lastTime=t.timeStamp,this.lastTap=n,this.count===this.numTaps)return this.reset(),n}};var Vn=function(){this._zoomIn=new Un({numTouches:1,numTaps:2}),this._zoomOut=new Un({numTouches:2,numTaps:1}),this.reset()};Vn.prototype.reset=function(){this._active=!1,this._zoomIn.reset(),this._zoomOut.reset()},Vn.prototype.touchstart=function(t,e,r){this._zoomIn.touchstart(t,e,r),this._zoomOut.touchstart(t,e,r)},Vn.prototype.touchmove=function(t,e,r){this._zoomIn.touchmove(t,e,r),this._zoomOut.touchmove(t,e,r)},Vn.prototype.touchend=function(t,e,r){var n=this,i=this._zoomIn.touchend(t,e,r),a=this._zoomOut.touchend(t,e,r);return i?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()+1,around:e.unproject(i)},{originalEvent:t})}}):a?(this._active=!0,t.preventDefault(),setTimeout((function(){return n.reset()}),0),{cameraAnimation:function(e){return e.easeTo({duration:300,zoom:e.getZoom()-1,around:e.unproject(a)},{originalEvent:t})}}):void 0},Vn.prototype.touchcancel=function(){this.reset()},Vn.prototype.enable=function(){this._enabled=!0},Vn.prototype.disable=function(){this._enabled=!1,this.reset()},Vn.prototype.isEnabled=function(){return this._enabled},Vn.prototype.isActive=function(){return this._active};var qn=function(t){this.reset(),this._clickTolerance=t.clickTolerance||1};qn.prototype.reset=function(){this._active=!1,this._moved=!1,delete this._lastPoint,delete this._eventButton},qn.prototype._correctButton=function(t,e){return!1},qn.prototype._move=function(t,e){return{}},qn.prototype.mousedown=function(t,e){if(!this._lastPoint){var n=r.mouseButton(t);this._correctButton(t,n)&&(this._lastPoint=e,this._eventButton=n)}},qn.prototype.mousemoveWindow=function(t,e){var r=this._lastPoint;if(r&&(t.preventDefault(),this._moved||!(e.dist(r)<this._clickTolerance)))return this._moved=!0,this._lastPoint=e,this._move(r,e)},qn.prototype.mouseupWindow=function(t){r.mouseButton(t)===this._eventButton&&(this._moved&&r.suppressClick(),this.reset())},qn.prototype.enable=function(){this._enabled=!0},qn.prototype.disable=function(){this._enabled=!1,this.reset()},qn.prototype.isEnabled=function(){return this._enabled},qn.prototype.isActive=function(){return this._active};var Hn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.mousedown=function(e,r){t.prototype.mousedown.call(this,e,r),this._lastPoint&&(this._active=!0)},e.prototype._correctButton=function(t,e){return 0===e&&!t.ctrlKey},e.prototype._move=function(t,e){return{around:e,panDelta:e.sub(t)}},e}(qn),Gn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=.8*(e.x-t.x);if(r)return this._active=!0,{bearingDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Yn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype._correctButton=function(t,e){return 0===e&&t.ctrlKey||2===e},e.prototype._move=function(t,e){var r=-.5*(e.y-t.y);if(r)return this._active=!0,{pitchDelta:r}},e.prototype.contextmenu=function(t){t.preventDefault()},e}(qn),Wn=function(t){this._minTouches=1,this._clickTolerance=t.clickTolerance||1,this.reset()};Wn.prototype.reset=function(){this._active=!1,this._touches={},this._sum=new t.Point(0,0)},Wn.prototype.touchstart=function(t,e,r){return this._calculateTransform(t,e,r)},Wn.prototype.touchmove=function(t,e,r){if(this._active)return t.preventDefault(),this._calculateTransform(t,e,r)},Wn.prototype.touchend=function(t,e,r){this._calculateTransform(t,e,r),this._active&&r.length<this._minTouches&&this.reset()},Wn.prototype.touchcancel=function(){this.reset()},Wn.prototype._calculateTransform=function(e,r,n){n.length>0&&(this._active=!0);var i=Nn(n,r),a=new t.Point(0,0),o=new t.Point(0,0),s=0;for(var l in i){var c=i[l],u=this._touches[l];u&&(a._add(c),o._add(c.sub(u)),s++,i[l]=c)}if(this._touches=i,!(s<this._minTouches)&&o.mag()){var f=o.div(s);if(this._sum._add(f),!(this._sum.mag()<this._clickTolerance))return{around:a.div(s),panDelta:f}}},Wn.prototype.enable=function(){this._enabled=!0},Wn.prototype.disable=function(){this._enabled=!1,this.reset()},Wn.prototype.isEnabled=function(){return this._enabled},Wn.prototype.isActive=function(){return this._active};var Xn=function(){this.reset()};function Zn(t,e,r){for(var n=0;n<t.length;n++)if(t[n].identifier===r)return e[n]}function Jn(t,e){return Math.log(t/e)/Math.LN2}Xn.prototype.reset=function(){this._active=!1,delete this._firstTwoTouches},Xn.prototype._start=function(t){},Xn.prototype._move=function(t,e,r){return{}},Xn.prototype.touchstart=function(t,e,r){this._firstTwoTouches||r.length<2||(this._firstTwoTouches=[r[0].identifier,r[1].identifier],this._start([e[0],e[1]]))},Xn.prototype.touchmove=function(t,e,r){if(this._firstTwoTouches){t.preventDefault();var n=this._firstTwoTouches,i=n[1],a=Zn(r,e,n[0]),o=Zn(r,e,i);if(a&&o){var s=this._aroundCenter?null:a.add(o).div(2);return this._move([a,o],s,t)}}},Xn.prototype.touchend=function(t,e,n){if(this._firstTwoTouches){var i=this._firstTwoTouches,a=i[1],o=Zn(n,e,i[0]),s=Zn(n,e,a);o&&s||(this._active&&r.suppressClick(),this.reset())}},Xn.prototype.touchcancel=function(){this.reset()},Xn.prototype.enable=function(t){this._enabled=!0,this._aroundCenter=!!t&&\"center\"===t.around},Xn.prototype.disable=function(){this._enabled=!1,this.reset()},Xn.prototype.isEnabled=function(){return this._enabled},Xn.prototype.isActive=function(){return this._active};var Kn=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._distance,delete this._startDistance},e.prototype._start=function(t){this._startDistance=this._distance=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._distance;if(this._distance=t[0].dist(t[1]),this._active||!(Math.abs(Jn(this._distance,this._startDistance))<.1))return this._active=!0,{zoomDelta:Jn(this._distance,r),pinchAround:e}},e}(Xn);function Qn(t,e){return 180*t.angleWith(e)/Math.PI}var $n=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),delete this._minDiameter,delete this._startVector,delete this._vector},e.prototype._start=function(t){this._startVector=this._vector=t[0].sub(t[1]),this._minDiameter=t[0].dist(t[1])},e.prototype._move=function(t,e){var r=this._vector;if(this._vector=t[0].sub(t[1]),this._active||!this._isBelowThreshold(this._vector))return this._active=!0,{bearingDelta:Qn(this._vector,r),pinchAround:e}},e.prototype._isBelowThreshold=function(t){this._minDiameter=Math.min(this._minDiameter,t.mag());var e=25/(Math.PI*this._minDiameter)*360,r=Qn(t,this._startVector);return Math.abs(r)<e},e}(Xn);function ti(t){return Math.abs(t.y)>Math.abs(t.x)}var ei=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e.prototype.reset=function(){t.prototype.reset.call(this),this._valid=void 0,delete this._firstMove,delete this._lastPoints},e.prototype._start=function(t){this._lastPoints=t,ti(t[0].sub(t[1]))&&(this._valid=!1)},e.prototype._move=function(t,e,r){var n=t[0].sub(this._lastPoints[0]),i=t[1].sub(this._lastPoints[1]);if(this._valid=this.gestureBeginsVertically(n,i,r.timeStamp),this._valid)return this._lastPoints=t,this._active=!0,{pitchDelta:(n.y+i.y)/2*-.5}},e.prototype.gestureBeginsVertically=function(t,e,r){if(void 0!==this._valid)return this._valid;var n=t.mag()>=2,i=e.mag()>=2;if(n||i){if(!n||!i)return void 0===this._firstMove&&(this._firstMove=r),r-this._firstMove<100&&void 0;var a=t.y>0==e.y>0;return ti(t)&&ti(e)&&a}},e}(Xn),ri={panStep:100,bearingStep:15,pitchStep:10},ni=function(){var t=ri;this._panStep=t.panStep,this._bearingStep=t.bearingStep,this._pitchStep=t.pitchStep};function ii(t){return t*(2-t)}ni.prototype.reset=function(){this._active=!1},ni.prototype.keydown=function(t){var e=this;if(!(t.altKey||t.ctrlKey||t.metaKey)){var r=0,n=0,i=0,a=0,o=0;switch(t.keyCode){case 61:case 107:case 171:case 187:r=1;break;case 189:case 109:case 173:r=-1;break;case 37:t.shiftKey?n=-1:(t.preventDefault(),a=-1);break;case 39:t.shiftKey?n=1:(t.preventDefault(),a=1);break;case 38:t.shiftKey?i=1:(t.preventDefault(),o=-1);break;case 40:t.shiftKey?i=-1:(t.preventDefault(),o=1);break;default:return}return{cameraAnimation:function(s){var l=s.getZoom();s.easeTo({duration:300,easeId:\"keyboardHandler\",easing:ii,zoom:r?Math.round(l)+r*(t.shiftKey?2:1):l,bearing:s.getBearing()+n*e._bearingStep,pitch:s.getPitch()+i*e._pitchStep,offset:[-a*e._panStep,-o*e._panStep],center:s.getCenter()},{originalEvent:t})}}}},ni.prototype.enable=function(){this._enabled=!0},ni.prototype.disable=function(){this._enabled=!1,this.reset()},ni.prototype.isEnabled=function(){return this._enabled},ni.prototype.isActive=function(){return this._active};var ai=function(e,r){this._map=e,this._el=e.getCanvasContainer(),this._handler=r,this._delta=0,this._defaultZoomRate=.01,this._wheelZoomRate=1/450,t.bindAll([\"_onWheel\",\"_onTimeout\",\"_onScrollFrame\",\"_onScrollFinished\"],this)};ai.prototype.setZoomRate=function(t){this._defaultZoomRate=t},ai.prototype.setWheelZoomRate=function(t){this._wheelZoomRate=t},ai.prototype.isEnabled=function(){return!!this._enabled},ai.prototype.isActive=function(){return!!this._active||void 0!==this._finishTimeout},ai.prototype.isZooming=function(){return!!this._zooming},ai.prototype.enable=function(t){this.isEnabled()||(this._enabled=!0,this._aroundCenter=t&&\"center\"===t.around)},ai.prototype.disable=function(){this.isEnabled()&&(this._enabled=!1)},ai.prototype.wheel=function(e){if(this.isEnabled()){var r=e.deltaMode===t.window.WheelEvent.DOM_DELTA_LINE?40*e.deltaY:e.deltaY,n=t.browser.now(),i=n-(this._lastWheelEventTime||0);this._lastWheelEventTime=n,0!==r&&r%4.000244140625==0?this._type=\"wheel\":0!==r&&Math.abs(r)<4?this._type=\"trackpad\":i>400?(this._type=null,this._lastValue=r,this._timeout=setTimeout(this._onTimeout,40,e)):this._type||(this._type=Math.abs(i*r)<200?\"trackpad\":\"wheel\",this._timeout&&(clearTimeout(this._timeout),this._timeout=null,r+=this._lastValue)),e.shiftKey&&r&&(r/=4),this._type&&(this._lastWheelEvent=e,this._delta-=r,this._active||this._start(e)),e.preventDefault()}},ai.prototype._onTimeout=function(t){this._type=\"wheel\",this._delta-=this._lastValue,this._active||this._start(t)},ai.prototype._start=function(e){if(this._delta){this._frameId&&(this._frameId=null),this._active=!0,this.isZooming()||(this._zooming=!0),this._finishTimeout&&(clearTimeout(this._finishTimeout),delete this._finishTimeout);var n=r.mousePos(this._el,e);this._around=t.LngLat.convert(this._aroundCenter?this._map.getCenter():this._map.unproject(n)),this._aroundPoint=this._map.transform.locationPoint(this._around),this._frameId||(this._frameId=!0,this._handler._triggerRenderFrame())}},ai.prototype.renderFrame=function(){return this._onScrollFrame()},ai.prototype._onScrollFrame=function(){var e=this;if(this._frameId&&(this._frameId=null,this.isActive())){var r=this._map.transform;if(0!==this._delta){var n=\"wheel\"===this._type&&Math.abs(this._delta)>4.000244140625?this._wheelZoomRate:this._defaultZoomRate,i=2/(1+Math.exp(-Math.abs(this._delta*n)));this._delta<0&&0!==i&&(i=1/i);var a=\"number\"==typeof this._targetZoom?r.zoomScale(this._targetZoom):r.scale;this._targetZoom=Math.min(r.maxZoom,Math.max(r.minZoom,r.scaleZoom(a*i))),\"wheel\"===this._type&&(this._startZoom=r.zoom,this._easing=this._smoothOutEasing(200)),this._delta=0}var o,s=\"number\"==typeof this._targetZoom?this._targetZoom:r.zoom,l=this._startZoom,c=this._easing,u=!1;if(\"wheel\"===this._type&&l&&c){var f=Math.min((t.browser.now()-this._lastWheelEventTime)/200,1),h=c(f);o=t.number(l,s,h),f<1?this._frameId||(this._frameId=!0):u=!0}else o=s,u=!0;return this._active=!0,u&&(this._active=!1,this._finishTimeout=setTimeout((function(){e._zooming=!1,e._handler._triggerRenderFrame(),delete e._targetZoom,delete e._finishTimeout}),200)),{noInertia:!0,needsRenderFrame:!u,zoomDelta:o-r.zoom,around:this._aroundPoint,originalEvent:this._lastWheelEvent}}},ai.prototype._smoothOutEasing=function(e){var r=t.ease;if(this._prevEase){var n=this._prevEase,i=(t.browser.now()-n.start)/n.duration,a=n.easing(i+.01)-n.easing(i),o=.27/Math.sqrt(a*a+1e-4)*.01,s=Math.sqrt(.0729-o*o);r=t.bezier(o,s,.25,1)}return this._prevEase={start:t.browser.now(),duration:e,easing:r},r},ai.prototype.reset=function(){this._active=!1};var oi=function(t,e){this._clickZoom=t,this._tapZoom=e};oi.prototype.enable=function(){this._clickZoom.enable(),this._tapZoom.enable()},oi.prototype.disable=function(){this._clickZoom.disable(),this._tapZoom.disable()},oi.prototype.isEnabled=function(){return this._clickZoom.isEnabled()&&this._tapZoom.isEnabled()},oi.prototype.isActive=function(){return this._clickZoom.isActive()||this._tapZoom.isActive()};var si=function(){this.reset()};si.prototype.reset=function(){this._active=!1},si.prototype.dblclick=function(t,e){return t.preventDefault(),{cameraAnimation:function(r){r.easeTo({duration:300,zoom:r.getZoom()+(t.shiftKey?-1:1),around:r.unproject(e)},{originalEvent:t})}}},si.prototype.enable=function(){this._enabled=!0},si.prototype.disable=function(){this._enabled=!1,this.reset()},si.prototype.isEnabled=function(){return this._enabled},si.prototype.isActive=function(){return this._active};var li=function(){this._tap=new Un({numTouches:1,numTaps:1}),this.reset()};li.prototype.reset=function(){this._active=!1,delete this._swipePoint,delete this._swipeTouch,delete this._tapTime,this._tap.reset()},li.prototype.touchstart=function(t,e,r){this._swipePoint||(this._tapTime&&t.timeStamp-this._tapTime>500&&this.reset(),this._tapTime?r.length>0&&(this._swipePoint=e[0],this._swipeTouch=r[0].identifier):this._tap.touchstart(t,e,r))},li.prototype.touchmove=function(t,e,r){if(this._tapTime){if(this._swipePoint){if(r[0].identifier!==this._swipeTouch)return;var n=e[0],i=n.y-this._swipePoint.y;return this._swipePoint=n,t.preventDefault(),this._active=!0,{zoomDelta:i/128}}}else this._tap.touchmove(t,e,r)},li.prototype.touchend=function(t,e,r){this._tapTime?this._swipePoint&&0===r.length&&this.reset():this._tap.touchend(t,e,r)&&(this._tapTime=t.timeStamp)},li.prototype.touchcancel=function(){this.reset()},li.prototype.enable=function(){this._enabled=!0},li.prototype.disable=function(){this._enabled=!1,this.reset()},li.prototype.isEnabled=function(){return this._enabled},li.prototype.isActive=function(){return this._active};var ci=function(t,e,r){this._el=t,this._mousePan=e,this._touchPan=r};ci.prototype.enable=function(t){this._inertiaOptions=t||{},this._mousePan.enable(),this._touchPan.enable(),this._el.classList.add(\"mapboxgl-touch-drag-pan\")},ci.prototype.disable=function(){this._mousePan.disable(),this._touchPan.disable(),this._el.classList.remove(\"mapboxgl-touch-drag-pan\")},ci.prototype.isEnabled=function(){return this._mousePan.isEnabled()&&this._touchPan.isEnabled()},ci.prototype.isActive=function(){return this._mousePan.isActive()||this._touchPan.isActive()};var ui=function(t,e,r){this._pitchWithRotate=t.pitchWithRotate,this._mouseRotate=e,this._mousePitch=r};ui.prototype.enable=function(){this._mouseRotate.enable(),this._pitchWithRotate&&this._mousePitch.enable()},ui.prototype.disable=function(){this._mouseRotate.disable(),this._mousePitch.disable()},ui.prototype.isEnabled=function(){return this._mouseRotate.isEnabled()&&(!this._pitchWithRotate||this._mousePitch.isEnabled())},ui.prototype.isActive=function(){return this._mouseRotate.isActive()||this._mousePitch.isActive()};var fi=function(t,e,r,n){this._el=t,this._touchZoom=e,this._touchRotate=r,this._tapDragZoom=n,this._rotationDisabled=!1,this._enabled=!0};fi.prototype.enable=function(t){this._touchZoom.enable(t),this._rotationDisabled||this._touchRotate.enable(t),this._tapDragZoom.enable(),this._el.classList.add(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.disable=function(){this._touchZoom.disable(),this._touchRotate.disable(),this._tapDragZoom.disable(),this._el.classList.remove(\"mapboxgl-touch-zoom-rotate\")},fi.prototype.isEnabled=function(){return this._touchZoom.isEnabled()&&(this._rotationDisabled||this._touchRotate.isEnabled())&&this._tapDragZoom.isEnabled()},fi.prototype.isActive=function(){return this._touchZoom.isActive()||this._touchRotate.isActive()||this._tapDragZoom.isActive()},fi.prototype.disableRotation=function(){this._rotationDisabled=!0,this._touchRotate.disable()},fi.prototype.enableRotation=function(){this._rotationDisabled=!1,this._touchZoom.isEnabled()&&this._touchRotate.enable()};var hi=function(t){return t.zoom||t.drag||t.pitch||t.rotate},pi=function(t){function e(){t.apply(this,arguments)}return t&&(e.__proto__=t),(e.prototype=Object.create(t&&t.prototype)).constructor=e,e}(t.Event);function di(t){return t.panDelta&&t.panDelta.mag()||t.zoomDelta||t.bearingDelta||t.pitchDelta}var gi=function(e,n){this._map=e,this._el=this._map.getCanvasContainer(),this._handlers=[],this._handlersById={},this._changes=[],this._inertia=new Ln(e),this._bearingSnap=n.bearingSnap,this._previousActiveHandlers={},this._eventsInProgress={},this._addDefaultHandlers(n),t.bindAll([\"handleEvent\",\"handleWindowEvent\"],this);var i=this._el;this._listeners=[[i,\"touchstart\",{passive:!1}],[i,\"touchmove\",{passive:!1}],[i,\"touchend\",void 0],[i,\"touchcancel\",void 0],[i,\"mousedown\",void 0],[i,\"mousemove\",void 0],[i,\"mouseup\",void 0],[t.window.document,\"mousemove\",{capture:!0}],[t.window.document,\"mouseup\",void 0],[i,\"mouseover\",void 0],[i,\"mouseout\",void 0],[i,\"dblclick\",void 0],[i,\"click\",void 0],[i,\"keydown\",{capture:!1}],[i,\"keyup\",void 0],[i,\"wheel\",{passive:!1}],[i,\"contextmenu\",void 0],[t.window,\"blur\",void 0]];for(var a=0,o=this._listeners;a<o.length;a+=1){var s=o[a],l=s[0];r.addEventListener(l,s[1],l===t.window.document?this.handleWindowEvent:this.handleEvent,s[2])}};gi.prototype.destroy=function(){for(var e=0,n=this._listeners;e<n.length;e+=1){var i=n[e],a=i[0];r.removeEventListener(a,i[1],a===t.window.document?this.handleWindowEvent:this.handleEvent,i[2])}},gi.prototype._addDefaultHandlers=function(t){var e=this._map,r=e.getCanvasContainer();this._add(\"mapEvent\",new Rn(e,t));var n=e.boxZoom=new Bn(e,t);this._add(\"boxZoom\",n);var i=new Vn,a=new si;e.doubleClickZoom=new oi(a,i),this._add(\"tapZoom\",i),this._add(\"clickZoom\",a);var o=new li;this._add(\"tapDragZoom\",o);var s=e.touchPitch=new ei;this._add(\"touchPitch\",s);var l=new Gn(t),c=new Yn(t);e.dragRotate=new ui(t,l,c),this._add(\"mouseRotate\",l,[\"mousePitch\"]),this._add(\"mousePitch\",c,[\"mouseRotate\"]);var u=new Hn(t),f=new Wn(t);e.dragPan=new ci(r,u,f),this._add(\"mousePan\",u),this._add(\"touchPan\",f,[\"touchZoom\",\"touchRotate\"]);var h=new $n,p=new Kn;e.touchZoomRotate=new fi(r,p,h,o),this._add(\"touchRotate\",h,[\"touchPan\",\"touchZoom\"]),this._add(\"touchZoom\",p,[\"touchPan\",\"touchRotate\"]);var d=e.scrollZoom=new ai(e,this);this._add(\"scrollZoom\",d,[\"mousePan\"]);var g=e.keyboard=new ni;this._add(\"keyboard\",g),this._add(\"blockableMapEvent\",new Fn(e));for(var m=0,v=[\"boxZoom\",\"doubleClickZoom\",\"tapDragZoom\",\"touchPitch\",\"dragRotate\",\"dragPan\",\"touchZoomRotate\",\"scrollZoom\",\"keyboard\"];m<v.length;m+=1){var y=v[m];t.interactive&&t[y]&&e[y].enable(t[y])}},gi.prototype._add=function(t,e,r){this._handlers.push({handlerName:t,handler:e,allowed:r}),this._handlersById[t]=e},gi.prototype.stop=function(){if(!this._updatingCamera){for(var t=0,e=this._handlers;t<e.length;t+=1)e[t].handler.reset();this._inertia.clear(),this._fireEvents({},{}),this._changes=[]}},gi.prototype.isActive=function(){for(var t=0,e=this._handlers;t<e.length;t+=1)if(e[t].handler.isActive())return!0;return!1},gi.prototype.isZooming=function(){return!!this._eventsInProgress.zoom||this._map.scrollZoom.isZooming()},gi.prototype.isRotating=function(){return!!this._eventsInProgress.rotate},gi.prototype.isMoving=function(){return Boolean(hi(this._eventsInProgress))||this.isZooming()},gi.prototype._blockedByActive=function(t,e,r){for(var n in t)if(n!==r&&(!e||e.indexOf(n)<0))return!0;return!1},gi.prototype.handleWindowEvent=function(t){this.handleEvent(t,t.type+\"Window\")},gi.prototype._getMapTouches=function(t){for(var e=[],r=0,n=t;r<n.length;r+=1){var i=n[r];this._el.contains(i.target)&&e.push(i)}return e},gi.prototype.handleEvent=function(t,e){if(\"blur\"!==t.type){this._updatingCamera=!0;for(var n=\"renderFrame\"===t.type?void 0:t,i={needsRenderFrame:!1},a={},o={},s=t.touches?this._getMapTouches(t.touches):void 0,l=s?r.touchPos(this._el,s):r.mousePos(this._el,t),c=0,u=this._handlers;c<u.length;c+=1){var f=u[c],h=f.handlerName,p=f.handler,d=f.allowed;if(p.isEnabled()){var g=void 0;this._blockedByActive(o,d,h)?p.reset():p[e||t.type]&&(g=p[e||t.type](t,l,s),this.mergeHandlerResult(i,a,g,h,n),g&&g.needsRenderFrame&&this._triggerRenderFrame()),(g||p.isActive())&&(o[h]=p)}}var m={};for(var v in this._previousActiveHandlers)o[v]||(m[v]=n);this._previousActiveHandlers=o,(Object.keys(m).length||di(i))&&(this._changes.push([i,a,m]),this._triggerRenderFrame()),(Object.keys(o).length||di(i))&&this._map._stop(!0),this._updatingCamera=!1;var y=i.cameraAnimation;y&&(this._inertia.clear(),this._fireEvents({},{}),this._changes=[],y(this._map))}else this.stop()},gi.prototype.mergeHandlerResult=function(e,r,n,i,a){if(n){t.extend(e,n);var o={handlerName:i,originalEvent:n.originalEvent||a};void 0!==n.zoomDelta&&(r.zoom=o),void 0!==n.panDelta&&(r.drag=o),void 0!==n.pitchDelta&&(r.pitch=o),void 0!==n.bearingDelta&&(r.rotate=o)}},gi.prototype._applyChanges=function(){for(var e={},r={},n={},i=0,a=this._changes;i<a.length;i+=1){var o=a[i],s=o[0],l=o[1],c=o[2];s.panDelta&&(e.panDelta=(e.panDelta||new t.Point(0,0))._add(s.panDelta)),s.zoomDelta&&(e.zoomDelta=(e.zoomDelta||0)+s.zoomDelta),s.bearingDelta&&(e.bearingDelta=(e.bearingDelta||0)+s.bearingDelta),s.pitchDelta&&(e.pitchDelta=(e.pitchDelta||0)+s.pitchDelta),void 0!==s.around&&(e.around=s.around),void 0!==s.pinchAround&&(e.pinchAround=s.pinchAround),s.noInertia&&(e.noInertia=s.noInertia),t.extend(r,l),t.extend(n,c)}this._updateMapTransform(e,r,n),this._changes=[]},gi.prototype._updateMapTransform=function(t,e,r){var n=this._map,i=n.transform;if(!di(t))return this._fireEvents(e,r);var a=t.panDelta,o=t.zoomDelta,s=t.bearingDelta,l=t.pitchDelta,c=t.around,u=t.pinchAround;void 0!==u&&(c=u),n._stop(!0),c=c||n.transform.centerPoint;var f=i.pointLocation(a?c.sub(a):c);s&&(i.bearing+=s),l&&(i.pitch+=l),o&&(i.zoom+=o),i.setLocationAtPoint(f,c),this._map._update(),t.noInertia||this._inertia.record(t),this._fireEvents(e,r)},gi.prototype._fireEvents=function(e,r){var n=this,i=hi(this._eventsInProgress),a=hi(e),o={};for(var s in e)this._eventsInProgress[s]||(o[s+\"start\"]=e[s].originalEvent),this._eventsInProgress[s]=e[s];for(var l in!i&&a&&this._fireEvent(\"movestart\",a.originalEvent),o)this._fireEvent(l,o[l]);for(var c in e.rotate&&(this._bearingChanged=!0),a&&this._fireEvent(\"move\",a.originalEvent),e)this._fireEvent(c,e[c].originalEvent);var u,f={};for(var h in this._eventsInProgress){var p=this._eventsInProgress[h],d=p.handlerName,g=p.originalEvent;this._handlersById[d].isActive()||(delete this._eventsInProgress[h],f[h+\"end\"]=u=r[d]||g)}for(var m in f)this._fireEvent(m,f[m]);var v=hi(this._eventsInProgress);if((i||a)&&!v){this._updatingCamera=!0;var y=this._inertia._onMoveEnd(this._map.dragPan._inertiaOptions),x=function(t){return 0!==t&&-n._bearingSnap<t&&t<n._bearingSnap};y?(x(y.bearing||this._map.getBearing())&&(y.bearing=0),this._map.easeTo(y,{originalEvent:u})):(this._map.fire(new t.Event(\"moveend\",{originalEvent:u})),x(this._map.getBearing())&&this._map.resetNorth()),this._bearingChanged=!1,this._updatingCamera=!1}},gi.prototype._fireEvent=function(e,r){this._map.fire(new t.Event(e,r?{originalEvent:r}:{}))},gi.prototype._triggerRenderFrame=function(){var t=this;void 0===this._frameId&&(this._frameId=this._map._requestRenderFrame((function(e){delete t._frameId,t.handleEvent(new pi(\"renderFrame\",{timeStamp:e})),t._applyChanges()})))};var mi=function(e){function r(r,n){e.call(this),this._moving=!1,this._zooming=!1,this.transform=r,this._bearingSnap=n.bearingSnap,t.bindAll([\"_renderFrameCallback\"],this)}return e&&(r.__proto__=e),(r.prototype=Object.create(e&&e.prototype)).constructor=r,r.prototype.getCenter=function(){return new t.LngLat(this.transform.center.lng,this.transform.center.lat)},r.prototype.setCenter=function(t,e){return this.jumpTo({center:t},e)},r.prototype.panBy=function(e,r,n){return e=t.Point.convert(e).mult(-1),this.panTo(this.transform.center,t.extend({offset:e},r),n)},r.prototype.panTo=function(e,r,n){return this.easeTo(t.extend({center:e},r),n)},r.prototype.getZoom=function(){return this.transform.zoom},r.prototype.setZoom=function(t,e){return this.jumpTo({zoom:t},e),this},r.prototype.zoomTo=function(e,r,n){return this.easeTo(t.extend({zoom:e},r),n)},r.prototype.zoomIn=function(t,e){return this.zoomTo(this.getZoom()+1,t,e),this},r.prototype.zoomOut=function(t,e){return this.zoomTo(this.getZoom()-1,t,e),this},r.prototype.getBearing=function(){return this.transform.bearing},r.prototype.setBearing=function(t,e){return this.jumpTo({bearing:t},e),this},r.prototype.getPadding=function(){return this.transform.padding},r.prototype.setPadding=function(t,e){return this.jumpTo({padding:t},e),this},r.prototype.rotateTo=function(e,r,n){return this.easeTo(t.extend({bearing:e},r),n)},r.prototype.resetNorth=function(e,r){return this.rotateTo(0,t.extend({duration:1e3},e),r),this},r.prototype.resetNorthPitch=function(e,r){return this.easeTo(t.extend({bearing:0,pitch:0,duration:1e3},e),r),this},r.prototype.snapToNorth=function(t,e){return Math.abs(this.getBearing())<this._bearingSnap?this.resetNorth(t,e):this},r.prototype.getPitch=function(){return this.transform.pitch},r.prototype.setPitch=function(t,e){return this.jumpTo({pitch:t},e),this},r.prototype.cameraForBounds=function(e,r){return e=t.LngLatBounds.convert(e),this._cameraForBoxAndBearing(e.getNorthWest(),e.getSouthEast(),0,r)},r.prototype._cameraForBoxAndBearing=function(e,r,n,i){var a={top:0,bottom:0,right:0,left:0};if(\"number\"==typeof(i=t.extend({padding:a,offset:[0,0],maxZoom:this.transform.maxZoom},i)).padding){var o=i.padding;i.padding={top:o,bottom:o,right:o,left:o}}i.padding=t.extend(a,i.padding);var s=this.transform,l=s.padding,c=s.project(t.LngLat.convert(e)),u=s.project(t.LngLat.convert(r)),f=c.rotate(-n*Math.PI/180),h=u.rotate(-n*Math.PI/180),p=new t.Point(Math.max(f.x,h.x),Math.max(f.y,h.y)),d=new t.Point(Math.min(f.x,h.x),Math.min(f.y,h.y)),g=p.sub(d),m=(s.width-(l.left+l.right+i.padding.left+i.padding.right))/g.x,v=(s.height-(l.top+l.bottom+i.padding.top+i.padding.bottom))/g.y;if(!(v<0||m<0)){var y=Math.min(s.scaleZoom(s.scale*Math.min(m,v)),i.maxZoom),x=t.Point.convert(i.offset),b=new t.Point(x.x+(i.padding.left-i.padding.right)/2,x.y+(i.padding.top-i.padding.bottom)/2).mult(s.scale/s.zoomScale(y));return{center:s.unproject(c.add(u).div(2).sub(b)),zoom:y,bearing:n}}t.warnOnce(\"Map cannot fit within canvas with the given bounds, padding, and/or offset.\")},r.prototype.fitBounds=function(t,e,r){return this._fitInternal(this.cameraForBounds(t,e),e,r)},r.prototype.fitScreenCoordinates=function(e,r,n,i,a){return this._fitInternal(this._cameraForBoxAndBearing(this.transform.pointLocation(t.Point.convert(e)),this.transform.pointLocation(t.Point.convert(r)),n,i),i,a)},r.prototype._fitInternal=function(e,r,n){return e?(delete(r=t.extend(e,r)).padding,r.linear?this.easeTo(r,n):this.flyTo(r,n)):this},r.prototype.jumpTo=function(e,r){this.stop();var n=this.transform,i=!1,a=!1,o=!1;return\"zoom\"in e&&n.zoom!==+e.zoom&&(i=!0,n.zoom=+e.zoom),void 0!==e.center&&(n.center=t.LngLat.convert(e.center)),\"bearing\"in e&&n.bearing!==+e.bearing&&(a=!0,n.bearing=+e.bearing),\"pitch\"in e&&n.pitch!==+e.pitch&&(o=!0,n.pitch=+e.pitch),null==e.padding||n.isPaddingEqual(e.padding)||(n.padding=e.padding),this.fire(new t.Event(\"movestart\",r)).fire(new t.Event(\"move\",r)),i&&this.fire(new t.Event(\"zoomstart\",r)).fire(new t.Event(\"zoom\",r)).fire(new t.Event(\"zoomend\",r)),a&&this.fire(new t.Event(\"rotatestart\",r)).fire(new t.Event(\"rotate\",r)).fire(new t.Event(\"rotateend\",r)),o&&this.fire(new t.Event(\"pitchstart\",r)).fire(new t.Event(\"pitch\",r)).fire(new t.Event(\"pitchend\",r)),this.fire(new t.Event(\"moveend\",r))},r.prototype.easeTo=function(e,r){var n=this;this._stop(!1,e.easeId),(!1===(e=t.extend({offset:[0,0],duration:500,easing:t.ease},e)).animate||!e.essential&&t.browser.prefersReducedMotion)&&(e.duration=0);var i=this.transform,a=this.getZoom(),o=this.getBearing(),s=this.getPitch(),l=this.getPadding(),c=\"zoom\"in e?+e.zoom:a,u=\"bearing\"in e?this._normalizeBearing(e.bearing,o):o,f=\"pitch\"in e?+e.pitch:s,h=\"padding\"in e?e.padding:i.padding,p=t.Point.convert(e.offset),d=i.centerPoint.add(p),g=i.pointLocation(d),m=t.LngLat.convert(e.center||g);this._normalizeCenter(m);var v,y,x=i.project(g),b=i.project(m).sub(x),_=i.zoomScale(c-a);e.around&&(v=t.LngLat.convert(e.around),y=i.locationPoint(v));var w={moving:this._moving,zooming:this._zooming,rotating:this._rotating,pitching:this._pitching};return this._zooming=this._zooming||c!==a,this._rotating=this._rotating||o!==u,this._pitching=this._pitching||f!==s,this._padding=!i.isPaddingEqual(h),this._easeId=e.easeId,this._prepareEase(r,e.noMoveStart,w),clearTimeout(this._easeEndTimeoutID),this._ease((function(e){if(n._zooming&&(i.zoom=t.number(a,c,e)),n._rotating&&(i.bearing=t.number(o,u,e)),n._pitching&&(i.pitch=t.number(s,f,e)),n._padding&&(i.interpolatePadding(l,h,e),d=i.centerPoint.add(p)),v)i.setLocationAtPoint(v,y);else{var g=i.zoomScale(i.zoom-a),m=c>a?Math.min(2,_):Math.max(.5,_),w=Math.pow(m,1-e),T=i.unproject(x.add(b.mult(e*w)).mult(g));i.setLocationAtPoint(i.renderWorldCopies?T.wrap():T,d)}n._fireMoveEvents(r)}),(function(t){n._afterEase(r,t)}),e),this},r.prototype._prepareEase=function(e,r,n){void 0===n&&(n={}),this._moving=!0,r||n.moving||this.fire(new t.Event(\"movestart\",e)),this._zooming&&!n.zooming&&this.fire(new t.Event(\"zoomstart\",e)),this._rotating&&!n.rotating&&this.fire(new t.Event(\"rotatestart\",e)),this._pitching&&!n.pitching&&this.fire(new t.Event(\"pitchstart\",e))},r.prototype._fireMoveEvents=function(e){this.fire(new t.Event(\"move\",e)),this._zooming&&this.fire(new t.Event(\"zoom\",e)),this._rotating&&this.fire(new t.Event(\"rotate\",e)),this._pitching&&this.fire(new t.Event(\"pitch\",e))},r.prototype._afterEase=function(e,r){if(!this._easeId||!r||this._easeId!==r){delete this._easeId;var n=this._zooming,i=this._rotating,a=this._pitching;this._moving=!1,this._zooming=!1,this._rotating=!1,this._pitching=!1,this._padding=!1,n&&this.fire(new t.Event(\"zoomend\",e)),i&&this.fire(new t.Event(\"rotateend\",e)),a&&this.fire(new t.Event(\"pitchend\",e)),this.fire(new t.Event(\"moveend\",e))}},r.prototype.flyTo=function(e,r){var n=this;if(!e.essential&&t.browser.prefersReducedMotion){var i=t.pick(e,[\"center\",\"zoom\",\"bearing\",\"pitch\",\"around\"]);return this.jumpTo(i,r)}this.stop(),e=t.extend({offset:[0,0],speed:1.2,curve:1.42,easing:t.ease},e);var a=this.transform,o=this.getZoom(),s=this.getBearing(),l=this.getPitch(),c=this.getPadding(),u=\"zoom\"in e?t.clamp(+e.zoom,a.minZoom,a.maxZoom):o,f=\"bearing\"in e?this._normalizeBearing(e.bearing,s):s,h=\"pitch\"in e?+e.pitch:l,p=\"padding\"in e?e.padding:a.padding,d=a.zoomScale(u-o),g=t.Point.convert(e.offset),m=a.centerPoint.add(g),v=a.pointLocation(m),y=t.LngLat.convert(e.center||v);this._normalizeCenter(y);var x=a.project(v),b=a.project(y).sub(x),_=e.curve,w=Math.max(a.width,a.height),T=w/d,k=b.mag();if(\"minZoom\"in e){var M=t.clamp(Math.min(e.minZoom,o,u),a.minZoom,a.maxZoom),A=w/a.zoomScale(M-o);_=Math.sqrt(A/k*2)}var S=_*_;function E(t){var e=(T*T-w*w+(t?-1:1)*S*S*k*k)/(2*(t?T:w)*S*k);return Math.log(Math.sqrt(e*e+1)-e)}function C(t){return(Math.exp(t)-Math.exp(-t))/2}function L(t){return(Math.exp(t)+Math.exp(-t))/2}var I=E(0),P=function(t){return L(I)/L(I+_*t)},z=function(t){return w*((L(I)*(C(e=I+_*t)/L(e))-C(I))/S)/k;var e},O=(E(1)-I)/_;if(Math.abs(k)<1e-6||!isFinite(O)){if(Math.abs(w-T)<1e-6)return this.easeTo(e,r);var D=T<w?-1:1;O=Math.abs(Math.log(T/w))/_,z=function(){return 0},P=function(t){return Math.exp(D*_*t)}}return e.duration=\"duration\"in e?+e.duration:1e3*O/(\"screenSpeed\"in e?+e.screenSpeed/_:+e.speed),e.maxDuration&&e.duration>e.maxDuration&&(e.duration=0),this._zooming=!0,this._rotating=s!==f,this._pitching=h!==l,this._padding=!a.isPaddingEqual(p),this._prepareEase(r,!1),this._ease((function(e){var i=e*O,d=1/P(i);a.zoom=1===e?u:o+a.scaleZoom(d),n._rotating&&(a.bearing=t.number(s,f,e)),n._pitching&&(a.pitch=t.number(l,h,e)),n._padding&&(a.interpolatePadding(c,p,e),m=a.centerPoint.add(g));var v=1===e?y:a.unproject(x.add(b.mult(z(i))).mult(d));a.setLocationAtPoint(a.renderWorldCopies?v.wrap():v,m),n._fireMoveEvents(r)}),(function(){return n._afterEase(r)}),e),this},r.prototype.isEasing=function(){return!!this._easeFrameId},r.prototype.stop=function(){return this._stop()},r.prototype._stop=function(t,e){if(this._easeFrameId&&(this._cancelRenderFrame(this._easeFrameId),delete this._easeFrameId,delete this._onEaseFrame),this._onEaseEnd){var r=this._onEaseEnd;delete this._onEaseEnd,r.call(this,e)}if(!t){var n=this.handlers;n&&n.stop()}return this},r.prototype._ease=function(e,r,n){!1===n.animate||0===n.duration?(e(1),r()):(this._easeStart=t.browser.now(),this._easeOptions=n,this._onEaseFrame=e,this._onEaseEnd=r,this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback))},r.prototype._renderFrameCallback=function(){var e=Math.min((t.browser.now()-this._easeStart)/this._easeOptions.duration,1);this._onEaseFrame(this._easeOptions.easing(e)),e<1?this._easeFrameId=this._requestRenderFrame(this._renderFrameCallback):this.stop()},r.prototype._normalizeBearing=function(e,r){e=t.wrap(e,-180,180);var n=Math.abs(e-r);return Math.abs(e-360-r)<n&&(e-=360),Math.abs(e+360-r)<n&&(e+=360),e},r.prototype._normalizeCenter=function(t){var e=this.transform;if(e.renderWorldCopies&&!e.lngRange){var r=t.lng-e.center.lng;t.lng+=r>180?-360:r<-180?360:0}},r}(t.Evented),vi=function(e){void 0===e&&(e={}),this.options=e,t.bindAll([\"_updateEditLink\",\"_updateData\",\"_updateCompact\"],this)};vi.prototype.getDefaultPosition=function(){return\"bottom-right\"},vi.prototype.onAdd=function(t){var e=this.options&&this.options.compact;return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-attrib\"),this._innerContainer=r.create(\"div\",\"mapboxgl-ctrl-attrib-inner\",this._container),e&&this._container.classList.add(\"mapboxgl-compact\"),this._updateAttributions(),this._updateEditLink(),this._map.on(\"styledata\",this._updateData),this._map.on(\"sourcedata\",this._updateData),this._map.on(\"moveend\",this._updateEditLink),void 0===e&&(this._map.on(\"resize\",this._updateCompact),this._updateCompact()),this._container},vi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"styledata\",this._updateData),this._map.off(\"sourcedata\",this._updateData),this._map.off(\"moveend\",this._updateEditLink),this._map.off(\"resize\",this._updateCompact),this._map=void 0,this._attribHTML=void 0},vi.prototype._updateEditLink=function(){var e=this._editLink;e||(e=this._editLink=this._container.querySelector(\".mapbox-improve-map\"));var r=[{key:\"owner\",value:this.styleOwner},{key:\"id\",value:this.styleId},{key:\"access_token\",value:this._map._requestManager._customAccessToken||t.config.ACCESS_TOKEN}];if(e){var n=r.reduce((function(t,e,n){return e.value&&(t+=e.key+\"=\"+e.value+(n<r.length-1?\"&\":\"\")),t}),\"?\");e.href=t.config.FEEDBACK_URL+\"/\"+n+(this._map._hash?this._map._hash.getHashString(!0):\"\"),e.rel=\"noopener nofollow\"}},vi.prototype._updateData=function(t){!t||\"metadata\"!==t.sourceDataType&&\"style\"!==t.dataType||(this._updateAttributions(),this._updateEditLink())},vi.prototype._updateAttributions=function(){if(this._map.style){var t=[];if(this.options.customAttribution&&(Array.isArray(this.options.customAttribution)?t=t.concat(this.options.customAttribution.map((function(t){return\"string\"!=typeof t?\"\":t}))):\"string\"==typeof this.options.customAttribution&&t.push(this.options.customAttribution)),this._map.style.stylesheet){var e=this._map.style.stylesheet;this.styleOwner=e.owner,this.styleId=e.id}var r=this._map.style.sourceCaches;for(var n in r){var i=r[n];if(i.used){var a=i.getSource();a.attribution&&t.indexOf(a.attribution)<0&&t.push(a.attribution)}}t.sort((function(t,e){return t.length-e.length}));var o=(t=t.filter((function(e,r){for(var n=r+1;n<t.length;n++)if(t[n].indexOf(e)>=0)return!1;return!0}))).join(\" | \");o!==this._attribHTML&&(this._attribHTML=o,t.length?(this._innerContainer.innerHTML=o,this._container.classList.remove(\"mapboxgl-attrib-empty\")):this._container.classList.add(\"mapboxgl-attrib-empty\"),this._editLink=null)}},vi.prototype._updateCompact=function(){this._map.getCanvasContainer().offsetWidth<=640?this._container.classList.add(\"mapboxgl-compact\"):this._container.classList.remove(\"mapboxgl-compact\")};var yi=function(){t.bindAll([\"_updateLogo\"],this),t.bindAll([\"_updateCompact\"],this)};yi.prototype.onAdd=function(t){this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl\");var e=r.create(\"a\",\"mapboxgl-ctrl-logo\");return e.target=\"_blank\",e.rel=\"noopener nofollow\",e.href=\"https://www.mapbox.com/\",e.setAttribute(\"aria-label\",this._map._getUIString(\"LogoControl.Title\")),e.setAttribute(\"rel\",\"noopener nofollow\"),this._container.appendChild(e),this._container.style.display=\"none\",this._map.on(\"sourcedata\",this._updateLogo),this._updateLogo(),this._map.on(\"resize\",this._updateCompact),this._updateCompact(),this._container},yi.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"sourcedata\",this._updateLogo),this._map.off(\"resize\",this._updateCompact)},yi.prototype.getDefaultPosition=function(){return\"bottom-left\"},yi.prototype._updateLogo=function(t){t&&\"metadata\"!==t.sourceDataType||(this._container.style.display=this._logoRequired()?\"block\":\"none\")},yi.prototype._logoRequired=function(){if(this._map.style){var t=this._map.style.sourceCaches;for(var e in t)if(t[e].getSource().mapbox_logo)return!0;return!1}},yi.prototype._updateCompact=function(){var t=this._container.children;if(t.length){var e=t[0];this._map.getCanvasContainer().offsetWidth<250?e.classList.add(\"mapboxgl-compact\"):e.classList.remove(\"mapboxgl-compact\")}};var xi=function(){this._queue=[],this._id=0,this._cleared=!1,this._currentlyRunning=!1};xi.prototype.add=function(t){var e=++this._id;return this._queue.push({callback:t,id:e,cancelled:!1}),e},xi.prototype.remove=function(t){for(var e=this._currentlyRunning,r=0,n=e?this._queue.concat(e):this._queue;r<n.length;r+=1){var i=n[r];if(i.id===t)return void(i.cancelled=!0)}},xi.prototype.run=function(t){void 0===t&&(t=0);var e=this._currentlyRunning=this._queue;this._queue=[];for(var r=0,n=e;r<n.length;r+=1){var i=n[r];if(!i.cancelled&&(i.callback(t),this._cleared))break}this._cleared=!1,this._currentlyRunning=!1},xi.prototype.clear=function(){this._currentlyRunning&&(this._cleared=!0),this._queue=[]};var bi={\"FullscreenControl.Enter\":\"Enter fullscreen\",\"FullscreenControl.Exit\":\"Exit fullscreen\",\"GeolocateControl.FindMyLocation\":\"Find my location\",\"GeolocateControl.LocationNotAvailable\":\"Location not available\",\"LogoControl.Title\":\"Mapbox logo\",\"NavigationControl.ResetBearing\":\"Reset bearing to north\",\"NavigationControl.ZoomIn\":\"Zoom in\",\"NavigationControl.ZoomOut\":\"Zoom out\",\"ScaleControl.Feet\":\"ft\",\"ScaleControl.Meters\":\"m\",\"ScaleControl.Kilometers\":\"km\",\"ScaleControl.Miles\":\"mi\",\"ScaleControl.NauticalMiles\":\"nm\"},_i=t.window.HTMLImageElement,wi=t.window.HTMLElement,Ti=t.window.ImageBitmap,ki={center:[0,0],zoom:0,bearing:0,pitch:0,minZoom:-2,maxZoom:22,minPitch:0,maxPitch:60,interactive:!0,scrollZoom:!0,boxZoom:!0,dragRotate:!0,dragPan:!0,keyboard:!0,doubleClickZoom:!0,touchZoomRotate:!0,touchPitch:!0,bearingSnap:7,clickTolerance:3,pitchWithRotate:!0,hash:!1,attributionControl:!0,failIfMajorPerformanceCaveat:!1,preserveDrawingBuffer:!1,trackResize:!0,renderWorldCopies:!0,refreshExpiredTiles:!0,maxTileCacheSize:null,localIdeographFontFamily:\"sans-serif\",transformRequest:null,accessToken:null,fadeDuration:300,crossSourceCollisions:!0},Mi=function(n){function i(e){var r=this;if(null!=(e=t.extend({},ki,e)).minZoom&&null!=e.maxZoom&&e.minZoom>e.maxZoom)throw new Error(\"maxZoom must be greater than or equal to minZoom\");if(null!=e.minPitch&&null!=e.maxPitch&&e.minPitch>e.maxPitch)throw new Error(\"maxPitch must be greater than or equal to minPitch\");if(null!=e.minPitch&&e.minPitch<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(null!=e.maxPitch&&e.maxPitch>60)throw new Error(\"maxPitch must be less than or equal to 60\");var i=new wn(e.minZoom,e.maxZoom,e.minPitch,e.maxPitch,e.renderWorldCopies);if(n.call(this,i,e),this._interactive=e.interactive,this._maxTileCacheSize=e.maxTileCacheSize,this._failIfMajorPerformanceCaveat=e.failIfMajorPerformanceCaveat,this._preserveDrawingBuffer=e.preserveDrawingBuffer,this._antialias=e.antialias,this._trackResize=e.trackResize,this._bearingSnap=e.bearingSnap,this._refreshExpiredTiles=e.refreshExpiredTiles,this._fadeDuration=e.fadeDuration,this._crossSourceCollisions=e.crossSourceCollisions,this._crossFadingFactor=1,this._collectResourceTiming=e.collectResourceTiming,this._renderTaskQueue=new xi,this._controls=[],this._mapId=t.uniqueId(),this._locale=t.extend({},bi,e.locale),this._requestManager=new t.RequestManager(e.transformRequest,e.accessToken),\"string\"==typeof e.container){if(this._container=t.window.document.getElementById(e.container),!this._container)throw new Error(\"Container '\"+e.container+\"' not found.\")}else{if(!(e.container instanceof wi))throw new Error(\"Invalid type: 'container' must be a String or HTMLElement.\");this._container=e.container}if(e.maxBounds&&this.setMaxBounds(e.maxBounds),t.bindAll([\"_onWindowOnline\",\"_onWindowResize\",\"_contextLost\",\"_contextRestored\"],this),this._setupContainer(),this._setupPainter(),void 0===this.painter)throw new Error(\"Failed to initialize WebGL.\");this.on(\"move\",(function(){return r._update(!1)})),this.on(\"moveend\",(function(){return r._update(!1)})),this.on(\"zoom\",(function(){return r._update(!0)})),void 0!==t.window&&(t.window.addEventListener(\"online\",this._onWindowOnline,!1),t.window.addEventListener(\"resize\",this._onWindowResize,!1)),this.handlers=new gi(this,e),this._hash=e.hash&&new kn(\"string\"==typeof e.hash&&e.hash||void 0).addTo(this),this._hash&&this._hash._onHashChange()||(this.jumpTo({center:e.center,zoom:e.zoom,bearing:e.bearing,pitch:e.pitch}),e.bounds&&(this.resize(),this.fitBounds(e.bounds,t.extend({},e.fitBoundsOptions,{duration:0})))),this.resize(),this._localIdeographFontFamily=e.localIdeographFontFamily,e.style&&this.setStyle(e.style,{localIdeographFontFamily:e.localIdeographFontFamily}),e.attributionControl&&this.addControl(new vi({customAttribution:e.customAttribution})),this.addControl(new yi,e.logoPosition),this.on(\"style.load\",(function(){r.transform.unmodified&&r.jumpTo(r.style.stylesheet)})),this.on(\"data\",(function(e){r._update(\"style\"===e.dataType),r.fire(new t.Event(e.dataType+\"data\",e))})),this.on(\"dataloading\",(function(e){r.fire(new t.Event(e.dataType+\"dataloading\",e))}))}n&&(i.__proto__=n),(i.prototype=Object.create(n&&n.prototype)).constructor=i;var a={showTileBoundaries:{configurable:!0},showPadding:{configurable:!0},showCollisionBoxes:{configurable:!0},showOverdrawInspector:{configurable:!0},repaint:{configurable:!0},vertices:{configurable:!0},version:{configurable:!0}};return i.prototype._getMapId=function(){return this._mapId},i.prototype.addControl=function(e,r){if(void 0===r&&e.getDefaultPosition&&(r=e.getDefaultPosition()),void 0===r&&(r=\"top-right\"),!e||!e.onAdd)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.addControl(). Argument must be a control with onAdd and onRemove methods.\")));var n=e.onAdd(this);this._controls.push(e);var i=this._controlPositions[r];return-1!==r.indexOf(\"bottom\")?i.insertBefore(n,i.firstChild):i.appendChild(n),this},i.prototype.removeControl=function(e){if(!e||!e.onRemove)return this.fire(new t.ErrorEvent(new Error(\"Invalid argument to map.removeControl(). Argument must be a control with onAdd and onRemove methods.\")));var r=this._controls.indexOf(e);return r>-1&&this._controls.splice(r,1),e.onRemove(this),this},i.prototype.resize=function(e){var r=this._containerDimensions(),n=r[0],i=r[1];this._resizeCanvas(n,i),this.transform.resize(n,i),this.painter.resize(n,i);var a=!this._moving;return a&&(this.stop(),this.fire(new t.Event(\"movestart\",e)).fire(new t.Event(\"move\",e))),this.fire(new t.Event(\"resize\",e)),a&&this.fire(new t.Event(\"moveend\",e)),this},i.prototype.getBounds=function(){return this.transform.getBounds()},i.prototype.getMaxBounds=function(){return this.transform.getMaxBounds()},i.prototype.setMaxBounds=function(e){return this.transform.setMaxBounds(t.LngLatBounds.convert(e)),this._update()},i.prototype.setMinZoom=function(t){if((t=null==t?-2:t)>=-2&&t<=this.transform.maxZoom)return this.transform.minZoom=t,this._update(),this.getZoom()<t&&this.setZoom(t),this;throw new Error(\"minZoom must be between -2 and the current maxZoom, inclusive\")},i.prototype.getMinZoom=function(){return this.transform.minZoom},i.prototype.setMaxZoom=function(t){if((t=null==t?22:t)>=this.transform.minZoom)return this.transform.maxZoom=t,this._update(),this.getZoom()>t&&this.setZoom(t),this;throw new Error(\"maxZoom must be greater than the current minZoom\")},i.prototype.getMaxZoom=function(){return this.transform.maxZoom},i.prototype.setMinPitch=function(t){if((t=null==t?0:t)<0)throw new Error(\"minPitch must be greater than or equal to 0\");if(t>=0&&t<=this.transform.maxPitch)return this.transform.minPitch=t,this._update(),this.getPitch()<t&&this.setPitch(t),this;throw new Error(\"minPitch must be between 0 and the current maxPitch, inclusive\")},i.prototype.getMinPitch=function(){return this.transform.minPitch},i.prototype.setMaxPitch=function(t){if((t=null==t?60:t)>60)throw new Error(\"maxPitch must be less than or equal to 60\");if(t>=this.transform.minPitch)return this.transform.maxPitch=t,this._update(),this.getPitch()>t&&this.setPitch(t),this;throw new Error(\"maxPitch must be greater than the current minPitch\")},i.prototype.getMaxPitch=function(){return this.transform.maxPitch},i.prototype.getRenderWorldCopies=function(){return this.transform.renderWorldCopies},i.prototype.setRenderWorldCopies=function(t){return this.transform.renderWorldCopies=t,this._update()},i.prototype.project=function(e){return this.transform.locationPoint(t.LngLat.convert(e))},i.prototype.unproject=function(e){return this.transform.pointLocation(t.Point.convert(e))},i.prototype.isMoving=function(){return this._moving||this.handlers.isMoving()},i.prototype.isZooming=function(){return this._zooming||this.handlers.isZooming()},i.prototype.isRotating=function(){return this._rotating||this.handlers.isRotating()},i.prototype._createDelegatedListener=function(t,e,r){var n,i=this;if(\"mouseenter\"===t||\"mouseover\"===t){var a=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){var o=i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[];o.length?a||(a=!0,r.call(i,new zn(t,i,n.originalEvent,{features:o}))):a=!1},mouseout:function(){a=!1}}}}if(\"mouseleave\"===t||\"mouseout\"===t){var o=!1;return{layer:e,listener:r,delegates:{mousemove:function(n){(i.getLayer(e)?i.queryRenderedFeatures(n.point,{layers:[e]}):[]).length?o=!0:o&&(o=!1,r.call(i,new zn(t,i,n.originalEvent)))},mouseout:function(e){o&&(o=!1,r.call(i,new zn(t,i,e.originalEvent)))}}}}return{layer:e,listener:r,delegates:(n={},n[t]=function(t){var n=i.getLayer(e)?i.queryRenderedFeatures(t.point,{layers:[e]}):[];n.length&&(t.features=n,r.call(i,t),delete t.features)},n)}},i.prototype.on=function(t,e,r){if(void 0===r)return n.prototype.on.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in this._delegatedListeners=this._delegatedListeners||{},this._delegatedListeners[t]=this._delegatedListeners[t]||[],this._delegatedListeners[t].push(i),i.delegates)this.on(a,i.delegates[a]);return this},i.prototype.once=function(t,e,r){if(void 0===r)return n.prototype.once.call(this,t,e);var i=this._createDelegatedListener(t,e,r);for(var a in i.delegates)this.once(a,i.delegates[a]);return this},i.prototype.off=function(t,e,r){var i=this;return void 0===r?n.prototype.off.call(this,t,e):(this._delegatedListeners&&this._delegatedListeners[t]&&function(n){for(var a=n[t],o=0;o<a.length;o++){var s=a[o];if(s.layer===e&&s.listener===r){for(var l in s.delegates)i.off(l,s.delegates[l]);return a.splice(o,1),i}}}(this._delegatedListeners),this)},i.prototype.queryRenderedFeatures=function(e,r){if(!this.style)return[];var n;if(void 0!==r||void 0===e||e instanceof t.Point||Array.isArray(e)||(r=e,e=void 0),r=r||{},(e=e||[[0,0],[this.transform.width,this.transform.height]])instanceof t.Point||\"number\"==typeof e[0])n=[t.Point.convert(e)];else{var i=t.Point.convert(e[0]),a=t.Point.convert(e[1]);n=[i,new t.Point(a.x,i.y),a,new t.Point(i.x,a.y),i]}return this.style.queryRenderedFeatures(n,r,this.transform)},i.prototype.querySourceFeatures=function(t,e){return this.style.querySourceFeatures(t,e)},i.prototype.setStyle=function(e,r){return!1!==(r=t.extend({},{localIdeographFontFamily:this._localIdeographFontFamily},r)).diff&&r.localIdeographFontFamily===this._localIdeographFontFamily&&this.style&&e?(this._diffStyle(e,r),this):(this._localIdeographFontFamily=r.localIdeographFontFamily,this._updateStyle(e,r))},i.prototype._getUIString=function(t){var e=this._locale[t];if(null==e)throw new Error(\"Missing UI string '\"+t+\"'\");return e},i.prototype._updateStyle=function(t,e){return this.style&&(this.style.setEventedParent(null),this.style._remove()),t?(this.style=new qe(this,e||{}),this.style.setEventedParent(this,{style:this.style}),\"string\"==typeof t?this.style.loadURL(t):this.style.loadJSON(t),this):(delete this.style,this)},i.prototype._lazyInitEmptyStyle=function(){this.style||(this.style=new qe(this,{}),this.style.setEventedParent(this,{style:this.style}),this.style.loadEmpty())},i.prototype._diffStyle=function(e,r){var n=this;if(\"string\"==typeof e){var i=this._requestManager.normalizeStyleURL(e),a=this._requestManager.transformRequest(i,t.ResourceType.Style);t.getJSON(a,(function(e,i){e?n.fire(new t.ErrorEvent(e)):i&&n._updateDiff(i,r)}))}else\"object\"==typeof e&&this._updateDiff(e,r)},i.prototype._updateDiff=function(e,r){try{this.style.setState(e)&&this._update(!0)}catch(n){t.warnOnce(\"Unable to perform style diff: \"+(n.message||n.error||n)+\".  Rebuilding the style from scratch.\"),this._updateStyle(e,r)}},i.prototype.getStyle=function(){if(this.style)return this.style.serialize()},i.prototype.isStyleLoaded=function(){return this.style?this.style.loaded():t.warnOnce(\"There is no style added to the map.\")},i.prototype.addSource=function(t,e){return this._lazyInitEmptyStyle(),this.style.addSource(t,e),this._update(!0)},i.prototype.isSourceLoaded=function(e){var r=this.style&&this.style.sourceCaches[e];if(void 0!==r)return r.loaded();this.fire(new t.ErrorEvent(new Error(\"There is no source with ID '\"+e+\"'\")))},i.prototype.areTilesLoaded=function(){var t=this.style&&this.style.sourceCaches;for(var e in t){var r=t[e]._tiles;for(var n in r){var i=r[n];if(\"loaded\"!==i.state&&\"errored\"!==i.state)return!1}}return!0},i.prototype.addSourceType=function(t,e,r){return this._lazyInitEmptyStyle(),this.style.addSourceType(t,e,r)},i.prototype.removeSource=function(t){return this.style.removeSource(t),this._update(!0)},i.prototype.getSource=function(t){return this.style.getSource(t)},i.prototype.addImage=function(e,r,n){void 0===n&&(n={});var i=n.pixelRatio;void 0===i&&(i=1);var a=n.sdf;void 0===a&&(a=!1);var o=n.stretchX,s=n.stretchY,l=n.content;if(this._lazyInitEmptyStyle(),r instanceof _i||Ti&&r instanceof Ti){var c=t.browser.getImageData(r);this.style.addImage(e,{data:new t.RGBAImage({width:c.width,height:c.height},c.data),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0})}else{if(void 0===r.width||void 0===r.height)return this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.addImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\")));var u=r;this.style.addImage(e,{data:new t.RGBAImage({width:r.width,height:r.height},new Uint8Array(r.data)),pixelRatio:i,stretchX:o,stretchY:s,content:l,sdf:a,version:0,userImage:u}),u.onAdd&&u.onAdd(this,e)}},i.prototype.updateImage=function(e,r){var n=this.style.getImage(e);if(!n)return this.fire(new t.ErrorEvent(new Error(\"The map has no image with that id. If you are adding a new image use `map.addImage(...)` instead.\")));var i=r instanceof _i||Ti&&r instanceof Ti?t.browser.getImageData(r):r,a=i.width,o=i.height,s=i.data;return void 0===a||void 0===o?this.fire(new t.ErrorEvent(new Error(\"Invalid arguments to map.updateImage(). The second argument must be an `HTMLImageElement`, `ImageData`, `ImageBitmap`, or object with `width`, `height`, and `data` properties with the same format as `ImageData`\"))):a!==n.data.width||o!==n.data.height?this.fire(new t.ErrorEvent(new Error(\"The width and height of the updated image must be that same as the previous version of the image\"))):(n.data.replace(s,!(r instanceof _i||Ti&&r instanceof Ti)),void this.style.updateImage(e,n))},i.prototype.hasImage=function(e){return e?!!this.style.getImage(e):(this.fire(new t.ErrorEvent(new Error(\"Missing required image id\"))),!1)},i.prototype.removeImage=function(t){this.style.removeImage(t)},i.prototype.loadImage=function(e,r){t.getImage(this._requestManager.transformRequest(e,t.ResourceType.Image),r)},i.prototype.listImages=function(){return this.style.listImages()},i.prototype.addLayer=function(t,e){return this._lazyInitEmptyStyle(),this.style.addLayer(t,e),this._update(!0)},i.prototype.moveLayer=function(t,e){return this.style.moveLayer(t,e),this._update(!0)},i.prototype.removeLayer=function(t){return this.style.removeLayer(t),this._update(!0)},i.prototype.getLayer=function(t){return this.style.getLayer(t)},i.prototype.setLayerZoomRange=function(t,e,r){return this.style.setLayerZoomRange(t,e,r),this._update(!0)},i.prototype.setFilter=function(t,e,r){return void 0===r&&(r={}),this.style.setFilter(t,e,r),this._update(!0)},i.prototype.getFilter=function(t){return this.style.getFilter(t)},i.prototype.setPaintProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setPaintProperty(t,e,r,n),this._update(!0)},i.prototype.getPaintProperty=function(t,e){return this.style.getPaintProperty(t,e)},i.prototype.setLayoutProperty=function(t,e,r,n){return void 0===n&&(n={}),this.style.setLayoutProperty(t,e,r,n),this._update(!0)},i.prototype.getLayoutProperty=function(t,e){return this.style.getLayoutProperty(t,e)},i.prototype.setLight=function(t,e){return void 0===e&&(e={}),this._lazyInitEmptyStyle(),this.style.setLight(t,e),this._update(!0)},i.prototype.getLight=function(){return this.style.getLight()},i.prototype.setFeatureState=function(t,e){return this.style.setFeatureState(t,e),this._update()},i.prototype.removeFeatureState=function(t,e){return this.style.removeFeatureState(t,e),this._update()},i.prototype.getFeatureState=function(t){return this.style.getFeatureState(t)},i.prototype.getContainer=function(){return this._container},i.prototype.getCanvasContainer=function(){return this._canvasContainer},i.prototype.getCanvas=function(){return this._canvas},i.prototype._containerDimensions=function(){var t=0,e=0;return this._container&&(t=this._container.clientWidth||400,e=this._container.clientHeight||300),[t,e]},i.prototype._detectMissingCSS=function(){\"rgb(250, 128, 114)\"!==t.window.getComputedStyle(this._missingCSSCanary).getPropertyValue(\"background-color\")&&t.warnOnce(\"This page appears to be missing CSS declarations for Mapbox GL JS, which may cause the map to display incorrectly. Please ensure your page includes mapbox-gl.css, as described in https://www.mapbox.com/mapbox-gl-js/api/.\")},i.prototype._setupContainer=function(){var t=this._container;t.classList.add(\"mapboxgl-map\"),(this._missingCSSCanary=r.create(\"div\",\"mapboxgl-canary\",t)).style.visibility=\"hidden\",this._detectMissingCSS();var e=this._canvasContainer=r.create(\"div\",\"mapboxgl-canvas-container\",t);this._interactive&&e.classList.add(\"mapboxgl-interactive\"),this._canvas=r.create(\"canvas\",\"mapboxgl-canvas\",e),this._canvas.addEventListener(\"webglcontextlost\",this._contextLost,!1),this._canvas.addEventListener(\"webglcontextrestored\",this._contextRestored,!1),this._canvas.setAttribute(\"tabindex\",\"0\"),this._canvas.setAttribute(\"aria-label\",\"Map\");var n=this._containerDimensions();this._resizeCanvas(n[0],n[1]);var i=this._controlContainer=r.create(\"div\",\"mapboxgl-control-container\",t),a=this._controlPositions={};[\"top-left\",\"top-right\",\"bottom-left\",\"bottom-right\"].forEach((function(t){a[t]=r.create(\"div\",\"mapboxgl-ctrl-\"+t,i)}))},i.prototype._resizeCanvas=function(e,r){var n=t.browser.devicePixelRatio||1;this._canvas.width=n*e,this._canvas.height=n*r,this._canvas.style.width=e+\"px\",this._canvas.style.height=r+\"px\"},i.prototype._setupPainter=function(){var r=t.extend({},e.webGLContextAttributes,{failIfMajorPerformanceCaveat:this._failIfMajorPerformanceCaveat,preserveDrawingBuffer:this._preserveDrawingBuffer,antialias:this._antialias||!1}),n=this._canvas.getContext(\"webgl\",r)||this._canvas.getContext(\"experimental-webgl\",r);n?(this.painter=new yn(n,this.transform),t.webpSupported.testSupport(n)):this.fire(new t.ErrorEvent(new Error(\"Failed to initialize WebGL\")))},i.prototype._contextLost=function(e){e.preventDefault(),this._frame&&(this._frame.cancel(),this._frame=null),this.fire(new t.Event(\"webglcontextlost\",{originalEvent:e}))},i.prototype._contextRestored=function(e){this._setupPainter(),this.resize(),this._update(),this.fire(new t.Event(\"webglcontextrestored\",{originalEvent:e}))},i.prototype.loaded=function(){return!this._styleDirty&&!this._sourcesDirty&&!!this.style&&this.style.loaded()},i.prototype._update=function(t){return this.style?(this._styleDirty=this._styleDirty||t,this._sourcesDirty=!0,this.triggerRepaint(),this):this},i.prototype._requestRenderFrame=function(t){return this._update(),this._renderTaskQueue.add(t)},i.prototype._cancelRenderFrame=function(t){this._renderTaskQueue.remove(t)},i.prototype._render=function(e){var r,n=this,i=0,a=this.painter.context.extTimerQuery;if(this.listens(\"gpu-timing-frame\")&&(r=a.createQueryEXT(),a.beginQueryEXT(a.TIME_ELAPSED_EXT,r),i=t.browser.now()),this.painter.context.setDirty(),this.painter.setBaseState(),this._renderTaskQueue.run(e),!this._removed){var o=!1;if(this.style&&this._styleDirty){this._styleDirty=!1;var s=this.transform.zoom,l=t.browser.now();this.style.zoomHistory.update(s,l);var c=new t.EvaluationParameters(s,{now:l,fadeDuration:this._fadeDuration,zoomHistory:this.style.zoomHistory,transition:this.style.getTransition()}),u=c.crossFadingFactor();1===u&&u===this._crossFadingFactor||(o=!0,this._crossFadingFactor=u),this.style.update(c)}if(this.style&&this._sourcesDirty&&(this._sourcesDirty=!1,this.style._updateSources(this.transform)),this._placementDirty=this.style&&this.style._updatePlacement(this.painter.transform,this.showCollisionBoxes,this._fadeDuration,this._crossSourceCollisions),this.painter.render(this.style,{showTileBoundaries:this.showTileBoundaries,showOverdrawInspector:this._showOverdrawInspector,rotating:this.isRotating(),zooming:this.isZooming(),moving:this.isMoving(),fadeDuration:this._fadeDuration,showPadding:this.showPadding,gpuTiming:!!this.listens(\"gpu-timing-layer\")}),this.fire(new t.Event(\"render\")),this.loaded()&&!this._loaded&&(this._loaded=!0,this.fire(new t.Event(\"load\"))),this.style&&(this.style.hasTransitions()||o)&&(this._styleDirty=!0),this.style&&!this._placementDirty&&this.style._releaseSymbolFadeTiles(),this.listens(\"gpu-timing-frame\")){var f=t.browser.now()-i;a.endQueryEXT(a.TIME_ELAPSED_EXT,r),setTimeout((function(){var e=a.getQueryObjectEXT(r,a.QUERY_RESULT_EXT)/1e6;a.deleteQueryEXT(r),n.fire(new t.Event(\"gpu-timing-frame\",{cpuTime:f,gpuTime:e}))}),50)}if(this.listens(\"gpu-timing-layer\")){var h=this.painter.collectGpuTimers();setTimeout((function(){var e=n.painter.queryGpuTimers(h);n.fire(new t.Event(\"gpu-timing-layer\",{layerTimes:e}))}),50)}return this._sourcesDirty||this._styleDirty||this._placementDirty||this._repaint?this.triggerRepaint():!this.isMoving()&&this.loaded()&&(this._fullyLoaded||(this._fullyLoaded=!0),this.fire(new t.Event(\"idle\"))),this}},i.prototype.remove=function(){this._hash&&this._hash.remove();for(var e=0,r=this._controls;e<r.length;e+=1)r[e].onRemove(this);this._controls=[],this._frame&&(this._frame.cancel(),this._frame=null),this._renderTaskQueue.clear(),this.painter.destroy(),this.handlers.destroy(),delete this.handlers,this.setStyle(null),void 0!==t.window&&(t.window.removeEventListener(\"resize\",this._onWindowResize,!1),t.window.removeEventListener(\"online\",this._onWindowOnline,!1));var n=this.painter.context.gl.getExtension(\"WEBGL_lose_context\");n&&n.loseContext(),Ai(this._canvasContainer),Ai(this._controlContainer),Ai(this._missingCSSCanary),this._container.classList.remove(\"mapboxgl-map\"),this._removed=!0,this.fire(new t.Event(\"remove\"))},i.prototype.triggerRepaint=function(){var e=this;this.style&&!this._frame&&(this._frame=t.browser.frame((function(t){e._frame=null,e._render(t)})))},i.prototype._onWindowOnline=function(){this._update()},i.prototype._onWindowResize=function(t){this._trackResize&&this.resize({originalEvent:t})._update()},a.showTileBoundaries.get=function(){return!!this._showTileBoundaries},a.showTileBoundaries.set=function(t){this._showTileBoundaries!==t&&(this._showTileBoundaries=t,this._update())},a.showPadding.get=function(){return!!this._showPadding},a.showPadding.set=function(t){this._showPadding!==t&&(this._showPadding=t,this._update())},a.showCollisionBoxes.get=function(){return!!this._showCollisionBoxes},a.showCollisionBoxes.set=function(t){this._showCollisionBoxes!==t&&(this._showCollisionBoxes=t,t?this.style._generateCollisionBoxes():this._update())},a.showOverdrawInspector.get=function(){return!!this._showOverdrawInspector},a.showOverdrawInspector.set=function(t){this._showOverdrawInspector!==t&&(this._showOverdrawInspector=t,this._update())},a.repaint.get=function(){return!!this._repaint},a.repaint.set=function(t){this._repaint!==t&&(this._repaint=t,this.triggerRepaint())},a.vertices.get=function(){return!!this._vertices},a.vertices.set=function(t){this._vertices=t,this._update()},i.prototype._setCacheLimits=function(e,r){t.setCacheLimits(e,r)},a.version.get=function(){return t.version},Object.defineProperties(i.prototype,a),i}(mi);function Ai(t){t.parentNode&&t.parentNode.removeChild(t)}var Si={showCompass:!0,showZoom:!0,visualizePitch:!1},Ei=function(e){var n=this;this.options=t.extend({},Si,e),this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this.options.showZoom&&(t.bindAll([\"_setButtonTitle\",\"_updateZoomButtons\"],this),this._zoomInButton=this._createButton(\"mapboxgl-ctrl-zoom-in\",(function(t){return n._map.zoomIn({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomInButton).setAttribute(\"aria-hidden\",!0),this._zoomOutButton=this._createButton(\"mapboxgl-ctrl-zoom-out\",(function(t){return n._map.zoomOut({},{originalEvent:t})})),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._zoomOutButton).setAttribute(\"aria-hidden\",!0)),this.options.showCompass&&(t.bindAll([\"_rotateCompassArrow\"],this),this._compass=this._createButton(\"mapboxgl-ctrl-compass\",(function(t){n.options.visualizePitch?n._map.resetNorthPitch({},{originalEvent:t}):n._map.resetNorth({},{originalEvent:t})})),this._compassIcon=r.create(\"span\",\"mapboxgl-ctrl-icon\",this._compass),this._compassIcon.setAttribute(\"aria-hidden\",!0))};Ei.prototype._updateZoomButtons=function(){var t=this._map.getZoom();this._zoomInButton.disabled=t===this._map.getMaxZoom(),this._zoomOutButton.disabled=t===this._map.getMinZoom()},Ei.prototype._rotateCompassArrow=function(){var t=this.options.visualizePitch?\"scale(\"+1/Math.pow(Math.cos(this._map.transform.pitch*(Math.PI/180)),.5)+\") rotateX(\"+this._map.transform.pitch+\"deg) rotateZ(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\":\"rotate(\"+this._map.transform.angle*(180/Math.PI)+\"deg)\";this._compassIcon.style.transform=t},Ei.prototype.onAdd=function(t){return this._map=t,this.options.showZoom&&(this._setButtonTitle(this._zoomInButton,\"ZoomIn\"),this._setButtonTitle(this._zoomOutButton,\"ZoomOut\"),this._map.on(\"zoom\",this._updateZoomButtons),this._updateZoomButtons()),this.options.showCompass&&(this._setButtonTitle(this._compass,\"ResetBearing\"),this.options.visualizePitch&&this._map.on(\"pitch\",this._rotateCompassArrow),this._map.on(\"rotate\",this._rotateCompassArrow),this._rotateCompassArrow(),this._handler=new Ci(this._map,this._compass,this.options.visualizePitch)),this._container},Ei.prototype.onRemove=function(){r.remove(this._container),this.options.showZoom&&this._map.off(\"zoom\",this._updateZoomButtons),this.options.showCompass&&(this.options.visualizePitch&&this._map.off(\"pitch\",this._rotateCompassArrow),this._map.off(\"rotate\",this._rotateCompassArrow),this._handler.off(),delete this._handler),delete this._map},Ei.prototype._createButton=function(t,e){var n=r.create(\"button\",t,this._container);return n.type=\"button\",n.addEventListener(\"click\",e),n},Ei.prototype._setButtonTitle=function(t,e){var r=this._map._getUIString(\"NavigationControl.\"+e);t.title=r,t.setAttribute(\"aria-label\",r)};var Ci=function(e,n,i){void 0===i&&(i=!1),this._clickTolerance=10,this.element=n,this.mouseRotate=new Gn({clickTolerance:e.dragRotate._mouseRotate._clickTolerance}),this.map=e,i&&(this.mousePitch=new Yn({clickTolerance:e.dragRotate._mousePitch._clickTolerance})),t.bindAll([\"mousedown\",\"mousemove\",\"mouseup\",\"touchstart\",\"touchmove\",\"touchend\",\"reset\"],this),r.addEventListener(n,\"mousedown\",this.mousedown),r.addEventListener(n,\"touchstart\",this.touchstart,{passive:!1}),r.addEventListener(n,\"touchmove\",this.touchmove),r.addEventListener(n,\"touchend\",this.touchend),r.addEventListener(n,\"touchcancel\",this.reset)};function Li(e,r,n){if(e=new t.LngLat(e.lng,e.lat),r){var i=new t.LngLat(e.lng-360,e.lat),a=new t.LngLat(e.lng+360,e.lat),o=n.locationPoint(e).distSqr(r);n.locationPoint(i).distSqr(r)<o?e=i:n.locationPoint(a).distSqr(r)<o&&(e=a)}for(;Math.abs(e.lng-n.center.lng)>180;){var s=n.locationPoint(e);if(s.x>=0&&s.y>=0&&s.x<=n.width&&s.y<=n.height)break;e.lng>n.center.lng?e.lng-=360:e.lng+=360}return e}Ci.prototype.down=function(t,e){this.mouseRotate.mousedown(t,e),this.mousePitch&&this.mousePitch.mousedown(t,e),r.disableDrag()},Ci.prototype.move=function(t,e){var r=this.map,n=this.mouseRotate.mousemoveWindow(t,e);if(n&&n.bearingDelta&&r.setBearing(r.getBearing()+n.bearingDelta),this.mousePitch){var i=this.mousePitch.mousemoveWindow(t,e);i&&i.pitchDelta&&r.setPitch(r.getPitch()+i.pitchDelta)}},Ci.prototype.off=function(){var t=this.element;r.removeEventListener(t,\"mousedown\",this.mousedown),r.removeEventListener(t,\"touchstart\",this.touchstart,{passive:!1}),r.removeEventListener(t,\"touchmove\",this.touchmove),r.removeEventListener(t,\"touchend\",this.touchend),r.removeEventListener(t,\"touchcancel\",this.reset),this.offTemp()},Ci.prototype.offTemp=function(){r.enableDrag(),r.removeEventListener(t.window,\"mousemove\",this.mousemove),r.removeEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousedown=function(e){this.down(t.extend({},e,{ctrlKey:!0,preventDefault:function(){return e.preventDefault()}}),r.mousePos(this.element,e)),r.addEventListener(t.window,\"mousemove\",this.mousemove),r.addEventListener(t.window,\"mouseup\",this.mouseup)},Ci.prototype.mousemove=function(t){this.move(t,r.mousePos(this.element,t))},Ci.prototype.mouseup=function(t){this.mouseRotate.mouseupWindow(t),this.mousePitch&&this.mousePitch.mouseupWindow(t),this.offTemp()},Ci.prototype.touchstart=function(t){1!==t.targetTouches.length?this.reset():(this._startPos=this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.down({type:\"mousedown\",button:0,ctrlKey:!0,preventDefault:function(){return t.preventDefault()}},this._startPos))},Ci.prototype.touchmove=function(t){1!==t.targetTouches.length?this.reset():(this._lastPos=r.touchPos(this.element,t.targetTouches)[0],this.move({preventDefault:function(){return t.preventDefault()}},this._lastPos))},Ci.prototype.touchend=function(t){0===t.targetTouches.length&&this._startPos&&this._lastPos&&this._startPos.dist(this._lastPos)<this._clickTolerance&&this.element.click(),this.reset()},Ci.prototype.reset=function(){this.mouseRotate.reset(),this.mousePitch&&this.mousePitch.reset(),delete this._startPos,delete this._lastPos,this.offTemp()};var Ii={center:\"translate(-50%,-50%)\",top:\"translate(-50%,0)\",\"top-left\":\"translate(0,0)\",\"top-right\":\"translate(-100%,0)\",bottom:\"translate(-50%,-100%)\",\"bottom-left\":\"translate(0,-100%)\",\"bottom-right\":\"translate(-100%,-100%)\",left:\"translate(0,-50%)\",right:\"translate(-100%,-50%)\"};function Pi(t,e,r){var n=t.classList;for(var i in Ii)n.remove(\"mapboxgl-\"+r+\"-anchor-\"+i);n.add(\"mapboxgl-\"+r+\"-anchor-\"+e)}var zi,Oi=function(e){function n(n,i){var a=this;if(e.call(this),(n instanceof t.window.HTMLElement||i)&&(n=t.extend({element:n},i)),t.bindAll([\"_update\",\"_onMove\",\"_onUp\",\"_addDragHandler\",\"_onMapClick\",\"_onKeyPress\"],this),this._anchor=n&&n.anchor||\"center\",this._color=n&&n.color||\"#3FB1CE\",this._draggable=n&&n.draggable||!1,this._state=\"inactive\",this._rotation=n&&n.rotation||0,this._rotationAlignment=n&&n.rotationAlignment||\"auto\",this._pitchAlignment=n&&n.pitchAlignment&&\"auto\"!==n.pitchAlignment?n.pitchAlignment:this._rotationAlignment,n&&n.element)this._element=n.element,this._offset=t.Point.convert(n&&n.offset||[0,0]);else{this._defaultMarker=!0,this._element=r.create(\"div\"),this._element.setAttribute(\"aria-label\",\"Map marker\");var o=r.createNS(\"http://www.w3.org/2000/svg\",\"svg\");o.setAttributeNS(null,\"display\",\"block\"),o.setAttributeNS(null,\"height\",\"41px\"),o.setAttributeNS(null,\"width\",\"27px\"),o.setAttributeNS(null,\"viewBox\",\"0 0 27 41\");var s=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");s.setAttributeNS(null,\"stroke\",\"none\"),s.setAttributeNS(null,\"stroke-width\",\"1\"),s.setAttributeNS(null,\"fill\",\"none\"),s.setAttributeNS(null,\"fill-rule\",\"evenodd\");var l=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");l.setAttributeNS(null,\"fill-rule\",\"nonzero\");var c=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");c.setAttributeNS(null,\"transform\",\"translate(3.0, 29.0)\"),c.setAttributeNS(null,\"fill\",\"#000000\");for(var u=0,f=[{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"10.5\",ry:\"5.25002273\"},{rx:\"9.5\",ry:\"4.77275007\"},{rx:\"8.5\",ry:\"4.29549936\"},{rx:\"7.5\",ry:\"3.81822308\"},{rx:\"6.5\",ry:\"3.34094679\"},{rx:\"5.5\",ry:\"2.86367051\"},{rx:\"4.5\",ry:\"2.38636864\"}];u<f.length;u+=1){var h=f[u],p=r.createNS(\"http://www.w3.org/2000/svg\",\"ellipse\");p.setAttributeNS(null,\"opacity\",\"0.04\"),p.setAttributeNS(null,\"cx\",\"10.5\"),p.setAttributeNS(null,\"cy\",\"5.80029008\"),p.setAttributeNS(null,\"rx\",h.rx),p.setAttributeNS(null,\"ry\",h.ry),c.appendChild(p)}var d=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");d.setAttributeNS(null,\"fill\",this._color);var g=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");g.setAttributeNS(null,\"d\",\"M27,13.5 C27,19.074644 20.250001,27.000002 14.75,34.500002 C14.016665,35.500004 12.983335,35.500004 12.25,34.500002 C6.7499993,27.000002 0,19.222562 0,13.5 C0,6.0441559 6.0441559,0 13.5,0 C20.955844,0 27,6.0441559 27,13.5 Z\"),d.appendChild(g);var m=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");m.setAttributeNS(null,\"opacity\",\"0.25\"),m.setAttributeNS(null,\"fill\",\"#000000\");var v=r.createNS(\"http://www.w3.org/2000/svg\",\"path\");v.setAttributeNS(null,\"d\",\"M13.5,0 C6.0441559,0 0,6.0441559 0,13.5 C0,19.222562 6.7499993,27 12.25,34.5 C13,35.522727 14.016664,35.500004 14.75,34.5 C20.250001,27 27,19.074644 27,13.5 C27,6.0441559 20.955844,0 13.5,0 Z M13.5,1 C20.415404,1 26,6.584596 26,13.5 C26,15.898657 24.495584,19.181431 22.220703,22.738281 C19.945823,26.295132 16.705119,30.142167 13.943359,33.908203 C13.743445,34.180814 13.612715,34.322738 13.5,34.441406 C13.387285,34.322738 13.256555,34.180814 13.056641,33.908203 C10.284481,30.127985 7.4148684,26.314159 5.015625,22.773438 C2.6163816,19.232715 1,15.953538 1,13.5 C1,6.584596 6.584596,1 13.5,1 Z\"),m.appendChild(v);var y=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");y.setAttributeNS(null,\"transform\",\"translate(6.0, 7.0)\"),y.setAttributeNS(null,\"fill\",\"#FFFFFF\");var x=r.createNS(\"http://www.w3.org/2000/svg\",\"g\");x.setAttributeNS(null,\"transform\",\"translate(8.0, 8.0)\");var b=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");b.setAttributeNS(null,\"fill\",\"#000000\"),b.setAttributeNS(null,\"opacity\",\"0.25\"),b.setAttributeNS(null,\"cx\",\"5.5\"),b.setAttributeNS(null,\"cy\",\"5.5\"),b.setAttributeNS(null,\"r\",\"5.4999962\");var _=r.createNS(\"http://www.w3.org/2000/svg\",\"circle\");_.setAttributeNS(null,\"fill\",\"#FFFFFF\"),_.setAttributeNS(null,\"cx\",\"5.5\"),_.setAttributeNS(null,\"cy\",\"5.5\"),_.setAttributeNS(null,\"r\",\"5.4999962\"),x.appendChild(b),x.appendChild(_),l.appendChild(c),l.appendChild(d),l.appendChild(m),l.appendChild(y),l.appendChild(x),o.appendChild(l),this._element.appendChild(o),this._offset=t.Point.convert(n&&n.offset||[0,-14])}this._element.classList.add(\"mapboxgl-marker\"),this._element.addEventListener(\"dragstart\",(function(t){t.preventDefault()})),this._element.addEventListener(\"mousedown\",(function(t){t.preventDefault()})),this._element.addEventListener(\"focus\",(function(){var t=a._map.getContainer();t.scrollTop=0,t.scrollLeft=0})),Pi(this._element,this._anchor,\"marker\"),this._popup=null}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(t){return this.remove(),this._map=t,t.getCanvasContainer().appendChild(this._element),t.on(\"move\",this._update),t.on(\"moveend\",this._update),this.setDraggable(this._draggable),this._update(),this._map.on(\"click\",this._onMapClick),this},n.prototype.remove=function(){return this._map&&(this._map.off(\"click\",this._onMapClick),this._map.off(\"move\",this._update),this._map.off(\"moveend\",this._update),this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler),this._map.off(\"mouseup\",this._onUp),this._map.off(\"touchend\",this._onUp),this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),delete this._map),r.remove(this._element),this._popup&&this._popup.remove(),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._popup&&this._popup.setLngLat(this._lngLat),this._update(),this},n.prototype.getElement=function(){return this._element},n.prototype.setPopup=function(t){if(this._popup&&(this._popup.remove(),this._popup=null,this._element.removeEventListener(\"keypress\",this._onKeyPress),this._originalTabIndex||this._element.removeAttribute(\"tabindex\")),t){if(!(\"offset\"in t.options)){var e=Math.sqrt(Math.pow(13.5,2)/2);t.options.offset=this._defaultMarker?{top:[0,0],\"top-left\":[0,0],\"top-right\":[0,0],bottom:[0,-38.1],\"bottom-left\":[e,-1*(24.6+e)],\"bottom-right\":[-e,-1*(24.6+e)],left:[13.5,-24.6],right:[-13.5,-24.6]}:this._offset}this._popup=t,this._lngLat&&this._popup.setLngLat(this._lngLat),this._originalTabIndex=this._element.getAttribute(\"tabindex\"),this._originalTabIndex||this._element.setAttribute(\"tabindex\",\"0\"),this._element.addEventListener(\"keypress\",this._onKeyPress)}return this},n.prototype._onKeyPress=function(t){var e=t.code,r=t.charCode||t.keyCode;\"Space\"!==e&&\"Enter\"!==e&&32!==r&&13!==r||this.togglePopup()},n.prototype._onMapClick=function(t){var e=t.originalEvent.target,r=this._element;this._popup&&(e===r||r.contains(e))&&this.togglePopup()},n.prototype.getPopup=function(){return this._popup},n.prototype.togglePopup=function(){var t=this._popup;return t?(t.isOpen()?t.remove():t.addTo(this._map),this):this},n.prototype._update=function(t){if(this._map){this._map.transform.renderWorldCopies&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),this._pos=this._map.project(this._lngLat)._add(this._offset);var e=\"\";\"viewport\"===this._rotationAlignment||\"auto\"===this._rotationAlignment?e=\"rotateZ(\"+this._rotation+\"deg)\":\"map\"===this._rotationAlignment&&(e=\"rotateZ(\"+(this._rotation-this._map.getBearing())+\"deg)\");var n=\"\";\"viewport\"===this._pitchAlignment||\"auto\"===this._pitchAlignment?n=\"rotateX(0deg)\":\"map\"===this._pitchAlignment&&(n=\"rotateX(\"+this._map.getPitch()+\"deg)\"),t&&\"moveend\"!==t.type||(this._pos=this._pos.round()),r.setTransform(this._element,Ii[this._anchor]+\" translate(\"+this._pos.x+\"px, \"+this._pos.y+\"px) \"+n+\" \"+e)}},n.prototype.getOffset=function(){return this._offset},n.prototype.setOffset=function(e){return this._offset=t.Point.convert(e),this._update(),this},n.prototype._onMove=function(e){this._pos=e.point.sub(this._positionDelta),this._lngLat=this._map.unproject(this._pos),this.setLngLat(this._lngLat),this._element.style.pointerEvents=\"none\",\"pending\"===this._state&&(this._state=\"active\",this.fire(new t.Event(\"dragstart\"))),this.fire(new t.Event(\"drag\"))},n.prototype._onUp=function(){this._element.style.pointerEvents=\"auto\",this._positionDelta=null,this._map.off(\"mousemove\",this._onMove),this._map.off(\"touchmove\",this._onMove),\"active\"===this._state&&this.fire(new t.Event(\"dragend\")),this._state=\"inactive\"},n.prototype._addDragHandler=function(t){this._element.contains(t.originalEvent.target)&&(t.preventDefault(),this._positionDelta=t.point.sub(this._pos).add(this._offset),this._state=\"pending\",this._map.on(\"mousemove\",this._onMove),this._map.on(\"touchmove\",this._onMove),this._map.once(\"mouseup\",this._onUp),this._map.once(\"touchend\",this._onUp))},n.prototype.setDraggable=function(t){return this._draggable=!!t,this._map&&(t?(this._map.on(\"mousedown\",this._addDragHandler),this._map.on(\"touchstart\",this._addDragHandler)):(this._map.off(\"mousedown\",this._addDragHandler),this._map.off(\"touchstart\",this._addDragHandler))),this},n.prototype.isDraggable=function(){return this._draggable},n.prototype.setRotation=function(t){return this._rotation=t||0,this._update(),this},n.prototype.getRotation=function(){return this._rotation},n.prototype.setRotationAlignment=function(t){return this._rotationAlignment=t||\"auto\",this._update(),this},n.prototype.getRotationAlignment=function(){return this._rotationAlignment},n.prototype.setPitchAlignment=function(t){return this._pitchAlignment=t&&\"auto\"!==t?t:this._rotationAlignment,this._update(),this},n.prototype.getPitchAlignment=function(){return this._pitchAlignment},n}(t.Evented),Di={positionOptions:{enableHighAccuracy:!1,maximumAge:0,timeout:6e3},fitBoundsOptions:{maxZoom:15},trackUserLocation:!1,showAccuracyCircle:!0,showUserLocation:!0},Ri=0,Fi=!1,Bi=function(e){function n(r){e.call(this),this.options=t.extend({},Di,r),t.bindAll([\"_onSuccess\",\"_onError\",\"_onZoom\",\"_finish\",\"_setupUI\",\"_updateCamera\",\"_updateMarker\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.onAdd=function(e){var n;return this._map=e,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),n=this._setupUI,void 0!==zi?n(zi):void 0!==t.window.navigator.permissions?t.window.navigator.permissions.query({name:\"geolocation\"}).then((function(t){n(zi=\"denied\"!==t.state)})):n(zi=!!t.window.navigator.geolocation),this._container},n.prototype.onRemove=function(){void 0!==this._geolocationWatchID&&(t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0),this.options.showUserLocation&&this._userLocationDotMarker&&this._userLocationDotMarker.remove(),this.options.showAccuracyCircle&&this._accuracyCircleMarker&&this._accuracyCircleMarker.remove(),r.remove(this._container),this._map.off(\"zoom\",this._onZoom),this._map=void 0,Ri=0,Fi=!1},n.prototype._isOutOfMapMaxBounds=function(t){var e=this._map.getMaxBounds(),r=t.coords;return e&&(r.longitude<e.getWest()||r.longitude>e.getEast()||r.latitude<e.getSouth()||r.latitude>e.getNorth())},n.prototype._setErrorState=function(){switch(this._watchState){case\"WAITING_ACTIVE\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"ACTIVE_LOCK\":this._watchState=\"ACTIVE_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\");break;case\"BACKGROUND\":this._watchState=\"BACKGROUND_ERROR\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\")}},n.prototype._onSuccess=function(e){if(this._map){if(this._isOutOfMapMaxBounds(e))return this._setErrorState(),this.fire(new t.Event(\"outofmaxbounds\",e)),this._updateMarker(),void this._finish();if(this.options.trackUserLocation)switch(this._lastKnownPosition=e,this._watchState){case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"BACKGROUND\":case\"BACKGROUND_ERROR\":this._watchState=\"BACKGROUND\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\")}this.options.showUserLocation&&\"OFF\"!==this._watchState&&this._updateMarker(e),this.options.trackUserLocation&&\"ACTIVE_LOCK\"!==this._watchState||this._updateCamera(e),this.options.showUserLocation&&this._dotElement.classList.remove(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"geolocate\",e)),this._finish()}},n.prototype._updateCamera=function(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude),n=e.coords.accuracy,i=this._map.getBearing(),a=t.extend({bearing:i},this.options.fitBoundsOptions);this._map.fitBounds(r.toBounds(n),a,{geolocateSource:!0})},n.prototype._updateMarker=function(e){if(e){var r=new t.LngLat(e.coords.longitude,e.coords.latitude);this._accuracyCircleMarker.setLngLat(r).addTo(this._map),this._userLocationDotMarker.setLngLat(r).addTo(this._map),this._accuracy=e.coords.accuracy,this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()}else this._userLocationDotMarker.remove(),this._accuracyCircleMarker.remove()},n.prototype._updateCircleRadius=function(){var t=this._map._container.clientHeight/2,e=this._map.unproject([0,t]),r=this._map.unproject([1,t]),n=e.distanceTo(r),i=Math.ceil(2*this._accuracy/n);this._circleElement.style.width=i+\"px\",this._circleElement.style.height=i+\"px\"},n.prototype._onZoom=function(){this.options.showUserLocation&&this.options.showAccuracyCircle&&this._updateCircleRadius()},n.prototype._onError=function(e){if(this._map){if(this.options.trackUserLocation)if(1===e.code){this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this._geolocateButton.disabled=!0;var r=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.title=r,this._geolocateButton.setAttribute(\"aria-label\",r),void 0!==this._geolocationWatchID&&this._clearWatch()}else{if(3===e.code&&Fi)return;this._setErrorState()}\"OFF\"!==this._watchState&&this.options.showUserLocation&&this._dotElement.classList.add(\"mapboxgl-user-location-dot-stale\"),this.fire(new t.Event(\"error\",e)),this._finish()}},n.prototype._finish=function(){this._timeoutId&&clearTimeout(this._timeoutId),this._timeoutId=void 0},n.prototype._setupUI=function(e){var n=this;if(this._container.addEventListener(\"contextmenu\",(function(t){return t.preventDefault()})),this._geolocateButton=r.create(\"button\",\"mapboxgl-ctrl-geolocate\",this._container),r.create(\"span\",\"mapboxgl-ctrl-icon\",this._geolocateButton).setAttribute(\"aria-hidden\",!0),this._geolocateButton.type=\"button\",!1===e){t.warnOnce(\"Geolocation support is not available so the GeolocateControl will be disabled.\");var i=this._map._getUIString(\"GeolocateControl.LocationNotAvailable\");this._geolocateButton.disabled=!0,this._geolocateButton.title=i,this._geolocateButton.setAttribute(\"aria-label\",i)}else{var a=this._map._getUIString(\"GeolocateControl.FindMyLocation\");this._geolocateButton.title=a,this._geolocateButton.setAttribute(\"aria-label\",a)}this.options.trackUserLocation&&(this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this._watchState=\"OFF\"),this.options.showUserLocation&&(this._dotElement=r.create(\"div\",\"mapboxgl-user-location-dot\"),this._userLocationDotMarker=new Oi(this._dotElement),this._circleElement=r.create(\"div\",\"mapboxgl-user-location-accuracy-circle\"),this._accuracyCircleMarker=new Oi({element:this._circleElement,pitchAlignment:\"map\"}),this.options.trackUserLocation&&(this._watchState=\"OFF\"),this._map.on(\"zoom\",this._onZoom)),this._geolocateButton.addEventListener(\"click\",this.trigger.bind(this)),this._setup=!0,this.options.trackUserLocation&&this._map.on(\"movestart\",(function(e){e.geolocateSource||\"ACTIVE_LOCK\"!==n._watchState||e.originalEvent&&\"resize\"===e.originalEvent.type||(n._watchState=\"BACKGROUND\",n._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\"),n._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),n.fire(new t.Event(\"trackuserlocationend\")))}))},n.prototype.trigger=function(){if(!this._setup)return t.warnOnce(\"Geolocate control triggered before added to a map\"),!1;if(this.options.trackUserLocation){switch(this._watchState){case\"OFF\":this._watchState=\"WAITING_ACTIVE\",this.fire(new t.Event(\"trackuserlocationstart\"));break;case\"WAITING_ACTIVE\":case\"ACTIVE_LOCK\":case\"ACTIVE_ERROR\":case\"BACKGROUND_ERROR\":Ri--,Fi=!1,this._watchState=\"OFF\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-active-error\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background-error\"),this.fire(new t.Event(\"trackuserlocationend\"));break;case\"BACKGROUND\":this._watchState=\"ACTIVE_LOCK\",this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-background\"),this._lastKnownPosition&&this._updateCamera(this._lastKnownPosition),this.fire(new t.Event(\"trackuserlocationstart\"))}switch(this._watchState){case\"WAITING_ACTIVE\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_LOCK\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active\");break;case\"ACTIVE_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-active-error\");break;case\"BACKGROUND\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background\");break;case\"BACKGROUND_ERROR\":this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-background-error\")}if(\"OFF\"===this._watchState&&void 0!==this._geolocationWatchID)this._clearWatch();else if(void 0===this._geolocationWatchID){var e;this._geolocateButton.classList.add(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"true\"),++Ri>1?(e={maximumAge:6e5,timeout:0},Fi=!0):(e=this.options.positionOptions,Fi=!1),this._geolocationWatchID=t.window.navigator.geolocation.watchPosition(this._onSuccess,this._onError,e)}}else t.window.navigator.geolocation.getCurrentPosition(this._onSuccess,this._onError,this.options.positionOptions),this._timeoutId=setTimeout(this._finish,1e4);return!0},n.prototype._clearWatch=function(){t.window.navigator.geolocation.clearWatch(this._geolocationWatchID),this._geolocationWatchID=void 0,this._geolocateButton.classList.remove(\"mapboxgl-ctrl-geolocate-waiting\"),this._geolocateButton.setAttribute(\"aria-pressed\",\"false\"),this.options.showUserLocation&&this._updateMarker(null)},n}(t.Evented),Ni={maxWidth:100,unit:\"metric\"},ji=function(e){this.options=t.extend({},Ni,e),t.bindAll([\"_onMove\",\"setUnit\"],this)};function Ui(t,e,r){var n=r&&r.maxWidth||100,i=t._container.clientHeight/2,a=t.unproject([0,i]),o=t.unproject([n,i]),s=a.distanceTo(o);if(r&&\"imperial\"===r.unit){var l=3.2808*s;l>5280?Vi(e,n,l/5280,t._getUIString(\"ScaleControl.Miles\")):Vi(e,n,l,t._getUIString(\"ScaleControl.Feet\"))}else r&&\"nautical\"===r.unit?Vi(e,n,s/1852,t._getUIString(\"ScaleControl.NauticalMiles\")):s>=1e3?Vi(e,n,s/1e3,t._getUIString(\"ScaleControl.Kilometers\")):Vi(e,n,s,t._getUIString(\"ScaleControl.Meters\"))}function Vi(t,e,r,n){var i,a,o,s=(i=r,(a=Math.pow(10,(\"\"+Math.floor(i)).length-1))*(o=(o=i/a)>=10?10:o>=5?5:o>=3?3:o>=2?2:o>=1?1:function(t){var e=Math.pow(10,Math.ceil(-Math.log(t)/Math.LN10));return Math.round(t*e)/e}(o)));t.style.width=e*(s/r)+\"px\",t.innerHTML=s+\"&nbsp;\"+n}ji.prototype.getDefaultPosition=function(){return\"bottom-left\"},ji.prototype._onMove=function(){Ui(this._map,this._container,this.options)},ji.prototype.onAdd=function(t){return this._map=t,this._container=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-scale\",t.getContainer()),this._map.on(\"move\",this._onMove),this._onMove(),this._container},ji.prototype.onRemove=function(){r.remove(this._container),this._map.off(\"move\",this._onMove),this._map=void 0},ji.prototype.setUnit=function(t){this.options.unit=t,Ui(this._map,this._container,this.options)};var qi=function(e){this._fullscreen=!1,e&&e.container&&(e.container instanceof t.window.HTMLElement?this._container=e.container:t.warnOnce(\"Full screen control 'container' must be a DOM element.\")),t.bindAll([\"_onClickFullscreen\",\"_changeIcon\"],this),\"onfullscreenchange\"in t.window.document?this._fullscreenchange=\"fullscreenchange\":\"onmozfullscreenchange\"in t.window.document?this._fullscreenchange=\"mozfullscreenchange\":\"onwebkitfullscreenchange\"in t.window.document?this._fullscreenchange=\"webkitfullscreenchange\":\"onmsfullscreenchange\"in t.window.document&&(this._fullscreenchange=\"MSFullscreenChange\")};qi.prototype.onAdd=function(e){return this._map=e,this._container||(this._container=this._map.getContainer()),this._controlContainer=r.create(\"div\",\"mapboxgl-ctrl mapboxgl-ctrl-group\"),this._checkFullscreenSupport()?this._setupUI():(this._controlContainer.style.display=\"none\",t.warnOnce(\"This device does not support fullscreen mode.\")),this._controlContainer},qi.prototype.onRemove=function(){r.remove(this._controlContainer),this._map=null,t.window.document.removeEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._checkFullscreenSupport=function(){return!!(t.window.document.fullscreenEnabled||t.window.document.mozFullScreenEnabled||t.window.document.msFullscreenEnabled||t.window.document.webkitFullscreenEnabled)},qi.prototype._setupUI=function(){var e=this._fullscreenButton=r.create(\"button\",\"mapboxgl-ctrl-fullscreen\",this._controlContainer);r.create(\"span\",\"mapboxgl-ctrl-icon\",e).setAttribute(\"aria-hidden\",!0),e.type=\"button\",this._updateTitle(),this._fullscreenButton.addEventListener(\"click\",this._onClickFullscreen),t.window.document.addEventListener(this._fullscreenchange,this._changeIcon)},qi.prototype._updateTitle=function(){var t=this._getTitle();this._fullscreenButton.setAttribute(\"aria-label\",t),this._fullscreenButton.title=t},qi.prototype._getTitle=function(){return this._map._getUIString(this._isFullscreen()?\"FullscreenControl.Exit\":\"FullscreenControl.Enter\")},qi.prototype._isFullscreen=function(){return this._fullscreen},qi.prototype._changeIcon=function(){(t.window.document.fullscreenElement||t.window.document.mozFullScreenElement||t.window.document.webkitFullscreenElement||t.window.document.msFullscreenElement)===this._container!==this._fullscreen&&(this._fullscreen=!this._fullscreen,this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-shrink\"),this._fullscreenButton.classList.toggle(\"mapboxgl-ctrl-fullscreen\"),this._updateTitle())},qi.prototype._onClickFullscreen=function(){this._isFullscreen()?t.window.document.exitFullscreen?t.window.document.exitFullscreen():t.window.document.mozCancelFullScreen?t.window.document.mozCancelFullScreen():t.window.document.msExitFullscreen?t.window.document.msExitFullscreen():t.window.document.webkitCancelFullScreen&&t.window.document.webkitCancelFullScreen():this._container.requestFullscreen?this._container.requestFullscreen():this._container.mozRequestFullScreen?this._container.mozRequestFullScreen():this._container.msRequestFullscreen?this._container.msRequestFullscreen():this._container.webkitRequestFullscreen&&this._container.webkitRequestFullscreen()};var Hi={closeButton:!0,closeOnClick:!0,className:\"\",maxWidth:\"240px\"},Gi=function(e){function n(r){e.call(this),this.options=t.extend(Object.create(Hi),r),t.bindAll([\"_update\",\"_onClose\",\"remove\",\"_onMouseMove\",\"_onMouseUp\",\"_onDrag\"],this)}return e&&(n.__proto__=e),(n.prototype=Object.create(e&&e.prototype)).constructor=n,n.prototype.addTo=function(e){return this._map&&this.remove(),this._map=e,this.options.closeOnClick&&this._map.on(\"click\",this._onClose),this.options.closeOnMove&&this._map.on(\"move\",this._onClose),this._map.on(\"remove\",this.remove),this._update(),this._trackPointer?(this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"mouseup\",this._onMouseUp),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")):this._map.on(\"move\",this._update),this.fire(new t.Event(\"open\")),this},n.prototype.isOpen=function(){return!!this._map},n.prototype.remove=function(){return this._content&&r.remove(this._content),this._container&&(r.remove(this._container),delete this._container),this._map&&(this._map.off(\"move\",this._update),this._map.off(\"move\",this._onClose),this._map.off(\"click\",this._onClose),this._map.off(\"remove\",this.remove),this._map.off(\"mousemove\",this._onMouseMove),this._map.off(\"mouseup\",this._onMouseUp),this._map.off(\"drag\",this._onDrag),delete this._map),this.fire(new t.Event(\"close\")),this},n.prototype.getLngLat=function(){return this._lngLat},n.prototype.setLngLat=function(e){return this._lngLat=t.LngLat.convert(e),this._pos=null,this._trackPointer=!1,this._update(),this._map&&(this._map.on(\"move\",this._update),this._map.off(\"mousemove\",this._onMouseMove),this._container&&this._container.classList.remove(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.remove(\"mapboxgl-track-pointer\")),this},n.prototype.trackPointer=function(){return this._trackPointer=!0,this._pos=null,this._update(),this._map&&(this._map.off(\"move\",this._update),this._map.on(\"mousemove\",this._onMouseMove),this._map.on(\"drag\",this._onDrag),this._container&&this._container.classList.add(\"mapboxgl-popup-track-pointer\"),this._map._canvasContainer.classList.add(\"mapboxgl-track-pointer\")),this},n.prototype.getElement=function(){return this._container},n.prototype.setText=function(e){return this.setDOMContent(t.window.document.createTextNode(e))},n.prototype.setHTML=function(e){var r,n=t.window.document.createDocumentFragment(),i=t.window.document.createElement(\"body\");for(i.innerHTML=e;r=i.firstChild;)n.appendChild(r);return this.setDOMContent(n)},n.prototype.getMaxWidth=function(){return this._container&&this._container.style.maxWidth},n.prototype.setMaxWidth=function(t){return this.options.maxWidth=t,this._update(),this},n.prototype.setDOMContent=function(t){return this._createContent(),this._content.appendChild(t),this._update(),this},n.prototype.addClassName=function(t){this._container&&this._container.classList.add(t)},n.prototype.removeClassName=function(t){this._container&&this._container.classList.remove(t)},n.prototype.toggleClassName=function(t){if(this._container)return this._container.classList.toggle(t)},n.prototype._createContent=function(){this._content&&r.remove(this._content),this._content=r.create(\"div\",\"mapboxgl-popup-content\",this._container),this.options.closeButton&&(this._closeButton=r.create(\"button\",\"mapboxgl-popup-close-button\",this._content),this._closeButton.type=\"button\",this._closeButton.setAttribute(\"aria-label\",\"Close popup\"),this._closeButton.innerHTML=\"&#215;\",this._closeButton.addEventListener(\"click\",this._onClose))},n.prototype._onMouseUp=function(t){this._update(t.point)},n.prototype._onMouseMove=function(t){this._update(t.point)},n.prototype._onDrag=function(t){this._update(t.point)},n.prototype._update=function(e){var n=this;if(this._map&&(this._lngLat||this._trackPointer)&&this._content&&(this._container||(this._container=r.create(\"div\",\"mapboxgl-popup\",this._map.getContainer()),this._tip=r.create(\"div\",\"mapboxgl-popup-tip\",this._container),this._container.appendChild(this._content),this.options.className&&this.options.className.split(\" \").forEach((function(t){return n._container.classList.add(t)})),this._trackPointer&&this._container.classList.add(\"mapboxgl-popup-track-pointer\")),this.options.maxWidth&&this._container.style.maxWidth!==this.options.maxWidth&&(this._container.style.maxWidth=this.options.maxWidth),this._map.transform.renderWorldCopies&&!this._trackPointer&&(this._lngLat=Li(this._lngLat,this._pos,this._map.transform)),!this._trackPointer||e)){var i=this._pos=this._trackPointer&&e?e:this._map.project(this._lngLat),a=this.options.anchor,o=function e(r){if(r){if(\"number\"==typeof r){var n=Math.round(Math.sqrt(.5*Math.pow(r,2)));return{center:new t.Point(0,0),top:new t.Point(0,r),\"top-left\":new t.Point(n,n),\"top-right\":new t.Point(-n,n),bottom:new t.Point(0,-r),\"bottom-left\":new t.Point(n,-n),\"bottom-right\":new t.Point(-n,-n),left:new t.Point(r,0),right:new t.Point(-r,0)}}if(r instanceof t.Point||Array.isArray(r)){var i=t.Point.convert(r);return{center:i,top:i,\"top-left\":i,\"top-right\":i,bottom:i,\"bottom-left\":i,\"bottom-right\":i,left:i,right:i}}return{center:t.Point.convert(r.center||[0,0]),top:t.Point.convert(r.top||[0,0]),\"top-left\":t.Point.convert(r[\"top-left\"]||[0,0]),\"top-right\":t.Point.convert(r[\"top-right\"]||[0,0]),bottom:t.Point.convert(r.bottom||[0,0]),\"bottom-left\":t.Point.convert(r[\"bottom-left\"]||[0,0]),\"bottom-right\":t.Point.convert(r[\"bottom-right\"]||[0,0]),left:t.Point.convert(r.left||[0,0]),right:t.Point.convert(r.right||[0,0])}}return e(new t.Point(0,0))}(this.options.offset);if(!a){var s,l=this._container.offsetWidth,c=this._container.offsetHeight;s=i.y+o.bottom.y<c?[\"top\"]:i.y>this._map.transform.height-c?[\"bottom\"]:[],i.x<l/2?s.push(\"left\"):i.x>this._map.transform.width-l/2&&s.push(\"right\"),a=0===s.length?\"bottom\":s.join(\"-\")}var u=i.add(o[a]).round();r.setTransform(this._container,Ii[a]+\" translate(\"+u.x+\"px,\"+u.y+\"px)\"),Pi(this._container,a,\"popup\")}},n.prototype._onClose=function(){this.remove()},n}(t.Evented),Yi={version:t.version,supported:e,setRTLTextPlugin:t.setRTLTextPlugin,getRTLTextPluginStatus:t.getRTLTextPluginStatus,Map:Mi,NavigationControl:Ei,GeolocateControl:Bi,AttributionControl:vi,ScaleControl:ji,FullscreenControl:qi,Popup:Gi,Marker:Oi,Style:qe,LngLat:t.LngLat,LngLatBounds:t.LngLatBounds,Point:t.Point,MercatorCoordinate:t.MercatorCoordinate,Evented:t.Evented,config:t.config,prewarm:function(){Bt().acquire(Ot)},clearPrewarmedResources:function(){var t=Rt;t&&(t.isPreloaded()&&1===t.numActive()?(t.release(Ot),Rt=null):console.warn(\"Could not clear WebWorkers since there are active Map instances that still reference it. The pre-warmed WebWorker pool can only be cleared when all map instances have been removed with map.remove()\"))},get accessToken(){return t.config.ACCESS_TOKEN},set accessToken(e){t.config.ACCESS_TOKEN=e},get baseApiUrl(){return t.config.API_URL},set baseApiUrl(e){t.config.API_URL=e},get workerCount(){return Dt.workerCount},set workerCount(t){Dt.workerCount=t},get maxParallelImageRequests(){return t.config.MAX_PARALLEL_IMAGE_REQUESTS},set maxParallelImageRequests(e){t.config.MAX_PARALLEL_IMAGE_REQUESTS=e},clearStorage:function(e){t.clearTileCache(e)},workerUrl:\"\"};return Yi})),r}))},{}],474:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=1<<t+1,r=new Array(e),n=0;n<e;++n)r[n]=a(t,n);return r};var n=t(\"convex-hull\");function i(t,e,r){for(var n=new Array(t),i=0;i<t;++i)n[i]=0,i===e&&(n[i]+=.5),i===r&&(n[i]+=.5);return n}function a(t,e){if(0===e||e===(1<<t+1)-1)return[];for(var r=[],a=[],o=0;o<=t;++o)if(e&1<<o){r.push(i(t,o-1,o-1)),a.push(null);for(var s=0;s<=t;++s)~e&1<<s&&(r.push(i(t,o-1,s-1)),a.push([o,s]))}var l=n(r),c=[];t:for(o=0;o<l.length;++o){var u=l[o],f=[];for(s=0;s<u.length;++s){if(!a[u[s]])continue t;f.push(a[u[s]].slice())}c.push(f)}return c}},{\"convex-hull\":135}],475:[function(t,e,r){var n=t(\"./normalize\"),i=t(\"gl-mat4/create\"),a=t(\"gl-mat4/clone\"),o=t(\"gl-mat4/determinant\"),s=t(\"gl-mat4/invert\"),l=t(\"gl-mat4/transpose\"),c={length:t(\"gl-vec3/length\"),normalize:t(\"gl-vec3/normalize\"),dot:t(\"gl-vec3/dot\"),cross:t(\"gl-vec3/cross\")},u=i(),f=i(),h=[0,0,0,0],p=[[0,0,0],[0,0,0],[0,0,0]],d=[0,0,0];function g(t,e,r,n,i){t[0]=e[0]*n+r[0]*i,t[1]=e[1]*n+r[1]*i,t[2]=e[2]*n+r[2]*i}e.exports=function(t,e,r,i,m,v){if(e||(e=[0,0,0]),r||(r=[0,0,0]),i||(i=[0,0,0]),m||(m=[0,0,0,1]),v||(v=[0,0,0,1]),!n(u,t))return!1;if(a(f,u),f[3]=0,f[7]=0,f[11]=0,f[15]=1,Math.abs(o(f)<1e-8))return!1;var y,x,b,_,w,T,k,M=u[3],A=u[7],S=u[11],E=u[12],C=u[13],L=u[14],I=u[15];if(0!==M||0!==A||0!==S){if(h[0]=M,h[1]=A,h[2]=S,h[3]=I,!s(f,f))return!1;l(f,f),y=m,b=f,_=(x=h)[0],w=x[1],T=x[2],k=x[3],y[0]=b[0]*_+b[4]*w+b[8]*T+b[12]*k,y[1]=b[1]*_+b[5]*w+b[9]*T+b[13]*k,y[2]=b[2]*_+b[6]*w+b[10]*T+b[14]*k,y[3]=b[3]*_+b[7]*w+b[11]*T+b[15]*k}else m[0]=m[1]=m[2]=0,m[3]=1;if(e[0]=E,e[1]=C,e[2]=L,function(t,e){t[0][0]=e[0],t[0][1]=e[1],t[0][2]=e[2],t[1][0]=e[4],t[1][1]=e[5],t[1][2]=e[6],t[2][0]=e[8],t[2][1]=e[9],t[2][2]=e[10]}(p,u),r[0]=c.length(p[0]),c.normalize(p[0],p[0]),i[0]=c.dot(p[0],p[1]),g(p[1],p[1],p[0],1,-i[0]),r[1]=c.length(p[1]),c.normalize(p[1],p[1]),i[0]/=r[1],i[1]=c.dot(p[0],p[2]),g(p[2],p[2],p[0],1,-i[1]),i[2]=c.dot(p[1],p[2]),g(p[2],p[2],p[1],1,-i[2]),r[2]=c.length(p[2]),c.normalize(p[2],p[2]),i[1]/=r[2],i[2]/=r[2],c.cross(d,p[1],p[2]),c.dot(p[0],d)<0)for(var P=0;P<3;P++)r[P]*=-1,p[P][0]*=-1,p[P][1]*=-1,p[P][2]*=-1;return v[0]=.5*Math.sqrt(Math.max(1+p[0][0]-p[1][1]-p[2][2],0)),v[1]=.5*Math.sqrt(Math.max(1-p[0][0]+p[1][1]-p[2][2],0)),v[2]=.5*Math.sqrt(Math.max(1-p[0][0]-p[1][1]+p[2][2],0)),v[3]=.5*Math.sqrt(Math.max(1+p[0][0]+p[1][1]+p[2][2],0)),p[2][1]>p[1][2]&&(v[0]=-v[0]),p[0][2]>p[2][0]&&(v[1]=-v[1]),p[1][0]>p[0][1]&&(v[2]=-v[2]),!0}},{\"./normalize\":476,\"gl-mat4/clone\":278,\"gl-mat4/create\":280,\"gl-mat4/determinant\":281,\"gl-mat4/invert\":293,\"gl-mat4/transpose\":306,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/length\":380,\"gl-vec3/normalize\":387}],476:[function(t,e,r){e.exports=function(t,e){var r=e[15];if(0===r)return!1;for(var n=1/r,i=0;i<16;i++)t[i]=e[i]*n;return!0}},{}],477:[function(t,e,r){var n=t(\"gl-vec3/lerp\"),i=t(\"mat4-recompose\"),a=t(\"mat4-decompose\"),o=t(\"gl-mat4/determinant\"),s=t(\"quat-slerp\"),l=f(),c=f(),u=f();function f(){return{translate:h(),scale:h(1),skew:h(),perspective:[0,0,0,1],quaternion:[0,0,0,1]}}function h(t){return[t||0,t||0,t||0]}e.exports=function(t,e,r,f){if(0===o(e)||0===o(r))return!1;var h=a(e,l.translate,l.scale,l.skew,l.perspective,l.quaternion),p=a(r,c.translate,c.scale,c.skew,c.perspective,c.quaternion);return!(!h||!p)&&(n(u.translate,l.translate,c.translate,f),n(u.skew,l.skew,c.skew,f),n(u.scale,l.scale,c.scale,f),n(u.perspective,l.perspective,c.perspective,f),s(u.quaternion,l.quaternion,c.quaternion,f),i(t,u.translate,u.scale,u.skew,u.perspective,u.quaternion),!0)}},{\"gl-mat4/determinant\":281,\"gl-vec3/lerp\":381,\"mat4-decompose\":475,\"mat4-recompose\":478,\"quat-slerp\":527}],478:[function(t,e,r){var n={identity:t(\"gl-mat4/identity\"),translate:t(\"gl-mat4/translate\"),multiply:t(\"gl-mat4/multiply\"),create:t(\"gl-mat4/create\"),scale:t(\"gl-mat4/scale\"),fromRotationTranslation:t(\"gl-mat4/fromRotationTranslation\")},i=(n.create(),n.create());e.exports=function(t,e,r,a,o,s){return n.identity(t),n.fromRotationTranslation(t,s,e),t[3]=o[0],t[7]=o[1],t[11]=o[2],t[15]=o[3],n.identity(i),0!==a[2]&&(i[9]=a[2],n.multiply(t,t,i)),0!==a[1]&&(i[9]=0,i[8]=a[1],n.multiply(t,t,i)),0!==a[0]&&(i[8]=0,i[4]=a[0],n.multiply(t,t,i)),n.scale(t,t,r),t}},{\"gl-mat4/create\":280,\"gl-mat4/fromRotationTranslation\":284,\"gl-mat4/identity\":291,\"gl-mat4/multiply\":295,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305}],479:[function(t,e,r){\"use strict\";e.exports=Math.log2||function(t){return Math.log(t)*Math.LOG2E}},{}],480:[function(t,e,r){\"use strict\";var n=t(\"binary-search-bounds\"),i=t(\"mat4-interpolate\"),a=t(\"gl-mat4/invert\"),o=t(\"gl-mat4/rotateX\"),s=t(\"gl-mat4/rotateY\"),l=t(\"gl-mat4/rotateZ\"),c=t(\"gl-mat4/lookAt\"),u=t(\"gl-mat4/translate\"),f=(t(\"gl-mat4/scale\"),t(\"gl-vec3/normalize\")),h=[0,0,0];function p(t){this._components=t.slice(),this._time=[0],this.prevMatrix=t.slice(),this.nextMatrix=t.slice(),this.computedMatrix=t.slice(),this.computedInverse=t.slice(),this.computedEye=[0,0,0],this.computedUp=[0,0,0],this.computedCenter=[0,0,0],this.computedRadius=[0],this._limits=[-1/0,1/0]}e.exports=function(t){return new p((t=t||{}).matrix||[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1])};var d=p.prototype;d.recalcMatrix=function(t){var e=this._time,r=n.le(e,t),o=this.computedMatrix;if(!(r<0)){var s=this._components;if(r===e.length-1)for(var l=16*r,c=0;c<16;++c)o[c]=s[l++];else{var u=e[r+1]-e[r],h=(l=16*r,this.prevMatrix),p=!0;for(c=0;c<16;++c)h[c]=s[l++];var d=this.nextMatrix;for(c=0;c<16;++c)d[c]=s[l++],p=p&&h[c]===d[c];if(u<1e-6||p)for(c=0;c<16;++c)o[c]=h[c];else i(o,h,d,(t-e[r])/u)}var g=this.computedUp;g[0]=o[1],g[1]=o[5],g[2]=o[9],f(g,g);var m=this.computedInverse;a(m,o);var v=this.computedEye,y=m[15];v[0]=m[12]/y,v[1]=m[13]/y,v[2]=m[14]/y;var x=this.computedCenter,b=Math.exp(this.computedRadius[0]);for(c=0;c<3;++c)x[c]=v[c]-o[2+4*c]*b}},d.idle=function(t){if(!(t<this.lastT())){for(var e=this._components,r=e.length-16,n=0;n<16;++n)e.push(e[r++]);this._time.push(t)}},d.flush=function(t){var e=n.gt(this._time,t)-2;e<0||(this._time.splice(0,e),this._components.splice(0,16*e))},d.lastT=function(){return this._time[this._time.length-1]},d.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||h,n=n||this.computedUp,this.setMatrix(t,c(this.computedMatrix,e,r,n));for(var i=0,a=0;a<3;++a)i+=Math.pow(r[a]-e[a],2);i=Math.log(Math.sqrt(i)),this.computedRadius[0]=i},d.rotate=function(t,e,r,n){this.recalcMatrix(t);var i=this.computedInverse;e&&s(i,i,e),r&&o(i,i,r),n&&l(i,i,n),this.setMatrix(t,a(this.computedMatrix,i))};var g=[0,0,0];d.pan=function(t,e,r,n){g[0]=-(e||0),g[1]=-(r||0),g[2]=-(n||0),this.recalcMatrix(t);var i=this.computedInverse;u(i,i,g),this.setMatrix(t,a(i,i))},d.translate=function(t,e,r,n){g[0]=e||0,g[1]=r||0,g[2]=n||0,this.recalcMatrix(t);var i=this.computedMatrix;u(i,i,g),this.setMatrix(t,i)},d.setMatrix=function(t,e){if(!(t<this.lastT())){this._time.push(t);for(var r=0;r<16;++r)this._components.push(e[r])}},d.setDistance=function(t,e){this.computedRadius[0]=e},d.setDistanceLimits=function(t,e){var r=this._limits;r[0]=t,r[1]=e},d.getDistanceLimits=function(t){var e=this._limits;return t?(t[0]=e[0],t[1]=e[1],t):e}},{\"binary-search-bounds\":481,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294,\"gl-mat4/rotateX\":300,\"gl-mat4/rotateY\":301,\"gl-mat4/rotateZ\":302,\"gl-mat4/scale\":303,\"gl-mat4/translate\":305,\"gl-vec3/normalize\":387,\"mat4-interpolate\":477}],481:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],482:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<3){for(var r=new Array(e),i=0;i<e;++i)r[i]=i;return 2===e&&t[0][0]===t[1][0]&&t[0][1]===t[1][1]?[0]:r}var a=new Array(e);for(i=0;i<e;++i)a[i]=i;a.sort((function(e,r){var n=t[e][0]-t[r][0];return n||t[e][1]-t[r][1]}));var o=[a[0],a[1]],s=[a[0],a[1]];for(i=2;i<e;++i){for(var l=a[i],c=t[l],u=o.length;u>1&&n(t[o[u-2]],t[o[u-1]],c)<=0;)u-=1,o.pop();for(o.push(l),u=s.length;u>1&&n(t[s[u-2]],t[s[u-1]],c)>=0;)u-=1,s.pop();s.push(l)}r=new Array(s.length+o.length-2);for(var f=0,h=(i=0,o.length);i<h;++i)r[f++]=o[i];for(var p=s.length-2;p>0;--p)r[f++]=s[p];return r};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],483:[function(t,e,r){\"use strict\";e.exports=function(t,e){e||(e=t,t=window);var r=0,i=0,a=0,o={shift:!1,alt:!1,control:!1,meta:!1},s=!1;function l(t){var e=!1;return\"altKey\"in t&&(e=e||t.altKey!==o.alt,o.alt=!!t.altKey),\"shiftKey\"in t&&(e=e||t.shiftKey!==o.shift,o.shift=!!t.shiftKey),\"ctrlKey\"in t&&(e=e||t.ctrlKey!==o.control,o.control=!!t.ctrlKey),\"metaKey\"in t&&(e=e||t.metaKey!==o.meta,o.meta=!!t.metaKey),e}function c(t,s){var c=n.x(s),u=n.y(s);\"buttons\"in s&&(t=0|s.buttons),(t!==r||c!==i||u!==a||l(s))&&(r=0|t,i=c||0,a=u||0,e&&e(r,i,a,o))}function u(t){c(0,t)}function f(){(r||i||a||o.shift||o.alt||o.meta||o.control)&&(i=a=0,r=0,o.shift=o.alt=o.control=o.meta=!1,e&&e(0,0,0,o))}function h(t){l(t)&&e&&e(r,i,a,o)}function p(t){0===n.buttons(t)?c(0,t):c(r,t)}function d(t){c(r|n.buttons(t),t)}function g(t){c(r&~n.buttons(t),t)}function m(){s||(s=!0,t.addEventListener(\"mousemove\",p),t.addEventListener(\"mousedown\",d),t.addEventListener(\"mouseup\",g),t.addEventListener(\"mouseleave\",u),t.addEventListener(\"mouseenter\",u),t.addEventListener(\"mouseout\",u),t.addEventListener(\"mouseover\",u),t.addEventListener(\"blur\",f),t.addEventListener(\"keyup\",h),t.addEventListener(\"keydown\",h),t.addEventListener(\"keypress\",h),t!==window&&(window.addEventListener(\"blur\",f),window.addEventListener(\"keyup\",h),window.addEventListener(\"keydown\",h),window.addEventListener(\"keypress\",h)))}m();var v={element:t};return Object.defineProperties(v,{enabled:{get:function(){return s},set:function(e){e?m():function(){if(!s)return;s=!1,t.removeEventListener(\"mousemove\",p),t.removeEventListener(\"mousedown\",d),t.removeEventListener(\"mouseup\",g),t.removeEventListener(\"mouseleave\",u),t.removeEventListener(\"mouseenter\",u),t.removeEventListener(\"mouseout\",u),t.removeEventListener(\"mouseover\",u),t.removeEventListener(\"blur\",f),t.removeEventListener(\"keyup\",h),t.removeEventListener(\"keydown\",h),t.removeEventListener(\"keypress\",h),t!==window&&(window.removeEventListener(\"blur\",f),window.removeEventListener(\"keyup\",h),window.removeEventListener(\"keydown\",h),window.removeEventListener(\"keypress\",h))}()},enumerable:!0},buttons:{get:function(){return r},enumerable:!0},x:{get:function(){return i},enumerable:!0},y:{get:function(){return a},enumerable:!0},mods:{get:function(){return o},enumerable:!0}}),v};var n=t(\"mouse-event\")},{\"mouse-event\":485}],484:[function(t,e,r){var n={left:0,top:0};e.exports=function(t,e,r){e=e||t.currentTarget||t.srcElement,Array.isArray(r)||(r=[0,0]);var i=t.clientX||0,a=t.clientY||0,o=(s=e,s===window||s===document||s===document.body?n:s.getBoundingClientRect());var s;return r[0]=i-o.left,r[1]=a-o.top,r}},{}],485:[function(t,e,r){\"use strict\";function n(t){return t.target||t.srcElement||window}r.buttons=function(t){if(\"object\"==typeof t){if(\"buttons\"in t)return t.buttons;if(\"which\"in t){if(2===(e=t.which))return 4;if(3===e)return 2;if(e>0)return 1<<e-1}else if(\"button\"in t){var e;if(1===(e=t.button))return 4;if(2===e)return 2;if(e>=0)return 1<<e}}return 0},r.element=n,r.x=function(t){if(\"object\"==typeof t){if(\"offsetX\"in t)return t.offsetX;var e=n(t).getBoundingClientRect();return t.clientX-e.left}return 0},r.y=function(t){if(\"object\"==typeof t){if(\"offsetY\"in t)return t.offsetY;var e=n(t).getBoundingClientRect();return t.clientY-e.top}return 0}},{}],486:[function(t,e,r){\"use strict\";var n=t(\"to-px\");e.exports=function(t,e,r){\"function\"==typeof t&&(r=!!e,e=t,t=window);var i=n(\"ex\",t),a=function(t){r&&t.preventDefault();var n=t.deltaX||0,a=t.deltaY||0,o=t.deltaZ||0,s=1;switch(t.deltaMode){case 1:s=i;break;case 2:s=window.innerHeight}if(a*=s,o*=s,(n*=s)||a||o)return e(n,a,o,t)};return t.addEventListener(\"wheel\",a),a}},{\"to-px\":578}],487:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\");function i(t){return\"a\"+t}function a(t){return\"d\"+t}function o(t,e){return\"c\"+t+\"_\"+e}function s(t){return\"s\"+t}function l(t,e){return\"t\"+t+\"_\"+e}function c(t){return\"o\"+t}function u(t){return\"x\"+t}function f(t){return\"p\"+t}function h(t,e){return\"d\"+t+\"_\"+e}function p(t){return\"i\"+t}function d(t,e){return\"u\"+t+\"_\"+e}function g(t){return\"b\"+t}function m(t){return\"y\"+t}function v(t){return\"e\"+t}function y(t){return\"v\"+t}e.exports=function(t){function e(t){throw new Error(\"ndarray-extract-contour: \"+t)}\"object\"!=typeof t&&e(\"Must specify arguments\");var r=t.order;Array.isArray(r)||e(\"Must specify order\");var b=t.arrayArguments||1;b<1&&e(\"Must have at least one array argument\");var _=t.scalarArguments||0;_<0&&e(\"Scalar arg count must be > 0\");\"function\"!=typeof t.vertex&&e(\"Must specify vertex creation function\");\"function\"!=typeof t.cell&&e(\"Must specify cell creation function\");\"function\"!=typeof t.phase&&e(\"Must specify phase function\");for(var w=t.getters||[],T=new Array(b),k=0;k<b;++k)w.indexOf(k)>=0?T[k]=!0:T[k]=!1;return function(t,e,r,b,_,w){var T=w.length,k=_.length;if(k<2)throw new Error(\"ndarray-extract-contour: Dimension must be at least 2\");for(var M=\"extractContour\"+_.join(\"_\"),A=[],S=[],E=[],C=0;C<T;++C)E.push(i(C));for(C=0;C<b;++C)E.push(u(C));for(C=0;C<k;++C)S.push(s(C)+\"=\"+i(0)+\".shape[\"+C+\"]|0\");for(C=0;C<T;++C){S.push(a(C)+\"=\"+i(C)+\".data\",c(C)+\"=\"+i(C)+\".offset|0\");for(var L=0;L<k;++L)S.push(l(C,L)+\"=\"+i(C)+\".stride[\"+L+\"]|0\")}for(C=0;C<T;++C){S.push(f(C)+\"=\"+c(C)),S.push(o(C,0));for(L=1;L<1<<k;++L){for(var I=[],P=0;P<k;++P)L&1<<P&&I.push(\"-\"+l(C,P));S.push(h(C,L)+\"=(\"+I.join(\"\")+\")|0\"),S.push(o(C,L)+\"=0\")}}for(C=0;C<T;++C)for(L=0;L<k;++L){var z=[l(C,_[L])];L>0&&z.push(l(C,_[L-1])+\"*\"+s(_[L-1])),S.push(d(C,_[L])+\"=(\"+z.join(\"-\")+\")|0\")}for(C=0;C<k;++C)S.push(p(C)+\"=0\");S.push(\"N=0\");var O=[\"2\"];for(C=k-2;C>=0;--C)O.push(s(_[C]));S.push(\"Q=(\"+O.join(\"*\")+\")|0\",\"P=mallocUint32(Q)\",\"V=mallocUint32(Q)\",\"X=0\"),S.push(g(0)+\"=0\");for(L=1;L<1<<k;++L){var D=[],R=[];for(P=0;P<k;++P)L&1<<P&&(0===R.length?D.push(\"1\"):D.unshift(R.join(\"*\"))),R.push(s(_[P]));var F=\"\";D[0].indexOf(s(_[k-2]))<0&&(F=\"-\");var B=x(k,L,_);S.push(v(B)+\"=(-\"+D.join(\"-\")+\")|0\",m(B)+\"=(\"+F+D.join(\"-\")+\")|0\",g(B)+\"=0\")}function N(t,e){A.push(\"for(\",p(_[t]),\"=\",e,\";\",p(_[t]),\"<\",s(_[t]),\";\",\"++\",p(_[t]),\"){\")}function j(t){for(var e=0;e<T;++e)A.push(f(e),\"+=\",d(e,_[t]),\";\");A.push(\"}\")}function U(){for(var t=1;t<1<<k;++t)A.push(\"T\",\"=\",v(t),\";\",v(t),\"=\",m(t),\";\",m(t),\"=\",\"T\",\";\")}S.push(y(0)+\"=0\",\"T=0\"),function t(e,r){if(e<0)!function(t){for(var e=0;e<T;++e)w[e]?A.push(o(e,0),\"=\",a(e),\".get(\",f(e),\");\"):A.push(o(e,0),\"=\",a(e),\"[\",f(e),\"];\");var r=[];for(e=0;e<T;++e)r.push(o(e,0));for(e=0;e<b;++e)r.push(u(e));A.push(g(0),\"=\",\"P\",\"[\",\"X\",\"]=phase(\",r.join(),\");\");for(var n=1;n<1<<k;++n)A.push(g(n),\"=\",\"P\",\"[\",\"X\",\"+\",v(n),\"];\");var i=[];for(n=1;n<1<<k;++n)i.push(\"(\"+g(0)+\"!==\"+g(n)+\")\");A.push(\"if(\",i.join(\"||\"),\"){\");var s=[];for(e=0;e<k;++e)s.push(p(e));for(e=0;e<T;++e){s.push(o(e,0));for(n=1;n<1<<k;++n)w[e]?A.push(o(e,n),\"=\",a(e),\".get(\",f(e),\"+\",h(e,n),\");\"):A.push(o(e,n),\"=\",a(e),\"[\",f(e),\"+\",h(e,n),\"];\"),s.push(o(e,n))}for(e=0;e<1<<k;++e)s.push(g(e));for(e=0;e<b;++e)s.push(u(e));A.push(\"vertex(\",s.join(),\");\",y(0),\"=\",\"V\",\"[\",\"X\",\"]=\",\"N\",\"++;\");var l=(1<<k)-1,c=g(l);for(n=0;n<k;++n)if(0==(t&~(1<<n))){for(var d=l^1<<n,m=g(d),x=[],_=d;_>0;_=_-1&d)x.push(\"V[X+\"+v(_)+\"]\");x.push(y(0));for(_=0;_<T;++_)1&n?x.push(o(_,l),o(_,d)):x.push(o(_,d),o(_,l));1&n?x.push(c,m):x.push(m,c);for(_=0;_<b;++_)x.push(u(_));A.push(\"if(\",c,\"!==\",m,\"){\",\"face(\",x.join(),\")}\")}A.push(\"}\",\"X\",\"+=1;\")}(r);else{!function(t){for(var e=t-1;e>=0;--e)N(e,0);var r=[];for(e=0;e<T;++e)w[e]?r.push(a(e)+\".get(\"+f(e)+\")\"):r.push(a(e)+\"[\"+f(e)+\"]\");for(e=0;e<b;++e)r.push(u(e));for(A.push(\"P\",\"[\",\"X\",\"++]=phase(\",r.join(),\");\"),e=0;e<t;++e)j(e);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[t]),\";\")}(e),A.push(\"if(\",s(_[e]),\">0){\",p(_[e]),\"=1;\"),t(e-1,r|1<<_[e]);for(var n=0;n<T;++n)A.push(f(n),\"+=\",d(n,_[e]),\";\");e===k-1&&(A.push(\"X\",\"=0;\"),U()),N(e,2),t(e-1,r),e===k-1&&(A.push(\"if(\",p(_[k-1]),\"&1){\",\"X\",\"=0;}\"),U()),j(e),A.push(\"}\")}}(k-1,0),A.push(\"freeUint32(\",\"V\",\");freeUint32(\",\"P\",\");\");var V=[\"'use strict';\",\"function \",M,\"(\",E.join(),\"){\",\"var \",S.join(),\";\",A.join(\"\"),\"}\",\"return \",M].join(\"\");return new Function(\"vertex\",\"face\",\"phase\",\"mallocUint32\",\"freeUint32\",V)(t,e,r,n.mallocUint32,n.freeUint32)}(t.vertex,t.cell,t.phase,_,r,T)};function x(t,e,r){for(var n=0,i=0;i<t;++i)e&1<<i&&(n|=1<<r[i]);return n}},{\"typedarray-pool\":595}],488:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(Array.isArray(r)){if(r.length!==e.dimension)throw new Error(\"ndarray-gradient: invalid boundary conditions\")}else r=n(e.dimension,\"string\"==typeof r?r:\"clamp\");if(t.dimension!==e.dimension+1)throw new Error(\"ndarray-gradient: output dimension must be +1 input dimension\");if(t.shape[e.dimension]!==e.dimension)throw new Error(\"ndarray-gradient: output shape must match input shape\");for(var i=0;i<e.dimension;++i)if(t.shape[i]!==e.shape[i])throw new Error(\"ndarray-gradient: shape mismatch\");if(0===e.size)return t;if(e.dimension<=0)return t.set(0),t;return function(t){var e=t.join();if(v=o[e])return v;var r=t.length,n=[\"function gradient(dst,src){var s=src.shape.slice();\"];function i(e){for(var i=r-e.length,a=[],o=[],s=[],l=0;l<r;++l)e.indexOf(l+1)>=0?s.push(\"0\"):e.indexOf(-(l+1))>=0?s.push(\"s[\"+l+\"]-1\"):(s.push(\"-1\"),a.push(\"1\"),o.push(\"s[\"+l+\"]-2\"));var c=\".lo(\"+a.join()+\").hi(\"+o.join()+\")\";if(0===a.length&&(c=\"\"),i>0){n.push(\"if(1\");for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\"&&s[\",l,\"]>2\");n.push(\"){grad\",i,\"(src.pick(\",s.join(),\")\",c);for(l=0;l<r;++l)e.indexOf(l+1)>=0||e.indexOf(-(l+1))>=0||n.push(\",dst.pick(\",s.join(),\",\",l,\")\",c);n.push(\");\")}for(l=0;l<e.length;++l){var u=Math.abs(e[l])-1,f=\"dst.pick(\"+s.join()+\",\"+u+\")\"+c;switch(t[u]){case\"clamp\":var h=s.slice(),p=s.slice();e[l]<0?h[u]=\"s[\"+u+\"]-2\":p[u]=\"1\",0===i?n.push(\"if(s[\",u,\"]>1){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",h.join(),\")-src.get(\",p.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>1){diff(\",f,\",src.pick(\",h.join(),\")\",c,\",src.pick(\",p.join(),\")\",c,\");}else{zero(\",f,\");};\");break;case\"mirror\":0===i?n.push(\"dst.set(\",s.join(),\",\",u,\",0);\"):n.push(\"zero(\",f,\");\");break;case\"wrap\":var d=s.slice(),g=s.slice();e[l]<0?(d[u]=\"s[\"+u+\"]-2\",g[u]=\"0\"):(d[u]=\"s[\"+u+\"]-1\",g[u]=\"1\"),0===i?n.push(\"if(s[\",u,\"]>2){dst.set(\",s.join(),\",\",u,\",0.5*(src.get(\",d.join(),\")-src.get(\",g.join(),\")))}else{dst.set(\",s.join(),\",\",u,\",0)};\"):n.push(\"if(s[\",u,\"]>2){diff(\",f,\",src.pick(\",d.join(),\")\",c,\",src.pick(\",g.join(),\")\",c,\");}else{zero(\",f,\");};\");break;default:throw new Error(\"ndarray-gradient: Invalid boundary condition\")}}i>0&&n.push(\"};\")}for(var s=0;s<1<<r;++s){for(var f=[],h=0;h<r;++h)s&1<<h&&f.push(h+1);for(var p=0;p<1<<f.length;++p){var d=f.slice();for(h=0;h<f.length;++h)p&1<<h&&(d[h]=-d[h]);i(d)}}n.push(\"return dst;};return gradient\");var g=[\"diff\",\"zero\"],m=[l,c];for(s=1;s<=r;++s)g.push(\"grad\"+s),m.push(u(s));g.push(n.join(\"\"));var v=Function.apply(void 0,g).apply(void 0,m);return a[e]=v,v}(r)(t,e)};var n=t(\"dup\"),i=t(\"cwise-compiler\"),a={},o={},s={body:\"\",args:[],thisVars:[],localVars:[]},l=i({args:[\"array\",\"array\",\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1},{name:\"left\",lvalue:!1,rvalue:!0,count:1},{name:\"right\",lvalue:!1,rvalue:!0,count:1}],body:\"out=0.5*(left-right)\",thisVars:[],localVars:[]},funcName:\"cdiff\"}),c=i({args:[\"array\"],pre:s,post:s,body:{args:[{name:\"out\",lvalue:!0,rvalue:!1,count:1}],body:\"out=0\",thisVars:[],localVars:[]},funcName:\"zero\"});function u(t){if(t in a)return a[t];for(var e=[],r=0;r<t;++r)e.push(\"out\",r,\"s=0.5*(inp\",r,\"l-inp\",r,\"r);\");var o=[\"array\"],l=[\"junk\"];for(r=0;r<t;++r){o.push(\"array\"),l.push(\"out\"+r+\"s\");var c=n(t);c[r]=-1,o.push({array:0,offset:c.slice()}),c[r]=1,o.push({array:0,offset:c.slice()}),l.push(\"inp\"+r+\"l\",\"inp\"+r+\"r\")}return a[t]=i({args:o,pre:s,post:s,body:{body:e.join(\"\"),args:l.map((function(t){return{name:t,lvalue:0===t.indexOf(\"out\"),rvalue:0===t.indexOf(\"inp\"),count:\"junk\"!==t|0}})),thisVars:[],localVars:[]},funcName:\"fdTemplate\"+t})}},{\"cwise-compiler\":151,dup:176}],489:[function(t,e,r){\"use strict\";function n(t,e){var r=Math.floor(e),n=e-r,i=0<=r&&r<t.shape[0],a=0<=r+1&&r+1<t.shape[0];return(1-n)*(i?+t.get(r):0)+n*(a?+t.get(r+1):0)}function i(t,e,r){var n=Math.floor(e),i=e-n,a=0<=n&&n<t.shape[0],o=0<=n+1&&n+1<t.shape[0],s=Math.floor(r),l=r-s,c=0<=s&&s<t.shape[1],u=0<=s+1&&s+1<t.shape[1],f=a&&c?t.get(n,s):0,h=a&&u?t.get(n,s+1):0;return(1-l)*((1-i)*f+i*(o&&c?t.get(n+1,s):0))+l*((1-i)*h+i*(o&&u?t.get(n+1,s+1):0))}function a(t,e,r,n){var i=Math.floor(e),a=e-i,o=0<=i&&i<t.shape[0],s=0<=i+1&&i+1<t.shape[0],l=Math.floor(r),c=r-l,u=0<=l&&l<t.shape[1],f=0<=l+1&&l+1<t.shape[1],h=Math.floor(n),p=n-h,d=0<=h&&h<t.shape[2],g=0<=h+1&&h+1<t.shape[2],m=o&&u&&d?t.get(i,l,h):0,v=o&&f&&d?t.get(i,l+1,h):0,y=s&&u&&d?t.get(i+1,l,h):0,x=s&&f&&d?t.get(i+1,l+1,h):0,b=o&&u&&g?t.get(i,l,h+1):0,_=o&&f&&g?t.get(i,l+1,h+1):0;return(1-p)*((1-c)*((1-a)*m+a*y)+c*((1-a)*v+a*x))+p*((1-c)*((1-a)*b+a*(s&&u&&g?t.get(i+1,l,h+1):0))+c*((1-a)*_+a*(s&&f&&g?t.get(i+1,l+1,h+1):0)))}function o(t){var e,r,n=0|t.shape.length,i=new Array(n),a=new Array(n),o=new Array(n),s=new Array(n);for(e=0;e<n;++e)r=+arguments[e+1],i[e]=Math.floor(r),a[e]=r-i[e],o[e]=0<=i[e]&&i[e]<t.shape[e],s[e]=0<=i[e]+1&&i[e]+1<t.shape[e];var l,c,u,f=0;t:for(e=0;e<1<<n;++e){for(c=1,u=t.offset,l=0;l<n;++l)if(e&1<<l){if(!s[l])continue t;c*=a[l],u+=t.stride[l]*(i[l]+1)}else{if(!o[l])continue t;c*=1-a[l],u+=t.stride[l]*i[l]}f+=c*t.data[u]}return f}e.exports=function(t,e,r,s){switch(t.shape.length){case 0:return 0;case 1:return n(t,e);case 2:return i(t,e,r);case 3:return a(t,e,r,s);default:return o.apply(void 0,arguments)}},e.exports.d1=n,e.exports.d2=i,e.exports.d3=a},{}],490:[function(t,e,r){\"use strict\";var n=t(\"cwise-compiler\"),i={body:\"\",args:[],thisVars:[],localVars:[]};function a(t){if(!t)return i;for(var e=0;e<t.args.length;++e){var r=t.args[e];t.args[e]=0===e?{name:r,lvalue:!0,rvalue:!!t.rvalue,count:t.count||1}:{name:r,lvalue:!1,rvalue:!0,count:1}}return t.thisVars||(t.thisVars=[]),t.localVars||(t.localVars=[]),t}function o(t){for(var e=[],r=0;r<t.args.length;++r)e.push(\"a\"+r);return new Function(\"P\",[\"return function \",t.funcName,\"_ndarrayops(\",e.join(\",\"),\") {P(\",e.join(\",\"),\");return a0}\"].join(\"\"))(function(t){return n({args:t.args,pre:a(t.pre),body:a(t.body),post:a(t.proc),funcName:t.funcName})}(t))}var s={add:\"+\",sub:\"-\",mul:\"*\",div:\"/\",mod:\"%\",band:\"&\",bor:\"|\",bxor:\"^\",lshift:\"<<\",rshift:\">>\",rrshift:\">>>\"};!function(){for(var t in s){var e=s[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a\"+e+\"=b\"},rvalue:!0,funcName:t+\"eq\"}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a\"+e+\"=s\"},rvalue:!0,funcName:t+\"seq\"})}}();var l={not:\"!\",bnot:\"~\",neg:\"-\",recip:\"1.0/\"};!function(){for(var t in l){var e=l[t];r[t]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=\"+e+\"b\"},funcName:t}),r[t+\"eq\"]=o({args:[\"array\"],body:{args:[\"a\"],body:\"a=\"+e+\"a\"},rvalue:!0,count:2,funcName:t+\"eq\"})}}();var c={and:\"&&\",or:\"||\",eq:\"===\",neq:\"!==\",lt:\"<\",gt:\">\",leq:\"<=\",geq:\">=\"};!function(){for(var t in c){var e=c[t];r[t]=o({args:[\"array\",\"array\",\"array\"],body:{args:[\"a\",\"b\",\"c\"],body:\"a=b\"+e+\"c\"},funcName:t}),r[t+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],body:{args:[\"a\",\"b\",\"s\"],body:\"a=b\"+e+\"s\"},funcName:t+\"s\"}),r[t+\"eq\"]=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=a\"+e+\"b\"},rvalue:!0,count:2,funcName:t+\"eq\"}),r[t+\"seq\"]=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"s\"],body:\"a=a\"+e+\"s\"},rvalue:!0,count:2,funcName:t+\"seq\"})}}();var u=[\"abs\",\"acos\",\"asin\",\"atan\",\"ceil\",\"cos\",\"exp\",\"floor\",\"log\",\"round\",\"sin\",\"sqrt\",\"tan\"];!function(){for(var t=0;t<u.length;++t){var e=u[t];r[e]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"eq\"]=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f(a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"})}}();var f=[\"max\",\"min\",\"atan2\",\"pow\"];!function(){for(var t=0;t<f.length;++t){var e=f[t];r[e]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e}),r[e+\"s\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(b,c)\",thisVars:[\"this_f\"]},funcName:e+\"s\"}),r[e+\"eq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"eq\"}),r[e+\"seq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(a,b)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"seq\"})}}();var h=[\"atan2\",\"pow\"];!function(){for(var t=0;t<h.length;++t){var e=h[t];r[e+\"op\"]=o({args:[\"array\",\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"op\"}),r[e+\"ops\"]=o({args:[\"array\",\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\",\"c\"],body:\"a=this_f(c,b)\",thisVars:[\"this_f\"]},funcName:e+\"ops\"}),r[e+\"opeq\"]=o({args:[\"array\",\"array\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opeq\"}),r[e+\"opseq\"]=o({args:[\"array\",\"scalar\"],pre:{args:[],body:\"this_f=Math.\"+e,thisVars:[\"this_f\"]},body:{args:[\"a\",\"b\"],body:\"a=this_f(b,a)\",thisVars:[\"this_f\"]},rvalue:!0,count:2,funcName:e+\"opseq\"})}}(),r.any=n({args:[\"array\"],pre:i,body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"if(a){return true}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return false\"},funcName:\"any\"}),r.all=n({args:[\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1}],body:\"if(!x){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"all\"}),r.sum=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s+=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"sum\"}),r.prod=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=1\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:1}],body:\"this_s*=a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"prod\"}),r.norm2squared=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm2squared\"}),r.norm2=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:2}],body:\"this_s+=a*a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return Math.sqrt(this_s)\"},funcName:\"norm2\"}),r.norminf=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:4}],body:\"if(-a>this_s){this_s=-a}else if(a>this_s){this_s=a}\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norminf\"}),r.norm1=n({args:[\"array\"],pre:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"this_s=0\"},body:{args:[{name:\"a\",lvalue:!1,rvalue:!0,count:3}],body:\"this_s+=a<0?-a:a\",localVars:[],thisVars:[\"this_s\"]},post:{args:[],localVars:[],thisVars:[\"this_s\"],body:\"return this_s\"},funcName:\"norm1\"}),r.sup=n({args:[\"array\"],pre:{body:\"this_h=-Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_>this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.inf=n({args:[\"array\"],pre:{body:\"this_h=Infinity\",args:[],thisVars:[\"this_h\"],localVars:[]},body:{body:\"if(_inline_1_arg0_<this_h)this_h=_inline_1_arg0_\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_h\"],localVars:[]},post:{body:\"return this_h\",args:[],thisVars:[\"this_h\"],localVars:[]}}),r.argmin=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_<this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.argmax=n({args:[\"index\",\"array\",\"shape\"],pre:{body:\"{this_v=-Infinity;this_i=_inline_0_arg2_.slice(0)}\",args:[{name:\"_inline_0_arg0_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg1_\",lvalue:!1,rvalue:!1,count:0},{name:\"_inline_0_arg2_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[\"this_i\",\"this_v\"],localVars:[]},body:{body:\"{if(_inline_1_arg1_>this_v){this_v=_inline_1_arg1_;for(var _inline_1_k=0;_inline_1_k<_inline_1_arg0_.length;++_inline_1_k){this_i[_inline_1_k]=_inline_1_arg0_[_inline_1_k]}}}\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:2}],thisVars:[\"this_i\",\"this_v\"],localVars:[\"_inline_1_k\"]},post:{body:\"{return this_i}\",args:[],thisVars:[\"this_i\"],localVars:[]}}),r.random=o({args:[\"array\"],pre:{args:[],body:\"this_f=Math.random\",thisVars:[\"this_f\"]},body:{args:[\"a\"],body:\"a=this_f()\",thisVars:[\"this_f\"]},funcName:\"random\"}),r.assign=o({args:[\"array\",\"array\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assign\"}),r.assigns=o({args:[\"array\",\"scalar\"],body:{args:[\"a\",\"b\"],body:\"a=b\"},funcName:\"assigns\"}),r.equals=n({args:[\"array\",\"array\"],pre:i,body:{args:[{name:\"x\",lvalue:!1,rvalue:!0,count:1},{name:\"y\",lvalue:!1,rvalue:!0,count:1}],body:\"if(x!==y){return false}\",localVars:[],thisVars:[]},post:{args:[],localVars:[],thisVars:[],body:\"return true\"},funcName:\"equals\"})},{\"cwise-compiler\":151}],491:[function(t,e,r){\"use strict\";var n=t(\"ndarray\"),i=t(\"./doConvert.js\");e.exports=function(t,e){for(var r=[],a=t,o=1;Array.isArray(a);)r.push(a.length),o*=a.length,a=a[0];return 0===r.length?n():(e||(e=n(new Float64Array(o),r)),i(e,t),e)}},{\"./doConvert.js\":492,ndarray:495}],492:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\nvar _inline_1_v=_inline_1_arg1_,_inline_1_i\\nfor(_inline_1_i=0;_inline_1_i<_inline_1_arg2_.length-1;++_inline_1_i) {\\n_inline_1_v=_inline_1_v[_inline_1_arg2_[_inline_1_i]]\\n}\\n_inline_1_arg0_=_inline_1_v[_inline_1_arg2_[_inline_1_arg2_.length-1]]\\n}\",args:[{name:\"_inline_1_arg0_\",lvalue:!0,rvalue:!1,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:4}],thisVars:[],localVars:[\"_inline_1_i\",\"_inline_1_v\"]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},funcName:\"convert\",blockSize:64})},{\"cwise-compiler\":151}],493:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=32;function a(t){switch(t){case\"uint8\":return[n.mallocUint8,n.freeUint8];case\"uint16\":return[n.mallocUint16,n.freeUint16];case\"uint32\":return[n.mallocUint32,n.freeUint32];case\"int8\":return[n.mallocInt8,n.freeInt8];case\"int16\":return[n.mallocInt16,n.freeInt16];case\"int32\":return[n.mallocInt32,n.freeInt32];case\"float32\":return[n.mallocFloat,n.freeFloat];case\"float64\":return[n.mallocDouble,n.freeDouble];default:return null}}function o(t){for(var e=[],r=0;r<t;++r)e.push(\"s\"+r);for(r=0;r<t;++r)e.push(\"n\"+r);for(r=1;r<t;++r)e.push(\"d\"+r);for(r=1;r<t;++r)e.push(\"e\"+r);for(r=1;r<t;++r)e.push(\"f\"+r);return e}e.exports=function(t,e){var r=[\"'use strict'\"],n=[\"ndarraySortWrapper\",t.join(\"d\"),e].join(\"\");r.push([\"function \",n,\"(\",[\"array\"].join(\",\"),\"){\"].join(\"\"));for(var s=[\"data=array.data,offset=array.offset|0,shape=array.shape,stride=array.stride\"],l=0;l<t.length;++l)s.push([\"s\",l,\"=stride[\",l,\"]|0,n\",l,\"=shape[\",l,\"]|0\"].join(\"\"));var c=new Array(t.length),u=[];for(l=0;l<t.length;++l){0!==(p=t[l])&&(0===u.length?c[p]=\"1\":c[p]=u.join(\"*\"),u.push(\"n\"+p))}var f=-1,h=-1;for(l=0;l<t.length;++l){var p,d=t[l];0!==d&&(f>0?s.push([\"d\",d,\"=s\",d,\"-d\",f,\"*n\",f].join(\"\")):s.push([\"d\",d,\"=s\",d].join(\"\")),f=d),0!==(p=t.length-1-l)&&(h>0?s.push([\"e\",p,\"=s\",p,\"-e\",h,\"*n\",h,\",f\",p,\"=\",c[p],\"-f\",h,\"*n\",h].join(\"\")):s.push([\"e\",p,\"=s\",p,\",f\",p,\"=\",c[p]].join(\"\")),h=p)}r.push(\"var \"+s.join(\",\"));var g=[\"0\",\"n0-1\",\"data\",\"offset\"].concat(o(t.length));r.push([\"if(n0<=\",i,\"){\",\"insertionSort(\",g.join(\",\"),\")}else{\",\"quickSort(\",g.join(\",\"),\")}\"].join(\"\")),r.push(\"}return \"+n);var m=new Function(\"insertionSort\",\"quickSort\",r.join(\"\\n\")),v=function(t,e){var r=[\"'use strict'\"],n=[\"ndarrayInsertionSort\",t.join(\"d\"),e].join(\"\"),i=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),s=a(e),l=[\"i,j,cptr,ptr=left*s0+offset\"];if(t.length>1){for(var c=[],u=1;u<t.length;++u)l.push(\"i\"+u),c.push(\"n\"+u);s?l.push(\"scratch=malloc(\"+c.join(\"*\")+\")\"):l.push(\"scratch=new Array(\"+c.join(\"*\")+\")\"),l.push(\"dptr\",\"sptr\",\"a\",\"b\")}else l.push(\"scratch\");function f(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function h(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}if(r.push([\"function \",n,\"(\",i.join(\",\"),\"){var \",l.join(\",\")].join(\"\"),\"for(i=left+1;i<=right;++i){\",\"j=i;ptr+=s0\",\"cptr=ptr\"),t.length>1){r.push(\"dptr=0;sptr=ptr\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(\"scratch[dptr++]=\",f(\"sptr\"));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push(\"sptr+=d\"+p,\"}\")}r.push(\"__g:while(j--\\x3eleft){\",\"dptr=0\",\"sptr=cptr-s0\");for(u=1;u<t.length;++u)1===u&&r.push(\"__l:\"),r.push([\"for(i\",u,\"=0;i\",u,\"<n\",u,\";++i\",u,\"){\"].join(\"\"));r.push([\"a=\",f(\"sptr\"),\"\\nb=scratch[dptr]\\nif(a<b){break __g}\\nif(a>b){break __l}\"].join(\"\"));for(u=t.length-1;u>=1;--u)r.push(\"sptr+=e\"+u,\"dptr+=f\"+u,\"}\");r.push(\"dptr=cptr;sptr=cptr-s0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",f(\"sptr\")));for(u=0;u<t.length;++u){0!==(p=t[u])&&r.push([\"dptr+=d\",p,\";sptr+=d\",p].join(\"\"),\"}\")}r.push(\"cptr-=s0\\n}\"),r.push(\"dptr=cptr;sptr=0\");for(u=t.length-1;u>=0;--u){0!==(p=t[u])&&r.push([\"for(i\",p,\"=0;i\",p,\"<n\",p,\";++i\",p,\"){\"].join(\"\"))}r.push(h(\"dptr\",\"scratch[sptr++]\"));for(u=0;u<t.length;++u){var p;0!==(p=t[u])&&r.push(\"dptr+=d\"+p,\"}\")}}else r.push(\"scratch=\"+f(\"ptr\"),\"while((j--\\x3eleft)&&(\"+f(\"cptr-s0\")+\">scratch)){\",h(\"cptr\",f(\"cptr-s0\")),\"cptr-=s0\",\"}\",h(\"cptr\",\"scratch\"));return r.push(\"}\"),t.length>1&&s&&r.push(\"free(scratch)\"),r.push(\"} return \"+n),s?new Function(\"malloc\",\"free\",r.join(\"\\n\"))(s[0],s[1]):new Function(r.join(\"\\n\"))()}(t,e),y=function(t,e,r){var n=[\"'use strict'\"],s=[\"ndarrayQuickSort\",t.join(\"d\"),e].join(\"\"),l=[\"left\",\"right\",\"data\",\"offset\"].concat(o(t.length)),c=a(e),u=0;n.push([\"function \",s,\"(\",l.join(\",\"),\"){\"].join(\"\"));var f=[\"sixth=((right-left+1)/6)|0\",\"index1=left+sixth\",\"index5=right-sixth\",\"index3=(left+right)>>1\",\"index2=index3-sixth\",\"index4=index3+sixth\",\"el1=index1\",\"el2=index2\",\"el3=index3\",\"el4=index4\",\"el5=index5\",\"less=left+1\",\"great=right-1\",\"pivots_are_equal=true\",\"tmp\",\"tmp0\",\"x\",\"y\",\"z\",\"k\",\"ptr0\",\"ptr1\",\"ptr2\",\"comp_pivot1=0\",\"comp_pivot2=0\",\"comp=0\"];if(t.length>1){for(var h=[],p=1;p<t.length;++p)h.push(\"n\"+p),f.push(\"i\"+p);for(p=0;p<8;++p)f.push(\"b_ptr\"+p);f.push(\"ptr3\",\"ptr4\",\"ptr5\",\"ptr6\",\"ptr7\",\"pivot_ptr\",\"ptr_shift\",\"elementSize=\"+h.join(\"*\")),c?f.push(\"pivot1=malloc(elementSize)\",\"pivot2=malloc(elementSize)\"):f.push(\"pivot1=new Array(elementSize),pivot2=new Array(elementSize)\")}else f.push(\"pivot1\",\"pivot2\");function d(t){return[\"(offset+\",t,\"*s0)\"].join(\"\")}function g(t){return\"generic\"===e?[\"data.get(\",t,\")\"].join(\"\"):[\"data[\",t,\"]\"].join(\"\")}function m(t,r){return\"generic\"===e?[\"data.set(\",t,\",\",r,\")\"].join(\"\"):[\"data[\",t,\"]=\",r].join(\"\")}function v(e,r,i){if(1===e.length)n.push(\"ptr0=\"+d(e[0]));else for(var a=0;a<e.length;++a)n.push([\"b_ptr\",a,\"=s0*\",e[a]].join(\"\"));r&&n.push(\"pivot_ptr=0\"),n.push(\"ptr_shift=offset\");for(a=t.length-1;a>=0;--a){0!==(o=t[a])&&n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"))}if(e.length>1)for(a=0;a<e.length;++a)n.push([\"ptr\",a,\"=b_ptr\",a,\"+ptr_shift\"].join(\"\"));n.push(i),r&&n.push(\"++pivot_ptr\");for(a=0;a<t.length;++a){var o;0!==(o=t[a])&&(e.length>1?n.push(\"ptr_shift+=d\"+o):n.push(\"ptr0+=d\"+o),n.push(\"}\"))}}function y(e,r,i,a){if(1===r.length)n.push(\"ptr0=\"+d(r[0]));else{for(var o=0;o<r.length;++o)n.push([\"b_ptr\",o,\"=s0*\",r[o]].join(\"\"));n.push(\"ptr_shift=offset\")}i&&n.push(\"pivot_ptr=0\"),e&&n.push(e+\":\");for(o=1;o<t.length;++o)n.push([\"for(i\",o,\"=0;i\",o,\"<n\",o,\";++i\",o,\"){\"].join(\"\"));if(r.length>1)for(o=0;o<r.length;++o)n.push([\"ptr\",o,\"=b_ptr\",o,\"+ptr_shift\"].join(\"\"));n.push(a);for(o=t.length-1;o>=1;--o)i&&n.push(\"pivot_ptr+=f\"+o),r.length>1?n.push(\"ptr_shift+=e\"+o):n.push(\"ptr0+=e\"+o),n.push(\"}\")}function x(){t.length>1&&c&&n.push(\"free(pivot1)\",\"free(pivot2)\")}function b(e,r){var i=\"el\"+e,a=\"el\"+r;if(t.length>1){var o=\"__l\"+ ++u;y(o,[i,a],!1,[\"comp=\",g(\"ptr0\"),\"-\",g(\"ptr1\"),\"\\n\",\"if(comp>0){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0;break \",o,\"}\\n\",\"if(comp<0){break \",o,\"}\"].join(\"\"))}else n.push([\"if(\",g(d(i)),\">\",g(d(a)),\"){tmp0=\",i,\";\",i,\"=\",a,\";\",a,\"=tmp0}\"].join(\"\"))}function _(e,r){t.length>1?v([e,r],!1,m(\"ptr0\",g(\"ptr1\"))):n.push(m(d(e),g(d(r))))}function w(e,r,i){if(t.length>1){var a=\"__l\"+ ++u;y(a,[r],!0,[e,\"=\",g(\"ptr0\"),\"-pivot\",i,\"[pivot_ptr]\\n\",\"if(\",e,\"!==0){break \",a,\"}\"].join(\"\"))}else n.push([e,\"=\",g(d(r)),\"-pivot\",i].join(\"\"))}function T(e,r){t.length>1?v([e,r],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\")):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",\"tmp\")].join(\"\"))}function k(e,r,i){t.length>1?(v([e,r,i],!1,[\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\")),n.push(\"++\"+r,\"--\"+i)):n.push([\"ptr0=\",d(e),\"\\n\",\"ptr1=\",d(r),\"\\n\",\"ptr2=\",d(i),\"\\n\",\"++\",r,\"\\n\",\"--\",i,\"\\n\",\"tmp=\",g(\"ptr0\"),\"\\n\",m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",g(\"ptr2\")),\"\\n\",m(\"ptr2\",\"tmp\")].join(\"\"))}function M(t,e){T(t,e),n.push(\"--\"+e)}function A(e,r,i){t.length>1?v([e,r],!0,[m(\"ptr0\",g(\"ptr1\")),\"\\n\",m(\"ptr1\",[\"pivot\",i,\"[pivot_ptr]\"].join(\"\"))].join(\"\")):n.push(m(d(e),g(d(r))),m(d(r),\"pivot\"+i))}function S(e,r){n.push([\"if((\",r,\"-\",e,\")<=\",i,\"){\\n\",\"insertionSort(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}else{\\n\",s,\"(\",e,\",\",r,\",data,offset,\",o(t.length).join(\",\"),\")\\n\",\"}\"].join(\"\"))}function E(e,r,i){t.length>1?(n.push([\"__l\",++u,\":while(true){\"].join(\"\")),v([e],!0,[\"if(\",g(\"ptr0\"),\"!==pivot\",r,\"[pivot_ptr]){break __l\",u,\"}\"].join(\"\")),n.push(i,\"}\")):n.push([\"while(\",g(d(e)),\"===pivot\",r,\"){\",i,\"}\"].join(\"\"))}return n.push(\"var \"+f.join(\",\")),b(1,2),b(4,5),b(1,3),b(2,3),b(1,4),b(3,4),b(2,5),b(2,3),b(4,5),t.length>1?v([\"el1\",\"el2\",\"el3\",\"el4\",\"el5\",\"index1\",\"index3\",\"index5\"],!0,[\"pivot1[pivot_ptr]=\",g(\"ptr1\"),\"\\n\",\"pivot2[pivot_ptr]=\",g(\"ptr3\"),\"\\n\",\"pivots_are_equal=pivots_are_equal&&(pivot1[pivot_ptr]===pivot2[pivot_ptr])\\n\",\"x=\",g(\"ptr0\"),\"\\n\",\"y=\",g(\"ptr2\"),\"\\n\",\"z=\",g(\"ptr4\"),\"\\n\",m(\"ptr5\",\"x\"),\"\\n\",m(\"ptr6\",\"y\"),\"\\n\",m(\"ptr7\",\"z\")].join(\"\")):n.push([\"pivot1=\",g(d(\"el2\")),\"\\n\",\"pivot2=\",g(d(\"el4\")),\"\\n\",\"pivots_are_equal=pivot1===pivot2\\n\",\"x=\",g(d(\"el1\")),\"\\n\",\"y=\",g(d(\"el3\")),\"\\n\",\"z=\",g(d(\"el5\")),\"\\n\",m(d(\"index1\"),\"x\"),\"\\n\",m(d(\"index3\"),\"y\"),\"\\n\",m(d(\"index5\"),\"z\")].join(\"\")),_(\"index2\",\"left\"),_(\"index4\",\"right\"),n.push(\"if(pivots_are_equal){\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp\",\"k\",1),n.push(\"if(comp===0){continue}\"),n.push(\"if(comp<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),n.push(\"while(true){\"),w(\"comp\",\"great\",1),n.push(\"if(comp>0){\"),n.push(\"great--\"),n.push(\"}else if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"break\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}else{\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1<0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2>0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp>0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),A(\"left\",\"(less-1)\",1),A(\"right\",\"(great+1)\",2),S(\"left\",\"(less-2)\"),S(\"(great+2)\",\"right\"),n.push(\"if(pivots_are_equal){\"),x(),n.push(\"return\"),n.push(\"}\"),n.push(\"if(less<index1&&great>index5){\"),E(\"less\",1,\"++less\"),E(\"great\",2,\"--great\"),n.push(\"for(k=less;k<=great;++k){\"),w(\"comp_pivot1\",\"k\",1),n.push(\"if(comp_pivot1===0){\"),n.push(\"if(k!==less){\"),T(\"k\",\"less\"),n.push(\"}\"),n.push(\"++less\"),n.push(\"}else{\"),w(\"comp_pivot2\",\"k\",2),n.push(\"if(comp_pivot2===0){\"),n.push(\"while(true){\"),w(\"comp\",\"great\",2),n.push(\"if(comp===0){\"),n.push(\"if(--great<k){break}\"),n.push(\"continue\"),n.push(\"}else{\"),w(\"comp\",\"great\",1),n.push(\"if(comp<0){\"),k(\"k\",\"less\",\"great\"),n.push(\"}else{\"),M(\"k\",\"great\"),n.push(\"}\"),n.push(\"break\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),n.push(\"}\"),x(),S(\"less\",\"great\"),n.push(\"}return \"+s),t.length>1&&c?new Function(\"insertionSort\",\"malloc\",\"free\",n.join(\"\\n\"))(r,c[0],c[1]):new Function(\"insertionSort\",n.join(\"\\n\"))(r)}(t,e,v);return m(v,y)}},{\"typedarray-pool\":595}],494:[function(t,e,r){\"use strict\";var n=t(\"./lib/compile_sort.js\"),i={};e.exports=function(t){var e=t.order,r=t.dtype,a=[e,r].join(\":\"),o=i[a];return o||(i[a]=o=n(e,r)),o(t),t}},{\"./lib/compile_sort.js\":493}],495:[function(t,e,r){var n=t(\"iota-array\"),i=t(\"is-buffer\"),a=\"undefined\"!=typeof Float64Array;function o(t,e){return t[0]-e[0]}function s(){var t,e=this.stride,r=new Array(e.length);for(t=0;t<r.length;++t)r[t]=[Math.abs(e[t]),t];r.sort(o);var n=new Array(r.length);for(t=0;t<n.length;++t)n[t]=r[t][1];return n}function l(t,e){var r=[\"View\",e,\"d\",t].join(\"\");e<0&&(r=\"View_Nil\"+t);var i=\"generic\"===t;if(-1===e){var a=\"function \"+r+\"(a){this.data=a;};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return -1};proto.size=0;proto.dimension=-1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function(){return new \"+r+\"(this.data);};proto.get=proto.set=function(){};proto.pick=function(){return null};return function construct_\"+r+\"(a){return new \"+r+\"(a);}\";return new Function(a)()}if(0===e){a=\"function \"+r+\"(a,d) {this.data = a;this.offset = d};var proto=\"+r+\".prototype;proto.dtype='\"+t+\"';proto.index=function(){return this.offset};proto.dimension=0;proto.size=1;proto.shape=proto.stride=proto.order=[];proto.lo=proto.hi=proto.transpose=proto.step=function \"+r+\"_copy() {return new \"+r+\"(this.data,this.offset)};proto.pick=function \"+r+\"_pick(){return TrivialArray(this.data);};proto.valueOf=proto.get=function \"+r+\"_get(){return \"+(i?\"this.data.get(this.offset)\":\"this.data[this.offset]\")+\"};proto.set=function \"+r+\"_set(v){return \"+(i?\"this.data.set(this.offset,v)\":\"this.data[this.offset]=v\")+\"};return function construct_\"+r+\"(a,b,c,d){return new \"+r+\"(a,d)}\";return new Function(\"TrivialArray\",a)(c[t][0])}a=[\"'use strict'\"];var o=n(e),l=o.map((function(t){return\"i\"+t})),u=\"this.offset+\"+o.map((function(t){return\"this.stride[\"+t+\"]*i\"+t})).join(\"+\"),f=o.map((function(t){return\"b\"+t})).join(\",\"),h=o.map((function(t){return\"c\"+t})).join(\",\");a.push(\"function \"+r+\"(a,\"+f+\",\"+h+\",d){this.data=a\",\"this.shape=[\"+f+\"]\",\"this.stride=[\"+h+\"]\",\"this.offset=d|0}\",\"var proto=\"+r+\".prototype\",\"proto.dtype='\"+t+\"'\",\"proto.dimension=\"+e),a.push(\"Object.defineProperty(proto,'size',{get:function \"+r+\"_size(){return \"+o.map((function(t){return\"this.shape[\"+t+\"]\"})).join(\"*\"),\"}})\"),1===e?a.push(\"proto.order=[0]\"):(a.push(\"Object.defineProperty(proto,'order',{get:\"),e<4?(a.push(\"function \"+r+\"_order(){\"),2===e?a.push(\"return (Math.abs(this.stride[0])>Math.abs(this.stride[1]))?[1,0]:[0,1]}})\"):3===e&&a.push(\"var s0=Math.abs(this.stride[0]),s1=Math.abs(this.stride[1]),s2=Math.abs(this.stride[2]);if(s0>s1){if(s1>s2){return [2,1,0];}else if(s0>s2){return [1,2,0];}else{return [1,0,2];}}else if(s0>s2){return [2,0,1];}else if(s2>s1){return [0,1,2];}else{return [0,2,1];}}})\")):a.push(\"ORDER})\")),a.push(\"proto.set=function \"+r+\"_set(\"+l.join(\",\")+\",v){\"),i?a.push(\"return this.data.set(\"+u+\",v)}\"):a.push(\"return this.data[\"+u+\"]=v}\"),a.push(\"proto.get=function \"+r+\"_get(\"+l.join(\",\")+\"){\"),i?a.push(\"return this.data.get(\"+u+\")}\"):a.push(\"return this.data[\"+u+\"]}\"),a.push(\"proto.index=function \"+r+\"_index(\",l.join(),\"){return \"+u+\"}\"),a.push(\"proto.hi=function \"+r+\"_hi(\"+l.join(\",\")+\"){return new \"+r+\"(this.data,\"+o.map((function(t){return[\"(typeof i\",t,\"!=='number'||i\",t,\"<0)?this.shape[\",t,\"]:i\",t,\"|0\"].join(\"\")})).join(\",\")+\",\"+o.map((function(t){return\"this.stride[\"+t+\"]\"})).join(\",\")+\",this.offset)}\");var p=o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})),d=o.map((function(t){return\"c\"+t+\"=this.stride[\"+t+\"]\"}));a.push(\"proto.lo=function \"+r+\"_lo(\"+l.join(\",\")+\"){var b=this.offset,d=0,\"+p.join(\",\")+\",\"+d.join(\",\"));for(var g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){d=i\"+g+\"|0;b+=c\"+g+\"*d;a\"+g+\"-=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"c\"+t})).join(\",\")+\",b)}\"),a.push(\"proto.step=function \"+r+\"_step(\"+l.join(\",\")+\"){var \"+o.map((function(t){return\"a\"+t+\"=this.shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t+\"=this.stride[\"+t+\"]\"})).join(\",\")+\",c=this.offset,d=0,ceil=Math.ceil\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'){d=i\"+g+\"|0;if(d<0){c+=b\"+g+\"*(a\"+g+\"-1);a\"+g+\"=ceil(-a\"+g+\"/d)}else{a\"+g+\"=ceil(a\"+g+\"/d)}b\"+g+\"*=d}\");a.push(\"return new \"+r+\"(this.data,\"+o.map((function(t){return\"a\"+t})).join(\",\")+\",\"+o.map((function(t){return\"b\"+t})).join(\",\")+\",c)}\");var m=new Array(e),v=new Array(e);for(g=0;g<e;++g)m[g]=\"a[i\"+g+\"]\",v[g]=\"b[i\"+g+\"]\";a.push(\"proto.transpose=function \"+r+\"_transpose(\"+l+\"){\"+l.map((function(t,e){return t+\"=(\"+t+\"===undefined?\"+e+\":\"+t+\"|0)\"})).join(\";\"),\"var a=this.shape,b=this.stride;return new \"+r+\"(this.data,\"+m.join(\",\")+\",\"+v.join(\",\")+\",this.offset)}\"),a.push(\"proto.pick=function \"+r+\"_pick(\"+l+\"){var a=[],b=[],c=this.offset\");for(g=0;g<e;++g)a.push(\"if(typeof i\"+g+\"==='number'&&i\"+g+\">=0){c=(c+this.stride[\"+g+\"]*i\"+g+\")|0}else{a.push(this.shape[\"+g+\"]);b.push(this.stride[\"+g+\"])}\");return a.push(\"var ctor=CTOR_LIST[a.length+1];return ctor(this.data,a,b,c)}\"),a.push(\"return function construct_\"+r+\"(data,shape,stride,offset){return new \"+r+\"(data,\"+o.map((function(t){return\"shape[\"+t+\"]\"})).join(\",\")+\",\"+o.map((function(t){return\"stride[\"+t+\"]\"})).join(\",\")+\",offset)}\"),new Function(\"CTOR_LIST\",\"ORDER\",a.join(\"\\n\"))(c[t],s)}var c={float32:[],float64:[],int8:[],int16:[],int32:[],uint8:[],uint16:[],uint32:[],array:[],uint8_clamped:[],bigint64:[],biguint64:[],buffer:[],generic:[]};e.exports=function(t,e,r,n){if(void 0===t)return(0,c.array[0])([]);\"number\"==typeof t&&(t=[t]),void 0===e&&(e=[t.length]);var o=e.length;if(void 0===r){r=new Array(o);for(var s=o-1,u=1;s>=0;--s)r[s]=u,u*=e[s]}if(void 0===n){n=0;for(s=0;s<o;++s)r[s]<0&&(n-=(e[s]-1)*r[s])}for(var f=function(t){if(i(t))return\"buffer\";if(a)switch(Object.prototype.toString.call(t)){case\"[object Float64Array]\":return\"float64\";case\"[object Float32Array]\":return\"float32\";case\"[object Int8Array]\":return\"int8\";case\"[object Int16Array]\":return\"int16\";case\"[object Int32Array]\":return\"int32\";case\"[object Uint8Array]\":return\"uint8\";case\"[object Uint16Array]\":return\"uint16\";case\"[object Uint32Array]\":return\"uint32\";case\"[object Uint8ClampedArray]\":return\"uint8_clamped\";case\"[object BigInt64Array]\":return\"bigint64\";case\"[object BigUint64Array]\":return\"biguint64\"}return Array.isArray(t)?\"array\":\"generic\"}(t),h=c[f];h.length<=o+1;)h.push(l(f,h.length-1));return(0,h[o+1])(t,e,r,n)}},{\"iota-array\":463,\"is-buffer\":465}],496:[function(t,e,r){\"use strict\";var n=t(\"double-bits\"),i=Math.pow(2,-1074);e.exports=function(t,e){if(isNaN(t)||isNaN(e))return NaN;if(t===e)return t;if(0===t)return e<0?-i:i;var r=n.hi(t),a=n.lo(t);e>t==t>0?a===-1>>>0?(r+=1,a=0):a+=1:0===a?(a=-1>>>0,r-=1):a-=1;return n.pack(a,r)}},{\"double-bits\":173}],497:[function(t,e,r){var n=Math.PI,i=c(120);function a(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function o(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}function s(t,e,r,a,o,c,u,f,h,p){if(p)T=p[0],k=p[1],_=p[2],w=p[3];else{var d=l(t,e,-o);t=d.x,e=d.y;var g=(t-(f=(d=l(f,h,-o)).x))/2,m=(e-(h=d.y))/2,v=g*g/(r*r)+m*m/(a*a);v>1&&(r*=v=Math.sqrt(v),a*=v);var y=r*r,x=a*a,b=(c==u?-1:1)*Math.sqrt(Math.abs((y*x-y*m*m-x*g*g)/(y*m*m+x*g*g)));b==1/0&&(b=1);var _=b*r*m/a+(t+f)/2,w=b*-a*g/r+(e+h)/2,T=Math.asin(((e-w)/a).toFixed(9)),k=Math.asin(((h-w)/a).toFixed(9));(T=t<_?n-T:T)<0&&(T=2*n+T),(k=f<_?n-k:k)<0&&(k=2*n+k),u&&T>k&&(T-=2*n),!u&&k>T&&(k-=2*n)}if(Math.abs(k-T)>i){var M=k,A=f,S=h;k=T+i*(u&&k>T?1:-1);var E=s(f=_+r*Math.cos(k),h=w+a*Math.sin(k),r,a,o,0,u,A,S,[k,M,_,w])}var C=Math.tan((k-T)/4),L=4/3*r*C,I=4/3*a*C,P=[2*t-(t+L*Math.sin(T)),2*e-(e-I*Math.cos(T)),f+L*Math.sin(k),h-I*Math.cos(k),f,h];if(p)return P;E&&(P=P.concat(E));for(var z=0;z<P.length;){var O=l(P[z],P[z+1],o);P[z++]=O.x,P[z++]=O.y}return P}function l(t,e,r){return{x:t*Math.cos(r)-e*Math.sin(r),y:t*Math.sin(r)+e*Math.cos(r)}}function c(t){return t*(n/180)}e.exports=function(t){for(var e,r=[],n=0,i=0,l=0,u=0,f=null,h=null,p=0,d=0,g=0,m=t.length;g<m;g++){var v=t[g],y=v[0];switch(y){case\"M\":l=v[1],u=v[2];break;case\"A\":(v=s(p,d,v[1],v[2],c(v[3]),v[4],v[5],v[6],v[7])).unshift(\"C\"),v.length>7&&(r.push(v.splice(0,7)),v.unshift(\"C\"));break;case\"S\":var x=p,b=d;\"C\"!=e&&\"S\"!=e||(x+=x-n,b+=b-i),v=[\"C\",x,b,v[1],v[2],v[3],v[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(f=2*p-f,h=2*d-h):(f=p,h=d),v=o(p,d,f,h,v[1],v[2]);break;case\"Q\":f=v[1],h=v[2],v=o(p,d,v[1],v[2],v[3],v[4]);break;case\"L\":v=a(p,d,v[1],v[2]);break;case\"H\":v=a(p,d,v[1],d);break;case\"V\":v=a(p,d,p,v[1]);break;case\"Z\":v=a(p,d,l,u)}e=y,p=v[v.length-2],d=v[v.length-1],v.length>4?(n=v[v.length-4],i=v[v.length-3]):(n=p,i=d),r.push(v)}return r}},{}],498:[function(t,e,r){r.vertexNormals=function(t,e,r){for(var n=e.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o)i[o]=[0,0,0];for(o=0;o<t.length;++o)for(var s=t[o],l=0,c=s[s.length-1],u=s[0],f=0;f<s.length;++f){l=c,c=u,u=s[(f+1)%s.length];for(var h=e[l],p=e[c],d=e[u],g=new Array(3),m=0,v=new Array(3),y=0,x=0;x<3;++x)g[x]=h[x]-p[x],m+=g[x]*g[x],v[x]=d[x]-p[x],y+=v[x]*v[x];if(m*y>a){var b=i[c],_=1/Math.sqrt(m*y);for(x=0;x<3;++x){var w=(x+1)%3,T=(x+2)%3;b[x]+=_*(v[w]*g[T]-v[T]*g[w])}}}for(o=0;o<n;++o){b=i[o];var k=0;for(x=0;x<3;++x)k+=b[x]*b[x];if(k>a)for(_=1/Math.sqrt(k),x=0;x<3;++x)b[x]*=_;else for(x=0;x<3;++x)b[x]=0}return i},r.faceNormals=function(t,e,r){for(var n=t.length,i=new Array(n),a=void 0===r?1e-6:r,o=0;o<n;++o){for(var s=t[o],l=new Array(3),c=0;c<3;++c)l[c]=e[s[c]];var u=new Array(3),f=new Array(3);for(c=0;c<3;++c)u[c]=l[1][c]-l[0][c],f[c]=l[2][c]-l[0][c];var h=new Array(3),p=0;for(c=0;c<3;++c){var d=(c+1)%3,g=(c+2)%3;h[c]=u[d]*f[g]-u[g]*f[d],p+=h[c]*h[c]}p=p>a?1/Math.sqrt(p):0;for(c=0;c<3;++c)h[c]*=p;i[o]=h}return i}},{}],499:[function(t,e,r){\n",
       "/*\n",
       "object-assign\n",
       "(c) Sindre Sorhus\n",
       "@license MIT\n",
       "*/\n",
       "\"use strict\";var n=Object.getOwnPropertySymbols,i=Object.prototype.hasOwnProperty,a=Object.prototype.propertyIsEnumerable;function o(t){if(null==t)throw new TypeError(\"Object.assign cannot be called with null or undefined\");return Object(t)}e.exports=function(){try{if(!Object.assign)return!1;var t=new String(\"abc\");if(t[5]=\"de\",\"5\"===Object.getOwnPropertyNames(t)[0])return!1;for(var e={},r=0;r<10;r++)e[\"_\"+String.fromCharCode(r)]=r;if(\"0123456789\"!==Object.getOwnPropertyNames(e).map((function(t){return e[t]})).join(\"\"))return!1;var n={};return\"abcdefghijklmnopqrst\".split(\"\").forEach((function(t){n[t]=t})),\"abcdefghijklmnopqrst\"===Object.keys(Object.assign({},n)).join(\"\")}catch(t){return!1}}()?Object.assign:function(t,e){for(var r,s,l=o(t),c=1;c<arguments.length;c++){for(var u in r=Object(arguments[c]))i.call(r,u)&&(l[u]=r[u]);if(n){s=n(r);for(var f=0;f<s.length;f++)a.call(r,s[f])&&(l[s[f]]=r[s[f]])}}return l}},{}],500:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a,o,s,l,c){var u=e+a+c;if(f>0){var f=Math.sqrt(u+1);t[0]=.5*(o-l)/f,t[1]=.5*(s-n)/f,t[2]=.5*(r-a)/f,t[3]=.5*f}else{var h=Math.max(e,a,c);f=Math.sqrt(2*h-u+1);e>=h?(t[0]=.5*f,t[1]=.5*(i+r)/f,t[2]=.5*(s+n)/f,t[3]=.5*(o-l)/f):a>=h?(t[0]=.5*(r+i)/f,t[1]=.5*f,t[2]=.5*(l+o)/f,t[3]=.5*(s-n)/f):(t[0]=.5*(n+s)/f,t[1]=.5*(o+l)/f,t[2]=.5*f,t[3]=.5*(r-i)/f)}return t}},{}],501:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.rotation||[0,0,0,1],n=t.radius||1;e=[].slice.call(e,0,3),u(r=[].slice.call(r,0,4),r);var i=new f(r,e,Math.log(n));i.setDistanceLimits(t.zoomMin,t.zoomMax),(\"eye\"in t||\"up\"in t)&&i.lookAt(0,t.eye,t.center,t.up);return i};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/lookAt\"),a=t(\"gl-mat4/fromQuat\"),o=t(\"gl-mat4/invert\"),s=t(\"./lib/quatFromFrame\");function l(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function c(t,e,r,n){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2)+Math.pow(n,2))}function u(t,e){var r=e[0],n=e[1],i=e[2],a=e[3],o=c(r,n,i,a);o>1e-6?(t[0]=r/o,t[1]=n/o,t[2]=i/o,t[3]=a/o):(t[0]=t[1]=t[2]=0,t[3]=1)}function f(t,e,r){this.radius=n([r]),this.center=n(e),this.rotation=n(t),this.computedRadius=this.radius.curve(0),this.computedCenter=this.center.curve(0),this.computedRotation=this.rotation.curve(0),this.computedUp=[.1,0,0],this.computedEye=[.1,0,0],this.computedMatrix=[.1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0],this.recalcMatrix(0)}var h=f.prototype;h.lastT=function(){return Math.max(this.radius.lastT(),this.center.lastT(),this.rotation.lastT())},h.recalcMatrix=function(t){this.radius.curve(t),this.center.curve(t),this.rotation.curve(t);var e=this.computedRotation;u(e,e);var r=this.computedMatrix;a(r,e);var n=this.computedCenter,i=this.computedEye,o=this.computedUp,s=Math.exp(this.computedRadius[0]);i[0]=n[0]+s*r[2],i[1]=n[1]+s*r[6],i[2]=n[2]+s*r[10],o[0]=r[1],o[1]=r[5],o[2]=r[9];for(var l=0;l<3;++l){for(var c=0,f=0;f<3;++f)c+=r[l+4*f]*i[f];r[12+l]=-c}},h.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r},h.idle=function(t){this.center.idle(t),this.radius.idle(t),this.rotation.idle(t)},h.flush=function(t){this.center.flush(t),this.radius.flush(t),this.rotation.flush(t)},h.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=i[1],o=i[5],s=i[9],c=l(a,o,s);a/=c,o/=c,s/=c;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=l(u-=a*p,f-=o*p,h-=s*p);u/=d,f/=d,h/=d;var g=i[2],m=i[6],v=i[10],y=g*a+m*o+v*s,x=g*u+m*f+v*h,b=l(g-=y*a+x*u,m-=y*o+x*f,v-=y*s+x*h);g/=b,m/=b,v/=b;var _=u*e+a*r,w=f*e+o*r,T=h*e+s*r;this.center.move(t,_,w,T);var k=Math.exp(this.computedRadius[0]);k=Math.max(1e-4,k+n),this.radius.set(t,Math.log(k))},h.rotate=function(t,e,r,n){this.recalcMatrix(t),e=e||0,r=r||0;var i=this.computedMatrix,a=i[0],o=i[4],s=i[8],u=i[1],f=i[5],h=i[9],p=i[2],d=i[6],g=i[10],m=e*a+r*u,v=e*o+r*f,y=e*s+r*h,x=-(d*y-g*v),b=-(g*m-p*y),_=-(p*v-d*m),w=Math.sqrt(Math.max(0,1-Math.pow(x,2)-Math.pow(b,2)-Math.pow(_,2))),T=c(x,b,_,w);T>1e-6?(x/=T,b/=T,_/=T,w/=T):(x=b=_=0,w=1);var k=this.computedRotation,M=k[0],A=k[1],S=k[2],E=k[3],C=M*w+E*x+A*_-S*b,L=A*w+E*b+S*x-M*_,I=S*w+E*_+M*b-A*x,P=E*w-M*x-A*b-S*_;if(n){x=p,b=d,_=g;var z=Math.sin(n)/l(x,b,_);x*=z,b*=z,_*=z,P=P*(w=Math.cos(e))-(C=C*w+P*x+L*_-I*b)*x-(L=L*w+P*b+I*x-C*_)*b-(I=I*w+P*_+C*b-L*x)*_}var O=c(C,L,I,P);O>1e-6?(C/=O,L/=O,I/=O,P/=O):(C=L=I=0,P=1),this.rotation.set(t,C,L,I,P)},h.lookAt=function(t,e,r,n){this.recalcMatrix(t),r=r||this.computedCenter,e=e||this.computedEye,n=n||this.computedUp;var a=this.computedMatrix;i(a,e,r,n);var o=this.computedRotation;s(o,a[0],a[1],a[2],a[4],a[5],a[6],a[8],a[9],a[10]),u(o,o),this.rotation.set(t,o[0],o[1],o[2],o[3]);for(var l=0,c=0;c<3;++c)l+=Math.pow(r[c]-e[c],2);this.radius.set(t,.5*Math.log(Math.max(l,1e-6))),this.center.set(t,r[0],r[1],r[2])},h.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},h.setMatrix=function(t,e){var r=this.computedRotation;s(r,e[0],e[1],e[2],e[4],e[5],e[6],e[8],e[9],e[10]),u(r,r),this.rotation.set(t,r[0],r[1],r[2],r[3]);var n=this.computedMatrix;o(n,e);var i=n[15];if(Math.abs(i)>1e-6){var a=n[12]/i,l=n[13]/i,c=n[14]/i;this.recalcMatrix(t);var f=Math.exp(this.computedRadius[0]);this.center.set(t,a-n[2]*f,l-n[6]*f,c-n[10]*f),this.radius.idle(t)}else this.center.idle(t),this.radius.idle(t)},h.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},h.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},h.getDistanceLimits=function(t){var e=this.radius.bounds;return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},h.toJSON=function(){return this.recalcMatrix(this.lastT()),{center:this.computedCenter.slice(),rotation:this.computedRotation.slice(),distance:Math.log(this.computedRadius[0]),zoomMin:this.radius.bounds[0][0],zoomMax:this.radius.bounds[1][0]}},h.fromJSON=function(t){var e=this.lastT(),r=t.center;r&&this.center.set(e,r[0],r[1],r[2]);var n=t.rotation;n&&this.rotation.set(e,n[0],n[1],n[2],n[3]);var i=t.distance;i&&i>0&&this.radius.set(e,Math.log(i)),this.setDistanceLimits(t.zoomMin,t.zoomMax)}},{\"./lib/quatFromFrame\":500,\"filtered-vector\":242,\"gl-mat4/fromQuat\":282,\"gl-mat4/invert\":293,\"gl-mat4/lookAt\":294}],502:[function(t,e,r){\n",
       "/*!\n",
       " * pad-left <https://github.com/jonschlinkert/pad-left>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT license.\n",
       " */\n",
       "\"use strict\";var n=t(\"repeat-string\");e.exports=function(t,e,r){return n(r=\"undefined\"!=typeof r?r+\"\":\" \",e)+t}},{\"repeat-string\":541}],503:[function(t,e,r){\"use strict\";function n(t,e){if(\"string\"!=typeof t)return[t];var r=[t];\"string\"==typeof e||Array.isArray(e)?e={brackets:e}:e||(e={});var n=e.brackets?Array.isArray(e.brackets)?e.brackets:[e.brackets]:[\"{}\",\"[]\",\"()\"],i=e.escape||\"___\",a=!!e.flat;n.forEach((function(t){var e=new RegExp([\"\\\\\",t[0],\"[^\\\\\",t[0],\"\\\\\",t[1],\"]*\\\\\",t[1]].join(\"\")),n=[];function a(e,a,o){var s=r.push(e.slice(t[0].length,-t[1].length))-1;return n.push(s),i+s+i}r.forEach((function(t,n){for(var i,o=0;t!=i;)if(i=t,t=t.replace(e,a),o++>1e4)throw Error(\"References have circular dependency. Please, check them.\");r[n]=t})),n=n.reverse(),r=r.map((function(e){return n.forEach((function(r){e=e.replace(new RegExp(\"(\\\\\"+i+r+\"\\\\\"+i+\")\",\"g\"),t[0]+\"$1\"+t[1])})),e}))}));var o=new RegExp(\"\\\\\"+i+\"([0-9]+)\\\\\"+i);return a?r:function t(e,r,n){for(var i,a=[],s=0;i=o.exec(e);){if(s++>1e4)throw Error(\"Circular references in parenthesis\");a.push(e.slice(0,i.index)),a.push(t(r[i[1]],r)),e=e.slice(i.index+i[0].length)}return a.push(e),a}(r[0],r)}function i(t,e){if(e&&e.flat){var r,n=e&&e.escape||\"___\",i=t[0];if(!i)return\"\";for(var a=new RegExp(\"\\\\\"+n+\"([0-9]+)\\\\\"+n),o=0;i!=r;){if(o++>1e4)throw Error(\"Circular references in \"+t);r=i,i=i.replace(a,s)}return i}return t.reduce((function t(e,r){return Array.isArray(r)&&(r=r.reduce(t,\"\")),e+r}),\"\");function s(e,r){if(null==t[r])throw Error(\"Reference \"+r+\"is undefined\");return t[r]}}function a(t,e){return Array.isArray(t)?i(t,e):n(t,e)}a.parse=n,a.stringify=i,e.exports=a},{}],504:[function(t,e,r){\"use strict\";var n=t(\"pick-by-alias\");e.exports=function(t){var e;arguments.length>1&&(t=arguments);\"string\"==typeof t?t=t.split(/\\s/).map(parseFloat):\"number\"==typeof t&&(t=[t]);t.length&&\"number\"==typeof t[0]?e=1===t.length?{width:t[0],height:t[0],x:0,y:0}:2===t.length?{width:t[0],height:t[1],x:0,y:0}:{x:t[0],y:t[1],width:t[2]-t[0]||0,height:t[3]-t[1]||0}:t&&(t=n(t,{left:\"x l left Left\",top:\"y t top Top\",width:\"w width W Width\",height:\"h height W Width\",bottom:\"b bottom Bottom\",right:\"r right Right\"}),e={x:t.left||0,y:t.top||0},null==t.width?t.right?e.width=t.right-e.x:e.width=0:e.width=t.width,null==t.height?t.bottom?e.height=t.bottom-e.y:e.height=0:e.height=t.height);return e}},{\"pick-by-alias\":511}],505:[function(t,e,r){e.exports=function(t){var e=[];return t.replace(i,(function(t,r,i){var o=r.toLowerCase();for(i=function(t){var e=t.match(a);return e?e.map(Number):[]}(i),\"m\"==o&&i.length>2&&(e.push([r].concat(i.splice(0,2))),o=\"l\",r=\"m\"==r?\"l\":\"L\");;){if(i.length==n[o])return i.unshift(r),e.push(i);if(i.length<n[o])throw new Error(\"malformed path data\");e.push([r].concat(i.splice(0,n[o])))}})),e};var n={a:7,c:6,h:1,l:2,m:2,q:4,s:4,t:2,v:1,z:0},i=/([astvzqmhlc])([^astvzqmhlc]*)/gi;var a=/-?[0-9]*\\.?[0-9]+(?:e[-+]?\\d+)?/gi},{}],506:[function(t,e,r){e.exports=function(t,e){e||(e=[0,\"\"]),t=String(t);var r=parseFloat(t,10);return e[0]=r,e[1]=t.match(/[\\d.\\-\\+]*\\s*(.*)/)[1]||\"\",e}},{}],507:[function(t,e,r){(function(t){(function(){\"use strict\";function r(t){if(\"string\"!=typeof t)throw new TypeError(\"Path must be a string. Received \"+JSON.stringify(t))}function n(t,e){for(var r,n=\"\",i=0,a=-1,o=0,s=0;s<=t.length;++s){if(s<t.length)r=t.charCodeAt(s);else{if(47===r)break;r=47}if(47===r){if(a===s-1||1===o);else if(a!==s-1&&2===o){if(n.length<2||2!==i||46!==n.charCodeAt(n.length-1)||46!==n.charCodeAt(n.length-2))if(n.length>2){var l=n.lastIndexOf(\"/\");if(l!==n.length-1){-1===l?(n=\"\",i=0):i=(n=n.slice(0,l)).length-1-n.lastIndexOf(\"/\"),a=s,o=0;continue}}else if(2===n.length||1===n.length){n=\"\",i=0,a=s,o=0;continue}e&&(n.length>0?n+=\"/..\":n=\"..\",i=2)}else n.length>0?n+=\"/\"+t.slice(a+1,s):n=t.slice(a+1,s),i=s-a-1;a=s,o=0}else 46===r&&-1!==o?++o:o=-1}return n}var i={resolve:function(){for(var e,i=\"\",a=!1,o=arguments.length-1;o>=-1&&!a;o--){var s;o>=0?s=arguments[o]:(void 0===e&&(e=t.cwd()),s=e),r(s),0!==s.length&&(i=s+\"/\"+i,a=47===s.charCodeAt(0))}return i=n(i,!a),a?i.length>0?\"/\"+i:\"/\":i.length>0?i:\".\"},normalize:function(t){if(r(t),0===t.length)return\".\";var e=47===t.charCodeAt(0),i=47===t.charCodeAt(t.length-1);return 0!==(t=n(t,!e)).length||e||(t=\".\"),t.length>0&&i&&(t+=\"/\"),e?\"/\"+t:t},isAbsolute:function(t){return r(t),t.length>0&&47===t.charCodeAt(0)},join:function(){if(0===arguments.length)return\".\";for(var t,e=0;e<arguments.length;++e){var n=arguments[e];r(n),n.length>0&&(void 0===t?t=n:t+=\"/\"+n)}return void 0===t?\".\":i.normalize(t)},relative:function(t,e){if(r(t),r(e),t===e)return\"\";if((t=i.resolve(t))===(e=i.resolve(e)))return\"\";for(var n=1;n<t.length&&47===t.charCodeAt(n);++n);for(var a=t.length,o=a-n,s=1;s<e.length&&47===e.charCodeAt(s);++s);for(var l=e.length-s,c=o<l?o:l,u=-1,f=0;f<=c;++f){if(f===c){if(l>c){if(47===e.charCodeAt(s+f))return e.slice(s+f+1);if(0===f)return e.slice(s+f)}else o>c&&(47===t.charCodeAt(n+f)?u=f:0===f&&(u=0));break}var h=t.charCodeAt(n+f);if(h!==e.charCodeAt(s+f))break;47===h&&(u=f)}var p=\"\";for(f=n+u+1;f<=a;++f)f!==a&&47!==t.charCodeAt(f)||(0===p.length?p+=\"..\":p+=\"/..\");return p.length>0?p+e.slice(s+u):(s+=u,47===e.charCodeAt(s)&&++s,e.slice(s))},_makeLong:function(t){return t},dirname:function(t){if(r(t),0===t.length)return\".\";for(var e=t.charCodeAt(0),n=47===e,i=-1,a=!0,o=t.length-1;o>=1;--o)if(47===(e=t.charCodeAt(o))){if(!a){i=o;break}}else a=!1;return-1===i?n?\"/\":\".\":n&&1===i?\"//\":t.slice(0,i)},basename:function(t,e){if(void 0!==e&&\"string\"!=typeof e)throw new TypeError('\"ext\" argument must be a string');r(t);var n,i=0,a=-1,o=!0;if(void 0!==e&&e.length>0&&e.length<=t.length){if(e.length===t.length&&e===t)return\"\";var s=e.length-1,l=-1;for(n=t.length-1;n>=0;--n){var c=t.charCodeAt(n);if(47===c){if(!o){i=n+1;break}}else-1===l&&(o=!1,l=n+1),s>=0&&(c===e.charCodeAt(s)?-1==--s&&(a=n):(s=-1,a=l))}return i===a?a=l:-1===a&&(a=t.length),t.slice(i,a)}for(n=t.length-1;n>=0;--n)if(47===t.charCodeAt(n)){if(!o){i=n+1;break}}else-1===a&&(o=!1,a=n+1);return-1===a?\"\":t.slice(i,a)},extname:function(t){r(t);for(var e=-1,n=0,i=-1,a=!0,o=0,s=t.length-1;s>=0;--s){var l=t.charCodeAt(s);if(47!==l)-1===i&&(a=!1,i=s+1),46===l?-1===e?e=s:1!==o&&(o=1):-1!==e&&(o=-1);else if(!a){n=s+1;break}}return-1===e||-1===i||0===o||1===o&&e===i-1&&e===n+1?\"\":t.slice(e,i)},format:function(t){if(null===t||\"object\"!=typeof t)throw new TypeError('The \"pathObject\" argument must be of type Object. Received type '+typeof t);return function(t,e){var r=e.dir||e.root,n=e.base||(e.name||\"\")+(e.ext||\"\");return r?r===e.root?r+n:r+t+n:n}(\"/\",t)},parse:function(t){r(t);var e={root:\"\",dir:\"\",base:\"\",ext:\"\",name:\"\"};if(0===t.length)return e;var n,i=t.charCodeAt(0),a=47===i;a?(e.root=\"/\",n=1):n=0;for(var o=-1,s=0,l=-1,c=!0,u=t.length-1,f=0;u>=n;--u)if(47!==(i=t.charCodeAt(u)))-1===l&&(c=!1,l=u+1),46===i?-1===o?o=u:1!==f&&(f=1):-1!==o&&(f=-1);else if(!c){s=u+1;break}return-1===o||-1===l||0===f||1===f&&o===l-1&&o===s+1?-1!==l&&(e.base=e.name=0===s&&a?t.slice(1,l):t.slice(s,l)):(0===s&&a?(e.name=t.slice(1,o),e.base=t.slice(1,l)):(e.name=t.slice(s,o),e.base=t.slice(s,l)),e.ext=t.slice(o,l)),s>0?e.dir=t.slice(0,s-1):a&&(e.dir=\"/\"),e},sep:\"/\",delimiter:\":\",win32:null,posix:null};i.posix=i,e.exports=i}).call(this)}).call(this,t(\"_process\"))},{_process:526}],508:[function(t,e,r){(function(t){(function(){(function(){var r,n,i,a,o,s;\"undefined\"!=typeof performance&&null!==performance&&performance.now?e.exports=function(){return performance.now()}:\"undefined\"!=typeof t&&null!==t&&t.hrtime?(e.exports=function(){return(r()-o)/1e6},n=t.hrtime,a=(r=function(){var t;return 1e9*(t=n())[0]+t[1]})(),s=1e9*t.uptime(),o=a-s):Date.now?(e.exports=function(){return Date.now()-i},i=Date.now()):(e.exports=function(){return(new Date).getTime()-i},i=(new Date).getTime())}).call(this)}).call(this)}).call(this,t(\"_process\"))},{_process:526}],509:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.length;if(e<32){for(var r=1,i=0;i<e;++i)for(var a=0;a<i;++a)if(t[i]<t[a])r=-r;else if(t[i]===t[a])return 0;return r}var o=n.mallocUint8(e);for(i=0;i<e;++i)o[i]=0;for(r=1,i=0;i<e;++i)if(!o[i]){var s=1;o[i]=1;for(a=t[i];a!==i;a=t[a]){if(o[a])return n.freeUint8(o),0;s+=1,o[a]=1}1&s||(r=-r)}return n.freeUint8(o),r};var n=t(\"typedarray-pool\")},{\"typedarray-pool\":595}],510:[function(t,e,r){\"use strict\";var n=t(\"typedarray-pool\"),i=t(\"invert-permutation\");r.rank=function(t){var e=t.length;switch(e){case 0:case 1:return 0;case 2:return t[1]}var r,a,o,s=n.mallocUint32(e),l=n.mallocUint32(e),c=0;for(i(t,l),o=0;o<e;++o)s[o]=t[o];for(o=e-1;o>0;--o)a=l[o],r=s[o],s[o]=s[a],s[a]=r,l[o]=l[r],l[r]=a,c=(c+r)*o;return n.freeUint32(l),n.freeUint32(s),c},r.unrank=function(t,e,r){switch(t){case 0:return r||[];case 1:return r?(r[0]=0,r):[0];case 2:return r?(e?(r[0]=0,r[1]=1):(r[0]=1,r[1]=0),r):e?[0,1]:[1,0]}var n,i,a,o=1;for((r=r||new Array(t))[0]=0,a=1;a<t;++a)r[a]=a,o=o*a|0;for(a=t-1;a>0;--a)e=e-(n=e/o|0)*o|0,o=o/a|0,i=0|r[a],r[a]=0|r[n],r[n]=0|i;return r}},{\"invert-permutation\":462,\"typedarray-pool\":595}],511:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n,a,o={};if(\"string\"==typeof e&&(e=i(e)),Array.isArray(e)){var s={};for(a=0;a<e.length;a++)s[e[a]]=!0;e=s}for(n in e)e[n]=i(e[n]);var l={};for(n in e){var c=e[n];if(Array.isArray(c))for(a=0;a<c.length;a++){var u=c[a];if(r&&(l[u]=!0),u in t){if(o[n]=t[u],r)for(var f=a;f<c.length;f++)l[c[f]]=!0;break}}else n in t&&(e[n]&&(o[n]=t[n]),r&&(l[n]=!0))}if(r)for(n in t)l[n]||(o[n]=t[n]);return o};var n={};function i(t){return n[t]?n[t]:(\"string\"==typeof t&&(t=n[t]=t.split(/\\s*,\\s*|\\s+/)),t)}},{}],512:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=0|e.length,i=t.length,a=[new Array(r),new Array(r)],o=0;o<r;++o)a[0][o]=[],a[1][o]=[];for(o=0;o<i;++o){var s=t[o];a[0][s[0]].push(s),a[1][s[1]].push(s)}var l=[];for(o=0;o<r;++o)a[0][o].length+a[1][o].length===0&&l.push([o]);function c(t,e){var r=a[e][t[e]];r.splice(r.indexOf(t),1)}function u(t,r,i){for(var o,s,l,u=0;u<2;++u)if(a[u][r].length>0){o=a[u][r][0],l=u;break}s=o[1^l];for(var f=0;f<2;++f)for(var h=a[f][r],p=0;p<h.length;++p){var d=h[p],g=d[1^f];n(e[t],e[r],e[s],e[g])>0&&(o=d,s=g,l=f)}return i||o&&c(o,l),s}function f(t,r){var i=a[r][t][0],o=[t];c(i,r);for(var s=i[1^r];;){for(;s!==t;)o.push(s),s=u(o[o.length-2],s,!1);if(a[0][t].length+a[1][t].length===0)break;var l=o[o.length-1],f=t,h=o[1],p=u(l,f,!0);if(n(e[l],e[f],e[h],e[p])<0)break;o.push(t),s=u(l,f)}return o}function h(t,e){return e[1]===e[e.length-1]}for(o=0;o<r;++o)for(var p=0;p<2;++p){for(var d=[];a[p][o].length>0;){a[0][o].length;var g=f(o,p);h(0,g)?d.push.apply(d,g):(d.length>0&&l.push(d),d=g)}d.length>0&&l.push(d)}return l};var n=t(\"compare-angle\")},{\"compare-angle\":132}],513:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=n(t,e.length),i=new Array(e.length),a=new Array(e.length),o=[],s=0;s<e.length;++s){var l=r[s].length;a[s]=l,i[s]=!0,l<=1&&o.push(s)}for(;o.length>0;){var c=o.pop();i[c]=!1;var u=r[c];for(s=0;s<u.length;++s){var f=u[s];0==--a[f]&&o.push(f)}}var h=new Array(e.length),p=[];for(s=0;s<e.length;++s)if(i[s]){c=p.length;h[s]=c,p.push(e[s])}else h[s]=-1;var d=[];for(s=0;s<t.length;++s){var g=t[s];i[g[0]]&&i[g[1]]&&d.push([h[g[0]],h[g[1]]])}return[d,p]};var n=t(\"edges-to-adjacency-list\")},{\"edges-to-adjacency-list\":178}],514:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=c(t,e);t=r[0];for(var f=(e=r[1]).length,h=(t.length,n(t,e.length)),p=0;p<f;++p)if(h[p].length%2==1)throw new Error(\"planar-graph-to-polyline: graph must be manifold\");var d=i(t,e);var g=(d=d.filter((function(t){for(var r=t.length,n=[0],i=0;i<r;++i){var a=e[t[i]],l=e[t[(i+1)%r]],c=o(-a[0],a[1]),u=o(-a[0],l[1]),f=o(l[0],a[1]),h=o(l[0],l[1]);n=s(n,s(s(c,u),s(f,h)))}return n[n.length-1]>0}))).length,m=new Array(g),v=new Array(g);for(p=0;p<g;++p){m[p]=p;var y=new Array(g),x=d[p].map((function(t){return e[t]})),b=a([x]),_=0;t:for(var w=0;w<g;++w)if(y[w]=0,p!==w){for(var T=(q=d[w]).length,k=0;k<T;++k){var M=b(e[q[k]]);if(0!==M){M<0&&(y[w]=1,_+=1);continue t}}y[w]=1,_+=1}v[p]=[_,p,y]}v.sort((function(t,e){return e[0]-t[0]}));for(p=0;p<g;++p){var A=(y=v[p])[1],S=y[2];for(w=0;w<g;++w)S[w]&&(m[w]=A)}var E=function(t){for(var e=new Array(t),r=0;r<t;++r)e[r]=[];return e}(g);for(p=0;p<g;++p)E[p].push(m[p]),E[m[p]].push(p);var C={},L=u(f,!1);for(p=0;p<g;++p)for(T=(q=d[p]).length,w=0;w<T;++w){var I=q[w],P=q[(w+1)%T],z=Math.min(I,P)+\":\"+Math.max(I,P);if(z in C){var O=C[z];E[O].push(p),E[p].push(O),L[I]=L[P]=!0}else C[z]=p}function D(t){for(var e=t.length,r=0;r<e;++r)if(!L[t[r]])return!1;return!0}var R=[],F=u(g,-1);for(p=0;p<g;++p)m[p]!==p||D(d[p])?F[p]=-1:(R.push(p),F[p]=0);r=[];for(;R.length>0;){var B=R.pop(),N=E[B];l(N,(function(t,e){return t-e}));var j,U=N.length,V=F[B];if(0===V){var q=d[B];j=[q]}for(p=0;p<U;++p){var H=N[p];if(!(F[H]>=0))if(F[H]=1^V,R.push(H),0===V)D(q=d[H])||(q.reverse(),j.push(q))}0===V&&r.push(j)}return r};var n=t(\"edges-to-adjacency-list\"),i=t(\"planar-dual\"),a=t(\"point-in-big-polygon\"),o=t(\"two-product\"),s=t(\"robust-sum\"),l=t(\"uniq\"),c=t(\"./lib/trim-leaves\");function u(t,e){for(var r=new Array(t),n=0;n<t;++n)r[n]=e;return r}},{\"./lib/trim-leaves\":513,\"edges-to-adjacency-list\":178,\"planar-dual\":512,\"point-in-big-polygon\":516,\"robust-sum\":553,\"two-product\":582,uniq:597}],515:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],516:[function(t,e,r){e.exports=function(t){for(var e=t.length,r=[],a=[],s=0;s<e;++s)for(var u=t[s],f=u.length,h=f-1,p=0;p<f;h=p++){var d=u[h],g=u[p];d[0]===g[0]?a.push([d,g]):r.push([d,g])}if(0===r.length)return 0===a.length?c:(m=l(a),function(t){return m(t[0],t[1])?0:1});var m;var v=i(r),y=function(t,e){return function(r){var i=o.le(e,r[0]);if(i<0)return 1;var a=t[i];if(!a){if(!(i>0&&e[i]===r[0]))return 1;a=t[i-1]}for(var s=1;a;){var l=a.key,c=n(r,l[0],l[1]);if(l[0][0]<l[1][0])if(c<0)a=a.left;else{if(!(c>0))return 0;s=-1,a=a.right}else if(c>0)a=a.left;else{if(!(c<0))return 0;s=1,a=a.right}}return s}}(v.slabs,v.coordinates);return 0===a.length?y:function(t,e){return function(r){return t(r[0],r[1])?0:e(r)}}(l(a),y)};var n=t(\"robust-orientation\")[3],i=t(\"slab-decomposition\"),a=t(\"interval-tree-1d\"),o=t(\"binary-search-bounds\");function s(){return!0}function l(t){for(var e={},r=0;r<t.length;++r){var n=t[r],i=n[0][0],o=n[0][1],l=n[1][1],c=[Math.min(o,l),Math.max(o,l)];i in e?e[i].push(c):e[i]=[c]}var u={},f=Object.keys(e);for(r=0;r<f.length;++r){var h=e[f[r]];u[f[r]]=a(h)}return function(t){return function(e,r){var n=t[e];return!!n&&!!n.queryPoint(r,s)}}(u)}function c(t){return 1}},{\"binary-search-bounds\":515,\"interval-tree-1d\":460,\"robust-orientation\":548,\"slab-decomposition\":565}],517:[function(t,e,r){\n",
       "/*\n",
       " * @copyright 2016 Sean Connelly (@voidqk), http://syntheti.cc\n",
       " * @license MIT\n",
       " * @preserve Project Home: https://github.com/voidqk/polybooljs\n",
       " */\n",
       "var n,i=t(\"./lib/build-log\"),a=t(\"./lib/epsilon\"),o=t(\"./lib/intersecter\"),s=t(\"./lib/segment-chainer\"),l=t(\"./lib/segment-selector\"),c=t(\"./lib/geojson\"),u=!1,f=a();function h(t,e,r){var i=n.segments(t),a=n.segments(e),o=r(n.combine(i,a));return n.polygon(o)}n={buildLog:function(t){return!0===t?u=i():!1===t&&(u=!1),!1!==u&&u.list},epsilon:function(t){return f.epsilon(t)},segments:function(t){var e=o(!0,f,u);return t.regions.forEach(e.addRegion),{segments:e.calculate(t.inverted),inverted:t.inverted}},combine:function(t,e){return{combined:o(!1,f,u).calculate(t.segments,t.inverted,e.segments,e.inverted),inverted1:t.inverted,inverted2:e.inverted}},selectUnion:function(t){return{segments:l.union(t.combined,u),inverted:t.inverted1||t.inverted2}},selectIntersect:function(t){return{segments:l.intersect(t.combined,u),inverted:t.inverted1&&t.inverted2}},selectDifference:function(t){return{segments:l.difference(t.combined,u),inverted:t.inverted1&&!t.inverted2}},selectDifferenceRev:function(t){return{segments:l.differenceRev(t.combined,u),inverted:!t.inverted1&&t.inverted2}},selectXor:function(t){return{segments:l.xor(t.combined,u),inverted:t.inverted1!==t.inverted2}},polygon:function(t){return{regions:s(t.segments,f,u),inverted:t.inverted}},polygonFromGeoJSON:function(t){return c.toPolygon(n,t)},polygonToGeoJSON:function(t){return c.fromPolygon(n,f,t)},union:function(t,e){return h(t,e,n.selectUnion)},intersect:function(t,e){return h(t,e,n.selectIntersect)},difference:function(t,e){return h(t,e,n.selectDifference)},differenceRev:function(t,e){return h(t,e,n.selectDifferenceRev)},xor:function(t,e){return h(t,e,n.selectXor)}},\"object\"==typeof window&&(window.PolyBool=n),e.exports=n},{\"./lib/build-log\":518,\"./lib/epsilon\":519,\"./lib/geojson\":520,\"./lib/intersecter\":521,\"./lib/segment-chainer\":523,\"./lib/segment-selector\":524}],518:[function(t,e,r){e.exports=function(){var t,e=0,r=!1;function n(e,r){return t.list.push({type:e,data:r?JSON.parse(JSON.stringify(r)):void 0}),t}return t={list:[],segmentId:function(){return e++},checkIntersection:function(t,e){return n(\"check\",{seg1:t,seg2:e})},segmentChop:function(t,e){return n(\"div_seg\",{seg:t,pt:e}),n(\"chop\",{seg:t,pt:e})},statusRemove:function(t){return n(\"pop_seg\",{seg:t})},segmentUpdate:function(t){return n(\"seg_update\",{seg:t})},segmentNew:function(t,e){return n(\"new_seg\",{seg:t,primary:e})},segmentRemove:function(t){return n(\"rem_seg\",{seg:t})},tempStatus:function(t,e,r){return n(\"temp_status\",{seg:t,above:e,below:r})},rewind:function(t){return n(\"rewind\",{seg:t})},status:function(t,e,r){return n(\"status\",{seg:t,above:e,below:r})},vert:function(e){return e===r?t:(r=e,n(\"vert\",{x:e}))},log:function(t){return\"string\"!=typeof t&&(t=JSON.stringify(t,!1,\"  \")),n(\"log\",{txt:t})},reset:function(){return n(\"reset\")},selected:function(t){return n(\"selected\",{segs:t})},chainStart:function(t){return n(\"chain_start\",{seg:t})},chainRemoveHead:function(t,e){return n(\"chain_rem_head\",{index:t,pt:e})},chainRemoveTail:function(t,e){return n(\"chain_rem_tail\",{index:t,pt:e})},chainNew:function(t,e){return n(\"chain_new\",{pt1:t,pt2:e})},chainMatch:function(t){return n(\"chain_match\",{index:t})},chainClose:function(t){return n(\"chain_close\",{index:t})},chainAddHead:function(t,e){return n(\"chain_add_head\",{index:t,pt:e})},chainAddTail:function(t,e){return n(\"chain_add_tail\",{index:t,pt:e})},chainConnect:function(t,e){return n(\"chain_con\",{index1:t,index2:e})},chainReverse:function(t){return n(\"chain_rev\",{index:t})},chainJoin:function(t,e){return n(\"chain_join\",{index1:t,index2:e})},done:function(){return n(\"done\")}}}},{}],519:[function(t,e,r){e.exports=function(t){\"number\"!=typeof t&&(t=1e-10);var e={epsilon:function(e){return\"number\"==typeof e&&(t=e),t},pointAboveOrOnLine:function(e,r,n){var i=r[0],a=r[1],o=n[0],s=n[1],l=e[0];return(o-i)*(e[1]-a)-(s-a)*(l-i)>=-t},pointBetween:function(e,r,n){var i=e[1]-r[1],a=n[0]-r[0],o=e[0]-r[0],s=n[1]-r[1],l=o*a+i*s;return!(l<t)&&!(l-(a*a+s*s)>-t)},pointsSameX:function(e,r){return Math.abs(e[0]-r[0])<t},pointsSameY:function(e,r){return Math.abs(e[1]-r[1])<t},pointsSame:function(t,r){return e.pointsSameX(t,r)&&e.pointsSameY(t,r)},pointsCompare:function(t,r){return e.pointsSameX(t,r)?e.pointsSameY(t,r)?0:t[1]<r[1]?-1:1:t[0]<r[0]?-1:1},pointsCollinear:function(e,r,n){var i=e[0]-r[0],a=e[1]-r[1],o=r[0]-n[0],s=r[1]-n[1];return Math.abs(i*s-o*a)<t},linesIntersect:function(e,r,n,i){var a=r[0]-e[0],o=r[1]-e[1],s=i[0]-n[0],l=i[1]-n[1],c=a*l-o*s;if(Math.abs(c)<t)return!1;var u=e[0]-n[0],f=e[1]-n[1],h=(s*f-l*u)/c,p=(a*f-o*u)/c,d={alongA:0,alongB:0,pt:[e[0]+h*a,e[1]+h*o]};return d.alongA=h<=-t?-2:h<t?-1:h-1<=-t?0:h-1<t?1:2,d.alongB=p<=-t?-2:p<t?-1:p-1<=-t?0:p-1<t?1:2,d},pointInsideRegion:function(e,r){for(var n=e[0],i=e[1],a=r[r.length-1][0],o=r[r.length-1][1],s=!1,l=0;l<r.length;l++){var c=r[l][0],u=r[l][1];u-i>t!=o-i>t&&(a-c)*(i-u)/(o-u)+c-n>t&&(s=!s),a=c,o=u}return s}};return e}},{}],520:[function(t,e,r){var n={toPolygon:function(t,e){function r(e){if(e.length<=0)return t.segments({inverted:!1,regions:[]});function r(e){var r=e.slice(0,e.length-1);return t.segments({inverted:!1,regions:[r]})}for(var n=r(e[0]),i=1;i<e.length;i++)n=t.selectDifference(t.combine(n,r(e[i])));return n}if(\"Polygon\"===e.type)return t.polygon(r(e.coordinates));if(\"MultiPolygon\"===e.type){for(var n=t.segments({inverted:!1,regions:[]}),i=0;i<e.coordinates.length;i++)n=t.selectUnion(t.combine(n,r(e.coordinates[i])));return t.polygon(n)}throw new Error(\"PolyBool: Cannot convert GeoJSON object to PolyBool polygon\")},fromPolygon:function(t,e,r){function n(t,r){return e.pointInsideRegion([.5*(t[0][0]+t[1][0]),.5*(t[0][1]+t[1][1])],r)}function i(t){return{region:t,children:[]}}r=t.polygon(t.segments(r));var a=i(null);function o(t,e){for(var r=0;r<t.children.length;r++){if(n(e,(s=t.children[r]).region))return void o(s,e)}var a=i(e);for(r=0;r<t.children.length;r++){var s;n((s=t.children[r]).region,e)&&(a.children.push(s),t.children.splice(r,1),r--)}t.children.push(a)}for(var s=0;s<r.regions.length;s++){var l=r.regions[s];l.length<3||o(a,l)}function c(t,e){for(var r=0,n=t[t.length-1][0],i=t[t.length-1][1],a=[],o=0;o<t.length;o++){var s=t[o][0],l=t[o][1];a.push([s,l]),r+=l*n-s*i,n=s,i=l}return r<0!==e&&a.reverse(),a.push([a[0][0],a[0][1]]),a}var u=[];function f(t){var e=[c(t.region,!1)];u.push(e);for(var r=0;r<t.children.length;r++)e.push(h(t.children[r]))}function h(t){for(var e=0;e<t.children.length;e++)f(t.children[e]);return c(t.region,!0)}for(s=0;s<a.children.length;s++)f(a.children[s]);return u.length<=0?{type:\"Polygon\",coordinates:[]}:1==u.length?{type:\"Polygon\",coordinates:u[0]}:{type:\"MultiPolygon\",coordinates:u}}};e.exports=n},{}],521:[function(t,e,r){var n=t(\"./linked-list\");e.exports=function(t,e,r){function i(t,e,n){return{id:r?r.segmentId():-1,start:t,end:e,myFill:{above:n.myFill.above,below:n.myFill.below},otherFill:null}}var a=n.create();function o(t,r){a.insertBefore(t,(function(n){return function(t,r,n,i,a,o){var s=e.pointsCompare(r,a);return 0!==s?s:e.pointsSame(n,o)?0:t!==i?t?1:-1:e.pointAboveOrOnLine(n,i?a:o,i?o:a)?1:-1}(t.isStart,t.pt,r,n.isStart,n.pt,n.other.pt)<0}))}function s(t,e){var r=function(t,e){var r=n.node({isStart:!0,pt:t.start,seg:t,primary:e,other:null,status:null});return o(r,t.end),r}(t,e);return function(t,e,r){var i=n.node({isStart:!1,pt:e.end,seg:e,primary:r,other:t,status:null});t.other=i,o(i,t.pt)}(r,t,e),r}function l(t,e){var n=i(e,t.seg.end,t.seg);return function(t,e){r&&r.segmentChop(t.seg,e),t.other.remove(),t.seg.end=e,t.other.pt=e,o(t.other,t.pt)}(t,e),s(n,t.primary)}function c(i,o){var s=n.create();function c(t){return s.findTransition((function(r){var n,i,a,o,s,l;return(n=t,i=r.ev,a=n.seg.start,o=n.seg.end,s=i.seg.start,l=i.seg.end,e.pointsCollinear(a,s,l)?e.pointsCollinear(o,s,l)||e.pointAboveOrOnLine(o,s,l)?1:-1:e.pointAboveOrOnLine(a,s,l)?1:-1)>0}))}function u(t,n){var i=t.seg,a=n.seg,o=i.start,s=i.end,c=a.start,u=a.end;r&&r.checkIntersection(i,a);var f=e.linesIntersect(o,s,c,u);if(!1===f){if(!e.pointsCollinear(o,s,c))return!1;if(e.pointsSame(o,u)||e.pointsSame(s,c))return!1;var h=e.pointsSame(o,c),p=e.pointsSame(s,u);if(h&&p)return n;var d=!h&&e.pointBetween(o,c,u),g=!p&&e.pointBetween(s,c,u);if(h)return g?l(n,s):l(t,u),n;d&&(p||(g?l(n,s):l(t,u)),l(n,o))}else 0===f.alongA&&(-1===f.alongB?l(t,c):0===f.alongB?l(t,f.pt):1===f.alongB&&l(t,u)),0===f.alongB&&(-1===f.alongA?l(n,o):0===f.alongA?l(n,f.pt):1===f.alongA&&l(n,s));return!1}for(var f=[];!a.isEmpty();){var h=a.getHead();if(r&&r.vert(h.pt[0]),h.isStart){r&&r.segmentNew(h.seg,h.primary);var p=c(h),d=p.before?p.before.ev:null,g=p.after?p.after.ev:null;function m(){if(d){var t=u(h,d);if(t)return t}return!!g&&u(h,g)}r&&r.tempStatus(h.seg,!!d&&d.seg,!!g&&g.seg);var v,y=m();if(y){var x;if(t)(x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below)&&(y.seg.myFill.above=!y.seg.myFill.above);else y.seg.otherFill=h.seg.myFill;r&&r.segmentUpdate(y.seg),h.other.remove(),h.remove()}if(a.getHead()!==h){r&&r.rewind(h.seg);continue}if(t)x=null===h.seg.myFill.below||h.seg.myFill.above!==h.seg.myFill.below,h.seg.myFill.below=g?g.seg.myFill.above:i,h.seg.myFill.above=x?!h.seg.myFill.below:h.seg.myFill.below;else if(null===h.seg.otherFill)v=g?h.primary===g.primary?g.seg.otherFill.above:g.seg.myFill.above:h.primary?o:i,h.seg.otherFill={above:v,below:v};r&&r.status(h.seg,!!d&&d.seg,!!g&&g.seg),h.other.status=p.insert(n.node({ev:h}))}else{var b=h.status;if(null===b)throw new Error(\"PolyBool: Zero-length segment detected; your epsilon is probably too small or too large\");if(s.exists(b.prev)&&s.exists(b.next)&&u(b.prev.ev,b.next.ev),r&&r.statusRemove(b.ev.seg),b.remove(),!h.primary){var _=h.seg.myFill;h.seg.myFill=h.seg.otherFill,h.seg.otherFill=_}f.push(h.seg)}a.getHead().remove()}return r&&r.done(),f}return t?{addRegion:function(t){for(var n,i,a,o=t[t.length-1],l=0;l<t.length;l++){n=o,o=t[l];var c=e.pointsCompare(n,o);0!==c&&s((i=c<0?n:o,a=c<0?o:n,{id:r?r.segmentId():-1,start:i,end:a,myFill:{above:null,below:null},otherFill:null}),!0)}},calculate:function(t){return c(t,!1)}}:{calculate:function(t,e,r,n){return t.forEach((function(t){s(i(t.start,t.end,t),!0)})),r.forEach((function(t){s(i(t.start,t.end,t),!1)})),c(e,n)}}}},{\"./linked-list\":522}],522:[function(t,e,r){e.exports={create:function(){var t={root:{root:!0,next:null},exists:function(e){return null!==e&&e!==t.root},isEmpty:function(){return null===t.root.next},getHead:function(){return t.root.next},insertBefore:function(e,r){for(var n=t.root,i=t.root.next;null!==i;){if(r(i))return e.prev=i.prev,e.next=i,i.prev.next=e,void(i.prev=e);n=i,i=i.next}n.next=e,e.prev=n,e.next=null},findTransition:function(e){for(var r=t.root,n=t.root.next;null!==n&&!e(n);)r=n,n=n.next;return{before:r===t.root?null:r,after:n,insert:function(t){return t.prev=r,t.next=n,r.next=t,null!==n&&(n.prev=t),t}}}};return t},node:function(t){return t.prev=null,t.next=null,t.remove=function(){t.prev.next=t.next,t.next&&(t.next.prev=t.prev),t.prev=null,t.next=null},t}}},{}],523:[function(t,e,r){e.exports=function(t,e,r){var n=[],i=[];return t.forEach((function(t){var a=t.start,o=t.end;if(e.pointsSame(a,o))console.warn(\"PolyBool: Warning: Zero-length segment detected; your epsilon is probably too small or too large\");else{r&&r.chainStart(t);for(var s={index:0,matches_head:!1,matches_pt1:!1},l={index:0,matches_head:!1,matches_pt1:!1},c=s,u=0;u<n.length;u++){var f=(m=n[u])[0],h=(m[1],m[m.length-1]);m[m.length-2];if(e.pointsSame(f,a)){if(k(u,!0,!0))break}else if(e.pointsSame(f,o)){if(k(u,!0,!1))break}else if(e.pointsSame(h,a)){if(k(u,!1,!0))break}else if(e.pointsSame(h,o)&&k(u,!1,!1))break}if(c===s)return n.push([a,o]),void(r&&r.chainNew(a,o));if(c===l){r&&r.chainMatch(s.index);var p=s.index,d=s.matches_pt1?o:a,g=s.matches_head,m=n[p],v=g?m[0]:m[m.length-1],y=g?m[1]:m[m.length-2],x=g?m[m.length-1]:m[0],b=g?m[m.length-2]:m[1];return e.pointsCollinear(y,v,d)&&(g?(r&&r.chainRemoveHead(s.index,d),m.shift()):(r&&r.chainRemoveTail(s.index,d),m.pop()),v=y),e.pointsSame(x,d)?(n.splice(p,1),e.pointsCollinear(b,x,v)&&(g?(r&&r.chainRemoveTail(s.index,v),m.pop()):(r&&r.chainRemoveHead(s.index,v),m.shift())),r&&r.chainClose(s.index),void i.push(m)):void(g?(r&&r.chainAddHead(s.index,d),m.unshift(d)):(r&&r.chainAddTail(s.index,d),m.push(d)))}var _=s.index,w=l.index;r&&r.chainConnect(_,w);var T=n[_].length<n[w].length;s.matches_head?l.matches_head?T?(M(_),A(_,w)):(M(w),A(w,_)):A(w,_):l.matches_head?A(_,w):T?(M(_),A(w,_)):(M(w),A(_,w))}function k(t,e,r){return c.index=t,c.matches_head=e,c.matches_pt1=r,c===s?(c=l,!1):(c=null,!0)}function M(t){r&&r.chainReverse(t),n[t].reverse()}function A(t,i){var a=n[t],o=n[i],s=a[a.length-1],l=a[a.length-2],c=o[0],u=o[1];e.pointsCollinear(l,s,c)&&(r&&r.chainRemoveTail(t,s),a.pop(),s=l),e.pointsCollinear(s,c,u)&&(r&&r.chainRemoveHead(i,c),o.shift()),r&&r.chainJoin(t,i),n[t]=a.concat(o),n.splice(i,1)}})),i}},{}],524:[function(t,e,r){function n(t,e,r){var n=[];return t.forEach((function(t){var i=(t.myFill.above?8:0)+(t.myFill.below?4:0)+(t.otherFill&&t.otherFill.above?2:0)+(t.otherFill&&t.otherFill.below?1:0);0!==e[i]&&n.push({id:r?r.segmentId():-1,start:t.start,end:t.end,myFill:{above:1===e[i],below:2===e[i]},otherFill:null})})),r&&r.selected(n),n}var i={union:function(t,e){return n(t,[0,2,1,0,2,2,0,0,1,0,1,0,0,0,0,0],e)},intersect:function(t,e){return n(t,[0,0,0,0,0,2,0,2,0,0,1,1,0,2,1,0],e)},difference:function(t,e){return n(t,[0,0,0,0,2,0,2,0,1,1,0,0,0,1,2,0],e)},differenceRev:function(t,e){return n(t,[0,2,1,0,0,0,1,1,0,2,0,2,0,0,0,0],e)},xor:function(t,e){return n(t,[0,2,1,0,2,0,0,1,1,0,0,2,0,1,2,0],e)}};e.exports=i},{}],525:[function(t,e,r){\"use strict\";var n=new Float64Array(4),i=new Float64Array(4),a=new Float64Array(4);e.exports=function(t,e,r,o,s){n.length<o.length&&(n=new Float64Array(o.length),i=new Float64Array(o.length),a=new Float64Array(o.length));for(var l=0;l<o.length;++l)n[l]=t[l]-o[l],i[l]=e[l]-t[l],a[l]=r[l]-t[l];var c=0,u=0,f=0,h=0,p=0,d=0;for(l=0;l<o.length;++l){var g=i[l],m=a[l],v=n[l];c+=g*g,u+=g*m,f+=m*m,h+=v*g,p+=v*m,d+=v*v}var y,x,b,_,w,T=Math.abs(c*f-u*u),k=u*p-f*h,M=u*h-c*p;if(k+M<=T)if(k<0)M<0&&h<0?(M=0,-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d):(k=0,p>=0?(M=0,y=d):-p>=f?(M=1,y=f+2*p+d):y=p*(M=-p/f)+d);else if(M<0)M=0,h>=0?(k=0,y=d):-h>=c?(k=1,y=c+2*h+d):y=h*(k=-h/c)+d;else{var A=1/T;y=(k*=A)*(c*k+u*(M*=A)+2*h)+M*(u*k+f*M+2*p)+d}else k<0?(b=f+p)>(x=u+h)?(_=b-x)>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d:(k=0,b<=0?(M=1,y=f+2*p+d):p>=0?(M=0,y=d):y=p*(M=-p/f)+d):M<0?(b=c+h)>(x=u+p)?(_=b-x)>=(w=c-2*u+f)?(M=1,k=0,y=f+2*p+d):y=(k=1-(M=_/w))*(c*k+u*M+2*h)+M*(u*k+f*M+2*p)+d:(M=0,b<=0?(k=1,y=c+2*h+d):h>=0?(k=0,y=d):y=h*(k=-h/c)+d):(_=f+p-u-h)<=0?(k=0,M=1,y=f+2*p+d):_>=(w=c-2*u+f)?(k=1,M=0,y=c+2*h+d):y=(k=_/w)*(c*k+u*(M=1-k)+2*h)+M*(u*k+f*M+2*p)+d;var S=1-k-M;for(l=0;l<o.length;++l)s[l]=S*t[l]+k*e[l]+M*r[l];return y<0?0:y}},{}],526:[function(t,e,r){var n,i,a=e.exports={};function o(){throw new Error(\"setTimeout has not been defined\")}function s(){throw new Error(\"clearTimeout has not been defined\")}function l(t){if(n===setTimeout)return setTimeout(t,0);if((n===o||!n)&&setTimeout)return n=setTimeout,setTimeout(t,0);try{return n(t,0)}catch(e){try{return n.call(null,t,0)}catch(e){return n.call(this,t,0)}}}!function(){try{n=\"function\"==typeof setTimeout?setTimeout:o}catch(t){n=o}try{i=\"function\"==typeof clearTimeout?clearTimeout:s}catch(t){i=s}}();var c,u=[],f=!1,h=-1;function p(){f&&c&&(f=!1,c.length?u=c.concat(u):h=-1,u.length&&d())}function d(){if(!f){var t=l(p);f=!0;for(var e=u.length;e;){for(c=u,u=[];++h<e;)c&&c[h].run();h=-1,e=u.length}c=null,f=!1,function(t){if(i===clearTimeout)return clearTimeout(t);if((i===s||!i)&&clearTimeout)return i=clearTimeout,clearTimeout(t);try{i(t)}catch(e){try{return i.call(null,t)}catch(e){return i.call(this,t)}}}(t)}}function g(t,e){this.fun=t,this.array=e}function m(){}a.nextTick=function(t){var e=new Array(arguments.length-1);if(arguments.length>1)for(var r=1;r<arguments.length;r++)e[r-1]=arguments[r];u.push(new g(t,e)),1!==u.length||f||l(d)},g.prototype.run=function(){this.fun.apply(null,this.array)},a.title=\"browser\",a.browser=!0,a.env={},a.argv=[],a.version=\"\",a.versions={},a.on=m,a.addListener=m,a.once=m,a.off=m,a.removeListener=m,a.removeAllListeners=m,a.emit=m,a.prependListener=m,a.prependOnceListener=m,a.listeners=function(t){return[]},a.binding=function(t){throw new Error(\"process.binding is not supported\")},a.cwd=function(){return\"/\"},a.chdir=function(t){throw new Error(\"process.chdir is not supported\")},a.umask=function(){return 0}},{}],527:[function(t,e,r){e.exports=t(\"gl-quat/slerp\")},{\"gl-quat/slerp\":325}],528:[function(t,e,r){(function(r){(function(){for(var n=t(\"performance-now\"),i=\"undefined\"==typeof window?r:window,a=[\"moz\",\"webkit\"],o=\"AnimationFrame\",s=i[\"request\"+o],l=i[\"cancel\"+o]||i[\"cancelRequest\"+o],c=0;!s&&c<a.length;c++)s=i[a[c]+\"Request\"+o],l=i[a[c]+\"Cancel\"+o]||i[a[c]+\"CancelRequest\"+o];if(!s||!l){var u=0,f=0,h=[];s=function(t){if(0===h.length){var e=n(),r=Math.max(0,1e3/60-(e-u));u=r+e,setTimeout((function(){var t=h.slice(0);h.length=0;for(var e=0;e<t.length;e++)if(!t[e].cancelled)try{t[e].callback(u)}catch(t){setTimeout((function(){throw t}),0)}}),Math.round(r))}return h.push({handle:++f,callback:t,cancelled:!1}),f},l=function(t){for(var e=0;e<h.length;e++)h[e].handle===t&&(h[e].cancelled=!0)}}e.exports=function(t){return s.call(i,t)},e.exports.cancel=function(){l.apply(i,arguments)},e.exports.polyfill=function(t){t||(t=i),t.requestAnimationFrame=s,t.cancelAnimationFrame=l}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"performance-now\":508}],529:[function(t,e,r){\"use strict\";var n=t(\"big-rat/add\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/add\":80}],530:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=new Array(t.length),r=0;r<t.length;++r)e[r]=n(t[r]);return e};var n=t(\"big-rat\")},{\"big-rat\":83}],531:[function(t,e,r){\"use strict\";var n=t(\"big-rat\"),i=t(\"big-rat/mul\");e.exports=function(t,e){for(var r=n(e),a=t.length,o=new Array(a),s=0;s<a;++s)o[s]=i(t[s],r);return o}},{\"big-rat\":83,\"big-rat/mul\":92}],532:[function(t,e,r){\"use strict\";var n=t(\"big-rat/sub\");e.exports=function(t,e){for(var r=t.length,i=new Array(r),a=0;a<r;++a)i[a]=n(t[a],e[a]);return i}},{\"big-rat/sub\":94}],533:[function(t,e,r){\"use strict\";var n=t(\"compare-cell\"),i=t(\"compare-oriented-cell\"),a=t(\"cell-orientation\");e.exports=function(t){t.sort(i);for(var e=t.length,r=0,o=0;o<e;++o){var s=t[o],l=a(s);if(0!==l){if(r>0){var c=t[r-1];if(0===n(s,c)&&a(c)!==l){r-=1;continue}}t[r++]=s}}return t.length=r,t}},{\"cell-orientation\":117,\"compare-cell\":133,\"compare-oriented-cell\":134}],534:[function(t,e,r){\"use strict\";var n=t(\"array-bounds\"),i=t(\"color-normalize\"),a=t(\"update-diff\"),o=t(\"pick-by-alias\"),s=t(\"object-assign\"),l=t(\"flatten-vertex-data\"),c=t(\"to-float32\"),u=c.float32,f=c.fract32;e.exports=function(t,e){\"function\"==typeof t?(e||(e={}),e.regl=t):e=t;e.length&&(e.positions=e);if(!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");var r,c,p,d,g,m,v=t._gl,y={color:\"black\",capSize:5,lineWidth:1,opacity:1,viewport:null,range:null,offset:0,count:0,bounds:null,positions:[],errors:[]},x=[];return d=t.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array(0)}),c=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),p=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),g=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)}),m=t.buffer({usage:\"static\",type:\"float\",data:h}),T(e),r=t({vert:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tattribute vec2 position, positionFract;\\n\\t\\tattribute vec4 error;\\n\\t\\tattribute vec4 color;\\n\\n\\t\\tattribute vec2 direction, lineOffset, capOffset;\\n\\n\\t\\tuniform vec4 viewport;\\n\\t\\tuniform float lineWidth, capSize;\\n\\t\\tuniform vec2 scale, scaleFract, translate, translateFract;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tfragColor = color / 255.;\\n\\n\\t\\t\\tvec2 pixelOffset = lineWidth * lineOffset + (capSize + lineWidth) * capOffset;\\n\\n\\t\\t\\tvec2 dxy = -step(.5, direction.xy) * error.xz + step(direction.xy, vec2(-.5)) * error.yw;\\n\\n\\t\\t\\tvec2 position = position + dxy;\\n\\n\\t\\t\\tvec2 pos = (position + translate) * scale\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scale\\n\\t\\t\\t\\t+ (position + translate) * scaleFract\\n\\t\\t\\t\\t+ (positionFract + translateFract) * scaleFract;\\n\\n\\t\\t\\tpos += pixelOffset / viewport.zw;\\n\\n\\t\\t\\tgl_Position = vec4(pos * 2. - 1., 0, 1);\\n\\t\\t}\\n\\t\\t\",frag:\"\\n\\t\\tprecision highp float;\\n\\n\\t\\tvarying vec4 fragColor;\\n\\n\\t\\tuniform float opacity;\\n\\n\\t\\tvoid main() {\\n\\t\\t\\tgl_FragColor = fragColor;\\n\\t\\t\\tgl_FragColor.a *= opacity;\\n\\t\\t}\\n\\t\\t\",uniforms:{range:t.prop(\"range\"),lineWidth:t.prop(\"lineWidth\"),capSize:t.prop(\"capSize\"),opacity:t.prop(\"opacity\"),scale:t.prop(\"scale\"),translate:t.prop(\"translate\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{color:{buffer:d,offset:function(t,e){return 4*e.offset},divisor:1},position:{buffer:c,offset:function(t,e){return 8*e.offset},divisor:1},positionFract:{buffer:p,offset:function(t,e){return 8*e.offset},divisor:1},error:{buffer:g,offset:function(t,e){return 16*e.offset},divisor:1},direction:{buffer:m,stride:24,offset:0},lineOffset:{buffer:m,stride:24,offset:8},capOffset:{buffer:m,stride:24,offset:16}},primitive:\"triangles\",blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:!1,instances:t.prop(\"count\"),count:h.length}),s(b,{update:T,draw:_,destroy:k,regl:t,gl:v,canvas:v.canvas,groups:x}),b;function b(t){t?T(t):null===t&&k(),_()}function _(e){if(\"number\"==typeof e)return w(e);e&&!Array.isArray(e)&&(e=[e]),t._refresh(),x.forEach((function(t,r){t&&(e&&(e[r]?t.draw=!0:t.draw=!1),t.draw?w(r):t.draw=!0)}))}function w(t){\"number\"==typeof t&&(t=x[t]),null!=t&&t&&t.count&&t.color&&t.opacity&&t.positions&&t.positions.length>1&&(t.scaleRatio=[t.scale[0]*t.viewport.width,t.scale[1]*t.viewport.height],r(t),t.after&&t.after(t))}function T(t){if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var e=0,r=0;if(b.groups=x=t.map((function(t,c){var u=x[c];return t?(\"function\"==typeof t?t={after:t}:\"number\"==typeof t[0]&&(t={positions:t}),t=o(t,{color:\"color colors fill\",capSize:\"capSize cap capsize cap-size\",lineWidth:\"lineWidth line-width width line thickness\",opacity:\"opacity alpha\",range:\"range dataBox\",viewport:\"viewport viewBox\",errors:\"errors error\",positions:\"positions position data points\"}),u||(x[c]=u={id:c,scale:null,translate:null,scaleFract:null,translateFract:null,draw:!0},t=s({},y,t)),a(u,t,[{lineWidth:function(t){return.5*+t},capSize:function(t){return.5*+t},opacity:parseFloat,errors:function(t){return t=l(t),r+=t.length,t},positions:function(t,r){return t=l(t,\"float64\"),r.count=Math.floor(t.length/2),r.bounds=n(t,2),r.offset=e,e+=r.count,t}},{color:function(t,e){var r=e.count;if(t||(t=\"transparent\"),!Array.isArray(t)||\"number\"==typeof t[0]){var n=t;t=Array(r);for(var a=0;a<r;a++)t[a]=n}if(t.length<r)throw Error(\"Not enough colors\");for(var o=new Uint8Array(4*r),s=0;s<r;s++){var l=i(t[s],\"uint8\");o.set(l,4*s)}return o},range:function(t,e,r){var n=e.bounds;return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=f(e.scale),e.translateFract=f(e.translate),t},viewport:function(t){var e;return Array.isArray(t)?e={x:t[0],y:t[1],width:t[2]-t[0],height:t[3]-t[1]}:t?(e={x:t.x||t.left||0,y:t.y||t.top||0},t.right?e.width=t.right-e.x:e.width=t.w||t.width||0,t.bottom?e.height=t.bottom-e.y:e.height=t.h||t.height||0):e={x:0,y:0,width:v.drawingBufferWidth,height:v.drawingBufferHeight},e}}]),u):u})),e||r){var h=x.reduce((function(t,e,r){return t+(e?e.count:0)}),0),m=new Float64Array(2*h),_=new Uint8Array(4*h),w=new Float32Array(4*h);x.forEach((function(t,e){if(t){var r=t.positions,n=t.count,i=t.offset,a=t.color,o=t.errors;n&&(_.set(a,4*i),w.set(o,4*i),m.set(r,2*i))}})),c(u(m)),p(f(m)),d(_),g(w)}}}function k(){c.destroy(),p.destroy(),d.destroy(),g.destroy(),m.destroy()}};var h=[[1,0,0,1,0,0],[1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,-1,0,0],[-1,0,0,1,0,0],[1,0,0,1,0,0],[1,0,-1,0,0,1],[1,0,-1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,-1],[1,0,1,0,0,1],[1,0,-1,0,0,1],[-1,0,-1,0,0,1],[-1,0,-1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,-1],[-1,0,1,0,0,1],[-1,0,-1,0,0,1],[0,1,1,0,0,0],[0,1,-1,0,0,0],[0,-1,-1,0,0,0],[0,-1,-1,0,0,0],[0,1,1,0,0,0],[0,-1,1,0,0,0],[0,1,0,-1,1,0],[0,1,0,-1,-1,0],[0,1,0,1,-1,0],[0,1,0,1,1,0],[0,1,0,-1,1,0],[0,1,0,1,-1,0],[0,-1,0,-1,1,0],[0,-1,0,-1,-1,0],[0,-1,0,1,-1,0],[0,-1,0,1,1,0],[0,-1,0,-1,1,0],[0,-1,0,1,-1,0]]},{\"array-bounds\":70,\"color-normalize\":125,\"flatten-vertex-data\":244,\"object-assign\":499,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],535:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\"),i=t(\"array-bounds\"),a=t(\"object-assign\"),o=t(\"glslify\"),s=t(\"pick-by-alias\"),l=t(\"flatten-vertex-data\"),c=t(\"earcut\"),u=t(\"array-normalize\"),f=t(\"to-float32\"),h=f.float32,p=f.fract32,d=t(\"es6-weak-map\"),g=t(\"parse-rect\");function m(t,e){if(!(this instanceof m))return new m(t,e);if(\"function\"==typeof t?(e||(e={}),e.regl=t):e=t,e.length&&(e.positions=e),!(t=e.regl).hasExtension(\"ANGLE_instanced_arrays\"))throw Error(\"regl-error2d: `ANGLE_instanced_arrays` extension should be enabled\");this.gl=t._gl,this.regl=t,this.passes=[],this.shaders=m.shaders.has(t)?m.shaders.get(t):m.shaders.set(t,m.createShaders(t)).get(t),this.update(e)}e.exports=m,m.dashMult=2,m.maxPatternLength=256,m.precisionThreshold=3e6,m.maxPoints=1e4,m.maxLines=2048,m.shaders=new d,m.createShaders=function(t){var e,r=t.buffer({usage:\"static\",type:\"float\",data:[0,1,0,0,1,1,1,0]}),n={primitive:\"triangle strip\",instances:t.prop(\"count\"),count:4,offset:0,uniforms:{miterMode:function(t,e){return\"round\"===e.join?2:1},miterLimit:t.prop(\"miterLimit\"),scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),thickness:t.prop(\"thickness\"),dashPattern:t.prop(\"dashTexture\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),dashSize:t.prop(\"dashLength\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]},depth:t.prop(\"depth\")},blend:{enable:!0,color:[0,0,0,0],equation:{rgb:\"add\",alpha:\"add\"},func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},depth:{enable:function(t,e){return!e.overlay}},stencil:{enable:!1},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\")},i=t(a({vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, aCoordFract, bCoordFract;\\nattribute vec4 color;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvec2 project(vec2 position, vec2 positionFract, vec2 scale, vec2 scaleFract, vec2 translate, vec2 translateFract) {\\n\\t// the order is important\\n\\treturn position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n}\\n\\nvoid main() {\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineOffset = lineTop * 2. - 1.;\\n\\n\\tvec2 diff = (bCoord + bCoordFract - aCoord - aCoordFract);\\n\\ttangent = normalize(diff * scale * viewport.zw);\\n\\tvec2 normal = vec2(-tangent.y, tangent.x);\\n\\n\\tvec2 position = project(aCoord, aCoordFract, scale, scaleFract, translate, translateFract) * lineStart\\n\\t\\t+ project(bCoord, bCoordFract, scale, scaleFract, translate, translateFract) * lineEnd\\n\\n\\t\\t+ thickness * normal * .5 * lineOffset / viewport.zw;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\n\\nuniform float dashSize, pixelRatio, thickness, opacity, id;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\n\\nvoid main() {\\n\\tfloat alpha = 1.;\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},aCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8,divisor:1},bCoordFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:16,divisor:1},color:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1}}},n));try{e=t(a({cull:{enable:!0,face:\"back\"},vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 aCoord, bCoord, nextCoord, prevCoord;\\nattribute vec4 aColor, bColor;\\nattribute float lineEnd, lineTop;\\n\\nuniform vec2 scale, translate;\\nuniform float thickness, pixelRatio, id, depth;\\nuniform vec4 viewport;\\nuniform float miterLimit, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 tangent;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nconst float REVERSE_THRESHOLD = -.875;\\nconst float MIN_DIFF = 1e-6;\\n\\n// TODO: possible optimizations: avoid overcalculating all for vertices and calc just one instead\\n// TODO: precalculate dot products, normalize things beforehead etc.\\n// TODO: refactor to rectangular algorithm\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nbool isNaN( float val ){\\n  return ( val < 0.0 || 0.0 < val || val == 0.0 ) ? false : true;\\n}\\n\\nvoid main() {\\n\\tvec2 aCoord = aCoord, bCoord = bCoord, prevCoord = prevCoord, nextCoord = nextCoord;\\n\\n  vec2 adjustedScale;\\n  adjustedScale.x = (abs(scale.x) < MIN_DIFF) ? MIN_DIFF : scale.x;\\n  adjustedScale.y = (abs(scale.y) < MIN_DIFF) ? MIN_DIFF : scale.y;\\n\\n  vec2 scaleRatio = adjustedScale * viewport.zw;\\n\\tvec2 normalWidth = thickness / scaleRatio;\\n\\n\\tfloat lineStart = 1. - lineEnd;\\n\\tfloat lineBot = 1. - lineTop;\\n\\n\\tfragColor = (lineStart * aColor + lineEnd * bColor) / 255.;\\n\\n\\tif (isNaN(aCoord.x) || isNaN(aCoord.y) || isNaN(bCoord.x) || isNaN(bCoord.y)) return;\\n\\n\\tif (aCoord == prevCoord) prevCoord = aCoord + normalize(bCoord - aCoord);\\n\\tif (bCoord == nextCoord) nextCoord = bCoord - normalize(bCoord - aCoord);\\n\\n\\tvec2 prevDiff = aCoord - prevCoord;\\n\\tvec2 currDiff = bCoord - aCoord;\\n\\tvec2 nextDiff = nextCoord - bCoord;\\n\\n\\tvec2 prevTangent = normalize(prevDiff * scaleRatio);\\n\\tvec2 currTangent = normalize(currDiff * scaleRatio);\\n\\tvec2 nextTangent = normalize(nextDiff * scaleRatio);\\n\\n\\tvec2 prevNormal = vec2(-prevTangent.y, prevTangent.x);\\n\\tvec2 currNormal = vec2(-currTangent.y, currTangent.x);\\n\\tvec2 nextNormal = vec2(-nextTangent.y, nextTangent.x);\\n\\n\\tvec2 startJoinDirection = normalize(prevTangent - currTangent);\\n\\tvec2 endJoinDirection = normalize(currTangent - nextTangent);\\n\\n\\t// collapsed/unidirectional segment cases\\n\\t// FIXME: there should be more elegant solution\\n\\tvec2 prevTanDiff = abs(prevTangent - currTangent);\\n\\tvec2 nextTanDiff = abs(nextTangent - currTangent);\\n\\tif (max(prevTanDiff.x, prevTanDiff.y) < MIN_DIFF) {\\n\\t\\tstartJoinDirection = currNormal;\\n\\t}\\n\\tif (max(nextTanDiff.x, nextTanDiff.y) < MIN_DIFF) {\\n\\t\\tendJoinDirection = currNormal;\\n\\t}\\n\\tif (aCoord == bCoord) {\\n\\t\\tendJoinDirection = startJoinDirection;\\n\\t\\tcurrNormal = prevNormal;\\n\\t\\tcurrTangent = prevTangent;\\n\\t}\\n\\n\\ttangent = currTangent;\\n\\n\\t//calculate join shifts relative to normals\\n\\tfloat startJoinShift = dot(currNormal, startJoinDirection);\\n\\tfloat endJoinShift = dot(currNormal, endJoinDirection);\\n\\n\\tfloat startMiterRatio = abs(1. / startJoinShift);\\n\\tfloat endMiterRatio = abs(1. / endJoinShift);\\n\\n\\tvec2 startJoin = startJoinDirection * startMiterRatio;\\n\\tvec2 endJoin = endJoinDirection * endMiterRatio;\\n\\n\\tvec2 startTopJoin, startBotJoin, endTopJoin, endBotJoin;\\n\\tstartTopJoin = sign(startJoinShift) * startJoin * .5;\\n\\tstartBotJoin = -startTopJoin;\\n\\n\\tendTopJoin = sign(endJoinShift) * endJoin * .5;\\n\\tendBotJoin = -endTopJoin;\\n\\n\\tvec2 aTopCoord = aCoord + normalWidth * startTopJoin;\\n\\tvec2 bTopCoord = bCoord + normalWidth * endTopJoin;\\n\\tvec2 aBotCoord = aCoord + normalWidth * startBotJoin;\\n\\tvec2 bBotCoord = bCoord + normalWidth * endBotJoin;\\n\\n\\t//miter anti-clipping\\n\\tfloat baClipping = distToLine(bCoord, aCoord, aBotCoord) / dot(normalize(normalWidth * endBotJoin), normalize(normalWidth.yx * vec2(-startBotJoin.y, startBotJoin.x)));\\n\\tfloat abClipping = distToLine(aCoord, bCoord, bTopCoord) / dot(normalize(normalWidth * startBotJoin), normalize(normalWidth.yx * vec2(-endBotJoin.y, endBotJoin.x)));\\n\\n\\t//prevent close to reverse direction switch\\n\\tbool prevReverse = dot(currTangent, prevTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, prevNormal)) * min(length(prevDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\tbool nextReverse = dot(currTangent, nextTangent) <= REVERSE_THRESHOLD && abs(dot(currTangent, nextNormal)) * min(length(nextDiff), length(currDiff)) <  length(normalWidth * currNormal);\\n\\n\\tif (prevReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * startJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / startMiterRatio, 1.);\\n\\t\\taBotCoord = aCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\taTopCoord = aCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!nextReverse && baClipping > 0. && baClipping < length(normalWidth * endBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\tbTopCoord -= normalWidth * endTopJoin;\\n\\t\\tbTopCoord += normalize(endTopJoin * normalWidth) * baClipping;\\n\\t}\\n\\n\\tif (nextReverse) {\\n\\t\\t//make join rectangular\\n\\t\\tvec2 miterShift = normalWidth * endJoinDirection * miterLimit * .5;\\n\\t\\tfloat normalAdjust = 1. - min(miterLimit / endMiterRatio, 1.);\\n\\t\\tbBotCoord = bCoord + miterShift - normalAdjust * normalWidth * currNormal * .5;\\n\\t\\tbTopCoord = bCoord + miterShift + normalAdjust * normalWidth * currNormal * .5;\\n\\t}\\n\\telse if (!prevReverse && abClipping > 0. && abClipping < length(normalWidth * startBotJoin)) {\\n\\t\\t//handle miter clipping\\n\\t\\taBotCoord -= normalWidth * startBotJoin;\\n\\t\\taBotCoord += normalize(startBotJoin * normalWidth) * abClipping;\\n\\t}\\n\\n\\tvec2 aTopPosition = (aTopCoord) * adjustedScale + translate;\\n\\tvec2 aBotPosition = (aBotCoord) * adjustedScale + translate;\\n\\n\\tvec2 bTopPosition = (bTopCoord) * adjustedScale + translate;\\n\\tvec2 bBotPosition = (bBotCoord) * adjustedScale + translate;\\n\\n\\t//position is normalized 0..1 coord on the screen\\n\\tvec2 position = (aTopPosition * lineTop + aBotPosition * lineBot) * lineStart + (bTopPosition * lineTop + bBotPosition * lineBot) * lineEnd;\\n\\n\\tstartCoord = aCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\tendCoord = bCoord * scaleRatio + translate * viewport.zw + viewport.xy;\\n\\n\\tgl_Position = vec4(position  * 2.0 - 1.0, depth, 1);\\n\\n\\tenableStartMiter = step(dot(currTangent, prevTangent), .5);\\n\\tenableEndMiter = step(dot(currTangent, nextTangent), .5);\\n\\n\\t//bevel miter cutoffs\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * miterLimit * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n\\n\\t//round miter cutoffs\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tvec2 startMiterWidth = vec2(startJoinDirection) * thickness * abs(dot(startJoinDirection, currNormal)) * .5;\\n\\t\\t\\tstartCutoff = vec4(aCoord, aCoord);\\n\\t\\t\\tstartCutoff.zw += vec2(-startJoinDirection.y, startJoinDirection.x) / scaleRatio;\\n\\t\\t\\tstartCutoff = startCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tstartCutoff += viewport.xyxy;\\n\\t\\t\\tstartCutoff += startMiterWidth.xyxy;\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tvec2 endMiterWidth = vec2(endJoinDirection) * thickness * abs(dot(endJoinDirection, currNormal)) * .5;\\n\\t\\t\\tendCutoff = vec4(bCoord, bCoord);\\n\\t\\t\\tendCutoff.zw += vec2(-endJoinDirection.y, endJoinDirection.x)  / scaleRatio;\\n\\t\\t\\tendCutoff = endCutoff * scaleRatio.xyxy + translate.xyxy * viewport.zwzw;\\n\\t\\t\\tendCutoff += viewport.xyxy;\\n\\t\\t\\tendCutoff += endMiterWidth.xyxy;\\n\\t\\t}\\n\\t}\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nuniform sampler2D dashPattern;\\nuniform float dashSize, pixelRatio, thickness, opacity, id, miterMode;\\n\\nvarying vec4 fragColor;\\nvarying vec2 tangent;\\nvarying vec4 startCutoff, endCutoff;\\nvarying vec2 startCoord, endCoord;\\nvarying float enableStartMiter, enableEndMiter;\\n\\nfloat distToLine(vec2 p, vec2 a, vec2 b) {\\n\\tvec2 diff = b - a;\\n\\tvec2 perp = normalize(vec2(-diff.y, diff.x));\\n\\treturn dot(p - a, perp);\\n}\\n\\nvoid main() {\\n\\tfloat alpha = 1., distToStart, distToEnd;\\n\\tfloat cutoff = thickness * .5;\\n\\n\\t//bevel miter\\n\\tif (miterMode == 1.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToStart + 1., 0.), 1.);\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < -1.) {\\n\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\treturn;\\n\\t\\t\\t}\\n\\t\\t\\talpha *= min(max(distToEnd + 1., 0.), 1.);\\n\\t\\t}\\n\\t}\\n\\n\\t// round miter\\n\\telse if (miterMode == 2.) {\\n\\t\\tif (enableStartMiter == 1.) {\\n\\t\\t\\tdistToStart = distToLine(gl_FragCoord.xy, startCutoff.xy, startCutoff.zw);\\n\\t\\t\\tif (distToStart < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - startCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\n\\t\\tif (enableEndMiter == 1.) {\\n\\t\\t\\tdistToEnd = distToLine(gl_FragCoord.xy, endCutoff.xy, endCutoff.zw);\\n\\t\\t\\tif (distToEnd < 0.) {\\n\\t\\t\\t\\tfloat radius = length(gl_FragCoord.xy - endCoord);\\n\\n\\t\\t\\t\\tif(radius > cutoff + .5) {\\n\\t\\t\\t\\t\\tdiscard;\\n\\t\\t\\t\\t\\treturn;\\n\\t\\t\\t\\t}\\n\\n\\t\\t\\t\\talpha -= smoothstep(cutoff - .5, cutoff + .5, radius);\\n\\t\\t\\t}\\n\\t\\t}\\n\\t}\\n\\n\\tfloat t = fract(dot(tangent, gl_FragCoord.xy) / dashSize) * .5 + .25;\\n\\tfloat dash = texture2D(dashPattern, vec2(t, .5)).r;\\n\\n\\tgl_FragColor = fragColor;\\n\\tgl_FragColor.a *= alpha * opacity * dash;\\n}\\n\"]),attributes:{lineEnd:{buffer:r,divisor:0,stride:8,offset:0},lineTop:{buffer:r,divisor:0,stride:8,offset:4},aColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:0,divisor:1},bColor:{buffer:t.prop(\"colorBuffer\"),stride:4,offset:4,divisor:1},prevCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:0,divisor:1},aCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8,divisor:1},bCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:16,divisor:1},nextCoord:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:24,divisor:1}}},n))}catch(t){e=i}return{fill:t({primitive:\"triangle\",elements:function(t,e){return e.triangles},offset:0,vert:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute vec2 position, positionFract;\\n\\nuniform vec4 color;\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio, id;\\nuniform vec4 viewport;\\nuniform float opacity;\\n\\nvarying vec4 fragColor;\\n\\nconst float MAX_LINES = 256.;\\n\\nvoid main() {\\n\\tfloat depth = (MAX_LINES - 4. - id) / (MAX_LINES);\\n\\n\\tvec2 position = position * scale + translate\\n       + positionFract * scale + translateFract\\n       + position * scaleFract\\n       + positionFract * scaleFract;\\n\\n\\tgl_Position = vec4(position * 2.0 - 1.0, depth, 1);\\n\\n\\tfragColor = color / 255.;\\n\\tfragColor.a *= opacity;\\n}\\n\"]),frag:o([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n\\tgl_FragColor = fragColor;\\n}\\n\"]),uniforms:{scale:t.prop(\"scale\"),color:t.prop(\"fill\"),scaleFract:t.prop(\"scaleFract\"),translateFract:t.prop(\"translateFract\"),translate:t.prop(\"translate\"),opacity:t.prop(\"opacity\"),pixelRatio:t.context(\"pixelRatio\"),id:t.prop(\"id\"),viewport:function(t,e){return[e.viewport.x,e.viewport.y,t.viewportWidth,t.viewportHeight]}},attributes:{position:{buffer:t.prop(\"positionBuffer\"),stride:8,offset:8},positionFract:{buffer:t.prop(\"positionFractBuffer\"),stride:8,offset:8}},blend:n.blend,depth:{enable:!1},scissor:n.scissor,stencil:n.stencil,viewport:n.viewport}),rect:i,miter:e}},m.defaults={dashes:null,join:\"miter\",miterLimit:1,thickness:10,cap:\"square\",color:\"black\",opacity:1,overlay:!1,viewport:null,range:null,close:!1,fill:null},m.prototype.render=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];e.length&&(t=this).update.apply(t,e),this.draw()},m.prototype.draw=function(){for(var t=this,e=[],r=arguments.length;r--;)e[r]=arguments[r];return(e.length?e:this.passes).forEach((function(e,r){var n;if(e&&Array.isArray(e))return(n=t).draw.apply(n,e);\"number\"==typeof e&&(e=t.passes[e]),e&&e.count>1&&e.opacity&&(t.regl._refresh(),e.fill&&e.triangles&&e.triangles.length>2&&t.shaders.fill(e),e.thickness&&(e.scale[0]*e.viewport.width>m.precisionThreshold||e.scale[1]*e.viewport.height>m.precisionThreshold||\"rect\"===e.join||!e.join&&(e.thickness<=2||e.count>=m.maxPoints)?t.shaders.rect(e):t.shaders.miter(e)))})),this},m.prototype.update=function(t){var e=this;if(t){null!=t.length?\"number\"==typeof t[0]&&(t=[{positions:t}]):Array.isArray(t)||(t=[t]);var r=this.regl,o=this.gl;if(t.forEach((function(t,f){var d=e.passes[f];if(void 0!==t)if(null!==t){if(\"number\"==typeof t[0]&&(t={positions:t}),t=s(t,{positions:\"positions points data coords\",thickness:\"thickness lineWidth lineWidths line-width linewidth width stroke-width strokewidth strokeWidth\",join:\"lineJoin linejoin join type mode\",miterLimit:\"miterlimit miterLimit\",dashes:\"dash dashes dasharray dash-array dashArray\",color:\"color colour stroke colors colours stroke-color strokeColor\",fill:\"fill fill-color fillColor\",opacity:\"alpha opacity\",overlay:\"overlay crease overlap intersect\",close:\"closed close closed-path closePath\",range:\"range dataBox\",viewport:\"viewport viewBox\",hole:\"holes hole hollow\"}),d||(e.passes[f]=d={id:f,scale:null,scaleFract:null,translate:null,translateFract:null,count:0,hole:[],depth:0,dashLength:1,dashTexture:r.texture({channels:1,data:new Uint8Array([255]),width:1,height:1,mag:\"linear\",min:\"linear\"}),colorBuffer:r.buffer({usage:\"dynamic\",type:\"uint8\",data:new Uint8Array}),positionBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),positionFractBuffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array})},t=a({},m.defaults,t)),null!=t.thickness&&(d.thickness=parseFloat(t.thickness)),null!=t.opacity&&(d.opacity=parseFloat(t.opacity)),null!=t.miterLimit&&(d.miterLimit=parseFloat(t.miterLimit)),null!=t.overlay&&(d.overlay=!!t.overlay,f<m.maxLines&&(d.depth=2*(m.maxLines-1-f%m.maxLines)/m.maxLines-1)),null!=t.join&&(d.join=t.join),null!=t.hole&&(d.hole=t.hole),null!=t.fill&&(d.fill=t.fill?n(t.fill,\"uint8\"):null),null!=t.viewport&&(d.viewport=g(t.viewport)),d.viewport||(d.viewport=g([o.drawingBufferWidth,o.drawingBufferHeight])),null!=t.close&&(d.close=t.close),null===t.positions&&(t.positions=[]),t.positions){var v,y;if(t.positions.x&&t.positions.y){var x=t.positions.x,b=t.positions.y;y=d.count=Math.max(x.length,b.length),v=new Float64Array(2*y);for(var _=0;_<y;_++)v[2*_]=x[_],v[2*_+1]=b[_]}else v=l(t.positions,\"float64\"),y=d.count=Math.floor(v.length/2);var w=d.bounds=i(v,2);if(d.fill){for(var T=[],k={},M=0,A=0,S=0,E=d.count;A<E;A++){var C=v[2*A],L=v[2*A+1];isNaN(C)||isNaN(L)||null==C||null==L?(C=v[2*M],L=v[2*M+1],k[A]=M):M=A,T[S++]=C,T[S++]=L}for(var I=c(T,d.hole||[]),P=0,z=I.length;P<z;P++)null!=k[I[P]]&&(I[P]=k[I[P]]);d.triangles=I}var O=new Float64Array(v);u(O,2,w);var D=new Float64Array(2*y+6);d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[0]=O[2*y-4],D[1]=O[2*y-3]):(D[0]=O[2*y-2],D[1]=O[2*y-1]):(D[0]=O[0],D[1]=O[1]),D.set(O,2),d.close?v[0]===v[2*y-2]&&v[1]===v[2*y-1]?(D[2*y+2]=O[2],D[2*y+3]=O[3],d.count-=1):(D[2*y+2]=O[0],D[2*y+3]=O[1],D[2*y+4]=O[2],D[2*y+5]=O[3]):(D[2*y+2]=O[2*y-2],D[2*y+3]=O[2*y-1],D[2*y+4]=O[2*y-2],D[2*y+5]=O[2*y-1]),d.positionBuffer(h(D)),d.positionFractBuffer(p(D))}if(t.range?d.range=t.range:d.range||(d.range=d.bounds),(t.range||t.positions)&&d.count){var R=d.bounds,F=R[2]-R[0],B=R[3]-R[1],N=d.range[2]-d.range[0],j=d.range[3]-d.range[1];d.scale=[F/N,B/j],d.translate=[-d.range[0]/N+R[0]/N||0,-d.range[1]/j+R[1]/j||0],d.scaleFract=p(d.scale),d.translateFract=p(d.translate)}if(t.dashes){var U,V=0;if(!t.dashes||t.dashes.length<2)V=1,U=new Uint8Array([255,255,255,255,255,255,255,255]);else{V=0;for(var q=0;q<t.dashes.length;++q)V+=t.dashes[q];U=new Uint8Array(V*m.dashMult);for(var H=0,G=255,Y=0;Y<2;Y++)for(var W=0;W<t.dashes.length;++W){for(var X=0,Z=t.dashes[W]*m.dashMult*.5;X<Z;++X)U[H++]=G;G^=255}}d.dashLength=V,d.dashTexture({channels:1,data:U,width:U.length,height:1,mag:\"linear\",min:\"linear\"},0,0)}if(t.color){var J=d.count,K=t.color;K||(K=\"transparent\");var Q=new Uint8Array(4*J+4);if(Array.isArray(K)&&\"number\"!=typeof K[0]){for(var $=0;$<J;$++){var tt=n(K[$],\"uint8\");Q.set(tt,4*$)}Q.set(n(K[0],\"uint8\"),4*J)}else for(var et=n(K,\"uint8\"),rt=0;rt<J+1;rt++)Q.set(et,4*rt);d.colorBuffer({usage:\"dynamic\",type:\"uint8\",data:Q})}}else e.passes[f]=null})),t.length<this.passes.length){for(var f=t.length;f<this.passes.length;f++){var d=this.passes[f];d&&(d.colorBuffer.destroy(),d.positionBuffer.destroy(),d.dashTexture.destroy())}this.passes.length=t.length}for(var v=[],y=0;y<this.passes.length;y++)null!==this.passes[y]&&v.push(this.passes[y]);return this.passes=v,this}},m.prototype.destroy=function(){return this.passes.forEach((function(t){t.colorBuffer.destroy(),t.positionBuffer.destroy(),t.dashTexture.destroy()})),this.passes.length=0,this}},{\"array-bounds\":70,\"array-normalize\":71,\"color-normalize\":125,earcut:177,\"es6-weak-map\":233,\"flatten-vertex-data\":244,glslify:536,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577}],536:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],537:[function(t,e,r){\"use strict\";function n(t,e){return function(t){if(Array.isArray(t))return t}(t)||function(t,e){if(\"undefined\"==typeof Symbol||!(Symbol.iterator in Object(t)))return;var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{n||null==s.return||s.return()}finally{if(i)throw a}}return r}(t,e)||a(t,e)||function(){throw new TypeError(\"Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function i(t){return function(t){if(Array.isArray(t))return o(t)}(t)||function(t){if(\"undefined\"!=typeof Symbol&&Symbol.iterator in Object(t))return Array.from(t)}(t)||a(t)||function(){throw new TypeError(\"Invalid attempt to spread non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.\")}()}function a(t,e){if(t){if(\"string\"==typeof t)return o(t,e);var r=Object.prototype.toString.call(t).slice(8,-1);return\"Object\"===r&&t.constructor&&(r=t.constructor.name),\"Map\"===r||\"Set\"===r?Array.from(t):\"Arguments\"===r||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(r)?o(t,e):void 0}}function o(t,e){(null==e||e>t.length)&&(e=t.length);for(var r=0,n=new Array(e);r<e;r++)n[r]=t[r];return n}var s=t(\"color-normalize\"),l=t(\"array-bounds\"),c=t(\"color-id\"),u=t(\"@plotly/point-cluster\"),f=t(\"object-assign\"),h=t(\"glslify\"),p=t(\"pick-by-alias\"),d=t(\"update-diff\"),g=t(\"flatten-vertex-data\"),m=t(\"is-iexplorer\"),v=t(\"to-float32\"),y=t(\"parse-rect\"),x=b;function b(t,e){var r=this;if(!(this instanceof b))return new b(t,e);\"function\"==typeof t?(e||(e={}),e.regl=t):(e=t,t=null),e&&e.length&&(e.positions=e);var n,i=(t=e.regl)._gl,a=[];this.tooManyColors=m,n=t.texture({data:new Uint8Array(1020),width:255,height:1,type:\"uint8\",format:\"rgba\",wrapS:\"clamp\",wrapT:\"clamp\",mag:\"nearest\",min:\"nearest\"}),f(this,{regl:t,gl:i,groups:[],markerCache:[null],markerTextures:[null],palette:a,paletteIds:{},paletteTexture:n,maxColors:255,maxSize:100,canvas:i.canvas}),this.update(e);var o={uniforms:{constPointSize:!!e.constPointSize,pixelRatio:t.context(\"pixelRatio\"),palette:n,paletteSize:function(t,e){return[r.tooManyColors?0:255,n.height]},scale:t.prop(\"scale\"),scaleFract:t.prop(\"scaleFract\"),translate:t.prop(\"translate\"),translateFract:t.prop(\"translateFract\"),opacity:t.prop(\"opacity\"),marker:t.prop(\"markerTexture\")},attributes:{x:function(t,e){return e.xAttr||{buffer:e.positionBuffer,stride:8,offset:0}},y:function(t,e){return e.yAttr||{buffer:e.positionBuffer,stride:8,offset:4}},xFract:function(t,e){return e.xAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:0}},yFract:function(t,e){return e.yAttr?{constant:[0,0]}:{buffer:e.positionFractBuffer,stride:8,offset:4}},size:function(t,e){return e.size.length?{buffer:e.sizeBuffer,stride:2,offset:0}:{constant:[Math.round(255*e.size/r.maxSize)]}},borderSize:function(t,e){return e.borderSize.length?{buffer:e.sizeBuffer,stride:2,offset:1}:{constant:[Math.round(255*e.borderSize/r.maxSize)]}},colorId:function(t,e){return e.color.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:0}:{constant:r.tooManyColors?a.slice(4*e.color,4*e.color+4):[e.color]}},borderColorId:function(t,e){return e.borderColor.length?{buffer:e.colorBuffer,stride:r.tooManyColors?8:4,offset:r.tooManyColors?4:2}:{constant:r.tooManyColors?a.slice(4*e.borderColor,4*e.borderColor+4):[e.borderColor]}},isActive:function(t,e){return!0===e.activation?{constant:[1]}:e.activation?e.activation:{constant:[0]}}},blend:{enable:!0,color:[0,0,0,1],func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:\"one minus dst alpha\",dstAlpha:\"one\"}},scissor:{enable:!0,box:t.prop(\"viewport\")},viewport:t.prop(\"viewport\"),stencil:{enable:!1},depth:{enable:!1},elements:t.prop(\"elements\"),count:t.prop(\"count\"),offset:t.prop(\"offset\"),primitive:\"points\"},s=f({},o);s.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nuniform sampler2D marker;\\nuniform float opacity;\\n\\nfloat smoothStep(float x, float y) {\\n  return 1.0 / (1.0 + exp(50.0*(x - y)));\\n}\\n\\nvoid main() {\\n  float dist = texture2D(marker, gl_PointCoord).r, delta = fragWidth;\\n\\n  // max-distance alpha\\n  if (dist < 0.003) discard;\\n\\n  // null-border case\\n  if (fragBorderColorLevel == fragColorLevel || fragBorderColor.a == 0.) {\\n    float colorAmt = smoothstep(.5 - delta, .5 + delta, dist);\\n    gl_FragColor = vec4(fragColor.rgb, colorAmt * fragColor.a * opacity);\\n  }\\n  else {\\n    float borderColorAmt = smoothstep(fragBorderColorLevel - delta, fragBorderColorLevel + delta, dist);\\n    float colorAmt = smoothstep(fragColorLevel - delta, fragColorLevel + delta, dist);\\n\\n    vec4 color = fragBorderColor;\\n    color.a *= borderColorAmt;\\n    color = mix(color, fragColor, colorAmt);\\n    color.a *= opacity;\\n\\n    gl_FragColor = color;\\n  }\\n\\n}\\n\"]),s.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract, paletteSize;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\n\\nconst float maxSize = 100.;\\nconst float borderLevel = .5;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragPointSize, fragBorderRadius, fragWidth, fragBorderColorLevel, fragColorLevel;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = 2. * size * pointSizeScale;\\n  fragPointSize = size * pixelRatio;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragColor = color;\\n  fragBorderColor = borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n\\n  fragBorderColorLevel = clamp(borderLevel - borderLevel * borderSize / size, 0., 1.);\\n  fragColorLevel = clamp(borderLevel + (1. - borderLevel) * borderSize / size, 0., 1.);\\n}\"]),this.drawMarker=t(s);var l=f({},o);l.frag=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor, fragBorderColor;\\n\\nuniform float opacity;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat smoothStep(float edge0, float edge1, float x) {\\n\\tfloat t;\\n\\tt = clamp((x - edge0) / (edge1 - edge0), 0.0, 1.0);\\n\\treturn t * t * (3.0 - 2.0 * t);\\n}\\n\\nvoid main() {\\n\\tfloat radius, alpha = 1.0, delta = fragWidth;\\n\\n\\tradius = length(2.0 * gl_PointCoord.xy - 1.0);\\n\\n\\tif (radius > 1.0 + delta) {\\n\\t\\tdiscard;\\n\\t}\\n\\n\\talpha -= smoothstep(1.0 - delta, 1.0 + delta, radius);\\n\\n\\tfloat borderRadius = fragBorderRadius;\\n\\tfloat ratio = smoothstep(borderRadius - delta, borderRadius + delta, radius);\\n\\tvec4 color = mix(fragColor, fragBorderColor, ratio);\\n\\tcolor.a *= alpha * opacity;\\n\\tgl_FragColor = color;\\n}\\n\"]),l.vert=h([\"precision highp float;\\n#define GLSLIFY 1\\n\\nattribute float x, y, xFract, yFract;\\nattribute float size, borderSize;\\nattribute vec4 colorId, borderColorId;\\nattribute float isActive;\\n\\nuniform vec2 scale, scaleFract, translate, translateFract;\\nuniform float pixelRatio;\\nuniform bool constPointSize;\\nuniform sampler2D palette;\\nuniform vec2 paletteSize;\\n\\nconst float maxSize = 100.;\\n\\nvarying vec4 fragColor, fragBorderColor;\\nvarying float fragBorderRadius, fragWidth;\\n\\nfloat pointSizeScale = (constPointSize) ? 2. : pixelRatio;\\n\\nbool isDirect = (paletteSize.x < 1.);\\n\\nvec4 getColor(vec4 id) {\\n  return isDirect ? id / 255. : texture2D(palette,\\n    vec2(\\n      (id.x + .5) / paletteSize.x,\\n      (id.y + .5) / paletteSize.y\\n    )\\n  );\\n}\\n\\nvoid main() {\\n  // ignore inactive points\\n  if (isActive == 0.) return;\\n\\n  vec2 position = vec2(x, y);\\n  vec2 positionFract = vec2(xFract, yFract);\\n\\n  vec4 color = getColor(colorId);\\n  vec4 borderColor = getColor(borderColorId);\\n\\n  float size = size * maxSize / 255.;\\n  float borderSize = borderSize * maxSize / 255.;\\n\\n  gl_PointSize = (size + borderSize) * pointSizeScale;\\n\\n  vec2 pos = (position + translate) * scale\\n      + (positionFract + translateFract) * scale\\n      + (position + translate) * scaleFract\\n      + (positionFract + translateFract) * scaleFract;\\n\\n  gl_Position = vec4(pos * 2. - 1., 0., 1.);\\n\\n  fragBorderRadius = 1. - 2. * borderSize / (size + borderSize);\\n  fragColor = color;\\n  fragBorderColor = borderColor.a == 0. || borderSize == 0. ? vec4(color.rgb, 0.) : borderColor;\\n  fragWidth = 1. / gl_PointSize;\\n}\\n\"]),m&&(l.frag=l.frag.replace(\"smoothstep\",\"smoothStep\"),s.frag=s.frag.replace(\"smoothstep\",\"smoothStep\")),this.drawCircle=t(l)}b.defaults={color:\"black\",borderColor:\"transparent\",borderSize:0,size:12,opacity:1,marker:void 0,viewport:null,range:null,pixelSize:null,count:0,offset:0,bounds:null,positions:[],snap:1e4},b.prototype.render=function(){return arguments.length&&this.update.apply(this,arguments),this.draw(),this},b.prototype.draw=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];var i=this.groups;if(1===r.length&&Array.isArray(r[0])&&(null===r[0][0]||Array.isArray(r[0][0]))&&(r=r[0]),this.regl._refresh(),r.length)for(var a=0;a<r.length;a++)this.drawItem(a,r[a]);else i.forEach((function(e,r){t.drawItem(r)}));return this},b.prototype.drawItem=function(t,e){var r=this.groups,n=r[t];if(\"number\"==typeof e&&(t=e,n=r[e],e=null),n&&n.count&&n.opacity){n.activation[0]&&this.drawCircle(this.getMarkerDrawOptions(0,n,e));for(var a=[],o=1;o<n.activation.length;o++)n.activation[o]&&(!0===n.activation[o]||n.activation[o].data.length)&&a.push.apply(a,i(this.getMarkerDrawOptions(o,n,e)));a.length&&this.drawMarker(a)}},b.prototype.getMarkerDrawOptions=function(t,e,r){var i=e.range,a=e.tree,o=e.viewport,s=e.activation,l=e.selectionBuffer,c=e.count;this.regl;if(!a)return r?[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],count:r.length,elements:r,offset:0})]:[f({},e,{markerTexture:this.markerTextures[t],activation:s[t],offset:0})];var u=[],h=a.range(i,{lod:!0,px:[(i[2]-i[0])/o.width,(i[3]-i[1])/o.height]});if(r){for(var p=s[t].data,d=new Uint8Array(c),g=0;g<r.length;g++){var m=r[g];d[m]=p?p[m]:1}l.subdata(d)}for(var v=h.length;v--;){var y=n(h[v],2),x=y[0],b=y[1];u.push(f({},e,{markerTexture:this.markerTextures[t],activation:r?l:s[t],offset:x,count:b-x}))}return u},b.prototype.update=function(){for(var t=this,e=arguments.length,r=new Array(e),n=0;n<e;n++)r[n]=arguments[n];if(r.length){1===r.length&&Array.isArray(r[0])&&(r=r[0]);var i=this.groups,a=this.gl,o=this.regl,s=this.maxSize,c=this.maxColors,h=this.palette;this.groups=i=r.map((function(e,r){var n=i[r];if(void 0===e)return n;null===e?e={positions:null}:\"function\"==typeof e?e={ondraw:e}:\"number\"==typeof e[0]&&(e={positions:e}),null===(e=p(e,{positions:\"positions data points\",snap:\"snap cluster lod tree\",size:\"sizes size radius\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",color:\"colors color fill fill-color fillColor\",borderColor:\"borderColors borderColor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range dataBox databox\",viewport:\"viewport viewPort viewBox viewbox\",opacity:\"opacity alpha transparency\",bounds:\"bound bounds boundaries limits\",tooManyColors:\"tooManyColors palette paletteMode optimizePalette enablePalette\"})).positions&&(e.positions=[]),null!=e.tooManyColors&&(t.tooManyColors=e.tooManyColors),n||(i[r]=n={id:r,scale:null,translate:null,scaleFract:null,translateFract:null,activation:[],selectionBuffer:o.buffer({data:new Uint8Array(0),usage:\"stream\",type:\"uint8\"}),sizeBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),colorBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"uint8\"}),positionBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"}),positionFractBuffer:o.buffer({data:new Uint8Array(0),usage:\"dynamic\",type:\"float\"})},e=f({},b.defaults,e)),e.positions&&!(\"marker\"in e)&&(e.marker=n.marker,delete n.marker),e.marker&&!(\"positions\"in e)&&(e.positions=n.positions,delete n.positions);var m=0,x=0;if(d(n,e,[{snap:!0,size:function(t,e){return null==t&&(t=b.defaults.size),m+=t&&t.length?1:0,t},borderSize:function(t,e){return null==t&&(t=b.defaults.borderSize),m+=t&&t.length?1:0,t},opacity:parseFloat,color:function(e,r){return null==e&&(e=b.defaults.color),e=t.updateColor(e),x++,e},borderColor:function(e,r){return null==e&&(e=b.defaults.borderColor),e=t.updateColor(e),x++,e},bounds:function(t,e,r){return\"range\"in r||(r.range=null),t},positions:function(t,e,r){var n=e.snap,i=e.positionBuffer,a=e.positionFractBuffer,s=e.selectionBuffer;if(t.x||t.y)return t.x.length?e.xAttr={buffer:o.buffer(t.x),offset:0,stride:4,count:t.x.length}:e.xAttr={buffer:t.x.buffer,offset:4*t.x.offset||0,stride:4*(t.x.stride||1),count:t.x.count},t.y.length?e.yAttr={buffer:o.buffer(t.y),offset:0,stride:4,count:t.y.length}:e.yAttr={buffer:t.y.buffer,offset:4*t.y.offset||0,stride:4*(t.y.stride||1),count:t.y.count},e.count=Math.max(e.xAttr.count,e.yAttr.count),t;t=g(t,\"float64\");var c=e.count=Math.floor(t.length/2),f=e.bounds=c?l(t,2):null;if(r.range||e.range||(delete e.range,r.range=f),r.marker||e.marker||(delete e.marker,r.marker=null),n&&(!0===n||c>n)?e.tree=u(t,{bounds:f}):n&&n.length&&(e.tree=n),e.tree){var h={primitive:\"points\",usage:\"static\",data:e.tree,type:\"uint32\"};e.elements?e.elements(h):e.elements=o.elements(h)}return i({data:v.float(t),usage:\"dynamic\"}),a({data:v.fract(t),usage:\"dynamic\"}),s({data:new Uint8Array(c),type:\"uint8\",usage:\"stream\"}),t}},{marker:function(e,r,n){var i=r.activation;if(i.forEach((function(t){return t&&t.destroy&&t.destroy()})),i.length=0,e&&\"number\"!=typeof e[0]){for(var a=[],s=0,l=Math.min(e.length,r.count);s<l;s++){var c=t.addMarker(e[s]);a[c]||(a[c]=new Uint8Array(r.count)),a[c][s]=1}for(var u=0;u<a.length;u++)if(a[u]){var f={data:a[u],type:\"uint8\",usage:\"static\"};i[u]?i[u](f):i[u]=o.buffer(f),i[u].data=a[u]}}else{i[t.addMarker(e)]=!0}return e},range:function(t,e,r){var n=e.bounds;if(n)return t||(t=n),e.scale=[1/(t[2]-t[0]),1/(t[3]-t[1])],e.translate=[-t[0],-t[1]],e.scaleFract=v.fract(e.scale),e.translateFract=v.fract(e.translate),t},viewport:function(t){return y(t||[a.drawingBufferWidth,a.drawingBufferHeight])}}]),m){var _=n,w=_.count,T=_.size,k=_.borderSize,M=_.sizeBuffer,A=new Uint8Array(2*w);if(T.length||k.length)for(var S=0;S<w;S++)A[2*S]=Math.round(255*(null==T[S]?T:T[S])/s),A[2*S+1]=Math.round(255*(null==k[S]?k:k[S])/s);M({data:A,usage:\"dynamic\"})}if(x){var E,C=n,L=C.count,I=C.color,P=C.borderColor,z=C.colorBuffer;if(t.tooManyColors){if(I.length||P.length){E=new Uint8Array(8*L);for(var O=0;O<L;O++){var D=I[O];E[8*O]=h[4*D],E[8*O+1]=h[4*D+1],E[8*O+2]=h[4*D+2],E[8*O+3]=h[4*D+3];var R=P[O];E[8*O+4]=h[4*R],E[8*O+5]=h[4*R+1],E[8*O+6]=h[4*R+2],E[8*O+7]=h[4*R+3]}}}else if(I.length||P.length){E=new Uint8Array(4*L+2);for(var F=0;F<L;F++)null!=I[F]&&(E[4*F]=I[F]%c,E[4*F+1]=Math.floor(I[F]/c)),null!=P[F]&&(E[4*F+2]=P[F]%c,E[4*F+3]=Math.floor(P[F]/c))}z({data:E||new Uint8Array(0),type:\"uint8\",usage:\"dynamic\"})}return n}))}},b.prototype.addMarker=function(t){var e,r=this.markerTextures,n=this.regl,i=this.markerCache,a=null==t?0:i.indexOf(t);if(a>=0)return a;if(t instanceof Uint8Array||t instanceof Uint8ClampedArray)e=t;else{e=new Uint8Array(t.length);for(var o=0,s=t.length;o<s;o++)e[o]=255*t[o]}var l=Math.floor(Math.sqrt(e.length));return a=r.length,i.push(t),r.push(n.texture({channels:1,data:e,radius:l,mag:\"linear\",min:\"linear\"})),a},b.prototype.updateColor=function(t){var e=this.paletteIds,r=this.palette,n=this.maxColors;Array.isArray(t)||(t=[t]);var i=[];if(\"number\"==typeof t[0]){var a=[];if(Array.isArray(t))for(var o=0;o<t.length;o+=4)a.push(t.slice(o,o+4));else for(var l=0;l<t.length;l+=4)a.push(t.subarray(l,l+4));t=a}for(var u=0;u<t.length;u++){var f=t[u];f=s(f,\"uint8\");var h=c(f,!1);if(null==e[h]){var p=r.length;e[h]=Math.floor(p/4),r[p]=f[0],r[p+1]=f[1],r[p+2]=f[2],r[p+3]=f[3]}i[u]=e[h]}return!this.tooManyColors&&r.length>4*n&&(this.tooManyColors=!0),this.updatePalette(r),1===i.length?i[0]:i},b.prototype.updatePalette=function(t){if(!this.tooManyColors){var e=this.maxColors,r=this.paletteTexture,n=Math.ceil(.25*t.length/e);if(n>1)for(var i=.25*(t=t.slice()).length%e;i<n*e;i++)t.push(0,0,0,0);r.height<n&&r.resize(e,n),r.subimage({width:Math.min(.25*t.length,e),height:n,data:t},0,0)}},b.prototype.destroy=function(){return this.groups.forEach((function(t){t.sizeBuffer.destroy(),t.positionBuffer.destroy(),t.positionFractBuffer.destroy(),t.colorBuffer.destroy(),t.activation.forEach((function(t){return t&&t.destroy&&t.destroy()})),t.selectionBuffer.destroy(),t.elements&&t.elements.destroy()})),this.groups.length=0,this.paletteTexture.destroy(),this.markerTextures.forEach((function(t){return t&&t.destroy&&t.destroy()})),this};var _=t(\"object-assign\");e.exports=function(t,e){var r=new x(t,e),n=r.render.bind(r);return _(n,{render:n,update:r.update.bind(r),draw:r.draw.bind(r),destroy:r.destroy.bind(r),regl:r.regl,gl:r.gl,canvas:r.gl.canvas,groups:r.groups,markers:r.markerCache,palette:r.palette}),n}},{\"@plotly/point-cluster\":57,\"array-bounds\":70,\"color-id\":123,\"color-normalize\":125,\"flatten-vertex-data\":244,glslify:538,\"is-iexplorer\":466,\"object-assign\":499,\"parse-rect\":504,\"pick-by-alias\":511,\"to-float32\":577,\"update-diff\":599}],538:[function(t,e,r){arguments[4][257][0].apply(r,arguments)},{dup:257}],539:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"pick-by-alias\"),a=t(\"array-bounds\"),o=t(\"raf\"),s=t(\"array-range\"),l=t(\"parse-rect\"),c=t(\"flatten-vertex-data\");function u(t,e){if(!(this instanceof u))return new u(t,e);this.traces=[],this.passes={},this.regl=t,this.scatter=n(t),this.canvas=this.scatter.canvas}function f(t,e,r){return(null!=t.id?t.id:t)<<16|(255&e)<<8|255&r}function h(t,e,r){var n,i,a,o,s=t[e],l=t[r];return s.length>2?(s[0],s[2],n=s[1],i=s[3]):s.length?(n=s[0],i=s[1]):(s.x,n=s.y,s.x+s.width,i=s.y+s.height),l.length>2?(a=l[0],o=l[2],l[1],l[3]):l.length?(a=l[0],o=l[1]):(a=l.x,l.y,o=l.x+l.width,l.y+l.height),[a,n,o,i]}function p(t){if(\"number\"==typeof t)return[t,t,t,t];if(2===t.length)return[t[0],t[1],t[0],t[1]];var e=l(t);return[e.x,e.y,e.x+e.width,e.y+e.height]}e.exports=u,u.prototype.render=function(){for(var t,e=this,r=[],n=arguments.length;n--;)r[n]=arguments[n];return r.length&&(t=this).update.apply(t,r),this.regl.attributes.preserveDrawingBuffer?this.draw():(this.dirty?null==this.planned&&(this.planned=o((function(){e.draw(),e.dirty=!0,e.planned=null}))):(this.draw(),this.dirty=!0,o((function(){e.dirty=!1}))),this)},u.prototype.update=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=0;n<e.length;n++)this.updateItem(n,e[n]);this.traces=this.traces.filter(Boolean);for(var i=[],a=0,o=0;o<this.traces.length;o++){for(var s=this.traces[o],l=this.traces[o].passes,c=0;c<l.length;c++)i.push(this.passes[l[c]]);s.passOffset=a,a+=s.passes.length}return(t=this.scatter).update.apply(t,i),this}},u.prototype.updateItem=function(t,e){var r=this.regl;if(null===e)return this.traces[t]=null,this;if(!e)return this;var n,o=i(e,{data:\"data items columns rows values dimensions samples x\",snap:\"snap cluster\",size:\"sizes size radius\",color:\"colors color fill fill-color fillColor\",opacity:\"opacity alpha transparency opaque\",borderSize:\"borderSizes borderSize border-size bordersize borderWidth borderWidths border-width borderwidth stroke-width strokeWidth strokewidth outline\",borderColor:\"borderColors borderColor bordercolor stroke stroke-color strokeColor\",marker:\"markers marker shape\",range:\"range ranges databox dataBox\",viewport:\"viewport viewBox viewbox\",domain:\"domain domains area areas\",padding:\"pad padding paddings pads margin margins\",transpose:\"transpose transposed\",diagonal:\"diagonal diag showDiagonal\",upper:\"upper up top upperhalf upperHalf showupperhalf showUpper showUpperHalf\",lower:\"lower low bottom lowerhalf lowerHalf showlowerhalf showLowerHalf showLower\"}),s=this.traces[t]||(this.traces[t]={id:t,buffer:r.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array}),color:\"black\",marker:null,size:12,borderColor:\"transparent\",borderSize:1,viewport:l([r._gl.drawingBufferWidth,r._gl.drawingBufferHeight]),padding:[0,0,0,0],opacity:1,diagonal:!0,upper:!0,lower:!0});if(null!=o.color&&(s.color=o.color),null!=o.size&&(s.size=o.size),null!=o.marker&&(s.marker=o.marker),null!=o.borderColor&&(s.borderColor=o.borderColor),null!=o.borderSize&&(s.borderSize=o.borderSize),null!=o.opacity&&(s.opacity=o.opacity),o.viewport&&(s.viewport=l(o.viewport)),null!=o.diagonal&&(s.diagonal=o.diagonal),null!=o.upper&&(s.upper=o.upper),null!=o.lower&&(s.lower=o.lower),o.data){s.buffer(c(o.data)),s.columns=o.data.length,s.count=o.data[0].length,s.bounds=[];for(var u=0;u<s.columns;u++)s.bounds[u]=a(o.data[u],1)}o.range&&(s.range=o.range,n=s.range&&\"number\"!=typeof s.range[0]),o.domain&&(s.domain=o.domain);var d=!1;null!=o.padding&&(Array.isArray(o.padding)&&o.padding.length===s.columns&&\"number\"==typeof o.padding[o.padding.length-1]?(s.padding=o.padding.map(p),d=!0):s.padding=p(o.padding));var g=s.columns,m=s.count,v=s.viewport.width,y=s.viewport.height,x=s.viewport.x,b=s.viewport.y,_=v/g,w=y/g;s.passes=[];for(var T=0;T<g;T++)for(var k=0;k<g;k++)if((s.diagonal||k!==T)&&(s.upper||!(T>k))&&(s.lower||!(T<k))){var M=f(s.id,T,k),A=this.passes[M]||(this.passes[M]={});if(o.data&&(o.transpose?A.positions={x:{buffer:s.buffer,offset:k,count:m,stride:g},y:{buffer:s.buffer,offset:T,count:m,stride:g}}:A.positions={x:{buffer:s.buffer,offset:k*m,count:m},y:{buffer:s.buffer,offset:T*m,count:m}},A.bounds=h(s.bounds,T,k)),o.domain||o.viewport||o.data){var S=d?h(s.padding,T,k):s.padding;if(s.domain){var E=h(s.domain,T,k),C=E[0],L=E[1],I=E[2],P=E[3];A.viewport=[x+C*v+S[0],b+L*y+S[1],x+I*v-S[2],b+P*y-S[3]]}else A.viewport=[x+k*_+_*S[0],b+T*w+w*S[1],x+(k+1)*_-_*S[2],b+(T+1)*w-w*S[3]]}o.color&&(A.color=s.color),o.size&&(A.size=s.size),o.marker&&(A.marker=s.marker),o.borderSize&&(A.borderSize=s.borderSize),o.borderColor&&(A.borderColor=s.borderColor),o.opacity&&(A.opacity=s.opacity),o.range&&(A.range=n?h(s.range,T,k):s.range||A.bounds),s.passes.push(M)}return this},u.prototype.draw=function(){for(var t,e=[],r=arguments.length;r--;)e[r]=arguments[r];if(e.length){for(var n=[],i=0;i<e.length;i++)if(\"number\"==typeof e[i]){var a=this.traces[e[i]],o=a.passes,l=a.passOffset;n.push.apply(n,s(l,l+o.length))}else if(e[i].length){var c=e[i],u=this.traces[i],f=u.passes,h=u.passOffset;f=f.map((function(t,e){n[h+e]=c}))}(t=this.scatter).draw.apply(t,n)}else this.scatter.draw();return this},u.prototype.destroy=function(){return this.traces.forEach((function(t){t.buffer&&t.buffer.destroy&&t.buffer.destroy()})),this.traces=null,this.passes=null,this.scatter.destroy(),this}},{\"array-bounds\":70,\"array-range\":72,\"flatten-vertex-data\":244,\"parse-rect\":504,\"pick-by-alias\":511,raf:528,\"regl-scatter2d\":537}],540:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?e.exports=n():t.createREGL=n()}(this,(function(){function t(t,e){this.id=V++,this.type=t,this.data=e}function e(t){return\"[\"+function t(e){if(0===e.length)return[];var r=e.charAt(0),n=e.charAt(e.length-1);if(1<e.length&&r===n&&('\"'===r||\"'\"===r))return['\"'+e.substr(1,e.length-2).replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];if(r=/\\[(false|true|null|\\d+|'[^']*'|\"[^\"]*\")\\]/.exec(e))return t(e.substr(0,r.index)).concat(t(r[1])).concat(t(e.substr(r.index+r[0].length)));if(1===(r=e.split(\".\")).length)return['\"'+e.replace(/\\\\/g,\"\\\\\\\\\").replace(/\"/g,'\\\\\"')+'\"'];for(e=[],n=0;n<r.length;++n)e=e.concat(t(r[n]));return e}(t).join(\"][\")+\"]\"}function r(t){return\"string\"==typeof t?t.split():t}function n(t){return\"string\"==typeof t?document.querySelector(t):t}function i(t){var e,i,a,o,s=t||{};t={};var l=[],c=[],u=\"undefined\"==typeof window?1:window.devicePixelRatio,f=!1,h=function(t){},p=function(){};if(\"string\"==typeof s?e=document.querySelector(s):\"object\"==typeof s&&(\"string\"==typeof s.nodeName&&\"function\"==typeof s.appendChild&&\"function\"==typeof s.getBoundingClientRect?e=s:\"function\"==typeof s.drawArrays||\"function\"==typeof s.drawElements?a=(o=s).canvas:(\"gl\"in s?o=s.gl:\"canvas\"in s?a=n(s.canvas):\"container\"in s&&(i=n(s.container)),\"attributes\"in s&&(t=s.attributes),\"extensions\"in s&&(l=r(s.extensions)),\"optionalExtensions\"in s&&(c=r(s.optionalExtensions)),\"onDone\"in s&&(h=s.onDone),\"profile\"in s&&(f=!!s.profile),\"pixelRatio\"in s&&(u=+s.pixelRatio))),e&&(\"canvas\"===e.nodeName.toLowerCase()?a=e:i=e),!o){if(!a){if(!(e=function(t,e,r){function n(){var e=window.innerWidth,n=window.innerHeight;t!==document.body&&(e=(n=t.getBoundingClientRect()).right-n.left,n=n.bottom-n.top),a.width=r*e,a.height=r*n,U(a.style,{width:e+\"px\",height:n+\"px\"})}var i,a=document.createElement(\"canvas\");return U(a.style,{border:0,margin:0,padding:0,top:0,left:0}),t.appendChild(a),t===document.body&&(a.style.position=\"absolute\",U(t.style,{margin:0,padding:0})),t!==document.body&&\"function\"==typeof ResizeObserver?(i=new ResizeObserver((function(){setTimeout(n)}))).observe(t):window.addEventListener(\"resize\",n,!1),n(),{canvas:a,onDestroy:function(){i?i.disconnect():window.removeEventListener(\"resize\",n),t.removeChild(a)}}}(i||document.body,0,u)))return null;a=e.canvas,p=e.onDestroy}void 0===t.premultipliedAlpha&&(t.premultipliedAlpha=!0),o=function(t,e){function r(r){try{return t.getContext(r,e)}catch(t){return null}}return r(\"webgl\")||r(\"experimental-webgl\")||r(\"webgl-experimental\")}(a,t)}return o?{gl:o,canvas:a,container:i,extensions:l,optionalExtensions:c,pixelRatio:u,profile:f,onDone:h,onDestroy:p}:(p(),h(\"webgl not supported, try upgrading your browser or graphics drivers http://get.webgl.org\"),null)}function a(t,e){for(var r=Array(t),n=0;n<t;++n)r[n]=e(n);return r}function o(t){var e,r;return e=(65535<t)<<4,e|=r=(255<(t>>>=e))<<3,(e|=r=(15<(t>>>=r))<<2)|(r=(3<(t>>>=r))<<1)|t>>>r>>1}function s(){function t(t){t:{for(var e=16;268435456>=e;e*=16)if(t<=e){t=e;break t}t=0}return 0<(e=r[o(t)>>2]).length?e.pop():new ArrayBuffer(t)}function e(t){r[o(t.byteLength)>>2].push(t)}var r=a(8,(function(){return[]}));return{alloc:t,free:e,allocType:function(e,r){var n=null;switch(e){case 5120:n=new Int8Array(t(r),0,r);break;case 5121:n=new Uint8Array(t(r),0,r);break;case 5122:n=new Int16Array(t(2*r),0,r);break;case 5123:n=new Uint16Array(t(2*r),0,r);break;case 5124:n=new Int32Array(t(4*r),0,r);break;case 5125:n=new Uint32Array(t(4*r),0,r);break;case 5126:n=new Float32Array(t(4*r),0,r);break;default:return null}return n.length!==r?n.subarray(0,r):n},freeType:function(t){e(t.buffer)}}}function l(t){return!!t&&\"object\"==typeof t&&Array.isArray(t.shape)&&Array.isArray(t.stride)&&\"number\"==typeof t.offset&&t.shape.length===t.stride.length&&(Array.isArray(t.data)||X(t.data))}function c(t,e,r,n,i,a){for(var o=0;o<e;++o)for(var s=t[o],l=0;l<r;++l)for(var c=s[l],u=0;u<n;++u)i[a++]=c[u]}function u(t){return 0|K[Object.prototype.toString.call(t)]}function f(t,e){for(var r=0;r<e.length;++r)t[r]=e[r]}function h(t,e,r,n,i,a,o){for(var s=0,l=0;l<r;++l)for(var c=0;c<n;++c)t[s++]=e[i*l+a*c+o]}function p(t,e,r,n){function i(e){this.id=c++,this.buffer=t.createBuffer(),this.type=e,this.usage=35044,this.byteLength=0,this.dimension=1,this.dtype=5121,this.persistentData=null,r.profile&&(this.stats={size:0})}function a(e,r,n){e.byteLength=r.byteLength,t.bufferData(e.type,r,n)}function o(t,e,r,n,i,o){if(t.usage=r,Array.isArray(e)){if(t.dtype=n||5126,0<e.length)if(Array.isArray(e[0])){i=et(e);for(var s=n=1;s<i.length;++s)n*=i[s];t.dimension=n,a(t,e=tt(e,i,t.dtype),r),o?t.persistentData=e:Y.freeType(e)}else\"number\"==typeof e[0]?(t.dimension=i,f(i=Y.allocType(t.dtype,e.length),e),a(t,i,r),o?t.persistentData=i:Y.freeType(i)):X(e[0])&&(t.dimension=e[0].length,t.dtype=n||u(e[0])||5126,a(t,e=tt(e,[e.length,e[0].length],t.dtype),r),o?t.persistentData=e:Y.freeType(e))}else if(X(e))t.dtype=n||u(e),t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e.buffer)));else if(l(e)){i=e.shape;var c=e.stride,p=(s=e.offset,0),d=0,g=0,m=0;1===i.length?(p=i[0],d=1,g=c[0],m=0):2===i.length&&(p=i[0],d=i[1],g=c[0],m=c[1]),t.dtype=n||u(e.data)||5126,t.dimension=d,h(i=Y.allocType(t.dtype,p*d),e.data,p,d,g,m,s),a(t,i,r),o?t.persistentData=i:Y.freeType(i)}else e instanceof ArrayBuffer&&(t.dtype=5121,t.dimension=i,a(t,e,r),o&&(t.persistentData=new Uint8Array(new Uint8Array(e))))}function s(r){e.bufferCount--,n(r),t.deleteBuffer(r.buffer),r.buffer=null,delete p[r.id]}var c=0,p={};i.prototype.bind=function(){t.bindBuffer(this.type,this.buffer)},i.prototype.destroy=function(){s(this)};var d=[];return r.profile&&(e.getTotalBufferSize=function(){var t=0;return Object.keys(p).forEach((function(e){t+=p[e].stats.size})),t}),{create:function(n,a,c,d){function g(e){var n=35044,i=null,a=0,s=0,c=1;return Array.isArray(e)||X(e)||l(e)||e instanceof ArrayBuffer?i=e:\"number\"==typeof e?a=0|e:e&&(\"data\"in e&&(i=e.data),\"usage\"in e&&(n=$[e.usage]),\"type\"in e&&(s=Q[e.type]),\"dimension\"in e&&(c=0|e.dimension),\"length\"in e&&(a=0|e.length)),m.bind(),i?o(m,i,n,s,c,d):(a&&t.bufferData(m.type,a,n),m.dtype=s||5121,m.usage=n,m.dimension=c,m.byteLength=a),r.profile&&(m.stats.size=m.byteLength*rt[m.dtype]),g}e.bufferCount++;var m=new i(a);return p[m.id]=m,c||g(n),g._reglType=\"buffer\",g._buffer=m,g.subdata=function(e,r){var n,i=0|(r||0);if(m.bind(),X(e)||e instanceof ArrayBuffer)t.bufferSubData(m.type,i,e);else if(Array.isArray(e)){if(0<e.length)if(\"number\"==typeof e[0]){var a=Y.allocType(m.dtype,e.length);f(a,e),t.bufferSubData(m.type,i,a),Y.freeType(a)}else(Array.isArray(e[0])||X(e[0]))&&(n=et(e),a=tt(e,n,m.dtype),t.bufferSubData(m.type,i,a),Y.freeType(a))}else if(l(e)){n=e.shape;var o=e.stride,s=a=0,c=0,p=0;1===n.length?(a=n[0],s=1,c=o[0],p=0):2===n.length&&(a=n[0],s=n[1],c=o[0],p=o[1]),n=Array.isArray(e.data)?m.dtype:u(e.data),h(n=Y.allocType(n,a*s),e.data,a,s,c,p,e.offset),t.bufferSubData(m.type,i,n),Y.freeType(n)}return g},r.profile&&(g.stats=m.stats),g.destroy=function(){s(m)},g},createStream:function(t,e){var r=d.pop();return r||(r=new i(t)),r.bind(),o(r,e,35040,0,1,!1),r},destroyStream:function(t){d.push(t)},clear:function(){Z(p).forEach(s),d.forEach(s)},getBuffer:function(t){return t&&t._buffer instanceof i?t._buffer:null},restore:function(){Z(p).forEach((function(e){e.buffer=t.createBuffer(),t.bindBuffer(e.type,e.buffer),t.bufferData(e.type,e.persistentData||e.byteLength,e.usage)}))},_initBuffer:o}}function d(t,e,r,n){function i(t){this.id=c++,s[this.id]=this,this.buffer=t,this.primType=4,this.type=this.vertCount=0}function a(n,i,a,o,s,c,u){var f;if(n.buffer.bind(),i?((f=u)||X(i)&&(!l(i)||X(i.data))||(f=e.oes_element_index_uint?5125:5123),r._initBuffer(n.buffer,i,a,f,3)):(t.bufferData(34963,c,a),n.buffer.dtype=f||5121,n.buffer.usage=a,n.buffer.dimension=3,n.buffer.byteLength=c),f=u,!u){switch(n.buffer.dtype){case 5121:case 5120:f=5121;break;case 5123:case 5122:f=5123;break;case 5125:case 5124:f=5125}n.buffer.dtype=f}n.type=f,0>(i=s)&&(i=n.buffer.byteLength,5123===f?i>>=1:5125===f&&(i>>=2)),n.vertCount=i,i=o,0>o&&(i=4,1===(o=n.buffer.dimension)&&(i=0),2===o&&(i=1),3===o&&(i=4)),n.primType=i}function o(t){n.elementsCount--,delete s[t.id],t.buffer.destroy(),t.buffer=null}var s={},c=0,u={uint8:5121,uint16:5123};e.oes_element_index_uint&&(u.uint32=5125),i.prototype.bind=function(){this.buffer.bind()};var f=[];return{create:function(t,e){function s(t){if(t)if(\"number\"==typeof t)c(t),f.primType=4,f.vertCount=0|t,f.type=5121;else{var e=null,r=35044,n=-1,i=-1,o=0,h=0;Array.isArray(t)||X(t)||l(t)?e=t:(\"data\"in t&&(e=t.data),\"usage\"in t&&(r=$[t.usage]),\"primitive\"in t&&(n=nt[t.primitive]),\"count\"in t&&(i=0|t.count),\"type\"in t&&(h=u[t.type]),\"length\"in t?o=0|t.length:(o=i,5123===h||5122===h?o*=2:5125!==h&&5124!==h||(o*=4))),a(f,e,r,n,i,o,h)}else c(),f.primType=4,f.vertCount=0,f.type=5121;return s}var c=r.create(null,34963,!0),f=new i(c._buffer);return n.elementsCount++,s(t),s._reglType=\"elements\",s._elements=f,s.subdata=function(t,e){return c.subdata(t,e),s},s.destroy=function(){o(f)},s},createStream:function(t){var e=f.pop();return e||(e=new i(r.create(null,34963,!0,!1)._buffer)),a(e,t,35040,-1,-1,0,0),e},destroyStream:function(t){f.push(t)},getElements:function(t){return\"function\"==typeof t&&t._elements instanceof i?t._elements:null},clear:function(){Z(s).forEach(o)}}}function g(t){for(var e=Y.allocType(5123,t.length),r=0;r<t.length;++r)if(isNaN(t[r]))e[r]=65535;else if(1/0===t[r])e[r]=31744;else if(-1/0===t[r])e[r]=64512;else{it[0]=t[r];var n=(a=at[0])>>>31<<15,i=(a<<1>>>24)-127,a=a>>13&1023;e[r]=-24>i?n:-14>i?n+(a+1024>>-14-i):15<i?n+31744:n+(i+15<<10)+a}return e}function m(t){return Array.isArray(t)||X(t)}function v(t){return\"[object \"+t+\"]\"}function y(t){return Array.isArray(t)&&(0===t.length||\"number\"==typeof t[0])}function x(t){return!(!Array.isArray(t)||0===t.length||!m(t[0]))}function b(t){return Object.prototype.toString.call(t)}function _(t){if(!t)return!1;var e=b(t);return 0<=gt.indexOf(e)||(y(t)||x(t)||l(t))}function w(t,e){36193===t.type?(t.data=g(e),Y.freeType(e)):t.data=e}function T(t,e,r,n,i,a){if(t=\"undefined\"!=typeof vt[t]?vt[t]:lt[t]*mt[e],a&&(t*=6),i){for(n=0;1<=r;)n+=t*r*r,r/=2;return n}return t*r*n}function k(t,e,r,n,i,a,o){function s(){this.format=this.internalformat=6408,this.type=5121,this.flipY=this.premultiplyAlpha=this.compressed=!1,this.unpackAlignment=1,this.colorSpace=37444,this.channels=this.height=this.width=0}function c(t,e){t.internalformat=e.internalformat,t.format=e.format,t.type=e.type,t.compressed=e.compressed,t.premultiplyAlpha=e.premultiplyAlpha,t.flipY=e.flipY,t.unpackAlignment=e.unpackAlignment,t.colorSpace=e.colorSpace,t.width=e.width,t.height=e.height,t.channels=e.channels}function u(t,e){if(\"object\"==typeof e&&e){\"premultiplyAlpha\"in e&&(t.premultiplyAlpha=e.premultiplyAlpha),\"flipY\"in e&&(t.flipY=e.flipY),\"alignment\"in e&&(t.unpackAlignment=e.alignment),\"colorSpace\"in e&&(t.colorSpace=q[e.colorSpace]),\"type\"in e&&(t.type=H[e.type]);var r=t.width,n=t.height,i=t.channels,a=!1;\"shape\"in e?(r=e.shape[0],n=e.shape[1],3===e.shape.length&&(i=e.shape[2],a=!0)):(\"radius\"in e&&(r=n=e.radius),\"width\"in e&&(r=e.width),\"height\"in e&&(n=e.height),\"channels\"in e&&(i=e.channels,a=!0)),t.width=0|r,t.height=0|n,t.channels=0|i,r=!1,\"format\"in e&&(r=e.format,n=t.internalformat=G[r],t.format=at[n],r in H&&!(\"type\"in e)&&(t.type=H[r]),r in W&&(t.compressed=!0),r=!0),!a&&r?t.channels=lt[t.format]:a&&!r&&t.channels!==st[t.format]&&(t.format=t.internalformat=st[t.channels])}}function f(e){t.pixelStorei(37440,e.flipY),t.pixelStorei(37441,e.premultiplyAlpha),t.pixelStorei(37443,e.colorSpace),t.pixelStorei(3317,e.unpackAlignment)}function h(){s.call(this),this.yOffset=this.xOffset=0,this.data=null,this.needsFree=!1,this.element=null,this.needsCopy=!1}function p(t,e){var r=null;if(_(e)?r=e:e&&(u(t,e),\"x\"in e&&(t.xOffset=0|e.x),\"y\"in e&&(t.yOffset=0|e.y),_(e.data)&&(r=e.data)),e.copy){var n=i.viewportWidth,a=i.viewportHeight;t.width=t.width||n-t.xOffset,t.height=t.height||a-t.yOffset,t.needsCopy=!0}else if(r){if(X(r))t.channels=t.channels||4,t.data=r,\"type\"in e||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(r)]);else if(y(r)){switch(t.channels=t.channels||4,a=(n=r).length,t.type){case 5121:case 5123:case 5125:case 5126:(a=Y.allocType(t.type,a)).set(n),t.data=a;break;case 36193:t.data=g(n)}t.alignment=1,t.needsFree=!0}else if(l(r)){n=r.data,Array.isArray(n)||5121!==t.type||(t.type=0|K[Object.prototype.toString.call(n)]);a=r.shape;var o,s,c,f,h=r.stride;3===a.length?(c=a[2],f=h[2]):f=c=1,o=a[0],s=a[1],a=h[0],h=h[1],t.alignment=1,t.width=o,t.height=s,t.channels=c,t.format=t.internalformat=st[c],t.needsFree=!0,o=f,r=r.offset,c=t.width,f=t.height,s=t.channels;for(var p=Y.allocType(36193===t.type?5126:t.type,c*f*s),d=0,v=0;v<f;++v)for(var T=0;T<c;++T)for(var k=0;k<s;++k)p[d++]=n[a*T+h*v+o*k+r];w(t,p)}else if(b(r)===ct||b(r)===ut||b(r)===ft)b(r)===ct||b(r)===ut?t.element=r:t.element=r.canvas,t.width=t.element.width,t.height=t.element.height,t.channels=4;else if(b(r)===ht)t.element=r,t.width=r.width,t.height=r.height,t.channels=4;else if(b(r)===pt)t.element=r,t.width=r.naturalWidth,t.height=r.naturalHeight,t.channels=4;else if(b(r)===dt)t.element=r,t.width=r.videoWidth,t.height=r.videoHeight,t.channels=4;else if(x(r)){for(n=t.width||r[0].length,a=t.height||r.length,h=t.channels,h=m(r[0][0])?h||r[0][0].length:h||1,o=J.shape(r),c=1,f=0;f<o.length;++f)c*=o[f];c=Y.allocType(36193===t.type?5126:t.type,c),J.flatten(r,o,\"\",c),w(t,c),t.alignment=1,t.width=n,t.height=a,t.channels=h,t.format=t.internalformat=st[h],t.needsFree=!0}}else t.width=t.width||1,t.height=t.height||1,t.channels=t.channels||4}function d(e,r,i,a,o){var s=e.element,l=e.data,c=e.internalformat,u=e.format,h=e.type,p=e.width,d=e.height;f(e),s?t.texSubImage2D(r,o,i,a,u,h,s):e.compressed?t.compressedTexSubImage2D(r,o,i,a,c,p,d,l):e.needsCopy?(n(),t.copyTexSubImage2D(r,o,i,a,e.xOffset,e.yOffset,p,d)):t.texSubImage2D(r,o,i,a,p,d,u,h,l)}function v(){return gt.pop()||new h}function k(t){t.needsFree&&Y.freeType(t.data),h.call(t),gt.push(t)}function M(){s.call(this),this.genMipmaps=!1,this.mipmapHint=4352,this.mipmask=0,this.images=Array(16)}function A(t,e,r){var n=t.images[0]=v();t.mipmask=1,n.width=t.width=e,n.height=t.height=r,n.channels=t.channels=4}function S(t,e){var r=null;if(_(e))c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;else if(u(t,e),Array.isArray(e.mipmap))for(var n=e.mipmap,i=0;i<n.length;++i)c(r=t.images[i]=v(),t),r.width>>=i,r.height>>=i,p(r,n[i]),t.mipmask|=1<<i;else c(r=t.images[0]=v(),t),p(r,e),t.mipmask=1;c(t,t.images[0])}function E(e,r){for(var i=e.images,a=0;a<i.length&&i[a];++a){var o=i[a],s=r,l=a,c=o.element,u=o.data,h=o.internalformat,p=o.format,d=o.type,g=o.width,m=o.height;f(o),c?t.texImage2D(s,l,p,p,d,c):o.compressed?t.compressedTexImage2D(s,l,h,g,m,0,u):o.needsCopy?(n(),t.copyTexImage2D(s,l,p,o.xOffset,o.yOffset,g,m,0)):t.texImage2D(s,l,p,g,m,0,p,d,u||null)}}function C(){var t=mt.pop()||new M;s.call(t);for(var e=t.mipmask=0;16>e;++e)t.images[e]=null;return t}function L(t){for(var e=t.images,r=0;r<e.length;++r)e[r]&&k(e[r]),e[r]=null;mt.push(t)}function I(){this.magFilter=this.minFilter=9728,this.wrapT=this.wrapS=33071,this.anisotropic=1,this.genMipmaps=!1,this.mipmapHint=4352}function P(t,e){\"min\"in e&&(t.minFilter=V[e.min],0<=ot.indexOf(t.minFilter)&&!(\"faces\"in e)&&(t.genMipmaps=!0)),\"mag\"in e&&(t.magFilter=j[e.mag]);var r=t.wrapS,n=t.wrapT;if(\"wrap\"in e){var i=e.wrap;\"string\"==typeof i?r=n=N[i]:Array.isArray(i)&&(r=N[i[0]],n=N[i[1]])}else\"wrapS\"in e&&(r=N[e.wrapS]),\"wrapT\"in e&&(n=N[e.wrapT]);if(t.wrapS=r,t.wrapT=n,\"anisotropic\"in e&&(t.anisotropic=e.anisotropic),\"mipmap\"in e){switch(r=!1,typeof e.mipmap){case\"string\":t.mipmapHint=B[e.mipmap],r=t.genMipmaps=!0;break;case\"boolean\":r=t.genMipmaps=e.mipmap;break;case\"object\":t.genMipmaps=!1,r=!0}!r||\"min\"in e||(t.minFilter=9984)}}function z(r,n){t.texParameteri(n,10241,r.minFilter),t.texParameteri(n,10240,r.magFilter),t.texParameteri(n,10242,r.wrapS),t.texParameteri(n,10243,r.wrapT),e.ext_texture_filter_anisotropic&&t.texParameteri(n,34046,r.anisotropic),r.genMipmaps&&(t.hint(33170,r.mipmapHint),t.generateMipmap(n))}function O(e){s.call(this),this.mipmask=0,this.internalformat=6408,this.id=vt++,this.refCount=1,this.target=e,this.texture=t.createTexture(),this.unit=-1,this.bindCount=0,this.texInfo=new I,o.profile&&(this.stats={size:0})}function D(e){t.activeTexture(33984),t.bindTexture(e.target,e.texture)}function R(){var e=bt[0];e?t.bindTexture(e.target,e.texture):t.bindTexture(3553,null)}function F(e){var r=e.texture,n=e.unit,i=e.target;0<=n&&(t.activeTexture(33984+n),t.bindTexture(i,null),bt[n]=null),t.deleteTexture(r),e.texture=null,e.params=null,e.pixels=null,e.refCount=0,delete yt[e.id],a.textureCount--}var B={\"don't care\":4352,\"dont care\":4352,nice:4354,fast:4353},N={repeat:10497,clamp:33071,mirror:33648},j={nearest:9728,linear:9729},V=U({mipmap:9987,\"nearest mipmap nearest\":9984,\"linear mipmap nearest\":9985,\"nearest mipmap linear\":9986,\"linear mipmap linear\":9987},j),q={none:0,browser:37444},H={uint8:5121,rgba4:32819,rgb565:33635,\"rgb5 a1\":32820},G={alpha:6406,luminance:6409,\"luminance alpha\":6410,rgb:6407,rgba:6408,rgba4:32854,\"rgb5 a1\":32855,rgb565:36194},W={};e.ext_srgb&&(G.srgb=35904,G.srgba=35906),e.oes_texture_float&&(H.float32=H.float=5126),e.oes_texture_half_float&&(H.float16=H[\"half float\"]=36193),e.webgl_depth_texture&&(U(G,{depth:6402,\"depth stencil\":34041}),U(H,{uint16:5123,uint32:5125,\"depth stencil\":34042})),e.webgl_compressed_texture_s3tc&&U(W,{\"rgb s3tc dxt1\":33776,\"rgba s3tc dxt1\":33777,\"rgba s3tc dxt3\":33778,\"rgba s3tc dxt5\":33779}),e.webgl_compressed_texture_atc&&U(W,{\"rgb atc\":35986,\"rgba atc explicit alpha\":35987,\"rgba atc interpolated alpha\":34798}),e.webgl_compressed_texture_pvrtc&&U(W,{\"rgb pvrtc 4bppv1\":35840,\"rgb pvrtc 2bppv1\":35841,\"rgba pvrtc 4bppv1\":35842,\"rgba pvrtc 2bppv1\":35843}),e.webgl_compressed_texture_etc1&&(W[\"rgb etc1\"]=36196);var Q=Array.prototype.slice.call(t.getParameter(34467));Object.keys(W).forEach((function(t){var e=W[t];0<=Q.indexOf(e)&&(G[t]=e)}));var $=Object.keys(G);r.textureFormats=$;var tt=[];Object.keys(G).forEach((function(t){tt[G[t]]=t}));var et=[];Object.keys(H).forEach((function(t){et[H[t]]=t}));var rt=[];Object.keys(j).forEach((function(t){rt[j[t]]=t}));var nt=[];Object.keys(V).forEach((function(t){nt[V[t]]=t}));var it=[];Object.keys(N).forEach((function(t){it[N[t]]=t}));var at=$.reduce((function(t,r){var n=G[r];return 6409===n||6406===n||6409===n||6410===n||6402===n||34041===n||e.ext_srgb&&(35904===n||35906===n)?t[n]=n:32855===n||0<=r.indexOf(\"rgba\")?t[n]=6408:t[n]=6407,t}),{}),gt=[],mt=[],vt=0,yt={},xt=r.maxTextureUnits,bt=Array(xt).map((function(){return null}));return U(O.prototype,{bind:function(){this.bindCount+=1;var e=this.unit;if(0>e){for(var r=0;r<xt;++r){var n=bt[r];if(n){if(0<n.bindCount)continue;n.unit=-1}bt[r]=this,e=r;break}o.profile&&a.maxTextureUnits<e+1&&(a.maxTextureUnits=e+1),this.unit=e,t.activeTexture(33984+e),t.bindTexture(this.target,this.texture)}return e},unbind:function(){--this.bindCount},decRef:function(){0>=--this.refCount&&F(this)}}),o.profile&&(a.getTotalTextureSize=function(){var t=0;return Object.keys(yt).forEach((function(e){t+=yt[e].stats.size})),t}),{create2D:function(e,r){function n(t,e){var r=i.texInfo;I.call(r);var a=C();return\"number\"==typeof t?A(a,0|t,\"number\"==typeof e?0|e:0|t):t?(P(r,t),S(a,t)):A(a,1,1),r.genMipmaps&&(a.mipmask=(a.width<<1)-1),i.mipmask=a.mipmask,c(i,a),i.internalformat=a.internalformat,n.width=a.width,n.height=a.height,D(i),E(a,3553),z(r,3553),R(),L(a),o.profile&&(i.stats.size=T(i.internalformat,i.type,a.width,a.height,r.genMipmaps,!1)),n.format=tt[i.internalformat],n.type=et[i.type],n.mag=rt[r.magFilter],n.min=nt[r.minFilter],n.wrapS=it[r.wrapS],n.wrapT=it[r.wrapT],n}var i=new O(3553);return yt[i.id]=i,a.textureCount++,n(e,r),n.subimage=function(t,e,r,a){e|=0,r|=0,a|=0;var o=v();return c(o,i),o.width=0,o.height=0,p(o,t),o.width=o.width||(i.width>>a)-e,o.height=o.height||(i.height>>a)-r,D(i),d(o,3553,e,r,a),R(),k(o),n},n.resize=function(e,r){var a=0|e,s=0|r||a;if(a===i.width&&s===i.height)return n;n.width=i.width=a,n.height=i.height=s,D(i);for(var l=0;i.mipmask>>l;++l){var c=a>>l,u=s>>l;if(!c||!u)break;t.texImage2D(3553,l,i.format,c,u,0,i.format,i.type,null)}return R(),o.profile&&(i.stats.size=T(i.internalformat,i.type,a,s,!1,!1)),n},n._reglType=\"texture2d\",n._texture=i,o.profile&&(n.stats=i.stats),n.destroy=function(){i.decRef()},n},createCube:function(e,r,n,i,s,l){function f(t,e,r,n,i,a){var s,l=h.texInfo;for(I.call(l),s=0;6>s;++s)g[s]=C();if(\"number\"!=typeof t&&t){if(\"object\"==typeof t)if(e)S(g[0],t),S(g[1],e),S(g[2],r),S(g[3],n),S(g[4],i),S(g[5],a);else if(P(l,t),u(h,t),\"faces\"in t)for(t=t.faces,s=0;6>s;++s)c(g[s],h),S(g[s],t[s]);else for(s=0;6>s;++s)S(g[s],t)}else for(t=0|t||1,s=0;6>s;++s)A(g[s],t,t);for(c(h,g[0]),h.mipmask=l.genMipmaps?(g[0].width<<1)-1:g[0].mipmask,h.internalformat=g[0].internalformat,f.width=g[0].width,f.height=g[0].height,D(h),s=0;6>s;++s)E(g[s],34069+s);for(z(l,34067),R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,l.genMipmaps,!0)),f.format=tt[h.internalformat],f.type=et[h.type],f.mag=rt[l.magFilter],f.min=nt[l.minFilter],f.wrapS=it[l.wrapS],f.wrapT=it[l.wrapT],s=0;6>s;++s)L(g[s]);return f}var h=new O(34067);yt[h.id]=h,a.cubeCount++;var g=Array(6);return f(e,r,n,i,s,l),f.subimage=function(t,e,r,n,i){r|=0,n|=0,i|=0;var a=v();return c(a,h),a.width=0,a.height=0,p(a,e),a.width=a.width||(h.width>>i)-r,a.height=a.height||(h.height>>i)-n,D(h),d(a,34069+t,r,n,i),R(),k(a),f},f.resize=function(e){if((e|=0)!==h.width){f.width=h.width=e,f.height=h.height=e,D(h);for(var r=0;6>r;++r)for(var n=0;h.mipmask>>n;++n)t.texImage2D(34069+r,n,h.format,e>>n,e>>n,0,h.format,h.type,null);return R(),o.profile&&(h.stats.size=T(h.internalformat,h.type,f.width,f.height,!1,!0)),f}},f._reglType=\"textureCube\",f._texture=h,o.profile&&(f.stats=h.stats),f.destroy=function(){h.decRef()},f},clear:function(){for(var e=0;e<xt;++e)t.activeTexture(33984+e),t.bindTexture(3553,null),bt[e]=null;Z(yt).forEach(F),a.cubeCount=0,a.textureCount=0},getTexture:function(t){return null},restore:function(){for(var e=0;e<xt;++e){var r=bt[e];r&&(r.bindCount=0,r.unit=-1,bt[e]=null)}Z(yt).forEach((function(e){e.texture=t.createTexture(),t.bindTexture(e.target,e.texture);for(var r=0;32>r;++r)if(0!=(e.mipmask&1<<r))if(3553===e.target)t.texImage2D(3553,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);else for(var n=0;6>n;++n)t.texImage2D(34069+n,r,e.internalformat,e.width>>r,e.height>>r,0,e.internalformat,e.type,null);z(e.texInfo,e.target)}))}}}function M(t,e,r,n,i,a){function o(t,e,r){this.target=t,this.texture=e,this.renderbuffer=r;var n=t=0;e?(t=e.width,n=e.height):r&&(t=r.width,n=r.height),this.width=t,this.height=n}function s(t){t&&(t.texture&&t.texture._texture.decRef(),t.renderbuffer&&t.renderbuffer._renderbuffer.decRef())}function l(t,e,r){t&&(t.texture?t.texture._texture.refCount+=1:t.renderbuffer._renderbuffer.refCount+=1)}function c(e,r){r&&(r.texture?t.framebufferTexture2D(36160,e,r.target,r.texture._texture.texture,0):t.framebufferRenderbuffer(36160,e,36161,r.renderbuffer._renderbuffer.renderbuffer))}function u(t){var e=3553,r=null,n=null,i=t;return\"object\"==typeof t&&(i=t.data,\"target\"in t&&(e=0|t.target)),\"texture2d\"===(t=i._reglType)||\"textureCube\"===t?r=i:\"renderbuffer\"===t&&(n=i,e=36161),new o(e,r,n)}function f(t,e,r,a,s){return r?((t=n.create2D({width:t,height:e,format:a,type:s}))._texture.refCount=0,new o(3553,t,null)):((t=i.create({width:t,height:e,format:a}))._renderbuffer.refCount=0,new o(36161,null,t))}function h(t){return t&&(t.texture||t.renderbuffer)}function p(t,e,r){t&&(t.texture?t.texture.resize(e,r):t.renderbuffer&&t.renderbuffer.resize(e,r),t.width=e,t.height=r)}function d(){this.id=T++,k[this.id]=this,this.framebuffer=t.createFramebuffer(),this.height=this.width=0,this.colorAttachments=[],this.depthStencilAttachment=this.stencilAttachment=this.depthAttachment=null}function g(t){t.colorAttachments.forEach(s),s(t.depthAttachment),s(t.stencilAttachment),s(t.depthStencilAttachment)}function m(e){t.deleteFramebuffer(e.framebuffer),e.framebuffer=null,a.framebufferCount--,delete k[e.id]}function v(e){var n;t.bindFramebuffer(36160,e.framebuffer);var i=e.colorAttachments;for(n=0;n<i.length;++n)c(36064+n,i[n]);for(n=i.length;n<r.maxColorAttachments;++n)t.framebufferTexture2D(36160,36064+n,3553,null,0);t.framebufferTexture2D(36160,33306,3553,null,0),t.framebufferTexture2D(36160,36096,3553,null,0),t.framebufferTexture2D(36160,36128,3553,null,0),c(36096,e.depthAttachment),c(36128,e.stencilAttachment),c(33306,e.depthStencilAttachment),t.checkFramebufferStatus(36160),t.isContextLost(),t.bindFramebuffer(36160,x.next?x.next.framebuffer:null),x.cur=x.next,t.getError()}function y(t,e){function r(t,e){var i,a=0,o=0,s=!0,c=!0;i=null;var p=!0,d=\"rgba\",m=\"uint8\",y=1,x=null,w=null,T=null,k=!1;\"number\"==typeof t?(a=0|t,o=0|e||a):t?(\"shape\"in t?(a=(o=t.shape)[0],o=o[1]):(\"radius\"in t&&(a=o=t.radius),\"width\"in t&&(a=t.width),\"height\"in t&&(o=t.height)),(\"color\"in t||\"colors\"in t)&&(i=t.color||t.colors,Array.isArray(i)),i||(\"colorCount\"in t&&(y=0|t.colorCount),\"colorTexture\"in t&&(p=!!t.colorTexture,d=\"rgba4\"),\"colorType\"in t&&(m=t.colorType,!p)&&(\"half float\"===m||\"float16\"===m?d=\"rgba16f\":\"float\"!==m&&\"float32\"!==m||(d=\"rgba32f\")),\"colorFormat\"in t&&(d=t.colorFormat,0<=b.indexOf(d)?p=!0:0<=_.indexOf(d)&&(p=!1))),(\"depthTexture\"in t||\"depthStencilTexture\"in t)&&(k=!(!t.depthTexture&&!t.depthStencilTexture)),\"depth\"in t&&(\"boolean\"==typeof t.depth?s=t.depth:(x=t.depth,c=!1)),\"stencil\"in t&&(\"boolean\"==typeof t.stencil?c=t.stencil:(w=t.stencil,s=!1)),\"depthStencil\"in t&&(\"boolean\"==typeof t.depthStencil?s=c=t.depthStencil:(T=t.depthStencil,c=s=!1))):a=o=1;var M=null,A=null,S=null,E=null;if(Array.isArray(i))M=i.map(u);else if(i)M=[u(i)];else for(M=Array(y),i=0;i<y;++i)M[i]=f(a,o,p,d,m);for(a=a||M[0].width,o=o||M[0].height,x?A=u(x):s&&!c&&(A=f(a,o,k,\"depth\",\"uint32\")),w?S=u(w):c&&!s&&(S=f(a,o,!1,\"stencil\",\"uint8\")),T?E=u(T):!x&&!w&&c&&s&&(E=f(a,o,k,\"depth stencil\",\"depth stencil\")),s=null,i=0;i<M.length;++i)l(M[i]),M[i]&&M[i].texture&&(c=bt[M[i].texture._texture.format]*_t[M[i].texture._texture.type],null===s&&(s=c));return l(A),l(S),l(E),g(n),n.width=a,n.height=o,n.colorAttachments=M,n.depthAttachment=A,n.stencilAttachment=S,n.depthStencilAttachment=E,r.color=M.map(h),r.depth=h(A),r.stencil=h(S),r.depthStencil=h(E),r.width=n.width,r.height=n.height,v(n),r}var n=new d;return a.framebufferCount++,r(t,e),U(r,{resize:function(t,e){var i=Math.max(0|t,1),a=Math.max(0|e||i,1);if(i===n.width&&a===n.height)return r;for(var o=n.colorAttachments,s=0;s<o.length;++s)p(o[s],i,a);return p(n.depthAttachment,i,a),p(n.stencilAttachment,i,a),p(n.depthStencilAttachment,i,a),n.width=r.width=i,n.height=r.height=a,v(n),r},_reglType:\"framebuffer\",_framebuffer:n,destroy:function(){m(n),g(n)},use:function(t){x.setFBO({framebuffer:r},t)}})}var x={cur:null,next:null,dirty:!1,setFBO:null},b=[\"rgba\"],_=[\"rgba4\",\"rgb565\",\"rgb5 a1\"];e.ext_srgb&&_.push(\"srgba\"),e.ext_color_buffer_half_float&&_.push(\"rgba16f\",\"rgb16f\"),e.webgl_color_buffer_float&&_.push(\"rgba32f\");var w=[\"uint8\"];e.oes_texture_half_float&&w.push(\"half float\",\"float16\"),e.oes_texture_float&&w.push(\"float\",\"float32\");var T=0,k={};return U(x,{getFramebuffer:function(t){return\"function\"==typeof t&&\"framebuffer\"===t._reglType&&(t=t._framebuffer)instanceof d?t:null},create:y,createCube:function(t){function e(t){var i,a={color:null},o=0,s=null;i=\"rgba\";var l=\"uint8\",c=1;if(\"number\"==typeof t?o=0|t:t?(\"shape\"in t?o=t.shape[0]:(\"radius\"in t&&(o=0|t.radius),\"width\"in t?o=0|t.width:\"height\"in t&&(o=0|t.height)),(\"color\"in t||\"colors\"in t)&&(s=t.color||t.colors,Array.isArray(s)),s||(\"colorCount\"in t&&(c=0|t.colorCount),\"colorType\"in t&&(l=t.colorType),\"colorFormat\"in t&&(i=t.colorFormat)),\"depth\"in t&&(a.depth=t.depth),\"stencil\"in t&&(a.stencil=t.stencil),\"depthStencil\"in t&&(a.depthStencil=t.depthStencil)):o=1,s)if(Array.isArray(s))for(t=[],i=0;i<s.length;++i)t[i]=s[i];else t=[s];else for(t=Array(c),s={radius:o,format:i,type:l},i=0;i<c;++i)t[i]=n.createCube(s);for(a.color=Array(t.length),i=0;i<t.length;++i)c=t[i],o=o||c.width,a.color[i]={target:34069,data:t[i]};for(i=0;6>i;++i){for(c=0;c<t.length;++c)a.color[c].target=34069+i;0<i&&(a.depth=r[0].depth,a.stencil=r[0].stencil,a.depthStencil=r[0].depthStencil),r[i]?r[i](a):r[i]=y(a)}return U(e,{width:o,height:o,color:t})}var r=Array(6);return e(t),U(e,{faces:r,resize:function(t){var n=0|t;if(n===e.width)return e;var i=e.color;for(t=0;t<i.length;++t)i[t].resize(n);for(t=0;6>t;++t)r[t].resize(n);return e.width=e.height=n,e},_reglType:\"framebufferCube\",destroy:function(){r.forEach((function(t){t.destroy()}))}})},clear:function(){Z(k).forEach(m)},restore:function(){x.cur=null,x.next=null,x.dirty=!0,Z(k).forEach((function(e){e.framebuffer=t.createFramebuffer(),v(e)}))}})}function A(){this.w=this.z=this.y=this.x=this.state=0,this.buffer=null,this.size=0,this.normalized=!1,this.type=5126,this.divisor=this.stride=this.offset=0}function S(t,e,r,n,i){function a(){this.id=++c,this.attributes=[];var t=e.oes_vertex_array_object;this.vao=t?t.createVertexArrayOES():null,u[this.id]=this,this.buffers=[]}var o=r.maxAttributes,s=Array(o);for(r=0;r<o;++r)s[r]=new A;var c=0,u={},f={Record:A,scope:{},state:s,currentVAO:null,targetVAO:null,restore:e.oes_vertex_array_object?function(){e.oes_vertex_array_object&&Z(u).forEach((function(t){t.refresh()}))}:function(){},createVAO:function(t){function e(t){for(var n=0;n<r.buffers.length;++n)r.buffers[n].destroy();r.buffers.length=0,(n=r.attributes).length=t.length;for(var a=0;a<t.length;++a){var o=t[a],s=n[a]=new A;Array.isArray(o)||X(o)||l(o)?(o=i.create(o,34962,!1,!0),s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1,r.buffers.push(o)):i.getBuffer(o)?(s.buffer=i.getBuffer(o),s.size=0|s.buffer.dimension,s.normalized=!1,s.type=s.buffer.dtype,s.offset=0,s.stride=0,s.divisor=0,s.state=1):i.getBuffer(o.buffer)?(s.buffer=i.getBuffer(o.buffer),s.size=0|(+o.size||s.buffer.dimension),s.normalized=!!o.normalized||!1,s.type=\"type\"in o?Q[o.type]:s.buffer.dtype,s.offset=0|(o.offset||0),s.stride=0|(o.stride||0),s.divisor=0|(o.divisor||0),s.state=1):\"x\"in o&&(s.x=+o.x||0,s.y=+o.y||0,s.z=+o.z||0,s.w=+o.w||0,s.state=2)}return r.refresh(),e}var r=new a;return n.vaoCount+=1,e.destroy=function(){r.destroy()},e._vao=r,e._reglType=\"vao\",e(t)},getVAO:function(t){return\"function\"==typeof t&&t._vao?t._vao:null},destroyBuffer:function(e){for(var r=0;r<s.length;++r){var n=s[r];n.buffer===e&&(t.disableVertexAttribArray(r),n.buffer=null)}},setVAO:e.oes_vertex_array_object?function(t){if(t!==f.currentVAO){var r=e.oes_vertex_array_object;t?r.bindVertexArrayOES(t.vao):r.bindVertexArrayOES(null),f.currentVAO=t}}:function(r){if(r!==f.currentVAO){if(r)r.bindAttrs();else for(var n=e.angle_instanced_arrays,i=0;i<s.length;++i){var a=s[i];a.buffer?(t.enableVertexAttribArray(i),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offfset),n&&n.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}f.currentVAO=r}},clear:e.oes_vertex_array_object?function(){Z(u).forEach((function(t){t.destroy()}))}:function(){}};return a.prototype.bindAttrs=function(){for(var r=e.angle_instanced_arrays,n=this.attributes,i=0;i<n.length;++i){var a=n[i];a.buffer?(t.enableVertexAttribArray(i),t.bindBuffer(34962,a.buffer.buffer),t.vertexAttribPointer(i,a.size,a.type,a.normalized,a.stride,a.offset),r&&r.vertexAttribDivisorANGLE(i,a.divisor)):(t.disableVertexAttribArray(i),t.vertexAttrib4f(i,a.x,a.y,a.z,a.w))}for(r=n.length;r<o;++r)t.disableVertexAttribArray(r)},a.prototype.refresh=function(){var t=e.oes_vertex_array_object;t&&(t.bindVertexArrayOES(this.vao),this.bindAttrs(),f.currentVAO=this)},a.prototype.destroy=function(){if(this.vao){var t=e.oes_vertex_array_object;this===f.currentVAO&&(f.currentVAO=null,t.bindVertexArrayOES(null)),t.deleteVertexArrayOES(this.vao),this.vao=null}u[this.id]&&(delete u[this.id],--n.vaoCount)},f}function E(t,e,r,n){function i(t,e,r,n){this.name=t,this.id=e,this.location=r,this.info=n}function a(t,e){for(var r=0;r<t.length;++r)if(t[r].id===e.id)return void(t[r].location=e.location);t.push(e)}function o(r,n,i){if(!(o=(i=35632===r?c:u)[n])){var a=e.str(n),o=t.createShader(r);t.shaderSource(o,a),t.compileShader(o),i[n]=o}return o}function s(t,e){this.id=p++,this.fragId=t,this.vertId=e,this.program=null,this.uniforms=[],this.attributes=[],n.profile&&(this.stats={uniformsCount:0,attributesCount:0})}function l(r,s,l){var c;c=o(35632,r.fragId);var u=o(35633,r.vertId);if(s=r.program=t.createProgram(),t.attachShader(s,c),t.attachShader(s,u),l)for(c=0;c<l.length;++c)u=l[c],t.bindAttribLocation(s,u[0],u[1]);t.linkProgram(s),u=t.getProgramParameter(s,35718),n.profile&&(r.stats.uniformsCount=u);var f=r.uniforms;for(c=0;c<u;++c)if(l=t.getActiveUniform(s,c))if(1<l.size)for(var h=0;h<l.size;++h){var p=l.name.replace(\"[0]\",\"[\"+h+\"]\");a(f,new i(p,e.id(p),t.getUniformLocation(s,p),l))}else a(f,new i(l.name,e.id(l.name),t.getUniformLocation(s,l.name),l));for(u=t.getProgramParameter(s,35721),n.profile&&(r.stats.attributesCount=u),r=r.attributes,c=0;c<u;++c)(l=t.getActiveAttrib(s,c))&&a(r,new i(l.name,e.id(l.name),t.getAttribLocation(s,l.name),l))}var c={},u={},f={},h=[],p=0;return n.profile&&(r.getMaxUniformsCount=function(){var t=0;return h.forEach((function(e){e.stats.uniformsCount>t&&(t=e.stats.uniformsCount)})),t},r.getMaxAttributesCount=function(){var t=0;return h.forEach((function(e){e.stats.attributesCount>t&&(t=e.stats.attributesCount)})),t}),{clear:function(){var e=t.deleteShader.bind(t);Z(c).forEach(e),c={},Z(u).forEach(e),u={},h.forEach((function(e){t.deleteProgram(e.program)})),h.length=0,f={},r.shaderCount=0},program:function(t,e,n,i){var a=f[e];a||(a=f[e]={});var o=a[t];return o&&!i?o:(e=new s(e,t),r.shaderCount++,l(e,n,i),o||(a[t]=e),h.push(e),e)},restore:function(){c={},u={};for(var t=0;t<h.length;++t)l(h[t],null,h[t].attributes.map((function(t){return[t.location,t.name]})))},shader:o,frag:-1,vert:-1}}function C(t,e,r,n,i,a,o){function s(i){var a;a=null===e.next?5121:e.next.colorAttachments[0].texture._texture.type;var o=0,s=0,l=n.framebufferWidth,c=n.framebufferHeight,u=null;return X(i)?u=i:i&&(o=0|i.x,s=0|i.y,l=0|(i.width||n.framebufferWidth-o),c=0|(i.height||n.framebufferHeight-s),u=i.data||null),r(),i=l*c*4,u||(5121===a?u=new Uint8Array(i):5126===a&&(u=u||new Float32Array(i))),t.pixelStorei(3333,4),t.readPixels(o,s,l,c,6408,a,u),u}return function(t){return t&&\"framebuffer\"in t?function(t){var r;return e.setFBO({framebuffer:t.framebuffer},(function(){r=s(t)})),r}(t):s(t)}}function L(t){return Array.prototype.slice.call(t)}function I(t){return L(t).join(\"\")}function P(){function t(){var t=[],e=[];return U((function(){t.push.apply(t,L(arguments))}),{def:function(){var n=\"v\"+r++;return e.push(n),0<arguments.length&&(t.push(n,\"=\"),t.push.apply(t,L(arguments)),t.push(\";\")),n},toString:function(){return I([0<e.length?\"var \"+e.join(\",\")+\";\":\"\",I(t)])}})}function e(){function e(t,e){n(t,e,\"=\",r.def(t,e),\";\")}var r=t(),n=t(),i=r.toString,a=n.toString;return U((function(){r.apply(r,L(arguments))}),{def:r.def,entry:r,exit:n,save:e,set:function(t,n,i){e(t,n),r(t,n,\"=\",i,\";\")},toString:function(){return i()+a()}})}var r=0,n=[],i=[],a=t(),o={};return{global:a,link:function(t){for(var e=0;e<i.length;++e)if(i[e]===t)return n[e];return e=\"g\"+r++,n.push(e),i.push(t),e},block:t,proc:function(t,r){function n(){var t=\"a\"+i.length;return i.push(t),t}var i=[];r=r||0;for(var a=0;a<r;++a)n();var s=(a=e()).toString;return o[t]=U(a,{arg:n,toString:function(){return I([\"function(\",i.join(),\"){\",s(),\"}\"])}})},scope:e,cond:function(){var t=I(arguments),r=e(),n=e(),i=r.toString,a=n.toString;return U(r,{then:function(){return r.apply(r,L(arguments)),this},else:function(){return n.apply(n,L(arguments)),this},toString:function(){var e=a();return e&&(e=\"else{\"+e+\"}\"),I([\"if(\",t,\"){\",i(),\"}\",e])}})},compile:function(){var t=['\"use strict\";',a,\"return {\"];Object.keys(o).forEach((function(e){t.push('\"',e,'\":',o[e].toString(),\",\")})),t.push(\"}\");var e=I(t).replace(/;/g,\";\\n\").replace(/}/g,\"}\\n\").replace(/{/g,\"{\\n\");return Function.apply(null,n.concat(e)).apply(null,i)}}}function z(t){return Array.isArray(t)||X(t)||l(t)}function O(t){return t.sort((function(t,e){return\"viewport\"===t?-1:\"viewport\"===e?1:t<e?-1:1}))}function D(t,e,r,n){this.thisDep=t,this.contextDep=e,this.propDep=r,this.append=n}function R(t){return t&&!(t.thisDep||t.contextDep||t.propDep)}function F(t){return new D(!1,!1,!1,t)}function B(t,e){var r=t.type;return 0===r?new D(!0,1<=(r=t.data.length),2<=r,e):4===r?new D((r=t.data).thisDep,r.contextDep,r.propDep,e):new D(3===r,2===r,1===r,e)}function N(t,e,r,n,i,o,s,l,c,u,f,h,p,d,g){function v(t){return t.replace(\".\",\"_\")}function y(t,e,r){var n=v(t);rt.push(t),et[n]=tt[n]=!!r,it[n]=e}function x(t,e,r){var n=v(t);rt.push(t),Array.isArray(r)?(tt[n]=r.slice(),et[n]=r.slice()):tt[n]=et[n]=r,at[n]=e}function b(){var t=P(),r=t.link,n=t.global;t.id=lt++,t.batchId=\"0\";var i=r(ot),a=t.shared={props:\"a0\"};Object.keys(ot).forEach((function(t){a[t]=n.def(i,\".\",t)}));var o=t.next={},s=t.current={};Object.keys(at).forEach((function(t){Array.isArray(tt[t])&&(o[t]=n.def(a.next,\".\",t),s[t]=n.def(a.current,\".\",t))}));var l=t.constants={};Object.keys(st).forEach((function(t){l[t]=n.def(JSON.stringify(st[t]))})),t.invoke=function(e,n){switch(n.type){case 0:var i=[\"this\",a.context,a.props,t.batchId];return e.def(r(n.data),\".call(\",i.slice(0,Math.max(n.data.length+1,4)),\")\");case 1:return e.def(a.props,n.data);case 2:return e.def(a.context,n.data);case 3:return e.def(\"this\",n.data);case 4:return n.data.append(t,e),n.data.ref}},t.attribCache={};var c={};return t.scopeAttrib=function(t){if((t=e.id(t))in c)return c[t];var n=u.scope[t];return n||(n=u.scope[t]=new Z),c[t]=r(n)},t}function _(t,e){var r=t.static,n=t.dynamic;if(\"framebuffer\"in r){var i=r.framebuffer;return i?(i=l.getFramebuffer(i),F((function(t,e){var r=t.link(i),n=t.shared;return e.set(n.framebuffer,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\".width\"),e.set(n,\".framebufferHeight\",r+\".height\"),r}))):F((function(t,e){var r=t.shared;return e.set(r.framebuffer,\".next\",\"null\"),r=r.context,e.set(r,\".framebufferWidth\",r+\".drawingBufferWidth\"),e.set(r,\".framebufferHeight\",r+\".drawingBufferHeight\"),\"null\"}))}if(\"framebuffer\"in n){var a=n.framebuffer;return B(a,(function(t,e){var r=t.invoke(e,a),n=t.shared,i=n.framebuffer;r=e.def(i,\".getFramebuffer(\",r,\")\");return e.set(i,\".next\",r),n=n.context,e.set(n,\".framebufferWidth\",r+\"?\"+r+\".width:\"+n+\".drawingBufferWidth\"),e.set(n,\".framebufferHeight\",r+\"?\"+r+\".height:\"+n+\".drawingBufferHeight\"),r}))}return null}function w(t,r,n){function i(t){if(t in a){var r=e.id(a[t]);return(t=F((function(){return r}))).id=r,t}if(t in o){var n=o[t];return B(n,(function(t,e){var r=t.invoke(e,n);return e.def(t.shared.strings,\".id(\",r,\")\")}))}return null}var a=t.static,o=t.dynamic,s=i(\"frag\"),l=i(\"vert\"),c=null;return R(s)&&R(l)?(c=f.program(l.id,s.id,null,n),t=F((function(t,e){return t.link(c)}))):t=new D(s&&s.thisDep||l&&l.thisDep,s&&s.contextDep||l&&l.contextDep,s&&s.propDep||l&&l.propDep,(function(t,e){var r,n,i=t.shared.shader;return r=s?s.append(t,e):e.def(i,\".\",\"frag\"),n=l?l.append(t,e):e.def(i,\".\",\"vert\"),e.def(i+\".program(\"+n+\",\"+r+\")\")})),{frag:s,vert:l,progVar:t,program:c}}function T(t,e){function r(t,e){if(t in n){var r=0|n[t];return F((function(t,n){return e&&(t.OFFSET=r),r}))}if(t in i){var o=i[t];return B(o,(function(t,r){var n=t.invoke(r,o);return e&&(t.OFFSET=n),n}))}return e&&a?F((function(t,e){return t.OFFSET=\"0\",0})):null}var n=t.static,i=t.dynamic,a=function(){if(\"elements\"in n){var t=n.elements;z(t)?t=o.getElements(o.create(t,!0)):t&&(t=o.getElements(t));var e=F((function(e,r){if(t){var n=e.link(t);return e.ELEMENTS=n}return e.ELEMENTS=null}));return e.value=t,e}if(\"elements\"in i){var r=i.elements;return B(r,(function(t,e){var n=(i=t.shared).isBufferArgs,i=i.elements,a=t.invoke(e,r),o=e.def(\"null\");n=e.def(n,\"(\",a,\")\"),a=t.cond(n).then(o,\"=\",i,\".createStream(\",a,\");\").else(o,\"=\",i,\".getElements(\",a,\");\");return e.entry(a),e.exit(t.cond(n).then(i,\".destroyStream(\",o,\");\")),t.ELEMENTS=o}))}return null}(),s=r(\"offset\",!0);return{elements:a,primitive:function(){if(\"primitive\"in n){var t=n.primitive;return F((function(e,r){return nt[t]}))}if(\"primitive\"in i){var e=i.primitive;return B(e,(function(t,r){var n=t.constants.primTypes,i=t.invoke(r,e);return r.def(n,\"[\",i,\"]\")}))}return a?R(a)?a.value?F((function(t,e){return e.def(t.ELEMENTS,\".primType\")})):F((function(){return 4})):new D(a.thisDep,a.contextDep,a.propDep,(function(t,e){var r=t.ELEMENTS;return e.def(r,\"?\",r,\".primType:\",4)})):null}(),count:function(){if(\"count\"in n){var t=0|n.count;return F((function(){return t}))}if(\"count\"in i){var e=i.count;return B(e,(function(t,r){return t.invoke(r,e)}))}return a?R(a)?a?s?new D(s.thisDep,s.contextDep,s.propDep,(function(t,e){return e.def(t.ELEMENTS,\".vertCount-\",t.OFFSET)})):F((function(t,e){return e.def(t.ELEMENTS,\".vertCount\")})):F((function(){return-1})):new D(a.thisDep||s.thisDep,a.contextDep||s.contextDep,a.propDep||s.propDep,(function(t,e){var r=t.ELEMENTS;return t.OFFSET?e.def(r,\"?\",r,\".vertCount-\",t.OFFSET,\":-1\"):e.def(r,\"?\",r,\".vertCount:-1\")})):null}(),instances:r(\"instances\",!1),offset:s}}function k(t,r){var n=t.static,a=t.dynamic,o={};return Object.keys(n).forEach((function(t){var r=n[t],a=e.id(t),s=new Z;if(z(r))s.state=1,s.buffer=i.getBuffer(i.create(r,34962,!1,!0)),s.type=0;else if(c=i.getBuffer(r))s.state=1,s.buffer=c,s.type=0;else if(\"constant\"in r){var l=r.constant;s.buffer=\"null\",s.state=2,\"number\"==typeof l?s.x=l:wt.forEach((function(t,e){e<l.length&&(s[t]=l[e])}))}else{var c=z(r.buffer)?i.getBuffer(i.create(r.buffer,34962,!1,!0)):i.getBuffer(r.buffer),u=0|r.offset,f=0|r.stride,h=0|r.size,p=!!r.normalized,d=0;\"type\"in r&&(d=Q[r.type]),r=0|r.divisor,s.buffer=c,s.state=1,s.size=h,s.normalized=p,s.type=d||c.dtype,s.offset=u,s.stride=f,s.divisor=r}o[t]=F((function(t,e){var r=t.attribCache;if(a in r)return r[a];var n={isStream:!1};return Object.keys(s).forEach((function(t){n[t]=s[t]})),s.buffer&&(n.buffer=t.link(s.buffer),n.type=n.type||n.buffer+\".dtype\"),r[a]=n}))})),Object.keys(a).forEach((function(t){var e=a[t];o[t]=B(e,(function(t,r){function n(t){r(l[t],\"=\",i,\".\",t,\"|0;\")}var i=t.invoke(r,e),a=t.shared,o=t.constants,s=a.isBufferArgs,l=(a=a.buffer,{isStream:r.def(!1)}),c=new Z;c.state=1,Object.keys(c).forEach((function(t){l[t]=r.def(\"\"+c[t])}));var u=l.buffer,f=l.type;return r(\"if(\",s,\"(\",i,\")){\",l.isStream,\"=true;\",u,\"=\",a,\".createStream(\",34962,\",\",i,\");\",f,\"=\",u,\".dtype;\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\");\",\"if(\",u,\"){\",f,\"=\",u,\".dtype;\",'}else if(\"constant\" in ',i,\"){\",l.state,\"=\",2,\";\",\"if(typeof \"+i+'.constant === \"number\"){',l[wt[0]],\"=\",i,\".constant;\",wt.slice(1).map((function(t){return l[t]})).join(\"=\"),\"=0;\",\"}else{\",wt.map((function(t,e){return l[t]+\"=\"+i+\".constant.length>\"+e+\"?\"+i+\".constant[\"+e+\"]:0;\"})).join(\"\"),\"}}else{\",\"if(\",s,\"(\",i,\".buffer)){\",u,\"=\",a,\".createStream(\",34962,\",\",i,\".buffer);\",\"}else{\",u,\"=\",a,\".getBuffer(\",i,\".buffer);\",\"}\",f,'=\"type\" in ',i,\"?\",o.glTypes,\"[\",i,\".type]:\",u,\".dtype;\",l.normalized,\"=!!\",i,\".normalized;\"),n(\"size\"),n(\"offset\"),n(\"stride\"),n(\"divisor\"),r(\"}}\"),r.exit(\"if(\",l.isStream,\"){\",a,\".destroyStream(\",u,\");\",\"}\"),l}))})),o}function M(t,e,n,i,o){function s(t){var e=c[t];e&&(h[t]=e)}var l=function(t,e){if(\"string\"==typeof(r=t.static).frag&&\"string\"==typeof r.vert){if(0<Object.keys(e.dynamic).length)return null;var r=e.static,n=Object.keys(r);if(0<n.length&&\"number\"==typeof r[n[0]]){for(var i=[],a=0;a<n.length;++a)i.push([0|r[n[a]],n[a]]);return i}}return null}(t,e),c=function(t,e,r){function n(t){if(t in i){var r=i[t];t=!0;var n,o,s=0|r.x,l=0|r.y;return\"width\"in r?n=0|r.width:t=!1,\"height\"in r?o=0|r.height:t=!1,new D(!t&&e&&e.thisDep,!t&&e&&e.contextDep,!t&&e&&e.propDep,(function(t,e){var i=t.shared.context,a=n;\"width\"in r||(a=e.def(i,\".\",\"framebufferWidth\",\"-\",s));var c=o;return\"height\"in r||(c=e.def(i,\".\",\"framebufferHeight\",\"-\",l)),[s,l,a,c]}))}if(t in a){var c=a[t];return t=B(c,(function(t,e){var r=t.invoke(e,c),n=t.shared.context,i=e.def(r,\".x|0\"),a=e.def(r,\".y|0\");return[i,a,e.def('\"width\" in ',r,\"?\",r,\".width|0:\",\"(\",n,\".\",\"framebufferWidth\",\"-\",i,\")\"),r=e.def('\"height\" in ',r,\"?\",r,\".height|0:\",\"(\",n,\".\",\"framebufferHeight\",\"-\",a,\")\")]})),e&&(t.thisDep=t.thisDep||e.thisDep,t.contextDep=t.contextDep||e.contextDep,t.propDep=t.propDep||e.propDep),t}return e?new D(e.thisDep,e.contextDep,e.propDep,(function(t,e){var r=t.shared.context;return[0,0,e.def(r,\".\",\"framebufferWidth\"),e.def(r,\".\",\"framebufferHeight\")]})):null}var i=t.static,a=t.dynamic;if(t=n(\"viewport\")){var o=t;t=new D(t.thisDep,t.contextDep,t.propDep,(function(t,e){var r=o.append(t,e),n=t.shared.context;return e.set(n,\".viewportWidth\",r[2]),e.set(n,\".viewportHeight\",r[3]),r}))}return{viewport:t,scissor_box:n(\"scissor.box\")}}(t,d=_(t)),f=T(t),h=function(t,e){var r=t.static,n=t.dynamic,i={};return rt.forEach((function(t){function e(e,a){if(t in r){var s=e(r[t]);i[o]=F((function(){return s}))}else if(t in n){var l=n[t];i[o]=B(l,(function(t,e){return a(t,e,t.invoke(e,l))}))}}var o=v(t);switch(t){case\"cull.enable\":case\"blend.enable\":case\"dither\":case\"stencil.enable\":case\"depth.enable\":case\"scissor.enable\":case\"polygonOffset.enable\":case\"sample.alpha\":case\"sample.enable\":case\"depth.mask\":return e((function(t){return t}),(function(t,e,r){return r}));case\"depth.func\":return e((function(t){return Mt[t]}),(function(t,e,r){return e.def(t.constants.compareFuncs,\"[\",r,\"]\")}));case\"depth.range\":return e((function(t){return t}),(function(t,e,r){return[e.def(\"+\",r,\"[0]\"),e=e.def(\"+\",r,\"[1]\")]}));case\"blend.func\":return e((function(t){return[kt[\"srcRGB\"in t?t.srcRGB:t.src],kt[\"dstRGB\"in t?t.dstRGB:t.dst],kt[\"srcAlpha\"in t?t.srcAlpha:t.src],kt[\"dstAlpha\"in t?t.dstAlpha:t.dst]]}),(function(t,e,r){function n(t,n){return e.def('\"',t,n,'\" in ',r,\"?\",r,\".\",t,n,\":\",r,\".\",t)}t=t.constants.blendFuncs;var i=n(\"src\",\"RGB\"),a=n(\"dst\",\"RGB\"),o=(i=e.def(t,\"[\",i,\"]\"),e.def(t,\"[\",n(\"src\",\"Alpha\"),\"]\"));return[i,a=e.def(t,\"[\",a,\"]\"),o,t=e.def(t,\"[\",n(\"dst\",\"Alpha\"),\"]\")]}));case\"blend.equation\":return e((function(t){return\"string\"==typeof t?[J[t],J[t]]:\"object\"==typeof t?[J[t.rgb],J[t.alpha]]:void 0}),(function(t,e,r){var n=t.constants.blendEquations,i=e.def(),a=e.def();return(t=t.cond(\"typeof \",r,'===\"string\"')).then(i,\"=\",a,\"=\",n,\"[\",r,\"];\"),t.else(i,\"=\",n,\"[\",r,\".rgb];\",a,\"=\",n,\"[\",r,\".alpha];\"),e(t),[i,a]}));case\"blend.color\":return e((function(t){return a(4,(function(e){return+t[e]}))}),(function(t,e,r){return a(4,(function(t){return e.def(\"+\",r,\"[\",t,\"]\")}))}));case\"stencil.mask\":return e((function(t){return 0|t}),(function(t,e,r){return e.def(r,\"|0\")}));case\"stencil.func\":return e((function(t){return[Mt[t.cmp||\"keep\"],t.ref||0,\"mask\"in t?t.mask:-1]}),(function(t,e,r){return[t=e.def('\"cmp\" in ',r,\"?\",t.constants.compareFuncs,\"[\",r,\".cmp]\",\":\",7680),e.def(r,\".ref|0\"),e=e.def('\"mask\" in ',r,\"?\",r,\".mask|0:-1\")]}));case\"stencil.opFront\":case\"stencil.opBack\":return e((function(e){return[\"stencil.opBack\"===t?1029:1028,At[e.fail||\"keep\"],At[e.zfail||\"keep\"],At[e.zpass||\"keep\"]]}),(function(e,r,n){function i(t){return r.def('\"',t,'\" in ',n,\"?\",a,\"[\",n,\".\",t,\"]:\",7680)}var a=e.constants.stencilOps;return[\"stencil.opBack\"===t?1029:1028,i(\"fail\"),i(\"zfail\"),i(\"zpass\")]}));case\"polygonOffset.offset\":return e((function(t){return[0|t.factor,0|t.units]}),(function(t,e,r){return[e.def(r,\".factor|0\"),e=e.def(r,\".units|0\")]}));case\"cull.face\":return e((function(t){var e=0;return\"front\"===t?e=1028:\"back\"===t&&(e=1029),e}),(function(t,e,r){return e.def(r,'===\"front\"?',1028,\":\",1029)}));case\"lineWidth\":return e((function(t){return t}),(function(t,e,r){return r}));case\"frontFace\":return e((function(t){return St[t]}),(function(t,e,r){return e.def(r+'===\"cw\"?2304:2305')}));case\"colorMask\":return e((function(t){return t.map((function(t){return!!t}))}),(function(t,e,r){return a(4,(function(t){return\"!!\"+r+\"[\"+t+\"]\"}))}));case\"sample.coverage\":return e((function(t){return[\"value\"in t?t.value:1,!!t.invert]}),(function(t,e,r){return[e.def('\"value\" in ',r,\"?+\",r,\".value:1\"),e=e.def(\"!!\",r,\".invert\")]}))}})),i}(t),p=w(t,0,l);s(\"viewport\"),s(v(\"scissor.box\"));var d,g=0<Object.keys(h).length;if((d={framebuffer:d,draw:f,shader:p,state:h,dirty:g,scopeVAO:null,drawVAO:null,useVAO:!1,attributes:{}}).profile=function(t){var e,r=t.static;if(t=t.dynamic,\"profile\"in r){var n=!!r.profile;(e=F((function(t,e){return n}))).enable=n}else if(\"profile\"in t){var i=t.profile;e=B(i,(function(t,e){return t.invoke(e,i)}))}return e}(t),d.uniforms=function(t,e){var r=t.static,n=t.dynamic,i={};return Object.keys(r).forEach((function(t){var e,n=r[t];if(\"number\"==typeof n||\"boolean\"==typeof n)e=F((function(){return n}));else if(\"function\"==typeof n){var o=n._reglType;\"texture2d\"===o||\"textureCube\"===o?e=F((function(t){return t.link(n)})):\"framebuffer\"!==o&&\"framebufferCube\"!==o||(e=F((function(t){return t.link(n.color[0])})))}else m(n)&&(e=F((function(t){return t.global.def(\"[\",a(n.length,(function(t){return n[t]})),\"]\")})));e.value=n,i[t]=e})),Object.keys(n).forEach((function(t){var e=n[t];i[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),i}(n),d.drawVAO=d.scopeVAO=function(t,e){var r=t.static,n=t.dynamic;if(\"vao\"in r){var i=r.vao;return null!==i&&null===u.getVAO(i)&&(i=u.createVAO(i)),F((function(t){return t.link(u.getVAO(i))}))}if(\"vao\"in n){var a=n.vao;return B(a,(function(t,e){var r=t.invoke(e,a);return e.def(t.shared.vao+\".getVAO(\"+r+\")\")}))}return null}(t),!d.drawVAO&&p.program&&!l&&r.angle_instanced_arrays){var y=!0;if(t=p.program.attributes.map((function(t){return t=e.static[t],y=y&&!!t,t})),y&&0<t.length){var x=u.getVAO(u.createVAO(t));d.drawVAO=new D(null,null,null,(function(t,e){return t.link(x)})),d.useVAO=!0}}return l?d.useVAO=!0:d.attributes=k(e),d.context=function(t){var e=t.static,r=t.dynamic,n={};return Object.keys(e).forEach((function(t){var r=e[t];n[t]=F((function(t,e){return\"number\"==typeof r||\"boolean\"==typeof r?\"\"+r:t.link(r)}))})),Object.keys(r).forEach((function(t){var e=r[t];n[t]=B(e,(function(t,r){return t.invoke(r,e)}))})),n}(i),d}function A(t,e,r){var n=t.shared.context,i=t.scope();Object.keys(r).forEach((function(a){e.save(n,\".\"+a),i(n,\".\",a,\"=\",r[a].append(t,e),\";\")})),e(i)}function S(t,e,r,n){var i,a=(s=t.shared).gl,o=s.framebuffer;$&&(i=e.def(s.extensions,\".webgl_draw_buffers\"));var s=(l=t.constants).drawBuffer,l=l.backBuffer;t=r?r.append(t,e):e.def(o,\".next\"),n||e(\"if(\",t,\"!==\",o,\".cur){\"),e(\"if(\",t,\"){\",a,\".bindFramebuffer(\",36160,\",\",t,\".framebuffer);\"),$&&e(i,\".drawBuffersWEBGL(\",s,\"[\",t,\".colorAttachments.length]);\"),e(\"}else{\",a,\".bindFramebuffer(\",36160,\",null);\"),$&&e(i,\".drawBuffersWEBGL(\",l,\");\"),e(\"}\",o,\".cur=\",t,\";\"),n||e(\"}\")}function E(t,e,r){var n=t.shared,i=n.gl,o=t.current,s=t.next,l=n.current,c=n.next,u=t.cond(l,\".dirty\");rt.forEach((function(e){var n,f;if(!((e=v(e))in r.state))if(e in s){n=s[e],f=o[e];var h=a(tt[e].length,(function(t){return u.def(n,\"[\",t,\"]\")}));u(t.cond(h.map((function(t,e){return t+\"!==\"+f+\"[\"+e+\"]\"})).join(\"||\")).then(i,\".\",at[e],\"(\",h,\");\",h.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\"))}else n=u.def(c,\".\",e),h=t.cond(n,\"!==\",l,\".\",e),u(h),e in it?h(t.cond(n).then(i,\".enable(\",it[e],\");\").else(i,\".disable(\",it[e],\");\"),l,\".\",e,\"=\",n,\";\"):h(i,\".\",at[e],\"(\",n,\");\",l,\".\",e,\"=\",n,\";\")})),0===Object.keys(r.state).length&&u(l,\".dirty=false;\"),e(u)}function C(t,e,r,n){var i=t.shared,a=t.current,o=i.current,s=i.gl;O(Object.keys(r)).forEach((function(i){var l=r[i];if(!n||n(l)){var c=l.append(t,e);if(it[i]){var u=it[i];R(l)?e(s,c?\".enable(\":\".disable(\",u,\");\"):e(t.cond(c).then(s,\".enable(\",u,\");\").else(s,\".disable(\",u,\");\")),e(o,\".\",i,\"=\",c,\";\")}else if(m(c)){var f=a[i];e(s,\".\",at[i],\"(\",c,\");\",c.map((function(t,e){return f+\"[\"+e+\"]=\"+t})).join(\";\"),\";\")}else e(s,\".\",at[i],\"(\",c,\");\",o,\".\",i,\"=\",c,\";\")}}))}function L(t,e){K&&(t.instancing=e.def(t.shared.extensions,\".angle_instanced_arrays\"))}function I(t,e,r,n,i){function a(){return\"undefined\"==typeof performance?\"Date.now()\":\"performance.now()\"}function o(t){t(c=e.def(),\"=\",a(),\";\"),\"string\"==typeof i?t(h,\".count+=\",i,\";\"):t(h,\".count++;\"),d&&(n?t(u=e.def(),\"=\",g,\".getNumPendingQueries();\"):t(g,\".beginQuery(\",h,\");\"))}function s(t){t(h,\".cpuTime+=\",a(),\"-\",c,\";\"),d&&(n?t(g,\".pushScopeStats(\",u,\",\",g,\".getNumPendingQueries(),\",h,\");\"):t(g,\".endQuery();\"))}function l(t){var r=e.def(p,\".profile\");e(p,\".profile=\",t,\";\"),e.exit(p,\".profile=\",r,\";\")}var c,u,f=t.shared,h=t.stats,p=f.current,g=f.timer;if(r=r.profile){if(R(r))return void(r.enable?(o(e),s(e.exit),l(\"true\")):l(\"false\"));l(r=r.append(t,e))}else r=e.def(p,\".profile\");o(f=t.block()),e(\"if(\",r,\"){\",f,\"}\"),s(t=t.block()),e.exit(\"if(\",r,\"){\",t,\"}\")}function N(t,e,r,n,i){function a(r,n,i){function a(){e(\"if(!\",u,\".buffer){\",l,\".enableVertexAttribArray(\",c,\");}\");var r,a=i.type;r=i.size?e.def(i.size,\"||\",n):n,e(\"if(\",u,\".type!==\",a,\"||\",u,\".size!==\",r,\"||\",p.map((function(t){return u+\".\"+t+\"!==\"+i[t]})).join(\"||\"),\"){\",l,\".bindBuffer(\",34962,\",\",f,\".buffer);\",l,\".vertexAttribPointer(\",[c,r,a,i.normalized,i.stride,i.offset],\");\",u,\".type=\",a,\";\",u,\".size=\",r,\";\",p.map((function(t){return u+\".\"+t+\"=\"+i[t]+\";\"})).join(\"\"),\"}\"),K&&(a=i.divisor,e(\"if(\",u,\".divisor!==\",a,\"){\",t.instancing,\".vertexAttribDivisorANGLE(\",[c,a],\");\",u,\".divisor=\",a,\";}\"))}function s(){e(\"if(\",u,\".buffer){\",l,\".disableVertexAttribArray(\",c,\");\",u,\".buffer=null;\",\"}if(\",wt.map((function(t,e){return u+\".\"+t+\"!==\"+h[e]})).join(\"||\"),\"){\",l,\".vertexAttrib4f(\",c,\",\",h,\");\",wt.map((function(t,e){return u+\".\"+t+\"=\"+h[e]+\";\"})).join(\"\"),\"}\")}var l=o.gl,c=e.def(r,\".location\"),u=e.def(o.attributes,\"[\",c,\"]\");r=i.state;var f=i.buffer,h=[i.x,i.y,i.z,i.w],p=[\"buffer\",\"normalized\",\"offset\",\"stride\"];1===r?a():2===r?s():(e(\"if(\",r,\"===\",1,\"){\"),a(),e(\"}else{\"),s(),e(\"}\"))}var o=t.shared;n.forEach((function(n){var o,s=n.name,l=r.attributes[s];if(l){if(!i(l))return;o=l.append(t,e)}else{if(!i(Et))return;var c=t.scopeAttrib(s);o={},Object.keys(new Z).forEach((function(t){o[t]=e.def(c,\".\",t)}))}a(t.link(n),function(t){switch(t){case 35664:case 35667:case 35671:return 2;case 35665:case 35668:case 35672:return 3;case 35666:case 35669:case 35673:return 4;default:return 1}}(n.info.type),o)}))}function j(t,r,n,i,o){for(var s,l=t.shared,c=l.gl,u=0;u<i.length;++u){var f,h=(g=i[u]).name,p=g.info.type,d=n.uniforms[h],g=t.link(g)+\".location\";if(d){if(!o(d))continue;if(R(d)){if(h=d.value,35678===p||35680===p)r(c,\".uniform1i(\",g,\",\",(p=t.link(h._texture||h.color[0]._texture))+\".bind());\"),r.exit(p,\".unbind();\");else if(35674===p||35675===p||35676===p)d=2,35675===p?d=3:35676===p&&(d=4),r(c,\".uniformMatrix\",d,\"fv(\",g,\",false,\",h=t.global.def(\"new Float32Array([\"+Array.prototype.slice.call(h)+\"])\"),\");\");else{switch(p){case 5126:s=\"1f\";break;case 35664:s=\"2f\";break;case 35665:s=\"3f\";break;case 35666:s=\"4f\";break;case 35670:case 5124:s=\"1i\";break;case 35671:case 35667:s=\"2i\";break;case 35672:case 35668:s=\"3i\";break;case 35673:s=\"4i\";break;case 35669:s=\"4i\"}r(c,\".uniform\",s,\"(\",g,\",\",m(h)?Array.prototype.slice.call(h):h,\");\")}continue}f=d.append(t,r)}else{if(!o(Et))continue;f=r.def(l.uniforms,\"[\",e.id(h),\"]\")}switch(35678===p?r(\"if(\",f,\"&&\",f,'._reglType===\"framebuffer\"){',f,\"=\",f,\".color[0];\",\"}\"):35680===p&&r(\"if(\",f,\"&&\",f,'._reglType===\"framebufferCube\"){',f,\"=\",f,\".color[0];\",\"}\"),h=1,p){case 35678:case 35680:p=r.def(f,\"._texture\"),r(c,\".uniform1i(\",g,\",\",p,\".bind());\"),r.exit(p,\".unbind();\");continue;case 5124:case 35670:s=\"1i\";break;case 35667:case 35671:s=\"2i\",h=2;break;case 35668:case 35672:s=\"3i\",h=3;break;case 35669:case 35673:s=\"4i\",h=4;break;case 5126:s=\"1f\";break;case 35664:s=\"2f\",h=2;break;case 35665:s=\"3f\",h=3;break;case 35666:s=\"4f\",h=4;break;case 35674:s=\"Matrix2fv\";break;case 35675:s=\"Matrix3fv\";break;case 35676:s=\"Matrix4fv\"}if(r(c,\".uniform\",s,\"(\",g,\",\"),\"M\"===s.charAt(0)){g=Math.pow(p-35674+2,2);var v=t.global.def(\"new Float32Array(\",g,\")\");r(\"false,(Array.isArray(\",f,\")||\",f,\" instanceof Float32Array)?\",f,\":(\",a(g,(function(t){return v+\"[\"+t+\"]=\"+f+\"[\"+t+\"]\"})),\",\",v,\")\")}else r(1<h?a(h,(function(t){return f+\"[\"+t+\"]\"})):f);r(\");\")}}function U(t,e,r,n){function i(i){var a=h[i];return a?a.contextDep&&n.contextDynamic||a.propDep?a.append(t,r):a.append(t,e):e.def(f,\".\",i)}function a(){function t(){r(l,\".drawElementsInstancedANGLE(\",[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\",s],\");\")}function e(){r(l,\".drawArraysInstancedANGLE(\",[d,g,m,s],\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}function o(){function t(){r(u+\".drawElements(\"+[d,m,v,g+\"<<((\"+v+\"-5121)>>1)\"]+\");\")}function e(){r(u+\".drawArrays(\"+[d,g,m]+\");\")}p?y?t():(r(\"if(\",p,\"){\"),t(),r(\"}else{\"),e(),r(\"}\")):e()}var s,l,c=t.shared,u=c.gl,f=c.draw,h=n.draw,p=function(){var i=h.elements,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"elements\"),i&&a(\"if(\"+i+\")\"+u+\".bindBuffer(34963,\"+i+\".buffer.buffer);\"),i}(),d=i(\"primitive\"),g=i(\"offset\"),m=function(){var i=h.count,a=e;return i?((i.contextDep&&n.contextDynamic||i.propDep)&&(a=r),i=i.append(t,a)):i=a.def(f,\".\",\"count\"),i}();if(\"number\"==typeof m){if(0===m)return}else r(\"if(\",m,\"){\"),r.exit(\"}\");K&&(s=i(\"instances\"),l=t.instancing);var v=p+\".type\",y=h.elements&&R(h.elements);K&&(\"number\"!=typeof s||0<=s)?\"string\"==typeof s?(r(\"if(\",s,\">0){\"),a(),r(\"}else if(\",s,\"<0){\"),o(),r(\"}\")):a():o()}function V(t,e,r,n,i){return i=(e=b()).proc(\"body\",i),K&&(e.instancing=i.def(e.shared.extensions,\".angle_instanced_arrays\")),t(e,i,r,n),e.compile().body}function H(t,e,r,n){L(t,e),r.useVAO?r.drawVAO?e(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,e),\");\"):e(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(e(t.shared.vao,\".setVAO(null);\"),N(t,e,r,n.attributes,(function(){return!0}))),j(t,e,r,n.uniforms,(function(){return!0})),U(t,e,e,r)}function G(t,e,r,n){function i(){return!0}t.batchId=\"a1\",L(t,e),N(t,e,r,n.attributes,i),j(t,e,r,n.uniforms,i),U(t,e,e,r)}function Y(t,e,r,n){function i(t){return t.contextDep&&o||t.propDep}function a(t){return!i(t)}L(t,e);var o=r.contextDep,s=e.def(),l=e.def();t.shared.props=l,t.batchId=s;var c=t.scope(),u=t.scope();e(c.entry,\"for(\",s,\"=0;\",s,\"<\",\"a1\",\";++\",s,\"){\",l,\"=\",\"a0\",\"[\",s,\"];\",u,\"}\",c.exit),r.needsContext&&A(t,u,r.context),r.needsFramebuffer&&S(t,u,r.framebuffer),C(t,u,r.state,i),r.profile&&i(r.profile)&&I(t,u,r,!1,!0),n?(r.useVAO?r.drawVAO?i(r.drawVAO)?u(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,u),\");\"):c(t.shared.vao,\".setVAO(\",r.drawVAO.append(t,c),\");\"):c(t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"):(c(t.shared.vao,\".setVAO(null);\"),N(t,c,r,n.attributes,a),N(t,u,r,n.attributes,i)),j(t,c,r,n.uniforms,a),j(t,u,r,n.uniforms,i),U(t,c,u,r)):(e=t.global.def(\"{}\"),n=r.shader.progVar.append(t,u),l=u.def(n,\".id\"),c=u.def(e,\"[\",l,\"]\"),u(t.shared.gl,\".useProgram(\",n,\".program);\",\"if(!\",c,\"){\",c,\"=\",e,\"[\",l,\"]=\",t.link((function(e){return V(G,t,r,e,2)})),\"(\",n,\");}\",c,\".call(this,a0[\",s,\"],\",s,\");\"))}function W(t,r){function n(e){var n=r.shader[e];n&&i.set(a.shader,\".\"+e,n.append(t,i))}var i=t.proc(\"scope\",3);t.batchId=\"a2\";var a=t.shared,o=a.current;A(t,i,r.context),r.framebuffer&&r.framebuffer.append(t,i),O(Object.keys(r.state)).forEach((function(e){var n=r.state[e].append(t,i);m(n)?n.forEach((function(r,n){i.set(t.next[e],\"[\"+n+\"]\",r)})):i.set(a.next,\".\"+e,n)})),I(t,i,r,!0,!0),[\"elements\",\"offset\",\"count\",\"instances\",\"primitive\"].forEach((function(e){var n=r.draw[e];n&&i.set(a.draw,\".\"+e,\"\"+n.append(t,i))})),Object.keys(r.uniforms).forEach((function(n){i.set(a.uniforms,\"[\"+e.id(n)+\"]\",r.uniforms[n].append(t,i))})),Object.keys(r.attributes).forEach((function(e){var n=r.attributes[e].append(t,i),a=t.scopeAttrib(e);Object.keys(new Z).forEach((function(t){i.set(a,\".\"+t,n[t])}))})),r.scopeVAO&&i.set(a.vao,\".targetVAO\",r.scopeVAO.append(t,i)),n(\"vert\"),n(\"frag\"),0<Object.keys(r.state).length&&(i(o,\".dirty=true;\"),i.exit(o,\".dirty=true;\")),i(\"a1(\",t.shared.context,\",a0,\",t.batchId,\");\")}function X(t,e,r){var n=e.static[r];if(n&&function(t){if(\"object\"==typeof t&&!m(t)){for(var e=Object.keys(t),r=0;r<e.length;++r)if(q.isDynamic(t[e[r]]))return!0;return!1}}(n)){var i=t.global,a=Object.keys(n),o=!1,s=!1,l=!1,c=t.global.def(\"{}\");a.forEach((function(e){var r=n[e];if(q.isDynamic(r))\"function\"==typeof r&&(r=n[e]=q.unbox(r)),e=B(r,null),o=o||e.thisDep,l=l||e.propDep,s=s||e.contextDep;else{switch(i(c,\".\",e,\"=\"),typeof r){case\"number\":i(r);break;case\"string\":i('\"',r,'\"');break;case\"object\":Array.isArray(r)&&i(\"[\",r.join(),\"]\");break;default:i(t.link(r))}i(\";\")}})),e.dynamic[r]=new q.DynamicVariable(4,{thisDep:o,contextDep:s,propDep:l,ref:c,append:function(t,e){a.forEach((function(r){var i=n[r];q.isDynamic(i)&&(i=t.invoke(e,i),e(c,\".\",r,\"=\",i,\";\"))}))}}),delete e.static[r]}}var Z=u.Record,J={add:32774,subtract:32778,\"reverse subtract\":32779};r.ext_blend_minmax&&(J.min=32775,J.max=32776);var K=r.angle_instanced_arrays,$=r.webgl_draw_buffers,tt={dirty:!0,profile:g.profile},et={},rt=[],it={},at={};y(\"dither\",3024),y(\"blend.enable\",3042),x(\"blend.color\",\"blendColor\",[0,0,0,0]),x(\"blend.equation\",\"blendEquationSeparate\",[32774,32774]),x(\"blend.func\",\"blendFuncSeparate\",[1,0,1,0]),y(\"depth.enable\",2929,!0),x(\"depth.func\",\"depthFunc\",513),x(\"depth.range\",\"depthRange\",[0,1]),x(\"depth.mask\",\"depthMask\",!0),x(\"colorMask\",\"colorMask\",[!0,!0,!0,!0]),y(\"cull.enable\",2884),x(\"cull.face\",\"cullFace\",1029),x(\"frontFace\",\"frontFace\",2305),x(\"lineWidth\",\"lineWidth\",1),y(\"polygonOffset.enable\",32823),x(\"polygonOffset.offset\",\"polygonOffset\",[0,0]),y(\"sample.alpha\",32926),y(\"sample.enable\",32928),x(\"sample.coverage\",\"sampleCoverage\",[1,!1]),y(\"stencil.enable\",2960),x(\"stencil.mask\",\"stencilMask\",-1),x(\"stencil.func\",\"stencilFunc\",[519,0,-1]),x(\"stencil.opFront\",\"stencilOpSeparate\",[1028,7680,7680,7680]),x(\"stencil.opBack\",\"stencilOpSeparate\",[1029,7680,7680,7680]),y(\"scissor.enable\",3089),x(\"scissor.box\",\"scissor\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]),x(\"viewport\",\"viewport\",[0,0,t.drawingBufferWidth,t.drawingBufferHeight]);var ot={gl:t,context:p,strings:e,next:et,current:tt,draw:h,elements:o,buffer:i,shader:f,attributes:u.state,vao:u,uniforms:c,framebuffer:l,extensions:r,timer:d,isBufferArgs:z},st={primTypes:nt,compareFuncs:Mt,blendFuncs:kt,blendEquations:J,stencilOps:At,glTypes:Q,orientationType:St};$&&(st.backBuffer=[1029],st.drawBuffer=a(n.maxDrawbuffers,(function(t){return 0===t?[0]:a(t,(function(t){return 36064+t}))})));var lt=0;return{next:et,current:tt,procs:function(){var t=b(),e=t.proc(\"poll\"),i=t.proc(\"refresh\"),o=t.block();e(o),i(o);var s,l=t.shared,c=l.gl,u=l.next,f=l.current;o(f,\".dirty=false;\"),S(t,e),S(t,i,null,!0),K&&(s=t.link(K)),r.oes_vertex_array_object&&i(t.link(r.oes_vertex_array_object),\".bindVertexArrayOES(null);\");for(var h=0;h<n.maxAttributes;++h){var p=i.def(l.attributes,\"[\",h,\"]\"),d=t.cond(p,\".buffer\");d.then(c,\".enableVertexAttribArray(\",h,\");\",c,\".bindBuffer(\",34962,\",\",p,\".buffer.buffer);\",c,\".vertexAttribPointer(\",h,\",\",p,\".size,\",p,\".type,\",p,\".normalized,\",p,\".stride,\",p,\".offset);\").else(c,\".disableVertexAttribArray(\",h,\");\",c,\".vertexAttrib4f(\",h,\",\",p,\".x,\",p,\".y,\",p,\".z,\",p,\".w);\",p,\".buffer=null;\"),i(d),K&&i(s,\".vertexAttribDivisorANGLE(\",h,\",\",p,\".divisor);\")}return i(t.shared.vao,\".currentVAO=null;\",t.shared.vao,\".setVAO(\",t.shared.vao,\".targetVAO);\"),Object.keys(it).forEach((function(r){var n=it[r],a=o.def(u,\".\",r),s=t.block();s(\"if(\",a,\"){\",c,\".enable(\",n,\")}else{\",c,\".disable(\",n,\")}\",f,\".\",r,\"=\",a,\";\"),i(s),e(\"if(\",a,\"!==\",f,\".\",r,\"){\",s,\"}\")})),Object.keys(at).forEach((function(r){var n,s,l=at[r],h=tt[r],p=t.block();p(c,\".\",l,\"(\"),m(h)?(l=h.length,n=t.global.def(u,\".\",r),s=t.global.def(f,\".\",r),p(a(l,(function(t){return n+\"[\"+t+\"]\"})),\");\",a(l,(function(t){return s+\"[\"+t+\"]=\"+n+\"[\"+t+\"];\"})).join(\"\")),e(\"if(\",a(l,(function(t){return n+\"[\"+t+\"]!==\"+s+\"[\"+t+\"]\"})).join(\"||\"),\"){\",p,\"}\")):(n=o.def(u,\".\",r),s=o.def(f,\".\",r),p(n,\");\",f,\".\",r,\"=\",n,\";\"),e(\"if(\",n,\"!==\",s,\"){\",p,\"}\")),i(p)})),t.compile()}(),compile:function(t,e,r,n,i){var a=b();return a.stats=a.link(i),Object.keys(e.static).forEach((function(t){X(a,e,t)})),Tt.forEach((function(e){X(a,t,e)})),r=M(t,e,r,n),function(t,e){var r=t.proc(\"draw\",1);L(t,r),A(t,r,e.context),S(t,r,e.framebuffer),E(t,r,e),C(t,r,e.state),I(t,r,e,!1,!0);var n=e.shader.progVar.append(t,r);if(r(t.shared.gl,\".useProgram(\",n,\".program);\"),e.shader.program)H(t,r,e,e.shader.program);else{r(t.shared.vao,\".setVAO(null);\");var i=t.global.def(\"{}\"),a=r.def(n,\".id\"),o=r.def(i,\"[\",a,\"]\");r(t.cond(o).then(o,\".call(this,a0);\").else(o,\"=\",i,\"[\",a,\"]=\",t.link((function(r){return V(H,t,e,r,1)})),\"(\",n,\");\",o,\".call(this,a0);\"))}0<Object.keys(e.state).length&&r(t.shared.current,\".dirty=true;\")}(a,r),W(a,r),function(t,e){function r(t){return t.contextDep&&i||t.propDep}var n=t.proc(\"batch\",2);t.batchId=\"0\",L(t,n);var i=!1,a=!0;Object.keys(e.context).forEach((function(t){i=i||e.context[t].propDep})),i||(A(t,n,e.context),a=!1);var o=!1;if((s=e.framebuffer)?(s.propDep?i=o=!0:s.contextDep&&i&&(o=!0),o||S(t,n,s)):S(t,n,null),e.state.viewport&&e.state.viewport.propDep&&(i=!0),E(t,n,e),C(t,n,e.state,(function(t){return!r(t)})),e.profile&&r(e.profile)||I(t,n,e,!1,\"a1\"),e.contextDep=i,e.needsContext=a,e.needsFramebuffer=o,(a=e.shader.progVar).contextDep&&i||a.propDep)Y(t,n,e,null);else if(a=a.append(t,n),n(t.shared.gl,\".useProgram(\",a,\".program);\"),e.shader.program)Y(t,n,e,e.shader.program);else{n(t.shared.vao,\".setVAO(null);\");var s=t.global.def(\"{}\"),l=(o=n.def(a,\".id\"),n.def(s,\"[\",o,\"]\"));n(t.cond(l).then(l,\".call(this,a0,a1);\").else(l,\"=\",s,\"[\",o,\"]=\",t.link((function(r){return V(Y,t,e,r,2)})),\"(\",a,\");\",l,\".call(this,a0,a1);\"))}0<Object.keys(e.state).length&&n(t.shared.current,\".dirty=true;\")}(a,r),a.compile()}}}function j(t,e){for(var r=0;r<t.length;++r)if(t[r]===e)return r;return-1}var U=function(t,e){for(var r=Object.keys(e),n=0;n<r.length;++n)t[r[n]]=e[r[n]];return t},V=0,q={DynamicVariable:t,define:function(r,n){return new t(r,e(n+\"\"))},isDynamic:function(e){return\"function\"==typeof e&&!e._reglType||e instanceof t},unbox:function(e,r){return\"function\"==typeof e?new t(0,e):e},accessor:e},H={next:\"function\"==typeof requestAnimationFrame?function(t){return requestAnimationFrame(t)}:function(t){return setTimeout(t,16)},cancel:\"function\"==typeof cancelAnimationFrame?function(t){return cancelAnimationFrame(t)}:clearTimeout},G=\"undefined\"!=typeof performance&&performance.now?function(){return performance.now()}:function(){return+new Date},Y=s();Y.zero=s();var W=function(t,e){var r=1;e.ext_texture_filter_anisotropic&&(r=t.getParameter(34047));var n=1,i=1;e.webgl_draw_buffers&&(n=t.getParameter(34852),i=t.getParameter(36063));var a=!!e.oes_texture_float;if(a){a=t.createTexture(),t.bindTexture(3553,a),t.texImage2D(3553,0,6408,1,1,0,6408,5126,null);var o=t.createFramebuffer();if(t.bindFramebuffer(36160,o),t.framebufferTexture2D(36160,36064,3553,a,0),t.bindTexture(3553,null),36053!==t.checkFramebufferStatus(36160))a=!1;else{t.viewport(0,0,1,1),t.clearColor(1,0,0,1),t.clear(16384);var s=Y.allocType(5126,4);t.readPixels(0,0,1,1,6408,5126,s),t.getError()?a=!1:(t.deleteFramebuffer(o),t.deleteTexture(a),a=1===s[0]),Y.freeType(s)}}return s=!0,\"undefined\"!=typeof navigator&&(/MSIE/.test(navigator.userAgent)||/Trident\\//.test(navigator.appVersion)||/Edge/.test(navigator.userAgent))||(s=t.createTexture(),o=Y.allocType(5121,36),t.activeTexture(33984),t.bindTexture(34067,s),t.texImage2D(34069,0,6408,3,3,0,6408,5121,o),Y.freeType(o),t.bindTexture(34067,null),t.deleteTexture(s),s=!t.getError()),{colorBits:[t.getParameter(3410),t.getParameter(3411),t.getParameter(3412),t.getParameter(3413)],depthBits:t.getParameter(3414),stencilBits:t.getParameter(3415),subpixelBits:t.getParameter(3408),extensions:Object.keys(e).filter((function(t){return!!e[t]})),maxAnisotropic:r,maxDrawbuffers:n,maxColorAttachments:i,pointSizeDims:t.getParameter(33901),lineWidthDims:t.getParameter(33902),maxViewportDims:t.getParameter(3386),maxCombinedTextureUnits:t.getParameter(35661),maxCubeMapSize:t.getParameter(34076),maxRenderbufferSize:t.getParameter(34024),maxTextureUnits:t.getParameter(34930),maxTextureSize:t.getParameter(3379),maxAttributes:t.getParameter(34921),maxVertexUniforms:t.getParameter(36347),maxVertexTextureUnits:t.getParameter(35660),maxVaryingVectors:t.getParameter(36348),maxFragmentUniforms:t.getParameter(36349),glsl:t.getParameter(35724),renderer:t.getParameter(7937),vendor:t.getParameter(7936),version:t.getParameter(7938),readFloat:a,npotTextureCube:s}},X=function(t){return t instanceof Uint8Array||t instanceof Uint16Array||t instanceof Uint32Array||t instanceof Int8Array||t instanceof Int16Array||t instanceof Int32Array||t instanceof Float32Array||t instanceof Float64Array||t instanceof Uint8ClampedArray},Z=function(t){return Object.keys(t).map((function(e){return t[e]}))},J={shape:function(t){for(var e=[];t.length;t=t[0])e.push(t.length);return e},flatten:function(t,e,r,n){var i=1;if(e.length)for(var a=0;a<e.length;++a)i*=e[a];else i=0;switch(r=n||Y.allocType(r,i),e.length){case 0:break;case 1:for(n=e[0],e=0;e<n;++e)r[e]=t[e];break;case 2:for(n=e[0],e=e[1],a=i=0;a<n;++a)for(var o=t[a],s=0;s<e;++s)r[i++]=o[s];break;case 3:c(t,e[0],e[1],e[2],r,0);break;default:!function t(e,r,n,i,a){for(var o=1,s=n+1;s<r.length;++s)o*=r[s];var l=r[n];if(4==r.length-n){var u=r[n+1],f=r[n+2];for(r=r[n+3],s=0;s<l;++s)c(e[s],u,f,r,i,a),a+=o}else for(s=0;s<l;++s)t(e[s],r,n+1,i,a),a+=o}(t,e,0,r,0)}return r}},K={\"[object Int8Array]\":5120,\"[object Int16Array]\":5122,\"[object Int32Array]\":5124,\"[object Uint8Array]\":5121,\"[object Uint8ClampedArray]\":5121,\"[object Uint16Array]\":5123,\"[object Uint32Array]\":5125,\"[object Float32Array]\":5126,\"[object Float64Array]\":5121,\"[object ArrayBuffer]\":5121},Q={int8:5120,int16:5122,int32:5124,uint8:5121,uint16:5123,uint32:5125,float:5126,float32:5126},$={dynamic:35048,stream:35040,static:35044},tt=J.flatten,et=J.shape,rt=[];rt[5120]=1,rt[5122]=2,rt[5124]=4,rt[5121]=1,rt[5123]=2,rt[5125]=4,rt[5126]=4;var nt={points:0,point:0,lines:1,line:1,triangles:4,triangle:4,\"line loop\":2,\"line strip\":3,\"triangle strip\":5,\"triangle fan\":6},it=new Float32Array(1),at=new Uint32Array(it.buffer),ot=[9984,9986,9985,9987],st=[0,6409,6410,6407,6408],lt={};lt[6409]=lt[6406]=lt[6402]=1,lt[34041]=lt[6410]=2,lt[6407]=lt[35904]=3,lt[6408]=lt[35906]=4;var ct=v(\"HTMLCanvasElement\"),ut=v(\"OffscreenCanvas\"),ft=v(\"CanvasRenderingContext2D\"),ht=v(\"ImageBitmap\"),pt=v(\"HTMLImageElement\"),dt=v(\"HTMLVideoElement\"),gt=Object.keys(K).concat([ct,ut,ft,ht,pt,dt]),mt=[];mt[5121]=1,mt[5126]=4,mt[36193]=2,mt[5123]=2,mt[5125]=4;var vt=[];vt[32854]=2,vt[32855]=2,vt[36194]=2,vt[34041]=4,vt[33776]=.5,vt[33777]=.5,vt[33778]=1,vt[33779]=1,vt[35986]=.5,vt[35987]=1,vt[34798]=1,vt[35840]=.5,vt[35841]=.25,vt[35842]=.5,vt[35843]=.25,vt[36196]=.5;var yt=[];yt[32854]=2,yt[32855]=2,yt[36194]=2,yt[33189]=2,yt[36168]=1,yt[34041]=4,yt[35907]=4,yt[34836]=16,yt[34842]=8,yt[34843]=6;var xt=function(t,e,r,n,i){function a(t){this.id=c++,this.refCount=1,this.renderbuffer=t,this.format=32854,this.height=this.width=0,i.profile&&(this.stats={size:0})}function o(e){var r=e.renderbuffer;t.bindRenderbuffer(36161,null),t.deleteRenderbuffer(r),e.renderbuffer=null,e.refCount=0,delete u[e.id],n.renderbufferCount--}var s={rgba4:32854,rgb565:36194,\"rgb5 a1\":32855,depth:33189,stencil:36168,\"depth stencil\":34041};e.ext_srgb&&(s.srgba=35907),e.ext_color_buffer_half_float&&(s.rgba16f=34842,s.rgb16f=34843),e.webgl_color_buffer_float&&(s.rgba32f=34836);var l=[];Object.keys(s).forEach((function(t){l[s[t]]=t}));var c=0,u={};return a.prototype.decRef=function(){0>=--this.refCount&&o(this)},i.profile&&(n.getTotalRenderbufferSize=function(){var t=0;return Object.keys(u).forEach((function(e){t+=u[e].stats.size})),t}),{create:function(e,r){function o(e,r){var n=0,a=0,u=32854;if(\"object\"==typeof e&&e?(\"shape\"in e?(n=0|(a=e.shape)[0],a=0|a[1]):(\"radius\"in e&&(n=a=0|e.radius),\"width\"in e&&(n=0|e.width),\"height\"in e&&(a=0|e.height)),\"format\"in e&&(u=s[e.format])):\"number\"==typeof e?(n=0|e,a=\"number\"==typeof r?0|r:n):e||(n=a=1),n!==c.width||a!==c.height||u!==c.format)return o.width=c.width=n,o.height=c.height=a,c.format=u,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,u,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height),o.format=l[c.format],o}var c=new a(t.createRenderbuffer());return u[c.id]=c,n.renderbufferCount++,o(e,r),o.resize=function(e,r){var n=0|e,a=0|r||n;return n===c.width&&a===c.height||(o.width=c.width=n,o.height=c.height=a,t.bindRenderbuffer(36161,c.renderbuffer),t.renderbufferStorage(36161,c.format,n,a),i.profile&&(c.stats.size=yt[c.format]*c.width*c.height)),o},o._reglType=\"renderbuffer\",o._renderbuffer=c,i.profile&&(o.stats=c.stats),o.destroy=function(){c.decRef()},o},clear:function(){Z(u).forEach(o)},restore:function(){Z(u).forEach((function(e){e.renderbuffer=t.createRenderbuffer(),t.bindRenderbuffer(36161,e.renderbuffer),t.renderbufferStorage(36161,e.format,e.width,e.height)})),t.bindRenderbuffer(36161,null)}}},bt=[];bt[6408]=4,bt[6407]=3;var _t=[];_t[5121]=1,_t[5126]=4,_t[36193]=2;var wt=[\"x\",\"y\",\"z\",\"w\"],Tt=\"blend.func blend.equation stencil.func stencil.opFront stencil.opBack sample.coverage viewport scissor.box polygonOffset.offset\".split(\" \"),kt={0:0,1:1,zero:0,one:1,\"src color\":768,\"one minus src color\":769,\"src alpha\":770,\"one minus src alpha\":771,\"dst color\":774,\"one minus dst color\":775,\"dst alpha\":772,\"one minus dst alpha\":773,\"constant color\":32769,\"one minus constant color\":32770,\"constant alpha\":32771,\"one minus constant alpha\":32772,\"src alpha saturate\":776},Mt={never:512,less:513,\"<\":513,equal:514,\"=\":514,\"==\":514,\"===\":514,lequal:515,\"<=\":515,greater:516,\">\":516,notequal:517,\"!=\":517,\"!==\":517,gequal:518,\">=\":518,always:519},At={0:0,zero:0,keep:7680,replace:7681,increment:7682,decrement:7683,\"increment wrap\":34055,\"decrement wrap\":34056,invert:5386},St={cw:2304,ccw:2305},Et=new D(!1,!1,!1,(function(){}));return function(t){function e(){if(0===J.length)w&&w.update(),tt=null;else{tt=H.next(e),f();for(var t=J.length-1;0<=t;--t){var r=J[t];r&&r(I,null,0)}m.flush(),w&&w.update()}}function r(){!tt&&0<J.length&&(tt=H.next(e))}function n(){tt&&(H.cancel(e),tt=null)}function a(t){t.preventDefault(),n(),K.forEach((function(t){t()}))}function o(t){m.getError(),y.restore(),R.restore(),z.restore(),F.restore(),B.restore(),V.restore(),O.restore(),w&&w.restore(),Y.procs.refresh(),r(),Q.forEach((function(t){t()}))}function s(t){function e(t){var e={},r={};return Object.keys(t).forEach((function(n){var i=t[n];q.isDynamic(i)?r[n]=q.unbox(i,n):e[n]=i})),{dynamic:r,static:e}}var r=e(t.context||{}),n=e(t.uniforms||{}),i=e(t.attributes||{}),a=e(function(t){function e(t){if(t in r){var e=r[t];delete r[t],Object.keys(e).forEach((function(n){r[t+\".\"+n]=e[n]}))}}var r=U({},t);return delete r.uniforms,delete r.attributes,delete r.context,delete r.vao,\"stencil\"in r&&r.stencil.op&&(r.stencil.opBack=r.stencil.opFront=r.stencil.op,delete r.stencil.op),e(\"blend\"),e(\"depth\"),e(\"cull\"),e(\"stencil\"),e(\"polygonOffset\"),e(\"scissor\"),e(\"sample\"),\"vao\"in t&&(r.vao=t.vao),r}(t));t={gpuTime:0,cpuTime:0,count:0};var o=(r=Y.compile(a,i,n,r,t)).draw,s=r.batch,l=r.scope,c=[];return U((function(t,e){var r;if(\"function\"==typeof t)return l.call(this,null,t,0);if(\"function\"==typeof e)if(\"number\"==typeof t)for(r=0;r<t;++r)l.call(this,null,e,r);else{if(!Array.isArray(t))return l.call(this,t,e,0);for(r=0;r<t.length;++r)l.call(this,t[r],e,r)}else if(\"number\"==typeof t){if(0<t)return s.call(this,function(t){for(;c.length<t;)c.push(null);return c}(0|t),0|t)}else{if(!Array.isArray(t))return o.call(this,t);if(t.length)return s.call(this,t,t.length)}}),{stats:t})}function l(t,e){var r=0;Y.procs.poll();var n=e.color;n&&(m.clearColor(+n[0]||0,+n[1]||0,+n[2]||0,+n[3]||0),r|=16384),\"depth\"in e&&(m.clearDepth(+e.depth),r|=256),\"stencil\"in e&&(m.clearStencil(0|e.stencil),r|=1024),m.clear(r)}function c(t){return J.push(t),r(),{cancel:function(){var e=j(J,t);J[e]=function t(){var e=j(J,t);J[e]=J[J.length-1],--J.length,0>=J.length&&n()}}}}function u(){var t=X.viewport,e=X.scissor_box;t[0]=t[1]=e[0]=e[1]=0,I.viewportWidth=I.framebufferWidth=I.drawingBufferWidth=t[2]=e[2]=m.drawingBufferWidth,I.viewportHeight=I.framebufferHeight=I.drawingBufferHeight=t[3]=e[3]=m.drawingBufferHeight}function f(){I.tick+=1,I.time=g(),u(),Y.procs.poll()}function h(){u(),Y.procs.refresh(),w&&w.update()}function g(){return(G()-T)/1e3}if(!(t=i(t)))return null;var m=t.gl,v=m.getContextAttributes();m.isContextLost();var y=function(t,e){function r(e){var r;e=e.toLowerCase();try{r=n[e]=t.getExtension(e)}catch(t){}return!!r}for(var n={},i=0;i<e.extensions.length;++i){var a=e.extensions[i];if(!r(a))return e.onDestroy(),e.onDone('\"'+a+'\" extension is not supported by the current WebGL context, try upgrading your system or a different browser'),null}return e.optionalExtensions.forEach(r),{extensions:n,restore:function(){Object.keys(n).forEach((function(t){if(n[t]&&!r(t))throw Error(\"(regl): error restoring extension \"+t)}))}}}(m,t);if(!y)return null;var x=function(){var t={\"\":0},e=[\"\"];return{id:function(r){var n=t[r];return n||(n=t[r]=e.length,e.push(r),n)},str:function(t){return e[t]}}}(),b={vaoCount:0,bufferCount:0,elementsCount:0,framebufferCount:0,shaderCount:0,textureCount:0,cubeCount:0,renderbufferCount:0,maxTextureUnits:0},_=y.extensions,w=function(t,e){function r(){this.endQueryIndex=this.startQueryIndex=-1,this.sum=0,this.stats=null}function n(t,e,n){var i=o.pop()||new r;i.startQueryIndex=t,i.endQueryIndex=e,i.sum=0,i.stats=n,s.push(i)}if(!e.ext_disjoint_timer_query)return null;var i=[],a=[],o=[],s=[],l=[],c=[];return{beginQuery:function(t){var r=i.pop()||e.ext_disjoint_timer_query.createQueryEXT();e.ext_disjoint_timer_query.beginQueryEXT(35007,r),a.push(r),n(a.length-1,a.length,t)},endQuery:function(){e.ext_disjoint_timer_query.endQueryEXT(35007)},pushScopeStats:n,update:function(){var t,r;if(0!==(t=a.length)){c.length=Math.max(c.length,t+1),l.length=Math.max(l.length,t+1),l[0]=0;var n=c[0]=0;for(r=t=0;r<a.length;++r){var u=a[r];e.ext_disjoint_timer_query.getQueryObjectEXT(u,34919)?(n+=e.ext_disjoint_timer_query.getQueryObjectEXT(u,34918),i.push(u)):a[t++]=u,l[r+1]=n,c[r+1]=t}for(a.length=t,r=t=0;r<s.length;++r){var f=(n=s[r]).startQueryIndex;u=n.endQueryIndex;n.sum+=l[u]-l[f],f=c[f],(u=c[u])===f?(n.stats.gpuTime+=n.sum/1e6,o.push(n)):(n.startQueryIndex=f,n.endQueryIndex=u,s[t++]=n)}s.length=t}},getNumPendingQueries:function(){return a.length},clear:function(){i.push.apply(i,a);for(var t=0;t<i.length;t++)e.ext_disjoint_timer_query.deleteQueryEXT(i[t]);a.length=0,i.length=0},restore:function(){a.length=0,i.length=0}}}(0,_),T=G(),A=m.drawingBufferWidth,L=m.drawingBufferHeight,I={tick:0,time:0,viewportWidth:A,viewportHeight:L,framebufferWidth:A,framebufferHeight:L,drawingBufferWidth:A,drawingBufferHeight:L,pixelRatio:t.pixelRatio},P=W(m,_),z=p(m,b,t,(function(t){return O.destroyBuffer(t)})),O=S(m,_,P,b,z),D=d(m,_,z,b),R=E(m,x,b,t),F=k(m,_,P,(function(){Y.procs.poll()}),I,b,t),B=xt(m,_,0,b,t),V=M(m,_,P,F,B,b),Y=N(m,x,_,P,z,D,0,V,{},O,R,{elements:null,primitive:4,count:-1,offset:0,instances:-1},I,w,t),X=(x=C(m,V,Y.procs.poll,I),Y.next),Z=m.canvas,J=[],K=[],Q=[],$=[t.onDestroy],tt=null;Z&&(Z.addEventListener(\"webglcontextlost\",a,!1),Z.addEventListener(\"webglcontextrestored\",o,!1));var et=V.setFBO=s({framebuffer:q.define.call(null,1,\"framebuffer\")});return h(),v=U(s,{clear:function(t){if(\"framebuffer\"in t)if(t.framebuffer&&\"framebufferCube\"===t.framebuffer_reglType)for(var e=0;6>e;++e)et(U({framebuffer:t.framebuffer.faces[e]},t),l);else et(t,l);else l(0,t)},prop:q.define.bind(null,1),context:q.define.bind(null,2),this:q.define.bind(null,3),draw:s({}),buffer:function(t){return z.create(t,34962,!1,!1)},elements:function(t){return D.create(t,!1)},texture:F.create2D,cube:F.createCube,renderbuffer:B.create,framebuffer:V.create,framebufferCube:V.createCube,vao:O.createVAO,attributes:v,frame:c,on:function(t,e){var r;switch(t){case\"frame\":return c(e);case\"lost\":r=K;break;case\"restore\":r=Q;break;case\"destroy\":r=$}return r.push(e),{cancel:function(){for(var t=0;t<r.length;++t)if(r[t]===e){r[t]=r[r.length-1],r.pop();break}}}},limits:P,hasExtension:function(t){return 0<=P.extensions.indexOf(t.toLowerCase())},read:x,destroy:function(){J.length=0,n(),Z&&(Z.removeEventListener(\"webglcontextlost\",a),Z.removeEventListener(\"webglcontextrestored\",o)),R.clear(),V.clear(),B.clear(),F.clear(),D.clear(),z.clear(),O.clear(),w&&w.clear(),$.forEach((function(t){t()}))},_gl:m,_refresh:h,poll:function(){f(),w&&w.update()},now:g,stats:b}),t.onDone(null,v),v}}))},{}],541:[function(t,e,r){\n",
       "/*!\n",
       " * repeat-string <https://github.com/jonschlinkert/repeat-string>\n",
       " *\n",
       " * Copyright (c) 2014-2015, Jon Schlinkert.\n",
       " * Licensed under the MIT License.\n",
       " */\n",
       "\"use strict\";var n,i=\"\";e.exports=function(t,e){if(\"string\"!=typeof t)throw new TypeError(\"expected a string\");if(1===e)return t;if(2===e)return t+t;var r=t.length*e;if(n!==t||\"undefined\"==typeof n)n=t,i=\"\";else if(i.length>=r)return i.substr(0,r);for(;r>i.length&&e>1;)1&e&&(i+=t),e>>=1,t+=t;return i=(i+=t).substr(0,r)}},{}],542:[function(t,e,r){(function(t){(function(){e.exports=t.performance&&t.performance.now?function(){return performance.now()}:Date.now||function(){return+new Date}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{}],543:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=t[t.length-1],n=e,i=e-2;i>=0;--i){var a=r,o=t[i];(l=o-((r=a+o)-a))&&(t[--n]=r,r=l)}var s=0;for(i=n;i<e;++i){var l;a=t[i];(l=(o=r)-((r=a+o)-a))&&(t[s++]=l)}return t[s++]=r,t.length=s,t}},{}],544:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-compress\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m[\",r,\"][\",n,\"]\"].join(\"\")}return e}function c(t){if(2===t.length)return[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\");for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",c(s(t,r)),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return function t(e){if(1===e.length)return e[0];if(2===e.length)return[\"sum(\",e[0],\",\",e[1],\")\"].join(\"\");var r=e.length>>1;return[\"sum(\",t(e.slice(0,r)),\",\",t(e.slice(r)),\")\"].join(\"\")}(e);var n}function u(t){return new Function(\"sum\",\"scale\",\"prod\",\"compress\",[\"function robustDeterminant\",t,\"(m){return compress(\",c(l(t)),\")};return robustDeterminant\",t].join(\"\"))(i,a,n,o)}var f=[function(){return[0]},function(t){return[t[0][0]]}];!function(){for(;f.length<6;)f.push(u(f.length));for(var t=[],r=[\"function robustDeterminant(m){switch(m.length){\"],n=0;n<6;++n)t.push(\"det\"+n),r.push(\"case \",n,\":return det\",n,\"(m);\");r.push(\"}var det=CACHE[m.length];if(!det)det=CACHE[m.length]=gen(m.length);return det(m);}return robustDeterminant\"),t.push(\"CACHE\",\"gen\",r.join(\"\"));var i=Function.apply(void 0,t);for(e.exports=i.apply(void 0,f.concat([f,u])),n=0;n<f.length;++n)e.exports[n]=f[n]}()},{\"robust-compress\":543,\"robust-scale\":550,\"robust-sum\":553,\"two-product\":582}],545:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\");e.exports=function(t,e){for(var r=n(t[0],e[0]),a=1;a<t.length;++a)r=i(r,n(t[a],e[a]));return r}},{\"robust-sum\":553,\"two-product\":582}],546:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-subtract\"),o=t(\"robust-scale\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t,e){if(\"m\"===t.charAt(0)){if(\"w\"===e.charAt(0)){var r=t.split(\"[\");return[\"w\",e.substr(1),\"m\",r[0].substr(1)].join(\"\")}return[\"prod(\",t,\",\",e,\")\"].join(\"\")}return c(e,t)}function u(t){if(2===t.length)return[[\"diff(\",c(t[0][0],t[1][1]),\",\",c(t[1][0],t[0][1]),\")\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(u(s(t,r))),\",\",(n=r,!0&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function f(t,e){for(var r=[],n=0;n<e-2;++n)r.push([\"prod(m\",t,\"[\",n,\"],m\",t,\"[\",n,\"])\"].join(\"\"));return l(r)}function h(t){for(var e=[],r=[],c=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-2,\"]\"].join(\"\")}return e}(t),h=0;h<t;++h)c[0][h]=\"1\",c[t-1][h]=\"w\"+h;for(h=0;h<t;++h)0==(1&h)?e.push.apply(e,u(s(c,h))):r.push.apply(r,u(s(c,h)));var p=l(e),d=l(r),g=\"exactInSphere\"+t,m=[];for(h=0;h<t;++h)m.push(\"m\"+h);var v=[\"function \",g,\"(\",m.join(),\"){\"];for(h=0;h<t;++h){v.push(\"var w\",h,\"=\",f(h,t),\";\");for(var y=0;y<t;++y)y!==h&&v.push(\"var w\",h,\"m\",y,\"=scale(w\",h,\",m\",y,\"[0]);\")}return v.push(\"var p=\",p,\",n=\",d,\",d=diff(p,n);return d[d.length-1];}return \",g),new Function(\"sum\",\"diff\",\"prod\",\"scale\",v.join(\"\"))(i,a,n,o)}var p=[function(){return 0},function(){return 0},function(){return 0}];function d(t){var e=p[t.length];return e||(e=p[t.length]=h(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=6;)p.push(h(p.length));for(var t=[],r=[\"slow\"],n=0;n<=6;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function testInSphere(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=6;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return testInSphere\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=6;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],547:[function(t,e,r){\"use strict\";var n=t(\"robust-determinant\");function i(t){for(var e=\"robustLinearSolve\"+t+\"d\",r=[\"function \",e,\"(A,b){return [\"],i=0;i<t;++i){r.push(\"det([\");for(var a=0;a<t;++a){a>0&&r.push(\",\"),r.push(\"[\");for(var o=0;o<t;++o)o>0&&r.push(\",\"),o===i?r.push(\"+b[\",a,\"]\"):r.push(\"+A[\",a,\"][\",o,\"]\");r.push(\"]\")}r.push(\"]),\")}r.push(\"det(A)]}return \",e);var s=new Function(\"det\",r.join(\"\"));return s(t<6?n[t]:n)}var a=[function(){return[0]},function(t,e){return[[e[0]],[t[0][0]]]}];!function(){for(;a.length<6;)a.push(i(a.length));for(var t=[],r=[\"function dispatchLinearSolve(A,b){switch(A.length){\"],n=0;n<6;++n)t.push(\"s\"+n),r.push(\"case \",n,\":return s\",n,\"(A,b);\");r.push(\"}var s=CACHE[A.length];if(!s)s=CACHE[A.length]=g(A.length);return s(A,b)}return dispatchLinearSolve\"),t.push(\"CACHE\",\"g\",r.join(\"\"));var o=Function.apply(void 0,t);for(e.exports=o.apply(void 0,a.concat([a,i])),n=0;n<6;++n)e.exports[n]=a[n]}()},{\"robust-determinant\":544}],548:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"robust-sum\"),a=t(\"robust-scale\"),o=t(\"robust-subtract\");function s(t,e){for(var r=new Array(t.length-1),n=1;n<t.length;++n)for(var i=r[n-1]=new Array(t.length-1),a=0,o=0;a<t.length;++a)a!==e&&(i[o++]=t[n][a]);return r}function l(t){if(1===t.length)return t[0];if(2===t.length)return[\"sum(\",t[0],\",\",t[1],\")\"].join(\"\");var e=t.length>>1;return[\"sum(\",l(t.slice(0,e)),\",\",l(t.slice(e)),\")\"].join(\"\")}function c(t){if(2===t.length)return[[\"sum(prod(\",t[0][0],\",\",t[1][1],\"),prod(-\",t[0][1],\",\",t[1][0],\"))\"].join(\"\")];for(var e=[],r=0;r<t.length;++r)e.push([\"scale(\",l(c(s(t,r))),\",\",(n=r,1&n?\"-\":\"\"),t[0][r],\")\"].join(\"\"));return e;var n}function u(t){for(var e=[],r=[],u=function(t){for(var e=new Array(t),r=0;r<t;++r){e[r]=new Array(t);for(var n=0;n<t;++n)e[r][n]=[\"m\",n,\"[\",t-r-1,\"]\"].join(\"\")}return e}(t),f=[],h=0;h<t;++h)0==(1&h)?e.push.apply(e,c(s(u,h))):r.push.apply(r,c(s(u,h))),f.push(\"m\"+h);var p=l(e),d=l(r),g=\"orientation\"+t+\"Exact\",m=[\"function \",g,\"(\",f.join(),\"){var p=\",p,\",n=\",d,\",d=sub(p,n);return d[d.length-1];};return \",g].join(\"\");return new Function(\"sum\",\"prod\",\"scale\",\"sub\",m)(i,n,a,o)}var f=u(3),h=u(4),p=[function(){return 0},function(){return 0},function(t,e){return e[0]-t[0]},function(t,e,r){var n,i=(t[1]-r[1])*(e[0]-r[0]),a=(t[0]-r[0])*(e[1]-r[1]),o=i-a;if(i>0){if(a<=0)return o;n=i+a}else{if(!(i<0))return o;if(a>=0)return o;n=-(i+a)}var s=33306690738754716e-32*n;return o>=s||o<=-s?o:f(t,e,r)},function(t,e,r,n){var i=t[0]-n[0],a=e[0]-n[0],o=r[0]-n[0],s=t[1]-n[1],l=e[1]-n[1],c=r[1]-n[1],u=t[2]-n[2],f=e[2]-n[2],p=r[2]-n[2],d=a*c,g=o*l,m=o*s,v=i*c,y=i*l,x=a*s,b=u*(d-g)+f*(m-v)+p*(y-x),_=7771561172376103e-31*((Math.abs(d)+Math.abs(g))*Math.abs(u)+(Math.abs(m)+Math.abs(v))*Math.abs(f)+(Math.abs(y)+Math.abs(x))*Math.abs(p));return b>_||-b>_?b:h(t,e,r,n)}];function d(t){var e=p[t.length];return e||(e=p[t.length]=u(t.length)),e.apply(void 0,t)}!function(){for(;p.length<=5;)p.push(u(p.length));for(var t=[],r=[\"slow\"],n=0;n<=5;++n)t.push(\"a\"+n),r.push(\"o\"+n);var i=[\"function getOrientation(\",t.join(),\"){switch(arguments.length){case 0:case 1:return 0;\"];for(n=2;n<=5;++n)i.push(\"case \",n,\":return o\",n,\"(\",t.slice(0,n).join(),\");\");i.push(\"}var s=new Array(arguments.length);for(var i=0;i<arguments.length;++i){s[i]=arguments[i]};return slow(s);}return getOrientation\"),r.push(i.join(\"\"));var a=Function.apply(void 0,r);for(e.exports=a.apply(void 0,[d].concat(p)),n=0;n<=5;++n)e.exports[n]=p[n]}()},{\"robust-scale\":550,\"robust-subtract\":552,\"robust-sum\":553,\"two-product\":582}],549:[function(t,e,r){\"use strict\";var n=t(\"robust-sum\"),i=t(\"robust-scale\");e.exports=function(t,e){if(1===t.length)return i(e,t[0]);if(1===e.length)return i(t,e[0]);if(0===t.length||0===e.length)return[0];var r=[0];if(t.length<e.length)for(var a=0;a<t.length;++a)r=n(r,i(e,t[a]));else for(a=0;a<e.length;++a)r=n(r,i(t,e[a]));return r}},{\"robust-scale\":550,\"robust-sum\":553}],550:[function(t,e,r){\"use strict\";var n=t(\"two-product\"),i=t(\"two-sum\");e.exports=function(t,e){var r=t.length;if(1===r){var a=n(t[0],e);return a[0]?a:[a[1]]}var o=new Array(2*r),s=[.1,.1],l=[.1,.1],c=0;n(t[0],e,s),s[0]&&(o[c++]=s[0]);for(var u=1;u<r;++u){n(t[u],e,l);var f=s[1];i(f,l[0],s),s[0]&&(o[c++]=s[0]);var h=l[1],p=s[1],d=h+p,g=p-(d-h);s[1]=d,g&&(o[c++]=g)}s[1]&&(o[c++]=s[1]);0===c&&(o[c++]=0);return o.length=c,o}},{\"two-product\":582,\"two-sum\":583}],551:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,i){var a=n(t,r,i),o=n(e,r,i);if(a>0&&o>0||a<0&&o<0)return!1;var s=n(r,t,e),l=n(i,t,e);if(s>0&&l>0||s<0&&l<0)return!1;if(0===a&&0===o&&0===s&&0===l)return function(t,e,r,n){for(var i=0;i<2;++i){var a=t[i],o=e[i],s=Math.min(a,o),l=Math.max(a,o),c=r[i],u=n[i],f=Math.min(c,u);if(Math.max(c,u)<s||l<f)return!1}return!0}(t,e,r,i);return!0};var n=t(\"robust-orientation\")[3]},{\"robust-orientation\":548}],552:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],-e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=-e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=-e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=-e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=-e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],553:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=0|t.length,n=0|e.length;if(1===r&&1===n)return function(t,e){var r=t+e,n=r-t,i=t-(r-n)+(e-n);if(i)return[i,r];return[r]}(t[0],e[0]);var i,a,o=new Array(r+n),s=0,l=0,c=0,u=Math.abs,f=t[l],h=u(f),p=e[c],d=u(p);h<d?(a=f,(l+=1)<r&&(f=t[l],h=u(f))):(a=p,(c+=1)<n&&(p=e[c],d=u(p)));l<r&&h<d||c>=n?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p)));var g,m,v=i+a,y=v-i,x=a-y,b=x,_=v;for(;l<r&&c<n;)h<d?(i=f,(l+=1)<r&&(f=t[l],h=u(f))):(i=p,(c+=1)<n&&(p=e[c],d=u(p))),(x=(a=b)-(y=(v=i+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g;for(;l<r;)(x=(a=b)-(y=(v=(i=f)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(l+=1)<r&&(f=t[l]);for(;c<n;)(x=(a=b)-(y=(v=(i=p)+a)-i))&&(o[s++]=x),b=_-((g=_+v)-(m=g-_))+(v-m),_=g,(c+=1)<n&&(p=e[c]);b&&(o[s++]=b);_&&(o[s++]=_);s||(o[s++]=0);return o.length=s,o}},{}],554:[function(t,e,r){\"use strict\";e.exports=function(t){return t<0?-1:t>0?1:0}},{}],555:[function(t,e,r){\"use strict\";e.exports=function(t){return i(n(t))};var n=t(\"boundary-cells\"),i=t(\"reduce-simplicial-complex\")},{\"boundary-cells\":100,\"reduce-simplicial-complex\":533}],556:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,s){r=r||0,\"undefined\"==typeof s&&(s=function(t){for(var e=t.length,r=0,n=0;n<e;++n)r=0|Math.max(r,t[n].length);return r-1}(t));if(0===t.length||s<1)return{cells:[],vertexIds:[],vertexWeights:[]};var l=function(t,e){for(var r=t.length,n=i.mallocUint8(r),a=0;a<r;++a)n[a]=t[a]<e|0;return n}(e,+r),c=function(t,e){for(var r=t.length,o=e*(e+1)/2*r|0,s=i.mallocUint32(2*o),l=0,c=0;c<r;++c)for(var u=t[c],f=(e=u.length,0);f<e;++f)for(var h=0;h<f;++h){var p=u[h],d=u[f];s[l++]=0|Math.min(p,d),s[l++]=0|Math.max(p,d)}a(n(s,[l/2|0,2]));var g=2;for(c=2;c<l;c+=2)s[c-2]===s[c]&&s[c-1]===s[c+1]||(s[g++]=s[c],s[g++]=s[c+1]);return n(s,[g/2|0,2])}(t,s),u=function(t,e,r,a){for(var o=t.data,s=t.shape[0],l=i.mallocDouble(s),c=0,u=0;u<s;++u){var f=o[2*u],h=o[2*u+1];if(r[f]!==r[h]){var p=e[f],d=e[h];o[2*c]=f,o[2*c+1]=h,l[c++]=(d-a)/(d-p)}}return t.shape[0]=c,n(l,[c])}(c,e,l,+r),f=function(t,e){var r=i.mallocInt32(2*e),n=t.shape[0],a=t.data;r[0]=0;for(var o=0,s=0;s<n;++s){var l=a[2*s];if(l!==o){for(r[2*o+1]=s;++o<l;)r[2*o]=s,r[2*o+1]=s;r[2*o]=s}}r[2*o+1]=n;for(;++o<e;)r[2*o]=r[2*o+1]=n;return r}(c,0|e.length),h=o(s)(t,c.data,f,l),p=function(t){for(var e=0|t.shape[0],r=t.data,n=new Array(e),i=0;i<e;++i)n[i]=[r[2*i],r[2*i+1]];return n}(c),d=[].slice.call(u.data,0,u.shape[0]);return i.free(l),i.free(c.data),i.free(u.data),i.free(f),{cells:h,vertexIds:p,vertexWeights:d}};var n=t(\"ndarray\"),i=t(\"typedarray-pool\"),a=t(\"ndarray-sort\"),o=t(\"./lib/codegen\")},{\"./lib/codegen\":557,ndarray:495,\"ndarray-sort\":494,\"typedarray-pool\":595}],557:[function(t,e,r){\"use strict\";e.exports=function(t){var e=a[t];e||(e=a[t]=function(t){var e=0,r=new Array(t+1);r[0]=[[]];for(var a=1;a<=t;++a)for(var o=r[a]=i(a),s=0;s<o.length;++s)e=Math.max(e,o[a].length);var l=[\"function B(C,E,i,j){\",\"var a=Math.min(i,j)|0,b=Math.max(i,j)|0,l=C[2*a],h=C[2*a+1];\",\"while(l<h){\",\"var m=(l+h)>>1,v=E[2*m+1];\",\"if(v===b){return m}\",\"if(b<v){h=m}else{l=m+1}\",\"}\",\"return l;\",\"};\",\"function getContour\",t,\"d(F,E,C,S){\",\"var n=F.length,R=[];\",\"for(var i=0;i<n;++i){var c=F[i],l=c.length;\"];function c(t){if(!(t.length<=0)){l.push(\"R.push(\");for(var e=0;e<t.length;++e){var r=t[e];e>0&&l.push(\",\"),l.push(\"[\");for(var n=0;n<r.length;++n){var i=r[n];n>0&&l.push(\",\"),l.push(\"B(C,E,c[\",i[0],\"],c[\",i[1],\"])\")}l.push(\"]\")}l.push(\");\")}}for(a=t+1;a>1;--a){a<t+1&&l.push(\"else \"),l.push(\"if(l===\",a,\"){\");var u=[];for(s=0;s<a;++s)u.push(\"(S[c[\"+s+\"]]<<\"+s+\")\");l.push(\"var M=\",u.join(\"+\"),\";if(M===0||M===\",(1<<a)-1,\"){continue}switch(M){\");for(o=r[a-1],s=0;s<o.length;++s)l.push(\"case \",s,\":\"),c(o[s]),l.push(\"break;\");l.push(\"}}\")}return l.push(\"}return R;};return getContour\",t,\"d\"),new Function(\"pool\",l.join(\"\"))(n)}(t));return e};var n=t(\"typedarray-pool\"),i=t(\"marching-simplex-table\"),a={}},{\"marching-simplex-table\":474,\"typedarray-pool\":595}],558:[function(t,e,r){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"union-find\");function a(t,e){var r=t.length,n=t.length-e.length,i=Math.min;if(n)return n;switch(r){case 0:return 0;case 1:return t[0]-e[0];case 2:return(s=t[0]+t[1]-e[0]-e[1])||i(t[0],t[1])-i(e[0],e[1]);case 3:var a=t[0]+t[1],o=e[0]+e[1];if(s=a+t[2]-(o+e[2]))return s;var s,l=i(t[0],t[1]),c=i(e[0],e[1]);return(s=i(l,t[2])-i(c,e[2]))||i(l+t[2],a)-i(c+e[2],o);default:var u=t.slice(0);u.sort();var f=e.slice(0);f.sort();for(var h=0;h<r;++h)if(n=u[h]-f[h])return n;return 0}}function o(t,e){return a(t[0],e[0])}function s(t,e){if(e){for(var r=t.length,n=new Array(r),i=0;i<r;++i)n[i]=[t[i],e[i]];n.sort(o);for(i=0;i<r;++i)t[i]=n[i][0],e[i]=n[i][1];return t}return t.sort(a),t}function l(t){if(0===t.length)return[];for(var e=1,r=t.length,n=1;n<r;++n){var i=t[n];if(a(i,t[n-1])){if(n===e){e++;continue}t[e++]=i}}return t.length=e,t}function c(t,e){for(var r=0,n=t.length-1,i=-1;r<=n;){var o=r+n>>1,s=a(t[o],e);s<=0?(0===s&&(i=o),r=o+1):s>0&&(n=o-1)}return i}function u(t,e){for(var r=new Array(t.length),i=0,o=r.length;i<o;++i)r[i]=[];for(var s=[],l=(i=0,e.length);i<l;++i)for(var u=e[i],f=u.length,h=1,p=1<<f;h<p;++h){s.length=n.popCount(h);for(var d=0,g=0;g<f;++g)h&1<<g&&(s[d++]=u[g]);var m=c(t,s);if(!(m<0))for(;r[m++].push(i),!(m>=t.length||0!==a(t[m],s)););}return r}function f(t,e){if(e<0)return[];for(var r=[],i=(1<<e+1)-1,a=0;a<t.length;++a)for(var o=t[a],l=i;l<1<<o.length;l=n.nextCombination(l)){for(var c=new Array(e+1),u=0,f=0;f<o.length;++f)l&1<<f&&(c[u++]=o[f]);r.push(c)}return s(r)}r.dimension=function(t){for(var e=0,r=Math.max,n=0,i=t.length;n<i;++n)e=r(e,t[n].length);return e-1},r.countVertices=function(t){for(var e=-1,r=Math.max,n=0,i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)e=r(e,a[o]);return e+1},r.cloneCells=function(t){for(var e=new Array(t.length),r=0,n=t.length;r<n;++r)e[r]=t[r].slice(0);return e},r.compareCells=a,r.normalize=s,r.unique=l,r.findCell=c,r.incidence=u,r.dual=function(t,e){if(!e)return u(l(f(t,0)),t);for(var r=new Array(e),n=0;n<e;++n)r[n]=[];n=0;for(var i=t.length;n<i;++n)for(var a=t[n],o=0,s=a.length;o<s;++o)r[a[o]].push(n);return r},r.explode=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0|i.length,o=1,l=1<<a;o<l;++o){for(var c=[],u=0;u<a;++u)o>>>u&1&&c.push(i[u]);e.push(c)}return s(e)},r.skeleton=f,r.boundary=function(t){for(var e=[],r=0,n=t.length;r<n;++r)for(var i=t[r],a=0,o=i.length;a<o;++a){for(var l=new Array(i.length-1),c=0,u=0;c<o;++c)c!==a&&(l[u++]=i[c]);e.push(l)}return s(e)},r.connectedComponents=function(t,e){return e?function(t,e){for(var r=new i(e),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var s=o+1;s<a.length;++s)r.link(a[o],a[s]);var l=[],c=r.ranks;for(n=0;n<c.length;++n)c[n]=-1;for(n=0;n<t.length;++n){var u=r.find(t[n][0]);c[u]<0?(c[u]=l.length,l.push([t[n].slice(0)])):l[c[u]].push(t[n].slice(0))}return l}(t,e):function(t){for(var e=l(s(f(t,0))),r=new i(e.length),n=0;n<t.length;++n)for(var a=t[n],o=0;o<a.length;++o)for(var u=c(e,[a[o]]),h=o+1;h<a.length;++h)r.link(u,c(e,[a[h]]));var p=[],d=r.ranks;for(n=0;n<d.length;++n)d[n]=-1;for(n=0;n<t.length;++n){var g=r.find(c(e,[t[n][0]]));d[g]<0?(d[g]=p.length,p.push([t[n].slice(0)])):p[d[g]].push(t[n].slice(0))}return p}(t)}},{\"bit-twiddle\":97,\"union-find\":596}],559:[function(t,e,r){arguments[4][97][0].apply(r,arguments)},{dup:97}],560:[function(t,e,r){arguments[4][558][0].apply(r,arguments)},{\"bit-twiddle\":559,dup:558,\"union-find\":561}],561:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n,n.prototype.length=function(){return this.roots.length},n.prototype.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},n.prototype.find=function(t){for(var e=this.roots;e[t]!==t;){var r=e[t];e[t]=e[r],t=r}return t},n.prototype.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],562:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){for(var a=e.length,o=t.length,s=new Array(a),l=new Array(a),c=new Array(a),u=new Array(a),f=0;f<a;++f)s[f]=l[f]=-1,c[f]=1/0,u[f]=!1;for(f=0;f<o;++f){var h=t[f];if(2!==h.length)throw new Error(\"Input must be a graph\");var p=h[1],d=h[0];-1!==l[d]?l[d]=-2:l[d]=p,-1!==s[p]?s[p]=-2:s[p]=d}function g(t){if(u[t])return 1/0;var r,i,a,o,c,f=s[t],h=l[t];return f<0||h<0?1/0:(r=e[t],i=e[f],a=e[h],o=Math.abs(n(r,i,a)),c=Math.sqrt(Math.pow(i[0]-a[0],2)+Math.pow(i[1]-a[1],2)),o/c)}function m(t,e){var r=k[t],n=k[e];k[t]=n,k[e]=r,M[r]=e,M[n]=t}function v(t){return c[k[t]]}function y(t){return 1&t?t-1>>1:(t>>1)-1}function x(t){for(var e=v(t);;){var r=e,n=2*t+1,i=2*(t+1),a=t;if(n<A){var o=v(n);o<r&&(a=n,r=o)}if(i<A)v(i)<r&&(a=i);if(a===t)return t;m(t,a),t=a}}function b(t){for(var e=v(t);t>0;){var r=y(t);if(r>=0)if(e<v(r)){m(t,r),t=r;continue}return t}}function _(){if(A>0){var t=k[0];return m(0,A-1),A-=1,x(0),t}return-1}function w(t,e){var r=k[t];return c[r]===e?t:(c[r]=-1/0,b(t),_(),c[r]=e,b((A+=1)-1))}function T(t){if(!u[t]){u[t]=!0;var e=s[t],r=l[t];s[r]>=0&&(s[r]=e),l[e]>=0&&(l[e]=r),M[e]>=0&&w(M[e],g(e)),M[r]>=0&&w(M[r],g(r))}}var k=[],M=new Array(a);for(f=0;f<a;++f){(c[f]=g(f))<1/0?(M[f]=k.length,k.push(f)):M[f]=-1}var A=k.length;for(f=A>>1;f>=0;--f)x(f);for(;;){var S=_();if(S<0||c[S]>r)break;T(S)}var E=[];for(f=0;f<a;++f)u[f]||(M[f]=E.length,E.push(e[f].slice()));E.length;function C(t,e){if(t[e]<0)return e;var r=e,n=e;do{var i=t[n];if(!u[n]||i<0||i===n)break;if(i=t[n=i],!u[n]||i<0||i===n)break;n=i,r=t[r]}while(r!==n);for(var a=e;a!==n;a=t[a])t[a]=n;return n}var L=[];return t.forEach((function(t){var e=C(s,t[0]),r=C(l,t[1]);if(e>=0&&r>=0&&e!==r){var n=M[e],i=M[r];n!==i&&L.push([n,i])}})),i.unique(i.normalize(L)),{positions:E,edges:L}};var n=t(\"robust-orientation\"),i=t(\"simplicial-complex\")},{\"robust-orientation\":548,\"simplicial-complex\":560}],563:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,a,o,s;if(e[0][0]<e[1][0])r=e[0],a=e[1];else{if(!(e[0][0]>e[1][0]))return i(e,t);r=e[1],a=e[0]}if(t[0][0]<t[1][0])o=t[0],s=t[1];else{if(!(t[0][0]>t[1][0]))return-i(t,e);o=t[1],s=t[0]}var l=n(r,a,s),c=n(r,a,o);if(l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;if(l=n(s,o,a),c=n(s,o,r),l<0){if(c<=0)return l}else if(l>0){if(c>=0)return l}else if(c)return c;return a[0]-s[0]};var n=t(\"robust-orientation\");function i(t,e){var r,i,a,o;if(e[0][0]<e[1][0])r=e[0],i=e[1];else{if(!(e[0][0]>e[1][0])){var s=Math.min(t[0][1],t[1][1]),l=Math.max(t[0][1],t[1][1]),c=Math.min(e[0][1],e[1][1]),u=Math.max(e[0][1],e[1][1]);return l<c?l-c:s>u?s-u:l-u}r=e[1],i=e[0]}t[0][1]<t[1][1]?(a=t[0],o=t[1]):(a=t[1],o=t[0]);var f=n(i,r,a);return f||((f=n(i,r,o))||o-i)}},{\"robust-orientation\":548}],564:[function(t,e,r){arguments[4][243][0].apply(r,arguments)},{dup:243}],565:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=2*e,n=new Array(r),a=0;a<e;++a){var l=t[a],c=l[0][0]<l[1][0];n[2*a]=new f(l[0][0],l,c,a),n[2*a+1]=new f(l[1][0],l,!c,a)}n.sort((function(t,e){var r=t.x-e.x;return r||((r=t.create-e.create)||Math.min(t.segment[0][1],t.segment[1][1])-Math.min(e.segment[0][1],e.segment[1][1]))}));var h=i(o),p=[],d=[],g=[];for(a=0;a<r;){for(var m=n[a].x,v=[];a<r;){var y=n[a];if(y.x!==m)break;a+=1,y.segment[0][0]===y.x&&y.segment[1][0]===y.x?y.create&&(y.segment[0][1]<y.segment[1][1]?(v.push(new u(y.segment[0][1],y.index,!0,!0)),v.push(new u(y.segment[1][1],y.index,!1,!1))):(v.push(new u(y.segment[1][1],y.index,!0,!1)),v.push(new u(y.segment[0][1],y.index,!1,!0)))):h=y.create?h.insert(y.segment,y.index):h.remove(y.segment)}p.push(h.root),d.push(m),g.push(v)}return new s(p,d,g)};var n=t(\"binary-search-bounds\"),i=t(\"functional-red-black-tree\"),a=t(\"robust-orientation\"),o=t(\"./lib/order-segments\");function s(t,e,r){this.slabs=t,this.coordinates=e,this.horizontal=r}function l(t,e){return t.y-e}function c(t,e){for(var r=null;t;){var n,i,o=t.key;o[0][0]<o[1][0]?(n=o[0],i=o[1]):(n=o[1],i=o[0]);var s=a(n,i,e);if(s<0)t=t.left;else if(s>0)if(e[0]!==o[1][0])r=t,t=t.right;else{if(l=c(t.right,e))return l;t=t.left}else{if(e[0]!==o[1][0])return t;var l;if(l=c(t.right,e))return l;t=t.left}}return r}function u(t,e,r,n){this.y=t,this.index=e,this.start=r,this.closed=n}function f(t,e,r,n){this.x=t,this.segment=e,this.create=r,this.index=n}s.prototype.castUp=function(t){var e=n.le(this.coordinates,t[0]);if(e<0)return-1;this.slabs[e];var r=c(this.slabs[e],t),i=-1;if(r&&(i=r.value),this.coordinates[e]===t[0]){var s=null;if(r&&(s=r.key),e>0){var u=c(this.slabs[e-1],t);u&&(s?o(u.key,s)>0&&(s=u.key,i=u.value):(i=u.value,s=u.key))}var f=this.horizontal[e];if(f.length>0){var h=n.ge(f,t[1],l);if(h<f.length){var p=f[h];if(t[1]===p.y){if(p.closed)return p.index;for(;h<f.length-1&&f[h+1].y===t[1];)if((p=f[h+=1]).closed)return p.index;if(p.y===t[1]&&!p.start){if((h+=1)>=f.length)return i;p=f[h]}}if(p.start)if(s){var d=a(s[0],s[1],[t[0],p.y]);s[0][0]>s[1][0]&&(d=-d),d>0&&(i=p.index)}else i=p.index;else p.y!==t[1]&&(i=p.index)}}}return i}},{\"./lib/order-segments\":563,\"binary-search-bounds\":564,\"functional-red-black-tree\":247,\"robust-orientation\":548}],566:[function(t,e,r){\"use strict\";var n=t(\"robust-dot-product\"),i=t(\"robust-sum\");function a(t,e){var r=i(n(t,e),[e[e.length-1]]);return r[r.length-1]}function o(t,e,r,n){var i=-e/(n-e);i<0?i=0:i>1&&(i=1);for(var a=1-i,o=t.length,s=new Array(o),l=0;l<o;++l)s[l]=i*t[l]+a*r[l];return s}e.exports=function(t,e){for(var r=[],n=[],i=a(t[t.length-1],e),s=t[t.length-1],l=t[0],c=0;c<t.length;++c,s=l){var u=a(l=t[c],e);if(i<0&&u>0||i>0&&u<0){var f=o(s,u,l,i);r.push(f),n.push(f.slice())}u<0?n.push(l.slice()):u>0?r.push(l.slice()):(r.push(l.slice()),n.push(l.slice())),i=u}return{positive:r,negative:n}},e.exports.positive=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c>=0&&r.push(s.slice()),n=c}return r},e.exports.negative=function(t,e){for(var r=[],n=a(t[t.length-1],e),i=t[t.length-1],s=t[0],l=0;l<t.length;++l,i=s){var c=a(s=t[l],e);(n<0&&c>0||n>0&&c<0)&&r.push(o(i,c,s,n)),c<=0&&r.push(s.slice()),n=c}return r}},{\"robust-dot-product\":545,\"robust-sum\":553}],567:[function(t,e,r){!function(){\"use strict\";var t={not_string:/[^s]/,not_bool:/[^t]/,not_type:/[^T]/,not_primitive:/[^v]/,number:/[diefg]/,numeric_arg:/[bcdiefguxX]/,json:/[j]/,not_json:/[^j]/,text:/^[^\\x25]+/,modulo:/^\\x25{2}/,placeholder:/^\\x25(?:([1-9]\\d*)\\$|\\(([^)]+)\\))?(\\+)?(0|'[^$])?(-)?(\\d+)?(?:\\.(\\d+))?([b-gijostTuvxX])/,key:/^([a-z_][a-z_\\d]*)/i,key_access:/^\\.([a-z_][a-z_\\d]*)/i,index_access:/^\\[(\\d+)\\]/,sign:/^[+-]/};function e(t){return i(o(t),arguments)}function n(t,r){return e.apply(null,[t].concat(r||[]))}function i(r,n){var i,a,o,s,l,c,u,f,h,p=1,d=r.length,g=\"\";for(a=0;a<d;a++)if(\"string\"==typeof r[a])g+=r[a];else if(\"object\"==typeof r[a]){if((s=r[a]).keys)for(i=n[p],o=0;o<s.keys.length;o++){if(null==i)throw new Error(e('[sprintf] Cannot access property \"%s\" of undefined value \"%s\"',s.keys[o],s.keys[o-1]));i=i[s.keys[o]]}else i=s.param_no?n[s.param_no]:n[p++];if(t.not_type.test(s.type)&&t.not_primitive.test(s.type)&&i instanceof Function&&(i=i()),t.numeric_arg.test(s.type)&&\"number\"!=typeof i&&isNaN(i))throw new TypeError(e(\"[sprintf] expecting number but found %T\",i));switch(t.number.test(s.type)&&(f=i>=0),s.type){case\"b\":i=parseInt(i,10).toString(2);break;case\"c\":i=String.fromCharCode(parseInt(i,10));break;case\"d\":case\"i\":i=parseInt(i,10);break;case\"j\":i=JSON.stringify(i,null,s.width?parseInt(s.width):0);break;case\"e\":i=s.precision?parseFloat(i).toExponential(s.precision):parseFloat(i).toExponential();break;case\"f\":i=s.precision?parseFloat(i).toFixed(s.precision):parseFloat(i);break;case\"g\":i=s.precision?String(Number(i.toPrecision(s.precision))):parseFloat(i);break;case\"o\":i=(parseInt(i,10)>>>0).toString(8);break;case\"s\":i=String(i),i=s.precision?i.substring(0,s.precision):i;break;case\"t\":i=String(!!i),i=s.precision?i.substring(0,s.precision):i;break;case\"T\":i=Object.prototype.toString.call(i).slice(8,-1).toLowerCase(),i=s.precision?i.substring(0,s.precision):i;break;case\"u\":i=parseInt(i,10)>>>0;break;case\"v\":i=i.valueOf(),i=s.precision?i.substring(0,s.precision):i;break;case\"x\":i=(parseInt(i,10)>>>0).toString(16);break;case\"X\":i=(parseInt(i,10)>>>0).toString(16).toUpperCase()}t.json.test(s.type)?g+=i:(!t.number.test(s.type)||f&&!s.sign?h=\"\":(h=f?\"+\":\"-\",i=i.toString().replace(t.sign,\"\")),c=s.pad_char?\"0\"===s.pad_char?\"0\":s.pad_char.charAt(1):\" \",u=s.width-(h+i).length,l=s.width&&u>0?c.repeat(u):\"\",g+=s.align?h+i+l:\"0\"===c?h+l+i:l+h+i)}return g}var a=Object.create(null);function o(e){if(a[e])return a[e];for(var r,n=e,i=[],o=0;n;){if(null!==(r=t.text.exec(n)))i.push(r[0]);else if(null!==(r=t.modulo.exec(n)))i.push(\"%\");else{if(null===(r=t.placeholder.exec(n)))throw new SyntaxError(\"[sprintf] unexpected placeholder\");if(r[2]){o|=1;var s=[],l=r[2],c=[];if(null===(c=t.key.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");for(s.push(c[1]);\"\"!==(l=l.substring(c[0].length));)if(null!==(c=t.key_access.exec(l)))s.push(c[1]);else{if(null===(c=t.index_access.exec(l)))throw new SyntaxError(\"[sprintf] failed to parse named argument key\");s.push(c[1])}r[2]=s}else o|=2;if(3===o)throw new Error(\"[sprintf] mixing positional and named placeholders is not (yet) supported\");i.push({placeholder:r[0],param_no:r[1],keys:r[2],sign:r[3],pad_char:r[4],align:r[5],width:r[6],precision:r[7],type:r[8]})}n=n.substring(r[0].length)}return a[e]=i}\"undefined\"!=typeof r&&(r.sprintf=e,r.vsprintf=n),\"undefined\"!=typeof window&&(window.sprintf=e,window.vsprintf=n)}()},{}],568:[function(t,e,r){\"use strict\";var n=t(\"parenthesis\");e.exports=function(t,e,r){if(null==t)throw Error(\"First argument should be a string\");if(null==e)throw Error(\"Separator should be a string or a RegExp\");r?(\"string\"==typeof r||Array.isArray(r))&&(r={ignore:r}):r={},null==r.escape&&(r.escape=!0),null==r.ignore?r.ignore=[\"[]\",\"()\",\"{}\",\"<>\",'\"\"',\"''\",\"``\",\"\\u201c\\u201d\",\"\\xab\\xbb\"]:(\"string\"==typeof r.ignore&&(r.ignore=[r.ignore]),r.ignore=r.ignore.map((function(t){return 1===t.length&&(t+=t),t})));var i=n.parse(t,{flat:!0,brackets:r.ignore}),a=i[0].split(e);if(r.escape){for(var o=[],s=0;s<a.length;s++){var l=a[s],c=a[s+1];\"\\\\\"===l[l.length-1]&&\"\\\\\"!==l[l.length-2]?(o.push(l+e+c),s++):o.push(l)}a=o}for(s=0;s<a.length;s++)i[0]=a[s],a[s]=n.stringify(i,{flat:!0});return a}},{parenthesis:503}],569:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.length,r=new Array(e),n=new Array(e),i=new Array(e),a=new Array(e),o=new Array(e),s=new Array(e),l=0;l<e;++l)r[l]=-1,n[l]=0,i[l]=!1,a[l]=0,o[l]=-1,s[l]=[];var c,u=0,f=[],h=[];function p(e){var l=[e],c=[e];for(r[e]=n[e]=u,i[e]=!0,u+=1;c.length>0;){e=c[c.length-1];var p=t[e];if(a[e]<p.length){for(var d=a[e];d<p.length;++d){var g=p[d];if(r[g]<0){r[g]=n[g]=u,i[g]=!0,u+=1,l.push(g),c.push(g);break}i[g]&&(n[e]=0|Math.min(n[e],n[g])),o[g]>=0&&s[e].push(o[g])}a[e]=d}else{if(n[e]===r[e]){var m=[],v=[],y=0;for(d=l.length-1;d>=0;--d){var x=l[d];if(i[x]=!1,m.push(x),v.push(s[x]),y+=s[x].length,o[x]=f.length,x===e){l.length=d;break}}f.push(m);var b=new Array(y);for(d=0;d<v.length;d++)for(var _=0;_<v[d].length;_++)b[--y]=v[d][_];h.push(b)}c.pop()}}}for(l=0;l<e;++l)r[l]<0&&p(l);for(l=0;l<h.length;l++){var d=h[l];if(0!==d.length){d.sort((function(t,e){return t-e})),c=[d[0]];for(var g=1;g<d.length;g++)d[g]!==d[g-1]&&c.push(d[g]);h[l]=c}}return{components:f,adjacencyList:h}}},{}],570:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(t.dimension<=0)return{positions:[],cells:[]};if(1===t.dimension)return function(t,e){for(var r=a(t,e),n=r.length,i=new Array(n),o=new Array(n),s=0;s<n;++s)i[s]=[r[s]],o[s]=[s];return{positions:i,cells:o}}(t,e);var r=t.order.join()+\"-\"+t.dtype,s=o[r];e=+e||0;s||(s=o[r]=function(t,e){var r=t.length,a=[\"'use strict';\"],o=\"surfaceNets\"+t.join(\"_\")+\"d\"+e;a.push(\"var contour=genContour({\",\"order:[\",t.join(),\"],\",\"scalarArguments: 3,\",\"phase:function phaseFunc(p,a,b,c) { return (p > c)|0 },\"),\"generic\"===e&&a.push(\"getters:[0],\");for(var s=[],l=[],c=0;c<r;++c)s.push(\"d\"+c),l.push(\"d\"+c);for(c=0;c<1<<r;++c)s.push(\"v\"+c),l.push(\"v\"+c);for(c=0;c<1<<r;++c)s.push(\"p\"+c),l.push(\"p\"+c);s.push(\"a\",\"b\",\"c\"),l.push(\"a\",\"c\"),a.push(\"vertex:function vertexFunc(\",s.join(),\"){\");var u=[];for(c=0;c<1<<r;++c)u.push(\"(p\"+c+\"<<\"+c+\")\");a.push(\"var m=(\",u.join(\"+\"),\")|0;if(m===0||m===\",(1<<(1<<r))-1,\"){return}\");var f=[],h=[];1<<(1<<r)<=128?(a.push(\"switch(m){\"),h=a):a.push(\"switch(m>>>7){\");for(c=0;c<1<<(1<<r);++c){if(1<<(1<<r)>128&&c%128==0){f.length>0&&h.push(\"}}\");var p=\"vExtra\"+f.length;a.push(\"case \",c>>>7,\":\",p,\"(m&0x7f,\",l.join(),\");break;\"),h=[\"function \",p,\"(m,\",l.join(),\"){switch(m){\"],f.push(h)}h.push(\"case \",127&c,\":\");for(var d=new Array(r),g=new Array(r),m=new Array(r),v=new Array(r),y=0,x=0;x<r;++x)d[x]=[],g[x]=[],m[x]=0,v[x]=0;for(x=0;x<1<<r;++x)for(var b=0;b<r;++b){var _=x^1<<b;if(!(_>x)&&!(c&1<<_)!=!(c&1<<x)){var w=1;c&1<<_?g[b].push(\"v\"+_+\"-v\"+x):(g[b].push(\"v\"+x+\"-v\"+_),w=-w),w<0?(d[b].push(\"-v\"+x+\"-v\"+_),m[b]+=2):(d[b].push(\"v\"+x+\"+v\"+_),m[b]-=2),y+=1;for(var T=0;T<r;++T)T!==b&&(_&1<<T?v[T]+=1:v[T]-=1)}}var k=[];for(b=0;b<r;++b)if(0===d[b].length)k.push(\"d\"+b+\"-0.5\");else{var M=\"\";m[b]<0?M=m[b]+\"*c\":m[b]>0&&(M=\"+\"+m[b]+\"*c\");var A=d[b].length/y*.5,S=.5+v[b]/y*.5;k.push(\"d\"+b+\"-\"+S+\"-\"+A+\"*(\"+d[b].join(\"+\")+M+\")/(\"+g[b].join(\"+\")+\")\")}h.push(\"a.push([\",k.join(),\"]);\",\"break;\")}a.push(\"}},\"),f.length>0&&h.push(\"}}\");var E=[];for(c=0;c<1<<r-1;++c)E.push(\"v\"+c);E.push(\"c0\",\"c1\",\"p0\",\"p1\",\"a\",\"b\",\"c\"),a.push(\"cell:function cellFunc(\",E.join(),\"){\");var C=i(r-1);a.push(\"if(p0){b.push(\",C.map((function(t){return\"[\"+t.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}else{b.push(\",C.map((function(t){var e=t.slice();return e.reverse(),\"[\"+e.map((function(t){return\"v\"+t}))+\"]\"})).join(),\")}}});function \",o,\"(array,level){var verts=[],cells=[];contour(array,verts,cells,level);return {positions:verts,cells:cells};} return \",o,\";\");for(c=0;c<f.length;++c)a.push(f[c].join(\"\"));return new Function(\"genContour\",a.join(\"\"))(n)}(t.order,t.dtype));return s(t,e)};var n=t(\"ndarray-extract-contour\"),i=t(\"triangulate-hypercube\"),a=t(\"zero-crossings\");var o={}},{\"ndarray-extract-contour\":487,\"triangulate-hypercube\":580,\"zero-crossings\":624}],571:[function(t,e,r){\"use strict\";Object.defineProperty(r,\"__esModule\",{value:!0});var n=function(t,e){if(Array.isArray(t))return t;if(Symbol.iterator in Object(t))return function(t,e){var r=[],n=!0,i=!1,a=void 0;try{for(var o,s=t[Symbol.iterator]();!(n=(o=s.next()).done)&&(r.push(o.value),!e||r.length!==e);n=!0);}catch(t){i=!0,a=t}finally{try{!n&&s.return&&s.return()}finally{if(i)throw a}}return r}(t,e);throw new TypeError(\"Invalid attempt to destructure non-iterable instance\")},i=2*Math.PI,a=function(t,e,r,n,i,a,o){var s=t.x,l=t.y;return{x:n*(s*=e)-i*(l*=r)+a,y:i*s+n*l+o}},o=function(t,e){var r=1.5707963267948966===e?.551915024494:-1.5707963267948966===e?-.551915024494:4/3*Math.tan(e/4),n=Math.cos(t),i=Math.sin(t),a=Math.cos(t+e),o=Math.sin(t+e);return[{x:n-i*r,y:i+n*r},{x:a+o*r,y:o-a*r},{x:a,y:o}]},s=function(t,e,r,n){var i=t*r+e*n;return i>1&&(i=1),i<-1&&(i=-1),(t*n-e*r<0?-1:1)*Math.acos(i)};r.default=function(t){var e=t.px,r=t.py,l=t.cx,c=t.cy,u=t.rx,f=t.ry,h=t.xAxisRotation,p=void 0===h?0:h,d=t.largeArcFlag,g=void 0===d?0:d,m=t.sweepFlag,v=void 0===m?0:m,y=[];if(0===u||0===f)return[];var x=Math.sin(p*i/360),b=Math.cos(p*i/360),_=b*(e-l)/2+x*(r-c)/2,w=-x*(e-l)/2+b*(r-c)/2;if(0===_&&0===w)return[];u=Math.abs(u),f=Math.abs(f);var T=Math.pow(_,2)/Math.pow(u,2)+Math.pow(w,2)/Math.pow(f,2);T>1&&(u*=Math.sqrt(T),f*=Math.sqrt(T));var k=function(t,e,r,n,a,o,l,c,u,f,h,p){var d=Math.pow(a,2),g=Math.pow(o,2),m=Math.pow(h,2),v=Math.pow(p,2),y=d*g-d*v-g*m;y<0&&(y=0),y/=d*v+g*m;var x=(y=Math.sqrt(y)*(l===c?-1:1))*a/o*p,b=y*-o/a*h,_=f*x-u*b+(t+r)/2,w=u*x+f*b+(e+n)/2,T=(h-x)/a,k=(p-b)/o,M=(-h-x)/a,A=(-p-b)/o,S=s(1,0,T,k),E=s(T,k,M,A);return 0===c&&E>0&&(E-=i),1===c&&E<0&&(E+=i),[_,w,S,E]}(e,r,l,c,u,f,g,v,x,b,_,w),M=n(k,4),A=M[0],S=M[1],E=M[2],C=M[3],L=Math.abs(C)/(i/4);Math.abs(1-L)<1e-7&&(L=1);var I=Math.max(Math.ceil(L),1);C/=I;for(var P=0;P<I;P++)y.push(o(E,C)),E+=C;return y.map((function(t){var e=a(t[0],u,f,b,x,A,S),r=e.x,n=e.y,i=a(t[1],u,f,b,x,A,S),o=i.x,s=i.y,l=a(t[2],u,f,b,x,A,S);return{x1:r,y1:n,x2:o,y2:s,x:l.x,y:l.y}}))},e.exports=r.default},{}],572:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"abs-svg-path\"),a=t(\"normalize-svg-path\"),o=t(\"is-svg-path\"),s=t(\"assert\");e.exports=function(t){Array.isArray(t)&&1===t.length&&\"string\"==typeof t[0]&&(t=t[0]);\"string\"==typeof t&&(s(o(t),\"String is not an SVG path.\"),t=n(t));if(s(Array.isArray(t),\"Argument should be a string or an array of path segments.\"),t=i(t),!(t=a(t)).length)return[0,0,0,0];for(var e=[1/0,1/0,-1/0,-1/0],r=0,l=t.length;r<l;r++)for(var c=t[r].slice(1),u=0;u<c.length;u+=2)c[u+0]<e[0]&&(e[0]=c[u+0]),c[u+1]<e[1]&&(e[1]=c[u+1]),c[u+0]>e[2]&&(e[2]=c[u+0]),c[u+1]>e[3]&&(e[3]=c[u+1]);return e}},{\"abs-svg-path\":65,assert:73,\"is-svg-path\":471,\"normalize-svg-path\":573,\"parse-svg-path\":505}],573:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e,r=[],o=0,s=0,l=0,c=0,u=null,f=null,h=0,p=0,d=0,g=t.length;d<g;d++){var m=t[d],v=m[0];switch(v){case\"M\":l=m[1],c=m[2];break;case\"A\":var y=n({px:h,py:p,cx:m[6],cy:m[7],rx:m[1],ry:m[2],xAxisRotation:m[3],largeArcFlag:m[4],sweepFlag:m[5]});if(!y.length)continue;for(var x,b=0;b<y.length;b++)x=y[b],m=[\"C\",x.x1,x.y1,x.x2,x.y2,x.x,x.y],b<y.length-1&&r.push(m);break;case\"S\":var _=h,w=p;\"C\"!=e&&\"S\"!=e||(_+=_-o,w+=w-s),m=[\"C\",_,w,m[1],m[2],m[3],m[4]];break;case\"T\":\"Q\"==e||\"T\"==e?(u=2*h-u,f=2*p-f):(u=h,f=p),m=a(h,p,u,f,m[1],m[2]);break;case\"Q\":u=m[1],f=m[2],m=a(h,p,m[1],m[2],m[3],m[4]);break;case\"L\":m=i(h,p,m[1],m[2]);break;case\"H\":m=i(h,p,m[1],p);break;case\"V\":m=i(h,p,h,m[1]);break;case\"Z\":m=i(h,p,l,c)}e=v,h=m[m.length-2],p=m[m.length-1],m.length>4?(o=m[m.length-4],s=m[m.length-3]):(o=h,s=p),r.push(m)}return r};var n=t(\"svg-arc-to-cubic-bezier\");function i(t,e,r,n){return[\"C\",t,e,r,n,r,n]}function a(t,e,r,n,i,a){return[\"C\",t/3+2/3*r,e/3+2/3*n,i/3+2/3*r,a/3+2/3*n,i,a]}},{\"svg-arc-to-cubic-bezier\":571}],574:[function(t,e,r){\"use strict\";var n,i=t(\"svg-path-bounds\"),a=t(\"parse-svg-path\"),o=t(\"draw-svg-path\"),s=t(\"is-svg-path\"),l=t(\"bitmap-sdf\"),c=document.createElement(\"canvas\"),u=c.getContext(\"2d\");e.exports=function(t,e){if(!s(t))throw Error(\"Argument should be valid svg path string\");e||(e={});var r,f;e.shape?(r=e.shape[0],f=e.shape[1]):(r=c.width=e.w||e.width||200,f=c.height=e.h||e.height||200);var h=Math.min(r,f),p=e.stroke||0,d=e.viewbox||e.viewBox||i(t),g=[r/(d[2]-d[0]),f/(d[3]-d[1])],m=Math.min(g[0]||0,g[1]||0)/2;u.fillStyle=\"black\",u.fillRect(0,0,r,f),u.fillStyle=\"white\",p&&(\"number\"!=typeof p&&(p=1),u.strokeStyle=p>0?\"white\":\"black\",u.lineWidth=Math.abs(p));if(u.translate(.5*r,.5*f),u.scale(m,m),function(){if(null!=n)return n;var t=document.createElement(\"canvas\").getContext(\"2d\");if(t.canvas.width=t.canvas.height=1,!window.Path2D)return n=!1;var e=new Path2D(\"M0,0h1v1h-1v-1Z\");t.fillStyle=\"black\",t.fill(e);var r=t.getImageData(0,0,1,1);return n=r&&r.data&&255===r.data[3]}()){var v=new Path2D(t);u.fill(v),p&&u.stroke(v)}else{var y=a(t);o(u,y),u.fill(),p&&u.stroke()}return u.setTransform(1,0,0,1,0,0),l(u,{cutoff:null!=e.cutoff?e.cutoff:.5,radius:null!=e.radius?e.radius:.5*h})}},{\"bitmap-sdf\":98,\"draw-svg-path\":174,\"is-svg-path\":471,\"parse-svg-path\":505,\"svg-path-bounds\":572}],575:[function(t,e,r){(function(r){(function(){\"use strict\";e.exports=function t(e,r,i){i=i||{};var o=a[e];o||(o=a[e]={\" \":{data:new Float32Array(0),shape:.2}});var s=o[r];if(!s)if(r.length<=1||!/\\d/.test(r))s=o[r]=function(t){for(var e=t.cells,r=t.positions,n=new Float32Array(6*e.length),i=0,a=0,o=0;o<e.length;++o)for(var s=e[o],l=0;l<3;++l){var c=r[s[l]];n[i++]=c[0],n[i++]=c[1]+1.4,a=Math.max(c[0],a)}return{data:n,shape:a}}(n(r,{triangles:!0,font:e,textAlign:i.textAlign||\"left\",textBaseline:\"alphabetic\",styletags:{breaklines:!0,bolds:!0,italics:!0,subscripts:!0,superscripts:!0}}));else{for(var l=r.split(/(\\d|\\s)/),c=new Array(l.length),u=0,f=0,h=0;h<l.length;++h)c[h]=t(e,l[h]),u+=c[h].data.length,f+=c[h].shape,h>0&&(f+=.02);var p=new Float32Array(u),d=0,g=-.5*f;for(h=0;h<c.length;++h){for(var m=c[h].data,v=0;v<m.length;v+=2)p[d++]=m[v]+g,p[d++]=m[v+1];g+=c[h].shape+.02}s=o[r]={data:p,shape:f}}return s};var n=t(\"vectorize-text\"),i=window||r.global||{},a=i.__TEXT_CACHE||{};i.__TEXT_CACHE={}}).call(this)}).call(this,t(\"_process\"))},{_process:526,\"vectorize-text\":600}],576:[function(t,e,r){!function(t){var r=/^\\s+/,n=/\\s+$/,i=0,a=t.round,o=t.min,s=t.max,l=t.random;function c(e,l){if(l=l||{},(e=e||\"\")instanceof c)return e;if(!(this instanceof c))return new c(e,l);var u=function(e){var i={r:0,g:0,b:0},a=1,l=null,c=null,u=null,f=!1,h=!1;\"string\"==typeof e&&(e=function(t){t=t.replace(r,\"\").replace(n,\"\").toLowerCase();var e,i=!1;if(S[t])t=S[t],i=!0;else if(\"transparent\"==t)return{r:0,g:0,b:0,a:0,format:\"name\"};if(e=j.rgb.exec(t))return{r:e[1],g:e[2],b:e[3]};if(e=j.rgba.exec(t))return{r:e[1],g:e[2],b:e[3],a:e[4]};if(e=j.hsl.exec(t))return{h:e[1],s:e[2],l:e[3]};if(e=j.hsla.exec(t))return{h:e[1],s:e[2],l:e[3],a:e[4]};if(e=j.hsv.exec(t))return{h:e[1],s:e[2],v:e[3]};if(e=j.hsva.exec(t))return{h:e[1],s:e[2],v:e[3],a:e[4]};if(e=j.hex8.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),a:R(e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex6.exec(t))return{r:P(e[1]),g:P(e[2]),b:P(e[3]),format:i?\"name\":\"hex\"};if(e=j.hex4.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),a:R(e[4]+\"\"+e[4]),format:i?\"name\":\"hex8\"};if(e=j.hex3.exec(t))return{r:P(e[1]+\"\"+e[1]),g:P(e[2]+\"\"+e[2]),b:P(e[3]+\"\"+e[3]),format:i?\"name\":\"hex\"};return!1}(e));\"object\"==typeof e&&(U(e.r)&&U(e.g)&&U(e.b)?(p=e.r,d=e.g,g=e.b,i={r:255*L(p,255),g:255*L(d,255),b:255*L(g,255)},f=!0,h=\"%\"===String(e.r).substr(-1)?\"prgb\":\"rgb\"):U(e.h)&&U(e.s)&&U(e.v)?(l=O(e.s),c=O(e.v),i=function(e,r,n){e=6*L(e,360),r=L(r,100),n=L(n,100);var i=t.floor(e),a=e-i,o=n*(1-r),s=n*(1-a*r),l=n*(1-(1-a)*r),c=i%6;return{r:255*[n,s,o,o,l,n][c],g:255*[l,n,n,s,o,o][c],b:255*[o,o,l,n,n,s][c]}}(e.h,l,c),f=!0,h=\"hsv\"):U(e.h)&&U(e.s)&&U(e.l)&&(l=O(e.s),u=O(e.l),i=function(t,e,r){var n,i,a;function o(t,e,r){return r<0&&(r+=1),r>1&&(r-=1),r<1/6?t+6*(e-t)*r:r<.5?e:r<2/3?t+(e-t)*(2/3-r)*6:t}if(t=L(t,360),e=L(e,100),r=L(r,100),0===e)n=i=a=r;else{var s=r<.5?r*(1+e):r+e-r*e,l=2*r-s;n=o(l,s,t+1/3),i=o(l,s,t),a=o(l,s,t-1/3)}return{r:255*n,g:255*i,b:255*a}}(e.h,l,u),f=!0,h=\"hsl\"),e.hasOwnProperty(\"a\")&&(a=e.a));var p,d,g;return a=C(a),{ok:f,format:e.format||h,r:o(255,s(i.r,0)),g:o(255,s(i.g,0)),b:o(255,s(i.b,0)),a:a}}(e);this._originalInput=e,this._r=u.r,this._g=u.g,this._b=u.b,this._a=u.a,this._roundA=a(100*this._a)/100,this._format=l.format||u.format,this._gradientType=l.gradientType,this._r<1&&(this._r=a(this._r)),this._g<1&&(this._g=a(this._g)),this._b<1&&(this._b=a(this._b)),this._ok=u.ok,this._tc_id=i++}function u(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=(a+l)/2;if(a==l)n=i=0;else{var u=a-l;switch(i=c>.5?u/(2-a-l):u/(a+l),a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,l:c}}function f(t,e,r){t=L(t,255),e=L(e,255),r=L(r,255);var n,i,a=s(t,e,r),l=o(t,e,r),c=a,u=a-l;if(i=0===a?0:u/a,a==l)n=0;else{switch(a){case t:n=(e-r)/u+(e<r?6:0);break;case e:n=(r-t)/u+2;break;case r:n=(t-e)/u+4}n/=6}return{h:n,s:i,v:c}}function h(t,e,r,n){var i=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))];return n&&i[0].charAt(0)==i[0].charAt(1)&&i[1].charAt(0)==i[1].charAt(1)&&i[2].charAt(0)==i[2].charAt(1)?i[0].charAt(0)+i[1].charAt(0)+i[2].charAt(0):i.join(\"\")}function p(t,e,r,n){return[z(D(n)),z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16))].join(\"\")}function d(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s-=e/100,r.s=I(r.s),c(r)}function g(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.s+=e/100,r.s=I(r.s),c(r)}function m(t){return c(t).desaturate(100)}function v(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l+=e/100,r.l=I(r.l),c(r)}function y(t,e){e=0===e?0:e||10;var r=c(t).toRgb();return r.r=s(0,o(255,r.r-a(-e/100*255))),r.g=s(0,o(255,r.g-a(-e/100*255))),r.b=s(0,o(255,r.b-a(-e/100*255))),c(r)}function x(t,e){e=0===e?0:e||10;var r=c(t).toHsl();return r.l-=e/100,r.l=I(r.l),c(r)}function b(t,e){var r=c(t).toHsl(),n=(r.h+e)%360;return r.h=n<0?360+n:n,c(r)}function _(t){var e=c(t).toHsl();return e.h=(e.h+180)%360,c(e)}function w(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+120)%360,s:e.s,l:e.l}),c({h:(r+240)%360,s:e.s,l:e.l})]}function T(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+90)%360,s:e.s,l:e.l}),c({h:(r+180)%360,s:e.s,l:e.l}),c({h:(r+270)%360,s:e.s,l:e.l})]}function k(t){var e=c(t).toHsl(),r=e.h;return[c(t),c({h:(r+72)%360,s:e.s,l:e.l}),c({h:(r+216)%360,s:e.s,l:e.l})]}function M(t,e,r){e=e||6,r=r||30;var n=c(t).toHsl(),i=360/r,a=[c(t)];for(n.h=(n.h-(i*e>>1)+720)%360;--e;)n.h=(n.h+i)%360,a.push(c(n));return a}function A(t,e){e=e||6;for(var r=c(t).toHsv(),n=r.h,i=r.s,a=r.v,o=[],s=1/e;e--;)o.push(c({h:n,s:i,v:a})),a=(a+s)%1;return o}c.prototype={isDark:function(){return this.getBrightness()<128},isLight:function(){return!this.isDark()},isValid:function(){return this._ok},getOriginalInput:function(){return this._originalInput},getFormat:function(){return this._format},getAlpha:function(){return this._a},getBrightness:function(){var t=this.toRgb();return(299*t.r+587*t.g+114*t.b)/1e3},getLuminance:function(){var e,r,n,i=this.toRgb();return e=i.r/255,r=i.g/255,n=i.b/255,.2126*(e<=.03928?e/12.92:t.pow((e+.055)/1.055,2.4))+.7152*(r<=.03928?r/12.92:t.pow((r+.055)/1.055,2.4))+.0722*(n<=.03928?n/12.92:t.pow((n+.055)/1.055,2.4))},setAlpha:function(t){return this._a=C(t),this._roundA=a(100*this._a)/100,this},toHsv:function(){var t=f(this._r,this._g,this._b);return{h:360*t.h,s:t.s,v:t.v,a:this._a}},toHsvString:function(){var t=f(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.v);return 1==this._a?\"hsv(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsva(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHsl:function(){var t=u(this._r,this._g,this._b);return{h:360*t.h,s:t.s,l:t.l,a:this._a}},toHslString:function(){var t=u(this._r,this._g,this._b),e=a(360*t.h),r=a(100*t.s),n=a(100*t.l);return 1==this._a?\"hsl(\"+e+\", \"+r+\"%, \"+n+\"%)\":\"hsla(\"+e+\", \"+r+\"%, \"+n+\"%, \"+this._roundA+\")\"},toHex:function(t){return h(this._r,this._g,this._b,t)},toHexString:function(t){return\"#\"+this.toHex(t)},toHex8:function(t){return function(t,e,r,n,i){var o=[z(a(t).toString(16)),z(a(e).toString(16)),z(a(r).toString(16)),z(D(n))];if(i&&o[0].charAt(0)==o[0].charAt(1)&&o[1].charAt(0)==o[1].charAt(1)&&o[2].charAt(0)==o[2].charAt(1)&&o[3].charAt(0)==o[3].charAt(1))return o[0].charAt(0)+o[1].charAt(0)+o[2].charAt(0)+o[3].charAt(0);return o.join(\"\")}(this._r,this._g,this._b,this._a,t)},toHex8String:function(t){return\"#\"+this.toHex8(t)},toRgb:function(){return{r:a(this._r),g:a(this._g),b:a(this._b),a:this._a}},toRgbString:function(){return 1==this._a?\"rgb(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\")\":\"rgba(\"+a(this._r)+\", \"+a(this._g)+\", \"+a(this._b)+\", \"+this._roundA+\")\"},toPercentageRgb:function(){return{r:a(100*L(this._r,255))+\"%\",g:a(100*L(this._g,255))+\"%\",b:a(100*L(this._b,255))+\"%\",a:this._a}},toPercentageRgbString:function(){return 1==this._a?\"rgb(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%)\":\"rgba(\"+a(100*L(this._r,255))+\"%, \"+a(100*L(this._g,255))+\"%, \"+a(100*L(this._b,255))+\"%, \"+this._roundA+\")\"},toName:function(){return 0===this._a?\"transparent\":!(this._a<1)&&(E[h(this._r,this._g,this._b,!0)]||!1)},toFilter:function(t){var e=\"#\"+p(this._r,this._g,this._b,this._a),r=e,n=this._gradientType?\"GradientType = 1, \":\"\";if(t){var i=c(t);r=\"#\"+p(i._r,i._g,i._b,i._a)}return\"progid:DXImageTransform.Microsoft.gradient(\"+n+\"startColorstr=\"+e+\",endColorstr=\"+r+\")\"},toString:function(t){var e=!!t;t=t||this._format;var r=!1,n=this._a<1&&this._a>=0;return e||!n||\"hex\"!==t&&\"hex6\"!==t&&\"hex3\"!==t&&\"hex4\"!==t&&\"hex8\"!==t&&\"name\"!==t?(\"rgb\"===t&&(r=this.toRgbString()),\"prgb\"===t&&(r=this.toPercentageRgbString()),\"hex\"!==t&&\"hex6\"!==t||(r=this.toHexString()),\"hex3\"===t&&(r=this.toHexString(!0)),\"hex4\"===t&&(r=this.toHex8String(!0)),\"hex8\"===t&&(r=this.toHex8String()),\"name\"===t&&(r=this.toName()),\"hsl\"===t&&(r=this.toHslString()),\"hsv\"===t&&(r=this.toHsvString()),r||this.toHexString()):\"name\"===t&&0===this._a?this.toName():this.toRgbString()},clone:function(){return c(this.toString())},_applyModification:function(t,e){var r=t.apply(null,[this].concat([].slice.call(e)));return this._r=r._r,this._g=r._g,this._b=r._b,this.setAlpha(r._a),this},lighten:function(){return this._applyModification(v,arguments)},brighten:function(){return this._applyModification(y,arguments)},darken:function(){return this._applyModification(x,arguments)},desaturate:function(){return this._applyModification(d,arguments)},saturate:function(){return this._applyModification(g,arguments)},greyscale:function(){return this._applyModification(m,arguments)},spin:function(){return this._applyModification(b,arguments)},_applyCombination:function(t,e){return t.apply(null,[this].concat([].slice.call(e)))},analogous:function(){return this._applyCombination(M,arguments)},complement:function(){return this._applyCombination(_,arguments)},monochromatic:function(){return this._applyCombination(A,arguments)},splitcomplement:function(){return this._applyCombination(k,arguments)},triad:function(){return this._applyCombination(w,arguments)},tetrad:function(){return this._applyCombination(T,arguments)}},c.fromRatio=function(t,e){if(\"object\"==typeof t){var r={};for(var n in t)t.hasOwnProperty(n)&&(r[n]=\"a\"===n?t[n]:O(t[n]));t=r}return c(t,e)},c.equals=function(t,e){return!(!t||!e)&&c(t).toRgbString()==c(e).toRgbString()},c.random=function(){return c.fromRatio({r:l(),g:l(),b:l()})},c.mix=function(t,e,r){r=0===r?0:r||50;var n=c(t).toRgb(),i=c(e).toRgb(),a=r/100;return c({r:(i.r-n.r)*a+n.r,g:(i.g-n.g)*a+n.g,b:(i.b-n.b)*a+n.b,a:(i.a-n.a)*a+n.a})},c.readability=function(e,r){var n=c(e),i=c(r);return(t.max(n.getLuminance(),i.getLuminance())+.05)/(t.min(n.getLuminance(),i.getLuminance())+.05)},c.isReadable=function(t,e,r){var n,i,a=c.readability(t,e);switch(i=!1,(n=function(t){var e,r;e=((t=t||{level:\"AA\",size:\"small\"}).level||\"AA\").toUpperCase(),r=(t.size||\"small\").toLowerCase(),\"AA\"!==e&&\"AAA\"!==e&&(e=\"AA\");\"small\"!==r&&\"large\"!==r&&(r=\"small\");return{level:e,size:r}}(r)).level+n.size){case\"AAsmall\":case\"AAAlarge\":i=a>=4.5;break;case\"AAlarge\":i=a>=3;break;case\"AAAsmall\":i=a>=7}return i},c.mostReadable=function(t,e,r){var n,i,a,o,s=null,l=0;i=(r=r||{}).includeFallbackColors,a=r.level,o=r.size;for(var u=0;u<e.length;u++)(n=c.readability(t,e[u]))>l&&(l=n,s=c(e[u]));return c.isReadable(t,s,{level:a,size:o})||!i?s:(r.includeFallbackColors=!1,c.mostReadable(t,[\"#fff\",\"#000\"],r))};var S=c.names={aliceblue:\"f0f8ff\",antiquewhite:\"faebd7\",aqua:\"0ff\",aquamarine:\"7fffd4\",azure:\"f0ffff\",beige:\"f5f5dc\",bisque:\"ffe4c4\",black:\"000\",blanchedalmond:\"ffebcd\",blue:\"00f\",blueviolet:\"8a2be2\",brown:\"a52a2a\",burlywood:\"deb887\",burntsienna:\"ea7e5d\",cadetblue:\"5f9ea0\",chartreuse:\"7fff00\",chocolate:\"d2691e\",coral:\"ff7f50\",cornflowerblue:\"6495ed\",cornsilk:\"fff8dc\",crimson:\"dc143c\",cyan:\"0ff\",darkblue:\"00008b\",darkcyan:\"008b8b\",darkgoldenrod:\"b8860b\",darkgray:\"a9a9a9\",darkgreen:\"006400\",darkgrey:\"a9a9a9\",darkkhaki:\"bdb76b\",darkmagenta:\"8b008b\",darkolivegreen:\"556b2f\",darkorange:\"ff8c00\",darkorchid:\"9932cc\",darkred:\"8b0000\",darksalmon:\"e9967a\",darkseagreen:\"8fbc8f\",darkslateblue:\"483d8b\",darkslategray:\"2f4f4f\",darkslategrey:\"2f4f4f\",darkturquoise:\"00ced1\",darkviolet:\"9400d3\",deeppink:\"ff1493\",deepskyblue:\"00bfff\",dimgray:\"696969\",dimgrey:\"696969\",dodgerblue:\"1e90ff\",firebrick:\"b22222\",floralwhite:\"fffaf0\",forestgreen:\"228b22\",fuchsia:\"f0f\",gainsboro:\"dcdcdc\",ghostwhite:\"f8f8ff\",gold:\"ffd700\",goldenrod:\"daa520\",gray:\"808080\",green:\"008000\",greenyellow:\"adff2f\",grey:\"808080\",honeydew:\"f0fff0\",hotpink:\"ff69b4\",indianred:\"cd5c5c\",indigo:\"4b0082\",ivory:\"fffff0\",khaki:\"f0e68c\",lavender:\"e6e6fa\",lavenderblush:\"fff0f5\",lawngreen:\"7cfc00\",lemonchiffon:\"fffacd\",lightblue:\"add8e6\",lightcoral:\"f08080\",lightcyan:\"e0ffff\",lightgoldenrodyellow:\"fafad2\",lightgray:\"d3d3d3\",lightgreen:\"90ee90\",lightgrey:\"d3d3d3\",lightpink:\"ffb6c1\",lightsalmon:\"ffa07a\",lightseagreen:\"20b2aa\",lightskyblue:\"87cefa\",lightslategray:\"789\",lightslategrey:\"789\",lightsteelblue:\"b0c4de\",lightyellow:\"ffffe0\",lime:\"0f0\",limegreen:\"32cd32\",linen:\"faf0e6\",magenta:\"f0f\",maroon:\"800000\",mediumaquamarine:\"66cdaa\",mediumblue:\"0000cd\",mediumorchid:\"ba55d3\",mediumpurple:\"9370db\",mediumseagreen:\"3cb371\",mediumslateblue:\"7b68ee\",mediumspringgreen:\"00fa9a\",mediumturquoise:\"48d1cc\",mediumvioletred:\"c71585\",midnightblue:\"191970\",mintcream:\"f5fffa\",mistyrose:\"ffe4e1\",moccasin:\"ffe4b5\",navajowhite:\"ffdead\",navy:\"000080\",oldlace:\"fdf5e6\",olive:\"808000\",olivedrab:\"6b8e23\",orange:\"ffa500\",orangered:\"ff4500\",orchid:\"da70d6\",palegoldenrod:\"eee8aa\",palegreen:\"98fb98\",paleturquoise:\"afeeee\",palevioletred:\"db7093\",papayawhip:\"ffefd5\",peachpuff:\"ffdab9\",peru:\"cd853f\",pink:\"ffc0cb\",plum:\"dda0dd\",powderblue:\"b0e0e6\",purple:\"800080\",rebeccapurple:\"663399\",red:\"f00\",rosybrown:\"bc8f8f\",royalblue:\"4169e1\",saddlebrown:\"8b4513\",salmon:\"fa8072\",sandybrown:\"f4a460\",seagreen:\"2e8b57\",seashell:\"fff5ee\",sienna:\"a0522d\",silver:\"c0c0c0\",skyblue:\"87ceeb\",slateblue:\"6a5acd\",slategray:\"708090\",slategrey:\"708090\",snow:\"fffafa\",springgreen:\"00ff7f\",steelblue:\"4682b4\",tan:\"d2b48c\",teal:\"008080\",thistle:\"d8bfd8\",tomato:\"ff6347\",turquoise:\"40e0d0\",violet:\"ee82ee\",wheat:\"f5deb3\",white:\"fff\",whitesmoke:\"f5f5f5\",yellow:\"ff0\",yellowgreen:\"9acd32\"},E=c.hexNames=function(t){var e={};for(var r in t)t.hasOwnProperty(r)&&(e[t[r]]=r);return e}(S);function C(t){return t=parseFloat(t),(isNaN(t)||t<0||t>1)&&(t=1),t}function L(e,r){(function(t){return\"string\"==typeof t&&-1!=t.indexOf(\".\")&&1===parseFloat(t)})(e)&&(e=\"100%\");var n=function(t){return\"string\"==typeof t&&-1!=t.indexOf(\"%\")}(e);return e=o(r,s(0,parseFloat(e))),n&&(e=parseInt(e*r,10)/100),t.abs(e-r)<1e-6?1:e%r/parseFloat(r)}function I(t){return o(1,s(0,t))}function P(t){return parseInt(t,16)}function z(t){return 1==t.length?\"0\"+t:\"\"+t}function O(t){return t<=1&&(t=100*t+\"%\"),t}function D(e){return t.round(255*parseFloat(e)).toString(16)}function R(t){return P(t)/255}var F,B,N,j=(B=\"[\\\\s|\\\\(]+(\"+(F=\"(?:[-\\\\+]?\\\\d*\\\\.\\\\d+%?)|(?:[-\\\\+]?\\\\d+%?)\")+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",N=\"[\\\\s|\\\\(]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")[,|\\\\s]+(\"+F+\")\\\\s*\\\\)?\",{CSS_UNIT:new RegExp(F),rgb:new RegExp(\"rgb\"+B),rgba:new RegExp(\"rgba\"+N),hsl:new RegExp(\"hsl\"+B),hsla:new RegExp(\"hsla\"+N),hsv:new RegExp(\"hsv\"+B),hsva:new RegExp(\"hsva\"+N),hex3:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex6:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/,hex4:/^#?([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})([0-9a-fA-F]{1})$/,hex8:/^#?([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/});function U(t){return!!j.CSS_UNIT.exec(t)}\"undefined\"!=typeof e&&e.exports?e.exports=c:window.tinycolor=c}(Math)},{}],577:[function(t,e,r){\"use strict\";e.exports=i,e.exports.float32=e.exports.float=i,e.exports.fract32=e.exports.fract=function(t){if(t.length){for(var e=i(t),r=0,n=e.length;r<n;r++)e[r]=t[r]-e[r];return e}return i(t-i(t))};var n=new Float32Array(1);function i(t){if(t.length){if(t instanceof Float32Array)return t;var e=new Float32Array(t);return e.set(t),e}return n[0]=t,n[0]}},{}],578:[function(t,e,r){\"use strict\";var n=t(\"parse-unit\");e.exports=a;function i(t,e){var r=n(getComputedStyle(t).getPropertyValue(e));return r[0]*a(r[1],t)}function a(t,e){switch(e=e||document.body,t=(t||\"px\").trim().toLowerCase(),e!==window&&e!==document||(e=document.body),t){case\"%\":return e.clientHeight/100;case\"ch\":case\"ex\":return function(t,e){var r=document.createElement(\"div\");r.style[\"font-size\"]=\"128\"+t,e.appendChild(r);var n=i(r,\"font-size\")/128;return e.removeChild(r),n}(t,e);case\"em\":return i(e,\"font-size\");case\"rem\":return i(document.body,\"font-size\");case\"vw\":return window.innerWidth/100;case\"vh\":return window.innerHeight/100;case\"vmin\":return Math.min(window.innerWidth,window.innerHeight)/100;case\"vmax\":return Math.max(window.innerWidth,window.innerHeight)/100;case\"in\":return 96;case\"cm\":return 96/2.54;case\"mm\":return 96/25.4;case\"pt\":return 96/72;case\"pc\":return 16}return 1}},{\"parse-unit\":506}],579:[function(t,e,r){!function(t,n){\"object\"==typeof r&&\"undefined\"!=typeof e?n(r):n((t=t||self).topojson=t.topojson||{})}(this,(function(t){\"use strict\";function e(t){return t}function r(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c);for(u[0]=(r+=t[0])*i+o,u[1]=(n+=t[1])*a+s;l<c;)u[l]=t[l],++l;return u}}function n(t){var e,n=r(t.transform),i=1/0,a=i,o=-i,s=-i;function l(t){(t=n(t))[0]<i&&(i=t[0]),t[0]>o&&(o=t[0]),t[1]<a&&(a=t[1]),t[1]>s&&(s=t[1])}function c(t){switch(t.type){case\"GeometryCollection\":t.geometries.forEach(c);break;case\"Point\":l(t.coordinates);break;case\"MultiPoint\":t.coordinates.forEach(l)}}for(e in t.arcs.forEach((function(t){for(var e,r=-1,l=t.length;++r<l;)(e=n(t[r],r))[0]<i&&(i=e[0]),e[0]>o&&(o=e[0]),e[1]<a&&(a=e[1]),e[1]>s&&(s=e[1])})),t.objects)c(t.objects[e]);return[i,a,o,s]}function i(t,e){var r=e.id,n=e.bbox,i=null==e.properties?{}:e.properties,o=a(t,e);return null==r&&null==n?{type:\"Feature\",properties:i,geometry:o}:null==n?{type:\"Feature\",id:r,properties:i,geometry:o}:{type:\"Feature\",id:r,bbox:n,properties:i,geometry:o}}function a(t,e){var n=r(t.transform),i=t.arcs;function a(t,e){e.length&&e.pop();for(var r=i[t<0?~t:t],a=0,o=r.length;a<o;++a)e.push(n(r[a],a));t<0&&function(t,e){for(var r,n=t.length,i=n-e;i<--n;)r=t[i],t[i++]=t[n],t[n]=r}(e,o)}function o(t){return n(t)}function s(t){for(var e=[],r=0,n=t.length;r<n;++r)a(t[r],e);return e.length<2&&e.push(e[0]),e}function l(t){for(var e=s(t);e.length<4;)e.push(e[0]);return e}function c(t){return t.map(l)}return function t(e){var r,n=e.type;switch(n){case\"GeometryCollection\":return{type:n,geometries:e.geometries.map(t)};case\"Point\":r=o(e.coordinates);break;case\"MultiPoint\":r=e.coordinates.map(o);break;case\"LineString\":r=s(e.arcs);break;case\"MultiLineString\":r=e.arcs.map(s);break;case\"Polygon\":r=c(e.arcs);break;case\"MultiPolygon\":r=e.arcs.map(c);break;default:return null}return{type:n,coordinates:r}}(e)}function o(t,e){var r={},n={},i={},a=[],o=-1;function s(t,e){for(var n in t){var i=t[n];delete e[i.start],delete i.start,delete i.end,i.forEach((function(t){r[t<0?~t:t]=1})),a.push(i)}}return e.forEach((function(r,n){var i,a=t.arcs[r<0?~r:r];a.length<3&&!a[1][0]&&!a[1][1]&&(i=e[++o],e[o]=r,e[n]=i)})),e.forEach((function(e){var r,a,o=function(e){var r,n=t.arcs[e<0?~e:e],i=n[0];t.transform?(r=[0,0],n.forEach((function(t){r[0]+=t[0],r[1]+=t[1]}))):r=n[n.length-1];return e<0?[r,i]:[i,r]}(e),s=o[0],l=o[1];if(r=i[s])if(delete i[r.end],r.push(e),r.end=l,a=n[l]){delete n[a.start];var c=a===r?r:r.concat(a);n[c.start=r.start]=i[c.end=a.end]=c}else n[r.start]=i[r.end]=r;else if(r=n[l])if(delete n[r.start],r.unshift(e),r.start=s,a=i[s]){delete i[a.end];var u=a===r?r:a.concat(r);n[u.start=a.start]=i[u.end=r.end]=u}else n[r.start]=i[r.end]=r;else n[(r=[e]).start=s]=i[r.end=l]=r})),s(i,n),s(n,i),e.forEach((function(t){r[t<0?~t:t]||a.push([t])})),a}function s(t,e,r){var n,i,a;if(arguments.length>1)n=l(t,e,r);else for(i=0,n=new Array(a=t.arcs.length);i<a;++i)n[i]=i;return{type:\"MultiLineString\",arcs:o(t,n)}}function l(t,e,r){var n,i=[],a=[];function o(t){var e=t<0?~t:t;(a[e]||(a[e]=[])).push({i:t,g:n})}function s(t){t.forEach(o)}function l(t){t.forEach(s)}return function t(e){switch(n=e,e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"LineString\":s(e.arcs);break;case\"MultiLineString\":case\"Polygon\":l(e.arcs);break;case\"MultiPolygon\":!function(t){t.forEach(l)}(e.arcs)}}(e),a.forEach(null==r?function(t){i.push(t[0].i)}:function(t){r(t[0].g,t[t.length-1].g)&&i.push(t[0].i)}),i}function c(t,e){var r={},n=[],i=[];function s(t){t.forEach((function(e){e.forEach((function(e){(r[e=e<0?~e:e]||(r[e]=[])).push(t)}))})),n.push(t)}function l(e){return function(t){for(var e,r=-1,n=t.length,i=t[n-1],a=0;++r<n;)e=i,i=t[r],a+=e[0]*i[1]-e[1]*i[0];return Math.abs(a)}(a(t,{type:\"Polygon\",arcs:[e]}).coordinates[0])}return e.forEach((function t(e){switch(e.type){case\"GeometryCollection\":e.geometries.forEach(t);break;case\"Polygon\":s(e.arcs);break;case\"MultiPolygon\":e.arcs.forEach(s)}})),n.forEach((function(t){if(!t._){var e=[],n=[t];for(t._=1,i.push(e);t=n.pop();)e.push(t),t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].forEach((function(t){t._||(t._=1,n.push(t))}))}))}))}})),n.forEach((function(t){delete t._})),{type:\"MultiPolygon\",arcs:i.map((function(e){var n,i=[];if(e.forEach((function(t){t.forEach((function(t){t.forEach((function(t){r[t<0?~t:t].length<2&&i.push(t)}))}))})),(n=(i=o(t,i)).length)>1)for(var a,s,c=1,u=l(i[0]);c<n;++c)(a=l(i[c]))>u&&(s=i[0],i[0]=i[c],i[c]=s,u=a);return i})).filter((function(t){return t.length>0}))}}function u(t,e){for(var r=0,n=t.length;r<n;){var i=r+n>>>1;t[i]<e?r=i+1:n=i}return r}function f(t){if(null==t)return e;var r,n,i=t.scale[0],a=t.scale[1],o=t.translate[0],s=t.translate[1];return function(t,e){e||(r=n=0);var l=2,c=t.length,u=new Array(c),f=Math.round((t[0]-o)/i),h=Math.round((t[1]-s)/a);for(u[0]=f-r,r=f,u[1]=h-n,n=h;l<c;)u[l]=t[l],++l;return u}}t.bbox=n,t.feature=function(t,e){return\"string\"==typeof e&&(e=t.objects[e]),\"GeometryCollection\"===e.type?{type:\"FeatureCollection\",features:e.geometries.map((function(e){return i(t,e)}))}:i(t,e)},t.merge=function(t){return a(t,c.apply(this,arguments))},t.mergeArcs=c,t.mesh=function(t){return a(t,s.apply(this,arguments))},t.meshArcs=s,t.neighbors=function(t){var e={},r=t.map((function(){return[]}));function n(t,r){t.forEach((function(t){t<0&&(t=~t);var n=e[t];n?n.push(r):e[t]=[r]}))}function i(t,e){t.forEach((function(t){n(t,e)}))}var a={LineString:n,MultiLineString:i,Polygon:i,MultiPolygon:function(t,e){t.forEach((function(t){i(t,e)}))}};for(var o in t.forEach((function t(e,r){\"GeometryCollection\"===e.type?e.geometries.forEach((function(e){t(e,r)})):e.type in a&&a[e.type](e.arcs,r)})),e)for(var s=e[o],l=s.length,c=0;c<l;++c)for(var f=c+1;f<l;++f){var h,p=s[c],d=s[f];(h=r[p])[o=u(h,d)]!==d&&h.splice(o,0,d),(h=r[d])[o=u(h,p)]!==p&&h.splice(o,0,p)}return r},t.quantize=function(t,e){if(t.transform)throw new Error(\"already quantized\");if(e&&e.scale)l=t.bbox;else{if(!((r=Math.floor(e))>=2))throw new Error(\"n must be \\u22652\");var r,i=(l=t.bbox||n(t))[0],a=l[1],o=l[2],s=l[3];e={scale:[o-i?(o-i)/(r-1):1,s-a?(s-a)/(r-1):1],translate:[i,a]}}var l,c,u=f(e),h=t.objects,p={};function d(t){return u(t)}function g(t){var e;switch(t.type){case\"GeometryCollection\":e={type:\"GeometryCollection\",geometries:t.geometries.map(g)};break;case\"Point\":e={type:\"Point\",coordinates:d(t.coordinates)};break;case\"MultiPoint\":e={type:\"MultiPoint\",coordinates:t.coordinates.map(d)};break;default:return t}return null!=t.id&&(e.id=t.id),null!=t.bbox&&(e.bbox=t.bbox),null!=t.properties&&(e.properties=t.properties),e}for(c in h)p[c]=g(h[c]);return{type:\"Topology\",bbox:l,transform:e,objects:p,arcs:t.arcs.map((function(t){var e,r=0,n=1,i=t.length,a=new Array(i);for(a[0]=u(t[0],0);++r<i;)((e=u(t[r],r))[0]||e[1])&&(a[n++]=e);return 1===n&&(a[n++]=[0,0]),a.length=n,a}))}},t.transform=r,t.untransform=f,Object.defineProperty(t,\"__esModule\",{value:!0})}))},{}],580:[function(t,e,r){\"use strict\";e.exports=function(t){if(t<0)return[];if(0===t)return[[0]];for(var e=0|Math.round(a(t+1)),r=[],o=0;o<e;++o){for(var s=n.unrank(t,o),l=[0],c=0,u=0;u<s.length;++u)c+=1<<s[u],l.push(c);i(s)<1&&(l[0]=c,l[t]=0),r.push(l)}return r};var n=t(\"permutation-rank\"),i=t(\"permutation-parity\"),a=t(\"gamma\")},{gamma:248,\"permutation-parity\":509,\"permutation-rank\":510}],581:[function(t,e,r){\"use strict\";e.exports=function(t){var e=(t=t||{}).center||[0,0,0],r=t.up||[0,1,0],n=t.right||f(r),i=t.radius||1,a=t.theta||0,u=t.phi||0;if(e=[].slice.call(e,0,3),r=[].slice.call(r,0,3),s(r,r),n=[].slice.call(n,0,3),s(n,n),\"eye\"in t){var p=t.eye,d=[p[0]-e[0],p[1]-e[1],p[2]-e[2]];o(n,d,r),c(n[0],n[1],n[2])<1e-6?n=f(r):s(n,n),i=c(d[0],d[1],d[2]);var g=l(r,d)/i,m=l(n,d)/i;u=Math.acos(g),a=Math.acos(m)}return i=Math.log(i),new h(t.zoomMin,t.zoomMax,e,r,n,i,a,u)};var n=t(\"filtered-vector\"),i=t(\"gl-mat4/invert\"),a=t(\"gl-mat4/rotate\"),o=t(\"gl-vec3/cross\"),s=t(\"gl-vec3/normalize\"),l=t(\"gl-vec3/dot\");function c(t,e,r){return Math.sqrt(Math.pow(t,2)+Math.pow(e,2)+Math.pow(r,2))}function u(t){return Math.min(1,Math.max(-1,t))}function f(t){var e=Math.abs(t[0]),r=Math.abs(t[1]),n=Math.abs(t[2]),i=[0,0,0];e>Math.max(r,n)?i[2]=1:r>Math.max(e,n)?i[0]=1:i[1]=1;for(var a=0,o=0,l=0;l<3;++l)a+=t[l]*t[l],o+=i[l]*t[l];for(l=0;l<3;++l)i[l]-=o/a*t[l];return s(i,i),i}function h(t,e,r,i,a,o,s,l){this.center=n(r),this.up=n(i),this.right=n(a),this.radius=n([o]),this.angle=n([s,l]),this.angle.bounds=[[-1/0,-Math.PI/2],[1/0,Math.PI/2]],this.setDistanceLimits(t,e),this.computedCenter=this.center.curve(0),this.computedUp=this.up.curve(0),this.computedRight=this.right.curve(0),this.computedRadius=this.radius.curve(0),this.computedAngle=this.angle.curve(0),this.computedToward=[0,0,0],this.computedEye=[0,0,0],this.computedMatrix=new Array(16);for(var c=0;c<16;++c)this.computedMatrix[c]=.5;this.recalcMatrix(0)}var p=h.prototype;p.setDistanceLimits=function(t,e){t=t>0?Math.log(t):-1/0,e=e>0?Math.log(e):1/0,e=Math.max(e,t),this.radius.bounds[0][0]=t,this.radius.bounds[1][0]=e},p.getDistanceLimits=function(t){var e=this.radius.bounds[0];return t?(t[0]=Math.exp(e[0][0]),t[1]=Math.exp(e[1][0]),t):[Math.exp(e[0][0]),Math.exp(e[1][0])]},p.recalcMatrix=function(t){this.center.curve(t),this.up.curve(t),this.right.curve(t),this.radius.curve(t),this.angle.curve(t);for(var e=this.computedUp,r=this.computedRight,n=0,i=0,a=0;a<3;++a)i+=e[a]*r[a],n+=e[a]*e[a];var l=Math.sqrt(n),u=0;for(a=0;a<3;++a)r[a]-=e[a]*i/n,u+=r[a]*r[a],e[a]/=l;var f=Math.sqrt(u);for(a=0;a<3;++a)r[a]/=f;var h=this.computedToward;o(h,e,r),s(h,h);var p=Math.exp(this.computedRadius[0]),d=this.computedAngle[0],g=this.computedAngle[1],m=Math.cos(d),v=Math.sin(d),y=Math.cos(g),x=Math.sin(g),b=this.computedCenter,_=m*y,w=v*y,T=x,k=-m*x,M=-v*x,A=y,S=this.computedEye,E=this.computedMatrix;for(a=0;a<3;++a){var C=_*r[a]+w*h[a]+T*e[a];E[4*a+1]=k*r[a]+M*h[a]+A*e[a],E[4*a+2]=C,E[4*a+3]=0}var L=E[1],I=E[5],P=E[9],z=E[2],O=E[6],D=E[10],R=I*D-P*O,F=P*z-L*D,B=L*O-I*z,N=c(R,F,B);R/=N,F/=N,B/=N,E[0]=R,E[4]=F,E[8]=B;for(a=0;a<3;++a)S[a]=b[a]+E[2+4*a]*p;for(a=0;a<3;++a){u=0;for(var j=0;j<3;++j)u+=E[a+4*j]*S[j];E[12+a]=-u}E[15]=1},p.getMatrix=function(t,e){this.recalcMatrix(t);var r=this.computedMatrix;if(e){for(var n=0;n<16;++n)e[n]=r[n];return e}return r};var d=[0,0,0];p.rotate=function(t,e,r,n){if(this.angle.move(t,e,r),n){this.recalcMatrix(t);var i=this.computedMatrix;d[0]=i[2],d[1]=i[6],d[2]=i[10];for(var o=this.computedUp,s=this.computedRight,l=this.computedToward,c=0;c<3;++c)i[4*c]=o[c],i[4*c+1]=s[c],i[4*c+2]=l[c];a(i,i,n,d);for(c=0;c<3;++c)o[c]=i[4*c],s[c]=i[4*c+1];this.up.set(t,o[0],o[1],o[2]),this.right.set(t,s[0],s[1],s[2])}},p.pan=function(t,e,r,n){e=e||0,r=r||0,n=n||0,this.recalcMatrix(t);var i=this.computedMatrix,a=(Math.exp(this.computedRadius[0]),i[1]),o=i[5],s=i[9],l=c(a,o,s);a/=l,o/=l,s/=l;var u=i[0],f=i[4],h=i[8],p=u*a+f*o+h*s,d=c(u-=a*p,f-=o*p,h-=s*p),g=(u/=d)*e+a*r,m=(f/=d)*e+o*r,v=(h/=d)*e+s*r;this.center.move(t,g,m,v);var y=Math.exp(this.computedRadius[0]);y=Math.max(1e-4,y+n),this.radius.set(t,Math.log(y))},p.translate=function(t,e,r,n){this.center.move(t,e||0,r||0,n||0)},p.setMatrix=function(t,e,r,n){var a=1;\"number\"==typeof r&&(a=0|r),(a<0||a>3)&&(a=1);var o=(a+2)%3;e||(this.recalcMatrix(t),e=this.computedMatrix);var s=e[a],l=e[a+4],f=e[a+8];if(n){var h=Math.abs(s),p=Math.abs(l),d=Math.abs(f),g=Math.max(h,p,d);h===g?(s=s<0?-1:1,l=f=0):d===g?(f=f<0?-1:1,s=l=0):(l=l<0?-1:1,s=f=0)}else{var m=c(s,l,f);s/=m,l/=m,f/=m}var v,y,x=e[o],b=e[o+4],_=e[o+8],w=x*s+b*l+_*f,T=c(x-=s*w,b-=l*w,_-=f*w),k=l*(_/=T)-f*(b/=T),M=f*(x/=T)-s*_,A=s*b-l*x,S=c(k,M,A);if(k/=S,M/=S,A/=S,this.center.jump(t,H,G,Y),this.radius.idle(t),this.up.jump(t,s,l,f),this.right.jump(t,x,b,_),2===a){var E=e[1],C=e[5],L=e[9],I=E*x+C*b+L*_,P=E*k+C*M+L*A;v=R<0?-Math.PI/2:Math.PI/2,y=Math.atan2(P,I)}else{var z=e[2],O=e[6],D=e[10],R=z*s+O*l+D*f,F=z*x+O*b+D*_,B=z*k+O*M+D*A;v=Math.asin(u(R)),y=Math.atan2(B,F)}this.angle.jump(t,y,v),this.recalcMatrix(t);var N=e[2],j=e[6],U=e[10],V=this.computedMatrix;i(V,e);var q=V[15],H=V[12]/q,G=V[13]/q,Y=V[14]/q,W=Math.exp(this.computedRadius[0]);this.center.jump(t,H-N*W,G-j*W,Y-U*W)},p.lastT=function(){return Math.max(this.center.lastT(),this.up.lastT(),this.right.lastT(),this.radius.lastT(),this.angle.lastT())},p.idle=function(t){this.center.idle(t),this.up.idle(t),this.right.idle(t),this.radius.idle(t),this.angle.idle(t)},p.flush=function(t){this.center.flush(t),this.up.flush(t),this.right.flush(t),this.radius.flush(t),this.angle.flush(t)},p.setDistance=function(t,e){e>0&&this.radius.set(t,Math.log(e))},p.lookAt=function(t,e,r,n){this.recalcMatrix(t),e=e||this.computedEye,r=r||this.computedCenter;var i=(n=n||this.computedUp)[0],a=n[1],o=n[2],s=c(i,a,o);if(!(s<1e-6)){i/=s,a/=s,o/=s;var l=e[0]-r[0],f=e[1]-r[1],h=e[2]-r[2],p=c(l,f,h);if(!(p<1e-6)){l/=p,f/=p,h/=p;var d=this.computedRight,g=d[0],m=d[1],v=d[2],y=i*g+a*m+o*v,x=c(g-=y*i,m-=y*a,v-=y*o);if(!(x<.01&&(x=c(g=a*h-o*f,m=o*l-i*h,v=i*f-a*l))<1e-6)){g/=x,m/=x,v/=x,this.up.set(t,i,a,o),this.right.set(t,g,m,v),this.center.set(t,r[0],r[1],r[2]),this.radius.set(t,Math.log(p));var b=a*v-o*m,_=o*g-i*v,w=i*m-a*g,T=c(b,_,w),k=i*l+a*f+o*h,M=g*l+m*f+v*h,A=(b/=T)*l+(_/=T)*f+(w/=T)*h,S=Math.asin(u(k)),E=Math.atan2(A,M),C=this.angle._state,L=C[C.length-1],I=C[C.length-2];L%=2*Math.PI;var P=Math.abs(L+2*Math.PI-E),z=Math.abs(L-E),O=Math.abs(L-2*Math.PI-E);P<z&&(L+=2*Math.PI),O<z&&(L-=2*Math.PI),this.angle.jump(this.angle.lastT(),L,I),this.angle.set(t,E,S)}}}}},{\"filtered-vector\":242,\"gl-mat4/invert\":293,\"gl-mat4/rotate\":299,\"gl-vec3/cross\":365,\"gl-vec3/dot\":370,\"gl-vec3/normalize\":387}],582:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var i=t*e,a=n*t,o=a-(a-t),s=t-o,l=n*e,c=l-(l-e),u=e-c,f=s*u-(i-o*c-s*c-o*u);if(r)return r[0]=f,r[1]=i,r;return[f,i]};var n=+(Math.pow(2,27)+1)},{}],583:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){var n=t+e,i=n-t,a=e-i,o=t-(n-i);if(r)return r[0]=o+a,r[1]=n,r;return[o+a,n]}},{}],584:[function(t,e,r){\"use strict\";var n=t(\"../prototype/is\");e.exports=function(t){if(\"function\"!=typeof t)return!1;if(!hasOwnProperty.call(t,\"length\"))return!1;try{if(\"number\"!=typeof t.length)return!1;if(\"function\"!=typeof t.call)return!1;if(\"function\"!=typeof t.apply)return!1}catch(t){return!1}return!n(t)}},{\"../prototype/is\":591}],585:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=t(\"../string/coerce\"),o=t(\"./to-short-string\"),s=function(t,e){return t.replace(\"%v\",o(e))};e.exports=function(t,e,r){if(!i(r))throw new TypeError(s(e,t));if(!n(t)){if(\"default\"in r)return r.default;if(r.isOptional)return null}var o=a(r.errorMessage);throw n(o)||(o=e),new TypeError(s(o,t))}},{\"../object/is\":588,\"../string/coerce\":592,\"../value/is\":594,\"./to-short-string\":587}],586:[function(t,e,r){\"use strict\";e.exports=function(t){try{return t.toString()}catch(e){try{return String(t)}catch(t){return null}}}},{}],587:[function(t,e,r){\"use strict\";var n=t(\"./safe-to-string\"),i=/[\\n\\r\\u2028\\u2029]/g;e.exports=function(t){var e=n(t);return null===e?\"<Non-coercible to string value>\":(e.length>100&&(e=e.slice(0,99)+\"\\u2026\"),e=e.replace(i,(function(t){switch(t){case\"\\n\":return\"\\\\n\";case\"\\r\":return\"\\\\r\";case\"\\u2028\":return\"\\\\u2028\";case\"\\u2029\":return\"\\\\u2029\";default:throw new Error(\"Unexpected character\")}})))}},{\"./safe-to-string\":586}],588:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i={object:!0,function:!0,undefined:!0};e.exports=function(t){return!!n(t)&&hasOwnProperty.call(i,typeof t)}},{\"../value/is\":594}],589:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"%v is not a plain function\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":590}],590:[function(t,e,r){\"use strict\";var n=t(\"../function/is\"),i=/^\\s*class[\\s{/}]/,a=Function.prototype.toString;e.exports=function(t){return!!n(t)&&!i.test(a.call(t))}},{\"../function/is\":584}],591:[function(t,e,r){\"use strict\";var n=t(\"../object/is\");e.exports=function(t){if(!n(t))return!1;try{return!!t.constructor&&t.constructor.prototype===t}catch(t){return!1}}},{\"../object/is\":588}],592:[function(t,e,r){\"use strict\";var n=t(\"../value/is\"),i=t(\"../object/is\"),a=Object.prototype.toString;e.exports=function(t){if(!n(t))return null;if(i(t)){var e=t.toString;if(\"function\"!=typeof e)return null;if(e===a)return null}try{return\"\"+t}catch(t){return null}}},{\"../object/is\":588,\"../value/is\":594}],593:[function(t,e,r){\"use strict\";var n=t(\"../lib/resolve-exception\"),i=t(\"./is\");e.exports=function(t){return i(t)?t:n(t,\"Cannot use %v\",arguments[1])}},{\"../lib/resolve-exception\":585,\"./is\":594}],594:[function(t,e,r){\"use strict\";e.exports=function(t){return null!=t}},{}],595:[function(t,e,r){(function(e){(function(){\"use strict\";var n=t(\"bit-twiddle\"),i=t(\"dup\"),a=t(\"buffer\").Buffer;e.__TYPEDARRAY_POOL||(e.__TYPEDARRAY_POOL={UINT8:i([32,0]),UINT16:i([32,0]),UINT32:i([32,0]),BIGUINT64:i([32,0]),INT8:i([32,0]),INT16:i([32,0]),INT32:i([32,0]),BIGINT64:i([32,0]),FLOAT:i([32,0]),DOUBLE:i([32,0]),DATA:i([32,0]),UINT8C:i([32,0]),BUFFER:i([32,0])});var o=\"undefined\"!=typeof Uint8ClampedArray,s=\"undefined\"!=typeof BigUint64Array,l=\"undefined\"!=typeof BigInt64Array,c=e.__TYPEDARRAY_POOL;c.UINT8C||(c.UINT8C=i([32,0])),c.BIGUINT64||(c.BIGUINT64=i([32,0])),c.BIGINT64||(c.BIGINT64=i([32,0])),c.BUFFER||(c.BUFFER=i([32,0]));var u=c.DATA,f=c.BUFFER;function h(t){if(t){var e=t.length||t.byteLength,r=n.log2(e);u[r].push(t)}}function p(t){t=n.nextPow2(t);var e=n.log2(t),r=u[e];return r.length>0?r.pop():new ArrayBuffer(t)}function d(t){return new Uint8Array(p(t),0,t)}function g(t){return new Uint16Array(p(2*t),0,t)}function m(t){return new Uint32Array(p(4*t),0,t)}function v(t){return new Int8Array(p(t),0,t)}function y(t){return new Int16Array(p(2*t),0,t)}function x(t){return new Int32Array(p(4*t),0,t)}function b(t){return new Float32Array(p(4*t),0,t)}function _(t){return new Float64Array(p(8*t),0,t)}function w(t){return o?new Uint8ClampedArray(p(t),0,t):d(t)}function T(t){return s?new BigUint64Array(p(8*t),0,t):null}function k(t){return l?new BigInt64Array(p(8*t),0,t):null}function M(t){return new DataView(p(t),0,t)}function A(t){t=n.nextPow2(t);var e=n.log2(t),r=f[e];return r.length>0?r.pop():new a(t)}r.free=function(t){if(a.isBuffer(t))f[n.log2(t.length)].push(t);else{if(\"[object ArrayBuffer]\"!==Object.prototype.toString.call(t)&&(t=t.buffer),!t)return;var e=t.length||t.byteLength,r=0|n.log2(e);u[r].push(t)}},r.freeUint8=r.freeUint16=r.freeUint32=r.freeBigUint64=r.freeInt8=r.freeInt16=r.freeInt32=r.freeBigInt64=r.freeFloat32=r.freeFloat=r.freeFloat64=r.freeDouble=r.freeUint8Clamped=r.freeDataView=function(t){h(t.buffer)},r.freeArrayBuffer=h,r.freeBuffer=function(t){f[n.log2(t.length)].push(t)},r.malloc=function(t,e){if(void 0===e||\"arraybuffer\"===e)return p(t);switch(e){case\"uint8\":return d(t);case\"uint16\":return g(t);case\"uint32\":return m(t);case\"int8\":return v(t);case\"int16\":return y(t);case\"int32\":return x(t);case\"float\":case\"float32\":return b(t);case\"double\":case\"float64\":return _(t);case\"uint8_clamped\":return w(t);case\"bigint64\":return k(t);case\"biguint64\":return T(t);case\"buffer\":return A(t);case\"data\":case\"dataview\":return M(t);default:return null}return null},r.mallocArrayBuffer=p,r.mallocUint8=d,r.mallocUint16=g,r.mallocUint32=m,r.mallocInt8=v,r.mallocInt16=y,r.mallocInt32=x,r.mallocFloat32=r.mallocFloat=b,r.mallocFloat64=r.mallocDouble=_,r.mallocUint8Clamped=w,r.mallocBigUint64=T,r.mallocBigInt64=k,r.mallocDataView=M,r.mallocBuffer=A,r.clearCache=function(){for(var t=0;t<32;++t)c.UINT8[t].length=0,c.UINT16[t].length=0,c.UINT32[t].length=0,c.INT8[t].length=0,c.INT16[t].length=0,c.INT32[t].length=0,c.FLOAT[t].length=0,c.DOUBLE[t].length=0,c.BIGUINT64[t].length=0,c.BIGINT64[t].length=0,c.UINT8C[t].length=0,u[t].length=0,f[t].length=0}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"bit-twiddle\":97,buffer:111,dup:176}],596:[function(t,e,r){\"use strict\";function n(t){this.roots=new Array(t),this.ranks=new Array(t);for(var e=0;e<t;++e)this.roots[e]=e,this.ranks[e]=0}e.exports=n;var i=n.prototype;Object.defineProperty(i,\"length\",{get:function(){return this.roots.length}}),i.makeSet=function(){var t=this.roots.length;return this.roots.push(t),this.ranks.push(0),t},i.find=function(t){for(var e=t,r=this.roots;r[t]!==t;)t=r[t];for(;r[e]!==t;){var n=r[e];r[e]=t,e=n}return t},i.link=function(t,e){var r=this.find(t),n=this.find(e);if(r!==n){var i=this.ranks,a=this.roots,o=i[r],s=i[n];o<s?a[r]=n:s<o?a[n]=r:(a[n]=r,++i[r])}}},{}],597:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return 0===t.length?t:e?(r||t.sort(e),function(t,e){for(var r=1,n=t.length,i=t[0],a=t[0],o=1;o<n;++o)if(a=i,e(i=t[o],a)){if(o===r){r++;continue}t[r++]=i}return t.length=r,t}(t,e)):(r||t.sort(),function(t){for(var e=1,r=t.length,n=t[0],i=t[0],a=1;a<r;++a,i=n)if(i=n,(n=t[a])!==i){if(a===e){e++;continue}t[e++]=n}return t.length=e,t}(t))}},{}],598:[function(t,e,r){var n=/[\\'\\\"]/;e.exports=function(t){return t?(n.test(t.charAt(0))&&(t=t.substr(1)),n.test(t.charAt(t.length-1))&&(t=t.substr(0,t.length-1)),t):\"\"}},{}],599:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){Array.isArray(r)||(r=[].slice.call(arguments,2));for(var n=0,i=r.length;n<i;n++){var a=r[n];for(var o in a)if((void 0===e[o]||Array.isArray(e[o])||t[o]!==e[o])&&o in e){var s;if(!0===a[o])s=e[o];else{if(!1===a[o])continue;if(\"function\"==typeof a[o]&&void 0===(s=a[o](e[o],t,e)))continue}t[o]=s}}return t}},{}],600:[function(t,e,r){\"use strict\";e.exports=function(t,e){\"object\"==typeof e&&null!==e||(e={});return n(t,e.canvas||i,e.context||a,e)};var n=t(\"./lib/vtext\"),i=null,a=null;\"undefined\"!=typeof document&&((i=document.createElement(\"canvas\")).width=8192,i.height=1024,a=i.getContext(\"2d\"))},{\"./lib/vtext\":601}],601:[function(t,e,r){e.exports=function(t,e,r,n){var a=64,o=1.25,s={breaklines:!1,bolds:!1,italics:!1,subscripts:!1,superscripts:!1};n&&(n.size&&n.size>0&&(a=n.size),n.lineSpacing&&n.lineSpacing>0&&(o=n.lineSpacing),n.styletags&&n.styletags.breaklines&&(s.breaklines=!!n.styletags.breaklines),n.styletags&&n.styletags.bolds&&(s.bolds=!!n.styletags.bolds),n.styletags&&n.styletags.italics&&(s.italics=!!n.styletags.italics),n.styletags&&n.styletags.subscripts&&(s.subscripts=!!n.styletags.subscripts),n.styletags&&n.styletags.superscripts&&(s.superscripts=!!n.styletags.superscripts));return r.font=[n.fontStyle,n.fontVariant,n.fontWeight,a+\"px\",n.font].filter((function(t){return t})).join(\" \"),r.textAlign=\"start\",r.textBaseline=\"alphabetic\",r.direction=\"ltr\",h(function(t,e,r,n,a,o){r=r.replace(/\\n/g,\"\"),r=!0===o.breaklines?r.replace(/\\<br\\>/g,\"\\n\"):r.replace(/\\<br\\>/g,\" \");var s=\"\",l=[];for(p=0;p<r.length;++p)l[p]=s;!0===o.bolds&&(l=c(\"b\",\"b|\",r,l));!0===o.italics&&(l=c(\"i\",\"i|\",r,l));!0===o.superscripts&&(l=c(\"sup\",\"+1\",r,l));!0===o.subscripts&&(l=c(\"sub\",\"-1\",r,l));var u=[],f=\"\";for(p=0;p<r.length;++p)null!==l[p]&&(f+=r[p],u.push(l[p]));var h,p,d,g,m,v=f.split(\"\\n\"),y=v.length,x=Math.round(a*n),b=n,_=2*n,w=0,T=y*x+_;t.height<T&&(t.height=T);e.fillStyle=\"#000\",e.fillRect(0,0,t.width,t.height),e.fillStyle=\"#fff\";var k=0,M=\"\";function A(){if(\"\"!==M){var t=e.measureText(M).width;e.fillText(M,b+d,_+g),d+=t}}function S(){return Math.round(m)+\"px \"}function E(t,r){var n=\"\"+e.font;if(!0===o.subscripts){var i=t.indexOf(\"-\"),a=r.indexOf(\"-\"),s=i>-1?parseInt(t[1+i]):0,l=a>-1?parseInt(r[1+a]):0;s!==l&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,l-s),n=n.replace(\"?px \",S())),g+=.25*x*(l-s)}if(!0===o.superscripts){var c=t.indexOf(\"+\"),u=r.indexOf(\"+\"),f=c>-1?parseInt(t[1+c]):0,h=u>-1?parseInt(r[1+u]):0;f!==h&&(n=n.replace(S(),\"?px \"),m*=Math.pow(.75,h-f),n=n.replace(\"?px \",S())),g-=.25*x*(h-f)}if(!0===o.bolds){var p=t.indexOf(\"b|\")>-1,d=r.indexOf(\"b|\")>-1;!p&&d&&(n=v?n.replace(\"italic \",\"italic bold \"):\"bold \"+n),p&&!d&&(n=n.replace(\"bold \",\"\"))}if(!0===o.italics){var v=t.indexOf(\"i|\")>-1,y=r.indexOf(\"i|\")>-1;!v&&y&&(n=\"italic \"+n),v&&!y&&(n=n.replace(\"italic \",\"\"))}e.font=n}for(h=0;h<y;++h){var C=v[h]+\"\\n\";for(d=0,g=h*x,m=n,M=\"\",p=0;p<C.length;++p){var L=p+k<u.length?u[p+k]:u[u.length-1];s===L?M+=C[p]:(A(),M=C[p],void 0!==L&&(E(s,L),s=L))}A(),k+=C.length;var I=0|Math.round(d+2*b);w<I&&(w=I)}var P=w,z=_+x*y;return i(e.getImageData(0,0,P,z).data,[z,P,4]).pick(-1,-1,0).transpose(1,0)}(e,r,t,a,o,s),n,a)},e.exports.processPixels=h;var n=t(\"surface-nets\"),i=t(\"ndarray\"),a=t(\"simplify-planar-graph\"),o=t(\"clean-pslg\"),s=t(\"cdt2d\"),l=t(\"planar-graph-to-polyline\");function c(t,e,r,n){for(var i=\"<\"+t+\">\",a=\"</\"+t+\">\",o=i.length,s=a.length,l=\"+\"===e[0]||\"-\"===e[0],c=0,u=-s;c>-1&&-1!==(c=r.indexOf(i,c))&&-1!==(u=r.indexOf(a,c+o))&&!(u<=c);){for(var f=c;f<u+s;++f)if(f<c+o||f>=u)n[f]=null,r=r.substr(0,f)+\" \"+r.substr(f+1);else if(null!==n[f]){var h=n[f].indexOf(e[0]);-1===h?n[f]+=e:l&&(n[f]=n[f].substr(0,h+1)+(1+parseInt(n[f][h+1]))+n[f].substr(h+2))}var p=c+o,d=r.substr(p,u-p).indexOf(i);c=-1!==d?d:u+s}return n}function u(t,e){var r=n(t,128);return e?a(r.cells,r.positions,.25):{edges:r.cells,positions:r.positions}}function f(t,e,r,n){var i=u(t,n),a=function(t,e,r){for(var n=e.textAlign||\"start\",i=e.textBaseline||\"alphabetic\",a=[1<<30,1<<30],o=[0,0],s=t.length,l=0;l<s;++l)for(var c=t[l],u=0;u<2;++u)a[u]=0|Math.min(a[u],c[u]),o[u]=0|Math.max(o[u],c[u]);var f=0;switch(n){case\"center\":f=-.5*(a[0]+o[0]);break;case\"right\":case\"end\":f=-o[0];break;case\"left\":case\"start\":f=-a[0];break;default:throw new Error(\"vectorize-text: Unrecognized textAlign: '\"+n+\"'\")}var h=0;switch(i){case\"hanging\":case\"top\":h=-a[1];break;case\"middle\":h=-.5*(a[1]+o[1]);break;case\"alphabetic\":case\"ideographic\":h=-3*r;break;case\"bottom\":h=-o[1];break;default:throw new Error(\"vectorize-text: Unrecoginized textBaseline: '\"+i+\"'\")}var p=1/r;return\"lineHeight\"in e?p*=+e.lineHeight:\"width\"in e?p=e.width/(o[0]-a[0]):\"height\"in e&&(p=e.height/(o[1]-a[1])),t.map((function(t){return[p*(t[0]+f),p*(t[1]+h)]}))}(i.positions,e,r),c=i.edges,f=\"ccw\"===e.orientation;if(o(a,c),e.polygons||e.polygon||e.polyline){for(var h=l(c,a),p=new Array(h.length),d=0;d<h.length;++d){for(var g=h[d],m=new Array(g.length),v=0;v<g.length;++v){for(var y=g[v],x=new Array(y.length),b=0;b<y.length;++b)x[b]=a[y[b]].slice();f&&x.reverse(),m[v]=x}p[d]=m}return p}return e.triangles||e.triangulate||e.triangle?{cells:s(a,c,{delaunay:!1,exterior:!1,interior:!0}),positions:a}:{edges:c,positions:a}}function h(t,e,r){try{return f(t,e,r,!0)}catch(t){}try{return f(t,e,r,!1)}catch(t){}return e.polygons||e.polyline||e.polygon?[]:e.triangles||e.triangulate||e.triangle?{cells:[],positions:[]}:{edges:[],positions:[]}}},{cdt2d:112,\"clean-pslg\":121,ndarray:495,\"planar-graph-to-polyline\":514,\"simplify-planar-graph\":562,\"surface-nets\":570}],602:[function(t,e,r){!function(){\"use strict\";if(\"undefined\"==typeof ses||!ses.ok||ses.ok()){\"undefined\"!=typeof ses&&(ses.weakMapPermitHostObjects=g);var t=!1;if(\"function\"==typeof WeakMap){var r=WeakMap;if(\"undefined\"!=typeof navigator&&/Firefox/.test(navigator.userAgent));else{var n=new r,i=Object.freeze({});if(n.set(i,1),1===n.get(i))return void(e.exports=WeakMap);t=!0}}Object.prototype.hasOwnProperty;var a=Object.getOwnPropertyNames,o=Object.defineProperty,s=Object.isExtensible,l=\"weakmap:ident:\"+Math.random()+\"___\";if(\"undefined\"!=typeof crypto&&\"function\"==typeof crypto.getRandomValues&&\"function\"==typeof ArrayBuffer&&\"function\"==typeof Uint8Array){var c=new ArrayBuffer(25),u=new Uint8Array(c);crypto.getRandomValues(u),l=\"weakmap:rand:\"+Array.prototype.map.call(u,(function(t){return(t%36).toString(36)})).join(\"\")+\"___\"}if(o(Object,\"getOwnPropertyNames\",{value:function(t){return a(t).filter(m)}}),\"getPropertyNames\"in Object){var f=Object.getPropertyNames;o(Object,\"getPropertyNames\",{value:function(t){return f(t).filter(m)}})}!function(){var t=Object.freeze;o(Object,\"freeze\",{value:function(e){return v(e),t(e)}});var e=Object.seal;o(Object,\"seal\",{value:function(t){return v(t),e(t)}});var r=Object.preventExtensions;o(Object,\"preventExtensions\",{value:function(t){return v(t),r(t)}})}();var h=!1,p=0,d=function(){this instanceof d||x();var t=[],e=[],r=p++;return Object.create(d.prototype,{get___:{value:y((function(n,i){var a,o=v(n);return o?r in o?o[r]:i:(a=t.indexOf(n))>=0?e[a]:i}))},has___:{value:y((function(e){var n=v(e);return n?r in n:t.indexOf(e)>=0}))},set___:{value:y((function(n,i){var a,o=v(n);return o?o[r]=i:(a=t.indexOf(n))>=0?e[a]=i:(a=t.length,e[a]=i,t[a]=n),this}))},delete___:{value:y((function(n){var i,a,o=v(n);return o?r in o&&delete o[r]:!((i=t.indexOf(n))<0)&&(a=t.length-1,t[i]=void 0,e[i]=e[a],t[i]=t[a],t.length=a,e.length=a,!0)}))}})};d.prototype=Object.create(Object.prototype,{get:{value:function(t,e){return this.get___(t,e)},writable:!0,configurable:!0},has:{value:function(t){return this.has___(t)},writable:!0,configurable:!0},set:{value:function(t,e){return this.set___(t,e)},writable:!0,configurable:!0},delete:{value:function(t){return this.delete___(t)},writable:!0,configurable:!0}}),\"function\"==typeof r?function(){function n(){this instanceof d||x();var e,n=new r,i=void 0,a=!1;return e=t?function(t,e){return n.set(t,e),n.has(t)||(i||(i=new d),i.set(t,e)),this}:function(t,e){if(a)try{n.set(t,e)}catch(r){i||(i=new d),i.set___(t,e)}else n.set(t,e);return this},Object.create(d.prototype,{get___:{value:y((function(t,e){return i?n.has(t)?n.get(t):i.get___(t,e):n.get(t,e)}))},has___:{value:y((function(t){return n.has(t)||!!i&&i.has___(t)}))},set___:{value:y(e)},delete___:{value:y((function(t){var e=!!n.delete(t);return i&&i.delete___(t)||e}))},permitHostObjects___:{value:y((function(t){if(t!==g)throw new Error(\"bogus call to permitHostObjects___\");a=!0}))}})}t&&\"undefined\"!=typeof Proxy&&(Proxy=void 0),n.prototype=d.prototype,e.exports=n,Object.defineProperty(WeakMap.prototype,\"constructor\",{value:WeakMap,enumerable:!1,configurable:!0,writable:!0})}():(\"undefined\"!=typeof Proxy&&(Proxy=void 0),e.exports=d)}function g(t){t.permitHostObjects___&&t.permitHostObjects___(g)}function m(t){return!(\"weakmap:\"==t.substr(0,\"weakmap:\".length)&&\"___\"===t.substr(t.length-3))}function v(t){if(t!==Object(t))throw new TypeError(\"Not an object: \"+t);var e=t[l];if(e&&e.key===t)return e;if(s(t)){e={key:t};try{return o(t,l,{value:e,writable:!1,enumerable:!1,configurable:!1}),e}catch(t){return}}}function y(t){return t.prototype=null,Object.freeze(t)}function x(){h||\"undefined\"==typeof console||(h=!0,console.warn(\"WeakMap should be invoked as new WeakMap(), not WeakMap(). This will be an error in the future.\"))}}()},{}],603:[function(t,e,r){var n=t(\"./hidden-store.js\");e.exports=function(){var t={};return function(e){if((\"object\"!=typeof e||null===e)&&\"function\"!=typeof e)throw new Error(\"Weakmap-shim: Key must be object\");var r=e.valueOf(t);return r&&r.identity===t?r:n(e,t)}}},{\"./hidden-store.js\":604}],604:[function(t,e,r){e.exports=function(t,e){var r={identity:e},n=t.valueOf;return Object.defineProperty(t,\"valueOf\",{value:function(t){return t!==e?n.apply(this,arguments):r},writable:!0}),r}},{}],605:[function(t,e,r){var n=t(\"./create-store.js\");e.exports=function(){var t=n();return{get:function(e,r){var n=t(e);return n.hasOwnProperty(\"value\")?n.value:r},set:function(e,r){return t(e).value=r,this},has:function(e){return\"value\"in t(e)},delete:function(e){return delete t(e).value}}}},{\"./create-store.js\":603}],606:[function(t,e,r){var n=t(\"get-canvas-context\");e.exports=function(t){return n(\"webgl\",t)}},{\"get-canvas-context\":249}],607:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Chinese\",jdEpoch:1721425.5,hasYearZero:!1,minMonth:0,firstMonth:0,minDay:1,regionalOptions:{\"\":{name:\"Chinese\",epochs:[\"BEC\",\"EC\"],monthNumbers:function(t,e){if(\"string\"==typeof t){var r=t.match(l);return r?r[0]:\"\"}var n=this._validateYear(t),i=t.month(),a=\"\"+this.toChineseMonth(n,i);return e&&a.length<2&&(a=\"0\"+a),this.isIntercalaryMonth(n,i)&&(a+=\"i\"),a},monthNames:function(t){if(\"string\"==typeof t){var e=t.match(c);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\\u6708\",\"\\u4e8c\\u6708\",\"\\u4e09\\u6708\",\"\\u56db\\u6708\",\"\\u4e94\\u6708\",\"\\u516d\\u6708\",\"\\u4e03\\u6708\",\"\\u516b\\u6708\",\"\\u4e5d\\u6708\",\"\\u5341\\u6708\",\"\\u5341\\u4e00\\u6708\",\"\\u5341\\u4e8c\\u6708\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},monthNamesShort:function(t){if(\"string\"==typeof t){var e=t.match(u);return e?e[0]:\"\"}var r=this._validateYear(t),n=t.month(),i=[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"][this.toChineseMonth(r,n)-1];return this.isIntercalaryMonth(r,n)&&(i=\"\\u95f0\"+i),i},parseMonth:function(t,e){t=this._validateYear(t);var r,n=parseInt(e);if(isNaN(n))\"\\u95f0\"===e[0]&&(r=!0,e=e.substring(1)),\"\\u6708\"===e[e.length-1]&&(e=e.substring(0,e.length-1)),n=1+[\"\\u4e00\",\"\\u4e8c\",\"\\u4e09\",\"\\u56db\",\"\\u4e94\",\"\\u516d\",\"\\u4e03\",\"\\u516b\",\"\\u4e5d\",\"\\u5341\",\"\\u5341\\u4e00\",\"\\u5341\\u4e8c\"].indexOf(e);else{var i=e[e.length-1];r=\"i\"===i||\"I\"===i}return this.toMonthIndex(t,n,r)},dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},_validateYear:function(t,e){if(t.year&&(t=t.year()),\"number\"!=typeof t||t<1888||t>2111)throw e.replace(/\\{0\\}/,this.local.name);return t},toMonthIndex:function(t,e,r){var i=this.intercalaryMonth(t);if(r&&e!==i||e<1||e>12)throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return i?!r&&e<=i?e-1:e:e-1},toChineseMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);if(e<0||e>(r?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r?e<r?e+1:e:e+1},intercalaryMonth:function(t){return t=this._validateYear(t),f[t-f[0]]>>13},isIntercalaryMonth:function(t,e){t.year&&(e=(t=t.year()).month());var r=this.intercalaryMonth(t);return!!r&&r===e},leapYear:function(t){return 0!==this.intercalaryMonth(t)},weekOfYear:function(t,e,r){var i,o=this._validateYear(t,n.local.invalidyear),s=h[o-h[0]],l=s>>9&4095,c=s>>5&15,u=31&s;(i=a.newDate(l,c,u)).add(4-(i.dayOfWeek()||7),\"d\");var f=this.toJD(t,e,r)-i.toJD();return 1+Math.floor(f/7)},monthsInYear:function(t){return this.leapYear(t)?13:12},daysInMonth:function(t,e){t.year&&(e=t.month(),t=t.year()),t=this._validateYear(t);var r=f[t-f[0]];if(e>(r>>13?12:11))throw n.local.invalidMonth.replace(/\\{0\\}/,this.local.name);return r&1<<12-e?30:29},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,s,r,n.local.invalidDate);t=this._validateYear(i.year()),e=i.month(),r=i.day();var o=this.isIntercalaryMonth(t,e),s=this.toChineseMonth(t,e),l=function(t,e,r,n,i){var a,o,s;if(\"object\"==typeof t)o=t,a=e||{};else{var l;if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Lunar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Lunar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=30))throw new Error(\"Lunar day outside range 1 - 30\");\"object\"==typeof n?(l=!1,a=n):(l=!!n,a=i||{}),o={year:t,month:e,day:r,isIntercalary:l}}s=o.day-1;var c,u=f[o.year-f[0]],p=u>>13;c=p&&(o.month>p||o.isIntercalary)?o.month:o.month-1;for(var d=0;d<c;d++){s+=u&1<<12-d?30:29}var g=h[o.year-h[0]],m=new Date(g>>9&4095,(g>>5&15)-1,(31&g)+s);return a.year=m.getFullYear(),a.month=1+m.getMonth(),a.day=m.getDate(),a}(t,s,r,o);return a.toJD(l.year,l.month,l.day)},fromJD:function(t){var e=a.fromJD(t),r=function(t,e,r,n){var i,a;if(\"object\"==typeof t)i=t,a=e||{};else{if(!(\"number\"==typeof t&&t>=1888&&t<=2111))throw new Error(\"Solar year outside range 1888-2111\");if(!(\"number\"==typeof e&&e>=1&&e<=12))throw new Error(\"Solar month outside range 1 - 12\");if(!(\"number\"==typeof r&&r>=1&&r<=31))throw new Error(\"Solar day outside range 1 - 31\");i={year:t,month:e,day:r},a=n||{}}var o=h[i.year-h[0]],s=i.year<<9|i.month<<5|i.day;a.year=s>=o?i.year:i.year-1,o=h[a.year-h[0]];var l,c=new Date(o>>9&4095,(o>>5&15)-1,31&o),u=new Date(i.year,i.month-1,i.day);l=Math.round((u-c)/864e5);var p,d=f[a.year-f[0]];for(p=0;p<13;p++){var g=d&1<<12-p?30:29;if(l<g)break;l-=g}var m=d>>13;!m||p<m?(a.isIntercalary=!1,a.month=1+p):p===m?(a.isIntercalary=!0,a.month=p):(a.isIntercalary=!1,a.month=p);return a.day=1+l,a}(e.year(),e.month(),e.day()),n=this.toMonthIndex(r.year,r.month,r.isIntercalary);return this.newDate(r.year,n,r.day)},fromString:function(t){var e=t.match(s),r=this._validateYear(+e[1]),n=+e[2],i=!!e[3],a=this.toMonthIndex(r,n,i),o=+e[4];return this.newDate(r,a,o)},add:function(t,e,r){var n=t.year(),i=t.month(),a=this.isIntercalaryMonth(n,i),s=this.toChineseMonth(n,i),l=Object.getPrototypeOf(o.prototype).add.call(this,t,e,r);if(\"y\"===r){var c=l.year(),u=l.month(),f=this.isIntercalaryMonth(c,s),h=a&&f?this.toMonthIndex(c,s,!0):this.toMonthIndex(c,s,!1);h!==u&&l.month(h)}return l}});var s=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)[-/](\\d?\\d)([iI]?)[-/](\\d?\\d)/m,l=/^\\d?\\d[iI]?/m,c=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?\\u6708/m,u=/^\\u95f0?\\u5341?[\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d]?/m;n.calendars.chinese=o;var f=[1887,5780,5802,19157,2742,50359,1198,2646,46378,7466,3412,30122,5482,67949,2396,5294,43597,6732,6954,36181,2772,4954,18781,2396,54427,5274,6730,47781,5800,6868,21210,4790,59703,2350,5270,46667,3402,3496,38325,1388,4782,18735,2350,52374,6804,7498,44457,2906,1388,29294,4700,63789,6442,6804,56138,5802,2772,38235,1210,4698,22827,5418,63125,3476,5802,43701,2484,5302,27223,2646,70954,7466,3412,54698,5482,2412,38062,5294,2636,32038,6954,60245,2772,4826,43357,2394,5274,39501,6730,72357,5800,5844,53978,4790,2358,38039,5270,87627,3402,3496,54708,5484,4782,43311,2350,3222,27978,7498,68965,2904,5484,45677,4700,6444,39573,6804,6986,19285,2772,62811,1210,4698,47403,5418,5780,38570,5546,76469,2420,5302,51799,2646,5414,36501,3412,5546,18869,2412,54446,5276,6732,48422,6822,2900,28010,4826,92509,2394,5274,55883,6730,6820,47956,5812,2778,18779,2358,62615,5270,5450,46757,3492,5556,27318,4718,67887,2350,3222,52554,7498,3428,38252,5468,4700,31022,6444,64149,6804,6986,43861,2772,5338,35421,2650,70955,5418,5780,54954,5546,2740,38074,5302,2646,29991,3366,61011,3412,5546,43445,2412,5294,35406,6732,72998,6820,6996,52586,2778,2396,38045,5274,6698,23333,6820,64338,5812,2746,43355,2358,5270,39499,5450,79525,3492,5548],h=[1887,966732,967231,967733,968265,968766,969297,969798,970298,970829,971330,971830,972362,972863,973395,973896,974397,974928,975428,975929,976461,976962,977462,977994,978494,979026,979526,980026,980558,981059,981559,982091,982593,983124,983624,984124,984656,985157,985656,986189,986690,987191,987722,988222,988753,989254,989754,990286,990788,991288,991819,992319,992851,993352,993851,994383,994885,995385,995917,996418,996918,997450,997949,998481,998982,999483,1000014,1000515,1001016,1001548,1002047,1002578,1003080,1003580,1004111,1004613,1005113,1005645,1006146,1006645,1007177,1007678,1008209,1008710,1009211,1009743,1010243,1010743,1011275,1011775,1012306,1012807,1013308,1013840,1014341,1014841,1015373,1015874,1016404,1016905,1017405,1017937,1018438,1018939,1019471,1019972,1020471,1021002,1021503,1022035,1022535,1023036,1023568,1024069,1024568,1025100,1025601,1026102,1026633,1027133,1027666,1028167,1028666,1029198,1029699,1030199,1030730,1031231,1031763,1032264,1032764,1033296,1033797,1034297,1034828,1035329,1035830,1036362,1036861,1037393,1037894,1038394,1038925,1039427,1039927,1040459,1040959,1041491,1041992,1042492,1043023,1043524,1044024,1044556,1045057,1045558,1046090,1046590,1047121,1047622,1048122,1048654,1049154,1049655,1050187,1050689,1051219,1051720,1052220,1052751,1053252,1053752,1054284,1054786,1055285,1055817,1056317,1056849,1057349,1057850,1058382,1058883,1059383,1059915,1060415,1060947,1061447,1061947,1062479,1062981,1063480,1064012,1064514,1065014,1065545,1066045,1066577,1067078,1067578,1068110,1068611,1069112,1069642,1070142,1070674,1071175,1071675,1072207,1072709,1073209,1073740,1074241,1074741,1075273,1075773,1076305,1076807,1077308,1077839,1078340,1078840,1079372,1079871,1080403,1080904]},{\"../main\":621,\"object-assign\":499}],608:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Coptic\",jdEpoch:1825029.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Coptic\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Thout\",\"Paopi\",\"Hathor\",\"Koiak\",\"Tobi\",\"Meshir\",\"Paremhat\",\"Paremoude\",\"Pashons\",\"Paoni\",\"Epip\",\"Mesori\",\"Pi Kogi Enavot\"],monthNamesShort:[\"Tho\",\"Pao\",\"Hath\",\"Koi\",\"Tob\",\"Mesh\",\"Pat\",\"Pad\",\"Pash\",\"Pao\",\"Epi\",\"Meso\",\"PiK\"],dayNames:[\"Tkyriaka\",\"Pesnau\",\"Pshoment\",\"Peftoou\",\"Ptiou\",\"Psoou\",\"Psabbaton\"],dayNamesShort:[\"Tky\",\"Pes\",\"Psh\",\"Pef\",\"Pti\",\"Pso\",\"Psa\"],dayNamesMin:[\"Tk\",\"Pes\",\"Psh\",\"Pef\",\"Pt\",\"Pso\",\"Psa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.coptic=a},{\"../main\":621,\"object-assign\":499}],609:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Discworld\",jdEpoch:1721425.5,daysPerMonth:[16,32,32,32,32,32,32,32,32,32,32,32,32],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Discworld\",epochs:[\"BUC\",\"UC\"],monthNames:[\"Ick\",\"Offle\",\"February\",\"March\",\"April\",\"May\",\"June\",\"Grune\",\"August\",\"Spune\",\"Sektober\",\"Ember\",\"December\"],monthNamesShort:[\"Ick\",\"Off\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Gru\",\"Aug\",\"Spu\",\"Sek\",\"Emb\",\"Dec\"],dayNames:[\"Sunday\",\"Octeday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Oct\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Oc\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:2,isRTL:!1}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),13},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),400},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/8)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]},daysInWeek:function(){return 8},dayOfWeek:function(t,e,r){return(this._validate(t,e,r,n.local.invalidDate).day()+1)%8},weekDay:function(t,e,r){var n=this.dayOfWeek(t,e,r);return n>=2&&n<=6},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{century:o[Math.floor((i.year()-1)/100)+1]||\"\"}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year()+(i.year()<0?1:0),e=i.month(),(r=i.day())+(e>1?16:0)+(e>2?32*(e-2):0)+400*(t-1)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t+.5)-Math.floor(this.jdEpoch)-1;var e=Math.floor(t/400)+1;t-=400*(e-1),t+=t>15?16:0;var r=Math.floor(t/32)+1,n=t-32*(r-1)+1;return this.newDate(e<=0?e-1:e,r,n)}});var o={20:\"Fruitbat\",21:\"Anchovy\"};n.calendars.discworld=a},{\"../main\":621,\"object-assign\":499}],610:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Ethiopian\",jdEpoch:1724220.5,daysPerMonth:[30,30,30,30,30,30,30,30,30,30,30,30,5],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Ethiopian\",epochs:[\"BEE\",\"EE\"],monthNames:[\"Meskerem\",\"Tikemet\",\"Hidar\",\"Tahesas\",\"Tir\",\"Yekatit\",\"Megabit\",\"Miazia\",\"Genbot\",\"Sene\",\"Hamle\",\"Nehase\",\"Pagume\"],monthNamesShort:[\"Mes\",\"Tik\",\"Hid\",\"Tah\",\"Tir\",\"Yek\",\"Meg\",\"Mia\",\"Gen\",\"Sen\",\"Ham\",\"Neh\",\"Pag\"],dayNames:[\"Ehud\",\"Segno\",\"Maksegno\",\"Irob\",\"Hamus\",\"Arb\",\"Kidame\"],dayNamesShort:[\"Ehu\",\"Seg\",\"Mak\",\"Iro\",\"Ham\",\"Arb\",\"Kid\"],dayNamesMin:[\"Eh\",\"Se\",\"Ma\",\"Ir\",\"Ha\",\"Ar\",\"Ki\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==3||t%4==-1},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear),13},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(13===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return(t=i.year())<0&&t++,i.day()+30*(i.month()-1)+365*(t-1)+Math.floor(t/4)+this.jdEpoch-1},fromJD:function(t){var e=Math.floor(t)+.5-this.jdEpoch,r=Math.floor((e-Math.floor((e+366)/1461))/365)+1;r<=0&&r--,e=Math.floor(t)+.5-this.newDate(r,1,1).toJD();var n=Math.floor(e/30)+1,i=e-30*(n-1)+1;return this.newDate(r,n,i)}}),n.calendars.ethiopian=a},{\"../main\":621,\"object-assign\":499}],611:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Hebrew\",jdEpoch:347995.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29,29],hasYearZero:!1,minMonth:1,firstMonth:7,minDay:1,regionalOptions:{\"\":{name:\"Hebrew\",epochs:[\"BAM\",\"AM\"],monthNames:[\"Nisan\",\"Iyar\",\"Sivan\",\"Tammuz\",\"Av\",\"Elul\",\"Tishrei\",\"Cheshvan\",\"Kislev\",\"Tevet\",\"Shevat\",\"Adar\",\"Adar II\"],monthNamesShort:[\"Nis\",\"Iya\",\"Siv\",\"Tam\",\"Av\",\"Elu\",\"Tis\",\"Che\",\"Kis\",\"Tev\",\"She\",\"Ada\",\"Ad2\"],dayNames:[\"Yom Rishon\",\"Yom Sheni\",\"Yom Shlishi\",\"Yom Revi'i\",\"Yom Chamishi\",\"Yom Shishi\",\"Yom Shabbat\"],dayNamesShort:[\"Ris\",\"She\",\"Shl\",\"Rev\",\"Cha\",\"Shi\",\"Sha\"],dayNamesMin:[\"Ri\",\"She\",\"Shl\",\"Re\",\"Ch\",\"Shi\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return this._leapYear(e.year())},_leapYear:function(t){return o(7*(t=t<0?t+1:t)+1,19)<7},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),this._leapYear(t.year?t.year():t)?13:12},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),this.toJD(-1===t?1:t+1,7,1)-this.toJD(t,7,1)},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),12===e&&this.leapYear(t)||8===e&&5===o(this.daysInYear(t),10)?30:9===e&&3===o(this.daysInYear(t),10)?29:this.daysPerMonth[e-1]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return{yearType:(this.leapYear(i)?\"embolismic\":\"common\")+\" \"+[\"deficient\",\"regular\",\"complete\"][this.daysInYear(i)%10-3]}},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t<=0?t+1:t,o=this.jdEpoch+this._delay1(a)+this._delay2(a)+r+1;if(e<7){for(var s=7;s<=this.monthsInYear(t);s++)o+=this.daysInMonth(t,s);for(s=1;s<e;s++)o+=this.daysInMonth(t,s)}else for(s=7;s<e;s++)o+=this.daysInMonth(t,s);return o},_delay1:function(t){var e=Math.floor((235*t-234)/19),r=12084+13753*e,n=29*e+Math.floor(r/25920);return o(3*(n+1),7)<3&&n++,n},_delay2:function(t){var e=this._delay1(t-1),r=this._delay1(t);return this._delay1(t+1)-r==356?2:r-e==382?1:0},fromJD:function(t){t=Math.floor(t)+.5;for(var e=Math.floor(98496*(t-this.jdEpoch)/35975351)-1;t>=this.toJD(-1===e?1:e+1,7,1);)e++;for(var r=t<this.toJD(e,1,1)?7:1;t>this.toJD(e,r,this.daysInMonth(e,r));)r++;var n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.hebrew=a},{\"../main\":621,\"object-assign\":499}],612:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Islamic\",jdEpoch:1948439.5,daysPerMonth:[30,29,30,29,30,29,30,29,30,29,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Islamic\",epochs:[\"BH\",\"AH\"],monthNames:[\"Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' al-thani\",\"Jumada al-awwal\",\"Jumada al-thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-ahad\",\"Yawm al-ithnayn\",\"Yawm ath-thulaathaa'\",\"Yawm al-arbi'aa'\",\"Yawm al-kham\\u012bs\",\"Yawm al-jum'a\",\"Yawm as-sabt\"],dayNamesShort:[\"Aha\",\"Ith\",\"Thu\",\"Arb\",\"Kha\",\"Jum\",\"Sab\"],dayNamesMin:[\"Ah\",\"It\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){return(11*this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year()+14)%30<11},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){return this.leapYear(t)?355:354},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),t=t<=0?t+1:t,(r=i.day())+Math.ceil(29.5*(e-1))+354*(t-1)+Math.floor((3+11*t)/30)+this.jdEpoch-1},fromJD:function(t){t=Math.floor(t)+.5;var e=Math.floor((30*(t-this.jdEpoch)+10646)/10631);e=e<=0?e-1:e;var r=Math.min(12,Math.ceil((t-29-this.toJD(e,1,1))/29.5)+1),n=t-this.toJD(e,r,1)+1;return this.newDate(e,r,n)}}),n.calendars.islamic=a},{\"../main\":621,\"object-assign\":499}],613:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Julian\",jdEpoch:1721423.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Julian\",epochs:[\"BC\",\"AD\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return(t=e.year()<0?e.year()+1:e.year())%4==0},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return t=i.year(),e=i.month(),r=i.day(),t<0&&t++,e<=2&&(t--,e+=12),Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r-1524.5},fromJD:function(t){var e=Math.floor(t+.5)+1524,r=Math.floor((e-122.1)/365.25),n=Math.floor(365.25*r),i=Math.floor((e-n)/30.6001),a=i-Math.floor(i<14?1:13),o=r-Math.floor(a>2?4716:4715),s=e-n-Math.floor(30.6001*i);return o<=0&&o--,this.newDate(o,a,s)}}),n.calendars.julian=a},{\"../main\":621,\"object-assign\":499}],614:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}function s(t,e){return o(t-1,e)+1}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Mayan\",jdEpoch:584282.5,hasYearZero:!0,minMonth:0,firstMonth:0,minDay:0,regionalOptions:{\"\":{name:\"Mayan\",epochs:[\"\",\"\"],monthNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],monthNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\"],dayNames:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesShort:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],dayNamesMin:[\"0\",\"1\",\"2\",\"3\",\"4\",\"5\",\"6\",\"7\",\"8\",\"9\",\"10\",\"11\",\"12\",\"13\",\"14\",\"15\",\"16\",\"17\",\"18\",\"19\"],digits:null,dateFormat:\"YYYY.m.d\",firstDay:0,isRTL:!1,haabMonths:[\"Pop\",\"Uo\",\"Zip\",\"Zotz\",\"Tzec\",\"Xul\",\"Yaxkin\",\"Mol\",\"Chen\",\"Yax\",\"Zac\",\"Ceh\",\"Mac\",\"Kankin\",\"Muan\",\"Pax\",\"Kayab\",\"Cumku\",\"Uayeb\"],tzolkinMonths:[\"Imix\",\"Ik\",\"Akbal\",\"Kan\",\"Chicchan\",\"Cimi\",\"Manik\",\"Lamat\",\"Muluc\",\"Oc\",\"Chuen\",\"Eb\",\"Ben\",\"Ix\",\"Men\",\"Cib\",\"Caban\",\"Etznab\",\"Cauac\",\"Ahau\"]}},leapYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),!1},formatYear:function(t){t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year();var e=Math.floor(t/400);return t%=400,t+=t<0?400:0,e+\".\"+Math.floor(t/20)+\".\"+t%20},forYear:function(t){if((t=t.split(\".\")).length<3)throw\"Invalid Mayan year\";for(var e=0,r=0;r<t.length;r++){var n=parseInt(t[r],10);if(Math.abs(n)>19||r>0&&n<0)throw\"Invalid Mayan year\";e=20*e+n}return e},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),18},weekOfYear:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),0},daysInYear:function(t){return this._validate(t,this.minMonth,this.minDay,n.local.invalidYear),360},daysInMonth:function(t,e){return this._validate(t,e,this.minDay,n.local.invalidMonth),20},daysInWeek:function(){return 5},dayOfWeek:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate).day()},weekDay:function(t,e,r){return this._validate(t,e,r,n.local.invalidDate),!0},extraInfo:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate).toJD(),a=this._toHaab(i),o=this._toTzolkin(i);return{haabMonthName:this.local.haabMonths[a[0]-1],haabMonth:a[0],haabDay:a[1],tzolkinDayName:this.local.tzolkinMonths[o[0]-1],tzolkinDay:o[0],tzolkinTrecena:o[1]}},_toHaab:function(t){var e=o((t-=this.jdEpoch)+8+340,365);return[Math.floor(e/20)+1,o(e,20)]},_toTzolkin:function(t){return[s((t-=this.jdEpoch)+20,20),s(t+4,13)]},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);return i.day()+20*i.month()+360*i.year()+this.jdEpoch},fromJD:function(t){t=Math.floor(t)+.5-this.jdEpoch;var e=Math.floor(t/360);t%=360,t+=t<0?360:0;var r=Math.floor(t/20),n=t%20;return this.newDate(e,r,n)}}),n.calendars.mayan=a},{\"../main\":621,\"object-assign\":499}],615:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar;var o=n.instance(\"gregorian\");i(a.prototype,{name:\"Nanakshahi\",jdEpoch:2257673.5,daysPerMonth:[31,31,31,31,31,30,30,30,30,30,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Nanakshahi\",epochs:[\"BN\",\"AN\"],monthNames:[\"Chet\",\"Vaisakh\",\"Jeth\",\"Harh\",\"Sawan\",\"Bhadon\",\"Assu\",\"Katak\",\"Maghar\",\"Poh\",\"Magh\",\"Phagun\"],monthNamesShort:[\"Che\",\"Vai\",\"Jet\",\"Har\",\"Saw\",\"Bha\",\"Ass\",\"Kat\",\"Mgr\",\"Poh\",\"Mgh\",\"Pha\"],dayNames:[\"Somvaar\",\"Mangalvar\",\"Budhvaar\",\"Veervaar\",\"Shukarvaar\",\"Sanicharvaar\",\"Etvaar\"],dayNamesShort:[\"Som\",\"Mangal\",\"Budh\",\"Veer\",\"Shukar\",\"Sanichar\",\"Et\"],dayNamesMin:[\"So\",\"Ma\",\"Bu\",\"Ve\",\"Sh\",\"Sa\",\"Et\"],digits:null,dateFormat:\"dd-mm-yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear||n.regionalOptions[\"\"].invalidYear);return o.leapYear(e.year()+(e.year()<1?1:0)+1469)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(1-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidMonth);(t=i.year())<0&&t++;for(var a=i.day(),s=1;s<i.month();s++)a+=this.daysPerMonth[s-1];return a+o.toJD(t+1468,3,13)},fromJD:function(t){t=Math.floor(t+.5);for(var e=Math.floor((t-(this.jdEpoch-1))/366);t>=this.toJD(e+1,1,1);)e++;for(var r=t-Math.floor(this.toJD(e,1,1)+.5)+1,n=1;r>this.daysInMonth(e,n);)r-=this.daysInMonth(e,n),n++;return this.newDate(e,n,r)}}),n.calendars.nanakshahi=a},{\"../main\":621,\"object-assign\":499}],616:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Nepali\",jdEpoch:1700709.5,daysPerMonth:[31,31,32,32,31,30,30,29,30,29,30,30],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,daysPerYear:365,regionalOptions:{\"\":{name:\"Nepali\",epochs:[\"BBS\",\"ABS\"],monthNames:[\"Baisakh\",\"Jestha\",\"Ashadh\",\"Shrawan\",\"Bhadra\",\"Ashwin\",\"Kartik\",\"Mangsir\",\"Paush\",\"Mangh\",\"Falgun\",\"Chaitra\"],monthNamesShort:[\"Bai\",\"Je\",\"As\",\"Shra\",\"Bha\",\"Ash\",\"Kar\",\"Mang\",\"Pau\",\"Ma\",\"Fal\",\"Chai\"],dayNames:[\"Aaitabaar\",\"Sombaar\",\"Manglbaar\",\"Budhabaar\",\"Bihibaar\",\"Shukrabaar\",\"Shanibaar\"],dayNamesShort:[\"Aaita\",\"Som\",\"Mangl\",\"Budha\",\"Bihi\",\"Shukra\",\"Shani\"],dayNamesMin:[\"Aai\",\"So\",\"Man\",\"Bu\",\"Bi\",\"Shu\",\"Sha\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:1,isRTL:!1}},leapYear:function(t){return this.daysInYear(t)!==this.daysPerYear},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){if(t=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear).year(),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t])return this.daysPerYear;for(var e=0,r=this.minMonth;r<=12;r++)e+=this.NEPALI_CALENDAR_DATA[t][r];return e},daysInMonth:function(t,e){return t.year&&(e=t.month(),t=t.year()),this._validate(t,e,this.minDay,n.local.invalidMonth),\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[t]?this.daysPerMonth[e-1]:this.NEPALI_CALENDAR_DATA[t][e]},weekDay:function(t,e,r){return 6!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=n.instance(),o=0,s=e,l=t;this._createMissingCalendarData(t);var c=t-(s>9||9===s&&r>=this.NEPALI_CALENDAR_DATA[l][0]?56:57);for(9!==e&&(o=r,s--);9!==s;)s<=0&&(s=12,l--),o+=this.NEPALI_CALENDAR_DATA[l][s],s--;return 9===e?(o+=r-this.NEPALI_CALENDAR_DATA[l][0])<0&&(o+=a.daysInYear(c)):o+=this.NEPALI_CALENDAR_DATA[l][9]-this.NEPALI_CALENDAR_DATA[l][0],a.newDate(c,1,1).add(o,\"d\").toJD()},fromJD:function(t){var e=n.instance().fromJD(t),r=e.year(),i=e.dayOfYear(),a=r+56;this._createMissingCalendarData(a);for(var o=9,s=this.NEPALI_CALENDAR_DATA[a][0],l=this.NEPALI_CALENDAR_DATA[a][o]-s+1;i>l;)++o>12&&(o=1,a++),l+=this.NEPALI_CALENDAR_DATA[a][o];var c=this.NEPALI_CALENDAR_DATA[a][o]-(l-i);return this.newDate(a,o,c)},_createMissingCalendarData:function(t){var e=this.daysPerMonth.slice(0);e.unshift(17);for(var r=t-1;r<t+2;r++)\"undefined\"==typeof this.NEPALI_CALENDAR_DATA[r]&&(this.NEPALI_CALENDAR_DATA[r]=e)},NEPALI_CALENDAR_DATA:{1970:[18,31,31,32,31,31,31,30,29,30,29,30,30],1971:[18,31,31,32,31,32,30,30,29,30,29,30,30],1972:[17,31,32,31,32,31,30,30,30,29,29,30,30],1973:[19,30,32,31,32,31,30,30,30,29,30,29,31],1974:[19,31,31,32,30,31,31,30,29,30,29,30,30],1975:[18,31,31,32,32,30,31,30,29,30,29,30,30],1976:[17,31,32,31,32,31,30,30,30,29,29,30,31],1977:[18,31,32,31,32,31,31,29,30,29,30,29,31],1978:[18,31,31,32,31,31,31,30,29,30,29,30,30],1979:[18,31,31,32,32,31,30,30,29,30,29,30,30],1980:[17,31,32,31,32,31,30,30,30,29,29,30,31],1981:[18,31,31,31,32,31,31,29,30,30,29,30,30],1982:[18,31,31,32,31,31,31,30,29,30,29,30,30],1983:[18,31,31,32,32,31,30,30,29,30,29,30,30],1984:[17,31,32,31,32,31,30,30,30,29,29,30,31],1985:[18,31,31,31,32,31,31,29,30,30,29,30,30],1986:[18,31,31,32,31,31,31,30,29,30,29,30,30],1987:[18,31,32,31,32,31,30,30,29,30,29,30,30],1988:[17,31,32,31,32,31,30,30,30,29,29,30,31],1989:[18,31,31,31,32,31,31,30,29,30,29,30,30],1990:[18,31,31,32,31,31,31,30,29,30,29,30,30],1991:[18,31,32,31,32,31,30,30,29,30,29,30,30],1992:[17,31,32,31,32,31,30,30,30,29,30,29,31],1993:[18,31,31,31,32,31,31,30,29,30,29,30,30],1994:[18,31,31,32,31,31,31,30,29,30,29,30,30],1995:[17,31,32,31,32,31,30,30,30,29,29,30,30],1996:[17,31,32,31,32,31,30,30,30,29,30,29,31],1997:[18,31,31,32,31,31,31,30,29,30,29,30,30],1998:[18,31,31,32,31,31,31,30,29,30,29,30,30],1999:[17,31,32,31,32,31,30,30,30,29,29,30,31],2e3:[17,30,32,31,32,31,30,30,30,29,30,29,31],2001:[18,31,31,32,31,31,31,30,29,30,29,30,30],2002:[18,31,31,32,32,31,30,30,29,30,29,30,30],2003:[17,31,32,31,32,31,30,30,30,29,29,30,31],2004:[17,30,32,31,32,31,30,30,30,29,30,29,31],2005:[18,31,31,32,31,31,31,30,29,30,29,30,30],2006:[18,31,31,32,32,31,30,30,29,30,29,30,30],2007:[17,31,32,31,32,31,30,30,30,29,29,30,31],2008:[17,31,31,31,32,31,31,29,30,30,29,29,31],2009:[18,31,31,32,31,31,31,30,29,30,29,30,30],2010:[18,31,31,32,32,31,30,30,29,30,29,30,30],2011:[17,31,32,31,32,31,30,30,30,29,29,30,31],2012:[17,31,31,31,32,31,31,29,30,30,29,30,30],2013:[18,31,31,32,31,31,31,30,29,30,29,30,30],2014:[18,31,31,32,32,31,30,30,29,30,29,30,30],2015:[17,31,32,31,32,31,30,30,30,29,29,30,31],2016:[17,31,31,31,32,31,31,29,30,30,29,30,30],2017:[18,31,31,32,31,31,31,30,29,30,29,30,30],2018:[18,31,32,31,32,31,30,30,29,30,29,30,30],2019:[17,31,32,31,32,31,30,30,30,29,30,29,31],2020:[17,31,31,31,32,31,31,30,29,30,29,30,30],2021:[18,31,31,32,31,31,31,30,29,30,29,30,30],2022:[17,31,32,31,32,31,30,30,30,29,29,30,30],2023:[17,31,32,31,32,31,30,30,30,29,30,29,31],2024:[17,31,31,31,32,31,31,30,29,30,29,30,30],2025:[18,31,31,32,31,31,31,30,29,30,29,30,30],2026:[17,31,32,31,32,31,30,30,30,29,29,30,31],2027:[17,30,32,31,32,31,30,30,30,29,30,29,31],2028:[17,31,31,32,31,31,31,30,29,30,29,30,30],2029:[18,31,31,32,31,32,30,30,29,30,29,30,30],2030:[17,31,32,31,32,31,30,30,30,30,30,30,31],2031:[17,31,32,31,32,31,31,31,31,31,31,31,31],2032:[17,32,32,32,32,32,32,32,32,32,32,32,32],2033:[18,31,31,32,32,31,30,30,29,30,29,30,30],2034:[17,31,32,31,32,31,30,30,30,29,29,30,31],2035:[17,30,32,31,32,31,31,29,30,30,29,29,31],2036:[17,31,31,32,31,31,31,30,29,30,29,30,30],2037:[18,31,31,32,32,31,30,30,29,30,29,30,30],2038:[17,31,32,31,32,31,30,30,30,29,29,30,31],2039:[17,31,31,31,32,31,31,29,30,30,29,30,30],2040:[17,31,31,32,31,31,31,30,29,30,29,30,30],2041:[18,31,31,32,32,31,30,30,29,30,29,30,30],2042:[17,31,32,31,32,31,30,30,30,29,29,30,31],2043:[17,31,31,31,32,31,31,29,30,30,29,30,30],2044:[17,31,31,32,31,31,31,30,29,30,29,30,30],2045:[18,31,32,31,32,31,30,30,29,30,29,30,30],2046:[17,31,32,31,32,31,30,30,30,29,29,30,31],2047:[17,31,31,31,32,31,31,30,29,30,29,30,30],2048:[17,31,31,32,31,31,31,30,29,30,29,30,30],2049:[17,31,32,31,32,31,30,30,30,29,29,30,30],2050:[17,31,32,31,32,31,30,30,30,29,30,29,31],2051:[17,31,31,31,32,31,31,30,29,30,29,30,30],2052:[17,31,31,32,31,31,31,30,29,30,29,30,30],2053:[17,31,32,31,32,31,30,30,30,29,29,30,30],2054:[17,31,32,31,32,31,30,30,30,29,30,29,31],2055:[17,31,31,32,31,31,31,30,29,30,30,29,30],2056:[17,31,31,32,31,32,30,30,29,30,29,30,30],2057:[17,31,32,31,32,31,30,30,30,29,29,30,31],2058:[17,30,32,31,32,31,30,30,30,29,30,29,31],2059:[17,31,31,32,31,31,31,30,29,30,29,30,30],2060:[17,31,31,32,32,31,30,30,29,30,29,30,30],2061:[17,31,32,31,32,31,30,30,30,29,29,30,31],2062:[17,30,32,31,32,31,31,29,30,29,30,29,31],2063:[17,31,31,32,31,31,31,30,29,30,29,30,30],2064:[17,31,31,32,32,31,30,30,29,30,29,30,30],2065:[17,31,32,31,32,31,30,30,30,29,29,30,31],2066:[17,31,31,31,32,31,31,29,30,30,29,29,31],2067:[17,31,31,32,31,31,31,30,29,30,29,30,30],2068:[17,31,31,32,32,31,30,30,29,30,29,30,30],2069:[17,31,32,31,32,31,30,30,30,29,29,30,31],2070:[17,31,31,31,32,31,31,29,30,30,29,30,30],2071:[17,31,31,32,31,31,31,30,29,30,29,30,30],2072:[17,31,32,31,32,31,30,30,29,30,29,30,30],2073:[17,31,32,31,32,31,30,30,30,29,29,30,31],2074:[17,31,31,31,32,31,31,30,29,30,29,30,30],2075:[17,31,31,32,31,31,31,30,29,30,29,30,30],2076:[16,31,32,31,32,31,30,30,30,29,29,30,30],2077:[17,31,32,31,32,31,30,30,30,29,30,29,31],2078:[17,31,31,31,32,31,31,30,29,30,29,30,30],2079:[17,31,31,32,31,31,31,30,29,30,29,30,30],2080:[16,31,32,31,32,31,30,30,30,29,29,30,30],2081:[17,31,31,32,32,31,30,30,30,29,30,30,30],2082:[17,31,32,31,32,31,30,30,30,29,30,30,30],2083:[17,31,31,32,31,31,30,30,30,29,30,30,30],2084:[17,31,31,32,31,31,30,30,30,29,30,30,30],2085:[17,31,32,31,32,31,31,30,30,29,30,30,30],2086:[17,31,32,31,32,31,30,30,30,29,30,30,30],2087:[16,31,31,32,31,31,31,30,30,29,30,30,30],2088:[16,30,31,32,32,30,31,30,30,29,30,30,30],2089:[17,31,32,31,32,31,30,30,30,29,30,30,30],2090:[17,31,32,31,32,31,30,30,30,29,30,30,30],2091:[16,31,31,32,31,31,31,30,30,29,30,30,30],2092:[16,31,31,32,32,31,30,30,30,29,30,30,30],2093:[17,31,32,31,32,31,30,30,30,29,30,30,30],2094:[17,31,31,32,31,31,30,30,30,29,30,30,30],2095:[17,31,31,32,31,31,31,30,29,30,30,30,30],2096:[17,30,31,32,32,31,30,30,29,30,29,30,30],2097:[17,31,32,31,32,31,30,30,30,29,30,30,30],2098:[17,31,31,32,31,31,31,29,30,29,30,30,31],2099:[17,31,31,32,31,31,31,30,29,29,30,30,30],2100:[17,31,32,31,32,30,31,30,29,30,29,30,30]}}),n.calendars.nepali=a},{\"../main\":621,\"object-assign\":499}],617:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}function o(t,e){return t-e*Math.floor(t/e)}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"Persian\",jdEpoch:1948320.5,daysPerMonth:[31,31,31,31,31,31,30,30,30,30,30,29],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Persian\",epochs:[\"BP\",\"AP\"],monthNames:[\"Farvardin\",\"Ordibehesht\",\"Khordad\",\"Tir\",\"Mordad\",\"Shahrivar\",\"Mehr\",\"Aban\",\"Azar\",\"Day\",\"Bahman\",\"Esfand\"],monthNamesShort:[\"Far\",\"Ord\",\"Kho\",\"Tir\",\"Mor\",\"Sha\",\"Meh\",\"Aba\",\"Aza\",\"Day\",\"Bah\",\"Esf\"],dayNames:[\"Yekshambe\",\"Doshambe\",\"Seshambe\",\"Ch\\xe6harshambe\",\"Panjshambe\",\"Jom'e\",\"Shambe\"],dayNamesShort:[\"Yek\",\"Do\",\"Se\",\"Ch\\xe6\",\"Panj\",\"Jom\",\"Sha\"],dayNamesMin:[\"Ye\",\"Do\",\"Se\",\"Ch\",\"Pa\",\"Jo\",\"Sh\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 682*((e.year()-(e.year()>0?474:473))%2820+474+38)%2816<682},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-(n.dayOfWeek()+1)%7,\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(12===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=i.year(),e=i.month(),r=i.day();var a=t-(t>=0?474:473),s=474+o(a,2820);return r+(e<=7?31*(e-1):30*(e-1)+6)+Math.floor((682*s-110)/2816)+365*(s-1)+1029983*Math.floor(a/2820)+this.jdEpoch-1},fromJD:function(t){var e=(t=Math.floor(t)+.5)-this.toJD(475,1,1),r=Math.floor(e/1029983),n=o(e,1029983),i=2820;if(1029982!==n){var a=Math.floor(n/366),s=o(n,366);i=Math.floor((2134*a+2816*s+2815)/1028522)+a+1}var l=i+2820*r+474;l=l<=0?l-1:l;var c=t-this.toJD(l,1,1)+1,u=c<=186?Math.ceil(c/31):Math.ceil((c-6)/30),f=t-this.toJD(l,u,1)+1;return this.newDate(l,u,f)}}),n.calendars.persian=a,n.calendars.jalali=a},{\"../main\":621,\"object-assign\":499}],618:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Taiwan\",jdEpoch:2419402.5,yearsOffset:1911,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Taiwan\",epochs:[\"BROC\",\"ROC\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:1,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)},_g2tYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)}}),n.calendars.taiwan=o},{\"../main\":621,\"object-assign\":499}],619:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\"),a=n.instance();function o(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}o.prototype=new n.baseCalendar,i(o.prototype,{name:\"Thai\",jdEpoch:1523098.5,yearsOffset:543,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Thai\",epochs:[\"BBE\",\"BE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"dd/mm/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(e.year());return a.leapYear(t)},weekOfYear:function(t,e,r){var i=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);t=this._t2gYear(i.year());return a.weekOfYear(t,i.month(),i.day())},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,n.local.invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate);t=this._t2gYear(i.year());return a.toJD(t,i.month(),i.day())},fromJD:function(t){var e=a.fromJD(t),r=this._g2tYear(e.year());return this.newDate(r,e.month(),e.day())},_t2gYear:function(t){return t-this.yearsOffset-(t>=1&&t<=this.yearsOffset?1:0)},_g2tYear:function(t){return t+this.yearsOffset+(t>=-this.yearsOffset&&t<=-1?1:0)}}),n.calendars.thai=o},{\"../main\":621,\"object-assign\":499}],620:[function(t,e,r){var n=t(\"../main\"),i=t(\"object-assign\");function a(t){this.local=this.regionalOptions[t||\"\"]||this.regionalOptions[\"\"]}a.prototype=new n.baseCalendar,i(a.prototype,{name:\"UmmAlQura\",hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Umm al-Qura\",epochs:[\"BH\",\"AH\"],monthNames:[\"Al-Muharram\",\"Safar\",\"Rabi' al-awwal\",\"Rabi' Al-Thani\",\"Jumada Al-Awwal\",\"Jumada Al-Thani\",\"Rajab\",\"Sha'aban\",\"Ramadan\",\"Shawwal\",\"Dhu al-Qi'dah\",\"Dhu al-Hijjah\"],monthNamesShort:[\"Muh\",\"Saf\",\"Rab1\",\"Rab2\",\"Jum1\",\"Jum2\",\"Raj\",\"Sha'\",\"Ram\",\"Shaw\",\"DhuQ\",\"DhuH\"],dayNames:[\"Yawm al-Ahad\",\"Yawm al-Ithnain\",\"Yawm al-Thal\\u0101th\\u0101\\u2019\",\"Yawm al-Arba\\u2018\\u0101\\u2019\",\"Yawm al-Kham\\u012bs\",\"Yawm al-Jum\\u2018a\",\"Yawm al-Sabt\"],dayNamesMin:[\"Ah\",\"Ith\",\"Th\",\"Ar\",\"Kh\",\"Ju\",\"Sa\"],digits:null,dateFormat:\"yyyy/mm/dd\",firstDay:6,isRTL:!0}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,n.local.invalidYear);return 355===this.daysInYear(e.year())},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(-n.dayOfWeek(),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInYear:function(t){for(var e=0,r=1;r<=12;r++)e+=this.daysInMonth(t,r);return e},daysInMonth:function(t,e){for(var r=this._validate(t,e,this.minDay,n.local.invalidMonth).toJD()-24e5+.5,i=0,a=0;a<o.length;a++){if(o[a]>r)return o[i]-o[i-1];i++}return 30},weekDay:function(t,e,r){return 5!==this.dayOfWeek(t,e,r)},toJD:function(t,e,r){var i=this._validate(t,e,r,n.local.invalidDate),a=12*(i.year()-1)+i.month()-15292;return i.day()+o[a-1]-1+24e5-.5},fromJD:function(t){for(var e=t-24e5+.5,r=0,n=0;n<o.length&&!(o[n]>e);n++)r++;var i=r+15292,a=Math.floor((i-1)/12),s=a+1,l=i-12*a,c=e-o[r-1]+1;return this.newDate(s,l,c)},isValid:function(t,e,r){var i=n.baseCalendar.prototype.isValid.apply(this,arguments);return i&&(i=(t=null!=t.year?t.year:t)>=1276&&t<=1500),i},_validate:function(t,e,r,i){var a=n.baseCalendar.prototype._validate.apply(this,arguments);if(a.year<1276||a.year>1500)throw i.replace(/\\{0\\}/,this.local.name);return a}}),n.calendars.ummalqura=a;var o=[20,50,79,109,138,168,197,227,256,286,315,345,374,404,433,463,492,522,551,581,611,641,670,700,729,759,788,818,847,877,906,936,965,995,1024,1054,1083,1113,1142,1172,1201,1231,1260,1290,1320,1350,1379,1409,1438,1468,1497,1527,1556,1586,1615,1645,1674,1704,1733,1763,1792,1822,1851,1881,1910,1940,1969,1999,2028,2058,2087,2117,2146,2176,2205,2235,2264,2294,2323,2353,2383,2413,2442,2472,2501,2531,2560,2590,2619,2649,2678,2708,2737,2767,2796,2826,2855,2885,2914,2944,2973,3003,3032,3062,3091,3121,3150,3180,3209,3239,3268,3298,3327,3357,3386,3416,3446,3476,3505,3535,3564,3594,3623,3653,3682,3712,3741,3771,3800,3830,3859,3889,3918,3948,3977,4007,4036,4066,4095,4125,4155,4185,4214,4244,4273,4303,4332,4362,4391,4421,4450,4480,4509,4539,4568,4598,4627,4657,4686,4716,4745,4775,4804,4834,4863,4893,4922,4952,4981,5011,5040,5070,5099,5129,5158,5188,5218,5248,5277,5307,5336,5366,5395,5425,5454,5484,5513,5543,5572,5602,5631,5661,5690,5720,5749,5779,5808,5838,5867,5897,5926,5956,5985,6015,6044,6074,6103,6133,6162,6192,6221,6251,6281,6311,6340,6370,6399,6429,6458,6488,6517,6547,6576,6606,6635,6665,6694,6724,6753,6783,6812,6842,6871,6901,6930,6960,6989,7019,7048,7078,7107,7137,7166,7196,7225,7255,7284,7314,7344,7374,7403,7433,7462,7492,7521,7551,7580,7610,7639,7669,7698,7728,7757,7787,7816,7846,7875,7905,7934,7964,7993,8023,8053,8083,8112,8142,8171,8201,8230,8260,8289,8319,8348,8378,8407,8437,8466,8496,8525,8555,8584,8614,8643,8673,8702,8732,8761,8791,8821,8850,8880,8909,8938,8968,8997,9027,9056,9086,9115,9145,9175,9205,9234,9264,9293,9322,9352,9381,9410,9440,9470,9499,9529,9559,9589,9618,9648,9677,9706,9736,9765,9794,9824,9853,9883,9913,9943,9972,10002,10032,10061,10090,10120,10149,10178,10208,10237,10267,10297,10326,10356,10386,10415,10445,10474,10504,10533,10562,10592,10621,10651,10680,10710,10740,10770,10799,10829,10858,10888,10917,10947,10976,11005,11035,11064,11094,11124,11153,11183,11213,11242,11272,11301,11331,11360,11389,11419,11448,11478,11507,11537,11567,11596,11626,11655,11685,11715,11744,11774,11803,11832,11862,11891,11921,11950,11980,12010,12039,12069,12099,12128,12158,12187,12216,12246,12275,12304,12334,12364,12393,12423,12453,12483,12512,12542,12571,12600,12630,12659,12688,12718,12747,12777,12807,12837,12866,12896,12926,12955,12984,13014,13043,13072,13102,13131,13161,13191,13220,13250,13280,13310,13339,13368,13398,13427,13456,13486,13515,13545,13574,13604,13634,13664,13693,13723,13752,13782,13811,13840,13870,13899,13929,13958,13988,14018,14047,14077,14107,14136,14166,14195,14224,14254,14283,14313,14342,14372,14401,14431,14461,14490,14520,14550,14579,14609,14638,14667,14697,14726,14756,14785,14815,14844,14874,14904,14933,14963,14993,15021,15051,15081,15110,15140,15169,15199,15228,15258,15287,15317,15347,15377,15406,15436,15465,15494,15524,15553,15582,15612,15641,15671,15701,15731,15760,15790,15820,15849,15878,15908,15937,15966,15996,16025,16055,16085,16114,16144,16174,16204,16233,16262,16292,16321,16350,16380,16409,16439,16468,16498,16528,16558,16587,16617,16646,16676,16705,16734,16764,16793,16823,16852,16882,16912,16941,16971,17001,17030,17060,17089,17118,17148,17177,17207,17236,17266,17295,17325,17355,17384,17414,17444,17473,17502,17532,17561,17591,17620,17650,17679,17709,17738,17768,17798,17827,17857,17886,17916,17945,17975,18004,18034,18063,18093,18122,18152,18181,18211,18241,18270,18300,18330,18359,18388,18418,18447,18476,18506,18535,18565,18595,18625,18654,18684,18714,18743,18772,18802,18831,18860,18890,18919,18949,18979,19008,19038,19068,19098,19127,19156,19186,19215,19244,19274,19303,19333,19362,19392,19422,19452,19481,19511,19540,19570,19599,19628,19658,19687,19717,19746,19776,19806,19836,19865,19895,19924,19954,19983,20012,20042,20071,20101,20130,20160,20190,20219,20249,20279,20308,20338,20367,20396,20426,20455,20485,20514,20544,20573,20603,20633,20662,20692,20721,20751,20780,20810,20839,20869,20898,20928,20957,20987,21016,21046,21076,21105,21135,21164,21194,21223,21253,21282,21312,21341,21371,21400,21430,21459,21489,21519,21548,21578,21607,21637,21666,21696,21725,21754,21784,21813,21843,21873,21902,21932,21962,21991,22021,22050,22080,22109,22138,22168,22197,22227,22256,22286,22316,22346,22375,22405,22434,22464,22493,22522,22552,22581,22611,22640,22670,22700,22730,22759,22789,22818,22848,22877,22906,22936,22965,22994,23024,23054,23083,23113,23143,23173,23202,23232,23261,23290,23320,23349,23379,23408,23438,23467,23497,23527,23556,23586,23616,23645,23674,23704,23733,23763,23792,23822,23851,23881,23910,23940,23970,23999,24029,24058,24088,24117,24147,24176,24206,24235,24265,24294,24324,24353,24383,24413,24442,24472,24501,24531,24560,24590,24619,24648,24678,24707,24737,24767,24796,24826,24856,24885,24915,24944,24974,25003,25032,25062,25091,25121,25150,25180,25210,25240,25269,25299,25328,25358,25387,25416,25446,25475,25505,25534,25564,25594,25624,25653,25683,25712,25742,25771,25800,25830,25859,25888,25918,25948,25977,26007,26037,26067,26096,26126,26155,26184,26214,26243,26272,26302,26332,26361,26391,26421,26451,26480,26510,26539,26568,26598,26627,26656,26686,26715,26745,26775,26805,26834,26864,26893,26923,26952,26982,27011,27041,27070,27099,27129,27159,27188,27218,27248,27277,27307,27336,27366,27395,27425,27454,27484,27513,27542,27572,27602,27631,27661,27691,27720,27750,27779,27809,27838,27868,27897,27926,27956,27985,28015,28045,28074,28104,28134,28163,28193,28222,28252,28281,28310,28340,28369,28399,28428,28458,28488,28517,28547,28577,28607,28636,28665,28695,28724,28754,28783,28813,28843,28872,28901,28931,28960,28990,29019,29049,29078,29108,29137,29167,29196,29226,29255,29285,29315,29345,29375,29404,29434,29463,29492,29522,29551,29580,29610,29640,29669,29699,29729,29759,29788,29818,29847,29876,29906,29935,29964,29994,30023,30053,30082,30112,30141,30171,30200,30230,30259,30289,30318,30348,30378,30408,30437,30467,30496,30526,30555,30585,30614,30644,30673,30703,30732,30762,30791,30821,30850,30880,30909,30939,30968,30998,31027,31057,31086,31116,31145,31175,31204,31234,31263,31293,31322,31352,31381,31411,31441,31471,31500,31530,31559,31589,31618,31648,31676,31706,31736,31766,31795,31825,31854,31884,31913,31943,31972,32002,32031,32061,32090,32120,32150,32180,32209,32239,32268,32298,32327,32357,32386,32416,32445,32475,32504,32534,32563,32593,32622,32652,32681,32711,32740,32770,32799,32829,32858,32888,32917,32947,32976,33006,33035,33065,33094,33124,33153,33183,33213,33243,33272,33302,33331,33361,33390,33420,33450,33479,33509,33539,33568,33598,33627,33657,33686,33716,33745,33775,33804,33834,33863,33893,33922,33952,33981,34011,34040,34069,34099,34128,34158,34187,34217,34247,34277,34306,34336,34365,34395,34424,34454,34483,34512,34542,34571,34601,34631,34660,34690,34719,34749,34778,34808,34837,34867,34896,34926,34955,34985,35015,35044,35074,35103,35133,35162,35192,35222,35251,35280,35310,35340,35370,35399,35429,35458,35488,35517,35547,35576,35605,35635,35665,35694,35723,35753,35782,35811,35841,35871,35901,35930,35960,35989,36019,36048,36078,36107,36136,36166,36195,36225,36254,36284,36314,36343,36373,36403,36433,36462,36492,36521,36551,36580,36610,36639,36669,36698,36728,36757,36786,36816,36845,36875,36904,36934,36963,36993,37022,37052,37081,37111,37141,37170,37200,37229,37259,37288,37318,37347,37377,37406,37436,37465,37495,37524,37554,37584,37613,37643,37672,37701,37731,37760,37790,37819,37849,37878,37908,37938,37967,37997,38027,38056,38085,38115,38144,38174,38203,38233,38262,38292,38322,38351,38381,38410,38440,38469,38499,38528,38558,38587,38617,38646,38676,38705,38735,38764,38794,38823,38853,38882,38912,38941,38971,39001,39030,39059,39089,39118,39148,39178,39208,39237,39267,39297,39326,39355,39385,39414,39444,39473,39503,39532,39562,39592,39621,39650,39680,39709,39739,39768,39798,39827,39857,39886,39916,39946,39975,40005,40035,40064,40094,40123,40153,40182,40212,40241,40271,40300,40330,40359,40389,40418,40448,40477,40507,40536,40566,40595,40625,40655,40685,40714,40744,40773,40803,40832,40862,40892,40921,40951,40980,41009,41039,41068,41098,41127,41157,41186,41216,41245,41275,41304,41334,41364,41393,41422,41452,41481,41511,41540,41570,41599,41629,41658,41688,41718,41748,41777,41807,41836,41865,41894,41924,41953,41983,42012,42042,42072,42102,42131,42161,42190,42220,42249,42279,42308,42337,42367,42397,42426,42456,42485,42515,42545,42574,42604,42633,42662,42692,42721,42751,42780,42810,42839,42869,42899,42929,42958,42988,43017,43046,43076,43105,43135,43164,43194,43223,43253,43283,43312,43342,43371,43401,43430,43460,43489,43519,43548,43578,43607,43637,43666,43696,43726,43755,43785,43814,43844,43873,43903,43932,43962,43991,44021,44050,44080,44109,44139,44169,44198,44228,44258,44287,44317,44346,44375,44405,44434,44464,44493,44523,44553,44582,44612,44641,44671,44700,44730,44759,44788,44818,44847,44877,44906,44936,44966,44996,45025,45055,45084,45114,45143,45172,45202,45231,45261,45290,45320,45350,45380,45409,45439,45468,45498,45527,45556,45586,45615,45644,45674,45704,45733,45763,45793,45823,45852,45882,45911,45940,45970,45999,46028,46058,46088,46117,46147,46177,46206,46236,46265,46295,46324,46354,46383,46413,46442,46472,46501,46531,46560,46590,46620,46649,46679,46708,46738,46767,46797,46826,46856,46885,46915,46944,46974,47003,47033,47063,47092,47122,47151,47181,47210,47240,47269,47298,47328,47357,47387,47417,47446,47476,47506,47535,47565,47594,47624,47653,47682,47712,47741,47771,47800,47830,47860,47890,47919,47949,47978,48008,48037,48066,48096,48125,48155,48184,48214,48244,48273,48303,48333,48362,48392,48421,48450,48480,48509,48538,48568,48598,48627,48657,48687,48717,48746,48776,48805,48834,48864,48893,48922,48952,48982,49011,49041,49071,49100,49130,49160,49189,49218,49248,49277,49306,49336,49365,49395,49425,49455,49484,49514,49543,49573,49602,49632,49661,49690,49720,49749,49779,49809,49838,49868,49898,49927,49957,49986,50016,50045,50075,50104,50133,50163,50192,50222,50252,50281,50311,50340,50370,50400,50429,50459,50488,50518,50547,50576,50606,50635,50665,50694,50724,50754,50784,50813,50843,50872,50902,50931,50960,50990,51019,51049,51078,51108,51138,51167,51197,51227,51256,51286,51315,51345,51374,51403,51433,51462,51492,51522,51552,51582,51611,51641,51670,51699,51729,51758,51787,51816,51846,51876,51906,51936,51965,51995,52025,52054,52083,52113,52142,52171,52200,52230,52260,52290,52319,52349,52379,52408,52438,52467,52497,52526,52555,52585,52614,52644,52673,52703,52733,52762,52792,52822,52851,52881,52910,52939,52969,52998,53028,53057,53087,53116,53146,53176,53205,53235,53264,53294,53324,53353,53383,53412,53441,53471,53500,53530,53559,53589,53619,53648,53678,53708,53737,53767,53796,53825,53855,53884,53913,53943,53973,54003,54032,54062,54092,54121,54151,54180,54209,54239,54268,54297,54327,54357,54387,54416,54446,54476,54505,54535,54564,54593,54623,54652,54681,54711,54741,54770,54800,54830,54859,54889,54919,54948,54977,55007,55036,55066,55095,55125,55154,55184,55213,55243,55273,55302,55332,55361,55391,55420,55450,55479,55508,55538,55567,55597,55627,55657,55686,55716,55745,55775,55804,55834,55863,55892,55922,55951,55981,56011,56040,56070,56100,56129,56159,56188,56218,56247,56276,56306,56335,56365,56394,56424,56454,56483,56513,56543,56572,56601,56631,56660,56690,56719,56749,56778,56808,56837,56867,56897,56926,56956,56985,57015,57044,57074,57103,57133,57162,57192,57221,57251,57280,57310,57340,57369,57399,57429,57458,57487,57517,57546,57576,57605,57634,57664,57694,57723,57753,57783,57813,57842,57871,57901,57930,57959,57989,58018,58048,58077,58107,58137,58167,58196,58226,58255,58285,58314,58343,58373,58402,58432,58461,58491,58521,58551,58580,58610,58639,58669,58698,58727,58757,58786,58816,58845,58875,58905,58934,58964,58994,59023,59053,59082,59111,59141,59170,59200,59229,59259,59288,59318,59348,59377,59407,59436,59466,59495,59525,59554,59584,59613,59643,59672,59702,59731,59761,59791,59820,59850,59879,59909,59939,59968,59997,60027,60056,60086,60115,60145,60174,60204,60234,60264,60293,60323,60352,60381,60411,60440,60469,60499,60528,60558,60588,60618,60648,60677,60707,60736,60765,60795,60824,60853,60883,60912,60942,60972,61002,61031,61061,61090,61120,61149,61179,61208,61237,61267,61296,61326,61356,61385,61415,61445,61474,61504,61533,61563,61592,61621,61651,61680,61710,61739,61769,61799,61828,61858,61888,61917,61947,61976,62006,62035,62064,62094,62123,62153,62182,62212,62242,62271,62301,62331,62360,62390,62419,62448,62478,62507,62537,62566,62596,62625,62655,62685,62715,62744,62774,62803,62832,62862,62891,62921,62950,62980,63009,63039,63069,63099,63128,63157,63187,63216,63246,63275,63305,63334,63363,63393,63423,63453,63482,63512,63541,63571,63600,63630,63659,63689,63718,63747,63777,63807,63836,63866,63895,63925,63955,63984,64014,64043,64073,64102,64131,64161,64190,64220,64249,64279,64309,64339,64368,64398,64427,64457,64486,64515,64545,64574,64603,64633,64663,64692,64722,64752,64782,64811,64841,64870,64899,64929,64958,64987,65017,65047,65076,65106,65136,65166,65195,65225,65254,65283,65313,65342,65371,65401,65431,65460,65490,65520,65549,65579,65608,65638,65667,65697,65726,65755,65785,65815,65844,65874,65903,65933,65963,65992,66022,66051,66081,66110,66140,66169,66199,66228,66258,66287,66317,66346,66376,66405,66435,66465,66494,66524,66553,66583,66612,66641,66671,66700,66730,66760,66789,66819,66849,66878,66908,66937,66967,66996,67025,67055,67084,67114,67143,67173,67203,67233,67262,67292,67321,67351,67380,67409,67439,67468,67497,67527,67557,67587,67617,67646,67676,67705,67735,67764,67793,67823,67852,67882,67911,67941,67971,68e3,68030,68060,68089,68119,68148,68177,68207,68236,68266,68295,68325,68354,68384,68414,68443,68473,68502,68532,68561,68591,68620,68650,68679,68708,68738,68768,68797,68827,68857,68886,68916,68946,68975,69004,69034,69063,69092,69122,69152,69181,69211,69240,69270,69300,69330,69359,69388,69418,69447,69476,69506,69535,69565,69595,69624,69654,69684,69713,69743,69772,69802,69831,69861,69890,69919,69949,69978,70008,70038,70067,70097,70126,70156,70186,70215,70245,70274,70303,70333,70362,70392,70421,70451,70481,70510,70540,70570,70599,70629,70658,70687,70717,70746,70776,70805,70835,70864,70894,70924,70954,70983,71013,71042,71071,71101,71130,71159,71189,71218,71248,71278,71308,71337,71367,71397,71426,71455,71485,71514,71543,71573,71602,71632,71662,71691,71721,71751,71781,71810,71839,71869,71898,71927,71957,71986,72016,72046,72075,72105,72135,72164,72194,72223,72253,72282,72311,72341,72370,72400,72429,72459,72489,72518,72548,72577,72607,72637,72666,72695,72725,72754,72784,72813,72843,72872,72902,72931,72961,72991,73020,73050,73080,73109,73139,73168,73197,73227,73256,73286,73315,73345,73375,73404,73434,73464,73493,73523,73552,73581,73611,73640,73669,73699,73729,73758,73788,73818,73848,73877,73907,73936,73965,73995,74024,74053,74083,74113,74142,74172,74202,74231,74261,74291,74320,74349,74379,74408,74437,74467,74497,74526,74556,74586,74615,74645,74675,74704,74733,74763,74792,74822,74851,74881,74910,74940,74969,74999,75029,75058,75088,75117,75147,75176,75206,75235,75264,75294,75323,75353,75383,75412,75442,75472,75501,75531,75560,75590,75619,75648,75678,75707,75737,75766,75796,75826,75856,75885,75915,75944,75974,76003,76032,76062,76091,76121,76150,76180,76210,76239,76269,76299,76328,76358,76387,76416,76446,76475,76505,76534,76564,76593,76623,76653,76682,76712,76741,76771,76801,76830,76859,76889,76918,76948,76977,77007,77036,77066,77096,77125,77155,77185,77214,77243,77273,77302,77332,77361,77390,77420,77450,77479,77509,77539,77569,77598,77627,77657,77686,77715,77745,77774,77804,77833,77863,77893,77923,77952,77982,78011,78041,78070,78099,78129,78158,78188,78217,78247,78277,78307,78336,78366,78395,78425,78454,78483,78513,78542,78572,78601,78631,78661,78690,78720,78750,78779,78808,78838,78867,78897,78926,78956,78985,79015,79044,79074,79104,79133,79163,79192,79222,79251,79281,79310,79340,79369,79399,79428,79458,79487,79517,79546,79576,79606,79635,79665,79695,79724,79753,79783,79812,79841,79871,79900,79930,79960,79990]},{\"../main\":621,\"object-assign\":499}],621:[function(t,e,r){var n=t(\"object-assign\");function i(){this.regionalOptions=[],this.regionalOptions[\"\"]={invalidCalendar:\"Calendar {0} not found\",invalidDate:\"Invalid {0} date\",invalidMonth:\"Invalid {0} month\",invalidYear:\"Invalid {0} year\",differentCalendars:\"Cannot mix {0} and {1} dates\"},this.local=this.regionalOptions[\"\"],this.calendars={},this._localCals={}}function a(t,e,r,n){if(this._calendar=t,this._year=e,this._month=r,this._day=n,0===this._calendar._validateLevel&&!this._calendar.isValid(this._year,this._month,this._day))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name)}function o(t,e){return\"000000\".substring(0,e-(t=\"\"+t).length)+t}function s(){this.shortYearCutoff=\"+10\"}function l(t){this.local=this.regionalOptions[t]||this.regionalOptions[\"\"]}n(i.prototype,{instance:function(t,e){t=(t||\"gregorian\").toLowerCase(),e=e||\"\";var r=this._localCals[t+\"-\"+e];if(!r&&this.calendars[t]&&(r=new this.calendars[t](e),this._localCals[t+\"-\"+e]=r),!r)throw(this.local.invalidCalendar||this.regionalOptions[\"\"].invalidCalendar).replace(/\\{0\\}/,t);return r},newDate:function(t,e,r,n,i){return(n=(null!=t&&t.year?t.calendar():\"string\"==typeof n?this.instance(n,i):n)||this.instance()).newDate(t,e,r)},substituteDigits:function(t){return function(e){return(e+\"\").replace(/[0-9]/g,(function(e){return t[e]}))}},substituteChineseDigits:function(t,e){return function(r){for(var n=\"\",i=0;r>0;){var a=r%10;n=(0===a?\"\":t[a]+e[i])+n,i++,r=Math.floor(r/10)}return 0===n.indexOf(t[1]+e[1])&&(n=n.substr(1)),n||t[0]}}}),n(a.prototype,{newDate:function(t,e,r){return this._calendar.newDate(null==t?this:t,e,r)},year:function(t){return 0===arguments.length?this._year:this.set(t,\"y\")},month:function(t){return 0===arguments.length?this._month:this.set(t,\"m\")},day:function(t){return 0===arguments.length?this._day:this.set(t,\"d\")},date:function(t,e,r){if(!this._calendar.isValid(t,e,r))throw(c.local.invalidDate||c.regionalOptions[\"\"].invalidDate).replace(/\\{0\\}/,this._calendar.local.name);return this._year=t,this._month=e,this._day=r,this},leapYear:function(){return this._calendar.leapYear(this)},epoch:function(){return this._calendar.epoch(this)},formatYear:function(){return this._calendar.formatYear(this)},monthOfYear:function(){return this._calendar.monthOfYear(this)},weekOfYear:function(){return this._calendar.weekOfYear(this)},daysInYear:function(){return this._calendar.daysInYear(this)},dayOfYear:function(){return this._calendar.dayOfYear(this)},daysInMonth:function(){return this._calendar.daysInMonth(this)},dayOfWeek:function(){return this._calendar.dayOfWeek(this)},weekDay:function(){return this._calendar.weekDay(this)},extraInfo:function(){return this._calendar.extraInfo(this)},add:function(t,e){return this._calendar.add(this,t,e)},set:function(t,e){return this._calendar.set(this,t,e)},compareTo:function(t){if(this._calendar.name!==t._calendar.name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this._calendar.local.name).replace(/\\{1\\}/,t._calendar.local.name);var e=this._year!==t._year?this._year-t._year:this._month!==t._month?this.monthOfYear()-t.monthOfYear():this._day-t._day;return 0===e?0:e<0?-1:1},calendar:function(){return this._calendar},toJD:function(){return this._calendar.toJD(this)},fromJD:function(t){return this._calendar.fromJD(t)},toJSDate:function(){return this._calendar.toJSDate(this)},fromJSDate:function(t){return this._calendar.fromJSDate(t)},toString:function(){return(this.year()<0?\"-\":\"\")+o(Math.abs(this.year()),4)+\"-\"+o(this.month(),2)+\"-\"+o(this.day(),2)}}),n(s.prototype,{_validateLevel:0,newDate:function(t,e,r){return null==t?this.today():(t.year&&(this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),r=t.day(),e=t.month(),t=t.year()),new a(this,t,e,r))},today:function(){return this.fromJSDate(new Date)},epoch:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear).year()<0?this.local.epochs[0]:this.local.epochs[1]},formatYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(e.year()<0?\"-\":\"\")+o(Math.abs(e.year()),4)},monthsInYear:function(t){return this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear),12},monthOfYear:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return(r.month()+this.monthsInYear(r)-this.firstMonth)%this.monthsInYear(r)+this.minMonth},fromMonthOfYear:function(t,e){var r=(e+this.firstMonth-2*this.minMonth)%this.monthsInYear(t)+this.minMonth;return this._validate(t,r,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth),r},daysInYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return this.leapYear(e)?366:365},dayOfYear:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return n.toJD()-this.newDate(n.year(),this.fromMonthOfYear(n.year(),this.minMonth),this.minDay).toJD()+1},daysInWeek:function(){return 7},dayOfWeek:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return(Math.floor(this.toJD(n))+2)%this.daysInWeek()},extraInfo:function(t,e,r){return this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),{}},add:function(t,e,r){return this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),this._correctAdd(t,this._add(t,e,r),e,r)},_add:function(t,e,r){if(this._validateLevel++,\"d\"===r||\"w\"===r){var n=t.toJD()+e*(\"w\"===r?this.daysInWeek():1),i=t.calendar().fromJD(n);return this._validateLevel--,[i.year(),i.month(),i.day()]}try{var a=t.year()+(\"y\"===r?e:0),o=t.monthOfYear()+(\"m\"===r?e:0);i=t.day();\"y\"===r?(t.month()!==this.fromMonthOfYear(a,o)&&(o=this.newDate(a,t.month(),this.minDay).monthOfYear()),o=Math.min(o,this.monthsInYear(a)),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o)))):\"m\"===r&&(!function(t){for(;o<t.minMonth;)a--,o+=t.monthsInYear(a);for(var e=t.monthsInYear(a);o>e-1+t.minMonth;)a++,o-=e,e=t.monthsInYear(a)}(this),i=Math.min(i,this.daysInMonth(a,this.fromMonthOfYear(a,o))));var s=[a,this.fromMonthOfYear(a,o),i];return this._validateLevel--,s}catch(t){throw this._validateLevel--,t}},_correctAdd:function(t,e,r,n){if(!(this.hasYearZero||\"y\"!==n&&\"m\"!==n||0!==e[0]&&t.year()>0==e[0]>0)){var i={y:[1,1,\"y\"],m:[1,this.monthsInYear(-1),\"m\"],w:[this.daysInWeek(),this.daysInYear(-1),\"d\"],d:[1,this.daysInYear(-1),\"d\"]}[n],a=r<0?-1:1;e=this._add(t,r*i[0]+a*i[1],i[2])}return t.date(e[0],e[1],e[2])},set:function(t,e,r){this._validate(t,this.minMonth,this.minDay,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);var n=\"y\"===r?e:t.year(),i=\"m\"===r?e:t.month(),a=\"d\"===r?e:t.day();return\"y\"!==r&&\"m\"!==r||(a=Math.min(a,this.daysInMonth(n,i))),t.date(n,i,a)},isValid:function(t,e,r){this._validateLevel++;var n=this.hasYearZero||0!==t;if(n){var i=this.newDate(t,e,this.minDay);n=e>=this.minMonth&&e-this.minMonth<this.monthsInYear(i)&&r>=this.minDay&&r-this.minDay<this.daysInMonth(i)}return this._validateLevel--,n},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);return c.instance().fromJD(this.toJD(n)).toJSDate()},fromJSDate:function(t){return this.fromJD(c.instance().fromJSDate(t).toJD())},_validate:function(t,e,r,n){if(t.year){if(0===this._validateLevel&&this.name!==t.calendar().name)throw(c.local.differentCalendars||c.regionalOptions[\"\"].differentCalendars).replace(/\\{0\\}/,this.local.name).replace(/\\{1\\}/,t.calendar().local.name);return t}try{if(this._validateLevel++,1===this._validateLevel&&!this.isValid(t,e,r))throw n.replace(/\\{0\\}/,this.local.name);var i=this.newDate(t,e,r);return this._validateLevel--,i}catch(t){throw this._validateLevel--,t}}}),l.prototype=new s,n(l.prototype,{name:\"Gregorian\",jdEpoch:1721425.5,daysPerMonth:[31,28,31,30,31,30,31,31,30,31,30,31],hasYearZero:!1,minMonth:1,firstMonth:1,minDay:1,regionalOptions:{\"\":{name:\"Gregorian\",epochs:[\"BCE\",\"CE\"],monthNames:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],monthNamesShort:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],dayNames:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],dayNamesShort:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],dayNamesMin:[\"Su\",\"Mo\",\"Tu\",\"We\",\"Th\",\"Fr\",\"Sa\"],digits:null,dateFormat:\"mm/dd/yyyy\",firstDay:0,isRTL:!1}},leapYear:function(t){var e=this._validate(t,this.minMonth,this.minDay,c.local.invalidYear||c.regionalOptions[\"\"].invalidYear);return(t=e.year()+(e.year()<0?1:0))%4==0&&(t%100!=0||t%400==0)},weekOfYear:function(t,e,r){var n=this.newDate(t,e,r);return n.add(4-(n.dayOfWeek()||7),\"d\"),Math.floor((n.dayOfYear()-1)/7)+1},daysInMonth:function(t,e){var r=this._validate(t,e,this.minDay,c.local.invalidMonth||c.regionalOptions[\"\"].invalidMonth);return this.daysPerMonth[r.month()-1]+(2===r.month()&&this.leapYear(r.year())?1:0)},weekDay:function(t,e,r){return(this.dayOfWeek(t,e,r)||7)<6},toJD:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate);t=n.year(),e=n.month(),r=n.day(),t<0&&t++,e<3&&(e+=12,t--);var i=Math.floor(t/100),a=2-i+Math.floor(i/4);return Math.floor(365.25*(t+4716))+Math.floor(30.6001*(e+1))+r+a-1524.5},fromJD:function(t){var e=Math.floor(t+.5),r=Math.floor((e-1867216.25)/36524.25),n=(r=e+1+r-Math.floor(r/4))+1524,i=Math.floor((n-122.1)/365.25),a=Math.floor(365.25*i),o=Math.floor((n-a)/30.6001),s=n-a-Math.floor(30.6001*o),l=o-(o>13.5?13:1),c=i-(l>2.5?4716:4715);return c<=0&&c--,this.newDate(c,l,s)},toJSDate:function(t,e,r){var n=this._validate(t,e,r,c.local.invalidDate||c.regionalOptions[\"\"].invalidDate),i=new Date(n.year(),n.month()-1,n.day());return i.setHours(0),i.setMinutes(0),i.setSeconds(0),i.setMilliseconds(0),i.setHours(i.getHours()>12?i.getHours()+2:0),i},fromJSDate:function(t){return this.newDate(t.getFullYear(),t.getMonth()+1,t.getDate())}});var c=e.exports=new i;c.cdate=a,c.baseCalendar=s,c.calendars.gregorian=l},{\"object-assign\":499}],622:[function(t,e,r){var n=t(\"object-assign\"),i=t(\"./main\");n(i.regionalOptions[\"\"],{invalidArguments:\"Invalid arguments\",invalidFormat:\"Cannot format a date from another calendar\",missingNumberAt:\"Missing number at position {0}\",unknownNameAt:\"Unknown name at position {0}\",unexpectedLiteralAt:\"Unexpected literal at position {0}\",unexpectedText:\"Additional text found at end\"}),i.local=i.regionalOptions[\"\"],n(i.cdate.prototype,{formatDate:function(t,e){return\"string\"!=typeof t&&(e=t,t=\"\"),this._calendar.formatDate(t||\"\",this,e)}}),n(i.baseCalendar.prototype,{UNIX_EPOCH:i.instance().newDate(1970,1,1).toJD(),SECS_PER_DAY:86400,TICKS_EPOCH:i.instance().jdEpoch,TICKS_PER_DAY:864e9,ATOM:\"yyyy-mm-dd\",COOKIE:\"D, dd M yyyy\",FULL:\"DD, MM d, yyyy\",ISO_8601:\"yyyy-mm-dd\",JULIAN:\"J\",RFC_822:\"D, d M yy\",RFC_850:\"DD, dd-M-yy\",RFC_1036:\"D, d M yy\",RFC_1123:\"D, d M yyyy\",RFC_2822:\"D, d M yyyy\",RSS:\"D, d M yy\",TICKS:\"!\",TIMESTAMP:\"@\",W3C:\"yyyy-mm-dd\",formatDate:function(t,e,r){if(\"string\"!=typeof t&&(r=e,e=t,t=\"\"),!e)return\"\";if(e.calendar()!==this)throw i.local.invalidFormat||i.regionalOptions[\"\"].invalidFormat;t=t||this.local.dateFormat;for(var n,a,o,s,l=(r=r||{}).dayNamesShort||this.local.dayNamesShort,c=r.dayNames||this.local.dayNames,u=r.monthNumbers||this.local.monthNumbers,f=r.monthNamesShort||this.local.monthNamesShort,h=r.monthNames||this.local.monthNames,p=(r.calculateWeek||this.local.calculateWeek,function(e,r){for(var n=1;w+n<t.length&&t.charAt(w+n)===e;)n++;return w+=n-1,Math.floor(n/(r||1))>1}),d=function(t,e,r,n){var i=\"\"+e;if(p(t,n))for(;i.length<r;)i=\"0\"+i;return i},g=this,m=function(t){return\"function\"==typeof u?u.call(g,t,p(\"m\")):x(d(\"m\",t.month(),2))},v=function(t,e){return e?\"function\"==typeof h?h.call(g,t):h[t.month()-g.minMonth]:\"function\"==typeof f?f.call(g,t):f[t.month()-g.minMonth]},y=this.local.digits,x=function(t){return r.localNumbers&&y?y(t):t},b=\"\",_=!1,w=0;w<t.length;w++)if(_)\"'\"!==t.charAt(w)||p(\"'\")?b+=t.charAt(w):_=!1;else switch(t.charAt(w)){case\"d\":b+=x(d(\"d\",e.day(),2));break;case\"D\":b+=(n=\"D\",a=e.dayOfWeek(),o=l,s=c,p(n)?s[a]:o[a]);break;case\"o\":b+=d(\"o\",e.dayOfYear(),3);break;case\"w\":b+=d(\"w\",e.weekOfYear(),2);break;case\"m\":b+=m(e);break;case\"M\":b+=v(e,p(\"M\"));break;case\"y\":b+=p(\"y\",2)?e.year():(e.year()%100<10?\"0\":\"\")+e.year()%100;break;case\"Y\":p(\"Y\",2),b+=e.formatYear();break;case\"J\":b+=e.toJD();break;case\"@\":b+=(e.toJD()-this.UNIX_EPOCH)*this.SECS_PER_DAY;break;case\"!\":b+=(e.toJD()-this.TICKS_EPOCH)*this.TICKS_PER_DAY;break;case\"'\":p(\"'\")?b+=\"'\":_=!0;break;default:b+=t.charAt(w)}return b},parseDate:function(t,e,r){if(null==e)throw i.local.invalidArguments||i.regionalOptions[\"\"].invalidArguments;if(\"\"===(e=\"object\"==typeof e?e.toString():e+\"\"))return null;t=t||this.local.dateFormat;var n=(r=r||{}).shortYearCutoff||this.shortYearCutoff;n=\"string\"!=typeof n?n:this.today().year()%100+parseInt(n,10);for(var a=r.dayNamesShort||this.local.dayNamesShort,o=r.dayNames||this.local.dayNames,s=r.parseMonth||this.local.parseMonth,l=r.monthNumbers||this.local.monthNumbers,c=r.monthNamesShort||this.local.monthNamesShort,u=r.monthNames||this.local.monthNames,f=-1,h=-1,p=-1,d=-1,g=-1,m=!1,v=!1,y=function(e,r){for(var n=1;A+n<t.length&&t.charAt(A+n)===e;)n++;return A+=n-1,Math.floor(n/(r||1))>1},x=function(t,r){var n=y(t,r),a=[2,3,n?4:2,n?4:2,10,11,20][\"oyYJ@!\".indexOf(t)+1],o=new RegExp(\"^-?\\\\d{1,\"+a+\"}\"),s=e.substring(M).match(o);if(!s)throw(i.local.missingNumberAt||i.regionalOptions[\"\"].missingNumberAt).replace(/\\{0\\}/,M);return M+=s[0].length,parseInt(s[0],10)},b=this,_=function(){if(\"function\"==typeof l){y(\"m\");var t=l.call(b,e.substring(M));return M+=t.length,t}return x(\"m\")},w=function(t,r,n,a){for(var o=y(t,a)?n:r,s=0;s<o.length;s++)if(e.substr(M,o[s].length).toLowerCase()===o[s].toLowerCase())return M+=o[s].length,s+b.minMonth;throw(i.local.unknownNameAt||i.regionalOptions[\"\"].unknownNameAt).replace(/\\{0\\}/,M)},T=function(){if(\"function\"==typeof u){var t=y(\"M\")?u.call(b,e.substring(M)):c.call(b,e.substring(M));return M+=t.length,t}return w(\"M\",c,u)},k=function(){if(e.charAt(M)!==t.charAt(A))throw(i.local.unexpectedLiteralAt||i.regionalOptions[\"\"].unexpectedLiteralAt).replace(/\\{0\\}/,M);M++},M=0,A=0;A<t.length;A++)if(v)\"'\"!==t.charAt(A)||y(\"'\")?k():v=!1;else switch(t.charAt(A)){case\"d\":d=x(\"d\");break;case\"D\":w(\"D\",a,o);break;case\"o\":g=x(\"o\");break;case\"w\":x(\"w\");break;case\"m\":p=_();break;case\"M\":p=T();break;case\"y\":var S=A;m=!y(\"y\",2),A=S,h=x(\"y\",2);break;case\"Y\":h=x(\"Y\",2);break;case\"J\":f=x(\"J\")+.5,\".\"===e.charAt(M)&&(M++,x(\"J\"));break;case\"@\":f=x(\"@\")/this.SECS_PER_DAY+this.UNIX_EPOCH;break;case\"!\":f=x(\"!\")/this.TICKS_PER_DAY+this.TICKS_EPOCH;break;case\"*\":M=e.length;break;case\"'\":y(\"'\")?k():v=!0;break;default:k()}if(M<e.length)throw i.local.unexpectedText||i.regionalOptions[\"\"].unexpectedText;if(-1===h?h=this.today().year():h<100&&m&&(h+=-1===n?1900:this.today().year()-this.today().year()%100-(h<=n?0:100)),\"string\"==typeof p&&(p=s.call(this,h,p)),g>-1){p=1,d=g;for(var E=this.daysInMonth(h,p);d>E;E=this.daysInMonth(h,p))p++,d-=E}return f>-1?this.fromJD(f):this.newDate(h,p,d)},determineDate:function(t,e,r,n,i){r&&\"object\"!=typeof r&&(i=n,n=r,r=null),\"string\"!=typeof n&&(i=n,n=\"\");var a=this;return e=e?e.newDate():null,t=null==t?e:\"string\"==typeof t?function(t){try{return a.parseDate(n,t,i)}catch(t){}for(var e=((t=t.toLowerCase()).match(/^c/)&&r?r.newDate():null)||a.today(),o=/([+-]?[0-9]+)\\s*(d|w|m|y)?/g,s=o.exec(t);s;)e.add(parseInt(s[1],10),s[2]||\"d\"),s=o.exec(t);return e}(t):\"number\"==typeof t?isNaN(t)||t===1/0||t===-1/0?e:a.today().add(t,\"d\"):a.newDate(t)}})},{\"./main\":621,\"object-assign\":499}],623:[function(t,e,r){e.exports=t(\"cwise-compiler\")({args:[\"array\",{offset:[1],array:0},\"scalar\",\"scalar\",\"index\"],pre:{body:\"{}\",args:[],thisVars:[],localVars:[]},post:{body:\"{}\",args:[],thisVars:[],localVars:[]},body:{body:\"{\\n        var _inline_1_da = _inline_1_arg0_ - _inline_1_arg3_\\n        var _inline_1_db = _inline_1_arg1_ - _inline_1_arg3_\\n        if((_inline_1_da >= 0) !== (_inline_1_db >= 0)) {\\n          _inline_1_arg2_.push(_inline_1_arg4_[0] + 0.5 + 0.5 * (_inline_1_da + _inline_1_db) / (_inline_1_da - _inline_1_db))\\n        }\\n      }\",args:[{name:\"_inline_1_arg0_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg1_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg2_\",lvalue:!1,rvalue:!0,count:1},{name:\"_inline_1_arg3_\",lvalue:!1,rvalue:!0,count:2},{name:\"_inline_1_arg4_\",lvalue:!1,rvalue:!0,count:1}],thisVars:[],localVars:[\"_inline_1_da\",\"_inline_1_db\"]},funcName:\"zeroCrossings\"})},{\"cwise-compiler\":151}],624:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r=[];return e=+e||0,n(t.hi(t.shape[0]-1),r,e),r};var n=t(\"./lib/zc-core\")},{\"./lib/zc-core\":623}],625:[function(t,e,r){\"use strict\";e.exports=[{path:\"\",backoff:0},{path:\"M-2.4,-3V3L0.6,0Z\",backoff:.6},{path:\"M-3.7,-2.5V2.5L1.3,0Z\",backoff:1.3},{path:\"M-4.45,-3L-1.65,-0.2V0.2L-4.45,3L1.55,0Z\",backoff:1.55},{path:\"M-2.2,-2.2L-0.2,-0.2V0.2L-2.2,2.2L-1.4,3L1.6,0L-1.4,-3Z\",backoff:1.6},{path:\"M-4.4,-2.1L-0.6,-0.2V0.2L-4.4,2.1L-4,3L2,0L-4,-3Z\",backoff:2},{path:\"M2,0A2,2 0 1,1 0,-2A2,2 0 0,1 2,0Z\",backoff:0,noRotate:!0},{path:\"M2,2V-2H-2V2Z\",backoff:0,noRotate:!0}]},{}],626:[function(t,e,r){\"use strict\";var n=t(\"./arrow_paths\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../plots/cartesian/constants\"),o=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=o(\"annotation\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},text:{valType:\"string\",editType:\"calc+arraydraw\"},textangle:{valType:\"angle\",dflt:0,editType:\"calc+arraydraw\"},font:i({editType:\"calc+arraydraw\",colorEditType:\"arraydraw\"}),width:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},height:{valType:\"number\",min:1,dflt:null,editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"center\",editType:\"arraydraw\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"arraydraw\"},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},borderpad:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc+arraydraw\"},showarrow:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},arrowcolor:{valType:\"color\",editType:\"arraydraw\"},arrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},startarrowhead:{valType:\"integer\",min:0,max:n.length,dflt:1,editType:\"arraydraw\"},arrowside:{valType:\"flaglist\",flags:[\"end\",\"start\"],extras:[\"none\"],dflt:\"end\",editType:\"arraydraw\"},arrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},startarrowsize:{valType:\"number\",min:.3,dflt:1,editType:\"calc+arraydraw\"},arrowwidth:{valType:\"number\",min:.1,editType:\"calc+arraydraw\"},standoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},startstandoff:{valType:\"number\",min:0,dflt:0,editType:\"calc+arraydraw\"},ax:{valType:\"any\",editType:\"calc+arraydraw\"},ay:{valType:\"any\",editType:\"calc+arraydraw\"},axref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.x.toString()],editType:\"calc\"},ayref:{valType:\"enumerated\",dflt:\"pixel\",values:[\"pixel\",a.idRegex.y.toString()],editType:\"calc\"},xref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.x.toString()],editType:\"calc\"},x:{valType:\"any\",editType:\"calc+arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"auto\",editType:\"calc+arraydraw\"},xshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",a.idRegex.y.toString()],editType:\"calc\"},y:{valType:\"any\",editType:\"calc+arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"auto\",editType:\"calc+arraydraw\"},yshift:{valType:\"number\",dflt:0,editType:\"calc+arraydraw\"},clicktoshow:{valType:\"enumerated\",values:[!1,\"onoff\",\"onout\"],dflt:!1,editType:\"arraydraw\"},xclick:{valType:\"any\",editType:\"arraydraw\"},yclick:{valType:\"any\",editType:\"arraydraw\"},hovertext:{valType:\"string\",editType:\"arraydraw\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"arraydraw\"},bordercolor:{valType:\"color\",editType:\"arraydraw\"},font:i({editType:\"arraydraw\"}),editType:\"arraydraw\"},captureevents:{valType:\"boolean\",editType:\"arraydraw\"},editType:\"calc\",_deprecated:{ref:{valType:\"string\",editType:\"calc\"}}})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/font_attributes\":856,\"./arrow_paths\":625}],627:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./draw\").draw;function o(t){var e=t._fullLayout;n.filterVisible(e.annotations).forEach((function(e){var r=i.getFromId(t,e.xref),n=i.getFromId(t,e.yref),a=i.getRefType(e.xref),o=i.getRefType(e.yref);e._extremes={},\"range\"===a&&s(e,r),\"range\"===o&&s(e,n)}))}function s(t,e){var r,n=e._id,a=n.charAt(0),o=t[a],s=t[\"a\"+a],l=t[a+\"ref\"],c=t[\"a\"+a+\"ref\"],u=t[\"_\"+a+\"padplus\"],f=t[\"_\"+a+\"padminus\"],h={x:1,y:-1}[a]*t[a+\"shift\"],p=3*t.arrowsize*t.arrowwidth||0,d=p+h,g=p-h,m=3*t.startarrowsize*t.arrowwidth||0,v=m+h,y=m-h;if(c===l){var x=i.findExtremes(e,[e.r2c(o)],{ppadplus:d,ppadminus:g}),b=i.findExtremes(e,[e.r2c(s)],{ppadplus:Math.max(u,v),ppadminus:Math.max(f,y)});r={min:[x.min[0],b.min[0]],max:[x.max[0],b.max[0]]}}else v=s?v+s:v,y=s?y-s:y,r=i.findExtremes(e,[e.r2c(o)],{ppadplus:Math.max(u,d,v),ppadminus:Math.max(f,g,y)});t._extremes[n]=r}e.exports=function(t){var e=t._fullLayout;if(n.filterVisible(e.annotations).length&&t._fullData.length)return n.syncOrAsync([a,o],t)}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./draw\":632}],628:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../plot_api/plot_template\").arrayEditor;function o(t,e){var r,n,i,a,o,l,c,u=t._fullLayout.annotations,f=[],h=[],p=[],d=(e||[]).length;for(r=0;r<u.length;r++)if(a=(i=u[r]).clicktoshow){for(n=0;n<d;n++)if(l=(o=e[n]).xaxis,c=o.yaxis,l._id===i.xref&&c._id===i.yref&&l.d2r(o.x)===s(i._xclick,l)&&c.d2r(o.y)===s(i._yclick,c)){(i.visible?\"onout\"===a?h:p:f).push(r);break}n===d&&i.visible&&\"onout\"===a&&h.push(r)}return{on:f,off:h,explicitOff:p}}function s(t,e){return\"log\"===e.type?e.l2r(t):e.d2r(t)}e.exports={hasClickToShow:function(t,e){var r=o(t,e);return r.on.length>0||r.explicitOff.length>0},onClick:function(t,e){var r,s,l=o(t,e),c=l.on,u=l.off.concat(l.explicitOff),f={},h=t._fullLayout.annotations;if(!c.length&&!u.length)return;for(r=0;r<c.length;r++)(s=a(t.layout,\"annotations\",h[c[r]])).modifyItem(\"visible\",!0),n.extendFlat(f,s.getUpdateObj());for(r=0;r<u.length;r++)(s=a(t.layout,\"annotations\",h[u[r]])).modifyItem(\"visible\",!1),n.extendFlat(f,s.getUpdateObj());return i.call(\"update\",t,{},f)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911}],629:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\");e.exports=function(t,e,r,a){a(\"opacity\");var o=a(\"bgcolor\"),s=a(\"bordercolor\"),l=i.opacity(s);a(\"borderpad\");var c=a(\"borderwidth\"),u=a(\"showarrow\");if(a(\"text\",u?\" \":r._dfltTitle.annotation),a(\"textangle\"),n.coerceFont(a,\"font\",r.font),a(\"width\"),a(\"align\"),a(\"height\")&&a(\"valign\"),u){var f,h,p=a(\"arrowside\");-1!==p.indexOf(\"end\")&&(f=a(\"arrowhead\"),h=a(\"arrowsize\")),-1!==p.indexOf(\"start\")&&(a(\"startarrowhead\",f),a(\"startarrowsize\",h)),a(\"arrowcolor\",l?e.bordercolor:i.defaultLine),a(\"arrowwidth\",2*(l&&c||1)),a(\"standoff\"),a(\"startstandoff\")}var d=a(\"hovertext\"),g=r.hoverlabel||{};if(d){var m=a(\"hoverlabel.bgcolor\",g.bgcolor||(i.opacity(o)?i.rgb(o):i.defaultLine)),v=a(\"hoverlabel.bordercolor\",g.bordercolor||i.contrast(m));n.coerceFont(a,\"hoverlabel.font\",{family:g.font.family,size:g.font.size,color:g.font.color||v})}a(\"captureevents\",!!d)}},{\"../../lib\":778,\"../color\":643}],630:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.annotations,f=e._id.charAt(0),h=0;h<u.length;h++)l=u[h],c=\"annotations[\"+h+\"].\",l[f+\"ref\"]===e._id&&p(f),l[\"a\"+f+\"ref\"]===e._id&&p(\"a\"+f);function p(t){var r=l[t],s=null;s=o?i(r,e.range):Math.pow(10,r),n(s)||(s=null),a(c+t,s)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],631:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./common_defaults\"),s=t(\"./attributes\");function l(t,e,r){function a(r,i){return n.coerce(t,e,s,r,i)}var l=a(\"visible\"),c=a(\"clicktoshow\");if(l||c){o(t,e,r,a);for(var u=e.showarrow,f=[\"x\",\"y\"],h=[-10,-30],p={_fullLayout:r},d=0;d<2;d++){var g=f[d],m=i.coerceRef(t,e,p,g,\"\",\"paper\");if(\"paper\"!==m)i.getFromId(p,m)._annIndices.push(e._index);if(i.coercePosition(e,p,a,m,g,.5),u){var v=\"a\"+g,y=i.coerceRef(t,e,p,v,\"pixel\",[\"pixel\",\"paper\"]);\"pixel\"!==y&&y!==m&&(y=e[v]=\"pixel\");var x=\"pixel\"===y?h[d]:.4;i.coercePosition(e,p,a,y,v,x)}a(g+\"anchor\"),a(g+\"shift\")}if(n.noneOrAll(t,e,[\"x\",\"y\"]),u&&n.noneOrAll(t,e,[\"ax\",\"ay\"]),c){var b=a(\"xclick\"),_=a(\"yclick\");e._xclick=void 0===b?e.x:i.cleanPosition(b,p,e.xref),e._yclick=void 0===_?e.y:i.cleanPosition(_,p,e.yref)}}}e.exports=function(t,e){a(t,e,{name:\"annotations\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":626,\"./common_defaults\":629}],632:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../plots/cartesian/axes\"),c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../fx\"),h=t(\"../../lib/svg_text_utils\"),p=t(\"../../lib/setcursor\"),d=t(\"../dragelement\"),g=t(\"../../plot_api/plot_template\").arrayEditor,m=t(\"./draw_arrow_head\");function v(t,e){var r=t._fullLayout.annotations[e]||{},n=l.getFromId(t,r.xref),i=l.getFromId(t,r.yref);n&&n.setScale(),i&&i.setScale(),x(t,r,e,!1,n,i)}function y(t,e,r,n,i){var a=i[r],o=i[r+\"ref\"],s=-1!==r.indexOf(\"y\"),c=\"domain\"===l.getRefType(o),u=s?n.h:n.w;return t?c?a+(s?-e:e)/t._length:t.p2r(t.r2p(a)+e):a+(s?-e:e)/u}function x(t,e,r,a,v,x){var b,_,w=t._fullLayout,T=t._fullLayout._size,k=t._context.edits;a?(b=\"annotation-\"+a,_=a+\".annotations\"):(b=\"annotation\",_=\"annotations\");var M=g(t.layout,_,e),A=M.modifyBase,S=M.modifyItem,E=M.getUpdateObj;w._infolayer.selectAll(\".\"+b+'[data-index=\"'+r+'\"]').remove();var C=\"clip\"+w._uid+\"_ann\"+r;if(e._input&&!1!==e.visible){var L={x:{},y:{}},I=+e.textangle||0,P=w._infolayer.append(\"g\").classed(b,!0).attr(\"data-index\",String(r)).style(\"opacity\",e.opacity),z=P.append(\"g\").classed(\"annotation-text-g\",!0),O=k[e.showarrow?\"annotationTail\":\"annotationPosition\"],D=e.captureevents||k.annotationText||O,R=z.append(\"g\").style(\"pointer-events\",D?\"all\":null).call(p,\"pointer\").on(\"click\",(function(){t._dragging=!1,t.emit(\"plotly_clickannotation\",Y(n.event))}));e.hovertext&&R.on(\"mouseover\",(function(){var r=e.hoverlabel,n=r.font,i=this.getBoundingClientRect(),a=t.getBoundingClientRect();f.loneHover({x0:i.left-a.left,x1:i.right-a.left,y:(i.top+i.bottom)/2-a.top,text:e.hovertext,color:r.bgcolor,borderColor:r.bordercolor,fontFamily:n.family,fontSize:n.size,fontColor:n.color},{container:w._hoverlayer.node(),outerContainer:w._paper.node(),gd:t})})).on(\"mouseout\",(function(){f.loneUnhover(w._hoverlayer.node())}));var F=e.borderwidth,B=e.borderpad,N=F+B,j=R.append(\"rect\").attr(\"class\",\"bg\").style(\"stroke-width\",F+\"px\").call(c.stroke,e.bordercolor).call(c.fill,e.bgcolor),U=e.width||e.height,V=w._topclips.selectAll(\"#\"+C).data(U?[0]:[]);V.enter().append(\"clipPath\").classed(\"annclip\",!0).attr(\"id\",C).append(\"rect\"),V.exit().remove();var q=e.font,H=w._meta?o.templateString(e.text,w._meta):e.text,G=R.append(\"text\").classed(\"annotation-text\",!0).text(H);k.annotationText?G.call(h.makeEditable,{delegate:R,gd:t}).call(W).on(\"edit\",(function(r){e.text=r,this.call(W),S(\"text\",r),v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0),i.call(\"_guiRelayout\",t,E())})):G.call(W)}else n.selectAll(\"#\"+C).remove();function Y(t){var n={index:r,annotation:e._input,fullAnnotation:e,event:t};return a&&(n.subplotId=a),n}function W(r){return r.call(u.font,q).attr({\"text-anchor\":{left:\"start\",right:\"end\"}[e.align]||\"middle\"}),h.convertToTspans(r,t,X),r}function X(){var r=G.selectAll(\"a\");1===r.size()&&r.text()===G.text()&&R.insert(\"a\",\":first-child\").attr({\"xlink:xlink:href\":r.attr(\"xlink:href\"),\"xlink:xlink:show\":r.attr(\"xlink:show\")}).style({cursor:\"pointer\"}).node().appendChild(j.node());var n=R.select(\".annotation-text-math-group\"),f=!n.empty(),g=u.bBox((f?n:G).node()),b=g.width,_=g.height,M=e.width||b,D=e.height||_,B=Math.round(M+2*N),q=Math.round(D+2*N);function H(t,e){return\"auto\"===e&&(e=t<1/3?\"left\":t>2/3?\"right\":\"center\"),{center:0,middle:0,left:.5,bottom:-.5,right:-.5,top:.5}[e]}for(var W=!1,X=[\"x\",\"y\"],Z=0;Z<X.length;Z++){var J,K,Q,$,tt,et=X[Z],rt=e[et+\"ref\"]||et,nt=e[\"a\"+et+\"ref\"],it={x:v,y:x}[et],at=(I+(\"x\"===et?0:-90))*Math.PI/180,ot=B*Math.cos(at),st=q*Math.sin(at),lt=Math.abs(ot)+Math.abs(st),ct=e[et+\"anchor\"],ut=e[et+\"shift\"]*(\"x\"===et?1:-1),ft=L[et],ht=l.getRefType(rt);if(it&&\"domain\"!==ht){var pt=it.r2fraction(e[et]);(pt<0||pt>1)&&(nt===rt?((pt=it.r2fraction(e[\"a\"+et]))<0||pt>1)&&(W=!0):W=!0),J=it._offset+it.r2p(e[et]),$=.5}else{var dt=\"domain\"===ht;\"x\"===et?(Q=e[et],J=dt?it._offset+it._length*Q:J=T.l+T.w*Q):(Q=1-e[et],J=dt?it._offset+it._length*Q:J=T.t+T.h*Q),$=e.showarrow?.5:Q}if(e.showarrow){ft.head=J;var gt=e[\"a\"+et];if(tt=ot*H(.5,e.xanchor)-st*H(.5,e.yanchor),nt===rt){var mt=l.getRefType(nt);\"domain\"===mt?(\"y\"===et&&(gt=1-gt),ft.tail=it._offset+it._length*gt):\"paper\"===mt?\"y\"===et?(gt=1-gt,ft.tail=T.t+T.h*gt):ft.tail=T.l+T.w*gt:ft.tail=it._offset+it.r2p(gt),K=tt}else ft.tail=J+gt,K=tt+gt;ft.text=ft.tail+tt;var vt=w[\"x\"===et?\"width\":\"height\"];if(\"paper\"===rt&&(ft.head=o.constrain(ft.head,1,vt-1)),\"pixel\"===nt){var yt=-Math.max(ft.tail-3,ft.text),xt=Math.min(ft.tail+3,ft.text)-vt;yt>0?(ft.tail+=yt,ft.text+=yt):xt>0&&(ft.tail-=xt,ft.text-=xt)}ft.tail+=ut,ft.head+=ut}else K=tt=lt*H($,ct),ft.text=J+tt;ft.text+=ut,tt+=ut,K+=ut,e[\"_\"+et+\"padplus\"]=lt/2+K,e[\"_\"+et+\"padminus\"]=lt/2-K,e[\"_\"+et+\"size\"]=lt,e[\"_\"+et+\"shift\"]=tt}if(W)R.remove();else{var bt=0,_t=0;if(\"left\"!==e.align&&(bt=(M-b)*(\"center\"===e.align?.5:1)),\"top\"!==e.valign&&(_t=(D-_)*(\"middle\"===e.valign?.5:1)),f)n.select(\"svg\").attr({x:N+bt-1,y:N+_t}).call(u.setClipUrl,U?C:null,t);else{var wt=N+_t-g.top,Tt=N+bt-g.left;G.call(h.positionText,Tt,wt).call(u.setClipUrl,U?C:null,t)}V.select(\"rect\").call(u.setRect,N,N,M,D),j.call(u.setRect,F/2,F/2,B-F,q-F),R.call(u.setTranslate,Math.round(L.x.text-B/2),Math.round(L.y.text-q/2)),z.attr({transform:\"rotate(\"+I+\",\"+L.x.text+\",\"+L.y.text+\")\"});var kt,Mt=function(r,n){P.selectAll(\".annotation-arrow-g\").remove();var l=L.x.head,f=L.y.head,h=L.x.tail+r,p=L.y.tail+n,g=L.x.text+r,b=L.y.text+n,_=o.rotationXYMatrix(I,g,b),w=o.apply2DTransform(_),M=o.apply2DTransform2(_),C=+j.attr(\"width\"),O=+j.attr(\"height\"),D=g-.5*C,F=D+C,B=b-.5*O,N=B+O,U=[[D,B,D,N],[D,N,F,N],[F,N,F,B],[F,B,D,B]].map(M);if(!U.reduce((function(t,e){return t^!!o.segmentsIntersect(l,f,l+1e6,f+1e6,e[0],e[1],e[2],e[3])}),!1)){U.forEach((function(t){var e=o.segmentsIntersect(h,p,l,f,t[0],t[1],t[2],t[3]);e&&(h=e.x,p=e.y)}));var V=e.arrowwidth,q=e.arrowcolor,H=e.arrowside,G=P.append(\"g\").style({opacity:c.opacity(q)}).classed(\"annotation-arrow-g\",!0),Y=G.append(\"path\").attr(\"d\",\"M\"+h+\",\"+p+\"L\"+l+\",\"+f).style(\"stroke-width\",V+\"px\").call(c.stroke,c.rgb(q));if(m(Y,H,e),k.annotationPosition&&Y.node().parentNode&&!a){var W=l,X=f;if(e.standoff){var Z=Math.sqrt(Math.pow(l-h,2)+Math.pow(f-p,2));W+=e.standoff*(h-l)/Z,X+=e.standoff*(p-f)/Z}var J,K,Q=G.append(\"path\").classed(\"annotation-arrow\",!0).classed(\"anndrag\",!0).classed(\"cursor-move\",!0).attr({d:\"M3,3H-3V-3H3ZM0,0L\"+(h-W)+\",\"+(p-X),transform:s(W,X)}).style(\"stroke-width\",V+6+\"px\").call(c.stroke,\"rgba(0,0,0,0)\").call(c.fill,\"rgba(0,0,0,0)\");d.init({element:Q.node(),gd:t,prepFn:function(){var t=u.getTranslate(R);J=t.x,K=t.y,v&&v.autorange&&A(v._name+\".autorange\",!0),x&&x.autorange&&A(x._name+\".autorange\",!0)},moveFn:function(t,r){var n=w(J,K),i=n[0]+t,a=n[1]+r;R.call(u.setTranslate,i,a),S(\"x\",y(v,t,\"x\",T,e)),S(\"y\",y(x,r,\"y\",T,e)),e.axref===e.xref&&S(\"ax\",y(v,t,\"ax\",T,e)),e.ayref===e.yref&&S(\"ay\",y(x,r,\"ay\",T,e)),G.attr(\"transform\",s(t,r)),z.attr({transform:\"rotate(\"+I+\",\"+i+\",\"+a+\")\"})},doneFn:function(){i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}};if(e.showarrow&&Mt(0,0),O)d.init({element:R.node(),gd:t,prepFn:function(){kt=z.attr(\"transform\")},moveFn:function(t,r){var n=\"pointer\";if(e.showarrow)e.axref===e.xref?S(\"ax\",y(v,t,\"ax\",T,e)):S(\"ax\",e.ax+t),e.ayref===e.yref?S(\"ay\",y(x,r,\"ay\",T.w,e)):S(\"ay\",e.ay+r),Mt(t,r);else{if(a)return;var i,o;if(v)i=y(v,t,\"x\",T,e);else{var l=e._xsize/T.w,c=e.x+(e._xshift-e.xshift)/T.w-l/2;i=d.align(c+t/T.w,l,0,1,e.xanchor)}if(x)o=y(x,r,\"y\",T,e);else{var u=e._ysize/T.h,f=e.y-(e._yshift+e.yshift)/T.h-u/2;o=d.align(f-r/T.h,u,0,1,e.yanchor)}S(\"x\",i),S(\"y\",o),v&&x||(n=d.getCursor(v?.5:i,x?.5:o,e.xanchor,e.yanchor))}z.attr({transform:s(t,r)+kt}),p(R,n)},clickFn:function(r,n){e.captureevents&&t.emit(\"plotly_clickannotation\",Y(n))},doneFn:function(){p(R),i.call(\"_guiRelayout\",t,E());var e=document.querySelector(\".js-notes-box-panel\");e&&e.redraw(e.selectedObj)}})}}}e.exports={draw:function(t){var e=t._fullLayout;e._infolayer.selectAll(\".annotation\").remove();for(var r=0;r<e.annotations.length;r++)e.annotations[r].visible&&v(t,r);return a.previousPromises(t)},drawOne:v,drawRaw:x}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../fx\":683,\"./draw_arrow_head\":633,d3:169}],633:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\"),a=t(\"./arrow_paths\"),o=t(\"../../lib\"),s=o.strScale,l=o.strRotate,c=o.strTranslate;e.exports=function(t,e,r){var o,u,f,h,p=t.node(),d=a[r.arrowhead||0],g=a[r.startarrowhead||0],m=(r.arrowwidth||1)*(r.arrowsize||1),v=(r.arrowwidth||1)*(r.startarrowsize||1),y=e.indexOf(\"start\")>=0,x=e.indexOf(\"end\")>=0,b=d.backoff*m+r.standoff,_=g.backoff*v+r.startstandoff;if(\"line\"===p.nodeName){o={x:+t.attr(\"x1\"),y:+t.attr(\"y1\")},u={x:+t.attr(\"x2\"),y:+t.attr(\"y2\")};var w=o.x-u.x,T=o.y-u.y;if(h=(f=Math.atan2(T,w))+Math.PI,b&&_&&b+_>Math.sqrt(w*w+T*T))return void O();if(b){if(b*b>w*w+T*T)return void O();var k=b*Math.cos(f),M=b*Math.sin(f);u.x+=k,u.y+=M,t.attr({x2:u.x,y2:u.y})}if(_){if(_*_>w*w+T*T)return void O();var A=_*Math.cos(f),S=_*Math.sin(f);o.x-=A,o.y-=S,t.attr({x1:o.x,y1:o.y})}}else if(\"path\"===p.nodeName){var E=p.getTotalLength(),C=\"\";if(E<b+_)return void O();var L=p.getPointAtLength(0),I=p.getPointAtLength(.1);f=Math.atan2(L.y-I.y,L.x-I.x),o=p.getPointAtLength(Math.min(_,E)),C=\"0px,\"+_+\"px,\";var P=p.getPointAtLength(E),z=p.getPointAtLength(E-.1);h=Math.atan2(P.y-z.y,P.x-z.x),u=p.getPointAtLength(Math.max(0,E-b)),C+=E-(C?_+b:b)+\"px,\"+E+\"px\",t.style(\"stroke-dasharray\",C)}function O(){t.style(\"stroke-dasharray\",\"0px,100px\")}function D(e,a,o,u){e.path&&(e.noRotate&&(o=0),n.select(p.parentNode).append(\"path\").attr({class:t.attr(\"class\"),d:e.path,transform:c(a.x,a.y)+l(180*o/Math.PI)+s(u)}).style({fill:i.rgb(r.arrowcolor),\"stroke-width\":0}))}y&&D(g,o,f,v),x&&D(d,u,h,m)}},{\"../../lib\":778,\"../color\":643,\"./arrow_paths\":625,d3:169}],634:[function(t,e,r){\"use strict\";var n=t(\"./draw\"),i=t(\"./click\");e.exports={moduleType:\"component\",name:\"annotations\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"annotations\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne,drawRaw:n.drawRaw,hasClickToShow:i.hasClickToShow,onClick:i.onClick,convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":626,\"./calc_autorange\":627,\"./click\":628,\"./convert_coords\":630,\"./defaults\":631,\"./draw\":632}],635:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"../../plot_api/plot_template\").templatedArray;e.exports=i(a(\"annotation\",{visible:n.visible,x:{valType:\"any\"},y:{valType:\"any\"},z:{valType:\"any\"},ax:{valType:\"number\"},ay:{valType:\"number\"},xanchor:n.xanchor,xshift:n.xshift,yanchor:n.yanchor,yshift:n.yshift,text:n.text,textangle:n.textangle,font:n.font,width:n.width,height:n.height,opacity:n.opacity,align:n.align,valign:n.valign,bgcolor:n.bgcolor,bordercolor:n.bordercolor,borderpad:n.borderpad,borderwidth:n.borderwidth,showarrow:n.showarrow,arrowcolor:n.arrowcolor,arrowhead:n.arrowhead,startarrowhead:n.startarrowhead,arrowside:n.arrowside,arrowsize:n.arrowsize,startarrowsize:n.startarrowsize,arrowwidth:n.arrowwidth,standoff:n.standoff,startstandoff:n.startstandoff,hovertext:n.hovertext,hoverlabel:n.hoverlabel,captureevents:n.captureevents}),\"calc\",\"from-root\")},{\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../annotations/attributes\":626}],636:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");function a(t,e){var r=e.fullSceneLayout.domain,a=e.fullLayout._size,o={pdata:null,type:\"linear\",autorange:!1,range:[-1/0,1/0]};t._xa={},n.extendFlat(t._xa,o),i.setConvert(t._xa),t._xa._offset=a.l+r.x[0]*a.w,t._xa.l2p=function(){return.5*(1+t._pdata[0]/t._pdata[3])*a.w*(r.x[1]-r.x[0])},t._ya={},n.extendFlat(t._ya,o),i.setConvert(t._ya),t._ya._offset=a.t+(1-r.y[1])*a.h,t._ya.l2p=function(){return.5*(1-t._pdata[1]/t._pdata[3])*a.h*(r.y[1]-r.y[0])}}e.exports=function(t){for(var e=t.fullSceneLayout.annotations,r=0;r<e.length;r++)a(e[r],t);t.fullLayout._infolayer.selectAll(\".annotation-\"+t.id).remove()}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],637:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"../annotations/common_defaults\"),s=t(\"./attributes\");function l(t,e,r,a){function l(r,i){return n.coerce(t,e,s,r,i)}function c(t){var n=t+\"axis\",a={_fullLayout:{}};return a._fullLayout[n]=r[n],i.coercePosition(e,a,l,t,t,.5)}l(\"visible\")&&(o(t,e,a.fullLayout,l),c(\"x\"),c(\"y\"),c(\"z\"),n.noneOrAll(t,e,[\"x\",\"y\",\"z\"]),e.xref=\"x\",e.yref=\"y\",e.zref=\"z\",l(\"xanchor\"),l(\"yanchor\"),l(\"xshift\"),l(\"yshift\"),e.showarrow&&(e.axref=\"pixel\",e.ayref=\"pixel\",l(\"ax\",-10),l(\"ay\",-30),n.noneOrAll(t,e,[\"ax\",\"ay\"])))}e.exports=function(t,e,r){a(t,e,{name:\"annotations\",handleItemDefaults:l,fullLayout:r.fullLayout})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../annotations/common_defaults\":629,\"./attributes\":635}],638:[function(t,e,r){\"use strict\";var n=t(\"../annotations/draw\").drawRaw,i=t(\"../../plots/gl3d/project\"),a=[\"x\",\"y\",\"z\"];e.exports=function(t){for(var e=t.fullSceneLayout,r=t.dataScale,o=e.annotations,s=0;s<o.length;s++){for(var l=o[s],c=!1,u=0;u<3;u++){var f=a[u],h=l[f],p=e[f+\"axis\"].r2fraction(h);if(p<0||p>1){c=!0;break}}c?t.fullLayout._infolayer.select(\".annotation-\"+t.id+'[data-index=\"'+s+'\"]').remove():(l._pdata=i(t.glplot.cameraParams,[e.xaxis.r2l(l.x)*r[0],e.yaxis.r2l(l.y)*r[1],e.zaxis.r2l(l.z)*r[2]]),n(t.graphDiv,l,s,t.id,l._xa,l._ya))}}},{\"../../plots/gl3d/project\":879,\"../annotations/draw\":632}],639:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports={moduleType:\"component\",name:\"annotations3d\",schema:{subplots:{scene:{annotations:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),includeBasePlot:function(t,e){var r=n.subplotsRegistry.gl3d;if(!r)return;for(var a=r.attrRegex,o=Object.keys(t),s=0;s<o.length;s++){var l=o[s];a.test(l)&&(t[l].annotations||[]).length&&(i.pushUnique(e._basePlotModules,r),i.pushUnique(e._subplots.gl3d,l))}},convert:t(\"./convert\"),draw:t(\"./draw\")}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":635,\"./convert\":636,\"./defaults\":637,\"./draw\":638}],640:[function(t,e,r){\"use strict\";e.exports=t(\"world-calendars/dist/main\"),t(\"world-calendars/dist/plus\"),t(\"world-calendars/dist/calendars/chinese\"),t(\"world-calendars/dist/calendars/coptic\"),t(\"world-calendars/dist/calendars/discworld\"),t(\"world-calendars/dist/calendars/ethiopian\"),t(\"world-calendars/dist/calendars/hebrew\"),t(\"world-calendars/dist/calendars/islamic\"),t(\"world-calendars/dist/calendars/julian\"),t(\"world-calendars/dist/calendars/mayan\"),t(\"world-calendars/dist/calendars/nanakshahi\"),t(\"world-calendars/dist/calendars/nepali\"),t(\"world-calendars/dist/calendars/persian\"),t(\"world-calendars/dist/calendars/taiwan\"),t(\"world-calendars/dist/calendars/thai\"),t(\"world-calendars/dist/calendars/ummalqura\")},{\"world-calendars/dist/calendars/chinese\":607,\"world-calendars/dist/calendars/coptic\":608,\"world-calendars/dist/calendars/discworld\":609,\"world-calendars/dist/calendars/ethiopian\":610,\"world-calendars/dist/calendars/hebrew\":611,\"world-calendars/dist/calendars/islamic\":612,\"world-calendars/dist/calendars/julian\":613,\"world-calendars/dist/calendars/mayan\":614,\"world-calendars/dist/calendars/nanakshahi\":615,\"world-calendars/dist/calendars/nepali\":616,\"world-calendars/dist/calendars/persian\":617,\"world-calendars/dist/calendars/taiwan\":618,\"world-calendars/dist/calendars/thai\":619,\"world-calendars/dist/calendars/ummalqura\":620,\"world-calendars/dist/main\":621,\"world-calendars/dist/plus\":622}],641:[function(t,e,r){\"use strict\";var n=t(\"./calendars\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.EPOCHJD,s=a.ONEDAY,l={valType:\"enumerated\",values:Object.keys(n.calendars),editType:\"calc\",dflt:\"gregorian\"},c=function(t,e,r,n){var a={};return a[r]=l,i.coerce(t,e,a,r,n)},u={d:{0:\"dd\",\"-\":\"d\"},e:{0:\"d\",\"-\":\"d\"},a:{0:\"D\",\"-\":\"D\"},A:{0:\"DD\",\"-\":\"DD\"},j:{0:\"oo\",\"-\":\"o\"},W:{0:\"ww\",\"-\":\"w\"},m:{0:\"mm\",\"-\":\"m\"},b:{0:\"M\",\"-\":\"M\"},B:{0:\"MM\",\"-\":\"MM\"},y:{0:\"yy\",\"-\":\"yy\"},Y:{0:\"yyyy\",\"-\":\"yyyy\"},U:\"##\",w:\"##\",c:{0:\"D M d %X yyyy\",\"-\":\"D M d %X yyyy\"},x:{0:\"mm/dd/yyyy\",\"-\":\"mm/dd/yyyy\"}};var f={};function h(t){var e=f[t];return e||(e=f[t]=n.instance(t))}function p(t){return i.extendFlat({},l,{description:t})}function d(t){return\"Sets the calendar system to use with `\"+t+\"` date data.\"}var g={xcalendar:p(d(\"x\"))},m=i.extendFlat({},g,{ycalendar:p(d(\"y\"))}),v=i.extendFlat({},m,{zcalendar:p(d(\"z\"))}),y=p([\"Sets the calendar system to use for `range` and `tick0`\",\"if this is a date axis. This does not set the calendar for\",\"interpreting data on this axis, that's specified in the trace\",\"or via the global `layout.calendar`\"].join(\" \"));e.exports={moduleType:\"component\",name:\"calendars\",schema:{traces:{scatter:m,bar:m,box:m,heatmap:m,contour:m,histogram:m,histogram2d:m,histogram2dcontour:m,scatter3d:v,surface:v,mesh3d:v,scattergl:m,ohlc:g,candlestick:g},layout:{calendar:p([\"Sets the default calendar system to use for interpreting and\",\"displaying dates throughout the plot.\"].join(\" \"))},subplots:{xaxis:{calendar:y},yaxis:{calendar:y},scene:{xaxis:{calendar:y},yaxis:{calendar:y},zaxis:{calendar:y}},polar:{radialaxis:{calendar:y}}},transforms:{filter:{valuecalendar:p([\"Sets the calendar system to use for `value`, if it is a date.\"].join(\" \")),targetcalendar:p([\"Sets the calendar system to use for `target`, if it is an\",\"array of dates. If `target` is a string (eg *x*) we use the\",\"corresponding trace attribute (eg `xcalendar`) if it exists,\",\"even if `targetcalendar` is provided.\"].join(\" \"))}}},layoutAttributes:l,handleDefaults:c,handleTraceDefaults:function(t,e,r,n){for(var i=0;i<r.length;i++)c(t,e,r[i]+\"calendar\",n.calendar)},CANONICAL_SUNDAY:{chinese:\"2000-01-02\",coptic:\"2000-01-03\",discworld:\"2000-01-03\",ethiopian:\"2000-01-05\",hebrew:\"5000-01-01\",islamic:\"1000-01-02\",julian:\"2000-01-03\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-05\",nepali:\"2000-01-05\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-04\",thai:\"2000-01-04\",ummalqura:\"1400-01-06\"},CANONICAL_TICK:{chinese:\"2000-01-01\",coptic:\"2000-01-01\",discworld:\"2000-01-01\",ethiopian:\"2000-01-01\",hebrew:\"5000-01-01\",islamic:\"1000-01-01\",julian:\"2000-01-01\",mayan:\"5000-01-01\",nanakshahi:\"1000-01-01\",nepali:\"2000-01-01\",persian:\"1000-01-01\",jalali:\"1000-01-01\",taiwan:\"1000-01-01\",thai:\"2000-01-01\",ummalqura:\"1400-01-01\"},DFLTRANGE:{chinese:[\"2000-01-01\",\"2001-01-01\"],coptic:[\"1700-01-01\",\"1701-01-01\"],discworld:[\"1800-01-01\",\"1801-01-01\"],ethiopian:[\"2000-01-01\",\"2001-01-01\"],hebrew:[\"5700-01-01\",\"5701-01-01\"],islamic:[\"1400-01-01\",\"1401-01-01\"],julian:[\"2000-01-01\",\"2001-01-01\"],mayan:[\"5200-01-01\",\"5201-01-01\"],nanakshahi:[\"0500-01-01\",\"0501-01-01\"],nepali:[\"2000-01-01\",\"2001-01-01\"],persian:[\"1400-01-01\",\"1401-01-01\"],jalali:[\"1400-01-01\",\"1401-01-01\"],taiwan:[\"0100-01-01\",\"0101-01-01\"],thai:[\"2500-01-01\",\"2501-01-01\"],ummalqura:[\"1400-01-01\",\"1401-01-01\"]},getCal:h,worldCalFmt:function(t,e,r){for(var n,i,a,l,c,f=Math.floor((e+.05)/s)+o,p=h(r).fromJD(f),d=0;-1!==(d=t.indexOf(\"%\",d));)\"0\"===(n=t.charAt(d+1))||\"-\"===n||\"_\"===n?(a=3,i=t.charAt(d+2),\"_\"===n&&(n=\"-\")):(i=n,n=\"0\",a=2),(l=u[i])?(c=\"##\"===l?\"##\":p.formatDate(l[n]),t=t.substr(0,d)+c+t.substr(d+a),d+=c.length):d+=a;return t}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./calendars\":640}],642:[function(t,e,r){\"use strict\";r.defaults=[\"#1f77b4\",\"#ff7f0e\",\"#2ca02c\",\"#d62728\",\"#9467bd\",\"#8c564b\",\"#e377c2\",\"#7f7f7f\",\"#bcbd22\",\"#17becf\"],r.defaultLine=\"#444\",r.lightLine=\"#eee\",r.background=\"#fff\",r.borderLine=\"#BEC8D9\",r.lightFraction=1e3/11},{}],643:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i=t(\"fast-isnumeric\"),a=e.exports={},o=t(\"./attributes\");a.defaults=o.defaults;var s=a.defaultLine=o.defaultLine;a.lightLine=o.lightLine;var l=a.background=o.background;function c(t){if(i(t)||\"string\"!=typeof t)return t;var e=t.trim();if(\"rgb\"!==e.substr(0,3))return t;var r=e.match(/^rgba?\\s*\\(([^()]*)\\)$/);if(!r)return t;var n=r[1].trim().split(/\\s*[\\s,]\\s*/),a=\"a\"===e.charAt(3)&&4===n.length;if(!a&&3!==n.length)return t;for(var o=0;o<n.length;o++){if(!n[o].length)return t;if(n[o]=Number(n[o]),!(n[o]>=0))return t;if(3===o)n[o]>1&&(n[o]=1);else if(n[o]>=1)return t}var s=Math.round(255*n[0])+\", \"+Math.round(255*n[1])+\", \"+Math.round(255*n[2]);return a?\"rgba(\"+s+\", \"+n[3]+\")\":\"rgb(\"+s+\")\"}a.tinyRGB=function(t){var e=t.toRgb();return\"rgb(\"+Math.round(e.r)+\", \"+Math.round(e.g)+\", \"+Math.round(e.b)+\")\"},a.rgb=function(t){return a.tinyRGB(n(t))},a.opacity=function(t){return t?n(t).getAlpha():0},a.addOpacity=function(t,e){var r=n(t).toRgb();return\"rgba(\"+Math.round(r.r)+\", \"+Math.round(r.g)+\", \"+Math.round(r.b)+\", \"+e+\")\"},a.combine=function(t,e){var r=n(t).toRgb();if(1===r.a)return n(t).toRgbString();var i=n(e||l).toRgb(),a=1===i.a?i:{r:255*(1-i.a)+i.r*i.a,g:255*(1-i.a)+i.g*i.a,b:255*(1-i.a)+i.b*i.a},o={r:a.r*(1-r.a)+r.r*r.a,g:a.g*(1-r.a)+r.g*r.a,b:a.b*(1-r.a)+r.b*r.a};return n(o).toRgbString()},a.contrast=function(t,e,r){var i=n(t);return 1!==i.getAlpha()&&(i=n(a.combine(t,l))),(i.isDark()?e?i.lighten(e):l:r?i.darken(r):s).toString()},a.stroke=function(t,e){var r=n(e);t.style({stroke:a.tinyRGB(r),\"stroke-opacity\":r.getAlpha()})},a.fill=function(t,e){var r=n(e);t.style({fill:a.tinyRGB(r),\"fill-opacity\":r.getAlpha()})},a.clean=function(t){if(t&&\"object\"==typeof t){var e,r,n,i,o=Object.keys(t);for(e=0;e<o.length;e++)if(i=t[n=o[e]],\"color\"===n.substr(n.length-5))if(Array.isArray(i))for(r=0;r<i.length;r++)i[r]=c(i[r]);else t[n]=c(i);else if(\"colorscale\"===n.substr(n.length-10)&&Array.isArray(i))for(r=0;r<i.length;r++)Array.isArray(i[r])&&(i[r][1]=c(i[r][1]));else if(Array.isArray(i)){var s=i[0];if(!Array.isArray(s)&&s&&\"object\"==typeof s)for(r=0;r<i.length;r++)a.clean(i[r])}else i&&\"object\"==typeof i&&a.clean(i)}}},{\"./attributes\":642,\"fast-isnumeric\":241,tinycolor2:576}],644:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/layout_attributes\"),i=t(\"../../plots/font_attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll;e.exports=o({thicknessmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"pixels\"},thickness:{valType:\"number\",min:0,dflt:30},lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",dflt:1.02,min:-2,max:3},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},xpad:{valType:\"number\",min:0,dflt:10},y:{valType:\"number\",dflt:.5,min:-2,max:3},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\"},ypad:{valType:\"number\",min:0,dflt:10},outlinecolor:n.linecolor,outlinewidth:n.linewidth,bordercolor:n.linecolor,borderwidth:{valType:\"number\",min:0,dflt:0},bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\"},tickmode:n.tickmode,nticks:n.nticks,tick0:n.tick0,dtick:n.dtick,tickvals:n.tickvals,ticktext:n.ticktext,ticks:a({},n.ticks,{dflt:\"\"}),ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\"},ticklen:n.ticklen,tickwidth:n.tickwidth,tickcolor:n.tickcolor,showticklabels:n.showticklabels,tickfont:i({}),tickangle:n.tickangle,tickformat:n.tickformat,tickformatstops:n.tickformatstops,tickprefix:n.tickprefix,showtickprefix:n.showtickprefix,ticksuffix:n.ticksuffix,showticksuffix:n.showticksuffix,separatethousands:n.separatethousands,exponentformat:n.exponentformat,minexponent:n.minexponent,showexponent:n.showexponent,title:{text:{valType:\"string\"},font:i({}),side:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}},_deprecated:{title:{valType:\"string\"},titlefont:i({}),titleside:{valType:\"enumerated\",values:[\"right\",\"top\",\"bottom\"],dflt:\"top\"}}},\"colorbars\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],645:[function(t,e,r){\"use strict\";e.exports={cn:{colorbar:\"colorbar\",cbbg:\"cbbg\",cbfill:\"cbfill\",cbfills:\"cbfills\",cbline:\"cbline\",cblines:\"cblines\",cbaxis:\"cbaxis\",cbtitleunshift:\"cbtitleunshift\",cbtitle:\"cbtitle\",cboutline:\"cboutline\",crisp:\"crisp\",jsPlaceholder:\"js-placeholder\"}}},{}],646:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/tick_value_defaults\"),o=t(\"../../plots/cartesian/tick_mark_defaults\"),s=t(\"../../plots/cartesian/tick_label_defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r){var c=i.newContainer(e,\"colorbar\"),u=t.colorbar||{};function f(t,e){return n.coerce(u,c,l,t,e)}var h=f(\"thicknessmode\");f(\"thickness\",\"fraction\"===h?30/(r.width-r.margin.l-r.margin.r):30);var p=f(\"lenmode\");f(\"len\",\"fraction\"===p?1:r.height-r.margin.t-r.margin.b),f(\"x\"),f(\"xanchor\"),f(\"xpad\"),f(\"y\"),f(\"yanchor\"),f(\"ypad\"),n.noneOrAll(u,c,[\"x\",\"y\"]),f(\"outlinecolor\"),f(\"outlinewidth\"),f(\"bordercolor\"),f(\"borderwidth\"),f(\"bgcolor\");var d=f(\"ticklabelposition\");a(u,c,f,\"linear\");var g={outerTicks:!1,font:r.font};-1!==d.indexOf(\"inside\")&&(g.bgColor=\"black\"),s(u,c,f,\"linear\",g),o(u,c,f,\"linear\",g),f(\"title.text\",r._dfltTitle.colorbar),n.coerceFont(f,\"title.font\",r.font),f(\"title.side\")}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"./attributes\":644}],647:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../dragelement\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../lib/setcursor\"),p=t(\"../drawing\"),d=t(\"../color\"),g=t(\"../titles\"),m=t(\"../../lib/svg_text_utils\"),v=t(\"../colorscale/helpers\").flipScale,y=t(\"../../plots/cartesian/axis_defaults\"),x=t(\"../../plots/cartesian/position_defaults\"),b=t(\"../../plots/cartesian/layout_attributes\"),_=t(\"../../constants/alignment\"),w=_.LINE_SPACING,T=_.FROM_TL,k=_.FROM_BR,M=t(\"./constants\").cn;e.exports={draw:function(t){var e=t._fullLayout._infolayer.selectAll(\"g.\"+M.colorbar).data(function(t){var e,r,n,i,a=t._fullLayout,o=t.calcdata,s=[];function l(t){return f(t,{_fillcolor:null,_line:{color:null,width:null,dash:null},_levels:{start:null,end:null,size:null},_filllevels:null,_fillgradient:null,_zrange:null})}function c(){\"function\"==typeof i.calc?i.calc(t,n,e):(e._fillgradient=r.reversescale?v(r.colorscale):r.colorscale,e._zrange=[r[i.min],r[i.max]])}for(var u=0;u<o.length;u++){var h=o[u],p=(n=h[0].trace)._module.colorbar;if(!0===n.visible&&p)for(var d=Array.isArray(p),g=d?p:[p],m=0;m<g.length;m++){var y=(i=g[m]).container;(r=y?n[y]:n)&&r.showscale&&((e=l(r.colorbar))._id=\"cb\"+n.uid+(d&&y?\"-\"+y:\"\"),e._traceIndex=n.index,e._propPrefix=(y?y+\".\":\"\")+\"colorbar.\",e._meta=n._meta,c(),s.push(e))}}for(var x in a._colorAxes)if((r=a[x]).showscale){var b=a._colorAxes[x];(e=l(r.colorbar))._id=\"cb\"+x,e._propPrefix=x+\".colorbar.\",e._meta=a._meta,i={min:\"cmin\",max:\"cmax\"},\"heatmap\"!==b[0]&&(n=b[1],i.calc=n._module.colorbar.calc),c(),s.push(e)}return s}(t),(function(t){return t._id}));e.enter().append(\"g\").attr(\"class\",(function(t){return t._id})).classed(M.colorbar,!0),e.each((function(e){var r=n.select(this);c.ensureSingle(r,\"rect\",M.cbbg),c.ensureSingle(r,\"g\",M.cbfills),c.ensureSingle(r,\"g\",M.cblines),c.ensureSingle(r,\"g\",M.cbaxis,(function(t){t.classed(M.crisp,!0)})),c.ensureSingle(r,\"g\",M.cbtitleunshift,(function(t){t.append(\"g\").classed(M.cbtitle,!0)})),c.ensureSingle(r,\"rect\",M.cboutline);var v=function(t,e,r){var o=r._fullLayout,l=o._size,h=e._fillcolor,v=e._line,_=e.title,A=_.side,S=e._zrange||n.extent((\"function\"==typeof h?h:v.color).domain()),E=\"function\"==typeof v.color?v.color:function(){return v.color},C=\"function\"==typeof h?h:function(){return h},L=e._levels,I=function(t,e,r){var n,i,a=e._levels,o=[],s=[],l=a.end+a.size/100,c=a.size,u=1.001*r[0]-.001*r[1],f=1.001*r[1]-.001*r[0];for(i=0;i<1e5&&(n=a.start+i*c,!(c>0?n>=l:n<=l));i++)n>u&&n<f&&o.push(n);if(e._fillgradient)s=[0];else if(\"function\"==typeof e._fillcolor){var h=e._filllevels;if(h)for(l=h.end+h.size/100,c=h.size,i=0;i<1e5&&(n=h.start+i*c,!(c>0?n>=l:n<=l));i++)n>r[0]&&n<r[1]&&s.push(n);else(s=o.map((function(t){return t-a.size/2}))).push(s[s.length-1]+a.size)}else e._fillcolor&&\"string\"==typeof e._fillcolor&&(s=[0]);a.size<0&&(o.reverse(),s.reverse());return{line:o,fill:s}}(0,e,S),P=I.fill,z=I.line,O=Math.round(e.thickness*(\"fraction\"===e.thicknessmode?l.w:1)),D=O/l.w,R=Math.round(e.len*(\"fraction\"===e.lenmode?l.h:1)),F=R/l.h,B=e.xpad/l.w,N=(e.borderwidth+e.outlinewidth)/2,j=e.ypad/l.h,U=Math.round(e.x*l.w+e.xpad),V=e.x-D*({middle:.5,right:1}[e.xanchor]||0),q=e.y+F*(({top:-.5,bottom:.5}[e.yanchor]||0)-.5),H=Math.round(l.h*(1-q)),G=H-R;e._lenFrac=F,e._thickFrac=D,e._xLeftFrac=V,e._yBottomFrac=q;var Y=e._axis=function(t,e,r){var n=t._fullLayout,i={type:\"linear\",range:r,tickmode:e.tickmode,nticks:e.nticks,tick0:e.tick0,dtick:e.dtick,tickvals:e.tickvals,ticktext:e.ticktext,ticks:e.ticks,ticklen:e.ticklen,tickwidth:e.tickwidth,tickcolor:e.tickcolor,showticklabels:e.showticklabels,ticklabelposition:e.ticklabelposition,tickfont:e.tickfont,tickangle:e.tickangle,tickformat:e.tickformat,exponentformat:e.exponentformat,minexponent:e.minexponent,separatethousands:e.separatethousands,showexponent:e.showexponent,showtickprefix:e.showtickprefix,tickprefix:e.tickprefix,showticksuffix:e.showticksuffix,ticksuffix:e.ticksuffix,title:e.title,showline:!0,anchor:\"free\",side:\"right\",position:1},a={type:\"linear\",_id:\"y\"+e._id},o={letter:\"y\",font:n.font,noHover:!0,noTickson:!0,noTicklabelmode:!0,calendar:n.calendar};function s(t,e){return c.coerce(i,a,b,t,e)}return y(i,a,s,o,n),x(i,a,s,o),a}(r,e,S);Y.position=e.x+B+D,-1!==[\"top\",\"bottom\"].indexOf(A)&&(Y.title.side=A,Y.titlex=e.x+B,Y.titley=q+(\"top\"===_.side?F-j:j));if(v.color&&\"auto\"===e.tickmode){Y.tickmode=\"linear\",Y.tick0=L.start;var W=L.size,X=c.constrain((H-G)/50,4,15)+1,Z=(S[1]-S[0])/((e.nticks||X)*W);if(Z>1){var J=Math.pow(10,Math.floor(Math.log(Z)/Math.LN10));W*=J*c.roundUp(Z/J,[2,5,10]),(Math.abs(L.start)/L.size+1e-6)%1<2e-6&&(Y.tick0=0)}Y.dtick=W}Y.domain=[q+j,q+F-j],Y.setScale(),t.attr(\"transform\",u(Math.round(l.l),Math.round(l.t)));var K,Q=t.select(\".\"+M.cbtitleunshift).attr(\"transform\",u(-Math.round(l.l),-Math.round(l.t))),$=t.select(\".\"+M.cbaxis),tt=0;function et(n,i){var a={propContainer:Y,propName:e._propPrefix+\"title\",traceIndex:e._traceIndex,_meta:e._meta,placeholder:o._dfltTitle.colorbar,containerGroup:t.select(\".\"+M.cbtitle)},s=\"h\"===n.charAt(0)?n.substr(1):\"h\"+n;t.selectAll(\".\"+s+\",.\"+s+\"-math-group\").remove(),g.draw(r,n,f(a,i||{}))}return c.syncOrAsync([a.previousPromises,function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var t,r=l.l+(e.x+B)*l.w,n=Y.title.font.size;t=\"top\"===A?(1-(q+F-j))*l.h+l.t+3+.75*n:(1-(q+j))*l.h+l.t-3-.25*n,et(Y._id+\"title\",{attributes:{x:r,y:t,\"text-anchor\":\"start\"}})}},function(){if(-1!==[\"top\",\"bottom\"].indexOf(A)){var a=t.select(\".\"+M.cbtitle),o=a.select(\"text\"),f=[-e.outlinewidth/2,e.outlinewidth/2],h=a.select(\".h\"+Y._id+\"title-math-group\").node(),d=15.6;if(o.node()&&(d=parseInt(o.node().style.fontSize,10)*w),h?(tt=p.bBox(h).height)>d&&(f[1]-=(tt-d)/2):o.node()&&!o.classed(M.jsPlaceholder)&&(tt=p.bBox(o.node()).height),tt){if(tt+=5,\"top\"===A)Y.domain[1]-=tt/l.h,f[1]*=-1;else{Y.domain[0]+=tt/l.h;var g=m.lineCount(o);f[1]+=(1-g)*d}a.attr(\"transform\",u(f[0],f[1])),Y.setScale()}}t.selectAll(\".\"+M.cbfills+\",.\"+M.cblines).attr(\"transform\",u(0,Math.round(l.h*(1-Y.domain[1])))),$.attr(\"transform\",u(0,Math.round(-l.t)));var y=t.select(\".\"+M.cbfills).selectAll(\"rect.\"+M.cbfill).attr(\"style\",\"\").data(P);y.enter().append(\"rect\").classed(M.cbfill,!0).style(\"stroke\",\"none\"),y.exit().remove();var x=S.map(Y.c2p).map(Math.round).sort((function(t,e){return t-e}));y.each((function(t,a){var o=[0===a?S[0]:(P[a]+P[a-1])/2,a===P.length-1?S[1]:(P[a]+P[a+1])/2].map(Y.c2p).map(Math.round);o[1]=c.constrain(o[1]+(o[1]>o[0])?1:-1,x[0],x[1]);var s=n.select(this).attr({x:U,width:Math.max(O,2),y:n.min(o),height:Math.max(n.max(o)-n.min(o),2)});if(e._fillgradient)p.gradient(s,r,e._id,\"vertical\",e._fillgradient,\"fill\");else{var l=C(t).replace(\"e-\",\"\");s.attr(\"fill\",i(l).toHexString())}}));var b=t.select(\".\"+M.cblines).selectAll(\"path.\"+M.cbline).data(v.color&&v.width?z:[]);b.enter().append(\"path\").classed(M.cbline,!0),b.exit().remove(),b.each((function(t){n.select(this).attr(\"d\",\"M\"+U+\",\"+(Math.round(Y.c2p(t))+v.width/2%1)+\"h\"+O).call(p.lineGroupStyle,v.width,E(t),v.dash)})),$.selectAll(\"g.\"+Y._id+\"tick,path\").remove();var _=U+O+(e.outlinewidth||0)/2-(\"outside\"===e.ticks?1:0),T=s.calcTicks(Y),k=s.getTickSigns(Y)[2];return s.drawTicks(r,Y,{vals:\"inside\"===Y.ticks?s.clipEnds(Y,T):T,layer:$,path:s.makeTickPath(Y,_,k),transFn:s.makeTransTickFn(Y)}),s.drawLabels(r,Y,{vals:T,layer:$,transFn:s.makeTransTickLabelFn(Y),labelFns:s.makeLabelFns(Y,_)})},function(){if(-1===[\"top\",\"bottom\"].indexOf(A)){var t=Y.title.font.size,e=Y._offset+Y._length/2,i=l.l+(Y.position||0)*l.w+(\"right\"===Y.side?10+t*(Y.showticklabels?1:.5):-10-t*(Y.showticklabels?.5:0));et(\"h\"+Y._id+\"title\",{avoid:{selection:n.select(r).selectAll(\"g.\"+Y._id+\"tick\"),side:A,offsetLeft:l.l,offsetTop:0,maxShift:o.width},attributes:{x:i,y:e,\"text-anchor\":\"middle\"},transform:{rotate:\"-90\",offset:0}})}},a.previousPromises,function(){var n=O+e.outlinewidth/2;if(-1===Y.ticklabelposition.indexOf(\"inside\")&&(n+=p.bBox($.node()).width),(K=Q.select(\"text\")).node()&&!K.classed(M.jsPlaceholder)){var i,o=Q.select(\".h\"+Y._id+\"title-math-group\").node();i=o&&-1!==[\"top\",\"bottom\"].indexOf(A)?p.bBox(o).width:p.bBox(Q.node()).right-U-l.l,n=Math.max(n,i)}var s=2*e.xpad+n+e.borderwidth+e.outlinewidth/2,c=H-G;t.select(\".\"+M.cbbg).attr({x:U-e.xpad-(e.borderwidth+e.outlinewidth)/2,y:G-N,width:Math.max(s,2),height:Math.max(c+2*N,2)}).call(d.fill,e.bgcolor).call(d.stroke,e.bordercolor).style(\"stroke-width\",e.borderwidth),t.selectAll(\".\"+M.cboutline).attr({x:U,y:G+e.ypad+(\"top\"===A?tt:0),width:Math.max(O,2),height:Math.max(c-2*e.ypad-tt,2)}).call(d.stroke,e.outlinecolor).style({fill:\"none\",\"stroke-width\":e.outlinewidth});var f=({center:.5,right:1}[e.xanchor]||0)*s;t.attr(\"transform\",u(l.l-f,l.t));var h={},g=T[e.yanchor],m=k[e.yanchor];\"pixels\"===e.lenmode?(h.y=e.y,h.t=c*g,h.b=c*m):(h.t=h.b=0,h.yt=e.y+e.len*g,h.yb=e.y-e.len*m);var v=T[e.xanchor],y=k[e.xanchor];if(\"pixels\"===e.thicknessmode)h.x=e.x,h.l=s*v,h.r=s*y;else{var x=s-O;h.l=x*v,h.r=x*y,h.xl=e.x-e.thickness*v,h.xr=e.x+e.thickness*y}a.autoMargin(r,e._id,h)}],r)}(r,e,t);v&&v.then&&(t._promises||[]).push(v),t._context.edits.colorbarPosition&&function(t,e,r){var n,i,a,s=r._fullLayout._size;l.init({element:t.node(),gd:r,prepFn:function(){n=t.attr(\"transform\"),h(t)},moveFn:function(r,o){t.attr(\"transform\",n+u(r,o)),i=l.align(e._xLeftFrac+r/s.w,e._thickFrac,0,1,e.xanchor),a=l.align(e._yBottomFrac-o/s.h,e._lenFrac,0,1,e.yanchor);var c=l.getCursor(i,a,e.xanchor,e.yanchor);h(t,c)},doneFn:function(){if(h(t),void 0!==i&&void 0!==a){var n={};n[e._propPrefix+\"x\"]=i,n[e._propPrefix+\"y\"]=a,void 0!==e._traceIndex?o.call(\"_guiRestyle\",r,n,e._traceIndex):o.call(\"_guiRelayout\",r,n)}}})}(r,e,t)})),e.exit().each((function(e){a.autoMargin(t,e._id)})).remove(),e.order()}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/extend\":768,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../colorscale/helpers\":654,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":645,d3:169,tinycolor2:576}],648:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t){return n.isPlainObject(t.colorbar)}},{\"../../lib\":778}],649:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"colorbar\",attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),draw:t(\"./draw\").draw,hasColorbar:t(\"./has_colorbar\")}},{\"./attributes\":644,\"./defaults\":646,\"./draw\":647,\"./has_colorbar\":648}],650:[function(t,e,r){\"use strict\";var n=t(\"../colorbar/attributes\"),i=t(\"../../lib/regex\").counter,a=t(\"./scales.js\").scales;Object.keys(a);function o(t){return\"`\"+t+\"`\"}e.exports=function(t,e){t=t||\"\";var r,s=(e=e||{}).cLetter||\"c\",l=(\"onlyIfNumerical\"in e?e.onlyIfNumerical:Boolean(t),\"noScale\"in e?e.noScale:\"marker.line\"===t),c=\"showScaleDflt\"in e?e.showScaleDflt:\"z\"===s,u=\"string\"==typeof e.colorscaleDflt?a[e.colorscaleDflt]:null,f=e.editTypeOverride||\"\",h=t?t+\".\":\"\";\"colorAttr\"in e?(r=e.colorAttr,e.colorAttr):o(h+(r={z:\"z\",c:\"color\"}[s]));var p=s+\"auto\",d=s+\"min\",g=s+\"max\",m=s+\"mid\",v=(o(h+p),o(h+d),o(h+g),{});v[d]=v[g]=void 0;var y={};y[p]=!1;var x={};return\"color\"===r&&(x.color={valType:\"color\",arrayOk:!0,editType:f||\"style\"},e.anim&&(x.color.anim=!0)),x[p]={valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:v},x[d]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[g]={valType:\"number\",dflt:null,editType:f||\"plot\",impliedEdits:y},x[m]={valType:\"number\",dflt:null,editType:\"calc\",impliedEdits:v},x.colorscale={valType:\"colorscale\",editType:\"calc\",dflt:u,impliedEdits:{autocolorscale:!1}},x.autocolorscale={valType:\"boolean\",dflt:!1!==e.autoColorDflt,editType:\"calc\",impliedEdits:{colorscale:void 0}},x.reversescale={valType:\"boolean\",dflt:!1,editType:\"plot\"},l||(x.showscale={valType:\"boolean\",dflt:c,editType:\"calc\"},x.colorbar=n),e.noColorAxis||(x.coloraxis={valType:\"subplotid\",regex:i(\"coloraxis\"),dflt:null,editType:\"calc\"}),x}},{\"../../lib/regex\":795,\"../colorbar/attributes\":644,\"./scales.js\":658}],651:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./helpers\").extractOpts;e.exports=function(t,e,r){var o,s=t._fullLayout,l=r.vals,c=r.containerStr,u=c?i.nestedProperty(e,c).get():e,f=a(u),h=!1!==f.auto,p=f.min,d=f.max,g=f.mid,m=function(){return i.aggNums(Math.min,null,l)},v=function(){return i.aggNums(Math.max,null,l)};(void 0===p?p=m():h&&(p=u._colorAx&&n(p)?Math.min(p,m()):m()),void 0===d?d=v():h&&(d=u._colorAx&&n(d)?Math.max(d,v()):v()),h&&void 0!==g&&(d-g>g-p?p=g-(d-g):d-g<g-p&&(d=g+(g-p))),p===d&&(p-=.5,d+=.5),f._sync(\"min\",p),f._sync(\"max\",d),f.autocolorscale)&&(o=p*d<0?s.colorscale.diverging:p>=0?s.colorscale.sequential:s.colorscale.sequentialminus,f._sync(\"colorscale\",o))}},{\"../../lib\":778,\"./helpers\":654,\"fast-isnumeric\":241}],652:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").hasColorscale,a=t(\"./helpers\").extractOpts;e.exports=function(t,e){function r(t,e){var r=t[\"_\"+e];void 0!==r&&(t[e]=r)}function o(t,i){var o=i.container?n.nestedProperty(t,i.container).get():t;if(o)if(o.coloraxis)o._colorAx=e[o.coloraxis];else{var s=a(o),l=s.auto;(l||void 0===s.min)&&r(o,i.min),(l||void 0===s.max)&&r(o,i.max),s.autocolorscale&&r(o,\"colorscale\")}}for(var s=0;s<t.length;s++){var l=t[s],c=l._module.colorbar;if(c)if(Array.isArray(c))for(var u=0;u<c.length;u++)o(l,c[u]);else o(l,c);i(l,\"marker.line\")&&o(l,{container:\"marker.line\",min:\"cmin\",max:\"cmax\"})}for(var f in e._colorAxes)o(e[f],{min:\"cmin\",max:\"cmax\"})}},{\"../../lib\":778,\"./helpers\":654}],653:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../colorbar/has_colorbar\"),o=t(\"../colorbar/defaults\"),s=t(\"./scales\").isValid,l=t(\"../../registry\").traceIs;function c(t,e){var r=e.slice(0,e.length-1);return e?i.nestedProperty(t,r).get()||{}:t}e.exports=function t(e,r,u,f,h){var p=h.prefix,d=h.cLetter,g=\"_module\"in r,m=c(e,p),v=c(r,p),y=c(r._template||{},p)||{},x=function(){return delete e.coloraxis,delete r.coloraxis,t(e,r,u,f,h)};if(g){var b=u._colorAxes||{},_=f(p+\"coloraxis\");if(_){var w=l(r,\"contour\")&&i.nestedProperty(r,\"contours.coloring\").get()||\"heatmap\",T=b[_];return void(T?(T[2].push(x),T[0]!==w&&(T[0]=!1,i.warn([\"Ignoring coloraxis:\",_,\"setting\",\"as it is linked to incompatible colorscales.\"].join(\" \")))):b[_]=[w,r,[x]])}}var k=m[d+\"min\"],M=m[d+\"max\"],A=n(k)&&n(M)&&k<M;f(p+d+\"auto\",!A)?f(p+d+\"mid\"):(f(p+d+\"min\"),f(p+d+\"max\"));var S,E,C=m.colorscale,L=y.colorscale;(void 0!==C&&(S=!s(C)),void 0!==L&&(S=!s(L)),f(p+\"autocolorscale\",S),f(p+\"colorscale\"),f(p+\"reversescale\"),\"marker.line.\"!==p)&&(p&&g&&(E=a(m)),f(p+\"showscale\",E)&&(p&&y&&(v._template=y),o(m,v,u)))}},{\"../../lib\":778,\"../../registry\":911,\"../colorbar/defaults\":646,\"../colorbar/has_colorbar\":648,\"./scales\":658,\"fast-isnumeric\":241}],654:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=t(\"../color\"),l=t(\"./scales\").isValid;var c=[\"showscale\",\"autocolorscale\",\"colorscale\",\"reversescale\",\"colorbar\"],u=[\"min\",\"max\",\"mid\",\"auto\"];function f(t){var e,r,n,i=t._colorAx,a=i||t,o={};for(r=0;r<c.length;r++)o[n=c[r]]=a[n];if(i)for(e=\"c\",r=0;r<u.length;r++)o[n=u[r]]=a[\"c\"+n];else{var s;for(r=0;r<u.length;r++)((s=\"c\"+(n=u[r]))in a||(s=\"z\"+n)in a)&&(o[n]=a[s]);e=s.charAt(0)}return o._sync=function(t,r){var n=-1!==u.indexOf(t)?e+t:t;a[n]=a[\"_\"+n]=r},o}function h(t){for(var e=f(t),r=e.min,n=e.max,i=e.reversescale?p(e.colorscale):e.colorscale,a=i.length,o=new Array(a),s=new Array(a),l=0;l<a;l++){var c=i[l];o[l]=r+c[0]*(n-r),s[l]=c[1]}return{domain:o,range:s}}function p(t){for(var e=t.length,r=new Array(e),n=e-1,i=0;n>=0;n--,i++){var a=t[n];r[i]=[1-a[0],a[1]]}return r}function d(t,e){e=e||{};for(var r=t.domain,o=t.range,l=o.length,c=new Array(l),u=0;u<l;u++){var f=i(o[u]).toRgb();c[u]=[f.r,f.g,f.b,f.a]}var h,p=n.scale.linear().domain(r).range(c).clamp(!0),d=e.noNumericCheck,m=e.returnArray;return(h=d&&m?p:d?function(t){return g(p(t))}:m?function(t){return a(t)?p(t):i(t).isValid()?t:s.defaultLine}:function(t){return a(t)?g(p(t)):i(t).isValid()?t:s.defaultLine}).domain=p.domain,h.range=function(){return o},h}function g(t){var e={r:t[0],g:t[1],b:t[2],a:t[3]};return i(e).toRgbString()}e.exports={hasColorscale:function(t,e,r){var n=e?o.nestedProperty(t,e).get()||{}:t,i=n[r||\"color\"],s=!1;if(o.isArrayOrTypedArray(i))for(var c=0;c<i.length;c++)if(a(i[c])){s=!0;break}return o.isPlainObject(n)&&(s||!0===n.showscale||a(n.cmin)&&a(n.cmax)||l(n.colorscale)||o.isPlainObject(n.colorbar))},extractOpts:f,extractScale:h,flipScale:p,makeColorScaleFunc:d,makeColorScaleFuncFromTrace:function(t,e){return d(h(t),e)}}},{\"../../lib\":778,\"../color\":643,\"./scales\":658,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],655:[function(t,e,r){\"use strict\";var n=t(\"./scales\"),i=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"colorscale\",attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),handleDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\"),scales:n.scales,defaultScale:n.defaultScale,getScale:n.get,isValidScale:n.isValid,hasColorscale:i.hasColorscale,extractOpts:i.extractOpts,extractScale:i.extractScale,flipScale:i.flipScale,makeColorScaleFunc:i.makeColorScaleFunc,makeColorScaleFuncFromTrace:i.makeColorScaleFuncFromTrace}},{\"./attributes\":650,\"./calc\":651,\"./cross_trace_defaults\":652,\"./defaults\":653,\"./helpers\":654,\"./layout_attributes\":656,\"./layout_defaults\":657,\"./scales\":658}],656:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"./attributes\"),a=t(\"./scales\").scales;e.exports={editType:\"calc\",colorscale:{editType:\"calc\",sequential:{valType:\"colorscale\",dflt:a.Reds,editType:\"calc\"},sequentialminus:{valType:\"colorscale\",dflt:a.Blues,editType:\"calc\"},diverging:{valType:\"colorscale\",dflt:a.RdBu,editType:\"calc\"}},coloraxis:n({_isSubplotObj:!0,editType:\"calc\"},i(\"\",{colorAttr:\"corresponding trace color array(s)\",noColorAxis:!0,showScaleDflt:!0}))}},{\"../../lib/extend\":768,\"./attributes\":650,\"./scales\":658}],657:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"./layout_attributes\"),o=t(\"./defaults\");e.exports=function(t,e){function r(r,i){return n.coerce(t,e,a,r,i)}r(\"colorscale.sequential\"),r(\"colorscale.sequentialminus\"),r(\"colorscale.diverging\");var s,l,c=e._colorAxes;function u(t,e){return n.coerce(s,l,a.coloraxis,t,e)}for(var f in c){var h=c[f];if(h[0])s=t[f]||{},(l=i.newContainer(e,f,\"coloraxis\"))._name=f,o(s,l,e,u,{prefix:\"\",cLetter:\"c\"});else{for(var p=0;p<h[2].length;p++)h[2][p]();delete e._colorAxes[f]}}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"./defaults\":653,\"./layout_attributes\":656}],658:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\"),i={Greys:[[0,\"rgb(0,0,0)\"],[1,\"rgb(255,255,255)\"]],YlGnBu:[[0,\"rgb(8,29,88)\"],[.125,\"rgb(37,52,148)\"],[.25,\"rgb(34,94,168)\"],[.375,\"rgb(29,145,192)\"],[.5,\"rgb(65,182,196)\"],[.625,\"rgb(127,205,187)\"],[.75,\"rgb(199,233,180)\"],[.875,\"rgb(237,248,217)\"],[1,\"rgb(255,255,217)\"]],Greens:[[0,\"rgb(0,68,27)\"],[.125,\"rgb(0,109,44)\"],[.25,\"rgb(35,139,69)\"],[.375,\"rgb(65,171,93)\"],[.5,\"rgb(116,196,118)\"],[.625,\"rgb(161,217,155)\"],[.75,\"rgb(199,233,192)\"],[.875,\"rgb(229,245,224)\"],[1,\"rgb(247,252,245)\"]],YlOrRd:[[0,\"rgb(128,0,38)\"],[.125,\"rgb(189,0,38)\"],[.25,\"rgb(227,26,28)\"],[.375,\"rgb(252,78,42)\"],[.5,\"rgb(253,141,60)\"],[.625,\"rgb(254,178,76)\"],[.75,\"rgb(254,217,118)\"],[.875,\"rgb(255,237,160)\"],[1,\"rgb(255,255,204)\"]],Bluered:[[0,\"rgb(0,0,255)\"],[1,\"rgb(255,0,0)\"]],RdBu:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(106,137,247)\"],[.5,\"rgb(190,190,190)\"],[.6,\"rgb(220,170,132)\"],[.7,\"rgb(230,145,90)\"],[1,\"rgb(178,10,28)\"]],Reds:[[0,\"rgb(220,220,220)\"],[.2,\"rgb(245,195,157)\"],[.4,\"rgb(245,160,105)\"],[1,\"rgb(178,10,28)\"]],Blues:[[0,\"rgb(5,10,172)\"],[.35,\"rgb(40,60,190)\"],[.5,\"rgb(70,100,245)\"],[.6,\"rgb(90,120,245)\"],[.7,\"rgb(106,137,247)\"],[1,\"rgb(220,220,220)\"]],Picnic:[[0,\"rgb(0,0,255)\"],[.1,\"rgb(51,153,255)\"],[.2,\"rgb(102,204,255)\"],[.3,\"rgb(153,204,255)\"],[.4,\"rgb(204,204,255)\"],[.5,\"rgb(255,255,255)\"],[.6,\"rgb(255,204,255)\"],[.7,\"rgb(255,153,255)\"],[.8,\"rgb(255,102,204)\"],[.9,\"rgb(255,102,102)\"],[1,\"rgb(255,0,0)\"]],Rainbow:[[0,\"rgb(150,0,90)\"],[.125,\"rgb(0,0,200)\"],[.25,\"rgb(0,25,255)\"],[.375,\"rgb(0,152,255)\"],[.5,\"rgb(44,255,150)\"],[.625,\"rgb(151,255,0)\"],[.75,\"rgb(255,234,0)\"],[.875,\"rgb(255,111,0)\"],[1,\"rgb(255,0,0)\"]],Portland:[[0,\"rgb(12,51,131)\"],[.25,\"rgb(10,136,186)\"],[.5,\"rgb(242,211,56)\"],[.75,\"rgb(242,143,56)\"],[1,\"rgb(217,30,30)\"]],Jet:[[0,\"rgb(0,0,131)\"],[.125,\"rgb(0,60,170)\"],[.375,\"rgb(5,255,255)\"],[.625,\"rgb(255,255,0)\"],[.875,\"rgb(250,0,0)\"],[1,\"rgb(128,0,0)\"]],Hot:[[0,\"rgb(0,0,0)\"],[.3,\"rgb(230,0,0)\"],[.6,\"rgb(255,210,0)\"],[1,\"rgb(255,255,255)\"]],Blackbody:[[0,\"rgb(0,0,0)\"],[.2,\"rgb(230,0,0)\"],[.4,\"rgb(230,210,0)\"],[.7,\"rgb(255,255,255)\"],[1,\"rgb(160,200,255)\"]],Earth:[[0,\"rgb(0,0,130)\"],[.1,\"rgb(0,180,180)\"],[.2,\"rgb(40,210,40)\"],[.4,\"rgb(230,230,50)\"],[.6,\"rgb(120,70,20)\"],[1,\"rgb(255,255,255)\"]],Electric:[[0,\"rgb(0,0,0)\"],[.15,\"rgb(30,0,100)\"],[.4,\"rgb(120,0,100)\"],[.6,\"rgb(160,90,0)\"],[.8,\"rgb(230,200,0)\"],[1,\"rgb(255,250,220)\"]],Viridis:[[0,\"#440154\"],[.06274509803921569,\"#48186a\"],[.12549019607843137,\"#472d7b\"],[.18823529411764706,\"#424086\"],[.25098039215686274,\"#3b528b\"],[.3137254901960784,\"#33638d\"],[.3764705882352941,\"#2c728e\"],[.4392156862745098,\"#26828e\"],[.5019607843137255,\"#21918c\"],[.5647058823529412,\"#1fa088\"],[.6274509803921569,\"#28ae80\"],[.6901960784313725,\"#3fbc73\"],[.7529411764705882,\"#5ec962\"],[.8156862745098039,\"#84d44b\"],[.8784313725490196,\"#addc30\"],[.9411764705882353,\"#d8e219\"],[1,\"#fde725\"]],Cividis:[[0,\"rgb(0,32,76)\"],[.058824,\"rgb(0,42,102)\"],[.117647,\"rgb(0,52,110)\"],[.176471,\"rgb(39,63,108)\"],[.235294,\"rgb(60,74,107)\"],[.294118,\"rgb(76,85,107)\"],[.352941,\"rgb(91,95,109)\"],[.411765,\"rgb(104,106,112)\"],[.470588,\"rgb(117,117,117)\"],[.529412,\"rgb(131,129,120)\"],[.588235,\"rgb(146,140,120)\"],[.647059,\"rgb(161,152,118)\"],[.705882,\"rgb(176,165,114)\"],[.764706,\"rgb(192,177,109)\"],[.823529,\"rgb(209,191,102)\"],[.882353,\"rgb(225,204,92)\"],[.941176,\"rgb(243,219,79)\"],[1,\"rgb(255,233,69)\"]]},a=i.RdBu;function o(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var i=t[r];if(2!==i.length||+i[0]<e||!n(i[1]).isValid())return!1;e=+i[0]}return!0}e.exports={scales:i,defaultScale:a,get:function(t,e){if(e||(e=a),!t)return e;function r(){try{t=i[t]||JSON.parse(t)}catch(r){t=e}}return\"string\"==typeof t&&(r(),\"string\"==typeof t&&r()),o(t)?t:e},isValid:function(t){return void 0!==i[t]||o(t)}}},{tinycolor2:576}],659:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=(t-r)/(n-r),o=a+e/(n-r),s=(a+o)/2;return\"left\"===i||\"bottom\"===i?a:\"center\"===i||\"middle\"===i?s:\"right\"===i||\"top\"===i?o:a<2/3-s?a:o>4/3-s?o:s}},{}],660:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[\"sw-resize\",\"s-resize\",\"se-resize\"],[\"w-resize\",\"move\",\"e-resize\"],[\"nw-resize\",\"n-resize\",\"ne-resize\"]];e.exports=function(t,e,r,a){return t=\"left\"===r?0:\"center\"===r?1:\"right\"===r?2:n.constrain(Math.floor(3*t),0,2),e=\"bottom\"===a?0:\"middle\"===a?1:\"top\"===a?2:n.constrain(Math.floor(3*e),0,2),i[e][t]}},{\"../../lib\":778}],661:[function(t,e,r){\"use strict\";r.selectMode=function(t){return\"lasso\"===t||\"select\"===t},r.drawMode=function(t){return\"drawclosedpath\"===t||\"drawopenpath\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.openMode=function(t){return\"drawline\"===t||\"drawopenpath\"===t},r.rectMode=function(t){return\"select\"===t||\"drawline\"===t||\"drawrect\"===t||\"drawcircle\"===t},r.freeMode=function(t){return\"lasso\"===t||\"drawclosedpath\"===t||\"drawopenpath\"===t},r.selectingOrDrawing=function(t){return r.freeMode(t)||r.rectMode(t)}},{}],662:[function(t,e,r){\"use strict\";var n=t(\"mouse-event-offset\"),i=t(\"has-hover\"),a=t(\"has-passive-events\"),o=t(\"../../lib\").removeElement,s=t(\"../../plots/cartesian/constants\"),l=e.exports={};l.align=t(\"./align\"),l.getCursor=t(\"./cursor\");var c=t(\"./unhover\");function u(){var t=document.createElement(\"div\");t.className=\"dragcover\";var e=t.style;return e.position=\"fixed\",e.left=0,e.right=0,e.top=0,e.bottom=0,e.zIndex=999999999,e.background=\"none\",document.body.appendChild(t),t}function f(t){return n(t.changedTouches?t.changedTouches[0]:t,document.body)}l.unhover=c.wrapped,l.unhoverRaw=c.raw,l.init=function(t){var e,r,n,c,h,p,d,g,m=t.gd,v=1,y=m._context.doubleClickDelay,x=t.element;m._mouseDownTime||(m._mouseDownTime=0),x.style.pointerEvents=\"all\",x.onmousedown=_,a?(x._ontouchstart&&x.removeEventListener(\"touchstart\",x._ontouchstart),x._ontouchstart=_,x.addEventListener(\"touchstart\",_,{passive:!1})):x.ontouchstart=_;var b=t.clampFn||function(t,e,r){return Math.abs(t)<r&&(t=0),Math.abs(e)<r&&(e=0),[t,e]};function _(a){m._dragged=!1,m._dragging=!0;var o=f(a);e=o[0],r=o[1],d=a.target,p=a,g=2===a.buttons||a.ctrlKey,\"undefined\"==typeof a.clientX&&\"undefined\"==typeof a.clientY&&(a.clientX=e,a.clientY=r),(n=(new Date).getTime())-m._mouseDownTime<y?v+=1:(v=1,m._mouseDownTime=n),t.prepFn&&t.prepFn(a,e,r),i&&!g?(h=u()).style.cursor=window.getComputedStyle(x).cursor:i||(h=document,c=window.getComputedStyle(document.documentElement).cursor,document.documentElement.style.cursor=window.getComputedStyle(x).cursor),document.addEventListener(\"mouseup\",T),document.addEventListener(\"touchend\",T),!1!==t.dragmode&&(a.preventDefault(),document.addEventListener(\"mousemove\",w),document.addEventListener(\"touchmove\",w,{passive:!1}))}function w(n){n.preventDefault();var i=f(n),a=t.minDrag||s.MINDRAG,o=b(i[0]-e,i[1]-r,a),c=o[0],u=o[1];(c||u)&&(m._dragged=!0,l.unhover(m)),m._dragged&&t.moveFn&&!g&&(m._dragdata={element:x,dx:c,dy:u},t.moveFn(c,u))}function T(e){if(delete m._dragdata,!1!==t.dragmode&&(e.preventDefault(),document.removeEventListener(\"mousemove\",w),document.removeEventListener(\"touchmove\",w)),document.removeEventListener(\"mouseup\",T),document.removeEventListener(\"touchend\",T),i?o(h):c&&(h.documentElement.style.cursor=c,c=null),m._dragging){if(m._dragging=!1,(new Date).getTime()-m._mouseDownTime>y&&(v=Math.max(v-1,1)),m._dragged)t.doneFn&&t.doneFn();else if(t.clickFn&&t.clickFn(v,p),!g){var r;try{r=new MouseEvent(\"click\",e)}catch(t){var n=f(e);(r=document.createEvent(\"MouseEvents\")).initMouseEvent(\"click\",e.bubbles,e.cancelable,e.view,e.detail,e.screenX,e.screenY,n[0],n[1],e.ctrlKey,e.altKey,e.shiftKey,e.metaKey,e.button,e.relatedTarget)}d.dispatchEvent(r)}m._dragging=!1,m._dragged=!1}else m._dragged=!1}},l.coverSlip=u},{\"../../lib\":778,\"../../plots/cartesian/constants\":834,\"./align\":659,\"./cursor\":660,\"./unhover\":663,\"has-hover\":440,\"has-passive-events\":441,\"mouse-event-offset\":484}],663:[function(t,e,r){\"use strict\";var n=t(\"../../lib/events\"),i=t(\"../../lib/throttle\"),a=t(\"../../lib/dom\").getGraphDiv,o=t(\"../fx/constants\"),s=e.exports={};s.wrapped=function(t,e,r){(t=a(t))._fullLayout&&i.clear(t._fullLayout._uid+o.HOVERID),s.raw(t,e,r)},s.raw=function(t,e){var r=t._fullLayout,i=t._hoverdata;e||(e={}),e.target&&!1===n.triggerHandler(t,\"plotly_beforehover\",e)||(r._hoverlayer.selectAll(\"g\").remove(),r._hoverlayer.selectAll(\"line\").remove(),r._hoverlayer.selectAll(\"circle\").remove(),t._hoverdata=void 0,e.target&&i&&t.emit(\"plotly_unhover\",{event:e,points:i}))}},{\"../../lib/dom\":766,\"../../lib/events\":767,\"../../lib/throttle\":804,\"../fx/constants\":677}],664:[function(t,e,r){\"use strict\";r.dash={valType:\"string\",values:[\"solid\",\"dot\",\"dash\",\"longdash\",\"dashdot\",\"longdashdot\"],dflt:\"solid\",editType:\"style\"}},{}],665:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../registry\"),s=t(\"../color\"),l=t(\"../colorscale\"),c=t(\"../../lib\"),u=c.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/xmlns_namespaces\"),p=t(\"../../constants/alignment\").LINE_SPACING,d=t(\"../../constants/interactions\").DESELECTDIM,g=t(\"../../traces/scatter/subtypes\"),m=t(\"../../traces/scatter/make_bubble_size_func\"),v=t(\"../../components/fx/helpers\").appendArrayPointValue,y=e.exports={};y.font=function(t,e,r,n){c.isPlainObject(e)&&(n=e.color,r=e.size,e=e.family),e&&t.style(\"font-family\",e),r+1&&t.style(\"font-size\",r+\"px\"),n&&t.call(s.fill,n)},y.setPosition=function(t,e,r){t.attr(\"x\",e).attr(\"y\",r)},y.setSize=function(t,e,r){t.attr(\"width\",e).attr(\"height\",r)},y.setRect=function(t,e,r,n,i){t.call(y.setPosition,e,r).call(y.setSize,n,i)},y.translatePoint=function(t,e,r,n){var a=r.c2p(t.x),o=n.c2p(t.y);return!!(i(a)&&i(o)&&e.node())&&(\"text\"===e.node().nodeName?e.attr(\"x\",a).attr(\"y\",o):e.attr(\"transform\",u(a,o)),!0)},y.translatePoints=function(t,e,r){t.each((function(t){var i=n.select(this);y.translatePoint(t,i,e,r)}))},y.hideOutsideRangePoint=function(t,e,r,n,i,a){e.attr(\"display\",r.isPtWithinRange(t,i)&&n.isPtWithinRange(t,a)?null:\"none\")},y.hideOutsideRangePoints=function(t,e){if(e._hasClipOnAxisFalse){var r=e.xaxis,i=e.yaxis;t.each((function(e){var a=e[0].trace,s=a.xcalendar,l=a.ycalendar,c=o.traceIs(a,\"bar-like\")?\".bartext\":\".point,.textpoint\";t.selectAll(c).each((function(t){y.hideOutsideRangePoint(t,n.select(this),r,i,s,l)}))}))}},y.crispRound=function(t,e,r){return e&&i(e)?t._context.staticPlot?e:e<1?1:Math.round(e):r||0},y.singleLineStyle=function(t,e,r,n,i){e.style(\"fill\",\"none\");var a=(((t||[])[0]||{}).trace||{}).line||{},o=r||a.width||0,l=i||a.dash||\"\";s.stroke(e,n||a.color),y.dashLine(e,l,o)},y.lineGroupStyle=function(t,e,r,i){t.style(\"fill\",\"none\").each((function(t){var a=(((t||[])[0]||{}).trace||{}).line||{},o=e||a.width||0,l=i||a.dash||\"\";n.select(this).call(s.stroke,r||a.color).call(y.dashLine,l,o)}))},y.dashLine=function(t,e,r){r=+r||0,e=y.dashStyle(e,r),t.style({\"stroke-dasharray\":e,\"stroke-width\":r+\"px\"})},y.dashStyle=function(t,e){e=+e||1;var r=Math.max(e,3);return\"solid\"===t?t=\"\":\"dot\"===t?t=r+\"px,\"+r+\"px\":\"dash\"===t?t=3*r+\"px,\"+3*r+\"px\":\"longdash\"===t?t=5*r+\"px,\"+5*r+\"px\":\"dashdot\"===t?t=3*r+\"px,\"+r+\"px,\"+r+\"px,\"+r+\"px\":\"longdashdot\"===t&&(t=5*r+\"px,\"+2*r+\"px,\"+r+\"px,\"+2*r+\"px\"),t},y.singleFillStyle=function(t){var e=(((n.select(t.node()).data()[0]||[])[0]||{}).trace||{}).fillcolor;e&&t.call(s.fill,e)},y.fillGroupStyle=function(t){t.style(\"stroke-width\",0).each((function(t){var e=n.select(this);t[0].trace&&e.call(s.fill,t[0].trace.fillcolor)}))};var x=t(\"./symbol_defs\");y.symbolNames=[],y.symbolFuncs=[],y.symbolNeedLines={},y.symbolNoDot={},y.symbolNoFill={},y.symbolList=[],Object.keys(x).forEach((function(t){var e=x[t],r=e.n;y.symbolList.push(r,String(r),t,r+100,String(r+100),t+\"-open\"),y.symbolNames[r]=t,y.symbolFuncs[r]=e.f,e.needLine&&(y.symbolNeedLines[r]=!0),e.noDot?y.symbolNoDot[r]=!0:y.symbolList.push(r+200,String(r+200),t+\"-dot\",r+300,String(r+300),t+\"-open-dot\"),e.noFill&&(y.symbolNoFill[r]=!0)}));var b=y.symbolNames.length;function _(t,e){var r=t%100;return y.symbolFuncs[r](e)+(t>=200?\"M0,0.5L0.5,0L0,-0.5L-0.5,0Z\":\"\")}y.symbolNumber=function(t){if(i(t))t=+t;else if(\"string\"==typeof t){var e=0;t.indexOf(\"-open\")>0&&(e=100,t=t.replace(\"-open\",\"\")),t.indexOf(\"-dot\")>0&&(e+=200,t=t.replace(\"-dot\",\"\")),(t=y.symbolNames.indexOf(t))>=0&&(t+=e)}return t%100>=b||t>=400?0:Math.floor(Math.max(t,0))};var w={x1:1,x2:0,y1:0,y2:0},T={x1:0,x2:0,y1:1,y2:0},k=n.format(\"~.1f\"),M={radial:{node:\"radialGradient\"},radialreversed:{node:\"radialGradient\",reversed:!0},horizontal:{node:\"linearGradient\",attrs:w},horizontalreversed:{node:\"linearGradient\",attrs:w,reversed:!0},vertical:{node:\"linearGradient\",attrs:T},verticalreversed:{node:\"linearGradient\",attrs:T,reversed:!0}};y.gradient=function(t,e,r,i,o,l){for(var u=o.length,f=M[i],h=new Array(u),p=0;p<u;p++)f.reversed?h[u-1-p]=[k(100*(1-o[p][0])),o[p][1]]:h[p]=[k(100*o[p][0]),o[p][1]];var d=e._fullLayout,g=\"g\"+d._uid+\"-\"+r,m=d._defs.select(\".gradients\").selectAll(\"#\"+g).data([i+h.join(\";\")],c.identity);m.exit().remove(),m.enter().append(f.node).each((function(){var t=n.select(this);f.attrs&&t.attr(f.attrs),t.attr(\"id\",g);var e=t.selectAll(\"stop\").data(h);e.exit().remove(),e.enter().append(\"stop\"),e.each((function(t){var e=a(t[1]);n.select(this).attr({offset:t[0]+\"%\",\"stop-color\":s.tinyRGB(e),\"stop-opacity\":e.getAlpha()})}))})),t.style(l,O(g,e)).style(l+\"-opacity\",null);var v=function(t){return\".\"+t.attr(\"class\").replace(/\\s/g,\".\")},y=v(n.select(t.node().parentNode))+\">\"+v(t);d._gradientUrlQueryParts[y]=1},y.initGradients=function(t){var e=t._fullLayout;c.ensureSingle(e._defs,\"g\",\"gradients\").selectAll(\"linearGradient,radialGradient\").remove(),e._gradientUrlQueryParts={}},y.pointStyle=function(t,e,r){if(t.size()){var i=y.makePointStyleFns(e);t.each((function(t){y.singlePointStyle(t,n.select(this),e,i,r)}))}},y.singlePointStyle=function(t,e,r,n,i){var a=r.marker,o=a.line;if(e.style(\"opacity\",n.selectedOpacityFn?n.selectedOpacityFn(t):void 0===t.mo?a.opacity:t.mo),n.ms2mrc){var l;l=\"various\"===t.ms||\"various\"===a.size?3:n.ms2mrc(t.ms),t.mrc=l,n.selectedSizeFn&&(l=t.mrc=n.selectedSizeFn(t));var u=y.symbolNumber(t.mx||a.symbol)||0;t.om=u%200>=100,e.attr(\"d\",_(u,l))}var f,h,p,d=!1;if(t.so)p=o.outlierwidth,h=o.outliercolor,f=a.outliercolor;else{var g=(o||{}).width;p=(t.mlw+1||g+1||(t.trace?(t.trace.marker.line||{}).width:0)+1)-1||0,h=\"mlc\"in t?t.mlcc=n.lineScale(t.mlc):c.isArrayOrTypedArray(o.color)?s.defaultLine:o.color,c.isArrayOrTypedArray(a.color)&&(f=s.defaultLine,d=!0),f=\"mc\"in t?t.mcc=n.markerScale(t.mc):a.color||\"rgba(0,0,0,0)\",n.selectedColorFn&&(f=n.selectedColorFn(t))}if(t.om)e.call(s.stroke,f).style({\"stroke-width\":(p||1)+\"px\",fill:\"none\"});else{e.style(\"stroke-width\",(t.isBlank?0:p)+\"px\");var m=a.gradient,v=t.mgt;if(v?d=!0:v=m&&m.type,Array.isArray(v)&&(v=v[0],M[v]||(v=0)),v&&\"none\"!==v){var x=t.mgc;x?d=!0:x=m.color;var b=r.uid;d&&(b+=\"-\"+t.i),y.gradient(e,i,b,v,[[0,x],[1,f]],\"fill\")}else s.fill(e,f);p&&s.stroke(e,h)}},y.makePointStyleFns=function(t){var e={},r=t.marker;return e.markerScale=y.tryColorscale(r,\"\"),e.lineScale=y.tryColorscale(r,\"line\"),o.traceIs(t,\"symbols\")&&(e.ms2mrc=g.isBubble(t)?m(t):function(){return(r.size||6)/2}),t.selectedpoints&&c.extendFlat(e,y.makeSelectedPointStyleFns(t)),e},y.makeSelectedPointStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.marker||{},a=r.marker||{},s=n.marker||{},l=i.opacity,u=a.opacity,f=s.opacity,h=void 0!==u,p=void 0!==f;(c.isArrayOrTypedArray(l)||h||p)&&(e.selectedOpacityFn=function(t){var e=void 0===t.mo?i.opacity:t.mo;return t.selected?h?u:e:p?f:d*e});var g=i.color,m=a.color,v=s.color;(m||v)&&(e.selectedColorFn=function(t){var e=t.mcc||g;return t.selected?m||e:v||e});var y=i.size,x=a.size,b=s.size,_=void 0!==x,w=void 0!==b;return o.traceIs(t,\"symbols\")&&(_||w)&&(e.selectedSizeFn=function(t){var e=t.mrc||y/2;return t.selected?_?x/2:e:w?b/2:e}),e},y.makeSelectedTextStyleFns=function(t){var e={},r=t.selected||{},n=t.unselected||{},i=t.textfont||{},a=r.textfont||{},o=n.textfont||{},l=i.color,c=a.color,u=o.color;return e.selectedTextColorFn=function(t){var e=t.tc||l;return t.selected?c||e:u||(c?e:s.addOpacity(e,d))},e},y.selectedPointStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedPointStyleFns(e),i=e.marker||{},a=[];r.selectedOpacityFn&&a.push((function(t,e){t.style(\"opacity\",r.selectedOpacityFn(e))})),r.selectedColorFn&&a.push((function(t,e){s.fill(t,r.selectedColorFn(e))})),r.selectedSizeFn&&a.push((function(t,e){var n=e.mx||i.symbol||0,a=r.selectedSizeFn(e);t.attr(\"d\",_(y.symbolNumber(n),a)),e.mrc2=a})),a.length&&t.each((function(t){for(var e=n.select(this),r=0;r<a.length;r++)a[r](e,t)}))}},y.tryColorscale=function(t,e){var r=e?c.nestedProperty(t,e).get():t;if(r){var n=r.color;if((r.colorscale||r._colorAx)&&c.isArrayOrTypedArray(n))return l.makeColorScaleFuncFromTrace(r)}return c.identity};var A={start:1,end:-1,middle:0,bottom:1,top:-1};function S(t,e,r,i){var a=n.select(t.node().parentNode),o=-1!==e.indexOf(\"top\")?\"top\":-1!==e.indexOf(\"bottom\")?\"bottom\":\"middle\",s=-1!==e.indexOf(\"left\")?\"end\":-1!==e.indexOf(\"right\")?\"start\":\"middle\",l=i?i/.8+1:0,c=(f.lineCount(t)-1)*p+1,h=A[s]*l,d=.75*r+A[o]*l+(A[o]-1)*c*r/2;t.attr(\"text-anchor\",s),a.attr(\"transform\",u(h,d))}function E(t,e){var r=t.ts||e.textfont.size;return i(r)&&r>0?r:0}y.textPointStyle=function(t,e,r){if(t.size()){var i;if(e.selectedpoints){var a=y.makeSelectedTextStyleFns(e);i=a.selectedTextColorFn}var o=e.texttemplate,s=r._fullLayout;t.each((function(t){var a=n.select(this),l=o?c.extractOption(t,e,\"txt\",\"texttemplate\"):c.extractOption(t,e,\"tx\",\"text\");if(l||0===l){if(o){var u=e._module.formatLabels?e._module.formatLabels(t,e,s):{},h={};v(h,e,t.i);var p=e._meta||{};l=c.texttemplateString(l,u,s._d3locale,h,t,p)}var d=t.tp||e.textposition,g=E(t,e),m=i?i(t):t.tc||e.textfont.color;a.call(y.font,t.tf||e.textfont.family,g,m).text(l).call(f.convertToTspans,r).call(S,d,g,t.mrc)}else a.remove()}))}},y.selectedTextStyle=function(t,e){if(t.size()&&e.selectedpoints){var r=y.makeSelectedTextStyleFns(e);t.each((function(t){var i=n.select(this),a=r.selectedTextColorFn(t),o=t.tp||e.textposition,l=E(t,e);s.fill(i,a),S(i,o,l,t.mrc2||t.mrc)}))}};function C(t,e,r,i){var a=t[0]-e[0],o=t[1]-e[1],s=r[0]-e[0],l=r[1]-e[1],c=Math.pow(a*a+o*o,.25),u=Math.pow(s*s+l*l,.25),f=(u*u*a-c*c*s)*i,h=(u*u*o-c*c*l)*i,p=3*u*(c+u),d=3*c*(c+u);return[[n.round(e[0]+(p&&f/p),2),n.round(e[1]+(p&&h/p),2)],[n.round(e[0]-(d&&f/d),2),n.round(e[1]-(d&&h/d),2)]]}y.smoothopen=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\");var r,n=\"M\"+t[0],i=[];for(r=1;r<t.length-1;r++)i.push(C(t[r-1],t[r],t[r+1],e));for(n+=\"Q\"+i[0][0]+\" \"+t[1],r=2;r<t.length-1;r++)n+=\"C\"+i[r-2][1]+\" \"+i[r-1][0]+\" \"+t[r];return n+=\"Q\"+i[t.length-3][1]+\" \"+t[t.length-1]},y.smoothclosed=function(t,e){if(t.length<3)return\"M\"+t.join(\"L\")+\"Z\";var r,n=\"M\"+t[0],i=t.length-1,a=[C(t[i],t[0],t[1],e)];for(r=1;r<i;r++)a.push(C(t[r-1],t[r],t[r+1],e));for(a.push(C(t[i-1],t[i],t[0],e)),r=1;r<=i;r++)n+=\"C\"+a[r-1][1]+\" \"+a[r][0]+\" \"+t[r];return n+=\"C\"+a[i][1]+\" \"+a[0][0]+\" \"+t[0]+\"Z\"};var L={hv:function(t,e){return\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)},vh:function(t,e){return\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},hvh:function(t,e){return\"H\"+n.round((t[0]+e[0])/2,2)+\"V\"+n.round(e[1],2)+\"H\"+n.round(e[0],2)},vhv:function(t,e){return\"V\"+n.round((t[1]+e[1])/2,2)+\"H\"+n.round(e[0],2)+\"V\"+n.round(e[1],2)}},I=function(t,e){return\"L\"+n.round(e[0],2)+\",\"+n.round(e[1],2)};y.steps=function(t){var e=L[t]||I;return function(t){for(var r=\"M\"+n.round(t[0][0],2)+\",\"+n.round(t[0][1],2),i=1;i<t.length;i++)r+=e(t[i-1],t[i]);return r}},y.makeTester=function(){var t=c.ensureSingleById(n.select(\"body\"),\"svg\",\"js-plotly-tester\",(function(t){t.attr(h.svgAttrs).style({position:\"absolute\",left:\"-10000px\",top:\"-10000px\",width:\"9000px\",height:\"9000px\",\"z-index\":\"1\"})})),e=c.ensureSingle(t,\"path\",\"js-reference-point\",(function(t){t.attr(\"d\",\"M0,0H1V1H0Z\").style({\"stroke-width\":0,fill:\"black\"})}));y.tester=t,y.testref=e},y.savedBBoxes={};var P=0;function z(t){var e=t.getAttribute(\"data-unformatted\");if(null!==e)return e+t.getAttribute(\"data-math\")+t.getAttribute(\"text-anchor\")+t.getAttribute(\"style\")}function O(t,e){if(!t)return null;var r=e._context;return\"url('\"+(r._exportedPlot?\"\":r._baseUrl||\"\")+\"#\"+t+\"')\"}y.bBox=function(t,e,r){var i,a,o;if(r||(r=z(t)),r){if(i=y.savedBBoxes[r])return c.extendFlat({},i)}else if(1===t.childNodes.length){var s=t.childNodes[0];if(r=z(s)){var l=+s.getAttribute(\"x\")||0,u=+s.getAttribute(\"y\")||0,h=s.getAttribute(\"transform\");if(!h){var p=y.bBox(s,!1,r);return l&&(p.left+=l,p.right+=l),u&&(p.top+=u,p.bottom+=u),p}if(r+=\"~\"+l+\"~\"+u+\"~\"+h,i=y.savedBBoxes[r])return c.extendFlat({},i)}}e?a=t:(o=y.tester.node(),a=t.cloneNode(!0),o.appendChild(a)),n.select(a).attr(\"transform\",null).call(f.positionText,0,0);var d=a.getBoundingClientRect(),g=y.testref.node().getBoundingClientRect();e||o.removeChild(a);var m={height:d.height,width:d.width,left:d.left-g.left,top:d.top-g.top,right:d.right-g.left,bottom:d.bottom-g.top};return P>=1e4&&(y.savedBBoxes={},P=0),r&&(y.savedBBoxes[r]=m),P++,c.extendFlat({},m)},y.setClipUrl=function(t,e,r){t.attr(\"clip-path\",O(e,r))},y.getTranslate=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\btranslate\\((-?\\d*\\.?\\d*)[^-\\d]*(-?\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||0,y:+e[1]||0}},y.setTranslate=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||0,r=r||0,a=a.replace(/(\\btranslate\\(.*?\\);?)/,\"\").trim(),a=(a+=u(e,r)).trim(),t[i](\"transform\",a),a},y.getScale=function(t){var e=(t[t.attr?\"attr\":\"getAttribute\"](\"transform\")||\"\").replace(/.*\\bscale\\((\\d*\\.?\\d*)[^\\d]*(\\d*\\.?\\d*)[^\\d].*/,(function(t,e,r){return[e,r].join(\" \")})).split(\" \");return{x:+e[0]||1,y:+e[1]||1}},y.setScale=function(t,e,r){var n=t.attr?\"attr\":\"getAttribute\",i=t.attr?\"attr\":\"setAttribute\",a=t[n](\"transform\")||\"\";return e=e||1,r=r||1,a=a.replace(/(\\bscale\\(.*?\\);?)/,\"\").trim(),a=(a+=\"scale(\"+e+\",\"+r+\")\").trim(),t[i](\"transform\",a),a};var D=/\\s*sc.*/;y.setPointGroupScale=function(t,e,r){if(e=e||1,r=r||1,t){var n=1===e&&1===r?\"\":\"scale(\"+e+\",\"+r+\")\";t.each((function(){var t=(this.getAttribute(\"transform\")||\"\").replace(D,\"\");t=(t+=n).trim(),this.setAttribute(\"transform\",t)}))}};var R=/translate\\([^)]*\\)\\s*$/;y.setTextPointsScale=function(t,e,r){t&&t.each((function(){var t,i=n.select(this),a=i.select(\"text\");if(a.node()){var o=parseFloat(a.attr(\"x\")||0),s=parseFloat(a.attr(\"y\")||0),l=(i.attr(\"transform\")||\"\").match(R);t=1===e&&1===r?[]:[u(o,s),\"scale(\"+e+\",\"+r+\")\",u(-o,-s)],l&&t.push(l),i.attr(\"transform\",t.join(\"\"))}}))}},{\"../../components/fx/helpers\":679,\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../registry\":911,\"../../traces/scatter/make_bubble_size_func\":1204,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale\":655,\"./symbol_defs\":666,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],666:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports={circle:{n:0,f:function(t){var e=n.round(t,2);return\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"}},square:{n:1,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"}},diamond:{n:2,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"Z\"}},cross:{n:3,f:function(t){var e=n.round(.4*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H\"+e+\"V\"+r+\"H-\"+e+\"V\"+e+\"H-\"+r+\"V-\"+e+\"H-\"+e+\"V-\"+r+\"H\"+e+\"V-\"+e+\"H\"+r+\"Z\"}},x:{n:4,f:function(t){var e=n.round(.8*t/Math.sqrt(2),2),r=\"l\"+e+\",\"+e,i=\"l\"+e+\",-\"+e,a=\"l-\"+e+\",-\"+e,o=\"l-\"+e+\",\"+e;return\"M0,\"+e+r+i+a+i+a+o+a+o+r+o+r+\"Z\"}},\"triangle-up\":{n:5,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",\"+n.round(t/2,2)+\"H\"+e+\"L0,-\"+n.round(t,2)+\"Z\"}},\"triangle-down\":{n:6,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+e+\",-\"+n.round(t/2,2)+\"H\"+e+\"L0,\"+n.round(t,2)+\"Z\"}},\"triangle-left\":{n:7,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L-\"+n.round(t,2)+\",0Z\"}},\"triangle-right\":{n:8,f:function(t){var e=n.round(2*t/Math.sqrt(3),2);return\"M-\"+n.round(t/2,2)+\",-\"+e+\"V\"+e+\"L\"+n.round(t,2)+\",0Z\"}},\"triangle-ne\":{n:9,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+r+\",-\"+e+\"H\"+e+\"V\"+r+\"Z\"}},\"triangle-se\":{n:10,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+e+\",-\"+r+\"V\"+e+\"H-\"+r+\"Z\"}},\"triangle-sw\":{n:11,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M\"+r+\",\"+e+\"H-\"+e+\"V-\"+r+\"Z\"}},\"triangle-nw\":{n:12,f:function(t){var e=n.round(.6*t,2),r=n.round(1.2*t,2);return\"M-\"+e+\",\"+r+\"V-\"+e+\"H\"+r+\"Z\"}},pentagon:{n:13,f:function(t){var e=n.round(.951*t,2),r=n.round(.588*t,2),i=n.round(-t,2),a=n.round(-.309*t,2);return\"M\"+e+\",\"+a+\"L\"+r+\",\"+n.round(.809*t,2)+\"H-\"+r+\"L-\"+e+\",\"+a+\"L0,\"+i+\"Z\"}},hexagon:{n:14,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M\"+i+\",-\"+r+\"V\"+r+\"L0,\"+e+\"L-\"+i+\",\"+r+\"V-\"+r+\"L0,-\"+e+\"Z\"}},hexagon2:{n:15,f:function(t){var e=n.round(t,2),r=n.round(t/2,2),i=n.round(t*Math.sqrt(3)/2,2);return\"M-\"+r+\",\"+i+\"H\"+r+\"L\"+e+\",0L\"+r+\",-\"+i+\"H-\"+r+\"L-\"+e+\",0Z\"}},octagon:{n:16,f:function(t){var e=n.round(.924*t,2),r=n.round(.383*t,2);return\"M-\"+r+\",-\"+e+\"H\"+r+\"L\"+e+\",-\"+r+\"V\"+r+\"L\"+r+\",\"+e+\"H-\"+r+\"L-\"+e+\",\"+r+\"V-\"+r+\"Z\"}},star:{n:17,f:function(t){var e=1.4*t,r=n.round(.225*e,2),i=n.round(.951*e,2),a=n.round(.363*e,2),o=n.round(.588*e,2),s=n.round(-e,2),l=n.round(-.309*e,2),c=n.round(.118*e,2),u=n.round(.809*e,2);return\"M\"+r+\",\"+l+\"H\"+i+\"L\"+a+\",\"+c+\"L\"+o+\",\"+u+\"L0,\"+n.round(.382*e,2)+\"L-\"+o+\",\"+u+\"L-\"+a+\",\"+c+\"L-\"+i+\",\"+l+\"H-\"+r+\"L0,\"+s+\"Z\"}},hexagram:{n:18,f:function(t){var e=n.round(.66*t,2),r=n.round(.38*t,2),i=n.round(.76*t,2);return\"M-\"+i+\",0l-\"+r+\",-\"+e+\"h\"+i+\"l\"+r+\",-\"+e+\"l\"+r+\",\"+e+\"h\"+i+\"l-\"+r+\",\"+e+\"l\"+r+\",\"+e+\"h-\"+i+\"l-\"+r+\",\"+e+\"l-\"+r+\",-\"+e+\"h-\"+i+\"Z\"}},\"star-triangle-up\":{n:19,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M-\"+e+\",\"+r+o+e+\",\"+r+o+\"0,-\"+i+o+\"-\"+e+\",\"+r+\"Z\"}},\"star-triangle-down\":{n:20,f:function(t){var e=n.round(t*Math.sqrt(3)*.8,2),r=n.round(.8*t,2),i=n.round(1.6*t,2),a=n.round(4*t,2),o=\"A \"+a+\",\"+a+\" 0 0 1 \";return\"M\"+e+\",-\"+r+o+\"-\"+e+\",-\"+r+o+\"0,\"+i+o+e+\",-\"+r+\"Z\"}},\"star-square\":{n:21,f:function(t){var e=n.round(1.1*t,2),r=n.round(2*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",-\"+e+i+\"-\"+e+\",\"+e+i+e+\",\"+e+i+e+\",-\"+e+i+\"-\"+e+\",-\"+e+\"Z\"}},\"star-diamond\":{n:22,f:function(t){var e=n.round(1.4*t,2),r=n.round(1.9*t,2),i=\"A \"+r+\",\"+r+\" 0 0 1 \";return\"M-\"+e+\",0\"+i+\"0,\"+e+i+e+\",0\"+i+\"0,-\"+e+i+\"-\"+e+\",0Z\"}},\"diamond-tall\":{n:23,f:function(t){var e=n.round(.7*t,2),r=n.round(1.4*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},\"diamond-wide\":{n:24,f:function(t){var e=n.round(1.4*t,2),r=n.round(.7*t,2);return\"M0,\"+r+\"L\"+e+\",0L0,-\"+r+\"L-\"+e+\",0Z\"}},hourglass:{n:25,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"H-\"+e+\"L\"+e+\",-\"+e+\"H-\"+e+\"Z\"},noDot:!0},bowtie:{n:26,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"V-\"+e+\"L-\"+e+\",\"+e+\"V-\"+e+\"Z\"},noDot:!0},\"circle-cross\":{n:27,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"circle-x\":{n:28,f:function(t){var e=n.round(t,2),r=n.round(t/Math.sqrt(2),2);return\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r+\"M\"+e+\",0A\"+e+\",\"+e+\" 0 1,1 0,-\"+e+\"A\"+e+\",\"+e+\" 0 0,1 \"+e+\",0Z\"},needLine:!0,noDot:!0},\"square-cross\":{n:29,f:function(t){var e=n.round(t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"square-x\":{n:30,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e+\"M\"+e+\",\"+e+\"H-\"+e+\"V-\"+e+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"diamond-cross\":{n:31,f:function(t){var e=n.round(1.3*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM0,-\"+e+\"V\"+e+\"M-\"+e+\",0H\"+e},needLine:!0,noDot:!0},\"diamond-x\":{n:32,f:function(t){var e=n.round(1.3*t,2),r=n.round(.65*t,2);return\"M\"+e+\",0L0,\"+e+\"L-\"+e+\",0L0,-\"+e+\"ZM-\"+r+\",-\"+r+\"L\"+r+\",\"+r+\"M-\"+r+\",\"+r+\"L\"+r+\",-\"+r},needLine:!0,noDot:!0},\"cross-thin\":{n:33,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"x-thin\":{n:34,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e+\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},asterisk:{n:35,f:function(t){var e=n.round(1.2*t,2),r=n.round(.85*t,2);return\"M0,\"+e+\"V-\"+e+\"M\"+e+\",0H-\"+e+\"M\"+r+\",\"+r+\"L-\"+r+\",-\"+r+\"M\"+r+\",-\"+r+\"L-\"+r+\",\"+r},needLine:!0,noDot:!0,noFill:!0},hash:{n:36,f:function(t){var e=n.round(t/2,2),r=n.round(t,2);return\"M\"+e+\",\"+r+\"V-\"+r+\"m-\"+r+\",0V\"+r+\"M\"+r+\",\"+e+\"H-\"+r+\"m0,-\"+r+\"H\"+r},needLine:!0,noFill:!0},\"y-up\":{n:37,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",\"+i+\"L0,0M\"+e+\",\"+i+\"L0,0M0,-\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-down\":{n:38,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+e+\",-\"+i+\"L0,0M\"+e+\",-\"+i+\"L0,0M0,\"+r+\"L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-left\":{n:39,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M\"+i+\",\"+e+\"L0,0M\"+i+\",-\"+e+\"L0,0M-\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"y-right\":{n:40,f:function(t){var e=n.round(1.2*t,2),r=n.round(1.6*t,2),i=n.round(.8*t,2);return\"M-\"+i+\",\"+e+\"L0,0M-\"+i+\",-\"+e+\"L0,0M\"+r+\",0L0,0\"},needLine:!0,noDot:!0,noFill:!0},\"line-ew\":{n:41,f:function(t){var e=n.round(1.4*t,2);return\"M\"+e+\",0H-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ns\":{n:42,f:function(t){var e=n.round(1.4*t,2);return\"M0,\"+e+\"V-\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-ne\":{n:43,f:function(t){var e=n.round(t,2);return\"M\"+e+\",-\"+e+\"L-\"+e+\",\"+e},needLine:!0,noDot:!0,noFill:!0},\"line-nw\":{n:44,f:function(t){var e=n.round(t,2);return\"M\"+e+\",\"+e+\"L-\"+e+\",-\"+e},needLine:!0,noDot:!0,noFill:!0},\"arrow-up\":{n:45,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-down\":{n:46,f:function(t){var e=n.round(t,2);return\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},noDot:!0},\"arrow-left\":{n:47,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-right\":{n:48,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},noDot:!0},\"arrow-bar-up\":{n:49,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-down\":{n:50,f:function(t){var e=n.round(t,2);return\"M-\"+e+\",0H\"+e+\"M0,0L-\"+e+\",-\"+n.round(2*t,2)+\"H\"+e+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-left\":{n:51,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0},\"arrow-bar-right\":{n:52,f:function(t){var e=n.round(2*t,2),r=n.round(t,2);return\"M0,-\"+r+\"V\"+r+\"M0,0L-\"+e+\",-\"+r+\"V\"+r+\"Z\"},needLine:!0,noDot:!0}}},{d3:169}],667:[function(t,e,r){\"use strict\";e.exports={visible:{valType:\"boolean\",editType:\"calc\"},type:{valType:\"enumerated\",values:[\"percent\",\"constant\",\"sqrt\",\"data\"],editType:\"calc\"},symmetric:{valType:\"boolean\",editType:\"calc\"},array:{valType:\"data_array\",editType:\"calc\"},arrayminus:{valType:\"data_array\",editType:\"calc\"},value:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},valueminus:{valType:\"number\",min:0,dflt:10,editType:\"calc\"},traceref:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},tracerefminus:{valType:\"integer\",min:0,dflt:0,editType:\"style\"},copy_ystyle:{valType:\"boolean\",editType:\"plot\"},copy_zstyle:{valType:\"boolean\",editType:\"style\"},color:{valType:\"color\",editType:\"style\"},thickness:{valType:\"number\",min:0,dflt:2,editType:\"style\"},width:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\",_deprecated:{opacity:{valType:\"number\",editType:\"style\"}}}},{}],668:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=t(\"./compute_error\");function l(t,e,r,i){var l=e[\"error_\"+i]||{},c=[];if(l.visible&&-1!==[\"linear\",\"log\"].indexOf(r.type)){for(var u=s(l),f=0;f<t.length;f++){var h=t[f],p=h.i;if(void 0===p)p=f;else if(null===p)continue;var d=h[i];if(n(r.c2l(d))){var g=u(d,p);if(n(g[0])&&n(g[1])){var m=h[i+\"s\"]=d-g[0],v=h[i+\"h\"]=d+g[1];c.push(m,v)}}}var y=r._id,x=e._extremes[y],b=a.findExtremes(r,c,o.extendFlat({tozero:x.opts.tozero},{padded:!0}));x.min=x.min.concat(b.min),x.max=x.max.concat(b.max)}}e.exports=function(t){for(var e=t.calcdata,r=0;r<e.length;r++){var n=e[r],o=n[0].trace;if(!0===o.visible&&i.traceIs(o,\"errorBarsOK\")){var s=a.getFromId(t,o.xaxis),c=a.getFromId(t,o.yaxis);l(n,o,s,\"x\"),l(n,o,c,\"y\")}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./compute_error\":669,\"fast-isnumeric\":241}],669:[function(t,e,r){\"use strict\";function n(t,e){return\"percent\"===t?function(t){return Math.abs(t*e/100)}:\"constant\"===t?function(){return Math.abs(e)}:\"sqrt\"===t?function(t){return Math.sqrt(Math.abs(t))}:void 0}e.exports=function(t){var e=t.type,r=t.symmetric;if(\"data\"===e){var i=t.array||[];if(r)return function(t,e){var r=+i[e];return[r,r]};var a=t.arrayminus||[];return function(t,e){var r=+i[e],n=+a[e];return isNaN(r)&&isNaN(n)?[NaN,NaN]:[n||0,r||0]}}var o=n(e,t.value),s=n(e,t.valueminus);return r||void 0===t.valueminus?function(t){var e=o(t);return[e,e]}:function(t){return[s(t),o(t)]}}},{}],670:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../plot_api/plot_template\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){var c=\"error_\"+l.axis,u=o.newContainer(e,c),f=t[c]||{};function h(t,e){return a.coerce(f,u,s,t,e)}if(!1!==h(\"visible\",void 0!==f.array||void 0!==f.value||\"sqrt\"===f.type)){var p=h(\"type\",\"array\"in f?\"data\":\"percent\"),d=!0;\"sqrt\"!==p&&(d=h(\"symmetric\",!((\"data\"===p?\"arrayminus\":\"valueminus\")in f))),\"data\"===p?(h(\"array\"),h(\"traceref\"),d||(h(\"arrayminus\"),h(\"tracerefminus\"))):\"percent\"!==p&&\"constant\"!==p||(h(\"value\"),d||h(\"valueminus\"));var g=\"copy_\"+l.inherit+\"style\";if(l.inherit)(e[\"error_\"+l.inherit]||{}).visible&&h(g,!(f.color||n(f.thickness)||n(f.width)));l.inherit&&u[g]||(h(\"color\",r),h(\"thickness\"),h(\"width\",i.traceIs(e,\"gl3d\")?0:4))}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"./attributes\":667,\"fast-isnumeric\":241}],671:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/edit_types\").overrideAll,a=t(\"./attributes\"),o={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a)};delete o.error_x.copy_zstyle,delete o.error_y.copy_zstyle,delete o.error_y.copy_ystyle;var s={error_x:n.extendFlat({},a),error_y:n.extendFlat({},a),error_z:n.extendFlat({},a)};delete s.error_x.copy_ystyle,delete s.error_y.copy_ystyle,delete s.error_z.copy_ystyle,delete s.error_z.copy_zstyle,e.exports={moduleType:\"component\",name:\"errorbars\",schema:{traces:{scatter:o,bar:o,histogram:o,scatter3d:i(s,\"calc\",\"nested\"),scattergl:i(o,\"calc\",\"nested\")}},supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),makeComputeError:t(\"./compute_error\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverInfo:function(t,e,r){(e.error_y||{}).visible&&(r.yerr=t.yh-t.y,e.error_y.symmetric||(r.yerrneg=t.y-t.ys));(e.error_x||{}).visible&&(r.xerr=t.xh-t.x,e.error_x.symmetric||(r.xerrneg=t.x-t.xs))}}},{\"../../lib\":778,\"../../plot_api/edit_types\":810,\"./attributes\":667,\"./calc\":668,\"./compute_error\":669,\"./defaults\":670,\"./plot\":672,\"./style\":673}],672:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../drawing\"),o=t(\"../../traces/scatter/subtypes\");e.exports=function(t,e,r,s){var l=r.xaxis,c=r.yaxis,u=s&&s.duration>0;e.each((function(e){var f,h=e[0].trace,p=h.error_x||{},d=h.error_y||{};h.ids&&(f=function(t){return t.id});var g=o.hasMarkers(h)&&h.marker.maxdisplayed>0;d.visible||p.visible||(e=[]);var m=n.select(this).selectAll(\"g.errorbar\").data(e,f);if(m.exit().remove(),e.length){p.visible||m.selectAll(\"path.xerror\").remove(),d.visible||m.selectAll(\"path.yerror\").remove(),m.style(\"opacity\",1);var v=m.enter().append(\"g\").classed(\"errorbar\",!0);u&&v.style(\"opacity\",0).transition().duration(s.duration).style(\"opacity\",1),a.setClipUrl(m,r.layerClipId,t),m.each((function(t){var e=n.select(this),r=function(t,e,r){var n={x:e.c2p(t.x),y:r.c2p(t.y)};void 0!==t.yh&&(n.yh=r.c2p(t.yh),n.ys=r.c2p(t.ys),i(n.ys)||(n.noYS=!0,n.ys=r.c2p(t.ys,!0)));void 0!==t.xh&&(n.xh=e.c2p(t.xh),n.xs=e.c2p(t.xs),i(n.xs)||(n.noXS=!0,n.xs=e.c2p(t.xs,!0)));return n}(t,l,c);if(!g||t.vis){var a,o=e.select(\"path.yerror\");if(d.visible&&i(r.x)&&i(r.yh)&&i(r.ys)){var f=d.width;a=\"M\"+(r.x-f)+\",\"+r.yh+\"h\"+2*f+\"m-\"+f+\",0V\"+r.ys,r.noYS||(a+=\"m-\"+f+\",0h\"+2*f),!o.size()?o=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"yerror\",!0):u&&(o=o.transition().duration(s.duration).ease(s.easing)),o.attr(\"d\",a)}else o.remove();var h=e.select(\"path.xerror\");if(p.visible&&i(r.y)&&i(r.xh)&&i(r.xs)){var m=(p.copy_ystyle?d:p).width;a=\"M\"+r.xh+\",\"+(r.y-m)+\"v\"+2*m+\"m0,-\"+m+\"H\"+r.xs,r.noXS||(a+=\"m0,-\"+m+\"v\"+2*m),!h.size()?h=e.append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").classed(\"xerror\",!0):u&&(h=h.transition().duration(s.duration).ease(s.easing)),h.attr(\"d\",a)}else h.remove()}}))}}))}},{\"../../traces/scatter/subtypes\":1212,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],673:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../color\");e.exports=function(t){t.each((function(t){var e=t[0].trace,r=e.error_y||{},a=e.error_x||{},o=n.select(this);o.selectAll(\"path.yerror\").style(\"stroke-width\",r.thickness+\"px\").call(i.stroke,r.color),a.copy_ystyle&&(a=r),o.selectAll(\"path.xerror\").style(\"stroke-width\",a.thickness+\"px\").call(i.stroke,a.color)}))}},{\"../color\":643,d3:169}],674:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./layout_attributes\").hoverlabel,a=t(\"../../lib/extend\").extendFlat;e.exports={hoverlabel:{bgcolor:a({},i.bgcolor,{arrayOk:!0}),bordercolor:a({},i.bordercolor,{arrayOk:!0}),font:n({arrayOk:!0,editType:\"none\"}),align:a({},i.align,{arrayOk:!0}),namelength:a({},i.namelength,{arrayOk:!0}),editType:\"none\"}}},{\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"./layout_attributes\":684}],675:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");function a(t,e,r,i){i=i||n.identity,Array.isArray(t)&&(e[0][r]=i(t))}e.exports=function(t){var e=t.calcdata,r=t._fullLayout;function o(t){return function(e){return n.coerceHoverinfo({hoverinfo:e},{_module:t._module},r)}}for(var s=0;s<e.length;s++){var l=e[s],c=l[0].trace;if(!i.traceIs(c,\"pie-like\")){var u=i.traceIs(c,\"2dMap\")?a:n.fillArray;u(c.hoverinfo,l,\"hi\",o(c)),c.hovertemplate&&u(c.hovertemplate,l,\"ht\"),c.hoverlabel&&(u(c.hoverlabel.bgcolor,l,\"hbg\"),u(c.hoverlabel.bordercolor,l,\"hbc\"),u(c.hoverlabel.font.size,l,\"hts\"),u(c.hoverlabel.font.color,l,\"htc\"),u(c.hoverlabel.font.family,l,\"htf\"),u(c.hoverlabel.namelength,l,\"hnl\"),u(c.hoverlabel.align,l,\"hta\"))}}}},{\"../../lib\":778,\"../../registry\":911}],676:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./hover\").hover;e.exports=function(t,e,r){var a=n.getComponentMethod(\"annotations\",\"onClick\")(t,t._hoverdata);function o(){t.emit(\"plotly_click\",{points:t._hoverdata,event:e})}void 0!==r&&i(t,e,r,!0),t._hoverdata&&e&&e.target&&(a&&a.then?a.then(o):o(),e.stopImmediatePropagation&&e.stopImmediatePropagation())}},{\"../../registry\":911,\"./hover\":680}],677:[function(t,e,r){\"use strict\";e.exports={YANGLE:60,HOVERARROWSIZE:6,HOVERTEXTPAD:3,HOVERFONTSIZE:13,HOVERFONT:\"Arial, sans-serif\",HOVERMINTIME:50,HOVERID:\"-hover\"}},{}],678:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r,o){var s=n.extendFlat({},o.hoverlabel);e.hovertemplate&&(s.namelength=-1),a(t,e,(function(r,a){return n.coerce(t,e,i,r,a)}),s)}},{\"../../lib\":778,\"./attributes\":674,\"./hoverlabel_defaults\":681}],679:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");r.getSubplot=function(t){return t.subplot||t.xaxis+t.yaxis||t.geo},r.isTraceInSubplots=function(t,e){if(\"splom\"===t.type){for(var n=t.xaxes||[],i=t.yaxes||[],a=0;a<n.length;a++)for(var o=0;o<i.length;o++)if(-1!==e.indexOf(n[a]+i[o]))return!0;return!1}return-1!==e.indexOf(r.getSubplot(t))},r.flat=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=e;return r},r.p2c=function(t,e){for(var r=new Array(t.length),n=0;n<t.length;n++)r[n]=t[n].p2c(e);return r},r.getDistanceFunction=function(t,e,n,i){return\"closest\"===t?i||r.quadrature(e,n):\"x\"===t.charAt(0)?e:n},r.getClosest=function(t,e,r){if(!1!==r.index)r.index>=0&&r.index<t.length?r.distance=0:r.index=!1;else for(var n=0;n<t.length;n++){var i=e(t[n]);i<=r.distance&&(r.index=n,r.distance=i)}return r},r.inbox=function(t,e,r){return t*e<0||0===t?r:1/0},r.quadrature=function(t,e){return function(r){var n=t(r),i=e(r);return Math.sqrt(n*n+i*i)}},r.makeEventData=function(t,e,n){var i=\"index\"in t?t.index:t.pointNumber,a={data:e._input,fullData:e,curveNumber:e.index,pointNumber:i};if(e._indexToPoints){var o=e._indexToPoints[i];1===o.length?a.pointIndex=o[0]:a.pointIndices=o}else a.pointIndex=i;return e._module.eventData?a=e._module.eventData(a,t,e,n,i):(\"xVal\"in t?a.x=t.xVal:\"x\"in t&&(a.x=t.x),\"yVal\"in t?a.y=t.yVal:\"y\"in t&&(a.y=t.y),t.xa&&(a.xaxis=t.xa),t.ya&&(a.yaxis=t.ya),void 0!==t.zLabelVal&&(a.z=t.zLabelVal)),r.appendArrayPointValue(a,e,i),a},r.appendArrayPointValue=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){var u=o(n.nestedProperty(e,l).get(),r);void 0!==u&&(t[c]=u)}}},r.appendArrayMultiPointValues=function(t,e,r){var i=e._arrayAttrs;if(i)for(var s=0;s<i.length;s++){var l=i[s],c=a(l);if(void 0===t[c]){for(var u=n.nestedProperty(e,l).get(),f=new Array(r.length),h=0;h<r.length;h++)f[h]=o(u,r[h]);t[c]=f}}};var i={ids:\"id\",locations:\"location\",labels:\"label\",values:\"value\",\"marker.colors\":\"color\",parents:\"parent\"};function a(t){return i[t]||t}function o(t,e){return Array.isArray(e)?Array.isArray(t)&&Array.isArray(t[e[0]])?t[e[0]][e[1]]:void 0:t[e]}var s={x:!0,y:!0},l={\"x unified\":!0,\"y unified\":!0};r.isUnifiedHover=function(t){return\"string\"==typeof t&&!!l[t]},r.isXYhover=function(t){return\"string\"==typeof t&&!!s[t]}},{\"../../lib\":778}],680:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"tinycolor2\"),o=t(\"../../lib\"),s=o.strTranslate,l=o.strRotate,c=t(\"../../lib/events\"),u=t(\"../../lib/svg_text_utils\"),f=t(\"../../lib/override_cursor\"),h=t(\"../drawing\"),p=t(\"../color\"),d=t(\"../dragelement\"),g=t(\"../../plots/cartesian/axes\"),m=t(\"../../registry\"),v=t(\"./helpers\"),y=t(\"./constants\"),x=t(\"../legend/defaults\"),b=t(\"../legend/draw\"),_=y.YANGLE,w=Math.PI*_/180,T=1/Math.sin(w),k=Math.cos(w),M=Math.sin(w),A=y.HOVERARROWSIZE,S=y.HOVERTEXTPAD;function E(t){return[t.trace.index,t.index,t.x0,t.y0,t.name,t.attr,t.xa,t.ya||\"\"].join(\",\")}r.hover=function(t,e,r,a){t=o.getGraphDiv(t),o.throttle(t._fullLayout._uid+y.HOVERID,y.HOVERMINTIME,(function(){!function(t,e,r,a){r||(r=\"xy\");var s=Array.isArray(r)?r:[r],l=t._fullLayout,u=l._plots||[],h=u[r],g=l._has(\"cartesian\");if(h){var y=h.overlays.map((function(t){return t.id}));s=s.concat(y)}for(var x=s.length,b=new Array(x),_=new Array(x),w=!1,k=0;k<x;k++){var M=s[k];if(u[M])w=!0,b[k]=u[M].xaxis,_[k]=u[M].yaxis;else{if(!l[M]||!l[M]._subplot)return void o.warn(\"Unrecognized subplot: \"+M);var A=l[M]._subplot;b[k]=A.xaxis,_[k]=A.yaxis}}var S=e.hovermode||l.hovermode;S&&!w&&(S=\"closest\");if(-1===[\"x\",\"y\",\"closest\",\"x unified\",\"y unified\"].indexOf(S)||!t.calcdata||t.querySelector(\".zoombox\")||t._dragging)return d.unhoverRaw(t,e);var C,I,R,F,B,N,j,U,V,q,H,G,Y,W=-1===l.hoverdistance?1/0:l.hoverdistance,X=-1===l.spikedistance?1/0:l.spikedistance,Z=[],J=[],K={hLinePoint:null,vLinePoint:null},Q=!1;if(Array.isArray(e))for(S=\"array\",R=0;R<e.length;R++)(B=t.calcdata[e[R].curveNumber||0])&&(N=B[0].trace,\"skip\"!==B[0].trace.hoverinfo&&(J.push(B),\"h\"===N.orientation&&(Q=!0)));else{for(F=0;F<t.calcdata.length;F++)B=t.calcdata[F],\"skip\"!==(N=B[0].trace).hoverinfo&&v.isTraceInSubplots(N,s)&&(J.push(B),\"h\"===N.orientation&&(Q=!0));var $,tt;if(!e.target)$=\"xpx\"in e?e.xpx:b[0]._length/2,tt=\"ypx\"in e?e.ypx:_[0]._length/2;else{if(!1===c.triggerHandler(t,\"plotly_beforehover\",e))return;var et=e.target.getBoundingClientRect();$=e.clientX-et.left,tt=e.clientY-et.top,l._calcInverseTransform(t);var rt=o.apply3DTransform(l._invTransform)($,tt);if($=rt[0],tt=rt[1],$<0||$>b[0]._length||tt<0||tt>_[0]._length)return d.unhoverRaw(t,e)}if(e.pointerX=$+b[0]._offset,e.pointerY=tt+_[0]._offset,C=\"xval\"in e?v.flat(s,e.xval):v.p2c(b,$),I=\"yval\"in e?v.flat(s,e.yval):v.p2c(_,tt),!i(C[0])||!i(I[0]))return o.warn(\"Fx.hover failed\",e,t),d.unhoverRaw(t,e)}var nt=1/0;function it(t,r){for(F=0;F<J.length;F++)if((B=J[F])&&B[0]&&B[0].trace&&!0===(N=B[0].trace).visible&&0!==N._length&&-1===[\"carpet\",\"contourcarpet\"].indexOf(N._module.name)){if(\"splom\"===N.type?j=s[U=0]:(j=v.getSubplot(N),U=s.indexOf(j)),V=S,v.isUnifiedHover(V)&&(V=V.charAt(0)),G={cd:B,trace:N,xa:b[U],ya:_[U],maxHoverDistance:W,maxSpikeDistance:X,index:!1,distance:Math.min(nt,W),spikeDistance:1/0,xSpike:void 0,ySpike:void 0,color:p.defaultLine,name:N.name,x0:void 0,x1:void 0,y0:void 0,y1:void 0,xLabelVal:void 0,yLabelVal:void 0,zLabelVal:void 0,text:void 0},l[j]&&(G.subplot=l[j]._subplot),l._splomScenes&&l._splomScenes[N.uid]&&(G.scene=l._splomScenes[N.uid]),Y=Z.length,\"array\"===V){var n=e[F];\"pointNumber\"in n?(G.index=n.pointNumber,V=\"closest\"):(V=\"\",\"xval\"in n&&(q=n.xval,V=\"x\"),\"yval\"in n&&(H=n.yval,V=V?\"closest\":\"y\"))}else void 0!==t&&void 0!==r?(q=t,H=r):(q=C[U],H=I[U]);if(0!==W)if(N._module&&N._module.hoverPoints){var a=N._module.hoverPoints(G,q,H,V,l._hoverlayer);if(a)for(var c,u=0;u<a.length;u++)c=a[u],i(c.x0)&&i(c.y0)&&Z.push(z(c,S))}else o.log(\"Unrecognized trace type in hover:\",N);if(\"closest\"===S&&Z.length>Y&&(Z.splice(0,Y),nt=Z[0].distance),g&&0!==X&&0===Z.length){G.distance=X,G.index=!1;var f=N._module.hoverPoints(G,q,H,\"closest\",l._hoverlayer);if(f&&(f=f.filter((function(t){return t.spikeDistance<=X}))),f&&f.length){var h,d=f.filter((function(t){return t.xa.showspikes&&\"hovered data\"!==t.xa.spikesnap}));if(d.length){var m=d[0];i(m.x0)&&i(m.y0)&&(h=ot(m),(!K.vLinePoint||K.vLinePoint.spikeDistance>h.spikeDistance)&&(K.vLinePoint=h))}var y=f.filter((function(t){return t.ya.showspikes&&\"hovered data\"!==t.ya.spikesnap}));if(y.length){var x=y[0];i(x.x0)&&i(x.y0)&&(h=ot(x),(!K.hLinePoint||K.hLinePoint.spikeDistance>h.spikeDistance)&&(K.hLinePoint=h))}}}}}function at(t,e){for(var r,n=null,i=1/0,a=0;a<t.length;a++)(r=t[a].spikeDistance)<=i&&r<=e&&(n=t[a],i=r);return n}function ot(t){return t?{xa:t.xa,ya:t.ya,x:void 0!==t.xSpike?t.xSpike:(t.x0+t.x1)/2,y:void 0!==t.ySpike?t.ySpike:(t.y0+t.y1)/2,distance:t.distance,spikeDistance:t.spikeDistance,curveNumber:t.trace.index,color:t.color,pointNumber:t.index}:null}it();var st={fullLayout:l,container:l._hoverlayer,outerContainer:l._paperdiv,event:e},lt=t._spikepoints,ct={vLinePoint:K.vLinePoint,hLinePoint:K.hLinePoint};if(t._spikepoints=ct,g&&0!==X&&0!==Z.length){var ut=at(Z.filter((function(t){return t.ya.showspikes})),X);K.hLinePoint=ot(ut);var ft=at(Z.filter((function(t){return t.xa.showspikes})),X);K.vLinePoint=ot(ft)}if(0===Z.length){var ht=d.unhoverRaw(t,e);return!g||null===K.hLinePoint&&null===K.vLinePoint||D(lt)&&O(t,K,st),ht}g&&D(lt)&&O(t,K,st);if(Z.sort((function(t,e){return t.distance-e.distance})),v.isXYhover(V)&&0!==Z[0].length&&\"splom\"!==Z[0].trace.type){var pt=Z[0],dt=pt.cd[pt.index],gt=\"group\"===l.boxmode||\"group\"===l.violinmode,mt=pt.xVal,vt=pt.xa;\"category\"===vt.type&&(mt=vt._categoriesMap[mt]),\"date\"===vt.type&&(mt=vt.d2c(mt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(mt+=dt.t.dPos);var yt=pt.yVal;\"category\"===(vt=pt.ya).type&&(yt=vt._categoriesMap[yt]),\"date\"===vt.type&&(yt=vt.d2c(yt)),dt&&dt.t&&dt.t.posLetter===vt._id&&gt&&(yt+=dt.t.dPos),it(mt,yt);var xt={};Z=Z.filter((function(t){var e=E(t);if(!xt[e])return xt[e]=!0,xt[e]}))}var bt=t._hoverdata,_t=[];for(R=0;R<Z.length;R++){var wt=Z[R],Tt=v.makeEventData(wt,wt.trace,wt.cd);if(!1!==wt.hovertemplate){var kt=!1;wt.cd[wt.index]&&wt.cd[wt.index].ht&&(kt=wt.cd[wt.index].ht),wt.hovertemplate=kt||wt.trace.hovertemplate||!1}wt.eventData=[Tt],_t.push(Tt)}t._hoverdata=_t;var Mt=\"y\"===S&&(J.length>1||Z.length>1)||\"closest\"===S&&Q&&Z.length>1,At=p.combine(l.plot_bgcolor||p.background,l.paper_bgcolor),St={hovermode:S,rotateLabels:Mt,bgColor:At,container:l._hoverlayer,outerContainer:l._paperdiv,commonLabelOpts:l.hoverlabel,hoverdistance:l.hoverdistance},Et=L(Z,St,t);v.isUnifiedHover(S)||(!function(t,e,r){var n,i,a,o,s,l,c,u=0,f=1,h=t.size(),p=new Array(h),d=0;function g(t){var e=t[0],r=t[t.length-1];if(i=e.pmin-e.pos-e.dp+e.size,a=r.pos+r.dp+r.size-e.pmax,i>.01){for(s=t.length-1;s>=0;s--)t[s].dp+=i;n=!1}if(!(a<.01)){if(i<-.01){for(s=t.length-1;s>=0;s--)t[s].dp-=a;n=!1}if(n){var c=0;for(o=0;o<t.length;o++)(l=t[o]).pos+l.dp+l.size>e.pmax&&c++;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos>e.pmax-1&&(l.del=!0,c--);for(o=0;o<t.length&&!(c<=0);o++)if((l=t[o]).pos<e.pmin+1)for(l.del=!0,c--,a=2*l.size,s=t.length-1;s>=0;s--)t[s].dp-=a;for(o=t.length-1;o>=0&&!(c<=0);o--)(l=t[o]).pos+l.dp+l.size>e.pmax&&(l.del=!0,c--)}}}t.each((function(t){var n=t[e],i=\"x\"===n._id.charAt(0),a=n.range;0===d&&a&&a[0]>a[1]!==i&&(f=-1),p[d++]=[{datum:t,traceIndex:t.trace.index,dp:0,pos:t.pos,posref:t.posref,size:t.by*(i?T:1)/2,pmin:0,pmax:i?r.width:r.height}]})),p.sort((function(t,e){return t[0].posref-e[0].posref||f*(e[0].traceIndex-t[0].traceIndex)}));for(;!n&&u<=h;){for(u++,n=!0,o=0;o<p.length-1;){var m=p[o],v=p[o+1],y=m[m.length-1],x=v[0];if((i=y.pos+y.dp+y.size-x.pos-x.dp+x.size)>.01&&y.pmin===x.pmin&&y.pmax===x.pmax){for(s=v.length-1;s>=0;s--)v[s].dp+=i;for(m.push.apply(m,v),p.splice(o+1,1),c=0,s=m.length-1;s>=0;s--)c+=m[s].dp;for(a=c/m.length,s=m.length-1;s>=0;s--)m[s].dp-=a;n=!1}else o++}p.forEach(g)}for(o=p.length-1;o>=0;o--){var b=p[o];for(s=b.length-1;s>=0;s--){var _=b[s],w=_.datum;w.offset=_.dp,w.del=_.del}}}(Et,Mt?\"xa\":\"ya\",l),P(Et,Mt,l._invScaleX,l._invScaleY));if(e.target&&e.target.tagName){var Ct=m.getComponentMethod(\"annotations\",\"hasClickToShow\")(t,_t);f(n.select(e.target),Ct?\"pointer\":\"\")}if(!e.target||a||!function(t,e,r){if(!r||r.length!==t._hoverdata.length)return!0;for(var n=r.length-1;n>=0;n--){var i=r[n],a=t._hoverdata[n];if(i.curveNumber!==a.curveNumber||String(i.pointNumber)!==String(a.pointNumber)||String(i.pointNumbers)!==String(a.pointNumbers))return!0}return!1}(t,0,bt))return;bt&&t.emit(\"plotly_unhover\",{event:e,points:bt});t.emit(\"plotly_hover\",{event:e,points:t._hoverdata,xaxes:b,yaxes:_,xvals:C,yvals:I})}(t,e,r,a)}))},r.loneHover=function(t,e){var r=!0;Array.isArray(t)||(r=!1,t=[t]);var i=t.map((function(t){return{color:t.color||p.defaultLine,x0:t.x0||t.x||0,x1:t.x1||t.x||0,y0:t.y0||t.y||0,y1:t.y1||t.y||0,xLabel:t.xLabel,yLabel:t.yLabel,zLabel:t.zLabel,text:t.text,name:t.name,idealAlign:t.idealAlign,borderColor:t.borderColor,fontFamily:t.fontFamily,fontSize:t.fontSize,fontColor:t.fontColor,nameLength:t.nameLength,textAlign:t.textAlign,trace:t.trace||{index:0,hoverinfo:\"\"},xa:{_offset:0},ya:{_offset:0},index:0,hovertemplate:t.hovertemplate||!1,eventData:t.eventData||!1,hovertemplateLabels:t.hovertemplateLabels||!1}})),a=n.select(e.container),o=e.outerContainer?n.select(e.outerContainer):a,s={hovermode:\"closest\",rotateLabels:!1,bgColor:e.bgColor||p.background,container:a,outerContainer:o},l=L(i,s,e.gd),c=0,u=0;l.sort((function(t,e){return t.y0-e.y0})).each((function(t,r){var n=t.y0-t.by/2;t.offset=n-5<c?c-n+5:0,c=n+t.by+t.offset,r===e.anchorIndex&&(u=t.offset)})).each((function(t){t.offset-=u}));var f=e.gd._fullLayout._invScaleX,h=e.gd._fullLayout._invScaleY;return P(l,s.rotateLabels,f,h),r?l:l.node()};var C=/<extra>([\\s\\S]*)<\\/extra>/;function L(t,e,r){var i=r._fullLayout,a=e.hovermode,c=e.rotateLabels,f=e.bgColor,d=e.container,g=e.outerContainer,m=e.commonLabelOpts||{},w=e.fontFamily||y.HOVERFONT,T=e.fontSize||y.HOVERFONTSIZE,k=t[0],M=k.xa,C=k.ya,L=\"y\"===a.charAt(0)?\"yLabel\":\"xLabel\",P=k[L],z=(String(P)||\"\").split(\" \")[0],O=g.node().getBoundingClientRect(),D=O.top,R=O.width,F=O.height,B=void 0!==P&&k.distance<=e.hoverdistance&&(\"x\"===a||\"y\"===a);if(B){var N,j,U=!0;for(N=0;N<t.length;N++)if(U&&void 0===t[N].zLabel&&(U=!1),j=t[N].hoverinfo||t[N].trace.hoverinfo){var V=Array.isArray(j)?j:j.split(\"+\");if(-1===V.indexOf(\"all\")&&-1===V.indexOf(a)){B=!1;break}}U&&(B=!1)}var q=d.selectAll(\"g.axistext\").data(B?[0]:[]);function H(t){return t.filter((function(t){return void 0!==t.zLabelVal||(t[L]||\"\").split(\" \")[0]===z}))}if(q.enter().append(\"g\").classed(\"axistext\",!0),q.exit().remove(),q.each((function(){var e=n.select(this),l=o.ensureSingle(e,\"path\",\"\",(function(t){t.style({\"stroke-width\":\"1px\"})})),c=o.ensureSingle(e,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),f=m.bgcolor||p.defaultLine,d=m.bordercolor||p.contrast(f),g=p.contrast(f),v={family:m.font.family||w,size:m.font.size||T,color:m.font.color||g};l.style({fill:f,stroke:d}),c.text(P).call(h.font,v).call(u.positionText,0,0).call(u.convertToTspans,r),e.attr(\"transform\",\"\");var y,x,b=c.node().getBoundingClientRect();if(\"x\"===a){var _=\"top\"===M.side?\"-\":\"\";c.attr(\"text-anchor\",\"middle\").call(u.positionText,0,\"top\"===M.side?D-b.bottom-A-S:D-b.top+A+S),y=M._offset+(k.x0+k.x1)/2,x=C._offset+(\"top\"===M.side?0:C._length);var E=b.width/2+S;y<E?(y=E,l.attr(\"d\",\"M-\"+(E-A)+\",0L-\"+(E-2*A)+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"Z\")):y>i.width-E?(y=i.width-E,l.attr(\"d\",\"M\"+(E-A)+\",0L\"+E+\",\"+_+A+\"v\"+_+(2*S+b.height)+\"H-\"+E+\"V\"+_+A+\"H\"+(E-2*A)+\"Z\")):l.attr(\"d\",\"M0,0L\"+A+\",\"+_+A+\"H\"+(S+b.width/2)+\"v\"+_+(2*S+b.height)+\"H-\"+(S+b.width/2)+\"V\"+_+A+\"H-\"+A+\"Z\")}else{var L,I,z;\"right\"===C.side?(L=\"start\",I=1,z=\"\",y=M._offset+M._length):(L=\"end\",I=-1,z=\"-\",y=M._offset),x=C._offset+(k.y0+k.y1)/2,c.attr(\"text-anchor\",L),l.attr(\"d\",\"M0,0L\"+z+A+\",\"+A+\"V\"+(S+b.height/2)+\"h\"+z+(2*S+b.width)+\"V-\"+(S+b.height/2)+\"H\"+z+A+\"V-\"+A+\"Z\");var O,R=b.height/2,F=D-b.top-R,B=\"clip\"+i._uid+\"commonlabel\"+C._id;if(y<b.width+2*S+A){O=\"M-\"+(A+S)+\"-\"+R+\"h-\"+(b.width-S)+\"V\"+R+\"h\"+(b.width-S)+\"Z\";var N=b.width-y+S;u.positionText(c,N,F),\"end\"===L&&c.selectAll(\"tspan\").each((function(){var t=n.select(this),e=h.tester.append(\"text\").text(t.text()).call(h.font,v),r=e.node().getBoundingClientRect();Math.round(r.width)<Math.round(b.width)&&t.attr(\"x\",N-r.width),e.remove()}))}else u.positionText(c,I*(S+A),F),O=null;var j=i._topclips.selectAll(\"#\"+B).data(O?[0]:[]);j.enter().append(\"clipPath\").attr(\"id\",B).append(\"path\"),j.exit().remove(),j.select(\"path\").attr(\"d\",O),h.setClipUrl(c,O?B:null,r)}e.attr(\"transform\",s(y,x)),t=H(t)})),v.isUnifiedHover(a)){if(d.selectAll(\"g.hovertext\").remove(),void 0!==P&&k.distance<=e.hoverdistance&&(t=H(t)),0===t.length)return;var G={showlegend:!0,legend:{title:{text:P,font:i.hoverlabel.font},font:i.hoverlabel.font,bgcolor:i.hoverlabel.bgcolor,bordercolor:i.hoverlabel.bordercolor,borderwidth:1,tracegroupgap:7,traceorder:i.legend?i.legend.traceorder:void 0,orientation:\"v\"}},Y={};x(G,Y,r._fullData);var W=Y.legend;W.entries=[];for(var X=0;X<t.length;X++){var Z=I(t[X],!0,a,i,P),J=Z[0],K=Z[1],Q=t[X];Q.name=K,Q.text=\"\"!==K?K+\" : \"+J:J;var $=Q.cd[Q.index];$&&($.mc&&(Q.mc=$.mc),$.mcc&&(Q.mc=$.mcc),$.mlc&&(Q.mlc=$.mlc),$.mlcc&&(Q.mlc=$.mlcc),$.mlw&&(Q.mlw=$.mlw),$.mrc&&(Q.mrc=$.mrc),$.dir&&(Q.dir=$.dir)),Q._distinct=!0,W.entries.push([Q])}W.entries.sort((function(t,e){return t[0].trace.index-e[0].trace.index})),W.layer=d,b(r,W);var tt=o.mean(t.map((function(t){return(t.y0+t.y1)/2}))),et=o.mean(t.map((function(t){return(t.x0+t.x1)/2}))),rt=d.select(\"g.legend\"),nt=rt.node().getBoundingClientRect();et+=M._offset,tt+=C._offset-nt.height/2;var it=nt.width+2*S;!(et+it<=R)&&et-it>=0?et-=it:et+=2*S;var at=nt.height+2*S,ot=tt+at>=F;return at<=F&&(tt<=D?tt=C._offset+2*S:ot&&(tt=F-at)),rt.attr(\"transform\",s(et,tt)),rt}var st=d.selectAll(\"g.hovertext\").data(t,(function(t){return E(t)}));return st.enter().append(\"g\").classed(\"hovertext\",!0).each((function(){var t=n.select(this);t.append(\"rect\").call(p.fill,p.addOpacity(f,.8)),t.append(\"text\").classed(\"name\",!0),t.append(\"path\").style(\"stroke-width\",\"1px\"),t.append(\"text\").classed(\"nums\",!0).call(h.font,w,T)})),st.exit().remove(),st.each((function(t){var e=n.select(this).attr(\"transform\",\"\"),o=t.color;Array.isArray(o)&&(o=o[t.eventData[0].pointNumber]);var d=t.bgcolor||o,g=p.combine(p.opacity(d)?d:p.defaultLine,f),m=p.combine(p.opacity(o)?o:p.defaultLine,f),v=t.borderColor||p.contrast(g),y=I(t,B,a,i,P,e),x=y[0],b=y[1],k=e.select(\"text.nums\").call(h.font,t.fontFamily||w,t.fontSize||T,t.fontColor||v).text(x).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r),M=e.select(\"text.name\"),E=0,C=0;if(b&&b!==x){M.call(h.font,t.fontFamily||w,t.fontSize||T,m).text(b).attr(\"data-notex\",1).call(u.positionText,0,0).call(u.convertToTspans,r);var L=M.node().getBoundingClientRect();E=L.width+2*S,C=L.height+2*S}else M.remove(),e.select(\"rect\").remove();e.select(\"path\").style({fill:g,stroke:v});var z,O,N=k.node().getBoundingClientRect(),j=t.xa._offset+(t.x0+t.x1)/2,U=t.ya._offset+(t.y0+t.y1)/2,V=Math.abs(t.x1-t.x0),q=Math.abs(t.y1-t.y0),H=N.width+A+S+E;if(t.ty0=D-N.top,t.bx=N.width+2*S,t.by=Math.max(N.height+2*S,C),t.anchor=\"start\",t.txwidth=N.width,t.tx2width=E,t.offset=0,c)t.pos=j,z=U+q/2+H<=F,O=U-q/2-H>=0,\"top\"!==t.idealAlign&&z||!O?z?(U+=q/2,t.anchor=\"start\"):t.anchor=\"middle\":(U-=q/2,t.anchor=\"end\");else if(t.pos=U,z=j+V/2+H<=R,O=j-V/2-H>=0,\"left\"!==t.idealAlign&&z||!O)if(z)j+=V/2,t.anchor=\"start\";else{t.anchor=\"middle\";var G=H/2,Y=j+G-R,W=j-G;Y>0&&(j-=Y),W<0&&(j+=-W)}else j-=V/2,t.anchor=\"end\";k.attr(\"text-anchor\",t.anchor),E&&M.attr(\"text-anchor\",t.anchor),e.attr(\"transform\",s(j,U)+(c?l(_):\"\"))})),st}function I(t,e,r,n,i,a){var s=\"\",l=\"\";void 0!==t.nameOverride&&(t.name=t.nameOverride),t.name&&(t.trace._meta&&(t.name=o.templateString(t.name,t.trace._meta)),s=R(t.name,t.nameLength)),void 0!==t.zLabel?(void 0!==t.xLabel&&(l+=\"x: \"+t.xLabel+\"<br>\"),void 0!==t.yLabel&&(l+=\"y: \"+t.yLabel+\"<br>\"),\"choropleth\"!==t.trace.type&&\"choroplethmapbox\"!==t.trace.type&&(l+=(l?\"z: \":\"\")+t.zLabel)):e&&t[r.charAt(0)+\"Label\"]===i?l=t[(\"x\"===r.charAt(0)?\"y\":\"x\")+\"Label\"]||\"\":void 0===t.xLabel?void 0!==t.yLabel&&\"scattercarpet\"!==t.trace.type&&(l=t.yLabel):l=void 0===t.yLabel?t.xLabel:\"(\"+t.xLabel+\", \"+t.yLabel+\")\",!t.text&&0!==t.text||Array.isArray(t.text)||(l+=(l?\"<br>\":\"\")+t.text),void 0!==t.extraText&&(l+=(l?\"<br>\":\"\")+t.extraText),a&&\"\"===l&&!t.hovertemplate&&(\"\"===s&&a.remove(),l=s);var c=n._d3locale,u=t.hovertemplate||!1,f=t.hovertemplateLabels||t,h=t.eventData[0]||{};return u&&(l=(l=o.hovertemplateString(u,f,c,h,t.trace._meta)).replace(C,(function(e,r){return s=R(r,t.nameLength),\"\"}))),[l,s]}function P(t,e,r,i){var a=function(t){return t*r},o=function(t){return t*i};t.each((function(t){var r=n.select(this);if(t.del)return r.remove();var i=r.select(\"text.nums\"),s=t.anchor,l=\"end\"===s?-1:1,c={start:1,end:-1,middle:0}[s],f=c*(A+S),p=f+c*(t.txwidth+S),d=0,g=t.offset,m=\"middle\"===s;m&&(f-=t.tx2width/2,p+=t.txwidth/2+S),e&&(g*=-M,d=t.offset*k),r.select(\"path\").attr(\"d\",m?\"M-\"+a(t.bx/2+t.tx2width/2)+\",\"+o(g-t.by/2)+\"h\"+a(t.bx)+\"v\"+o(t.by)+\"h-\"+a(t.bx)+\"Z\":\"M0,0L\"+a(l*A+d)+\",\"+o(A+g)+\"v\"+o(t.by/2-A)+\"h\"+a(l*t.bx)+\"v-\"+o(t.by)+\"H\"+a(l*A+d)+\"V\"+o(g-A)+\"Z\");var v=d+f,y=g+t.ty0-t.by/2+S,x=t.textAlign||\"auto\";\"auto\"!==x&&(\"left\"===x&&\"start\"!==s?(i.attr(\"text-anchor\",\"start\"),v=m?-t.bx/2-t.tx2width/2+S:-t.bx-S):\"right\"===x&&\"end\"!==s&&(i.attr(\"text-anchor\",\"end\"),v=m?t.bx/2-t.tx2width/2-S:t.bx+S)),i.call(u.positionText,a(v),o(y)),t.tx2width&&(r.select(\"text.name\").call(u.positionText,a(p+c*S+d),o(g+t.ty0-t.by/2+S)),r.select(\"rect\").call(h.setRect,a(p+(c-1)*t.tx2width/2+d),o(g-t.by/2-1),a(t.tx2width),o(t.by+2)))}))}function z(t,e){var r=t.index,n=t.trace||{},a=t.cd[0],s=t.cd[r]||{};function l(t){return t||i(t)&&0===t}var c=Array.isArray(r)?function(t,e){var i=o.castOption(a,r,t);return l(i)?i:o.extractOption({},n,\"\",e)}:function(t,e){return o.extractOption(s,n,t,e)};function u(e,r,n){var i=c(r,n);l(i)&&(t[e]=i)}if(u(\"hoverinfo\",\"hi\",\"hoverinfo\"),u(\"bgcolor\",\"hbg\",\"hoverlabel.bgcolor\"),u(\"borderColor\",\"hbc\",\"hoverlabel.bordercolor\"),u(\"fontFamily\",\"htf\",\"hoverlabel.font.family\"),u(\"fontSize\",\"hts\",\"hoverlabel.font.size\"),u(\"fontColor\",\"htc\",\"hoverlabel.font.color\"),u(\"nameLength\",\"hnl\",\"hoverlabel.namelength\"),u(\"textAlign\",\"hta\",\"hoverlabel.align\"),t.posref=\"y\"===e||\"closest\"===e&&\"h\"===n.orientation?t.xa._offset+(t.x0+t.x1)/2:t.ya._offset+(t.y0+t.y1)/2,t.x0=o.constrain(t.x0,0,t.xa._length),t.x1=o.constrain(t.x1,0,t.xa._length),t.y0=o.constrain(t.y0,0,t.ya._length),t.y1=o.constrain(t.y1,0,t.ya._length),void 0!==t.xLabelVal&&(t.xLabel=\"xLabel\"in t?t.xLabel:g.hoverLabelText(t.xa,t.xLabelVal),t.xVal=t.xa.c2d(t.xLabelVal)),void 0!==t.yLabelVal&&(t.yLabel=\"yLabel\"in t?t.yLabel:g.hoverLabelText(t.ya,t.yLabelVal),t.yVal=t.ya.c2d(t.yLabelVal)),void 0!==t.zLabelVal&&void 0===t.zLabel&&(t.zLabel=String(t.zLabelVal)),!(isNaN(t.xerr)||\"log\"===t.xa.type&&t.xerr<=0)){var f=g.tickText(t.xa,t.xa.c2l(t.xerr),\"hover\").text;void 0!==t.xerrneg?t.xLabel+=\" +\"+f+\" / -\"+g.tickText(t.xa,t.xa.c2l(t.xerrneg),\"hover\").text:t.xLabel+=\" \\xb1 \"+f,\"x\"===e&&(t.distance+=1)}if(!(isNaN(t.yerr)||\"log\"===t.ya.type&&t.yerr<=0)){var h=g.tickText(t.ya,t.ya.c2l(t.yerr),\"hover\").text;void 0!==t.yerrneg?t.yLabel+=\" +\"+h+\" / -\"+g.tickText(t.ya,t.ya.c2l(t.yerrneg),\"hover\").text:t.yLabel+=\" \\xb1 \"+h,\"y\"===e&&(t.distance+=1)}var p=t.hoverinfo||t.trace.hoverinfo;return p&&\"all\"!==p&&(-1===(p=Array.isArray(p)?p:p.split(\"+\")).indexOf(\"x\")&&(t.xLabel=void 0),-1===p.indexOf(\"y\")&&(t.yLabel=void 0),-1===p.indexOf(\"z\")&&(t.zLabel=void 0),-1===p.indexOf(\"text\")&&(t.text=void 0),-1===p.indexOf(\"name\")&&(t.name=void 0)),t}function O(t,e,r){var n,i,o=r.container,s=r.fullLayout,l=s._size,c=r.event,u=!!e.hLinePoint,f=!!e.vLinePoint;if(o.selectAll(\".spikeline\").remove(),f||u){var d=p.combine(s.plot_bgcolor,s.paper_bgcolor);if(u){var m,v,y=e.hLinePoint;n=y&&y.xa,\"cursor\"===(i=y&&y.ya).spikesnap?(m=c.pointerX,v=c.pointerY):(m=n._offset+y.x,v=i._offset+y.y);var x,b,_=a.readability(y.color,d)<1.5?p.contrast(d):y.color,w=i.spikemode,T=i.spikethickness,k=i.spikecolor||_,M=g.getPxPosition(t,i);if(-1!==w.indexOf(\"toaxis\")||-1!==w.indexOf(\"across\")){if(-1!==w.indexOf(\"toaxis\")&&(x=M,b=m),-1!==w.indexOf(\"across\")){var A=i._counterDomainMin,S=i._counterDomainMax;\"free\"===i.anchor&&(A=Math.min(A,i.position),S=Math.max(S,i.position)),x=l.l+A*l.w,b=l.l+S*l.w}o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T,stroke:k,\"stroke-dasharray\":h.dashStyle(i.spikedash,T)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:x,x2:b,y1:v,y2:v,\"stroke-width\":T+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==w.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:M+(\"right\"!==i.side?T:-T),cy:v,r:T,fill:k}).classed(\"spikeline\",!0)}if(f){var E,C,L=e.vLinePoint;n=L&&L.xa,i=L&&L.ya,\"cursor\"===n.spikesnap?(E=c.pointerX,C=c.pointerY):(E=n._offset+L.x,C=i._offset+L.y);var I,P,z=a.readability(L.color,d)<1.5?p.contrast(d):L.color,O=n.spikemode,D=n.spikethickness,R=n.spikecolor||z,F=g.getPxPosition(t,n);if(-1!==O.indexOf(\"toaxis\")||-1!==O.indexOf(\"across\")){if(-1!==O.indexOf(\"toaxis\")&&(I=F,P=C),-1!==O.indexOf(\"across\")){var B=n._counterDomainMin,N=n._counterDomainMax;\"free\"===n.anchor&&(B=Math.min(B,n.position),N=Math.max(N,n.position)),I=l.t+(1-N)*l.h,P=l.t+(1-B)*l.h}o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D,stroke:R,\"stroke-dasharray\":h.dashStyle(n.spikedash,D)}).classed(\"spikeline\",!0).classed(\"crisp\",!0),o.insert(\"line\",\":first-child\").attr({x1:E,x2:E,y1:I,y2:P,\"stroke-width\":D+2,stroke:d}).classed(\"spikeline\",!0).classed(\"crisp\",!0)}-1!==O.indexOf(\"marker\")&&o.insert(\"circle\",\":first-child\").attr({cx:E,cy:F-(\"top\"!==n.side?D:-D),r:D,fill:R}).classed(\"spikeline\",!0)}}}function D(t,e){return!e||(e.vLinePoint!==t._spikepoints.vLinePoint||e.hLinePoint!==t._spikepoints.hLinePoint)}function R(t,e){return u.plainText(t||\"\",{len:e,allowedTags:[\"br\",\"sub\",\"sup\",\"b\",\"i\",\"em\"]})}},{\"../../lib\":778,\"../../lib/events\":767,\"../../lib/override_cursor\":789,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../legend/defaults\":695,\"../legend/draw\":696,\"./constants\":677,\"./helpers\":679,d3:169,\"fast-isnumeric\":241,tinycolor2:576}],681:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"./helpers\").isUnifiedHover;e.exports=function(t,e,r,o){function s(t){o.font[t]||(o.font[t]=e.legend?e.legend.font[t]:e.font[t])}o=o||{},e&&a(e.hovermode)&&(o.font||(o.font={}),s(\"size\"),s(\"family\"),s(\"color\"),e.legend?(o.bgcolor||(o.bgcolor=i.combine(e.legend.bgcolor,e.paper_bgcolor)),o.bordercolor||(o.bordercolor=e.legend.bordercolor)):o.bgcolor||(o.bgcolor=e.paper_bgcolor)),r(\"hoverlabel.bgcolor\",o.bgcolor),r(\"hoverlabel.bordercolor\",o.bordercolor),r(\"hoverlabel.namelength\",o.namelength),n.coerceFont(r,\"hoverlabel.font\",o.font),r(\"hoverlabel.align\",o.align)}},{\"../../lib\":778,\"../color\":643,\"./helpers\":679}],682:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){function a(r,a){return void 0!==e[r]?e[r]:n.coerce(t,e,i,r,a)}var o,s=a(\"clickmode\");return e._has(\"cartesian\")?s.indexOf(\"select\")>-1?o=\"closest\":(e._isHoriz=function(t,e){for(var r=e._scatterStackOpts||{},n=0;n<t.length;n++){var i=t[n],a=i.xaxis+i.yaxis,o=(r[a]||{})[i.stackgroup]||{};if(\"h\"!==i.orientation&&\"h\"!==o.orientation)return!1}return!0}(r,e),o=e._isHoriz?\"y\":\"x\"):o=\"closest\",a(\"hovermode\",o)}},{\"../../lib\":778,\"./layout_attributes\":684}],683:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../dragelement\"),o=t(\"./helpers\"),s=t(\"./layout_attributes\"),l=t(\"./hover\");e.exports={moduleType:\"component\",name:\"fx\",constants:t(\"./constants\"),schema:{layout:s},attributes:t(\"./attributes\"),layoutAttributes:s,supplyLayoutGlobalDefaults:t(\"./layout_global_defaults\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),getDistanceFunction:o.getDistanceFunction,getClosest:o.getClosest,inbox:o.inbox,quadrature:o.quadrature,appendArrayPointValue:o.appendArrayPointValue,castHoverOption:function(t,e,r){return i.castOption(t,e,\"hoverlabel.\"+r)},castHoverinfo:function(t,e,r){return i.castOption(t,r,\"hoverinfo\",(function(r){return i.coerceHoverinfo({hoverinfo:r},{_module:t._module},e)}))},hover:l.hover,unhover:a.unhover,loneHover:l.loneHover,loneUnhover:function(t){var e=i.isD3Selection(t)?t:n.select(t);e.selectAll(\"g.hovertext\").remove(),e.selectAll(\".spikeline\").remove()},click:t(\"./click\")}},{\"../../lib\":778,\"../dragelement\":662,\"./attributes\":674,\"./calc\":675,\"./click\":676,\"./constants\":677,\"./defaults\":678,\"./helpers\":679,\"./hover\":680,\"./layout_attributes\":684,\"./layout_defaults\":685,\"./layout_global_defaults\":686,d3:169}],684:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../plots/font_attributes\")({editType:\"none\"});i.family.dflt=n.HOVERFONT,i.size.dflt=n.HOVERFONTSIZE,e.exports={clickmode:{valType:\"flaglist\",flags:[\"event\",\"select\"],dflt:\"event\",editType:\"plot\",extras:[\"none\"]},dragmode:{valType:\"enumerated\",values:[\"zoom\",\"pan\",\"select\",\"lasso\",\"drawclosedpath\",\"drawopenpath\",\"drawline\",\"drawrect\",\"drawcircle\",\"orbit\",\"turntable\",!1],dflt:\"zoom\",editType:\"modebar\"},hovermode:{valType:\"enumerated\",values:[\"x\",\"y\",\"closest\",!1,\"x unified\",\"y unified\"],editType:\"modebar\"},hoverdistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},spikedistance:{valType:\"integer\",min:-1,dflt:20,editType:\"none\"},hoverlabel:{bgcolor:{valType:\"color\",editType:\"none\"},bordercolor:{valType:\"color\",editType:\"none\"},font:i,align:{valType:\"enumerated\",values:[\"left\",\"right\",\"auto\"],dflt:\"auto\",editType:\"none\"},namelength:{valType:\"integer\",min:-1,dflt:15,editType:\"none\"},editType:\"none\"},selectdirection:{valType:\"enumerated\",values:[\"h\",\"v\",\"d\",\"any\"],dflt:\"any\",editType:\"none\"}}},{\"../../plots/font_attributes\":856,\"./constants\":677}],685:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./helpers\").isUnifiedHover,a=t(\"./layout_attributes\"),o=t(\"./hovermode_defaults\"),s=t(\"./hoverlabel_defaults\");e.exports=function(t,e,r){function l(r,i){return n.coerce(t,e,a,r,i)}var c=o(t,e,r);c&&(l(\"hoverdistance\"),l(\"spikedistance\",i(c)?-1:void 0)),\"select\"===l(\"dragmode\")&&l(\"selectdirection\");var u=e._has(\"mapbox\"),f=e._has(\"geo\"),h=e._basePlotModules.length;\"zoom\"===e.dragmode&&((u||f)&&1===h||u&&f&&2===h)&&(e.dragmode=\"pan\"),s(t,e,l)}},{\"../../lib\":778,\"./helpers\":679,\"./hoverlabel_defaults\":681,\"./hovermode_defaults\":682,\"./layout_attributes\":684}],686:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./hoverlabel_defaults\"),a=t(\"./layout_attributes\");e.exports=function(t,e){i(t,e,(function(r,i){return n.coerce(t,e,a,r,i)}))}},{\"../../lib\":778,\"./hoverlabel_defaults\":681,\"./layout_attributes\":684}],687:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/regex\").counter,a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/cartesian/constants\").idRegex,s=t(\"../../plot_api/plot_template\"),l={rows:{valType:\"integer\",min:1,editType:\"plot\"},roworder:{valType:\"enumerated\",values:[\"top to bottom\",\"bottom to top\"],dflt:\"top to bottom\",editType:\"plot\"},columns:{valType:\"integer\",min:1,editType:\"plot\"},subplots:{valType:\"info_array\",freeLength:!0,dimensions:2,items:{valType:\"enumerated\",values:[i(\"xy\").toString(),\"\"],editType:\"plot\"},editType:\"plot\"},xaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.x.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},yaxes:{valType:\"info_array\",freeLength:!0,items:{valType:\"enumerated\",values:[o.y.toString(),\"\"],editType:\"plot\"},editType:\"plot\"},pattern:{valType:\"enumerated\",values:[\"independent\",\"coupled\"],dflt:\"coupled\",editType:\"plot\"},xgap:{valType:\"number\",min:0,max:1,editType:\"plot\"},ygap:{valType:\"number\",min:0,max:1,editType:\"plot\"},domain:a({name:\"grid\",editType:\"plot\",noGridCell:!0},{}),xside:{valType:\"enumerated\",values:[\"bottom\",\"bottom plot\",\"top plot\",\"top\"],dflt:\"bottom plot\",editType:\"plot\"},yside:{valType:\"enumerated\",values:[\"left\",\"left plot\",\"right plot\",\"right\"],dflt:\"left plot\",editType:\"plot\"},editType:\"plot\"};function c(t,e,r){var n=e[r+\"axes\"],i=Object.keys((t._splomAxes||{})[r]||{});return Array.isArray(n)?n:i.length?i:void 0}function u(t,e,r,n,i,a){var o=e(t+\"gap\",r),s=e(\"domain.\"+t);e(t+\"side\",n);for(var l=new Array(i),c=s[0],u=(s[1]-c)/(i-o),f=u*(1-o),h=0;h<i;h++){var p=c+u*h;l[a?i-1-h:h]=[p,p+f]}return l}function f(t,e,r,n,i){var a,o=new Array(r);function s(t,r){-1!==e.indexOf(r)&&void 0===n[r]?(o[t]=r,n[r]=t):o[t]=\"\"}if(Array.isArray(t))for(a=0;a<r;a++)s(a,t[a]);else for(s(0,i),a=1;a<r;a++)s(a,i+(a+1));return o}e.exports={moduleType:\"component\",name:\"grid\",schema:{layout:{grid:l}},layoutAttributes:l,sizeDefaults:function(t,e){var r=t.grid||{},i=c(e,r,\"x\"),a=c(e,r,\"y\");if(t.grid||i||a){var o,f,h=Array.isArray(r.subplots)&&Array.isArray(r.subplots[0]),p=Array.isArray(i),d=Array.isArray(a),g=p&&i!==r.xaxes&&d&&a!==r.yaxes;h?(o=r.subplots.length,f=r.subplots[0].length):(d&&(o=a.length),p&&(f=i.length));var m=s.newContainer(e,\"grid\"),v=k(\"rows\",o),y=k(\"columns\",f);if(v*y>1){if(!h&&!p&&!d)\"independent\"===k(\"pattern\")&&(h=!0);m._hasSubplotGrid=h;var x,b,_=\"top to bottom\"===k(\"roworder\"),w=h?.2:.1,T=h?.3:.1;g&&e._splomGridDflt&&(x=e._splomGridDflt.xside,b=e._splomGridDflt.yside),m._domains={x:u(\"x\",k,w,x,y),y:u(\"y\",k,T,b,v,_)}}else delete e.grid}function k(t,e){return n.coerce(r,m,l,t,e)}},contentDefaults:function(t,e){var r=e.grid;if(r&&r._domains){var n,i,a,o,s,l,u,h=t.grid||{},p=e._subplots,d=r._hasSubplotGrid,g=r.rows,m=r.columns,v=\"independent\"===r.pattern,y=r._axisMap={};if(d){var x=h.subplots||[];l=r.subplots=new Array(g);var b=1;for(n=0;n<g;n++){var _=l[n]=new Array(m),w=x[n]||[];for(i=0;i<m;i++)if(v?(s=1===b?\"xy\":\"x\"+b+\"y\"+b,b++):s=w[i],_[i]=\"\",-1!==p.cartesian.indexOf(s)){if(u=s.indexOf(\"y\"),a=s.slice(0,u),o=s.slice(u),void 0!==y[a]&&y[a]!==i||void 0!==y[o]&&y[o]!==n)continue;_[i]=s,y[a]=i,y[o]=n}}}else{var T=c(e,h,\"x\"),k=c(e,h,\"y\");r.xaxes=f(T,p.xaxis,m,y,\"x\"),r.yaxes=f(k,p.yaxis,g,y,\"y\")}var M=r._anchors={},A=\"top to bottom\"===r.roworder;for(var S in y){var E,C,L,I=S.charAt(0),P=r[I+\"side\"];if(P.length<8)M[S]=\"free\";else if(\"x\"===I){if(\"t\"===P.charAt(0)===A?(E=0,C=1,L=g):(E=g-1,C=-1,L=-1),d){var z=y[S];for(n=E;n!==L;n+=C)if((s=l[n][z])&&(u=s.indexOf(\"y\"),s.slice(0,u)===S)){M[S]=s.slice(u);break}}else for(n=E;n!==L;n+=C)if(o=r.yaxes[n],-1!==p.cartesian.indexOf(S+o)){M[S]=o;break}}else if(\"l\"===P.charAt(0)?(E=0,C=1,L=m):(E=m-1,C=-1,L=-1),d){var O=y[S];for(n=E;n!==L;n+=C)if((s=l[O][n])&&(u=s.indexOf(\"y\"),s.slice(u)===S)){M[S]=s.slice(0,u);break}}else for(n=E;n!==L;n+=C)if(a=r.xaxes[n],-1!==p.cartesian.indexOf(a+S)){M[S]=a;break}}}}}},{\"../../lib\":778,\"../../lib/regex\":795,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/domain\":855}],688:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/constants\"),i=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=i(\"image\",{visible:{valType:\"boolean\",dflt:!0,editType:\"arraydraw\"},source:{valType:\"string\",editType:\"arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},sizex:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizey:{valType:\"number\",dflt:0,editType:\"arraydraw\"},sizing:{valType:\"enumerated\",values:[\"fill\",\"contain\",\"stretch\"],dflt:\"contain\",editType:\"arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},x:{valType:\"any\",dflt:0,editType:\"arraydraw\"},y:{valType:\"any\",dflt:0,editType:\"arraydraw\"},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"arraydraw\"},yanchor:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"top\",editType:\"arraydraw\"},xref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.x.toString()],dflt:\"paper\",editType:\"arraydraw\"},yref:{valType:\"enumerated\",values:[\"paper\",n.idRegex.y.toString()],dflt:\"paper\",editType:\"arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834}],689:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib/to_log_range\");e.exports=function(t,e,r,a){e=e||{};var o=\"log\"===r&&\"linear\"===e.type,s=\"linear\"===r&&\"log\"===e.type;if(o||s)for(var l,c,u=t._fullLayout.images,f=e._id.charAt(0),h=0;h<u.length;h++)if(c=\"images[\"+h+\"].\",(l=u[h])[f+\"ref\"]===e._id){var p=l[f],d=l[\"size\"+f],g=null,m=null;if(o){g=i(p,e.range);var v=d/Math.pow(10,g)/2;m=2*Math.log(v+Math.sqrt(1+v*v))/Math.LN10}else m=(g=Math.pow(10,p))*(Math.pow(10,d/2)-Math.pow(10,-d/2));n(g)?n(m)||(m=null):(g=null,m=null),a(c+f,g),a(c+\"size\"+f,m)}}},{\"../../lib/to_log_range\":805,\"fast-isnumeric\":241}],690:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\");function s(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}var s=a(\"source\");if(!a(\"visible\",!!s))return e;a(\"layer\"),a(\"xanchor\"),a(\"yanchor\"),a(\"sizex\"),a(\"sizey\"),a(\"sizing\"),a(\"opacity\");for(var l={_fullLayout:r},c=[\"x\",\"y\"],u=0;u<2;u++){var f=c[u],h=i.coerceRef(t,e,l,f,\"paper\",void 0);if(\"paper\"!==h)i.getFromId(l,h)._imgIndices.push(e._index);i.coercePosition(e,l,a,h,f,0)}return e}e.exports=function(t,e){a(t,e,{name:\"images\",handleItemDefaults:s})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":688}],691:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../drawing\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/axis_ids\"),s=t(\"../../constants/xmlns_namespaces\");e.exports=function(t){var e,r,l=t._fullLayout,c=[],u={},f=[];for(r=0;r<l.images.length;r++){var h=l.images[r];if(h.visible)if(\"below\"===h.layer&&\"paper\"!==h.xref&&\"paper\"!==h.yref){e=o.ref2id(h.xref)+o.ref2id(h.yref);var p=l._plots[e];if(!p){f.push(h);continue}p.mainplot&&(e=p.mainplot.id),u[e]||(u[e]=[]),u[e].push(h)}else\"above\"===h.layer?c.push(h):f.push(h)}var d={left:{sizing:\"xMin\",offset:0},center:{sizing:\"xMid\",offset:-.5},right:{sizing:\"xMax\",offset:-1}},g={top:{sizing:\"YMin\",offset:0},middle:{sizing:\"YMid\",offset:-.5},bottom:{sizing:\"YMax\",offset:-1}};function m(e){var r=n.select(this);if(this._imgSrc!==e.source)if(r.attr(\"xmlns\",s.svg),e.source&&\"data:\"===e.source.slice(0,5))r.attr(\"xlink:href\",e.source),this._imgSrc=e.source;else{var i=new Promise(function(t){var n=new Image;function i(){r.remove(),t()}this.img=n,n.setAttribute(\"crossOrigin\",\"anonymous\"),n.onerror=i,n.onload=function(){var e=document.createElement(\"canvas\");e.width=this.width,e.height=this.height,e.getContext(\"2d\").drawImage(this,0,0);var n=e.toDataURL(\"image/png\");r.attr(\"xlink:href\",n),t()},r.on(\"error\",i),n.src=e.source,this._imgSrc=e.source}.bind(this));t._promises.push(i)}}function v(e){var r,o,s=n.select(this),c=a.getFromId(t,e.xref),u=a.getFromId(t,e.yref),f=\"domain\"===a.getRefType(e.xref),h=\"domain\"===a.getRefType(e.yref),p=l._size;r=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.sizex:Math.abs(c.l2p(e.sizex)-c.l2p(0)):e.sizex*p.w,o=void 0!==u?\"string\"==typeof e.yref&&h?u._length*e.sizey:Math.abs(u.l2p(e.sizey)-u.l2p(0)):e.sizey*p.h;var m,v,y=r*d[e.xanchor].offset,x=o*g[e.yanchor].offset,b=d[e.xanchor].sizing+g[e.yanchor].sizing;switch(m=void 0!==c?\"string\"==typeof e.xref&&f?c._length*e.x+c._offset:c.r2p(e.x)+c._offset:e.x*p.w+p.l,m+=y,v=void 0!==u?\"string\"==typeof e.yref&&h?u._length*(1-e.y)+u._offset:u.r2p(e.y)+u._offset:p.h-e.y*p.h+p.t,v+=x,e.sizing){case\"fill\":b+=\" slice\";break;case\"stretch\":b=\"none\"}s.attr({x:m,y:v,width:r,height:o,preserveAspectRatio:b,opacity:e.opacity});var _=(c&&\"domain\"!==a.getRefType(e.xref)?c._id:\"\")+(u&&\"domain\"!==a.getRefType(e.yref)?u._id:\"\");i.setClipUrl(s,_?\"clip\"+l._uid+_:null,t)}var y=l._imageLowerLayer.selectAll(\"image\").data(f),x=l._imageUpperLayer.selectAll(\"image\").data(c);y.enter().append(\"image\"),x.enter().append(\"image\"),y.exit().remove(),x.exit().remove(),y.each((function(t){m.bind(this)(t),v.bind(this)(t)})),x.each((function(t){m.bind(this)(t),v.bind(this)(t)}));var b=Object.keys(l._plots);for(r=0;r<b.length;r++){e=b[r];var _=l._plots[e];if(_.imagelayer){var w=_.imagelayer.selectAll(\"image\").data(u[e]||[]);w.enter().append(\"image\"),w.exit().remove(),w.each((function(t){m.bind(this)(t),v.bind(this)(t)}))}}}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../drawing\":665,d3:169}],692:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"images\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"images\"),draw:t(\"./draw\"),convertCoords:t(\"./convert_coords\")}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":688,\"./convert_coords\":689,\"./defaults\":690,\"./draw\":691}],693:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",editType:\"legend\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"legend\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"legend\"},font:n({editType:\"legend\"}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"v\",editType:\"legend\"},traceorder:{valType:\"flaglist\",flags:[\"reversed\",\"grouped\"],extras:[\"normal\"],editType:\"legend\"},tracegroupgap:{valType:\"number\",min:0,dflt:10,editType:\"legend\"},itemsizing:{valType:\"enumerated\",values:[\"trace\",\"constant\"],dflt:\"trace\",editType:\"legend\"},itemwidth:{valType:\"number\",min:30,dflt:30,editType:\"legend\"},itemclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggle\",editType:\"legend\"},itemdoubleclick:{valType:\"enumerated\",values:[\"toggle\",\"toggleothers\",!1],dflt:\"toggleothers\",editType:\"legend\"},x:{valType:\"number\",min:-2,max:3,editType:\"legend\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"legend\"},y:{valType:\"number\",min:-2,max:3,editType:\"legend\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"legend\"},uirevision:{valType:\"any\",editType:\"none\"},valign:{valType:\"enumerated\",values:[\"top\",\"middle\",\"bottom\"],dflt:\"middle\",editType:\"legend\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"legend\"},font:n({editType:\"legend\"}),side:{valType:\"enumerated\",values:[\"top\",\"left\",\"top left\"],editType:\"legend\"},editType:\"legend\"},editType:\"legend\"}},{\"../../plots/font_attributes\":856,\"../color/attributes\":642}],694:[function(t,e,r){\"use strict\";e.exports={scrollBarWidth:6,scrollBarMinHeight:20,scrollBarColor:\"#808BA4\",scrollBarMargin:4,scrollBarEnterAttrs:{rx:20,ry:3,width:0,height:0},titlePad:2,itemGap:5}},{}],695:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plot_api/plot_template\"),o=t(\"./attributes\"),s=t(\"../../plots/layout_attributes\"),l=t(\"./helpers\");e.exports=function(t,e,r){for(var c=t.legend||{},u=0,f=!1,h=\"normal\",p=0;p<r.length;p++){var d=r[p];d.visible&&((d.showlegend||d._dfltShowLegend&&!(d._module&&d._module.attributes&&d._module.attributes.showlegend&&!1===d._module.attributes.showlegend.dflt))&&(u++,d.showlegend&&(f=!0,(n.traceIs(d,\"pie-like\")||!0===d._input.showlegend)&&u++)),(n.traceIs(d,\"bar\")&&\"stack\"===e.barmode||-1!==[\"tonextx\",\"tonexty\"].indexOf(d.fill))&&(h=l.isGrouped({traceorder:h})?\"grouped+reversed\":\"reversed\"),void 0!==d.legendgroup&&\"\"!==d.legendgroup&&(h=l.isReversed({traceorder:h})?\"reversed+grouped\":\"grouped\"))}var g=i.coerce(t,e,s,\"showlegend\",f&&u>1);if(!1!==g||c.uirevision){var m=a.newContainer(e,\"legend\");if(_(\"uirevision\",e.uirevision),!1!==g){_(\"bgcolor\",e.paper_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),i.coerceFont(_,\"font\",e.font);var v,y,x,b=_(\"orientation\");\"h\"===b?(v=0,n.getComponentMethod(\"rangeslider\",\"isVisible\")(t.xaxis)?(y=1.1,x=\"bottom\"):(y=-.1,x=\"top\")):(v=1.02,y=1,x=\"auto\"),_(\"traceorder\",h),l.isGrouped(e.legend)&&_(\"tracegroupgap\"),_(\"itemsizing\"),_(\"itemwidth\"),_(\"itemclick\"),_(\"itemdoubleclick\"),_(\"x\",v),_(\"xanchor\"),_(\"y\",y),_(\"yanchor\",x),_(\"valign\"),i.noneOrAll(c,m,[\"x\",\"y\"]),_(\"title.text\")&&(_(\"title.side\",\"h\"===b?\"left\":\"top\"),i.coerceFont(_,\"title.font\",e.font))}}function _(t,e){return i.coerce(c,m,o,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/layout_attributes\":882,\"../../registry\":911,\"./attributes\":693,\"./helpers\":699}],696:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib/events\"),l=t(\"../dragelement\"),c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./handle_click\"),p=t(\"./constants\"),d=t(\"../../constants/alignment\"),g=d.LINE_SPACING,m=d.FROM_TL,v=d.FROM_BR,y=t(\"./get_legend_data\"),x=t(\"./style\"),b=t(\"./helpers\");function _(t,e,r,n,i){var a=r.data()[0][0].trace,l={event:i,node:r.node(),curveNumber:a.index,expandedIndex:a._expandedIndex,data:t.data,layout:t.layout,frames:t._transitionData._frames,config:t._context,fullData:t._fullData,fullLayout:t._fullLayout};if(a._group&&(l.group=a._group),o.traceIs(a,\"pie-like\")&&(l.label=r.datum()[0].label),!1!==s.triggerHandler(t,\"plotly_legendclick\",l))if(1===n)e._clickTimeout=setTimeout((function(){h(r,t,n)}),t._context.doubleClickDelay);else if(2===n){e._clickTimeout&&clearTimeout(e._clickTimeout),t._legendMouseDownTime=0,!1!==s.triggerHandler(t,\"plotly_legenddoubleclick\",l)&&h(r,t,n)}}function w(t,e,r){var n,a=t.data()[0][0],s=a.trace,l=o.traceIs(s,\"pie-like\"),u=s.index,h=r._main&&e._context.edits.legendText&&!l,d=r._maxNameLength;r.entries?n=a.text:(n=l?a.label:s.name,s._meta&&(n=i.templateString(n,s._meta)));var g=i.ensureSingle(t,\"text\",\"legendtext\");g.attr(\"text-anchor\",\"start\").call(c.font,r.font).text(h?T(n,d):n);var m=r.itemwidth+2*p.itemGap;f.positionText(g,m,0),h?g.call(f.makeEditable,{gd:e,text:n}).call(M,t,e,r).on(\"edit\",(function(n){this.text(T(n,d)).call(M,t,e,r);var s=a.trace._fullInput||{},l={};if(o.hasTransform(s,\"groupby\")){var c=o.getTransformIndices(s,\"groupby\"),f=c[c.length-1],h=i.keyedContainer(s,\"transforms[\"+f+\"].styles\",\"target\",\"value.name\");h.set(a.trace._group,n),l=h.constructUpdate()}else l.name=n;return o.call(\"_guiRestyle\",e,l,u)})):M(g,t,e,r)}function T(t,e){var r=Math.max(4,e);if(t&&t.trim().length>=r/2)return t;for(var n=r-(t=t||\"\").length;n>0;n--)t+=\" \";return t}function k(t,e){var r,a=e._context.doubleClickDelay,o=1,s=i.ensureSingle(t,\"rect\",\"legendtoggle\",(function(t){e._context.staticPlot||t.style(\"cursor\",\"pointer\").attr(\"pointer-events\",\"all\"),t.call(u.fill,\"rgba(0,0,0,0)\")}));e._context.staticPlot||(s.on(\"mousedown\",(function(){(r=(new Date).getTime())-e._legendMouseDownTime<a?o+=1:(o=1,e._legendMouseDownTime=r)})),s.on(\"mouseup\",(function(){if(!e._dragged&&!e._editing){var r=e._fullLayout.legend;(new Date).getTime()-e._legendMouseDownTime>a&&(o=Math.max(o-1,1)),_(e,r,t,o,n.event)}})))}function M(t,e,r,n){n._main||t.attr(\"data-notex\",!0),f.convertToTspans(t,r,(function(){!function(t,e,r){var n=t.data()[0][0];if(r._main&&n&&!n.trace.showlegend)return void t.remove();var i=t.select(\"g[class*=math-group]\"),a=i.node();r||(r=e._fullLayout.legend);var o,s,l=r.borderwidth,u=(n?r:r.title).font.size*g;if(a){var h=c.bBox(a);o=h.height,s=h.width,n?c.setTranslate(i,0,.25*o):c.setTranslate(i,l,.75*o+l)}else{var d=t.select(n?\".legendtext\":\".legendtitletext\"),m=f.lineCount(d),v=d.node();o=u*m,s=v?c.bBox(v).width:0;var y=u*((m-1)/2-.3);if(n){var x=r.itemwidth+2*p.itemGap;f.positionText(d,x,-y)}else f.positionText(d,p.titlePad+l,u+l)}n?(n.lineHeight=u,n.height=Math.max(o,16)+3,n.width=s):(r._titleWidth=s,r._titleHeight=o)}(e,r,n)}))}function A(t){return i.isRightAnchor(t)?\"right\":i.isCenterAnchor(t)?\"center\":\"left\"}function S(t){return i.isBottomAnchor(t)?\"bottom\":i.isMiddleAnchor(t)?\"middle\":\"top\"}e.exports=function(t,e){var r,s=t._fullLayout,f=\"legend\"+s._uid;if(e?(r=e.layer,f+=\"-hover\"):((e=s.legend||{})._main=!0,r=s._infolayer),r){var h;if(t._legendMouseDownTime||(t._legendMouseDownTime=0),e._main){if(!t.calcdata)return;h=s.showlegend&&y(t.calcdata,e)}else{if(!e.entries)return;h=y(e.entries,e)}var d=s.hiddenlabels||[];if(e._main&&(!s.showlegend||!h.length))return r.selectAll(\".legend\").remove(),s._topdefs.select(\"#\"+f).remove(),a.autoMargin(t,\"legend\");var g=i.ensureSingle(r,\"g\",\"legend\",(function(t){e._main&&t.attr(\"pointer-events\",\"all\")})),T=i.ensureSingleById(s._topdefs,\"clipPath\",f,(function(t){t.append(\"rect\")})),E=i.ensureSingle(g,\"rect\",\"bg\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));E.call(u.stroke,e.bordercolor).call(u.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\");var C=i.ensureSingle(g,\"g\",\"scrollbox\"),L=e.title;if(e._titleWidth=0,e._titleHeight=0,L.text){var I=i.ensureSingle(C,\"text\",\"legendtitletext\");I.attr(\"text-anchor\",\"start\").call(c.font,L.font).text(L.text),M(I,C,t,e)}else C.selectAll(\".legendtitletext\").remove();var P=i.ensureSingle(g,\"rect\",\"scrollbar\",(function(t){t.attr(p.scrollBarEnterAttrs).call(u.fill,p.scrollBarColor)})),z=C.selectAll(\"g.groups\").data(h);z.enter().append(\"g\").attr(\"class\",\"groups\"),z.exit().remove();var O=z.selectAll(\"g.traces\").data(i.identity);O.enter().append(\"g\").attr(\"class\",\"traces\"),O.exit().remove(),O.style(\"opacity\",(function(t){var e=t[0].trace;return o.traceIs(e,\"pie-like\")?-1!==d.indexOf(t[0].label)?.5:1:\"legendonly\"===e.visible?.5:1})).each((function(){n.select(this).call(w,t,e)})).call(x,t,e).each((function(){e._main&&n.select(this).call(k,t)})),i.syncOrAsync([a.previousPromises,function(){return function(t,e,r,i){var a=t._fullLayout;i||(i=a.legend);var o=a._size,s=b.isVertical(i),l=b.isGrouped(i),u=i.borderwidth,f=2*u,h=p.itemGap,d=i.itemwidth+2*h,g=2*(u+h),m=S(i),v=i.y<0||0===i.y&&\"top\"===m,y=i.y>1||1===i.y&&\"bottom\"===m;i._maxHeight=Math.max(v||y?a.height/2:o.h,30);var x=0;i._width=0,i._height=0;var _=function(t){var e=0,r=0,n=t.title.side;n&&(-1!==n.indexOf(\"left\")&&(e=t._titleWidth),-1!==n.indexOf(\"top\")&&(r=t._titleHeight));return[e,r]}(i);if(s)r.each((function(t){var e=t[0].height;c.setTranslate(this,u+_[0],u+_[1]+i._height+e/2+h),i._height+=e,i._width=Math.max(i._width,t[0].width)})),x=d+i._width,i._width+=h+d+f,i._height+=g,l&&(e.each((function(t,e){c.setTranslate(this,0,e*i.tracegroupgap)})),i._height+=(i._lgroupsLength-1)*i.tracegroupgap);else{var w=A(i),T=i.x<0||0===i.x&&\"right\"===w,k=i.x>1||1===i.x&&\"left\"===w,M=y||v,E=a.width/2;i._maxWidth=Math.max(T?M&&\"left\"===w?o.l+o.w:E:k?M&&\"right\"===w?o.r+o.w:E:o.w,2*d);var C=0,L=0;r.each((function(t){var e=t[0].width+d;C=Math.max(C,e),L+=e})),x=null;var I=0;if(l){var P=0,z=0,O=0;e.each((function(){var t=0,e=0;n.select(this).selectAll(\"g.traces\").each((function(r){var n=r[0].height;c.setTranslate(this,_[0],_[1]+u+h+n/2+e),e+=n,t=Math.max(t,d+r[0].width)})),P=Math.max(P,e);var r=t+h;r+u+z>i._maxWidth&&(I=Math.max(I,z),z=0,O+=P+i.tracegroupgap,P=e),c.setTranslate(this,z,O),z+=r})),i._width=Math.max(I,z)+u,i._height=O+P+g}else{var D=r.size(),R=L+f+(D-1)*h<i._maxWidth,F=0,B=0,N=0,j=0;r.each((function(t){var e=t[0].height,r=d+t[0].width,n=(R?r:C)+h;n+u+B-h>=i._maxWidth&&(I=Math.max(I,j),B=0,N+=F,i._height+=F,F=0),c.setTranslate(this,_[0]+u+B,_[1]+u+N+e/2+h),j=B+r+h,B+=n,F=Math.max(F,e)})),R?(i._width=B+f,i._height=F+g):(i._width=Math.max(I,j)+f,i._height+=F+g)}}i._width=Math.ceil(Math.max(i._width+_[0],i._titleWidth+2*(u+p.titlePad))),i._height=Math.ceil(Math.max(i._height+_[1],i._titleHeight+2*(u+p.itemGap))),i._effHeight=Math.min(i._height,i._maxHeight);var U=t._context.edits,V=U.legendText||U.legendPosition;r.each((function(t){var e=n.select(this).select(\".legendtoggle\"),r=t[0].height,i=V?d:x||d+t[0].width;s||(i+=h/2),c.setRect(e,0,-r/2,i,r)}))}(t,z,O,e)},function(){if(!e._main||!function(t){var e=t._fullLayout.legend,r=A(e),n=S(e);return a.autoMargin(t,\"legend\",{x:e.x,y:e.y,l:e._width*m[r],r:e._width*v[r],b:e._effHeight*v[n],t:e._effHeight*m[n]})}(t)){var u,h,d,y,x=s._size,b=e.borderwidth,w=x.l+x.w*e.x-m[A(e)]*e._width,k=x.t+x.h*(1-e.y)-m[S(e)]*e._effHeight;if(e._main&&s.margin.autoexpand){var M=w,L=k;w=i.constrain(w,0,s.width-e._width),k=i.constrain(k,0,s.height-e._effHeight),w!==M&&i.log(\"Constrain legend.x to make legend fit inside graph\"),k!==L&&i.log(\"Constrain legend.y to make legend fit inside graph\")}if(e._main&&c.setTranslate(g,w,k),P.on(\".drag\",null),g.on(\"wheel\",null),!e._main||e._height<=e._maxHeight||t._context.staticPlot){var I=e._effHeight;e._main||(I=e._height),E.attr({width:e._width-b,height:I-b,x:b/2,y:b/2}),c.setTranslate(C,0,0),T.select(\"rect\").attr({width:e._width-2*b,height:I-2*b,x:b,y:b}),c.setClipUrl(C,f,t),c.setRect(P,0,0,0,0),delete e._scrollY}else{var z,O,D,R=Math.max(p.scrollBarMinHeight,e._effHeight*e._effHeight/e._height),F=e._effHeight-R-2*p.scrollBarMargin,B=e._height-e._effHeight,N=F/B,j=Math.min(e._scrollY||0,B);E.attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-b,x:b/2,y:b/2}),T.select(\"rect\").attr({width:e._width-2*b+p.scrollBarWidth+p.scrollBarMargin,height:e._effHeight-2*b,x:b,y:b+j}),c.setClipUrl(C,f,t),q(j,R,N),g.on(\"wheel\",(function(){q(j=i.constrain(e._scrollY+n.event.deltaY/F*B,0,B),R,N),0!==j&&j!==B&&n.event.preventDefault()}));var U=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;z=\"touchstart\"===t.type?t.changedTouches[0].clientY:t.clientY,D=j})).on(\"drag\",(function(){var t=n.event.sourceEvent;2===t.buttons||t.ctrlKey||(O=\"touchmove\"===t.type?t.changedTouches[0].clientY:t.clientY,q(j=function(t,e,r){var n=(r-e)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));P.call(U);var V=n.behavior.drag().on(\"dragstart\",(function(){var t=n.event.sourceEvent;\"touchstart\"===t.type&&(z=t.changedTouches[0].clientY,D=j)})).on(\"drag\",(function(){var t=n.event.sourceEvent;\"touchmove\"===t.type&&(O=t.changedTouches[0].clientY,q(j=function(t,e,r){var n=(e-r)/N+t;return i.constrain(n,0,B)}(D,z,O),R,N))}));C.call(V)}if(t._context.edits.legendPosition)g.classed(\"cursor-move\",!0),l.init({element:g.node(),gd:t,prepFn:function(){var t=c.getTranslate(g);d=t.x,y=t.y},moveFn:function(t,r){var n=d+t,i=y+r;c.setTranslate(g,n,i),u=l.align(n,0,x.l,x.l+x.w,e.xanchor),h=l.align(i,0,x.t+x.h,x.t,e.yanchor)},doneFn:function(){void 0!==u&&void 0!==h&&o.call(\"_guiRelayout\",t,{\"legend.x\":u,\"legend.y\":h})},clickFn:function(e,n){var i=r.selectAll(\"g.traces\").filter((function(){var t=this.getBoundingClientRect();return n.clientX>=t.left&&n.clientX<=t.right&&n.clientY>=t.top&&n.clientY<=t.bottom}));i.size()>0&&_(t,g,i,e,n)}})}function q(r,n,i){e._scrollY=t._fullLayout.legend._scrollY=r,c.setTranslate(C,0,-r),c.setRect(P,e._width,p.scrollBarMargin+r*i,p.scrollBarWidth,n),T.select(\"rect\").attr(\"y\",b+r)}}],t)}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/events\":767,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":694,\"./get_legend_data\":697,\"./handle_click\":698,\"./helpers\":699,\"./style\":701,d3:169}],697:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./helpers\");e.exports=function(t,e){var r,a,o={},s=[],l=!1,c={},u=0,f=0,h=e._main;function p(t,r){if(\"\"!==t&&i.isGrouped(e))-1===s.indexOf(t)?(s.push(t),l=!0,o[t]=[[r]]):o[t].push([r]);else{var n=\"~~i\"+u;s.push(n),o[n]=[[r]],u++}}for(r=0;r<t.length;r++){var d=t[r],g=d[0],m=g.trace,v=m.legendgroup;if(!h||m.visible&&m.showlegend)if(n.traceIs(m,\"pie-like\"))for(c[v]||(c[v]={}),a=0;a<d.length;a++){var y=d[a].label;c[v][y]||(p(v,{label:y,color:d[a].color,i:d[a].i,trace:m,pts:d[a].pts}),c[v][y]=!0,f=Math.max(f,(y||\"\").length))}else p(v,g),f=Math.max(f,(m.name||\"\").length)}if(!s.length)return[];var x,b,_=s.length;if(l&&i.isGrouped(e))for(b=new Array(_),r=0;r<_;r++)x=o[s[r]],b[r]=i.isReversed(e)?x.reverse():x;else{for(b=[new Array(_)],r=0;r<_;r++)x=o[s[r]][0],b[0][i.isReversed(e)?_-r-1:r]=x;_=1}return e._lgroupsLength=_,e._maxNameLength=f,b}},{\"../../registry\":911,\"./helpers\":699}],698:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=!0;e.exports=function(t,e,r){var o=e._fullLayout;if(!e._dragged&&!e._editing){var s,l=o.legend.itemclick,c=o.legend.itemdoubleclick;if(1===r&&\"toggle\"===l&&\"toggleothers\"===c&&a&&e.data&&e._context.showTips?(n.notifier(n._(e,\"Double-click on legend to isolate one trace\"),\"long\"),a=!1):a=!1,1===r?s=l:2===r&&(s=c),s){var u,f,h,p,d,g=o.hiddenlabels?o.hiddenlabels.slice():[],m=t.data()[0][0],v=e._fullData,y=m.trace,x=y.legendgroup,b={},_=[],w=[],T=[];if(i.traceIs(y,\"pie-like\")){var k=m.label,M=g.indexOf(k);\"toggle\"===s?-1===M?g.push(k):g.splice(M,1):\"toggleothers\"===s&&(g=[],e.calcdata[0].forEach((function(t){k!==t.label&&g.push(t.label)})),e._fullLayout.hiddenlabels&&e._fullLayout.hiddenlabels.length===g.length&&-1===M&&(g=[])),i.call(\"_guiRelayout\",e,\"hiddenlabels\",g)}else{var A,S=x&&x.length,E=[];if(S)for(u=0;u<v.length;u++)(A=v[u]).visible&&A.legendgroup===x&&E.push(u);if(\"toggle\"===s){var C;switch(y.visible){case!0:C=\"legendonly\";break;case!1:C=!1;break;case\"legendonly\":C=!0}if(S)for(u=0;u<v.length;u++)!1!==v[u].visible&&v[u].legendgroup===x&&B(v[u],C);else B(y,C)}else if(\"toggleothers\"===s){var L,I,P,z,O=!0;for(u=0;u<v.length;u++)if(L=v[u]===y,P=!0!==v[u].showlegend,!(L||P||(I=S&&v[u].legendgroup===x)||!0!==v[u].visible||i.traceIs(v[u],\"notLegendIsolatable\"))){O=!1;break}for(u=0;u<v.length;u++)if(!1!==v[u].visible&&!i.traceIs(v[u],\"notLegendIsolatable\"))switch(y.visible){case\"legendonly\":B(v[u],!0);break;case!0:z=!!O||\"legendonly\",L=v[u]===y,P=!0!==v[u].showlegend&&!v[u].legendgroup,I=L||S&&v[u].legendgroup===x,B(v[u],!(!I&&!P)||z)}}for(u=0;u<w.length;u++)if(h=w[u]){var D=h.constructUpdate(),R=Object.keys(D);for(f=0;f<R.length;f++)p=R[f],(b[p]=b[p]||[])[T[u]]=D[p]}for(d=Object.keys(b),u=0;u<d.length;u++)for(p=d[u],f=0;f<_.length;f++)b[p].hasOwnProperty(f)||(b[p][f]=void 0);i.call(\"_guiRestyle\",e,b,_)}}}function F(t,e,r){var n=_.indexOf(t),i=b[e];return i||(i=b[e]=[]),-1===_.indexOf(t)&&(_.push(t),n=_.length-1),i[n]=r,n}function B(t,e){var r=t._fullInput;if(i.hasTransform(r,\"groupby\")){var a=w[r.index];if(!a){var o=i.getTransformIndices(r,\"groupby\"),s=o[o.length-1];a=n.keyedContainer(r,\"transforms[\"+s+\"].styles\",\"target\",\"value.visible\"),w[r.index]=a}var l=a.get(t._group);void 0===l&&(l=!0),!1!==l&&a.set(t._group,e),T[r.index]=F(r.index,\"visible\",!1!==r.visible)}else{var c=!1!==r.visible&&e;F(r.index,\"visible\",c)}}}},{\"../../lib\":778,\"../../registry\":911}],699:[function(t,e,r){\"use strict\";r.isGrouped=function(t){return-1!==(t.traceorder||\"\").indexOf(\"grouped\")},r.isVertical=function(t){return\"h\"!==t.orientation},r.isReversed=function(t){return-1!==(t.traceorder||\"\").indexOf(\"reversed\")}},{}],700:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"legend\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\"),style:t(\"./style\")}},{\"./attributes\":693,\"./defaults\":695,\"./draw\":696,\"./style\":701}],701:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../drawing\"),l=t(\"../color\"),c=t(\"../colorscale/helpers\").extractOpts,u=t(\"../../traces/scatter/subtypes\"),f=t(\"../../traces/pie/style_one\"),h=t(\"../../traces/pie/helpers\").castOption,p=t(\"./constants\");function d(t,e){return(e?\"radial\":\"horizontal\")+(t?\"\":\"reversed\")}e.exports=function(t,e,r){var g=e._fullLayout;r||(r=g.legend);var m=\"constant\"===r.itemsizing,v=r.itemwidth,y=(v+2*p.itemGap)/2,x=o(y,0),b=function(t,e,r,n){var i;if(t+1)i=t;else{if(!(e&&e.width>0))return 0;i=e.width}return m?n:Math.min(i,r)};function _(t,e,r){var a=t[0].trace,o=a.marker||{},s=o.line||{},c=r?a.visible&&a.type===r:i.traceIs(a,\"bar\"),u=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(c?[t]:[]);u.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),u.exit().remove(),u.each((function(t){var e=n.select(this),r=t[0],i=b(r.mlw,o.line,5,2);e.style(\"stroke-width\",i+\"px\").call(l.fill,r.mc||o.color),i&&l.stroke(e,r.mlc||s.color)}))}function w(t,e,r){var o=t[0],s=o.trace,l=r?s.visible&&s.type===r:i.traceIs(s,r),c=n.select(e).select(\"g.legendpoints\").selectAll(\"path.legend\"+r).data(l?[t]:[]);if(c.enter().append(\"path\").classed(\"legend\"+r,!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),c.exit().remove(),c.size()){var u=(s.marker||{}).line,p=b(h(u.width,o.pts),u,5,2),d=a.minExtend(s,{marker:{line:{width:p}}});d.marker.line.color=u.color;var g=a.minExtend(o,{trace:d});f(c,g,d)}}t.each((function(t){var e=n.select(this),i=a.ensureSingle(e,\"g\",\"layers\");i.style(\"opacity\",t[0].trace.opacity);var s=r.valign,l=t[0].lineHeight,c=t[0].height;if(\"middle\"!==s&&l&&c){var u={top:1,bottom:-1}[s]*(.5*(l-c+3));i.attr(\"transform\",o(0,u))}else i.attr(\"transform\",null);i.selectAll(\"g.legendfill\").data([t]).enter().append(\"g\").classed(\"legendfill\",!0),i.selectAll(\"g.legendlines\").data([t]).enter().append(\"g\").classed(\"legendlines\",!0);var f=i.selectAll(\"g.legendsymbols\").data([t]);f.enter().append(\"g\").classed(\"legendsymbols\",!0),f.selectAll(\"g.legendpoints\").data([t]).enter().append(\"g\").classed(\"legendpoints\",!0)})).each((function(t){var r,i=t[0].trace,o=[];if(i.visible)switch(i.type){case\"histogram2d\":case\"heatmap\":o=[[\"M-15,-2V4H15V-2Z\"]],r=!0;break;case\"choropleth\":case\"choroplethmapbox\":o=[[\"M-6,-6V6H6V-6Z\"]],r=!0;break;case\"densitymapbox\":o=[[\"M-6,0 a6,6 0 1,0 12,0 a 6,6 0 1,0 -12,0\"]],r=\"radial\";break;case\"cone\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 V6L6,4Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 L6,-4Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 L6,0Z\"]],r=!1;break;case\"streamtube\":o=[[\"M-6,2 A2,2 0 0,0 -6,6 H6 A2,2 0 0,1 6,2 Z\"],[\"M-6,-6 A2,2 0 0,0 -6,-2 H6 A2,2 0 0,1 6,-6 Z\"],[\"M-6,-2 A2,2 0 0,0 -6,2 H6 A2,2 0 0,1 6,-2 Z\"]],r=!1;break;case\"surface\":o=[[\"M-6,-6 A2,3 0 0,0 -6,0 H6 A2,3 0 0,1 6,-6 Z\"],[\"M-6,1 A2,3 0 0,1 -6,6 H6 A2,3 0 0,0 6,0 Z\"]],r=!0;break;case\"mesh3d\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!1;break;case\"volume\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6H6L0,6Z\"]],r=!0;break;case\"isosurface\":o=[[\"M-6,6H0L-6,-6Z\"],[\"M6,6H0L6,-6Z\"],[\"M-6,-6 A12,24 0 0,0 6,-6 L0,6Z\"]],r=!1}var u=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legend3dandfriends\").data(o);u.enter().append(\"path\").classed(\"legend3dandfriends\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),u.exit().remove(),u.each((function(t,o){var u,f=n.select(this),h=c(i),p=h.colorscale,g=h.reversescale;if(p){if(!r){var m=p.length;u=0===o?p[g?m-1:0][1]:1===o?p[g?0:m-1][1]:p[Math.floor((m-1)/2)][1]}}else{var v=i.vertexcolor||i.facecolor||i.color;u=a.isArrayOrTypedArray(v)?v[o]||v[0]:v}f.attr(\"d\",t[0]),u?f.call(l.fill,u):f.call((function(t){if(t.size()){var n=\"legendfill-\"+i.uid;s.gradient(t,e,n,d(g,\"radial\"===r),p,\"fill\")}}))}))})).each((function(t){var e=t[0].trace,r=\"waterfall\"===e.type;if(t[0]._distinct&&r){var i=t[0].trace[t[0].dir].marker;return t[0].mc=i.color,t[0].mlw=i.line.width,t[0].mlc=i.line.color,_(t,this,\"waterfall\")}var a=[];e.visible&&r&&(a=t[0].hasTotals?[[\"increasing\",\"M-6,-6V6H0Z\"],[\"totals\",\"M6,6H0L-6,-6H-0Z\"],[\"decreasing\",\"M6,6V-6H0Z\"]]:[[\"increasing\",\"M-6,-6V6H6Z\"],[\"decreasing\",\"M6,6V-6H-6Z\"]]);var o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendwaterfall\").data(a);o.enter().append(\"path\").classed(\"legendwaterfall\",!0).attr(\"transform\",x).style(\"stroke-miterlimit\",1),o.exit().remove(),o.each((function(t){var r=n.select(this),i=e[t[0]].marker,a=b(void 0,i.line,5,2);r.attr(\"d\",t[1]).style(\"stroke-width\",a+\"px\").call(l.fill,i.color),a&&r.call(l.stroke,i.line.color)}))})).each((function(t){_(t,this,\"funnel\")})).each((function(t){_(t,this)})).each((function(t){var r=t[0].trace,o=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendbox\").data(r.visible&&i.traceIs(r,\"box-violin\")?[t]:[]);o.enter().append(\"path\").classed(\"legendbox\",!0).attr(\"d\",\"M6,6H-6V-6H6Z\").attr(\"transform\",x),o.exit().remove(),o.each((function(){var t=n.select(this);if(\"all\"!==r.boxpoints&&\"all\"!==r.points||0!==l.opacity(r.fillcolor)||0!==l.opacity((r.line||{}).color)){var i=b(void 0,r.line,5,2);t.style(\"stroke-width\",i+\"px\").call(l.fill,r.fillcolor),i&&l.stroke(t,r.line.color)}else{var c=a.minExtend(r,{marker:{size:m?12:a.constrain(r.marker.size,2,16),sizeref:1,sizemin:1,sizemode:\"diameter\"}});o.call(s.pointStyle,c,e)}}))})).each((function(t){w(t,this,\"funnelarea\")})).each((function(t){w(t,this,\"pie\")})).each((function(t){var r,i,o=t[0],l=o.trace,f=l.visible&&l.fill&&\"none\"!==l.fill,h=u.hasLines(l),p=l.contours,g=!1,m=!1,y=c(l),x=y.colorscale,_=y.reversescale;if(p){var w=p.coloring;\"lines\"===w?g=!0:h=\"none\"===w||\"heatmap\"===w||p.showlines,\"constraint\"===p.type?f=\"=\"!==p._operation:\"fill\"!==w&&\"heatmap\"!==w||(m=!0)}var T=u.hasMarkers(l)||u.hasText(l),k=f||m,M=h||g,A=T||!k?\"M5,0\":M?\"M5,-2\":\"M5,-3\",S=n.select(this),E=S.select(\".legendfill\").selectAll(\"path\").data(f||m?[t]:[]);if(E.enter().append(\"path\").classed(\"js-fill\",!0),E.exit().remove(),E.attr(\"d\",A+\"h\"+v+\"v6h-\"+v+\"z\").call(f?s.fillGroupStyle:function(t){if(t.size()){var r=\"legendfill-\"+l.uid;s.gradient(t,e,r,d(_),x,\"fill\")}}),h||g){var C=b(void 0,l.line,10,5);i=a.minExtend(l,{line:{width:C}}),r=[a.minExtend(o,{trace:i})]}var L=S.select(\".legendlines\").selectAll(\"path\").data(h||g?[r]:[]);L.enter().append(\"path\").classed(\"js-line\",!0),L.exit().remove(),L.attr(\"d\",A+(g?\"l\"+v+\",0.0001\":\"h\"+v)).call(h?s.lineGroupStyle:function(t){if(t.size()){var r=\"legendline-\"+l.uid;s.lineGroupStyle(t),s.gradient(t,e,r,d(_),x,\"stroke\")}})})).each((function(t){var r,i,o=t[0],l=o.trace,c=u.hasMarkers(l),f=u.hasText(l),h=u.hasLines(l);function p(t,e,r,n){var i=a.nestedProperty(l,t).get(),o=a.isArrayOrTypedArray(i)&&e?e(i):i;if(m&&o&&void 0!==n&&(o=n),r){if(o<r[0])return r[0];if(o>r[1])return r[1]}return o}function d(t){return o._distinct&&o.index&&t[o.index]?t[o.index]:t[0]}if(c||f||h){var g={},v={};if(c){g.mc=p(\"marker.color\",d),g.mx=p(\"marker.symbol\",d),g.mo=p(\"marker.opacity\",a.mean,[.2,1]),g.mlc=p(\"marker.line.color\",d),g.mlw=p(\"marker.line.width\",a.mean,[0,5],2),v.marker={sizeref:1,sizemin:1,sizemode:\"diameter\"};var y=p(\"marker.size\",a.mean,[2,16],12);g.ms=y,v.marker.size=y}h&&(v.line={width:p(\"line.width\",d,[0,10],5)}),f&&(g.tx=\"Aa\",g.tp=p(\"textposition\",d),g.ts=10,g.tc=p(\"textfont.color\",d),g.tf=p(\"textfont.family\",d)),r=[a.minExtend(o,g)],(i=a.minExtend(l,v)).selectedpoints=null,i.texttemplate=null}var b=n.select(this).select(\"g.legendpoints\"),_=b.selectAll(\"path.scatterpts\").data(c?r:[]);_.enter().insert(\"path\",\":first-child\").classed(\"scatterpts\",!0).attr(\"transform\",x),_.exit().remove(),_.call(s.pointStyle,i,e),c&&(r[0].mrc=3);var w=b.selectAll(\"g.pointtext\").data(f?r:[]);w.enter().append(\"g\").classed(\"pointtext\",!0).append(\"text\").attr(\"transform\",x),w.exit().remove(),w.selectAll(\"text\").call(s.textPointStyle,i,e)})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendcandle\").data(e.visible&&\"candlestick\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendcandle\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H-8M-8,6V-6H8Z\":\"M15,0H8M8,-6V6H-8Z\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"stroke-width\",o+\"px\").call(l.fill,a.fillcolor),o&&l.stroke(i,a.line.color)}))})).each((function(t){var e=t[0].trace,r=n.select(this).select(\"g.legendpoints\").selectAll(\"path.legendohlc\").data(e.visible&&\"ohlc\"===e.type?[t,t]:[]);r.enter().append(\"path\").classed(\"legendohlc\",!0).attr(\"d\",(function(t,e){return e?\"M-15,0H0M-8,-6V0\":\"M15,0H0M8,6V0\"})).attr(\"transform\",x).style(\"stroke-miterlimit\",1),r.exit().remove(),r.each((function(t,r){var i=n.select(this),a=e[r?\"increasing\":\"decreasing\"],o=b(void 0,a.line,5,2);i.style(\"fill\",\"none\").call(s.dashLine,a.line.dash,o),o&&l.stroke(i,a.line.color)}))}))}},{\"../../lib\":778,\"../../registry\":911,\"../../traces/pie/helpers\":1166,\"../../traces/pie/style_one\":1172,\"../../traces/scatter/subtypes\":1212,\"../color\":643,\"../colorscale/helpers\":654,\"../drawing\":665,\"./constants\":694,d3:169}],702:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/plots\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../fonts/ploticon\"),s=t(\"../shapes/draw\").eraseActiveShape,l=t(\"../../lib\"),c=l._,u=e.exports={};function f(t,e){var r,i,o=e.currentTarget,s=o.getAttribute(\"data-attr\"),l=o.getAttribute(\"data-val\")||!0,c=t._fullLayout,u={},f=a.list(t,null,!0),h=c._cartesianSpikesEnabled;if(\"zoom\"===s){var p,d=\"in\"===l?.5:2,g=(1+d)/2,m=(1-d)/2;for(i=0;i<f.length;i++)if(!(r=f[i]).fixedrange)if(p=r._name,\"auto\"===l)u[p+\".autorange\"]=!0;else if(\"reset\"===l){if(void 0===r._rangeInitial)u[p+\".autorange\"]=!0;else{var v=r._rangeInitial.slice();u[p+\".range[0]\"]=v[0],u[p+\".range[1]\"]=v[1]}void 0!==r._showSpikeInitial&&(u[p+\".showspikes\"]=r._showSpikeInitial,\"on\"!==h||r._showSpikeInitial||(h=\"off\"))}else{var y=[r.r2l(r.range[0]),r.r2l(r.range[1])],x=[g*y[0]+m*y[1],g*y[1]+m*y[0]];u[p+\".range[0]\"]=r.l2r(x[0]),u[p+\".range[1]\"]=r.l2r(x[1])}}else\"hovermode\"!==s||\"x\"!==l&&\"y\"!==l||(l=c._isHoriz?\"y\":\"x\",o.setAttribute(\"data-val\",l)),u[s]=l;c._cartesianSpikesEnabled=h,n.call(\"_guiRelayout\",t,u)}function h(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout._subplots.gl3d||[],s={},l=i.split(\".\"),c=0;c<o.length;c++)s[o[c]+\".\"+l[1]]=a;var u=\"pan\"===a?a:\"zoom\";s.dragmode=u,n.call(\"_guiRelayout\",t,s)}function p(t,e){for(var r=e.currentTarget.getAttribute(\"data-attr\"),i=\"resetLastSave\"===r,a=\"resetDefault\"===r,o=t._fullLayout,s=o._subplots.gl3d||[],l={},c=0;c<s.length;c++){var u,f=s[c],h=f+\".camera\",p=f+\".aspectratio\",d=f+\".aspectmode\",g=o[f]._scene;i?(l[h+\".up\"]=g.viewInitial.up,l[h+\".eye\"]=g.viewInitial.eye,l[h+\".center\"]=g.viewInitial.center,u=!0):a&&(l[h+\".up\"]=null,l[h+\".eye\"]=null,l[h+\".center\"]=null,u=!0),u&&(l[p+\".x\"]=g.viewInitial.aspectratio.x,l[p+\".y\"]=g.viewInitial.aspectratio.y,l[p+\".z\"]=g.viewInitial.aspectratio.z,l[d]=g.viewInitial.aspectmode)}n.call(\"_guiRelayout\",t,l)}function d(t,e){var r=e.currentTarget,n=r._previousVal,i=t._fullLayout,a=i._subplots.gl3d||[],o=[\"xaxis\",\"yaxis\",\"zaxis\"],s={},l={};if(n)l=n,r._previousVal=null;else{for(var c=0;c<a.length;c++){var u=a[c],f=i[u],h=u+\".hovermode\";s[h]=f.hovermode,l[h]=!1;for(var p=0;p<3;p++){var d=o[p],g=u+\".\"+d+\".showspikes\";l[g]=!1,s[g]=f[d].showspikes}}r._previousVal=s}return l}function g(t,e){for(var r=e.currentTarget,i=r.getAttribute(\"data-attr\"),a=r.getAttribute(\"data-val\")||!0,o=t._fullLayout,s=o._subplots.geo||[],l=0;l<s.length;l++){var c=s[l],u=o[c];if(\"zoom\"===i){var f=u.projection.scale,h=\"in\"===a?2*f:.5*f;n.call(\"_guiRelayout\",t,c+\".projection.scale\",h)}}\"reset\"===i&&x(t,\"geo\")}function m(t){var e=t._fullLayout;return!e.hovermode&&(e._has(\"cartesian\")?e._isHoriz?\"y\":\"x\":\"closest\")}function v(t){var e=m(t);n.call(\"_guiRelayout\",t,\"hovermode\",e)}function y(t,e){for(var r=e.currentTarget.getAttribute(\"data-val\"),i=t._fullLayout,a=i._subplots.mapbox||[],o={},s=0;s<a.length;s++){var l=a[s],c=i[l].zoom,u=\"in\"===r?1.05*c:c/1.05;o[l+\".zoom\"]=u}n.call(\"_guiRelayout\",t,o)}function x(t,e){for(var r=t._fullLayout,i=r._subplots[e]||[],a={},o=0;o<i.length;o++)for(var s=i[o],l=r[s]._subplot.viewInitial,c=Object.keys(l),u=0;u<c.length;u++){var f=c[u];a[s+\".\"+f]=l[f]}n.call(\"_guiRelayout\",t,a)}u.toImage={name:\"toImage\",title:function(t){var e=(t._context.toImageButtonOptions||{}).format||\"png\";return c(t,\"png\"===e?\"Download plot as a png\":\"Download plot\")},icon:o.camera,click:function(t){var e=t._context.toImageButtonOptions,r={format:e.format||\"png\"};l.notifier(c(t,\"Taking snapshot - this may take a few seconds\"),\"long\"),\"svg\"!==r.format&&l.isIE()&&(l.notifier(c(t,\"IE only supports svg.  Changing format to svg.\"),\"long\"),r.format=\"svg\"),[\"filename\",\"width\",\"height\",\"scale\"].forEach((function(t){t in e&&(r[t]=e[t])})),n.call(\"downloadImage\",t,r).then((function(e){l.notifier(c(t,\"Snapshot succeeded\")+\" - \"+e,\"long\")})).catch((function(){l.notifier(c(t,\"Sorry, there was a problem downloading your snapshot!\"),\"long\")}))}},u.sendDataToCloud={name:\"sendDataToCloud\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.disk,click:function(t){i.sendDataToCloud(t)}},u.editInChartStudio={name:\"editInChartStudio\",title:function(t){return c(t,\"Edit in Chart Studio\")},icon:o.pencil,click:function(t){i.sendDataToCloud(t)}},u.zoom2d={name:\"zoom2d\",title:function(t){return c(t,\"Zoom\")},attr:\"dragmode\",val:\"zoom\",icon:o.zoombox,click:f},u.pan2d={name:\"pan2d\",title:function(t){return c(t,\"Pan\")},attr:\"dragmode\",val:\"pan\",icon:o.pan,click:f},u.select2d={name:\"select2d\",title:function(t){return c(t,\"Box Select\")},attr:\"dragmode\",val:\"select\",icon:o.selectbox,click:f},u.lasso2d={name:\"lasso2d\",title:function(t){return c(t,\"Lasso Select\")},attr:\"dragmode\",val:\"lasso\",icon:o.lasso,click:f},u.drawclosedpath={name:\"drawclosedpath\",title:function(t){return c(t,\"Draw closed freeform\")},attr:\"dragmode\",val:\"drawclosedpath\",icon:o.drawclosedpath,click:f},u.drawopenpath={name:\"drawopenpath\",title:function(t){return c(t,\"Draw open freeform\")},attr:\"dragmode\",val:\"drawopenpath\",icon:o.drawopenpath,click:f},u.drawline={name:\"drawline\",title:function(t){return c(t,\"Draw line\")},attr:\"dragmode\",val:\"drawline\",icon:o.drawline,click:f},u.drawrect={name:\"drawrect\",title:function(t){return c(t,\"Draw rectangle\")},attr:\"dragmode\",val:\"drawrect\",icon:o.drawrect,click:f},u.drawcircle={name:\"drawcircle\",title:function(t){return c(t,\"Draw circle\")},attr:\"dragmode\",val:\"drawcircle\",icon:o.drawcircle,click:f},u.eraseshape={name:\"eraseshape\",title:function(t){return c(t,\"Erase active shape\")},icon:o.eraseshape,click:s},u.zoomIn2d={name:\"zoomIn2d\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:f},u.zoomOut2d={name:\"zoomOut2d\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:f},u.autoScale2d={name:\"autoScale2d\",title:function(t){return c(t,\"Autoscale\")},attr:\"zoom\",val:\"auto\",icon:o.autoscale,click:f},u.resetScale2d={name:\"resetScale2d\",title:function(t){return c(t,\"Reset axes\")},attr:\"zoom\",val:\"reset\",icon:o.home,click:f},u.hoverClosestCartesian={name:\"hoverClosestCartesian\",title:function(t){return c(t,\"Show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:f},u.hoverCompareCartesian={name:\"hoverCompareCartesian\",title:function(t){return c(t,\"Compare data on hover\")},attr:\"hovermode\",val:function(t){return t._fullLayout._isHoriz?\"y\":\"x\"},icon:o.tooltip_compare,gravity:\"ne\",click:f},u.zoom3d={name:\"zoom3d\",title:function(t){return c(t,\"Zoom\")},attr:\"scene.dragmode\",val:\"zoom\",icon:o.zoombox,click:h},u.pan3d={name:\"pan3d\",title:function(t){return c(t,\"Pan\")},attr:\"scene.dragmode\",val:\"pan\",icon:o.pan,click:h},u.orbitRotation={name:\"orbitRotation\",title:function(t){return c(t,\"Orbital rotation\")},attr:\"scene.dragmode\",val:\"orbit\",icon:o[\"3d_rotate\"],click:h},u.tableRotation={name:\"tableRotation\",title:function(t){return c(t,\"Turntable rotation\")},attr:\"scene.dragmode\",val:\"turntable\",icon:o[\"z-axis\"],click:h},u.resetCameraDefault3d={name:\"resetCameraDefault3d\",title:function(t){return c(t,\"Reset camera to default\")},attr:\"resetDefault\",icon:o.home,click:p},u.resetCameraLastSave3d={name:\"resetCameraLastSave3d\",title:function(t){return c(t,\"Reset camera to last save\")},attr:\"resetLastSave\",icon:o.movie,click:p},u.hoverClosest3d={name:\"hoverClosest3d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);n.call(\"_guiRelayout\",t,r)}},u.zoomInGeo={name:\"zoomInGeo\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:g},u.zoomOutGeo={name:\"zoomOutGeo\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:g},u.resetGeo={name:\"resetGeo\",title:function(t){return c(t,\"Reset\")},attr:\"reset\",val:null,icon:o.autoscale,click:g},u.hoverClosestGeo={name:\"hoverClosestGeo\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestGl2d={name:\"hoverClosestGl2d\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:v},u.hoverClosestPie={name:\"hoverClosestPie\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:\"closest\",icon:o.tooltip_basic,gravity:\"ne\",click:v},u.resetViewSankey={name:\"resetSankeyGroup\",title:function(t){return c(t,\"Reset view\")},icon:o.home,click:function(t){for(var e={\"node.groups\":[],\"node.x\":[],\"node.y\":[]},r=0;r<t._fullData.length;r++){var i=t._fullData[r]._viewInitial;e[\"node.groups\"].push(i.node.groups.slice()),e[\"node.x\"].push(i.node.x.slice()),e[\"node.y\"].push(i.node.y.slice())}n.call(\"restyle\",t,e)}},u.toggleHover={name:\"toggleHover\",title:function(t){return c(t,\"Toggle show closest data on hover\")},attr:\"hovermode\",val:null,toggle:!0,icon:o.tooltip_basic,gravity:\"ne\",click:function(t,e){var r=d(t,e);r.hovermode=m(t),n.call(\"_guiRelayout\",t,r)}},u.resetViews={name:\"resetViews\",title:function(t){return c(t,\"Reset views\")},icon:o.home,click:function(t,e){var r=e.currentTarget;r.setAttribute(\"data-attr\",\"zoom\"),r.setAttribute(\"data-val\",\"reset\"),f(t,e),r.setAttribute(\"data-attr\",\"resetLastSave\"),p(t,e),x(t,\"geo\"),x(t,\"mapbox\")}},u.toggleSpikelines={name:\"toggleSpikelines\",title:function(t){return c(t,\"Toggle Spike Lines\")},icon:o.spikeline,attr:\"_cartesianSpikesEnabled\",val:\"on\",click:function(t){var e=t._fullLayout,r=e._cartesianSpikesEnabled;e._cartesianSpikesEnabled=\"on\"===r?\"off\":\"on\",n.call(\"_guiRelayout\",t,function(t){for(var e=\"on\"===t._fullLayout._cartesianSpikesEnabled,r=a.list(t,null,!0),n={},i=0;i<r.length;i++){var o=r[i];n[o._name+\".showspikes\"]=!!e||o._showSpikeInitial}return n}(t))}},u.resetViewMapbox={name:\"resetViewMapbox\",title:function(t){return c(t,\"Reset view\")},attr:\"reset\",icon:o.home,click:function(t){x(t,\"mapbox\")}},u.zoomInMapbox={name:\"zoomInMapbox\",title:function(t){return c(t,\"Zoom in\")},attr:\"zoom\",val:\"in\",icon:o.zoom_plus,click:y},u.zoomOutMapbox={name:\"zoomOutMapbox\",title:function(t){return c(t,\"Zoom out\")},attr:\"zoom\",val:\"out\",icon:o.zoom_minus,click:y}},{\"../../fonts/ploticon\":757,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../shapes/draw\":724}],703:[function(t,e,r){\"use strict\";r.manage=t(\"./manage\")},{\"./manage\":704}],704:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../traces/scatter/subtypes\"),a=t(\"../../registry\"),o=t(\"../fx/helpers\").isUnifiedHover,s=t(\"./modebar\"),l=t(\"./buttons\");e.exports=function(t){var e=t._fullLayout,r=t._context,u=e._modeBar;if(r.displayModeBar||r.watermark){if(!Array.isArray(r.modeBarButtonsToRemove))throw new Error([\"*modeBarButtonsToRemove* configuration options\",\"must be an array.\"].join(\" \"));if(!Array.isArray(r.modeBarButtonsToAdd))throw new Error([\"*modeBarButtonsToAdd* configuration options\",\"must be an array.\"].join(\" \"));var f,h=r.modeBarButtons;f=Array.isArray(h)&&h.length?function(t){for(var e=0;e<t.length;e++)for(var r=t[e],n=0;n<r.length;n++){var i=r[n];if(\"string\"==typeof i){if(void 0===l[i])throw new Error([\"*modeBarButtons* configuration options\",\"invalid button name\"].join(\" \"));t[e][n]=l[i]}}return t}(h):!r.displayModeBar&&r.watermark?[]:function(t){var e=t._fullLayout,r=t._fullData,s=t._context,u=s.modeBarButtonsToRemove,f=s.modeBarButtonsToAdd,h=e._has(\"cartesian\"),p=e._has(\"gl3d\"),d=e._has(\"geo\"),g=e._has(\"pie\"),m=e._has(\"funnelarea\"),v=e._has(\"gl2d\"),y=e._has(\"ternary\"),x=e._has(\"mapbox\"),b=e._has(\"polar\"),_=e._has(\"sankey\"),w=function(t){for(var e=n.list({_fullLayout:t},null,!0),r=0;r<e.length;r++)if(!e[r].fixedrange)return!1;return!0}(e),T=o(e.hovermode),k=[];function M(t){if(t.length){for(var e=[],r=0;r<t.length;r++){var n=t[r];-1===u.indexOf(n)&&e.push(l[n])}k.push(e)}}var A=[\"toImage\"];s.showEditInChartStudio?A.push(\"editInChartStudio\"):s.showSendToCloud&&A.push(\"sendDataToCloud\");M(A);var S=[],E=[],C=[],L=[];(h||v||g||m||y)+d+p+x+b>1?(E=[\"toggleHover\"],C=[\"resetViews\"]):d?(S=[\"zoomInGeo\",\"zoomOutGeo\"],E=[\"hoverClosestGeo\"],C=[\"resetGeo\"]):p?(E=[\"hoverClosest3d\"],C=[\"resetCameraDefault3d\",\"resetCameraLastSave3d\"]):x?(S=[\"zoomInMapbox\",\"zoomOutMapbox\"],E=[\"toggleHover\"],C=[\"resetViewMapbox\"]):v?E=[\"hoverClosestGl2d\"]:g?E=[\"hoverClosestPie\"]:_?(E=[\"hoverClosestCartesian\",\"hoverCompareCartesian\"],C=[\"resetViewSankey\"]):E=[\"toggleHover\"];h&&(E=[\"toggleSpikelines\",\"hoverClosestCartesian\",\"hoverCompareCartesian\"]);(function(t){for(var e=0;e<t.length;e++)if(!a.traceIs(t[e],\"noHover\"))return!1;return!0}(r)||T)&&(E=[]);!h&&!v||w||(S=[\"zoomIn2d\",\"zoomOut2d\",\"autoScale2d\"],\"resetViews\"!==C[0]&&(C=[\"resetScale2d\"]));p?L=[\"zoom3d\",\"pan3d\",\"orbitRotation\",\"tableRotation\"]:(h||v)&&!w||y?L=[\"zoom2d\",\"pan2d\"]:x||d?L=[\"pan2d\"]:b&&(L=[\"zoom2d\"]);(function(t){for(var e=!1,r=0;r<t.length&&!e;r++){var n=t[r];n._module&&n._module.selectPoints&&(a.traceIs(n,\"scatter-like\")?(i.hasMarkers(n)||i.hasText(n))&&(e=!0):a.traceIs(n,\"box-violin\")&&\"all\"!==n.boxpoints&&\"all\"!==n.points||(e=!0))}return e})(r)&&L.push(\"select2d\",\"lasso2d\");if(Array.isArray(f)){for(var I=[],P=0;P<f.length;P++){var z=f[P];\"string\"==typeof z?-1!==c.indexOf(z)&&(e._has(\"mapbox\")||e._has(\"cartesian\"))&&L.push(z):I.push(z)}f=I}return M(L),M(S.concat(C)),M(E),function(t,e){if(e.length)if(Array.isArray(e[0]))for(var r=0;r<e.length;r++)t.push(e[r]);else t.push(e);return t}(k,f)}(t),u?u.update(t,f):e._modeBar=s(t,f)}else u&&(u.destroy(),delete e._modeBar)};var c=[\"drawline\",\"drawopenpath\",\"drawclosedpath\",\"drawcircle\",\"drawrect\",\"eraseshape\"]},{\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../../traces/scatter/subtypes\":1212,\"../fx/helpers\":679,\"./buttons\":702,\"./modebar\":705}],705:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../fonts/ploticon\"),s=new DOMParser;function l(t){this.container=t.container,this.element=document.createElement(\"div\"),this.update(t.graphInfo,t.buttons),this.container.appendChild(this.element)}var c=l.prototype;c.update=function(t,e){this.graphInfo=t;var r=this.graphInfo._context,n=this.graphInfo._fullLayout,i=\"modebar-\"+n._uid;this.element.setAttribute(\"id\",i),this._uid=i,this.element.className=\"modebar\",\"hover\"===r.displayModeBar&&(this.element.className+=\" modebar--hover ease-bg\"),\"v\"===n.modebar.orientation&&(this.element.className+=\" vertical\",e=e.reverse());var o=n.modebar,s=\"hover\"===r.displayModeBar?\".js-plotly-plot .plotly:hover \":\"\";a.deleteRelatedStyleRule(i),a.addRelatedStyleRule(i,s+\"#\"+i+\" .modebar-group\",\"background-color: \"+o.bgcolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn .icon path\",\"fill: \"+o.color),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn:hover .icon path\",\"fill: \"+o.activecolor),a.addRelatedStyleRule(i,\"#\"+i+\" .modebar-btn.active .icon path\",\"fill: \"+o.activecolor);var l=!this.hasButtons(e),c=this.hasLogo!==r.displaylogo,u=this.locale!==r.locale;if(this.locale=r.locale,(l||c||u)&&(this.removeAllButtons(),this.updateButtons(e),r.watermark||r.displaylogo)){var f=this.getLogo();r.watermark&&(f.className=f.className+\" watermark\"),\"v\"===n.modebar.orientation?this.element.insertBefore(f,this.element.childNodes[0]):this.element.appendChild(f),this.hasLogo=!0}this.updateActiveButton()},c.updateButtons=function(t){var e=this;this.buttons=t,this.buttonElements=[],this.buttonsNames=[],this.buttons.forEach((function(t){var r=e.createGroup();t.forEach((function(t){var n=t.name;if(!n)throw new Error(\"must provide button 'name' in button config\");if(-1!==e.buttonsNames.indexOf(n))throw new Error(\"button name '\"+n+\"' is taken\");e.buttonsNames.push(n);var i=e.createButton(t);e.buttonElements.push(i),r.appendChild(i)})),e.element.appendChild(r)}))},c.createGroup=function(){var t=document.createElement(\"div\");return t.className=\"modebar-group\",t},c.createButton=function(t){var e=this,r=document.createElement(\"a\");r.setAttribute(\"rel\",\"tooltip\"),r.className=\"modebar-btn\";var i=t.title;void 0===i?i=t.name:\"function\"==typeof i&&(i=i(this.graphInfo)),(i||0===i)&&r.setAttribute(\"data-title\",i),void 0!==t.attr&&r.setAttribute(\"data-attr\",t.attr);var a=t.val;if(void 0!==a&&(\"function\"==typeof a&&(a=a(this.graphInfo)),r.setAttribute(\"data-val\",a)),\"function\"!=typeof t.click)throw new Error(\"must provide button 'click' function in button config\");r.addEventListener(\"click\",(function(r){t.click(e.graphInfo,r),e.updateActiveButton(r.currentTarget)})),r.setAttribute(\"data-toggle\",t.toggle||!1),t.toggle&&n.select(r).classed(\"active\",!0);var s=t.icon;return\"function\"==typeof s?r.appendChild(s()):r.appendChild(this.createIcon(s||o.question)),r.setAttribute(\"data-gravity\",t.gravity||\"n\"),r},c.createIcon=function(t){var e,r=i(t.height)?Number(t.height):t.ascent-t.descent,n=\"http://www.w3.org/2000/svg\";if(t.path){(e=document.createElementNS(n,\"svg\")).setAttribute(\"viewBox\",[0,0,t.width,r].join(\" \")),e.setAttribute(\"class\",\"icon\");var a=document.createElementNS(n,\"path\");a.setAttribute(\"d\",t.path),t.transform?a.setAttribute(\"transform\",t.transform):void 0!==t.ascent&&a.setAttribute(\"transform\",\"matrix(1 0 0 -1 0 \"+t.ascent+\")\"),e.appendChild(a)}t.svg&&(e=s.parseFromString(t.svg,\"application/xml\").childNodes[0]);return e.setAttribute(\"height\",\"1em\"),e.setAttribute(\"width\",\"1em\"),e},c.updateActiveButton=function(t){var e=this.graphInfo._fullLayout,r=void 0!==t?t.getAttribute(\"data-attr\"):null;this.buttonElements.forEach((function(t){var i=t.getAttribute(\"data-val\")||!0,o=t.getAttribute(\"data-attr\"),s=\"true\"===t.getAttribute(\"data-toggle\"),l=n.select(t);if(s)o===r&&l.classed(\"active\",!l.classed(\"active\"));else{var c=null===o?o:a.nestedProperty(e,o).get();l.classed(\"active\",c===i)}}))},c.hasButtons=function(t){var e=this.buttons;if(!e)return!1;if(t.length!==e.length)return!1;for(var r=0;r<t.length;++r){if(t[r].length!==e[r].length)return!1;for(var n=0;n<t[r].length;n++)if(t[r][n].name!==e[r][n].name)return!1}return!0},c.getLogo=function(){var t=this.createGroup(),e=document.createElement(\"a\");return e.href=\"https://plotly.com/\",e.target=\"_blank\",e.setAttribute(\"data-title\",a._(this.graphInfo,\"Produced with Plotly\")),e.className=\"modebar-btn plotlyjsicon modebar-btn--logo\",e.appendChild(this.createIcon(o.newplotlylogo)),t.appendChild(e),t},c.removeAllButtons=function(){for(;this.element.firstChild;)this.element.removeChild(this.element.firstChild);this.hasLogo=!1},c.destroy=function(){a.removeElement(this.container.querySelector(\".modebar\")),a.deleteRelatedStyleRule(this._uid)},e.exports=function(t,e){var r=t._fullLayout,i=new l({graphInfo:t,container:r._modebardiv.node(),buttons:e});return r._privateplot&&n.select(i.element).append(\"span\").classed(\"badge-private float--left\",!0).text(\"PRIVATE\"),i}},{\"../../fonts/ploticon\":757,\"../../lib\":778,d3:169,\"fast-isnumeric\":241}],706:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=(0,t(\"../../plot_api/plot_template\").templatedArray)(\"button\",{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},step:{valType:\"enumerated\",values:[\"month\",\"year\",\"day\",\"hour\",\"minute\",\"second\",\"all\"],dflt:\"month\",editType:\"plot\"},stepmode:{valType:\"enumerated\",values:[\"backward\",\"todate\"],dflt:\"backward\",editType:\"plot\"},count:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},label:{valType:\"string\",editType:\"plot\"},editType:\"plot\"});e.exports={visible:{valType:\"boolean\",editType:\"plot\"},buttons:a,x:{valType:\"number\",min:-2,max:3,editType:\"plot\"},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\",editType:\"plot\"},y:{valType:\"number\",min:-2,max:3,editType:\"plot\"},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"bottom\",editType:\"plot\"},font:n({editType:\"plot\"}),bgcolor:{valType:\"color\",dflt:i.lightLine,editType:\"plot\"},activecolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"}},{\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../color/attributes\":642}],707:[function(t,e,r){\"use strict\";e.exports={yPad:.02,minButtonWidth:30,rx:3,ry:3,lightAmount:25,darkAmount:10}},{}],708:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../../plots/array_container_defaults\"),s=t(\"./attributes\"),l=t(\"./constants\");function c(t,e,r,i){var a=i.calendar;function o(r,i){return n.coerce(t,e,s.buttons,r,i)}if(o(\"visible\")){var l=o(\"step\");\"all\"!==l&&(!a||\"gregorian\"===a||\"month\"!==l&&\"year\"!==l?o(\"stepmode\"):e.stepmode=\"backward\",o(\"count\")),o(\"label\")}}e.exports=function(t,e,r,u,f){var h=t.rangeselector||{},p=a.newContainer(e,\"rangeselector\");function d(t,e){return n.coerce(h,p,s,t,e)}if(d(\"visible\",o(h,p,{name:\"buttons\",handleItemDefaults:c,calendar:f}).length>0)){var g=function(t,e,r){for(var n=r.filter((function(r){return e[r].anchor===t._id})),i=0,a=0;a<n.length;a++){var o=e[n[a]].domain;o&&(i=Math.max(o[1],i))}return[t.domain[0],i+l.yPad]}(e,r,u);d(\"x\",g[0]),d(\"y\",g[1]),n.noneOrAll(t,e,[\"x\",\"y\"]),d(\"xanchor\"),d(\"yanchor\"),n.coerceFont(d,\"font\",r.font);var m=d(\"bgcolor\");d(\"activecolor\",i.contrast(m,l.lightAmount,l.darkAmount)),d(\"bordercolor\"),d(\"borderwidth\")}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../color\":643,\"./attributes\":706,\"./constants\":707}],709:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../color\"),s=t(\"../drawing\"),l=t(\"../../lib\"),c=l.strTranslate,u=t(\"../../lib/svg_text_utils\"),f=t(\"../../plots/cartesian/axis_ids\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR,m=t(\"./constants\"),v=t(\"./get_update_object\");function y(t){return t._id}function x(t,e,r){var n=l.ensureSingle(t,\"rect\",\"selector-rect\",(function(t){t.attr(\"shape-rendering\",\"crispEdges\")}));n.attr({rx:m.rx,ry:m.ry}),n.call(o.stroke,e.bordercolor).call(o.fill,function(t,e){return e._isActive||e._isHovered?t.activecolor:t.bgcolor}(e,r)).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){l.ensureSingle(t,\"text\",\"selector-text\",(function(t){t.attr(\"text-anchor\",\"middle\")})).call(s.font,e.font).text(function(t,e){if(t.label)return e?l.templateString(t.label,e):t.label;return\"all\"===t.step?\"all\":t.count+t.step.charAt(0)}(r,n._fullLayout._meta)).call((function(t){u.convertToTspans(t,n)}))}e.exports=function(t){var e=t._fullLayout._infolayer.selectAll(\".rangeselector\").data(function(t){for(var e=f.list(t,\"x\",!0),r=[],n=0;n<e.length;n++){var i=e[n];i.rangeselector&&i.rangeselector.visible&&r.push(i)}return r}(t),y);e.enter().append(\"g\").classed(\"rangeselector\",!0),e.exit().remove(),e.style({cursor:\"pointer\",\"pointer-events\":\"all\"}),e.each((function(e){var r=n.select(this),o=e,f=o.rangeselector,h=r.selectAll(\"g.button\").data(l.filterVisible(f.buttons));h.enter().append(\"g\").classed(\"button\",!0),h.exit().remove(),h.each((function(e){var r=n.select(this),a=v(o,e);e._isActive=function(t,e,r){if(\"all\"===e.step)return!0===t.autorange;var n=Object.keys(r);return t.range[0]===r[n[0]]&&t.range[1]===r[n[1]]}(o,e,a),r.call(x,f,e),r.call(b,f,e,t),r.on(\"click\",(function(){t._dragged||i.call(\"_guiRelayout\",t,a)})),r.on(\"mouseover\",(function(){e._isHovered=!0,r.call(x,f,e)})),r.on(\"mouseout\",(function(){e._isHovered=!1,r.call(x,f,e)}))})),function(t,e,r,i,o){var f=0,h=0,v=r.borderwidth;e.each((function(){var t=n.select(this).select(\".selector-text\"),e=r.font.size*p,i=Math.max(e*u.lineCount(t),16)+3;h=Math.max(h,i)})),e.each((function(){var t=n.select(this),e=t.select(\".selector-rect\"),i=t.select(\".selector-text\"),a=i.node()&&s.bBox(i.node()).width,o=r.font.size*p,l=u.lineCount(i),d=Math.max(a+10,m.minButtonWidth);t.attr(\"transform\",c(v+f,v)),e.attr({x:0,y:0,width:d,height:h}),u.positionText(i,d/2,h/2-(l-1)*o/2+3),f+=d+5}));var y=t._fullLayout._size,x=y.l+y.w*r.x,b=y.t+y.h*(1-r.y),_=\"left\";l.isRightAnchor(r)&&(x-=f,_=\"right\");l.isCenterAnchor(r)&&(x-=f/2,_=\"center\");var w=\"top\";l.isBottomAnchor(r)&&(b-=h,w=\"bottom\");l.isMiddleAnchor(r)&&(b-=h/2,w=\"middle\");f=Math.ceil(f),h=Math.ceil(h),x=Math.round(x),b=Math.round(b),a.autoMargin(t,i+\"-range-selector\",{x:r.x,y:r.y,l:f*d[_],r:f*g[_],b:h*g[w],t:h*d[w]}),o.attr(\"transform\",c(x,b))}(t,h,f,o._name,r)}))}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,\"./constants\":707,\"./get_update_object\":710,d3:169}],710:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e){var r=t._name,i={};if(\"all\"===e.step)i[r+\".autorange\"]=!0;else{var a=function(t,e){var r,i=t.range,a=new Date(t.r2l(i[1])),o=e.step,s=e.count;switch(e.stepmode){case\"backward\":r=t.l2r(+n.time[o].utc.offset(a,-s));break;case\"todate\":var l=n.time[o].utc.offset(a,-s);r=t.l2r(+n.time[o].utc.ceil(l))}var c=i[1];return[r,c]}(t,e);i[r+\".range[0]\"]=a[0],i[r+\".range[1]\"]=a[1]}return i}},{d3:169}],711:[function(t,e,r){\"use strict\";e.exports={moduleType:\"component\",name:\"rangeselector\",schema:{subplots:{xaxis:{rangeselector:t(\"./attributes\")}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":706,\"./defaults\":708,\"./draw\":709}],712:[function(t,e,r){\"use strict\";var n=t(\"../color/attributes\");e.exports={bgcolor:{valType:\"color\",dflt:n.background,editType:\"plot\"},bordercolor:{valType:\"color\",dflt:n.defaultLine,editType:\"plot\"},borderwidth:{valType:\"integer\",dflt:0,min:0,editType:\"plot\"},autorange:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"calc\",impliedEdits:{\"^autorange\":!1}}],editType:\"calc\",impliedEdits:{autorange:!1}},thickness:{valType:\"number\",dflt:.15,min:0,max:1,editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"}},{\"../color/attributes\":642}],713:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\").list,i=t(\"../../plots/cartesian/autorange\").getAutoRange,a=t(\"./constants\");e.exports=function(t){for(var e=n(t,\"x\",!0),r=0;r<e.length;r++){var o=e[r],s=o[a.name];s&&s.visible&&s.autorange&&(s._input.autorange=!0,s._input.range=s.range=i(t,o))}}},{\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],714:[function(t,e,r){\"use strict\";e.exports={name:\"rangeslider\",containerClassName:\"rangeslider-container\",bgClassName:\"rangeslider-bg\",rangePlotClassName:\"rangeslider-rangeplot\",maskMinClassName:\"rangeslider-mask-min\",maskMaxClassName:\"rangeslider-mask-max\",slideBoxClassName:\"rangeslider-slidebox\",grabberMinClassName:\"rangeslider-grabber-min\",grabAreaMinClassName:\"rangeslider-grabarea-min\",handleMinClassName:\"rangeslider-handle-min\",grabberMaxClassName:\"rangeslider-grabber-max\",grabAreaMaxClassName:\"rangeslider-grabarea-max\",handleMaxClassName:\"rangeslider-handle-max\",maskMinOppAxisClassName:\"rangeslider-mask-min-opp-axis\",maskMaxOppAxisClassName:\"rangeslider-mask-max-opp-axis\",maskColor:\"rgba(0,0,0,0.4)\",maskOppAxisColor:\"rgba(0,0,0,0.2)\",slideBoxFill:\"transparent\",slideBoxCursor:\"ew-resize\",grabAreaFill:\"transparent\",grabAreaCursor:\"col-resize\",grabAreaWidth:10,handleWidth:4,handleRadius:1,handleStrokeWidth:1,extraPad:15}},{}],715:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"./attributes\"),s=t(\"./oppaxis_attributes\");e.exports=function(t,e,r){var l=t[r],c=e[r];if(l.rangeslider||e._requestRangeslider[c._id]){n.isPlainObject(l.rangeslider)||(l.rangeslider={});var u,f,h=l.rangeslider,p=i.newContainer(c,\"rangeslider\");if(_(\"visible\")){_(\"bgcolor\",e.plot_bgcolor),_(\"bordercolor\"),_(\"borderwidth\"),_(\"thickness\"),_(\"autorange\",!c.isValidRange(h.range)),_(\"range\");var d=e._subplots;if(d)for(var g=d.cartesian.filter((function(t){return t.substr(0,t.indexOf(\"y\"))===a.name2id(r)})).map((function(t){return t.substr(t.indexOf(\"y\"),t.length)})),m=n.simpleMap(g,a.id2name),v=0;v<m.length;v++){var y=m[v];u=h[y]||{},f=i.newContainer(p,y,\"yaxis\");var x,b=e[y];u.range&&b.isValidRange(u.range)&&(x=\"fixed\"),\"match\"!==w(\"rangemode\",x)&&w(\"range\",b.range.slice())}p._input=h}}function _(t,e){return n.coerce(h,p,o,t,e)}function w(t,e){return n.coerce(u,f,s,t,e)}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axis_ids\":831,\"./attributes\":712,\"./oppaxis_attributes\":719}],716:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../plots/plots\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../drawing\"),c=t(\"../color\"),u=t(\"../titles\"),f=t(\"../../plots/cartesian\"),h=t(\"../../plots/cartesian/axis_ids\"),p=t(\"../dragelement\"),d=t(\"../../lib/setcursor\"),g=t(\"./constants\");function m(t,e,r,n){var i=o.ensureSingle(t,\"rect\",g.bgClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})),a=n.borderwidth%2==0?n.borderwidth:n.borderwidth-1,c=-n._offsetShift,u=l.crispRound(e,n.borderwidth);i.attr({width:n._width+a,height:n._height+a,transform:s(c,c),fill:n.bgcolor,stroke:n.bordercolor,\"stroke-width\":u})}function v(t,e,r,n){var i=e._fullLayout;o.ensureSingleById(i._topdefs,\"clipPath\",n._clipId,(function(t){t.append(\"rect\").attr({x:0,y:0})})).select(\"rect\").attr({width:n._width,height:n._height})}function y(t,e,r,i){var s,c=e.calcdata,u=t.selectAll(\"g.\"+g.rangePlotClassName).data(r._subplotsWith,o.identity);u.enter().append(\"g\").attr(\"class\",(function(t){return g.rangePlotClassName+\" \"+t})).call(l.setClipUrl,i._clipId,e),u.order(),u.exit().remove(),u.each((function(t,o){var l=n.select(this),u=0===o,p=h.getFromId(e,t,\"y\"),d=p._name,g=i[d],m={data:[],layout:{xaxis:{type:r.type,domain:[0,1],range:i.range.slice(),calendar:r.calendar},width:i._width,height:i._height,margin:{t:0,b:0,l:0,r:0}},_context:e._context};r.rangebreaks&&(m.layout.xaxis.rangebreaks=r.rangebreaks),m.layout[d]={type:p.type,domain:[0,1],range:\"match\"!==g.rangemode?g.range.slice():p.range.slice(),calendar:p.calendar},p.rangebreaks&&(m.layout[d].rangebreaks=p.rangebreaks),a.supplyDefaults(m);var v=m._fullLayout.xaxis,y=m._fullLayout[d];v.clearCalc(),v.setScale(),y.clearCalc(),y.setScale();var x={id:t,plotgroup:l,xaxis:v,yaxis:y,isRangePlot:!0};u?s=x:(x.mainplot=\"xy\",x.mainplotinfo=s),f.rangePlot(e,x,function(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n],a=i[0].trace;a.xaxis+a.yaxis===e&&r.push(i)}return r}(c,t))}))}function x(t,e,r,n,i){(o.ensureSingle(t,\"rect\",g.maskMinClassName,(function(t){t.attr({x:0,y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),o.ensureSingle(t,\"rect\",g.maskMaxClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"height\",n._height).call(c.fill,g.maskColor),\"match\"!==i.rangemode)&&(o.ensureSingle(t,\"rect\",g.maskMinOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).call(c.fill,g.maskOppAxisColor),o.ensureSingle(t,\"rect\",g.maskMaxOppAxisClassName,(function(t){t.attr({y:0,\"shape-rendering\":\"crispEdges\"})})).attr(\"width\",n._width).style(\"border-top\",g.maskOppBorder).call(c.fill,g.maskOppAxisColor))}function b(t,e,r,n){e._context.staticPlot||o.ensureSingle(t,\"rect\",g.slideBoxClassName,(function(t){t.attr({y:0,cursor:g.slideBoxCursor,\"shape-rendering\":\"crispEdges\"})})).attr({height:n._height,fill:g.slideBoxFill})}function _(t,e,r,n){var i=o.ensureSingle(t,\"g\",g.grabberMinClassName),a=o.ensureSingle(t,\"g\",g.grabberMaxClassName),s={x:0,width:g.handleWidth,rx:g.handleRadius,fill:c.background,stroke:c.defaultLine,\"stroke-width\":g.handleStrokeWidth,\"shape-rendering\":\"crispEdges\"},l={y:Math.round(n._height/4),height:Math.round(n._height/2)};o.ensureSingle(i,\"rect\",g.handleMinClassName,(function(t){t.attr(s)})).attr(l),o.ensureSingle(a,\"rect\",g.handleMaxClassName,(function(t){t.attr(s)})).attr(l);var u={width:g.grabAreaWidth,x:0,y:0,fill:g.grabAreaFill,cursor:e._context.staticPlot?void 0:g.grabAreaCursor};o.ensureSingle(i,\"rect\",g.grabAreaMinClassName,(function(t){t.attr(u)})).attr(\"height\",n._height),o.ensureSingle(a,\"rect\",g.grabAreaMaxClassName,(function(t){t.attr(u)})).attr(\"height\",n._height)}e.exports=function(t){for(var e=t._fullLayout,r=e._rangeSliderData,a=0;a<r.length;a++){var l=r[a][g.name];l._clipId=l._id+\"-\"+e._uid}var c=e._infolayer.selectAll(\"g.\"+g.containerClassName).data(r,(function(t){return t._name}));c.exit().each((function(t){var r=t[g.name];e._topdefs.select(\"#\"+r._clipId).remove()})).remove(),0!==r.length&&(c.enter().append(\"g\").classed(g.containerClassName,!0).attr(\"pointer-events\",\"all\"),c.each((function(r){var a=n.select(this),l=r[g.name],c=e[h.id2name(r.anchor)],f=l[h.id2name(r.anchor)];if(l.range){var w,T=o.simpleMap(l.range,r.r2l),k=o.simpleMap(r.range,r.r2l);w=k[0]<k[1]?[Math.min(T[0],k[0]),Math.max(T[1],k[1])]:[Math.max(T[0],k[0]),Math.min(T[1],k[1])],l.range=l._input.range=o.simpleMap(w,r.l2r)}r.cleanRange(\"rangeslider.range\");var M=e._size,A=r.domain;l._width=M.w*(A[1]-A[0]);var S=Math.round(M.l+M.w*A[0]),E=Math.round(M.t+M.h*(1-r._counterDomainMin)+(\"bottom\"===r.side?r._depth:0)+l._offsetShift+g.extraPad);a.attr(\"transform\",s(S,E)),l._rl=o.simpleMap(l.range,r.r2l);var C=l._rl[0],L=l._rl[1],I=L-C;if(l.p2d=function(t){return t/l._width*I+C},l.d2p=function(t){return(t-C)/I*l._width},r.rangebreaks){var P=r.locateBreaks(C,L);if(P.length){var z,O,D=0;for(z=0;z<P.length;z++)D+=(O=P[z]).max-O.min;var R=l._width/(L-C-D),F=[-R*C];for(z=0;z<P.length;z++)O=P[z],F.push(F[F.length-1]-R*(O.max-O.min));for(l.d2p=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.max)e=F[r+1];else if(t<n.min)break}return e+R*t},z=0;z<P.length;z++)(O=P[z]).pmin=l.d2p(O.min),O.pmax=l.d2p(O.max);l.p2d=function(t){for(var e=F[0],r=0;r<P.length;r++){var n=P[r];if(t>=n.pmax)e=F[r+1];else if(t<n.pmin)break}return(t-e)/R}}}if(\"match\"!==f.rangemode){var B=c.r2l(f.range[0]),N=c.r2l(f.range[1])-B;l.d2pOppAxis=function(t){return(t-B)/N*l._height}}a.call(m,t,r,l).call(v,t,r,l).call(y,t,r,l).call(x,t,r,l,f).call(b,t,r,l).call(_,t,r,l),function(t,e,r,a){if(e._context.staticPlot)return;var s=t.select(\"rect.\"+g.slideBoxClassName).node(),l=t.select(\"rect.\"+g.grabAreaMinClassName).node(),c=t.select(\"rect.\"+g.grabAreaMaxClassName).node();function u(){var u=n.event,f=u.target,h=u.clientX||u.touches[0].clientX,g=h-t.node().getBoundingClientRect().left,m=a.d2p(r._rl[0]),v=a.d2p(r._rl[1]),y=p.coverSlip();function x(t){var u,p,x,b=+(t.clientX||t.touches[0].clientX)-h;switch(f){case s:x=\"ew-resize\",u=m+b,p=v+b;break;case l:x=\"col-resize\",u=m+b,p=v;break;case c:x=\"col-resize\",u=m,p=v+b;break;default:x=\"ew-resize\",u=g,p=g+b}if(p<u){var _=p;p=u,u=_}a._pixelMin=u,a._pixelMax=p,d(n.select(y),x),function(t,e,r,n){function a(t){return r.l2r(o.constrain(t,n._rl[0],n._rl[1]))}var s=a(n.p2d(n._pixelMin)),l=a(n.p2d(n._pixelMax));window.requestAnimationFrame((function(){i.call(\"_guiRelayout\",e,r._name+\".range\",[s,l])}))}(0,e,r,a)}function b(){y.removeEventListener(\"mousemove\",x),y.removeEventListener(\"mouseup\",b),this.removeEventListener(\"touchmove\",x),this.removeEventListener(\"touchend\",b),o.removeElement(y)}this.addEventListener(\"touchmove\",x),this.addEventListener(\"touchend\",b),y.addEventListener(\"mousemove\",x),y.addEventListener(\"mouseup\",b)}t.on(\"mousedown\",u),t.on(\"touchstart\",u)}(a,t,r,l),function(t,e,r,n,i,a){var l=g.handleWidth/2;function c(t){return o.constrain(t,0,n._width)}function u(t){return o.constrain(t,0,n._height)}function f(t){return o.constrain(t,-l,n._width+l)}var h=c(n.d2p(r._rl[0])),p=c(n.d2p(r._rl[1]));if(t.select(\"rect.\"+g.slideBoxClassName).attr(\"x\",h).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMinClassName).attr(\"width\",h),t.select(\"rect.\"+g.maskMaxClassName).attr(\"x\",p).attr(\"width\",n._width-p),\"match\"!==a.rangemode){var d=n._height-u(n.d2pOppAxis(i._rl[1])),m=n._height-u(n.d2pOppAxis(i._rl[0]));t.select(\"rect.\"+g.maskMinOppAxisClassName).attr(\"x\",h).attr(\"height\",d).attr(\"width\",p-h),t.select(\"rect.\"+g.maskMaxOppAxisClassName).attr(\"x\",h).attr(\"y\",m).attr(\"height\",n._height-m).attr(\"width\",p-h),t.select(\"rect.\"+g.slideBoxClassName).attr(\"y\",d).attr(\"height\",m-d)}var v=Math.round(f(h-l))-.5,y=Math.round(f(p-l))+.5;t.select(\"g.\"+g.grabberMinClassName).attr(\"transform\",s(v,.5)),t.select(\"g.\"+g.grabberMaxClassName).attr(\"transform\",s(y,.5))}(a,0,r,l,c,f),\"bottom\"===r.side&&u.draw(t,r._id+\"title\",{propContainer:r,propName:r._name+\".title\",placeholder:e._dfltTitle.x,attributes:{x:r._offset+r._length/2,y:E+l._height+l._offsetShift+10+1.5*r.title.font.size,\"text-anchor\":\"middle\"}})})))}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plots/cartesian\":841,\"../../plots/cartesian/axis_ids\":831,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"../titles\":738,\"./constants\":714,d3:169}],717:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axis_ids\"),i=t(\"../../lib/svg_text_utils\"),a=t(\"./constants\"),o=t(\"../../constants/alignment\").LINE_SPACING,s=a.name;function l(t){var e=t&&t[s];return e&&e.visible}r.isVisible=l,r.makeData=function(t){var e=n.list({_fullLayout:t},\"x\",!0),r=t.margin,i=[];if(!t._has(\"gl2d\"))for(var a=0;a<e.length;a++){var o=e[a];if(l(o)){i.push(o);var c=o[s];c._id=s+o._id,c._height=(t.height-r.b-r.t)*c.thickness,c._offsetShift=Math.floor(c.borderwidth/2)}}t._rangeSliderData=i},r.autoMarginOpts=function(t,e){var r=t._fullLayout,n=e[s],l=e._id.charAt(0),c=0,u=0;\"bottom\"===e.side&&(c=e._depth,e.title.text!==r._dfltTitle[l]&&(u=1.5*e.title.font.size+10+n._offsetShift,u+=(e.title.text.match(i.BR_TAG_ALL)||[]).length*e.title.font.size*o));return{x:0,y:e._counterDomainMin,l:0,r:0,t:0,b:n._height+c+Math.max(r.margin.b,u),pad:a.extraPad+2*n._offsetShift}}},{\"../../constants/alignment\":745,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axis_ids\":831,\"./constants\":714}],718:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./oppaxis_attributes\"),o=t(\"./helpers\");e.exports={moduleType:\"component\",name:\"rangeslider\",schema:{subplots:{xaxis:{rangeslider:n.extendFlat({},i,{yaxis:a})}}},layoutAttributes:t(\"./attributes\"),handleDefaults:t(\"./defaults\"),calcAutorange:t(\"./calc_autorange\"),draw:t(\"./draw\"),isVisible:o.isVisible,makeData:o.makeData,autoMarginOpts:o.autoMarginOpts}},{\"../../lib\":778,\"./attributes\":712,\"./calc_autorange\":713,\"./defaults\":715,\"./draw\":716,\"./helpers\":717,\"./oppaxis_attributes\":719}],719:[function(t,e,r){\"use strict\";e.exports={_isSubplotObj:!0,rangemode:{valType:\"enumerated\",values:[\"auto\",\"fixed\",\"match\"],dflt:\"match\",editType:\"calc\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"plot\"},{valType:\"any\",editType:\"plot\"}],editType:\"plot\"},editType:\"calc\"}},{}],720:[function(t,e,r){\"use strict\";var n=t(\"../annotations/attributes\"),i=t(\"../../traces/scatter/attributes\").line,a=t(\"../drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray;t(\"../../constants/axis_placeable_objects\");e.exports=s(\"shape\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc+arraydraw\"},type:{valType:\"enumerated\",values:[\"circle\",\"rect\",\"path\",\"line\"],editType:\"calc+arraydraw\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"arraydraw\"},xref:o({},n.xref,{}),xsizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},xanchor:{valType:\"any\",editType:\"calc+arraydraw\"},x0:{valType:\"any\",editType:\"calc+arraydraw\"},x1:{valType:\"any\",editType:\"calc+arraydraw\"},yref:o({},n.yref,{}),ysizemode:{valType:\"enumerated\",values:[\"scaled\",\"pixel\"],dflt:\"scaled\",editType:\"calc+arraydraw\"},yanchor:{valType:\"any\",editType:\"calc+arraydraw\"},y0:{valType:\"any\",editType:\"calc+arraydraw\"},y1:{valType:\"any\",editType:\"calc+arraydraw\"},path:{valType:\"string\",editType:\"calc+arraydraw\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"arraydraw\"},line:{color:o({},i.color,{editType:\"arraydraw\"}),width:o({},i.width,{editType:\"calc+arraydraw\"}),dash:o({},a,{editType:\"arraydraw\"}),editType:\"calc+arraydraw\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"arraydraw\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"arraydraw\"},editable:{valType:\"boolean\",dflt:!1,editType:\"calc+arraydraw\"},editType:\"arraydraw\"})},{\"../../constants/axis_placeable_objects\":746,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../annotations/attributes\":626,\"../drawing/attributes\":664}],721:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"./constants\"),o=t(\"./helpers\");function s(t){return c(t.line.width,t.xsizemode,t.x0,t.x1,t.path,!1)}function l(t){return c(t.line.width,t.ysizemode,t.y0,t.y1,t.path,!0)}function c(t,e,r,i,s,l){var c=t/2,u=l;if(\"pixel\"===e){var f=s?o.extractPathCoords(s,l?a.paramIsY:a.paramIsX):[r,i],h=n.aggNums(Math.max,null,f),p=n.aggNums(Math.min,null,f),d=p<0?Math.abs(p)+c:c,g=h>0?h+c:c;return{ppad:c,ppadplus:u?d:g,ppadminus:u?g:d}}return{ppad:c}}function u(t,e,r,n,i){var s=\"category\"===t.type||\"multicategory\"===t.type?t.r2c:t.d2c;if(void 0!==e)return[s(e),s(r)];if(n){var l,c,u,f,h=1/0,p=-1/0,d=n.match(a.segmentRE);for(\"date\"===t.type&&(s=o.decodeDate(s)),l=0;l<d.length;l++)void 0!==(c=i[d[l].charAt(0)].drawn)&&(!(u=d[l].substr(1).match(a.paramRE))||u.length<c||((f=s(u[c]))<h&&(h=f),f>p&&(p=f)));return p>=h?[h,p]:void 0}}e.exports=function(t){var e=t._fullLayout,r=n.filterVisible(e.shapes);if(r.length&&t._fullData.length)for(var o=0;o<r.length;o++){var c,f,h=r[o];h._extremes={};var p=i.getRefType(h.xref),d=i.getRefType(h.yref);if(\"paper\"!==h.xref&&\"domain\"!==p){var g=\"pixel\"===h.xsizemode?h.xanchor:h.x0,m=\"pixel\"===h.xsizemode?h.xanchor:h.x1;(f=u(c=i.getFromId(t,h.xref),g,m,h.path,a.paramIsX))&&(h._extremes[c._id]=i.findExtremes(c,f,s(h)))}if(\"paper\"!==h.yref&&\"domain\"!==d){var v=\"pixel\"===h.ysizemode?h.yanchor:h.y0,y=\"pixel\"===h.ysizemode?h.yanchor:h.y1;(f=u(c=i.getFromId(t,h.yref),v,y,h.path,a.paramIsY))&&(h._extremes[c._id]=i.findExtremes(c,f,l(h)))}}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":722,\"./helpers\":731}],722:[function(t,e,r){\"use strict\";e.exports={segmentRE:/[MLHVQCTSZ][^MLHVQCTSZ]*/g,paramRE:/[^\\s,]+/g,paramIsX:{M:{0:!0,drawn:0},L:{0:!0,drawn:0},H:{0:!0,drawn:0},V:{},Q:{0:!0,2:!0,drawn:2},C:{0:!0,2:!0,4:!0,drawn:4},T:{0:!0,drawn:0},S:{0:!0,2:!0,drawn:2},Z:{}},paramIsY:{M:{1:!0,drawn:1},L:{1:!0,drawn:1},H:{},V:{0:!0,drawn:0},Q:{1:!0,3:!0,drawn:3},C:{1:!0,3:!0,5:!0,drawn:5},T:{1:!0,drawn:1},S:{1:!0,3:!0,drawn:5},Z:{}},numParams:{M:2,L:2,H:1,V:1,Q:4,C:6,T:2,S:4,Z:0}}},{}],723:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/array_container_defaults\"),o=t(\"./attributes\"),s=t(\"./helpers\");function l(t,e,r){function a(r,i){return n.coerce(t,e,o,r,i)}if(a(\"visible\")){var l=a(\"path\"),c=a(\"type\",l?\"path\":\"rect\");\"path\"!==e.type&&delete e.path,a(\"editable\"),a(\"layer\"),a(\"opacity\"),a(\"fillcolor\"),a(\"fillrule\"),a(\"line.width\")&&(a(\"line.color\"),a(\"line.dash\"));for(var u=a(\"xsizemode\"),f=a(\"ysizemode\"),h=[\"x\",\"y\"],p=0;p<2;p++){var d,g,m,v=h[p],y=v+\"anchor\",x=\"x\"===v?u:f,b={_fullLayout:r},_=i.coerceRef(t,e,b,v,void 0,\"paper\");if(\"range\"===i.getRefType(_)?((d=i.getFromId(b,_))._shapeIndices.push(e._index),m=s.rangeToShapePosition(d),g=s.shapePositionToRange(d)):g=m=n.identity,\"path\"!==c){var w=v+\"0\",T=v+\"1\",k=t[w],M=t[T];t[w]=g(t[w],!0),t[T]=g(t[T],!0),\"pixel\"===x?(a(w,0),a(T,10)):(i.coercePosition(e,b,a,_,w,.25),i.coercePosition(e,b,a,_,T,.75)),e[w]=m(e[w]),e[T]=m(e[T]),t[w]=k,t[T]=M}if(\"pixel\"===x){var A=t[y];t[y]=g(t[y],!0),i.coercePosition(e,b,a,_,y,.25),e[y]=m(e[y]),t[y]=A}}\"path\"===c?a(\"path\"):n.noneOrAll(t,e,[\"x0\",\"x1\",\"y0\",\"y1\"])}}e.exports=function(t,e){a(t,e,{name:\"shapes\",handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"./attributes\":720,\"./helpers\":731}],724:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"./draw_newshape/helpers\").readPaths,s=t(\"./draw_newshape/display_outlines\"),l=t(\"../../plots/cartesian/handle_outline\").clearOutlineControllers,c=t(\"../color\"),u=t(\"../drawing\"),f=t(\"../../plot_api/plot_template\").arrayEditor,h=t(\"../dragelement\"),p=t(\"../../lib/setcursor\"),d=t(\"./constants\"),g=t(\"./helpers\");function m(t){var e=t._fullLayout;for(var r in e._shapeUpperLayer.selectAll(\"path\").remove(),e._shapeLowerLayer.selectAll(\"path\").remove(),e._plots){var n=e._plots[r].shapelayer;n&&n.selectAll(\"path\").remove()}for(var i=0;i<e.shapes.length;i++)e.shapes[i].visible&&x(t,i)}function v(t){return!!t._fullLayout._drawing}function y(t){return!t._context.edits.shapePosition}function x(t,e){t._fullLayout._paperdiv.selectAll('.shapelayer [data-index=\"'+e+'\"]').remove();var r=g.makeOptionsAndPlotinfo(t,e),l=r.options,x=r.plotinfo;if(l._input&&!1!==l.visible)if(\"below\"!==l.layer)k(t._fullLayout._shapeUpperLayer);else if(\"paper\"===l.xref||\"paper\"===l.yref)k(t._fullLayout._shapeLowerLayer);else{if(x._hadPlotinfo)k((x.mainplotinfo||x).shapelayer);else k(t._fullLayout._shapeLowerLayer)}function k(r){var k=_(t,l),M={\"data-index\":e,\"fill-rule\":l.fillrule,d:k},A=l.opacity,S=l.fillcolor,E=l.line.width?l.line.color:\"rgba(0,0,0,0)\",C=l.line.width,L=l.line.dash;C||!0!==l.editable||(C=5,L=\"solid\");var I=\"Z\"!==k[k.length-1],P=y(t)&&l.editable&&t._fullLayout._activeShapeIndex===e;P&&(S=I?\"rgba(0,0,0,0)\":t._fullLayout.activeshape.fillcolor,A=t._fullLayout.activeshape.opacity);var z,O=r.append(\"path\").attr(M).style(\"opacity\",A).call(c.stroke,E).call(c.fill,S).call(u.dashLine,L,C);if(b(O,t,l),(P||t._context.edits.shapePosition)&&(z=f(t.layout,\"shapes\",l)),P){O.style({cursor:\"move\"});var D={element:O.node(),plotinfo:x,gd:t,editHelpers:z,isActiveShape:!0},R=o(k,t);s(R,O,D)}else t._context.edits.shapePosition?function(t,e,r,o,s,l){var c,f,m,y,x,T,k,M,A,S,E,C,L,I,P,z,O=\"pixel\"===r.xsizemode,D=\"pixel\"===r.ysizemode,R=\"line\"===r.type,F=\"path\"===r.type,B=l.modifyItem,N=a.getFromId(t,r.xref),j=a.getRefType(r.xref),U=a.getFromId(t,r.yref),V=a.getRefType(r.yref),q=g.getDataToPixel(t,N,!1,j),H=g.getDataToPixel(t,U,!0,V),G=g.getPixelToData(t,N,!1,j),Y=g.getPixelToData(t,U,!0,V),W=R?function(){var t=Math.max(r.line.width,10),n=s.append(\"g\").attr(\"data-index\",o);n.append(\"path\").attr(\"d\",e.attr(\"d\")).style({cursor:\"move\",\"stroke-width\":t,\"stroke-opacity\":\"0\"});var i={\"fill-opacity\":\"0\"},a=Math.max(t/2,10);return n.append(\"circle\").attr({\"data-line-point\":\"start-point\",cx:O?q(r.xanchor)+r.x0:q(r.x0),cy:D?H(r.yanchor)-r.y0:H(r.y0),r:a}).style(i).classed(\"cursor-grab\",!0),n.append(\"circle\").attr({\"data-line-point\":\"end-point\",cx:O?q(r.xanchor)+r.x1:q(r.x1),cy:D?H(r.yanchor)-r.y1:H(r.y1),r:a}).style(i).classed(\"cursor-grab\",!0),n}():e,X={element:W.node(),gd:t,prepFn:function(n){if(v(t))return;O&&(x=q(r.xanchor));D&&(T=H(r.yanchor));\"path\"===r.type?P=r.path:(c=O?r.x0:q(r.x0),f=D?r.y0:H(r.y0),m=O?r.x1:q(r.x1),y=D?r.y1:H(r.y1));c<m?(A=c,L=\"x0\",S=m,I=\"x1\"):(A=m,L=\"x1\",S=c,I=\"x0\");!D&&f<y||D&&f>y?(k=f,E=\"y0\",M=y,C=\"y1\"):(k=y,E=\"y1\",M=f,C=\"y0\");Z(n),Q(s,r),function(t,e,r){var n=e.xref,i=e.yref,o=a.getFromId(r,n),s=a.getFromId(r,i),l=\"\";\"paper\"===n||o.autorange||(l+=n);\"paper\"===i||s.autorange||(l+=i);u.setClipUrl(t,l?\"clip\"+r._fullLayout._uid+l:null,r)}(e,r,t),X.moveFn=\"move\"===z?J:K,X.altKey=n.altKey},doneFn:function(){if(v(t))return;p(e),$(s),b(e,t,r),n.call(\"_guiRelayout\",t,l.getUpdateObj())},clickFn:function(){if(v(t))return;$(s)}};function Z(r){if(v(t))z=null;else if(R)z=\"path\"===r.target.tagName?\"move\":\"start-point\"===r.target.attributes[\"data-line-point\"].value?\"resize-over-start-point\":\"resize-over-end-point\";else{var n=X.element.getBoundingClientRect(),i=n.right-n.left,a=n.bottom-n.top,o=r.clientX-n.left,s=r.clientY-n.top,l=!F&&i>10&&a>10&&!r.shiftKey?h.getCursor(o/i,1-s/a):\"move\";p(e,l),z=l.split(\"-\")[0]}}function J(n,i){if(\"path\"===r.type){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else O?B(\"xanchor\",r.xanchor=G(x+n)):(B(\"x0\",r.x0=G(c+n)),B(\"x1\",r.x1=G(m+n))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(B(\"y0\",r.y0=Y(f+i)),B(\"y1\",r.y1=Y(y+i)));e.attr(\"d\",_(t,r)),Q(s,r)}function K(n,i){if(F){var a=function(t){return t},o=a,l=a;O?B(\"xanchor\",r.xanchor=G(x+n)):(o=function(t){return G(q(t)+n)},N&&\"date\"===N.type&&(o=g.encodeDate(o))),D?B(\"yanchor\",r.yanchor=Y(T+i)):(l=function(t){return Y(H(t)+i)},U&&\"date\"===U.type&&(l=g.encodeDate(l))),B(\"path\",r.path=w(P,o,l))}else if(R){if(\"resize-over-start-point\"===z){var u=c+n,h=D?f-i:f+i;B(\"x0\",r.x0=O?u:G(u)),B(\"y0\",r.y0=D?h:Y(h))}else if(\"resize-over-end-point\"===z){var p=m+n,d=D?y-i:y+i;B(\"x1\",r.x1=O?p:G(p)),B(\"y1\",r.y1=D?d:Y(d))}}else{var v=function(t){return-1!==z.indexOf(t)},b=v(\"n\"),j=v(\"s\"),V=v(\"w\"),W=v(\"e\"),X=b?k+i:k,Z=j?M+i:M,J=V?A+n:A,K=W?S+n:S;D&&(b&&(X=k-i),j&&(Z=M-i)),(!D&&Z-X>10||D&&X-Z>10)&&(B(E,r[E]=D?X:Y(X)),B(C,r[C]=D?Z:Y(Z))),K-J>10&&(B(L,r[L]=O?J:G(J)),B(I,r[I]=O?K:G(K)))}e.attr(\"d\",_(t,r)),Q(s,r)}function Q(t,e){(O||D)&&function(){var r=\"path\"!==e.type,n=t.selectAll(\".visual-cue\").data([0]);n.enter().append(\"path\").attr({fill:\"#fff\",\"fill-rule\":\"evenodd\",stroke:\"#000\",\"stroke-width\":1}).classed(\"visual-cue\",!0);var a=q(O?e.xanchor:i.midRange(r?[e.x0,e.x1]:g.extractPathCoords(e.path,d.paramIsX))),o=H(D?e.yanchor:i.midRange(r?[e.y0,e.y1]:g.extractPathCoords(e.path,d.paramIsY)));if(a=g.roundPositionForSharpStrokeRendering(a,1),o=g.roundPositionForSharpStrokeRendering(o,1),O&&D){var s=\"M\"+(a-1-1)+\",\"+(o-1-1)+\"h-8v2h8 v8h2v-8 h8v-2h-8 v-8h-2 Z\";n.attr(\"d\",s)}else if(O){var l=\"M\"+(a-1-1)+\",\"+(o-9-1)+\"v18 h2 v-18 Z\";n.attr(\"d\",l)}else{var c=\"M\"+(a-9-1)+\",\"+(o-1-1)+\"h18 v2 h-18 Z\";n.attr(\"d\",c)}}()}function $(t){t.selectAll(\".visual-cue\").remove()}h.init(X),W.node().onmousemove=Z}(t,O,l,e,r,z):!0===l.editable&&O.style(\"pointer-events\",I||c.opacity(S)*A<=.5?\"stroke\":\"all\");O.node().addEventListener(\"click\",(function(){return function(t,e){if(!y(t))return;var r=+e.node().getAttribute(\"data-index\");if(r>=0){if(r===t._fullLayout._activeShapeIndex)return void T(t);t._fullLayout._activeShapeIndex=r,t._fullLayout._deactivateShape=T,m(t)}}(t,O)}))}}function b(t,e,r){var n=(r.xref+r.yref).replace(/paper/g,\"\").replace(/[xyz][1-9]* *domain/g,\"\");u.setClipUrl(t,n?\"clip\"+e._fullLayout._uid+n:null,e)}function _(t,e){var r,n,o,s,l,c,u,f,h=e.type,p=a.getRefType(e.xref),m=a.getRefType(e.yref),v=a.getFromId(t,e.xref),y=a.getFromId(t,e.yref),x=t._fullLayout._size;if(v?\"domain\"===p?n=function(t){return v._offset+v._length*t}:(r=g.shapePositionToRange(v),n=function(t){return v._offset+v.r2p(r(t,!0))}):n=function(t){return x.l+x.w*t},y?\"domain\"===m?s=function(t){return y._offset+y._length*(1-t)}:(o=g.shapePositionToRange(y),s=function(t){return y._offset+y.r2p(o(t,!0))}):s=function(t){return x.t+x.h*(1-t)},\"path\"===h)return v&&\"date\"===v.type&&(n=g.decodeDate(n)),y&&\"date\"===y.type&&(s=g.decodeDate(s)),function(t,e,r){var n=t.path,a=t.xsizemode,o=t.ysizemode,s=t.xanchor,l=t.yanchor;return n.replace(d.segmentRE,(function(t){var n=0,c=t.charAt(0),u=d.paramIsX[c],f=d.paramIsY[c],h=d.numParams[c],p=t.substr(1).replace(d.paramRE,(function(t){return u[n]?t=\"pixel\"===a?e(s)+Number(t):e(t):f[n]&&(t=\"pixel\"===o?r(l)-Number(t):r(t)),++n>h&&(t=\"X\"),t}));return n>h&&(p=p.replace(/[\\s,]*X.*/,\"\"),i.log(\"Ignoring extra params in segment \"+t)),c+p}))}(e,n,s);if(\"pixel\"===e.xsizemode){var b=n(e.xanchor);l=b+e.x0,c=b+e.x1}else l=n(e.x0),c=n(e.x1);if(\"pixel\"===e.ysizemode){var _=s(e.yanchor);u=_-e.y0,f=_-e.y1}else u=s(e.y0),f=s(e.y1);if(\"line\"===h)return\"M\"+l+\",\"+u+\"L\"+c+\",\"+f;if(\"rect\"===h)return\"M\"+l+\",\"+u+\"H\"+c+\"V\"+f+\"H\"+l+\"Z\";var w=(l+c)/2,T=(u+f)/2,k=Math.abs(w-l),M=Math.abs(T-u),A=\"A\"+k+\",\"+M,S=w+k+\",\"+T;return\"M\"+S+A+\" 0 1,1 \"+(w+\",\"+(T-M))+A+\" 0 0,1 \"+S+\"Z\"}function w(t,e,r){return t.replace(d.segmentRE,(function(t){var n=0,i=t.charAt(0),a=d.paramIsX[i],o=d.paramIsY[i],s=d.numParams[i];return i+t.substr(1).replace(d.paramRE,(function(t){return n>=s||(a[n]?t=e(t):o[n]&&(t=r(t)),n++),t}))}))}function T(t){y(t)&&(t._fullLayout._activeShapeIndex>=0&&(l(t),delete t._fullLayout._activeShapeIndex,m(t)))}e.exports={draw:m,drawOne:x,eraseActiveShape:function(t){if(!y(t))return;l(t);var e=t._fullLayout._activeShapeIndex,r=(t.layout||{}).shapes||[];if(e<r.length){for(var i=[],a=0;a<r.length;a++)a!==e&&i.push(r[a]);delete t._fullLayout._activeShapeIndex,n.call(\"_guiRelayout\",t,{shapes:i})}}}},{\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/handle_outline\":838,\"../../registry\":911,\"../color\":643,\"../dragelement\":662,\"../drawing\":665,\"./constants\":722,\"./draw_newshape/display_outlines\":728,\"./draw_newshape/helpers\":729,\"./helpers\":731}],725:[function(t,e,r){\"use strict\";var n=t(\"../../drawing/attributes\").dash,i=t(\"../../../lib/extend\").extendFlat;e.exports={newshape:{line:{color:{valType:\"color\",editType:\"none\"},width:{valType:\"number\",min:0,dflt:4,editType:\"none\"},dash:i({},n,{dflt:\"solid\",editType:\"none\"}),editType:\"none\"},fillcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"none\"},fillrule:{valType:\"enumerated\",values:[\"evenodd\",\"nonzero\"],dflt:\"evenodd\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"none\"},layer:{valType:\"enumerated\",values:[\"below\",\"above\"],dflt:\"above\",editType:\"none\"},drawdirection:{valType:\"enumerated\",values:[\"ortho\",\"horizontal\",\"vertical\",\"diagonal\"],dflt:\"diagonal\",editType:\"none\"},editType:\"none\"},activeshape:{fillcolor:{valType:\"color\",dflt:\"rgb(255,0,255)\",editType:\"none\"},opacity:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"none\"},editType:\"none\"}}},{\"../../../lib/extend\":768,\"../../drawing/attributes\":664}],726:[function(t,e,r){\"use strict\";e.exports={CIRCLE_SIDES:32,i000:0,i090:8,i180:16,i270:24,cos45:Math.cos(Math.PI/4),sin45:Math.sin(Math.PI/4),SQRT2:Math.sqrt(2)}},{}],727:[function(t,e,r){\"use strict\";var n=t(\"../../color\");e.exports=function(t,e,r){if(r(\"newshape.drawdirection\"),r(\"newshape.layer\"),r(\"newshape.fillcolor\"),r(\"newshape.fillrule\"),r(\"newshape.opacity\"),r(\"newshape.line.width\")){var i=(t||{}).plot_bgcolor||\"#FFF\";r(\"newshape.line.color\",n.contrast(i)),r(\"newshape.line.dash\")}r(\"activeshape.fillcolor\"),r(\"activeshape.opacity\")}},{\"../../color\":643}],728:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement\"),i=t(\"../../dragelement/helpers\").drawMode,a=t(\"../../../registry\"),o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=t(\"../../../plots/cartesian/handle_outline\").clearOutlineControllers,h=t(\"./helpers\"),p=h.pointsShapeRectangle,d=h.pointsShapeEllipse,g=h.writePaths,m=t(\"./newshapes\");e.exports=function t(e,r,o,h){h||(h=0);var v=o.gd;function y(){t(e,r,o,h++),d(e[0])&&x({redrawing:!0})}function x(t){o.isActiveShape=!1;var e=m(r,o);Object.keys(e).length&&a.call((t||{}).redrawing?\"relayout\":\"_guiRelayout\",v,e)}var b,_,w,T,k,M=o.isActiveShape,A=v._fullLayout._zoomlayer,S=o.dragmode;(i(S)?v._fullLayout._drawing=!0:v._fullLayout._activeShapeIndex>=0&&f(v),r.attr(\"d\",g(e)),M&&!h)&&(k=function(t,e){for(var r=0;r<e.length;r++){var n=e[r];t[r]=[];for(var i=0;i<n.length;i++){t[r][i]=[];for(var a=0;a<n[i].length;a++)t[r][i][a]=n[i][a]}}return t}([],e),function(t){b=[];for(var r=0;r<e.length;r++){var i=e[r],a=!p(i)&&d(i);b[r]=[];for(var o=0;o<i.length;o++)if(\"Z\"!==i[o][0]&&(!a||o===s||o===l||o===c||o===u)){var f=i[o][1],h=i[o][2],g=t.append(\"circle\").classed(\"cursor-grab\",!0).attr(\"data-i\",r).attr(\"data-j\",o).attr(\"cx\",f).attr(\"cy\",h).attr(\"r\",4).style({\"mix-blend-mode\":\"luminosity\",fill:\"black\",stroke:\"white\",\"stroke-width\":1});b[r][o]={element:g.node(),gd:v,prepFn:E,doneFn:L,clickFn:I},n.init(b[r][o])}}}(A.append(\"g\").attr(\"class\",\"outline-controllers\")),function(){if(_=[],!e.length)return;_[0]={element:r[0][0],gd:v,prepFn:z,doneFn:O},n.init(_[0])}());function E(t){w=+t.srcElement.getAttribute(\"data-i\"),T=+t.srcElement.getAttribute(\"data-j\"),b[w][T].moveFn=C}function C(t,r){if(e.length){var n=k[w][T][1],i=k[w][T][2],a=e[w],o=a.length;if(p(a)){for(var s=0;s<o;s++)if(s!==T){var l=a[s];l[1]===a[T][1]&&(l[1]=n+t),l[2]===a[T][2]&&(l[2]=i+r)}if(a[T][1]=n+t,a[T][2]=i+r,!p(a))for(var c=0;c<o;c++)for(var u=0;u<a[c].length;u++)a[c][u]=k[w][c][u]}else a[T][1]=n+t,a[T][2]=i+r;y()}}function L(){x()}function I(t,r){if(2===t){w=+r.srcElement.getAttribute(\"data-i\"),T=+r.srcElement.getAttribute(\"data-j\");var n=e[w];p(n)||d(n)||function(){if(e.length&&e[w]&&e[w].length){for(var t=[],r=0;r<e[w].length;r++)r!==T&&t.push(e[w][r]);t.length>1&&(2!==t.length||\"Z\"!==t[1][0])&&(0===T&&(t[0][0]=\"M\"),e[w]=t,y(),x())}}()}}function P(t,r){!function(t,r){if(e.length)for(var n=0;n<e.length;n++)for(var i=0;i<e[n].length;i++)for(var a=0;a+2<e[n][i].length;a+=2)e[n][i][a+1]=k[n][i][a+1]+t,e[n][i][a+2]=k[n][i][a+2]+r}(t,r),y()}function z(t){(w=+t.srcElement.getAttribute(\"data-i\"))||(w=0),_[w].moveFn=P}function O(){x()}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../registry\":911,\"../../dragelement\":662,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729,\"./newshapes\":730}],729:[function(t,e,r){\"use strict\";var n=t(\"parse-svg-path\"),i=t(\"./constants\"),a=i.CIRCLE_SIDES,o=i.SQRT2,s=t(\"../../../plots/cartesian/helpers\"),l=s.p2r,c=s.r2p,u=[0,3,4,5,6,1,2],f=[0,3,4,1,2];function h(t,e){return Math.abs(t-e)<=1e-6}function p(t,e){var r=e[1]-t[1],n=e[2]-t[2];return Math.sqrt(r*r+n*n)}r.writePaths=function(t){var e=t.length;if(!e)return\"M0,0Z\";for(var r=\"\",n=0;n<e;n++)for(var i=t[n].length,a=0;a<i;a++){var o=t[n][a][0];if(\"Z\"===o)r+=\"Z\";else for(var s=t[n][a].length,l=0;l<s;l++){var c=l;\"Q\"===o||\"S\"===o?c=f[l]:\"C\"===o&&(c=u[l]),r+=t[n][a][c],l>0&&l<s-1&&(r+=\",\")}}return r},r.readPaths=function(t,e,r,i){var o,s,u,f=n(t),h=[],p=-1,d=0,g=0,m=function(){s=d,u=g};m();for(var v=0;v<f.length;v++){var y,x,b,_,w=[],T=f[v][0],k=T;switch(T){case\"M\":p++,h[p]=[],d=+f[v][1],g=+f[v][2],w.push([k,d,g]),m();break;case\"Q\":case\"S\":y=+f[v][1],b=+f[v][2],d=+f[v][3],g=+f[v][4],w.push([k,d,g,y,b]);break;case\"C\":y=+f[v][1],b=+f[v][2],x=+f[v][3],_=+f[v][4],d=+f[v][5],g=+f[v][6],w.push([k,d,g,y,b,x,_]);break;case\"T\":case\"L\":d=+f[v][1],g=+f[v][2],w.push([k,d,g]);break;case\"H\":k=\"L\",d=+f[v][1],w.push([k,d,g]);break;case\"V\":k=\"L\",g=+f[v][1],w.push([k,d,g]);break;case\"A\":k=\"L\";var M=+f[v][1],A=+f[v][2];+f[v][4]||(M=-M,A=-A);var S=d-M,E=g;for(o=1;o<=a/2;o++){var C=2*Math.PI*o/a;w.push([k,S+M*Math.cos(C),E+A*Math.sin(C)])}break;case\"Z\":d===s&&g===u||(d=s,g=u,w.push([k,d,g]))}for(var L=(r||{}).domain,I=e._fullLayout._size,P=r&&\"pixel\"===r.xsizemode,z=r&&\"pixel\"===r.ysizemode,O=!1===i,D=0;D<w.length;D++){for(o=0;o+2<7;o+=2){var R=w[D][o+1],F=w[D][o+2];void 0!==R&&void 0!==F&&(d=R,g=F,r&&(r.xaxis&&r.xaxis.p2r?(O&&(R-=r.xaxis._offset),R=P?c(r.xaxis,r.xanchor)+R:l(r.xaxis,R)):(O&&(R-=I.l),L?R=L.x[0]+R/I.w:R/=I.w),r.yaxis&&r.yaxis.p2r?(O&&(F-=r.yaxis._offset),F=z?c(r.yaxis,r.yanchor)-F:l(r.yaxis,F)):(O&&(F-=I.t),F=L?L.y[1]-F/I.h:1-F/I.h)),w[D][o+1]=R,w[D][o+2]=F)}h[p].push(w[D].slice())}}return h},r.pointsShapeRectangle=function(t){if(5!==t.length)return!1;for(var e=1;e<3;e++){if(!h(t[0][e]-t[1][e],t[3][e]-t[2][e]))return!1;if(!h(t[0][e]-t[3][e],t[1][e]-t[2][e]))return!1}return!(!h(t[0][1],t[1][1])&&!h(t[0][1],t[3][1]))&&!!(p(t[0],t[1])*p(t[0],t[3]))},r.pointsShapeEllipse=function(t){var e=t.length;if(e!==a+1)return!1;e=a;for(var r=0;r<e;r++){var n=(2*e-r)%e,i=(e/2+n)%e,o=(e/2+r)%e;if(!h(p(t[r],t[o]),p(t[n],t[i])))return!1}return!0},r.handleEllipse=function(t,e,n){if(!t)return[e,n];var i=r.ellipseOver({x0:e[0],y0:e[1],x1:n[0],y1:n[1]}),s=(i.x1+i.x0)/2,l=(i.y1+i.y0)/2,c=(i.x1-i.x0)/2,u=(i.y1-i.y0)/2;c||(c=u/=o),u||(u=c/=o);for(var f=[],h=0;h<a;h++){var p=2*h*Math.PI/a;f.push([s+c*Math.cos(p),l+u*Math.sin(p)])}return f},r.ellipseOver=function(t){var e=t.x0,r=t.y0,n=t.x1,i=t.y1,a=n-e,s=i-r,l=((e-=a)+n)/2,c=((r-=s)+i)/2;return{x0:l-(a*=o),y0:c-(s*=o),x1:l+a,y1:c+s}}},{\"../../../plots/cartesian/helpers\":839,\"./constants\":726,\"parse-svg-path\":505}],730:[function(t,e,r){\"use strict\";var n=t(\"../../dragelement/helpers\"),i=n.drawMode,a=n.openMode,o=t(\"./constants\"),s=o.i000,l=o.i090,c=o.i180,u=o.i270,f=o.cos45,h=o.sin45,p=t(\"../../../plots/cartesian/helpers\"),d=p.p2r,g=p.r2p,m=t(\"../../../plots/cartesian/handle_outline\").clearSelect,v=t(\"./helpers\"),y=v.readPaths,x=v.writePaths,b=v.ellipseOver;e.exports=function(t,e){if(t.length){var r=t[0][0];if(r){var n=r.getAttribute(\"d\"),o=e.gd,p=o._fullLayout.newshape,v=e.plotinfo,_=v.xaxis,w=v.yaxis,T=!!v.domain||!v.xaxis,k=!!v.domain||!v.yaxis,M=e.isActiveShape,A=e.dragmode,S=(o.layout||{}).shapes||[];if(!i(A)&&void 0!==M){var E=o._fullLayout._activeShapeIndex;if(E<S.length)switch(o._fullLayout.shapes[E].type){case\"rect\":A=\"drawrect\";break;case\"circle\":A=\"drawcircle\";break;case\"line\":A=\"drawline\";break;case\"path\":var C=S[E].path||\"\";A=\"Z\"===C[C.length-1]?\"drawclosedpath\":\"drawopenpath\"}}var L,I=a(A),P=y(n,o,v,M),z={editable:!0,xref:T?\"paper\":_._id,yref:k?\"paper\":w._id,layer:p.layer,opacity:p.opacity,line:{color:p.line.color,width:p.line.width,dash:p.line.dash}};if(I||(z.fillcolor=p.fillcolor,z.fillrule=p.fillrule),1===P.length&&(L=P[0]),L&&\"drawrect\"===A)z.type=\"rect\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[2][1],z.y1=L[2][2];else if(L&&\"drawline\"===A)z.type=\"line\",z.x0=L[0][1],z.y0=L[0][2],z.x1=L[1][1],z.y1=L[1][2];else if(L&&\"drawcircle\"===A){z.type=\"circle\";var O=L[s][1],D=L[l][1],R=L[c][1],F=L[u][1],B=L[s][2],N=L[l][2],j=L[c][2],U=L[u][2],V=v.xaxis&&(\"date\"===v.xaxis.type||\"log\"===v.xaxis.type),q=v.yaxis&&(\"date\"===v.yaxis.type||\"log\"===v.yaxis.type);V&&(O=g(v.xaxis,O),D=g(v.xaxis,D),R=g(v.xaxis,R),F=g(v.xaxis,F)),q&&(B=g(v.yaxis,B),N=g(v.yaxis,N),j=g(v.yaxis,j),U=g(v.yaxis,U));var H=(D+F)/2,G=(B+j)/2,Y=b({x0:H,y0:G,x1:H+(F-D+R-O)/2*f,y1:G+(U-N+j-B)/2*h});V&&(Y.x0=d(v.xaxis,Y.x0),Y.x1=d(v.xaxis,Y.x1)),q&&(Y.y0=d(v.yaxis,Y.y0),Y.y1=d(v.yaxis,Y.y1)),z.x0=Y.x0,z.y0=Y.y0,z.x1=Y.x1,z.y1=Y.y1}else z.type=\"path\",_&&w&&function(t,e,r){var n=\"date\"===e.type,i=\"date\"===r.type;if(!n&&!i)return t;for(var a=0;a<t.length;a++)for(var o=0;o<t[a].length;o++)for(var s=0;s+2<t[a][o].length;s+=2)n&&(t[a][o][s+1]=t[a][o][s+1].replace(\" \",\"_\")),i&&(t[a][o][s+2]=t[a][o][s+2].replace(\" \",\"_\"))}(P,_,w),z.path=x(P),L=null;m(o);for(var W=e.editHelpers,X=(W||{}).modifyItem,Z=[],J=0;J<S.length;J++){var K=o._fullLayout.shapes[J];if(Z[J]=K._input,void 0!==M&&J===o._fullLayout._activeShapeIndex){var Q=z;switch(K.type){case\"line\":case\"rect\":case\"circle\":X(\"x0\",Q.x0),X(\"x1\",Q.x1),X(\"y0\",Q.y0),X(\"y1\",Q.y1);break;case\"path\":X(\"path\",Q.path)}}}return void 0===M?(Z.push(z),Z):W?W.getUpdateObj():{}}}}},{\"../../../plots/cartesian/handle_outline\":838,\"../../../plots/cartesian/helpers\":839,\"../../dragelement/helpers\":661,\"./constants\":726,\"./helpers\":729}],731:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib\");r.rangeToShapePosition=function(t){return\"log\"===t.type?t.r2d:function(t){return t}},r.shapePositionToRange=function(t){return\"log\"===t.type?t.d2r:function(t){return t}},r.decodeDate=function(t){return function(e){return e.replace&&(e=e.replace(\"_\",\" \")),t(e)}},r.encodeDate=function(t){return function(e){return t(e).replace(\" \",\"_\")}},r.extractPathCoords=function(t,e){var r=[];return t.match(n.segmentRE).forEach((function(t){var a=e[t.charAt(0)].drawn;if(void 0!==a){var o=t.substr(1).match(n.paramRE);!o||o.length<a||r.push(i.cleanNumber(o[a]))}})),r},r.getDataToPixel=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){return e._length*(n?1-t:t)+e._offset};else{var s=r.shapePositionToRange(e);a=function(t){return e._offset+e.r2p(s(t,!0))},\"date\"===e.type&&(a=r.decodeDate(a))}else a=n?function(t){return o.t+o.h*(1-t)}:function(t){return o.l+o.w*t};return a},r.getPixelToData=function(t,e,n,i){var a,o=t._fullLayout._size;if(e)if(\"domain\"===i)a=function(t){var r=(t-e._offset)/e._length;return n?1-r:r};else{var s=r.rangeToShapePosition(e);a=function(t){return s(e.p2r(t-e._offset))}}else a=n?function(t){return 1-(t-o.t)/o.h}:function(t){return(t-o.l)/o.w};return a},r.roundPositionForSharpStrokeRendering=function(t,e){var r=1===Math.round(e%2),n=Math.round(t);return r?n+.5:n},r.makeOptionsAndPlotinfo=function(t,e){var r=t._fullLayout.shapes[e]||{},n=t._fullLayout._plots[r.xref+r.yref];return!!n?n._hadPlotinfo=!0:(n={},r.xref&&\"paper\"!==r.xref&&(n.xaxis=t._fullLayout[r.xref+\"axis\"]),r.yref&&\"paper\"!==r.yref&&(n.yaxis=t._fullLayout[r.yref+\"axis\"])),n.xsizemode=r.xsizemode,n.ysizemode=r.ysizemode,n.xanchor=r.xanchor,n.yanchor=r.yanchor,{options:r,plotinfo:n}}},{\"../../lib\":778,\"./constants\":722}],732:[function(t,e,r){\"use strict\";var n=t(\"./draw\");e.exports={moduleType:\"component\",name:\"shapes\",layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),supplyDrawNewShapeDefaults:t(\"./draw_newshape/defaults\"),includeBasePlot:t(\"../../plots/cartesian/include_components\")(\"shapes\"),calcAutorange:t(\"./calc_autorange\"),draw:n.draw,drawOne:n.drawOne}},{\"../../plots/cartesian/include_components\":840,\"./attributes\":720,\"./calc_autorange\":721,\"./defaults\":723,\"./draw\":724,\"./draw_newshape/defaults\":727}],733:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/pad_attributes\"),a=t(\"../../lib/extend\").extendDeepAll,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/animation_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"./constants\"),u=l(\"step\",{visible:{valType:\"boolean\",dflt:!0},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\"},value:{valType:\"string\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"slider\",{visible:{valType:\"boolean\",dflt:!0},active:{valType:\"number\",min:0,dflt:0},steps:u,lenmode:{valType:\"enumerated\",values:[\"fraction\",\"pixels\"],dflt:\"fraction\"},len:{valType:\"number\",min:0,dflt:1},x:{valType:\"number\",min:-2,max:3,dflt:0},pad:a(i({editType:\"arraydraw\"}),{},{t:{dflt:20}}),xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"left\"},y:{valType:\"number\",min:-2,max:3,dflt:0},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},transition:{duration:{valType:\"number\",min:0,dflt:150},easing:{valType:\"enumerated\",values:s.transition.easing.values,dflt:\"cubic-in-out\"}},currentvalue:{visible:{valType:\"boolean\",dflt:!0},xanchor:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],dflt:\"left\"},offset:{valType:\"number\",dflt:10},prefix:{valType:\"string\"},suffix:{valType:\"string\"},font:n({})},font:n({}),activebgcolor:{valType:\"color\",dflt:c.gripBgActiveColor},bgcolor:{valType:\"color\",dflt:c.railBgColor},bordercolor:{valType:\"color\",dflt:c.railBorderColor},borderwidth:{valType:\"number\",min:0,dflt:c.railBorderWidth},ticklen:{valType:\"number\",min:0,dflt:c.tickLength},tickcolor:{valType:\"color\",dflt:c.tickColor},tickwidth:{valType:\"number\",min:0,dflt:1},minorticklen:{valType:\"number\",min:0,dflt:c.minorTickLength}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/animation_attributes\":822,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"./constants\":734}],734:[function(t,e,r){\"use strict\";e.exports={name:\"sliders\",containerClassName:\"slider-container\",groupClassName:\"slider-group\",inputAreaClass:\"slider-input-area\",railRectClass:\"slider-rail-rect\",railTouchRectClass:\"slider-rail-touch-rect\",gripRectClass:\"slider-grip-rect\",tickRectClass:\"slider-tick-rect\",inputProxyClass:\"slider-input-proxy\",labelsClass:\"slider-labels\",labelGroupClass:\"slider-label-group\",labelClass:\"slider-label\",currentValueClass:\"slider-current-value\",railHeight:5,menuIndexAttrName:\"slider-active-index\",autoMarginIdRoot:\"slider-\",minWidth:30,minHeight:30,textPadX:40,arrowOffsetX:4,railRadius:2,railWidth:5,railBorder:4,railBorderWidth:1,railBorderColor:\"#bec8d9\",railBgColor:\"#f8fafc\",railInset:8,stepInset:10,gripRadius:10,gripWidth:20,gripHeight:20,gripBorder:20,gripBorderWidth:1,gripBorderColor:\"#bec8d9\",gripBgColor:\"#f6f8fa\",gripBgActiveColor:\"#dbdde0\",labelPadding:8,labelOffset:0,tickWidth:1,tickColor:\"#333\",tickOffset:25,tickLength:7,minorTickOffset:25,minorTickColor:\"#333\",minorTickLength:4,currentValuePadding:8,currentValueInset:0}},{}],735:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.steps;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}for(var s=i(t,e,{name:\"steps\",handleItemDefaults:c}),l=0,u=0;u<s.length;u++)s[u].visible&&l++;if(l<2?e.visible=!1:o(\"visible\")){e._stepCount=l;var f=e._visibleSteps=n.filterVisible(s);(s[o(\"active\")]||{}).visible||(e.active=f[0]._index),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"len\"),o(\"lenmode\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"currentvalue.visible\")&&(o(\"currentvalue.xanchor\"),o(\"currentvalue.prefix\"),o(\"currentvalue.suffix\"),o(\"currentvalue.offset\"),n.coerceFont(o,\"currentvalue.font\",e.font)),o(\"transition.duration\"),o(\"transition.easing\"),o(\"bgcolor\"),o(\"activebgcolor\"),o(\"bordercolor\"),o(\"borderwidth\"),o(\"ticklen\"),o(\"tickwidth\"),o(\"tickcolor\"),o(\"minorticklen\")}}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}if(\"skip\"===t.method||Array.isArray(t.args)?r(\"visible\"):e.visible=!1){r(\"method\"),r(\"args\");var i=r(\"label\",\"step-\"+e._index);r(\"value\",i),r(\"execute\")}}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":733,\"./constants\":734}],736:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../plot_api/plot_template\").arrayEditor,f=t(\"./constants\"),h=t(\"../../constants/alignment\"),p=h.LINE_SPACING,d=h.FROM_TL,g=h.FROM_BR;function m(t){return f.autoMarginIdRoot+t._index}function v(t){return t._index}function y(t,e){var r=o.tester.selectAll(\"g.\"+f.labelGroupClass).data(e._visibleSteps);r.enter().append(\"g\").classed(f.labelGroupClass,!0);var a=0,l=0;r.each((function(t){var r=_(n.select(this),{step:t},e).node();if(r){var i=o.bBox(r);l=Math.max(l,i.height),a=Math.max(a,i.width)}})),r.remove();var u=e._dims={};u.inputAreaWidth=Math.max(f.railWidth,f.gripHeight);var h=t._fullLayout._size;u.lx=h.l+h.w*e.x,u.ly=h.t+h.h*(1-e.y),\"fraction\"===e.lenmode?u.outerLength=Math.round(h.w*e.len):u.outerLength=e.len,u.inputAreaStart=0,u.inputAreaLength=Math.round(u.outerLength-e.pad.l-e.pad.r);var p=(u.inputAreaLength-2*f.stepInset)/(e._stepCount-1),v=a+f.labelPadding;if(u.labelStride=Math.max(1,Math.ceil(v/p)),u.labelHeight=l,u.currentValueMaxWidth=0,u.currentValueHeight=0,u.currentValueTotalHeight=0,u.currentValueMaxLines=1,e.currentvalue.visible){var y=o.tester.append(\"g\");r.each((function(t){var r=x(y,e,t.label),n=r.node()&&o.bBox(r.node())||{width:0,height:0},i=c.lineCount(r);u.currentValueMaxWidth=Math.max(u.currentValueMaxWidth,Math.ceil(n.width)),u.currentValueHeight=Math.max(u.currentValueHeight,Math.ceil(n.height)),u.currentValueMaxLines=Math.max(u.currentValueMaxLines,i)})),u.currentValueTotalHeight=u.currentValueHeight+e.currentvalue.offset,y.remove()}u.height=u.currentValueTotalHeight+f.tickOffset+e.ticklen+f.labelOffset+u.labelHeight+e.pad.t+e.pad.b;var b=\"left\";s.isRightAnchor(e)&&(u.lx-=u.outerLength,b=\"right\"),s.isCenterAnchor(e)&&(u.lx-=u.outerLength/2,b=\"center\");var w=\"top\";s.isBottomAnchor(e)&&(u.ly-=u.height,w=\"bottom\"),s.isMiddleAnchor(e)&&(u.ly-=u.height/2,w=\"middle\"),u.outerLength=Math.ceil(u.outerLength),u.height=Math.ceil(u.height),u.lx=Math.round(u.lx),u.ly=Math.round(u.ly);var T={y:e.y,b:u.height*g[w],t:u.height*d[w]};\"fraction\"===e.lenmode?(T.l=0,T.xl=e.x-e.len*d[b],T.r=0,T.xr=e.x+e.len*g[b]):(T.x=e.x,T.l=u.outerLength*d[b],T.r=u.outerLength*g[b]),i.autoMargin(t,m(e),T)}function x(t,e,r){if(e.currentvalue.visible){var n,i,a=e._dims;switch(e.currentvalue.xanchor){case\"right\":n=a.inputAreaLength-f.currentValueInset-a.currentValueMaxWidth,i=\"left\";break;case\"center\":n=.5*a.inputAreaLength,i=\"middle\";break;default:n=f.currentValueInset,i=\"left\"}var l=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":i,\"data-notex\":1})})),u=e.currentvalue.prefix?e.currentvalue.prefix:\"\";if(\"string\"==typeof r)u+=r;else{var h=e.steps[e.active].label,d=e._gd._fullLayout._meta;d&&(h=s.templateString(h,d)),u+=h}e.currentvalue.suffix&&(u+=e.currentvalue.suffix),l.call(o.font,e.currentvalue.font).text(u).call(c.convertToTspans,e._gd);var g=c.lineCount(l),m=(a.currentValueMaxLines+1-g)*e.currentvalue.font.size*p;return c.positionText(l,n,m),l}}function b(t,e,r){s.ensureSingle(t,\"rect\",f.gripRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")})).attr({width:f.gripWidth,height:f.gripHeight,rx:f.gripRadius,ry:f.gripRadius}).call(a.stroke,r.bordercolor).call(a.fill,r.bgcolor).style(\"stroke-width\",r.borderwidth+\"px\")}function _(t,e,r){var n=s.ensureSingle(t,\"text\",f.labelClass,(function(t){t.attr({\"text-anchor\":\"middle\",\"data-notex\":1})})),i=e.step.label,a=r._gd._fullLayout._meta;return a&&(i=s.templateString(i,a)),n.call(o.font,r.font).text(i).call(c.convertToTspans,r._gd),n}function w(t,e){var r=s.ensureSingle(t,\"g\",f.labelsClass),i=e._dims,a=r.selectAll(\"g.\"+f.labelGroupClass).data(i.labelSteps);a.enter().append(\"g\").classed(f.labelGroupClass,!0),a.exit().remove(),a.each((function(t){var r=n.select(this);r.call(_,t,e),o.setTranslate(r,E(e,t.fraction),f.tickOffset+e.ticklen+e.font.size*p+f.labelOffset+i.currentValueTotalHeight)}))}function T(t,e,r,n,i){var a=Math.round(n*(r._stepCount-1)),o=r._visibleSteps[a]._index;o!==r.active&&k(t,e,r,o,!0,i)}function k(t,e,r,n,a,o){var s=r.active;r.active=n,u(t.layout,f.name,r).applyUpdate(\"active\",n);var l=r.steps[r.active];e.call(S,r,o),e.call(x,r),t.emit(\"plotly_sliderchange\",{slider:r,step:r.steps[r.active],interaction:a,previousActive:s}),l&&l.method&&a&&(e._nextMethod?(e._nextMethod.step=l,e._nextMethod.doCallback=a,e._nextMethod.doTransition=o):(e._nextMethod={step:l,doCallback:a,doTransition:o},e._nextMethodRaf=window.requestAnimationFrame((function(){var r=e._nextMethod.step;r.method&&(r.execute&&i.executeAPICommand(t,r.method,r.args),e._nextMethod=null,e._nextMethodRaf=null)}))))}function M(t,e,r){var i=r.node(),o=n.select(e);function s(){return r.data()[0]}t.on(\"mousedown\",(function(){var t=s();e.emit(\"plotly_sliderstart\",{slider:t});var l=r.select(\".\"+f.gripRectClass);n.event.stopPropagation(),n.event.preventDefault(),l.call(a.fill,t.activebgcolor);var c=C(t,n.mouse(i)[0]);T(e,r,t,c,!0),t._dragging=!0,o.on(\"mousemove\",(function(){var t=s(),a=C(t,n.mouse(i)[0]);T(e,r,t,a,!1)})),o.on(\"mouseup\",(function(){var t=s();t._dragging=!1,l.call(a.fill,t.bgcolor),o.on(\"mouseup\",null),o.on(\"mousemove\",null),e.emit(\"plotly_sliderend\",{slider:t,step:t.steps[t.active]})}))}))}function A(t,e){var r=t.selectAll(\"rect.\"+f.tickRectClass).data(e._visibleSteps),i=e._dims;r.enter().append(\"rect\").classed(f.tickRectClass,!0),r.exit().remove(),r.attr({width:e.tickwidth+\"px\",\"shape-rendering\":\"crispEdges\"}),r.each((function(t,r){var s=r%i.labelStride==0,l=n.select(this);l.attr({height:s?e.ticklen:e.minorticklen}).call(a.fill,e.tickcolor),o.setTranslate(l,E(e,r/(e._stepCount-1))-.5*e.tickwidth,(s?f.tickOffset:f.minorTickOffset)+i.currentValueTotalHeight)}))}function S(t,e,r){for(var n=t.select(\"rect.\"+f.gripRectClass),i=0,a=0;a<e._stepCount;a++)if(e._visibleSteps[a]._index===e.active){i=a;break}var o=E(e,i/(e._stepCount-1));if(!e._invokingCommand){var s=n;r&&e.transition.duration>0&&(s=s.transition().duration(e.transition.duration).ease(e.transition.easing)),s.attr(\"transform\",l(o-.5*f.gripWidth,e._dims.currentValueTotalHeight))}}function E(t,e){var r=t._dims;return r.inputAreaStart+f.stepInset+(r.inputAreaLength-2*f.stepInset)*Math.min(1,Math.max(0,e))}function C(t,e){var r=t._dims;return Math.min(1,Math.max(0,(e-f.stepInset-r.inputAreaStart)/(r.inputAreaLength-2*f.stepInset-2*r.inputAreaStart)))}function L(t,e,r){var n=r._dims,i=s.ensureSingle(t,\"rect\",f.railTouchRectClass,(function(n){n.call(M,e,t,r).style(\"pointer-events\",\"all\")}));i.attr({width:n.inputAreaLength,height:Math.max(n.inputAreaWidth,f.tickOffset+r.ticklen+n.labelHeight)}).call(a.fill,r.bgcolor).attr(\"opacity\",0),o.setTranslate(i,0,n.currentValueTotalHeight)}function I(t,e){var r=e._dims,n=r.inputAreaLength-2*f.railInset,i=s.ensureSingle(t,\"rect\",f.railRectClass);i.attr({width:n,height:f.railWidth,rx:f.railRadius,ry:f.railRadius,\"shape-rendering\":\"crispEdges\"}).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\"),o.setTranslate(i,f.railInset,.5*(r.inputAreaWidth-f.railWidth)+r.currentValueTotalHeight)}e.exports=function(t){var e=t._fullLayout,r=function(t,e){for(var r=t[f.name],n=[],i=0;i<r.length;i++){var a=r[i];a.visible&&(a._gd=e,n.push(a))}return n}(e,t),a=e._infolayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);function s(e){e._commandObserver&&(e._commandObserver.remove(),delete e._commandObserver),i.autoMargin(t,m(e))}if(a.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"ew-resize\"),a.exit().each((function(){n.select(this).selectAll(\"g.\"+f.groupClassName).each(s)})).remove(),0!==r.length){var l=a.selectAll(\"g.\"+f.groupClassName).data(r,v);l.enter().append(\"g\").classed(f.groupClassName,!0),l.exit().each(s).remove();for(var c=0;c<r.length;c++){var u=r[c];y(t,u)}l.each((function(e){var r=n.select(this);!function(t){var e=t._dims;e.labelSteps=[];for(var r=t._stepCount,n=0;n<r;n+=e.labelStride)e.labelSteps.push({fraction:n/(r-1),step:t._visibleSteps[n]})}(e),i.manageCommandObserver(t,e,e._visibleSteps,(function(e){var n=r.data()[0];n.active!==e.index&&(n._dragging||k(t,r,n,e.index,!1,!0))})),function(t,e,r){(r.steps[r.active]||{}).visible||(r.active=r._visibleSteps[0]._index);e.call(x,r).call(I,r).call(w,r).call(A,r).call(L,t,r).call(b,t,r);var n=r._dims;o.setTranslate(e,n.lx+r.pad.l,n.ly+r.pad.t),e.call(S,r,!1),e.call(x,r)}(t,n.select(this),e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":734,d3:169}],737:[function(t,e,r){\"use strict\";var n=t(\"./constants\");e.exports={moduleType:\"component\",name:n.name,layoutAttributes:t(\"./attributes\"),supplyLayoutDefaults:t(\"./defaults\"),draw:t(\"./draw\")}},{\"./attributes\":733,\"./constants\":734,\"./defaults\":735,\"./draw\":736}],738:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../drawing\"),u=t(\"../color\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../constants/interactions\"),p=t(\"../../constants/alignment\").OPPOSITE_SIDE,d=/ [XY][0-9]* /;e.exports={draw:function(t,e,r){var g,m=r.propContainer,v=r.propName,y=r.placeholder,x=r.traceIndex,b=r.avoid||{},_=r.attributes,w=r.transform,T=r.containerGroup,k=t._fullLayout,M=1,A=!1,S=m.title,E=(S&&S.text?S.text:\"\").trim(),C=S&&S.font?S.font:{},L=C.family,I=C.size,P=C.color;\"title.text\"===v?g=\"titleText\":-1!==v.indexOf(\"axis\")?g=\"axisTitleText\":v.indexOf(!0)&&(g=\"colorbarTitleText\");var z=t._context.edits[g];\"\"===E?M=0:E.replace(d,\" % \")===y.replace(d,\" % \")&&(M=.2,A=!0,z||(E=\"\")),r._meta?E=s.templateString(E,r._meta):k._meta&&(E=s.templateString(E,k._meta));var O=E||z;T||(T=s.ensureSingle(k._infolayer,\"g\",\"g-\"+e));var D=T.selectAll(\"text\").data(O?[0]:[]);if(D.enter().append(\"text\"),D.text(E).attr(\"class\",e),D.exit().remove(),!O)return T;function R(t){s.syncOrAsync([F,B],t)}function F(e){var r;return w?(r=\"\",w.rotate&&(r+=\"rotate(\"+[w.rotate,_.x,_.y]+\")\"),w.offset&&(r+=l(0,w.offset))):r=null,e.attr(\"transform\",r),e.style({\"font-family\":L,\"font-size\":n.round(I,2)+\"px\",fill:u.rgb(P),opacity:M*u.opacity(P),\"font-weight\":a.fontWeight}).attr(_).call(f.convertToTspans,t),a.previousPromises(t)}function B(t){var e=n.select(t.node().parentNode);if(b&&b.selection&&b.side&&E){e.attr(\"transform\",null);var r=p[b.side],a=\"left\"===b.side||\"top\"===b.side?-1:1,o=i(b.pad)?b.pad:2,u=c.bBox(e.node()),f={left:0,top:0,right:k.width,bottom:k.height},h=b.maxShift||a*(f[b.side]-u[b.side]),d=0;if(h<0)d=h;else{var g=b.offsetLeft||0,m=b.offsetTop||0;u.left-=g,u.right-=g,u.top-=m,u.bottom-=m,b.selection.each((function(){var t=c.bBox(this);s.bBoxIntersect(u,t,o)&&(d=Math.max(d,a*(t[b.side]-u[r])+o))})),d=Math.min(h,d)}if(d>0||h<0){var v={left:[-d,0],right:[d,0],top:[0,-d],bottom:[0,d]}[b.side];e.attr(\"transform\",l(v[0],v[1]))}}}return D.call(R),z&&(E?D.on(\".opacity\",null):(M=0,A=!0,D.text(y).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(h.SHOW_PLACEHOLDER).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(h.HIDE_PLACEHOLDER).style(\"opacity\",0)}))),D.call(f.makeEditable,{gd:t}).on(\"edit\",(function(e){void 0!==x?o.call(\"_guiRestyle\",t,v,e,x):o.call(\"_guiRelayout\",t,v,e)})).on(\"cancel\",(function(){this.text(this.attr(\"data-unformatted\")).call(R)})).on(\"input\",(function(t){this.text(t||\" \").call(f.positionText,_.x,_.y)}))),D.classed(\"js-placeholder\",A),T}}},{\"../../constants/alignment\":745,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"../color\":643,\"../drawing\":665,d3:169,\"fast-isnumeric\":241}],739:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../color/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../plots/pad_attributes\"),l=t(\"../../plot_api/plot_template\").templatedArray,c=l(\"button\",{visible:{valType:\"boolean\"},method:{valType:\"enumerated\",values:[\"restyle\",\"relayout\",\"animate\",\"update\",\"skip\"],dflt:\"restyle\"},args:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},args2:{valType:\"info_array\",freeLength:!0,items:[{valType:\"any\"},{valType:\"any\"},{valType:\"any\"}]},label:{valType:\"string\",dflt:\"\"},execute:{valType:\"boolean\",dflt:!0}});e.exports=o(l(\"updatemenu\",{_arrayAttrRegexps:[/^updatemenus\\[(0|[1-9][0-9]+)\\]\\.buttons/],visible:{valType:\"boolean\"},type:{valType:\"enumerated\",values:[\"dropdown\",\"buttons\"],dflt:\"dropdown\"},direction:{valType:\"enumerated\",values:[\"left\",\"right\",\"up\",\"down\"],dflt:\"down\"},active:{valType:\"integer\",min:-1,dflt:0},showactive:{valType:\"boolean\",dflt:!0},buttons:c,x:{valType:\"number\",min:-2,max:3,dflt:-.05},xanchor:{valType:\"enumerated\",values:[\"auto\",\"left\",\"center\",\"right\"],dflt:\"right\"},y:{valType:\"number\",min:-2,max:3,dflt:1},yanchor:{valType:\"enumerated\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],dflt:\"top\"},pad:a(s({editType:\"arraydraw\"}),{}),font:n({}),bgcolor:{valType:\"color\"},bordercolor:{valType:\"color\",dflt:i.borderLine},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"arraydraw\"}}),\"arraydraw\",\"from-root\")},{\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/font_attributes\":856,\"../../plots/pad_attributes\":890,\"../color/attributes\":642}],740:[function(t,e,r){\"use strict\";e.exports={name:\"updatemenus\",containerClassName:\"updatemenu-container\",headerGroupClassName:\"updatemenu-header-group\",headerClassName:\"updatemenu-header\",headerArrowClassName:\"updatemenu-header-arrow\",dropdownButtonGroupClassName:\"updatemenu-dropdown-button-group\",dropdownButtonClassName:\"updatemenu-dropdown-button\",buttonClassName:\"updatemenu-button\",itemRectClassName:\"updatemenu-item-rect\",itemTextClassName:\"updatemenu-item-text\",menuIndexAttrName:\"updatemenu-active-index\",autoMarginIdRoot:\"updatemenu-\",blankHeaderOpts:{label:\"  \"},minWidth:30,minHeight:30,textPadX:24,arrowPadX:16,rx:2,ry:2,textOffsetX:12,textOffsetY:3,arrowOffsetX:4,gapButtonHeader:5,gapButton:2,activeColor:\"#F4FAFF\",hoverColor:\"#F4FAFF\",arrowSymbol:{left:\"\\u25c4\",right:\"\\u25ba\",up:\"\\u25b2\",down:\"\\u25bc\"}}},{}],741:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"./constants\").name,s=a.buttons;function l(t,e,r){function o(r,i){return n.coerce(t,e,a,r,i)}o(\"visible\",i(t,e,{name:\"buttons\",handleItemDefaults:c}).length>0)&&(o(\"active\"),o(\"direction\"),o(\"type\"),o(\"showactive\"),o(\"x\"),o(\"y\"),n.noneOrAll(t,e,[\"x\",\"y\"]),o(\"xanchor\"),o(\"yanchor\"),o(\"pad.t\"),o(\"pad.r\"),o(\"pad.b\"),o(\"pad.l\"),n.coerceFont(o,\"font\",r.font),o(\"bgcolor\",r.paper_bgcolor),o(\"bordercolor\"),o(\"borderwidth\"))}function c(t,e){function r(r,i){return n.coerce(t,e,s,r,i)}r(\"visible\",\"skip\"===t.method||Array.isArray(t.args))&&(r(\"method\"),r(\"args\"),r(\"args2\"),r(\"label\"),r(\"execute\"))}e.exports=function(t,e){i(t,e,{name:o,handleItemDefaults:l})}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"./attributes\":739,\"./constants\":740}],742:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../color\"),o=t(\"../drawing\"),s=t(\"../../lib\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../plot_api/plot_template\").arrayEditor,u=t(\"../../constants/alignment\").LINE_SPACING,f=t(\"./constants\"),h=t(\"./scrollbox\");function p(t){return t._index}function d(t,e){return+t.attr(f.menuIndexAttrName)===e._index}function g(t,e,r,n,i,a,o,s){e.active=o,c(t.layout,f.name,e).applyUpdate(\"active\",o),\"buttons\"===e.type?v(t,n,null,null,e):\"dropdown\"===e.type&&(i.attr(f.menuIndexAttrName,\"-1\"),m(t,n,i,a,e),s||v(t,n,i,a,e))}function m(t,e,r,n,i){var a=s.ensureSingle(e,\"g\",f.headerClassName,(function(t){t.style(\"pointer-events\",\"all\")})),l=i._dims,c=i.active,u=i.buttons[c]||f.blankHeaderOpts,h={y:i.pad.t,yPad:0,x:i.pad.l,xPad:0,index:0},p={width:l.headerWidth,height:l.headerHeight};a.call(y,i,u,t).call(A,i,h,p),s.ensureSingle(e,\"text\",f.headerArrowClassName,(function(t){t.attr(\"text-anchor\",\"end\").call(o.font,i.font).text(f.arrowSymbol[i.direction])})).attr({x:l.headerWidth-f.arrowOffsetX+i.pad.l,y:l.headerHeight/2+f.textOffsetY+i.pad.t}),a.on(\"click\",(function(){r.call(S,String(d(r,i)?-1:i._index)),v(t,e,r,n,i)})),a.on(\"mouseover\",(function(){a.call(w)})),a.on(\"mouseout\",(function(){a.call(T,i)})),o.setTranslate(e,l.lx,l.ly)}function v(t,e,r,a,o){r||(r=e).attr(\"pointer-events\",\"all\");var l=function(t){return-1==+t.attr(f.menuIndexAttrName)}(r)&&\"buttons\"!==o.type?[]:o.buttons,c=\"dropdown\"===o.type?f.dropdownButtonClassName:f.buttonClassName,u=r.selectAll(\"g.\"+c).data(s.filterVisible(l)),h=u.enter().append(\"g\").classed(c,!0),p=u.exit();\"dropdown\"===o.type?(h.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\"),p.transition().attr(\"opacity\",\"0\").remove()):p.remove();var d=0,m=0,v=o._dims,x=-1!==[\"up\",\"down\"].indexOf(o.direction);\"dropdown\"===o.type&&(x?m=v.headerHeight+f.gapButtonHeader:d=v.headerWidth+f.gapButtonHeader),\"dropdown\"===o.type&&\"up\"===o.direction&&(m=-f.gapButtonHeader+f.gapButton-v.openHeight),\"dropdown\"===o.type&&\"left\"===o.direction&&(d=-f.gapButtonHeader+f.gapButton-v.openWidth);var b={x:v.lx+d+o.pad.l,y:v.ly+m+o.pad.t,yPad:f.gapButton,xPad:f.gapButton,index:0},k={l:b.x+o.borderwidth,t:b.y+o.borderwidth};u.each((function(s,l){var c=n.select(this);c.call(y,o,s,t).call(A,o,b),c.on(\"click\",(function(){n.event.defaultPrevented||(s.execute&&(s.args2&&o.active===l?(g(t,o,0,e,r,a,-1),i.executeAPICommand(t,s.method,s.args2)):(g(t,o,0,e,r,a,l),i.executeAPICommand(t,s.method,s.args))),t.emit(\"plotly_buttonclicked\",{menu:o,button:s,active:o.active}))})),c.on(\"mouseover\",(function(){c.call(w)})),c.on(\"mouseout\",(function(){c.call(T,o),u.call(_,o)}))})),u.call(_,o),x?(k.w=Math.max(v.openWidth,v.headerWidth),k.h=b.y-k.t):(k.w=b.x-k.l,k.h=Math.max(v.openHeight,v.headerHeight)),k.direction=o.direction,a&&(u.size()?function(t,e,r,n,i,a){var o,s,l,c=i.direction,u=\"up\"===c||\"down\"===c,h=i._dims,p=i.active;if(u)for(s=0,l=0;l<p;l++)s+=h.heights[l]+f.gapButton;else for(o=0,l=0;l<p;l++)o+=h.widths[l]+f.gapButton;n.enable(a,o,s),n.hbar&&n.hbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\");n.vbar&&n.vbar.attr(\"opacity\",\"0\").transition().attr(\"opacity\",\"1\")}(0,0,0,a,o,k):function(t){var e=!!t.hbar,r=!!t.vbar;e&&t.hbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){e=!1,r||t.disable()}));r&&t.vbar.transition().attr(\"opacity\",\"0\").each(\"end\",(function(){r=!1,e||t.disable()}))}(a))}function y(t,e,r,n){t.call(x,e).call(b,e,r,n)}function x(t,e){s.ensureSingle(t,\"rect\",f.itemRectClassName,(function(t){t.attr({rx:f.rx,ry:f.ry,\"shape-rendering\":\"crispEdges\"})})).call(a.stroke,e.bordercolor).call(a.fill,e.bgcolor).style(\"stroke-width\",e.borderwidth+\"px\")}function b(t,e,r,n){var i=s.ensureSingle(t,\"text\",f.itemTextClassName,(function(t){t.attr({\"text-anchor\":\"start\",\"data-notex\":1})})),a=r.label,c=n._fullLayout._meta;c&&(a=s.templateString(a,c)),i.call(o.font,e.font).text(a).call(l.convertToTspans,n)}function _(t,e){var r=e.active;t.each((function(t,i){var o=n.select(this);i===r&&e.showactive&&o.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.activeColor)}))}function w(t){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,f.hoverColor)}function T(t,e){t.select(\"rect.\"+f.itemRectClassName).call(a.fill,e.bgcolor)}function k(t,e){var r=e._dims={width1:0,height1:0,heights:[],widths:[],totalWidth:0,totalHeight:0,openWidth:0,openHeight:0,lx:0,ly:0},a=o.tester.selectAll(\"g.\"+f.dropdownButtonClassName).data(s.filterVisible(e.buttons));a.enter().append(\"g\").classed(f.dropdownButtonClassName,!0);var c=-1!==[\"up\",\"down\"].indexOf(e.direction);a.each((function(i,a){var s=n.select(this);s.call(y,e,i,t);var h=s.select(\".\"+f.itemTextClassName),p=h.node()&&o.bBox(h.node()).width,d=Math.max(p+f.textPadX,f.minWidth),g=e.font.size*u,m=l.lineCount(h),v=Math.max(g*m,f.minHeight)+f.textOffsetY;v=Math.ceil(v),d=Math.ceil(d),r.widths[a]=d,r.heights[a]=v,r.height1=Math.max(r.height1,v),r.width1=Math.max(r.width1,d),c?(r.totalWidth=Math.max(r.totalWidth,d),r.openWidth=r.totalWidth,r.totalHeight+=v+f.gapButton,r.openHeight+=v+f.gapButton):(r.totalWidth+=d+f.gapButton,r.openWidth+=d+f.gapButton,r.totalHeight=Math.max(r.totalHeight,v),r.openHeight=r.totalHeight)})),c?r.totalHeight-=f.gapButton:r.totalWidth-=f.gapButton,r.headerWidth=r.width1+f.arrowPadX,r.headerHeight=r.height1,\"dropdown\"===e.type&&(c?(r.width1+=f.arrowPadX,r.totalHeight=r.height1):r.totalWidth=r.width1,r.totalWidth+=f.arrowPadX),a.remove();var h=r.totalWidth+e.pad.l+e.pad.r,p=r.totalHeight+e.pad.t+e.pad.b,d=t._fullLayout._size;r.lx=d.l+d.w*e.x,r.ly=d.t+d.h*(1-e.y);var g=\"left\";s.isRightAnchor(e)&&(r.lx-=h,g=\"right\"),s.isCenterAnchor(e)&&(r.lx-=h/2,g=\"center\");var m=\"top\";s.isBottomAnchor(e)&&(r.ly-=p,m=\"bottom\"),s.isMiddleAnchor(e)&&(r.ly-=p/2,m=\"middle\"),r.totalWidth=Math.ceil(r.totalWidth),r.totalHeight=Math.ceil(r.totalHeight),r.lx=Math.round(r.lx),r.ly=Math.round(r.ly),i.autoMargin(t,M(e),{x:e.x,y:e.y,l:h*({right:1,center:.5}[g]||0),r:h*({left:1,center:.5}[g]||0),b:p*({top:1,middle:.5}[m]||0),t:p*({bottom:1,middle:.5}[m]||0)})}function M(t){return f.autoMarginIdRoot+t._index}function A(t,e,r,n){n=n||{};var i=t.select(\".\"+f.itemRectClassName),a=t.select(\".\"+f.itemTextClassName),s=e.borderwidth,c=r.index,h=e._dims;o.setTranslate(t,s+r.x,s+r.y);var p=-1!==[\"up\",\"down\"].indexOf(e.direction),d=n.height||(p?h.heights[c]:h.height1);i.attr({x:0,y:0,width:n.width||(p?h.width1:h.widths[c]),height:d});var g=e.font.size*u,m=(l.lineCount(a)-1)*g/2;l.positionText(a,f.textOffsetX,d/2-m+f.textOffsetY),p?r.y+=h.heights[c]+r.yPad:r.x+=h.widths[c]+r.xPad,r.index++}function S(t,e){t.attr(f.menuIndexAttrName,e||\"-1\").selectAll(\"g.\"+f.dropdownButtonClassName).remove()}e.exports=function(t){var e=t._fullLayout,r=s.filterVisible(e[f.name]);function a(e){i.autoMargin(t,M(e))}var o=e._menulayer.selectAll(\"g.\"+f.containerClassName).data(r.length>0?[0]:[]);if(o.enter().append(\"g\").classed(f.containerClassName,!0).style(\"cursor\",\"pointer\"),o.exit().each((function(){n.select(this).selectAll(\"g.\"+f.headerGroupClassName).each(a)})).remove(),0!==r.length){var l=o.selectAll(\"g.\"+f.headerGroupClassName).data(r,p);l.enter().append(\"g\").classed(f.headerGroupClassName,!0);for(var c=s.ensureSingle(o,\"g\",f.dropdownButtonGroupClassName,(function(t){t.style(\"pointer-events\",\"all\")})),u=0;u<r.length;u++){var y=r[u];k(t,y)}var x=\"updatemenus\"+e._uid,b=new h(t,c,x);l.enter().size()&&(c.node().parentNode.appendChild(c.node()),c.call(S)),l.exit().each((function(t){c.call(S),a(t)})).remove(),l.each((function(e){var r=n.select(this),a=\"dropdown\"===e.type?c:null;i.manageCommandObserver(t,e,e.buttons,(function(n){g(t,e,e.buttons[n.index],r,a,b,n.index,!0)})),\"dropdown\"===e.type?(m(t,r,c,b,e),d(c,e)&&v(t,r,c,b,e)):v(t,r,null,null,e)}))}}},{\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_template\":817,\"../../plots/plots\":891,\"../color\":643,\"../drawing\":665,\"./constants\":740,\"./scrollbox\":744,d3:169}],743:[function(t,e,r){arguments[4][737][0].apply(r,arguments)},{\"./attributes\":739,\"./constants\":740,\"./defaults\":741,\"./draw\":742,dup:737}],744:[function(t,e,r){\"use strict\";e.exports=s;var n=t(\"d3\"),i=t(\"../color\"),a=t(\"../drawing\"),o=t(\"../../lib\");function s(t,e,r){this.gd=t,this.container=e,this.id=r,this.position=null,this.translateX=null,this.translateY=null,this.hbar=null,this.vbar=null,this.bg=this.container.selectAll(\"rect.scrollbox-bg\").data([0]),this.bg.exit().on(\".drag\",null).on(\"wheel\",null).remove(),this.bg.enter().append(\"rect\").classed(\"scrollbox-bg\",!0).style(\"pointer-events\",\"all\").attr({opacity:0,x:0,y:0,width:0,height:0})}s.barWidth=2,s.barLength=20,s.barRadius=2,s.barPad=1,s.barColor=\"#808BA4\",s.prototype.enable=function(t,e,r){var o=this.gd._fullLayout,l=o.width,c=o.height;this.position=t;var u,f,h,p,d=this.position.l,g=this.position.w,m=this.position.t,v=this.position.h,y=this.position.direction,x=\"down\"===y,b=\"left\"===y,_=\"up\"===y,w=g,T=v;x||b||\"right\"===y||_||(this.position.direction=\"down\",x=!0),x||_?(f=(u=d)+w,x?(h=m,T=(p=Math.min(h+T,c))-h):T=(p=m+T)-(h=Math.max(p-T,0))):(p=(h=m)+T,b?w=(f=d+w)-(u=Math.max(f-w,0)):(u=d,w=(f=Math.min(u+w,l))-u)),this._box={l:u,t:h,w:w,h:T};var k=g>w,M=s.barLength+2*s.barPad,A=s.barWidth+2*s.barPad,S=d,E=m+v;E+A>c&&(E=c-A);var C=this.container.selectAll(\"rect.scrollbar-horizontal\").data(k?[0]:[]);C.exit().on(\".drag\",null).remove(),C.enter().append(\"rect\").classed(\"scrollbar-horizontal\",!0).call(i.fill,s.barColor),k?(this.hbar=C.attr({rx:s.barRadius,ry:s.barRadius,x:S,y:E,width:M,height:A}),this._hbarXMin=S+M/2,this._hbarTranslateMax=w-M):(delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax);var L=v>T,I=s.barWidth+2*s.barPad,P=s.barLength+2*s.barPad,z=d+g,O=m;z+I>l&&(z=l-I);var D=this.container.selectAll(\"rect.scrollbar-vertical\").data(L?[0]:[]);D.exit().on(\".drag\",null).remove(),D.enter().append(\"rect\").classed(\"scrollbar-vertical\",!0).call(i.fill,s.barColor),L?(this.vbar=D.attr({rx:s.barRadius,ry:s.barRadius,x:z,y:O,width:I,height:P}),this._vbarYMin=O+P/2,this._vbarTranslateMax=T-P):(delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax);var R=this.id,F=u-.5,B=L?f+I+.5:f+.5,N=h-.5,j=k?p+A+.5:p+.5,U=o._topdefs.selectAll(\"#\"+R).data(k||L?[0]:[]);if(U.exit().remove(),U.enter().append(\"clipPath\").attr(\"id\",R).append(\"rect\"),k||L?(this._clipRect=U.select(\"rect\").attr({x:Math.floor(F),y:Math.floor(N),width:Math.ceil(B)-Math.floor(F),height:Math.ceil(j)-Math.floor(N)}),this.container.call(a.setClipUrl,R,this.gd),this.bg.attr({x:d,y:m,width:g,height:v})):(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),k||L){var V=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault()})).on(\"drag\",this._onBoxDrag.bind(this));this.container.on(\"wheel\",null).on(\"wheel\",this._onBoxWheel.bind(this)).on(\".drag\",null).call(V);var q=n.behavior.drag().on(\"dragstart\",(function(){n.event.sourceEvent.preventDefault(),n.event.sourceEvent.stopPropagation()})).on(\"drag\",this._onBarDrag.bind(this));k&&this.hbar.on(\".drag\",null).call(q),L&&this.vbar.on(\".drag\",null).call(q)}this.setTranslate(e,r)},s.prototype.disable=function(){(this.hbar||this.vbar)&&(this.bg.attr({width:0,height:0}),this.container.on(\"wheel\",null).on(\".drag\",null).call(a.setClipUrl,null),delete this._clipRect),this.hbar&&(this.hbar.on(\".drag\",null),this.hbar.remove(),delete this.hbar,delete this._hbarXMin,delete this._hbarTranslateMax),this.vbar&&(this.vbar.on(\".drag\",null),this.vbar.remove(),delete this.vbar,delete this._vbarYMin,delete this._vbarTranslateMax)},s.prototype._onBoxDrag=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t-=n.event.dx),this.vbar&&(e-=n.event.dy),this.setTranslate(t,e)},s.prototype._onBoxWheel=function(){var t=this.translateX,e=this.translateY;this.hbar&&(t+=n.event.deltaY),this.vbar&&(e+=n.event.deltaY),this.setTranslate(t,e)},s.prototype._onBarDrag=function(){var t=this.translateX,e=this.translateY;if(this.hbar){var r=t+this._hbarXMin,i=r+this._hbarTranslateMax;t=(o.constrain(n.event.x,r,i)-r)/(i-r)*(this.position.w-this._box.w)}if(this.vbar){var a=e+this._vbarYMin,s=a+this._vbarTranslateMax;e=(o.constrain(n.event.y,a,s)-a)/(s-a)*(this.position.h-this._box.h)}this.setTranslate(t,e)},s.prototype.setTranslate=function(t,e){var r=this.position.w-this._box.w,n=this.position.h-this._box.h;if(t=o.constrain(t||0,0,r),e=o.constrain(e||0,0,n),this.translateX=t,this.translateY=e,this.container.call(a.setTranslate,this._box.l-this.position.l-t,this._box.t-this.position.t-e),this._clipRect&&this._clipRect.attr({x:Math.floor(this.position.l+t-.5),y:Math.floor(this.position.t+e-.5)}),this.hbar){var i=t/r;this.hbar.call(a.setTranslate,t+i*this._hbarTranslateMax,e)}if(this.vbar){var s=e/n;this.vbar.call(a.setTranslate,t,e+s*this._vbarTranslateMax)}}},{\"../../lib\":778,\"../color\":643,\"../drawing\":665,d3:169}],745:[function(t,e,r){\"use strict\";e.exports={FROM_BL:{left:0,center:.5,right:1,bottom:0,middle:.5,top:1},FROM_TL:{left:0,center:.5,right:1,bottom:1,middle:.5,top:0},FROM_BR:{left:1,center:.5,right:0,bottom:0,middle:.5,top:1},LINE_SPACING:1.3,CAP_SHIFT:.7,MID_SHIFT:.35,OPPOSITE_SIDE:{left:\"right\",right:\"left\",top:\"bottom\",bottom:\"top\"}}},{}],746:[function(t,e,r){\"use strict\";e.exports={axisRefDescription:function(t,e,r){return[\"If set to a\",t,\"axis id (e.g. *\"+t+\"* or\",\"*\"+t+\"2*), the `\"+t+\"` position refers to a\",t,\"coordinate. If set to *paper*, the `\"+t+\"`\",\"position refers to the distance from the\",e,\"of the plotting\",\"area in normalized coordinates where *0* (*1*) corresponds to the\",e,\"(\"+r+\"). If set to a\",t,\"axis ID followed by\",\"*domain* (separated by a space), the position behaves like for\",\"*paper*, but refers to the distance in fractions of the domain\",\"length from the\",e,\"of the domain of that axis: e.g.,\",\"*\"+t+\"2 domain* refers to the domain of the second\",t,\" axis and a\",t,\"position of 0.5 refers to the\",\"point between the\",e,\"and the\",r,\"of the domain of the\",\"second\",t,\"axis.\"].join(\" \")}}},{}],747:[function(t,e,r){\"use strict\";e.exports={INCREASING:{COLOR:\"#3D9970\",SYMBOL:\"\\u25b2\"},DECREASING:{COLOR:\"#FF4136\",SYMBOL:\"\\u25bc\"}}},{}],748:[function(t,e,r){\"use strict\";e.exports={FORMAT_LINK:\"https://github.com/d3/d3-3.x-api-reference/blob/master/Formatting.md#d3_format\",DATE_FORMAT_LINK:\"https://github.com/d3/d3-time-format#locale_format\"}},{}],749:[function(t,e,r){\"use strict\";e.exports={COMPARISON_OPS:[\"=\",\"!=\",\"<\",\">=\",\">\",\"<=\"],COMPARISON_OPS2:[\"=\",\"<\",\">=\",\">\",\"<=\"],INTERVAL_OPS:[\"[]\",\"()\",\"[)\",\"(]\",\"][\",\")(\",\"](\",\")[\"],SET_OPS:[\"{}\",\"}{\"],CONSTRAINT_REDUCTION:{\"=\":\"=\",\"<\":\"<\",\"<=\":\"<\",\">\":\">\",\">=\":\">\",\"[]\":\"[]\",\"()\":\"[]\",\"[)\":\"[]\",\"(]\":\"[]\",\"][\":\"][\",\")(\":\"][\",\"](\":\"][\",\")[\":\"][\"}}},{}],750:[function(t,e,r){\"use strict\";e.exports={solid:[[],0],dot:[[.5,1],200],dash:[[.5,1],50],longdash:[[.5,1],10],dashdot:[[.5,.625,.875,1],50],longdashdot:[[.5,.7,.8,1],10]}},{}],751:[function(t,e,r){\"use strict\";e.exports={circle:\"\\u25cf\",\"circle-open\":\"\\u25cb\",square:\"\\u25a0\",\"square-open\":\"\\u25a1\",diamond:\"\\u25c6\",\"diamond-open\":\"\\u25c7\",cross:\"+\",x:\"\\u274c\"}},{}],752:[function(t,e,r){\"use strict\";e.exports={SHOW_PLACEHOLDER:100,HIDE_PLACEHOLDER:1e3,DESELECTDIM:.2}},{}],753:[function(t,e,r){\"use strict\";e.exports={BADNUM:void 0,FP_SAFE:Number.MAX_VALUE/1e4,ONEMAXYEAR:316224e5,ONEAVGYEAR:315576e5,ONEMINYEAR:31536e6,ONEMAXQUARTER:79488e5,ONEAVGQUARTER:78894e5,ONEMINQUARTER:76896e5,ONEMAXMONTH:26784e5,ONEAVGMONTH:26298e5,ONEMINMONTH:24192e5,ONEWEEK:6048e5,ONEDAY:864e5,ONEHOUR:36e5,ONEMIN:6e4,ONESEC:1e3,EPOCHJD:2440587.5,ALMOST_EQUAL:.999999,LOG_CLIP:10,MINUS_SIGN:\"\\u2212\"}},{}],754:[function(t,e,r){\"use strict\";r.xmlns=\"http://www.w3.org/2000/xmlns/\",r.svg=\"http://www.w3.org/2000/svg\",r.xlink=\"http://www.w3.org/1999/xlink\",r.svgAttrs={xmlns:r.svg,\"xmlns:xlink\":r.xlink}},{}],755:[function(t,e,r){\"use strict\";r.version=t(\"./version\").version,t(\"es6-promise\").polyfill(),t(\"../build/plotcss\"),t(\"./fonts/mathjax_config\")();for(var n=t(\"./registry\"),i=r.register=n.register,a=t(\"./plot_api\"),o=Object.keys(a),s=0;s<o.length;s++){var l=o[s];\"_\"!==l.charAt(0)&&(r[l]=a[l]),i({moduleType:\"apiMethod\",name:l,fn:a[l]})}i(t(\"./traces/scatter\")),i([t(\"./components/legend\"),t(\"./components/fx\"),t(\"./components/annotations\"),t(\"./components/annotations3d\"),t(\"./components/shapes\"),t(\"./components/images\"),t(\"./components/updatemenus\"),t(\"./components/sliders\"),t(\"./components/rangeslider\"),t(\"./components/rangeselector\"),t(\"./components/grid\"),t(\"./components/errorbars\"),t(\"./components/colorscale\"),t(\"./components/colorbar\")]),i([t(\"./locale-en\"),t(\"./locale-en-us\")]),window.PlotlyLocales&&Array.isArray(window.PlotlyLocales)&&(i(window.PlotlyLocales),delete window.PlotlyLocales),r.Icons=t(\"./fonts/ploticon\"),r.Plots=t(\"./plots/plots\"),r.Fx=t(\"./components/fx\"),r.Snapshot=t(\"./snapshot\"),r.PlotSchema=t(\"./plot_api/plot_schema\"),r.Queue=t(\"./lib/queue\"),r.d3=t(\"d3\")},{\"../build/plotcss\":1,\"./components/annotations\":634,\"./components/annotations3d\":639,\"./components/colorbar\":649,\"./components/colorscale\":655,\"./components/errorbars\":671,\"./components/fx\":683,\"./components/grid\":687,\"./components/images\":692,\"./components/legend\":700,\"./components/rangeselector\":711,\"./components/rangeslider\":718,\"./components/shapes\":732,\"./components/sliders\":737,\"./components/updatemenus\":743,\"./fonts/mathjax_config\":756,\"./fonts/ploticon\":757,\"./lib/queue\":794,\"./locale-en\":808,\"./locale-en-us\":807,\"./plot_api\":812,\"./plot_api/plot_schema\":816,\"./plots/plots\":891,\"./registry\":911,\"./snapshot\":916,\"./traces/scatter\":1199,\"./version\":1370,d3:169,\"es6-promise\":224}],756:[function(t,e,r){\"use strict\";e.exports=function(){\"undefined\"!=typeof MathJax&&(\"local\"!==(window.PlotlyConfig||{}).MathJaxConfig&&(MathJax.Hub.Config({messageStyle:\"none\",skipStartupTypeset:!0,displayAlign:\"left\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]}}),MathJax.Hub.Configured()))}},{}],757:[function(t,e,r){\"use strict\";e.exports={undo:{width:857.1,height:1e3,path:\"m857 350q0-87-34-166t-91-137-137-92-166-34q-96 0-183 41t-147 114q-4 6-4 13t5 11l76 77q6 5 14 5 9-1 13-7 41-53 100-82t126-29q58 0 110 23t92 61 61 91 22 111-22 111-61 91-92 61-110 23q-55 0-105-20t-90-57l77-77q17-16 8-38-10-23-33-23h-250q-15 0-25 11t-11 25v250q0 24 22 33 22 10 39-8l72-72q60 57 137 88t159 31q87 0 166-34t137-92 91-137 34-166z\",transform:\"matrix(1 0 0 -1 0 850)\"},home:{width:928.6,height:1e3,path:\"m786 296v-267q0-15-11-26t-25-10h-214v214h-143v-214h-214q-15 0-25 10t-11 26v267q0 1 0 2t0 2l321 264 321-264q1-1 1-4z m124 39l-34-41q-5-5-12-6h-2q-7 0-12 3l-386 322-386-322q-7-4-13-4-7 2-12 7l-35 41q-4 5-3 13t6 12l401 334q18 15 42 15t43-15l136-114v109q0 8 5 13t13 5h107q8 0 13-5t5-13v-227l122-102q5-5 6-12t-4-13z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"camera-retro\":{width:1e3,height:1e3,path:\"m518 386q0 8-5 13t-13 5q-37 0-63-27t-26-63q0-8 5-13t13-5 12 5 5 13q0 23 16 38t38 16q8 0 13 5t5 13z m125-73q0-59-42-101t-101-42-101 42-42 101 42 101 101 42 101-42 42-101z m-572-320h858v71h-858v-71z m643 320q0 89-62 152t-152 62-151-62-63-152 63-151 151-63 152 63 62 151z m-571 358h214v72h-214v-72z m-72-107h858v143h-462l-36-71h-360v-72z m929 143v-714q0-30-21-51t-50-21h-858q-29 0-50 21t-21 51v714q0 30 21 51t50 21h858q29 0 50-21t21-51z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoombox:{width:1e3,height:1e3,path:\"m1000-25l-250 251c40 63 63 138 63 218 0 224-182 406-407 406-224 0-406-182-406-406s183-406 407-406c80 0 155 22 218 62l250-250 125 125z m-812 250l0 438 437 0 0-438-437 0z m62 375l313 0 0-312-313 0 0 312z\",transform:\"matrix(1 0 0 -1 0 850)\"},pan:{width:1e3,height:1e3,path:\"m1000 350l-187 188 0-125-250 0 0 250 125 0-188 187-187-187 125 0 0-250-250 0 0 125-188-188 186-187 0 125 252 0 0-250-125 0 187-188 188 188-125 0 0 250 250 0 0-126 187 188z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_plus:{width:875,height:1e3,path:\"m1 787l0-875 875 0 0 875-875 0z m687-500l-187 0 0-187-125 0 0 187-188 0 0 125 188 0 0 187 125 0 0-187 187 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},zoom_minus:{width:875,height:1e3,path:\"m0 788l0-876 875 0 0 876-875 0z m688-500l-500 0 0 125 500 0 0-125z\",transform:\"matrix(1 0 0 -1 0 850)\"},autoscale:{width:1e3,height:1e3,path:\"m250 850l-187 0-63 0 0-62 0-188 63 0 0 188 187 0 0 62z m688 0l-188 0 0-62 188 0 0-188 62 0 0 188 0 62-62 0z m-875-938l0 188-63 0 0-188 0-62 63 0 187 0 0 62-187 0z m875 188l0-188-188 0 0-62 188 0 62 0 0 62 0 188-62 0z m-125 188l-1 0-93-94-156 156 156 156 92-93 2 0 0 250-250 0 0-2 93-92-156-156-156 156 94 92 0 2-250 0 0-250 0 0 93 93 157-156-157-156-93 94 0 0 0-250 250 0 0 0-94 93 156 157 156-157-93-93 0 0 250 0 0 250z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_basic:{width:1500,height:1e3,path:\"m375 725l0 0-375-375 375-374 0-1 1125 0 0 750-1125 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},tooltip_compare:{width:1125,height:1e3,path:\"m187 786l0 2-187-188 188-187 0 0 937 0 0 373-938 0z m0-499l0 1-187-188 188-188 0 0 937 0 0 376-938-1z\",transform:\"matrix(1 0 0 -1 0 850)\"},plotlylogo:{width:1542,height:1e3,path:\"m0-10h182v-140h-182v140z m228 146h183v-286h-183v286z m225 714h182v-1000h-182v1000z m225-285h182v-715h-182v715z m225 142h183v-857h-183v857z m231-428h182v-429h-182v429z m225-291h183v-138h-183v138z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"z-axis\":{width:1e3,height:1e3,path:\"m833 5l-17 108v41l-130-65 130-66c0 0 0 38 0 39 0-1 36-14 39-25 4-15-6-22-16-30-15-12-39-16-56-20-90-22-187-23-279-23-261 0-341 34-353 59 3 60 228 110 228 110-140-8-351-35-351-116 0-120 293-142 474-142 155 0 477 22 477 142 0 50-74 79-163 96z m-374 94c-58-5-99-21-99-40 0-24 65-43 144-43 79 0 143 19 143 43 0 19-42 34-98 40v216h87l-132 135-133-135h88v-216z m167 515h-136v1c16 16 31 34 46 52l84 109v54h-230v-71h124v-1c-16-17-28-32-44-51l-89-114v-51h245v72z\",transform:\"matrix(1 0 0 -1 0 850)\"},\"3d_rotate\":{width:1e3,height:1e3,path:\"m922 660c-5 4-9 7-14 11-359 263-580-31-580-31l-102 28 58-400c0 1 1 1 2 2 118 108 351 249 351 249s-62 27-100 42c88 83 222 183 347 122 16-8 30-17 44-27-2 1-4 2-6 4z m36-329c0 0 64 229-88 296-62 27-124 14-175-11 157-78 225-208 249-266 8-19 11-31 11-31 2 5 6 15 11 32-5-13-8-20-8-20z m-775-239c70-31 117-50 198-32-121 80-199 346-199 346l-96-15-58-12c0 0 55-226 155-287z m603 133l-317-139c0 0 4-4 19-14 7-5 24-15 24-15s-177-147-389 4c235-287 536-112 536-112l31-22 100 299-4-1z m-298-153c6-4 14-9 24-15 0 0-17 10-24 15z\",transform:\"matrix(1 0 0 -1 0 850)\"},camera:{width:1e3,height:1e3,path:\"m500 450c-83 0-150-67-150-150 0-83 67-150 150-150 83 0 150 67 150 150 0 83-67 150-150 150z m400 150h-120c-16 0-34 13-39 29l-31 93c-6 15-23 28-40 28h-340c-16 0-34-13-39-28l-31-94c-6-15-23-28-40-28h-120c-55 0-100-45-100-100v-450c0-55 45-100 100-100h800c55 0 100 45 100 100v450c0 55-45 100-100 100z m-400-550c-138 0-250 112-250 250 0 138 112 250 250 250 138 0 250-112 250-250 0-138-112-250-250-250z m365 380c-19 0-35 16-35 35 0 19 16 35 35 35 19 0 35-16 35-35 0-19-16-35-35-35z\",transform:\"matrix(1 0 0 -1 0 850)\"},movie:{width:1e3,height:1e3,path:\"m938 413l-188-125c0 37-17 71-44 94 64 38 107 107 107 187 0 121-98 219-219 219-121 0-219-98-219-219 0-61 25-117 66-156h-115c30 33 49 76 49 125 0 103-84 187-187 187s-188-84-188-187c0-57 26-107 65-141-38-22-65-62-65-109v-250c0-70 56-126 125-126h500c69 0 125 56 125 126l188-126c34 0 62 28 62 63v375c0 35-28 63-62 63z m-750 0c-69 0-125 56-125 125s56 125 125 125 125-56 125-125-56-125-125-125z m406-1c-87 0-157 70-157 157 0 86 70 156 157 156s156-70 156-156-70-157-156-157z\",transform:\"matrix(1 0 0 -1 0 850)\"},question:{width:857.1,height:1e3,path:\"m500 82v107q0 8-5 13t-13 5h-107q-8 0-13-5t-5-13v-107q0-8 5-13t13-5h107q8 0 13 5t5 13z m143 375q0 49-31 91t-77 65-95 23q-136 0-207-119-9-14 4-24l74-55q4-4 10-4 9 0 14 7 30 38 48 51 19 14 48 14 27 0 48-15t21-33q0-21-11-34t-38-25q-35-16-65-48t-29-70v-20q0-8 5-13t13-5h107q8 0 13 5t5 13q0 10 12 27t30 28q18 10 28 16t25 19 25 27 16 34 7 45z m214-107q0-117-57-215t-156-156-215-58-216 58-155 156-58 215 58 215 155 156 216 58 215-58 156-156 57-215z\",transform:\"matrix(1 0 0 -1 0 850)\"},disk:{width:857.1,height:1e3,path:\"m214-7h429v214h-429v-214z m500 0h72v500q0 8-6 21t-11 20l-157 156q-5 6-19 12t-22 5v-232q0-22-15-38t-38-16h-322q-22 0-37 16t-16 38v232h-72v-714h72v232q0 22 16 38t37 16h465q22 0 38-16t15-38v-232z m-214 518v178q0 8-5 13t-13 5h-107q-7 0-13-5t-5-13v-178q0-8 5-13t13-5h107q7 0 13 5t5 13z m357-18v-518q0-22-15-38t-38-16h-750q-23 0-38 16t-16 38v750q0 22 16 38t38 16h517q23 0 50-12t42-26l156-157q16-15 27-42t11-49z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawopenpath:{width:70,height:70,path:\"M33.21,85.65a7.31,7.31,0,0,1-2.59-.48c-8.16-3.11-9.27-19.8-9.88-41.3-.1-3.58-.19-6.68-.35-9-.15-2.1-.67-3.48-1.43-3.79-2.13-.88-7.91,2.32-12,5.86L3,32.38c1.87-1.64,11.55-9.66,18.27-6.9,2.13.87,4.75,3.14,5.17,9,.17,2.43.26,5.59.36,9.25a224.17,224.17,0,0,0,1.5,23.4c1.54,10.76,4,12.22,4.48,12.4.84.32,2.79-.46,5.76-3.59L43,80.07C41.53,81.57,37.68,85.64,33.21,85.65ZM74.81,69a11.34,11.34,0,0,0,6.09-6.72L87.26,44.5,74.72,32,56.9,38.35c-2.37.86-5.57,3.42-6.61,6L38.65,72.14l8.42,8.43ZM55,46.27a7.91,7.91,0,0,1,3.64-3.17l14.8-5.3,8,8L76.11,60.6l-.06.19a6.37,6.37,0,0,1-3,3.43L48.25,74.59,44.62,71Zm16.57,7.82A6.9,6.9,0,1,0,64.64,61,6.91,6.91,0,0,0,71.54,54.09Zm-4.05,0a2.85,2.85,0,1,1-2.85-2.85A2.86,2.86,0,0,1,67.49,54.09Zm-4.13,5.22L60.5,56.45,44.26,72.7l2.86,2.86ZM97.83,35.67,84.14,22l-8.57,8.57L89.26,44.24Zm-13.69-8,8,8-2.85,2.85-8-8Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawclosedpath:{width:90,height:90,path:\"M88.41,21.12a26.56,26.56,0,0,0-36.18,0l-2.07,2-2.07-2a26.57,26.57,0,0,0-36.18,0,23.74,23.74,0,0,0,0,34.8L48,90.12a3.22,3.22,0,0,0,4.42,0l36-34.21a23.73,23.73,0,0,0,0-34.79ZM84,51.24,50.16,83.35,16.35,51.25a17.28,17.28,0,0,1,0-25.47,20,20,0,0,1,27.3,0l4.29,4.07a3.23,3.23,0,0,0,4.44,0l4.29-4.07a20,20,0,0,1,27.3,0,17.27,17.27,0,0,1,0,25.46ZM66.76,47.68h-33v6.91h33ZM53.35,35H46.44V68h6.91Z\",transform:\"matrix(1 0 0 1 -5 -5)\"},lasso:{width:1031,height:1e3,path:\"m1018 538c-36 207-290 336-568 286-277-48-473-256-436-463 10-57 36-108 76-151-13-66 11-137 68-183 34-28 75-41 114-42l-55-70 0 0c-2-1-3-2-4-3-10-14-8-34 5-45 14-11 34-8 45 4 1 1 2 3 2 5l0 0 113 140c16 11 31 24 45 40 4 3 6 7 8 11 48-3 100 0 151 9 278 48 473 255 436 462z m-624-379c-80 14-149 48-197 96 42 42 109 47 156 9 33-26 47-66 41-105z m-187-74c-19 16-33 37-39 60 50-32 109-55 174-68-42-25-95-24-135 8z m360 75c-34-7-69-9-102-8 8 62-16 128-68 170-73 59-175 54-244-5-9 20-16 40-20 61-28 159 121 317 333 354s407-60 434-217c28-159-121-318-333-355z\",transform:\"matrix(1 0 0 -1 0 850)\"},selectbox:{width:1e3,height:1e3,path:\"m0 850l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-285l0-143 143 0 0 143-143 0z m857 0l0-143 143 0 0 143-143 0z m-857-286l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z m285 0l0-143 143 0 0 143-143 0z m286 0l0-143 143 0 0 143-143 0z\",transform:\"matrix(1 0 0 -1 0 850)\"},drawline:{width:70,height:70,path:\"M60.64,62.3a11.29,11.29,0,0,0,6.09-6.72l6.35-17.72L60.54,25.31l-17.82,6.4c-2.36.86-5.57,3.41-6.6,6L24.48,65.5l8.42,8.42ZM40.79,39.63a7.89,7.89,0,0,1,3.65-3.17l14.79-5.31,8,8L61.94,54l-.06.19a6.44,6.44,0,0,1-3,3.43L34.07,68l-3.62-3.63Zm16.57,7.81a6.9,6.9,0,1,0-6.89,6.9A6.9,6.9,0,0,0,57.36,47.44Zm-4,0a2.86,2.86,0,1,1-2.85-2.85A2.86,2.86,0,0,1,53.32,47.44Zm-4.13,5.22L46.33,49.8,30.08,66.05l2.86,2.86ZM83.65,29,70,15.34,61.4,23.9,75.09,37.59ZM70,21.06l8,8-2.84,2.85-8-8ZM87,80.49H10.67V87H87Z\",transform:\"matrix(1 0 0 1 -15 -15)\"},drawrect:{width:80,height:80,path:\"M78,22V79H21V22H78m9-9H12V88H87V13ZM68,46.22H31V54H68ZM53,32H45.22V69H53Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},drawcircle:{width:80,height:80,path:\"M50,84.72C26.84,84.72,8,69.28,8,50.3S26.84,15.87,50,15.87,92,31.31,92,50.3,73.16,84.72,50,84.72Zm0-60.59c-18.6,0-33.74,11.74-33.74,26.17S31.4,76.46,50,76.46,83.74,64.72,83.74,50.3,68.6,24.13,50,24.13Zm17.15,22h-34v7.11h34Zm-13.8-13H46.24v34h7.11Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},eraseshape:{width:80,height:80,path:\"M82.77,78H31.85L6,49.57,31.85,21.14H82.77a8.72,8.72,0,0,1,8.65,8.77V69.24A8.72,8.72,0,0,1,82.77,78ZM35.46,69.84H82.77a.57.57,0,0,0,.49-.6V29.91a.57.57,0,0,0-.49-.61H35.46L17,49.57Zm32.68-34.7-24,24,5,5,24-24Zm-19,.53-5,5,24,24,5-5Z\",transform:\"matrix(1 0 0 1 -10 -10)\"},spikeline:{width:1e3,height:1e3,path:\"M512 409c0-57-46-104-103-104-57 0-104 47-104 104 0 57 47 103 104 103 57 0 103-46 103-103z m-327-39l92 0 0 92-92 0z m-185 0l92 0 0 92-92 0z m370-186l92 0 0 93-92 0z m0-184l92 0 0 92-92 0z\",transform:\"matrix(1.5 0 0 -1.5 0 850)\"},pencil:{width:1792,height:1792,path:\"M491 1536l91-91-235-235-91 91v107h128v128h107zm523-928q0-22-22-22-10 0-17 7l-542 542q-7 7-7 17 0 22 22 22 10 0 17-7l542-542q7-7 7-17zm-54-192l416 416-832 832h-416v-416zm683 96q0 53-37 90l-166 166-416-416 166-165q36-38 90-38 53 0 91 38l235 234q37 39 37 91z\",transform:\"matrix(1 0 0 1 0 1)\"},newplotlylogo:{name:\"newplotlylogo\",svg:\"<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 132 132'><defs><style>.cls-1 {fill: #3f4f75;} .cls-2 {fill: #80cfbe;} .cls-3 {fill: #fff;}</style></defs><title>plotly-logomark</title><g id='symbol'><rect class='cls-1' width='132' height='132' rx='6' ry='6'/><circle class='cls-2' cx='78' cy='54' r='6'/><circle class='cls-2' cx='102' cy='30' r='6'/><circle class='cls-2' cx='78' cy='30' r='6'/><circle class='cls-2' cx='54' cy='30' r='6'/><circle class='cls-2' cx='30' cy='30' r='6'/><circle class='cls-2' cx='30' cy='54' r='6'/><path class='cls-3' d='M30,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,30,72Z'/><path class='cls-3' d='M78,72a6,6,0,0,0-6,6v24a6,6,0,0,0,12,0V78A6,6,0,0,0,78,72Z'/><path class='cls-3' d='M54,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,54,48Z'/><path class='cls-3' d='M102,48a6,6,0,0,0-6,6v48a6,6,0,0,0,12,0V54A6,6,0,0,0,102,48Z'/></g></svg>\"}}},{}],758:[function(t,e,r){\"use strict\";r.isLeftAnchor=function(t){return\"left\"===t.xanchor||\"auto\"===t.xanchor&&t.x<=1/3},r.isCenterAnchor=function(t){return\"center\"===t.xanchor||\"auto\"===t.xanchor&&t.x>1/3&&t.x<2/3},r.isRightAnchor=function(t){return\"right\"===t.xanchor||\"auto\"===t.xanchor&&t.x>=2/3},r.isTopAnchor=function(t){return\"top\"===t.yanchor||\"auto\"===t.yanchor&&t.y>=2/3},r.isMiddleAnchor=function(t){return\"middle\"===t.yanchor||\"auto\"===t.yanchor&&t.y>1/3&&t.y<2/3},r.isBottomAnchor=function(t){return\"bottom\"===t.yanchor||\"auto\"===t.yanchor&&t.y<=1/3}},{}],759:[function(t,e,r){\"use strict\";var n=t(\"./mod\"),i=n.mod,a=n.modHalf,o=Math.PI,s=2*o;function l(t){return Math.abs(t[1]-t[0])>s-1e-14}function c(t,e){return a(e-t,s)}function u(t,e){if(l(e))return!0;var r,n;e[0]<e[1]?(r=e[0],n=e[1]):(r=e[1],n=e[0]),(r=i(r,s))>(n=i(n,s))&&(n+=s);var a=i(t,s),o=a+s;return a>=r&&a<=n||o>=r&&o<=n}function f(t,e,r,n,i,a,c){i=i||0,a=a||0;var u,f,h,p,d,g=l([r,n]);function m(t,e){return[t*Math.cos(e)+i,a-t*Math.sin(e)]}g?(u=0,f=o,h=s):r<n?(u=r,h=n):(u=n,h=r),t<e?(p=t,d=e):(p=e,d=t);var v,y=Math.abs(h-u)<=o?0:1;function x(t,e,r){return\"A\"+[t,t]+\" \"+[0,y,r]+\" \"+m(t,e)}return g?v=null===p?\"M\"+m(d,u)+x(d,f,0)+x(d,h,0)+\"Z\":\"M\"+m(p,u)+x(p,f,0)+x(p,h,0)+\"ZM\"+m(d,u)+x(d,f,1)+x(d,h,1)+\"Z\":null===p?(v=\"M\"+m(d,u)+x(d,h,0),c&&(v+=\"L0,0Z\")):v=\"M\"+m(p,u)+\"L\"+m(d,u)+x(d,h,0)+\"L\"+m(p,h)+x(p,u,1)+\"Z\",v}e.exports={deg2rad:function(t){return t/180*o},rad2deg:function(t){return t/o*180},angleDelta:c,angleDist:function(t,e){return Math.abs(c(t,e))},isFullCircle:l,isAngleInsideSector:u,isPtInsideSector:function(t,e,r,n){return!!u(e,n)&&(r[0]<r[1]?(i=r[0],a=r[1]):(i=r[1],a=r[0]),t>=i&&t<=a);var i,a},pathArc:function(t,e,r,n,i){return f(null,t,e,r,n,i,0)},pathSector:function(t,e,r,n,i){return f(null,t,e,r,n,i,1)},pathAnnulus:function(t,e,r,n,i,a){return f(t,e,r,n,i,a,1)}}},{\"./mod\":785}],760:[function(t,e,r){\"use strict\";var n=Array.isArray,i=\"undefined\"!=typeof ArrayBuffer&&ArrayBuffer.isView?ArrayBuffer:{isView:function(){return!1}},a=\"undefined\"==typeof DataView?function(){}:DataView;function o(t){return i.isView(t)&&!(t instanceof a)}function s(t){return n(t)||o(t)}function l(t,e,r){if(s(t)){if(s(t[0])){for(var n=r,i=0;i<t.length;i++)n=e(n,t[i].length);return n}return t.length}return 0}r.isTypedArray=o,r.isArrayOrTypedArray=s,r.isArray1D=function(t){return!s(t[0])},r.ensureArray=function(t,e){return n(t)||(t=[]),t.length=e,t},r.concat=function(){var t,e,r,i,a,o,s,l,c=[],u=!0,f=0;for(r=0;r<arguments.length;r++)(o=(i=arguments[r]).length)&&(e?c.push(i):(e=i,a=o),n(i)?t=!1:(u=!1,f?t!==i.constructor&&(t=!1):t=i.constructor),f+=o);if(!f)return[];if(!c.length)return e;if(u)return e.concat.apply(e,c);if(t){for((s=new t(f)).set(e),r=0;r<c.length;r++)i=c[r],s.set(i,a),a+=i.length;return s}for(s=new Array(f),l=0;l<e.length;l++)s[l]=e[l];for(r=0;r<c.length;r++){for(i=c[r],l=0;l<i.length;l++)s[a+l]=i[l];a+=l}return s},r.maxRowLength=function(t){return l(t,Math.max,0)},r.minRowLength=function(t){return l(t,Math.min,1/0)}},{}],761:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../constants/numerical\").BADNUM,a=/^['\"%,$#\\s']+|[, ]|['\"%,$#\\s']+$/g;e.exports=function(t){return\"string\"==typeof t&&(t=t.replace(a,\"\")),n(t)?Number(t):i}},{\"../constants/numerical\":753,\"fast-isnumeric\":241}],762:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t._fullLayout;e._glcanvas&&e._glcanvas.size()&&e._glcanvas.each((function(t){t.regl&&t.regl.clear({color:!0,depth:!0})}))}},{}],763:[function(t,e,r){\"use strict\";e.exports=function(t){t._responsiveChartHandler&&(window.removeEventListener(\"resize\",t._responsiveChartHandler),delete t._responsiveChartHandler)}},{}],764:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../plots/attributes\"),o=t(\"../components/colorscale/scales\"),s=t(\"../constants/interactions\").DESELECTDIM,l=t(\"./nested_property\"),c=t(\"./regex\").counter,u=t(\"./mod\").modHalf,f=t(\"./array\").isArrayOrTypedArray;function h(t,e){var n=r.valObjectMeta[e.valType];if(e.arrayOk&&f(t))return!0;if(n.validateFunction)return n.validateFunction(t,e);var i={},a=i,o={set:function(t){a=t}};return n.coerceFunction(t,o,i,e),a!==i}r.valObjectMeta={data_array:{coerceFunction:function(t,e,r){f(t)?e.set(t):void 0!==r&&e.set(r)}},enumerated:{coerceFunction:function(t,e,r,n){n.coerceNumber&&(t=+t),-1===n.values.indexOf(t)?e.set(r):e.set(t)},validateFunction:function(t,e){e.coerceNumber&&(t=+t);for(var r=e.values,n=0;n<r.length;n++){var i=String(r[n]);if(\"/\"===i.charAt(0)&&\"/\"===i.charAt(i.length-1)){if(new RegExp(i.substr(1,i.length-2)).test(t))return!0}else if(t===r[n])return!0}return!1}},boolean:{coerceFunction:function(t,e,r){!0===t||!1===t?e.set(t):e.set(r)}},number:{coerceFunction:function(t,e,r,i){!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},integer:{coerceFunction:function(t,e,r,i){t%1||!n(t)||void 0!==i.min&&t<i.min||void 0!==i.max&&t>i.max?e.set(r):e.set(+t)}},string:{coerceFunction:function(t,e,r,n){if(\"string\"!=typeof t){var i=\"number\"==typeof t;!0!==n.strict&&i?e.set(String(t)):e.set(r)}else n.noBlank&&!t?e.set(r):e.set(t)}},color:{coerceFunction:function(t,e,r){i(t).isValid()?e.set(t):e.set(r)}},colorlist:{coerceFunction:function(t,e,r){Array.isArray(t)&&t.length&&t.every((function(t){return i(t).isValid()}))?e.set(t):e.set(r)}},colorscale:{coerceFunction:function(t,e,r){e.set(o.get(t,r))}},angle:{coerceFunction:function(t,e,r){\"auto\"===t?e.set(\"auto\"):n(t)?e.set(u(+t,360)):e.set(r)}},subplotid:{coerceFunction:function(t,e,r,n){var i=n.regex||c(r);\"string\"==typeof t&&i.test(t)?e.set(t):e.set(r)},validateFunction:function(t,e){var r=e.dflt;return t===r||\"string\"==typeof t&&!!c(r).test(t)}},flaglist:{coerceFunction:function(t,e,r,n){if(\"string\"==typeof t)if(-1===(n.extras||[]).indexOf(t)){for(var i=t.split(\"+\"),a=0;a<i.length;){var o=i[a];-1===n.flags.indexOf(o)||i.indexOf(o)<a?i.splice(a,1):a++}i.length?e.set(i.join(\"+\")):e.set(r)}else e.set(t);else e.set(r)}},any:{coerceFunction:function(t,e,r){void 0===t?e.set(r):e.set(t)}},info_array:{coerceFunction:function(t,e,n,i){function a(t,e,n){var i,a={set:function(t){i=t}};return void 0===n&&(n=e.dflt),r.valObjectMeta[e.valType].coerceFunction(t,a,n,e),i}var o=2===i.dimensions||\"1-2\"===i.dimensions&&Array.isArray(t)&&Array.isArray(t[0]);if(Array.isArray(t)){var s,l,c,u,f,h,p=i.items,d=[],g=Array.isArray(p),m=g&&o&&Array.isArray(p[0]),v=o&&g&&!m,y=g&&!v?p.length:t.length;if(n=Array.isArray(n)?n:[],o)for(s=0;s<y;s++)for(d[s]=[],c=Array.isArray(t[s])?t[s]:[],f=v?p.length:g?p[s].length:c.length,l=0;l<f;l++)u=v?p[l]:g?p[s][l]:p,void 0!==(h=a(c[l],u,(n[s]||[])[l]))&&(d[s][l]=h);else for(s=0;s<y;s++)void 0!==(h=a(t[s],g?p[s]:p,n[s]))&&(d[s]=h);e.set(d)}else e.set(n)},validateFunction:function(t,e){if(!Array.isArray(t))return!1;var r=e.items,n=Array.isArray(r),i=2===e.dimensions;if(!e.freeLength&&t.length!==r.length)return!1;for(var a=0;a<t.length;a++)if(i){if(!Array.isArray(t[a])||!e.freeLength&&t[a].length!==r[a].length)return!1;for(var o=0;o<t[a].length;o++)if(!h(t[a][o],n?r[a][o]:r))return!1}else if(!h(t[a],n?r[a]:r))return!1;return!0}}},r.coerce=function(t,e,n,i,a){var o=l(n,i).get(),s=l(t,i),c=l(e,i),u=s.get(),p=e._template;if(void 0===u&&p&&(u=l(p,i).get(),p=0),void 0===a&&(a=o.dflt),o.arrayOk&&f(u))return c.set(u),u;var d=r.valObjectMeta[o.valType].coerceFunction;d(u,c,a,o);var g=c.get();return p&&g===a&&!h(u,o)&&(d(u=l(p,i).get(),c,a,o),g=c.get()),g},r.coerce2=function(t,e,n,i,a){var o=l(t,i),s=r.coerce(t,e,n,i,a),c=o.get();return null!=c&&s},r.coerceFont=function(t,e,r){var n={};return r=r||{},n.family=t(e+\".family\",r.family),n.size=t(e+\".size\",r.size),n.color=t(e+\".color\",r.color),n},r.coerceHoverinfo=function(t,e,n){var i,o=e._module.attributes,s=o.hoverinfo?o:a,l=s.hoverinfo;if(1===n._dataLength){var c=\"all\"===l.dflt?l.flags.slice():l.dflt.split(\"+\");c.splice(c.indexOf(\"name\"),1),i=c.join(\"+\")}return r.coerce(t,e,s,\"hoverinfo\",i)},r.coerceSelectionMarkerOpacity=function(t,e){if(t.marker){var r,n,i=t.marker.opacity;if(void 0!==i)f(i)||t.selected||t.unselected||(r=i,n=s*i),e(\"selected.marker.opacity\",r),e(\"unselected.marker.opacity\",n)}},r.validate=h},{\"../components/colorscale/scales\":658,\"../constants/interactions\":752,\"../plots/attributes\":824,\"./array\":760,\"./mod\":785,\"./nested_property\":786,\"./regex\":795,\"fast-isnumeric\":241,tinycolor2:576}],765:[function(t,e,r){\"use strict\";var n,i,a=t(\"d3-time-format\").timeFormat,o=t(\"fast-isnumeric\"),s=t(\"./loggers\"),l=t(\"./mod\").mod,c=t(\"../constants/numerical\"),u=c.BADNUM,f=c.ONEDAY,h=c.ONEHOUR,p=c.ONEMIN,d=c.ONESEC,g=c.EPOCHJD,m=t(\"../registry\"),v=t(\"d3-time-format\").utcFormat,y=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\d)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,x=/^\\s*(-?\\d\\d\\d\\d|\\d\\d)(-(\\d?\\di?)(-(\\d?\\d)([ Tt]([01]?\\d|2[0-3])(:([0-5]\\d)(:([0-5]\\d(\\.\\d+)?))?(Z|z|[+\\-]\\d\\d(:?\\d\\d)?)?)?)?)?)?\\s*$/m,b=(new Date).getFullYear()-70;function _(t){return t&&m.componentsRegistry.calendars&&\"string\"==typeof t&&\"gregorian\"!==t}function w(t,e){return String(t+Math.pow(10,e)).substr(1)}r.dateTick0=function(t,e){var n=function(t,e){return _(t)?e?m.getComponentMethod(\"calendars\",\"CANONICAL_SUNDAY\")[t]:m.getComponentMethod(\"calendars\",\"CANONICAL_TICK\")[t]:e?\"2000-01-02\":\"2000-01-01\"}(t,!!e);if(e<2)return n;var i=r.dateTime2ms(n,t);return i+=f*(e-1),r.ms2DateTime(i,0,t)},r.dfltRange=function(t){return _(t)?m.getComponentMethod(\"calendars\",\"DFLTRANGE\")[t]:[\"2000-01-01\",\"2001-01-01\"]},r.isJSDate=function(t){return\"object\"==typeof t&&null!==t&&\"function\"==typeof t.getTime},r.dateTime2ms=function(t,e){if(r.isJSDate(t)){var a=t.getTimezoneOffset()*p,o=(t.getUTCMinutes()-t.getMinutes())*p+(t.getUTCSeconds()-t.getSeconds())*d+(t.getUTCMilliseconds()-t.getMilliseconds());if(o){var s=3*p;a=a-s/2+l(o-a+s/2,s)}return(t=Number(t)-a)>=n&&t<=i?t:u}if(\"string\"!=typeof t&&\"number\"!=typeof t)return u;t=String(t);var c=_(e),v=t.charAt(0);!c||\"G\"!==v&&\"g\"!==v||(t=t.substr(1),e=\"\");var w=c&&\"chinese\"===e.substr(0,7),T=t.match(w?x:y);if(!T)return u;var k=T[1],M=T[3]||\"1\",A=Number(T[5]||1),S=Number(T[7]||0),E=Number(T[9]||0),C=Number(T[11]||0);if(c){if(2===k.length)return u;var L;k=Number(k);try{var I=m.getComponentMethod(\"calendars\",\"getCal\")(e);if(w){var P=\"i\"===M.charAt(M.length-1);M=parseInt(M,10),L=I.newDate(k,I.toMonthIndex(k,M,P),A)}else L=I.newDate(k,Number(M),A)}catch(t){return u}return L?(L.toJD()-g)*f+S*h+E*p+C*d:u}k=2===k.length?(Number(k)+2e3-b)%100+b:Number(k),M-=1;var z=new Date(Date.UTC(2e3,M,A,S,E));return z.setUTCFullYear(k),z.getUTCMonth()!==M||z.getUTCDate()!==A?u:z.getTime()+C*d},n=r.MIN_MS=r.dateTime2ms(\"-9999\"),i=r.MAX_MS=r.dateTime2ms(\"9999-12-31 23:59:59.9999\"),r.isDateTime=function(t,e){return r.dateTime2ms(t,e)!==u};var T=90*f,k=3*h,M=5*p;function A(t,e,r,n,i){if((e||r||n||i)&&(t+=\" \"+w(e,2)+\":\"+w(r,2),(n||i)&&(t+=\":\"+w(n,2),i))){for(var a=4;i%10==0;)a-=1,i/=10;t+=\".\"+w(i,a)}return t}r.ms2DateTime=function(t,e,r){if(\"number\"!=typeof t||!(t>=n&&t<=i))return u;e||(e=0);var a,o,s,c,y,x,b=Math.floor(10*l(t+.05,1)),w=Math.round(t-b/10);if(_(r)){var S=Math.floor(w/f)+g,E=Math.floor(l(t,f));try{a=m.getComponentMethod(\"calendars\",\"getCal\")(r).fromJD(S).formatDate(\"yyyy-mm-dd\")}catch(t){a=v(\"G%Y-%m-%d\")(new Date(w))}if(\"-\"===a.charAt(0))for(;a.length<11;)a=\"-0\"+a.substr(1);else for(;a.length<10;)a=\"0\"+a;o=e<T?Math.floor(E/h):0,s=e<T?Math.floor(E%h/p):0,c=e<k?Math.floor(E%p/d):0,y=e<M?E%d*10+b:0}else x=new Date(w),a=v(\"%Y-%m-%d\")(x),o=e<T?x.getUTCHours():0,s=e<T?x.getUTCMinutes():0,c=e<k?x.getUTCSeconds():0,y=e<M?10*x.getUTCMilliseconds()+b:0;return A(a,o,s,c,y)},r.ms2DateTimeLocal=function(t){if(!(t>=n+f&&t<=i-f))return u;var e=Math.floor(10*l(t+.05,1)),r=new Date(Math.round(t-e/10));return A(a(\"%Y-%m-%d\")(r),r.getHours(),r.getMinutes(),r.getSeconds(),10*r.getUTCMilliseconds()+e)},r.cleanDate=function(t,e,n){if(t===u)return e;if(r.isJSDate(t)||\"number\"==typeof t&&isFinite(t)){if(_(n))return s.error(\"JS Dates and milliseconds are incompatible with world calendars\",t),e;if(!(t=r.ms2DateTimeLocal(+t))&&void 0!==e)return e}else if(!r.isDateTime(t,n))return s.error(\"unrecognized date\",t),e;return t};var S=/%\\d?f/g;function E(t,e,r,n){t=t.replace(S,(function(t){var r=Math.min(+t.charAt(1)||6,6);return(e/1e3%1+2).toFixed(r).substr(2).replace(/0+$/,\"\")||\"0\"}));var i=new Date(Math.floor(e+.05));if(_(n))try{t=m.getComponentMethod(\"calendars\",\"worldCalFmt\")(t,e,n)}catch(t){return\"Invalid\"}return r(t)(i)}var C=[59,59.9,59.99,59.999,59.9999];r.formatDate=function(t,e,r,n,i,a){if(i=_(i)&&i,!e)if(\"y\"===r)e=a.year;else if(\"m\"===r)e=a.month;else{if(\"d\"!==r)return function(t,e){var r=l(t+.05,f),n=w(Math.floor(r/h),2)+\":\"+w(l(Math.floor(r/p),60),2);if(\"M\"!==e){o(e)||(e=0);var i=(100+Math.min(l(t/d,60),C[e])).toFixed(e).substr(1);e>0&&(i=i.replace(/0+$/,\"\").replace(/[\\.]$/,\"\")),n+=\":\"+i}return n}(t,r)+\"\\n\"+E(a.dayMonthYear,t,n,i);e=a.dayMonth+\"\\n\"+a.year}return E(e,t,n,i)};var L=3*f;r.incrementMonth=function(t,e,r){r=_(r)&&r;var n=l(t,f);if(t=Math.round(t-n),r)try{var i=Math.round(t/f)+g,a=m.getComponentMethod(\"calendars\",\"getCal\")(r),o=a.fromJD(i);return e%12?a.add(o,e,\"m\"):a.add(o,e/12,\"y\"),(o.toJD()-g)*f+n}catch(e){s.error(\"invalid ms \"+t+\" in calendar \"+r)}var c=new Date(t+L);return c.setUTCMonth(c.getUTCMonth()+e)+n-L},r.findExactDates=function(t,e){for(var r,n,i=0,a=0,s=0,l=0,c=_(e)&&m.getComponentMethod(\"calendars\",\"getCal\")(e),u=0;u<t.length;u++)if(n=t[u],o(n)){if(!(n%f))if(c)try{1===(r=c.fromJD(n/f+g)).day()?1===r.month()?i++:a++:s++}catch(t){}else 1===(r=new Date(n)).getUTCDate()?0===r.getUTCMonth()?i++:a++:s++}else l++;s+=a+=i;var h=t.length-l;return{exactYears:i/h,exactMonths:a/h,exactDays:s/h}}},{\"../constants/numerical\":753,\"../registry\":911,\"./loggers\":782,\"./mod\":785,\"d3-time-format\":166,\"fast-isnumeric\":241}],766:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./loggers\"),a=t(\"./matrix\"),o=t(\"gl-mat4\");function s(t){var e=t&&t.parentNode;e&&e.removeChild(t)}function l(t,e,r){var n=\"plotly.js-style-\"+t,a=document.getElementById(n);a||((a=document.createElement(\"style\")).setAttribute(\"id\",n),a.appendChild(document.createTextNode(\"\")),document.head.appendChild(a));var o=a.sheet;o.insertRule?o.insertRule(e+\"{\"+r+\"}\",0):o.addRule?o.addRule(e,r,0):i.warn(\"addStyleRule failed\")}function c(t){var e=window.getComputedStyle(t,null),r=e.getPropertyValue(\"-webkit-transform\")||e.getPropertyValue(\"-moz-transform\")||e.getPropertyValue(\"-ms-transform\")||e.getPropertyValue(\"-o-transform\")||e.getPropertyValue(\"transform\");return\"none\"===r?null:r.replace(\"matrix\",\"\").replace(\"3d\",\"\").slice(1,-1).split(\",\").map((function(t){return+t}))}function u(t){for(var e=[];f(t);)e.push(t),t=t.parentNode;return e}function f(t){return t&&(t instanceof Element||t instanceof HTMLElement)}e.exports={getGraphDiv:function(t){var e;if(\"string\"==typeof t){if(null===(e=document.getElementById(t)))throw new Error(\"No DOM element with id '\"+t+\"' exists on the page.\");return e}if(null==t)throw new Error(\"DOM element provided is null or undefined\");return t},isPlotDiv:function(t){var e=n.select(t);return e.node()instanceof HTMLElement&&e.size()&&e.classed(\"js-plotly-plot\")},removeElement:s,addStyleRule:function(t,e){l(\"global\",t,e)},addRelatedStyleRule:l,deleteRelatedStyleRule:function(t){var e=\"plotly.js-style-\"+t,r=document.getElementById(e);r&&s(r)},getFullTransformMatrix:function(t){var e=u(t),r=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];return e.forEach((function(t){var e=c(t);if(e){var n=a.convertCssMatrix(e);r=o.multiply(r,r,n)}})),r},getElementTransformMatrix:c,getElementAndAncestors:u,equalDomRects:function(t,e){return t&&e&&t.x===e.x&&t.y===e.y&&t.top===e.top&&t.left===e.left&&t.right===e.right&&t.bottom===e.bottom}}},{\"./loggers\":782,\"./matrix\":784,d3:169,\"gl-mat4\":292}],767:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i={init:function(t){if(t._ev instanceof n)return t;var e=new n,r=new n;return t._ev=e,t._internalEv=r,t.on=e.on.bind(e),t.once=e.once.bind(e),t.removeListener=e.removeListener.bind(e),t.removeAllListeners=e.removeAllListeners.bind(e),t._internalOn=r.on.bind(r),t._internalOnce=r.once.bind(r),t._removeInternalListener=r.removeListener.bind(r),t._removeAllInternalListeners=r.removeAllListeners.bind(r),t.emit=function(n,i){\"undefined\"!=typeof jQuery&&jQuery(t).trigger(n,i),e.emit(n,i),r.emit(n,i)},t},triggerHandler:function(t,e,r){var n,i;\"undefined\"!=typeof jQuery&&(n=jQuery(t).triggerHandler(e,r));var a=t._ev;if(!a)return n;var o,s=a._events[e];if(!s)return n;function l(t){return t.listener?(a.removeListener(e,t.listener),t.fired?void 0:(t.fired=!0,t.listener.apply(a,[r]))):t.apply(a,[r])}for(s=Array.isArray(s)?s:[s],o=0;o<s.length-1;o++)l(s[o]);return i=l(s[o]),void 0!==n?n:i},purge:function(t){return delete t._ev,delete t.on,delete t.once,delete t.removeListener,delete t.removeAllListeners,delete t.emit,delete t._ev,delete t._internalEv,delete t._internalOn,delete t._internalOnce,delete t._removeInternalListener,delete t._removeAllInternalListeners,t}};e.exports=i},{events:110}],768:[function(t,e,r){\"use strict\";var n=t(\"./is_plain_object.js\"),i=Array.isArray;function a(t,e,r,o){var s,l,c,u,f,h,p=t[0],d=t.length;if(2===d&&i(p)&&i(t[1])&&0===p.length){if(function(t,e){var r,n;for(r=0;r<t.length;r++){if(null!==(n=t[r])&&\"object\"==typeof n)return!1;void 0!==n&&(e[r]=n)}return!0}(t[1],p))return p;p.splice(0,p.length)}for(var g=1;g<d;g++)for(l in s=t[g])c=p[l],u=s[l],o&&i(u)?p[l]=u:e&&u&&(n(u)||(f=i(u)))?(f?(f=!1,h=c&&i(c)?c:[]):h=c&&n(c)?c:{},p[l]=a([h,u],e,r,o)):(\"undefined\"!=typeof u||r)&&(p[l]=u);return p}r.extendFlat=function(){return a(arguments,!1,!1,!1)},r.extendDeep=function(){return a(arguments,!0,!1,!1)},r.extendDeepAll=function(){return a(arguments,!0,!0,!1)},r.extendDeepNoArrays=function(){return a(arguments,!0,!1,!0)}},{\"./is_plain_object.js\":779}],769:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e={},r=[],n=0,i=0;i<t.length;i++){var a=t[i];1!==e[a]&&(e[a]=1,r[n++]=a)}return r}},{}],770:[function(t,e,r){\"use strict\";function n(t){return!0===t.visible}function i(t){var e=t[0].trace;return!0===e.visible&&0!==e._length}e.exports=function(t){for(var e,r=(e=t,Array.isArray(e)&&Array.isArray(e[0])&&e[0][0]&&e[0][0].trace?i:n),a=[],o=0;o<t.length;o++){var s=t[o];r(s)&&a.push(s)}return a}},{}],771:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"country-regex\"),a=t(\"@turf/area\"),o=t(\"@turf/centroid\"),s=t(\"@turf/bbox\"),l=t(\"./identity\"),c=t(\"./loggers\"),u=t(\"./is_plain_object\"),f=t(\"./nested_property\"),h=t(\"./polygon\"),p=Object.keys(i),d={\"ISO-3\":l,\"USA-states\":l,\"country names\":function(t){for(var e=0;e<p.length;e++){var r=p[e];if(new RegExp(i[r]).test(t.trim().toLowerCase()))return r}return c.log(\"Unrecognized country name: \"+t+\".\"),!1}};function g(t){var e=t.geojson,r=window.PlotlyGeoAssets||{},n=\"string\"==typeof e?r[e]:e;return u(n)?n:(c.error(\"Oops ... something went wrong when fetching \"+e),!1)}e.exports={locationToFeature:function(t,e,r){if(!e||\"string\"!=typeof e)return!1;var n,i,a,o=d[t](e);if(o){if(\"USA-states\"===t)for(n=[],a=0;a<r.length;a++)(i=r[a]).properties&&i.properties.gu&&\"USA\"===i.properties.gu&&n.push(i);else n=r;for(a=0;a<n.length;a++)if((i=n[a]).id===o)return i;c.log([\"Location with id\",o,\"does not have a matching topojson feature at this resolution.\"].join(\" \"))}return!1},feature2polygons:function(t){var e,r,n,i,a=t.geometry,o=a.coordinates,s=t.id,l=[];function c(t){for(var e=0;e<t.length-1;e++)if(t[e][0]>0&&t[e+1][0]<0)return e;return null}switch(e=\"RUS\"===s||\"FJI\"===s?function(t){var e;if(null===c(t))e=t;else for(e=new Array(t.length),i=0;i<t.length;i++)e[i]=[t[i][0]<0?t[i][0]+360:t[i][0],t[i][1]];l.push(h.tester(e))}:\"ATA\"===s?function(t){var e=c(t);if(null===e)return l.push(h.tester(t));var r=new Array(t.length+1),n=0;for(i=0;i<t.length;i++)i>e?r[n++]=[t[i][0]+360,t[i][1]]:i===e?(r[n++]=t[i],r[n++]=[t[i][0],-90]):r[n++]=t[i];var a=h.tester(r);a.pts.pop(),l.push(a)}:function(t){l.push(h.tester(t))},a.type){case\"MultiPolygon\":for(r=0;r<o.length;r++)for(n=0;n<o[r].length;n++)e(o[r][n]);break;case\"Polygon\":for(r=0;r<o.length;r++)e(o[r])}return l},getTraceGeojson:g,extractTraceFeature:function(t){var e=t[0].trace,r=g(e);if(!r)return!1;var n,i={},s=[];for(n=0;n<e._length;n++){var l=t[n];(l.loc||0===l.loc)&&(i[l.loc]=l)}function u(t){var r=f(t,e.featureidkey||\"id\").get(),n=i[r];if(n){var l=t.geometry;if(\"Polygon\"===l.type||\"MultiPolygon\"===l.type){var u={type:\"Feature\",id:r,geometry:l,properties:{}};u.properties.ct=function(t){var e,r=t.geometry;if(\"MultiPolygon\"===r.type)for(var n=r.coordinates,i=0,s=0;s<n.length;s++){var l={type:\"Polygon\",coordinates:n[s]},c=a.default(l);c>i&&(i=c,e=l)}else e=r;return o.default(e).geometry.coordinates}(u),n.fIn=t,n.fOut=u,s.push(u)}else c.log([\"Location\",n.loc,\"does not have a valid GeoJSON geometry.\",\"Traces with locationmode *geojson-id* only support\",\"*Polygon* and *MultiPolygon* geometries.\"].join(\" \"))}delete i[r]}switch(r.type){case\"FeatureCollection\":var h=r.features;for(n=0;n<h.length;n++)u(h[n]);break;case\"Feature\":u(r);break;default:return c.warn([\"Invalid GeoJSON type\",(r.type||\"none\")+\".\",\"Traces with locationmode *geojson-id* only support\",\"*FeatureCollection* and *Feature* types.\"].join(\" \")),!1}for(var p in i)c.log([\"Location *\"+p+\"*\",\"does not have a matching feature with id-key\",\"*\"+e.featureidkey+\"*.\"].join(\" \"));return s},fetchTraceGeoData:function(t){var e=window.PlotlyGeoAssets||{},r=[];function i(t){return new Promise((function(r,i){n.json(t,(function(n,a){if(n){delete e[t];var o=404===n.status?'GeoJSON at URL \"'+t+'\" does not exist.':\"Unexpected error while fetching from \"+t;return i(new Error(o))}return e[t]=a,r(a)}))}))}function a(t){return new Promise((function(r,n){var i=0,a=setInterval((function(){return e[t]&&\"pending\"!==e[t]?(clearInterval(a),r(e[t])):i>100?(clearInterval(a),n(\"Unexpected error while fetching from \"+t)):void i++}),50)}))}for(var o=0;o<t.length;o++){var s=t[o][0].trace.geojson;\"string\"==typeof s&&(e[s]?\"pending\"===e[s]&&r.push(a(s)):(e[s]=\"pending\",r.push(i(s))))}return r},computeBbox:function(t){return s.default(t)}}},{\"./identity\":776,\"./is_plain_object\":779,\"./loggers\":782,\"./nested_property\":786,\"./polygon\":790,\"@turf/area\":59,\"@turf/bbox\":60,\"@turf/centroid\":61,\"country-regex\":139,d3:169}],772:[function(t,e,r){\"use strict\";var n=t(\"../constants/numerical\").BADNUM;r.calcTraceToLineCoords=function(t){for(var e=t[0].trace.connectgaps,r=[],i=[],a=0;a<t.length;a++){var o=t[a].lonlat;o[0]!==n?i.push(o):!e&&i.length>0&&(r.push(i),i=[])}return i.length>0&&r.push(i),r},r.makeLine=function(t){return 1===t.length?{type:\"LineString\",coordinates:t[0]}:{type:\"MultiLineString\",coordinates:t}},r.makePolygon=function(t){if(1===t.length)return{type:\"Polygon\",coordinates:t};for(var e=new Array(t.length),r=0;r<t.length;r++)e[r]=[t[r]];return{type:\"MultiPolygon\",coordinates:e}},r.makeBlank=function(){return{type:\"Point\",coordinates:[]}}},{\"../constants/numerical\":753}],773:[function(t,e,r){\"use strict\";var n,i,a,o=t(\"./mod\").mod;function s(t,e,r,n,i,a,o,s){var l=r-t,c=i-t,u=o-i,f=n-e,h=a-e,p=s-a,d=l*p-u*f;if(0===d)return null;var g=(c*p-u*h)/d,m=(c*f-l*h)/d;return m<0||m>1||g<0||g>1?null:{x:t+l*g,y:e+f*g}}function l(t,e,r,n,i){var a=n*t+i*e;if(a<0)return n*n+i*i;if(a>r){var o=n-t,s=i-e;return o*o+s*s}var l=n*e-i*t;return l*l/r}r.segmentsIntersect=s,r.segmentDistance=function(t,e,r,n,i,a,o,c){if(s(t,e,r,n,i,a,o,c))return 0;var u=r-t,f=n-e,h=o-i,p=c-a,d=u*u+f*f,g=h*h+p*p,m=Math.min(l(u,f,d,i-t,a-e),l(u,f,d,o-t,c-e),l(h,p,g,t-i,e-a),l(h,p,g,r-i,n-a));return Math.sqrt(m)},r.getTextLocation=function(t,e,r,s){if(t===i&&s===a||(n={},i=t,a=s),n[r])return n[r];var l=t.getPointAtLength(o(r-s/2,e)),c=t.getPointAtLength(o(r+s/2,e)),u=Math.atan((c.y-l.y)/(c.x-l.x)),f=t.getPointAtLength(o(r,e)),h={x:(4*f.x+l.x+c.x)/6,y:(4*f.y+l.y+c.y)/6,theta:u};return n[r]=h,h},r.clearLocationCache=function(){i=null},r.getVisibleSegment=function(t,e,r){var n,i,a=e.left,o=e.right,s=e.top,l=e.bottom,c=0,u=t.getTotalLength(),f=u;function h(e){var r=t.getPointAtLength(e);0===e?n=r:e===u&&(i=r);var c=r.x<a?a-r.x:r.x>o?r.x-o:0,f=r.y<s?s-r.y:r.y>l?r.y-l:0;return Math.sqrt(c*c+f*f)}for(var p=h(c);p;){if((c+=p+r)>f)return;p=h(c)}for(p=h(f);p;){if(c>(f-=p+r))return;p=h(f)}return{min:c,max:f,len:f-c,total:u,isClosed:0===c&&f===u&&Math.abs(n.x-i.x)<.1&&Math.abs(n.y-i.y)<.1}},r.findPointOnPath=function(t,e,r,n){for(var i,a,o,s=(n=n||{}).pathLength||t.getTotalLength(),l=n.tolerance||.001,c=n.iterationLimit||30,u=t.getPointAtLength(0)[r]>t.getPointAtLength(s)[r]?-1:1,f=0,h=0,p=s;f<c;){if(i=(h+p)/2,o=(a=t.getPointAtLength(i))[r]-e,Math.abs(o)<l)return a;u*o>0?p=i:h=i,f++}return a}},{\"./mod\":785}],774:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"color-normalize\"),o=t(\"../components/colorscale\"),s=t(\"../components/color/attributes\").defaultLine,l=t(\"./array\").isArrayOrTypedArray,c=a(s);function u(t,e){var r=t;return r[3]*=e,r}function f(t){if(n(t))return c;var e=a(t);return e.length?e:c}function h(t){return n(t)?t:1}e.exports={formatColor:function(t,e,r){var n,i,s,p,d,g=t.color,m=l(g),v=l(e),y=o.extractOpts(t),x=[];if(n=void 0!==y.colorscale?o.makeColorScaleFuncFromTrace(t):f,i=m?function(t,e){return void 0===t[e]?c:a(n(t[e]))}:f,s=v?function(t,e){return void 0===t[e]?1:h(t[e])}:h,m||v)for(var b=0;b<r;b++)p=i(g,b),d=s(e,b),x[b]=u(p,d);else x=u(a(g),e);return x},parseColorScale:function(t){var e=o.extractOpts(t),r=e.colorscale;return e.reversescale&&(r=o.flipScale(e.colorscale)),r.map((function(t){var e=t[0],r=i(t[1]).toRgb();return{index:e,rgb:[r.r,r.g,r.b,r.a]}}))}}},{\"../components/color/attributes\":642,\"../components/colorscale\":655,\"./array\":760,\"color-normalize\":125,\"fast-isnumeric\":241,tinycolor2:576}],775:[function(t,e,r){\"use strict\";var n=t(\"./identity\");function i(t){return[t]}e.exports={keyFun:function(t){return t.key},repeat:i,descend:n,wrap:i,unwrap:function(t){return t[0]}}},{\"./identity\":776}],776:[function(t,e,r){\"use strict\";e.exports=function(t){return t}},{}],777:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(!e)return t;var r=1/Math.abs(e),n=r>1?(r*t+r*e)/r:t+e,i=String(n).length;if(i>16){var a=String(e).length;if(i>=String(t).length+a){var o=parseFloat(n).toPrecision(12);-1===o.indexOf(\"e+\")&&(n=+o)}}return n}},{}],778:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../constants/numerical\"),s=o.FP_SAFE,l=o.BADNUM,c=e.exports={};c.nestedProperty=t(\"./nested_property\"),c.keyedContainer=t(\"./keyed_container\"),c.relativeAttr=t(\"./relative_attr\"),c.isPlainObject=t(\"./is_plain_object\"),c.toLogRange=t(\"./to_log_range\"),c.relinkPrivateKeys=t(\"./relink_private\");var u=t(\"./array\");c.isTypedArray=u.isTypedArray,c.isArrayOrTypedArray=u.isArrayOrTypedArray,c.isArray1D=u.isArray1D,c.ensureArray=u.ensureArray,c.concat=u.concat,c.maxRowLength=u.maxRowLength,c.minRowLength=u.minRowLength;var f=t(\"./mod\");c.mod=f.mod,c.modHalf=f.modHalf;var h=t(\"./coerce\");c.valObjectMeta=h.valObjectMeta,c.coerce=h.coerce,c.coerce2=h.coerce2,c.coerceFont=h.coerceFont,c.coerceHoverinfo=h.coerceHoverinfo,c.coerceSelectionMarkerOpacity=h.coerceSelectionMarkerOpacity,c.validate=h.validate;var p=t(\"./dates\");c.dateTime2ms=p.dateTime2ms,c.isDateTime=p.isDateTime,c.ms2DateTime=p.ms2DateTime,c.ms2DateTimeLocal=p.ms2DateTimeLocal,c.cleanDate=p.cleanDate,c.isJSDate=p.isJSDate,c.formatDate=p.formatDate,c.incrementMonth=p.incrementMonth,c.dateTick0=p.dateTick0,c.dfltRange=p.dfltRange,c.findExactDates=p.findExactDates,c.MIN_MS=p.MIN_MS,c.MAX_MS=p.MAX_MS;var d=t(\"./search\");c.findBin=d.findBin,c.sorterAsc=d.sorterAsc,c.sorterDes=d.sorterDes,c.distinctVals=d.distinctVals,c.roundUp=d.roundUp,c.sort=d.sort,c.findIndexOfMin=d.findIndexOfMin;var g=t(\"./stats\");c.aggNums=g.aggNums,c.len=g.len,c.mean=g.mean,c.median=g.median,c.midRange=g.midRange,c.variance=g.variance,c.stdev=g.stdev,c.interp=g.interp;var m=t(\"./matrix\");c.init2dArray=m.init2dArray,c.transposeRagged=m.transposeRagged,c.dot=m.dot,c.translationMatrix=m.translationMatrix,c.rotationMatrix=m.rotationMatrix,c.rotationXYMatrix=m.rotationXYMatrix,c.apply3DTransform=m.apply3DTransform,c.apply2DTransform=m.apply2DTransform,c.apply2DTransform2=m.apply2DTransform2,c.convertCssMatrix=m.convertCssMatrix,c.inverseTransformMatrix=m.inverseTransformMatrix;var v=t(\"./angles\");c.deg2rad=v.deg2rad,c.rad2deg=v.rad2deg,c.angleDelta=v.angleDelta,c.angleDist=v.angleDist,c.isFullCircle=v.isFullCircle,c.isAngleInsideSector=v.isAngleInsideSector,c.isPtInsideSector=v.isPtInsideSector,c.pathArc=v.pathArc,c.pathSector=v.pathSector,c.pathAnnulus=v.pathAnnulus;var y=t(\"./anchor_utils\");c.isLeftAnchor=y.isLeftAnchor,c.isCenterAnchor=y.isCenterAnchor,c.isRightAnchor=y.isRightAnchor,c.isTopAnchor=y.isTopAnchor,c.isMiddleAnchor=y.isMiddleAnchor,c.isBottomAnchor=y.isBottomAnchor;var x=t(\"./geometry2d\");c.segmentsIntersect=x.segmentsIntersect,c.segmentDistance=x.segmentDistance,c.getTextLocation=x.getTextLocation,c.clearLocationCache=x.clearLocationCache,c.getVisibleSegment=x.getVisibleSegment,c.findPointOnPath=x.findPointOnPath;var b=t(\"./extend\");c.extendFlat=b.extendFlat,c.extendDeep=b.extendDeep,c.extendDeepAll=b.extendDeepAll,c.extendDeepNoArrays=b.extendDeepNoArrays;var _=t(\"./loggers\");c.log=_.log,c.warn=_.warn,c.error=_.error;var w=t(\"./regex\");c.counterRegex=w.counter;var T=t(\"./throttle\");c.throttle=T.throttle,c.throttleDone=T.done,c.clearThrottle=T.clear;var k=t(\"./dom\");function M(t){var e={};for(var r in t)for(var n=t[r],i=0;i<n.length;i++)e[n[i]]=+r;return e}c.getGraphDiv=k.getGraphDiv,c.isPlotDiv=k.isPlotDiv,c.removeElement=k.removeElement,c.addStyleRule=k.addStyleRule,c.addRelatedStyleRule=k.addRelatedStyleRule,c.deleteRelatedStyleRule=k.deleteRelatedStyleRule,c.getFullTransformMatrix=k.getFullTransformMatrix,c.getElementTransformMatrix=k.getElementTransformMatrix,c.getElementAndAncestors=k.getElementAndAncestors,c.equalDomRects=k.equalDomRects,c.clearResponsive=t(\"./clear_responsive\"),c.preserveDrawingBuffer=t(\"./preserve_drawing_buffer\"),c.makeTraceGroups=t(\"./make_trace_groups\"),c._=t(\"./localize\"),c.notifier=t(\"./notifier\"),c.filterUnique=t(\"./filter_unique\"),c.filterVisible=t(\"./filter_visible\"),c.pushUnique=t(\"./push_unique\"),c.increment=t(\"./increment\"),c.cleanNumber=t(\"./clean_number\"),c.ensureNumber=function(t){return a(t)?(t=Number(t))<-s||t>s?l:a(t)?Number(t):l:l},c.isIndex=function(t,e){return!(void 0!==e&&t>=e)&&(a(t)&&t>=0&&t%1==0)},c.noop=t(\"./noop\"),c.identity=t(\"./identity\"),c.repeat=function(t,e){for(var r=new Array(e),n=0;n<e;n++)r[n]=t;return r},c.swapAttrs=function(t,e,r,n){r||(r=\"x\"),n||(n=\"y\");for(var i=0;i<e.length;i++){var a=e[i],o=c.nestedProperty(t,a.replace(\"?\",r)),s=c.nestedProperty(t,a.replace(\"?\",n)),l=o.get();o.set(s.get()),s.set(l)}},c.raiseToTop=function(t){t.parentNode.appendChild(t)},c.cancelTransition=function(t){return t.transition().duration(0)},c.constrain=function(t,e,r){return e>r?Math.max(r,Math.min(e,t)):Math.max(e,Math.min(r,t))},c.bBoxIntersect=function(t,e,r){return r=r||0,t.left<=e.right+r&&e.left<=t.right+r&&t.top<=e.bottom+r&&e.top<=t.bottom+r},c.simpleMap=function(t,e,r,n,i){for(var a=t.length,o=new Array(a),s=0;s<a;s++)o[s]=e(t[s],r,n,i);return o},c.randstr=function t(e,r,n,i){if(n||(n=16),void 0===r&&(r=24),r<=0)return\"0\";var a,o,s=Math.log(Math.pow(2,r))/Math.log(n),l=\"\";for(a=2;s===1/0;a*=2)s=Math.log(Math.pow(2,r/a))/Math.log(n)*a;var u=s-Math.floor(s);for(a=0;a<Math.floor(s);a++)l=Math.floor(Math.random()*n).toString(n)+l;u&&(o=Math.pow(n,u),l=Math.floor(Math.random()*o).toString(n)+l);var f=parseInt(l,n);return e&&e[l]||f!==1/0&&f>=Math.pow(2,r)?i>10?(c.warn(\"randstr failed uniqueness\"),l):t(e,r,n,(i||0)+1):l},c.OptionControl=function(t,e){t||(t={}),e||(e=\"opt\");var r={optionList:[],_newoption:function(n){n[e]=t,r[n.name]=n,r.optionList.push(n)}};return r[\"_\"+e]=t,r},c.smooth=function(t,e){if((e=Math.round(e)||0)<2)return t;var r,n,i,a,o=t.length,s=2*o,l=2*e-1,c=new Array(l),u=new Array(o);for(r=0;r<l;r++)c[r]=(1-Math.cos(Math.PI*(r+1)/e))/(2*e);for(r=0;r<o;r++){for(a=0,n=0;n<l;n++)(i=r+n+1-e)<-o?i-=s*Math.round(i/s):i>=s&&(i-=s*Math.floor(i/s)),i<0?i=-1-i:i>=o&&(i=s-1-i),a+=t[i]*c[n];u[r]=a}return u},c.syncOrAsync=function(t,e,r){var n;function i(){return c.syncOrAsync(t,e,r)}for(;t.length;)if((n=(0,t.splice(0,1)[0])(e))&&n.then)return n.then(i).then(void 0,c.promiseError);return r&&r(e)},c.stripTrailingSlash=function(t){return\"/\"===t.substr(-1)?t.substr(0,t.length-1):t},c.noneOrAll=function(t,e,r){if(t){var n,i=!1,a=!0;for(n=0;n<r.length;n++)null!=t[r[n]]?i=!0:a=!1;if(i&&!a)for(n=0;n<r.length;n++)t[r[n]]=e[r[n]]}},c.mergeArray=function(t,e,r,n){var i=\"function\"==typeof n;if(c.isArrayOrTypedArray(t))for(var a=Math.min(t.length,e.length),o=0;o<a;o++){var s=t[o];e[o][r]=i?n(s):s}},c.mergeArrayCastPositive=function(t,e,r){return c.mergeArray(t,e,r,(function(t){var e=+t;return isFinite(e)&&e>0?e:0}))},c.fillArray=function(t,e,r,n){if(n=n||c.identity,c.isArrayOrTypedArray(t))for(var i=0;i<e.length;i++)e[i][r]=n(t[i])},c.castOption=function(t,e,r,n){n=n||c.identity;var i=c.nestedProperty(t,r).get();return c.isArrayOrTypedArray(i)?Array.isArray(e)&&c.isArrayOrTypedArray(i[e[0]])?n(i[e[0]][e[1]]):n(i[e]):i},c.extractOption=function(t,e,r,n){if(r in t)return t[r];var i=c.nestedProperty(e,n).get();return Array.isArray(i)?void 0:i},c.tagSelected=function(t,e,r){var n,i,a=e.selectedpoints,o=e._indexToPoints;o&&(n=M(o));for(var s=0;s<a.length;s++){var l=a[s];if(c.isIndex(l)||c.isArrayOrTypedArray(l)&&c.isIndex(l[0])&&c.isIndex(l[1])){var u=n?n[l]:l,f=r?r[u]:u;void 0!==(i=f)&&i<t.length&&(t[f].selected=1)}}},c.selIndices2selPoints=function(t){var e=t.selectedpoints,r=t._indexToPoints;if(r){for(var n=M(r),i=[],a=0;a<e.length;a++){var o=e[a];if(c.isIndex(o)){var s=n[o];c.isIndex(s)&&i.push(s)}}return i}return e},c.getTargetArray=function(t,e){var r=e.target;if(\"string\"==typeof r&&r){var n=c.nestedProperty(t,r).get();return!!Array.isArray(n)&&n}return!!Array.isArray(r)&&r},c.minExtend=function(t,e){var r={};\"object\"!=typeof e&&(e={});var n,i,a,o=Object.keys(t);for(n=0;n<o.length;n++)a=t[i=o[n]],\"_\"!==i.charAt(0)&&\"function\"!=typeof a&&(\"module\"===i?r[i]=a:Array.isArray(a)?r[i]=\"colorscale\"===i?a.slice():a.slice(0,3):c.isTypedArray(a)?r[i]=a.subarray(0,3):r[i]=a&&\"object\"==typeof a?c.minExtend(t[i],e[i]):a);for(o=Object.keys(e),n=0;n<o.length;n++)\"object\"==typeof(a=e[i=o[n]])&&i in r&&\"object\"==typeof r[i]||(r[i]=a);return r},c.titleCase=function(t){return t.charAt(0).toUpperCase()+t.substr(1)},c.containsAny=function(t,e){for(var r=0;r<e.length;r++)if(-1!==t.indexOf(e[r]))return!0;return!1},c.isIE=function(){return\"undefined\"!=typeof window.navigator.msSaveBlob};var A=/MSIE [1-9]\\./;c.isIE9orBelow=function(){return c.isIE()&&A.test(window.navigator.userAgent)};var S=/Version\\/[\\d\\.]+.*Safari/;c.isSafari=function(){return S.test(window.navigator.userAgent)};var E=/iPad|iPhone|iPod/;c.isIOS=function(){return E.test(window.navigator.userAgent)},c.isD3Selection=function(t){return t&&\"function\"==typeof t.classed},c.ensureSingle=function(t,e,r,n){var i=t.select(e+(r?\".\"+r:\"\"));if(i.size())return i;var a=t.append(e);return r&&a.classed(r,!0),n&&a.call(n),a},c.ensureSingleById=function(t,e,r,n){var i=t.select(e+\"#\"+r);if(i.size())return i;var a=t.append(e).attr(\"id\",r);return n&&a.call(n),a},c.objectFromPath=function(t,e){for(var r,n=t.split(\".\"),i=r={},a=0;a<n.length;a++){var o=n[a],s=null,l=n[a].match(/(.*)\\[([0-9]+)\\]/);l?(o=l[1],s=l[2],r=r[o]=[],a===n.length-1?r[s]=e:r[s]={},r=r[s]):(a===n.length-1?r[o]=e:r[o]={},r=r[o])}return i};var C=/^([^\\[\\.]+)\\.(.+)?/,L=/^([^\\.]+)\\[([0-9]+)\\](\\.)?(.+)?/;c.expandObjectPaths=function(t){var e,r,n,i,a,o,s;if(\"object\"==typeof t&&!Array.isArray(t))for(r in t)t.hasOwnProperty(r)&&((e=r.match(C))?(i=t[r],n=e[1],delete t[r],t[n]=c.extendDeepNoArrays(t[n]||{},c.objectFromPath(r,c.expandObjectPaths(i))[n])):(e=r.match(L))?(i=t[r],n=e[1],a=parseInt(e[2]),delete t[r],t[n]=t[n]||[],\".\"===e[3]?(s=e[4],o=t[n][a]=t[n][a]||{},c.extendDeepNoArrays(o,c.objectFromPath(s,c.expandObjectPaths(i)))):t[n][a]=c.expandObjectPaths(i)):t[r]=c.expandObjectPaths(t[r]));return t},c.numSeparate=function(t,e,r){if(r||(r=!1),\"string\"!=typeof e||0===e.length)throw new Error(\"Separator string required for formatting!\");\"number\"==typeof t&&(t=String(t));var n=/(\\d+)(\\d{3})/,i=e.charAt(0),a=e.charAt(1),o=t.split(\".\"),s=o[0],l=o.length>1?i+o[1]:\"\";if(a&&(o.length>1||s.length>4||r))for(;n.test(s);)s=s.replace(n,\"$1\"+a+\"$2\");return s+l},c.TEMPLATE_STRING_REGEX=/%{([^\\s%{}:]*)([:|\\|][^}]*)?}/g;var I=/^\\w*$/;c.templateString=function(t,e){var r={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,n){var i;return I.test(n)?i=e[n]:(r[n]=r[n]||c.nestedProperty(e,n).get,i=r[n]()),c.isValidTextValue(i)?i:\"\"}))};var P={max:10,count:0,name:\"hovertemplate\"};c.hovertemplateString=function(){return D.apply(P,arguments)};var z={max:10,count:0,name:\"texttemplate\"};c.texttemplateString=function(){return D.apply(z,arguments)};var O=/^[:|\\|]/;function D(t,e,r){var a=this,o=arguments;e||(e={});var s={};return t.replace(c.TEMPLATE_STRING_REGEX,(function(t,l,u){var f,h,p,d;for(p=3;p<o.length;p++)if(f=o[p]){if(f.hasOwnProperty(l)){h=f[l];break}if(I.test(l)||(h=s[l]||c.nestedProperty(f,l).get())&&(s[l]=h),void 0!==h)break}if(void 0===h&&a)return a.count<a.max&&(c.warn(\"Variable '\"+l+\"' in \"+a.name+\" could not be found!\"),h=t),a.count===a.max&&c.warn(\"Too many \"+a.name+\" warnings - additional warnings will be suppressed\"),a.count++,t;if(u){if(\":\"===u[0]&&(h=(d=r?r.numberFormat:n.format)(u.replace(O,\"\"))(h)),\"|\"===u[0]){d=r?r.timeFormat:i;var g=c.dateTime2ms(h);h=c.formatDate(g,u.replace(O,\"\"),!1,d)}}else e.hasOwnProperty(l+\"Label\")&&(h=e[l+\"Label\"]);return h}))}c.subplotSort=function(t,e){for(var r=Math.min(t.length,e.length)+1,n=0,i=0,a=0;a<r;a++){var o=t.charCodeAt(a)||0,s=e.charCodeAt(a)||0,l=o>=48&&o<=57,c=s>=48&&s<=57;if(l&&(n=10*n+o-48),c&&(i=10*i+s-48),!l||!c){if(n!==i)return n-i;if(o!==s)return o-s}}return i-n};var R=2e9;c.seedPseudoRandom=function(){R=2e9},c.pseudoRandom=function(){var t=R;return R=(69069*R+1)%4294967296,Math.abs(R-t)<429496729?c.pseudoRandom():R/4294967296},c.fillText=function(t,e,r){var n=Array.isArray(r)?function(t){r.push(t)}:function(t){r.text=t},i=c.extractOption(t,e,\"htx\",\"hovertext\");if(c.isValidTextValue(i))return n(i);var a=c.extractOption(t,e,\"tx\",\"text\");return c.isValidTextValue(a)?n(a):void 0},c.isValidTextValue=function(t){return t||0===t},c.formatPercent=function(t,e){e=e||0;for(var r=(Math.round(100*t*Math.pow(10,e))*Math.pow(.1,e)).toFixed(e)+\"%\",n=0;n<e;n++)-1!==r.indexOf(\".\")&&(r=(r=r.replace(\"0%\",\"%\")).replace(\".%\",\"%\"));return r},c.isHidden=function(t){var e=window.getComputedStyle(t).display;return!e||\"none\"===e},c.strTranslate=function(t,e){return t||e?\"translate(\"+t+\",\"+e+\")\":\"\"},c.strRotate=function(t){return t?\"rotate(\"+t+\")\":\"\"},c.strScale=function(t){return 1!==t?\"scale(\"+t+\")\":\"\"},c.getTextTransform=function(t){var e=t.noCenter,r=t.textX,n=t.textY,i=t.targetX,a=t.targetY,o=t.anchorX||0,s=t.anchorY||0,l=t.rotate,u=t.scale;return u?u>1&&(u=1):u=0,c.strTranslate(i-u*(r+o),a-u*(n+s))+c.strScale(u)+(l?\"rotate(\"+l+(e?\"\":\" \"+r+\" \"+n)+\")\":\"\")},c.ensureUniformFontSize=function(t,e){var r=c.extendFlat({},e);return r.size=Math.max(e.size,t._fullLayout.uniformtext.minsize||0),r},c.join2=function(t,e,r){var n=t.length;return n>1?t.slice(0,-1).join(e)+r+t[n-1]:t.join(e)}},{\"../constants/numerical\":753,\"./anchor_utils\":758,\"./angles\":759,\"./array\":760,\"./clean_number\":761,\"./clear_responsive\":763,\"./coerce\":764,\"./dates\":765,\"./dom\":766,\"./extend\":768,\"./filter_unique\":769,\"./filter_visible\":770,\"./geometry2d\":773,\"./identity\":776,\"./increment\":777,\"./is_plain_object\":779,\"./keyed_container\":780,\"./localize\":781,\"./loggers\":782,\"./make_trace_groups\":783,\"./matrix\":784,\"./mod\":785,\"./nested_property\":786,\"./noop\":787,\"./notifier\":788,\"./preserve_drawing_buffer\":792,\"./push_unique\":793,\"./regex\":795,\"./relative_attr\":796,\"./relink_private\":797,\"./search\":798,\"./stats\":801,\"./throttle\":804,\"./to_log_range\":805,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],779:[function(t,e,r){\"use strict\";e.exports=function(t){return window&&window.process&&window.process.versions?\"[object Object]\"===Object.prototype.toString.call(t):\"[object Object]\"===Object.prototype.toString.call(t)&&Object.getPrototypeOf(t)===Object.prototype}},{}],780:[function(t,e,r){\"use strict\";var n=t(\"./nested_property\"),i=/^\\w*$/;e.exports=function(t,e,r,a){var o,s,l;r=r||\"name\",a=a||\"value\";var c={};e&&e.length?(l=n(t,e),s=l.get()):s=t,e=e||\"\";var u={};if(s)for(o=0;o<s.length;o++)u[s[o][r]]=o;var f=i.test(a),h={set:function(t,e){var i=null===e?4:0;if(!s){if(!l||4===i)return;s=[],l.set(s)}var o=u[t];if(void 0===o){if(4===i)return;i|=3,o=s.length,u[t]=o}else e!==(f?s[o][a]:n(s[o],a).get())&&(i|=2);var p=s[o]=s[o]||{};return p[r]=t,f?p[a]=e:n(p,a).set(e),null!==e&&(i&=-5),c[o]=c[o]|i,h},get:function(t){if(s){var e=u[t];return void 0===e?void 0:f?s[e][a]:n(s[e],a).get()}},rename:function(t,e){var n=u[t];return void 0===n||(c[n]=1|c[n],u[e]=n,delete u[t],s[n][r]=e),h},remove:function(t){var e=u[t];if(void 0===e)return h;var i=s[e];if(Object.keys(i).length>2)return c[e]=2|c[e],h.set(t,null);if(f){for(o=e;o<s.length;o++)c[o]=3|c[o];for(o=e;o<s.length;o++)u[s[o][r]]--;s.splice(e,1),delete u[t]}else n(i,a).set(null),c[e]=6|c[e];return h},constructUpdate:function(){for(var t,i,o={},l=Object.keys(c),u=0;u<l.length;u++)i=l[u],t=e+\"[\"+i+\"]\",s[i]?(1&c[i]&&(o[t+\".\"+r]=s[i][r]),2&c[i]&&(o[t+\".\"+a]=f?4&c[i]?null:s[i][a]:4&c[i]?null:n(s[i],a).get())):o[t]=null;return o}};return h}},{\"./nested_property\":786}],781:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t,e){for(var r=t._context.locale,i=0;i<2;i++){for(var a=t._context.locales,o=0;o<2;o++){var s=(a[r]||{}).dictionary;if(s){var l=s[e];if(l)return l}a=n.localeRegistry}var c=r.split(\"-\")[0];if(c===r)break;r=c}return e}},{\"../registry\":911}],782:[function(t,e,r){\"use strict\";var n=t(\"../plot_api/plot_config\").dfltConfig,i=t(\"./notifier\"),a=e.exports={};function o(t,e){if(t&&t.apply)try{return void t.apply(console,e)}catch(t){}for(var r=0;r<e.length;r++)try{t(e[r])}catch(t){console.log(e[r])}}a.log=function(){var t;if(n.logging>1){var e=[\"LOG:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>1){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"long\")}},a.warn=function(){var t;if(n.logging>0){var e=[\"WARN:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.trace||console.log,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}},a.error=function(){var t;if(n.logging>0){var e=[\"ERROR:\"];for(t=0;t<arguments.length;t++)e.push(arguments[t]);o(console.error,e)}if(n.notifyOnLogging>0){var r=[];for(t=0;t<arguments.length;t++)r.push(arguments[t]);i(r.join(\"<br>\"),\"stick\")}}},{\"../plot_api/plot_config\":815,\"./notifier\":788}],783:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t,e,r){var i=t.selectAll(\"g.\"+r.replace(/\\s/g,\".\")).data(e,(function(t){return t[0].trace.uid}));i.exit().remove(),i.enter().append(\"g\").attr(\"class\",r),i.order();var a=t.classed(\"rangeplot\")?\"nodeRangePlot3\":\"node3\";return i.each((function(t){t[0][a]=n.select(this)})),i}},{d3:169}],784:[function(t,e,r){\"use strict\";var n=t(\"gl-mat4\");r.init2dArray=function(t,e){for(var r=new Array(t),n=0;n<t;n++)r[n]=new Array(e);return r},r.transposeRagged=function(t){var e,r,n=0,i=t.length;for(e=0;e<i;e++)n=Math.max(n,t[e].length);var a=new Array(n);for(e=0;e<n;e++)for(a[e]=new Array(i),r=0;r<i;r++)a[e][r]=t[r][e];return a},r.dot=function(t,e){if(!t.length||!e.length||t.length!==e.length)return null;var n,i,a=t.length;if(t[0].length)for(n=new Array(a),i=0;i<a;i++)n[i]=r.dot(t[i],e);else if(e[0].length){var o=r.transposeRagged(e);for(n=new Array(o.length),i=0;i<o.length;i++)n[i]=r.dot(t,o[i])}else for(n=0,i=0;i<a;i++)n+=t[i]*e[i];return n},r.translationMatrix=function(t,e){return[[1,0,t],[0,1,e],[0,0,1]]},r.rotationMatrix=function(t){var e=t*Math.PI/180;return[[Math.cos(e),-Math.sin(e),0],[Math.sin(e),Math.cos(e),0],[0,0,1]]},r.rotationXYMatrix=function(t,e,n){return r.dot(r.dot(r.translationMatrix(e,n),r.rotationMatrix(t)),r.translationMatrix(-e,-n))},r.apply3DTransform=function(t){return function(){var e=arguments,n=1===arguments.length?e[0]:[e[0],e[1],e[2]||0];return r.dot(t,[n[0],n[1],n[2],1]).slice(0,3)}},r.apply2DTransform=function(t){return function(){var e=arguments;3===e.length&&(e=e[0]);var n=1===arguments.length?e[0]:[e[0],e[1]];return r.dot(t,[n[0],n[1],1]).slice(0,2)}},r.apply2DTransform2=function(t){var e=r.apply2DTransform(t);return function(t){return e(t.slice(0,2)).concat(e(t.slice(2,4)))}},r.convertCssMatrix=function(t){if(t){var e=t.length;if(16===e)return t;if(6===e)return[t[0],t[1],0,0,t[2],t[3],0,0,0,0,1,0,t[4],t[5],0,1]}return[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1]},r.inverseTransformMatrix=function(t){var e=[];return n.invert(e,t),[[e[0],e[1],e[2],e[3]],[e[4],e[5],e[6],e[7]],[e[8],e[9],e[10],e[11]],[e[12],e[13],e[14],e[15]]]}},{\"gl-mat4\":292}],785:[function(t,e,r){\"use strict\";e.exports={mod:function(t,e){var r=t%e;return r<0?r+e:r},modHalf:function(t,e){return Math.abs(t)>e/2?t-Math.round(t/e)*e:t}}},{}],786:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;function a(t,e){return function(){var r,n,o,s,l,c=t;for(s=0;s<e.length-1;s++){if(-1===(r=e[s])){for(n=!0,o=[],l=0;l<c.length;l++)o[l]=a(c[l],e.slice(s+1))(),o[l]!==o[0]&&(n=!1);return n?o[0]:o}if(\"number\"==typeof r&&!i(c))return;if(\"object\"!=typeof(c=c[r])||null===c)return}if(\"object\"==typeof c&&null!==c&&null!==(o=c[e[s]]))return o}}e.exports=function(t,e){if(n(e))e=String(e);else if(\"string\"!=typeof e||\"[-1]\"===e.substr(e.length-4))throw\"bad property string\";for(var r,i,o,s=0,c=e.split(\".\");s<c.length;){if(r=String(c[s]).match(/^([^\\[\\]]*)((\\[\\-?[0-9]*\\])+)$/)){if(r[1])c[s]=r[1];else{if(0!==s)throw\"bad property string\";c.splice(0,1)}for(i=r[2].substr(1,r[2].length-2).split(\"][\"),o=0;o<i.length;o++)s++,c.splice(s,0,Number(i[o]))}s++}return\"object\"!=typeof t?function(t,e,r){return{set:function(){throw\"bad container\"},get:function(){},astr:e,parts:r,obj:t}}(t,e,c):{set:l(t,c,e),get:a(t,c),astr:e,parts:c,obj:t}};var o=/(^|\\.)args\\[/;function s(t,e){return void 0===t||null===t&&!e.match(o)}function l(t,e,r){return function(n){var a,o,l=t,h=\"\",p=[[t,h]],d=s(n,r);for(o=0;o<e.length-1;o++){if(\"number\"==typeof(a=e[o])&&!i(l))throw\"array index but container is not an array\";if(-1===a){if(d=!u(l,e.slice(o+1),n,r))break;return}if(!f(l,a,e[o+1],d))break;if(\"object\"!=typeof(l=l[a])||null===l)throw\"container is not an object\";h=c(h,a),p.push([l,h])}if(d){if(o===e.length-1&&(delete l[e[o]],Array.isArray(l)&&+e[o]==l.length-1))for(;l.length&&void 0===l[l.length-1];)l.pop()}else l[e[o]]=n}}function c(t,e){var r=e;return n(e)?r=\"[\"+e+\"]\":t&&(r=\".\"+e),t+r}function u(t,e,r,n){var a,o=i(r),c=!0,u=r,h=n.replace(\"-1\",0),p=!o&&s(r,h),d=e[0];for(a=0;a<t.length;a++)h=n.replace(\"-1\",a),o&&(p=s(u=r[a%r.length],h)),p&&(c=!1),f(t,a,d,p)&&l(t[a],e,n.replace(\"-1\",a))(u);return c}function f(t,e,r,n){if(void 0===t[e]){if(n)return!1;t[e]=\"number\"==typeof r?[]:{}}return!0}},{\"./array\":760,\"fast-isnumeric\":241}],787:[function(t,e,r){\"use strict\";e.exports=function(){}},{}],788:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=[];e.exports=function(t,e){if(-1===a.indexOf(t)){a.push(t);var r=1e3;i(e)?r=e:\"long\"===e&&(r=3e3);var o=n.select(\"body\").selectAll(\".plotly-notifier\").data([0]);o.enter().append(\"div\").classed(\"plotly-notifier\",!0),o.selectAll(\".notifier-note\").data(a).enter().append(\"div\").classed(\"notifier-note\",!0).style(\"opacity\",0).each((function(t){var i=n.select(this);i.append(\"button\").classed(\"notifier-close\",!0).html(\"&times;\").on(\"click\",(function(){i.transition().call(s)}));for(var a=i.append(\"p\"),o=t.split(/<br\\s*\\/?>/g),l=0;l<o.length;l++)l&&a.append(\"br\"),a.append(\"span\").text(o[l]);\"stick\"===e?i.transition().duration(350).style(\"opacity\",1):i.transition().duration(700).style(\"opacity\",1).transition().delay(r).call(s)}))}function s(t){t.duration(700).style(\"opacity\",0).each(\"end\",(function(t){var e=a.indexOf(t);-1!==e&&a.splice(e,1),n.select(this).remove()}))}}},{d3:169,\"fast-isnumeric\":241}],789:[function(t,e,r){\"use strict\";var n=t(\"./setcursor\"),i=\"data-savedcursor\";e.exports=function(t,e){var r=t.attr(i);if(e){if(!r){for(var a=(t.attr(\"class\")||\"\").split(\" \"),o=0;o<a.length;o++){var s=a[o];0===s.indexOf(\"cursor-\")&&t.attr(i,s.substr(7)).classed(s,!1)}t.attr(i)||t.attr(i,\"!!\")}n(t,e)}else r&&(t.attr(i,null),\"!!\"===r?n(t):n(t,r))}},{\"./setcursor\":799}],790:[function(t,e,r){\"use strict\";var n=t(\"./matrix\").dot,i=t(\"../constants/numerical\").BADNUM,a=e.exports={};a.tester=function(t){var e,r=t.slice(),n=r[0][0],a=n,o=r[0][1],s=o;for(r.push(r[0]),e=1;e<r.length;e++)n=Math.min(n,r[e][0]),a=Math.max(a,r[e][0]),o=Math.min(o,r[e][1]),s=Math.max(s,r[e][1]);var l,c=!1;5===r.length&&(r[0][0]===r[1][0]?r[2][0]===r[3][0]&&r[0][1]===r[3][1]&&r[1][1]===r[2][1]&&(c=!0,l=function(t){return t[0]===r[0][0]}):r[0][1]===r[1][1]&&r[2][1]===r[3][1]&&r[0][0]===r[3][0]&&r[1][0]===r[2][0]&&(c=!0,l=function(t){return t[1]===r[0][1]}));var u=!0,f=r[0];for(e=1;e<r.length;e++)if(f[0]!==r[e][0]||f[1]!==r[e][1]){u=!1;break}return{xmin:n,xmax:a,ymin:o,ymax:s,pts:r,contains:c?function(t,e){var r=t[0],c=t[1];return!(r===i||r<n||r>a||c===i||c<o||c>s)&&(!e||!l(t))}:function(t,e){var l=t[0],c=t[1];if(l===i||l<n||l>a||c===i||c<o||c>s)return!1;var u,f,h,p,d,g=r.length,m=r[0][0],v=r[0][1],y=0;for(u=1;u<g;u++)if(f=m,h=v,m=r[u][0],v=r[u][1],!(l<(p=Math.min(f,m))||l>Math.max(f,m)||c>Math.max(h,v)))if(c<Math.min(h,v))l!==p&&y++;else{if(c===(d=m===f?c:h+(l-f)*(v-h)/(m-f)))return 1!==u||!e;c<=d&&l!==p&&y++}return y%2==1},isRect:c,degenerate:u}},a.isSegmentBent=function(t,e,r,i){var a,o,s,l=t[e],c=[t[r][0]-l[0],t[r][1]-l[1]],u=n(c,c),f=Math.sqrt(u),h=[-c[1]/f,c[0]/f];for(a=e+1;a<r;a++)if(o=[t[a][0]-l[0],t[a][1]-l[1]],(s=n(o,c))<0||s>u||Math.abs(n(o,h))>i)return!0;return!1},a.filter=function(t,e){var r=[t[0]],n=0,i=0;function o(o){t.push(o);var s=r.length,l=n;r.splice(i+1);for(var c=l+1;c<t.length;c++)(c===t.length-1||a.isSegmentBent(t,l,c+1,e))&&(r.push(t[c]),r.length<s-2&&(n=c,i=r.length-1),l=c)}t.length>1&&o(t.pop());return{addPt:o,raw:t,filtered:r}}},{\"../constants/numerical\":753,\"./matrix\":784}],791:[function(t,e,r){(function(r){(function(){\"use strict\";var n=t(\"./show_no_webgl_msg\"),i=t(\"regl\");e.exports=function(t,e){var a=t._fullLayout,o=!0;return a._glcanvas.each((function(n){if(!n.regl&&(!n.pick||a._has(\"parcoords\"))){try{n.regl=i({canvas:this,attributes:{antialias:!n.pick,preserveDrawingBuffer:!0},pixelRatio:t._context.plotGlPixelRatio||r.devicePixelRatio,extensions:e||[]})}catch(t){o=!1}n.regl||(o=!1),o&&this.addEventListener(\"webglcontextlost\",(function(e){t&&t.emit&&t.emit(\"plotly_webglcontextlost\",{event:e,layer:n.key})}),!1)}})),o||n({container:a._glcontainer.node()}),o}}).call(this)}).call(this,\"undefined\"!=typeof global?global:\"undefined\"!=typeof self?self:\"undefined\"!=typeof window?window:{})},{\"./show_no_webgl_msg\":800,regl:540}],792:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"is-mobile\");e.exports=function(t){var e;if(\"string\"!=typeof(e=t&&t.hasOwnProperty(\"userAgent\")?t.userAgent:function(){var t;\"undefined\"!=typeof navigator&&(t=navigator.userAgent);t&&t.headers&&\"string\"==typeof t.headers[\"user-agent\"]&&(t=t.headers[\"user-agent\"]);return t}()))return!0;var r=i({ua:{headers:{\"user-agent\":e}},tablet:!0,featureDetect:!1});if(!r)for(var a=e.split(\" \"),o=1;o<a.length;o++){if(-1!==a[o].indexOf(\"Safari\"))for(var s=o-1;s>-1;s--){var l=a[s];if(\"Version/\"===l.substr(0,8)){var c=l.substr(8).split(\".\")[0];if(n(c)&&(c=+c),c>=13)return!0}}}return r}},{\"fast-isnumeric\":241,\"is-mobile\":467}],793:[function(t,e,r){\"use strict\";e.exports=function(t,e){if(e instanceof RegExp){for(var r=e.toString(),n=0;n<t.length;n++)if(t[n]instanceof RegExp&&t[n].toString()===r)return t;t.push(e)}else!e&&0!==e||-1!==t.indexOf(e)||t.push(e);return t}},{}],794:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_config\").dfltConfig;var a={add:function(t,e,r,n,a){var o,s;t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},s=t.undoQueue.index,t.autoplay?t.undoQueue.inSequence||(t.autoplay=!1):(!t.undoQueue.sequence||t.undoQueue.beginSequence?(o={undo:{calls:[],args:[]},redo:{calls:[],args:[]}},t.undoQueue.queue.splice(s,t.undoQueue.queue.length-s,o),t.undoQueue.index+=1):o=t.undoQueue.queue[s-1],t.undoQueue.beginSequence=!1,o&&(o.undo.calls.unshift(e),o.undo.args.unshift(r),o.redo.calls.push(n),o.redo.args.push(a)),t.undoQueue.queue.length>i.queueLength&&(t.undoQueue.queue.shift(),t.undoQueue.index--))},startSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!0,t.undoQueue.beginSequence=!0},stopSequence:function(t){t.undoQueue=t.undoQueue||{index:0,queue:[],sequence:!1},t.undoQueue.sequence=!1,t.undoQueue.beginSequence=!1},undo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.undo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index<=0)){for(t.undoQueue.index--,e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.undo.calls.length;r++)a.plotDo(t,e.undo.calls[r],e.undo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1}},redo:function(t){var e,r;if(t.framework&&t.framework.isPolar)t.framework.redo();else if(!(void 0===t.undoQueue||isNaN(t.undoQueue.index)||t.undoQueue.index>=t.undoQueue.queue.length)){for(e=t.undoQueue.queue[t.undoQueue.index],t.undoQueue.inSequence=!0,r=0;r<e.redo.calls.length;r++)a.plotDo(t,e.redo.calls[r],e.redo.args[r]);t.undoQueue.inSequence=!1,t.autoplay=!1,t.undoQueue.index++}}};a.plotDo=function(t,e,r){t.autoplay=!0,r=function(t,e){for(var r,i=[],a=0;a<e.length;a++)r=e[a],i[a]=r===t?r:\"object\"==typeof r?Array.isArray(r)?n.extendDeep([],r):n.extendDeepAll({},r):r;return i}(t,r),e.apply(null,r)},e.exports=a},{\"../lib\":778,\"../plot_api/plot_config\":815}],795:[function(t,e,r){\"use strict\";r.counter=function(t,e,r,n){var i=(e||\"\")+(r?\"\":\"$\"),a=!1===n?\"\":\"^\";return\"xy\"===t?new RegExp(a+\"x([2-9]|[1-9][0-9]+)?y([2-9]|[1-9][0-9]+)?\"+i):new RegExp(a+t+\"([2-9]|[1-9][0-9]+)?\"+i)}},{}],796:[function(t,e,r){\"use strict\";var n=/^(.*)(\\.[^\\.\\[\\]]+|\\[\\d\\])$/,i=/^[^\\.\\[\\]]+$/;e.exports=function(t,e){for(;e;){var r=t.match(n);if(r)t=r[1];else{if(!t.match(i))throw new Error(\"bad relativeAttr call:\"+[t,e]);t=\"\"}if(\"^\"!==e.charAt(0))break;e=e.slice(1)}return t&&\"[\"!==e.charAt(0)?t+\".\"+e:t+e}},{}],797:[function(t,e,r){\"use strict\";var n=t(\"./array\").isArrayOrTypedArray,i=t(\"./is_plain_object\");e.exports=function t(e,r){for(var a in r){var o=r[a],s=e[a];if(s!==o)if(\"_\"===a.charAt(0)||\"function\"==typeof o){if(a in e)continue;e[a]=o}else if(n(o)&&n(s)&&i(o[0])){if(\"customdata\"===a||\"ids\"===a)continue;for(var l=Math.min(o.length,s.length),c=0;c<l;c++)s[c]!==o[c]&&i(o[c])&&i(s[c])&&t(s[c],o[c])}else i(o)&&i(s)&&(t(s,o),Object.keys(s).length||delete e[a])}}},{\"./array\":760,\"./is_plain_object\":779}],798:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./loggers\"),a=t(\"./identity\"),o=t(\"../constants/numerical\").BADNUM;function s(t,e){return t<e}function l(t,e){return t<=e}function c(t,e){return t>e}function u(t,e){return t>=e}r.findBin=function(t,e,r){if(n(e.start))return r?Math.ceil((t-e.start)/e.size-1e-9)-1:Math.floor((t-e.start)/e.size+1e-9);var a,o,f=0,h=e.length,p=0,d=h>1?(e[h-1]-e[0])/(h-1):1;for(o=d>=0?r?s:l:r?u:c,t+=1e-9*d*(r?-1:1)*(d>=0?1:-1);f<h&&p++<100;)o(e[a=Math.floor((f+h)/2)],t)?f=a+1:h=a;return p>90&&i.log(\"Long binary search...\"),f-1},r.sorterAsc=function(t,e){return t-e},r.sorterDes=function(t,e){return e-t},r.distinctVals=function(t,e){var n,i=(e||{}).unitMinDiff,a=t.slice();for(a.sort(r.sorterAsc),n=a.length-1;n>-1&&a[n]===o;n--);var s=1;i||(s=a[n]-a[0]||1);for(var l,c=s/(n||1)/1e4,u=[],f=0;f<=n;f++){var h=a[f],p=h-l;void 0===l?(u.push(h),l=h):p>c&&(s=Math.min(s,p),u.push(h),l=h)}return{vals:u,minDiff:s}},r.roundUp=function(t,e,r){for(var n,i=0,a=e.length-1,o=0,s=r?0:1,l=r?1:0,c=r?Math.ceil:Math.floor;i<a&&o++<100;)e[n=c((i+a)/2)]<=t?i=n+s:a=n-l;return e[i]},r.sort=function(t,e){for(var r=0,n=0,i=1;i<t.length;i++){var a=e(t[i],t[i-1]);if(a<0?r=1:a>0&&(n=1),r&&n)return t.sort(e)}return n?t:t.reverse()},r.findIndexOfMin=function(t,e){e=e||a;for(var r,n=1/0,i=0;i<t.length;i++){var o=e(t[i]);o<n&&(n=o,r=i)}return r}},{\"../constants/numerical\":753,\"./identity\":776,\"./loggers\":782,\"fast-isnumeric\":241}],799:[function(t,e,r){\"use strict\";e.exports=function(t,e){(t.attr(\"class\")||\"\").split(\" \").forEach((function(e){0===e.indexOf(\"cursor-\")&&t.classed(e,!1)})),e&&t.classed(\"cursor-\"+e,!0)}},{}],800:[function(t,e,r){\"use strict\";var n=t(\"../components/color\"),i=function(){};e.exports=function(t){for(var e in t)\"function\"==typeof t[e]&&(t[e]=i);t.destroy=function(){t.container.parentNode.removeChild(t.container)};var r=document.createElement(\"div\");r.className=\"no-webgl\",r.style.cursor=\"pointer\",r.style.fontSize=\"24px\",r.style.color=n.defaults[0],r.style.position=\"absolute\",r.style.left=r.style.top=\"0px\",r.style.width=r.style.height=\"100%\",r.style[\"background-color\"]=n.lightLine,r.style[\"z-index\"]=30;var a=document.createElement(\"p\");return a.textContent=\"WebGL is not supported by your browser - visit https://get.webgl.org for more info\",a.style.position=\"relative\",a.style.top=\"50%\",a.style.left=\"50%\",a.style.height=\"30%\",a.style.width=\"50%\",a.style.margin=\"-15% 0 0 -25%\",r.appendChild(a),t.container.appendChild(r),t.container.style.background=\"#FFFFFF\",t.container.onclick=function(){window.open(\"https://get.webgl.org\")},!1}},{\"../components/color\":643}],801:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./array\").isArrayOrTypedArray;r.aggNums=function(t,e,a,o){var s,l;if((!o||o>a.length)&&(o=a.length),n(e)||(e=!1),i(a[0])){for(l=new Array(o),s=0;s<o;s++)l[s]=r.aggNums(t,e,a[s]);a=l}for(s=0;s<o;s++)n(e)?n(a[s])&&(e=t(+e,+a[s])):e=a[s];return e},r.len=function(t){return r.aggNums((function(t){return t+1}),0,t)},r.mean=function(t,e){return e||(e=r.len(t)),r.aggNums((function(t,e){return t+e}),0,t)/e},r.midRange=function(t){if(void 0!==t&&0!==t.length)return(r.aggNums(Math.max,null,t)+r.aggNums(Math.min,null,t))/2},r.variance=function(t,e,i){return e||(e=r.len(t)),n(i)||(i=r.mean(t,e)),r.aggNums((function(t,e){return t+Math.pow(e-i,2)}),0,t)/e},r.stdev=function(t,e,n){return Math.sqrt(r.variance(t,e,n))},r.median=function(t){var e=t.slice().sort();return r.interp(e,.5)},r.interp=function(t,e){if(!n(e))throw\"n should be a finite number\";if((e=e*t.length-.5)<0)return t[0];if(e>t.length-1)return t[t.length-1];var r=e%1;return r*t[Math.ceil(e)]+(1-r)*t[Math.floor(e)]}},{\"./array\":760,\"fast-isnumeric\":241}],802:[function(t,e,r){\"use strict\";var n=t(\"color-normalize\");e.exports=function(t){return t?n(t):[0,0,0,1]}},{\"color-normalize\":125}],803:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=i.strTranslate,o=t(\"../constants/xmlns_namespaces\"),s=t(\"../constants/alignment\").LINE_SPACING;function l(t,e){return t.node().getBoundingClientRect()[e]}var c=/([^$]*)([$]+[^$]*[$]+)([^$]*)/;r.convertToTspans=function(t,e,A){var S=t.text(),C=!t.attr(\"data-notex\")&&\"undefined\"!=typeof MathJax&&S.match(c),L=n.select(t.node().parentNode);if(!L.empty()){var I=t.attr(\"class\")?t.attr(\"class\").split(\" \")[0]:\"text\";return I+=\"-math\",L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove(),t.style(\"display\",null).attr({\"data-unformatted\":S,\"data-math\":\"N\"}),C?(e&&e._promises||[]).push(new Promise((function(e){t.style(\"display\",\"none\");var r=parseInt(t.node().style.fontSize,10),o={fontSize:r};!function(t,e,r){var a,o,s,l;MathJax.Hub.Queue((function(){return o=i.extendDeepAll({},MathJax.Hub.config),s=MathJax.Hub.processSectionDelay,void 0!==MathJax.Hub.processSectionDelay&&(MathJax.Hub.processSectionDelay=0),MathJax.Hub.Config({messageStyle:\"none\",tex2jax:{inlineMath:[[\"$\",\"$\"],[\"\\\\(\",\"\\\\)\"]]},displayAlign:\"left\"})}),(function(){if(\"SVG\"!==(a=MathJax.Hub.config.menuSettings.renderer))return MathJax.Hub.setRenderer(\"SVG\")}),(function(){var r=\"math-output-\"+i.randstr({},64);return l=n.select(\"body\").append(\"div\").attr({id:r}).style({visibility:\"hidden\",position:\"absolute\"}).style({\"font-size\":e.fontSize+\"px\"}).text(t.replace(u,\"\\\\lt \").replace(f,\"\\\\gt \")),MathJax.Hub.Typeset(l.node())}),(function(){var e=n.select(\"body\").select(\"#MathJax_SVG_glyphs\");if(l.select(\".MathJax_SVG\").empty()||!l.select(\"svg\").node())i.log(\"There was an error in the tex syntax.\",t),r();else{var o=l.select(\"svg\").node().getBoundingClientRect();r(l.select(\".MathJax_SVG\"),e,o)}if(l.remove(),\"SVG\"!==a)return MathJax.Hub.setRenderer(a)}),(function(){return void 0!==s&&(MathJax.Hub.processSectionDelay=s),MathJax.Hub.Config(o)}))}(C[2],o,(function(n,i,o){L.selectAll(\"svg.\"+I).remove(),L.selectAll(\"g.\"+I+\"-group\").remove();var s=n&&n.select(\"svg\");if(!s||!s.node())return P(),void e();var c=L.append(\"g\").classed(I+\"-group\",!0).attr({\"pointer-events\":\"none\",\"data-unformatted\":S,\"data-math\":\"Y\"});c.node().appendChild(s.node()),i&&i.node()&&s.node().insertBefore(i.node().cloneNode(!0),s.node().firstChild),s.attr({class:I,height:o.height,preserveAspectRatio:\"xMinYMin meet\"}).style({overflow:\"visible\",\"pointer-events\":\"none\"});var u=t.node().style.fill||\"black\",f=s.select(\"g\");f.attr({fill:u,stroke:u});var h=l(f,\"width\"),p=l(f,\"height\"),d=+t.attr(\"x\")-h*{start:0,middle:.5,end:1}[t.attr(\"text-anchor\")||\"start\"],g=-(r||l(t,\"height\"))/4;\"y\"===I[0]?(c.attr({transform:\"rotate(\"+[-90,+t.attr(\"x\"),+t.attr(\"y\")]+\")\"+a(-h/2,g-p/2)}),s.attr({x:+t.attr(\"x\"),y:+t.attr(\"y\")})):\"l\"===I[0]?s.attr({x:t.attr(\"x\"),y:g-p/2}):\"a\"===I[0]&&0!==I.indexOf(\"atitle\")?s.attr({x:0,y:g}):s.attr({x:d,y:+t.attr(\"y\")+g-p/2}),A&&A.call(t,c),e(c)}))}))):P(),t}function P(){L.empty()||(I=t.attr(\"class\")+\"-math\",L.select(\"svg.\"+I).remove()),t.text(\"\").style(\"white-space\",\"pre\"),function(t,e){e=e.replace(m,\" \");var r,a=!1,l=[],c=-1;function u(){c++;var e=document.createElementNS(o.svg,\"tspan\");n.select(e).attr({class:\"line\",dy:c*s+\"em\"}),t.appendChild(e),r=e;var i=l;if(l=[{node:e}],i.length>1)for(var a=1;a<i.length;a++)f(i[a])}function f(t){var e,i=t.type,a={};if(\"a\"===i){e=\"a\";var s=t.target,c=t.href,u=t.popup;c&&(a={\"xlink:xlink:show\":\"_blank\"===s||\"_\"!==s.charAt(0)?\"new\":\"replace\",target:s,\"xlink:xlink:href\":c},u&&(a.onclick='window.open(this.href.baseVal,this.target.baseVal,\"'+u+'\");return false;'))}else e=\"tspan\";t.style&&(a.style=t.style);var f=document.createElementNS(o.svg,e);if(\"sup\"===i||\"sub\"===i){A(r,\"\\u200b\"),r.appendChild(f);var h=document.createElementNS(o.svg,\"tspan\");A(h,\"\\u200b\"),n.select(h).attr(\"dy\",d[i]),a.dy=p[i],r.appendChild(f),r.appendChild(h)}else r.appendChild(f);n.select(f).attr(a),r=t.node=f,l.push(t)}function A(t,e){t.appendChild(document.createTextNode(e))}function S(t){if(1!==l.length){var n=l.pop();t!==n.type&&i.log(\"Start tag <\"+n.type+\"> doesnt match end tag <\"+t+\">. Pretending it did match.\",e),r=l[l.length-1].node}else i.log(\"Ignoring unexpected end tag </\"+t+\">.\",e)}x.test(e)?u():(r=t,l=[{node:t}]);for(var C=e.split(v),L=0;L<C.length;L++){var I=C[L],P=I.match(y),z=P&&P[2].toLowerCase(),O=h[z];if(\"br\"===z)u();else if(void 0===O)A(r,E(I));else if(P[1])S(z);else{var D=P[4],R={type:z},F=k(D,b);if(F?(F=F.replace(M,\"$1 fill:\"),O&&(F+=\";\"+O)):O&&(F=O),F&&(R.style=F),\"a\"===z){a=!0;var B=k(D,_);if(B){var N=document.createElement(\"a\");N.href=B,-1!==g.indexOf(N.protocol)&&(R.href=encodeURI(decodeURI(B)),R.target=k(D,w)||\"_blank\",R.popup=k(D,T))}}f(R)}}return a}(t.node(),S)&&t.style(\"pointer-events\",\"all\"),r.positionText(t),A&&A.call(t)}};var u=/(<|&lt;|&#60;)/g,f=/(>|&gt;|&#62;)/g;var h={sup:\"font-size:70%\",sub:\"font-size:70%\",b:\"font-weight:bold\",i:\"font-style:italic\",a:\"cursor:pointer\",span:\"\",em:\"font-style:italic;font-weight:bold\"},p={sub:\"0.3em\",sup:\"-0.6em\"},d={sub:\"-0.21em\",sup:\"0.42em\"},g=[\"http:\",\"https:\",\"mailto:\",\"\",void 0,\":\"],m=r.NEWLINES=/(\\r\\n?|\\n)/g,v=/(<[^<>]*>)/,y=/<(\\/?)([^ >]*)(\\s+(.*))?>/i,x=/<br(\\s+.*)?>/i;r.BR_TAG_ALL=/<br(\\s+.*)?>/gi;var b=/(^|[\\s\"'])style\\s*=\\s*(\"([^\"]*);?\"|'([^']*);?')/i,_=/(^|[\\s\"'])href\\s*=\\s*(\"([^\"]*)\"|'([^']*)')/i,w=/(^|[\\s\"'])target\\s*=\\s*(\"([^\"\\s]*)\"|'([^'\\s]*)')/i,T=/(^|[\\s\"'])popup\\s*=\\s*(\"([\\w=,]*)\"|'([\\w=,]*)')/i;function k(t,e){if(!t)return null;var r=t.match(e),n=r&&(r[3]||r[4]);return n&&E(n)}var M=/(^|;)\\s*color:/;r.plainText=function(t,e){for(var r=void 0!==(e=e||{}).len&&-1!==e.len?e.len:1/0,n=void 0!==e.allowedTags?e.allowedTags:[\"br\"],i=\"...\".length,a=t.split(v),o=[],s=\"\",l=0,c=0;c<a.length;c++){var u=a[c],f=u.match(y),h=f&&f[2].toLowerCase();if(h)-1!==n.indexOf(h)&&(o.push(u),s=h);else{var p=u.length;if(l+p<r)o.push(u),l+=p;else if(l<r){var d=r-l;s&&(\"br\"!==s||d<=i||p<=i)&&o.pop(),r>i?o.push(u.substr(0,d-i)+\"...\"):o.push(u.substr(0,d));break}s=\"\"}}return o.join(\"\")};var A={mu:\"\\u03bc\",amp:\"&\",lt:\"<\",gt:\">\",nbsp:\"\\xa0\",times:\"\\xd7\",plusmn:\"\\xb1\",deg:\"\\xb0\"},S=/&(#\\d+|#x[\\da-fA-F]+|[a-z]+);/g;function E(t){return t.replace(S,(function(t,e){return(\"#\"===e.charAt(0)?function(t){if(t>1114111)return;var e=String.fromCodePoint;if(e)return e(t);var r=String.fromCharCode;return t<=65535?r(t):r(55232+(t>>10),t%1024+56320)}(\"x\"===e.charAt(1)?parseInt(e.substr(2),16):parseInt(e.substr(1),10)):A[e])||t}))}function C(t,e,r){var n,a,o,s=r.horizontalAlign,l=r.verticalAlign||\"top\",c=t.node().getBoundingClientRect(),u=e.node().getBoundingClientRect();return a=\"bottom\"===l?function(){return c.bottom-n.height}:\"middle\"===l?function(){return c.top+(c.height-n.height)/2}:function(){return c.top},o=\"right\"===s?function(){return c.right-n.width}:\"center\"===s?function(){return c.left+(c.width-n.width)/2}:function(){return c.left},function(){n=this.node().getBoundingClientRect();var t=o()-u.left,e=a()-u.top,s=r.gd||{};if(r.gd){s._fullLayout._calcInverseTransform(s);var l=i.apply3DTransform(s._fullLayout._invTransform)(t,e);t=l[0],e=l[1]}return this.style({top:e+\"px\",left:t+\"px\",\"z-index\":1e3}),this}}r.convertEntities=E,r.sanitizeHTML=function(t){t=t.replace(m,\" \");for(var e=document.createElement(\"p\"),r=e,i=[],a=t.split(v),o=0;o<a.length;o++){var s=a[o],l=s.match(y),c=l&&l[2].toLowerCase();if(c in h)if(l[1])i.length&&(r=i.pop());else{var u=l[4],f=k(u,b),p=f?{style:f}:{};if(\"a\"===c){var d=k(u,_);if(d){var x=document.createElement(\"a\");if(x.href=d,-1!==g.indexOf(x.protocol)){p.href=encodeURI(decodeURI(d));var T=k(u,w);T&&(p.target=T)}}}var M=document.createElement(c);r.appendChild(M),n.select(M).attr(p),r=M,i.push(M)}else r.appendChild(document.createTextNode(E(s)))}return e.innerHTML},r.lineCount=function(t){return t.selectAll(\"tspan.line\").size()||1},r.positionText=function(t,e,r){return t.each((function(){var t=n.select(this);function i(e,r){return void 0===r?null===(r=t.attr(e))&&(t.attr(e,0),r=0):t.attr(e,r),r}var a=i(\"x\",e),o=i(\"y\",r);\"text\"===this.nodeName&&t.selectAll(\"tspan.line\").attr({x:a,y:o})}))},r.makeEditable=function(t,e){var r=e.gd,i=e.delegate,a=n.dispatch(\"edit\",\"input\",\"cancel\"),o=i||t;if(t.style({\"pointer-events\":i?\"none\":\"all\"}),1!==t.size())throw new Error(\"boo\");function s(){!function(){var i=n.select(r).select(\".svg-container\"),o=i.append(\"div\"),s=t.node().style,c=parseFloat(s.fontSize||12),u=e.text;void 0===u&&(u=t.attr(\"data-unformatted\"));o.classed(\"plugin-editable editable\",!0).style({position:\"absolute\",\"font-family\":s.fontFamily||\"Arial\",\"font-size\":c,color:e.fill||s.fill||\"black\",opacity:1,\"background-color\":e.background||\"transparent\",outline:\"#ffffff33 1px solid\",margin:[-c/8+1,0,0,-1].join(\"px \")+\"px\",padding:\"0\",\"box-sizing\":\"border-box\"}).attr({contenteditable:!0}).text(u).call(C(t,i,e)).on(\"blur\",(function(){r._editing=!1,t.text(this.textContent).style({opacity:1});var e,i=n.select(this).attr(\"class\");(e=i?\".\"+i.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(e).style({opacity:0});var o=this.textContent;n.select(this).transition().duration(0).remove(),n.select(document).on(\"mouseup\",null),a.edit.call(t,o)})).on(\"focus\",(function(){var t=this;r._editing=!0,n.select(document).on(\"mouseup\",(function(){if(n.event.target===t)return!1;document.activeElement===o.node()&&o.node().blur()}))})).on(\"keyup\",(function(){27===n.event.which?(r._editing=!1,t.style({opacity:1}),n.select(this).style({opacity:0}).on(\"blur\",(function(){return!1})).transition().remove(),a.cancel.call(t,this.textContent)):(a.input.call(t,this.textContent),n.select(this).call(C(t,i,e)))})).on(\"keydown\",(function(){13===n.event.which&&this.blur()})).call(l)}(),t.style({opacity:0});var i,s=o.attr(\"class\");(i=s?\".\"+s.split(\" \")[0]+\"-math-group\":\"[class*=-math-group]\")&&n.select(t.node().parentNode).select(i).style({opacity:0})}function l(t){var e=t.node(),r=document.createRange();r.selectNodeContents(e);var n=window.getSelection();n.removeAllRanges(),n.addRange(r),e.focus()}return e.immediate?s():o.on(\"click\",s),n.rebind(t,a,\"on\")}},{\"../constants/alignment\":745,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],804:[function(t,e,r){\"use strict\";var n={};function i(t){t&&null!==t.timer&&(clearTimeout(t.timer),t.timer=null)}r.throttle=function(t,e,r){var a=n[t],o=Date.now();if(!a){for(var s in n)n[s].ts<o-6e4&&delete n[s];a=n[t]={ts:0,timer:null}}function l(){r(),a.ts=Date.now(),a.onDone&&(a.onDone(),a.onDone=null)}i(a),o>a.ts+e?l():a.timer=setTimeout((function(){l(),a.timer=null}),e)},r.done=function(t){var e=n[t];return e&&e.timer?new Promise((function(t){var r=e.onDone;e.onDone=function(){r&&r(),t(),e.onDone=null}})):Promise.resolve()},r.clear=function(t){if(t)i(n[t]),delete n[t];else for(var e in n)r.clear(e)}},{}],805:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t,e){if(t>0)return Math.log(t)/Math.LN10;var r=Math.log(Math.min(e[0],e[1]))/Math.LN10;return n(r)||(r=Math.log(Math.max(e[0],e[1]))/Math.LN10-6),r}},{\"fast-isnumeric\":241}],806:[function(t,e,r){\"use strict\";var n=e.exports={},i=t(\"../plots/geo/constants\").locationmodeToLayer,a=t(\"topojson-client\").feature;n.getTopojsonName=function(t){return[t.scope.replace(/ /g,\"-\"),\"_\",t.resolution.toString(),\"m\"].join(\"\")},n.getTopojsonPath=function(t,e){return t+e+\".json\"},n.getTopojsonFeatures=function(t,e){var r=i[t.locationmode],n=e.objects[r];return a(e,n).features}},{\"../plots/geo/constants\":858,\"topojson-client\":579}],807:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en-US\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colorscale title\"},format:{date:\"%m/%d/%Y\"}}},{}],808:[function(t,e,r){\"use strict\";e.exports={moduleType:\"locale\",name:\"en\",dictionary:{\"Click to enter Colorscale title\":\"Click to enter Colourscale title\"},format:{days:[\"Sunday\",\"Monday\",\"Tuesday\",\"Wednesday\",\"Thursday\",\"Friday\",\"Saturday\"],shortDays:[\"Sun\",\"Mon\",\"Tue\",\"Wed\",\"Thu\",\"Fri\",\"Sat\"],months:[\"January\",\"February\",\"March\",\"April\",\"May\",\"June\",\"July\",\"August\",\"September\",\"October\",\"November\",\"December\"],shortMonths:[\"Jan\",\"Feb\",\"Mar\",\"Apr\",\"May\",\"Jun\",\"Jul\",\"Aug\",\"Sep\",\"Oct\",\"Nov\",\"Dec\"],periods:[\"AM\",\"PM\"],dateTime:\"%a %b %e %X %Y\",date:\"%d/%m/%Y\",time:\"%H:%M:%S\",decimal:\".\",thousands:\",\",grouping:[3],currency:[\"$\",\"\"],year:\"%Y\",month:\"%b %Y\",dayMonth:\"%b %-d\",dayMonthYear:\"%b %-d, %Y\"}}},{}],809:[function(t,e,r){\"use strict\";var n=t(\"../registry\");e.exports=function(t){for(var e,r,i=n.layoutArrayContainers,a=n.layoutArrayRegexes,o=t.split(\"[\")[0],s=0;s<a.length;s++)if((r=t.match(a[s]))&&0===r.index){e=r[0];break}if(e||(e=i[i.indexOf(o)]),!e)return!1;var l=t.substr(e.length);return l?!!(r=l.match(/^\\[(0|[1-9][0-9]*)\\](\\.(.+))?$/))&&{array:e,index:Number(r[1]),property:r[3]||\"\"}:{array:e,index:\"\",property:\"\"}}},{\"../registry\":911}],810:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.extendFlat,a=n.isPlainObject,o={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"clearAxisTypes\",\"plot\",\"style\",\"markerSize\",\"colorbars\"]},s={valType:\"flaglist\",extras:[\"none\"],flags:[\"calc\",\"plot\",\"legend\",\"ticks\",\"axrange\",\"layoutstyle\",\"modebar\",\"camera\",\"arraydraw\",\"colorbars\"]},l=o.flags.slice().concat([\"fullReplot\"]),c=s.flags.slice().concat(\"layoutReplot\");function u(t){for(var e={},r=0;r<t.length;r++)e[t[r]]=!1;return e}function f(t,e,r){var n=i({},t);for(var o in n){var s=n[o];a(s)&&(n[o]=h(s,e,r,o))}return\"from-root\"===r&&(n.editType=e),n}function h(t,e,r,n){if(t.valType){var a=i({},t);if(a.editType=e,Array.isArray(t.items)){a.items=new Array(t.items.length);for(var o=0;o<t.items.length;o++)a.items[o]=h(t.items[o],e,\"from-root\")}return a}return f(t,e,\"_\"===n.charAt(0)?\"nested\":\"from-root\")}e.exports={traces:o,layout:s,traceFlags:function(){return u(l)},layoutFlags:function(){return u(c)},update:function(t,e){var r=e.editType;if(r&&\"none\"!==r)for(var n=r.split(\"+\"),i=0;i<n.length;i++)t[n[i]]=!0},overrideAll:f}},{\"../lib\":778}],811:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"gl-mat4/fromQuat\"),a=t(\"../registry\"),o=t(\"../lib\"),s=t(\"../plots/plots\"),l=t(\"../plots/cartesian/axis_ids\"),c=t(\"../components/color\"),u=l.cleanId,f=l.getFromTrace,h=a.traceIs;function p(t,e){var r=t[e],n=e.charAt(0);r&&\"paper\"!==r&&(t[e]=u(r,n,!0))}function d(t){function e(e,r){var n=t[e],i=t.title&&t.title[r];n&&!i&&(t.title||(t.title={}),t.title[r]=t[e],delete t[e])}t&&(\"string\"!=typeof t.title&&\"number\"!=typeof t.title||(t.title={text:t.title}),e(\"titlefont\",\"font\"),e(\"titleposition\",\"position\"),e(\"titleside\",\"side\"),e(\"titleoffset\",\"offset\"))}function g(t){if(!o.isPlainObject(t))return!1;var e=t.name;return delete t.name,delete t.showlegend,(\"string\"==typeof e||\"number\"==typeof e)&&String(e)}function m(t,e,r,n){if(r&&!n)return t;if(n&&!r)return e;if(!t.trim())return e;if(!e.trim())return t;var i,a=Math.min(t.length,e.length);for(i=0;i<a&&t.charAt(i)===e.charAt(i);i++);return t.substr(0,i).trim()}function v(t){var e=\"middle\",r=\"center\";return\"string\"==typeof t&&(-1!==t.indexOf(\"top\")?e=\"top\":-1!==t.indexOf(\"bottom\")&&(e=\"bottom\"),-1!==t.indexOf(\"left\")?r=\"left\":-1!==t.indexOf(\"right\")&&(r=\"right\")),e+\" \"+r}function y(t,e){return e in t&&\"object\"==typeof t[e]&&0===Object.keys(t[e]).length}r.clearPromiseQueue=function(t){Array.isArray(t._promises)&&t._promises.length>0&&o.log(\"Clearing previous rejected promises from queue.\"),t._promises=[]},r.cleanLayout=function(t){var e,n;t||(t={}),t.xaxis1&&(t.xaxis||(t.xaxis=t.xaxis1),delete t.xaxis1),t.yaxis1&&(t.yaxis||(t.yaxis=t.yaxis1),delete t.yaxis1),t.scene1&&(t.scene||(t.scene=t.scene1),delete t.scene1);var a=(s.subplotsRegistry.cartesian||{}).attrRegex,l=(s.subplotsRegistry.polar||{}).attrRegex,f=(s.subplotsRegistry.ternary||{}).attrRegex,h=(s.subplotsRegistry.gl3d||{}).attrRegex,g=Object.keys(t);for(e=0;e<g.length;e++){var m=g[e];if(a&&a.test(m)){var v=t[m];v.anchor&&\"free\"!==v.anchor&&(v.anchor=u(v.anchor)),v.overlaying&&(v.overlaying=u(v.overlaying)),v.type||(v.isdate?v.type=\"date\":v.islog?v.type=\"log\":!1===v.isdate&&!1===v.islog&&(v.type=\"linear\")),\"withzero\"!==v.autorange&&\"tozero\"!==v.autorange||(v.autorange=!0,v.rangemode=\"tozero\"),delete v.islog,delete v.isdate,delete v.categories,y(v,\"domain\")&&delete v.domain,void 0!==v.autotick&&(void 0===v.tickmode&&(v.tickmode=v.autotick?\"auto\":\"linear\"),delete v.autotick),d(v)}else if(l&&l.test(m)){d(t[m].radialaxis)}else if(f&&f.test(m)){var x=t[m];d(x.aaxis),d(x.baxis),d(x.caxis)}else if(h&&h.test(m)){var b=t[m],_=b.cameraposition;if(Array.isArray(_)&&4===_[0].length){var w=_[0],T=_[1],k=_[2],M=i([],w),A=[];for(n=0;n<3;++n)A[n]=T[n]+k*M[2+4*n];b.camera={eye:{x:A[0],y:A[1],z:A[2]},center:{x:T[0],y:T[1],z:T[2]},up:{x:0,y:0,z:1}},delete b.cameraposition}d(b.xaxis),d(b.yaxis),d(b.zaxis)}}var S=Array.isArray(t.annotations)?t.annotations.length:0;for(e=0;e<S;e++){var E=t.annotations[e];o.isPlainObject(E)&&(E.ref&&(\"paper\"===E.ref?(E.xref=\"paper\",E.yref=\"paper\"):\"data\"===E.ref&&(E.xref=\"x\",E.yref=\"y\"),delete E.ref),p(E,\"xref\"),p(E,\"yref\"))}var C=Array.isArray(t.shapes)?t.shapes.length:0;for(e=0;e<C;e++){var L=t.shapes[e];o.isPlainObject(L)&&(p(L,\"xref\"),p(L,\"yref\"))}var I=Array.isArray(t.images)?t.images.length:0;for(e=0;e<I;e++){var P=t.images[e];o.isPlainObject(P)&&(p(P,\"xref\"),p(P,\"yref\"))}var z=t.legend;return z&&(z.x>3?(z.x=1.02,z.xanchor=\"left\"):z.x<-2&&(z.x=-.02,z.xanchor=\"right\"),z.y>3?(z.y=1.02,z.yanchor=\"bottom\"):z.y<-2&&(z.y=-.02,z.yanchor=\"top\")),d(t),\"rotate\"===t.dragmode&&(t.dragmode=\"orbit\"),c.clean(t),t.template&&t.template.layout&&r.cleanLayout(t.template.layout),t},r.cleanData=function(t){for(var e=0;e<t.length;e++){var n,i=t[e];if(\"histogramy\"===i.type&&\"xbins\"in i&&!(\"ybins\"in i)&&(i.ybins=i.xbins,delete i.xbins),i.error_y&&\"opacity\"in i.error_y){var l=c.defaults,f=i.error_y.color||(h(i,\"bar\")?c.defaultLine:l[e%l.length]);i.error_y.color=c.addOpacity(c.rgb(f),c.opacity(f)*i.error_y.opacity),delete i.error_y.opacity}if(\"bardir\"in i&&(\"h\"!==i.bardir||!h(i,\"bar\")&&\"histogram\"!==i.type.substr(0,9)||(i.orientation=\"h\",r.swapXYData(i)),delete i.bardir),\"histogramy\"===i.type&&r.swapXYData(i),\"histogramx\"!==i.type&&\"histogramy\"!==i.type||(i.type=\"histogram\"),\"scl\"in i&&!(\"colorscale\"in i)&&(i.colorscale=i.scl,delete i.scl),\"reversescl\"in i&&!(\"reversescale\"in i)&&(i.reversescale=i.reversescl,delete i.reversescl),i.xaxis&&(i.xaxis=u(i.xaxis,\"x\")),i.yaxis&&(i.yaxis=u(i.yaxis,\"y\")),h(i,\"gl3d\")&&i.scene&&(i.scene=s.subplotsRegistry.gl3d.cleanId(i.scene)),!h(i,\"pie-like\")&&!h(i,\"bar-like\"))if(Array.isArray(i.textposition))for(n=0;n<i.textposition.length;n++)i.textposition[n]=v(i.textposition[n]);else i.textposition&&(i.textposition=v(i.textposition));var p=a.getModule(i);if(p&&p.colorbar){var x=p.colorbar.container,b=x?i[x]:i;b&&b.colorscale&&(\"YIGnBu\"===b.colorscale&&(b.colorscale=\"YlGnBu\"),\"YIOrRd\"===b.colorscale&&(b.colorscale=\"YlOrRd\"))}if(\"surface\"===i.type&&o.isPlainObject(i.contours)){var _=[\"x\",\"y\",\"z\"];for(n=0;n<_.length;n++){var w=i.contours[_[n]];o.isPlainObject(w)&&(w.highlightColor&&(w.highlightcolor=w.highlightColor,delete w.highlightColor),w.highlightWidth&&(w.highlightwidth=w.highlightWidth,delete w.highlightWidth))}}if(\"candlestick\"===i.type||\"ohlc\"===i.type){var T=!1!==(i.increasing||{}).showlegend,k=!1!==(i.decreasing||{}).showlegend,M=g(i.increasing),A=g(i.decreasing);if(!1!==M&&!1!==A){var S=m(M,A,T,k);S&&(i.name=S)}else!M&&!A||i.name||(i.name=M||A)}if(Array.isArray(i.transforms)){var E=i.transforms;for(n=0;n<E.length;n++){var C=E[n];if(o.isPlainObject(C))switch(C.type){case\"filter\":C.filtersrc&&(C.target=C.filtersrc,delete C.filtersrc),C.calendar&&(C.valuecalendar||(C.valuecalendar=C.calendar),delete C.calendar);break;case\"groupby\":if(C.styles=C.styles||C.style,C.styles&&!Array.isArray(C.styles)){var L=C.styles,I=Object.keys(L);C.styles=[];for(var P=0;P<I.length;P++)C.styles.push({target:I[P],value:L[I[P]]})}}}}y(i,\"line\")&&delete i.line,\"marker\"in i&&(y(i.marker,\"line\")&&delete i.marker.line,y(i,\"marker\")&&delete i.marker),c.clean(i),i.autobinx&&(delete i.autobinx,delete i.xbins),i.autobiny&&(delete i.autobiny,delete i.ybins),d(i),i.colorbar&&d(i.colorbar),i.marker&&i.marker.colorbar&&d(i.marker.colorbar),i.line&&i.line.colorbar&&d(i.line.colorbar),i.aaxis&&d(i.aaxis),i.baxis&&d(i.baxis)}},r.swapXYData=function(t){var e;if(o.swapAttrs(t,[\"?\",\"?0\",\"d?\",\"?bins\",\"nbins?\",\"autobin?\",\"?src\",\"error_?\"]),Array.isArray(t.z)&&Array.isArray(t.z[0])&&(t.transpose?delete t.transpose:t.transpose=!0),t.error_x&&t.error_y){var r=t.error_y,n=\"copy_ystyle\"in r?r.copy_ystyle:!(r.color||r.thickness||r.width);o.swapAttrs(t,[\"error_?.copy_ystyle\"]),n&&o.swapAttrs(t,[\"error_?.color\",\"error_?.thickness\",\"error_?.width\"])}if(\"string\"==typeof t.hoverinfo){var i=t.hoverinfo.split(\"+\");for(e=0;e<i.length;e++)\"x\"===i[e]?i[e]=\"y\":\"y\"===i[e]&&(i[e]=\"x\");t.hoverinfo=i.join(\"+\")}},r.coerceTraceIndices=function(t,e){if(n(e))return[e];if(!Array.isArray(e)||!e.length)return t.data.map((function(t,e){return e}));if(Array.isArray(e)){for(var r=[],i=0;i<e.length;i++)o.isIndex(e[i],t.data.length)?r.push(e[i]):o.warn(\"trace index (\",e[i],\") is not a number or is out of bounds\");return r}return e},r.manageArrayContainers=function(t,e,r){var i=t.obj,a=t.parts,s=a.length,l=a[s-1],c=n(l);if(c&&null===e){var u=a.slice(0,s-1).join(\".\");o.nestedProperty(i,u).get().splice(l,1)}else c&&void 0===t.get()?(void 0===t.get()&&(r[t.astr]=null),t.set(e)):t.set(e)};var x=/(\\.[^\\[\\]\\.]+|\\[[^\\[\\]\\.]+\\])$/;function b(t){var e=t.search(x);if(e>0)return t.substr(0,e)}r.hasParent=function(t,e){for(var r=b(e);r;){if(r in t)return!0;r=b(r)}return!1};var _=[\"x\",\"y\",\"z\"];r.clearAxisTypes=function(t,e,r){for(var n=0;n<e.length;n++)for(var i=t._fullData[n],a=0;a<3;a++){var s=f(t,i,_[a]);if(s&&\"log\"!==s.type){var l=s._name,c=s._id.substr(1);if(\"scene\"===c.substr(0,5)){if(void 0!==r[c])continue;l=c+\".\"+l}var u=l+\".type\";void 0===r[l]&&void 0===r[u]&&o.nestedProperty(t.layout,u).set(null)}}}},{\"../components/color\":643,\"../lib\":778,\"../plots/cartesian/axis_ids\":831,\"../plots/plots\":891,\"../registry\":911,\"fast-isnumeric\":241,\"gl-mat4/fromQuat\":282}],812:[function(t,e,r){\"use strict\";var n=t(\"./plot_api\");r.plot=n.plot,r.newPlot=n.newPlot,r.restyle=n.restyle,r.relayout=n.relayout,r.redraw=n.redraw,r.update=n.update,r._guiRestyle=n._guiRestyle,r._guiRelayout=n._guiRelayout,r._guiUpdate=n._guiUpdate,r._storeDirectGUIEdit=n._storeDirectGUIEdit,r.react=n.react,r.extendTraces=n.extendTraces,r.prependTraces=n.prependTraces,r.addTraces=n.addTraces,r.deleteTraces=n.deleteTraces,r.moveTraces=n.moveTraces,r.purge=n.purge,r.addFrames=n.addFrames,r.deleteFrames=n.deleteFrames,r.animate=n.animate,r.setPlotConfig=n.setPlotConfig,r.toImage=t(\"./to_image\"),r.validate=t(\"./validate\"),r.downloadImage=t(\"../snapshot/download\");var i=t(\"./template_api\");r.makeTemplate=i.makeTemplate,r.validateTemplate=i.validateTemplate},{\"../snapshot/download\":913,\"./plot_api\":814,\"./template_api\":819,\"./to_image\":820,\"./validate\":821}],813:[function(t,e,r){\"use strict\";var n=t(\"../lib/is_plain_object\"),i=t(\"../lib/noop\"),a=t(\"../lib/loggers\"),o=t(\"../lib/search\").sorterAsc,s=t(\"../registry\");r.containerArrayMatch=t(\"./container_array_match\");var l=r.isAddVal=function(t){return\"add\"===t||n(t)},c=r.isRemoveVal=function(t){return null===t||\"remove\"===t};r.applyContainerArrayChanges=function(t,e,r,n,u){var f=e.astr,h=s.getComponentMethod(f,\"supplyLayoutDefaults\"),p=s.getComponentMethod(f,\"draw\"),d=s.getComponentMethod(f,\"drawOne\"),g=n.replot||n.recalc||h===i||p===i,m=t.layout,v=t._fullLayout;if(r[\"\"]){Object.keys(r).length>1&&a.warn(\"Full array edits are incompatible with other edits\",f);var y=r[\"\"][\"\"];if(c(y))e.set(null);else{if(!Array.isArray(y))return a.warn(\"Unrecognized full array edit value\",f,y),!0;e.set(y)}return!g&&(h(m,v),p(t),!0)}var x,b,_,w,T,k,M,A,S=Object.keys(r).map(Number).sort(o),E=e.get(),C=E||[],L=u(v,f).get(),I=[],P=-1,z=C.length;for(x=0;x<S.length;x++)if(w=r[_=S[x]],T=Object.keys(w),k=w[\"\"],M=l(k),_<0||_>C.length-(M?0:1))a.warn(\"index out of range\",f,_);else if(void 0!==k)T.length>1&&a.warn(\"Insertion & removal are incompatible with edits to the same index.\",f,_),c(k)?I.push(_):M?(\"add\"===k&&(k={}),C.splice(_,0,k),L&&L.splice(_,0,{})):a.warn(\"Unrecognized full object edit value\",f,_,k),-1===P&&(P=_);else for(b=0;b<T.length;b++)A=f+\"[\"+_+\"].\",u(C[_],T[b],A).set(w[T[b]]);for(x=I.length-1;x>=0;x--)C.splice(I[x],1),L&&L.splice(I[x],1);if(C.length?E||e.set(C):e.set(null),g)return!1;if(h(m,v),d!==i){var O;if(-1===P)O=S;else{for(z=Math.max(C.length,z),O=[],x=0;x<S.length&&!((_=S[x])>=P);x++)O.push(_);for(x=P;x<z;x++)O.push(x)}for(x=0;x<O.length;x++)d(t,O[x])}else p(t);return!0}},{\"../lib/is_plain_object\":779,\"../lib/loggers\":782,\"../lib/noop\":787,\"../lib/search\":798,\"../registry\":911,\"./container_array_match\":809}],814:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"has-hover\"),o=t(\"../lib\"),s=o.nestedProperty,l=t(\"../lib/events\"),c=t(\"../lib/queue\"),u=t(\"../registry\"),f=t(\"./plot_schema\"),h=t(\"../plots/plots\"),p=t(\"../plots/polar/legacy\"),d=t(\"../plots/cartesian/axes\"),g=t(\"../components/drawing\"),m=t(\"../components/color\"),v=t(\"../plots/cartesian/graph_interact\").initInteractions,y=t(\"../constants/xmlns_namespaces\"),x=t(\"../lib/svg_text_utils\"),b=t(\"../plots/cartesian/select\").clearSelect,_=t(\"./plot_config\").dfltConfig,w=t(\"./manage_arrays\"),T=t(\"./helpers\"),k=t(\"./subroutines\"),M=t(\"./edit_types\"),A=t(\"../plots/cartesian/constants\").AX_NAME_PATTERN,S=0;function E(t){var e=t._fullLayout;e._redrawFromAutoMarginCount?e._redrawFromAutoMarginCount--:t.emit(\"plotly_afterplot\")}function C(t,e){try{t._fullLayout._paper.style(\"background\",e)}catch(t){o.error(t)}}function L(t,e){C(t,m.combine(e,\"white\"))}function I(t,e){if(!t._context){t._context=o.extendDeep({},_);var r=n.select(\"base\");t._context._baseUrl=r.size()&&r.attr(\"href\")?window.location.href.split(\"#\")[0]:\"\"}var i,s,l,c=t._context;if(e){for(s=Object.keys(e),i=0;i<s.length;i++)\"editable\"!==(l=s[i])&&\"edits\"!==l&&l in c&&(\"setBackground\"===l&&\"opaque\"===e[l]?c[l]=L:c[l]=e[l]);e.plot3dPixelRatio&&!c.plotGlPixelRatio&&(c.plotGlPixelRatio=c.plot3dPixelRatio);var u=e.editable;if(void 0!==u)for(c.editable=u,s=Object.keys(c.edits),i=0;i<s.length;i++)c.edits[s[i]]=u;if(e.edits)for(s=Object.keys(e.edits),i=0;i<s.length;i++)(l=s[i])in c.edits&&(c.edits[l]=e.edits[l]);c._exportedPlot=e._exportedPlot}c.staticPlot&&(c.editable=!1,c.edits={},c.autosizable=!1,c.scrollZoom=!1,c.doubleClick=!1,c.showTips=!1,c.showLink=!1,c.displayModeBar=!1),\"hover\"!==c.displayModeBar||a||(c.displayModeBar=!0),\"transparent\"!==c.setBackground&&\"function\"==typeof c.setBackground||(c.setBackground=C),c._hasZeroHeight=c._hasZeroHeight||0===t.clientHeight,c._hasZeroWidth=c._hasZeroWidth||0===t.clientWidth;var f=c.scrollZoom,h=c._scrollZoom={};if(!0===f)h.cartesian=1,h.gl3d=1,h.geo=1,h.mapbox=1;else if(\"string\"==typeof f){var p=f.split(\"+\");for(i=0;i<p.length;i++)h[p[i]]=1}else!1!==f&&(h.gl3d=1,h.geo=1,h.mapbox=1)}function P(t,e){var r,n,i=e+1,a=[];for(r=0;r<t.length;r++)(n=t[r])<0?a.push(i+n):a.push(n);return a}function z(t,e,r){var n,i;for(n=0;n<e.length;n++){if((i=e[n])!==parseInt(i,10))throw new Error(\"all values in \"+r+\" must be integers\");if(i>=t.data.length||i<-t.data.length)throw new Error(r+\" must be valid indices for gd.data.\");if(e.indexOf(i,n+1)>-1||i>=0&&e.indexOf(-t.data.length+i)>-1||i<0&&e.indexOf(t.data.length+i)>-1)throw new Error(\"each index in \"+r+\" must be unique.\")}}function O(t,e,r){if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"currentIndices is a required argument.\");if(Array.isArray(e)||(e=[e]),z(t,e,\"currentIndices\"),\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&z(t,r,\"newIndices\"),\"undefined\"!=typeof r&&e.length!==r.length)throw new Error(\"current and new indices must be of equal length.\")}function D(t,e,r,n,a){!function(t,e,r,n){var i=o.isPlainObject(n);if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array\");if(!o.isPlainObject(e))throw new Error(\"update must be a key:value object\");if(\"undefined\"==typeof r)throw new Error(\"indices must be an integer or array of integers\");for(var a in z(t,r,\"indices\"),e){if(!Array.isArray(e[a])||e[a].length!==r.length)throw new Error(\"attribute \"+a+\" must be an array of length equal to indices array length\");if(i&&(!(a in n)||!Array.isArray(n[a])||n[a].length!==e[a].length))throw new Error(\"when maxPoints is set as a key:value object it must contain a 1:1 corrispondence with the keys and number of traces in the update object\")}}(t,e,r,n);for(var l=function(t,e,r,n){var a,l,c,u,f,h=o.isPlainObject(n),p=[];for(var d in Array.isArray(r)||(r=[r]),r=P(r,t.data.length-1),e)for(var g=0;g<r.length;g++){if(a=t.data[r[g]],l=(c=s(a,d)).get(),u=e[d][g],!o.isArrayOrTypedArray(u))throw new Error(\"attribute: \"+d+\" index: \"+g+\" must be an array\");if(!o.isArrayOrTypedArray(l))throw new Error(\"cannot extend missing or non-array attribute: \"+d);if(l.constructor!==u.constructor)throw new Error(\"cannot extend array with an array of a different type: \"+d);f=h?n[d][g]:n,i(f)||(f=-1),p.push({prop:c,target:l,insert:u,maxp:Math.floor(f)})}return p}(t,e,r,n),c={},u={},f=0;f<l.length;f++){var h=l[f].prop,p=l[f].maxp,d=a(l[f].target,l[f].insert,p);h.set(d[0]),Array.isArray(c[h.astr])||(c[h.astr]=[]),c[h.astr].push(d[1]),Array.isArray(u[h.astr])||(u[h.astr]=[]),u[h.astr].push(l[f].target.length)}return{update:c,maxPoints:u}}function R(t,e){var r=new t.constructor(t.length+e.length);return r.set(t),r.set(e,t.length),r}function F(t,e,n,i){t=o.getGraphDiv(t),T.clearPromiseQueue(t);var a={};if(\"string\"==typeof e)a[e]=n;else{if(!o.isPlainObject(e))return o.warn(\"Restyle fail.\",e,n,i),Promise.reject();a=o.extendFlat({},e),void 0===i&&(i=n)}Object.keys(a).length&&(t.changed=!0);var s=T.coerceTraceIndices(t,i),l=U(t,a,s),u=l.flags;u.calc&&(t.calcdata=void 0),u.clearAxisTypes&&T.clearAxisTypes(t,s,{});var f=[];u.fullReplot?f.push(r.plot):(f.push(h.previousPromises),h.supplyDefaults(t),u.markerSize&&(h.doCalcdata(t),G(f)),u.style&&f.push(k.doTraceStyle),u.colorbars&&f.push(k.doColorBars),f.push(E)),f.push(h.rehover,h.redrag),c.add(t,F,[t,l.undoit,l.traces],F,[t,l.redoit,l.traces]);var p=o.syncOrAsync(f,t);return p&&p.then||(p=Promise.resolve()),p.then((function(){return t.emit(\"plotly_restyle\",l.eventData),t}))}function B(t){return void 0===t?null:t}function N(t,e){return e?function(e,r,n){var i=s(e,r),a=i.set;return i.set=function(e){j((n||\"\")+r,i.get(),e,t),a(e)},i}:s}function j(t,e,r,n){if(Array.isArray(e)||Array.isArray(r))for(var i=Array.isArray(e)?e:[],a=Array.isArray(r)?r:[],s=Math.max(i.length,a.length),l=0;l<s;l++)j(t+\"[\"+l+\"]\",i[l],a[l],n);else if(o.isPlainObject(e)||o.isPlainObject(r)){var c=o.isPlainObject(e)?e:{},u=o.isPlainObject(r)?r:{},f=o.extendFlat({},c,u);for(var h in f)j(t+\".\"+h,c[h],u[h],n)}else void 0===n[t]&&(n[t]=B(e))}function U(t,e,r){var n,i=t._fullLayout,a=t._fullData,l=t.data,c=i._guiEditing,p=N(i._preGUI,c),g=o.extendDeepAll({},e);V(e);var m,v=M.traceFlags(),y={},x={};function b(){return r.map((function(){}))}function _(t){var e=d.id2name(t);-1===m.indexOf(e)&&m.push(e)}function w(t){return\"LAYOUT\"+t+\".autorange\"}function k(t){return\"LAYOUT\"+t+\".range\"}function A(t){for(var e=t;e<a.length;e++)if(a[e]._input===l[t])return a[e]}function S(n,a,o){if(Array.isArray(n))n.forEach((function(t){S(t,a,o)}));else if(!(n in e)&&!T.hasParent(e,n)){var s;if(\"LAYOUT\"===n.substr(0,6))s=p(t.layout,n.replace(\"LAYOUT\",\"\"));else{var u=r[o];s=N(i._tracePreGUI[A(u)._fullInput.uid],c)(l[u],n)}n in x||(x[n]=b()),void 0===x[n][o]&&(x[n][o]=B(s.get())),void 0!==a&&s.set(a)}}function E(t){return function(e){return a[e][t]}}function C(t){return function(e,n){return!1===e?a[r[n]][t]:null}}for(var L in e){if(T.hasParent(e,L))throw new Error(\"cannot set \"+L+\" and a parent attribute simultaneously\");var I,P,z,O,D,R,F=e[L];if(\"autobinx\"!==L&&\"autobiny\"!==L||(L=L.charAt(L.length-1)+\"bins\",F=Array.isArray(F)?F.map(C(L)):!1===F?r.map(E(L)):null),y[L]=F,\"LAYOUT\"!==L.substr(0,6)){for(x[L]=b(),n=0;n<r.length;n++){if(I=l[r[n]],P=A(r[n]),O=(z=N(i._tracePreGUI[P._fullInput.uid],c)(I,L)).get(),void 0!==(D=Array.isArray(F)?F[n%F.length]:F)){var j=z.parts[z.parts.length-1],U=L.substr(0,L.length-j.length-1),q=U?U+\".\":\"\",H=U?s(P,U).get():P;if((R=f.getTraceValObject(P,z.parts))&&R.impliedEdits&&null!==D)for(var G in R.impliedEdits)S(o.relativeAttr(L,G),R.impliedEdits[G],n);else if(\"thicknessmode\"!==j&&\"lenmode\"!==j||O===D||\"fraction\"!==D&&\"pixels\"!==D||!H){if(\"type\"===L&&(\"pie\"===D!=(\"pie\"===O)||\"funnelarea\"===D!=(\"funnelarea\"===O))){var Y=\"x\",W=\"y\";\"bar\"!==D&&\"bar\"!==O||\"h\"!==I.orientation||(Y=\"y\",W=\"x\"),o.swapAttrs(I,[\"?\",\"?src\"],\"labels\",Y),o.swapAttrs(I,[\"d?\",\"?0\"],\"label\",Y),o.swapAttrs(I,[\"?\",\"?src\"],\"values\",W),\"pie\"===O||\"funnelarea\"===O?(s(I,\"marker.color\").set(s(I,\"marker.colors\").get()),i._pielayer.selectAll(\"g.trace\").remove()):u.traceIs(I,\"cartesian\")&&s(I,\"marker.colors\").set(s(I,\"marker.color\").get())}}else{var X=i._size,Z=H.orient,J=\"top\"===Z||\"bottom\"===Z;if(\"thicknessmode\"===j){var K=J?X.h:X.w;S(q+\"thickness\",H.thickness*(\"fraction\"===D?1/K:K),n)}else{var Q=J?X.w:X.h;S(q+\"len\",H.len*(\"fraction\"===D?1/Q:Q),n)}}x[L][n]=B(O);if(-1!==[\"swapxy\",\"swapxyaxes\",\"orientation\",\"orientationaxes\"].indexOf(L)){if(\"orientation\"===L){z.set(D);var $=I.x&&!I.y?\"h\":\"v\";if((z.get()||$)===P.orientation)continue}else\"orientationaxes\"===L&&(I.orientation={v:\"h\",h:\"v\"}[P.orientation]);T.swapXYData(I),v.calc=v.clearAxisTypes=!0}else-1!==h.dataArrayContainers.indexOf(z.parts[0])?(T.manageArrayContainers(z,D,x),v.calc=!0):(R?R.arrayOk&&!u.traceIs(P,\"regl\")&&(o.isArrayOrTypedArray(D)||o.isArrayOrTypedArray(O))?v.calc=!0:M.update(v,R):v.calc=!0,z.set(D))}}if(-1!==[\"swapxyaxes\",\"orientationaxes\"].indexOf(L)&&d.swap(t,r),\"orientationaxes\"===L){var tt=s(t.layout,\"hovermode\"),et=tt.get();\"x\"===et?tt.set(\"y\"):\"y\"===et?tt.set(\"x\"):\"x unified\"===et?tt.set(\"y unified\"):\"y unified\"===et&&tt.set(\"x unified\")}if(-1!==[\"orientation\",\"type\"].indexOf(L)){for(m=[],n=0;n<r.length;n++){var rt=l[r[n]];u.traceIs(rt,\"cartesian\")&&(_(rt.xaxis||\"x\"),_(rt.yaxis||\"y\"))}S(m.map(w),!0,0),S(m.map(k),[0,1],0)}}else z=p(t.layout,L.replace(\"LAYOUT\",\"\")),x[L]=[B(z.get())],z.set(Array.isArray(F)?F[0]:F),v.calc=!0}return(v.calc||v.plot)&&(v.fullReplot=!0),{flags:v,undoit:x,redoit:y,traces:r,eventData:o.extendDeepNoArrays([],[g,r])}}function V(t){var e,r,n,i=o.counterRegex(\"axis\",\".title\",!1,!1),a=/colorbar\\.title$/,s=Object.keys(t);for(e=0;e<s.length;e++)r=s[e],n=t[r],\"title\"!==r&&!i.test(r)&&!a.test(r)||\"string\"!=typeof n&&\"number\"!=typeof n?r.indexOf(\"titlefont\")>-1?l(r,r.replace(\"titlefont\",\"title.font\")):r.indexOf(\"titleposition\")>-1?l(r,r.replace(\"titleposition\",\"title.position\")):r.indexOf(\"titleside\")>-1?l(r,r.replace(\"titleside\",\"title.side\")):r.indexOf(\"titleoffset\")>-1&&l(r,r.replace(\"titleoffset\",\"title.offset\")):l(r,r.replace(\"title\",\"title.text\"));function l(e,r){t[r]=t[e],delete t[e]}}function q(t,e,r){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);var n={};if(\"string\"==typeof e)n[e]=r;else{if(!o.isPlainObject(e))return o.warn(\"Relayout fail.\",e,r),Promise.reject();n=o.extendFlat({},e)}Object.keys(n).length&&(t.changed=!0);var i=Z(t,n),a=i.flags;a.calc&&(t.calcdata=void 0);var s=[h.previousPromises];a.layoutReplot?s.push(k.layoutReplot):Object.keys(n).length&&(H(t,a,i)||h.supplyDefaults(t),a.legend&&s.push(k.doLegend),a.layoutstyle&&s.push(k.layoutStyles),a.axrange&&G(s,i.rangesAltered),a.ticks&&s.push(k.doTicksRelayout),a.modebar&&s.push(k.doModeBar),a.camera&&s.push(k.doCamera),a.colorbars&&s.push(k.doColorBars),s.push(E)),s.push(h.rehover,h.redrag),c.add(t,q,[t,i.undoit],q,[t,i.redoit]);var l=o.syncOrAsync(s,t);return l&&l.then||(l=Promise.resolve(t)),l.then((function(){return t.emit(\"plotly_relayout\",i.eventData),t}))}function H(t,e,r){var n=t._fullLayout;if(!e.axrange)return!1;for(var i in e)if(\"axrange\"!==i&&e[i])return!1;for(var a in r.rangesAltered){var o=d.id2name(a),s=t.layout[o],l=n[o];if(l.autorange=s.autorange,s.range&&(l.range=s.range.slice()),l.cleanRange(),l._matchGroup)for(var c in l._matchGroup)if(c!==a){var u=n[d.id2name(c)];u.autorange=l.autorange,u.range=l.range.slice(),u._input.range=l.range.slice()}}return!0}function G(t,e){var r=e?function(t){var r=[],n=!0;for(var i in e){var a=d.getFromId(t,i);if(r.push(i),-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")&&a._anchorAxis&&r.push(a._anchorAxis._id),a._matchGroup)for(var o in a._matchGroup)e[o]||r.push(o);a.automargin&&(n=!1)}return d.draw(t,r,{skipTitle:n})}:function(t){return d.draw(t,\"redraw\")};t.push(b,k.doAutoRangeAndConstraints,r,k.drawData,k.finalDraw)}var Y=/^[xyz]axis[0-9]*\\.range(\\[[0|1]\\])?$/,W=/^[xyz]axis[0-9]*\\.autorange$/,X=/^[xyz]axis[0-9]*\\.domain(\\[[0|1]\\])?$/;function Z(t,e){var r,n,i,a=t.layout,l=t._fullLayout,c=l._guiEditing,h=N(l._preGUI,c),p=Object.keys(e),g=d.list(t),m=o.extendDeepAll({},e),v={};for(V(e),p=Object.keys(e),n=0;n<p.length;n++)if(0===p[n].indexOf(\"allaxes\")){for(i=0;i<g.length;i++){var y=g[i]._id.substr(1),x=-1!==y.indexOf(\"scene\")?y+\".\":\"\",b=p[n].replace(\"allaxes\",x+g[i]._name);e[b]||(e[b]=e[p[n]])}delete e[p[n]]}var _=M.layoutFlags(),k={},S={};function E(t,r){if(Array.isArray(t))t.forEach((function(t){E(t,r)}));else if(!(t in e)&&!T.hasParent(e,t)){var n=h(a,t);t in S||(S[t]=B(n.get())),void 0!==r&&n.set(r)}}var C,L={};function I(t){var e=d.name2id(t.split(\".\")[0]);return L[e]=1,e}for(var P in e){if(T.hasParent(e,P))throw new Error(\"cannot set \"+P+\" and a parent attribute simultaneously\");for(var z=h(a,P),O=e[P],D=z.parts.length-1;D>0&&\"string\"!=typeof z.parts[D];)D--;var R=z.parts[D],F=z.parts[D-1]+\".\"+R,j=z.parts.slice(0,D).join(\".\"),U=s(t.layout,j).get(),q=s(l,j).get(),H=z.get();if(void 0!==O){k[P]=O,S[P]=\"reverse\"===R?O:B(H);var G=f.getLayoutValObject(l,z.parts);if(G&&G.impliedEdits&&null!==O)for(var Z in G.impliedEdits)E(o.relativeAttr(P,Z),G.impliedEdits[Z]);if(-1!==[\"width\",\"height\"].indexOf(P))if(O){E(\"autosize\",null);var K=\"height\"===P?\"width\":\"height\";E(K,l[K])}else l[P]=t._initialAutoSize[P];else if(\"autosize\"===P)E(\"width\",O?null:l.width),E(\"height\",O?null:l.height);else if(F.match(Y))I(F),s(l,j+\"._inputRange\").set(null);else if(F.match(W)){I(F),s(l,j+\"._inputRange\").set(null);var Q=s(l,j).get();Q._inputDomain&&(Q._input.domain=Q._inputDomain.slice())}else F.match(X)&&s(l,j+\"._inputDomain\").set(null);if(\"type\"===R){C=U;var $=\"linear\"===q.type&&\"log\"===O,tt=\"log\"===q.type&&\"linear\"===O;if($||tt){if(C&&C.range)if(q.autorange)$&&(C.range=C.range[1]>C.range[0]?[1,2]:[2,1]);else{var et=C.range[0],rt=C.range[1];$?(et<=0&&rt<=0&&E(j+\".autorange\",!0),et<=0?et=rt/1e6:rt<=0&&(rt=et/1e6),E(j+\".range[0]\",Math.log(et)/Math.LN10),E(j+\".range[1]\",Math.log(rt)/Math.LN10)):(E(j+\".range[0]\",Math.pow(10,et)),E(j+\".range[1]\",Math.pow(10,rt)))}else E(j+\".autorange\",!0);Array.isArray(l._subplots.polar)&&l._subplots.polar.length&&l[z.parts[0]]&&\"radialaxis\"===z.parts[1]&&delete l[z.parts[0]]._subplot.viewInitial[\"radialaxis.range\"],u.getComponentMethod(\"annotations\",\"convertCoords\")(t,q,O,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,q,O,E)}else E(j+\".autorange\",!0),E(j+\".range\",null);s(l,j+\"._inputRange\").set(null)}else if(R.match(A)){var nt=s(l,P).get(),it=(O||{}).type;it&&\"-\"!==it||(it=\"linear\"),u.getComponentMethod(\"annotations\",\"convertCoords\")(t,nt,it,E),u.getComponentMethod(\"images\",\"convertCoords\")(t,nt,it,E)}var at=w.containerArrayMatch(P);if(at){r=at.array,n=at.index;var ot=at.property,st=G||{editType:\"calc\"};\"\"!==n&&\"\"===ot&&(w.isAddVal(O)?S[P]=null:w.isRemoveVal(O)?S[P]=(s(a,r).get()||[])[n]:o.warn(\"unrecognized full object value\",e)),M.update(_,st),v[r]||(v[r]={});var lt=v[r][n];lt||(lt=v[r][n]={}),lt[ot]=O,delete e[P]}else\"reverse\"===R?(U.range?U.range.reverse():(E(j+\".autorange\",!0),U.range=[1,0]),q.autorange?_.calc=!0:_.plot=!0):(l._has(\"scatter-like\")&&l._has(\"regl\")&&\"dragmode\"===P&&(\"lasso\"===O||\"select\"===O)&&\"lasso\"!==H&&\"select\"!==H||l._has(\"gl2d\")?_.plot=!0:G?M.update(_,G):_.calc=!0,z.set(O))}}for(r in v){w.applyContainerArrayChanges(t,h(a,r),v[r],_,h)||(_.plot=!0)}for(var ct in L){var ut=(C=d.getFromId(t,ct))&&C._constraintGroup;if(ut)for(var ft in _.calc=!0,ut)L[ft]||(d.getFromId(t,ft)._constraintShrinkable=!0)}return(J(t)||e.height||e.width)&&(_.plot=!0),(_.plot||_.calc)&&(_.layoutReplot=!0),{flags:_,rangesAltered:L,undoit:S,redoit:k,eventData:m}}function J(t){var e=t._fullLayout,r=e.width,n=e.height;return t.layout.autosize&&h.plotAutoSize(t,t.layout,e),e.width!==r||e.height!==n}function K(t,e,n,i){if(t=o.getGraphDiv(t),T.clearPromiseQueue(t),t.framework&&t.framework.isPolar)return Promise.resolve(t);o.isPlainObject(e)||(e={}),o.isPlainObject(n)||(n={}),Object.keys(e).length&&(t.changed=!0),Object.keys(n).length&&(t.changed=!0);var a=T.coerceTraceIndices(t,i),s=U(t,o.extendFlat({},e),a),l=s.flags,u=Z(t,o.extendFlat({},n)),f=u.flags;(l.calc||f.calc)&&(t.calcdata=void 0),l.clearAxisTypes&&T.clearAxisTypes(t,a,n);var p=[];f.layoutReplot?p.push(k.layoutReplot):l.fullReplot?p.push(r.plot):(p.push(h.previousPromises),H(t,f,u)||h.supplyDefaults(t),l.style&&p.push(k.doTraceStyle),(l.colorbars||f.colorbars)&&p.push(k.doColorBars),f.legend&&p.push(k.doLegend),f.layoutstyle&&p.push(k.layoutStyles),f.axrange&&G(p,u.rangesAltered),f.ticks&&p.push(k.doTicksRelayout),f.modebar&&p.push(k.doModeBar),f.camera&&p.push(k.doCamera),p.push(E)),p.push(h.rehover,h.redrag),c.add(t,K,[t,s.undoit,u.undoit,s.traces],K,[t,s.redoit,u.redoit,s.traces]);var d=o.syncOrAsync(p,t);return d&&d.then||(d=Promise.resolve(t)),d.then((function(){return t.emit(\"plotly_update\",{data:s.eventData,layout:u.eventData}),t}))}function Q(t){return function(e){e._fullLayout._guiEditing=!0;var r=t.apply(null,arguments);return e._fullLayout._guiEditing=!1,r}}var $=[{pattern:/^hiddenlabels/,attr:\"legend.uirevision\"},{pattern:/^((x|y)axis\\d*)\\.((auto)?range|title\\.text)/},{pattern:/axis\\d*\\.showspikes$/,attr:\"modebar.uirevision\"},{pattern:/(hover|drag)mode$/,attr:\"modebar.uirevision\"},{pattern:/^(scene\\d*)\\.camera/},{pattern:/^(geo\\d*)\\.(projection|center|fitbounds)/},{pattern:/^(ternary\\d*\\.[abc]axis)\\.(min|title\\.text)$/},{pattern:/^(polar\\d*\\.radialaxis)\\.((auto)?range|angle|title\\.text)/},{pattern:/^(polar\\d*\\.angularaxis)\\.rotation/},{pattern:/^(mapbox\\d*)\\.(center|zoom|bearing|pitch)/},{pattern:/^legend\\.(x|y)$/,attr:\"editrevision\"},{pattern:/^(shapes|annotations)/,attr:\"editrevision\"},{pattern:/^title\\.text$/,attr:\"editrevision\"}],tt=[{pattern:/^selectedpoints$/,attr:\"selectionrevision\"},{pattern:/(^|value\\.)visible$/,attr:\"legend.uirevision\"},{pattern:/^dimensions\\[\\d+\\]\\.constraintrange/},{pattern:/^node\\.(x|y|groups)/},{pattern:/^level$/},{pattern:/(^|value\\.)name$/},{pattern:/colorbar\\.title\\.text$/},{pattern:/colorbar\\.(x|y)$/,attr:\"editrevision\"}];function et(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=t.match(n.pattern);if(i)return{head:i[1],attr:n.attr}}}function rt(t,e){var r=s(e,t).get();if(void 0!==r)return r;var n=t.split(\".\");for(n.pop();n.length>1;)if(n.pop(),void 0!==(r=s(e,n.join(\".\")+\".uirevision\").get()))return r;return e.uirevision}function nt(t,e){for(var r=0;r<e.length;r++)if(e[r]._fullInput.uid===t)return r;return-1}function it(t,e,r){for(var n=0;n<e.length;n++)if(e[n].uid===t)return n;return!e[r]||e[r].uid?-1:r}function at(t,e){var r=o.isPlainObject(t),n=Array.isArray(t);return r||n?(r&&o.isPlainObject(e)||n&&Array.isArray(e))&&JSON.stringify(t)===JSON.stringify(e):t===e}function ot(t,e,r,n){var i,a,l,c=n.getValObject,u=n.flags,f=n.immutable,h=n.inArray,p=n.arrayIndex;function d(){var t=i.editType;h&&-1!==t.indexOf(\"arraydraw\")?o.pushUnique(u.arrays[h],p):(M.update(u,i),\"none\"!==t&&u.nChanges++,n.transition&&i.anim&&u.nChangesAnim++,(Y.test(l)||W.test(l))&&(u.rangesAltered[r[0]]=1),X.test(l)&&s(e,\"_inputDomain\").set(null),\"datarevision\"===a&&(u.newDataRevision=1))}function g(t){return\"data_array\"===t.valType||t.arrayOk}for(a in t){if(u.calc&&!n.transition)return;var m=t[a],v=e[a],y=r.concat(a);if(l=y.join(\".\"),\"_\"!==a.charAt(0)&&\"function\"!=typeof m&&m!==v){if((\"tick0\"===a||\"dtick\"===a)&&\"geo\"!==r[0]){var x=e.tickmode;if(\"auto\"===x||\"array\"===x||!x)continue}if((\"range\"!==a||!e.autorange)&&(\"zmin\"!==a&&\"zmax\"!==a||\"contourcarpet\"!==e.type)&&(i=c(y))&&(!i._compareAsJSON||JSON.stringify(m)!==JSON.stringify(v))){var b,_=i.valType,w=g(i),T=Array.isArray(m),k=Array.isArray(v);if(T&&k){var A=\"_input_\"+a,S=t[A],E=e[A];if(Array.isArray(S)&&S===E)continue}if(void 0===v)w&&T?u.calc=!0:d();else if(i._isLinkedToArray){var C=[],L=!1;h||(u.arrays[a]=C);var I=Math.min(m.length,v.length),P=Math.max(m.length,v.length);if(I!==P){if(\"arraydraw\"!==i.editType){d();continue}L=!0}for(b=0;b<I;b++)ot(m[b],v[b],y.concat(b),o.extendFlat({inArray:a,arrayIndex:b},n));if(L)for(b=I;b<P;b++)C.push(b)}else!_&&o.isPlainObject(m)?ot(m,v,y,n):w?T&&k?(f&&(u.calc=!0),(f||n.newDataRevision)&&d()):T!==k?u.calc=!0:d():T&&k&&m.length===v.length&&String(m)===String(v)||d()}}}for(a in e)if(!(a in t)&&\"_\"!==a.charAt(0)&&\"function\"!=typeof e[a]){if(g(i=c(r.concat(a)))&&Array.isArray(e[a]))return void(u.calc=!0);d()}}function st(t){var e=t._fullLayout,r=t.getBoundingClientRect();if(!o.equalDomRects(r,e._lastBBox)){var n=e._invTransform=o.inverseTransformMatrix(o.getFullTransformMatrix(t));e._invScaleX=Math.sqrt(n[0][0]*n[0][0]+n[0][1]*n[0][1]+n[0][2]*n[0][2]),e._invScaleY=Math.sqrt(n[1][0]*n[1][0]+n[1][1]*n[1][1]+n[1][2]*n[1][2]),e._lastBBox=r}}function lt(t){var e=n.select(t),r=t._fullLayout;if(r._calcInverseTransform=st,r._calcInverseTransform(t),r._container=e.selectAll(\".plot-container\").data([0]),r._container.enter().insert(\"div\",\":first-child\").classed(\"plot-container\",!0).classed(\"plotly\",!0),r._paperdiv=r._container.selectAll(\".svg-container\").data([0]),r._paperdiv.enter().append(\"div\").classed(\"user-select-none\",!0).classed(\"svg-container\",!0).style(\"position\",\"relative\"),r._glcontainer=r._paperdiv.selectAll(\".gl-container\").data([{}]),r._glcontainer.enter().append(\"div\").classed(\"gl-container\",!0),r._paperdiv.selectAll(\".main-svg\").remove(),r._paperdiv.select(\".modebar-container\").remove(),r._paper=r._paperdiv.insert(\"svg\",\":first-child\").classed(\"main-svg\",!0),r._toppaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),r._modebardiv=r._paperdiv.append(\"div\"),delete r._modeBar,r._hoverpaper=r._paperdiv.append(\"svg\").classed(\"main-svg\",!0),!r._uid){var i={};n.selectAll(\"defs\").each((function(){this.id&&(i[this.id.split(\"-\")[1]]=1)})),r._uid=o.randstr(i)}r._paperdiv.selectAll(\".main-svg\").attr(y.svgAttrs),r._defs=r._paper.append(\"defs\").attr(\"id\",\"defs-\"+r._uid),r._clips=r._defs.append(\"g\").classed(\"clips\",!0),r._topdefs=r._toppaper.append(\"defs\").attr(\"id\",\"topdefs-\"+r._uid),r._topclips=r._topdefs.append(\"g\").classed(\"clips\",!0),r._bgLayer=r._paper.append(\"g\").classed(\"bglayer\",!0),r._draggers=r._paper.append(\"g\").classed(\"draglayer\",!0);var a=r._paper.append(\"g\").classed(\"layer-below\",!0);r._imageLowerLayer=a.append(\"g\").classed(\"imagelayer\",!0),r._shapeLowerLayer=a.append(\"g\").classed(\"shapelayer\",!0),r._cartesianlayer=r._paper.append(\"g\").classed(\"cartesianlayer\",!0),r._polarlayer=r._paper.append(\"g\").classed(\"polarlayer\",!0),r._ternarylayer=r._paper.append(\"g\").classed(\"ternarylayer\",!0),r._geolayer=r._paper.append(\"g\").classed(\"geolayer\",!0),r._funnelarealayer=r._paper.append(\"g\").classed(\"funnelarealayer\",!0),r._pielayer=r._paper.append(\"g\").classed(\"pielayer\",!0),r._treemaplayer=r._paper.append(\"g\").classed(\"treemaplayer\",!0),r._sunburstlayer=r._paper.append(\"g\").classed(\"sunburstlayer\",!0),r._indicatorlayer=r._toppaper.append(\"g\").classed(\"indicatorlayer\",!0),r._glimages=r._paper.append(\"g\").classed(\"glimages\",!0);var s=r._toppaper.append(\"g\").classed(\"layer-above\",!0);r._imageUpperLayer=s.append(\"g\").classed(\"imagelayer\",!0),r._shapeUpperLayer=s.append(\"g\").classed(\"shapelayer\",!0),r._infolayer=r._toppaper.append(\"g\").classed(\"infolayer\",!0),r._menulayer=r._toppaper.append(\"g\").classed(\"menulayer\",!0),r._zoomlayer=r._toppaper.append(\"g\").classed(\"zoomlayer\",!0),r._hoverlayer=r._hoverpaper.append(\"g\").classed(\"hoverlayer\",!0),r._modebardiv.classed(\"modebar-container\",!0).style(\"position\",\"absolute\").style(\"top\",\"0px\").style(\"right\",\"0px\"),t.emit(\"plotly_framework\")}r.animate=function(t,e,r){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before animating it. For more details, see https://plotly.com/javascript/animations/\");var n=t._transitionData;n._frameQueue||(n._frameQueue=[]);var i=(r=h.supplyAnimationDefaults(r)).transition,a=r.frame;function s(t){return Array.isArray(i)?t>=i.length?i[0]:i[t]:i}function l(t){return Array.isArray(a)?t>=a.length?a[0]:a[t]:a}function c(t,e){var r=0;return function(){if(t&&++r===e)return t()}}return void 0===n._frameWaitingCnt&&(n._frameWaitingCnt=0),new Promise((function(a,u){function f(){n._currentFrame&&n._currentFrame.onComplete&&n._currentFrame.onComplete();var e=n._currentFrame=n._frameQueue.shift();if(e){var r=e.name?e.name.toString():null;t._fullLayout._currentFrame=r,n._lastFrameAt=Date.now(),n._timeToNext=e.frameOpts.duration,h.transition(t,e.frame.data,e.frame.layout,T.coerceTraceIndices(t,e.frame.traces),e.frameOpts,e.transitionOpts).then((function(){e.onComplete&&e.onComplete()})),t.emit(\"plotly_animatingframe\",{name:r,frame:e.frame,animation:{frame:e.frameOpts,transition:e.transitionOpts}})}else t.emit(\"plotly_animated\"),window.cancelAnimationFrame(n._animationRaf),n._animationRaf=null}function p(){t.emit(\"plotly_animating\"),n._lastFrameAt=-1/0,n._timeToNext=0,n._runningTransitions=0,n._currentFrame=null;var e=function(){n._animationRaf=window.requestAnimationFrame(e),Date.now()-n._lastFrameAt>n._timeToNext&&f()};e()}var d,g,m=0;function v(t){return Array.isArray(i)?m>=i.length?t.transitionOpts=i[m]:t.transitionOpts=i[0]:t.transitionOpts=i,m++,t}var y=[],x=null==e,b=Array.isArray(e);if(!x&&!b&&o.isPlainObject(e))y.push({type:\"object\",data:v(o.extendFlat({},e))});else if(x||-1!==[\"string\",\"number\"].indexOf(typeof e))for(d=0;d<n._frames.length;d++)(g=n._frames[d])&&(x||String(g.group)===String(e))&&y.push({type:\"byname\",name:String(g.name),data:v({name:g.name})});else if(b)for(d=0;d<e.length;d++){var _=e[d];-1!==[\"number\",\"string\"].indexOf(typeof _)?(_=String(_),y.push({type:\"byname\",name:_,data:v({name:_})})):o.isPlainObject(_)&&y.push({type:\"object\",data:v(o.extendFlat({},_))})}for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&!n._frameHash[g.data.name])return o.warn('animate failure: frame not found: \"'+g.data.name+'\"'),void u();-1!==[\"next\",\"immediate\"].indexOf(r.mode)&&function(){if(0!==n._frameQueue.length){for(;n._frameQueue.length;){var e=n._frameQueue.pop();e.onInterrupt&&e.onInterrupt()}t.emit(\"plotly_animationinterrupted\",[])}}(),\"reverse\"===r.direction&&y.reverse();var w=t._fullLayout._currentFrame;if(w&&r.fromcurrent){var k=-1;for(d=0;d<y.length;d++)if(\"byname\"===(g=y[d]).type&&g.name===w){k=d;break}if(k>0&&k<y.length-1){var M=[];for(d=0;d<y.length;d++)g=y[d],(\"byname\"!==y[d].type||d>k)&&M.push(g);y=M}}y.length>0?function(e){if(0!==e.length){for(var i=0;i<e.length;i++){var o;o=\"byname\"===e[i].type?h.computeFrame(t,e[i].name):e[i].data;var f=l(i),d=s(i);d.duration=Math.min(d.duration,f.duration);var g={frame:o,name:e[i].name,frameOpts:f,transitionOpts:d};i===e.length-1&&(g.onComplete=c(a,2),g.onInterrupt=u),n._frameQueue.push(g)}\"immediate\"===r.mode&&(n._lastFrameAt=-1/0),n._animationRaf||p()}}(y):(t.emit(\"plotly_animated\"),a())}))},r.addFrames=function(t,e,r){if(t=o.getGraphDiv(t),null==e)return Promise.resolve();if(!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t+\". It's likely that you've failed to create a plot before adding frames. For more details, see https://plotly.com/javascript/animations/\");var n,i,a,s,l=t._transitionData._frames,u=t._transitionData._frameHash;if(!Array.isArray(e))throw new Error(\"addFrames failure: frameList must be an Array of frame definitions\"+e);var f=l.length+2*e.length,p=[],d={};for(n=e.length-1;n>=0;n--)if(o.isPlainObject(e[n])){var g=e[n].name,m=(u[g]||d[g]||{}).name,v=e[n].name,y=u[m]||d[m];m&&v&&\"number\"==typeof v&&y&&S<5&&(S++,o.warn('addFrames: overwriting frame \"'+(u[m]||d[m]).name+'\" with a frame whose name of type \"number\" also equates to \"'+m+'\". This is valid but may potentially lead to unexpected behavior since all plotly.js frame names are stored internally as strings.'),5===S&&o.warn(\"addFrames: This API call has yielded too many of these warnings. For the rest of this call, further warnings about numeric frame names will be suppressed.\")),d[g]={name:g},p.push({frame:h.supplyFrameDefaults(e[n]),index:r&&void 0!==r[n]&&null!==r[n]?r[n]:f+n})}p.sort((function(t,e){return t.index>e.index?-1:t.index<e.index?1:0}));var x=[],b=[],_=l.length;for(n=p.length-1;n>=0;n--){if(\"number\"==typeof(i=p[n].frame).name&&o.warn(\"Warning: addFrames accepts frames with numeric names, but the numbers areimplicitly cast to strings\"),!i.name)for(;u[i.name=\"frame \"+t._transitionData._counter++];);if(u[i.name]){for(a=0;a<l.length&&(l[a]||{}).name!==i.name;a++);x.push({type:\"replace\",index:a,value:i}),b.unshift({type:\"replace\",index:a,value:l[a]})}else s=Math.max(0,Math.min(p[n].index,_)),x.push({type:\"insert\",index:s,value:i}),b.unshift({type:\"delete\",index:s}),_++}var w=h.modifyFrames,T=h.modifyFrames,k=[t,b],M=[t,x];return c&&c.add(t,w,k,T,M),h.modifyFrames(t,x)},r.deleteFrames=function(t,e){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);var r,n,i=t._transitionData._frames,a=[],s=[];if(!e)for(e=[],r=0;r<i.length;r++)e.push(r);for((e=e.slice()).sort(),r=e.length-1;r>=0;r--)n=e[r],a.push({type:\"delete\",index:n}),s.unshift({type:\"insert\",index:n,value:i[n]});var l=h.modifyFrames,u=h.modifyFrames,f=[t,s],p=[t,a];return c&&c.add(t,l,f,u,p),h.modifyFrames(t,a)},r.addTraces=function t(e,n,i){e=o.getGraphDiv(e);var a,s,l=[],u=r.deleteTraces,f=t,h=[e,l],p=[e,n];for(function(t,e,r){var n,i;if(!Array.isArray(t.data))throw new Error(\"gd.data must be an array.\");if(\"undefined\"==typeof e)throw new Error(\"traces must be defined.\");for(Array.isArray(e)||(e=[e]),n=0;n<e.length;n++)if(\"object\"!=typeof(i=e[n])||Array.isArray(i)||null===i)throw new Error(\"all values in traces array must be non-array objects\");if(\"undefined\"==typeof r||Array.isArray(r)||(r=[r]),\"undefined\"!=typeof r&&r.length!==e.length)throw new Error(\"if indices is specified, traces.length must equal indices.length\")}(e,n,i),Array.isArray(n)||(n=[n]),n=n.map((function(t){return o.extendFlat({},t)})),T.cleanData(n),a=0;a<n.length;a++)e.data.push(n[a]);for(a=0;a<n.length;a++)l.push(-n.length+a);if(\"undefined\"==typeof i)return s=r.redraw(e),c.add(e,u,h,f,p),s;Array.isArray(i)||(i=[i]);try{O(e,l,i)}catch(t){throw e.data.splice(e.data.length-n.length,n.length),t}return c.startSequence(e),c.add(e,u,h,f,p),s=r.moveTraces(e,l,i),c.stopSequence(e),s},r.deleteTraces=function t(e,n){e=o.getGraphDiv(e);var i,a,s=[],l=r.addTraces,u=t,f=[e,s,n],h=[e,n];if(\"undefined\"==typeof n)throw new Error(\"indices must be an integer or array of integers.\");for(Array.isArray(n)||(n=[n]),z(e,n,\"indices\"),(n=P(n,e.data.length-1)).sort(o.sorterDes),i=0;i<n.length;i+=1)a=e.data.splice(n[i],1)[0],s.push(a);var p=r.redraw(e);return c.add(e,l,f,u,h),p},r.extendTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<0){var a=new t.constructor(0),s=R(t,e);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(l)),i.set(t),i.set(e.subarray(0,l),t.length)}else{var c=r-e.length,u=t.length-c;n.set(t.subarray(u)),n.set(e,c),i.set(t.subarray(0,u))}else n=t.concat(e),i=r>=0&&r<n.length?n.splice(0,n.length-r):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.prependTraces,f,t,arguments),u},r.moveTraces=function t(e,n,i){var a,s=[],l=[],u=t,f=t,h=[e=o.getGraphDiv(e),i,n],p=[e,n,i];if(O(e,n,i),n=Array.isArray(n)?n:[n],\"undefined\"==typeof i)for(i=[],a=0;a<n.length;a++)i.push(-n.length+a);for(i=Array.isArray(i)?i:[i],n=P(n,e.data.length-1),i=P(i,e.data.length-1),a=0;a<e.data.length;a++)-1===n.indexOf(a)&&s.push(e.data[a]);for(a=0;a<n.length;a++)l.push({newIndex:i[a],trace:e.data[n[a]]});for(l.sort((function(t,e){return t.newIndex-e.newIndex})),a=0;a<l.length;a+=1)s.splice(l[a].newIndex,0,l[a].trace);e.data=s;var d=r.redraw(e);return c.add(e,u,h,f,p),d},r.prependTraces=function t(e,n,i,a){function s(t,e,r){var n,i;if(o.isTypedArray(t))if(r<=0){var a=new t.constructor(0),s=R(e,t);r<0?(n=s,i=a):(n=a,i=s)}else if(n=new t.constructor(r),i=new t.constructor(t.length+e.length-r),r===e.length)n.set(e),i.set(t);else if(r<e.length){var l=e.length-r;n.set(e.subarray(0,l)),i.set(e.subarray(l)),i.set(t,l)}else{var c=r-e.length;n.set(e),n.set(t.subarray(0,c),e.length),i.set(t.subarray(c))}else n=e.concat(t),i=r>=0&&r<n.length?n.splice(r,n.length):[];return[n,i]}var l=D(e=o.getGraphDiv(e),n,i,a,s),u=r.redraw(e),f=[e,l.update,i,l.maxPoints];return c.add(e,r.extendTraces,f,t,arguments),u},r.newPlot=function(t,e,n,i){return t=o.getGraphDiv(t),h.cleanPlot([],{},t._fullData||[],t._fullLayout||{}),h.purge(t),r.plot(t,e,n,i)},r.plot=function(t,e,i,a){var s;if(t=o.getGraphDiv(t),l.init(t),o.isPlainObject(e)){var c=e;e=c.data,i=c.layout,a=c.config,s=c.frames}if(!1===l.triggerHandler(t,\"plotly_beforeplot\",[e,i,a]))return Promise.reject();e||i||o.isPlotDiv(t)||o.warn(\"Calling Plotly.plot as if redrawing but this container doesn't yet have a plot.\",t),I(t,a),i||(i={}),n.select(t).classed(\"js-plotly-plot\",!0),g.makeTester(),Array.isArray(t._promises)||(t._promises=[]);var f=0===(t.data||[]).length&&Array.isArray(e);Array.isArray(e)&&(T.cleanData(e),f?t.data=e:t.data.push.apply(t.data,e),t.empty=!1),t.layout&&!f||(t.layout=T.cleanLayout(i)),h.supplyDefaults(t);var m=t._fullLayout,y=m._has(\"cartesian\");if(!m._has(\"polar\")&&e&&e[0]&&e[0].r)return o.log(\"Legacy polar charts are deprecated!\"),function(t,e,r){var i=n.select(t).selectAll(\".plot-container\").data([0]);i.enter().insert(\"div\",\":first-child\").classed(\"plot-container plotly\",!0);var a=i.selectAll(\".svg-container\").data([0]);a.enter().append(\"div\").classed(\"svg-container\",!0).style(\"position\",\"relative\"),a.html(\"\"),e&&(t.data=e);r&&(t.layout=r);p.manager.fillLayout(t),a.style({width:t._fullLayout.width+\"px\",height:t._fullLayout.height+\"px\"}),t.framework=p.manager.framework(t),t.framework({data:t.data,layout:t.layout},a.node()),t.framework.setUndoPoint();var s=t.framework.svg(),l=1,c=t._fullLayout.title?t._fullLayout.title.text:\"\";\"\"!==c&&c||(l=0);var u=function(){this.call(x.convertToTspans,t)},f=s.select(\".title-group text\").call(u);if(t._context.edits.titleText){var d=o._(t,\"Click to enter Plot title\");c&&c!==d||(l=.2,f.attr({\"data-unformatted\":d}).text(d).style({opacity:l}).on(\"mouseover.opacity\",(function(){n.select(this).transition().duration(100).style(\"opacity\",1)})).on(\"mouseout.opacity\",(function(){n.select(this).transition().duration(1e3).style(\"opacity\",0)})));var g=function(){this.call(x.makeEditable,{gd:t}).on(\"edit\",(function(e){t.framework({layout:{title:{text:e}}}),this.text(e).call(u),this.call(g)})).on(\"cancel\",(function(){var t=this.attr(\"data-unformatted\");this.text(t).call(u)}))};f.call(g)}return t._context.setBackground(t,t._fullLayout.paper_bgcolor),h.addLinks(t),Promise.resolve()}(t,e,i);m._replotting=!0,(f||m._shouldCreateBgLayer)&&(lt(t),m._shouldCreateBgLayer&&delete m._shouldCreateBgLayer),t.framework!==lt&&(t.framework=lt,lt(t)),g.initGradients(t),f&&d.saveShowSpikeInitial(t);var b=!t.calcdata||t.calcdata.length!==(t._fullData||[]).length;b&&h.doCalcdata(t);for(var _=0;_<t.calcdata.length;_++)t.calcdata[_][0].trace=t._fullData[_];t._context.responsive?t._responsiveChartHandler||(t._responsiveChartHandler=function(){o.isHidden(t)||h.resize(t)},window.addEventListener(\"resize\",t._responsiveChartHandler)):o.clearResponsive(t);var w=o.extendFlat({},m._size),M=0;function A(){if(h.clearAutoMarginIds(t),k.drawMarginPushers(t),d.allowAutoMargin(t),m._has(\"pie\"))for(var e=t._fullData,r=0;r<e.length;r++){var n=e[r];\"pie\"===n.type&&n.automargin&&h.allowAutoMargin(t,\"pie.\"+n.uid+\".automargin\")}return h.doAutoMargin(t),h.previousPromises(t)}function S(){t._transitioning||(k.doAutoRangeAndConstraints(t),f&&d.saveRangeInitial(t),u.getComponentMethod(\"rangeslider\",\"calcAutorange\")(t))}var C=[h.previousPromises,function(){if(s)return r.addFrames(t,s)},function e(){for(var r=m._basePlotModules,n=0;n<r.length;n++)r[n].drawFramework&&r[n].drawFramework(t);if(!m._glcanvas&&m._has(\"gl\")&&(m._glcanvas=m._glcontainer.selectAll(\".gl-canvas\").data([{key:\"contextLayer\",context:!0,pick:!1},{key:\"focusLayer\",context:!1,pick:!1},{key:\"pickLayer\",context:!1,pick:!0}],(function(t){return t.key})),m._glcanvas.enter().append(\"canvas\").attr(\"class\",(function(t){return\"gl-canvas gl-canvas-\"+t.key.replace(\"Layer\",\"\")})).style({position:\"absolute\",top:0,left:0,overflow:\"visible\",\"pointer-events\":\"none\"})),m._glcanvas){m._glcanvas.attr(\"width\",m.width).attr(\"height\",m.height);var i=m._glcanvas.data()[0].regl;if(i&&(Math.floor(m.width)!==i._gl.drawingBufferWidth||Math.floor(m.height)!==i._gl.drawingBufferHeight)){var a=\"WebGL context buffer and canvas dimensions do not match due to browser/WebGL bug.\";if(!M)return o.log(a+\" Clearing graph and plotting again.\"),h.cleanPlot([],{},t._fullData,m),h.supplyDefaults(t),m=t._fullLayout,h.doCalcdata(t),M++,e();o.error(a)}}return\"h\"===m.modebar.orientation?m._modebardiv.style(\"height\",null).style(\"width\",\"100%\"):m._modebardiv.style(\"width\",null).style(\"height\",m.height+\"px\"),h.previousPromises(t)},A,function(){if(h.didMarginChange(w,m._size))return o.syncOrAsync([A,k.layoutStyles],t)}];y&&C.push((function(){if(b)return o.syncOrAsync([u.getComponentMethod(\"shapes\",\"calcAutorange\"),u.getComponentMethod(\"annotations\",\"calcAutorange\"),S],t);S()})),C.push(k.layoutStyles),y&&C.push((function(){return d.draw(t,f?\"\":\"redraw\")}),(function(t){t._fullLayout._insideTickLabelsAutorange&&q(t,t._fullLayout._insideTickLabelsAutorange).then((function(){t._fullLayout._insideTickLabelsAutorange=void 0}))})),C.push(k.drawData,k.finalDraw,v,h.addLinks,h.rehover,h.redrag,h.doAutoMargin,(function(t){t._fullLayout._insideTickLabelsAutorange&&f&&d.saveRangeInitial(t,!0)}),h.previousPromises);var L=o.syncOrAsync(C,t);return L&&L.then||(L=Promise.resolve()),L.then((function(){return E(t),t}))},r.purge=function(t){var e=(t=o.getGraphDiv(t))._fullLayout||{},r=t._fullData||[];return h.cleanPlot([],{},r,e),h.purge(t),l.purge(t),e._container&&e._container.remove(),delete t._context,t},r.react=function(t,e,n,i){var a,l;t=o.getGraphDiv(t),T.clearPromiseQueue(t);var c=t._fullData,p=t._fullLayout;if(o.isPlotDiv(t)&&c&&p){if(o.isPlainObject(e)){var d=e;e=d.data,n=d.layout,i=d.config,a=d.frames}var g=!1;if(i){var m=o.extendDeep({},t._context);t._context=void 0,I(t,i),g=function t(e,r){var n;for(n in e)if(\"_\"!==n.charAt(0)){var i=e[n],a=r[n];if(i!==a)if(o.isPlainObject(i)&&o.isPlainObject(a)){if(t(i,a))return!0}else{if(!Array.isArray(i)||!Array.isArray(a))return!0;if(i.length!==a.length)return!0;for(var s=0;s<i.length;s++)if(i[s]!==a[s]){if(!o.isPlainObject(i[s])||!o.isPlainObject(a[s]))return!0;if(t(i[s],a[s]))return!0}}}}(m,t._context)}t.data=e||[],T.cleanData(t.data),t.layout=n||{},T.cleanLayout(t.layout),function(t,e,r,n){var i,a,l,c,u,f,h,p,d=n._preGUI,g=[],m={};for(i in d){if(u=et(i,$)){if(a=u.attr||u.head+\".uirevision\",(c=(l=s(n,a).get())&&rt(a,e))&&c===l&&(null===(f=d[i])&&(f=void 0),at(p=(h=s(e,i)).get(),f))){void 0===p&&\"autorange\"===i.substr(i.length-9)&&g.push(i.substr(0,i.length-10)),h.set(B(s(n,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i);delete d[i],\"range[\"===i.substr(i.length-8,6)&&(m[i.substr(0,i.length-9)]=1)}for(var v=0;v<g.length;v++){var y=g[v];if(m[y]){var x=s(e,y).get();x&&delete x.autorange}}var b=n._tracePreGUI;for(var _ in b){var w,T=b[_],k=null;for(i in T){if(!k){var M=nt(_,r);if(M<0){delete b[_];break}var A=it(_,t,(w=r[M]._fullInput).index);if(A<0){delete b[_];break}k=t[A]}if(u=et(i,tt)){if(u.attr?c=(l=s(n,u.attr).get())&&rt(u.attr,e):(l=w.uirevision,void 0===(c=k.uirevision)&&(c=e.uirevision)),c&&c===l&&(null===(f=T[i])&&(f=void 0),at(p=(h=s(k,i)).get(),f))){h.set(B(s(w,i).get()));continue}}else o.warn(\"unrecognized GUI edit: \"+i+\" in trace uid \"+_);delete T[i]}}}(t.data,t.layout,c,p),h.supplyDefaults(t,{skipUpdateCalc:!0});var v=t._fullData,y=t._fullLayout,x=void 0===y.datarevision,b=y.transition,_=function(t,e,r,n,i){var a=M.layoutFlags();function o(t){return f.getLayoutValObject(r,t)}a.arrays={},a.rangesAltered={},a.nChanges=0,a.nChangesAnim=0,ot(e,r,[],{getValObject:o,flags:a,immutable:n,transition:i,gd:t}),(a.plot||a.calc)&&(a.layoutReplot=!0);i&&a.nChanges&&a.nChangesAnim&&(a.anim=a.nChanges===a.nChangesAnim?\"all\":\"some\");return a}(t,p,y,x,b),w=_.newDataRevision,A=function(t,e,r,n,i,a){var o=e.length===r.length;if(!i&&!o)return{fullReplot:!0,calc:!0};var s,l,c=M.traceFlags();c.arrays={},c.nChanges=0,c.nChangesAnim=0;var u={getValObject:function(t){var e=f.getTraceValObject(l,t);return!l._module.animatable&&e.anim&&(e.anim=!1),e},flags:c,immutable:n,transition:i,newDataRevision:a,gd:t},p={};for(s=0;s<e.length;s++)if(r[s]){if(l=r[s]._fullInput,h.hasMakesDataTransform(l)&&(l=r[s]),p[l.uid])continue;p[l.uid]=1,ot(e[s]._fullInput,l,[],u)}(c.calc||c.plot)&&(c.fullReplot=!0);i&&c.nChanges&&c.nChangesAnim&&(c.anim=c.nChanges===c.nChangesAnim&&o?\"all\":\"some\");return c}(t,c,v,x,b,w);if(J(t)&&(_.layoutReplot=!0),A.calc||_.calc){t.calcdata=void 0;for(var S=Object.getOwnPropertyNames(y),C=0;C<S.length;C++){var L=S[C],P=L.substring(0,5);if(\"xaxis\"===P||\"yaxis\"===P){var z=y[L]._emptyCategories;z&&z()}}}else h.supplyDefaultsUpdateCalc(t.calcdata,v);var O=[];if(a&&(t._transitionData={},h.createTransitionData(t),O.push((function(){return r.addFrames(t,a)}))),y.transition&&!g&&(A.anim||_.anim))_.ticks&&O.push(k.doTicksRelayout),h.doCalcdata(t),k.doAutoRangeAndConstraints(t),O.push((function(){return h.transitionFromReact(t,A,_,p)}));else if(A.fullReplot||_.layoutReplot||g)t._fullLayout._skipDefaults=!0,O.push(r.plot);else{for(var D in _.arrays){var R=_.arrays[D];if(R.length){var F=u.getComponentMethod(D,\"drawOne\");if(F!==o.noop)for(var N=0;N<R.length;N++)F(t,R[N]);else{var j=u.getComponentMethod(D,\"draw\");if(j===o.noop)throw new Error(\"cannot draw components: \"+D);j(t)}}}O.push(h.previousPromises),A.style&&O.push(k.doTraceStyle),(A.colorbars||_.colorbars)&&O.push(k.doColorBars),_.legend&&O.push(k.doLegend),_.layoutstyle&&O.push(k.layoutStyles),_.axrange&&G(O),_.ticks&&O.push(k.doTicksRelayout),_.modebar&&O.push(k.doModeBar),_.camera&&O.push(k.doCamera),O.push(E)}O.push(h.rehover,h.redrag),(l=o.syncOrAsync(O,t))&&l.then||(l=Promise.resolve(t))}else l=r.newPlot(t,e,n,i);return l.then((function(){return t.emit(\"plotly_react\",{data:e,layout:n}),t}))},r.redraw=function(t){if(t=o.getGraphDiv(t),!o.isPlotDiv(t))throw new Error(\"This element is not a Plotly plot: \"+t);return T.cleanData(t.data),T.cleanLayout(t.layout),t.calcdata=void 0,r.plot(t).then((function(){return t.emit(\"plotly_redraw\"),t}))},r.relayout=q,r.restyle=F,r.setPlotConfig=function(t){return o.extendFlat(_,t)},r.update=K,r._guiRelayout=Q(q),r._guiRestyle=Q(F),r._guiUpdate=Q(K),r._storeDirectGUIEdit=function(t,e,r){for(var n in r){j(n,s(t,n).get(),r[n],e)}}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,\"../lib/events\":767,\"../lib/queue\":794,\"../lib/svg_text_utils\":803,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constants\":834,\"../plots/cartesian/graph_interact\":837,\"../plots/cartesian/select\":847,\"../plots/plots\":891,\"../plots/polar/legacy\":899,\"../registry\":911,\"./edit_types\":810,\"./helpers\":811,\"./manage_arrays\":813,\"./plot_config\":815,\"./plot_schema\":816,\"./subroutines\":818,d3:169,\"fast-isnumeric\":241,\"has-hover\":440}],815:[function(t,e,r){\"use strict\";var n={staticPlot:{valType:\"boolean\",dflt:!1},plotlyServerURL:{valType:\"string\",dflt:\"\"},editable:{valType:\"boolean\",dflt:!1},edits:{annotationPosition:{valType:\"boolean\",dflt:!1},annotationTail:{valType:\"boolean\",dflt:!1},annotationText:{valType:\"boolean\",dflt:!1},axisTitleText:{valType:\"boolean\",dflt:!1},colorbarPosition:{valType:\"boolean\",dflt:!1},colorbarTitleText:{valType:\"boolean\",dflt:!1},legendPosition:{valType:\"boolean\",dflt:!1},legendText:{valType:\"boolean\",dflt:!1},shapePosition:{valType:\"boolean\",dflt:!1},titleText:{valType:\"boolean\",dflt:!1}},autosizable:{valType:\"boolean\",dflt:!1},responsive:{valType:\"boolean\",dflt:!1},fillFrame:{valType:\"boolean\",dflt:!1},frameMargins:{valType:\"number\",dflt:0,min:0,max:.5},scrollZoom:{valType:\"flaglist\",flags:[\"cartesian\",\"gl3d\",\"geo\",\"mapbox\"],extras:[!0,!1],dflt:\"gl3d+geo+mapbox\"},doubleClick:{valType:\"enumerated\",values:[!1,\"reset\",\"autosize\",\"reset+autosize\"],dflt:\"reset+autosize\"},doubleClickDelay:{valType:\"number\",dflt:300,min:0},showAxisDragHandles:{valType:\"boolean\",dflt:!0},showAxisRangeEntryBoxes:{valType:\"boolean\",dflt:!0},showTips:{valType:\"boolean\",dflt:!0},showLink:{valType:\"boolean\",dflt:!1},linkText:{valType:\"string\",dflt:\"Edit chart\",noBlank:!0},sendData:{valType:\"boolean\",dflt:!0},showSources:{valType:\"any\",dflt:!1},displayModeBar:{valType:\"enumerated\",values:[\"hover\",!0,!1],dflt:\"hover\"},showSendToCloud:{valType:\"boolean\",dflt:!1},showEditInChartStudio:{valType:\"boolean\",dflt:!1},modeBarButtonsToRemove:{valType:\"any\",dflt:[]},modeBarButtonsToAdd:{valType:\"any\",dflt:[]},modeBarButtons:{valType:\"any\",dflt:!1},toImageButtonOptions:{valType:\"any\",dflt:{}},displaylogo:{valType:\"boolean\",dflt:!0},watermark:{valType:\"boolean\",dflt:!1},plotGlPixelRatio:{valType:\"number\",dflt:2,min:1,max:4},setBackground:{valType:\"any\",dflt:\"transparent\"},topojsonURL:{valType:\"string\",noBlank:!0,dflt:\"https://cdn.plot.ly/\"},mapboxAccessToken:{valType:\"string\",dflt:null},logging:{valType:\"integer\",min:0,max:2,dflt:1},notifyOnLogging:{valType:\"integer\",min:0,max:2,dflt:0},queueLength:{valType:\"integer\",min:0,dflt:0},globalTransforms:{valType:\"any\",dflt:[]},locale:{valType:\"string\",dflt:\"en-US\"},locales:{valType:\"any\",dflt:{}}},i={};!function t(e,r){for(var n in e){var i=e[n];i.valType?r[n]=i.dflt:(r[n]||(r[n]={}),t(i,r[n]))}}(n,i),e.exports={configAttributes:n,dfltConfig:i}},{}],816:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=t(\"../plots/attributes\"),o=t(\"../plots/layout_attributes\"),s=t(\"../plots/frame_attributes\"),l=t(\"../plots/animation_attributes\"),c=t(\"./plot_config\").configAttributes,u=t(\"../plots/polar/legacy/area_attributes\"),f=t(\"../plots/polar/legacy/axis_attributes\"),h=t(\"./edit_types\"),p=i.extendFlat,d=i.extendDeepAll,g=i.isPlainObject,m=i.isArrayOrTypedArray,v=i.nestedProperty,y=i.valObjectMeta,x=[\"_isSubplotObj\",\"_isLinkedToArray\",\"_arrayAttrRegexps\",\"_deprecated\"];function b(t,e,r){if(!t)return!1;if(t._isLinkedToArray)if(_(e[r]))r++;else if(r<e.length)return!1;for(;r<e.length;r++){var n=t[e[r]];if(!g(n))break;if(t=n,r===e.length-1)break;if(t._isLinkedToArray){if(!_(e[++r]))return!1}else if(\"info_array\"===t.valType){var i=e[++r];if(!_(i))return!1;var a=t.items;if(Array.isArray(a)){if(i>=a.length)return!1;if(2===t.dimensions){if(r++,e.length===r)return t;var o=e[r];if(!_(o))return!1;t=a[i][o]}else t=a[i]}else t=a}}return t}function _(t){return t===Math.round(t)&&t>=0}function w(){var t,e,r={};for(t in d(r,o),n.subplotsRegistry){if((e=n.subplotsRegistry[t]).layoutAttributes)if(Array.isArray(e.attr))for(var i=0;i<e.attr.length;i++)M(r,e,e.attr[i]);else M(r,e,\"subplot\"===e.attr?e.name:e.attr)}for(t in r=function(t){return p(t,{radialaxis:f.radialaxis,angularaxis:f.angularaxis}),p(t,f.layout),t}(r),n.componentsRegistry){var a=(e=n.componentsRegistry[t]).schema;if(a&&(a.subplots||a.layout)){var s=a.subplots;if(s&&s.xaxis&&!s.yaxis)for(var l in s.xaxis)delete r.yaxis[l]}else\"colorscale\"===e.name?d(r,e.layoutAttributes):e.layoutAttributes&&A(r,e.layoutAttributes,e.name)}return{layoutAttributes:k(r)}}function T(){var t={frames:d({},s)};return k(t),t.frames}function k(t){return function(t){r.crawl(t,(function(t,e,n){r.isValObject(t)?\"data_array\"===t.valType?(t.role=\"data\",n[e+\"src\"]={valType:\"string\",editType:\"none\"}):!0===t.arrayOk&&(n[e+\"src\"]={valType:\"string\",editType:\"none\"}):g(t)&&(t.role=\"object\")}))}(t),function(t){r.crawl(t,(function(t,e,r){if(t){var n=t._isLinkedToArray;n&&(delete t._isLinkedToArray,r[e]={items:{}},r[e].items[n]=t,r[e].role=\"object\")}}))}(t),function(t){!function t(e){for(var r in e)if(g(e[r]))t(e[r]);else if(Array.isArray(e[r]))for(var n=0;n<e[r].length;n++)t(e[r][n]);else e[r]instanceof RegExp&&(e[r]=e[r].toString())}(t)}(t),t}function M(t,e,r){var n=v(t,r),i=d({},e.layoutAttributes);i._isSubplotObj=!0,n.set(i)}function A(t,e,r){var n=v(t,r);n.set(d(n.get()||{},e))}r.IS_SUBPLOT_OBJ=\"_isSubplotObj\",r.IS_LINKED_TO_ARRAY=\"_isLinkedToArray\",r.DEPRECATED=\"_deprecated\",r.UNDERSCORE_ATTRS=x,r.get=function(){var t={};n.allTypes.concat(\"area\").forEach((function(e){t[e]=function(t){var e,i;\"area\"===t?(e={attributes:u},i={}):(e=n.modules[t]._module,i=e.basePlotModule);var o={type:null},s=d({},a),l=d({},e.attributes);r.crawl(l,(function(t,e,r,n,i){v(s,i).set(void 0),void 0===t&&v(l,i).set(void 0)})),d(o,s),n.traceIs(t,\"noOpacity\")&&delete o.opacity;n.traceIs(t,\"showLegend\")||(delete o.showlegend,delete o.legendgroup);n.traceIs(t,\"noHover\")&&(delete o.hoverinfo,delete o.hoverlabel);e.selectPoints||delete o.selectedpoints;d(o,l),i.attributes&&d(o,i.attributes);o.type=t;var c={meta:e.meta||{},categories:e.categories||{},animatable:Boolean(e.animatable),type:t,attributes:k(o)};if(e.layoutAttributes){var f={};d(f,e.layoutAttributes),c.layoutAttributes=k(f)}e.animatable||r.crawl(c,(function(t){r.isValObject(t)&&\"anim\"in t&&delete t.anim}));return c}(e)}));var e={};return Object.keys(n.transformsRegistry).forEach((function(t){e[t]=function(t){var e=n.transformsRegistry[t],r=d({},e.attributes);return Object.keys(n.componentsRegistry).forEach((function(e){var i=n.componentsRegistry[e];i.schema&&i.schema.transforms&&i.schema.transforms[t]&&Object.keys(i.schema.transforms[t]).forEach((function(e){A(r,i.schema.transforms[t][e],e)}))})),{attributes:k(r)}}(t)})),{defs:{valObjects:y,metaKeys:x.concat([\"description\",\"role\",\"editType\",\"impliedEdits\"]),editType:{traces:h.traces,layout:h.layout},impliedEdits:{}},traces:t,layout:w(),transforms:e,frames:T(),animation:k(l),config:k(c)}},r.crawl=function(t,e,n,i){var a=n||0;i=i||\"\",Object.keys(t).forEach((function(n){var o=t[n];if(-1===x.indexOf(n)){var s=(i?i+\".\":\"\")+n;e(o,n,t,a,s),r.isValObject(o)||g(o)&&\"impliedEdits\"!==n&&r.crawl(o,e,a+1,s)}}))},r.isValObject=function(t){return t&&void 0!==t.valType},r.findArrayAttributes=function(t){var e,n,i=[],o=[],s=[];function l(t,r,a,l){o=o.slice(0,l).concat([r]),s=s.slice(0,l).concat([t&&t._isLinkedToArray]),t&&(\"data_array\"===t.valType||!0===t.arrayOk)&&!(\"colorbar\"===o[l-1]&&(\"ticktext\"===r||\"tickvals\"===r))&&function t(e,r,a){var l=e[o[r]],c=a+o[r];if(r===o.length-1)m(l)&&i.push(n+c);else if(s[r]){if(Array.isArray(l))for(var u=0;u<l.length;u++)g(l[u])&&t(l[u],r+1,c+\"[\"+u+\"].\")}else g(l)&&t(l,r+1,c+\".\")}(e,0,\"\")}e=t,n=\"\",r.crawl(a,l),t._module&&t._module.attributes&&r.crawl(t._module.attributes,l);var c=t.transforms;if(c)for(var u=0;u<c.length;u++){var f=c[u],h=f._module;h&&(n=\"transforms[\"+u+\"].\",e=f,r.crawl(h.attributes,l))}return i},r.getTraceValObject=function(t,e){var r,i,o=e[0],s=1;if(\"transforms\"===o){if(1===e.length)return a.transforms;var l=t.transforms;if(!Array.isArray(l)||!l.length)return!1;var c=e[1];if(!_(c)||c>=l.length)return!1;i=(r=(n.transformsRegistry[l[c].type]||{}).attributes)&&r[e[2]],s=3}else if(\"area\"===t.type)i=u[o];else{var f=t._module;if(f||(f=(n.modules[t.type||a.type.dflt]||{})._module),!f)return!1;if(!(i=(r=f.attributes)&&r[o])){var h=f.basePlotModule;h&&h.attributes&&(i=h.attributes[o])}i||(i=a[o])}return b(i,e,s)},r.getLayoutValObject=function(t,e){return b(function(t,e){var r,i,a,s,l=t._basePlotModules;if(l){var c;for(r=0;r<l.length;r++){if((a=l[r]).attrRegex&&a.attrRegex.test(e)){if(a.layoutAttrOverrides)return a.layoutAttrOverrides;!c&&a.layoutAttributes&&(c=a.layoutAttributes)}var u=a.baseLayoutAttrOverrides;if(u&&e in u)return u[e]}if(c)return c}var h=t._modules;if(h)for(r=0;r<h.length;r++)if((s=h[r].layoutAttributes)&&e in s)return s[e];for(i in n.componentsRegistry){if(\"colorscale\"===(a=n.componentsRegistry[i]).name&&0===e.indexOf(\"coloraxis\"))return a.layoutAttributes[e];if(!a.schema&&e===a.name)return a.layoutAttributes}if(e in o)return o[e];if(\"radialaxis\"===e||\"angularaxis\"===e)return f[e];return f.layout[e]||!1}(t,e[0]),e,1)}},{\"../lib\":778,\"../plots/animation_attributes\":822,\"../plots/attributes\":824,\"../plots/frame_attributes\":857,\"../plots/layout_attributes\":882,\"../plots/polar/legacy/area_attributes\":897,\"../plots/polar/legacy/axis_attributes\":898,\"../registry\":911,\"./edit_types\":810,\"./plot_config\":815}],817:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/attributes\"),a={name:{valType:\"string\",editType:\"none\"}};function o(t){return t&&\"string\"==typeof t}function s(t){var e=t.length-1;return\"s\"!==t.charAt(e)&&n.warn(\"bad argument to arrayDefaultKey: \"+t),t.substr(0,t.length-1)+\"defaults\"}a.templateitemname={valType:\"string\",editType:\"calc\"},r.templatedArray=function(t,e){return e._isLinkedToArray=t,e.name=a.name,e.templateitemname=a.templateitemname,e},r.traceTemplater=function(t){var e,r,a={};for(e in t)r=t[e],Array.isArray(r)&&r.length&&(a[e]=0);return{newTrace:function(o){var s={type:e=n.coerce(o,{},i,\"type\"),_template:null};if(e in a){r=t[e];var l=a[e]%r.length;a[e]++,s._template=r[l]}return s}}},r.newContainer=function(t,e,r){var i=t._template,a=i&&(i[e]||r&&i[r]);return n.isPlainObject(a)||(a=null),t[e]={_template:a}},r.arrayTemplater=function(t,e,r){var n=t._template,i=n&&n[s(e)],a=n&&n[e];Array.isArray(a)&&a.length||(a=[]);var l={};return{newItem:function(t){var e={name:t.name,_input:t},n=e.templateitemname=t.templateitemname;if(!o(n))return e._template=i,e;for(var s=0;s<a.length;s++){var c=a[s];if(c.name===n)return l[n]=1,e._template=c,e}return e[r]=t[r]||!1,e._template=!1,e},defaultItems:function(){for(var t=[],e=0;e<a.length;e++){var r=a[e],n=r.name;if(o(n)&&!l[n]){var i={_template:r,name:n,_input:{_templateitemname:n}};i.templateitemname=r.templateitemname,t.push(i),l[n]=1}}return t}}},r.arrayDefaultKey=s,r.arrayEditor=function(t,e,r){var i=(n.nestedProperty(t,e).get()||[]).length,a=r._index,o=a>=i&&(r._input||{})._templateitemname;o&&(a=i);var s,l=e+\"[\"+a+\"]\";function c(){s={},o&&(s[l]={},s[l].templateitemname=o)}function u(t,e){o?n.nestedProperty(s[l],t).set(e):s[l+\".\"+t]=e}function f(){var t=s;return c(),t}return c(),{modifyBase:function(t,e){s[t]=e},modifyItem:u,getUpdateObj:f,applyUpdate:function(e,r){e&&u(e,r);var i=f();for(var a in i)n.nestedProperty(t,a).set(i[a])}}}},{\"../lib\":778,\"../plots/attributes\":824}],818:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../registry\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../lib/clear_gl_canvases\"),l=t(\"../components/color\"),c=t(\"../components/drawing\"),u=t(\"../components/titles\"),f=t(\"../components/modebar\"),h=t(\"../plots/cartesian/axes\"),p=t(\"../constants/alignment\"),d=t(\"../plots/cartesian/constraints\"),g=d.enforce,m=d.clean,v=t(\"../plots/cartesian/autorange\").doAutoRange;function y(t,e,r){for(var n=0;n<r.length;n++){var i=r[n][0],a=r[n][1];if(!(i[0]>=t[1]||i[1]<=t[0])&&(a[0]<e[1]&&a[1]>e[0]))return!0}return!1}function x(t){var e,i,s,u,d,g,m=t._fullLayout,v=m._size,x=v.p,_=h.list(t,\"\",!0);if(m._paperdiv.style({width:t._context.responsive&&m.autosize&&!t._context._hasZeroWidth&&!t.layout.width?\"100%\":m.width+\"px\",height:t._context.responsive&&m.autosize&&!t._context._hasZeroHeight&&!t.layout.height?\"100%\":m.height+\"px\"}).selectAll(\".main-svg\").call(c.setSize,m.width,m.height),t._context.setBackground(t,m.paper_bgcolor),r.drawMainTitle(t),f.manage(t),!m._has(\"cartesian\"))return a.previousPromises(t);function T(t,e,r){var n=t._lw/2;return\"x\"===t._id.charAt(0)?e?\"top\"===r?e._offset-x-n:e._offset+e._length+x+n:v.t+v.h*(1-(t.position||0))+n%1:e?\"right\"===r?e._offset+e._length+x+n:e._offset-x-n:v.l+v.w*(t.position||0)+n%1}for(e=0;e<_.length;e++){var k=(u=_[e])._anchorAxis;u._linepositions={},u._lw=c.crispRound(t,u.linewidth,1),u._mainLinePosition=T(u,k,u.side),u._mainMirrorPosition=u.mirror&&k?T(u,k,p.OPPOSITE_SIDE[u.side]):null}var M=[],A=[],S=[],E=1===l.opacity(m.paper_bgcolor)&&1===l.opacity(m.plot_bgcolor)&&m.paper_bgcolor===m.plot_bgcolor;for(i in m._plots)if((s=m._plots[i]).mainplot)s.bg&&s.bg.remove(),s.bg=void 0;else{var C=s.xaxis.domain,L=s.yaxis.domain,I=s.plotgroup;if(y(C,L,S)){var P=I.node(),z=s.bg=o.ensureSingle(I,\"rect\",\"bg\");P.insertBefore(z.node(),P.childNodes[0]),A.push(i)}else I.select(\"rect.bg\").remove(),S.push([C,L]),E||(M.push(i),A.push(i))}var O,D,R,F,B,N,j,U,V,q,H,G,Y,W=m._bgLayer.selectAll(\".bg\").data(M);for(W.enter().append(\"rect\").classed(\"bg\",!0),W.exit().remove(),W.each((function(t){m._plots[t].bg=n.select(this)})),e=0;e<A.length;e++)s=m._plots[A[e]],d=s.xaxis,g=s.yaxis,s.bg&&void 0!==d._offset&&void 0!==g._offset&&s.bg.call(c.setRect,d._offset-x,g._offset-x,d._length+2*x,g._length+2*x).call(l.fill,m.plot_bgcolor).style(\"stroke-width\",0);if(!m._hasOnlyLargeSploms)for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var X,Z,J=s.clipId=\"clip\"+m._uid+i+\"plot\",K=o.ensureSingleById(m._clips,\"clipPath\",J,(function(t){t.classed(\"plotclip\",!0).append(\"rect\")}));s.clipRect=K.select(\"rect\").attr({width:d._length,height:g._length}),c.setTranslate(s.plot,d._offset,g._offset),s._hasClipOnAxisFalse?(X=null,Z=J):(X=J,Z=null),c.setClipUrl(s.plot,X,t),s.layerClipId=Z}function Q(t){return\"M\"+O+\",\"+t+\"H\"+D}function $(t){return\"M\"+d._offset+\",\"+t+\"h\"+d._length}function tt(t){return\"M\"+t+\",\"+U+\"V\"+j}function et(t){return\"M\"+t+\",\"+g._offset+\"v\"+g._length}function rt(t,e,r){if(!t.showline||i!==t._mainSubplot)return\"\";if(!t._anchorAxis)return r(t._mainLinePosition);var n=e(t._mainLinePosition);return t.mirror&&(n+=e(t._mainMirrorPosition)),n}for(i in m._plots){s=m._plots[i],d=s.xaxis,g=s.yaxis;var nt=\"M0,0\";b(d,i)&&(B=w(d,\"left\",g,_),O=d._offset-(B?x+B:0),N=w(d,\"right\",g,_),D=d._offset+d._length+(N?x+N:0),R=T(d,g,\"bottom\"),F=T(d,g,\"top\"),!(Y=!d._anchorAxis||i!==d._mainSubplot)||\"allticks\"!==d.mirror&&\"all\"!==d.mirror||(d._linepositions[i]=[R,F]),nt=rt(d,Q,$),Y&&d.showline&&(\"all\"===d.mirror||\"allticks\"===d.mirror)&&(nt+=Q(R)+Q(F)),s.xlines.style(\"stroke-width\",d._lw+\"px\").call(l.stroke,d.showline?d.linecolor:\"rgba(0,0,0,0)\")),s.xlines.attr(\"d\",nt);var it=\"M0,0\";b(g,i)&&(H=w(g,\"bottom\",d,_),j=g._offset+g._length+(H?x:0),G=w(g,\"top\",d,_),U=g._offset-(G?x:0),V=T(g,d,\"left\"),q=T(g,d,\"right\"),!(Y=!g._anchorAxis||i!==g._mainSubplot)||\"allticks\"!==g.mirror&&\"all\"!==g.mirror||(g._linepositions[i]=[V,q]),it=rt(g,tt,et),Y&&g.showline&&(\"all\"===g.mirror||\"allticks\"===g.mirror)&&(it+=tt(V)+tt(q)),s.ylines.style(\"stroke-width\",g._lw+\"px\").call(l.stroke,g.showline?g.linecolor:\"rgba(0,0,0,0)\")),s.ylines.attr(\"d\",it)}return h.makeClipPaths(t),a.previousPromises(t)}function b(t,e){return(t.ticks||t.showline)&&(e===t._mainSubplot||\"all\"===t.mirror||\"allticks\"===t.mirror)}function _(t,e,r){if(!r.showline||!r._lw)return!1;if(\"all\"===r.mirror||\"allticks\"===r.mirror)return!0;var n=r._anchorAxis;if(!n)return!1;var i=p.FROM_BL[e];return r.side===e?n.domain[i]===t.domain[i]:r.mirror&&n.domain[1-i]===t.domain[1-i]}function w(t,e,r,n){if(_(t,e,r))return r._lw;for(var i=0;i<n.length;i++){var a=n[i];if(a._mainAxis===r._mainAxis&&_(t,e,a))return a._lw}return 0}function T(t,e){var r=t.title,n=t._size,i=0;switch(\"start\"===e?i=r.pad.l:\"end\"===e&&(i=-r.pad.r),r.xref){case\"paper\":return n.l+n.w*r.x+i;case\"container\":default:return t.width*r.x+i}}function k(t,e){var r=t.title,n=t._size,i=0;if(\"0em\"!==e&&e?e===p.CAP_SHIFT+\"em\"&&(i=r.pad.t):i=-r.pad.b,\"auto\"===r.y)return n.t/2;switch(r.yref){case\"paper\":return n.t+n.h-n.h*r.y+i;case\"container\":default:return t.height-t.height*r.y+i}}r.layoutStyles=function(t){return o.syncOrAsync([a.doAutoMargin,x],t)},r.drawMainTitle=function(t){var e=t._fullLayout,r=function(t){var e=t.title,r=\"middle\";o.isRightAnchor(e)?r=\"end\":o.isLeftAnchor(e)&&(r=\"start\");return r}(e),n=function(t){var e=t.title,r=\"0em\";o.isTopAnchor(e)?r=p.CAP_SHIFT+\"em\":o.isMiddleAnchor(e)&&(r=p.MID_SHIFT+\"em\");return r}(e);u.draw(t,\"gtitle\",{propContainer:e,propName:\"title.text\",placeholder:e._dfltTitle.plot,attributes:{x:T(e,r),y:k(e,n),\"text-anchor\":r,dy:n}})},r.doTraceStyle=function(t){var e,n=t.calcdata,o=[];for(e=0;e<n.length;e++){var l=n[e],c=l[0]||{},u=c.trace||{},f=u._module||{},h=f.arraysToCalcdata;h&&h(l,u);var p=f.editStyle;p&&o.push({fn:p,cd0:c})}if(o.length){for(e=0;e<o.length;e++){var d=o[e];d.fn(t,d.cd0)}s(t),r.redrawReglTraces(t)}return a.style(t),i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doColorBars=function(t){return i.getComponentMethod(\"colorbar\",\"draw\")(t),a.previousPromises(t)},r.layoutReplot=function(t){var e=t.layout;return t.layout=void 0,i.call(\"plot\",t,\"\",e)},r.doLegend=function(t){return i.getComponentMethod(\"legend\",\"draw\")(t),a.previousPromises(t)},r.doTicksRelayout=function(t){return h.draw(t,\"redraw\"),t._fullLayout._hasOnlyLargeSploms&&(i.subplotsRegistry.splom.updateGrid(t),s(t),r.redrawReglTraces(t)),r.drawMainTitle(t),a.previousPromises(t)},r.doModeBar=function(t){var e=t._fullLayout;f.manage(t);for(var r=0;r<e._basePlotModules.length;r++){var n=e._basePlotModules[r].updateFx;n&&n(t)}return a.previousPromises(t)},r.doCamera=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){var i=e[r[n]];i._scene.setViewport(i)}},r.drawData=function(t){var e=t._fullLayout;s(t);for(var n=e._basePlotModules,o=0;o<n.length;o++)n[o].plot(t);return r.redrawReglTraces(t),a.style(t),i.getComponentMethod(\"shapes\",\"draw\")(t),i.getComponentMethod(\"annotations\",\"draw\")(t),i.getComponentMethod(\"images\",\"draw\")(t),e._replotting=!1,a.previousPromises(t)},r.redrawReglTraces=function(t){var e=t._fullLayout;if(e._has(\"regl\")){var r,n,i=t._fullData,a=[],s=[];for(e._hasOnlyLargeSploms&&e._splomGrid.draw(),r=0;r<i.length;r++){var l=i[r];!0===l.visible&&0!==l._length&&(\"splom\"===l.type?e._splomScenes[l.uid].draw():\"scattergl\"===l.type?o.pushUnique(a,l.xaxis+l.yaxis):\"scatterpolargl\"===l.type&&o.pushUnique(s,l.subplot))}for(r=0;r<a.length;r++)(n=e._plots[a[r]])._scene&&n._scene.draw();for(r=0;r<s.length;r++)(n=e[s[r]]._subplot)._scene&&n._scene.draw()}},r.doAutoRangeAndConstraints=function(t){for(var e,r=h.list(t,\"\",!0),n={},i=0;i<r.length;i++)if(!n[(e=r[i])._id]){n[e._id]=1,m(t,e),v(t,e);var a=e._matchGroup;if(a)for(var o in a){var s=h.getFromId(t,o);v(t,s,e.range),n[o]=1}}g(t)},r.finalDraw=function(t){i.getComponentMethod(\"rangeslider\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t)},r.drawMarginPushers=function(t){i.getComponentMethod(\"legend\",\"draw\")(t),i.getComponentMethod(\"rangeselector\",\"draw\")(t),i.getComponentMethod(\"sliders\",\"draw\")(t),i.getComponentMethod(\"updatemenus\",\"draw\")(t),i.getComponentMethod(\"colorbar\",\"draw\")(t)}},{\"../components/color\":643,\"../components/drawing\":665,\"../components/modebar\":703,\"../components/titles\":738,\"../constants/alignment\":745,\"../lib\":778,\"../lib/clear_gl_canvases\":762,\"../plots/cartesian/autorange\":827,\"../plots/cartesian/axes\":828,\"../plots/cartesian/constraints\":835,\"../plots/plots\":891,\"../registry\":911,d3:169}],819:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=n.isPlainObject,a=t(\"./plot_schema\"),o=t(\"../plots/plots\"),s=t(\"../plots/attributes\"),l=t(\"./plot_template\"),c=t(\"./plot_config\").dfltConfig;function u(t,e){t=n.extendDeep({},t);var r,a,o=Object.keys(t).sort();function s(e,r,n){if(i(r)&&i(e))u(e,r);else if(Array.isArray(r)&&Array.isArray(e)){var o=l.arrayTemplater({_template:t},n);for(a=0;a<r.length;a++){var s=r[a],c=o.newItem(s)._template;c&&u(c,s)}var f=o.defaultItems();for(a=0;a<f.length;a++)r.push(f[a]._template);for(a=0;a<r.length;a++)delete r[a].templateitemname}}for(r=0;r<o.length;r++){var c=o[r],h=t[c];if(c in e?s(h,e[c],c):e[c]=h,f(c)===c)for(var p in e){var d=f(p);p===d||d!==c||p in t||s(h,e[p],c)}}}function f(t){return t.replace(/[0-9]+$/,\"\")}function h(t,e,r,a,o){var s=o&&r(o);for(var c in t){var u=t[c],p=g(t,c,a),d=g(t,c,o),m=r(d);if(!m){var v=f(c);v!==c&&(m=r(d=g(t,v,o)))}if((!s||s!==m)&&!(!m||m._noTemplating||\"data_array\"===m.valType||m.arrayOk&&Array.isArray(u)))if(!m.valType&&i(u))h(u,e,r,p,d);else if(m._isLinkedToArray&&Array.isArray(u))for(var y=!1,x=0,b={},_=0;_<u.length;_++){var w=u[_];if(i(w)){var T=w.name;if(T)b[T]||(h(w,e,r,g(u,x,p),g(u,x,d)),x++,b[T]=1);else if(!y){var k=g(t,l.arrayDefaultKey(c),a),M=g(u,x,p);h(w,e,r,M,g(u,x,d));var A=n.nestedProperty(e,M);n.nestedProperty(e,k).set(A.get()),A.set(null),y=!0}}}else{n.nestedProperty(e,p).set(u)}}}function p(t,e){return a.getLayoutValObject(t,n.nestedProperty({},e).parts)}function d(t,e){return a.getTraceValObject(t,n.nestedProperty({},e).parts)}function g(t,e,r){return r?Array.isArray(t)?r+\"[\"+e+\"]\":r+\".\"+e:e}function m(t){for(var e=0;e<t.length;e++)if(i(t[e]))return!0}function v(t){var e;switch(t.code){case\"data\":e=\"The template has no key data.\";break;case\"layout\":e=\"The template has no key layout.\";break;case\"missing\":e=t.path?\"There are no templates for item \"+t.path+\" with name \"+t.templateitemname:\"There are no templates for trace \"+t.index+\", of type \"+t.traceType+\".\";break;case\"unused\":e=t.path?\"The template item at \"+t.path+\" was not used in constructing the plot.\":t.dataCount?\"Some of the templates of type \"+t.traceType+\" were not used. The template has \"+t.templateCount+\" traces, the data only has \"+t.dataCount+\" of this type.\":\"The template has \"+t.templateCount+\" traces of type \"+t.traceType+\" but there are none in the data.\";break;case\"reused\":e=\"Some of the templates of type \"+t.traceType+\" were used more than once. The template has \"+t.templateCount+\" traces, the data has \"+t.dataCount+\" of this type.\"}return t.msg=e,t}r.makeTemplate=function(t){t=n.isPlainObject(t)?t:n.getGraphDiv(t),t=n.extendDeep({_context:c},{data:t.data,layout:t.layout}),o.supplyDefaults(t);var e=t.data||[],r=t.layout||{};r._basePlotModules=t._fullLayout._basePlotModules,r._modules=t._fullLayout._modules;var a={data:{},layout:{}};e.forEach((function(t){var e={};h(t,e,d.bind(null,t));var r=n.coerce(t,{},s,\"type\"),i=a.data[r];i||(i=a.data[r]=[]),i.push(e)})),h(r,a.layout,p.bind(null,r)),delete a.layout.template;var l=r.template;if(i(l)){var f,g,m,v,y,x,b=l.layout;i(b)&&u(b,a.layout);var _=l.data;if(i(_)){for(g in a.data)if(m=_[g],Array.isArray(m)){for(x=(y=a.data[g]).length,v=m.length,f=0;f<x;f++)u(m[f%v],y[f]);for(f=x;f<v;f++)y.push(n.extendDeep({},m[f]))}for(g in _)g in a.data||(a.data[g]=n.extendDeep([],_[g]))}}return a},r.validateTemplate=function(t,e){var r=n.extendDeep({},{_context:c,data:t.data,layout:t.layout}),a=r.layout||{};i(e)||(e=a.template||{});var s=e.layout,l=e.data,u=[];r.layout=a,r.layout.template=e,o.supplyDefaults(r);var h=r._fullLayout,p=r._fullData,d={};if(i(s)?(!function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)&&i(e[n])){var a,o=f(n),s=[];for(a=0;a<r.length;a++)s.push(g(e,n,r[a])),o!==n&&s.push(g(e,o,r[a]));for(a=0;a<s.length;a++)d[s[a]]=1;t(e[n],s)}}(h,[\"layout\"]),function t(e,r){for(var n in e)if(-1===n.indexOf(\"defaults\")&&i(e[n])){var a=g(e,n,r);d[a]?t(e[n],a):u.push({code:\"unused\",path:a})}}(s,\"layout\")):u.push({code:\"layout\"}),i(l)){for(var y,x={},b=0;b<p.length;b++){var _=p[b];x[y=_.type]=(x[y]||0)+1,_._fullInput._template||u.push({code:\"missing\",index:_._fullInput.index,traceType:y})}for(y in l){var w=l[y].length,T=x[y]||0;w>T?u.push({code:\"unused\",traceType:y,templateCount:w,dataCount:T}):T>w&&u.push({code:\"reused\",traceType:y,templateCount:w,dataCount:T})}}else u.push({code:\"data\"});if(function t(e,r){for(var n in e)if(\"_\"!==n.charAt(0)){var a=e[n],o=g(e,n,r);i(a)?(Array.isArray(e)&&!1===a._template&&a.templateitemname&&u.push({code:\"missing\",path:o,templateitemname:a.templateitemname}),t(a,o)):Array.isArray(a)&&m(a)&&t(a,o)}}({data:p,layout:h},\"\"),u.length)return u.map(v)}},{\"../lib\":778,\"../plots/attributes\":824,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816,\"./plot_template\":817}],820:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./plot_api\"),a=t(\"../plots/plots\"),o=t(\"../lib\"),s=t(\"../snapshot/helpers\"),l=t(\"../snapshot/tosvg\"),c=t(\"../snapshot/svgtoimg\"),u=t(\"../version\").version,f={format:{valType:\"enumerated\",values:[\"png\",\"jpeg\",\"webp\",\"svg\",\"full-json\"],dflt:\"png\"},width:{valType:\"number\",min:1},height:{valType:\"number\",min:1},scale:{valType:\"number\",min:0,dflt:1},setBackground:{valType:\"any\",dflt:!1},imageDataOnly:{valType:\"boolean\",dflt:!1}};e.exports=function(t,e){var r,h,p,d;function g(t){return!(t in e)||o.validate(e[t],f[t])}if(e=e||{},o.isPlainObject(t)?(r=t.data||[],h=t.layout||{},p=t.config||{},d={}):(t=o.getGraphDiv(t),r=o.extendDeep([],t.data),h=o.extendDeep({},t.layout),p=t._context,d=t._fullLayout||{}),!g(\"width\")&&null!==e.width||!g(\"height\")&&null!==e.height)throw new Error(\"Height and width should be pixel values.\");if(!g(\"format\"))throw new Error(\"Export format is not \"+o.join2(f.format.values,\", \",\" or \")+\".\");var m={};function v(t,r){return o.coerce(e,m,f,t,r)}var y=v(\"format\"),x=v(\"width\"),b=v(\"height\"),_=v(\"scale\"),w=v(\"setBackground\"),T=v(\"imageDataOnly\"),k=document.createElement(\"div\");k.style.position=\"absolute\",k.style.left=\"-5000px\",document.body.appendChild(k);var M=o.extendFlat({},h);x?M.width=x:null===e.width&&n(d.width)&&(M.width=d.width),b?M.height=b:null===e.height&&n(d.height)&&(M.height=d.height);var A=o.extendFlat({},p,{_exportedPlot:!0,staticPlot:!0,setBackground:w}),S=s.getRedrawFunc(k);function E(){return new Promise((function(t){setTimeout(t,s.getDelay(k._fullLayout))}))}function C(){return new Promise((function(t,e){var r=l(k,y,_),n=k._fullLayout.width,f=k._fullLayout.height;function h(){i.purge(k),document.body.removeChild(k)}if(\"full-json\"===y){var p=a.graphJson(k,!1,\"keepdata\",\"object\",!0,!0);return p.version=u,p=JSON.stringify(p),h(),t(T?p:s.encodeJSON(p))}if(h(),\"svg\"===y)return t(T?r:s.encodeSVG(r));var d=document.createElement(\"canvas\");d.id=o.randstr(),c({format:y,width:n,height:f,scale:_,canvas:d,svg:r,promise:!0}).then(t).catch(e)}))}return new Promise((function(t,e){i.plot(k,r,M,A).then(S).then(E).then(C).then((function(e){t(function(t){return T?t.replace(s.IMAGE_URL_PREFIX,\"\"):t}(e))})).catch((function(t){e(t)}))}))}},{\"../lib\":778,\"../plots/plots\":891,\"../snapshot/helpers\":915,\"../snapshot/svgtoimg\":917,\"../snapshot/tosvg\":919,\"../version\":1370,\"./plot_api\":814,\"fast-isnumeric\":241}],821:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/plots\"),a=t(\"./plot_schema\"),o=t(\"./plot_config\").dfltConfig,s=n.isPlainObject,l=Array.isArray,c=n.isArrayOrTypedArray;function u(t,e,r,i,a,o){o=o||[];for(var f=Object.keys(t),h=0;h<f.length;h++){var p=f[h];if(\"transforms\"!==p){var v=o.slice();v.push(p);var y=t[p],x=e[p],b=m(r,p),_=(b||{}).valType,w=\"info_array\"===_,T=\"colorscale\"===_,k=(b||{}).items;if(g(r,p))if(s(y)&&s(x)&&\"any\"!==_)u(y,x,b,i,a,v);else if(w&&l(y)){y.length>x.length&&i.push(d(\"unused\",a,v.concat(x.length)));var M,A,S,E,C,L=x.length,I=Array.isArray(k);if(I&&(L=Math.min(L,k.length)),2===b.dimensions)for(A=0;A<L;A++)if(l(y[A])){y[A].length>x[A].length&&i.push(d(\"unused\",a,v.concat(A,x[A].length)));var P=x[A].length;for(M=0;M<(I?Math.min(P,k[A].length):P);M++)S=I?k[A][M]:k,E=y[A][M],C=x[A][M],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A,M),E,C)):i.push(d(\"value\",a,v.concat(A,M),E))}else i.push(d(\"array\",a,v.concat(A),y[A]));else for(A=0;A<L;A++)S=I?k[A]:k,E=y[A],C=x[A],n.validate(E,S)?C!==E&&C!==+E&&i.push(d(\"dynamic\",a,v.concat(A),E,C)):i.push(d(\"value\",a,v.concat(A),E))}else if(b.items&&!w&&l(y)){var z,O,D=k[Object.keys(k)[0]],R=[];for(z=0;z<x.length;z++){var F=x[z]._index||z;if((O=v.slice()).push(F),s(y[F])&&s(x[z])){R.push(F);var B=y[F],N=x[z];s(B)&&!1!==B.visible&&!1===N.visible?i.push(d(\"invisible\",a,O)):u(B,N,D,i,a,O)}}for(z=0;z<y.length;z++)(O=v.slice()).push(z),s(y[z])?-1===R.indexOf(z)&&i.push(d(\"unused\",a,O)):i.push(d(\"object\",a,O,y[z]))}else!s(y)&&s(x)?i.push(d(\"object\",a,v,y)):c(y)||!c(x)||w||T?p in e?n.validate(y,b)?\"enumerated\"===b.valType&&(b.coerceNumber&&y!==+x||y!==x)&&i.push(d(\"dynamic\",a,v,y,x)):i.push(d(\"value\",a,v,y)):i.push(d(\"unused\",a,v,y)):i.push(d(\"array\",a,v,y));else i.push(d(\"schema\",a,v))}}return i}function f(t,e){for(var r=t.layout.layoutAttributes,i=0;i<e.length;i++){var a=e[i],o=t.traces[a.type],s=o.layoutAttributes;s&&(a.subplot?n.extendFlat(r[o.attributes.subplot.dflt],s):n.extendFlat(r,s))}return r}e.exports=function(t,e){void 0===t&&(t=[]),void 0===e&&(e={});var r,c,h=a.get(),p=[],g={_context:n.extendFlat({},o)};l(t)?(g.data=n.extendDeep([],t),r=t):(g.data=[],r=[],p.push(d(\"array\",\"data\"))),s(e)?(g.layout=n.extendDeep({},e),c=e):(g.layout={},c={},arguments.length>1&&p.push(d(\"object\",\"layout\"))),i.supplyDefaults(g);for(var m=g._fullData,v=r.length,y=0;y<v;y++){var x=r[y],b=[\"data\",y];if(s(x)){var _=m[y],w=_.type,T=h.traces[w].attributes;T.type={valType:\"enumerated\",values:[w]},!1===_.visible&&!1!==x.visible&&p.push(d(\"invisible\",b)),u(x,_,T,p,b);var k=x.transforms,M=_.transforms;if(k){l(k)||p.push(d(\"array\",b,[\"transforms\"])),b.push(\"transforms\");for(var A=0;A<k.length;A++){var S=[\"transforms\",A],E=k[A].type;if(s(k[A])){var C=h.transforms[E]?h.transforms[E].attributes:{};C.type={valType:\"enumerated\",values:Object.keys(h.transforms)},u(k[A],M[A],C,p,b,S)}else p.push(d(\"object\",b,S))}}}else p.push(d(\"object\",b))}var L=g._fullLayout,I=f(h,m);return u(c,L,I,p,\"layout\"),0===p.length?void 0:p};var h={object:function(t,e){return(\"layout\"===t&&\"\"===e?\"The layout argument\":\"data\"===t[0]&&\"\"===e?\"Trace \"+t[1]+\" in the data argument\":p(t)+\"key \"+e)+\" must be linked to an object container\"},array:function(t,e){return(\"data\"===t?\"The data argument\":p(t)+\"key \"+e)+\" must be linked to an array container\"},schema:function(t,e){return p(t)+\"key \"+e+\" is not part of the schema\"},unused:function(t,e,r){var n=s(r)?\"container\":\"key\";return p(t)+n+\" \"+e+\" did not get coerced\"},dynamic:function(t,e,r,n){return[p(t)+\"key\",e,\"(set to '\"+r+\"')\",\"got reset to\",\"'\"+n+\"'\",\"during defaults.\"].join(\" \")},invisible:function(t,e){return(e?p(t)+\"item \"+e:\"Trace \"+t[1])+\" got defaulted to be not visible\"},value:function(t,e,r){return[p(t)+\"key \"+e,\"is set to an invalid value (\"+r+\")\"].join(\" \")}};function p(t){return l(t)?\"In data trace \"+t[1]+\", \":\"In \"+t+\", \"}function d(t,e,r,i,a){var o,s;r=r||\"\",l(e)?(o=e[0],s=e[1]):(o=e,s=null);var c=function(t){if(!l(t))return String(t);for(var e=\"\",r=0;r<t.length;r++){var n=t[r];\"number\"==typeof n?e=e.substr(0,e.length-1)+\"[\"+n+\"]\":e+=n,r<t.length-1&&(e+=\".\")}return e}(r),u=h[t](e,c,i,a);return n.log(u),{code:t,container:o,trace:s,path:r,astr:c,msg:u}}function g(t,e){var r=y(e),n=r.keyMinusId,i=r.id;return!!(n in t&&t[n]._isSubplotObj&&i)||e in t}function m(t,e){return e in t?t[e]:t[y(e).keyMinusId]}var v=n.counterRegex(\"([a-z]+)\");function y(t){var e=t.match(v);return{keyMinusId:e&&e[1],id:e&&e[2]}}},{\"../lib\":778,\"../plots/plots\":891,\"./plot_config\":815,\"./plot_schema\":816}],822:[function(t,e,r){\"use strict\";e.exports={mode:{valType:\"enumerated\",dflt:\"afterall\",values:[\"immediate\",\"next\",\"afterall\"]},direction:{valType:\"enumerated\",values:[\"forward\",\"reverse\"],dflt:\"forward\"},fromcurrent:{valType:\"boolean\",dflt:!1},frame:{duration:{valType:\"number\",min:0,dflt:500},redraw:{valType:\"boolean\",dflt:!0}},transition:{duration:{valType:\"number\",min:0,dflt:500,editType:\"none\"},easing:{valType:\"enumerated\",dflt:\"cubic-in-out\",values:[\"linear\",\"quad\",\"cubic\",\"sin\",\"exp\",\"circle\",\"elastic\",\"back\",\"bounce\",\"linear-in\",\"quad-in\",\"cubic-in\",\"sin-in\",\"exp-in\",\"circle-in\",\"elastic-in\",\"back-in\",\"bounce-in\",\"linear-out\",\"quad-out\",\"cubic-out\",\"sin-out\",\"exp-out\",\"circle-out\",\"elastic-out\",\"back-out\",\"bounce-out\",\"linear-in-out\",\"quad-in-out\",\"cubic-in-out\",\"sin-in-out\",\"exp-in-out\",\"circle-in-out\",\"elastic-in-out\",\"back-in-out\",\"bounce-in-out\"],editType:\"none\"},ordering:{valType:\"enumerated\",values:[\"layout first\",\"traces first\"],dflt:\"layout first\",editType:\"none\"}}}},{}],823:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\");e.exports=function(t,e,r){var a,o,s=r.name,l=r.inclusionAttr||\"visible\",c=e[s],u=n.isArrayOrTypedArray(t[s])?t[s]:[],f=e[s]=[],h=i.arrayTemplater(e,s,l);for(a=0;a<u.length;a++){var p=u[a];n.isPlainObject(p)?o=h.newItem(p):(o=h.newItem({}))[l]=!1,o._index=a,!1!==o[l]&&r.handleItemDefaults(p,o,e,r),f.push(o)}var d=h.defaultItems();for(a=0;a<d.length;a++)(o=d[a])._index=f.length,r.handleItemDefaults({},o,e,r,{}),f.push(o);if(n.isArrayOrTypedArray(c)){var g=Math.min(c.length,f.length);for(a=0;a<g;a++)n.relinkPrivateKeys(f[a],c[a])}return f}},{\"../lib\":778,\"../plot_api/plot_template\":817}],824:[function(t,e,r){\"use strict\";var n=t(\"../components/fx/attributes\");e.exports={type:{valType:\"enumerated\",values:[],dflt:\"scatter\",editType:\"calc+clearAxisTypes\",_noTemplating:!0},visible:{valType:\"enumerated\",values:[!0,!1,\"legendonly\"],dflt:!0,editType:\"calc\"},showlegend:{valType:\"boolean\",dflt:!0,editType:\"style\"},legendgroup:{valType:\"string\",dflt:\"\",editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,editType:\"style\"},name:{valType:\"string\",editType:\"style\"},uid:{valType:\"string\",editType:\"plot\",anim:!0},ids:{valType:\"data_array\",editType:\"calc\",anim:!0},customdata:{valType:\"data_array\",editType:\"calc\"},meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},selectedpoints:{valType:\"any\",editType:\"calc\"},hoverinfo:{valType:\"flaglist\",flags:[\"x\",\"y\",\"z\",\"text\",\"name\"],extras:[\"all\",\"none\",\"skip\"],arrayOk:!0,dflt:\"all\",editType:\"none\"},hoverlabel:n.hoverlabel,stream:{token:{valType:\"string\",noBlank:!0,strict:!0,editType:\"calc\"},maxpoints:{valType:\"number\",min:0,max:1e4,dflt:500,editType:\"calc\"},editType:\"calc\"},transforms:{_isLinkedToArray:\"transform\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"}}},{\"../components/fx/attributes\":674}],825:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=i.dateTime2ms,o=i.incrementMonth,s=t(\"../../constants/numerical\").ONEAVGMONTH;e.exports=function(t,e,r,i){if(\"date\"!==e.type)return i;var l=t[r+\"periodalignment\"];if(!l)return i;var c,u=t[r+\"period\"];if(n(u)){if((u=+u)<=0)return i}else if(\"string\"==typeof u&&\"M\"===u.charAt(0)){var f=+u.substring(1);if(!(f>0&&Math.round(f)===f))return i;c=f}for(var h=e.calendar,p=\"start\"===l,d=\"end\"===l,g=t[r+\"period0\"],m=a(g,h)||0,v=[],y=i.length,x=0;x<y;x++){var b,_,w,T=i[x];if(c){for(b=Math.round((T-m)/(c*s)),w=o(m,c*b,h);w>T;)w=o(w,-c,h);for(;w<=T;)w=o(w,c,h);_=o(w,-c,h)}else{for(w=m+(b=Math.round((T-m)/u))*u;w>T;)w-=u;for(;w<=T;)w+=u;_=w-u}v[x]=p?_:d?w:(_+w)/2}return v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],826:[function(t,e,r){\"use strict\";e.exports={xaxis:{valType:\"subplotid\",dflt:\"x\",editType:\"calc+clearAxisTypes\"},yaxis:{valType:\"subplotid\",dflt:\"y\",editType:\"calc+clearAxisTypes\"}}},{}],827:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").FP_SAFE,o=t(\"../../registry\"),s=t(\"./axis_ids\"),l=s.getFromId,c=s.isLinked;function u(t,e){var r,n,a=[],o=t._fullLayout,s=h(o,e,0),l=h(o,e,1),c=p(t,e),u=c.min,d=c.max;if(0===u.length||0===d.length)return i.simpleMap(e.range,e.r2l);var g=u[0].val,m=d[0].val;for(r=1;r<u.length&&g===m;r++)g=Math.min(g,u[r].val);for(r=1;r<d.length&&g===m;r++)m=Math.max(m,d[r].val);var v=!1;if(e.range){var y=i.simpleMap(e.range,e.r2l);v=y[1]<y[0]}\"reversed\"===e.autorange&&(v=!0,e.autorange=!0);var x,b,_,w,T,k,M=e.rangemode,A=\"tozero\"===M,S=\"nonnegative\"===M,E=e._length,C=E/10,L=0;for(r=0;r<u.length;r++)for(x=u[r],n=0;n<d.length;n++)(k=(b=d[n]).val-x.val-f(e,x.val,b.val))>0&&((T=E-s(x)-l(b))>C?k/T>L&&(_=x,w=b,L=k/T):k/E>L&&(_={val:x.val,nopad:1},w={val:b.val,nopad:1},L=k/E));if(g===m){var I=g-1,P=g+1;if(A)if(0===g)a=[0,1];else{var z=(g>0?d:u).reduce((function(t,e){return Math.max(t,l(e))}),0),O=g/(1-Math.min(.5,z/E));a=g>0?[0,O]:[O,0]}else a=S?[Math.max(0,I),Math.max(1,P)]:[I,P]}else A?(_.val>=0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:0,nopad:1})):S&&(_.val-L*s(_)<0&&(_={val:0,nopad:1}),w.val<=0&&(w={val:1,nopad:1})),L=(w.val-_.val-f(e,x.val,b.val))/(E-s(_)-l(w)),a=[_.val-L*s(_),w.val+L*l(w)];return v&&a.reverse(),i.simpleMap(a,e.l2r||Number)}function f(t,e,r){var n=0;if(t.rangebreaks)for(var i=t.locateBreaks(e,r),a=0;a<i.length;a++){var o=i[a];n+=o.max-o.min}return n}function h(t,e,r){var n=.05*e._length,a=e._anchorAxis||{};if(-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")||-1!==(a.ticklabelposition||\"\").indexOf(\"inside\")){var o=\"reversed\"===e.autorange;if(!o){var s=i.simpleMap(e.range,e.r2l);o=s[1]<s[0]}o&&(r=!r)}var l=0;return c(t,e._id)||(l=function(t,e){var r=0,n=t._anchorAxis||{};if(-1!==(n.ticklabelposition||\"\").indexOf(\"inside\")&&(!e&&(\"left\"===n.side||\"bottom\"===n.side)||e&&(\"top\"===n.side||\"right\"===n.side))){var a=\"x\"===t._id.charAt(0);if(n._vals){var o=i.deg2rad(n._tickAngles[n._id+\"tick\"]||0),s=Math.abs(Math.cos(o)),l=Math.abs(Math.sin(o));n._vals.forEach((function(t){if(t.bb){var e=6+t.bb.width,n=6+t.bb.height;r=Math.max(r,a?Math.max(e*s,n*l):Math.max(n*s,e*l))}}))}\"inside\"===n.ticks&&\"inside\"===n.ticklabelposition&&(r+=n.ticklen||0)}return r}(e,r)),n=Math.max(l,n),\"domain\"===e.constrain&&e._inputDomain&&(n*=(e._inputDomain[1]-e._inputDomain[0])/(e.domain[1]-e.domain[0])),function(t){return t.nopad?0:t.pad+(t.extrapad?n:l)}}e.exports={getAutoRange:u,makePadFn:h,doAutoRange:function(t,e,r){if(e.setScale(),e.autorange){e.range=r?r.slice():u(t,e),e._r=e.range.slice(),e._rl=i.simpleMap(e._r,e.r2l);var n=e._input,a={};a[e._attr+\".range\"]=e.range,a[e._attr+\".autorange\"]=e.autorange,o.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,a),n.range=e.range.slice(),n.autorange=e.autorange}var s=e._anchorAxis;if(s&&s.rangeslider){var l=s.rangeslider[e._name];l&&\"auto\"===l.rangemode&&(l.range=u(t,e)),s._input.rangeslider[e._name]=i.extendFlat({},l)}},findExtremes:function(t,e,r){r||(r={});t._m||t.setScale();var i,o,s,l,c,u,f,h,p,m=[],y=[],x=e.length,b=r.padded||!1,_=r.tozero&&(\"linear\"===t.type||\"-\"===t.type),w=\"log\"===t.type,T=!1,k=r.vpadLinearized||!1;function M(t){if(Array.isArray(t))return T=!0,function(e){return Math.max(Number(t[e]||0),0)};var e=Math.max(Number(t||0),0);return function(){return e}}var A=M((t._m>0?r.ppadplus:r.ppadminus)||r.ppad||0),S=M((t._m>0?r.ppadminus:r.ppadplus)||r.ppad||0),E=M(r.vpadplus||r.vpad),C=M(r.vpadminus||r.vpad);if(!T){if(h=1/0,p=-1/0,w)for(i=0;i<x;i++)(o=e[i])<h&&o>0&&(h=o),o>p&&o<a&&(p=o);else for(i=0;i<x;i++)(o=e[i])<h&&o>-a&&(h=o),o>p&&o<a&&(p=o);e=[h,p],x=2}var L={tozero:_,extrapad:b};function I(r){s=e[r],n(s)&&(u=A(r),f=S(r),k?(l=t.c2l(s)-C(r),c=t.c2l(s)+E(r)):(h=s-C(r),p=s+E(r),w&&h<p/10&&(h=p/10),l=t.c2l(h),c=t.c2l(p)),_&&(l=Math.min(0,l),c=Math.max(0,c)),v(l)&&d(m,l,f,L),v(c)&&g(y,c,u,L))}var P=Math.min(6,x);for(i=0;i<P;i++)I(i);for(i=x-1;i>=P;i--)I(i);return{min:m,max:y,opts:r}},concatExtremes:p};function p(t,e,r){var n,i,a,o=e._id,s=t._fullData,c=t._fullLayout,u=[],f=[];function h(t,e){for(n=0;n<e.length;n++){var r=t[e[n]],s=(r._extremes||{})[o];if(!0===r.visible&&s){for(i=0;i<s.min.length;i++)a=s.min[i],d(u,a.val,a.pad,{extrapad:a.extrapad});for(i=0;i<s.max.length;i++)a=s.max[i],g(f,a.val,a.pad,{extrapad:a.extrapad})}}}if(h(s,e._traceIndices),h(c.annotations||[],e._annIndices||[]),h(c.shapes||[],e._shapeIndices||[]),e._matchGroup&&!r)for(var m in e._matchGroup)if(m!==e._id){var v=l(t,m),y=p(t,v,!0),x=e._length/v._length;for(i=0;i<y.min.length;i++)a=y.min[i],d(u,a.val,a.pad*x,{extrapad:a.extrapad});for(i=0;i<y.max.length;i++)a=y.max[i],g(f,a.val,a.pad*x,{extrapad:a.extrapad})}return{min:u,max:f}}function d(t,e,r,n){m(t,e,r,n,y)}function g(t,e,r,n){m(t,e,r,n,x)}function m(t,e,r,n,i){for(var a=n.tozero,o=n.extrapad,s=!0,l=0;l<t.length&&s;l++){var c=t[l];if(i(c.val,e)&&c.pad>=r&&(c.extrapad||!o)){s=!1;break}i(e,c.val)&&c.pad<=r&&(o||!c.extrapad)&&(t.splice(l,1),l--)}if(s){var u=a&&0===e;t.push({val:e,pad:u?0:r,extrapad:!u&&o})}}function v(t){return n(t)&&Math.abs(t)<a}function y(t,e){return t<=e}function x(t,e){return t>=e}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831,\"fast-isnumeric\":241}],828:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../plots/plots\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/titles\"),f=t(\"../../components/color\"),h=t(\"../../components/drawing\"),p=t(\"./layout_attributes\"),d=t(\"./clean_ticks\"),g=t(\"../../constants/numerical\"),m=g.ONEMAXYEAR,v=g.ONEAVGYEAR,y=g.ONEMINYEAR,x=g.ONEMAXQUARTER,b=g.ONEAVGQUARTER,_=g.ONEMINQUARTER,w=g.ONEMAXMONTH,T=g.ONEAVGMONTH,k=g.ONEMINMONTH,M=g.ONEWEEK,A=g.ONEDAY,S=A/2,E=g.ONEHOUR,C=g.ONEMIN,L=g.ONESEC,I=g.MINUS_SIGN,P=g.BADNUM,z=t(\"../../constants/alignment\"),O=z.MID_SHIFT,D=z.CAP_SHIFT,R=z.LINE_SPACING,F=z.OPPOSITE_SIDE,B=e.exports={};B.setConvert=t(\"./set_convert\");var N=t(\"./axis_autotype\"),j=t(\"./axis_ids\"),U=j.idSort,V=j.isLinked;B.id2name=j.id2name,B.name2id=j.name2id,B.cleanId=j.cleanId,B.list=j.list,B.listIds=j.listIds,B.getFromId=j.getFromId,B.getFromTrace=j.getFromTrace;var q=t(\"./autorange\");B.getAutoRange=q.getAutoRange,B.findExtremes=q.findExtremes;function H(t){var e=1e-4*(t[1]-t[0]);return[t[0]-e,t[1]+e]}B.coerceRef=function(t,e,r,n,i,a){var o=n.charAt(n.length-1),l=r._fullLayout._subplots[o+\"axis\"],c=n+\"ref\",u={};return i||(i=l[0]||(\"string\"==typeof a?a:a[0])),a||(a=i),l=l.concat(l.map((function(t){return t+\" domain\"}))),u[c]={valType:\"enumerated\",values:l.concat(a?\"string\"==typeof a?[a]:a:[]),dflt:i},s.coerce(t,e,u,c)},B.getRefType=function(t){return void 0===t?t:\"paper\"===t?\"paper\":\"pixel\"===t?\"pixel\":/( domain)$/.test(t)?\"domain\":\"range\"},B.coercePosition=function(t,e,r,n,i,a){var o,l;if(\"range\"!==B.getRefType(n))o=s.ensureNumber,l=r(i,a);else{var c=B.getFromId(e,n);l=r(i,a=c.fraction2r(a)),o=c.cleanPos}t[i]=o(l)},B.cleanPosition=function(t,e,r){return(\"paper\"===r||\"pixel\"===r?s.ensureNumber:B.getFromId(e,r).cleanPos)(t)},B.redrawComponents=function(t,e){e=e||B.listIds(t);var r=t._fullLayout;function n(n,i,a,s){for(var l=o.getComponentMethod(n,i),c={},u=0;u<e.length;u++)for(var f=r[B.id2name(e[u])][a],h=0;h<f.length;h++){var p=f[h];if(!c[p]&&(l(t,p),c[p]=1,s))return}}n(\"annotations\",\"drawOne\",\"_annIndices\"),n(\"shapes\",\"drawOne\",\"_shapeIndices\"),n(\"images\",\"draw\",\"_imgIndices\",!0)};var G=B.getDataConversions=function(t,e,r,n){var i,a=\"x\"===r||\"y\"===r||\"z\"===r?r:n;if(Array.isArray(a)){if(i={type:N(n,void 0,{autotypenumbers:t._fullLayout.autotypenumbers}),_categories:[]},B.setConvert(i),\"category\"===i.type)for(var o=0;o<n.length;o++)i.d2c(n[o])}else i=B.getFromTrace(t,e,a);return i?{d2c:i.d2c,c2d:i.c2d}:\"ids\"===a?{d2c:W,c2d:W}:{d2c:Y,c2d:Y}};function Y(t){return+t}function W(t){return String(t)}function X(t){return+t.substring(1)}B.getDataToCoordFunc=function(t,e,r,n){return G(t,e,r,n).d2c},B.counterLetter=function(t){var e=t.charAt(0);return\"x\"===e?\"y\":\"y\"===e?\"x\":void 0},B.minDtick=function(t,e,r,n){-1===[\"log\",\"category\",\"multicategory\"].indexOf(t.type)&&n?void 0===t._minDtick?(t._minDtick=e,t._forceTick0=r):t._minDtick&&((t._minDtick/e+1e-6)%1<2e-6&&((r-t._forceTick0)/e%1+1.000001)%1<2e-6?(t._minDtick=e,t._forceTick0=r):((e/t._minDtick+1e-6)%1>2e-6||((r-t._forceTick0)/t._minDtick%1+1.000001)%1>2e-6)&&(t._minDtick=0)):t._minDtick=0},B.saveRangeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=0;i<r.length;i++){var a=r[i],o=void 0===a._rangeInitial,s=o||!(a.range[0]===a._rangeInitial[0]&&a.range[1]===a._rangeInitial[1]);(o&&!1===a.autorange||e&&s)&&(a._rangeInitial=a.range.slice(),n=!0)}return n},B.saveShowSpikeInitial=function(t,e){for(var r=B.list(t,\"\",!0),n=!1,i=\"on\",a=0;a<r.length;a++){var o=r[a],s=void 0===o._showSpikeInitial,l=s||!(o.showspikes===o._showspikes);(s||e&&l)&&(o._showSpikeInitial=o.showspikes,n=!0),\"on\"!==i||o.showspikes||(i=\"off\")}return t._fullLayout._cartesianSpikesEnabled=i,n},B.autoBin=function(t,e,r,n,a,o){var l,c=s.aggNums(Math.min,null,t),u=s.aggNums(Math.max,null,t);if(\"category\"===e.type||\"multicategory\"===e.type)return{start:c-.5,end:u+.5,size:Math.max(1,Math.round(o)||1),_dataSpan:u-c};if(a||(a=e.calendar),l=\"log\"===e.type?{type:\"linear\",range:[c,u]}:{type:e.type,range:s.simpleMap([c,u],e.c2r,0,a),calendar:a},B.setConvert(l),o=o&&d.dtick(o,l.type))l.dtick=o,l.tick0=d.tick0(void 0,l.type,a);else{var f;if(r)f=(u-c)/r;else{var h=s.distinctVals(t),p=Math.pow(10,Math.floor(Math.log(h.minDiff)/Math.LN10)),g=p*s.roundUp(h.minDiff/p,[.9,1.9,4.9,9.9],!0);f=Math.max(g,2*s.stdev(t)/Math.pow(t.length,n?.25:.4)),i(f)||(f=1)}B.autoTicks(l,f)}var m,v=l.dtick,y=B.tickIncrement(B.tickFirst(l),v,\"reverse\",a);if(\"number\"==typeof v)m=(y=function(t,e,r,n,a){var o=0,s=0,l=0,c=0;function u(e){return(1+100*(e-t)/r.dtick)%100<2}for(var f=0;f<e.length;f++)e[f]%1==0?l++:i(e[f])||c++,u(e[f])&&o++,u(e[f]+r.dtick/2)&&s++;var h=e.length-c;if(l===h&&\"date\"!==r.type)r.dtick<1?t=n-.5*r.dtick:(t-=.5)+r.dtick<n&&(t+=r.dtick);else if(s<.1*h&&(o>.3*h||u(n)||u(a))){var p=r.dtick/2;t+=t+p<n?p:-p}return t}(y,t,l,c,u))+(1+Math.floor((u-y)/v))*v;else for(\"M\"===l.dtick.charAt(0)&&(y=function(t,e,r,n,i){var a=s.findExactDates(e,i);if(a.exactDays>.8){var o=Number(r.substr(1));a.exactYears>.8&&o%12==0?t=B.tickIncrement(t,\"M6\",\"reverse\")+1.5*A:a.exactMonths>.8?t=B.tickIncrement(t,\"M1\",\"reverse\")+15.5*A:t-=S;var l=B.tickIncrement(t,r);if(l<=n)return l}return t}(y,t,v,c,a)),m=y,0;m<=u;)m=B.tickIncrement(m,v,!1,a);return{start:e.c2r(y,0,a),end:e.c2r(m,0,a),size:v,_dataSpan:u-c}},B.prepTicks=function(t,e){var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(t._dtickInit=t.dtick,t._tick0Init=t.tick0,\"auto\"===t.tickmode||!t.dtick){var n,a=t.nticks;a||(\"category\"===t.type||\"multicategory\"===t.type?(n=t.tickfont?1.2*(t.tickfont.size||12):15,a=t._length/n):(n=\"y\"===t._id.charAt(0)?40:80,a=s.constrain(t._length/n,4,9)+1),\"radialaxis\"===t._name&&(a*=2)),\"array\"===t.tickmode&&(a*=100),t._roughDTick=Math.abs(r[1]-r[0])/a,B.autoTicks(t,t._roughDTick),t._minDtick>0&&t.dtick<2*t._minDtick&&(t.dtick=t._minDtick,t.tick0=t.l2r(t._forceTick0))}\"period\"===t.ticklabelmode&&function(t){var e;function r(){return!(i(t.dtick)||\"M\"!==t.dtick.charAt(0))}var n=r(),a=B.getTickFormat(t);if(a){var o=t._dtickInit!==t.dtick;/%[fLQsSMX]/.test(a)||(/%[HI]/.test(a)?(e=E,o&&!n&&t.dtick<E&&(t.dtick=E)):/%p/.test(a)?(e=S,o&&!n&&t.dtick<S&&(t.dtick=S)):/%[Aadejuwx]/.test(a)?(e=A,o&&!n&&t.dtick<A&&(t.dtick=A)):/%[UVW]/.test(a)?(e=M,o&&!n&&t.dtick<M&&(t.dtick=M)):/%[Bbm]/.test(a)?(e=T,o&&(n?X(t.dtick)<1:t.dtick<k)&&(t.dtick=\"M1\")):/%[q]/.test(a)?(e=b,o&&(n?X(t.dtick)<3:t.dtick<_)&&(t.dtick=\"M3\")):/%[Yy]/.test(a)&&(e=v,o&&(n?X(t.dtick)<12:t.dtick<y)&&(t.dtick=\"M12\")))}(n=r())&&t.tick0===t._dowTick0&&(t.tick0=t._rawTick0);t._definedDelta=e}(t),t.tick0||(t.tick0=\"date\"===t.type?\"2000-01-01\":0),\"date\"===t.type&&t.dtick<.1&&(t.dtick=.1),nt(t)},B.calcTicks=function(t,e){B.prepTicks(t,e);var r=s.simpleMap(t.range,t.r2l,void 0,void 0,e);if(\"array\"===t.tickmode)return function(t){var e=t.tickvals,r=t.ticktext,n=new Array(e.length),i=H(s.simpleMap(t.range,t.r2l)),a=Math.min(i[0],i[1]),o=Math.max(i[0],i[1]),l=0;Array.isArray(r)||(r=[]);var c=\"category\"===t.type?t.d2l_noadd:t.d2l;\"log\"===t.type&&\"L\"!==String(t.dtick).charAt(0)&&(t.dtick=\"L\"+Math.pow(10,Math.floor(Math.min(t.range[0],t.range[1]))-1));for(var u=0;u<e.length;u++){var f=c(e[u]);f>a&&f<o&&(void 0===r[u]?n[l]=B.tickText(t,f):n[l]=it(t,f,String(r[u])),l++)}l<e.length&&n.splice(l,e.length-l);t.rangebreaks&&(n=n.filter((function(e){return t.maskBreaks(e.x)!==P})));return n}(t);var n=H(r),a=n[0],o=n[1],l=r[1]<r[0],c=Math.min(r[0],r[1]),u=Math.max(r[0],r[1]),f=\"log\"===t.type&&!(i(t.dtick)||\"L\"===t.dtick.charAt(0)),h=\"period\"===t.ticklabelmode;if(t._tmin=B.tickFirst(t,e),t._tmin<a!==l)return[];\"category\"!==t.type&&\"multicategory\"!==t.type||(o=l?Math.max(-.5,o):Math.min(t._categories.length-.5,o));var p=t._tmin;t.rangebreaks&&t._tick0Init!==t.tick0&&(p=wt(p,t),l||(p=B.tickIncrement(p,t.dtick,!l,t.calendar))),h&&(p=B.tickIncrement(p,t.dtick,!l,t.calendar));for(var d,g=Math.max(1e3,t._length||0),C=[],L=null;l?p>=o:p<=o;p=B.tickIncrement(p,t.dtick,l,t.calendar)){if(t.rangebreaks&&!l){if(p<a)continue;if(t.maskBreaks(p)===P&&wt(p,t)>=u)break}if(C.length>g||p===L)break;L=p;var I=!1;f&&p!==(0|p)&&(I=!0),C.push({minor:I,value:p})}if(h&&function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n].value,a=n,o=n+1;n<t.length-1?(a=n,o=n+1):n>0?(a=n-1,o=n):(a=n,o=n);var s,l=t[a].value,c=t[o].value,u=Math.abs(c-l),f=r||u,h=0;f>=y?h=u>=y&&u<=m?u:v:r===b&&f>=_?h=u>=_&&u<=x?u:b:f>=k?h=u>=k&&u<=w?u:T:r===M&&f>=M?h=M:f>=A?h=A:r===S&&f>=S?h=S:r===E&&f>=E&&(h=E),h>=u&&(h=u,s=!0);var p=i+h;if(e.rangebreaks&&h>0){for(var d=0,g=0;g<84;g++){var C=(g+.5)/84;e.maskBreaks(i*(1-C)+C*p)!==P&&d++}(h*=d/84)||(t[n].drop=!0),s&&u>M&&(h=u)}(h>0||0===n)&&(t[n].periodX=i+h/2)}}(C,t,t._definedDelta),t.rangebreaks){var z=\"y\"===t._id.charAt(0),O=1;\"auto\"===t.tickmode&&(O=t.tickfont?t.tickfont.size:12);var D=NaN;for(d=C.length-1;d>-1;d--)if(C[d].drop)C.splice(d,1);else{C[d].value=wt(C[d].value,t);var R=t.c2p(C[d].value);(z?D>R-O:D<R+O)?C.splice(l?d+1:d,1):D=R}}_t(t)&&360===Math.abs(r[1]-r[0])&&C.pop(),t._tmax=(C[C.length-1]||{}).value,t._prevDateHead=\"\",t._inCalcTicks=!0;var F,N,j=[];for(d=0;d<C.length;d++){var U=C[d].minor,V=C[d].value;F=B.tickText(t,V,!1,U),void 0!==(N=C[d].periodX)&&(F.periodX=N,(N>u||N<c)&&(N>u&&(F.periodX=u),N<c&&(F.periodX=c),F.text=\" \",t._prevDateHead=\"\")),j.push(F)}return t._inCalcTicks=!1,j};var Z=[2,5,10],J=[1,2,3,6,12],K=[1,2,5,10,15,30],Q=[1,2,3,7,14],$=[-.046,0,.301,.477,.602,.699,.778,.845,.903,.954,1],tt=[-.301,0,.301,.699,1],et=[15,30,45,90,180];function rt(t,e,r){return e*s.roundUp(t/e,r)}function nt(t){var e=t.dtick;if(t._tickexponent=0,i(e)||\"string\"==typeof e||(e=1),\"category\"!==t.type&&\"multicategory\"!==t.type||(t._tickround=null),\"date\"===t.type){var r=t.r2l(t.tick0),n=t.l2r(r).replace(/(^-|i)/g,\"\"),a=n.length;if(\"M\"===String(e).charAt(0))a>10||\"01-01\"!==n.substr(5)?t._tickround=\"d\":t._tickround=+e.substr(1)%12==0?\"y\":\"m\";else if(e>=A&&a<=10||e>=15*A)t._tickround=\"d\";else if(e>=C&&a<=16||e>=E)t._tickround=\"M\";else if(e>=L&&a<=19||e>=C)t._tickround=\"S\";else{var o=t.l2r(r+e).replace(/^-/,\"\").length;t._tickround=Math.max(a,o)-20,t._tickround<0&&(t._tickround=4)}}else if(i(e)||\"L\"===e.charAt(0)){var s=t.range.map(t.r2d||Number);i(e)||(e=Number(e.substr(1))),t._tickround=2-Math.floor(Math.log(e)/Math.LN10+.01);var l=Math.max(Math.abs(s[0]),Math.abs(s[1])),c=Math.floor(Math.log(l)/Math.LN10+.01),u=void 0===t.minexponent?3:t.minexponent;Math.abs(c)>u&&(ot(t.exponentformat)&&!st(c)?t._tickexponent=3*Math.round((c-1)/3):t._tickexponent=c)}else t._tickround=null}function it(t,e,r){var n=t.tickfont||{};return{x:e,dx:0,dy:0,text:r||\"\",fontSize:n.size,font:n.family,fontColor:n.color}}B.autoTicks=function(t,e){var r;function n(t){return Math.pow(t,Math.floor(Math.log(e)/Math.LN10))}if(\"date\"===t.type){t.tick0=s.dateTick0(t.calendar,0);var a=2*e;if(a>v)e/=v,r=n(10),t.dtick=\"M\"+12*rt(e,r,Z);else if(a>T)e/=T,t.dtick=\"M\"+rt(e,1,J);else if(a>A){t.dtick=rt(e,A,t._hasDayOfWeekBreaks?[1,2,7,14]:Q);var o=B.getTickFormat(t),l=\"period\"===t.ticklabelmode;l&&(t._rawTick0=t.tick0),/%[uVW]/.test(o)?t.tick0=s.dateTick0(t.calendar,2):t.tick0=s.dateTick0(t.calendar,1),l&&(t._dowTick0=t.tick0)}else a>E?t.dtick=rt(e,E,J):a>C?t.dtick=rt(e,C,K):a>L?t.dtick=rt(e,L,K):(r=n(10),t.dtick=rt(e,r,Z))}else if(\"log\"===t.type){t.tick0=0;var c=s.simpleMap(t.range,t.r2l);if(e>.7)t.dtick=Math.ceil(e);else if(Math.abs(c[1]-c[0])<1){var u=1.5*Math.abs((c[1]-c[0])/e);e=Math.abs(Math.pow(10,c[1])-Math.pow(10,c[0]))/u,r=n(10),t.dtick=\"L\"+rt(e,r,Z)}else t.dtick=e>.3?\"D2\":\"D1\"}else\"category\"===t.type||\"multicategory\"===t.type?(t.tick0=0,t.dtick=Math.ceil(Math.max(e,1))):_t(t)?(t.tick0=0,r=1,t.dtick=rt(e,r,et)):(t.tick0=0,r=n(10),t.dtick=rt(e,r,Z));if(0===t.dtick&&(t.dtick=1),!i(t.dtick)&&\"string\"!=typeof t.dtick){var f=t.dtick;throw t.dtick=1,\"ax.dtick error: \"+String(f)}},B.tickIncrement=function(t,e,r,a){var o=r?-1:1;if(i(e))return s.increment(t,o*e);var l=e.charAt(0),c=o*Number(e.substr(1));if(\"M\"===l)return s.incrementMonth(t,c,a);if(\"L\"===l)return Math.log(Math.pow(10,t)+c)/Math.LN10;if(\"D\"===l){var u=\"D2\"===e?tt:$,f=t+.01*o,h=s.roundUp(s.mod(f,1),u,r);return Math.floor(f)+Math.log(n.round(Math.pow(10,h),1))/Math.LN10}throw\"unrecognized dtick \"+String(e)},B.tickFirst=function(t,e){var r=t.r2l||Number,a=s.simpleMap(t.range,r,void 0,void 0,e),o=a[1]<a[0],l=o?Math.floor:Math.ceil,c=H(a)[0],u=t.dtick,f=r(t.tick0);if(i(u)){var h=l((c-f)/u)*u+f;return\"category\"!==t.type&&\"multicategory\"!==t.type||(h=s.constrain(h,0,t._categories.length-1)),h}var p=u.charAt(0),d=Number(u.substr(1));if(\"M\"===p){for(var g,m,v,y=0,x=f;y<10;){if(((g=B.tickIncrement(x,u,o,t.calendar))-c)*(x-c)<=0)return o?Math.min(x,g):Math.max(x,g);m=(c-(x+g)/2)/(g-x),v=p+(Math.abs(Math.round(m))||1)*d,x=B.tickIncrement(x,v,m<0?!o:o,t.calendar),y++}return s.error(\"tickFirst did not converge\",t),x}if(\"L\"===p)return Math.log(l((Math.pow(10,c)-f)/d)*d+f)/Math.LN10;if(\"D\"===p){var b=\"D2\"===u?tt:$,_=s.roundUp(s.mod(c,1),b,o);return Math.floor(c)+Math.log(n.round(Math.pow(10,_),1))/Math.LN10}throw\"unrecognized dtick \"+String(u)},B.tickText=function(t,e,r,n){var a,o=it(t,e),l=\"array\"===t.tickmode,c=r||l,u=t.type,f=\"category\"===u?t.d2l_noadd:t.d2l;if(l&&Array.isArray(t.ticktext)){var h=s.simpleMap(t.range,t.r2l),p=(Math.abs(h[1]-h[0])-(t._lBreaks||0))/1e4;for(a=0;a<t.ticktext.length&&!(Math.abs(e-f(t.tickvals[a]))<p);a++);if(a<t.ticktext.length)return o.text=String(t.ticktext[a]),o}function d(n){if(void 0===n)return!0;if(r)return\"none\"===n;var i={first:t._tmin,last:t._tmax}[n];return\"all\"!==n&&e!==i}var g=r?\"never\":\"none\"!==t.exponentformat&&d(t.showexponent)?\"hide\":\"\";if(\"date\"===u?function(t,e,r,n){var a=t._tickround,o=r&&t.hoverformat||B.getTickFormat(t);n&&(a=i(a)?4:{y:\"m\",m:\"d\",d:\"M\",M:\"S\",S:4}[a]);var l,c=s.formatDate(e.x,o,a,t._dateFormat,t.calendar,t._extraFormat),u=c.indexOf(\"\\n\");-1!==u&&(l=c.substr(u+1),c=c.substr(0,u));n&&(\"00:00:00\"===c||\"00:00\"===c?(c=l,l=\"\"):8===c.length&&(c=c.replace(/:00$/,\"\")));if(l)if(r)\"d\"===a?c+=\", \"+l:c=l+(c?\", \"+c:\"\");else if(t._inCalcTicks&&t._prevDateHead===l){var f=-1!==(t.ticklabelposition||\"\").indexOf(\"inside\"),h=t._realSide||t.side;(!f&&\"top\"===h||f&&\"bottom\"===h)&&(c+=\"<br> \")}else t._prevDateHead=l,c+=\"<br>\"+l;e.text=c}(t,o,r,c):\"log\"===u?function(t,e,r,n,a){var o=t.dtick,l=e.x,c=t.tickformat,u=\"string\"==typeof o&&o.charAt(0);\"never\"===a&&(a=\"\");n&&\"L\"!==u&&(o=\"L3\",u=\"L\");if(c||\"L\"===u)e.text=lt(Math.pow(10,l),t,a,n);else if(i(o)||\"D\"===u&&s.mod(l+.01,1)<.1){var f=Math.round(l),h=Math.abs(f),p=t.exponentformat;\"power\"===p||ot(p)&&st(f)?(e.text=0===f?1:1===f?\"10\":\"10<sup>\"+(f>1?\"\":I)+h+\"</sup>\",e.fontSize*=1.25):(\"e\"===p||\"E\"===p)&&h>2?e.text=\"1\"+p+(f>0?\"+\":I)+h:(e.text=lt(Math.pow(10,l),t,\"\",\"fakehover\"),\"D1\"===o&&\"y\"===t._id.charAt(0)&&(e.dy-=e.fontSize/6))}else{if(\"D\"!==u)throw\"unrecognized dtick \"+String(o);e.text=String(Math.round(Math.pow(10,s.mod(l,1)))),e.fontSize*=.75}if(\"D1\"===t.dtick){var d=String(e.text).charAt(0);\"0\"!==d&&\"1\"!==d||(\"y\"===t._id.charAt(0)?e.dx-=e.fontSize/4:(e.dy+=e.fontSize/2,e.dx+=(t.range[1]>t.range[0]?1:-1)*e.fontSize*(l<0?.5:.25)))}}(t,o,0,c,g):\"category\"===u?function(t,e){var r=t._categories[Math.round(e.x)];void 0===r&&(r=\"\");e.text=String(r)}(t,o):\"multicategory\"===u?function(t,e,r){var n=Math.round(e.x),i=t._categories[n]||[],a=void 0===i[1]?\"\":String(i[1]),o=void 0===i[0]?\"\":String(i[0]);r?e.text=o+\" - \"+a:(e.text=a,e.text2=o)}(t,o,r):_t(t)?function(t,e,r,n,i){if(\"radians\"!==t.thetaunit||r)e.text=lt(e.x,t,i,n);else{var a=e.x/180;if(0===a)e.text=\"0\";else{var o=function(t){function e(t,e){return Math.abs(t-e)<=1e-6}var r=function(t){for(var r=1;!e(Math.round(t*r)/r,t);)r*=10;return r}(t),n=t*r,i=Math.abs(function t(r,n){return e(n,0)?r:t(n,r%n)}(n,r));return[Math.round(n/i),Math.round(r/i)]}(a);if(o[1]>=100)e.text=lt(s.deg2rad(e.x),t,i,n);else{var l=e.x<0;1===o[1]?1===o[0]?e.text=\"\\u03c0\":e.text=o[0]+\"\\u03c0\":e.text=[\"<sup>\",o[0],\"</sup>\",\"\\u2044\",\"<sub>\",o[1],\"</sub>\",\"\\u03c0\"].join(\"\"),l&&(e.text=I+e.text)}}}}(t,o,r,c,g):function(t,e,r,n,i){\"never\"===i?i=\"\":\"all\"===t.showexponent&&Math.abs(e.x/t.dtick)<1e-6&&(i=\"hide\");e.text=lt(e.x,t,i,n)}(t,o,0,c,g),n||(t.tickprefix&&!d(t.showtickprefix)&&(o.text=t.tickprefix+o.text),t.ticksuffix&&!d(t.showticksuffix)&&(o.text+=t.ticksuffix)),\"boundaries\"===t.tickson||t.showdividers){var m=function(e){var r=t.l2p(e);return r>=0&&r<=t._length?e:null};o.xbnd=[m(o.x-.5),m(o.x+t.dtick-.5)]}return o},B.hoverLabelText=function(t,e,r){if(r!==P&&r!==e)return B.hoverLabelText(t,e)+\" - \"+B.hoverLabelText(t,r);var n=\"log\"===t.type&&e<=0,i=B.tickText(t,t.c2l(n?-e:e),\"hover\").text;return n?0===e?\"0\":I+i:i};var at=[\"f\",\"p\",\"n\",\"\\u03bc\",\"m\",\"\",\"k\",\"M\",\"G\",\"T\"];function ot(t){return\"SI\"===t||\"B\"===t}function st(t){return t>14||t<-15}function lt(t,e,r,n){var a=t<0,o=e._tickround,l=r||e.exponentformat||\"B\",c=e._tickexponent,u=B.getTickFormat(e),f=e.separatethousands;if(n){var h={exponentformat:l,minexponent:e.minexponent,dtick:\"none\"===e.showexponent?e.dtick:i(t)&&Math.abs(t)||1,range:\"none\"===e.showexponent?e.range.map(e.r2d):[0,t||1]};nt(h),o=(Number(h._tickround)||0)+4,c=h._tickexponent,e.hoverformat&&(u=e.hoverformat)}if(u)return e._numFormat(u)(t).replace(/-/g,I);var p,d=Math.pow(10,-o)/2;if(\"none\"===l&&(c=0),(t=Math.abs(t))<d)t=\"0\",a=!1;else{if(t+=d,c&&(t*=Math.pow(10,-c),o+=c),0===o)t=String(Math.floor(t));else if(o<0){t=(t=String(Math.round(t))).substr(0,t.length+o);for(var g=o;g<0;g++)t+=\"0\"}else{var m=(t=String(t)).indexOf(\".\")+1;m&&(t=t.substr(0,m+o).replace(/\\.?0+$/,\"\"))}t=s.numSeparate(t,e._separators,f)}c&&\"hide\"!==l&&(ot(l)&&st(c)&&(l=\"power\"),p=c<0?I+-c:\"power\"!==l?\"+\"+c:String(c),\"e\"===l||\"E\"===l?t+=l+p:\"power\"===l?t+=\"\\xd710<sup>\"+p+\"</sup>\":\"B\"===l&&9===c?t+=\"B\":ot(l)&&(t+=at[c/3+5]));return a?I+t:t}function ct(t,e){for(var r=[],n={},i=0;i<e.length;i++){var a=e[i];n[a.text2]?n[a.text2].push(a.x):n[a.text2]=[a.x]}for(var o in n)r.push(it(t,s.interp(n[o],.5),o));return r}function ut(t){return void 0!==t.periodX?t.periodX:t.x}function ft(t){return[t.text,t.x,t.axInfo,t.font,t.fontSize,t.fontColor].join(\"_\")}function ht(t){var e=t.title.font.size,r=(t.title.text.match(c.BR_TAG_ALL)||[]).length;return t.title.hasOwnProperty(\"standoff\")?r?e*(D+r*R):e*D:r?e*(r+1)*R:e}function pt(t,e){var r=t.l2p(e);return r>1&&r<t._length-1}function dt(t){var e=n.select(t),r=e.select(\".text-math-group\");return r.empty()?e.select(\"text\"):r}function gt(t){return t._id+\".automargin\"}function mt(t){return gt(t)+\".mirror\"}function vt(t){return t._id+\".rangeslider\"}function yt(t,e){for(var r=0;r<e.length;r++)-1===t.indexOf(e[r])&&t.push(e[r])}function xt(t,e,r){var n,i,a=[],o=[],l=t.layout;for(n=0;n<e.length;n++)a.push(B.getFromId(t,e[n]));for(n=0;n<r.length;n++)o.push(B.getFromId(t,r[n]));var c=Object.keys(p),u=[\"anchor\",\"domain\",\"overlaying\",\"position\",\"side\",\"tickangle\",\"editType\"],f=[\"linear\",\"log\"];for(n=0;n<c.length;n++){var h=c[n],d=a[0][h],g=o[0][h],m=!0,v=!1,y=!1;if(\"_\"!==h.charAt(0)&&\"function\"!=typeof d&&-1===u.indexOf(h)){for(i=1;i<a.length&&m;i++){var x=a[i][h];\"type\"===h&&-1!==f.indexOf(d)&&-1!==f.indexOf(x)&&d!==x?v=!0:x!==d&&(m=!1)}for(i=1;i<o.length&&m;i++){var b=o[i][h];\"type\"===h&&-1!==f.indexOf(g)&&-1!==f.indexOf(b)&&g!==b?y=!0:o[i][h]!==g&&(m=!1)}m&&(v&&(l[a[0]._name].type=\"linear\"),y&&(l[o[0]._name].type=\"linear\"),bt(l,h,a,o,t._fullLayout._dfltTitle))}}for(n=0;n<t._fullLayout.annotations.length;n++){var _=t._fullLayout.annotations[n];-1!==e.indexOf(_.xref)&&-1!==r.indexOf(_.yref)&&s.swapAttrs(l.annotations[n],[\"?\"])}}function bt(t,e,r,n,i){var a,o=s.nestedProperty,l=o(t[r[0]._name],e).get(),c=o(t[n[0]._name],e).get();for(\"title\"===e&&(l&&l.text===i.x&&(l.text=i.y),c&&c.text===i.y&&(c.text=i.x)),a=0;a<r.length;a++)o(t,r[a]._name+\".\"+e).set(c);for(a=0;a<n.length;a++)o(t,n[a]._name+\".\"+e).set(l)}function _t(t){return\"angularaxis\"===t._id}function wt(t,e){for(var r=e._rangebreaks.length,n=0;n<r;n++){var i=e._rangebreaks[n];if(t>=i.min&&t<i.max)return i.max}return t}B.getTickFormat=function(t){var e,r,n,i,a,o,s,l;function c(t){return\"string\"!=typeof t?t:Number(t.replace(\"M\",\"\"))*T}function u(t,e){var r=[\"L\",\"D\"];if(typeof t==typeof e){if(\"number\"==typeof t)return t-e;var n=r.indexOf(t.charAt(0)),i=r.indexOf(e.charAt(0));return n===i?Number(t.replace(/(L|D)/g,\"\"))-Number(e.replace(/(L|D)/g,\"\")):n-i}return\"number\"==typeof t?1:-1}function f(t,e){var r=null===e[0],n=null===e[1],i=u(t,e[0])>=0,a=u(t,e[1])<=0;return(r||i)&&(n||a)}if(t.tickformatstops&&t.tickformatstops.length>0)switch(t.type){case\"date\":case\"linear\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&(i=t.dtick,a=n.dtickrange,o=void 0,s=void 0,l=void 0,o=c||function(t){return t},s=a[0],l=a[1],(!s&&\"number\"!=typeof s||o(s)<=o(i))&&(!l&&\"number\"!=typeof l||o(l)>=o(i)))){r=n;break}break;case\"log\":for(e=0;e<t.tickformatstops.length;e++)if((n=t.tickformatstops[e]).enabled&&f(t.dtick,n.dtickrange)){r=n;break}}return r?r.value:t.tickformat},B.getSubplots=function(t,e){var r=t._fullLayout._subplots,n=r.cartesian.concat(r.gl2d||[]),i=e?B.findSubplotsWithAxis(n,e):n;return i.sort((function(t,e){var r=t.substr(1).split(\"y\"),n=e.substr(1).split(\"y\");return r[0]===n[0]?+r[1]-+n[1]:+r[0]-+n[0]})),i},B.findSubplotsWithAxis=function(t,e){for(var r=new RegExp(\"x\"===e._id.charAt(0)?\"^\"+e._id+\"y\":e._id+\"$\"),n=[],i=0;i<t.length;i++){var a=t[i];r.test(a)&&n.push(a)}return n},B.makeClipPaths=function(t){var e=t._fullLayout;if(!e._hasOnlyLargeSploms){var r,i,a={_offset:0,_length:e.width,_id:\"\"},o={_offset:0,_length:e.height,_id:\"\"},s=B.list(t,\"x\",!0),l=B.list(t,\"y\",!0),c=[];for(r=0;r<s.length;r++)for(c.push({x:s[r],y:o}),i=0;i<l.length;i++)0===r&&c.push({x:a,y:l[i]}),c.push({x:s[r],y:l[i]});var u=e._clips.selectAll(\".axesclip\").data(c,(function(t){return t.x._id+t.y._id}));u.enter().append(\"clipPath\").classed(\"axesclip\",!0).attr(\"id\",(function(t){return\"clip\"+e._uid+t.x._id+t.y._id})).append(\"rect\"),u.exit().remove(),u.each((function(t){n.select(this).select(\"rect\").attr({x:t.x._offset||0,y:t.y._offset||0,width:t.x._length||1,height:t.y._length||1})}))}},B.draw=function(t,e,r){var n=t._fullLayout;\"redraw\"===e&&n._paper.selectAll(\"g.subplot\").each((function(t){var e=t[0],r=n._plots[e];if(r){var i=r.xaxis,a=r.yaxis;r.xaxislayer.selectAll(\".\"+i._id+\"tick\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"tick2\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"tick2\").remove(),r.xaxislayer.selectAll(\".\"+i._id+\"divider\").remove(),r.yaxislayer.selectAll(\".\"+a._id+\"divider\").remove(),r.gridlayer&&r.gridlayer.selectAll(\"path\").remove(),r.zerolinelayer&&r.zerolinelayer.selectAll(\"path\").remove(),n._infolayer.select(\".g-\"+i._id+\"title\").remove(),n._infolayer.select(\".g-\"+a._id+\"title\").remove()}}));var i=e&&\"redraw\"!==e?e:B.listIds(t);return s.syncOrAsync(i.map((function(e){return function(){if(e){var n=B.getFromId(t,e),i=B.drawOne(t,n,r);return n._r=n.range.slice(),n._rl=s.simpleMap(n._r,n.r2l),i}}})))},B.drawOne=function(t,e,r){var n,i,l;r=r||{},e.setScale();var c=t._fullLayout,p=e._id,d=p.charAt(0),g=B.counterLetter(p),m=c._plots[e._mainSubplot];if(m){var v=m[d+\"axislayer\"],y=e._mainLinePosition,x=e._mainMirrorPosition,b=e._vals=B.calcTicks(e),_=[e.mirror,y,x].join(\"_\");for(n=0;n<b.length;n++)b[n].axInfo=_;e._selections={},e._tickAngles&&(e._prevTickAngles=e._tickAngles),e._tickAngles={},e._depth=null;var w={};if(e.visible){var T,k,M=B.makeTransTickFn(e),A=B.makeTransTickLabelFn(e),S=\"inside\"===e.ticks,E=\"outside\"===e.ticks;if(\"boundaries\"===e.tickson){var C=function(t,e){var r,n=[],i=function(t,e){var r=t.xbnd[e];null!==r&&n.push(s.extendFlat({},t,{x:r}))};if(e.length){for(r=0;r<e.length;r++)i(e[r],0);i(e[r-1],1)}return n}(0,b);k=B.clipEnds(e,C),T=S?k:C}else k=B.clipEnds(e,b),T=S&&\"period\"!==e.ticklabelmode?k:b;var L=e._gridVals=k,I=function(t,e){var r,n,i=[],a=e.length&&e[e.length-1].x<e[0].x,o=function(t,e){var r=t.xbnd[e];null!==r&&i.push(s.extendFlat({},t,{x:r}))};if(t.showdividers&&e.length){for(r=0;r<e.length;r++){var l=e[r];l.text2!==n&&o(l,a?1:0),n=l.text2}o(e[r-1],a?0:1)}return i}(e,b);if(!c._hasOnlyLargeSploms){var P=e._subplotsWith,z={};for(n=0;n<P.length;n++){i=P[n];var O=(l=c._plots[i])[g+\"axis\"],D=O._mainAxis._id;if(!z[D]){z[D]=1;var N=\"x\"===d?\"M0,\"+O._offset+\"v\"+O._length:\"M\"+O._offset+\",0h\"+O._length;B.drawGrid(t,e,{vals:L,counterAxis:O,layer:l.gridlayer.select(\".\"+p),path:N,transFn:M}),B.drawZeroLine(t,e,{counterAxis:O,layer:l.zerolinelayer,path:N,transFn:M})}}}var j=B.getTickSigns(e),U=[];if(e.ticks){var V,q,H,G=B.makeTickPath(e,y,j[2]);if(e._anchorAxis&&e.mirror&&!0!==e.mirror?(V=B.makeTickPath(e,x,j[3]),q=G+V):(V=\"\",q=G),e.showdividers&&E&&\"boundaries\"===e.tickson){var Y={};for(n=0;n<I.length;n++)Y[I[n].x]=1;H=function(t){return Y[t.x]?V:q}}else H=q;B.drawTicks(t,e,{vals:T,layer:v,path:H,transFn:M}),\"allticks\"===e.mirror&&(U=Object.keys(e._linepositions||{}))}for(n=0;n<U.length;n++){i=U[n],l=c._plots[i];var W=e._linepositions[i]||[],X=B.makeTickPath(e,W[0],j[0])+B.makeTickPath(e,W[1],j[1]);B.drawTicks(t,e,{vals:T,layer:l[d+\"axislayer\"],path:X,transFn:M})}var Z=[];if(Z.push((function(){return B.drawLabels(t,e,{vals:b,layer:v,transFn:A,labelFns:B.makeLabelFns(e,y)})})),\"multicategory\"===e.type){var J={x:2,y:10}[d];Z.push((function(){var r={x:\"height\",y:\"width\"}[d],n=Q()[r]+J+(e._tickAngles[p+\"tick\"]?e.tickfont.size*R:0);return B.drawLabels(t,e,{vals:ct(e,b),layer:v,cls:p+\"tick2\",repositionOnUpdate:!0,secondary:!0,transFn:M,labelFns:B.makeLabelFns(e,y+n*j[4])})})),Z.push((function(){return e._depth=j[4]*(Q(\"tick2\")[e.side]-y),function(t,e,r){var n=e._id+\"divider\",i=r.vals,a=r.layer.selectAll(\"path.\"+n).data(i,ft);a.exit().remove(),a.enter().insert(\"path\",\":first-child\").classed(n,1).classed(\"crisp\",1).call(f.stroke,e.dividercolor).style(\"stroke-width\",h.crispRound(t,e.dividerwidth,1)+\"px\"),a.attr(\"transform\",r.transFn).attr(\"d\",r.path)}(t,e,{vals:I,layer:v,path:B.makeTickPath(e,y,j[4],e._depth),transFn:M})}))}else e.title.hasOwnProperty(\"standoff\")&&Z.push((function(){e._depth=j[4]*(Q()[e.side]-y)}));var K=o.getComponentMethod(\"rangeslider\",\"isVisible\")(e);return Z.push((function(){var r,n,i,s,l=e.side.charAt(0),u=F[e.side].charAt(0),f=B.getPxPosition(t,e),h=E?e.ticklen:0;if((e.automargin||K)&&(\"multicategory\"===e.type?r=Q(\"tick2\"):(r=Q(),\"x\"===d&&\"b\"===l&&(e._depth=Math.max(r.width>0?r.bottom-f:0,h)))),e.automargin){n={x:0,y:0,r:0,l:0,t:0,b:0};var p=[0,1];if(\"x\"===d){if(\"b\"===l?n[l]=e._depth:(n[l]=e._depth=Math.max(r.width>0?f-r.top:0,h),p.reverse()),r.width>0){var m=r.right-(e._offset+e._length);m>0&&(n.xr=1,n.r=m);var v=e._offset-r.left;v>0&&(n.xl=0,n.l=v)}}else if(\"l\"===l?n[l]=e._depth=Math.max(r.height>0?f-r.left:0,h):(n[l]=e._depth=Math.max(r.height>0?r.right-f:0,h),p.reverse()),r.height>0){var y=r.bottom-(e._offset+e._length);y>0&&(n.yb=0,n.b=y);var x=e._offset-r.top;x>0&&(n.yt=1,n.t=x)}n[g]=\"free\"===e.anchor?e.position:e._anchorAxis.domain[p[0]],e.title.text!==c._dfltTitle[d]&&(n[l]+=ht(e)+(e.title.standoff||0)),e.mirror&&\"free\"!==e.anchor&&((i={x:0,y:0,r:0,l:0,t:0,b:0})[u]=e.linewidth,e.mirror&&!0!==e.mirror&&(i[u]+=h),!0===e.mirror||\"ticks\"===e.mirror?i[g]=e._anchorAxis.domain[p[1]]:\"all\"!==e.mirror&&\"allticks\"!==e.mirror||(i[g]=[e._counterDomainMin,e._counterDomainMax][p[1]]))}K&&(s=o.getComponentMethod(\"rangeslider\",\"autoMarginOpts\")(t,e)),a.autoMargin(t,gt(e),n),a.autoMargin(t,mt(e),i),a.autoMargin(t,vt(e),s)})),r.skipTitle||K&&\"bottom\"===e.side||Z.push((function(){return function(t,e){var r,n=t._fullLayout,i=e._id,a=i.charAt(0),o=e.title.font.size;if(e.title.hasOwnProperty(\"standoff\"))r=e._depth+e.title.standoff+ht(e);else{var s=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");if(\"multicategory\"===e.type)r=e._depth;else{var l=1.5*o;s&&(l=.5*o,\"outside\"===e.ticks&&(l+=e.ticklen)),r=10+l+(e.linewidth?e.linewidth-1:0)}s||(r+=\"x\"===a?\"top\"===e.side?o*(e.showticklabels?1:0):o*(e.showticklabels?1.5:.5):\"right\"===e.side?o*(e.showticklabels?1:.5):o*(e.showticklabels?.5:0))}var c,f,p,d,g=B.getPxPosition(t,e);\"x\"===a?(f=e._offset+e._length/2,p=\"top\"===e.side?g-r:g+r):(p=e._offset+e._length/2,f=\"right\"===e.side?g+r:g-r,c={rotate:\"-90\",offset:0});if(\"multicategory\"!==e.type){var m=e._selections[e._id+\"tick\"];if(d={selection:m,side:e.side},m&&m.node()&&m.node().parentNode){var v=h.getTranslate(m.node().parentNode);d.offsetLeft=v.x,d.offsetTop=v.y}e.title.hasOwnProperty(\"standoff\")&&(d.pad=0)}return u.draw(t,i+\"title\",{propContainer:e,propName:e._name+\".title.text\",placeholder:n._dfltTitle[a],avoid:d,transform:c,attributes:{x:f,y:p,\"text-anchor\":\"middle\"}})}(t,e)})),s.syncOrAsync(Z)}}function Q(t){var r=p+(t||\"tick\");return w[r]||(w[r]=function(t,e){var r,n,i,a;t._selections[e].size()?(r=1/0,n=-1/0,i=1/0,a=-1/0,t._selections[e].each((function(){var t=dt(this),e=h.bBox(t.node().parentNode);r=Math.min(r,e.top),n=Math.max(n,e.bottom),i=Math.min(i,e.left),a=Math.max(a,e.right)}))):(r=0,n=0,i=0,a=0);return{top:r,bottom:n,left:i,right:a,height:n-r,width:a-i}}(e,r)),w[r]}},B.getTickSigns=function(t){var e=t._id.charAt(0),r={x:\"top\",y:\"right\"}[e],n=t.side===r?1:-1,i=[-1,1,n,-n];return\"inside\"!==t.ticks==(\"x\"===e)&&(i=i.map((function(t){return-t}))),t.side&&i.push({l:-1,t:-1,r:1,b:1}[t.side.charAt(0)]),i},B.makeTransTickFn=function(t){return\"x\"===t._id.charAt(0)?function(e){return l(t._offset+t.l2p(e.x),0)}:function(e){return l(0,t._offset+t.l2p(e.x))}},B.makeTransTickLabelFn=function(t){var e=function(t){var e=t.ticklabelposition||\"\",r=function(t){return-1!==e.indexOf(t)},n=r(\"top\"),i=r(\"left\"),a=r(\"right\"),o=r(\"bottom\"),s=r(\"inside\"),l=o||i||n||a;if(!l&&!s)return[0,0];var c=t.side,u=l?(t.tickwidth||0)/2:0,f=3,h=t.tickfont?t.tickfont.size:12;(o||n)&&(u+=h*D,f+=(t.linewidth||0)/2);(i||a)&&(u+=(t.linewidth||0)/2,f+=3);s&&\"top\"===c&&(f-=h*(1-D));(i||n)&&(u=-u);\"bottom\"!==c&&\"right\"!==c||(f=-f);return[l?u:0,s?f:0]}(t),r=e[0],n=e[1];return\"x\"===t._id.charAt(0)?function(e){return l(r+t._offset+t.l2p(ut(e)),n)}:function(e){return l(n,r+t._offset+t.l2p(ut(e)))}},B.makeTickPath=function(t,e,r,n){n=void 0!==n?n:t.ticklen;var i=t._id.charAt(0),a=(t.linewidth||1)/2;return\"x\"===i?\"M0,\"+(e+a*r)+\"v\"+n*r:\"M\"+(e+a*r)+\",0h\"+n*r},B.makeLabelFns=function(t,e,r){var n=t.ticklabelposition||\"\",a=function(t){return-1!==n.indexOf(t)},o=a(\"top\"),l=a(\"left\"),c=a(\"right\"),u=a(\"bottom\")||l||o||c,f=a(\"inside\"),h=\"inside\"===n&&\"inside\"===t.ticks||!f&&\"outside\"===t.ticks&&\"boundaries\"!==t.tickson,p=0,d=0,g=h?t.ticklen:0;if(f?g*=-1:u&&(g=0),h&&(p+=g,r)){var m=s.deg2rad(r);p=g*Math.cos(m)+1,d=g*Math.sin(m)}t.showticklabels&&(h||t.showline)&&(p+=.2*t.tickfont.size);var v,y,x,b,_,w={labelStandoff:p+=(t.linewidth||1)/2*(f?-1:1),labelShift:d},T=0,k=t.side,M=t._id.charAt(0),A=t.tickangle;if(\"x\"===M)b=(_=!f&&\"bottom\"===k||f&&\"top\"===k)?1:-1,f&&(b*=-1),v=d*b,y=e+p*b,x=_?1:-.2,90===Math.abs(A)&&(f?x+=O:x=-90===A&&\"bottom\"===k?D:90===A&&\"top\"===k?O:.5,T=O/2*(A/90)),w.xFn=function(t){return t.dx+v+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*x},w.anchorFn=function(t,e){if(u){if(l)return\"end\";if(c)return\"start\"}return i(e)&&0!==e&&180!==e?e*b<0!==f?\"end\":\"start\":\"middle\"},w.heightFn=function(e,r,n){return r<-60||r>60?-.5*n:\"top\"===t.side!==f?-n:0};else if(\"y\"===M){if(b=(_=!f&&\"left\"===k||f&&\"right\"===k)?1:-1,f&&(b*=-1),v=p,y=d*b,x=0,f||90!==Math.abs(A)||(x=-90===A&&\"left\"===k||90===A&&\"right\"===k?D:.5),f){var S=i(A)?+A:0;if(0!==S){var E=s.deg2rad(S);T=Math.abs(Math.sin(E))*D*b,x=0}}w.xFn=function(t){return t.dx+e-(v+t.fontSize*x)*b+T*t.fontSize},w.yFn=function(t){return t.dy+y+t.fontSize*O},w.anchorFn=function(t,e){return i(e)&&90===Math.abs(e)?\"middle\":_?\"end\":\"start\"},w.heightFn=function(e,r,n){return\"right\"===t.side&&(r*=-1),r<-30?-n:r<30?-.5*n:0}}return w},B.drawTicks=function(t,e,r){r=r||{};var n=e._id+\"tick\",i=r.vals;\"period\"===e.ticklabelmode&&(i=i.slice()).shift();var a=r.layer.selectAll(\"path.\"+n).data(e.ticks?i:[],ft);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"ticks\",1).classed(\"crisp\",!1!==r.crisp).call(f.stroke,e.tickcolor).style(\"stroke-width\",h.crispRound(t,e.tickwidth,1)+\"px\").attr(\"d\",r.path),a.attr(\"transform\",r.transFn)},B.drawGrid=function(t,e,r){r=r||{};var n=e._id+\"grid\",i=r.vals,a=r.counterAxis;if(!1===e.showgrid)i=[];else if(a&&B.shouldShowZeroLine(t,e,a))for(var o=\"array\"===e.tickmode,s=0;s<i.length;s++){var l=i[s].x;if(o?!l:Math.abs(l)<e.dtick/100){if(i=i.slice(0,s).concat(i.slice(s+1)),!o)break;s--}}var c=r.layer.selectAll(\"path.\"+n).data(i,ft);c.exit().remove(),c.enter().append(\"path\").classed(n,1).classed(\"crisp\",!1!==r.crisp),e._gw=h.crispRound(t,e.gridwidth,1),c.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.gridcolor||\"#ddd\").style(\"stroke-width\",e._gw+\"px\"),\"function\"==typeof r.path&&c.attr(\"d\",r.path)},B.drawZeroLine=function(t,e,r){r=r||r;var n=e._id+\"zl\",i=B.shouldShowZeroLine(t,e,r.counterAxis),a=r.layer.selectAll(\"path.\"+n).data(i?[{x:0,id:e._id}]:[]);a.exit().remove(),a.enter().append(\"path\").classed(n,1).classed(\"zl\",1).classed(\"crisp\",!1!==r.crisp).each((function(){r.layer.selectAll(\"path\").sort((function(t,e){return U(t.id,e.id)}))})),a.attr(\"transform\",r.transFn).attr(\"d\",r.path).call(f.stroke,e.zerolinecolor||f.defaultLine).style(\"stroke-width\",h.crispRound(t,e.zerolinewidth,e._gw||1)+\"px\")},B.drawLabels=function(t,e,r){r=r||{};var a=t._fullLayout,o=e._id,u=o.charAt(0),f=r.cls||o+\"tick\",p=r.vals,d=r.labelFns,g=r.secondary?0:e.tickangle,m=(e._prevTickAngles||{})[f],v=r.layer.selectAll(\"g.\"+f).data(e.showticklabels?p:[],ft),y=[];function x(t,a){var o=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\");t.each((function(t){var s=n.select(this),u=s.select(\".text-math-group\"),f=d.anchorFn(t,a),p=r.transFn.call(s.node(),t)+(i(a)&&0!=+a?\" rotate(\"+a+\",\"+d.xFn(t)+\",\"+(d.yFn(t)-t.fontSize/2)+\")\":\"\"),g=c.lineCount(s),m=R*t.fontSize,v=d.heightFn(t,i(a)?+a:0,(g-1)*m);if(v&&(p+=l(0,v)),u.empty()){var y=s.select(\"text\");y.attr({transform:p,\"text-anchor\":f}),o&&(y.style({opacity:100}),e._hideOutOfRangeInsideTickLabels&&e._hideOutOfRangeInsideTickLabels())}else{var x=h.bBox(u.node()).width*{end:-.5,start:.5}[f];u.attr(\"transform\",p+l(x,0))}}))}v.enter().append(\"g\").classed(f,1).append(\"text\").attr(\"text-anchor\",\"middle\").each((function(e){var r=n.select(this),i=t._promises.length;r.call(c.positionText,d.xFn(e),d.yFn(e)).call(h.font,e.font,e.fontSize,e.fontColor).text(e.text).call(c.convertToTspans,t),t._promises[i]?y.push(t._promises.pop().then((function(){x(r,g)}))):x(r,g)})),v.exit().remove(),r.repositionOnUpdate&&v.each((function(t){n.select(this).select(\"text\").call(c.positionText,d.xFn(t),d.yFn(t))})),e._hideOutOfRangeInsideTickLabels=void 0,-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&(e._hideOutOfRangeInsideTickLabels=function(){var t=s.simpleMap(e.range,e.r2l),r=e.l2p(t[0]),i=e.l2p(t[1]),a=Math.min(r,i)+e._offset,o=Math.max(r,i)+e._offset,l=\"x\"===e._id.charAt(0);v.each((function(t){var r=n.select(this);if(r.select(\".text-math-group\").empty()){var i=h.bBox(r.node()),s=!1;l?(i.right>o||i.left<a)&&(s=!0):(i.bottom>o||i.top+(e.tickangle?0:t.fontSize/4)<a)&&(s=!0),s&&r.select(\"text\").style({opacity:0})}}))}),x(v,m+1?m:g);var b=null;e._selections&&(e._selections[f]=v);var _=[function(){return y.length&&Promise.all(y)}];e.automargin&&a._redrawFromAutoMarginCount&&90===m?(b=90,_.push((function(){x(v,m)}))):_.push((function(){if(x(v,g),p.length&&\"x\"===u&&!i(g)&&(\"log\"!==e.type||\"D\"!==String(e.dtick).charAt(0))){b=0;var t,n=0,a=[];if(v.each((function(t){n=Math.max(n,t.fontSize);var r=e.l2p(t.x),i=dt(this),o=h.bBox(i.node());a.push({top:0,bottom:10,height:10,left:r-o.width/2,right:r+o.width/2+2,width:o.width+2})})),\"boundaries\"!==e.tickson&&!e.showdividers||r.secondary){var o=p.length,l=Math.abs((p[o-1].x-p[0].x)*e._m)/(o-1),c=e.ticklabelposition||\"\",f=function(t){return-1!==c.indexOf(t)},d=f(\"top\"),m=f(\"left\"),y=f(\"right\"),_=f(\"bottom\")||m||d||y?(e.tickwidth||0)+6:0,w=l<2.5*n||\"multicategory\"===e.type;for(t=0;t<a.length-1;t++)if(s.bBoxIntersect(a[t],a[t+1],_)){b=w?90:30;break}}else{var T=2;for(e.ticks&&(T+=e.tickwidth/2),t=0;t<a.length;t++){var k=p[t].xbnd,M=a[t];if(null!==k[0]&&M.left-e.l2p(k[0])<T||null!==k[1]&&e.l2p(k[1])-M.right<T){b=90;break}}}b&&x(v,b)}})),e._tickAngles&&_.push((function(){e._tickAngles[f]=null===b?i(g)?g:0:b}));var w=e._anchorAxis;w&&w.autorange&&-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")&&!V(a,e._id)&&(a._insideTickLabelsAutorange||(a._insideTickLabelsAutorange={}),a._insideTickLabelsAutorange[w._name+\".autorange\"]=w.autorange,_.push((function(){v.each((function(t,r){var n=dt(this);e._vals[r].bb=h.bBox(n.node())}))})));var T=s.syncOrAsync(_);return T&&T.then&&t._promises.push(T),T},B.getPxPosition=function(t,e){var r,n=t._fullLayout._size,i=e._id.charAt(0),a=e.side;return\"free\"!==e.anchor?r=e._anchorAxis:\"x\"===i?r={_offset:n.t+(1-(e.position||0))*n.h,_length:0}:\"y\"===i&&(r={_offset:n.l+(e.position||0)*n.w,_length:0}),\"top\"===a||\"left\"===a?r._offset:\"bottom\"===a||\"right\"===a?r._offset+r._length:void 0},B.shouldShowZeroLine=function(t,e,r){var n=s.simpleMap(e.range,e.r2l);return n[0]*n[1]<=0&&e.zeroline&&(\"linear\"===e.type||\"-\"===e.type)&&!(e.rangebreaks&&e.maskBreaks(0)===P)&&(pt(e,0)||!function(t,e,r,n){var i=r._mainAxis;if(!i)return;var a=t._fullLayout,o=e._id.charAt(0),s=B.counterLetter(e._id),l=e._offset+(Math.abs(n[0])<Math.abs(n[1])==(\"x\"===o)?0:e._length);function c(t){if(!t.showline||!t.linewidth)return!1;var r=Math.max((t.linewidth+e.zerolinewidth)/2,1);function n(t){return\"number\"==typeof t&&Math.abs(t-l)<r}if(n(t._mainLinePosition)||n(t._mainMirrorPosition))return!0;var i=t._linepositions||{};for(var a in i)if(n(i[a][0])||n(i[a][1]))return!0}var u=a._plots[r._mainSubplot];if(!(u.mainplotinfo||u).overlays.length)return c(r);for(var f=B.list(t,s),h=0;h<f.length;h++){var p=f[h];if(p._mainAxis===i&&c(p))return!0}}(t,e,r,n)||function(t,e){for(var r=t._fullData,n=e._mainSubplot,i=e._id.charAt(0),a=0;a<r.length;a++){var s=r[a];if(!0===s.visible&&s.xaxis+s.yaxis===n){if(o.traceIs(s,\"bar-like\")&&s.orientation==={x:\"h\",y:\"v\"}[i])return!0;if(s.fill&&s.fill.charAt(s.fill.length-1)===i)return!0}}return!1}(t,e))},B.clipEnds=function(t,e){return e.filter((function(e){return pt(t,e.x)}))},B.allowAutoMargin=function(t){for(var e=B.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r];n.automargin&&(a.allowAutoMargin(t,gt(n)),n.mirror&&a.allowAutoMargin(t,mt(n))),o.getComponentMethod(\"rangeslider\",\"isVisible\")(n)&&a.allowAutoMargin(t,vt(n))}},B.swap=function(t,e){for(var r=function(t,e){var r,n,i=[];for(r=0;r<e.length;r++){var a=[],o=t._fullData[e[r]].xaxis,s=t._fullData[e[r]].yaxis;if(o&&s){for(n=0;n<i.length;n++)-1===i[n].x.indexOf(o)&&-1===i[n].y.indexOf(s)||a.push(n);if(a.length){var l,c=i[a[0]];if(a.length>1)for(n=1;n<a.length;n++)l=i[a[n]],yt(c.x,l.x),yt(c.y,l.y);yt(c.x,[o]),yt(c.y,[s])}else i.push({x:[o],y:[s]})}}return i}(t,e),n=0;n<r.length;n++)xt(t,r[n].x,r[n].y)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../../registry\":911,\"./autorange\":827,\"./axis_autotype\":829,\"./axis_ids\":831,\"./clean_ticks\":833,\"./layout_attributes\":842,\"./set_convert\":848,d3:169,\"fast-isnumeric\":241}],829:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=i.isArrayOrTypedArray,s=i.isDateTime,l=i.cleanNumber,c=Math.round;function u(t,e){return e?n(t):\"number\"==typeof t}function f(t){return Math.max(1,(t-1)/1e3)}e.exports=function(t,e,r){var i=t,h=r.noMultiCategory;if(o(i)&&!i.length)return\"-\";if(!h&&function(t){return o(t[0])&&o(t[1])}(i))return\"multicategory\";if(h&&Array.isArray(i[0])){for(var p=[],d=0;d<i.length;d++)if(o(i[d]))for(var g=0;g<i[d].length;g++)p.push(i[d][g]);i=p}if(function(t,e){for(var r=t.length,i=f(r),a=0,o=0,l={},u=0;u<r;u+=i){var h=c(u),p=t[h],d=String(p);l[d]||(l[d]=1,s(p,e)&&a++,n(p)&&o++)}return a>2*o}(i,e))return\"date\";var m=\"strict\"!==r.autotypenumbers;return function(t,e){for(var r=t.length,n=f(r),i=0,o=0,s={},u=0;u<r;u+=n){var h=c(u),p=t[h],d=String(p);if(!s[d]){s[d]=1;var g=typeof p;\"boolean\"===g?o++:(e?l(p)!==a:\"number\"===g)?i++:\"string\"===g&&o++}}return o>2*i}(i,m)?\"category\":function(t,e){for(var r=t.length,n=0;n<r;n++)if(u(t[n],e))return!0;return!1}(i,m)?\"linear\":\"-\"}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],830:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../array_container_defaults\"),s=t(\"./layout_attributes\"),l=t(\"./tick_value_defaults\"),c=t(\"./tick_mark_defaults\"),u=t(\"./tick_label_defaults\"),f=t(\"./category_order_defaults\"),h=t(\"./line_grid_defaults\"),p=t(\"./set_convert\"),d=t(\"./constants\").WEEKDAY_PATTERN,g=t(\"./constants\").HOUR_PATTERN;function m(t,e,r){function i(r,n){return a.coerce(t,e,s.rangebreaks,r,n)}if(i(\"enabled\")){var o=i(\"bounds\");if(o&&o.length>=2){var l,c,u=\"\";if(2===o.length)for(l=0;l<2;l++)if(c=y(o[l])){u=d;break}var f=i(\"pattern\",u);if(f===d)for(l=0;l<2;l++)(c=y(o[l]))&&(e.bounds[l]=o[l]=c-1);if(f)for(l=0;l<2;l++)switch(c=o[l],f){case d:if(!n(c))return void(e.enabled=!1);if((c=+c)!==Math.floor(c)||c<0||c>=7)return void(e.enabled=!1);e.bounds[l]=o[l]=c;break;case g:if(!n(c))return void(e.enabled=!1);if((c=+c)<0||c>24)return void(e.enabled=!1);e.bounds[l]=o[l]=c}if(!1===r.autorange){var h=r.range;if(h[0]<h[1]){if(o[0]<h[0]&&o[1]>h[1])return void(e.enabled=!1)}else if(o[0]>h[0]&&o[1]<h[1])return void(e.enabled=!1)}}else{var p=i(\"values\");if(!p||!p.length)return void(e.enabled=!1);i(\"dvalue\")}}}e.exports=function(t,e,r,n,g){var v,y=n.letter,x=n.font||{},b=n.splomStash||{},_=r(\"visible\",!n.visibleDflt),w=e._template||{},T=e.type||w.type||\"-\";\"date\"===T&&(i.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",n.calendar),n.noTicklabelmode||(v=r(\"ticklabelmode\")));n.noTicklabelposition&&\"multicategory\"!==T||a.coerce(t,e,{ticklabelposition:{valType:\"enumerated\",dflt:\"outside\",values:\"period\"===v?[\"outside\",\"inside\"]:\"x\"===y?[\"outside\",\"inside\",\"outside left\",\"inside left\",\"outside right\",\"inside right\"]:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside bottom\",\"inside bottom\"]}},\"ticklabelposition\"),p(e,g);var k=!e.isValidRange(t.range);k&&n.reverseDflt&&(k=\"reversed\"),!r(\"autorange\",k)||\"linear\"!==T&&\"-\"!==T||r(\"rangemode\"),r(\"range\"),e.cleanRange(),f(t,e,r,n),\"category\"===T||n.noHover||r(\"hoverformat\");var M=r(\"color\"),A=M!==s.color.dflt?M:x.color,S=b.label||g._dfltTitle[y];if(u(t,e,r,T,n,{pass:1}),!_)return e;r(\"title.text\",S),a.coerceFont(r,\"title.font\",{family:x.family,size:Math.round(1.2*x.size),color:A}),l(t,e,r,T),u(t,e,r,T,n,{pass:2}),c(t,e,r,n),h(t,e,r,{dfltColor:M,bgColor:n.bgColor,showGrid:n.showGrid,attributes:s}),(e.showline||e.ticks)&&r(\"mirror\"),n.automargin&&r(\"automargin\");var E,C=\"multicategory\"===T;n.noTickson||\"category\"!==T&&!C||!e.ticks&&!e.showgrid||(C&&(E=\"boundaries\"),\"boundaries\"===r(\"tickson\",E)&&delete e.ticklabelposition);C&&(r(\"showdividers\")&&(r(\"dividercolor\"),r(\"dividerwidth\")));if(\"date\"===T)if(o(t,e,{name:\"rangebreaks\",inclusionAttr:\"enabled\",handleItemDefaults:m}),e.rangebreaks.length){for(var L=0;L<e.rangebreaks.length;L++)if(e.rangebreaks[L].pattern===d){e._hasDayOfWeekBreaks=!0;break}if(p(e,g),g._has(\"scattergl\")||g._has(\"splom\"))for(var I=0;I<n.data.length;I++){var P=n.data[I];\"scattergl\"!==P.type&&\"splom\"!==P.type||(P.visible=!1,a.warn(P.type+\" traces do not work on axes with rangebreaks. Setting trace \"+P.index+\" to `visible: false`.\"))}}else delete e.rangebreaks;return e};var v={sun:1,mon:2,tue:3,wed:4,thu:5,fri:6,sat:7};function y(t){if(\"string\"==typeof t)return v[t.substr(0,3).toLowerCase()]}},{\"../../lib\":778,\"../../registry\":911,\"../array_container_defaults\":823,\"./category_order_defaults\":832,\"./constants\":834,\"./layout_attributes\":842,\"./line_grid_defaults\":844,\"./set_convert\":848,\"./tick_label_defaults\":849,\"./tick_mark_defaults\":850,\"./tick_value_defaults\":851,\"fast-isnumeric\":241}],831:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"./constants\");function a(t,e){if(e&&e.length)for(var r=0;r<e.length;r++)if(e[r][t])return!0;return!1}r.id2name=function(t){if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)){var e=t.split(\" \")[0].substr(1);return\"1\"===e&&(e=\"\"),t.charAt(0)+\"axis\"+e}},r.name2id=function(t){if(t.match(i.AX_NAME_PATTERN)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),t.charAt(0)+e}},r.cleanId=function(t,e,r){var n=/( domain)$/.test(t);if(\"string\"==typeof t&&t.match(i.AX_ID_PATTERN)&&(!e||t.charAt(0)===e)&&(!n||r)){var a=t.split(\" \")[0].substr(1).replace(/^0+/,\"\");return\"1\"===a&&(a=\"\"),t.charAt(0)+a+(n&&r?\" domain\":\"\")}},r.list=function(t,e,n){var i=t._fullLayout;if(!i)return[];var a,o=r.listIds(t,e),s=new Array(o.length);for(a=0;a<o.length;a++){var l=o[a];s[a]=i[l.charAt(0)+\"axis\"+l.substr(1)]}if(!n){var c=i._subplots.gl3d||[];for(a=0;a<c.length;a++){var u=i[c[a]];e?s.push(u[e+\"axis\"]):s.push(u.xaxis,u.yaxis,u.zaxis)}}return s},r.listIds=function(t,e){var r=t._fullLayout;if(!r)return[];var n=r._subplots;return e?n[e+\"axis\"]:n.xaxis.concat(n.yaxis)},r.getFromId=function(t,e,n){var i=t._fullLayout;return e=void 0===e||\"string\"!=typeof e?e:e.replace(\" domain\",\"\"),\"x\"===n?e=e.replace(/y[0-9]*/,\"\"):\"y\"===n&&(e=e.replace(/x[0-9]*/,\"\")),i[r.id2name(e)]},r.getFromTrace=function(t,e,i){var a=t._fullLayout,o=null;if(n.traceIs(e,\"gl3d\")){var s=e.scene;\"scene\"===s.substr(0,5)&&(o=a[s][i+\"axis\"])}else o=r.getFromId(t,e[i+\"axis\"]||i);return o},r.idSort=function(t,e){var r=t.charAt(0),n=e.charAt(0);return r!==n?r>n?1:-1:+(t.substr(1)||1)-+(e.substr(1)||1)},r.ref2id=function(t){return!!/^[xyz]/.test(t)&&t.split(\" \")[0]},r.isLinked=function(t,e){return a(e,t._axisMatchGroups)||a(e,t._axisConstraintGroups)}},{\"../../registry\":911,\"./constants\":834}],832:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){if(\"category\"===e.type){var i,a=t.categoryarray,o=Array.isArray(a)&&a.length>0;o&&(i=\"array\");var s,l=r(\"categoryorder\",i);\"array\"===l&&(s=r(\"categoryarray\")),o||\"array\"!==l||(l=e.categoryorder=\"trace\"),\"trace\"===l?e._initialCategories=[]:\"array\"===l?e._initialCategories=s.slice():(s=function(t,e){var r,n,i,a=e.dataAttr||t._id.charAt(0),o={};if(e.axData)r=e.axData;else for(r=[],n=0;n<e.data.length;n++){var s=e.data[n];s[a+\"axis\"]===t._id&&r.push(s)}for(n=0;n<r.length;n++){var l=r[n][a];for(i=0;i<l.length;i++){var c=l[i];null!=c&&(o[c]=1)}}return Object.keys(o)}(e,n).sort(),\"category ascending\"===l?e._initialCategories=s:\"category descending\"===l&&(e._initialCategories=s.reverse()))}}},{}],833:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\"),o=a.ONEDAY,s=a.ONEWEEK;r.dtick=function(t,e){var r=\"log\"===e,i=\"date\"===e,a=\"category\"===e,s=i?o:1;if(!t)return s;if(n(t))return(t=Number(t))<=0?s:a?Math.max(1,Math.round(t)):i?Math.max(.1,t):t;if(\"string\"!=typeof t||!i&&!r)return s;var l=t.charAt(0),c=t.substr(1);return(c=n(c)?Number(c):0)<=0||!(i&&\"M\"===l&&c===Math.round(c)||r&&\"L\"===l||r&&\"D\"===l&&(1===c||2===c))?s:t},r.tick0=function(t,e,r,a){return\"date\"===e?i.cleanDate(t,i.dateTick0(r,a%s==0?1:0)):\"D1\"!==a&&\"D2\"!==a?n(t)?Number(t):0:void 0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],834:[function(t,e,r){\"use strict\";var n=t(\"../../lib/regex\").counter;e.exports={idRegex:{x:n(\"x\",\"( domain)?\"),y:n(\"y\",\"( domain)?\")},attrRegex:n(\"[xy]axis\"),xAxisMatch:n(\"xaxis\"),yAxisMatch:n(\"yaxis\"),AX_ID_PATTERN:/^[xyz][0-9]*( domain)?$/,AX_NAME_PATTERN:/^[xyz]axis[0-9]*$/,SUBPLOT_PATTERN:/^x([0-9]*)y([0-9]*)$/,HOUR_PATTERN:\"hour\",WEEKDAY_PATTERN:\"day of week\",MINDRAG:8,MINSELECT:12,MINZOOM:20,DRAGGERSIZE:20,BENDPX:1.5,REDRAWDELAY:50,SELECTDELAY:100,SELECTID:\"-select\",DFLTRANGEX:[-1,6],DFLTRANGEY:[-1,4],traceLayerClasses:[\"imagelayer\",\"heatmaplayer\",\"contourcarpetlayer\",\"contourlayer\",\"funnellayer\",\"waterfalllayer\",\"barlayer\",\"carpetlayer\",\"violinlayer\",\"boxlayer\",\"ohlclayer\",\"scattercarpetlayer\",\"scatterlayer\"],clipOnAxisFalseQuery:[\".scatterlayer\",\".barlayer\",\".funnellayer\",\".waterfalllayer\"],layerValue2layerClass:{\"above traces\":\"above\",\"below traces\":\"below\"}}},{\"../../lib/regex\":795}],835:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./autorange\"),a=t(\"./axis_ids\").id2name,o=t(\"./layout_attributes\"),s=t(\"./scale_zoom\"),l=t(\"./set_convert\"),c=t(\"../../constants/numerical\").ALMOST_EQUAL,u=t(\"../../constants/alignment\").FROM_BL;function f(t,e,r){var i=r.axIds,s=r.layoutOut,l=r.hasImage,c=s._axisConstraintGroups,u=s._axisMatchGroups,f=e._id,g=f.charAt(0),m=((s._splomAxes||{})[g]||{})[f]||{},v=e._id,y=\"x\"===v.charAt(0);function x(r,i){return n.coerce(t,e,o,r,i)}e._matchGroup=null,e._constraintGroup=null,x(\"constrain\",l?\"domain\":\"range\"),n.coerce(t,e,{constraintoward:{valType:\"enumerated\",values:y?[\"left\",\"center\",\"right\"]:[\"bottom\",\"middle\",\"top\"],dflt:y?\"center\":\"middle\"}},\"constraintoward\");var b,_,w=e.type,T=[];for(b=0;b<i.length;b++){if((_=i[b])!==v)s[a(_)].type===w&&T.push(_)}var k=p(c,v);if(k){var M=[];for(b=0;b<T.length;b++)k[_=T[b]]||M.push(_);T=M}var A,S,E=T.length;E&&(t.matches||m.matches)&&(A=n.coerce(t,e,{matches:{valType:\"enumerated\",values:T,dflt:-1!==T.indexOf(m.matches)?m.matches:void 0}},\"matches\"));var C=l&&!y?e.anchor:void 0;if(E&&!A&&(t.scaleanchor||C)&&(S=n.coerce(t,e,{scaleanchor:{valType:\"enumerated\",values:T}},\"scaleanchor\",C)),A){e._matchGroup=d(u,v,A,1);var L=s[a(A)],I=h(s,e)/h(s,L);y!==(\"x\"===A.charAt(0))&&(I=(y?\"x\":\"y\")+I),d(c,v,A,I)}else t.matches&&-1!==i.indexOf(t.matches)&&n.warn(\"ignored \"+e._name+'.matches: \"'+t.matches+'\" to avoid an infinite loop');if(S){var P=x(\"scaleratio\");P||(P=e.scaleratio=1),d(c,v,S,P)}else t.scaleanchor&&-1!==i.indexOf(t.scaleanchor)&&n.warn(\"ignored \"+e._name+'.scaleanchor: \"'+t.scaleanchor+'\" to avoid either an infinite loop and possibly inconsistent scaleratios, or because this axis declares a *matches* constraint.')}function h(t,e){var r=e.domain;return r||(r=t[a(e.overlaying)].domain),r[1]-r[0]}function p(t,e){for(var r=0;r<t.length;r++)if(t[r][e])return t[r];return null}function d(t,e,r,n){var i,a,o,s,l,c=p(t,e);null===c?((c={})[e]=1,l=t.length,t.push(c)):l=t.indexOf(c);var u=Object.keys(c);for(i=0;i<t.length;i++)if(o=t[i],i!==l&&o[r]){var f=o[r];for(a=0;a<u.length;a++)o[s=u[a]]=g(f,g(n,c[s]));return void t.splice(l,1)}if(1!==n)for(a=0;a<u.length;a++){var h=u[a];c[h]=g(n,c[h])}c[r]=1}function g(t,e){var r,n,i=\"\",a=\"\";\"string\"==typeof t&&(r=(i=t.match(/^[xy]*/)[0]).length,t=+t.substr(r)),\"string\"==typeof e&&(n=(a=e.match(/^[xy]*/)[0]).length,e=+e.substr(n));var o=t*e;return r||n?r&&n&&i.charAt(0)!==a.charAt(0)?r===n?o:(r>n?i.substr(n):a.substr(r))+o:i+a+t*e:o}function m(t,e){for(var r=e._size,n=r.h/r.w,i={},a=Object.keys(t),o=0;o<a.length;o++){var s=a[o],l=t[s];if(\"string\"==typeof l){var c=l.match(/^[xy]*/)[0],u=c.length;l=+l.substr(u);for(var f=\"y\"===c.charAt(0)?n:1/n,h=0;h<u;h++)l*=f}i[s]=l}return i}function v(t,e){var r=t._inputDomain,n=u[t.constraintoward],i=r[0]+(r[1]-r[0])*n;t.domain=t._input.domain=[i+(r[0]-i)/e,i+(r[1]-i)/e],t.setScale()}r.handleDefaults=function(t,e,r){var i,o,s,c,u,h,p,d,g=r.axIds,m=r.axHasImage,v=e._axisConstraintGroups=[],y=e._axisMatchGroups=[];for(i=0;i<g.length;i++)f(u=t[c=a(g[i])],h=e[c],{axIds:g,layoutOut:e,hasImage:m[c]});function x(t,r){for(i=0;i<t.length;i++)for(s in o=t[i])e[a(s)][r]=o}for(x(y,\"_matchGroup\"),i=0;i<v.length;i++)for(s in o=v[i])if((h=e[a(s)]).fixedrange){for(var b in o){var _=a(b);!1===(t[_]||{}).fixedrange&&n.warn(\"fixedrange was specified as false for axis \"+_+\" but was overridden because another axis in its constraint group has fixedrange true\"),e[_].fixedrange=!0}break}for(i=0;i<v.length;){for(s in o=v[i]){(h=e[a(s)])._matchGroup&&Object.keys(h._matchGroup).length===Object.keys(o).length&&(v.splice(i,1),i--);break}i++}x(v,\"_constraintGroup\");var w=[\"constrain\",\"range\",\"autorange\",\"rangemode\",\"rangebreaks\",\"categoryorder\",\"categoryarray\"],T=!1,k=!1;function M(){d=h[p],\"rangebreaks\"===p&&(k=h._hasDayOfWeekBreaks)}for(i=0;i<y.length;i++){o=y[i];for(var A=0;A<w.length;A++){var S;for(s in p=w[A],d=null,o)if(u=t[c=a(s)],h=e[c],p in h){if(!h.matches&&(S=h,p in u)){M();break}null===d&&p in u&&M()}if(\"range\"===p&&d&&(T=!0),\"autorange\"===p&&null===d&&T&&(d=!1),null===d&&p in S&&(d=S[p]),null!==d)for(s in o)(h=e[a(s)])[p]=\"range\"===p?d.slice():d,\"rangebreaks\"===p&&(h._hasDayOfWeekBreaks=k,l(h,e))}}},r.enforce=function(t){var e,r,n,o,l,u,f,h,p=t._fullLayout,d=p._axisConstraintGroups||[];for(e=0;e<d.length;e++){n=m(d[e],p);var g=Object.keys(n),y=1/0,x=0,b=1/0,_={},w={},T=!1;for(r=0;r<g.length;r++)w[o=g[r]]=l=p[a(o)],l._inputDomain?l.domain=l._inputDomain.slice():l._inputDomain=l.domain.slice(),l._inputRange||(l._inputRange=l.range.slice()),l.setScale(),_[o]=u=Math.abs(l._m)/n[o],y=Math.min(y,u),\"domain\"!==l.constrain&&l._constraintShrinkable||(b=Math.min(b,u)),delete l._constraintShrinkable,x=Math.max(x,u),\"domain\"===l.constrain&&(T=!0);if(!(y>c*x)||T)for(r=0;r<g.length;r++)if(u=_[o=g[r]],f=(l=w[o]).constrain,u!==b||\"domain\"===f)if(h=u/b,\"range\"===f)s(l,h);else{var k=l._inputDomain,M=(l.domain[1]-l.domain[0])/(k[1]-k[0]),A=(l.r2l(l.range[1])-l.r2l(l.range[0]))/(l.r2l(l._inputRange[1])-l.r2l(l._inputRange[0]));if((h/=M)*A<1){l.domain=l._input.domain=k.slice(),s(l,h);continue}if(A<1&&(l.range=l._input.range=l._inputRange.slice(),h*=A),l.autorange){var S=l.r2l(l.range[0]),E=l.r2l(l.range[1]),C=(S+E)/2,L=C,I=C,P=Math.abs(E-C),z=C-P*h*1.0001,O=C+P*h*1.0001,D=i.makePadFn(p,l,0),R=i.makePadFn(p,l,1);v(l,h);var F,B,N=Math.abs(l._m),j=i.concatExtremes(t,l),U=j.min,V=j.max;for(B=0;B<U.length;B++)(F=U[B].val-D(U[B])/N)>z&&F<L&&(L=F);for(B=0;B<V.length;B++)(F=V[B].val+R(V[B])/N)<O&&F>I&&(I=F);h/=(I-L)/(2*P),L=l.l2r(L),I=l.l2r(I),l.range=l._input.range=S<E?[L,I]:[I,L]}v(l,h)}}},r.getAxisGroup=function(t,e){for(var r=t._axisMatchGroups,n=0;n<r.length;n++){if(r[n][e])return\"g\"+n}return e},r.clean=function(t,e){if(e._inputDomain){for(var r=!1,n=e._id,i=t._fullLayout._axisConstraintGroups,a=0;a<i.length;a++)if(i[a][n]){r=!0;break}r&&\"domain\"===e.constrain||(e._input.domain=e.domain=e._inputDomain,delete e._inputDomain)}}},{\"../../constants/alignment\":745,\"../../constants/numerical\":753,\"../../lib\":778,\"./autorange\":827,\"./axis_ids\":831,\"./layout_attributes\":842,\"./scale_zoom\":846,\"./set_convert\":848}],836:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"has-passive-events\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=s.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/color\"),f=t(\"../../components/drawing\"),h=t(\"../../components/fx\"),p=t(\"./axes\"),d=t(\"../../lib/setcursor\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/dragelement/helpers\"),v=m.selectingOrDrawing,y=m.freeMode,x=t(\"../../constants/alignment\").FROM_TL,b=t(\"../../lib/clear_gl_canvases\"),_=t(\"../../plot_api/subroutines\").redrawReglTraces,w=t(\"../plots\"),T=t(\"./axis_ids\").getFromId,k=t(\"./select\").prepSelect,M=t(\"./select\").clearSelect,A=t(\"./select\").selectOnClick,S=t(\"./scale_zoom\"),E=t(\"./constants\"),C=E.MINDRAG,L=E.MINZOOM,I=!0;function P(t,e,r,n){var i=s.ensureSingle(t.draglayer,e,r,(function(e){e.classed(\"drag\",!0).style({fill:\"transparent\",\"stroke-width\":0}).attr(\"data-subplot\",t.id)}));return i.call(d,n),i.node()}function z(t,e,r,i,a,o,s){var l=P(t,\"rect\",e,r);return n.select(l).call(f.setRect,i,a,o,s),l}function O(t,e){for(var r=0;r<t.length;r++)if(!t[r].fixedrange)return e;return\"\"}function D(t,e,r,n,i){for(var a=0;a<t.length;a++){var o=t[a];if(!o.fixedrange)if(o.rangebreaks){var s=\"y\"===o._id.charAt(0),l=s?1-e:e,c=s?1-r:r;n[o._name+\".range[0]\"]=o.l2r(o.p2l(l*o._length)),n[o._name+\".range[1]\"]=o.l2r(o.p2l(c*o._length))}else{var u=o._rl[0],f=o._rl[1]-u;n[o._name+\".range[0]\"]=o.l2r(u+f*e),n[o._name+\".range[1]\"]=o.l2r(u+f*r)}}if(i&&i.length){var h=(e+(1-r))/2;D(i,h,1-h,n,[])}}function R(t,e){for(var r=0;r<t.length;r++){var n=t[r];if(!n.fixedrange)if(n.rangebreaks){var i=n._length,a=(n.p2l(0+e)-n.p2l(0)+(n.p2l(i+e)-n.p2l(i)))/2;n.range=[n.l2r(n._rl[0]-a),n.l2r(n._rl[1]-a)]}else n.range=[n.l2r(n._rl[0]-e/n._m),n.l2r(n._rl[1]-e/n._m)]}}function F(t){return 1-(t>=0?Math.min(t,.9):1/(1/Math.max(t,-.3)+3.222))}function B(t,e,r,n,i){return t.append(\"path\").attr(\"class\",\"zoombox\").style({fill:e>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"transform\",l(r,n)).attr(\"d\",i+\"Z\")}function N(t,e,r){return t.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:u.background,stroke:u.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"transform\",l(e,r)).attr(\"d\",\"M0,0Z\")}function j(t,e,r,n,i,a){t.attr(\"d\",n+\"M\"+r.l+\",\"+r.t+\"v\"+r.h+\"h\"+r.w+\"v-\"+r.h+\"h-\"+r.w+\"Z\"),U(t,e,i,a)}function U(t,e,r,n){r||(t.transition().style(\"fill\",n>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),e.transition().style(\"opacity\",1).duration(200))}function V(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}function q(t){I&&t.data&&t._context.showTips&&(s.notifier(s._(t,\"Double-click to zoom back out\"),\"long\"),I=!1)}function H(t){var e=Math.floor(Math.min(t.b-t.t,t.r-t.l,L)/2);return\"M\"+(t.l-3.5)+\",\"+(t.t-.5+e)+\"h3v\"+-e+\"h\"+e+\"v-3h-\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.t-.5+e)+\"h-3v\"+-e+\"h\"+-e+\"v-3h\"+(e+3)+\"ZM\"+(t.r+3.5)+\",\"+(t.b+.5-e)+\"h-3v\"+e+\"h\"+-e+\"v3h\"+(e+3)+\"ZM\"+(t.l-3.5)+\",\"+(t.b+.5-e)+\"h3v\"+e+\"h\"+e+\"v3h-\"+(e+3)+\"Z\"}function G(t,e,r,n,i){for(var a,o,l,c,u=!1,f={},h={},p=(i||{}).xaHash,d=(i||{}).yaHash,g=0;g<e.length;g++){var m=e[g];for(a in r)if(m[a]){for(l in m)i&&(p[l]||d[l])||(\"x\"===l.charAt(0)?r:n)[l]||(f[l]=a);for(o in n)i&&(p[o]||d[o])||!m[o]||(u=!0)}for(o in n)if(m[o])for(c in m)i&&(p[c]||d[c])||(\"x\"===c.charAt(0)?r:n)[c]||(h[c]=o)}u&&(s.extendFlat(f,h),h={});var v={},y=[];for(l in f){var x=T(t,l);y.push(x),v[x._id]=x}var b={},_=[];for(c in h){var w=T(t,c);_.push(w),b[w._id]=w}return{xaHash:v,yaHash:b,xaxes:y,yaxes:_,xLinks:f,yLinks:h,isSubplotConstrained:u}}function Y(t,e){if(a){var r=void 0!==t.onwheel?\"wheel\":\"mousewheel\";t._onwheel&&t.removeEventListener(r,t._onwheel),t._onwheel=e,t.addEventListener(r,e,{passive:!1})}else void 0!==t.onwheel?t.onwheel=e:void 0!==t.onmousewheel?t.onmousewheel=e:t.isAddedWheelEvent||(t.isAddedWheelEvent=!0,t.addEventListener(\"wheel\",e,{passive:!1}))}function W(t){var e=[];for(var r in t)e.push(t[r]);return e}e.exports={makeDragBox:function(t,e,r,a,l,u,d,m){var I,P,U,X,Z,J,K,Q,$,tt,et,rt,nt,it,at,ot,st,lt,ct,ut,ft,ht,pt,dt=t._fullLayout._zoomlayer,gt=d+m===\"nsew\",mt=1===(d+m).length;function vt(){if(I=e.xaxis,P=e.yaxis,$=I._length,tt=P._length,K=I._offset,Q=P._offset,(U={})[I._id]=I,(X={})[P._id]=P,d&&m)for(var r=e.overlays,n=0;n<r.length;n++){var i=r[n].xaxis;U[i._id]=i;var a=r[n].yaxis;X[a._id]=a}Z=W(U),J=W(X),nt=O(Z,m),it=O(J,d),at=!it&&!nt,rt=G(t,t._fullLayout._axisMatchGroups,U,X);var o=(et=G(t,t._fullLayout._axisConstraintGroups,U,X,rt)).isSubplotConstrained||rt.isSubplotConstrained;ot=m||o,st=d||o;var s=t._fullLayout;lt=s._has(\"scattergl\"),ct=s._has(\"splom\"),ut=s._has(\"svg\")}vt();var yt=function(t,e,r){if(!t)return\"pointer\";if(\"nsew\"===t)return r?\"\":\"pan\"===e?\"move\":\"crosshair\";return t.toLowerCase()+\"-resize\"}(it+nt,t._fullLayout.dragmode,gt),xt=z(e,d+m+\"drag\",yt,r,a,l,u);if(at&&!gt)return xt.onmousedown=null,xt.style.pointerEvents=\"none\",xt;var bt,_t,wt,Tt,kt,Mt,At,St,Et,Ct,Lt={element:xt,gd:t,plotinfo:e};function It(){Lt.plotinfo.selection=!1,M(t)}function Pt(t,r){var i=Lt.gd;if(i._fullLayout._activeShapeIndex>=0)i._fullLayout._deactivateShape(i);else{var a=i._fullLayout.clickmode;if(V(i),2!==t||mt||qt(),gt)a.indexOf(\"select\")>-1&&A(r,i,Z,J,e.id,Lt),a.indexOf(\"event\")>-1&&h.click(i,r,e.id);else if(1===t&&mt){var s=d?P:I,l=\"s\"===d||\"w\"===m?0:1,u=s._name+\".range[\"+l+\"]\",f=function(t,e){var r,i=t.range[e],a=Math.abs(i-t.range[1-e]);return\"date\"===t.type?i:\"log\"===t.type?(r=Math.ceil(Math.max(0,-Math.log(a)/Math.LN10))+3,n.format(\".\"+r+\"g\")(Math.pow(10,i))):(r=Math.floor(Math.log(Math.abs(i))/Math.LN10)-Math.floor(Math.log(a)/Math.LN10)+4,n.format(\".\"+String(r)+\"g\")(i))}(s,l),p=\"left\",g=\"middle\";if(s.fixedrange)return;d?(g=\"n\"===d?\"top\":\"bottom\",\"right\"===s.side&&(p=\"right\")):\"e\"===m&&(p=\"right\"),i._context.showAxisRangeEntryBoxes&&n.select(xt).call(c.makeEditable,{gd:i,immediate:!0,background:i._fullLayout.paper_bgcolor,text:String(f),fill:s.tickfont?s.tickfont.color:\"#444\",horizontalAlign:p,verticalAlign:g}).on(\"edit\",(function(t){var e=s.d2r(t);void 0!==e&&o.call(\"_guiRelayout\",i,u,e)}))}}}function zt(e,r){if(t._transitioningWithDuration)return!1;var n=Math.max(0,Math.min($,ht*e+bt)),i=Math.max(0,Math.min(tt,pt*r+_t)),a=Math.abs(n-bt),o=Math.abs(i-_t);function s(){At=\"\",wt.r=wt.l,wt.t=wt.b,Et.attr(\"d\",\"M0,0Z\")}if(wt.l=Math.min(bt,n),wt.r=Math.max(bt,n),wt.t=Math.min(_t,i),wt.b=Math.max(_t,i),et.isSubplotConstrained)a>L||o>L?(At=\"xy\",a/$>o/tt?(o=a*tt/$,_t>i?wt.t=_t-o:wt.b=_t+o):(a=o*$/tt,bt>n?wt.l=bt-a:wt.r=bt+a),Et.attr(\"d\",H(wt))):s();else if(rt.isSubplotConstrained)if(a>L||o>L){At=\"xy\";var l=Math.min(wt.l/$,(tt-wt.b)/tt),c=Math.max(wt.r/$,(tt-wt.t)/tt);wt.l=l*$,wt.r=c*$,wt.b=(1-l)*tt,wt.t=(1-c)*tt,Et.attr(\"d\",H(wt))}else s();else!it||o<Math.min(Math.max(.6*a,C),L)?a<C||!nt?s():(wt.t=0,wt.b=tt,At=\"x\",Et.attr(\"d\",function(t,e){return\"M\"+(t.l-.5)+\",\"+(e-L-.5)+\"h-3v\"+(2*L+1)+\"h3ZM\"+(t.r+.5)+\",\"+(e-L-.5)+\"h3v\"+(2*L+1)+\"h-3Z\"}(wt,_t))):!nt||a<Math.min(.6*o,L)?(wt.l=0,wt.r=$,At=\"y\",Et.attr(\"d\",function(t,e){return\"M\"+(e-L-.5)+\",\"+(t.t-.5)+\"v-3h\"+(2*L+1)+\"v3ZM\"+(e-L-.5)+\",\"+(t.b+.5)+\"v3h\"+(2*L+1)+\"v-3Z\"}(wt,bt))):(At=\"xy\",Et.attr(\"d\",H(wt)));wt.w=wt.r-wt.l,wt.h=wt.b-wt.t,At&&(Ct=!0),t._dragged=Ct,j(St,Et,wt,kt,Mt,Tt),Ot(),t.emit(\"plotly_relayouting\",ft),Mt=!0}function Ot(){ft={},\"xy\"!==At&&\"x\"!==At||(D(Z,wt.l/$,wt.r/$,ft,et.xaxes),Ut(\"x\",ft)),\"xy\"!==At&&\"y\"!==At||(D(J,(tt-wt.b)/tt,(tt-wt.t)/tt,ft,et.yaxes),Ut(\"y\",ft))}function Dt(){Ot(),V(t),Ht(),q(t)}Lt.prepFn=function(e,r,n){var a=Lt.dragmode,o=t._fullLayout.dragmode;o!==a&&(Lt.dragmode=o),vt(),ht=t._fullLayout._invScaleX,pt=t._fullLayout._invScaleY,at||(gt?e.shiftKey?\"pan\"===o?o=\"zoom\":v(o)||(o=\"pan\"):e.ctrlKey&&(o=\"pan\"):o=\"pan\"),y(o)?Lt.minDrag=1:Lt.minDrag=void 0,v(o)?(Lt.xaxes=Z,Lt.yaxes=J,k(e,r,n,Lt,o)):(Lt.clickFn=Pt,v(a)&&It(),at||(\"zoom\"===o?(Lt.moveFn=zt,Lt.doneFn=Dt,Lt.minDrag=1,function(e,r,n){var a=xt.getBoundingClientRect();bt=r-a.left,_t=n-a.top,t._fullLayout._calcInverseTransform(t);var o=s.apply3DTransform(t._fullLayout._invTransform)(bt,_t);bt=o[0],_t=o[1],wt={l:bt,r:bt,w:0,t:_t,b:_t,h:0},Tt=t._hmpixcount?t._hmlumcount/t._hmpixcount:i(t._fullLayout.plot_bgcolor).getLuminance(),Mt=!1,At=\"xy\",Ct=!1,St=B(dt,Tt,K,Q,kt=\"M0,0H\"+$+\"V\"+tt+\"H0V0\"),Et=N(dt,K,Q)}(0,r,n)):\"pan\"===o&&(Lt.moveFn=jt,Lt.doneFn=Ht))),t._fullLayout._redrag=function(){var e=t._dragdata;if(e&&e.element===xt){var r=t._fullLayout.dragmode;v(r)||(vt(),Gt([0,0,$,tt]),Lt.moveFn(e.dx,e.dy))}}},g.init(Lt);var Rt=[0,0,$,tt],Ft=null,Bt=E.REDRAWDELAY,Nt=e.mainplot?t._fullLayout._plots[e.mainplot]:e;function jt(e,r){if(e*=ht,r*=pt,!t._transitioningWithDuration){if(t._fullLayout._replotting=!0,\"ew\"===nt||\"ns\"===it){var n=nt?-e:0,i=it?-r:0;if(rt.isSubplotConstrained){if(nt&&it){var a=(e/$-r/tt)/2;n=-(e=a*$),i=-(r=-a*tt)}it?n=-i*$/tt:i=-n*tt/$}return nt&&(R(Z,e),Ut(\"x\")),it&&(R(J,r),Ut(\"y\")),Gt([n,i,$,tt]),Vt(),void t.emit(\"plotly_relayouting\",ft)}var o,s,l=\"w\"===nt==(\"n\"===it)?1:-1;if(nt&&it&&(et.isSubplotConstrained||rt.isSubplotConstrained)){var c=(e/$+l*r/tt)/2;e=c*$,r=l*c*tt}if(\"w\"===nt?e=p(Z,0,e):\"e\"===nt?e=p(Z,1,-e):nt||(e=0),\"n\"===it?r=p(J,1,r):\"s\"===it?r=p(J,0,-r):it||(r=0),o=\"w\"===nt?e:0,s=\"n\"===it?r:0,et.isSubplotConstrained&&!rt.isSubplotConstrained||rt.isSubplotConstrained&&nt&&it&&l>0){var u;if(rt.isSubplotConstrained||!nt&&1===it.length){for(u=0;u<Z.length;u++)Z[u].range=Z[u]._r.slice(),S(Z[u],1-r/tt);o=(e=r*$/tt)/2}if(rt.isSubplotConstrained||!it&&1===nt.length){for(u=0;u<J.length;u++)J[u].range=J[u]._r.slice(),S(J[u],1-e/$);s=(r=e*tt/$)/2}}rt.isSubplotConstrained&&it||Ut(\"x\"),rt.isSubplotConstrained&&nt||Ut(\"y\");var f=$-e,h=tt-r;!rt.isSubplotConstrained||nt&&it||(nt?(s=o?0:e*tt/$,h=f*tt/$):(o=s?0:r*$/tt,f=h*$/tt)),Gt([o,s,f,h]),Vt(),t.emit(\"plotly_relayouting\",ft)}function p(t,e,r){for(var n,i,a=1-e,o=0;o<t.length;o++){var s=t[o];if(!s.fixedrange){n=s,i=s._rl[a]+(s._rl[e]-s._rl[a])/F(r/s._length);var l=s.l2r(i);!1!==l&&void 0!==l&&(s.range[e]=l)}}return n._length*(n._rl[e]-i)/(n._rl[e]-n._rl[a])}}function Ut(t,e){for(var r=rt.isSubplotConstrained?{x:J,y:Z}[t]:rt[t+\"axes\"],n=rt.isSubplotConstrained?{x:Z,y:J}[t]:[],i=0;i<r.length;i++){var a=r[i],o=a._id,s=rt.xLinks[o]||rt.yLinks[o],l=n[0]||U[s]||X[s];l&&(e?(e[a._name+\".range[0]\"]=e[l._name+\".range[0]\"],e[a._name+\".range[1]\"]=e[l._name+\".range[1]\"]):a.range=l.range.slice())}}function Vt(){var e,r=[];function n(t){for(e=0;e<t.length;e++)t[e].fixedrange||r.push(t[e]._id)}for(ot&&(n(Z),n(et.xaxes),n(rt.xaxes)),st&&(n(J),n(et.yaxes),n(rt.yaxes)),ft={},e=0;e<r.length;e++){var i=r[e],a=T(t,i);p.drawOne(t,a,{skipTitle:!0}),ft[a._name+\".range[0]\"]=a.range[0],ft[a._name+\".range[1]\"]=a.range[1]}p.redrawComponents(t,r)}function qt(){if(!t._transitioningWithDuration){var e=t._context.doubleClick,r=[];nt&&(r=r.concat(Z)),it&&(r=r.concat(J)),rt.xaxes&&(r=r.concat(rt.xaxes)),rt.yaxes&&(r=r.concat(rt.yaxes));var n,i,a,s={};if(\"reset+autosize\"===e)for(e=\"autosize\",i=0;i<r.length;i++)if((n=r[i])._rangeInitial&&(n.range[0]!==n._rangeInitial[0]||n.range[1]!==n._rangeInitial[1])||!n._rangeInitial&&!n.autorange){e=\"reset\";break}if(\"autosize\"===e)for(i=0;i<r.length;i++)(n=r[i]).fixedrange||(s[n._name+\".autorange\"]=!0);else if(\"reset\"===e)for((nt||et.isSubplotConstrained)&&(r=r.concat(et.xaxes)),it&&!et.isSubplotConstrained&&(r=r.concat(et.yaxes)),et.isSubplotConstrained&&(nt?it||(r=r.concat(J)):r=r.concat(Z)),i=0;i<r.length;i++)(n=r[i]).fixedrange||(n._rangeInitial?(a=n._rangeInitial,s[n._name+\".range[0]\"]=a[0],s[n._name+\".range[1]\"]=a[1]):s[n._name+\".autorange\"]=!0);t.emit(\"plotly_doubleclick\",null),o.call(\"_guiRelayout\",t,s)}}function Ht(){Gt([0,0,$,tt]),s.syncOrAsync([w.previousPromises,function(){t._fullLayout._replotting=!1,o.call(\"_guiRelayout\",t,ft)}],t)}function Gt(e){var r,n,i,a,l=t._fullLayout,c=l._plots,u=l._subplots.cartesian;if(ct&&o.subplotsRegistry.splom.drag(t),lt)for(r=0;r<u.length;r++)if(i=(n=c[u[r]]).xaxis,a=n.yaxis,n._scene){var h=s.simpleMap(i.range,i.r2l),p=s.simpleMap(a.range,a.r2l);n._scene.update({range:[h[0],p[0],h[1],p[1]]})}if((ct||lt)&&(b(t),_(t)),ut){var g=e[2]/I._length,v=e[3]/P._length;for(r=0;r<u.length;r++){i=(n=c[u[r]]).xaxis,a=n.yaxis;var y,x,w,T,k=(ot||rt.isSubplotConstrained)&&!i.fixedrange&&U[i._id],M=(st||rt.isSubplotConstrained)&&!a.fixedrange&&X[a._id];if(k?(y=g,w=m||rt.isSubplotConstrained?e[0]:Xt(i,y)):rt.xaHash[i._id]?(y=g,w=e[0]*i._length/I._length):rt.yaHash[i._id]?(y=v,w=\"ns\"===it?-e[1]*i._length/P._length:Xt(i,y,{n:\"top\",s:\"bottom\"}[it])):w=Wt(i,y=Yt(i,g,v)),M?(x=v,T=d||rt.isSubplotConstrained?e[1]:Xt(a,x)):rt.yaHash[a._id]?(x=v,T=e[1]*a._length/P._length):rt.xaHash[a._id]?(x=g,T=\"ew\"===nt?-e[0]*a._length/I._length:Xt(a,x,{e:\"right\",w:\"left\"}[nt])):T=Wt(a,x=Yt(a,g,v)),y||x){y||(y=1),x||(x=1);var A=i._offset-w/y,S=a._offset-T/x;n.clipRect.call(f.setTranslate,w,T).call(f.setScale,y,x),n.plot.call(f.setTranslate,A,S).call(f.setScale,1/y,1/x),y===n.xScaleFactor&&x===n.yScaleFactor||(f.setPointGroupScale(n.zoomScalePts,y,x),f.setTextPointsScale(n.zoomScaleTxt,y,x)),f.hideOutsideRangePoints(n.clipOnAxisFalseTraces,n),n.xScaleFactor=y,n.yScaleFactor=x}}}}function Yt(t,e,r){return t.fixedrange?0:ot&&et.xaHash[t._id]?e:st&&(et.isSubplotConstrained?et.xaHash:et.yaHash)[t._id]?r:0}function Wt(t,e){return e?(t.range=t._r.slice(),S(t,e),Xt(t,e)):0}function Xt(t,e,r){return t._length*(1-e)*x[r||t.constraintoward||\"middle\"]}return d.length*m.length!=1&&Y(xt,(function(e){if(t._context._scrollZoom.cartesian||t._fullLayout._enablescrollzoom){if(It(),t._transitioningWithDuration)return e.preventDefault(),void e.stopPropagation();vt(),clearTimeout(Ft);var r=-e.deltaY;if(isFinite(r)||(r=e.wheelDelta/10),isFinite(r)){var n,i=Math.exp(-Math.min(Math.max(r,-20),20)/200),a=Nt.draglayer.select(\".nsewdrag\").node().getBoundingClientRect(),o=(e.clientX-a.left)/a.width,l=(a.bottom-e.clientY)/a.height;if(ot){for(m||(o=.5),n=0;n<Z.length;n++)c(Z[n],o,i);Ut(\"x\"),Rt[2]*=i,Rt[0]+=Rt[2]*o*(1/i-1)}if(st){for(d||(l=.5),n=0;n<J.length;n++)c(J[n],l,i);Ut(\"y\"),Rt[3]*=i,Rt[1]+=Rt[3]*(1-l)*(1/i-1)}Gt(Rt),Vt(),t.emit(\"plotly_relayouting\",ft),Ft=setTimeout((function(){Rt=[0,0,$,tt],Ht()}),Bt),e.preventDefault()}else s.log(\"Did not find wheel motion attributes: \",e)}function c(t,e,r){if(!t.fixedrange){var n=s.simpleMap(t.range,t.r2l),i=n[0]+(n[1]-n[0])*e;t.range=n.map((function(e){return t.l2r(i+(e-i)*r)}))}}})),xt},makeDragger:P,makeRectDragger:z,makeZoombox:B,makeCorners:N,updateZoombox:j,xyCorners:H,transitionZoombox:U,removeZoombox:V,showDoubleClickNotifier:q,attachWheelEventHandler:Y}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../lib/svg_text_utils\":803,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"../plots\":891,\"./axes\":828,\"./axis_ids\":831,\"./constants\":834,\"./scale_zoom\":846,\"./select\":847,d3:169,\"has-passive-events\":441,tinycolor2:576}],837:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/fx\"),a=t(\"../../components/dragelement\"),o=t(\"../../lib/setcursor\"),s=t(\"./dragbox\").makeDragBox,l=t(\"./constants\").DRAGGERSIZE;r.initInteractions=function(t){var e=t._fullLayout;if(t._context.staticPlot)n.select(t).selectAll(\".drag\").remove();else if(e._has(\"cartesian\")||e._has(\"splom\")){Object.keys(e._plots||{}).sort((function(t,r){if((e._plots[t].mainplot&&!0)===(e._plots[r].mainplot&&!0)){var n=t.split(\"y\"),i=r.split(\"y\");return n[0]===i[0]?Number(n[1]||1)-Number(i[1]||1):Number(n[0]||1)-Number(i[0]||1)}return e._plots[t].mainplot?1:-1})).forEach((function(r){var n=e._plots[r],o=n.xaxis,c=n.yaxis;if(!n.mainplot){var u=s(t,n,o._offset,c._offset,o._length,c._length,\"ns\",\"ew\");u.onmousemove=function(e){t._fullLayout._rehover=function(){t._fullLayout._hoversubplot===r&&t._fullLayout._plots[r]&&i.hover(t,e,r)},i.hover(t,e,r),t._fullLayout._lasthover=u,t._fullLayout._hoversubplot=r},u.onmouseout=function(e){t._dragging||(t._fullLayout._hoversubplot=null,a.unhover(t,e))},t._context.showAxisDragHandles&&(s(t,n,o._offset-l,c._offset-l,l,l,\"n\",\"w\"),s(t,n,o._offset+o._length,c._offset-l,l,l,\"n\",\"e\"),s(t,n,o._offset-l,c._offset+c._length,l,l,\"s\",\"w\"),s(t,n,o._offset+o._length,c._offset+c._length,l,l,\"s\",\"e\"))}if(t._context.showAxisDragHandles){if(r===o._mainSubplot){var f=o._mainLinePosition;\"top\"===o.side&&(f-=l),s(t,n,o._offset+.1*o._length,f,.8*o._length,l,\"\",\"ew\"),s(t,n,o._offset,f,.1*o._length,l,\"\",\"w\"),s(t,n,o._offset+.9*o._length,f,.1*o._length,l,\"\",\"e\")}if(r===c._mainSubplot){var h=c._mainLinePosition;\"right\"!==c.side&&(h-=l),s(t,n,h,c._offset+.1*c._length,l,.8*c._length,\"ns\",\"\"),s(t,n,h,c._offset+.9*c._length,l,.1*c._length,\"s\",\"\"),s(t,n,h,c._offset,l,.1*c._length,\"n\",\"\")}}}));var o=e._hoverlayer.node();o.onmousemove=function(r){r.target=t._fullLayout._lasthover,i.hover(t,r,e._hoversubplot)},o.onclick=function(e){e.target=t._fullLayout._lasthover,i.click(t,e)},o.onmousedown=function(e){t._fullLayout._lasthover.onmousedown(e)},r.updateFx(t)}},r.updateFx=function(t){var e=t._fullLayout,r=\"pan\"===e.dragmode?\"move\":\"crosshair\";o(e._draggers,r)}},{\"../../components/dragelement\":662,\"../../components/fx\":683,\"../../lib/setcursor\":799,\"./constants\":834,\"./dragbox\":836,d3:169}],838:[function(t,e,r){\"use strict\";e.exports={clearOutlineControllers:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".outline-controllers\").remove()},clearSelect:function(t){var e=t._fullLayout._zoomlayer;e&&e.selectAll(\".select-outline\").remove(),t._fullLayout._drawing=!1}}},{}],839:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").strTranslate;function i(t,e){switch(t.type){case\"log\":return t.p2d(e);case\"date\":return t.p2r(e,0,t.calendar);default:return t.p2r(e)}}e.exports={p2r:i,r2p:function(t,e){switch(t.type){case\"log\":return t.d2p(e);case\"date\":return t.r2p(e,0,t.calendar);default:return t.r2p(e)}},axValue:function(t){var e=\"y\"===t._id.charAt(0)?1:0;return function(r){return i(t,r[e])}},getTransform:function(t){return n(t.xaxis._offset,t.yaxis._offset)}}},{\"../../lib\":778}],840:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./axis_ids\");e.exports=function(t){return function(e,r){var o=e[t];if(Array.isArray(o))for(var s=n.subplotsRegistry.cartesian,l=s.idRegex,c=r._subplots,u=c.xaxis,f=c.yaxis,h=c.cartesian,p=r._has(\"cartesian\")||r._has(\"gl2d\"),d=0;d<o.length;d++){var g=o[d];if(i.isPlainObject(g)){var m=a.cleanId(g.xref,\"x\",!1),v=a.cleanId(g.yref,\"y\",!1),y=l.x.test(m),x=l.y.test(v);if(y||x){p||i.pushUnique(r._basePlotModules,s);var b=!1;y&&-1===u.indexOf(m)&&(u.push(m),b=!0),x&&-1===f.indexOf(v)&&(f.push(v),b=!0),b&&y&&x&&h.push(m+v)}}}}}},{\"../../lib\":778,\"../../registry\":911,\"./axis_ids\":831}],841:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../plots\"),s=t(\"../../components/drawing\"),l=t(\"../get_data\").getModuleCalcData,c=t(\"./axis_ids\"),u=t(\"./constants\"),f=t(\"../../constants/xmlns_namespaces\"),h=a.ensureSingle;function p(t,e,r){return a.ensureSingle(t,e,r,(function(t){t.datum(r)}))}function d(t,e,r,a,o){for(var c,f,h,p=u.traceLayerClasses,d=t._fullLayout,g=d._modules,m=[],v=[],y=0;y<g.length;y++){var x=(c=g[y]).name,b=i.modules[x].categories;if(b.svg){var _=c.layerName||x+\"layer\",w=c.plot;h=(f=l(r,w))[0],r=f[1],h.length&&m.push({i:p.indexOf(_),className:_,plotMethod:w,cdModule:h}),b.zoomScale&&v.push(\".\"+_)}}m.sort((function(t,e){return t.i-e.i}));var T=e.plot.selectAll(\"g.mlayer\").data(m,(function(t){return t.className}));if(T.enter().append(\"g\").attr(\"class\",(function(t){return t.className})).classed(\"mlayer\",!0).classed(\"rangeplot\",e.isRangePlot),T.exit().remove(),T.order(),T.each((function(r){var i=n.select(this),l=r.className;r.plotMethod(t,e,r.cdModule,i,a,o),-1===u.clipOnAxisFalseQuery.indexOf(\".\"+l)&&s.setClipUrl(i,e.layerClipId,t)})),d._has(\"scattergl\")&&(c=i.getModule(\"scattergl\"),h=l(r,c)[0],c.plot(t,e,h)),!t._context.staticPlot&&(e._hasClipOnAxisFalse&&(e.clipOnAxisFalseTraces=e.plot.selectAll(u.clipOnAxisFalseQuery.join(\",\")).selectAll(\".trace\")),v.length)){var k=e.plot.selectAll(v.join(\",\")).selectAll(\".trace\");e.zoomScalePts=k.selectAll(\"path.point\"),e.zoomScaleTxt=k.selectAll(\".textpoint\")}}function g(t,e){var r=e.plotgroup,n=e.id,i=u.layerValue2layerClass[e.xaxis.layer],a=u.layerValue2layerClass[e.yaxis.layer],o=t._fullLayout._hasOnlyLargeSploms;if(e.mainplot){var s=e.mainplotinfo,l=s.plotgroup,f=n+\"-x\",d=n+\"-y\";e.gridlayer=s.gridlayer,e.zerolinelayer=s.zerolinelayer,h(s.overlinesBelow,\"path\",f),h(s.overlinesBelow,\"path\",d),h(s.overaxesBelow,\"g\",f),h(s.overaxesBelow,\"g\",d),e.plot=h(s.overplot,\"g\",n),h(s.overlinesAbove,\"path\",f),h(s.overlinesAbove,\"path\",d),h(s.overaxesAbove,\"g\",f),h(s.overaxesAbove,\"g\",d),e.xlines=l.select(\".overlines-\"+i).select(\".\"+f),e.ylines=l.select(\".overlines-\"+a).select(\".\"+d),e.xaxislayer=l.select(\".overaxes-\"+i).select(\".\"+f),e.yaxislayer=l.select(\".overaxes-\"+a).select(\".\"+d)}else if(o)e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.xaxislayer=h(r,\"g\",\"xaxislayer-above\"),e.yaxislayer=h(r,\"g\",\"yaxislayer-above\");else{var g=h(r,\"g\",\"layer-subplot\");e.shapelayer=h(g,\"g\",\"shapelayer\"),e.imagelayer=h(g,\"g\",\"imagelayer\"),e.gridlayer=h(r,\"g\",\"gridlayer\"),e.zerolinelayer=h(r,\"g\",\"zerolinelayer\"),h(r,\"path\",\"xlines-below\"),h(r,\"path\",\"ylines-below\"),e.overlinesBelow=h(r,\"g\",\"overlines-below\"),h(r,\"g\",\"xaxislayer-below\"),h(r,\"g\",\"yaxislayer-below\"),e.overaxesBelow=h(r,\"g\",\"overaxes-below\"),e.plot=h(r,\"g\",\"plot\"),e.overplot=h(r,\"g\",\"overplot\"),e.xlines=h(r,\"path\",\"xlines-above\"),e.ylines=h(r,\"path\",\"ylines-above\"),e.overlinesAbove=h(r,\"g\",\"overlines-above\"),h(r,\"g\",\"xaxislayer-above\"),h(r,\"g\",\"yaxislayer-above\"),e.overaxesAbove=h(r,\"g\",\"overaxes-above\"),e.xlines=r.select(\".xlines-\"+i),e.ylines=r.select(\".ylines-\"+a),e.xaxislayer=r.select(\".xaxislayer-\"+i),e.yaxislayer=r.select(\".yaxislayer-\"+a)}o||(p(e.gridlayer,\"g\",e.xaxis._id),p(e.gridlayer,\"g\",e.yaxis._id),e.gridlayer.selectAll(\"g\").map((function(t){return t[0]})).sort(c.idSort)),e.xlines.style(\"fill\",\"none\").classed(\"crisp\",!0),e.ylines.style(\"fill\",\"none\").classed(\"crisp\",!0)}function m(t,e){if(t){var r={};for(var i in t.each((function(t){var i=t[0];n.select(this).remove(),v(i,e),r[i]=!0})),e._plots)for(var a=e._plots[i].overlays||[],o=0;o<a.length;o++){var s=a[o];r[s.id]&&s.plot.selectAll(\".trace\").remove()}}}function v(t,e){e._draggers.selectAll(\"g.\"+t).remove(),e._defs.select(\"#clip\"+e._uid+t+\"plot\").remove()}r.name=\"cartesian\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=u.idRegex,r.attrRegex=u.attrRegex,r.attributes=t(\"./attributes\"),r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.transitionAxes=t(\"./transition_axes\"),r.finalizeSubplots=function(t,e){var r,n,i,o=e._subplots,s=o.xaxis,l=o.yaxis,f=o.cartesian,h=f.concat(o.gl2d||[]),p={},d={};for(r=0;r<h.length;r++){var g=h[r].split(\"y\");p[g[0]]=1,d[\"y\"+g[1]]=1}for(r=0;r<s.length;r++)p[n=s[r]]||(i=(t[c.id2name(n)]||{}).anchor,u.idRegex.y.test(i)||(i=\"y\"),f.push(n+i),h.push(n+i),d[i]||(d[i]=1,a.pushUnique(l,i)));for(r=0;r<l.length;r++)d[i=l[r]]||(n=(t[c.id2name(i)]||{}).anchor,u.idRegex.x.test(n)||(n=\"x\"),f.push(n+i),h.push(n+i),p[n]||(p[n]=1,a.pushUnique(s,n)));if(!h.length){for(var m in n=\"\",i=\"\",t){if(u.attrRegex.test(m))\"x\"===m.charAt(0)?(!n||+m.substr(5)<+n.substr(5))&&(n=m):(!i||+m.substr(5)<+i.substr(5))&&(i=m)}n=n?c.name2id(n):\"x\",i=i?c.name2id(i):\"y\",s.push(n),l.push(i),f.push(n+i)}},r.plot=function(t,e,r,n){var i,a=t._fullLayout,o=a._subplots.cartesian,s=t.calcdata;if(!Array.isArray(e))for(e=[],i=0;i<s.length;i++)e.push(i);for(i=0;i<o.length;i++){for(var l,c=o[i],u=a._plots[c],f=[],h=0;h<s.length;h++){var p=s[h],g=p[0].trace;g.xaxis+g.yaxis===c&&((-1!==e.indexOf(g.index)||g.carpet)&&(l&&l[0].trace.xaxis+l[0].trace.yaxis===c&&-1!==[\"tonextx\",\"tonexty\",\"tonext\"].indexOf(g.fill)&&-1===f.indexOf(l)&&f.push(l),f.push(p)),l=p)}d(t,u,f,r,n)}},r.clean=function(t,e,r,n){var i,a,o,s=n._plots||{},l=e._plots||{},u=n._subplots||{};if(n._hasOnlyLargeSploms&&!e._hasOnlyLargeSploms)for(o in s)(i=s[o]).plotgroup&&i.plotgroup.remove();var f=n._has&&n._has(\"gl\"),h=e._has&&e._has(\"gl\");if(f&&!h)for(o in s)(i=s[o])._scene&&i._scene.destroy();if(u.xaxis&&u.yaxis){var p=c.listIds({_fullLayout:n});for(a=0;a<p.length;a++){var d=p[a];e[c.id2name(d)]||n._infolayer.selectAll(\".g-\"+d+\"title\").remove()}}var g=n._has&&n._has(\"cartesian\"),y=e._has&&e._has(\"cartesian\");if(g&&!y)m(n._cartesianlayer.selectAll(\".subplot\"),n),n._defs.selectAll(\".axesclip\").remove(),delete n._axisConstraintGroups,delete n._axisMatchGroups;else if(u.cartesian)for(a=0;a<u.cartesian.length;a++){var x=u.cartesian[a];if(!l[x]){var b=\".\"+x+\",.\"+x+\"-x,.\"+x+\"-y\";n._cartesianlayer.selectAll(b).remove(),v(x,n)}}},r.drawFramework=function(t){var e=t._fullLayout,r=function(t){var e,r,n,i,a,o,s=t._fullLayout,l=s._subplots.cartesian,c=l.length,u=[],f=[];for(e=0;e<c;e++){n=l[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var h=a._mainAxis,p=o._mainAxis,d=h._id+p._id,g=s._plots[d];i.overlays=[],d!==n&&g?(i.mainplot=d,i.mainplotinfo=g,f.push(n)):(i.mainplot=void 0,i.mainplotinfo=void 0,u.push(n))}for(e=0;e<f.length;e++)n=f[e],(i=s._plots[n]).mainplotinfo.overlays.push(i);var m=u.concat(f),v=new Array(c);for(e=0;e<c;e++){n=m[e],i=s._plots[n],a=i.xaxis,o=i.yaxis;var y=[n,a.layer,o.layer,a.overlaying||\"\",o.overlaying||\"\"];for(r=0;r<i.overlays.length;r++)y.push(i.overlays[r].id);v[e]=y}return v}(t),i=e._cartesianlayer.selectAll(\".subplot\").data(r,String);i.enter().append(\"g\").attr(\"class\",(function(t){return\"subplot \"+t[0]})),i.order(),i.exit().call(m,e),i.each((function(r){var i=r[0],a=e._plots[i];a.plotgroup=n.select(this),g(t,a),a.draglayer=h(e._draggers,\"g\",i)}))},r.rangePlot=function(t,e,r){g(t,e),d(t,e,r),o.style(t)},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:f.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})}))},r.updateFx=t(\"./graph_interact\").updateFx},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,\"../get_data\":865,\"../plots\":891,\"./attributes\":826,\"./axis_ids\":831,\"./constants\":834,\"./graph_interact\":837,\"./layout_attributes\":842,\"./layout_defaults\":843,\"./transition_axes\":852,d3:169}],842:[function(t,e,r){\"use strict\";var n=t(\"../font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/plot_template\").templatedArray,l=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").DATE_FORMAT_LINK,t(\"../../constants/numerical\").ONEDAY),c=t(\"./constants\"),u=c.HOUR_PATTERN,f=c.WEEKDAY_PATTERN;e.exports={visible:{valType:\"boolean\",editType:\"plot\"},color:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},title:{text:{valType:\"string\",editType:\"ticks\"},font:n({editType:\"ticks\"}),standoff:{valType:\"number\",min:0,editType:\"ticks\"},editType:\"ticks\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"log\",\"date\",\"category\",\"multicategory\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"axrange\",impliedEdits:{\"range[0]\":void 0,\"range[1]\":void 0}},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0},{valType:\"any\",editType:\"axrange\",impliedEdits:{\"^autorange\":!1},anim:!0}],editType:\"axrange\",impliedEdits:{autorange:!1},anim:!0},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},scaleanchor:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},scaleratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},constrain:{valType:\"enumerated\",values:[\"range\",\"domain\"],editType:\"plot\"},constraintoward:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\",\"top\",\"middle\",\"bottom\"],editType:\"plot\"},matches:{valType:\"enumerated\",values:[c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"calc\"},rangebreaks:s(\"rangebreak\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},bounds:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},pattern:{valType:\"enumerated\",values:[f,u,\"\"],editType:\"calc\"},values:{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"any\",editType:\"calc\"}},dvalue:{valType:\"number\",editType:\"calc\",min:0,dflt:l},editType:\"calc\"}),tickmode:{valType:\"enumerated\",values:[\"auto\",\"linear\",\"array\"],editType:\"ticks\",impliedEdits:{tick0:void 0,dtick:void 0}},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"ticks\"},tick0:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},dtick:{valType:\"any\",editType:\"ticks\",impliedEdits:{tickmode:\"linear\"}},tickvals:{valType:\"data_array\",editType:\"ticks\"},ticktext:{valType:\"data_array\",editType:\"ticks\"},ticks:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"\"],editType:\"ticks\"},tickson:{valType:\"enumerated\",values:[\"labels\",\"boundaries\"],dflt:\"labels\",editType:\"ticks\"},ticklabelmode:{valType:\"enumerated\",values:[\"instant\",\"period\"],dflt:\"instant\",editType:\"ticks\"},ticklabelposition:{valType:\"enumerated\",values:[\"outside\",\"inside\",\"outside top\",\"inside top\",\"outside left\",\"inside left\",\"outside right\",\"inside right\",\"outside bottom\",\"inside bottom\"],dflt:\"outside\",editType:\"calc\"},mirror:{valType:\"enumerated\",values:[!0,\"ticks\",!1,\"all\",\"allticks\"],dflt:!1,editType:\"ticks+layoutstyle\"},ticklen:{valType:\"number\",min:0,dflt:5,editType:\"ticks\"},tickwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},tickcolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},showticklabels:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},automargin:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},showspikes:{valType:\"boolean\",dflt:!1,editType:\"modebar\"},spikecolor:{valType:\"color\",dflt:null,editType:\"none\"},spikethickness:{valType:\"number\",dflt:3,editType:\"none\"},spikedash:o({},a,{dflt:\"dash\",editType:\"none\"}),spikemode:{valType:\"flaglist\",flags:[\"toaxis\",\"across\",\"marker\"],dflt:\"toaxis\",editType:\"none\"},spikesnap:{valType:\"enumerated\",values:[\"data\",\"cursor\",\"hovered data\"],dflt:\"data\",editType:\"none\"},tickfont:n({editType:\"ticks\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"ticks\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"ticks\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"ticks\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"ticks\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"ticks\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"ticks\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"ticks\"},tickformatstops:s(\"tickformatstop\",{enabled:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dtickrange:{valType:\"info_array\",items:[{valType:\"any\",editType:\"ticks\"},{valType:\"any\",editType:\"ticks\"}],editType:\"ticks\"},value:{valType:\"string\",dflt:\"\",editType:\"ticks\"},editType:\"ticks\"}),hoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},showline:{valType:\"boolean\",dflt:!1,editType:\"ticks+layoutstyle\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"layoutstyle\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks+layoutstyle\"},showgrid:{valType:\"boolean\",editType:\"ticks\"},gridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"ticks\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"ticks\"},zeroline:{valType:\"boolean\",editType:\"ticks\"},zerolinecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},zerolinewidth:{valType:\"number\",dflt:1,editType:\"ticks\"},showdividers:{valType:\"boolean\",dflt:!0,editType:\"ticks\"},dividercolor:{valType:\"color\",dflt:i.defaultLine,editType:\"ticks\"},dividerwidth:{valType:\"number\",dflt:1,editType:\"ticks\"},anchor:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],editType:\"plot\"},overlaying:{valType:\"enumerated\",values:[\"free\",c.idRegex.x.toString(),c.idRegex.y.toString()],editType:\"plot\"},layer:{valType:\"enumerated\",values:[\"above traces\",\"below traces\"],dflt:\"above traces\",editType:\"plot\"},domain:{valType:\"info_array\",items:[{valType:\"number\",min:0,max:1,editType:\"plot\"},{valType:\"number\",min:0,max:1,editType:\"plot\"}],dflt:[0,1],editType:\"plot\"},position:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\",\"total ascending\",\"total descending\",\"min ascending\",\"min descending\",\"max ascending\",\"max descending\",\"sum ascending\",\"sum descending\",\"mean ascending\",\"mean descending\",\"median ascending\",\"median descending\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{autotick:{valType:\"boolean\",editType:\"ticks\"},title:{valType:\"string\",editType:\"ticks\"},titlefont:n({editType:\"ticks\"})}}},{\"../../components/color/attributes\":642,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/numerical\":753,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../font_attributes\":856,\"./constants\":834}],843:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../components/fx/helpers\").isUnifiedHover,o=t(\"../../components/fx/hovermode_defaults\"),s=t(\"../../plot_api/plot_template\"),l=t(\"../layout_attributes\"),c=t(\"./layout_attributes\"),u=t(\"./type_defaults\"),f=t(\"./axis_defaults\"),h=t(\"./constraints\"),p=t(\"./position_defaults\"),d=t(\"./axis_ids\"),g=d.id2name,m=d.name2id,v=t(\"./constants\").AX_ID_PATTERN,y=t(\"../../registry\"),x=y.traceIs,b=y.getComponentMethod;function _(t,e,r){Array.isArray(t[e])?t[e].push(r):t[e]=[r]}e.exports=function(t,e,r){var y,w,T=e.autotypenumbers,k={},M={},A={},S={},E={},C={},L={},I={},P={},z={};for(y=0;y<r.length;y++){var O=r[y];if(x(O,\"cartesian\")||x(O,\"gl2d\")){var D,R;if(O.xaxis)D=g(O.xaxis),_(k,D,O);else if(O.xaxes)for(w=0;w<O.xaxes.length;w++)_(k,g(O.xaxes[w]),O);if(O.yaxis)R=g(O.yaxis),_(k,R,O);else if(O.yaxes)for(w=0;w<O.yaxes.length;w++)_(k,g(O.yaxes[w]),O);if(\"funnel\"===O.type?\"h\"===O.orientation?(D&&(M[D]=!0),R&&(L[R]=!0)):R&&(A[R]=!0):\"image\"===O.type?(R&&(I[R]=!0),D&&(I[D]=!0)):(R&&(E[R]=!0,C[R]=!0),x(O,\"carpet\")&&(\"carpet\"!==O.type||O._cheater)||D&&(S[D]=!0)),\"carpet\"===O.type&&O._cheater&&D&&(M[D]=!0),x(O,\"2dMap\")&&(P[D]=!0,P[R]=!0),x(O,\"oriented\"))z[\"h\"===O.orientation?R:D]=!0}}var F=e._subplots,B=F.xaxis,N=F.yaxis,j=n.simpleMap(B,g),U=n.simpleMap(N,g),V=j.concat(U),q=i.background;B.length&&N.length&&(q=n.coerce(t,e,l,\"plot_bgcolor\"));var H,G,Y,W,X,Z=i.combine(q,e.paper_bgcolor);function J(){var t=k[H]||[];X._traceIndices=t.map((function(t){return t._expandedIndex})),X._annIndices=[],X._shapeIndices=[],X._imgIndices=[],X._subplotsWith=[],X._counterAxes=[],X._name=X._attr=H,X._id=G}function K(t,e){return n.coerce(W,X,c,t,e)}function Q(t,e){return n.coerce2(W,X,c,t,e)}function $(t){return\"x\"===t?N:B}function tt(e,r){for(var n=\"x\"===e?j:U,i=[],a=0;a<n.length;a++){var o=n[a];o===r||(t[o]||{}).overlaying||i.push(m(o))}return i}var et={x:$(\"x\"),y:$(\"y\")},rt=et.x.concat(et.y),nt={},it=[];function at(){var t=W.matches;v.test(t)&&-1===rt.indexOf(t)&&(nt[t]=W.type,it=Object.keys(nt))}var ot=o(t,e,r),st=a(ot);for(y=0;y<V.length;y++){H=V[y],G=m(H),Y=H.charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var lt=\"x\"===Y&&!S[H]&&M[H]||\"y\"===Y&&!E[H]&&A[H],ct=\"y\"===Y&&(!C[H]&&L[H]||I[H]),ut={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:k[H]||[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:lt,reverseDflt:ct,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),u(W,X,K,ut),f(W,X,K,ut,e);var ft=st&&Y===ot.charAt(0),ht=Q(\"spikecolor\",st?X.color:void 0),pt=Q(\"spikethickness\",st?1.5:void 0),dt=Q(\"spikedash\",st?\"dot\":void 0),gt=Q(\"spikemode\",st?\"across\":void 0),mt=Q(\"spikesnap\",st?\"hovered data\":void 0);K(\"showspikes\",!!(ft||ht||pt||dt||gt||mt))||(delete X.spikecolor,delete X.spikethickness,delete X.spikedash,delete X.spikemode,delete X.spikesnap),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"title.standoff\"),at(),X._input=W}for(y=0;y<it.length;){G=it[y++],Y=(H=g(G)).charAt(0),n.isPlainObject(t[H])||(t[H]={}),W=t[H],X=s.newContainer(e,H,Y+\"axis\"),J();var vt={letter:Y,font:e.font,outerTicks:P[H],showGrid:!z[H],data:[],bgColor:Z,calendar:e.calendar,automargin:!0,visibleDflt:!1,reverseDflt:!1,autotypenumbersDflt:T,splomStash:((e._splomAxes||{})[Y]||{})[G]};K(\"uirevision\",e.uirevision),X.type=nt[G]||\"linear\",f(W,X,K,vt,e),p(W,X,K,{letter:Y,counterAxes:et[Y],overlayableAxes:tt(Y,H),grid:e.grid}),K(\"fixedrange\"),at(),X._input=W}var yt=b(\"rangeslider\",\"handleDefaults\"),xt=b(\"rangeselector\",\"handleDefaults\");for(y=0;y<j.length;y++)H=j[y],W=t[H],X=e[H],yt(t,e,H),\"date\"===X.type&&xt(W,X,e,U,X.calendar),K(\"fixedrange\");for(y=0;y<U.length;y++){H=U[y],W=t[H],X=e[H];var bt=e[g(X.anchor)];K(\"fixedrange\",b(\"rangeslider\",\"isVisible\")(bt))}h.handleDefaults(t,e,{axIds:rt.concat(it).sort(d.idSort),axHasImage:I})}},{\"../../components/color\":643,\"../../components/fx/helpers\":679,\"../../components/fx/hovermode_defaults\":682,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../registry\":911,\"../layout_attributes\":882,\"./axis_defaults\":830,\"./axis_ids\":831,\"./constants\":834,\"./constraints\":835,\"./layout_attributes\":842,\"./position_defaults\":845,\"./type_defaults\":853}],844:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../components/color/attributes\").lightFraction,a=t(\"../../lib\");e.exports=function(t,e,r,o){var s=(o=o||{}).dfltColor;function l(r,n){return a.coerce2(t,e,o.attributes,r,n)}var c=l(\"linecolor\",s),u=l(\"linewidth\");r(\"showline\",o.showLine||!!c||!!u)||(delete e.linecolor,delete e.linewidth);var f=l(\"gridcolor\",n(s,o.bgColor,o.blend||i).toRgbString()),h=l(\"gridwidth\");if(r(\"showgrid\",o.showGrid||!!f||!!h)||(delete e.gridcolor,delete e.gridwidth),!o.noZeroLine){var p=l(\"zerolinecolor\",s),d=l(\"zerolinewidth\");r(\"zeroline\",o.showGrid||!!p||!!d)||(delete e.zerolinecolor,delete e.zerolinewidth)}}},{\"../../components/color/attributes\":642,\"../../lib\":778,tinycolor2:576}],845:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o,s,l,c,u=a.counterAxes||[],f=a.overlayableAxes||[],h=a.letter,p=a.grid;p&&(s=p._domains[h][p._axisMap[e._id]],o=p._anchors[e._id],s&&(l=p[h+\"side\"].split(\" \")[0],c=p.domain[h][\"right\"===l||\"top\"===l?1:0])),s=s||[0,1],o=o||(n(t.position)?\"free\":u[0]||\"free\"),l=l||(\"x\"===h?\"bottom\":\"left\"),c=c||0,\"free\"===i.coerce(t,e,{anchor:{valType:\"enumerated\",values:[\"free\"].concat(u),dflt:o}},\"anchor\")&&r(\"position\",c),i.coerce(t,e,{side:{valType:\"enumerated\",values:\"x\"===h?[\"bottom\",\"top\"]:[\"left\",\"right\"],dflt:l}},\"side\");var d=!1;if(f.length&&(d=i.coerce(t,e,{overlaying:{valType:\"enumerated\",values:[!1].concat(f),dflt:!1}},\"overlaying\")),!d){var g=r(\"domain\",s);g[0]>g[1]-1/4096&&(e.domain=s),i.noneOrAll(t.domain,e.domain,s)}return r(\"layer\"),e}},{\"../../lib\":778,\"fast-isnumeric\":241}],846:[function(t,e,r){\"use strict\";var n=t(\"../../constants/alignment\").FROM_BL;e.exports=function(t,e,r){void 0===r&&(r=n[t.constraintoward||\"center\"]);var i=[t.r2l(t.range[0]),t.r2l(t.range[1])],a=i[0]+(i[1]-i[0])*r;t.range=t._input.range=[t.l2r(a+(i[0]-a)*e),t.l2r(a+(i[1]-a)*e)],t.setScale()}},{\"../../constants/alignment\":745}],847:[function(t,e,r){\"use strict\";var n=t(\"polybooljs\"),i=t(\"../../registry\"),a=t(\"../../components/drawing\").dashStyle,o=t(\"../../components/color\"),s=t(\"../../components/fx\"),l=t(\"../../components/fx/helpers\").makeEventData,c=t(\"../../components/dragelement/helpers\"),u=c.freeMode,f=c.rectMode,h=c.drawMode,p=c.openMode,d=c.selectMode,g=t(\"../../components/shapes/draw_newshape/display_outlines\"),m=t(\"../../components/shapes/draw_newshape/helpers\").handleEllipse,v=t(\"../../components/shapes/draw_newshape/newshapes\"),y=t(\"../../lib\"),x=t(\"../../lib/polygon\"),b=t(\"../../lib/throttle\"),_=t(\"./axis_ids\").getFromId,w=t(\"../../lib/clear_gl_canvases\"),T=t(\"../../plot_api/subroutines\").redrawReglTraces,k=t(\"./constants\"),M=k.MINSELECT,A=x.filter,S=x.tester,E=t(\"./handle_outline\").clearSelect,C=t(\"./helpers\"),L=C.p2r,I=C.axValue,P=C.getTransform;function z(t,e,r,n,i,a,o){var s,l,c,u,f,h,d,m,v,y=e._hoverdata,x=e._fullLayout.clickmode.indexOf(\"event\")>-1,b=[];if(function(t){return t&&Array.isArray(t)&&!0!==t[0].hoverOnBox}(y)){F(t,e,a);var _=function(t,e){var r,n,i=t[0],a=-1,o=[];for(n=0;n<e.length;n++)if(r=e[n],i.fullData._expandedIndex===r.cd[0].trace._expandedIndex){if(!0===i.hoverOnBox)break;void 0!==i.pointNumber?a=i.pointNumber:void 0!==i.binNumber&&(a=i.binNumber,o=i.pointNumbers);break}return{pointNumber:a,pointNumbers:o,searchInfo:r}}(y,s=N(e,r,n,i));if(_.pointNumbers.length>0?function(t,e){var r,n,i,a=[];for(i=0;i<t.length;i++)(r=t[i]).cd[0].trace.selectedpoints&&r.cd[0].trace.selectedpoints.length>0&&a.push(r);if(1===a.length&&a[0]===e.searchInfo&&(n=e.searchInfo.cd[0].trace).selectedpoints.length===e.pointNumbers.length){for(i=0;i<e.pointNumbers.length;i++)if(n.selectedpoints.indexOf(e.pointNumbers[i])<0)return!1;return!0}return!1}(s,_):function(t){var e,r,n,i=0;for(n=0;n<t.length;n++)if(e=t[n],(r=e.cd[0].trace).selectedpoints){if(r.selectedpoints.length>1)return!1;if((i+=r.selectedpoints.length)>1)return!1}return 1===i}(s)&&(h=j(_))){for(o&&o.remove(),v=0;v<s.length;v++)(l=s[v])._module.selectPoints(l,!1);U(e,s),B(a),x&&e.emit(\"plotly_deselect\",null)}else{for(d=t.shiftKey&&(void 0!==h?h:j(_)),c=function(t,e,r){return{pointNumber:t,searchInfo:e,subtract:r}}(_.pointNumber,_.searchInfo,d),u=R(a.selectionDefs.concat([c])),v=0;v<s.length;v++)if(f=V(s[v]._module.selectPoints(s[v],u),s[v]),b.length)for(var w=0;w<f.length;w++)b.push(f[w]);else b=f;if(U(e,s,m={points:b}),c&&a&&a.selectionDefs.push(c),o){var T=a.mergedPolygons,k=p(a.dragmode);g(q(T,k),o,a)}x&&e.emit(\"plotly_selected\",m)}}}function O(t){return\"pointNumber\"in t&&\"searchInfo\"in t}function D(t){return{xmin:0,xmax:0,ymin:0,ymax:0,pts:[],contains:function(e,r,n,i){var a=t.searchInfo.cd[0].trace._expandedIndex;return i.cd[0].trace._expandedIndex===a&&n===t.pointNumber},isRect:!1,degenerate:!1,subtract:t.subtract}}function R(t){for(var e=[],r=O(t[0])?0:t[0][0][0],n=r,i=O(t[0])?0:t[0][0][1],a=i,o=0;o<t.length;o++)if(O(t[o]))e.push(D(t[o]));else{var s=x.tester(t[o]);s.subtract=t[o].subtract,e.push(s),r=Math.min(r,s.xmin),n=Math.max(n,s.xmax),i=Math.min(i,s.ymin),a=Math.max(a,s.ymax)}return{xmin:r,xmax:n,ymin:i,ymax:a,pts:[],contains:function(t,r,n,i){for(var a=!1,o=0;o<e.length;o++)e[o].contains(t,r,n,i)&&(a=!1===e[o].subtract);return a},isRect:!1,degenerate:!1}}function F(t,e,r){e._fullLayout._drawing=!1;var n=e._fullLayout,i=r.plotinfo,a=r.dragmode,o=n._lastSelectedSubplot&&n._lastSelectedSubplot===i.id,s=(t.shiftKey||t.altKey)&&!(h(a)&&p(a));o&&s&&i.selection&&i.selection.selectionDefs&&!r.selectionDefs?(r.selectionDefs=i.selection.selectionDefs,r.mergedPolygons=i.selection.mergedPolygons):s&&i.selection||B(r),o||(E(e),n._lastSelectedSubplot=i.id)}function B(t){var e=t.dragmode,r=t.plotinfo,n=t.gd;if(n._fullLayout._activeShapeIndex>=0&&n._fullLayout._deactivateShape(n),h(e)){var a=n._fullLayout._zoomlayer.selectAll(\".select-outline-\"+r.id);if(a&&n._fullLayout._drawing){var o=v(a,t);o&&i.call(\"_guiRelayout\",n,{shapes:o}),n._fullLayout._drawing=!1}}r.selection={},r.selection.selectionDefs=t.selectionDefs=[],r.selection.mergedPolygons=t.mergedPolygons=[]}function N(t,e,r,n){var i,a,o,s=[],l=e.map((function(t){return t._id})),c=r.map((function(t){return t._id}));for(o=0;o<t.calcdata.length;o++)if(!0===(a=(i=t.calcdata[o])[0].trace).visible&&a._module&&a._module.selectPoints)if(!n||a.subplot!==n&&a.geo!==n)if(\"splom\"===a.type&&a._xaxes[l[0]]&&a._yaxes[c[0]]){var u=h(a._module,i,e[0],r[0]);u.scene=t._fullLayout._splomScenes[a.uid],s.push(u)}else if(\"sankey\"===a.type){var f=h(a._module,i,e[0],r[0]);s.push(f)}else{if(-1===l.indexOf(a.xaxis))continue;if(-1===c.indexOf(a.yaxis))continue;s.push(h(a._module,i,_(t,a.xaxis),_(t,a.yaxis)))}else s.push(h(a._module,i,e[0],r[0]));return s;function h(t,e,r,n){return{_module:t,cd:e,xaxis:r,yaxis:n}}}function j(t){var e=t.searchInfo.cd[0].trace,r=t.pointNumber,n=t.pointNumbers,i=n.length>0?n[0]:r;return!!e.selectedpoints&&e.selectedpoints.indexOf(i)>-1}function U(t,e,r){var n,a,o,s;for(n=0;n<e.length;n++){var l=e[n].cd[0].trace._fullInput,c=t._fullLayout._tracePreGUI[l.uid]||{};void 0===c.selectedpoints&&(c.selectedpoints=l._input.selectedpoints||null)}if(r){var u=r.points||[];for(n=0;n<e.length;n++)(s=e[n].cd[0].trace)._input.selectedpoints=s._fullInput.selectedpoints=[],s._fullInput!==s&&(s.selectedpoints=[]);for(n=0;n<u.length;n++){var f=u[n],h=f.data,p=f.fullData;f.pointIndices?([].push.apply(h.selectedpoints,f.pointIndices),s._fullInput!==s&&[].push.apply(p.selectedpoints,f.pointIndices)):(h.selectedpoints.push(f.pointIndex),s._fullInput!==s&&p.selectedpoints.push(f.pointIndex))}}else for(n=0;n<e.length;n++)delete(s=e[n].cd[0].trace).selectedpoints,delete s._input.selectedpoints,s._fullInput!==s&&delete s._fullInput.selectedpoints;var d=!1;for(n=0;n<e.length;n++){s=(o=(a=e[n]).cd)[0].trace,i.traceIs(s,\"regl\")&&(d=!0);var g=a._module,m=g.styleOnSelect||g.style;m&&(m(t,o,o[0].node3),o[0].nodeRangePlot3&&m(t,o,o[0].nodeRangePlot3))}d&&(w(t),T(t))}function V(t,e){if(Array.isArray(t))for(var r=e.cd,n=e.cd[0].trace,i=0;i<t.length;i++)t[i]=l(t[i],n,r);return t}function q(t,e){for(var r=[],n=0;n<t.length;n++){r[n]=[];for(var i=0;i<t[n].length;i++){r[n][i]=[],r[n][i][0]=i?\"L\":\"M\";for(var a=0;a<t[n][i].length;a++)r[n][i].push(t[n][i][a])}e||r[n].push([\"Z\",r[n][0][1],r[n][0][2]])}return r}e.exports={prepSelect:function(t,e,r,i,l){var c=u(l),v=f(l),x=p(l),_=h(l),w=d(l),T=\"drawcircle\"===l,E=\"drawline\"===l||T,C=i.gd,O=C._fullLayout,D=O._zoomlayer,j=i.element.getBoundingClientRect(),H=i.plotinfo,G=P(H),Y=e-j.left,W=r-j.top;O._calcInverseTransform(C);var X=y.apply3DTransform(O._invTransform)(Y,W);Y=X[0],W=X[1];var Z,J,K,Q,$,tt,et,rt=O._invScaleX,nt=O._invScaleY,it=Y,at=W,ot=\"M\"+Y+\",\"+W,st=i.xaxes[0]._length,lt=i.yaxes[0]._length,ct=i.xaxes.concat(i.yaxes),ut=t.altKey&&!(h(l)&&x);F(t,C,i),c&&(Z=A([[Y,W]],k.BENDPX));var ft=D.selectAll(\"path.select-outline-\"+H.id).data(_?[0]:[1,2]),ht=O.newshape;ft.enter().append(\"path\").attr(\"class\",(function(t){return\"select-outline select-outline-\"+t+\" select-outline-\"+H.id})).style(_?{opacity:ht.opacity/2,fill:x?void 0:ht.fillcolor,stroke:ht.line.color,\"stroke-dasharray\":a(ht.line.dash,ht.line.width),\"stroke-width\":ht.line.width+\"px\"}:{}).attr(\"fill-rule\",ht.fillrule).classed(\"cursor-move\",!!_).attr(\"transform\",G).attr(\"d\",ot+\"Z\");var pt,dt=D.append(\"path\").attr(\"class\",\"zoombox-corners\").style({fill:o.background,stroke:o.defaultLine,\"stroke-width\":1}).attr(\"transform\",G).attr(\"d\",\"M0,0Z\"),gt=O._uid+k.SELECTID,mt=[],vt=N(C,i.xaxes,i.yaxes,i.subplot);function yt(t,e){return t-e}pt=H.fillRangeItems?H.fillRangeItems:v?function(t,e){var r=t.range={};for($=0;$<ct.length;$++){var n=ct[$],i=n._id.charAt(0);r[n._id]=[L(n,e[i+\"min\"]),L(n,e[i+\"max\"])].sort(yt)}}:function(t,e,r){var n=t.lassoPoints={};for($=0;$<ct.length;$++){var i=ct[$];n[i._id]=r.filtered.map(I(i))}},i.moveFn=function(t,e){it=Math.max(0,Math.min(st,rt*t+Y)),at=Math.max(0,Math.min(lt,nt*e+W));var r=Math.abs(it-Y),a=Math.abs(at-W);if(v){var o,s,l;if(w){var u=O.selectdirection;switch(o=\"any\"===u?a<Math.min(.6*r,M)?\"h\":r<Math.min(.6*a,M)?\"v\":\"d\":u){case\"h\":s=T?lt/2:0,l=lt;break;case\"v\":s=T?st/2:0,l=st}}if(_)switch(O.newshape.drawdirection){case\"vertical\":o=\"h\",s=T?lt/2:0,l=lt;break;case\"horizontal\":o=\"v\",s=T?st/2:0,l=st;break;case\"ortho\":r<a?(o=\"h\",s=W,l=at):(o=\"v\",s=Y,l=it);break;default:o=\"d\"}\"h\"===o?((Q=E?m(T,[it,s],[it,l]):[[Y,s],[Y,l],[it,l],[it,s]]).xmin=E?it:Math.min(Y,it),Q.xmax=E?it:Math.max(Y,it),Q.ymin=Math.min(s,l),Q.ymax=Math.max(s,l),dt.attr(\"d\",\"M\"+Q.xmin+\",\"+(W-M)+\"h-4v\"+2*M+\"h4ZM\"+(Q.xmax-1)+\",\"+(W-M)+\"h4v\"+2*M+\"h-4Z\")):\"v\"===o?((Q=E?m(T,[s,at],[l,at]):[[s,W],[s,at],[l,at],[l,W]]).xmin=Math.min(s,l),Q.xmax=Math.max(s,l),Q.ymin=E?at:Math.min(W,at),Q.ymax=E?at:Math.max(W,at),dt.attr(\"d\",\"M\"+(Y-M)+\",\"+Q.ymin+\"v-4h\"+2*M+\"v4ZM\"+(Y-M)+\",\"+(Q.ymax-1)+\"v4h\"+2*M+\"v-4Z\")):\"d\"===o&&((Q=E?m(T,[Y,W],[it,at]):[[Y,W],[Y,at],[it,at],[it,W]]).xmin=Math.min(Y,it),Q.xmax=Math.max(Y,it),Q.ymin=Math.min(W,at),Q.ymax=Math.max(W,at),dt.attr(\"d\",\"M0,0Z\"))}else c&&(Z.addPt([it,at]),Q=Z.filtered);i.selectionDefs&&i.selectionDefs.length?(K=function(t,e,r){if(r)return n.difference({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions;return n.union({regions:t,inverted:!1},{regions:[e],inverted:!1}).regions}(i.mergedPolygons,Q,ut),Q.subtract=ut,J=R(i.selectionDefs.concat([Q]))):(K=[Q],J=S(Q)),g(q(K,x),ft,i),w&&b.throttle(gt,k.SELECTDELAY,(function(){var t;mt=[];var e,r=[];for($=0;$<vt.length;$++)if(e=(tt=vt[$])._module.selectPoints(tt,J),r.push(e),t=V(e,tt),mt.length)for(var n=0;n<t.length;n++)mt.push(t[n]);else mt=t;U(C,vt,et={points:mt}),pt(et,Q,Z),i.gd.emit(\"plotly_selecting\",et)}))},i.clickFn=function(t,e){if(dt.remove(),C._fullLayout._activeShapeIndex>=0)C._fullLayout._deactivateShape(C);else if(!_){var r=O.clickmode;b.done(gt).then((function(){if(b.clear(gt),2===t){for(ft.remove(),$=0;$<vt.length;$++)(tt=vt[$])._module.selectPoints(tt,!1);U(C,vt),B(i),C.emit(\"plotly_deselect\",null)}else r.indexOf(\"select\")>-1&&z(e,C,i.xaxes,i.yaxes,i.subplot,i,ft),\"event\"===r&&C.emit(\"plotly_selected\",void 0);s.click(C,e)})).catch(y.error)}},i.doneFn=function(){dt.remove(),b.done(gt).then((function(){b.clear(gt),i.gd.emit(\"plotly_selected\",et),Q&&i.selectionDefs&&(Q.subtract=ut,i.selectionDefs.push(Q),i.mergedPolygons.length=0,[].push.apply(i.mergedPolygons,K)),i.doneFnCompleted&&i.doneFnCompleted(mt)})).catch(y.error),_&&B(i)}},clearSelect:E,clearSelectionsCache:B,selectOnClick:z}},{\"../../components/color\":643,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../components/shapes/draw_newshape/display_outlines\":728,\"../../components/shapes/draw_newshape/helpers\":729,\"../../components/shapes/draw_newshape/newshapes\":730,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/polygon\":790,\"../../lib/throttle\":804,\"../../plot_api/subroutines\":818,\"../../registry\":911,\"./axis_ids\":831,\"./constants\":834,\"./handle_outline\":838,\"./helpers\":839,polybooljs:517}],848:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").utcFormat,a=t(\"fast-isnumeric\"),o=t(\"../../lib\"),s=o.cleanNumber,l=o.ms2DateTime,c=o.dateTime2ms,u=o.ensureNumber,f=o.isArrayOrTypedArray,h=t(\"../../constants/numerical\"),p=h.FP_SAFE,d=h.BADNUM,g=h.LOG_CLIP,m=h.ONEWEEK,v=h.ONEDAY,y=h.ONEHOUR,x=h.ONEMIN,b=h.ONESEC,_=t(\"./axis_ids\"),w=t(\"./constants\"),T=w.HOUR_PATTERN,k=w.WEEKDAY_PATTERN;function M(t){return Math.pow(10,t)}function A(t){return null!=t}e.exports=function(t,e){e=e||{};var r=t._id||\"x\",h=r.charAt(0);function S(e,r){if(e>0)return Math.log(e)/Math.LN10;if(e<=0&&r&&t.range&&2===t.range.length){var n=t.range[0],i=t.range[1];return.5*(n+i-2*g*Math.abs(n-i))}return d}function E(e,r,n,i){if((i||{}).msUTC&&a(e))return+e;var s=c(e,n||t.calendar);if(s===d){if(!a(e))return d;e=+e;var l=Math.floor(10*o.mod(e+.05,1)),u=Math.round(e-l/10);s=c(new Date(u))+l/10}return s}function C(e,r,n){return l(e,r,n||t.calendar)}function L(e){return t._categories[Math.round(e)]}function I(e){if(A(e)){if(void 0===t._categoriesMap&&(t._categoriesMap={}),void 0!==t._categoriesMap[e])return t._categoriesMap[e];t._categories.push(\"number\"==typeof e?String(e):e);var r=t._categories.length-1;return t._categoriesMap[e]=r,r}return d}function P(e){if(t._categoriesMap)return t._categoriesMap[e]}function z(t){var e=P(t);return void 0!==e?e:a(t)?+t:void 0}function O(t){return a(t)?+t:P(t)}function D(t,e,r){return n.round(r+e*t,2)}function R(t,e,r){return(t-r)/e}var F=function(e){return a(e)?D(e,t._m,t._b):d},B=function(e){return R(e,t._m,t._b)};if(t.rangebreaks){var N=\"y\"===h;F=function(e){if(!a(e))return d;var r=t._rangebreaks.length;if(!r)return D(e,t._m,t._b);var n=N;t.range[0]>t.range[1]&&(n=!n);for(var i=n?-1:1,o=i*e,s=0,l=0;l<r;l++){var c=i*t._rangebreaks[l].min,u=i*t._rangebreaks[l].max;if(o<c)break;if(!(o>u)){s=o<(c+u)/2?l:l+1;break}s=l+1}var f=t._B[s]||0;return isFinite(f)?D(e,t._m2,f):0},B=function(e){var r=t._rangebreaks.length;if(!r)return R(e,t._m,t._b);for(var n=0,i=0;i<r&&!(e<t._rangebreaks[i].pmin);i++)e>t._rangebreaks[i].pmax&&(n=i+1);return R(e,t._m2,t._B[n])}}t.c2l=\"log\"===t.type?S:u,t.l2c=\"log\"===t.type?M:u,t.l2p=F,t.p2l=B,t.c2p=\"log\"===t.type?function(t,e){return F(S(t,e))}:F,t.p2c=\"log\"===t.type?function(t){return M(B(t))}:B,-1!==[\"linear\",\"-\"].indexOf(t.type)?(t.d2r=t.r2d=t.d2c=t.r2c=t.d2l=t.r2l=s,t.c2d=t.c2r=t.l2d=t.l2r=u,t.d2p=t.r2p=function(e){return t.l2p(s(e))},t.p2d=t.p2r=B,t.cleanPos=u):\"log\"===t.type?(t.d2r=t.d2l=function(t,e){return S(s(t),e)},t.r2d=t.r2c=function(t){return M(s(t))},t.d2c=t.r2l=s,t.c2d=t.l2r=u,t.c2r=S,t.l2d=M,t.d2p=function(e,r){return t.l2p(t.d2r(e,r))},t.p2d=function(t){return M(B(t))},t.r2p=function(e){return t.l2p(s(e))},t.p2r=B,t.cleanPos=u):\"date\"===t.type?(t.d2r=t.r2d=o.identity,t.d2c=t.r2c=t.d2l=t.r2l=E,t.c2d=t.c2r=t.l2d=t.l2r=C,t.d2p=t.r2p=function(e,r,n){return t.l2p(E(e,0,n))},t.p2d=t.p2r=function(t,e,r){return C(B(t),e,r)},t.cleanPos=function(e){return o.cleanDate(e,d,t.calendar)}):\"category\"===t.type?(t.d2c=t.d2l=I,t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=O(e);return void 0!==r?r:t.fraction2r(.5)},t.l2r=t.c2r=u,t.r2l=O,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return\"string\"==typeof t&&\"\"!==t?t:u(t)}):\"multicategory\"===t.type&&(t.r2d=t.c2d=t.l2d=L,t.d2r=t.d2l_noadd=z,t.r2c=function(e){var r=z(e);return void 0!==r?r:t.fraction2r(.5)},t.r2c_just_indices=P,t.l2r=t.c2r=u,t.r2l=z,t.d2p=function(e){return t.l2p(t.r2c(e))},t.p2d=function(t){return L(B(t))},t.r2p=t.d2p,t.p2r=B,t.cleanPos=function(t){return Array.isArray(t)||\"string\"==typeof t&&\"\"!==t?t:u(t)},t.setupMultiCategory=function(n){var i,a,s=t._traceIndices,l=t._matchGroup;if(l&&0===t._categories.length)for(var c in l)if(c!==r){var u=e[_.id2name(c)];s=s.concat(u._traceIndices)}var p=[[0,{}],[0,{}]],d=[];for(i=0;i<s.length;i++){var g=n[s[i]];if(h in g){var m=g[h],v=g._length||o.minRowLength(m);if(f(m[0])&&f(m[1]))for(a=0;a<v;a++){var y=m[0][a],x=m[1][a];A(y)&&A(x)&&(d.push([y,x]),y in p[0][1]||(p[0][1][y]=p[0][0]++),x in p[1][1]||(p[1][1][x]=p[1][0]++))}}}for(d.sort((function(t,e){var r=p[0][1],n=r[t[0]]-r[e[0]];if(n)return n;var i=p[1][1];return i[t[1]]-i[e[1]]})),i=0;i<d.length;i++)I(d[i])}),t.fraction2r=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return t.l2r(r+e*(n-r))},t.r2fraction=function(e){var r=t.r2l(t.range[0]),n=t.r2l(t.range[1]);return(t.r2l(e)-r)/(n-r)},t.cleanRange=function(e,r){r||(r={}),e||(e=\"range\");var n,i,s=o.nestedProperty(t,e).get();if(i=(i=\"date\"===t.type?o.dfltRange(t.calendar):\"y\"===h?w.DFLTRANGEY:r.dfltRange||w.DFLTRANGEX).slice(),\"tozero\"!==t.rangemode&&\"nonnegative\"!==t.rangemode||(i[0]=0),s&&2===s.length)for(\"date\"!==t.type||t.autorange||(s[0]=o.cleanDate(s[0],d,t.calendar),s[1]=o.cleanDate(s[1],d,t.calendar)),n=0;n<2;n++)if(\"date\"===t.type){if(!o.isDateTime(s[n],t.calendar)){t[e]=i;break}if(t.r2l(s[0])===t.r2l(s[1])){var l=o.constrain(t.r2l(s[0]),o.MIN_MS+1e3,o.MAX_MS-1e3);s[0]=t.l2r(l-1e3),s[1]=t.l2r(l+1e3);break}}else{if(!a(s[n])){if(!a(s[1-n])){t[e]=i;break}s[n]=s[1-n]*(n?10:.1)}if(s[n]<-p?s[n]=-p:s[n]>p&&(s[n]=p),s[0]===s[1]){var c=Math.max(1,Math.abs(1e-6*s[0]));s[0]-=c,s[1]+=c}}else o.nestedProperty(t,e).set(i)},t.setScale=function(r){var n=e._size;if(t.overlaying){var i=_.getFromId({_fullLayout:e},t.overlaying);t.domain=i.domain}var a=r&&t._r?\"_r\":\"range\",o=t.calendar;t.cleanRange(a);var s,l,c=t.r2l(t[a][0],o),u=t.r2l(t[a][1],o),f=\"y\"===h;if((f?(t._offset=n.t+(1-t.domain[1])*n.h,t._length=n.h*(t.domain[1]-t.domain[0]),t._m=t._length/(c-u),t._b=-t._m*u):(t._offset=n.l+t.domain[0]*n.w,t._length=n.w*(t.domain[1]-t.domain[0]),t._m=t._length/(u-c),t._b=-t._m*c),t._rangebreaks=[],t._lBreaks=0,t._m2=0,t._B=[],t.rangebreaks)&&(t._rangebreaks=t.locateBreaks(Math.min(c,u),Math.max(c,u)),t._rangebreaks.length)){for(s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._lBreaks+=Math.abs(l.max-l.min);var p=f;c>u&&(p=!p),p&&t._rangebreaks.reverse();var d=p?-1:1;for(t._m2=d*t._length/(Math.abs(u-c)-t._lBreaks),t._B.push(-t._m2*(f?u:c)),s=0;s<t._rangebreaks.length;s++)l=t._rangebreaks[s],t._B.push(t._B[t._B.length-1]-d*t._m2*(l.max-l.min));for(s=0;s<t._rangebreaks.length;s++)(l=t._rangebreaks[s]).pmin=F(l.min),l.pmax=F(l.max)}if(!isFinite(t._m)||!isFinite(t._b)||t._length<0)throw e._replotting=!1,new Error(\"Something went wrong with axis scaling\")},t.maskBreaks=function(e){for(var r,n,i,a,l,c=t.rangebreaks||[],u=0;u<c.length;u++){var f=c[u];if(f.enabled)if(f.bounds){var h=f.pattern;switch(n=(r=o.simpleMap(f.bounds,h?s:t.d2c))[0],i=r[1],h){case k:a=(l=new Date(e)).getUTCDay(),n>i&&(i+=7,a<n&&(a+=7));break;case T:a=(l=new Date(e)).getUTCHours()+(l.getUTCMinutes()/60+l.getUTCSeconds()/3600+l.getUTCMilliseconds()/36e5),n>i&&(i+=24,a<n&&(a+=24));break;case\"\":a=e}if(a>=n&&a<i)return d}else for(var p=o.simpleMap(f.values,t.d2c).sort(o.sorterAsc),g=0;g<p.length;g++)if(i=(n=p[g])+f.dvalue,e>=n&&e<i)return d}return e},t.locateBreaks=function(e,r){var n,i,a,l,c=[];if(!t.rangebreaks)return c;var u=t.rangebreaks.slice().sort((function(t,e){return t.pattern===k&&e.pattern===T?-1:e.pattern===k&&t.pattern===T?1:0})),f=function(t,n){if((t=o.constrain(t,e,r))!==(n=o.constrain(n,e,r))){for(var i=!0,a=0;a<c.length;a++){var s=c[a];t<s.max&&n>=s.min&&(t<s.min&&(s.min=t),n>s.max&&(s.max=n),i=!1)}i&&c.push({min:t,max:n})}};for(n=0;n<u.length;n++){var h=u[n];if(h.enabled)if(h.bounds){var p=e,d=r;h.pattern&&(p=Math.floor(p)),a=(i=o.simpleMap(h.bounds,h.pattern?s:t.r2l))[0],l=i[1];var g,_,w=new Date(p);switch(h.pattern){case k:_=m,g=(l-a+(l<a?7:0))*v,p+=a*v-(w.getUTCDay()*v+w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;case T:_=v,g=(l-a+(l<a?24:0))*y,p+=a*y-(w.getUTCHours()*y+w.getUTCMinutes()*x+w.getUTCSeconds()*b+w.getUTCMilliseconds());break;default:p=Math.min(i[0],i[1]),g=_=(d=Math.max(i[0],i[1]))-p}for(var M=p;M<d;M+=_)f(M,M+g)}else for(var A=o.simpleMap(h.values,t.d2c),S=0;S<A.length;S++)f(a=A[S],l=a+h.dvalue)}return c.sort((function(t,e){return t.min-e.min})),c},t.makeCalcdata=function(e,r,n){var i,a,s,l,c=t.type,u=\"date\"===c&&e[r+\"calendar\"];if(r in e){if(i=e[r],l=e._length||o.minRowLength(i),o.isTypedArray(i)&&(\"linear\"===c||\"log\"===c)){if(l===i.length)return i;if(i.subarray)return i.subarray(0,l)}if(\"multicategory\"===c)return function(t,e){for(var r=new Array(e),n=0;n<e;n++){var i=(t[0]||[])[n],a=(t[1]||[])[n];r[n]=P([i,a])}return r}(i,l);for(a=new Array(l),s=0;s<l;s++)a[s]=t.d2c(i[s],0,u,n)}else{var f=r+\"0\"in e?t.d2c(e[r+\"0\"],0,u):0,h=e[\"d\"+r]?Number(e[\"d\"+r]):1;for(i=e[{x:\"y\",y:\"x\"}[r]],l=e._length||i.length,a=new Array(l),s=0;s<l;s++)a[s]=f+s*h}if(t.rangebreaks)for(s=0;s<l;s++)a[s]=t.maskBreaks(a[s]);return a},t.isValidRange=function(e){return Array.isArray(e)&&2===e.length&&a(t.r2l(e[0]))&&a(t.r2l(e[1]))},t.isPtWithinRange=function(e,r){var n=t.c2l(e[h],null,r),i=t.r2l(t.range[0]),a=t.r2l(t.range[1]);return i<a?i<=n&&n<=a:a<=n&&n<=i},t._emptyCategories=function(){t._categories=[],t._categoriesMap={}},t.clearCalc=function(){var r=t._matchGroup;if(r){var n=null,i=null;for(var a in r){var o=e[_.id2name(a)];if(o._categories){n=o._categories,i=o._categoriesMap;break}}n&&i?(t._categories=n,t._categoriesMap=i):t._emptyCategories()}else t._emptyCategories();if(t._initialCategories)for(var s=0;s<t._initialCategories.length;s++)I(t._initialCategories[s])},t.sortByInitialCategories=function(){var n=[];if(t._emptyCategories(),t._initialCategories)for(var i=0;i<t._initialCategories.length;i++)I(t._initialCategories[i]);n=n.concat(t._traceIndices);var a=t._matchGroup;for(var o in a)if(r!==o){var s=e[_.id2name(o)];s._categories=t._categories,s._categoriesMap=t._categoriesMap,n=n.concat(s._traceIndices)}return n};var j=e._d3locale;\"date\"===t.type&&(t._dateFormat=j?j.timeFormat:i,t._extraFormat=e._extraFormat),t._separators=e.separators,t._numFormat=j?j.numberFormat:n.format,delete t._minDtick,delete t._forceTick0}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./axis_ids\":831,\"./constants\":834,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],849:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").contrast,a=t(\"./layout_attributes\"),o=t(\"../array_container_defaults\");function s(t){var e=[\"showexponent\",\"showtickprefix\",\"showticksuffix\"].filter((function(e){return void 0!==t[e]}));if(e.every((function(r){return t[r]===t[e[0]]}))||1===e.length)return t[e[0]]}function l(t,e){function r(r,i){return n.coerce(t,e,a.tickformatstops,r,i)}r(\"enabled\")&&(r(\"dtickrange\"),r(\"value\"))}e.exports=function(t,e,r,c,u,f){f&&1!==f.pass||function(t,e,r,n,i){var a=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",a);r(\"ticksuffix\",i.tickSuffixDflt)&&r(\"showticksuffix\",a)}(t,0,r,0,u),f&&2!==f.pass||function(t,e,r,c,u){var f=s(t);r(\"tickprefix\")&&r(\"showtickprefix\",f);r(\"ticksuffix\",u.tickSuffixDflt)&&r(\"showticksuffix\",f);if(r(\"showticklabels\")){var h=u.font||{},p=e.color,d=-1!==(e.ticklabelposition||\"\").indexOf(\"inside\")?i(u.bgColor):p&&p!==a.color.dflt?p:h.color;if(n.coerceFont(r,\"tickfont\",{family:h.family,size:h.size,color:d}),r(\"tickangle\"),\"category\"!==c){var g=r(\"tickformat\");o(t,e,{name:\"tickformatstops\",inclusionAttr:\"enabled\",handleItemDefaults:l}),e.tickformatstops.length||delete e.tickformatstops,g||\"date\"===c||(r(\"showexponent\",f),r(\"exponentformat\"),r(\"minexponent\"),r(\"separatethousands\"))}}}(t,e,r,c,u)}},{\"../../components/color\":643,\"../../lib\":778,\"../array_container_defaults\":823,\"./layout_attributes\":842}],850:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r,a){var o=n.coerce2(t,e,i,\"ticklen\"),s=n.coerce2(t,e,i,\"tickwidth\"),l=n.coerce2(t,e,i,\"tickcolor\",e.color);r(\"ticks\",a.outerTicks||o||s||l?\"outside\":\"\")||(delete e.ticklen,delete e.tickwidth,delete e.tickcolor)}},{\"../../lib\":778,\"./layout_attributes\":842}],851:[function(t,e,r){\"use strict\";var n=t(\"./clean_ticks\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){function o(r){var n=t[r];return void 0!==n?n:(e._template||{})[r]}var s=o(\"tick0\"),l=o(\"dtick\"),c=o(\"tickvals\"),u=r(\"tickmode\",i(c)?\"array\":l?\"linear\":\"auto\");if(\"auto\"===u)r(\"nticks\");else if(\"linear\"===u){var f=e.dtick=n.dtick(l,a);e.tick0=n.tick0(s,a,e.calendar,f)}else if(\"multicategory\"!==a){void 0===r(\"tickvals\")?e.tickmode=\"auto\":r(\"ticktext\")}}},{\"../../lib\":778,\"./clean_ticks\":833}],852:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"./axes\");e.exports=function(t,e,r,l){var c=t._fullLayout;if(0!==e.length){var u,f,h,p;l&&(u=l());var d=n.ease(r.easing);return t._transitionData._interruptCallbacks.push((function(){return window.cancelAnimationFrame(p),p=null,function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr0&&(r[o._name+\".range\"]=a.xr0.slice()),a.yr0&&(r[s._name+\".range\"]=a.yr0.slice())}return i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}()})),f=Date.now(),p=window.requestAnimationFrame((function n(){h=Date.now();for(var a=Math.min(1,(h-f)/r.duration),o=d(a),s=0;s<e.length;s++)m(e[s],o);h-f>r.duration?(!function(){for(var r={},n=0;n<e.length;n++){var a=e[n],o=a.plotinfo.xaxis,s=a.plotinfo.yaxis;a.xr1&&(r[o._name+\".range\"]=a.xr1.slice()),a.yr1&&(r[s._name+\".range\"]=a.yr1.slice())}u&&u(),i.call(\"relayout\",t,r).then((function(){for(var t=0;t<e.length;t++)g(e[t].plotinfo)}))}(),p=window.cancelAnimationFrame(n)):p=window.requestAnimationFrame(n)})),Promise.resolve()}function g(t){var e=t.xaxis,r=t.yaxis;c._defs.select(\"#\"+t.clipId+\"> rect\").call(o.setTranslate,0,0).call(o.setScale,1,1),t.plot.call(o.setTranslate,e._offset,r._offset).call(o.setScale,1,1);var n=t.plot.selectAll(\".scatterlayer .trace\");n.selectAll(\".point\").call(o.setPointGroupScale,1,1),n.selectAll(\".textpoint\").call(o.setTextPointsScale,1,1),n.call(o.hideOutsideRangePoints,t)}function m(e,r){var n=e.plotinfo,i=n.xaxis,l=n.yaxis,c=i._length,u=l._length,f=!!e.xr1,h=!!e.yr1,p=[];if(f){var d=a.simpleMap(e.xr0,i.r2l),g=a.simpleMap(e.xr1,i.r2l),m=d[1]-d[0],v=g[1]-g[0];p[0]=(d[0]*(1-r)+r*g[0]-d[0])/(d[1]-d[0])*c,p[2]=c*(1-r+r*v/m),i.range[0]=i.l2r(d[0]*(1-r)+r*g[0]),i.range[1]=i.l2r(d[1]*(1-r)+r*g[1])}else p[0]=0,p[2]=c;if(h){var y=a.simpleMap(e.yr0,l.r2l),x=a.simpleMap(e.yr1,l.r2l),b=y[1]-y[0],_=x[1]-x[0];p[1]=(y[1]*(1-r)+r*x[1]-y[1])/(y[0]-y[1])*u,p[3]=u*(1-r+r*_/b),l.range[0]=i.l2r(y[0]*(1-r)+r*x[0]),l.range[1]=l.l2r(y[1]*(1-r)+r*x[1])}else p[1]=0,p[3]=u;s.drawOne(t,i,{skipTitle:!0}),s.drawOne(t,l,{skipTitle:!0}),s.redrawComponents(t,[i._id,l._id]);var w=f?c/p[2]:1,T=h?u/p[3]:1,k=f?p[0]:0,M=h?p[1]:0,A=f?p[0]/p[2]*c:0,S=h?p[1]/p[3]*u:0,E=i._offset-A,C=l._offset-S;n.clipRect.call(o.setTranslate,k,M).call(o.setScale,1/w,1/T),n.plot.call(o.setTranslate,E,C).call(o.setScale,w,T),o.setPointGroupScale(n.zoomScalePts,1/w,1/T),o.setTextPointsScale(n.zoomScaleTxt,1/w,1/T)}s.redrawComponents(t)}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./axes\":828,d3:169}],853:[function(t,e,r){\"use strict\";var n=t(\"../../registry\").traceIs,i=t(\"./axis_autotype\");function a(t){return{v:\"x\",h:\"y\"}[t.orientation||\"v\"]}function o(t,e){var r=a(t),i=n(t,\"box-violin\"),o=n(t._fullInput||{},\"candlestick\");return i&&!o&&e===r&&void 0===t[r]&&void 0===t[r+\"0\"]}e.exports=function(t,e,r,s){r(\"autotypenumbers\",s.autotypenumbersDflt),\"-\"===r(\"type\",(s.splomStash||{}).type)&&(!function(t,e){if(\"-\"!==t.type)return;var r,s=t._id,l=s.charAt(0);-1!==s.indexOf(\"scene\")&&(s=l);var c=function(t,e,r){for(var n=0;n<t.length;n++){var i=t[n];if(\"splom\"===i.type&&i._length>0&&(i[\"_\"+r+\"axes\"]||{})[e])return i;if((i[r+\"axis\"]||r)===e){if(o(i,r))return i;if((i[r]||[]).length||i[r+\"0\"])return i}}}(e,s,l);if(!c)return;if(\"histogram\"===c.type&&l==={v:\"y\",h:\"x\"}[c.orientation||\"v\"])return void(t.type=\"linear\");var u=l+\"calendar\",f=c[u],h={noMultiCategory:!n(c,\"cartesian\")||n(c,\"noMultiCategory\")};\"box\"===c.type&&c._hasPreCompStats&&l==={h:\"x\",v:\"y\"}[c.orientation||\"v\"]&&(h.noMultiCategory=!0);if(h.autotypenumbers=t.autotypenumbers,o(c,l)){var p=a(c),d=[];for(r=0;r<e.length;r++){var g=e[r];n(g,\"box-violin\")&&(g[l+\"axis\"]||l)===s&&(void 0!==g[p]?d.push(g[p][0]):void 0!==g.name?d.push(g.name):d.push(\"text\"),g[u]!==f&&(f=void 0))}t.type=i(d,f,h)}else if(\"splom\"===c.type){var m=c.dimensions[c._axesDim[s]];m.visible&&(t.type=i(m.values,f,h))}else t.type=i(c[l]||[c[l+\"0\"]],f,h)}(e,s.data),\"-\"===e.type?e.type=\"linear\":t.type=e.type)}},{\"../../registry\":911,\"./axis_autotype\":829}],854:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\");function a(t,e,r){var n,a,o,s=!1;if(\"data\"===e.type)n=t._fullData[null!==e.traces?e.traces[0]:0];else{if(\"layout\"!==e.type)return!1;n=t._fullLayout}return a=i.nestedProperty(n,e.prop).get(),(o=r[e.type]=r[e.type]||{}).hasOwnProperty(e.prop)&&o[e.prop]!==a&&(s=!0),o[e.prop]=a,{changed:s,value:a}}function o(t,e){var r=[],n=e[0],a={};if(\"string\"==typeof n)a[n]=e[1];else{if(!i.isPlainObject(n))return r;a=n}return l(a,(function(t,e,n){r.push({type:\"layout\",prop:t,value:n})}),\"\",0),r}function s(t,e){var r,n,a,o,s=[];if(n=e[0],a=e[1],r=e[2],o={},\"string\"==typeof n)o[n]=a;else{if(!i.isPlainObject(n))return s;o=n,void 0===r&&(r=a)}return void 0===r&&(r=null),l(o,(function(e,n,i){var a,o;if(Array.isArray(i)){o=i.slice();var l=Math.min(o.length,t.data.length);r&&(l=Math.min(l,r.length)),a=[];for(var c=0;c<l;c++)a[c]=r?r[c]:c}else o=i,a=r?r.slice():null;if(null===a)Array.isArray(o)&&(o=o[0]);else if(Array.isArray(a)){if(!Array.isArray(o)){var u=o;o=[];for(var f=0;f<a.length;f++)o[f]=u}o.length=Math.min(a.length,o.length)}s.push({type:\"data\",prop:e,traces:a,value:o})}),\"\",0),s}function l(t,e,r,n){Object.keys(t).forEach((function(a){var o=t[a];if(\"_\"!==a[0]){var s=r+(n>0?\".\":\"\")+a;i.isPlainObject(o)?l(o,e,s,n+1):e(s,a,o)}}))}r.manageCommandObserver=function(t,e,n,o){var s={},l=!0;e&&e._commandObserver&&(s=e._commandObserver),s.cache||(s.cache={}),s.lookupTable={};var c=r.hasSimpleAPICommandBindings(t,n,s.lookupTable);if(e&&e._commandObserver){if(c)return s;if(e._commandObserver.remove)return e._commandObserver.remove(),e._commandObserver=null,s}if(c){a(t,c,s.cache),s.check=function(){if(l){var e=a(t,c,s.cache);return e.changed&&o&&void 0!==s.lookupTable[e.value]&&(s.disable(),Promise.resolve(o({value:e.value,type:c.type,prop:c.prop,traces:c.traces,index:s.lookupTable[e.value]})).then(s.enable,s.enable)),e.changed}};for(var u=[\"plotly_relayout\",\"plotly_redraw\",\"plotly_restyle\",\"plotly_update\",\"plotly_animatingframe\",\"plotly_afterplot\"],f=0;f<u.length;f++)t._internalOn(u[f],s.check);s.remove=function(){for(var e=0;e<u.length;e++)t._removeInternalListener(u[e],s.check)}}else i.log(\"Unable to automatically bind plot updates to API command\"),s.lookupTable={},s.remove=function(){};return s.disable=function(){l=!1},s.enable=function(){l=!0},e&&(e._commandObserver=s),s},r.hasSimpleAPICommandBindings=function(t,e,n){var i,a,o=e.length;for(i=0;i<o;i++){var s,l=e[i],c=l.method,u=l.args;if(Array.isArray(u)||(u=[]),!c)return!1;var f=r.computeAPICommandBindings(t,c,u);if(1!==f.length)return!1;if(a){if((s=f[0]).type!==a.type)return!1;if(s.prop!==a.prop)return!1;if(Array.isArray(a.traces)){if(!Array.isArray(s.traces))return!1;s.traces.sort();for(var h=0;h<a.traces.length;h++)if(a.traces[h]!==s.traces[h])return!1}else if(s.prop!==a.prop)return!1}else a=f[0],Array.isArray(a.traces)&&a.traces.sort();var p=(s=f[0]).value;if(Array.isArray(p)){if(1!==p.length)return!1;p=p[0]}n&&(n[p]=i)}return a},r.executeAPICommand=function(t,e,r){if(\"skip\"===e)return Promise.resolve();var a=n.apiMethodRegistry[e],o=[t];Array.isArray(r)||(r=[]);for(var s=0;s<r.length;s++)o.push(r[s]);return a.apply(null,o).catch((function(t){return i.warn(\"API call to Plotly.\"+e+\" rejected.\",t),Promise.reject(t)}))},r.computeAPICommandBindings=function(t,e,r){var n;switch(Array.isArray(r)||(r=[]),e){case\"restyle\":n=s(t,r);break;case\"relayout\":n=o(t,r);break;case\"update\":n=s(t,[r[0],r[2]]).concat(o(t,[r[1]]));break;case\"animate\":n=function(t,e){return Array.isArray(e[0])&&1===e[0].length&&-1!==[\"string\",\"number\"].indexOf(typeof e[0][0])?[{type:\"layout\",prop:\"_currentFrame\",value:e[0][0].toString()}]:[]}(0,r);break;default:n=[]}return n}},{\"../lib\":778,\"../registry\":911}],855:[function(t,e,r){\"use strict\";var n=t(\"../lib/extend\").extendFlat;r.attributes=function(t,e){e=e||{};var r={valType:\"info_array\",editType:(t=t||{}).editType,items:[{valType:\"number\",min:0,max:1,editType:t.editType},{valType:\"number\",min:0,max:1,editType:t.editType}],dflt:[0,1]},i=(t.name&&t.name,t.trace,e.description&&e.description,{x:n({},r,{}),y:n({},r,{}),editType:t.editType});return t.noGridCell||(i.row={valType:\"integer\",min:0,dflt:0,editType:t.editType},i.column={valType:\"integer\",min:0,dflt:0,editType:t.editType}),i},r.defaults=function(t,e,r,n){var i=n&&n.x||[0,1],a=n&&n.y||[0,1],o=e.grid;if(o){var s=r(\"domain.column\");void 0!==s&&(s<o.columns?i=o._domains.x[s]:delete t.domain.column);var l=r(\"domain.row\");void 0!==l&&(l<o.rows?a=o._domains.y[l]:delete t.domain.row)}var c=r(\"domain.x\",i),u=r(\"domain.y\",a);c[0]<c[1]||(t.domain.x=i.slice()),u[0]<u[1]||(t.domain.y=a.slice())}},{\"../lib/extend\":768}],856:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType,r=t.colorEditType;void 0===r&&(r=e);var n={family:{valType:\"string\",noBlank:!0,strict:!0,editType:e},size:{valType:\"number\",min:1,editType:e},color:{valType:\"color\",editType:r},editType:e};return t.arrayOk&&(n.family.arrayOk=!0,n.size.arrayOk=!0,n.color.arrayOk=!0),n}},{}],857:[function(t,e,r){\"use strict\";e.exports={_isLinkedToArray:\"frames_entry\",group:{valType:\"string\"},name:{valType:\"string\"},traces:{valType:\"any\"},baseframe:{valType:\"string\"},data:{valType:\"any\"},layout:{valType:\"any\"}}},{}],858:[function(t,e,r){\"use strict\";r.projNames={equirectangular:\"equirectangular\",mercator:\"mercator\",orthographic:\"orthographic\",\"natural earth\":\"naturalEarth\",kavrayskiy7:\"kavrayskiy7\",miller:\"miller\",robinson:\"robinson\",eckert4:\"eckert4\",\"azimuthal equal area\":\"azimuthalEqualArea\",\"azimuthal equidistant\":\"azimuthalEquidistant\",\"conic equal area\":\"conicEqualArea\",\"conic conformal\":\"conicConformal\",\"conic equidistant\":\"conicEquidistant\",gnomonic:\"gnomonic\",stereographic:\"stereographic\",mollweide:\"mollweide\",hammer:\"hammer\",\"transverse mercator\":\"transverseMercator\",\"albers usa\":\"albersUsa\",\"winkel tripel\":\"winkel3\",aitoff:\"aitoff\",sinusoidal:\"sinusoidal\"},r.axesNames=[\"lonaxis\",\"lataxis\"],r.lonaxisSpan={orthographic:180,\"azimuthal equal area\":360,\"azimuthal equidistant\":360,\"conic conformal\":180,gnomonic:160,stereographic:180,\"transverse mercator\":180,\"*\":360},r.lataxisSpan={\"conic conformal\":150,stereographic:179.5,\"*\":180},r.scopeDefaults={world:{lonaxisRange:[-180,180],lataxisRange:[-90,90],projType:\"equirectangular\",projRotate:[0,0,0]},usa:{lonaxisRange:[-180,-50],lataxisRange:[15,80],projType:\"albers usa\"},europe:{lonaxisRange:[-30,60],lataxisRange:[30,85],projType:\"conic conformal\",projRotate:[15,0,0],projParallels:[0,60]},asia:{lonaxisRange:[22,160],lataxisRange:[-15,55],projType:\"mercator\",projRotate:[0,0,0]},africa:{lonaxisRange:[-30,60],lataxisRange:[-40,40],projType:\"mercator\",projRotate:[0,0,0]},\"north america\":{lonaxisRange:[-180,-45],lataxisRange:[5,85],projType:\"conic conformal\",projRotate:[-100,0,0],projParallels:[29.5,45.5]},\"south america\":{lonaxisRange:[-100,-30],lataxisRange:[-60,15],projType:\"mercator\",projRotate:[0,0,0]}},r.clipPad=.001,r.precision=.1,r.landColor=\"#F0DC82\",r.waterColor=\"#3399FF\",r.locationmodeToLayer={\"ISO-3\":\"countries\",\"USA-states\":\"subunits\",\"country names\":\"countries\"},r.sphereSVG={type:\"Sphere\"},r.fillLayers={ocean:1,land:1,lakes:1},r.lineLayers={subunits:1,countries:1,coastlines:1,rivers:1,frame:1},r.layers=[\"bg\",\"ocean\",\"land\",\"lakes\",\"subunits\",\"countries\",\"coastlines\",\"rivers\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"frontplot\"],r.layersForChoropleth=[\"bg\",\"ocean\",\"land\",\"subunits\",\"countries\",\"coastlines\",\"lataxis\",\"lonaxis\",\"frame\",\"backplot\",\"rivers\",\"lakes\",\"frontplot\"],r.layerNameToAdjective={ocean:\"ocean\",land:\"land\",lakes:\"lake\",subunits:\"subunit\",countries:\"country\",coastlines:\"coastline\",rivers:\"river\",frame:\"frame\"}},{}],859:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.strTranslate,s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../components/fx\"),u=t(\"../plots\"),f=t(\"../cartesian/axes\"),h=t(\"../cartesian/autorange\").getAutoRange,p=t(\"../../components/dragelement\"),d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").selectOnClick,v=t(\"./zoom\"),y=t(\"./constants\"),x=t(\"../../lib/geo_location_utils\"),b=t(\"../../lib/topojson_utils\"),_=t(\"topojson-client\").feature;function w(t){this.id=t.id,this.graphDiv=t.graphDiv,this.container=t.container,this.topojsonURL=t.topojsonURL,this.isStatic=t.staticPlot,this.topojsonName=null,this.topojson=null,this.projection=null,this.scope=null,this.viewInitial=null,this.fitScale=null,this.bounds=null,this.midPt=null,this.hasChoropleth=!1,this.traceHash={},this.layers={},this.basePaths={},this.dataPaths={},this.dataPoints={},this.clipDef=null,this.clipRect=null,this.bgRect=null,this.makeFramework()}t(\"./projections\")(n);var T=w.prototype;function k(t,e){var r=y.clipPad,n=t[0]+r,i=t[1]-r,a=e[0]+r,o=e[1]-r;n>0&&i<0&&(i+=360);var s=(i-n)/4;return{type:\"Polygon\",coordinates:[[[n,a],[n,o],[n+s,o],[n+2*s,o],[n+3*s,o],[i,o],[i,a],[i-s,a],[i-2*s,a],[i-3*s,a],[n,a]]]}}e.exports=function(t){return new w(t)},T.plot=function(t,e,r){var n=this,i=e[this.id],a=[],o=!1;for(var s in y.layerNameToAdjective)if(\"frame\"!==s&&i[\"show\"+s]){o=!0;break}for(var l=0;l<t.length;l++)if(t[0][0].trace.locationmode){o=!0;break}if(o){var c=b.getTopojsonName(i);null!==n.topojson&&c===n.topojsonName||(n.topojsonName=c,void 0===PlotlyGeoAssets.topojson[n.topojsonName]&&a.push(n.fetchTopojson()))}a=a.concat(x.fetchTraceGeoData(t)),r.push(new Promise((function(r,i){Promise.all(a).then((function(){n.topojson=PlotlyGeoAssets.topojson[n.topojsonName],n.update(t,e),r()})).catch(i)})))},T.fetchTopojson=function(){var t=this,e=b.getTopojsonPath(t.topojsonURL,t.topojsonName);return new Promise((function(r,i){n.json(e,(function(n,a){if(n)return 404===n.status?i(new Error([\"plotly.js could not find topojson file at\",e,\".\",\"Make sure the *topojsonURL* plot config option\",\"is set properly.\"].join(\" \"))):i(new Error([\"unexpected error while fetching topojson file at\",e].join(\" \")));PlotlyGeoAssets.topojson[t.topojsonName]=a,r()}))}))},T.update=function(t,e){var r=e[this.id];this.hasChoropleth=!1;for(var n=0;n<t.length;n++){var i=t[n],a=i[0].trace;\"choropleth\"===a.type&&(this.hasChoropleth=!0),!0===a.visible&&a._length>0&&a._module.calcGeoJSON(i,e)}if(!this.updateProjection(t,e)){this.viewInitial&&this.scope===r.scope||this.saveViewInitial(r),this.scope=r.scope,this.updateBaseLayers(e,r),this.updateDims(e,r),this.updateFx(e,r),u.generalUpdatePerTraceModule(this.graphDiv,this,t,r);var o=this.layers.frontplot.select(\".scatterlayer\");this.dataPoints.point=o.selectAll(\".point\"),this.dataPoints.text=o.selectAll(\"text\"),this.dataPaths.line=o.selectAll(\".js-line\");var s=this.layers.backplot.select(\".choroplethlayer\");this.dataPaths.choropleth=s.selectAll(\"path\"),this.render()}},T.updateProjection=function(t,e){var r=this.graphDiv,o=e[this.id],s=e._size,l=o.domain,c=o.projection,u=o.lonaxis,f=o.lataxis,p=u._ax,d=f._ax,g=this.projection=function(t){for(var e=t.projection.type,r=n.geo[y.projNames[e]](),i=t._isClipped?y.lonaxisSpan[e]/2:null,a=[\"center\",\"rotate\",\"parallels\",\"clipExtent\"],o=function(t){return t?r:[]},s=0;s<a.length;s++){var l=a[s];\"function\"!=typeof r[l]&&(r[l]=o)}r.isLonLatOverEdges=function(t){if(null===r(t))return!0;if(i){var e=r.rotate();return n.geo.distance(t,[-e[0],-e[1]])>i*Math.PI/180}return!1},r.getPath=function(){return n.geo.path().projection(r)},r.getBounds=function(t){return r.getPath().bounds(t)},r.fitExtent=function(t,e){var n=t[1][0]-t[0][0],i=t[1][1]-t[0][1],a=r.clipExtent&&r.clipExtent();r.scale(150).translate([0,0]),a&&r.clipExtent(null);var o=r.getBounds(e),s=Math.min(n/(o[1][0]-o[0][0]),i/(o[1][1]-o[0][1])),l=+t[0][0]+(n-s*(o[1][0]+o[0][0]))/2,c=+t[0][1]+(i-s*(o[1][1]+o[0][1]))/2;return a&&r.clipExtent(a),r.scale(150*s).translate([l,c])},r.precision(y.precision),i&&r.clipAngle(i-y.clipPad);return r}(o),m=[[s.l+s.w*l.x[0],s.t+s.h*(1-l.y[1])],[s.l+s.w*l.x[1],s.t+s.h*(1-l.y[0])]],v=o.center||{},x=c.rotation||{},b=u.range||[],_=f.range||[];if(o.fitbounds){p._length=m[1][0]-m[0][0],d._length=m[1][1]-m[0][1],p.range=h(r,p),d.range=h(r,d);var w=(p.range[0]+p.range[1])/2,T=(d.range[0]+d.range[1])/2;if(o._isScoped)v={lon:w,lat:T};else if(o._isClipped){v={lon:w,lat:T},x={lon:w,lat:T,roll:x.roll};var M=c.type,A=y.lonaxisSpan[M]/2||180,S=y.lataxisSpan[M]/2||90;b=[w-A,w+A],_=[T-S,T+S]}else v={lon:w,lat:T},x={lon:w,lat:x.lat,roll:x.roll}}g.center([v.lon-x.lon,v.lat-x.lat]).rotate([-x.lon,-x.lat,x.roll]).parallels(c.parallels);var E=k(b,_);g.fitExtent(m,E);var C=this.bounds=g.getBounds(E),L=this.fitScale=g.scale(),I=g.translate();if(!isFinite(C[0][0])||!isFinite(C[0][1])||!isFinite(C[1][0])||!isFinite(C[1][1])||isNaN(I[0])||isNaN(I[0])){for(var P=[\"fitbounds\",\"projection.rotation\",\"center\",\"lonaxis.range\",\"lataxis.range\"],z=\"Invalid geo settings, relayout'ing to default view.\",O={},D=0;D<P.length;D++)O[this.id+\".\"+P[D]]=null;return this.viewInitial=null,a.warn(z),r._promises.push(i.call(\"relayout\",r,O)),z}if(o.fitbounds){var R=g.getBounds(k(p.range,d.range)),F=Math.min((C[1][0]-C[0][0])/(R[1][0]-R[0][0]),(C[1][1]-C[0][1])/(R[1][1]-R[0][1]));isFinite(F)?g.scale(F*L):a.warn(\"Something went wrong during\"+this.id+\"fitbounds computations.\")}else g.scale(c.scale*L);var B=this.midPt=[(C[0][0]+C[1][0])/2,(C[0][1]+C[1][1])/2];if(g.translate([I[0]+(B[0]-I[0]),I[1]+(B[1]-I[1])]).clipExtent(C),o._isAlbersUsa){var N=g([v.lon,v.lat]),j=g.translate();g.translate([j[0]-(N[0]-j[0]),j[1]-(N[1]-j[1])])}},T.updateBaseLayers=function(t,e){var r=this,i=r.topojson,a=r.layers,o=r.basePaths;function c(t){return\"lonaxis\"===t||\"lataxis\"===t}function u(t){return Boolean(y.lineLayers[t])}function h(t){return Boolean(y.fillLayers[t])}var p=(this.hasChoropleth?y.layersForChoropleth:y.layers).filter((function(t){return u(t)||h(t)?e[\"show\"+t]:!c(t)||e[t].showgrid})),d=r.framework.selectAll(\".layer\").data(p,String);d.exit().each((function(t){delete a[t],delete o[t],n.select(this).remove()})),d.enter().append(\"g\").attr(\"class\",(function(t){return\"layer \"+t})).each((function(t){var e=a[t]=n.select(this);\"bg\"===t?r.bgRect=e.append(\"rect\").style(\"pointer-events\",\"all\"):c(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\"):\"backplot\"===t?e.append(\"g\").classed(\"choroplethlayer\",!0):\"frontplot\"===t?e.append(\"g\").classed(\"scatterlayer\",!0):u(t)?o[t]=e.append(\"path\").style(\"fill\",\"none\").style(\"stroke-miterlimit\",2):h(t)&&(o[t]=e.append(\"path\").style(\"stroke\",\"none\"))})),d.order(),d.each((function(r){var n=o[r],a=y.layerNameToAdjective[r];\"frame\"===r?n.datum(y.sphereSVG):u(r)||h(r)?n.datum(_(i,i.objects[r])):c(r)&&n.datum(function(t,e,r){var n,i,a,o=e[t],s=y.scopeDefaults[e.scope];\"lonaxis\"===t?(n=s.lonaxisRange,i=s.lataxisRange,a=function(t,e){return[t,e]}):\"lataxis\"===t&&(n=s.lataxisRange,i=s.lonaxisRange,a=function(t,e){return[e,t]});var l={type:\"linear\",range:[n[0],n[1]-1e-6],tick0:o.tick0,dtick:o.dtick};f.setConvert(l,r);var c=f.calcTicks(l);e.isScoped||\"lonaxis\"!==t||c.pop();for(var u=c.length,h=new Array(u),p=0;p<u;p++)for(var d=c[p].x,g=h[p]=[],m=i[0];m<i[1]+2.5;m+=2.5)g.push(a(d,m));return{type:\"MultiLineString\",coordinates:h}}(r,e,t)).call(s.stroke,e[r].gridcolor).call(l.dashLine,\"\",e[r].gridwidth),u(r)?n.call(s.stroke,e[a+\"color\"]).call(l.dashLine,\"\",e[a+\"width\"]):h(r)&&n.call(s.fill,e[a+\"color\"])}))},T.updateDims=function(t,e){var r=this.bounds,n=(e.framewidth||0)/2,i=r[0][0]-n,a=r[0][1]-n,o=r[1][0]-i+n,c=r[1][1]-a+n;l.setRect(this.clipRect,i,a,o,c),this.bgRect.call(l.setRect,i,a,o,c).call(s.fill,e.bgcolor),this.xaxis._offset=i,this.xaxis._length=o,this.yaxis._offset=a,this.yaxis._length=c},T.updateFx=function(t,e){var r=this,a=r.graphDiv,o=r.bgRect,s=t.dragmode,l=t.clickmode;if(!r.isStatic){var u;\"select\"===s?u=function(t,e){(t.range={})[r.id]=[h([e.xmin,e.ymin]),h([e.xmax,e.ymax])]}:\"lasso\"===s&&(u=function(t,e,n){(t.lassoPoints={})[r.id]=n.filtered.map(h)});var f={element:r.bgRect.node(),gd:a,plotinfo:{id:r.id,xaxis:r.xaxis,yaxis:r.yaxis,fillRangeItems:u},xaxes:[r.xaxis],yaxes:[r.yaxis],subplot:r.id,clickFn:function(t){2===t&&g(a)}};\"pan\"===s?(o.node().onmousedown=null,o.call(v(r,e)),o.on(\"dblclick.zoom\",(function(){var t=r.viewInitial,e={};for(var n in t)e[r.id+\".\"+n]=t[n];i.call(\"_guiRelayout\",a,e),a.emit(\"plotly_doubleclick\",null)})),a._context._scrollZoom.geo||o.on(\"wheel.zoom\",null)):\"select\"!==s&&\"lasso\"!==s||(o.on(\".zoom\",null),f.prepFn=function(t,e,r){d(t,e,r,f,s)},p.init(f)),o.on(\"mousemove\",(function(){var t=r.projection.invert(n.mouse(this));if(!t||isNaN(t[0])||isNaN(t[1]))return p.unhover(a,n.event);r.xaxis.p2c=function(){return t[0]},r.yaxis.p2c=function(){return t[1]},c.hover(a,n.event,r.id)})),o.on(\"mouseout\",(function(){a._dragging||p.unhover(a,n.event)})),o.on(\"click\",(function(){\"select\"!==s&&\"lasso\"!==s&&(l.indexOf(\"select\")>-1&&m(n.event,a,[r.xaxis],[r.yaxis],r.id,f),l.indexOf(\"event\")>-1&&c.click(a,n.event))}))}function h(t){return r.projection.invert([t[0]+r.xaxis._offset,t[1]+r.yaxis._offset])}},T.makeFramework=function(){var t=this,e=t.graphDiv,r=e._fullLayout,i=\"clip\"+r._uid+t.id;t.clipDef=r._clips.append(\"clipPath\").attr(\"id\",i),t.clipRect=t.clipDef.append(\"rect\"),t.framework=n.select(t.container).append(\"g\").attr(\"class\",\"geo \"+t.id).call(l.setClipUrl,i,e),t.project=function(e){var r=t.projection(e);return r?[r[0]-t.xaxis._offset,r[1]-t.yaxis._offset]:[null,null]},t.xaxis={_id:\"x\",c2p:function(e){return t.project(e)[0]}},t.yaxis={_id:\"y\",c2p:function(e){return t.project(e)[1]}},t.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},f.setConvert(t.mockAxis,r)},T.saveViewInitial=function(t){var e,r=t.center||{},n=t.projection,i=n.rotation||{};this.viewInitial={fitbounds:t.fitbounds,\"projection.scale\":n.scale},e=t._isScoped?{\"center.lon\":r.lon,\"center.lat\":r.lat}:t._isClipped?{\"projection.rotation.lon\":i.lon,\"projection.rotation.lat\":i.lat}:{\"center.lon\":r.lon,\"center.lat\":r.lat,\"projection.rotation.lon\":i.lon},a.extendFlat(this.viewInitial,e)},T.render=function(){var t,e=this.projection,r=e.getPath();function n(t){var r=e(t.lonlat);return r?o(r[0],r[1]):null}function i(t){return e.isLonLatOverEdges(t.lonlat)?\"none\":null}for(t in this.basePaths)this.basePaths[t].attr(\"d\",r);for(t in this.dataPaths)this.dataPaths[t].attr(\"d\",(function(t){return r(t.geojson)}));for(t in this.dataPoints)this.dataPoints[t].attr(\"display\",i).attr(\"transform\",n)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"../plots\":891,\"./constants\":858,\"./projections\":863,\"./zoom\":864,d3:169,\"topojson-client\":579}],860:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./geo\"),o=\"geo\",s=i(o),l={};l.geo={valType:\"subplotid\",dflt:o,editType:\"calc\"},e.exports={attr:o,name:o,idRoot:o,idRegex:s,attrRegex:s,attributes:l,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots.geo,s=0;s<i.length;s++){var l=i[s],c=n(r,o,l),u=e[l]._subplot;u||(u=a({id:l,graphDiv:t,container:e._geolayer.node(),topojsonURL:t._context.topojsonURL,staticPlot:t._context.staticPlot}),e[l]._subplot=u),u.plot(c,e,t._promises)}},updateFx:function(t){for(var e=t._fullLayout,r=e._subplots.geo,n=0;n<r.length;n++){var i=e[r[n]];i._subplot.updateFx(e,i)}},clean:function(t,e,r,n){for(var i=n._subplots.geo||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.framework.remove(),s.clipDef.remove())}}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./geo\":859,\"./layout_attributes\":861,\"./layout_defaults\":862}],861:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"./constants\"),o=t(\"../../plot_api/edit_types\").overrideAll,s={range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},showgrid:{valType:\"boolean\",dflt:!1},tick0:{valType:\"number\",dflt:0},dtick:{valType:\"number\"},gridcolor:{valType:\"color\",dflt:n.lightLine},gridwidth:{valType:\"number\",min:0,dflt:1}};(e.exports=o({domain:i({name:\"geo\"},{}),fitbounds:{valType:\"enumerated\",values:[!1,\"locations\",\"geojson\"],dflt:!1,editType:\"plot\"},resolution:{valType:\"enumerated\",values:[110,50],dflt:110,coerceNumber:!0},scope:{valType:\"enumerated\",values:Object.keys(a.scopeDefaults),dflt:\"world\"},projection:{type:{valType:\"enumerated\",values:Object.keys(a.projNames)},rotation:{lon:{valType:\"number\"},lat:{valType:\"number\"},roll:{valType:\"number\"}},parallels:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},scale:{valType:\"number\",min:0,dflt:1}},center:{lon:{valType:\"number\"},lat:{valType:\"number\"}},visible:{valType:\"boolean\",dflt:!0},showcoastlines:{valType:\"boolean\"},coastlinecolor:{valType:\"color\",dflt:n.defaultLine},coastlinewidth:{valType:\"number\",min:0,dflt:1},showland:{valType:\"boolean\",dflt:!1},landcolor:{valType:\"color\",dflt:a.landColor},showocean:{valType:\"boolean\",dflt:!1},oceancolor:{valType:\"color\",dflt:a.waterColor},showlakes:{valType:\"boolean\",dflt:!1},lakecolor:{valType:\"color\",dflt:a.waterColor},showrivers:{valType:\"boolean\",dflt:!1},rivercolor:{valType:\"color\",dflt:a.waterColor},riverwidth:{valType:\"number\",min:0,dflt:1},showcountries:{valType:\"boolean\"},countrycolor:{valType:\"color\",dflt:n.defaultLine},countrywidth:{valType:\"number\",min:0,dflt:1},showsubunits:{valType:\"boolean\"},subunitcolor:{valType:\"color\",dflt:n.defaultLine},subunitwidth:{valType:\"number\",min:0,dflt:1},showframe:{valType:\"boolean\"},framecolor:{valType:\"color\",dflt:n.defaultLine},framewidth:{valType:\"number\",min:0,dflt:1},bgcolor:{valType:\"color\",dflt:n.background},lonaxis:s,lataxis:s},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../plot_api/edit_types\":810,\"../domain\":855,\"./constants\":858}],862:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../get_data\").getSubplotData,o=t(\"./constants\"),s=t(\"./layout_attributes\"),l=o.axesNames;function c(t,e,r,i){var s=a(i.fullData,\"geo\",i.id).map((function(t){return t._expandedIndex})),c=r(\"resolution\"),u=r(\"scope\"),f=o.scopeDefaults[u],h=r(\"projection.type\",f.projType),p=e._isAlbersUsa=\"albers usa\"===h;p&&(u=e.scope=\"usa\");var d=e._isScoped=\"world\"!==u,g=e._isConic=-1!==h.indexOf(\"conic\"),m=e._isClipped=!!o.lonaxisSpan[h];if(!1===t.visible){var v=n.extendDeep({},e._template);v.showcoastlines=!1,v.showcountries=!1,v.showframe=!1,v.showlakes=!1,v.showland=!1,v.showocean=!1,v.showrivers=!1,v.showsubunits=!1,v.lonaxis&&(v.lonaxis.showgrid=!1),v.lataxis&&(v.lataxis.showgrid=!1),e._template=v}for(var y=r(\"visible\"),x=0;x<l.length;x++){var b,_=l[x],w=[30,10][x];if(d)b=f[_+\"Range\"];else{var T=o[_+\"Span\"],k=(T[h]||T[\"*\"])/2,M=r(\"projection.rotation.\"+_.substr(0,3),f.projRotate[x]);b=[M-k,M+k]}var A=r(_+\".range\",b);r(_+\".tick0\"),r(_+\".dtick\",w),r(_+\".showgrid\",!!y&&void 0)&&(r(_+\".gridcolor\"),r(_+\".gridwidth\")),e[_]._ax={type:\"linear\",_id:_.slice(0,3),_traceIndices:s,setScale:n.identity,c2l:n.identity,r2l:n.identity,autorange:!0,range:A.slice(),_m:1,_input:{}}}var S=e.lonaxis.range,E=e.lataxis.range,C=S[0],L=S[1];C>0&&L<0&&(L+=360);var I,P,z,O=(C+L)/2;if(!p){var D=d?f.projRotate:[O,0,0];I=r(\"projection.rotation.lon\",D[0]),r(\"projection.rotation.lat\",D[1]),r(\"projection.rotation.roll\",D[2]),r(\"showcoastlines\",!d&&y)&&(r(\"coastlinecolor\"),r(\"coastlinewidth\")),r(\"showocean\",!!y&&void 0)&&r(\"oceancolor\")}(p?(P=-96.6,z=38.7):(P=d?O:I,z=(E[0]+E[1])/2),r(\"center.lon\",P),r(\"center.lat\",z),g)&&r(\"projection.parallels\",f.projParallels||[0,60]);r(\"projection.scale\"),r(\"showland\",!!y&&void 0)&&r(\"landcolor\"),r(\"showlakes\",!!y&&void 0)&&r(\"lakecolor\"),r(\"showrivers\",!!y&&void 0)&&(r(\"rivercolor\"),r(\"riverwidth\")),r(\"showcountries\",d&&\"usa\"!==u&&y)&&(r(\"countrycolor\"),r(\"countrywidth\")),(\"usa\"===u||\"north america\"===u&&50===c)&&(r(\"showsubunits\",y),r(\"subunitcolor\"),r(\"subunitwidth\")),d||r(\"showframe\",y)&&(r(\"framecolor\"),r(\"framewidth\")),r(\"bgcolor\"),r(\"fitbounds\")&&(delete e.projection.scale,d?(delete e.center.lon,delete e.center.lat):m?(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon,delete e.projection.rotation.lat,delete e.lonaxis.range,delete e.lataxis.range):(delete e.center.lon,delete e.center.lat,delete e.projection.rotation.lon))}e.exports=function(t,e,r){i(t,e,r,{type:\"geo\",attributes:s,handleDefaults:c,fullData:r,partition:\"y\"})}},{\"../../lib\":778,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":858,\"./layout_attributes\":861}],863:[function(t,e,r){\"use strict\";e.exports=function(t){function e(t,e){return{type:\"Feature\",id:t.id,properties:t.properties,geometry:r(t.geometry,e)}}function r(e,n){if(!e)return null;if(\"GeometryCollection\"===e.type)return{type:\"GeometryCollection\",geometries:object.geometries.map((function(t){return r(t,n)}))};if(!c.hasOwnProperty(e.type))return null;var i=c[e.type];return t.geo.stream(e,n(i)),i.result()}t.geo.project=function(t,e){var i=e.stream;if(!i)throw new Error(\"not yet supported\");return(t&&n.hasOwnProperty(t.type)?n[t.type]:r)(t,i)};var n={Feature:e,FeatureCollection:function(t,r){return{type:\"FeatureCollection\",features:t.features.map((function(t){return e(t,r)}))}}},i=[],a=[],o={point:function(t,e){i.push([t,e])},result:function(){var t=i.length?i.length<2?{type:\"Point\",coordinates:i[0]}:{type:\"MultiPoint\",coordinates:i}:null;return i=[],t}},s={lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){i.length&&(a.push(i),i=[])},result:function(){var t=a.length?a.length<2?{type:\"LineString\",coordinates:a[0]}:{type:\"MultiLineString\",coordinates:a}:null;return a=[],t}},l={polygonStart:u,lineStart:u,point:function(t,e){i.push([t,e])},lineEnd:function(){var t=i.length;if(t){do{i.push(i[0].slice())}while(++t<4);a.push(i),i=[]}},polygonEnd:u,result:function(){if(!a.length)return null;var t=[],e=[];return a.forEach((function(r){!function(t){if((e=t.length)<4)return!1;var e,r=0,n=t[e-1][1]*t[0][0]-t[e-1][0]*t[0][1];for(;++r<e;)n+=t[r-1][1]*t[r][0]-t[r-1][0]*t[r][1];return n<=0}(r)?e.push(r):t.push([r])})),e.forEach((function(e){var r=e[0];t.some((function(t){if(function(t,e){for(var r=e[0],n=e[1],i=!1,a=0,o=t.length,s=o-1;a<o;s=a++){var l=t[a],c=l[0],u=l[1],f=t[s],h=f[0],p=f[1];u>n^p>n&&r<(h-c)*(n-u)/(p-u)+c&&(i=!i)}return i}(t[0],r))return t.push(e),!0}))||t.push([e])})),a=[],t.length?t.length>1?{type:\"MultiPolygon\",coordinates:t}:{type:\"Polygon\",coordinates:t[0]}:null}},c={Point:o,MultiPoint:o,LineString:s,MultiLineString:s,Polygon:l,MultiPolygon:l,Sphere:l};function u(){}var f=1e-6,h=Math.PI,p=h/2,d=(Math.sqrt(h),h/180),g=180/h;function m(t){return t>1?p:t<-1?-p:Math.asin(t)}function v(t){return t>1?0:t<-1?h:Math.acos(t)}var y=t.geo.projection,x=t.geo.projectionMutator;function b(t,e){var r=(2+p)*Math.sin(e);e/=2;for(var n=0,i=1/0;n<10&&Math.abs(i)>f;n++){var a=Math.cos(e);e-=i=(e+Math.sin(e)*(a+2)-r)/(2*a*(1+a))}return[2/Math.sqrt(h*(4+h))*t*(1+Math.cos(e)),2*Math.sqrt(h/(4+h))*Math.sin(e)]}t.geo.interrupt=function(e){var r,n=[[[[-h,0],[0,p],[h,0]]],[[[-h,0],[0,-p],[h,0]]]];function i(t,r){for(var i=r<0?-1:1,a=n[+(r<0)],o=0,s=a.length-1;o<s&&t>a[o][2][0];++o);var l=e(t-a[o][1][0],r);return l[0]+=e(a[o][1][0],i*r>i*a[o][0][1]?a[o][0][1]:r)[0],l}function a(){r=n.map((function(t){return t.map((function(t){var r,n=e(t[0][0],t[0][1])[0],i=e(t[2][0],t[2][1])[0],a=e(t[1][0],t[0][1])[1],o=e(t[1][0],t[1][1])[1];return a>o&&(r=a,a=o,o=r),[[n,a],[i,o]]}))}))}e.invert&&(i.invert=function(t,a){for(var o=r[+(a<0)],s=n[+(a<0)],l=0,u=o.length;l<u;++l){var f=o[l];if(f[0][0]<=t&&t<f[1][0]&&f[0][1]<=a&&a<f[1][1]){var h=e.invert(t-e(s[l][1][0],0)[0],a);return h[0]+=s[l][1][0],c(i(h[0],h[1]),[t,a])?h:null}}});var o=t.geo.projection(i),s=o.stream;function l(t,e){for(var r,n,i,a=-1,o=t.length,s=t[0],l=[];++a<o;){n=((r=t[a])[0]-s[0])/e,i=(r[1]-s[1])/e;for(var c=0;c<e;++c)l.push([s[0]+c*n,s[1]+c*i]);s=r}return l.push(r),l}function c(t,e){return Math.abs(t[0]-e[0])<f&&Math.abs(t[1]-e[1])<f}return o.stream=function(e){var r=o.rotate(),i=s(e),a=(o.rotate([0,0]),s(e));return o.rotate(r),i.sphere=function(){t.geo.stream(function(){for(var e=1e-6,r=[],i=0,a=n[0].length;i<a;++i){var o=180*(p=n[0][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[o+e,s+e],[o+e,c-e],[u-e,c-e],[u-e,f+e]],30))}for(i=n[1].length-1;i>=0;--i){var p;o=180*(p=n[1][i])[0][0]/h,s=180*p[0][1]/h,c=180*p[1][1]/h,u=180*p[2][0]/h,f=180*p[2][1]/h;r.push(l([[u-e,f-e],[u-e,c+e],[o+e,c+e],[o+e,s-e]],30))}return{type:\"Polygon\",coordinates:[t.merge(r)]}}(),a)},i},o.lobes=function(t){return arguments.length?(n=t.map((function(t){return t.map((function(t){return[[t[0][0]*h/180,t[0][1]*h/180],[t[1][0]*h/180,t[1][1]*h/180],[t[2][0]*h/180,t[2][1]*h/180]]}))})),a(),o):n.map((function(t){return t.map((function(t){return[[180*t[0][0]/h,180*t[0][1]/h],[180*t[1][0]/h,180*t[1][1]/h],[180*t[2][0]/h,180*t[2][1]/h]]}))}))},o},b.invert=function(t,e){var r=.5*e*Math.sqrt((4+h)/h),n=m(r),i=Math.cos(n);return[t/(2/Math.sqrt(h*(4+h))*(1+i)),m((n+r*(i+2))/(2+p))]},(t.geo.eckert4=function(){return y(b)}).raw=b;var _=t.geo.azimuthalEqualArea.raw;function w(t,e){if(arguments.length<2&&(e=t),1===e)return _;if(e===1/0)return T;function r(r,n){var i=_(r/e,n);return i[0]*=t,i}return r.invert=function(r,n){var i=_.invert(r/t,n);return i[0]*=e,i},r}function T(t,e){return[t*Math.cos(e)/Math.cos(e/=2),2*Math.sin(e)]}function k(t,e){return[3*t/(2*h)*Math.sqrt(h*h/3-e*e),e]}function M(t,e){return[t,1.25*Math.log(Math.tan(h/4+.4*e))]}function A(t){return function(e){var r,n=t*Math.sin(e),i=30;do{e-=r=(e+Math.sin(e)-n)/(1+Math.cos(e))}while(Math.abs(r)>f&&--i>0);return e/2}}T.invert=function(t,e){var r=2*m(e/2);return[t*Math.cos(r/2)/Math.cos(r),r]},(t.geo.hammer=function(){var t=2,e=x(w),r=e(t);return r.coefficient=function(r){return arguments.length?e(t=+r):t},r}).raw=w,k.invert=function(t,e){return[2/3*h*t/Math.sqrt(h*h/3-e*e),e]},(t.geo.kavrayskiy7=function(){return y(k)}).raw=k,M.invert=function(t,e){return[t,2.5*Math.atan(Math.exp(.8*e))-.625*h]},(t.geo.miller=function(){return y(M)}).raw=M,A(h);var S=function(t,e,r){var n=A(r);function i(r,i){return[t*r*Math.cos(i=n(i)),e*Math.sin(i)]}return i.invert=function(n,i){var a=m(i/e);return[n/(t*Math.cos(a)),m((2*a+Math.sin(2*a))/r)]},i}(Math.SQRT2/p,Math.SQRT2,h);function E(t,e){var r=e*e,n=r*r;return[t*(.8707-.131979*r+n*(n*(.003971*r-.001529*n)-.013791)),e*(1.007226+r*(.015085+n*(.028874*r-.044475-.005916*n)))]}(t.geo.mollweide=function(){return y(S)}).raw=S,E.invert=function(t,e){var r,n=e,i=25;do{var a=n*n,o=a*a;n-=r=(n*(1.007226+a*(.015085+o*(.028874*a-.044475-.005916*o)))-e)/(1.007226+a*(.045255+o*(.259866*a-.311325-.005916*11*o)))}while(Math.abs(r)>f&&--i>0);return[t/(.8707+(a=n*n)*(a*(a*a*a*(.003971-.001529*a)-.013791)-.131979)),n]},(t.geo.naturalEarth=function(){return y(E)}).raw=E;var C=[[.9986,-.062],[1,0],[.9986,.062],[.9954,.124],[.99,.186],[.9822,.248],[.973,.31],[.96,.372],[.9427,.434],[.9216,.4958],[.8962,.5571],[.8679,.6176],[.835,.6769],[.7986,.7346],[.7597,.7903],[.7186,.8435],[.6732,.8936],[.6213,.9394],[.5722,.9761],[.5322,1]];function L(t,e){var r,n=Math.min(18,36*Math.abs(e)/h),i=Math.floor(n),a=n-i,o=(r=C[i])[0],s=r[1],l=(r=C[++i])[0],c=r[1],u=(r=C[Math.min(19,++i)])[0],f=r[1];return[t*(l+a*(u-o)/2+a*a*(u-2*l+o)/2),(e>0?p:-p)*(c+a*(f-s)/2+a*a*(f-2*c+s)/2)]}function I(t,e){return[t*Math.cos(e),e]}function P(t,e){var r,n=Math.cos(e),i=(r=v(n*Math.cos(t/=2)))?r/Math.sin(r):1;return[2*n*Math.sin(t)*i,Math.sin(e)*i]}function z(t,e){var r=P(t,e);return[(r[0]+t/p)/2,(r[1]+e)/2]}C.forEach((function(t){t[1]*=1.0144})),L.invert=function(t,e){var r=e/p,n=90*r,i=Math.min(18,Math.abs(n/5)),a=Math.max(0,Math.floor(i));do{var o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],c=l-o,u=l-2*s+o,f=2*(Math.abs(r)-s)/c,h=u/c,m=f*(1-h*f*(1-2*h*f));if(m>=0||1===a){n=(e>=0?5:-5)*(m+i);var v,y=50;do{m=(i=Math.min(18,Math.abs(n)/5))-(a=Math.floor(i)),o=C[a][1],s=C[a+1][1],l=C[Math.min(19,a+2)][1],n-=(v=(e>=0?p:-p)*(s+m*(l-o)/2+m*m*(l-2*s+o)/2)-e)*g}while(Math.abs(v)>1e-12&&--y>0);break}}while(--a>=0);var x=C[a][0],b=C[a+1][0],_=C[Math.min(19,a+2)][0];return[t/(b+m*(_-x)/2+m*m*(_-2*b+x)/2),n*d]},(t.geo.robinson=function(){return y(L)}).raw=L,I.invert=function(t,e){return[t/Math.cos(e),e]},(t.geo.sinusoidal=function(){return y(I)}).raw=I,P.invert=function(t,e){if(!(t*t+4*e*e>h*h+f)){var r=t,n=e,i=25;do{var a,o=Math.sin(r),s=Math.sin(r/2),l=Math.cos(r/2),c=Math.sin(n),u=Math.cos(n),p=Math.sin(2*n),d=c*c,g=u*u,m=s*s,y=1-g*l*l,x=y?v(u*l)*Math.sqrt(a=1/y):a=0,b=2*x*u*s-t,_=x*c-e,w=a*(g*m+x*u*l*d),T=a*(.5*o*p-2*x*c*s),k=.25*a*(p*s-x*c*g*o),M=a*(d*l+x*m*u),A=T*k-M*w;if(!A)break;var S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]}},(t.geo.aitoff=function(){return y(P)}).raw=P,z.invert=function(t,e){var r=t,n=e,i=25;do{var a,o=Math.cos(n),s=Math.sin(n),l=Math.sin(2*n),c=s*s,u=o*o,h=Math.sin(r),d=Math.cos(r/2),g=Math.sin(r/2),m=g*g,y=1-u*d*d,x=y?v(o*d)*Math.sqrt(a=1/y):a=0,b=.5*(2*x*o*g+r/p)-t,_=.5*(x*s+n)-e,w=.5*a*(u*m+x*o*d*c)+.5/p,T=a*(h*l/4-x*s*g),k=.125*a*(l*g-x*s*u*h),M=.5*a*(c*d+x*m*o)+.5,A=T*k-M*w,S=(_*T-b*M)/A,E=(b*k-_*w)/A;r-=S,n-=E}while((Math.abs(S)>f||Math.abs(E)>f)&&--i>0);return[r,n]},(t.geo.winkel3=function(){return y(z)}).raw=z}},{}],864:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=Math.PI/180,s=180/Math.PI,l={cursor:\"pointer\"},c={cursor:\"auto\"};function u(t,e){return n.behavior.zoom().translate(e.translate()).scale(e.scale())}function f(t,e,r){var n=t.id,o=t.graphDiv,s=o.layout,l=s[n],c=o._fullLayout,u=c[n],f={},h={};function p(t,e){f[n+\".\"+t]=i.nestedProperty(l,t).get(),a.call(\"_storeDirectGUIEdit\",s,c._preGUI,f);var r=i.nestedProperty(u,t);r.get()!==e&&(r.set(e),i.nestedProperty(l,t).set(e),h[n+\".\"+t]=e)}r(p),p(\"projection.scale\",e.scale()/t.fitScale),p(\"fitbounds\",!1),o.emit(\"plotly_relayout\",h)}function h(t,e){var r=u(0,e);function i(r){var n=e.invert(t.midPt);r(\"center.lon\",n[0]),r(\"center.lat\",n[1])}return r.on(\"zoomstart\",(function(){n.select(this).style(l)})).on(\"zoom\",(function(){e.scale(n.event.scale).translate(n.event.translate),t.render();var r=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":r[0],\"geo.center.lat\":r[1]})})).on(\"zoomend\",(function(){n.select(this).style(c),f(t,e,i)})),r}function p(t,e){var r,i,a,o,s,h,p,d,g,m=u(0,e);function v(t){return e.invert(t)}function y(r){var n=e.rotate(),i=e.invert(t.midPt);r(\"projection.rotation.lon\",-n[0]),r(\"center.lon\",i[0]),r(\"center.lat\",i[1])}return m.on(\"zoomstart\",(function(){n.select(this).style(l),r=n.mouse(this),i=e.rotate(),a=e.translate(),o=i,s=v(r)})).on(\"zoom\",(function(){if(h=n.mouse(this),function(t){var r=v(t);if(!r)return!0;var n=e(r);return Math.abs(n[0]-t[0])>2||Math.abs(n[1]-t[1])>2}(r))return m.scale(e.scale()),void m.translate(e.translate());e.scale(n.event.scale),e.translate([a[0],n.event.translate[1]]),s?v(h)&&(d=v(h),p=[o[0]+(d[0]-s[0]),i[1],i[2]],e.rotate(p),o=p):s=v(r=h),g=!0,t.render();var l=e.rotate(),c=e.invert(t.midPt);t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.center.lon\":c[0],\"geo.center.lat\":c[1],\"geo.projection.rotation.lon\":-l[0]})})).on(\"zoomend\",(function(){n.select(this).style(c),g&&f(t,e,y)})),m}function d(t,e){var r,i={r:e.rotate(),k:e.scale()},a=u(0,e),o=function(t){var e=0,r=arguments.length,i=[];for(;++e<r;)i.push(arguments[e]);var a=n.dispatch.apply(null,i);return a.of=function(e,r){return function(i){var o;try{o=i.sourceEvent=n.event,i.target=t,n.event=i,a[i.type].apply(e,r)}finally{n.event=o}}},a}(a,\"zoomstart\",\"zoom\",\"zoomend\"),s=0,h=a.on;function p(t){s++||t({type:\"zoomstart\"})}function d(t){t({type:\"zoom\"})}function b(t){--s||t({type:\"zoomend\"})}function _(t){var r=e.rotate();t(\"projection.rotation.lon\",-r[0]),t(\"projection.rotation.lat\",-r[1])}return a.on(\"zoomstart\",(function(){n.select(this).style(l);var t=n.mouse(this),s=e.rotate(),c=s,u=e.translate(),f=m(s);r=g(e,t),h.call(a,\"zoom\",(function(){var a=n.mouse(this);if(e.scale(i.k=n.event.scale),r){if(g(e,a)){e.rotate(s).translate(u);var l=g(e,a),h=y(r,l),p=T(v(f,h)),m=i.r=x(p,r,c);isFinite(m[0])&&isFinite(m[1])&&isFinite(m[2])||(m=c),e.rotate(m),c=m}}else r=g(e,t=a);d(o.of(this,arguments))})),p(o.of(this,arguments))})).on(\"zoomend\",(function(){n.select(this).style(c),h.call(a,\"zoom\",null),b(o.of(this,arguments)),f(t,e,_)})).on(\"zoom.redraw\",(function(){t.render();var r=e.rotate();t.graphDiv.emit(\"plotly_relayouting\",{\"geo.projection.scale\":e.scale()/t.fitScale,\"geo.projection.rotation.lon\":-r[0],\"geo.projection.rotation.lat\":-r[1]})})),n.rebind(a,o,\"on\")}function g(t,e){var r=t.invert(e);return r&&isFinite(r[0])&&isFinite(r[1])&&function(t){var e=t[0]*o,r=t[1]*o,n=Math.cos(r);return[n*Math.cos(e),n*Math.sin(e),Math.sin(r)]}(r)}function m(t){var e=.5*t[0]*o,r=.5*t[1]*o,n=.5*t[2]*o,i=Math.sin(e),a=Math.cos(e),s=Math.sin(r),l=Math.cos(r),c=Math.sin(n),u=Math.cos(n);return[a*l*u+i*s*c,i*l*u-a*s*c,a*s*u+i*l*c,a*l*c-i*s*u]}function v(t,e){var r=t[0],n=t[1],i=t[2],a=t[3],o=e[0],s=e[1],l=e[2],c=e[3];return[r*o-n*s-i*l-a*c,r*s+n*o+i*c-a*l,r*l-n*c+i*o+a*s,r*c+n*l-i*s+a*o]}function y(t,e){if(t&&e){var r=function(t,e){return[t[1]*e[2]-t[2]*e[1],t[2]*e[0]-t[0]*e[2],t[0]*e[1]-t[1]*e[0]]}(t,e),n=Math.sqrt(k(r,r)),i=.5*Math.acos(Math.max(-1,Math.min(1,k(t,e)))),a=Math.sin(i)/n;return n&&[Math.cos(i),r[2]*a,-r[1]*a,r[0]*a]}}function x(t,e,r){var n=w(e,2,t[0]);n=w(n,1,t[1]),n=w(n,0,t[2]-r[2]);var i,a,o=e[0],l=e[1],c=e[2],u=n[0],f=n[1],h=n[2],p=Math.atan2(l,o)*s,d=Math.sqrt(o*o+l*l);Math.abs(f)>d?(a=(f>0?90:-90)-p,i=0):(a=Math.asin(f/d)*s-p,i=Math.sqrt(d*d-f*f));var g=180-a-2*p,m=(Math.atan2(h,u)-Math.atan2(c,i))*s,v=(Math.atan2(h,u)-Math.atan2(c,-i))*s;return b(r[0],r[1],a,m)<=b(r[0],r[1],g,v)?[a,m,r[2]]:[g,v,r[2]]}function b(t,e,r,n){var i=_(r-t),a=_(n-e);return Math.sqrt(i*i+a*a)}function _(t){return(t%360+540)%360-180}function w(t,e,r){var n=r*o,i=t.slice(),a=0===e?1:0,s=2===e?1:2,l=Math.cos(n),c=Math.sin(n);return i[a]=t[a]*l-t[s]*c,i[s]=t[s]*l+t[a]*c,i}function T(t){return[Math.atan2(2*(t[0]*t[1]+t[2]*t[3]),1-2*(t[1]*t[1]+t[2]*t[2]))*s,Math.asin(Math.max(-1,Math.min(1,2*(t[0]*t[2]-t[3]*t[1]))))*s,Math.atan2(2*(t[0]*t[3]+t[1]*t[2]),1-2*(t[2]*t[2]+t[3]*t[3]))*s]}function k(t,e){for(var r=0,n=0,i=t.length;n<i;++n)r+=t[n]*e[n];return r}e.exports=function(t,e){var r=t.projection;return(e._isScoped?h:e._isClipped?d:p)(t,r)}},{\"../../lib\":778,\"../../registry\":911,d3:169}],865:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"./cartesian/constants\").SUBPLOT_PATTERN;r.getSubplotCalcData=function(t,e,r){var i=n.subplotsRegistry[e];if(!i)return[];for(var a=i.attr,o=[],s=0;s<t.length;s++){var l=t[s];l[0].trace[a]===r&&o.push(l)}return o},r.getModuleCalcData=function(t,e){var r,i=[],a=[];if(!(r=\"string\"==typeof e?n.getModule(e).plot:\"function\"==typeof e?e:e.plot))return[i,t];for(var o=0;o<t.length;o++){var s=t[o],l=s[0].trace;!0===l.visible&&0!==l._length&&(l._module.plot===r?i.push(s):a.push(s))}return[i,a]},r.getSubplotData=function(t,e,r){if(!n.subplotsRegistry[e])return[];var a,o,s,l=n.subplotsRegistry[e].attr,c=[];if(\"gl2d\"===e){var u=r.match(i);o=\"x\"+u[1],s=\"y\"+u[2]}for(var f=0;f<t.length;f++)a=t[f],\"gl2d\"===e&&n.traceIs(a,\"gl2d\")?a[l[0]]===o&&a[l[1]]===s&&c.push(a):a[l]===r&&c.push(a);return c}},{\"../registry\":911,\"./cartesian/constants\":834}],866:[function(t,e,r){\"use strict\";var n=t(\"mouse-change\"),i=t(\"mouse-wheel\"),a=t(\"mouse-event-offset\"),o=t(\"../cartesian/constants\"),s=t(\"has-passive-events\");function l(t,e){this.element=t,this.plot=e,this.mouseListener=null,this.wheelListener=null,this.lastInputTime=Date.now(),this.lastPos=[0,0],this.boxEnabled=!1,this.boxInited=!1,this.boxStart=[0,0],this.boxEnd=[0,0],this.dragStart=[0,0]}e.exports=function(t){var e=t.mouseContainer,r=t.glplot,c=new l(e,r);function u(){t.xaxis.autorange=!1,t.yaxis.autorange=!1}function f(e,n,i){var a,s,l=t.calcDataBox(),f=r.viewBox,h=c.lastPos[0],p=c.lastPos[1],d=o.MINDRAG*r.pixelRatio,g=o.MINZOOM*r.pixelRatio;function m(e,r,n){var i=Math.min(r,n),a=Math.max(r,n);i!==a?(l[e]=i,l[e+2]=a,c.dataBox=l,t.setRanges(l)):(t.selectBox.selectBox=[0,0,1,1],t.glplot.setDirty())}switch(n*=r.pixelRatio,i*=r.pixelRatio,i=f[3]-f[1]-i,t.fullLayout.dragmode){case\"zoom\":if(e){var v=n/(f[2]-f[0])*(l[2]-l[0])+l[0],y=i/(f[3]-f[1])*(l[3]-l[1])+l[1];c.boxInited||(c.boxStart[0]=v,c.boxStart[1]=y,c.dragStart[0]=n,c.dragStart[1]=i),c.boxEnd[0]=v,c.boxEnd[1]=y,c.boxInited=!0,c.boxEnabled||c.boxStart[0]===c.boxEnd[0]&&c.boxStart[1]===c.boxEnd[1]||(c.boxEnabled=!0);var x=Math.abs(c.dragStart[0]-n)<g,b=Math.abs(c.dragStart[1]-i)<g;if(!function(){for(var e=t.graphDiv._fullLayout._axisConstraintGroups,r=t.xaxis._id,n=t.yaxis._id,i=0;i<e.length;i++)if(-1!==e[i][r]){if(-1!==e[i][n])return!0;break}return!1}()||x&&b)x&&(c.boxEnd[0]=c.boxStart[0]),b&&(c.boxEnd[1]=c.boxStart[1]);else{a=c.boxEnd[0]-c.boxStart[0],s=c.boxEnd[1]-c.boxStart[1];var _=(l[3]-l[1])/(l[2]-l[0]);Math.abs(a*_)>Math.abs(s)?(c.boxEnd[1]=c.boxStart[1]+Math.abs(a)*_*(s>=0?1:-1),c.boxEnd[1]<l[1]?(c.boxEnd[1]=l[1],c.boxEnd[0]=c.boxStart[0]+(l[1]-c.boxStart[1])/Math.abs(_)):c.boxEnd[1]>l[3]&&(c.boxEnd[1]=l[3],c.boxEnd[0]=c.boxStart[0]+(l[3]-c.boxStart[1])/Math.abs(_))):(c.boxEnd[0]=c.boxStart[0]+Math.abs(s)/_*(a>=0?1:-1),c.boxEnd[0]<l[0]?(c.boxEnd[0]=l[0],c.boxEnd[1]=c.boxStart[1]+(l[0]-c.boxStart[0])*Math.abs(_)):c.boxEnd[0]>l[2]&&(c.boxEnd[0]=l[2],c.boxEnd[1]=c.boxStart[1]+(l[2]-c.boxStart[0])*Math.abs(_)))}}else c.boxEnabled?(a=c.boxStart[0]!==c.boxEnd[0],s=c.boxStart[1]!==c.boxEnd[1],a||s?(a&&(m(0,c.boxStart[0],c.boxEnd[0]),t.xaxis.autorange=!1),s&&(m(1,c.boxStart[1],c.boxEnd[1]),t.yaxis.autorange=!1),t.relayoutCallback()):t.glplot.setDirty(),c.boxEnabled=!1,c.boxInited=!1):c.boxInited&&(c.boxInited=!1);break;case\"pan\":c.boxEnabled=!1,c.boxInited=!1,e?(c.panning||(c.dragStart[0]=n,c.dragStart[1]=i),Math.abs(c.dragStart[0]-n)<d&&(n=c.dragStart[0]),Math.abs(c.dragStart[1]-i)<d&&(i=c.dragStart[1]),a=(h-n)*(l[2]-l[0])/(r.viewBox[2]-r.viewBox[0]),s=(p-i)*(l[3]-l[1])/(r.viewBox[3]-r.viewBox[1]),l[0]+=a,l[2]+=a,l[1]+=s,l[3]+=s,t.setRanges(l),c.panning=!0,c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations()):c.panning&&(c.panning=!1,t.relayoutCallback())}c.lastPos[0]=n,c.lastPos[1]=i}return c.mouseListener=n(e,f),e.addEventListener(\"touchstart\",(function(t){var r=a(t.changedTouches[0],e);f(0,r[0],r[1]),f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchmove\",(function(t){t.preventDefault();var r=a(t.changedTouches[0],e);f(1,r[0],r[1]),t.preventDefault()}),!!s&&{passive:!1}),e.addEventListener(\"touchend\",(function(t){f(0,c.lastPos[0],c.lastPos[1]),t.preventDefault()}),!!s&&{passive:!1}),c.wheelListener=i(e,(function(e,n){if(!t.scrollZoom)return!1;var i=t.calcDataBox(),a=r.viewBox,o=c.lastPos[0],s=c.lastPos[1],l=Math.exp(5*n/(a[3]-a[1])),f=o/(a[2]-a[0])*(i[2]-i[0])+i[0],h=s/(a[3]-a[1])*(i[3]-i[1])+i[1];return i[0]=(i[0]-f)*l+f,i[2]=(i[2]-f)*l+f,i[1]=(i[1]-h)*l+h,i[3]=(i[3]-h)*l+h,t.setRanges(i),c.lastInputTime=Date.now(),u(),t.cameraChanged(),t.handleAnnotations(),t.relayoutCallback(),!0}),!0),c}},{\"../cartesian/constants\":834,\"has-passive-events\":441,\"mouse-change\":483,\"mouse-event-offset\":484,\"mouse-wheel\":486}],867:[function(t,e,r){\"use strict\";var n=t(\"../cartesian/axes\"),i=t(\"../../lib/str2rgbarray\");function a(t){this.scene=t,this.gl=t.gl,this.pixelRatio=t.pixelRatio,this.screenBox=[0,0,1,1],this.viewBox=[0,0,1,1],this.dataBox=[-1,-1,1,1],this.borderLineEnable=[!1,!1,!1,!1],this.borderLineWidth=[1,1,1,1],this.borderLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.ticks=[[],[]],this.tickEnable=[!0,!0,!1,!1],this.tickPad=[15,15,15,15],this.tickAngle=[0,0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickMarkLength=[0,0,0,0],this.tickMarkWidth=[0,0,0,0],this.tickMarkColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labels=[\"x\",\"y\"],this.labelEnable=[!0,!0,!1,!1],this.labelAngle=[0,Math.PI/2,0,3*Math.PI/2],this.labelPad=[15,15,15,15],this.labelSize=[12,12],this.labelFont=[\"sans-serif\",\"sans-serif\"],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.title=\"\",this.titleEnable=!0,this.titleCenter=[0,0,0,0],this.titleAngle=0,this.titleColor=[0,0,0,1],this.titleFont=\"sans-serif\",this.titleSize=18,this.gridLineEnable=[!0,!0],this.gridLineColor=[[0,0,0,.5],[0,0,0,.5]],this.gridLineWidth=[1,1],this.zeroLineEnable=[!0,!0],this.zeroLineWidth=[1,1],this.zeroLineColor=[[0,0,0,1],[0,0,0,1]],this.borderColor=[0,0,0,0],this.backgroundColor=[0,0,0,0],this.static=this.scene.staticPlot}var o=a.prototype,s=[\"xaxis\",\"yaxis\"];o.merge=function(t){var e,r,n,a,o,l,c,u,f,h,p;for(this.titleEnable=!1,this.backgroundColor=i(t.plot_bgcolor),h=0;h<2;++h){var d=(e=s[h]).charAt(0);for(n=(r=t[this.scene[e]._name]).title.text===this.scene.fullLayout._dfltTitle[d]?\"\":r.title.text,p=0;p<=2;p+=2)this.labelEnable[h+p]=!1,this.labels[h+p]=n,this.labelColor[h+p]=i(r.title.font.color),this.labelFont[h+p]=r.title.font.family,this.labelSize[h+p]=r.title.font.size,this.labelPad[h+p]=this.getLabelPad(e,r),this.tickEnable[h+p]=!1,this.tickColor[h+p]=i((r.tickfont||{}).color),this.tickAngle[h+p]=\"auto\"===r.tickangle?0:Math.PI*-r.tickangle/180,this.tickPad[h+p]=this.getTickPad(r),this.tickMarkLength[h+p]=0,this.tickMarkWidth[h+p]=r.tickwidth||0,this.tickMarkColor[h+p]=i(r.tickcolor),this.borderLineEnable[h+p]=!1,this.borderLineColor[h+p]=i(r.linecolor),this.borderLineWidth[h+p]=r.linewidth||0;c=this.hasSharedAxis(r),o=this.hasAxisInDfltPos(e,r)&&!c,l=this.hasAxisInAltrPos(e,r)&&!c,a=r.mirror||!1,u=c?-1!==String(a).indexOf(\"all\"):!!a,f=c?\"allticks\"===a:-1!==String(a).indexOf(\"ticks\"),o?this.labelEnable[h]=!0:l&&(this.labelEnable[h+2]=!0),o?this.tickEnable[h]=r.showticklabels:l&&(this.tickEnable[h+2]=r.showticklabels),(o||u)&&(this.borderLineEnable[h]=r.showline),(l||u)&&(this.borderLineEnable[h+2]=r.showline),(o||f)&&(this.tickMarkLength[h]=this.getTickMarkLength(r)),(l||f)&&(this.tickMarkLength[h+2]=this.getTickMarkLength(r)),this.gridLineEnable[h]=r.showgrid,this.gridLineColor[h]=i(r.gridcolor),this.gridLineWidth[h]=r.gridwidth,this.zeroLineEnable[h]=r.zeroline,this.zeroLineColor[h]=i(r.zerolinecolor),this.zeroLineWidth[h]=r.zerolinewidth}},o.hasSharedAxis=function(t){var e=this.scene,r=e.fullLayout._subplots.gl2d;return 0!==n.findSubplotsWithAxis(r,t).indexOf(e.id)},o.hasAxisInDfltPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"bottom\"===r:\"yaxis\"===t?\"left\"===r:void 0},o.hasAxisInAltrPos=function(t,e){var r=e.side;return\"xaxis\"===t?\"top\"===r:\"yaxis\"===t?\"right\"===r:void 0},o.getLabelPad=function(t,e){var r=e.title.font.size,n=e.showticklabels;return\"xaxis\"===t?\"top\"===e.side?r*(1.5+(n?1:0))-10:r*(1.5+(n?.5:0))-10:\"yaxis\"===t?\"right\"===e.side?10+r*(1.5+(n?1:.5)):10+r*(1.5+(n?.5:0)):void 0},o.getTickPad=function(t){return\"outside\"===t.ticks?10+t.ticklen:15},o.getTickMarkLength=function(t){if(!t.ticks)return 0;var e=t.ticklen;return\"inside\"===t.ticks?-e:e},e.exports=function(t){return new a(t)}},{\"../../lib/str2rgbarray\":802,\"../cartesian/axes\":828}],868:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"./scene2d\"),a=t(\"../layout_attributes\"),o=t(\"../../constants/xmlns_namespaces\"),s=t(\"../cartesian/constants\"),l=t(\"../cartesian\"),c=t(\"../../components/fx/layout_attributes\"),u=t(\"../get_data\").getSubplotData;r.name=\"gl2d\",r.attr=[\"xaxis\",\"yaxis\"],r.idRoot=[\"x\",\"y\"],r.idRegex=s.idRegex,r.attrRegex=s.attrRegex,r.attributes=t(\"../cartesian/attributes\"),r.supplyLayoutDefaults=function(t,e,r){e._has(\"cartesian\")||l.supplyLayoutDefaults(t,e,r)},r.layoutAttrOverrides=n(l.layoutAttributes,\"plot\",\"from-root\"),r.baseLayoutAttrOverrides=n({plot_bgcolor:a.plot_bgcolor,hoverlabel:c.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl2d,a=0;a<n.length;a++){var o=n[a],s=e._plots[o],l=u(r,\"gl2d\",o),c=s._scene2d;void 0===c&&(c=new i({id:o,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio},e),s._scene2d=c),c.plot(l,t.calcdata,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl2d||[],a=0;a<i.length;a++){var o=i[a],s=n._plots[o];if(s._scene2d){var c=u(t,\"gl2d\",o);0===c.length&&(s._scene2d.destroy(),delete n._plots[o])}}l.clean.apply(this,arguments)},r.drawFramework=function(t){t._context.staticPlot||l.drawFramework(t)},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){var i=e._plots[r[n]]._scene2d,a=i.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":a,x:0,y:0,width:\"100%\",height:\"100%\",preserveAspectRatio:\"none\"}),i.destroy()}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl2d,n=0;n<r.length;n++){e._plots[r[n]]._scene2d.updateFx(e.dragmode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../plot_api/edit_types\":810,\"../cartesian\":841,\"../cartesian/attributes\":826,\"../cartesian/constants\":834,\"../get_data\":865,\"../layout_attributes\":882,\"./scene2d\":869}],869:[function(t,e,r){\"use strict\";var n,i,a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../components/fx\"),l=t(\"gl-plot2d\"),c=t(\"gl-spikes2d\"),u=t(\"gl-select-box\"),f=t(\"webgl-context\"),h=t(\"./convert\"),p=t(\"./camera\"),d=t(\"../../lib/show_no_webgl_msg\"),g=t(\"../cartesian/constraints\"),m=g.enforce,v=g.clean,y=t(\"../cartesian/autorange\").doAutoRange,x=t(\"../../components/dragelement/helpers\"),b=x.drawMode,_=x.selectMode,w=[\"xaxis\",\"yaxis\"],T=t(\"../cartesian/constants\").SUBPLOT_PATTERN;function k(t,e){this.container=t.container,this.graphDiv=t.graphDiv,this.pixelRatio=t.plotGlPixelRatio||window.devicePixelRatio,this.id=t.id,this.staticPlot=!!t.staticPlot,this.scrollZoom=this.graphDiv._context._scrollZoom.cartesian,this.fullData=null,this.updateRefs(e),this.makeFramework(),this.stopped||(this.glplotOptions=h(this),this.glplotOptions.merge(e),this.glplot=l(this.glplotOptions),this.camera=p(this),this.traces={},this.spikes=c(this.glplot),this.selectBox=u(this.glplot,{innerFill:!1,outerFill:!0}),this.lastButtonState=0,this.pickResult=null,this.isMouseOver=!0,this.stopped=!1,this.redraw=this.draw.bind(this),this.redraw())}e.exports=k;var M=k.prototype;M.makeFramework=function(){if(this.staticPlot){if(!(i||(n=document.createElement(\"canvas\"),i=f({canvas:n,preserveDrawingBuffer:!1,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"Error creating static canvas/context for image server\");this.canvas=n,this.gl=i}else{var t=this.container.querySelector(\".gl-canvas-focus\"),e=f({canvas:t,preserveDrawingBuffer:!0,premultipliedAlpha:!0});if(!e)return d(this),void(this.stopped=!0);this.canvas=t,this.gl=e}var r=this.canvas;r.style.width=\"100%\",r.style.height=\"100%\",r.style.position=\"absolute\",r.style.top=\"0px\",r.style.left=\"0px\",r.style[\"pointer-events\"]=\"none\",this.updateSize(r);var a=this.svgContainer=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");a.style.position=\"absolute\",a.style.top=a.style.left=\"0px\",a.style.width=a.style.height=\"100%\",a.style[\"z-index\"]=20,a.style[\"pointer-events\"]=\"none\";var o=this.mouseContainer=document.createElement(\"div\");o.style.position=\"absolute\",o.style[\"pointer-events\"]=\"auto\",this.pickCanvas=this.container.querySelector(\".gl-canvas-pick\");var s=this.container;s.appendChild(a),s.appendChild(o);var l=this;o.addEventListener(\"mouseout\",(function(){l.isMouseOver=!1,l.unhover()})),o.addEventListener(\"mouseover\",(function(){l.isMouseOver=!0}))},M.toImage=function(t){t||(t=\"png\"),this.stopped=!0,this.staticPlot&&this.container.appendChild(n),this.updateSize(this.canvas);var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.clearColor(1,1,1,0),e.clear(e.COLOR_BUFFER_BIT|e.DEPTH_BUFFER_BIT),this.glplot.setDirty(),this.glplot.draw(),e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a);for(var o=0,s=i-1;o<s;++o,--s)for(var l=0;l<r;++l)for(var c=0;c<4;++c){var u=a[4*(r*o+l)+c];a[4*(r*o+l)+c]=a[4*(r*s+l)+c],a[4*(r*s+l)+c]=u}var f=document.createElement(\"canvas\");f.width=r,f.height=i;var h,p=f.getContext(\"2d\"),d=p.createImageData(r,i);switch(d.data.set(a),p.putImageData(d,0,0),t){case\"jpeg\":h=f.toDataURL(\"image/jpeg\");break;case\"webp\":h=f.toDataURL(\"image/webp\");break;default:h=f.toDataURL(\"image/png\")}return this.staticPlot&&this.container.removeChild(n),h},M.updateSize=function(t){t||(t=this.canvas);var e=this.pixelRatio,r=this.fullLayout,n=r.width,i=r.height,a=0|Math.ceil(e*n),o=0|Math.ceil(e*i);return t.width===a&&t.height===o||(t.width=a,t.height=o),t},M.computeTickMarks=function(){this.xaxis.setScale(),this.yaxis.setScale();for(var t=[o.calcTicks(this.xaxis),o.calcTicks(this.yaxis)],e=0;e<2;++e)for(var r=0;r<t[e].length;++r)t[e][r].text=t[e][r].text+\"\";return t},M.updateRefs=function(t){this.fullLayout=t;var e=this.id.match(T),r=\"xaxis\"+e[1],n=\"yaxis\"+e[2];this.xaxis=this.fullLayout[r],this.yaxis=this.fullLayout[n]},M.relayoutCallback=function(){var t=this.graphDiv,e=this.xaxis,r=this.yaxis,n=t.layout,i={},o=i[e._name+\".range\"]=e.range.slice(),s=i[r._name+\".range\"]=r.range.slice();i[e._name+\".autorange\"]=e.autorange,i[r._name+\".autorange\"]=r.autorange,a.call(\"_storeDirectGUIEdit\",t.layout,t._fullLayout._preGUI,i);var l=n[e._name];l.range=o,l.autorange=e.autorange;var c=n[r._name];c.range=s,c.autorange=r.autorange,i.lastInputTime=this.camera.lastInputTime,t.emit(\"plotly_relayout\",i)},M.cameraChanged=function(){var t=this.camera;this.glplot.setDataBox(this.calcDataBox());var e=this.computeTickMarks();(function(t,e){for(var r=0;r<2;++r){var n=t[r],i=e[r];if(n.length!==i.length)return!0;for(var a=0;a<n.length;++a)if(n[a].x!==i[a].x)return!0}return!1})(e,this.glplotOptions.ticks)&&(this.glplotOptions.ticks=e,this.glplotOptions.dataBox=t.dataBox,this.glplot.update(this.glplotOptions),this.handleAnnotations())},M.handleAnnotations=function(){for(var t=this.graphDiv,e=this.fullLayout.annotations,r=0;r<e.length;r++){var n=e[r];n.xref===this.xaxis._id&&n.yref===this.yaxis._id&&a.getComponentMethod(\"annotations\",\"drawOne\")(t,r)}},M.destroy=function(){if(this.glplot){var t=this.traces;t&&Object.keys(t).map((function(e){t[e].dispose(),delete t[e]})),this.glplot.dispose(),this.container.removeChild(this.svgContainer),this.container.removeChild(this.mouseContainer),this.fullData=null,this.glplot=null,this.stopped=!0,this.camera.mouseListener.enabled=!1,this.mouseContainer.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null}},M.plot=function(t,e,r){var n=this.glplot;this.updateRefs(r),this.xaxis.clearCalc(),this.yaxis.clearCalc(),this.updateTraces(t,e),this.updateFx(r.dragmode);var i=r.width,a=r.height;this.updateSize(this.canvas);var o=this.glplotOptions;o.merge(r),o.screenBox=[0,0,i,a];var s={_fullLayout:{_axisConstraintGroups:this.graphDiv._fullLayout._axisConstraintGroups,xaxis:this.xaxis,yaxis:this.yaxis}};v(s,this.xaxis),v(s,this.yaxis);var l,c,u=r._size,f=this.xaxis.domain,h=this.yaxis.domain;for(o.viewBox=[u.l+f[0]*u.w,u.b+h[0]*u.h,i-u.r-(1-f[1])*u.w,a-u.t-(1-h[1])*u.h],this.mouseContainer.style.width=u.w*(f[1]-f[0])+\"px\",this.mouseContainer.style.height=u.h*(h[1]-h[0])+\"px\",this.mouseContainer.height=u.h*(h[1]-h[0]),this.mouseContainer.style.left=u.l+f[0]*u.w+\"px\",this.mouseContainer.style.top=u.t+(1-h[1])*u.h+\"px\",c=0;c<2;++c)(l=this[w[c]])._length=o.viewBox[c+2]-o.viewBox[c],y(this.graphDiv,l),l.setScale();m(s),o.ticks=this.computeTickMarks(),o.dataBox=this.calcDataBox(),o.merge(r),n.update(o),this.glplot.draw()},M.calcDataBox=function(){var t=this.xaxis,e=this.yaxis,r=t.range,n=e.range,i=t.r2l,a=e.r2l;return[i(r[0]),a(n[0]),i(r[1]),a(n[1])]},M.setRanges=function(t){var e=this.xaxis,r=this.yaxis,n=e.l2r,i=r.l2r;e.range=[n(t[0]),n(t[2])],r.range=[i(t[1]),i(t[3])]},M.updateTraces=function(t,e){var r,n,i,a=Object.keys(this.traces);this.fullData=t;t:for(r=0;r<a.length;r++){var o=a[r],s=this.traces[o];for(n=0;n<t.length;n++)if((i=t[n]).uid===o&&i.type===s.type)continue t;s.dispose(),delete this.traces[o]}for(r=0;r<t.length;r++){i=t[r];var l=e[r],c=this.traces[i.uid];c?c.update(i,l):(c=i._module.plot(this,i,l),this.traces[i.uid]=c)}this.glplot.objects.sort((function(t,e){return t._trace.index-e._trace.index}))},M.updateFx=function(t){_(t)||b(t)?(this.pickCanvas.style[\"pointer-events\"]=\"none\",this.mouseContainer.style[\"pointer-events\"]=\"none\"):(this.pickCanvas.style[\"pointer-events\"]=\"auto\",this.mouseContainer.style[\"pointer-events\"]=\"auto\"),this.mouseContainer.style.cursor=\"pan\"===t?\"move\":\"zoom\"===t?\"crosshair\":null},M.emitPointAction=function(t,e){for(var r,n=t.trace.uid,i=t.pointIndex,a=0;a<this.fullData.length;a++)this.fullData[a].uid===n&&(r=this.fullData[a]);var o={x:t.traceCoord[0],y:t.traceCoord[1],curveNumber:r.index,pointNumber:i,data:r._input,fullData:this.fullData,xaxis:this.xaxis,yaxis:this.yaxis};s.appendArrayPointValue(o,r,i),this.graphDiv.emit(e,{points:[o]})},M.draw=function(){if(!this.stopped){requestAnimationFrame(this.redraw);var t=this.glplot,e=this.camera,r=e.mouseListener,n=1===this.lastButtonState&&0===r.buttons,i=this.fullLayout;this.lastButtonState=r.buttons,this.cameraChanged();var a,o=r.x*t.pixelRatio,l=this.canvas.height-t.pixelRatio*r.y;if(e.boxEnabled&&\"zoom\"===i.dragmode){this.selectBox.enabled=!0;for(var c=this.selectBox.selectBox=[Math.min(e.boxStart[0],e.boxEnd[0]),Math.min(e.boxStart[1],e.boxEnd[1]),Math.max(e.boxStart[0],e.boxEnd[0]),Math.max(e.boxStart[1],e.boxEnd[1])],u=0;u<2;u++)e.boxStart[u]===e.boxEnd[u]&&(c[u]=t.dataBox[u],c[u+2]=t.dataBox[u+2]);t.setDirty()}else if(!e.panning&&this.isMouseOver){this.selectBox.enabled=!1;var f=i._size,h=this.xaxis.domain,p=this.yaxis.domain,d=(a=t.pick(o/t.pixelRatio+f.l+h[0]*f.w,l/t.pixelRatio-(f.t+(1-p[1])*f.h)))&&a.object._trace.handlePick(a);if(d&&n&&this.emitPointAction(d,\"plotly_click\"),a&&\"skip\"!==a.object._trace.hoverinfo&&i.hovermode&&d&&(!this.lastPickResult||this.lastPickResult.traceUid!==d.trace.uid||this.lastPickResult.dataCoord[0]!==d.dataCoord[0]||this.lastPickResult.dataCoord[1]!==d.dataCoord[1])){var g=d;this.lastPickResult={traceUid:d.trace?d.trace.uid:null,dataCoord:d.dataCoord.slice()},this.spikes.update({center:a.dataCoord}),g.screenCoord=[((t.viewBox[2]-t.viewBox[0])*(a.dataCoord[0]-t.dataBox[0])/(t.dataBox[2]-t.dataBox[0])+t.viewBox[0])/t.pixelRatio,(this.canvas.height-(t.viewBox[3]-t.viewBox[1])*(a.dataCoord[1]-t.dataBox[1])/(t.dataBox[3]-t.dataBox[1])-t.viewBox[1])/t.pixelRatio],this.emitPointAction(d,\"plotly_hover\");var m=this.fullData[g.trace.index]||{},v=g.pointIndex,y=s.castHoverinfo(m,i,v);if(y&&\"all\"!==y){var x=y.split(\"+\");-1===x.indexOf(\"x\")&&(g.traceCoord[0]=void 0),-1===x.indexOf(\"y\")&&(g.traceCoord[1]=void 0),-1===x.indexOf(\"z\")&&(g.traceCoord[2]=void 0),-1===x.indexOf(\"text\")&&(g.textLabel=void 0),-1===x.indexOf(\"name\")&&(g.name=void 0)}s.loneHover({x:g.screenCoord[0],y:g.screenCoord[1],xLabel:this.hoverFormatter(\"xaxis\",g.traceCoord[0]),yLabel:this.hoverFormatter(\"yaxis\",g.traceCoord[1]),zLabel:g.traceCoord[2],text:g.textLabel,name:g.name,color:s.castHoverOption(m,v,\"bgcolor\")||g.color,borderColor:s.castHoverOption(m,v,\"bordercolor\"),fontFamily:s.castHoverOption(m,v,\"font.family\"),fontSize:s.castHoverOption(m,v,\"font.size\"),fontColor:s.castHoverOption(m,v,\"font.color\"),nameLength:s.castHoverOption(m,v,\"namelength\"),textAlign:s.castHoverOption(m,v,\"align\")},{container:this.svgContainer,gd:this.graphDiv})}}a||this.unhover(),t.draw()}},M.unhover=function(){this.lastPickResult&&(this.spikes.update({}),this.lastPickResult=null,this.graphDiv.emit(\"plotly_unhover\"),s.loneUnhover(this.svgContainer))},M.hoverFormatter=function(t,e){if(void 0!==e){var r=this[t];return o.tickText(r,r.c2l(e),\"hover\").text}}},{\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib/show_no_webgl_msg\":800,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/constants\":834,\"../cartesian/constraints\":835,\"./camera\":866,\"./convert\":867,\"gl-plot2d\":317,\"gl-select-box\":333,\"gl-spikes2d\":342,\"webgl-context\":606}],870:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../components/fx/layout_attributes\"),a=t(\"./scene\"),o=t(\"../get_data\").getSubplotData,s=t(\"../../lib\"),l=t(\"../../constants/xmlns_namespaces\");r.name=\"gl3d\",r.attr=\"scene\",r.idRoot=\"scene\",r.idRegex=r.attrRegex=s.counterRegex(\"scene\"),r.attributes=t(\"./layout/attributes\"),r.layoutAttributes=t(\"./layout/layout_attributes\"),r.baseLayoutAttrOverrides=n({hoverlabel:i.hoverlabel},\"plot\",\"nested\"),r.supplyLayoutDefaults=t(\"./layout/defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t._fullData,n=e._subplots.gl3d,i=0;i<n.length;i++){var s=n[i],l=o(r,\"gl3d\",s),c=e[s],u=c.camera,f=c._scene;f||(f=new a({id:s,graphDiv:t,container:t.querySelector(\".gl-container\"),staticPlot:t._context.staticPlot,plotGlPixelRatio:t._context.plotGlPixelRatio,camera:u},e),c._scene=f),f.viewInitial||(f.viewInitial={up:{x:u.up.x,y:u.up.y,z:u.up.z},eye:{x:u.eye.x,y:u.eye.y,z:u.eye.z},center:{x:u.center.x,y:u.center.y,z:u.center.z}}),f.plot(l,e,t.layout)}},r.clean=function(t,e,r,n){for(var i=n._subplots.gl3d||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._scene&&(n[o]._scene.destroy(),n._infolayer&&n._infolayer.selectAll(\".annotation-\"+o).remove())}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=e._size,i=0;i<r.length;i++){var a=e[r[i]],o=a.domain,s=a._scene,c=s.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":c,x:n.l+n.w*o.x[0],y:n.t+n.h*(1-o.y[1]),width:n.w*(o.x[1]-o.x[0]),height:n.h*(o.y[1]-o.y[0]),preserveAspectRatio:\"none\"}),s.destroy()}},r.cleanId=function(t){if(t.match(/^scene[0-9]*$/)){var e=t.substr(5);return\"1\"===e&&(e=\"\"),\"scene\"+e}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.gl3d,n=0;n<r.length;n++){e[r[n]]._scene.updateFx(e.dragmode,e.hovermode)}}},{\"../../components/fx/layout_attributes\":684,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../get_data\":865,\"./layout/attributes\":871,\"./layout/defaults\":875,\"./layout/layout_attributes\":876,\"./scene\":880}],871:[function(t,e,r){\"use strict\";e.exports={scene:{valType:\"subplotid\",dflt:\"scene\",editType:\"calc+clearAxisTypes\"}}},{}],872:[function(t,e,r){\"use strict\";var n=t(\"../../../components/color\"),i=t(\"../../cartesian/layout_attributes\"),a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../plot_api/edit_types\").overrideAll;e.exports=o({visible:i.visible,showspikes:{valType:\"boolean\",dflt:!0},spikesides:{valType:\"boolean\",dflt:!0},spikethickness:{valType:\"number\",min:0,dflt:2},spikecolor:{valType:\"color\",dflt:n.defaultLine},showbackground:{valType:\"boolean\",dflt:!1},backgroundcolor:{valType:\"color\",dflt:\"rgba(204, 204, 204, 0.5)\"},showaxeslabels:{valType:\"boolean\",dflt:!0},color:i.color,categoryorder:i.categoryorder,categoryarray:i.categoryarray,title:{text:i.title.text,font:i.title.font},type:a({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:i.autorange,rangemode:i.rangemode,range:a({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],anim:!1}),tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,mirror:i.mirror,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,tickfont:i.tickfont,tickangle:i.tickangle,tickprefix:i.tickprefix,showtickprefix:i.showtickprefix,ticksuffix:i.ticksuffix,showticksuffix:i.showticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickformat:i.tickformat,tickformatstops:i.tickformatstops,hoverformat:i.hoverformat,showline:i.showline,linecolor:i.linecolor,linewidth:i.linewidth,showgrid:i.showgrid,gridcolor:a({},i.gridcolor,{dflt:\"rgb(204, 204, 204)\"}),gridwidth:i.gridwidth,zeroline:i.zeroline,zerolinecolor:i.zerolinecolor,zerolinewidth:i.zerolinewidth,_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}},\"plot\",\"from-root\")},{\"../../../components/color\":643,\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],873:[function(t,e,r){\"use strict\";var n=t(\"tinycolor2\").mix,i=t(\"../../../lib\"),a=t(\"../../../plot_api/plot_template\"),o=t(\"./axis_attributes\"),s=t(\"../../cartesian/type_defaults\"),l=t(\"../../cartesian/axis_defaults\"),c=[\"xaxis\",\"yaxis\",\"zaxis\"];e.exports=function(t,e,r){var u,f;function h(t,e){return i.coerce(u,f,o,t,e)}for(var p=0;p<c.length;p++){var d=c[p];u=t[d]||{},(f=a.newContainer(e,d))._id=d[0]+r.scene,f._name=d,s(u,f,h,r),l(u,f,h,{font:r.font,letter:d[0],data:r.data,showGrid:!0,noTickson:!0,noTicklabelmode:!0,noTicklabelposition:!0,bgColor:r.bgColor,calendar:r.calendar},r.fullLayout),h(\"gridcolor\",n(f.color,r.bgColor,13600/187).toRgbString()),h(\"title.text\",d[0]),f.setScale=i.noop,h(\"showspikes\")&&(h(\"spikesides\"),h(\"spikethickness\"),h(\"spikecolor\",f.color)),h(\"showaxeslabels\"),h(\"showbackground\")&&h(\"backgroundcolor\")}}},{\"../../../lib\":778,\"../../../plot_api/plot_template\":817,\"../../cartesian/axis_defaults\":830,\"../../cartesian/type_defaults\":853,\"./axis_attributes\":872,tinycolor2:576}],874:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"];function o(){this.bounds=[[-10,-10,-10],[10,10,10]],this.ticks=[[],[],[]],this.tickEnable=[!0,!0,!0],this.tickFont=[\"sans-serif\",\"sans-serif\",\"sans-serif\"],this.tickSize=[12,12,12],this.tickAngle=[0,0,0],this.tickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.tickPad=[18,18,18],this.labels=[\"x\",\"y\",\"z\"],this.labelEnable=[!0,!0,!0],this.labelFont=[\"Open Sans\",\"Open Sans\",\"Open Sans\"],this.labelSize=[20,20,20],this.labelColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.labelPad=[30,30,30],this.lineEnable=[!0,!0,!0],this.lineMirror=[!1,!1,!1],this.lineWidth=[1,1,1],this.lineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.lineTickEnable=[!0,!0,!0],this.lineTickMirror=[!1,!1,!1],this.lineTickLength=[10,10,10],this.lineTickWidth=[1,1,1],this.lineTickColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.gridEnable=[!0,!0,!0],this.gridWidth=[1,1,1],this.gridColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroEnable=[!0,!0,!0],this.zeroLineColor=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.zeroLineWidth=[2,2,2],this.backgroundEnable=[!0,!0,!0],this.backgroundColor=[[.8,.8,.8,.5],[.8,.8,.8,.5],[.8,.8,.8,.5]],this._defaultTickPad=this.tickPad.slice(),this._defaultLabelPad=this.labelPad.slice(),this._defaultLineTickLength=this.lineTickLength.slice()}o.prototype.merge=function(t,e){for(var r=0;r<3;++r){var o=e[a[r]];o.visible?(this.labels[r]=t._meta?i.templateString(o.title.text,t._meta):o.title.text,\"font\"in o.title&&(o.title.font.color&&(this.labelColor[r]=n(o.title.font.color)),o.title.font.family&&(this.labelFont[r]=o.title.font.family),o.title.font.size&&(this.labelSize[r]=o.title.font.size)),\"showline\"in o&&(this.lineEnable[r]=o.showline),\"linecolor\"in o&&(this.lineColor[r]=n(o.linecolor)),\"linewidth\"in o&&(this.lineWidth[r]=o.linewidth),\"showgrid\"in o&&(this.gridEnable[r]=o.showgrid),\"gridcolor\"in o&&(this.gridColor[r]=n(o.gridcolor)),\"gridwidth\"in o&&(this.gridWidth[r]=o.gridwidth),\"log\"===o.type?this.zeroEnable[r]=!1:\"zeroline\"in o&&(this.zeroEnable[r]=o.zeroline),\"zerolinecolor\"in o&&(this.zeroLineColor[r]=n(o.zerolinecolor)),\"zerolinewidth\"in o&&(this.zeroLineWidth[r]=o.zerolinewidth),\"ticks\"in o&&o.ticks?this.lineTickEnable[r]=!0:this.lineTickEnable[r]=!1,\"ticklen\"in o&&(this.lineTickLength[r]=this._defaultLineTickLength[r]=o.ticklen),\"tickcolor\"in o&&(this.lineTickColor[r]=n(o.tickcolor)),\"tickwidth\"in o&&(this.lineTickWidth[r]=o.tickwidth),\"tickangle\"in o&&(this.tickAngle[r]=\"auto\"===o.tickangle?-3600:Math.PI*-o.tickangle/180),\"showticklabels\"in o&&(this.tickEnable[r]=o.showticklabels),\"tickfont\"in o&&(o.tickfont.color&&(this.tickColor[r]=n(o.tickfont.color)),o.tickfont.family&&(this.tickFont[r]=o.tickfont.family),o.tickfont.size&&(this.tickSize[r]=o.tickfont.size)),\"mirror\"in o?-1!==[\"ticks\",\"all\",\"allticks\"].indexOf(o.mirror)?(this.lineTickMirror[r]=!0,this.lineMirror[r]=!0):!0===o.mirror?(this.lineTickMirror[r]=!1,this.lineMirror[r]=!0):(this.lineTickMirror[r]=!1,this.lineMirror[r]=!1):this.lineMirror[r]=!1,\"showbackground\"in o&&!1!==o.showbackground?(this.backgroundEnable[r]=!0,this.backgroundColor[r]=n(o.backgroundcolor)):this.backgroundEnable[r]=!1):(this.tickEnable[r]=!1,this.labelEnable[r]=!1,this.lineEnable[r]=!1,this.lineTickEnable[r]=!1,this.gridEnable[r]=!1,this.zeroEnable[r]=!1,this.backgroundEnable[r]=!1)}},e.exports=function(t,e){var r=new o;return r.merge(t,e),r}},{\"../../../lib\":778,\"../../../lib/str2rgbarray\":802}],875:[function(t,e,r){\"use strict\";var n=t(\"../../../lib\"),i=t(\"../../../components/color\"),a=t(\"../../../registry\"),o=t(\"../../subplot_defaults\"),s=t(\"./axis_defaults\"),l=t(\"./layout_attributes\"),c=t(\"../../get_data\").getSubplotData;function u(t,e,r,n){for(var o=r(\"bgcolor\"),l=i.combine(o,n.paper_bgcolor),u=[\"up\",\"center\",\"eye\"],f=0;f<u.length;f++)r(\"camera.\"+u[f]+\".x\"),r(\"camera.\"+u[f]+\".y\"),r(\"camera.\"+u[f]+\".z\");r(\"camera.projection.type\");var h=!!r(\"aspectratio.x\")&&!!r(\"aspectratio.y\")&&!!r(\"aspectratio.z\"),p=r(\"aspectmode\",h?\"manual\":\"auto\");h||(t.aspectratio=e.aspectratio={x:1,y:1,z:1},\"manual\"===p&&(e.aspectmode=\"auto\"),t.aspectmode=e.aspectmode);var d=c(n.fullData,\"gl3d\",n.id);s(t,e,{font:n.font,scene:n.id,data:d,bgColor:l,calendar:n.calendar,autotypenumbersDflt:n.autotypenumbersDflt,fullLayout:n.fullLayout}),a.getComponentMethod(\"annotations3d\",\"handleDefaults\")(t,e,n);var g=n.getDfltFromLayout(\"dragmode\");if(!1!==g&&!g)if(g=\"orbit\",t.camera&&t.camera.up){var m=t.camera.up.x,v=t.camera.up.y,y=t.camera.up.z;0!==y&&(m&&v&&y?y/Math.sqrt(m*m+v*v+y*y)>.999&&(g=\"turntable\"):g=\"turntable\")}else g=\"turntable\";r(\"dragmode\",g),r(\"hovermode\",n.getDfltFromLayout(\"hovermode\"))}e.exports=function(t,e,r){var i=e._basePlotModules.length>1;o(t,e,r,{type:\"gl3d\",attributes:l,handleDefaults:u,fullLayout:e,font:e.font,fullData:r,getDfltFromLayout:function(e){if(!i)return n.validate(t[e],l[e])?t[e]:void 0},autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,calendar:e.calendar})}},{\"../../../components/color\":643,\"../../../lib\":778,\"../../../registry\":911,\"../../get_data\":865,\"../../subplot_defaults\":905,\"./axis_defaults\":873,\"./layout_attributes\":876}],876:[function(t,e,r){\"use strict\";var n=t(\"./axis_attributes\"),i=t(\"../../domain\").attributes,a=t(\"../../../lib/extend\").extendFlat,o=t(\"../../../lib\").counterRegex;function s(t,e,r){return{x:{valType:\"number\",dflt:t,editType:\"camera\"},y:{valType:\"number\",dflt:e,editType:\"camera\"},z:{valType:\"number\",dflt:r,editType:\"camera\"},editType:\"camera\"}}e.exports={_arrayAttrRegexps:[o(\"scene\",\".annotations\",!0)],bgcolor:{valType:\"color\",dflt:\"rgba(0,0,0,0)\",editType:\"plot\"},camera:{up:a(s(0,0,1),{}),center:a(s(0,0,0),{}),eye:a(s(1.25,1.25,1.25),{}),projection:{type:{valType:\"enumerated\",values:[\"perspective\",\"orthographic\"],dflt:\"perspective\",editType:\"calc\"},editType:\"calc\"},editType:\"camera\"},domain:i({name:\"scene\",editType:\"plot\"}),aspectmode:{valType:\"enumerated\",values:[\"auto\",\"cube\",\"data\",\"manual\"],dflt:\"auto\",editType:\"plot\",impliedEdits:{\"aspectratio.x\":void 0,\"aspectratio.y\":void 0,\"aspectratio.z\":void 0}},aspectratio:{x:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},y:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},z:{valType:\"number\",min:0,editType:\"plot\",impliedEdits:{\"^aspectmode\":\"manual\"}},editType:\"plot\",impliedEdits:{aspectmode:\"manual\"}},xaxis:n,yaxis:n,zaxis:n,dragmode:{valType:\"enumerated\",values:[\"orbit\",\"turntable\",\"zoom\",\"pan\",!1],editType:\"plot\"},hovermode:{valType:\"enumerated\",values:[\"closest\",!1],dflt:\"closest\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"plot\",_deprecated:{cameraposition:{valType:\"info_array\",editType:\"camera\"}}}},{\"../../../lib\":778,\"../../../lib/extend\":768,\"../../domain\":855,\"./axis_attributes\":872}],877:[function(t,e,r){\"use strict\";var n=t(\"../../../lib/str2rgbarray\"),i=[\"xaxis\",\"yaxis\",\"zaxis\"];function a(){this.enabled=[!0,!0,!0],this.colors=[[0,0,0,1],[0,0,0,1],[0,0,0,1]],this.drawSides=[!0,!0,!0],this.lineWidth=[1,1,1]}a.prototype.merge=function(t){for(var e=0;e<3;++e){var r=t[i[e]];r.visible?(this.enabled[e]=r.showspikes,this.colors[e]=n(r.spikecolor),this.drawSides[e]=r.spikesides,this.lineWidth[e]=r.spikethickness):(this.enabled[e]=!1,this.drawSides[e]=!1)}},e.exports=function(t){var e=new a;return e.merge(t),e}},{\"../../../lib/str2rgbarray\":802}],878:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=t.axesOptions,r=t.glplot.axesPixels,s=t.fullSceneLayout,l=[[],[],[]],c=0;c<3;++c){var u=s[a[c]];if(u._length=(r[c].hi-r[c].lo)*r[c].pixelsPerDataUnit/t.dataScale[c],Math.abs(u._length)===1/0||isNaN(u._length))l[c]=[];else{u._input_range=u.range.slice(),u.range[0]=r[c].lo/t.dataScale[c],u.range[1]=r[c].hi/t.dataScale[c],u._m=1/(t.dataScale[c]*r[c].pixelsPerDataUnit),u.range[0]===u.range[1]&&(u.range[0]-=1,u.range[1]+=1);var f=u.tickmode;if(\"auto\"===u.tickmode){u.tickmode=\"linear\";var h=u.nticks||i.constrain(u._length/40,4,9);n.autoTicks(u,Math.abs(u.range[1]-u.range[0])/h)}for(var p=n.calcTicks(u,{msUTC:!0}),d=0;d<p.length;++d)p[d].x=p[d].x*t.dataScale[c],\"date\"===u.type&&(p[d].text=p[d].text.replace(/\\<br\\>/g,\" \"));l[c]=p,u.tickmode=f}}e.ticks=l;for(c=0;c<3;++c){o[c]=.5*(t.glplot.bounds[0][c]+t.glplot.bounds[1][c]);for(d=0;d<2;++d)e.bounds[d][c]=t.glplot.bounds[d][c]}t.contourLevels=function(t){for(var e=new Array(3),r=0;r<3;++r){for(var n=t[r],i=new Array(n.length),a=0;a<n.length;++a)i[a]=n[a].x;e[r]=i}return e}(l)};var n=t(\"../../cartesian/axes\"),i=t(\"../../../lib\"),a=[\"xaxis\",\"yaxis\",\"zaxis\"],o=[0,0,0]},{\"../../../lib\":778,\"../../cartesian/axes\":828}],879:[function(t,e,r){\"use strict\";function n(t,e){var r,n,i=[0,0,0,0];for(r=0;r<4;++r)for(n=0;n<4;++n)i[n]+=t[4*r+n]*e[r];return i}e.exports=function(t,e){return n(t.projection,n(t.view,n(t.model,[e[0],e[1],e[2],1])))}},{}],880:[function(t,e,r){\"use strict\";var n,i,a=t(\"gl-plot3d\"),o=a.createCamera,s=a.createScene,l=t(\"webgl-context\"),c=t(\"has-passive-events\"),u=t(\"../../registry\"),f=t(\"../../lib\"),h=f.preserveDrawingBuffer(),p=t(\"../../plots/cartesian/axes\"),d=t(\"../../components/fx\"),g=t(\"../../lib/str2rgbarray\"),m=t(\"../../lib/show_no_webgl_msg\"),v=t(\"./project\"),y=t(\"./layout/convert\"),x=t(\"./layout/spikes\"),b=t(\"./layout/tick_marks\");function _(t,e){var r=document.createElement(\"div\"),n=t.container;this.graphDiv=t.graphDiv;var i=document.createElementNS(\"http://www.w3.org/2000/svg\",\"svg\");i.style.position=\"absolute\",i.style.top=i.style.left=\"0px\",i.style.width=i.style.height=\"100%\",i.style[\"z-index\"]=20,i.style[\"pointer-events\"]=\"none\",r.appendChild(i),this.svgContainer=i,r.id=t.id,r.style.position=\"absolute\",r.style.top=r.style.left=\"0px\",r.style.width=r.style.height=\"100%\",n.appendChild(r),this.fullLayout=e,this.id=t.id||\"scene\",this.fullSceneLayout=e[this.id],this.plotArgs=[[],{},{}],this.axesOptions=y(e,e[this.id]),this.spikeOptions=x(e[this.id]),this.container=r,this.staticMode=!!t.staticPlot,this.pixelRatio=this.pixelRatio||t.plotGlPixelRatio||2,this.dataScale=[1,1,1],this.contourLevels=[[],[],[]],this.convertAnnotations=u.getComponentMethod(\"annotations3d\",\"convert\"),this.drawAnnotations=u.getComponentMethod(\"annotations3d\",\"draw\"),this.initializeGLPlot()}var w=_.prototype;w.prepareOptions=function(){var t={canvas:this.canvas,gl:this.gl,glOptions:{preserveDrawingBuffer:h,premultipliedAlpha:!0,antialias:!0},container:this.container,axes:this.axesOptions,spikes:this.spikeOptions,pickRadius:10,snapToData:!0,autoScale:!0,autoBounds:!1,cameraObject:this.camera,pixelRatio:this.pixelRatio};if(this.staticMode){if(!(i||(n=document.createElement(\"canvas\"),i=l({canvas:n,preserveDrawingBuffer:!0,premultipliedAlpha:!0,antialias:!0}))))throw new Error(\"error creating static canvas/context for image server\");t.gl=i,t.canvas=n}return t};var T=!0;w.tryCreatePlot=function(){var t=this.prepareOptions(),e=!0;try{this.glplot=s(t)}catch(r){if(this.staticMode||!T||h)e=!1;else{f.warn([\"webgl setup failed possibly due to\",\"false preserveDrawingBuffer config.\",\"The mobile/tablet device may not be detected by is-mobile module.\",\"Enabling preserveDrawingBuffer in second attempt to create webgl scene...\"].join(\" \"));try{h=t.glOptions.preserveDrawingBuffer=!0,this.glplot=s(t)}catch(r){h=t.glOptions.preserveDrawingBuffer=!1,e=!1}}}return T=!1,e},w.initializeGLCamera=function(){var t=this.fullSceneLayout.camera,e=\"orthographic\"===t.projection.type;this.camera=o(this.container,{center:[t.center.x,t.center.y,t.center.z],eye:[t.eye.x,t.eye.y,t.eye.z],up:[t.up.x,t.up.y,t.up.z],_ortho:e,zoomMin:.01,zoomMax:100,mode:\"orbit\"})},w.initializeGLPlot=function(){var t=this;if(t.initializeGLCamera(),!t.tryCreatePlot())return m(t);t.traces={},t.make4thDimension();var e=t.graphDiv,r=e.layout,n=function(){var e={};return t.isCameraChanged(r)&&(e[t.id+\".camera\"]=t.getCamera()),t.isAspectChanged(r)&&(e[t.id+\".aspectratio\"]=t.glplot.getAspectratio(),\"manual\"!==r[t.id].aspectmode&&(t.fullSceneLayout.aspectmode=r[t.id].aspectmode=e[t.id+\".aspectmode\"]=\"manual\")),e},i=function(t){if(!1!==t.fullSceneLayout.dragmode){var e=n();t.saveLayout(r),t.graphDiv.emit(\"plotly_relayout\",e)}};return t.glplot.canvas&&(t.glplot.canvas.addEventListener(\"mouseup\",(function(){i(t)})),t.glplot.canvas.addEventListener(\"wheel\",(function(r){if(e._context._scrollZoom.gl3d){if(t.camera._ortho){var n=r.deltaX>r.deltaY?1.1:1/1.1,a=t.glplot.getAspectratio();t.glplot.setAspectratio({x:n*a.x,y:n*a.y,z:n*a.z})}i(t)}}),!!c&&{passive:!1}),t.glplot.canvas.addEventListener(\"mousemove\",(function(){if(!1!==t.fullSceneLayout.dragmode&&0!==t.camera.mouseListener.buttons){var e=n();t.graphDiv.emit(\"plotly_relayouting\",e)}})),t.staticMode||t.glplot.canvas.addEventListener(\"webglcontextlost\",(function(r){e&&e.emit&&e.emit(\"plotly_webglcontextlost\",{event:r,layer:t.id})}),!1)),t.glplot.oncontextloss=function(){t.recoverContext()},t.glplot.onrender=function(){t.render()},!0},w.render=function(){var t,e=this,r=e.graphDiv,n=e.svgContainer,i=e.container.getBoundingClientRect();r._fullLayout._calcInverseTransform(r);var a=r._fullLayout._invScaleX,o=r._fullLayout._invScaleY,s=i.width*a,l=i.height*o;n.setAttributeNS(null,\"viewBox\",\"0 0 \"+s+\" \"+l),n.setAttributeNS(null,\"width\",s),n.setAttributeNS(null,\"height\",l),b(e),e.glplot.axes.update(e.axesOptions);for(var c,u=Object.keys(e.traces),h=null,g=e.glplot.selection,m=0;m<u.length;++m)\"skip\"!==(t=e.traces[u[m]]).data.hoverinfo&&t.handlePick(g)&&(h=t),t.setContourLevels&&t.setContourLevels();function y(t,r){var n=e.fullSceneLayout[t];return p.tickText(n,n.d2l(r),\"hover\").text}if(null!==h){var x=v(e.glplot.cameraParams,g.dataCoordinate);t=h.data;var _,w=r._fullData[t.index],T=g.index,k={xLabel:y(\"xaxis\",g.traceCoordinate[0]),yLabel:y(\"yaxis\",g.traceCoordinate[1]),zLabel:y(\"zaxis\",g.traceCoordinate[2])},M=d.castHoverinfo(w,e.fullLayout,T),A=(M||\"\").split(\"+\"),S=M&&\"all\"===M;w.hovertemplate||S||(-1===A.indexOf(\"x\")&&(k.xLabel=void 0),-1===A.indexOf(\"y\")&&(k.yLabel=void 0),-1===A.indexOf(\"z\")&&(k.zLabel=void 0),-1===A.indexOf(\"text\")&&(g.textLabel=void 0),-1===A.indexOf(\"name\")&&(h.name=void 0));var E=[];\"cone\"===t.type||\"streamtube\"===t.type?(k.uLabel=y(\"xaxis\",g.traceCoordinate[3]),(S||-1!==A.indexOf(\"u\"))&&E.push(\"u: \"+k.uLabel),k.vLabel=y(\"yaxis\",g.traceCoordinate[4]),(S||-1!==A.indexOf(\"v\"))&&E.push(\"v: \"+k.vLabel),k.wLabel=y(\"zaxis\",g.traceCoordinate[5]),(S||-1!==A.indexOf(\"w\"))&&E.push(\"w: \"+k.wLabel),k.normLabel=g.traceCoordinate[6].toPrecision(3),(S||-1!==A.indexOf(\"norm\"))&&E.push(\"norm: \"+k.normLabel),\"streamtube\"===t.type&&(k.divergenceLabel=g.traceCoordinate[7].toPrecision(3),(S||-1!==A.indexOf(\"divergence\"))&&E.push(\"divergence: \"+k.divergenceLabel)),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):\"isosurface\"===t.type||\"volume\"===t.type?(k.valueLabel=p.tickText(e._mockAxis,e._mockAxis.d2l(g.traceCoordinate[3]),\"hover\").text,E.push(\"value: \"+k.valueLabel),g.textLabel&&E.push(g.textLabel),_=E.join(\"<br>\")):_=g.textLabel;var C={x:g.traceCoordinate[0],y:g.traceCoordinate[1],z:g.traceCoordinate[2],data:w._input,fullData:w,curveNumber:w.index,pointNumber:T};d.appendArrayPointValue(C,w,T),t._module.eventData&&(C=w._module.eventData(C,g,w,{},T));var L={points:[C]};e.fullSceneLayout.hovermode&&d.loneHover({trace:w,x:(.5+.5*x[0]/x[3])*s,y:(.5-.5*x[1]/x[3])*l,xLabel:k.xLabel,yLabel:k.yLabel,zLabel:k.zLabel,text:_,name:h.name,color:d.castHoverOption(w,T,\"bgcolor\")||h.color,borderColor:d.castHoverOption(w,T,\"bordercolor\"),fontFamily:d.castHoverOption(w,T,\"font.family\"),fontSize:d.castHoverOption(w,T,\"font.size\"),fontColor:d.castHoverOption(w,T,\"font.color\"),nameLength:d.castHoverOption(w,T,\"namelength\"),textAlign:d.castHoverOption(w,T,\"align\"),hovertemplate:f.castOption(w,T,\"hovertemplate\"),hovertemplateLabels:f.extendFlat({},C,k),eventData:[C]},{container:n,gd:r}),g.buttons&&g.distance<5?r.emit(\"plotly_click\",L):r.emit(\"plotly_hover\",L),c=L}else d.loneUnhover(n),r.emit(\"plotly_unhover\",c);e.drawAnnotations(e)},w.recoverContext=function(){var t=this;t.glplot.dispose();var e=function(){t.glplot.gl.isContextLost()?requestAnimationFrame(e):t.initializeGLPlot()?t.plot.apply(t,t.plotArgs):f.error(\"Catastrophic and unrecoverable WebGL error. Context lost.\")};requestAnimationFrame(e)};var k=[\"xaxis\",\"yaxis\",\"zaxis\"];function M(t,e,r){for(var n=t.fullSceneLayout,i=0;i<3;i++){var a=k[i],o=a.charAt(0),s=n[a],l=e[o],c=e[o+\"calendar\"],u=e[\"_\"+o+\"length\"];if(f.isArrayOrTypedArray(l))for(var h,p=0;p<(u||l.length);p++)if(f.isArrayOrTypedArray(l[p]))for(var d=0;d<l[p].length;++d)h=s.d2l(l[p][d],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else h=s.d2l(l[p],0,c),!isNaN(h)&&isFinite(h)&&(r[0][i]=Math.min(r[0][i],h),r[1][i]=Math.max(r[1][i],h));else r[0][i]=Math.min(r[0][i],0),r[1][i]=Math.max(r[1][i],u-1)}}w.plot=function(t,e,r){if(this.plotArgs=[t,e,r],!this.glplot.contextLost){var n,i,a,o,s,l,c=e[this.id],u=r[this.id];this.fullLayout=e,this.fullSceneLayout=c,this.axesOptions.merge(e,c),this.spikeOptions.merge(c),this.setViewport(c),this.updateFx(c.dragmode,c.hovermode),this.camera.enableWheel=this.graphDiv._context._scrollZoom.gl3d,this.glplot.setClearColor(g(c.bgcolor)),this.setConvert(s),t?Array.isArray(t)||(t=[t]):t=[];var f=[[1/0,1/0,1/0],[-1/0,-1/0,-1/0]];for(a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&M(this,n,f);!function(t,e){for(var r=t.fullSceneLayout,n=r.annotations||[],i=0;i<3;i++)for(var a=k[i],o=a.charAt(0),s=r[a],l=0;l<n.length;l++){var c=n[l];if(c.visible){var u=s.r2l(c[o]);!isNaN(u)&&isFinite(u)&&(e[0][i]=Math.min(e[0][i],u),e[1][i]=Math.max(e[1][i],u))}}}(this,f);var h=[1,1,1];for(o=0;o<3;++o)f[1][o]===f[0][o]?h[o]=1:h[o]=1/(f[1][o]-f[0][o]);for(this.dataScale=h,this.convertAnnotations(this),a=0;a<t.length;++a)!0===(n=t[a]).visible&&0!==n._length&&((i=this.traces[n.uid])?i.data.type===n.type?i.update(n):(i.dispose(),i=n._module.plot(this,n),this.traces[n.uid]=i):(i=n._module.plot(this,n),this.traces[n.uid]=i),i.name=n.name);var p=Object.keys(this.traces);t:for(a=0;a<p.length;++a){for(o=0;o<t.length;++o)if(t[o].uid===p[a]&&!0===t[o].visible&&0!==t[o]._length)continue t;(i=this.traces[p[a]]).dispose(),delete this.traces[p[a]]}this.glplot.objects.sort((function(t,e){return t._trace.data.index-e._trace.data.index}));var d,m=[[0,0,0],[0,0,0]],v=[],y={};for(a=0;a<3;++a){if((l=(s=c[k[a]]).type)in y?(y[l].acc*=h[a],y[l].count+=1):y[l]={acc:h[a],count:1},s.autorange){m[0][a]=1/0,m[1][a]=-1/0;var x=this.glplot.objects,b=this.fullSceneLayout.annotations||[],_=s._name.charAt(0);for(o=0;o<x.length;o++){var w=x[o],T=w.bounds,A=w._trace.data._pad||0;\"ErrorBars\"===w.constructor.name&&s._lowerLogErrorBound?m[0][a]=Math.min(m[0][a],s._lowerLogErrorBound):m[0][a]=Math.min(m[0][a],T[0][a]/h[a]-A),m[1][a]=Math.max(m[1][a],T[1][a]/h[a]+A)}for(o=0;o<b.length;o++){var S=b[o];if(S.visible){var E=s.r2l(S[_]);m[0][a]=Math.min(m[0][a],E),m[1][a]=Math.max(m[1][a],E)}}if(\"rangemode\"in s&&\"tozero\"===s.rangemode&&(m[0][a]=Math.min(m[0][a],0),m[1][a]=Math.max(m[1][a],0)),m[0][a]>m[1][a])m[0][a]=-1,m[1][a]=1;else{var C=m[1][a]-m[0][a];m[0][a]-=C/32,m[1][a]+=C/32}if(\"reversed\"===s.autorange){var L=m[0][a];m[0][a]=m[1][a],m[1][a]=L}}else{var I=s.range;m[0][a]=s.r2l(I[0]),m[1][a]=s.r2l(I[1])}m[0][a]===m[1][a]&&(m[0][a]-=1,m[1][a]+=1),v[a]=m[1][a]-m[0][a],this.glplot.setBounds(a,{min:m[0][a]*h[a],max:m[1][a]*h[a]})}var P=c.aspectmode;if(\"cube\"===P)d=[1,1,1];else if(\"manual\"===P){var z=c.aspectratio;d=[z.x,z.y,z.z]}else{if(\"auto\"!==P&&\"data\"!==P)throw new Error(\"scene.js aspectRatio was not one of the enumerated types\");var O=[1,1,1];for(a=0;a<3;++a){var D=y[l=(s=c[k[a]]).type];O[a]=Math.pow(D.acc,1/D.count)/h[a]}d=\"data\"===P||Math.max.apply(null,O)/Math.min.apply(null,O)<=4?O:[1,1,1]}c.aspectratio.x=u.aspectratio.x=d[0],c.aspectratio.y=u.aspectratio.y=d[1],c.aspectratio.z=u.aspectratio.z=d[2],this.glplot.setAspectratio(c.aspectratio),this.viewInitial.aspectratio||(this.viewInitial.aspectratio={x:c.aspectratio.x,y:c.aspectratio.y,z:c.aspectratio.z}),this.viewInitial.aspectmode||(this.viewInitial.aspectmode=c.aspectmode);var R=c.domain||null,F=e._size||null;if(R&&F){var B=this.container.style;B.position=\"absolute\",B.left=F.l+R.x[0]*F.w+\"px\",B.top=F.t+(1-R.y[1])*F.h+\"px\",B.width=F.w*(R.x[1]-R.x[0])+\"px\",B.height=F.h*(R.y[1]-R.y[0])+\"px\"}this.glplot.redraw()}},w.destroy=function(){this.glplot&&(this.camera.mouseListener.enabled=!1,this.container.removeEventListener(\"wheel\",this.camera.wheelListener),this.camera=null,this.glplot.dispose(),this.container.parentNode.removeChild(this.container),this.glplot=null)},w.getCamera=function(){var t;return this.camera.view.recalcMatrix(this.camera.view.lastT()),{up:{x:(t=this.camera).up[0],y:t.up[1],z:t.up[2]},center:{x:t.center[0],y:t.center[1],z:t.center[2]},eye:{x:t.eye[0],y:t.eye[1],z:t.eye[2]},projection:{type:!0===t._ortho?\"orthographic\":\"perspective\"}}},w.setViewport=function(t){var e,r=t.camera;this.camera.lookAt.apply(this,[[(e=r).eye.x,e.eye.y,e.eye.z],[e.center.x,e.center.y,e.center.z],[e.up.x,e.up.y,e.up.z]]),this.glplot.setAspectratio(t.aspectratio),\"orthographic\"===r.projection.type!==this.camera._ortho&&(this.glplot.redraw(),this.glplot.clearRGBA(),this.glplot.dispose(),this.initializeGLPlot())},w.isCameraChanged=function(t){var e=this.getCamera(),r=f.nestedProperty(t,this.id+\".camera\").get();function n(t,e,r,n){var i=[\"up\",\"center\",\"eye\"],a=[\"x\",\"y\",\"z\"];return e[i[r]]&&t[i[r]][a[n]]===e[i[r]][a[n]]}var i=!1;if(void 0===r)i=!0;else{for(var a=0;a<3;a++)for(var o=0;o<3;o++)if(!n(e,r,a,o)){i=!0;break}(!r.projection||e.projection&&e.projection.type!==r.projection.type)&&(i=!0)}return i},w.isAspectChanged=function(t){var e=this.glplot.getAspectratio(),r=f.nestedProperty(t,this.id+\".aspectratio\").get();return void 0===r||r.x!==e.x||r.y!==e.y||r.z!==e.z},w.saveLayout=function(t){var e,r,n,i,a,o,s=this.fullLayout,l=this.isCameraChanged(t),c=this.isAspectChanged(t),h=l||c;if(h){var p={};if(l&&(e=this.getCamera(),n=(r=f.nestedProperty(t,this.id+\".camera\")).get(),p[this.id+\".camera\"]=n),c&&(i=this.glplot.getAspectratio(),o=(a=f.nestedProperty(t,this.id+\".aspectratio\")).get(),p[this.id+\".aspectratio\"]=o),u.call(\"_storeDirectGUIEdit\",t,s._preGUI,p),l)r.set(e),f.nestedProperty(s,this.id+\".camera\").set(e);if(c)a.set(i),f.nestedProperty(s,this.id+\".aspectratio\").set(i),this.glplot.redraw()}return h},w.updateFx=function(t,e){var r=this.camera;if(r)if(\"orbit\"===t)r.mode=\"orbit\",r.keyBindingMode=\"rotate\";else if(\"turntable\"===t){r.up=[0,0,1],r.mode=\"turntable\",r.keyBindingMode=\"rotate\";var n=this.graphDiv,i=n._fullLayout,a=this.fullSceneLayout.camera,o=a.up.x,s=a.up.y,l=a.up.z;if(l/Math.sqrt(o*o+s*s+l*l)<.999){var c=this.id+\".camera.up\",h={x:0,y:0,z:1},p={};p[c]=h;var d=n.layout;u.call(\"_storeDirectGUIEdit\",d,i._preGUI,p),a.up=h,f.nestedProperty(d,c).set(h)}}else r.keyBindingMode=t;this.fullSceneLayout.hovermode=e},w.toImage=function(t){t||(t=\"png\"),this.staticMode&&this.container.appendChild(n),this.glplot.redraw();var e=this.glplot.gl,r=e.drawingBufferWidth,i=e.drawingBufferHeight;e.bindFramebuffer(e.FRAMEBUFFER,null);var a=new Uint8Array(r*i*4);e.readPixels(0,0,r,i,e.RGBA,e.UNSIGNED_BYTE,a),function(t,e,r){for(var n=0,i=r-1;n<i;++n,--i)for(var a=0;a<e;++a)for(var o=0;o<4;++o){var s=4*(e*n+a)+o,l=4*(e*i+a)+o,c=t[s];t[s]=t[l],t[l]=c}}(a,r,i),function(t,e,r){for(var n=0;n<r;++n)for(var i=0;i<e;++i){var a=4*(e*n+i),o=t[a+3];if(o>0)for(var s=255/o,l=0;l<3;++l)t[a+l]=Math.min(s*t[a+l],255)}}(a,r,i);var o=document.createElement(\"canvas\");o.width=r,o.height=i;var s,l=o.getContext(\"2d\"),c=l.createImageData(r,i);switch(c.data.set(a),l.putImageData(c,0,0),t){case\"jpeg\":s=o.toDataURL(\"image/jpeg\");break;case\"webp\":s=o.toDataURL(\"image/webp\");break;default:s=o.toDataURL(\"image/png\")}return this.staticMode&&this.container.removeChild(n),s},w.setConvert=function(){for(var t=0;t<3;t++){var e=this.fullSceneLayout[k[t]];p.setConvert(e,this.fullLayout),e.setScale=f.noop}},w.make4thDimension=function(){var t=this.graphDiv._fullLayout;this._mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},p.setConvert(this._mockAxis,t)},e.exports=_},{\"../../components/fx\":683,\"../../lib\":778,\"../../lib/show_no_webgl_msg\":800,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout/convert\":874,\"./layout/spikes\":877,\"./layout/tick_marks\":878,\"./project\":879,\"gl-plot3d\":321,\"has-passive-events\":441,\"webgl-context\":606}],881:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){n=n||t.length;for(var i=new Array(n),a=0;a<n;a++)i[a]=[t[a],e[a],r[a]];return i}},{}],882:[function(t,e,r){\"use strict\";var n=t(\"./font_attributes\"),i=t(\"./animation_attributes\"),a=t(\"../components/color/attributes\"),o=t(\"../components/shapes/draw_newshape/attributes\"),s=t(\"./pad_attributes\"),l=t(\"../lib/extend\").extendFlat,c=n({editType:\"calc\"});c.family.dflt='\"Open Sans\", verdana, arial, sans-serif',c.size.dflt=12,c.color.dflt=a.defaultLine,e.exports={font:c,title:{text:{valType:\"string\",editType:\"layoutstyle\"},font:n({editType:\"layoutstyle\"}),xref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},yref:{valType:\"enumerated\",dflt:\"container\",values:[\"container\",\"paper\"],editType:\"layoutstyle\"},x:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"layoutstyle\"},y:{valType:\"number\",min:0,max:1,dflt:\"auto\",editType:\"layoutstyle\"},xanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"left\",\"center\",\"right\"],editType:\"layoutstyle\"},yanchor:{valType:\"enumerated\",dflt:\"auto\",values:[\"auto\",\"top\",\"middle\",\"bottom\"],editType:\"layoutstyle\"},pad:l(s({editType:\"layoutstyle\"}),{}),editType:\"layoutstyle\"},uniformtext:{mode:{valType:\"enumerated\",values:[!1,\"hide\",\"show\"],dflt:!1,editType:\"plot\"},minsize:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"plot\"},autosize:{valType:\"boolean\",dflt:!1,editType:\"none\"},width:{valType:\"number\",min:10,dflt:700,editType:\"plot\"},height:{valType:\"number\",min:10,dflt:450,editType:\"plot\"},margin:{l:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},r:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},t:{valType:\"number\",min:0,dflt:100,editType:\"plot\"},b:{valType:\"number\",min:0,dflt:80,editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},autoexpand:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},computed:{valType:\"any\",editType:\"none\"},paper_bgcolor:{valType:\"color\",dflt:a.background,editType:\"plot\"},plot_bgcolor:{valType:\"color\",dflt:a.background,editType:\"layoutstyle\"},autotypenumbers:{valType:\"enumerated\",values:[\"convert types\",\"strict\"],dflt:\"convert types\",editType:\"calc\"},separators:{valType:\"string\",editType:\"plot\"},hidesources:{valType:\"boolean\",dflt:!1,editType:\"plot\"},showlegend:{valType:\"boolean\",editType:\"legend\"},colorway:{valType:\"colorlist\",dflt:a.defaults,editType:\"calc\"},datarevision:{valType:\"any\",editType:\"calc\"},uirevision:{valType:\"any\",editType:\"none\"},editrevision:{valType:\"any\",editType:\"none\"},selectionrevision:{valType:\"any\",editType:\"none\"},template:{valType:\"any\",editType:\"calc\"},modebar:{orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\",editType:\"modebar\"},bgcolor:{valType:\"color\",editType:\"modebar\"},color:{valType:\"color\",editType:\"modebar\"},activecolor:{valType:\"color\",editType:\"modebar\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"modebar\"},newshape:o.newshape,activeshape:o.activeshape,meta:{valType:\"any\",arrayOk:!0,editType:\"plot\"},transition:l({},i.transition,{editType:\"none\"}),_deprecated:{title:{valType:\"string\",editType:\"layoutstyle\"},titlefont:n({editType:\"layoutstyle\"})}}},{\"../components/color/attributes\":642,\"../components/shapes/draw_newshape/attributes\":725,\"../lib/extend\":768,\"./animation_attributes\":822,\"./font_attributes\":856,\"./pad_attributes\":890}],883:[function(t,e,r){\"use strict\";var n={\"open-street-map\":{id:\"osm\",version:8,sources:{\"plotly-osm-tiles\":{type:\"raster\",attribution:'<a href=\"http://www.openstreetmap.org/about/\" target=\"_blank\">\\xa9 OpenStreetMap</a>',tiles:[\"https://a.tile.openstreetmap.org/{z}/{x}/{y}.png\",\"https://b.tile.openstreetmap.org/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-osm-tiles\",type:\"raster\",source:\"plotly-osm-tiles\",minzoom:0,maxzoom:22}]},\"white-bg\":{id:\"white-bg\",version:8,sources:{},layers:[{id:\"white-bg\",type:\"background\",paint:{\"background-color\":\"#FFFFFF\"},minzoom:0,maxzoom:22}]},\"carto-positron\":{id:\"carto-positron\",version:8,sources:{\"plotly-carto-positron\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/light_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-positron\",type:\"raster\",source:\"plotly-carto-positron\",minzoom:0,maxzoom:22}]},\"carto-darkmatter\":{id:\"carto-darkmatter\",version:8,sources:{\"plotly-carto-darkmatter\":{type:\"raster\",attribution:'<a href=\"https://carto.com/\" target=\"_blank\">\\xa9 CARTO</a>',tiles:[\"https://cartodb-basemaps-c.global.ssl.fastly.net/dark_all/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-carto-darkmatter\",type:\"raster\",source:\"plotly-carto-darkmatter\",minzoom:0,maxzoom:22}]},\"stamen-terrain\":{id:\"stamen-terrain\",version:8,sources:{\"plotly-stamen-terrain\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/terrain/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-terrain\",type:\"raster\",source:\"plotly-stamen-terrain\",minzoom:0,maxzoom:22}]},\"stamen-toner\":{id:\"stamen-toner\",version:8,sources:{\"plotly-stamen-toner\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://www.openstreetmap.org/copyright\">ODbL</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/toner/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-toner\",type:\"raster\",source:\"plotly-stamen-toner\",minzoom:0,maxzoom:22}]},\"stamen-watercolor\":{id:\"stamen-watercolor\",version:8,sources:{\"plotly-stamen-watercolor\":{type:\"raster\",attribution:'Map tiles by <a href=\"http://stamen.com\">Stamen Design</a>, under <a href=\"http://creativecommons.org/licenses/by/3.0\">CC BY 3.0</a> | Data by <a href=\"http://openstreetmap.org\">OpenStreetMap</a>, under <a href=\"http://creativecommons.org/licenses/by-sa/3.0\">CC BY SA</a>.',tiles:[\"https://stamen-tiles.a.ssl.fastly.net/watercolor/{z}/{x}/{y}.png\"],tileSize:256}},layers:[{id:\"plotly-stamen-watercolor\",type:\"raster\",source:\"plotly-stamen-watercolor\",minzoom:0,maxzoom:22}]}},i=Object.keys(n);e.exports={requiredVersion:\"1.10.1\",styleUrlPrefix:\"mapbox://styles/mapbox/\",styleUrlSuffix:\"v9\",styleValuesMapbox:[\"basic\",\"streets\",\"outdoors\",\"light\",\"dark\",\"satellite\",\"satellite-streets\"],styleValueDflt:\"basic\",stylesNonMapbox:n,styleValuesNonMapbox:i,traceLayerPrefix:\"plotly-trace-layer-\",layoutLayerPrefix:\"plotly-layout-layer-\",wrongVersionErrorMsg:[\"Your custom plotly.js bundle is not using the correct mapbox-gl version\",\"Please install mapbox-gl@1.10.1.\"].join(\"\\n\"),noAccessTokenErrorMsg:[\"Missing Mapbox access token.\",\"Mapbox trace type require a Mapbox access token to be registered.\",\"For example:\",\"  Plotly.plot(gd, data, layout, { mapboxAccessToken: 'my-access-token' });\",\"More info here: https://www.mapbox.com/help/define-access-token/\"].join(\"\\n\"),missingStyleErrorMsg:[\"No valid mapbox style found, please set `mapbox.style` to one of:\",i.join(\", \"),\"or register a Mapbox access token to use a Mapbox-served style.\"].join(\"\\n\"),multipleTokensErrorMsg:[\"Set multiple mapbox access token across different mapbox subplot,\",\"using first token found as mapbox-gl does not allow multipleaccess tokens on the same page.\"].join(\"\\n\"),mapOnErrorMsg:\"Mapbox error.\",mapboxLogo:{path0:\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\",path1:\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\",path2:\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\",polygon:\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34\"},styleRules:{map:\"overflow:hidden;position:relative;\",\"missing-css\":\"display:none;\",canary:\"background-color:salmon;\",\"ctrl-bottom-left\":\"position: absolute; pointer-events: none; z-index: 2; bottom: 0; left: 0;\",\"ctrl-bottom-right\":\"position: absolute; pointer-events: none; z-index: 2; right: 0; bottom: 0;\",ctrl:\"clear: both; pointer-events: auto; transform: translate(0, 0);\",\"ctrl-attrib.mapboxgl-compact .mapboxgl-ctrl-attrib-inner\":\"display: none;\",\"ctrl-attrib.mapboxgl-compact:hover .mapboxgl-ctrl-attrib-inner\":\"display: block; margin-top:2px\",\"ctrl-attrib.mapboxgl-compact:hover\":\"padding: 2px 24px 2px 4px; visibility: visible; margin-top: 6px;\",\"ctrl-attrib.mapboxgl-compact::after\":'content: \"\"; cursor: pointer; position: absolute; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3Csvg viewBox=\"0 0 20 20\" xmlns=\"http://www.w3.org/2000/svg\"%3E %3Cpath fill=\"%23333333\" fill-rule=\"evenodd\" d=\"M4,10a6,6 0 1,0 12,0a6,6 0 1,0 -12,0 M9,7a1,1 0 1,0 2,0a1,1 0 1,0 -2,0 M9,10a1,1 0 1,1 2,0l0,3a1,1 0 1,1 -2,0\"/%3E %3C/svg%3E\\'); background-color: rgba(255, 255, 255, 0.5); width: 24px; height: 24px; box-sizing: border-box; border-radius: 12px;',\"ctrl-attrib.mapboxgl-compact\":\"min-height: 20px; padding: 0; margin: 10px; position: relative; background-color: #fff; border-radius: 3px 12px 12px 3px;\",\"ctrl-bottom-right > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; right: 0\",\"ctrl-bottom-left > .mapboxgl-ctrl-attrib.mapboxgl-compact::after\":\"bottom: 0; left: 0\",\"ctrl-bottom-left .mapboxgl-ctrl\":\"margin: 0 0 10px 10px; float: left;\",\"ctrl-bottom-right .mapboxgl-ctrl\":\"margin: 0 10px 10px 0; float: right;\",\"ctrl-attrib\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a\":\"color: rgba(0, 0, 0, 0.75); text-decoration: none; font-size: 12px\",\"ctrl-attrib a:hover\":\"color: inherit; text-decoration: underline;\",\"ctrl-attrib .mapbox-improve-map\":\"font-weight: bold; margin-left: 2px;\",\"attrib-empty\":\"display: none;\",\"ctrl-logo\":'display:block; width: 21px; height: 21px; background-image: url(\\'data:image/svg+xml;charset=utf-8,%3C?xml version=\"1.0\" encoding=\"utf-8\"?%3E %3Csvg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 21 21\" style=\"enable-background:new 0 0 21 21;\" xml:space=\"preserve\"%3E%3Cg transform=\"translate(0,0.01)\"%3E%3Cpath d=\"m 10.5,1.24 c -5.11,0 -9.25,4.15 -9.25,9.25 0,5.1 4.15,9.25 9.25,9.25 5.1,0 9.25,-4.15 9.25,-9.25 0,-5.11 -4.14,-9.25 -9.25,-9.25 z m 4.39,11.53 c -1.93,1.93 -4.78,2.31 -6.7,2.31 -0.7,0 -1.41,-0.05 -2.1,-0.16 0,0 -1.02,-5.64 2.14,-8.81 0.83,-0.83 1.95,-1.28 3.13,-1.28 1.27,0 2.49,0.51 3.39,1.42 1.84,1.84 1.89,4.75 0.14,6.52 z\" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3Cpath d=\"M 10.5,-0.01 C 4.7,-0.01 0,4.7 0,10.49 c 0,5.79 4.7,10.5 10.5,10.5 5.8,0 10.5,-4.7 10.5,-10.5 C 20.99,4.7 16.3,-0.01 10.5,-0.01 Z m 0,19.75 c -5.11,0 -9.25,-4.15 -9.25,-9.25 0,-5.1 4.14,-9.26 9.25,-9.26 5.11,0 9.25,4.15 9.25,9.25 0,5.13 -4.14,9.26 -9.25,9.26 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpath d=\"M 14.74,6.25 C 12.9,4.41 9.98,4.35 8.23,6.1 5.07,9.27 6.09,14.91 6.09,14.91 c 0,0 5.64,1.02 8.81,-2.14 C 16.64,11 16.59,8.09 14.74,6.25 Z m -2.27,4.09 -0.91,1.87 -0.9,-1.87 -1.86,-0.91 1.86,-0.9 0.9,-1.87 0.91,1.87 1.86,0.9 z\" style=\"opacity:0.35;enable-background:new\" class=\"st1\"/%3E%3Cpolygon points=\"11.56,12.21 10.66,10.34 8.8,9.43 10.66,8.53 11.56,6.66 12.47,8.53 14.33,9.43 12.47,10.34 \" style=\"opacity:0.9;fill:%23ffffff;enable-background:new\" class=\"st0\"/%3E%3C/g%3E%3C/svg%3E\\')'}}},{}],884:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t.split(\" \"),i=r[0],a=r[1],o=n.isArrayOrTypedArray(e)?n.mean(e):e,s=.5+o/100,l=1.5+o/100,c=[\"\",\"\"],u=[0,0];switch(i){case\"top\":c[0]=\"top\",u[1]=-l;break;case\"bottom\":c[0]=\"bottom\",u[1]=l}switch(a){case\"left\":c[1]=\"right\",u[0]=-s;break;case\"right\":c[1]=\"left\",u[0]=s}return{anchor:c[0]&&c[1]?c.join(\"-\"):c[0]?c[0]:c[1]?c[1]:\"center\",offset:u}}},{\"../../lib\":778}],885:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=i.strTranslate,o=i.strScale,s=t(\"../../plots/get_data\").getSubplotCalcData,l=t(\"../../constants/xmlns_namespaces\"),c=t(\"d3\"),u=t(\"../../components/drawing\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"./mapbox\"),p=r.constants=t(\"./constants\");function d(t){return\"string\"==typeof t&&(-1!==p.styleValuesMapbox.indexOf(t)||0===t.indexOf(\"mapbox://\"))}r.name=\"mapbox\",r.attr=\"subplot\",r.idRoot=\"mapbox\",r.idRegex=r.attrRegex=i.counterRegex(\"mapbox\"),r.attributes={subplot:{valType:\"subplotid\",dflt:\"mapbox\",editType:\"calc\"}},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){var e=t._fullLayout,r=t.calcdata,a=e._subplots.mapbox;if(n.version!==p.requiredVersion)throw new Error(p.wrongVersionErrorMsg);var o=function(t,e){var r=t._fullLayout;if(\"\"===t._context.mapboxAccessToken)return\"\";for(var n=[],a=[],o=!1,s=!1,l=0;l<e.length;l++){var c=r[e[l]],u=c.accesstoken;d(c.style)&&(u?i.pushUnique(n,u):(d(c._input.style)&&(i.error(\"Uses Mapbox map style, but did not set an access token.\"),o=!0),s=!0)),u&&i.pushUnique(a,u)}if(s){var f=o?p.noAccessTokenErrorMsg:p.missingStyleErrorMsg;throw i.error(f),new Error(f)}return n.length?(n.length>1&&i.warn(p.multipleTokensErrorMsg),n[0]):(a.length&&i.log([\"Listed mapbox access token(s)\",a.join(\",\"),\"but did not use a Mapbox map style, ignoring token(s).\"].join(\" \")),\"\")}(t,a);n.accessToken=o;for(var l=0;l<a.length;l++){var c=a[l],u=s(r,\"mapbox\",c),f=e[c],g=f._subplot;g||(g=new h(t,c),e[c]._subplot=g),g.viewInitial||(g.viewInitial={center:i.extendFlat({},f.center),zoom:f.zoom,bearing:f.bearing,pitch:f.pitch}),g.plot(u,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.mapbox||[],a=0;a<i.length;a++){var o=i[a];!e[o]&&n[o]._subplot&&n[o]._subplot.destroy()}},r.toSVG=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=e._size,i=0;i<r.length;i++){var s=e[r[i]],h=s.domain,d=s._subplot.toImage(\"png\");e._glimages.append(\"svg:image\").attr({xmlns:l.svg,\"xlink:href\":d,x:n.l+n.w*h.x[0],y:n.t+n.h*(1-h.y[1]),width:n.w*(h.x[1]-h.x[0]),height:n.h*(h.y[1]-h.y[0]),preserveAspectRatio:\"none\"});var g=c.select(s._subplot.div);if(!(null===g.select(\".mapboxgl-ctrl-logo\").node().offsetParent)){var m=e._glimages.append(\"g\");m.attr(\"transform\",a(n.l+n.w*h.x[0]+10,n.t+n.h*(1-h.y[0])-31)),m.append(\"path\").attr(\"d\",p.mapboxLogo.path0).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"}),m.append(\"path\").attr(\"d\",p.mapboxLogo.path1).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"path\").attr(\"d\",p.mapboxLogo.path2).style(\"opacity\",.35).style(\"enable-background\",\"new\"),m.append(\"polygon\").attr(\"points\",p.mapboxLogo.polygon).style({opacity:.9,fill:\"#ffffff\",\"enable-background\":\"new\"})}var v=g.select(\".mapboxgl-ctrl-attrib\").text().replace(\"Improve this map\",\"\"),y=e._glimages.append(\"g\"),x=y.append(\"text\");x.text(v).classed(\"static-attribution\",!0).attr({\"font-size\":12,\"font-family\":\"Arial\",color:\"rgba(0, 0, 0, 0.75)\",\"text-anchor\":\"end\",\"data-unformatted\":v});var b=u.bBox(x.node()),_=n.w*(h.x[1]-h.x[0]);if(b.width>_/2){var w=v.split(\"|\").join(\"<br>\");x.text(w).attr(\"data-unformatted\",w).call(f.convertToTspans,t),b=u.bBox(x.node())}x.attr(\"transform\",a(-3,8-b.height)),y.insert(\"rect\",\".static-attribution\").attr({x:-b.width-6,y:-b.height-3,width:b.width+6,height:b.height+3,fill:\"rgba(255, 255, 255, 0.75)\"});var T=1;b.width+6>_&&(T=_/(b.width+6));var k=[n.l+n.w*h.x[1],n.t+n.h*(1-h.y[0])];y.attr(\"transform\",a(k[0],k[1])+o(T))}},r.updateFx=function(t){for(var e=t._fullLayout,r=e._subplots.mapbox,n=0;n<r.length;n++){e[r[n]]._subplot.updateFx(e)}}},{\"../../components/drawing\":665,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/get_data\":865,\"./constants\":883,\"./layout_attributes\":887,\"./layout_defaults\":888,\"./mapbox\":889,d3:169,\"mapbox-gl\":473}],886:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/svg_text_utils\").sanitizeHTML,a=t(\"./convert_text_opts\"),o=t(\"./constants\");function s(t,e){this.subplot=t,this.uid=t.uid+\"-\"+e,this.index=e,this.idSource=\"source-\"+this.uid,this.idLayer=o.layoutLayerPrefix+this.uid,this.sourceType=null,this.source=null,this.layerType=null,this.below=null,this.visible=!1}var l=s.prototype;function c(t){if(!t.visible)return!1;var e=t.source;if(Array.isArray(e)&&e.length>0){for(var r=0;r<e.length;r++)if(\"string\"!=typeof e[r]||0===e[r].length)return!1;return!0}return n.isPlainObject(e)||\"string\"==typeof e&&e.length>0}function u(t){var e={},r={};switch(t.type){case\"circle\":n.extendFlat(r,{\"circle-radius\":t.circle.radius,\"circle-color\":t.color,\"circle-opacity\":t.opacity});break;case\"line\":n.extendFlat(r,{\"line-width\":t.line.width,\"line-color\":t.color,\"line-opacity\":t.opacity,\"line-dasharray\":t.line.dash});break;case\"fill\":n.extendFlat(r,{\"fill-color\":t.color,\"fill-outline-color\":t.fill.outlinecolor,\"fill-opacity\":t.opacity});break;case\"symbol\":var i=t.symbol,o=a(i.textposition,i.iconsize);n.extendFlat(e,{\"icon-image\":i.icon+\"-15\",\"icon-size\":i.iconsize/10,\"text-field\":i.text,\"text-size\":i.textfont.size,\"text-anchor\":o.anchor,\"text-offset\":o.offset,\"symbol-placement\":i.placement}),n.extendFlat(r,{\"icon-color\":t.color,\"text-color\":i.textfont.color,\"text-opacity\":t.opacity});break;case\"raster\":n.extendFlat(r,{\"raster-fade-duration\":0,\"raster-opacity\":t.opacity})}return{layout:e,paint:r}}l.update=function(t){this.visible?this.needsNewImage(t)?this.updateImage(t):this.needsNewSource(t)?(this.removeLayer(),this.updateSource(t),this.updateLayer(t)):this.needsNewLayer(t)?this.updateLayer(t):this.updateStyle(t):(this.updateSource(t),this.updateLayer(t)),this.visible=c(t)},l.needsNewImage=function(t){return this.subplot.map.getSource(this.idSource)&&\"image\"===this.sourceType&&\"image\"===t.sourcetype&&(this.source!==t.source||JSON.stringify(this.coordinates)!==JSON.stringify(t.coordinates))},l.needsNewSource=function(t){return this.sourceType!==t.sourcetype||JSON.stringify(this.source)!==JSON.stringify(t.source)||this.layerType!==t.type},l.needsNewLayer=function(t){return this.layerType!==t.type||this.below!==this.subplot.belowLookup[\"layout-\"+this.index]},l.lookupBelow=function(){return this.subplot.belowLookup[\"layout-\"+this.index]},l.updateImage=function(t){this.subplot.map.getSource(this.idSource).updateImage({url:t.source,coordinates:t.coordinates});var e=this.findFollowingMapboxLayerId(this.lookupBelow());null!==e&&this.subplot.map.moveLayer(this.idLayer,e)},l.updateSource=function(t){var e=this.subplot.map;if(e.getSource(this.idSource)&&e.removeSource(this.idSource),this.sourceType=t.sourcetype,this.source=t.source,c(t)){var r=function(t){var e,r=t.sourcetype,n=t.source,a={type:r};\"geojson\"===r?e=\"data\":\"vector\"===r?e=\"string\"==typeof n?\"url\":\"tiles\":\"raster\"===r?(e=\"tiles\",a.tileSize=256):\"image\"===r&&(e=\"url\",a.coordinates=t.coordinates);a[e]=n,t.sourceattribution&&(a.attribution=i(t.sourceattribution));return a}(t);e.addSource(this.idSource,r)}},l.findFollowingMapboxLayerId=function(t){if(\"traces\"===t)for(var e=this.subplot.getMapLayers(),r=0;r<e.length;r++){var n=e[r].id;if(\"string\"==typeof n&&0===n.indexOf(o.traceLayerPrefix)){t=n;break}}return t},l.updateLayer=function(t){var e=this.subplot,r=u(t),n=this.lookupBelow(),i=this.findFollowingMapboxLayerId(n);this.removeLayer(),c(t)&&e.addLayer({id:this.idLayer,source:this.idSource,\"source-layer\":t.sourcelayer||\"\",type:t.type,minzoom:t.minzoom,maxzoom:t.maxzoom,layout:r.layout,paint:r.paint},i),this.layerType=t.type,this.below=n},l.updateStyle=function(t){if(c(t)){var e=u(t);this.subplot.setOptions(this.idLayer,\"setLayoutProperty\",e.layout),this.subplot.setOptions(this.idLayer,\"setPaintProperty\",e.paint)}},l.removeLayer=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer)},l.dispose=function(){var t=this.subplot.map;t.getLayer(this.idLayer)&&t.removeLayer(this.idLayer),t.getSource(this.idSource)&&t.removeSource(this.idSource)},e.exports=function(t,e,r){var n=new s(t,e);return n.update(r),n}},{\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./constants\":883,\"./convert_text_opts\":884}],887:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\").defaultLine,a=t(\"../domain\").attributes,o=t(\"../font_attributes\"),s=t(\"../../traces/scatter/attributes\").textposition,l=t(\"../../plot_api/edit_types\").overrideAll,c=t(\"../../plot_api/plot_template\").templatedArray,u=t(\"./constants\"),f=o({});f.family.dflt=\"Open Sans Regular, Arial Unicode MS Regular\",(e.exports=l({_arrayAttrRegexps:[n.counterRegex(\"mapbox\",\".layers\",!0)],domain:a({name:\"mapbox\"}),accesstoken:{valType:\"string\",noBlank:!0,strict:!0},style:{valType:\"any\",values:u.styleValuesMapbox.concat(u.styleValuesNonMapbox),dflt:u.styleValueDflt},center:{lon:{valType:\"number\",dflt:0},lat:{valType:\"number\",dflt:0}},zoom:{valType:\"number\",dflt:1},bearing:{valType:\"number\",dflt:0},pitch:{valType:\"number\",dflt:0},layers:c(\"layer\",{visible:{valType:\"boolean\",dflt:!0},sourcetype:{valType:\"enumerated\",values:[\"geojson\",\"vector\",\"raster\",\"image\"],dflt:\"geojson\"},source:{valType:\"any\"},sourcelayer:{valType:\"string\",dflt:\"\"},sourceattribution:{valType:\"string\"},type:{valType:\"enumerated\",values:[\"circle\",\"line\",\"fill\",\"symbol\",\"raster\"],dflt:\"circle\"},coordinates:{valType:\"any\"},below:{valType:\"string\"},color:{valType:\"color\",dflt:i},opacity:{valType:\"number\",min:0,max:1,dflt:1},minzoom:{valType:\"number\",min:0,max:24,dflt:0},maxzoom:{valType:\"number\",min:0,max:24,dflt:24},circle:{radius:{valType:\"number\",dflt:15}},line:{width:{valType:\"number\",dflt:2},dash:{valType:\"data_array\"}},fill:{outlinecolor:{valType:\"color\",dflt:i}},symbol:{icon:{valType:\"string\",dflt:\"marker\"},iconsize:{valType:\"number\",dflt:10},text:{valType:\"string\",dflt:\"\"},placement:{valType:\"enumerated\",values:[\"point\",\"line\",\"line-center\"],dflt:\"point\"},textfont:f,textposition:n.extendFlat({},s,{arrayOk:!1})}})},\"plot\",\"from-root\")).uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../traces/scatter/attributes\":1187,\"../domain\":855,\"../font_attributes\":856,\"./constants\":883}],888:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../subplot_defaults\"),a=t(\"../array_container_defaults\"),o=t(\"./layout_attributes\");function s(t,e,r,n){r(\"accesstoken\",n.accessToken),r(\"style\"),r(\"center.lon\"),r(\"center.lat\"),r(\"zoom\"),r(\"bearing\"),r(\"pitch\"),a(t,e,{name:\"layers\",handleItemDefaults:l}),e._input=t}function l(t,e){function r(r,i){return n.coerce(t,e,o.layers,r,i)}if(r(\"visible\")){var i,a=r(\"sourcetype\"),s=\"raster\"===a||\"image\"===a;r(\"source\"),r(\"sourceattribution\"),\"vector\"===a&&r(\"sourcelayer\"),\"image\"===a&&r(\"coordinates\"),s&&(i=\"raster\");var l=r(\"type\",i);s&&\"raster\"!==l&&(l=e.type=\"raster\",n.log(\"Source types *raster* and *image* must drawn *raster* layer type.\")),r(\"below\"),r(\"color\"),r(\"opacity\"),r(\"minzoom\"),r(\"maxzoom\"),\"circle\"===l&&r(\"circle.radius\"),\"line\"===l&&(r(\"line.width\"),r(\"line.dash\")),\"fill\"===l&&r(\"fill.outlinecolor\"),\"symbol\"===l&&(r(\"symbol.icon\"),r(\"symbol.iconsize\"),r(\"symbol.text\"),n.coerceFont(r,\"symbol.textfont\"),r(\"symbol.textposition\"),r(\"symbol.placement\"))}}e.exports=function(t,e,r){i(t,e,r,{type:\"mapbox\",attributes:o,handleDefaults:s,partition:\"y\",accessToken:e._mapboxAccessToken})}},{\"../../lib\":778,\"../array_container_defaults\":823,\"../subplot_defaults\":905,\"./layout_attributes\":887}],889:[function(t,e,r){\"use strict\";var n=t(\"mapbox-gl\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../registry\"),s=t(\"../cartesian/axes\"),l=t(\"../../components/dragelement\"),c=t(\"../../components/fx\"),u=t(\"../../components/dragelement/helpers\"),f=u.rectMode,h=u.drawMode,p=u.selectMode,d=t(\"../cartesian/select\").prepSelect,g=t(\"../cartesian/select\").clearSelect,m=t(\"../cartesian/select\").clearSelectionsCache,v=t(\"../cartesian/select\").selectOnClick,y=t(\"./constants\"),x=t(\"./layers\");function b(t,e){this.id=e,this.gd=t;var r=t._fullLayout,n=t._context;this.container=r._glcontainer.node(),this.isStatic=n.staticPlot,this.uid=r._uid+\"-\"+this.id,this.div=null,this.xaxis=null,this.yaxis=null,this.createFramework(r),this.map=null,this.accessToken=null,this.styleObj=null,this.traceHash={},this.layerList=[],this.belowLookup={},this.dragging=!1,this.wheeling=!1}var _=b.prototype;_.plot=function(t,e,r){var n,i=this,a=e[i.id];i.map&&a.accesstoken!==i.accessToken&&(i.map.remove(),i.map=null,i.styleObj=null,i.traceHash={},i.layerList=[]),n=i.map?new Promise((function(r,n){i.updateMap(t,e,r,n)})):new Promise((function(r,n){i.createMap(t,e,r,n)})),r.push(n)},_.createMap=function(t,e,r,i){var o=this,s=e[o.id],l=o.styleObj=T(s.style);o.accessToken=s.accesstoken;var c=o.map=new n.Map({container:o.div,style:l.style,center:M(s.center),zoom:s.zoom,bearing:s.bearing,pitch:s.pitch,interactive:!o.isStatic,preserveDrawingBuffer:o.isStatic,doubleClickZoom:!1,boxZoom:!1,attributionControl:!1}).addControl(new n.AttributionControl({compact:!0}));c._canvas.style.left=\"0px\",c._canvas.style.top=\"0px\",o.rejectOnError(i),o.isStatic||o.initFx(t,e);var u=[];u.push(new Promise((function(t){c.once(\"load\",t)}))),u=u.concat(a.fetchTraceGeoData(t)),Promise.all(u).then((function(){o.fillBelowLookup(t,e),o.updateData(t),o.updateLayout(e),o.resolveOnRender(r)})).catch(i)},_.updateMap=function(t,e,r,n){var i=this,o=i.map,s=e[this.id];i.rejectOnError(n);var l=[],c=T(s.style);JSON.stringify(i.styleObj)!==JSON.stringify(c)&&(i.styleObj=c,o.setStyle(c.style),i.traceHash={},l.push(new Promise((function(t){o.once(\"styledata\",t)})))),l=l.concat(a.fetchTraceGeoData(t)),Promise.all(l).then((function(){i.fillBelowLookup(t,e),i.updateData(t),i.updateLayout(e),i.resolveOnRender(r)})).catch(n)},_.fillBelowLookup=function(t,e){var r,n,i=e[this.id].layers,a=this.belowLookup={},o=!1;for(r=0;r<t.length;r++){var s=t[r][0].trace,l=s._module;\"string\"==typeof s.below?n=s.below:l.getBelow&&(n=l.getBelow(s,this)),\"\"===n&&(o=!0),a[\"trace-\"+s.uid]=n||\"\"}for(r=0;r<i.length;r++){var c=i[r];n=\"string\"==typeof c.below?c.below:o?\"traces\":\"\",a[\"layout-\"+r]=n}var u,f,h={};for(u in a)h[n=a[u]]?h[n].push(u):h[n]=[u];for(n in h){var p=h[n];if(p.length>1)for(r=0;r<p.length;r++)0===(u=p[r]).indexOf(\"trace-\")?(f=u.split(\"trace-\")[1],this.traceHash[f]&&(this.traceHash[f].below=null)):0===u.indexOf(\"layout-\")&&(f=u.split(\"layout-\")[1],this.layerList[f]&&(this.layerList[f].below=null))}};var w={choroplethmapbox:0,densitymapbox:1,scattermapbox:2};function T(t){var e={};return i.isPlainObject(t)?(e.id=t.id,e.style=t):\"string\"==typeof t?(e.id=t,-1!==y.styleValuesMapbox.indexOf(t)?e.style=k(t):y.stylesNonMapbox[t]?e.style=y.stylesNonMapbox[t]:e.style=t):(e.id=y.styleValueDflt,e.style=k(y.styleValueDflt)),e.transition={duration:0,delay:0},e}function k(t){return y.styleUrlPrefix+t+\"-\"+y.styleUrlSuffix}function M(t){return[t.lon,t.lat]}_.updateData=function(t){var e,r,n,i,a=this.traceHash,o=t.slice().sort((function(t,e){return w[t[0].trace.type]-w[e[0].trace.type]}));for(n=0;n<o.length;n++){var s=o[n],l=!1;(e=a[(r=s[0].trace).uid])&&(e.type===r.type?(e.update(s),l=!0):e.dispose()),!l&&r._module&&(a[r.uid]=r._module.plot(this,s))}var c=Object.keys(a);t:for(n=0;n<c.length;n++){var u=c[n];for(i=0;i<t.length;i++)if(u===(r=t[i][0].trace).uid)continue t;(e=a[u]).dispose(),delete a[u]}},_.updateLayout=function(t){var e=this.map,r=t[this.id];this.dragging||this.wheeling||(e.setCenter(M(r.center)),e.setZoom(r.zoom),e.setBearing(r.bearing),e.setPitch(r.pitch)),this.updateLayers(t),this.updateFramework(t),this.updateFx(t),this.map.resize(),this.gd._context._scrollZoom.mapbox?e.scrollZoom.enable():e.scrollZoom.disable()},_.resolveOnRender=function(t){var e=this.map;e.on(\"render\",(function r(){e.loaded()&&(e.off(\"render\",r),setTimeout(t,10))}))},_.rejectOnError=function(t){var e=this.map;function r(){t(new Error(y.mapOnErrorMsg))}e.once(\"error\",r),e.once(\"style.error\",r),e.once(\"source.error\",r),e.once(\"tile.error\",r),e.once(\"layer.error\",r)},_.createFramework=function(t){var e=this,r=e.div=document.createElement(\"div\");r.id=e.uid,r.style.position=\"absolute\",e.container.appendChild(r),e.xaxis={_id:\"x\",c2p:function(t){return e.project(t).x}},e.yaxis={_id:\"y\",c2p:function(t){return e.project(t).y}},e.updateFramework(t),e.mockAxis={type:\"linear\",showexponent:\"all\",exponentformat:\"B\"},s.setConvert(e.mockAxis,t)},_.initFx=function(t,e){var r=this,n=r.gd,i=r.map;function a(){c.loneUnhover(e._hoverlayer)}function s(){var t=r.getView();n.emit(\"plotly_relayouting\",r.getViewEditsWithDerived(t))}i.on(\"moveend\",(function(t){if(r.map){var e=n._fullLayout;if(t.originalEvent||r.wheeling){var i=e[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,e._preGUI,r.getViewEdits(i));var a=r.getView();i._input.center=i.center=a.center,i._input.zoom=i.zoom=a.zoom,i._input.bearing=i.bearing=a.bearing,i._input.pitch=i.pitch=a.pitch,n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))}t.originalEvent&&\"mouseup\"===t.originalEvent.type?r.dragging=!1:r.wheeling&&(r.wheeling=!1),e._rehover&&e._rehover()}})),i.on(\"wheel\",(function(){r.wheeling=!0})),i.on(\"mousemove\",(function(t){var e=r.div.getBoundingClientRect(),a=[t.originalEvent.offsetX,t.originalEvent.offsetY];t.target.getBoundingClientRect=function(){return e},r.xaxis.p2c=function(){return i.unproject(a).lng},r.yaxis.p2c=function(){return i.unproject(a).lat},n._fullLayout._rehover=function(){n._fullLayout._hoversubplot===r.id&&n._fullLayout[r.id]&&c.hover(n,t,r.id)},c.hover(n,t,r.id),n._fullLayout._hoversubplot=r.id})),i.on(\"dragstart\",(function(){r.dragging=!0,a()})),i.on(\"zoomstart\",a),i.on(\"mouseout\",(function(){n._fullLayout._hoversubplot=null})),i.on(\"drag\",s),i.on(\"zoom\",s),i.on(\"dblclick\",(function(){var t=n._fullLayout[r.id];o.call(\"_storeDirectGUIEdit\",n.layout,n._fullLayout._preGUI,r.getViewEdits(t));var e=r.viewInitial;i.setCenter(M(e.center)),i.setZoom(e.zoom),i.setBearing(e.bearing),i.setPitch(e.pitch);var a=r.getView();t._input.center=t.center=a.center,t._input.zoom=t.zoom=a.zoom,t._input.bearing=t.bearing=a.bearing,t._input.pitch=t.pitch=a.pitch,n.emit(\"plotly_doubleclick\",null),n.emit(\"plotly_relayout\",r.getViewEditsWithDerived(a))})),r.clearSelect=function(){m(r.dragOptions),g(r.dragOptions.gd)},r.onClickInPanFn=function(t){return function(e){var i=n._fullLayout.clickmode;i.indexOf(\"select\")>-1&&v(e.originalEvent,n,[r.xaxis],[r.yaxis],r.id,t),i.indexOf(\"event\")>-1&&c.click(n,e.originalEvent)}}},_.updateFx=function(t){var e=this,r=e.map,n=e.gd;if(!e.isStatic){var a,o=t.dragmode;a=f(o)?function(t,r){(t.range={})[e.id]=[c([r.xmin,r.ymin]),c([r.xmax,r.ymax])]}:function(t,r,n){(t.lassoPoints={})[e.id]=n.filtered.map(c)};var s=e.dragOptions;e.dragOptions=i.extendDeep(s||{},{dragmode:t.dragmode,element:e.div,gd:n,plotinfo:{id:e.id,domain:t[e.id].domain,xaxis:e.xaxis,yaxis:e.yaxis,fillRangeItems:a},xaxes:[e.xaxis],yaxes:[e.yaxis],subplot:e.id}),r.off(\"click\",e.onClickInPanHandler),p(o)||h(o)?(r.dragPan.disable(),r.on(\"zoomstart\",e.clearSelect),e.dragOptions.prepFn=function(t,r,n){d(t,r,n,e.dragOptions,o)},l.init(e.dragOptions)):(r.dragPan.enable(),r.off(\"zoomstart\",e.clearSelect),e.div.onmousedown=null,e.onClickInPanHandler=e.onClickInPanFn(e.dragOptions),r.on(\"click\",e.onClickInPanHandler))}function c(t){var r=e.map.unproject(t);return[r.lng,r.lat]}},_.updateFramework=function(t){var e=t[this.id].domain,r=t._size,n=this.div.style;n.width=r.w*(e.x[1]-e.x[0])+\"px\",n.height=r.h*(e.y[1]-e.y[0])+\"px\",n.left=r.l+e.x[0]*r.w+\"px\",n.top=r.t+(1-e.y[1])*r.h+\"px\",this.xaxis._offset=r.l+e.x[0]*r.w,this.xaxis._length=r.w*(e.x[1]-e.x[0]),this.yaxis._offset=r.t+(1-e.y[1])*r.h,this.yaxis._length=r.h*(e.y[1]-e.y[0])},_.updateLayers=function(t){var e,r=t[this.id].layers,n=this.layerList;if(r.length!==n.length){for(e=0;e<n.length;e++)n[e].dispose();for(n=this.layerList=[],e=0;e<r.length;e++)n.push(x(this,e,r[e]))}else for(e=0;e<r.length;e++)n[e].update(r[e])},_.destroy=function(){this.map&&(this.map.remove(),this.map=null,this.container.removeChild(this.div))},_.toImage=function(){return this.map.stop(),this.map.getCanvas().toDataURL()},_.setOptions=function(t,e,r){for(var n in r)this.map[e](t,n,r[n])},_.getMapLayers=function(){return this.map.getStyle().layers},_.addLayer=function(t,e){var r=this.map;if(\"string\"==typeof e){if(\"\"===e)return void r.addLayer(t,e);for(var n=this.getMapLayers(),a=0;a<n.length;a++)if(e===n[a].id)return void r.addLayer(t,e);i.warn([\"Trying to add layer with *below* value\",e,\"referencing a layer that does not exist\",\"or that does not yet exist.\"].join(\" \"))}r.addLayer(t)},_.project=function(t){return this.map.project(new n.LngLat(t[0],t[1]))},_.getView=function(){var t=this.map,e=t.getCenter(),r={lon:e.lng,lat:e.lat},n=t.getCanvas(),i=n.width,a=n.height;return{center:r,zoom:t.getZoom(),bearing:t.getBearing(),pitch:t.getPitch(),_derived:{coordinates:[t.unproject([0,0]).toArray(),t.unproject([i,0]).toArray(),t.unproject([i,a]).toArray(),t.unproject([0,a]).toArray()]}}},_.getViewEdits=function(t){for(var e=this.id,r=[\"center\",\"zoom\",\"bearing\",\"pitch\"],n={},i=0;i<r.length;i++){var a=r[i];n[e+\".\"+a]=t[a]}return n},_.getViewEditsWithDerived=function(t){var e=this.id,r=this.getViewEdits(t);return r[e+\"._derived\"]=t._derived,r},e.exports=b},{\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/select\":847,\"./constants\":883,\"./layers\":886,\"mapbox-gl\":473}],890:[function(t,e,r){\"use strict\";e.exports=function(t){var e=t.editType;return{t:{valType:\"number\",dflt:0,editType:e},r:{valType:\"number\",dflt:0,editType:e},b:{valType:\"number\",dflt:0,editType:e},l:{valType:\"number\",dflt:0,editType:e},editType:e}}},{}],891:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-time-format\").timeFormatLocale,a=t(\"fast-isnumeric\"),o=t(\"../registry\"),s=t(\"../plot_api/plot_schema\"),l=t(\"../plot_api/plot_template\"),c=t(\"../lib\"),u=t(\"../components/color\"),f=t(\"../constants/numerical\").BADNUM,h=t(\"./cartesian/axis_ids\"),p=t(\"./cartesian/handle_outline\").clearSelect,d=t(\"./animation_attributes\"),g=t(\"./frame_attributes\"),m=t(\"../plots/get_data\").getModuleCalcData,v=c.relinkPrivateKeys,y=c._,x=e.exports={};c.extendFlat(x,o),x.attributes=t(\"./attributes\"),x.attributes.type.values=x.allTypes,x.fontAttrs=t(\"./font_attributes\"),x.layoutAttributes=t(\"./layout_attributes\"),x.fontWeight=\"normal\";var b=x.transformsRegistry,_=t(\"./command\");x.executeAPICommand=_.executeAPICommand,x.computeAPICommandBindings=_.computeAPICommandBindings,x.manageCommandObserver=_.manageCommandObserver,x.hasSimpleAPICommandBindings=_.hasSimpleAPICommandBindings,x.redrawText=function(t){var e=(t=c.getGraphDiv(t))._fullLayout||{};if(!(!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r))return new Promise((function(e){setTimeout((function(){o.getComponentMethod(\"annotations\",\"draw\")(t),o.getComponentMethod(\"legend\",\"draw\")(t),o.getComponentMethod(\"colorbar\",\"draw\")(t),e(x.previousPromises(t))}),300)}))},x.resize=function(t){var e;t=c.getGraphDiv(t);var r=new Promise((function(r,n){t&&!c.isHidden(t)||n(new Error(\"Resize must be passed a displayed plot div element.\")),t._redrawTimer&&clearTimeout(t._redrawTimer),t._resolveResize&&(e=t._resolveResize),t._resolveResize=r,t._redrawTimer=setTimeout((function(){if(!t.layout||t.layout.width&&t.layout.height||c.isHidden(t))r(t);else{delete t.layout.width,delete t.layout.height;var e=t.changed;t.autoplay=!0,o.call(\"relayout\",t,{autosize:!0}).then((function(){t.changed=e,t._resolveResize===r&&(delete t._resolveResize,r(t))}))}}),100)}));return e&&e(r),r},x.previousPromises=function(t){if((t._promises||[]).length)return Promise.all(t._promises).then((function(){t._promises=[]}))},x.addLinks=function(t){if(t._context.showLink||t._context.showSources){var e=t._fullLayout,r=c.ensureSingle(e._paper,\"text\",\"js-plot-link-container\",(function(t){t.style({\"font-family\":'\"Open Sans\", Arial, sans-serif',\"font-size\":\"12px\",fill:u.defaultLine,\"pointer-events\":\"all\"}).each((function(){var t=n.select(this);t.append(\"tspan\").classed(\"js-link-to-tool\",!0),t.append(\"tspan\").classed(\"js-link-spacer\",!0),t.append(\"tspan\").classed(\"js-sourcelinks\",!0)}))})),i=r.node(),a={y:e._paper.attr(\"height\")-9};document.body.contains(i)&&i.getComputedTextLength()>=e.width-20?(a[\"text-anchor\"]=\"start\",a.x=5):(a[\"text-anchor\"]=\"end\",a.x=e._paper.attr(\"width\")-7),r.attr(a);var o=r.select(\".js-link-to-tool\"),s=r.select(\".js-link-spacer\"),l=r.select(\".js-sourcelinks\");t._context.showSources&&t._context.showSources(t),t._context.showLink&&function(t,e){e.text(\"\");var r=e.append(\"a\").attr({\"xlink:xlink:href\":\"#\",class:\"link--impt link--embedview\",\"font-weight\":\"bold\"}).text(t._context.linkText+\" \"+String.fromCharCode(187));if(t._context.sendData)r.on(\"click\",(function(){x.sendDataToCloud(t)}));else{var n=window.location.pathname.split(\"/\"),i=window.location.search;r.attr({\"xlink:xlink:show\":\"new\",\"xlink:xlink:href\":\"/\"+n[2].split(\".\")[0]+\"/\"+n[1]+i})}}(t,o),s.text(o.text()&&l.text()?\" - \":\"\")}},x.sendDataToCloud=function(t){var e=(window.PLOTLYENV||{}).BASE_URL||t._context.plotlyServerURL;if(e){t.emit(\"plotly_beforeexport\");var r=n.select(t).append(\"div\").attr(\"id\",\"hiddenform\").style(\"display\",\"none\"),i=r.append(\"form\").attr({action:e+\"/external\",method:\"post\",target:\"_blank\"});return i.append(\"input\").attr({type:\"text\",name:\"data\"}).node().value=x.graphJson(t,!1,\"keepdata\"),i.node().submit(),r.remove(),t.emit(\"plotly_afterexport\"),!1}};var w=[\"days\",\"shortDays\",\"months\",\"shortMonths\",\"periods\",\"dateTime\",\"date\",\"time\",\"decimal\",\"thousands\",\"grouping\",\"currency\"],T=[\"year\",\"month\",\"dayMonth\",\"dayMonthYear\"];function k(t,e){var r=t._context.locale;r||(r=\"en-US\");var n=!1,i={};function a(t){for(var r=!0,a=0;a<e.length;a++){var o=e[a];i[o]||(t[o]?i[o]=t[o]:r=!1)}r&&(n=!0)}for(var s=0;s<2;s++){for(var l=t._context.locales,c=0;c<2;c++){var u=(l[r]||{}).format;if(u&&(a(u),n))break;l=o.localeRegistry}var f=r.split(\"-\")[0];if(n||f===r)break;r=f}return n||a(o.localeRegistry.en.format),i}function M(t,e){var r={_fullLayout:e},n=\"x\"===t._id.charAt(0),i=t._mainAxis._anchorAxis,a=\"\",o=\"\",s=\"\";if(i&&(s=i._mainAxis._id,a=n?t._id+s:s+t._id),!a||!e._plots[a]){a=\"\";for(var l=t._counterAxes,c=0;c<l.length;c++){var u=l[c],f=n?t._id+u:u+t._id;o||(o=f);var p=h.getFromId(r,u);if(s&&p.overlaying===s){a=f;break}}}return a||o}function A(t){var e=t.transforms;if(Array.isArray(e)&&e.length)for(var r=0;r<e.length;r++){var n=e[r],i=n._module||b[n.type];if(i&&i.makesData)return!0}return!1}function S(t,e,r,n){for(var i=t.transforms,a=[t],o=0;o<i.length;o++){var s=i[o],l=b[s.type];l&&l.transform&&(a=l.transform(a,{transform:s,fullTrace:t,fullData:e,layout:r,fullLayout:n,transformIndex:o}))}return a}function E(t){return\"string\"==typeof t&&\"px\"===t.substr(t.length-2)&&parseFloat(t)}function C(t){var e=t.margin;if(!t._size){var r=t._size={l:Math.round(e.l),r:Math.round(e.r),t:Math.round(e.t),b:Math.round(e.b),p:Math.round(e.pad)};r.w=Math.round(t.width)-r.l-r.r,r.h=Math.round(t.height)-r.t-r.b}t._pushmargin||(t._pushmargin={}),t._pushmarginIds||(t._pushmarginIds={})}x.supplyDefaults=function(t,e){var r=e&&e.skipUpdateCalc,a=t._fullLayout||{};if(a._skipDefaults)delete a._skipDefaults;else{var s,l=t._fullLayout={},u=t.layout||{},f=t._fullData||[],h=t._fullData=[],d=t.data||[],g=t.calcdata||[],m=t._context||{};t._transitionData||x.createTransitionData(t),l._dfltTitle={plot:y(t,\"Click to enter Plot title\"),x:y(t,\"Click to enter X axis title\"),y:y(t,\"Click to enter Y axis title\"),colorbar:y(t,\"Click to enter Colorscale title\"),annotation:y(t,\"new text\")},l._traceWord=y(t,\"trace\");var b=k(t,w);if(l._mapboxAccessToken=m.mapboxAccessToken,a._initialAutoSizeIsDone){var _=a.width,M=a.height;x.supplyLayoutGlobalDefaults(u,l,b),u.width||(l.width=_),u.height||(l.height=M),x.sanitizeMargins(l)}else{x.supplyLayoutGlobalDefaults(u,l,b);var A=!u.width||!u.height,S=l.autosize,E=m.autosizable;A&&(S||E)?x.plotAutoSize(t,u,l):A&&x.sanitizeMargins(l),!S&&A&&(u.width=l.width,u.height=l.height)}l._d3locale=function(t,e){return t.decimal=e.charAt(0),t.thousands=e.charAt(1),{numberFormat:n.locale(t).numberFormat,timeFormat:i(t).utcFormat}}(b,l.separators),l._extraFormat=k(t,T),l._initialAutoSizeIsDone=!0,l._dataLength=d.length,l._modules=[],l._visibleModules=[],l._basePlotModules=[];var L=l._subplots=function(){var t,e,r=o.collectableSubplotTypes,n={};if(!r){r=[];var i=o.subplotsRegistry;for(var a in i){var s=i[a].attr;if(s&&(r.push(a),Array.isArray(s)))for(e=0;e<s.length;e++)c.pushUnique(r,s[e])}}for(t=0;t<r.length;t++)n[r[t]]=[];return n}(),I=l._splomAxes={x:{},y:{}},P=l._splomSubplots={};l._splomGridDflt={},l._scatterStackOpts={},l._firstScatter={},l._alignmentOpts={},l._colorAxes={},l._requestRangeslider={},l._traceUids=function(t,e){var r,n,i=e.length,a=[];for(r=0;r<t.length;r++){var o=t[r]._fullInput;o!==n&&a.push(o),n=o}var s=a.length,l=new Array(i),u={};function f(t,e){l[e]=t,u[t]=1}function h(t,e){if(t&&\"string\"==typeof t&&!u[t])return f(t,e),!0}for(r=0;r<i;r++){var p=e[r].uid;\"number\"==typeof p&&(p=String(p)),h(p,r)||(r<s&&h(a[r].uid,r)||f(c.randstr(u),r))}return l}(f,d),l._globalTransforms=(t._context||{}).globalTransforms,x.supplyDataDefaults(d,h,u,l);var z=Object.keys(I.x),O=Object.keys(I.y);if(z.length>1&&O.length>1){for(o.getComponentMethod(\"grid\",\"sizeDefaults\")(u,l),s=0;s<z.length;s++)c.pushUnique(L.xaxis,z[s]);for(s=0;s<O.length;s++)c.pushUnique(L.yaxis,O[s]);for(var D in P)c.pushUnique(L.cartesian,D)}if(l._has=x._hasPlotType.bind(l),f.length===h.length)for(s=0;s<h.length;s++)v(h[s],f[s]);x.supplyLayoutModuleDefaults(u,l,h,t._transitionData);var R=l._visibleModules,F=[];for(s=0;s<R.length;s++){var B=R[s].crossTraceDefaults;B&&c.pushUnique(F,B)}for(s=0;s<F.length;s++)F[s](h,l);l._hasOnlyLargeSploms=1===l._basePlotModules.length&&\"splom\"===l._basePlotModules[0].name&&z.length>15&&O.length>15&&0===l.shapes.length&&0===l.images.length,l._hasCartesian=l._has(\"cartesian\"),l._hasGeo=l._has(\"geo\"),l._hasGL3D=l._has(\"gl3d\"),l._hasGL2D=l._has(\"gl2d\"),l._hasTernary=l._has(\"ternary\"),l._hasPie=l._has(\"pie\"),x.linkSubplots(h,l,f,a),x.cleanPlot(h,l,f,a);var N=!(!a._has||!a._has(\"gl2d\")),j=!(!l._has||!l._has(\"gl2d\")),U=!(!a._has||!a._has(\"cartesian\"))||N,V=!(!l._has||!l._has(\"cartesian\"))||j;U&&!V?a._bgLayer.remove():V&&!U&&(l._shouldCreateBgLayer=!0),a._zoomlayer&&!t._dragging&&p({_fullLayout:a}),function(t,e){var r,n=[];e.meta&&(r=e._meta={meta:e.meta,layout:{meta:e.meta}});for(var i=0;i<t.length;i++){var a=t[i];a.meta?n[a.index]=a._meta={meta:a.meta}:e.meta&&(a._meta={meta:e.meta}),e.meta&&(a._meta.layout={meta:e.meta})}n.length&&(r||(r=e._meta={}),r.data=n)}(h,l),v(l,a),o.getComponentMethod(\"colorscale\",\"crossTraceDefaults\")(h,l),l._preGUI||(l._preGUI={}),l._tracePreGUI||(l._tracePreGUI={});var q,H=l._tracePreGUI,G={};for(q in H)G[q]=\"old\";for(s=0;s<h.length;s++)G[q=h[s]._fullInput.uid]||(H[q]={}),G[q]=\"new\";for(q in G)\"old\"===G[q]&&delete H[q];C(l),o.getComponentMethod(\"rangeslider\",\"makeData\")(l),r||g.length!==h.length||x.supplyDefaultsUpdateCalc(g,h)}},x.supplyDefaultsUpdateCalc=function(t,e){for(var r=0;r<e.length;r++){var n=e[r],i=(t[r]||[])[0];if(i&&i.trace){var a=i.trace;if(a._hasCalcTransform){var o,s,l,u=a._arrayAttrs;for(o=0;o<u.length;o++)s=u[o],l=c.nestedProperty(a,s).get().slice(),c.nestedProperty(n,s).set(l)}i.trace=n}}},x.createTransitionData=function(t){t._transitionData||(t._transitionData={}),t._transitionData._frames||(t._transitionData._frames=[]),t._transitionData._frameHash||(t._transitionData._frameHash={}),t._transitionData._counter||(t._transitionData._counter=0),t._transitionData._interruptCallbacks||(t._transitionData._interruptCallbacks=[])},x._hasPlotType=function(t){var e,r=this._basePlotModules||[];for(e=0;e<r.length;e++)if(r[e].name===t)return!0;var n=this._modules||[];for(e=0;e<n.length;e++){var i=n[e].name;if(i===t)return!0;var a=o.modules[i];if(a&&a.categories[t])return!0}return!1},x.cleanPlot=function(t,e,r,n){var i,a,o=n._basePlotModules||[];for(i=0;i<o.length;i++){var s=o[i];s.clean&&s.clean(t,e,r,n)}var l=n._has&&n._has(\"gl\"),c=e._has&&e._has(\"gl\");l&&!c&&void 0!==n._glcontainer&&(n._glcontainer.selectAll(\".gl-canvas\").remove(),n._glcontainer.selectAll(\".no-webgl\").remove(),n._glcanvas=null);var u=!!n._infolayer;t:for(i=0;i<r.length;i++){var f=r[i].uid;for(a=0;a<t.length;a++){if(f===t[a].uid)continue t}u&&n._infolayer.select(\".cb\"+f).remove()}},x.linkSubplots=function(t,e,r,n){var i,a,s=n._plots||{},l=e._plots={},u=e._subplots,f={_fullData:t,_fullLayout:e},p=u.cartesian.concat(u.gl2d||[]);for(i=0;i<p.length;i++){var d,g=p[i],m=s[g],v=h.getFromId(f,g,\"x\"),y=h.getFromId(f,g,\"y\");for(m?d=l[g]=m:(d=l[g]={}).id=g,v._counterAxes.push(y._id),y._counterAxes.push(v._id),v._subplotsWith.push(g),y._subplotsWith.push(g),d.xaxis=v,d.yaxis=y,d._hasClipOnAxisFalse=!1,a=0;a<t.length;a++){var x=t[a];if(x.xaxis===d.xaxis._id&&x.yaxis===d.yaxis._id&&!1===x.cliponaxis){d._hasClipOnAxisFalse=!0;break}}}var b,_=h.list(f,null,!0);for(i=0;i<_.length;i++){var w=null;(b=_[i]).overlaying&&(w=h.getFromId(f,b.overlaying))&&w.overlaying&&(b.overlaying=!1,w=null),b._mainAxis=w||b,w&&(b.domain=w.domain.slice()),b._anchorAxis=\"free\"===b.anchor?null:h.getFromId(f,b.anchor)}for(i=0;i<_.length;i++)if((b=_[i])._counterAxes.sort(h.idSort),b._subplotsWith.sort(c.subplotSort),b._mainSubplot=M(b,e),b._counterAxes.length&&(b.spikemode&&-1!==b.spikemode.indexOf(\"across\")||b.automargin&&b.mirror&&\"free\"!==b.anchor||o.getComponentMethod(\"rangeslider\",\"isVisible\")(b))){var T=1,k=0;for(a=0;a<b._counterAxes.length;a++){var A=h.getFromId(f,b._counterAxes[a]);T=Math.min(T,A.domain[0]),k=Math.max(k,A.domain[1])}T<k&&(b._counterDomainMin=T,b._counterDomainMax=k)}},x.clearExpandedTraceDefaultColors=function(t){var e,r,n;for(r=[],(e=t._module._colorAttrs)||(t._module._colorAttrs=e=[],s.crawl(t._module.attributes,(function(t,n,i,a){r[a]=n,r.length=a+1,\"color\"===t.valType&&void 0===t.dflt&&e.push(r.join(\".\"))}))),n=0;n<e.length;n++){c.nestedProperty(t,\"_input.\"+e[n]).get()||c.nestedProperty(t,e[n]).set(null)}},x.supplyDataDefaults=function(t,e,r,n){var i,a,s,u=n._modules,f=n._visibleModules,h=n._basePlotModules,p=0,d=0;function g(t){e.push(t);var r=t._module;r&&(c.pushUnique(u,r),!0===t.visible&&c.pushUnique(f,r),c.pushUnique(h,t._module.basePlotModule),p++,!1!==t._input.visible&&d++)}n._transformModules=[];var m={},y=[],b=(r.template||{}).data||{},_=l.traceTemplater(b);for(i=0;i<t.length;i++){if(s=t[i],(a=_.newTrace(s)).uid=n._traceUids[i],x.supplyTraceDefaults(s,a,d,n,i),a.index=i,a._input=s,a._expandedIndex=p,a.transforms&&a.transforms.length)for(var w=!1!==s.visible&&!1===a.visible,T=S(a,e,r,n),k=0;k<T.length;k++){var M=T[k],A={_template:a._template,type:a.type,uid:a.uid+k};w&&!1===M.visible&&delete M.visible,x.supplyTraceDefaults(M,A,p,n,i),v(A,M),A.index=i,A._input=s,A._fullInput=a,A._expandedIndex=p,A._expandedInput=M,g(A)}else a._fullInput=a,a._expandedInput=a,g(a);o.traceIs(a,\"carpetAxis\")&&(m[a.carpet]=a),o.traceIs(a,\"carpetDependent\")&&y.push(i)}for(i=0;i<y.length;i++)if((a=e[y[i]]).visible){var E=m[a.carpet];a._carpet=E,E&&E.visible?(a.xaxis=E.xaxis,a.yaxis=E.yaxis):a.visible=!1}},x.supplyAnimationDefaults=function(t){var e;t=t||{};var r={};function n(e,n){return c.coerce(t||{},r,d,e,n)}if(n(\"mode\"),n(\"direction\"),n(\"fromcurrent\"),Array.isArray(t.frame))for(r.frame=[],e=0;e<t.frame.length;e++)r.frame[e]=x.supplyAnimationFrameDefaults(t.frame[e]||{});else r.frame=x.supplyAnimationFrameDefaults(t.frame||{});if(Array.isArray(t.transition))for(r.transition=[],e=0;e<t.transition.length;e++)r.transition[e]=x.supplyAnimationTransitionDefaults(t.transition[e]||{});else r.transition=x.supplyAnimationTransitionDefaults(t.transition||{});return r},x.supplyAnimationFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.frame,r,n)}return r(\"duration\"),r(\"redraw\"),e},x.supplyAnimationTransitionDefaults=function(t){var e={};function r(r,n){return c.coerce(t||{},e,d.transition,r,n)}return r(\"duration\"),r(\"easing\"),e},x.supplyFrameDefaults=function(t){var e={};function r(r,n){return c.coerce(t,e,g,r,n)}return r(\"group\"),r(\"name\"),r(\"traces\"),r(\"baseframe\"),r(\"data\"),r(\"layout\"),e},x.supplyTraceDefaults=function(t,e,r,n,i){var a,s=n.colorway||u.defaults,l=s[r%s.length];function f(r,n){return c.coerce(t,e,x.attributes,r,n)}var h=f(\"visible\");f(\"type\"),f(\"name\",n._traceWord+\" \"+i),f(\"uirevision\",n.uirevision);var p=x.getModule(e);if(e._module=p,p){var d=p.basePlotModule,g=d.attr,m=d.attributes;if(g&&m){var v=n._subplots,y=\"\";if(h||\"gl2d\"!==d.name){if(Array.isArray(g))for(a=0;a<g.length;a++){var b=g[a],_=c.coerce(t,e,m,b);v[b]&&c.pushUnique(v[b],_),y+=_}else y=c.coerce(t,e,m,g);v[d.name]&&c.pushUnique(v[d.name],y)}}}return h&&(f(\"customdata\"),f(\"ids\"),f(\"meta\"),o.traceIs(e,\"showLegend\")?(c.coerce(t,e,p.attributes.showlegend?p.attributes:x.attributes,\"showlegend\"),f(\"legendgroup\"),e._dfltShowLegend=!0):e._dfltShowLegend=!1,p&&p.supplyDefaults(t,e,l,n),o.traceIs(e,\"noOpacity\")||f(\"opacity\"),o.traceIs(e,\"notLegendIsolatable\")&&(e.visible=!!e.visible),o.traceIs(e,\"noHover\")||(e.hovertemplate||c.coerceHoverinfo(t,e,n),\"parcats\"!==e.type&&o.getComponentMethod(\"fx\",\"supplyDefaults\")(t,e,l,n)),p&&p.selectPoints&&f(\"selectedpoints\"),x.supplyTransformDefaults(t,e,n)),e},x.hasMakesDataTransform=A,x.supplyTransformDefaults=function(t,e,r){if(e._length||A(t)){var n=r._globalTransforms||[],i=r._transformModules||[];if(Array.isArray(t.transforms)||0!==n.length)for(var a=t.transforms||[],o=n.concat(a),s=e.transforms=[],l=0;l<o.length;l++){var u,f=o[l],h=f.type,p=b[h],d=!(f._module&&f._module===p),g=p&&\"function\"==typeof p.transform;p||c.warn(\"Unrecognized transform type \"+h+\".\"),p&&p.supplyDefaults&&(d||g)?((u=p.supplyDefaults(f,e,r,t)).type=h,u._module=p,c.pushUnique(i,p)):u=c.extendFlat({},f),s.push(u)}}},x.supplyLayoutGlobalDefaults=function(t,e,r){function n(r,n){return c.coerce(t,e,x.layoutAttributes,r,n)}var i=t.template;c.isPlainObject(i)&&(e.template=i,e._template=i.layout,e._dataTemplate=i.data),n(\"autotypenumbers\");var a=c.coerceFont(n,\"font\");n(\"title.text\",e._dfltTitle.plot),c.coerceFont(n,\"title.font\",{family:a.family,size:Math.round(1.4*a.size),color:a.color}),n(\"title.xref\"),n(\"title.yref\"),n(\"title.x\"),n(\"title.y\"),n(\"title.xanchor\"),n(\"title.yanchor\"),n(\"title.pad.t\"),n(\"title.pad.r\"),n(\"title.pad.b\"),n(\"title.pad.l\"),n(\"uniformtext.mode\")&&n(\"uniformtext.minsize\"),n(\"autosize\",!(t.width&&t.height)),n(\"width\"),n(\"height\"),n(\"margin.l\"),n(\"margin.r\"),n(\"margin.t\"),n(\"margin.b\"),n(\"margin.pad\"),n(\"margin.autoexpand\"),t.width&&t.height&&x.sanitizeMargins(e),o.getComponentMethod(\"grid\",\"sizeDefaults\")(t,e),n(\"paper_bgcolor\"),n(\"separators\",r.decimal+r.thousands),n(\"hidesources\"),n(\"colorway\"),n(\"datarevision\");var s=n(\"uirevision\");n(\"editrevision\",s),n(\"selectionrevision\",s),n(\"modebar.orientation\"),n(\"modebar.bgcolor\",u.addOpacity(e.paper_bgcolor,.5));var l=u.contrast(u.rgb(e.modebar.bgcolor));n(\"modebar.color\",u.addOpacity(l,.3)),n(\"modebar.activecolor\",u.addOpacity(l,.7)),n(\"modebar.uirevision\",s),o.getComponentMethod(\"shapes\",\"supplyDrawNewShapeDefaults\")(t,e,n),n(\"meta\"),c.isPlainObject(t.transition)&&(n(\"transition.duration\"),n(\"transition.easing\"),n(\"transition.ordering\")),o.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\"),o.getComponentMethod(\"fx\",\"supplyLayoutGlobalDefaults\")(t,e,n)},x.plotAutoSize=function(t,e,r){var n,i,o=t._context||{},s=o.frameMargins,l=c.isPlotDiv(t);if(l&&t.emit(\"plotly_autosize\"),o.fillFrame)n=window.innerWidth,i=window.innerHeight,document.body.style.overflow=\"hidden\";else{var u=l?window.getComputedStyle(t):{};if(n=E(u.width)||E(u.maxWidth)||r.width,i=E(u.height)||E(u.maxHeight)||r.height,a(s)&&s>0){var f=1-2*s;n=Math.round(f*n),i=Math.round(f*i)}}var h=x.layoutAttributes.width.min,p=x.layoutAttributes.height.min;n<h&&(n=h),i<p&&(i=p);var d=!e.width&&Math.abs(r.width-n)>1,g=!e.height&&Math.abs(r.height-i)>1;(g||d)&&(d&&(r.width=n),g&&(r.height=i)),t._initialAutoSize||(t._initialAutoSize={width:n,height:i}),x.sanitizeMargins(r)},x.supplyLayoutModuleDefaults=function(t,e,r,n){var i,a,s,l=o.componentsRegistry,u=e._basePlotModules,f=o.subplotsRegistry.cartesian;for(i in l)(s=l[i]).includeBasePlot&&s.includeBasePlot(t,e);for(var h in u.length||u.push(f),e._has(\"cartesian\")&&(o.getComponentMethod(\"grid\",\"contentDefaults\")(t,e),f.finalizeSubplots(t,e)),e._subplots)e._subplots[h].sort(c.subplotSort);for(a=0;a<u.length;a++)(s=u[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var p=e._modules;for(a=0;a<p.length;a++)(s=p[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r);var d=e._transformModules;for(a=0;a<d.length;a++)(s=d[a]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r,n);for(i in l)(s=l[i]).supplyLayoutDefaults&&s.supplyLayoutDefaults(t,e,r)},x.purge=function(t){var e=t._fullLayout||{};void 0!==e._glcontainer&&(e._glcontainer.selectAll(\".gl-canvas\").remove(),e._glcontainer.remove(),e._glcanvas=null),e._modeBar&&e._modeBar.destroy(),t._transitionData&&(t._transitionData._interruptCallbacks&&(t._transitionData._interruptCallbacks.length=0),t._transitionData._animationRaf&&window.cancelAnimationFrame(t._transitionData._animationRaf)),c.clearThrottle(),c.clearResponsive(t),delete t.data,delete t.layout,delete t._fullData,delete t._fullLayout,delete t.calcdata,delete t.framework,delete t.empty,delete t.fid,delete t.undoqueue,delete t.undonum,delete t.autoplay,delete t.changed,delete t._promises,delete t._redrawTimer,delete t._hmlumcount,delete t._hmpixcount,delete t._transitionData,delete t._transitioning,delete t._initialAutoSize,delete t._transitioningWithDuration,delete t._dragging,delete t._dragged,delete t._dragdata,delete t._hoverdata,delete t._snapshotInProgress,delete t._editing,delete t._mouseDownTime,delete t._legendMouseDownTime,t.removeAllListeners&&t.removeAllListeners()},x.style=function(t){var e,r=t._fullLayout._visibleModules,n=[];for(e=0;e<r.length;e++){var i=r[e];i.style&&c.pushUnique(n,i.style)}for(e=0;e<n.length;e++)n[e](t)},x.sanitizeMargins=function(t){if(t&&t.margin){var e,r=t.width,n=t.height,i=t.margin,a=r-(i.l+i.r),o=n-(i.t+i.b);a<0&&(e=(r-1)/(i.l+i.r),i.l=Math.floor(e*i.l),i.r=Math.floor(e*i.r)),o<0&&(e=(n-1)/(i.t+i.b),i.t=Math.floor(e*i.t),i.b=Math.floor(e*i.b))}},x.clearAutoMarginIds=function(t){t._fullLayout._pushmarginIds={}},x.allowAutoMargin=function(t,e){t._fullLayout._pushmarginIds[e]=1};x.autoMargin=function(t,e,r){var n=t._fullLayout,i=n.width,a=n.height,o=n.margin,s=c.constrain(i-o.l-o.r,2,64),l=c.constrain(a-o.t-o.b,2,64),u=Math.max(0,i-s),f=Math.max(0,a-l),h=n._pushmargin,p=n._pushmarginIds;if(!1!==o.autoexpand){if(r){var d=r.pad;if(void 0===d&&(d=Math.min(12,o.l,o.r,o.t,o.b)),u){var g=(r.l+r.r)/u;g>1&&(r.l/=g,r.r/=g)}if(f){var m=(r.t+r.b)/f;m>1&&(r.t/=m,r.b/=m)}var v=void 0!==r.xl?r.xl:r.x,y=void 0!==r.xr?r.xr:r.x,b=void 0!==r.yt?r.yt:r.y,_=void 0!==r.yb?r.yb:r.y;h[e]={l:{val:v,size:r.l+d},r:{val:y,size:r.r+d},b:{val:_,size:r.b+d},t:{val:b,size:r.t+d}},p[e]=1}else delete h[e],delete p[e];if(!n._replotting)return x.doAutoMargin(t)}},x.doAutoMargin=function(t){var e=t._fullLayout,r=e.width,n=e.height;e._size||(e._size={}),C(e);var i=e._size,s=e.margin,l=c.extendFlat({},i),u=s.l,f=s.r,p=s.t,d=s.b,g=e._pushmargin,m=e._pushmarginIds;if(!1!==e.margin.autoexpand){for(var v in g)m[v]||delete g[v];for(var y in g.base={l:{val:0,size:u},r:{val:1,size:f},t:{val:1,size:p},b:{val:0,size:d}},g){var b=g[y].l||{},_=g[y].b||{},w=b.val,T=b.size,k=_.val,M=_.size;for(var A in g){if(a(T)&&g[A].r){var S=g[A].r.val,E=g[A].r.size;if(S>w){var L=(T*S+(E-r)*w)/(S-w),I=(E*(1-w)+(T-r)*(1-S))/(S-w);L+I>u+f&&(u=L,f=I)}}if(a(M)&&g[A].t){var P=g[A].t.val,z=g[A].t.size;if(P>k){var O=(M*P+(z-n)*k)/(P-k),D=(z*(1-k)+(M-n)*(1-P))/(P-k);O+D>d+p&&(d=O,p=D)}}}}}var R=c.constrain(r-s.l-s.r,2,64),F=c.constrain(n-s.t-s.b,2,64),B=Math.max(0,r-R),N=Math.max(0,n-F);if(B){var j=(u+f)/B;j>1&&(u/=j,f/=j)}if(N){var U=(d+p)/N;U>1&&(d/=U,p/=U)}if(i.l=Math.round(u),i.r=Math.round(f),i.t=Math.round(p),i.b=Math.round(d),i.p=Math.round(s.pad),i.w=Math.round(r)-i.l-i.r,i.h=Math.round(n)-i.t-i.b,!e._replotting&&x.didMarginChange(l,i)){\"_redrawFromAutoMarginCount\"in e?e._redrawFromAutoMarginCount++:e._redrawFromAutoMarginCount=1;var V=3*(1+Object.keys(m).length);if(e._redrawFromAutoMarginCount<V)return o.call(\"plot\",t);e._size=l,c.warn(\"Too many auto-margin redraws.\")}!function(t){for(var e=h.list(t,\"\",!0),r=0;r<e.length;r++){var n=e[r]._hideOutOfRangeInsideTickLabels;n&&n()}}(t)};var L=[\"l\",\"r\",\"t\",\"b\",\"p\",\"w\",\"h\"];function I(t,e,r){var n=!1;var i=[x.previousPromises,function(){if(t._transitionData)return t._transitioning=!1,function(t){var e=Promise.resolve();if(!t)return e;for(;t.length;)e=e.then(t.shift());return e}(t._transitionData._interruptCallbacks)},r.prepareFn,x.rehover,function(){return t.emit(\"plotly_transitioning\",[]),new Promise((function(i){t._transitioning=!0,e.duration>0&&(t._transitioningWithDuration=!0),t._transitionData._interruptCallbacks.push((function(){n=!0})),r.redraw&&t._transitionData._interruptCallbacks.push((function(){return o.call(\"redraw\",t)})),t._transitionData._interruptCallbacks.push((function(){t.emit(\"plotly_transitioninterrupted\",[])}));var a=0,s=0;function l(){return a++,function(){s++,n||s!==a||function(e){if(!t._transitionData)return;(function(t){if(t)for(;t.length;)t.shift()})(t._transitionData._interruptCallbacks),Promise.resolve().then((function(){if(r.redraw)return o.call(\"redraw\",t)})).then((function(){t._transitioning=!1,t._transitioningWithDuration=!1,t.emit(\"plotly_transitioned\",[])})).then(e)}(i)}}r.runFn(l),setTimeout(l())}))}],a=c.syncOrAsync(i,t);return a&&a.then||(a=Promise.resolve()),a.then((function(){return t}))}x.didMarginChange=function(t,e){for(var r=0;r<L.length;r++){var n=L[r],i=t[n],o=e[n];if(!a(i)||Math.abs(o-i)>1)return!0}return!1},x.graphJson=function(t,e,r,n,i,a){(i&&e&&!t._fullData||i&&!e&&!t._fullLayout)&&x.supplyDefaults(t);var o=i?t._fullData:t.data,s=i?t._fullLayout:t.layout,l=(t._transitionData||{})._frames;function u(t,e){if(\"function\"==typeof t)return e?\"_function_\":null;if(c.isPlainObject(t)){var n,i={};return Object.keys(t).sort().forEach((function(a){if(-1===[\"_\",\"[\"].indexOf(a.charAt(0)))if(\"function\"!=typeof t[a]){if(\"keepdata\"===r){if(\"src\"===a.substr(a.length-3))return}else if(\"keepstream\"===r){if(\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0&&!c.isPlainObject(t.stream))return}else if(\"keepall\"!==r&&\"string\"==typeof(n=t[a+\"src\"])&&n.indexOf(\":\")>0)return;i[a]=u(t[a],e)}else e&&(i[a]=\"_function\")})),i}return Array.isArray(t)?t.map((function(t){return u(t,e)})):c.isTypedArray(t)?c.simpleMap(t,c.identity):c.isJSDate(t)?c.ms2DateTimeLocal(+t):t}var f={data:(o||[]).map((function(t){var r=u(t);return e&&delete r.fit,r}))};if(!e&&(f.layout=u(s),i)){var h=s._size;f.layout.computed={margin:{b:h.b,l:h.l,r:h.r,t:h.t}}}return t.framework&&t.framework.isPolar&&(f=t.framework.getConfig()),l&&(f.frames=u(l)),a&&(f.config=u(t._context,!0)),\"object\"===n?f:JSON.stringify(f)},x.modifyFrames=function(t,e){var r,n,i,a=t._transitionData._frames,o=t._transitionData._frameHash;for(r=0;r<e.length;r++)switch((n=e[r]).type){case\"replace\":i=n.value;var s=(a[n.index]||{}).name,l=i.name;a[n.index]=o[l]=i,l!==s&&(delete o[s],o[l]=i);break;case\"insert\":o[(i=n.value).name]=i,a.splice(n.index,0,i);break;case\"delete\":delete o[(i=a[n.index]).name],a.splice(n.index,1)}return Promise.resolve()},x.computeFrame=function(t,e){var r,n,i,a,o=t._transitionData._frameHash;if(!e)throw new Error(\"computeFrame must be given a string frame name\");var s=o[e.toString()];if(!s)return!1;for(var l=[s],c=[s.name];s.baseframe&&(s=o[s.baseframe.toString()])&&-1===c.indexOf(s.name);)l.push(s),c.push(s.name);for(var u={};s=l.pop();)if(s.layout&&(u.layout=x.extendLayout(u.layout,s.layout)),s.data){if(u.data||(u.data=[]),!(n=s.traces))for(n=[],r=0;r<s.data.length;r++)n[r]=r;for(u.traces||(u.traces=[]),r=0;r<s.data.length;r++)null!=(i=n[r])&&(-1===(a=u.traces.indexOf(i))&&(a=u.data.length,u.traces[a]=i),u.data[a]=x.extendTrace(u.data[a],s.data[r]))}return u},x.recomputeFrameHash=function(t){for(var e=t._transitionData._frameHash={},r=t._transitionData._frames,n=0;n<r.length;n++){var i=r[n];i&&i.name&&(e[i.name]=i)}},x.extendObjectWithContainers=function(t,e,r){var n,i,a,o,s,l,u,f=c.extendDeepNoArrays({},e||{}),h=c.expandObjectPaths(f),p={};if(r&&r.length)for(a=0;a<r.length;a++)void 0===(i=(n=c.nestedProperty(h,r[a])).get())?c.nestedProperty(p,r[a]).set(null):(n.set(null),c.nestedProperty(p,r[a]).set(i));if(t=c.extendDeepNoArrays(t||{},h),r&&r.length)for(a=0;a<r.length;a++)if(l=c.nestedProperty(p,r[a]).get()){for(u=(s=c.nestedProperty(t,r[a])).get(),Array.isArray(u)||(u=[],s.set(u)),o=0;o<l.length;o++){var d=l[o];u[o]=null===d?null:x.extendObjectWithContainers(u[o],d)}s.set(u)}return t},x.dataArrayContainers=[\"transforms\",\"dimensions\"],x.layoutArrayContainers=o.layoutArrayContainers,x.extendTrace=function(t,e){return x.extendObjectWithContainers(t,e,x.dataArrayContainers)},x.extendLayout=function(t,e){return x.extendObjectWithContainers(t,e,x.layoutArrayContainers)},x.transition=function(t,e,r,n,i,a){var o={redraw:i.redraw},s={},l=[];return o.prepareFn=function(){for(var i=Array.isArray(e)?e.length:0,a=n.slice(0,i),o=0;o<a.length;o++){var u=a[o],f=t._fullData[u]._module;if(f){if(f.animatable){var h=f.basePlotModule.name;s[h]||(s[h]=[]),s[h].push(u)}t.data[a[o]]=x.extendTrace(t.data[a[o]],e[o])}}var p=c.expandObjectPaths(c.extendDeepNoArrays({},r)),d=/^[xy]axis[0-9]*$/;for(var g in p)d.test(g)&&delete p[g].range;x.extendLayout(t.layout,p),delete t.calcdata,x.supplyDefaults(t),x.doCalcdata(t);var m=c.expandObjectPaths(r);if(m){var v=t._fullLayout._plots;for(var y in v){var b=v[y],_=b.xaxis,w=b.yaxis,T=_.range.slice(),k=w.range.slice(),M=null,A=null,S=null,E=null;Array.isArray(m[_._name+\".range\"])?M=m[_._name+\".range\"].slice():Array.isArray((m[_._name]||{}).range)&&(M=m[_._name].range.slice()),Array.isArray(m[w._name+\".range\"])?A=m[w._name+\".range\"].slice():Array.isArray((m[w._name]||{}).range)&&(A=m[w._name].range.slice()),T&&M&&(_.r2l(T[0])!==_.r2l(M[0])||_.r2l(T[1])!==_.r2l(M[1]))&&(S={xr0:T,xr1:M}),k&&A&&(w.r2l(k[0])!==w.r2l(A[0])||w.r2l(k[1])!==w.r2l(A[1]))&&(E={yr0:k,yr1:A}),(S||E)&&l.push(c.extendFlat({plotinfo:b},S,E))}}return Promise.resolve()},o.runFn=function(e){var n,i,o=t._fullLayout._basePlotModules,u=l.length;if(r)for(i=0;i<o.length;i++)o[i].transitionAxes&&o[i].transitionAxes(t,l,a,e);for(var f in u?((n=c.extendFlat({},a)).duration=0,delete s.cartesian):n=a,s){var h=s[f];t._fullData[h[0]]._module.basePlotModule.plot(t,h,n,e)}},I(t,a,o)},x.transitionFromReact=function(t,e,r,n){var i=t._fullLayout,a=i.transition,o={},s=[];return o.prepareFn=function(){var t=i._plots;for(var a in o.redraw=!1,\"some\"===e.anim&&(o.redraw=!0),\"some\"===r.anim&&(o.redraw=!0),t){var l=t[a],u=l.xaxis,f=l.yaxis,h=n[u._name].range.slice(),p=n[f._name].range.slice(),d=u.range.slice(),g=f.range.slice();u.setScale(),f.setScale();var m=null,v=null;u.r2l(h[0])===u.r2l(d[0])&&u.r2l(h[1])===u.r2l(d[1])||(m={xr0:h,xr1:d}),f.r2l(p[0])===f.r2l(g[0])&&f.r2l(p[1])===f.r2l(g[1])||(v={yr0:p,yr1:g}),(m||v)&&s.push(c.extendFlat({plotinfo:l},m,v))}return Promise.resolve()},o.runFn=function(r){for(var n,i,o,l=t._fullData,u=t._fullLayout._basePlotModules,f=[],h=0;h<l.length;h++)f.push(h);function p(){for(var e=0;e<u.length;e++)u[e].transitionAxes&&u[e].transitionAxes(t,s,n,r)}function d(){for(var e=0;e<u.length;e++)u[e].plot(t,o,i,r)}s.length&&e.anim?\"traces first\"===a.ordering?(n=c.extendFlat({},a,{duration:0}),o=f,i=a,setTimeout(p,a.duration),d()):(n=a,o=null,i=c.extendFlat({},a,{duration:0}),setTimeout(d,n.duration),p()):s.length?(n=a,p()):e.anim&&(o=f,i=a,d())},I(t,a,o)},x.doCalcdata=function(t,e){var r,n,i,a,l=h.list(t),u=t._fullData,p=t._fullLayout,d=new Array(u.length),g=(t.calcdata||[]).slice();for(t.calcdata=d,p._numBoxes=0,p._numViolins=0,p._violinScaleGroupStats={},t._hmpixcount=0,t._hmlumcount=0,p._piecolormap={},p._sunburstcolormap={},p._treemapcolormap={},p._funnelareacolormap={},i=0;i<u.length;i++)Array.isArray(e)&&-1===e.indexOf(i)&&(d[i]=g[i]);for(i=0;i<u.length;i++)(r=u[i])._arrayAttrs=s.findArrayAttributes(r),r._extremes={};var m=p._subplots.polar||[];for(i=0;i<m.length;i++)l.push(p[m[i]].radialaxis,p[m[i]].angularaxis);for(var v in p._colorAxes){var y=p[v];!1!==y.cauto&&(delete y.cmin,delete y.cmax)}var x=!1;function _(e){if(r=u[e],n=r._module,!0===r.visible&&r.transforms){if(n&&n.calc){var i=n.calc(t,r);i[0]&&i[0].t&&i[0].t._scene&&delete i[0].t._scene.dirty}for(a=0;a<r.transforms.length;a++){var o=r.transforms[a];(n=b[o.type])&&n.calcTransform&&(r._hasCalcTransform=!0,x=!0,n.calcTransform(t,r,o))}}}function w(e,i){if(r=u[e],!!(n=r._module).isContainer===i){var o=[];if(!0===r.visible&&0!==r._length){delete r._indexToPoints;var s=r.transforms||[];for(a=s.length-1;a>=0;a--)if(s[a].enabled){r._indexToPoints=s[a]._indexToPoints;break}n&&n.calc&&(o=n.calc(t,r))}Array.isArray(o)&&o[0]||(o=[{x:f,y:f}]),o[0].t||(o[0].t={}),o[0].trace=r,d[e]=o}}for(z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)_(i);for(x&&z(l,u,p),i=0;i<u.length;i++)w(i,!0);for(i=0;i<u.length;i++)w(i,!1);O(t);var T=function(t,e){var r,n,i,a,s,l=[];function u(t,r,n){var i=r._id.charAt(0);if(\"histogram2dcontour\"===t){var a=r._counterAxes[0],o=h.getFromId(e,a),s=\"x\"===i||\"x\"===a&&\"category\"===o.type,l=\"y\"===i||\"y\"===a&&\"category\"===o.type;return function(t,e){return 0===t||0===e||s&&t===n[e].length-1||l&&e===n.length-1?-1:(\"y\"===i?e:t)-1}}return function(t,e){return\"y\"===i?e:t}}var f={min:function(t){return c.aggNums(Math.min,null,t)},max:function(t){return c.aggNums(Math.max,null,t)},sum:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},total:function(t){return c.aggNums((function(t,e){return t+e}),null,t)},mean:function(t){return c.mean(t)},median:function(t){return c.median(t)}};for(r=0;r<t.length;r++){var p=t[r];if(\"category\"===p.type){var d=p.categoryorder.match(P);if(d){var g=d[1],m=d[2],v=p._id.charAt(0),y=\"x\"===v,x=[];for(n=0;n<p._categories.length;n++)x.push([p._categories[n],[]]);for(n=0;n<p._traceIndices.length;n++){var b=p._traceIndices[n],_=e._fullData[b];if(!0===_.visible){var w=_.type;o.traceIs(_,\"histogram\")&&(delete _._xautoBinFinished,delete _._yautoBinFinished);var T=\"splom\"===w,k=\"scattergl\"===w,M=e.calcdata[b];for(i=0;i<M.length;i++){var A,S,E=M[i];if(T){var C=_._axesDim[p._id];if(!y){var L=_._diag[C][0];L&&(p=e._fullLayout[h.id2name(L)])}var I=E.trace.dimensions[C].values;for(a=0;a<I.length;a++)for(A=p._categoriesMap[I[a]],s=0;s<E.trace.dimensions.length;s++)if(s!==C){var z=E.trace.dimensions[s];x[A][1].push(z.values[a])}}else if(k){for(a=0;a<E.t.x.length;a++)y?(A=E.t.x[a],S=E.t.y[a]):(A=E.t.y[a],S=E.t.x[a]),x[A][1].push(S);E.t&&E.t._scene&&delete E.t._scene.dirty}else if(E.hasOwnProperty(\"z\")){S=E.z;var O=u(_.type,p,S);for(a=0;a<S.length;a++)for(s=0;s<S[a].length;s++)(A=O(s,a))+1&&x[A][1].push(S[a][s])}else for(void 0===(A=E.p)&&(A=E[v]),void 0===(S=E.s)&&(S=E.v),void 0===S&&(S=y?E.y:E.x),Array.isArray(S)||(S=void 0===S?[]:[S]),a=0;a<S.length;a++)x[A][1].push(S[a])}}}p._categoriesValue=x;var D=[];for(n=0;n<x.length;n++)D.push([x[n][0],f[g](x[n][1])]);D.sort((function(t,e){return t[1]-e[1]})),p._categoriesAggregatedValue=D,p._initialCategories=D.map((function(t){return t[0]})),\"descending\"===m&&p._initialCategories.reverse(),l=l.concat(p.sortByInitialCategories())}}}return l}(l,t);if(T.length){for(p._numBoxes=0,p._numViolins=0,i=0;i<T.length;i++)w(T[i],!0);for(i=0;i<T.length;i++)w(T[i],!1);O(t)}o.getComponentMethod(\"fx\",\"calc\")(t),o.getComponentMethod(\"errorbars\",\"calc\")(t)};var P=/(total|sum|min|max|mean|median) (ascending|descending)/;function z(t,e,r){var n={};function i(t){t.clearCalc(),\"multicategory\"===t.type&&t.setupMultiCategory(e),n[t._id]=1}c.simpleMap(t,i);for(var a=r._axisMatchGroups||[],o=0;o<a.length;o++)for(var s in a[o])n[s]||i(r[h.id2name(s)])}function O(t){var e,r,n,i=t._fullLayout,a=i._visibleModules,o={};for(r=0;r<a.length;r++){var s=a[r],l=s.crossTraceCalc;if(l){var u=s.basePlotModule.name;o[u]?c.pushUnique(o[u],l):o[u]=[l]}}for(n in o){var f=o[n],h=i._subplots[n];if(Array.isArray(h))for(e=0;e<h.length;e++){var p=h[e],d=\"cartesian\"===n?i._plots[p]:i[p];for(r=0;r<f.length;r++)f[r](t,d,p)}else for(r=0;r<f.length;r++)f[r](t)}}x.rehover=function(t){t._fullLayout._rehover&&t._fullLayout._rehover()},x.redrag=function(t){t._fullLayout._redrag&&t._fullLayout._redrag()},x.generalUpdatePerTraceModule=function(t,e,r,n){var i,a=e.traceHash,o={};for(i=0;i<r.length;i++){var s=r[i],l=s[0].trace;l.visible&&(o[l.type]=o[l.type]||[],o[l.type].push(s))}for(var u in a)if(!o[u]){var f=a[u][0];f[0].trace.visible=!1,o[u]=[f]}for(var h in o){var p=o[h];p[0][0].trace._module.plot(t,e,c.filterVisible(p),n)}e.traceHash=o},x.plotBasePlot=function(t,e,r,n,i){var a=o.getModule(t),s=m(e.calcdata,a)[0];a.plot(e,s,n,i)},x.cleanBasePlot=function(t,e,r,n,i){var a=i._has&&i._has(t),o=r._has&&r._has(t);a&&!o&&i[\"_\"+t+\"layer\"].selectAll(\"g.trace\").remove()}},{\"../components/color\":643,\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plot_api/plot_template\":817,\"../plots/get_data\":865,\"../registry\":911,\"./animation_attributes\":822,\"./attributes\":824,\"./cartesian/axis_ids\":831,\"./cartesian/handle_outline\":838,\"./command\":854,\"./font_attributes\":856,\"./frame_attributes\":857,\"./layout_attributes\":882,d3:169,\"d3-time-format\":166,\"fast-isnumeric\":241}],892:[function(t,e,r){\"use strict\";e.exports={attr:\"subplot\",name:\"polar\",axisNames:[\"angularaxis\",\"radialaxis\"],axisName2dataArray:{angularaxis:\"theta\",radialaxis:\"r\"},layerNames:[\"draglayer\",\"plotbg\",\"backplot\",\"angular-grid\",\"radial-grid\",\"frontplot\",\"angular-line\",\"radial-line\",\"angular-axis\",\"radial-axis\"],radialDragBoxSize:50,angularDragBoxSize:30,cornerLen:25,cornerHalfWidth:2,MINDRAG:8,MINZOOM:20,OFFEDGE:20}},{}],893:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../lib/polygon\").tester,a=n.findIndexOfMin,o=n.isAngleInsideSector,s=n.angleDelta,l=n.angleDist;function c(t,e,r,n){var i,a,o=n[0],s=n[1],l=f(Math.sin(e)-Math.sin(t)),c=f(Math.cos(e)-Math.cos(t)),u=Math.tan(r),h=f(1/u),p=l/c,d=s-p*o;return h?l&&c?a=u*(i=d/(u-p)):c?(i=s*h,a=s):(i=o,a=o*u):l&&c?(i=0,a=d):c?(i=0,a=s):i=a=NaN,[i,a]}function u(t,e,r,i){return n.isFullCircle([e,r])?function(t,e){var r,n=e.length,i=new Array(n+1);for(r=0;r<n;r++){var a=e[r];i[r]=[t*Math.cos(a),t*Math.sin(a)]}return i[r]=i[0].slice(),i}(t,i):function(t,e,r,i){var s,u,f=i.length,h=[];function p(e){return[t*Math.cos(e),t*Math.sin(e)]}function d(t,e,r){return c(t,e,r,p(t))}function g(t){return n.mod(t,f)}function m(t){return o(t,[e,r])}var v=a(i,(function(t){return m(t)?l(t,e):1/0})),y=d(i[v],i[g(v-1)],e);for(h.push(y),s=v,u=0;u<f;s++,u++){var x=i[g(s)];if(!m(x))break;h.push(p(x))}var b=a(i,(function(t){return m(t)?l(t,r):1/0})),_=d(i[b],i[g(b+1)],r);return h.push(_),h.push([0,0]),h.push(h[0].slice()),h}(t,e,r,i)}function f(t){return Math.abs(t)>1e-10?t:0}function h(t,e,r){e=e||0,r=r||0;for(var n=t.length,i=new Array(n),a=0;a<n;a++){var o=t[a];i[a]=[e+o[0],r-o[1]]}return i}e.exports={isPtInsidePolygon:function(t,e,r,n,a){if(!o(e,n))return!1;var s,l;r[0]<r[1]?(s=r[0],l=r[1]):(s=r[1],l=r[0]);var c=i(u(s,n[0],n[1],a)),f=i(u(l,n[0],n[1],a)),h=[t*Math.cos(e),t*Math.sin(e)];return f.contains(h)&&!c.contains(h)},findPolygonOffset:function(t,e,r,n){for(var i=1/0,a=1/0,o=u(t,e,r,n),s=0;s<o.length;s++){var l=o[s];i=Math.min(i,l[0]),a=Math.min(a,-l[1])}return[i,a]},findEnclosingVertexAngles:function(t,e){var r=a(e,(function(e){var r=s(e,t);return r>0?r:1/0})),i=n.mod(r+1,e.length);return[e[r],e[i]]},findIntersectionXY:c,findXYatLength:function(t,e,r,n){var i=-e*r,a=e*e+1,o=2*(e*i-r),s=i*i+r*r-t*t,l=Math.sqrt(o*o-4*a*s),c=(-o+l)/(2*a),u=(-o-l)/(2*a);return[[c,e*c+i+n],[u,e*u+i+n]]},clampTiny:f,pathPolygon:function(t,e,r,n,i,a){return\"M\"+h(u(t,e,r,n),i,a).join(\"L\")},pathPolygonAnnulus:function(t,e,r,n,i,a,o){var s,l;t<e?(s=t,l=e):(s=e,l=t);var c=h(u(s,r,n,i),a,o);return\"M\"+h(u(l,r,n,i),a,o).reverse().join(\"L\")+\"M\"+c.join(\"L\")}}},{\"../../lib\":778,\"../../lib/polygon\":790}],894:[function(t,e,r){\"use strict\";var n=t(\"../get_data\").getSubplotCalcData,i=t(\"../../lib\").counterRegex,a=t(\"./polar\"),o=t(\"./constants\"),s=o.attr,l=o.name,c=i(l),u={};u[s]={valType:\"subplotid\",dflt:l,editType:\"calc\"},e.exports={attr:s,name:l,idRoot:l,idRegex:c,attrRegex:c,attributes:u,layoutAttributes:t(\"./layout_attributes\"),supplyLayoutDefaults:t(\"./layout_defaults\"),plot:function(t){for(var e=t._fullLayout,r=t.calcdata,i=e._subplots[l],o=0;o<i.length;o++){var s=i[o],c=n(r,l,s),u=e[s]._subplot;u||(u=a(t,s),e[s]._subplot=u),u.plot(c,e,t._promises)}},clean:function(t,e,r,n){for(var i=n._subplots[l]||[],a=n._has&&n._has(\"gl\"),o=e._has&&e._has(\"gl\"),s=a&&!o,c=0;c<i.length;c++){var u=i[c],f=n[u]._subplot;if(!e[u]&&f)for(var h in f.framework.remove(),f.layers[\"radial-axis-title\"].remove(),f.clipPaths)f.clipPaths[h].remove();s&&f._scene&&(f._scene.destroy(),f._scene=null)}},toSVG:t(\"../cartesian\").toSVG}},{\"../../lib\":778,\"../cartesian\":841,\"../get_data\":865,\"./constants\":892,\"./layout_attributes\":895,\"./layout_defaults\":896,\"./polar\":903}],895:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../cartesian/layout_attributes\"),a=t(\"../domain\").attributes,o=t(\"../../lib\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=s({color:i.color,showline:o({},i.showline,{dflt:!0}),linecolor:i.linecolor,linewidth:i.linewidth,showgrid:o({},i.showgrid,{dflt:!0}),gridcolor:i.gridcolor,gridwidth:i.gridwidth},\"plot\",\"from-root\"),c=s({tickmode:i.tickmode,nticks:i.nticks,tick0:i.tick0,dtick:i.dtick,tickvals:i.tickvals,ticktext:i.ticktext,ticks:i.ticks,ticklen:i.ticklen,tickwidth:i.tickwidth,tickcolor:i.tickcolor,showticklabels:i.showticklabels,showtickprefix:i.showtickprefix,tickprefix:i.tickprefix,showticksuffix:i.showticksuffix,ticksuffix:i.ticksuffix,showexponent:i.showexponent,exponentformat:i.exponentformat,minexponent:i.minexponent,separatethousands:i.separatethousands,tickfont:i.tickfont,tickangle:i.tickangle,tickformat:i.tickformat,tickformatstops:i.tickformatstops,layer:i.layer},\"plot\",\"from-root\"),u={visible:o({},i.visible,{dflt:!0}),type:o({},i.type,{values:[\"-\",\"linear\",\"log\",\"date\",\"category\"]}),autotypenumbers:i.autotypenumbers,autorange:o({},i.autorange,{editType:\"plot\"}),rangemode:{valType:\"enumerated\",values:[\"tozero\",\"nonnegative\",\"normal\"],dflt:\"tozero\",editType:\"calc\"},range:o({},i.range,{items:[{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}},{valType:\"any\",editType:\"plot\",impliedEdits:{\"^autorange\":!1}}],editType:\"plot\"}),categoryorder:i.categoryorder,categoryarray:i.categoryarray,angle:{valType:\"angle\",editType:\"plot\"},side:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"clockwise\",editType:\"plot\"},title:{text:o({},i.title.text,{editType:\"plot\",dflt:\"\"}),font:o({},i.title.font,{editType:\"plot\"}),editType:\"plot\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\",_deprecated:{title:i._deprecated.title,titlefont:i._deprecated.titlefont}};o(u,l,c);var f={visible:o({},i.visible,{dflt:!0}),type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"category\"],dflt:\"-\",editType:\"calc\",_noTemplating:!0},autotypenumbers:i.autotypenumbers,categoryorder:i.categoryorder,categoryarray:i.categoryarray,thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\"],dflt:\"degrees\",editType:\"calc\"},period:{valType:\"number\",editType:\"calc\",min:0},direction:{valType:\"enumerated\",values:[\"counterclockwise\",\"clockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"angle\",editType:\"calc\"},hoverformat:i.hoverformat,uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"};o(f,l,c),e.exports={domain:a({name:\"polar\",editType:\"plot\"}),sector:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],dflt:[0,360],editType:\"plot\"},hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"plot\"},bgcolor:{valType:\"color\",editType:\"plot\",dflt:n.background},radialaxis:u,angularaxis:f,gridshape:{valType:\"enumerated\",values:[\"circular\",\"linear\"],dflt:\"circular\",editType:\"plot\"},uirevision:{valType:\"any\",editType:\"none\"},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],896:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../plot_api/plot_template\"),o=t(\"../subplot_defaults\"),s=t(\"../get_data\").getSubplotData,l=t(\"../cartesian/tick_value_defaults\"),c=t(\"../cartesian/tick_mark_defaults\"),u=t(\"../cartesian/tick_label_defaults\"),f=t(\"../cartesian/category_order_defaults\"),h=t(\"../cartesian/line_grid_defaults\"),p=t(\"../cartesian/axis_autotype\"),d=t(\"./layout_attributes\"),g=t(\"./set_convert\"),m=t(\"./constants\"),v=m.axisNames;function y(t,e,r,o){var p=r(\"bgcolor\");o.bgColor=i.combine(p,o.paper_bgcolor);var y=r(\"sector\");r(\"hole\");var b,_=s(o.fullData,m.name,o.id),w=o.layoutOut;function T(t,e){return r(b+\".\"+t,e)}for(var k=0;k<v.length;k++){b=v[k],n.isPlainObject(t[b])||(t[b]={});var M=t[b],A=a.newContainer(e,b);A._id=A._name=b,A._attr=o.id+\".\"+b,A._traceIndices=_.map((function(t){return t._expandedIndex}));var S=m.axisName2dataArray[b],E=x(M,A,T,_,S,o);f(M,A,T,{axData:_,dataAttr:S});var C,L,I=T(\"visible\");switch(g(A,e,w),T(\"uirevision\",e.uirevision),I&&(L=(C=T(\"color\"))===M.color?C:o.font.color),A._m=1,b){case\"radialaxis\":var P=T(\"autorange\",!A.isValidRange(M.range));M.autorange=P,!P||\"linear\"!==E&&\"-\"!==E||T(\"rangemode\"),\"reversed\"===P&&(A._m=-1),T(\"range\"),A.cleanRange(\"range\",{dfltRange:[0,1]}),I&&(T(\"side\"),T(\"angle\",y[0]),T(\"title.text\"),n.coerceFont(T,\"title.font\",{family:o.font.family,size:Math.round(1.2*o.font.size),color:L}));break;case\"angularaxis\":if(\"date\"===E){n.log(\"Polar plots do not support date angular axes yet.\");for(var z=0;z<_.length;z++)_[z].visible=!1;E=M.type=A.type=\"linear\"}T(\"linear\"===E?\"thetaunit\":\"period\");var O=T(\"direction\");T(\"rotation\",{counterclockwise:0,clockwise:90}[O])}if(I)l(M,A,T,A.type),u(M,A,T,A.type,{tickSuffixDflt:\"degrees\"===A.thetaunit?\"\\xb0\":void 0}),c(M,A,T,{outerTicks:!0}),T(\"showticklabels\")&&(n.coerceFont(T,\"tickfont\",{family:o.font.family,size:o.font.size,color:L}),T(\"tickangle\"),T(\"tickformat\")),h(M,A,T,{dfltColor:C,bgColor:o.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:d[b]}),T(\"layer\");\"category\"!==E&&T(\"hoverformat\"),A._input=M}\"category\"===e.angularaxis.type&&r(\"gridshape\")}function x(t,e,r,n,i,a){var o=r(\"autotypenumbers\",a.autotypenumbersDflt);if(\"-\"===r(\"type\")){for(var s,l=0;l<n.length;l++)if(n[l].visible){s=n[l];break}s&&s[i]&&(e.type=p(s[i],\"gregorian\",{noMultiCategory:!0,autotypenumbers:o})),\"-\"===e.type?e.type=\"linear\":t.type=e.type}return e.type}e.exports=function(t,e,r){o(t,e,r,{type:m.name,attributes:d,handleDefaults:y,font:e.font,autotypenumbersDflt:e.autotypenumbers,paper_bgcolor:e.paper_bgcolor,fullData:r,layoutOut:e})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/axis_autotype\":829,\"../cartesian/category_order_defaults\":832,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../get_data\":865,\"../subplot_defaults\":905,\"./constants\":892,\"./layout_attributes\":895,\"./set_convert\":904}],897:[function(t,e,r){\"use strict\";var n=t(\"../../../traces/scatter/attributes\"),i=n.marker,a=t(\"../../../lib/extend\").extendFlat;[\"Area traces are deprecated!\",\"Please switch to the *barpolar* trace type.\"].join(\" \");e.exports={r:a({},n.r,{}),t:a({},n.t,{}),marker:{color:a({},i.color,{}),size:a({},i.size,{}),symbol:a({},i.symbol,{}),opacity:a({},i.opacity,{}),editType:\"calc\"}}},{\"../../../lib/extend\":768,\"../../../traces/scatter/attributes\":1187}],898:[function(t,e,r){\"use strict\";var n=t(\"../../cartesian/layout_attributes\"),i=t(\"../../../lib/extend\").extendFlat,a=t(\"../../../plot_api/edit_types\").overrideAll,o=[\"Legacy polar charts are deprecated!\",\"Please switch to *polar* subplots.\"].join(\" \"),s=i({},n.domain,{});function l(t,e){return i({},e,{showline:{valType:\"boolean\"},showticklabels:{valType:\"boolean\"},tickorientation:{valType:\"enumerated\",values:[\"horizontal\",\"vertical\"]},ticklen:{valType:\"number\",min:0},tickcolor:{valType:\"color\"},ticksuffix:{valType:\"string\"},endpadding:{valType:\"number\",description:o},visible:{valType:\"boolean\"}})}e.exports=a({radialaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\"},{valType:\"number\"}]},domain:s,orientation:{valType:\"number\"}}),angularaxis:l(0,{range:{valType:\"info_array\",items:[{valType:\"number\",dflt:0},{valType:\"number\",dflt:360}]},domain:s}),layout:{direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"]},orientation:{valType:\"angle\"}}},\"plot\",\"nested\")},{\"../../../lib/extend\":768,\"../../../plot_api/edit_types\":810,\"../../cartesian/layout_attributes\":842}],899:[function(t,e,r){\"use strict\";(e.exports=t(\"./micropolar\")).manager=t(\"./micropolar_manager\")},{\"./micropolar\":900,\"./micropolar_manager\":901}],900:[function(t,e,r){var n=t(\"d3\"),i=t(\"../../../lib\").extendDeepAll,a=t(\"../../../constants/alignment\").MID_SHIFT,o=e.exports={version:\"0.2.2\"};o.Axis=function(){var t,e,r,s,l={data:[],layout:{}},c={},u={},f=n.dispatch(\"hover\"),h={};return h.render=function(c){return function(c){e=c||e;var f=l.data,h=l.layout;(\"string\"==typeof e||e.nodeName)&&(e=n.select(e)),e.datum(f).each((function(e,l){var c=e.slice();u={data:o.util.cloneJson(c),layout:o.util.cloneJson(h)};var f=0;c.forEach((function(t,e){t.color||(t.color=h.defaultColorRange[f],f=(f+1)%h.defaultColorRange.length),t.strokeColor||(t.strokeColor=\"LinePlot\"===t.geometry?t.color:n.rgb(t.color).darker().toString()),u.data[e].color=t.color,u.data[e].strokeColor=t.strokeColor,u.data[e].strokeDash=t.strokeDash,u.data[e].strokeSize=t.strokeSize}));var p=c.filter((function(t,e){var r=t.visible;return\"undefined\"==typeof r||!0===r})),d=!1,g=p.map((function(t,e){return d=d||\"undefined\"!=typeof t.groupId,t}));if(d){var m=n.nest().key((function(t,e){return\"undefined\"!=typeof t.groupId?t.groupId:\"unstacked\"})).entries(g),v=[],y=m.map((function(t,e){if(\"unstacked\"===t.key)return t.values;var r=t.values[0].r.map((function(t,e){return 0}));return t.values.forEach((function(t,e,n){t.yStack=[r],v.push(r),r=o.util.sumArrays(t.r,r)})),t.values}));p=n.merge(y)}p.forEach((function(t,e){t.t=Array.isArray(t.t[0])?t.t:[t.t],t.r=Array.isArray(t.r[0])?t.r:[t.r]}));var x=Math.min(h.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2;x=Math.max(10,x);var b,_=[h.margin.left+x,h.margin.top+x];d?b=[0,n.max(o.util.sumArrays(o.util.arrayLast(p).r[0],o.util.arrayLast(v)))]:b=n.extent(o.util.flattenArray(p.map((function(t,e){return t.r}))));h.radialAxis.domain!=o.DATAEXTENT&&(b[0]=0),r=n.scale.linear().domain(h.radialAxis.domain!=o.DATAEXTENT&&h.radialAxis.domain?h.radialAxis.domain:b).range([0,x]),u.layout.radialAxis.domain=r.domain();var w,T=o.util.flattenArray(p.map((function(t,e){return t.t}))),k=\"string\"==typeof T[0];k&&(T=o.util.deduplicate(T),w=T.slice(),T=n.range(T.length),p=p.map((function(t,e){var r=t;return t.t=[T],d&&(r.yStack=t.yStack),r})));var M=p.filter((function(t,e){return\"LinePlot\"===t.geometry||\"DotPlot\"===t.geometry})).length===p.length,A=null===h.needsEndSpacing?k||!M:h.needsEndSpacing,S=h.angularAxis.domain&&h.angularAxis.domain!=o.DATAEXTENT&&!k&&h.angularAxis.domain[0]>=0?h.angularAxis.domain:n.extent(T),E=Math.abs(T[1]-T[0]);M&&!k&&(E=0);var C=S.slice();A&&k&&(C[1]+=E);var L=h.angularAxis.ticksCount||4;L>8&&(L=L/(L/8)+L%8),h.angularAxis.ticksStep&&(L=(C[1]-C[0])/L);var I=h.angularAxis.ticksStep||(C[1]-C[0])/(L*(h.minorTicks+1));w&&(I=Math.max(Math.round(I),1)),C[2]||(C[2]=I);var P=n.range.apply(this,C);if(P=P.map((function(t,e){return parseFloat(t.toPrecision(12))})),s=n.scale.linear().domain(C.slice(0,2)).range(\"clockwise\"===h.direction?[0,360]:[360,0]),u.layout.angularAxis.domain=s.domain(),u.layout.angularAxis.endPadding=A?E:0,\"undefined\"==typeof(t=n.select(this).select(\"svg.chart-root\"))||t.empty()){var z=(new DOMParser).parseFromString(\"<svg xmlns='http://www.w3.org/2000/svg' class='chart-root'>' + '<g class='outer-group'>' + '<g class='chart-group'>' + '<circle class='background-circle'></circle>' + '<g class='geometry-group'></g>' + '<g class='radial axis-group'>' + '<circle class='outside-circle'></circle>' + '</g>' + '<g class='angular axis-group'></g>' + '<g class='guides-group'><line></line><circle r='0'></circle></g>' + '</g>' + '<g class='legend-group'></g>' + '<g class='tooltips-group'></g>' + '<g class='title-group'><text></text></g>' + '</g>' + '</svg>\",\"application/xml\"),O=this.appendChild(this.ownerDocument.importNode(z.documentElement,!0));t=n.select(O)}t.select(\".guides-group\").style({\"pointer-events\":\"none\"}),t.select(\".angular.axis-group\").style({\"pointer-events\":\"none\"}),t.select(\".radial.axis-group\").style({\"pointer-events\":\"none\"});var D,R=t.select(\".chart-group\"),F={fill:\"none\",stroke:h.tickColor},B={\"font-size\":h.font.size,\"font-family\":h.font.family,fill:h.font.color,\"text-shadow\":[\"-1px 0px\",\"1px -1px\",\"-1px 1px\",\"1px 1px\"].map((function(t,e){return\" \"+t+\" 0 \"+h.font.outlineColor})).join(\",\")};if(h.showLegend){D=t.select(\".legend-group\").attr({transform:\"translate(\"+[x,h.margin.top]+\")\"}).style({display:\"block\"});var N=p.map((function(t,e){var r=o.util.cloneJson(t);return r.symbol=\"DotPlot\"===t.geometry?t.dotType||\"circle\":\"LinePlot\"!=t.geometry?\"square\":\"line\",r.visibleInLegend=\"undefined\"==typeof t.visibleInLegend||t.visibleInLegend,r.color=\"LinePlot\"===t.geometry?t.strokeColor:t.color,r}));o.Legend().config({data:p.map((function(t,e){return t.name||\"Element\"+e})),legendConfig:i({},o.Legend.defaultConfig().legendConfig,{container:D,elements:N,reverseOrder:h.legend.reverseOrder})})();var j=D.node().getBBox();x=Math.min(h.width-j.width-h.margin.left-h.margin.right,h.height-h.margin.top-h.margin.bottom)/2,x=Math.max(10,x),_=[h.margin.left+x,h.margin.top+x],r.range([0,x]),u.layout.radialAxis.domain=r.domain(),D.attr(\"transform\",\"translate(\"+[_[0]+x,_[1]-x]+\")\")}else D=t.select(\".legend-group\").style({display:\"none\"});t.attr({width:h.width,height:h.height}).style({opacity:h.opacity}),R.attr(\"transform\",\"translate(\"+_+\")\").style({cursor:\"crosshair\"});var U=[(h.width-(h.margin.left+h.margin.right+2*x+(j?j.width:0)))/2,(h.height-(h.margin.top+h.margin.bottom+2*x))/2];if(U[0]=Math.max(0,U[0]),U[1]=Math.max(0,U[1]),t.select(\".outer-group\").attr(\"transform\",\"translate(\"+U+\")\"),h.title&&h.title.text){var V=t.select(\"g.title-group text\").style(B).text(h.title.text),q=V.node().getBBox();V.attr({x:_[0]-q.width/2,y:_[1]-x-20})}var H=t.select(\".radial.axis-group\");if(h.radialAxis.gridLinesVisible){var G=H.selectAll(\"circle.grid-circle\").data(r.ticks(5));G.enter().append(\"circle\").attr({class:\"grid-circle\"}).style(F),G.attr(\"r\",r),G.exit().remove()}H.select(\"circle.outside-circle\").attr({r:x}).style(F);var Y=t.select(\"circle.background-circle\").attr({r:x}).style({fill:h.backgroundColor,stroke:h.stroke});function W(t,e){return s(t)%360+h.orientation}if(h.radialAxis.visible){var X=n.svg.axis().scale(r).ticks(5).tickSize(5);H.call(X).attr({transform:\"rotate(\"+h.radialAxis.orientation+\")\"}),H.selectAll(\".domain\").style(F),H.selectAll(\"g>text\").text((function(t,e){return this.textContent+h.radialAxis.ticksSuffix})).style(B).style({\"text-anchor\":\"start\"}).attr({x:0,y:0,dx:0,dy:0,transform:function(t,e){return\"horizontal\"===h.radialAxis.tickOrientation?\"rotate(\"+-h.radialAxis.orientation+\") translate(\"+[0,B[\"font-size\"]]+\")\":\"translate(\"+[0,B[\"font-size\"]]+\")\"}}),H.selectAll(\"g>line\").style({stroke:\"black\"})}var Z=t.select(\".angular.axis-group\").selectAll(\"g.angular-tick\").data(P),J=Z.enter().append(\"g\").classed(\"angular-tick\",!0);Z.attr({transform:function(t,e){return\"rotate(\"+W(t)+\")\"}}).style({display:h.angularAxis.visible?\"block\":\"none\"}),Z.exit().remove(),J.append(\"line\").classed(\"grid-line\",!0).classed(\"major\",(function(t,e){return e%(h.minorTicks+1)==0})).classed(\"minor\",(function(t,e){return!(e%(h.minorTicks+1)==0)})).style(F),J.selectAll(\".minor\").style({stroke:h.minorTickColor}),Z.select(\"line.grid-line\").attr({x1:h.tickLength?x-h.tickLength:0,x2:x}).style({display:h.angularAxis.gridLinesVisible?\"block\":\"none\"}),J.append(\"text\").classed(\"axis-text\",!0).style(B);var K=Z.select(\"text.axis-text\").attr({x:x+h.labelOffset,dy:a+\"em\",transform:function(t,e){var r=W(t),n=x+h.labelOffset,i=h.angularAxis.tickOrientation;return\"horizontal\"==i?\"rotate(\"+-r+\" \"+n+\" 0)\":\"radial\"==i?r<270&&r>90?\"rotate(180 \"+n+\" 0)\":null:\"rotate(\"+(r<=180&&r>0?-90:90)+\" \"+n+\" 0)\"}}).style({\"text-anchor\":\"middle\",display:h.angularAxis.labelsVisible?\"block\":\"none\"}).text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":w?w[t]+h.angularAxis.ticksSuffix:t+h.angularAxis.ticksSuffix})).style(B);h.angularAxis.rewriteTicks&&K.text((function(t,e){return e%(h.minorTicks+1)!=0?\"\":h.angularAxis.rewriteTicks(this.textContent,e)}));var Q=n.max(R.selectAll(\".angular-tick text\")[0].map((function(t,e){return t.getCTM().e+t.getBBox().width})));D.attr({transform:\"translate(\"+[x+Q,h.margin.top]+\")\"});var $=t.select(\"g.geometry-group\").selectAll(\"g\").size()>0,tt=t.select(\"g.geometry-group\").selectAll(\"g.geometry\").data(p);if(tt.enter().append(\"g\").attr({class:function(t,e){return\"geometry geometry\"+e}}),tt.exit().remove(),p[0]||$){var et=[];p.forEach((function(t,e){var n={};n.radialScale=r,n.angularScale=s,n.container=tt.filter((function(t,r){return r==e})),n.geometry=t.geometry,n.orientation=h.orientation,n.direction=h.direction,n.index=e,et.push({data:t,geometryConfig:n})}));var rt=n.nest().key((function(t,e){return\"undefined\"!=typeof t.data.groupId||\"unstacked\"})).entries(et),nt=[];rt.forEach((function(t,e){\"unstacked\"===t.key?nt=nt.concat(t.values.map((function(t,e){return[t]}))):nt.push(t.values)})),nt.forEach((function(t,e){var r;r=Array.isArray(t)?t[0].geometryConfig.geometry:t.geometryConfig.geometry;var n=t.map((function(t,e){return i(o[r].defaultConfig(),t)}));o[r]().config(n)()}))}var it,at,ot=t.select(\".guides-group\"),st=t.select(\".tooltips-group\"),lt=o.tooltipPanel().config({container:st,fontSize:8})(),ct=o.tooltipPanel().config({container:st,fontSize:8})(),ut=o.tooltipPanel().config({container:st,hasTick:!0})();if(!k){var ft=ot.select(\"line\").attr({x1:0,y1:0,y2:0}).style({stroke:\"grey\",\"pointer-events\":\"none\"});R.on(\"mousemove.angular-guide\",(function(t,e){var r=o.util.getMousePos(Y).angle;ft.attr({x2:-x,transform:\"rotate(\"+r+\")\"}).style({opacity:.5});var n=(r+180+360-h.orientation)%360;it=s.invert(n);var i=o.util.convertToCartesian(x+12,r+180);lt.text(o.util.round(it)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.angular-guide\",(function(t,e){ot.select(\"line\").style({opacity:0})}))}var ht=ot.select(\"circle\").style({stroke:\"grey\",fill:\"none\"});R.on(\"mousemove.radial-guide\",(function(t,e){var n=o.util.getMousePos(Y).radius;ht.attr({r:n}).style({opacity:.5}),at=r.invert(o.util.getMousePos(Y).radius);var i=o.util.convertToCartesian(n,h.radialAxis.orientation);ct.text(o.util.round(at)).move([i[0]+_[0],i[1]+_[1]])})).on(\"mouseout.radial-guide\",(function(t,e){ht.style({opacity:0}),ut.hide(),lt.hide(),ct.hide()})),t.selectAll(\".geometry-group .mark\").on(\"mouseover.tooltip\",(function(e,r){var i=n.select(this),a=this.style.fill,s=\"black\",l=this.style.opacity||1;if(i.attr({\"data-opacity\":l}),a&&\"none\"!==a){i.attr({\"data-fill\":a}),s=n.hsl(a).darker().toString(),i.style({fill:s,opacity:1});var c={t:o.util.round(e[0]),r:o.util.round(e[1])};k&&(c.t=w[e[0]]);var u=\"t: \"+c.t+\", r: \"+c.r,f=this.getBoundingClientRect(),h=t.node().getBoundingClientRect(),p=[f.left+f.width/2-U[0]-h.left,f.top+f.height/2-U[1]-h.top];ut.config({color:s}).text(u),ut.move(p)}else a=this.style.stroke||\"black\",i.attr({\"data-stroke\":a}),s=n.hsl(a).darker().toString(),i.style({stroke:s,opacity:1})})).on(\"mousemove.tooltip\",(function(t,e){if(0!=n.event.which)return!1;n.select(this).attr(\"data-fill\")&&ut.show()})).on(\"mouseout.tooltip\",(function(t,e){ut.hide();var r=n.select(this),i=r.attr(\"data-fill\");i?r.style({fill:i,opacity:r.attr(\"data-opacity\")}):r.style({stroke:r.attr(\"data-stroke\"),opacity:r.attr(\"data-opacity\")})}))}))}(c),this},h.config=function(t){if(!arguments.length)return l;var e=o.util.cloneJson(t);return e.data.forEach((function(t,e){l.data[e]||(l.data[e]={}),i(l.data[e],o.Axis.defaultConfig().data[0]),i(l.data[e],t)})),i(l.layout,o.Axis.defaultConfig().layout),i(l.layout,e.layout),this},h.getLiveConfig=function(){return u},h.getinputConfig=function(){return c},h.radialScale=function(t){return r},h.angularScale=function(t){return s},h.svg=function(){return t},n.rebind(h,f,\"on\"),h},o.Axis.defaultConfig=function(t,e){return{data:[{t:[1,2,3,4],r:[10,11,12,13],name:\"Line1\",geometry:\"LinePlot\",color:null,strokeDash:\"solid\",strokeColor:null,strokeSize:\"1\",visibleInLegend:!0,opacity:1}],layout:{defaultColorRange:n.scale.category10().range(),title:null,height:450,width:500,margin:{top:40,right:40,bottom:40,left:40},font:{size:12,color:\"gray\",outlineColor:\"white\",family:\"Tahoma, sans-serif\"},direction:\"clockwise\",orientation:0,labelOffset:10,radialAxis:{domain:null,orientation:-45,ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null},angularAxis:{domain:[0,360],ticksSuffix:\"\",visible:!0,gridLinesVisible:!0,labelsVisible:!0,tickOrientation:\"horizontal\",rewriteTicks:null,ticksCount:null,ticksStep:null},minorTicks:0,tickLength:null,tickColor:\"silver\",minorTickColor:\"#eee\",backgroundColor:\"none\",needsEndSpacing:null,showLegend:!0,legend:{reverseOrder:!1},opacity:1}}},o.util={},o.DATAEXTENT=\"dataExtent\",o.AREA=\"AreaChart\",o.LINE=\"LinePlot\",o.DOT=\"DotPlot\",o.BAR=\"BarChart\",o.util._override=function(t,e){for(var r in t)r in e&&(e[r]=t[r])},o.util._extend=function(t,e){for(var r in t)e[r]=t[r]},o.util._rndSnd=function(){return 2*Math.random()-1+(2*Math.random()-1)+(2*Math.random()-1)},o.util.dataFromEquation2=function(t,e){var r=e||6;return n.range(0,360+r,r).map((function(e,r){var n=e*Math.PI/180;return[e,t(n)]}))},o.util.dataFromEquation=function(t,e,r){var i=e||6,a=[],o=[];n.range(0,360+i,i).forEach((function(e,r){var n=e*Math.PI/180,i=t(n);a.push(e),o.push(i)}));var s={t:a,r:o};return r&&(s.name=r),s},o.util.ensureArray=function(t,e){if(\"undefined\"==typeof t)return null;var r=[].concat(t);return n.range(e).map((function(t,e){return r[e]||r[0]}))},o.util.fillArrays=function(t,e,r){return e.forEach((function(e,n){t[e]=o.util.ensureArray(t[e],r)})),t},o.util.cloneJson=function(t){return JSON.parse(JSON.stringify(t))},o.util.validateKeys=function(t,e){\"string\"==typeof e&&(e=e.split(\".\"));var r=e.shift();return t[r]&&(!e.length||objHasKeys(t[r],e))},o.util.sumArrays=function(t,e){return n.zip(t,e).map((function(t,e){return n.sum(t)}))},o.util.arrayLast=function(t){return t[t.length-1]},o.util.arrayEqual=function(t,e){for(var r=Math.max(t.length,e.length,1);r-- >=0&&t[r]===e[r];);return-2===r},o.util.flattenArray=function(t){for(var e=[];!o.util.arrayEqual(e,t);)e=t,t=[].concat.apply([],t);return t},o.util.deduplicate=function(t){return t.filter((function(t,e,r){return r.indexOf(t)==e}))},o.util.convertToCartesian=function(t,e){var r=e*Math.PI/180;return[t*Math.cos(r),t*Math.sin(r)]},o.util.round=function(t,e){var r=e||2,n=Math.pow(10,r);return Math.round(t*n)/n},o.util.getMousePos=function(t){var e=n.mouse(t.node()),r=e[0],i=e[1],a={};return a.x=r,a.y=i,a.pos=e,a.angle=180*(Math.atan2(i,r)+Math.PI)/Math.PI,a.radius=Math.sqrt(r*r+i*i),a},o.util.duplicatesCount=function(t){for(var e,r={},n={},i=0,a=t.length;i<a;i++)(e=t[i])in r?(r[e]++,n[e]=r[e]):r[e]=1;return n},o.util.duplicates=function(t){return Object.keys(o.util.duplicatesCount(t))},o.util.translator=function(t,e,r,n){if(n){var i=r.slice();r=e,e=i}var a=e.reduce((function(t,e){if(\"undefined\"!=typeof t)return t[e]}),t);\"undefined\"!=typeof a&&(e.reduce((function(t,r,n){if(\"undefined\"!=typeof t)return n===e.length-1&&delete t[r],t[r]}),t),r.reduce((function(t,e,n){return\"undefined\"==typeof t[e]&&(t[e]={}),n===r.length-1&&(t[e]=a),t[e]}),t))},o.PolyChart=function(){var t=[o.PolyChart.defaultConfig()],e=n.dispatch(\"hover\"),r={solid:\"none\",dash:[5,2],dot:[2,5]};function a(){var e=t[0].geometryConfig,i=e.container;\"string\"==typeof i&&(i=n.select(i)),i.datum(t).each((function(t,i){var a=!!t[0].data.yStack,o=t.map((function(t,e){return a?n.zip(t.data.t[0],t.data.r[0],t.data.yStack[0]):n.zip(t.data.t[0],t.data.r[0])})),s=e.angularScale,l=e.radialScale.domain()[0],c={bar:function(r,i,a){var o=t[a].data,l=e.radialScale(r[1])-e.radialScale(0),c=e.radialScale(r[2]||0),u=o.barWidth;n.select(this).attr({class:\"mark bar\",d:\"M\"+[[l+c,-u/2],[l+c,u/2],[c,u/2],[c,-u/2]].join(\"L\")+\"Z\",transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0]))+\")\"}})}};c.dot=function(r,i,a){var o=r[2]?[r[0],r[1]+r[2]]:r,s=n.svg.symbol().size(t[a].data.dotSize).type(t[a].data.dotType)(r,i);n.select(this).attr({class:\"mark dot\",d:s,transform:function(t,r){var n,i,a,s=(n=function(t,r){var n=e.radialScale(t[1]),i=(e.angularScale(t[0])+e.orientation)*Math.PI/180;return{r:n,t:i}}(o),i=n.r*Math.cos(n.t),a=n.r*Math.sin(n.t),{x:i,y:a});return\"translate(\"+[s.x,s.y]+\")\"}})};var u=n.svg.line.radial().interpolate(t[0].data.lineInterpolation).radius((function(t){return e.radialScale(t[1])})).angle((function(t){return e.angularScale(t[0])*Math.PI/180}));c.line=function(r,i,a){var s=r[2]?o[a].map((function(t,e){return[t[0],t[1]+t[2]]})):o[a];if(n.select(this).each(c.dot).style({opacity:function(e,r){return+t[a].data.dotVisible},fill:d.stroke(r,i,a)}).attr({class:\"mark dot\"}),!(i>0)){var l=n.select(this.parentNode).selectAll(\"path.line\").data([0]);l.enter().insert(\"path\"),l.attr({class:\"line\",d:u(s),transform:function(t,r){return\"rotate(\"+(e.orientation+90)+\")\"},\"pointer-events\":\"none\"}).style({fill:function(t,e){return d.fill(r,i,a)},\"fill-opacity\":0,stroke:function(t,e){return d.stroke(r,i,a)},\"stroke-width\":function(t,e){return d[\"stroke-width\"](r,i,a)},\"stroke-dasharray\":function(t,e){return d[\"stroke-dasharray\"](r,i,a)},opacity:function(t,e){return d.opacity(r,i,a)},display:function(t,e){return d.display(r,i,a)}})}};var f=e.angularScale.range(),h=Math.abs(f[1]-f[0])/o[0].length*Math.PI/180,p=n.svg.arc().startAngle((function(t){return-h/2})).endAngle((function(t){return h/2})).innerRadius((function(t){return e.radialScale(l+(t[2]||0))})).outerRadius((function(t){return e.radialScale(l+(t[2]||0))+e.radialScale(t[1])}));c.arc=function(t,r,i){n.select(this).attr({class:\"mark arc\",d:p,transform:function(t,r){return\"rotate(\"+(e.orientation+s(t[0])+90)+\")\"}})};var d={fill:function(e,r,n){return t[n].data.color},stroke:function(e,r,n){return t[n].data.strokeColor},\"stroke-width\":function(e,r,n){return t[n].data.strokeSize+\"px\"},\"stroke-dasharray\":function(e,n,i){return r[t[i].data.strokeDash]},opacity:function(e,r,n){return t[n].data.opacity},display:function(e,r,n){return\"undefined\"==typeof t[n].data.visible||t[n].data.visible?\"block\":\"none\"}},g=n.select(this).selectAll(\"g.layer\").data(o);g.enter().append(\"g\").attr({class:\"layer\"});var m=g.selectAll(\"path.mark\").data((function(t,e){return t}));m.enter().append(\"path\").attr({class:\"mark\"}),m.style(d).each(c[e.geometryType]),m.exit().remove(),g.exit().remove()}))}return a.config=function(e){return arguments.length?(e.forEach((function(e,r){t[r]||(t[r]={}),i(t[r],o.PolyChart.defaultConfig()),i(t[r],e)})),this):t},a.getColorScale=function(){},n.rebind(a,e,\"on\"),a},o.PolyChart.defaultConfig=function(){return{data:{name:\"geom1\",t:[[1,2,3,4]],r:[[1,2,3,4]],dotType:\"circle\",dotSize:64,dotVisible:!1,barWidth:20,color:\"#ffa500\",strokeSize:1,strokeColor:\"silver\",strokeDash:\"solid\",opacity:1,index:0,visible:!0,visibleInLegend:!0},geometryConfig:{geometry:\"LinePlot\",geometryType:\"arc\",direction:\"clockwise\",orientation:0,container:\"body\",radialScale:null,angularScale:null,colorScale:n.scale.category20()}}},o.BarChart=function(){return o.PolyChart()},o.BarChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"bar\"}}},o.AreaChart=function(){return o.PolyChart()},o.AreaChart.defaultConfig=function(){return{geometryConfig:{geometryType:\"arc\"}}},o.DotPlot=function(){return o.PolyChart()},o.DotPlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"dot\",dotType:\"circle\"}}},o.LinePlot=function(){return o.PolyChart()},o.LinePlot.defaultConfig=function(){return{geometryConfig:{geometryType:\"line\"}}},o.Legend=function(){var t=o.Legend.defaultConfig(),e=n.dispatch(\"hover\");function r(){var e=t.legendConfig,a=t.data.map((function(t,r){return[].concat(t).map((function(t,n){var a=i({},e.elements[r]);return a.name=t,a.color=[].concat(e.elements[r].color)[n],a}))})),o=n.merge(a);o=o.filter((function(t,r){return e.elements[r]&&(e.elements[r].visibleInLegend||\"undefined\"==typeof e.elements[r].visibleInLegend)})),e.reverseOrder&&(o=o.reverse());var s=e.container;(\"string\"==typeof s||s.nodeName)&&(s=n.select(s));var l=o.map((function(t,e){return t.color})),c=e.fontSize,u=null==e.isContinuous?\"number\"==typeof o[0]:e.isContinuous,f=u?e.height:c*o.length,h=s.classed(\"legend-group\",!0).selectAll(\"svg\").data([0]),p=h.enter().append(\"svg\").attr({width:300,height:f+c,xmlns:\"http://www.w3.org/2000/svg\",\"xmlns:xlink\":\"http://www.w3.org/1999/xlink\",version:\"1.1\"});p.append(\"g\").classed(\"legend-axis\",!0),p.append(\"g\").classed(\"legend-marks\",!0);var d=n.range(o.length),g=n.scale[u?\"linear\":\"ordinal\"]().domain(d).range(l),m=n.scale[u?\"linear\":\"ordinal\"]().domain(d)[u?\"range\":\"rangePoints\"]([0,f]);if(u){var v=h.select(\".legend-marks\").append(\"defs\").append(\"linearGradient\").attr({id:\"grad1\",x1:\"0%\",y1:\"0%\",x2:\"0%\",y2:\"100%\"}).selectAll(\"stop\").data(l);v.enter().append(\"stop\"),v.attr({offset:function(t,e){return e/(l.length-1)*100+\"%\"}}).style({\"stop-color\":function(t,e){return t}}),h.append(\"rect\").classed(\"legend-mark\",!0).attr({height:e.height,width:e.colorBandWidth,fill:\"url(#grad1)\"})}else{var y=h.select(\".legend-marks\").selectAll(\"path.legend-mark\").data(o);y.enter().append(\"path\").classed(\"legend-mark\",!0),y.attr({transform:function(t,e){return\"translate(\"+[c/2,m(e)+c/2]+\")\"},d:function(t,e){var r,i,a,o=t.symbol;return a=3*(i=c),\"line\"===(r=o)?\"M\"+[[-i/2,-i/12],[i/2,-i/12],[i/2,i/12],[-i/2,i/12]]+\"Z\":-1!=n.svg.symbolTypes.indexOf(r)?n.svg.symbol().type(r).size(a)():n.svg.symbol().type(\"square\").size(a)()},fill:function(t,e){return g(e)}}),y.exit().remove()}var x=n.svg.axis().scale(m).orient(\"right\"),b=h.select(\"g.legend-axis\").attr({transform:\"translate(\"+[u?e.colorBandWidth:c,c/2]+\")\"}).call(x);return b.selectAll(\".domain\").style({fill:\"none\",stroke:\"none\"}),b.selectAll(\"line\").style({fill:\"none\",stroke:u?e.textColor:\"none\"}),b.selectAll(\"text\").style({fill:e.textColor,\"font-size\":e.fontSize}).text((function(t,e){return o[e].name})),r}return r.config=function(e){return arguments.length?(i(t,e),this):t},n.rebind(r,e,\"on\"),r},o.Legend.defaultConfig=function(t,e){return{data:[\"a\",\"b\",\"c\"],legendConfig:{elements:[{symbol:\"line\",color:\"red\"},{symbol:\"square\",color:\"yellow\"},{symbol:\"diamond\",color:\"limegreen\"}],height:150,colorBandWidth:30,fontSize:12,container:\"body\",isContinuous:null,textColor:\"grey\",reverseOrder:!1}}},o.tooltipPanel=function(){var t,e,r,a={container:null,hasTick:!1,fontSize:12,color:\"white\",padding:5},s=\"tooltip-\"+o.tooltipPanel.uid++,l=10,c=function(){var n=(t=a.container.selectAll(\"g.\"+s).data([0])).enter().append(\"g\").classed(s,!0).style({\"pointer-events\":\"none\",display:\"none\"});return r=n.append(\"path\").style({fill:\"white\",\"fill-opacity\":.9}).attr({d:\"M0 0\"}),e=n.append(\"text\").attr({dx:a.padding+l,dy:.3*+a.fontSize}),c};return c.text=function(i){var o=n.hsl(a.color).l,s=o>=.5?\"#aaa\":\"white\",u=o>=.5?\"black\":\"white\",f=i||\"\";e.style({fill:u,\"font-size\":a.fontSize+\"px\"}).text(f);var h=a.padding,p=e.node().getBBox(),d={fill:a.color,stroke:s,\"stroke-width\":\"2px\"},g=p.width+2*h+l,m=p.height+2*h;return r.attr({d:\"M\"+[[l,-m/2],[l,-m/4],[a.hasTick?0:l,0],[l,m/4],[l,m/2],[g,m/2],[g,-m/2]].join(\"L\")+\"Z\"}).style(d),t.attr({transform:\"translate(\"+[l,-m/2+2*h]+\")\"}),t.style({display:\"block\"}),c},c.move=function(e){if(t)return t.attr({transform:\"translate(\"+[e[0],e[1]]+\")\"}).style({display:\"block\"}),c},c.hide=function(){if(t)return t.style({display:\"none\"}),c},c.show=function(){if(t)return t.style({display:\"block\"}),c},c.config=function(t){return i(a,t),c},c},o.tooltipPanel.uid=1,o.adapter={},o.adapter.plotly=function(){var t={convert:function(t,e){var r={};if(t.data&&(r.data=t.data.map((function(t,r){var n=i({},t);return[[n,[\"marker\",\"color\"],[\"color\"]],[n,[\"marker\",\"opacity\"],[\"opacity\"]],[n,[\"marker\",\"line\",\"color\"],[\"strokeColor\"]],[n,[\"marker\",\"line\",\"dash\"],[\"strokeDash\"]],[n,[\"marker\",\"line\",\"width\"],[\"strokeSize\"]],[n,[\"marker\",\"symbol\"],[\"dotType\"]],[n,[\"marker\",\"size\"],[\"dotSize\"]],[n,[\"marker\",\"barWidth\"],[\"barWidth\"]],[n,[\"line\",\"interpolation\"],[\"lineInterpolation\"]],[n,[\"showlegend\"],[\"visibleInLegend\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e||delete n.marker,e&&delete n.groupId,e?(\"LinePlot\"===n.geometry?(n.type=\"scatter\",!0===n.dotVisible?(delete n.dotVisible,n.mode=\"lines+markers\"):n.mode=\"lines\"):\"DotPlot\"===n.geometry?(n.type=\"scatter\",n.mode=\"markers\"):\"AreaChart\"===n.geometry?n.type=\"area\":\"BarChart\"===n.geometry&&(n.type=\"bar\"),delete n.geometry):(\"scatter\"===n.type?\"lines\"===n.mode?n.geometry=\"LinePlot\":\"markers\"===n.mode?n.geometry=\"DotPlot\":\"lines+markers\"===n.mode&&(n.geometry=\"LinePlot\",n.dotVisible=!0):\"area\"===n.type?n.geometry=\"AreaChart\":\"bar\"===n.type&&(n.geometry=\"BarChart\"),delete n.mode,delete n.type),n})),!e&&t.layout&&\"stack\"===t.layout.barmode)){var a=o.util.duplicates(r.data.map((function(t,e){return t.geometry})));r.data.forEach((function(t,e){var n=a.indexOf(t.geometry);-1!=n&&(r.data[e].groupId=n)}))}if(t.layout){var s=i({},t.layout);if([[s,[\"plot_bgcolor\"],[\"backgroundColor\"]],[s,[\"showlegend\"],[\"showLegend\"]],[s,[\"radialaxis\"],[\"radialAxis\"]],[s,[\"angularaxis\"],[\"angularAxis\"]],[s.angularaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularaxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularaxis,[\"nticks\"],[\"ticksCount\"]],[s.angularaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularaxis,[\"range\"],[\"domain\"]],[s.angularaxis,[\"endpadding\"],[\"endPadding\"]],[s.radialaxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialaxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialaxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialaxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.angularAxis,[\"showticklabels\"],[\"labelsVisible\"]],[s.angularAxis,[\"nticks\"],[\"ticksCount\"]],[s.angularAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.angularAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.angularAxis,[\"range\"],[\"domain\"]],[s.angularAxis,[\"endpadding\"],[\"endPadding\"]],[s.radialAxis,[\"showline\"],[\"gridLinesVisible\"]],[s.radialAxis,[\"tickorientation\"],[\"tickOrientation\"]],[s.radialAxis,[\"ticksuffix\"],[\"ticksSuffix\"]],[s.radialAxis,[\"range\"],[\"domain\"]],[s.font,[\"outlinecolor\"],[\"outlineColor\"]],[s.legend,[\"traceorder\"],[\"reverseOrder\"]],[s,[\"labeloffset\"],[\"labelOffset\"]],[s,[\"defaultcolorrange\"],[\"defaultColorRange\"]]].forEach((function(t,r){o.util.translator.apply(null,t.concat(e))})),e?(\"undefined\"!=typeof s.tickLength&&(s.angularaxis.ticklen=s.tickLength,delete s.tickLength),s.tickColor&&(s.angularaxis.tickcolor=s.tickColor,delete s.tickColor)):(s.angularAxis&&\"undefined\"!=typeof s.angularAxis.ticklen&&(s.tickLength=s.angularAxis.ticklen),s.angularAxis&&\"undefined\"!=typeof s.angularAxis.tickcolor&&(s.tickColor=s.angularAxis.tickcolor)),s.legend&&\"boolean\"!=typeof s.legend.reverseOrder&&(s.legend.reverseOrder=\"normal\"!=s.legend.reverseOrder),s.legend&&\"boolean\"==typeof s.legend.traceorder&&(s.legend.traceorder=s.legend.traceorder?\"reversed\":\"normal\",delete s.legend.reverseOrder),s.margin&&\"undefined\"!=typeof s.margin.t){var l=[\"t\",\"r\",\"b\",\"l\",\"pad\"],c=[\"top\",\"right\",\"bottom\",\"left\",\"pad\"],u={};n.entries(s.margin).forEach((function(t,e){u[c[l.indexOf(t.key)]]=t.value})),s.margin=u}e&&(delete s.needsEndSpacing,delete s.minorTickColor,delete s.minorTicks,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksCount,delete s.angularaxis.ticksStep,delete s.angularaxis.rewriteTicks,delete s.angularaxis.nticks,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksCount,delete s.radialaxis.ticksStep,delete s.radialaxis.rewriteTicks,delete s.radialaxis.nticks),r.layout=s}return r}};return t}},{\"../../../constants/alignment\":745,\"../../../lib\":778,d3:169}],901:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../../lib\"),a=t(\"../../../components/color\"),o=t(\"./micropolar\"),s=t(\"./undo_manager\"),l=i.extendDeepAll,c=e.exports={};c.framework=function(t){var e,r,i,a,u,f=new s;function h(r,s){return s&&(u=s),n.select(n.select(u).node().parentNode).selectAll(\".svg-container>*:not(.chart-root)\").remove(),e=e?l(e,r):r,i||(i=o.Axis()),a=o.adapter.plotly().convert(e),i.config(a).render(u),t.data=e.data,t.layout=e.layout,c.fillLayout(t),e}return h.isPolar=!0,h.svg=function(){return i.svg()},h.getConfig=function(){return e},h.getLiveConfig=function(){return o.adapter.plotly().convert(i.getLiveConfig(),!0)},h.getLiveScales=function(){return{t:i.angularScale(),r:i.radialScale()}},h.setUndoPoint=function(){var t,n,i=this,a=o.util.cloneJson(e);t=a,n=r,f.add({undo:function(){n&&i(n)},redo:function(){i(t)}}),r=o.util.cloneJson(a)},h.undo=function(){f.undo()},h.redo=function(){f.redo()},h},c.fillLayout=function(t){var e=n.select(t).selectAll(\".plot-container\"),r=e.selectAll(\".svg-container\"),i=t.framework&&t.framework.svg&&t.framework.svg(),o={width:800,height:600,paper_bgcolor:a.background,_container:e,_paperdiv:r,_paper:i};t._fullLayout=l(o,t.layout)}},{\"../../../components/color\":643,\"../../../lib\":778,\"./micropolar\":900,\"./undo_manager\":902,d3:169}],902:[function(t,e,r){\"use strict\";e.exports=function(){var t,e=[],r=-1,n=!1;function i(t,e){return t?(n=!0,t[e](),n=!1,this):this}return{add:function(t){return n||(e.splice(r+1,e.length-r),e.push(t),r=e.length-1),this},setCallback:function(e){t=e},undo:function(){var n=e[r];return n?(i(n,\"undo\"),r-=1,t&&t(n.undo),this):this},redo:function(){var n=e[r+1];return n?(i(n,\"redo\"),r+=1,t&&t(n.redo),this):this},clear:function(){e=[],r=-1},hasUndo:function(){return-1!==r},hasRedo:function(){return r<e.length-1},getCommands:function(){return e},getPreviousCommand:function(){return e[r-1]},getIndex:function(){return r}}}},{}],903:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../plots\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../cartesian/set_convert\"),d=t(\"./set_convert\"),g=t(\"../cartesian/autorange\").doAutoRange,m=t(\"../cartesian/dragbox\"),v=t(\"../../components/dragelement\"),y=t(\"../../components/fx\"),x=t(\"../../components/titles\"),b=t(\"../cartesian/select\").prepSelect,_=t(\"../cartesian/select\").selectOnClick,w=t(\"../cartesian/select\").clearSelect,T=t(\"../../lib/setcursor\"),k=t(\"../../lib/clear_gl_canvases\"),M=t(\"../../plot_api/subroutines\").redrawReglTraces,A=t(\"../../constants/alignment\").MID_SHIFT,S=t(\"./constants\"),E=t(\"./helpers\"),C=o._,L=o.mod,I=o.deg2rad,P=o.rad2deg;function z(t,e){this.id=e,this.gd=t,this._hasClipOnAxisFalse=null,this.vangles=null,this.radialAxisAngle=null,this.traceHash={},this.layers={},this.clipPaths={},this.clipIds={},this.viewInitial={};var r=t._fullLayout,n=\"clip\"+r._uid+e;this.clipIds.forTraces=n+\"-for-traces\",this.clipPaths.forTraces=r._clips.append(\"clipPath\").attr(\"id\",this.clipIds.forTraces),this.clipPaths.forTraces.append(\"path\"),this.framework=r._polarlayer.append(\"g\").attr(\"class\",e),this.radialTickLayout=null,this.angularTickLayout=null}var O=z.prototype;function D(t){var e=t.ticks+String(t.ticklen)+String(t.showticklabels);return\"side\"in t&&(e+=t.side),e}function R(t,e){return e[o.findIndexOfMin(e,(function(e){return o.angleDist(t,e)}))]}function F(t,e,r){return e?(t.attr(\"display\",null),t.attr(r)):t&&t.attr(\"display\",\"none\"),t}e.exports=function(t,e){return new z(t,e)},O.plot=function(t,e){var r=e[this.id];this._hasClipOnAxisFalse=!1;for(var n=0;n<t.length;n++){if(!1===t[n][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(e,r),this.updateLayout(e,r),f.generalUpdatePerTraceModule(this.gd,this,t,r),this.updateFx(e,r)},O.updateLayers=function(t,e){var r=this.layers,i=e.radialaxis,a=e.angularaxis,o=S.layerNames,s=o.indexOf(\"frontplot\"),l=o.slice(0,s),c=\"below traces\"===a.layer,u=\"below traces\"===i.layer;c&&l.push(\"angular-line\"),u&&l.push(\"radial-line\"),c&&l.push(\"angular-axis\"),u&&l.push(\"radial-axis\"),l.push(\"frontplot\"),c||l.push(\"angular-line\"),u||l.push(\"radial-line\"),c||l.push(\"angular-axis\"),u||l.push(\"radial-axis\");var f=this.framework.selectAll(\".polarsublayer\").data(l,String);f.enter().append(\"g\").attr(\"class\",(function(t){return\"polarsublayer \"+t})).each((function(t){var e=r[t]=n.select(this);switch(t){case\"frontplot\":e.append(\"g\").classed(\"barlayer\",!0),e.append(\"g\").classed(\"scatterlayer\",!0);break;case\"backplot\":e.append(\"g\").classed(\"maplayer\",!0);break;case\"plotbg\":r.bg=e.append(\"path\");break;case\"radial-grid\":case\"angular-grid\":e.style(\"fill\",\"none\");break;case\"radial-line\":e.append(\"line\").style(\"fill\",\"none\");break;case\"angular-line\":e.append(\"path\").style(\"fill\",\"none\")}})),f.order()},O.updateLayout=function(t,e){var r=this.layers,n=t._size,i=e.radialaxis,a=e.angularaxis,o=e.domain.x,s=e.domain.y;this.xOffset=n.l+n.w*o[0],this.yOffset=n.t+n.h*(1-s[1]);var f=this.xLength=n.w*(o[1]-o[0]),h=this.yLength=n.h*(s[1]-s[0]),p=e.sector;this.sectorInRad=p.map(I);var d,g,m,v,y,x=this.sectorBBox=function(t){var e,r,n,i,a=t[0],o=t[1]-a,s=L(a,360),l=s+o,c=Math.cos(I(s)),u=Math.sin(I(s)),f=Math.cos(I(l)),h=Math.sin(I(l));i=s<=90&&l>=90||s>90&&l>=450?1:u<=0&&h<=0?0:Math.max(u,h);e=s<=180&&l>=180||s>180&&l>=540?-1:c>=0&&f>=0?0:Math.min(c,f);r=s<=270&&l>=270||s>270&&l>=630?-1:u>=0&&h>=0?0:Math.min(u,h);n=l>=360?1:c<=0&&f<=0?0:Math.max(c,f);return[e,r,n,i]}(p),b=x[2]-x[0],_=x[3]-x[1],w=h/f,T=Math.abs(_/b);w>T?(d=f,y=(h-(g=f*T))/n.h/2,m=[o[0],o[1]],v=[s[0]+y,s[1]-y]):(g=h,y=(f-(d=h/T))/n.w/2,m=[o[0]+y,o[1]-y],v=[s[0],s[1]]),this.xLength2=d,this.yLength2=g,this.xDomain2=m,this.yDomain2=v;var k=this.xOffset2=n.l+n.w*m[0],M=this.yOffset2=n.t+n.h*(1-v[1]),A=this.radius=d/b,S=this.innerRadius=e.hole*A,E=this.cx=k-A*x[0],C=this.cy=M+A*x[3],P=this.cxx=E-k,z=this.cyy=C-M;this.radialAxis=this.mockAxis(t,e,i,{_id:\"x\",side:{counterclockwise:\"top\",clockwise:\"bottom\"}[i.side],_realSide:i.side,domain:[S/n.w,A/n.w]}),this.angularAxis=this.mockAxis(t,e,a,{side:\"right\",domain:[0,Math.PI],autorange:!1}),this.doAutoRange(t,e),this.updateAngularAxis(t,e),this.updateRadialAxis(t,e),this.updateRadialAxisTitle(t,e),this.xaxis=this.mockCartesianAxis(t,e,{_id:\"x\",domain:m}),this.yaxis=this.mockCartesianAxis(t,e,{_id:\"y\",domain:v});var O=this.pathSubplot();this.clipPaths.forTraces.select(\"path\").attr(\"d\",O).attr(\"transform\",l(P,z)),r.frontplot.attr(\"transform\",l(k,M)).call(u.setClipUrl,this._hasClipOnAxisFalse?null:this.clipIds.forTraces,this.gd),r.bg.attr(\"d\",O).attr(\"transform\",l(E,C)).call(c.fill,e.bgcolor)},O.mockAxis=function(t,e,r,n){var i=o.extendFlat({},r,n);return d(i,e,t),i},O.mockCartesianAxis=function(t,e,r){var n=this,i=r._id,a=o.extendFlat({type:\"linear\"},r);p(a,t);var s={x:[0,2],y:[1,3]};return a.setRange=function(){var t=n.sectorBBox,r=s[i],o=n.radialAxis._rl,l=(o[1]-o[0])/(1-e.hole);a.range=[t[r[0]]*l,t[r[1]]*l]},a.isPtWithinRange=\"x\"===i?function(t){return n.isPtInside(t)}:function(){return!0},a.setRange(),a.setScale(),a},O.doAutoRange=function(t,e){var r=this.gd,n=this.radialAxis,i=e.radialaxis;n.setScale(),g(r,n);var a=n.range;i.range=a.slice(),i._input.range=a.slice(),n._rl=[n.r2l(a[0],null,\"gregorian\"),n.r2l(a[1],null,\"gregorian\")]},O.updateRadialAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.radialaxis,g=L(e.sector[0],360),m=r.radialAxis,v=u<a;r.fillViewInitialKey(\"radialaxis.angle\",d.angle),r.fillViewInitialKey(\"radialaxis.range\",m.range.slice()),m.setGeometry(),\"auto\"===m.tickangle&&g>90&&g<=270&&(m.tickangle=180);var y=function(t){return l(m.l2p(t.x)+u,0)},x=D(d);if(r.radialTickLayout!==x&&(i[\"radial-axis\"].selectAll(\".xtick\").remove(),r.radialTickLayout=x),v){m.setScale();var b=h.calcTicks(m),_=h.clipEnds(m,b),w=h.getTickSigns(m)[2];h.drawTicks(n,m,{vals:b,layer:i[\"radial-axis\"],path:h.makeTickPath(m,0,w),transFn:y,crisp:!1}),h.drawGrid(n,m,{vals:_,layer:i[\"radial-grid\"],path:function(t){return r.pathArc(m.r2p(t.x)+u)},transFn:o.noop,crisp:!1}),h.drawLabels(n,m,{vals:b,layer:i[\"radial-axis\"],transFn:y,labelFns:h.makeLabelFns(m,0)})}var T=r.radialAxisAngle=r.vangles?P(R(I(d.angle),r.vangles)):d.angle,k=l(f,p),M=k+s(-T);F(i[\"radial-axis\"],v&&(d.showticklabels||d.ticks),{transform:M}),F(i[\"radial-grid\"],v&&d.showgrid,{transform:k}),F(i[\"radial-line\"].select(\"line\"),v&&d.showline,{x1:u,y1:0,x2:a,y2:0,transform:M}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateRadialAxisTitle=function(t,e,r){var n=this.gd,i=this.radius,a=this.cx,o=this.cy,s=e.radialaxis,l=this.id+\"title\",c=void 0!==r?r:this.radialAxisAngle,f=I(c),h=Math.cos(f),p=Math.sin(f),d=0;if(s.title){var g=u.bBox(this.layers[\"radial-axis\"].node()).height,m=s.title.font.size;d=\"counterclockwise\"===s.side?-g-.4*m:g+.8*m}this.layers[\"radial-axis-title\"]=x.draw(n,l,{propContainer:s,propName:this.id+\".radialaxis.title\",placeholder:C(n,\"Click to enter radial axis title\"),attributes:{x:a+i/2*h+d*p,y:o-i/2*p+d*h,\"text-anchor\":\"middle\"},transform:{rotate:-c}})},O.updateAngularAxis=function(t,e){var r=this,n=r.gd,i=r.layers,a=r.radius,u=r.innerRadius,f=r.cx,p=r.cy,d=e.angularaxis,g=r.angularAxis;r.fillViewInitialKey(\"angularaxis.rotation\",d.rotation),g.setGeometry(),g.setScale();var m=function(t){return g.t2g(t.x)};\"linear\"===g.type&&\"radians\"===g.thetaunit&&(g.tick0=P(g.tick0),g.dtick=P(g.dtick));var v=function(t){return l(f+a*Math.cos(t),p-a*Math.sin(t))},y=h.makeLabelFns(g,0).labelStandoff,x={xFn:function(t){var e=m(t);return Math.cos(e)*y},yFn:function(t){var e=m(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(y+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*A)},anchorFn:function(t){var e=m(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},heightFn:function(t,e,r){var n=m(t);return-.5*(1+Math.sin(n))*r}},b=D(d);r.angularTickLayout!==b&&(i[\"angular-axis\"].selectAll(\".\"+g._id+\"tick\").remove(),r.angularTickLayout=b);var _,w=h.calcTicks(g);if(\"linear\"===e.gridshape?(_=w.map(m),o.angleDelta(_[0],_[1])<0&&(_=_.slice().reverse())):_=null,r.vangles=_,\"category\"===g.type&&(w=w.filter((function(t){return o.isAngleInsideSector(m(t),r.sectorInRad)}))),g.visible){var T=\"inside\"===g.ticks?-1:1,k=(g.linewidth||1)/2;h.drawTicks(n,g,{vals:w,layer:i[\"angular-axis\"],path:\"M\"+T*k+\",0h\"+T*g.ticklen,transFn:function(t){var e=m(t);return v(e)+s(-P(e))},crisp:!1}),h.drawGrid(n,g,{vals:w,layer:i[\"angular-grid\"],path:function(t){var e=m(t),r=Math.cos(e),n=Math.sin(e);return\"M\"+[f+u*r,p-u*n]+\"L\"+[f+a*r,p-a*n]},transFn:o.noop,crisp:!1}),h.drawLabels(n,g,{vals:w,layer:i[\"angular-axis\"],repositionOnUpdate:!0,transFn:function(t){return v(m(t))},labelFns:x})}F(i[\"angular-line\"].select(\"path\"),d.showline,{d:r.pathSubplot(),transform:l(f,p)}).attr(\"stroke-width\",d.linewidth).call(c.stroke,d.linecolor)},O.updateFx=function(t,e){this.gd._context.staticPlot||(this.updateAngularDrag(t),this.updateRadialDrag(t,e,0),this.updateRadialDrag(t,e,1),this.updateMainDrag(t))},O.updateMainDrag=function(t){var e,r,s=this,c=s.gd,u=s.layers,f=t._zoomlayer,h=S.MINZOOM,p=S.OFFEDGE,d=s.radius,g=s.innerRadius,x=s.cx,T=s.cy,k=s.cxx,M=s.cyy,A=s.sectorInRad,C=s.vangles,L=s.radialAxis,I=E.clampTiny,P=E.findXYatLength,z=E.findEnclosingVertexAngles,O=S.cornerHalfWidth,D=S.cornerLen/2,R=m.makeDragger(u,\"path\",\"maindrag\",\"crosshair\");n.select(R).attr(\"d\",s.pathSubplot()).attr(\"transform\",l(x,T));var F,B,N,j,U,V,q,H,G,Y={element:R,gd:c,subplot:s.id,plotinfo:{id:s.id,xaxis:s.xaxis,yaxis:s.yaxis},xaxes:[s.xaxis],yaxes:[s.yaxis]};function W(t,e){return Math.sqrt(t*t+e*e)}function X(t,e){return W(t-k,e-M)}function Z(t,e){return Math.atan2(M-e,t-k)}function J(t,e){return[t*Math.cos(e),t*Math.sin(-e)]}function K(t,e){if(0===t)return s.pathSector(2*O);var r=D/t,n=e-r,i=e+r,a=Math.max(0,Math.min(t,d)),o=a-O,l=a+O;return\"M\"+J(o,n)+\"A\"+[o,o]+\" 0,0,0 \"+J(o,i)+\"L\"+J(l,i)+\"A\"+[l,l]+\" 0,0,1 \"+J(l,n)+\"Z\"}function Q(t,e,r){if(0===t)return s.pathSector(2*O);var n,i,a=J(t,e),o=J(t,r),l=I((a[0]+o[0])/2),c=I((a[1]+o[1])/2);if(l&&c){var u=c/l,f=-1/u,h=P(O,u,l,c);n=P(D,f,h[0][0],h[0][1]),i=P(D,f,h[1][0],h[1][1])}else{var p,d;c?(p=D,d=O):(p=O,d=D),n=[[l-p,c-d],[l+p,c-d]],i=[[l-p,c+d],[l+p,c+d]]}return\"M\"+n.join(\"L\")+\"L\"+i.reverse().join(\"L\")+\"Z\"}function $(t,e){return e=Math.max(Math.min(e,d),g),t<p?t=0:d-t<p?t=d:e<p?e=0:d-e<p&&(e=d),Math.abs(e-t)>h?(t<e?(N=t,j=e):(N=e,j=t),!0):(N=null,j=null,!1)}function tt(t,e){t=t||U,e=e||\"M0,0Z\",H.attr(\"d\",t),G.attr(\"d\",e),m.transitionZoombox(H,G,V,q),V=!0;var r={};at(r),c.emit(\"plotly_relayouting\",r)}function et(t,n){var i,a,o=F+(t*=e),l=B+(n*=r),c=X(F,B),u=Math.min(X(o,l),d),f=Z(F,B);$(c,u)&&(i=U+s.pathSector(j),N&&(i+=s.pathSector(N)),a=K(N,f)+K(j,f)),tt(i,a)}function rt(t,e,r,n){var i=E.findIntersectionXY(r,n,r,[t-k,M-e]);return W(i[0],i[1])}function nt(t,e){var r,n,i=F+t,a=B+e,o=Z(F,B),l=Z(i,a),c=z(o,C),u=z(l,C);$(rt(F,B,c[0],c[1]),Math.min(rt(i,a,u[0],u[1]),d))&&(r=U+s.pathSector(j),N&&(r+=s.pathSector(N)),n=[Q(N,c[0],c[1]),Q(j,c[0],c[1])].join(\" \")),tt(r,n)}function it(){if(m.removeZoombox(c),null!==N&&null!==j){var t={};at(t),m.showDoubleClickNotifier(c),a.call(\"_guiRelayout\",c,t)}}function at(t){var e=L._rl,r=(e[1]-e[0])/(1-g/d)/d,n=[e[0]+(N-g)*r,e[0]+(j-g)*r];t[s.id+\".radialaxis.range\"]=n}function ot(t,e){var r=c._fullLayout.clickmode;if(m.removeZoombox(c),2===t){var n={};for(var i in s.viewInitial)n[s.id+\".\"+i]=s.viewInitial[i];c.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",c,n)}r.indexOf(\"select\")>-1&&1===t&&_(e,c,[s.xaxis],[s.yaxis],s.id,Y),r.indexOf(\"event\")>-1&&y.click(c,e,s.id)}Y.prepFn=function(t,n,a){var l=c._fullLayout.dragmode,u=R.getBoundingClientRect();c._fullLayout._calcInverseTransform(c);var h=c._fullLayout._invTransform;e=c._fullLayout._invScaleX,r=c._fullLayout._invScaleY;var p=o.apply3DTransform(h)(n-u.left,a-u.top);if(F=p[0],B=p[1],C){var g=E.findPolygonOffset(d,A[0],A[1],C);F+=k+g[0],B+=M+g[1]}switch(l){case\"zoom\":Y.moveFn=C?nt:et,Y.clickFn=ot,Y.doneFn=it,function(){N=null,j=null,U=s.pathSubplot(),V=!1;var t=c._fullLayout[s.id];q=i(t.bgcolor).getLuminance(),(H=m.makeZoombox(f,q,x,T,U)).attr(\"fill-rule\",\"evenodd\"),G=m.makeCorners(f,x,T),w(c)}();break;case\"select\":case\"lasso\":b(t,n,a,Y,l)}},R.onmousemove=function(t){y.hover(c,t,s.id),c._fullLayout._lasthover=R,c._fullLayout._hoversubplot=s.id},R.onmouseout=function(t){c._dragging||v.unhover(c,t)},v.init(Y)},O.updateRadialDrag=function(t,e,r){var i=this,c=i.gd,u=i.layers,f=i.radius,h=i.innerRadius,p=i.cx,d=i.cy,g=i.radialAxis,y=S.radialDragBoxSize,x=y/2;if(g.visible){var b,_,T,A=I(i.radialAxisAngle),E=g._rl,C=E[0],L=E[1],z=E[r],O=.75*(E[1]-E[0])/(1-e.hole)/f;r?(b=p+(f+x)*Math.cos(A),_=d-(f+x)*Math.sin(A),T=\"radialdrag\"):(b=p+(h-x)*Math.cos(A),_=d-(h-x)*Math.sin(A),T=\"radialdrag-inner\");var D,B,N,j=m.makeRectDragger(u,T,\"crosshair\",-x,-x,y,y),U={element:j,gd:c};F(n.select(j),g.visible&&h<f,{transform:l(b,_)}),U.prepFn=function(){D=null,B=null,N=null,U.moveFn=V,U.doneFn=q,w(c)},U.clampFn=function(t,e){return Math.sqrt(t*t+e*e)<S.MINDRAG&&(t=0,e=0),[t,e]},v.init(U)}function V(t,e){if(D)D(t,e);else{var n=[t,-e],a=[Math.cos(A),Math.sin(A)],s=Math.abs(o.dot(n,a)/Math.sqrt(o.dot(n,n)));isNaN(s)||(D=s<.5?H:G)}var l={};!function(t){null!==B?t[i.id+\".radialaxis.angle\"]=B:null!==N&&(t[i.id+\".radialaxis.range[\"+r+\"]\"]=N)}(l),c.emit(\"plotly_relayouting\",l)}function q(){null!==B?a.call(\"_guiRelayout\",c,i.id+\".radialaxis.angle\",B):null!==N&&a.call(\"_guiRelayout\",c,i.id+\".radialaxis.range[\"+r+\"]\",N)}function H(t,e){if(0!==r){var n=b+t,a=_+e;B=Math.atan2(d-a,n-p),i.vangles&&(B=R(B,i.vangles)),B=P(B);var o=l(p,d)+s(-B);u[\"radial-axis\"].attr(\"transform\",o),u[\"radial-line\"].select(\"line\").attr(\"transform\",o);var c=i.gd._fullLayout,f=c[i.id];i.updateRadialAxisTitle(c,f,B)}}function G(t,e){var n=o.dot([t,-e],[Math.cos(A),Math.sin(A)]);if(N=z-O*n,O>0==(r?N>C:N<L)){var s=c._fullLayout,l=s[i.id];g.range[r]=N,g._rl[r]=N,i.updateRadialAxis(s,l),i.xaxis.setRange(),i.xaxis.setScale(),i.yaxis.setRange(),i.yaxis.setScale();var u=!1;for(var f in i.traceHash){var h=i.traceHash[f],p=o.filterVisible(h);h[0][0].trace._module.plot(c,i,p,l),a.traceIs(f,\"gl\")&&p.length&&(u=!0)}u&&(k(c),M(c))}else N=null}},O.updateAngularDrag=function(t){var e=this,r=e.gd,i=e.layers,c=e.radius,f=e.angularAxis,h=e.cx,p=e.cy,d=e.cxx,g=e.cyy,y=S.angularDragBoxSize,x=m.makeDragger(i,\"path\",\"angulardrag\",\"move\"),b={element:x,gd:r};function _(t,e){return Math.atan2(g+y-e,t-d-y)}n.select(x).attr(\"d\",e.pathAnnulus(c,c+y)).attr(\"transform\",l(h,p)).call(T,\"move\");var A,E,C,L,I,z,O=i.frontplot.select(\".scatterlayer\").selectAll(\".trace\"),D=O.selectAll(\".point\"),R=O.selectAll(\".textpoint\");function F(c,m){var v=e.gd._fullLayout,y=v[e.id],x=_(A+c*t._invScaleX,E+m*t._invScaleY),b=P(x-z);if(L=C+b,i.frontplot.attr(\"transform\",l(e.xOffset2,e.yOffset2)+s([-b,d,g])),e.vangles){I=e.radialAxisAngle+b;var w=l(h,p)+s(-b),T=l(h,p)+s(-I);i.bg.attr(\"transform\",w),i[\"radial-grid\"].attr(\"transform\",w),i[\"radial-axis\"].attr(\"transform\",T),i[\"radial-line\"].select(\"line\").attr(\"transform\",T),e.updateRadialAxisTitle(v,y,I)}else e.clipPaths.forTraces.select(\"path\").attr(\"transform\",l(d,g)+s(b));D.each((function(){var t=n.select(this),e=u.getTranslate(t);t.attr(\"transform\",l(e.x,e.y)+s([b]))})),R.each((function(){var t=n.select(this),e=t.select(\"text\"),r=u.getTranslate(t);t.attr(\"transform\",s([b,e.attr(\"x\"),e.attr(\"y\")])+l(r.x,r.y))})),f.rotation=o.modHalf(L,360),e.updateAngularAxis(v,y),e._hasClipOnAxisFalse&&!o.isFullCircle(e.sectorInRad)&&O.call(u.hideOutsideRangePoints,e);var S=!1;for(var F in e.traceHash)if(a.traceIs(F,\"gl\")){var N=e.traceHash[F],j=o.filterVisible(N);N[0][0].trace._module.plot(r,e,j,y),j.length&&(S=!0)}S&&(k(r),M(r));var U={};B(U),r.emit(\"plotly_relayouting\",U)}function B(t){t[e.id+\".angularaxis.rotation\"]=L,e.vangles&&(t[e.id+\".radialaxis.angle\"]=I)}function N(){R.select(\"text\").attr(\"transform\",null);var t={};B(t),a.call(\"_guiRelayout\",r,t)}b.prepFn=function(n,i,a){var s=t[e.id];C=s.angularaxis.rotation;var l=x.getBoundingClientRect();A=i-l.left,E=a-l.top,r._fullLayout._calcInverseTransform(r);var c=o.apply3DTransform(t._invTransform)(A,E);A=c[0],E=c[1],z=_(A,E),b.moveFn=F,b.doneFn=N,w(r)},e.vangles&&!o.isFullCircle(e.sectorInRad)&&(b.prepFn=o.noop,T(n.select(x),null)),v.init(b)},O.isPtInside=function(t){var e=this.sectorInRad,r=this.vangles,n=this.angularAxis.c2g(t.theta),i=this.radialAxis,a=i.c2l(t.r),s=i._rl;return(r?E.isPtInsidePolygon:o.isPtInsideSector)(a,n,s,e,r)},O.pathArc=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathArc)(t,e[0],e[1],r)},O.pathSector=function(t){var e=this.sectorInRad,r=this.vangles;return(r?E.pathPolygon:o.pathSector)(t,e[0],e[1],r)},O.pathAnnulus=function(t,e){var r=this.sectorInRad,n=this.vangles;return(n?E.pathPolygonAnnulus:o.pathAnnulus)(t,e,r[0],r[1],n)},O.pathSubplot=function(){var t=this.innerRadius,e=this.radius;return t?this.pathAnnulus(t,e):this.pathSector(e)},O.fillViewInitialKey=function(t,e){t in this.viewInitial||(this.viewInitial[t]=e)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/clear_gl_canvases\":762,\"../../lib/setcursor\":799,\"../../plot_api/subroutines\":818,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../cartesian/autorange\":827,\"../cartesian/dragbox\":836,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,\"./constants\":892,\"./helpers\":893,\"./set_convert\":904,d3:169,tinycolor2:576}],904:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../cartesian/set_convert\"),a=n.deg2rad,o=n.rad2deg;e.exports=function(t,e,r){switch(i(t,r),t._id){case\"x\":case\"radialaxis\":!function(t,e){var r=e._subplot;t.setGeometry=function(){var e=t._rl[0],n=t._rl[1],i=r.innerRadius,a=(r.radius-i)/(n-e),o=i/a,s=e>n?function(t){return t<=0}:function(t){return t>=0};t.c2g=function(r){var n=t.c2l(r)-e;return(s(n)?n:0)+o},t.g2c=function(r){return t.l2c(r+e-o)},t.g2p=function(t){return t*a},t.c2p=function(e){return t.g2p(t.c2g(e))}}}(t,e);break;case\"angularaxis\":!function(t,e){var r=t.type;if(\"linear\"===r){var i=t.d2c,s=t.c2d;t.d2c=function(t,e){return function(t,e){return\"degrees\"===e?a(t):t}(i(t),e)},t.c2d=function(t,e){return s(function(t,e){return\"degrees\"===e?o(t):t}(t,e))}}t.makeCalcdata=function(e,i){var a,o,s=e[i],l=e._length,c=function(r){return t.d2c(r,e.thetaunit)};if(s){if(n.isTypedArray(s)&&\"linear\"===r){if(l===s.length)return s;if(s.subarray)return s.subarray(0,l)}for(a=new Array(l),o=0;o<l;o++)a[o]=c(s[o])}else{var u=i+\"0\",f=\"d\"+i,h=u in e?c(e[u]):0,p=e[f]?c(e[f]):(t.period||2*Math.PI)/l;for(a=new Array(l),o=0;o<l;o++)a[o]=h+o*p}return a},t.setGeometry=function(){var i,s,l,c,u=e.sector,f=u.map(a),h={clockwise:-1,counterclockwise:1}[t.direction],p=a(t.rotation),d=function(t){return h*t+p},g=function(t){return(t-p)/h};switch(r){case\"linear\":s=i=n.identity,c=a,l=o,t.range=n.isFullCircle(f)?[u[0],u[0]+360]:f.map(g).map(o);break;case\"category\":var m=t._categories.length,v=t.period?Math.max(t.period,m):m;0===v&&(v=1),s=c=function(t){return 2*t*Math.PI/v},i=l=function(t){return t*v/Math.PI/2},t.range=[0,v]}t.c2g=function(t){return d(s(t))},t.g2c=function(t){return i(g(t))},t.t2g=function(t){return d(c(t))},t.g2t=function(t){return l(g(t))}}}(t,e)}}},{\"../../lib\":778,\"../cartesian/set_convert\":848}],905:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_template\"),a=t(\"./domain\").defaults;e.exports=function(t,e,r,o){var s,l,c=o.type,u=o.attributes,f=o.handleDefaults,h=o.partition||\"x\",p=e._subplots[c],d=p.length,g=d&&p[0].replace(/\\d+$/,\"\");function m(t,e){return n.coerce(s,l,u,t,e)}for(var v=0;v<d;v++){var y=p[v];s=t[y]?t[y]:t[y]={},l=i.newContainer(e,y,g),m(\"uirevision\",e.uirevision);var x={};x[h]=[v/d,(v+1)/d],a(l,e,m,x),o.id=y,f(s,l,m,o)}}},{\"../lib\":778,\"../plot_api/plot_template\":817,\"./domain\":855}],906:[function(t,e,r){\"use strict\";['Variables are inserted using %{variable}, for example \"y: %{y}\".','Numbers are formatted using d3-format\\'s syntax %{variable:d3-format}, for example \"Price: %{y:$.2f}\".',t(\"../constants/docs\").FORMAT_LINK,\"for details on the formatting syntax.\",'Dates are formatted using d3-time-format\\'s syntax %{variable|d3-time-format}, for example \"Day: %{2019-01-01|%A}\".',t(\"../constants/docs\").DATE_FORMAT_LINK,\"for details on the date formatting syntax.\"].join(\" \");function n(t){var e=t.description?\" \"+t.description:\"\",r=t.keys||[];if(r.length>0){for(var n=[],i=0;i<r.length;i++)n[i]=\"`\"+r[i]+\"`\";e+=\"Finally, the template string has access to \",e=1===r.length?\"variable \"+n[0]:\"variables \"+n.slice(0,-1).join(\", \")+\" and \"+n.slice(-1)+\".\"}return e}r.hovertemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"none\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r},r.texttemplateAttrs=function(t,e){t=t||{};n(e=e||{});var r={valType:\"string\",dflt:\"\",editType:t.editType||\"calc\"};return!1!==t.arrayOk&&(r.arrayOk=!0),r}},{\"../constants/docs\":748}],907:[function(t,e,r){\"use strict\";var n=t(\"./ternary\"),i=t(\"../../plots/get_data\").getSubplotCalcData,a=t(\"../../lib\").counterRegex;r.name=\"ternary\";var o=r.attr=\"subplot\";r.idRoot=\"ternary\",r.idRegex=r.attrRegex=a(\"ternary\"),(r.attributes={})[o]={valType:\"subplotid\",dflt:\"ternary\",editType:\"calc\"},r.layoutAttributes=t(\"./layout_attributes\"),r.supplyLayoutDefaults=t(\"./layout_defaults\"),r.plot=function(t){for(var e=t._fullLayout,r=t.calcdata,a=e._subplots.ternary,o=0;o<a.length;o++){var s=a[o],l=i(r,\"ternary\",s),c=e[s]._subplot;c||(c=new n({id:s,graphDiv:t,container:e._ternarylayer.node()},e),e[s]._subplot=c),c.plot(l,e,t._promises)}},r.clean=function(t,e,r,n){for(var i=n._subplots.ternary||[],a=0;a<i.length;a++){var o=i[a],s=n[o]._subplot;!e[o]&&s&&(s.plotContainer.remove(),s.clipDef.remove(),s.clipDefRelative.remove(),s.layers[\"a-title\"].remove(),s.layers[\"b-title\"].remove(),s.layers[\"c-title\"].remove())}}},{\"../../lib\":778,\"../../plots/get_data\":865,\"./layout_attributes\":908,\"./layout_defaults\":909,\"./ternary\":910}],908:[function(t,e,r){\"use strict\";var n=t(\"../../components/color/attributes\"),i=t(\"../domain\").attributes,a=t(\"../cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll,s=t(\"../../lib/extend\").extendFlat,l={title:{text:a.title.text,font:a.title.font},color:a.color,tickmode:a.tickmode,nticks:s({},a.nticks,{dflt:6,min:1}),tick0:a.tick0,dtick:a.dtick,tickvals:a.tickvals,ticktext:a.ticktext,ticks:a.ticks,ticklen:a.ticklen,tickwidth:a.tickwidth,tickcolor:a.tickcolor,showticklabels:a.showticklabels,showtickprefix:a.showtickprefix,tickprefix:a.tickprefix,showticksuffix:a.showticksuffix,ticksuffix:a.ticksuffix,showexponent:a.showexponent,exponentformat:a.exponentformat,minexponent:a.minexponent,separatethousands:a.separatethousands,tickfont:a.tickfont,tickangle:a.tickangle,tickformat:a.tickformat,tickformatstops:a.tickformatstops,hoverformat:a.hoverformat,showline:s({},a.showline,{dflt:!0}),linecolor:a.linecolor,linewidth:a.linewidth,showgrid:s({},a.showgrid,{dflt:!0}),gridcolor:a.gridcolor,gridwidth:a.gridwidth,layer:a.layer,min:{valType:\"number\",dflt:0,min:0},_deprecated:{title:a._deprecated.title,titlefont:a._deprecated.titlefont}},c=e.exports=o({domain:i({name:\"ternary\"}),bgcolor:{valType:\"color\",dflt:n.background},sum:{valType:\"number\",dflt:1,min:0},aaxis:l,baxis:l,caxis:l},\"plot\",\"from-root\");c.uirevision={valType:\"any\",editType:\"none\"},c.aaxis.uirevision=c.baxis.uirevision=c.caxis.uirevision={valType:\"any\",editType:\"none\"}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../cartesian/layout_attributes\":842,\"../domain\":855}],909:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../plot_api/plot_template\"),a=t(\"../../lib\"),o=t(\"../subplot_defaults\"),s=t(\"../cartesian/tick_label_defaults\"),l=t(\"../cartesian/tick_mark_defaults\"),c=t(\"../cartesian/tick_value_defaults\"),u=t(\"../cartesian/line_grid_defaults\"),f=t(\"./layout_attributes\"),h=[\"aaxis\",\"baxis\",\"caxis\"];function p(t,e,r,a){var o,s,l,c=r(\"bgcolor\"),u=r(\"sum\");a.bgColor=n.combine(c,a.paper_bgcolor);for(var f=0;f<h.length;f++)s=t[o=h[f]]||{},(l=i.newContainer(e,o))._name=o,d(s,l,a,e);var p=e.aaxis,g=e.baxis,m=e.caxis;p.min+g.min+m.min>=u&&(p.min=0,g.min=0,m.min=0,t.aaxis&&delete t.aaxis.min,t.baxis&&delete t.baxis.min,t.caxis&&delete t.caxis.min)}function d(t,e,r,n){var i=f[e._name];function o(r,n){return a.coerce(t,e,i,r,n)}o(\"uirevision\",n.uirevision),e.type=\"linear\";var h=o(\"color\"),p=h!==i.color.dflt?h:r.font.color,d=e._name.charAt(0).toUpperCase(),g=\"Component \"+d,m=o(\"title.text\",g);e._hovertitle=m===g?m:d,a.coerceFont(o,\"title.font\",{family:r.font.family,size:Math.round(1.2*r.font.size),color:p}),o(\"min\"),c(t,e,o,\"linear\"),s(t,e,o,\"linear\",{}),l(t,e,o,{outerTicks:!0}),o(\"showticklabels\")&&(a.coerceFont(o,\"tickfont\",{family:r.font.family,size:r.font.size,color:p}),o(\"tickangle\"),o(\"tickformat\")),u(t,e,o,{dfltColor:h,bgColor:r.bgColor,blend:60,showLine:!0,showGrid:!0,noZeroLine:!0,attributes:i}),o(\"hoverformat\"),o(\"layer\")}e.exports=function(t,e,r){o(t,e,r,{type:\"ternary\",attributes:f,handleDefaults:p,font:e.font,paper_bgcolor:e.paper_bgcolor})}},{\"../../components/color\":643,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../cartesian/line_grid_defaults\":844,\"../cartesian/tick_label_defaults\":849,\"../cartesian/tick_mark_defaults\":850,\"../cartesian/tick_value_defaults\":851,\"../subplot_defaults\":905,\"./layout_attributes\":908}],910:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=o.strTranslate,l=o._,c=t(\"../../components/color\"),u=t(\"../../components/drawing\"),f=t(\"../cartesian/set_convert\"),h=t(\"../../lib/extend\").extendFlat,p=t(\"../plots\"),d=t(\"../cartesian/axes\"),g=t(\"../../components/dragelement\"),m=t(\"../../components/fx\"),v=t(\"../../components/dragelement/helpers\"),y=v.freeMode,x=v.rectMode,b=t(\"../../components/titles\"),_=t(\"../cartesian/select\").prepSelect,w=t(\"../cartesian/select\").selectOnClick,T=t(\"../cartesian/select\").clearSelect,k=t(\"../cartesian/select\").clearSelectionsCache,M=t(\"../cartesian/constants\");function A(t,e){this.id=t.id,this.graphDiv=t.graphDiv,this.init(e),this.makeFramework(e),this.aTickLayout=null,this.bTickLayout=null,this.cTickLayout=null}e.exports=A;var S=A.prototype;S.init=function(t){this.container=t._ternarylayer,this.defs=t._defs,this.layoutId=t._uid,this.traceHash={},this.layers={}},S.plot=function(t,e){var r=e[this.id],n=e._size;this._hasClipOnAxisFalse=!1;for(var i=0;i<t.length;i++){if(!1===t[i][0].trace.cliponaxis){this._hasClipOnAxisFalse=!0;break}}this.updateLayers(r),this.adjustLayout(r,n),p.generalUpdatePerTraceModule(this.graphDiv,this,t,r),this.layers.plotbg.select(\"path\").call(c.fill,r.bgcolor)},S.makeFramework=function(t){var e=this.graphDiv,r=t[this.id],n=this.clipId=\"clip\"+this.layoutId+this.id,i=this.clipIdRelative=\"clip-relative\"+this.layoutId+this.id;this.clipDef=o.ensureSingleById(t._clips,\"clipPath\",n,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.clipDefRelative=o.ensureSingleById(t._clips,\"clipPath\",i,(function(t){t.append(\"path\").attr(\"d\",\"M0,0Z\")})),this.plotContainer=o.ensureSingle(this.container,\"g\",this.id),this.updateLayers(r),u.setClipUrl(this.layers.backplot,n,e),u.setClipUrl(this.layers.grids,n,e)},S.updateLayers=function(t){var e=this.layers,r=[\"draglayer\",\"plotbg\",\"backplot\",\"grids\"];\"below traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"below traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"below traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\"),r.push(\"frontplot\"),\"above traces\"===t.aaxis.layer&&r.push(\"aaxis\",\"aline\"),\"above traces\"===t.baxis.layer&&r.push(\"baxis\",\"bline\"),\"above traces\"===t.caxis.layer&&r.push(\"caxis\",\"cline\");var i=this.plotContainer.selectAll(\"g.toplevel\").data(r,String),a=[\"agrid\",\"bgrid\",\"cgrid\"];i.enter().append(\"g\").attr(\"class\",(function(t){return\"toplevel \"+t})).each((function(t){var r=n.select(this);e[t]=r,\"frontplot\"===t?r.append(\"g\").classed(\"scatterlayer\",!0):\"backplot\"===t?r.append(\"g\").classed(\"maplayer\",!0):\"plotbg\"===t?r.append(\"path\").attr(\"d\",\"M0,0Z\"):\"aline\"===t||\"bline\"===t||\"cline\"===t?r.append(\"path\"):\"grids\"===t&&a.forEach((function(t){e[t]=r.append(\"g\").classed(\"grid \"+t,!0)}))})),i.order()};var E=Math.sqrt(4/3);S.adjustLayout=function(t,e){var r,n,i,a,o,l,p=this,d=t.domain,g=(d.x[0]+d.x[1])/2,m=(d.y[0]+d.y[1])/2,v=d.x[1]-d.x[0],y=d.y[1]-d.y[0],x=v*e.w,b=y*e.h,_=t.sum,w=t.aaxis.min,T=t.baxis.min,k=t.caxis.min;x>E*b?i=(a=b)*E:a=(i=x)/E,o=v*i/x,l=y*a/b,r=e.l+e.w*g-i/2,n=e.t+e.h*(1-m)-a/2,p.x0=r,p.y0=n,p.w=i,p.h=a,p.sum=_,p.xaxis={type:\"linear\",range:[w+2*k-_,_-w-2*T],domain:[g-o/2,g+o/2],_id:\"x\"},f(p.xaxis,p.graphDiv._fullLayout),p.xaxis.setScale(),p.xaxis.isPtWithinRange=function(t){return t.a>=p.aaxis.range[0]&&t.a<=p.aaxis.range[1]&&t.b>=p.baxis.range[1]&&t.b<=p.baxis.range[0]&&t.c>=p.caxis.range[1]&&t.c<=p.caxis.range[0]},p.yaxis={type:\"linear\",range:[w,_-T-k],domain:[m-l/2,m+l/2],_id:\"y\"},f(p.yaxis,p.graphDiv._fullLayout),p.yaxis.setScale(),p.yaxis.isPtWithinRange=function(){return!0};var M=p.yaxis.domain[0],A=p.aaxis=h({},t.aaxis,{range:[w,_-T-k],side:\"left\",tickangle:(+t.aaxis.tickangle||0)-30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(A,p.graphDiv._fullLayout),A.setScale();var S=p.baxis=h({},t.baxis,{range:[_-w-k,T],side:\"bottom\",domain:p.xaxis.domain,anchor:\"free\",position:0,_id:\"x\",_length:i});f(S,p.graphDiv._fullLayout),S.setScale();var C=p.caxis=h({},t.caxis,{range:[_-w-T,k],side:\"right\",tickangle:(+t.caxis.tickangle||0)+30,domain:[M,M+l*E],anchor:\"free\",position:0,_id:\"y\",_length:i});f(C,p.graphDiv._fullLayout),C.setScale();var L=\"M\"+r+\",\"+(n+a)+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDef.select(\"path\").attr(\"d\",L),p.layers.plotbg.select(\"path\").attr(\"d\",L);var I=\"M0,\"+a+\"h\"+i+\"l-\"+i/2+\",-\"+a+\"Z\";p.clipDefRelative.select(\"path\").attr(\"d\",I);var P=s(r,n);p.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",P),p.clipDefRelative.select(\"path\").attr(\"transform\",null);var z=s(r-S._offset,n+a);p.layers.baxis.attr(\"transform\",z),p.layers.bgrid.attr(\"transform\",z);var O=s(r+i/2,n)+\"rotate(30)\"+s(0,-A._offset);p.layers.aaxis.attr(\"transform\",O),p.layers.agrid.attr(\"transform\",O);var D=s(r+i/2,n)+\"rotate(-30)\"+s(0,-C._offset);p.layers.caxis.attr(\"transform\",D),p.layers.cgrid.attr(\"transform\",D),p.drawAxes(!0),p.layers.aline.select(\"path\").attr(\"d\",A.showline?\"M\"+r+\",\"+(n+a)+\"l\"+i/2+\",-\"+a:\"M0,0\").call(c.stroke,A.linecolor||\"#000\").style(\"stroke-width\",(A.linewidth||0)+\"px\"),p.layers.bline.select(\"path\").attr(\"d\",S.showline?\"M\"+r+\",\"+(n+a)+\"h\"+i:\"M0,0\").call(c.stroke,S.linecolor||\"#000\").style(\"stroke-width\",(S.linewidth||0)+\"px\"),p.layers.cline.select(\"path\").attr(\"d\",C.showline?\"M\"+(r+i/2)+\",\"+n+\"l\"+i/2+\",\"+a:\"M0,0\").call(c.stroke,C.linecolor||\"#000\").style(\"stroke-width\",(C.linewidth||0)+\"px\"),p.graphDiv._context.staticPlot||p.initInteractions(),u.setClipUrl(p.layers.frontplot,p._hasClipOnAxisFalse?null:p.clipId,p.graphDiv)},S.drawAxes=function(t){var e=this.graphDiv,r=this.id.substr(7)+\"title\",n=this.layers,i=this.aaxis,a=this.baxis,o=this.caxis;if(this.drawAx(i),this.drawAx(a),this.drawAx(o),t){var s=Math.max(i.showticklabels?i.tickfont.size/2:0,(o.showticklabels?.75*o.tickfont.size:0)+(\"outside\"===o.ticks?.87*o.ticklen:0)),c=(a.showticklabels?a.tickfont.size:0)+(\"outside\"===a.ticks?a.ticklen:0)+3;n[\"a-title\"]=b.draw(e,\"a\"+r,{propContainer:i,propName:this.id+\".aaxis.title\",placeholder:l(e,\"Click to enter Component A title\"),attributes:{x:this.x0+this.w/2,y:this.y0-i.title.font.size/3-s,\"text-anchor\":\"middle\"}}),n[\"b-title\"]=b.draw(e,\"b\"+r,{propContainer:a,propName:this.id+\".baxis.title\",placeholder:l(e,\"Click to enter Component B title\"),attributes:{x:this.x0-c,y:this.y0+this.h+.83*a.title.font.size+c,\"text-anchor\":\"middle\"}}),n[\"c-title\"]=b.draw(e,\"c\"+r,{propContainer:o,propName:this.id+\".caxis.title\",placeholder:l(e,\"Click to enter Component C title\"),attributes:{x:this.x0+this.w+c,y:this.y0+this.h+.83*o.title.font.size+c,\"text-anchor\":\"middle\"}})}},S.drawAx=function(t){var e,r=this.graphDiv,n=t._name,i=n.charAt(0),a=t._id,s=this.layers[n],l=i+\"tickLayout\",c=(e=t).ticks+String(e.ticklen)+String(e.showticklabels);this[l]!==c&&(s.selectAll(\".\"+a+\"tick\").remove(),this[l]=c),t.setScale();var u=d.calcTicks(t),f=d.clipEnds(t,u),h=d.makeTransTickFn(t),p=d.getTickSigns(t)[2],g=o.deg2rad(30),m=p*(t.linewidth||1)/2,v=p*t.ticklen,y=this.w,x=this.h,b=\"b\"===i?\"M0,\"+m+\"l\"+Math.sin(g)*v+\",\"+Math.cos(g)*v:\"M\"+m+\",0l\"+Math.cos(g)*v+\",\"+-Math.sin(g)*v,_={a:\"M0,0l\"+x+\",-\"+y/2,b:\"M0,0l-\"+y/2+\",-\"+x,c:\"M0,0l-\"+x+\",\"+y/2}[i];d.drawTicks(r,t,{vals:\"inside\"===t.ticks?f:u,layer:s,path:b,transFn:h,crisp:!1}),d.drawGrid(r,t,{vals:f,layer:this.layers[i+\"grid\"],path:_,transFn:h,crisp:!1}),d.drawLabels(r,t,{vals:u,layer:s,transFn:h,labelFns:d.makeLabelFns(t,0,30)})};var C=M.MINZOOM/2+.87,L=\"m-0.87,.5h\"+C+\"v3h-\"+(C+5.2)+\"l\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l2.6,1.5l-\"+C/2+\",\"+.87*C+\"Z\",I=\"m0.87,.5h-\"+C+\"v3h\"+(C+5.2)+\"l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-2.6,1.5l\"+C/2+\",\"+.87*C+\"Z\",P=\"m0,1l\"+C/2+\",\"+.87*C+\"l2.6,-1.5l-\"+(C/2+2.6)+\",-\"+(.87*C+4.5)+\"l-\"+(C/2+2.6)+\",\"+(.87*C+4.5)+\"l2.6,1.5l\"+C/2+\",-\"+.87*C+\"Z\",z=!0;function O(t){n.select(t).selectAll(\".zoombox,.js-zoombox-backdrop,.js-zoombox-menu,.zoombox-corners\").remove()}S.clearSelect=function(){k(this.dragOptions),T(this.dragOptions.gd)},S.initInteractions=function(){var t,e,r,n,f,h,p,d,v,b,T,k,A=this,S=A.layers.plotbg.select(\"path\").node(),C=A.graphDiv,D=C._fullLayout._zoomlayer;function R(t){var e={};return e[A.id+\".aaxis.min\"]=t.a,e[A.id+\".baxis.min\"]=t.b,e[A.id+\".caxis.min\"]=t.c,e}function F(t,e){var r=C._fullLayout.clickmode;O(C),2===t&&(C.emit(\"plotly_doubleclick\",null),a.call(\"_guiRelayout\",C,R({a:0,b:0,c:0}))),r.indexOf(\"select\")>-1&&1===t&&w(e,C,[A.xaxis],[A.yaxis],A.id,A.dragOptions),r.indexOf(\"event\")>-1&&m.click(C,e,A.id)}function B(t,e){return 1-e/A.h}function N(t,e){return 1-(t+(A.h-e)/Math.sqrt(3))/A.w}function j(t,e){return(t-(A.h-e)/Math.sqrt(3))/A.w}function U(i,a){var o=r+i*t,s=n+a*e,l=Math.max(0,Math.min(1,B(0,n),B(0,s))),c=Math.max(0,Math.min(1,N(r,n),N(o,s))),u=Math.max(0,Math.min(1,j(r,n),j(o,s))),g=(l/2+u)*A.w,m=(1-l/2-c)*A.w,y=(g+m)/2,x=m-g,_=(1-l)*A.h,w=_-x/E;x<M.MINZOOM?(p=f,T.attr(\"d\",v),k.attr(\"d\",\"M0,0Z\")):(p={a:f.a+l*h,b:f.b+c*h,c:f.c+u*h},T.attr(\"d\",v+\"M\"+g+\",\"+_+\"H\"+m+\"L\"+y+\",\"+w+\"L\"+g+\",\"+_+\"Z\"),k.attr(\"d\",\"M\"+r+\",\"+n+\"m0.5,0.5h5v-2h-5v-5h-2v5h-5v2h5v5h2ZM\"+g+\",\"+_+L+\"M\"+m+\",\"+_+I+\"M\"+y+\",\"+w+P)),b||(T.transition().style(\"fill\",d>.2?\"rgba(0,0,0,0.4)\":\"rgba(255,255,255,0.3)\").duration(200),k.transition().style(\"opacity\",1).duration(200),b=!0),C.emit(\"plotly_relayouting\",R(p))}function V(){O(C),p!==f&&(a.call(\"_guiRelayout\",C,R(p)),z&&C.data&&C._context.showTips&&(o.notifier(l(C,\"Double-click to zoom back out\"),\"long\"),z=!1))}function q(t,e){var r=t/A.xaxis._m,n=e/A.yaxis._m,i=[(p={a:f.a-n,b:f.b+(r+n)/2,c:f.c-(r-n)/2}).a,p.b,p.c].sort(o.sorterAsc),a=i.indexOf(p.a),l=i.indexOf(p.b),c=i.indexOf(p.c);i[0]<0&&(i[1]+i[0]/2<0?(i[2]+=i[0]+i[1],i[0]=i[1]=0):(i[2]+=i[0]/2,i[1]+=i[0]/2,i[0]=0),p={a:i[a],b:i[l],c:i[c]},e=(f.a-p.a)*A.yaxis._m,t=(f.c-p.c-f.b+p.b)*A.xaxis._m);var h=s(A.x0+t,A.y0+e);A.plotContainer.selectAll(\".scatterlayer,.maplayer\").attr(\"transform\",h);var d=s(-t,-e);A.clipDefRelative.select(\"path\").attr(\"transform\",d),A.aaxis.range=[p.a,A.sum-p.b-p.c],A.baxis.range=[A.sum-p.a-p.c,p.b],A.caxis.range=[A.sum-p.a-p.b,p.c],A.drawAxes(!1),A._hasClipOnAxisFalse&&A.plotContainer.select(\".scatterlayer\").selectAll(\".trace\").call(u.hideOutsideRangePoints,A),C.emit(\"plotly_relayouting\",R(p))}function H(){a.call(\"_guiRelayout\",C,R(p))}this.dragOptions={element:S,gd:C,plotinfo:{id:A.id,domain:C._fullLayout[A.id].domain,xaxis:A.xaxis,yaxis:A.yaxis},subplot:A.id,prepFn:function(a,l,u){A.dragOptions.xaxes=[A.xaxis],A.dragOptions.yaxes=[A.yaxis],t=C._fullLayout._invScaleX,e=C._fullLayout._invScaleY;var g=A.dragOptions.dragmode=C._fullLayout.dragmode;y(g)?A.dragOptions.minDrag=1:A.dragOptions.minDrag=void 0,\"zoom\"===g?(A.dragOptions.moveFn=U,A.dragOptions.clickFn=F,A.dragOptions.doneFn=V,function(t,e,a){var l=S.getBoundingClientRect();r=e-l.left,n=a-l.top,C._fullLayout._calcInverseTransform(C);var u=C._fullLayout._invTransform,g=o.apply3DTransform(u)(r,n);r=g[0],n=g[1],f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,h=A.aaxis.range[1]-f.a,d=i(A.graphDiv._fullLayout[A.id].bgcolor).getLuminance(),v=\"M0,\"+A.h+\"L\"+A.w/2+\", 0L\"+A.w+\",\"+A.h+\"Z\",b=!1,T=D.append(\"path\").attr(\"class\",\"zoombox\").attr(\"transform\",s(A.x0,A.y0)).style({fill:d>.2?\"rgba(0,0,0,0)\":\"rgba(255,255,255,0)\",\"stroke-width\":0}).attr(\"d\",v),k=D.append(\"path\").attr(\"class\",\"zoombox-corners\").attr(\"transform\",s(A.x0,A.y0)).style({fill:c.background,stroke:c.defaultLine,\"stroke-width\":1,opacity:0}).attr(\"d\",\"M0,0Z\"),A.clearSelect(C)}(0,l,u)):\"pan\"===g?(A.dragOptions.moveFn=q,A.dragOptions.clickFn=F,A.dragOptions.doneFn=H,f={a:A.aaxis.range[0],b:A.baxis.range[1],c:A.caxis.range[1]},p=f,A.clearSelect(C)):(x(g)||y(g))&&_(a,l,u,A.dragOptions,g)}},S.onmousemove=function(t){m.hover(C,t,A.id),C._fullLayout._lasthover=S,C._fullLayout._hoversubplot=A.id},S.onmouseout=function(t){C._dragging||g.unhover(C,t)},g.init(this.dragOptions)}},{\"../../components/color\":643,\"../../components/dragelement\":662,\"../../components/dragelement/helpers\":661,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../components/titles\":738,\"../../lib\":778,\"../../lib/extend\":768,\"../../registry\":911,\"../cartesian/axes\":828,\"../cartesian/constants\":834,\"../cartesian/select\":847,\"../cartesian/set_convert\":848,\"../plots\":891,d3:169,tinycolor2:576}],911:[function(t,e,r){\"use strict\";var n=t(\"./lib/loggers\"),i=t(\"./lib/noop\"),a=t(\"./lib/push_unique\"),o=t(\"./lib/is_plain_object\"),s=t(\"./lib/dom\").addStyleRule,l=t(\"./lib/extend\"),c=t(\"./plots/attributes\"),u=t(\"./plots/layout_attributes\"),f=l.extendFlat,h=l.extendDeepAll;function p(t){var e=t.name,i=t.categories,a=t.meta;if(r.modules[e])n.log(\"Type \"+e+\" already registered\");else{r.subplotsRegistry[t.basePlotModule.name]||function(t){var e=t.name;if(r.subplotsRegistry[e])return void n.log(\"Plot type \"+e+\" already registered.\");for(var i in v(t),r.subplotsRegistry[e]=t,r.componentsRegistry)b(i,t.name)}(t.basePlotModule);for(var o={},l=0;l<i.length;l++)o[i[l]]=!0,r.allCategories[i[l]]=!0;for(var c in r.modules[e]={_module:t,categories:o},a&&Object.keys(a).length&&(r.modules[e].meta=a),r.allTypes.push(e),r.componentsRegistry)y(c,e);t.layoutAttributes&&f(r.traceLayoutAttributes,t.layoutAttributes);var u=t.basePlotModule,h=u.name;if(\"mapbox\"===h){var p=u.constants.styleRules;for(var d in p)s(\".js-plotly-plot .plotly .mapboxgl-\"+d,p[d])}\"geo\"!==h&&\"mapbox\"!==h||void 0===typeof window||void 0!==window.PlotlyGeoAssets||(window.PlotlyGeoAssets={topojson:{}})}}function d(t){if(\"string\"!=typeof t.name)throw new Error(\"Component module *name* must be a string.\");var e=t.name;for(var n in r.componentsRegistry[e]=t,t.layoutAttributes&&(t.layoutAttributes._isLinkedToArray&&a(r.layoutArrayContainers,e),v(t)),r.modules)y(e,n);for(var i in r.subplotsRegistry)b(e,i);for(var o in r.transformsRegistry)x(e,o);t.schema&&t.schema.layout&&h(u,t.schema.layout)}function g(t){if(\"string\"!=typeof t.name)throw new Error(\"Transform module *name* must be a string.\");var e=\"Transform module \"+t.name,i=\"function\"==typeof t.transform,a=\"function\"==typeof t.calcTransform;if(!i&&!a)throw new Error(e+\" is missing a *transform* or *calcTransform* method.\");for(var s in i&&a&&n.log([e+\" has both a *transform* and *calcTransform* methods.\",\"Please note that all *transform* methods are executed\",\"before all *calcTransform* methods.\"].join(\" \")),o(t.attributes)||n.log(e+\" registered without an *attributes* object.\"),\"function\"!=typeof t.supplyDefaults&&n.log(e+\" registered without a *supplyDefaults* method.\"),r.transformsRegistry[t.name]=t,r.componentsRegistry)x(s,t.name)}function m(t){var e=t.name,n=e.split(\"-\")[0],i=t.dictionary,a=t.format,o=i&&Object.keys(i).length,s=a&&Object.keys(a).length,l=r.localeRegistry,c=l[e];if(c||(l[e]=c={}),n!==e){var u=l[n];u||(l[n]=u={}),o&&u.dictionary===c.dictionary&&(u.dictionary=i),s&&u.format===c.format&&(u.format=a)}o&&(c.dictionary=i),s&&(c.format=a)}function v(t){if(t.layoutAttributes){var e=t.layoutAttributes._arrayAttrRegexps;if(e)for(var n=0;n<e.length;n++)a(r.layoutArrayRegexes,e[n])}}function y(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.traces){var i=n.traces[e];i&&h(r.modules[e]._module.attributes,i)}}function x(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.transforms){var i=n.transforms[e];i&&h(r.transformsRegistry[e].attributes,i)}}function b(t,e){var n=r.componentsRegistry[t].schema;if(n&&n.subplots){var i=r.subplotsRegistry[e],a=i.layoutAttributes,o=\"subplot\"===i.attr?i.name:i.attr;Array.isArray(o)&&(o=o[0]);var s=n.subplots[o];a&&s&&h(a,s)}}function _(t){return\"object\"==typeof t&&(t=t.type),t}r.modules={},r.allCategories={},r.allTypes=[],r.subplotsRegistry={},r.transformsRegistry={},r.componentsRegistry={},r.layoutArrayContainers=[],r.layoutArrayRegexes=[],r.traceLayoutAttributes={},r.localeRegistry={},r.apiMethodRegistry={},r.collectableSubplotTypes=null,r.register=function(t){if(r.collectableSubplotTypes=null,!t)throw new Error(\"No argument passed to Plotly.register.\");t&&!Array.isArray(t)&&(t=[t]);for(var e=0;e<t.length;e++){var n=t[e];if(!n)throw new Error(\"Invalid module was attempted to be registered!\");switch(n.moduleType){case\"trace\":p(n);break;case\"transform\":g(n);break;case\"component\":d(n);break;case\"locale\":m(n);break;case\"apiMethod\":var i=n.name;r.apiMethodRegistry[i]=n.fn;break;default:throw new Error(\"Invalid module was attempted to be registered!\")}}},r.getModule=function(t){var e=r.modules[_(t)];return!!e&&e._module},r.traceIs=function(t,e){if(\"various\"===(t=_(t)))return!1;var i=r.modules[t];return i||(t&&\"area\"!==t&&n.log(\"Unrecognized trace type \"+t+\".\"),i=r.modules[c.type.dflt]),!!i.categories[e]},r.getTransformIndices=function(t,e){for(var r=[],n=t.transforms||[],i=0;i<n.length;i++)n[i].type===e&&r.push(i);return r},r.hasTransform=function(t,e){for(var r=t.transforms||[],n=0;n<r.length;n++)if(r[n].type===e)return!0;return!1},r.getComponentMethod=function(t,e){var n=r.componentsRegistry[t];return n&&n[e]||i},r.call=function(){var t=arguments[0],e=[].slice.call(arguments,1);return r.apiMethodRegistry[t].apply(null,e)}},{\"./lib/dom\":766,\"./lib/extend\":768,\"./lib/is_plain_object\":779,\"./lib/loggers\":782,\"./lib/noop\":787,\"./lib/push_unique\":793,\"./plots/attributes\":824,\"./plots/layout_attributes\":882}],912:[function(t,e,r){\"use strict\";var n=t(\"../registry\"),i=t(\"../lib\"),a=i.extendFlat,o=i.extendDeep;function s(t){var e;switch(t){case\"themes__thumb\":e={autosize:!0,width:150,height:150,title:{text:\"\"},showlegend:!1,margin:{l:5,r:5,t:5,b:5,pad:0},annotations:[]};break;case\"thumbnail\":e={title:{text:\"\"},hidesources:!0,showlegend:!1,borderwidth:0,bordercolor:\"\",margin:{l:1,r:1,t:1,b:1,pad:0},annotations:[]};break;default:e={}}return e}e.exports=function(t,e){var r;t.framework&&t.framework.isPolar&&(t=t.framework.getConfig());var i,l=t.data,c=t.layout,u=o([],l),f=o({},c,s(e.tileClass)),h=t._context||{};if(e.width&&(f.width=e.width),e.height&&(f.height=e.height),\"thumbnail\"===e.tileClass||\"themes__thumb\"===e.tileClass){f.annotations=[];var p=Object.keys(f);for(r=0;r<p.length;r++)i=p[r],[\"xaxis\",\"yaxis\",\"zaxis\"].indexOf(i.slice(0,5))>-1&&(f[p[r]].title={text:\"\"});for(r=0;r<u.length;r++){var d=u[r];d.showscale=!1,d.marker&&(d.marker.showscale=!1),n.traceIs(d,\"pie-like\")&&(d.textposition=\"none\")}}if(Array.isArray(e.annotations))for(r=0;r<e.annotations.length;r++)f.annotations.push(e.annotations[r]);var g=Object.keys(f).filter((function(t){return t.match(/^scene\\d*$/)}));if(g.length){var m={};for(\"thumbnail\"===e.tileClass&&(m={title:{text:\"\"},showaxeslabels:!1,showticklabels:!1,linetickenable:!1}),r=0;r<g.length;r++){var v=f[g[r]];v.xaxis||(v.xaxis={}),v.yaxis||(v.yaxis={}),v.zaxis||(v.zaxis={}),a(v.xaxis,m),a(v.yaxis,m),a(v.zaxis,m),v._scene=null}}var y=document.createElement(\"div\");e.tileClass&&(y.className=e.tileClass);var x={gd:y,td:y,layout:f,data:u,config:{staticPlot:void 0===e.staticPlot||e.staticPlot,plotGlPixelRatio:void 0===e.plotGlPixelRatio?2:e.plotGlPixelRatio,displaylogo:e.displaylogo||!1,showLink:e.showLink||!1,showTips:e.showTips||!1,mapboxAccessToken:h.mapboxAccessToken}};return\"transparent\"!==e.setBackground&&(x.config.setBackground=e.setBackground||\"opaque\"),x.gd.defaultLayout=s(e.tileClass),x}},{\"../lib\":778,\"../registry\":911}],913:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/to_image\"),a=t(\"./filesaver\"),o=t(\"./helpers\");e.exports=function(t,e){var r;return n.isPlainObject(t)||(r=n.getGraphDiv(t)),(e=e||{}).format=e.format||\"png\",e.width=e.width||null,e.height=e.height||null,e.imageDataOnly=!0,new Promise((function(s,l){r&&r._snapshotInProgress&&l(new Error(\"Snapshotting already in progress.\")),n.isIE()&&\"svg\"!==e.format&&l(new Error(o.MSG_IE_BAD_FORMAT)),r&&(r._snapshotInProgress=!0);var c=i(t,e),u=e.filename||t.fn||\"newplot\";u+=\".\"+e.format.replace(\"-\",\".\"),c.then((function(t){return r&&(r._snapshotInProgress=!1),a(t,u,e.format)})).then((function(t){s(t)})).catch((function(t){r&&(r._snapshotInProgress=!1),l(t)}))}))}},{\"../lib\":778,\"../plot_api/to_image\":820,\"./filesaver\":914,\"./helpers\":915}],914:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"./helpers\");e.exports=function(t,e,r){var a=document.createElement(\"a\"),o=\"download\"in a;return new Promise((function(s,l){var c,u;if(n.isIE9orBelow()&&l(new Error(\"IE < 10 unsupported\")),n.isSafari()){var f=\"svg\"===r?\",\":\";base64,\";return i.octetStream(f+encodeURIComponent(t)),s(e)}return n.isIE()?(c=i.createBlob(t,\"svg\"),window.navigator.msSaveBlob(c,e),c=null,s(e)):o?(c=i.createBlob(t,r),u=i.createObjectURL(c),a.href=u,a.download=e,document.body.appendChild(a),a.click(),document.body.removeChild(a),i.revokeObjectURL(u),c=null,s(e)):void l(new Error(\"download error\"))}))}},{\"../lib\":778,\"./helpers\":915}],915:[function(t,e,r){\"use strict\";var n=t(\"../registry\");r.getDelay=function(t){return t._has&&(t._has(\"gl3d\")||t._has(\"gl2d\")||t._has(\"mapbox\"))?500:0},r.getRedrawFunc=function(t){return function(){var e=t._fullLayout||{};!(e._has&&e._has(\"polar\"))&&t.data&&t.data[0]&&t.data[0].r||n.getComponentMethod(\"colorbar\",\"draw\")(t)}},r.encodeSVG=function(t){return\"data:image/svg+xml,\"+encodeURIComponent(t)},r.encodeJSON=function(t){return\"data:application/json,\"+encodeURIComponent(t)};var i=window.URL||window.webkitURL;r.createObjectURL=function(t){return i.createObjectURL(t)},r.revokeObjectURL=function(t){return i.revokeObjectURL(t)},r.createBlob=function(t,e){if(\"svg\"===e)return new window.Blob([t],{type:\"image/svg+xml;charset=utf-8\"});if(\"full-json\"===e)return new window.Blob([t],{type:\"application/json;charset=utf-8\"});var r=function(t){for(var e=t.length,r=new ArrayBuffer(e),n=new Uint8Array(r),i=0;i<e;i++)n[i]=t.charCodeAt(i);return r}(window.atob(t));return new window.Blob([r],{type:\"image/\"+e})},r.octetStream=function(t){document.location.href=\"data:application/octet-stream\"+t},r.IMAGE_URL_PREFIX=/^data:image\\/\\w+;base64,/,r.MSG_IE_BAD_FORMAT=\"Sorry IE does not support downloading from canvas. Try {format:'svg'} instead.\"},{\"../registry\":911}],916:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i={getDelay:n.getDelay,getRedrawFunc:n.getRedrawFunc,clone:t(\"./cloneplot\"),toSVG:t(\"./tosvg\"),svgToImg:t(\"./svgtoimg\"),toImage:t(\"./toimage\"),downloadImage:t(\"./download\")};e.exports=i},{\"./cloneplot\":912,\"./download\":913,\"./helpers\":915,\"./svgtoimg\":917,\"./toimage\":918,\"./tosvg\":919}],917:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"events\").EventEmitter,a=t(\"./helpers\");e.exports=function(t){var e=t.emitter||new i,r=new Promise((function(i,o){var s=window.Image,l=t.svg,c=t.format||\"png\";if(n.isIE()&&\"svg\"!==c){var u=new Error(a.MSG_IE_BAD_FORMAT);return o(u),t.promise?r:e.emit(\"error\",u)}var f,h,p=t.canvas,d=t.scale||1,g=t.width||300,m=t.height||150,v=d*g,y=d*m,x=p.getContext(\"2d\"),b=new s;\"svg\"===c||n.isIE9orBelow()||n.isSafari()?h=a.encodeSVG(l):(f=a.createBlob(l,\"svg\"),h=a.createObjectURL(f)),p.width=v,p.height=y,b.onload=function(){var r;switch(f=null,a.revokeObjectURL(h),\"svg\"!==c&&x.drawImage(b,0,0,v,y),c){case\"jpeg\":r=p.toDataURL(\"image/jpeg\");break;case\"png\":r=p.toDataURL(\"image/png\");break;case\"webp\":r=p.toDataURL(\"image/webp\");break;case\"svg\":r=h;break;default:var n=\"Image format is not jpeg, png, svg or webp.\";if(o(new Error(n)),!t.promise)return e.emit(\"error\",n)}i(r),t.promise||e.emit(\"success\",r)},b.onerror=function(r){if(f=null,a.revokeObjectURL(h),o(r),!t.promise)return e.emit(\"error\",r)},b.src=h}));return t.promise?r:e}},{\"../lib\":778,\"./helpers\":915,events:110}],918:[function(t,e,r){\"use strict\";var n=t(\"events\").EventEmitter,i=t(\"../registry\"),a=t(\"../lib\"),o=t(\"./helpers\"),s=t(\"./cloneplot\"),l=t(\"./tosvg\"),c=t(\"./svgtoimg\");e.exports=function(t,e){var r=new n,u=s(t,{format:\"png\"}),f=u.gd;f.style.position=\"absolute\",f.style.left=\"-5000px\",document.body.appendChild(f);var h=o.getRedrawFunc(f);return i.call(\"plot\",f,u.data,u.layout,u.config).then(h).then((function(){var t=o.getDelay(f._fullLayout);setTimeout((function(){var t=l(f),n=document.createElement(\"canvas\");n.id=a.randstr(),(r=c({format:e.format,width:f._fullLayout.width,height:f._fullLayout.height,canvas:n,emitter:r,svg:t})).clean=function(){f&&document.body.removeChild(f)}}),t)})).catch((function(t){r.emit(\"error\",t)})),r}},{\"../lib\":778,\"../registry\":911,\"./cloneplot\":912,\"./helpers\":915,\"./svgtoimg\":917,\"./tosvg\":919,events:110}],919:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../lib\"),a=t(\"../components/drawing\"),o=t(\"../components/color\"),s=t(\"../constants/xmlns_namespaces\"),l=/\"/g,c=new RegExp('(\"TOBESTRIPPED)|(TOBESTRIPPED\")',\"g\");e.exports=function(t,e,r){var u,f=t._fullLayout,h=f._paper,p=f._toppaper,d=f.width,g=f.height;h.insert(\"rect\",\":first-child\").call(a.setRect,0,0,d,g).call(o.fill,f.paper_bgcolor);var m=f._basePlotModules||[];for(u=0;u<m.length;u++){var v=m[u];v.toSVG&&v.toSVG(t)}if(p){var y=p.node().childNodes,x=Array.prototype.slice.call(y);for(u=0;u<x.length;u++){var b=x[u];b.childNodes.length&&h.node().appendChild(b)}}if(f._draggers&&f._draggers.remove(),h.node().style.background=\"\",h.selectAll(\"text\").attr({\"data-unformatted\":null,\"data-math\":null}).each((function(){var t=n.select(this);if(\"hidden\"!==this.style.visibility&&\"none\"!==this.style.display){t.style({visibility:null,display:null});var e=this.style.fontFamily;e&&-1!==e.indexOf('\"')&&t.style(\"font-family\",e.replace(l,\"TOBESTRIPPED\"))}else t.remove()})),f._gradientUrlQueryParts){var _=[];for(var w in f._gradientUrlQueryParts)_.push(w);_.length&&h.selectAll(_.join(\",\")).each((function(){var t=n.select(this),e=this.style.fill;e&&-1!==e.indexOf(\"url(\")&&t.style(\"fill\",e.replace(l,\"TOBESTRIPPED\"));var r=this.style.stroke;r&&-1!==r.indexOf(\"url(\")&&t.style(\"stroke\",r.replace(l,\"TOBESTRIPPED\"))}))}\"pdf\"!==e&&\"eps\"!==e||h.selectAll(\"#MathJax_SVG_glyphs path\").attr(\"stroke-width\",0),h.node().setAttributeNS(s.xmlns,\"xmlns\",s.svg),h.node().setAttributeNS(s.xmlns,\"xmlns:xlink\",s.xlink),\"svg\"===e&&r&&(h.attr(\"width\",r*d),h.attr(\"height\",r*g),h.attr(\"viewBox\",\"0 0 \"+d+\" \"+g));var T=(new window.XMLSerializer).serializeToString(h.node());return T=function(t){var e=n.select(\"body\").append(\"div\").style({display:\"none\"}).html(\"\"),r=t.replace(/(&[^;]*;)/gi,(function(t){return\"&lt;\"===t?\"&#60;\":\"&rt;\"===t?\"&#62;\":-1!==t.indexOf(\"<\")||-1!==t.indexOf(\">\")?\"\":e.html(t).text()}));return e.remove(),r}(T),T=(T=T.replace(/&(?!\\w+;|\\#[0-9]+;| \\#x[0-9A-F]+;)/g,\"&amp;\")).replace(c,\"'\"),i.isIE()&&(T=(T=(T=T.replace(/\"/gi,\"'\")).replace(/(\\('#)([^']*)('\\))/gi,'(\"#$2\")')).replace(/(\\\\')/gi,'\"')),T}},{\"../components/color\":643,\"../components/drawing\":665,\"../constants/xmlns_namespaces\":754,\"../lib\":778,d3:169}],920:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\",!0),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],921:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/font_attributes\"),l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=s({editType:\"calc\",arrayOk:!0,colorEditType:\"style\"}),f=c({},n.marker.line.width,{dflt:0}),h=c({width:f,editType:\"calc\"},o(\"marker.line\")),p=c({line:h,editType:\"calc\"},o(\"marker\"),{opacity:{valType:\"number\",arrayOk:!0,dflt:1,min:0,max:1,editType:\"style\"}});e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,texttemplate:a({editType:\"plot\"},{keys:l.eventDataKeys}),hovertext:n.hovertext,hovertemplate:i({},{keys:l.eventDataKeys}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"none\",arrayOk:!0,editType:\"calc\"},insidetextanchor:{valType:\"enumerated\",values:[\"end\",\"middle\",\"start\"],dflt:\"end\",editType:\"plot\"},textangle:{valType:\"angle\",dflt:\"auto\",editType:\"plot\"},textfont:c({},u,{}),insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),constraintext:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"both\",\"none\"],dflt:\"both\",editType:\"calc\"},cliponaxis:c({},n.cliponaxis,{}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},base:{valType:\"any\",dflt:null,arrayOk:!0,editType:\"calc\"},offset:{valType:\"number\",dflt:null,arrayOk:!0,editType:\"calc\"},width:{valType:\"number\",dflt:null,min:0,arrayOk:!0,editType:\"calc\"},marker:p,offsetgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},alignmentgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},selected:{marker:{opacity:n.selected.marker.opacity,color:n.selected.marker.color,editType:\"style\"},textfont:n.selected.textfont,editType:\"style\"},unselected:{marker:{opacity:n.unselected.marker.opacity,color:n.unselected.marker.color,editType:\"style\"},textfont:n.unselected.textfont,editType:\"style\"},r:n.r,t:n.t,_deprecated:{bardir:{valType:\"enumerated\",editType:\"calc\",values:[\"v\",\"h\"]}}}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"./constants\":923}],922:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../components/colorscale/helpers\").hasColorscale,o=t(\"../../components/colorscale/calc\"),s=t(\"./arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\");e.exports=function(t,e){var r,c,u,f,h=n.getFromId(t,e.xaxis||\"x\"),p=n.getFromId(t,e.yaxis||\"y\"),d={msUTC:!(!e.base&&0!==e.base)};\"h\"===e.orientation?(r=h.makeCalcdata(e,\"x\",d),u=p.makeCalcdata(e,\"y\"),c=i(e,p,\"y\",u),f=!!e.yperiodalignment):(r=p.makeCalcdata(e,\"y\",d),u=h.makeCalcdata(e,\"x\"),c=i(e,h,\"x\",u),f=!!e.xperiodalignment);for(var g=Math.min(c.length,r.length),m=new Array(g),v=0;v<g;v++)m[v]={p:c[v],s:r[v]},f&&(m[v].orig_p=u[v]),e.ids&&(m[v].id=String(e.ids[v]));return a(e,\"marker\")&&o(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),a(e,\"marker.line\")&&o(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),s(m,e),l(m,e),m}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":920}],923:[function(t,e,r){\"use strict\";e.exports={TEXTPAD:3,eventDataKeys:[\"value\",\"label\"]}},{}],924:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../registry\"),s=t(\"../../plots/cartesian/axes\"),l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=t(\"./sieve.js\");function u(t,e,r,o,u){if(o.length){var b,_,w,T;switch(function(t,e){var r,a;for(r=0;r<e.length;r++){var o,s=e[r],l=s[0].trace,c=\"funnel\"===l.type?l._base:l.base,u=\"h\"===l.orientation?l.xcalendar:l.ycalendar,f=\"category\"===t.type||\"multicategory\"===t.type?function(){return null}:t.d2c;if(i(c)){for(a=0;a<Math.min(c.length,s.length);a++)o=f(c[a],0,u),n(o)?(s[a].b=+o,s[a].hasB=1):s[a].b=0;for(;a<s.length;a++)s[a].b=0}else{o=f(c,0,u);var h=n(o);for(o=h?o:0,a=0;a<s.length;a++)s[a].b=o,h&&(s[a].hasB=1)}}}(r,o),u.mode){case\"overlay\":f(e,r,o,u);break;case\"group\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.offset?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:!1,overlapNoMerge:!i.norm});(function(t,e,r,n){for(var i=t._fullLayout,a=r.positions,o=r.distinctPositions,s=r.minDiff,c=r.traces,u=c.length,f=a.length!==o.length,h=s*(1-n.gap),m=l(i,e._id)+c[0][0].trace.orientation,v=i._alignmentOpts[m]||{},y=0;y<u;y++){var x,b,_=c[y],w=_[0].trace,T=v[w.alignmentgroup]||{},k=Object.keys(T.offsetGroups||{}).length,M=(x=k?h/k:f?h/u:h)*(1-(n.groupgap||0));b=k?((2*w._offsetIndex+1-k)*x-M)/2:f?((2*y+1-u)*x-M)/2:-M/2;var A=_[0].t;A.barwidth=M,A.poffset=b,A.bargroupwidth=h,A.bardelta=s}r.binWidth=c[0][0].t.barwidth/100,p(r),d(e,r),g(e,r,f)})(t,e,o,i),function(t){for(var e=t.traces,r=0;r<e.length;r++){var n=e[r];if(void 0===n[0].trace.base)for(var i=new c([n],{sepNegVal:!0,overlapNoMerge:!0}),o=0;o<n.length;o++){var s=n[o];if(s.p!==a){var l=i.put(s.p,s.b+s.s);l&&(s.b=l)}}}}(o),i.norm?(v(o),y(r,o,i)):m(r,o)}(t,e,r,_,u),b.length&&f(e,r,b,u);break;case\"stack\":case\"relative\":for(b=[],_=[],w=0;w<o.length;w++)void 0===(T=o[w])[0].trace.base?_.push(T):b.push(T);_.length&&function(t,e,r,n,i){var o=new c(n,{sepNegVal:\"relative\"===i.mode,overlapNoMerge:!(i.norm||\"stack\"===i.mode||\"relative\"===i.mode)});h(e,o,i),function(t,e,r){var n,i,o,l,c,u,f=x(t),h=e.traces;for(l=0;l<h.length;l++)if(n=h[l],\"funnel\"===(i=n[0].trace).type)for(c=0;c<n.length;c++)(u=n[c]).s!==a&&e.put(u.p,-.5*u.s);for(l=0;l<h.length;l++){n=h[l],i=n[0].trace,o=\"funnel\"===i.type;var p=[];for(c=0;c<n.length;c++)if((u=n[c]).s!==a){var d;d=o?u.s:u.s+u.b;var g=e.put(u.p,d),m=g+d;u.b=g,u[f]=m,r.norm||(p.push(m),u.hasB&&p.push(g))}r.norm||(i._extremes[t._id]=s.findExtremes(t,p,{tozero:!0,padded:!0}))}}(r,o,i);for(var l=0;l<n.length;l++)for(var u=n[l],f=0;f<u.length;f++){var p=u[f];if(p.s!==a)p.b+p.s===o.get(p.p,p.s)&&(p._outmost=!0)}i.norm&&y(r,o,i)}(0,e,r,_,u),b.length&&f(e,r,b,u)}!function(t,e){var r,i,a,o=x(e),s={},l=1/0,c=-1/0;for(r=0;r<t.length;r++)for(a=t[r],i=0;i<a.length;i++){var u=a[i].p;n(u)&&(l=Math.min(l,u),c=Math.max(c,u))}var f=1e4/(c-l),h=s.round=function(t){return String(Math.round(f*(t-l)))};for(r=0;r<t.length;r++){(a=t[r])[0].t.extents=s;var p=a[0].t.poffset,d=Array.isArray(p);for(i=0;i<a.length;i++){var g=a[i],m=g[o]-g.w/2;if(n(m)){var v=g[o]+g.w/2,y=h(g.p);s[y]?s[y]=[Math.min(m,s[y][0]),Math.max(v,s[y][1])]:s[y]=[m,v]}g.p0=g.p+(d?p[i]:p),g.p1=g.p0+g.w,g.s0=g.b,g.s1=g.s0+g.s}}}(o,e)}}function f(t,e,r,n){for(var i=0;i<r.length;i++){var a=r[i],o=new c([a],{unitMinDiff:n.xCat||n.yCat,sepNegVal:!1,overlapNoMerge:!n.norm});h(t,o,n),n.norm?(v(o),y(e,o,n)):m(e,o)}}function h(t,e,r){for(var n=e.minDiff,i=e.traces,a=n*(1-r.gap),o=a*(1-(r.groupgap||0)),s=-o/2,l=0;l<i.length;l++){var c=i[l][0].t;c.barwidth=o,c.poffset=s,c.bargroupwidth=a,c.bardelta=n}e.binWidth=i[0][0].t.barwidth/100,p(e),d(t,e),g(t,e)}function p(t){var e,r,a=t.traces;for(e=0;e<a.length;e++){var o,s=a[e],l=s[0],c=l.trace,u=l.t,f=c._offset||c.offset,h=u.poffset;if(i(f)){for(o=Array.prototype.slice.call(f,0,s.length),r=0;r<o.length;r++)n(o[r])||(o[r]=h);for(r=o.length;r<s.length;r++)o.push(h);u.poffset=o}else void 0!==f&&(u.poffset=f);var p=c._width||c.width,d=u.barwidth;if(i(p)){var g=Array.prototype.slice.call(p,0,s.length);for(r=0;r<g.length;r++)n(g[r])||(g[r]=d);for(r=g.length;r<s.length;r++)g.push(d);if(u.barwidth=g,void 0===f){for(o=[],r=0;r<s.length;r++)o.push(h+(d-g[r])/2);u.poffset=o}}else void 0!==p&&(u.barwidth=p,void 0===f&&(u.poffset=h+(d-p)/2))}}function d(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++)for(var a=r[i],o=a[0].t,s=o.poffset,l=Array.isArray(s),c=o.barwidth,u=Array.isArray(c),f=0;f<a.length;f++){var h=a[f],p=h.w=u?c[f]:c;h[n]=h.p+(l?s[f]:s)+p/2}}function g(t,e,r){var n=e.traces,i=e.minDiff/2;s.minDtick(t,e.minDiff,e.distinctPositions[0],r);for(var a=0;a<n.length;a++){var o,l,c,u,f=n[a],h=f[0],p=h.trace,d=[];for(u=0;u<f.length;u++)l=(o=f[u]).p-i,c=o.p+i,d.push(l,c);if(p.width||p.offset){var g=h.t,m=g.poffset,v=g.barwidth,y=Array.isArray(m),x=Array.isArray(v);for(u=0;u<f.length;u++){o=f[u];var b=y?m[u]:m,_=x?v[u]:v;c=(l=o.p+b)+_,d.push(l,c)}}p._extremes[t._id]=s.findExtremes(t,d,{padded:!1})}}function m(t,e){for(var r=e.traces,n=x(t),i=0;i<r.length;i++){for(var a=r[i],o=a[0].trace,l=[],c=!1,u=0;u<a.length;u++){var f=a[u],h=f.b,p=h+f.s;f[n]=p,l.push(p),f.hasB&&l.push(h),f.hasB&&f.b||(c=!0)}o._extremes[t._id]=s.findExtremes(t,l,{tozero:c,padded:!0})}}function v(t){for(var e=t.traces,r=0;r<e.length;r++)for(var n=e[r],i=0;i<n.length;i++){var o=n[i];o.s!==a&&t.put(o.p,o.b+o.s)}}function y(t,e,r){var i=e.traces,o=x(t),l=\"fraction\"===r.norm?1:100,c=l/1e9,u=t.l2c(t.c2l(0)),f=\"stack\"===r.mode?l:u;function h(e){return n(t.c2l(e))&&(e<u-c||e>f+c||!n(u))}for(var p=0;p<i.length;p++){for(var d=i[p],g=d[0].trace,m=[],v=!1,y=!1,b=0;b<d.length;b++){var _=d[b];if(_.s!==a){var w=Math.abs(l/e.get(_.p,_.s));_.b*=w,_.s*=w;var T=_.b,k=T+_.s;_[o]=k,m.push(k),y=y||h(k),_.hasB&&(m.push(T),y=y||h(T)),_.hasB&&_.b||(v=!0)}}g._extremes[t._id]=s.findExtremes(t,m,{tozero:v,padded:y})}}function x(t){return t._id.charAt(0)}e.exports={crossTraceCalc:function(t,e){for(var r=e.xaxis,n=e.yaxis,i=t._fullLayout,a=t._fullData,s=t.calcdata,l=[],c=[],f=0;f<a.length;f++){var h=a[f];if(!0===h.visible&&o.traceIs(h,\"bar\")&&h.xaxis===r._id&&h.yaxis===n._id&&(\"h\"===h.orientation?l.push(s[f]):c.push(s[f]),h._computePh))for(var p=t.calcdata[f],d=0;d<p.length;d++)\"function\"==typeof p[d].ph0&&(p[d].ph0=p[d].ph0()),\"function\"==typeof p[d].ph1&&(p[d].ph1=p[d].ph1())}var g={xCat:\"category\"===r.type||\"multicategory\"===r.type,yCat:\"category\"===n.type||\"multicategory\"===n.type,mode:i.barmode,norm:i.barnorm,gap:i.bargap,groupgap:i.bargroupgap};u(t,r,n,c,g),u(t,n,r,l,g)},setGroupPositions:u}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"./sieve.js\":934,\"fast-isnumeric\":241}],925:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../registry\"),o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./style_defaults\"),c=t(\"../../plots/cartesian/constraints\").getAxisGroup,u=t(\"./attributes\"),f=n.coerceFont;function h(t,e,r,n){var i=e.orientation,a=e[{v:\"x\",h:\"y\"}[i]+\"axis\"],o=c(r,a)+i,s=r._alignmentOpts||{},l=n(\"alignmentgroup\"),u=s[o];u||(u=s[o]={});var f=u[l];f?f.traces.push(e):f=u[l]={traces:[e],alignmentIndex:Object.keys(u).length,offsetGroups:{}};var h=n(\"offsetgroup\"),p=f.offsetGroups,d=p[h];h&&(d||(d=p[h]={offsetIndex:Object.keys(p).length}),e._offsetIndex=d.offsetIndex)}function p(t,e,r,i,a,o){var s=!(!1===(o=o||{}).moduleHasSelected),l=!(!1===o.moduleHasUnselected),c=!(!1===o.moduleHasConstrain),u=!(!1===o.moduleHasCliponaxis),h=!(!1===o.moduleHasTextangle),p=!(!1===o.moduleHasInsideanchor),d=!!o.hasPathbar,g=Array.isArray(a)||\"auto\"===a,m=g||\"inside\"===a,v=g||\"outside\"===a;if(m||v){var y=f(i,\"textfont\",r.font),x=n.extendFlat({},y),b=!(t.textfont&&t.textfont.color);if(b&&delete x.color,f(i,\"insidetextfont\",x),d){var _=n.extendFlat({},y);b&&delete _.color,f(i,\"pathbar.textfont\",_)}v&&f(i,\"outsidetextfont\",y),s&&i(\"selected.textfont.color\"),l&&i(\"unselected.textfont.color\"),c&&i(\"constraintext\"),u&&i(\"cliponaxis\"),h&&i(\"textangle\"),i(\"texttemplate\")}m&&p&&i(\"insidetextanchor\")}e.exports={supplyDefaults:function(t,e,r,c){function f(r,i){return n.coerce(t,e,u,r,i)}if(o(t,e,c,f)){s(t,e,c,f),f(\"orientation\",e.x&&!e.y?\"h\":\"v\"),f(\"base\"),f(\"offset\"),f(\"width\"),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\");var h=f(\"textposition\");p(t,e,c,f,h,{moduleHasSelected:!0,moduleHasUnselected:!0,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),l(t,e,f,r,c);var d=(e.marker.line||{}).color,g=a.getComponentMethod(\"errorbars\",\"supplyDefaults\");g(t,e,d||i.defaultLine,{axis:\"y\"}),g(t,e,d||i.defaultLine,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1},crossTraceDefaults:function(t,e){var r;function i(t){return n.coerce(r._input,r,u,t)}if(\"group\"===e.barmode)for(var a=0;a<t.length;a++)\"bar\"===(r=t[a]).type&&(r._input,h(0,r,e,i))},handleGroupingDefaults:h,handleText:p}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":921,\"./style_defaults\":936}],926:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),\"h\"===r.orientation?(t.label=t.y,t.value=t.x):(t.label=t.x,t.value=t.y),t}},{}],927:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../lib\").isArrayOrTypedArray;r.coerceString=function(t,e,r){if(\"string\"==typeof e){if(e||!t.noBlank)return e}else if((\"number\"==typeof e||!0===e)&&!t.strict)return String(e);return void 0!==r?r:t.dflt},r.coerceNumber=function(t,e,r){if(n(e)){e=+e;var i=t.min,a=t.max;if(!(void 0!==i&&e<i||void 0!==a&&e>a))return e}return void 0!==r?r:t.dflt},r.coerceColor=function(t,e,r){return i(e).isValid()?e:void 0!==r?r:t.dflt},r.coerceEnumerated=function(t,e,r){return t.coerceNumber&&(e=+e),-1!==t.values.indexOf(e)?e:void 0!==r?r:t.dflt},r.getValue=function(t,e){var r;return Array.isArray(t)?e<t.length&&(r=t[e]):r=t,r},r.getLineWidth=function(t,e){return 0<e.mlw?e.mlw:a(t.marker.line.width)?0:t.marker.line.width}},{\"../../lib\":778,\"fast-isnumeric\":241,tinycolor2:576}],928:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../../lib\").fillText,s=t(\"./helpers\").getLineWidth,l=t(\"../../plots/cartesian/axes\").hoverLabelText,c=t(\"../../constants/numerical\").BADNUM;function u(t,e,r,i){var a,s,u,f,h,p,d,g=t.cd,m=g[0].trace,v=g[0].t,y=\"closest\"===i,x=\"waterfall\"===m.type,b=t.maxHoverDistance;function _(t){return t[u]-t.w/2}function w(t){return t[u]+t.w/2}var T=y?_:function(t){return Math.min(_(t),t.p-v.bardelta/2)},k=y?w:function(t){return Math.max(w(t),t.p+v.bardelta/2)};function M(t,e){return n.inbox(t-a,e-a,b+Math.min(1,Math.abs(e-t)/d)-1)}function A(t){return M(T(t),k(t))}function S(t){var e=s,r=t.b,i=t[f];if(x){var a=Math.abs(t.rawS)||0;e>0?i+=a:e<0&&(i-=a)}return n.inbox(r-e,i-e,b+(i-e)/(i-r)-1)}\"h\"===m.orientation?(a=r,s=e,u=\"y\",f=\"x\",h=S,p=A):(a=e,s=r,u=\"x\",f=\"y\",p=S,h=A);var E=t[u+\"a\"],C=t[f+\"a\"];d=Math.abs(E.r2c(E.range[1])-E.r2c(E.range[0]));var L=n.getDistanceFunction(i,h,p,(function(t){return(h(t)+p(t))/2}));if(n.getClosest(g,L,t),!1!==t.index&&g[t.index].p!==c){y||(T=function(t){return Math.min(_(t),t.p-v.bargroupwidth/2)},k=function(t){return Math.max(w(t),t.p+v.bargroupwidth/2)});var I=g[t.index],P=m.base?I.b+I.s:I.s;t[f+\"0\"]=t[f+\"1\"]=C.c2p(I[f],!0),t[f+\"LabelVal\"]=P;var z=v.extents[v.extents.round(I.p)];t[u+\"0\"]=E.c2p(y?T(I):z[0],!0),t[u+\"1\"]=E.c2p(y?k(I):z[1],!0);var O=void 0!==I.orig_p;return t[u+\"LabelVal\"]=O?I.orig_p:I.p,t.labelLabel=l(E,t[u+\"LabelVal\"]),t.valueLabel=l(C,t[f+\"LabelVal\"]),t.baseLabel=l(C,I.b),t.spikeDistance=(S(I)+function(t){return M(_(t),w(t))}(I))/2-b,t[u+\"Spike\"]=E.c2p(I.p,!0),o(I,m,t),t.hovertemplate=m.hovertemplate,t}}function f(t,e){var r=e.mcc||t.marker.color,n=e.mlcc||t.marker.line.color,i=s(t,e);return a.opacity(r)?r:a.opacity(n)&&i?n:void 0}e.exports={hoverPoints:function(t,e,r,n){var a=u(t,e,r,n);if(a){var o=a.cd,s=o[0].trace,l=o[a.index];return a.color=f(s,l),i.getComponentMethod(\"errorbars\",\"hoverInfo\")(l,s,a),[a]}},hoverOnBars:u,getTraceColor:f}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./helpers\":927}],929:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,colorbar:t(\"../scatter/marker_colorbar\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"bar\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"oriented\",\"errorBarsOK\",\"showLegend\",\"zoomScale\"],animatable:!0,meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"./arrays_to_calcdata\":920,\"./attributes\":921,\"./calc\":922,\"./cross_trace_calc\":924,\"./defaults\":925,\"./event_data\":926,\"./hover\":928,\"./layout_attributes\":930,\"./layout_defaults\":931,\"./plot\":932,\"./select\":933,\"./style\":935}],930:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\",\"relative\"],dflt:\"group\",editType:\"calc\"},barnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},bargap:{valType:\"number\",min:0,max:1,editType:\"calc\"},bargroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],931:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib\"),o=t(\"./layout_attributes\");e.exports=function(t,e,r){function s(r,n){return a.coerce(t,e,o,r,n)}for(var l=!1,c=!1,u=!1,f={},h=s(\"barmode\"),p=0;p<r.length;p++){var d=r[p];if(n.traceIs(d,\"bar\")&&d.visible){if(l=!0,\"group\"===h){var g=d.xaxis+d.yaxis;f[g]&&(u=!0),f[g]=!0}if(d.visible&&\"histogram\"===d.type)\"category\"!==i.getFromId({_fullLayout:e},d[\"v\"===d.orientation?\"xaxis\":\"yaxis\"]).type&&(c=!0)}}l?(\"overlay\"!==h&&s(\"barnorm\"),s(\"bargap\",c&&!u?0:.2),s(\"bargroupgap\")):delete e.barmode}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./layout_attributes\":930}],932:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"../../components/color\"),l=t(\"../../components/drawing\"),c=t(\"../../registry\"),u=t(\"../../plots/cartesian/axes\").tickText,f=t(\"./uniform_text\"),h=f.recordMinTextSize,p=f.clearMinTextSize,d=t(\"./style\"),g=t(\"./helpers\"),m=t(\"./constants\"),v=t(\"./attributes\"),y=v.text,x=v.textposition,b=t(\"../../components/fx/helpers\").appendArrayPointValue,_=m.TEXTPAD;function w(t){return t.id}function T(t){if(t.ids)return w}function k(t,e){return t<e?1:-1}function M(t,e,r,n){var i;return!e.uniformtext.mode&&A(r)?(n&&(i=n()),t.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){i&&i()})).each(\"interrupt\",(function(){i&&i()}))):t}function A(t){return t&&t.duration>0}function S(t){return\"auto\"===t?0:t}function E(t,e){var r=Math.PI/180*e,n=Math.abs(Math.sin(r)),i=Math.abs(Math.cos(r));return{x:t.width*i+t.height*n,y:t.width*n+t.height*i}}function C(t,e,r,n,i,a){var o=!!a.isHorizontal,s=!!a.constrained,l=a.angle||0,c=a.anchor||\"end\",u=\"end\"===c,f=\"start\"===c,h=((a.leftToRight||0)+1)/2,p=1-h,d=i.width,g=i.height,m=Math.abs(e-t),v=Math.abs(n-r),y=m>2*_&&v>2*_?_:0;m-=2*y,v-=2*y;var x=S(l);\"auto\"!==l||d<=m&&g<=v||!(d>m||g>v)||(d>v||g>m)&&d<g==m<v||(x+=90);var b=E(i,x),w=1;s&&(w=Math.min(1,m/b.x,v/b.y));var T=i.left*p+i.right*h,M=(i.top+i.bottom)/2,A=(t+_)*p+(e-_)*h,C=(r+n)/2,L=0,I=0;if(f||u){var P=(o?b.x:b.y)/2,z=o?k(t,e):k(r,n);o?f?(A=t+z*y,L=-z*P):(A=e-z*y,L=z*P):f?(C=r+z*y,I=-z*P):(C=n-z*y,I=z*P)}return{textX:T,textY:M,targetX:A,targetY:C,anchorX:L,anchorY:I,scale:w,rotate:x}}e.exports={plot:function(t,e,r,f,m,v){var w=e.xaxis,L=e.yaxis,I=t._fullLayout;m||(m={mode:I.barmode,norm:I.barmode,gap:I.bargap,groupgap:I.bargroupgap},p(\"bar\",I));var P=a.makeTraceGroups(f,r,\"trace bars\").each((function(r){var c=n.select(this),f=r[0].trace,p=\"waterfall\"===f.type,P=\"funnel\"===f.type,z=\"bar\"===f.type||P,O=0;p&&f.connector.visible&&\"between\"===f.connector.mode&&(O=f.connector.line.width/2);var D=\"h\"===f.orientation,R=A(m),F=a.ensureSingle(c,\"g\",\"points\"),B=T(f),N=F.selectAll(\"g.point\").data(a.identity,B);N.enter().append(\"g\").classed(\"point\",!0),N.exit().remove(),N.each((function(c,p){var T,A,P=n.select(this),F=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),n?[i,a]:[a,i]}(c,w,L,D),B=F[0][0],N=F[0][1],j=F[1][0],U=F[1][1],V=0==(D?N-B:U-j);if(V&&z&&g.getLineWidth(f,c)&&(V=!1),V||(V=!(i(B)&&i(N)&&i(j)&&i(U))),c.isBlank=V,V&&(D?N=B:U=j),O&&!V&&(D?(B-=k(B,N)*O,N+=k(B,N)*O):(j-=k(j,U)*O,U+=k(j,U)*O)),\"waterfall\"===f.type){if(!V){var q=f[c.dir].marker;T=q.line.width,A=q.color}}else T=g.getLineWidth(f,c),A=c.mc||f.marker.color;function H(t){var e=n.round(T/2%1,2);return 0===m.gap&&0===m.groupgap?n.round(Math.round(t)-e,2):t}if(!t._context.staticPlot){var G=s.opacity(A)<1||T>.01?H:function(t,e,r){return r&&t===e?t:Math.abs(t-e)>=2?H(t):t>e?Math.ceil(t):Math.floor(t)};B=G(B,N,D),N=G(N,B,D),j=G(j,U,!D),U=G(U,j,!D)}var Y=M(a.ensureSingle(P,\"path\"),I,m,v);if(Y.style(\"vector-effect\",\"non-scaling-stroke\").attr(\"d\",isNaN((N-B)*(U-j))||V&&t._context.staticPlot?\"M0,0Z\":\"M\"+B+\",\"+j+\"V\"+U+\"H\"+N+\"V\"+j+\"Z\").call(l.setClipUrl,e.layerClipId,t),!I.uniformtext.mode&&R){var W=l.makePointStyleFns(f);l.singlePointStyle(c,Y,f,W,t)}!function(t,e,r,n,i,s,c,f,p,m,v){var w,T=e.xaxis,A=e.yaxis,L=t._fullLayout;function I(e,r,n){return a.ensureSingle(e,\"text\").text(r).attr({class:\"bartext bartext-\"+w,\"text-anchor\":\"middle\",\"data-notex\":1}).call(l.font,n).call(o.convertToTspans,t)}var P=n[0].trace,z=\"h\"===P.orientation,O=function(t,e,r,n,i){var o,s=e[0].trace;o=s.texttemplate?function(t,e,r,n,i){var o=e[0].trace,s=a.castOption(o,r,\"texttemplate\");if(!s)return\"\";var l,c,f,h,p=\"waterfall\"===o.type,d=\"funnel\"===o.type;\"h\"===o.orientation?(l=\"y\",c=i,f=\"x\",h=n):(l=\"x\",c=n,f=\"y\",h=i);function g(t){return u(h,+t,!0).text}var m=e[r],v={};v.label=m.p,v.labelLabel=v[l+\"Label\"]=(y=m.p,u(c,y,!0).text);var y;var x=a.castOption(o,m.i,\"text\");(0===x||x)&&(v.text=x);v.value=m.s,v.valueLabel=v[f+\"Label\"]=g(m.s);var _={};b(_,o,m.i),p&&(v.delta=+m.rawS||m.s,v.deltaLabel=g(v.delta),v.final=m.v,v.finalLabel=g(v.final),v.initial=v.final-v.delta,v.initialLabel=g(v.initial));d&&(v.value=m.s,v.valueLabel=g(v.value),v.percentInitial=m.begR,v.percentInitialLabel=a.formatPercent(m.begR),v.percentPrevious=m.difR,v.percentPreviousLabel=a.formatPercent(m.difR),v.percentTotal=m.sumR,v.percenTotalLabel=a.formatPercent(m.sumR));var w=a.castOption(o,m.i,\"customdata\");w&&(v.customdata=w);return a.texttemplateString(s,v,t._d3locale,_,v,o._meta||{})}(t,e,r,n,i):s.textinfo?function(t,e,r,n){var i=t[0].trace,o=\"h\"===i.orientation,s=\"waterfall\"===i.type,l=\"funnel\"===i.type;function c(t){return u(o?r:n,+t,!0).text}var f,h=i.textinfo,p=t[e],d=h.split(\"+\"),g=[],m=function(t){return-1!==d.indexOf(t)};m(\"label\")&&g.push((v=t[e].p,u(o?n:r,v,!0).text));var v;m(\"text\")&&(0===(f=a.castOption(i,p.i,\"text\"))||f)&&g.push(f);if(s){var y=+p.rawS||p.s,x=p.v,b=x-y;m(\"initial\")&&g.push(c(b)),m(\"delta\")&&g.push(c(y)),m(\"final\")&&g.push(c(x))}if(l){m(\"value\")&&g.push(c(p.s));var _=0;m(\"percent initial\")&&_++,m(\"percent previous\")&&_++,m(\"percent total\")&&_++;var w=_>1;m(\"percent initial\")&&(f=a.formatPercent(p.begR),w&&(f+=\" of initial\"),g.push(f)),m(\"percent previous\")&&(f=a.formatPercent(p.difR),w&&(f+=\" of previous\"),g.push(f)),m(\"percent total\")&&(f=a.formatPercent(p.sumR),w&&(f+=\" of total\"),g.push(f))}return g.join(\"<br>\")}(e,r,n,i):g.getValue(s.text,r);return g.coerceString(y,o)}(L,n,i,T,A);w=function(t,e){var r=g.getValue(t.textposition,e);return g.coerceEnumerated(x,r)}(P,i);var D=\"stack\"===m.mode||\"relative\"===m.mode,R=n[i],F=!D||R._outmost;if(!O||\"none\"===w||(R.isBlank||s===c||f===p)&&(\"auto\"===w||\"inside\"===w))return void r.select(\"text\").remove();var B=L.font,N=d.getBarColor(n[i],P),j=d.getInsideTextFont(P,i,B,N),U=d.getOutsideTextFont(P,i,B),V=r.datum();z?\"log\"===T.type&&V.s0<=0&&(s=T.range[0]<T.range[1]?0:T._length):\"log\"===A.type&&V.s0<=0&&(f=A.range[0]<A.range[1]?A._length:0);var q,H,G,Y,W,X=Math.abs(c-s)-2*_,Z=Math.abs(p-f)-2*_;\"outside\"===w&&(F||R.hasB||(w=\"inside\"));if(\"auto\"===w)if(F){w=\"inside\",W=a.ensureUniformFontSize(t,j),q=I(r,O,W),H=l.bBox(q.node()),G=H.width,Y=H.height;var J=G<=X&&Y<=Z,K=G<=Z&&Y<=X,Q=z?X>=G*(Z/Y):Z>=Y*(X/G);G>0&&Y>0&&(J||K||Q)?w=\"inside\":(w=\"outside\",q.remove(),q=null)}else w=\"inside\";if(!q){W=a.ensureUniformFontSize(t,\"outside\"===w?U:j);var $=(q=I(r,O,W)).attr(\"transform\");if(q.attr(\"transform\",\"\"),H=l.bBox(q.node()),G=H.width,Y=H.height,q.attr(\"transform\",$),G<=0||Y<=0)return void q.remove()}var tt,et,rt=P.textangle;\"outside\"===w?(et=\"both\"===P.constraintext||\"outside\"===P.constraintext,tt=function(t,e,r,n,i,a){var o,s=!!a.isHorizontal,l=!!a.constrained,c=a.angle||0,u=i.width,f=i.height,h=Math.abs(e-t),p=Math.abs(n-r);o=s?p>2*_?_:0:h>2*_?_:0;var d=1;l&&(d=s?Math.min(1,p/f):Math.min(1,h/u));var g=S(c),m=E(i,g),v=(s?m.x:m.y)/2,y=(i.left+i.right)/2,x=(i.top+i.bottom)/2,b=(t+e)/2,w=(r+n)/2,T=0,M=0,A=s?k(e,t):k(r,n);s?(b=e-A*o,T=A*v):(w=n+A*o,M=-A*v);return{textX:y,textY:x,targetX:b,targetY:w,anchorX:T,anchorY:M,scale:d,rotate:g}}(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt})):(et=\"both\"===P.constraintext||\"inside\"===P.constraintext,tt=C(s,c,f,p,H,{isHorizontal:z,constrained:et,angle:rt,anchor:P.insidetextanchor}));tt.fontSize=W.size,h(P.type,tt,L),R.transform=tt,M(q,L,m,v).attr(\"transform\",a.getTextTransform(tt))}(t,e,P,r,p,B,N,j,U,m,v),e.layerClipId&&l.hideOutsideRangePoint(c,P.select(\"text\"),w,L,f.xcalendar,f.ycalendar)}));var j=!1===f.cliponaxis;l.setClipUrl(c,j?null:e.layerClipId,t)}));c.getComponentMethod(\"errorbars\",\"plot\")(t,P,e,m)},toMoveInsideBar:C}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"./attributes\":921,\"./constants\":923,\"./helpers\":927,\"./style\":935,\"./uniform_text\":937,d3:169,\"fast-isnumeric\":241}],933:[function(t,e,r){\"use strict\";function n(t,e,r,n,i){var a=e.c2p(n?t.s0:t.p0,!0),o=e.c2p(n?t.s1:t.p1,!0),s=r.c2p(n?t.p0:t.s0,!0),l=r.c2p(n?t.p1:t.s1,!0);return i?[(a+o)/2,(s+l)/2]:n?[o,(s+l)/2]:[(a+o)/2,l]}e.exports=function(t,e){var r,i=t.cd,a=t.xaxis,o=t.yaxis,s=i[0].trace,l=\"funnel\"===s.type,c=\"h\"===s.orientation,u=[];if(!1===e)for(r=0;r<i.length;r++)i[r].selected=0;else for(r=0;r<i.length;r++){var f=i[r],h=\"ct\"in f?f.ct:n(f,a,o,c,l);e.contains(h,!1,r,t)?(u.push({pointNumber:r,x:a.c2d(f.x),y:o.c2d(f.y)}),f.selected=1):f.selected=0}return u}},{}],934:[function(t,e,r){\"use strict\";e.exports=a;var n=t(\"../../lib\").distinctVals,i=t(\"../../constants/numerical\").BADNUM;function a(t,e){this.traces=t,this.sepNegVal=e.sepNegVal,this.overlapNoMerge=e.overlapNoMerge;for(var r=1/0,a=[],o=0;o<t.length;o++){for(var s=t[o],l=0;l<s.length;l++){var c=s[l];c.p!==i&&a.push(c.p)}s[0]&&s[0].width1&&(r=Math.min(s[0].width1,r))}this.positions=a;var u=n(a,{unitMinDiff:e.unitMinDiff});this.distinctPositions=u.vals,1===u.vals.length&&r!==1/0?this.minDiff=r:this.minDiff=Math.min(u.minDiff,r),this.binWidth=this.minDiff,this.bins={}}a.prototype.put=function(t,e){var r=this.getLabel(t,e),n=this.bins[r]||0;return this.bins[r]=n+e,n},a.prototype.get=function(t,e){var r=this.getLabel(t,e);return this.bins[r]||0},a.prototype.getLabel=function(t,e){return(e<0&&this.sepNegVal?\"v\":\"^\")+(this.overlapNoMerge?t:Math.round(t/this.binWidth))}},{\"../../constants/numerical\":753,\"../../lib\":778}],935:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../registry\"),l=t(\"./uniform_text\").resizeText,c=t(\"./attributes\"),u=c.textfont,f=c.insidetextfont,h=c.outsidetextfont,p=t(\"./helpers\");function d(t,e,r){a.pointStyle(t.selectAll(\"path\"),e,r),g(t,e,r)}function g(t,e,r){t.selectAll(\"text\").each((function(t){var i=n.select(this),s=o.ensureUniformFontSize(r,m(i,t,e,r));a.font(i,s)}))}function m(t,e,r,n){var i=n._fullLayout.font,a=r.textfont;if(t.classed(\"bartext-inside\")){var o=_(e,r);a=y(r,e.i,i,o)}else t.classed(\"bartext-outside\")&&(a=x(r,e.i,i));return a}function v(t,e,r){return b(u,t.textfont,e,r)}function y(t,e,r,n){var a=v(t,e,r);return(void 0===t._input.textfont||void 0===t._input.textfont.color||Array.isArray(t.textfont.color)&&void 0===t.textfont.color[e])&&(a={color:i.contrast(n),family:a.family,size:a.size}),b(f,t.insidetextfont,e,a)}function x(t,e,r){var n=v(t,e,r);return b(h,t.outsidetextfont,e,n)}function b(t,e,r,n){e=e||{};var i=p.getValue(e.family,r),a=p.getValue(e.size,r),o=p.getValue(e.color,r);return{family:p.coerceString(t.family,i,n.family),size:p.coerceNumber(t.size,a,n.size),color:p.coerceColor(t.color,o,n.color)}}function _(t,e){return\"waterfall\"===e.type?e[t.dir].marker.color:t.mc||e.marker.color}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.barlayer\").selectAll(\"g.trace\");l(t,e,\"bar\");var r=e.size(),i=t._fullLayout;e.style(\"opacity\",(function(t){return t[0].trace.opacity})).each((function(t){(\"stack\"===i.barmode&&r>1||0===i.bargap&&0===i.bargroupgap&&!t[0].trace.marker.line.width)&&n.select(this).attr(\"shape-rendering\",\"crispEdges\")})),e.selectAll(\"g.points\").each((function(e){d(n.select(this),e[0].trace,t)})),s.getComponentMethod(\"errorbars\",\"style\")(e)},styleTextPoints:g,styleOnSelect:function(t,e,r){var i=e[0].trace;i.selectedpoints?function(t,e,r){a.selectedPointStyle(t.selectAll(\"path\"),e),function(t,e,r){t.each((function(t){var i,s=n.select(this);if(t.selected){i=o.ensureUniformFontSize(r,m(s,t,e,r));var l=e.selected.textfont&&e.selected.textfont.color;l&&(i.color=l),a.font(s,i)}else a.selectedTextStyle(s,e)}))}(t.selectAll(\"text\"),e,r)}(r,i,t):(d(r,i,t),s.getComponentMethod(\"errorbars\",\"style\")(r))},getInsideTextFont:y,getOutsideTextFont:x,getBarColor:_,resizeText:l}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../registry\":911,\"./attributes\":921,\"./helpers\":927,\"./uniform_text\":937,d3:169}],936:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s){r(\"marker.color\",o),i(t,\"marker\")&&a(t,e,s,r,{prefix:\"marker.\",cLetter:\"c\"}),r(\"marker.line.color\",n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,r,{prefix:\"marker.line.\",cLetter:\"c\"}),r(\"marker.line.width\"),r(\"marker.opacity\"),r(\"selected.marker.color\"),r(\"unselected.marker.color\")}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654}],937:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");function a(t){return\"_\"+t+\"Text_minsize\"}e.exports={recordMinTextSize:function(t,e,r){if(r.uniformtext.mode){var n=a(t),i=r.uniformtext.minsize,o=e.scale*e.fontSize;e.hide=o<i,r[n]=r[n]||1/0,e.hide||(r[n]=Math.min(r[n],Math.max(o,i)))}},clearMinTextSize:function(t,e){e[a(t)]=void 0},resizeText:function(t,e,r){var a=t._fullLayout,o=a[\"_\"+r+\"Text_minsize\"];if(o){var s,l=\"hide\"===a.uniformtext.mode;switch(r){case\"funnelarea\":case\"pie\":case\"sunburst\":s=\"g.slice\";break;case\"treemap\":s=\"g.slice, g.pathbar\";break;default:s=\"g.points > g.point\"}e.selectAll(s).each((function(t){var e=t.transform;e&&(e.scale=l&&e.hide?0:o/e.fontSize,n.select(this).select(\"text\").attr(\"transform\",i.getTextTransform(e)))}))}}}},{\"../../lib\":778,d3:169}],938:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../lib/extend\").extendFlat,a=t(\"../scatterpolar/attributes\"),o=t(\"../bar/attributes\");e.exports={r:a.r,theta:a.theta,r0:a.r0,dr:a.dr,theta0:a.theta0,dtheta:a.dtheta,thetaunit:a.thetaunit,base:i({},o.base,{}),offset:i({},o.offset,{}),width:i({},o.width,{}),text:i({},o.text,{}),hovertext:i({},o.hovertext,{}),marker:o.marker,hoverinfo:a.hoverinfo,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatterpolar/attributes\":1261}],939:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"../bar/arrays_to_calcdata\"),o=t(\"../bar/cross_trace_calc\").setGroupPositions,s=t(\"../scatter/calc_selection\"),l=t(\"../../registry\").traceIs,c=t(\"../../lib\").extendFlat;e.exports={calc:function(t,e){for(var r=t._fullLayout,o=e.subplot,l=r[o].radialaxis,c=r[o].angularaxis,u=l.makeCalcdata(e,\"r\"),f=c.makeCalcdata(e,\"theta\"),h=e._length,p=new Array(h),d=u,g=f,m=0;m<h;m++)p[m]={p:g[m],s:d[m]};function v(t){var r=e[t];void 0!==r&&(e[\"_\"+t]=Array.isArray(r)?c.makeCalcdata(e,t):c.d2c(r,e.thetaunit))}return\"linear\"===c.type&&(v(\"width\"),v(\"offset\")),n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}),a(p,e),s(p,e),p},crossTraceCalc:function(t,e,r){for(var n=t.calcdata,i=[],a=0;a<n.length;a++){var s=n[a],u=s[0].trace;!0===u.visible&&l(u,\"bar\")&&u.subplot===r&&i.push(s)}var f=c({},e.radialaxis,{_id:\"x\"}),h=e.angularaxis;o(t,h,f,i,{mode:e.barmode,norm:e.barnorm,gap:e.bargap,groupgap:e.bargroupgap})}}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"../bar/cross_trace_calc\":924,\"../scatter/calc_selection\":1189}],940:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatterpolar/defaults\").handleRThetaDefaults,a=t(\"../bar/style_defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,s,l)?(l(\"thetaunit\"),l(\"base\"),l(\"offset\"),l(\"width\"),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),a(t,e,l,r,s),n.coerceSelectionMarkerOpacity(e,l)):e.visible=!1}},{\"../../lib\":778,\"../bar/style_defaults\":936,\"../scatterpolar/defaults\":1263,\"./attributes\":938}],941:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../bar/hover\").getTraceColor,o=i.fillText,s=t(\"../scatterpolar/hover\").makeHoverPointText,l=t(\"../../plots/polar/helpers\").isPtInsidePolygon;e.exports=function(t,e,r){var c=t.cd,u=c[0].trace,f=t.subplot,h=f.radialAxis,p=f.angularAxis,d=f.vangles,g=d?l:i.isPtInsideSector,m=t.maxHoverDistance,v=p._period||2*Math.PI,y=Math.abs(h.g2p(Math.sqrt(e*e+r*r))),x=Math.atan2(r,e);h.range[0]>h.range[1]&&(x+=Math.PI);if(n.getClosest(c,(function(t){return g(y,x,[t.rp0,t.rp1],[t.thetag0,t.thetag1],d)?m+Math.min(1,Math.abs(t.thetag1-t.thetag0)/v)-1+(t.rp1-y)/(t.rp1-t.rp0)-1:1/0}),t),!1!==t.index){var b=c[t.index];t.x0=t.x1=b.ct[0],t.y0=t.y1=b.ct[1];var _=i.extendFlat({},b,{r:b.s,theta:b.p});return o(b,u,t),s(_,u,f,t),t.hovertemplate=u.hovertemplate,t.color=a(u,b),t.xLabelVal=t.yLabelVal=void 0,b.s<0&&(t.idealAlign=\"left\"),[t]}}},{\"../../components/fx\":683,\"../../lib\":778,\"../../plots/polar/helpers\":893,\"../bar/hover\":928,\"../scatterpolar/hover\":1265}],942:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"barpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"bar\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"../scatterpolar/format_labels\"),style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),meta:{}}},{\"../../plots/polar\":894,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"../scatterpolar/format_labels\":1264,\"./attributes\":938,\"./calc\":939,\"./defaults\":940,\"./hover\":941,\"./layout_attributes\":943,\"./layout_defaults\":944,\"./plot\":945}],943:[function(t,e,r){\"use strict\";e.exports={barmode:{valType:\"enumerated\",values:[\"stack\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},bargap:{valType:\"number\",dflt:.1,min:0,max:1,editType:\"calc\"}}},{}],944:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a,o={};function s(r,o){return n.coerce(t[a]||{},e[a],i,r,o)}for(var l=0;l<r.length;l++){var c=r[l];\"barpolar\"===c.type&&!0===c.visible&&(o[a=c.subplot]||(s(\"barmode\"),s(\"bargap\"),o[a]=1))}}},{\"../../lib\":778,\"./layout_attributes\":943}],945:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/drawing\"),s=t(\"../../plots/polar/helpers\");e.exports=function(t,e,r){var l=e.xaxis,c=e.yaxis,u=e.radialAxis,f=e.angularAxis,h=function(t){var e=t.cxx,r=t.cyy;if(t.vangles)return function(n,i,o,l){var c,u;a.angleDelta(o,l)>0?(c=o,u=l):(c=l,u=o);var f=[s.findEnclosingVertexAngles(c,t.vangles)[0],(c+u)/2,s.findEnclosingVertexAngles(u,t.vangles)[1]];return s.pathPolygonAnnulus(n,i,c,u,f,e,r)};return function(t,n,i,o){return a.pathAnnulus(t,n,i,o,e,r)}}(e),p=e.layers.frontplot.select(\"g.barlayer\");a.makeTraceGroups(p,r,\"trace bars\").each((function(){var r=n.select(this),s=a.ensureSingle(r,\"g\",\"points\").selectAll(\"g.point\").data(a.identity);s.enter().append(\"g\").style(\"vector-effect\",\"non-scaling-stroke\").style(\"stroke-miterlimit\",2).classed(\"point\",!0),s.exit().remove(),s.each((function(t){var e,r=n.select(this),o=t.rp0=u.c2p(t.s0),s=t.rp1=u.c2p(t.s1),p=t.thetag0=f.c2g(t.p0),d=t.thetag1=f.c2g(t.p1);if(i(o)&&i(s)&&i(p)&&i(d)&&o!==s&&p!==d){var g=u.c2g(t.s1),m=(p+d)/2;t.ct=[l.c2p(g*Math.cos(m)),c.c2p(g*Math.sin(m))],e=h(o,s,p,d)}else e=\"M0,0Z\";a.ensureSingle(r,\"path\").attr(\"d\",e)})),o.setClipUrl(r,e._hasClipOnAxisFalse?e.clipIds.forTraces:null,t)}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../plots/polar/helpers\":893,d3:169,\"fast-isnumeric\":241}],946:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../bar/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../lib/extend\").extendFlat,l=n.marker,c=l.line;e.exports={y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},x0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",editType:\"calc\"},dy:{valType:\"number\",editType:\"calc\"},xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,name:{valType:\"string\",editType:\"calc+clearAxisTypes\"},q1:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},median:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},q3:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},lowerfence:{valType:\"data_array\",editType:\"calc\"},upperfence:{valType:\"data_array\",editType:\"calc\"},notched:{valType:\"boolean\",editType:\"calc\"},notchwidth:{valType:\"number\",min:0,max:.5,dflt:.25,editType:\"calc\"},notchspan:{valType:\"data_array\",editType:\"calc\"},boxpoints:{valType:\"enumerated\",values:[\"all\",\"outliers\",\"suspectedoutliers\",!1],editType:\"calc\"},jitter:{valType:\"number\",min:0,max:1,editType:\"calc\"},pointpos:{valType:\"number\",min:-2,max:2,editType:\"calc\"},boxmean:{valType:\"enumerated\",values:[!0,\"sd\",!1],editType:\"calc\"},mean:{valType:\"data_array\",editType:\"calc\"},sd:{valType:\"data_array\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc+clearAxisTypes\"},quartilemethod:{valType:\"enumerated\",values:[\"linear\",\"exclusive\",\"inclusive\"],dflt:\"linear\",editType:\"calc\"},width:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},marker:{outliercolor:{valType:\"color\",dflt:\"rgba(0, 0, 0, 0)\",editType:\"style\"},symbol:s({},l.symbol,{arrayOk:!1,editType:\"plot\"}),opacity:s({},l.opacity,{arrayOk:!1,dflt:1,editType:\"style\"}),size:s({},l.size,{arrayOk:!1,editType:\"calc\"}),color:s({},l.color,{arrayOk:!1,editType:\"style\"}),line:{color:s({},c.color,{arrayOk:!1,dflt:a.defaultLine,editType:\"style\"}),width:s({},c.width,{arrayOk:!1,dflt:0,editType:\"style\"}),outliercolor:{valType:\"color\",editType:\"style\"},outlierwidth:{valType:\"number\",min:0,dflt:1,editType:\"style\"},editType:\"style\"},editType:\"plot\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,whiskerwidth:{valType:\"number\",min:0,max:1,dflt:.5,editType:\"calc\"},offsetgroup:i.offsetgroup,alignmentgroup:i.alignmentgroup,selected:{marker:n.selected.marker,editType:\"style\"},unselected:{marker:n.unselected.marker,editType:\"style\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),hovertemplate:o({}),hoveron:{valType:\"flaglist\",flags:[\"boxes\",\"points\"],dflt:\"boxes+points\",editType:\"style\"}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187}],947:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../../lib\"),s=t(\"../../constants/numerical\").BADNUM,l=o._;e.exports=function(t,e){var r,c,y,x,b,_,w,T=t._fullLayout,k=i.getFromId(t,e.xaxis||\"x\"),M=i.getFromId(t,e.yaxis||\"y\"),A=[],S=\"violin\"===e.type?\"_numViolins\":\"_numBoxes\";\"h\"===e.orientation?(y=k,x=\"x\",b=M,_=\"y\",w=!!e.yperiodalignment):(y=M,x=\"y\",b=k,_=\"x\",w=!!e.xperiodalignment);var E,C,L,I,P,z,O=function(t,e,r,i){var s,l=e+\"0\"in t,c=\"d\"+e in t;if(e in t||l&&c){var u=r.makeCalcdata(t,e);return[a(t,r,e,u),u]}s=l?t[e+\"0\"]:\"name\"in t&&(\"category\"===r.type||n(t.name)&&-1!==[\"linear\",\"log\"].indexOf(r.type)||o.isDateTime(t.name)&&\"date\"===r.type)?t.name:i;for(var f=\"multicategory\"===r.type?r.r2c_just_indices(s):r.d2c(s,0,t[e+\"calendar\"]),h=t._length,p=new Array(h),d=0;d<h;d++)p[d]=f;return[p]}(e,_,b,T[S]),D=O[0],R=O[1],F=o.distinctVals(D),B=F.vals,N=F.minDiff/2,j=\"all\"===(e.boxpoints||e.points)?o.identity:function(t){return t.v<E.lf||t.v>E.uf};if(e._hasPreCompStats){var U=e[x],V=function(t){return y.d2c((e[t]||[])[r])},q=1/0,H=-1/0;for(r=0;r<e._length;r++){var G=D[r];if(n(G)){if((E={}).pos=E[_]=G,w&&R&&(E.orig_p=R[r]),E.q1=V(\"q1\"),E.med=V(\"median\"),E.q3=V(\"q3\"),C=[],U&&o.isArrayOrTypedArray(U[r]))for(c=0;c<U[r].length;c++)(z=y.d2c(U[r][c]))!==s&&(u(P={v:z,i:[r,c]},e,[r,c]),C.push(P));if(E.pts=C.sort(f),I=(L=E[x]=C.map(h)).length,E.med!==s&&E.q1!==s&&E.q3!==s&&E.med>=E.q1&&E.q3>=E.med){var Y=V(\"lowerfence\");E.lf=Y!==s&&Y<=E.q1?Y:p(E,L,I);var W=V(\"upperfence\");E.uf=W!==s&&W>=E.q3?W:d(E,L,I);var X=V(\"mean\");E.mean=X!==s?X:I?o.mean(L,I):(E.q1+E.q3)/2;var Z=V(\"sd\");E.sd=X!==s&&Z>=0?Z:I?o.stdev(L,I,E.mean):E.q3-E.q1,E.lo=g(E),E.uo=m(E);var J=V(\"notchspan\");J=J!==s&&J>0?J:v(E,I),E.ln=E.med-J,E.un=E.med+J;var K=E.lf,Q=E.uf;e.boxpoints&&L.length&&(K=Math.min(K,L[0]),Q=Math.max(Q,L[I-1])),e.notched&&(K=Math.min(K,E.ln),Q=Math.max(Q,E.un)),E.min=K,E.max=Q}else{var $;o.warn([\"Invalid input - make sure that q1 <= median <= q3\",\"q1 = \"+E.q1,\"median = \"+E.med,\"q3 = \"+E.q3].join(\"\\n\")),$=E.med!==s?E.med:E.q1!==s?E.q3!==s?(E.q1+E.q3)/2:E.q1:E.q3!==s?E.q3:0,E.med=$,E.q1=E.q3=$,E.lf=E.uf=$,E.mean=E.sd=$,E.ln=E.un=$,E.min=E.max=$}q=Math.min(q,E.min),H=Math.max(H,E.max),E.pts2=C.filter(j),A.push(E)}}e._extremes[y._id]=i.findExtremes(y,[q,H],{padded:!0})}else{var tt=y.makeCalcdata(e,x),et=function(t,e){for(var r=t.length,n=new Array(r+1),i=0;i<r;i++)n[i]=t[i]-e;return n[r]=t[r-1]+e,n}(B,N),rt=B.length,nt=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=[];return e}(rt);for(r=0;r<e._length;r++)if(z=tt[r],n(z)){var it=o.findBin(D[r],et);it>=0&&it<rt&&(u(P={v:z,i:r},e,r),nt[it].push(P))}var at=1/0,ot=-1/0,st=e.quartilemethod,lt=\"exclusive\"===st,ct=\"inclusive\"===st;for(r=0;r<rt;r++)if(nt[r].length>0){var ut,ft;if((E={}).pos=E[_]=B[r],C=E.pts=nt[r].sort(f),I=(L=E[x]=C.map(h)).length,E.min=L[0],E.max=L[I-1],E.mean=o.mean(L,I),E.sd=o.stdev(L,I,E.mean),E.med=o.interp(L,.5),I%2&&(lt||ct))lt?(ut=L.slice(0,I/2),ft=L.slice(I/2+1)):ct&&(ut=L.slice(0,I/2+1),ft=L.slice(I/2)),E.q1=o.interp(ut,.5),E.q3=o.interp(ft,.5);else E.q1=o.interp(L,.25),E.q3=o.interp(L,.75);E.lf=p(E,L,I),E.uf=d(E,L,I),E.lo=g(E),E.uo=m(E);var ht=v(E,I);E.ln=E.med-ht,E.un=E.med+ht,at=Math.min(at,E.ln),ot=Math.max(ot,E.un),E.pts2=C.filter(j),A.push(E)}e._extremes[y._id]=i.findExtremes(y,e.notched?tt.concat([at,ot]):tt,{padded:!0})}return function(t,e){if(o.isArrayOrTypedArray(e.selectedpoints))for(var r=0;r<t.length;r++){for(var n=t[r].pts||[],i={},a=0;a<n.length;a++)i[n[a].i]=a;o.tagSelected(n,e,i)}}(A,e),A.length>0?(A[0].t={num:T[S],dPos:N,posLetter:_,valLetter:x,labels:{med:l(t,\"median:\"),min:l(t,\"min:\"),q1:l(t,\"q1:\"),q3:l(t,\"q3:\"),max:l(t,\"max:\"),mean:\"sd\"===e.boxmean?l(t,\"mean \\xb1 \\u03c3:\"):l(t,\"mean:\"),lf:l(t,\"lower fence:\"),uf:l(t,\"upper fence:\")}},T[S]++,A):[{t:{empty:!0}}]};var c={text:\"tx\",hovertext:\"htx\"};function u(t,e,r){for(var n in c)o.isArrayOrTypedArray(e[n])&&(Array.isArray(r)?o.isArrayOrTypedArray(e[n][r[0]])&&(t[c[n]]=e[n][r[0]][r[1]]):t[c[n]]=e[n][r])}function f(t,e){return t.v-e.v}function h(t){return t.v}function p(t,e,r){return 0===r?t.q1:Math.min(t.q1,e[Math.min(o.findBin(2.5*t.q1-1.5*t.q3,e,!0)+1,r-1)])}function d(t,e,r){return 0===r?t.q3:Math.max(t.q3,e[Math.max(o.findBin(2.5*t.q3-1.5*t.q1,e),0)])}function g(t){return 4*t.q1-3*t.q3}function m(t){return 4*t.q3-3*t.q1}function v(t,e){return 0===e?0:1.57*(t.q3-t.q1)/Math.sqrt(e)}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"fast-isnumeric\":241}],948:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/constraints\").getAxisGroup,o=[\"v\",\"h\"];function s(t,e,r,o){var s,l,c,u=e.calcdata,f=e._fullLayout,h=o._id,p=h.charAt(0),d=[],g=0;for(s=0;s<r.length;s++)for(c=u[r[s]],l=0;l<c.length;l++)d.push(o.c2l(c[l].pos,!0)),g+=(c[l].pts2||[]).length;if(d.length){var m=i.distinctVals(d,{unitMinDiff:\"category\"===o.type||\"multicategory\"===o.type}),v=m.minDiff/2;n.minDtick(o,m.minDiff,m.vals[0],!0);var y=f[\"violin\"===t?\"_numViolins\":\"_numBoxes\"],x=\"group\"===f[t+\"mode\"]&&y>1,b=1-f[t+\"gap\"],_=1-f[t+\"groupgap\"];for(s=0;s<r.length;s++){var w,T,k,M,A,S,E=(c=u[r[s]])[0].trace,C=c[0].t,L=E.width,I=E.side;if(L)w=T=M=L/2,k=0;else if(w=v,x){var P=a(f,o._id)+E.orientation,z=(f._alignmentOpts[P]||{})[E.alignmentgroup]||{},O=Object.keys(z.offsetGroups||{}).length,D=O||y;T=w*b*_/D,k=2*w*(((O?E._offsetIndex:C.num)+.5)/D-.5)*b,M=w*b/D}else T=w*b*_,k=0,M=w;C.dPos=w,C.bPos=k,C.bdPos=T,C.wHover=M;var R,F,B,N,j,U,V=k+T,q=Boolean(L);if(\"positive\"===I?(A=w*(L?1:.5),R=V,S=R=k):\"negative\"===I?(A=R=k,S=w*(L?1:.5),F=V):(A=S=w,R=F=V),(E.boxpoints||E.points)&&g>0){var H=E.pointpos,G=E.jitter,Y=E.marker.size/2,W=0;H+G>=0&&((W=V*(H+G))>A?(q=!0,j=Y,B=W):W>R&&(j=Y,B=A)),W<=A&&(B=A);var X=0;H-G<=0&&((X=-V*(H-G))>S?(q=!0,U=Y,N=X):X>F&&(U=Y,N=S)),X<=S&&(N=S)}else B=A,N=S;var Z=new Array(c.length);for(l=0;l<c.length;l++)Z[l]=c[l].pos;E._extremes[h]=n.findExtremes(o,Z,{padded:q,vpadminus:N,vpadplus:B,vpadLinearized:!0,ppadminus:{x:U,y:j}[p],ppadplus:{x:j,y:U}[p]})}}}e.exports={crossTraceCalc:function(t,e){for(var r=t.calcdata,n=e.xaxis,i=e.yaxis,a=0;a<o.length;a++){for(var l=o[a],c=\"h\"===l?i:n,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"box\"!==d.type&&\"candlestick\"!==d.type||p.empty||(d.orientation||\"v\")!==l||d.xaxis!==n._id||d.yaxis!==i._id||u.push(f)}s(\"box\",t,u,c)}},setPositionOffset:s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/constraints\":835}],949:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"../../components/color\"),o=t(\"../scatter/period_defaults\"),s=t(\"../bar/defaults\").handleGroupingDefaults,l=t(\"../../plots/cartesian/axis_autotype\"),c=t(\"./attributes\");function u(t,e,r,a){function o(t){var e=0;return t&&t.length&&(e+=1,n.isArrayOrTypedArray(t[0])&&t[0].length&&(e+=1)),e}function s(e){return n.validate(t[e],c[e])}var u,f=r(\"y\"),h=r(\"x\");if(\"box\"===e.type){var p=r(\"q1\"),d=r(\"median\"),g=r(\"q3\");e._hasPreCompStats=p&&p.length&&d&&d.length&&g&&g.length,u=Math.min(n.minRowLength(p),n.minRowLength(d),n.minRowLength(g))}var m,v,y=o(f),x=o(h),b=y&&n.minRowLength(f),_=x&&n.minRowLength(h),w=a.calendar,T={autotypenumbers:a.autotypenumbers};if(e._hasPreCompStats)switch(String(x)+String(y)){case\"00\":var k=s(\"x0\")||s(\"dx\");m=(s(\"y0\")||s(\"dy\"))&&!k?\"h\":\"v\",v=u;break;case\"10\":m=\"v\",v=Math.min(u,_);break;case\"20\":m=\"h\",v=Math.min(u,h.length);break;case\"01\":m=\"h\",v=Math.min(u,b);break;case\"02\":m=\"v\",v=Math.min(u,f.length);break;case\"12\":m=\"v\",v=Math.min(u,_,f.length);break;case\"21\":m=\"h\",v=Math.min(u,h.length,b);break;case\"11\":v=0;break;case\"22\":var M,A=!1;for(M=0;M<h.length;M++)if(\"category\"===l(h[M],w,T)){A=!0;break}if(A)m=\"v\",v=Math.min(u,_,f.length);else{for(M=0;M<f.length;M++)if(\"category\"===l(f[M],w,T)){A=!0;break}A?(m=\"h\",v=Math.min(u,h.length,b)):(m=\"v\",v=Math.min(u,_,f.length))}}else y>0?(m=\"v\",v=x>0?Math.min(_,b):Math.min(b)):x>0?(m=\"h\",v=Math.min(_)):v=0;if(v){e._length=v;var S=r(\"orientation\",m);e._hasPreCompStats?\"v\"===S&&0===x?(r(\"x0\",0),r(\"dx\",1)):\"h\"===S&&0===y&&(r(\"y0\",0),r(\"dy\",1)):\"v\"===S&&0===x?r(\"x0\"):\"h\"===S&&0===y&&r(\"y0\"),i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a)}else e.visible=!1}function f(t,e,r,i){var a=i.prefix,o=n.coerce2(t,e,c,\"marker.outliercolor\"),s=r(\"marker.line.outliercolor\"),l=\"outliers\";e._hasPreCompStats?l=\"all\":(o||s)&&(l=\"suspectedoutliers\");var u=r(a+\"points\",l);u?(r(\"jitter\",\"all\"===u?.3:0),r(\"pointpos\",\"all\"===u?-1.5:0),r(\"marker.symbol\"),r(\"marker.opacity\"),r(\"marker.size\"),r(\"marker.color\",e.line.color),r(\"marker.line.color\"),r(\"marker.line.width\"),\"suspectedoutliers\"===u&&(r(\"marker.line.outliercolor\",e.marker.color),r(\"marker.line.outlierwidth\")),r(\"selected.marker.color\"),r(\"unselected.marker.color\"),r(\"selected.marker.size\"),r(\"unselected.marker.size\"),r(\"text\"),r(\"hovertext\")):delete e.marker;var f=r(\"hoveron\");\"all\"!==f&&-1===f.indexOf(\"points\")||r(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,r)}e.exports={supplyDefaults:function(t,e,r,i){function s(r,i){return n.coerce(t,e,c,r,i)}if(u(t,e,s,i),!1!==e.visible){o(t,e,i,s);var l=e._hasPreCompStats;l&&(s(\"lowerfence\"),s(\"upperfence\")),s(\"line.color\",(t.marker||{}).color||r),s(\"line.width\"),s(\"fillcolor\",a.addOpacity(e.line.color,.5));var h=!1;if(l){var p=s(\"mean\"),d=s(\"sd\");p&&p.length&&(h=!0,d&&d.length&&(h=\"sd\"))}s(\"boxmean\",h),s(\"whiskerwidth\"),s(\"width\"),s(\"quartilemethod\");var g=!1;if(l){var m=s(\"notchspan\");m&&m.length&&(g=!0)}else n.validate(t.notchwidth,c.notchwidth)&&(g=!0);s(\"notched\",g)&&s(\"notchwidth\"),f(t,e,s,{prefix:\"box\"})}},crossTraceDefaults:function(t,e){var r,i;function a(t){return n.coerce(i._input,i,c,t)}for(var o=0;o<t.length;o++){var l=(i=t[o]).type;\"box\"!==l&&\"violin\"!==l||(r=i._input,\"group\"===e[l+\"mode\"]&&s(r,i,e,a))}},handleSampleDefaults:u,handlePointsDefaults:f}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../registry\":911,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"./attributes\":946}],950:[function(t,e,r){\"use strict\";e.exports=function(t,e){return e.hoverOnBox&&(t.hoverOnBox=e.hoverOnBox),\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],951:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=i.fillText;function l(t,e,r,s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w=t.cd,T=t.xa,k=t.ya,M=w[0].trace,A=w[0].t,S=\"violin\"===M.type,E=[],C=A.bdPos,L=A.wHover,I=function(t){return u.c2l(t.pos)+A.bPos-u.c2l(p)};S&&\"both\"!==M.side?(\"positive\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e,e+L,v)},x=C,b=0),\"negative\"===M.side&&(m=function(t){var e=I(t);return a.inbox(e-L,e,v)},x=0,b=C)):(m=function(t){var e=I(t);return a.inbox(e-L,e+L,v)},x=b=C),_=S?function(t){return a.inbox(t.span[0]-h,t.span[1]-h,v)}:function(t){return a.inbox(t.min-h,t.max-h,v)},\"h\"===M.orientation?(h=e,p=r,d=_,g=m,l=\"y\",u=k,c=\"x\",f=T):(h=r,p=e,d=m,g=_,l=\"x\",u=T,c=\"y\",f=k);var P=Math.min(1,C/Math.abs(u.r2c(u.range[1])-u.r2c(u.range[0])));function z(t){return(d(t)+g(t))/2}v=t.maxHoverDistance-P,y=t.maxSpikeDistance-P;var O=a.getDistanceFunction(s,d,g,z);if(a.getClosest(w,O,t),!1===t.index)return[];var D=w[t.index],R=M.line.color,F=(M.marker||{}).color;o.opacity(R)&&M.line.width?t.color=R:o.opacity(F)&&M.boxpoints?t.color=F:t.color=M.fillcolor,t[l+\"0\"]=u.c2p(D.pos+A.bPos-b,!0),t[l+\"1\"]=u.c2p(D.pos+A.bPos+x,!0),t[l+\"LabelVal\"]=void 0!==D.orig_p?D.orig_p:D.pos;var B=l+\"Spike\";t.spikeDistance=z(D)*y/v,t[B]=u.c2p(D.pos,!0);var N={},j=[\"med\",\"q1\",\"q3\",\"min\",\"max\"];(M.boxmean||(M.meanline||{}).visible)&&j.push(\"mean\"),(M.boxpoints||M.points)&&j.push(\"lf\",\"uf\");for(var U=0;U<j.length;U++){var V=j[U];if(V in D&&!(D[V]in N)){N[D[V]]=!0;var q=D[V],H=f.c2p(q,!0),G=i.extendFlat({},t);G.attr=V,G[c+\"0\"]=G[c+\"1\"]=H,G[c+\"LabelVal\"]=q,G[c+\"Label\"]=(A.labels?A.labels[V]+\" \":\"\")+n.hoverLabelText(f,q),G.hoverOnBox=!0,\"mean\"===V&&\"sd\"in D&&\"sd\"===M.boxmean&&(G[c+\"err\"]=D.sd),t.name=\"\",t.spikeDistance=void 0,t[B]=void 0,G.hovertemplate=!1,E.push(G)}}return E}function c(t,e,r){for(var n,o,l,c=t.cd,u=t.xa,f=t.ya,h=c[0].trace,p=u.c2p(e),d=f.c2p(r),g=a.quadrature((function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(u.c2p(t.x)-p)-e,1-3/e)}),(function(t){var e=Math.max(3,t.mrc||0);return Math.max(Math.abs(f.c2p(t.y)-d)-e,1-3/e)})),m=!1,v=0;v<c.length;v++){o=c[v];for(var y=0;y<(o.pts||[]).length;y++){var x=g(l=o.pts[y]);x<=t.distance&&(t.distance=x,m=[v,y])}}if(!m)return!1;l=(o=c[m[0]]).pts[m[1]];var b=u.c2p(l.x,!0),_=f.c2p(l.y,!0),w=l.mrc||1;n=i.extendFlat({},t,{index:l.i,color:(h.marker||{}).color,name:h.name,x0:b-w,x1:b+w,y0:_-w,y1:_+w,spikeDistance:t.distance,hovertemplate:h.hovertemplate});var T,k=o.orig_p,M=void 0!==k?k:o.pos;return\"h\"===h.orientation?(T=f,n.xLabelVal=l.x,n.yLabelVal=M):(T=u,n.xLabelVal=M,n.yLabelVal=l.y),n[T._id.charAt(0)+\"Spike\"]=T.c2p(o.pos,!0),s(l,h,n),n}e.exports={hoverPoints:function(t,e,r,n){var i,a=t.cd[0].trace.hoveron,o=[];return-1!==a.indexOf(\"boxes\")&&(o=o.concat(l(t,e,r,n))),-1!==a.indexOf(\"points\")&&(i=c(t,e,r)),\"closest\"===n?i?[i]:o:i?(o.push(i),o):o},hoverOnBoxes:l,hoverOnPoints:c}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],952:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\").supplyLayoutDefaults,calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"box\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"boxLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":946,\"./calc\":947,\"./cross_trace_calc\":948,\"./defaults\":949,\"./event_data\":950,\"./hover\":951,\"./layout_attributes\":953,\"./layout_defaults\":954,\"./plot\":955,\"./select\":956,\"./style\":957}],953:[function(t,e,r){\"use strict\";e.exports={boxmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"overlay\",editType:\"calc\"},boxgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"},boxgroupgap:{valType:\"number\",min:0,max:1,dflt:.3,editType:\"calc\"}}},{}],954:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"./layout_attributes\");function o(t,e,r,i,a){for(var o=a+\"Layout\",s=!1,l=0;l<r.length;l++){var c=r[l];if(n.traceIs(c,o)){s=!0;break}}s&&(i(a+\"mode\"),i(a+\"gap\"),i(a+\"groupgap\"))}e.exports={supplyLayoutDefaults:function(t,e,r){o(0,0,r,(function(r,n){return i.coerce(t,e,a,r,n)}),\"box\")},_supply:o}},{\"../../lib\":778,\"../../registry\":911,\"./layout_attributes\":953}],955:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\");function o(t,e,r,a){var o,s,l=\"h\"===r.orientation,c=e.val,u=e.pos,f=!!u.rangebreaks,h=a.bPos,p=a.wdPos||0,d=a.bPosPxOffset||0,g=r.whiskerwidth||0,m=r.notched||!1,v=m?1-2*r.notchwidth:1;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var y=t.selectAll(\"path.box\").data(\"violin\"!==r.type||r.box.visible?i.identity:[]);y.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"box\"),y.exit().remove(),y.each((function(t){if(t.empty)return\"M0,0Z\";var e=u.c2l(t.pos+h,!0),a=u.l2p(e-o)+d,y=u.l2p(e+s)+d,x=f?(a+y)/2:u.l2p(e)+d,b=r.whiskerwidth,_=f?a*b+(1-b)*x:u.l2p(e-p)+d,w=f?y*b+(1-b)*x:u.l2p(e+p)+d,T=u.l2p(e-o*v)+d,k=u.l2p(e+s*v)+d,M=c.c2p(t.q1,!0),A=c.c2p(t.q3,!0),S=i.constrain(c.c2p(t.med,!0),Math.min(M,A)+1,Math.max(M,A)-1),E=void 0===t.lf||!1===r.boxpoints,C=c.c2p(E?t.min:t.lf,!0),L=c.c2p(E?t.max:t.uf,!0),I=c.c2p(t.ln,!0),P=c.c2p(t.un,!0);l?n.select(this).attr(\"d\",\"M\"+S+\",\"+T+\"V\"+k+\"M\"+M+\",\"+a+\"V\"+y+(m?\"H\"+I+\"L\"+S+\",\"+k+\"L\"+P+\",\"+y:\"\")+\"H\"+A+\"V\"+a+(m?\"H\"+P+\"L\"+S+\",\"+T+\"L\"+I+\",\"+a:\"\")+\"ZM\"+M+\",\"+x+\"H\"+C+\"M\"+A+\",\"+x+\"H\"+L+(0===g?\"\":\"M\"+C+\",\"+_+\"V\"+w+\"M\"+L+\",\"+_+\"V\"+w)):n.select(this).attr(\"d\",\"M\"+T+\",\"+S+\"H\"+k+\"M\"+a+\",\"+M+\"H\"+y+(m?\"V\"+I+\"L\"+k+\",\"+S+\"L\"+y+\",\"+P:\"\")+\"V\"+A+\"H\"+a+(m?\"V\"+P+\"L\"+T+\",\"+S+\"L\"+a+\",\"+I:\"\")+\"ZM\"+x+\",\"+M+\"V\"+C+\"M\"+x+\",\"+A+\"V\"+L+(0===g?\"\":\"M\"+_+\",\"+C+\"H\"+w+\"M\"+_+\",\"+L+\"H\"+w))}))}function s(t,e,r,n){var o=e.x,s=e.y,l=n.bdPos,c=n.bPos,u=r.boxpoints||r.points;i.seedPseudoRandom();var f=t.selectAll(\"g.points\").data(u?function(t){return t.forEach((function(t){t.t=n,t.trace=r})),t}:[]);f.enter().append(\"g\").attr(\"class\",\"points\"),f.exit().remove();var h=f.selectAll(\"path\").data((function(t){var e,n,a=t.pts2,o=Math.max((t.max-t.min)/10,t.q3-t.q1),s=1e-9*o,f=.01*o,h=[],p=0;if(r.jitter){if(0===o)for(p=1,h=new Array(a.length),e=0;e<a.length;e++)h[e]=1;else for(e=0;e<a.length;e++){var d=Math.max(0,e-5),g=a[d].v,m=Math.min(a.length-1,e+5),v=a[m].v;\"all\"!==u&&(a[e].v<t.lf?v=Math.min(v,t.lf):g=Math.max(g,t.uf));var y=Math.sqrt(f*(m-d)/(v-g+s))||0;y=i.constrain(Math.abs(y),0,1),h.push(y),p=Math.max(y,p)}n=2*r.jitter/(p||1)}for(e=0;e<a.length;e++){var x=a[e],b=x.v,_=r.jitter?n*h[e]*(i.pseudoRandom()-.5):0,w=t.pos+c+l*(r.pointpos+_);\"h\"===r.orientation?(x.y=w,x.x=b):(x.x=w,x.y=b),\"suspectedoutliers\"===u&&b<t.uo&&b>t.lo&&(x.so=!0)}return a}));h.enter().append(\"path\").classed(\"point\",!0),h.exit().remove(),h.call(a.translatePoints,o,s)}function l(t,e,r,a){var o,s,l=e.val,c=e.pos,u=!!c.rangebreaks,f=a.bPos,h=a.bPosPxOffset||0,p=r.boxmean||(r.meanline||{}).visible;Array.isArray(a.bdPos)?(o=a.bdPos[0],s=a.bdPos[1]):(o=a.bdPos,s=a.bdPos);var d=t.selectAll(\"path.mean\").data(\"box\"===r.type&&r.boxmean||\"violin\"===r.type&&r.box.visible&&r.meanline.visible?i.identity:[]);d.enter().append(\"path\").attr(\"class\",\"mean\").style({fill:\"none\",\"vector-effect\":\"non-scaling-stroke\"}),d.exit().remove(),d.each((function(t){var e=c.c2l(t.pos+f,!0),i=c.l2p(e-o)+h,a=c.l2p(e+s)+h,d=u?(i+a)/2:c.l2p(e)+h,g=l.c2p(t.mean,!0),m=l.c2p(t.mean-t.sd,!0),v=l.c2p(t.mean+t.sd,!0);\"h\"===r.orientation?n.select(this).attr(\"d\",\"M\"+g+\",\"+i+\"V\"+a+(\"sd\"===p?\"m0,0L\"+m+\",\"+d+\"L\"+g+\",\"+i+\"L\"+v+\",\"+d+\"Z\":\"\")):n.select(this).attr(\"d\",\"M\"+i+\",\"+g+\"H\"+a+(\"sd\"===p?\"m0,0L\"+d+\",\"+m+\"L\"+i+\",\"+g+\"L\"+d+\",\"+v+\"Z\":\"\"))}))}e.exports={plot:function(t,e,r,a){var c=e.xaxis,u=e.yaxis;i.makeTraceGroups(a,r,\"trace boxes\").each((function(t){var e,r,i=n.select(this),a=t[0],f=a.t,h=a.trace;(f.wdPos=f.bdPos*h.whiskerwidth,!0!==h.visible||f.empty)?i.remove():(\"h\"===h.orientation?(e=u,r=c):(e=c,r=u),o(i,{pos:e,val:r},h,f),s(i,{x:c,y:u},h,f),l(i,{pos:e,val:r},h,f))}))},plotBoxAndWhiskers:o,plotPoints:s,plotBoxMean:l}},{\"../../components/drawing\":665,\"../../lib\":778,d3:169}],956:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i=t.cd,a=t.xaxis,o=t.yaxis,s=[];if(!1===e)for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++)i[r].pts[n].selected=0;else for(r=0;r<i.length;r++)for(n=0;n<(i[r].pts||[]).length;n++){var l=i[r].pts[n],c=a.c2p(l.x),u=o.c2p(l.y);e.contains([c,u],null,l.i,t)?(s.push({pointNumber:l.i,x:a.c2d(l.x),y:o.c2d(l.y)}),l.selected=1):l.selected=0}return s}},{}],957:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\");e.exports={style:function(t,e,r){var o=r||n.select(t).selectAll(\"g.trace.boxes\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(e){var r=n.select(this),o=e[0].trace,s=o.line.width;function l(t,e,r,n){t.style(\"stroke-width\",e+\"px\").call(i.stroke,r).call(i.fill,n)}var c=r.selectAll(\"path.box\");if(\"candlestick\"===o.type)c.each((function(t){if(!t.empty){var e=n.select(this),r=o[t.dir];l(e,r.line.width,r.line.color,r.fillcolor),e.style(\"opacity\",o.selectedpoints&&!t.selected?.3:1)}}));else{l(c,s,o.line.color,o.fillcolor),r.selectAll(\"path.mean\").style({\"stroke-width\":s,\"stroke-dasharray\":2*s+\"px,\"+s+\"px\"}).call(i.stroke,o.line.color);var u=r.selectAll(\"path.point\");a.pointStyle(u,o,t)}}))},styleOnSelect:function(t,e,r){var n=e[0].trace,i=r.selectAll(\"path.point\");n.selectedpoints?a.selectedPointStyle(i,n):a.pointStyle(i,n,t)}}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],958:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../ohlc/attributes\"),a=t(\"../box/attributes\");function o(t){return{line:{color:n({},a.line.color,{dflt:t}),width:a.line.width,editType:\"style\"},fillcolor:a.fillcolor,editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:i.x,open:i.open,high:i.high,low:i.low,close:i.close,line:{width:n({},a.line.width,{}),editType:\"style\"},increasing:o(i.increasing.line.color.dflt),decreasing:o(i.decreasing.line.color.dflt),text:i.text,hovertext:i.hovertext,whiskerwidth:n({},a.whiskerwidth,{dflt:0}),hoverlabel:i.hoverlabel}},{\"../../lib\":778,\"../box/attributes\":946,\"../ohlc/attributes\":1133}],959:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../plots/cartesian/align_period\"),o=t(\"../ohlc/calc\").calcCommon;function s(t,e,r,n){return{min:r,q1:Math.min(t,n),med:n,q3:Math.max(t,n),max:e}}e.exports=function(t,e){var r=t._fullLayout,l=i.getFromId(t,e.xaxis),c=i.getFromId(t,e.yaxis),u=l.makeCalcdata(e,\"x\"),f=a(e,l,\"x\",u),h=o(t,e,u,f,c,s);return h.length?(n.extendFlat(h[0].t,{num:r._numBoxes,dPos:n.distinctVals(f).minDiff/2,posLetter:\"x\",valLetter:\"y\"}),r._numBoxes++,h):[{t:{empty:!0}}]}},{\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../ohlc/calc\":1134}],960:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../ohlc/ohlc_defaults\"),o=t(\"../scatter/period_defaults\"),s=t(\"./attributes\");function l(t,e,r,n){var a=r(n+\".line.color\");r(n+\".line.width\",e.line.width),r(n+\".fillcolor\",i.addOpacity(a,.5))}e.exports=function(t,e,r,i){function c(r,i){return n.coerce(t,e,s,r,i)}a(t,e,c,i)?(o(t,e,i,c,{x:!0}),c(\"line.width\"),l(t,e,c,\"increasing\"),l(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"whiskerwidth\"),i._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../ohlc/ohlc_defaults\":1138,\"../scatter/period_defaults\":1207,\"./attributes\":958}],961:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"candlestick\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\",\"candlestick\",\"boxLayout\"],meta:{},attributes:t(\"./attributes\"),layoutAttributes:t(\"../box/layout_attributes\"),supplyLayoutDefaults:t(\"../box/layout_defaults\").supplyLayoutDefaults,crossTraceCalc:t(\"../box/cross_trace_calc\").crossTraceCalc,supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"../box/plot\").plot,layerName:\"boxlayer\",style:t(\"../box/style\").style,hoverPoints:t(\"../ohlc/hover\").hoverPoints,selectPoints:t(\"../ohlc/select\")}},{\"../../plots/cartesian\":841,\"../box/cross_trace_calc\":948,\"../box/layout_attributes\":953,\"../box/layout_defaults\":954,\"../box/plot\":955,\"../box/style\":957,\"../ohlc/hover\":1136,\"../ohlc/select\":1140,\"./attributes\":958,\"./calc\":959,\"./defaults\":960}],962:[function(t,e,r){\"use strict\";var n=t(\"./axis_defaults\"),i=t(\"../../plot_api/plot_template\");e.exports=function(t,e,r,a,o){a(\"a\")||(a(\"da\"),a(\"a0\")),a(\"b\")||(a(\"db\"),a(\"b0\")),function(t,e,r,a){[\"aaxis\",\"baxis\"].forEach((function(o){var s=o.charAt(0),l=t[o]||{},c=i.newContainer(e,o),u={tickfont:\"x\",id:s+\"axis\",letter:s,font:e.font,name:o,data:t[s],calendar:e.calendar,dfltColor:a,bgColor:r.paper_bgcolor,autotypenumbersDflt:r.autotypenumbers,fullLayout:r};n(l,c,u),c._categories=c._categories||[],t[o]||\"-\"===l.type||(t[o]={type:l.type})}))}(t,e,r,o)}},{\"../../plot_api/plot_template\":817,\"./axis_defaults\":967}],963:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t){return function t(e,r){if(!n(e)||r>=10)return null;for(var i=1/0,a=-1/0,o=e.length,s=0;s<o;s++){var l=e[s];if(n(l)){var c=t(l,r+1);c&&(i=Math.min(c[0],i),a=Math.max(c[1],a))}else i=Math.min(l,i),a=Math.max(l,a)}return[i,a]}(t,0)}},{\"../../lib\":778}],964:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"./axis_attributes\"),a=t(\"../../components/color/attributes\"),o=n({editType:\"calc\"});o.family.dflt='\"Open Sans\", verdana, arial, sans-serif',o.size.dflt=12,o.color.dflt=a.defaultLine,e.exports={carpet:{valType:\"string\",editType:\"calc\"},x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},a:{valType:\"data_array\",editType:\"calc\"},a0:{valType:\"number\",dflt:0,editType:\"calc\"},da:{valType:\"number\",dflt:1,editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},b0:{valType:\"number\",dflt:0,editType:\"calc\"},db:{valType:\"number\",dflt:1,editType:\"calc\"},cheaterslope:{valType:\"number\",dflt:1,editType:\"calc\"},aaxis:i,baxis:i,font:o,color:{valType:\"color\",dflt:a.defaultLine,editType:\"plot\"},transforms:void 0}},{\"../../components/color/attributes\":642,\"../../plots/font_attributes\":856,\"./axis_attributes\":966}],965:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,i){var a,o,s,l,c,u,f,h,p,d,g,m,v,y=n(r)?\"a\":\"b\",x=(\"a\"===y?t.aaxis:t.baxis).smoothing,b=\"a\"===y?t.a2i:t.b2j,_=\"a\"===y?r:i,w=\"a\"===y?i:r,T=\"a\"===y?e.a.length:e.b.length,k=\"a\"===y?e.b.length:e.a.length,M=Math.floor(\"a\"===y?t.b2j(w):t.a2i(w)),A=\"a\"===y?function(e){return t.evalxy([],e,M)}:function(e){return t.evalxy([],M,e)};x&&(s=Math.max(0,Math.min(k-2,M)),l=M-s,o=\"a\"===y?function(e,r){return t.dxydi([],e,s,r,l)}:function(e,r){return t.dxydj([],s,e,l,r)});var S=b(_[0]),E=b(_[1]),C=S<E?1:-1,L=1e-8*(E-S),I=C>0?Math.floor:Math.ceil,P=C>0?Math.ceil:Math.floor,z=C>0?Math.min:Math.max,O=C>0?Math.max:Math.min,D=I(S+L),R=P(E-L),F=[[f=A(S)]];for(a=D;a*C<R*C;a+=C)c=[],g=O(S,a),v=(m=z(E,a+C))-g,u=Math.max(0,Math.min(T-2,Math.floor(.5*(g+m)))),h=A(m),x&&(p=o(u,g-u),d=o(u,m-u),c.push([f[0]+p[0]/3*v,f[1]+p[1]/3*v]),c.push([h[0]-d[0]/3*v,h[1]-d[1]/3*v])),c.push(h),F.push(c),f=h;return F}},{\"../../lib\":778}],966:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../components/color/attributes\"),a=t(\"../../plots/cartesian/layout_attributes\"),o=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK,t(\"../../constants/docs\").TIME_FORMAT_LINK;e.exports={color:{valType:\"color\",editType:\"calc\"},smoothing:{valType:\"number\",dflt:1,min:0,max:1.3,editType:\"calc\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"calc\"},font:n({editType:\"calc\"}),offset:{valType:\"number\",dflt:10,editType:\"calc\"},editType:\"calc\"},type:{valType:\"enumerated\",values:[\"-\",\"linear\",\"date\",\"category\"],dflt:\"-\",editType:\"calc\"},autotypenumbers:a.autotypenumbers,autorange:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],dflt:!0,editType:\"calc\"},rangemode:{valType:\"enumerated\",values:[\"normal\",\"tozero\",\"nonnegative\"],dflt:\"normal\",editType:\"calc\"},range:{valType:\"info_array\",editType:\"calc\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}]},fixedrange:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cheatertype:{valType:\"enumerated\",values:[\"index\",\"value\"],dflt:\"value\",editType:\"calc\"},tickmode:{valType:\"enumerated\",values:[\"linear\",\"array\"],dflt:\"array\",editType:\"calc\"},nticks:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},tickvals:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},showticklabels:{valType:\"enumerated\",values:[\"start\",\"end\",\"both\",\"none\"],dflt:\"start\",editType:\"calc\"},tickfont:n({editType:\"calc\"}),tickangle:{valType:\"angle\",dflt:\"auto\",editType:\"calc\"},tickprefix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showtickprefix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},ticksuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showticksuffix:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},showexponent:{valType:\"enumerated\",values:[\"all\",\"first\",\"last\",\"none\"],dflt:\"all\",editType:\"calc\"},exponentformat:{valType:\"enumerated\",values:[\"none\",\"e\",\"E\",\"power\",\"SI\",\"B\"],dflt:\"B\",editType:\"calc\"},minexponent:{valType:\"number\",dflt:3,min:0,editType:\"calc\"},separatethousands:{valType:\"boolean\",dflt:!1,editType:\"calc\"},tickformat:{valType:\"string\",dflt:\"\",editType:\"calc\"},tickformatstops:o(a.tickformatstops,\"calc\",\"from-root\"),categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},labelpadding:{valType:\"integer\",dflt:10,editType:\"calc\"},labelprefix:{valType:\"string\",editType:\"calc\"},labelsuffix:{valType:\"string\",dflt:\"\",editType:\"calc\"},showline:{valType:\"boolean\",dflt:!1,editType:\"calc\"},linecolor:{valType:\"color\",dflt:i.defaultLine,editType:\"calc\"},linewidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},gridcolor:{valType:\"color\",editType:\"calc\"},gridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},showgrid:{valType:\"boolean\",dflt:!0,editType:\"calc\"},minorgridcount:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},minorgridwidth:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},minorgridcolor:{valType:\"color\",dflt:i.lightLine,editType:\"calc\"},startline:{valType:\"boolean\",editType:\"calc\"},startlinecolor:{valType:\"color\",editType:\"calc\"},startlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endline:{valType:\"boolean\",editType:\"calc\"},endlinewidth:{valType:\"number\",dflt:1,editType:\"calc\"},endlinecolor:{valType:\"color\",editType:\"calc\"},tick0:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},dtick:{valType:\"number\",min:0,dflt:1,editType:\"calc\"},arraytick0:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},arraydtick:{valType:\"integer\",min:1,dflt:1,editType:\"calc\"},_deprecated:{title:{valType:\"string\",editType:\"calc\"},titlefont:n({editType:\"calc\"}),titleoffset:{valType:\"number\",dflt:10,editType:\"calc\"}},editType:\"calc\"}},{\"../../components/color/attributes\":642,\"../../constants/docs\":748,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/font_attributes\":856}],967:[function(t,e,r){\"use strict\";var n=t(\"./attributes\"),i=t(\"../../components/color\").addOpacity,a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../plots/cartesian/tick_value_defaults\"),l=t(\"../../plots/cartesian/tick_label_defaults\"),c=t(\"../../plots/cartesian/category_order_defaults\"),u=t(\"../../plots/cartesian/set_convert\"),f=t(\"../../plots/cartesian/axis_autotype\");e.exports=function(t,e,r){var h=r.letter,p=r.font||{},d=n[h+\"axis\"];function g(r,n){return o.coerce(t,e,d,r,n)}function m(r,n){return o.coerce2(t,e,d,r,n)}r.name&&(e._name=r.name,e._id=r.name),g(\"autotypenumbers\",r.autotypenumbersDflt);var v=g(\"type\");(\"-\"===v&&(r.data&&function(t,e){if(\"-\"!==t.type)return;var r=t._id.charAt(0),n=t[r+\"calendar\"];t.type=f(e,n,{autotypenumbers:t.autotypenumbers})}(e,r.data),\"-\"===e.type?e.type=\"linear\":v=t.type=e.type),g(\"smoothing\"),g(\"cheatertype\"),g(\"showticklabels\"),g(\"labelprefix\",h+\" = \"),g(\"labelsuffix\"),g(\"showtickprefix\"),g(\"showticksuffix\"),g(\"separatethousands\"),g(\"tickformat\"),g(\"exponentformat\"),g(\"minexponent\"),g(\"showexponent\"),g(\"categoryorder\"),g(\"tickmode\"),g(\"tickvals\"),g(\"ticktext\"),g(\"tick0\"),g(\"dtick\"),\"array\"===e.tickmode&&(g(\"arraytick0\"),g(\"arraydtick\")),g(\"labelpadding\"),e._hovertitle=h,\"date\"===v)&&a.getComponentMethod(\"calendars\",\"handleDefaults\")(t,e,\"calendar\",r.calendar);u(e,r.fullLayout),e.c2p=o.identity;var y=g(\"color\",r.dfltColor),x=y===t.color?y:p.color;g(\"title.text\")&&(o.coerceFont(g,\"title.font\",{family:p.family,size:Math.round(1.2*p.size),color:x}),g(\"title.offset\")),g(\"tickangle\"),g(\"autorange\",!e.isValidRange(t.range))&&g(\"rangemode\"),g(\"range\"),e.cleanRange(),g(\"fixedrange\"),s(t,e,g,v),l(t,e,g,v,r),c(t,e,g,{data:r.data,dataAttr:h});var b=m(\"gridcolor\",i(y,.3)),_=m(\"gridwidth\"),w=g(\"showgrid\");w||(delete e.gridcolor,delete e.gridwidth);var T=m(\"startlinecolor\",y),k=m(\"startlinewidth\",_);g(\"startline\",e.showgrid||!!T||!!k)||(delete e.startlinecolor,delete e.startlinewidth);var M=m(\"endlinecolor\",y),A=m(\"endlinewidth\",_);return g(\"endline\",e.showgrid||!!M||!!A)||(delete e.endlinecolor,delete e.endlinewidth),w?(g(\"minorgridcount\"),g(\"minorgridwidth\",_),g(\"minorgridcolor\",i(b,.06)),e.minorgridcount||(delete e.minorgridwidth,delete e.minorgridcolor)):(delete e.gridcolor,delete e.gridWidth),\"none\"===e.showticklabels&&(delete e.tickfont,delete e.tickangle,delete e.showexponent,delete e.exponentformat,delete e.minexponent,delete e.tickformat,delete e.showticksuffix,delete e.showtickprefix),e.showticksuffix||delete e.ticksuffix,e.showtickprefix||delete e.tickprefix,g(\"tickmode\"),e}},{\"../../components/color\":643,\"../../lib\":778,\"../../plots/cartesian/axis_autotype\":829,\"../../plots/cartesian/category_order_defaults\":832,\"../../plots/cartesian/set_convert\":848,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_value_defaults\":851,\"../../registry\":911,\"./attributes\":964}],968:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\").isArray1D,a=t(\"./cheater_basis\"),o=t(\"./array_minmax\"),s=t(\"./calc_gridlines\"),l=t(\"./calc_labels\"),c=t(\"./calc_clippath\"),u=t(\"../heatmap/clean_2d_array\"),f=t(\"./smooth_fill_2d_array\"),h=t(\"../heatmap/convert_column_xyz\"),p=t(\"./set_convert\");e.exports=function(t,e){var r=n.getFromId(t,e.xaxis),d=n.getFromId(t,e.yaxis),g=e.aaxis,m=e.baxis,v=e.x,y=e.y,x=[];v&&i(v)&&x.push(\"x\"),y&&i(y)&&x.push(\"y\"),x.length&&h(e,g,m,\"a\",\"b\",x);var b=e._a=e._a||e.a,_=e._b=e._b||e.b;v=e._x||e.x,y=e._y||e.y;var w={};if(e._cheater){var T=\"index\"===g.cheatertype?b.length:b,k=\"index\"===m.cheatertype?_.length:_;v=a(T,k,e.cheaterslope)}e._x=v=u(v),e._y=y=u(y),f(v,b,_),f(y,b,_),p(e),e.setScale();var M=o(v),A=o(y),S=.5*(M[1]-M[0]),E=.5*(M[1]+M[0]),C=.5*(A[1]-A[0]),L=.5*(A[1]+A[0]);return M=[E-1.3*S,E+1.3*S],A=[L-1.3*C,L+1.3*C],e._extremes[r._id]=n.findExtremes(r,M,{padded:!0}),e._extremes[d._id]=n.findExtremes(d,A,{padded:!0}),s(e,\"a\",\"b\"),s(e,\"b\",\"a\"),l(e,g),l(e,m),w.clipsegments=c(e._xctrl,e._yctrl,g,m),w.x=v,w.y=y,w.a=b,w.b=_,[w]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"./array_minmax\":963,\"./calc_clippath\":969,\"./calc_gridlines\":970,\"./calc_labels\":971,\"./cheater_basis\":973,\"./set_convert\":986,\"./smooth_fill_2d_array\":987}],969:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a,o,s=[],l=!!r.smoothing,c=!!n.smoothing,u=t[0].length-1,f=t.length-1;for(i=0,a=[],o=[];i<=u;i++)a[i]=t[0][i],o[i]=e[0][i];for(s.push({x:a,y:o,bicubic:l}),i=0,a=[],o=[];i<=f;i++)a[i]=t[i][u],o[i]=e[i][u];for(s.push({x:a,y:o,bicubic:c}),i=u,a=[],o=[];i>=0;i--)a[u-i]=t[f][i],o[u-i]=e[f][i];for(s.push({x:a,y:o,bicubic:l}),i=f,a=[],o=[];i>=0;i--)a[f-i]=t[i][0],o[f-i]=e[i][0];return s.push({x:a,y:o,bicubic:c}),s}},{}],970:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e,r){var a,o,s,l,c,u,f,h,p,d,g,m,v,y,x=t[\"_\"+e],b=t[e+\"axis\"],_=b._gridlines=[],w=b._minorgridlines=[],T=b._boundarylines=[],k=t[\"_\"+r],M=t[r+\"axis\"];\"array\"===b.tickmode&&(b.tickvals=x.slice());var A=t._xctrl,S=t._yctrl,E=A[0].length,C=A.length,L=t._a.length,I=t._b.length;n.prepTicks(b),\"array\"===b.tickmode&&delete b.tickvals;var P=b.smoothing?3:1;function z(n){var i,a,o,s,l,c,u,f,p,d,g,m,v=[],y=[],x={};if(\"b\"===e)for(a=t.b2j(n),o=Math.floor(Math.max(0,Math.min(I-2,a))),s=a-o,x.length=I,x.crossLength=L,x.xy=function(e){return t.evalxy([],e,a)},x.dxy=function(e,r){return t.dxydi([],e,o,r,s)},i=0;i<L;i++)c=Math.min(L-2,i),u=i-c,f=t.evalxy([],i,a),M.smoothing&&i>0&&(p=t.dxydi([],i-1,o,0,s),v.push(l[0]+p[0]/3),y.push(l[1]+p[1]/3),d=t.dxydi([],i-1,o,1,s),v.push(f[0]-d[0]/3),y.push(f[1]-d[1]/3)),v.push(f[0]),y.push(f[1]),l=f;else for(i=t.a2i(n),c=Math.floor(Math.max(0,Math.min(L-2,i))),u=i-c,x.length=L,x.crossLength=I,x.xy=function(e){return t.evalxy([],i,e)},x.dxy=function(e,r){return t.dxydj([],c,e,u,r)},a=0;a<I;a++)o=Math.min(I-2,a),s=a-o,f=t.evalxy([],i,a),M.smoothing&&a>0&&(g=t.dxydj([],c,a-1,u,0),v.push(l[0]+g[0]/3),y.push(l[1]+g[1]/3),m=t.dxydj([],c,a-1,u,1),v.push(f[0]-m[0]/3),y.push(f[1]-m[1]/3)),v.push(f[0]),y.push(f[1]),l=f;return x.axisLetter=e,x.axis=b,x.crossAxis=M,x.value=n,x.constvar=r,x.index=h,x.x=v,x.y=y,x.smoothing=M.smoothing,x}function O(n){var i,a,o,s,l,c=[],u=[],f={};if(f.length=x.length,f.crossLength=k.length,\"b\"===e)for(o=Math.max(0,Math.min(I-2,n)),l=Math.min(1,Math.max(0,n-o)),f.xy=function(e){return t.evalxy([],e,n)},f.dxy=function(e,r){return t.dxydi([],e,o,r,l)},i=0;i<E;i++)c[i]=A[n*P][i],u[i]=S[n*P][i];else for(a=Math.max(0,Math.min(L-2,n)),s=Math.min(1,Math.max(0,n-a)),f.xy=function(e){return t.evalxy([],n,e)},f.dxy=function(e,r){return t.dxydj([],a,e,s,r)},i=0;i<C;i++)c[i]=A[i][n*P],u[i]=S[i][n*P];return f.axisLetter=e,f.axis=b,f.crossAxis=M,f.value=x[n],f.constvar=r,f.index=n,f.x=c,f.y=u,f.smoothing=M.smoothing,f}if(\"array\"===b.tickmode){for(l=5e-15,u=(c=[Math.floor((x.length-1-b.arraytick0)/b.arraydtick*(1+l)),Math.ceil(-b.arraytick0/b.arraydtick/(1+l))].sort((function(t,e){return t-e})))[0]-1,f=c[1]+1,h=u;h<f;h++)(o=b.arraytick0+b.arraydtick*h)<0||o>x.length-1||_.push(i(O(o),{color:b.gridcolor,width:b.gridwidth}));for(h=u;h<f;h++)if(s=b.arraytick0+b.arraydtick*h,g=Math.min(s+b.arraydtick,x.length-1),!(s<0||s>x.length-1||g<0||g>x.length-1))for(m=x[s],v=x[g],a=0;a<b.minorgridcount;a++)(y=g-s)<=0||(d=m+(v-m)*(a+1)/(b.minorgridcount+1)*(b.arraydtick/y))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(O(0),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(O(x.length-1),{color:b.endlinecolor,width:b.endlinewidth}))}else{for(l=5e-15,u=(c=[Math.floor((x[x.length-1]-b.tick0)/b.dtick*(1+l)),Math.ceil((x[0]-b.tick0)/b.dtick/(1+l))].sort((function(t,e){return t-e})))[0],f=c[1],h=u;h<=f;h++)p=b.tick0+b.dtick*h,_.push(i(z(p),{color:b.gridcolor,width:b.gridwidth}));for(h=u-1;h<f+1;h++)for(p=b.tick0+b.dtick*h,a=0;a<b.minorgridcount;a++)(d=p+b.dtick*(a+1)/(b.minorgridcount+1))<x[0]||d>x[x.length-1]||w.push(i(z(d),{color:b.minorgridcolor,width:b.minorgridwidth}));b.startline&&T.push(i(z(x[0]),{color:b.startlinecolor,width:b.startlinewidth})),b.endline&&T.push(i(z(x[x.length-1]),{color:b.endlinecolor,width:b.endlinewidth}))}}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],971:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib/extend\").extendFlat;e.exports=function(t,e){var r,a,o,s=e._labels=[],l=e._gridlines;for(r=0;r<l.length;r++)o=l[r],-1!==[\"start\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{prefix:void 0,suffix:void 0,endAnchor:!0,xy:o.xy(0),dxy:o.dxy(0,0),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a)),-1!==[\"end\",\"both\"].indexOf(e.showticklabels)&&(a=n.tickText(e,o.value),i(a,{endAnchor:!1,xy:o.xy(o.crossLength-1),dxy:o.dxy(o.crossLength-2,1),axis:o.axis,length:o.crossAxis.length,font:o.axis.tickfont,isFirst:0===r,isLast:r===l.length-1}),s.push(a))}},{\"../../lib/extend\":768,\"../../plots/cartesian/axes\":828}],972:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=t[0]-e[0],a=t[1]-e[1],o=r[0]-e[0],s=r[1]-e[1],l=Math.pow(i*i+a*a,.25),c=Math.pow(o*o+s*s,.25),u=(c*c*i-l*l*o)*n,f=(c*c*a-l*l*s)*n,h=c*(l+c)*3,p=l*(l+c)*3;return[[e[0]+(h&&u/h),e[1]+(h&&f/h)],[e[0]-(p&&u/p),e[1]-(p&&f/p)]]}},{}],973:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i,a,o,s,l,c,u=[],f=n(t)?t.length:t,h=n(e)?e.length:e,p=n(t)?t:null,d=n(e)?e:null;p&&(o=(p.length-1)/(p[p.length-1]-p[0])/(f-1)),d&&(s=(d.length-1)/(d[d.length-1]-d[0])/(h-1));var g=1/0,m=-1/0;for(a=0;a<h;a++)for(u[a]=[],l=d?(d[a]-d[0])*s:a/(h-1),i=0;i<f;i++)c=(p?(p[i]-p[0])*o:i/(f-1))-l*r,g=Math.min(c,g),m=Math.max(c,m),u[a][i]=c;var v=1/(m-g),y=-g*v;for(a=0;a<h;a++)for(i=0;i<f;i++)u[a][i]=v*u[a][i]+y;return u}},{\"../../lib\":778}],974:[function(t,e,r){\"use strict\";var n=t(\"./catmull_rom\"),i=t(\"../../lib\").ensureArray;function a(t,e,r){var n=-.5*r[0]+1.5*e[0],i=-.5*r[1]+1.5*e[1];return[(2*n+t[0])/3,(2*i+t[1])/3]}e.exports=function(t,e,r,o,s,l){var c,u,f,h,p,d,g,m,v,y,x=r[0].length,b=r.length,_=s?3*x-2:x,w=l?3*b-2:b;for(t=i(t,w),e=i(e,w),f=0;f<w;f++)t[f]=i(t[f],_),e[f]=i(e[f],_);for(u=0,h=0;u<b;u++,h+=l?3:1)for(p=t[h],d=e[h],g=r[u],m=o[u],c=0,f=0;c<x;c++,f+=s?3:1)p[f]=g[c],d[f]=m[c];if(s)for(u=0,h=0;u<b;u++,h+=l?3:1){for(c=1,f=3;c<x-1;c++,f+=3)v=n([r[u][c-1],o[u][c-1]],[r[u][c],o[u][c]],[r[u][c+1],o[u][c+1]],s),t[h][f-1]=v[0][0],e[h][f-1]=v[0][1],t[h][f+1]=v[1][0],e[h][f+1]=v[1][1];y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=y[0],e[h][1]=y[1],y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=y[0],e[h][_-2]=y[1]}if(l)for(f=0;f<_;f++){for(h=3;h<w-3;h+=3)v=n([t[h-3][f],e[h-3][f]],[t[h][f],e[h][f]],[t[h+3][f],e[h+3][f]],l),t[h-1][f]=v[0][0],e[h-1][f]=v[0][1],t[h+1][f]=v[1][0],e[h+1][f]=v[1][1];y=a([t[0][f],e[0][f]],[t[2][f],e[2][f]],[t[3][f],e[3][f]]),t[1][f]=y[0],e[1][f]=y[1],y=a([t[w-1][f],e[w-1][f]],[t[w-3][f],e[w-3][f]],[t[w-4][f],e[w-4][f]]),t[w-2][f]=y[0],e[w-2][f]=y[1]}if(s&&l)for(h=1;h<w;h+=(h+1)%3==0?2:1){for(f=3;f<_-3;f+=3)v=n([t[h][f-3],e[h][f-3]],[t[h][f],e[h][f]],[t[h][f+3],e[h][f+3]],s),t[h][f-1]=.5*(t[h][f-1]+v[0][0]),e[h][f-1]=.5*(e[h][f-1]+v[0][1]),t[h][f+1]=.5*(t[h][f+1]+v[1][0]),e[h][f+1]=.5*(e[h][f+1]+v[1][1]);y=a([t[h][0],e[h][0]],[t[h][2],e[h][2]],[t[h][3],e[h][3]]),t[h][1]=.5*(t[h][1]+y[0]),e[h][1]=.5*(e[h][1]+y[1]),y=a([t[h][_-1],e[h][_-1]],[t[h][_-3],e[h][_-3]],[t[h][_-4],e[h][_-4]]),t[h][_-2]=.5*(t[h][_-2]+y[0]),e[h][_-2]=.5*(e[h][_-2]+y[1])}return[t,e]}},{\"../../lib\":778,\"./catmull_rom\":972}],975:[function(t,e,r){\"use strict\";e.exports={RELATIVE_CULL_TOLERANCE:1e-6}},{}],976:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=1-i,d=p*p,g=p*i*2,m=-3*d,v=3*(d-g),y=3*(g-h),x=3*h,b=a*a,_=b*a,w=1-a,T=w*w,k=T*w;for(f=0;f<t.length;f++)o=m*(u=t[f])[n][r]+v*u[n][r+1]+y*u[n][r+2]+x*u[n][r+3],s=m*u[n+1][r]+v*u[n+1][r+1]+y*u[n+1][r+2]+x*u[n+1][r+3],l=m*u[n+2][r]+v*u[n+2][r+1]+y*u[n+2][r+2]+x*u[n+2][r+3],c=m*u[n+3][r]+v*u[n+3][r+1]+y*u[n+3][r+2]+x*u[n+3][r+3],e[f]=k*o+3*(T*a*s+w*b*l)+_*c;return e}:e?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),r*=3;var u=i*i,f=1-i,h=f*f,p=f*i*2,d=-3*h,g=3*(h-p),m=3*(p-u),v=3*u,y=1-a;for(l=0;l<t.length;l++)o=d*(c=t[l])[n][r]+g*c[n][r+1]+m*c[n][r+2]+v*c[n][r+3],s=d*c[n+1][r]+g*c[n+1][r+1]+m*c[n+1][r+2]+v*c[n+1][r+3],e[l]=y*o+a*s;return e}:r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),n*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n][r+1]-f[n][r],s=f[n+1][r+1]-f[n+1][r],l=f[n+2][r+1]-f[n+2][r],c=f[n+3][r+1]-f[n+3][r],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-a;for(l=0;l<t.length;l++)o=(c=t[l])[n][r+1]-c[n][r],s=c[n+1][r+1]-c[n+1][r],e[l]=u*o+a*s;return e}}},{}],977:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){return e&&r?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3,n*=3;var h=i*i,p=h*i,d=1-i,g=d*d,m=g*d,v=a*a,y=1-a,x=y*y,b=y*a*2,_=-3*x,w=3*(x-b),T=3*(b-v),k=3*v;for(f=0;f<t.length;f++)o=_*(u=t[f])[n][r]+w*u[n+1][r]+T*u[n+2][r]+k*u[n+3][r],s=_*u[n][r+1]+w*u[n+1][r+1]+T*u[n+2][r+1]+k*u[n+3][r+1],l=_*u[n][r+2]+w*u[n+1][r+2]+T*u[n+2][r+2]+k*u[n+3][r+2],c=_*u[n][r+3]+w*u[n+1][r+3]+T*u[n+2][r+3]+k*u[n+3][r+3],e[f]=m*o+3*(g*i*s+d*h*l)+p*c;return e}:e?function(e,r,n,i,a){var o,s,l,c,u,f;e||(e=[]),r*=3;var h=a*a,p=h*a,d=1-a,g=d*d,m=g*d;for(u=0;u<t.length;u++)o=(f=t[u])[n+1][r]-f[n][r],s=f[n+1][r+1]-f[n][r+1],l=f[n+1][r+2]-f[n][r+2],c=f[n+1][r+3]-f[n][r+3],e[u]=m*o+3*(g*a*s+d*h*l)+p*c;return e}:r?function(e,r,n,i,a){var o,s,l,c;e||(e=[]),n*=3;var u=1-i,f=a*a,h=1-a,p=h*h,d=h*a*2,g=-3*p,m=3*(p-d),v=3*(d-f),y=3*f;for(l=0;l<t.length;l++)o=g*(c=t[l])[n][r]+m*c[n+1][r]+v*c[n+2][r]+y*c[n+3][r],s=g*c[n][r+1]+m*c[n+1][r+1]+v*c[n+2][r+1]+y*c[n+3][r+1],e[l]=u*o+i*s;return e}:function(e,r,n,i,a){var o,s,l,c;e||(e=[]);var u=1-i;for(l=0;l<t.length;l++)o=(c=t[l])[n+1][r]-c[n][r],s=c[n+1][r+1]-c[n][r+1],e[l]=u*o+i*s;return e}}},{}],978:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=e-2,o=r-2;return n&&i?function(e,r,n){var i,s,l,c,u,f;e||(e=[]);var h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3,p*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=g*g,w=_*g,T=1-g,k=T*T,M=k*T;for(f=0;f<t.length;f++)i=b*(u=t[f])[p][h]+3*(x*d*u[p][h+1]+y*m*u[p][h+2])+v*u[p][h+3],s=b*u[p+1][h]+3*(x*d*u[p+1][h+1]+y*m*u[p+1][h+2])+v*u[p+1][h+3],l=b*u[p+2][h]+3*(x*d*u[p+2][h+1]+y*m*u[p+2][h+2])+v*u[p+2][h+3],c=b*u[p+3][h]+3*(x*d*u[p+3][h+1]+y*m*u[p+3][h+2])+v*u[p+3][h+3],e[f]=M*i+3*(k*g*s+T*_*l)+w*c;return e}:n?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));h*=3;var m=d*d,v=m*d,y=1-d,x=y*y,b=x*y,_=1-g;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+g*f[p+1][h],s=_*f[p][h+1]+g*f[p+1][h+1],l=_*f[p][h+2]+g*f[p+1][h+1],c=_*f[p][h+3]+g*f[p+1][h+1],e[u]=b*i+3*(x*d*s+y*m*l)+v*c;return e}:i?function(e,r,n){e||(e=[]);var i,s,l,c,u,f,h=Math.max(0,Math.min(Math.floor(r),a)),p=Math.max(0,Math.min(Math.floor(n),o)),d=Math.max(0,Math.min(1,r-h)),g=Math.max(0,Math.min(1,n-p));p*=3;var m=g*g,v=m*g,y=1-g,x=y*y,b=x*y,_=1-d;for(u=0;u<t.length;u++)i=_*(f=t[u])[p][h]+d*f[p][h+1],s=_*f[p+1][h]+d*f[p+1][h+1],l=_*f[p+2][h]+d*f[p+2][h+1],c=_*f[p+3][h]+d*f[p+3][h+1],e[u]=b*i+3*(x*g*s+y*m*l)+v*c;return e}:function(e,r,n){e||(e=[]);var i,s,l,c,u=Math.max(0,Math.min(Math.floor(r),a)),f=Math.max(0,Math.min(Math.floor(n),o)),h=Math.max(0,Math.min(1,r-u)),p=Math.max(0,Math.min(1,n-f)),d=1-p,g=1-h;for(l=0;l<t.length;l++)i=g*(c=t[l])[f][u]+h*c[f][u+1],s=g*c[f+1][u]+h*c[f+1][u+1],e[l]=d*i+p*s;return e}}},{}],979:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xy_defaults\"),a=t(\"./ab_defaults\"),o=t(\"./attributes\"),s=t(\"../../components/color/attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}e._clipPathId=\"clip\"+e.uid+\"carpet\";var u=c(\"color\",s.defaultLine);(n.coerceFont(c,\"font\"),c(\"carpet\"),a(t,e,l,c,u),e.a&&e.b)?(e.a.length<3&&(e.aaxis.smoothing=0),e.b.length<3&&(e.baxis.smoothing=0),i(t,e,c)||(e.visible=!1),e._cheater&&c(\"cheaterslope\")):e.visible=!1}},{\"../../components/color/attributes\":642,\"../../lib\":778,\"./ab_defaults\":962,\"./attributes\":964,\"./xy_defaults\":988}],980:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),plot:t(\"./plot\"),calc:t(\"./calc\"),animatable:!0,isContainer:!0,moduleType:\"trace\",name:\"carpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"carpetAxis\",\"notLegendIsolatable\",\"noMultiCategory\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":964,\"./calc\":968,\"./defaults\":979,\"./plot\":985}],981:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r,n=t._fullData.length,i=0;i<n;i++){var a=t._fullData[i];if(a.index!==e.index&&(\"carpet\"===a.type&&(r||(r=a),a.carpet===e.carpet)))return a}return r}},{}],982:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){if(0===t.length)return\"\";var n,i=[],a=r?3:1;for(n=0;n<t.length;n+=a)i.push(t[n]+\",\"+e[n]),r&&n<t.length-a&&(i.push(\"C\"),i.push([t[n+1]+\",\"+e[n+1],t[n+2]+\",\"+e[n+2]+\" \"].join(\" \")));return i.join(r?\"\":\"L\")}},{}],983:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r){var i;for(n(t)?t.length>e.length&&(t=t.slice(0,e.length)):t=[],i=0;i<e.length;i++)t[i]=r(e[i]);return t}},{\"../../lib\":778}],984:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i,a){var o=i[0]*t.dpdx(e),s=i[1]*t.dpdy(r),l=1,c=1;if(a){var u=Math.sqrt(i[0]*i[0]+i[1]*i[1]),f=Math.sqrt(a[0]*a[0]+a[1]*a[1]),h=(i[0]*a[0]+i[1]*a[1])/u/f;c=Math.max(0,h)}var p=180*Math.atan2(s,o)/Math.PI;return p<-90?(p+=180,l=-l):p>90&&(p-=180,l=-l),{angle:p,flip:l,p:t.c2p(n,e,r),offsetMultplier:c}}},{}],985:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"./map_1d_array\"),o=t(\"./makepath\"),s=t(\"./orient_text\"),l=t(\"../../lib/svg_text_utils\"),c=t(\"../../lib\"),u=c.strRotate,f=c.strTranslate,h=t(\"../../constants/alignment\");function p(t,e,r,i,s,l){var c=\"const-\"+s+\"-lines\",u=r.selectAll(\".\"+c).data(l);u.enter().append(\"path\").classed(c,!0).style(\"vector-effect\",\"non-scaling-stroke\"),u.each((function(r){var i=r,s=i.x,l=i.y,c=a([],s,t.c2p),u=a([],l,e.c2p),f=\"M\"+o(c,u,i.smoothing);n.select(this).attr(\"d\",f).style(\"stroke-width\",i.width).style(\"stroke\",i.color).style(\"fill\",\"none\")})),u.exit().remove()}function d(t,e,r,a,o,c,h,p){var d=c.selectAll(\"text.\"+p).data(h);d.enter().append(\"text\").classed(p,!0);var g=0,m={};return d.each((function(o,c){var h;if(\"auto\"===o.axis.tickangle)h=s(a,e,r,o.xy,o.dxy);else{var p=(o.axis.tickangle+180)*Math.PI/180;h=s(a,e,r,o.xy,[Math.cos(p),Math.sin(p)])}c||(m={angle:h.angle,flip:h.flip});var d=(o.endAnchor?-1:1)*h.flip,v=n.select(this).attr({\"text-anchor\":d>0?\"start\":\"end\",\"data-notex\":1}).call(i.font,o.font).text(o.text).call(l.convertToTspans,t),y=i.bBox(this);v.attr(\"transform\",f(h.p[0],h.p[1])+u(h.angle)+f(o.axis.labelpadding*d,.3*y.height)),g=Math.max(g,y.width+o.axis.labelpadding)})),d.exit().remove(),m.maxExtent=g,m}e.exports=function(t,e,r,i){var l=e.xaxis,u=e.yaxis,f=t._fullLayout._clips;c.makeTraceGroups(i,r,\"trace\").each((function(e){var r=n.select(this),i=e[0],h=i.trace,g=h.aaxis,m=h.baxis,y=c.ensureSingle(r,\"g\",\"minorlayer\"),x=c.ensureSingle(r,\"g\",\"majorlayer\"),b=c.ensureSingle(r,\"g\",\"boundarylayer\"),_=c.ensureSingle(r,\"g\",\"labellayer\");r.style(\"opacity\",h.opacity),p(l,u,x,g,\"a\",g._gridlines),p(l,u,x,m,\"b\",m._gridlines),p(l,u,y,g,\"a\",g._minorgridlines),p(l,u,y,m,\"b\",m._minorgridlines),p(l,u,b,g,\"a-boundary\",g._boundarylines),p(l,u,b,m,\"b-boundary\",m._boundarylines);var w=d(t,l,u,h,i,_,g._labels,\"a-label\"),T=d(t,l,u,h,i,_,m._labels,\"b-label\");!function(t,e,r,n,i,a,o,l){var u,f,h,p,d=c.aggNums(Math.min,null,r.a),g=c.aggNums(Math.max,null,r.a),m=c.aggNums(Math.min,null,r.b),y=c.aggNums(Math.max,null,r.b);u=.5*(d+g),f=m,h=r.ab2xy(u,f,!0),p=r.dxyda_rough(u,f),void 0===o.angle&&c.extendFlat(o,s(r,i,a,h,r.dxydb_rough(u,f)));v(t,e,r,n,h,p,r.aaxis,i,a,o,\"a-title\"),u=d,f=.5*(m+y),h=r.ab2xy(u,f,!0),p=r.dxydb_rough(u,f),void 0===l.angle&&c.extendFlat(l,s(r,i,a,h,r.dxyda_rough(u,f)));v(t,e,r,n,h,p,r.baxis,i,a,l,\"b-title\")}(t,_,h,i,l,u,w,T),function(t,e,r,n,i){var s,l,u,f,h=r.select(\"#\"+t._clipPathId);h.size()||(h=r.append(\"clipPath\").classed(\"carpetclip\",!0));var p=c.ensureSingle(h,\"path\",\"carpetboundary\"),d=e.clipsegments,g=[];for(f=0;f<d.length;f++)s=d[f],l=a([],s.x,n.c2p),u=a([],s.y,i.c2p),g.push(o(l,u,s.bicubic));var m=\"M\"+g.join(\"L\")+\"Z\";h.attr(\"id\",t._clipPathId),p.attr(\"d\",m)}(h,i,f,l,u)}))};var g=h.LINE_SPACING,m=(1-h.MID_SHIFT)/g+1;function v(t,e,r,a,o,c,h,p,d,v,y){var x=[];h.title.text&&x.push(h.title.text);var b=e.selectAll(\"text.\"+y).data(x),_=v.maxExtent;b.enter().append(\"text\").classed(y,!0),b.each((function(){var e=s(r,p,d,o,c);-1===[\"start\",\"both\"].indexOf(h.showticklabels)&&(_=0);var a=h.title.font.size;_+=a+h.title.offset;var y=(v.angle+(v.flip<0?180:0)-e.angle+450)%360,x=y>90&&y<270,b=n.select(this);b.text(h.title.text).call(l.convertToTspans,t),x&&(_=(-l.lineCount(b)+m)*g*a-_),b.attr(\"transform\",f(e.p[0],e.p[1])+u(e.angle)+f(0,_)).attr(\"text-anchor\",\"middle\").call(i.font,h.title.font)})),b.exit().remove()}},{\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"./makepath\":982,\"./map_1d_array\":983,\"./orient_text\":984,d3:169}],986:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/search\").findBin,a=t(\"./compute_control_points\"),o=t(\"./create_spline_evaluator\"),s=t(\"./create_i_derivative_evaluator\"),l=t(\"./create_j_derivative_evaluator\");e.exports=function(t){var e=t._a,r=t._b,c=e.length,u=r.length,f=t.aaxis,h=t.baxis,p=e[0],d=e[c-1],g=r[0],m=r[u-1],v=e[e.length-1]-e[0],y=r[r.length-1]-r[0],x=v*n.RELATIVE_CULL_TOLERANCE,b=y*n.RELATIVE_CULL_TOLERANCE;p-=x,d+=x,g-=b,m+=b,t.isVisible=function(t,e){return t>p&&t<d&&e>g&&e<m},t.isOccluded=function(t,e){return t<p||t>d||e<g||e>m},t.setScale=function(){var e=t._x,r=t._y,n=a(t._xctrl,t._yctrl,e,r,f.smoothing,h.smoothing);t._xctrl=n[0],t._yctrl=n[1],t.evalxy=o([t._xctrl,t._yctrl],c,u,f.smoothing,h.smoothing),t.dxydi=s([t._xctrl,t._yctrl],f.smoothing,h.smoothing),t.dxydj=l([t._xctrl,t._yctrl],f.smoothing,h.smoothing)},t.i2a=function(t){var r=Math.max(0,Math.floor(t[0]),c-2),n=t[0]-r;return(1-n)*e[r]+n*e[r+1]},t.j2b=function(t){var e=Math.max(0,Math.floor(t[1]),c-2),n=t[1]-e;return(1-n)*r[e]+n*r[e+1]},t.ij2ab=function(e){return[t.i2a(e[0]),t.j2b(e[1])]},t.a2i=function(t){var r=Math.max(0,Math.min(i(t,e),c-2)),n=e[r],a=e[r+1];return Math.max(0,Math.min(c-1,r+(t-n)/(a-n)))},t.b2j=function(t){var e=Math.max(0,Math.min(i(t,r),u-2)),n=r[e],a=r[e+1];return Math.max(0,Math.min(u-1,e+(t-n)/(a-n)))},t.ab2ij=function(e){return[t.a2i(e[0]),t.b2j(e[1])]},t.i2c=function(e,r){return t.evalxy([],e,r)},t.ab2xy=function(n,i,a){if(!a&&(n<e[0]||n>e[c-1]|i<r[0]||i>r[u-1]))return[!1,!1];var o=t.a2i(n),s=t.b2j(i),l=t.evalxy([],o,s);if(a){var f,h,p,d,g=0,m=0,v=[];n<e[0]?(f=0,h=0,g=(n-e[0])/(e[1]-e[0])):n>e[c-1]?(f=c-2,h=1,g=(n-e[c-1])/(e[c-1]-e[c-2])):h=o-(f=Math.max(0,Math.min(c-2,Math.floor(o)))),i<r[0]?(p=0,d=0,m=(i-r[0])/(r[1]-r[0])):i>r[u-1]?(p=u-2,d=1,m=(i-r[u-1])/(r[u-1]-r[u-2])):d=s-(p=Math.max(0,Math.min(u-2,Math.floor(s)))),g&&(t.dxydi(v,f,p,h,d),l[0]+=v[0]*g,l[1]+=v[1]*g),m&&(t.dxydj(v,f,p,h,d),l[0]+=v[0]*m,l[1]+=v[1]*m)}return l},t.c2p=function(t,e,r){return[e.c2p(t[0]),r.c2p(t[1])]},t.p2x=function(t,e,r){return[e.p2c(t[0]),r.p2c(t[1])]},t.dadi=function(t){var r=Math.max(0,Math.min(e.length-2,t));return e[r+1]-e[r]},t.dbdj=function(t){var e=Math.max(0,Math.min(r.length-2,t));return r[e+1]-r[e]},t.dxyda=function(e,r,n,i){var a=t.dxydi(null,e,r,n,i),o=t.dadi(e,n);return[a[0]/o,a[1]/o]},t.dxydb=function(e,r,n,i){var a=t.dxydj(null,e,r,n,i),o=t.dbdj(r,i);return[a[0]/o,a[1]/o]},t.dxyda_rough=function(e,r,n){var i=v*(n||.1),a=t.ab2xy(e+i,r,!0),o=t.ab2xy(e-i,r,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dxydb_rough=function(e,r,n){var i=y*(n||.1),a=t.ab2xy(e,r+i,!0),o=t.ab2xy(e,r-i,!0);return[.5*(a[0]-o[0])/i,.5*(a[1]-o[1])/i]},t.dpdx=function(t){return t._m},t.dpdy=function(t){return t._m}}},{\"../../lib/search\":798,\"./compute_control_points\":974,\"./constants\":975,\"./create_i_derivative_evaluator\":976,\"./create_j_derivative_evaluator\":977,\"./create_spline_evaluator\":978}],987:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r){var i,a,o,s=[],l=[],c=t[0].length,u=t.length;function f(e,r){var n,i=0,a=0;return e>0&&void 0!==(n=t[r][e-1])&&(a++,i+=n),e<c-1&&void 0!==(n=t[r][e+1])&&(a++,i+=n),r>0&&void 0!==(n=t[r-1][e])&&(a++,i+=n),r<u-1&&void 0!==(n=t[r+1][e])&&(a++,i+=n),i/Math.max(1,a)}var h,p,d,g,m,v,y,x,b,_,w,T=0;for(i=0;i<c;i++)for(a=0;a<u;a++)void 0===t[a][i]&&(s.push(i),l.push(a),t[a][i]=f(i,a)),T=Math.max(T,Math.abs(t[a][i]));if(!s.length)return t;var k=0,M=0,A=s.length;do{for(k=0,o=0;o<A;o++){i=s[o],a=l[o];var S,E,C,L,I,P,z=0,O=0;0===i?(C=e[I=Math.min(c-1,2)],L=e[1],S=t[a][I],O+=(E=t[a][1])+(E-S)*(e[0]-L)/(L-C),z++):i===c-1&&(C=e[I=Math.max(0,c-3)],L=e[c-2],S=t[a][I],O+=(E=t[a][c-2])+(E-S)*(e[c-1]-L)/(L-C),z++),(0===i||i===c-1)&&a>0&&a<u-1&&(h=r[a+1]-r[a],O+=((p=r[a]-r[a-1])*t[a+1][i]+h*t[a-1][i])/(p+h),z++),0===a?(C=r[P=Math.min(u-1,2)],L=r[1],S=t[P][i],O+=(E=t[1][i])+(E-S)*(r[0]-L)/(L-C),z++):a===u-1&&(C=r[P=Math.max(0,u-3)],L=r[u-2],S=t[P][i],O+=(E=t[u-2][i])+(E-S)*(r[u-1]-L)/(L-C),z++),(0===a||a===u-1)&&i>0&&i<c-1&&(h=e[i+1]-e[i],O+=((p=e[i]-e[i-1])*t[a][i+1]+h*t[a][i-1])/(p+h),z++),z?O/=z:(d=e[i+1]-e[i],g=e[i]-e[i-1],x=(m=r[a+1]-r[a])*(v=r[a]-r[a-1])*(m+v),O=((y=d*g*(d+g))*(v*t[a+1][i]+m*t[a-1][i])+x*(g*t[a][i+1]+d*t[a][i-1]))/(x*(g+d)+y*(v+m))),k+=(_=(b=O-t[a][i])/T)*_,w=z?0:.85,t[a][i]+=b*(1+w)}k=Math.sqrt(k)}while(M++<100&&k>1e-5);return n.log(\"Smoother converged to\",k,\"after\",M,\"iterations\"),t}},{\"../../lib\":778}],988:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArray1D;e.exports=function(t,e,r){var i=r(\"x\"),a=i&&i.length,o=r(\"y\"),s=o&&o.length;if(!a&&!s)return!1;if(e._cheater=!i,a&&!n(i)||s&&!n(o))e._length=null;else{var l=a?i.length:1/0;s&&(l=Math.min(l,o.length)),e.a&&e.a.length&&(l=Math.min(l,e.a.length)),e.b&&e.b.length&&(l=Math.min(l,e.b.length)),e._length=l}return!0}},{\"../../lib\":778}],989:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../scattergeo/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/color/attributes\").defaultLine,l=t(\"../../lib/extend\").extendFlat,c=i.marker.line;e.exports=l({locations:{valType:\"data_array\",editType:\"calc\"},locationmode:i.locationmode,z:{valType:\"data_array\",editType:\"calc\"},geojson:l({},i.geojson,{}),featureidkey:i.featureidkey,text:l({},i.text,{}),hovertext:l({},i.hovertext,{}),marker:{line:{color:l({},c.color,{dflt:s}),width:l({},c.width,{dflt:1}),editType:\"calc\"},opacity:{valType:\"number\",arrayOk:!0,min:0,max:1,dflt:1,editType:\"style\"},editType:\"calc\"},selected:{marker:{opacity:i.selected.marker.opacity,editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:i.unselected.marker.opacity,editType:\"plot\"},editType:\"plot\"},hoverinfo:l({},o.hoverinfo,{editType:\"calc\",flags:[\"location\",\"z\",\"text\",\"name\"]}),hovertemplate:n(),showlegend:l({},o.showlegend,{dflt:!1})},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattergeo/attributes\":1229}],990:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../components/colorscale/calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\");function l(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,c=e._length,u=new Array(c);r=e.geojson?function(t){return l(t)||n(t)}:l;for(var f=0;f<c;f++){var h=u[f]={},p=e.locations[f],d=e.z[f];r(p)&&n(d)?(h.loc=p,h.z=d):(h.loc=null,h.z=i),h.index=f}return o(u,e),a(t,e,{vals:e.z,containerStr:\"\",cLetter:\"z\"}),s(u,e),u}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"fast-isnumeric\":241}],991:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\");if(l&&l.length&&n.isArrayOrTypedArray(c)&&c.length){e._length=Math.min(l.length,c.length);var u,f=s(\"geojson\");(\"string\"==typeof f&&\"\"!==f||n.isPlainObject(f))&&(u=\"geojson-id\"),\"geojson-id\"===s(\"locationmode\",u)&&s(\"featureidkey\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)}else e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":989}],992:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.location=e.location,t.z=e.z;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t.ct=a.ct,t}},{}],993:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"./attributes\"),a=t(\"../../lib\").fillText;e.exports=function(t,e,r){var o,s,l,c,u=t.cd,f=u[0].trace,h=t.subplot,p=[e,r],d=[e+360,r];for(s=0;s<u.length;s++)if(c=!1,(o=u[s])._polygons){for(l=0;l<o._polygons.length;l++)o._polygons[l].contains(p)&&(c=!c),o._polygons[l].contains(d)&&(c=!c);if(c)break}if(c&&o)return t.x0=t.x1=t.xa.c2p(o.ct),t.y0=t.y1=t.ya.c2p(o.ct),t.index=o.index,t.location=o.loc,t.z=o.z,t.zLabel=n.tickText(h.mockAxis,h.mockAxis.c2l(o.z),\"hover\").text,t.hovertemplate=o.hovertemplate,function(t,e,r){if(e.hovertemplate)return;var n=r.hi||e.hoverinfo,o=String(r.loc),s=\"all\"===n?i.hoverinfo.flags:n.split(\"+\"),l=-1!==s.indexOf(\"name\"),c=-1!==s.indexOf(\"location\"),u=-1!==s.indexOf(\"z\"),f=-1!==s.indexOf(\"text\"),h=[];!l&&c?t.nameOverride=o:(l&&(t.nameOverride=e.name),c&&h.push(o));u&&h.push(t.zLabel);f&&a(r,e,h);t.extraText=h.join(\"<br>\")}(t,f,o),[t]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./attributes\":989}],994:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"choropleth\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"noOpacity\",\"showLegend\"],meta:{}}},{\"../../plots/geo\":860,\"../heatmap/colorbar\":1068,\"./attributes\":989,\"./calc\":990,\"./defaults\":991,\"./event_data\":992,\"./hover\":993,\"./plot\":995,\"./select\":996,\"./style\":997}],995:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/geo_location_utils\"),o=t(\"../../lib/topojson_utils\").getTopojsonFeatures,s=t(\"../../plots/cartesian/autorange\").findExtremes,l=t(\"./style\").style;e.exports={calcGeoJSON:function(t,e){for(var r=t[0].trace,n=e[r.geo],i=n._subplot,l=r.locationmode,c=r._length,u=\"geojson-id\"===l?a.extractTraceFeature(t):o(r,i.topojson),f=[],h=[],p=0;p<c;p++){var d=t[p],g=\"geojson-id\"===l?d.fOut:a.locationToFeature(l,d.loc,u);if(g){d.geojson=g,d.ct=g.properties.ct,d._polygons=a.feature2polygons(g);var m=a.computeBbox(g);f.push(m[0],m[2]),h.push(m[1],m[3])}else d.geojson=null}if(\"geojson\"===n.fitbounds&&\"geojson-id\"===l){var v=a.computeBbox(a.getTraceGeojson(r));f=[v[0],v[2]],h=[v[1],v[3]]}var y={padded:!0};r._extremes.lon=s(n.lonaxis._ax,f,y),r._extremes.lat=s(n.lataxis._ax,h,y)},plot:function(t,e,r){var a=e.layers.backplot.select(\".choroplethlayer\");i.makeTraceGroups(a,r,\"trace choropleth\").each((function(e){var r=n.select(this).selectAll(\"path.choroplethlocation\").data(i.identity);r.enter().append(\"path\").classed(\"choroplethlocation\",!0),r.exit().remove(),l(t,e)}))}}},{\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"./style\":997,d3:169}],996:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)(i=(n=s[r]).ct)&&(a=l.c2p(i),o=c.c2p(i),e.contains([a,o],null,r,t)?(u.push({pointNumber:r,lon:i[0],lat:i[1]}),n.selected=1):n.selected=0);return u}},{}],997:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\");function s(t,e){var r=e[0].trace,s=e[0].node3.selectAll(\".choroplethlocation\"),l=r.marker||{},c=l.line||{},u=o.makeColorScaleFuncFromTrace(r);s.each((function(t){n.select(this).attr(\"fill\",u(t.z)).call(i.stroke,t.mlc||c.color).call(a.dashLine,\"\",t.mlw||c.width||0).style(\"opacity\",l.opacity)})),a.selectedPointStyle(s,r,t)}e.exports={style:function(t,e){e&&s(t,e)},styleOnSelect:function(t,e){var r=e[0].node3,n=e[0].trace;n.selectedpoints?a.selectedPointStyle(r.selectAll(\".choroplethlocation\"),n,t):s(t,e)}}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../components/drawing\":665,d3:169}],998:[function(t,e,r){\"use strict\";var n=t(\"../choropleth/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({locations:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:s({},n.featureidkey,{}),below:{valType:\"string\",editType:\"plot\"},text:n.text,hovertext:n.hovertext,marker:{line:{color:s({},n.marker.line.color,{editType:\"plot\"}),width:s({},n.marker.line.width,{editType:\"plot\"}),editType:\"calc\"},opacity:s({},n.marker.opacity,{editType:\"plot\"}),editType:\"calc\"},selected:{marker:{opacity:s({},n.selected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},unselected:{marker:{opacity:s({},n.unselected.marker.opacity,{editType:\"plot\"}),editType:\"plot\"},editType:\"plot\"},hoverinfo:n.hoverinfo,hovertemplate:a({},{keys:[\"properties\"]}),showlegend:s({},o.showlegend,{dflt:!1})},i(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../choropleth/attributes\":989}],999:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/geojson_utils\").makeBlank,l=t(\"../../lib/geo_location_utils\");function c(t){var e,r=t[0].trace,n=r._opts;if(r.selectedpoints){for(var a=o.makeSelectedPointStyleFns(r),s=0;s<t.length;s++){var l=t[s];l.fOut&&(l.fOut.properties.mo2=a.selectedOpacityFn(l))}e={type:\"identity\",property:\"mo2\"}}else e=i.isArrayOrTypedArray(r.marker.opacity)?{type:\"identity\",property:\"mo\"}:r.marker.opacity;return i.extendFlat(n.fill.paint,{\"fill-opacity\":e}),i.extendFlat(n.line.paint,{\"line-opacity\":e}),n}e.exports={convert:function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,o={layout:{visibility:\"none\"},paint:{}},u={layout:{visibility:\"none\"},paint:{}},f=e._opts={fill:o,line:u,geojson:s()};if(!r)return f;var h=l.extractTraceFeature(t);if(!h)return f;var p,d,g,m=a.makeColorScaleFuncFromTrace(e),v=e.marker,y=v.line||{};i.isArrayOrTypedArray(v.opacity)&&(p=function(t){var e=t.mo;return n(e)?+i.constrain(e,0,1):0}),i.isArrayOrTypedArray(y.color)&&(d=function(t){return t.mlc}),i.isArrayOrTypedArray(y.width)&&(g=function(t){return t.mlw});for(var x=0;x<t.length;x++){var b=t[x],_=b.fOut;if(_){var w=_.properties;w.fc=m(b.z),p&&(w.mo=p(b)),d&&(w.mlc=d(b)),g&&(w.mlw=g(b)),b.ct=w.ct,b._polygons=l.feature2polygons(_)}}var T=p?{type:\"identity\",property:\"mo\"}:v.opacity;return i.extendFlat(o.paint,{\"fill-color\":{type:\"identity\",property:\"fc\"},\"fill-opacity\":T}),i.extendFlat(u.paint,{\"line-color\":d?{type:\"identity\",property:\"mlc\"}:y.color,\"line-width\":g?{type:\"identity\",property:\"mlw\"}:y.width,\"line-opacity\":T}),o.layout.visibility=\"visible\",u.layout.visibility=\"visible\",f.geojson={type:\"FeatureCollection\",features:h},c(t),f},convertOnSelect:c}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1e3:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"locations\"),c=s(\"z\"),u=s(\"geojson\");n.isArrayOrTypedArray(l)&&l.length&&n.isArrayOrTypedArray(c)&&c.length&&(\"string\"==typeof u&&\"\"!==u||n.isPlainObject(u))?(s(\"featureidkey\"),e._length=Math.min(l.length,c.length),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),s(\"marker.line.width\")&&s(\"marker.line.color\"),s(\"marker.opacity\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"}),n.coerceSelectionMarkerOpacity(e,s)):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":998}],1001:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../choropleth/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"../choropleth/hover\"),eventData:t(\"../choropleth/event_data\"),selectPoints:t(\"../choropleth/select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.updateOnSelect(e)},getBelow:function(t,e){for(var r=e.getMapLayers(),n=r.length-2;n>=0;n--){var i=r[n].id;if(\"string\"==typeof i&&0===i.indexOf(\"water\"))for(var a=n+1;a<r.length;a++)if(\"string\"==typeof(i=r[a].id)&&-1===i.indexOf(\"plotly-\"))return i}},moduleType:\"trace\",name:\"choroplethmapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"noOpacity\",\"showLegend\"],meta:{hr_name:\"choropleth_mapbox\"}}},{\"../../plots/mapbox\":885,\"../choropleth/calc\":990,\"../choropleth/event_data\":992,\"../choropleth/hover\":993,\"../choropleth/select\":996,\"../heatmap/colorbar\":1068,\"./attributes\":998,\"./defaults\":1e3,\"./plot\":1002}],1002:[function(t,e,r){\"use strict\";var n=t(\"./convert\").convert,i=t(\"./convert\").convertOnSelect,a=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function o(t,e){this.type=\"choroplethmapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"fill\",a+e+\"-fill\"],[\"line\",a+e+\"-line\"]],this.below=null}var s=o.prototype;s.update=function(t){this._update(n(t))},s.updateOnSelect=function(t){this._update(i(t))},s._update=function(t){var e=this.subplot,r=this.layerList,n=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(t.geojson),n!==this.below&&(this._removeLayers(),this._addLayers(t,n),this.below=n);for(var i=0;i<r.length;i++){var a=r[i],o=a[0],s=a[1],l=t[o];e.setOptions(s,\"setLayoutProperty\",l.layout),\"visible\"===l.layout.visibility&&e.setOptions(s,\"setPaintProperty\",l.paint)}},s._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},s._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},s.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new o(t,r.uid),a=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(a,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":999}],1003:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"scaled\",\"absolute\"],editType:\"calc\",dflt:\"scaled\"},sizeref:{valType:\"number\",editType:\"calc\",min:0},anchor:{valType:\"enumerated\",editType:\"calc\",values:[\"tip\",\"tail\",\"cm\",\"center\"],dflt:\"cm\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"norm\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1004:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){for(var r=e.u,i=e.v,a=e.w,o=Math.min(e.x.length,e.y.length,e.z.length,r.length,i.length,a.length),s=-1/0,l=1/0,c=0;c<o;c++){var u=r[c],f=i[c],h=a[c],p=Math.sqrt(u*u+f*f+h*h);s=Math.max(s,p),l=Math.min(l,p)}e._len=o,e._normMax=s,n(t,e,{vals:[l,s],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1005:[function(t,e,r){\"use strict\";var n=t(\"gl-cone3d\"),i=t(\"gl-cone3d\").createConeMesh,a=t(\"../../lib\").simpleMap,o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\");function c(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index,r=this.data.x[e],n=this.data.y[e],i=this.data.z[e],a=this.data.u[e],o=this.data.v[e],s=this.data.w[e];t.traceCoordinate=[r,n,i,a,o,s,Math.sqrt(a*a+o*o+s*s)];var l=this.data.hovertext||this.data.text;return Array.isArray(l)&&void 0!==l[e]?t.textLabel=l[e]:l&&(t.textLabel=l),!0}};var f={xaxis:0,yaxis:1,zaxis:2},h={tip:1,tail:0,cm:.25,center:.5},p={tip:1,tail:1,cm:.75,center:.5};function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,c={};function u(t,e){var n=r[e],o=i[f[e]];return a(t,(function(t){return n.d2l(t)*o}))}c.vectors=l(u(e.u,\"xaxis\"),u(e.v,\"yaxis\"),u(e.w,\"zaxis\"),e._len),c.positions=l(u(e.x,\"xaxis\"),u(e.y,\"yaxis\"),u(e.z,\"zaxis\"),e._len);var d=s(e);c.colormap=o(e),c.vertexIntensityBounds=[d.min/e._normMax,d.max/e._normMax],c.coneOffset=h[e.anchor],\"scaled\"===e.sizemode?c.coneSize=e.sizeref||.5:c.coneSize=e.sizeref&&e._normMax?e.sizeref/e._normMax:.5;var g=n(c),m=e.lightposition;return g.lightPosition=[m.x,m.y,m.z],g.ambient=e.lighting.ambient,g.diffuse=e.lighting.diffuse,g.specular=e.lighting.specular,g.roughness=e.lighting.roughness,g.fresnel=e.lighting.fresnel,g.opacity=e.opacity,e._pad=p[e.anchor]*g.vectorScale*g.coneScale*e._normMax,g}u.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new c(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-cone3d\":260}],1006:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"sizeref\"),s(\"sizemode\"),s(\"anchor\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1003}],1007:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"cone\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),eventData:function(t,e){return t.norm=e.traceCoordinate[6],t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1003,\"./calc\":1004,\"./convert\":1005,\"./defaults\":1006}],1008:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../components/drawing/attributes\").dash,s=t(\"../../plots/font_attributes\"),l=t(\"../../lib/extend\").extendFlat,c=t(\"../../constants/filter_ops\"),u=c.COMPARISON_OPS2,f=c.INTERVAL_OPS,h=(t(\"../../constants/docs\").FORMAT_LINK,i.line);e.exports=l({z:n.z,x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,text:n.text,hovertext:n.hovertext,transpose:n.transpose,xtype:n.xtype,ytype:n.ytype,zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate,hoverongaps:n.hoverongaps,connectgaps:l({},n.connectgaps,{}),fillcolor:{valType:\"color\",editType:\"calc\"},autocontour:{valType:\"boolean\",dflt:!0,editType:\"calc\",impliedEdits:{\"contours.start\":void 0,\"contours.end\":void 0,\"contours.size\":void 0}},ncontours:{valType:\"integer\",dflt:15,min:1,editType:\"calc\"},contours:{type:{valType:\"enumerated\",values:[\"levels\",\"constraint\"],dflt:\"levels\",editType:\"calc\"},start:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},end:{valType:\"number\",dflt:null,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\",impliedEdits:{\"^autocontour\":!1}},coloring:{valType:\"enumerated\",values:[\"fill\",\"heatmap\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:{valType:\"boolean\",dflt:!0,editType:\"plot\"},showlabels:{valType:\"boolean\",dflt:!1,editType:\"plot\"},labelfont:s({editType:\"plot\",colorEditType:\"style\"}),labelformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},operation:{valType:\"enumerated\",values:[].concat(u).concat(f),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:l({},h.color,{editType:\"style+colorbars\"}),width:{valType:\"number\",min:0,editType:\"style+colorbars\"},dash:o,smoothing:l({},h.smoothing,{}),editType:\"plot\"}},a(\"\",{cLetter:\"z\",autoColorDflt:!1,editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../constants/docs\":748,\"../../constants/filter_ops\":749,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../heatmap/attributes\":1065,\"../scatter/attributes\":1187}],1009:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"../heatmap/calc\"),a=t(\"./set_contours\"),o=t(\"./end_plus\");e.exports=function(t,e){var r=i(t,e),s=r[0].z;a(e,s);var l,c=e.contours,u=n.extractOpts(e);if(\"heatmap\"===c.coloring&&u.auto&&!1===e.autocontour){var f=c.start,h=o(c),p=c.size||1,d=Math.floor((h-f)/p)+1;isFinite(p)||(p=1,d=1);var g=f-p/2;l=[g,g+d*p]}else l=s;return n.calc(t,e,{vals:l,cLetter:\"z\"}),r}},{\"../../components/colorscale\":655,\"../heatmap/calc\":1066,\"./end_plus\":1019,\"./set_contours\":1027}],1010:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t[0],i=n.z;switch(e.type){case\"levels\":var a=Math.min(i[0][0],i[0][1]);for(r=0;r<t.length;r++){var o=t[r];o.prefixBoundary=!o.edgepaths.length&&(a>o.level||o.starts.length&&a===o.level)}break;case\"constraint\":if(n.prefixBoundary=!1,n.edgepaths.length)return;var s=n.x.length,l=n.y.length,c=-1/0,u=1/0;for(r=0;r<l;r++)u=Math.min(u,i[r][0]),u=Math.min(u,i[r][s-1]),c=Math.max(c,i[r][0]),c=Math.max(c,i[r][s-1]);for(r=1;r<s-1;r++)u=Math.min(u,i[0][r]),u=Math.min(u,i[l-1][r]),c=Math.max(c,i[0][r]),c=Math.max(c,i[l-1][r]);var f,h,p=e.value;switch(e._operation){case\">\":p>c&&(n.prefixBoundary=!0);break;case\"<\":(p<u||n.starts.length&&p===u)&&(n.prefixBoundary=!0);break;case\"[]\":f=Math.min(p[0],p[1]),((h=Math.max(p[0],p[1]))<u||f>c||n.starts.length&&h===u)&&(n.prefixBoundary=!0);break;case\"][\":f=Math.min(p[0],p[1]),h=Math.max(p[0],p[1]),f<u&&h>c&&(n.prefixBoundary=!0)}}}},{}],1011:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale\"),i=t(\"./make_color_map\"),a=t(\"./end_plus\");e.exports={min:\"zmin\",max:\"zmax\",calc:function(t,e,r){var o=e.contours,s=e.line,l=o.size||1,c=o.coloring,u=i(e,{isColorbar:!0});if(\"heatmap\"===c){var f=n.extractOpts(e);r._fillgradient=f.reversescale?n.flipScale(f.colorscale):f.colorscale,r._zrange=[f.min,f.max]}else\"fill\"===c&&(r._fillcolor=u);r._line={color:\"lines\"===c?u:s.color,width:!1!==o.showlines?s.width:0,dash:s.dash},r._levels={start:o.start,end:a(o),size:l}}}},{\"../../components/colorscale\":655,\"./end_plus\":1019,\"./make_color_map\":1024}],1012:[function(t,e,r){\"use strict\";e.exports={BOTTOMSTART:[1,9,13,104,713],TOPSTART:[4,6,7,104,713],LEFTSTART:[8,12,14,208,1114],RIGHTSTART:[2,3,11,208,1114],NEWDELTA:[null,[-1,0],[0,-1],[-1,0],[1,0],null,[0,-1],[-1,0],[0,1],[0,1],null,[0,1],[1,0],[1,0],[0,-1]],CHOOSESADDLE:{104:[4,1],208:[2,8],713:[7,13],1114:[11,14]},SADDLEREMAINDER:{1:4,2:8,4:1,7:13,8:2,11:14,13:7,14:11},LABELDISTANCE:2,LABELINCREASE:10,LABELMIN:3,LABELMAX:10,LABELOPTIMIZER:{EDGECOST:1,ANGLECOST:1,NEIGHBORCOST:5,SAMELEVELFACTOR:10,SAMELEVELDISTANCE:5,MAXCOST:100,INITIALSEARCHPOINTS:10,ITERATIONS:5}}},{}],1013:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"./label_defaults\"),a=t(\"../../components/color\"),o=a.addOpacity,s=a.opacity,l=t(\"../../constants/filter_ops\"),c=l.CONSTRAINT_REDUCTION,u=l.COMPARISON_OPS2;e.exports=function(t,e,r,a,l,f){var h,p,d,g=e.contours,m=r(\"contours.operation\");(g._operation=c[m],function(t,e){var r;-1===u.indexOf(e.operation)?(t(\"contours.value\",[0,1]),Array.isArray(e.value)?e.value.length>2?e.value=e.value.slice(2):0===e.length?e.value=[0,1]:e.length<2?(r=parseFloat(e.value[0]),e.value=[r,r+1]):e.value=[parseFloat(e.value[0]),parseFloat(e.value[1])]:n(e.value)&&(r=parseFloat(e.value),e.value=[r,r+1])):(t(\"contours.value\",0),n(e.value)||(Array.isArray(e.value)?e.value=parseFloat(e.value[0]):e.value=0))}(r,g),\"=\"===m?h=g.showlines=!0:(h=r(\"contours.showlines\"),d=r(\"fillcolor\",o((t.line||{}).color||l,.5))),h)&&(p=r(\"line.color\",d&&s(d)?o(e.fillcolor,1):l),r(\"line.width\",2),r(\"line.dash\"));r(\"line.smoothing\"),i(r,a,p,f)}},{\"../../components/color\":643,\"../../constants/filter_ops\":749,\"./label_defaults\":1023,\"fast-isnumeric\":241}],1014:[function(t,e,r){\"use strict\";var n=t(\"../../constants/filter_ops\"),i=t(\"fast-isnumeric\");function a(t,e){var r,a=Array.isArray(e);function o(t){return i(t)?+t:null}return-1!==n.COMPARISON_OPS2.indexOf(t)?r=o(a?e[0]:e):-1!==n.INTERVAL_OPS.indexOf(t)?r=a?[o(e[0]),o(e[1])]:[o(e),o(e)]:-1!==n.SET_OPS.indexOf(t)&&(r=a?e.map(o):[o(e)]),r}function o(t){return function(e){e=a(t,e);var r=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return{start:r,end:n,size:n-r}}}function s(t){return function(e){return{start:e=a(t,e),end:1/0,size:1/0}}}e.exports={\"[]\":o(\"[]\"),\"][\":o(\"][\"),\">\":s(\">\"),\"<\":s(\"<\"),\"=\":s(\"=\")}},{\"../../constants/filter_ops\":749,\"fast-isnumeric\":241}],1015:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i=n(\"contours.start\"),a=n(\"contours.end\"),o=!1===i||!1===a,s=r(\"contours.size\");!(o?e.autocontour=!0:r(\"autocontour\",!1))&&s||r(\"ncontours\")}},{}],1016:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return n.extendFlat({},t,{edgepaths:n.extendDeep([],t.edgepaths),paths:n.extendDeep([],t.paths),starts:n.extendDeep([],t.starts)})}e.exports=function(t,e){var r,a,o,s=function(t){return t.reverse()},l=function(t){return t};switch(e){case\"=\":case\"<\":return t;case\">\":for(1!==t.length&&n.warn(\"Contour data invalid for the specified inequality operation.\"),a=t[0],r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);return t;case\"][\":var c=s;s=l,l=c;case\"[]\":for(2!==t.length&&n.warn(\"Contour data invalid for the specified inequality range operation.\"),a=i(t[0]),o=i(t[1]),r=0;r<a.edgepaths.length;r++)a.edgepaths[r]=s(a.edgepaths[r]);for(r=0;r<a.paths.length;r++)a.paths[r]=s(a.paths[r]);for(r=0;r<a.starts.length;r++)a.starts[r]=s(a.starts[r]);for(;o.edgepaths.length;)a.edgepaths.push(l(o.edgepaths.shift()));for(;o.paths.length;)a.paths.push(l(o.paths.shift()));for(;o.starts.length;)a.starts.push(l(o.starts.shift()));return[a]}}},{\"../../lib\":778}],1017:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./constraint_defaults\"),s=t(\"./contours_defaults\"),l=t(\"./style_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(i(t,e,f,u)){a(t,e,u,f),f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"hoverongaps\");var h=\"constraint\"===f(\"contours.type\");f(\"connectgaps\",n.isArray1D(e.z)),h?o(t,e,f,u,r):(s(t,e,f,(function(r){return n.coerce2(t,e,c,r)})),l(t,e,f,u))}else e.visible=!1}},{\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"../scatter/period_defaults\":1207,\"./attributes\":1008,\"./constraint_defaults\":1013,\"./contours_defaults\":1015,\"./style_defaults\":1029}],1018:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constraint_mapping\"),a=t(\"./end_plus\");e.exports=function(t,e,r){for(var o=\"constraint\"===t.type?i[t._operation](t.value):t,s=o.size,l=[],c=a(o),u=r.trace._carpetTrace,f=u?{xaxis:u.aaxis,yaxis:u.baxis,x:r.a,y:r.b}:{xaxis:e.xaxis,yaxis:e.yaxis,x:r.x,y:r.y},h=o.start;h<c;h+=s)if(l.push(n.extendFlat({level:h,crossings:{},starts:[],edgepaths:[],paths:[],z:r.z,smoothing:r.trace.line.smoothing},f)),l.length>1e3){n.warn(\"Too many contours, clipping at 1000\",t);break}return l}},{\"../../lib\":778,\"./constraint_mapping\":1014,\"./end_plus\":1019}],1019:[function(t,e,r){\"use strict\";e.exports=function(t){return t.end+t.size/1e6}},{}],1020:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\");function a(t,e,r,n){return Math.abs(t[0]-e[0])<r&&Math.abs(t[1]-e[1])<n}function o(t,e,r,o,l){var c,u=e.join(\",\"),f=t.crossings[u],h=function(t,e,r){var n=0,a=0;t>20&&e?208===t||1114===t?n=0===r[0]?1:-1:a=0===r[1]?1:-1:-1!==i.BOTTOMSTART.indexOf(t)?a=1:-1!==i.LEFTSTART.indexOf(t)?n=1:-1!==i.TOPSTART.indexOf(t)?a=-1:n=-1;return[n,a]}(f,r,e),p=[s(t,e,[-h[0],-h[1]])],d=t.z.length,g=t.z[0].length,m=e.slice(),v=h.slice();for(c=0;c<1e4;c++){if(f>20?(f=i.CHOOSESADDLE[f][(h[0]||h[1])<0?0:1],t.crossings[u]=i.SADDLEREMAINDER[f]):delete t.crossings[u],!(h=i.NEWDELTA[f])){n.log(\"Found bad marching index:\",f,e,t.level);break}p.push(s(t,e,h)),e[0]+=h[0],e[1]+=h[1],u=e.join(\",\"),a(p[p.length-1],p[p.length-2],o,l)&&p.pop();var y=h[0]&&(e[0]<0||e[0]>g-2)||h[1]&&(e[1]<0||e[1]>d-2);if(e[0]===m[0]&&e[1]===m[1]&&h[0]===v[0]&&h[1]===v[1]||r&&y)break;f=t.crossings[u]}1e4===c&&n.log(\"Infinite loop in contour?\");var x,b,_,w,T,k,M,A,S,E,C,L,I,P,z,O=a(p[0],p[p.length-1],o,l),D=0,R=.2*t.smoothing,F=[],B=0;for(c=1;c<p.length;c++)L=p[c],I=p[c-1],P=void 0,z=void 0,P=L[2]-I[2],z=L[3]-I[3],D+=M=Math.sqrt(P*P+z*z),F.push(M);var N=D/F.length*R;function j(t){return p[t%p.length]}for(c=p.length-2;c>=B;c--)if((x=F[c])<N){for(_=0,b=c-1;b>=B&&x+F[b]<N;b--)x+=F[b];if(O&&c===p.length-2)for(_=0;_<b&&x+F[_]<N;_++)x+=F[_];T=c-b+_+1,k=Math.floor((c+b+_+2)/2),w=O||c!==p.length-2?O||-1!==b?T%2?j(k):[(j(k)[0]+j(k+1)[0])/2,(j(k)[1]+j(k+1)[1])/2]:p[0]:p[p.length-1],p.splice(b+1,c-b+1,w),c=b+1,_&&(B=_),O&&(c===p.length-2?p[_]=p[p.length-1]:0===c&&(p[p.length-1]=p[0]))}for(p.splice(0,B),c=0;c<p.length;c++)p[c].length=2;if(!(p.length<2))if(O)p.pop(),t.paths.push(p);else{r||n.log(\"Unclosed interior contour?\",t.level,m.join(\",\"),p.join(\"L\"));var U=!1;for(A=0;A<t.edgepaths.length;A++)if(E=t.edgepaths[A],!U&&a(E[0],p[p.length-1],o,l)){p.pop(),U=!0;var V=!1;for(S=0;S<t.edgepaths.length;S++)if(a((C=t.edgepaths[S])[C.length-1],p[0],o,l)){V=!0,p.shift(),t.edgepaths.splice(A,1),S===A?t.paths.push(p.concat(C)):(S>A&&S--,t.edgepaths[S]=C.concat(p,E));break}V||(t.edgepaths[A]=p.concat(E))}for(A=0;A<t.edgepaths.length&&!U;A++)a((E=t.edgepaths[A])[E.length-1],p[0],o,l)&&(p.shift(),t.edgepaths[A]=E.concat(p),U=!0);U||t.edgepaths.push(p)}}function s(t,e,r){var n=e[0]+Math.max(r[0],0),i=e[1]+Math.max(r[1],0),a=t.z[i][n],o=t.xaxis,s=t.yaxis;if(r[1]){var l=(t.level-a)/(t.z[i][n+1]-a);return[o.c2p((1-l)*t.x[n]+l*t.x[n+1],!0),s.c2p(t.y[i],!0),n+l,i]}var c=(t.level-a)/(t.z[i+1][n]-a);return[o.c2p(t.x[n],!0),s.c2p((1-c)*t.y[i]+c*t.y[i+1],!0),n,i+c]}e.exports=function(t,e,r){var i,a,s,l;for(e=e||.01,r=r||.01,a=0;a<t.length;a++){for(s=t[a],l=0;l<s.starts.length;l++)o(s,s.starts[l],\"edge\",e,r);for(i=0;Object.keys(s.crossings).length&&i<1e4;)i++,o(s,Object.keys(s.crossings)[0].split(\",\").map(Number),void 0,e,r);1e4===i&&n.log(\"Infinite loop in contour?\")}}},{\"../../lib\":778,\"./constants\":1012}],1021:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../heatmap/hover\");e.exports=function(t,e,r,a,o){var s=i(t,e,r,a,o,!0);return s&&s.forEach((function(t){var e=t.trace;\"constraint\"===e.contours.type&&(e.fillcolor&&n.opacity(e.fillcolor)?t.color=n.addOpacity(e.fillcolor,1):e.contours.showlines&&n.opacity(e.line.color)&&(t.color=n.addOpacity(e.line.color,1)))})),s}},{\"../../components/color\":643,\"../heatmap/hover\":1072}],1022:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\").plot,style:t(\"./style\"),colorbar:t(\"./colorbar\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"contour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1008,\"./calc\":1009,\"./colorbar\":1011,\"./defaults\":1017,\"./hover\":1021,\"./plot\":1026,\"./style\":1028}],1023:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i){if(i||(i={}),t(\"contours.showlabels\")){var a=e.font;n.coerceFont(t,\"contours.labelfont\",{family:a.family,size:a.size,color:r}),t(\"contours.labelformat\")}!1!==i.hasHover&&t(\"zhoverformat\")}},{\"../../lib\":778}],1024:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/colorscale\"),a=t(\"./end_plus\");e.exports=function(t){var e=t.contours,r=e.start,o=a(e),s=e.size||1,l=Math.floor((o-r)/s)+1,c=\"lines\"===e.coloring?0:1,u=i.extractOpts(t);isFinite(s)||(s=1,l=1);var f,h,p=u.reversescale?i.flipScale(u.colorscale):u.colorscale,d=p.length,g=new Array(d),m=new Array(d);if(\"heatmap\"===e.coloring){var v=u.min,y=u.max;for(h=0;h<d;h++)f=p[h],g[h]=f[0]*(y-v)+v,m[h]=f[1];var x=n.extent([v,y,e.start,e.start+s*(l-1)]),b=x[v<y?0:1],_=x[v<y?1:0];b!==v&&(g.splice(0,0,b),m.splice(0,0,m[0])),_!==y&&(g.push(_),m.push(m[m.length-1]))}else for(h=0;h<d;h++)f=p[h],g[h]=(f[0]*(l+c-1)-c/2)*s+r,m[h]=f[1];return i.makeColorScaleFunc({domain:g,range:m},{noNumericCheck:!0})}},{\"../../components/colorscale\":655,\"./end_plus\":1019,d3:169}],1025:[function(t,e,r){\"use strict\";var n=t(\"./constants\");function i(t,e){var r=(e[0][0]>t?0:1)+(e[0][1]>t?0:2)+(e[1][1]>t?0:4)+(e[1][0]>t?0:8);return 5===r||10===r?t>(e[0][0]+e[0][1]+e[1][0]+e[1][1])/4?5===r?713:1114:5===r?104:208:15===r?0:r}e.exports=function(t){var e,r,a,o,s,l,c,u,f,h=t[0].z,p=h.length,d=h[0].length,g=2===p||2===d;for(r=0;r<p-1;r++)for(o=[],0===r&&(o=o.concat(n.BOTTOMSTART)),r===p-2&&(o=o.concat(n.TOPSTART)),e=0;e<d-1;e++)for(a=o.slice(),0===e&&(a=a.concat(n.LEFTSTART)),e===d-2&&(a=a.concat(n.RIGHTSTART)),s=e+\",\"+r,l=[[h[r][e],h[r][e+1]],[h[r+1][e],h[r+1][e+1]]],f=0;f<t.length;f++)(c=i((u=t[f]).level,l))&&(u.crossings[s]=c,-1!==a.indexOf(c)&&(u.starts.push([e,r]),g&&-1!==a.indexOf(c,a.indexOf(c)+1)&&u.starts.push([e,r])))}},{\"./constants\":1012}],1026:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../components/colorscale\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"../../plots/cartesian/set_convert\"),u=t(\"../heatmap/plot\"),f=t(\"./make_crossings\"),h=t(\"./find_all_paths\"),p=t(\"./empty_pathinfo\"),d=t(\"./convert_to_constraints\"),g=t(\"./close_boundaries\"),m=t(\"./constants\"),v=m.LABELOPTIMIZER;function y(t,e){var r,n,o,s,l,c,u,f=\"\",h=0,p=t.edgepaths.map((function(t,e){return e})),d=!0;function g(t){return Math.abs(t[1]-e[2][1])<.01}function m(t){return Math.abs(t[0]-e[0][0])<.01}function v(t){return Math.abs(t[0]-e[2][0])<.01}for(;p.length;){for(c=a.smoothopen(t.edgepaths[h],t.smoothing),f+=d?c:c.replace(/^M/,\"L\"),p.splice(p.indexOf(h),1),r=t.edgepaths[h][t.edgepaths[h].length-1],s=-1,o=0;o<4;o++){if(!r){i.log(\"Missing end?\",h,t);break}for(u=r,Math.abs(u[1]-e[0][1])<.01&&!v(r)?n=e[1]:m(r)?n=e[0]:g(r)?n=e[3]:v(r)&&(n=e[2]),l=0;l<t.edgepaths.length;l++){var y=t.edgepaths[l][0];Math.abs(r[0]-n[0])<.01?Math.abs(r[0]-y[0])<.01&&(y[1]-r[1])*(n[1]-y[1])>=0&&(n=y,s=l):Math.abs(r[1]-n[1])<.01?Math.abs(r[1]-y[1])<.01&&(y[0]-r[0])*(n[0]-y[0])>=0&&(n=y,s=l):i.log(\"endpt to newendpt is not vert. or horz.\",r,n,y)}if(r=n,s>=0)break;f+=\"L\"+n}if(s===t.edgepaths.length){i.log(\"unclosed perimeter path\");break}h=s,(d=-1===p.indexOf(h))&&(h=p[0],f+=\"Z\")}for(h=0;h<t.paths.length;h++)f+=a.smoothclosed(t.paths[h],t.smoothing);return f}function x(t,e,r,n){var a=e.width/2,o=e.height/2,s=t.x,l=t.y,c=t.theta,u=Math.cos(c)*a,f=Math.sin(c)*a,h=(s>n.center?n.right-s:s-n.left)/(u+Math.abs(Math.sin(c)*o)),p=(l>n.middle?n.bottom-l:l-n.top)/(Math.abs(f)+Math.cos(c)*o);if(h<1||p<1)return 1/0;var d=v.EDGECOST*(1/(h-1)+1/(p-1));d+=v.ANGLECOST*c*c;for(var g=s-u,m=l-f,y=s+u,x=l+f,b=0;b<r.length;b++){var _=r[b],w=Math.cos(_.theta)*_.width/2,T=Math.sin(_.theta)*_.width/2,k=2*i.segmentDistance(g,m,y,x,_.x-w,_.y-T,_.x+w,_.y+T)/(e.height+_.height),M=_.level===e.level,A=M?v.SAMELEVELDISTANCE:1;if(k<=A)return 1/0;d+=v.NEIGHBORCOST*(M?v.SAMELEVELFACTOR:1)/(k-A)}return d}function b(t){var e,r,n=t.trace._emptypoints,i=[],a=t.z.length,o=t.z[0].length,s=[];for(e=0;e<o;e++)s.push(1);for(e=0;e<a;e++)i.push(s.slice());for(e=0;e<n.length;e++)i[(r=n[e])[0]][r[1]]=0;return t.zmask=i,i}r.plot=function(t,e,o,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,o,\"contour\").each((function(o){var s=n.select(this),v=o[0],x=v.trace,_=v.x,w=v.y,T=x.contours,k=p(T,e,v),M=i.ensureSingle(s,\"g\",\"heatmapcoloring\"),A=[];\"heatmap\"===T.coloring&&(A=[o]),u(t,e,A,M),f(k),h(k);var S=l.c2p(_[0],!0),E=l.c2p(_[_.length-1],!0),C=c.c2p(w[0],!0),L=c.c2p(w[w.length-1],!0),I=[[S,L],[E,L],[E,C],[S,C]],P=k;\"constraint\"===T.type&&(P=d(k,T._operation)),function(t,e,r){var n=i.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"===r.coloring?[0]:[]);n.enter().append(\"path\"),n.exit().remove(),n.attr(\"d\",\"M\"+e.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(s,I,T),function(t,e,r,a){var o=\"fill\"===a.coloring||\"constraint\"===a.type&&\"=\"!==a._operation,s=\"M\"+r.join(\"L\")+\"Z\";o&&g(e,a);var l=i.ensureSingle(t,\"g\",\"contourfill\").selectAll(\"path\").data(o?e:[]);l.enter().append(\"path\"),l.exit().remove(),l.each((function(t){var e=(t.prefixBoundary?s:\"\")+y(t,r);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(s,P,I,T),function(t,e,o,s,l){var c=i.ensureSingle(t,\"g\",\"contourlines\"),u=!1!==l.showlines,f=l.showlabels,h=u&&f,p=r.createLines(c,u||f,e),d=r.createLineClip(c,h,o,s.trace.uid),g=t.selectAll(\"g.contourlabels\").data(f?[0]:[]);if(g.exit().remove(),g.enter().append(\"g\").classed(\"contourlabels\",!0),f){var v=[],y=[];i.clearLocationCache();var x=r.labelFormatter(o,s),b=a.tester.append(\"text\").attr(\"data-notex\",1).call(a.font,l.labelfont),_=e[0].xaxis,w=e[0].yaxis,T=_._length,k=w._length,M=_.range,A=w.range,S=i.aggNums(Math.min,null,s.x),E=i.aggNums(Math.max,null,s.x),C=i.aggNums(Math.min,null,s.y),L=i.aggNums(Math.max,null,s.y),I=Math.max(_.c2p(S,!0),0),P=Math.min(_.c2p(E,!0),T),z=Math.max(w.c2p(L,!0),0),O=Math.min(w.c2p(C,!0),k),D={};M[0]<M[1]?(D.left=I,D.right=P):(D.left=P,D.right=I),A[0]<A[1]?(D.top=z,D.bottom=O):(D.top=O,D.bottom=z),D.middle=(D.top+D.bottom)/2,D.center=(D.left+D.right)/2,v.push([[D.left,D.top],[D.right,D.top],[D.right,D.bottom],[D.left,D.bottom]]);var R=Math.sqrt(T*T+k*k),F=m.LABELDISTANCE*R/Math.max(1,e.length/m.LABELINCREASE);p.each((function(t){var e=r.calcTextOpts(t.level,x,b,o);n.select(this).selectAll(\"path\").each((function(){var t=i.getVisibleSegment(this,D,e.height/2);if(t&&!(t.len<(e.width+e.height)*m.LABELMIN))for(var n=Math.min(Math.ceil(t.len/F),m.LABELMAX),a=0;a<n;a++){var o=r.findBestTextLocation(this,t,e,y,D);if(!o)break;r.addLabelData(o,e,y,v)}}))})),b.remove(),r.drawLabels(g,y,o,d,h?v:null)}f&&!u&&p.remove()}(s,k,t,v,T),function(t,e,r,n,o){var s=n.trace,l=r._fullLayout._clips,c=\"clip\"+s.uid,u=l.selectAll(\"#\"+c).data(s.connectgaps?[]:[0]);if(u.enter().append(\"clipPath\").classed(\"contourclip\",!0).attr(\"id\",c),u.exit().remove(),!1===s.connectgaps){var p={level:.9,crossings:{},starts:[],edgepaths:[],paths:[],xaxis:e.xaxis,yaxis:e.yaxis,x:n.x,y:n.y,z:b(n),smoothing:0};f([p]),h([p]),g([p],{type:\"levels\"}),i.ensureSingle(u,\"path\",\"\").attr(\"d\",(p.prefixBoundary?\"M\"+o.join(\"L\")+\"Z\":\"\")+y(p,o))}else c=null;a.setClipUrl(t,c,r)}(s,e,t,v,I)}))},r.createLines=function(t,e,r){var n=r[0].smoothing,i=t.selectAll(\"g.contourlevel\").data(e?r:[]);if(i.exit().remove(),i.enter().append(\"g\").classed(\"contourlevel\",!0),e){var o=i.selectAll(\"path.openline\").data((function(t){return t.pedgepaths||t.edgepaths}));o.exit().remove(),o.enter().append(\"path\").classed(\"openline\",!0),o.attr(\"d\",(function(t){return a.smoothopen(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\");var s=i.selectAll(\"path.closedline\").data((function(t){return t.ppaths||t.paths}));s.exit().remove(),s.enter().append(\"path\").classed(\"closedline\",!0),s.attr(\"d\",(function(t){return a.smoothclosed(t,n)})).style(\"stroke-miterlimit\",1).style(\"vector-effect\",\"non-scaling-stroke\")}return i},r.createLineClip=function(t,e,r,n){var i=e?\"clipline\"+n:null,o=r._fullLayout._clips.selectAll(\"#\"+i).data(e?[0]:[]);return o.exit().remove(),o.enter().append(\"clipPath\").classed(\"contourlineclip\",!0).attr(\"id\",i),a.setClipUrl(t,i,r),o},r.labelFormatter=function(t,e){var r=t._fullLayout,n=e.trace,i=n.contours,a={type:\"linear\",_id:\"ycontour\",showexponent:\"all\",exponentformat:\"B\"};if(i.labelformat)a.tickformat=i.labelformat,c(a,r);else{var s=o.extractOpts(n);if(s&&s.colorbar&&s.colorbar._axis)a=s.colorbar._axis;else{if(\"constraint\"===i.type){var u=i.value;Array.isArray(u)?a.range=[u[0],u[u.length-1]]:a.range=[u,u]}else a.range=[i.start,i.end],a.nticks=(i.end-i.start)/i.size;a.range[0]===a.range[1]&&(a.range[1]+=a.range[0]||1),a.nticks||(a.nticks=1e3),c(a,r),l.prepTicks(a),a._tmin=null,a._tmax=null}}return function(t){return l.tickText(a,t).text}},r.calcTextOpts=function(t,e,r,n){var i=e(t);r.text(i).call(s.convertToTspans,n);var o=r.node(),l=a.bBox(o,!0);return{text:i,width:l.width,height:l.height,fontSize:+o.style[\"font-size\"].replace(\"px\",\"\"),level:t,dy:(l.top+l.bottom)/2}},r.findBestTextLocation=function(t,e,r,n,a){var o,s,l,c,u,f=r.width;e.isClosed?(s=e.len/v.INITIALSEARCHPOINTS,o=e.min+s/2,l=e.max):(s=(e.len-f)/(v.INITIALSEARCHPOINTS+1),o=e.min+s+f/2,l=e.max-(s+f)/2);for(var h=1/0,p=0;p<v.ITERATIONS;p++){for(var d=o;d<l;d+=s){var g=i.getTextLocation(t,e.total,d,f),m=x(g,r,n,a);m<h&&(h=m,u=g,c=d)}if(h>2*v.MAXCOST)break;p&&(s/=2),l=(o=c-s/2)+1.5*s}if(h<=v.MAXCOST)return u},r.addLabelData=function(t,e,r,n){var i=e.fontSize,a=e.width+i/3,o=Math.max(0,e.height-i/3),s=t.x,l=t.y,c=t.theta,u=Math.sin(c),f=Math.cos(c),h=function(t,e){return[s+t*f-e*u,l+t*u+e*f]},p=[h(-a/2,-o/2),h(-a/2,o/2),h(a/2,o/2),h(a/2,-o/2)];r.push({text:e.text,x:s,y:l,dy:e.dy,theta:c,level:e.level,width:a,height:o}),n.push(p)},r.drawLabels=function(t,e,r,a,o){var l=t.selectAll(\"text\").data(e,(function(t){return t.text+\",\"+t.x+\",\"+t.y+\",\"+t.theta}));if(l.exit().remove(),l.enter().append(\"text\").attr({\"data-notex\":1,\"text-anchor\":\"middle\"}).each((function(t){var e=t.x+Math.sin(t.theta)*t.dy,i=t.y-Math.cos(t.theta)*t.dy;n.select(this).text(t.text).attr({x:e,y:i,transform:\"rotate(\"+180*t.theta/Math.PI+\" \"+e+\" \"+i+\")\"}).call(s.convertToTspans,r)})),o){for(var c=\"\",u=0;u<o.length;u++)c+=\"M\"+o[u].join(\"L\")+\"Z\";i.ensureSingle(a,\"path\",\"\").attr(\"d\",c)}}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/set_convert\":848,\"../heatmap/plot\":1076,\"./close_boundaries\":1010,\"./constants\":1012,\"./convert_to_constraints\":1016,\"./empty_pathinfo\":1018,\"./find_all_paths\":1020,\"./make_crossings\":1025,d3:169}],1027:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\");function a(t,e,r){var i={type:\"linear\",range:[t,e]};return n.autoTicks(i,(e-t)/(r||15)),i}e.exports=function(t,e){var r=t.contours;if(t.autocontour){var o=t.zmin,s=t.zmax;(t.zauto||void 0===o)&&(o=i.aggNums(Math.min,null,e)),(t.zauto||void 0===s)&&(s=i.aggNums(Math.max,null,e));var l=a(o,s,t.ncontours);r.size=l.dtick,r.start=n.tickFirst(l),l.range.reverse(),r.end=n.tickFirst(l),r.start===o&&(r.start+=r.size),r.end===s&&(r.end-=r.size),r.start>r.end&&(r.start=r.end=(r.start+r.end)/2),t._input.contours||(t._input.contours={}),i.extendFlat(t._input.contours,{start:r.start,end:r.end,size:r.size}),t._input.autocontour=!0}else if(\"constraint\"!==r.type){var c,u=r.start,f=r.end,h=t._input.contours;if(u>f&&(r.start=h.start=f,f=r.end=h.end=u,u=r.start),!(r.size>0))c=u===f?1:a(u,f,t.ncontours).dtick,h.size=r.size=c}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1028:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../heatmap/style\"),o=t(\"./make_color_map\");e.exports=function(t){var e=n.select(t).selectAll(\"g.contour\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(t){var e=n.select(this),r=t[0].trace,a=r.contours,s=r.line,l=a.size||1,c=a.start,u=\"constraint\"===a.type,f=!u&&\"lines\"===a.coloring,h=!u&&\"fill\"===a.coloring,p=f||h?o(r):null;e.selectAll(\"g.contourlevel\").each((function(t){n.select(this).selectAll(\"path\").call(i.lineGroupStyle,s.width,f?p(t.level):s.color,s.dash)}));var d=a.labelfont;if(e.selectAll(\"g.contourlabels text\").each((function(t){i.font(n.select(this),{family:d.family,size:d.size,color:d.color||(f?p(t.level):s.color)})})),u)e.selectAll(\"g.contourfill path\").style(\"fill\",r.fillcolor);else if(h){var g;e.selectAll(\"g.contourfill path\").style(\"fill\",(function(t){return void 0===g&&(g=t.level),p(t.level+.5*l)})),void 0===g&&(g=c),e.selectAll(\"g.contourbg path\").style(\"fill\",p(g-.5*l))}})),a(t)}},{\"../../components/drawing\":665,\"../heatmap/style\":1077,\"./make_color_map\":1024,d3:169}],1029:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/defaults\"),i=t(\"./label_defaults\");e.exports=function(t,e,r,a,o){var s,l=r(\"contours.coloring\"),c=\"\";\"fill\"===l&&(s=r(\"contours.showlines\")),!1!==s&&(\"lines\"!==l&&(c=r(\"line.color\",\"#000\")),r(\"line.width\",.5),r(\"line.dash\")),\"none\"!==l&&(!0!==t.showlegend&&(e.showlegend=!1),e._dfltShowLegend=!1,n(t,e,a,r,{prefix:\"\",cLetter:\"z\"})),r(\"line.smoothing\"),i(r,a,c,o)}},{\"../../components/colorscale/defaults\":653,\"./label_defaults\":1023}],1030:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=i.contours;e.exports=o({carpet:{valType:\"string\",editType:\"calc\"},z:n.z,a:n.x,a0:n.x0,da:n.dx,b:n.y,b0:n.y0,db:n.dy,text:n.text,hovertext:n.hovertext,transpose:n.transpose,atype:n.xtype,btype:n.ytype,fillcolor:i.fillcolor,autocontour:i.autocontour,ncontours:i.ncontours,contours:{type:s.type,start:s.start,end:s.end,size:s.size,coloring:{valType:\"enumerated\",values:[\"fill\",\"lines\",\"none\"],dflt:\"fill\",editType:\"calc\"},showlines:s.showlines,showlabels:s.showlabels,labelfont:s.labelfont,labelformat:s.labelformat,operation:s.operation,value:s.value,editType:\"calc\",impliedEdits:{autocontour:!1}},line:{color:i.line.color,width:i.line.width,dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},transforms:void 0},a(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../heatmap/attributes\":1065}],1031:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../../lib\"),a=t(\"../heatmap/convert_column_xyz\"),o=t(\"../heatmap/clean_2d_array\"),s=t(\"../heatmap/interp2d\"),l=t(\"../heatmap/find_empties\"),c=t(\"../heatmap/make_bound_array\"),u=t(\"./defaults\"),f=t(\"../carpet/lookup_carpetid\"),h=t(\"../contour/set_contours\");e.exports=function(t,e){var r=e._carpetTrace=f(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){if(!e.a||!e.b){var p=t.data[r.index],d=t.data[e.index];d.a||(d.a=p.a),d.b||(d.b=p.b),u(d,e,e._defaultColor,t._fullLayout)}var g=function(t,e){var r,u,f,h,p,d,g,m=e._carpetTrace,v=m.aaxis,y=m.baxis;v._minDtick=0,y._minDtick=0,i.isArray1D(e.z)&&a(e,v,y,\"a\",\"b\",[\"z\"]);r=e._a=e._a||e.a,h=e._b=e._b||e.b,r=r?v.makeCalcdata(e,\"_a\"):[],h=h?y.makeCalcdata(e,\"_b\"):[],u=e.a0||0,f=e.da||1,p=e.b0||0,d=e.db||1,g=e._z=o(e._z||e.z,e.transpose),e._emptypoints=l(g),s(g,e._emptypoints);var x=i.maxRowLength(g),b=\"scaled\"===e.xtype?\"\":r,_=c(e,b,u,f,x,v),w=\"scaled\"===e.ytype?\"\":h,T=c(e,w,p,d,g.length,y),k={a:_,b:T,z:g};\"levels\"===e.contours.type&&\"none\"!==e.contours.coloring&&n(t,e,{vals:g,containerStr:\"\",cLetter:\"z\"});return[k]}(t,e);return h(e,e._z),g}}},{\"../../components/colorscale/calc\":651,\"../../lib\":778,\"../carpet/lookup_carpetid\":981,\"../contour/set_contours\":1027,\"../heatmap/clean_2d_array\":1067,\"../heatmap/convert_column_xyz\":1069,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"../heatmap/make_bound_array\":1075,\"./defaults\":1032}],1032:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"./attributes\"),o=t(\"../contour/constraint_defaults\"),s=t(\"../contour/contours_defaults\"),l=t(\"../contour/style_defaults\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,a,r,i)}if(u(\"carpet\"),t.a&&t.b){if(!i(t,e,u,c,\"a\",\"b\"))return void(e.visible=!1);u(\"text\"),\"constraint\"===u(\"contours.type\")?o(t,e,u,c,r,{hasHover:!1}):(s(t,e,u,(function(r){return n.coerce2(t,e,a,r)})),l(t,e,u,c,{hasHover:!1}))}else e._defaultColor=r,e._length=null}},{\"../../lib\":778,\"../contour/constraint_defaults\":1013,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1030}],1033:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../contour/colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../contour/style\"),moduleType:\"trace\",name:\"contourcarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"carpet\",\"contour\",\"symbols\",\"showLegend\",\"hasLines\",\"carpetDependent\",\"noHover\",\"noSortingByValue\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/colorbar\":1011,\"../contour/style\":1028,\"./attributes\":1030,\"./calc\":1031,\"./defaults\":1032,\"./plot\":1034}],1034:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../carpet/map_1d_array\"),a=t(\"../carpet/makepath\"),o=t(\"../../components/drawing\"),s=t(\"../../lib\"),l=t(\"../contour/make_crossings\"),c=t(\"../contour/find_all_paths\"),u=t(\"../contour/plot\"),f=t(\"../contour/constants\"),h=t(\"../contour/convert_to_constraints\"),p=t(\"../contour/empty_pathinfo\"),d=t(\"../contour/close_boundaries\"),g=t(\"../carpet/lookup_carpetid\"),m=t(\"../carpet/axis_aligned_line\");function v(t,e,r){var n=t.getPointAtLength(e),i=t.getPointAtLength(r),a=i.x-n.x,o=i.y-n.y,s=Math.sqrt(a*a+o*o);return[a/s,o/s]}function y(t){var e=Math.sqrt(t[0]*t[0]+t[1]*t[1]);return[t[0]/e,t[1]/e]}function x(t,e){var r=Math.abs(t[0]*e[0]+t[1]*e[1]);return Math.sqrt(1-r*r)/r}e.exports=function(t,e,r,b){var _=e.xaxis,w=e.yaxis;s.makeTraceGroups(b,r,\"contour\").each((function(r){var b=n.select(this),T=r[0],k=T.trace,M=k._carpetTrace=g(t,k),A=t.calcdata[M.index][0];if(M.visible&&\"legendonly\"!==M.visible){var S=T.a,E=T.b,C=k.contours,L=p(C,e,T),I=\"constraint\"===C.type,P=C._operation,z=I?\"=\"===P?\"lines\":\"fill\":C.coloring,O=[[S[0],E[E.length-1]],[S[S.length-1],E[E.length-1]],[S[S.length-1],E[0]],[S[0],E[0]]];l(L);var D=1e-8*(S[S.length-1]-S[0]),R=1e-8*(E[E.length-1]-E[0]);c(L,D,R);var F,B,N,j,U=L;\"constraint\"===C.type&&(U=h(L,P)),function(t,e){var r,n,i,a,o,s,l,c,u;for(r=0;r<t.length;r++){for(a=t[r],o=a.pedgepaths=[],s=a.ppaths=[],n=0;n<a.edgepaths.length;n++){for(u=a.edgepaths[n],l=[],i=0;i<u.length;i++)l[i]=e(u[i]);o.push(l)}for(n=0;n<a.paths.length;n++){for(u=a.paths[n],c=[],i=0;i<u.length;i++)c[i]=e(u[i]);s.push(c)}}}(L,H);var V=[];for(j=A.clipsegments.length-1;j>=0;j--)F=A.clipsegments[j],B=i([],F.x,_.c2p),N=i([],F.y,w.c2p),B.reverse(),N.reverse(),V.push(a(B,N,F.bicubic));var q=\"M\"+V.join(\"L\")+\"Z\";!function(t,e,r,n,o,l){var c,u,f,h,p=s.ensureSingle(t,\"g\",\"contourbg\").selectAll(\"path\").data(\"fill\"!==l||o?[]:[0]);p.enter().append(\"path\"),p.exit().remove();var d=[];for(h=0;h<e.length;h++)c=e[h],u=i([],c.x,r.c2p),f=i([],c.y,n.c2p),d.push(a(u,f,c.bicubic));p.attr(\"d\",\"M\"+d.join(\"L\")+\"Z\").style(\"stroke\",\"none\")}(b,A.clipsegments,_,w,I,z),function(t,e,r,i,a,l,c,u,f,h,p){var g=\"fill\"===h;g&&d(a,t.contours);var v=s.ensureSingle(e,\"g\",\"contourfill\").selectAll(\"path\").data(g?a:[]);v.enter().append(\"path\"),v.exit().remove(),v.each((function(t){var e=(t.prefixBoundary?p:\"\")+function(t,e,r,n,i,a,l,c){var u,f,h,p,d,g,v,y=\"\",x=e.edgepaths.map((function(t,e){return e})),b=!0,_=1e-4*Math.abs(r[0][0]-r[2][0]),w=1e-4*Math.abs(r[0][1]-r[2][1]);function T(t){return Math.abs(t[1]-r[0][1])<w}function k(t){return Math.abs(t[1]-r[2][1])<w}function M(t){return Math.abs(t[0]-r[0][0])<_}function A(t){return Math.abs(t[0]-r[2][0])<_}function S(t,e){var r,n,o,s,u=\"\";for(T(t)&&!A(t)||k(t)&&!M(t)?(s=i.aaxis,o=m(i,a,[t[0],e[0]],.5*(t[1]+e[1]))):(s=i.baxis,o=m(i,a,.5*(t[0]+e[0]),[t[1],e[1]])),r=1;r<o.length;r++)for(u+=s.smoothing?\"C\":\"L\",n=0;n<o[r].length;n++){var f=o[r][n];u+=[l.c2p(f[0]),c.c2p(f[1])]+\" \"}return u}u=0,f=null;for(;x.length;){var E=e.edgepaths[u][0];for(f&&(y+=S(f,E)),v=o.smoothopen(e.edgepaths[u].map(n),e.smoothing),y+=b?v:v.replace(/^M/,\"L\"),x.splice(x.indexOf(u),1),f=e.edgepaths[u][e.edgepaths[u].length-1],d=-1,p=0;p<4;p++){if(!f){s.log(\"Missing end?\",u,e);break}for(T(f)&&!A(f)?h=r[1]:M(f)?h=r[0]:k(f)?h=r[3]:A(f)&&(h=r[2]),g=0;g<e.edgepaths.length;g++){var C=e.edgepaths[g][0];Math.abs(f[0]-h[0])<_?Math.abs(f[0]-C[0])<_&&(C[1]-f[1])*(h[1]-C[1])>=0&&(h=C,d=g):Math.abs(f[1]-h[1])<w?Math.abs(f[1]-C[1])<w&&(C[0]-f[0])*(h[0]-C[0])>=0&&(h=C,d=g):s.log(\"endpt to newendpt is not vert. or horz.\",f,h,C)}if(d>=0)break;y+=S(f,h),f=h}if(d===e.edgepaths.length){s.log(\"unclosed perimeter path\");break}u=d,(b=-1===x.indexOf(u))&&(u=x[0],y+=S(f,h)+\"Z\",f=null)}for(u=0;u<e.paths.length;u++)y+=o.smoothclosed(e.paths[u].map(n),e.smoothing);return y}(0,t,l,c,u,f,r,i);e?n.select(this).attr(\"d\",e).style(\"stroke\",\"none\"):n.select(this).remove()}))}(k,b,_,w,U,O,H,M,A,z,q),function(t,e,r,i,a,l,c){var h=s.ensureSingle(t,\"g\",\"contourlines\"),p=!1!==a.showlines,d=a.showlabels,g=p&&d,m=u.createLines(h,p||d,e),b=u.createLineClip(h,g,r,i.trace.uid),_=t.selectAll(\"g.contourlabels\").data(d?[0]:[]);if(_.exit().remove(),_.enter().append(\"g\").classed(\"contourlabels\",!0),d){var w=l.xaxis,T=l.yaxis,k=w._length,M=T._length,A=[[[0,0],[k,0],[k,M],[0,M]]],S=[];s.clearLocationCache();var E=u.labelFormatter(r,i),C=o.tester.append(\"text\").attr(\"data-notex\",1).call(o.font,a.labelfont),L={left:0,right:k,center:k/2,top:0,bottom:M,middle:M/2},I=Math.sqrt(k*k+M*M),P=f.LABELDISTANCE*I/Math.max(1,e.length/f.LABELINCREASE);m.each((function(t){var e=u.calcTextOpts(t.level,E,C,r);n.select(this).selectAll(\"path\").each((function(r){var n=s.getVisibleSegment(this,L,e.height/2);if(n&&(function(t,e,r,n,i,a){for(var o,s=0;s<r.pedgepaths.length;s++)e===r.pedgepaths[s]&&(o=r.edgepaths[s]);if(!o)return;var l=i.a[0],c=i.a[i.a.length-1],u=i.b[0],f=i.b[i.b.length-1];function h(t,e){var r,n=0;return(Math.abs(t[0]-l)<.1||Math.abs(t[0]-c)<.1)&&(r=y(i.dxydb_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),(Math.abs(t[1]-u)<.1||Math.abs(t[1]-f)<.1)&&(r=y(i.dxyda_rough(t[0],t[1],.1)),n=Math.max(n,a*x(e,r)/2)),n}var p=v(t,0,1),d=v(t,n.total,n.total-1),g=h(o[0],p),m=n.total-h(o[o.length-1],d);n.min<g&&(n.min=g);n.max>m&&(n.max=m);n.len=n.max-n.min}(this,r,t,n,c,e.height),!(n.len<(e.width+e.height)*f.LABELMIN)))for(var i=Math.min(Math.ceil(n.len/P),f.LABELMAX),a=0;a<i;a++){var o=u.findBestTextLocation(this,n,e,S,L);if(!o)break;u.addLabelData(o,e,S,A)}}))})),C.remove(),u.drawLabels(_,S,r,b,g?A:null)}d&&!p&&m.remove()}(b,L,t,T,C,e,M),o.setClipUrl(b,M._clipPathId,t)}function H(t){var e=M.ab2xy(t[0],t[1],!0);return[_.c2p(e[0]),w.c2p(e[1])]}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../carpet/axis_aligned_line\":965,\"../carpet/lookup_carpetid\":981,\"../carpet/makepath\":982,\"../carpet/map_1d_array\":983,\"../contour/close_boundaries\":1010,\"../contour/constants\":1012,\"../contour/convert_to_constraints\":1016,\"../contour/empty_pathinfo\":1018,\"../contour/find_all_paths\":1020,\"../contour/make_crossings\":1025,\"../contour/plot\":1026,d3:169}],1035:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/attributes\"),o=t(\"../scattermapbox/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({lon:o.lon,lat:o.lat,z:{valType:\"data_array\",editType:\"calc\"},radius:{valType:\"number\",editType:\"plot\",arrayOk:!0,min:1,dflt:30},below:{valType:\"string\",editType:\"plot\"},text:o.text,hovertext:o.hovertext,hoverinfo:s({},a.hoverinfo,{flags:[\"lon\",\"lat\",\"z\",\"text\",\"name\"]}),hovertemplate:i(),showlegend:s({},a.showlegend,{dflt:!1})},n(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scattermapbox/attributes\":1252}],1036:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\").isArrayOrTypedArray,a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../components/colorscale/calc\"),s=t(\"../../lib\")._;e.exports=function(t,e){for(var r=e._length,l=new Array(r),c=e.z,u=i(c)&&c.length,f=0;f<r;f++){var h=l[f]={},p=e.lon[f],d=e.lat[f];if(h.lonlat=n(p)&&n(d)?[+p,+d]:[a,a],u){var g=c[f];h.z=n(g)?g:a}}return o(t,e,{vals:u?c:[0,1],containerStr:\"\",cLetter:\"z\"}),r&&(l[0].t={labels:{lat:s(t,\"lat:\")+\" \",lon:s(t,\"lon:\")+\" \"}}),l}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1037:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../../components/colorscale\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"../../lib/geojson_utils\").makeBlank;e.exports=function(t){var e=t[0].trace,r=!0===e.visible&&0!==e._length,c=e._opts={heatmap:{layout:{visibility:\"none\"},paint:{}},geojson:l()};if(!r)return c;var u,f=[],h=e.z,p=e.radius,d=i.isArrayOrTypedArray(h)&&h.length,g=i.isArrayOrTypedArray(p);for(u=0;u<t.length;u++){var m=t[u],v=m.lonlat;if(v[0]!==s){var y={};if(d){var x=m.z;y.z=x!==s?x:0}g&&(y.r=n(p[u])&&p[u]>0?+p[u]:0),f.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:v},properties:y})}}var b=o.extractOpts(e),_=b.reversescale?o.flipScale(b.colorscale):b.colorscale,w=_[0][1],T=[\"interpolate\",[\"linear\"],[\"heatmap-density\"],0,a.opacity(w)<1?w:a.addOpacity(w,0)];for(u=1;u<_.length;u++)T.push(_[u][0],_[u][1]);var k=[\"interpolate\",[\"linear\"],[\"get\",\"z\"],b.min,0,b.max,1];return i.extendFlat(c.heatmap.paint,{\"heatmap-weight\":d?k:1/(b.max-b.min),\"heatmap-color\":T,\"heatmap-radius\":g?{type:\"identity\",property:\"r\"}:e.radius,\"heatmap-opacity\":e.opacity}),c.geojson={type:\"FeatureCollection\",features:f},c.heatmap.layout.visibility=\"visible\",c}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"fast-isnumeric\":241}],1038:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"lon\")||[],c=s(\"lat\")||[],u=Math.min(l.length,c.length);u?(e._length=u,s(\"z\"),s(\"radius\"),s(\"below\"),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),i(t,e,o,s,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1035}],1039:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t.z=e.z,t}},{}],1040:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../scattermapbox/hover\");e.exports=function(t,e,r){var o=a(t,e,r);if(o){var s=o[0],l=s.cd,c=l[0].trace,u=l[s.index];if(delete s.color,\"z\"in u){var f=s.subplot.mockAxis;s.z=u.z,s.zLabel=i.tickText(f,f.c2l(u.z),\"hover\").text}return s.extraText=function(t,e,r){if(t.hovertemplate)return;var i=(e.hi||t.hoverinfo).split(\"+\"),a=-1!==i.indexOf(\"all\"),o=-1!==i.indexOf(\"lon\"),s=-1!==i.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}a||o&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):o?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(a||-1!==i.indexOf(\"text\"))&&n.fillText(e,t,c);return c.join(\"<br>\")}(c,u,l[0].t.labels),[s]}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../scattermapbox/hover\":1257}],1041:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),formatLabels:t(\"../scattermapbox/format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),getBelow:function(t,e){for(var r=e.getMapLayers(),n=0;n<r.length;n++){var i=r[n],a=i.id;if(\"symbol\"===i.type&&\"string\"==typeof a&&-1===a.indexOf(\"plotly-\"))return a}},moduleType:\"trace\",name:\"densitymapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"showLegend\"],meta:{hr_name:\"density_mapbox\"}}},{\"../../plots/mapbox\":885,\"../heatmap/colorbar\":1068,\"../scattermapbox/format_labels\":1256,\"./attributes\":1035,\"./calc\":1036,\"./defaults\":1038,\"./event_data\":1039,\"./hover\":1040,\"./plot\":1042}],1042:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix;function a(t,e){this.type=\"densitymapbox\",this.subplot=t,this.uid=e,this.sourceId=\"source-\"+e,this.layerList=[[\"heatmap\",i+e+\"-heatmap\"]],this.below=null}var o=a.prototype;o.update=function(t){var e=this.subplot,r=this.layerList,i=n(t),a=e.belowLookup[\"trace-\"+this.uid];e.map.getSource(this.sourceId).setData(i.geojson),a!==this.below&&(this._removeLayers(),this._addLayers(i,a),this.below=a);for(var o=0;o<r.length;o++){var s=r[o],l=s[0],c=s[1],u=i[l];e.setOptions(c,\"setLayoutProperty\",u.layout),\"visible\"===u.layout.visibility&&e.setOptions(c,\"setPaintProperty\",u.paint)}},o._addLayers=function(t,e){for(var r=this.subplot,n=this.layerList,i=this.sourceId,a=0;a<n.length;a++){var o=n[a],s=o[0],l=t[s];r.addLayer({type:s,id:o[1],source:i,layout:l.layout,paint:l.paint},e)}},o._removeLayers=function(){for(var t=this.subplot.map,e=this.layerList,r=e.length-1;r>=0;r--)t.removeLayer(e[r][1])},o.dispose=function(){var t=this.subplot.map;this._removeLayers(),t.removeSource(this.sourceId)},e.exports=function(t,e){var r=e[0].trace,i=new a(t,r.uid),o=i.sourceId,s=n(e),l=i.below=t.belowLookup[\"trace-\"+r.uid];return t.map.addSource(o,{type:\"geojson\",data:s.geojson}),i._addLayers(s,l),i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1037}],1043:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.hovertext,t,\"htx\");var i=e.marker;if(i){n.mergeArray(i.opacity,t,\"mo\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;a&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"))}}},{\"../../lib\":778}],1044:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");e.exports={x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"percent initial\",\"percent previous\",\"percent total\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"percent initial\",\"percent previous\",\"percent total\",\"value\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\",\"value\"])}),text:n.text,textposition:c({},n.textposition,{dflt:\"auto\"}),insidetextanchor:c({},n.insidetextanchor,{dflt:\"middle\"}),textangle:c({},n.textangle,{dflt:0}),textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:c({},n.orientation,{}),offset:c({},n.offset,{arrayOk:!1}),width:c({},n.width,{arrayOk:!1}),marker:n.marker,connector:{fillcolor:{valType:\"color\",editType:\"style\"},line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{dflt:0,editType:\"plot\"}),dash:i.dash,editType:\"style\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1046}],1045:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"./arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return t===s?0:t}e.exports=function(t,e){var r,c,u,f,h,p,d=n.getFromId(t,e.xaxis||\"x\"),g=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=d.makeCalcdata(e,\"x\"),u=g.makeCalcdata(e,\"y\"),c=i(e,g,\"y\",u),p=!!e.yperiodalignment):(r=g.makeCalcdata(e,\"y\"),u=d.makeCalcdata(e,\"x\"),c=i(e,d,\"x\",u),p=!!e.xperiodalignment);var m,v=Math.min(c.length,r.length),y=new Array(v);for(e._base=[],f=0;f<v;f++){r[f]<0&&(r[f]=s);var x=!1;r[f]!==s&&f+1<v&&r[f+1]!==s&&(x=!0),h=y[f]={p:c[f],s:r[f],cNext:x},e._base[f]=-.5*h.s,p&&(y[f].orig_p=u[f]),e.ids&&(h.id=String(e.ids[f])),0===f&&(y[0].vTotal=0),y[0].vTotal+=l(h.s),h.begR=l(h.s)/l(y[0].s)}for(f=0;f<v;f++)(h=y[f]).s!==s&&(h.sumR=h.s/y[0].vTotal,h.difR=void 0!==m?h.s/m:1,m=h.s);return a(y,e),o(y,e),y}},{\"../../constants/numerical\":753,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189,\"./arrays_to_calcdata\":1043}],1046:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"percentInitial\",\"percentPrevious\",\"percentTotal\"]}},{}],1047:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i],d=\"h\"===p.orientation;!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"funnel\"===p.type&&(r=s[i],d?h.push(r):f.push(r),u.push(r))}var g={mode:a.funnelmode,norm:a.funnelnorm,gap:a.funnelgap,groupgap:a.funnelgroupgap};for(n(t,l,c,f,g),n(t,c,l,h,g),i=0;i<u.length;i++){r=u[i];for(var m=0;m<r.length;m++)m+1<r.length&&(r[m].nextP0=r[m+1].p0,r[m].nextS0=r[m+1].s0,r[m].nextP1=r[m+1].p1,r[m].nextS1=r[m+1].s1)}}},{\"../bar/cross_trace_calc\":924}],1048:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\");e.exports={supplyDefaults:function(t,e,r,i){function u(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,u)){s(t,e,i,u),u(\"orientation\",e.y&&!e.x?\"v\":\"h\"),u(\"offset\"),u(\"width\");var f=u(\"text\");u(\"hovertext\"),u(\"hovertemplate\");var h=u(\"textposition\");a(t,e,i,u,h,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"===e.textposition||e.texttemplate||u(\"textinfo\",Array.isArray(f)?\"text+value\":\"value\");var p=u(\"marker.color\",r);if(u(\"marker.line.color\",c.defaultLine),u(\"marker.line.width\"),u(\"connector.visible\"))u(\"connector.fillcolor\",function(t){var e=n.isArrayOrTypedArray(t)?\"#000\":t;return c.addOpacity(e,.5*c.opacity(e))}(p)),u(\"connector.line.width\")&&(u(\"connector.line.color\"),u(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.funnelmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1044}],1049:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"percentInitial\"in e&&(t.percentInitial=e.percentInitial),\"percentPrevious\"in e&&(t.percentPrevious=e.percentPrevious),\"percentTotal\"in e&&(t.percentTotal=e.percentTotal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1050:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\").opacity,i=t(\"../bar/hover\").hoverOnBars,a=t(\"../../lib\").formatPercent;e.exports=function(t,e,r,o){var s=i(t,e,r,o);if(s){var l=s.cd,c=l[0].trace,u=\"h\"===c.orientation,f=l[s.index];s[(u?\"x\":\"y\")+\"LabelVal\"]=f.s,s.percentInitial=f.begR,s.percentInitialLabel=a(f.begR,1),s.percentPrevious=f.difR,s.percentPreviousLabel=a(f.difR,1),s.percentTotal=f.sumR,s.percentTotalLabel=a(f.sumR,1);var h=f.hi||c.hoverinfo,p=[];if(h&&\"none\"!==h&&\"skip\"!==h){var d=\"all\"===h,g=h.split(\"+\"),m=function(t){return d||-1!==g.indexOf(t)};m(\"percent initial\")&&p.push(s.percentInitialLabel+\" of initial\"),m(\"percent previous\")&&p.push(s.percentPreviousLabel+\" of previous\"),m(\"percent total\")&&p.push(s.percentTotalLabel+\" of total\")}return s.extraText=p.join(\"<br>\"),s.color=function(t,e){var r=t.marker,i=e.mc||r.color,a=e.mlc||r.line.color,o=e.mlw||r.line.width;if(n(i))return i;if(n(a)&&o)return a}(c,f),[s]}}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/hover\":928}],1051:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"funnel\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1044,\"./calc\":1045,\"./cross_trace_calc\":1047,\"./defaults\":1048,\"./event_data\":1049,\"./hover\":1050,\"./layout_attributes\":1052,\"./layout_defaults\":1053,\"./plot\":1054,\"./style\":1055}],1052:[function(t,e,r){\"use strict\";e.exports={funnelmode:{valType:\"enumerated\",values:[\"stack\",\"group\",\"overlay\"],dflt:\"stack\",editType:\"calc\"},funnelgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},funnelgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1053:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"funnel\"===l.type){a=!0;break}}a&&(o(\"funnelmode\"),o(\"funnelgap\",.2),o(\"funnelgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1052}],1054:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;function c(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),i[3]=o.c2p(t.nextS1,!0),a[3]=s.c2p(t.nextP1,!0),n?[i,a]:[a,i]}e.exports=function(t,e,r,u){var f=t._fullLayout;l(\"funnel\",f),function(t,e,r,s){var l=e.xaxis,u=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),f=r[0].trace,h=i.ensureSingle(s,\"g\",\"regions\");if(f.connector&&f.connector.visible){var p=\"h\"===f.orientation,d=h.selectAll(\"g.region\").data(i.identity);d.enter().append(\"g\").classed(\"region\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var f=c(r,l,u,p),h=f[0],d=f[1],m=\"\";h[0]!==o&&d[0]!==o&&h[1]!==o&&d[1]!==o&&h[2]!==o&&d[2]!==o&&h[3]!==o&&d[3]!==o&&(m+=p?\"M\"+h[0]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[2]+\"H\"+h[3]+\"L\"+h[1]+\",\"+d[1]+\"Z\":\"M\"+h[1]+\",\"+d[1]+\"L\"+h[2]+\",\"+d[3]+\"V\"+d[2]+\"L\"+h[1]+\",\"+d[0]+\"Z\"),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else h.remove()}))}(t,e,r,u),function(t,e,r,o){var s=e.xaxis,l=e.yaxis;i.makeTraceGroups(o,r,\"trace bars\").each((function(r){var o=n.select(this),u=r[0].trace,f=i.ensureSingle(o,\"g\",\"lines\");if(u.connector&&u.connector.visible&&u.connector.line.width){var h=\"h\"===u.orientation,p=f.selectAll(\"g.line\").data(i.identity);p.enter().append(\"g\").classed(\"line\",!0),p.exit().remove();var d=p.size();p.each((function(r,o){if(o===d-1||r.cNext){var u=c(r,s,l,h),f=u[0],p=u[1],g=\"\";void 0!==f[3]&&void 0!==p[3]&&(h?(g+=\"M\"+f[0]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[2],g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[3]+\",\"+p[2]):(g+=\"M\"+f[1]+\",\"+p[1]+\"L\"+f[2]+\",\"+p[3],g+=\"M\"+f[1]+\",\"+p[0]+\"L\"+f[2]+\",\"+p[2])),\"\"===g&&(g=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",g).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,u),s.plot(t,e,r,u,{mode:f.funnelmode,norm:f.funnelmode,gap:f.funnelgap,groupgap:f.funnelgroupgap})}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1055:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.funnellayer\").selectAll(\"g.trace\");l(t,s,\"funnel\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s.marker;n.select(this).call(a.fill,t.mc||e.color).call(a.stroke,t.mlc||e.line.color).call(i.dashLine,e.line.dash,t.mlw||e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".regions\").each((function(){n.select(this).selectAll(\"path\").style(\"stroke-width\",0).call(a.fill,s.connector.fillcolor)})),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1056:[function(t,e,r){\"use strict\";var n=t(\"../pie/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/domain\").attributes,o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"../../lib/extend\").extendFlat;e.exports={labels:n.labels,label0:n.label0,dlabel:n.dlabel,values:n.values,marker:{colors:n.marker.colors,line:{color:l({},n.marker.line.color,{dflt:null}),width:l({},n.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},text:n.text,hovertext:n.hovertext,scalegroup:l({},n.scalegroup,{}),textinfo:l({},n.textinfo,{flags:[\"label\",\"text\",\"value\",\"percent\"]}),texttemplate:s({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),hoverinfo:l({},i.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:o({},{keys:[\"label\",\"color\",\"value\",\"text\",\"percent\"]}),textposition:l({},n.textposition,{values:[\"inside\",\"none\"],dflt:\"inside\"}),textfont:n.textfont,insidetextfont:n.insidetextfont,title:{text:n.title.text,font:n.title.font,position:l({},n.title.position,{values:[\"top left\",\"top center\",\"top right\"],dflt:\"top center\"}),editType:\"plot\"},domain:a({name:\"funnelarea\",trace:!0,editType:\"calc\"}),aspectratio:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},baseratio:{valType:\"number\",min:0,max:1,dflt:.333,editType:\"plot\"}}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161}],1057:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"funnelarea\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1058:[function(t,e,r){\"use strict\";var n=t(\"../pie/calc\");e.exports={calc:function(t,e){return n.calc(t,e)},crossTraceCalc:function(t){n.crossTraceCalc(t,{type:\"funnelarea\"})}}},{\"../pie/calc\":1163}],1059:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../pie/defaults\").handleLabelsAndValues;e.exports=function(t,e,r,l){function c(r,a){return n.coerce(t,e,i,r,a)}var u=c(\"labels\"),f=c(\"values\"),h=s(u,f),p=h.len;if(e._hasLabels=h.hasLabels,e._hasValues=h.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),p){e._length=p,c(\"marker.line.width\")&&c(\"marker.line.color\",l.paper_bgcolor),c(\"marker.colors\"),c(\"scalegroup\");var d,g=c(\"text\"),m=c(\"texttemplate\");if(m||(d=c(\"textinfo\",Array.isArray(g)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),m||d&&\"none\"!==d){var v=c(\"textposition\");o(t,e,l,c,v,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1})}a(e,l,c),c(\"title.text\")&&(c(\"title.position\"),n.coerceFont(c,\"title.font\",l.font)),c(\"aspectratio\"),c(\"baseratio\")}else e.visible=!1}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"../pie/defaults\":1164,\"./attributes\":1056}],1060:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"funnelarea\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"funnelarea\",\"showLegend\"],attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\"),styleOne:t(\"../pie/style_one\"),meta:{}}},{\"../pie/style_one\":1172,\"./attributes\":1056,\"./base_plot\":1057,\"./calc\":1058,\"./defaults\":1059,\"./layout_attributes\":1061,\"./layout_defaults\":1062,\"./plot\":1063,\"./style\":1064}],1061:[function(t,e,r){\"use strict\";var n=t(\"../pie/layout_attributes\").hiddenlabels;e.exports={hiddenlabels:n,funnelareacolorway:{valType:\"colorlist\",editType:\"calc\"},extendfunnelareacolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{\"../pie/layout_attributes\":1168}],1062:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"funnelareacolorway\",e.colorway),r(\"extendfunnelareacolors\")}},{\"../../lib\":778,\"./layout_attributes\":1061}],1063:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../lib\"),o=a.strScale,s=a.strTranslate,l=t(\"../../lib/svg_text_utils\"),c=t(\"../bar/plot\").toMoveInsideBar,u=t(\"../bar/uniform_text\"),f=u.recordMinTextSize,h=u.clearMinTextSize,p=t(\"../pie/helpers\"),d=t(\"../pie/plot\"),g=d.attachFxHandlers,m=d.determineInsideTextFont,v=d.layoutAreas,y=d.prerenderTitles,x=d.positionTitleOutside,b=d.formatSliceLabel;function _(t,e){return\"l\"+(e[0]-t[0])+\",\"+(e[1]-t[1])}e.exports=function(t,e){var r=t._fullLayout;h(\"funnelarea\",r),y(e,t),v(e,r._size),a.makeTraceGroups(r._funnelarealayer,e,\"trace\").each((function(e){var u=n.select(this),h=e[0],d=h.trace;!function(t){if(!t.length)return;var e=t[0],r=e.trace,n=r.aspectratio,i=r.baseratio;i>.999&&(i=.999);var a,o=Math.pow(i,2),s=e.vTotal,l=s,c=s*o/(1-o)/s;function u(){var t,e={x:t=Math.sqrt(c),y:-t};return[e.x,e.y]}var f,h,p=[];for(p.push(u()),f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var d=h.v/l;c+=d,p.push(u())}var g=1/0,m=-1/0;for(f=0;f<p.length;f++)a=p[f],g=Math.min(g,a[1]),m=Math.max(m,a[1]);for(f=0;f<p.length;f++)p[f][1]-=(m+g)/2;var v=p[p.length-1][0],y=e.r,x=(m-g)/2,b=y/v,_=y/x*n;for(e.r=_*x,f=0;f<p.length;f++)p[f][0]*=b,p[f][1]*=_;var w=[-(a=p[0])[0],a[1]],T=[a[0],a[1]],k=0;for(f=t.length-1;f>-1;f--)if(!(h=t[f]).hidden){var M=p[k+=1][0],A=p[k][1];h.TL=[-M,A],h.TR=[M,A],h.BL=w,h.BR=T,h.pxmid=(S=h.TR,E=h.BR,[.5*(S[0]+E[0]),.5*(S[1]+E[1])]),w=h.TL,T=h.TR}var S,E}(e),u.each((function(){var u=n.select(this).selectAll(\"g.slice\").data(e);u.enter().append(\"g\").classed(\"slice\",!0),u.exit().remove(),u.each((function(o,s){if(o.hidden)n.select(this).selectAll(\"path,g\").remove();else{o.pointNumber=o.i,o.curveNumber=d.index;var u=h.cx,v=h.cy,y=n.select(this),x=y.selectAll(\"path.surface\").data([o]);x.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),y.call(g,t,e);var w=\"M\"+(u+o.TR[0])+\",\"+(v+o.TR[1])+_(o.TR,o.BR)+_(o.BR,o.BL)+_(o.BL,o.TL)+\"Z\";x.attr(\"d\",w),b(t,o,h);var T=p.castOption(d.textposition,o.pts),k=y.selectAll(\"g.slicetext\").data(o.text&&\"none\"!==T?[0]:[]);k.enter().append(\"g\").classed(\"slicetext\",!0),k.exit().remove(),k.each((function(){var h=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),p=a.ensureUniformFontSize(t,m(d,o,r.font));h.text(o.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,p).call(l.convertToTspans,t);var g,y,x,b=i.bBox(h.node()),_=Math.min(o.BL[1],o.BR[1])+v,w=Math.max(o.TL[1],o.TR[1])+v;y=Math.max(o.TL[0],o.BL[0])+u,x=Math.min(o.TR[0],o.BR[0])+u,(g=c(y,x,_,w,b,{isHorizontal:!0,constrained:!0,angle:0,anchor:\"middle\"})).fontSize=p.size,f(d.type,g,r),e[s].transform=g,h.attr(\"transform\",a.getTextTransform(g))}))}}));var v=n.select(this).selectAll(\"g.titletext\").data(d.title.text?[0]:[]);v.enter().append(\"g\").classed(\"titletext\",!0),v.exit().remove(),v.each((function(){var e=a.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),c=d.title.text;d._meta&&(c=a.templateString(c,d._meta)),e.text(c).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(i.font,d.title.font).call(l.convertToTspans,t);var u=x(h,r._size);e.attr(\"transform\",s(u.x,u.y)+o(Math.min(1,u.scale))+s(u.tx,u.ty))}))}))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/plot\":932,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,d3:169}],1064:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../pie/style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._funnelarealayer.selectAll(\".trace\");a(t,e,\"funnelarea\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"../pie/style_one\":1172,d3:169}],1065:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=(t(\"../../constants/docs\").FORMAT_LINK,t(\"../../lib/extend\").extendFlat);e.exports=s({z:{valType:\"data_array\",editType:\"calc\"},x:s({},n.x,{impliedEdits:{xtype:\"array\"}}),x0:s({},n.x0,{impliedEdits:{xtype:\"scaled\"}}),dx:s({},n.dx,{impliedEdits:{xtype:\"scaled\"}}),y:s({},n.y,{impliedEdits:{ytype:\"array\"}}),y0:s({},n.y0,{impliedEdits:{ytype:\"scaled\"}}),dy:s({},n.dy,{impliedEdits:{ytype:\"scaled\"}}),xperiod:s({},n.xperiod,{impliedEdits:{xtype:\"scaled\"}}),yperiod:s({},n.yperiod,{impliedEdits:{ytype:\"scaled\"}}),xperiod0:s({},n.xperiod0,{impliedEdits:{xtype:\"scaled\"}}),yperiod0:s({},n.yperiod0,{impliedEdits:{ytype:\"scaled\"}}),xperiodalignment:s({},n.xperiodalignment,{impliedEdits:{xtype:\"scaled\"}}),yperiodalignment:s({},n.yperiodalignment,{impliedEdits:{ytype:\"scaled\"}}),text:{valType:\"data_array\",editType:\"calc\"},hovertext:{valType:\"data_array\",editType:\"calc\"},transpose:{valType:\"boolean\",dflt:!1,editType:\"calc\"},xtype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},ytype:{valType:\"enumerated\",values:[\"array\",\"scaled\"],editType:\"calc+clearAxisTypes\"},zsmooth:{valType:\"enumerated\",values:[\"fast\",\"best\",!1],dflt:!1,editType:\"calc\"},hoverongaps:{valType:\"boolean\",dflt:!0,editType:\"none\"},connectgaps:{valType:\"boolean\",editType:\"calc\"},xgap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},ygap:{valType:\"number\",dflt:0,min:0,editType:\"plot\"},zhoverformat:{valType:\"string\",dflt:\"\",editType:\"none\"},hovertemplate:a(),showlegend:s({},i.showlegend,{dflt:!1})},{transforms:void 0},o(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1066:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../histogram2d/calc\"),l=t(\"../../components/colorscale/calc\"),c=t(\"./convert_column_xyz\"),u=t(\"./clean_2d_array\"),f=t(\"./interp2d\"),h=t(\"./find_empties\"),p=t(\"./make_bound_array\"),d=t(\"../../constants/numerical\").BADNUM;function g(t){for(var e=[],r=t.length,n=0;n<r;n++){var i=t[n];i!==d&&e.push(i)}return e}e.exports=function(t,e){var r,m,v,y,x,b,_,w,T,k,M,A=a.getFromId(t,e.xaxis||\"x\"),S=a.getFromId(t,e.yaxis||\"y\"),E=n.traceIs(e,\"contour\"),C=n.traceIs(e,\"histogram\"),L=n.traceIs(e,\"gl2d\"),I=E?\"best\":e.zsmooth;if(A._minDtick=0,S._minDtick=0,C)y=(M=s(t,e)).orig_x,r=M.x,m=M.x0,v=M.dx,w=M.orig_y,x=M.y,b=M.y0,_=M.dy,T=M.z;else{var P=e.z;i.isArray1D(P)?(c(e,A,S,\"x\",\"y\",[\"z\"]),r=e._x,x=e._y,P=e._z):(y=e.x?A.makeCalcdata(e,\"x\"):[],w=e.y?S.makeCalcdata(e,\"y\"):[],r=o(e,A,\"x\",y),x=o(e,S,\"y\",w),e._x=r,e._y=x),m=e.x0,v=e.dx,b=e.y0,_=e.dy,T=u(P,e,A,S)}function z(t){I=e._input.zsmooth=e.zsmooth=!1,i.warn('cannot use zsmooth: \"fast\": '+t)}if((A.rangebreaks||S.rangebreaks)&&(T=function(t,e,r){for(var n=[],i=-1,a=0;a<r.length;a++)if(e[a]!==d){i++,n[i]=[];for(var o=0;o<r[a].length;o++)t[o]!==d&&n[i].push(r[a][o])}return n}(r,x,T),C||(r=g(r),x=g(x),e._x=r,e._y=x)),C||!E&&!e.connectgaps||(e._emptypoints=h(T),f(T,e._emptypoints)),\"fast\"===I)if(\"log\"===A.type||\"log\"===S.type)z(\"log axis found\");else if(!C){if(r.length){var O=(r[r.length-1]-r[0])/(r.length-1),D=Math.abs(O/100);for(k=0;k<r.length-1;k++)if(Math.abs(r[k+1]-r[k]-O)>D){z(\"x scale is not linear\");break}}if(x.length&&\"fast\"===I){var R=(x[x.length-1]-x[0])/(x.length-1),F=Math.abs(R/100);for(k=0;k<x.length-1;k++)if(Math.abs(x[k+1]-x[k]-R)>F){z(\"y scale is not linear\");break}}}var B=i.maxRowLength(T),N=\"scaled\"===e.xtype?\"\":r,j=p(e,N,m,v,B,A),U=\"scaled\"===e.ytype?\"\":x,V=p(e,U,b,_,T.length,S);L||(e._extremes[A._id]=a.findExtremes(A,j),e._extremes[S._id]=a.findExtremes(S,V));var q={x:j,y:V,z:T,text:e._text||e.text,hovertext:e._hovertext||e.hovertext};if(e.xperiodalignment&&y&&(q.orig_x=y),e.yperiodalignment&&w&&(q.orig_y=w),N&&N.length===j.length-1&&(q.xCenter=N),U&&U.length===V.length-1&&(q.yCenter=U),C&&(q.xRanges=M.xRanges,q.yRanges=M.yRanges,q.pts=M.pts),E||l(t,e,{vals:T,cLetter:\"z\"}),E&&e.contours&&\"heatmap\"===e.contours.coloring){var H={type:\"contour\"===e.type?\"heatmap\":\"histogram2d\",xcalendar:e.xcalendar,ycalendar:e.ycalendar};q.xfill=p(H,N,m,v,B,A),q.yfill=p(H,U,b,_,T.length,S)}return[q]}},{\"../../components/colorscale/calc\":651,\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../histogram2d/calc\":1098,\"./clean_2d_array\":1067,\"./convert_column_xyz\":1069,\"./find_empties\":1071,\"./interp2d\":1074,\"./make_bound_array\":1075}],1067:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r,o){var s,l,c,u,f,h;function p(t){if(n(t))return+t}if(e&&e.transpose){for(s=0,f=0;f<t.length;f++)s=Math.max(s,t[f].length);if(0===s)return!1;c=function(t){return t.length},u=function(t,e,r){return(t[r]||[])[e]}}else s=t.length,c=function(t,e){return t[e].length},u=function(t,e,r){return(t[e]||[])[r]};var d=function(t,e,r){return e===a||r===a?a:u(t,e,r)};function g(t){if(e&&\"carpet\"!==e.type&&\"contourcarpet\"!==e.type&&t&&\"category\"===t.type&&e[\"_\"+t._id.charAt(0)].length){var r=t._id.charAt(0),n={},o=e[\"_\"+r+\"CategoryMap\"]||e[r];for(f=0;f<o.length;f++)n[o[f]]=f;return function(e){var r=n[t._categories[e]];return r+1?r:a}}return i.identity}var m=g(r),v=g(o);o&&\"category\"===o.type&&(s=o._categories.length);var y=new Array(s);for(f=0;f<s;f++)for(l=r&&\"category\"===r.type?r._categories.length:c(t,f),y[f]=new Array(l),h=0;h<l;h++)y[f][h]=p(d(t,v(f),m(h)));return y}},{\"../../constants/numerical\":753,\"../../lib\":778,\"fast-isnumeric\":241}],1068:[function(t,e,r){\"use strict\";e.exports={min:\"zmin\",max:\"zmax\"}},{}],1069:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/align_period\");e.exports=function(t,e,r,o,s,l){var c=t._length,u=e.makeCalcdata(t,o),f=r.makeCalcdata(t,s);u=a(t,e,o,u),f=a(t,r,s,f);var h,p,d,g,m=t.text,v=void 0!==m&&n.isArray1D(m),y=t.hovertext,x=void 0!==y&&n.isArray1D(y),b=n.distinctVals(u),_=b.vals,w=n.distinctVals(f),T=w.vals,k=[],M=T.length,A=_.length;for(h=0;h<l.length;h++)k[h]=n.init2dArray(M,A);v&&(d=n.init2dArray(M,A)),x&&(g=n.init2dArray(M,A));var S=n.init2dArray(M,A);for(h=0;h<c;h++)if(u[h]!==i&&f[h]!==i){var E=n.findBin(u[h]+b.minDiff/2,_),C=n.findBin(f[h]+w.minDiff/2,T);for(p=0;p<l.length;p++){var L=t[l[p]];k[p][C][E]=L[h],S[C][E]=h}v&&(d[C][E]=m[h]),x&&(g[C][E]=y[h])}for(t[\"_\"+o]=_,t[\"_\"+s]=T,p=0;p<l.length;p++)t[\"_\"+l[p]]=k[p];v&&(t._text=d),x&&(t._hovertext=g),e&&\"category\"===e.type&&(t[\"_\"+o+\"CategoryMap\"]=_.map((function(t){return e._categories[t]}))),r&&\"category\"===r.type&&(t[\"_\"+s+\"CategoryMap\"]=T.map((function(t){return r._categories[t]}))),t._after2before=S}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825}],1070:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./xyz_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./style_defaults\"),s=t(\"../../components/colorscale/defaults\"),l=t(\"./attributes\");e.exports=function(t,e,r,c){function u(r,i){return n.coerce(t,e,l,r,i)}i(t,e,u,c)?(a(t,e,c,u),u(\"text\"),u(\"hovertext\"),u(\"hovertemplate\"),o(t,e,u,c),u(\"hoverongaps\"),u(\"connectgaps\",n.isArray1D(e.z)&&!1!==e.zsmooth),s(t,e,c,u,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1065,\"./style_defaults\":1078,\"./xyz_defaults\":1079}],1071:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").maxRowLength;e.exports=function(t){var e,r,i,a,o,s,l,c,u=[],f={},h=[],p=t[0],d=[],g=[0,0,0],m=n(t);for(r=0;r<t.length;r++)for(e=d,d=p,p=t[r+1]||[],i=0;i<m;i++)void 0===d[i]&&((s=(void 0!==d[i-1]?1:0)+(void 0!==d[i+1]?1:0)+(void 0!==e[i]?1:0)+(void 0!==p[i]?1:0))?(0===r&&s++,0===i&&s++,r===t.length-1&&s++,i===d.length-1&&s++,s<4&&(f[[r,i]]=[r,i,s]),u.push([r,i,s])):h.push([r,i]));for(;h.length;){for(l={},c=!1,o=h.length-1;o>=0;o--)(s=((f[[(r=(a=h[o])[0])-1,i=a[1]]]||g)[2]+(f[[r+1,i]]||g)[2]+(f[[r,i-1]]||g)[2]+(f[[r,i+1]]||g)[2])/20)&&(l[a]=[r,i,s],h.splice(o,1),c=!0);if(!c)throw\"findEmpties iterated with no new neighbors\";for(a in l)f[a]=l[a],u.push(l[a])}return u.sort((function(t,e){return e[2]-t[2]}))}},{\"../../lib\":778}],1072:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../components/colorscale\").extractOpts;e.exports=function(t,e,r,s,l,c){var u,f,h,p,d=t.cd[0],g=d.trace,m=t.xa,v=t.ya,y=d.x,x=d.y,b=d.z,_=d.xCenter,w=d.yCenter,T=d.zmask,k=g.zhoverformat,M=y,A=x;if(!1!==t.index){try{h=Math.round(t.index[1]),p=Math.round(t.index[0])}catch(e){return void i.error(\"Error hovering on heatmap, pointNumber must be [row,col], found:\",t.index)}if(h<0||h>=b[0].length||p<0||p>b.length)return}else{if(n.inbox(e-y[0],e-y[y.length-1],0)>0||n.inbox(r-x[0],r-x[x.length-1],0)>0)return;if(c){var S;for(M=[2*y[0]-y[1]],S=1;S<y.length;S++)M.push((y[S]+y[S-1])/2);for(M.push([2*y[y.length-1]-y[y.length-2]]),A=[2*x[0]-x[1]],S=1;S<x.length;S++)A.push((x[S]+x[S-1])/2);A.push([2*x[x.length-1]-x[x.length-2]])}h=Math.max(0,Math.min(M.length-2,i.findBin(e,M))),p=Math.max(0,Math.min(A.length-2,i.findBin(r,A)))}var E,C,L=m.c2p(y[h]),I=m.c2p(y[h+1]),P=v.c2p(x[p]),z=v.c2p(x[p+1]);c?(E=d.orig_x||y,C=d.orig_y||x,I=L,u=E[h],z=P,f=C[p]):(E=d.orig_x||_||y,C=d.orig_y||w||x,u=_?E[h]:(E[h]+E[h+1])/2,f=w?C[p]:(C[p]+C[p+1])/2,m&&\"category\"===m.type&&(u=y[h]),v&&\"category\"===v.type&&(f=x[p]),g.zsmooth&&(L=I=m.c2p(u),P=z=v.c2p(f)));var O=b[p][h];if(T&&!T[p][h]&&(O=void 0),void 0!==O||g.hoverongaps){var D;Array.isArray(d.hovertext)&&Array.isArray(d.hovertext[p])?D=d.hovertext[p][h]:Array.isArray(d.text)&&Array.isArray(d.text[p])&&(D=d.text[p][h]);var R=o(g),F={type:\"linear\",range:[R.min,R.max],hoverformat:k,_separators:m._separators,_numFormat:m._numFormat},B=a.tickText(F,O,\"hover\").text;return[i.extendFlat(t,{index:g._after2before?g._after2before[p][h]:[p,h],distance:t.maxHoverDistance,spikeDistance:t.maxSpikeDistance,x0:L,x1:I,y0:P,y1:z,xLabelVal:u,yLabelVal:f,zLabelVal:O,zLabel:B,text:D})]}}},{\"../../components/colorscale\":655,\"../../components/fx\":683,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1073:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:t(\"./colorbar\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),moduleType:\"trace\",name:\"heatmap\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1065,\"./calc\":1066,\"./colorbar\":1068,\"./defaults\":1070,\"./hover\":1072,\"./plot\":1076,\"./style\":1077}],1074:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=[[-1,0],[1,0],[0,-1],[0,1]];function a(t){return.5-.25*Math.min(1,.5*t)}function o(t,e,r){var n,a,o,s,l,c,u,f,h,p,d,g,m,v=0;for(s=0;s<e.length;s++){for(a=(n=e[s])[0],o=n[1],d=t[a][o],p=0,h=0,l=0;l<4;l++)(u=t[a+(c=i[l])[0]])&&void 0!==(f=u[o+c[1]])&&(0===p?g=m=f:(g=Math.min(g,f),m=Math.max(m,f)),h++,p+=f);if(0===h)throw\"iterateInterp2d order is wrong: no defined neighbors\";t[a][o]=p/h,void 0===d?h<4&&(v=1):(t[a][o]=(1+r)*t[a][o]-r*d,m>g&&(v=Math.max(v,Math.abs(t[a][o]-d)/(m-g))))}return v}e.exports=function(t,e){var r,i=1;for(o(t,e),r=0;r<e.length&&!(e[r][2]<4);r++);for(e=e.slice(r),r=0;r<100&&i>.01;r++)i=o(t,e,a(i));return i>.01&&n.log(\"interp2d didn't converge quickly\",i),t}},{\"../../lib\":778}],1075:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a,o,s){var l,c,u,f=[],h=n.traceIs(t,\"contour\"),p=n.traceIs(t,\"histogram\"),d=n.traceIs(t,\"gl2d\");if(i(e)&&e.length>1&&!p&&\"category\"!==s.type){var g=e.length;if(!(g<=o))return h?e.slice(0,o):e.slice(0,o+1);if(h||d)f=e.slice(0,o);else if(1===o)f=[e[0]-.5,e[0]+.5];else{for(f=[1.5*e[0]-.5*e[1]],u=1;u<g;u++)f.push(.5*(e[u-1]+e[u]));f.push(1.5*e[g-1]-.5*e[g-2])}if(g<o){var m=f[f.length-1],v=m-f[f.length-2];for(u=g;u<o;u++)m+=v,f.push(m)}}else{var y=t[s._id.charAt(0)+\"calendar\"];if(p)l=s.r2c(r,0,y);else if(i(e)&&1===e.length)l=e[0];else if(void 0===r)l=0;else{l=(\"log\"===s.type?s.d2c:s.r2c)(r,0,y)}for(c=a||1,u=h||d?0:-.5;u<o;u++)f.push(l+c*u)}return f}},{\"../../lib\":778,\"../../registry\":911}],1076:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"tinycolor2\"),a=t(\"../../registry\"),o=t(\"../../lib\"),s=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,l=t(\"../../constants/xmlns_namespaces\");function c(t,e){var r=e.length-2,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=e[n+1],s=o.constrain(n+(t-i)/(a-i)-.5,0,r),l=Math.round(s),c=Math.abs(s-l);return s&&s!==r&&c?{bin0:l,frac:c,bin1:Math.round(l+c/(s-l))}:{bin0:l,bin1:l,frac:0}}function u(t,e){var r=e.length-1,n=o.constrain(o.findBin(t,e),0,r),i=e[n],a=(t-i)/(e[n+1]-i)||0;return a<=0?{bin0:n,bin1:n,frac:0}:a<.5?{bin0:n,bin1:n+1,frac:a}:{bin0:n+1,bin1:n,frac:1-a}}function f(t,e,r){t[e]=r[0],t[e+1]=r[1],t[e+2]=r[2],t[e+3]=Math.round(255*r[3])}e.exports=function(t,e,r,h){var p=e.xaxis,d=e.yaxis;o.makeTraceGroups(h,r,\"hm\").each((function(e){var r,h,g,m,v,y,x=n.select(this),b=e[0],_=b.trace,w=b.z,T=b.x,k=b.y,M=b.xCenter,A=b.yCenter,S=a.traceIs(_,\"contour\"),E=S?\"best\":_.zsmooth,C=w.length,L=o.maxRowLength(w),I=!1,P=!1;for(y=0;void 0===r&&y<T.length-1;)r=p.c2p(T[y]),y++;for(y=T.length-1;void 0===h&&y>0;)h=p.c2p(T[y]),y--;for(h<r&&(g=h,h=r,r=g,I=!0),y=0;void 0===m&&y<k.length-1;)m=d.c2p(k[y]),y++;for(y=k.length-1;void 0===v&&y>0;)v=d.c2p(k[y]),y--;if(v<m&&(g=m,m=v,v=g,P=!0),S&&(M=T,A=k,T=b.xfill,k=b.yfill),\"fast\"!==E){var z=\"best\"===E?0:.5;r=Math.max(-z*p._length,r),h=Math.min((1+z)*p._length,h),m=Math.max(-z*d._length,m),v=Math.min((1+z)*d._length,v)}var O=Math.round(h-r),D=Math.round(v-m);if(O<=0||D<=0){x.selectAll(\"image\").data([]).exit().remove()}else{var R,F;\"fast\"===E?(R=L,F=C):(R=O,F=D);var B=document.createElement(\"canvas\");B.width=R,B.height=F;var N,j,U=B.getContext(\"2d\"),V=s(_,{noNumericCheck:!0,returnArray:!0});\"fast\"===E?(N=I?function(t){return L-1-t}:o.identity,j=P?function(t){return C-1-t}:o.identity):(N=function(t){return o.constrain(Math.round(p.c2p(T[t])-r),0,O)},j=function(t){return o.constrain(Math.round(d.c2p(k[t])-m),0,D)});var q,H,G,Y,W,X=j(0),Z=[X,X],J=I?0:1,K=P?0:1,Q=0,$=0,tt=0,et=0;if(E){var rt,nt=0;try{rt=new Uint8Array(O*D*4)}catch(t){rt=new Array(O*D*4)}if(\"best\"===E){var it,at,ot,st=M||T,lt=A||k,ct=new Array(st.length),ut=new Array(lt.length),ft=new Array(O),ht=M?u:c,pt=A?u:c;for(y=0;y<st.length;y++)ct[y]=Math.round(p.c2p(st[y])-r);for(y=0;y<lt.length;y++)ut[y]=Math.round(d.c2p(lt[y])-m);for(y=0;y<O;y++)ft[y]=ht(y,ct);for(H=0;H<D;H++)for(at=w[(it=pt(H,ut)).bin0],ot=w[it.bin1],y=0;y<O;y++,nt+=4)f(rt,nt,W=kt(at,ot,ft[y],it))}else for(H=0;H<C;H++)for(Y=w[H],Z=j(H),y=0;y<O;y++)W=Tt(Y[y],1),f(rt,nt=4*(Z*O+N(y)),W);var dt=U.createImageData(O,D);try{dt.data.set(rt)}catch(t){var gt=dt.data,mt=gt.length;for(H=0;H<mt;H++)gt[H]=rt[H]}U.putImageData(dt,0,0)}else{var vt=_.xgap,yt=_.ygap,xt=Math.floor(vt/2),bt=Math.floor(yt/2);for(H=0;H<C;H++)if(Y=w[H],Z.reverse(),Z[K]=j(H+1),Z[0]!==Z[1]&&void 0!==Z[0]&&void 0!==Z[1])for(q=[G=N(0),G],y=0;y<L;y++)q.reverse(),q[J]=N(y+1),q[0]!==q[1]&&void 0!==q[0]&&void 0!==q[1]&&(W=Tt(Y[y],(q[1]-q[0])*(Z[1]-Z[0])),U.fillStyle=\"rgba(\"+W.join(\",\")+\")\",U.fillRect(q[0]+xt,Z[0]+bt,q[1]-q[0]-vt,Z[1]-Z[0]-yt))}$=Math.round($/Q),tt=Math.round(tt/Q),et=Math.round(et/Q);var _t=i(\"rgb(\"+$+\",\"+tt+\",\"+et+\")\");t._hmpixcount=(t._hmpixcount||0)+Q,t._hmlumcount=(t._hmlumcount||0)+Q*_t.getLuminance();var wt=x.selectAll(\"image\").data(e);wt.enter().append(\"svg:image\").attr({xmlns:l.svg,preserveAspectRatio:\"none\"}),wt.attr({height:D,width:O,x:r,y:m,\"xlink:href\":B.toDataURL(\"image/png\")})}function Tt(t,e){if(void 0!==t){var r=V(t);return r[0]=Math.round(r[0]),r[1]=Math.round(r[1]),r[2]=Math.round(r[2]),Q+=e,$+=r[0]*e,tt+=r[1]*e,et+=r[2]*e,r}return[0,0,0,0]}function kt(t,e,r,n){var i=t[r.bin0];if(void 0===i)return Tt(void 0,1);var a,o=t[r.bin1],s=e[r.bin0],l=e[r.bin1],c=o-i||0,u=s-i||0;return a=void 0===o?void 0===l?0:void 0===s?2*(l-i):2*(2*l-s-i)/3:void 0===l?void 0===s?0:2*(2*i-o-s)/3:void 0===s?2*(2*l-o-i)/3:l+i-o-s,Tt(i+r.frac*c+n.frac*(u+r.frac*a))}}))}},{\"../../components/colorscale\":655,\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"../../registry\":911,d3:169,tinycolor2:576}],1077:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".hm image\").style(\"opacity\",(function(t){return t.trace.opacity}))}},{d3:169}],1078:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){!1===r(\"zsmooth\")&&(r(\"xgap\"),r(\"ygap\")),r(\"zhoverformat\")}},{}],1079:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\");function o(t,e){var r=e(t);return\"scaled\"===(r?e(t+\"type\",\"array\"):\"scaled\")&&(e(t+\"0\"),e(\"d\"+t)),r}e.exports=function(t,e,r,s,l,c){var u,f,h=r(\"z\");if(l=l||\"x\",c=c||\"y\",void 0===h||!h.length)return 0;if(i.isArray1D(t.z)){u=r(l),f=r(c);var p=i.minRowLength(u),d=i.minRowLength(f);if(0===p||0===d)return 0;e._length=Math.min(p,d,h.length)}else{if(u=o(l,r),f=o(c,r),!function(t){for(var e,r=!0,a=!1,o=!1,s=0;s<t.length;s++){if(e=t[s],!i.isArrayOrTypedArray(e)){r=!1;break}e.length>0&&(a=!0);for(var l=0;l<e.length;l++)if(n(e[l])){o=!0;break}}return r&&a&&o}(h))return 0;r(\"transpose\"),e._length=null}return\"heatmapgl\"===t.type||\"contourgl\"===t.type||a.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[l,c],s),!0}},{\"../../lib\":778,\"../../registry\":911,\"fast-isnumeric\":241}],1080:[function(t,e,r){\"use strict\";for(var n=t(\"../heatmap/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../lib/extend\").extendFlat,o=t(\"../../plot_api/edit_types\").overrideAll,s=[\"z\",\"x\",\"x0\",\"dx\",\"y\",\"y0\",\"dy\",\"text\",\"transpose\",\"xtype\",\"ytype\"],l={},c=0;c<s.length;c++){var u=s[c];l[u]=n[u]}l.zsmooth={valType:\"enumerated\",values:[\"fast\",!1],dflt:\"fast\",editType:\"calc\"},a(l,i(\"\",{cLetter:\"z\",autoColorDflt:!1})),e.exports=o(l,\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../heatmap/attributes\":1065}],1081:[function(t,e,r){\"use strict\";var n=t(\"gl-heatmap2d\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../lib/str2rgbarray\");function o(t,e){this.scene=t,this.uid=e,this.type=\"heatmapgl\",this.name=\"\",this.hoverinfo=\"all\",this.xData=[],this.yData=[],this.zData=[],this.textLabels=[],this.idToIndex=[],this.bounds=[0,0,0,0],this.options={zsmooth:\"fast\",z:[],x:[],y:[],shape:[0,0],colorLevels:[0],colorValues:[0,0,0,1]},this.heatmap=n(t.glplot,this.options),this.heatmap._trace=this}var s=o.prototype;s.handlePick=function(t){var e=this.options,r=e.shape,n=t.pointId,i=n%r[0],a=Math.floor(n/r[0]),o=n;return{trace:this,dataCoord:t.dataCoord,traceCoord:[e.x[i],e.y[a],e.z[o]],textLabel:this.textLabels[n],name:this.name,pointIndex:[a,i],hoverinfo:this.hoverinfo}},s.update=function(t,e){var r=e[0];this.index=t.index,this.name=t.name,this.hoverinfo=t.hoverinfo;var n=r.z;this.options.z=[].concat.apply([],n);var o=n[0].length,s=n.length;this.options.shape=[o,s],this.options.x=r.x,this.options.y=r.y,this.options.zsmooth=t.zsmooth;var l=function(t){for(var e=t.colorscale,r=t.zmin,n=t.zmax,i=e.length,o=new Array(i),s=new Array(4*i),l=0;l<i;l++){var c=e[l],u=a(c[1]);o[l]=r+c[0]*(n-r);for(var f=0;f<4;f++)s[4*l+f]=u[f]}return{colorLevels:o,colorValues:s}}(t);this.options.colorLevels=l.colorLevels,this.options.colorValues=l.colorValues,this.textLabels=[].concat.apply([],t.text),this.heatmap.update(this.options);var c,u,f=this.scene.xaxis,h=this.scene.yaxis;!1===t.zsmooth&&(c={ppad:r.x[1]-r.x[0]},u={ppad:r.y[1]-r.y[0]}),t._extremes[f._id]=i.findExtremes(f,r.x,c),t._extremes[h._id]=i.findExtremes(h,r.y,u)},s.dispose=function(){this.heatmap.dispose()},e.exports=function(t,e,r){var n=new o(t,e.uid);return n.update(e,r),n}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"gl-heatmap2d\":271}],1082:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../heatmap/xyz_defaults\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}i(t,e,l,s)?(l(\"text\"),l(\"zsmooth\"),a(t,e,s,l,{prefix:\"\",cLetter:\"z\"})):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/xyz_defaults\":1079,\"./attributes\":1080}],1083:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../heatmap/colorbar\"),calc:t(\"../heatmap/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"heatmapgl\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"2dMap\"],meta:{}}},{\"../../plots/gl2d\":868,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"./attributes\":1080,\"./convert\":1081,\"./defaults\":1082}],1084:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"./bin_attributes\"),o=t(\"./constants\"),s=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},text:s({},n.text,{}),hovertext:s({},n.hovertext,{}),orientation:n.orientation,histfunc:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"min\",\"max\"],dflt:\"count\",editType:\"calc\"},histnorm:{valType:\"enumerated\",values:[\"\",\"percent\",\"probability\",\"density\",\"probability density\"],dflt:\"\",editType:\"calc\"},cumulative:{enabled:{valType:\"boolean\",dflt:!1,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"increasing\",\"decreasing\"],dflt:\"increasing\",editType:\"calc\"},currentbin:{valType:\"enumerated\",values:[\"include\",\"exclude\",\"half\"],dflt:\"include\",editType:\"calc\"},editType:\"calc\"},nbinsx:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},xbins:a(\"x\",!0),nbinsy:{valType:\"integer\",min:0,dflt:0,editType:\"calc\"},ybins:a(\"y\",!0),autobinx:{valType:\"boolean\",dflt:null,editType:\"calc\"},autobiny:{valType:\"boolean\",dflt:null,editType:\"calc\"},bingroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({},{keys:o.eventDataKeys}),marker:n.marker,offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,_deprecated:{bardir:n._deprecated.bardir}}},{\"../../lib/extend\":768,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"./bin_attributes\":1086,\"./constants\":1090}],1085:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=t.length,n=0,i=0;i<r;i++)e[i]?(t[i]/=e[i],n+=t[i]):t[i]=null;return n}},{}],1086:[function(t,e,r){\"use strict\";e.exports=function(t,e){return{start:{valType:\"any\",editType:\"calc\"},end:{valType:\"any\",editType:\"calc\"},size:{valType:\"any\",editType:\"calc\"},editType:\"calc\"}}},{}],1087:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports={count:function(t,e,r){return r[t]++,1},sum:function(t,e,r,i){var a=i[e];return n(a)?(a=Number(a),r[t]+=a,a):0},avg:function(t,e,r,i,a){var o=i[e];return n(o)&&(o=Number(o),r[t]+=o,a[t]++),0},min:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]>a){var o=a-r[t];return r[t]=a,o}}return 0},max:function(t,e,r,i){var a=i[e];if(n(a)){if(a=Number(a),!n(r[t]))return r[t]=a,a;if(r[t]<a){var o=a-r[t];return r[t]=a,o}}return 0}}},{\"fast-isnumeric\":241}],1088:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.ONEAVGYEAR,a=n.ONEAVGMONTH,o=n.ONEDAY,s=n.ONEHOUR,l=n.ONEMIN,c=n.ONESEC,u=t(\"../../plots/cartesian/axes\").tickIncrement;function f(t,e,r,n){if(t*e<=0)return 1/0;for(var i=Math.abs(e-t),a=\"date\"===r.type,o=h(i,a),s=0;s<10;s++){var l=h(80*o,a);if(o===l)break;if(!p(l,t,e,a,r,n))break;o=l}return o}function h(t,e){return e&&t>c?t>o?t>1.1*i?i:t>1.1*a?a:o:t>s?s:t>l?l:c:Math.pow(10,Math.floor(Math.log(t)/Math.LN10))}function p(t,e,r,n,a,s){if(n&&t>o){var l=d(e,a,s),c=d(r,a,s),u=t===i?0:1;return l[u]!==c[u]}return Math.floor(r/t)-Math.floor(e/t)>.1}function d(t,e,r){var n=e.c2d(t,i,r).split(\"-\");return\"\"===n[0]&&(n.unshift(),n[0]=\"-\"+n[0]),n}e.exports=function(t,e,r,n,a){var s,l,c=-1.1*e,h=-.1*e,p=t-h,d=r[0],g=r[1],m=Math.min(f(d+h,d+p,n,a),f(g+h,g+p,n,a)),v=Math.min(f(d+c,d+h,n,a),f(g+c,g+h,n,a));if(m>v&&v<Math.abs(g-d)/4e3?(s=m,l=!1):(s=Math.min(m,v),l=!0),\"date\"===n.type&&s>o){var y=s===i?1:6,x=s===i?\"M12\":\"M1\";return function(e,r){var o=n.c2d(e,i,a),s=o.indexOf(\"-\",y);s>0&&(o=o.substr(0,s));var c=n.d2c(o,0,a);if(c<e){var f=u(c,x,!1,a);(c+f)/2<e+t&&(c=f)}return r&&l?u(c,x,!0,a):c}}return function(e,r){var n=s*Math.round(e/s);return n+s/10<e&&n+.9*s<e+t&&(n+=s),r&&l&&(n-=s),n}}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828}],1089:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../registry\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../bar/arrays_to_calcdata\"),l=t(\"./bin_functions\"),c=t(\"./norm_functions\"),u=t(\"./average\"),f=t(\"./bin_label_vals\");function h(t,e,r,s,l){var c,u,f,p,d,g,m,v=s+\"bins\",y=t._fullLayout,x=e[\"_\"+s+\"bingroup\"],b=y._histogramBinOpts[x],_=\"overlay\"===y.barmode,w=function(t){return r.r2c(t,0,p)},T=function(t){return r.c2r(t,0,p)},k=\"date\"===r.type?function(t){return t||0===t?i.cleanDate(t,null,p):null}:function(t){return n(t)?Number(t):null};function M(t,e,r){e[t+\"Found\"]?(e[t]=k(e[t]),null===e[t]&&(e[t]=r[t])):(g[t]=e[t]=r[t],i.nestedProperty(u[0],v+\".\"+t).set(r[t]))}if(e[\"_\"+s+\"autoBinFinished\"])delete e[\"_\"+s+\"autoBinFinished\"];else{u=b.traces;var A=[],S=!0,E=!1,C=!1;for(c=0;c<u.length;c++)if((f=u[c]).visible){var L=b.dirs[c];d=f[\"_\"+L+\"pos0\"]=r.makeCalcdata(f,L),A=i.concat(A,d),delete f[\"_\"+s+\"autoBinFinished\"],!0===e.visible&&(S?S=!1:(delete f._autoBin,f[\"_\"+s+\"autoBinFinished\"]=1),a.traceIs(f,\"2dMap\")&&(E=!0),\"histogram2dcontour\"===f.type&&(C=!0))}p=u[0][s+\"calendar\"];var I=o.autoBin(A,r,b.nbins,E,p,b.sizeFound&&b.size),P=u[0]._autoBin={};if(g=P[b.dirs[0]]={},C&&(b.size||(I.start=T(o.tickIncrement(w(I.start),I.size,!0,p))),void 0===b.end&&(I.end=T(o.tickIncrement(w(I.end),I.size,!1,p)))),_&&!a.traceIs(e,\"2dMap\")&&0===I._dataSpan&&\"category\"!==r.type&&\"multicategory\"!==r.type){if(l)return[I,d,!0];I=function(t,e,r,n,a){var o,s,l,c=t._fullLayout,u=function(t,e){for(var r=e.xaxis,n=e.yaxis,i=e.orientation,a=[],o=t._fullData,s=0;s<o.length;s++){var l=o[s];\"histogram\"===l.type&&!0===l.visible&&l.orientation===i&&l.xaxis===r&&l.yaxis===n&&a.push(l)}return a}(t,e),f=!1,p=1/0,d=[e];for(o=0;o<u.length;o++)if((s=u[o])===e)f=!0;else if(f){var g=h(t,s,r,n,!0),m=g[0],v=g[2];s[\"_\"+n+\"autoBinFinished\"]=1,s[\"_\"+n+\"pos0\"]=g[1],v?d.push(s):p=Math.min(p,m.size)}else l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]],p=Math.min(p,l.size||s[a].size);var y=new Array(d.length);for(o=0;o<d.length;o++)for(var x=d[o][\"_\"+n+\"pos0\"],b=0;b<x.length;b++)if(void 0!==x[b]){y[o]=x[b];break}isFinite(p)||(p=i.distinctVals(y).minDiff);for(o=0;o<d.length;o++){var _=(s=d[o])[n+\"calendar\"],w={start:r.c2r(y[o]-p/2,0,_),end:r.c2r(y[o]+p/2,0,_),size:p};s._input[a]=s[a]=w,(l=c._histogramBinOpts[s[\"_\"+n+\"bingroup\"]])&&i.extendFlat(l,w)}return e[a]}(t,e,r,s,v)}(m=f.cumulative||{}).enabled&&\"include\"!==m.currentbin&&(\"decreasing\"===m.direction?I.start=T(o.tickIncrement(w(I.start),I.size,!0,p)):I.end=T(o.tickIncrement(w(I.end),I.size,!1,p))),b.size=I.size,b.sizeFound||(g.size=I.size,i.nestedProperty(u[0],v+\".size\").set(I.size)),M(\"start\",b,I),M(\"end\",b,I)}d=e[\"_\"+s+\"pos0\"],delete e[\"_\"+s+\"pos0\"];var z=e._input[v]||{},O=i.extendFlat({},b),D=b.start,R=r.r2l(z.start),F=void 0!==R;if((b.startFound||F)&&R!==r.r2l(D)){var B=F?R:i.aggNums(Math.min,null,d),N={type:\"category\"===r.type||\"multicategory\"===r.type?\"linear\":r.type,r2l:r.r2l,dtick:b.size,tick0:D,calendar:p,range:[B,o.tickIncrement(B,b.size,!1,p)].map(r.l2r)},j=o.tickFirst(N);j>r.r2l(B)&&(j=o.tickIncrement(j,b.size,!0,p)),O.start=r.l2r(j),F||i.nestedProperty(e,v+\".start\").set(O.start)}var U=b.end,V=r.r2l(z.end),q=void 0!==V;if((b.endFound||q)&&V!==r.r2l(U)){var H=q?V:i.aggNums(Math.max,null,d);O.end=r.l2r(H),q||i.nestedProperty(e,v+\".start\").set(O.end)}var G=\"autobin\"+s;return!1===e._input[G]&&(e._input[v]=i.extendFlat({},e[v]||{}),delete e._input[G],delete e[G]),[O,d]}e.exports={calc:function(t,e){var r,a,p,d,g=[],m=[],v=o.getFromId(t,\"h\"===e.orientation?e.yaxis:e.xaxis),y=\"h\"===e.orientation?\"y\":\"x\",x={x:\"y\",y:\"x\"}[y],b=e[y+\"calendar\"],_=e.cumulative,w=h(t,e,v,y),T=w[0],k=w[1],M=\"string\"==typeof T.size,A=[],S=M?A:T,E=[],C=[],L=[],I=0,P=e.histnorm,z=e.histfunc,O=-1!==P.indexOf(\"density\");_.enabled&&O&&(P=P.replace(/ ?density$/,\"\"),O=!1);var D,R=\"max\"===z||\"min\"===z?null:0,F=l.count,B=c[P],N=!1,j=function(t){return v.r2c(t,0,b)};for(i.isArrayOrTypedArray(e[x])&&\"count\"!==z&&(D=e[x],N=\"avg\"===z,F=l[z]),r=j(T.start),p=j(T.end)+(r-o.tickIncrement(r,T.size,!1,b))/1e6;r<p&&g.length<1e6&&(a=o.tickIncrement(r,T.size,!1,b),g.push((r+a)/2),m.push(R),L.push([]),A.push(r),O&&E.push(1/(a-r)),N&&C.push(0),!(a<=r));)r=a;A.push(r),M||\"date\"!==v.type||(S={start:j(S.start),end:j(S.end),size:S.size}),t._fullLayout._roundFnOpts||(t._fullLayout._roundFnOpts={});var U=e[\"_\"+y+\"bingroup\"],V={leftGap:1/0,rightGap:1/0};U&&(t._fullLayout._roundFnOpts[U]||(t._fullLayout._roundFnOpts[U]=V),V=t._fullLayout._roundFnOpts[U]);var q,H=m.length,G=!0,Y=V.leftGap,W=V.rightGap,X={};for(r=0;r<k.length;r++){var Z=k[r];(d=i.findBin(Z,S))>=0&&d<H&&(I+=F(d,r,m,D,C),G&&L[d].length&&Z!==k[L[d][0]]&&(G=!1),L[d].push(r),X[r]=d,Y=Math.min(Y,Z-A[d]),W=Math.min(W,A[d+1]-Z))}V.leftGap=Y,V.rightGap=W,G||(q=function(e,r){return function(){var n=t._fullLayout._roundFnOpts[U];return f(n.leftGap,n.rightGap,A,v,b)(e,r)}}),N&&(I=u(m,C)),B&&B(m,I,E),_.enabled&&function(t,e,r){var n,i,a;function o(e){a=t[e],t[e]/=2}function s(e){i=t[e],t[e]=a+i/2,a+=i}if(\"half\"===r)if(\"increasing\"===e)for(o(0),n=1;n<t.length;n++)s(n);else for(o(t.length-1),n=t.length-2;n>=0;n--)s(n);else if(\"increasing\"===e){for(n=1;n<t.length;n++)t[n]+=t[n-1];\"exclude\"===r&&(t.unshift(0),t.pop())}else{for(n=t.length-2;n>=0;n--)t[n]+=t[n+1];\"exclude\"===r&&(t.push(0),t.shift())}}(m,_.direction,_.currentbin);var J=Math.min(g.length,m.length),K=[],Q=0,$=J-1;for(r=0;r<J;r++)if(m[r]){Q=r;break}for(r=J-1;r>=Q;r--)if(m[r]){$=r;break}for(r=Q;r<=$;r++)if(n(g[r])&&n(m[r])){var tt={p:g[r],s:m[r],b:0};_.enabled||(tt.pts=L[r],G?tt.ph0=tt.ph1=L[r].length?k[L[r][0]]:g[r]:(e._computePh=!0,tt.ph0=q(A[r]),tt.ph1=q(A[r+1],!0))),K.push(tt)}return 1===K.length&&(K[0].width1=o.tickIncrement(K[0].p,T.size,!1,b)-K[0].p),s(K,e),i.isArrayOrTypedArray(e.selectedpoints)&&i.tagSelected(K,e,X),K},calcAllAutoBins:h}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../../registry\":911,\"../bar/arrays_to_calcdata\":920,\"./average\":1085,\"./bin_functions\":1087,\"./bin_label_vals\":1088,\"./norm_functions\":1096,\"fast-isnumeric\":241}],1090:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"binNumber\"]}},{}],1091:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../../registry\").traceIs,o=t(\"../bar/defaults\").handleGroupingDefaults,s=n.nestedProperty,l=t(\"../../plots/cartesian/constraints\").getAxisGroup,c=[{aStr:{x:\"xbins.start\",y:\"ybins.start\"},name:\"start\"},{aStr:{x:\"xbins.end\",y:\"ybins.end\"},name:\"end\"},{aStr:{x:\"xbins.size\",y:\"ybins.size\"},name:\"size\"},{aStr:{x:\"nbinsx\",y:\"nbinsy\"},name:\"nbins\"}],u=[\"x\",\"y\"];e.exports=function(t,e){var r,f,h,p,d,g,m,v=e._histogramBinOpts={},y=[],x={},b=[];function _(t,e){return n.coerce(r._input,r,r._module.attributes,t,e)}function w(t){return\"v\"===t.orientation?\"x\":\"y\"}function T(t,r,a){var o=t.uid+\"__\"+a;r||(r=o);var s=function(t,r){return i.getFromTrace({_fullLayout:e},t,r).type}(t,a),l=t[a+\"calendar\"]||\"\",c=v[r],u=!0;c&&(s===c.axType&&l===c.calendar?(u=!1,c.traces.push(t),c.dirs.push(a)):(r=o,s!==c.axType&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set on a\",\"type:\"+s,\"axis\",\"with bins on\",\"type:\"+c.axType,\"axis.\"].join(\" \")),l!==c.calendar&&n.warn([\"Attempted to group the bins of trace\",t.index,\"set with a\",l,\"calendar\",\"with bins\",c.calendar?\"on a \"+c.calendar+\" calendar\":\"w/o a set calendar\"].join(\" \")))),u&&(v[r]={traces:[t],dirs:[a],axType:s,calendar:t[a+\"calendar\"]||\"\"}),t[\"_\"+a+\"bingroup\"]=r}for(d=0;d<t.length;d++)r=t[d],a(r,\"histogram\")&&(y.push(r),delete r._xautoBinFinished,delete r._yautoBinFinished,a(r,\"2dMap\")||o(r._input,r,e,_));var k=e._alignmentOpts||{};for(d=0;d<y.length;d++){if(r=y[d],h=\"\",!a(r,\"2dMap\")){if(p=w(r),\"group\"===e.barmode&&r.alignmentgroup){var M=r[p+\"axis\"],A=l(e,M)+r.orientation;(k[A]||{})[r.alignmentgroup]&&(h=A)}h||\"overlay\"===e.barmode||(h=l(e,r.xaxis)+l(e,r.yaxis)+w(r))}h?(x[h]||(x[h]=[]),x[h].push(r)):b.push(r)}for(h in x)if(1!==(f=x[h]).length){var S=!1;for(f.length&&(r=f[0],S=_(\"bingroup\")),h=S||h,d=0;d<f.length;d++){var E=(r=f[d])._input.bingroup;E&&E!==h&&n.warn([\"Trace\",r.index,\"must match\",\"within bingroup\",h+\".\",\"Ignoring its bingroup:\",E,\"setting.\"].join(\" \")),r.bingroup=h,T(r,h,w(r))}}else b.push(f[0]);for(d=0;d<b.length;d++){r=b[d];var C=_(\"bingroup\");if(a(r,\"2dMap\"))for(m=0;m<2;m++){var L=_((p=u[m])+\"bingroup\",C?C+\"__\"+p:null);T(r,L,p)}else T(r,C,w(r))}for(h in v){var I=v[h];for(f=I.traces,g=0;g<c.length;g++){var P,z,O=c[g],D=O.name;if(\"nbins\"!==D||!I.sizeFound){for(d=0;d<f.length;d++){if(r=f[d],p=I.dirs[d],P=O.aStr[p],void 0!==s(r._input,P).get()){I[D]=_(P),I[D+\"Found\"]=!0;break}(z=(r._autoBin||{})[p]||{})[D]&&s(r,P).set(z[D])}if(\"start\"===D||\"end\"===D)for(;d<f.length;d++)(r=f[d])[\"_\"+p+\"bingroup\"]&&_(P,(z=(r._autoBin||{})[p]||{})[D]);\"nbins\"!==D||I.sizeFound||I.nbinsFound||(r=f[0],I[D]=_(P))}}}}},{\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../../plots/cartesian/constraints\":835,\"../../registry\":911,\"../bar/defaults\":925}],1092:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/color\"),o=t(\"../bar/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,n){return i.coerce(t,e,s,r,n)}var u=c(\"x\"),f=c(\"y\");c(\"cumulative.enabled\")&&(c(\"cumulative.direction\"),c(\"cumulative.currentbin\")),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var h=c(\"orientation\",f&&!u?\"h\":\"v\"),p=\"v\"===h?\"x\":\"y\",d=\"v\"===h?\"y\":\"x\",g=u&&f?Math.min(i.minRowLength(u)&&i.minRowLength(f)):i.minRowLength(e[p]||[]);if(g){e._length=g,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],l),e[d]&&c(\"histfunc\"),c(\"histnorm\"),c(\"autobin\"+p),o(t,e,c,r,l),i.coerceSelectionMarkerOpacity(e,c);var m=(e.marker.line||{}).color,v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,m||a.defaultLine,{axis:\"y\"}),v(t,e,m||a.defaultLine,{axis:\"x\",inherit:\"y\"})}else e.visible=!1}},{\"../../components/color\":643,\"../../lib\":778,\"../../registry\":911,\"../bar/style_defaults\":936,\"./attributes\":1084}],1093:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"zLabelVal\"in e&&(t.z=e.zLabelVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),!(r.cumulative||{}).enabled){var a,o=Array.isArray(i)?n[0].pts[i[0]][i[1]]:n[i].pts;if(t.pointNumbers=o,t.binNumber=t.pointNumber,delete t.pointNumber,delete t.pointIndex,r._indexToPoints){a=[];for(var s=0;s<o.length;s++)a=a.concat(r._indexToPoints[o[s]])}else a=o;t.pointIndices=a}return t}},{}],1094:[function(t,e,r){\"use strict\";var n=t(\"../bar/hover\").hoverPoints,i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o){var s=(t=o[0]).cd[t.index],l=t.cd[0].trace;if(!l.cumulative.enabled){var c=\"h\"===l.orientation?\"y\":\"x\";t[c+\"Label\"]=i(t[c+\"a\"],s.ph0,s.ph1)}return o}}},{\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1095:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"../bar/layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),supplyLayoutDefaults:t(\"../bar/layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"../bar/cross_trace_calc\").crossTraceCalc,plot:t(\"../bar/plot\").plot,layerName:\"barlayer\",style:t(\"../bar/style\").style,styleOnSelect:t(\"../bar/style\").styleOnSelect,colorbar:t(\"../scatter/marker_colorbar\"),hoverPoints:t(\"./hover\"),selectPoints:t(\"../bar/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"histogram\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"bar\",\"histogram\",\"oriented\",\"errorBarsOK\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/cross_trace_calc\":924,\"../bar/layout_attributes\":930,\"../bar/layout_defaults\":931,\"../bar/plot\":932,\"../bar/select\":933,\"../bar/style\":935,\"../scatter/marker_colorbar\":1205,\"./attributes\":1084,\"./calc\":1089,\"./cross_trace_defaults\":1091,\"./defaults\":1092,\"./event_data\":1093,\"./hover\":1094}],1096:[function(t,e,r){\"use strict\";e.exports={percent:function(t,e){for(var r=t.length,n=100/e,i=0;i<r;i++)t[i]*=n},probability:function(t,e){for(var r=t.length,n=0;n<r;n++)t[n]/=e},density:function(t,e,r,n){var i=t.length;n=n||1;for(var a=0;a<i;a++)t[a]*=r[a]*n},\"probability density\":function(t,e,r,n){var i=t.length;n&&(e/=n);for(var a=0;a<i;a++)t[a]*=r[a]/e}}},{}],1097:[function(t,e,r){\"use strict\";var n=t(\"../histogram/attributes\"),i=t(\"../histogram/bin_attributes\"),a=t(\"../heatmap/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../components/colorscale/attributes\"),c=t(\"../../lib/extend\").extendFlat;e.exports=c({x:n.x,y:n.y,z:{valType:\"data_array\",editType:\"calc\"},marker:{color:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:i(\"x\"),nbinsy:n.nbinsy,ybins:i(\"y\"),autobinx:n.autobinx,autobiny:n.autobiny,bingroup:c({},n.bingroup,{}),xbingroup:c({},n.bingroup,{}),ybingroup:c({},n.bingroup,{}),xgap:a.xgap,ygap:a.ygap,zsmooth:a.zsmooth,zhoverformat:a.zhoverformat,hovertemplate:s({},{keys:\"z\"}),showlegend:c({},o.showlegend,{dflt:!1})},l(\"\",{cLetter:\"z\",autoColorDflt:!1}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../heatmap/attributes\":1065,\"../histogram/attributes\":1084,\"../histogram/bin_attributes\":1086}],1098:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../histogram/bin_functions\"),o=t(\"../histogram/norm_functions\"),s=t(\"../histogram/average\"),l=t(\"../histogram/bin_label_vals\"),c=t(\"../histogram/calc\").calcAllAutoBins;function u(t,e,r,n){var i,a=new Array(t);if(n)for(i=0;i<t;i++)a[i]=1/(e[i+1]-e[i]);else{var o=1/r;for(i=0;i<t;i++)a[i]=o}return a}function f(t,e){return{start:t(e.start),end:t(e.end),size:e.size}}function h(t,e,r,n,i,a){var o,s=t.length-1,c=new Array(s),u=l(r,n,t,i,a);for(o=0;o<s;o++){var f=(e||[])[o];c[o]=void 0===f?[u(t[o]),u(t[o+1],!0)]:[f,f]}return c}e.exports=function(t,e){var r,l,p,d,g=i.getFromId(t,e.xaxis),m=i.getFromId(t,e.yaxis),v=e.xcalendar,y=e.ycalendar,x=function(t){return g.r2c(t,0,v)},b=function(t){return m.r2c(t,0,y)},_=c(t,e,g,\"x\"),w=_[0],T=_[1],k=c(t,e,m,\"y\"),M=k[0],A=k[1],S=e._length;T.length>S&&T.splice(S,T.length-S),A.length>S&&A.splice(S,A.length-S);var E=[],C=[],L=[],I=\"string\"==typeof w.size,P=\"string\"==typeof M.size,z=[],O=[],D=I?z:w,R=P?O:M,F=0,B=[],N=[],j=e.histnorm,U=e.histfunc,V=-1!==j.indexOf(\"density\"),q=\"max\"===U||\"min\"===U?null:0,H=a.count,G=o[j],Y=!1,W=[],X=[],Z=\"z\"in e?e.z:\"marker\"in e&&Array.isArray(e.marker.color)?e.marker.color:\"\";Z&&\"count\"!==U&&(Y=\"avg\"===U,H=a[U]);var J=w.size,K=x(w.start),Q=x(w.end)+(K-i.tickIncrement(K,J,!1,v))/1e6;for(r=K;r<Q;r=i.tickIncrement(r,J,!1,v))C.push(q),z.push(r),Y&&L.push(0);z.push(r);var $,tt=C.length,et=(r-K)/tt,rt=($=K+et/2,g.c2r($,0,v)),nt=M.size,it=b(M.start),at=b(M.end)+(it-i.tickIncrement(it,nt,!1,y))/1e6;for(r=it;r<at;r=i.tickIncrement(r,nt,!1,y)){E.push(C.slice()),O.push(r);var ot=new Array(tt);for(l=0;l<tt;l++)ot[l]=[];N.push(ot),Y&&B.push(L.slice())}O.push(r);var st=E.length,lt=(r-it)/st,ct=function(t){return m.c2r(t,0,y)}(it+lt/2);V&&(W=u(C.length,D,et,I),X=u(E.length,R,lt,P)),I||\"date\"!==g.type||(D=f(x,D)),P||\"date\"!==m.type||(R=f(b,R));var ut=!0,ft=!0,ht=new Array(tt),pt=new Array(st),dt=1/0,gt=1/0,mt=1/0,vt=1/0;for(r=0;r<S;r++){var yt=T[r],xt=A[r];p=n.findBin(yt,D),d=n.findBin(xt,R),p>=0&&p<tt&&d>=0&&d<st&&(F+=H(p,r,E[d],Z,B[d]),N[d][p].push(r),ut&&(void 0===ht[p]?ht[p]=yt:ht[p]!==yt&&(ut=!1)),ft&&(void 0===pt[d]?pt[d]=xt:pt[d]!==xt&&(ft=!1)),dt=Math.min(dt,yt-z[p]),gt=Math.min(gt,z[p+1]-yt),mt=Math.min(mt,xt-O[d]),vt=Math.min(vt,O[d+1]-xt))}if(Y)for(d=0;d<st;d++)F+=s(E[d],B[d]);if(G)for(d=0;d<st;d++)G(E[d],F,W,X[d]);return{x:T,xRanges:h(z,ut&&ht,dt,gt,g,v),x0:rt,dx:et,y:A,yRanges:h(O,ft&&pt,mt,vt,m,y),y0:ct,dy:lt,z:E,pts:N}}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../histogram/average\":1085,\"../histogram/bin_functions\":1087,\"../histogram/bin_label_vals\":1088,\"../histogram/calc\":1089,\"../histogram/norm_functions\":1096}],1099:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./sample_defaults\"),a=t(\"../heatmap/style_defaults\"),o=t(\"../../components/colorscale/defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,l),o(t,e,l,c,{prefix:\"\",cLetter:\"z\"}),c(\"hovertemplate\"))}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../heatmap/style_defaults\":1078,\"./attributes\":1097,\"./sample_defaults\":1102}],1100:[function(t,e,r){\"use strict\";var n=t(\"../heatmap/hover\"),i=t(\"../../plots/cartesian/axes\").hoverLabelText;e.exports=function(t,e,r,a,o,s){var l=n(t,e,r,a,o,s);if(l){var c=(t=l[0]).index,u=c[0],f=c[1],h=t.cd[0],p=h.xRanges[f],d=h.yRanges[u];return t.xLabel=i(t.xa,p[0],p[1]),t.yLabel=i(t.ya,d[0],d[1]),l}}},{\"../../plots/cartesian/axes\":828,\"../heatmap/hover\":1072}],1101:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../heatmap/calc\"),plot:t(\"../heatmap/plot\"),layerName:\"heatmaplayer\",colorbar:t(\"../heatmap/colorbar\"),style:t(\"../heatmap/style\"),hoverPoints:t(\"./hover\"),eventData:t(\"../histogram/event_data\"),moduleType:\"trace\",name:\"histogram2d\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../heatmap/calc\":1066,\"../heatmap/colorbar\":1068,\"../heatmap/plot\":1076,\"../heatmap/style\":1077,\"../histogram/cross_trace_defaults\":1091,\"../histogram/event_data\":1093,\"./attributes\":1097,\"./defaults\":1099,\"./hover\":1100}],1102:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"y\"),l=i.minRowLength(o),c=i.minRowLength(s);l&&c?(e._length=Math.min(l,c),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],a),(r(\"z\")||r(\"marker.color\"))&&r(\"histfunc\"),r(\"histnorm\"),r(\"autobinx\"),r(\"autobiny\")):e.visible=!1}},{\"../../lib\":778,\"../../registry\":911}],1103:[function(t,e,r){\"use strict\";var n=t(\"../histogram2d/attributes\"),i=t(\"../contour/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat;e.exports=o({x:n.x,y:n.y,z:n.z,marker:n.marker,histnorm:n.histnorm,histfunc:n.histfunc,nbinsx:n.nbinsx,xbins:n.xbins,nbinsy:n.nbinsy,ybins:n.ybins,autobinx:n.autobinx,autobiny:n.autobiny,bingroup:n.bingroup,xbingroup:n.xbingroup,ybingroup:n.ybingroup,autocontour:i.autocontour,ncontours:i.ncontours,contours:i.contours,line:{color:i.line.color,width:o({},i.line.width,{dflt:.5}),dash:i.line.dash,smoothing:i.line.smoothing,editType:\"plot\"},zhoverformat:n.zhoverformat,hovertemplate:n.hovertemplate},a(\"\",{cLetter:\"z\",editTypeOverride:\"calc\"}))},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../contour/attributes\":1008,\"../histogram2d/attributes\":1097}],1104:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../histogram2d/sample_defaults\"),a=t(\"../contour/contours_defaults\"),o=t(\"../contour/style_defaults\"),s=t(\"./attributes\");e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,s,r,i)}i(t,e,c,l),!1!==e.visible&&(a(t,e,c,(function(r){return n.coerce2(t,e,s,r)})),o(t,e,c,l),c(\"hovertemplate\"))}},{\"../../lib\":778,\"../contour/contours_defaults\":1015,\"../contour/style_defaults\":1029,\"../histogram2d/sample_defaults\":1102,\"./attributes\":1103}],1105:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../histogram/cross_trace_defaults\"),calc:t(\"../contour/calc\"),plot:t(\"../contour/plot\").plot,layerName:\"contourlayer\",style:t(\"../contour/style\"),colorbar:t(\"../contour/colorbar\"),hoverPoints:t(\"../contour/hover\"),moduleType:\"trace\",name:\"histogram2dcontour\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"contour\",\"histogram\",\"showLegend\"],meta:{}}},{\"../../plots/cartesian\":841,\"../contour/calc\":1009,\"../contour/colorbar\":1011,\"../contour/hover\":1021,\"../contour/plot\":1026,\"../contour/style\":1028,\"../histogram/cross_trace_defaults\":1091,\"./attributes\":1103,\"./defaults\":1104}],1106:[function(t,e,r){\"use strict\";for(var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"./constants\").colormodel,s=[\"rgb\",\"rgba\",\"rgba256\",\"hsl\",\"hsla\"],l=[],c=[],u=0;u<s.length;u++){var f=o[s[u]];l.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zminDflt||f.min).join(\", \")+\"].\"),c.push(\"For the `\"+s[u]+\"` colormodel, it is [\"+(f.zmaxDflt||f.max).join(\", \")+\"].\")}e.exports=a({source:{valType:\"string\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},colormodel:{valType:\"enumerated\",values:s,editType:\"calc\"},zmin:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},zmax:{valType:\"info_array\",items:[{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"},{valType:\"number\",editType:\"calc\"}],editType:\"calc\"},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dx:{valType:\"number\",dflt:1,editType:\"calc\"},dy:{valType:\"number\",dflt:1,editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"data_array\",editType:\"plot\"},hoverinfo:a({},n.hoverinfo,{flags:[\"x\",\"y\",\"z\",\"color\",\"name\",\"text\"],dflt:\"x+y+z+text+name\"}),hovertemplate:i({},{keys:[\"z\",\"color\",\"colormodel\"]}),transforms:void 0})},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"./constants\":1108}],1107:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./constants\"),a=t(\"fast-isnumeric\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../../lib\").maxRowLength,l=t(\"./helpers\").getImageSize;function c(t,e,r,i){return function(a){return n.constrain((a-t)*e,r,i)}}function u(t,e){return function(r){return n.constrain(r,t,e)}}e.exports=function(t,e){var r,n;if(e._hasZ)r=e.z.length,n=s(e.z);else if(e._hasSource){var f=l(e.source);r=f.height,n=f.width}var h,p=o.getFromId(t,e.xaxis||\"x\"),d=o.getFromId(t,e.yaxis||\"y\"),g=p.d2c(e.x0)-e.dx/2,m=d.d2c(e.y0)-e.dy/2,v=[g,g+n*e.dx],y=[m,m+r*e.dy];if(p&&\"log\"===p.type)for(h=0;h<n;h++)v.push(g+h*e.dx);if(d&&\"log\"===d.type)for(h=0;h<r;h++)y.push(m+h*e.dy);return e._extremes[p._id]=o.findExtremes(p,v),e._extremes[d._id]=o.findExtremes(d,y),e._scaler=function(t){var e=i.colormodel[t.colormodel],r=(e.colormodel||t.colormodel).length;t._sArray=[];for(var n=0;n<r;n++)e.min[n]!==t.zmin[n]||e.max[n]!==t.zmax[n]?t._sArray.push(c(t.zmin[n],(e.max[n]-e.min[n])/(t.zmax[n]-t.zmin[n]),e.min[n],e.max[n])):t._sArray.push(u(e.min[n],e.max[n]));return function(e){for(var n=e.slice(0,r),i=0;i<r;i++){var o=n[i];if(!a(o))return!1;n[i]=t._sArray[i](o)}return n}}(e),[{x0:g,y0:m,z:e.z,w:n,h:r}]}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"./constants\":1108,\"./helpers\":1111,\"fast-isnumeric\":241}],1108:[function(t,e,r){\"use strict\";e.exports={colormodel:{rgb:{min:[0,0,0],max:[255,255,255],fmt:function(t){return t.slice(0,3)},suffix:[\"\",\"\",\"\"]},rgba:{min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},rgba256:{colormodel:\"rgba\",zminDflt:[0,0,0,0],zmaxDflt:[255,255,255,255],min:[0,0,0,0],max:[255,255,255,1],fmt:function(t){return t.slice(0,4)},suffix:[\"\",\"\",\"\",\"\"]},hsl:{min:[0,0,0],max:[360,100,100],fmt:function(t){var e=t.slice(0,3);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\"]},hsla:{min:[0,0,0,0],max:[360,100,100,1],fmt:function(t){var e=t.slice(0,4);return e[1]=e[1]+\"%\",e[2]=e[2]+\"%\",e},suffix:[\"\\xb0\",\"%\",\"%\",\"\"]}}}},{}],1109:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"./constants\"),o=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX;e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"source\"),e.source&&!e.source.match(o)&&delete e.source,e._hasSource=!!e.source;var s,l=r(\"z\");(e._hasZ=!(void 0===l||!l.length||!l[0]||!l[0].length),e._hasZ||e._hasSource)?(r(\"x0\"),r(\"y0\"),r(\"dx\"),r(\"dy\"),e._hasZ?(r(\"colormodel\",\"rgb\"),r(\"zmin\",(s=a.colormodel[e.colormodel]).zminDflt||s.min),r(\"zmax\",s.zmaxDflt||s.max)):e._hasSource&&(e.colormodel=\"rgba256\",s=a.colormodel[e.colormodel],e.zmin=s.zminDflt,e.zmax=s.zmaxDflt),r(\"text\"),r(\"hovertext\"),r(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../lib\":778,\"../../snapshot/helpers\":915,\"./attributes\":1106,\"./constants\":1108}],1110:[function(t,e,r){\"use strict\";e.exports=function(t,e){return\"xVal\"in e&&(t.x=e.xVal),\"yVal\"in e&&(t.y=e.yVal),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t.color=e.color,t.colormodel=e.trace.colormodel,t.z||(t.z=e.color),t}},{}],1111:[function(t,e,r){\"use strict\";var n=t(\"image-size\"),i=t(\"../../snapshot/helpers\").IMAGE_URL_PREFIX,a=t(\"buffer/\").Buffer;r.getImageSize=function(t){var e=t.replace(i,\"\"),r=new a(e,\"base64\");return n(r)}},{\"../../snapshot/helpers\":915,\"buffer/\":111,\"image-size\":444}],1112:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"./constants\");e.exports=function(t,e,r){var o=t.cd[0],s=o.trace,l=t.xa,c=t.ya;if(!(n.inbox(e-o.x0,e-(o.x0+o.w*s.dx),0)>0||n.inbox(r-o.y0,r-(o.y0+o.h*s.dy),0)>0)){var u,f=Math.floor((e-o.x0)/s.dx),h=Math.floor(Math.abs(r-o.y0)/s.dy);if(s._hasZ?u=o.z[h][f]:s._hasSource&&(u=s._canvas.el.getContext(\"2d\").getImageData(f,h,1,1).data),u){var p,d=o.hi||s.hoverinfo;if(d){var g=d.split(\"+\");-1!==g.indexOf(\"all\")&&(g=[\"color\"]),-1!==g.indexOf(\"color\")&&(p=!0)}var m,v=a.colormodel[s.colormodel],y=v.colormodel||s.colormodel,x=y.length,b=s._scaler(u),_=v.suffix,w=[];(s.hovertemplate||p)&&(w.push(\"[\"+[b[0]+_[0],b[1]+_[1],b[2]+_[2]].join(\", \")),4===x&&w.push(\", \"+b[3]+_[3]),w.push(\"]\"),w=w.join(\"\"),t.extraText=y.toUpperCase()+\": \"+w),Array.isArray(s.hovertext)&&Array.isArray(s.hovertext[h])?m=s.hovertext[h][f]:Array.isArray(s.text)&&Array.isArray(s.text[h])&&(m=s.text[h][f]);var T=c.c2p(o.y0+(h+.5)*s.dy),k=o.x0+(f+.5)*s.dx,M=o.y0+(h+.5)*s.dy,A=\"[\"+u.slice(0,s.colormodel.length).join(\", \")+\"]\";return[i.extendFlat(t,{index:[h,f],x0:l.c2p(o.x0+f*s.dx),x1:l.c2p(o.x0+(f+1)*s.dx),y0:T,y1:T,color:b,xVal:k,xLabelVal:k,yVal:M,yLabelVal:M,zLabelVal:A,text:m,hovertemplateLabels:{zLabel:A,colorLabel:w,\"color[0]Label\":b[0]+_[0],\"color[1]Label\":b[1]+_[1],\"color[2]Label\":b[2]+_[2],\"color[3]Label\":b[3]+_[3]}})]}}}},{\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1108}],1113:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"image\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"2dMap\",\"noSortingByValue\"],animatable:!1,meta:{}}},{\"../../plots/cartesian\":841,\"./attributes\":1106,\"./calc\":1107,\"./defaults\":1109,\"./event_data\":1110,\"./hover\":1112,\"./plot\":1114,\"./style\":1115}],1114:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strTranslate,o=t(\"../../constants/xmlns_namespaces\"),s=t(\"./constants\"),l=i.isIOS()||i.isSafari()||i.isIE();e.exports=function(t,e,r,c){var u=e.xaxis,f=e.yaxis,h=!(l||t._context._exportedPlot);i.makeTraceGroups(c,r,\"im\").each((function(e){var r=n.select(this),l=e[0],c=l.trace,p=h&&!c._hasZ&&c._hasSource&&\"linear\"===u.type&&\"linear\"===f.type;c._fastImage=p;var d,g,m,v,y,x,b=l.z,_=l.x0,w=l.y0,T=l.w,k=l.h,M=c.dx,A=c.dy;for(x=0;void 0===d&&x<T;)d=u.c2p(_+x*M),x++;for(x=T;void 0===g&&x>0;)g=u.c2p(_+x*M),x--;for(x=0;void 0===v&&x<k;)v=f.c2p(w+x*A),x++;for(x=k;void 0===y&&x>0;)y=f.c2p(w+x*A),x--;if(g<d&&(m=g,g=d,d=m),y<v&&(m=v,v=y,y=m),!p){d=Math.max(-.5*u._length,d),g=Math.min(1.5*u._length,g),v=Math.max(-.5*f._length,v),y=Math.min(1.5*f._length,y)}var S=Math.round(g-d),E=Math.round(y-v);if(S<=0||E<=0){r.selectAll(\"image\").data([]).exit().remove()}else{var C=r.selectAll(\"image\").data([e]);C.enter().append(\"svg:image\").attr({xmlns:o.svg,preserveAspectRatio:\"none\"}),C.exit().remove();var L=\"image-rendering: optimizeSpeed; image-rendering: -moz-crisp-edges; image-rendering: -o-crisp-edges; image-rendering: -webkit-optimize-contrast; image-rendering: optimize-contrast; image-rendering: crisp-edges; image-rendering: pixelated;\";if(p){var I=i.simpleMap(u.range,u.r2l),P=i.simpleMap(f.range,f.r2l),z=I[1]<I[0],O=P[1]>P[0];if(z||O){var D=d+S/2,R=v+E/2;L+=\"transform:\"+a(D+\"px\",R+\"px\")+\"scale(\"+(z?-1:1)+\",\"+(O?-1:1)+\")\"+a(-D+\"px\",-R+\"px\")+\";\"}}C.attr(\"style\",L);var F=new Promise((function(t){if(c._hasZ)t();else if(c._hasSource)if(c._canvas&&c._canvas.el.width===T&&c._canvas.el.height===k&&c._canvas.source===c.source)t();else{var e=document.createElement(\"canvas\");e.width=T,e.height=k;var r=e.getContext(\"2d\");c._image=c._image||new Image;var n=c._image;n.onload=function(){r.drawImage(n,0,0),c._canvas={el:e,source:c.source},t()},n.setAttribute(\"src\",c.source)}})).then((function(){var t;if(c._hasZ)t=B((function(t,e){return b[e][t]})).toDataURL(\"image/png\");else if(c._hasSource)if(p)t=c.source;else{var e=c._canvas.el.getContext(\"2d\").getImageData(0,0,T,k).data;t=B((function(t,r){var n=4*(r*T+t);return[e[n],e[n+1],e[n+2],e[n+3]]})).toDataURL(\"image/png\")}C.attr({\"xlink:href\":t,height:E,width:S,x:d,y:v})}));t._promises.push(F)}function B(t){var e=document.createElement(\"canvas\");e.width=S,e.height=E;var r,n=e.getContext(\"2d\"),a=function(t){return i.constrain(Math.round(u.c2p(_+t*M)-d),0,S)},o=function(t){return i.constrain(Math.round(f.c2p(w+t*A)-v),0,E)},h=s.colormodel[c.colormodel],p=h.colormodel||c.colormodel,g=h.fmt;for(x=0;x<l.w;x++){var m=a(x),y=a(x+1);if(y!==m&&!isNaN(y)&&!isNaN(m))for(var b=0;b<l.h;b++){var T=o(b),k=o(b+1);k===T||isNaN(k)||isNaN(T)||!t(x,b)||(r=c._scaler(t(x,b)),n.fillStyle=r?p+\"(\"+g(r).join(\",\")+\")\":\"rgba(0,0,0,0)\",n.fillRect(m,T,y-m,k-T))}}return e}}))}},{\"../../constants/xmlns_namespaces\":754,\"../../lib\":778,\"./constants\":1108,d3:169}],1115:[function(t,e,r){\"use strict\";var n=t(\"d3\");e.exports=function(t){n.select(t).selectAll(\".im image\").style(\"opacity\",(function(t){return t[0].trace.opacity}))}},{d3:169}],1116:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../lib/extend\").extendDeep,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../components/color/attributes\"),l=t(\"../../plots/domain\").attributes,c=t(\"../../plots/cartesian/layout_attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../constants/delta.js\"),h=(t(\"../../constants/docs\").FORMAT_LINK,o({editType:\"plot\",colorEditType:\"plot\"})),p={color:{valType:\"color\",editType:\"plot\"},line:{color:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},width:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},editType:\"calc\"},thickness:{valType:\"number\",min:0,max:1,dflt:1,editType:\"plot\"},editType:\"calc\"},d={valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},g=u(\"step\",i({},p,{range:d}));e.exports={mode:{valType:\"flaglist\",editType:\"calc\",flags:[\"number\",\"delta\",\"gauge\"],dflt:\"number\"},value:{valType:\"number\",editType:\"calc\",anim:!0},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},domain:l({name:\"indicator\",trace:!0,editType:\"calc\"}),title:{text:{valType:\"string\",editType:\"plot\"},align:{valType:\"enumerated\",values:[\"left\",\"center\",\"right\"],editType:\"plot\"},font:n({},h,{}),editType:\"plot\"},number:{valueformat:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:n({},h,{}),prefix:{valType:\"string\",dflt:\"\",editType:\"plot\"},suffix:{valType:\"string\",dflt:\"\",editType:\"plot\"},editType:\"plot\"},delta:{reference:{valType:\"number\",editType:\"calc\"},position:{valType:\"enumerated\",values:[\"top\",\"bottom\",\"left\",\"right\"],dflt:\"bottom\",editType:\"plot\"},relative:{valType:\"boolean\",editType:\"plot\",dflt:!1},valueformat:{valType:\"string\",editType:\"plot\"},increasing:{symbol:{valType:\"string\",dflt:f.INCREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.INCREASING.COLOR,editType:\"plot\"},editType:\"plot\"},decreasing:{symbol:{valType:\"string\",dflt:f.DECREASING.SYMBOL,editType:\"plot\"},color:{valType:\"color\",dflt:f.DECREASING.COLOR,editType:\"plot\"},editType:\"plot\"},font:n({},h,{}),editType:\"calc\"},gauge:{shape:{valType:\"enumerated\",editType:\"plot\",dflt:\"angular\",values:[\"angular\",\"bullet\"]},bar:i({},p,{color:{dflt:\"green\"}}),bgcolor:{valType:\"color\",editType:\"plot\"},bordercolor:{valType:\"color\",dflt:s.defaultLine,editType:\"plot\"},borderwidth:{valType:\"number\",min:0,dflt:1,editType:\"plot\"},axis:a({range:d,visible:n({},c.visible,{dflt:!0}),tickmode:c.tickmode,nticks:c.nticks,tick0:c.tick0,dtick:c.dtick,tickvals:c.tickvals,ticktext:c.ticktext,ticks:n({},c.ticks,{dflt:\"outside\"}),ticklen:c.ticklen,tickwidth:c.tickwidth,tickcolor:c.tickcolor,showticklabels:c.showticklabels,tickfont:o({}),tickangle:c.tickangle,tickformat:c.tickformat,tickformatstops:c.tickformatstops,tickprefix:c.tickprefix,showtickprefix:c.showtickprefix,ticksuffix:c.ticksuffix,showticksuffix:c.showticksuffix,separatethousands:c.separatethousands,exponentformat:c.exponentformat,minexponent:c.minexponent,showexponent:c.showexponent,editType:\"plot\"},\"plot\"),steps:g,threshold:{line:{color:n({},p.line.color,{}),width:n({},p.line.width,{dflt:1}),editType:\"plot\"},thickness:n({},p.thickness,{dflt:.85}),value:{valType:\"number\",editType:\"calc\",dflt:!1},editType:\"plot\"},editType:\"plot\"}}},{\"../../components/color/attributes\":642,\"../../constants/delta.js\":747,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1117:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"indicator\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1118:[function(t,e,r){\"use strict\";e.exports={calc:function(t,e){var r=[],n=e.value;\"number\"!=typeof e._lastValue&&(e._lastValue=e.value);var i=e._lastValue,a=i;return e._hasDelta&&\"number\"==typeof e.delta.reference&&(a=e.delta.reference),r[0]={y:n,lastY:i,delta:n-a,relativeDelta:(n-a)/a},r}}},{}],1119:[function(t,e,r){\"use strict\";e.exports={defaultNumberFontSize:80,bulletNumberDomainSize:.25,bulletPadding:.025,innerRadius:.75,valueThickness:.5,titlePadding:5,horizontalPadding:10}},{}],1120:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../../plot_api/plot_template\"),s=t(\"../../plots/array_container_defaults\"),l=t(\"./constants.js\"),c=t(\"../../plots/cartesian/tick_value_defaults\"),u=t(\"../../plots/cartesian/tick_mark_defaults\"),f=t(\"../../plots/cartesian/tick_label_defaults\");function h(t,e){function r(r,a){return n.coerce(t,e,i.gauge.steps,r,a)}r(\"color\"),r(\"line.color\"),r(\"line.width\"),r(\"range\"),r(\"thickness\")}e.exports={supplyDefaults:function(t,e,r,p){function d(r,a){return n.coerce(t,e,i,r,a)}a(e,p,d),d(\"mode\"),e._hasNumber=-1!==e.mode.indexOf(\"number\"),e._hasDelta=-1!==e.mode.indexOf(\"delta\"),e._hasGauge=-1!==e.mode.indexOf(\"gauge\");var g=d(\"value\");e._range=[0,\"number\"==typeof g?1.5*g:1];var m,v,y,x,b,_,w=new Array(2);function T(t,e){return n.coerce(y,x,i.gauge,t,e)}function k(t,e){return n.coerce(b,_,i.gauge.axis,t,e)}if(e._hasNumber&&(d(\"number.valueformat\"),d(\"number.font.color\",p.font.color),d(\"number.font.family\",p.font.family),d(\"number.font.size\"),void 0===e.number.font.size&&(e.number.font.size=l.defaultNumberFontSize,w[0]=!0),d(\"number.prefix\"),d(\"number.suffix\"),m=e.number.font.size),e._hasDelta&&(d(\"delta.font.color\",p.font.color),d(\"delta.font.family\",p.font.family),d(\"delta.font.size\"),void 0===e.delta.font.size&&(e.delta.font.size=(e._hasNumber?.5:1)*(m||l.defaultNumberFontSize),w[1]=!0),d(\"delta.reference\",e.value),d(\"delta.relative\"),d(\"delta.valueformat\",e.delta.relative?\"2%\":\"\"),d(\"delta.increasing.symbol\"),d(\"delta.increasing.color\"),d(\"delta.decreasing.symbol\"),d(\"delta.decreasing.color\"),d(\"delta.position\"),v=e.delta.font.size),e._scaleNumbers=(!e._hasNumber||w[0])&&(!e._hasDelta||w[1])||!1,d(\"title.font.color\",p.font.color),d(\"title.font.family\",p.font.family),d(\"title.font.size\",.25*(m||v||l.defaultNumberFontSize)),d(\"title.text\"),e._hasGauge){(y=t.gauge)||(y={}),x=o.newContainer(e,\"gauge\"),T(\"shape\"),(e._isBullet=\"bullet\"===e.gauge.shape)||d(\"title.align\",\"center\"),(e._isAngular=\"angular\"===e.gauge.shape)||d(\"align\",\"center\"),T(\"bgcolor\",p.paper_bgcolor),T(\"borderwidth\"),T(\"bordercolor\"),T(\"bar.color\"),T(\"bar.line.color\"),T(\"bar.line.width\"),T(\"bar.thickness\",l.valueThickness*(\"bullet\"===e.gauge.shape?.5:1)),s(y,x,{name:\"steps\",handleItemDefaults:h}),T(\"threshold.value\"),T(\"threshold.thickness\"),T(\"threshold.line.width\"),T(\"threshold.line.color\"),b={},y&&(b=y.axis||{}),_=o.newContainer(x,\"axis\"),k(\"visible\"),e._range=k(\"range\",e._range);var M={outerTicks:!0};c(b,_,k,\"linear\"),f(b,_,k,\"linear\",M),u(b,_,k,M)}else d(\"title.align\",\"center\"),d(\"align\",\"center\"),e._isAngular=e._isBullet=!1;e._length=null}}},{\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/tick_label_defaults\":849,\"../../plots/cartesian/tick_mark_defaults\":850,\"../../plots/cartesian/tick_value_defaults\":851,\"../../plots/domain\":855,\"./attributes\":1116,\"./constants.js\":1119}],1121:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"indicator\",basePlotModule:t(\"./base_plot\"),categories:[\"svg\",\"noOpacity\",\"noHover\"],animatable:!0,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\").calc,plot:t(\"./plot\"),meta:{}}},{\"./attributes\":1116,\"./base_plot\":1117,\"./calc\":1118,\"./defaults\":1120,\"./plot\":1122}],1122:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=i.strScale,o=i.strTranslate,s=i.rad2deg,l=t(\"../../constants/alignment\").MID_SHIFT,c=t(\"../../components/drawing\"),u=t(\"./constants\"),f=t(\"../../lib/svg_text_utils\"),h=t(\"../../plots/cartesian/axes\"),p=t(\"../../plots/cartesian/axis_defaults\"),d=t(\"../../plots/cartesian/position_defaults\"),g=t(\"../../plots/cartesian/layout_attributes\"),m=t(\"../../components/color\"),v={left:\"start\",center:\"middle\",right:\"end\"},y={left:0,center:.5,right:1},x=/[yzafpn\\xb5mkMGTPEZY]/;function b(t){return t&&t.duration>0}function _(t){t.each((function(t){m.stroke(n.select(this),t.line.color)})).each((function(t){m.fill(n.select(this),t.color)})).style(\"stroke-width\",(function(t){return t.line.width}))}function w(t,e,r){var n=t._fullLayout,a=i.extendFlat({type:\"linear\",ticks:\"outside\",range:r,showline:!0},e),o={type:\"linear\",_id:\"x\"+e._id},s={letter:\"x\",font:n.font,noHover:!0,noTickson:!0};function l(t,e){return i.coerce(a,o,g,t,e)}return p(a,o,l,s,n),d(a,o,l,s),o}function T(t,e,r){return[Math.min(e/t.width,r/t.height),t,e+\"x\"+r]}function k(t,e,r,i){var a=document.createElementNS(\"http://www.w3.org/2000/svg\",\"text\"),o=n.select(a);return o.text(t).attr(\"x\",0).attr(\"y\",0).attr(\"text-anchor\",r).attr(\"data-unformatted\",t).call(f.convertToTspans,i).call(c.font,e),c.bBox(o.node())}function M(t,e,r,n,a,o){var s=\"_cache\"+e;t[s]&&t[s].key===a||(t[s]={key:a,value:r});var l=i.aggNums(o,null,[t[s].value,n],2);return t[s].value=l,l}e.exports=function(t,e,r,p){var d,g=t._fullLayout;b(r)&&p&&(d=p()),i.makeTraceGroups(g._indicatorlayer,e,\"trace\").each((function(e){var p,A,S,E,C,L=e[0].trace,I=n.select(this),P=L._hasGauge,z=L._isAngular,O=L._isBullet,D=L.domain,R={w:g._size.w*(D.x[1]-D.x[0]),h:g._size.h*(D.y[1]-D.y[0]),l:g._size.l+g._size.w*D.x[0],r:g._size.r+g._size.w*(1-D.x[1]),t:g._size.t+g._size.h*(1-D.y[1]),b:g._size.b+g._size.h*D.y[0]},F=R.l+R.w/2,B=R.t+R.h/2,N=Math.min(R.w/2,R.h),j=u.innerRadius*N,U=L.align||\"center\";if(A=B,P){if(z&&(p=F,A=B+N/2,S=function(t){return function(t,e){var r=Math.sqrt(t.width/2*(t.width/2)+t.height*t.height);return[e/r,t,e]}(t,.9*j)}),O){var V=u.bulletPadding,q=1-u.bulletNumberDomainSize+V;p=R.l+(q+(1-q)*y[U])*R.w,S=function(t){return T(t,(u.bulletNumberDomainSize-V)*R.w,R.h)}}}else p=R.l+y[U]*R.w,S=function(t){return T(t,R.w,R.h)};!function(t,e,r,s){var l,u,p,d=r[0].trace,g=s.numbersX,_=s.numbersY,T=d.align||\"center\",A=v[T],S=s.transitionOpts,E=s.onComplete,C=i.ensureSingle(e,\"g\",\"numbers\"),L=[];d._hasNumber&&L.push(\"number\");d._hasDelta&&(L.push(\"delta\"),\"left\"===d.delta.position&&L.reverse());var I=C.selectAll(\"text\").data(L);function P(e,r,n,i){if(!e.match(\"s\")||n>=0==i>=0||r(n).slice(-1).match(x)||r(i).slice(-1).match(x))return r;var a=e.slice().replace(\"s\",\"f\").replace(/\\d+/,(function(t){return parseInt(t)-1})),o=w(t,{tickformat:a});return function(t){return Math.abs(t)<1?h.tickText(o,t).text:r(t)}}I.enter().append(\"text\"),I.attr(\"text-anchor\",(function(){return A})).attr(\"class\",(function(t){return t})).attr(\"x\",null).attr(\"y\",null).attr(\"dx\",null).attr(\"dy\",null),I.exit().remove();var z,O=d.mode+d.align;d._hasDelta&&(z=function(){var e=w(t,{tickformat:d.delta.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=function(t){return d.delta.relative?t.relativeDelta:t.delta},o=function(t,e){return 0===t||\"number\"!=typeof t||isNaN(t)?\"-\":(t>0?d.delta.increasing.symbol:d.delta.decreasing.symbol)+e(t)},s=function(t){return t.delta>=0?d.delta.increasing.color:d.delta.decreasing.color};void 0===d._deltaLastValue&&(d._deltaLastValue=a(r[0]));var l=C.select(\"text.delta\");function p(){l.text(o(a(r[0]),i)).call(m.fill,s(r[0])).call(f.convertToTspans,t)}return l.call(c.font,d.delta.font).call(m.fill,s({delta:d._deltaLastValue})),b(S)?l.transition().duration(S.duration).ease(S.easing).tween(\"text\",(function(){var t=n.select(this),e=a(r[0]),l=d._deltaLastValue,c=P(d.delta.valueformat,i,l,e),u=n.interpolateNumber(l,e);return d._deltaLastValue=e,function(e){t.text(o(u(e),c)),t.call(m.fill,s({delta:u(e)}))}})).each(\"end\",(function(){p(),E&&E()})).each(\"interrupt\",(function(){p(),E&&E()})):p(),u=k(o(a(r[0]),i),d.delta.font,A,t),l}(),O+=d.delta.position+d.delta.font.size+d.delta.font.family+d.delta.valueformat,O+=d.delta.increasing.symbol+d.delta.decreasing.symbol,p=u);d._hasNumber&&(!function(){var e=w(t,{tickformat:d.number.valueformat},d._range);e.setScale(),h.prepTicks(e);var i=function(t){return h.tickText(e,t).text},a=d.number.suffix,o=d.number.prefix,s=C.select(\"text.number\");function u(){var e=\"number\"==typeof r[0].y?o+i(r[0].y)+a:\"-\";s.text(e).call(c.font,d.number.font).call(f.convertToTspans,t)}b(S)?s.transition().duration(S.duration).ease(S.easing).each(\"end\",(function(){u(),E&&E()})).each(\"interrupt\",(function(){u(),E&&E()})).attrTween(\"text\",(function(){var t=n.select(this),e=n.interpolateNumber(r[0].lastY,r[0].y);d._lastValue=r[0].y;var s=P(d.number.valueformat,i,r[0].lastY,r[0].y);return function(r){t.text(o+s(e(r))+a)}})):u(),l=k(o+i(r[0].y)+a,d.number.font,A,t)}(),O+=d.number.font.size+d.number.font.family+d.number.valueformat+d.number.suffix+d.number.prefix,p=l);if(d._hasDelta&&d._hasNumber){var D,R,F=[(l.left+l.right)/2,(l.top+l.bottom)/2],B=[(u.left+u.right)/2,(u.top+u.bottom)/2],N=.75*d.delta.font.size;\"left\"===d.delta.position&&(D=M(d,\"deltaPos\",0,-1*(l.width*y[d.align]+u.width*(1-y[d.align])+N),O,Math.min),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:u.left+D,right:l.right,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"right\"===d.delta.position&&(D=M(d,\"deltaPos\",0,l.width*(1-y[d.align])+u.width*y[d.align]+N,O,Math.max),R=F[1]-B[1],p={width:l.width+u.width+N,height:Math.max(l.height,u.height),left:l.left,right:u.right+D,top:Math.min(l.top,u.top+R),bottom:Math.max(l.bottom,u.bottom+R)}),\"bottom\"===d.delta.position&&(D=null,R=u.height,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height,bottom:l.bottom+u.height}),\"top\"===d.delta.position&&(D=null,R=l.top,p={width:Math.max(l.width,u.width),height:l.height+u.height,left:Math.min(l.left,u.left),right:Math.max(l.right,u.right),top:l.bottom-l.height-u.height,bottom:l.bottom}),z.attr({dx:D,dy:R})}(d._hasNumber||d._hasDelta)&&C.attr(\"transform\",(function(){var t=s.numbersScaler(p);O+=t[2];var e,r=M(d,\"numbersScale\",1,t[0],O,Math.min);d._scaleNumbers||(r=1),e=d._isAngular?_-r*p.bottom:_-r*(p.top+p.bottom)/2,d._numbersTop=r*p.top+e;var n=p[T];\"center\"===T&&(n=(p.left+p.right)/2);var i=g-r*n;return i=M(d,\"numbersTranslate\",0,i,O,Math.max),o(i,e)+a(r)}))}(t,I,e,{numbersX:p,numbersY:A,numbersScaler:S,transitionOpts:r,onComplete:d}),P&&(E={range:L.gauge.axis.range,color:L.gauge.bgcolor,line:{color:L.gauge.bordercolor,width:0},thickness:1},C={range:L.gauge.axis.range,color:\"rgba(0, 0, 0, 0)\",line:{color:L.gauge.bordercolor,width:L.gauge.borderwidth},thickness:1});var H=I.selectAll(\"g.angular\").data(z?e:[]);H.exit().remove();var G=I.selectAll(\"g.angularaxis\").data(z?e:[]);G.exit().remove(),z&&function(t,e,r,i){var a,c,u,f,p=r[0].trace,d=i.size,g=i.radius,m=i.innerRadius,v=i.gaugeBg,y=i.gaugeOutline,x=[d.l+d.w/2,d.t+d.h/2+g/2],T=i.gauge,k=i.layer,M=i.transitionOpts,A=i.onComplete,S=Math.PI/2;function E(t){var e=p.gauge.axis.range[0],r=(t-e)/(p.gauge.axis.range[1]-e)*Math.PI-S;return r<-S?-S:r>S?S:r}function C(t){return n.svg.arc().innerRadius((m+g)/2-t/2*(g-m)).outerRadius((m+g)/2+t/2*(g-m)).startAngle(-S)}function L(t){t.attr(\"d\",(function(t){return C(t.thickness).startAngle(E(t.range[0])).endAngle(E(t.range[1]))()}))}T.enter().append(\"g\").classed(\"angular\",!0),T.attr(\"transform\",o(x[0],x[1])),k.enter().append(\"g\").classed(\"angularaxis\",!0).classed(\"crisp\",!0),k.selectAll(\"g.xangularaxistick,path,text\").remove(),(a=w(t,p.gauge.axis)).type=\"linear\",a.range=p.gauge.axis.range,a._id=\"xangularaxis\",a.setScale();var I=function(t){return(a.range[0]-t.x)/(a.range[1]-a.range[0])*Math.PI+Math.PI},P={},z=h.makeLabelFns(a,0).labelStandoff;P.xFn=function(t){var e=I(t);return Math.cos(e)*z},P.yFn=function(t){var e=I(t),r=Math.sin(e)>0?.2:1;return-Math.sin(e)*(z+t.fontSize*r)+Math.abs(Math.cos(e))*(t.fontSize*l)},P.anchorFn=function(t){var e=I(t),r=Math.cos(e);return Math.abs(r)<.1?\"middle\":r>0?\"start\":\"end\"},P.heightFn=function(t,e,r){var n=I(t);return-.5*(1+Math.sin(n))*r};var O=function(t){return o(x[0]+g*Math.cos(t),x[1]-g*Math.sin(t))};u=function(t){return O(I(t))};if(c=h.calcTicks(a),f=h.getTickSigns(a)[2],a.visible){f=\"inside\"===a.ticks?-1:1;var D=(a.linewidth||1)/2;h.drawTicks(t,a,{vals:c,layer:k,path:\"M\"+f*D+\",0h\"+f*a.ticklen,transFn:function(t){var e=I(t);return O(e)+\"rotate(\"+-s(e)+\")\"}}),h.drawLabels(t,a,{vals:c,layer:k,transFn:u,labelFns:P})}var R=[v].concat(p.gauge.steps),F=T.selectAll(\"g.bg-arc\").data(R);F.enter().append(\"g\").classed(\"bg-arc\",!0).append(\"path\"),F.select(\"path\").call(L).call(_),F.exit().remove();var B=C(p.gauge.bar.thickness),N=T.selectAll(\"g.value-arc\").data([p.gauge.bar]);N.enter().append(\"g\").classed(\"value-arc\",!0).append(\"path\");var j=N.select(\"path\");b(M)?(j.transition().duration(M.duration).ease(M.easing).each(\"end\",(function(){A&&A()})).each(\"interrupt\",(function(){A&&A()})).attrTween(\"d\",(U=B,V=E(r[0].lastY),q=E(r[0].y),function(){var t=n.interpolate(V,q);return function(e){return U.endAngle(t(e))()}})),p._lastValue=r[0].y):j.attr(\"d\",\"number\"==typeof r[0].y?B.endAngle(E(r[0].y)):\"M0,0Z\");var U,V,q;j.call(_),N.exit().remove(),R=[];var H=p.gauge.threshold.value;H&&R.push({range:[H,H],color:p.gauge.threshold.color,line:{color:p.gauge.threshold.line.color,width:p.gauge.threshold.line.width},thickness:p.gauge.threshold.thickness});var G=T.selectAll(\"g.threshold-arc\").data(R);G.enter().append(\"g\").classed(\"threshold-arc\",!0).append(\"path\"),G.select(\"path\").call(L).call(_),G.exit().remove();var Y=T.selectAll(\"g.gauge-outline\").data([y]);Y.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"path\"),Y.select(\"path\").call(L).call(_),Y.exit().remove()}(t,0,e,{radius:N,innerRadius:j,gauge:H,layer:G,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var Y=I.selectAll(\"g.bullet\").data(O?e:[]);Y.exit().remove();var W=I.selectAll(\"g.bulletaxis\").data(O?e:[]);W.exit().remove(),O&&function(t,e,r,n){var i,a,s,l,c,f=r[0].trace,p=n.gauge,d=n.layer,g=n.gaugeBg,v=n.gaugeOutline,y=n.size,x=f.domain,T=n.transitionOpts,k=n.onComplete;p.enter().append(\"g\").classed(\"bullet\",!0),p.attr(\"transform\",o(y.l,y.t)),d.enter().append(\"g\").classed(\"bulletaxis\",!0).classed(\"crisp\",!0),d.selectAll(\"g.xbulletaxistick,path,text\").remove();var M=y.h,A=f.gauge.bar.thickness*M,S=x.x[0],E=x.x[0]+(x.x[1]-x.x[0])*(f._hasNumber||f._hasDelta?1-u.bulletNumberDomainSize:1);(i=w(t,f.gauge.axis))._id=\"xbulletaxis\",i.domain=[S,E],i.setScale(),a=h.calcTicks(i),s=h.makeTransTickFn(i),l=h.getTickSigns(i)[2],c=y.t+y.h,i.visible&&(h.drawTicks(t,i,{vals:\"inside\"===i.ticks?h.clipEnds(i,a):a,layer:d,path:h.makeTickPath(i,c,l),transFn:s}),h.drawLabels(t,i,{vals:a,layer:d,transFn:s,labelFns:h.makeLabelFns(i,c)}));function C(t){t.attr(\"width\",(function(t){return Math.max(0,i.c2p(t.range[1])-i.c2p(t.range[0]))})).attr(\"x\",(function(t){return i.c2p(t.range[0])})).attr(\"y\",(function(t){return.5*(1-t.thickness)*M})).attr(\"height\",(function(t){return t.thickness*M}))}var L=[g].concat(f.gauge.steps),I=p.selectAll(\"g.bg-bullet\").data(L);I.enter().append(\"g\").classed(\"bg-bullet\",!0).append(\"rect\"),I.select(\"rect\").call(C).call(_),I.exit().remove();var P=p.selectAll(\"g.value-bullet\").data([f.gauge.bar]);P.enter().append(\"g\").classed(\"value-bullet\",!0).append(\"rect\"),P.select(\"rect\").attr(\"height\",A).attr(\"y\",(M-A)/2).call(_),b(T)?P.select(\"rect\").transition().duration(T.duration).ease(T.easing).each(\"end\",(function(){k&&k()})).each(\"interrupt\",(function(){k&&k()})).attr(\"width\",Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y)))):P.select(\"rect\").attr(\"width\",\"number\"==typeof r[0].y?Math.max(0,i.c2p(Math.min(f.gauge.axis.range[1],r[0].y))):0);P.exit().remove();var z=r.filter((function(){return f.gauge.threshold.value})),O=p.selectAll(\"g.threshold-bullet\").data(z);O.enter().append(\"g\").classed(\"threshold-bullet\",!0).append(\"line\"),O.select(\"line\").attr(\"x1\",i.c2p(f.gauge.threshold.value)).attr(\"x2\",i.c2p(f.gauge.threshold.value)).attr(\"y1\",(1-f.gauge.threshold.thickness)/2*M).attr(\"y2\",(1-(1-f.gauge.threshold.thickness)/2)*M).call(m.stroke,f.gauge.threshold.line.color).style(\"stroke-width\",f.gauge.threshold.line.width),O.exit().remove();var D=p.selectAll(\"g.gauge-outline\").data([v]);D.enter().append(\"g\").classed(\"gauge-outline\",!0).append(\"rect\"),D.select(\"rect\").call(C).call(_),D.exit().remove()}(t,0,e,{gauge:Y,layer:W,size:R,gaugeBg:E,gaugeOutline:C,transitionOpts:r,onComplete:d});var X=I.selectAll(\"text.title\").data(e);X.exit().remove(),X.enter().append(\"text\").classed(\"title\",!0),X.attr(\"text-anchor\",(function(){return O?v.right:v[L.title.align]})).text(L.title.text).call(c.font,L.title.font).call(f.convertToTspans,t),X.attr(\"transform\",(function(){var t,e=R.l+R.w*y[L.title.align],r=u.titlePadding,n=c.bBox(X.node());if(P){if(z)if(L.gauge.axis.visible)t=c.bBox(G.node()).top-r-n.bottom;else t=R.t+R.h/2-N/2-n.bottom-r;O&&(t=A-(n.top+n.bottom)/2,e=R.l-u.bulletPadding*R.w)}else t=L._numbersTop-r-n.bottom;return o(e,t)}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/alignment\":745,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_defaults\":830,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/cartesian/position_defaults\":845,\"./constants\":1119,d3:169}],1123:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;var c=e.exports=l(s({x:{valType:\"data_array\"},y:{valType:\"data_array\"},z:{valType:\"data_array\"},value:{valType:\"data_array\"},isomin:{valType:\"number\"},isomax:{valType:\"number\"},surface:{show:{valType:\"boolean\",dflt:!0},count:{valType:\"integer\",dflt:2,min:1},fill:{valType:\"number\",min:0,max:1,dflt:1},pattern:{valType:\"flaglist\",flags:[\"A\",\"B\",\"C\",\"D\",\"E\"],extras:[\"all\",\"odd\",\"even\"],dflt:\"all\"}},spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:.15}},slices:{x:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!1},locations:{valType:\"data_array\",dflt:[]},fill:{valType:\"number\",min:0,max:1,dflt:1}}},caps:{x:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},y:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}},z:{show:{valType:\"boolean\",dflt:!0},fill:{valType:\"number\",min:0,max:1,dflt:1}}},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:i(),showlegend:s({},o.showlegend,{dflt:!1})},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,lightposition:a.lightposition,lighting:a.lighting,flatshading:a.flatshading,contour:a.contour,hoverinfo:s({},o.hoverinfo)}),\"calc\",\"nested\");c.flatshading.dflt=!0,c.lighting.facenormalsepsilon.dflt=0,c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1124:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\"),i=t(\"../streamtube/calc\").processGrid,a=t(\"../streamtube/calc\").filter;e.exports=function(t,e){e._len=Math.min(e.x.length,e.y.length,e.z.length,e.value.length),e._x=a(e.x,e._len),e._y=a(e.y,e._len),e._z=a(e.z,e._len),e._value=a(e.value,e._len);var r=i(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;for(var o=1/0,s=-1/0,l=0;l<e._len;l++){var c=e._value[l];o=Math.min(o,c),s=Math.max(s,c)}e._minValues=o,e._maxValues=s,e._vMin=void 0===e.isomin||null===e.isomin?o:e.isomin,e._vMax=void 0===e.isomax||null===e.isomin?s:e.isomax,n(t,e,{vals:[e._vMin,e._vMax],containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651,\"../streamtube/calc\":1295}],1125:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=function(t,e){for(var r=e.length-1;r>0;r--){var n=Math.min(e[r],e[r-1]),i=Math.max(e[r],e[r-1]);if(i>n&&n<t&&t<=i)return{id:r,distRatio:(i-t)/(i-n)}}return{id:0,distRatio:0}};function c(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var u=c.prototype;u.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},u.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=h(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},c=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[c.min,c.max],l.colormap=i(t),this.mesh.update(l)},u.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()};var f=[\"xyz\",\"xzy\",\"yxz\",\"yzx\",\"zxy\",\"zyx\"];function h(t){t._meshI=[],t._meshJ=[],t._meshK=[];var e,r,n,i,a,o,s,c=t.surface.show,u=t.spaceframe.show,h=t.surface.fill,p=t.spaceframe.fill,d=!1,g=!1,m=0,v=t._Xs,y=t._Ys,x=t._Zs,b=v.length,_=y.length,w=x.length,T=f.indexOf(t._gridFill.replace(/-/g,\"\").replace(/\\+/g,\"\")),k=function(t,e,r){switch(T){case 5:return r+w*e+w*_*t;case 4:return r+w*t+w*b*e;case 3:return e+_*r+_*w*t;case 2:return e+_*t+_*b*r;case 1:return t+b*r+b*w*e;default:return t+b*e+b*_*r}},M=t._minValues,A=t._maxValues,S=t._vMin,E=t._vMax;function C(t,e,s){for(var l=o.length,c=r;c<l;c++)if(t===n[c]&&e===i[c]&&s===a[c])return c;return-1}function L(){r=e}function I(){n=[],i=[],a=[],o=[],e=0,L()}function P(t,r,s,l){return n.push(t),i.push(r),a.push(s),o.push(l),++e-1}function z(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=t[i]*(1-r)+r*e[i];return n}function O(t){s=t}function D(t,e){return\"all\"===t||null===t||t.indexOf(e)>-1}function R(t,e){return null===t?e:t}function F(e,r,n){L();var i,a,o,l=[r],c=[n];if(s>=1)l=[r],c=[n];else if(s>0){var u=function(t,e){var r=t[0],n=t[1],i=t[2],a=function(t,e,r){for(var n=[],i=0;i<t.length;i++)n[i]=(t[i]+e[i]+r[i])/3;return n}(r,n,i),o=Math.sqrt(1-s),l=z(a,r,o),c=z(a,n,o),u=z(a,i,o),f=e[0],h=e[1],p=e[2];return{xyzv:[[r,n,c],[c,l,r],[n,i,u],[u,c,n],[i,r,l],[l,u,i]],abc:[[f,h,-1],[-1,-1,f],[h,p,-1],[-1,-1,h],[p,f,-1],[-1,-1,p]]}}(r,n);l=u.xyzv,c=u.abc}for(var f=0;f<l.length;f++){r=l[f],n=c[f];for(var h=[],p=0;p<3;p++){var d=r[p][0],g=r[p][1],v=r[p][2],y=r[p][3],x=n[p]>-1?n[p]:C(d,g,v);h[p]=x>-1?x:P(d,g,v,R(e,y))}i=h[0],a=h[1],o=h[2],t._meshI.push(i),t._meshJ.push(a),t._meshK.push(o),++m}}function B(t,e,r,n){var i=t[3];i<r&&(i=r),i>n&&(i=n);for(var a=(t[3]-i)/(t[3]-e[3]+1e-9),o=[],s=0;s<4;s++)o[s]=(1-a)*t[s]+a*e[s];return o}function N(t,e,r){return t>=e&&t<=r}function j(t){var e=.001*(E-S);return t>=S-e&&t<=E+e}function U(e){for(var r=[],n=0;n<4;n++){var i=e[n];r.push([t._x[i],t._y[i],t._z[i],t._value[i]])}return r}function V(t,e,r,n,i,a){a||(a=1),r=[-1,-1,-1];var o=!1,s=[N(e[0][3],n,i),N(e[1][3],n,i),N(e[2][3],n,i)];if(!s[0]&&!s[1]&&!s[2])return!1;var l=function(t,e,r){return j(e[0][3])&&j(e[1][3])&&j(e[2][3])?(F(t,e,r),!0):a<3&&V(t,e,r,S,E,++a)};if(s[0]&&s[1]&&s[2])return l(t,e,r)||o;var c=!1;return[[0,1,2],[2,0,1],[1,2,0]].forEach((function(a){if(s[a[0]]&&s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(h,u,n,i),d=B(h,f,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,o=l(t,[u,f,d],[r[a[0]],r[a[1]],-1])||o,c=!0}})),c||[[0,1,2],[1,2,0],[2,0,1]].forEach((function(a){if(s[a[0]]&&!s[a[1]]&&!s[a[2]]){var u=e[a[0]],f=e[a[1]],h=e[a[2]],p=B(f,u,n,i),d=B(h,u,n,i);o=l(t,[d,p,u],[-1,-1,r[a[0]]])||o,c=!0}})),o}function q(t,e,r,n){var i=!1,a=U(e),o=[N(a[0][3],r,n),N(a[1][3],r,n),N(a[2][3],r,n),N(a[3][3],r,n)];if(!(o[0]||o[1]||o[2]||o[3]))return i;if(o[0]&&o[1]&&o[2]&&o[3])return g&&(i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(3,0,1),n(2,3,0),n(1,2,3)}(t,a,e)||i),i;var s=!1;return[[0,1,2,3],[3,0,1,2],[2,3,0,1],[1,2,3,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]];if(g)i=F(t,[c,u,f],[e[l[0]],e[l[1]],e[l[2]]])||i;else{var p=B(h,c,r,n),d=B(h,u,r,n),m=B(h,f,r,n);i=F(null,[p,d,m],[-1,-1,-1])||i}s=!0}})),s?i:([[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2],[0,2,3,1],[1,3,2,0]].forEach((function(l){if(o[l[0]]&&o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(f,c,r,n),d=B(f,u,r,n),m=B(h,u,r,n),v=B(h,c,r,n);g?(i=F(t,[c,v,p],[e[l[0]],-1,-1])||i,i=F(t,[u,d,m],[e[l[1]],-1,-1])||i):i=function(t,e,r){var n=function(n,i,a){F(t,[e[n],e[i],e[a]],[r[n],r[i],r[a]])};n(0,1,2),n(2,3,0)}(null,[p,d,m,v],[-1,-1,-1,-1])||i,s=!0}})),s||[[0,1,2,3],[1,2,3,0],[2,3,0,1],[3,0,1,2]].forEach((function(l){if(o[l[0]]&&!o[l[1]]&&!o[l[2]]&&!o[l[3]]){var c=a[l[0]],u=a[l[1]],f=a[l[2]],h=a[l[3]],p=B(u,c,r,n),d=B(f,c,r,n),m=B(h,c,r,n);g?(i=F(t,[c,p,d],[e[l[0]],-1,-1])||i,i=F(t,[c,d,m],[e[l[0]],-1,-1])||i,i=F(t,[c,m,p],[e[l[0]],-1,-1])||i):i=F(null,[p,d,m],[-1,-1,-1])||i,s=!0}})),i)}function H(t,e,r,n,i,a,o,s,l,c,u){var f=!1;return d&&(D(t,\"A\")&&(f=q(null,[e,r,n,a],c,u)||f),D(t,\"B\")&&(f=q(null,[r,n,i,l],c,u)||f),D(t,\"C\")&&(f=q(null,[r,a,o,l],c,u)||f),D(t,\"D\")&&(f=q(null,[n,a,s,l],c,u)||f),D(t,\"E\")&&(f=q(null,[r,n,a,l],c,u)||f)),g&&(f=q(t,[r,n,a,l],c,u)||f),f}function G(t,e,r,n,i,a,o,s){return[!0===s[0]||V(t,U([e,r,n]),[e,r,n],a,o),!0===s[1]||V(t,U([n,i,e]),[n,i,e],a,o)]}function Y(t,e,r,n,i,a,o,s,l){return s?G(t,e,r,i,n,a,o,l):G(t,r,i,n,e,a,o,l)}function W(t,e,r,n,i,a,o){var s,l,c,u,f=!1,h=function(){f=V(t,[s,l,c],[-1,-1,-1],i,a)||f,f=V(t,[c,u,s],[-1,-1,-1],i,a)||f},p=o[0],d=o[1],g=o[2];return p&&(s=z(U([k(e,r-0,n-0)])[0],U([k(e-1,r-0,n-0)])[0],p),l=z(U([k(e,r-0,n-1)])[0],U([k(e-1,r-0,n-1)])[0],p),c=z(U([k(e,r-1,n-1)])[0],U([k(e-1,r-1,n-1)])[0],p),u=z(U([k(e,r-1,n-0)])[0],U([k(e-1,r-1,n-0)])[0],p),h()),d&&(s=z(U([k(e-0,r,n-0)])[0],U([k(e-0,r-1,n-0)])[0],d),l=z(U([k(e-0,r,n-1)])[0],U([k(e-0,r-1,n-1)])[0],d),c=z(U([k(e-1,r,n-1)])[0],U([k(e-1,r-1,n-1)])[0],d),u=z(U([k(e-1,r,n-0)])[0],U([k(e-1,r-1,n-0)])[0],d),h()),g&&(s=z(U([k(e-0,r-0,n)])[0],U([k(e-0,r-0,n-1)])[0],g),l=z(U([k(e-0,r-1,n)])[0],U([k(e-0,r-1,n-1)])[0],g),c=z(U([k(e-1,r-1,n)])[0],U([k(e-1,r-1,n-1)])[0],g),u=z(U([k(e-1,r-0,n)])[0],U([k(e-1,r-0,n-1)])[0],g),h()),f}function X(t,e,r,n,i,a,o,s,l,c,u,f){var h=t;return f?(d&&\"even\"===t&&(h=null),H(h,e,r,n,i,a,o,s,l,c,u)):(d&&\"odd\"===t&&(h=null),H(h,l,s,o,a,i,n,r,e,c,u))}function Z(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<w;c++)for(var u=1;u<_;u++)a.push(Y(t,k(l,u-1,c-1),k(l,u-1,c),k(l,u,c-1),k(l,u,c),r,n,(l+u+c)%2,i&&i[o]?i[o]:[])),o++;return a}function J(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<b;c++)for(var u=1;u<w;u++)a.push(Y(t,k(c-1,l,u-1),k(c,l,u-1),k(c-1,l,u),k(c,l,u),r,n,(c+l+u)%2,i&&i[o]?i[o]:[])),o++;return a}function K(t,e,r,n,i){for(var a=[],o=0,s=0;s<e.length;s++)for(var l=e[s],c=1;c<_;c++)for(var u=1;u<b;u++)a.push(Y(t,k(u-1,c-1,l),k(u-1,c,l),k(u,c-1,l),k(u,c,l),r,n,(u+c+l)%2,i&&i[o]?i[o]:[])),o++;return a}function Q(t,e,r){for(var n=1;n<w;n++)for(var i=1;i<_;i++)for(var a=1;a<b;a++)X(t,k(a-1,i-1,n-1),k(a-1,i-1,n),k(a-1,i,n-1),k(a-1,i,n),k(a,i-1,n-1),k(a,i-1,n),k(a,i,n-1),k(a,i,n),e,r,(a+i+n)%2)}function $(t,e,r){d=!0,Q(t,e,r),d=!1}function tt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<w;u++)for(var f=1;f<_;f++)o.push(W(t,c,f,u,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function et(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<b;u++)for(var f=1;f<w;f++)o.push(W(t,u,c,f,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function rt(t,e,r,n,i,a){for(var o=[],s=0,l=0;l<e.length;l++)for(var c=e[l],u=1;u<_;u++)for(var f=1;f<b;f++)o.push(W(t,f,u,c,r,n,i[l],a&&a[s]&&a[s])),s++;return o}function nt(t,e){for(var r=[],n=t;n<e;n++)r.push(n);return r}return function(){if(I(),function(){for(var e=0;e<b;e++)for(var r=0;r<_;r++)for(var n=0;n<w;n++){var i=k(e,r,n);P(t._x[i],t._y[i],t._z[i],t._value[i])}}(),u&&p&&(O(p),g=!0,Q(null,S,E),g=!1),c&&h){O(h);for(var e=t.surface.pattern,r=t.surface.count,s=0;s<r;s++){var f=1===r?.5:s/(r-1),d=(1-f)*S+f*E,T=Math.abs(d-M)>Math.abs(d-A)?[M,d]:[d,A];$(e,T[0],T[1])}}var C=[[Math.min(S,A),Math.max(S,A)],[Math.min(M,E),Math.max(M,E)]];[\"x\",\"y\",\"z\"].forEach((function(e){for(var r=[],n=0;n<C.length;n++){var i=0,a=C[n][0],o=C[n][1],s=t.slices[e];if(s.show&&s.fill){O(s.fill);var c=[],u=[],f=[];if(s.locations.length)for(var h=0;h<s.locations.length;h++){var p=l(s.locations[h],\"x\"===e?v:\"y\"===e?y:x);0===p.distRatio?c.push(p.id):p.id>0&&(u.push(p.id),\"x\"===e?f.push([p.distRatio,0,0]):\"y\"===e?f.push([0,p.distRatio,0]):f.push([0,0,p.distRatio]))}else c=nt(1,\"x\"===e?b-1:\"y\"===e?_-1:w-1);u.length>0&&(r[i]=\"x\"===e?tt(null,u,a,o,f,r[i]):\"y\"===e?et(null,u,a,o,f,r[i]):rt(null,u,a,o,f,r[i]),i++),c.length>0&&(r[i]=\"x\"===e?Z(null,c,a,o,r[i]):\"y\"===e?J(null,c,a,o,r[i]):K(null,c,a,o,r[i]),i++)}var d=t.caps[e];d.show&&d.fill&&(O(d.fill),r[i]=\"x\"===e?Z(null,[0,b-1],a,o,r[i]):\"y\"===e?J(null,[0,_-1],a,o,r[i]):K(null,[0,w-1],a,o,r[i]),i++)}})),0===m&&I(),t._meshX=n,t._meshY=i,t._meshZ=a,t._meshIntensity=o,t._Xs=v,t._Ys=y,t._Zs=x}(),t}e.exports={findNearestOnAxis:l,generateIsoMeshes:h,createIsosurfaceTrace:function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new c(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"gl-mesh3d\":309}],1126:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"../../components/colorscale/defaults\");function s(t,e,r,n,a){var s=a(\"isomin\"),l=a(\"isomax\");null!=l&&null!=s&&s>l&&(e.isomin=null,e.isomax=null);var c=a(\"x\"),u=a(\"y\"),f=a(\"z\"),h=a(\"value\");c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length?(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],n),[\"x\",\"y\",\"z\"].forEach((function(t){var e=\"caps.\"+t;a(e+\".show\")&&a(e+\".fill\");var r=\"slices.\"+t;a(r+\".show\")&&(a(r+\".fill\"),a(r+\".locations\"))})),a(\"spaceframe.show\")&&a(\"spaceframe.fill\"),a(\"surface.show\")&&(a(\"surface.count\"),a(\"surface.fill\"),a(\"surface.pattern\")),a(\"contour.show\")&&(a(\"contour.color\"),a(\"contour.width\")),[\"text\",\"hovertext\",\"hovertemplate\",\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"opacity\"].forEach((function(t){a(t)})),o(t,e,n,a,{prefix:\"\",cLetter:\"c\"}),e._length=null):e.visible=!1}e.exports={supplyDefaults:function(t,e,r,i){s(t,e,r,i,(function(r,i){return n.coerce(t,e,a,r,i)}))},supplyIsoDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1123}],1127:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\").createIsosurfaceTrace,moduleType:\"trace\",name:\"isosurface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1123,\"./calc\":1124,\"./convert\":1125,\"./defaults\":1126}],1128:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat;e.exports=s({x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},i:{valType:\"data_array\",editType:\"calc\"},j:{valType:\"data_array\",editType:\"calc\"},k:{valType:\"data_array\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertemplate:i({editType:\"calc\"}),delaunayaxis:{valType:\"enumerated\",values:[\"x\",\"y\",\"z\"],dflt:\"z\",editType:\"calc\"},alphahull:{valType:\"number\",dflt:-1,editType:\"calc\"},intensity:{valType:\"data_array\",editType:\"calc\"},intensitymode:{valType:\"enumerated\",values:[\"vertex\",\"cell\"],dflt:\"vertex\",editType:\"calc\"},color:{valType:\"color\",editType:\"calc\"},vertexcolor:{valType:\"data_array\",editType:\"calc\"},facecolor:{valType:\"data_array\",editType:\"calc\"},transforms:void 0},n(\"\",{colorAttr:\"`intensity`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{opacity:a.opacity,flatshading:{valType:\"boolean\",dflt:!1,editType:\"calc\"},contour:{show:s({},a.contours.x.show,{}),color:a.contours.x.color,width:a.contours.x.width,editType:\"calc\"},lightposition:{x:s({},a.lightposition.x,{dflt:1e5}),y:s({},a.lightposition.y,{dflt:1e5}),z:s({},a.lightposition.z,{dflt:0}),editType:\"calc\"},lighting:s({vertexnormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-12,editType:\"calc\"},facenormalsepsilon:{valType:\"number\",min:0,max:1,dflt:1e-6,editType:\"calc\"},editType:\"calc\"},a.lighting),hoverinfo:s({},o.hoverinfo,{editType:\"calc\"}),showlegend:s({},o.showlegend,{dflt:!1})})},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../surface/attributes\":1311}],1129:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.intensity&&n(t,e,{vals:e.intensity,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1130:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"delaunay-triangulate\"),a=t(\"alpha-shape\"),o=t(\"convex-hull\"),s=t(\"../../lib/gl_format_color\").parseColorScale,l=t(\"../../lib/str2rgbarray\"),c=t(\"../../components/colorscale\").extractOpts,u=t(\"../../plots/gl3d/zip3\");function f(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.color=\"#fff\",this.data=null,this.showContour=!1}var h=f.prototype;function p(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=l(t[n]);return e}function d(t,e,r,n){for(var i=[],a=e.length,o=0;o<a;o++)i[o]=t.d2l(e[o],0,n)*r;return i}function g(t){for(var e=[],r=t.length,n=0;n<r;n++)e[n]=Math.round(t[n]);return e}function m(t,e){for(var r=t.length,n=0;n<r;n++)if(t[n]<=-.5||t[n]>=e-.5)return!1;return!0}h.handlePick=function(t){if(t.object===this.mesh){var e=t.index=t.data.index;t.data._cellCenter?t.traceCoordinate=t.data.dataCoordinate:t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]];var r=this.data.hovertext||this.data.text;return Array.isArray(r)&&void 0!==r[e]?t.textLabel=r[e]:r&&(t.textLabel=r),!0}},h.update=function(t){var e=this.scene,r=e.fullSceneLayout;this.data=t;var n,f=t.x.length,h=u(d(r.xaxis,t.x,e.dataScale[0],t.xcalendar),d(r.yaxis,t.y,e.dataScale[1],t.ycalendar),d(r.zaxis,t.z,e.dataScale[2],t.zcalendar));if(t.i&&t.j&&t.k){if(t.i.length!==t.j.length||t.j.length!==t.k.length||!m(t.i,f)||!m(t.j,f)||!m(t.k,f))return;n=u(g(t.i),g(t.j),g(t.k))}else n=0===t.alphahull?o(h):t.alphahull>0?a(t.alphahull,h):function(t,e){for(var r=[\"x\",\"y\",\"z\"].indexOf(t),n=[],a=e.length,o=0;o<a;o++)n[o]=[e[o][(r+1)%3],e[o][(r+2)%3]];return i(n)}(t.delaunayaxis,h);var v={positions:h,cells:n,lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,contourEnable:t.contour.show,contourColor:l(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading};if(t.intensity){var y=c(t);this.color=\"#fff\";var x=t.intensitymode;v[x+\"Intensity\"]=t.intensity,v[x+\"IntensityBounds\"]=[y.min,y.max],v.colormap=s(t)}else t.vertexcolor?(this.color=t.vertexcolor[0],v.vertexColors=p(t.vertexcolor)):t.facecolor?(this.color=t.facecolor[0],v.cellColors=p(t.facecolor)):(this.color=t.color,v.meshColor=l(t.color));this.mesh.update(v)},h.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new f(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"alpha-shape\":69,\"convex-hull\":135,\"delaunay-triangulate\":171,\"gl-mesh3d\":309}],1131:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,n){return i.coerce(t,e,o,r,n)}function c(t){var e=t.map((function(t){var e=l(t);return e&&i.isArrayOrTypedArray(e)?e:null}));return e.every((function(t){return t&&t.length===e[0].length}))&&e}c([\"x\",\"y\",\"z\"])?(c([\"i\",\"j\",\"k\"]),(!e.i||e.j&&e.k)&&(!e.j||e.k&&e.i)&&(!e.k||e.i&&e.j)?(n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],s),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lighting.vertexnormalsepsilon\",\"lighting.facenormalsepsilon\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"flatshading\",\"alphahull\",\"delaunayaxis\",\"opacity\"].forEach((function(t){l(t)})),l(\"contour.show\")&&(l(\"contour.color\"),l(\"contour.width\")),\"intensity\"in t?(l(\"intensity\"),l(\"intensitymode\"),a(t,e,s,l,{prefix:\"\",cLetter:\"c\"})):(e.showscale=!1,\"facecolor\"in t?l(\"facecolor\"):\"vertexcolor\"in t?l(\"vertexcolor\"):l(\"color\",r)),l(\"text\"),l(\"hovertext\"),l(\"hovertemplate\"),e._length=null):e.visible=!1):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1128}],1132:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"mesh3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1128,\"./calc\":1129,\"./convert\":1130,\"./defaults\":1131}],1133:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").extendFlat,i=t(\"../scatter/attributes\"),a=t(\"../../components/drawing/attributes\").dash,o=t(\"../../components/fx/attributes\"),s=t(\"../../constants/delta.js\"),l=s.INCREASING.COLOR,c=s.DECREASING.COLOR,u=i.line;function f(t){return{line:{color:n({},u.color,{dflt:t}),width:u.width,dash:a,editType:\"style\"},editType:\"style\"}}e.exports={xperiod:i.xperiod,xperiod0:i.xperiod0,xperiodalignment:i.xperiodalignment,x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},open:{valType:\"data_array\",editType:\"calc\"},high:{valType:\"data_array\",editType:\"calc\"},low:{valType:\"data_array\",editType:\"calc\"},close:{valType:\"data_array\",editType:\"calc\"},line:{width:n({},u.width,{}),dash:n({},a,{}),editType:\"style\"},increasing:f(l),decreasing:f(c),text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},tickwidth:{valType:\"number\",min:0,max:.5,dflt:.3,editType:\"calc\"},hoverlabel:n({},o.hoverlabel,{split:{valType:\"boolean\",dflt:!1,editType:\"style\"}})}},{\"../../components/drawing/attributes\":664,\"../../components/fx/attributes\":674,\"../../constants/delta.js\":747,\"../../lib\":778,\"../scatter/attributes\":1187}],1134:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=n._,a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r,n){return{o:t,h:e,l:r,c:n}}function c(t,e,r,o,l,c){for(var u=l.makeCalcdata(e,\"open\"),f=l.makeCalcdata(e,\"high\"),h=l.makeCalcdata(e,\"low\"),p=l.makeCalcdata(e,\"close\"),d=Array.isArray(e.text),g=Array.isArray(e.hovertext),m=!0,v=null,y=!!e.xperiodalignment,x=[],b=0;b<o.length;b++){var _=o[b],w=u[b],T=f[b],k=h[b],M=p[b];if(_!==s&&w!==s&&T!==s&&k!==s&&M!==s){M===w?null!==v&&M!==v&&(m=M>v):m=M>w,v=M;var A=c(w,T,k,M);A.pos=_,A.yc=(w+M)/2,A.i=b,A.dir=m?\"increasing\":\"decreasing\",A.x=A.pos,A.y=[k,T],y&&(A.orig_p=r[b]),d&&(A.tx=e.text[b]),g&&(A.htx=e.hovertext[b]),x.push(A)}else x.push({pos:_,empty:!0})}return e._extremes[l._id]=a.findExtremes(l,n.concat(h,f),{padded:!0}),x.length&&(x[0].t={labels:{open:i(t,\"open:\")+\" \",high:i(t,\"high:\")+\" \",low:i(t,\"low:\")+\" \",close:i(t,\"close:\")+\" \"}}),x}e.exports={calc:function(t,e){var r=a.getFromId(t,e.xaxis),i=a.getFromId(t,e.yaxis),s=function(t,e,r){var i=r._minDiff;if(!i){var a,s=t._fullData,l=[];for(i=1/0,a=0;a<s.length;a++){var c=s[a];if(\"ohlc\"===c.type&&!0===c.visible&&c.xaxis===e._id){l.push(c);var u=e.makeCalcdata(c,\"x\");c._origX=u;var f=o(r,e,\"x\",u);c._xcalc=f;var h=n.distinctVals(f).minDiff;h&&isFinite(h)&&(i=Math.min(i,h))}}for(i===1/0&&(i=1),a=0;a<l.length;a++)l[a]._minDiff=i}return i*r.tickwidth}(t,r,e),u=e._minDiff;e._minDiff=null;var f=e._origX;e._origX=null;var h=e._xcalc;e._xcalc=null;var p=c(t,e,f,h,i,l);return e._extremes[r._id]=a.findExtremes(r,h,{vpad:u/2}),p.length?(n.extendFlat(p[0].t,{wHover:u/2,tickLen:s}),p):[{t:{empty:!0}}]},calcCommon:c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828}],1135:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./ohlc_defaults\"),a=t(\"../scatter/period_defaults\"),o=t(\"./attributes\");function s(t,e,r,n){r(n+\".line.color\"),r(n+\".line.width\",e.line.width),r(n+\".line.dash\",e.line.dash)}e.exports=function(t,e,r,l){function c(r,i){return n.coerce(t,e,o,r,i)}i(t,e,c,l)?(a(t,e,l,c,{x:!0}),c(\"line.width\"),c(\"line.dash\"),s(t,e,c,\"increasing\"),s(t,e,c,\"decreasing\"),c(\"text\"),c(\"hovertext\"),c(\"tickwidth\"),l._requestRangeslider[e.xaxis]=!0):e.visible=!1}},{\"../../lib\":778,\"../scatter/period_defaults\":1207,\"./attributes\":1133,\"./ohlc_defaults\":1138}],1136:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../lib\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\").fillText,l=t(\"../../constants/delta.js\"),c={increasing:l.INCREASING.SYMBOL,decreasing:l.DECREASING.SYMBOL};function u(t,e,r,n){var i,s,l=t.cd,c=t.xa,u=l[0].trace,f=l[0].t,h=u.type,p=\"ohlc\"===h?\"l\":\"min\",d=\"ohlc\"===h?\"h\":\"max\",g=f.bPos||0,m=f.bdPos||f.tickLen,v=f.wHover,y=Math.min(1,m/Math.abs(c.r2c(c.range[1])-c.r2c(c.range[0])));function x(t){var r=function(t){return t.pos+g-e}(t);return a.inbox(r-v,r+v,i)}function b(t){var e=t[p],n=t[d];return e===n||a.inbox(e-r,n-r,i)}function _(t){return(x(t)+b(t))/2}i=t.maxHoverDistance-y,s=t.maxSpikeDistance-y;var w=a.getDistanceFunction(n,x,b,_);if(a.getClosest(l,w,t),!1===t.index)return null;var T=l[t.index];if(T.empty)return null;var k=u[T.dir],M=k.line.color;return o.opacity(M)&&k.line.width?t.color=M:t.color=k.fillcolor,t.x0=c.c2p(T.pos+g-m,!0),t.x1=c.c2p(T.pos+g+m,!0),t.xLabelVal=void 0!==T.orig_p?T.orig_p:T.pos,t.spikeDistance=_(T)*s/i,t.xSpike=c.c2p(T.pos,!0),t}function f(t,e,r,a){var o=t.cd,s=t.ya,l=o[0].trace,c=o[0].t,f=[],h=u(t,e,r,a);if(!h)return[];var p=o[h.index].hi||l.hoverinfo,d=p.split(\"+\");if(!(\"all\"===p||-1!==d.indexOf(\"y\")))return[];for(var g=[\"high\",\"open\",\"close\",\"low\"],m={},v=0;v<g.length;v++){var y,x=g[v],b=l[x][h.index],_=s.c2p(b,!0);b in m?(y=m[b]).yLabel+=\"<br>\"+c.labels[x]+n.hoverLabelText(s,b):((y=i.extendFlat({},h)).y0=y.y1=_,y.yLabelVal=b,y.yLabel=c.labels[x]+n.hoverLabelText(s,b),y.name=\"\",f.push(y),m[b]=y)}return f}function h(t,e,r,i){var a=t.cd,o=t.ya,l=a[0].trace,f=a[0].t,h=u(t,e,r,i);if(!h)return[];var p=a[h.index],d=h.index=p.i,g=p.dir;function m(t){return f.labels[t]+n.hoverLabelText(o,l[t][d])}var v=p.hi||l.hoverinfo,y=v.split(\"+\"),x=\"all\"===v,b=x||-1!==y.indexOf(\"y\"),_=x||-1!==y.indexOf(\"text\"),w=b?[m(\"open\"),m(\"high\"),m(\"low\"),m(\"close\")+\"  \"+c[g]]:[];return _&&s(p,l,w),h.extraText=w.join(\"<br>\"),h.y0=h.y1=o.c2p(p.yc,!0),[h]}e.exports={hoverPoints:function(t,e,r,n){return t.cd[0].trace.hoverlabel.split?f(t,e,r,n):h(t,e,r,n)},hoverSplit:f,hoverOnPoints:h}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../constants/delta.js\":747,\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1137:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"ohlc\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"showLegend\"],meta:{},attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\").calc,plot:t(\"./plot\"),style:t(\"./style\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\")}},{\"../../plots/cartesian\":841,\"./attributes\":1133,\"./calc\":1134,\"./defaults\":1135,\"./hover\":1136,\"./plot\":1139,\"./select\":1140,\"./style\":1141}],1138:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=r(\"x\"),s=r(\"open\"),l=r(\"high\"),c=r(\"low\"),u=r(\"close\");if(r(\"hoverlabel.split\"),n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\"],a),s&&l&&c&&u){var f=Math.min(s.length,l.length,c.length,u.length);return o&&(f=Math.min(f,i.minRowLength(o))),e._length=f,f}}},{\"../../lib\":778,\"../../registry\":911}],1139:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\");e.exports=function(t,e,r,a){var o=e.yaxis,s=e.xaxis,l=!!s.rangebreaks;i.makeTraceGroups(a,r,\"trace ohlc\").each((function(t){var e=n.select(this),r=t[0],a=r.t;if(!0!==r.trace.visible||a.empty)e.remove();else{var c=a.tickLen,u=e.selectAll(\"path\").data(i.identity);u.enter().append(\"path\"),u.exit().remove(),u.attr(\"d\",(function(t){if(t.empty)return\"M0,0Z\";var e=s.c2p(t.pos-c,!0),r=s.c2p(t.pos+c,!0),n=l?(e+r)/2:s.c2p(t.pos,!0);return\"M\"+e+\",\"+o.c2p(t.o,!0)+\"H\"+n+\"M\"+n+\",\"+o.c2p(t.h,!0)+\"V\"+o.c2p(t.l,!0)+\"M\"+r+\",\"+o.c2p(t.c,!0)+\"H\"+n}))}}))}},{\"../../lib\":778,d3:169}],1140:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r,n=t.cd,i=t.xaxis,a=t.yaxis,o=[],s=n[0].t.bPos||0;if(!1===e)for(r=0;r<n.length;r++)n[r].selected=0;else for(r=0;r<n.length;r++){var l=n[r];e.contains([i.c2p(l.pos+s),a.c2p(l.yc)],null,l.i,t)?(o.push({pointNumber:l.i,x:i.c2d(l.pos),y:a.c2d(l.yc)}),l.selected=1):l.selected=0}return o}},{}],1141:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\");e.exports=function(t,e,r){var o=r||n.select(t).selectAll(\"g.ohlclayer\").selectAll(\"g.trace\");o.style(\"opacity\",(function(t){return t[0].trace.opacity})),o.each((function(t){var e=t[0].trace;n.select(this).selectAll(\"path\").each((function(t){if(!t.empty){var r=e[t.dir].line;n.select(this).style(\"fill\",\"none\").call(a.stroke,r.color).call(i.dashLine,r.dash,r.width).style(\"opacity\",e.selectedpoints&&!t.selected?.3:1)}}))}))}},{\"../../components/color\":643,\"../../components/drawing\":665,d3:169}],1142:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat,i=t(\"../../plots/attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/domain\").attributes,c=n({editType:\"calc\"},o(\"line\",{editTypeOverride:\"calc\"}),{shape:{valType:\"enumerated\",values:[\"linear\",\"hspline\"],dflt:\"linear\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\"]})});e.exports={domain:l({name:\"parcats\",trace:!0,editType:\"calc\"}),hoverinfo:n({},i.hoverinfo,{flags:[\"count\",\"probability\"],editType:\"plot\",arrayOk:!1}),hoveron:{valType:\"enumerated\",values:[\"category\",\"color\",\"dimension\"],dflt:\"category\",editType:\"plot\"},hovertemplate:s({editType:\"plot\",arrayOk:!1},{keys:[\"count\",\"probability\",\"category\",\"categorycount\",\"colorcount\",\"bandcolorcount\"]}),arrangement:{valType:\"enumerated\",values:[\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"perpendicular\",editType:\"plot\"},bundlecolors:{valType:\"boolean\",dflt:!0,editType:\"plot\"},sortpaths:{valType:\"enumerated\",values:[\"forward\",\"backward\"],dflt:\"forward\",editType:\"plot\"},labelfont:a({editType:\"calc\"}),tickfont:a({editType:\"calc\"}),dimensions:{_isLinkedToArray:\"dimension\",label:{valType:\"string\",editType:\"calc\"},categoryorder:{valType:\"enumerated\",values:[\"trace\",\"category ascending\",\"category descending\",\"array\"],dflt:\"trace\",editType:\"calc\"},categoryarray:{valType:\"data_array\",editType:\"calc\"},ticktext:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",dflt:[],editType:\"calc\"},displayindex:{valType:\"integer\",editType:\"calc\"},editType:\"calc\",visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"}},line:c,counts:{valType:\"number\",min:0,dflt:1,arrayOk:!0,editType:\"calc\"},customdata:void 0,hoverlabel:void 0,ids:void 0,legendgroup:void 0,opacity:void 0,selectedpoints:void 0,showlegend:void 0}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1143:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"parcats\",r.plot=function(t,e,r,a){var o=n(t.calcdata,\"parcats\");if(o.length){var s=o[0];i(t,s,r,a)}},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcats\"),a=e._has&&e._has(\"parcats\");i&&!a&&n._paperdiv.selectAll(\".parcats\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1148}],1144:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/calc\"),o=t(\"../../lib/filter_unique.js\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=t(\"fast-isnumeric\");function u(t,e,r){t.valueInds.push(e),t.count+=r}function f(t,e,r){return{categoryInds:t,color:e,rawColor:r,valueInds:[],count:0}}function h(t,e,r){t.valueInds.push(e),t.count+=r}e.exports=function(t,e){var r=l.filterVisible(e.dimensions);if(0===r.length)return[];var p,d,g,m=r.map((function(t){var e;if(\"trace\"===t.categoryorder)e=null;else if(\"array\"===t.categoryorder)e=t.categoryarray;else{e=o(t.values);for(var r=!0,n=0;n<e.length;n++)if(!c(e[n])){r=!1;break}e.sort(r?l.sorterAsc:void 0),\"category descending\"===t.categoryorder&&(e=e.reverse())}return function(t,e){e=null==e?[]:e.map((function(t){return t}));var r={},n={},i=[];e.forEach((function(t,e){r[t]=0,n[t]=e}));for(var a=0;a<t.length;a++){var o,s=t[a];void 0===r[s]?(r[s]=1,o=e.push(s)-1,n[s]=o):(r[s]++,o=n[s]),i.push(o)}var l=e.map((function(t){return r[t]}));return{uniqueValues:e,uniqueCounts:l,inds:i}}(t.values,e)}));p=l.isArrayOrTypedArray(e.counts)?e.counts:[e.counts],function(t){var e;if(function(t){for(var e=new Array(t.length),r=0;r<t.length;r++){if(t[r]<0||t[r]>=t.length)return!1;if(void 0!==e[t[r]])return!1;e[t[r]]=!0}return!0}(t.map((function(t){return t.displayindex}))))for(e=0;e<t.length;e++)t[e]._displayindex=t[e].displayindex;else for(e=0;e<t.length;e++)t[e]._displayindex=e}(r),r.forEach((function(t,e){!function(t,e){t._categoryarray=e.uniqueValues,null===t.ticktext||void 0===t.ticktext?t._ticktext=[]:t._ticktext=t.ticktext.slice();for(var r=t._ticktext.length;r<e.uniqueValues.length;r++)t._ticktext.push(e.uniqueValues[r])}(t,m[e])}));var v,y=e.line;y?(i(e,\"line\")&&a(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),v=s.tryColorscale(y)):v=l.identity;var x,b,_,w,T,k=r[0].values.length,M={},A=m.map((function(t){return t.inds}));for(g=0,x=0;x<k;x++){var S=[];for(b=0;b<A.length;b++)S.push(A[b][x]);d=p[x%p.length],g+=d;var E=(_=x,w=void 0,T=void 0,l.isArrayOrTypedArray(y.color)?T=w=y.color[_%y.color.length]:w=y.color,{color:v(w),rawColor:T}),C=S+\"-\"+E.rawColor;void 0===M[C]&&(M[C]=f(S,E.color,E.rawColor)),h(M[C],x,d)}var L,I=r.map((function(t,e){return function(t,e,r,n,i){return{dimensionInd:t,containerInd:e,displayInd:r,dimensionLabel:n,count:i,categories:[],dragX:null}}(e,t._index,t._displayindex,t.label,g)}));for(x=0;x<k;x++)for(d=p[x%p.length],b=0;b<I.length;b++){var P=I[b].containerInd,z=m[b].inds[x],O=I[b].categories;if(void 0===O[z]){var D=e.dimensions[P]._categoryarray[z],R=e.dimensions[P]._ticktext[z];O[z]={dimensionInd:b,categoryInd:L=z,categoryValue:D,displayInd:L,categoryLabel:R,valueInds:[],count:0,dragY:null}}u(O[z],x,d)}return n(function(t,e,r){var n=t.map((function(t){return t.categories.length})).reduce((function(t,e){return Math.max(t,e)}));return{dimensions:t,paths:e,trace:void 0,maxCats:n,count:r}}(I,M,g))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/filter_unique.js\":769,\"../../lib/gup\":775,\"fast-isnumeric\":241}],1145:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"./attributes\"),c=t(\"../parcoords/merge_length\");function u(t,e){function r(r,i){return n.coerce(t,e,l.dimensions,r,i)}var i=r(\"values\"),a=r(\"visible\");if(i&&i.length||(a=e.visible=!1),a){r(\"label\"),r(\"displayindex\",e._index);var o,s=t.categoryarray,c=Array.isArray(s)&&s.length>0;c&&(o=\"array\");var u=r(\"categoryorder\",o);\"array\"===u?(r(\"categoryarray\"),r(\"ticktext\")):(delete t.categoryarray,delete t.ticktext),c||\"array\"!==u||(e.categoryorder=\"trace\")}}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,l,r,i)}var p=s(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=function(t,e,r,o,s){s(\"line.shape\"),s(\"line.hovertemplate\");var l=s(\"line.color\",o.colorway[0]);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,f,h);o(e,f,h),Array.isArray(p)&&p.length||(e.visible=!1),c(e,p,\"values\",d),h(\"hoveron\"),h(\"hovertemplate\"),h(\"arrangement\"),h(\"bundlecolors\"),h(\"sortpaths\"),h(\"counts\");var g={family:f.font.family,size:Math.round(f.font.size),color:f.font.color};n.coerceFont(h,\"labelfont\",g);var m={family:f.font.family,size:Math.round(f.font.size/1.2),color:f.font.color};n.coerceFont(h,\"tickfont\",m)}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"../parcoords/merge_length\":1158,\"./attributes\":1142}],1146:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcats\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1142,\"./base_plot\":1143,\"./calc\":1144,\"./defaults\":1145,\"./plot\":1148}],1147:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plot_api/plot_api\"),a=t(\"../../components/fx\"),o=t(\"../../lib\"),s=o.strTranslate,l=t(\"../../components/drawing\"),c=t(\"tinycolor2\"),u=t(\"../../lib/svg_text_utils\");function f(t,e,r,i){var a=t.map(R.bind(0,e,r)),c=i.selectAll(\"g.parcatslayer\").data([null]);c.enter().append(\"g\").attr(\"class\",\"parcatslayer\").style(\"pointer-events\",\"all\");var f=c.selectAll(\"g.trace.parcats\").data(a,h),v=f.enter().append(\"g\").attr(\"class\",\"trace parcats\");f.attr(\"transform\",(function(t){return s(t.x,t.y)})),v.append(\"g\").attr(\"class\",\"paths\");var y=f.select(\"g.paths\").selectAll(\"path.path\").data((function(t){return t.paths}),h);y.attr(\"fill\",(function(t){return t.model.color}));var _=y.enter().append(\"path\").attr(\"class\",\"path\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",0);b(_),y.attr(\"d\",(function(t){return t.svgD})),_.empty()||y.sort(d),y.exit().remove(),y.on(\"mouseover\",g).on(\"mouseout\",m).on(\"click\",x),v.append(\"g\").attr(\"class\",\"dimensions\");var k=f.select(\"g.dimensions\").selectAll(\"g.dimension\").data((function(t){return t.dimensions}),h);k.enter().append(\"g\").attr(\"class\",\"dimension\"),k.attr(\"transform\",(function(t){return s(t.x,0)})),k.exit().remove();var M=k.selectAll(\"g.category\").data((function(t){return t.categories}),h),A=M.enter().append(\"g\").attr(\"class\",\"category\");M.attr(\"transform\",(function(t){return s(0,t.y)})),A.append(\"rect\").attr(\"class\",\"catrect\").attr(\"pointer-events\",\"none\"),M.select(\"rect.catrect\").attr(\"fill\",\"none\").attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),w(A);var S=M.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h);S.each((function(){o.raiseToTop(this)})),S.attr(\"fill\",(function(t){return t.color}));var z=S.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);S.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})).attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"perpendicular\"===t.parcatsViewModel.arrangement?\"ns-resize\":\"move\"})),T(z),S.exit().remove(),A.append(\"text\").attr(\"class\",\"catlabel\").attr(\"pointer-events\",\"none\");var O=e._fullLayout.paper_bgcolor;M.select(\"text.catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"alignment-baseline\",\"middle\").style(\"text-shadow\",O+\" -1px  1px 2px, \"+O+\" 1px  1px 2px, \"+O+\"  1px -1px 2px, \"+O+\" -1px -1px 2px\").style(\"fill\",\"rgb(0, 0, 0)\").attr(\"x\",(function(t){return p(t)?t.width+5:-5})).attr(\"y\",(function(t){return t.height/2})).text((function(t){return t.model.categoryLabel})).each((function(t){l.font(n.select(this),t.parcatsViewModel.categorylabelfont),u.convertToTspans(n.select(this),e)})),A.append(\"text\").attr(\"class\",\"dimlabel\"),M.select(\"text.dimlabel\").attr(\"text-anchor\",\"middle\").attr(\"alignment-baseline\",\"baseline\").attr(\"cursor\",(function(t){return\"fixed\"===t.parcatsViewModel.arrangement?\"default\":\"ew-resize\"})).attr(\"x\",(function(t){return t.width/2})).attr(\"y\",-5).text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})).each((function(t){l.font(n.select(this),t.parcatsViewModel.labelfont)})),M.selectAll(\"rect.bandrect\").on(\"mouseover\",E).on(\"mouseout\",C),M.exit().remove(),k.call(n.behavior.drag().origin((function(t){return{x:t.x,y:0}})).on(\"dragstart\",L).on(\"drag\",I).on(\"dragend\",P)),f.each((function(t){t.traceSelection=n.select(this),t.pathSelection=n.select(this).selectAll(\"g.paths\").selectAll(\"path.path\"),t.dimensionSelection=n.select(this).selectAll(\"g.dimensions\").selectAll(\"g.dimension\")})),f.exit().remove()}function h(t){return t.key}function p(t){var e=t.parcatsViewModel.dimensions.length,r=t.parcatsViewModel.dimensions[e-1].model.dimensionInd;return t.model.dimensionInd===r}function d(t,e){return t.model.rawColor>e.model.rawColor?1:t.model.rawColor<e.model.rawColor?-1:0}function g(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){o.raiseToTop(this),_(n.select(this));var e=v(t),r=y(t);if(t.parcatsViewModel.graphDiv.emit(\"plotly_hover\",{points:e,event:n.event,constraints:r}),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\")){var i,s,l,u=n.mouse(this)[0],f=t.parcatsViewModel.graphDiv,h=t.parcatsViewModel.trace,p=f._fullLayout,d=p._paperdiv.node().getBoundingClientRect(),g=t.parcatsViewModel.graphDiv.getBoundingClientRect();for(l=0;l<t.leftXs.length-1;l++)if(t.leftXs[l]+t.dimWidths[l]-2<=u&&u<=t.leftXs[l+1]+2){var m=t.parcatsViewModel.dimensions[l],x=t.parcatsViewModel.dimensions[l+1];i=(m.x+m.width+x.x)/2,s=(t.topYs[l]+t.topYs[l+1]+t.height)/2;break}var b=t.parcatsViewModel.x+i,w=t.parcatsViewModel.y+s,T=c.mostReadable(t.model.color,[\"black\",\"white\"]),k=t.model.count,M=k/t.parcatsViewModel.model.count,A={countLabel:k,probabilityLabel:M.toFixed(3)},S=[];-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&S.push([\"Count:\",A.countLabel].join(\" \")),-1!==t.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&S.push([\"P:\",A.probabilityLabel].join(\" \"));var E=S.join(\"<br>\"),C=n.mouse(f)[0];a.loneHover({trace:h,x:b-d.left+g.left,y:w-d.top+g.top,text:E,color:t.model.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:10,fontColor:T,idealAlign:C<b?\"right\":\"left\",hovertemplate:(h.line||{}).hovertemplate,hovertemplateLabels:A,eventData:[{data:h._input,fullData:h,count:k,probability:M}]},{container:p._hoverlayer.node(),outerContainer:p._paper.node(),gd:f})}}}function m(t){if(!t.parcatsViewModel.dragDimension&&(b(n.select(this)),a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()),t.parcatsViewModel.pathSelection.sort(d),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\"))){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_unhover\",{points:e,event:n.event,constraints:r})}}function v(t){for(var e=[],r=z(t.parcatsViewModel),n=0;n<t.model.valueInds.length;n++){var i=t.model.valueInds[n];e.push({curveNumber:r,pointNumber:i})}return e}function y(t){for(var e={},r=t.parcatsViewModel.model.dimensions,n=0;n<r.length;n++){var i=r[n],a=i.categories[t.model.categoryInds[n]];e[i.containerInd]=a.categoryValue}return void 0!==t.model.rawColor&&(e.color=t.model.rawColor),e}function x(t){if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){var e=v(t),r=y(t);t.parcatsViewModel.graphDiv.emit(\"plotly_click\",{points:e,event:n.event,constraints:r})}}function b(t){t.attr(\"fill\",(function(t){return t.model.color})).attr(\"fill-opacity\",.6).attr(\"stroke\",\"lightgray\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1)}function _(t){t.attr(\"fill-opacity\",.8).attr(\"stroke\",(function(t){return c.mostReadable(t.model.color,[\"black\",\"white\"])})).attr(\"stroke-width\",.3)}function w(t){t.select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",1).attr(\"stroke-opacity\",1)}function T(t){t.attr(\"stroke\",\"black\").attr(\"stroke-width\",.2).attr(\"stroke-opacity\",1).attr(\"fill-opacity\",1)}function k(t){var e=t.parcatsViewModel.pathSelection,r=t.categoryViewModel.model.dimensionInd,n=t.categoryViewModel.model.categoryInd;return e.filter((function(e){return e.model.categoryInds[r]===n&&e.model.color===t.color}))}function M(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=n.select(t.parentNode).selectAll(\"rect.bandrect\"),l=[];s.each((function(t){k(t).each((function(t){Array.prototype.push.apply(l,v(t))}))}));var c={};c[a.dimensionInd]=a.categoryValue,o.emit(e,{points:l,event:r,constraints:c})}function A(t,e,r){var i=n.select(t).datum(),a=i.categoryViewModel.model,o=i.parcatsViewModel.graphDiv,s=k(i),l=[];s.each((function(t){Array.prototype.push.apply(l,v(t))}));var c={};c[a.dimensionInd]=a.categoryValue,void 0!==i.rawColor&&(c.color=i.rawColor),o.emit(e,{points:l,event:r,constraints:c})}function S(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=n.select(r.parentNode).select(\"rect.catrect\"),c=l.node().getBoundingClientRect(),u=l.datum(),f=u.parcatsViewModel,h=f.model.dimensions[u.model.dimensionInd],p=f.trace,d=c.top+c.height/2;f.dimensions.length>1&&h.displayInd===f.dimensions.length-1?(i=c.left,a=\"left\"):(i=c.left+c.width,a=\"right\");var g=u.model.count,m=u.model.categoryLabel,v=g/u.parcatsViewModel.model.count,y={countLabel:g,categoryLabel:m,probabilityLabel:v.toFixed(3)},x=[];-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&x.push([\"Count:\",y.countLabel].join(\" \")),-1!==u.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&x.push([\"P(\"+y.categoryLabel+\"):\",y.probabilityLabel].join(\" \"));var b=x.join(\"<br>\");return{trace:p,x:o*(i-e.left),y:s*(d-e.top),text:b,color:\"lightgray\",borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontSize:12,fontColor:\"black\",idealAlign:a,hovertemplate:p.hovertemplate,hovertemplateLabels:y,eventData:[{data:p._input,fullData:p,count:g,category:m,probability:v}]}}function E(t){if(!t.parcatsViewModel.dragDimension&&-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")){if(n.mouse(this)[1]<-1)return;var e,r=t.parcatsViewModel.graphDiv,i=r._fullLayout,s=i._paperdiv.node().getBoundingClientRect(),l=t.parcatsViewModel.hoveron;if(\"color\"===l?(!function(t){var e=n.select(t).datum(),r=k(e);_(r),r.each((function(){o.raiseToTop(this)})),n.select(t.parentNode).selectAll(\"rect.bandrect\").filter((function(t){return t.color===e.color})).each((function(){o.raiseToTop(this),n.select(this).attr(\"stroke\",\"black\").attr(\"stroke-width\",1.5)}))}(this),A(this,\"plotly_hover\",n.event)):(!function(t){n.select(t.parentNode).selectAll(\"rect.bandrect\").each((function(t){var e=k(t);_(e),e.each((function(){o.raiseToTop(this)}))})),n.select(t.parentNode).select(\"rect.catrect\").attr(\"stroke\",\"black\").attr(\"stroke-width\",2.5)}(this),M(this,\"plotly_hover\",n.event)),-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"none\"))\"category\"===l?e=S(r,s,this):\"color\"===l?e=function(t,e,r){t._fullLayout._calcInverseTransform(t);var i,a,o=t._fullLayout._invScaleX,s=t._fullLayout._invScaleY,l=r.getBoundingClientRect(),u=n.select(r).datum(),f=u.categoryViewModel,h=f.parcatsViewModel,p=h.model.dimensions[f.model.dimensionInd],d=h.trace,g=l.y+l.height/2;h.dimensions.length>1&&p.displayInd===h.dimensions.length-1?(i=l.left,a=\"left\"):(i=l.left+l.width,a=\"right\");var m=f.model.categoryLabel,v=u.parcatsViewModel.model.count,y=0;u.categoryViewModel.bands.forEach((function(t){t.color===u.color&&(y+=t.count)}));var x=f.model.count,b=0;h.pathSelection.each((function(t){t.model.color===u.color&&(b+=t.model.count)}));var _=y/v,w=y/b,T=y/x,k={countLabel:v,categoryLabel:m,probabilityLabel:_.toFixed(3)},M=[];-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"count\")&&M.push([\"Count:\",k.countLabel].join(\" \")),-1!==f.parcatsViewModel.hoverinfoItems.indexOf(\"probability\")&&(M.push(\"P(color \\u2229 \"+m+\"): \"+k.probabilityLabel),M.push(\"P(\"+m+\" | color): \"+w.toFixed(3)),M.push(\"P(color | \"+m+\"): \"+T.toFixed(3)));var A=M.join(\"<br>\"),S=c.mostReadable(u.color,[\"black\",\"white\"]);return{trace:d,x:o*(i-e.left),y:s*(g-e.top),text:A,color:u.color,borderColor:\"black\",fontFamily:'Monaco, \"Courier New\", monospace',fontColor:S,fontSize:10,idealAlign:a,hovertemplate:d.hovertemplate,hovertemplateLabels:k,eventData:[{data:d._input,fullData:d,category:m,count:v,probability:_,categorycount:x,colorcount:b,bandcolorcount:y}]}}(r,s,this):\"dimension\"===l&&(e=function(t,e,r){var i=[];return n.select(r.parentNode.parentNode).selectAll(\"g.category\").select(\"rect.catrect\").each((function(){i.push(S(t,e,this))})),i}(r,s,this)),e&&a.loneHover(e,{container:i._hoverlayer.node(),outerContainer:i._paper.node(),gd:r})}}function C(t){var e=t.parcatsViewModel;if(!e.dragDimension&&(b(e.pathSelection),w(e.dimensionSelection.selectAll(\"g.category\")),T(e.dimensionSelection.selectAll(\"g.category\").selectAll(\"rect.bandrect\")),a.loneUnhover(e.graphDiv._fullLayout._hoverlayer.node()),e.pathSelection.sort(d),-1===e.hoverinfoItems.indexOf(\"skip\"))){\"color\"===t.parcatsViewModel.hoveron?A(this,\"plotly_unhover\",n.event):M(this,\"plotly_unhover\",n.event)}}function L(t){\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragDimensionDisplayInd=t.model.displayInd,t.initialDragDimensionDisplayInds=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),t.dragHasMoved=!1,t.dragCategoryDisplayInd=null,n.select(this).selectAll(\"g.category\").select(\"rect.catrect\").each((function(e){var r=n.mouse(this)[0],i=n.mouse(this)[1];-2<=r&&r<=e.width+2&&-2<=i&&i<=e.height+2&&(t.dragCategoryDisplayInd=e.model.displayInd,t.initialDragCategoryDisplayInds=t.model.categories.map((function(t){return t.displayInd})),e.model.dragY=e.y,o.raiseToTop(this.parentNode),n.select(this.parentNode).selectAll(\"rect.bandrect\").each((function(e){e.y<i&&i<=e.y+e.height&&(t.potentialClickBand=this)})))})),t.parcatsViewModel.dragDimension=t,a.loneUnhover(t.parcatsViewModel.graphDiv._fullLayout._hoverlayer.node()))}function I(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&(t.dragHasMoved=!0,null!==t.dragDimensionDisplayInd)){var e=t.dragDimensionDisplayInd,r=e-1,i=e+1,a=t.parcatsViewModel.dimensions[e];if(null!==t.dragCategoryDisplayInd){var o=a.categories[t.dragCategoryDisplayInd];o.model.dragY+=n.event.dy;var s=o.model.dragY,l=o.model.displayInd,c=a.categories,u=c[l-1],f=c[l+1];void 0!==u&&s<u.y+u.height/2&&(o.model.displayInd=u.model.displayInd,u.model.displayInd=l),void 0!==f&&s+o.height>f.y+f.height/2&&(o.model.displayInd=f.model.displayInd,f.model.displayInd=l),t.dragCategoryDisplayInd=o.model.displayInd}if(null===t.dragCategoryDisplayInd||\"freeform\"===t.parcatsViewModel.arrangement){a.model.dragX=n.event.x;var h=t.parcatsViewModel.dimensions[r],p=t.parcatsViewModel.dimensions[i];void 0!==h&&a.model.dragX<h.x+h.width&&(a.model.displayInd=h.model.displayInd,h.model.displayInd=e),void 0!==p&&a.model.dragX+a.width>p.x&&(a.model.displayInd=p.model.displayInd,p.model.displayInd=t.dragDimensionDisplayInd),t.dragDimensionDisplayInd=a.model.displayInd}N(t.parcatsViewModel),B(t.parcatsViewModel),D(t.parcatsViewModel),O(t.parcatsViewModel)}}function P(t){if(\"fixed\"!==t.parcatsViewModel.arrangement&&null!==t.dragDimensionDisplayInd){n.select(this).selectAll(\"text\").attr(\"font-weight\",\"normal\");var e={},r=z(t.parcatsViewModel),a=t.parcatsViewModel.model.dimensions.map((function(t){return t.displayInd})),o=t.initialDragDimensionDisplayInds.some((function(t,e){return t!==a[e]}));o&&a.forEach((function(r,n){var i=t.parcatsViewModel.model.dimensions[n].containerInd;e[\"dimensions[\"+i+\"].displayindex\"]=r}));var s=!1;if(null!==t.dragCategoryDisplayInd){var l=t.model.categories.map((function(t){return t.displayInd}));if(s=t.initialDragCategoryDisplayInds.some((function(t,e){return t!==l[e]}))){var c=t.model.categories.slice().sort((function(t,e){return t.displayInd-e.displayInd})),u=c.map((function(t){return t.categoryValue})),f=c.map((function(t){return t.categoryLabel}));e[\"dimensions[\"+t.model.containerInd+\"].categoryarray\"]=[u],e[\"dimensions[\"+t.model.containerInd+\"].ticktext\"]=[f],e[\"dimensions[\"+t.model.containerInd+\"].categoryorder\"]=\"array\"}}if(-1===t.parcatsViewModel.hoverinfoItems.indexOf(\"skip\")&&!t.dragHasMoved&&t.potentialClickBand&&(\"color\"===t.parcatsViewModel.hoveron?A(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent):M(t.potentialClickBand,\"plotly_click\",n.event.sourceEvent)),t.model.dragX=null,null!==t.dragCategoryDisplayInd)t.parcatsViewModel.dimensions[t.dragDimensionDisplayInd].categories[t.dragCategoryDisplayInd].model.dragY=null,t.dragCategoryDisplayInd=null;t.dragDimensionDisplayInd=null,t.parcatsViewModel.dragDimension=null,t.dragHasMoved=null,t.potentialClickBand=null,N(t.parcatsViewModel),B(t.parcatsViewModel),n.transition().duration(300).ease(\"cubic-in-out\").each((function(){D(t.parcatsViewModel,!0),O(t.parcatsViewModel,!0)})).each(\"end\",(function(){(o||s)&&i.restyle(t.parcatsViewModel.graphDiv,e,[r])}))}}function z(t){for(var e,r=t.graphDiv._fullData,n=0;n<r.length;n++)if(t.key===r[n].uid){e=n;break}return e}function O(t,e){var r;void 0===e&&(e=!1),t.pathSelection.data((function(t){return t.paths}),h),(r=t.pathSelection,e?r.transition():r).attr(\"d\",(function(t){return t.svgD}))}function D(t,e){function r(t){return e?t.transition():t}void 0===e&&(e=!1),t.dimensionSelection.data((function(t){return t.dimensions}),h);var i=t.dimensionSelection.selectAll(\"g.category\").data((function(t){return t.categories}),h);r(t.dimensionSelection).attr(\"transform\",(function(t){return s(t.x,0)})),r(i).attr(\"transform\",(function(t){return s(0,t.y)})),i.select(\".dimlabel\").text((function(t,e){return 0===e?t.parcatsViewModel.model.dimensions[t.model.dimensionInd].dimensionLabel:null})),i.select(\".catlabel\").attr(\"text-anchor\",(function(t){return p(t)?\"start\":\"end\"})).attr(\"x\",(function(t){return p(t)?t.width+5:-5})).each((function(t){var e,r;p(t)?(e=t.width+5,r=\"start\"):(e=-5,r=\"end\"),n.select(this).selectAll(\"tspan\").attr(\"x\",e).attr(\"text-anchor\",r)}));var a=i.selectAll(\"rect.bandrect\").data((function(t){return t.bands}),h),l=a.enter().append(\"rect\").attr(\"class\",\"bandrect\").attr(\"cursor\",\"move\").attr(\"stroke-opacity\",0).attr(\"fill\",(function(t){return t.color})).attr(\"fill-opacity\",0);a.attr(\"fill\",(function(t){return t.color})).attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})).attr(\"y\",(function(t){return t.y})),T(l),a.each((function(){o.raiseToTop(this)})),a.exit().remove()}function R(t,e,r){var n,i=r[0],a=e.margin||{l:80,r:80,t:100,b:80},o=i.trace,s=o.domain,l=e.width,c=e.height,u=Math.floor(l*(s.x[1]-s.x[0])),f=Math.floor(c*(s.y[1]-s.y[0])),h=s.x[0]*l+a.l,p=e.height-s.y[1]*e.height+a.t,d=o.line.shape;n=\"all\"===o.hoverinfo?[\"count\",\"probability\"]:(o.hoverinfo||\"\").split(\"+\");var g={trace:o,key:o.uid,model:i,x:h,y:p,width:u,height:f,hoveron:o.hoveron,hoverinfoItems:n,arrangement:o.arrangement,bundlecolors:o.bundlecolors,sortpaths:o.sortpaths,labelfont:o.labelfont,categorylabelfont:o.tickfont,pathShape:d,dragDimension:null,margin:a,paths:[],dimensions:[],graphDiv:t,traceSelection:null,pathSelection:null,dimensionSelection:null};return i.dimensions&&(N(g),B(g)),g}function F(t,e,r,i,a){var o,s,l=[],c=[];for(s=0;s<r.length-1;s++)o=n.interpolateNumber(r[s]+t[s],t[s+1]),l.push(o(a)),c.push(o(1-a));var u=\"M \"+t[0]+\",\"+e[0];for(u+=\"l\"+r[0]+\",0 \",s=1;s<r.length;s++)u+=\"C\"+l[s-1]+\",\"+e[s-1]+\" \"+c[s-1]+\",\"+e[s]+\" \"+t[s]+\",\"+e[s],u+=\"l\"+r[s]+\",0 \";for(u+=\"l0,\"+i+\" \",u+=\"l -\"+r[r.length-1]+\",0 \",s=r.length-2;s>=0;s--)u+=\"C\"+c[s]+\",\"+(e[s+1]+i)+\" \"+l[s]+\",\"+(e[s]+i)+\" \"+(t[s]+r[s])+\",\"+(e[s]+i),u+=\"l-\"+r[s]+\",0 \";return u+=\"Z\"}function B(t){var e=t.dimensions,r=t.model,n=e.map((function(t){return t.categories.map((function(t){return t.y}))})),i=t.model.dimensions.map((function(t){return t.categories.map((function(t){return t.displayInd}))})),a=t.model.dimensions.map((function(t){return t.displayInd})),o=t.dimensions.map((function(t){return t.model.dimensionInd})),s=e.map((function(t){return t.x})),l=e.map((function(t){return t.width})),c=[];for(var u in r.paths)r.paths.hasOwnProperty(u)&&c.push(r.paths[u]);function f(t){var e=t.categoryInds.map((function(t,e){return i[e][t]}));return o.map((function(t){return e[t]}))}c.sort((function(e,r){var n=f(e),i=f(r);return\"backward\"===t.sortpaths&&(n.reverse(),i.reverse()),n.push(e.valueInds[0]),i.push(r.valueInds[0]),t.bundlecolors&&(n.unshift(e.rawColor),i.unshift(r.rawColor)),n<i?-1:n>i?1:0}));for(var h=new Array(c.length),p=e[0].model.count,d=e[0].categories.map((function(t){return t.height})).reduce((function(t,e){return t+e})),g=0;g<c.length;g++){var m,v=c[g];m=p>0?d*(v.count/p):0;for(var y,x=new Array(n.length),b=0;b<v.categoryInds.length;b++){var _=v.categoryInds[b],w=i[b][_],T=a[b];x[T]=n[T][w],n[T][w]+=m;var k=t.dimensions[T].categories[w],M=k.bands.length,A=k.bands[M-1];if(void 0===A||v.rawColor!==A.rawColor){var S=void 0===A?0:A.y+A.height;k.bands.push({key:S,color:v.color,rawColor:v.rawColor,height:m,width:k.width,count:v.count,y:S,categoryViewModel:k,parcatsViewModel:t})}else{var E=k.bands[M-1];E.height+=m,E.count+=v.count}}y=\"hspline\"===t.pathShape?F(s,x,l,m,.5):F(s,x,l,m,0),h[g]={key:v.valueInds[0],model:v,height:m,leftXs:s,topYs:x,dimWidths:l,svgD:y,parcatsViewModel:t}}t.paths=h}function N(t){var e=t.model.dimensions.map((function(t){return{displayInd:t.displayInd,dimensionInd:t.dimensionInd}}));e.sort((function(t,e){return t.displayInd-e.displayInd}));var r=[];for(var n in e){var i=e[n].dimensionInd,a=t.model.dimensions[i];r.push(j(t,a))}t.dimensions=r}function j(t,e){var r,n=t.model.dimensions.length,i=e.displayInd;r=40+(n>1?(t.width-80-16)/(n-1):0)*i;var a,o,s,l,c,u=[],f=t.model.maxCats,h=e.categories.length,p=e.count,d=t.height-8*(f-1),g=8*(f-h)/2,m=e.categories.map((function(t){return{displayInd:t.displayInd,categoryInd:t.categoryInd}}));for(m.sort((function(t,e){return t.displayInd-e.displayInd})),c=0;c<h;c++)l=m[c].categoryInd,o=e.categories[l],a=p>0?o.count/p*d:0,s={key:o.valueInds[0],model:o,width:16,height:a,y:null!==o.dragY?o.dragY:g,bands:[],parcatsViewModel:t},g=g+a+8,u.push(s);return{key:e.dimensionInd,x:null!==e.dragX?e.dragX:r,y:0,width:16,model:e,categories:u,parcatsViewModel:t,dragCategoryDisplayInd:null,dragDimensionDisplayInd:null,initialDragDimensionDisplayInds:null,initialDragCategoryDisplayInds:null,dragHasMoved:null,potentialClickBand:null}}e.exports=function(t,e,r,n){f(r,t,n,e)}},{\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plot_api/plot_api\":814,d3:169,tinycolor2:576}],1148:[function(t,e,r){\"use strict\";var n=t(\"./parcats\");e.exports=function(t,e,r,i){var a=t._fullLayout,o=a._paper,s=a._size;n(t,o,e,{width:s.w,height:s.h,margin:{t:s.t,r:s.r,b:s.b,l:s.l}},r,i)}},{\"./parcats\":1147}],1149:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/cartesian/layout_attributes\"),a=t(\"../../plots/font_attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/plot_template\").templatedArray;e.exports={domain:o({name:\"parcoords\",trace:!0,editType:\"plot\"}),labelangle:{valType:\"angle\",dflt:0,editType:\"plot\"},labelside:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},labelfont:a({editType:\"plot\"}),tickfont:a({editType:\"plot\"}),rangefont:a({editType:\"plot\"}),dimensions:l(\"dimension\",{label:{valType:\"string\",editType:\"plot\"},tickvals:s({},i.tickvals,{editType:\"plot\"}),ticktext:s({},i.ticktext,{editType:\"plot\"}),tickformat:s({},i.tickformat,{editType:\"plot\"}),visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},range:{valType:\"info_array\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},constraintrange:{valType:\"info_array\",freeLength:!0,dimensions:\"1-2\",items:[{valType:\"number\",editType:\"plot\"},{valType:\"number\",editType:\"plot\"}],editType:\"plot\"},multiselect:{valType:\"boolean\",dflt:!0,editType:\"plot\"},values:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"}),line:s({editType:\"calc\"},n(\"line\",{colorscaleDflt:\"Viridis\",autoColorDflt:!1,editTypeOverride:\"calc\"}))}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/layout_attributes\":842,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1150:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\").keyFun,o=t(\"../../lib/gup\").repeat,s=t(\"../../lib\").sorterAsc,l=t(\"../../lib\").strTranslate,c=n.bar.snapRatio;function u(t,e){return t*(1-c)+e*c}var f=n.bar.snapClose;function h(t,e){return t*(1-f)+e*f}function p(t,e,r,n){if(function(t,e){for(var r=0;r<e.length;r++)if(t>=e[r][0]&&t<=e[r][1])return!0;return!1}(r,n))return r;var i=t?-1:1,a=0,o=e.length-1;if(i<0){var s=a;a=o,o=s}for(var l=e[a],c=l,f=a;i*f<i*o;f+=i){var p=f+i,d=e[p];if(i*r<i*h(l,d))return u(l,c);if(i*r<i*d||p===o)return u(d,l);c=l,l=d}}function d(t){t.attr(\"x\",-n.bar.captureWidth/2).attr(\"width\",n.bar.captureWidth)}function g(t){t.attr(\"visibility\",\"visible\").style(\"visibility\",\"visible\").attr(\"fill\",\"yellow\").attr(\"opacity\",0)}function m(t){if(!t.brush.filterSpecified)return\"0,\"+t.height;for(var e,r,n,i=v(t.brush.filter.getConsolidated(),t.height),a=[0],o=i.length?i[0][0]:null,s=0;s<i.length;s++)r=(e=i[s])[1]-e[0],a.push(o),a.push(r),(n=s+1)<i.length&&(o=i[n][0]-e[1]);return a.push(t.height),a}function v(t,e){return t.map((function(t){return t.map((function(t){return Math.max(0,t*e)})).sort(s)}))}function y(){i.select(document.body).style(\"cursor\",null)}function x(t){t.attr(\"stroke-dasharray\",m)}function b(t,e){var r=i.select(t).selectAll(\".highlight, .highlight-shadow\");x(e?r.transition().duration(n.bar.snapDuration).each(\"end\",e):r)}function _(t,e){var r,i=t.brush,a=NaN,o={};if(i.filterSpecified){var s=t.height,l=i.filter.getConsolidated(),c=v(l,s),u=NaN,f=NaN,h=NaN;for(r=0;r<=c.length;r++){var p=c[r];if(p&&p[0]<=e&&e<=p[1]){u=r;break}if(f=r?r-1:NaN,p&&p[0]>e){h=r;break}}if(a=u,isNaN(a)&&(a=isNaN(f)||isNaN(h)?isNaN(f)?h:f:e-c[f][1]<c[h][0]-e?f:h),!isNaN(a)){var d=c[a],g=function(t,e){var r=n.bar.handleHeight;if(!(e>t[1]+r||e<t[0]-r))return e>=.9*t[1]+.1*t[0]?\"n\":e<=.9*t[0]+.1*t[1]?\"s\":\"ns\"}(d,e);g&&(o.interval=l[a],o.intervalPix=d,o.region=g)}}if(t.ordinal&&!o.region){var m=t.unitTickvals,y=t.unitToPaddedPx.invert(e);for(r=0;r<m.length;r++){var x=[.25*m[Math.max(r-1,0)]+.75*m[r],.25*m[Math.min(r+1,m.length-1)]+.75*m[r]];if(y>=x[0]&&y<=x[1]){o.clickableOrdinalRange=x;break}}}return o}function w(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.brush.svgBrush;a.wasDragged=!0,a._dragging=!0,a.grabbingBar?a.newExtent=[r-a.grabPoint,r+a.barLength-a.grabPoint].map(e.unitToPaddedPx.invert):a.newExtent=[a.startExtent,e.unitToPaddedPx.invert(r)].sort(s),e.brush.filterSpecified=!0,a.extent=a.stayingIntervals.concat([a.newExtent]),a.brushCallback(e),b(t.parentNode)}function T(t,e){var r=_(e,e.height-i.mouse(t)[1]-2*n.verticalPadding),a=\"crosshair\";r.clickableOrdinalRange?a=\"pointer\":r.region&&(a=r.region+\"-resize\"),i.select(document.body).style(\"cursor\",a)}function k(t){t.on(\"mousemove\",(function(t){i.event.preventDefault(),t.parent.inBrushDrag||T(this,t)})).on(\"mouseleave\",(function(t){t.parent.inBrushDrag||y()})).call(i.behavior.drag().on(\"dragstart\",(function(t){!function(t,e){i.event.sourceEvent.stopPropagation();var r=e.height-i.mouse(t)[1]-2*n.verticalPadding,a=e.unitToPaddedPx.invert(r),o=e.brush,s=_(e,r),l=s.interval,c=o.svgBrush;if(c.wasDragged=!1,c.grabbingBar=\"ns\"===s.region,c.grabbingBar){var u=l.map(e.unitToPaddedPx);c.grabPoint=r-u[0]-n.verticalPadding,c.barLength=u[1]-u[0]}c.clickableOrdinalRange=s.clickableOrdinalRange,c.stayingIntervals=e.multiselect&&o.filterSpecified?o.filter.getConsolidated():[],l&&(c.stayingIntervals=c.stayingIntervals.filter((function(t){return t[0]!==l[0]&&t[1]!==l[1]}))),c.startExtent=s.region?l[\"s\"===s.region?1:0]:a,e.parent.inBrushDrag=!0,c.brushStartCallback()}(this,t)})).on(\"drag\",(function(t){w(this,t)})).on(\"dragend\",(function(t){!function(t,e){var r=e.brush,n=r.filter,a=r.svgBrush;a._dragging||(T(t,e),w(t,e),e.brush.svgBrush.wasDragged=!1),a._dragging=!1,i.event.sourceEvent.stopPropagation();var o=a.grabbingBar;if(a.grabbingBar=!1,a.grabLocation=void 0,e.parent.inBrushDrag=!1,y(),!a.wasDragged)return a.wasDragged=void 0,a.clickableOrdinalRange?r.filterSpecified&&e.multiselect?a.extent.push(a.clickableOrdinalRange):(a.extent=[a.clickableOrdinalRange],r.filterSpecified=!0):o?(a.extent=a.stayingIntervals,0===a.extent.length&&A(r)):A(r),a.brushCallback(e),b(t.parentNode),void a.brushEndCallback(r.filterSpecified?n.getConsolidated():[]);var s=function(){n.set(n.getConsolidated())};if(e.ordinal){var l=e.unitTickvals;l[l.length-1]<l[0]&&l.reverse(),a.newExtent=[p(0,l,a.newExtent[0],a.stayingIntervals),p(1,l,a.newExtent[1],a.stayingIntervals)];var c=a.newExtent[1]>a.newExtent[0];a.extent=a.stayingIntervals.concat(c?[a.newExtent]:[]),a.extent.length||A(r),a.brushCallback(e),c?b(t.parentNode,s):(s(),b(t.parentNode))}else s();a.brushEndCallback(r.filterSpecified?n.getConsolidated():[])}(this,t)})))}function M(t,e){return t[0]-e[0]}function A(t){t.filterSpecified=!1,t.svgBrush.extent=[[-1/0,1/0]]}function S(t){for(var e,r=t.slice(),n=[],i=r.shift();i;){for(e=i.slice();(i=r.shift())&&i[0]<=e[1];)e[1]=Math.max(e[1],i[1]);n.push(e)}return 1===n.length&&n[0][0]>n[0][1]&&(n=[]),n}e.exports={makeBrush:function(t,e,r,n,i,a){var o,l=function(){var t,e,r=[];return{set:function(n){1===(r=n.map((function(t){return t.slice().sort(s)})).sort(M)).length&&r[0][0]===-1/0&&r[0][1]===1/0&&(r=[[0,-1]]),t=S(r),e=r.reduce((function(t,e){return[Math.min(t[0],e[0]),Math.max(t[1],e[1])]}),[1/0,-1/0])},get:function(){return r.slice()},getConsolidated:function(){return t},getBounds:function(){return e}}}();return l.set(r),{filter:l,filterSpecified:e,svgBrush:{extent:[],brushStartCallback:n,brushCallback:(o=i,function(t){var e=t.brush,r=function(t){return t.svgBrush.extent.map((function(t){return t.slice()}))}(e).slice();e.filter.set(r),o()}),brushEndCallback:a}}},ensureAxisBrush:function(t){var e=t.selectAll(\".\"+n.cn.axisBrush).data(o,a);e.enter().append(\"g\").classed(n.cn.axisBrush,!0),function(t){var e=t.selectAll(\".background\").data(o);e.enter().append(\"rect\").classed(\"background\",!0).call(d).call(g).style(\"pointer-events\",\"auto\").attr(\"transform\",l(0,n.verticalPadding)),e.call(k).attr(\"height\",(function(t){return t.height-n.verticalPadding}));var r=t.selectAll(\".highlight-shadow\").data(o);r.enter().append(\"line\").classed(\"highlight-shadow\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width+n.bar.strokeWidth).attr(\"stroke\",n.bar.strokeColor).attr(\"opacity\",n.bar.strokeOpacity).attr(\"stroke-linecap\",\"butt\"),r.attr(\"y1\",(function(t){return t.height})).call(x);var i=t.selectAll(\".highlight\").data(o);i.enter().append(\"line\").classed(\"highlight\",!0).attr(\"x\",-n.bar.width/2).attr(\"stroke-width\",n.bar.width-n.bar.strokeWidth).attr(\"stroke\",n.bar.fillColor).attr(\"opacity\",n.bar.fillOpacity).attr(\"stroke-linecap\",\"butt\"),i.attr(\"y1\",(function(t){return t.height})).call(x)}(e)},cleanRanges:function(t,e){if(Array.isArray(t[0])?(t=t.map((function(t){return t.sort(s)})),t=e.multiselect?S(t.sort(M)):[t[0]]):t=[t.sort(s)],e.tickvals){var r=e.tickvals.slice().sort(s);if(!(t=t.map((function(t){var e=[p(0,r,t[0],[]),p(1,r,t[1],[])];if(e[1]>e[0])return e})).filter((function(t){return t}))).length)return}return t.length>1?t:t[0]}}},{\"../../lib\":778,\"../../lib/gup\":775,\"./constants\":1153,d3:169}],1151:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../constants/xmlns_namespaces\");r.name=\"parcoords\",r.plot=function(t){var e=i(t.calcdata,\"parcoords\")[0];e.length&&a(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"parcoords\"),a=e._has&&e._has(\"parcoords\");i&&!a&&(n._paperdiv.selectAll(\".parcoords\").remove(),n._glimages.selectAll(\"*\").remove())},r.toSVG=function(t){var e=t._fullLayout._glimages,r=n.select(t).selectAll(\".svg-container\");r.filter((function(t,e){return e===r.size()-1})).selectAll(\".gl-canvas-context, .gl-canvas-focus\").each((function(){var t=this.toDataURL(\"image/png\");e.append(\"svg:image\").attr({xmlns:o.svg,\"xlink:href\":t,preserveAspectRatio:\"none\",x:0,y:0,width:this.width,height:this.height})})),window.setTimeout((function(){n.selectAll(\"#filterBarPattern\").attr(\"id\",\"filterBarPattern\")}),60)}},{\"../../constants/xmlns_namespaces\":754,\"../../plots/get_data\":865,\"./plot\":1160,d3:169}],1152:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale\"),a=t(\"../../lib/gup\").wrap;e.exports=function(t,e){var r,o;return i.hasColorscale(e,\"line\")&&n(e.line.color)?(r=e.line.color,o=i.extractOpts(e.line).colorscale,i.calc(t,e,{vals:r,containerStr:\"line\",cLetter:\"c\"})):(r=function(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=.5;return e}(e._length),o=[[0,e.line.color],[1,e.line.color]]),a({lineColor:r,cscale:o})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775}],1153:[function(t,e,r){\"use strict\";e.exports={maxDimensionCount:60,overdrag:45,verticalPadding:2,tickDistance:50,canvasPixelRatio:1,blockLineCount:5e3,layers:[\"contextLineLayer\",\"focusLineLayer\",\"pickLineLayer\"],axisTitleOffset:28,axisExtentOffset:10,deselectedLineColor:\"#777\",bar:{width:4,captureWidth:10,fillColor:\"magenta\",fillOpacity:1,snapDuration:150,snapRatio:.25,snapClose:.01,strokeColor:\"white\",strokeOpacity:1,strokeWidth:1,handleHeight:8,handleOpacity:1,handleOverlap:0},cn:{axisExtentText:\"axis-extent-text\",parcoordsLineLayers:\"parcoords-line-layers\",parcoordsLineLayer:\"parcoords-lines\",parcoords:\"parcoords\",parcoordsControlView:\"parcoords-control-view\",yAxis:\"y-axis\",axisOverlays:\"axis-overlays\",axis:\"axis\",axisHeading:\"axis-heading\",axisTitle:\"axis-title\",axisExtent:\"axis-extent\",axisExtentTop:\"axis-extent-top\",axisExtentTopText:\"axis-extent-top-text\",axisExtentBottom:\"axis-extent-bottom\",axisExtentBottomText:\"axis-extent-bottom-text\",axisBrush:\"axis-brush\"},id:{filterBarPattern:\"filter-bar-pattern\"}}},{}],1154:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"../../plots/domain\").defaults,s=t(\"../../plots/array_container_defaults\"),l=t(\"../../plots/cartesian/axes\"),c=t(\"./attributes\"),u=t(\"./axisbrush\"),f=t(\"./constants\").maxDimensionCount,h=t(\"./merge_length\");function p(t,e,r,i){function a(r,i){return n.coerce(t,e,c.dimensions,r,i)}var o=a(\"values\"),s=a(\"visible\");if(o&&o.length||(s=e.visible=!1),s){a(\"label\"),a(\"tickvals\"),a(\"ticktext\"),a(\"tickformat\");var f=a(\"range\");e._ax={_id:\"y\",type:\"linear\",showexponent:\"all\",exponentformat:\"B\",range:f},l.setConvert(e._ax,i.layout),a(\"multiselect\");var h=a(\"constraintrange\");h&&(e.constraintrange=u.cleanRanges(h,e))}}e.exports=function(t,e,r,l){function u(r,i){return n.coerce(t,e,c,r,i)}var d=t.dimensions;Array.isArray(d)&&d.length>f&&(n.log(\"parcoords traces support up to \"+f+\" dimensions at the moment\"),d.splice(f));var g=s(t,e,{name:\"dimensions\",layout:l,handleItemDefaults:p}),m=function(t,e,r,o,s){var l=s(\"line.color\",r);if(i(t,\"line\")&&n.isArrayOrTypedArray(l)){if(l.length)return s(\"line.colorscale\"),a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}),l.length;e.line.color=r}return 1/0}(t,e,r,l,u);o(e,l,u),Array.isArray(g)&&g.length||(e.visible=!1),h(e,g,\"values\",m);var v={family:l.font.family,size:Math.round(l.font.size/1.2),color:l.font.color};n.coerceFont(u,\"labelfont\",v),n.coerceFont(u,\"tickfont\",v),n.coerceFont(u,\"rangefont\",v),u(\"labelangle\"),u(\"labelside\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../../plots/cartesian/axes\":828,\"../../plots/domain\":855,\"./attributes\":1149,\"./axisbrush\":1150,\"./constants\":1153,\"./merge_length\":1158}],1155:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isTypedArray;r.convertTypedArray=function(t){return n(t)?Array.prototype.slice.call(t):t},r.isOrdinal=function(t){return!!t.tickvals},r.isVisible=function(t){return t.visible||!(\"visible\"in t)}},{\"../../lib\":778}],1156:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),colorbar:{container:\"line\",min:\"cmin\",max:\"cmax\"},moduleType:\"trace\",name:\"parcoords\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"noOpacity\",\"noHover\"],meta:{}}},{\"./attributes\":1149,\"./base_plot\":1151,\"./calc\":1152,\"./defaults\":1154,\"./plot\":1160}],1157:[function(t,e,r){\"use strict\";var n=t(\"glslify\"),i=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nattribute vec4 p01_04, p05_08, p09_12, p13_16,\\n               p17_20, p21_24, p25_28, p29_32,\\n               p33_36, p37_40, p41_44, p45_48,\\n               p49_52, p53_56, p57_60, colors;\\n\\nuniform mat4 dim0A, dim1A, dim0B, dim1B, dim0C, dim1C, dim0D, dim1D,\\n             loA, hiA, loB, hiB, loC, hiC, loD, hiD;\\n\\nuniform vec2 resolution, viewBoxPos, viewBoxSize;\\nuniform sampler2D mask, palette;\\nuniform float maskHeight;\\nuniform float drwLayer; // 0: context, 1: focus, 2: pick\\nuniform vec4 contextColor;\\n\\nbool isPick    = (drwLayer > 1.5);\\nbool isContext = (drwLayer < 0.5);\\n\\nconst vec4 ZEROS = vec4(0.0, 0.0, 0.0, 0.0);\\nconst vec4 UNITS = vec4(1.0, 1.0, 1.0, 1.0);\\n\\nfloat val(mat4 p, mat4 v) {\\n    return dot(matrixCompMult(p, v) * UNITS, UNITS);\\n}\\n\\nfloat axisY(float ratio, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float y1 = val(A, dim0A) + val(B, dim0B) + val(C, dim0C) + val(D, dim0D);\\n    float y2 = val(A, dim1A) + val(B, dim1B) + val(C, dim1C) + val(D, dim1D);\\n    return y1 * (1.0 - ratio) + y2 * ratio;\\n}\\n\\nint iMod(int a, int b) {\\n    return a - b * (a / b);\\n}\\n\\nbool fOutside(float p, float lo, float hi) {\\n    return (lo < hi) && (lo > p || p > hi);\\n}\\n\\nbool vOutside(vec4 p, vec4 lo, vec4 hi) {\\n    return (\\n        fOutside(p[0], lo[0], hi[0]) ||\\n        fOutside(p[1], lo[1], hi[1]) ||\\n        fOutside(p[2], lo[2], hi[2]) ||\\n        fOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool mOutside(mat4 p, mat4 lo, mat4 hi) {\\n    return (\\n        vOutside(p[0], lo[0], hi[0]) ||\\n        vOutside(p[1], lo[1], hi[1]) ||\\n        vOutside(p[2], lo[2], hi[2]) ||\\n        vOutside(p[3], lo[3], hi[3])\\n    );\\n}\\n\\nbool outsideBoundingBox(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    return mOutside(A, loA, hiA) ||\\n           mOutside(B, loB, hiB) ||\\n           mOutside(C, loC, hiC) ||\\n           mOutside(D, loD, hiD);\\n}\\n\\nbool outsideRasterMask(mat4 A, mat4 B, mat4 C, mat4 D) {\\n    mat4 pnts[4];\\n    pnts[0] = A;\\n    pnts[1] = B;\\n    pnts[2] = C;\\n    pnts[3] = D;\\n\\n    for(int i = 0; i < 4; ++i) {\\n        for(int j = 0; j < 4; ++j) {\\n            for(int k = 0; k < 4; ++k) {\\n                if(0 == iMod(\\n                    int(255.0 * texture2D(mask,\\n                        vec2(\\n                            (float(i * 2 + j / 2) + 0.5) / 8.0,\\n                            (pnts[i][j][k] * (maskHeight - 1.0) + 1.0) / maskHeight\\n                        ))[3]\\n                    ) / int(pow(2.0, float(iMod(j * 4 + k, 8)))),\\n                    2\\n                )) return true;\\n            }\\n        }\\n    }\\n    return false;\\n}\\n\\nvec4 position(bool isContext, float v, mat4 A, mat4 B, mat4 C, mat4 D) {\\n    float x = 0.5 * sign(v) + 0.5;\\n    float y = axisY(x, A, B, C, D);\\n    float z = 1.0 - abs(v);\\n\\n    z += isContext ? 0.0 : 2.0 * float(\\n        outsideBoundingBox(A, B, C, D) ||\\n        outsideRasterMask(A, B, C, D)\\n    );\\n\\n    return vec4(\\n        2.0 * (vec2(x, y) * viewBoxSize + viewBoxPos) / resolution - 1.0,\\n        z,\\n        1.0\\n    );\\n}\\n\\nvoid main() {\\n    mat4 A = mat4(p01_04, p05_08, p09_12, p13_16);\\n    mat4 B = mat4(p17_20, p21_24, p25_28, p29_32);\\n    mat4 C = mat4(p33_36, p37_40, p41_44, p45_48);\\n    mat4 D = mat4(p49_52, p53_56, p57_60, ZEROS);\\n\\n    float v = colors[3];\\n\\n    gl_Position = position(isContext, v, A, B, C, D);\\n\\n    fragColor =\\n        isContext ? vec4(contextColor) :\\n        isPick ? vec4(colors.rgb, 1.0) : texture2D(palette, vec2(abs(v), 0.5));\\n}\\n\"]),a=n([\"precision highp float;\\n#define GLSLIFY 1\\n\\nvarying vec4 fragColor;\\n\\nvoid main() {\\n    gl_FragColor = fragColor;\\n}\\n\"]),o=t(\"./constants\").maxDimensionCount,s=t(\"../../lib\"),l=new Uint8Array(4),c=new Uint8Array(4),u={shape:[256,1],format:\"rgba\",type:\"uint8\",mag:\"nearest\",min:\"nearest\"};function f(t,e,r,n,i){var a=t._gl;a.enable(a.SCISSOR_TEST),a.scissor(e,r,n,i),t.clear({color:[0,0,0,0],depth:1})}function h(t,e,r,n,i,a){var o=a.key;r.drawCompleted||(!function(t){t.read({x:0,y:0,width:1,height:1,data:l})}(t),r.drawCompleted=!0),function s(l){var c=Math.min(n,i-l*n);0===l&&(window.cancelAnimationFrame(r.currentRafs[o]),delete r.currentRafs[o],f(t,a.scissorX,a.scissorY,a.scissorWidth,a.viewBoxSize[1])),r.clearOnly||(a.count=2*c,a.offset=2*l*n,e(a),l*n+c<i&&(r.currentRafs[o]=window.requestAnimationFrame((function(){s(l+1)}))),r.drawCompleted=!1)}(0)}function p(t,e){for(var r=new Array(256),n=0;n<256;n++)r[n]=t(n/255).concat(e);return r}function d(t,e){return(t>>>8*e)%256/255}function g(t,e,r){for(var n=new Array(8*e),i=0,a=0;a<e;a++)for(var o=0;o<2;o++)for(var s=0;s<4;s++){var l=4*t+s,c=r[64*a+l];63===l&&0===o&&(c*=-1),n[i++]=c}return n}function m(t){var e=\"0\"+t;return e.substr(e.length-2)}function v(t){return t<o?\"p\"+m(t+1)+\"_\"+m(t+4):\"colors\"}function y(t,e,r,n,i,a,o,l,c,u,f,h,p){for(var d=[[],[]],g=0;g<64;g++)d[0][g]=g===i?1:0,d[1][g]=g===a?1:0;var m=t.lines.canvasOverdrag,v=t.domain,y=t.canvasWidth,x=t.canvasHeight,b=t.deselectedLines.color;return s.extendFlat({key:f,resolution:[y,x],viewBoxPos:[o+m,l],viewBoxSize:[c,u],i0:i,i1:a,dim0A:d[0].slice(0,16),dim0B:d[0].slice(16,32),dim0C:d[0].slice(32,48),dim0D:d[0].slice(48,64),dim1A:d[1].slice(0,16),dim1B:d[1].slice(16,32),dim1C:d[1].slice(32,48),dim1D:d[1].slice(48,64),drwLayer:h,contextColor:[b[0]/255,b[1]/255,b[2]/255,b[3]<1?b[3]:Math.max(1/255,Math.pow(1/t.lines.color.length,1/3))],scissorX:(n===e?0:o+m)+(t.pad.l-m)+t.layoutWidth*v.x[0],scissorWidth:(n===r?y-o+m:c+.5)+(n===e?o+m:0),scissorY:l+t.pad.b+t.layoutHeight*v.y[0],scissorHeight:u,viewportX:t.pad.l-m+t.layoutWidth*v.x[0],viewportY:t.pad.b+t.layoutHeight*v.y[0],viewportWidth:y,viewportHeight:x},p)}function x(t){var e=Math.max(0,Math.floor(2047*t[0]),0),r=Math.min(2047,Math.ceil(2047*t[1]),2047);return[Math.min(e,r),Math.max(e,r)]}e.exports=function(t,e){var r,n,l,m,b,_=e.context,w=e.pick,T=e.regl,k={currentRafs:{},drawCompleted:!0,clearOnly:!1},M=function(t){for(var e={},r=0;r<=o;r+=4)e[v(r)]=t.buffer({usage:\"dynamic\",type:\"float\",data:new Uint8Array(0)});return e}(T),A=T.texture(u),S=[];C(e);var E=T({profile:!1,blend:{enable:_,func:{srcRGB:\"src alpha\",dstRGB:\"one minus src alpha\",srcAlpha:1,dstAlpha:1},equation:{rgb:\"add\",alpha:\"add\"},color:[0,0,0,0]},depth:{enable:!_,mask:!0,func:\"less\",range:[0,1]},cull:{enable:!0,face:\"back\"},scissor:{enable:!0,box:{x:T.prop(\"scissorX\"),y:T.prop(\"scissorY\"),width:T.prop(\"scissorWidth\"),height:T.prop(\"scissorHeight\")}},viewport:{x:T.prop(\"viewportX\"),y:T.prop(\"viewportY\"),width:T.prop(\"viewportWidth\"),height:T.prop(\"viewportHeight\")},dither:!1,vert:i,frag:a,primitive:\"lines\",lineWidth:1,attributes:M,uniforms:{resolution:T.prop(\"resolution\"),viewBoxPos:T.prop(\"viewBoxPos\"),viewBoxSize:T.prop(\"viewBoxSize\"),dim0A:T.prop(\"dim0A\"),dim1A:T.prop(\"dim1A\"),dim0B:T.prop(\"dim0B\"),dim1B:T.prop(\"dim1B\"),dim0C:T.prop(\"dim0C\"),dim1C:T.prop(\"dim1C\"),dim0D:T.prop(\"dim0D\"),dim1D:T.prop(\"dim1D\"),loA:T.prop(\"loA\"),hiA:T.prop(\"hiA\"),loB:T.prop(\"loB\"),hiB:T.prop(\"hiB\"),loC:T.prop(\"loC\"),hiC:T.prop(\"hiC\"),loD:T.prop(\"loD\"),hiD:T.prop(\"hiD\"),palette:A,contextColor:T.prop(\"contextColor\"),mask:T.prop(\"maskTexture\"),drwLayer:T.prop(\"drwLayer\"),maskHeight:T.prop(\"maskHeight\")},offset:T.prop(\"offset\"),count:T.prop(\"count\")});function C(t){r=t.model,n=t.viewModel,l=n.dimensions.slice(),m=l[0]?l[0].values.length:0;var e=r.lines,i=w?e.color.map((function(t,r){return r/e.color.length})):e.color,a=function(t,e,r){for(var n,i=new Array(t*(o+4)),a=0,s=0;s<t;s++){for(var l=0;l<o;l++)i[a++]=l<e.length?e[l].paddedUnitValues[s]:.5;i[a++]=d(s,2),i[a++]=d(s,1),i[a++]=d(s,0),i[a++]=(n=r[s],Math.max(1e-6,Math.min(.999999,n)))}return i}(m,l,i);!function(t,e,r){for(var n=0;n<=o;n+=4)t[v(n)](g(n/4,e,r))}(M,m,a),_||w||(A=T.texture(s.extendFlat({data:p(r.unitToColor,255)},u)))}return{render:function(t,e,n){var i,a,o,s=t.length,c=1/0,u=-1/0;for(i=0;i<s;i++)t[i].dim0.canvasX<c&&(c=t[i].dim0.canvasX,a=i),t[i].dim1.canvasX>u&&(u=t[i].dim1.canvasX,o=i);0===s&&f(T,0,0,r.canvasWidth,r.canvasHeight);var p=function(t){var e,r,n,i=[[],[]];for(n=0;n<64;n++){var a=!t&&n<l.length?l[n].brush.filter.getBounds():[-1/0,1/0];i[0][n]=a[0],i[1][n]=a[1]}var o=new Array(16384);for(e=0;e<16384;e++)o[e]=255;if(!t)for(e=0;e<l.length;e++){var s=e%8,c=(e-s)/8,u=Math.pow(2,s),f=l[e].brush.filter.get();if(!(f.length<2)){var h=x(f[0])[1];for(r=1;r<f.length;r++){var p=x(f[r]);for(n=h+1;n<p[0];n++)o[8*n+c]&=~u;h=Math.max(h,p[1])}}}var d={shape:[8,2048],format:\"alpha\",type:\"uint8\",mag:\"nearest\",min:\"nearest\",data:o};return b?b(d):b=T.texture(d),{maskTexture:b,maskHeight:2048,loA:i[0].slice(0,16),loB:i[0].slice(16,32),loC:i[0].slice(32,48),loD:i[0].slice(48,64),hiA:i[1].slice(0,16),hiB:i[1].slice(16,32),hiC:i[1].slice(32,48),hiD:i[1].slice(48,64)}}(_);for(i=0;i<s;i++){var d=t[i],g=d.dim0.crossfilterDimensionIndex,v=d.dim1.crossfilterDimensionIndex,M=d.canvasX,A=d.canvasY,C=M+d.panelSizeX;if(e||!S[g]||S[g][0]!==M||S[g][1]!==C){S[g]=[M,C];var L=y(r,a,o,i,g,v,M,A,d.panelSizeX,d.panelSizeY,d.dim0.crossfilterDimensionIndex,_?0:w?2:1,p);k.clearOnly=n;var I=e?r.lines.blockLineCount:m;h(T,E,k,I,m,L)}}},readPixel:function(t,e){return T.read({x:t,y:e,width:1,height:1,data:c}),c},readPixels:function(t,e,r,n){var i=new Uint8Array(4*r*n);return T.read({x:t,y:e,width:r,height:n,data:i}),i},destroy:function(){for(var e in t.style[\"pointer-events\"]=\"none\",A.destroy(),b&&b.destroy(),M)M[e].destroy()},update:C}}},{\"../../lib\":778,\"./constants\":1153,glslify:439}],1158:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n){var i,a;for(n||(n=1/0),i=0;i<e.length;i++)(a=e[i]).visible&&(n=Math.min(n,a[r].length));for(n===1/0&&(n=0),t._length=n,i=0;i<e.length;i++)(a=e[i]).visible&&(a._length=n);return n}},{}],1159:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"color-rgba\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../lib\"),s=o.strRotate,l=o.strTranslate,c=t(\"../../lib/svg_text_utils\"),u=t(\"../../components/drawing\"),f=t(\"../../components/colorscale\"),h=t(\"../../lib/gup\"),p=h.keyFun,d=h.repeat,g=h.unwrap,m=t(\"./helpers\"),v=t(\"./constants\"),y=t(\"./axisbrush\"),x=t(\"./lines\");function b(t,e,r){return o.aggNums(t,null,e,r)}function _(t,e){return T(b(Math.min,t,e),b(Math.max,t,e))}function w(t){var e=t.range;return e?T(e[0],e[1]):_(t.values,t._length)}function T(t,e){return!isNaN(t)&&isFinite(t)||(t=0),!isNaN(e)&&isFinite(e)||(e=0),t===e&&(0===t?(t-=1,e+=1):(t*=.9,e*=1.1)),[t,e]}function k(t,e,r,i,a){var o,s,l=w(r);return i?n.scale.ordinal().domain(i.map((o=n.format(r.tickformat),s=a,s?function(t,e){var r=s[e];return null==r?o(t):r}:o))).range(i.map((function(r){var n=(r-l[0])/(l[1]-l[0]);return t-e+n*(2*e-t)}))):n.scale.linear().domain(l).range([t-e,e])}function M(t){if(t.tickvals){var e=w(t);return n.scale.ordinal().domain(t.tickvals).range(t.tickvals.map((function(t){return(t-e[0])/(e[1]-e[0])})))}}function A(t){var e=t.map((function(t){return t[0]})),r=t.map((function(t){var e=i(t[1]);return n.rgb(\"rgb(\"+e[0]+\",\"+e[1]+\",\"+e[2]+\")\")})),a=\"rgb\".split(\"\").map((function(t){return n.scale.linear().clamp(!0).domain(e).range(r.map((i=t,function(t){return t[i]})));var i}));return function(t){return a.map((function(e){return e(t)}))}}function S(t){return t.dimensions.some((function(t){return t.brush.filterSpecified}))}function E(t,e,r){var a=g(e),s=a.trace,l=m.convertTypedArray(a.lineColor),c=s.line,u={color:i(v.deselectedLineColor)},h=f.extractOpts(c),p=h.reversescale?f.flipScale(a.cscale):a.cscale,d=s.domain,y=s.dimensions,x=t.width,b=s.labelangle,_=s.labelside,T=s.labelfont,k=s.tickfont,M=s.rangefont,S=o.extendDeepNoArrays({},c,{color:l.map(n.scale.linear().domain(w({values:l,range:[h.min,h.max],_length:s._length}))),blockLineCount:v.blockLineCount,canvasOverdrag:v.overdrag*v.canvasPixelRatio}),E=Math.floor(x*(d.x[1]-d.x[0])),C=Math.floor(t.height*(d.y[1]-d.y[0])),L=t.margin||{l:80,r:80,t:100,b:80},I=E,P=C;return{key:r,colCount:y.filter(m.isVisible).length,dimensions:y,tickDistance:v.tickDistance,unitToColor:A(p),lines:S,deselectedLines:u,labelAngle:b,labelSide:_,labelFont:T,tickFont:k,rangeFont:M,layoutWidth:x,layoutHeight:t.height,domain:d,translateX:d.x[0]*x,translateY:t.height-d.y[1]*t.height,pad:L,canvasWidth:I*v.canvasPixelRatio+2*S.canvasOverdrag,canvasHeight:P*v.canvasPixelRatio,width:I,height:P,canvasPixelRatio:v.canvasPixelRatio}}function C(t,e,r){var i=r.width,a=r.height,s=r.dimensions,l=r.canvasPixelRatio,c=function(t){return i*t/Math.max(1,r.colCount-1)},u=v.verticalPadding/a,f=function(t,e){return n.scale.linear().range([e,t-e])}(a,v.verticalPadding),h={key:r.key,xScale:c,model:r,inBrushDrag:!1},p={};return h.dimensions=s.filter(m.isVisible).map((function(i,s){var d=function(t,e){return n.scale.linear().domain(w(t)).range([e,1-e])}(i,u),g=p[i.label];p[i.label]=(g||0)+1;var x=i.label+(g?\"__\"+g:\"\"),b=i.constraintrange,_=b&&b.length;_&&!Array.isArray(b[0])&&(b=[b]);var T=_?b.map((function(t){return t.map(d)})):[[-1/0,1/0]],A=i.values;A.length>i._length&&(A=A.slice(0,i._length));var E,C=i.tickvals;function L(t,e){return{val:t,text:E[e]}}function I(t,e){return t.val-e.val}if(Array.isArray(C)&&C.length){E=i.ticktext,Array.isArray(E)&&E.length?E.length>C.length?E=E.slice(0,C.length):C.length>E.length&&(C=C.slice(0,E.length)):E=C.map(n.format(i.tickformat));for(var P=1;P<C.length;P++)if(C[P]<C[P-1]){for(var z=C.map(L).sort(I),O=0;O<C.length;O++)C[O]=z[O].val,E[O]=z[O].text;break}}else C=void 0;return A=m.convertTypedArray(A),{key:x,label:i.label,tickFormat:i.tickformat,tickvals:C,ticktext:E,ordinal:m.isOrdinal(i),multiselect:i.multiselect,xIndex:s,crossfilterDimensionIndex:s,visibleIndex:i._index,height:a,values:A,paddedUnitValues:A.map(d),unitTickvals:C&&C.map(d),xScale:c,x:c(s),canvasX:c(s)*l,unitToPaddedPx:f,domainScale:k(a,v.verticalPadding,i,C,E),ordinalScale:M(i),parent:h,model:r,brush:y.makeBrush(t,_,T,(function(){t.linePickActive(!1)}),(function(){var e=h;e.focusLayer&&e.focusLayer.render(e.panels,!0);var r=S(e);!t.contextShown()&&r?(e.contextLayer&&e.contextLayer.render(e.panels,!0),t.contextShown(!0)):t.contextShown()&&!r&&(e.contextLayer&&e.contextLayer.render(e.panels,!0,!0),t.contextShown(!1))}),(function(r){if(h.focusLayer.render(h.panels,!0),h.pickLayer&&h.pickLayer.render(h.panels,!0),t.linePickActive(!0),e&&e.filterChanged){var n=d.invert,a=r.map((function(t){return t.map(n).sort(o.sorterAsc)})).sort((function(t,e){return t[0]-e[0]}));e.filterChanged(h.key,i._index,a)}}))}})),h}function L(t){t.classed(v.cn.axisExtentText,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"default\")}function I(t,e){var r=\"top\"===e?1:-1,n=t*Math.PI/180;return{dir:r,dx:Math.sin(n),dy:Math.cos(n),degrees:t}}function P(t,e){for(var r=e.panels||(e.panels=[]),n=t.data(),i=0;i<n.length-1;i++){var a=r[i]||(r[i]={}),o=n[i],s=n[i+1];a.dim0=o,a.dim1=s,a.canvasX=o.canvasX,a.panelSizeX=s.canvasX-o.canvasX,a.panelSizeY=e.model.canvasHeight,a.y=0,a.canvasY=0}}function z(t,e){return a.tickText(t._ax,e,!1).text}function O(t,e){if(t.ordinal)return\"\";var r=t.domainScale.domain(),n=r[e?r.length-1:0];return z(t.model.dimensions[t.visibleIndex],n)}e.exports=function(t,e,r,i){var f=t._fullLayout,h=f._toppaper,b=f._glcontainer;!function(t){for(var e=0;e<t.length;e++)for(var r=0;r<t[e].length;r++)for(var n=t[e][r].trace,i=n.dimensions,o=0;o<i.length;o++){var s=i[o].values,l=i[o]._ax;l&&(l.range?l.range=T(l.range[0],l.range[1]):l.range=_(s,n._length),l.dtick||(l.dtick=.01*(Math.abs(l.range[1]-l.range[0])||1)),l.tickformat=i[o].tickformat,a.calcTicks(l),l.cleanRange())}}(e);var w,k,M=(w=!0,k=!1,{linePickActive:function(t){return arguments.length?w=!!t:w},contextShown:function(t){return arguments.length?k=!!t:k}}),A=e.filter((function(t){return g(t).trace.visible})).map(E.bind(0,r)).map(C.bind(0,M,i));b.each((function(t,e){return o.extendFlat(t,A[e])}));var D=b.selectAll(\".gl-canvas\").each((function(t){t.viewModel=A[0],t.model=t.viewModel?t.viewModel.model:null})),R=null;D.filter((function(t){return t.pick})).style(\"pointer-events\",\"auto\").on(\"mousemove\",(function(t){if(M.linePickActive()&&t.lineLayer&&i&&i.hover){var e=n.event,r=this.width,a=this.height,o=n.mouse(this),s=o[0],l=o[1];if(s<0||l<0||s>=r||l>=a)return;var c=t.lineLayer.readPixel(s,a-1-l),u=0!==c[3],f=u?c[2]+256*(c[1]+256*c[0]):null,h={x:s,y:l,clientX:e.clientX,clientY:e.clientY,dataIndex:t.model.key,curveNumber:f};f!==R&&(u?i.hover(h):i.unhover&&i.unhover(h),R=f)}})),D.style(\"opacity\",(function(t){return t.pick?0:1})),h.style(\"background\",\"rgba(255, 255, 255, 0)\");var F=h.selectAll(\".\"+v.cn.parcoords).data(A,p);F.exit().remove(),F.enter().append(\"g\").classed(v.cn.parcoords,!0).style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"none\"),F.attr(\"transform\",(function(t){return l(t.model.translateX,t.model.translateY)}));var B=F.selectAll(\".\"+v.cn.parcoordsControlView).data(d,p);B.enter().append(\"g\").classed(v.cn.parcoordsControlView,!0),B.attr(\"transform\",(function(t){return l(t.model.pad.l,t.model.pad.t)}));var N=B.selectAll(\".\"+v.cn.yAxis).data((function(t){return t.dimensions}),p);N.enter().append(\"g\").classed(v.cn.yAxis,!0),B.each((function(t){P(N,t)})),D.each((function(t){if(t.viewModel){!t.lineLayer||i?t.lineLayer=x(this,t):t.lineLayer.update(t),(t.key||0===t.key)&&(t.viewModel[t.key]=t.lineLayer);var e=!t.context||i;t.lineLayer.render(t.viewModel.panels,e)}})),N.attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),N.call(n.behavior.drag().origin((function(t){return t})).on(\"drag\",(function(t){var e=t.parent;M.linePickActive(!1),t.x=Math.max(-v.overdrag,Math.min(t.model.width+v.overdrag,n.event.x)),t.canvasX=t.x*t.model.canvasPixelRatio,N.sort((function(t,e){return t.x-e.x})).each((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e.xIndex),e.canvasX=e.x*e.model.canvasPixelRatio})),P(N,e),N.filter((function(e){return 0!==Math.abs(t.xIndex-e.xIndex)})).attr(\"transform\",(function(t){return l(t.xScale(t.xIndex),0)})),n.select(this).attr(\"transform\",l(t.x,0)),N.each((function(r,n,i){i===t.parent.key&&(e.dimensions[n]=r)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer.render&&e.focusLayer.render(e.panels)})).on(\"dragend\",(function(t){var e=t.parent;t.x=t.xScale(t.xIndex),t.canvasX=t.x*t.model.canvasPixelRatio,P(N,e),n.select(this).attr(\"transform\",(function(t){return l(t.x,0)})),e.contextLayer&&e.contextLayer.render(e.panels,!1,!S(e)),e.focusLayer&&e.focusLayer.render(e.panels),e.pickLayer&&e.pickLayer.render(e.panels,!0),M.linePickActive(!0),i&&i.axesMoved&&i.axesMoved(e.key,e.dimensions.map((function(t){return t.crossfilterDimensionIndex})))}))),N.exit().remove();var j=N.selectAll(\".\"+v.cn.axisOverlays).data(d,p);j.enter().append(\"g\").classed(v.cn.axisOverlays,!0),j.selectAll(\".\"+v.cn.axis).remove();var U=j.selectAll(\".\"+v.cn.axis).data(d,p);U.enter().append(\"g\").classed(v.cn.axis,!0),U.each((function(t){var e=t.model.height/t.model.tickDistance,r=t.domainScale,i=r.domain();n.select(this).call(n.svg.axis().orient(\"left\").tickSize(4).outerTickSize(2).ticks(e,t.tickFormat).tickValues(t.ordinal?i:null).tickFormat((function(e){return m.isOrdinal(t)?e:z(t.model.dimensions[t.visibleIndex],e)})).scale(r)),u.font(U.selectAll(\"text\"),t.model.tickFont)})),U.selectAll(\".domain, .tick>line\").attr(\"fill\",\"none\").attr(\"stroke\",\"black\").attr(\"stroke-opacity\",.25).attr(\"stroke-width\",\"1px\"),U.selectAll(\"text\").style(\"text-shadow\",\"1px 1px 1px #fff, -1px -1px 1px #fff, 1px -1px 1px #fff, -1px 1px 1px #fff\").style(\"cursor\",\"default\");var V=j.selectAll(\".\"+v.cn.axisHeading).data(d,p);V.enter().append(\"g\").classed(v.cn.axisHeading,!0);var q=V.selectAll(\".\"+v.cn.axisTitle).data(d,p);q.enter().append(\"text\").classed(v.cn.axisTitle,!0).attr(\"text-anchor\",\"middle\").style(\"cursor\",\"ew-resize\").style(\"pointer-events\",\"auto\"),q.text((function(t){return t.label})).each((function(e){var r=n.select(this);u.font(r,e.model.labelFont),c.convertToTspans(r,t)})).attr(\"transform\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide),r=v.axisTitleOffset;return(e.dir>0?\"\":l(0,2*r+t.model.height))+s(e.degrees)+l(-r*e.dx,-r*e.dy)})).attr(\"text-anchor\",(function(t){var e=I(t.model.labelAngle,t.model.labelSide);return 2*Math.abs(e.dx)>Math.abs(e.dy)?e.dir*e.dx<0?\"start\":\"end\":\"middle\"}));var H=j.selectAll(\".\"+v.cn.axisExtent).data(d,p);H.enter().append(\"g\").classed(v.cn.axisExtent,!0);var G=H.selectAll(\".\"+v.cn.axisExtentTop).data(d,p);G.enter().append(\"g\").classed(v.cn.axisExtentTop,!0),G.attr(\"transform\",l(0,-v.axisExtentOffset));var Y=G.selectAll(\".\"+v.cn.axisExtentTopText).data(d,p);Y.enter().append(\"text\").classed(v.cn.axisExtentTopText,!0).call(L),Y.text((function(t){return O(t,!0)})).each((function(t){u.font(n.select(this),t.model.rangeFont)}));var W=H.selectAll(\".\"+v.cn.axisExtentBottom).data(d,p);W.enter().append(\"g\").classed(v.cn.axisExtentBottom,!0),W.attr(\"transform\",(function(t){return l(0,t.model.height+v.axisExtentOffset)}));var X=W.selectAll(\".\"+v.cn.axisExtentBottomText).data(d,p);X.enter().append(\"text\").classed(v.cn.axisExtentBottomText,!0).attr(\"dy\",\"0.75em\").call(L),X.text((function(t){return O(t,!1)})).each((function(t){u.font(n.select(this),t.model.rangeFont)})),y.ensureAxisBrush(j)}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"../../plots/cartesian/axes\":828,\"./axisbrush\":1150,\"./constants\":1153,\"./helpers\":1155,\"./lines\":1157,\"color-rgba\":127,d3:169}],1160:[function(t,e,r){\"use strict\";var n=t(\"./parcoords\"),i=t(\"../../lib/prepare_regl\"),a=t(\"./helpers\").isVisible;function o(t,e,r){var n=e.indexOf(r),i=t.indexOf(n);return-1===i&&(i+=e.length),i}e.exports=function(t,e){var r=t._fullLayout;if(i(t)){var s={},l={},c={},u={},f=r._size;e.forEach((function(e,r){var n=e[0].trace;c[r]=n.index;var i=u[r]=n._fullInput.index;s[r]=t.data[i].dimensions,l[r]=t.data[i].dimensions.slice()}));n(t,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{filterChanged:function(e,n,i){var a=l[e][n],o=i.map((function(t){return t.slice()})),s=\"dimensions[\"+n+\"].constraintrange\",f=r._tracePreGUI[t._fullData[c[e]]._fullInput.uid];if(void 0===f[s]){var h=a.constraintrange;f[s]=h||null}var p=t._fullData[c[e]].dimensions[n];o.length?(1===o.length&&(o=o[0]),a.constraintrange=o,p.constraintrange=o.slice(),o=[o]):(delete a.constraintrange,delete p.constraintrange,o=null);var d={};d[s]=o,t.emit(\"plotly_restyle\",[d,[u[e]]])},hover:function(e){t.emit(\"plotly_hover\",e)},unhover:function(e){t.emit(\"plotly_unhover\",e)},axesMoved:function(e,r){var n=function(t,e){return function(r,n){return o(t,e,r)-o(t,e,n)}}(r,l[e].filter(a));s[e].sort(n),l[e].filter((function(t){return!a(t)})).sort((function(t){return l[e].indexOf(t)})).forEach((function(t){s[e].splice(s[e].indexOf(t),1),s[e].splice(l[e].indexOf(t),0,t)})),t.emit(\"plotly_restyle\",[{dimensions:[s[e]]},[u[e]]])}})}}},{\"../../lib/prepare_regl\":791,\"./helpers\":1155,\"./parcoords\":1159}],1161:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/domain\").attributes,a=t(\"../../plots/font_attributes\"),o=t(\"../../components/color/attributes\"),s=t(\"../../plots/template_attributes\").hovertemplateAttrs,l=t(\"../../plots/template_attributes\").texttemplateAttrs,c=t(\"../../lib/extend\").extendFlat,u=a({editType:\"plot\",arrayOk:!0,colorEditType:\"plot\"});e.exports={labels:{valType:\"data_array\",editType:\"calc\"},label0:{valType:\"number\",dflt:0,editType:\"calc\"},dlabel:{valType:\"number\",dflt:1,editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},marker:{colors:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:o.defaultLine,arrayOk:!0,editType:\"style\"},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0,editType:\"style\"},editType:\"calc\"},editType:\"calc\"},text:{valType:\"data_array\",editType:\"plot\"},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"percent\"],extras:[\"none\"],editType:\"calc\"},hoverinfo:c({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"percent\",\"name\"]}),hovertemplate:s({},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),texttemplate:l({editType:\"plot\"},{keys:[\"label\",\"color\",\"value\",\"percent\",\"text\"]}),textposition:{valType:\"enumerated\",values:[\"inside\",\"outside\",\"auto\",\"none\"],dflt:\"auto\",arrayOk:!0,editType:\"plot\"},textfont:c({},u,{}),insidetextorientation:{valType:\"enumerated\",values:[\"horizontal\",\"radial\",\"tangential\",\"auto\"],dflt:\"auto\",editType:\"plot\"},insidetextfont:c({},u,{}),outsidetextfont:c({},u,{}),automargin:{valType:\"boolean\",dflt:!1,editType:\"plot\"},title:{text:{valType:\"string\",dflt:\"\",editType:\"plot\"},font:c({},u,{}),position:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"plot\"},editType:\"plot\"},domain:i({name:\"pie\",trace:!0,editType:\"calc\"}),hole:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},sort:{valType:\"boolean\",dflt:!0,editType:\"calc\"},direction:{valType:\"enumerated\",values:[\"clockwise\",\"counterclockwise\"],dflt:\"counterclockwise\",editType:\"calc\"},rotation:{valType:\"number\",min:-360,max:360,dflt:0,editType:\"calc\"},pull:{valType:\"number\",min:0,max:1,dflt:0,arrayOk:!0,editType:\"calc\"},_deprecated:{title:{valType:\"string\",dflt:\"\",editType:\"calc\"},titlefont:c({},u,{}),titleposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle center\",\"bottom left\",\"bottom center\",\"bottom right\"],editType:\"calc\"}}}},{\"../../components/color/attributes\":642,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1162:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"pie\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1163:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"tinycolor2\"),a=t(\"../../components/color\"),o={};function s(t){return function(e,r){return!!e&&(!!(e=i(e)).isValid()&&(e=a.addOpacity(e,e.getAlpha()),t[r]||(t[r]=e),e))}}function l(t,e){var r,n=JSON.stringify(t),a=e[n];if(!a){for(a=t.slice(),r=0;r<t.length;r++)a.push(i(t[r]).lighten(20).toHexString());for(r=0;r<t.length;r++)a.push(i(t[r]).darken(20).toHexString());e[n]=a}return a}e.exports={calc:function(t,e){var r,i,a=[],o=t._fullLayout,l=o.hiddenlabels||[],c=e.labels,u=e.marker.colors||[],f=e.values,h=e._length,p=e._hasValues&&h;if(e.dlabel)for(c=new Array(h),r=0;r<h;r++)c[r]=String(e.label0+r*e.dlabel);var d={},g=s(o[\"_\"+e.type+\"colormap\"]),m=0,v=!1;for(r=0;r<h;r++){var y,x,b;if(p){if(y=f[r],!n(y))continue;if((y=+y)<0)continue}else y=1;void 0!==(x=c[r])&&\"\"!==x||(x=r);var _=d[x=String(x)];void 0===_?(d[x]=a.length,(b=-1!==l.indexOf(x))||(m+=y),a.push({v:y,label:x,color:g(u[r],x),i:r,pts:[r],hidden:b})):(v=!0,(i=a[_]).v+=y,i.pts.push(r),i.hidden||(m+=y),!1===i.color&&u[r]&&(i.color=g(u[r],x)))}return(\"funnelarea\"===e.type?v:e.sort)&&a.sort((function(t,e){return e.v-t.v})),a[0]&&(a[0].vTotal=m),a},crossTraceCalc:function(t,e){var r=(e||{}).type;r||(r=\"pie\");var n=t._fullLayout,i=t.calcdata,a=n[r+\"colorway\"],s=n[\"_\"+r+\"colormap\"];n[\"extend\"+r+\"colors\"]&&(a=l(a,o));for(var c=0,u=0;u<i.length;u++){var f=i[u];if(f[0].trace.type===r)for(var h=0;h<f.length;h++){var p=f[h];!1===p.color&&(s[p.label]?p.color=s[p.label]:(s[p.label]=p.color=a[c%a.length],c++))}}},makePullColorFn:s,generateExtendedColors:l}},{\"../../components/color\":643,\"fast-isnumeric\":241,tinycolor2:576}],1164:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"./attributes\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText;function l(t,e){var r=Array.isArray(t),a=i.isArrayOrTypedArray(e),o=Math.min(r?t.length:1/0,a?e.length:1/0);if(isFinite(o)||(o=0),o&&a){for(var s,l=0;l<o;l++){var c=e[l];if(n(c)&&c>0){s=!0;break}}s||(o=0)}return{hasLabels:r,hasValues:a,len:o}}e.exports={handleLabelsAndValues:l,supplyDefaults:function(t,e,r,n){function c(r,n){return i.coerce(t,e,a,r,n)}var u=l(c(\"labels\"),c(\"values\")),f=u.len;if(e._hasLabels=u.hasLabels,e._hasValues=u.hasValues,!e._hasLabels&&e._hasValues&&(c(\"label0\"),c(\"dlabel\")),f){e._length=f,c(\"marker.line.width\")&&c(\"marker.line.color\"),c(\"marker.colors\"),c(\"scalegroup\");var h,p=c(\"text\"),d=c(\"texttemplate\");if(d||(h=c(\"textinfo\",Array.isArray(p)?\"text+percent\":\"percent\")),c(\"hovertext\"),c(\"hovertemplate\"),d||h&&\"none\"!==h){var g=c(\"textposition\");s(t,e,n,c,g,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),(Array.isArray(g)||\"auto\"===g||\"outside\"===g)&&c(\"automargin\"),(\"inside\"===g||\"auto\"===g||Array.isArray(g))&&c(\"insidetextorientation\")}o(e,n,c);var m=c(\"hole\");if(c(\"title.text\")){var v=c(\"title.position\",m?\"middle center\":\"top center\");m||\"middle center\"!==v||(e.title.position=\"top center\"),i.coerceFont(c,\"title.font\",n.font)}c(\"sort\"),c(\"direction\"),c(\"rotation\"),c(\"pull\")}else e.visible=!1}}},{\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1161,\"fast-isnumeric\":241}],1165:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx/helpers\").appendArrayMultiPointValues;e.exports=function(t,e){var r={curveNumber:e.index,pointNumbers:t.pts,data:e._input,fullData:e,label:t.label,color:t.color,value:t.v,percent:t.percent,text:t.text,v:t.v};return 1===t.pts.length&&(r.pointNumber=r.i=t.pts[0]),n(r,e,t.pts),\"funnelarea\"===e.type&&(delete r.v,delete r.i),r}},{\"../../components/fx/helpers\":679}],1166:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");function i(t){return-1!==t.indexOf(\"e\")?t.replace(/[.]?0+e/,\"e\"):-1!==t.indexOf(\".\")?t.replace(/[.]?0+$/,\"\"):t}r.formatPiePercent=function(t,e){var r=i((100*t).toPrecision(3));return n.numSeparate(r,e)+\"%\"},r.formatPieValue=function(t,e){var r=i(t.toPrecision(10));return n.numSeparate(r,e)},r.getFirstFilled=function(t,e){if(Array.isArray(t))for(var r=0;r<e.length;r++){var n=t[e[r]];if(n||0===n||\"\"===n)return n}},r.castOption=function(t,e){return Array.isArray(t)?r.getFirstFilled(t,e):t||void 0},r.getRotationAngle=function(t){return(\"auto\"===t?0:t)*Math.PI/180}},{\"../../lib\":778}],1167:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),layoutAttributes:t(\"./layout_attributes\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOne:t(\"./style_one\"),moduleType:\"trace\",name:\"pie\",basePlotModule:t(\"./base_plot\"),categories:[\"pie-like\",\"pie\",\"showLegend\"],meta:{}}},{\"./attributes\":1161,\"./base_plot\":1162,\"./calc\":1163,\"./defaults\":1164,\"./layout_attributes\":1168,\"./layout_defaults\":1169,\"./plot\":1170,\"./style\":1171,\"./style_one\":1172}],1168:[function(t,e,r){\"use strict\";e.exports={hiddenlabels:{valType:\"data_array\",editType:\"calc\"},piecolorway:{valType:\"colorlist\",editType:\"calc\"},extendpiecolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1169:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"hiddenlabels\"),r(\"piecolorway\",e.colorway),r(\"extendpiecolors\")}},{\"../../lib\":778,\"./layout_attributes\":1168}],1170:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../plots/plots\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"../../lib\"),c=l.strScale,u=l.strTranslate,f=t(\"../../lib/svg_text_utils\"),h=t(\"../bar/uniform_text\"),p=h.recordMinTextSize,d=h.clearMinTextSize,g=t(\"../bar/constants\").TEXTPAD,m=t(\"./helpers\"),v=t(\"./event_data\"),y=t(\"../../lib\").isValidTextValue;function x(t,e,r){var i=r[0],o=i.trace,s=i.cx,c=i.cy;\"_hasHoverLabel\"in o||(o._hasHoverLabel=!1),\"_hasHoverEvent\"in o||(o._hasHoverEvent=!1),t.on(\"mouseover\",(function(t){var r=e._fullLayout,u=e._fullData[o.index];if(!e._dragging&&!1!==r.hovermode){var f=u.hoverinfo;if(Array.isArray(f)&&(f=a.castHoverinfo({hoverinfo:[m.castOption(f,t.pts)],_module:o._module},r,0)),\"all\"===f&&(f=\"label+text+value+percent+name\"),u.hovertemplate||\"none\"!==f&&\"skip\"!==f&&f){var h=t.rInscribed||0,p=s+t.pxmid[0]*(1-h),d=c+t.pxmid[1]*(1-h),g=r.separators,y=[];if(f&&-1!==f.indexOf(\"label\")&&y.push(t.label),t.text=m.castOption(u.hovertext||u.text,t.pts),f&&-1!==f.indexOf(\"text\")){var x=t.text;l.isValidTextValue(x)&&y.push(x)}t.value=t.v,t.valueLabel=m.formatPieValue(t.v,g),f&&-1!==f.indexOf(\"value\")&&y.push(t.valueLabel),t.percent=t.v/i.vTotal,t.percentLabel=m.formatPiePercent(t.percent,g),f&&-1!==f.indexOf(\"percent\")&&y.push(t.percentLabel);var b=u.hoverlabel,_=b.font;a.loneHover({trace:o,x0:p-h*i.r,x1:p+h*i.r,y:d,text:y.join(\"<br>\"),name:u.hovertemplate||-1!==f.indexOf(\"name\")?u.name:void 0,idealAlign:t.pxmid[0]<0?\"left\":\"right\",color:m.castOption(b.bgcolor,t.pts)||t.color,borderColor:m.castOption(b.bordercolor,t.pts),fontFamily:m.castOption(_.family,t.pts),fontSize:m.castOption(_.size,t.pts),fontColor:m.castOption(_.color,t.pts),nameLength:m.castOption(b.namelength,t.pts),textAlign:m.castOption(b.align,t.pts),hovertemplate:m.castOption(u.hovertemplate,t.pts),hovertemplateLabels:t,eventData:[v(t,u)]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:e}),o._hasHoverLabel=!0}o._hasHoverEvent=!0,e.emit(\"plotly_hover\",{points:[v(t,u)],event:n.event})}})),t.on(\"mouseout\",(function(t){var r=e._fullLayout,i=e._fullData[o.index],s=n.select(this).datum();o._hasHoverEvent&&(t.originalEvent=n.event,e.emit(\"plotly_unhover\",{points:[v(s,i)],event:n.event}),o._hasHoverEvent=!1),o._hasHoverLabel&&(a.loneUnhover(r._hoverlayer.node()),o._hasHoverLabel=!1)})),t.on(\"click\",(function(t){var r=e._fullLayout,i=e._fullData[o.index];e._dragging||!1===r.hovermode||(e._hoverdata=[v(t,i)],a.click(e,n.event))}))}function b(t,e,r){var n=m.castOption(t.insidetextfont.color,e.pts);!n&&t._input.textfont&&(n=m.castOption(t._input.textfont.color,e.pts));var i=m.castOption(t.insidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.insidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n||o.contrast(e.color),family:i,size:a}}function _(t,e){for(var r,n,i=0;i<t.length;i++)if((n=(r=t[i][0]).trace).title.text){var a=n.title.text;n._meta&&(a=l.templateString(a,n._meta));var o=s.tester.append(\"text\").attr(\"data-notex\",1).text(a).call(s.font,n.title.font).call(f.convertToTspans,e),c=s.bBox(o.node(),!0);r.titleBox={width:c.width,height:c.height},o.remove()}}function w(t,e,r){var n=r.r||e.rpx1,i=e.rInscribed;if(e.startangle===e.stopangle)return{rCenter:1-i,scale:0,rotate:0,textPosAngle:0};var a,o=e.ring,s=1===o&&Math.abs(e.startangle-e.stopangle)===2*Math.PI,l=e.halfangle,c=e.midangle,u=r.trace.insidetextorientation,f=\"horizontal\"===u,h=\"tangential\"===u,p=\"radial\"===u,d=\"auto\"===u,g=[];if(!d){var m,v=function(r,i){if(function(t,e){var r=t.startangle,n=t.stopangle;return r>e&&e>n||r<e&&e<n}(e,r)){var s=Math.abs(r-e.startangle),l=Math.abs(r-e.stopangle),c=s<l?s:l;(a=\"tan\"===i?k(t,n,o,c,0):T(t,n,o,c,Math.PI/2)).textPosAngle=r,g.push(a)}};if(f||h){for(m=4;m>=-4;m-=2)v(Math.PI*m,\"tan\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+1),\"tan\")}if(f||p){for(m=4;m>=-4;m-=2)v(Math.PI*(m+1.5),\"rad\");for(m=4;m>=-4;m-=2)v(Math.PI*(m+.5),\"rad\")}}if(s||d||f){var y=Math.sqrt(t.width*t.width+t.height*t.height);if((a={scale:i*n*2/y,rCenter:1-i,rotate:0}).textPosAngle=(e.startangle+e.stopangle)/2,a.scale>=1)return a;g.push(a)}(d||p)&&((a=T(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a)),(d||h)&&((a=k(t,n,o,l,c)).textPosAngle=(e.startangle+e.stopangle)/2,g.push(a));for(var x=0,b=0,_=0;_<g.length;_++){var w=g[_].scale;if(b<w&&(b=w,x=_),!d&&b>=1)break}return g[x]}function T(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.width/t.height,o=S(a,n,e,r);return{scale:2*o/t.height,rCenter:M(a,o/e),rotate:A(i)}}function k(t,e,r,n,i){e=Math.max(0,e-2*g);var a=t.height/t.width,o=S(a,n,e,r);return{scale:2*o/t.width,rCenter:M(a,o/e),rotate:A(i+Math.PI/2)}}function M(t,e){return Math.cos(e)-t*e}function A(t){return(180/Math.PI*t+720)%180-90}function S(t,e,r,n){var i=t+1/(2*Math.tan(e));return r*Math.min(1/(Math.sqrt(i*i+.5)+i),n/(Math.sqrt(t*t+n/2)+t))}function E(t,e){return t.v!==e.vTotal||e.trace.hole?Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2):1}function C(t,e){var r=e.pxmid[0],n=e.pxmid[1],i=t.width/2,a=t.height/2;return r<0&&(i*=-1),n<0&&(a*=-1),{scale:1,rCenter:1,rotate:0,x:i+Math.abs(a)*(i>0?1:-1)/2,y:a/(1+r*r/(n*n)),outside:!0}}function L(t,e){var r,n,i,a=t.trace,o={x:t.cx,y:t.cy},s={tx:0,ty:0};s.ty+=a.title.font.size,i=P(a),-1!==a.title.position.indexOf(\"top\")?(o.y-=(1+i)*t.r,s.ty-=t.titleBox.height):-1!==a.title.position.indexOf(\"bottom\")&&(o.y+=(1+i)*t.r);var l,c,u=(l=t.r,c=t.trace.aspectratio,l/(void 0===c?1:c)),f=e.w*(a.domain.x[1]-a.domain.x[0])/2;return-1!==a.title.position.indexOf(\"left\")?(f+=u,o.x-=(1+i)*u,s.tx+=t.titleBox.width/2):-1!==a.title.position.indexOf(\"center\")?f*=2:-1!==a.title.position.indexOf(\"right\")&&(f+=u,o.x+=(1+i)*u,s.tx-=t.titleBox.width/2),r=f/t.titleBox.width,n=I(t,e)/t.titleBox.height,{x:o.x,y:o.y,scale:Math.min(r,n),tx:s.tx,ty:s.ty}}function I(t,e){var r=t.trace,n=e.h*(r.domain.y[1]-r.domain.y[0]);return Math.min(t.titleBox.height,n/2)}function P(t){var e,r=t.pull;if(!r)return 0;if(Array.isArray(r))for(r=0,e=0;e<t.pull.length;e++)t.pull[e]>r&&(r=t.pull[e]);return r}function z(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n][0],a=i.trace,o=a.domain,s=e.w*(o.x[1]-o.x[0]),l=e.h*(o.y[1]-o.y[0]);a.title.text&&\"middle center\"!==a.title.position&&(l-=I(i,e));var c=s/2,u=l/2;\"funnelarea\"!==a.type||a.scalegroup||(u/=a.aspectratio),i.r=Math.min(c,u)/(1+P(a)),i.cx=e.l+e.w*(a.domain.x[1]+a.domain.x[0])/2,i.cy=e.t+e.h*(1-a.domain.y[0])-l/2,a.title.text&&-1!==a.title.position.indexOf(\"bottom\")&&(i.cy-=I(i,e)),a.scalegroup&&-1===r.indexOf(a.scalegroup)&&r.push(a.scalegroup)}!function(t,e){for(var r,n,i,a=0;a<e.length;a++){var o=1/0,s=e[a];for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var l;if(\"pie\"===i.type)l=r.r*r.r;else if(\"funnelarea\"===i.type){var c,u;i.aspectratio>1?(c=r.r,u=c/i.aspectratio):(u=r.r,c=u*i.aspectratio),c*=(1+i.baseratio)/2,l=c*u}o=Math.min(o,l/r.vTotal)}for(n=0;n<t.length;n++)if(r=t[n][0],(i=r.trace).scalegroup===s){var f=o*r.vTotal;\"funnelarea\"===i.type&&(f/=(1+i.baseratio)/2,f/=i.aspectratio),r.r=Math.sqrt(f)}}}(t,r)}function O(t,e){return[t*Math.sin(e),-t*Math.cos(e)]}function D(t,e,r){var n=t._fullLayout,i=r.trace,a=i.texttemplate,o=i.textinfo;if(!a&&o&&\"none\"!==o){var s,c=o.split(\"+\"),u=function(t){return-1!==c.indexOf(t)},f=u(\"label\"),h=u(\"text\"),p=u(\"value\"),d=u(\"percent\"),g=n.separators;if(s=f?[e.label]:[],h){var v=m.getFirstFilled(i.text,e.pts);y(v)&&s.push(v)}p&&s.push(m.formatPieValue(e.v,g)),d&&s.push(m.formatPiePercent(e.v/r.vTotal,g)),e.text=s.join(\"<br>\")}if(a){var x=l.castOption(i,e.i,\"texttemplate\");if(x){var b=function(t){return{label:t.label,value:t.v,valueLabel:m.formatPieValue(t.v,n.separators),percent:t.v/r.vTotal,percentLabel:m.formatPiePercent(t.v/r.vTotal,n.separators),color:t.color,text:t.text,customdata:l.castOption(i,t.i,\"customdata\")}}(e),_=m.getFirstFilled(i.text,e.pts);(y(_)||\"\"===_)&&(b.text=_),e.text=l.texttemplateString(x,b,t._fullLayout._d3locale,b,i._meta||{})}else e.text=\"\"}}function R(t,e){var r=t.rotate*Math.PI/180,n=Math.cos(r),i=Math.sin(r),a=(e.left+e.right)/2,o=(e.top+e.bottom)/2;t.textX=a*n-o*i,t.textY=a*i+o*n,t.noCenter=!0}e.exports={plot:function(t,e){var r=t._fullLayout,a=r._size;d(\"pie\",r),_(e,t),z(e,a);var h=l.makeTraceGroups(r._pielayer,e,\"trace\").each((function(e){var h=n.select(this),d=e[0],g=d.trace;!function(t){var e,r,n,i=t[0],a=i.r,o=i.trace,s=m.getRotationAngle(o.rotation),l=2*Math.PI/i.vTotal,c=\"px0\",u=\"px1\";if(\"counterclockwise\"===o.direction){for(e=0;e<t.length&&t[e].hidden;e++);if(e===t.length)return;s+=l*t[e].v,l*=-1,c=\"px1\",u=\"px0\"}for(n=O(a,s),e=0;e<t.length;e++)(r=t[e]).hidden||(r[c]=n,r.startangle=s,s+=l*r.v/2,r.pxmid=O(a,s),r.midangle=s,s+=l*r.v/2,n=O(a,s),r.stopangle=s,r[u]=n,r.largeArc=r.v>i.vTotal/2?1:0,r.halfangle=Math.PI*Math.min(r.v/i.vTotal,.5),r.ring=1-o.hole,r.rInscribed=E(r,i))}(e),h.attr(\"stroke-linejoin\",\"round\"),h.each((function(){var v=n.select(this).selectAll(\"g.slice\").data(e);v.enter().append(\"g\").classed(\"slice\",!0),v.exit().remove();var y=[[[],[]],[[],[]]],_=!1;v.each((function(i,a){if(i.hidden)n.select(this).selectAll(\"path,g\").remove();else{i.pointNumber=i.i,i.curveNumber=g.index,y[i.pxmid[1]<0?0:1][i.pxmid[0]<0?0:1].push(i);var o=d.cx,c=d.cy,u=n.select(this),h=u.selectAll(\"path.surface\").data([i]);if(h.enter().append(\"path\").classed(\"surface\",!0).style({\"pointer-events\":\"all\"}),u.call(x,t,e),g.pull){var v=+m.castOption(g.pull,i.pts)||0;v>0&&(o+=v*i.pxmid[0],c+=v*i.pxmid[1])}i.cxFinal=o,i.cyFinal=c;var T=g.hole;if(i.v===d.vTotal){var k=\"M\"+(o+i.px0[0])+\",\"+(c+i.px0[1])+L(i.px0,i.pxmid,!0,1)+L(i.pxmid,i.px0,!0,1)+\"Z\";T?h.attr(\"d\",\"M\"+(o+T*i.px0[0])+\",\"+(c+T*i.px0[1])+L(i.px0,i.pxmid,!1,T)+L(i.pxmid,i.px0,!1,T)+\"Z\"+k):h.attr(\"d\",k)}else{var M=L(i.px0,i.px1,!0,1);if(T){var A=1-T;h.attr(\"d\",\"M\"+(o+T*i.px1[0])+\",\"+(c+T*i.px1[1])+L(i.px1,i.px0,!1,T)+\"l\"+A*i.px0[0]+\",\"+A*i.px0[1]+M+\"Z\")}else h.attr(\"d\",\"M\"+o+\",\"+c+\"l\"+i.px0[0]+\",\"+i.px0[1]+M+\"Z\")}D(t,i,d);var S=m.castOption(g.textposition,i.pts),E=u.selectAll(\"g.slicetext\").data(i.text&&\"none\"!==S?[0]:[]);E.enter().append(\"g\").classed(\"slicetext\",!0),E.exit().remove(),E.each((function(){var u=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),h=l.ensureUniformFontSize(t,\"outside\"===S?function(t,e,r){var n=m.castOption(t.outsidetextfont.color,e.pts)||m.castOption(t.textfont.color,e.pts)||r.color,i=m.castOption(t.outsidetextfont.family,e.pts)||m.castOption(t.textfont.family,e.pts)||r.family,a=m.castOption(t.outsidetextfont.size,e.pts)||m.castOption(t.textfont.size,e.pts)||r.size;return{color:n,family:i,size:a}}(g,i,r.font):b(g,i,r.font));u.text(i.text).attr({class:\"slicetext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,h).call(f.convertToTspans,t);var v,y=s.bBox(u.node());if(\"outside\"===S)v=C(y,i);else if(v=w(y,i,d),\"auto\"===S&&v.scale<1){var x=l.ensureUniformFontSize(t,g.outsidetextfont);u.call(s.font,x),v=C(y=s.bBox(u.node()),i)}var T=v.textPosAngle,k=void 0===T?i.pxmid:O(d.r,T);if(v.targetX=o+k[0]*v.rCenter+(v.x||0),v.targetY=c+k[1]*v.rCenter+(v.y||0),R(v,y),v.outside){var M=v.targetY;i.yLabelMin=M-y.height/2,i.yLabelMid=M,i.yLabelMax=M+y.height/2,i.labelExtraX=0,i.labelExtraY=0,_=!0}v.fontSize=h.size,p(g.type,v,r),e[a].transform=v,u.attr(\"transform\",l.getTextTransform(v))}))}function L(t,e,r,n){var a=n*(e[0]-t[0]),o=n*(e[1]-t[1]);return\"a\"+n*d.r+\",\"+n*d.r+\" 0 \"+i.largeArc+(r?\" 1 \":\" 0 \")+a+\",\"+o}}));var T=n.select(this).selectAll(\"g.titletext\").data(g.title.text?[0]:[]);if(T.enter().append(\"g\").classed(\"titletext\",!0),T.exit().remove(),T.each((function(){var e,r=l.ensureSingle(n.select(this),\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),i=g.title.text;g._meta&&(i=l.templateString(i,g._meta)),r.text(i).attr({class:\"titletext\",transform:\"\",\"text-anchor\":\"middle\"}).call(s.font,g.title.font).call(f.convertToTspans,t),e=\"middle center\"===g.title.position?function(t){var e=Math.sqrt(t.titleBox.width*t.titleBox.width+t.titleBox.height*t.titleBox.height);return{x:t.cx,y:t.cy,scale:t.trace.hole*t.r*2/e,tx:0,ty:-t.titleBox.height/2+t.trace.title.font.size}}(d):L(d,a),r.attr(\"transform\",u(e.x,e.y)+c(Math.min(1,e.scale))+u(e.tx,e.ty))})),_&&function(t,e){var r,n,i,a,o,s,l,c,u,f,h,p,d;function g(t,e){return t.pxmid[1]-e.pxmid[1]}function v(t,e){return e.pxmid[1]-t.pxmid[1]}function y(t,r){r||(r={});var i,c,u,h,p=r.labelExtraY+(n?r.yLabelMax:r.yLabelMin),d=n?t.yLabelMin:t.yLabelMax,g=n?t.yLabelMax:t.yLabelMin,v=t.cyFinal+o(t.px0[1],t.px1[1]),y=p-d;if(y*l>0&&(t.labelExtraY=y),Array.isArray(e.pull))for(c=0;c<f.length;c++)(u=f[c])===t||(m.castOption(e.pull,t.pts)||0)>=(m.castOption(e.pull,u.pts)||0)||((t.pxmid[1]-u.pxmid[1])*l>0?(y=u.cyFinal+o(u.px0[1],u.px1[1])-d-t.labelExtraY)*l>0&&(t.labelExtraY+=y):(g+t.labelExtraY-v)*l>0&&(i=3*s*Math.abs(c-f.indexOf(t)),(h=u.cxFinal+a(u.px0[0],u.px1[0])+i-(t.cxFinal+t.pxmid[0])-t.labelExtraX)*s>0&&(t.labelExtraX+=h)))}for(n=0;n<2;n++)for(i=n?g:v,o=n?Math.max:Math.min,l=n?1:-1,r=0;r<2;r++){for(a=r?Math.max:Math.min,s=r?1:-1,(c=t[n][r]).sort(i),u=t[1-n][r],f=u.concat(c),p=[],h=0;h<c.length;h++)void 0!==c[h].yLabelMid&&p.push(c[h]);for(d=!1,h=0;n&&h<u.length;h++)if(void 0!==u[h].yLabelMid){d=u[h];break}for(h=0;h<p.length;h++){var x=h&&p[h-1];d&&!h&&(x=d),y(p[h],x)}}}(y,g),function(t,e){t.each((function(t){var r=n.select(this);if(t.labelExtraX||t.labelExtraY){var i=r.select(\"g.slicetext text\");t.transform.targetX+=t.labelExtraX,t.transform.targetY+=t.labelExtraY,i.attr(\"transform\",l.getTextTransform(t.transform));var a=t.cxFinal+t.pxmid[0],s=\"M\"+a+\",\"+(t.cyFinal+t.pxmid[1]),c=(t.yLabelMax-t.yLabelMin)*(t.pxmid[0]<0?-1:1)/4;if(t.labelExtraX){var u=t.labelExtraX*t.pxmid[1]/t.pxmid[0],f=t.yLabelMid+t.labelExtraY-(t.cyFinal+t.pxmid[1]);Math.abs(u)>Math.abs(f)?s+=\"l\"+f*t.pxmid[0]/t.pxmid[1]+\",\"+f+\"H\"+(a+t.labelExtraX+c):s+=\"l\"+t.labelExtraX+\",\"+u+\"v\"+(f-u)+\"h\"+c}else s+=\"V\"+(t.yLabelMid+t.labelExtraY)+\"h\"+c;l.ensureSingle(r,\"path\",\"textline\").call(o.stroke,e.outsidetextfont.color).attr({\"stroke-width\":Math.min(2,e.outsidetextfont.size/8),d:s,fill:\"none\"})}else r.select(\"path.textline\").remove()}))}(v,g),_&&g.automargin){var k=s.bBox(h.node()),M=g.domain,A=a.w*(M.x[1]-M.x[0]),S=a.h*(M.y[1]-M.y[0]),E=(.5*A-d.r)/a.w,I=(.5*S-d.r)/a.h;i.autoMargin(t,\"pie.\"+g.uid+\".automargin\",{xl:M.x[0]-E,xr:M.x[1]+E,yb:M.y[0]-I,yt:M.y[1]+I,l:Math.max(d.cx-d.r-k.left,0),r:Math.max(k.right-(d.cx+d.r),0),b:Math.max(k.bottom-(d.cy+d.r),0),t:Math.max(d.cy-d.r-k.top,0),pad:5})}}))}));setTimeout((function(){h.selectAll(\"tspan\").each((function(){var t=n.select(this);t.attr(\"dy\")&&t.attr(\"dy\",t.attr(\"dy\"))}))}),0)},formatSliceLabel:D,transformInsideText:w,determineInsideTextFont:b,positionTitleOutside:L,prerenderTitles:_,layoutAreas:z,attachFxHandlers:x,computeTransform:R}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../components/fx\":683,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../../plots/plots\":891,\"../bar/constants\":923,\"../bar/uniform_text\":937,\"./event_data\":1165,\"./helpers\":1166,d3:169}],1171:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./style_one\"),a=t(\"../bar/uniform_text\").resizeText;e.exports=function(t){var e=t._fullLayout._pielayer.selectAll(\".trace\");a(t,e,\"pie\"),e.each((function(t){var e=t[0].trace,r=n.select(this);r.style({opacity:e.opacity}),r.selectAll(\"path.surface\").each((function(t){n.select(this).call(i,t,e)}))}))}},{\"../bar/uniform_text\":937,\"./style_one\":1172,d3:169}],1172:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./helpers\").castOption;e.exports=function(t,e,r){var a=r.marker.line,o=i(a.color,e.pts)||n.defaultLine,s=i(a.width,e.pts)||0;t.style(\"stroke-width\",s).call(n.fill,e.color).call(n.stroke,o)}},{\"../../components/color\":643,\"./helpers\":1166}],1173:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\");e.exports={x:n.x,y:n.y,xy:{valType:\"data_array\",editType:\"calc\"},indices:{valType:\"data_array\",editType:\"calc\"},xbounds:{valType:\"data_array\",editType:\"calc\"},ybounds:{valType:\"data_array\",editType:\"calc\"},text:n.text,marker:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},opacity:{valType:\"number\",min:0,max:1,dflt:1,arrayOk:!1,editType:\"calc\"},blend:{valType:\"boolean\",dflt:null,editType:\"calc\"},sizemin:{valType:\"number\",min:.1,max:2,dflt:.5,editType:\"calc\"},sizemax:{valType:\"number\",min:.1,dflt:20,editType:\"calc\"},border:{color:{valType:\"color\",arrayOk:!1,editType:\"calc\"},arearatio:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},transforms:void 0}},{\"../scatter/attributes\":1187}],1174:[function(t,e,r){\"use strict\";var n=t(\"gl-pointcloud2d\"),i=t(\"../../lib/str2rgbarray\"),a=t(\"../../plots/cartesian/autorange\").findExtremes,o=t(\"../scatter/get_trace_color\");function s(t,e){this.scene=t,this.uid=e,this.type=\"pointcloud\",this.pickXData=[],this.pickYData=[],this.xData=[],this.yData=[],this.textLabels=[],this.color=\"rgb(0, 0, 0)\",this.name=\"\",this.hoverinfo=\"all\",this.idToIndex=new Int32Array(0),this.bounds=[0,0,0,0],this.pointcloudOptions={positions:new Float32Array(0),idToIndex:this.idToIndex,sizemin:.5,sizemax:12,color:[0,0,0,1],areaRatio:1,borderColor:[0,0,0,1]},this.pointcloud=n(t.glplot,this.pointcloudOptions),this.pointcloud._trace=this}var l=s.prototype;l.handlePick=function(t){var e=this.idToIndex[t.pointId];return{trace:this,dataCoord:t.dataCoord,traceCoord:this.pickXYData?[this.pickXYData[2*e],this.pickXYData[2*e+1]]:[this.pickXData[e],this.pickYData[e]],textLabel:Array.isArray(this.textLabels)?this.textLabels[e]:this.textLabels,color:this.color,name:this.name,pointIndex:e,hoverinfo:this.hoverinfo}},l.update=function(t){this.index=t.index,this.textLabels=t.text,this.name=t.name,this.hoverinfo=t.hoverinfo,this.bounds=[1/0,1/0,-1/0,-1/0],this.updateFast(t),this.color=o(t,{})},l.updateFast=function(t){var e,r,n,o,s,l,c=this.xData=this.pickXData=t.x,u=this.yData=this.pickYData=t.y,f=this.pickXYData=t.xy,h=t.xbounds&&t.ybounds,p=t.indices,d=this.bounds;if(f){if(n=f,e=f.length>>>1,h)d[0]=t.xbounds[0],d[2]=t.xbounds[1],d[1]=t.ybounds[0],d[3]=t.ybounds[1];else for(l=0;l<e;l++)o=n[2*l],s=n[2*l+1],o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);if(p)r=p;else for(r=new Int32Array(e),l=0;l<e;l++)r[l]=l}else for(e=c.length,n=new Float32Array(2*e),r=new Int32Array(e),l=0;l<e;l++)o=c[l],s=u[l],r[l]=l,n[2*l]=o,n[2*l+1]=s,o<d[0]&&(d[0]=o),o>d[2]&&(d[2]=o),s<d[1]&&(d[1]=s),s>d[3]&&(d[3]=s);this.idToIndex=r,this.pointcloudOptions.idToIndex=r,this.pointcloudOptions.positions=n;var g=i(t.marker.color),m=i(t.marker.border.color),v=t.opacity*t.marker.opacity;g[3]*=v,this.pointcloudOptions.color=g;var y=t.marker.blend;if(null===y){y=c.length<100||u.length<100}this.pointcloudOptions.blend=y,m[3]*=v,this.pointcloudOptions.borderColor=m;var x=t.marker.sizemin,b=Math.max(t.marker.sizemax,t.marker.sizemin);this.pointcloudOptions.sizeMin=x,this.pointcloudOptions.sizeMax=b,this.pointcloudOptions.areaRatio=t.marker.border.arearatio,this.pointcloud.update(this.pointcloudOptions);var _=this.scene.xaxis,w=this.scene.yaxis,T=b/2||.5;t._extremes[_._id]=a(_,[d[0],d[2]],{ppad:T}),t._extremes[w._id]=a(w,[d[1],d[3]],{ppad:T})},l.dispose=function(){this.pointcloud.dispose()},e.exports=function(t,e){var r=new s(t,e.uid);return r.update(e),r}},{\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/autorange\":827,\"../scatter/get_trace_color\":1197,\"gl-pointcloud2d\":324}],1175:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\");e.exports=function(t,e,r){function a(r,a){return n.coerce(t,e,i,r,a)}a(\"x\"),a(\"y\"),a(\"xbounds\"),a(\"ybounds\"),t.xy&&t.xy instanceof Float32Array&&(e.xy=t.xy),t.indices&&t.indices instanceof Int32Array&&(e.indices=t.indices),a(\"text\"),a(\"marker.color\",r),a(\"marker.opacity\"),a(\"marker.blend\"),a(\"marker.sizemin\"),a(\"marker.sizemax\"),a(\"marker.border.color\",r),a(\"marker.border.arearatio\"),e._length=null}},{\"../../lib\":778,\"./attributes\":1173}],1176:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../scatter3d/calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"pointcloud\",basePlotModule:t(\"../../plots/gl2d\"),categories:[\"gl\",\"gl2d\",\"showLegend\"],meta:{}}},{\"../../plots/gl2d\":868,\"../scatter3d/calc\":1216,\"./attributes\":1173,\"./convert\":1174,\"./defaults\":1175}],1177:[function(t,e,r){\"use strict\";var n=t(\"../../plots/font_attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../components/color/attributes\"),o=t(\"../../components/fx/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../../plots/template_attributes\").hovertemplateAttrs,c=t(\"../../components/colorscale/attributes\"),u=t(\"../../plot_api/plot_template\").templatedArray,f=t(\"../../lib/extend\").extendFlat,h=t(\"../../plot_api/edit_types\").overrideAll;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=h({hoverinfo:f({},i.hoverinfo,{flags:[],arrayOk:!1}),hoverlabel:o.hoverlabel,domain:s({name:\"sankey\",trace:!0}),orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],dflt:\"h\"},valueformat:{valType:\"string\",dflt:\".3s\"},valuesuffix:{valType:\"string\",dflt:\"\"},arrangement:{valType:\"enumerated\",values:[\"snap\",\"perpendicular\",\"freeform\",\"fixed\"],dflt:\"snap\"},textfont:n({}),customdata:void 0,node:{label:{valType:\"data_array\",dflt:[]},groups:{valType:\"info_array\",impliedEdits:{x:[],y:[]},dimensions:2,freeLength:!0,dflt:[],items:{valType:\"number\",editType:\"calc\"}},x:{valType:\"data_array\",dflt:[]},y:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:.5,arrayOk:!0}},pad:{valType:\"number\",arrayOk:!1,min:0,dflt:20},thickness:{valType:\"number\",arrayOk:!1,min:1,dflt:20},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]})},link:{label:{valType:\"data_array\",dflt:[]},color:{valType:\"color\",arrayOk:!0},customdata:{valType:\"data_array\",editType:\"calc\"},line:{color:{valType:\"color\",dflt:a.defaultLine,arrayOk:!0},width:{valType:\"number\",min:0,dflt:0,arrayOk:!0}},source:{valType:\"data_array\",dflt:[]},target:{valType:\"data_array\",dflt:[]},value:{valType:\"data_array\",dflt:[]},hoverinfo:{valType:\"enumerated\",values:[\"all\",\"none\",\"skip\"],dflt:\"all\"},hoverlabel:o.hoverlabel,hovertemplate:l({},{keys:[\"value\",\"label\"]}),colorscales:u(\"concentrationscales\",{editType:\"calc\",label:{valType:\"string\",editType:\"calc\",dflt:\"\"},cmax:{valType:\"number\",editType:\"calc\",dflt:1},cmin:{valType:\"number\",editType:\"calc\",dflt:0},colorscale:f(c().colorscale,{dflt:[[0,\"white\"],[1,\"black\"]]})})}},\"calc\",\"nested\")).transforms=void 0},{\"../../components/color/attributes\":642,\"../../components/colorscale/attributes\":650,\"../../components/fx/attributes\":674,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plot_api/plot_template\":817,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906}],1178:[function(t,e,r){\"use strict\";var n=t(\"../../plot_api/edit_types\").overrideAll,i=t(\"../../plots/get_data\").getModuleCalcData,a=t(\"./plot\"),o=t(\"../../components/fx/layout_attributes\"),s=t(\"../../lib/setcursor\"),l=t(\"../../components/dragelement\"),c=t(\"../../plots/cartesian/select\").prepSelect,u=t(\"../../lib\"),f=t(\"../../registry\");function h(t,e){var r=t._fullData[e],n=t._fullLayout,i=n.dragmode,a=\"pan\"===n.dragmode?\"move\":\"crosshair\",o=r._bgRect;if(\"pan\"!==i&&\"zoom\"!==i){s(o,a);var h={_id:\"x\",c2p:u.identity,_offset:r._sankey.translateX,_length:r._sankey.width},p={_id:\"y\",c2p:u.identity,_offset:r._sankey.translateY,_length:r._sankey.height},d={gd:t,element:o.node(),plotinfo:{id:e,xaxis:h,yaxis:p,fillRangeItems:u.noop},subplot:e,xaxes:[h],yaxes:[p],doneFnCompleted:function(r){var n,i=t._fullData[e],a=i.node.groups.slice(),o=[];function s(t){for(var e=i._sankey.graph.nodes,r=0;r<e.length;r++)if(e[r].pointNumber===t)return e[r]}for(var l=0;l<r.length;l++){var c=s(r[l].pointNumber);if(c)if(c.group){for(var u=0;u<c.childrenNodes.length;u++)o.push(c.childrenNodes[u].pointNumber);a[c.pointNumber-i.node._count]=!1}else o.push(c.pointNumber)}n=a.filter(Boolean).concat([o]),f.call(\"_guiRestyle\",t,{\"node.groups\":[n]},e)},prepFn:function(t,e,r){c(t,e,r,d,i)}};l.init(d)}}r.name=\"sankey\",r.baseLayoutAttrOverrides=n({hoverlabel:o.hoverlabel},\"plot\",\"nested\"),r.plot=function(t){var e=i(t.calcdata,\"sankey\")[0];a(t,e),r.updateFx(t)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"sankey\"),a=e._has&&e._has(\"sankey\");i&&!a&&(n._paperdiv.selectAll(\".sankey\").remove(),n._paperdiv.selectAll(\".bgsankey\").remove())},r.updateFx=function(t){for(var e=0;e<t._fullData.length;e++)h(t,e)}},{\"../../components/dragelement\":662,\"../../components/fx/layout_attributes\":684,\"../../lib\":778,\"../../lib/setcursor\":799,\"../../plot_api/edit_types\":810,\"../../plots/cartesian/select\":847,\"../../plots/get_data\":865,\"../../registry\":911,\"./plot\":1183}],1179:[function(t,e,r){\"use strict\";var n=t(\"strongly-connected-components\"),i=t(\"../../lib\"),a=t(\"../../lib/gup\").wrap,o=i.isArrayOrTypedArray,s=i.isIndex,l=t(\"../../components/colorscale\");function c(t){var e,r=t.node,a=t.link,c=[],u=o(a.color),f=o(a.customdata),h={},p={},d=a.colorscales.length;for(e=0;e<d;e++){var g=a.colorscales[e],m=l.extractScale(g,{cLetter:\"c\"}),v=l.makeColorScaleFunc(m);p[g.label]=v}var y=0;for(e=0;e<a.value.length;e++)a.source[e]>y&&(y=a.source[e]),a.target[e]>y&&(y=a.target[e]);var x,b=y+1;t.node._count=b;var _=t.node.groups,w={};for(e=0;e<_.length;e++){var T=_[e];for(x=0;x<T.length;x++){var k=T[x],M=b+e;w.hasOwnProperty(k)?i.warn(\"Node \"+k+\" is already part of a group.\"):w[k]=M}}var A={source:[],target:[]};for(e=0;e<a.value.length;e++){var S=a.value[e],E=a.source[e],C=a.target[e];if(S>0&&s(E,b)&&s(C,b)&&(!w.hasOwnProperty(E)||!w.hasOwnProperty(C)||w[E]!==w[C])){w.hasOwnProperty(C)&&(C=w[C]),w.hasOwnProperty(E)&&(E=w[E]),C=+C,h[E=+E]=h[C]=!0;var L=\"\";a.label&&a.label[e]&&(L=a.label[e]);var I=null;L&&p.hasOwnProperty(L)&&(I=p[L]),c.push({pointNumber:e,label:L,color:u?a.color[e]:a.color,customdata:f?a.customdata[e]:a.customdata,concentrationscale:I,source:E,target:C,value:+S}),A.source.push(E),A.target.push(C)}}var P=b+_.length,z=o(r.color),O=o(r.customdata),D=[];for(e=0;e<P;e++)if(h[e]){var R=r.label[e];D.push({group:e>b-1,childrenNodes:[],pointNumber:e,label:R,color:z?r.color[e]:r.color,customdata:O?r.customdata[e]:r.customdata})}var F=!1;return function(t,e,r){for(var a=i.init2dArray(t,0),o=0;o<Math.min(e.length,r.length);o++)if(i.isIndex(e[o],t)&&i.isIndex(r[o],t)){if(e[o]===r[o])return!0;a[e[o]].push(r[o])}return n(a).components.some((function(t){return t.length>1}))}(P,A.source,A.target)&&(F=!0),{circular:F,links:c,nodes:D,groups:_,groupLookup:w}}e.exports=function(t,e){var r=c(e);return a({circular:r.circular,_nodes:r.nodes,_links:r.links,_groups:r.groups,_groupLookup:r.groupLookup})}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gup\":775,\"strongly-connected-components\":569}],1180:[function(t,e,r){\"use strict\";e.exports={nodeTextOffsetHorizontal:4,nodeTextOffsetVertical:3,nodePadAcross:10,sankeyIterations:50,forceIterations:5,forceTicksPerFrame:10,duration:500,ease:\"linear\",cn:{sankey:\"sankey\",sankeyLinks:\"sankey-links\",sankeyLink:\"sankey-link\",sankeyNodeSet:\"sankey-node-set\",sankeyNode:\"sankey-node\",nodeRect:\"node-rect\",nodeCapture:\"node-capture\",nodeCentered:\"node-entered\",nodeLabelGuide:\"node-label-guide\",nodeLabel:\"node-label\",nodeLabelTextPath:\"node-label-text-path\"}}},{}],1181:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"tinycolor2\"),s=t(\"../../plots/domain\").defaults,l=t(\"../../components/fx/hoverlabel_defaults\"),c=t(\"../../plot_api/plot_template\"),u=t(\"../../plots/array_container_defaults\");function f(t,e){function r(r,a){return n.coerce(t,e,i.link.colorscales,r,a)}r(\"label\"),r(\"cmin\"),r(\"cmax\"),r(\"colorscale\")}e.exports=function(t,e,r,h){function p(r,a){return n.coerce(t,e,i,r,a)}var d=n.extendDeep(h.hoverlabel,t.hoverlabel),g=t.node,m=c.newContainer(e,\"node\");function v(t,e){return n.coerce(g,m,i.node,t,e)}v(\"label\"),v(\"groups\"),v(\"x\"),v(\"y\"),v(\"pad\"),v(\"thickness\"),v(\"line.color\"),v(\"line.width\"),v(\"hoverinfo\",t.hoverinfo),l(g,m,v,d),v(\"hovertemplate\");var y=h.colorway;v(\"color\",m.label.map((function(t,e){return a.addOpacity(function(t){return y[t%y.length]}(e),.8)}))),v(\"customdata\");var x=t.link||{},b=c.newContainer(e,\"link\");function _(t,e){return n.coerce(x,b,i.link,t,e)}_(\"label\"),_(\"source\"),_(\"target\"),_(\"value\"),_(\"line.color\"),_(\"line.width\"),_(\"hoverinfo\",t.hoverinfo),l(x,b,_,d),_(\"hovertemplate\");var w,T=o(h.paper_bgcolor).getLuminance()<.333?\"rgba(255, 255, 255, 0.6)\":\"rgba(0, 0, 0, 0.2)\";_(\"color\",n.repeat(T,b.value.length)),_(\"customdata\"),u(x,b,{name:\"colorscales\",handleItemDefaults:f}),s(e,h,p),p(\"orientation\"),p(\"valueformat\"),p(\"valuesuffix\"),m.x.length&&m.y.length&&(w=\"freeform\"),p(\"arrangement\",w),n.coerceFont(p,\"textfont\",n.extendFlat({},h.font)),e._length=null}},{\"../../components/color\":643,\"../../components/fx/hoverlabel_defaults\":681,\"../../lib\":778,\"../../plot_api/plot_template\":817,\"../../plots/array_container_defaults\":823,\"../../plots/domain\":855,\"./attributes\":1177,tinycolor2:576}],1182:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"sankey\",basePlotModule:t(\"./base_plot\"),selectPoints:t(\"./select.js\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1177,\"./base_plot\":1178,\"./calc\":1179,\"./defaults\":1181,\"./plot\":1183,\"./select.js\":1185}],1183:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"./render\"),a=t(\"../../components/fx\"),o=t(\"../../components/color\"),s=t(\"../../lib\"),l=t(\"./constants\").cn,c=s._;function u(t){return\"\"!==t}function f(t,e){return t.filter((function(t){return t.key===e.traceId}))}function h(t,e){n.select(t).select(\"path\").style(\"fill-opacity\",e),n.select(t).select(\"rect\").style(\"fill-opacity\",e)}function p(t){n.select(t).select(\"text.name\").style(\"fill\",\"black\")}function d(t){return function(e){return-1!==t.node.sourceLinks.indexOf(e.link)||-1!==t.node.targetLinks.indexOf(e.link)}}function g(t){return function(e){return-1!==e.node.sourceLinks.indexOf(t.link)||-1!==e.node.targetLinks.indexOf(t.link)}}function m(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(y.bind(0,e,r,!1))}function v(t,e,r){e&&r&&f(r,e).selectAll(\".\"+l.sankeyLink).filter(d(e)).call(x.bind(0,e,r,!1))}function y(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){if(!t.link.concentrationscale)return.4})),r&&f(e,t).selectAll(\".\"+l.sankeyNode).filter(g(t)).call(m)}function x(t,e,r,n){var i=n.datum().link.label;n.style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),i&&f(e,t).selectAll(\".\"+l.sankeyLink).filter((function(t){return t.link.label===i})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),r&&f(e,t).selectAll(l.sankeyNode).filter(g(t)).call(v)}function b(t,e){var r=t.hoverlabel||{},n=s.nestedProperty(r,e).get();return!Array.isArray(n)&&n}e.exports=function(t,e){for(var r=t._fullLayout,s=r._paper,f=r._size,d=0;d<t._fullData.length;d++)if(t._fullData[d].visible&&t._fullData[d].type===l.sankey&&!t._fullData[d]._viewInitial){var g=t._fullData[d].node;t._fullData[d]._viewInitial={node:{groups:g.groups.slice(),x:g.x.slice(),y:g.y.slice()}}}var _=c(t,\"source:\")+\" \",w=c(t,\"target:\")+\" \",T=c(t,\"concentration:\")+\" \",k=c(t,\"incoming flow count:\")+\" \",M=c(t,\"outgoing flow count:\")+\" \";i(t,s,e,{width:f.w,height:f.h,margin:{t:f.t,r:f.r,b:f.b,l:f.l}},{linkEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(y.bind(0,r,i,!0)),\"skip\"!==r.link.trace.link.hoverinfo&&(r.link.fullData=r.link.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.link]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var s=i.link.trace.link;if(\"none\"!==s.hoverinfo&&\"skip\"!==s.hoverinfo){for(var l=[],c=0,f=0;f<i.flow.links.length;f++){var d=i.flow.links[f];if(\"closest\"!==t._fullLayout.hovermode||i.link.pointNumber===d.pointNumber){i.link.pointNumber===d.pointNumber&&(c=f),d.fullData=d.trace,s=i.link.trace.link;var g=v(d),m={valueLabel:n.format(i.valueFormat)(d.value)+i.valueSuffix};l.push({x:g[0],y:g[1],name:m.valueLabel,text:[d.label||\"\",_+d.source.label,w+d.target.label,d.concentrationscale?T+n.format(\"%0.2f\")(d.flow.labelConcentration):\"\"].filter(u).join(\"<br>\"),color:b(s,\"bgcolor\")||o.addOpacity(d.color,1),borderColor:b(s,\"bordercolor\"),fontFamily:b(s,\"font.family\"),fontSize:b(s,\"font.size\"),fontColor:b(s,\"font.color\"),nameLength:b(s,\"namelength\"),textAlign:b(s,\"align\"),idealAlign:n.event.x<g[0]?\"right\":\"left\",hovertemplate:s.hovertemplate,hovertemplateLabels:m,eventData:[d]})}}a.loneHover(l,{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t,anchorIndex:c}).each((function(){i.link.concentrationscale||h(this,.65),p(this)}))}}function v(t){var e,r;t.circular?(e=(t.circularPathData.leftInnerExtent+t.circularPathData.rightInnerExtent)/2,r=t.circularPathData.verticalFullExtent):(e=(t.source.x1+t.target.x0)/2,r=(t.y0+t.y1)/2);var n=[e,r];return\"v\"===t.trace.orientation&&n.reverse(),n[0]+=i.parent.translateX,n[1]+=i.parent.translateY,n}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(x.bind(0,i,o,!0)),\"skip\"!==i.link.trace.link.hoverinfo&&(i.link.fullData=i.link.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.link]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r){var i=r.link;i.originalEvent=n.event,t._hoverdata=[i],a.click(t,{target:!0})}},nodeEvents:{hover:function(e,r,i){!1!==t._fullLayout.hovermode&&(n.select(e).call(m,r,i),\"skip\"!==r.node.trace.node.hoverinfo&&(r.node.fullData=r.node.trace,t.emit(\"plotly_hover\",{event:n.event,points:[r.node]})))},follow:function(e,i){if(!1!==t._fullLayout.hovermode){var o=i.node.trace.node;if(\"none\"!==o.hoverinfo&&\"skip\"!==o.hoverinfo){var s=n.select(e).select(\".\"+l.nodeRect),c=t._fullLayout._paperdiv.node().getBoundingClientRect(),f=s.node().getBoundingClientRect(),d=f.left-2-c.left,g=f.right+2-c.left,m=f.top+f.height/4-c.top,v={valueLabel:n.format(i.valueFormat)(i.node.value)+i.valueSuffix};i.node.fullData=i.node.trace,t._fullLayout._calcInverseTransform(t);var y=t._fullLayout._invScaleX,x=t._fullLayout._invScaleY,_=a.loneHover({x0:y*d,x1:y*g,y:x*m,name:n.format(i.valueFormat)(i.node.value)+i.valueSuffix,text:[i.node.label,k+i.node.targetLinks.length,M+i.node.sourceLinks.length].filter(u).join(\"<br>\"),color:b(o,\"bgcolor\")||i.tinyColorHue,borderColor:b(o,\"bordercolor\"),fontFamily:b(o,\"font.family\"),fontSize:b(o,\"font.size\"),fontColor:b(o,\"font.color\"),nameLength:b(o,\"namelength\"),textAlign:b(o,\"align\"),idealAlign:\"left\",hovertemplate:o.hovertemplate,hovertemplateLabels:v,eventData:[i.node]},{container:r._hoverlayer.node(),outerContainer:r._paper.node(),gd:t});h(_,.85),p(_)}}},unhover:function(e,i,o){!1!==t._fullLayout.hovermode&&(n.select(e).call(v,i,o),\"skip\"!==i.node.trace.node.hoverinfo&&(i.node.fullData=i.node.trace,t.emit(\"plotly_unhover\",{event:n.event,points:[i.node]})),a.loneUnhover(r._hoverlayer.node()))},select:function(e,r,i){var o=r.node;o.originalEvent=n.event,t._hoverdata=[o],n.select(e).call(v,r,i),a.click(t,{target:!0})}}})}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"./constants\":1180,\"./render\":1184,d3:169}],1184:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"tinycolor2\"),o=t(\"../../components/color\"),s=t(\"../../components/drawing\"),l=t(\"@plotly/d3-sankey\"),c=t(\"@plotly/d3-sankey-circular\"),u=t(\"d3-force\"),f=t(\"../../lib\"),h=f.strTranslate,p=t(\"../../lib/gup\"),d=p.keyFun,g=p.repeat,m=p.unwrap,v=t(\"d3-interpolate\").interpolateNumber,y=t(\"../../registry\");function x(t,e,r){var i,o=m(e),s=o.trace,u=s.domain,h=\"h\"===s.orientation,p=s.node.pad,d=s.node.thickness,g=t.width*(u.x[1]-u.x[0]),v=t.height*(u.y[1]-u.y[0]),y=o._nodes,x=o._links,b=o.circular;(i=b?c.sankeyCircular().circularLinkGap(0):l.sankey()).iterations(n.sankeyIterations).size(h?[g,v]:[v,g]).nodeWidth(d).nodePadding(p).nodeId((function(t){return t.pointNumber})).nodes(y).links(x);var _,w,T,k=i();for(var M in i.nodePadding()<p&&f.warn(\"node.pad was reduced to \",i.nodePadding(),\" to fit within the figure.\"),o._groupLookup){var A,S=parseInt(o._groupLookup[M]);for(_=0;_<k.nodes.length;_++)if(k.nodes[_].pointNumber===S){A=k.nodes[_];break}if(A){var E={pointNumber:parseInt(M),x0:A.x0,x1:A.x1,y0:A.y0,y1:A.y1,partOfGroup:!0,sourceLinks:[],targetLinks:[]};k.nodes.unshift(E),A.childrenNodes.unshift(E)}}if(function(){for(_=0;_<k.nodes.length;_++){var t,e,r=k.nodes[_],n={};for(w=0;w<r.targetLinks.length;w++)t=(e=r.targetLinks[w]).source.pointNumber+\":\"+e.target.pointNumber,n.hasOwnProperty(t)||(n[t]=[]),n[t].push(e);var i=Object.keys(n);for(w=0;w<i.length;w++){var o=n[t=i[w]],s=0,l={};for(T=0;T<o.length;T++)l[(e=o[T]).label]||(l[e.label]=0),l[e.label]+=e.value,s+=e.value;for(T=0;T<o.length;T++)(e=o[T]).flow={value:s,labelConcentration:l[e.label]/s,concentration:e.value/s,links:o},e.concentrationscale&&(e.color=a(e.concentrationscale(e.flow.labelConcentration)))}var c=0;for(w=0;w<r.sourceLinks.length;w++)c+=r.sourceLinks[w].value;for(w=0;w<r.sourceLinks.length;w++)(e=r.sourceLinks[w]).concentrationOut=e.value/c;var u=0;for(w=0;w<r.targetLinks.length;w++)u+=r.targetLinks[w].value;for(w=0;w<r.targetLinks.length;w++)(e=r.targetLinks[w]).concenrationIn=e.value/u}}(),s.node.x.length&&s.node.y.length){for(_=0;_<Math.min(s.node.x.length,s.node.y.length,k.nodes.length);_++)if(s.node.x[_]&&s.node.y[_]){var C=[s.node.x[_]*g,s.node.y[_]*v];k.nodes[_].x0=C[0]-d/2,k.nodes[_].x1=C[0]+d/2;var L=k.nodes[_].y1-k.nodes[_].y0;k.nodes[_].y0=C[1]-L/2,k.nodes[_].y1=C[1]+L/2}if(\"snap\"===s.arrangement)!function(t){t.forEach((function(t){var e,r,n,i=0,a=t.length;for(t.sort((function(t,e){return t.y0-e.y0})),n=0;n<a;++n)(e=t[n]).y0>=i||(r=i-e.y0)>1e-6&&(e.y0+=r,e.y1+=r),i=e.y1+p}))}(function(t){var e,r,n=t.map((function(t,e){return{x0:t.x0,index:e}})).sort((function(t,e){return t.x0-e.x0})),i=[],a=-1,o=-1/0;for(_=0;_<n.length;_++){var s=t[n[_].index];s.x0>o+d&&(a+=1,e=s.x0),o=s.x0,i[a]||(i[a]=[]),i[a].push(s),r=e-s.x0,s.x0+=r,s.x1+=r}return i}(y=k.nodes));i.update(k)}return{circular:b,key:r,trace:s,guid:f.randstr(),horizontal:h,width:g,height:v,nodePad:s.node.pad,nodeLineColor:s.node.line.color,nodeLineWidth:s.node.line.width,linkLineColor:s.link.line.color,linkLineWidth:s.link.line.width,valueFormat:s.valueformat,valueSuffix:s.valuesuffix,textFont:s.textfont,translateX:u.x[0]*t.width+t.margin.l,translateY:t.height-u.y[1]*t.height+t.margin.t,dragParallel:h?v:g,dragPerpendicular:h?g:v,arrangement:s.arrangement,sankey:i,graph:k,forceLayouts:{},interactionState:{dragInProgress:!1,hovered:!1}}}function b(t,e,r){var n=a(e.color),i=e.source.label+\"|\"+e.target.label+\"__\"+r;return e.trace=t.trace,e.curveNumber=t.trace.index,{circular:t.circular,key:i,traceId:t.key,pointNumber:e.pointNumber,link:e,tinyColorHue:o.tinyRGB(n),tinyColorAlpha:n.getAlpha(),linkPath:_,linkLineColor:t.linkLineColor,linkLineWidth:t.linkLineWidth,valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,parent:t,interactionState:t.interactionState,flow:e.flow}}function _(){return function(t){if(t.link.circular)return e=t.link,r=e.width/2,n=e.circularPathData,\"top\"===e.circularLinkType?\"M \"+n.targetX+\" \"+(n.targetY+r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 1 \"+(n.rightFullExtent-r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 1 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 0 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY-n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 0 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY-n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"L\"+n.targetX+\" \"+(n.targetY-r)+\"Z\":\"M \"+n.targetX+\" \"+(n.targetY-r)+\" L\"+n.rightInnerExtent+\" \"+(n.targetY-r)+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightSmallArcRadius+r)+\" 0 0 0 \"+(n.rightFullExtent-r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"L\"+(n.rightFullExtent-r)+\" \"+n.verticalRightInnerExtent+\"A\"+(n.rightLargeArcRadius+r)+\" \"+(n.rightLargeArcRadius+r)+\" 0 0 0 \"+n.rightInnerExtent+\" \"+(n.verticalFullExtent+r)+\"L\"+n.leftInnerExtent+\" \"+(n.verticalFullExtent+r)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftLargeArcRadius+r)+\" 0 0 0 \"+(n.leftFullExtent+r)+\" \"+n.verticalLeftInnerExtent+\"L\"+(n.leftFullExtent+r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"A\"+(n.leftLargeArcRadius+r)+\" \"+(n.leftSmallArcRadius+r)+\" 0 0 0 \"+n.leftInnerExtent+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY-r)+\"L\"+n.sourceX+\" \"+(n.sourceY+r)+\"L\"+n.leftInnerExtent+\" \"+(n.sourceY+r)+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftSmallArcRadius-r)+\" 0 0 1 \"+(n.leftFullExtent-r)+\" \"+(n.sourceY+n.leftSmallArcRadius)+\"L\"+(n.leftFullExtent-r)+\" \"+n.verticalLeftInnerExtent+\"A\"+(n.leftLargeArcRadius-r)+\" \"+(n.leftLargeArcRadius-r)+\" 0 0 1 \"+n.leftInnerExtent+\" \"+(n.verticalFullExtent-r)+\"L\"+n.rightInnerExtent+\" \"+(n.verticalFullExtent-r)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightLargeArcRadius-r)+\" 0 0 1 \"+(n.rightFullExtent+r)+\" \"+n.verticalRightInnerExtent+\"L\"+(n.rightFullExtent+r)+\" \"+(n.targetY+n.rightSmallArcRadius)+\"A\"+(n.rightLargeArcRadius-r)+\" \"+(n.rightSmallArcRadius-r)+\" 0 0 1 \"+n.rightInnerExtent+\" \"+(n.targetY+r)+\"L\"+n.targetX+\" \"+(n.targetY+r)+\"Z\";var e,r,n,i=t.link.source.x1,a=t.link.target.x0,o=v(i,a),s=o(.5),l=o(.5),c=t.link.y0-t.link.width/2,u=t.link.y0+t.link.width/2,f=t.link.y1-t.link.width/2,h=t.link.y1+t.link.width/2;return\"M\"+i+\",\"+c+\"C\"+s+\",\"+c+\" \"+l+\",\"+f+\" \"+a+\",\"+f+\"L\"+a+\",\"+h+\"C\"+l+\",\"+h+\" \"+s+\",\"+u+\" \"+i+\",\"+u+\"Z\"}}function w(t,e){var r=a(e.color),i=n.nodePadAcross,s=t.nodePad/2;e.dx=e.x1-e.x0,e.dy=e.y1-e.y0;var l=e.dx,c=Math.max(.5,e.dy),u=\"node_\"+e.pointNumber;return e.group&&(u=f.randstr()),e.trace=t.trace,e.curveNumber=t.trace.index,{index:e.pointNumber,key:u,partOfGroup:e.partOfGroup||!1,group:e.group,traceId:t.key,trace:t.trace,node:e,nodePad:t.nodePad,nodeLineColor:t.nodeLineColor,nodeLineWidth:t.nodeLineWidth,textFont:t.textFont,size:t.horizontal?t.height:t.width,visibleWidth:Math.ceil(l),visibleHeight:c,zoneX:-i,zoneY:-s,zoneWidth:l+2*i,zoneHeight:c+2*s,labelY:t.horizontal?e.dy/2+1:e.dx/2+1,left:1===e.originalLayer,sizeAcross:t.width,forceLayouts:t.forceLayouts,horizontal:t.horizontal,darkBackground:r.getBrightness()<=128,tinyColorHue:o.tinyRGB(r),tinyColorAlpha:r.getAlpha(),valueFormat:t.valueFormat,valueSuffix:t.valueSuffix,sankey:t.sankey,graph:t.graph,arrangement:t.arrangement,uniqueNodeLabelPathId:[t.guid,t.key,u].join(\"_\"),interactionState:t.interactionState,figure:t}}function T(t){t.attr(\"transform\",(function(t){return h(t.node.x0.toFixed(3),t.node.y0.toFixed(3))}))}function k(t){t.call(T)}function M(t,e){t.call(k),e.attr(\"d\",_())}function A(t){t.attr(\"width\",(function(t){return t.node.x1-t.node.x0})).attr(\"height\",(function(t){return t.visibleHeight}))}function S(t){return t.link.width>1||t.linkLineWidth>0}function E(t){return h(t.translateX,t.translateY)+(t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\")}function C(t){return h(t.horizontal?0:t.labelY,t.horizontal?t.labelY:0)}function L(t){return i.svg.line()([[t.horizontal?t.left?-t.sizeAcross:t.visibleWidth+n.nodeTextOffsetHorizontal:n.nodeTextOffsetHorizontal,0],[t.horizontal?t.left?-n.nodeTextOffsetHorizontal:t.sizeAcross:t.visibleHeight-n.nodeTextOffsetHorizontal,0]])}function I(t){return t.horizontal?\"matrix(1 0 0 1 0 0)\":\"matrix(0 1 1 0 0 0)\"}function P(t){return t.horizontal?\"scale(1 1)\":\"scale(-1 1)\"}function z(t){return t.darkBackground&&!t.horizontal?\"rgb(255,255,255)\":\"rgb(0,0,0)\"}function O(t){return t.horizontal&&t.left?\"100%\":\"0%\"}function D(t,e,r){t.on(\".basic\",null).on(\"mouseover.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.hover(this,t,e),t.interactionState.hovered=[this,t])})).on(\"mousemove.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.follow(this,t),t.interactionState.hovered=[this,t])})).on(\"mouseout.basic\",(function(t){t.interactionState.dragInProgress||t.partOfGroup||(r.unhover(this,t,e),t.interactionState.hovered=!1)})).on(\"click.basic\",(function(t){t.interactionState.hovered&&(r.unhover(this,t,e),t.interactionState.hovered=!1),t.interactionState.dragInProgress||t.partOfGroup||r.select(this,t,e)}))}function R(t,e,r,a){var o=i.behavior.drag().origin((function(t){return{x:t.node.x0+t.visibleWidth/2,y:t.node.y0+t.visibleHeight/2}})).on(\"dragstart\",(function(i){if(\"fixed\"!==i.arrangement&&(f.ensureSingle(a._fullLayout._infolayer,\"g\",\"dragcover\",(function(t){a._fullLayout._dragCover=t})),f.raiseToTop(this),i.interactionState.dragInProgress=i.node,B(i.node),i.interactionState.hovered&&(r.nodeEvents.unhover.apply(0,i.interactionState.hovered),i.interactionState.hovered=!1),\"snap\"===i.arrangement)){var o=i.traceId+\"|\"+i.key;i.forceLayouts[o]?i.forceLayouts[o].alpha(1):function(t,e,r,i){!function(t){for(var e=0;e<t.length;e++)t[e].y=(t[e].y0+t[e].y1)/2,t[e].x=(t[e].x0+t[e].x1)/2}(r.graph.nodes);var a=r.graph.nodes.filter((function(t){return t.originalX===r.node.originalX})).filter((function(t){return!t.partOfGroup}));r.forceLayouts[e]=u.forceSimulation(a).alphaDecay(0).force(\"collide\",u.forceCollide().radius((function(t){return t.dy/2+r.nodePad/2})).strength(1).iterations(n.forceIterations)).force(\"constrain\",function(t,e,r,i){return function(){for(var t=0,a=0;a<r.length;a++){var o=r[a];o===i.interactionState.dragInProgress?(o.x=o.lastDraggedX,o.y=o.lastDraggedY):(o.vx=(o.originalX-o.x)/n.forceTicksPerFrame,o.y=Math.min(i.size-o.dy/2,Math.max(o.dy/2,o.y))),t=Math.max(t,Math.abs(o.vx),Math.abs(o.vy))}!i.interactionState.dragInProgress&&t<.1&&i.forceLayouts[e].alpha()>0&&i.forceLayouts[e].alpha(0)}}(0,e,a,r)).stop()}(0,o,i),function(t,e,r,i,a){window.requestAnimationFrame((function o(){var s;for(s=0;s<n.forceTicksPerFrame;s++)r.forceLayouts[i].tick();if(function(t){for(var e=0;e<t.length;e++)t[e].y0=t[e].y-t[e].dy/2,t[e].y1=t[e].y0+t[e].dy,t[e].x0=t[e].x-t[e].dx/2,t[e].x1=t[e].x0+t[e].dx}(r.graph.nodes),r.sankey.update(r.graph),M(t.filter(N(r)),e),r.forceLayouts[i].alpha()>0)window.requestAnimationFrame(o);else{var l=r.node.originalX;r.node.x0=l-r.visibleWidth/2,r.node.x1=l+r.visibleWidth/2,F(r,a)}}))}(t,e,i,o,a)}})).on(\"drag\",(function(r){if(\"fixed\"!==r.arrangement){var n=i.event.x,a=i.event.y;\"snap\"===r.arrangement?(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2,r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2):(\"freeform\"===r.arrangement&&(r.node.x0=n-r.visibleWidth/2,r.node.x1=n+r.visibleWidth/2),a=Math.max(0,Math.min(r.size-r.visibleHeight/2,a)),r.node.y0=a-r.visibleHeight/2,r.node.y1=a+r.visibleHeight/2),B(r.node),\"snap\"!==r.arrangement&&(r.sankey.update(r.graph),M(t.filter(N(r)),e))}})).on(\"dragend\",(function(t){if(\"fixed\"!==t.arrangement){t.interactionState.dragInProgress=!1;for(var e=0;e<t.node.childrenNodes.length;e++)t.node.childrenNodes[e].x=t.node.x,t.node.childrenNodes[e].y=t.node.y;\"snap\"!==t.arrangement&&F(t,a)}}));t.on(\".drag\",null).call(o)}function F(t,e){for(var r=[],n=[],i=0;i<t.graph.nodes.length;i++){var a=(t.graph.nodes[i].x0+t.graph.nodes[i].x1)/2,o=(t.graph.nodes[i].y0+t.graph.nodes[i].y1)/2;r.push(a/t.figure.width),n.push(o/t.figure.height)}y.call(\"_guiRestyle\",e,{\"node.x\":[r],\"node.y\":[n]},t.trace.index).then((function(){e._fullLayout._dragCover&&e._fullLayout._dragCover.remove()}))}function B(t){t.lastDraggedX=t.x0+t.dx/2,t.lastDraggedY=t.y0+t.dy/2}function N(t){return function(e){return e.node.originalX===t.node.originalX}}e.exports=function(t,e,r,l,c){var u=!1;f.ensureSingle(t._fullLayout._infolayer,\"g\",\"first-render\",(function(){u=!0}));var h=t._fullLayout._dragCover,p=r.filter((function(t){return m(t).trace.visible})).map(x.bind(null,l)),v=e.selectAll(\".\"+n.cn.sankey).data(p,d);v.exit().remove(),v.enter().append(\"g\").classed(n.cn.sankey,!0).style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"shape-rendering\",\"geometricPrecision\").style(\"pointer-events\",\"auto\").attr(\"transform\",E),v.each((function(e,r){t._fullData[r]._sankey=e;var n=\"bgsankey-\"+e.trace.uid+\"-\"+r;f.ensureSingle(t._fullLayout._draggers,\"rect\",n),t._fullData[r]._bgRect=i.select(\".\"+n),t._fullData[r]._bgRect.style(\"pointer-events\",\"all\").attr(\"width\",e.width).attr(\"height\",e.height).attr(\"x\",e.translateX).attr(\"y\",e.translateY).classed(\"bgsankey\",!0).style({fill:\"transparent\",\"stroke-width\":0})})),v.transition().ease(n.ease).duration(n.duration).attr(\"transform\",E);var y=v.selectAll(\".\"+n.cn.sankeyLinks).data(g,d);y.enter().append(\"g\").classed(n.cn.sankeyLinks,!0).style(\"fill\",\"none\");var k=y.selectAll(\".\"+n.cn.sankeyLink).data((function(t){return t.graph.links.filter((function(t){return t.value})).map(b.bind(null,t))}),d);k.enter().append(\"path\").classed(n.cn.sankeyLink,!0).call(D,v,c.linkEvents),k.style(\"stroke\",(function(t){return S(t)?o.tinyRGB(a(t.linkLineColor)):t.tinyColorHue})).style(\"stroke-opacity\",(function(t){return S(t)?o.opacity(t.linkLineColor):t.tinyColorAlpha})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})).style(\"stroke-width\",(function(t){return S(t)?t.linkLineWidth:1})).attr(\"d\",_()),k.style(\"opacity\",(function(){return t._context.staticPlot||u||h?1:0})).transition().ease(n.ease).duration(n.duration).style(\"opacity\",1),k.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var M=v.selectAll(\".\"+n.cn.sankeyNodeSet).data(g,d);M.enter().append(\"g\").classed(n.cn.sankeyNodeSet,!0),M.style(\"cursor\",(function(t){switch(t.arrangement){case\"fixed\":return\"default\";case\"perpendicular\":return\"ns-resize\";default:return\"move\"}}));var F=M.selectAll(\".\"+n.cn.sankeyNode).data((function(t){var e=t.graph.nodes;return function(t){var e,r=[];for(e=0;e<t.length;e++)t[e].originalX=(t[e].x0+t[e].x1)/2,t[e].originalY=(t[e].y0+t[e].y1)/2,-1===r.indexOf(t[e].originalX)&&r.push(t[e].originalX);for(r.sort((function(t,e){return t-e})),e=0;e<t.length;e++)t[e].originalLayerIndex=r.indexOf(t[e].originalX),t[e].originalLayer=t[e].originalLayerIndex/(r.length-1)}(e),e.map(w.bind(null,t))}),d);F.enter().append(\"g\").classed(n.cn.sankeyNode,!0).call(T).style(\"opacity\",(function(e){return!t._context.staticPlot&&!u||e.partOfGroup?0:1})),F.call(D,v,c.nodeEvents).call(R,k,c,t),F.transition().ease(n.ease).duration(n.duration).call(T).style(\"opacity\",(function(t){return t.partOfGroup?0:1})),F.exit().transition().ease(n.ease).duration(n.duration).style(\"opacity\",0).remove();var B=F.selectAll(\".\"+n.cn.nodeRect).data(g);B.enter().append(\"rect\").classed(n.cn.nodeRect,!0).call(A),B.style(\"stroke-width\",(function(t){return t.nodeLineWidth})).style(\"stroke\",(function(t){return o.tinyRGB(a(t.nodeLineColor))})).style(\"stroke-opacity\",(function(t){return o.opacity(t.nodeLineColor)})).style(\"fill\",(function(t){return t.tinyColorHue})).style(\"fill-opacity\",(function(t){return t.tinyColorAlpha})),B.transition().ease(n.ease).duration(n.duration).call(A);var N=F.selectAll(\".\"+n.cn.nodeCapture).data(g);N.enter().append(\"rect\").classed(n.cn.nodeCapture,!0).style(\"fill-opacity\",0),N.attr(\"x\",(function(t){return t.zoneX})).attr(\"y\",(function(t){return t.zoneY})).attr(\"width\",(function(t){return t.zoneWidth})).attr(\"height\",(function(t){return t.zoneHeight}));var j=F.selectAll(\".\"+n.cn.nodeCentered).data(g);j.enter().append(\"g\").classed(n.cn.nodeCentered,!0).attr(\"transform\",C),j.transition().ease(n.ease).duration(n.duration).attr(\"transform\",C);var U=j.selectAll(\".\"+n.cn.nodeLabelGuide).data(g);U.enter().append(\"path\").classed(n.cn.nodeLabelGuide,!0).attr(\"id\",(function(t){return t.uniqueNodeLabelPathId})).attr(\"d\",L).attr(\"transform\",I),U.transition().ease(n.ease).duration(n.duration).attr(\"d\",L).attr(\"transform\",I);var V=j.selectAll(\".\"+n.cn.nodeLabel).data(g);V.enter().append(\"text\").classed(n.cn.nodeLabel,!0).attr(\"transform\",P).style(\"cursor\",\"default\").style(\"fill\",\"black\"),V.style(\"text-shadow\",(function(t){return t.horizontal?\"-1px 1px 1px #fff, 1px 1px 1px #fff, 1px -1px 1px #fff, -1px -1px 1px #fff\":\"none\"})).each((function(t){s.font(V,t.textFont)})),V.transition().ease(n.ease).duration(n.duration).attr(\"transform\",P);var q=V.selectAll(\".\"+n.cn.nodeLabelTextPath).data(g);q.enter().append(\"textPath\").classed(n.cn.nodeLabelTextPath,!0).attr(\"alignment-baseline\",\"middle\").attr(\"xlink:href\",(function(t){return\"#\"+t.uniqueNodeLabelPathId})).attr(\"startOffset\",O).style(\"fill\",z),q.text((function(t){return t.horizontal||t.node.dy>5?t.node.label:\"\"})).attr(\"text-anchor\",(function(t){return t.horizontal&&t.left?\"end\":\"start\"})),q.transition().ease(n.ease).duration(n.duration).attr(\"startOffset\",O).style(\"fill\",z)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../registry\":911,\"./constants\":1180,\"@plotly/d3-sankey\":56,\"@plotly/d3-sankey-circular\":55,d3:169,\"d3-force\":160,\"d3-interpolate\":162,tinycolor2:576}],1185:[function(t,e,r){\"use strict\";e.exports=function(t,e){for(var r=[],n=t.cd[0].trace,i=n._sankey.graph.nodes,a=0;a<i.length;a++){var o=i[a];if(!o.partOfGroup){var s=[(o.x0+o.x1)/2,(o.y0+o.y1)/2];\"v\"===n.orientation&&s.reverse(),e&&e.contains(s,!1,a,t)&&r.push({pointNumber:o.pointNumber})}}return r}},{}],1186:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){for(var r=0;r<t.length;r++)t[r].i=r;n.mergeArray(e.text,t,\"tx\"),n.mergeArray(e.texttemplate,t,\"txt\"),n.mergeArray(e.hovertext,t,\"htx\"),n.mergeArray(e.customdata,t,\"data\"),n.mergeArray(e.textposition,t,\"tp\"),e.textfont&&(n.mergeArrayCastPositive(e.textfont.size,t,\"ts\"),n.mergeArray(e.textfont.color,t,\"tc\"),n.mergeArray(e.textfont.family,t,\"tf\"));var i=e.marker;if(i){n.mergeArrayCastPositive(i.size,t,\"ms\"),n.mergeArrayCastPositive(i.opacity,t,\"mo\"),n.mergeArray(i.symbol,t,\"mx\"),n.mergeArray(i.color,t,\"mc\");var a=i.line;i.line&&(n.mergeArray(a.color,t,\"mlc\"),n.mergeArrayCastPositive(a.width,t,\"mlw\"));var o=i.gradient;o&&\"none\"!==o.type&&(n.mergeArray(o.type,t,\"mgt\"),n.mergeArray(o.color,t,\"mgc\"))}}},{\"../../lib\":778}],1187:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").texttemplateAttrs,i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/font_attributes\"),s=t(\"../../components/drawing/attributes\").dash,l=t(\"../../components/drawing\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},x0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dx:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\",anim:!0},y0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\",anim:!0},dy:{valType:\"number\",dflt:1,editType:\"calc\",anim:!0},xperiod:{valType:\"any\",dflt:0,editType:\"calc\"},yperiod:{valType:\"any\",dflt:0,editType:\"calc\"},xperiod0:{valType:\"any\",editType:\"calc\"},yperiod0:{valType:\"any\",editType:\"calc\"},xperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},yperiodalignment:{valType:\"enumerated\",values:[\"start\",\"middle\",\"end\"],dflt:\"middle\",editType:\"calc\"},stackgroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},orientation:{valType:\"enumerated\",values:[\"v\",\"h\"],editType:\"calc\"},groupnorm:{valType:\"enumerated\",values:[\"\",\"fraction\",\"percent\"],dflt:\"\",editType:\"calc\"},stackgaps:{valType:\"enumerated\",values:[\"infer zero\",\"interpolate\"],dflt:\"infer zero\",editType:\"calc\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"calc\"},texttemplate:n({},{}),hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0,editType:\"style\"},mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"],editType:\"calc\"},hoveron:{valType:\"flaglist\",flags:[\"points\",\"fills\"],editType:\"style\"},hovertemplate:i({},{keys:c.eventDataKeys}),line:{color:{valType:\"color\",editType:\"style\",anim:!0},width:{valType:\"number\",min:0,dflt:2,editType:\"style\",anim:!0},shape:{valType:\"enumerated\",values:[\"linear\",\"spline\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},smoothing:{valType:\"number\",min:0,max:1.3,dflt:1,editType:\"plot\"},dash:u({},s,{editType:\"style\"}),simplify:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},cliponaxis:{valType:\"boolean\",dflt:!0,editType:\"plot\"},fill:{valType:\"enumerated\",values:[\"none\",\"tozeroy\",\"tozerox\",\"tonexty\",\"tonextx\",\"toself\",\"tonext\"],editType:\"calc\"},fillcolor:{valType:\"color\",editType:\"style\",anim:!0},marker:u({symbol:{valType:\"enumerated\",values:l.symbolList,dflt:\"circle\",arrayOk:!0,editType:\"style\"},opacity:{valType:\"number\",min:0,max:1,arrayOk:!0,editType:\"style\",anim:!0},size:{valType:\"number\",min:0,dflt:6,arrayOk:!0,editType:\"calc\",anim:!0},maxdisplayed:{valType:\"number\",min:0,dflt:0,editType:\"plot\"},sizeref:{valType:\"number\",dflt:1,editType:\"calc\"},sizemin:{valType:\"number\",min:0,dflt:0,editType:\"calc\"},sizemode:{valType:\"enumerated\",values:[\"diameter\",\"area\"],dflt:\"diameter\",editType:\"calc\"},line:u({width:{valType:\"number\",min:0,arrayOk:!0,editType:\"style\",anim:!0},editType:\"calc\"},a(\"marker.line\",{anim:!0})),gradient:{type:{valType:\"enumerated\",values:[\"radial\",\"horizontal\",\"vertical\",\"none\"],arrayOk:!0,dflt:\"none\",editType:\"calc\"},color:{valType:\"color\",arrayOk:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},a(\"marker\",{anim:!0})),selected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},unselected:{marker:{opacity:{valType:\"number\",min:0,max:1,editType:\"style\"},color:{valType:\"color\",editType:\"style\"},size:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},textfont:{color:{valType:\"color\",editType:\"style\"},editType:\"style\"},editType:\"style\"},textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"middle center\",arrayOk:!0,editType:\"calc\"},textfont:o({editType:\"calc\",colorEditType:\"style\",arrayOk:!0}),r:{valType:\"data_array\",editType:\"calc\"},t:{valType:\"data_array\",editType:\"calc\"}}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing\":665,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/font_attributes\":856,\"../../plots/template_attributes\":906,\"./constants\":1191}],1188:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axes\"),o=t(\"../../plots/cartesian/align_period\"),s=t(\"../../constants/numerical\").BADNUM,l=t(\"./subtypes\"),c=t(\"./colorscale_calc\"),u=t(\"./arrays_to_calcdata\"),f=t(\"./calc_selection\");function h(t,e,r,n,i,o,s){var c=e._length,u=t._fullLayout,f=r._id,h=n._id,p=u._firstScatter[g(e)]===e.uid,d=(m(e,u,r,n)||{}).orientation,v=e.fill;r._minDtick=0,n._minDtick=0;var y={padded:!0},x={padded:!0};s&&(y.ppad=x.ppad=s);var b=c<2||i[0]!==i[c-1]||o[0]!==o[c-1];b&&(\"tozerox\"===v||\"tonextx\"===v&&(p||\"h\"===d))?y.tozero=!0:(e.error_y||{}).visible||\"tonexty\"!==v&&\"tozeroy\"!==v&&(l.hasMarkers(e)||l.hasText(e))||(y.padded=!1,y.ppad=0),b&&(\"tozeroy\"===v||\"tonexty\"===v&&(p||\"v\"===d))?x.tozero=!0:\"tonextx\"!==v&&\"tozerox\"!==v||(x.padded=!1),f&&(e._extremes[f]=a.findExtremes(r,i,y)),h&&(e._extremes[h]=a.findExtremes(n,o,x))}function p(t,e){if(l.hasMarkers(t)){var r,n=t.marker,o=1.6*(t.marker.sizeref||1);if(r=\"area\"===t.marker.sizemode?function(t){return Math.max(Math.sqrt((t||0)/o),3)}:function(t){return Math.max((t||0)/o,3)},i.isArrayOrTypedArray(n.size)){var s={type:\"linear\"};a.setConvert(s);for(var c=s.makeCalcdata(t.marker,\"size\"),u=new Array(e),f=0;f<e;f++)u[f]=r(c[f]);return u}return r(n.size)}}function d(t,e){var r=g(e),n=t._firstScatter;n[r]||(n[r]=e.uid)}function g(t){var e=t.stackgroup;return t.xaxis+t.yaxis+t.type+(e?\"-\"+e:\"\")}function m(t,e,r,n){var i=t.stackgroup;if(i){var a=e._scatterStackOpts[r._id+n._id][i],o=\"v\"===a.orientation?n:r;return\"linear\"===o.type||\"log\"===o.type?a:void 0}}e.exports={calc:function(t,e){var r,l,g,v,y,x,b=t._fullLayout,_=a.getFromId(t,e.xaxis||\"x\"),w=a.getFromId(t,e.yaxis||\"y\"),T=_.makeCalcdata(e,\"x\"),k=w.makeCalcdata(e,\"y\"),M=o(e,_,\"x\",T),A=o(e,w,\"y\",k),S=e._length,E=new Array(S),C=e.ids,L=m(e,b,_,w),I=!1;d(b,e);var P,z=\"x\",O=\"y\";L?(i.pushUnique(L.traceIndices,e._expandedIndex),(r=\"v\"===L.orientation)?(O=\"s\",P=\"x\"):(z=\"s\",P=\"y\"),y=\"interpolate\"===L.stackgaps):h(t,e,_,w,M,A,p(e,S));var D=!!e.xperiodalignment,R=!!e.yperiodalignment;for(l=0;l<S;l++){var F=E[l]={},B=n(M[l]),N=n(A[l]);B&&N?(F[z]=M[l],F[O]=A[l],D&&(F.orig_x=T[l]),R&&(F.orig_y=k[l])):L&&(r?B:N)?(F[P]=r?M[l]:A[l],F.gap=!0,y?(F.s=s,I=!0):F.s=0):F[z]=F[O]=s,C&&(F.id=String(C[l]))}if(u(E,e),c(t,e),f(E,e),L){for(l=0;l<E.length;)E[l][P]===s?E.splice(l,1):l++;if(i.sort(E,(function(t,e){return t[P]-e[P]||t.i-e.i})),I){for(l=0;l<E.length-1&&E[l].gap;)l++;for((x=E[l].s)||(x=E[l].s=0),g=0;g<l;g++)E[g].s=x;for(v=E.length-1;v>l&&E[v].gap;)v--;for(x=E[v].s,g=E.length-1;g>v;g--)E[g].s=x;for(;l<v;)if(E[++l].gap){for(g=l+1;E[g].gap;)g++;for(var j=E[l-1][P],U=E[l-1].s,V=(E[g].s-U)/(E[g][P]-j);l<g;)E[l].s=U+(E[l][P]-j)*V,l++}}}return E},calcMarkerSize:p,calcAxisExpansion:h,setFirstScatter:d,getStackOpts:m}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"./arrays_to_calcdata\":1186,\"./calc_selection\":1189,\"./colorscale_calc\":1190,\"./subtypes\":1212,\"fast-isnumeric\":241}],1189:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){n.isArrayOrTypedArray(e.selectedpoints)&&n.tagSelected(t,e)}},{\"../../lib\":778}],1190:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/helpers\").hasColorscale,i=t(\"../../components/colorscale/calc\"),a=t(\"./subtypes\");e.exports=function(t,e){a.hasLines(e)&&n(e,\"line\")&&i(t,e,{vals:e.line.color,containerStr:\"line\",cLetter:\"c\"}),a.hasMarkers(e)&&(n(e,\"marker\")&&i(t,e,{vals:e.marker.color,containerStr:\"marker\",cLetter:\"c\"}),n(e,\"marker.line\")&&i(t,e,{vals:e.marker.line.color,containerStr:\"marker.line\",cLetter:\"c\"}))}},{\"../../components/colorscale/calc\":651,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1191:[function(t,e,r){\"use strict\";e.exports={PTS_LINESONLY:20,minTolerance:.2,toleranceGrowth:10,maxScreensAway:20,eventDataKeys:[]}},{}],1192:[function(t,e,r){\"use strict\";var n=t(\"./calc\");function i(t,e,r,n,i,a,o){i[n]=!0;var s={i:null,gap:!0,s:0};if(s[o]=r,t.splice(e,0,s),e&&r===t[e-1][o]){var l=t[e-1];s.s=l.s,s.i=l.i,s.gap=l.gap}else a&&(s.s=function(t,e,r,n){var i=t[e-1],a=t[e+1];return a?i?i.s+(a.s-i.s)*(r-i[n])/(a[n]-i[n]):a.s:i.s}(t,e,r,o));e||(t[0].t=t[1].t,t[0].trace=t[1].trace,delete t[1].t,delete t[1].trace)}e.exports=function(t,e){var r=e.xaxis,a=e.yaxis,o=r._id+a._id,s=t._fullLayout._scatterStackOpts[o];if(s){var l,c,u,f,h,p,d,g,m,v,y,x,b,_,w,T=t.calcdata;for(var k in s){var M=(v=s[k]).traceIndices;if(M.length){for(y=\"interpolate\"===v.stackgaps,x=v.groupnorm,\"v\"===v.orientation?(b=\"x\",_=\"y\"):(b=\"y\",_=\"x\"),w=new Array(M.length),l=0;l<w.length;l++)w[l]=!1;p=T[M[0]];var A=new Array(p.length);for(l=0;l<p.length;l++)A[l]=p[l][b];for(l=1;l<M.length;l++){for(h=T[M[l]],c=u=0;c<h.length;c++){for(d=h[c][b];d>A[u]&&u<A.length;u++)i(h,c,A[u],l,w,y,b),c++;if(d!==A[u]){for(f=0;f<l;f++)i(T[M[f]],u,d,f,w,y,b);A.splice(u,0,d)}u++}for(;u<A.length;u++)i(h,c,A[u],l,w,y,b),c++}var S=A.length;for(c=0;c<p.length;c++){for(g=p[c][_]=p[c].s,l=1;l<M.length;l++)(h=T[M[l]])[0].trace._rawLength=h[0].trace._length,h[0].trace._length=S,g+=h[c].s,h[c][_]=g;if(x)for(m=(\"fraction\"===x?g:g/100)||1,l=0;l<M.length;l++){var E=T[M[l]][c];E[_]/=m,E.sNorm=E.s/m}}for(l=0;l<M.length;l++){var C=(h=T[M[l]])[0].trace,L=n.calcMarkerSize(C,C._rawLength),I=Array.isArray(L);if(L&&w[l]||I){var P=L;for(L=new Array(S),c=0;c<S;c++)L[c]=h[c].gap?0:I?P[h[c].i]:P}var z=new Array(S),O=new Array(S);for(c=0;c<S;c++)z[c]=h[c].x,O[c]=h[c].y;n.calcAxisExpansion(t,C,r,a,z,O,L),h[0].t.orientation=v.orientation}}}}}},{\"./calc\":1188}],1193:[function(t,e,r){\"use strict\";e.exports=function(t){for(var e=0;e<t.length;e++){var r=t[e];if(\"scatter\"===r.type){var n=r.fill;if(\"none\"!==n&&\"toself\"!==n&&(r.opacity=void 0,\"tonexty\"===n||\"tonextx\"===n))for(var i=e-1;i>=0;i--){var a=t[i];if(\"scatter\"===a.type&&a.xaxis===r.xaxis&&a.yaxis===r.yaxis){a.opacity=void 0;break}}}}}},{}],1194:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./attributes\"),o=t(\"./constants\"),s=t(\"./subtypes\"),l=t(\"./xy_defaults\"),c=t(\"./period_defaults\"),u=t(\"./stack_defaults\"),f=t(\"./marker_defaults\"),h=t(\"./line_defaults\"),p=t(\"./line_shape_defaults\"),d=t(\"./text_defaults\"),g=t(\"./fillcolor_defaults\");e.exports=function(t,e,r,m){function v(r,i){return n.coerce(t,e,a,r,i)}var y=l(t,e,m,v);if(y||(e.visible=!1),e.visible){c(t,e,m,v);var x=u(t,e,m,v),b=!x&&y<o.PTS_LINESONLY?\"lines+markers\":\"lines\";v(\"text\"),v(\"hovertext\"),v(\"mode\",b),s.hasLines(e)&&(h(t,e,r,m,v),p(t,e,v),v(\"connectgaps\"),v(\"line.simplify\")),s.hasMarkers(e)&&f(t,e,r,m,v,{gradient:!0}),s.hasText(e)&&(v(\"texttemplate\"),d(t,e,m,v));var _=[];(s.hasMarkers(e)||s.hasText(e))&&(v(\"cliponaxis\"),v(\"marker.maxdisplayed\"),_.push(\"points\")),v(\"fill\",x?x.fillDflt:\"none\"),\"none\"!==e.fill&&(g(t,e,r,v),s.hasLines(e)||p(t,e,v));var w=(e.line||{}).color,T=(e.marker||{}).color;\"tonext\"!==e.fill&&\"toself\"!==e.fill||_.push(\"fills\"),v(\"hoveron\",_.join(\"+\")||\"points\"),\"fills\"!==e.hoveron&&v(\"hovertemplate\");var k=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");k(t,e,w||T||r,{axis:\"y\"}),k(t,e,w||T||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,v)}}},{\"../../lib\":778,\"../../registry\":911,\"./attributes\":1187,\"./constants\":1191,\"./fillcolor_defaults\":1195,\"./line_defaults\":1200,\"./line_shape_defaults\":1202,\"./marker_defaults\":1206,\"./period_defaults\":1207,\"./stack_defaults\":1210,\"./subtypes\":1212,\"./text_defaults\":1213,\"./xy_defaults\":1214}],1195:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../lib\").isArrayOrTypedArray;e.exports=function(t,e,r,a){var o=!1;if(e.marker){var s=e.marker.color,l=(e.marker.line||{}).color;s&&!i(s)?o=s:l&&!i(l)&&(o=l)}a(\"fillcolor\",n.addOpacity((e.line||{}).color||o||r,.5))}},{\"../../components/color\":643,\"../../lib\":778}],1196:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a={_fullLayout:r},o=n.getFromTrace(a,e,\"x\"),s=n.getFromTrace(a,e,\"y\");return i.xLabel=n.tickText(o,t.x,!0).text,i.yLabel=n.tickText(s,t.y,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1197:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"./subtypes\");e.exports=function(t,e){var r,a;if(\"lines\"===t.mode)return(r=t.line.color)&&n.opacity(r)?r:t.fillcolor;if(\"none\"===t.mode)return t.fill?t.fillcolor:\"\";var o=e.mcc||(t.marker||{}).color,s=e.mlcc||((t.marker||{}).line||{}).color;return(a=o&&n.opacity(o)?o:s&&n.opacity(s)&&(e.mlw||((t.marker||{}).line||{}).width)?s:\"\")?n.opacity(a)<.3?n.addOpacity(a,.3):a:(r=(t.line||{}).color)&&n.opacity(r)&&i.hasLines(t)&&t.line.width?r:t.fillcolor}},{\"../../components/color\":643,\"./subtypes\":1212}],1198:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/fx\"),a=t(\"../../registry\"),o=t(\"./get_trace_color\"),s=t(\"../../components/color\"),l=n.fillText;e.exports=function(t,e,r,c){var u=t.cd,f=u[0].trace,h=t.xa,p=t.ya,d=h.c2p(e),g=p.c2p(r),m=[d,g],v=f.hoveron||\"\",y=-1!==f.mode.indexOf(\"markers\")?3:.5;if(-1!==v.indexOf(\"points\")){var x=function(t){var e=Math.max(y,t.mrc||0),r=h.c2p(t.x)-d,n=p.c2p(t.y)-g;return Math.max(Math.sqrt(r*r+n*n)-e,1-y/e)},b=i.getDistanceFunction(c,(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(h.c2p(t.x)-d);return n<e?r*n/e:n-e+r}),(function(t){var e=Math.max(3,t.mrc||0),r=1-1/e,n=Math.abs(p.c2p(t.y)-g);return n<e?r*n/e:n-e+r}),x);if(i.getClosest(u,b,t),!1!==t.index){var _=u[t.index],w=h.c2p(_.x,!0),T=p.c2p(_.y,!0),k=_.mrc||1;t.index=_.i;var M=u[0].t.orientation,A=M&&(_.sNorm||_.s),S=\"h\"===M?A:void 0!==_.orig_x?_.orig_x:_.x,E=\"v\"===M?A:void 0!==_.orig_y?_.orig_y:_.y;return n.extendFlat(t,{color:o(f,_),x0:w-k,x1:w+k,xLabelVal:S,y0:T-k,y1:T+k,yLabelVal:E,spikeDistance:x(_),hovertemplate:f.hovertemplate}),l(_,f,t),a.getComponentMethod(\"errorbars\",\"hoverInfo\")(_,f,t),[t]}}if(-1!==v.indexOf(\"fills\")&&f._polygons){var C,L,I,P,z,O,D,R,F,B=f._polygons,N=[],j=!1,U=1/0,V=-1/0,q=1/0,H=-1/0;for(C=0;C<B.length;C++)(I=B[C]).contains(m)&&(j=!j,N.push(I),q=Math.min(q,I.ymin),H=Math.max(H,I.ymax));if(j){var G=((q=Math.max(q,0))+(H=Math.min(H,p._length)))/2;for(C=0;C<N.length;C++)for(P=N[C].pts,L=1;L<P.length;L++)(R=P[L-1][1])>G!=(F=P[L][1])>=G&&(O=P[L-1][0],D=P[L][0],F-R&&(z=O+(D-O)*(G-R)/(F-R),U=Math.min(U,z),V=Math.max(V,z)));U=Math.max(U,0),V=Math.min(V,h._length);var Y=s.defaultLine;return s.opacity(f.fillcolor)?Y=f.fillcolor:s.opacity((f.line||{}).color)&&(Y=f.line.color),n.extendFlat(t,{distance:t.maxHoverDistance,x0:U,x1:V,y0:G,y1:G,color:Y,hovertemplate:!1}),delete t.index,f.text&&!Array.isArray(f.text)?t.text=String(f.text):t.text=f.name,[t]}}}},{\"../../components/color\":643,\"../../components/fx\":683,\"../../lib\":778,\"../../registry\":911,\"./get_trace_color\":1197}],1199:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports={hasLines:n.hasLines,hasMarkers:n.hasMarkers,hasText:n.hasText,isBubble:n.isBubble,attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"./cross_trace_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./cross_trace_calc\"),arraysToCalcdata:t(\"./arrays_to_calcdata\"),plot:t(\"./plot\"),colorbar:t(\"./marker_colorbar\"),formatLabels:t(\"./format_labels\"),style:t(\"./style\").style,styleOnSelect:t(\"./style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"./select\"),animatable:!0,moduleType:\"trace\",name:\"scatter\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"./arrays_to_calcdata\":1186,\"./attributes\":1187,\"./calc\":1188,\"./cross_trace_calc\":1192,\"./cross_trace_defaults\":1193,\"./defaults\":1194,\"./format_labels\":1196,\"./hover\":1198,\"./marker_colorbar\":1205,\"./plot\":1208,\"./select\":1209,\"./style\":1211,\"./subtypes\":1212}],1200:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").isArrayOrTypedArray,i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\");e.exports=function(t,e,r,o,s,l){var c=(t.marker||{}).color;(s(\"line.color\",r),i(t,\"line\"))?a(t,e,o,s,{prefix:\"line.\",cLetter:\"c\"}):s(\"line.color\",!n(c)&&c||r);s(\"line.width\"),(l||{}).noDash||s(\"line.dash\")}},{\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"../../lib\":778}],1201:[function(t,e,r){\"use strict\";var n=t(\"../../constants/numerical\"),i=n.BADNUM,a=n.LOG_CLIP,o=a+.5,s=a-.5,l=t(\"../../lib\"),c=l.segmentsIntersect,u=l.constrain,f=t(\"./constants\");e.exports=function(t,e){var r,n,a,h,p,d,g,m,v,y,x,b,_,w,T,k,M,A,S=e.xaxis,E=e.yaxis,C=\"log\"===S.type,L=\"log\"===E.type,I=S._length,P=E._length,z=e.connectGaps,O=e.baseTolerance,D=e.shape,R=\"linear\"===D,F=e.fill&&\"none\"!==e.fill,B=[],N=f.minTolerance,j=t.length,U=new Array(j),V=0;function q(r){var n=t[r];if(!n)return!1;var a=e.linearized?S.l2p(n.x):S.c2p(n.x),l=e.linearized?E.l2p(n.y):E.c2p(n.y);if(a===i){if(C&&(a=S.c2p(n.x,!0)),a===i)return!1;L&&l===i&&(a*=Math.abs(S._m*P*(S._m>0?o:s)/(E._m*I*(E._m>0?o:s)))),a*=1e3}if(l===i){if(L&&(l=E.c2p(n.y,!0)),l===i)return!1;l*=1e3}return[a,l]}function H(t,e,r,n){var i=r-t,a=n-e,o=.5-t,s=.5-e,l=i*i+a*a,c=i*o+a*s;if(c>0&&c<l){var u=o*a-s*i;if(u*u<l)return!0}}function G(t,e){var r=t[0]/I,n=t[1]/P,i=Math.max(0,-r,r-1,-n,n-1);return i&&void 0!==M&&H(r,n,M,A)&&(i=0),i&&e&&H(r,n,e[0]/I,e[1]/P)&&(i=0),(1+f.toleranceGrowth*i)*O}function Y(t,e){var r=t[0]-e[0],n=t[1]-e[1];return Math.sqrt(r*r+n*n)}var W,X,Z,J,K,Q,$,tt=f.maxScreensAway,et=-I*tt,rt=I*(1+tt),nt=-P*tt,it=P*(1+tt),at=[[et,nt,rt,nt],[rt,nt,rt,it],[rt,it,et,it],[et,it,et,nt]];function ot(t){if(t[0]<et||t[0]>rt||t[1]<nt||t[1]>it)return[u(t[0],et,rt),u(t[1],nt,it)]}function st(t,e){return t[0]===e[0]&&(t[0]===et||t[0]===rt)||(t[1]===e[1]&&(t[1]===nt||t[1]===it)||void 0)}function lt(t,e,r){return function(n,i){var a=ot(n),o=ot(i),s=[];if(a&&o&&st(a,o))return s;a&&s.push(a),o&&s.push(o);var c=2*l.constrain((n[t]+i[t])/2,e,r)-((a||n)[t]+(o||i)[t]);c&&((a&&o?c>0==a[t]>o[t]?a:o:a||o)[t]+=c);return s}}function ct(t){var e=t[0],r=t[1],n=e===U[V-1][0],i=r===U[V-1][1];if(!n||!i)if(V>1){var a=e===U[V-2][0],o=r===U[V-2][1];n&&(e===et||e===rt)&&a?o?V--:U[V-1]=t:i&&(r===nt||r===it)&&o?a?V--:U[V-1]=t:U[V++]=t}else U[V++]=t}function ut(t){U[V-1][0]!==t[0]&&U[V-1][1]!==t[1]&&ct([Z,J]),ct(t),K=null,Z=J=0}function ft(t){if(M=t[0]/I,A=t[1]/P,W=t[0]<et?et:t[0]>rt?rt:0,X=t[1]<nt?nt:t[1]>it?it:0,W||X){if(V)if(K){var e=$(K,t);e.length>1&&(ut(e[0]),U[V++]=e[1])}else Q=$(U[V-1],t)[0],U[V++]=Q;else U[V++]=[W||t[0],X||t[1]];var r=U[V-1];W&&X&&(r[0]!==W||r[1]!==X)?(K&&(Z!==W&&J!==X?ct(Z&&J?(n=K,a=(i=t)[0]-n[0],o=(i[1]-n[1])/a,(n[1]*i[0]-i[1]*n[0])/a>0?[o>0?et:rt,it]:[o>0?rt:et,nt]):[Z||W,J||X]):Z&&J&&ct([Z,J])),ct([W,X])):Z-W&&J-X&&ct([W||Z,X||J]),K=t,Z=W,J=X}else K&&ut($(K,t)[0]),U[V++]=t;var n,i,a,o}for(\"linear\"===D||\"spline\"===D?$=function(t,e){for(var r=[],n=0,i=0;i<4;i++){var a=at[i],o=c(t[0],t[1],e[0],e[1],a[0],a[1],a[2],a[3]);o&&(!n||Math.abs(o.x-r[0][0])>1||Math.abs(o.y-r[0][1])>1)&&(o=[o.x,o.y],n&&Y(o,t)<Y(r[0],t)?r.unshift(o):r.push(o),n++)}return r}:\"hv\"===D||\"vh\"===D?$=function(t,e){var r=[],n=ot(t),i=ot(e);return n&&i&&st(n,i)||(n&&r.push(n),i&&r.push(i)),r}:\"hvh\"===D?$=lt(0,et,rt):\"vhv\"===D&&($=lt(1,nt,it)),r=0;r<j;r++)if(n=q(r)){for(V=0,K=null,ft(n),r++;r<j;r++){if(!(h=q(r))){if(z)continue;break}if(R&&e.simplify){var ht=q(r+1);if(y=Y(h,n),F&&(0===V||V===j-1)||!(y<G(h,ht)*N)){for(m=[(h[0]-n[0])/y,(h[1]-n[1])/y],p=n,x=y,b=w=T=0,g=!1,a=h,r++;r<t.length;r++){if(d=ht,ht=q(r+1),!d){if(z)continue;break}if(k=(v=[d[0]-n[0],d[1]-n[1]])[0]*m[1]-v[1]*m[0],w=Math.min(w,k),(T=Math.max(T,k))-w>G(d,ht))break;a=d,(_=v[0]*m[0]+v[1]*m[1])>x?(x=_,h=d,g=!1):_<b&&(b=_,p=d,g=!0)}if(g?(ft(h),a!==p&&ft(p)):(p!==n&&ft(p),a!==h&&ft(h)),ft(a),r>=t.length||!d)break;ft(d),n=d}}else ft(h)}K&&ct([Z||K[0],J||K[1]]),B.push(U.slice(0,V))}return B}},{\"../../constants/numerical\":753,\"../../lib\":778,\"./constants\":1191}],1202:[function(t,e,r){\"use strict\";e.exports=function(t,e,r){\"spline\"===r(\"line.shape\")&&r(\"line.smoothing\")}},{}],1203:[function(t,e,r){\"use strict\";var n={tonextx:1,tonexty:1,tonext:1};e.exports=function(t,e,r){var i,a,o,s,l,c={},u=!1,f=-1,h=0,p=-1;for(a=0;a<r.length;a++)(o=(i=r[a][0].trace).stackgroup||\"\")?o in c?l=c[o]:(l=c[o]=h,h++):i.fill in n&&p>=0?l=p:(l=p=h,h++),l<f&&(u=!0),i._groupIndex=f=l;var d=r.slice();u&&d.sort((function(t,e){var r=t[0].trace,n=e[0].trace;return r._groupIndex-n._groupIndex||r.index-n.index}));var g={};for(a=0;a<d.length;a++)o=(i=d[a][0].trace).stackgroup||\"\",!0===i.visible?(i._nexttrace=null,i.fill in n&&(s=g[o],i._prevtrace=s||null,s&&(s._nexttrace=i)),i._ownfill=i.fill&&(\"tozero\"===i.fill.substr(0,6)||\"toself\"===i.fill||\"to\"===i.fill.substr(0,2)&&!i._prevtrace),g[o]=i):i._prevtrace=i._nexttrace=i._ownfill=null;return d}},{}],1204:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\");e.exports=function(t){var e=t.marker,r=e.sizeref||1,i=e.sizemin||0,a=\"area\"===e.sizemode?function(t){return Math.sqrt(t/r)}:function(t){return t/r};return function(t){var e=a(t/2);return n(e)&&e>0?Math.max(e,i):0}}},{\"fast-isnumeric\":241}],1205:[function(t,e,r){\"use strict\";e.exports={container:\"marker\",min:\"cmin\",max:\"cmax\"}},{}],1206:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/helpers\").hasColorscale,a=t(\"../../components/colorscale/defaults\"),o=t(\"./subtypes\");e.exports=function(t,e,r,s,l,c){var u=o.isBubble(t),f=(t.line||{}).color;(c=c||{},f&&(r=f),l(\"marker.symbol\"),l(\"marker.opacity\",u?.7:1),l(\"marker.size\"),l(\"marker.color\",r),i(t,\"marker\")&&a(t,e,s,l,{prefix:\"marker.\",cLetter:\"c\"}),c.noSelect||(l(\"selected.marker.color\"),l(\"unselected.marker.color\"),l(\"selected.marker.size\"),l(\"unselected.marker.size\")),c.noLine||(l(\"marker.line.color\",f&&!Array.isArray(f)&&e.marker.color!==f?f:u?n.background:n.defaultLine),i(t,\"marker.line\")&&a(t,e,s,l,{prefix:\"marker.line.\",cLetter:\"c\"}),l(\"marker.line.width\",u?1:0)),u&&(l(\"marker.sizeref\"),l(\"marker.sizemin\"),l(\"marker.sizemode\")),c.gradient)&&(\"none\"!==l(\"marker.gradient.type\")&&l(\"marker.gradient.color\"))}},{\"../../components/color\":643,\"../../components/colorscale/defaults\":653,\"../../components/colorscale/helpers\":654,\"./subtypes\":1212}],1207:[function(t,e,r){\"use strict\";var n=t(\"../../lib\").dateTick0,i=t(\"../../constants/numerical\").ONEWEEK;function a(t,e){return n(e,t%i==0?1:0)}e.exports=function(t,e,r,n,i){if(i||(i={x:!0,y:!0}),i.x){var o=n(\"xperiod\");o&&(n(\"xperiod0\",a(o,e.xcalendar)),n(\"xperiodalignment\"))}if(i.y){var s=n(\"yperiod\");s&&(n(\"yperiod0\",a(s,e.ycalendar)),n(\"yperiodalignment\"))}}},{\"../../constants/numerical\":753,\"../../lib\":778}],1208:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../lib\"),o=a.ensureSingle,s=a.identity,l=t(\"../../components/drawing\"),c=t(\"./subtypes\"),u=t(\"./line_points\"),f=t(\"./link_traces\"),h=t(\"../../lib/polygon\").tester;function p(t,e,r,f,p,d,g){var m;!function(t,e,r,i,o){var s=r.xaxis,l=r.yaxis,u=n.extent(a.simpleMap(s.range,s.r2c)),f=n.extent(a.simpleMap(l.range,l.r2c)),h=i[0].trace;if(!c.hasMarkers(h))return;var p=h.marker.maxdisplayed;if(0===p)return;var d=i.filter((function(t){return t.x>=u[0]&&t.x<=u[1]&&t.y>=f[0]&&t.y<=f[1]})),g=Math.ceil(d.length/p),m=0;o.forEach((function(t,r){var n=t[0].trace;c.hasMarkers(n)&&n.marker.maxdisplayed>0&&r<e&&m++}));var v=Math.round(m*g/3+Math.floor(m/3)*g/7.1);i.forEach((function(t){delete t.vis})),d.forEach((function(t,e){0===Math.round((e+v)%g)&&(t.vis=!0)}))}(0,e,r,f,p);var v=!!g&&g.duration>0;function y(t){return v?t.transition():t}var x=r.xaxis,b=r.yaxis,_=f[0].trace,w=_.line,T=n.select(d),k=o(T,\"g\",\"errorbars\"),M=o(T,\"g\",\"lines\"),A=o(T,\"g\",\"points\"),S=o(T,\"g\",\"text\");if(i.getComponentMethod(\"errorbars\",\"plot\")(t,k,r,g),!0===_.visible){var E,C;y(T).style(\"opacity\",_.opacity);var L=_.fill.charAt(_.fill.length-1);\"x\"!==L&&\"y\"!==L&&(L=\"\"),f[0][r.isRangePlot?\"nodeRangePlot3\":\"node3\"]=T;var I,P,z=\"\",O=[],D=_._prevtrace;D&&(z=D._prevRevpath||\"\",C=D._nextFill,O=D._polygons);var R,F,B,N,j,U,V,q=\"\",H=\"\",G=[],Y=a.noop;if(E=_._ownFill,c.hasLines(_)||\"none\"!==_.fill){for(C&&C.datum(f),-1!==[\"hv\",\"vh\",\"hvh\",\"vhv\"].indexOf(w.shape)?(R=l.steps(w.shape),F=l.steps(w.shape.split(\"\").reverse().join(\"\"))):R=F=\"spline\"===w.shape?function(t){var e=t[t.length-1];return t.length>1&&t[0][0]===e[0]&&t[0][1]===e[1]?l.smoothclosed(t.slice(1),w.smoothing):l.smoothopen(t,w.smoothing)}:function(t){return\"M\"+t.join(\"L\")},B=function(t){return F(t.reverse())},G=u(f,{xaxis:x,yaxis:b,connectGaps:_.connectgaps,baseTolerance:Math.max(w.width||1,3)/4,shape:w.shape,simplify:w.simplify,fill:_.fill}),V=_._polygons=new Array(G.length),m=0;m<G.length;m++)_._polygons[m]=h(G[m]);G.length&&(N=G[0][0],U=(j=G[G.length-1])[j.length-1]),Y=function(t){return function(e){if(I=R(e),P=B(e),q?L?(q+=\"L\"+I.substr(1),H=P+\"L\"+H.substr(1)):(q+=\"Z\"+I,H=P+\"Z\"+H):(q=I,H=P),c.hasLines(_)&&e.length>1){var r=n.select(this);if(r.datum(f),t)y(r.style(\"opacity\",0).attr(\"d\",I).call(l.lineGroupStyle)).style(\"opacity\",1);else{var i=y(r);i.attr(\"d\",I),l.singleLineStyle(f,i)}}}}}var W=M.selectAll(\".js-line\").data(G);y(W.exit()).style(\"opacity\",0).remove(),W.each(Y(!1)),W.enter().append(\"path\").classed(\"js-line\",!0).style(\"vector-effect\",\"non-scaling-stroke\").call(l.lineGroupStyle).each(Y(!0)),l.setClipUrl(W,r.layerClipId,t),G.length?(E?(E.datum(f),N&&U&&(L?(\"y\"===L?N[1]=U[1]=b.c2p(0,!0):\"x\"===L&&(N[0]=U[0]=x.c2p(0,!0)),y(E).attr(\"d\",\"M\"+U+\"L\"+N+\"L\"+q.substr(1)).call(l.singleFillStyle)):y(E).attr(\"d\",q+\"Z\").call(l.singleFillStyle))):C&&(\"tonext\"===_.fill.substr(0,6)&&q&&z?(\"tonext\"===_.fill?y(C).attr(\"d\",q+\"Z\"+z+\"Z\").call(l.singleFillStyle):y(C).attr(\"d\",q+\"L\"+z.substr(1)+\"Z\").call(l.singleFillStyle),_._polygons=_._polygons.concat(O)):(Z(C),_._polygons=null)),_._prevRevpath=H,_._prevPolygons=V):(E?Z(E):C&&Z(C),_._polygons=_._prevRevpath=_._prevPolygons=null),A.datum(f),S.datum(f),function(e,i,a){var o,u=a[0].trace,f=c.hasMarkers(u),h=c.hasText(u),p=tt(u),d=et,g=et;if(f||h){var m=s,_=u.stackgroup,w=_&&\"infer zero\"===t._fullLayout._scatterStackOpts[x._id+b._id][_].stackgaps;u.marker.maxdisplayed||u._needsCull?m=w?K:J:_&&!w&&(m=Q),f&&(d=m),h&&(g=m)}var T,k=(o=e.selectAll(\"path.point\").data(d,p)).enter().append(\"path\").classed(\"point\",!0);v&&k.call(l.pointStyle,u,t).call(l.translatePoints,x,b).style(\"opacity\",0).transition().style(\"opacity\",1),o.order(),f&&(T=l.makePointStyleFns(u)),o.each((function(e){var i=n.select(this),a=y(i);l.translatePoint(e,a,x,b)?(l.singlePointStyle(e,a,u,T,t),r.layerClipId&&l.hideOutsideRangePoint(e,a,x,b,u.xcalendar,u.ycalendar),u.customdata&&i.classed(\"plotly-customdata\",null!==e.data&&void 0!==e.data)):a.remove()})),v?o.exit().transition().style(\"opacity\",0).remove():o.exit().remove(),(o=i.selectAll(\"g\").data(g,p)).enter().append(\"g\").classed(\"textpoint\",!0).append(\"text\"),o.order(),o.each((function(t){var e=n.select(this),i=y(e.select(\"text\"));l.translatePoint(t,i,x,b)?r.layerClipId&&l.hideOutsideRangePoint(t,e,x,b,u.xcalendar,u.ycalendar):e.remove()})),o.selectAll(\"text\").call(l.textPointStyle,u,t).each((function(t){var e=x.c2p(t.x),r=b.c2p(t.y);n.select(this).selectAll(\"tspan.line\").each((function(){y(n.select(this)).attr({x:e,y:r})}))})),o.exit().remove()}(A,S,f);var X=!1===_.cliponaxis?null:r.layerClipId;l.setClipUrl(A,X,t),l.setClipUrl(S,X,t)}function Z(t){y(t).attr(\"d\",\"M0,0Z\")}function J(t){return t.filter((function(t){return!t.gap&&t.vis}))}function K(t){return t.filter((function(t){return t.vis}))}function Q(t){return t.filter((function(t){return!t.gap}))}function $(t){return t.id}function tt(t){if(t.ids)return $}function et(){return!1}}e.exports=function(t,e,r,i,a,c){var u,h,d=!a,g=!!a&&a.duration>0,m=f(t,e,r);((u=i.selectAll(\"g.trace\").data(m,(function(t){return t[0].trace.uid}))).enter().append(\"g\").attr(\"class\",(function(t){return\"trace scatter trace\"+t[0].trace.uid})).style(\"stroke-miterlimit\",2),u.order(),function(t,e,r){e.each((function(e){var i=o(n.select(this),\"g\",\"fills\");l.setClipUrl(i,r.layerClipId,t);var a=e[0].trace,c=[];a._ownfill&&c.push(\"_ownFill\"),a._nexttrace&&c.push(\"_nextFill\");var u=i.selectAll(\"g\").data(c,s);u.enter().append(\"g\"),u.exit().each((function(t){a[t]=null})).remove(),u.order().each((function(t){a[t]=o(n.select(this),\"path\",\"js-fill\")}))}))}(t,u,e),g)?(c&&(h=c()),n.transition().duration(a.duration).ease(a.easing).each(\"end\",(function(){h&&h()})).each(\"interrupt\",(function(){h&&h()})).each((function(){i.selectAll(\"g.trace\").each((function(r,n){p(t,n,e,r,m,this,a)}))}))):u.each((function(r,n){p(t,n,e,r,m,this,a)}));d&&u.exit().remove(),i.selectAll(\"path:not([d])\").remove()}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/polygon\":790,\"../../registry\":911,\"./line_points\":1201,\"./link_traces\":1203,\"./subtypes\":1212,d3:169}],1209:[function(t,e,r){\"use strict\";var n=t(\"./subtypes\");e.exports=function(t,e){var r,i,a,o,s=t.cd,l=t.xaxis,c=t.yaxis,u=[],f=s[0].trace;if(!n.hasMarkers(f)&&!n.hasText(f))return[];if(!1===e)for(r=0;r<s.length;r++)s[r].selected=0;else for(r=0;r<s.length;r++)i=s[r],a=l.c2p(i.x),o=c.c2p(i.y),null!==i.i&&e.contains([a,o],!1,r,t)?(u.push({pointNumber:i.i,x:l.c2d(i.x),y:c.c2d(i.y)}),i.selected=1):i.selected=0;return u}},{\"./subtypes\":1212}],1210:[function(t,e,r){\"use strict\";var n=[\"orientation\",\"groupnorm\",\"stackgaps\"];e.exports=function(t,e,r,i){var a=r._scatterStackOpts,o=i(\"stackgroup\");if(o){var s=e.xaxis+e.yaxis,l=a[s];l||(l=a[s]={});var c=l[o],u=!1;c?c.traces.push(e):(c=l[o]={traceIndices:[],traces:[e]},u=!0);for(var f={orientation:e.x&&!e.y?\"h\":\"v\"},h=0;h<n.length;h++){var p=n[h],d=p+\"Found\";if(!c[d]){var g=void 0!==t[p],m=\"orientation\"===p;if((g||u)&&(c[p]=i(p,f[p]),m&&(c.fillDflt=\"h\"===c[p]?\"tonextx\":\"tonexty\"),g&&(c[d]=!0,!u&&(delete c.traces[0][p],m))))for(var v=0;v<c.traces.length-1;v++){var y=c.traces[v];y._input.fill!==y.fill&&(y.fill=c.fillDflt)}}}return c}}},{}],1211:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../registry\");function o(t,e,r){i.pointStyle(t.selectAll(\"path.point\"),e,r)}function s(t,e,r){i.textPointStyle(t.selectAll(\"text\"),e,r)}e.exports={style:function(t){var e=n.select(t).selectAll(\"g.trace.scatter\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.selectAll(\"g.points\").each((function(e){o(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.text\").each((function(e){s(n.select(this),e.trace||e[0].trace,t)})),e.selectAll(\"g.trace path.js-line\").call(i.lineGroupStyle),e.selectAll(\"g.trace path.js-fill\").call(i.fillGroupStyle),a.getComponentMethod(\"errorbars\",\"style\")(e)},stylePoints:o,styleText:s,styleOnSelect:function(t,e,r){var n=e[0].trace;n.selectedpoints?(i.selectedPointStyle(r.selectAll(\"path.point\"),n),i.selectedTextStyle(r.selectAll(\"text\"),n)):(o(r,n,t),s(r,n,t))}}},{\"../../components/drawing\":665,\"../../registry\":911,d3:169}],1212:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports={hasLines:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"lines\")},hasMarkers:function(t){return t.visible&&(t.mode&&-1!==t.mode.indexOf(\"markers\")||\"splom\"===t.type)},hasText:function(t){return t.visible&&t.mode&&-1!==t.mode.indexOf(\"text\")},isBubble:function(t){return n.isPlainObject(t.marker)&&n.isArrayOrTypedArray(t.marker.size)}}},{\"../../lib\":778}],1213:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e,r,i,a){a=a||{},i(\"textposition\"),n.coerceFont(i,\"textfont\",r.font),a.noSelect||(i(\"selected.textfont.color\"),i(\"unselected.textfont.color\"))}},{\"../../lib\":778}],1214:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\");e.exports=function(t,e,r,a){var o,s=a(\"x\"),l=a(\"y\");if(i.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\"],r),s){var c=n.minRowLength(s);l?o=Math.min(c,n.minRowLength(l)):(o=c,a(\"y0\"),a(\"dy\"))}else{if(!l)return 0;o=n.minRowLength(l),a(\"x0\"),a(\"dx\")}return e._length=o,o}},{\"../../lib\":778,\"../../registry\":911}],1215:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../plots/attributes\"),l=t(\"../../constants/gl3d_dashes\"),c=t(\"../../constants/gl3d_markers\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=n.line,p=n.marker,d=p.line,g=u({width:h.width,dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},i(\"line\"));var m=e.exports=f({x:n.x,y:n.y,z:{valType:\"data_array\"},text:u({},n.text,{}),texttemplate:o({},{}),hovertext:u({},n.hovertext,{}),hovertemplate:a(),mode:u({},n.mode,{dflt:\"lines+markers\"}),surfaceaxis:{valType:\"enumerated\",values:[-1,0,1,2],dflt:-1},surfacecolor:{valType:\"color\"},projection:{x:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},y:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}},z:{show:{valType:\"boolean\",dflt:!1},opacity:{valType:\"number\",min:0,max:1,dflt:1},scale:{valType:\"number\",min:0,max:10,dflt:2/3}}},connectgaps:n.connectgaps,line:g,marker:u({symbol:{valType:\"enumerated\",values:Object.keys(c),dflt:\"circle\",arrayOk:!0},size:u({},p.size,{dflt:8}),sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode,opacity:u({},p.opacity,{arrayOk:!1}),colorbar:p.colorbar,line:u({width:u({},d.width,{arrayOk:!1})},i(\"marker.line\"))},i(\"marker\")),textposition:u({},n.textposition,{dflt:\"top center\"}),textfont:{color:n.textfont.color,size:n.textfont.size,family:u({},n.textfont.family,{arrayOk:!1})},hoverinfo:u({},s.hoverinfo)},\"calc\",\"nested\");m.x.editType=m.y.editType=m.z.editType=\"calc+clearAxisTypes\"},{\"../../components/colorscale/attributes\":650,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1216:[function(t,e,r){\"use strict\";var n=t(\"../scatter/arrays_to_calcdata\"),i=t(\"../scatter/colorscale_calc\");e.exports=function(t,e){var r=[{x:!1,y:!1,trace:e,t:{}}];return n(r,e),i(t,e),r}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/colorscale_calc\":1190}],1217:[function(t,e,r){\"use strict\";var n=t(\"../../registry\");function i(t,e,r,i){if(!e||!e.visible)return null;for(var a=n.getComponentMethod(\"errorbars\",\"makeComputeError\")(e),o=new Array(t.length),s=0;s<t.length;s++){var l=a(+t[s],s);if(\"log\"===i.type){var c=i.c2l(t[s]),u=t[s]-l[0],f=t[s]+l[1];if(o[s]=[(i.c2l(u,!0)-c)*r,(i.c2l(f,!0)-c)*r],u>0){var h=i.c2l(u);i._lowerLogErrorBound||(i._lowerLogErrorBound=h),i._lowerErrorBound=Math.min(i._lowerLogErrorBound,h)}}else o[s]=[-l[0]*r,l[1]*r]}return o}e.exports=function(t,e,r){var n=[i(t.x,t.error_x,e[0],r.xaxis),i(t.y,t.error_y,e[1],r.yaxis),i(t.z,t.error_z,e[2],r.zaxis)],a=function(t){for(var e=0;e<t.length;e++)if(t[e])return t[e].length;return 0}(n);if(0===a)return null;for(var o=new Array(a),s=0;s<a;s++){for(var l=[[0,0,0],[0,0,0]],c=0;c<3;c++)if(n[c])for(var u=0;u<2;u++)l[u][c]=n[c][s][u];o[s]=l}return o}},{\"../../registry\":911}],1218:[function(t,e,r){\"use strict\";var n=t(\"gl-line3d\"),i=t(\"gl-scatter3d\"),a=t(\"gl-error3d\"),o=t(\"gl-mesh3d\"),s=t(\"delaunay-triangulate\"),l=t(\"../../lib\"),c=t(\"../../lib/str2rgbarray\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/make_bubble_size_func\"),h=t(\"../../constants/gl3d_dashes\"),p=t(\"../../constants/gl3d_markers\"),d=t(\"../../plots/cartesian/axes\"),g=t(\"../../components/fx/helpers\").appendArrayPointValue,m=t(\"./calc_errors\");function v(t,e){this.scene=t,this.uid=e,this.linePlot=null,this.scatterPlot=null,this.errorBars=null,this.textMarkers=null,this.delaunayMesh=null,this.color=null,this.mode=\"\",this.dataPoints=[],this.axesBounds=[[-1/0,-1/0,-1/0],[1/0,1/0,1/0]],this.textLabels=null,this.data=null}var y=v.prototype;function x(t){return null==t?0:t.indexOf(\"left\")>-1?-1:t.indexOf(\"right\")>-1?1:0}function b(t){return null==t?0:t.indexOf(\"top\")>-1?-1:t.indexOf(\"bottom\")>-1?1:0}function _(t,e){return e(4*t)}function w(t){return p[t]}function T(t,e,r,n,i){var a=null;if(l.isArrayOrTypedArray(t)){a=[];for(var o=0;o<e;o++)void 0===t[o]?a[o]=n:a[o]=r(t[o],i)}else a=r(t,l.identity);return a}function k(t,e){var r,n,i,a,o,s,h=[],p=t.fullSceneLayout,v=t.dataScale,y=p.xaxis,k=p.yaxis,M=p.zaxis,A=e.marker,S=e.line,E=e.x||[],C=e.y||[],L=e.z||[],I=E.length,P=e.xcalendar,z=e.ycalendar,O=e.zcalendar;for(o=0;o<I;o++)r=y.d2l(E[o],0,P)*v[0],n=k.d2l(C[o],0,z)*v[1],i=M.d2l(L[o],0,O)*v[2],h[o]=[r,n,i];if(Array.isArray(e.text))s=e.text;else if(void 0!==e.text)for(s=new Array(I),o=0;o<I;o++)s[o]=e.text;function D(t,e){var r=p[t];return d.tickText(r,r.d2l(e),!0).text}var R=e.texttemplate;if(R){var F=t.fullLayout._d3locale,B=Array.isArray(R),N=B?Math.min(R.length,I):I,j=B?function(t){return R[t]}:function(){return R};for(s=new Array(N),o=0;o<N;o++){var U={x:E[o],y:C[o],z:L[o]},V={xLabel:D(\"xaxis\",E[o]),yLabel:D(\"yaxis\",C[o]),zLabel:D(\"zaxis\",L[o])},q={};g(q,e,o);var H=e._meta||{};s[o]=l.texttemplateString(j(o),V,F,q,U,H)}}if(a={position:h,mode:e.mode,text:s},\"line\"in e&&(a.lineColor=u(S,1,I),a.lineWidth=S.width,a.lineDashes=S.dash),\"marker\"in e){var G=f(e);a.scatterColor=u(A,1,I),a.scatterSize=T(A.size,I,_,20,G),a.scatterMarker=T(A.symbol,I,w,\"\\u25cf\"),a.scatterLineWidth=A.line.width,a.scatterLineColor=u(A.line,1,I),a.scatterAngle=0}\"textposition\"in e&&(a.textOffset=function(t){var e=[0,0];if(Array.isArray(t))for(var r=0;r<t.length;r++)e[r]=[0,0],t[r]&&(e[r][0]=x(t[r]),e[r][1]=b(t[r]));else e[0]=x(t),e[1]=b(t);return e}(e.textposition),a.textColor=u(e.textfont,1,I),a.textSize=T(e.textfont.size,I,l.identity,12),a.textFont=e.textfont.family,a.textAngle=0);var Y=[\"x\",\"y\",\"z\"];for(a.project=[!1,!1,!1],a.projectScale=[1,1,1],a.projectOpacity=[1,1,1],o=0;o<3;++o){var W=e.projection[Y[o]];(a.project[o]=W.show)&&(a.projectOpacity[o]=W.opacity,a.projectScale[o]=W.scale)}a.errorBounds=m(e,v,p);var X=function(t){for(var e=[0,0,0],r=[[0,0,0],[0,0,0],[0,0,0]],n=[1,1,1],i=0;i<3;i++){var a=t[i];a&&!1!==a.copy_zstyle&&!1!==t[2].visible&&(a=t[2]),a&&a.visible&&(e[i]=a.width/2,r[i]=c(a.color),n[i]=a.thickness)}return{capSize:e,color:r,lineWidth:n}}([e.error_x,e.error_y,e.error_z]);return a.errorColor=X.color,a.errorLineWidth=X.lineWidth,a.errorCapSize=X.capSize,a.delaunayAxis=e.surfaceaxis,a.delaunayColor=c(e.surfacecolor),a}function M(t){if(l.isArrayOrTypedArray(t)){var e=t[0];return l.isArrayOrTypedArray(e)&&(t=e),\"rgb(\"+t.slice(0,3).map((function(t){return Math.round(255*t)}))+\")\"}return null}function A(t){return l.isArrayOrTypedArray(t)?4===t.length&&\"number\"==typeof t[0]?M(t):t.map(M):null}y.handlePick=function(t){if(t.object&&(t.object===this.linePlot||t.object===this.delaunayMesh||t.object===this.textMarkers||t.object===this.scatterPlot)){var e=t.index=t.data.index;return t.object.highlight&&t.object.highlight(null),this.scatterPlot&&(t.object=this.scatterPlot,this.scatterPlot.highlight(t.data)),t.textLabel=\"\",this.textLabels&&(Array.isArray(this.textLabels)?(this.textLabels[e]||0===this.textLabels[e])&&(t.textLabel=this.textLabels[e]):t.textLabel=this.textLabels),t.traceCoordinate=[this.data.x[e],this.data.y[e],this.data.z[e]],!0}},y.update=function(t){var e,r,l,c,u=this.scene.glplot.gl,f=h.solid;this.data=t;var p=k(this.scene,t);\"mode\"in p&&(this.mode=p.mode),\"lineDashes\"in p&&p.lineDashes in h&&(f=h[p.lineDashes]),this.color=A(p.scatterColor)||A(p.lineColor),this.dataPoints=p.position,e={gl:this.scene.glplot.gl,position:p.position,color:p.lineColor,lineWidth:p.lineWidth||1,dashes:f[0],dashScale:f[1],opacity:t.opacity,connectGaps:t.connectgaps},-1!==this.mode.indexOf(\"lines\")?this.linePlot?this.linePlot.update(e):(this.linePlot=n(e),this.linePlot._trace=this,this.scene.glplot.add(this.linePlot)):this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose(),this.linePlot=null);var d=t.opacity;if(t.marker&&t.marker.opacity&&(d*=t.marker.opacity),r={gl:this.scene.glplot.gl,position:p.position,color:p.scatterColor,size:p.scatterSize,glyph:p.scatterMarker,opacity:d,orthographic:!0,lineWidth:p.scatterLineWidth,lineColor:p.scatterLineColor,project:p.project,projectScale:p.projectScale,projectOpacity:p.projectOpacity},-1!==this.mode.indexOf(\"markers\")?this.scatterPlot?this.scatterPlot.update(r):(this.scatterPlot=i(r),this.scatterPlot._trace=this,this.scatterPlot.highlightScale=1,this.scene.glplot.add(this.scatterPlot)):this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose(),this.scatterPlot=null),c={gl:this.scene.glplot.gl,position:p.position,glyph:p.text,color:p.textColor,size:p.textSize,angle:p.textAngle,alignment:p.textOffset,font:p.textFont,orthographic:!0,lineWidth:0,project:!1,opacity:t.opacity},this.textLabels=t.hovertext||t.text,-1!==this.mode.indexOf(\"text\")?this.textMarkers?this.textMarkers.update(c):(this.textMarkers=i(c),this.textMarkers._trace=this,this.textMarkers.highlightScale=1,this.scene.glplot.add(this.textMarkers)):this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose(),this.textMarkers=null),l={gl:this.scene.glplot.gl,position:p.position,color:p.errorColor,error:p.errorBounds,lineWidth:p.errorLineWidth,capSize:p.errorCapSize,opacity:t.opacity},this.errorBars?p.errorBounds?this.errorBars.update(l):(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose(),this.errorBars=null):p.errorBounds&&(this.errorBars=a(l),this.errorBars._trace=this,this.scene.glplot.add(this.errorBars)),p.delaunayAxis>=0){var g=function(t,e,r){var n,i=(r+1)%3,a=(r+2)%3,o=[],l=[];for(n=0;n<t.length;++n){var c=t[n];!isNaN(c[i])&&isFinite(c[i])&&!isNaN(c[a])&&isFinite(c[a])&&(o.push([c[i],c[a]]),l.push(n))}var u=s(o);for(n=0;n<u.length;++n)for(var f=u[n],h=0;h<f.length;++h)f[h]=l[f[h]];return{positions:t,cells:u,meshColor:e}}(p.position,p.delaunayColor,p.delaunayAxis);g.opacity=t.opacity,this.delaunayMesh?this.delaunayMesh.update(g):(g.gl=u,this.delaunayMesh=o(g),this.delaunayMesh._trace=this,this.scene.glplot.add(this.delaunayMesh))}else this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose(),this.delaunayMesh=null)},y.dispose=function(){this.linePlot&&(this.scene.glplot.remove(this.linePlot),this.linePlot.dispose()),this.scatterPlot&&(this.scene.glplot.remove(this.scatterPlot),this.scatterPlot.dispose()),this.errorBars&&(this.scene.glplot.remove(this.errorBars),this.errorBars.dispose()),this.textMarkers&&(this.scene.glplot.remove(this.textMarkers),this.textMarkers.dispose()),this.delaunayMesh&&(this.scene.glplot.remove(this.delaunayMesh),this.delaunayMesh.dispose())},e.exports=function(t,e){var r=new v(t,e.uid);return r.update(e),r}},{\"../../components/fx/helpers\":679,\"../../constants/gl3d_dashes\":750,\"../../constants/gl3d_markers\":751,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/cartesian/axes\":828,\"../scatter/make_bubble_size_func\":1204,\"./calc_errors\":1217,\"delaunay-triangulate\":171,\"gl-error3d\":266,\"gl-line3d\":275,\"gl-mesh3d\":309,\"gl-scatter3d\":330}],1219:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,n){return i.coerce(t,e,c,r,n)}if(function(t,e,r,i){var a=0,o=r(\"x\"),s=r(\"y\"),l=r(\"z\");n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],i),o&&s&&l&&(a=Math.min(o.length,s.length,l.length),e._length=e._xlength=e._ylength=e._zlength=a);return a}(t,e,f,u)){f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),a.hasLines(e)&&(f(\"connectgaps\"),s(t,e,r,u,f)),a.hasMarkers(e)&&o(t,e,r,u,f,{noSelect:!0}),a.hasText(e)&&(f(\"texttemplate\"),l(t,e,u,f,{noSelect:!0}));var h=(e.line||{}).color,p=(e.marker||{}).color;f(\"surfaceaxis\")>=0&&f(\"surfacecolor\",h||p);for(var d=[\"x\",\"y\",\"z\"],g=0;g<3;++g){var m=\"projection.\"+d[g];f(m+\".show\")&&(f(m+\".opacity\"),f(m+\".scale\"))}var v=n.getComponentMethod(\"errorbars\",\"supplyDefaults\");v(t,e,h||p||r,{axis:\"z\"}),v(t,e,h||p||r,{axis:\"y\",inherit:\"z\"}),v(t,e,h||p||r,{axis:\"x\",inherit:\"z\"})}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1215}],1220:[function(t,e,r){\"use strict\";e.exports={plot:t(\"./convert\"),attributes:t(\"./attributes\"),markerSymbols:t(\"../../constants/gl3d_markers\"),supplyDefaults:t(\"./defaults\"),colorbar:[{container:\"marker\",min:\"cmin\",max:\"cmax\"},{container:\"line\",min:\"cmin\",max:\"cmax\"}],calc:t(\"./calc\"),moduleType:\"trace\",name:\"scatter3d\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../constants/gl3d_markers\":751,\"../../plots/gl3d\":870,\"./attributes\":1215,\"./calc\":1216,\"./convert\":1218,\"./defaults\":1219}],1221:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../plots/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/template_attributes\").texttemplateAttrs,s=t(\"../../components/colorscale/attributes\"),l=t(\"../../lib/extend\").extendFlat,c=n.marker,u=n.line,f=c.line;e.exports={carpet:{valType:\"string\",editType:\"calc\"},a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},mode:l({},n.mode,{dflt:\"markers\"}),text:l({},n.text,{}),texttemplate:o({editType:\"plot\"},{keys:[\"a\",\"b\",\"text\"]}),hovertext:l({},n.hovertext,{}),line:{color:u.color,width:u.width,dash:u.dash,shape:l({},u.shape,{values:[\"linear\",\"spline\"]}),smoothing:u.smoothing,editType:\"calc\"},connectgaps:n.connectgaps,fill:l({},n.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:n.fillcolor,marker:l({symbol:c.symbol,opacity:c.opacity,maxdisplayed:c.maxdisplayed,size:c.size,sizeref:c.sizeref,sizemin:c.sizemin,sizemode:c.sizemode,line:l({width:f.width,editType:\"calc\"},s(\"marker.line\")),gradient:c.gradient,editType:\"calc\"},s(\"marker\")),textfont:n.textfont,textposition:n.textposition,selected:n.selected,unselected:n.unselected,hoverinfo:l({},i.hoverinfo,{flags:[\"a\",\"b\",\"text\",\"name\"]}),hoveron:n.hoveron,hovertemplate:a()}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1222:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=t(\"../carpet/lookup_carpetid\");e.exports=function(t,e){var r=e._carpetTrace=l(t,e);if(r&&r.visible&&\"legendonly\"!==r.visible){var c;e.xaxis=r.xaxis,e.yaxis=r.yaxis;var u,f,h=e._length,p=new Array(h),d=!1;for(c=0;c<h;c++)if(u=e.a[c],f=e.b[c],n(u)&&n(f)){var g=r.ab2xy(+u,+f,!0),m=r.isVisible(+u,+f);m||(d=!0),p[c]={x:g[0],y:g[1],a:u,b:f,vis:m}}else p[c]={x:!1,y:!1};return e._needsCull=d,p[0].carpet=r,p[0].trace=e,s(e,h),i(t,e),a(p,e),o(p,e),p}}},{\"../carpet/lookup_carpetid\":981,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1223:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}p(\"carpet\"),e.xaxis=\"x\",e.yaxis=\"y\";var d=p(\"a\"),g=p(\"b\"),m=Math.min(d.length,g.length);if(m){e._length=m,p(\"text\"),p(\"texttemplate\"),p(\"hovertext\"),p(\"mode\",m<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&c(t,e,h,p);var v=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"marker.maxdisplayed\"),v.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||v.push(\"fills\"),\"fills\"!==p(\"hoveron\",v.join(\"+\")||\"points\")&&p(\"hovertemplate\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1221}],1224:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){var a=n[i];return t.a=a.a,t.b=a.b,t.y=a.y,t}},{}],1225:[function(t,e,r){\"use strict\";e.exports=function(t,e){var r={},n=e._carpet,i=n.ab2ij([t.a,t.b]),a=Math.floor(i[0]),o=i[0]-a,s=Math.floor(i[1]),l=i[1]-s,c=n.evalxy([],a,s,o,l);return r.yLabel=c[1].toFixed(3),r}},{}],1226:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\"),i=t(\"../../lib\").fillText;e.exports=function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index){var l=1-s.y0/t.ya._length,c=t.xa._length,u=c*l/2,f=c-u;return s.x0=Math.max(Math.min(s.x0,f),u),s.x1=Math.max(Math.min(s.x1,f),u),o}var h=s.cd[s.index];s.a=h.a,s.b=h.b,s.xLabelVal=void 0,s.yLabelVal=void 0;var p=s.trace,d=p._carpet,g=p._module.formatLabels(h,p);s.yLabel=g.yLabel,delete s.text;var m=[];if(!p.hovertemplate){var v=(h.hi||p.hoverinfo).split(\"+\");-1!==v.indexOf(\"all\")&&(v=[\"a\",\"b\",\"text\"]),-1!==v.indexOf(\"a\")&&y(d.aaxis,h.a),-1!==v.indexOf(\"b\")&&y(d.baxis,h.b),m.push(\"y: \"+s.yLabel),-1!==v.indexOf(\"text\")&&i(h,p,m),s.extraText=m.join(\"<br>\")}return o}function y(t,e){var r;r=t.labelprefix&&t.labelprefix.length>0?t.labelprefix.replace(/ = $/,\"\"):t._hovertitle,m.push(r+\": \"+e.toFixed(3)+t.labelsuffix)}}},{\"../../lib\":778,\"../scatter/hover\":1198}],1227:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scattercarpet\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"svg\",\"carpet\",\"symbols\",\"showLegend\",\"carpetDependent\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1221,\"./calc\":1222,\"./defaults\":1223,\"./event_data\":1224,\"./format_labels\":1225,\"./hover\":1226,\"./plot\":1228}],1228:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../../components/drawing\");e.exports=function(t,e,r,o){var s,l,c,u=r[0][0].carpet,f={xaxis:i.getFromId(t,u.xaxis||\"x\"),yaxis:i.getFromId(t,u.yaxis||\"y\"),plot:e.plot};for(n(t,f,r,o),s=0;s<r.length;s++)l=r[s][0].trace,c=o.selectAll(\"g.trace\"+l.uid+\" .js-line\"),a.setClipUrl(c,r[s][0].carpet._clipPathId,t)}},{\"../../components/drawing\":665,\"../../plots/cartesian/axes\":828,\"../scatter/plot\":1208}],1229:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=t(\"../../plot_api/edit_types\").overrideAll,f=a.marker,h=a.line,p=f.line;e.exports=u({lon:{valType:\"data_array\"},lat:{valType:\"data_array\"},locations:{valType:\"data_array\"},locationmode:{valType:\"enumerated\",values:[\"ISO-3\",\"USA-states\",\"country names\",\"geojson-id\"],dflt:\"ISO-3\"},geojson:{valType:\"any\",editType:\"calc\"},featureidkey:{valType:\"string\",editType:\"calc\",dflt:\"id\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"location\",\"text\"]}),hovertext:c({},a.hovertext,{}),textfont:a.textfont,textposition:a.textposition,line:{color:h.color,width:h.width,dash:l},connectgaps:a.connectgaps,marker:c({symbol:f.symbol,opacity:f.opacity,size:f.size,sizeref:f.sizeref,sizemin:f.sizemin,sizemode:f.sizemode,colorbar:f.colorbar,line:c({width:p.width},s(\"marker.line\")),gradient:f.gradient},s(\"marker\")),fill:{valType:\"enumerated\",values:[\"none\",\"toself\"],dflt:\"none\"},fillcolor:a.fillcolor,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"lon\",\"lat\",\"location\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1230:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/colorscale_calc\"),o=t(\"../scatter/arrays_to_calcdata\"),s=t(\"../scatter/calc_selection\"),l=t(\"../../lib\")._;function c(t){return t&&\"string\"==typeof t}e.exports=function(t,e){var r,u=Array.isArray(e.locations),f=u?e.locations.length:e._length,h=new Array(f);r=e.geojson?function(t){return c(t)||n(t)}:c;for(var p=0;p<f;p++){var d=h[p]={};if(u){var g=e.locations[p];d.loc=r(g)?g:null}else{var m=e.lon[p],v=e.lat[p];n(m)&&n(v)?d.lonlat=[+m,+v]:d.lonlat=[i,i]}}return o(h,e),a(t,e),s(h,e),f&&(h[0].t={labels:{lat:l(t,\"lat:\")+\" \",lon:l(t,\"lon:\")+\" \"}}),h}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1231:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}var h,p=f(\"locations\");if(p&&p.length){var d,g=f(\"geojson\");(\"string\"==typeof g&&\"\"!==g||n.isPlainObject(g))&&(d=\"geojson-id\"),\"geojson-id\"===f(\"locationmode\",d)&&f(\"featureidkey\"),h=p.length}else{var m=f(\"lon\")||[],v=f(\"lat\")||[];h=Math.min(m.length,v.length)}h?(e._length=h,f(\"text\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),i.hasLines(e)&&(o(t,e,r,u,f),f(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,u,f,{gradient:!0}),i.hasText(e)&&(f(\"texttemplate\"),s(t,e,u,f)),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)):e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1229}],1232:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){t.lon=e.lon,t.lat=e.lat,t.location=e.loc?e.loc:null;var a=n[i];return a.fIn&&a.fIn.properties&&(t.properties=a.fIn.properties),t}},{}],1233:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.geo]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1234:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../scatter/get_trace_color\"),o=t(\"../../lib\").fillText,s=t(\"./attributes\");e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=h.projection.isLonLatOverEdges,d=h.project;if(n.getClosest(l,(function(t){var n=t.lonlat;if(n[0]===i)return 1/0;if(p(n))return 1/0;var a=d(n),o=d([e,r]),s=Math.abs(a[0]-o[0]),l=Math.abs(a[1]-o[1]),c=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(s*s+l*l)-c,1-3/c)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[u.c2p(m),f.c2p(m)],y=g.mrc||1;t.x0=v[0]-y,t.x1=v[0]+y,t.y0=v[1]-y,t.y1=v[1]+y,t.loc=g.loc,t.lon=m[0],t.lat=m[1];var x={};x[c.geo]={_subplot:h};var b=c._module.formatLabels(g,c,x);return t.lonLabel=b.lonLabel,t.latLabel=b.latLabel,t.color=a(c,g),t.extraText=function(t,e,r,n){if(t.hovertemplate)return;var i=e.hi||t.hoverinfo,a=\"all\"===i?s.hoverinfo.flags:i.split(\"+\"),l=-1!==a.indexOf(\"location\")&&Array.isArray(t.locations),c=-1!==a.indexOf(\"lon\"),u=-1!==a.indexOf(\"lat\"),f=-1!==a.indexOf(\"text\"),h=[];function p(t){return t+\"\\xb0\"}l?h.push(e.loc):c&&u?h.push(\"(\"+p(r.lonLabel)+\", \"+p(r.latLabel)+\")\"):c?h.push(n.lon+p(r.lonLabel)):u&&h.push(n.lat+p(r.latLabel));f&&o(e,t,h);return h.join(\"<br>\")}(c,g,t,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197,\"./attributes\":1229}],1235:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),calcGeoJSON:t(\"./plot\").calcGeoJSON,plot:t(\"./plot\").plot,style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),moduleType:\"trace\",name:\"scattergeo\",basePlotModule:t(\"../../plots/geo\"),categories:[\"geo\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/geo\":860,\"../scatter/marker_colorbar\":1205,\"../scatter/style\":1211,\"./attributes\":1229,\"./calc\":1230,\"./defaults\":1231,\"./event_data\":1232,\"./format_labels\":1233,\"./hover\":1234,\"./plot\":1236,\"./select\":1237,\"./style\":1238}],1236:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../lib/topojson_utils\").getTopojsonFeatures,o=t(\"../../lib/geojson_utils\"),s=t(\"../../lib/geo_location_utils\"),l=t(\"../../plots/cartesian/autorange\").findExtremes,c=t(\"../../constants/numerical\").BADNUM,u=t(\"../scatter/calc\").calcMarkerSize,f=t(\"../scatter/subtypes\"),h=t(\"./style\");e.exports={calcGeoJSON:function(t,e){var r,n,i=t[0].trace,o=e[i.geo],f=o._subplot,h=i._length;if(Array.isArray(i.locations)){var p=i.locationmode,d=\"geojson-id\"===p?s.extractTraceFeature(t):a(i,f.topojson);for(r=0;r<h;r++){n=t[r];var g=\"geojson-id\"===p?n.fOut:s.locationToFeature(p,n.loc,d);n.lonlat=g?g.properties.ct:[c,c]}}var m,v,y={padded:!0};if(\"geojson\"===o.fitbounds&&\"geojson-id\"===i.locationmode){var x=s.computeBbox(s.getTraceGeojson(i));m=[x[0],x[2]],v=[x[1],x[3]]}else{for(m=new Array(h),v=new Array(h),r=0;r<h;r++)n=t[r],m[r]=n.lonlat[0],v[r]=n.lonlat[1];y.ppad=u(i,h)}i._extremes.lon=l(o.lonaxis._ax,m,y),i._extremes.lat=l(o.lataxis._ax,v,y)},plot:function(t,e,r){var a=e.layers.frontplot.select(\".scatterlayer\"),s=i.makeTraceGroups(a,r,\"trace scattergeo\");function l(t,e){t.lonlat[0]===c&&n.select(e).remove()}s.selectAll(\"*\").remove(),s.each((function(e){var r=n.select(this),a=e[0].trace;if(f.hasLines(a)||\"none\"!==a.fill){var s=o.calcTraceToLineCoords(e),c=\"none\"!==a.fill?o.makePolygon(s):o.makeLine(s);r.selectAll(\"path.js-line\").data([{geojson:c,trace:a}]).enter().append(\"path\").classed(\"js-line\",!0).style(\"stroke-miterlimit\",2)}f.hasMarkers(a)&&r.selectAll(\"path.point\").data(i.identity).enter().append(\"path\").classed(\"point\",!0).each((function(t){l(t,this)})),f.hasText(a)&&r.selectAll(\"g\").data(i.identity).enter().append(\"g\").append(\"text\").each((function(t){l(t,this)})),h(t,e)}))}}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geo_location_utils\":771,\"../../lib/geojson_utils\":772,\"../../lib/topojson_utils\":806,\"../../plots/cartesian/autorange\":827,\"../scatter/calc\":1188,\"../scatter/subtypes\":1212,\"./style\":1238,d3:169}],1237:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,a,o,s,l,c=t.cd,u=t.xaxis,f=t.yaxis,h=[],p=c[0].trace;if(!n.hasMarkers(p)&&!n.hasText(p))return[];if(!1===e)for(l=0;l<c.length;l++)c[l].selected=0;else for(l=0;l<c.length;l++)(a=(r=c[l]).lonlat)[0]!==i&&(o=u.c2p(a),s=f.c2p(a),e.contains([o,s],null,l,t)?(h.push({pointNumber:l,lon:a[0],lat:a[1]}),r.selected=1):r.selected=0);return h}},{\"../../constants/numerical\":753,\"../scatter/subtypes\":1212}],1238:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../scatter/style\"),s=o.stylePoints,l=o.styleText;e.exports=function(t,e){e&&function(t,e){var r=e[0].trace,o=e[0].node3;o.style(\"opacity\",e[0].trace.opacity),s(o,r,t),l(o,r,t),o.selectAll(\"path.js-line\").style(\"fill\",\"none\").each((function(t){var e=n.select(this),r=t.trace,o=r.line||{};e.call(a.stroke,o.color).call(i.dashLine,o.dash||\"\",o.width||0),\"none\"!==r.fill&&e.call(a.fill,r.fillcolor)}))}(t,e)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../scatter/style\":1211,d3:169}],1239:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../scatter/attributes\"),a=t(\"../../components/colorscale/attributes\"),o=t(\"../../lib/extend\").extendFlat,s=t(\"../../plot_api/edit_types\").overrideAll,l=t(\"./constants\").DASHES,c=i.line,u=i.marker,f=u.line,h=e.exports=s({x:i.x,x0:i.x0,dx:i.dx,y:i.y,y0:i.y0,dy:i.dy,xperiod:i.xperiod,yperiod:i.yperiod,xperiod0:i.xperiod0,yperiod0:i.yperiod0,xperiodalignment:i.xperiodalignment,yperiodalignment:i.yperiodalignment,text:i.text,hovertext:i.hovertext,textposition:i.textposition,textfont:i.textfont,mode:{valType:\"flaglist\",flags:[\"lines\",\"markers\",\"text\"],extras:[\"none\"]},line:{color:c.color,width:c.width,shape:{valType:\"enumerated\",values:[\"linear\",\"hv\",\"vh\",\"hvh\",\"vhv\"],dflt:\"linear\",editType:\"plot\"},dash:{valType:\"enumerated\",values:Object.keys(l),dflt:\"solid\"}},marker:o({},a(\"marker\"),{symbol:u.symbol,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:o({},a(\"marker.line\"),{width:f.width})}),connectgaps:i.connectgaps,fill:o({},i.fill,{dflt:\"none\"}),fillcolor:i.fillcolor,selected:{marker:i.selected.marker,textfont:i.selected.textfont},unselected:{marker:i.unselected.marker,textfont:i.unselected.textfont},opacity:n.opacity},\"calc\",\"nested\");h.x.editType=h.y.editType=h.x0.editType=h.y0.editType=\"calc+clearAxisTypes\",h.hovertemplate=i.hovertemplate,h.texttemplate=i.texttemplate},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../scatter/attributes\":1187,\"./constants\":1241}],1240:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../plots/cartesian/autorange\").findExtremes,s=t(\"../../plots/cartesian/align_period\"),l=t(\"../scatter/calc\"),c=l.calcMarkerSize,u=l.calcAxisExpansion,f=l.setFirstScatter,h=t(\"../scatter/colorscale_calc\"),p=t(\"./convert\"),d=t(\"./scene_update\"),g=t(\"../../constants/numerical\").BADNUM,m=t(\"./constants\").TOO_MANY_POINTS;function v(t,e,r){var n=t._extremes[e._id],i=o(e,r._bnds,{padded:!0});n.min=n.min.concat(i.min),n.max=n.max.concat(i.max)}e.exports=function(t,e){var r,o,l,y=t._fullLayout,x=a.getFromId(t,e.xaxis),b=a.getFromId(t,e.yaxis),_=y._plots[e.xaxis+e.yaxis],w=e._length,T=w>=m,k=2*w,M={},A=x.makeCalcdata(e,\"x\"),S=b.makeCalcdata(e,\"y\"),E=s(e,x,\"x\",A),C=s(e,b,\"y\",S);e._x=E,e._y=C,e.xperiodalignment&&(e._origX=A),e.yperiodalignment&&(e._origY=S);var L=new Array(k);for(r=0;r<w;r++)o=E[r],l=C[r],L[2*r]=o===g?NaN:o,L[2*r+1]=l===g?NaN:l;if(\"log\"===x.type)for(r=0;r<k;r+=2)L[r]=x.c2l(L[r]);if(\"log\"===b.type)for(r=1;r<k;r+=2)L[r]=b.c2l(L[r]);if(T&&\"log\"!==x.type&&\"log\"!==b.type)M.tree=n(L);else{var I=M.ids=new Array(w);for(r=0;r<w;r++)I[r]=r}h(t,e);var P,z=function(t,e,r,n,a,o){var s=p.style(t,r);s.marker&&(s.marker.positions=n);s.line&&n.length>1&&i.extendFlat(s.line,p.linePositions(t,r,n));if(s.errorX||s.errorY){var l=p.errorBarPositions(t,r,n,a,o);s.errorX&&i.extendFlat(s.errorX,l.x),s.errorY&&i.extendFlat(s.errorY,l.y)}s.text&&(i.extendFlat(s.text,{positions:n},p.textPosition(t,r,s.text,s.marker)),i.extendFlat(s.textSel,{positions:n},p.textPosition(t,r,s.text,s.markerSel)),i.extendFlat(s.textUnsel,{positions:n},p.textPosition(t,r,s.text,s.markerUnsel)));return s}(t,0,e,L,E,C),O=d(t,_);return f(y,e),T?z.marker&&(P=2*(z.marker.sizeAvg||Math.max(z.marker.size,3))):P=c(e,w),u(t,e,x,b,E,C,P),z.errorX&&v(e,x,z.errorX),z.errorY&&v(e,b,z.errorY),z.fill&&!O.fill2d&&(O.fill2d=!0),z.marker&&!O.scatter2d&&(O.scatter2d=!0),z.line&&!O.line2d&&(O.line2d=!0),!z.errorX&&!z.errorY||O.error2d||(O.error2d=!0),z.text&&!O.glText&&(O.glText=!0),z.marker&&(z.marker.snap=w),O.lineOptions.push(z.line),O.errorXOptions.push(z.errorX),O.errorYOptions.push(z.errorY),O.fillOptions.push(z.fill),O.markerOptions.push(z.marker),O.markerSelectedOptions.push(z.markerSel),O.markerUnselectedOptions.push(z.markerUnsel),O.textOptions.push(z.text),O.textSelectedOptions.push(z.textSel),O.textUnselectedOptions.push(z.textUnsel),O.selectBatch.push([]),O.unselectBatch.push([]),M._scene=O,M.index=O.count,M.x=E,M.y=C,M.positions=L,O.count++,[{x:!1,y:!1,t:M,trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/autorange\":827,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"./constants\":1241,\"./convert\":1242,\"./scene_update\":1250,\"@plotly/point-cluster\":57}],1241:[function(t,e,r){\"use strict\";e.exports={TOO_MANY_POINTS:1e5,SYMBOL_SDF_SIZE:200,SYMBOL_SIZE:20,SYMBOL_STROKE:1,DOT_RE:/-dot/,OPEN_RE:/-open/,DASHES:{solid:[1],dot:[1,1],dash:[4,1],longdash:[8,1],dashdot:[4,1,1,1],longdashdot:[8,1,1,1]}}},{}],1242:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"svg-path-sdf\"),a=t(\"color-normalize\"),o=t(\"../../registry\"),s=t(\"../../lib\"),l=t(\"../../components/drawing\"),c=t(\"../../plots/cartesian/axis_ids\"),u=t(\"../../lib/gl_format_color\").formatColor,f=t(\"../scatter/subtypes\"),h=t(\"../scatter/make_bubble_size_func\"),p=t(\"./helpers\"),d=t(\"./constants\"),g=t(\"../../constants/interactions\").DESELECTDIM,m={start:1,left:1,end:-1,right:-1,middle:0,center:0,bottom:1,top:-1},v=t(\"../../components/fx/helpers\").appendArrayPointValue;function y(t,e){var r,i=t._fullLayout,a=e._length,o=e.textfont,l=e.textposition,c=Array.isArray(l)?l:[l],u=o.color,f=o.size,h=o.family,p={},d=e.texttemplate;if(d){p.text=[];var g=i._d3locale,m=Array.isArray(d),y=m?Math.min(d.length,a):a,x=m?function(t){return d[t]}:function(){return d};for(r=0;r<y;r++){var b={i:r},_=e._module.formatLabels(b,e,i),w={};v(w,e,r);var T=e._meta||{};p.text.push(s.texttemplateString(x(r),_,g,w,b,T))}}else Array.isArray(e.text)&&e.text.length<a?p.text=e.text.slice():p.text=e.text;if(Array.isArray(p.text))for(r=p.text.length;r<a;r++)p.text[r]=\"\";for(p.opacity=e.opacity,p.font={},p.align=[],p.baseline=[],r=0;r<c.length;r++){var k=c[r].split(/\\s+/);switch(k[1]){case\"left\":p.align.push(\"right\");break;case\"right\":p.align.push(\"left\");break;default:p.align.push(k[1])}switch(k[0]){case\"top\":p.baseline.push(\"bottom\");break;case\"bottom\":p.baseline.push(\"top\");break;default:p.baseline.push(k[0])}}if(Array.isArray(u))for(p.color=new Array(a),r=0;r<a;r++)p.color[r]=u[r];else p.color=u;if(s.isArrayOrTypedArray(f)||Array.isArray(h))for(p.font=new Array(a),r=0;r<a;r++){var M=p.font[r]={};M.size=s.isTypedArray(f)?f[r]:Array.isArray(f)?n(f[r])?f[r]:0:f,M.family=Array.isArray(h)?h[r]:h}else p.font={size:f,family:h};return p}function x(t){var e,r,n=t._length,i=t.marker,o={},l=s.isArrayOrTypedArray(i.symbol),c=s.isArrayOrTypedArray(i.color),f=s.isArrayOrTypedArray(i.line.color),d=s.isArrayOrTypedArray(i.opacity),g=s.isArrayOrTypedArray(i.size),m=s.isArrayOrTypedArray(i.line.width);if(l||(r=p.isOpenSymbol(i.symbol)),l||c||f||d){o.colors=new Array(n),o.borderColors=new Array(n);var v=u(i,i.opacity,n),y=u(i.line,i.opacity,n);if(!Array.isArray(y[0])){var x=y;for(y=Array(n),e=0;e<n;e++)y[e]=x}if(!Array.isArray(v[0])){var b=v;for(v=Array(n),e=0;e<n;e++)v[e]=b}for(o.colors=v,o.borderColors=y,e=0;e<n;e++){if(l){var _=i.symbol[e];r=p.isOpenSymbol(_)}r&&(y[e]=v[e].slice(),v[e]=v[e].slice(),v[e][3]=0)}o.opacity=t.opacity}else r?(o.color=a(i.color,\"uint8\"),o.color[3]=0,o.borderColor=a(i.color,\"uint8\")):(o.color=a(i.color,\"uint8\"),o.borderColor=a(i.line.color,\"uint8\")),o.opacity=t.opacity*i.opacity;if(l)for(o.markers=new Array(n),e=0;e<n;e++)o.markers[e]=E(i.symbol[e]);else o.marker=E(i.symbol);var w,T=h(t);if(g||m){var k,M=o.sizes=new Array(n),A=o.borderSizes=new Array(n),S=0;if(g){for(e=0;e<n;e++)M[e]=T(i.size[e]),S+=M[e];k=S/n}else for(w=T(i.size),e=0;e<n;e++)M[e]=w;if(m)for(e=0;e<n;e++)A[e]=i.line.width[e]/2;else for(w=i.line.width/2,e=0;e<n;e++)A[e]=w;o.sizeAvg=k}else o.size=T(i&&i.size||10),o.borderSizes=T(i.line.width);return o}function b(t,e){var r=t.marker,n={};return e?(e.marker&&e.marker.symbol?n=x(s.extendFlat({},r,e.marker)):e.marker&&(e.marker.size&&(n.size=e.marker.size/2),e.marker.color&&(n.colors=e.marker.color),void 0!==e.marker.opacity&&(n.opacity=e.marker.opacity)),n):n}function _(t,e,r){var n={};if(!r)return n;if(r.textfont){var i={opacity:1,text:e.text,texttemplate:e.texttemplate,textposition:e.textposition,textfont:s.extendFlat({},e.textfont)};r.textfont&&s.extendFlat(i.textfont,r.textfont),n=y(t,i)}return n}function w(t,e){var r={capSize:2*e.width,lineWidth:e.thickness,color:e.color};return e.copy_ystyle&&(r=t.error_y),r}var T=d.SYMBOL_SDF_SIZE,k=d.SYMBOL_SIZE,M=d.SYMBOL_STROKE,A={},S=l.symbolFuncs[0](.05*k);function E(t){if(\"circle\"===t)return null;var e,r,n=l.symbolNumber(t),a=l.symbolFuncs[n%100],o=!!l.symbolNoDot[n%100],s=!!l.symbolNoFill[n%100],c=p.isDotSymbol(t);return A[t]?A[t]:(e=c&&!o?a(1.1*k)+S:a(k),r=i(e,{w:T,h:T,viewBox:[-k,-k,k,k],stroke:s?M:-M}),A[t]=r,r||null)}e.exports={style:function(t,e){var r,n={marker:void 0,markerSel:void 0,markerUnsel:void 0,line:void 0,fill:void 0,errorX:void 0,errorY:void 0,text:void 0,textSel:void 0,textUnsel:void 0};if(!0!==e.visible)return n;if(f.hasText(e)&&(n.text=y(t,e),n.textSel=_(t,e,e.selected),n.textUnsel=_(t,e,e.unselected)),f.hasMarkers(e)&&(n.marker=x(e),n.markerSel=b(e,e.selected),n.markerUnsel=b(e,e.unselected),!e.unselected&&s.isArrayOrTypedArray(e.marker.opacity))){var i=e.marker.opacity;for(n.markerUnsel.opacity=new Array(i.length),r=0;r<i.length;r++)n.markerUnsel.opacity[r]=g*i[r]}if(f.hasLines(e)){n.line={overlay:!0,thickness:e.line.width,color:e.line.color,opacity:e.opacity};var a=(d.DASHES[e.line.dash]||[1]).slice();for(r=0;r<a.length;++r)a[r]*=e.line.width;n.line.dashes=a}return e.error_x&&e.error_x.visible&&(n.errorX=w(e,e.error_x)),e.error_y&&e.error_y.visible&&(n.errorY=w(e,e.error_y)),e.fill&&\"none\"!==e.fill&&(n.fill={closed:!0,fill:e.fillcolor,thickness:0}),n},markerStyle:x,markerSelection:b,linePositions:function(t,e,r){var n,i,a=r.length,o=a/2;if(f.hasLines(e)&&o)if(\"hv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i+2],r[2*i+1]));n.push(r[a-2],r[a-1])}else if(\"hvh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var s=(r[2*i]+r[2*i+2])/2;n.push(r[2*i],r[2*i+1],s,r[2*i+1],s,r[2*i+3])}n.push(r[a-2],r[a-1])}else if(\"vhv\"===e.line.shape){for(n=[],i=0;i<o-1;i++)if(isNaN(r[2*i])||isNaN(r[2*i+1])||isNaN(r[2*i+2])||isNaN(r[2*i+3]))isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+1]),n.push(NaN,NaN);else{var l=(r[2*i+1]+r[2*i+3])/2;n.push(r[2*i],r[2*i+1],r[2*i],l,r[2*i+2],l)}n.push(r[a-2],r[a-1])}else if(\"vh\"===e.line.shape){for(n=[],i=0;i<o-1;i++)isNaN(r[2*i])||isNaN(r[2*i+1])?n.push(NaN,NaN,NaN,NaN):(n.push(r[2*i],r[2*i+1]),isNaN(r[2*i+2])||isNaN(r[2*i+3])?n.push(NaN,NaN):n.push(r[2*i],r[2*i+3]));n.push(r[a-2],r[a-1])}else n=r;var c=!1;for(i=0;i<n.length;i++)if(isNaN(n[i])){c=!0;break}var u=c||n.length>d.TOO_MANY_POINTS||f.hasMarkers(e)?\"rect\":\"round\";if(c&&e.connectgaps){var h=n[0],p=n[1];for(i=0;i<n.length;i+=2)isNaN(n[i])||isNaN(n[i+1])?(n[i]=h,n[i+1]=p):(h=n[i],p=n[i+1])}return{join:u,positions:n}},errorBarPositions:function(t,e,r,i,a){var s=o.getComponentMethod(\"errorbars\",\"makeComputeError\"),l=c.getFromId(t,e.xaxis),u=c.getFromId(t,e.yaxis),f=r.length/2,h={};function p(t,i){var a=i._id.charAt(0),o=e[\"error_\"+a];if(o&&o.visible&&(\"linear\"===i.type||\"log\"===i.type)){for(var l=s(o),c={x:0,y:1}[a],u={x:[0,1,2,3],y:[2,3,0,1]}[a],p=new Float64Array(4*f),d=1/0,g=-1/0,m=0,v=0;m<f;m++,v+=4){var y=t[m];if(n(y)){var x=r[2*m+c],b=l(y,m),_=b[0],w=b[1];if(n(_)&&n(w)){var T=y-_,k=y+w;p[v+u[0]]=x-i.c2l(T),p[v+u[1]]=i.c2l(k)-x,p[v+u[2]]=0,p[v+u[3]]=0,d=Math.min(d,y-_),g=Math.max(g,y+w)}}}h[a]={positions:r,errors:p,_bnds:[d,g]}}}return p(i,l),p(a,u),h},textPosition:function(t,e,r,n){var i,a=e._length,o={};if(f.hasMarkers(e)){var s=r.font,l=r.align,c=r.baseline;for(o.offset=new Array(a),i=0;i<a;i++){var u=n.sizes?n.sizes[i]:n.size,h=Array.isArray(s)?s[i].size:s.size,p=Array.isArray(l)?l.length>1?l[i]:l[0]:l,d=Array.isArray(c)?c.length>1?c[i]:c[0]:c,g=m[p],v=m[d],y=u?u/.8+1:0,x=-v*y-.5*v;o.offset[i]=[g*y/h,x/h]}}return o}}},{\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/interactions\":752,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/cartesian/axis_ids\":831,\"../../registry\":911,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"./constants\":1241,\"./helpers\":1246,\"color-normalize\":125,\"fast-isnumeric\":241,\"svg-path-sdf\":574}],1243:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../registry\"),a=t(\"./helpers\"),o=t(\"./attributes\"),s=t(\"../scatter/constants\"),l=t(\"../scatter/subtypes\"),c=t(\"../scatter/xy_defaults\"),u=t(\"../scatter/period_defaults\"),f=t(\"../scatter/marker_defaults\"),h=t(\"../scatter/line_defaults\"),p=t(\"../scatter/fillcolor_defaults\"),d=t(\"../scatter/text_defaults\");e.exports=function(t,e,r,g){function m(r,i){return n.coerce(t,e,o,r,i)}var v=!!t.marker&&a.isOpenSymbol(t.marker.symbol),y=l.isBubble(t),x=c(t,e,g,m);if(x){u(t,e,g,m);var b=x<s.PTS_LINESONLY?\"lines+markers\":\"lines\";m(\"text\"),m(\"hovertext\"),m(\"hovertemplate\"),m(\"mode\",b),l.hasLines(e)&&(m(\"connectgaps\"),h(t,e,r,g,m),m(\"line.shape\")),l.hasMarkers(e)&&(f(t,e,r,g,m),m(\"marker.line.width\",v||y?1:0)),l.hasText(e)&&(m(\"texttemplate\"),d(t,e,g,m));var _=(e.line||{}).color,w=(e.marker||{}).color;m(\"fill\"),\"none\"!==e.fill&&p(t,e,r,m);var T=i.getComponentMethod(\"errorbars\",\"supplyDefaults\");T(t,e,_||w||r,{axis:\"y\"}),T(t,e,_||w||r,{axis:\"x\",inherit:\"y\"}),n.coerceSelectionMarkerOpacity(e,m)}else e.visible=!1}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/period_defaults\":1207,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatter/xy_defaults\":1214,\"./attributes\":1239,\"./helpers\":1246}],1244:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../constants/interactions\").DESELECTDIM;e.exports={styleTextSelection:function(t){var e,r,o=t[0],s=o.trace,l=o.t,c=l._scene,u=l.index,f=c.selectBatch[u],h=c.unselectBatch[u],p=c.textOptions[u],d=c.textSelectedOptions[u]||{},g=c.textUnselectedOptions[u]||{},m=n.extendFlat({},p);if(f.length||h.length){var v=d.color,y=g.color,x=p.color,b=Array.isArray(x);for(m.color=new Array(s._length),e=0;e<f.length;e++)r=f[e],m.color[r]=v||(b?x[r]:x);for(e=0;e<h.length;e++){r=h[e];var _=b?x[r]:x;m.color[r]=y||(v?_:i.addOpacity(_,a))}}c.glText[u].update(m)}}},{\"../../components/color\":643,\"../../constants/interactions\":752,\"../../lib\":778}],1245:[function(t,e,r){\"use strict\";var n=t(\"../scatter/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"x\"in t||(t.x=e._x[i]),\"y\"in t||(t.y=e._y[i]),n(t,e,r)}},{\"../scatter/format_labels\":1196}],1246:[function(t,e,r){\"use strict\";var n=t(\"./constants\");r.isOpenSymbol=function(t){return\"string\"==typeof t?n.OPEN_RE.test(t):t%200>100},r.isDotSymbol=function(t){return\"string\"==typeof t?n.DOT_RE.test(t):t>200}},{\"./constants\":1241}],1247:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\");function o(t,e,r,o){var s=t.xa,l=t.ya,c=t.distance,u=t.dxy,f=t.index,h={pointNumber:f,x:e[f],y:r[f]};h.tx=Array.isArray(o.text)?o.text[f]:o.text,h.htx=Array.isArray(o.hovertext)?o.hovertext[f]:o.hovertext,h.data=Array.isArray(o.customdata)?o.customdata[f]:o.customdata,h.tp=Array.isArray(o.textposition)?o.textposition[f]:o.textposition;var p=o.textfont;p&&(h.ts=i.isArrayOrTypedArray(p.size)?p.size[f]:p.size,h.tc=Array.isArray(p.color)?p.color[f]:p.color,h.tf=Array.isArray(p.family)?p.family[f]:p.family);var d=o.marker;d&&(h.ms=i.isArrayOrTypedArray(d.size)?d.size[f]:d.size,h.mo=i.isArrayOrTypedArray(d.opacity)?d.opacity[f]:d.opacity,h.mx=i.isArrayOrTypedArray(d.symbol)?d.symbol[f]:d.symbol,h.mc=i.isArrayOrTypedArray(d.color)?d.color[f]:d.color);var g=d&&d.line;g&&(h.mlc=Array.isArray(g.color)?g.color[f]:g.color,h.mlw=i.isArrayOrTypedArray(g.width)?g.width[f]:g.width);var m=d&&d.gradient;m&&\"none\"!==m.type&&(h.mgt=Array.isArray(m.type)?m.type[f]:m.type,h.mgc=Array.isArray(m.color)?m.color[f]:m.color);var v=s.c2p(h.x,!0),y=l.c2p(h.y,!0),x=h.mrc||1,b=o.hoverlabel;b&&(h.hbg=Array.isArray(b.bgcolor)?b.bgcolor[f]:b.bgcolor,h.hbc=Array.isArray(b.bordercolor)?b.bordercolor[f]:b.bordercolor,h.hts=i.isArrayOrTypedArray(b.font.size)?b.font.size[f]:b.font.size,h.htc=Array.isArray(b.font.color)?b.font.color[f]:b.font.color,h.htf=Array.isArray(b.font.family)?b.font.family[f]:b.font.family,h.hnl=i.isArrayOrTypedArray(b.namelength)?b.namelength[f]:b.namelength);var _=o.hoverinfo;_&&(h.hi=Array.isArray(_)?_[f]:_);var w=o.hovertemplate;w&&(h.ht=Array.isArray(w)?w[f]:w);var T={};T[t.index]=h;var k=o._origX,M=o._origY,A=i.extendFlat({},t,{color:a(o,h),x0:v-x,x1:v+x,xLabelVal:k?k[f]:h.x,y0:y-x,y1:y+x,yLabelVal:M?M[f]:h.y,cd:T,distance:c,spikeDistance:u,hovertemplate:h.ht});return h.htx?A.text=h.htx:h.tx?A.text=h.tx:o.text&&(A.text=o.text),i.fillText(h,o,A),n.getComponentMethod(\"errorbars\",\"hoverInfo\")(h,o,A),A}e.exports={hoverPoints:function(t,e,r,n){var i,a,s,l,c,u,f,h,p,d=t.cd,g=d[0].t,m=d[0].trace,v=t.xa,y=t.ya,x=g.x,b=g.y,_=v.c2p(e),w=y.c2p(r),T=t.distance;if(g.tree){var k=v.p2c(_-T),M=v.p2c(_+T),A=y.p2c(w-T),S=y.p2c(w+T);i=\"x\"===n?g.tree.range(Math.min(k,M),Math.min(y._rl[0],y._rl[1]),Math.max(k,M),Math.max(y._rl[0],y._rl[1])):g.tree.range(Math.min(k,M),Math.min(A,S),Math.max(k,M),Math.max(A,S))}else i=g.ids;var E=T;if(\"x\"===n)for(c=0;c<i.length;c++)s=x[i[c]],(u=Math.abs(v.c2p(s)-_))<E&&(E=u,f=y.c2p(b[i[c]])-w,p=Math.sqrt(u*u+f*f),a=i[c]);else for(c=i.length-1;c>-1;c--)s=x[i[c]],l=b[i[c]],u=v.c2p(s)-_,f=y.c2p(l)-w,(h=Math.sqrt(u*u+f*f))<E&&(E=p=h,a=i[c]);return t.index=a,t.distance=E,t.dxy=p,void 0===a?[t]:[o(t,x,b,m)]},calcHover:o}},{\"../../lib\":778,\"../../registry\":911,\"../scatter/get_trace_color\":1197}],1248:[function(t,e,r){\"use strict\";var n=t(\"./hover\");e.exports={moduleType:\"trace\",name:\"scattergl\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"errorBarsOK\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../scatter/cross_trace_defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:n.hoverPoints,selectPoints:t(\"./select\"),meta:{}}},{\"../../plots/cartesian\":841,\"../scatter/cross_trace_defaults\":1193,\"../scatter/marker_colorbar\":1205,\"./attributes\":1239,\"./calc\":1240,\"./defaults\":1243,\"./format_labels\":1245,\"./hover\":1247,\"./plot\":1249,\"./select\":1251}],1249:[function(t,e,r){\"use strict\";var n=t(\"regl-scatter2d\"),i=t(\"regl-line2d\"),a=t(\"regl-error2d\"),o=t(\"gl-text\"),s=t(\"../../lib\"),l=t(\"../../components/dragelement/helpers\").selectMode,c=t(\"../../lib/prepare_regl\"),u=t(\"../scatter/subtypes\"),f=t(\"../scatter/link_traces\"),h=t(\"./edit_style\").styleTextSelection;function p(t,e,r){var n=t._size,i=t.width,a=t.height;return[n.l+e.domain[0]*n.w,n.b+r.domain[0]*n.h,i-n.r-(1-e.domain[1])*n.w,a-n.t-(1-r.domain[1])*n.h]}e.exports=function(t,e,r){if(r.length){var d,g,m=t._fullLayout,v=e._scene,y=e.xaxis,x=e.yaxis;if(v)if(c(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])){var b=v.count,_=m._glcanvas.data()[0].regl;if(f(t,e,r),v.dirty){if(!0===v.error2d&&(v.error2d=a(_)),!0===v.line2d&&(v.line2d=i(_)),!0===v.scatter2d&&(v.scatter2d=n(_,{constPointSize:!0})),!0===v.fill2d&&(v.fill2d=i(_)),!0===v.glText)for(v.glText=new Array(b),d=0;d<b;d++)v.glText[d]=new o(_);if(v.glText){if(b>v.glText.length){var w=b-v.glText.length;for(d=0;d<w;d++)v.glText.push(new o(_))}else if(b<v.glText.length){var T=v.glText.length-b;v.glText.splice(b,T).forEach((function(t){t.destroy()}))}for(d=0;d<b;d++)v.glText[d].update(v.textOptions[d])}if(v.line2d&&(v.line2d.update(v.lineOptions),v.lineOptions=v.lineOptions.map((function(t){if(t&&t.positions){for(var e=t.positions,r=0;r<e.length&&(isNaN(e[r])||isNaN(e[r+1]));)r+=2;for(var n=e.length-2;n>r&&(isNaN(e[n])||isNaN(e[n+1]));)n-=2;t.positions=e.slice(r,n+2)}return t})),v.line2d.update(v.lineOptions)),v.error2d){var k=(v.errorXOptions||[]).concat(v.errorYOptions||[]);v.error2d.update(k)}v.scatter2d&&v.scatter2d.update(v.markerOptions),v.fillOrder=s.repeat(null,b),v.fill2d&&(v.fillOptions=v.fillOptions.map((function(t,e){var n=r[e];if(t&&n&&n[0]&&n[0].trace){var i,a,o=n[0],s=o.trace,l=o.t,c=v.lineOptions[e],u=[];s._ownfill&&u.push(e),s._nexttrace&&u.push(e+1),u.length&&(v.fillOrder[e]=u);var f,h,p=[],d=c&&c.positions||l.positions;if(\"tozeroy\"===s.fill){for(f=0;f<d.length&&isNaN(d[f+1]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h+1]);)h-=2;0!==d[f+1]&&(p=[d[f],0]),p=p.concat(d.slice(f,h+2)),0!==d[h+1]&&(p=p.concat([d[h],0]))}else if(\"tozerox\"===s.fill){for(f=0;f<d.length&&isNaN(d[f]);)f+=2;for(h=d.length-2;h>f&&isNaN(d[h]);)h-=2;0!==d[f]&&(p=[0,d[f+1]]),p=p.concat(d.slice(f,h+2)),0!==d[h]&&(p=p.concat([0,d[h+1]]))}else if(\"toself\"===s.fill||\"tonext\"===s.fill){for(p=[],i=0,a=0;a<d.length;a+=2)(isNaN(d[a])||isNaN(d[a+1]))&&((p=p.concat(d.slice(i,a))).push(d[i],d[i+1]),i=a+2);p=p.concat(d.slice(i)),i&&p.push(d[i],d[i+1])}else{var g=s._nexttrace;if(g){var m=v.lineOptions[e+1];if(m){var y=m.positions;if(\"tonexty\"===s.fill){for(p=d.slice(),e=Math.floor(y.length/2);e--;){var x=y[2*e],b=y[2*e+1];isNaN(x)||isNaN(b)||p.push(x,b)}t.fill=g.fillcolor}}}}if(s._prevtrace&&\"tonext\"===s._prevtrace.fill){var _=v.lineOptions[e-1].positions,w=p.length/2,T=[i=w];for(a=0;a<_.length;a+=2)(isNaN(_[a])||isNaN(_[a+1]))&&(T.push(a/2+w+1),i=a+2);p=p.concat(_),t.hole=T}return t.fillmode=s.fill,t.opacity=s.opacity,t.positions=p,t}})),v.fill2d.update(v.fillOptions))}var M=m.dragmode,A=l(M),S=m.clickmode.indexOf(\"select\")>-1;for(d=0;d<b;d++){var E=r[d][0],C=E.trace,L=E.t,I=L.index,P=C._length,z=L.x,O=L.y;if(C.selectedpoints||A||S){if(A||(A=!0),C.selectedpoints){var D=v.selectBatch[I]=s.selIndices2selPoints(C),R={};for(g=0;g<D.length;g++)R[D[g]]=1;var F=[];for(g=0;g<P;g++)R[g]||F.push(g);v.unselectBatch[I]=F}var B=L.xpx=new Array(P),N=L.ypx=new Array(P);for(g=0;g<P;g++)B[g]=y.c2p(z[g]),N[g]=x.c2p(O[g])}else L.xpx=L.ypx=null}if(A){if(v.select2d||(v.select2d=n(m._glcanvas.data()[1].regl)),v.scatter2d){var j=new Array(b);for(d=0;d<b;d++)j[d]=v.selectBatch[d].length||v.unselectBatch[d].length?v.markerUnselectedOptions[d]:{};v.scatter2d.update(j)}v.select2d&&(v.select2d.update(v.markerOptions),v.select2d.update(v.markerSelectedOptions)),v.glText&&r.forEach((function(t){var e=((t||[])[0]||{}).trace||{};u.hasText(e)&&h(t)}))}else v.scatter2d&&v.scatter2d.update(v.markerOptions);var U={viewport:p(m,y,x),range:[(y._rl||y.range)[0],(x._rl||x.range)[0],(y._rl||y.range)[1],(x._rl||x.range)[1]]},V=s.repeat(U,v.count);v.fill2d&&v.fill2d.update(V),v.line2d&&v.line2d.update(V),v.error2d&&v.error2d.update(V.concat(V)),v.scatter2d&&v.scatter2d.update(V),v.select2d&&v.select2d.update(V),v.glText&&v.glText.forEach((function(t){t.update(U)}))}else v.init()}}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../lib/prepare_regl\":791,\"../scatter/link_traces\":1203,\"../scatter/subtypes\":1212,\"./edit_style\":1244,\"gl-text\":352,\"regl-error2d\":534,\"regl-line2d\":535,\"regl-scatter2d\":537}],1250:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=e._scene,i={count:0,dirty:!0,lineOptions:[],fillOptions:[],markerOptions:[],markerSelectedOptions:[],markerUnselectedOptions:[],errorXOptions:[],errorYOptions:[],textOptions:[],textSelectedOptions:[],textUnselectedOptions:[],selectBatch:[],unselectBatch:[]},a={fill2d:!1,scatter2d:!1,error2d:!1,line2d:!1,glText:!1,select2d:!1};return e._scene||((r=e._scene={}).init=function(){n.extendFlat(r,a,i)},r.init(),r.update=function(t){var e=n.repeat(t,r.count);if(r.fill2d&&r.fill2d.update(e),r.scatter2d&&r.scatter2d.update(e),r.line2d&&r.line2d.update(e),r.error2d&&r.error2d.update(e.concat(e)),r.select2d&&r.select2d.update(e),r.glText)for(var i=0;i<r.count;i++)r.glText[i].update(t)},r.draw=function(){for(var t=r.count,e=r.fill2d,i=r.error2d,a=r.line2d,o=r.scatter2d,s=r.glText,l=r.select2d,c=r.selectBatch,u=r.unselectBatch,f=0;f<t;f++){if(e&&r.fillOrder[f]&&e.draw(r.fillOrder[f]),a&&r.lineOptions[f]&&a.draw(f),i&&(r.errorXOptions[f]&&i.draw(f),r.errorYOptions[f]&&i.draw(f+t)),o&&r.markerOptions[f])if(u[f].length){var h=n.repeat([],r.count);h[f]=u[f],o.draw(h)}else c[f].length||o.draw(f);s[f]&&r.textOptions[f]&&s[f].render()}l&&l.draw(c),r.dirty=!1},r.destroy=function(){r.fill2d&&r.fill2d.destroy&&r.fill2d.destroy(),r.scatter2d&&r.scatter2d.destroy&&r.scatter2d.destroy(),r.error2d&&r.error2d.destroy&&r.error2d.destroy(),r.line2d&&r.line2d.destroy&&r.line2d.destroy(),r.select2d&&r.select2d.destroy&&r.select2d.destroy(),r.glText&&r.glText.forEach((function(t){t.destroy&&t.destroy()})),r.lineOptions=null,r.fillOptions=null,r.markerOptions=null,r.markerSelectedOptions=null,r.markerUnselectedOptions=null,r.errorXOptions=null,r.errorYOptions=null,r.textOptions=null,r.textSelectedOptions=null,r.textUnselectedOptions=null,r.selectBatch=null,r.unselectBatch=null,e._scene=null}),r.dirty||n.extendFlat(r,i),r}},{\"../../lib\":778}],1251:[function(t,e,r){\"use strict\";var n=t(\"../scatter/subtypes\"),i=t(\"./edit_style\").styleTextSelection;e.exports=function(t,e){var r=t.cd,a=[],o=r[0].trace,s=r[0].t,l=o._length,c=s.x,u=s.y,f=s._scene,h=s.index;if(!f)return a;var p=n.hasText(o),d=n.hasMarkers(o),g=!d&&!p;if(!0!==o.visible||g)return a;var m=[],v=[];if(!1!==e&&!e.degenerate)for(var y=0;y<l;y++)e.contains([s.xpx[y],s.ypx[y]],!1,y,t)?(m.push(y),a.push({pointNumber:y,x:c[y],y:u[y]})):v.push(y);if(d){var x=f.scatter2d;if(m.length||v.length){if(!f.selectBatch[h].length&&!f.unselectBatch[h].length){var b=new Array(f.count);b[h]=f.markerUnselectedOptions[h],x.update.apply(x,b)}}else{var _=new Array(f.count);_[h]=f.markerOptions[h],x.update.apply(x,_)}}return f.selectBatch[h]=m,f.unselectBatch[h]=v,p&&i(r),a}},{\"../scatter/subtypes\":1212,\"./edit_style\":1244}],1252:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scattergeo/attributes\"),o=t(\"../scatter/attributes\"),s=t(\"../../plots/mapbox/layout_attributes\"),l=t(\"../../plots/attributes\"),c=t(\"../../components/colorscale/attributes\"),u=t(\"../../lib/extend\").extendFlat,f=t(\"../../plot_api/edit_types\").overrideAll,h=a.line,p=a.marker;e.exports=f({lon:a.lon,lat:a.lat,mode:u({},o.mode,{dflt:\"markers\"}),text:u({},o.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"lat\",\"lon\",\"text\"]}),hovertext:u({},o.hovertext,{}),line:{color:h.color,width:h.width},connectgaps:o.connectgaps,marker:u({symbol:{valType:\"string\",dflt:\"circle\",arrayOk:!0},angle:{valType:\"number\",dflt:\"auto\",arrayOk:!0},allowoverlap:{valType:\"boolean\",dflt:!1},opacity:p.opacity,size:p.size,sizeref:p.sizeref,sizemin:p.sizemin,sizemode:p.sizemode},c(\"marker\")),fill:a.fill,fillcolor:o.fillcolor,textfont:s.layers.symbol.textfont,textposition:s.layers.symbol.textposition,below:{valType:\"string\"},selected:{marker:o.selected.marker},unselected:{marker:o.unselected.marker},hoverinfo:u({},l.hoverinfo,{flags:[\"lon\",\"lat\",\"text\",\"name\"]}),hovertemplate:n()},\"calc\",\"nested\")},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/mapbox/layout_attributes\":887,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergeo/attributes\":1229}],1253:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../lib\"),a=t(\"../../constants/numerical\").BADNUM,o=t(\"../../lib/geojson_utils\"),s=t(\"../../components/colorscale\"),l=t(\"../../components/drawing\"),c=t(\"../scatter/make_bubble_size_func\"),u=t(\"../scatter/subtypes\"),f=t(\"../../plots/mapbox/convert_text_opts\"),h=t(\"../../components/fx/helpers\").appendArrayPointValue,p=t(\"../../lib/svg_text_utils\").NEWLINES,d=t(\"../../lib/svg_text_utils\").BR_TAG_ALL;function g(){return{geojson:o.makeBlank(),layout:{visibility:\"none\"},paint:{}}}function m(t,e){return i.isArrayOrTypedArray(t)?e?function(e){return n(t[e])?+t[e]:0}:function(e){return t[e]}:t?function(){return t}:v}function v(){return\"\"}function y(t){return t[0]===a}e.exports=function(t,e){var r,a=e[0].trace,x=!0===a.visible&&0!==a._length,b=\"none\"!==a.fill,_=u.hasLines(a),w=u.hasMarkers(a),T=u.hasText(a),k=w&&\"circle\"===a.marker.symbol,M=w&&\"circle\"!==a.marker.symbol,A=g(),S=g(),E=g(),C=g(),L={fill:A,line:S,circle:E,symbol:C};if(!x)return L;if((b||_)&&(r=o.calcTraceToLineCoords(e)),b&&(A.geojson=o.makePolygon(r),A.layout.visibility=\"visible\",i.extendFlat(A.paint,{\"fill-color\":a.fillcolor})),_&&(S.geojson=o.makeLine(r),S.layout.visibility=\"visible\",i.extendFlat(S.paint,{\"line-width\":a.line.width,\"line-color\":a.line.color,\"line-opacity\":a.opacity})),k){var I=function(t){var e,r,a,o,u=t[0].trace,f=u.marker,h=u.selectedpoints,p=i.isArrayOrTypedArray(f.color),d=i.isArrayOrTypedArray(f.size),g=i.isArrayOrTypedArray(f.opacity);function m(t){return u.opacity*t}p&&(r=s.hasColorscale(u,\"marker\")?s.makeColorScaleFuncFromTrace(f):i.identity);d&&(a=c(u));g&&(o=function(t){return m(n(t)?+i.constrain(t,0,1):0)});var v,x=[];for(e=0;e<t.length;e++){var b=t[e],_=b.lonlat;if(!y(_)){var w={};r&&(w.mcc=b.mcc=r(b.mc)),a&&(w.mrc=b.mrc=a(b.ms)),o&&(w.mo=o(b.mo)),h&&(w.selected=b.selected||0),x.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:_},properties:w})}}if(h)for(v=l.makeSelectedPointStyleFns(u),e=0;e<x.length;e++){var T=x[e].properties;v.selectedOpacityFn&&(T.mo=m(v.selectedOpacityFn(T))),v.selectedColorFn&&(T.mcc=v.selectedColorFn(T)),v.selectedSizeFn&&(T.mrc=v.selectedSizeFn(T))}return{geojson:{type:\"FeatureCollection\",features:x},mcc:p||v&&v.selectedColorFn?{type:\"identity\",property:\"mcc\"}:f.color,mrc:d||v&&v.selectedSizeFn?{type:\"identity\",property:\"mrc\"}:(k=f.size,k/2),mo:g||v&&v.selectedOpacityFn?{type:\"identity\",property:\"mo\"}:m(f.opacity)};var k}(e);E.geojson=I.geojson,E.layout.visibility=\"visible\",i.extendFlat(E.paint,{\"circle-color\":I.mcc,\"circle-radius\":I.mrc,\"circle-opacity\":I.mo})}if((M||T)&&(C.geojson=function(t,e){for(var r=e._fullLayout,n=t[0].trace,a=n.marker||{},o=a.symbol,s=a.angle,l=\"circle\"!==o?m(o):v,c=\"auto\"!==s?m(s,!0):v,f=u.hasText(n)?m(n.text):v,g=[],x=0;x<t.length;x++){var b=t[x];if(!y(b.lonlat)){var _,w=n.texttemplate;if(w){var T=Array.isArray(w)?w[x]||\"\":w,k=n._module.formatLabels(b,n,r),M={};h(M,n,b.i);var A=n._meta||{};_=i.texttemplateString(T,k,r._d3locale,M,b,A)}else _=f(x);_&&(_=_.replace(p,\"\").replace(d,\"\\n\")),g.push({type:\"Feature\",geometry:{type:\"Point\",coordinates:b.lonlat},properties:{symbol:l(x),angle:c(x),text:_}})}}return{type:\"FeatureCollection\",features:g}}(e,t),i.extendFlat(C.layout,{visibility:\"visible\",\"icon-image\":\"{symbol}-15\",\"text-field\":\"{text}\"}),M&&(i.extendFlat(C.layout,{\"icon-size\":a.marker.size/10}),\"angle\"in a.marker&&\"auto\"!==a.marker.angle&&i.extendFlat(C.layout,{\"icon-rotate\":{type:\"identity\",property:\"angle\"},\"icon-rotation-alignment\":\"map\"}),C.layout[\"icon-allow-overlap\"]=a.marker.allowoverlap,i.extendFlat(C.paint,{\"icon-opacity\":a.opacity*a.marker.opacity,\"icon-color\":a.marker.color})),T)){var P=(a.marker||{}).size,z=f(a.textposition,P);i.extendFlat(C.layout,{\"text-size\":a.textfont.size,\"text-anchor\":z.anchor,\"text-offset\":z.offset}),i.extendFlat(C.paint,{\"text-color\":a.textfont.color,\"text-opacity\":a.opacity})}return L}},{\"../../components/colorscale\":655,\"../../components/drawing\":665,\"../../components/fx/helpers\":679,\"../../constants/numerical\":753,\"../../lib\":778,\"../../lib/geojson_utils\":772,\"../../lib/svg_text_utils\":803,\"../../plots/mapbox/convert_text_opts\":884,\"../scatter/make_bubble_size_func\":1204,\"../scatter/subtypes\":1212,\"fast-isnumeric\":241}],1254:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/text_defaults\"),l=t(\"../scatter/fillcolor_defaults\"),c=t(\"./attributes\");e.exports=function(t,e,r,u){function f(r,i){return n.coerce(t,e,c,r,i)}if(function(t,e,r){var n=r(\"lon\")||[],i=r(\"lat\")||[],a=Math.min(n.length,i.length);return e._length=a,a}(0,e,f)){if(f(\"text\"),f(\"texttemplate\"),f(\"hovertext\"),f(\"hovertemplate\"),f(\"mode\"),f(\"below\"),i.hasLines(e)&&(o(t,e,r,u,f,{noDash:!0}),f(\"connectgaps\")),i.hasMarkers(e)){a(t,e,r,u,f,{noLine:!0}),f(\"marker.allowoverlap\"),f(\"marker.angle\");var h=e.marker;\"circle\"!==h.symbol&&(n.isArrayOrTypedArray(h.size)&&(h.size=h.size[0]),n.isArrayOrTypedArray(h.color)&&(h.color=h.color[0]))}i.hasText(e)&&s(t,e,u,f,{noSelect:!0}),f(\"fill\"),\"none\"!==e.fill&&l(t,e,r,f),n.coerceSelectionMarkerOpacity(e,f)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1252}],1255:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.lon=e.lon,t.lat=e.lat,t}},{}],1256:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot.mockAxis,o=t.lonlat;return i.lonLabel=n.tickText(a,a.c2l(o[0]),!0).text,i.latLabel=n.tickText(a,a.c2l(o[1]),!0).text,i}},{\"../../plots/cartesian/axes\":828}],1257:[function(t,e,r){\"use strict\";var n=t(\"../../components/fx\"),i=t(\"../../lib\"),a=t(\"../scatter/get_trace_color\"),o=i.fillText,s=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){var l=t.cd,c=l[0].trace,u=t.xa,f=t.ya,h=t.subplot,p=360*(e>=0?Math.floor((e+180)/360):Math.ceil((e-180)/360)),d=e-p;if(n.getClosest(l,(function(t){var e=t.lonlat;if(e[0]===s)return 1/0;var n=i.modHalf(e[0],360),a=e[1],o=h.project([n,a]),l=o.x-u.c2p([d,a]),c=o.y-f.c2p([n,r]),p=Math.max(3,t.mrc||0);return Math.max(Math.sqrt(l*l+c*c)-p,1-3/p)}),t),!1!==t.index){var g=l[t.index],m=g.lonlat,v=[i.modHalf(m[0],360)+p,m[1]],y=u.c2p(v),x=f.c2p(v),b=g.mrc||1;t.x0=y-b,t.x1=y+b,t.y0=x-b,t.y1=x+b;var _={};_[c.subplot]={_subplot:h};var w=c._module.formatLabels(g,c,_);return t.lonLabel=w.lonLabel,t.latLabel=w.latLabel,t.color=a(c,g),t.extraText=function(t,e,r){if(t.hovertemplate)return;var n=(e.hi||t.hoverinfo).split(\"+\"),i=-1!==n.indexOf(\"all\"),a=-1!==n.indexOf(\"lon\"),s=-1!==n.indexOf(\"lat\"),l=e.lonlat,c=[];function u(t){return t+\"\\xb0\"}i||a&&s?c.push(\"(\"+u(l[0])+\", \"+u(l[1])+\")\"):a?c.push(r.lon+u(l[0])):s&&c.push(r.lat+u(l[1]));(i||-1!==n.indexOf(\"text\"))&&o(e,t,c);return c.join(\"<br>\")}(c,g,l[0].t.labels),t.hovertemplate=c.hovertemplate,[t]}}},{\"../../components/fx\":683,\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/get_trace_color\":1197}],1258:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"../scattergeo/calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"./select\"),styleOnSelect:function(t,e){e&&e[0].trace._glTrace.update(e)},moduleType:\"trace\",name:\"scattermapbox\",basePlotModule:t(\"../../plots/mapbox\"),categories:[\"mapbox\",\"gl\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/mapbox\":885,\"../scatter/marker_colorbar\":1205,\"../scattergeo/calc\":1230,\"./attributes\":1252,\"./defaults\":1254,\"./event_data\":1255,\"./format_labels\":1256,\"./hover\":1257,\"./plot\":1259,\"./select\":1260}],1259:[function(t,e,r){\"use strict\";var n=t(\"./convert\"),i=t(\"../../plots/mapbox/constants\").traceLayerPrefix,a=[\"fill\",\"line\",\"circle\",\"symbol\"];function o(t,e){this.type=\"scattermapbox\",this.subplot=t,this.uid=e,this.sourceIds={fill:\"source-\"+e+\"-fill\",line:\"source-\"+e+\"-line\",circle:\"source-\"+e+\"-circle\",symbol:\"source-\"+e+\"-symbol\"},this.layerIds={fill:i+e+\"-fill\",line:i+e+\"-line\",circle:i+e+\"-circle\",symbol:i+e+\"-symbol\"},this.below=null}var s=o.prototype;s.addSource=function(t,e){this.subplot.map.addSource(this.sourceIds[t],{type:\"geojson\",data:e.geojson})},s.setSourceData=function(t,e){this.subplot.map.getSource(this.sourceIds[t]).setData(e.geojson)},s.addLayer=function(t,e,r){this.subplot.addLayer({type:t,id:this.layerIds[t],source:this.sourceIds[t],layout:e.layout,paint:e.paint},r)},s.update=function(t){var e,r,i,o=this.subplot,s=o.map,l=n(o.gd,t),c=o.belowLookup[\"trace-\"+this.uid];if(c!==this.below){for(e=a.length-1;e>=0;e--)r=a[e],s.removeLayer(this.layerIds[r]);for(e=0;e<a.length;e++)i=l[r=a[e]],this.addLayer(r,i,c);this.below=c}for(e=0;e<a.length;e++)i=l[r=a[e]],o.setOptions(this.layerIds[r],\"setLayoutProperty\",i.layout),\"visible\"===i.layout.visibility&&(this.setSourceData(r,i),o.setOptions(this.layerIds[r],\"setPaintProperty\",i.paint));t[0].trace._glTrace=this},s.dispose=function(){for(var t=this.subplot.map,e=a.length-1;e>=0;e--){var r=a[e];t.removeLayer(this.layerIds[r]),t.removeSource(this.sourceIds[r])}},e.exports=function(t,e){for(var r=e[0].trace,i=new o(t,r.uid),s=n(t.gd,e),l=i.below=t.belowLookup[\"trace-\"+r.uid],c=0;c<a.length;c++){var u=a[c],f=s[u];i.addSource(u,f),i.addLayer(u,f,l)}return e[0].trace._glTrace=i,i}},{\"../../plots/mapbox/constants\":883,\"./convert\":1253}],1260:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e){var r,o=t.cd,s=t.xaxis,l=t.yaxis,c=[],u=o[0].trace;if(!i.hasMarkers(u))return[];if(!1===e)for(r=0;r<o.length;r++)o[r].selected=0;else for(r=0;r<o.length;r++){var f=o[r],h=f.lonlat;if(h[0]!==a){var p=[n.modHalf(h[0],360),h[1]],d=[s.c2p(p),l.c2p(p)];e.contains(d,null,r,t)?(c.push({pointNumber:r,lon:h[0],lat:h[1]}),f.selected=1):f.selected=0}}return c}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../scatter/subtypes\":1212}],1261:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../lib/extend\").extendFlat,o=t(\"../scatter/attributes\"),s=t(\"../../plots/attributes\"),l=o.line;e.exports={mode:o.mode,r:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},theta:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},r0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dr:{valType:\"number\",dflt:1,editType:\"calc\"},theta0:{valType:\"any\",dflt:0,editType:\"calc+clearAxisTypes\"},dtheta:{valType:\"number\",editType:\"calc\"},thetaunit:{valType:\"enumerated\",values:[\"radians\",\"degrees\",\"gradians\"],dflt:\"degrees\",editType:\"calc+clearAxisTypes\"},text:o.text,texttemplate:i({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:o.hovertext,line:{color:l.color,width:l.width,dash:l.dash,shape:a({},l.shape,{values:[\"linear\",\"spline\"]}),smoothing:l.smoothing,editType:\"calc\"},connectgaps:o.connectgaps,marker:o.marker,cliponaxis:a({},o.cliponaxis,{dflt:!1}),textposition:o.textposition,textfont:o.textfont,fill:a({},o.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:o.fillcolor,hoverinfo:a({},s.hoverinfo,{flags:[\"r\",\"theta\",\"text\",\"name\"]}),hoveron:o.hoveron,hovertemplate:n(),selected:o.selected,unselected:o.unselected}},{\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1262:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../../constants/numerical\").BADNUM,a=t(\"../../plots/cartesian/axes\"),o=t(\"../scatter/colorscale_calc\"),s=t(\"../scatter/arrays_to_calcdata\"),l=t(\"../scatter/calc_selection\"),c=t(\"../scatter/calc\").calcMarkerSize;e.exports=function(t,e){for(var r=t._fullLayout,u=e.subplot,f=r[u].radialaxis,h=r[u].angularaxis,p=f.makeCalcdata(e,\"r\"),d=h.makeCalcdata(e,\"theta\"),g=e._length,m=new Array(g),v=0;v<g;v++){var y=p[v],x=d[v],b=m[v]={};n(y)&&n(x)?(b.r=y,b.theta=x):b.r=i}var _=c(e,g);return e._extremes.x=a.findExtremes(f,p,{ppad:_}),o(t,e),s(m,e),l(m,e),m}},{\"../../constants/numerical\":753,\"../../plots/cartesian/axes\":828,\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1263:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatter/marker_defaults\"),o=t(\"../scatter/line_defaults\"),s=t(\"../scatter/line_shape_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");function h(t,e,r,n){var i,a=n(\"r\"),o=n(\"theta\");if(a)o?i=Math.min(a.length,o.length):(i=a.length,n(\"theta0\"),n(\"dtheta\"));else{if(!o)return 0;i=e.theta.length,n(\"r0\"),n(\"dr\")}return e._length=i,i}e.exports={handleRThetaDefaults:h,supplyDefaults:function(t,e,r,p){function d(r,i){return n.coerce(t,e,f,r,i)}var g=h(t,e,p,d);if(g){d(\"thetaunit\"),d(\"mode\",g<u?\"lines+markers\":\"lines\"),d(\"text\"),d(\"hovertext\"),\"fills\"!==e.hoveron&&d(\"hovertemplate\"),i.hasLines(e)&&(o(t,e,r,p,d),s(t,e,d),d(\"connectgaps\")),i.hasMarkers(e)&&a(t,e,r,p,d,{gradient:!0}),i.hasText(e)&&(d(\"texttemplate\"),l(t,e,p,d));var m=[];(i.hasMarkers(e)||i.hasText(e))&&(d(\"cliponaxis\"),d(\"marker.maxdisplayed\"),m.push(\"points\")),d(\"fill\"),\"none\"!==e.fill&&(c(t,e,r,d),i.hasLines(e)||s(t,e,d)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||m.push(\"fills\"),d(\"hoveron\",m.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,d)}else e.visible=!1}}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1261}],1264:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var a,o,s={},l=r[e.subplot]._subplot;l?(a=l.radialAxis,o=l.angularAxis):(a=(l=r[e.subplot]).radialaxis,o=l.angularaxis);var c=a.c2l(t.r);s.rLabel=i.tickText(a,c,!0).text;var u=\"degrees\"===o.thetaunit?n.rad2deg(t.theta):t.theta;return s.thetaLabel=i.tickText(o,u,!0).text,s}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828}],1265:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");function i(t,e,r,n){var i=r.radialAxis,a=r.angularAxis;i._hovertitle=\"r\",a._hovertitle=\"\\u03b8\";var o={};o[e.subplot]={_subplot:r};var s=e._module.formatLabels(t,e,o);n.rLabel=s.rLabel,n.thetaLabel=s.thetaLabel;var l=t.hi||e.hoverinfo,c=[];function u(t,e){c.push(t._hovertitle+\": \"+e)}if(!e.hovertemplate){var f=l.split(\"+\");-1!==f.indexOf(\"all\")&&(f=[\"r\",\"theta\",\"text\"]),-1!==f.indexOf(\"r\")&&u(i,n.rLabel),-1!==f.indexOf(\"theta\")&&u(a,n.thetaLabel),-1!==f.indexOf(\"text\")&&n.text&&(c.push(n.text),delete n.text),n.extraText=c.join(\"<br>\")}}e.exports={hoverPoints:function(t,e,r,a){var o=n(t,e,r,a);if(o&&!1!==o[0].index){var s=o[0];if(void 0===s.index)return o;var l=t.subplot,c=s.cd[s.index],u=s.trace;if(l.isPtInside(c))return s.xLabelVal=void 0,s.yLabelVal=void 0,i(c,u,l,s),s.hovertemplate=u.hovertemplate,o}},makeHoverPointText:i}},{\"../scatter/hover\":1198}],1266:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolar\",basePlotModule:t(\"../../plots/polar\"),categories:[\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scatter/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1261,\"./calc\":1262,\"./defaults\":1263,\"./format_labels\":1264,\"./hover\":1265,\"./plot\":1267}],1267:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\"),i=t(\"../../constants/numerical\").BADNUM;e.exports=function(t,e,r){for(var a=e.layers.frontplot.select(\"g.scatterlayer\"),o={xaxis:e.xaxis,yaxis:e.yaxis,plot:e.framework,layerClipId:e._hasClipOnAxisFalse?e.clipIds.forTraces:null},s=e.radialAxis,l=e.angularAxis,c=0;c<r.length;c++)for(var u=r[c],f=0;f<u.length;f++){var h=u[f],p=h.r;if(p===i)h.x=h.y=i;else{var d=s.c2g(p),g=l.c2g(h.theta);h.x=d*Math.cos(g),h.y=d*Math.sin(g)}}n(t,o,r,a)}},{\"../../constants/numerical\":753,\"../scatter/plot\":1208}],1268:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/attributes\"),i=t(\"../scattergl/attributes\"),a=t(\"../../plots/template_attributes\").texttemplateAttrs;e.exports={mode:n.mode,r:n.r,theta:n.theta,r0:n.r0,dr:n.dr,theta0:n.theta0,dtheta:n.dtheta,thetaunit:n.thetaunit,text:n.text,texttemplate:a({editType:\"plot\"},{keys:[\"r\",\"theta\",\"text\"]}),hovertext:n.hovertext,hovertemplate:n.hovertemplate,line:i.line,connectgaps:i.connectgaps,marker:i.marker,fill:i.fill,fillcolor:i.fillcolor,textposition:i.textposition,textfont:i.textfont,hoverinfo:n.hoverinfo,selected:n.selected,unselected:n.unselected}},{\"../../plots/template_attributes\":906,\"../scattergl/attributes\":1239,\"../scatterpolar/attributes\":1261}],1269:[function(t,e,r){\"use strict\";var n=t(\"../scatter/colorscale_calc\"),i=t(\"../scatter/calc\").calcMarkerSize,a=t(\"../scattergl/convert\"),o=t(\"../../plots/cartesian/axes\"),s=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r=t._fullLayout,l=e.subplot,c=r[l].radialaxis,u=r[l].angularaxis,f=e._r=c.makeCalcdata(e,\"r\"),h=e._theta=u.makeCalcdata(e,\"theta\"),p=e._length,d={};p<f.length&&(f=f.slice(0,p)),p<h.length&&(h=h.slice(0,p)),d.r=f,d.theta=h,n(t,e);var g,m=d.opts=a.style(t,e);return p<s?g=i(e,p):m.marker&&(g=2*(m.marker.sizeAvg||Math.max(m.marker.size,3))),e._extremes.x=o.findExtremes(c,f,{ppad:g}),[{x:!1,y:!1,t:d,trace:e}]}},{\"../../plots/cartesian/axes\":828,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242}],1270:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"../scatterpolar/defaults\").handleRThetaDefaults,o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/text_defaults\"),c=t(\"../scatter/fillcolor_defaults\"),u=t(\"../scatter/constants\").PTS_LINESONLY,f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d=a(t,e,h,p);d?(p(\"thetaunit\"),p(\"mode\",d<u?\"lines+markers\":\"lines\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),i.hasLines(e)&&(s(t,e,r,h,p),p(\"connectgaps\")),i.hasMarkers(e)&&o(t,e,r,h,p),i.hasText(e)&&(p(\"texttemplate\"),l(t,e,h,p)),p(\"fill\"),\"none\"!==e.fill&&c(t,e,r,p),n.coerceSelectionMarkerOpacity(e,p)):e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"../scatterpolar/defaults\":1263,\"./attributes\":1268}],1271:[function(t,e,r){\"use strict\";var n=t(\"../scatterpolar/format_labels\");e.exports=function(t,e,r){var i=t.i;return\"r\"in t||(t.r=e._r[i]),\"theta\"in t||(t.theta=e._theta[i]),n(t,e,r)}},{\"../scatterpolar/format_labels\":1264}],1272:[function(t,e,r){\"use strict\";var n=t(\"../scattergl/hover\"),i=t(\"../scatterpolar/hover\").makeHoverPointText;e.exports={hoverPoints:function(t,e,r,a){var o=t.cd[0].t,s=o.r,l=o.theta,c=n.hoverPoints(t,e,r,a);if(c&&!1!==c[0].index){var u=c[0];if(void 0===u.index)return c;var f=t.subplot,h=u.cd[u.index],p=u.trace;if(h.r=s[u.index],h.theta=l[u.index],f.isPtInside(h))return u.xLabelVal=void 0,u.yLabelVal=void 0,i(h,p,f,u),c}}}},{\"../scattergl/hover\":1247,\"../scatterpolar/hover\":1265}],1273:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"scatterpolargl\",basePlotModule:t(\"../../plots/polar\"),categories:[\"gl\",\"regl\",\"polar\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"../scattergl/select\"),meta:{}}},{\"../../plots/polar\":894,\"../scatter/marker_colorbar\":1205,\"../scattergl/select\":1251,\"./attributes\":1268,\"./calc\":1269,\"./defaults\":1270,\"./format_labels\":1271,\"./hover\":1272,\"./plot\":1274}],1274:[function(t,e,r){\"use strict\";var n=t(\"@plotly/point-cluster\"),i=t(\"fast-isnumeric\"),a=t(\"../scattergl/plot\"),o=t(\"../scattergl/scene_update\"),s=t(\"../scattergl/convert\"),l=t(\"../../lib\"),c=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e,r){if(r.length){var u=e.radialAxis,f=e.angularAxis,h=o(t,e);return r.forEach((function(r){if(r&&r[0]&&r[0].trace){var a,o=r[0],p=o.trace,d=o.t,g=p._length,m=d.r,v=d.theta,y=d.opts,x=m.slice(),b=v.slice();for(a=0;a<m.length;a++)e.isPtInside({r:m[a],theta:v[a]})||(x[a]=NaN,b[a]=NaN);var _=new Array(2*g),w=Array(g),T=Array(g);for(a=0;a<g;a++){var k,M,A=x[a];if(i(A)){var S=u.c2g(A),E=f.c2g(b[a],p.thetaunit);k=S*Math.cos(E),M=S*Math.sin(E)}else k=M=NaN;w[a]=_[2*a]=k,T[a]=_[2*a+1]=M}d.tree=n(_),y.marker&&g>=c&&(y.marker.cluster=d.tree),y.marker&&(y.markerSel.positions=y.markerUnsel.positions=y.marker.positions=_),y.line&&_.length>1&&l.extendFlat(y.line,s.linePositions(t,p,_)),y.text&&(l.extendFlat(y.text,{positions:_},s.textPosition(t,p,y.text,y.marker)),l.extendFlat(y.textSel,{positions:_},s.textPosition(t,p,y.text,y.markerSel)),l.extendFlat(y.textUnsel,{positions:_},s.textPosition(t,p,y.text,y.markerUnsel))),y.fill&&!h.fill2d&&(h.fill2d=!0),y.marker&&!h.scatter2d&&(h.scatter2d=!0),y.line&&!h.line2d&&(h.line2d=!0),y.text&&!h.glText&&(h.glText=!0),h.lineOptions.push(y.line),h.fillOptions.push(y.fill),h.markerOptions.push(y.marker),h.markerSelectedOptions.push(y.markerSel),h.markerUnselectedOptions.push(y.markerUnsel),h.textOptions.push(y.text),h.textSelectedOptions.push(y.textSel),h.textUnselectedOptions.push(y.textUnsel),h.selectBatch.push([]),h.unselectBatch.push([]),d.x=w,d.y=T,d.rawx=w,d.rawy=T,d.r=m,d.theta=v,d.positions=_,d._scene=h,d.index=h.count,h.count++}})),a(t,e,r)}}},{\"../../lib\":778,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"../scattergl/plot\":1249,\"../scattergl/scene_update\":1250,\"@plotly/point-cluster\":57,\"fast-isnumeric\":241}],1275:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../scatter/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../components/colorscale/attributes\"),l=t(\"../../components/drawing/attributes\").dash,c=t(\"../../lib/extend\").extendFlat,u=a.marker,f=a.line,h=u.line;e.exports={a:{valType:\"data_array\",editType:\"calc\"},b:{valType:\"data_array\",editType:\"calc\"},c:{valType:\"data_array\",editType:\"calc\"},sum:{valType:\"number\",dflt:0,min:0,editType:\"calc\"},mode:c({},a.mode,{dflt:\"markers\"}),text:c({},a.text,{}),texttemplate:i({editType:\"plot\"},{keys:[\"a\",\"b\",\"c\",\"text\"]}),hovertext:c({},a.hovertext,{}),line:{color:f.color,width:f.width,dash:l,shape:c({},f.shape,{values:[\"linear\",\"spline\"]}),smoothing:f.smoothing,editType:\"calc\"},connectgaps:a.connectgaps,cliponaxis:a.cliponaxis,fill:c({},a.fill,{values:[\"none\",\"toself\",\"tonext\"],dflt:\"none\"}),fillcolor:a.fillcolor,marker:c({symbol:u.symbol,opacity:u.opacity,maxdisplayed:u.maxdisplayed,size:u.size,sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,line:c({width:h.width,editType:\"calc\"},s(\"marker.line\")),gradient:u.gradient,editType:\"calc\"},s(\"marker\")),textfont:a.textfont,textposition:a.textposition,selected:a.selected,unselected:a.unselected,hoverinfo:c({},o.hoverinfo,{flags:[\"a\",\"b\",\"c\",\"text\",\"name\"]}),hoveron:a.hoveron,hovertemplate:n()}},{\"../../components/colorscale/attributes\":650,\"../../components/drawing/attributes\":664,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187}],1276:[function(t,e,r){\"use strict\";var n=t(\"fast-isnumeric\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scatter/arrays_to_calcdata\"),o=t(\"../scatter/calc_selection\"),s=t(\"../scatter/calc\").calcMarkerSize,l=[\"a\",\"b\",\"c\"],c={a:[\"b\",\"c\"],b:[\"a\",\"c\"],c:[\"a\",\"b\"]};e.exports=function(t,e){var r,u,f,h,p,d,g=t._fullLayout[e.subplot].sum,m=e.sum||g,v={a:e.a,b:e.b,c:e.c};for(r=0;r<l.length;r++)if(!v[f=l[r]]){for(p=v[c[f][0]],d=v[c[f][1]],h=new Array(p.length),u=0;u<p.length;u++)h[u]=m-p[u]-d[u];v[f]=h}var y,x,b,_,w,T,k=e._length,M=new Array(k);for(r=0;r<k;r++)y=v.a[r],x=v.b[r],b=v.c[r],n(y)&&n(x)&&n(b)?(1!==(_=g/((y=+y)+(x=+x)+(b=+b)))&&(y*=_,x*=_,b*=_),T=y,w=b-x,M[r]={x:w,y:T,a:y,b:x,c:b}):M[r]={x:!1,y:!1};return s(e,k),i(t,e),a(M,e),o(M,e),M}},{\"../scatter/arrays_to_calcdata\":1186,\"../scatter/calc\":1188,\"../scatter/calc_selection\":1189,\"../scatter/colorscale_calc\":1190,\"fast-isnumeric\":241}],1277:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/constants\"),a=t(\"../scatter/subtypes\"),o=t(\"../scatter/marker_defaults\"),s=t(\"../scatter/line_defaults\"),l=t(\"../scatter/line_shape_defaults\"),c=t(\"../scatter/text_defaults\"),u=t(\"../scatter/fillcolor_defaults\"),f=t(\"./attributes\");e.exports=function(t,e,r,h){function p(r,i){return n.coerce(t,e,f,r,i)}var d,g=p(\"a\"),m=p(\"b\"),v=p(\"c\");if(g?(d=g.length,m?(d=Math.min(d,m.length),v&&(d=Math.min(d,v.length))):d=v?Math.min(d,v.length):0):m&&v&&(d=Math.min(m.length,v.length)),d){e._length=d,p(\"sum\"),p(\"text\"),p(\"hovertext\"),\"fills\"!==e.hoveron&&p(\"hovertemplate\"),p(\"mode\",d<i.PTS_LINESONLY?\"lines+markers\":\"lines\"),a.hasLines(e)&&(s(t,e,r,h,p),l(t,e,p),p(\"connectgaps\")),a.hasMarkers(e)&&o(t,e,r,h,p,{gradient:!0}),a.hasText(e)&&(p(\"texttemplate\"),c(t,e,h,p));var y=[];(a.hasMarkers(e)||a.hasText(e))&&(p(\"cliponaxis\"),p(\"marker.maxdisplayed\"),y.push(\"points\")),p(\"fill\"),\"none\"!==e.fill&&(u(t,e,r,p),a.hasLines(e)||l(t,e,p)),\"tonext\"!==e.fill&&\"toself\"!==e.fill||y.push(\"fills\"),p(\"hoveron\",y.join(\"+\")||\"points\"),n.coerceSelectionMarkerOpacity(e,p)}else e.visible=!1}},{\"../../lib\":778,\"../scatter/constants\":1191,\"../scatter/fillcolor_defaults\":1195,\"../scatter/line_defaults\":1200,\"../scatter/line_shape_defaults\":1202,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scatter/text_defaults\":1213,\"./attributes\":1275}],1278:[function(t,e,r){\"use strict\";e.exports=function(t,e,r,n,i){if(e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),n[i]){var a=n[i];t.a=a.a,t.b=a.b,t.c=a.c}else t.a=e.a,t.b=e.b,t.c=e.c;return t}},{}],1279:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\");e.exports=function(t,e,r){var i={},a=r[e.subplot]._subplot;return i.aLabel=n.tickText(a.aaxis,t.a,!0).text,i.bLabel=n.tickText(a.baxis,t.b,!0).text,i.cLabel=n.tickText(a.caxis,t.c,!0).text,i}},{\"../../plots/cartesian/axes\":828}],1280:[function(t,e,r){\"use strict\";var n=t(\"../scatter/hover\");e.exports=function(t,e,r,i){var a=n(t,e,r,i);if(a&&!1!==a[0].index){var o=a[0];if(void 0===o.index){var s=1-o.y0/t.ya._length,l=t.xa._length,c=l*s/2,u=l-c;return o.x0=Math.max(Math.min(o.x0,u),c),o.x1=Math.max(Math.min(o.x1,u),c),a}var f=o.cd[o.index],h=o.trace,p=o.subplot;o.a=f.a,o.b=f.b,o.c=f.c,o.xLabelVal=void 0,o.yLabelVal=void 0;var d={};d[h.subplot]={_subplot:p};var g=h._module.formatLabels(f,h,d);o.aLabel=g.aLabel,o.bLabel=g.bLabel,o.cLabel=g.cLabel;var m=f.hi||h.hoverinfo,v=[];if(!h.hovertemplate){var y=m.split(\"+\");-1!==y.indexOf(\"all\")&&(y=[\"a\",\"b\",\"c\"]),-1!==y.indexOf(\"a\")&&x(p.aaxis,o.aLabel),-1!==y.indexOf(\"b\")&&x(p.baxis,o.bLabel),-1!==y.indexOf(\"c\")&&x(p.caxis,o.cLabel)}return o.extraText=v.join(\"<br>\"),o.hovertemplate=h.hovertemplate,a}function x(t,e){v.push(t._hovertitle+\": \"+e)}}},{\"../scatter/hover\":1198}],1281:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),formatLabels:t(\"./format_labels\"),calc:t(\"./calc\"),plot:t(\"./plot\"),style:t(\"../scatter/style\").style,styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../scatter/select\"),eventData:t(\"./event_data\"),moduleType:\"trace\",name:\"scatterternary\",basePlotModule:t(\"../../plots/ternary\"),categories:[\"ternary\",\"symbols\",\"showLegend\",\"scatter-like\"],meta:{}}},{\"../../plots/ternary\":907,\"../scatter/marker_colorbar\":1205,\"../scatter/select\":1209,\"../scatter/style\":1211,\"./attributes\":1275,\"./calc\":1276,\"./defaults\":1277,\"./event_data\":1278,\"./format_labels\":1279,\"./hover\":1280,\"./plot\":1282}],1282:[function(t,e,r){\"use strict\";var n=t(\"../scatter/plot\");e.exports=function(t,e,r){var i=e.plotContainer;i.select(\".scatterlayer\").selectAll(\"*\").remove();var a={xaxis:e.xaxis,yaxis:e.yaxis,plot:i,layerClipId:e._hasClipOnAxisFalse?e.clipIdRelative:null},o=e.layers.frontplot.select(\"g.scatterlayer\");n(t,a,r,o)}},{\"../scatter/plot\":1208}],1283:[function(t,e,r){\"use strict\";var n=t(\"../scatter/attributes\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../scattergl/attributes\"),s=t(\"../../plots/cartesian/constants\").idRegex,l=t(\"../../plot_api/plot_template\").templatedArray,c=t(\"../../lib/extend\").extendFlat,u=n.marker,f=u.line,h=c(i(\"marker.line\",{editTypeOverride:\"calc\"}),{width:c({},f.width,{editType:\"calc\"}),editType:\"calc\"}),p=c(i(\"marker\"),{symbol:u.symbol,size:c({},u.size,{editType:\"markerSize\"}),sizeref:u.sizeref,sizemin:u.sizemin,sizemode:u.sizemode,opacity:u.opacity,colorbar:u.colorbar,line:h,editType:\"calc\"});function d(t){return{valType:\"info_array\",freeLength:!0,editType:\"calc\",items:{valType:\"subplotid\",regex:s[t],editType:\"plot\"}}}p.color.editType=p.cmin.editType=p.cmax.editType=\"style\",e.exports={dimensions:l(\"dimension\",{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},label:{valType:\"string\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},axis:{type:{valType:\"enumerated\",values:[\"linear\",\"log\",\"date\",\"category\"],editType:\"calc+clearAxisTypes\"},matches:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc+clearAxisTypes\"},editType:\"calc+clearAxisTypes\"}),text:c({},o.text,{}),hovertext:c({},o.hovertext,{}),hovertemplate:a(),marker:p,xaxes:d(\"x\"),yaxes:d(\"y\"),diagonal:{visible:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},showupperhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},showlowerhalf:{valType:\"boolean\",dflt:!0,editType:\"calc\"},selected:{marker:o.selected.marker,editType:\"calc\"},unselected:{marker:o.unselected.marker,editType:\"calc\"},opacity:o.opacity}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/plot_template\":817,\"../../plots/cartesian/constants\":834,\"../../plots/template_attributes\":906,\"../scatter/attributes\":1187,\"../scattergl/attributes\":1239}],1284:[function(t,e,r){\"use strict\";var n=t(\"regl-line2d\"),i=t(\"../../registry\"),a=t(\"../../lib/prepare_regl\"),o=t(\"../../plots/get_data\").getModuleCalcData,s=t(\"../../plots/cartesian\"),l=t(\"../../plots/cartesian/axis_ids\").getFromId,c=t(\"../../plots/cartesian/axes\").shouldShowZeroLine;function u(t,e,r){for(var n=r.matrixOptions.data.length,i=e._visibleDims,a=r.viewOpts.ranges=new Array(n),o=0;o<i.length;o++){var s=i[o],c=a[o]=new Array(4),u=l(t,e._diag[s][0]);u&&(c[0]=u.r2l(u.range[0]),c[2]=u.r2l(u.range[1]));var f=l(t,e._diag[s][1]);f&&(c[1]=f.r2l(f.range[0]),c[3]=f.r2l(f.range[1]))}r.selectBatch.length||r.unselectBatch.length?r.matrix.update({ranges:a},{ranges:a}):r.matrix.update({ranges:a})}function f(t){var e=t._fullLayout,r=e._glcanvas.data()[0].regl,i=e._splomGrid;i||(i=e._splomGrid=n(r)),i.update(function(t){var e,r=t._fullLayout,n=r._size,i=[0,0,r.width,r.height],a={};function o(t,e,r,n,o,s){var l=e[t+\"color\"],c=e[t+\"width\"],u=String(l+c);u in a?a[u].data.push(NaN,NaN,r,n,o,s):a[u]={data:[r,n,o,s],join:\"rect\",thickness:c,color:l,viewport:i,range:i,overlay:!1}}for(e in r._splomSubplots){var s,l,u=r._plots[e],f=u.xaxis,h=u.yaxis,p=f._gridVals,d=h._gridVals,g=n.b+h.domain[0]*n.h,m=-h._m,v=-m*h.r2l(h.range[0],h.calendar);if(f.showgrid)for(e=0;e<p.length;e++)s=f._offset+f.l2p(p[e].x),o(\"grid\",f,s,g,s,g+h._length);if(h.showgrid)for(e=0;e<d.length;e++)l=g+v+m*d[e].x,o(\"grid\",h,f._offset,l,f._offset+f._length,l);c(t,f,h)&&(s=f._offset+f.l2p(0),o(\"zeroline\",f,s,g,s,g+h._length)),c(t,h,f)&&(l=g+v+0,o(\"zeroline\",h,f._offset,l,f._offset+f._length,l))}var y=[];for(e in a)y.push(a[e]);return y}(t))}e.exports={name:\"splom\",attr:s.attr,attrRegex:s.attrRegex,layoutAttributes:s.layoutAttributes,supplyLayoutDefaults:s.supplyLayoutDefaults,drawFramework:s.drawFramework,plot:function(t){var e=t._fullLayout,r=i.getModule(\"splom\"),n=o(t.calcdata,r)[0];a(t,[\"ANGLE_instanced_arrays\",\"OES_element_index_uint\"])&&(e._hasOnlyLargeSploms&&f(t),r.plot(t,{},n))},drag:function(t){var e=t.calcdata,r=t._fullLayout;r._hasOnlyLargeSploms&&f(t);for(var n=0;n<e.length;n++){var i=e[n][0].trace,a=r._splomScenes[i.uid];\"splom\"===i.type&&a&&a.matrix&&u(t,i,a)}},updateGrid:f,clean:function(t,e,r,n){var i,a={};if(n._splomScenes){for(i=0;i<t.length;i++){var o=t[i];\"splom\"===o.type&&(a[o.uid]=1)}for(i=0;i<r.length;i++){var l=r[i];if(!a[l.uid]){var c=n._splomScenes[l.uid];c&&c.destroy&&c.destroy(),n._splomScenes[l.uid]=null,delete n._splomScenes[l.uid]}}}0===Object.keys(n._splomScenes||{}).length&&delete n._splomScenes,n._splomGrid&&!e._hasOnlyLargeSploms&&n._hasOnlyLargeSploms&&(n._splomGrid.destroy(),n._splomGrid=null,delete n._splomGrid),s.clean(t,e,r,n)},updateFx:s.updateFx,toSVG:s.toSVG}},{\"../../lib/prepare_regl\":791,\"../../plots/cartesian\":841,\"../../plots/cartesian/axes\":828,\"../../plots/cartesian/axis_ids\":831,\"../../plots/get_data\":865,\"../../registry\":911,\"regl-line2d\":535}],1285:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axis_ids\"),a=t(\"../scatter/calc\").calcMarkerSize,o=t(\"../scatter/calc\").calcAxisExpansion,s=t(\"../scatter/colorscale_calc\"),l=t(\"../scattergl/convert\").markerSelection,c=t(\"../scattergl/convert\").markerStyle,u=t(\"./scene_update\"),f=t(\"../../constants/numerical\").BADNUM,h=t(\"../scattergl/constants\").TOO_MANY_POINTS;e.exports=function(t,e){var r,p,d,g,m,v,y=e.dimensions,x=e._length,b={},_=b.cdata=[],w=b.data=[],T=e._visibleDims=[];function k(t,r){for(var i=t.makeCalcdata({v:r.values,vcalendar:e.calendar},\"v\"),a=0;a<i.length;a++)i[a]=i[a]===f?NaN:i[a];_.push(i),w.push(\"log\"===t.type?n.simpleMap(i,t.c2l):i)}for(r=0;r<y.length;r++)if((d=y[r]).visible){if(g=i.getFromId(t,e._diag[r][0]),m=i.getFromId(t,e._diag[r][1]),g&&m&&g.type!==m.type){n.log(\"Skipping splom dimension \"+r+\" with conflicting axis types\");continue}g?(k(g,d),m&&\"category\"===m.type&&(m._categories=g._categories.slice())):k(m,d),T.push(r)}for(s(t,e),n.extendFlat(b,c(e)),v=_.length*x>h?2*(b.sizeAvg||Math.max(b.size,3)):a(e,x),p=0;p<T.length;p++)d=y[r=T[p]],g=i.getFromId(t,e._diag[r][0])||{},m=i.getFromId(t,e._diag[r][1])||{},o(t,e,g,m,_[p],_[p],v);var M=u(t,e);return M.matrix||(M.matrix=!0),M.matrixOptions=b,M.selectedOptions=l(e,e.selected),M.unselectedOptions=l(e,e.unselected),[{x:!1,y:!1,t:{},trace:e}]}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"../scatter/calc\":1188,\"../scatter/colorscale_calc\":1190,\"../scattergl/constants\":1241,\"../scattergl/convert\":1242,\"./scene_update\":1292}],1286:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/array_container_defaults\"),a=t(\"./attributes\"),o=t(\"../scatter/subtypes\"),s=t(\"../scatter/marker_defaults\"),l=t(\"../parcoords/merge_length\"),c=t(\"../scattergl/helpers\").isOpenSymbol;function u(t,e){function r(r,i){return n.coerce(t,e,a.dimensions,r,i)}r(\"label\");var i=r(\"values\");i&&i.length?r(\"visible\"):e.visible=!1,r(\"axis.type\"),r(\"axis.matches\")}e.exports=function(t,e,r,f){function h(r,i){return n.coerce(t,e,a,r,i)}var p=i(t,e,{name:\"dimensions\",handleItemDefaults:u}),d=h(\"diagonal.visible\"),g=h(\"showupperhalf\"),m=h(\"showlowerhalf\");if(l(e,p,\"values\")&&(d||g||m)){h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),s(t,e,r,f,h);var v=c(e.marker.symbol),y=o.isBubble(e);h(\"marker.line.width\",v||y?1:0),function(t,e,r,n){var i,a,o=e.dimensions,s=o.length,l=e.showupperhalf,c=e.showlowerhalf,u=e.diagonal.visible,f=new Array(s),h=new Array(s);for(i=0;i<s;i++){var p=i?i+1:\"\";f[i]=\"x\"+p,h[i]=\"y\"+p}var d=n(\"xaxes\",f),g=n(\"yaxes\",h),m=e._diag=new Array(s);e._xaxes={},e._yaxes={};var v=[],y=[];function x(t,n,i,a){if(t){var o=t.charAt(0),s=r._splomAxes[o];if(e[\"_\"+o+\"axes\"][t]=1,a.push(t),!(t in s)){var l=s[t]={};i&&(l.label=i.label||\"\",i.visible&&i.axis&&(i.axis.type&&(l.type=i.axis.type),i.axis.matches&&(l.matches=n)))}}}var b=!u&&!c,_=!u&&!l;for(e._axesDim={},i=0;i<s;i++){var w=o[i],T=0===i,k=i===s-1,M=T&&b||k&&_?void 0:d[i],A=T&&_||k&&b?void 0:g[i];x(M,A,w,v),x(A,M,w,y),m[i]=[M,A],e._axesDim[M]=i,e._axesDim[A]=i}for(i=0;i<v.length;i++)for(a=0;a<y.length;a++){var S=v[i]+y[a];i>a&&l||i<a&&c?r._splomSubplots[S]=1:i!==a||!u&&c&&l||(r._splomSubplots[S]=1)}(!c||!u&&l&&c)&&(r._splomGridDflt.xside=\"bottom\",r._splomGridDflt.yside=\"left\")}(0,e,f,h),n.coerceSelectionMarkerOpacity(e,h)}else e.visible=!1}},{\"../../lib\":778,\"../../plots/array_container_defaults\":823,\"../parcoords/merge_length\":1158,\"../scatter/marker_defaults\":1206,\"../scatter/subtypes\":1212,\"../scattergl/helpers\":1246,\"./attributes\":1283}],1287:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/colorscale_calc\"),a=t(\"../scattergl/convert\").markerStyle;e.exports=function(t,e){var r=e.trace,o=t._fullLayout._splomScenes[r.uid];if(o){i(t,r),n.extendFlat(o.matrixOptions,a(r));var s=n.extendFlat({},o.matrixOptions,o.viewOpts);o.matrix.update(s,null)}}},{\"../../lib\":778,\"../scatter/colorscale_calc\":1190,\"../scattergl/convert\":1242}],1288:[function(t,e,r){\"use strict\";r.getDimIndex=function(t,e){for(var r=e._id,n={x:0,y:1}[r.charAt(0)],i=t._visibleDims,a=0;a<i.length;a++){var o=i[a];if(t._diag[o][n]===r)return a}return!1}},{}],1289:[function(t,e,r){\"use strict\";var n=t(\"./helpers\"),i=t(\"../scattergl/hover\").calcHover;e.exports={hoverPoints:function(t,e,r){var a=t.cd[0].trace,o=t.scene.matrixOptions.cdata,s=t.xa,l=t.ya,c=s.c2p(e),u=l.c2p(r),f=t.distance,h=n.getDimIndex(a,s),p=n.getDimIndex(a,l);if(!1===h||!1===p)return[t];for(var d,g,m=o[h],v=o[p],y=f,x=0;x<m.length;x++){var b=m[x],_=v[x],w=s.c2p(b)-c,T=l.c2p(_)-u,k=Math.sqrt(w*w+T*T);k<y&&(y=g=k,d=x)}return t.index=d,t.distance=y,t.dxy=g,void 0===d?[t]:[i(t,m,v,a)]}}},{\"../scattergl/hover\":1247,\"./helpers\":1288}],1290:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../components/grid\");e.exports={moduleType:\"trace\",name:\"splom\",basePlotModule:t(\"./base_plot\"),categories:[\"gl\",\"regl\",\"cartesian\",\"symbols\",\"showLegend\",\"scatter-like\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:t(\"../scatter/marker_colorbar\"),calc:t(\"./calc\"),plot:t(\"./plot\"),hoverPoints:t(\"./hover\").hoverPoints,selectPoints:t(\"./select\"),editStyle:t(\"./edit_style\"),meta:{}},n.register(i)},{\"../../components/grid\":687,\"../../registry\":911,\"../scatter/marker_colorbar\":1205,\"./attributes\":1283,\"./base_plot\":1284,\"./calc\":1285,\"./defaults\":1286,\"./edit_style\":1287,\"./hover\":1289,\"./plot\":1291,\"./select\":1293}],1291:[function(t,e,r){\"use strict\";var n=t(\"regl-splom\"),i=t(\"../../lib\"),a=t(\"../../plots/cartesian/axis_ids\"),o=t(\"../../components/dragelement/helpers\").selectMode;function s(t,e){var r,s,l,c,u,f=t._fullLayout,h=f._size,p=e.trace,d=e.t,g=f._splomScenes[p.uid],m=g.matrixOptions,v=m.cdata,y=f._glcanvas.data()[0].regl,x=f.dragmode;if(0!==v.length){m.lower=p.showupperhalf,m.upper=p.showlowerhalf,m.diagonal=p.diagonal.visible;var b=p._visibleDims,_=v.length,w=g.viewOpts={};for(w.ranges=new Array(_),w.domains=new Array(_),u=0;u<b.length;u++){l=b[u];var T=w.ranges[u]=new Array(4),k=w.domains[u]=new Array(4);(r=a.getFromId(t,p._diag[l][0]))&&(T[0]=r._rl[0],T[2]=r._rl[1],k[0]=r.domain[0],k[2]=r.domain[1]),(s=a.getFromId(t,p._diag[l][1]))&&(T[1]=s._rl[0],T[3]=s._rl[1],k[1]=s.domain[0],k[3]=s.domain[1])}w.viewport=[h.l,h.b,h.w+h.l,h.h+h.b],!0===g.matrix&&(g.matrix=n(y));var M=f.clickmode.indexOf(\"select\")>-1,A=!0;if(o(x)||!!p.selectedpoints||M){var S=p._length;if(p.selectedpoints){g.selectBatch=p.selectedpoints;var E=p.selectedpoints,C={};for(l=0;l<E.length;l++)C[E[l]]=!0;var L=[];for(l=0;l<S;l++)C[l]||L.push(l);g.unselectBatch=L}var I=d.xpx=new Array(_),P=d.ypx=new Array(_);for(u=0;u<b.length;u++){if(l=b[u],r=a.getFromId(t,p._diag[l][0]))for(I[u]=new Array(S),c=0;c<S;c++)I[u][c]=r.c2p(v[u][c]);if(s=a.getFromId(t,p._diag[l][1]))for(P[u]=new Array(S),c=0;c<S;c++)P[u][c]=s.c2p(v[u][c])}if(g.selectBatch.length||g.unselectBatch.length){var z=i.extendFlat({},m,g.unselectedOptions,w),O=i.extendFlat({},m,g.selectedOptions,w);g.matrix.update(z,O),A=!1}}else d.xpx=d.ypx=null;if(A){var D=i.extendFlat({},m,w);g.matrix.update(D,null)}}}e.exports=function(t,e,r){if(r.length)for(var n=0;n<r.length;n++)s(t,r[n][0])}},{\"../../components/dragelement/helpers\":661,\"../../lib\":778,\"../../plots/cartesian/axis_ids\":831,\"regl-splom\":539}],1292:[function(t,e,r){\"use strict\";var n=t(\"../../lib\");e.exports=function(t,e){var r=t._fullLayout,i=e.uid,a=r._splomScenes;a||(a=r._splomScenes={});var o={dirty:!0,selectBatch:[],unselectBatch:[]},s=a[e.uid];return s||((s=a[i]=n.extendFlat({},o,{matrix:!1,selectBatch:[],unselectBatch:[]})).draw=function(){s.matrix&&s.matrix.draw&&(s.selectBatch.length||s.unselectBatch.length?s.matrix.draw(s.unselectBatch,s.selectBatch):s.matrix.draw()),s.dirty=!1},s.destroy=function(){s.matrix&&s.matrix.destroy&&s.matrix.destroy(),s.matrixOptions=null,s.selectBatch=null,s.unselectBatch=null,s=null}),s.dirty||n.extendFlat(s,o),s}},{\"../../lib\":778}],1293:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../scatter/subtypes\"),a=t(\"./helpers\");e.exports=function(t,e){var r=t.cd,o=r[0].trace,s=r[0].t,l=t.scene,c=l.matrixOptions.cdata,u=t.xaxis,f=t.yaxis,h=[];if(!l)return h;var p=!i.hasMarkers(o)&&!i.hasText(o);if(!0!==o.visible||p)return h;var d=a.getDimIndex(o,u),g=a.getDimIndex(o,f);if(!1===d||!1===g)return h;var m=s.xpx[d],v=s.ypx[g],y=c[d],x=c[g],b=[],_=[];if(!1!==e&&!e.degenerate)for(var w=0;w<y.length;w++)e.contains([m[w],v[w]],null,w,t)?(b.push(w),h.push({pointNumber:w,x:y[w],y:x[w]})):_.push(w);var T=l.matrixOptions;return b.length||_.length?l.selectBatch.length||l.unselectBatch.length||l.matrix.update(l.unselectedOptions,n.extendFlat({},T,l.selectedOptions,l.viewOpts)):l.matrix.update(T,null),l.selectBatch=b,l.unselectBatch=_,h}},{\"../../lib\":778,\"../scatter/subtypes\":1212,\"./helpers\":1288}],1294:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../mesh3d/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l={x:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},y:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},z:{valType:\"data_array\",editType:\"calc+clearAxisTypes\"},u:{valType:\"data_array\",editType:\"calc\"},v:{valType:\"data_array\",editType:\"calc\"},w:{valType:\"data_array\",editType:\"calc\"},starts:{x:{valType:\"data_array\",editType:\"calc\"},y:{valType:\"data_array\",editType:\"calc\"},z:{valType:\"data_array\",editType:\"calc\"},editType:\"calc\"},maxdisplayed:{valType:\"integer\",min:0,dflt:1e3,editType:\"calc\"},sizeref:{valType:\"number\",editType:\"calc\",min:0,dflt:1},text:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertext:{valType:\"string\",dflt:\"\",editType:\"calc\"},hovertemplate:i({editType:\"calc\"},{keys:[\"tubex\",\"tubey\",\"tubez\",\"tubeu\",\"tubev\",\"tubew\",\"norm\",\"divergence\"]}),showlegend:s({},o.showlegend,{dflt:!1})};s(l,n(\"\",{colorAttr:\"u/v/w norm\",showScaleDflt:!0,editTypeOverride:\"calc\"}));[\"opacity\",\"lightposition\",\"lighting\"].forEach((function(t){l[t]=a[t]})),l.hoverinfo=s({},o.hoverinfo,{editType:\"calc\",flags:[\"x\",\"y\",\"z\",\"u\",\"v\",\"w\",\"norm\",\"divergence\",\"text\",\"name\"],dflt:\"x+y+z+norm+text+name\"}),l.transforms=void 0,e.exports=l},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../mesh3d/attributes\":1128}],1295:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/calc\");function a(t){var e,r,i,a,s,l,c,u,f,h,p,d,g=t._x,m=t._y,v=t._z,y=t._len,x=-1/0,b=1/0,_=-1/0,w=1/0,T=-1/0,k=1/0,M=\"\";for(y&&(c=g[0],f=m[0],p=v[0]),y>1&&(u=g[y-1],h=m[y-1],d=v[y-1]),e=0;e<y;e++)x=Math.max(x,g[e]),b=Math.min(b,g[e]),_=Math.max(_,m[e]),w=Math.min(w,m[e]),T=Math.max(T,v[e]),k=Math.min(k,v[e]),a||g[e]===c||(a=!0,M+=\"x\"),s||m[e]===f||(s=!0,M+=\"y\"),l||v[e]===p||(l=!0,M+=\"z\");a||(M+=\"x\"),s||(M+=\"y\"),l||(M+=\"z\");var A=o(t._x),S=o(t._y),E=o(t._z);M=(M=(M=M.replace(\"x\",(c>u?\"-\":\"+\")+\"x\")).replace(\"y\",(f>h?\"-\":\"+\")+\"y\")).replace(\"z\",(p>d?\"-\":\"+\")+\"z\");var C=function(){y=0,A=[],S=[],E=[]};(!y||y<A.length*S.length*E.length)&&C();var L=function(t){return\"x\"===t?g:\"y\"===t?m:v},I=function(t){return\"x\"===t?A:\"y\"===t?S:E},P=function(t){return t[y-1]<t[0]?-1:1},z=L(M[1]),O=L(M[3]),D=L(M[5]),R=I(M[1]).length,F=I(M[3]).length,B=I(M[5]).length,N=!1,j=function(t,e,r){return R*(F*t+e)+r},U=P(L(M[1])),V=P(L(M[3])),q=P(L(M[5]));for(e=0;e<B-1;e++){for(r=0;r<F-1;r++){for(i=0;i<R-1;i++){var H=j(e,r,i),G=j(e,r,i+1),Y=j(e,r+1,i),W=j(e+1,r,i);if(z[H]*U<z[G]*U&&O[H]*V<O[Y]*V&&D[H]*q<D[W]*q||(N=!0),N)break}if(N)break}if(N)break}return N&&(n.warn(\"Encountered arbitrary coordinates! Unable to input data grid.\"),C()),{xMin:b,yMin:w,zMin:k,xMax:x,yMax:_,zMax:T,Xs:A,Ys:S,Zs:E,len:y,fill:M}}function o(t){return n.distinctVals(t).vals}function s(t,e){if(void 0===e&&(e=t.length),n.isTypedArray(t))return t.subarray(0,e);for(var r=[],i=0;i<e;i++)r[i]=+t[i];return r}e.exports={calc:function(t,e){e._len=Math.min(e.u.length,e.v.length,e.w.length,e.x.length,e.y.length,e.z.length),e._u=s(e.u,e._len),e._v=s(e.v,e._len),e._w=s(e.w,e._len),e._x=s(e.x,e._len),e._y=s(e.y,e._len),e._z=s(e.z,e._len);var r=a(e);e._gridFill=r.fill,e._Xs=r.Xs,e._Ys=r.Ys,e._Zs=r.Zs,e._len=r.len;var n,o,l,c=0;e.starts&&(n=s(e.starts.x||[]),o=s(e.starts.y||[]),l=s(e.starts.z||[]),c=Math.min(n.length,o.length,l.length)),e._startsX=n||[],e._startsY=o||[],e._startsZ=l||[];var u,f=0,h=1/0;for(u=0;u<e._len;u++){var p=e._u[u],d=e._v[u],g=e._w[u],m=Math.sqrt(p*p+d*d+g*g);f=Math.max(f,m),h=Math.min(h,m)}for(i(t,e,{vals:[h,f],containerStr:\"\",cLetter:\"c\"}),u=0;u<c;u++){var v=n[u];r.xMax=Math.max(r.xMax,v),r.xMin=Math.min(r.xMin,v);var y=o[u];r.yMax=Math.max(r.yMax,y),r.yMin=Math.min(r.yMin,y);var x=l[u];r.zMax=Math.max(r.zMax,x),r.zMin=Math.min(r.zMin,x)}e._slen=c,e._normMax=f,e._xbnds=[r.xMin,r.xMax],e._ybnds=[r.yMin,r.yMax],e._zbnds=[r.zMin,r.zMax]},filter:s,processGrid:a}},{\"../../components/colorscale/calc\":651,\"../../lib\":778}],1296:[function(t,e,r){\"use strict\";var n=t(\"gl-streamtube3d\"),i=n.createTubeMesh,a=t(\"../../lib\"),o=t(\"../../lib/gl_format_color\").parseColorScale,s=t(\"../../components/colorscale\").extractOpts,l=t(\"../../plots/gl3d/zip3\"),c={xaxis:0,yaxis:1,zaxis:2};function u(t,e){this.scene=t,this.uid=e,this.mesh=null,this.data=null}var f=u.prototype;function h(t){var e=t.length;return e>2?t.slice(1,e-1):2===e?[(t[0]+t[1])/2]:t}function p(t){var e=t.length;return 1===e?[.5,.5]:[t[1]-t[0],t[e-1]-t[e-2]]}function d(t,e){var r=t.fullSceneLayout,i=t.dataScale,u=e._len,f={};function d(t,e){var n=r[e],o=i[c[e]];return a.simpleMap(t,(function(t){return n.d2l(t)*o}))}if(f.vectors=l(d(e._u,\"xaxis\"),d(e._v,\"yaxis\"),d(e._w,\"zaxis\"),u),!u)return{positions:[],cells:[]};var g=d(e._Xs,\"xaxis\"),m=d(e._Ys,\"yaxis\"),v=d(e._Zs,\"zaxis\");if(f.meshgrid=[g,m,v],f.gridFill=e._gridFill,e._slen)f.startingPositions=l(d(e._startsX,\"xaxis\"),d(e._startsY,\"yaxis\"),d(e._startsZ,\"zaxis\"));else{for(var y=m[0],x=h(g),b=h(v),_=new Array(x.length*b.length),w=0,T=0;T<x.length;T++)for(var k=0;k<b.length;k++)_[w++]=[x[T],y,b[k]];f.startingPositions=_}f.colormap=o(e),f.tubeSize=e.sizeref,f.maxLength=e.maxdisplayed;var M=d(e._xbnds,\"xaxis\"),A=d(e._ybnds,\"yaxis\"),S=d(e._zbnds,\"zaxis\"),E=p(g),C=p(m),L=p(v),I=[[M[0]-E[0],A[0]-C[0],S[0]-L[0]],[M[1]+E[1],A[1]+C[1],S[1]+L[1]]],P=n(f,I),z=s(e);P.vertexIntensityBounds=[z.min/e._normMax,z.max/e._normMax];var O=e.lightposition;return P.lightPosition=[O.x,O.y,O.z],P.ambient=e.lighting.ambient,P.diffuse=e.lighting.diffuse,P.specular=e.lighting.specular,P.roughness=e.lighting.roughness,P.fresnel=e.lighting.fresnel,P.opacity=e.opacity,e._pad=P.tubeScale*e.sizeref*2,P}f.handlePick=function(t){var e=this.scene.fullSceneLayout,r=this.scene.dataScale;function n(t,n){var i=e[n],a=r[c[n]];return i.l2c(t)/a}if(t.object===this.mesh){var i=t.data.position,a=t.data.velocity;return t.traceCoordinate=[n(i[0],\"xaxis\"),n(i[1],\"yaxis\"),n(i[2],\"zaxis\"),n(a[0],\"xaxis\"),n(a[1],\"yaxis\"),n(a[2],\"zaxis\"),t.data.intensity*this.data._normMax,t.data.divergence],t.textLabel=this.data.hovertext||this.data.text,!0}},f.update=function(t){this.data=t;var e=d(this.scene,t);this.mesh.update(e)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,n=d(t,e),a=i(r,n),o=new u(t,e.uid);return o.mesh=a,o.data=e,a._trace=o,t.glplot.add(a),o}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../plots/gl3d/zip3\":881,\"gl-streamtube3d\":348}],1297:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/colorscale/defaults\"),a=t(\"./attributes\");e.exports=function(t,e,r,o){function s(r,i){return n.coerce(t,e,a,r,i)}var l=s(\"u\"),c=s(\"v\"),u=s(\"w\"),f=s(\"x\"),h=s(\"y\"),p=s(\"z\");l&&l.length&&c&&c.length&&u&&u.length&&f&&f.length&&h&&h.length&&p&&p.length?(s(\"starts.x\"),s(\"starts.y\"),s(\"starts.z\"),s(\"maxdisplayed\"),s(\"sizeref\"),s(\"lighting.ambient\"),s(\"lighting.diffuse\"),s(\"lighting.specular\"),s(\"lighting.roughness\"),s(\"lighting.fresnel\"),s(\"lightposition.x\"),s(\"lightposition.y\"),s(\"lightposition.z\"),i(t,e,o,s,{prefix:\"\",cLetter:\"c\"}),s(\"text\"),s(\"hovertext\"),s(\"hovertemplate\"),e._length=null):e.visible=!1}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"./attributes\":1294}],1298:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"streamtube\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\").calc,plot:t(\"./convert\"),eventData:function(t,e){return t.tubex=t.x,t.tubey=t.y,t.tubez=t.z,t.tubeu=e.traceCoordinate[3],t.tubev=e.traceCoordinate[4],t.tubew=e.traceCoordinate[5],t.norm=e.traceCoordinate[6],t.divergence=e.traceCoordinate[7],delete t.x,delete t.y,delete t.z,t},meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1294,\"./calc\":1295,\"./convert\":1296,\"./defaults\":1297}],1299:[function(t,e,r){\"use strict\";var n=t(\"../../plots/attributes\"),i=t(\"../../plots/template_attributes\").hovertemplateAttrs,a=t(\"../../plots/template_attributes\").texttemplateAttrs,o=t(\"../../components/colorscale/attributes\"),s=t(\"../../plots/domain\").attributes,l=t(\"../pie/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:{valType:\"data_array\",editType:\"calc\"},parents:{valType:\"data_array\",editType:\"calc\"},values:{valType:\"data_array\",editType:\"calc\"},branchvalues:{valType:\"enumerated\",values:[\"remainder\",\"total\"],dflt:\"remainder\",editType:\"calc\"},count:{valType:\"flaglist\",flags:[\"branches\",\"leaves\"],dflt:\"leaves\",editType:\"calc\"},level:{valType:\"any\",editType:\"plot\",anim:!0},maxdepth:{valType:\"integer\",editType:\"plot\",dflt:-1},marker:u({colors:{valType:\"data_array\",editType:\"calc\"},line:{color:u({},l.marker.line.color,{dflt:null}),width:u({},l.marker.line.width,{dflt:1}),editType:\"calc\"},editType:\"calc\"},o(\"marker\",{colorAttr:\"colors\",anim:!1})),leaf:{opacity:{valType:\"number\",editType:\"style\",min:0,max:1},editType:\"plot\"},text:l.text,textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"value\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],extras:[\"none\"],editType:\"plot\"},texttemplate:a({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:l.hovertext,hoverinfo:u({},n.hoverinfo,{flags:[\"label\",\"text\",\"value\",\"name\",\"current path\",\"percent root\",\"percent entry\",\"percent parent\"],dflt:\"label+text+value+name\"}),hovertemplate:i({},{keys:c.eventDataKeys}),textfont:l.textfont,insidetextorientation:l.insidetextorientation,insidetextfont:l.insidetextfont,outsidetextfont:u({},l.outsidetextfont,{}),rotation:{valType:\"angle\",dflt:0,editType:\"plot\"},sort:l.sort,root:{color:{valType:\"color\",editType:\"calc\",dflt:\"rgba(0,0,0,0)\"},editType:\"calc\"},domain:s({name:\"sunburst\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"./constants\":1302}],1300:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"sunburst\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1301:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\"),i=t(\"fast-isnumeric\"),a=t(\"../../lib\"),o=t(\"../../components/colorscale\").makeColorScaleFuncFromTrace,s=t(\"../pie/calc\").makePullColorFn,l=t(\"../pie/calc\").generateExtendedColors,c=t(\"../../components/colorscale\").calc,u=t(\"../../constants/numerical\").ALMOST_EQUAL,f={},h={};r.calc=function(t,e){var r,l,f,h,p,d,g=t._fullLayout,m=e.ids,v=a.isArrayOrTypedArray(m),y=e.labels,x=e.parents,b=e.values,_=a.isArrayOrTypedArray(b),w=[],T={},k={},M=function(t){return t||\"number\"==typeof t},A=function(t){return!_||i(b[t])&&b[t]>=0};v?(r=Math.min(m.length,x.length),l=function(t){return M(m[t])&&A(t)},f=function(t){return String(m[t])}):(r=Math.min(y.length,x.length),l=function(t){return M(y[t])&&A(t)},f=function(t){return String(y[t])}),_&&(r=Math.min(r,b.length));for(var S=0;S<r;S++)if(l(S)){var E=f(S),C=M(x[S])?String(x[S]):\"\",L={i:S,id:E,pid:C,label:M(y[S])?String(y[S]):\"\"};_&&(L.v=+b[S]),w.push(L),p=E,T[h=C]?T[h].push(p):T[h]=[p],k[p]=1}if(T[\"\"]){if(T[\"\"].length>1){for(var I=a.randstr(),P=0;P<w.length;P++)\"\"===w[P].pid&&(w[P].pid=I);w.unshift({hasMultipleRoots:!0,id:I,pid:\"\",label:\"\"})}}else{var z,O=[];for(z in T)k[z]||O.push(z);if(1!==O.length)return a.warn([\"Multiple implied roots, cannot build\",e.type,\"hierarchy of\",e.name+\".\",\"These roots include:\",O.join(\", \")].join(\" \"));z=O[0],w.unshift({hasImpliedRoot:!0,id:z,pid:\"\",label:z})}try{d=n.stratify().id((function(t){return t.id})).parentId((function(t){return t.pid}))(w)}catch(t){return a.warn([\"Failed to build\",e.type,\"hierarchy of\",e.name+\".\",\"Error:\",t.message].join(\" \"))}var D=n.hierarchy(d),R=!1;if(_)switch(e.branchvalues){case\"remainder\":D.sum((function(t){return t.data.v}));break;case\"total\":D.each((function(t){var r=t.data.data,n=r.v;if(t.children){var i=t.children.reduce((function(t,e){return t+e.data.data.v}),0);if((r.hasImpliedRoot||r.hasMultipleRoots)&&(n=i),n<i*u)return R=!0,a.warn([\"Total value for node\",t.data.data.id,\"of\",e.name,\"is smaller than the sum of its children.\",\"\\nparent value =\",n,\"\\nchildren sum =\",i].join(\" \"))}t.value=n}))}else!function t(e,r,n){var i=0,a=e.children;if(a){for(var o=a.length,s=0;s<o;s++)i+=t(a[s],r,n);n.branches&&i++}else n.leaves&&i++;e.value=e.data.data.value=i,r._values||(r._values=[]);return r._values[e.data.data.i]=i,i}(D,e,{branches:-1!==e.count.indexOf(\"branches\"),leaves:-1!==e.count.indexOf(\"leaves\")});if(!R){var F,B;e.sort&&D.sort((function(t,e){return e.value-t.value}));var N=e.marker.colors||[],j=!!N.length;return e._hasColorscale?(j||(N=_?e.values:e._values),c(t,e,{vals:N,containerStr:\"marker\",cLetter:\"c\"}),B=o(e.marker)):F=s(g[\"_\"+e.type+\"colormap\"]),D.each((function(t){var r=t.data.data;r.color=e._hasColorscale?B(N[r.i]):F(N[r.i],r.id)})),w[0].hierarchy=D,w}},r._runCrossTraceCalc=function(t,e){var r=e._fullLayout,n=e.calcdata,i=r[t+\"colorway\"],a=r[\"_\"+t+\"colormap\"];r[\"extend\"+t+\"colors\"]&&(i=l(i,\"treemap\"===t?h:f));var o,s=0;function c(t){var e=t.data.data,r=e.id;!1===e.color&&(a[r]?e.color=a[r]:t.parent?t.parent.parent?e.color=t.parent.data.data.color:(a[r]=e.color=i[s%i.length],s++):e.color=o)}for(var u=0;u<n.length;u++){var p=n[u][0];p.trace.type===t&&p.hierarchy&&(o=p.trace.root.color,p.hierarchy.each(c))}},r.crossTraceCalc=function(t){return r._runCrossTraceCalc(\"sunburst\",t)}},{\"../../components/colorscale\":655,\"../../constants/numerical\":753,\"../../lib\":778,\"../pie/calc\":1163,\"d3-hierarchy\":161,\"fast-isnumeric\":241}],1302:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"linear\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"]}},{}],1303:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults,o=t(\"../bar/defaults\").handleText,s=t(\"../../components/colorscale\"),l=s.hasColorscale,c=s.handleDefaults;e.exports=function(t,e,r,s){function u(r,a){return n.coerce(t,e,i,r,a)}var f=u(\"labels\"),h=u(\"parents\");if(f&&f.length&&h&&h.length){var p=u(\"values\");p&&p.length?u(\"branchvalues\"):u(\"count\"),u(\"level\"),u(\"maxdepth\"),u(\"marker.line.width\")&&u(\"marker.line.color\",s.paper_bgcolor),u(\"marker.colors\");var d=e._hasColorscale=l(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;d&&c(t,e,s,u,{prefix:\"marker.\",cLetter:\"c\"}),u(\"leaf.opacity\",d?1:.7);var g=u(\"text\");u(\"texttemplate\"),e.texttemplate||u(\"textinfo\",Array.isArray(g)?\"text+label\":\"label\"),u(\"hovertext\"),u(\"hovertemplate\");o(t,e,s,u,\"auto\",{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),u(\"insidetextorientation\"),u(\"sort\"),u(\"rotation\"),u(\"root.color\"),a(e,s,u),e._length=null}else e.visible=!1}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/defaults\":925,\"./attributes\":1299}],1304:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../registry\"),a=t(\"../../components/fx/helpers\").appendArrayPointValue,o=t(\"../../components/fx\"),s=t(\"../../lib\"),l=t(\"../../lib/events\"),c=t(\"./helpers\"),u=t(\"../pie/helpers\").formatPieValue;function f(t,e,r){for(var n=t.data.data,i={curveNumber:e.index,pointNumber:n.i,data:e._input,fullData:e},o=0;o<r.length;o++){var s=r[o];s in t&&(i[s]=t[s])}return\"parentString\"in t&&!c.isHierarchyRoot(t)&&(i.parent=t.parentString),a(i,e,n.i),i}e.exports=function(t,e,r,a,h){var p=a[0],d=p.trace,g=p.hierarchy,m=\"sunburst\"===d.type,v=\"treemap\"===d.type;\"_hasHoverLabel\"in d||(d._hasHoverLabel=!1),\"_hasHoverEvent\"in d||(d._hasHoverEvent=!1);t.on(\"mouseover\",(function(i){var a=r._fullLayout;if(!r._dragging&&!1!==a.hovermode){var l=r._fullData[d.index],y=i.data.data,x=y.i,b=c.isHierarchyRoot(i),_=c.getParent(g,i),w=c.getValue(i),T=function(t){return s.castOption(l,x,t)},k=T(\"hovertemplate\"),M=o.castHoverinfo(l,a,x),A=a.separators;if(k||M&&\"none\"!==M&&\"skip\"!==M){var S,E;m&&(S=p.cx+i.pxmid[0]*(1-i.rInscribed),E=p.cy+i.pxmid[1]*(1-i.rInscribed)),v&&(S=i._hoverX,E=i._hoverY);var C,L={},I=[],P=[],z=function(t){return-1!==I.indexOf(t)};M&&(I=\"all\"===M?l._module.attributes.hoverinfo.flags:M.split(\"+\")),L.label=y.label,z(\"label\")&&L.label&&P.push(L.label),y.hasOwnProperty(\"v\")&&(L.value=y.v,L.valueLabel=u(L.value,A),z(\"value\")&&P.push(L.valueLabel)),L.currentPath=i.currentPath=c.getPath(i.data),z(\"current path\")&&!b&&P.push(L.currentPath);var O=[],D=function(){-1===O.indexOf(C)&&(P.push(C),O.push(C))};L.percentParent=i.percentParent=w/c.getValue(_),L.parent=i.parentString=c.getPtLabel(_),z(\"percent parent\")&&(C=c.formatPercent(L.percentParent,A)+\" of \"+L.parent,D()),L.percentEntry=i.percentEntry=w/c.getValue(e),L.entry=i.entry=c.getPtLabel(e),!z(\"percent entry\")||b||i.onPathbar||(C=c.formatPercent(L.percentEntry,A)+\" of \"+L.entry,D()),L.percentRoot=i.percentRoot=w/c.getValue(g),L.root=i.root=c.getPtLabel(g),z(\"percent root\")&&!b&&(C=c.formatPercent(L.percentRoot,A)+\" of \"+L.root,D()),L.text=T(\"hovertext\")||T(\"text\"),z(\"text\")&&(C=L.text,s.isValidTextValue(C)&&P.push(C));var R={trace:l,y:E,text:P.join(\"<br>\"),name:k||z(\"name\")?l.name:void 0,color:T(\"hoverlabel.bgcolor\")||y.color,borderColor:T(\"hoverlabel.bordercolor\"),fontFamily:T(\"hoverlabel.font.family\"),fontSize:T(\"hoverlabel.font.size\"),fontColor:T(\"hoverlabel.font.color\"),nameLength:T(\"hoverlabel.namelength\"),textAlign:T(\"hoverlabel.align\"),hovertemplate:k,hovertemplateLabels:L,eventData:[f(i,l,h.eventDataKeys)]};m&&(R.x0=S-i.rInscribed*i.rpx1,R.x1=S+i.rInscribed*i.rpx1,R.idealAlign=i.pxmid[0]<0?\"left\":\"right\"),v&&(R.x=S,R.idealAlign=S<0?\"left\":\"right\"),o.loneHover(R,{container:a._hoverlayer.node(),outerContainer:a._paper.node(),gd:r}),d._hasHoverLabel=!0}if(v){var F=t.select(\"path.surface\");h.styleOne(F,i,l,{hovered:!0})}d._hasHoverEvent=!0,r.emit(\"plotly_hover\",{points:[f(i,l,h.eventDataKeys)],event:n.event})}})),t.on(\"mouseout\",(function(e){var i=r._fullLayout,a=r._fullData[d.index],s=n.select(this).datum();if(d._hasHoverEvent&&(e.originalEvent=n.event,r.emit(\"plotly_unhover\",{points:[f(s,a,h.eventDataKeys)],event:n.event}),d._hasHoverEvent=!1),d._hasHoverLabel&&(o.loneUnhover(i._hoverlayer.node()),d._hasHoverLabel=!1),v){var l=t.select(\"path.surface\");h.styleOne(l,s,a,{hovered:!1})}})),t.on(\"click\",(function(t){var e=r._fullLayout,a=r._fullData[d.index],s=m&&(c.isHierarchyRoot(t)||c.isLeaf(t)),u=c.getPtId(t),p=c.isEntry(t)?c.findEntryWithChild(g,u):c.findEntryWithLevel(g,u),v=c.getPtId(p),y={points:[f(t,a,h.eventDataKeys)],event:n.event};s||(y.nextLevel=v);var x=l.triggerHandler(r,\"plotly_\"+d.type+\"click\",y);if(!1!==x&&e.hovermode&&(r._hoverdata=[f(t,a,h.eventDataKeys)],o.click(r,n.event)),!s&&!1!==x&&!r._dragging&&!r._transitioning){i.call(\"_storeDirectGUIEdit\",a,e._tracePreGUI[a.uid],{level:a.level});var b={data:[{level:v}],traces:[d.index]},_={frame:{redraw:!1,duration:h.transitionTime},transition:{duration:h.transitionTime,easing:h.transitionEasing},mode:\"immediate\",fromcurrent:!0};o.loneUnhover(e._hoverlayer.node()),i.call(\"animate\",r,b,_)}}))}},{\"../../components/fx\":683,\"../../components/fx/helpers\":679,\"../../lib\":778,\"../../lib/events\":767,\"../../registry\":911,\"../pie/helpers\":1166,\"./helpers\":1305,d3:169}],1305:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../../lib/setcursor\"),o=t(\"../pie/helpers\");function s(t){return t.data.data.pid}r.findEntryWithLevel=function(t,e){var n;return e&&t.eachAfter((function(t){if(r.getPtId(t)===e)return n=t.copy()})),n||t},r.findEntryWithChild=function(t,e){var n;return t.eachAfter((function(t){for(var i=t.children||[],a=0;a<i.length;a++){var o=i[a];if(r.getPtId(o)===e)return n=t.copy()}})),n||t},r.isEntry=function(t){return!t.parent},r.isLeaf=function(t){return!t.children},r.getPtId=function(t){return t.data.data.id},r.getPtLabel=function(t){return t.data.data.label},r.getValue=function(t){return t.value},r.isHierarchyRoot=function(t){return\"\"===s(t)},r.setSliceCursor=function(t,e,n){var i=n.isTransitioning;if(!i){var o=t.datum();i=n.hideOnRoot&&r.isHierarchyRoot(o)||n.hideOnLeaves&&r.isLeaf(o)}a(t,i?null:\"pointer\")},r.getInsideTextFontKey=function(t,e,r,i,a){var o=(a||{}).onPathbar?\"pathbar.textfont\":\"insidetextfont\",s=r.data.data.i;return n.castOption(e,s,o+\".\"+t)||n.castOption(e,s,\"textfont.\"+t)||i.size},r.getOutsideTextFontKey=function(t,e,r,i){var a=r.data.data.i;return n.castOption(e,a,\"outsidetextfont.\"+t)||n.castOption(e,a,\"textfont.\"+t)||i.size},r.isOutsideText=function(t,e){return!t._hasColorscale&&r.isHierarchyRoot(e)},r.determineTextFont=function(t,e,a,o){return r.isOutsideText(t,e)?function(t,e,n){return{color:r.getOutsideTextFontKey(\"color\",t,e,n),family:r.getOutsideTextFontKey(\"family\",t,e,n),size:r.getOutsideTextFontKey(\"size\",t,e,n)}}(t,e,a):function(t,e,a,o){var s=(o||{}).onPathbar,l=e.data.data,c=l.i,u=n.castOption(t,c,(s?\"pathbar.textfont\":\"insidetextfont\")+\".color\");return!u&&t._input.textfont&&(u=n.castOption(t._input,c,\"textfont.color\")),{color:u||i.contrast(l.color),family:r.getInsideTextFontKey(\"family\",t,e,a,o),size:r.getInsideTextFontKey(\"size\",t,e,a,o)}}(t,e,a,o)},r.hasTransition=function(t){return!!(t&&t.duration>0)},r.getMaxDepth=function(t){return t.maxdepth>=0?t.maxdepth:1/0},r.isHeader=function(t,e){return!(r.isLeaf(t)||t.depth===e._maxDepth-1)},r.getParent=function(t,e){return r.findEntryWithLevel(t,s(e))},r.listPath=function(t,e){var n=t.parent;if(!n)return[];var i=e?[n.data[e]]:[n];return r.listPath(n,e).concat(i)},r.getPath=function(t){return r.listPath(t,\"label\").join(\"/\")+\"/\"},r.formatValue=o.formatPieValue,r.formatPercent=function(t,e){var r=n.formatPercent(t,0);return\"0%\"===r&&(r=o.formatPiePercent(t,e)),r}},{\"../../components/color\":643,\"../../lib\":778,\"../../lib/setcursor\":799,\"../pie/helpers\":1166}],1306:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"sunburst\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\").plot,style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1299,\"./base_plot\":1300,\"./calc\":1301,\"./defaults\":1303,\"./layout_attributes\":1307,\"./layout_defaults\":1308,\"./plot\":1309,\"./style\":1310}],1307:[function(t,e,r){\"use strict\";e.exports={sunburstcolorway:{valType:\"colorlist\",editType:\"calc\"},extendsunburstcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1308:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"sunburstcolorway\",e.colorway),r(\"extendsunburstcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1307}],1309:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"d3-hierarchy\"),a=t(\"../../components/drawing\"),o=t(\"../../lib\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../pie/plot\"),h=t(\"../pie/helpers\").getRotationAngle,p=f.computeTransform,d=f.transformInsideText,g=t(\"./style\").styleOne,m=t(\"../bar/style\").resizeText,v=t(\"./fx\"),y=t(\"./constants\"),x=t(\"./helpers\");function b(t,e,l,u){var f=t._fullLayout,m=!f.uniformtext.mode&&x.hasTransition(u),b=n.select(l).selectAll(\"g.slice\"),w=e[0],T=w.trace,k=w.hierarchy,M=x.findEntryWithLevel(k,T.level),A=x.getMaxDepth(T),S=f._size,E=T.domain,C=S.w*(E.x[1]-E.x[0]),L=S.h*(E.y[1]-E.y[0]),I=.5*Math.min(C,L),P=w.cx=S.l+S.w*(E.x[1]+E.x[0])/2,z=w.cy=S.t+S.h*(1-E.y[0])-L/2;if(!M)return b.remove();var O=null,D={};m&&b.each((function(t){D[x.getPtId(t)]={rpx0:t.rpx0,rpx1:t.rpx1,x0:t.x0,x1:t.x1,transform:t.transform},!O&&x.isEntry(t)&&(O=t)}));var R=function(t){return i.partition().size([2*Math.PI,t.height+1])(t)}(M).descendants(),F=M.height+1,B=0,N=A;w.hasMultipleRoots&&x.isHierarchyRoot(M)&&(R=R.slice(1),F-=1,B=1,N+=1),R=R.filter((function(t){return t.y1<=N}));var j=h(T.rotation);j&&R.forEach((function(t){t.x0+=j,t.x1+=j}));var U=Math.min(F,A),V=function(t){return(t-B)/U*I},q=function(t,e){return[t*Math.cos(e),-t*Math.sin(e)]},H=function(t){return o.pathAnnulus(t.rpx0,t.rpx1,t.x0,t.x1,P,z)},G=function(t){return P+_(t)[0]*(t.transform.rCenter||0)+(t.transform.x||0)},Y=function(t){return z+_(t)[1]*(t.transform.rCenter||0)+(t.transform.y||0)};(b=b.data(R,x.getPtId)).enter().append(\"g\").classed(\"slice\",!0),m?b.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=x.getPtId(t),i=D[r],a=D[x.getPtId(M)];if(a){var o=(t.x1>a.x1?2*Math.PI:0)+j;e=t.rpx1<a.rpx1?{rpx0:0,rpx1:0}:{x0:o,x1:o}}else{var s,l=x.getPtId(t.parent);b.each((function(t){if(x.getPtId(t)===l)return s=t}));var c,u=s.children;u.forEach((function(t,e){if(x.getPtId(t)===r)return c=e}));var f=u.length,h=n.interpolate(s.x0,s.x1);e={rpx0:I,rpx1:I,x0:h(c/f),x1:h((c+1)/f)}}return n.interpolate(i,e)}(t);return function(t){return H(e(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():b.exit().remove(),b.order();var W=null;if(m&&O){var X=x.getPtId(O);b.each((function(t){null===W&&x.getPtId(t)===X&&(W=t.x1)}))}var Z=b;function J(t){var e=t.parent,r=D[x.getPtId(e)],i={};if(r){var a=e.children,o=a.indexOf(t),s=a.length,l=n.interpolate(r.x0,r.x1);i.x0=l(o/s),i.x1=l(o/s)}else i.x0=i.x1=0;return i}m&&(Z=Z.transition().each(\"end\",(function(){var e=n.select(this);x.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:!1})}))),Z.each((function(i){var l=n.select(this),u=o.ensureSingle(l,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));i.rpx0=V(i.y0),i.rpx1=V(i.y1),i.xmid=(i.x0+i.x1)/2,i.pxmid=q(i.rpx1,i.xmid),i.midangle=-(i.xmid-Math.PI/2),i.startangle=-(i.x0-Math.PI/2),i.stopangle=-(i.x1-Math.PI/2),i.halfangle=.5*Math.min(o.angleDelta(i.x0,i.x1)||Math.PI,Math.PI),i.ring=1-i.rpx0/i.rpx1,i.rInscribed=function(t){return 0===t.rpx0&&o.isFullCircle([t.x0,t.x1])?1:Math.max(0,Math.min(1/(1+1/Math.sin(t.halfangle)),t.ring/2))}(i),m?u.transition().attrTween(\"d\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i={x0:t.x0,x1:t.x1,rpx0:t.rpx0,rpx1:t.rpx1};if(r)e=r;else if(O)if(t.parent)if(W){var a=(t.x1>W?2*Math.PI:0)+j;e={x0:a,x1:a}}else e={rpx0:I,rpx1:I},o.extendFlat(e,J(t));else e={rpx0:0,rpx1:0};else e={x0:j,x1:j};return n.interpolate(e,i)}(t);return function(t){return H(e(t))}})):u.attr(\"d\",H),l.call(v,M,t,e,{eventDataKeys:y.eventDataKeys,transitionTime:y.CLICK_TRANSITION_TIME,transitionEasing:y.CLICK_TRANSITION_EASING}).call(x.setSliceCursor,t,{hideOnRoot:!0,hideOnLeaves:!0,isTransitioning:t._transitioning}),u.call(g,i,T);var h=o.ensureSingle(l,\"g\",\"slicetext\"),b=o.ensureSingle(h,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),_=o.ensureUniformFontSize(t,x.determineTextFont(T,i,f.font));b.text(r.formatSliceLabel(i,M,T,e,f)).classed(\"slicetext\",!0).attr(\"text-anchor\",\"middle\").call(a.font,_).call(s.convertToTspans,t);var k=a.bBox(b.node());i.transform=d(k,i,w),i.transform.targetX=G(i),i.transform.targetY=Y(i);var A=function(t,e){var r=t.transform;return p(r,e),r.fontSize=_.size,c(T.type,r,f),o.getTextTransform(r)};m?b.transition().attrTween(\"transform\",(function(t){var e=function(t){var e,r=D[x.getPtId(t)],i=t.transform;if(r)e=r;else if(e={rpx1:t.rpx1,transform:{textPosAngle:i.textPosAngle,scale:0,rotate:i.rotate,rCenter:i.rCenter,x:i.x,y:i.y}},O)if(t.parent)if(W){var a=t.x1>W?2*Math.PI:0;e.x0=e.x1=a}else o.extendFlat(e,J(t));else e.x0=e.x1=j;else e.x0=e.x1=j;var s=n.interpolate(e.transform.textPosAngle,t.transform.textPosAngle),l=n.interpolate(e.rpx1,t.rpx1),u=n.interpolate(e.x0,t.x0),h=n.interpolate(e.x1,t.x1),p=n.interpolate(e.transform.scale,i.scale),d=n.interpolate(e.transform.rotate,i.rotate),g=0===i.rCenter?3:0===e.transform.rCenter?1/3:1,m=n.interpolate(e.transform.rCenter,i.rCenter);return function(t){var e=l(t),r=u(t),n=h(t),a=function(t){return m(Math.pow(t,g))}(t),o={pxmid:q(e,(r+n)/2),rpx1:e,transform:{textPosAngle:s(t),rCenter:a,x:i.x,y:i.y}};return c(T.type,i,f),{transform:{targetX:G(o),targetY:Y(o),scale:p(t),rotate:d(t),rCenter:a}}}}(t);return function(t){return A(e(t),k)}})):b.attr(\"transform\",A(i,k))}))}function _(t){return e=t.rpx1,r=t.transform.textPosAngle,[e*Math.sin(r),-e*Math.cos(r)];var e,r}r.plot=function(t,e,r,i){var a,o,s=t._fullLayout,l=s._sunburstlayer,c=!r,f=!s.uniformtext.mode&&x.hasTransition(r);(u(\"sunburst\",s),(a=l.selectAll(\"g.trace.sunburst\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"sunburst\",!0).attr(\"stroke-linejoin\",\"round\"),a.order(),f)?(i&&(o=i()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){o&&o()})).each(\"interrupt\",(function(){o&&o()})).each((function(){l.selectAll(\"g.trace\").each((function(e){b(t,e,this,r)}))}))):(a.each((function(e){b(t,e,this,r)})),s.uniformtext.mode&&m(t,s._sunburstlayer.selectAll(\".trace\"),\"sunburst\"));c&&a.exit().remove()},r.formatSliceLabel=function(t,e,r,n,i){var a=r.texttemplate,s=r.textinfo;if(!(a||s&&\"none\"!==s))return\"\";var l=i.separators,c=n[0],u=t.data.data,f=c.hierarchy,h=x.isHierarchyRoot(t),p=x.getParent(f,t),d=x.getValue(t);if(!a){var g,m=s.split(\"+\"),v=function(t){return-1!==m.indexOf(t)},y=[];if(v(\"label\")&&u.label&&y.push(u.label),u.hasOwnProperty(\"v\")&&v(\"value\")&&y.push(x.formatValue(u.v,l)),!h){v(\"current path\")&&y.push(x.getPath(t.data));var b=0;v(\"percent parent\")&&b++,v(\"percent entry\")&&b++,v(\"percent root\")&&b++;var _=b>1;if(b){var w,T=function(t){g=x.formatPercent(w,l),_&&(g+=\" of \"+t),y.push(g)};v(\"percent parent\")&&!h&&(w=d/x.getValue(p),T(\"parent\")),v(\"percent entry\")&&(w=d/x.getValue(e),T(\"entry\")),v(\"percent root\")&&(w=d/x.getValue(f),T(\"root\"))}}return v(\"text\")&&(g=o.castOption(r,u.i,\"text\"),o.isValidTextValue(g)&&y.push(g)),y.join(\"<br>\")}var k=o.castOption(r,u.i,\"texttemplate\");if(!k)return\"\";var M={};u.label&&(M.label=u.label),u.hasOwnProperty(\"v\")&&(M.value=u.v,M.valueLabel=x.formatValue(u.v,l)),M.currentPath=x.getPath(t.data),h||(M.percentParent=d/x.getValue(p),M.percentParentLabel=x.formatPercent(M.percentParent,l),M.parent=x.getPtLabel(p)),M.percentEntry=d/x.getValue(e),M.percentEntryLabel=x.formatPercent(M.percentEntry,l),M.entry=x.getPtLabel(e),M.percentRoot=d/x.getValue(f),M.percentRootLabel=x.formatPercent(M.percentRoot,l),M.root=x.getPtLabel(f),u.hasOwnProperty(\"color\")&&(M.color=u.color);var A=o.castOption(r,u.i,\"text\");return(o.isValidTextValue(A)||\"\"===A)&&(M.text=A),M.customdata=o.castOption(r,u.i,\"customdata\"),o.texttemplateString(k,M,i._d3locale,M,r._meta||{})}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../pie/helpers\":1166,\"../pie/plot\":1170,\"./constants\":1302,\"./fx\":1304,\"./helpers\":1305,\"./style\":1310,d3:169,\"d3-hierarchy\":161}],1310:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../bar/uniform_text\").resizeText;function s(t,e,r){var n=e.data.data,o=!e.children,s=n.i,l=a.castOption(r,s,\"marker.line.color\")||i.defaultLine,c=a.castOption(r,s,\"marker.line.width\")||0;t.style(\"stroke-width\",c).call(i.fill,n.color).call(i.stroke,l).style(\"opacity\",o?r.leaf.opacity:null)}e.exports={style:function(t){var e=t._fullLayout._sunburstlayer.selectAll(\".trace\");o(t,e,\"sunburst\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(s,t,r)}))}))},styleOne:s}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,d3:169}],1311:[function(t,e,r){\"use strict\";var n=t(\"../../components/color\"),i=t(\"../../components/colorscale/attributes\"),a=t(\"../../plots/template_attributes\").hovertemplateAttrs,o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll;function c(t){return{show:{valType:\"boolean\",dflt:!1},start:{valType:\"number\",dflt:null,editType:\"plot\"},end:{valType:\"number\",dflt:null,editType:\"plot\"},size:{valType:\"number\",dflt:null,min:0,editType:\"plot\"},project:{x:{valType:\"boolean\",dflt:!1},y:{valType:\"boolean\",dflt:!1},z:{valType:\"boolean\",dflt:!1}},color:{valType:\"color\",dflt:n.defaultLine},usecolormap:{valType:\"boolean\",dflt:!1},width:{valType:\"number\",min:1,max:16,dflt:2},highlight:{valType:\"boolean\",dflt:!0},highlightcolor:{valType:\"color\",dflt:n.defaultLine},highlightwidth:{valType:\"number\",min:1,max:16,dflt:2}}}var u=e.exports=l(s({z:{valType:\"data_array\"},x:{valType:\"data_array\"},y:{valType:\"data_array\"},text:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertext:{valType:\"string\",dflt:\"\",arrayOk:!0},hovertemplate:a(),connectgaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},surfacecolor:{valType:\"data_array\"}},i(\"\",{colorAttr:\"z or surfacecolor\",showScaleDflt:!0,autoColorDflt:!1,editTypeOverride:\"calc\"}),{contours:{x:c(),y:c(),z:c()},hidesurface:{valType:\"boolean\",dflt:!1},lightposition:{x:{valType:\"number\",min:-1e5,max:1e5,dflt:10},y:{valType:\"number\",min:-1e5,max:1e5,dflt:1e4},z:{valType:\"number\",min:-1e5,max:1e5,dflt:0}},lighting:{ambient:{valType:\"number\",min:0,max:1,dflt:.8},diffuse:{valType:\"number\",min:0,max:1,dflt:.8},specular:{valType:\"number\",min:0,max:2,dflt:.05},roughness:{valType:\"number\",min:0,max:1,dflt:.5},fresnel:{valType:\"number\",min:0,max:5,dflt:.2}},opacity:{valType:\"number\",min:0,max:1,dflt:1},opacityscale:{valType:\"any\",editType:\"calc\"},_deprecated:{zauto:s({},i.zauto,{}),zmin:s({},i.zmin,{}),zmax:s({},i.zmax,{})},hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");u.x.editType=u.y.editType=u.z.editType=\"calc+clearAxisTypes\",u.transforms=void 0},{\"../../components/color\":643,\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906}],1312:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/calc\");e.exports=function(t,e){e.surfacecolor?n(t,e,{vals:e.surfacecolor,containerStr:\"\",cLetter:\"c\"}):n(t,e,{vals:e.z,containerStr:\"\",cLetter:\"c\"})}},{\"../../components/colorscale/calc\":651}],1313:[function(t,e,r){\"use strict\";var n=t(\"gl-surface3d\"),i=t(\"ndarray\"),a=t(\"ndarray-linear-interpolate\").d2,o=t(\"../heatmap/interp2d\"),s=t(\"../heatmap/find_empties\"),l=t(\"../../lib\").isArrayOrTypedArray,c=t(\"../../lib/gl_format_color\").parseColorScale,u=t(\"../../lib/str2rgbarray\"),f=t(\"../../components/colorscale\").extractOpts;function h(t,e,r){this.scene=t,this.uid=r,this.surface=e,this.data=null,this.showContour=[!1,!1,!1],this.contourStart=[null,null,null],this.contourEnd=[null,null,null],this.contourSize=[0,0,0],this.minValues=[1/0,1/0,1/0],this.maxValues=[-1/0,-1/0,-1/0],this.dataScaleX=1,this.dataScaleY=1,this.refineData=!0,this.objectOffset=[0,0,0]}var p=h.prototype;p.getXat=function(t,e,r,n){var i=l(this.data.x)?l(this.data.x[0])?this.data.x[e][t]:this.data.x[t]:t;return void 0===r?i:n.d2l(i,0,r)},p.getYat=function(t,e,r,n){var i=l(this.data.y)?l(this.data.y[0])?this.data.y[e][t]:this.data.y[e]:e;return void 0===r?i:n.d2l(i,0,r)},p.getZat=function(t,e,r,n){var i=this.data.z[e][t];return null===i&&this.data.connectgaps&&this.data._interpolatedZ&&(i=this.data._interpolatedZ[e][t]),void 0===r?i:n.d2l(i,0,r)},p.handlePick=function(t){if(t.object===this.surface){var e=(t.data.index[0]-1)/this.dataScaleX-1,r=(t.data.index[1]-1)/this.dataScaleY-1,n=Math.max(Math.min(Math.round(e),this.data.z[0].length-1),0),i=Math.max(Math.min(Math.round(r),this.data._ylength-1),0);t.index=[n,i],t.traceCoordinate=[this.getXat(n,i),this.getYat(n,i),this.getZat(n,i)],t.dataCoordinate=[this.getXat(n,i,this.data.xcalendar,this.scene.fullSceneLayout.xaxis),this.getYat(n,i,this.data.ycalendar,this.scene.fullSceneLayout.yaxis),this.getZat(n,i,this.data.zcalendar,this.scene.fullSceneLayout.zaxis)];for(var a=0;a<3;a++){var o=t.dataCoordinate[a];null!=o&&(t.dataCoordinate[a]*=this.scene.dataScale[a])}var s=this.data.hovertext||this.data.text;return Array.isArray(s)&&s[i]&&void 0!==s[i][n]?t.textLabel=s[i][n]:t.textLabel=s||\"\",t.data.dataCoordinate=t.dataCoordinate.slice(),this.surface.highlight(t.data),this.scene.glplot.spikes.position=t.dataCoordinate,!0}};var d=[2,3,5,7,11,13,17,19,23,29,31,37,41,43,47,53,59,61,67,71,73,79,83,89,97,101,103,107,109,113,127,131,137,139,149,151,157,163,167,173,179,181,191,193,197,199,211,223,227,229,233,239,241,251,257,263,269,271,277,281,283,293,307,311,313,317,331,337,347,349,353,359,367,373,379,383,389,397,401,409,419,421,431,433,439,443,449,457,461,463,467,479,487,491,499,503,509,521,523,541,547,557,563,569,571,577,587,593,599,601,607,613,617,619,631,641,643,647,653,659,661,673,677,683,691,701,709,719,727,733,739,743,751,757,761,769,773,787,797,809,811,821,823,827,829,839,853,857,859,863,877,881,883,887,907,911,919,929,937,941,947,953,967,971,977,983,991,997,1009,1013,1019,1021,1031,1033,1039,1049,1051,1061,1063,1069,1087,1091,1093,1097,1103,1109,1117,1123,1129,1151,1153,1163,1171,1181,1187,1193,1201,1213,1217,1223,1229,1231,1237,1249,1259,1277,1279,1283,1289,1291,1297,1301,1303,1307,1319,1321,1327,1361,1367,1373,1381,1399,1409,1423,1427,1429,1433,1439,1447,1451,1453,1459,1471,1481,1483,1487,1489,1493,1499,1511,1523,1531,1543,1549,1553,1559,1567,1571,1579,1583,1597,1601,1607,1609,1613,1619,1621,1627,1637,1657,1663,1667,1669,1693,1697,1699,1709,1721,1723,1733,1741,1747,1753,1759,1777,1783,1787,1789,1801,1811,1823,1831,1847,1861,1867,1871,1873,1877,1879,1889,1901,1907,1913,1931,1933,1949,1951,1973,1979,1987,1993,1997,1999,2003,2011,2017,2027,2029,2039,2053,2063,2069,2081,2083,2087,2089,2099,2111,2113,2129,2131,2137,2141,2143,2153,2161,2179,2203,2207,2213,2221,2237,2239,2243,2251,2267,2269,2273,2281,2287,2293,2297,2309,2311,2333,2339,2341,2347,2351,2357,2371,2377,2381,2383,2389,2393,2399,2411,2417,2423,2437,2441,2447,2459,2467,2473,2477,2503,2521,2531,2539,2543,2549,2551,2557,2579,2591,2593,2609,2617,2621,2633,2647,2657,2659,2663,2671,2677,2683,2687,2689,2693,2699,2707,2711,2713,2719,2729,2731,2741,2749,2753,2767,2777,2789,2791,2797,2801,2803,2819,2833,2837,2843,2851,2857,2861,2879,2887,2897,2903,2909,2917,2927,2939,2953,2957,2963,2969,2971,2999];function g(t,e){if(t<e)return 0;for(var r=0;0===Math.floor(t%e);)t/=e,r++;return r}function m(t){for(var e=[],r=0;r<d.length;r++){var n=d[r];e.push(g(t,n))}return e}function v(t){for(var e=m(t),r=t,n=0;n<d.length;n++)if(e[n]>0){r=d[n];break}return r}function y(t,e){if(!(t<1||e<1)){for(var r=m(t),n=m(e),i=1,a=0;a<d.length;a++)i*=Math.pow(d[a],Math.max(r[a],n[a]));return i}}p.calcXnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getXat(e-1,0),i=this.getXat(e,0);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r},p.calcYnums=function(t){var e,r=[];for(e=1;e<t;e++){var n=this.getYat(0,e-1),i=this.getYat(0,e);r[e-1]=i!==n&&null!=n&&null!=i?Math.abs(i-n):0}var a=0;for(e=1;e<t;e++)a+=r[e-1];for(e=1;e<t;e++)0===r[e-1]?r[e-1]=1:r[e-1]=Math.round(a/r[e-1]);return r};var x=[1,2,4,6,12,24,36,48,60,120,180,240,360,720,840,1260],b=x[9],_=x[13];function w(t,e,r){var n=r[8]+r[2]*e[0]+r[5]*e[1];return t[0]=(r[6]+r[0]*e[0]+r[3]*e[1])/n,t[1]=(r[7]+r[1]*e[0]+r[4]*e[1])/n,t}function T(t,e,r){return function(t,e,r,n){for(var i=[0,0],o=t.shape[0],s=t.shape[1],l=0;l<o;l++)for(var c=0;c<s;c++)r(i,[l,c],n),t.set(l,c,a(e,i[0],i[1]))}(t,e,w,r),t}function k(t,e){for(var r=!1,n=0;n<t.length;n++)if(e===t[n]){r=!0;break}!1===r&&t.push(e)}p.estimateScale=function(t,e){for(var r=1+function(t){if(0!==t.length){for(var e=1,r=0;r<t.length;r++)e=y(e,t[r]);return e}}(0===e?this.calcXnums(t):this.calcYnums(t));r<b;)r*=2;for(;r>_;)r--,r/=v(r),++r<b&&(r=_);var n=Math.round(r/t);return n>1?n:1},p.refineCoords=function(t){for(var e=this.dataScaleX,r=this.dataScaleY,n=t[0].shape[0],a=t[0].shape[1],o=0|Math.floor(t[0].shape[0]*e+1),s=0|Math.floor(t[0].shape[1]*r+1),l=1+n+1,c=1+a+1,u=i(new Float32Array(l*c),[l,c]),f=[1/e,0,0,0,1/r,0,0,0,1],h=0;h<t.length;++h){this.surface.padField(u,t[h]);var p=i(new Float32Array(o*s),[o,s]);T(p,u,f),t[h]=p}},p.setContourLevels=function(){var t,e,r,n=[[],[],[]],i=[!1,!1,!1],a=!1;for(t=0;t<3;++t)if(this.showContour[t]&&(a=!0,this.contourSize[t]>0&&null!==this.contourStart[t]&&null!==this.contourEnd[t]&&this.contourEnd[t]>this.contourStart[t]))for(i[t]=!0,e=this.contourStart[t];e<this.contourEnd[t];e+=this.contourSize[t])r=e*this.scene.dataScale[t],k(n[t],r);if(a){var o=[[],[],[]];for(t=0;t<3;++t)this.showContour[t]&&(o[t]=i[t]?n[t]:this.scene.contourLevels[t]);this.surface.update({levels:o})}},p.update=function(t){var e,r,n,a,l=this.scene,h=l.fullSceneLayout,p=this.surface,d=c(t),g=l.dataScale,m=t.z[0].length,v=t._ylength,y=l.contourLevels;this.data=t;var x=[];for(e=0;e<3;e++)for(x[e]=[],r=0;r<m;r++)x[e][r]=[];for(r=0;r<m;r++)for(n=0;n<v;n++)x[0][r][n]=this.getXat(r,n,t.xcalendar,h.xaxis),x[1][r][n]=this.getYat(r,n,t.ycalendar,h.yaxis),x[2][r][n]=this.getZat(r,n,t.zcalendar,h.zaxis);if(t.connectgaps)for(t._emptypoints=s(x[2]),o(x[2],t._emptypoints),t._interpolatedZ=[],r=0;r<m;r++)for(t._interpolatedZ[r]=[],n=0;n<v;n++)t._interpolatedZ[r][n]=x[2][r][n];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null==(a=x[e][r][n])?x[e][r][n]=NaN:a=x[e][r][n]*=g[e];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(this.minValues[e]>a&&(this.minValues[e]=a),this.maxValues[e]<a&&(this.maxValues[e]=a));for(e=0;e<3;e++)this.objectOffset[e]=.5*(this.minValues[e]+this.maxValues[e]);for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)null!=(a=x[e][r][n])&&(x[e][r][n]-=this.objectOffset[e]);var b=[i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v]),i(new Float32Array(m*v),[m,v])];for(e=0;e<3;e++)for(r=0;r<m;r++)for(n=0;n<v;n++)b[e].set(r,n,x[e][r][n]);x=[];var w={colormap:d,levels:[[],[],[]],showContour:[!0,!0,!0],showSurface:!t.hidesurface,contourProject:[[!1,!1,!1],[!1,!1,!1],[!1,!1,!1]],contourWidth:[1,1,1],contourColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],contourTint:[1,1,1],dynamicColor:[[1,1,1,1],[1,1,1,1],[1,1,1,1]],dynamicWidth:[1,1,1],dynamicTint:[1,1,1],opacityscale:t.opacityscale,opacity:t.opacity},T=f(t);if(w.intensityBounds=[T.min,T.max],t.surfacecolor){var k=i(new Float32Array(m*v),[m,v]);for(r=0;r<m;r++)for(n=0;n<v;n++)k.set(r,n,t.surfacecolor[n][r]);b.push(k)}else w.intensityBounds[0]*=g[2],w.intensityBounds[1]*=g[2];(_<b[0].shape[0]||_<b[0].shape[1])&&(this.refineData=!1),!0===this.refineData&&(this.dataScaleX=this.estimateScale(b[0].shape[0],0),this.dataScaleY=this.estimateScale(b[0].shape[1],1),1===this.dataScaleX&&1===this.dataScaleY||this.refineCoords(b)),t.surfacecolor&&(w.intensity=b.pop());var M=[!0,!0,!0],A=[\"x\",\"y\",\"z\"];for(e=0;e<3;++e){var S=t.contours[A[e]];M[e]=S.highlight,w.showContour[e]=S.show||S.highlight,w.showContour[e]&&(w.contourProject[e]=[S.project.x,S.project.y,S.project.z],S.show?(this.showContour[e]=!0,w.levels[e]=y[e],p.highlightColor[e]=w.contourColor[e]=u(S.color),S.usecolormap?p.highlightTint[e]=w.contourTint[e]=0:p.highlightTint[e]=w.contourTint[e]=1,w.contourWidth[e]=S.width,this.contourStart[e]=S.start,this.contourEnd[e]=S.end,this.contourSize[e]=S.size):(this.showContour[e]=!1,this.contourStart[e]=null,this.contourEnd[e]=null,this.contourSize[e]=0),S.highlight&&(w.dynamicColor[e]=u(S.highlightcolor),w.dynamicWidth[e]=S.highlightwidth))}(function(t){var e=t[0].rgb,r=t[t.length-1].rgb;return e[0]===r[0]&&e[1]===r[1]&&e[2]===r[2]&&e[3]===r[3]})(d)&&(w.vertexColor=!0),w.objectOffset=this.objectOffset,w.coords=b,p.update(w),p.visible=t.visible,p.enableDynamic=M,p.enableHighlight=M,p.snapToData=!0,\"lighting\"in t&&(p.ambientLight=t.lighting.ambient,p.diffuseLight=t.lighting.diffuse,p.specularLight=t.lighting.specular,p.roughness=t.lighting.roughness,p.fresnel=t.lighting.fresnel),\"lightposition\"in t&&(p.lightPosition=[t.lightposition.x,t.lightposition.y,t.lightposition.z])},p.dispose=function(){this.scene.glplot.remove(this.surface),this.surface.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new h(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib\":778,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../heatmap/find_empties\":1071,\"../heatmap/interp2d\":1074,\"gl-surface3d\":351,ndarray:495,\"ndarray-linear-interpolate\":489}],1314:[function(t,e,r){\"use strict\";var n=t(\"../../registry\"),i=t(\"../../lib\"),a=t(\"../../components/colorscale/defaults\"),o=t(\"./attributes\");function s(t,e,r,n){var i=n(\"opacityscale\");\"max\"===i?e.opacityscale=[[0,.1],[1,1]]:\"min\"===i?e.opacityscale=[[0,1],[1,.1]]:\"extremes\"===i?e.opacityscale=function(t,e){for(var r=[],n=0;n<32;n++){var i=n/31,a=e+(1-e)*(1-Math.pow(Math.sin(t*i*Math.PI),2));r.push([i,Math.max(0,Math.min(1,a))])}return r}(1,.1):function(t){var e=0;if(!Array.isArray(t)||t.length<2)return!1;if(!t[0]||!t[t.length-1])return!1;if(0!=+t[0][0]||1!=+t[t.length-1][0])return!1;for(var r=0;r<t.length;r++){var n=t[r];if(2!==n.length||+n[0]<e)return!1;e=+n[0]}return!0}(i)||(e.opacityscale=void 0)}function l(t,e,r){e in t&&!(r in t)&&(t[r]=t[e])}e.exports={supplyDefaults:function(t,e,r,c){var u,f;function h(r,n){return i.coerce(t,e,o,r,n)}var p=h(\"x\"),d=h(\"y\"),g=h(\"z\");if(!g||!g.length||p&&p.length<1||d&&d.length<1)e.visible=!1;else{e._xlength=Array.isArray(p)&&i.isArrayOrTypedArray(p[0])?g.length:g[0].length,e._ylength=g.length,n.getComponentMethod(\"calendars\",\"handleTraceDefaults\")(t,e,[\"x\",\"y\",\"z\"],c),h(\"text\"),h(\"hovertext\"),h(\"hovertemplate\"),[\"lighting.ambient\",\"lighting.diffuse\",\"lighting.specular\",\"lighting.roughness\",\"lighting.fresnel\",\"lightposition.x\",\"lightposition.y\",\"lightposition.z\",\"hidesurface\",\"connectgaps\",\"opacity\"].forEach((function(t){h(t)}));var m=h(\"surfacecolor\"),v=[\"x\",\"y\",\"z\"];for(u=0;u<3;++u){var y=\"contours.\"+v[u],x=h(y+\".show\"),b=h(y+\".highlight\");if(x||b)for(f=0;f<3;++f)h(y+\".project.\"+v[f]);x&&(h(y+\".color\"),h(y+\".width\"),h(y+\".usecolormap\")),b&&(h(y+\".highlightcolor\"),h(y+\".highlightwidth\")),h(y+\".start\"),h(y+\".end\"),h(y+\".size\")}m||(l(t,\"zmin\",\"cmin\"),l(t,\"zmax\",\"cmax\"),l(t,\"zauto\",\"cauto\")),a(t,e,c,h,{prefix:\"\",cLetter:\"c\"}),s(t,e,c,h),e._length=null}},opacityscaleDefaults:s}},{\"../../components/colorscale/defaults\":653,\"../../lib\":778,\"../../registry\":911,\"./attributes\":1311}],1315:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,colorbar:{min:\"cmin\",max:\"cmax\"},calc:t(\"./calc\"),plot:t(\"./convert\"),moduleType:\"trace\",name:\"surface\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"2dMap\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"./attributes\":1311,\"./calc\":1312,\"./convert\":1313,\"./defaults\":1314}],1316:[function(t,e,r){\"use strict\";var n=t(\"../../components/annotations/attributes\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"../../plot_api/edit_types\").overrideAll,o=t(\"../../plots/font_attributes\"),s=t(\"../../plots/domain\").attributes;t(\"../../constants/docs\").FORMAT_LINK;(e.exports=a({domain:s({name:\"table\",trace:!0}),columnwidth:{valType:\"number\",arrayOk:!0,dflt:null},columnorder:{valType:\"data_array\"},header:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:28},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))},cells:{values:{valType:\"data_array\",dflt:[]},format:{valType:\"data_array\",dflt:[]},prefix:{valType:\"string\",arrayOk:!0,dflt:null},suffix:{valType:\"string\",arrayOk:!0,dflt:null},height:{valType:\"number\",dflt:20},align:i({},n.align,{arrayOk:!0}),line:{width:{valType:\"number\",arrayOk:!0,dflt:1},color:{valType:\"color\",arrayOk:!0,dflt:\"grey\"}},fill:{color:{valType:\"color\",arrayOk:!0,dflt:\"white\"}},font:i({},o({arrayOk:!0}))}},\"calc\",\"from-root\")).transforms=void 0},{\"../../components/annotations/attributes\":626,\"../../constants/docs\":748,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/domain\":855,\"../../plots/font_attributes\":856}],1317:[function(t,e,r){\"use strict\";var n=t(\"../../plots/get_data\").getModuleCalcData,i=t(\"./plot\");r.name=\"table\",r.plot=function(t){var e=n(t.calcdata,\"table\")[0];e.length&&i(t,e)},r.clean=function(t,e,r,n){var i=n._has&&n._has(\"table\"),a=e._has&&e._has(\"table\");i&&!a&&n._paperdiv.selectAll(\".table\").remove()}},{\"../../plots/get_data\":865,\"./plot\":1324}],1318:[function(t,e,r){\"use strict\";var n=t(\"../../lib/gup\").wrap;e.exports=function(){return n({})}},{\"../../lib/gup\":775}],1319:[function(t,e,r){\"use strict\";e.exports={cellPad:8,columnExtentOffset:10,columnTitleOffset:28,emptyHeaderHeight:16,latexCheck:/^\\$.*\\$$/,goldenRatio:1.618,lineBreaker:\"<br>\",maxDimensionCount:60,overdrag:45,releaseTransitionDuration:120,releaseTransitionEase:\"cubic-out\",scrollbarCaptureWidth:18,scrollbarHideDelay:1e3,scrollbarHideDuration:1e3,scrollbarOffset:5,scrollbarWidth:8,transitionDuration:100,transitionEase:\"cubic-out\",uplift:5,wrapSpacer:\" \",wrapSplitCharacter:\" \",cn:{table:\"table\",tableControlView:\"table-control-view\",scrollBackground:\"scroll-background\",yColumn:\"y-column\",columnBlock:\"column-block\",scrollAreaClip:\"scroll-area-clip\",scrollAreaClipRect:\"scroll-area-clip-rect\",columnBoundary:\"column-boundary\",columnBoundaryClippath:\"column-boundary-clippath\",columnBoundaryRect:\"column-boundary-rect\",columnCells:\"column-cells\",columnCell:\"column-cell\",cellRect:\"cell-rect\",cellText:\"cell-text\",cellTextHolder:\"cell-text-holder\",scrollbarKit:\"scrollbar-kit\",scrollbar:\"scrollbar\",scrollbarSlider:\"scrollbar-slider\",scrollbarGlyph:\"scrollbar-glyph\",scrollbarCaptureZone:\"scrollbar-capture-zone\"}}},{}],1320:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"../../lib/extend\").extendFlat,a=t(\"fast-isnumeric\");function o(t){if(Array.isArray(t)){for(var e=0,r=0;r<t.length;r++)e=Math.max(e,o(t[r]));return e}return t}function s(t,e){return t+e}function l(t){var e,r=t.slice(),n=1/0,i=0;for(e=0;e<r.length;e++)Array.isArray(r[e])||(r[e]=[r[e]]),n=Math.min(n,r[e].length),i=Math.max(i,r[e].length);if(n!==i)for(e=0;e<r.length;e++){var a=i-r[e].length;a&&(r[e]=r[e].concat(c(a)))}return r}function c(t){for(var e=new Array(t),r=0;r<t;r++)e[r]=\"\";return e}function u(t){return t.calcdata.columns.reduce((function(e,r){return r.xIndex<t.xIndex?e+r.columnWidth:e}),0)}function f(t,e){return Object.keys(t).map((function(r){return i({},t[r],{auxiliaryBlocks:e})}))}function h(t,e){for(var r,n={},i=0,a=0,o={firstRowIndex:null,lastRowIndex:null,rows:[]},s=0,l=0,c=0;c<t.length;c++)r=t[c],o.rows.push({rowIndex:c,rowHeight:r}),((a+=r)>=e||c===t.length-1)&&(n[i]=o,o.key=l++,o.firstRowIndex=s,o.lastRowIndex=c,o={firstRowIndex:null,lastRowIndex:null,rows:[]},i+=a,s=c+1,a=0);return n}e.exports=function(t,e){var r=l(e.cells.values),p=function(t){return t.slice(e.header.values.length,t.length)},d=l(e.header.values);d.length&&!d[0].length&&(d[0]=[\"\"],d=l(d));var g=d.concat(p(r).map((function(){return c((d[0]||[\"\"]).length)}))),m=e.domain,v=Math.floor(t._fullLayout._size.w*(m.x[1]-m.x[0])),y=Math.floor(t._fullLayout._size.h*(m.y[1]-m.y[0])),x=e.header.values.length?g[0].map((function(){return e.header.height})):[n.emptyHeaderHeight],b=r.length?r[0].map((function(){return e.cells.height})):[],_=x.reduce(s,0),w=h(b,y-_+n.uplift),T=f(h(x,_),[]),k=f(w,T),M={},A=e._fullInput.columnorder.concat(p(r.map((function(t,e){return e})))),S=g.map((function(t,r){var n=Array.isArray(e.columnwidth)?e.columnwidth[Math.min(r,e.columnwidth.length-1)]:e.columnwidth;return a(n)?Number(n):1})),E=S.reduce(s,0);S=S.map((function(t){return t/E*v}));var C=Math.max(o(e.header.line.width),o(e.cells.line.width)),L={key:e.uid+t._context.staticPlot,translateX:m.x[0]*t._fullLayout._size.w,translateY:t._fullLayout._size.h*(1-m.y[1]),size:t._fullLayout._size,width:v,maxLineWidth:C,height:y,columnOrder:A,groupHeight:y,rowBlocks:k,headerRowBlocks:T,scrollY:0,cells:i({},e.cells,{values:r}),headerCells:i({},e.header,{values:g}),gdColumns:g.map((function(t){return t[0]})),gdColumnsOriginalOrder:g.map((function(t){return t[0]})),prevPages:[0,0],scrollbarState:{scrollbarScrollInProgress:!1},columns:g.map((function(t,e){var r=M[t];return M[t]=(r||0)+1,{key:t+\"__\"+M[t],label:t,specIndex:e,xIndex:A[e],xScale:u,x:void 0,calcdata:void 0,columnWidth:S[e]}}))};return L.columns.forEach((function(t){t.calcdata=L,t.x=u(t)})),L}},{\"../../lib/extend\":768,\"./constants\":1319,\"fast-isnumeric\":241}],1321:[function(t,e,r){\"use strict\";var n=t(\"../../lib/extend\").extendFlat;r.splitToPanels=function(t){var e=[0,0],r=n({},t,{key:\"header\",type:\"header\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!0,values:t.calcdata.headerCells.values[t.specIndex],rowBlocks:t.calcdata.headerRowBlocks,calcdata:n({},t.calcdata,{cells:t.calcdata.headerCells})});return[n({},t,{key:\"cells1\",type:\"cells\",page:0,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),n({},t,{key:\"cells2\",type:\"cells\",page:1,prevPages:e,currentRepaint:[null,null],dragHandle:!1,values:t.calcdata.cells.values[t.specIndex],rowBlocks:t.calcdata.rowBlocks}),r]},r.splitToCells=function(t){var e=function(t){var e=t.rowBlocks[t.page],r=e?e.rows[0].rowIndex:0,n=e?r+e.rows.length:0;return[r,n]}(t);return(t.values||[]).slice(e[0],e[1]).map((function(r,n){return{keyWithinBlock:n+(\"string\"==typeof r&&r.match(/[<$&> ]/)?\"_keybuster_\"+Math.random():\"\"),key:e[0]+n,column:t,calcdata:t.calcdata,page:t.page,rowBlocks:t.rowBlocks,value:r}}))}},{\"../../lib/extend\":768}],1322:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../plots/domain\").defaults;e.exports=function(t,e,r,o){function s(r,a){return n.coerce(t,e,i,r,a)}a(e,o,s),s(\"columnwidth\"),s(\"header.values\"),s(\"header.format\"),s(\"header.align\"),s(\"header.prefix\"),s(\"header.suffix\"),s(\"header.height\"),s(\"header.line.width\"),s(\"header.line.color\"),s(\"header.fill.color\"),n.coerceFont(s,\"header.font\",n.extendFlat({},o.font)),function(t,e){for(var r=t.columnorder||[],n=t.header.values.length,i=r.slice(0,n),a=i.slice().sort((function(t,e){return t-e})),o=i.map((function(t){return a.indexOf(t)})),s=o.length;s<n;s++)o.push(s);e(\"columnorder\",o)}(e,s),s(\"cells.values\"),s(\"cells.format\"),s(\"cells.align\"),s(\"cells.prefix\"),s(\"cells.suffix\"),s(\"cells.height\"),s(\"cells.line.width\"),s(\"cells.line.color\"),s(\"cells.fill.color\"),n.coerceFont(s,\"cells.font\",n.extendFlat({},o.font)),e._length=null}},{\"../../lib\":778,\"../../plots/domain\":855,\"./attributes\":1316}],1323:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"./calc\"),plot:t(\"./plot\"),moduleType:\"trace\",name:\"table\",basePlotModule:t(\"./base_plot\"),categories:[\"noOpacity\"],meta:{}}},{\"./attributes\":1316,\"./base_plot\":1317,\"./calc\":1318,\"./defaults\":1322,\"./plot\":1324}],1324:[function(t,e,r){\"use strict\";var n=t(\"./constants\"),i=t(\"d3\"),a=t(\"../../lib/gup\"),o=t(\"../../components/drawing\"),s=t(\"../../lib/svg_text_utils\"),l=t(\"../../lib\").raiseToTop,c=t(\"../../lib\").strTranslate,u=t(\"../../lib\").cancelTransition,f=t(\"./data_preparation_helper\"),h=t(\"./data_split_helpers\"),p=t(\"../../components/color\");function d(t){return Math.ceil(t.calcdata.maxLineWidth/2)}function g(t,e){return\"clip\"+t._fullLayout._uid+\"_scrollAreaBottomClip_\"+e.key}function m(t,e){return\"clip\"+t._fullLayout._uid+\"_columnBoundaryClippath_\"+e.calcdata.key+\"_\"+e.specIndex}function v(t){return[].concat.apply([],t.map((function(t){return t}))).map((function(t){return t.__data__}))}function y(t,e,r){var o=t.selectAll(\".\"+n.cn.scrollbarKit).data(a.repeat,a.keyFun);o.enter().append(\"g\").classed(n.cn.scrollbarKit,!0).style(\"shape-rendering\",\"geometricPrecision\"),o.each((function(t){var e=t.scrollbarState;e.totalHeight=function(t){var e=t.rowBlocks;return O(e,e.length-1)+(e.length?D(e[e.length-1],1/0):1)}(t),e.scrollableAreaHeight=t.groupHeight-A(t),e.currentlyVisibleHeight=Math.min(e.totalHeight,e.scrollableAreaHeight),e.ratio=e.currentlyVisibleHeight/e.totalHeight,e.barLength=Math.max(e.ratio*e.currentlyVisibleHeight,n.goldenRatio*n.scrollbarWidth),e.barWiggleRoom=e.currentlyVisibleHeight-e.barLength,e.wiggleRoom=Math.max(0,e.totalHeight-e.scrollableAreaHeight),e.topY=0===e.barWiggleRoom?0:t.scrollY/e.wiggleRoom*e.barWiggleRoom,e.bottomY=e.topY+e.barLength,e.dragMultiplier=e.wiggleRoom/e.barWiggleRoom})).attr(\"transform\",(function(t){var e=t.width+n.scrollbarWidth/2+n.scrollbarOffset;return c(e,A(t))}));var s=o.selectAll(\".\"+n.cn.scrollbar).data(a.repeat,a.keyFun);s.enter().append(\"g\").classed(n.cn.scrollbar,!0);var l=s.selectAll(\".\"+n.cn.scrollbarSlider).data(a.repeat,a.keyFun);l.enter().append(\"g\").classed(n.cn.scrollbarSlider,!0),l.attr(\"transform\",(function(t){return c(0,t.scrollbarState.topY||0)}));var u=l.selectAll(\".\"+n.cn.scrollbarGlyph).data(a.repeat,a.keyFun);u.enter().append(\"line\").classed(n.cn.scrollbarGlyph,!0).attr(\"stroke\",\"black\").attr(\"stroke-width\",n.scrollbarWidth).attr(\"stroke-linecap\",\"round\").attr(\"y1\",n.scrollbarWidth/2),u.attr(\"y2\",(function(t){return t.scrollbarState.barLength-n.scrollbarWidth/2})).attr(\"stroke-opacity\",(function(t){return t.columnDragInProgress||!t.scrollbarState.barWiggleRoom||r?0:.4})),u.transition().delay(0).duration(0),u.transition().delay(n.scrollbarHideDelay).duration(n.scrollbarHideDuration).attr(\"stroke-opacity\",0);var f=s.selectAll(\".\"+n.cn.scrollbarCaptureZone).data(a.repeat,a.keyFun);f.enter().append(\"line\").classed(n.cn.scrollbarCaptureZone,!0).attr(\"stroke\",\"white\").attr(\"stroke-opacity\",.01).attr(\"stroke-width\",n.scrollbarCaptureWidth).attr(\"stroke-linecap\",\"butt\").attr(\"y1\",0).on(\"mousedown\",(function(r){var n=i.event.y,a=this.getBoundingClientRect(),o=r.scrollbarState,s=n-a.top,l=i.scale.linear().domain([0,o.scrollableAreaHeight]).range([0,o.totalHeight]).clamp(!0);o.topY<=s&&s<=o.bottomY||E(e,t,null,l(s-o.barLength/2))(r)})).call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t.scrollbarState.scrollbarScrollInProgress=!0,t})).on(\"drag\",E(e,t)).on(\"dragend\",(function(){}))),f.attr(\"y2\",(function(t){return t.scrollbarState.scrollableAreaHeight})),e._context.staticPlot&&(u.remove(),f.remove())}function x(t,e,r,s){var l=function(t){var e=t.selectAll(\".\"+n.cn.columnCell).data(h.splitToCells,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.columnCell,!0),e.exit().remove(),e}(function(t){var e=t.selectAll(\".\"+n.cn.columnCells).data(a.repeat,a.keyFun);return e.enter().append(\"g\").classed(n.cn.columnCells,!0),e.exit().remove(),e}(r));!function(t){t.each((function(t,e){var r=t.calcdata.cells.font,n=t.column.specIndex,i={size:w(r.size,n,e),color:w(r.color,n,e),family:w(r.family,n,e)};t.rowNumber=t.key,t.align=w(t.calcdata.cells.align,n,e),t.cellBorderWidth=w(t.calcdata.cells.line.width,n,e),t.font=i}))}(l),function(t){t.attr(\"width\",(function(t){return t.column.columnWidth})).attr(\"stroke-width\",(function(t){return t.cellBorderWidth})).each((function(t){var e=i.select(this);p.stroke(e,w(t.calcdata.cells.line.color,t.column.specIndex,t.rowNumber)),p.fill(e,w(t.calcdata.cells.fill.color,t.column.specIndex,t.rowNumber))}))}(function(t){var e=t.selectAll(\".\"+n.cn.cellRect).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"rect\").classed(n.cn.cellRect,!0),e}(l));var c=function(t){var e=t.selectAll(\".\"+n.cn.cellText).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"text\").classed(n.cn.cellText,!0).style(\"cursor\",(function(){return\"auto\"})).on(\"mousedown\",(function(){i.event.stopPropagation()})),e}(function(t){var e=t.selectAll(\".\"+n.cn.cellTextHolder).data(a.repeat,(function(t){return t.keyWithinBlock}));return e.enter().append(\"g\").classed(n.cn.cellTextHolder,!0).style(\"shape-rendering\",\"geometricPrecision\"),e}(l));!function(t){t.each((function(t){o.font(i.select(this),t.font)}))}(c),b(c,e,s,t),z(l)}function b(t,e,r,a){t.text((function(t){var e=t.column.specIndex,r=t.rowNumber,a=t.value,o=\"string\"==typeof a,s=o&&a.match(/<br>/i),l=!o||s;t.mayHaveMarkup=o&&a.match(/[<&>]/);var c,u=\"string\"==typeof(c=a)&&c.match(n.latexCheck);t.latex=u;var f,h,p=u?\"\":w(t.calcdata.cells.prefix,e,r)||\"\",d=u?\"\":w(t.calcdata.cells.suffix,e,r)||\"\",g=u?null:w(t.calcdata.cells.format,e,r)||null,m=p+(g?i.format(g)(t.value):t.value)+d;if(t.wrappingNeeded=!t.wrapped&&!l&&!u&&(f=_(m)),t.cellHeightMayIncrease=s||u||t.mayHaveMarkup||(void 0===f?_(m):f),t.needsConvertToTspans=t.mayHaveMarkup||t.wrappingNeeded||t.latex,t.wrappingNeeded){var v=(\" \"===n.wrapSplitCharacter?m.replace(/<a href=/gi,\"<a_href=\"):m).split(n.wrapSplitCharacter),y=\" \"===n.wrapSplitCharacter?v.map((function(t){return t.replace(/<a_href=/gi,\"<a href=\")})):v;t.fragments=y.map((function(t){return{text:t,width:null}})),t.fragments.push({fragment:n.wrapSpacer,width:null}),h=y.join(n.lineBreaker)+n.lineBreaker+n.wrapSpacer}else delete t.fragments,h=m;return h})).attr(\"dy\",(function(t){return t.needsConvertToTspans?0:\"0.75em\"})).each((function(t){var o=i.select(this),l=t.wrappingNeeded?L:I;t.needsConvertToTspans?s.convertToTspans(o,a,l(r,this,e,a,t)):i.select(this.parentNode).attr(\"transform\",(function(t){return c(P(t),n.cellPad)})).attr(\"text-anchor\",(function(t){return{left:\"start\",center:\"middle\",right:\"end\"}[t.align]}))}))}function _(t){return-1!==t.indexOf(n.wrapSplitCharacter)}function w(t,e,r){if(Array.isArray(t)){var n=t[Math.min(e,t.length-1)];return Array.isArray(n)?n[Math.min(r,n.length-1)]:n}return t}function T(t,e,r){t.transition().ease(n.releaseTransitionEase).duration(n.releaseTransitionDuration).attr(\"transform\",c(e.x,r))}function k(t){return\"cells\"===t.type}function M(t){return\"header\"===t.type}function A(t){return(t.rowBlocks.length?t.rowBlocks[0].auxiliaryBlocks:[]).reduce((function(t,e){return t+D(e,1/0)}),0)}function S(t,e,r){var n=v(e)[0];if(void 0!==n){var i=n.rowBlocks,a=n.calcdata,o=O(i,i.length),s=n.calcdata.groupHeight-A(n),l=a.scrollY=Math.max(0,Math.min(o-s,a.scrollY)),u=function(t,e,r){for(var n=[],i=0,a=0;a<t.length;a++){for(var o=t[a],s=o.rows,l=0,c=0;c<s.length;c++)l+=s[c].rowHeight;o.allRowsHeight=l;e<i+l&&e+r>i&&n.push(a),i+=l}return n}(i,l,s);1===u.length&&(u[0]===i.length-1?u.unshift(u[0]-1):u.push(u[0]+1)),u[0]%2&&u.reverse(),e.each((function(t,e){t.page=u[e],t.scrollY=l})),e.attr(\"transform\",(function(t){var e=O(t.rowBlocks,t.page)-t.scrollY;return c(0,e)})),t&&(C(t,r,e,u,n.prevPages,n,0),C(t,r,e,u,n.prevPages,n,1),y(r,t))}}function E(t,e,r,a){return function(o){var s=o.calcdata?o.calcdata:o,l=e.filter((function(t){return s.key===t.key})),c=r||s.scrollbarState.dragMultiplier,u=s.scrollY;s.scrollY=void 0===a?s.scrollY+c*i.event.dy:a;var f=l.selectAll(\".\"+n.cn.yColumn).selectAll(\".\"+n.cn.columnBlock).filter(k);return S(t,f,l),s.scrollY===u}}function C(t,e,r,n,i,a,o){n[o]!==i[o]&&(clearTimeout(a.currentRepaint[o]),a.currentRepaint[o]=setTimeout((function(){var a=r.filter((function(t,e){return e===o&&n[e]!==i[e]}));x(t,e,a,r),i[o]=n[o]})))}function L(t,e,r,a){return function(){var o=i.select(e.parentNode);o.each((function(t){var e=t.fragments;o.selectAll(\"tspan.line\").each((function(t,r){e[r].width=this.getComputedTextLength()}));var r,i,a=e[e.length-1].width,s=e.slice(0,-1),l=[],c=0,u=t.column.columnWidth-2*n.cellPad;for(t.value=\"\";s.length;)c+(i=(r=s.shift()).width+a)>u&&(t.value+=l.join(n.wrapSpacer)+n.lineBreaker,l=[],c=0),l.push(r.text),c+=i;c&&(t.value+=l.join(n.wrapSpacer)),t.wrapped=!0})),o.selectAll(\"tspan.line\").remove(),b(o.select(\".\"+n.cn.cellText),r,t,a),i.select(e.parentNode.parentNode).call(z)}}function I(t,e,r,a,o){return function(){if(!o.settledY){var s=i.select(e.parentNode),l=F(o),u=o.key-l.firstRowIndex,f=l.rows[u].rowHeight,h=o.cellHeightMayIncrease?e.parentNode.getBoundingClientRect().height+2*n.cellPad:f,p=Math.max(h,f);p-l.rows[u].rowHeight&&(l.rows[u].rowHeight=p,t.selectAll(\".\"+n.cn.columnCell).call(z),S(null,t.filter(k),0),y(r,a,!0)),s.attr(\"transform\",(function(){var t=this.parentNode.getBoundingClientRect(),e=i.select(this.parentNode).select(\".\"+n.cn.cellRect).node().getBoundingClientRect(),r=this.transform.baseVal.consolidate(),a=e.top-t.top+(r?r.matrix.f:n.cellPad);return c(P(o,i.select(this.parentNode).select(\".\"+n.cn.cellTextHolder).node().getBoundingClientRect().width),a)})),o.settledY=!0}}}function P(t,e){switch(t.align){case\"left\":return n.cellPad;case\"right\":return t.column.columnWidth-(e||0)-n.cellPad;case\"center\":return(t.column.columnWidth-(e||0))/2;default:return n.cellPad}}function z(t){t.attr(\"transform\",(function(t){var e=t.rowBlocks[0].auxiliaryBlocks.reduce((function(t,e){return t+D(e,1/0)}),0),r=D(F(t),t.key);return c(0,r+e)})).selectAll(\".\"+n.cn.cellRect).attr(\"height\",(function(t){return(e=F(t),r=t.key,e.rows[r-e.firstRowIndex]).rowHeight;var e,r}))}function O(t,e){for(var r=0,n=e-1;n>=0;n--)r+=R(t[n]);return r}function D(t,e){for(var r=0,n=0;n<t.rows.length&&t.rows[n].rowIndex<e;n++)r+=t.rows[n].rowHeight;return r}function R(t){var e=t.allRowsHeight;if(void 0!==e)return e;for(var r=0,n=0;n<t.rows.length;n++)r+=t.rows[n].rowHeight;return t.allRowsHeight=r,r}function F(t){return t.rowBlocks[t.page]}e.exports=function(t,e){var r=!t._context.staticPlot,s=t._fullLayout._paper.selectAll(\".\"+n.cn.table).data(e.map((function(e){var r=a.unwrap(e).trace;return f(t,r)})),a.keyFun);s.exit().remove(),s.enter().append(\"g\").classed(n.cn.table,!0).attr(\"overflow\",\"visible\").style(\"box-sizing\",\"content-box\").style(\"position\",\"absolute\").style(\"left\",0).style(\"overflow\",\"visible\").style(\"shape-rendering\",\"crispEdges\").style(\"pointer-events\",\"all\"),s.attr(\"width\",(function(t){return t.width+t.size.l+t.size.r})).attr(\"height\",(function(t){return t.height+t.size.t+t.size.b})).attr(\"transform\",(function(t){return c(t.translateX,t.translateY)}));var p=s.selectAll(\".\"+n.cn.tableControlView).data(a.repeat,a.keyFun),b=p.enter().append(\"g\").classed(n.cn.tableControlView,!0).style(\"box-sizing\",\"content-box\");if(r){var _=\"onwheel\"in document?\"wheel\":\"mousewheel\";b.on(\"mousemove\",(function(e){p.filter((function(t){return e===t})).call(y,t)})).on(_,(function(e){if(!e.scrollbarState.wheeling){e.scrollbarState.wheeling=!0;var r=e.scrollY+i.event.deltaY;E(t,p,null,r)(e)||(i.event.stopPropagation(),i.event.preventDefault()),e.scrollbarState.wheeling=!1}})).call(y,t,!0)}p.attr(\"transform\",(function(t){return c(t.size.l,t.size.t)}));var w=p.selectAll(\".\"+n.cn.scrollBackground).data(a.repeat,a.keyFun);w.enter().append(\"rect\").classed(n.cn.scrollBackground,!0).attr(\"fill\",\"none\"),w.attr(\"width\",(function(t){return t.width})).attr(\"height\",(function(t){return t.height})),p.each((function(e){o.setClipUrl(i.select(this),g(t,e),t)}));var A=p.selectAll(\".\"+n.cn.yColumn).data((function(t){return t.columns}),a.keyFun);A.enter().append(\"g\").classed(n.cn.yColumn,!0),A.exit().remove(),A.attr(\"transform\",(function(t){return c(t.x,0)})),r&&A.call(i.behavior.drag().origin((function(e){return T(i.select(this),e,-n.uplift),l(this),e.calcdata.columnDragInProgress=!0,y(p.filter((function(t){return e.calcdata.key===t.key})),t),e})).on(\"drag\",(function(t){var e=i.select(this),r=function(e){return(t===e?i.event.x:e.x)+e.columnWidth/2};t.x=Math.max(-n.overdrag,Math.min(t.calcdata.width+n.overdrag-t.columnWidth,i.event.x)),v(A).filter((function(e){return e.calcdata.key===t.calcdata.key})).sort((function(t,e){return r(t)-r(e)})).forEach((function(e,r){e.xIndex=r,e.x=t===e?e.x:e.xScale(e)})),A.filter((function(e){return t!==e})).transition().ease(n.transitionEase).duration(n.transitionDuration).attr(\"transform\",(function(t){return c(t.x,0)})),e.call(u).attr(\"transform\",c(t.x,-n.uplift))})).on(\"dragend\",(function(e){var r=i.select(this),n=e.calcdata;e.x=e.xScale(e),e.calcdata.columnDragInProgress=!1,T(r,e,0),function(t,e,r){var n=e.gdColumnsOriginalOrder;e.gdColumns.sort((function(t,e){return r[n.indexOf(t)]-r[n.indexOf(e)]})),e.columnorder=r,t.emit(\"plotly_restyle\")}(t,n,n.columns.map((function(t){return t.xIndex})))}))),A.each((function(e){o.setClipUrl(i.select(this),m(t,e),t)}));var C=A.selectAll(\".\"+n.cn.columnBlock).data(h.splitToPanels,a.keyFun);C.enter().append(\"g\").classed(n.cn.columnBlock,!0).attr(\"id\",(function(t){return t.key})),C.style(\"cursor\",(function(t){return t.dragHandle?\"ew-resize\":t.calcdata.scrollbarState.barWiggleRoom?\"ns-resize\":\"default\"}));var L=C.filter(M),I=C.filter(k);r&&I.call(i.behavior.drag().origin((function(t){return i.event.stopPropagation(),t})).on(\"drag\",E(t,p,-1)).on(\"dragend\",(function(){}))),x(t,p,L,C),x(t,p,I,C);var P=p.selectAll(\".\"+n.cn.scrollAreaClip).data(a.repeat,a.keyFun);P.enter().append(\"clipPath\").classed(n.cn.scrollAreaClip,!0).attr(\"id\",(function(e){return g(t,e)}));var z=P.selectAll(\".\"+n.cn.scrollAreaClipRect).data(a.repeat,a.keyFun);z.enter().append(\"rect\").classed(n.cn.scrollAreaClipRect,!0).attr(\"x\",-n.overdrag).attr(\"y\",-n.uplift).attr(\"fill\",\"none\"),z.attr(\"width\",(function(t){return t.width+2*n.overdrag})).attr(\"height\",(function(t){return t.height+n.uplift})),A.selectAll(\".\"+n.cn.columnBoundary).data(a.repeat,a.keyFun).enter().append(\"g\").classed(n.cn.columnBoundary,!0);var O=A.selectAll(\".\"+n.cn.columnBoundaryClippath).data(a.repeat,a.keyFun);O.enter().append(\"clipPath\").classed(n.cn.columnBoundaryClippath,!0),O.attr(\"id\",(function(e){return m(t,e)}));var D=O.selectAll(\".\"+n.cn.columnBoundaryRect).data(a.repeat,a.keyFun);D.enter().append(\"rect\").classed(n.cn.columnBoundaryRect,!0).attr(\"fill\",\"none\"),D.attr(\"width\",(function(t){return t.columnWidth+2*d(t)})).attr(\"height\",(function(t){return t.calcdata.height+2*d(t)+n.uplift})).attr(\"x\",(function(t){return-d(t)})).attr(\"y\",(function(t){return-d(t)})),S(null,I,p)}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/gup\":775,\"../../lib/svg_text_utils\":803,\"./constants\":1319,\"./data_preparation_helper\":1320,\"./data_split_helpers\":1321,d3:169}],1325:[function(t,e,r){\"use strict\";var n=t(\"../../plots/template_attributes\").hovertemplateAttrs,i=t(\"../../plots/template_attributes\").texttemplateAttrs,a=t(\"../../components/colorscale/attributes\"),o=t(\"../../plots/domain\").attributes,s=t(\"../pie/attributes\"),l=t(\"../sunburst/attributes\"),c=t(\"./constants\"),u=t(\"../../lib/extend\").extendFlat;e.exports={labels:l.labels,parents:l.parents,values:l.values,branchvalues:l.branchvalues,count:l.count,level:l.level,maxdepth:l.maxdepth,tiling:{packing:{valType:\"enumerated\",values:[\"squarify\",\"binary\",\"dice\",\"slice\",\"slice-dice\",\"dice-slice\"],dflt:\"squarify\",editType:\"plot\"},squarifyratio:{valType:\"number\",min:1,dflt:1,editType:\"plot\"},flip:{valType:\"flaglist\",flags:[\"x\",\"y\"],dflt:\"\",editType:\"plot\"},pad:{valType:\"number\",min:0,dflt:3,editType:\"plot\"},editType:\"calc\"},marker:u({pad:{t:{valType:\"number\",min:0,editType:\"plot\"},l:{valType:\"number\",min:0,editType:\"plot\"},r:{valType:\"number\",min:0,editType:\"plot\"},b:{valType:\"number\",min:0,editType:\"plot\"},editType:\"calc\"},colors:l.marker.colors,depthfade:{valType:\"enumerated\",values:[!0,!1,\"reversed\"],editType:\"style\"},line:l.marker.line,editType:\"calc\"},a(\"marker\",{colorAttr:\"colors\",anim:!1})),pathbar:{visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},side:{valType:\"enumerated\",values:[\"top\",\"bottom\"],dflt:\"top\",editType:\"plot\"},edgeshape:{valType:\"enumerated\",values:[\">\",\"<\",\"|\",\"/\",\"\\\\\"],dflt:\">\",editType:\"plot\"},thickness:{valType:\"number\",min:12,editType:\"plot\"},textfont:u({},s.textfont,{}),editType:\"calc\"},text:s.text,textinfo:l.textinfo,texttemplate:i({editType:\"plot\"},{keys:c.eventDataKeys.concat([\"label\",\"value\"])}),hovertext:s.hovertext,hoverinfo:l.hoverinfo,hovertemplate:n({},{keys:c.eventDataKeys}),textfont:s.textfont,insidetextfont:s.insidetextfont,outsidetextfont:u({},s.outsidetextfont,{}),textposition:{valType:\"enumerated\",values:[\"top left\",\"top center\",\"top right\",\"middle left\",\"middle center\",\"middle right\",\"bottom left\",\"bottom center\",\"bottom right\"],dflt:\"top left\",editType:\"plot\"},sort:s.sort,root:l.root,domain:o({name:\"treemap\",trace:!0,editType:\"calc\"})}},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plots/domain\":855,\"../../plots/template_attributes\":906,\"../pie/attributes\":1161,\"../sunburst/attributes\":1299,\"./constants\":1328}],1326:[function(t,e,r){\"use strict\";var n=t(\"../../plots/plots\");r.name=\"treemap\",r.plot=function(t,e,i,a){n.plotBasePlot(r.name,t,e,i,a)},r.clean=function(t,e,i,a){n.cleanBasePlot(r.name,t,e,i,a)}},{\"../../plots/plots\":891}],1327:[function(t,e,r){\"use strict\";var n=t(\"../sunburst/calc\");r.calc=function(t,e){return n.calc(t,e)},r.crossTraceCalc=function(t){return n._runCrossTraceCalc(\"treemap\",t)}},{\"../sunburst/calc\":1301}],1328:[function(t,e,r){\"use strict\";e.exports={CLICK_TRANSITION_TIME:750,CLICK_TRANSITION_EASING:\"poly\",eventDataKeys:[\"currentPath\",\"root\",\"entry\",\"percentRoot\",\"percentEntry\",\"percentParent\"],gapWithPathbar:1}},{}],1329:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../../components/color\"),o=t(\"../../plots/domain\").defaults,s=t(\"../bar/defaults\").handleText,l=t(\"../bar/constants\").TEXTPAD,c=t(\"../../components/colorscale\"),u=c.hasColorscale,f=c.handleDefaults;e.exports=function(t,e,r,c){function h(r,a){return n.coerce(t,e,i,r,a)}var p=h(\"labels\"),d=h(\"parents\");if(p&&p.length&&d&&d.length){var g=h(\"values\");g&&g.length?h(\"branchvalues\"):h(\"count\"),h(\"level\"),h(\"maxdepth\"),\"squarify\"===h(\"tiling.packing\")&&h(\"tiling.squarifyratio\"),h(\"tiling.flip\"),h(\"tiling.pad\");var m=h(\"text\");h(\"texttemplate\"),e.texttemplate||h(\"textinfo\",Array.isArray(m)?\"text+label\":\"label\"),h(\"hovertext\"),h(\"hovertemplate\");var v=h(\"pathbar.visible\");s(t,e,c,h,\"auto\",{hasPathbar:v,moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!1,moduleHasCliponaxis:!1,moduleHasTextangle:!1,moduleHasInsideanchor:!1}),h(\"textposition\");var y=-1!==e.textposition.indexOf(\"bottom\");h(\"marker.line.width\")&&h(\"marker.line.color\",c.paper_bgcolor);var x=h(\"marker.colors\"),b=e._hasColorscale=u(t,\"marker\",\"colors\")||(t.marker||{}).coloraxis;b?f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}):h(\"marker.depthfade\",!(x||[]).length);var _=2*e.textfont.size;h(\"marker.pad.t\",y?_/4:_),h(\"marker.pad.l\",_/4),h(\"marker.pad.r\",_/4),h(\"marker.pad.b\",y?_:_/4),b&&f(t,e,c,h,{prefix:\"marker.\",cLetter:\"c\"}),e._hovered={marker:{line:{width:2,color:a.contrast(c.paper_bgcolor)}}},v&&(h(\"pathbar.thickness\",e.pathbar.textfont.size+2*l),h(\"pathbar.side\"),h(\"pathbar.edgeshape\")),h(\"sort\"),h(\"root.color\"),o(e,c,h),e._length=null}else e.visible=!1}},{\"../../components/color\":643,\"../../components/colorscale\":655,\"../../lib\":778,\"../../plots/domain\":855,\"../bar/constants\":923,\"../bar/defaults\":925,\"./attributes\":1325}],1330:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\");e.exports=function(t,e,r,h,p){var d=p.barDifY,g=p.width,m=p.height,v=p.viewX,y=p.viewY,x=p.pathSlice,b=p.toMoveInsideSlice,_=p.strTransform,w=p.hasTransition,T=p.handleSlicesExit,k=p.makeUpdateSliceInterpolator,M=p.makeUpdateTextInterpolator,A={},S=t._fullLayout,E=e[0],C=E.trace,L=E.hierarchy,I=g/C._entryDepth,P=u.listPath(r.data,\"id\"),z=s(L.copy(),[g,m],{packing:\"dice\",pad:{inner:0,top:0,left:0,right:0,bottom:0}}).descendants();(z=z.filter((function(t){var e=P.indexOf(t.data.id);return-1!==e&&(t.x0=I*e,t.x1=I*(e+1),t.y0=d,t.y1=d+m,t.onPathbar=!0,!0)}))).reverse(),(h=h.data(z,u.getPtId)).enter().append(\"g\").classed(\"pathbar\",!0),T(h,!0,A,[g,m],x),h.order();var O=h;w&&(O=O.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:!1})}))),O.each((function(s){s._hoverX=v(s.x1-Math.min(g,m)/2),s._hoverY=y(s.y1-m/2);var h=n.select(this),p=i.ensureSingle(h,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?p.transition().attrTween(\"d\",(function(t){var e=k(t,!0,A,[g,m]);return function(t){return x(e(t))}})):p.attr(\"d\",x),h.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{hideOnRoot:!1,hideOnLeaves:!1,isTransitioning:t._transitioning}),p.call(l,s,C,{hovered:!1}),s._text=(u.getPtLabel(s)||\"\").split(\"<br>\").join(\" \")||\"\";var d=i.ensureSingle(h,\"g\",\"slicetext\"),T=i.ensureSingle(d,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),E=i.ensureUniformFontSize(t,u.determineTextFont(C,s,S.font,{onPathbar:!0}));T.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",\"start\").call(a.font,E).call(o.convertToTspans,t),s.textBB=a.bBox(T.node()),s.transform=b(s,{fontSize:E.size,onPathbar:!0}),s.transform.fontSize=E.size,w?T.transition().attrTween(\"transform\",(function(t){var e=M(t,!0,A,[g,m]);return function(t){return _(e(t))}})):T.attr(\"transform\",_(s))}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1331:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../lib/svg_text_utils\"),s=t(\"./partition\"),l=t(\"./style\").styleOne,c=t(\"./constants\"),u=t(\"../sunburst/helpers\"),f=t(\"../sunburst/fx\"),h=t(\"../sunburst/plot\").formatSliceLabel;e.exports=function(t,e,r,p,d){var g=d.width,m=d.height,v=d.viewX,y=d.viewY,x=d.pathSlice,b=d.toMoveInsideSlice,_=d.strTransform,w=d.hasTransition,T=d.handleSlicesExit,k=d.makeUpdateSliceInterpolator,M=d.makeUpdateTextInterpolator,A=d.prevEntry,S=t._fullLayout,E=e[0].trace,C=-1!==E.textposition.indexOf(\"left\"),L=-1!==E.textposition.indexOf(\"right\"),I=-1!==E.textposition.indexOf(\"bottom\"),P=!I&&!E.marker.pad.t||I&&!E.marker.pad.b,z=s(r,[g,m],{packing:E.tiling.packing,squarifyratio:E.tiling.squarifyratio,flipX:E.tiling.flip.indexOf(\"x\")>-1,flipY:E.tiling.flip.indexOf(\"y\")>-1,pad:{inner:E.tiling.pad,top:E.marker.pad.t,left:E.marker.pad.l,right:E.marker.pad.r,bottom:E.marker.pad.b}}).descendants(),O=1/0,D=-1/0;z.forEach((function(t){var e=t.depth;e>=E._maxDepth?(t.x0=t.x1=(t.x0+t.x1)/2,t.y0=t.y1=(t.y0+t.y1)/2):(O=Math.min(O,e),D=Math.max(D,e))})),p=p.data(z,u.getPtId),E._maxVisibleLayers=isFinite(D)?D-O+1:0,p.enter().append(\"g\").classed(\"slice\",!0),T(p,!1,{},[g,m],x),p.order();var R=null;if(w&&A){var F=u.getPtId(A);p.each((function(t){null===R&&u.getPtId(t)===F&&(R={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})}))}var B=function(){return R||{x0:0,x1:g,y0:0,y1:m}},N=p;return w&&(N=N.transition().each(\"end\",(function(){var e=n.select(this);u.setSliceCursor(e,t,{hideOnRoot:!0,hideOnLeaves:!1,isTransitioning:!1})}))),N.each((function(s){var p=u.isHeader(s,E);s._hoverX=v(s.x1-E.marker.pad.r),s._hoverY=y(I?s.y1-E.marker.pad.b/2:s.y0+E.marker.pad.t/2);var d=n.select(this),T=i.ensureSingle(d,\"path\",\"surface\",(function(t){t.style(\"pointer-events\",\"all\")}));w?T.transition().attrTween(\"d\",(function(t){var e=k(t,!1,B(),[g,m]);return function(t){return x(e(t))}})):T.attr(\"d\",x),d.call(f,r,t,e,{styleOne:l,eventDataKeys:c.eventDataKeys,transitionTime:c.CLICK_TRANSITION_TIME,transitionEasing:c.CLICK_TRANSITION_EASING}).call(u.setSliceCursor,t,{isTransitioning:t._transitioning}),T.call(l,s,E,{hovered:!1}),s.x0===s.x1||s.y0===s.y1?s._text=\"\":s._text=p?P?\"\":u.getPtLabel(s)||\"\":h(s,r,E,e,S)||\"\";var A=i.ensureSingle(d,\"g\",\"slicetext\"),z=i.ensureSingle(A,\"text\",\"\",(function(t){t.attr(\"data-notex\",1)})),O=i.ensureUniformFontSize(t,u.determineTextFont(E,s,S.font));z.text(s._text||\" \").classed(\"slicetext\",!0).attr(\"text-anchor\",L?\"end\":C||p?\"start\":\"middle\").call(a.font,O).call(o.convertToTspans,t),s.textBB=a.bBox(z.node()),s.transform=b(s,{fontSize:O.size,isHeader:p}),s.transform.fontSize=O.size,w?z.transition().attrTween(\"transform\",(function(t){var e=M(t,!1,B(),[g,m]);return function(t){return _(e(t))}})):z.attr(\"transform\",_(s))})),R}},{\"../../components/drawing\":665,\"../../lib\":778,\"../../lib/svg_text_utils\":803,\"../sunburst/fx\":1304,\"../sunburst/helpers\":1305,\"../sunburst/plot\":1309,\"./constants\":1328,\"./partition\":1335,\"./style\":1337,d3:169}],1332:[function(t,e,r){\"use strict\";e.exports={moduleType:\"trace\",name:\"treemap\",basePlotModule:t(\"./base_plot\"),categories:[],animatable:!0,attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\").calc,crossTraceCalc:t(\"./calc\").crossTraceCalc,plot:t(\"./plot\"),style:t(\"./style\").style,colorbar:t(\"../scatter/marker_colorbar\"),meta:{}}},{\"../scatter/marker_colorbar\":1205,\"./attributes\":1325,\"./base_plot\":1326,\"./calc\":1327,\"./defaults\":1329,\"./layout_attributes\":1333,\"./layout_defaults\":1334,\"./plot\":1336,\"./style\":1337}],1333:[function(t,e,r){\"use strict\";e.exports={treemapcolorway:{valType:\"colorlist\",editType:\"calc\"},extendtreemapcolors:{valType:\"boolean\",dflt:!0,editType:\"calc\"}}},{}],1334:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e){function r(r,a){return n.coerce(t,e,i,r,a)}r(\"treemapcolorway\",e.colorway),r(\"extendtreemapcolors\")}},{\"../../lib\":778,\"./layout_attributes\":1333}],1335:[function(t,e,r){\"use strict\";var n=t(\"d3-hierarchy\");e.exports=function(t,e,r){var i,a=r.flipX,o=r.flipY,s=\"dice-slice\"===r.packing,l=r.pad[o?\"bottom\":\"top\"],c=r.pad[a?\"right\":\"left\"],u=r.pad[a?\"left\":\"right\"],f=r.pad[o?\"top\":\"bottom\"];s&&(i=c,c=l,l=i,i=u,u=f,f=i);var h=n.treemap().tile(function(t,e){switch(t){case\"squarify\":return n.treemapSquarify.ratio(e);case\"binary\":return n.treemapBinary;case\"dice\":return n.treemapDice;case\"slice\":return n.treemapSlice;default:return n.treemapSliceDice}}(r.packing,r.squarifyratio)).paddingInner(r.pad.inner).paddingLeft(c).paddingRight(u).paddingTop(l).paddingBottom(f).size(s?[e[1],e[0]]:e)(t);return(s||a||o)&&function t(e,r,n){var i;n.swapXY&&(i=e.x0,e.x0=e.y0,e.y0=i,i=e.x1,e.x1=e.y1,e.y1=i);n.flipX&&(i=e.x0,e.x0=r[0]-e.x1,e.x1=r[0]-i);n.flipY&&(i=e.y0,e.y0=r[1]-e.y1,e.y1=r[1]-i);var a=e.children;if(a)for(var o=0;o<a.length;o++)t(a[o],r,n)}(h,e,{swapXY:s,flipX:a,flipY:o}),h}},{\"d3-hierarchy\":161}],1336:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../sunburst/helpers\"),a=t(\"../../lib\"),o=t(\"../bar/constants\").TEXTPAD,s=t(\"../bar/plot\").toMoveInsideBar,l=t(\"../bar/uniform_text\"),c=l.recordMinTextSize,u=l.clearMinTextSize,f=t(\"../bar/style\").resizeText,h=t(\"./constants\"),p=t(\"./draw_descendants\"),d=t(\"./draw_ancestors\");function g(t){return i.isHierarchyRoot(t)?\"\":i.getPtId(t)}function m(t,e,r,l){var u=t._fullLayout,f=e[0],m=f.trace,v=f.hierarchy,y=i.findEntryWithLevel(v,m.level),x=n.select(r),b=x.selectAll(\"g.pathbar\"),_=x.selectAll(\"g.slice\");if(!y)return b.remove(),void _.remove();var w=i.isHierarchyRoot(y),T=!u.uniformtext.mode&&i.hasTransition(l),k=i.getMaxDepth(m),M=u._size,A=m.domain,S=M.w*(A.x[1]-A.x[0]),E=M.h*(A.y[1]-A.y[0]),C=S,L=m.pathbar.thickness,I=m.marker.line.width+h.gapWithPathbar,P=m.pathbar.visible?m.pathbar.side.indexOf(\"bottom\")>-1?E+I:-(L+I):0,z={x0:C,x1:C,y0:P,y1:P+L},O=function(t,e,r){var n=m.tiling.pad,i=function(t){return t-n<=e.x0},a=function(t){return t+n>=e.x1},o=function(t){return t-n<=e.y0},s=function(t){return t+n>=e.y1};return{x0:i(t.x0-n)?0:a(t.x0-n)?r[0]:t.x0,x1:i(t.x1+n)?0:a(t.x1+n)?r[0]:t.x1,y0:o(t.y0-n)?0:s(t.y0-n)?r[1]:t.y0,y1:o(t.y1+n)?0:s(t.y1+n)?r[1]:t.y1}},D=null,R={},F={},B=null,N=function(t,e){return e?R[g(t)]:F[g(t)]},j=function(t,e,r,n){if(e)return R[g(v)]||z;var i=F[m.level]||r;return function(t){return t.data.depth-y.data.depth<k}(t)?O(t,i,n):{}};f.hasMultipleRoots&&w&&k++,m._maxDepth=k,m._backgroundColor=u.paper_bgcolor,m._entryDepth=y.data.depth,m._atRootLevel=w;var U=-S/2+M.l+M.w*(A.x[1]+A.x[0])/2,V=-E/2+M.t+M.h*(1-(A.y[1]+A.y[0])/2),q=function(t){return U+t},H=function(t){return V+t},G=H(0),Y=q(0),W=function(t){return Y+t},X=function(t){return G+t};function Z(t,e){return t+\",\"+e}var J=W(0),K=function(t){t.x=Math.max(J,t.x)},Q=m.pathbar.edgeshape,$=function(t,e){var r=t.x0,n=t.x1,i=t.y0,a=t.y1,l=t.textBB,f=function(t){return-1!==m.textposition.indexOf(t)},h=f(\"bottom\"),p=f(\"top\")||e.isHeader&&!h?\"start\":h?\"end\":\"middle\",d=f(\"right\"),g=f(\"left\")||e.onPathbar?-1:d?1:0,v=m.marker.pad;if(e.isHeader){if((r+=v.l-o)>=(n-=v.r-o)){var y=(r+n)/2;r=y,n=y}var x;h?i<(x=a-v.b)&&x<a&&(i=x):i<(x=i+v.t)&&x<a&&(a=x)}var b=s(r,n,i,a,l,{isHorizontal:!1,constrained:!0,angle:0,anchor:p,leftToRight:g});return b.fontSize=e.fontSize,b.targetX=q(b.targetX),b.targetY=H(b.targetY),isNaN(b.targetX)||isNaN(b.targetY)?{}:(r!==n&&i!==a&&c(m.type,b,u),{scale:b.scale,rotate:b.rotate,textX:b.textX,textY:b.textY,anchorX:b.anchorX,anchorY:b.anchorY,targetX:b.targetX,targetY:b.targetY})},tt=function(t,e){for(var r,n=0,i=t;!r&&n<k;)n++,(i=i.parent)?r=N(i,e):n=k;return r||{}},et=function(t,e,r,i){var o,s=N(t,e);if(s)o=s;else if(e)o=z;else if(D)if(t.parent){var l=B||r;l&&!e?o=O(t,l,i):(o={},a.extendFlat(o,tt(t,e)))}else o=t;else o={};return n.interpolate(o,{x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1})},rt=function(t,e,r,o){var s=N(t,e),l={},f=j(t,e,r,o);a.extendFlat(l,{transform:$({x0:f.x0,x1:f.x1,y0:f.y0,y1:f.y1,textBB:t.textBB,_text:t._text},{isHeader:i.isHeader(t,m)})}),s?l=s:t.parent&&a.extendFlat(l,tt(t,e));var h=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,h,u),n.interpolate(l,{transform:{scale:h.scale,rotate:h.rotate,textX:h.textX,textY:h.textY,anchorX:h.anchorX,anchorY:h.anchorY,targetX:h.targetX,targetY:h.targetY}})},nt=function(t,e,r,i,a){var o=i[0],s=i[1];T?t.exit().transition().each((function(){var t=n.select(this);t.select(\"path.surface\").transition().attrTween(\"d\",(function(t){var r=function(t,e,r,i){var a,o=N(t,e);if(e)a=z;else{var s=N(y,e);a=s?O(t,s,i):{}}return n.interpolate(o,a)}(t,e,0,[o,s]);return function(t){return a(r(t))}})),t.select(\"g.slicetext\").attr(\"opacity\",0)})).remove():t.exit().remove()},it=function(t){var e=t.transform;return t.x0!==t.x1&&t.y0!==t.y1&&c(m.type,e,u),a.getTextTransform({textX:e.textX,textY:e.textY,anchorX:e.anchorX,anchorY:e.anchorY,targetX:e.targetX,targetY:e.targetY,scale:e.scale,rotate:e.rotate})};T&&(b.each((function(t){R[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(R[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate})})),_.each((function(t){F[g(t)]={x0:t.x0,x1:t.x1,y0:t.y0,y1:t.y1},t.transform&&(F[g(t)].transform={textX:t.transform.textX,textY:t.transform.textY,anchorX:t.transform.anchorX,anchorY:t.transform.anchorY,targetX:t.transform.targetX,targetY:t.transform.targetY,scale:t.transform.scale,rotate:t.transform.rotate}),!D&&i.isEntry(t)&&(D=t)}))),B=p(t,e,y,_,{width:S,height:E,viewX:q,viewY:H,pathSlice:function(t){var e=q(t.x0),r=q(t.x1),n=H(t.y0),i=H(t.y1),a=r-e,o=i-n;if(!a||!o)return\"\";return\"M\"+Z(e,n+0)+\"L\"+Z(r-0,n)+\"L\"+Z(r,i-0)+\"L\"+Z(e+0,i)+\"Z\"},toMoveInsideSlice:$,prevEntry:D,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}),m.pathbar.visible?d(t,e,y,b,{barDifY:P,width:C,height:L,viewX:W,viewY:X,pathSlice:function(t){var e=W(Math.max(Math.min(t.x0,t.x0),0)),r=W(Math.min(Math.max(t.x1,t.x1),C)),n=X(t.y0),i=X(t.y1),a=L/2,o={},s={};o.x=e,s.x=r,o.y=s.y=(n+i)/2;var l={x:e,y:n},c={x:r,y:n},u={x:r,y:i},f={x:e,y:i};return\">\"===Q?(l.x-=a,c.x-=a,u.x-=a,f.x-=a):\"/\"===Q?(u.x-=a,f.x-=a,o.x-=a/2,s.x-=a/2):\"\\\\\"===Q?(l.x-=a,c.x-=a,o.x-=a/2,s.x-=a/2):\"<\"===Q&&(o.x-=a,s.x-=a),K(l),K(f),K(o),K(c),K(u),K(s),\"M\"+Z(l.x,l.y)+\"L\"+Z(c.x,c.y)+\"L\"+Z(s.x,s.y)+\"L\"+Z(u.x,u.y)+\"L\"+Z(f.x,f.y)+\"L\"+Z(o.x,o.y)+\"Z\"},toMoveInsideSlice:$,makeUpdateSliceInterpolator:et,makeUpdateTextInterpolator:rt,handleSlicesExit:nt,hasTransition:T,strTransform:it}):b.remove()}e.exports=function(t,e,r,a){var o,s,l=t._fullLayout,c=l._treemaplayer,h=!r;(u(\"treemap\",l),(o=c.selectAll(\"g.trace.treemap\").data(e,(function(t){return t[0].trace.uid}))).enter().append(\"g\").classed(\"trace\",!0).classed(\"treemap\",!0),o.order(),!l.uniformtext.mode&&i.hasTransition(r))?(a&&(s=a()),n.transition().duration(r.duration).ease(r.easing).each(\"end\",(function(){s&&s()})).each(\"interrupt\",(function(){s&&s()})).each((function(){c.selectAll(\"g.trace\").each((function(e){m(t,e,this,r)}))}))):(o.each((function(e){m(t,e,this,r)})),l.uniformtext.mode&&f(t,l._treemaplayer.selectAll(\".trace\"),\"treemap\"));h&&o.exit().remove()}},{\"../../lib\":778,\"../bar/constants\":923,\"../bar/plot\":932,\"../bar/style\":935,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,\"./constants\":1328,\"./draw_ancestors\":1330,\"./draw_descendants\":1331,d3:169}],1337:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../../lib\"),o=t(\"../sunburst/helpers\"),s=t(\"../bar/uniform_text\").resizeText;function l(t,e,r,n){var s,l,c=(n||{}).hovered,u=e.data.data,f=u.i,h=u.color,p=o.isHierarchyRoot(e),d=1;if(c)s=r._hovered.marker.line.color,l=r._hovered.marker.line.width;else if(p&&h===r.root.color)d=100,s=\"rgba(0,0,0,0)\",l=0;else if(s=a.castOption(r,f,\"marker.line.color\")||i.defaultLine,l=a.castOption(r,f,\"marker.line.width\")||0,!r._hasColorscale&&!e.onPathbar){var g=r.marker.depthfade;if(g){var m,v=i.combine(i.addOpacity(r._backgroundColor,.75),h);if(!0===g){var y=o.getMaxDepth(r);m=isFinite(y)?o.isLeaf(e)?0:r._maxVisibleLayers-(e.data.depth-r._entryDepth):e.data.height+1}else m=e.data.depth-r._entryDepth,r._atRootLevel||m++;if(m>0)for(var x=0;x<m;x++){var b=.5*x/m;h=i.combine(i.addOpacity(v,b),h)}}}t.style(\"stroke-width\",l).call(i.fill,h).call(i.stroke,s).style(\"opacity\",d)}e.exports={style:function(t){var e=t._fullLayout._treemaplayer.selectAll(\".trace\");s(t,e,\"treemap\"),e.each((function(t){var e=n.select(this),r=t[0].trace;e.style(\"opacity\",r.opacity),e.selectAll(\"path.surface\").each((function(t){n.select(this).call(l,t,r,{hovered:!1})}))}))},styleOne:l}},{\"../../components/color\":643,\"../../lib\":778,\"../bar/uniform_text\":937,\"../sunburst/helpers\":1305,d3:169}],1338:[function(t,e,r){\"use strict\";var n=t(\"../box/attributes\"),i=t(\"../../lib/extend\").extendFlat;e.exports={y:n.y,x:n.x,x0:n.x0,y0:n.y0,name:i({},n.name,{}),orientation:i({},n.orientation,{}),bandwidth:{valType:\"number\",min:0,editType:\"calc\"},scalegroup:{valType:\"string\",dflt:\"\",editType:\"calc\"},scalemode:{valType:\"enumerated\",values:[\"width\",\"count\"],dflt:\"width\",editType:\"calc\"},spanmode:{valType:\"enumerated\",values:[\"soft\",\"hard\",\"manual\"],dflt:\"soft\",editType:\"calc\"},span:{valType:\"info_array\",items:[{valType:\"any\",editType:\"calc\"},{valType:\"any\",editType:\"calc\"}],editType:\"calc\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,dflt:2,editType:\"style\"},editType:\"plot\"},fillcolor:n.fillcolor,points:i({},n.boxpoints,{}),jitter:i({},n.jitter,{}),pointpos:i({},n.pointpos,{}),width:i({},n.width,{}),marker:n.marker,text:n.text,hovertext:n.hovertext,hovertemplate:n.hovertemplate,box:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},width:{valType:\"number\",min:0,max:1,dflt:.25,editType:\"plot\"},fillcolor:{valType:\"color\",editType:\"style\"},line:{color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"style\"},editType:\"plot\"},meanline:{visible:{valType:\"boolean\",dflt:!1,editType:\"plot\"},color:{valType:\"color\",editType:\"style\"},width:{valType:\"number\",min:0,editType:\"style\"},editType:\"plot\"},side:{valType:\"enumerated\",values:[\"both\",\"positive\",\"negative\"],dflt:\"both\",editType:\"calc\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup,selected:n.selected,unselected:n.unselected,hoveron:{valType:\"flaglist\",flags:[\"violins\",\"points\",\"kde\"],dflt:\"violins+points+kde\",extras:[\"all\"],editType:\"style\"}}},{\"../../lib/extend\":768,\"../box/attributes\":946}],1339:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/calc\"),o=t(\"./helpers\"),s=t(\"../../constants/numerical\").BADNUM;function l(t,e,r){var i=e.max-e.min;if(!i)return t.bandwidth?t.bandwidth:0;if(t.bandwidth)return Math.max(t.bandwidth,i/1e4);var a=r.length,o=n.stdev(r,a-1,e.mean);return Math.max(function(t,e,r){return 1.059*Math.min(e,r/1.349)*Math.pow(t,-.2)}(a,o,e.q3-e.q1),i/100)}function c(t,e,r,n){var a,o=t.spanmode,l=t.span||[],c=[e.min,e.max],u=[e.min-2*n,e.max+2*n];function f(n){var i=l[n],a=\"multicategory\"===r.type?r.r2c(i):r.d2c(i,0,t[e.valLetter+\"calendar\"]);return a===s?u[n]:a}var h={type:\"linear\",range:a=\"soft\"===o?u:\"hard\"===o?c:[f(0),f(1)]};return i.setConvert(h),h.cleanRange(),a}e.exports=function(t,e){var r=a(t,e);if(r[0].t.empty)return r;for(var s=t._fullLayout,u=i.getFromId(t,e[\"h\"===e.orientation?\"xaxis\":\"yaxis\"]),f=1/0,h=-1/0,p=0,d=0,g=0;g<r.length;g++){var m=r[g],v=m.pts.map(o.extractVal),y=m.bandwidth=l(e,m,v),x=m.span=c(e,m,u,y);if(m.min===m.max&&0===y)x=m.span=[m.min,m.max],m.density=[{v:1,t:x[0]}],m.bandwidth=y,p=Math.max(p,1);else{var b=x[1]-x[0],_=Math.ceil(b/(y/3)),w=b/_;if(!isFinite(w)||!isFinite(_))return n.error(\"Something went wrong with computing the violin span\"),r[0].t.empty=!0,r;var T=o.makeKDE(m,e,v);m.density=new Array(_);for(var k=0,M=x[0];M<x[1]+w/2;k++,M+=w){var A=T(M);m.density[k]={v:A,t:M},p=Math.max(p,A)}}d=Math.max(d,v.length),f=Math.min(f,x[0]),h=Math.max(h,x[1])}var S=i.findExtremes(u,[f,h],{padded:!0});if(e._extremes[u._id]=S,e.width)r[0].t.maxKDE=p;else{var E=s._violinScaleGroupStats,C=e.scalegroup,L=E[C];L?(L.maxKDE=Math.max(L.maxKDE,p),L.maxCount=Math.max(L.maxCount,d)):E[C]={maxKDE:p,maxCount:d}}return r[0].t.labels.kde=n._(t,\"kde:\"),r}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/calc\":947,\"./helpers\":1342}],1340:[function(t,e,r){\"use strict\";var n=t(\"../box/cross_trace_calc\").setPositionOffset,i=[\"v\",\"h\"];e.exports=function(t,e){for(var r=t.calcdata,a=e.xaxis,o=e.yaxis,s=0;s<i.length;s++){for(var l=i[s],c=\"h\"===l?o:a,u=[],f=0;f<r.length;f++){var h=r[f],p=h[0].t,d=h[0].trace;!0!==d.visible||\"violin\"!==d.type||p.empty||d.orientation!==l||d.xaxis!==a._id||d.yaxis!==o._id||u.push(f)}n(\"violin\",t,u,c)}}},{\"../box/cross_trace_calc\":948}],1341:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../components/color\"),a=t(\"../box/defaults\"),o=t(\"./attributes\");e.exports=function(t,e,r,s){function l(r,i){return n.coerce(t,e,o,r,i)}function c(r,i){return n.coerce2(t,e,o,r,i)}if(a.handleSampleDefaults(t,e,l,s),!1!==e.visible){l(\"bandwidth\"),l(\"side\"),l(\"width\")||(l(\"scalegroup\",e.name),l(\"scalemode\"));var u,f=l(\"span\");Array.isArray(f)&&(u=\"manual\"),l(\"spanmode\",u);var h=l(\"line.color\",(t.marker||{}).color||r),p=l(\"line.width\"),d=l(\"fillcolor\",i.addOpacity(e.line.color,.5));a.handlePointsDefaults(t,e,l,{prefix:\"\"});var g=c(\"box.width\"),m=c(\"box.fillcolor\",d),v=c(\"box.line.color\",h),y=c(\"box.line.width\",p);l(\"box.visible\",Boolean(g||m||v||y))||(e.box={visible:!1});var x=c(\"meanline.color\",h),b=c(\"meanline.width\",p);l(\"meanline.visible\",Boolean(x||b))||(e.meanline={visible:!1})}}},{\"../../components/color\":643,\"../../lib\":778,\"../box/defaults\":949,\"./attributes\":1338}],1342:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=function(t){return 1/Math.sqrt(2*Math.PI)*Math.exp(-.5*t*t)};r.makeKDE=function(t,e,r){var n=r.length,a=i,o=t.bandwidth,s=1/(n*o);return function(t){for(var e=0,i=0;i<n;i++)e+=a((t-r[i])/o);return s*e}},r.getPositionOnKdePath=function(t,e,r){var i,a;\"h\"===e.orientation?(i=\"y\",a=\"x\"):(i=\"x\",a=\"y\");var o=n.findPointOnPath(t.path,r,a,{pathLength:t.pathLength}),s=t.posCenterPx,l=o[i];return[l,\"both\"===e.side?2*s-l:s]},r.getKdeValue=function(t,e,n){var i=t.pts.map(r.extractVal);return r.makeKDE(t,e,i)(n)/t.posDensityScale},r.extractVal=function(t){return t.v}},{\"../../lib\":778}],1343:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../../plots/cartesian/axes\"),a=t(\"../box/hover\"),o=t(\"./helpers\");e.exports=function(t,e,r,s,l){var c,u,f=t.cd,h=f[0].trace,p=h.hoveron,d=-1!==p.indexOf(\"violins\"),g=-1!==p.indexOf(\"kde\"),m=[];if(d||g){var v=a.hoverOnBoxes(t,e,r,s);if(g&&v.length>0){var y,x,b,_,w,T=t.xa,k=t.ya;\"h\"===h.orientation?(w=e,y=\"y\",b=k,x=\"x\",_=T):(w=r,y=\"x\",b=T,x=\"y\",_=k);var M=f[t.index];if(w>=M.span[0]&&w<=M.span[1]){var A=n.extendFlat({},t),S=_.c2p(w,!0),E=o.getKdeValue(M,h,w),C=o.getPositionOnKdePath(M,h,S),L=b._offset,I=b._length;A[y+\"0\"]=C[0],A[y+\"1\"]=C[1],A[x+\"0\"]=A[x+\"1\"]=S,A[x+\"Label\"]=x+\": \"+i.hoverLabelText(_,w)+\", \"+f[0].t.labels.kde+\" \"+E.toFixed(3),A.spikeDistance=v[0].spikeDistance;var P=y+\"Spike\";A[P]=v[0][P],v[0].spikeDistance=void 0,v[0][P]=void 0,A.hovertemplate=!1,m.push(A),(u={stroke:t.color})[y+\"1\"]=n.constrain(L+C[0],L,L+I),u[y+\"2\"]=n.constrain(L+C[1],L,L+I),u[x+\"1\"]=u[x+\"2\"]=_._offset+S}}d&&(m=m.concat(v))}-1!==p.indexOf(\"points\")&&(c=a.hoverOnPoints(t,e,r));var z=l.selectAll(\".violinline-\"+h.uid).data(u?[0]:[]);return z.enter().append(\"line\").classed(\"violinline-\"+h.uid,!0).attr(\"stroke-width\",1.5),z.exit().remove(),z.attr(u),\"closest\"===s?c?[c]:m:c?(m.push(c),m):m}},{\"../../lib\":778,\"../../plots/cartesian/axes\":828,\"../box/hover\":951,\"./helpers\":1342}],1344:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\"),crossTraceDefaults:t(\"../box/defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\"),styleOnSelect:t(\"../scatter/style\").styleOnSelect,hoverPoints:t(\"./hover\"),selectPoints:t(\"../box/select\"),moduleType:\"trace\",name:\"violin\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"cartesian\",\"svg\",\"symbols\",\"oriented\",\"box-violin\",\"showLegend\",\"violinLayout\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../box/defaults\":949,\"../box/select\":956,\"../scatter/style\":1211,\"./attributes\":1338,\"./calc\":1339,\"./cross_trace_calc\":1340,\"./defaults\":1341,\"./hover\":1343,\"./layout_attributes\":1345,\"./layout_defaults\":1346,\"./plot\":1347,\"./style\":1348}],1345:[function(t,e,r){\"use strict\";var n=t(\"../box/layout_attributes\"),i=t(\"../../lib\").extendFlat;e.exports={violinmode:i({},n.boxmode,{}),violingap:i({},n.boxgap,{}),violingroupgap:i({},n.boxgroupgap,{})}},{\"../../lib\":778,\"../box/layout_attributes\":953}],1346:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\"),a=t(\"../box/layout_defaults\");e.exports=function(t,e,r){a._supply(t,e,r,(function(r,a){return n.coerce(t,e,i,r,a)}),\"violin\")}},{\"../../lib\":778,\"../box/layout_defaults\":954,\"./layout_attributes\":1345}],1347:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../box/plot\"),s=t(\"../scatter/line_points\"),l=t(\"./helpers\");e.exports=function(t,e,r,c){var u=t._fullLayout,f=e.xaxis,h=e.yaxis;function p(t){var e=s(t,{xaxis:f,yaxis:h,connectGaps:!0,baseTolerance:.75,shape:\"spline\",simplify:!0,linearized:!0});return a.smoothopen(e[0],1)}i.makeTraceGroups(c,r,\"trace violins\").each((function(t){var r=n.select(this),a=t[0],s=a.t,c=a.trace;if(!0!==c.visible||s.empty)r.remove();else{var d=s.bPos,g=s.bdPos,m=e[s.valLetter+\"axis\"],v=e[s.posLetter+\"axis\"],y=\"both\"===c.side,x=y||\"positive\"===c.side,b=y||\"negative\"===c.side,_=r.selectAll(\"path.violin\").data(i.identity);_.enter().append(\"path\").style(\"vector-effect\",\"non-scaling-stroke\").attr(\"class\",\"violin\"),_.exit().remove(),_.each((function(t){var e,r,i,a,o,l,f,h,_=n.select(this),w=t.density,T=w.length,k=v.c2l(t.pos+d,!0),M=v.l2p(k);if(c.width)e=s.maxKDE/g;else{var A=u._violinScaleGroupStats[c.scalegroup];e=\"count\"===c.scalemode?A.maxKDE/g*(A.maxCount/t.pts.length):A.maxKDE/g}if(x){for(f=new Array(T),o=0;o<T;o++)(h=f[o]={})[s.posLetter]=k+w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);r=p(f)}if(b){for(f=new Array(T),l=0,o=T-1;l<T;l++,o--)(h=f[l]={})[s.posLetter]=k-w[o].v/e,h[s.valLetter]=m.c2l(w[o].t,!0);i=p(f)}if(y)a=r+\"L\"+i.substr(1)+\"Z\";else{var S=[M,m.c2p(w[0].t)],E=[M,m.c2p(w[T-1].t)];\"h\"===c.orientation&&(S.reverse(),E.reverse()),a=x?\"M\"+S+\"L\"+r.substr(1)+\"L\"+E:\"M\"+E+\"L\"+i.substr(1)+\"L\"+S}_.attr(\"d\",a),t.posCenterPx=M,t.posDensityScale=e*g,t.path=_.node(),t.pathLength=t.path.getTotalLength()/(y?2:1)}));var w,T,k,M=c.box,A=M.width,S=(M.line||{}).width;y?(w=g*A,T=0):x?(w=[0,g*A/2],T=S*{x:1,y:-1}[s.posLetter]):(w=[g*A/2,0],T=S*{x:-1,y:1}[s.posLetter]),o.plotBoxAndWhiskers(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),o.plotBoxMean(r,{pos:v,val:m},c,{bPos:d,bdPos:w,bPosPxOffset:T}),!c.box.visible&&c.meanline.visible&&(k=i.identity);var E=r.selectAll(\"path.meanline\").data(k||[]);E.enter().append(\"path\").attr(\"class\",\"meanline\").style(\"fill\",\"none\").style(\"vector-effect\",\"non-scaling-stroke\"),E.exit().remove(),E.each((function(t){var e=m.c2p(t.mean,!0),r=l.getPositionOnKdePath(t,c,e);n.select(this).attr(\"d\",\"h\"===c.orientation?\"M\"+e+\",\"+r[0]+\"V\"+r[1]:\"M\"+r[0]+\",\"+e+\"H\"+r[1])})),o.plotPoints(r,{x:f,y:h},c,s)}}))}},{\"../../components/drawing\":665,\"../../lib\":778,\"../box/plot\":955,\"../scatter/line_points\":1201,\"./helpers\":1342,d3:169}],1348:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/color\"),a=t(\"../scatter/style\").stylePoints;e.exports=function(t){var e=n.select(t).selectAll(\"g.trace.violins\");e.style(\"opacity\",(function(t){return t[0].trace.opacity})),e.each((function(e){var r=e[0].trace,o=n.select(this),s=r.box||{},l=s.line||{},c=r.meanline||{},u=c.width;o.selectAll(\"path.violin\").style(\"stroke-width\",r.line.width+\"px\").call(i.stroke,r.line.color).call(i.fill,r.fillcolor),o.selectAll(\"path.box\").style(\"stroke-width\",l.width+\"px\").call(i.stroke,l.color).call(i.fill,s.fillcolor);var f={\"stroke-width\":u+\"px\",\"stroke-dasharray\":2*u+\"px,\"+u+\"px\"};o.selectAll(\"path.mean\").style(f).call(i.stroke,c.color),o.selectAll(\"path.meanline\").style(f).call(i.stroke,c.color),a(o,r,t)}))}},{\"../../components/color\":643,\"../scatter/style\":1211,d3:169}],1349:[function(t,e,r){\"use strict\";var n=t(\"../../components/colorscale/attributes\"),i=t(\"../isosurface/attributes\"),a=t(\"../surface/attributes\"),o=t(\"../../plots/attributes\"),s=t(\"../../lib/extend\").extendFlat,l=t(\"../../plot_api/edit_types\").overrideAll,c=e.exports=l(s({x:i.x,y:i.y,z:i.z,value:i.value,isomin:i.isomin,isomax:i.isomax,surface:i.surface,spaceframe:{show:{valType:\"boolean\",dflt:!1},fill:{valType:\"number\",min:0,max:1,dflt:1}},slices:i.slices,caps:i.caps,text:i.text,hovertext:i.hovertext,hovertemplate:i.hovertemplate},n(\"\",{colorAttr:\"`value`\",showScaleDflt:!0,editTypeOverride:\"calc\"}),{colorbar:i.colorbar,opacity:i.opacity,opacityscale:a.opacityscale,lightposition:i.lightposition,lighting:i.lighting,flatshading:i.flatshading,contour:i.contour,hoverinfo:s({},o.hoverinfo),showlegend:s({},o.showlegend,{dflt:!1})}),\"calc\",\"nested\");c.x.editType=c.y.editType=c.z.editType=c.value.editType=\"calc+clearAxisTypes\",c.transforms=void 0},{\"../../components/colorscale/attributes\":650,\"../../lib/extend\":768,\"../../plot_api/edit_types\":810,\"../../plots/attributes\":824,\"../isosurface/attributes\":1123,\"../surface/attributes\":1311}],1350:[function(t,e,r){\"use strict\";var n=t(\"gl-mesh3d\"),i=t(\"../../lib/gl_format_color\").parseColorScale,a=t(\"../../lib/str2rgbarray\"),o=t(\"../../components/colorscale\").extractOpts,s=t(\"../../plots/gl3d/zip3\"),l=t(\"../isosurface/convert\").findNearestOnAxis,c=t(\"../isosurface/convert\").generateIsoMeshes;function u(t,e,r){this.scene=t,this.uid=r,this.mesh=e,this.name=\"\",this.data=null,this.showContour=!1}var f=u.prototype;f.handlePick=function(t){if(t.object===this.mesh){var e=t.data.index,r=this.data._meshX[e],n=this.data._meshY[e],i=this.data._meshZ[e],a=this.data._Ys.length,o=this.data._Zs.length,s=l(r,this.data._Xs).id,c=l(n,this.data._Ys).id,u=l(i,this.data._Zs).id,f=t.index=u+o*c+o*a*s;t.traceCoordinate=[this.data._meshX[f],this.data._meshY[f],this.data._meshZ[f],this.data._value[f]];var h=this.data.hovertext||this.data.text;return Array.isArray(h)&&void 0!==h[f]?t.textLabel=h[f]:h&&(t.textLabel=h),!0}},f.update=function(t){var e=this.scene,r=e.fullSceneLayout;function n(t,e,r,n){return e.map((function(e){return t.d2l(e,0,n)*r}))}this.data=c(t);var l={positions:s(n(r.xaxis,t._meshX,e.dataScale[0],t.xcalendar),n(r.yaxis,t._meshY,e.dataScale[1],t.ycalendar),n(r.zaxis,t._meshZ,e.dataScale[2],t.zcalendar)),cells:s(t._meshI,t._meshJ,t._meshK),lightPosition:[t.lightposition.x,t.lightposition.y,t.lightposition.z],ambient:t.lighting.ambient,diffuse:t.lighting.diffuse,specular:t.lighting.specular,roughness:t.lighting.roughness,fresnel:t.lighting.fresnel,vertexNormalsEpsilon:t.lighting.vertexnormalsepsilon,faceNormalsEpsilon:t.lighting.facenormalsepsilon,opacity:t.opacity,opacityscale:t.opacityscale,contourEnable:t.contour.show,contourColor:a(t.contour.color).slice(0,3),contourWidth:t.contour.width,useFacetNormals:t.flatshading},u=o(t);l.vertexIntensity=t._meshIntensity,l.vertexIntensityBounds=[u.min,u.max],l.colormap=i(t),this.mesh.update(l)},f.dispose=function(){this.scene.glplot.remove(this.mesh),this.mesh.dispose()},e.exports=function(t,e){var r=t.glplot.gl,i=n({gl:r}),a=new u(t,i,e.uid);return i._trace=a,a.update(e),t.glplot.add(i),a}},{\"../../components/colorscale\":655,\"../../lib/gl_format_color\":774,\"../../lib/str2rgbarray\":802,\"../../plots/gl3d/zip3\":881,\"../isosurface/convert\":1125,\"gl-mesh3d\":309}],1351:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./attributes\"),a=t(\"../isosurface/defaults\").supplyIsoDefaults,o=t(\"../surface/defaults\").opacityscaleDefaults;e.exports=function(t,e,r,s){function l(r,a){return n.coerce(t,e,i,r,a)}a(t,e,r,s,l),o(t,e,s,l)}},{\"../../lib\":778,\"../isosurface/defaults\":1126,\"../surface/defaults\":1314,\"./attributes\":1349}],1352:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),supplyDefaults:t(\"./defaults\"),calc:t(\"../isosurface/calc\"),colorbar:{min:\"cmin\",max:\"cmax\"},plot:t(\"./convert\"),moduleType:\"trace\",name:\"volume\",basePlotModule:t(\"../../plots/gl3d\"),categories:[\"gl3d\",\"showLegend\"],meta:{}}},{\"../../plots/gl3d\":870,\"../isosurface/calc\":1124,\"./attributes\":1349,\"./convert\":1350,\"./defaults\":1351}],1353:[function(t,e,r){\"use strict\";var n=t(\"../bar/attributes\"),i=t(\"../scatter/attributes\").line,a=t(\"../../plots/attributes\"),o=t(\"../../plots/template_attributes\").hovertemplateAttrs,s=t(\"../../plots/template_attributes\").texttemplateAttrs,l=t(\"./constants\"),c=t(\"../../lib/extend\").extendFlat,u=t(\"../../components/color\");function f(t){return{marker:{color:c({},n.marker.color,{arrayOk:!1,editType:\"style\"}),line:{color:c({},n.marker.line.color,{arrayOk:!1,editType:\"style\"}),width:c({},n.marker.line.width,{arrayOk:!1,editType:\"style\"}),editType:\"style\"},editType:\"style\"},editType:\"style\"}}e.exports={measure:{valType:\"data_array\",dflt:[],editType:\"calc\"},base:{valType:\"number\",dflt:null,arrayOk:!1,editType:\"calc\"},x:n.x,x0:n.x0,dx:n.dx,y:n.y,y0:n.y0,dy:n.dy,xperiod:n.xperiod,yperiod:n.yperiod,xperiod0:n.xperiod0,yperiod0:n.yperiod0,xperiodalignment:n.xperiodalignment,yperiodalignment:n.yperiodalignment,hovertext:n.hovertext,hovertemplate:o({},{keys:l.eventDataKeys}),hoverinfo:c({},a.hoverinfo,{flags:[\"name\",\"x\",\"y\",\"text\",\"initial\",\"delta\",\"final\"]}),textinfo:{valType:\"flaglist\",flags:[\"label\",\"text\",\"initial\",\"delta\",\"final\"],extras:[\"none\"],editType:\"plot\",arrayOk:!1},texttemplate:s({editType:\"plot\"},{keys:l.eventDataKeys.concat([\"label\"])}),text:n.text,textposition:n.textposition,insidetextanchor:n.insidetextanchor,textangle:n.textangle,textfont:n.textfont,insidetextfont:n.insidetextfont,outsidetextfont:n.outsidetextfont,constraintext:n.constraintext,cliponaxis:n.cliponaxis,orientation:n.orientation,offset:n.offset,width:n.width,increasing:f(),decreasing:f(),totals:f(),connector:{line:{color:c({},i.color,{dflt:u.defaultLine}),width:c({},i.width,{editType:\"plot\"}),dash:i.dash,editType:\"plot\"},mode:{valType:\"enumerated\",values:[\"spanning\",\"between\"],dflt:\"between\",editType:\"plot\"},visible:{valType:\"boolean\",dflt:!0,editType:\"plot\"},editType:\"plot\"},offsetgroup:n.offsetgroup,alignmentgroup:n.alignmentgroup}},{\"../../components/color\":643,\"../../lib/extend\":768,\"../../plots/attributes\":824,\"../../plots/template_attributes\":906,\"../bar/attributes\":921,\"../scatter/attributes\":1187,\"./constants\":1355}],1354:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\"),i=t(\"../../plots/cartesian/align_period\"),a=t(\"../../lib\").mergeArray,o=t(\"../scatter/calc_selection\"),s=t(\"../../constants/numerical\").BADNUM;function l(t){return\"a\"===t||\"absolute\"===t}function c(t){return\"t\"===t||\"total\"===t}e.exports=function(t,e){var r,u,f,h,p=n.getFromId(t,e.xaxis||\"x\"),d=n.getFromId(t,e.yaxis||\"y\");\"h\"===e.orientation?(r=p.makeCalcdata(e,\"x\"),f=d.makeCalcdata(e,\"y\"),u=i(e,d,\"y\",f),h=!!e.yperiodalignment):(r=d.makeCalcdata(e,\"y\"),f=p.makeCalcdata(e,\"x\"),u=i(e,p,\"x\",f),h=!!e.xperiodalignment);for(var g,m=Math.min(u.length,r.length),v=new Array(m),y=0,x=!1,b=0;b<m;b++){var _=r[b]||0,w=!1;(r[b]!==s||c(e.measure[b])||l(e.measure[b]))&&b+1<m&&(r[b+1]!==s||c(e.measure[b+1])||l(e.measure[b+1]))&&(w=!0);var T=v[b]={i:b,p:u[b],s:_,rawS:_,cNext:w};l(e.measure[b])?(y=T.s,T.isSum=!0,T.dir=\"totals\",T.s=y):c(e.measure[b])?(T.isSum=!0,T.dir=\"totals\",T.s=y):(T.isSum=!1,T.dir=T.rawS<0?\"decreasing\":\"increasing\",g=T.s,T.s=y+g,y+=g),\"totals\"===T.dir&&(x=!0),h&&(v[b].orig_p=f[b]),e.ids&&(T.id=String(e.ids[b])),T.v=(e.base||0)+y}return v.length&&(v[0].hasTotals=x),a(e.text,v,\"tx\"),a(e.hovertext,v,\"htx\"),o(v,e),v}},{\"../../constants/numerical\":753,\"../../lib\":778,\"../../plots/cartesian/align_period\":825,\"../../plots/cartesian/axes\":828,\"../scatter/calc_selection\":1189}],1355:[function(t,e,r){\"use strict\";e.exports={eventDataKeys:[\"initial\",\"delta\",\"final\"]}},{}],1356:[function(t,e,r){\"use strict\";var n=t(\"../bar/cross_trace_calc\").setGroupPositions;e.exports=function(t,e){var r,i,a=t._fullLayout,o=t._fullData,s=t.calcdata,l=e.xaxis,c=e.yaxis,u=[],f=[],h=[];for(i=0;i<o.length;i++){var p=o[i];!0===p.visible&&p.xaxis===l._id&&p.yaxis===c._id&&\"waterfall\"===p.type&&(r=s[i],\"h\"===p.orientation?h.push(r):f.push(r),u.push(r))}var d={mode:a.waterfallmode,norm:a.waterfallnorm,gap:a.waterfallgap,groupgap:a.waterfallgroupgap};for(n(t,l,c,f,d),n(t,c,l,h,d),i=0;i<u.length;i++){r=u[i];for(var g=0;g<r.length;g++){var m=r[g];!1===m.isSum&&(m.s0+=0===g?0:r[g-1].s),g+1<r.length&&(r[g].nextP0=r[g+1].p0,r[g].nextS0=r[g+1].s0)}}}},{\"../bar/cross_trace_calc\":924}],1357:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"../bar/defaults\").handleGroupingDefaults,a=t(\"../bar/defaults\").handleText,o=t(\"../scatter/xy_defaults\"),s=t(\"../scatter/period_defaults\"),l=t(\"./attributes\"),c=t(\"../../components/color\"),u=t(\"../../constants/delta.js\"),f=u.INCREASING.COLOR,h=u.DECREASING.COLOR;function p(t,e,r){t(e+\".marker.color\",r),t(e+\".marker.line.color\",c.defaultLine),t(e+\".marker.line.width\")}e.exports={supplyDefaults:function(t,e,r,i){function c(r,i){return n.coerce(t,e,l,r,i)}if(o(t,e,i,c)){s(t,e,i,c),c(\"measure\"),c(\"orientation\",e.x&&!e.y?\"h\":\"v\"),c(\"base\"),c(\"offset\"),c(\"width\"),c(\"text\"),c(\"hovertext\"),c(\"hovertemplate\");var u=c(\"textposition\");if(a(t,e,i,c,u,{moduleHasSelected:!1,moduleHasUnselected:!1,moduleHasConstrain:!0,moduleHasCliponaxis:!0,moduleHasTextangle:!0,moduleHasInsideanchor:!0}),\"none\"!==e.textposition&&(c(\"texttemplate\"),e.texttemplate||c(\"textinfo\")),p(c,\"increasing\",f),p(c,\"decreasing\",h),p(c,\"totals\",\"#4499FF\"),c(\"connector.visible\"))c(\"connector.mode\"),c(\"connector.line.width\")&&(c(\"connector.line.color\"),c(\"connector.line.dash\"))}else e.visible=!1},crossTraceDefaults:function(t,e){var r,a;function o(t){return n.coerce(a._input,a,l,t)}if(\"group\"===e.waterfallmode)for(var s=0;s<t.length;s++)r=(a=t[s])._input,i(r,a,e,o)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../lib\":778,\"../bar/defaults\":925,\"../scatter/period_defaults\":1207,\"../scatter/xy_defaults\":1214,\"./attributes\":1353}],1358:[function(t,e,r){\"use strict\";e.exports=function(t,e){return t.x=\"xVal\"in e?e.xVal:e.x,t.y=\"yVal\"in e?e.yVal:e.y,\"initial\"in e&&(t.initial=e.initial),\"delta\"in e&&(t.delta=e.delta),\"final\"in e&&(t.final=e.final),e.xa&&(t.xaxis=e.xa),e.ya&&(t.yaxis=e.ya),t}},{}],1359:[function(t,e,r){\"use strict\";var n=t(\"../../plots/cartesian/axes\").hoverLabelText,i=t(\"../../components/color\").opacity,a=t(\"../bar/hover\").hoverOnBars,o=t(\"../../constants/delta.js\"),s=o.INCREASING.SYMBOL,l=o.DECREASING.SYMBOL;e.exports=function(t,e,r,o){var c=a(t,e,r,o);if(c){var u=c.cd,f=u[0].trace,h=\"h\"===f.orientation,p=h?t.xa:t.ya,d=u[c.index],g=d.isSum?d.b+d.s:d.rawS;if(!d.isSum){c.initial=d.b+d.s-g,c.delta=g,c.final=c.initial+c.delta;var m=w(Math.abs(c.delta));c.deltaLabel=g<0?\"(\"+m+\")\":m,c.finalLabel=w(c.final),c.initialLabel=w(c.initial)}var v=d.hi||f.hoverinfo,y=[];if(v&&\"none\"!==v&&\"skip\"!==v){var x=\"all\"===v,b=v.split(\"+\"),_=function(t){return x||-1!==b.indexOf(t)};d.isSum||(!_(\"final\")||_(h?\"x\":\"y\")||y.push(c.finalLabel),_(\"delta\")&&(g<0?y.push(c.deltaLabel+\" \"+l):y.push(c.deltaLabel+\" \"+s)),_(\"initial\")&&y.push(\"Initial: \"+c.initialLabel))}return y.length&&(c.extraText=y.join(\"<br>\")),c.color=function(t,e){var r=t[e.dir].marker,n=r.color,a=r.line.color,o=r.line.width;if(i(n))return n;if(i(a)&&o)return a}(f,d),[c]}function w(t){return n(p,t)}}},{\"../../components/color\":643,\"../../constants/delta.js\":747,\"../../plots/cartesian/axes\":828,\"../bar/hover\":928}],1360:[function(t,e,r){\"use strict\";e.exports={attributes:t(\"./attributes\"),layoutAttributes:t(\"./layout_attributes\"),supplyDefaults:t(\"./defaults\").supplyDefaults,crossTraceDefaults:t(\"./defaults\").crossTraceDefaults,supplyLayoutDefaults:t(\"./layout_defaults\"),calc:t(\"./calc\"),crossTraceCalc:t(\"./cross_trace_calc\"),plot:t(\"./plot\"),style:t(\"./style\").style,hoverPoints:t(\"./hover\"),eventData:t(\"./event_data\"),selectPoints:t(\"../bar/select\"),moduleType:\"trace\",name:\"waterfall\",basePlotModule:t(\"../../plots/cartesian\"),categories:[\"bar-like\",\"cartesian\",\"svg\",\"oriented\",\"showLegend\",\"zoomScale\"],meta:{}}},{\"../../plots/cartesian\":841,\"../bar/select\":933,\"./attributes\":1353,\"./calc\":1354,\"./cross_trace_calc\":1356,\"./defaults\":1357,\"./event_data\":1358,\"./hover\":1359,\"./layout_attributes\":1361,\"./layout_defaults\":1362,\"./plot\":1363,\"./style\":1364}],1361:[function(t,e,r){\"use strict\";e.exports={waterfallmode:{valType:\"enumerated\",values:[\"group\",\"overlay\"],dflt:\"group\",editType:\"calc\"},waterfallgap:{valType:\"number\",min:0,max:1,editType:\"calc\"},waterfallgroupgap:{valType:\"number\",min:0,max:1,dflt:0,editType:\"calc\"}}},{}],1362:[function(t,e,r){\"use strict\";var n=t(\"../../lib\"),i=t(\"./layout_attributes\");e.exports=function(t,e,r){var a=!1;function o(r,a){return n.coerce(t,e,i,r,a)}for(var s=0;s<r.length;s++){var l=r[s];if(l.visible&&\"waterfall\"===l.type){a=!0;break}}a&&(o(\"waterfallmode\"),o(\"waterfallgap\",.2),o(\"waterfallgroupgap\"))}},{\"../../lib\":778,\"./layout_attributes\":1361}],1363:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../lib\"),a=t(\"../../components/drawing\"),o=t(\"../../constants/numerical\").BADNUM,s=t(\"../bar/plot\"),l=t(\"../bar/uniform_text\").clearMinTextSize;e.exports=function(t,e,r,c){var u=t._fullLayout;l(\"waterfall\",u),s.plot(t,e,r,c,{mode:u.waterfallmode,norm:u.waterfallmode,gap:u.waterfallgap,groupgap:u.waterfallgroupgap}),function(t,e,r,s){var l=e.xaxis,c=e.yaxis;i.makeTraceGroups(s,r,\"trace bars\").each((function(r){var s=n.select(this),u=r[0].trace,f=i.ensureSingle(s,\"g\",\"lines\");if(u.connector&&u.connector.visible){var h=\"h\"===u.orientation,p=u.connector.mode,d=f.selectAll(\"g.line\").data(i.identity);d.enter().append(\"g\").classed(\"line\",!0),d.exit().remove();var g=d.size();d.each((function(r,s){if(s===g-1||r.cNext){var u=function(t,e,r,n){var i=[],a=[],o=n?e:r,s=n?r:e;return i[0]=o.c2p(t.s0,!0),a[0]=s.c2p(t.p0,!0),i[1]=o.c2p(t.s1,!0),a[1]=s.c2p(t.p1,!0),i[2]=o.c2p(t.nextS0,!0),a[2]=s.c2p(t.nextP0,!0),n?[i,a]:[a,i]}(r,l,c,h),f=u[0],d=u[1],m=\"\";f[0]!==o&&d[0]!==o&&f[1]!==o&&d[1]!==o&&(\"spanning\"===p&&!r.isSum&&s>0&&(m+=h?\"M\"+f[0]+\",\"+d[1]+\"V\"+d[0]:\"M\"+f[1]+\",\"+d[0]+\"H\"+f[0]),\"between\"!==p&&(r.isSum||s<g-1)&&(m+=h?\"M\"+f[1]+\",\"+d[0]+\"V\"+d[1]:\"M\"+f[0]+\",\"+d[1]+\"H\"+f[1]),f[2]!==o&&d[2]!==o&&(m+=h?\"M\"+f[1]+\",\"+d[1]+\"V\"+d[2]:\"M\"+f[1]+\",\"+d[1]+\"H\"+f[2])),\"\"===m&&(m=\"M0,0Z\"),i.ensureSingle(n.select(this),\"path\").attr(\"d\",m).call(a.setClipUrl,e.layerClipId,t)}}))}else f.remove()}))}(t,e,r,c)}},{\"../../components/drawing\":665,\"../../constants/numerical\":753,\"../../lib\":778,\"../bar/plot\":932,\"../bar/uniform_text\":937,d3:169}],1364:[function(t,e,r){\"use strict\";var n=t(\"d3\"),i=t(\"../../components/drawing\"),a=t(\"../../components/color\"),o=t(\"../../constants/interactions\").DESELECTDIM,s=t(\"../bar/style\"),l=t(\"../bar/uniform_text\").resizeText,c=s.styleTextPoints;e.exports={style:function(t,e,r){var s=r||n.select(t).selectAll(\"g.waterfalllayer\").selectAll(\"g.trace\");l(t,s,\"waterfall\"),s.style(\"opacity\",(function(t){return t[0].trace.opacity})),s.each((function(e){var r=n.select(this),s=e[0].trace;r.selectAll(\".point > path\").each((function(t){if(!t.isBlank){var e=s[t.dir].marker;n.select(this).call(a.fill,e.color).call(a.stroke,e.line.color).call(i.dashLine,e.line.dash,e.line.width).style(\"opacity\",s.selectedpoints&&!t.selected?o:1)}})),c(r,s,t),r.selectAll(\".lines\").each((function(){var t=s.connector.line;i.lineGroupStyle(n.select(this).selectAll(\"path\"),t.width,t.color,t.dash)}))}))}}},{\"../../components/color\":643,\"../../components/drawing\":665,\"../../constants/interactions\":752,\"../bar/style\":935,\"../bar/uniform_text\":937,d3:169}],1365:[function(t,e,r){\"use strict\";var n=t(\"../plots/cartesian/axes\"),i=t(\"../lib\"),a=t(\"../plot_api/plot_schema\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"aggregate\";var l=r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},aggregations:{_isLinkedToArray:\"aggregation\",target:{valType:\"string\",editType:\"calc\"},func:{valType:\"enumerated\",values:[\"count\",\"sum\",\"avg\",\"median\",\"mode\",\"rms\",\"stddev\",\"min\",\"max\",\"first\",\"last\",\"change\",\"range\"],dflt:\"first\",editType:\"calc\"},funcmode:{valType:\"enumerated\",values:[\"sample\",\"population\"],dflt:\"sample\",editType:\"calc\"},enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},editType:\"calc\"},editType:\"calc\"},c=l.aggregations;function u(t,e,r,a){if(a.enabled){for(var o=a.target,l=i.nestedProperty(e,o),c=l.get(),u=function(t,e){var r=t.func,n=e.d2c,a=e.c2d;switch(r){case\"count\":return f;case\"first\":return h;case\"last\":return p;case\"sum\":return function(t,e){for(var r=0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r+=o)}return a(r)};case\"avg\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l,i++)}return i?a(r/i):s};case\"min\":return function(t,e){for(var r=1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.min(r,o))}return r===1/0?s:a(r)};case\"max\":return function(t,e){for(var r=-1/0,i=0;i<e.length;i++){var o=n(t[e[i]]);o!==s&&(r=Math.max(r,o))}return r===-1/0?s:a(r)};case\"range\":return function(t,e){for(var r=1/0,i=-1/0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r=Math.min(r,l),i=Math.max(i,l))}return i===-1/0||r===1/0?s:a(i-r)};case\"change\":return function(t,e){var r=n(t[e[0]]),i=n(t[e[e.length-1]]);return r===s||i===s?s:a(i-r)};case\"median\":return function(t,e){for(var r=[],o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&r.push(l)}if(!r.length)return s;r.sort(i.sorterAsc);var c=(r.length-1)/2;return a((r[Math.floor(c)]+r[Math.ceil(c)])/2)};case\"mode\":return function(t,e){for(var r={},i=0,o=s,l=0;l<e.length;l++){var c=n(t[e[l]]);if(c!==s){var u=r[c]=(r[c]||0)+1;u>i&&(i=u,o=c)}}return i?a(o):s};case\"rms\":return function(t,e){for(var r=0,i=0,o=0;o<e.length;o++){var l=n(t[e[o]]);l!==s&&(r+=l*l,i++)}return i?a(Math.sqrt(r/i)):s};case\"stddev\":return function(e,r){var i,a=0,o=0,l=1,c=s;for(i=0;i<r.length&&c===s;i++)c=n(e[r[i]]);if(c===s)return s;for(;i<r.length;i++){var u=n(e[r[i]]);if(u!==s){var f=u-c;a+=f,o+=f*f,l++}}var h=\"sample\"===t.funcmode?l-1:l;return h?Math.sqrt((o-a*a/l)/h):0}}}(a,n.getDataConversions(t,e,o,c)),d=new Array(r.length),g=0;g<r.length;g++)d[g]=u(c,r[g]);l.set(d),\"count\"===a.func&&i.pushUnique(e._arrayAttrs,o)}}function f(t,e){return e.length}function h(t,e){return t[e[0]]}function p(t,e){return t[e[e.length-1]]}r.supplyDefaults=function(t,e){var r,n={};function o(e,r){return i.coerce(t,n,l,e,r)}if(!o(\"enabled\"))return n;var s=a.findArrayAttributes(e),u={};for(r=0;r<s.length;r++)u[s[r]]=1;var f=o(\"groups\");if(!Array.isArray(f)){if(!u[f])return n.enabled=!1,n;u[f]=0}var h,p=t.aggregations||[],d=n.aggregations=new Array(p.length);function g(t,e){return i.coerce(p[r],h,c,t,e)}for(r=0;r<p.length;r++){h={_index:r};var m=g(\"target\"),v=g(\"func\");g(\"enabled\")&&m&&(u[m]||\"count\"===v&&void 0===u[m])?(\"stddev\"===v&&g(\"funcmode\"),u[m]=0,d[r]=h):d[r]={enabled:!1,_index:r}}for(r=0;r<s.length;r++)u[s[r]]&&d.push({target:s[r],func:c.func.dflt,enabled:!0,_index:-1});return n},r.calcTransform=function(t,e,r){if(r.enabled){var n=r.groups,a=i.getTargetArray(e,{target:n});if(a){var s,l,c,f,h={},p={},d=[],g=o(e.transforms,r),m=a.length;for(e._length&&(m=Math.min(m,e._length)),s=0;s<m;s++)void 0===(c=h[l=a[s]])?(h[l]=d.length,f=[s],d.push(f),p[h[l]]=g(s)):(d[c].push(s),p[h[l]]=(p[h[l]]||[]).concat(g(s)));r._indexToPoints=p;var v=r.aggregations;for(s=0;s<v.length;s++)u(t,e,d,v[s]);\"string\"==typeof n&&u(t,e,d,{target:n,func:\"first\",enabled:!0}),e._length=d.length}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1366:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../registry\"),a=t(\"../plots/cartesian/axes\"),o=t(\"./helpers\").pointsAccessorFunction,s=t(\"../constants/filter_ops\"),l=s.COMPARISON_OPS,c=s.INTERVAL_OPS,u=s.SET_OPS;r.moduleType=\"transform\",r.name=\"filter\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},operation:{valType:\"enumerated\",values:[].concat(l).concat(c).concat(u),dflt:\"=\",editType:\"calc\"},value:{valType:\"any\",dflt:0,editType:\"calc\"},preservegaps:{valType:\"boolean\",dflt:!1,editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function a(i,a){return n.coerce(t,e,r.attributes,i,a)}if(a(\"enabled\")){var o=a(\"target\");if(n.isArrayOrTypedArray(o)&&0===o.length)return e.enabled=!1,e;a(\"preservegaps\"),a(\"operation\"),a(\"value\");var s=i.getComponentMethod(\"calendars\",\"handleDefaults\");s(t,e,\"valuecalendar\",null),s(t,e,\"targetcalendar\",null)}return e},r.calcTransform=function(t,e,r){if(r.enabled){var i=n.getTargetArray(e,r);if(i){var s=r.target,f=i.length;e._length&&(f=Math.min(f,e._length));var h=r.targetcalendar,p=e._arrayAttrs,d=r.preservegaps;if(\"string\"==typeof s){var g=n.nestedProperty(e,s+\"calendar\").get();g&&(h=g)}var m,v,y=function(t,e,r){var n=t.operation,i=t.value,a=Array.isArray(i);function o(t){return-1!==t.indexOf(n)}var s,f=function(r){return e(r,0,t.valuecalendar)},h=function(t){return e(t,0,r)};o(l)?s=f(a?i[0]:i):o(c)?s=a?[f(i[0]),f(i[1])]:[f(i),f(i)]:o(u)&&(s=a?i.map(f):[f(i)]);switch(n){case\"=\":return function(t){return h(t)===s};case\"!=\":return function(t){return h(t)!==s};case\"<\":return function(t){return h(t)<s};case\"<=\":return function(t){return h(t)<=s};case\">\":return function(t){return h(t)>s};case\">=\":return function(t){return h(t)>=s};case\"[]\":return function(t){var e=h(t);return e>=s[0]&&e<=s[1]};case\"()\":return function(t){var e=h(t);return e>s[0]&&e<s[1]};case\"[)\":return function(t){var e=h(t);return e>=s[0]&&e<s[1]};case\"(]\":return function(t){var e=h(t);return e>s[0]&&e<=s[1]};case\"][\":return function(t){var e=h(t);return e<=s[0]||e>=s[1]};case\")(\":return function(t){var e=h(t);return e<s[0]||e>s[1]};case\"](\":return function(t){var e=h(t);return e<=s[0]||e>s[1]};case\")[\":return function(t){var e=h(t);return e<s[0]||e>=s[1]};case\"{}\":return function(t){return-1!==s.indexOf(h(t))};case\"}{\":return function(t){return-1===s.indexOf(h(t))}}}(r,a.getDataToCoordFunc(t,e,s,i),h),x={},b={},_=0;d?(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set(new Array(f))},v=function(t,e){var r=x[t.astr][e];t.get()[e]=r}):(m=function(t){x[t.astr]=n.extendDeep([],t.get()),t.set([])},v=function(t,e){var r=x[t.astr][e];t.get().push(r)}),k(m);for(var w=o(e.transforms,r),T=0;T<f;T++){y(i[T])?(k(v,T),b[_++]=w(T)):d&&_++}r._indexToPoints=b,e._length=_}}function k(t,r){for(var i=0;i<p.length;i++){t(n.nestedProperty(e,p[i]),r)}}}},{\"../constants/filter_ops\":749,\"../lib\":778,\"../plots/cartesian/axes\":828,\"../registry\":911,\"./helpers\":1368}],1367:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plot_api/plot_schema\"),a=t(\"../plots/plots\"),o=t(\"./helpers\").pointsAccessorFunction;function s(t,e){var r,s,l,c,u,f,h,p,d,g,m=e.transform,v=e.transformIndex,y=t.transforms[v].groups,x=o(t.transforms,m);if(!n.isArrayOrTypedArray(y)||0===y.length)return[t];var b=n.filterUnique(y),_=new Array(b.length),w=y.length,T=i.findArrayAttributes(t),k=m.styles||[],M={};for(r=0;r<k.length;r++)M[k[r].target]=k[r].value;m.styles&&(g=n.keyedContainer(m,\"styles\",\"target\",\"value.name\"));var A={},S={};for(r=0;r<b.length;r++){A[f=b[r]]=r,S[f]=0,(h=_[r]=n.extendDeepNoArrays({},t))._group=f,h.transforms[v]._indexToPoints={};var E=null;for(g&&(E=g.get(f)),h.name=E||\"\"===E?E:n.templateString(m.nameformat,{trace:t.name,group:f}),p=h.transforms,h.transforms=[],s=0;s<p.length;s++)h.transforms[s]=n.extendDeepNoArrays({},p[s]);for(s=0;s<T.length;s++)n.nestedProperty(h,T[s]).set([])}for(l=0;l<T.length;l++){for(c=T[l],s=0,d=[];s<b.length;s++)d[s]=n.nestedProperty(_[s],c).get();for(u=n.nestedProperty(t,c).get(),s=0;s<w;s++)d[A[y[s]]].push(u[s])}for(s=0;s<w;s++){(h=_[A[y[s]]]).transforms[v]._indexToPoints[S[y[s]]]=x(s),S[y[s]]++}for(r=0;r<b.length;r++)f=b[r],h=_[r],a.clearExpandedTraceDefaultColors(h),h=n.extendDeepNoArrays(h,M[f]||{});return _}r.moduleType=\"transform\",r.name=\"groupby\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},groups:{valType:\"data_array\",dflt:[],editType:\"calc\"},nameformat:{valType:\"string\",editType:\"calc\"},styles:{_isLinkedToArray:\"style\",target:{valType:\"string\",editType:\"calc\"},value:{valType:\"any\",dflt:{},editType:\"calc\",_compareAsJSON:!0},editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t,e,i){var a,o={};function s(e,i){return n.coerce(t,o,r.attributes,e,i)}if(!s(\"enabled\"))return o;s(\"groups\"),s(\"nameformat\",i._dataLength>1?\"%{group} (%{trace})\":\"%{group}\");var l=t.styles,c=o.styles=[];if(l)for(a=0;a<l.length;a++){var u=c[a]={};n.coerce(l[a],c[a],r.attributes.styles,\"target\");var f=n.coerce(l[a],c[a],r.attributes.styles,\"value\");n.isPlainObject(f)?u.value=n.extendDeep({},f):f&&delete u.value}return o},r.transform=function(t,e){var r,n,i,a=[];for(n=0;n<t.length;n++)for(r=s(t[n],e),i=0;i<r.length;i++)a.push(r[i]);return a}},{\"../lib\":778,\"../plot_api/plot_schema\":816,\"../plots/plots\":891,\"./helpers\":1368}],1368:[function(t,e,r){\"use strict\";r.pointsAccessorFunction=function(t,e){for(var r,n,i=0;i<t.length&&(r=t[i])!==e;i++)r._indexToPoints&&!1!==r.enabled&&(n=r._indexToPoints);return n?function(t){return n[t]}:function(t){return[t]}}},{}],1369:[function(t,e,r){\"use strict\";var n=t(\"../lib\"),i=t(\"../plots/cartesian/axes\"),a=t(\"./helpers\").pointsAccessorFunction,o=t(\"../constants/numerical\").BADNUM;r.moduleType=\"transform\",r.name=\"sort\",r.attributes={enabled:{valType:\"boolean\",dflt:!0,editType:\"calc\"},target:{valType:\"string\",strict:!0,noBlank:!0,arrayOk:!0,dflt:\"x\",editType:\"calc\"},order:{valType:\"enumerated\",values:[\"ascending\",\"descending\"],dflt:\"ascending\",editType:\"calc\"},editType:\"calc\"},r.supplyDefaults=function(t){var e={};function i(i,a){return n.coerce(t,e,r.attributes,i,a)}return i(\"enabled\")&&(i(\"target\"),i(\"order\")),e},r.calcTransform=function(t,e,r){if(r.enabled){var s=n.getTargetArray(e,r);if(s){var l=r.target,c=s.length;e._length&&(c=Math.min(c,e._length));var u,f,h=e._arrayAttrs,p=function(t,e,r,n){var i,a=new Array(n),s=new Array(n);for(i=0;i<n;i++)a[i]={v:e[i],i:i};for(a.sort(function(t,e){switch(t.order){case\"ascending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:n-i};case\"descending\":return function(t,r){var n=e(t.v),i=e(r.v);return n===o?1:i===o?-1:i-n}}}(t,r)),i=0;i<n;i++)s[i]=a[i].i;return s}(r,s,i.getDataToCoordFunc(t,e,l,s),c),d=a(e.transforms,r),g={};for(u=0;u<h.length;u++){var m=n.nestedProperty(e,h[u]),v=m.get(),y=new Array(c);for(f=0;f<c;f++)y[f]=v[p[f]];m.set(y)}for(f=0;f<c;f++)g[f]=d(p[f]);r._indexToPoints=g,e._length=c}}}},{\"../constants/numerical\":753,\"../lib\":778,\"../plots/cartesian/axes\":828,\"./helpers\":1368}],1370:[function(t,e,r){\"use strict\";r.version=\"1.58.4\"},{}]},{},[26])(26)}));</script>                <div id=\"206158dd-4395-4f21-acbe-a5dac5b76df9\" class=\"plotly-graph-div\" style=\"height:500px; width:800px;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"206158dd-4395-4f21-acbe-a5dac5b76df9\")) {                    Plotly.newPlot(                        \"206158dd-4395-4f21-acbe-a5dac5b76df9\",                        [{\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": true, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03256724156173212, 0.013672953903941172, 0.06061645091644355, 0.03729672224393912, 0.011484352771991065, 0.01923555854175772, 0.04516428489504116, 0.06274682695844344, 0.05096403582553778, 0.054108112651322565, 0.032284197464053116, 0.03973245261503117, 0.018002404265904, 0.015192036051303148, 0.050516016116099696, 0.039127487755779705, 0.025722455100289414, 0.03440776779981596, 0.04297404849369611, 0.031066559587738345, 0.022110738725002323, 0.06717555038630962, 0.015482393060145634, 0.027069399698770473, 0.021256600539865236, 0.05320065688075764, 0.0626478965527245, 0.003842486559213804, 0.07085970376751252, 0.07436139908220087, 0.06357631566269056, 0.05812543351203203, 0.004800130596517452, 0.0432230606675148, 0.0400665903996144, 0.07456396892666817, 0.0057154009700752795, 0.03703166950227959, 0.007710192568733224, 0.04741585407672184, 0.025245051431868757, 0.005163537837298853, 0.038212350968803675, 0.019853559755054966, 0.038391562245254, 0.03449132260201233, 0.01805528249990727, 0.04665152509031551, 0.04199720912479928, 0.011998675530776381, 0.042119996821773906, 0.014129501950394894, 0.03422538097947836, 0.042458314382072, 0.02131652705637472, 0.08610292510794741, 0.07238908777279512, 0.0051214631530456245, 0.028332287379141365, 0.020812255097553134, 0.06750545411237649, 0.026405422648947154, 0.08062395839286701, 0.042638472214873345, 0.03772564458527735, 0.011273154506592878, 0.05130381223612598, 0.042945502525461574, 0.0459223781446261, 0.03391106320278985, 0.032812145206012895, 0.08641814533621073, 0.07028544601053, 0.007053928765734392, 0.041023820106472285, 0.02609774942642876, 0.08109510596841574, 0.011242228576780429, 0.006225901456283671, 0.01884389286195593, 0.022908660283844386, 0.030088485285107578, 0.02582791301288775, 0.023365689241992574, 0.011973901369076754, 0.021888864559254477, 0.025682212884670923, 0.07415914136384215, 0.028314151834430437, 0.056173278085355244, 0.023999371399570788, 0.009169701037795415, 0.052278863665248664, 0.016154375126851455, 0.03734474895255906, 0.042359037923493555, 0.06948157200323683, 0.07054207473993301, 0.03678102884441614, 0.08429531460361821, 0.014182537095621228, 0.03161131464211004, 0.0468255828932992, 0.06306661372738225, 0.041050313506275415, 0.03638417406805924, 0.03712174163333007, 0.02648031086261783, 0.011353716121188231, 0.039782874552266936, 0.033523728272744586, 0.04814255151099392, 0.0548185693499233, 0.027985321890030588, 0.043505069999290366, 0.03845320375902312, 0.019981823229630078, 0.01964060832480235, 0.023937299016064832, 0.027678953151085546, 0.03920564820457782, 0.024088062711858323, 0.038621019039835246, 0.057099793904594014, 0.0481244414113462, 0.012816617265343666, 0.0206077700879957, 0.04709749901667237, 0.02718447075624551, 0.08102271985262632, 0.0099313396328528, 0.01748653275093862, 0.07025236064302069, 0.02348923180917544, 0.038710270143513165, 0.03310484146433217, 0.07147300442946808, 0.04164696970422353, 0.06863028196884052, 0.019285780311162983, 0.059261497908404896, 0.03297852199258549, 0.05279677248160754, 0.03849862150049635, 0.04667428994019117, 0.04093275731429458, 0.01408200619542705, 0.07734993193298578, 0.03309657351512994, 0.03135373257100582, 0.054879820706056695, 0.03587063501722046, 0.08590967154928617, 0.06641037323112998, 0.044999651943466494, 0.0587901874844517, 0.015046125577230538, 0.04329149092414549, 0.022706548450514674, 0.024233304828937565, 0.04391103410827262, 0.04681634124634521, 0.021925619104877114, 0.03302864198173795, 0.04827214491420558, 0.05356698775930064, 0.02307213972588735, 0.11373265393610511, 0.04972319883693542, 0.04652372641222818, 0.08086924201675824, 0.02962730199630771, 0.04899087974003383, 0.04135277388351304, 0.009877295166786228, 0.011661633616313338, 0.03059418047113078, 0.0207138997502625, 0.04868106743586915, 0.038999529621962986, 0.03892867699531572, 0.0341704908891448, 0.04477014425875885, 0.023581492215661064, 0.03177177121064492, 0.014405659765803387, 0.06324258499911853, 0.07501144920076643, 0.044076956276382716, 0.026038487874237553, 0.017155994594629322, 0.05900628731719085, 0.039759957032012086, 0.03590743536395686, 0.03023499117365905, 0.11456877871283463, 0.027429413416289856, 0.03259041692529406, 0.025718260057536618, 0.04629302450588771, 0.01176904740610293, 0.051902361546776125, 0.024587218516639302, 0.0583646171061056, 0.02011581862877522, 0.022409993024276834, 0.036093153791236024, 0.04692536825314164, 0.02471524789663298, 0.02961404002936823, 0.010552363719658127, 0.06084061174520424, 0.006926998188386538, 0.05638876384390252, 0.04179554512458188, 0.03205079498833843, 0.03566045879519411, 0.03205700358375907, 0.0768747470740761, 0.0198752576086138, 0.059027030132710934, 0.0493628492445818, 0.02318191312120429, 0.07665506457643849, 0.009883907490542956, 0.009838982535127019, 0.03760906887639846, 0.0228764230851084, 0.0726456418633461, 0.028521116889481033, 0.020158289831929972, 0.01816792949102819, 0.03747396916151047, 0.03344992741144129, 0.019438050354697874, 0.043056663524891646, 0.07882362178393773, 0.022899505150105273, 0.06987896960760866, 0.021269660642636672, 0.008540670237770038, 0.09695730052356209, 0.031122725323906968, 0.07073935879660503, 0.03221058998523014, 0.021353378293237517, 0.014092565048485994, 0.015328413108363748, 0.012602040743721383, 0.03587105231625693, 0.03471748171640294, 0.032432399690151215, 0.05805046217782157, 0.007695895835890302, 0.019097863430423394, 0.02247424011251756, 0.005524149937887809, 0.05205326773492353, 0.05441756872460246, 0.023397934922416295, 0.012345658831431397, 0.03696302889979311, 0.03442651911505631, 0.08349673316947051, 0.04317886768175023, 0.028954643090920787, 0.0739085515961051, 0.00533345784892195, 0.09557578965489354, 0.03500026797077485, 0.02420221605072064, 0.040153154504618475, 0.008908481170822467, 0.05597943759390286, 0.01481971879755812, 0.047040366368102174, 0.0735007520498974, 0.06661131459155253, 0.03503481558124934, 0.0111808194612552, 0.04406059001173292, 0.04004356770643166, 0.06111116401318993, 0.0298080908666764, 0.020019804227298925, 0.0755393969427262, 0.05505079796005573, 0.03117613960057497, 0.0165106433310679, 0.03301913909880178, 0.006332624836691788, 0.023110346336449896, 0.04246879435543503, 0.014471331777583276, 0.04214197796370302, 0.007318431894028825, 0.0355140716502709, 0.02125782359923635, 0.0413670027628541, 0.033118123787322214, 0.03506299174789872, 0.048472319530057054, 0.04765311063134244, 0.023374947852322032, 0.09026679596198456, 0.06720787579459803, 0.0745573260688356, 0.04781716004280107, 0.036862412334552834, 0.050675851825092516, 0.024042639881372452, 0.09283141405986887, 0.06980939262679645, 0.02125824598728546, 0.08233233993606907, 0.016759056697732637, 0.02856689764718924, 0.0388829030229577, 0.08073976396449975, 0.00535293562071664, 0.01234358421061188, 0.030825774651020765, 0.02233530497843666, 0.0339064186305872, 0.04169917279588325, 0.03753890157012003, 0.023112224182114005, 0.006405348523652979, 0.01410238938738725, 0.05647526688075491, 0.015247014351189137, 0.02016980287485889, 0.026078753838581697, 0.04468862506161843, 0.02572741519127573, 0.007309612635123942, 0.049163305666297674, 0.012598777838450457, 0.015061474039352365, 0.029419561714998314, 0.03759854819093432, 0.02524279530293175, 0.043787265928196054, 0.07230159068214041, 0.027001067829717482, 0.03194791550881096, 0.028520421391086917, 0.05216437105887702, 0.018972230975383093, 0.07729638194931404, 0.0021487639169208705, 0.004094388444043163, 0.11078521995139973, 0.14968265380178178, 0.0875024510813611, 0.08181264996528625, 0.11523511367184774, 0.13332305236586503, 0.12029558712882654, 0.12692483354892048, 0.12629314458795957, 0.15284864391599381, 0.15870016706841333, 0.15974291254367146, 0.15468541107007436, 0.11217823877398457, 0.13030392437108926, 0.12470140999981336, 0.12311400446508612, 0.11705688520201615, 0.12651790252753667, 0.2543156306658472, 0.15698477625846863, 0.1323405879416636, 0.04518600819366319, 0.1381258996469634, 0.08283625396766833, 0.1385792696050235, 0.1451602993266923, 0.115238506346941, 0.1570305230894259, 0.13055726220565184, 0.19229752996138164, 0.16873381366687162, 0.0890191261257444, 0.1382296069392136, 0.13742025036896977, 0.18162706467722142, 0.05994620081037283, 0.14616382547787257, 0.09603605352874313, 0.20444869436323643, 0.11007845109062535, 0.1190137801957982, 0.1436397023499012, 0.10634348222187587, 0.12463302724063396, 0.09172346815466881, 0.11579917983285018, 0.16511787341109344, 0.08379566855728626, 0.059977603411035876, 0.1407424392444747, 0.0922959413645523, 0.1585730638887201, 0.11424741095730237, 0.13578354247978755, 0.11389116650181157, 0.2078503668308258, 0.11118915184800114, 0.15365806833973952, 0.14346122049859591, 0.2298016260777201, 0.10535569808312825, 0.21799165622464248, 0.1562606165451663, 0.22146525340420858, 0.14228184521198273, 0.07916836507086243, 0.18288886839790003, 0.07843467872589827, 0.08323502221277781, 0.08020504444305386, 0.11651686632207461, 0.1156418818448271, 0.1205315680376121, 0.1426729799381324, 0.10819913979087557, 0.1314956218536411, 0.09554492309689522, 0.1265231001057795, 0.2770576003406729, 0.08971026153968913, 0.11461862389530454, 0.19898864520447596, 0.07631355111620255, 0.16206583646791323, 0.10899380607796566, 0.1659121122211218, 0.16175687233252184, 0.08826162998697587, 0.2065415270626545, 0.14167292788624763, 0.06207990845931428, 0.24031055931534084, 0.061137022982750616, 0.12088162425373282, 0.12415273301303387, 0.08568532073072024, 0.09632751146065337, 0.09475069107221705, 0.16333099215158395, 0.07412839694214718, 0.17616873899740831, 0.15618259858872208, 0.13730016324136937, 0.13767528454107897, 0.11060258546578032, 0.1993878816387483, 0.09830674382724933, 0.18737698399594852, 0.13561419370983327, 0.09403426665812731, 0.12520579222057546, 0.12211528234183788, 0.13580370854054177, 0.08838162211967365, 0.14568300199295792, 0.0990128137969545, 0.126820461292352, 0.11777940286057335, 0.08292909791426999, 0.13020275479980878, 0.08837375111345734, 0.06533507164567709, 0.185922557754176, 0.116750621635999, 0.09589949157088995, 0.1750763247587851, 0.14295957955930913, 0.21809948900980608, 0.1366627745862518, 0.13414912803896836, 0.12042269030851976, 0.14691443448620184, 0.1070938537429486, 0.1217188686132431, 0.10871483319039855, 0.127477405326707, 0.12138136529496737, 0.20436779941831315, 0.09968054653810603, 0.14659373169498785, 0.10421121306717396, 0.12916295416653156, 0.11191327084920236, 0.12457375042140484, 0.1514889140214239, 0.11194805255425827, 0.22353044258696692, 0.1797152922621795, 0.1079549825351153, 0.10007247515022755, 0.10471143586827175, 0.19832012536270277, 0.10463910403528384, 0.06834224385342427, 0.14729205279478005, 0.13299736912761415, 0.20006881867136272, 0.125502027039017, 0.09376439971051045, 0.14539674163929053, 0.14549118014318602, 0.1275520577494587, 0.07390399184077978, 0.1529454980045557, 0.09432944974728993, 0.1479439213871956, 0.17971436945455416, 0.08846277490790401, 0.12564126242484364, 0.08988977476422276, 0.09648872459573404, 0.09605786842959267, 0.1623665631881782, 0.07545970300478594, 0.1324244277285678], [0.036553828178771904, 0.0034959124999919106, 0.07253255721713815, 0.037059513186769824, 0.03954290725024683, 0.03239407942497304, 0.027245479536109736, 0.0601174562637295, 0.047468511786844046, 0.012982277349302811, 0.04185558529570699, 0.03665551343666656, 0.01885789443206574, 0.03559064093445029, 0.04324906212942941, 0.03931364044547081, 0.024112471312816654, 0.014040114291544472, 0.04052018088155559, 0.06430047537599291, 0.008774563803204467, 0.035782086197286844, 0.0791917745290058, 0.0227091217945729, 0.03761570155620575, 0.010203984333202243, 0.029564605360584598, 0.03259760261114154, 0.02959063057122486, 0.050175252437059364, 0.0439870028889605, 0.02813249104656279, 0.010707996752379196, 0.011338566978728133, 0.050410615878977945, 0.03589750839663403, 0.020012689787628393, 0.038752719294279814, 0.004111472259475184, 0.05984484803463731, 0.04095507772373302, 0.0395846914366952, 0.022429807943158915, 0.039481231809726784, 0.028223345189222267, 0.05091578520036169, 0.04168097448668309, 0.03200398625007697, 0.031094186141022613, 0.03162972329716597, 0.08568962264273848, 0.029296685808471272, 0.08725663141480514, 0.014404224664238947, 0.033427118456789424, 0.020178686594590545, 0.013889884942078164, 0.020219264685043266, 0.07276303520692246, 0.021755505286689316, 0.040032073323215754, 0.057658065376537185, 0.018588597453864555, 0.0642005746651973, 0.04377878424046295, 0.04375801428354212, 0.009963563260888415, 0.03628879240048783, 0.0459588290458279, 0.01653984238925789, 0.06666141761732952, 0.018949679864038314, 0.036904054028647285, 0.06674616664115872, 0.010802917864306696, 0.024318907110552703, 0.019206084676885178, 0.04883182095363736, 0.012219856742636433, 0.0227834722692413, 0.013916521682403982, 0.023085917379441004, 0.06280222934271608, 0.04960348490359528, 0.025548811203667095, 0.02372822880611888, 0.04574933475149529, 0.05780303438327142, 0.010400943541234093, 0.055960594676434994, 0.07650343235582113, 0.03827892543215837, 0.015940787570018853, 0.024810181731092076, 0.054246177564242055, 0.06014330166258982, 0.0639907716374312, 0.04036451137757727, 0.06643435265868902, 0.01735677819566003, 0.03501102614349552, 0.028751944324799945, 0.03895523824862071, 0.07230906135269574, 0.039321172184177806, 0.026481374466259564, 0.08557200538260595, 0.040399082736777406, 0.035808033376399956, 0.023686386944193925, 0.02642836222159011, 0.04572353006473609, 0.04214112640225461, 0.03922388383320399, 0.02106267862421061, 0.0049784487512494835, 0.04213272953139884, 0.02114354812407068, 0.032027361781469414, 0.034730458698634586, 0.07634106571120874, 0.03698742562638862, 0.01847024228689926, 0.03200475638732314, 0.060837945102580955, 0.033400424889155796, 0.018497641530952284, 0.024867891134428124, 0.056654925990317545, 0.012269957223907113, 0.07582187107098953, 0.030551975592970848, 0.05392978007772139, 0.005728994571005127, 0.10661656542548112, 0.03517223588590111, 0.06766301672905684, 0.03376002470031381, 0.012087194664802934, 0.022634947739009346, 0.046298856514372995, 0.04826663860252925, 0.08664376501526151, 0.016583801280441027, 0.014654739793123943, 0.050126150250434875, 0.030667747237852643, 0.050530472304672, 0.025265611042933803, 0.012055335749339844, 0.05313503236642905, 0.024414782412350178, 0.032392759674361775, 0.03725876160232084, 0.03740323188581637, 0.024343232590971247, 0.061774262360164096, 0.07823930135262863, 0.05429674877918192, 0.016043434651302438, 0.026005085291607038, 0.053825424784528356, 0.02981518834297146, 0.02810996538028121, 0.057534653427345414, 0.06959327243800674, 0.042765066493302584, 0.027454244405297295, 0.010490687430969306, 0.011532220873050392, 0.018598800924207484, 0.040119553450495005, 0.0443141755115773, 0.02874914536784802, 0.025201894908345172, 0.040836371414895566, 0.07283818296023778, 0.015017253912187048, 0.06953438238373824, 0.019212863241721476, 0.0263043158421559, 0.019033258414960334, 0.034768941812217236, 0.03824175189116171, 0.03784636953579528, 0.07494024373590946, 0.08803736059261219, 0.0856664167451007, 0.06050003466329404, 0.03236014249601534, 0.06744467773075614, 0.08289442477481705, 0.04366629670507141, 0.006200734168357615, 0.028308043322925056, 0.006852754582983575, 0.03240078335095729, 0.01809633895754814, 0.03877511094989521, 0.050050401993628056, 0.06958073311086212, 0.034576197154819965, 0.05485410762152501, 0.06035725732467004, 0.03612443764827081, 0.05148315243422985, 0.06365976189928395, 0.044976717459836175, 0.03791035199537873, 0.012281092831731906, 0.018237984839028547, 0.06209164032978671, 0.01172688917722553, 0.08776112898652043, 0.035828389426959414, 0.039893452011580975, 0.025885186457474316, 0.016263476772499934, 0.01100083889572748, 0.0739316421427897, 0.0029818361342352417, 0.037246724391090016, 0.06630059305046286, 0.08574551357222454, 0.03867635017793093, 0.05109260803354638, 0.04160584369674325, 0.03348009168569531, 0.009654281910375824, 0.03772297454997897, 0.021179318793916276, 0.018398322663935165, 0.049615695141255856, 0.023663854492562156, 0.029597541450389793, 0.018920222962541238, 0.02893821575811931, 0.01767426642722317, 0.036147840321063995, 0.06424637577895607, 0.06628276793552296, 0.02617986573438559, 0.030300954955496957, 0.04211706555049334, 0.028412561464522566, 0.018198957201093435, 0.05332555482164025, 0.044410215358116796, 0.03806102069626961, 0.036346552693950276, 0.014199341015358056, 0.0289878200606576, 0.01842148954580937, 0.054774383149508915, 0.035576055824224434, 0.03623259273756828, 0.019537862855941057, 0.011661012756771274, 0.008580268693289586, 0.0852642422541976, 0.04341484519786068, 0.039222207851707935, 0.04601140533174787, 0.03596156210239444, 0.012804854860795396, 0.03958493910197701, 0.02665778000040778, 0.006262516054058713, 0.01626936306378671, 0.029963695909827948, 0.058299776299723556, 0.07909326481499843, 0.08331499435007572, 0.02075861520799143, 0.016096221283078194, 0.080127657524177, 0.06878805493137666, 0.0420212462278349, 0.014050203259103, 0.05373865711901869, 0.03061490971595049, 0.040503994428685734, 0.061844450022493086, 0.0767124414976154, 0.006647995190827974, 0.010008923326885062, 0.008332423599702972, 0.06500515434890985, 0.07381899854434387, 0.03329935370545302, 0.03468484078933086, 0.013223276872720038, 0.06540133737559829, 0.037802525995565314, 0.02513344768833901, 0.02381463345539357, 0.02492152593497719, 0.020726780041253993, 0.03568029237378921, 0.04436590023604887, 0.06491524167358875, 0.027385958337358067, 0.023200286153171743, 0.02746181855244296, 0.011916132593926574, 0.041590227213289054, 0.02862976391666702, 0.03570114714758737, 0.07608451840600797, 0.018958390557340214, 0.09236097894608974, 0.05212520601760064, 0.03226446227303573, 0.07061490190348454, 0.011041132849641144, 0.04452968841152532, 0.07637609847422157, 0.020209866975034987, 0.04283571555944426, 0.011405125326876129, 0.007806327410175332, 0.010298258292355707, 0.03851412602567247, 0.025558843343917812, 0.007897923700511456, 0.022751450505373732, 0.05998661435608353, 0.04150083700993231, 0.04559345829433628, 0.02380353771150112, 0.027500869939103723, 0.02005239256790706, 0.041526214219629765, 0.04049736853422863, 0.01838427359637405, 0.041509115137159824, 0.08109300250985793, 0.023549830075353384, 0.025744704263550893, 0.01280258855383311, 0.029285232137356485, 0.004552980577240565, 0.01662395698284464, 0.04950457824660199, 0.023131457257217596, 0.021324615193797008, 0.03873476865036147, 0.054012629203498363, 0.08665287095521178, 0.025425394165462682, 0.02970056002959609, 0.058772457364414415, 0.1700259479028838, 0.07601971831172705, 0.18668394189860138, 0.1136839622631669, 0.12445742237780776, 0.11120222721781049, 0.08235287919108357, 0.15154350894902432, 0.1346954708652837, 0.1049316069111228, 0.22708972516868794, 0.12005668851946082, 0.11118518241814204, 0.09538961321647678, 0.227363201922604, 0.20241180009075574, 0.10376645371850048, 0.08825723308005504, 0.1295642533472606, 0.12951273896864482, 0.07665924435215336, 0.10461976578725235, 0.0862337127327919, 0.10641003972185509, 0.1301482277257102, 0.06183394630040441, 0.10889542528561183, 0.1141615491360426, 0.18237755154924734, 0.13062932262463228, 0.2640969029494694, 0.09358086955866643, 0.11833605941917215, 0.1304184746529375, 0.07536171576274292, 0.17366753678236688, 0.10162545860345874, 0.1269308046570846, 0.11353432493550436, 0.1389808537704604, 0.09741649231208221, 0.12290416072521891, 0.11993854200201375, 0.14581466492797646, 0.153917078727058, 0.07957566250115633, 0.1509416483874832, 0.30546940863132477, 0.11059088073670864, 0.11956675909459591, 0.2507926497076239, 0.07251454889774323, 0.1806058423327548, 0.06581940315663815, 0.1168793940118381, 0.10003061632492713, 0.12853497000677244, 0.1108353908306786, 0.1779532725257533, 0.08770538733473845, 0.10788833682558366, 0.16108866461685725, 0.1478976317282234, 0.20190378092229366, 0.15330871780003819, 0.09940733441284724, 0.06813001845564161, 0.11773938286517348, 0.11659763913069453, 0.10534657857247762, 0.1729671393654176, 0.1285712987716709, 0.10477154050022364, 0.14568843027310713, 0.07470622379332781, 0.10804914962500334, 0.09458322862961463, 0.139603178948164, 0.08733547718397208, 0.09316604717501573, 0.18600809387862682, 0.14655729436448642, 0.11499257811478206, 0.144256504252553, 0.1069950997563345, 0.12800145149230957, 0.0798942686191627, 0.1124137243522065, 0.07145278408591237, 0.13934867403336934, 0.09937645428414855, 0.15797375461884908, 0.09595247158514601, 0.1049498255763735, 0.23992118878023966, 0.1787470363612686, 0.16894171679658548, 0.09953492613775389, 0.13167983054050378, 0.12954556649284704, 0.14027577000004904, 0.10739491294537272, 0.14367556971098694, 0.12890729574220522, 0.11709744802543096, 0.10372490023395844, 0.20280638177480015, 0.1001622589038951, 0.0964121383481792, 0.10083801871431725, 0.14222423758889946, 0.14390488740588936, 0.1443922519683838, 0.15196090298039572, 0.1813194304704666, 0.07445363234728575, 0.09408917371183634, 0.15941835567355156, 0.13896330685487815, 0.10939914254205567, 0.12438416773719446, 0.06148083667669978, 0.1706301969076906, 0.09662698967648403, 0.1541711086673396, 0.11732440441846848, 0.17260049975344113, 0.11663288223956313, 0.11413203286273138, 0.10239262386624302, 0.13971489295363426, 0.13988193470452512, 0.21956032062215464, 0.06971743077571903, 0.3263078161648342, 0.12377123348414898, 0.15383536954011234, 0.17255186236330441, 0.0794452955680234, 0.12227103327001844, 0.23527629088078225, 0.09839678542422396, 0.16929405289036886, 0.11737476528755256, 0.08045552564518792, 0.10098786638783556, 0.07993411219545773, 0.12804020941257477, 0.16707547408129486, 0.08322535987411227, 0.09867429946150098, 0.1245391315647534, 0.15656401669340475, 0.12674130339707645, 0.16488618084362575, 0.109684235815491, 0.14709197995918138, 0.13518774802131311, 0.10418939816632442, 0.11205189555351223, 0.11000178341886827, 0.09728827633495842, 0.053880538791418076, 0.1222525771175112, 0.1561895739287138, 0.12301135568746499, 0.14486337240253175, 0.13209417116429123, 0.13886149946068013, 0.10170534931655441, 0.10395642995302166, 0.16729042040450232, 0.12934913060494832, 0.10054704254227025, 0.113779805334551, 0.18098430202475616], [0.06204507925680705, 0.02176058242496635, 0.08965677940951926, 0.05987484606781176, 0.0256069192463266, 0.03911262783887131, 0.06326106150767632, 0.042237308741148026, 0.035049682283507924, 0.03624967146398766, 0.02553819552330034, 0.010780806952555264, 0.03711975013305034, 0.02796612274167793, 0.028496560707156147, 0.01002098004599767, 0.01287174060208989, 0.03551783073427422, 0.012452167625139867, 0.05026882241613098, 0.027203661422910433, 0.07457381446978875, 0.05713279106255088, 0.023202564334496856, 0.036578682916505, 0.04470994123922927, 0.038099039013364484, 0.007779370910221977, 0.010616571792135281, 0.027765659748443534, 0.05015217546107514, 0.06740424382899489, 0.04336622816377452, 0.034625485938574584, 0.02777689289567726, 0.026121503241094093, 0.06176401648138251, 0.04677998873272112, 0.003376798434016694, 0.05717538270567145, 0.025380124005356004, 0.04822537688804524, 0.06922799668141774, 0.01958734671851354, 0.011802493245340884, 0.0031500125229026055, 0.046492184711886306, 0.014408626660172428, 0.04910599659862263, 0.023802903281258683, 0.03365425805428198, 0.02998519529189382, 0.03274523486782398, 0.024747525807470083, 0.016170907632580826, 0.0529606047618602, 0.04082235288141029, 0.0030707748997623897, 0.014755213866010308, 0.021655540115066936, 0.025385374170062796, 0.04447822831571102, 0.03744053095579147, 0.030981925914862325, 0.015125330969957369, 0.013071724379967366, 0.0403541026503912, 0.02830808064235108, 0.04297086616445865, 0.07448170334100723, 0.002038909097401691, 0.006116273945995739, 0.041275142692029476, 0.06800956491913114, 0.07827706861176661, 0.029626375796007257, 0.045856628101319075, 0.07401695435068437, 0.06127102007823331, 0.047171527187206914, 0.013947768220012742, 0.01987993950024247, 0.006220662317770932, 0.06961730614836727, 0.018756295687385967, 0.019226031910095896, 0.012258302536793053, 0.02704607505750443, 0.017661396314256957, 0.011820307334086724, 0.03751617743234549, 0.013679293117352893, 0.04676144097798637, 0.019470004265063574, 0.02225883408183498, 0.020006057107821107, 0.0862703061263476, 0.010121807805262506, 0.0124556145830346, 0.07758752096976552, 0.08622189943811723, 0.025722967394228493, 0.05118940783930676, 0.041115466438766034, 0.017629876666303192, 0.0215960410756192, 0.030296917672136, 0.06577928138098546, 0.0714521666190454, 0.00474838975683919, 0.028908594311880212, 0.05179461018581476, 0.03400184440293482, 0.034842569647090774, 0.03521082417241164, 0.07480133404689175, 0.035232231952250004, 0.007106101323318268, 0.021818028895982673, 0.0295388006738254, 0.023560221839163984, 0.03516749631879585, 0.03758603600519044, 0.031152597828102962, 0.02313227149923997, 0.019569150105650936, 0.07193073736769812, 0.019009129709697196, 0.02313451236113906, 0.020908155844413807, 0.05269208470625537, 0.02421984269416758, 0.03304024493055684, 0.04181658988818526, 0.01683988718182913, 0.034092154021241834, 0.12959463814539568, 0.041002212158803425, 0.045547782709555965, 0.03248457224773509, 0.07791652224425759, 0.026532666624656746, 0.07319131972534315, 0.013935389196766275, 0.0241918446429606, 0.01995496342091688, 0.016249188521344746, 0.034629346802830696, 0.022709827470992292, 0.006779602994876248, 0.04165152606687375, 0.03217835617916925, 0.05004317559567945, 0.015202117385342717, 0.03675367709781442, 0.051936122056628974, 0.023134322371333838, 0.05357722006738186, 0.022057582291641405, 0.022612939455679486, 0.023462767247110605, 0.04257843204374824, 0.03245610770370279, 0.019410467906189815, 0.03669870558327862, 0.016133988542216163, 0.02345345096130456, 0.022991897870919535, 0.026838748682556406, 0.028094579598733356, 0.019503167664100016, 0.06192843908710139, 0.06560487752514226, 0.042643208389303515, 0.020147614779749086, 0.02858156418161733, 0.036690325675798316, 0.01902826948623572, 0.06773024597870451, 0.01596353715285659, 0.1049904969653913, 0.021295439884332672, 0.055704430743519745, 0.031820306820528846, 0.02938105146001492, 0.032546536065638065, 0.046856527482824664, 0.017083208143178905, 0.01979527359695307, 0.02873993425496987, 0.03882356852825199, 0.05113534216902085, 0.00792205155760582, 0.041640856103705506, 0.033152355879013023, 0.02796833137316363, 0.04189025843515992, 0.010807094247346478, 0.057078677894813676, 0.023235127230041792, 0.02918207106579627, 0.03375716128253511, 0.03415010091183441, 0.025368553286950504, 0.09525041854275124, 0.02582703939905124, 0.029712481889873743, 0.019074744046000496, 0.07637569813856057, 0.0398575982211956, 0.04425528206463371, 0.013461546989024749, 0.04312759418306606, 0.030952056803341423, 0.013250477645280105, 0.0223408553948892, 0.04664390853473118, 0.05077311642734068, 0.007240248544673834, 0.04747532427843128, 0.024605837517551014, 0.03977721557021141, 0.01501656519914312, 0.037287897896021605, 0.005953736395375537, 0.022840691431026374, 0.026810670903484737, 0.042504485297415934, 0.05488663998299411, 0.001732129102622691, 0.036097123221095116, 0.009919424557925334, 0.02096065749148173, 0.010984247018183981, 0.03740772378763982, 0.048847556180719814, 0.02998668806893485, 0.044845688955060074, 0.028505242562719753, 0.044027867660458596, 0.04664447171879666, 0.02530360221862793, 0.02985461462023003, 0.038891062406556945, 0.008137222645538194, 0.06102316480662141, 0.017896554499332393, 0.02093171118758619, 0.05773768467562539, 0.04680185452369707, 0.012956020588587438, 0.04914909714300718, 0.015600403870588966, 0.032351827049361806, 0.037396643310785294, 0.024946463793250065, 0.029472344954098974, 0.0498818505023207, 0.019672368852687732, 0.05693995819560119, 0.054606656078249216, 0.03127859499571579, 0.020805481621729474, 0.04482980105759842, 0.007110587712044695, 0.04694422474130988, 0.03347376434664641, 0.03367378968479378, 0.06518315444035189, 0.012333032991071897, 0.04698403099817889, 0.052721750257270675, 0.02724395283231778, 0.02321144126887832, 0.031375907095415254, 0.06788318098655768, 0.040796622833503146, 0.10737505901072707, 0.0621373803753938, 0.03339912549459508, 0.04430841814194407, 0.0484984533063003, 0.03170389735272952, 0.024319166650197337, 0.0567735305189022, 0.04890202897201691, 0.014422207538570677, 0.012627012528745192, 0.011275761777402034, 0.056064821047974486, 0.02841372006306691, 0.0498563952610961, 0.025867520798263804, 0.005717174066895885, 0.018994286756164262, 0.02390075651263552, 0.0040308924092512044, 0.024050300541732992, 0.034157574975064824, 0.029996889842940227, 0.014097304615591253, 0.020337865820952823, 0.046681126180504046, 0.008023249966624593, 0.023685705016500185, 0.01758986515259104, 0.03793677754168, 0.040746424812823534, 0.029514037538319826, 0.006104896185986165, 0.031095326079853942, 0.0026944381742006434, 0.06427410750516824, 0.058788097596594265, 0.026222728791513612, 0.017359721341303418, 0.00919963969915573, 0.02521044953859278, 0.003999244687812669, 0.017066862234579663, 0.022257115691900253, 0.040665814852608104, 0.0351750009161021, 0.05012446069823844, 0.02124016811805112, 0.049856595428926606, 0.03048810169899038, 0.03821453245888863, 0.026882963720709085, 0.030536101266209568, 0.01768094999715686, 0.02603158208408526, 0.06998971330800227, 0.03403496369719505, 0.01958542307173567, 0.01815653349538999, 0.022652540455705354, 0.020700658139373575, 0.03404368626485978, 0.007011129321264369, 0.10133220933909927, 0.02211752237885126, 0.023144715831481984, 0.023056051660595194, 0.010183219465294054, 0.009491067945158907, 0.013553810788185468, 0.05133255837219102, 0.023262808066127554, 0.012585787285518433, 0.03869091493210622, 0.02324840785669429, 0.07591282869023935, 0.12740028303648743, 0.2662510616438729, 0.09677966684103012, 0.11517447978258133, 0.14798871826912674, 0.1809273050831897, 0.1797893882862159, 0.17915429307946137, 0.16130177889551434, 0.10312723301883255, 0.12840162430490765, 0.12287943490913936, 0.11139987768339259, 0.13679829160017626, 0.060939080747110505, 0.0902594474277326, 0.07380677134330783, 0.13038874124842031, 0.10732149545635496, 0.13614840433001518, 0.1468270527465003, 0.1467466192053897, 0.11062949616461992, 0.17020989874643938, 0.09804510072405849, 0.16720634991569178, 0.1517188831099442, 0.2097054272890091, 0.10788990424147674, 0.13284976061965736, 0.15243503611002648, 0.2571471030158656, 0.17134765269500868, 0.16429455259016582, 0.09190025366842747, 0.12492623579289232, 0.11431265888469559, 0.1134298373279827, 0.09434046237064259, 0.1114840635231563, 0.190734524545925, 0.09569610748440027, 0.1526514616395746, 0.07453869349722352, 0.13668425700494222, 0.08262758409338337, 0.11557058138506753, 0.17401529955012457, 0.07314118277281523, 0.168657817744783, 0.12282437857772623, 0.0924097520432302, 0.10549140508685793, 0.08853290150208132, 0.13466994437788213, 0.15350336235548767, 0.16538076501871857, 0.12719436122902802, 0.15086439039025987, 0.1612462340188878, 0.1560594037707363, 0.1530971098691225, 0.11931485975427286, 0.06584549961345536, 0.07285959752542631, 0.09116714407822915, 0.15544824727943965, 0.1485170934881483, 0.19408355626676763, 0.14867042883166245, 0.13751956075429916, 0.15134971934769834, 0.1584799960255623, 0.14915032950895174, 0.14144977128931455, 0.09799543196069342, 0.1369147417800767, 0.11301904544234276, 0.09176997494484697, 0.1308654120990208, 0.09301898828042404, 0.05585222245593156, 0.17873950462256158, 0.15474069810339383, 0.1549155565776995, 0.09840514497565371, 0.1482405090438468, 0.11125641502439976, 0.09900796227157116, 0.13016810880175658, 0.07487039534108979, 0.11543726282460348, 0.1111896268225142, 0.1472226386623723, 0.13346166349947453, 0.12879085913300514, 0.11568150828991618, 0.10230398005140678, 0.21867389604449272, 0.15031408491943563, 0.16452838932829245, 0.180983569206936, 0.13276149678443158, 0.1276768131979874, 0.08285276951002223, 0.16177781192319735, 0.1278318584497486, 0.12133085514817919, 0.17131217888423375, 0.07540553555424724, 0.17954158729740552, 0.12759028641240938, 0.10465036093124322, 0.1775492456342493, 0.179387220580663, 0.10116950342697756, 0.07922157578702484, 0.08857044484466314, 0.12270506498004709, 0.137545535074813, 0.10461948080254452, 0.15041809076709406, 0.08868320379406214, 0.07954518949346882, 0.16298086808196136, 0.1703049343611513, 0.20603037306240626, 0.13108630238899163, 0.07729140828762736, 0.11798379117889063, 0.141496033806886, 0.05278832811330046, 0.0841004800583635, 0.14568092567580088, 0.04264093190431595, 0.2670198418200016, 0.10615446272173099, 0.17479632049798965, 0.15447350458375045, 0.10422133680965219, 0.15272523196680204, 0.14722955971956253, 0.13100225904158183, 0.12800702905016287, 0.11219099523233515, 0.10098918953112193, 0.13386697960751398, 0.10012419987469912, 0.1001766234902399, 0.13777033372649125, 0.14196872844227723, 0.1006200664809772, 0.06919416492538792, 0.10989013048154966, 0.1756017551358257, 0.16735379557524407, 0.1427440225545849, 0.13207471077995642, 0.0566296980583242, 0.12264116055199079, 0.09582453380737986, 0.1316226843212332, 0.0842231320483344, 0.1961059027484485, 0.14510771286274704, 0.11724395730665751, 0.10987165397299187, 0.12309413695974009, 0.0961297524294683, 0.09563145666782345, 0.12074640579521656, 0.12423711562795298, 0.10092508154256002, 0.18634071174476827, 0.06202891655266285], [0.04801796230354479, 0.02863423546243991, 0.037614982309085984, 0.024733403797394464, 0.05206068412267736, 0.03166887816041708, 0.052016162047428746, 0.04682132847873228, 0.04999875190800854, 0.03158060075449092, 0.015273271960073283, 0.045427682011255195, 0.13127037536885056, 0.04054805510012167, 0.012331043187129711, 0.024285568988748958, 0.015519278223759361, 0.04075389209070376, 0.016942646221390793, 0.03082931660381811, 0.01735517685301602, 0.07017343344965152, 0.05517380278823631, 0.05057392568726625, 0.030484332436961786, 0.03665068905268397, 0.08072488369154078, 0.0066583763525289085, 0.024827133232195462, 0.043048619492245574, 0.02189133781939745, 0.04422623058781028, 0.034875889109181504, 0.020178354112431407, 0.027331896059747254, 0.022746229178405235, 0.029545253541852747, 0.09115282698933568, 0.02165536878497473, 0.07008381254438843, 0.06917677407285996, 0.005510689075370985, 0.014864132307203752, 0.03055014694109559, 0.005092042722805802, 0.07087364766214575, 0.06026978737541607, 0.009839795080811849, 0.025428966652335863, 0.03899420990741678, 0.02131092914247087, 0.01021640915756247, 0.012533400989403682, 0.03960381255352071, 0.06249663752636739, 0.03850459600133555, 0.022515866539574096, 0.013820663343981972, 0.02537764565620039, 0.02715268817597202, 0.031643836825553856, 0.030070639814117124, 0.023287372730140175, 0.0228783297685108, 0.03234771851982389, 0.009987920971720346, 0.05645831707598908, 0.03074369566248996, 0.05495782169912543, 0.031110701683376516, 0.04077997497682061, 0.0563065423630178, 0.012916666405674602, 0.015069216123915144, 0.09942810436976807, 0.03767691898558821, 0.04537768415840609, 0.015263982815667987, 0.01698552624189428, 0.041962980425783565, 0.06541912177843706, 0.04898960070152368, 0.05422724304454667, 0.011547670267256243, 0.028233618209404603, 0.016235580501545752, 0.023450031144810573, 0.01729998311826161, 0.015104165766388178, 0.025827329472771714, 0.035182736215314696, 0.031075970868446996, 0.022641936649701426, 0.01582737553066441, 0.015015488024801016, 0.025018897406490784, 0.018894486129283905, 0.060945771102394374, 0.07672737605337586, 0.01800218374202294, 0.050476844289473126, 0.07420099340379238, 0.047304648972515545, 0.05662765566791807, 0.018078831057729464, 0.06937247714293854, 0.038625415946756086, 0.04692549717479518, 0.06536021136811801, 0.04066422368798937, 0.020203124033287168, 0.04768154124862381, 0.007255829405039549, 0.01988332030097289, 0.04763396915846637, 0.030199683603963683, 0.031224010246140615, 0.007159783621318638, 0.02945695917255112, 0.029398611946297542, 0.06096874629812581, 0.037619905080646276, 0.011331614539293306, 0.021791632187419703, 0.02531773440672883, 0.052169653453997204, 0.025493929595021263, 0.03234959466915045, 0.02702812271724854, 0.02875949302688241, 0.06770569658172981, 0.01476148352958262, 0.014527353325060435, 0.08254416499819074, 0.03878594036879284, 0.056634536013007164, 0.04187677933701447, 0.005605574988294393, 0.015340284078515001, 0.05586302812610354, 0.0081721985812432, 0.04618290505771126, 0.027053007989057472, 0.022429989451276403, 0.04003756606419172, 0.03661641964156713, 0.022672421531751752, 0.0343668317821409, 0.025916019088721702, 0.014945013681426644, 0.01740524255936699, 0.06667743104376964, 0.040225700076137266, 0.08546177736882653, 0.04571345042703407, 0.04688096831419638, 0.027247886639088392, 0.03508050134405494, 0.01134953719364213, 0.03292381849938205, 0.029804436955600977, 0.051350051004971774, 0.05138210499925273, 0.07438138872385025, 0.03735148680529424, 0.03876626963860222, 0.05329525484038251, 0.03257048495912126, 0.035681103223136494, 0.02376857110565262, 0.016701474519712583, 0.04887486382254532, 0.06864522330995117, 0.03450500865333846, 0.02969030397278922, 0.026614698115736246, 0.04000658415524023, 0.043952814902045896, 0.0456369761377573, 0.015105687381167496, 0.024271324842369983, 0.008432063074516398, 0.08047493174672127, 0.04884001087131245, 0.04418516904115677, 0.06881264504045248, 0.03169329185038805, 0.06379367078521422, 0.03314626941989575, 0.030981613788753748, 0.024547240929678082, 0.12577695585787296, 0.009128583512002868, 0.03190734590004597, 0.022023202618584037, 0.03852463314043624, 0.029116273525037935, 0.0747770628492747, 0.04539208945685199, 0.011175308908735002, 0.004891690415596324, 0.07425041110920054, 0.03402770337249551, 0.015387847686984708, 0.04625492137191551, 0.01643017925588148, 0.0468542001077107, 0.14312227868608066, 0.05069898308387824, 0.035878519594137154, 0.01885154334429119, 0.014223480746815247, 0.005336364099223698, 0.00516316803571369, 0.05598867245550666, 0.02673749259806105, 0.0486498141129102, 0.01746033621020615, 0.03318969226841416, 0.07999693775283438, 0.06101276965013572, 0.026105323573574424, 0.05384489534688847, 0.05557969565104161, 0.016115087949271713, 0.0009888328994358225, 0.024299874203279614, 0.017689932104466215, 0.046468646332089386, 0.023541714796530347, 0.052476215575422556, 0.03345506052885737, 0.037798186764121056, 0.05008455944646682, 0.03457138294886265, 0.05235147709026933, 0.03777724717344556, 0.04038316769791501, 0.04938234016299248, 0.024512603413313627, 0.0184663067837911, 0.019017416318612437, 0.08703452654715095, 0.03345477554414954, 0.07929029102836337, 0.06409586314111948, 0.05222801085827606, 0.10453490819782019, 0.035607427890811644, 0.005702821354913924, 0.03360277420974203, 0.04703418491408229, 0.06130727420427969, 0.04826330699558769, 0.026765376994652406, 0.007048666302580386, 0.0251036074145564, 0.029310680593230894, 0.023176685008885603, 0.05035234329157642, 0.030307648703455925, 0.013083426564532732, 0.09463090928537504, 0.014845431882089801, 0.03554814428623233, 0.021563303457306962, 0.05457818474886673, 0.04531649726309946, 0.03866671498066612, 0.04497679888403841, 0.017234004069385783, 0.04356783109584025, 0.03088873252272606, 0.033798877615481615, 0.0682981051504612, 0.03534613423315542, 0.03171902529097029, 0.03742640385670321, 0.02045521166707788, 0.0311382196710578, 0.017471861127497892, 0.01450893618831677, 0.053890000962253125, 0.02558135035048638, 0.04853835795074701, 0.0784207551873156, 0.009604798047803342, 0.022593933689807142, 0.03205062196190868, 0.03666186113176601, 0.05031884741038084, 0.02700299147649535, 0.0032513667829334736, 0.03303982423884528, 0.016135810408741236, 0.002422178754516478, 0.013223083490239722, 0.038657503867787976, 0.07172706151115042, 0.011076842451335063, 0.03899980103597045, 0.001720943664882465, 0.0363226445125682, 0.024655531725979278, 0.03865491525669183, 0.008631460767771517, 0.03646389854007533, 0.02656348907787885, 0.04162515480337398, 0.07415909386639084, 0.002254346086244498, 0.13480331722114766, 0.039430144908172746, 0.030104495318872587, 0.056006168480962515, 0.04477166756987572, 0.05318445346451231, 0.018067670853010247, 0.006271722926093, 0.08941424385245357, 0.05551079720524805, 0.02370974381587335, 0.006760289767823581, 0.02967762215329068, 0.029407453257590532, 0.05786089984966176, 0.022982137144676278, 0.08071484137326479, 0.09022597529526268, 0.07031078250812632, 0.02515706409966307, 0.06625741108187608, 0.0852666035560625, 0.04274672569174852, 0.03921910355399762, 0.04023315378331712, 0.02126014418900013, 0.029749421336288964, 0.02603071186292384, 0.0819346234202385, 0.09871694538742304, 0.057903715409338474, 0.08672826976648398, 0.025938008712338548, 0.036557064790810855, 0.014810273590098535, 0.06161144109708922, 0.053759423683264425, 0.07295888755470514, 0.07694273628294468, 0.0882055897797857, 0.03032786226166146, 0.187399633494871, 0.09575758954244, 0.08341146845902715, 0.14729404768773488, 0.14277704006859235, 0.14600850881210395, 0.15621785526829107, 0.27956701282943996, 0.14379424548574857, 0.13666113253150666, 0.10370889359286853, 0.14375668178711618, 0.17408741425190652, 0.15354608292026178, 0.10116169348891292, 0.25557097473314827, 0.06388934422284365, 0.10856235958635807, 0.14572319840746267, 0.11949118386421885, 0.15343280828424863, 0.26471143854515894, 0.1303860271083457, 0.11697442962655, 0.13315892831555434, 0.2360078330550875, 0.20665383817894117, 0.11979728458183152, 0.08192721381783485, 0.1265627265508686, 0.10384986602834292, 0.22061818385762827, 0.12647220997938088, 0.13193866450871738, 0.187194200232625, 0.0978472399126206, 0.06776932959577867, 0.20075135704662117, 0.13512548564800195, 0.15368039214185306, 0.07359742293400423, 0.10420837000544582, 0.11119876668921538, 0.19391058411981377, 0.24564142897725105, 0.10086245954568897, 0.12084053217300347, 0.10036931386483566, 0.1297451507832323, 0.16361482334988459, 0.10785903089812823, 0.08320556700761829, 0.06236312897609813, 0.09614614583551884, 0.14207137721989835, 0.1152304724923202, 0.1943590957671404, 0.11014612817338534, 0.08557788828121764, 0.10471610418920006, 0.1397872654987233, 0.18047237449458667, 0.09745413064956665, 0.10307978985032865, 0.10079313362283365, 0.10155636338250977, 0.1849459015897342, 0.0806439955319677, 0.22885615538273538, 0.13329539527850492, 0.08927136473357677, 0.15414175524243287, 0.13331771908061846, 0.07852896795208965, 0.23707573860883713, 0.09308881631919316, 0.18255585698144777, 0.16757353235568317, 0.1004542935905712, 0.0683323915249535, 0.16497139127126761, 0.19558520854583808, 0.1471787645880665, 0.1378929992871625, 0.04044924343803099, 0.17148768875215734, 0.10112071675913674, 0.08400241139211825, 0.12211125184382711, 0.08864000146942479, 0.14401293732225895, 0.09955979444618736, 0.051462341765207906, 0.09946769688810621, 0.1259842211646693, 0.10322040266224317, 0.09300729033670255, 0.08159091829189233, 0.1112139183761818, 0.11276351593966995, 0.15794909665627138, 0.19906796594815596, 0.15501963027885982, 0.13054835982620716, 0.1226473759327616, 0.09852164943835565, 0.12480753287672997, 0.09678221134735004, 0.11191974407328026, 0.14551722231720174, 0.08383904051567827, 0.11202060830380235, 0.18871557073933737, 0.10104052070528269, 0.15410093457571097, 0.0829223600615348, 0.0942727785025324, 0.09566819255373307, 0.1274252531251737, 0.08047999361796038, 0.1170107719621488, 0.14268718846142292, 0.1401154321751424, 0.043764168596161265, 0.12421823878373418, 0.11601256552551474, 0.06962882767298392, 0.09556328425449984, 0.09066961506115538, 0.07190210997526135, 0.14894634831164563, 0.08347312693617173, 0.13652929317738327, 0.15769464602427824, 0.07725671479212386, 0.2473606195833002, 0.22189722236778053, 0.09361052153898136, 0.1070517845717924, 0.18987849833709852, 0.10876900064093725, 0.11892554350197315, 0.11409655905195645, 0.15833603803600582, 0.12819537680063928, 0.08199226497007267, 0.13278607332280704, 0.13601697209690297, 0.18343609331973962, 0.1649194969130414, 0.06184771377593279, 0.12076605616935662, 0.19733088915901525, 0.11961318446057183, 0.07117724458553962, 0.18226931164307253, 0.17759735376707145, 0.20349813465561184, 0.0987227875739336, 0.11888122159455504, 0.0948404816112348, 0.13133826958281652, 0.06966369758759226, 0.14590413655553544, 0.15833978354930878, 0.10102669216160264, 0.15343981076564106, 0.10554082279226609, 0.11065115500241518, 0.12468672650200979, 0.14779984126133577, 0.21433927863836288, 0.14810514130762645, 0.15620348389659608, 0.29480091109871864, 0.12287224243794169], [0.0668336298050625, 0.03751377881105457, 0.0356901345242347, 0.05646274112431066, 0.036060702853969166, 0.04690463222297175, 0.03414089658430644, 0.036624110836003504, 0.015985195990651846, 0.019930994171383123, 0.025566860235163143, 0.044583798186587434, 0.017444980962734138, 0.04213296362598028, 0.058774479398769994, 0.024001084700492874, 0.05184703380135553, 0.0255954978056252, 0.010282531546960984, 0.07298151669757706, 0.003174227529338428, 0.0166765146090516, 0.01947638758325151, 0.029546634360615696, 0.03909942015473332, 0.04008531118077891, 0.021006443338202577, 0.03319715954629438, 0.03161430698154228, 0.013631089141459336, 0.060850552283227444, 0.005242357737318213, 0.03239229827054909, 0.04309486165376646, 0.04442606254347733, 0.08516942377069167, 0.08748905680009297, 0.02272438713615494, 0.03646675856517894, 0.02252066378215594, 0.05531968103189554, 0.011680919277880873, 0.11237717167075191, 0.04280732226158891, 0.061166579968162944, 0.05526107256965978, 0.0619500707834959, 0.06361632208739008, 0.039943816273340156, 0.042930876703134606, 0.01510981796309352, 0.012366438966377504, 0.05952833180448838, 0.017462607606181076, 0.020251568040943572, 0.07447447694305863, 0.03763493463130934, 0.023362396650814583, 0.03956729719149215, 0.01784312665196402, 0.06875906791538, 0.008067182564575757, 0.030428777382309948, 0.024281920166686177, 0.01688998851126858, 0.012655740005097218, 0.028342897970495478, 0.0063165698499817935, 0.04650249844416976, 0.01774427936678486, 0.07515592287693705, 0.09494924398937396, 0.013751317065076103, 0.04347584210336208, 0.06375619529613427, 0.009809043873766703, 0.06546164556805577, 0.037766363471746445, 0.00843793070609016, 0.04939429255734597, 0.013621859368868172, 0.04071000783837267, 0.023557334672659636, 0.03453448082187346, 0.026277082839182446, 0.019985258313161985, 0.02498961183508592, 0.03508506449205535, 0.022730946873447726, 0.028001046939087764, 0.012856246254939054, 0.025701127048315744, 0.04072486775528107, 0.05998305204723563, 0.009308198516789292, 0.03795821924826928, 0.04313939729971545, 0.01547830827933337, 0.02786668513103255, 0.0395143578893372, 0.03809880831145814, 0.041277626130197725, 0.08884567221892731, 0.035030452601079426, 0.026956367639026473, 0.0248059035677995, 0.014296885513301407, 0.040724575985223055, 0.02898933319374919, 0.03488393992717777, 0.06112737421478544, 0.030174414959869215, 0.04287927411496639, 0.047457231142159016, 0.03232052283627646, 0.051429191936871836, 0.018775932490825653, 0.028204985727955188, 0.039277732372283936, 0.05972090682813099, 0.015184997946822217, 0.029328312325690473, 0.050668594893068075, 0.032393526418932846, 0.019761200960991637, 0.07893923736576523, 0.06957466022244521, 0.046764843831104894, 0.05722868163138628, 0.013351970368863215, 0.08612621921513762, 0.03351590476397957, 0.02964249100270016, 0.01985776497583304, 0.035869057423302105, 0.030396669105227505, 0.08700222828026329, 0.016455768507772257, 0.047838696744292974, 0.03529128146224788, 0.03874973374019776, 0.018044453081009642, 0.029928449408284256, 0.06510650033929519, 0.01226013882218727, 0.0446425016437258, 0.04912767239979335, 0.024352416562448655, 0.04456672963819333, 0.0614225369478975, 0.05785714755100863, 0.010317074916591602, 0.02320603164844215, 0.02698062526594315, 0.06807016488164663, 0.032587451727262566, 0.042936332124684534, 0.017591062766898955, 0.004032453463878483, 0.08267707643764359, 0.0389744204335979, 0.027028216015813605, 0.052633126798485, 0.04098361351394227, 0.02933391702494451, 0.0659037179180554, 0.03576083108782768, 0.020246406085789204, 0.03465507685073784, 0.01724222282479916, 0.02588258936469044, 0.07188528230679886, 0.04445151099935174, 0.014601834417719926, 0.028097895938637, 0.027629416702049117, 0.010839450189710727, 0.07623101411653416, 0.014586910039984753, 0.008822010364383459, 0.03602816031447478, 0.05400134516613824, 0.06450293665485722, 0.04370942099818161, 0.021280250877940228, 0.009540353336238434, 0.04839996394834348, 0.0048119460116140544, 0.02346950170717069, 0.025217501213774085, 0.031855682243726084, 0.02223659848927387, 0.0113850830987628, 0.041198064506586106, 0.041346022460077486, 0.09724216988044125, 0.05241500153871519, 0.04348651545920542, 0.03552145750394889, 0.015171834367460437, 0.0396638629026711, 0.02597856305406562, 0.04849207168444991, 0.028272617009601424, 0.0432859676490937, 0.035143652598240545, 0.05298774616260614, 0.02176461461931467, 0.007919839533445026, 0.020523519787405218, 0.044948276664529524, 0.08057219974164452, 0.026024662723232592, 0.04028486154441323, 0.038776179642549584, 0.05089867254719138, 0.007292436369295631, 0.024798697525901452, 0.02253919287717768, 0.10144164346690689, 0.04695288284814783, 0.04288988300998296, 0.029676811303943396, 0.026919521491176317, 0.07068418711423874, 0.021232283541134427, 0.05467462493106723, 0.006869218387042305, 0.017539970776332275, 0.03291463452790465, 0.10463870369962283, 0.05061991339815514, 0.02679152773427112, 0.04571121126147253, 0.022457995984171118, 0.04814586615456002, 0.10657954455486365, 0.06519126971917492, 0.04432042142642396, 0.03027338268501418, 0.07821313704230956, 0.04821710554616792, 0.0061349412925275305, 0.018471500969358852, 0.03416410248194422, 0.051006712285535674, 0.060466935725084374, 0.03698475559109023, 0.04155526908912829, 0.006700283947533795, 0.05497142632624932, 0.012030426728805261, 0.050055284053087234, 0.020815247436985373, 0.07484402747026511, 0.03232178491141115, 0.0488056973554194, 0.035356749913522174, 0.023574740792225515, 0.030962119477667978, 0.027807284479162524, 0.04254184204286762, 0.02178393760030823, 0.06453611701726913, 0.047963123103337627, 0.07063006037580115, 0.020675330123464977, 0.046026475594512055, 0.01437448277803404, 0.0678251865985138, 0.02741800724262638, 0.05507436008857829, 0.044244089629501104, 0.014200419037868934, 0.02861796080001763, 0.027231919013762047, 0.03964117269164749, 0.01953244475381715, 0.040803856016801934, 0.02251003622742636, 0.019518008921295404, 0.012305649862225567, 0.028802206806306328, 0.07680302592260496, 0.05642995431220957, 0.03751747343423111, 0.06742067116179637, 0.028086079251287237, 0.0395141068313803, 0.05062740442476102, 0.04037638234772852, 0.037516096008143256, 0.005829765078877764, 0.013222258222023291, 0.04326490592211485, 0.07510571128555707, 0.06173273601702281, 0.03108439488070352, 0.019757798107873117, 0.057885489958737574, 0.05215441355747836, 0.022493764957679168, 0.041299400318946154, 0.05839205027690955, 0.009254406805017164, 0.019556721040446843, 0.029250803270510266, 0.04060274502262473, 0.024139478702896407, 0.028277195424639752, 0.05161299350272332, 0.017856368262852942, 0.06894764636776277, 0.025212374881708195, 0.01533677096345595, 0.007618123000221593, 0.014566774513306362, 0.0541613640795861, 0.04237414211300867, 0.01777539019738989, 0.014095986561317529, 0.025027295973684107, 0.03397799389702933, 0.021563493447112184, 0.04535143842388477, 0.09508661340389933, 0.03707927551918796, 0.014885243227971452, 0.04939177179975169, 0.058133087387042384, 0.017233517220509902, 0.03724956406014306, 0.035605466924607754, 0.0021446017407080425, 0.03996873547190002, 0.02397498824367566, 0.03161583368533424, 0.03281858789601496, 0.039644792675971985, 0.021342538696314608, 0.030087813535439115, 0.03174919635057449, 0.044053594315690656, 0.02286782265374703, 0.03569103019045932, 0.013255277432368269, 0.05829314701259136, 0.04197660540895803, 0.07712853952710118, 0.047199269091444354, 0.009805775031314364, 0.017472386992137347, 0.11492883653513022, 0.14207596411662443, 0.15353792692933763, 0.14292781054973602, 0.09113637930048363, 0.14027221447655133, 0.13115505155708107, 0.09748368084962879, 0.10047764198056289, 0.043534772869731696, 0.13908952793904714, 0.12745405015136513, 0.14093910583427974, 0.10763404904199497, 0.21051927576107637, 0.14687545943473065, 0.11734594111996037, 0.11822762952319213, 0.13548798619636468, 0.1546748394944838, 0.1609571102474417, 0.15052835270762444, 0.08085624128580093, 0.12654683526073182, 0.16482424416712352, 0.11349563486874104, 0.11010213196277618, 0.11873783357441425, 0.1495273235653128, 0.06123796185212476, 0.17466159058468683, 0.10673738537090165, 0.12853883765637875, 0.10537584378783192, 0.08924267627298832, 0.11831529624760151, 0.16880352635468754, 0.18113446182438306, 0.11137469724885055, 0.0925481121188828, 0.10881796372788292, 0.06589946350348846, 0.1588546966335603, 0.22496979178062507, 0.15786360124392168, 0.16334319221121923, 0.15307902012552532, 0.12018780862646443, 0.10513354571802275, 0.08764911642564194, 0.1922237460634538, 0.08420977847916739, 0.13913118998919213, 0.1792574982557978, 0.18978346272238664, 0.1765438060143164, 0.135275251897318, 0.0774905922423516, 0.1085336304136685, 0.12646163840379032, 0.15071082434483937, 0.1494334414601326, 0.07702004177761929, 0.08794370918933835, 0.12346897327474185, 0.1369678167892354, 0.0644531457551888, 0.12099734161581312, 0.10487799585929938, 0.15445882108594688, 0.3300808237067291, 0.16113690845668316, 0.08572147307651383, 0.0735388042937432, 0.19563894851931504, 0.18037413619458675, 0.200067081621715, 0.07175917657358305, 0.15317396074533463, 0.1278098060616425, 0.14064862499279635, 0.07649946292596203, 0.07557352725416422, 0.16490634690437997, 0.09209081344306469, 0.10510042642376252, 0.09590951353311539, 0.09239234762000186, 0.17268632086259977, 0.12816467987639563, 0.15747414928461823, 0.108760295036648, 0.1582156252115965, 0.15163744533700602, 0.11251286510378122, 0.07098644053829567, 0.15700720862618514, 0.055363392257796865, 0.11516267327325684, 0.10213395274643387, 0.14421014674007893, 0.09122828008340937, 0.1257034433739526, 0.08386052293436867, 0.07553922730897154, 0.08279613897736583, 0.15474145806261472, 0.23125168255397252, 0.09945596501763378, 0.1922451877700431, 0.14928063537393296, 0.09913051926663943, 0.12883408181369305, 0.12437671742268971, 0.09917093959770032, 0.0970987140067986, 0.12639164073126657, 0.06461655055837971, 0.10328264467950378, 0.17871669227523462, 0.12224613103483405, 0.13654176465102605, 0.10034784501684563, 0.2489252941949027, 0.15638781471976212, 0.122535322659782, 0.13519886242491858, 0.12597556305783136, 0.13371824473142624, 0.09383815646703754, 0.17050135667834962, 0.15907406700508936, 0.10402747935482434, 0.15791955324155943, 0.18226746602782182, 0.10772232644792114, 0.2676991910806724, 0.0776449657444443, 0.11537947878241539, 0.08878306379275662, 0.18270003210221017, 0.06831080732601029, 0.20856262503990106, 0.17270275498075144, 0.10439860408327409, 0.12682275474071503, 0.1054056721872517, 0.16252574750355311, 0.14946012145706586, 0.15280213712581567, 0.15549364127218723, 0.05780051023300205, 0.15106913154678686, 0.14321176388434, 0.23409800125019892, 0.129079792914646, 0.15337631345859595, 0.05384506158796804, 0.15388817313526357, 0.17195621718253407, 0.16160786604242666, 0.07794334473354475, 0.1063006395207984, 0.10321196168661118, 0.20432138762303761, 0.12159745155700616, 0.12578063351767405, 0.09303652841065611, 0.11338844669184514, 0.06980063952505589, 0.13715898724538939, 0.16823931091598102, 0.14758322574198246, 0.08811805876238005, 0.08815953760807003, 0.11819097506148474], [0.010997720179148018, 0.050127687132252116, 0.020880743029660413, 0.057751024674092016, 0.030922018058065857, 0.024648067840774144, 0.015200030890160372, 0.041251756982611756, 0.00577500942329477, 0.06339226303888218, 0.012924891098269393, 0.0682608467925872, 0.03936539909669331, 0.04022498422169259, 0.02614673286942499, 0.030112152586558034, 0.016946832782455852, 0.040028826533151526, 0.0369248816610447, 0.0671864612294095, 0.04342319457126515, 0.0295450262326215, 0.021710954373702407, 0.0628556843314852, 0.0751842584993158, 0.0055920933456426215, 0.014151696830854883, 0.03972762483837349, 0.047531167710466046, 0.027148559290383543, 0.04244347142853907, 0.01456820113318307, 0.015427043262336935, 0.06096141811992441, 0.035133647599390576, 0.040131305677017996, 0.06149512662419251, 0.02793170914186963, 0.01532272868124502, 0.020856234344786832, 0.04906058903517468, 0.02037286465721471, 0.05761270531054054, 0.041291529312729836, 0.04076259769499302, 0.04145700704040272, 0.054901092778891325, 0.04090367191072021, 0.03267931179808719, 0.013564733505648161, 0.02130472393972533, 0.02007470788833286, 0.023815864996452416, 0.06858990913523094, 0.03670404565387538, 0.009697457093612423, 0.041014015275452814, 0.029150166349219422, 0.04549782896148307, 0.05202245545972671, 0.053967635546411784, 0.02754542594110327, 0.1109515560258712, 0.04144861695489713, 0.030880389934671775, 0.04983910618882094, 0.09087959450802632, 0.008881914828504835, 0.015387401550209947, 0.04260636054511581, 0.0784274794693504, 0.0051661107572726905, 0.07708549326551811, 0.03203348556001272, 0.003387159451709262, 0.05381804910887565, 0.005075623871692057, 0.05305947409942746, 0.08272823797804968, 0.03682691816772733, 0.022869637734921913, 0.03603545456592526, 0.042174544251923046, 0.006471169813136969, 0.03794403786637953, 0.04456246843827622, 0.03326308600870626, 0.048669986959014616, 0.042538839525410106, 0.0753005797575627, 0.03724842072863664, 0.0035017638043167865, 0.018546221245612417, 0.032582230400294065, 0.031217007764748166, 0.01786877527566893, 0.03945267227079187, 0.015249334940952914, 0.10526936807270561, 0.025355264178610275, 0.06330647585647446, 0.009689358778164854, 0.024594504286402037, 0.04334867785551718, 0.011805999575049748, 0.03985544387251139, 0.005905079497357032, 0.057420761324465275, 0.008992380329540797, 0.0600885913840362, 0.039913356836353026, 0.005750120758810746, 0.0354970539920032, 0.08701784815639257, 0.049167085106351545, 0.06925741117447615, 0.038437200510608296, 0.03338358364999294, 0.02444293991928654, 0.03686229359092457, 0.014760967842968447, 0.0012140397323361996, 0.060676372343940396, 0.020900766598060727, 0.03670133151380079, 0.04739452093573553, 0.006639691194452877, 0.03579647113968219, 0.021238122334969894, 0.023401992561827813, 0.003561851684935391, 0.020348849606567194, 0.04500173504597374, 0.025551023227827888, 0.03432615700044802, 0.03699128309796963, 0.043087323129709275, 0.04894686317337411, 0.023007205620940243, 0.05620670611304896, 0.06888011177735669, 0.03464207272710545, 0.0684292863256165, 0.03249238557847483, 0.04698124221925225, 0.013037621209930097, 0.03876745368220976, 0.02568640623108617, 0.038339603426201005, 0.07479169206427676, 0.008353839013060289, 0.13823910642947468, 0.05034530009808285, 0.021937401865475943, 0.011813527921081653, 0.0720057561993599, 0.027794078491362076, 0.03276222877736602, 0.01860450061836413, 0.02303456754556724, 0.05804319506777184, 0.03233893827668258, 0.029481396611247743, 0.014053809672727116, 0.03654217773250171, 0.004022876366174647, 0.023039977166003416, 0.09021971241704055, 0.02917615424043366, 0.020219281648418734, 0.028889978703643595, 0.021771013204540526, 0.009921518686626638, 0.042988569143095186, 0.020543712989560196, 0.08191831143839018, 0.05073729995638132, 0.03302547322320087, 0.05929418972560337, 0.032035273499786854, 0.03659011962424431, 0.055953168110655885, 0.026004954673615948, 0.02494787853876395, 0.035014232221458635, 0.008188341777505619, 0.06856181100010872, 0.09249425000910248, 0.05544633637847645, 0.01454033369996718, 0.02244657793614481, 0.04195268704955067, 0.01129280827340803, 0.005611381975800863, 0.01701911711799247, 0.022460046856264983, 0.07373887712934188, 0.013607370949882482, 0.011717039393261075, 0.014719967364466615, 0.050088081043213606, 0.06774539088032075, 0.019174078180055534, 0.03785125159525445, 0.08609996669526611, 0.017627145562853132, 0.06618367468139955, 0.013823024645846869, 0.015457394133721079, 0.058965168095060756, 0.01071775408594736, 0.05290303445820298, 0.03415659449196287, 0.06370290315576962, 0.012026369937562516, 0.03721448040700384, 0.05658452798213277, 0.02559126544344638, 0.06420984345355205, 0.005145268281921744, 0.044744404032826424, 0.012857683052841042, 0.06820366664656571, 0.04660810902714729, 0.022010924527421594, 0.0627512102946639, 0.06104471507881369, 0.0392030460227813, 0.06227335200778075, 0.06164241622069052, 0.036255201524389644, 0.03230083514271038, 0.0176714657739337, 0.021352209516667893, 0.04416421248710581, 0.047899924351700714, 0.0203285648021847, 0.01575741857024176, 0.08764210715889931, 0.045208240393549204, 0.024110954787049974, 0.08104475188468184, 0.027210602836151208, 0.03965151695800679, 0.03997646737843752, 0.0346757823468319, 0.09524783332433019, 0.016134170050333654, 0.06130346762282508, 0.008614778136169272, 0.02371311783125358, 0.021870623841615658, 0.0179573478443282, 0.07043994843427624, 0.019649731228128076, 0.047842757776379585, 0.042216691454606395, 0.05152728095916765, 0.04471040264304195, 0.04090879485011101, 0.005998953120849494, 0.05748771237475531, 0.02647821418941021, 0.018837255093136003, 0.07135345334453241, 0.023089701908507516, 0.048940800462982485, 0.036397042484687905, 0.06109012942761183, 0.03073667621772204, 0.07507544183837515, 0.06414205101983887, 0.04411561580907021, 0.038372454699128866, 0.029183353496981517, 0.03512036527640053, 0.057669661540005884, 0.04097281802179558, 0.0072646020146618995, 0.05389997881970235, 0.034833538345992565, 0.01809948736003467, 0.031091634849352495, 0.034436822669314485, 0.05509644979611039, 0.0568670597858727, 0.014935924704851848, 0.008123654489671546, 0.014472453056701591, 0.026563282124698162, 0.0393744405758168, 0.03900829290172883, 0.027249532086508613, 0.022180571852784072, 0.01797228748910129, 0.041004251156534464, 0.13091559654900006, 0.017003164759704044, 0.07808335364929267, 0.029091150765972476, 0.06362935674509831, 0.01479211768933705, 0.019419675626392876, 0.031112645686204945, 0.01733324320853821, 0.026661973346823027, 0.012189923170288759, 0.01708934209974749, 0.02969615294464997, 0.020914147308628474, 0.016850290820002556, 0.0432946495046573, 0.061613788828253746, 0.025046725823943104, 0.03213873991210546, 0.012079571323868419, 0.03953417789723192, 0.019854993160281862, 0.04770126286894083, 0.03406200331768819, 0.04618184993575726, 0.04760138251419578, 0.02730124832929245, 0.04433540008696062, 0.038401892940912924, 0.03264082868450454, 0.08509150080915008, 0.04052475081490619, 0.07134529735360827, 0.041842370826218805, 0.014030055858061781, 0.040788307386849604, 0.041609612958771844, 0.029696214012801647, 0.04264395138514893, 0.015968398856265203, 0.08351025637239218, 0.023419614116262113, 0.02995385036670736, 0.05328340083360672, 0.04318675904401711, 0.03855331142299941, 0.046781362766133885, 0.05705795543534415, 0.022684358659067323, 0.04587830729516489, 0.058539136312901974, 0.04877536005473562, 0.03653889362301145, 0.033890954817512205, 0.01873225179900016, 0.0225729957954692, 0.1590715699962207, 0.0945405148501907, 0.15427506023219653, 0.1523745379277638, 0.11869921136115279, 0.11182360923183815, 0.07327219431421586, 0.11990589089691639, 0.19439736514219216, 0.13111705359603676, 0.11661053129604884, 0.316658261099032, 0.17116765092526162, 0.12706712234233106, 0.10592774381594998, 0.10917321073689631, 0.1522398894386632, 0.09678381268999406, 0.14002023371202604, 0.12627106505845273, 0.13742383303386824, 0.11715874687901565, 0.16621083047773155, 0.14832867788416998, 0.18244133384100028, 0.10746774689427444, 0.09631187801382371, 0.1251635602010148, 0.11773187826786723, 0.09867740715188639, 0.24190785789063998, 0.15650400705635548, 0.05020457532789026, 0.09671951471162693, 0.11454406646745545, 0.12480940563338143, 0.08425815124064684, 0.1222352609038353, 0.0680770112999848, 0.15130667308611528, 0.20833611647997582, 0.20655926396804197, 0.15377014875411987, 0.13588765689304896, 0.18398880080452987, 0.1339767122907298, 0.09779425989836454, 0.07402566674032382, 0.17017401781465324, 0.14218262982155594, 0.1924521138093301, 0.14739824352519854, 0.10245081502944231, 0.1414787040225097, 0.22866081872156688, 0.06813861549432788, 0.14292196157787526, 0.1881791345242943, 0.0862031379448516, 0.16440431241478237, 0.11571128240653447, 0.05612132265897734, 0.239760267415217, 0.1808533990489585, 0.09392192161508969, 0.21726993923740728, 0.17570076696574688, 0.19323028491011687, 0.16866813147706644, 0.07535030958907944, 0.24278365660990986, 0.08737344121826546, 0.19455992856195994, 0.20994452945888042, 0.08990088916782822, 0.13191961124539375, 0.09051207958587579, 0.269021140145404, 0.13159011464033807, 0.10664772375353745, 0.10380126256495714, 0.15152383143348352, 0.11534172509397779, 0.12664060880030903, 0.07284830670271601, 0.13377726370734827, 0.15569638753575937, 0.10326648876070976, 0.15615865987326416, 0.09705641413373606, 0.12120918024863515, 0.07965317155633654, 0.08279868348368577, 0.09308994268732411, 0.15208755832697662, 0.18814537062176637, 0.19837991786854609, 0.15411177756530897, 0.24946358959589685, 0.19671108813158103, 0.12825181734349045, 0.11742592682795865, 0.10907384606876544, 0.11025034436689955, 0.172021125842418, 0.12931740230747632, 0.1332307851740292, 0.1478234814213855, 0.18661394422607763, 0.15268595835992269, 0.10172998692308154, 0.07708713532026325, 0.11597642675042152, 0.21693342658025877, 0.14850927676473344, 0.10453186157558646, 0.15719304579709256, 0.23426595223801477, 0.05784182623028755, 0.19166947794812067, 0.18600742891430855, 0.13501750358513423, 0.18544393272272178, 0.08214720844158105, 0.18231841043702193, 0.1493950363780771, 0.10454386486006634, 0.09541263590965952, 0.2366845224584852, 0.12836175358721189, 0.050618753103273254, 0.0901168736496142, 0.10799378116748162, 0.17913025936910085, 0.11722391338220664, 0.09319759905338287, 0.15158280969730445, 0.09409665116774184, 0.0962167474042092, 0.21451210150761263, 0.15553305058607034, 0.10606176805283342, 0.14912639079349382, 0.16118321168635572, 0.10329817634608064, 0.1446045520050185, 0.16968959809413978, 0.15804631715374334, 0.15267419256269932, 0.1781235576740333, 0.15502846480480262, 0.28109119247112957, 0.189321706071496, 0.09287047732089247, 0.10376284391220127, 0.16534301133028098, 0.09360726457089186, 0.1196579270597015, 0.12954110173242434, 0.15598716693265097, 0.23998459109238215, 0.15481191713895115, 0.10612979118845292, 0.14579809510282107, 0.15322187888835156, 0.10738324214305196, 0.13232932426035404, 0.18979328790945665, 0.10492026859096118, 0.1339385107691799, 0.16924521193972655, 0.13661305154008524, 0.10416606334703309, 0.0935387664607593, 0.1136881352535316, 0.20441395337028162], [0.03332658331575138, 0.0602809696325234, 0.0271305323112756, 0.016634196076276045, 0.05956829073173659, 0.003485235751473478, 0.0415073679094868, 0.01579132496512362, 0.05713583089943443, 0.04538775022540774, 0.014936934025692088, 0.053293775634041855, 0.012600532699642437, 0.03494229054610644, 0.04891154542565346, 0.06575463020375796, 0.022297271394303868, 0.005430703367372709, 0.016863259320546473, 0.01936109769823296, 0.015755832494635667, 0.046587440850479264, 0.03863805026880332, 0.04712566500529647, 0.0074443824123591185, 0.025794032063069086, 0.015763674663113694, 0.07407446019351482, 0.03742748951273305, 0.02457654007178332, 0.015573038553286876, 0.03805923954184566, 0.03845294252304094, 0.01674683458570923, 0.03991069358640483, 0.020484953553282788, 0.05839891026594809, 0.0363075335377029, 0.06012537476739713, 0.023341316264122725, 0.03819521456690771, 0.04842869312103305, 0.005437422984479261, 0.05507628034268107, 0.0664157404431275, 0.0058009014714376205, 0.04699269928304212, 0.03145609636391912, 0.020571744967518107, 0.025732419387038265, 0.040918145062667985, 0.15001194684633187, 0.08531532915575163, 0.0031983093732768403, 0.011986994550430348, 0.01627224514127842, 0.031100330275616477, 0.03619028947183064, 0.02064505558727043, 0.0028784761670976877, 0.012457511088411723, 0.0525867421446102, 0.04418501297810248, 0.012403240161282676, 0.0821134920365044, 0.04460491419636777, 0.06523785114820514, 0.033165081803287776, 0.01420129434804299, 0.03330844607470291, 0.04054670820810965, 0.03852813098845737, 0.02590354422240385, 0.03290409009371485, 0.08761475541229759, 0.04651385372770684, 0.03822704464463251, 0.04883780563250184, 0.0343366573298616, 0.04638970217534474, 0.03450165669034634, 0.040387466217258146, 0.02530833669672055, 0.040070916060358286, 0.08286011125892401, 0.06380024578954492, 0.0075497427855485254, 0.027637150304924165, 0.024228051271555678, 0.011603759668235267, 0.024710491366152252, 0.07145690957882575, 0.05196824390441179, 0.050718239907707484, 0.04385805070134146, 0.055925572091447454, 0.035468195897660086, 0.020361774002334902, 0.013364167035823422, 0.03312608300309096, 0.016610620377053107, 0.03540460020303726, 0.04888022764186774, 0.013081880352858986, 0.036108346190303564, 0.009736131893337836, 0.03703821057985936, 0.012446501009565378, 0.04913287337071129, 0.04480030174766268, 0.06376534194818564, 0.042024489625224044, 0.05060101280521069, 0.01722506945952773, 0.03272230716954384, 0.04932497002716575, 0.045535287487187555, 0.006792305170425347, 0.022640102908813527, 0.029351172170468738, 0.03432553614090596, 0.0036194177477487494, 0.05436591524630785, 0.04246203614664929, 0.02797798523014145, 0.012134110272329832, 0.02860633410247309, 0.01957251224666834, 0.04560684918292931, 0.036153397522866726, 0.05187970865517855, 0.030756876205227206, 0.052439001322324784, 0.017533997971830622, 0.10736433137208223, 0.034556251617946794, 0.04244581237435341, 0.029708495496639183, 0.06364321243017912, 0.03132035204076341, 0.05049460833626134, 0.01048407341087503, 0.05390418912949307, 0.05897632321076734, 0.03274631034582853, 0.01355894305743277, 0.01276698921407972, 0.04147872355367456, 0.05943932158074208, 0.03596215921321085, 0.015305817892242755, 0.049237330444157124, 0.0028884131004036006, 0.04028692429086991, 0.04926830217508333, 0.010917751434525209, 0.04037563595920801, 0.0033822464340898606, 0.02566323595653687, 0.027448191872930953, 0.0420479058687176, 0.07070884507681642, 0.016649157773437243, 0.039483555792165656, 0.0303135349947427, 0.03286536270752549, 0.04900047083252242, 0.01526049175299704, 0.024194397630968263, 0.07042809442750045, 0.04120222053357533, 0.12029614352754184, 0.08490576541849545, 0.05532789469829627, 0.044213036474372656, 0.03214174921491316, 0.016789821475478153, 0.007133381823743028, 0.023294768761843443, 0.020589361432939768, 0.035473803989589214, 0.04574985383078456, 0.03493431097428713, 0.04007688716852239, 0.0629903803180371, 0.046739605721086264, 0.030879772467804805, 0.052157582316015444, 0.01579421043529042, 0.015366984431498816, 0.04915260856172868, 0.017359616168375527, 0.03455376139442835, 0.05844545776822737, 0.031582700820373635, 0.02193819235877267, 0.04235828474962285, 0.07668162922241858, 0.0044651505803423265, 0.013654265353190047, 0.0574321946395295, 0.006246872853288161, 0.02189239294135145, 0.01237542022551809, 0.029409821344805614, 0.01958544342778623, 0.021019929221698215, 0.019253217415618043, 0.05852371321192809, 0.03660022979602218, 0.032668882714850564, 0.06343541108071804, 0.01607399756487991, 0.014491502927350146, 0.04108189591871841, 0.022064988501369953, 0.03336717328056693, 0.01438775153032371, 0.0448058657348156, 0.038587604582841904, 0.06378185749053955, 0.018800398767260567, 0.010910966084338725, 0.02409760291422052, 0.06983889532940728, 0.00898417005581515, 0.04162387576486383, 0.0396850976560797, 0.07846456819346972, 0.04469254020867603, 0.01951493855033602, 0.019500879304749624, 0.04025072444762502, 0.0025172977018103537, 0.04137389328596847, 0.07439917312668902, 0.04784804017149976, 0.04385677844818149, 0.05184572083609445, 0.03376825533009001, 0.06434668361076287, 0.03502844753009932, 0.040197506946112425, 0.05242462316527963, 0.013130063124533211, 0.023332325675125633, 0.01736104957360242, 0.0541948972802077, 0.0488589080715818, 0.012164912369501377, 0.04635180599455323, 0.03624400569658194, 0.027559354568698576, 0.017381283487858515, 0.013915231617699777, 0.04056972072326711, 0.05098513826461775, 0.07828916010579892, 0.017654690691935163, 0.026595497271046042, 0.026911704767761484, 0.013187777616881897, 0.058798438470278463, 0.012083213360581015, 0.03535009687766433, 0.008917392031954867, 0.029937484102057557, 0.08378039473401648, 0.028421282335849743, 0.046497212656374486, 0.057181767720196924, 0.005846457464420902, 0.06656918435224465, 0.017513375596276352, 0.02948137964787228, 0.022184454769428288, 0.03302320691623858, 0.027919731302452937, 0.03364136588892766, 0.04599806533328124, 0.04600876583052533, 0.015665896070588912, 0.038012071180024316, 0.03429723105260304, 0.06582443788647652, 0.0412679027233805, 0.040896811921681674, 0.042404014617204666, 0.02437074888231499, 0.0306278561641063, 0.012948580452107956, 0.01979011673081134, 0.06575574300118855, 0.005841449027814503, 0.018240564968436956, 0.03367962847862925, 0.017997096425720623, 0.02612756934416081, 0.037063689569809606, 0.033835376014134715, 0.0364385111523526, 0.07394983366663967, 0.06520342228135892, 0.043064727913588285, 0.055796104217214246, 0.013834032180186893, 0.0372968342022172, 0.05381616956687399, 0.03733204338433487, 0.05682472598605922, 0.015589669446593948, 0.07092705515346356, 0.004552080246087695, 0.05336715919630868, 0.04312667476811579, 0.0035916546392919762, 0.058803364634513855, 0.052250599289046865, 0.01920403041211622, 0.08914928271302155, 0.07801254173474652, 0.01661265258943396, 0.047439304246966324, 0.007119469311354416, 0.040750007477722, 0.11282887243266616, 0.030576073764158145, 0.03497356761779104, 0.03284880645307047, 0.02008838715430881, 0.05087104599390711, 0.004531926059696291, 0.04164672203894172, 0.05047532437103135, 0.03113923068823559, 0.01170631853996643, 0.016243448115086982, 0.038718375244310925, 0.02918812699083771, 0.0287597474775144, 0.0445406908568527, 0.04188724234700203, 0.011749024685871388, 0.03687140292354992, 0.008903167393457676, 0.01615207828581333, 0.0439624026018594, 0.0695051307390843, 0.04258986196613737, 0.0411734201147088, 0.02760290803520807, 0.02472007567329066, 0.10327332839369774, 0.14976554363965988, 0.11561754957905837, 0.13318184922848428, 0.07793778074639184, 0.13605909555086068, 0.24100402210439953, 0.1634599273758275, 0.1176176265414272, 0.09885546152612992, 0.0935650732634323, 0.1406888621194022, 0.06297307088971138, 0.08848772464053971, 0.10275235599172966, 0.1625628633690732, 0.13321159620370182, 0.148003863170743, 0.09528831472354275, 0.10880159746323313, 0.138485848903656, 0.19072189022387775, 0.1361556646547147, 0.11071895422147852, 0.15862867661884852, 0.0894491680498634, 0.11396569678825991, 0.12185750688825335, 0.11813768292112009, 0.10415388364344835, 0.19255626893469266, 0.061877677882356305, 0.1588126817452056, 0.09188668975340468, 0.10263306275010109, 0.1895227831389223, 0.09829959885350295, 0.10065421714846577, 0.09415900175060544, 0.1392067109367677, 0.10450878459960222, 0.07839200565857546, 0.11912378429302148, 0.19870858666087898, 0.21253860954727444, 0.09057027074907507, 0.12817420650805744, 0.12337658394660268, 0.13104066412363732, 0.07404698631060974, 0.14495625027588435, 0.1480346279484885, 0.14877556104745182, 0.1141501497477293, 0.10107652377337217, 0.08127443598849432, 0.12944538758269378, 0.10618073559765305, 0.07602655794471502, 0.13274591762040341, 0.14498126107667172, 0.15500467536704882, 0.11935530044138432, 0.14960737712681293, 0.18653771760208265, 0.11389941748763834, 0.12658606815551007, 0.11529401051146643, 0.07657753516520772, 0.0858656210558755, 0.15017655944185598, 0.1511793527752161, 0.11339446529746056, 0.10519612021744251, 0.139542816472905, 0.1572154238820076, 0.08690777620566742, 0.09300170599349908, 0.0981315460854343, 0.12601235322654247, 0.07569299691489764, 0.14766657698367322, 0.06617147462176425, 0.15320920385420322, 0.20093693637422153, 0.11456952510135514, 0.09406918407018695, 0.21563211855079445, 0.1298855668199914, 0.10989500914833375, 0.08473903579371315, 0.2132892592677048, 0.1580490991473198, 0.11233569282506194, 0.18697006654526505, 0.08667426516434976, 0.11406411150736467, 0.0675722151728613, 0.0990486065191882, 0.12173649695302759, 0.10640298974301134, 0.10085236972996167, 0.13134738909346716, 0.07399313777152981, 0.17957609758845397, 0.09496208187192678, 0.15854897589555808, 0.12885565922728606, 0.1680287750703948, 0.1532442569732666, 0.0992997730416911, 0.15015050369713986, 0.23517524344580515, 0.09268995986453124, 0.09583387723458664, 0.07950968175594296, 0.14434187752859934, 0.16673677654138633, 0.11953470510031496, 0.0789246420775141, 0.12320616309131895, 0.09843514979417835, 0.09442314864801508, 0.11051726647253547, 0.11984890752605029, 0.18158172496727534, 0.2518296412059239, 0.09218430199793406, 0.16790811797337873, 0.12634023491825375, 0.16461463112916264, 0.1295598428696394, 0.1130922186587538, 0.1694411864238126, 0.15924888476729393, 0.16698608387793812, 0.13625570785786423, 0.13382001141352312, 0.19403886795043945, 0.09849566154714141, 0.070990199622299, 0.10182452720722981, 0.2223711519369057, 0.19834577398640768, 0.1874261506433998, 0.13420168736151286, 0.1223594599536487, 0.10306546597608499, 0.14479173267526285, 0.19384715466627053, 0.10420820037169115, 0.13685864050473484, 0.14112600151981625, 0.13361129404178687, 0.11485526976840836, 0.05130697420931288, 0.13524212581770761, 0.08581500912883452, 0.08560671923416001, 0.09882862546614238, 0.09896134013043982, 0.17996432818472385, 0.12479640490242414, 0.11933721069778715, 0.09782760989453111, 0.15800377300807408, 0.10993791970291308, 0.11865783429571561, 0.11497929239911692, 0.10110057105443307, 0.0833488464621561, 0.21920528395899705, 0.11457563191652298, 0.13455873248832567, 0.0822586781744446, 0.08438209923250334], [0.031060574908873866, 0.026075878546440175, 0.06560624816587993, 0.025024807446503212, 0.048880315851420164, 0.0471773591956922, 0.024839545334024087, 0.0481682645955256, 0.011904116586915084, 0.05494361656851002, 0.04806138175938811, 0.04956421808206609, 0.062136606845472536, 0.015711300241361772, 0.008891238747829837, 0.05708345478134496, 0.02886479826910155, 0.051193638505148034, 0.005905743613506534, 0.031962517582412274, 0.022788026935553977, 0.03306504538548844, 0.0168655052714582, 0.05144252175731318, 0.013893643177912703, 0.02525970439559647, 0.02135604663219835, 0.008632552360982766, 0.03005299111828208, 0.030989583182547773, 0.056209260797394175, 0.03373093929673944, 0.0731196121445724, 0.01483446336351335, 0.08669523868177618, 0.01357088188108589, 0.041703450959175825, 0.02675770445992904, 0.03525495609002454, 0.04109857430947678, 0.05033917631953955, 0.051006227132997344, 0.03129763129566397, 0.014147369473773454, 0.01978749080028917, 0.06994894692408186, 0.04784983828929918, 0.04905928285526378, 0.00638697252309482, 0.028086101303675344, 0.025849744877112762, 0.01949089635828776, 0.0725625077528613, 0.03031886488731418, 0.03274784044229558, 0.056191391577678065, 0.05057718604803085, 0.03305304210100855, 0.021458357838647704, 0.011815607630913811, 0.018980714359453747, 0.02891363582706877, 0.03085902625960963, 0.03097112363736544, 0.08434243207531315, 0.036241708855543814, 0.05295912216284445, 0.01952365263631301, 0.017924857891297767, 0.029134013823100498, 0.04002644148256097, 0.061084585796509466, 0.10559257465813841, 0.03830293878646834, 0.048067061097494194, 0.032439660014850755, 0.03497288908277239, 0.043881653541965146, 0.07115251198410988, 0.016124327899888158, 0.03545800769435508, 0.04903384457741465, 0.06353620067238808, 0.03504524466448596, 0.02410834581990327, 0.03789814854306834, 0.020239035499149134, 0.051114321154143126, 0.0023839057747474207, 0.03850554255768657, 0.04315011815301009, 0.06061284789549453, 0.045255256084991355, 0.012412080624406891, 0.017053491702037196, 0.024409150571695397, 0.03138760843181184, 0.006098791491240263, 0.07336326728441886, 0.002401587973249012, 0.028637641708233526, 0.07605030667036772, 0.027088700627375926, 0.024211958117250885, 0.04240224703348108, 0.03815618183995996, 0.08251874707639217, 0.014431084472952145, 0.022690930270722935, 0.008946992273974632, 0.04668696836701461, 0.054435648290174346, 0.0009606567327864468, 0.043489501013287475, 0.02051219673428152, 0.04504630461867366, 0.04268173560766237, 0.04687401672293033, 0.06688208399074418, 0.047899591869541576, 0.0118698200343975, 0.043932106013276746, 0.020384903564783077, 0.02971113160518663, 0.02939271547698549, 0.0022255747171584517, 0.04819087677502206, 0.02197798334860376, 0.05336324744192617, 0.04756072808855346, 0.015780210561518158, 0.046491506176867654, 0.0330319328765784, 0.05118575392823134, 0.002620125018958268, 0.006681779025322092, 0.021771194712658013, 0.002496637582745669, 0.045155294306044064, 0.013120518681327147, 0.03823276808751481, 0.08688530312584979, 0.04534583033195563, 0.057817846802728515, 0.031026268178331, 0.05876466099705015, 0.032251030672341585, 0.04657303215935826, 0.020051776797377636, 0.03246624840955649, 0.0328208304542516, 0.05901081993111542, 0.05252462565632803, 0.020610594490010823, 0.07550208430205073, 0.023519431706517935, 0.006830193717697901, 0.03316457968737398, 0.024239253884713565, 0.03112158877775073, 0.010185843699478676, 0.023514089939583625, 0.03545776002907327, 0.004600157420749643, 0.03994876618630119, 0.008357273248423423, 0.03175695539851274, 0.0402779438798981, 0.07343358386840139, 0.05184923904016614, 0.029419331013091972, 0.017619671499622718, 0.032126868941954205, 0.007535070313939026, 0.01867978577502072, 0.02736211461680276, 0.033247133650417836, 0.028573839060430015, 0.01539925386064819, 0.05173952332032578, 0.04987723985686898, 0.027430052935544933, 0.04495915697355356, 0.03382286382839084, 0.04236764514020511, 0.09398608388645308, 0.0432243159572993, 0.03164109215140343, 0.017159611186278716, 0.025554704280304055, 0.024884829064831138, 0.01682138692454568, 0.022499827668070793, 0.07775323279201984, 0.04236455780587026, 0.011841233354061842, 0.02337834731276546, 0.03777952705110822, 0.02998060839516776, 0.062386877701750824, 0.024041603419131467, 0.03133900836110115, 0.02277455462275871, 0.016427315838102783, 0.022259475297427604, 0.04440578452444502, 0.042152749707124064, 0.06935710153941597, 0.04756219372419374, 0.06899696229291813, 0.05194824069206204, 0.013788954554391759, 0.061792908502476554, 0.014787773368880153, 0.02860746386327914, 0.019250411673315933, 0.03395685413852334, 0.08239882958254643, 0.040967868108834536, 0.021627296094915698, 0.019259376817249825, 0.04699757455715111, 0.012109455702427243, 0.033054745223905356, 0.006410780196477259, 0.040554616533751996, 0.05008752464449831, 0.010232843275714134, 0.030628073295312266, 0.08297384729874985, 0.015792539542807, 0.017579863546416163, 0.02853088779374957, 0.061366605306310315, 0.023877867830118964, 0.015906898138512458, 0.056172195822000504, 0.06481958859200988, 0.035974101429539065, 0.04553546051361731, 0.06427747303886072, 0.013088237377814949, 0.011921716937130051, 0.02218379150144756, 0.019073446347777332, 0.014480807519118701, 0.07898551345403705, 0.054535060455756526, 0.023145945676203285, 0.013392668051112975, 0.020557514391839504, 0.012113163896304156, 0.02086346922442317, 0.02780977131000587, 0.029506315809807608, 0.0240564209276012, 0.047626814006694725, 0.05333552589373929, 0.02076718340893941, 0.01675173021586878, 0.02142395102418959, 0.02808262381170477, 0.024212572191442763, 0.053552521392703056, 0.030350583006760905, 0.027174436919657246, 0.09157338977924415, 0.04833250738946455, 0.03719921676175935, 0.01746928269442703, 0.022594839534057037, 0.0606248104678733, 0.07665969897061586, 0.012322145896697683, 0.013087068601245326, 0.05646711088983076, 0.03868526952075107, 0.10486958202506814, 0.037598429447306056, 0.043357050977647305, 0.005753430313364203, 0.07397043398980584, 0.01867887144908309, 0.03738263834800039, 0.04625329628054585, 0.04240938522187727, 0.07574394132409777, 0.02170273901096412, 0.04700092652014323, 0.029443622566759586, 0.044882150034287145, 0.057229943706520965, 0.041695742801363976, 0.007864943505930049, 0.008933741333229201, 0.016953825085823025, 0.10755267233720847, 0.0721484317577311, 0.023471659448529993, 0.019869805579738956, 0.016922407218122056, 0.021781706916434423, 0.03471230449421065, 0.02607464530904378, 0.016720475196572285, 0.01714168768376112, 0.009130962625412005, 0.046609031834772656, 0.04597148711660078, 0.015510640472971966, 0.012689101875626614, 0.04593574867716857, 0.026040413217352967, 0.012747050462556737, 0.0636812239619238, 0.035635661732937605, 0.019999361663524593, 0.05966323135154588, 0.014067177660763264, 0.08074583685291664, 0.018748506105371883, 0.04125310726729887, 0.04756229550444654, 0.026916072836944034, 0.057084730427180014, 0.06500128669930355, 0.015613262109192354, 0.026747195648827722, 0.007080372123579893, 0.03561868139409593, 0.06647695108715977, 0.0066140548691951805, 0.03723769308999181, 0.05076374925140824, 0.01219864743429103, 0.03673222182052476, 0.03158623938049589, 0.03129638957657984, 0.05090084046657596, 0.07190003365810428, 0.008744950838653105, 0.030362908595374653, 0.056540382493819506, 0.04972062040386455, 0.09000380935945682, 0.06685412834797587, 0.054184278207165856, 0.030656985672456876, 0.05373998026230505, 0.041773753972457986, 0.0074238728432516965, 0.020117608264886906, 0.13065225710826261, 0.08466578793845006, 0.13119764998555183, 0.14691728433328016, 0.11896134300955705, 0.20850891220782483, 0.11930787084358078, 0.14481959332312855, 0.13403474060552462, 0.1312637392963682, 0.1257932406983205, 0.09464918223342725, 0.08122265019587108, 0.1365059922848429, 0.12140866954411779, 0.159359390980431, 0.1088434291471328, 0.1587748737739665, 0.1064686719328165, 0.1522726355386632, 0.12688792124390602, 0.15393526346555778, 0.08411262583519731, 0.1384867445698806, 0.15703357649700983, 0.14063132234982081, 0.1365321430244616, 0.15790423192083836, 0.1479380859860352, 0.11678715396140303, 0.15934416465461254, 0.12347453726189477, 0.18213612878961222, 0.20746527106634208, 0.16146103106439114, 0.12401132631514754, 0.22002861835062504, 0.21196569528962883, 0.13865184571061814, 0.09424951832209315, 0.1422205599290984, 0.1076942825956004, 0.11925552865224225, 0.10842869497303452, 0.08734693085508687, 0.09809812145041567, 0.2280008484210287, 0.13818702208144323, 0.16748735840831483, 0.14336215438587324, 0.08950613785002913, 0.08341602821435247, 0.1725927373128278, 0.12436942995658942, 0.07355259212532214, 0.15032305515238217, 0.1410904327141387, 0.1398926962699209, 0.079389974607953, 0.18319062649139337, 0.12541651805596693, 0.12192872592381068, 0.1437606444316251, 0.14479048417082854, 0.15119077930493013, 0.09666751178779773, 0.1019267485077892, 0.11535326018929482, 0.08976201340556145, 0.0859439918505294, 0.1679491964834077, 0.15651246160268784, 0.21213432481246336, 0.1677056159824133, 0.11768294232232229, 0.07650482335260936, 0.1042310195043683, 0.07296685355582408, 0.20285070368221828, 0.13994372210332326, 0.1539048379553216, 0.14628854021430016, 0.15052122808992863, 0.05196284615833845, 0.20333326421678066, 0.11257564994905676, 0.2167938926390239, 0.24574027795876774, 0.1027078101677554, 0.12151099262492997, 0.21259483295891965, 0.16926011256873608, 0.16671587766281196, 0.11927281772451741, 0.05236491886898875, 0.11604247534913675, 0.12993638909288815, 0.10656387718128306, 0.10212025990975754, 0.16948493836181505, 0.08567326316343886, 0.17581518154059136, 0.10395458433777094, 0.10233111466680254, 0.1605923298214163, 0.12083704450300761, 0.13409822434186935, 0.0946952411904931, 0.08671302308461495, 0.1021778607474906, 0.1839598680713347, 0.20466250074761255, 0.09737570557211127, 0.23078683178339685, 0.10337764636746474, 0.17624155937560967, 0.09475225170275994, 0.1436235803578581, 0.13794684782624245, 0.226079115111913, 0.366184233554772, 0.1203306538185903, 0.11874508032841341, 0.07420241154198136, 0.1050426559522748, 0.05211299577994006, 0.12619067222944327, 0.0893757234194449, 0.15353685484400817, 0.17364646148468765, 0.06363344152591058, 0.2007154489734343, 0.08493401283132178, 0.14083052666059562, 0.1182152937565531, 0.12323760640408311, 0.09958561948899712, 0.05838737517063107, 0.142405311443976, 0.08898762853017875, 0.08456598900790725, 0.15939405054918357, 0.10741211380809546, 0.1424441643591438, 0.04298442329413124, 0.1450669736202274, 0.20750668884388038, 0.0996581209557397, 0.12581175113362925, 0.13305485461439404, 0.08757658781749861, 0.12892193852790765, 0.08514276412980896, 0.06671982591173478, 0.29232121844376835, 0.09433255065232515, 0.10100445656904153, 0.1448704291667257, 0.11344114850674357, 0.10472149854259831, 0.10884405339934997, 0.1510085655110223, 0.08309104386717081, 0.14049476039196762, 0.12320175261369773, 0.07455852029046842, 0.19409362572644437, 0.17329835944942065, 0.21000824389713152, 0.10980323050171137, 0.1379981315029519, 0.09543180452393633, 0.11938887435410704, 0.12070038755025182, 0.12215538376144, 0.1468451153486967], [0.023352576552757194, 0.04052829276770353, 0.03022186830639839, 0.09319700194256646, 0.07235713555876698, 0.03892420884221792, 0.038417594241244454, 0.07672903846417155, 0.0695456460650478, 0.025733443974916424, 0.065639543879245, 0.0587289904111198, 0.03237624413200787, 0.03703133023477026, 0.052252828276583126, 0.035971519603793106, 0.05686569932316031, 0.039351716438042264, 0.04234949093578117, 0.033355095357234986, 0.1366028328027044, 0.09732162633112498, 0.00904248420348657, 0.016751706467143128, 0.042717962592308006, 0.055051198295716725, 0.04691952606663108, 0.02474199913974319, 0.0056407591494332466, 0.07261013412582022, 0.005245420898843024, 0.013217361743694969, 0.06471981680286781, 0.02724378489490066, 0.009421814964818103, 0.02507525822147727, 0.04489098456022995, 0.0066677384394487095, 0.042658061520861726, 0.007956943524602269, 0.0038142739213071764, 0.052963210336331806, 0.019583362021616528, 0.08148414402135781, 0.041760827880352736, 0.0365498146441366, 0.01656277008753802, 0.06264435459992715, 0.03350128572700279, 0.04230773728340864, 0.035805509226130586, 0.03310033259913325, 0.04393592616543174, 0.07876673340797424, 0.04763072236840214, 0.021237715213958706, 0.05601991220776524, 0.013753384900545436, 0.02474374127840357, 0.04896875949842589, 0.032824284197496514, 0.03264070315552609, 0.0766154991995011, 0.008380478297892426, 0.03652332124433347, 0.05044631699898413, 0.004533409930965198, 0.023399773752316833, 0.02833217372452574, 0.033124749681779316, 0.030384133170757974, 0.06340737401374749, 0.02674345183186233, 0.01664130712327148, 0.06313289981335402, 0.06043809120144163, 0.006041789884745542, 0.009251793597026594, 0.030370280878352265, 0.01912195990527315, 0.04569773894867726, 0.04071541236979621, 0.022252893507746712, 0.04687633052734392, 0.0228311885480902, 0.07095446796821696, 0.045453554551516256, 0.04371220977710826, 0.05288939590432814, 0.042563178576529026, 0.056737072832350216, 0.03362262475171259, 0.0419583935290575, 0.024865784283195223, 0.06379630350108657, 0.049278113791452985, 0.02960741752758622, 0.06357842590659857, 0.039562479592859745, 0.0544138842794512, 0.05214182334020734, 0.024414451626528586, 0.03295302264658468, 0.06694358640483447, 0.026518855044352155, 0.023140493647328446, 0.041525993695748706, 0.021614945061238747, 0.025981540126459937, 0.006927594875118562, 0.06845582383019583, 0.011898838432638772, 0.031473300619316955, 0.029014927534652606, 0.03992362646386027, 0.022493250967402543, 0.028216663315626125, 0.025896326306142976, 0.015287356650722879, 0.024248537940106223, 0.03473811596632004, 0.022517014960093156, 0.07994200355772461, 0.024825340203408684, 0.041406557961766205, 0.006907262997369149, 0.01969725582083421, 0.034753019988004646, 0.021213371073827147, 0.007993085692370576, 0.043463085645011494, 0.037747768219560385, 0.01931052139428045, 0.0520382755036865, 0.02453440983247544, 0.10225665223385606, 0.04219092747994831, 0.037982663472316096, 0.007364208410893167, 0.03956336508105908, 0.028367167471774986, 0.05489334051630326, 0.06444291344710759, 0.04668690390618784, 0.07445327950907604, 0.010340735432691872, 0.013300559466837772, 0.025287624415276305, 0.040648793801665306, 0.027461638740663017, 0.05501644712473665, 0.06426270811685494, 0.016572493494355252, 0.028895315381565263, 0.018431564094498754, 0.05960235318967274, 0.08981450487460409, 0.03157926743317928, 0.034390858707151244, 0.013256405496836772, 0.03387965042410152, 0.03448283073625394, 0.03304651798680425, 0.03830732890803899, 0.03797415803585734, 0.0744496425613761, 0.027879363557855998, 0.0885644398097481, 0.05229774729481765, 0.026071415482355014, 0.00890511054811733, 0.04449310180331979, 0.058033756645662446, 0.018043548933097293, 0.008053095329419842, 0.016884354974276254, 0.022547839109652808, 0.012170042942411132, 0.05670280342123338, 0.09186718187161855, 0.039768034991409094, 0.02071720251946577, 0.037771411772285185, 0.015659589087590575, 0.01909338340296277, 0.01522990848336901, 0.02403379857007946, 0.03125340099047337, 0.035997802657740455, 0.06793285653527294, 0.0613672634852784, 0.05586403575060623, 0.0346627307257482, 0.040759238946650705, 0.07346105775130646, 0.05164107806714518, 0.03724790843469756, 0.031030271534941027, 0.040661621506192853, 0.05055422781567488, 0.026837981937985336, 0.026819568193916763, 0.04559158893035991, 0.006474434838829828, 0.046866647832627804, 0.06658249720931053, 0.04820405053240912, 0.06421374502990927, 0.08575027688805546, 0.013870844401286116, 0.027358177417357053, 0.023497847507574728, 0.0182639116620911, 0.04723595408722758, 0.01713585906795093, 0.006133447243233344, 0.04654273557077561, 0.02329418182905231, 0.01054032311575221, 0.030708106500761848, 0.06633937132677861, 0.02358043539736952, 0.06925137899816036, 0.06854182814380952, 0.04904309640239392, 0.0313108695138778, 0.0264682041015476, 0.03624323895201087, 0.030602577341986553, 0.04303884519530194, 0.05922186467796564, 0.07759271854800837, 0.023982866035242165, 0.020453467832079957, 0.023324532700436454, 0.04782242886722088, 0.02582499531230756, 0.014032669066052352, 0.04755333884220038, 0.007579782378992864, 0.04204393643885851, 0.03459251252934337, 0.04716115238677178, 0.048868733258651834, 0.02444604252065931, 0.04292838987229126, 0.04285432438233069, 0.043824887302305014, 0.030405880218105655, 0.01206635685438024, 0.07413427305540868, 0.05077858202691589, 0.05292329551385982, 0.012172172694200916, 0.04900920357821243, 0.02545875433965453, 0.03174187495772328, 0.04396790891353573, 0.019616371053936224, 0.01583622532364513, 0.0204969466597374, 0.07091050568435874, 0.014870481698640754, 0.06238739338836499, 0.01225514056360615, 0.04574436787515879, 0.05421059179518904, 0.07432495496634926, 0.048504689043121677, 0.050383532153708596, 0.0017193935304281435, 0.021935439202934504, 0.07606429806245224, 0.03935519732268793, 0.031801165347652774, 0.037939467933028936, 0.031024507379957607, 0.017513071951855506, 0.050253283964203935, 0.017322829392339503, 0.0314770427399448, 0.025276499833645563, 0.04971912423414843, 0.014946667610534599, 0.06399505319339888, 0.04086213878222874, 0.028926527992423092, 0.015539468033239245, 0.037721932998725345, 0.021799318292843442, 0.06106142061097281, 0.00926673154546214, 0.038679708926273246, 0.02364635168175612, 0.08275361518774714, 0.029557307716459036, 0.045356965091611655, 0.06427160371094942, 0.08066259417682886, 0.019466268929785917, 0.04983562869685037, 0.006850595993455499, 0.03350734843739441, 0.031063431541302373, 0.04640476904543383, 0.050373913919819255, 0.009514161036349833, 0.006582488571958882, 0.039759054580437284, 0.09985925230596747, 0.024999157126460756, 0.06353126093745232, 0.029485908869121755, 0.00832638972704964, 0.013362698007508047, 0.029934678359755447, 0.02219973537804825, 0.033504264495734654, 0.042897913471928666, 0.017649730600948845, 0.049132605349378924, 0.035311030223965645, 0.011760016105004718, 0.018811799851911407, 0.02287332557274827, 0.058496632879333835, 0.010455336604666497, 0.05764224872525249, 0.01348468248865434, 0.020429681787001233, 0.02263178746215999, 0.05769552050956658, 0.0366094035894743, 0.014734633898894702, 0.010795562544704547, 0.030515402555465698, 0.027279604758535112, 0.09063096570649318, 0.013884449028410017, 0.006173326442616859, 0.04408244223200849, 0.03041363587336881, 0.021579208318144083, 0.07212124285953385, 0.07002988936645643, 0.046575932896562984, 0.008137008058838546, 0.03475840077070253, 0.0668642045930028, 0.044502438445176394, 0.03897574018420918, 0.05263237362461431, 0.127065955262099, 0.15291357971727848, 0.12819696457258292, 0.14733288703220232, 0.12366200291684695, 0.08917816116341523, 0.08233552905065672, 0.10900802817195654, 0.09734194166958332, 0.1639595055686576, 0.13083638437092304, 0.1326253826596907, 0.1499818063208035, 0.17790827208331653, 0.1250053529760667, 0.08500428191785302, 0.13359570130705833, 0.13730278238654137, 0.13164697587490082, 0.13728476049644606, 0.28445786610245705, 0.23484102423701966, 0.09384979334260736, 0.13660883105226926, 0.1731832799102579, 0.09702931344509125, 0.16581713088921138, 0.07336511968501977, 0.07753372671348707, 0.2882698486958231, 0.09294658859393426, 0.1311155879603965, 0.18015703213002, 0.10494949987956456, 0.1305530145764351, 0.08296508062630892, 0.10129214863159827, 0.11310967736478363, 0.17076640602733406, 0.0546307610347867, 0.10969012549945287, 0.17148517817258835, 0.11955675748842103, 0.1896409025149686, 0.13300993559615953, 0.10760852933994361, 0.12600210734776088, 0.17814508080482483, 0.13874209086809838, 0.12006217108241149, 0.17333893584353582, 0.1285615007260016, 0.1185218830193792, 0.14521470426448754, 0.08152048635695662, 0.10741001713488783, 0.1885985913021224, 0.09568487094449145, 0.14599153186593736, 0.21101613981383188, 0.10575625087533679, 0.09223224728235177, 0.11802674244557108, 0.0662879180163145, 0.13641379294650896, 0.16812778690031596, 0.12942518080983842, 0.10261922063572065, 0.17021620912211283, 0.24139613392097609, 0.14155379070767335, 0.10124281235039234, 0.11827735256935869, 0.10312438317175422, 0.1830091726567064, 0.13467311992176942, 0.09181250551981585, 0.1316071187279054, 0.11200688832572528, 0.08118929341435432, 0.09947110313389983, 0.0878012982596244, 0.09893069070364748, 0.19368550048342772, 0.11392045207321644, 0.13261360329176697, 0.152034157621009, 0.14793599609817776, 0.1314513542290245, 0.2498900895672185, 0.13268776716930525, 0.11924115728054728, 0.17472575285605021, 0.11661975937230246, 0.1571043205580541, 0.0952570139031325, 0.21853166153388365, 0.08206698524632625, 0.16690810663359507, 0.18510629369744233, 0.22068476171365806, 0.12611800112894603, 0.17634533452136175, 0.09194220070328031, 0.1003198961594275, 0.1941618863493204, 0.08782908426863806, 0.0731770433485508, 0.15275729953178338, 0.1574642698147467, 0.12181447419737067, 0.11314194170492035, 0.21273785457015038, 0.14418532592909677, 0.11931267487151281, 0.07185366257492985, 0.14534872850137098, 0.1416967851775033, 0.17619343767208712, 0.08884841350040265, 0.1767112820276192, 0.26248326525092125, 0.1675999273679086, 0.07988896247531686, 0.19922463968396187, 0.06754951817648751, 0.14060066613767827, 0.07179535606077739, 0.11199291050434113, 0.14171487492110046, 0.09640615366931472, 0.12468186819127627, 0.14451744167932443, 0.19608494958707265, 0.22317729225116117, 0.17810898274183273, 0.1665493380278349, 0.08202366078538553, 0.0799323208630085, 0.09123195095786027, 0.09319505454706294, 0.09562679513224534, 0.2033912246780736, 0.1791155080177954, 0.12623548268207482, 0.07947198913565703, 0.07988457235374621, 0.17380768140511854, 0.16902767361274787, 0.19008336162992887, 0.1776427613305194, 0.2600553583885942, 0.08786032402089664, 0.10305795459342854, 0.0833775077813438, 0.20836481851126465, 0.2178527872477259, 0.1574677981968437, 0.10787572285958699, 0.14905358398599283, 0.12724787050059863, 0.13593470651124204, 0.1300043783017567, 0.06850601506552526, 0.11671894762132849, 0.18762763483183725, 0.07010293366121394, 0.12446590406554085, 0.2102909894394023, 0.0873808508206691, 0.0602573226871235, 0.13157233702284948, 0.14098710540149892, 0.09222877318305628, 0.10195741829063211, 0.19666018443448202], [0.015059183983664428, 0.012504389376512595, 0.02643766493669578, 0.025824574620596, 0.04721605944048081, 0.02023392273778362, 0.025605986260675957, 0.05160963475438101, 0.013133658511963273, 0.06830406268792492, 0.03921513751681362, 0.03205243365040847, 0.05588521282853825, 0.02913655832942043, 0.03509427899760859, 0.019690358512369648, 0.07106290464954716, 0.024560574142794524, 0.05077097225668175, 0.048211724763470035, 0.03990527887695602, 0.012957081647722848, 0.10024820214935712, 0.009686897392384708, 0.045878592279872725, 0.04627956576379282, 0.06544228017862354, 0.012262327097622412, 0.013995631232059427, 0.03174093518672245, 0.009615165214719517, 0.009048959972070796, 0.045947416086814234, 0.014959727713306035, 0.0471385503853006, 0.004210745749462928, 0.013852179599260646, 0.05231096515698092, 0.04868836168731962, 0.011458592190008079, 0.044274806909795315, 0.027577052458322475, 0.027136343963710324, 0.019347620296425054, 0.021326732223055193, 0.052105036564171314, 0.034498576141361675, 0.05860673875680991, 0.02591764587642891, 0.033975310291030576, 0.04339483180748565, 0.07156544125505857, 0.0334908396803907, 0.03146507338221584, 0.018511227498363172, 0.0322421350782471, 0.026082409445994666, 0.01798767496698669, 0.02900887160961117, 0.09737626197082655, 0.013591701031795569, 0.042403342867536206, 0.053063443529286554, 0.06258597344692264, 0.08128115348517895, 0.020890291713710343, 0.09749674264873777, 0.053613358842475076, 0.0811083781133805, 0.028887217066117694, 0.027634052792564034, 0.04189736608948026, 0.04800506674551538, 0.06462590077093669, 0.017598999930279594, 0.06898107100278139, 0.06736334173807076, 0.03440083656460047, 0.028535254166594574, 0.019669802293979695, 0.05244836510558214, 0.016568887080731134, 0.07975975583706583, 0.03701185627973505, 0.08802210034004279, 0.05662336732660021, 0.0627654188179544, 0.017258935142308474, 0.0626455352508596, 0.024101611359843185, 0.051877961427505524, 0.02419843152165413, 0.062050426112754006, 0.041067015645759444, 0.007884922969554151, 0.001666856896398323, 0.10283050286982741, 0.046634208876639605, 0.0846864018323166, 0.01585458648124976, 0.057986198126205375, 0.016114010774929608, 0.038594586708183796, 0.012541182937898805, 0.04984320454033358, 0.026575948677158782, 0.018901142557816844, 0.028964458099965538, 0.01945326310981597, 0.029466801322996616, 0.04797417643879141, 0.047111120607171736, 0.08402687257954053, 0.015489029132628014, 0.03206054553655641, 0.08491715802145855, 0.023719380709475706, 0.020836909667455723, 0.03578954668981688, 0.02530242156769548, 0.01985955630828227, 0.05645345197990537, 0.030960094050637314, 0.021730743847521286, 0.06745225018156426, 0.015442461274298174, 0.03618911899892347, 0.0236065267651741, 0.004660018204179193, 0.05485337480370488, 0.0446736803278327, 0.05469825830576675, 0.038539615193648, 0.014999569593263524, 0.08372449023383004, 0.009317514802595335, 0.08548857950206314, 0.06201232637145689, 0.06832755357027054, 0.04876486990334732, 0.03849708801135421, 0.02501535545369344, 0.01589349707189415, 0.041723837543811114, 0.03736825679828014, 0.04047456636492695, 0.039055223776293654, 0.02280858315394393, 0.0321843035386077, 0.0256701247833137, 0.027318586595356464, 0.023859998610402857, 0.042406593050275526, 0.07332802417555026, 0.027111434943175743, 0.019076469221285412, 0.01887643540145031, 0.05360515196142452, 0.028336333144190054, 0.010024232773243316, 0.015256524019475495, 0.044362304000450034, 0.023086310929751823, 0.04306665834571634, 0.02451688327294375, 0.054601790982165506, 0.004120075235342873, 0.004865917535166123, 0.015608045871236494, 0.01622296992822417, 0.00522179515766246, 0.015624274732545018, 0.0005532623992101954, 0.0017576118033113225, 0.055600265440131934, 0.018122318367074643, 0.05835298701588597, 0.029853841090308766, 0.008982914766030652, 0.03289540145280106, 0.02414582809433341, 0.01896162038402898, 0.05892675622765507, 0.056966950318643024, 0.023397699131497314, 0.014015087375550397, 0.0723786586895585, 0.02430602681956121, 0.04993952258623072, 0.03508755810824888, 0.1055572908371687, 0.06920658890157938, 0.08281288522162608, 0.09274709251310144, 0.017602594469540885, 0.01533429091796279, 0.017703436647674868, 0.006041896754010979, 0.017487557338816778, 0.04479290571595941, 0.01974017316076372, 0.019698638335934708, 0.03156621581209557, 0.02615128075038748, 0.017013631162366698, 0.02902871197355645, 0.016964411928451488, 0.0412884351930448, 0.054047689107911925, 0.048608735602881224, 0.03182376395644886, 0.046185975428670645, 0.03904838753598077, 0.06917980033904314, 0.022728485487667576, 0.04549346598131316, 0.05202351736703089, 0.016662083865542496, 0.0436764950864017, 0.024938536807894707, 0.038136436470917294, 0.01334933256397822, 0.023697625180440288, 0.041859507228114774, 0.061859974903719764, 0.02248513399224196, 0.024250071429248368, 0.017382336913474968, 0.023964957799762487, 0.05517242196947336, 0.0730259743119989, 0.026032192765602043, 0.06385119698409523, 0.023952253927875842, 0.018553627455340962, 0.01975166584764208, 0.05178153820868049, 0.012391225850608732, 0.02726899755985609, 0.022785397612356713, 0.10343879594334535, 0.056317965500056744, 0.05572506160076175, 0.05120081401297024, 0.018681110614644628, 0.0047928706959023005, 0.038761828626905165, 0.02061710842618985, 0.016816138456176435, 0.045198815542140176, 0.03353185712226799, 0.033962564010705264, 0.04760002883683358, 0.025381235106449043, 0.021661635055871944, 0.028608206859124557, 0.0934051764862878, 0.05330240659947906, 0.06476689356246165, 0.03780477873182722, 0.0215669505830322, 0.02111933460193021, 0.049483129754662514, 0.05263785618756499, 0.036273796776575704, 0.01641506319200354, 0.054617916366883686, 0.02423939637706748, 0.052017841421599896, 0.05695878754236868, 0.048530317310776026, 0.010159180665920888, 0.022809719700100164, 0.01774822674425585, 0.04035443513255034, 0.023513112849156772, 0.05841898133179971, 0.05278961732983589, 0.02301228784822992, 0.01929852828782584, 0.02419941539743117, 0.027755563147366047, 0.03785545172701989, 0.05196185888988631, 0.05743893927761486, 0.051339374256453345, 0.05288619321904012, 0.05252421174996665, 0.033583948255649636, 0.028437828412279487, 0.027739615878090262, 0.08385996653565339, 0.005113268994526672, 0.04912531788327864, 0.02727227658033371, 0.03183666969250355, 0.04551639367959329, 0.07976565230637789, 0.0241593886166811, 0.02949634473770857, 0.09719630091318063, 0.006212463918408113, 0.07182437700352498, 0.022543255605601838, 0.01566143979185394, 0.012275584823718029, 0.04196048680959003, 0.08365171735308, 0.02696448122151196, 0.025744677122150148, 0.009159599347705287, 0.021931678422593644, 0.04291734332218766, 0.043198874286775074, 0.006960695933750165, 0.02229697453523321, 0.02238278546636658, 0.04211350663432053, 0.030123538404170955, 0.004995173367206007, 0.022458764425079738, 0.03764366398432425, 0.08322273394359009, 0.010422303823621144, 0.010612127387763133, 0.0280537674136992, 0.0603701291339738, 0.045453422237187624, 0.10103000341249363, 0.042881350432123454, 0.006582317665951061, 0.12510550474481924, 0.02962936135008931, 0.05336560195844088, 0.09054224046745471, 0.034395296326173205, 0.0308509075881115, 0.07277719623276166, 0.01804866678347545, 0.05958566801356418, 0.07289688302470104, 0.057732860291642804, 0.05107199074700475, 0.035217341501265764, 0.05097865146983947, 0.030946961005351374, 0.04843923416254776, 0.04752874534044947, 0.06735768275601522, 0.050221667625010014, 0.01603009465283581, 0.04188574617728591, 0.10514703499419348, 0.17065824754536152, 0.06452865991741419, 0.15715526496725424, 0.16449792310595512, 0.08780380205384322, 0.15229604499680655, 0.21464282806430543, 0.10193692653306893, 0.1345934056277786, 0.18997828369694097, 0.1753787478165967, 0.11287277364837271, 0.18504869964505943, 0.19820548008595193, 0.15338615221636637, 0.1842366832175425, 0.13884502463042736, 0.104074841099126, 0.08721705246716738, 0.0991044295951724, 0.09730188774743251, 0.1569363831409386, 0.20103742741048336, 0.08692357928625175, 0.13111978130681173, 0.18175107373722962, 0.08818097252930913, 0.10620554283793483, 0.16259987066899026, 0.07266565186104604, 0.11725632021469728, 0.14058553480676242, 0.11751917111022131, 0.112995330643441, 0.10718015661197049, 0.10552853452307837, 0.12116397624569279, 0.06767438897596938, 0.11192331995282855, 0.17498897016048431, 0.056406527890690734, 0.1632638443261385, 0.12096634613616125, 0.13230028296155588, 0.11265619884112052, 0.18581875546702317, 0.15708581012274536, 0.1578363919896739, 0.049013519060931036, 0.11733074193554265, 0.08384389882641179, 0.11829183250665665, 0.11538627770330225, 0.15677706311855996, 0.08905364998749324, 0.12011380759733063, 0.08184263442776032, 0.13782293376113686, 0.2189577543841941, 0.15002661677343504, 0.10422516374715737, 0.1582032758742571, 0.1253765252019678, 0.13623076491057873, 0.12034317957503454, 0.13206785757626804, 0.28897709931646076, 0.16974584864718573, 0.10518786244626556, 0.11057209210204226, 0.12617646370615276, 0.11382353691650288, 0.11614991458398954, 0.11806954443454742, 0.13211406581103802, 0.18257887288928032, 0.14700022845395974, 0.18576216564646789, 0.12561319821647235, 0.15379055908748082, 0.10838910924004656, 0.1626160740852356, 0.1376564484089613, 0.17779503815940448, 0.17910826126379625, 0.09328481794467994, 0.12773032246955804, 0.18509615638426372, 0.08225296490958758, 0.15385621413588524, 0.09701239756707634, 0.16612300090491772, 0.16529524246496813, 0.13898303865322045, 0.12296786159276962, 0.11756392728005137, 0.11409212143293448, 0.1945945881307125, 0.09319031837263278, 0.2320973000356129, 0.13168983214667865, 0.12037652278585093, 0.09002139698714018, 0.1530081403574773, 0.10966377119932856, 0.11230480591101305, 0.12309315986931324, 0.0682992586599929, 0.1668987428503377, 0.17908460753304617, 0.1112228071849261, 0.12274503069264547, 0.0882667868531176, 0.2607891804405621, 0.15726355915623053, 0.11096178154860224, 0.12265527408037867, 0.08214227549199547, 0.09418704560292618, 0.13818217734141008, 0.13308948704174586, 0.1254670282027551, 0.07118620803313595, 0.19672939500638417, 0.09550315926649741, 0.21311076384569916, 0.09225358720868826, 0.12111841940454074, 0.20251501883779252, 0.17380439729562827, 0.09584562946110964, 0.12146033320043768, 0.1226582189223596, 0.19753902299063547, 0.0784684969112277, 0.1317671715681042, 0.13112967434738362, 0.12496044752853257, 0.16374051517673902, 0.13563782029918262, 0.12204172914581639, 0.13768709105040344, 0.0564498218175556, 0.07691377640834876, 0.1352195848843881, 0.19365465428147996, 0.12246194588286535, 0.12498123784150396, 0.08177393275712218, 0.1401849277317524, 0.17476889411253588, 0.2517157830297947, 0.14612381905317307, 0.08935224610779967, 0.2330760189465114, 0.08263726678809949, 0.10029633742358003, 0.17465705797076225, 0.13380030675658158, 0.08339683924402509, 0.1404142997094563, 0.13045883391584667, 0.24153881626469748, 0.12359075673988887, 0.11873536370694637, 0.16423515363463334, 0.11659454501100949, 0.11980605125427246, 0.09117895737290382, 0.13165784600589955, 0.11674127142344203, 0.13666341240916932, 0.104003852765475, 0.13563684320875577, 0.11472816658871514], [0.04130561909239207, 0.040199712184923034, 0.03061507934970515, 0.017783094962526644, 0.016835861772830998, 0.10376440454274416, 0.026109907077625394, 0.03456074691244534, 0.056241620132433515, 0.010463127034849353, 0.032268146718186994, 0.03806726321844118, 0.043741525882588964, 0.007931803802161344, 0.04543592621173177, 0.007826624088920653, 0.019627032535416738, 0.03454918467572757, 0.01914619717613927, 0.021474393317475915, 0.04195225278713873, 0.04632109889228429, 0.051803750052515946, 0.03274095670453139, 0.025104102745120014, 0.03433717640915087, 0.028048634296283126, 0.06256590238107101, 0.01201336835843644, 0.018076120310329964, 0.04052953787946275, 0.033880518948925395, 0.04522527501519237, 0.010838266146103186, 0.005718269900951002, 0.022901661195127026, 0.048631826149565835, 0.002690831124449947, 0.023650699394888113, 0.06256206187286548, 0.02302817744202912, 0.04561286100319453, 0.023536615605865206, 0.016918899192075645, 0.07536663514162813, 0.015839762187429836, 0.05185619741678238, 0.01790924310418112, 0.009333966732291239, 0.06707506613539797, 0.08831535638975245, 0.06989785323717765, 0.008026404306292534, 0.03381145086937717, 0.03424527562622513, 0.038291074601667266, 0.055956089203911166, 0.032443829612540345, 0.01068911312281021, 0.01036501256749034, 0.09272680431604385, 0.01934814446472696, 0.028401365636714866, 0.02829696623874562, 0.07901831383683852, 0.06518964123513017, 0.039188199676573277, 0.0041625790929953966, 0.06443453353962728, 0.019484212788354074, 0.043553890593882115, 0.03765390307775565, 0.04238529383604016, 0.023372048811454858, 0.03781702968158892, 0.058039924528981955, 0.02048863290942141, 0.06828844959714583, 0.05552355366359864, 0.03690425419647779, 0.06341616782758917, 0.032521766144782305, 0.0049918828964499486, 0.05387296973328505, 0.07064532062837056, 0.03055242003340806, 0.022767832037061453, 0.022883834383849586, 0.0484093921924276, 0.01831389424790229, 0.026935892844838754, 0.045783329355929575, 0.054351835644670894, 0.017562472693888203, 0.02090079034678638, 0.014660274942538567, 0.04641580541751214, 0.030525227742535726, 0.06321876841996397, 0.04210723018539803, 0.038720190325485807, 0.015153871849179268, 0.01469838825453605, 0.023181314314050332, 0.04038915916212967, 0.030969556221472364, 0.061840989493897984, 0.01821401050048215, 0.01374397870884942, 0.027758234879001975, 0.028054093110508153, 0.03135827197028058, 0.04947822055380259, 0.05644462084663766, 0.07338459364005498, 0.008127722307108343, 0.04879408422857523, 0.07427185281578984, 0.005249903046725584, 0.02339928351076586, 0.057453025664602, 0.025899322038250308, 0.07199411253843989, 0.037601679630045376, 0.028976071226809706, 0.023910478223115206, 0.04848974430933595, 0.02211448423830526, 0.017351733287796378, 0.05592724128759333, 0.02041005516158683, 0.01028489284882588, 0.03252989160163062, 0.05237194509910686, 0.008062001949708377, 0.04685227306825774, 0.05907252590571131, 0.0422327557711729, 0.026418435254267285, 0.07123555109969207, 0.02351797794524048, 0.05038149654865265, 0.013635567472582417, 0.03361927278872047, 0.015367732516356876, 0.041540259894515784, 0.03338415361940861, 0.052031999054763994, 0.025037894690675393, 0.06330231643681015, 0.03230957806642566, 0.05372178873845509, 0.024085340090095997, 0.018560662167146802, 0.02680157174888466, 0.062007861611034186, 0.027935229042278867, 0.06064648287636893, 0.03860569432643907, 0.010918143288498479, 0.03395135461219719, 0.021319124149158597, 0.036698926107159684, 0.07516879468624081, 0.02341646741011313, 0.06956375616469554, 0.10672301399920668, 0.017885017707677822, 0.03593046484248979, 0.014463525232193726, 0.05698899592139891, 0.052461677962648015, 0.027199720830789635, 0.01841095868231995, 0.043624807681356154, 0.043531315733811686, 0.04231489243518029, 0.06092118777866874, 0.057614157375480445, 0.042143409672592363, 0.06822890136390924, 0.07000015596193926, 0.0751424403861165, 0.014150360116868146, 0.08519391209951468, 0.03126653403575931, 0.038621110642062764, 0.00978210857803268, 0.030460020527243614, 0.02784987272960799, 0.05067828776580947, 0.04376368683629802, 0.029635536018759012, 0.03522556873836687, 0.018505356474114314, 0.01633909441131566, 0.05053927968921406, 0.0635866904631257, 0.012855334473507745, 0.034774420982492824, 0.006721642109498913, 0.026674529637343118, 0.0814787768093603, 0.032926057664943595, 0.01565726171247661, 0.03344623278826475, 0.018016992768804942, 0.017353100535858954, 0.043069324988339625, 0.008208011659527463, 0.0296260534918734, 0.1148989809943097, 0.07653167976864747, 0.021109595928075056, 0.09234563048396792, 0.02937357061143432, 0.008225997926534286, 0.013541586979824518, 0.031410084904304574, 0.038294253538229635, 0.04302910482510924, 0.03595026110165885, 0.04716287247304406, 0.0292995322628745, 0.06659376767597028, 0.020732827484607697, 0.030201071208076816, 0.04898303587521825, 0.029815697244235446, 0.040600879051323445, 0.006903916547474052, 0.011616595006281776, 0.03463783188323889, 0.012886376602442136, 0.09669721805091415, 0.02513202276479985, 0.05181162105873227, 0.047514865906643014, 0.03237360802346042, 0.010032377737973417, 0.025775392706106817, 0.04681908592049565, 0.008260870385648949, 0.0473382059218628, 0.064999556435006, 0.03339708310418895, 0.03680014656856656, 0.017927678900637796, 0.044885108446968455, 0.05651228775137237, 0.00990625673771969, 0.06263262272945472, 0.055842173352305374, 0.04485836398920842, 0.016861912428534458, 0.03281787882692047, 0.020708629229505147, 0.027378282409959605, 0.008055769605562091, 0.022665473333160793, 0.04069276626354881, 0.03717700491792389, 0.06087508810950177, 0.030111792962998152, 0.03341003294501986, 0.07826197120760169, 0.052039276342839, 0.017331395896949937, 0.041449156390236955, 0.06941847503185272, 0.036727641709148884, 0.01385030260176531, 0.06489035300910473, 0.1258010845631361, 0.025319800545860614, 0.052156805393419096, 0.11476095340081624, 0.0580133463123015, 0.07014694344252348, 0.010627061943523586, 0.05132181377017072, 0.07051013609660522, 0.04194827996460455, 0.05219622149265238, 0.020460611109488776, 0.0025374900557965574, 0.03221591987780162, 0.011149537300557961, 0.012528797129302152, 0.017993038786309104, 0.04659787332639098, 0.00872873978888882, 0.0668321166719709, 0.03380290811349239, 0.03569344238245061, 0.03714062187022396, 0.02750727191700467, 0.0565561991451042, 0.02939699703295316, 0.04757072290937815, 0.045547334876443656, 0.02988879582179444, 0.01689469245528536, 0.05332035045804722, 0.01798202616295644, 0.03834209704239454, 0.031237750580268245, 0.0362028627257262, 0.03582877279924495, 0.03902133095211216, 0.08982680671449218, 0.029266942225928818, 0.027569118687616925, 0.03380077412085874, 0.02823804395406374, 0.012559443163419408, 0.010584330352555429, 0.03917101238455091, 0.07131966908595391, 0.005609479533242328, 0.026238842301868966, 0.02766814239190093, 0.05411544422219906, 0.03424829849973321, 0.030572925361671617, 0.10020192606108529, 0.02308644324408046, 0.004329583948544625, 0.029571468742298226, 0.03989613901025482, 0.04437197990981596, 0.011231298225798776, 0.027166581180478846, 0.023351779274110283, 0.031459044598575146, 0.014599001534017069, 0.007579556766099164, 0.014884854766673275, 0.06199634008641754, 0.07508550451270171, 0.04863168026453682, 0.06415293472153799, 0.05988459661602974, 0.008262819477490016, 0.08043265222970929, 0.009108073942895447, 0.03508136647620371, 0.04186056574274387, 0.02478871457943959, 0.006683968573010394, 0.07281210685947112, 0.033509733487984965, 0.15820441581308842, 0.11529140493699483, 0.1394324188253709, 0.0890173212225948, 0.09906020946800709, 0.20368836873344012, 0.14723417375768932, 0.11665299401751586, 0.22751461022666522, 0.1008428702397006, 0.08704948145896196, 0.09046152872698647, 0.1458008499549968, 0.07731910608708858, 0.15206404030323029, 0.14496767680559838, 0.13077147571103914, 0.0896787978708744, 0.11174894323838608, 0.1410979237407446, 0.1533882285335234, 0.12482706111456666, 0.09071469692779438, 0.1147557965346745, 0.13935429230332375, 0.13797607911484583, 0.1738641762307712, 0.12297023646533489, 0.06028198743505137, 0.14056213891931943, 0.0767389450754438, 0.11267213762870856, 0.17801888686205658, 0.11317338501768452, 0.06758256961724587, 0.209638401599867, 0.23262207901903562, 0.10909260077668087, 0.148339412308165, 0.2239509578794241, 0.08248164478157248, 0.0908567210925477, 0.11670315132609435, 0.0695290355277913, 0.19676214110638413, 0.06689368015421288, 0.11987614392169885, 0.08913069763886076, 0.1564295853355101, 0.17593913631779806, 0.2296248541346618, 0.1169844176620245, 0.08375223553074257, 0.1679459395153182, 0.12145387354706015, 0.08443185620542083, 0.1081144314791475, 0.17972549742886, 0.1413836141249963, 0.09953496684985501, 0.3282136581838131, 0.14302509890070983, 0.18131157303495066, 0.21640711410769395, 0.1825490173484598, 0.10988818308604614, 0.163763218958463, 0.1343390228492873, 0.1729423456958362, 0.09516011231711932, 0.0839728611920561, 0.09702455691461052, 0.13070820910590036, 0.11975457758775779, 0.10555051905768258, 0.13081107501472744, 0.15277893122817787, 0.11273784695991448, 0.1626233479806355, 0.13845987458314213, 0.1879310892628772, 0.12332829939467566, 0.08966768346726894, 0.10593675476099763, 0.1066666209538068, 0.1575476617685386, 0.15120810908930643, 0.20108109792428358, 0.13506607312176908, 0.09105929093701498, 0.1593939419835806, 0.08142733028424637, 0.1255777379763978, 0.13086549352322305, 0.15509694255888462, 0.08406793073351894, 0.1672807987779379, 0.13374704175761767, 0.13303512281605176, 0.15667474003774778, 0.22727628158671515, 0.13894137660307543, 0.17575142639023916, 0.06429204118571111, 0.17200773156114987, 0.10240385362080165, 0.1379496298198189, 0.14521937258541584, 0.06147905891495092, 0.1194359375430005, 0.06402155677122728, 0.08583077149731771, 0.14393631714795316, 0.1145798931164401, 0.16764439855303082, 0.10045513497399432, 0.17183113603719644, 0.11138244611876351, 0.10639994312077761, 0.09530397531177316, 0.17310569621622562, 0.20773496159485408, 0.1940194075661046, 0.10707317878093038, 0.1490894513470786, 0.09568105079233646, 0.1889079896999257, 0.1477871255150863, 0.09020848944783211, 0.09976995031216315, 0.16621289322418825, 0.15523573011159897, 0.09868635702878237, 0.10203936496483428, 0.09741670944328819, 0.17290502626981052, 0.14177317464990274, 0.09070868510752916, 0.11486487782427243, 0.1267293340393475, 0.15226506308785506, 0.11345245290015425, 0.20958778288747582, 0.1257545506315572, 0.06303612714899437, 0.07381985349846737, 0.13450723168041023, 0.21638770800616058, 0.23737187843237603, 0.1873459613748959, 0.09728883273367371, 0.12223105398671967, 0.14742294219987734, 0.16902728006243706, 0.16211560022618088, 0.10431466930146728, 0.12418938747474126, 0.129620883879917, 0.21453618950077466, 0.10814874499504055, 0.10946066531219653, 0.07979675635163273, 0.13240855000913143, 0.20572785500969204, 0.18021690606006555, 0.19247158776436532, 0.1465135831385851, 0.15826408618262836, 0.12647868320345879, 0.0722713280203087, 0.138300500277962, 0.1132505073079041, 0.20569124126008578, 0.13218957318791322, 0.20014754230422632, 0.13140995002218656], [0.07343184681875364, 0.06436718215367623, 0.022923074063978026, 0.02555471276199179, 0.04945081452439938, 0.03868214486699019, 0.06773861910083465, 0.06820304239434855, 0.026877392948205982, 0.05381830355950764, 0.03151653687070523, 0.01970759839085596, 0.024952860682138374, 0.04922304728201457, 0.027023159233587127, 0.019540641456842422, 0.0581133488033499, 0.01066207604682339, 0.061151387569095404, 0.06345101738614695, 0.038576870158846886, 0.0831726784152644, 0.06802735610732011, 0.01725246531090566, 0.04827111354097724, 0.03799258365428873, 0.04122950103400009, 0.06795554674629654, 0.06772109254130296, 0.029873752700431005, 0.014122021101814295, 0.08205071397657905, 0.03381463998396482, 0.05591935671067663, 0.0449889039487711, 0.10083700091178928, 0.011219000626754547, 0.038731769525579045, 0.025665982327024852, 0.054307873360812664, 0.09495273165936981, 0.02703678421676159, 0.01864820845159037, 0.01929132394226534, 0.06766697937356574, 0.038785160053521395, 0.07429127248802356, 0.06511993533266441, 0.05701978105519499, 0.0708313477890832, 0.03741418344101735, 0.011870051584472614, 0.04797996773517557, 0.04033750568383506, 0.022401368844189813, 0.008367190037720969, 0.05134210196722831, 0.03913738758170179, 0.06447185296565294, 0.03890861610748938, 0.015354952309280634, 0.08231999738407986, 0.0315168014993625, 0.014907634883586849, 0.017135258564459424, 0.014889509516901203, 0.03064204433134624, 0.016533961186983755, 0.054598571333502016, 0.02194974441746516, 0.08038067644728081, 0.03150820106800113, 0.010645264493567603, 0.02114593147832368, 0.040709458225007565, 0.026841725754950727, 0.04839972985376205, 0.05631981450798256, 0.052006560776914866, 0.07241387465702635, 0.00785016077238002, 0.014757765157680427, 0.06221322701977832, 0.021761111682280898, 0.012422504618630877, 0.05280346283689141, 0.05227931149836097, 0.048839288231517584, 0.057858518191746304, 0.034318068863025734, 0.045443546159991195, 0.030651852555040802, 0.021544998278841376, 0.03958038952467697, 0.02947708112852914, 0.006968788312016321, 0.028572247895811285, 0.029785203880497386, 0.0456574068271688, 0.05761883248175893, 0.05867028356130634, 0.033428597663130076, 0.010259191638657024, 0.0330626060520964, 0.021181647865367786, 0.0077114758480872425, 0.03997698985040188, 0.026935195650107095, 0.03800702627216067, 0.021456045730571662, 0.021645667430545603, 0.037223769551409144, 0.024343180004507303, 0.023470740033579723, 0.04402387787454894, 0.00903703980813069, 0.06695678391094718, 0.06202197513942208, 0.030132651129471402, 0.06659065998558487, 0.04828284201877458, 0.05674299644306302, 0.059396892786026, 0.018333154464406625, 0.013253159554941314, 0.034540818338947635, 0.09753695263394288, 0.028776493721774647, 0.03263294071491275, 0.015416978891672832, 0.03192591401083129, 0.0027117056181720856, 0.029671739254679, 0.03596524315487061, 0.013515645737892814, 0.03399245687095182, 0.003484963913381632, 0.01699253381229937, 0.0642759327643684, 0.037682795098849704, 0.030997369371886765, 0.05309392332232424, 0.02368713672538953, 0.05746058454470975, 0.03531632958246129, 0.005969036511877286, 0.04265563575817006, 0.08345669281802007, 0.07783125753381423, 0.05109548502202545, 0.0758630106491702, 0.028050883639869944, 0.054163111307259114, 0.014464654992999775, 0.024048085124897103, 0.025810038704159002, 0.06044999949101891, 0.06138801308614867, 0.03895417973399162, 0.057713664535965235, 0.05864097763385091, 0.040516720352960486, 0.029604971408843994, 0.061950857884117534, 0.025671670146818672, 0.04368014221212693, 0.032467256034059186, 0.01915355758475406, 0.07240847351827792, 0.039959755060928207, 0.015333907545677252, 0.05107932571055634, 0.018400704321850623, 0.005016031533679259, 0.008926912726435279, 0.0006336460043842505, 0.05427020788192749, 0.04549440235963889, 0.012042949092574418, 0.041365930677524636, 0.0058316738827021, 0.05142230141375746, 0.0508155757561326, 0.06890242200876985, 0.011531294672749937, 0.05968244067792382, 0.07168151824069874, 0.024863809746290957, 0.02255966597502785, 0.02485619149436908, 0.03353652883587139, 0.021877027515854155, 0.02216081800205367, 0.04839602844523532, 0.026606464093284946, 0.061491062199430804, 0.047909674899918694, 0.09210648760199547, 0.02198777291258531, 0.08293829206377268, 0.009426386594506246, 0.02497366626214768, 0.07121523576123373, 0.03476255001234157, 0.0581683237105608, 0.013380740253653909, 0.025878691181008304, 0.035671335711543045, 0.036680897431714196, 0.0680528147412198, 0.05505620588415435, 0.05813444445707968, 0.04064761654340795, 0.050358117624585114, 0.0071625545887010434, 0.030532342182206254, 0.07044536992907524, 0.03701201234278934, 0.037141775379755666, 0.022612486533554535, 0.04369892066876803, 0.039050039768751175, 0.05187825659023864, 0.06443825869687966, 0.029327647361372198, 0.02792055911517569, 0.009311975412336844, 0.012754282797686756, 0.025261117444772805, 0.09286886240754809, 0.03567396164206522, 0.04642267219190087, 0.001379324501613155, 0.040170097524034123, 0.00981791063012289, 0.03356124108125057, 0.01910039097336786, 0.014585145848936268, 0.0335345644769924, 0.023098197166940997, 0.020011761890990392, 0.05430223473480769, 0.027386536788461462, 0.02336017953764115, 0.11662900101925645, 0.06616339326969214, 0.06222212939922299, 0.05206909117155841, 0.022463559971324036, 0.005053017629377011, 0.022514521343899623, 0.02238587788971407, 0.030155164921390157, 0.028144222917035222, 0.04998504210795675, 0.030354793316551616, 0.03626761192988072, 0.04008850029536656, 0.04850110298554812, 0.04072935287175434, 0.015319176550422395, 0.0497045832286988, 0.01717206569654601, 0.010923175473830529, 0.08738548521484647, 0.029819537752441, 0.03082653121756656, 0.10131591771330152, 0.07959378617150442, 0.04924899446112769, 0.028340414532327225, 0.012579420930705965, 0.022697133777130927, 0.06098138740552323, 0.024012036255693862, 0.03977782964440329, 0.036080173416329284, 0.029685767966189554, 0.0523982315457293, 0.010573731635564139, 0.029337764318500246, 0.025362371832930615, 0.06674380533929382, 0.0272123127443982, 0.006016889769983078, 0.027689772391957895, 0.01528342962930245, 0.03544197730453951, 0.036264276930264065, 0.015726027843941535, 0.031245672476610968, 0.03531573925699506, 0.042640344971524816, 0.010622070470292653, 0.061864711078149934, 0.05269095155277422, 0.022725135221013, 0.011899649281986058, 0.060899488228772364, 0.018753620563074946, 0.022087914503312538, 0.046706740877458026, 0.028055984526872635, 0.013096352656637984, 0.07758676101054464, 0.04375852318480611, 0.09332540112414531, 0.05849214097751038, 0.04972595029643603, 0.05659128279824342, 0.04384847657222833, 0.02589097266484584, 0.04058078084407108, 0.03762846140723143, 0.07094184721687011, 0.056672941095062664, 0.019763786179412688, 0.032954115087964704, 0.034412673608000786, 0.01637089565130217, 0.016284752238009657, 0.024261107801326683, 0.0032261935578260037, 0.01588011296865131, 0.06645451871944325, 0.03310630709997245, 0.05734161699989012, 0.07151237981660025, 0.005718098570858794, 0.040286910720169544, 0.03983126427712185, 0.035707929105098755, 0.03980190406686493, 0.0445858236136181, 0.02537699256624494, 0.03866089993555631, 0.022907757832269584, 0.06471403568450894, 0.046303555369377136, 0.04351857963151165, 0.026303289557940195, 0.07041586044111423, 0.04791712860709854, 0.03691255607243095, 0.07812659668603114, 0.015502723665641887, 0.026196340564638376, 0.044497447820114236, 0.059427745773323944, 0.020172695130375878, 0.0709549497280802, 0.01586982298509351, 0.12191762509090559, 0.11957226879894733, 0.08335919412119047, 0.12103618096028056, 0.14008545449801854, 0.1375748206462179, 0.15399464885038988, 0.19998102981065, 0.09671969113073178, 0.10788506628679377, 0.12839817734701292, 0.13929322415164538, 0.0775835176131555, 0.15908405504056386, 0.18556175354335988, 0.12267512801502432, 0.10438349989375897, 0.11417372205427714, 0.103342070776437, 0.08786615942205701, 0.15766641896750244, 0.2300155817398003, 0.12470810035509722, 0.2771633703793798, 0.13010712207428046, 0.18020398675331048, 0.1099471477791667, 0.1327948264245476, 0.12886733002960682, 0.08330937608012132, 0.11597582963960511, 0.15301373148603098, 0.10325857025704213, 0.13700117357075214, 0.15289964260799543, 0.23105029336043767, 0.15006031282246113, 0.1097088802073683, 0.14245780291301863, 0.1674702593258449, 0.20936271282179014, 0.1096267503287111, 0.13543150494141237, 0.09852270795298473, 0.18538316312645162, 0.11811079936368124, 0.16945762054196425, 0.15732835925051145, 0.09487745498440095, 0.1255001678530659, 0.18332798912056855, 0.08233245528702225, 0.11125891203326838, 0.16427479365042277, 0.12973315428410256, 0.09509003322039332, 0.23092131742409297, 0.1544183532574347, 0.12740686482616834, 0.15636173183364527, 0.13761021303279058, 0.17521382309496403, 0.12097343004175595, 0.10919246077537537, 0.12339687214366027, 0.1637976478253092, 0.14197756296822003, 0.1382172168897731, 0.19561057218483516, 0.17134683845298632, 0.15435614516692503, 0.1632358751126698, 0.10762593376317195, 0.10102335376931088, 0.15467783861926623, 0.12320950148361069, 0.11676324238734585, 0.10456766786852054, 0.17178096515791758, 0.13963291235268116, 0.11438443431896822, 0.09865379413323742, 0.137731100831713, 0.14300571994057723, 0.10083113158387796, 0.1271227350724595, 0.07473517688257353, 0.16856787114271096, 0.12436700080122266, 0.2759024623249258, 0.10106751282832452, 0.2636051821921553, 0.15052262587206705, 0.11037092003971338, 0.13513596222868987, 0.08071353180067879, 0.16495125235191413, 0.09751273571912732, 0.0899949816188642, 0.1724897085555962, 0.12372316606342793, 0.14213579733456883, 0.12551681910242352, 0.06629468979580061, 0.14291725254484586, 0.1038082582609994, 0.1910342470343624, 0.19349595851131848, 0.11428101201142583, 0.08043132230107274, 0.10634395041103874, 0.12150191382638045, 0.1939585701163326, 0.13186037513826573, 0.12998461936201366, 0.09583100024610758, 0.18284949979611806, 0.13638228178024292, 0.0856189260791455, 0.17776720465293952, 0.11480052556310381, 0.1384182668157986, 0.14088988490402699, 0.11138993714536939, 0.0922066732974989, 0.18781112427158014, 0.16920090360300882, 0.13490669881658895, 0.11940547132066318, 0.0833318220185382, 0.14598797634243965, 0.14450882428458758, 0.183033464210374, 0.13046066596039704, 0.15779098442622594, 0.10005453468433448, 0.08545130078813859, 0.1566662583500147, 0.17756335916263716, 0.14072854284729275, 0.102622762588518, 0.13743775657245091, 0.11761449170964104, 0.11054431287837879, 0.10035527497529984, 0.10560191808534519, 0.14709279420120375, 0.13422691529350622, 0.1822353306093386, 0.11681038700044155, 0.15677083416708879, 0.17743518389761448, 0.13544888900859015, 0.08600398791687829, 0.19414184242486954, 0.12912133282848767, 0.12342784048191138, 0.15987852455249854, 0.10960261483809777, 0.139056049021227, 0.08718143616403852, 0.2333876293684755, 0.12349734960922173, 0.09991835949144193, 0.07962932105043105, 0.1333246129964079, 0.15319996220724924, 0.06878848919378859, 0.16625712013670377, 0.13157198418463978, 0.0806891859642097, 0.15108395075159414, 0.1092980679656778, 0.09517070424876042, 0.13472831196018628, 0.11692663361983639], [0.06085650982069118, 0.032469505377646, 0.01494070837673332, 0.030133668931999376, 0.03252875166279929, 0.020590577706960694, 0.007393322652205825, 0.07002330079142537, 0.032356054322527986, 0.022162025794386864, 0.08380088649157967, 0.03465225075238517, 0.040316640732011626, 0.012125715097811605, 0.02460477900292192, 0.015976649842091968, 0.02915580497522439, 0.011589406956253307, 0.03979455553261297, 0.04385425429791212, 0.025523803795554807, 0.04719870251470378, 0.03148597226079021, 0.03466864415843572, 0.024329689031999027, 0.0020702296377359225, 0.04356819411207523, 0.01921983858171318, 0.023067793709092906, 0.032669462862291505, 0.023552067544577376, 0.010964734895553972, 0.02731142465823463, 0.03779319953173399, 0.027852725969361405, 0.029080959169992378, 0.07449427659490279, 0.047971669251897504, 0.008500434807501733, 0.1027520913630724, 0.10777090276990618, 0.1023394131500806, 0.021369971867118562, 0.046874203320060454, 0.021048295378152813, 0.04203905437939933, 0.05370425878624831, 0.05846255685069731, 0.08336308891219751, 0.08425992221704551, 0.02273522673307785, 0.014836573607421346, 0.010465023540226477, 0.02019873391171651, 0.018649395887873003, 0.019542127448533262, 0.031036707439592907, 0.05273994178112064, 0.015677426076893295, 0.017242999747395515, 0.07907936163246632, 0.05727467952030046, 0.02210991600129221, 0.07180290815553494, 0.04195187620020338, 0.0628950936453683, 0.01639920243594263, 0.02526009964224483, 0.059710192760186534, 0.041326623143894334, 0.056108091226113696, 0.003958973634455885, 0.04987173354519265, 0.06083713086055858, 0.0612427115972553, 0.04174456000328064, 0.03300482540258339, 0.028627406007477214, 0.04419561508776886, 0.021500633962984596, 0.030126992147415876, 0.09973981657198497, 0.04532214267445462, 0.046103882869439464, 0.07770683456744466, 0.06465423639331545, 0.02560023058738027, 0.022954692099509493, 0.018025343838546957, 0.005588198130551193, 0.021378489177940146, 0.02890816004946828, 0.047181908772992234, 0.058686351270547936, 0.07748480433864252, 0.03343378845602274, 0.016572390017764907, 0.015197996981441975, 0.04143926674234016, 0.10262670487697635, 0.04052094423345157, 0.02199655315572662, 0.04123911587521434, 0.08393899550927536, 0.051748452841171196, 0.02607371741240578, 0.03530531017375844, 0.01834041648544371, 0.029315739071794918, 0.04428215544404728, 0.04322186305320688, 0.048635826113500764, 0.0081271039920726, 0.0998287114447781, 0.04817857154245887, 0.06462638931615011, 0.034863583876618316, 0.020536929335711256, 0.017485528519111018, 0.04942243140456932, 0.04479341800989849, 0.047830072564205954, 0.05715652621750321, 0.01686913543380797, 0.05459353321098855, 0.03198460389726928, 0.03921266086399555, 0.04746799610022988, 0.060586832862879546, 0.02002470155379602, 0.04585016505526645, 0.06545957603624888, 0.0013227903421336252, 0.015076948030452644, 0.0036288803426681882, 0.04033346500779901, 0.013993066369688936, 0.0379922986695809, 0.010231879755987652, 0.02496967477990048, 0.03020512206213815, 0.05176308884152344, 0.039439661361809285, 0.06134569964238575, 0.02840084146841296, 0.01061924861278385, 0.06287309554006372, 0.025661483639851213, 0.07327290677598544, 0.004697315153732363, 0.02309043302999011, 0.02793063366386507, 0.04584708111360669, 0.024197734326922467, 0.01879458881116339, 0.020104315763871585, 0.06671061819153172, 0.03618799602346761, 0.015593057032674551, 0.024789159019876803, 0.030915412519659315, 0.039972457236477306, 0.03649225112582956, 0.018272183003968427, 0.03537684812077454, 0.059343322446303706, 0.03282151577462043, 0.06611826390560184, 0.02678511048933225, 0.054633892473897765, 0.06316441097962004, 0.0763268368318677, 0.018078479915857315, 0.03102108756346362, 0.006258766299911908, 0.025664277507790496, 0.018492364224844744, 0.030345833261630366, 0.030132512029792582, 0.012541598540597727, 0.014941755016999585, 0.02162199673642005, 0.019245639875797287, 0.014754587917455604, 0.07243530279291527, 0.01580776077961283, 0.05535742114963276, 0.021077703085861037, 0.06827358289488725, 0.05255547525095088, 0.06724892716322627, 0.02006679108100278, 0.00807314773555845, 0.054986323562583754, 0.09504189794617039, 0.042449578243706904, 0.016678214339273315, 0.03119691295017089, 0.028932214115879366, 0.004095945257826575, 0.05284895521721669, 0.0399177401725735, 0.025248210012380565, 0.029989877183522497, 0.011229606129096022, 0.037236695643514395, 0.022687971858041625, 0.02237122322964881, 0.03560275278453316, 0.014476135805515307, 0.0049956759072041935, 0.07285118369119507, 0.08037658488111836, 0.05419943667948246, 0.032424786527241976, 0.042978333442338874, 0.0566745797571327, 0.0336499323935381, 0.046965649484523704, 0.039245440890746455, 0.027584026101976633, 0.003127011458023584, 0.02030438181412007, 0.039469316734799316, 0.046892337168433836, 0.0337094229512981, 0.03341167839244008, 0.032151543867907355, 0.033110154393528185, 0.004329866812830525, 0.02738643840088376, 0.04220636754429766, 0.022991243084626536, 0.013123186172119208, 0.021518557465502193, 0.021883996070495675, 0.009608405309596231, 0.03699648067621248, 0.017531774073307003, 0.0402819099170821, 0.04047817617122616, 0.006201191331326429, 0.002757957109549482, 0.02047748627540256, 0.04542194839034762, 0.027119691018015146, 0.03934623048241649, 0.029612401367298195, 0.09326773243291037, 0.06988634528326136, 0.04700524539553693, 0.06501006694244486, 0.007833495104153241, 0.012981753181000906, 0.017733585654890964, 0.02894120809755155, 0.023491130010890107, 0.046872734291745086, 0.0170338362388845, 0.03144180641642638, 0.02386016145880733, 0.04853190169004457, 0.034499777148344686, 0.008534759349588836, 0.03459098582555141, 0.030956280683832507, 0.03358974973005908, 0.03285454007397805, 0.03335495286488107, 0.01743848398993058, 0.0475984105308141, 0.024945749635142938, 0.04937805860702481, 0.0525561673566699, 0.05589217459782958, 0.05144715954416564, 0.03060247895440885, 0.018678035154672604, 0.04728311566369874, 0.050254121954951964, 0.06865849545491592, 0.03569116250478795, 0.018215189455077052, 0.08522300089576415, 0.03053018104817186, 0.010422001875537847, 0.0631584127300552, 0.040882708571319065, 0.029878790822944472, 0.017514764896727035, 0.05685381478230868, 0.029007389010595422, 0.018240710853465965, 0.02922699347670589, 0.05765508660780532, 0.03982023808306881, 0.010673226921686103, 0.023162283103114793, 0.00858443065746022, 0.05261888434844358, 0.022678324786413993, 0.013467655500530131, 0.04757899764393057, 0.014125690279927636, 0.06740748722638402, 0.05291153310931154, 0.03644422102453453, 0.03231885364013059, 0.014948114586461867, 0.060533160742904456, 0.014259796789182084, 0.031387279342327795, 0.044204113738877435, 0.0187068779819778, 0.03958540389846478, 0.03747803358627217, 0.02095511555671692, 0.027379079688606516, 0.03740442610744919, 0.07628817390650511, 0.05007536190428904, 0.01379797313295837, 0.014040626585483551, 0.020722376348982965, 0.03324080631136894, 0.06501834506967238, 0.043051350595695634, 0.02635019668377936, 0.025667067983054688, 0.013145038392394781, 0.053288951250059266, 0.025132387477372373, 0.05428007717377373, 0.019133208319544792, 0.028071662078478506, 0.00946588157343545, 0.007851803675293922, 0.01652992220728525, 0.049387948254921606, 0.034520876194749556, 0.03936064595888768, 0.008428134356758423, 0.020543400863451616, 0.05327928891139371, 0.0238886175211519, 0.014676807448267937, 0.03497126738407782, 0.07071544043719769, 0.1265901257949216, 0.013011931874124067, 0.05260715587064624, 0.0325551534603749, 0.14473481715789863, 0.13355561345815659, 0.21416653719331535, 0.14965401962399483, 0.08476992270776204, 0.08979868143796921, 0.12565533524113043, 0.13888474607041904, 0.12916500334228787, 0.1323792372963258, 0.16498593906206743, 0.06245903990098408, 0.12809575428920134, 0.09189128343548093, 0.09386552856968981, 0.07313796651682683, 0.1045044284047825, 0.15278340955930098, 0.27029502178941456, 0.11210660583206586, 0.12776709906756878, 0.14504851746772016, 0.11092857404478959, 0.11165494578225271, 0.17170708626508713, 0.1562751100531646, 0.10309815100793328, 0.07570405703570161, 0.13258728970374378, 0.11094705733869757, 0.10811444504984788, 0.07667417890791382, 0.12879450965140546, 0.10101989324071578, 0.09979249124548265, 0.13482346971120152, 0.20775700041225978, 0.11543487438133784, 0.12704272222306046, 0.235222903745515, 0.2643140070140362, 0.14266205552433217, 0.12713592579322203, 0.15150737017393112, 0.0854940213529127, 0.13098429143428802, 0.09840853765074696, 0.15371156404060976, 0.16551526423011506, 0.15260172502270766, 0.14225786578442368, 0.08062633326543228, 0.11388580607516424, 0.1257020863039153, 0.1588446136031832, 0.1368680992828948, 0.08382093720138073, 0.12820353279156343, 0.08280665627015488, 0.12006880715489388, 0.17111771074788912, 0.145153228991798, 0.14114314131438732, 0.16977598917271408, 0.2012321941022362, 0.09234625473618507, 0.1189256656382765, 0.09020381434155361, 0.10358721869332449, 0.23984899265425547, 0.08498396657939468, 0.18459926519010747, 0.2646536002201693, 0.2036746216139623, 0.12197093080197062, 0.15059646405279636, 0.10375326978308813, 0.05852472422910588, 0.14438663369842938, 0.12079796088593346, 0.15852224161582334, 0.1781357577336686, 0.19300792898450578, 0.19156711415520736, 0.16610113850661687, 0.2096160642270531, 0.11616423167288303, 0.10833485357995544, 0.11293087660201959, 0.08858689253351518, 0.10253578796982765, 0.1195489950478077, 0.17074082525713102, 0.12401246625397887, 0.2074570200805153, 0.08468145531203065, 0.16025367299360888, 0.11926344037055969, 0.22544444059687002, 0.16416109832269804, 0.15731591491826943, 0.05823725608310529, 0.09160939284733363, 0.1691689717450312, 0.18323224782943726, 0.11017744934984616, 0.15481715542929514, 0.12378502131572791, 0.18656176488314355, 0.13864512821393354, 0.1040984405470746, 0.10294679698667356, 0.24319349176117352, 0.18057365263147013, 0.21619911598307745, 0.2015847201858248, 0.12931171618402004, 0.1277950004275356, 0.2056616164211716, 0.14464807324111462, 0.10307450406253338, 0.12332478458327906, 0.10877909045666456, 0.11477645114064217, 0.12408903214548316, 0.12667932600847312, 0.1229289136826992, 0.15841541306248733, 0.10512085032782384, 0.09700055034565074, 0.10904977164630379, 0.14625287641371998, 0.10582432829375778, 0.13252600442085946, 0.10084355556006942, 0.1113436949838485, 0.10896697680332831, 0.13528372001435074, 0.16853579000702926, 0.09217271261981555, 0.08042592116232429, 0.18173829013747828, 0.08609628225011484, 0.13412879912980966, 0.14952409373862402, 0.12005771989268915, 0.12341515187706266, 0.10524257951016937, 0.16131743948374475, 0.07359927533460514, 0.08476505761167832, 0.11658542550035886, 0.12819347690258706, 0.13286396914294787, 0.1588015402001994, 0.09869126283696719, 0.18717636833233492, 0.13301966578832694, 0.10555342997291259, 0.07958423918379204, 0.19557212639067853, 0.08709927914398057, 0.08991395775228739, 0.10807815699705056, 0.1149424072355032, 0.13446908444166183, 0.14908470160194806, 0.16692084952124528, 0.10477962185229574, 0.08078625718397753, 0.14454908855259418, 0.1562845009778227, 0.1582911325884717, 0.1343684984104974, 0.14909455393041882, 0.13653303869068623], [0.027768163542662348, 0.06473285824592624, 0.029993307178041766, 0.021486501774883697, 0.011293354494098042, 0.05755701115620988, 0.04302728295858417, 0.012113979834664081, 0.04225675555478249, 0.0030180344931847814, 0.01930477250633495, 0.06195857282727957, 0.032580584952873845, 0.0179283302942557, 0.0574456499889493, 0.013833291728847792, 0.010129437083378434, 0.05661378641213689, 0.016948357789910266, 0.04778561155710902, 0.07847150282136031, 0.08021555495049272, 0.05325333494693041, 0.07048261471624885, 0.0241949557260211, 0.08616179480616536, 0.030634672048368623, 0.018724714971280525, 0.039906853078199286, 0.112263069222016, 0.046051320154219866, 0.0407288202217647, 0.03803635934101684, 0.03707138415692108, 0.06255979556590319, 0.0796732222661376, 0.06939778649913413, 0.042138269769826105, 0.04420742838244353, 0.03991505317389965, 0.02542755869217217, 0.030601135455071926, 0.02488610640700374, 0.021328085900417397, 0.01381948693389339, 0.04492552199267915, 0.01685385312885046, 0.06625086321894612, 0.02520930620708636, 0.01155404934460031, 0.006280554059360708, 0.0030275373761209524, 0.021531609086585895, 0.015215526933648756, 0.04009367073220866, 0.11234040185809135, 0.0705124091889177, 0.0536107329119529, 0.02562923795942749, 0.021236415819397995, 0.08346127971474614, 0.020373073306732943, 0.042720619056906016, 0.04551361847136702, 0.038224059090550454, 0.021022565330245664, 0.04226764264915671, 0.021793774661741087, 0.08190603673990283, 0.05040683304624898, 0.06019844620355538, 0.034812245917107375, 0.037439092461551936, 0.019164995988830924, 0.029639746328549724, 0.006375830554004226, 0.0478022865551923, 0.04395254688071353, 0.030028227982776504, 0.007572721373955054, 0.008065558321374868, 0.04750588210299611, 0.023012114821800163, 0.05903109455747264, 0.08564960264733859, 0.03011608130431601, 0.010820727712208671, 0.013049705918612224, 0.07104226361427989, 0.10371391475200653, 0.10820648153977734, 0.05109808720382197, 0.038848932167249065, 0.009064629041988934, 0.03747153661346861, 0.04113821432526622, 0.06281248879219804, 0.054621563492608924, 0.010860215057618916, 0.05574384005740285, 0.034818386659026146, 0.010589839208738079, 0.05825666218463864, 0.06785573424505335, 0.0344913870628391, 0.022082404798961112, 0.07769971673509904, 0.03920874571693795, 0.07872432496930871, 0.011798405071853526, 0.06925090402364731, 0.033497628423252275, 0.024090059301150695, 0.022997332936418906, 0.0395884064159223, 0.023345635139516423, 0.056335003514375, 0.048423566788967164, 0.02254180014798684, 0.03206740213291986, 0.026178522235048667, 0.056674647610634565, 0.009146207610943487, 0.10058248921164445, 0.05807220243981906, 0.02236202059845839, 0.07130445633083582, 0.06124303050871406, 0.0256136214759733, 0.06557130361241953, 0.03600954809891326, 0.0648850468652589, 0.008532349702103861, 0.01145219021210713, 0.06472374552062579, 0.05236643539475543, 0.027070809355271713, 0.018993808388976113, 0.038482736995709796, 0.022922673728317022, 0.0651091466258679, 0.027562706531690698, 0.02082221768796444, 0.012378353193136198, 0.07887844062809433, 0.011499163495110614, 0.05896807901029076, 0.020560845998781066, 0.06384048970150095, 0.01970768320773329, 0.026363497666482414, 0.021068687051800743, 0.017486705777368376, 0.027633287744330506, 0.03297567893085735, 0.03617291558267815, 0.018956336292571256, 0.03852954234129616, 0.04192798498219677, 0.1274022100759404, 0.029128337877669504, 0.027747259575075338, 0.0348642454482615, 0.06455816262002502, 0.03647038533485361, 0.08958573000771658, 0.04661948127405984, 0.033693331493330855, 0.056114581413567066, 0.0444138760545424, 0.05681084315957768, 0.10563910858971731, 0.02138829740163471, 0.0071425242349505424, 0.06405591099922146, 0.01455954641902021, 0.05604744715882199, 0.05842288290815694, 0.013195448455267718, 0.04393378199477281, 0.06621389663113014, 0.08344786507742745, 0.04757408844307065, 0.002210113660631967, 0.030029004905372858, 0.035533314903399775, 0.037455200882894654, 0.032863588338451724, 0.03730556355523212, 0.031855159771761725, 0.06594806696687426, 0.03365063128460731, 0.05208810033010585, 0.015547520547573055, 0.07434575885002102, 0.05108450632542372, 0.057911593200904984, 0.059732699766755104, 0.07225365896842309, 0.05206507085157292, 0.03601907133789999, 0.057396910818559785, 0.03713835895593677, 0.01535694211322282, 0.09394273228411164, 0.024207349168136716, 0.05196218119402017, 0.05428659789530294, 0.06402990953730685, 0.1226262463522809, 0.036410134817872725, 0.03459116903000644, 0.028303090017288923, 0.0490162976618324, 0.07650932882513319, 0.008753567385221166, 0.008599161652715077, 0.02634996428553547, 0.02495313888149602, 0.04747127681704504, 0.02806483262351581, 0.017956250313935534, 0.05309317693380373, 0.0033331289804274483, 0.0193838184433324, 0.05483814508521131, 0.046509880905172656, 0.026375886019585387, 0.034892034849950244, 0.020225795584597757, 0.02219476510903665, 0.027276551350951195, 0.051110487431287766, 0.02512232310670827, 0.04766173141875437, 0.020014435318963866, 0.03816460585221648, 0.0322832543003772, 0.026877460801707845, 0.03528277263311403, 0.025732843471424918, 0.022604774983067597, 0.036632514492209466, 0.014023616560734808, 0.057023838694606505, 0.043600923248699734, 0.0780468416799392, 0.03385359128671033, 0.05525046367464321, 0.028899661398359706, 0.020250903076625297, 0.014150852054756666, 0.03009624094037073, 0.03324284530909998, 0.022089858506140963, 0.02004304574802518, 0.023642419571323053, 0.0230206813264106, 0.030680164428693906, 0.057920346302645545, 0.05081411012049232, 0.05186220245169742, 0.02433379925787449, 0.005937404905645443, 0.031521398574113846, 0.028879013577742235, 0.012355310992071671, 0.02669376440878425, 0.06022893956729344, 0.052115217982126136, 0.03229885042778083, 0.06382625403680972, 0.031219939036028724, 0.035515432112983296, 0.0041692126209714585, 0.058285201367522986, 0.057880238097693236, 0.00168097328735582, 0.07847368091877018, 0.023721884503694515, 0.028308857564947436, 0.02257017987514181, 0.022064615307109695, 0.032442760919885974, 0.02129640679673425, 0.011945329955779016, 0.07378602174243756, 0.020908717332141738, 0.017818589129352143, 0.027077978077743734, 0.02292158467961209, 0.03351335007963436, 0.06250204545046602, 0.017656617731388127, 0.0857278173789382, 0.043702337092586925, 0.03159163712656923, 0.06342894464199032, 0.036163443233817816, 0.05020617327785917, 0.06234535814395972, 0.004024741913391543, 0.09315476992300578, 0.1079510198906064, 0.034383109837238274, 0.04295715975708195, 0.04157975741795131, 0.05292254573266421, 0.02111175706210945, 0.024336927304310457, 0.04438422407422747, 0.030131270310708454, 0.03031854597585542, 0.02657751439671431, 0.009565252178747739, 0.03806329378858209, 0.059775671389486106, 0.03147755164120879, 0.03222595541072743, 0.08260665807340827, 0.06268421174692256, 0.025592496984505227, 0.035979261688355885, 0.017751448089256883, 0.03317700366356543, 0.025878524939928736, 0.06385329365730286, 0.007493238630039352, 0.008336504139671368, 0.045080244940306456, 0.01703450968489051, 0.11686416768601962, 0.02528470501835857, 0.03136934905446001, 0.027169945017833794, 0.03274444776720234, 0.014322018450392144, 0.028460686560720205, 0.030766650502170836, 0.05608113981517298, 0.011244423637565757, 0.11395098614905562, 0.03562176872843078, 0.05024852404104812, 0.08202858694962092, 0.018908141646534204, 0.05013257258438638, 0.06569034579609122, 0.011761393531092575, 0.03246923057096345, 0.03180292953870126, 0.06045370429222073, 0.16538909742874758, 0.3130374625325203, 0.14117626739399775, 0.13323865618024552, 0.138429123376097, 0.14535893366805144, 0.1415661671864135, 0.045574500025915246, 0.20156745825495037, 0.12658419539885862, 0.10518279378967625, 0.12562746102256434, 0.10377707957689251, 0.13865435629018716, 0.1776181033679417, 0.10260249474751097, 0.1627859521125044, 0.1095667542623622, 0.14855742560965673, 0.09137805311807565, 0.14411393047443458, 0.19438739067741803, 0.15831190933074268, 0.12059279903769493, 0.1332493634628398, 0.20860644483140536, 0.15277076166655335, 0.08655740107808794, 0.14769717891301426, 0.10598814700331007, 0.12305307202041149, 0.15354308379547937, 0.12652414504970821, 0.24604013615420886, 0.17140916867979936, 0.10047424252011947, 0.13769793404000147, 0.15521365058209213, 0.1394372499947037, 0.0915460041058915, 0.05620339825483305, 0.14847976049142225, 0.09368429186620883, 0.136943715225373, 0.12022077185767037, 0.14965730373348507, 0.1180630304983684, 0.1299111611608948, 0.17721707560122013, 0.13186768974576676, 0.17228431600545133, 0.08860539618347373, 0.11422869696148805, 0.12414982888315405, 0.18761014219905647, 0.16705144037093433, 0.09922304430178233, 0.2066939395985433, 0.16806830652058125, 0.07197624671139888, 0.13717265294066497, 0.10163377744278737, 0.06574038096836635, 0.1568276004067489, 0.09277569276413747, 0.07585549248116356, 0.14414582162031106, 0.13271372791911873, 0.13082512068961347, 0.17517830857208797, 0.17387218294399126, 0.17778785925890717, 0.10352553307477917, 0.08887478815657751, 0.08302251183028732, 0.09191123915037938, 0.1350878540958677, 0.07888846259031977, 0.09713584344301905, 0.06931468631540026, 0.07917688747069665, 0.10230539818959576, 0.1578605342656374, 0.17708230497581617, 0.15337739911462578, 0.1229816765657493, 0.11245675025773899, 0.06810408484722887, 0.1295695730618068, 0.1904828151954072, 0.23600378898637636, 0.0968927311311875, 0.15257603568690165, 0.1038637827815754, 0.1660306251474789, 0.10151210932859353, 0.15102616670940602, 0.17562416036214146, 0.09053632364209209, 0.18213025267635072, 0.16923989222518035, 0.15112817766410963, 0.14264920407107898, 0.20191599455262932, 0.08787935692816973, 0.15483713150024414, 0.16592623932021006, 0.16014859506062099, 0.16480774219546998, 0.12440877141697065, 0.21803007487739834, 0.12870445448373044, 0.15267975654985222, 0.10114456726504223, 0.17513372882136277, 0.09862435249877827, 0.1660033616104296, 0.11375149685357298, 0.17008788457938603, 0.09509502723813057, 0.18200795352458954, 0.1465327992503132, 0.11830742524138518, 0.22163357080093452, 0.18827102173651966, 0.16018887289932796, 0.21838998342198984, 0.19336535409092903, 0.1086905144953302, 0.22809057789189474, 0.1373244005122355, 0.17965194423283848, 0.1565854176878929, 0.13200490309723786, 0.175795992570264, 0.14927465069506848, 0.10530136099883489, 0.07904278180961098, 0.11931697678353105, 0.10679085393037115, 0.14500183425843716, 0.15346649076257432, 0.16963820585182735, 0.12339722498186997, 0.23222684594137327, 0.13724345128451074, 0.16032215074769088, 0.10474239742117268, 0.13783520167427404, 0.10157525379742895, 0.14160253666341305, 0.12506441266408988, 0.10432627903563635, 0.10279482549854688, 0.11756186453359467, 0.17130039951631001, 0.146055775561503, 0.11095838887350899, 0.11887328273483685, 0.16546727823359625, 0.06959109434059688, 0.09218051577253, 0.07533268124929496, 0.14728111481027945, 0.07596440413700682, 0.19970884227326938, 0.10255476659429924, 0.12746934433068546, 0.19554635563067027, 0.08800157465572868, 0.14885266976697104, 0.24649147050721304, 0.12950207239815167, 0.07639655630503382, 0.09611681276666266, 0.15610700978764466], [0.009005274191232664, 0.040379215231431384, 0.03117082327870386, 0.024737885521192635, 0.03600916133395263, 0.04043288056605628, 0.04853191865342004, 0.036237783530460935, 0.038696655338363986, 0.03547818393313459, 0.048218381192002974, 0.015710290920521532, 0.01909906104473131, 0.0051879519513542095, 0.013328252177286361, 0.05267465653430138, 0.03234732157683798, 0.01483794764083411, 0.02035878335924021, 0.027393630872081434, 0.009396356330918414, 0.025628447466130768, 0.054277715871908834, 0.04590540459113462, 0.03708454095093267, 0.02295306870447738, 0.016799007143293108, 0.058920920826494694, 0.07525808989469494, 0.09323395495968205, 0.03539123984852007, 0.04769984133807676, 0.04290162166580558, 0.03665094689599105, 0.037809280811675956, 0.03933199821040034, 0.04123532286446009, 0.01432104135996529, 0.026540337463042567, 0.010660206682847014, 0.041002514106886725, 0.04113410579572831, 0.0033455911242137, 0.01772361627912947, 0.038692390745771785, 0.05558703400726829, 0.045668931744460545, 0.01992409347024347, 0.031937394823346815, 0.002910146365008716, 0.07495594503624098, 0.022920923107968907, 0.045180668123066425, 0.028337009982871156, 0.012003613569374596, 0.06532898518655982, 0.056890381034463644, 0.016647369833663106, 0.027445774591927017, 0.03756764431350997, 0.03274016621123467, 0.0299231059450124, 0.021891726280695627, 0.023576688187729036, 0.014000107018676187, 0.03172701843348997, 0.034905880357005765, 0.05689099510865552, 0.016199182186807905, 0.06414201030773775, 0.055304183292069604, 0.04767860319199307, 0.0073648004326969385, 0.043653957545757294, 0.01306147510851068, 0.07043496120188918, 0.009834247208865625, 0.04143190463738782, 0.05760254764131137, 0.015998364659026265, 0.018508294530745064, 0.027267238457820246, 0.017521652027166316, 0.033373090105929544, 0.03883633855730295, 0.03929267371339457, 0.09585640459720578, 0.05845974093036992, 0.02879829505192382, 0.04751539855663266, 0.06686879148972885, 0.022530965640076568, 0.07142503878899983, 0.01959724145542298, 0.0066525795430477175, 0.06920749135315418, 0.04035969377894487, 0.04318352582465325, 0.05109046047021236, 0.029360807367733548, 0.018894577731511424, 0.04633177224812763, 0.017155090446716974, 0.021889144454949667, 0.02523633056054158, 0.040623216424137354, 0.050474764579640966, 0.04283124401367136, 0.04898392475609269, 0.02952214263911758, 0.01964736314091299, 0.01620571987171258, 0.02201487699390522, 0.010446493597035962, 0.01197456124438239, 0.03985273991046207, 0.01465708582795092, 0.011170938295046133, 0.04743831019316401, 0.07359507520283971, 0.07100465920354639, 0.05014566152489611, 0.03459950144003544, 0.03641983447596431, 0.009298527696436005, 0.044655750039964914, 0.003233361432129251, 0.0259475726634264, 0.04892567591741681, 0.037479441546435864, 0.021836278095309223, 0.031943009700626135, 0.0644755849082555, 0.03799676003732851, 0.024182986368292143, 0.007678854428896946, 0.025252854584583213, 0.027403584980805005, 0.039818344970366785, 0.017415627537827407, 0.04603617525260363, 0.00720175270855959, 0.015355110068672469, 0.011670148382628602, 0.044818523805588484, 0.029576422047934363, 0.04417263310668724, 0.00419119673149128, 0.0403947672540588, 0.023567595818479146, 0.03087935856144343, 0.022078024855415736, 0.021974751825577447, 0.01866118034480938, 0.0374824847759945, 0.032708821286048205, 0.02649114197785301, 0.01433342632039317, 0.011328965708214258, 0.012577043513634374, 0.06600396468171052, 0.06785693525203637, 0.05056115905089038, 0.03818483976647258, 0.03195508083860789, 0.017155480604352694, 0.023931845290852443, 0.013461563952400215, 0.07555635353284222, 0.07983747523810182, 0.05838304611721209, 0.04598305613866874, 0.02950016488986356, 0.005870278284419328, 0.029486746859869788, 0.03800096356176904, 0.027833134967035482, 0.023821863246017268, 0.039172722292797904, 0.013647452861602818, 0.06866603397897311, 0.028464048701737608, 0.027069101143362265, 0.01199027950808938, 0.009380126621441116, 0.04755605298227497, 0.027638368275282637, 0.038780596905520985, 0.03294634246932609, 0.029981368354388645, 0.06469437173966851, 0.078093735235078, 0.04637253184669784, 0.04412660129102213, 0.008250761910208633, 0.028396514111331532, 0.020578445500827262, 0.02137469786352345, 0.03788093410964523, 0.04426392660077129, 0.0667288029300315, 0.060542741657367775, 0.012727166842004018, 0.07407715397753886, 0.010435269779658743, 0.03223268308543733, 0.019289970264903138, 0.040949866574789794, 0.038767368865332434, 0.026317109619932513, 0.014465372543781996, 0.02157552896200546, 0.047479680473251004, 0.028996247465589216, 0.033223018515855074, 0.041276469227990935, 0.07157986012420484, 0.05044213383059416, 0.014113842210333263, 0.04803657112643123, 0.08091589129929032, 0.02059485756659082, 0.031230371511940445, 0.05777995740728719, 0.039323899894952774, 0.04341491983671274, 0.05527393759361335, 0.0650222534313798, 0.02540102458026792, 0.019969531567767262, 0.03614815244717257, 0.010447057629270213, 0.015197735745459795, 0.038741903446082554, 0.01561976077833346, 0.042286716268530915, 0.10632024918283735, 0.02532955787942878, 0.032654311175325086, 0.05553833894165499, 0.017851552360558083, 0.025865968649408648, 0.07219061627984047, 0.02431690882492278, 0.014362050320154853, 0.03414962932999645, 0.046057545713015964, 0.019721325154283216, 0.11759949608572892, 0.02982720180547663, 0.013356091620932733, 0.0794473108170288, 0.02125139278359711, 0.08595404095415558, 0.061335623397358825, 0.033040207611130815, 0.0479925579524466, 0.01079768211846905, 0.01004093830540244, 0.06032300487692867, 0.030568715051880906, 0.023301991767116954, 0.0826999159263713, 0.026378104829096367, 0.0709680997367416, 0.032194793689996004, 0.05462078317733748, 0.03968258368383561, 0.04354643010135208, 0.029906841460615396, 0.08094658143818378, 0.016694027597882917, 0.06308093760162592, 0.04852899416748967, 0.012870161311833985, 0.07681729551404715, 0.05642998484628541, 0.06291324445711714, 0.03986926223816616, 0.0702851881672229, 0.0133637132655297, 0.04219320735761097, 0.044878506301237006, 0.05185221102354782, 0.022783745379586304, 0.059867694308715205, 0.049168876438800774, 0.01964233010741217, 0.030457876356584684, 0.015960035912160362, 0.06330538341509444, 0.014786219523687447, 0.03596054429986647, 0.040329054530177794, 0.08003876265138388, 0.0021971318014298697, 0.030459582872156585, 0.08156248767461095, 0.034490756025271754, 0.018936540033402186, 0.045269698702863286, 0.0749790830803769, 0.021908513237056986, 0.06275534257292747, 0.06429451783852917, 0.022054998769557903, 0.01372930284456483, 0.022281261360538856, 0.029638752274747406, 0.02526892059748726, 0.007839562903557504, 0.011356426868587732, 0.0337133889884821, 0.03468695103323885, 0.044242885229843, 0.009589490297782634, 0.02664884878322482, 0.051506490646196265, 0.0610767894291452, 0.015188975858369043, 0.027336367605520145, 0.02249828739357846, 0.076204083061644, 0.05644925184813993, 0.05014832138216921, 0.015000412673024195, 0.030322257562407424, 0.06154831698430436, 0.048375156708061695, 0.061416681190686565, 0.06364806395556245, 0.021717069670557976, 0.06829404072569949, 0.015097438091678279, 0.04034848777311189, 0.05703404386128698, 0.030030724991645132, 0.010875116534797209, 0.009874962702659624, 0.035713113112641234, 0.047187632215874534, 0.02087803228226091, 0.01160986054622169, 0.017138919260885035, 0.05004299578389951, 0.056629636990172524, 0.03552783912579928, 0.06350215857050248, 0.07270567864179611, 0.00453989884616541, 0.051091742901397605, 0.042243198425109894, 0.1378090509346553, 0.10736747298921857, 0.09993827449423925, 0.13305094625268662, 0.15198547951877117, 0.24726204201579094, 0.1456176590706621, 0.0809998871492488, 0.06628766017300741, 0.15144489066941397, 0.11879568547010422, 0.1637032771749156, 0.07287358213216066, 0.14563232899776526, 0.16079609388751642, 0.08314933002527271, 0.11426204017230443, 0.1093711122604353, 0.12240456896168844, 0.07215679130916085, 0.0639292285112398, 0.2724275759288243, 0.16290682634072645, 0.18119230014937265, 0.16318092734685966, 0.184241066553763, 0.04354784484686596, 0.13579073495098523, 0.161171323752829, 0.2677979857793876, 0.12581637874245644, 0.136465280183724, 0.11263278259762696, 0.13849616263593945, 0.11518946183579308, 0.11442985545311656, 0.16967365252120153, 0.07512002158910036, 0.08368001226335764, 0.12665987919483865, 0.17683392044688973, 0.1026877798140049, 0.17884524751986774, 0.14283030506755623, 0.1619618306202548, 0.15753825727318013, 0.10245899137641702, 0.13500946973051342, 0.09221851373357431, 0.12421990797988006, 0.18604814101542744, 0.15772420300969056, 0.12169107581887927, 0.1109260023970689, 0.09290957450866699, 0.19329123092549189, 0.09323815509144749, 0.15315110768590653, 0.12150517079446997, 0.1657086331397295, 0.06961833073624543, 0.14680723952395575, 0.12466060290379183, 0.18561176157423429, 0.09054597919540745, 0.13861388846167497, 0.20522256355200494, 0.07824681952063527, 0.09326950340930905, 0.17647075493420872, 0.13195816560515336, 0.1269118735300643, 0.16812188364565372, 0.088660276095782, 0.15318390806870802, 0.2352364201630865, 0.09874081624937908, 0.10662514889346701, 0.17487607550408157, 0.05142265764464225, 0.06382761110684701, 0.0998452812699335, 0.0978816891355174, 0.11323507742158004, 0.1747249657554286, 0.1674755790403911, 0.1850162928125688, 0.12197376707834856, 0.09492651985159942, 0.19141916637974127, 0.15382557149444306, 0.09439519300524678, 0.11968462062733513, 0.0975109376013279, 0.12399775561477457, 0.14283159428409167, 0.1511822161929948, 0.17188844510487147, 0.12207556090184621, 0.09351746724652392, 0.09699972931827817, 0.16763544189078466, 0.13944475459200995, 0.20003770105540752, 0.14366714230605535, 0.15617814739899977, 0.10592852413122143, 0.10642656204955918, 0.13374584753598484, 0.11725615736629282, 0.17715241121394293, 0.059448176462735446, 0.0827659305983356, 0.14978562827621186, 0.12447304225393704, 0.0891760102074061, 0.11406126166028635, 0.09894725374345269, 0.21916354048464978, 0.1156332508793899, 0.17484920551734312, 0.2018898031009095, 0.16380498957421097, 0.19525871106556483, 0.07999115663447551, 0.2026709054729768, 0.07853187208196946, 0.22732797238443578, 0.15182054122643812, 0.16035153131399835, 0.08035394216754607, 0.09852937795221806, 0.10707309057137795, 0.1722767978374447, 0.08506933307009083, 0.06930059992841311, 0.15228826898549283, 0.11455613082008702, 0.09144598125879254, 0.1424132367329938, 0.3488837076084954, 0.07970801754189388, 0.10603841287749154, 0.08324604840683085, 0.1114754800551704, 0.08422854675778321, 0.16373493761888572, 0.1914716171366828, 0.2130615022033453, 0.1450751567525523, 0.10131540881203753, 0.12904061430266925, 0.10809790236609322, 0.13145572399454458, 0.2572716006210872, 0.08263659503843103, 0.08066243811377458, 0.21625143103301525, 0.17859120400888578, 0.18822830117174558, 0.17673809773155622, 0.13498652167618275, 0.10574792525065796, 0.13202008871095522, 0.09512696588145834, 0.06243734713643789, 0.11891556903719902, 0.05896674908165421, 0.17112418397196702, 0.1431939455547503, 0.17531888745725155, 0.16503859337951454, 0.09257051055984837, 0.08426659221627883, 0.12053448573819228, 0.10386093293449708], [0.04459456993000848, 0.018633720032604675, 0.04872237664780446, 0.06109907251915761, 0.046505650239331384, 0.028914015806679214, 0.030116142372467687, 0.028509524118687426, 0.024009844587583627, 0.04489379030253206, 0.005346765616975192, 0.01571812291097428, 0.034202419354447296, 0.04748253032032933, 0.044219265425843854, 0.02143064816482365, 0.03971076324316008, 0.048724802410496135, 0.03816135906215225, 0.01613996982840555, 0.002685645844654313, 0.12961869899715694, 0.014643516823915499, 0.04534442237179194, 0.03109269675665668, 0.014137590935985957, 0.007555493369831571, 0.044474754216415543, 0.026642696166943227, 0.01967443329548197, 0.04591732305873718, 0.027012684349236742, 0.02199693992068725, 0.005899546044279954, 0.028880058521670953, 0.027472162818802253, 0.07049592757331473, 0.05904468561389616, 0.016672645263107758, 0.057245841782007895, 0.04656658268400601, 0.05996013113430568, 0.05138187769002148, 0.028787458847676004, 0.057118915021419525, 0.03777333202638796, 0.03966223781130143, 0.020354437342445766, 0.06407822801598481, 0.06840880813875369, 0.01923336517730994, 0.016370349430612156, 0.011885323711404843, 0.04162629134953022, 0.0529333955076124, 0.03796020396319883, 0.03663926252296992, 0.012975971214473248, 0.007986352928648037, 0.009734509346474494, 0.04741988457473261, 0.04728997904541237, 0.045569692605308125, 0.054358461539127996, 0.018072756472975016, 0.006405836644782019, 0.04780535353347659, 0.040481826689626486, 0.024417130143514702, 0.011901505923430835, 0.04478493971484048, 0.026197054722745503, 0.02429816429503262, 0.016567160209108676, 0.0138551015406847, 0.04109448613598943, 0.04045527222167168, 0.018420963681169918, 0.03642404139307993, 0.012272348211679076, 0.10066213565213339, 0.021089395940569893, 0.07788010526980672, 0.021616734697350433, 0.03173164604231715, 0.1244636241878782, 0.02248899994551071, 0.08760749508759805, 0.018648571467825344, 0.03917555517650076, 0.023232496210506985, 0.067436413174229, 0.04498852736183575, 0.03335894265079072, 0.024120167596265674, 0.03110349903415356, 0.024669168583516563, 0.014328649433861886, 0.01946757680603436, 0.0263689513916948, 0.03945735416242054, 0.022571993259979144, 0.08215298277458974, 0.03735136466899088, 0.05356891819142869, 0.07423636543431453, 0.006744413744724754, 0.0365465474980218, 0.027093004235731702, 0.04798481926055891, 0.04064288376165288, 0.009857049378167306, 0.018866935911189233, 0.016013221183259572, 0.04595188423991203, 0.06828839531434433, 0.01604778745344707, 0.053528986405581236, 0.028605102561414242, 0.0303070583779897, 0.01884996235769774, 0.051857981963881424, 0.053822303523442576, 0.021624726143532565, 0.08149010155882154, 0.08844638150185347, 0.08644078804978303, 0.028640318528882096, 0.043199159271482906, 0.018262841273099184, 0.016862875948260938, 0.05087032674678734, 0.031096635652439933, 0.0600115301619683, 0.015072685134197985, 0.0751864230260253, 0.022976384864055684, 0.02486075464236949, 0.07961363332079989, 0.040482013286756616, 0.02492896607145667, 0.04361838874007974, 0.057181679510644505, 0.06283375407968249, 0.04548317599775536, 0.03904765471816063, 0.0200120858914618, 0.016644984783072556, 0.009228332400588053, 0.07224392877625567, 0.02829307653675122, 0.06116152488227401, 0.014134876795911362, 0.004769890411158225, 0.04274269858641284, 0.008636378450319171, 0.05057940825021692, 0.13788374406950815, 0.019351674543161477, 0.07105083351156541, 0.027118720712938478, 0.03850051800587347, 0.030573929593499218, 0.01569656246075673, 0.06948216232870306, 0.021451182330825498, 0.05963258871010371, 0.027475340059027076, 0.022346753560538803, 0.051134504178272824, 0.03279513433309538, 0.027239713684788773, 0.03579844567658646, 0.01736505632288754, 0.020845499920791814, 0.03929313172453216, 0.061440986315054555, 0.021641619969159365, 0.028049552014895847, 0.04050710890442133, 0.038774666509457996, 0.037062152687992365, 0.026971736457198858, 0.028311308772702302, 0.0270961696015937, 0.01925091039655464, 0.029983923038733856, 0.04508448239149792, 0.03056036228580134, 0.06106031459889241, 0.08396239139671836, 0.01913108959394906, 0.04356544265257461, 0.020951604137995412, 0.051113890284406285, 0.0328804702897157, 0.01872840620178197, 0.0642259790162955, 0.04518348404339381, 0.02967172229130353, 0.011850100958586803, 0.014903862228883165, 0.026818519857312952, 0.04495276856635298, 0.047615682639713795, 0.07046669628471136, 0.024575741096798862, 0.040120055566408803, 0.04843526134001357, 0.010698650780666088, 0.02377060501437102, 0.06145283353648015, 0.022048506885766983, 0.04435577310089554, 0.06099692585745028, 0.07711044978350401, 0.04350922941895468, 0.06741932766245944, 0.03605008378092732, 0.08948057065052645, 0.05646726356020995, 0.047280160643692525, 0.03269788669422269, 0.03759785608521529, 0.01983182967108275, 0.02728149787123714, 0.011166106277544583, 0.025042449356988072, 0.03898814380435007, 0.02716416729215, 0.015428278196070875, 0.02784706020195569, 0.051323791699750085, 0.022243363483409797, 0.0065558166326289725, 0.029364722514791147, 0.028391199485797967, 0.012083421161930476, 0.020374077538560544, 0.031209150329232216, 0.0688522443441408, 0.05212556564116052, 0.07749210537544318, 0.019901484683422104, 0.054379580941583426, 0.05748613817351205, 0.015965124924800227, 0.06007897654282195, 0.01480872483391847, 0.06826342522565808, 0.02489160593332989, 0.035140171713594875, 0.043062970507889986, 0.01992144888000829, 0.039197923083390505, 0.0315945683978498, 0.06105612125247717, 0.05178325150960258, 0.042558890235211165, 0.038702436456722875, 0.009204101066903343, 0.05779008793511561, 0.001685362242694412, 0.03608972379671676, 0.01902679706524525, 0.05917875734823091, 0.11412237052406583, 0.03512777148612908, 0.0104400856819536, 0.015187298180535436, 0.06524772383272648, 0.015767067338206937, 0.04557441520903792, 0.04120688885450363, 0.07524245644786529, 0.04414540010371378, 0.01702706445939839, 0.026120873899864297, 0.06544218518372093, 0.06146310655666249, 0.06850617791392974, 0.0318984978034028, 0.02139021595939994, 0.0250062647807811, 0.02298505654159401, 0.059683329558798244, 0.047550539885248454, 0.03449325642681547, 0.013564641055251871, 0.02305832475290767, 0.011799537377165896, 0.0519640234165958, 0.059580382225768905, 0.03263534951422896, 0.08057208439069134, 0.024079533526673913, 0.01531765323930553, 0.04606052787442293, 0.03567923725183521, 0.023950291265334402, 0.05714909625904901, 0.0327662592753768, 0.03317004867962428, 0.044788912537374666, 0.022108489381415502, 0.041991098916956356, 0.006278786051552743, 0.03341859944963029, 0.023274936879585897, 0.018964794231578708, 0.0326723771701966, 0.062037452523197444, 0.014563919577215399, 0.029553803083087717, 0.07075005250849895, 0.016055633014600192, 0.05940192751586437, 0.09459482479308333, 0.03778260760009289, 0.01842619857883879, 0.03117744578048587, 0.039730569680354426, 0.04540074077833976, 0.00843966521123158, 0.03426392176853759, 0.02434153964609972, 0.02452689336080636, 0.00957995857710817, 0.043404161663992066, 0.00833543375067945, 0.02421403782708304, 0.034538484178483486, 0.05245811565380011, 0.07018230190234524, 0.054497493364449055, 0.01831141589874668, 0.021393863085125173, 0.030241932586899826, 0.06952134772603001, 0.010654378067036825, 0.0332253119642181, 0.033024418101246865, 0.03435401086296354, 0.030902571244431392, 0.016821780474856496, 0.04703369297619377, 0.026925214399982775, 0.015849850306819593, 0.011017937130028648, 0.019911058812535236, 0.003968748355483902, 0.02641276779052402, 0.25998582211988314, 0.05071615680520024, 0.12743986876947538, 0.17834385085318769, 0.16847977015588964, 0.15298060540642056, 0.11248826820935522, 0.11548497740711484, 0.15802013927272388, 0.07558468915522099, 0.0905748780018517, 0.09829461162111588, 0.14237586302416666, 0.14122334415359156, 0.16883224195667676, 0.1058844125696591, 0.12284113839268684, 0.11190936248749495, 0.14450939425400325, 0.0809322711346405, 0.06703694603805031, 0.16706114342170103, 0.1434350154761757, 0.13051037543586322, 0.21259073460740702, 0.11793081116463457, 0.11403276318950312, 0.1410550946103675, 0.13157083067510808, 0.18721048507307256, 0.16284030276749814, 0.12120029143989086, 0.16070880714271749, 0.07997325009533338, 0.14221762865781784, 0.17594004555472306, 0.20437968735183987, 0.19082391474928173, 0.12355630073164191, 0.2326686265213149, 0.17239134811929294, 0.12345757388642856, 0.12780105295990193, 0.23673082568815776, 0.16727956384420395, 0.13581281448049204, 0.20259501811649117, 0.10351578252656118, 0.1490919076438461, 0.14725640256490025, 0.07462536956050567, 0.12729245025132382, 0.16070612014404365, 0.07836687950683491, 0.08221208996006421, 0.17495512483375414, 0.16135625168681145, 0.08226120911006417, 0.0936570961826614, 0.07297756083841835, 0.14302990292864187, 0.07505122492355959, 0.07214945634560925, 0.13493907850767883, 0.10199426952749491, 0.09088741123144116, 0.1547391510435513, 0.12087061841573034, 0.1215695637677397, 0.1421996203384229, 0.12026810646057129, 0.20878166971462114, 0.09488357537026916, 0.1972806639969349, 0.20352865516075067, 0.08816161392522709, 0.1534251408385379, 0.07722910520221506, 0.10399362045739378, 0.1198071369103023, 0.17358414482857498, 0.14908261171409062, 0.158605335014207, 0.11704678860093866, 0.08167270211769001, 0.19670348853937217, 0.12213643906371933, 0.19791684485971928, 0.12380946214709963, 0.11770959517785481, 0.13053474841373308, 0.15407067191387924, 0.08515689801424742, 0.08315168454178742, 0.13027067615517549, 0.09155470292483057, 0.1618161762931517, 0.10464844067714044, 0.15977192670106888, 0.18282640246408327, 0.1518348040325301, 0.07225455463464771, 0.17081337422132492, 0.14740234187671117, 0.17830114385911397, 0.11956350212650639, 0.1253394636192492, 0.1551648367728506, 0.0795409350789019, 0.09990537911653519, 0.13379890897444316, 0.10635093932173081, 0.17287792558116571, 0.07975738774985075, 0.10942299304796116, 0.14930690824985504, 0.11980819542493139, 0.17590301111340523, 0.13562752013759954, 0.18572342129690306, 0.12039123342505523, 0.17640714906156063, 0.14039023885769503, 0.07835274562239647, 0.12260779019977365, 0.14649120505367005, 0.13365336321294308, 0.17652460347328866, 0.13953737462205545, 0.08986250444182328, 0.10362489095755986, 0.1122720055282116, 0.14169215756867612, 0.19607785211077758, 0.11447030971092836, 0.17454185629529612, 0.11463524800326143, 0.11558402994913713, 0.1812716887465545, 0.13471067004970141, 0.12882409377821855, 0.1611491899405207, 0.26402345831905094, 0.1640110606593745, 0.09469714108854532, 0.15766143852046557, 0.10275207100702183, 0.09352849344057695, 0.1544013898819685, 0.06074769315975053, 0.06855749551739011, 0.11703723482787609, 0.13160709158650466, 0.04800434071304543, 0.08137259964964219, 0.21878855489194393, 0.10957556843225445, 0.21005093732050487, 0.1304556176598583, 0.08206739915268761, 0.09244701718645436, 0.12488641935799803, 0.14843830200178282, 0.07598125216151987, 0.09517628180661372, 0.08492105281246559, 0.09154557662882976, 0.09884162619709969, 0.17684199501361164, 0.18651031835802964, 0.15593494687761578, 0.061254599530782015, 0.08213717969400541, 0.1344724092632532, 0.16018738012228692, 0.09101435834808008], [0.018439764190199118, 0.021092517201655676, 0.03949987116668906, 0.00999716601134943, 0.005613679240923375, 0.02989582883726273, 0.036227798887661526, 0.04780572333506175, 0.09717634519828217, 0.02712272576588605, 0.0183318618551961, 0.03641700837761164, 0.03132972600204604, 0.03286981389724782, 0.025477061214457666, 0.01877417169245226, 0.05733821753944669, 0.03453520006899323, 0.008771198269511973, 0.02858463115990162, 0.08057473746261426, 0.03254163365012833, 0.028323591952877383, 0.05922721153391259, 0.06692016337599073, 0.012753237853758037, 0.069517235803817, 0.07387338312608854, 0.038993185319538624, 0.03746621011357222, 0.029953419496970515, 0.030166496456201588, 0.05003794069801058, 0.02882860181853175, 0.03517799325553434, 0.0529854052167918, 0.0773031876555511, 0.021680481366014907, 0.029234382723058974, 0.04135759487482054, 0.0069823140594443035, 0.05319324049300381, 0.035447741459522925, 0.06394658543701683, 0.03136439914149897, 0.004518318888066071, 0.014245099720678158, 0.05887182881789548, 0.05434894847816654, 0.022979677455233674, 0.04971798090264201, 0.024774071793737154, 0.006644247557103101, 0.07306778563984803, 0.03152084217539855, 0.033659241893993955, 0.0005813042901406464, 0.029755870811641216, 0.042673535511962006, 0.0186800215659397, 0.0402612315623888, 0.02777588357483702, 0.021831747177722197, 0.033053754562778134, 0.06040840529437576, 0.029902393663568155, 0.01978088865455772, 0.05512755384136524, 0.045477327025894604, 0.07059789781591722, 0.007300454956878508, 0.043357125616499355, 0.04245610235791121, 0.030048095488122532, 0.018223253843773688, 0.01622660517958658, 0.04455103851588709, 0.01773524297667401, 0.011704823218419083, 0.022747075650840998, 0.050596140923776796, 0.018122547372643436, 0.04415638219299061, 0.02123562023708863, 0.019026435745347823, 0.023309219861403108, 0.017072916463283554, 0.05521403652216707, 0.08443436678498983, 0.01808982841404421, 0.060625801129000526, 0.049500452753688605, 0.012117024760560265, 0.023831232118287256, 0.02049686523553516, 0.007777225043225501, 0.027987023316589848, 0.049564136657863855, 0.04904354762818132, 0.04890702298975416, 0.05041164725220629, 0.025630552621026124, 0.010781186083996934, 0.03034724122179406, 0.047169657823230536, 0.03102039885041969, 0.018638892165784324, 0.02145110090662326, 0.05143755488097668, 0.0471251459260072, 0.07555383616792304, 0.02215420567829694, 0.024587155752150074, 0.008440872155396002, 0.01811202838351684, 0.0396504075532513, 0.03462881754551615, 0.0315147964283824, 0.013043742443967079, 0.025033000756853392, 0.04150644510186144, 0.03386001701333693, 0.04287114187276789, 0.04378163069486618, 0.039785005152225494, 0.030251988475876193, 0.018441782831879597, 0.05991493391671351, 0.05165432307070919, 0.04310539930260607, 0.012934920694013792, 0.011830720302116658, 0.04903629408883197, 0.06572066274072443, 0.02720695062141333, 0.011384619998612573, 0.04796296704028334, 0.01794127165339887, 0.08906209774847541, 0.053339437648121796, 0.025457129248284867, 0.03940941905602813, 0.03454572753980756, 0.03515039384365082, 0.051031200614358695, 0.042711268844349046, 0.01620805572851428, 0.076866665722004, 0.025354210752993822, 0.030513058216976266, 0.027785852950598513, 0.034472761276577196, 0.02900231017598084, 0.024897565167131167, 0.018501110541235124, 0.03830655537811773, 0.018111056382102624, 0.04083172684269292, 0.0273039098829031, 0.07062942933823381, 0.023075255897960494, 0.011787759705579706, 0.06517242680170707, 0.012466013132195388, 0.019195440158780133, 0.014788551987814052, 0.06756350278322186, 0.03700627532920667, 0.01480064178550882, 0.03693463560193777, 0.03065977445138352, 0.044711237241114886, 0.030256337885345732, 0.04408665254179921, 0.04200083589447396, 0.051957618046019755, 0.013688260805793107, 0.05840746659253325, 0.010176671602364098, 0.044904931847538264, 0.02228341910189816, 0.0422510287192251, 0.009934748423152735, 0.058813725864248614, 0.010605753399431705, 0.03350642562976905, 0.011090888974389859, 0.0679903013099517, 0.04285604107592787, 0.05879821455372231, 0.05256579576858452, 0.05236562454540815, 0.04538221337965556, 0.006984873832802155, 0.0016534501046407968, 0.03984351861955864, 0.050692760917757235, 0.010305416836802448, 0.04071914431239877, 0.04724605068830507, 0.019624703463965228, 0.05759422880198274, 0.051160006916948726, 0.04162527693967734, 0.029780148794608455, 0.011568261260565902, 0.001421503086541114, 0.016752732751358832, 0.04396744750972305, 0.046630561750914366, 0.013356362186771418, 0.03794624989054032, 0.08521186613610812, 0.024895583844876716, 0.024704304823119725, 0.04252601182088256, 0.06082479509391955, 0.023755266730274473, 0.05095718940719962, 0.03157662453928164, 0.038015881154154024, 0.030448522751352618, 0.030215303480092968, 0.04627830368865814, 0.02787276141212455, 0.023691080710185424, 0.0420555868851287, 0.016333128392164196, 0.055748454095529656, 0.01582522627099284, 0.00976468634326011, 0.0207907353594367, 0.02536980518405991, 0.04551738773339561, 0.022957933800561086, 0.0433545403980783, 0.029163730264242207, 0.068513573945633, 0.018027231862236346, 0.0215844958022769, 0.033452767080494335, 0.01710883471449571, 0.07982083755944457, 0.05060563362868769, 0.07888549060693809, 0.060352466867438385, 0.026284828316420317, 0.030046297370323112, 0.0159316527923303, 0.043920560739934444, 0.03160384736422982, 0.0083975095268605, 0.01891206357894199, 0.00800336804240942, 0.03256934841296502, 0.026572476274200847, 0.04890630713530949, 0.019266959446083223, 0.034389345574059656, 0.024584791057610085, 0.009512115253268607, 0.07711430386240993, 0.02850119849400861, 0.08143699940826211, 0.04407752285312329, 0.073363599766578, 0.016549613293526427, 0.028216639566900473, 0.03070147382095456, 0.03598919204835381, 0.020181058074480722, 0.03114791932914938, 0.011767711540284966, 0.04047938057088426, 0.03944791913298624, 0.022330063295417597, 0.027430929942056537, 0.01331891299092344, 0.05128349011231746, 0.06719774526676961, 0.025589501252397895, 0.009897600327219282, 0.017462610998856168, 0.07252989057451487, 0.050293673761188984, 0.09206891033266272, 0.03023498778098396, 0.05586001882329583, 0.01753491229776825, 0.009539171837137213, 0.05324830021709204, 0.06590356185500111, 0.0049726710255656925, 0.03914620514426913, 0.018899512377434542, 0.08054370805621147, 0.05399746733850666, 0.019062627106904984, 0.050806524098983834, 0.05482555486794029, 0.020665469313306466, 0.02345912521039801, 0.03392469157863941, 0.009662377681317074, 0.0600434077371444, 0.020427703857421875, 0.01640940590628556, 0.016465554679078714, 0.029295824068997587, 0.02576199163948851, 0.008153035055979021, 0.03038824848564608, 0.03302799058812005, 0.014653610032317894, 0.0703239528728383, 0.03316907158919743, 0.024600093718618155, 0.020632526438151087, 0.03776210905717952, 0.01251218659204564, 0.020189604223040596, 0.035114957352301905, 0.012157181311132652, 0.014338249008038213, 0.03676446919728603, 0.03420285700953432, 0.023177478894857422, 0.0317640528748078, 0.029101138801446984, 0.05739388455237661, 0.014522656166393842, 0.02723494019093258, 0.021857589183907424, 0.02680446400440165, 0.0206111576740763, 0.00921249624142157, 0.01998013028475855, 0.03474238395158734, 0.030546455710594143, 0.048451987228223255, 0.05640920131866421, 0.10649471410683223, 0.0252294654824904, 0.02818040070789201, 0.030799176078289747, 0.022213528298639824, 0.03034374676644802, 0.010998973772594971, 0.02963947830721736, 0.03764689041833792, 0.03340081165411642, 0.07613728807440825, 0.10659916778760296, 0.15410359443298408, 0.11751865542360715, 0.09425451912518058, 0.131838662017669, 0.12771097065082618, 0.12189722832824502, 0.16897491072969778, 0.12947677661265644, 0.10028544693653073, 0.10706579631992749, 0.13420616569263594, 0.10796917748770543, 0.15248737830136502, 0.14287388058645384, 0.1309377032199076, 0.12169815972447395, 0.18982425624770777, 0.1304297111928463, 0.17357843156371797, 0.11435676366090775, 0.08430888530399118, 0.07984468127999987, 0.18901456040995462, 0.13815373315342835, 0.0937641757939543, 0.11177232555512871, 0.09454255724059683, 0.0757819324997919, 0.08797599388552563, 0.11959114564316613, 0.10063086197312389, 0.17238610982894897, 0.12823390401899815, 0.1442881646965231, 0.08581435094986643, 0.19896747491189412, 0.10222996545157262, 0.056480552668550184, 0.11384342477789947, 0.07231658630605255, 0.09217693989298173, 0.18239028086619719, 0.11283444320516926, 0.06975135074130126, 0.16319642508668558, 0.19771477713116578, 0.1513223743864468, 0.11416274335767541, 0.11828525071697575, 0.19691584285880837, 0.09362532717308827, 0.15677771451217787, 0.1512292522404875, 0.09260238134967429, 0.0906390334878649, 0.12376515381038189, 0.1807309099073921, 0.13117626256176404, 0.13954797333904675, 0.14094948742006505, 0.13938602060079575, 0.24009445948260172, 0.10675597723041262, 0.1934302356094122, 0.12578918305890902, 0.18680090776511601, 0.10925405139901809, 0.16663404633956297, 0.17971597079719814, 0.11435185106737272, 0.08661547010498387, 0.1008446208600487, 0.1566310559532472, 0.11422434076666832, 0.09135069458612374, 0.12689109678779328, 0.10962261805044753, 0.13792103635413305, 0.09768762812018394, 0.14080878639859812, 0.11494427999215466, 0.13885837819959435, 0.08800869927342449, 0.1278467047959566, 0.25295991769858767, 0.16114043683878013, 0.2043700792959758, 0.21290329497839722, 0.12735912310225622, 0.11627913479294096, 0.11466290509062153, 0.07920431385615043, 0.11393434847039835, 0.09706073640180485, 0.14493688488645212, 0.09167756526065723, 0.12359106886599745, 0.21442402766219207, 0.10236333150948797, 0.13620061081434998, 0.17469733580946922, 0.19498083740472794, 0.24592986064297812, 0.11951113279376711, 0.11897114105522633, 0.08351118596536772, 0.12129226007631846, 0.16124081930943898, 0.14409953196133884, 0.11804679994072233, 0.193544297346047, 0.053979374202234406, 0.05849081104887383, 0.14180389871554716, 0.10596996226481029, 0.06029247080108949, 0.1014722657522985, 0.07520888253514256, 0.14650843984314374, 0.14413306516196045, 0.14079502570841992, 0.12575175506728037, 0.14261966065636703, 0.10917089014713253, 0.09532891825905868, 0.08693592183824096, 0.13714258026863846, 0.15619832703045436, 0.11220514947282416, 0.1736907698214054, 0.17672417419297354, 0.12692388359989437, 0.13617165093975409, 0.07374954369983502, 0.1288082974829844, 0.10439131661717381, 0.10857507533260755, 0.2553047447332314, 0.12111641094088554, 0.10218091415507452, 0.09233627348606076, 0.11856007097022873, 0.11480862727122647, 0.18601775621729238, 0.11070376182241098, 0.11923224133040224, 0.20457218773663044, 0.17795148119330406, 0.07044650986790657, 0.11509684180574757, 0.16896005081278936, 0.053130364045500755, 0.13024951943329402, 0.1004842576969947, 0.10572093312761613, 0.10754123902214424, 0.1334303016109126, 0.10924958663859538, 0.12441345330859933, 0.13333327110324586, 0.19238527810999326, 0.207537494333727, 0.09576305174934012, 0.12029112236840384, 0.10961039763476167, 0.17530861443706922, 0.08461871796420642, 0.1277576945722103, 0.09061249598328557, 0.14208507005657467, 0.1047336511047823, 0.12895522745592253, 0.15988699266953127, 0.13138696125575475, 0.11563711852899619], [0.007879390364645847, 0.048358278149472814, 0.017388131602534225, 0.024596528017095158, 0.02696383322056915, 0.0349559664194073, 0.018554726682071174, 0.09198416809418372, 0.010055365656236452, 0.06227284989186695, 0.04863382104252066, 0.04954752612060734, 0.01616917227927063, 0.01531715112339173, 0.03103970656437533, 0.08394622869257416, 0.09464345539786986, 0.004637638422926622, 0.02262029986429427, 0.04240742764834847, 0.017672585356714468, 0.05319501825475267, 0.031597367354801724, 0.057525092868932655, 0.06481165651764188, 0.053744679117309194, 0.02355962133567248, 0.007653206653360809, 0.04823194171435066, 0.05725243714238916, 0.058117976412177086, 0.0398585515628968, 0.05355840768398983, 0.01681554304169757, 0.022333795238020163, 0.1094114783086947, 0.029561819974333048, 0.02707540473368551, 0.02287749177776277, 0.023826942080631852, 0.017618786011423384, 0.035914142682616196, 0.02301093756354281, 0.029077603814325163, 0.02878196271402495, 0.03681840933859348, 0.09114389746849026, 0.05360012062426124, 0.06378081254661083, 0.016063246177509427, 0.07577577140182257, 0.024852503656542728, 0.07437434553035668, 0.045142653198646646, 0.025606539266716157, 0.021717444561155777, 0.015490182642159718, 0.06337342690676451, 0.02380916615948081, 0.012097075831012001, 0.056413374309028895, 0.012484851808819388, 0.06048284737127168, 0.022965175465547612, 0.01668651621522648, 0.021005025200013603, 0.023230341861822774, 0.0506008601348315, 0.01844759109163923, 0.029819843093199388, 0.03635171973811729, 0.050128559049751074, 0.06268712266215257, 0.05091275554150343, 0.07632777999554362, 0.027573398547247052, 0.00575763892681737, 0.043450495427740474, 0.022710163345826522, 0.016307464501421367, 0.03134109824895859, 0.06013705914041825, 0.049575081427714655, 0.08497363249106066, 0.011222454369999468, 0.0030627912991414113, 0.042392448987811804, 0.041311749656285555, 0.010879416750477893, 0.01661685441753694, 0.04183854728138872, 0.01731056147920234, 0.07384567854127713, 0.02411509385066373, 0.05567162696804319, 0.025416722487924353, 0.059685745143464634, 0.005627885643791939, 0.026345156864928346, 0.0171723710373044, 0.03759536586169686, 0.022805068342547332, 0.014556749158405831, 0.049689848840768845, 0.09455056395381689, 0.030494540996317352, 0.01229931743416403, 0.07816314936748572, 0.015083512856758066, 0.05636933060096843, 0.04595092750553574, 0.034373179477240355, 0.06256327645054885, 0.06278110654758555, 0.030256039329937527, 0.047588334285787175, 0.021023927489295602, 0.02201303986034223, 0.07667665556073189, 0.05538982119677322, 0.035193263686129024, 0.04211853797148381, 0.028703293363962854, 0.04572374719594206, 0.02655765028404338, 0.05430305915485535, 0.04441840527579188, 0.041084660948919396, 0.05223773765776839, 0.01364832986811442, 0.057576071204883714, 0.03442263450207455, 0.009350759625834013, 0.019511586587343897, 0.11325800511986017, 0.05330562624814255, 0.039953451470604966, 0.02161704682345901, 0.040466912489916594, 0.048587317645017586, 0.01914833965046065, 0.04085031870220389, 0.03014130923630936, 0.03550455519663436, 0.04585221762369786, 0.013413278552304422, 0.05128065383593951, 0.028854257227586846, 0.05044058337807655, 0.021874532203323076, 0.01978339923412672, 0.03116315583299313, 0.0499243200091379, 0.03046806455988969, 0.015167534151779754, 0.0422895864716598, 0.014329131193725126, 0.033045985336814604, 0.04208141192793846, 0.12190062100333826, 0.032607482081013064, 0.02228368033788034, 0.03466363996267319, 0.004193583478419376, 0.020274163257064562, 0.10850112858627524, 0.021879454974883368, 0.02391057661069291, 0.014304327346118433, 0.003573436398125653, 0.056879663573844094, 0.02244872719581638, 0.014117954980715044, 0.050804688661758385, 0.047010900984917364, 0.026763360049309473, 0.027827448843579208, 0.024898359053102986, 0.02437839257930006, 0.038547218178531954, 0.04833220544138125, 0.004500183343355144, 0.03906342726466911, 0.050057472328522375, 0.03096868091129831, 0.009939923100838704, 0.07318630535155535, 0.034592919650354555, 0.05869028677365609, 0.07397358917764255, 0.03551257887322988, 0.03317865250366075, 0.05694340515349593, 0.01963076108534421, 0.022047989502815262, 0.026122651661613157, 0.008963825879618526, 0.04742031205179436, 0.007624367218730705, 0.031626137239592414, 0.02893117256462574, 0.022910655176799213, 0.03538380649739078, 0.033734583029789586, 0.02584064063350005, 0.01861990675596254, 0.03966324543580413, 0.04791563922273261, 0.06168589674468551, 0.0031999851427307086, 0.008569055902106422, 0.04130913729646376, 0.014835699993584837, 0.013949727489879089, 0.04148322902619839, 0.05057728782828365, 0.021761846196438586, 0.034992702305316925, 0.08318714478186198, 0.02004473190754652, 0.029505284436579262, 0.03995066269167832, 0.05673534935340285, 0.05381065307717238, 0.005536107421253941, 0.016911984920235615, 0.05363023740106395, 0.029156856704503298, 0.04867661963882191, 0.0445395882374474, 0.03571018523403576, 0.04713690833055547, 0.004044678544492594, 0.06642433069646358, 0.020962267315813472, 0.0336504820069032, 0.04758354722123061, 0.01725234147826476, 0.05390794821349638, 0.03944329491683415, 0.030369883935366358, 0.007788512473260718, 0.012690018746070564, 0.04508212787498321, 0.04107107328517096, 0.038194206942405017, 0.008440147819263595, 0.11908989825419017, 0.017123256976317083, 0.019972797017544508, 0.022726884145023565, 0.020041057640420537, 0.05141581461897918, 0.020014065517378703, 0.048845072742551565, 0.04795041074976325, 0.033575283363461494, 0.018117176767970835, 0.05156062416998403, 0.049859937213893445, 0.030278088325368505, 0.038958244158753326, 0.05232008466763156, 0.0323397321626544, 0.02792259132755654, 0.016422243788838387, 0.024437155408252562, 0.030020692851394415, 0.039802063522594314, 0.03711242534752403, 0.03473349514284304, 0.03613229508378676, 0.07219756447843143, 0.07200530836624758, 0.028874691309673444, 0.037908723511333973, 0.0046967791110676315, 0.027235730684229305, 0.0580515003364001, 0.043685258366167545, 0.054151287834559164, 0.026917703017326336, 0.05733986637954201, 0.051480299194476435, 0.04462435422465205, 0.07668006859187569, 0.03971425769850612, 0.008042930026671715, 0.08697413693049125, 0.034666025013263733, 0.04164394343804036, 0.04499596071296504, 0.04206777337406363, 0.0692427276766726, 0.04638814154480185, 0.11279696093073913, 0.04092703387141228, 0.09008361186300005, 0.04398728787366833, 0.04098029547770109, 0.03321712543921811, 0.037608098571321795, 0.027670948134203042, 0.029826231500399963, 0.009977461354407881, 0.02812206874867635, 0.08200608672840254, 0.031599274038204124, 0.022528054724846567, 0.025755623588338494, 0.1317833342722484, 0.007433379118862961, 0.04138530624498214, 0.02763790517513241, 0.009245155828206666, 0.090284349662917, 0.04394720002476658, 0.07142934070101806, 0.023550355939992836, 0.039470415961529524, 0.06608827944312777, 0.029716000093945434, 0.006195798250181335, 0.0477499748979296, 0.023573098737480383, 0.03257058673937406, 0.010696336976252496, 0.039318753206836324, 0.01461072322646422, 0.021291541700650538, 0.014701855568481343, 0.0300363636176501, 0.03687153523787856, 0.01653166943495827, 0.03111840984118836, 0.05225300808836307, 0.022287973768210838, 0.043036609422415495, 0.01270126546400466, 0.03961991418951324, 0.006718380476481148, 0.02399998208108757, 0.05521688976192048, 0.02505076989265425, 0.014386823633685708, 0.01163539127446711, 0.012305201180944485, 0.04355340883401888, 0.005248398819406117, 0.0400515269222004, 0.04607574062954102, 0.034860812061067135, 0.09058379395199673, 0.13944645092955657, 0.1029915056590523, 0.11978880289409842, 0.10558638641876833, 0.06097234931907483, 0.175620686262846, 0.1834638996848038, 0.06221615829105888, 0.1055666749764766, 0.13453030187104428, 0.09803573015545096, 0.1518161850316184, 0.1299148252499955, 0.1055746070508446, 0.15986350178718567, 0.14923164514558657, 0.09710784030279943, 0.08198885872427907, 0.11442659848502704, 0.07444107266409056, 0.16654449328780174, 0.15536134051425116, 0.1594032107719353, 0.1798565768237625, 0.14737344985561712, 0.11892163514026574, 0.10440865997225046, 0.16843087492244585, 0.16841115669480392, 0.11126432674271719, 0.1073996355491025, 0.1865446250885725, 0.07796143447714192, 0.13686729861157282, 0.14408996461757592, 0.10566827881016902, 0.10387732634054762, 0.1186119517577546, 0.11891090071627072, 0.10299838600414139, 0.1554155418915408, 0.1975396065307515, 0.10997649441872324, 0.09618078504822083, 0.1374729996813195, 0.13769775762089662, 0.23920188737767084, 0.159315910456436, 0.055273557614002905, 0.1353360486349889, 0.06792571156152657, 0.12972467259636947, 0.09274021216801234, 0.14064285744513783, 0.1462784707546234, 0.12538340554705688, 0.15028375440410205, 0.0921698763434376, 0.12313431980354445, 0.13788595609366894, 0.16187757014163903, 0.14681672544351645, 0.07267498850290265, 0.08244342290397201, 0.10833199694752693, 0.10080297238060407, 0.1219075827726296, 0.11416272978697505, 0.1447455244404929, 0.10827578710658209, 0.15357612845088753, 0.16052932105958462, 0.14817562752536365, 0.27030012437275475, 0.08263055607676506, 0.1743846804435764, 0.07576570872749601, 0.11594205216637679, 0.09507662536842482, 0.08951773401349783, 0.1374863532504865, 0.11295253543981484, 0.15567350733493054, 0.18133407325616904, 0.12352411103035722, 0.15167031357330935, 0.07895236701837607, 0.09122428351214953, 0.10692096980554716, 0.160627830773592, 0.11429555980222565, 0.18623708587672028, 0.09774780739098787, 0.15059393990252698, 0.10958919341542891, 0.13563263629164013, 0.13266693614423275, 0.19013634164418491, 0.15389726550451346, 0.13853577551032814, 0.11424762808850833, 0.15322077966162137, 0.18692639603146485, 0.14769476332834788, 0.11817781148212296, 0.1737719633217369, 0.20441357339067118, 0.096770384481975, 0.2017277553677559, 0.09502530776496444, 0.1309390195778438, 0.2225258443504572, 0.10259070180888687, 0.1484019732368844, 0.14835709493075097, 0.11887872458568641, 0.1456281492220504, 0.20704664210123674, 0.2956037265913827, 0.20426749837185654, 0.15003650981400693, 0.1319870576262474, 0.1875343769788742, 0.11201665244464364, 0.17935490874307497, 0.09362166986933776, 0.1621771433523723, 0.09256050216832332, 0.0401365270039865, 0.19261184095271996, 0.10021280297743422, 0.15578865472759518, 0.083020862990192, 0.17697106594485895, 0.15191820955702237, 0.14558036678603717, 0.115257681746568, 0.049503987921135764, 0.13666596370083944, 0.13453197106719017, 0.19539779717368738, 0.09317475277930498, 0.0769122022071055, 0.14632021422897065, 0.2067241072654724, 0.14080555657190935, 0.0737363597644227, 0.10270360325063978, 0.07073129101523332, 0.07879789852138076, 0.11784949552799974, 0.1205409046794687, 0.1705850064754486, 0.1340591407247952, 0.16610325553587504, 0.11780661211482116, 0.07684075246964182, 0.10281813317643744, 0.2097525583314044, 0.11751116439700127, 0.10366264464599745, 0.15461763899241174, 0.08435377039547477, 0.16276750953069755, 0.1469613891094923, 0.13023657298513822, 0.12326571132455554, 0.09974666977567331, 0.12682122125157289, 0.14482922852039337, 0.15241336370153086, 0.10790509664054428, 0.1681717966816255, 0.1460661707179887, 0.11693417892924376], [0.02402624817165945, 0.031457677350512574, 0.056151449613805325, 0.062473567335733345, 0.022545009618625045, 0.016095768360953246, 0.060009718473468504, 0.026330393639260104, 0.03682277910411358, 0.03444889380729624, 0.007284310064278543, 0.023446336521634033, 0.024903108798233525, 0.046042614549930604, 0.0332264688664249, 0.021643821815294877, 0.03390134658132281, 0.07020664095346417, 0.02318904791692538, 0.02762299606443516, 0.01205169371262725, 0.03603015860010471, 0.03595028145770941, 0.12254526998315539, 0.054562714150441546, 0.06967913425926651, 0.04743184036176119, 0.021593164087140133, 0.03419621754437685, 0.014752106175624898, 0.06335030243332897, 0.03742369310930371, 0.04000935257811632, 0.057403119413980415, 0.017533877531864812, 0.02777772070840001, 0.02306904730253986, 0.05369190266355872, 0.02711357402482203, 0.027524640717144524, 0.017369653397638882, 0.07828105161232607, 0.09250209387391806, 0.03167338024026581, 0.05912131257355213, 0.03122602210247091, 0.06816576368042401, 0.02557892119511962, 0.03669843416927116, 0.06533423704760415, 0.07142285390623979, 0.06227801354335887, 0.03917974513024092, 0.058654337988368103, 0.018053238413163593, 0.06329612819744007, 0.03968310954847506, 0.08442980702966452, 0.04283874861097761, 0.010145324980840087, 0.014497384129624282, 0.010253532656601496, 0.02925245211060558, 0.010128957868021513, 0.07534771079995803, 0.04685100760044796, 0.01446716217989368, 0.02074044743286712, 0.03542567889339157, 0.01996034081093967, 0.06411923867251192, 0.012821897964126297, 0.04262940698702421, 0.03743430878967047, 0.06621991523674556, 0.017329443412433778, 0.030183405548866307, 0.014736274257302284, 0.03869761207274028, 0.059335878917149136, 0.07671453817082302, 0.03585896082222462, 0.05275066263441529, 0.03138154572142022, 0.057984963192471435, 0.03454325767233968, 0.02326525079219469, 0.04972980437534196, 0.04153424468157547, 0.03890551859512925, 0.042995055937873464, 0.04280294231804354, 0.036563521051513295, 0.051472197486353774, 0.02531248254568449, 0.011621564427124602, 0.019935849089441553, 0.0369769897578018, 0.06346760756735291, 0.02923289333869304, 0.009965887243327285, 0.0416184169506388, 0.05446401783930404, 0.03018905096022146, 0.02939788930650268, 0.012871136705923294, 0.03021803797621812, 0.05029700197545545, 0.1272003459078925, 0.021862427138590386, 0.025616125270192112, 0.02838342177814671, 0.06762953781123672, 0.07611210763986621, 0.023085075996017883, 0.01380414525712175, 0.018777601686971526, 0.009510741219855845, 0.03337330384446042, 0.060685573278793266, 0.05200907135648387, 0.05641509439530117, 0.03704723509560738, 0.0024000171646808405, 0.060243283797587664, 0.018178696145436594, 0.024756299265261208, 0.03476229216903448, 0.05373097949528268, 0.03878834916810904, 0.023637011647224426, 0.04493068564417107, 0.029722435998597314, 0.0031922971289272285, 0.053105763758399656, 0.018415182562811033, 0.04363649205437728, 0.021836425676675777, 0.03613275648759944, 0.017126485106668303, 0.059256368183663914, 0.022131306817755103, 0.0158730137960187, 0.018950529729149172, 0.027800645014005046, 0.0285516577506704, 0.04454703176660197, 0.009112912745747184, 0.03500957747123071, 0.06484821598444666, 0.03118764076914106, 0.04473154918689813, 0.06632200083030121, 0.022390834588025297, 0.0724656129521983, 0.03148094770897712, 0.04444108530879021, 0.055854977308107276, 0.023298963804596236, 0.023853179333465438, 0.08456562938434736, 0.03944990724059088, 0.033403230631457906, 0.022889939502679875, 0.01915829036650913, 0.05146090666364346, 0.041904273575970104, 0.023737377154507806, 0.05536819628572889, 0.05606131302192807, 0.02956122625619173, 0.03249732531341059, 0.012443449298319007, 0.04195687361061573, 0.011219004867598414, 0.02070201520941087, 0.05884329642036131, 0.06549920248133795, 0.05855949914881161, 0.06779723774109568, 0.019127410237810442, 0.032584795262664557, 0.06743845556463514, 0.03143151643286858, 0.04312781131427203, 0.014251511876604386, 0.01526251039467752, 0.030385432565318685, 0.05834688698606832, 0.051207911489265304, 0.051822962771568976, 0.03642198882464852, 0.06715127240334239, 0.09188044723123312, 0.03070391993969679, 0.0369157926844699, 0.06623218314988272, 0.005374668673279562, 0.03713858287249293, 0.03933917711089764, 0.09368864127567836, 0.07523058208503894, 0.03825980770800795, 0.023859513457864523, 0.038614233689648766, 0.021192268634747182, 0.005232421864223267, 0.08419384647692953, 0.04389966186136007, 0.03288307247151222, 0.023192484696794833, 0.014634636496858937, 0.01589070150761732, 0.07106548986796822, 0.022351160645484924, 0.0038007002523435013, 0.024003138965261833, 0.03712497824536903, 0.08460725072239127, 0.01829700551128813, 0.04467493222494211, 0.024695293878072073, 0.021251732051106434, 0.023191544925794005, 0.017448475418080176, 0.03307273657992482, 0.05525074865935104, 0.01947290839494339, 0.018508879767198647, 0.019725316636530415, 0.02798980361382876, 0.055812769037272246, 0.057534843417150636, 0.009786004217208495, 0.052570572655115805, 0.01917912478425673, 0.05692327980484281, 0.06213736680469342, 0.04380428358646376, 0.00835163886326232, 0.09889073177639927, 0.03979132231324911, 0.04652943967708519, 0.06654835332717214, 0.023286458404202546, 0.09409213890986783, 0.02027461787552706, 0.07202682471168892, 0.003977515452009226, 0.06500807204949004, 0.06625827960669994, 0.016954176227695177, 0.04328315851411649, 0.013294218557088502, 0.052936608370925696, 0.039550337208701034, 0.11460231191345624, 0.026464300828852823, 0.024843370575191717, 0.04002280453486102, 0.018072585142882805, 0.02661266759969294, 0.03866310178169182, 0.05364682758226991, 0.043080887225057395, 0.028447356740278856, 0.021590441465377808, 0.04326266336387821, 0.0459677653520235, 0.016487549391708205, 0.02412549579249961, 0.03497918249507036, 0.04224506778908627, 0.014893579030675548, 0.03747650348980512, 0.026609120557882955, 0.03233814439071076, 0.032011195684650114, 0.017415763244831135, 0.026374059064047675, 0.03516291620741997, 0.06434559795473303, 0.028864917012729814, 0.06925960284258638, 0.010035554130029465, 0.07451788961355175, 0.03322535267631922, 0.03444563683920673, 0.032776226954800744, 0.024133921501093676, 0.0174725600185671, 0.022758439416065812, 0.04447706462815404, 0.03152623313612171, 0.056890645663120916, 0.038061943503894975, 0.015580673768584217, 0.1005877342873386, 0.06766953066523586, 0.027312813958685313, 0.06793833909822361, 0.04309790827600019, 0.022044028554643904, 0.010168588553954448, 0.043075594651911936, 0.02700843332734491, 0.0441657731176487, 0.03360482677817345, 0.03614976057516677, 0.02708232239820063, 0.07689871971628495, 0.04879907824631248, 0.04741810681298375, 0.05883703354213919, 0.046103214512446096, 0.04112689636115517, 0.033485353724764924, 0.01820703685682799, 0.010183702921494842, 0.0358087661942201, 0.0030944284184702803, 0.045737331467015405, 0.029328872117080858, 0.027758753958291242, 0.030279781270240034, 0.012465868095335151, 0.013324174181824284, 0.017838188613365804, 0.05156726363514151, 0.020296193592782532, 0.01146140302132283, 0.024380725043426667, 0.02646583940700761, 0.06613669970205852, 0.016898398952824727, 0.03014807423044528, 0.05316430775980864, 0.056488359213939736, 0.03625393944925495, 0.03832588344812393, 0.023945407509537678, 0.04623849743178912, 0.01763642961824579, 0.0035834553917603834, 0.009104968797016357, 0.037164146679320505, 0.02644215683851923, 0.047111894137093, 0.05274069156231625, 0.05658295378088951, 0.01605450834280678, 0.009391083265654743, 0.12174546718597412, 0.13067107966967992, 0.1326038052460977, 0.17219641857913562, 0.1288330504404647, 0.10018024686723948, 0.14079389934028896, 0.1173419649047511, 0.15060394150870188, 0.06261291128716298, 0.05043264451835837, 0.08829904440790415, 0.17885146290063858, 0.07927332086754696, 0.1252875556903226, 0.11499540082045964, 0.09968756259019886, 0.1468004270323685, 0.12749440941427434, 0.12103417249662535, 0.14477915263601712, 0.12699112642024243, 0.1259436583412545, 0.203416819018977, 0.14588025212287903, 0.18644114849822863, 0.08601860356117998, 0.07368192089987652, 0.09332439010696751, 0.07435122784227133, 0.12399905840201036, 0.17499310922409805, 0.13688646044049943, 0.23507935287696974, 0.05300120829737612, 0.12821019600544656, 0.08203921280801296, 0.18462213182023593, 0.10196470575673239, 0.05880007373967341, 0.10096934238182646, 0.1709030494093895, 0.2767351604998112, 0.10106565364237342, 0.17837719406400407, 0.18746321222611836, 0.15634292284292833, 0.10796573731516089, 0.10264115767287356, 0.1482917791498559, 0.1173674642507519, 0.13216112899993146, 0.10855513318840947, 0.14883002026804856, 0.11138713479574237, 0.21659038641623088, 0.13695449036146912, 0.13032850090946468, 0.17977226206234523, 0.054399333095976284, 0.09639716986566782, 0.10024729969778232, 0.1462932899594307, 0.05670628769855414, 0.15780687571636268, 0.1714840925165585, 0.1056769165609564, 0.16044070438614913, 0.1311077983783824, 0.13593873700925282, 0.11306954880378076, 0.13189517041402204, 0.12621452952069895, 0.24114342033863068, 0.15936016451035226, 0.06783155804233891, 0.09199568283345018, 0.086671836008983, 0.23764855787158012, 0.18581828049251012, 0.21019531600177288, 0.13550504456673348, 0.14622056457613195, 0.17191531509160995, 0.13141824172011443, 0.16385802387126855, 0.14966028928756714, 0.13219277587320122, 0.08379256765225104, 0.13445744078074182, 0.06155113290463175, 0.13530216259615763, 0.09068390500864812, 0.08772011154464313, 0.16202340088784695, 0.22061454690992832, 0.11569336908204214, 0.14346628236983502, 0.1380342702780451, 0.1595594095332282, 0.10988320263900928, 0.16669138254863874, 0.07689836009272508, 0.07711777117635522, 0.06902937591075897, 0.09220679543380227, 0.1095630426758102, 0.21263520579252923, 0.23750793827431543, 0.12226863125605242, 0.11824174305158001, 0.08220939617604017, 0.17559786034481867, 0.15603581789348805, 0.13423930534294673, 0.08758994138666562, 0.12731032286371502, 0.06142435542174748, 0.24001773074269295, 0.147192973111357, 0.10944142205906765, 0.256284305027553, 0.1387113125196525, 0.0986583810299635, 0.18164951061563833, 0.11742334839488779, 0.1594754068979195, 0.09262827424598591, 0.19897069116788252, 0.11699918258403029, 0.1191089650882142, 0.1738661304116249, 0.11764220307980265, 0.13356450226690086, 0.1423762294330767, 0.09795098113162176, 0.12561680802277156, 0.07997312795903001, 0.11622164930616107, 0.15625748171338014, 0.1092497291309493, 0.06967825894909245, 0.09531101850526673, 0.10323657215173755, 0.11142231005110911, 0.15897304671151297, 0.21985280992729322, 0.057617583977324624, 0.19985098178897584, 0.14085492677986622, 0.10444363845246178, 0.11506056732365064, 0.12238434861813273, 0.07712087208139044, 0.2139900638056653, 0.1456440133707864, 0.10106750604297433, 0.16888496412762574, 0.06628430142466511, 0.09089146887085267, 0.1515373614217554, 0.11407978566629545, 0.1204826185213668, 0.15567657431321485, 0.07221107411065272, 0.18172993058604853, 0.12025107523160321, 0.10220011669610228, 0.07344566179173333, 0.1799535530486277, 0.15591870274926933, 0.11194202716329268, 0.14861007992710384, 0.14985189400613308, 0.07508760797125952, 0.11949961126915046], [0.024721929770229117, 0.056484915648720095, 0.051447166329515834, 0.02208008590553488, 0.010056163783052137, 0.04609025110091482, 0.04658421780914068, 0.07974436666284289, 0.010539051710761018, 0.04248210721250091, 0.02751653900902186, 0.02075572804148708, 0.007929700343603534, 0.03486400117565479, 0.014731492281758359, 0.024707614377673184, 0.019410103193617294, 0.04947782021814159, 0.03262634535453149, 0.09488272041614566, 0.03814334735008223, 0.023163606246401156, 0.04024859045499137, 0.0262152038381568, 0.010674210797463144, 0.027884756214916706, 0.02760643302462995, 0.03417279112285801, 0.05991613492369652, 0.04300805666883077, 0.04644119280523487, 0.016585855545209985, 0.010222836580526615, 0.0521598146962268, 0.04567318276635238, 0.08710571165595736, 0.02274472961601402, 0.038374673508639844, 0.049721689096518924, 0.046981662910963805, 0.020362971616642814, 0.024645830371550152, 0.02039515962158995, 0.02742811062905405, 0.005555528789825205, 0.00956419960130006, 0.031329251027532985, 0.06582949975771563, 0.010599010457683886, 0.039944433740207126, 0.027080473390274813, 0.025043764018586705, 0.02793475067509072, 0.060672552191785405, 0.032404637429863214, 0.042336927859910896, 0.018326050202761377, 0.06693319124834878, 0.05689768885661449, 0.007392667017744056, 0.015269012456493718, 0.054691975071494064, 0.026743792795709202, 0.04275694103645427, 0.05348825055573668, 0.05971892550587654, 0.0276967731770128, 0.025596122057842355, 0.07374385079102856, 0.03630173884864364, 0.011399810701342565, 0.05035032464989594, 0.02533052139915526, 0.012577701692602463, 0.039462711196392775, 0.02117409577061023, 0.01789659690777106, 0.052865240057664256, 0.025201908479045545, 0.05310227269572871, 0.013835429114156535, 0.08733872736671142, 0.02628788342034178, 0.020225485154826726, 0.007918839542461293, 0.03368521621450782, 0.04982744895720056, 0.012796000826970806, 0.042127867827990224, 0.018466554449072907, 0.054842762516013215, 0.026215227586882453, 0.024938513059169054, 0.04398004111966916, 0.04232361161016992, 0.010981768669028367, 0.09558330782290016, 0.013213886796230716, 0.008364061991285001, 0.00971595904723342, 0.030676941387355328, 0.0323823068423995, 0.041181806807539294, 0.0665196105837822, 0.05187740842146533, 0.012186441437474318, 0.08662962434547287, 0.04548684347953115, 0.04863002463909132, 0.013824192574247718, 0.04505868109741381, 0.01603370445913502, 0.06079380639961787, 0.014187539595046213, 0.023215632918956022, 0.02525461368661906, 0.013303306685494525, 0.02873037030388202, 0.06531132970537458, 0.002739872454964955, 0.04306290265438812, 0.02140115903291319, 0.021443472476676106, 0.027810901070811918, 0.05301584090505328, 0.029885355649249892, 0.02743191042515848, 0.07344560750893184, 0.021205103124624917, 0.05456829170829483, 0.046744338502841334, 0.05421410321391054, 0.054589536639728715, 0.07717423207525696, 0.00410655203242121, 0.05003628846524017, 0.08567385348890509, 0.012782659132166632, 0.028054903959855437, 0.021272690301494937, 0.011529985100163944, 0.03420706731932504, 0.037817620007055144, 0.01827256128724132, 0.031664281085665734, 0.008197049926301199, 0.013929820120600718, 0.024624843283423355, 0.040304535667278936, 0.03086698886805347, 0.08770150611443178, 0.016223831667697856, 0.04871390853077173, 0.03287501147549067, 0.0497102557814547, 0.05550983029284647, 0.05661213078669139, 0.015007691657436746, 0.03677770063014967, 0.06144505073981626, 0.06216205869402204, 0.02539199497550726, 0.020223273130665933, 0.03294547733717731, 0.0388960530316191, 0.0736527167526739, 0.007379013196831303, 0.023457435658201575, 0.03236583201214671, 0.07429347772683416, 0.07618699754987444, 0.07706323053155627, 0.060004744811781814, 0.0039260320315536645, 0.04031721409410238, 0.0638041270098516, 0.06749293514128242, 0.029983597341924906, 0.025413402755345618, 0.020449949628008262, 0.04109979567251035, 0.02737945457920432, 0.03955655258947185, 0.013998552325314708, 0.009587179886044135, 0.024151916249788234, 0.0298012614117137, 0.02335778600536287, 0.05263082317209669, 0.01889953442982265, 0.04242040802325521, 0.017935697488220673, 0.01556027022057346, 0.023463092943919555, 0.047853587195277214, 0.04036953592939036, 0.013418094454599279, 0.030479494482278824, 0.05284852434747985, 0.036658804331507, 0.0340424716871764, 0.05672720693317907, 0.0533699615459357, 0.012387915447886502, 0.05416441748717001, 0.04831436336306589, 0.05037098264853869, 0.026552211825868914, 0.03130125467266355, 0.04288246662222913, 0.016295135520132523, 0.053425360537533245, 0.04803173317174826, 0.06143921533865588, 0.03347455823261823, 0.08012107573449612, 0.012140897318853863, 0.01717794011346996, 0.03453308643241014, 0.019555866086323346, 0.03183658826830132, 0.018500242016411254, 0.060043821643505774, 0.0289984153849738, 0.04295905286978398, 0.017122427467256784, 0.011116491796981012, 0.15484367257782392, 0.04371702398306557, 0.03540847124531865, 0.02286840958653816, 0.05194245618102806, 0.06004398449191025, 0.042347065173089504, 0.013893649115094116, 0.020899847183110457, 0.04242284396397216, 0.03573766929496612, 0.052193073090165854, 0.06321276338504893, 0.040593008045107126, 0.06611824354955129, 0.01127194841059723, 0.012486975623427756, 0.03265459616003292, 0.01258502562996, 0.02621539552429957, 0.02737741558147328, 0.005572534573730081, 0.03300913409995181, 0.015200721299541848, 0.018596619434122528, 0.015629431598686745, 0.043869728289012394, 0.06470560827957732, 0.026255203477506126, 0.005590252395320151, 0.05791574583521911, 0.040650771731244664, 0.0015043171193350904, 0.008141033467836678, 0.04079386119597724, 0.046422743438077826, 0.04494891109477196, 0.022965245015387024, 0.02153491015945162, 0.05037046017657433, 0.027993142006120512, 0.008516982580269021, 0.034575393090822866, 0.0245076721600656, 0.02490064741245338, 0.006605911176718239, 0.008886416908353567, 0.06699674962354557, 0.008622665257592286, 0.03178939276507922, 0.01713599307861711, 0.024766731741172925, 0.04537197767889925, 0.005896725883108697, 0.049175929810319624, 0.06052830921752112, 0.05034586667482342, 0.02621867454477719, 0.028338857294459428, 0.04010553152433463, 0.017308257852814028, 0.07376097022954907, 0.02806714133891676, 0.0245240129796522, 0.025081594042213898, 0.01824304840660521, 0.0683904809079, 0.0217505672480911, 0.06815423537045717, 0.02913299941324762, 0.022925900162330697, 0.02812802798247763, 0.028423029563522766, 0.041832759377679656, 0.02811217910077955, 0.033608355160270414, 0.04813020217365452, 0.018997231598145196, 0.038116273802838156, 0.03335068148693868, 0.03851751530809062, 0.04096854664385319, 0.032266969459929636, 0.01727077048937125, 0.0202041113017393, 0.05194576743191906, 0.028674682934901545, 0.039663292933255434, 0.013160626886279454, 0.0483412672765553, 0.033506683473076136, 0.043132150545716286, 0.020823520475200245, 0.03177668719685503, 0.008942815042766077, 0.01373723491893283, 0.03261632678498115, 0.05989357363432646, 0.0414913035929203, 0.04939657922035881, 0.045216752615358145, 0.013934751373848744, 0.09773994995547192, 0.03928380865337593, 0.03858713639367904, 0.02337334650967802, 0.04621017877278583, 0.04456093834180917, 0.005653058868899409, 0.0773103665560484, 0.03209267416968942, 0.027487884475184337, 0.010540710728881615, 0.10399374937904732, 0.05683866309534226, 0.02986717430342521, 0.022819855316941227, 0.014011369003648204, 0.023910987124379193, 0.015014517719724348, 0.03530200570821762, 0.03009482958753194, 0.028364246378519704, 0.011082009495502072, 0.02203525848952787, 0.13149539115173475, 0.11611164520893778, 0.1971428535346474, 0.12321433265294347, 0.10942800742174898, 0.2890831950519766, 0.16304182766803674, 0.10663145926914044, 0.10186563964400973, 0.05680719942652753, 0.05471823776939085, 0.14755636932594435, 0.11305553027029548, 0.13273364970726625, 0.1319233024758952, 0.17645373727594102, 0.10080361698887177, 0.10256805230996438, 0.08527461026928254, 0.10648465821785585, 0.06993655687464134, 0.08648770196097237, 0.17225273698568344, 0.14688224478491715, 0.09563482898686614, 0.13193666961576256, 0.1614337403859411, 0.1182197178048747, 0.13610302390796797, 0.12979472455169472, 0.11574861540326051, 0.10617386203791414, 0.11326732140566621, 0.13757905470473425, 0.10044819356075355, 0.1041325708585126, 0.08567120720233236, 0.08757242161248412, 0.07205403396593672, 0.12172337408576693, 0.16481148770877294, 0.1616682963711875, 0.12402240000665188, 0.09914627484977245, 0.16439317086977617, 0.1074130501864212, 0.1899071189441851, 0.2107650682862316, 0.08668955934367009, 0.10352349068437304, 0.06301837667290654, 0.22638617934925215, 0.15843358423028672, 0.19389263008322033, 0.12085255581353392, 0.10816009688590254, 0.12726070838315146, 0.13576432636805943, 0.15525713110608713, 0.10863199763532196, 0.15827463061681815, 0.1138980332762003, 0.1526707863169057, 0.18672360905579158, 0.12577745797378675, 0.13314579187759332, 0.07371624798646995, 0.15250146468835218, 0.13746932202151843, 0.1045038787914174, 0.10582217733774867, 0.15372099567736897, 0.1076908695644566, 0.11813473807913916, 0.14366232470742293, 0.07847475978944983, 0.15310111322573253, 0.1071621822193265, 0.14527693949639797, 0.1137828655274851, 0.09961383297507252, 0.19310288317501545, 0.1801043642418725, 0.15112672559916973, 0.11100676163498845, 0.08282465780419962, 0.14319694467953273, 0.0877277043515018, 0.07457416052264826, 0.11219879159969942, 0.15089854784309864, 0.10252228512295655, 0.15881545016808168, 0.09399482341749327, 0.09016635920852423, 0.09681278613529035, 0.1378910993891103, 0.07912103046796151, 0.15791694766708783, 0.05157543658944113, 0.06896281841077975, 0.13219277587320122, 0.12779281554477556, 0.13773587771824428, 0.12964828312397003, 0.12223804289741175, 0.1798231386180435, 0.12478742109877722, 0.1175882595458201, 0.10440703148820571, 0.1361098363995552, 0.12516289523669652, 0.15310673149568693, 0.07934536771582705, 0.08517143901969705, 0.13392762706748076, 0.13369248754211835, 0.13997002212064608, 0.14558735569672926, 0.12021725704627377, 0.14709899601127419, 0.1080715616366693, 0.13763531882848057, 0.06023539922067097, 0.1369438509323767, 0.08051795765225377, 0.08046528976410627, 0.10770986854497876, 0.12892966025641986, 0.14700771948056562, 0.08229402984891619, 0.07931640105588095, 0.15784093817429884, 0.18716310975807054, 0.1175572369247675, 0.11520015554768698, 0.11106244900396892, 0.13428255516503537, 0.08990565248365913, 0.0970578526279756, 0.10919569738741432, 0.11313466102417026, 0.1183414605579206, 0.07239396643957921, 0.052854427602142096, 0.10351905985070126, 0.11030698168490614, 0.1419459975191525, 0.20743743755987712, 0.22277189471891948, 0.19262265680091722, 0.1363918219826051, 0.12231255961315972, 0.14554534080837453, 0.1520813022341047, 0.14815894913460526, 0.1973973313080413, 0.20888647623360157, 0.09590540839625256, 0.1068596098838108, 0.23345263302326202, 0.11993900340582643, 0.1317669137247971, 0.17053096794656344, 0.22201344184577465, 0.2035395795745509, 0.0979676798784307, 0.17817618485007966, 0.09302354125039917, 0.20285486988723278, 0.11774627678096294, 0.2066995171563966, 0.207391405744212, 0.08396994349147592, 0.19914724597973482, 0.1414173101740224], [0.011903110658749938, 0.0406569803266653, 0.10238347721419164, 0.014165088567616684, 0.03311544357399855, 0.06130915374628135, 0.052953256227608235, 0.010391230312442141, 0.038143001297222714, 0.0565538921260408, 0.020565358256655078, 0.0360499412885734, 0.03128567550863538, 0.04624441086447664, 0.015992676839232445, 0.0665011340752244, 0.060528295646820746, 0.0078003181344164264, 0.06537245892520462, 0.035670813239578686, 0.040842006648225446, 0.024850279758019105, 0.0867235946602055, 0.044173881611121554, 0.017294524304036583, 0.04359642795420118, 0.07821562048047781, 0.07171379615153585, 0.010326113851208771, 0.022781560496826257, 0.0038041489065757817, 0.019065271697140167, 0.05151156269546066, 0.04792203102260828, 0.010357698808158082, 0.042825099879077504, 0.037416157977921624, 0.04073599233691182, 0.011500308522954583, 0.041066961362957954, 0.044216798951051066, 0.07403009757399559, 0.03422362018110497, 0.039473635610193014, 0.027643526837761914, 0.018240061156185608, 0.022312640212476254, 0.03796342700453741, 0.07158783969602414, 0.034999267131622346, 0.005597908390752439, 0.025871761642130356, 0.027577349317393134, 0.014757083229986685, 0.014141672324123127, 0.020145166964669312, 0.05220004843015756, 0.06006220315716096, 0.02631713676133326, 0.0521945047990552, 0.033688561392149756, 0.03787934633770159, 0.019448006159758995, 0.016044399867366468, 0.09001157858542033, 0.03270286035590938, 0.027445574424096515, 0.036338491697928736, 0.019272922072559595, 0.07673975931746618, 0.02409967583870249, 0.035322344795401604, 0.00967726982863886, 0.04099883305441056, 0.0176670230658991, 0.029252519964107444, 0.04236065962218812, 0.07131900412163564, 0.04823100872870002, 0.03171894386676805, 0.036278563485081704, 0.03067565556349499, 0.015617392691118377, 0.043412144628486464, 0.0540430818551353, 0.026340926199087074, 0.05366018793678709, 0.077968823723495, 0.05791679756449802, 0.033388424997351, 0.0619379725041134, 0.010081121997375573, 0.07343911392880337, 0.008495299993748111, 0.04271009158609169, 0.04608155906732593, 0.0526172151522977, 0.03383950489972319, 0.03521592675575188, 0.051658896396734884, 0.06982866302132607, 0.020648991090378592, 0.050662399868347814, 0.02156366647354194, 0.04528891481459141, 0.014285821999822344, 0.0022199613241744892, 0.04710099007934332, 0.011474966088176837, 0.037488615339887996, 0.024206892853336673, 0.027002228124599372, 0.05742675957403012, 0.02605812467767724, 0.034232685408954105, 0.08156339691153594, 0.0773753769961851, 0.05238071516422289, 0.0751734155097178, 0.07505376942987953, 0.034924434897090705, 0.0452454953587481, 0.029434710009289638, 0.014714927545615604, 0.06717372512710945, 0.032446506433188915, 0.038746924605220556, 0.039009761930044205, 0.02559177264837282, 0.006943200332378703, 0.040473253399665864, 0.04189766125221338, 0.0215014600793698, 0.026772888377308846, 0.01591175136023334, 0.0053717696324123865, 0.041028831087585, 0.05283327088026064, 0.03316144485558782, 0.05366647795640996, 0.09465413553906338, 0.01711282450040536, 0.03028219685490642, 0.013762380578555167, 0.04023214955148952, 0.04621632630005479, 0.07210149749049119, 0.047854079133165736, 0.06584395255361285, 0.0330630063877574, 0.02397596533410251, 0.03487953623490674, 0.0782571400382689, 0.032716417485581975, 0.027109635129038776, 0.019860733566539626, 0.02896217822230288, 0.08502380337033953, 0.005340083743379052, 0.03662053495645523, 0.009412468993104994, 0.06408795142280203, 0.024491246523601667, 0.04044834777180638, 0.022014413893754994, 0.041821607654648166, 0.015048222250438162, 0.0472097897769085, 0.07548736009214606, 0.04174728771405561, 0.02298973673688514, 0.054459254523473125, 0.04319023992866278, 0.04688989104969161, 0.0800729947430747, 0.009963907617410379, 0.05779078682618482, 0.021824810853494064, 0.024330759420990944, 0.02024559354010437, 0.01609052498159664, 0.07627501711249352, 0.016259461541527083, 0.04410579062200018, 0.03390733465286238, 0.005866817755824221, 0.009541175211779773, 0.029164222202130725, 0.041040172800421715, 0.027807086007669568, 0.00421093955602763, 0.0664521845589791, 0.062012496005211554, 0.015194280305877328, 0.01533116287152682, 0.06334572910730328, 0.054868499349270544, 0.031760833226144314, 0.01518265191199524, 0.028768663427659442, 0.06101094439093556, 0.015434502058529427, 0.058294158029769144, 0.08825542817690543, 0.040716643910855055, 0.04690099188259669, 0.01102285141990121, 0.037808921188116074, 0.05148612102493644, 0.049651779633547576, 0.03856758101444159, 0.03375306632369757, 0.009563143631177289, 0.05669691373727151, 0.01574093695463879, 0.03124071917097483, 0.07844896188804082, 0.021840159315615892, 0.030395400244742632, 0.023896988946944475, 0.09581262551780258, 0.018952483910002878, 0.04219371286619987, 0.019023333143975054, 0.024436254653015306, 0.0395853937204395, 0.0364801833805229, 0.03938257960336549, 0.03440338785627058, 0.011960980365984142, 0.029018673047955548, 0.01146933255118451, 0.039299594770584784, 0.02263654229630317, 0.026572360923247676, 0.06397088377603463, 0.04586260260215827, 0.051718783897480795, 0.03341683525858181, 0.0022973620257939076, 0.08478225847440106, 0.010555199147867305, 0.037048738050673685, 0.045812774383063824, 0.06104246234255178, 0.030738881456532648, 0.09573122167161532, 0.02366816658260567, 0.03790428928498711, 0.08591465199632303, 0.037458973537598333, 0.04464969411492348, 0.029238864446857145, 0.1033718923905066, 0.007786534543681357, 0.010564339862737273, 0.027596048046169535, 0.04848738979282124, 0.015816293357472335, 0.07667334430984088, 0.0029750690196773833, 0.03649581004200237, 0.06798676614250455, 0.03385544029463615, 0.06780578728233065, 0.032088813305433304, 0.014198906752946121, 0.007843712993365313, 0.015058006725407072, 0.060199382581881115, 0.060341556024338515, 0.053354423094008646, 0.030524756160697768, 0.04152543729703341, 0.04127042008829968, 0.05422909205247249, 0.045305036806634495, 0.016765987932948128, 0.0300943987177951, 0.022365764415423785, 0.0327523018100432, 0.038965429844600816, 0.026741090529997433, 0.03171008898477469, 0.015086048881390264, 0.04091706958466342, 0.011736044310964644, 0.019960858193891387, 0.02888346816013966, 0.02621194687006729, 0.02127200158845101, 0.025153707047658305, 0.05788368505558797, 0.021467078709974885, 0.04000491835176945, 0.07559739811612026, 0.039166361026998074, 0.026009838429412672, 0.056963476219347546, 0.023866195331460664, 0.03582462355760591, 0.023024252116946236, 0.049199203561459265, 0.0962098738444703, 0.06450951165918793, 0.02629286386737866, 0.03354223192270313, 0.04343774575474007, 0.0227482291603727, 0.028802454471588135, 0.05967823376080819, 0.07895736782146351, 0.017965366431911076, 0.01738213504930692, 0.06055109442344733, 0.04352112074515649, 0.05108924928520407, 0.02269432633849127, 0.03227765638647335, 0.01913421764038503, 0.06833947543054819, 0.046643135004809926, 0.04271329087870462, 0.02884468649114881, 0.04832146083936095, 0.021559532498940825, 0.04247440244736416, 0.03417035857481616, 0.05925129274172442, 0.02652145892248622, 0.027950721693092158, 0.006560950598213822, 0.058467693360788484, 0.01003144814499787, 0.047220575091029914, 0.0529856562747487, 0.0368686514640493, 0.026646346685343554, 0.0246859436655151, 0.06926110919032778, 0.017916045417743068, 0.03308347100391984, 0.027916671109518836, 0.007594718631090862, 0.04156049380877188, 0.02899445952581508, 0.03721839216138635, 0.02372481407863753, 0.02214880284321095, 0.03528037401182311, 0.03913633245974779, 0.012086702726914414, 0.20036049373447895, 0.1493645023022379, 0.21898796276322433, 0.08624258118548564, 0.0732966758576887, 0.1983296519943646, 0.10182986049247639, 0.10060543048062495, 0.1187080323163952, 0.1521400362253189, 0.10183133969881705, 0.11206442809530667, 0.10251104858304773, 0.13458733952471189, 0.08406238031706639, 0.17418535399649823, 0.181846163634743, 0.07660301415515797, 0.10304893007768051, 0.1401744782924652, 0.09990303138537066, 0.0679863929482443, 0.20667196863463946, 0.1435628921857902, 0.12359637500984327, 0.12053034667457853, 0.18384709555123532, 0.3028460294008255, 0.15619264090699808, 0.10262118160192456, 0.07369840251547949, 0.09226877282240561, 0.10377970550741468, 0.2118846374963011, 0.09196917925562177, 0.12501942579235348, 0.08535345603844949, 0.1455756848944085, 0.08963322745902197, 0.08565195037850312, 0.09213658741542272, 0.1961090782923358, 0.0740931470479284, 0.1157715091747897, 0.2439792895955699, 0.11206038402659552, 0.0945457395698343, 0.10109848795192582, 0.18251886325223105, 0.15478093522999967, 0.07141671316432101, 0.17365438677370548, 0.18498073757759162, 0.10753712031458106, 0.22159359151763575, 0.06594098984662976, 0.1574828073914562, 0.1055413249081799, 0.0757498513641102, 0.2026842726128442, 0.1832608412951231, 0.12273882888257504, 0.07731028513184615, 0.07153578248939343, 0.12387906626931258, 0.12443216730441366, 0.15355130763990538, 0.1446876318327018, 0.2317367536681039, 0.14246500895491668, 0.1871565958218915, 0.18672788382640906, 0.11495297881109373, 0.1365667890225138, 0.11594990960189275, 0.14509927188711508, 0.08885455424232142, 0.25958820059895515, 0.1284126572843109, 0.11784360584403787, 0.15437420776912145, 0.13783767154174192, 0.07921475651008741, 0.15938213547425611, 0.19911669833319529, 0.13631122559309006, 0.26969869807362556, 0.18655548164887087, 0.12644078023731709, 0.1652205629008157, 0.16297577906932148, 0.06423308327794075, 0.1272624997156007, 0.13091350666114263, 0.1387240554073027, 0.16624460795095988, 0.11892696842551231, 0.295967339937176, 0.11811056866177491, 0.11366278518523489, 0.1317218861409596, 0.09624534765524523, 0.18750519997307233, 0.08548696458871875, 0.12304491602948733, 0.13582757940249784, 0.07986315100320748, 0.20018127906535352, 0.0961861251188176, 0.07309998212648289, 0.15045258748744214, 0.0825056309944817, 0.17435559843267712, 0.0865784560197166, 0.06506595787193094, 0.1626002506486007, 0.20356172695755959, 0.09994191144193922, 0.14727795283709252, 0.16399925415005, 0.1830338170485837, 0.15110472749386514, 0.15187020998980316, 0.12190866842865944, 0.12277017720043659, 0.08694140440119164, 0.12147143403334276, 0.14350706232445581, 0.1548018069671733, 0.10440388987106936, 0.08204481072191681, 0.0864417515695095, 0.08481359322156225, 0.09200329599635941, 0.1848309984696763, 0.13776379264891148, 0.12721304808344158, 0.17048804382128374, 0.1118237381534917, 0.10335730388760567, 0.2254539265164307, 0.06952239945530891, 0.14537425498877252, 0.13639282621443272, 0.15059326136750834, 0.10652286652475595, 0.20999932794698647, 0.12389788883072989, 0.22676349910242216, 0.07542281784117222, 0.14183878898620605, 0.1281036931489195, 0.1783559966300215, 0.08054181494350944, 0.12641186107482227, 0.17644066869148187, 0.09654025933040039, 0.12902470944183214, 0.1123001172340342, 0.08025163265743426, 0.1143544295004436, 0.17104840518108436, 0.1468462281461273, 0.12841022812894412, 0.08511223683931998, 0.10163073760590383, 0.06858734427286045, 0.15678289851972035, 0.11702518404594489, 0.07381023187190294, 0.13927402161061764, 0.11744762637785502, 0.1252684345734971, 0.13808526897004672, 0.08956545538135938, 0.06738170289567538], [0.00226021371781826, 0.019250299715037857, 0.05471721657418779, 0.029534376625503813, 0.038203055039048195, 0.034402777174753804, 0.026803783773045455, 0.07121923911784377, 0.04611605239499893, 0.0473147116468421, 0.04540405881458095, 0.0460116903164557, 0.034111370132969956, 0.05954800932002919, 0.07720105456454412, 0.01962897484190762, 0.016686673974618316, 0.02742872809592102, 0.013686118331471724, 0.045790643963430605, 0.0346801487196769, 0.02677557707232024, 0.02179689083381423, 0.03376774982150112, 0.0043594988611792874, 0.019972914064835225, 0.04347523820719548, 0.09038287973297493, 0.02350702808637704, 0.01941925154200622, 0.03021108638495207, 0.0385084873996675, 0.010982867047589804, 0.04962802751521979, 0.021716735492061292, 0.07161521858402661, 0.008745391886415226, 0.008831652346998453, 0.0580787570880992, 0.025775825272181203, 0.03148997561740024, 0.07607864229274647, 0.048232569359242916, 0.041508701230798445, 0.01909236390409725, 0.0678674593301756, 0.005758092697111091, 0.014737850154883094, 0.08019323793372937, 0.022282209613227417, 0.03025542864842074, 0.04052633858684983, 0.047913542549524984, 0.029332098551094532, 0.06739306157188756, 0.11275506817868777, 0.0735307704391224, 0.06696341998342957, 0.02308982065213578, 0.03038850293627807, 0.035854879434087446, 0.040760735116366825, 0.020219651450003897, 0.06539604480245284, 0.053186000524354834, 0.07471066819769995, 0.02625233497071479, 0.0631270304854427, 0.015583011321723461, 0.012905744536380683, 0.047460189554840326, 0.13223694850291523, 0.05219743946301086, 0.015231000924749034, 0.05284560664689966, 0.006006157466409994, 0.019300575767244612, 0.07550969067960978, 0.034664399921894073, 0.057415244834763665, 0.05163039792595165, 0.02736651322006115, 0.03344077058136463, 0.035571136445339234, 0.024581120183159198, 0.03005862295893686, 0.04387763322197965, 0.06198181265166827, 0.036524834377425056, 0.02096707304008305, 0.04223008912854961, 0.031698842266840596, 0.01392399998647826, 0.049712803680449724, 0.05291835577892406, 0.031224427545177083, 0.01955773714663727, 0.01778674717726452, 0.01918395425725196, 0.05575015043307628, 0.041701785155705044, 0.03610464817445193, 0.03554365238440888, 0.02974584884941578, 0.06653393445802586, 0.016563139889123182, 0.01879329450561532, 0.02303420452933226, 0.030787413673741475, 0.027671965936731015, 0.030108546172933917, 0.016210194810160568, 0.08090310091418879, 0.01188487503012376, 0.003025183707775016, 0.058754218343113146, 0.028339581630591835, 0.08120773599616118, 0.06289312589381423, 0.012027534473288273, 0.03406679716759494, 0.02494441461749375, 0.04584429572735514, 0.030714287954781736, 0.058733210898935795, 0.049340861317302497, 0.027955968465123857, 0.03795688931963273, 0.06537839610661779, 0.03510849769892437, 0.024061565919380103, 0.06405341399035283, 0.014992341498977371, 0.03476766277370708, 0.05016965452315552, 0.01917604253893452, 0.0532064990672682, 0.007309572771191597, 0.01682680841934468, 0.06132880412042141, 0.050650484793420346, 0.06473194900900126, 0.023500022212309495, 0.0311497174469488, 0.014384104404598475, 0.01889938854479364, 0.028271999542734454, 0.04045045462303928, 0.0247660175830658, 0.027429554212306227, 0.04777448019012809, 0.02818056016362139, 0.04183781785624368, 0.055077114940754006, 0.01852070663257369, 0.05950479342469147, 0.017024034800540124, 0.05244539990755064, 0.01762011424372239, 0.02664985810406506, 0.07447430730930396, 0.02484064795342939, 0.04195093642920256, 0.015088223586125033, 0.03238021016919187, 0.01615929450573666, 0.034246144151049, 0.05555669670658452, 0.048925363791308234, 0.0764860754300441, 0.033388391070600064, 0.08846614044159651, 0.02034252735653094, 0.07570946495980024, 0.008195330688197697, 0.003045457698005651, 0.04121658172724502, 0.051277729350009134, 0.018176304309495857, 0.0489786932510989, 0.04622500815561839, 0.0601916608533689, 0.040133117365517786, 0.051746464733566554, 0.026228866140757288, 0.027451033238321543, 0.03689453757501074, 0.0339228866754898, 0.0341798275310014, 0.014823065671537603, 0.08347035851329565, 0.017065506860879914, 0.05077761511451431, 0.027493346682084457, 0.050087086989411285, 0.03730554319918156, 0.013997452250415725, 0.06814206923757281, 0.02137948153540492, 0.09000434540212154, 0.01665659451724163, 0.04914932105956333, 0.0633226249899183, 0.06433892117014953, 0.043291589311723194, 0.026974776294082403, 0.018925714007179652, 0.052090576982923915, 0.01765239385089704, 0.03957531747541257, 0.027921034089688743, 0.01727128278331033, 0.027985555984612023, 0.04360900799344693, 0.05644702625327876, 0.05245374249560492, 0.05808542708733252, 0.06311416546148912, 0.02407924345295344, 0.020922489896682755, 0.022973787771271806, 0.015152462192678025, 0.013913569206904088, 0.012964892433956265, 0.04629612201824784, 0.016194272985947982, 0.037442983859883885, 0.032498757022299936, 0.02500612398476473, 0.0901886083717857, 0.02754823337974293, 0.0314432041985648, 0.03546066755162818, 0.03325885534286499, 0.032224598340690136, 0.02182785577939025, 0.028034729417413473, 0.08322331069835595, 0.004777987878437021, 0.02461765759757587, 0.033817381265440156, 0.058260095571832995, 0.024910803385344998, 0.023568650940433145, 0.057217574013131, 0.0450252530697201, 0.06282424780407123, 0.048917228156434636, 0.03299227589741349, 0.03297260177454778, 0.035904979067189355, 0.007012169176180447, 0.03508985494928701, 0.0492529062155102, 0.05562753236985632, 0.0039640940293403605, 0.04336624851982508, 0.01998898516675191, 0.0428304738764252, 0.03714456755135741, 0.018346131446638277, 0.013160949190413314, 0.009588296076149812, 0.024407382987971817, 0.045929882741932354, 0.06649765997592892, 0.04909703654370137, 0.04477295000106096, 0.01847600644188268, 0.01732139089809997, 0.031024660050336803, 0.05878956323223455, 0.05324104328506759, 0.046464436022298675, 0.0198201079786356, 0.04112182091921568, 0.06692072656005621, 0.07667248935571738, 0.03333849499800375, 0.010593890062799411, 0.048522812713469775, 0.00983583667714681, 0.047719959901379685, 0.011769043165259063, 0.050769187709582705, 0.04462446957560522, 0.03146310563066176, 0.07405565120279789, 0.08743250090628862, 0.033567836441631825, 0.018238015373104384, 0.028830176019775014, 0.04078699102891343, 0.060768782028130124, 0.03449165169149637, 0.045162764976599386, 0.008710454118305018, 0.009917202355739261, 0.023923903038459163, 0.003967814945748874, 0.0073676053268302765, 0.028536950504141192, 0.024485579059858407, 0.053444610576012304, 0.030388197595519677, 0.03354562799047146, 0.010947484839042383, 0.04519131433750902, 0.021167100074567964, 0.014092710933515003, 0.042903636914810965, 0.035543038310217004, 0.026317453976454477, 0.025522526453382204, 0.03484154166653752, 0.0527110429746764, 0.05953001457133463, 0.025406425719016364, 0.009584807557985187, 0.021322242017569285, 0.020178092876449227, 0.01564987076978598, 0.022987573906513195, 0.06923457168574844, 0.05665430513077548, 0.045890449679323604, 0.01445558637247554, 0.03857861738651991, 0.06061553489416838, 0.011705553491732903, 0.053299872271184406, 0.05966719399605479, 0.040391825804752965, 0.010219593183137476, 0.043219342295612605, 0.05408216207953436, 0.01832616555371455, 0.03605896580432143, 0.015576261594625456, 0.06602339113929442, 0.009875234116667082, 0.057825086771377494, 0.04031141601236803, 0.022926146131274954, 0.032791477029344866, 0.14873589389026165, 0.0612959765962192, 0.022246021644345353, 0.032253595534712076, 0.0552270745725504, 0.03569959330239466, 0.05033295754609363, 0.08475649449974298, 0.10852643115712063, 0.17634332605770656, 0.11785904930106231, 0.07397195390824761, 0.13636084007365362, 0.1419631237430232, 0.1733466847134488, 0.11895112427217619, 0.14476642331906728, 0.1227816715836525, 0.1682442370802164, 0.07164788325982434, 0.11705679020711354, 0.17033440992236137, 0.10844544121729476, 0.13566021195479802, 0.09671950792627675, 0.10597412846982479, 0.11563774278121335, 0.0810551606118679, 0.10479792194174868, 0.07143982406705618, 0.20634722177471432, 0.05431776300870946, 0.13502739662570612, 0.14634778989212854, 0.1390700132719108, 0.10338458778070551, 0.07284428977540561, 0.10435297938862018, 0.11681105196475983, 0.0967009092814156, 0.16446117364934512, 0.3168012691395623, 0.13952616522354738, 0.09589278085955552, 0.09052802515881402, 0.12675000221601554, 0.17441221539463314, 0.11545045354536601, 0.2794133110770157, 0.08130942125405584, 0.06588330079934426, 0.13832210483295576, 0.1571760145681245, 0.11946111119219235, 0.08484949450939894, 0.18671121900635107, 0.1413663521941219, 0.09141269233077765, 0.2216823846101761, 0.18245046692235128, 0.13269293760614737, 0.13196337675409658, 0.13888486820672238, 0.1475072976733957, 0.1391966279063906, 0.09249782588865076, 0.11424504965543747, 0.14249008760920592, 0.13913987523743085, 0.06797734807644572, 0.11622567980417184, 0.1553152815571853, 0.13962297860000814, 0.11068867120359625, 0.18750693702272006, 0.19204531849495002, 0.10531459921704871, 0.09956721083394118, 0.21798781571643694, 0.14882642403244972, 0.11245109806103365, 0.13084853014775685, 0.1419137263936656, 0.12425764809761729, 0.201487431834851, 0.10460260563663074, 0.1129077249871833, 0.14029463327356748, 0.09101766959897109, 0.1411065954182829, 0.11692990415862628, 0.13892810445811066, 0.11756243450301034, 0.13399356710059301, 0.05621029556329761, 0.18019907415977546, 0.18381361663341522, 0.09435309669268982, 0.0985102296939918, 0.09406628672565732, 0.10362117258565766, 0.10302658591951643, 0.2192496872906174, 0.139723361070667, 0.174039075417178, 0.10685663111507893, 0.12945954182318278, 0.13663078844547272, 0.0973088630874242, 0.12584402225911617, 0.09248348165835653, 0.10872340308768408, 0.11080964721207108, 0.12936236203781196, 0.07308751743819032, 0.11446488143077918, 0.13274521194398403, 0.08854750357568264, 0.12264247690992695, 0.15883966029754706, 0.12680421716400556, 0.1542695912399462, 0.1443429903260299, 0.242007955376591, 0.15921381807753018, 0.11623562712754522, 0.12302042091531412, 0.06469568131225449, 0.07873101532459259, 0.1624689676931926, 0.10637388059071132, 0.1775183587202004, 0.10442577941077096, 0.12825177663138934, 0.12604090598012718, 0.1500201571200575, 0.14601586413170609, 0.1557804580245699, 0.13149855312492165, 0.10260505282453128, 0.11044150803770338, 0.13963828635002884, 0.09606827715677874, 0.14923159086278506, 0.11022493323045117, 0.11384878520454679, 0.12388141400047711, 0.15883512768362248, 0.1417058232639517, 0.149276306320514, 0.09269692841917276, 0.06991592262472425, 0.15115322917699814, 0.07127478399447032, 0.12950395872550352, 0.12309465264635426, 0.08358604194862501, 0.2245646928037916, 0.10913529420005423, 0.12007268837520055, 0.12520355305501393, 0.14747771354658262, 0.11586218859468188, 0.10004063828715257, 0.07991165947169065, 0.16908095218241215, 0.18932861355798586, 0.13564680410282953, 0.07773356206182923, 0.12054395808705262, 0.15456232481769153, 0.0891920236338462, 0.08748197967984847, 0.0778850857168436, 0.11467435876173632, 0.12192180486662046, 0.17456496719803127, 0.22193739164088452, 0.17255001674805368, 0.11993443007980074, 0.12367303589625017, 0.11280698967831475, 0.12458495981991291], [0.027163544736270393, 0.07215073199144431, 0.04743913461321166, 0.06837737161133971, 0.0667251863383821, 0.01632881799845823, 0.10375415866396256, 0.01062405772972852, 0.045363516347216706, 0.0733751416472452, 0.04053869470953941, 0.01788052580585437, 0.020547017455101013, 0.007116937527566084, 0.03627020732632705, 0.03193179012409278, 0.020866057835519314, 0.02944020614294069, 0.007393151322113616, 0.08018329061035599, 0.01914087576525552, 0.018004928416173373, 0.018297429595674788, 0.017432180399607335, 0.039610333275049925, 0.031132991558739116, 0.015161332341709306, 0.022773860820702145, 0.07150563517851488, 0.045020510109939745, 0.08886968557323728, 0.009740245511888393, 0.03385078215173312, 0.027803001226857305, 0.046923933151577196, 0.030825221644980565, 0.039462073373475244, 0.025144037923642566, 0.06467662126358066, 0.03174899618274399, 0.016137240421293036, 0.01086046950825091, 0.043318886775523424, 0.06045624201319047, 0.031330258652035675, 0.023051325664190308, 0.03077036887407303, 0.03880829470498221, 0.01279264547130359, 0.028996108365910392, 0.049753922902579815, 0.030496844622705663, 0.08169925997831992, 0.053685358193303855, 0.03827674733474851, 0.07511690032801457, 0.013927889688472663, 0.03018887454111661, 0.030272456484713724, 0.027897492317216735, 0.06988018418529204, 0.08606078808328935, 0.03869047727701919, 0.06938406652105705, 0.029684933368116617, 0.022282562451437116, 0.03963975116078343, 0.02686226331362767, 0.06035247365278857, 0.013938669913581439, 0.09944453848791973, 0.0021161624296967474, 0.06994828874511377, 0.022069344696189677, 0.07940485488091197, 0.008310934395662375, 0.059829384221562316, 0.03956763306632638, 0.08064446372113057, 0.08562055456319026, 0.029908778678093637, 0.04080502309703401, 0.026745000588042394, 0.034044880486492596, 0.027662849818755473, 0.06475801832441773, 0.045915033003049235, 0.020960406433524828, 0.012657133546391768, 0.06170104843165193, 0.02290389357533838, 0.005877601797692478, 0.03224363464063831, 0.04015147852312241, 0.04589703146900449, 0.04752557997458747, 0.030890140482889752, 0.014280595583841205, 0.06722450668790511, 0.06222242795463119, 0.032278565623398335, 0.015717273045863425, 0.10109763299780232, 0.015180290610130345, 0.01893229240418545, 0.05291267304814287, 0.0438552212103137, 0.036565359881413836, 0.026586664441440786, 0.041555153738175116, 0.012863551532583577, 0.036165068325187476, 0.031343934525336535, 0.020006389589980245, 0.013216256579783345, 0.03610016984332885, 0.05258534775514688, 0.016867601944665824, 0.023076268611475825, 0.02222811510520322, 0.03957870336515563, 0.045422460684286695, 0.036063359318567176, 0.03988513995760253, 0.035644920343267064, 0.03178310274545636, 0.03905479290655681, 0.026827685169077346, 0.020319991512224078, 0.02966105572081038, 0.05274471188230174, 0.014508325506799986, 0.03964925743639469, 0.0416653580032289, 0.03246050800329872, 0.03257862737934504, 0.00903885149663048, 0.024630939920565913, 0.003918451523142201, 0.0345608656560736, 0.03984851942264608, 0.06244542170315981, 0.026088234669129764, 0.04328309405328972, 0.023409863568044136, 0.022223017610875622, 0.025305687017472725, 0.05387655579085861, 0.05407798908916967, 0.05118093293692384, 0.004660653482590402, 0.06809573886649949, 0.016941655560263565, 0.05025306683299797, 0.03549723380378314, 0.011140992000166858, 0.02081372412586851, 0.03987118249226894, 0.024907894166452543, 0.041351315033222945, 0.04845876579305955, 0.03532105218619108, 0.05498422010402594, 0.022788854748276726, 0.01145385516740914, 0.05492859041052205, 0.028033582693231956, 0.04414660789604698, 0.0388761244581214, 0.024699353213821138, 0.03398713715640562, 0.010886308969929814, 0.014053573033639362, 0.015357011663062232, 0.008947158515054201, 0.0582577342699681, 0.057475295183914046, 0.05093418028471725, 0.02636093958946211, 0.0016410718235420063, 0.015602242700489504, 0.05868710444441863, 0.04168711183592677, 0.04968453591157283, 0.08943602482655219, 0.041033584225390635, 0.021978638134896755, 0.06155481734978301, 0.0403956730983087, 0.011709397392613547, 0.04291478863784245, 0.022992949600198438, 0.0326979307989989, 0.02395892053443406, 0.0374063293981765, 0.05986970955772059, 0.030529746785759926, 0.03534630725958517, 0.010435859256956195, 0.014846202019335968, 0.05300221931455391, 0.05872951288308416, 0.02688251928027187, 0.021223240365673388, 0.015130676129566771, 0.029686660239739076, 0.0356589592328029, 0.009428570629097521, 0.024965076008811593, 0.06063597236893006, 0.06506986623363835, 0.04342498251103929, 0.03792587009125522, 0.04249543703294226, 0.015056834556162357, 0.05321524877633367, 0.05047004197591117, 0.03321047579603536, 0.016279768398297683, 0.04871212398367269, 0.05287101439067295, 0.03683816488566143, 0.047349340681518824, 0.02246926136181823, 0.027172408099951487, 0.06785138483558383, 0.06683035926627261, 0.023278904613107443, 0.02880450025466936, 0.06339440042419092, 0.010407267487607896, 0.009446271063227738, 0.03147923780073013, 0.03131240978837013, 0.06361292941229683, 0.05160953297412821, 0.0367159844775285, 0.05143079327951584, 0.046123512887528965, 0.009352870717910784, 0.04529031938208001, 0.02668934714581285, 0.06207314346517835, 0.014890873372288687, 0.012799412161777062, 0.0264587656794382, 0.09432493748941592, 0.01269257512675332, 0.0798274464905262, 0.05108076759747096, 0.01725181222095021, 0.028532115942133323, 0.01732334168627858, 0.025928914646751115, 0.02897167092721377, 0.024569427328450338, 0.034846254092242034, 0.03078387172094413, 0.027448510784389715, 0.027829496322997978, 0.01356679031492344, 0.04621756462646382, 0.04538407935095685, 0.007982845750770398, 0.0042926012455219665, 0.05365422361397317, 0.05686739905338202, 0.051961153213466914, 0.057584396829562526, 0.02776249438258154, 0.02398322056978941, 0.020991118624806404, 0.03392532600888184, 0.012720590141335768, 0.032458960943456204, 0.017845218236159, 0.029941026054854904, 0.035090787934937646, 0.05097566591575742, 0.015120645685653602, 0.022054932612393583, 0.03132192284933158, 0.05886823936764683, 0.10226746129670314, 0.033863138274422715, 0.07104249431618623, 0.019112770844783102, 0.029895723664334843, 0.055484205417867215, 0.0024596881703473628, 0.07010306258286748, 0.012122392820726548, 0.0435000793742282, 0.022071953663336377, 0.022389112805415477, 0.014910645882732101, 0.03296052045854075, 0.02385453470716519, 0.0669265076784151, 0.03668691264465451, 0.036782833747565746, 0.04494875842439277, 0.045589275125946314, 0.02795287604177637, 0.026029013829039674, 0.0353832467060004, 0.03000990075192281, 0.03974525996350816, 0.01545437634922564, 0.01779739508804466, 0.03605592596743788, 0.0414033993812544, 0.027284513959395032, 0.02321334625594318, 0.03993683075532317, 0.03577141962679369, 0.014083767841969217, 0.0511542495473155, 0.07670098782650062, 0.019357143535411785, 0.04937035044921296, 0.0011661109872095818, 0.02003744274510869, 0.017949001863598824, 0.02598759944417647, 0.007192944475848759, 0.02932029204177005, 0.03732925460540822, 0.011398938783843602, 0.03955338043825967, 0.047816437403006215, 0.04221563293997731, 0.06261090960885797, 0.00476972883500691, 0.020210455604163662, 0.02401042982403721, 0.09379223321697541, 0.026627457966761928, 0.0717034281364509, 0.03842620824330619, 0.032400912272610834, 0.05037433461153081, 0.023381936763014113, 0.011436778137327304, 0.11011398596955196, 0.027694186262254204, 0.021019562812788144, 0.020829710410907865, 0.025810947941083993, 0.024247336933123212, 0.010749496802288507, 0.0062471048274476615, 0.1394669698285205, 0.11050787554787737, 0.14911458428416932, 0.12423100881278515, 0.10501500565026488, 0.10073840298822948, 0.1995531456278903, 0.07101719853069101, 0.1486347514603819, 0.12423341082675116, 0.08149516343006066, 0.14513782624687466, 0.10307826314653669, 0.12234464074884142, 0.11968216433056764, 0.09754298481025866, 0.14651878071682795, 0.14419449972254889, 0.10954285625900541, 0.18182008074862616, 0.2092620860785246, 0.10554028674960136, 0.12091084197163582, 0.11900011450052261, 0.12317714893392154, 0.2081173025071621, 0.04715426864900759, 0.11143090030444519, 0.13589053388152803, 0.11083944847009011, 0.308657600411347, 0.06611824354955129, 0.15632796793111733, 0.08853839085038219, 0.12161285430192947, 0.08247185352125339, 0.1517000062657254, 0.10859259510678904, 0.17921979885016168, 0.1238075215369463, 0.09196779504418373, 0.1634051153170211, 0.11040085021938596, 0.1498679888567754, 0.08984988369047642, 0.12101749410586697, 0.17893068864941597, 0.13088371897382395, 0.09141485685748713, 0.10341252306742327, 0.17504737845488957, 0.13689354434609413, 0.13169957590954645, 0.11911138067288057, 0.1451284353222166, 0.20772878692618438, 0.07249531242996454, 0.09089892597070762, 0.08655947060989481, 0.12149316072463989, 0.1509415941046817, 0.14162939307945116, 0.14017485827207565, 0.20414690912834235, 0.08060692716389894, 0.1271670569798776, 0.20402057947857039, 0.10528672499848263, 0.18866516915815218, 0.1023411298436778, 0.18294437256242546, 0.11396689100989274, 0.15331596455403737, 0.15776773781648704, 0.20210517011582851, 0.11385543484772954, 0.17150204655315193, 0.11336053854652814, 0.09724683141601936, 0.09923033855323281, 0.1282522108938013, 0.1410904327141387, 0.13235714419611863, 0.18064762651920319, 0.10631347740335123, 0.21158076237354959, 0.22751340243433202, 0.16930822070155824, 0.10134725924581289, 0.11283851441528116, 0.14208960267049925, 0.1530087510389941, 0.11766464901821953, 0.12328984002981867, 0.15785081764417036, 0.15342033681060585, 0.1265809927135706, 0.06792772681053195, 0.210885847519551, 0.11295267793216876, 0.18902738472180708, 0.09395649297428982, 0.1761427511061941, 0.10788782113896948, 0.07482462815408196, 0.07630674540996552, 0.1860377730003425, 0.20313013797359808, 0.13106879618551048, 0.1719868326825755, 0.08234469605875866, 0.15286393809531415, 0.14182417334190436, 0.09612584406776087, 0.17815057693847589, 0.12373271983649049, 0.1760275358600276, 0.2357910546873297, 0.19657935734306062, 0.13462989724108151, 0.11229759986911501, 0.14757367196891988, 0.11939593111830098, 0.12881278938480786, 0.10256073770246335, 0.12127212115696498, 0.14549890187169823, 0.07637898903340101, 0.1234089093548911, 0.10669342308704342, 0.14896572727177823, 0.10645406985921518, 0.14005040137895516, 0.162557543654527, 0.11787110008299351, 0.13959640716867788, 0.09861330594867468, 0.11600943069372859, 0.12125757336616516, 0.09148678156946387, 0.07176984314407621, 0.1585605245615755, 0.27977982855268885, 0.11810864162232194, 0.19727159876908573, 0.09377134112375123, 0.13373058049806527, 0.10019560211471149, 0.08844925849033253, 0.1696268878877163, 0.1422167329915932, 0.12597891502082348, 0.1340307236782142, 0.1798280104994774, 0.05727527663111687, 0.11998682655394077, 0.1618701062564339, 0.1100148248619267, 0.2182306633996112, 0.15997091388063772, 0.14290469964700087, 0.17387846617826394, 0.15802742673882417, 0.08172205196959631, 0.1572256697607892, 0.16530698112079076, 0.08724491990038327, 0.1392411533743143, 0.23164189447249683, 0.09195823448577098, 0.130197014393551, 0.06782288636480059, 0.07228542119264603, 0.11709972790309361, 0.09598578086921147, 0.09786208625882864], [0.02813797360951347, 0.03192993772349187, 0.011373294400982559, 0.014022329888705696, 0.04918627407667892, 0.0511053475285215, 0.03142922976985574, 0.014295233280530997, 0.054528872216386456, 0.03257101082376071, 0.0596540846994945, 0.011927839019335806, 0.032637639569916894, 0.05646086836765919, 0.06310689156608922, 0.0502093250730208, 0.021896001051313112, 0.04967499231653554, 0.02156789374670812, 0.03804314469120332, 0.04090466596452253, 0.0437774034217, 0.021071321464010646, 0.016104740290237323, 0.033189461566507816, 0.023290943520675813, 0.08045726948018585, 0.08561168611049652, 0.016734548012859056, 0.027579166094905565, 0.029660665563174655, 0.012802027066105177, 0.016875795255016004, 0.023133240107979094, 0.07396306509950332, 0.024743770116141865, 0.013022597596448447, 0.005173968616873026, 0.026328466599807143, 0.04728667797254665, 0.03565385325678757, 0.052637774763362746, 0.03689999978191086, 0.08709480081285749, 0.05730097275227308, 0.08273813780397177, 0.023044742178171873, 0.008659614882032787, 0.0676425996103457, 0.06426348843212638, 0.034662360924163034, 0.009068581508472562, 0.05939679779112339, 0.034420622645744255, 0.00894085577289973, 0.058206722007266114, 0.0354385676660708, 0.034822722497795305, 0.013963617101710821, 0.05551723989525011, 0.02697734963814063, 0.015198999516932028, 0.07781411095389298, 0.014508849675101894, 0.016721740664382066, 0.028439718132306422, 0.0277466505898961, 0.007305817928032151, 0.013329365822885717, 0.02427573871266629, 0.054888516132320674, 0.02554681970338736, 0.06633831959749971, 0.02539912298587816, 0.02710207285625594, 0.04562421967940671, 0.0381854809820652, 0.05452315555885434, 0.09522646625659295, 0.02886400438312973, 0.0524125859540488, 0.027369542878919413, 0.017036540200933814, 0.03660823650924223, 0.027174046762021523, 0.01335392115704183, 0.030186798223959546, 0.017173812924219028, 0.06388918815978936, 0.0666816176048347, 0.025640047022274563, 0.0588645413517952, 0.02617912782755281, 0.028208224036331688, 0.048627130687236786, 0.03336544980161956, 0.013324582151004245, 0.01152716324265514, 0.028843923139252832, 0.03717357831607972, 0.09609921156827893, 0.03981574957392045, 0.015789900041584457, 0.02873805132029312, 0.07307354640215635, 0.01894747632156525, 0.028993451901312386, 0.029463954868593385, 0.06224601383187941, 0.035663200076669455, 0.05653704410152776, 0.02729899898570563, 0.03843490366957017, 0.02136152410613639, 0.01518133216138397, 0.017911061578031098, 0.054475532578570504, 0.08647528477013111, 0.01868867628010256, 0.06093207826571805, 0.07011820748448372, 0.019874099010069455, 0.08125815793339695, 0.018829843794394816, 0.022206483408808708, 0.035048111474939754, 0.014669562390606319, 0.05465026891657284, 0.028244242371459092, 0.034048307088336775, 0.037271735191877396, 0.014261467681665505, 0.05382569959121091, 0.04691099009609648, 0.026307391302127923, 0.017792575793074708, 0.05236410801964147, 0.04690861861620631, 0.05239144280286772, 0.048121259082108736, 0.03796261276251503, 0.018009354160832505, 0.07061421658311572, 0.054641471710056067, 0.01848433885191168, 0.05887554718979767, 0.023161126200907996, 0.063260722240167, 0.008841095009951718, 0.04503503075933882, 0.008681861500787948, 0.031425609785531244, 0.005842052075812327, 0.0362552693778915, 0.025181433684857826, 0.05934364814311266, 0.03423222400514143, 0.04903367833633508, 0.06908179952629975, 0.028811153290527206, 0.038854937202164104, 0.021727215465424315, 0.048466877679207494, 0.05225540670965399, 0.0481352335108178, 0.021857151528820395, 0.02928018044414265, 0.06351186162126915, 0.0132295957300812, 0.011519171796473009, 0.009400589541266007, 0.046781549363264015, 0.046338998646076233, 0.04175155230664781, 0.014775315465937768, 0.02171787034187998, 0.02371287695132196, 0.03027435638276594, 0.03967580172632422, 0.028547511901706457, 0.026223697400252734, 0.042667601723223925, 0.05658162045957787, 0.02616405756478863, 0.05263611574524215, 0.011243751887897295, 0.038217925133981874, 0.06716475489416293, 0.016788576363718936, 0.023912557932947363, 0.0644315140587943, 0.0834111902596695, 0.012621455326942461, 0.049555210529693534, 0.02730968760858689, 0.006611607054115406, 0.00582545850193128, 0.014764362214399236, 0.010661495051213672, 0.043568404457931004, 0.02997426748541849, 0.013540045857163412, 0.0186482678234045, 0.034045830435518704, 0.02164836460724473, 0.03873624446402703, 0.017947783893240348, 0.03183522441291383, 0.06760641333780118, 0.00402770541508549, 0.02896684654323118, 0.020062821651143686, 0.03909616997199399, 0.031468920675771575, 0.05121098864557488, 0.04603385805551495, 0.03999169709693108, 0.0479077614311661, 0.035090014405016384, 0.02062530173654003, 0.07510472740978003, 0.10138220379927329, 0.02633114850946835, 0.02008056194920625, 0.0036268290464899367, 0.013836578382844371, 0.003941316456933106, 0.03040386496910027, 0.035986576295856915, 0.021425657539761493, 0.035467388440987895, 0.01891822467691132, 0.024145383653896194, 0.06759835912712983, 0.030106714128383567, 0.020744245532634, 0.03073043030287538, 0.02175219912481095, 0.02815175974475486, 0.050334060165498934, 0.05752906908414193, 0.02616547231030251, 0.02828986367343792, 0.035051616108311076, 0.026143080654687116, 0.04166172444820404, 0.037405213208070824, 0.02147324150428176, 0.01883167414260762, 0.03703827164801104, 0.06181072683206626, 0.021498250608731593, 0.031084401666053703, 0.08764540483908993, 0.10348509238766772, 0.01641855255833694, 0.031201560915048634, 0.03079936606809497, 0.006055413595666843, 0.03115850786811539, 0.018082076151456152, 0.021015763016683713, 0.003588772561800267, 0.01823035640908139, 0.059676727413066795, 0.06907542129712445, 0.058364834237311564, 0.04248701302068574, 0.016451412312952534, 0.01302356705335634, 0.022895442421681116, 0.02293567276293678, 0.045895932242274284, 0.01786550473687904, 0.04098572715052536, 0.008187456289306283, 0.0237911476620606, 0.026242667543036596, 0.014427825808525085, 0.020904695315818702, 0.026333145098760724, 0.050620459618845155, 0.04777001542970538, 0.05798883084207773, 0.018419197793783884, 0.042391940086547814, 0.021940217785803334, 0.0353054289173867, 0.038129325423921855, 0.037935478147119284, 0.01581117550709418, 0.027249942600194896, 0.03606558830610343, 0.011972521398482578, 0.06843738124838897, 0.04680794098281434, 0.02807431684673897, 0.005050573631056717, 0.035780725734574456, 0.08130058672811304, 0.025534628125439798, 0.03228448584143605, 0.043384772525834184, 0.0064826586832558465, 0.010164980443992784, 0.04810816674892392, 0.007973897570211972, 0.037735978673611364, 0.022123418848163316, 0.03314703955714192, 0.024679891133148755, 0.01897093327715993, 0.032885515197579346, 0.016126833390444517, 0.0315026438661984, 0.034056347728307755, 0.006842922610563359, 0.009708891256845422, 0.059287051537207196, 0.00553800435071545, 0.0348220236067261, 0.04219521242859108, 0.026797916141471693, 0.018019433798534528, 0.03785782999226025, 0.008932341854753239, 0.05818461533635855, 0.02940692739295108, 0.009452838434039481, 0.02532273351347872, 0.0280166176214282, 0.03710370956520949, 0.03566819070173161, 0.06378696685922997, 0.06122618926955121, 0.036608965934387276, 0.011195511440746486, 0.04927689582109451, 0.07211411824183804, 0.04743859178519674, 0.06516169237771205, 0.016857559626389827, 0.03782513138971158, 0.07138697297445365, 0.028123091640216962, 0.009506208605931273, 0.038293320552578995, 0.07485311305416481, 0.06643820673759494, 0.02859381852405412, 0.027569987212440798, 0.04154420896832432, 0.15012892628354685, 0.16199794225394726, 0.07429193745234183, 0.08085947789783988, 0.10683438195181744, 0.16731659828552178, 0.12111661450139113, 0.12673071825078555, 0.1765969353062766, 0.13727185476039136, 0.12826709795211041, 0.1138638893940619, 0.11360359657555819, 0.13529862064336026, 0.12524396660072462, 0.14836588874459267, 0.07970268425664731, 0.07632042467594147, 0.1052007410409195, 0.12528648360499314, 0.09327806652124439, 0.16532409377396107, 0.07716400655252592, 0.06911228610468761, 0.0953332744538784, 0.049110909192157645, 0.1048416942358017, 0.14855742560965673, 0.04580431644405637, 0.13231731419052395, 0.06932909161384616, 0.15383023981537136, 0.13258145430258342, 0.12438757398298808, 0.1458075674516814, 0.11068833872143712, 0.0871852563161935, 0.14110550976225308, 0.09192645869084767, 0.17005032088075364, 0.12347651858414922, 0.10271911456116609, 0.13061809965542384, 0.1492908676820142, 0.19280496558972768, 0.17856360120432718, 0.1080182898523552, 0.14367744246763842, 0.09926255539591823, 0.14507609313087805, 0.0997041527714048, 0.06580986973962613, 0.08900967413293463, 0.10810791075761829, 0.07915946269141776, 0.15435241322432244, 0.12762630305119924, 0.10968226127858673, 0.0695851096617324, 0.10163780115544796, 0.13363163652164595, 0.107450593529003, 0.10983451096607105, 0.16434354281851224, 0.16374400284673485, 0.14185671588139875, 0.12380123830267362, 0.09616074112376996, 0.08685107103415898, 0.11316153101090874, 0.15994669018047197, 0.1391421551150935, 0.16546501192663396, 0.08212531211652926, 0.2087887129081147, 0.10442424592162881, 0.1434034500271082, 0.1915868188121489, 0.11203226553542273, 0.12383226092372622, 0.15960837262017386, 0.10872025468519755, 0.11150347641003983, 0.145926351792046, 0.07963333797774144, 0.12997338282210485, 0.16230484364288195, 0.06689671999109642, 0.1967945886509759, 0.12149037873106343, 0.09300215382661138, 0.16675790612186703, 0.14972583577036858, 0.12902271454887732, 0.10495004949292966, 0.12159123617623534, 0.10949563700705767, 0.10146185023976223, 0.13900036843759672, 0.10204631316342525, 0.24933293089270592, 0.11979223628129278, 0.06825262294816119, 0.10839120591325418, 0.12448050613914217, 0.12978898414543696, 0.11916289505149637, 0.10361605643161706, 0.17439299928290503, 0.0964082774839231, 0.12375136597880296, 0.11794743527259145, 0.12516282738319465, 0.11306163708546332, 0.08665924239903688, 0.11365359782108239, 0.12945810332894325, 0.12557805010250636, 0.14393079387290136, 0.18028306322438375, 0.1510553437152079, 0.1827751323580742, 0.1464144220309598, 0.10670487675815821, 0.14620134846440383, 0.12476329239351408, 0.11860119019235883, 0.15769824225987705, 0.07258925560329642, 0.1779098462845598, 0.1169236209243536, 0.13166022087846482, 0.13279625134808676, 0.10144748565341745, 0.07081313590918269, 0.17940214835107327, 0.15240739259336675, 0.12209640549761908, 0.11703544349542686, 0.1222326960414648, 0.10653155855834484, 0.07563380830522094, 0.161561196403844, 0.23027551493474416, 0.07686113566160202, 0.1634547162268843, 0.06232103944889136, 0.14250646744455608, 0.07553989227328982, 0.07929162095699992, 0.09788190626672336, 0.09599884945367064, 0.05802167193698032, 0.07584369275718927, 0.1062563176133803, 0.1612954820905413, 0.10764644587678568, 0.14144413944865974, 0.12715102998273714, 0.1078620096668601, 0.07768656672643763, 0.1307142073554652, 0.14656702455665382, 0.13767373748123646, 0.09739647552903209, 0.09853768322084631, 0.15757569883550915, 0.1191443574747869, 0.06805033130305153, 0.05058333018262472, 0.08149633729564291, 0.16805906487362726, 0.16373940237930842, 0.09552658908069134, 0.06387168874165841, 0.07003959241722311], [0.02864499363516058, 0.034685929838035784, 0.09018892728324447, 0.055551017368478436, 0.026357163542083333, 0.02204684617130884, 0.026602006118212427, 0.03607719125492232, 0.030605383084288666, 0.04608298399086509, 0.021815316452245628, 0.0030342629304089186, 0.03902900179049798, 0.04162286135501095, 0.013826617488770612, 0.043193527430828126, 0.020773251208343675, 0.008985164109617472, 0.039938988496682475, 0.014847918712933148, 0.05218613167692508, 0.04699711315333843, 0.04642805975994893, 0.043348202881004126, 0.02358595358340868, 0.011861887111860727, 0.06487882469913789, 0.05133278907409736, 0.014010142551601996, 0.03358650293999484, 0.028579555717962127, 0.08193412130432469, 0.024148260642375265, 0.041765391028353145, 0.02467533477049853, 0.055345265194773674, 0.011298722554264324, 0.0025645502443824497, 0.03844581111999495, 0.0892559891300542, 0.06706314427512032, 0.007123624490174864, 0.013100610463880002, 0.02051325694524816, 0.02506783335203571, 0.029502132641417638, 0.04219416409198727, 0.02955699898302555, 0.06595730861382824, 0.036588216333517005, 0.04518282586442573, 0.048525000988904915, 0.1046601114794612, 0.016458182396101098, 0.0347582141735724, 0.02861130776415978, 0.05892672908625432, 0.07327560056000948, 0.030634152969079356, 0.032020908913442066, 0.03165903940264668, 0.037841399266783676, 0.022241600988698856, 0.06620399680520807, 0.0284620436307575, 0.04086674264233027, 0.030769055908811942, 0.0167452434210905, 0.024715029069089463, 0.01835220942406782, 0.021302747706483518, 0.029647583408015113, 0.04266946430185011, 0.01989755087665149, 0.06976338795253209, 0.036566364113241434, 0.019813398963638713, 0.01909888462562646, 0.05040673126599618, 0.04610150121152401, 0.026844860586736883, 0.0790713888459972, 0.03552468054528747, 0.04689604536231075, 0.05077715031802654, 0.06018560832100255, 0.029920286632009914, 0.028141556274411932, 0.04702154719935996, 0.061528924453471384, 0.011784182977862656, 0.031669227605951686, 0.02377751928621105, 0.03616412516151156, 0.014499847211741974, 0.05109158344566822, 0.059439084093485556, 0.03094788042030164, 0.029995339390422617, 0.02658838452771306, 0.07993339973368815, 0.02842373015092952, 0.05777911602386406, 0.015444620711995023, 0.028028581890144517, 0.04501901054754853, 0.01645031478255987, 0.021011474675365856, 0.062158252112567425, 0.027902769623324275, 0.034843173543257375, 0.010859979266699935, 0.010280649460453008, 0.06123886430369956, 0.007461590908600816, 0.028813816540475403, 0.09273204260638782, 0.07372318939971072, 0.01590975307460342, 0.027630612620019486, 0.05383090056212885, 0.04802322434261441, 0.05452885525301099, 0.028889795499188558, 0.02406943353292133, 0.045720941453639946, 0.03618057963571378, 0.02427779806644789, 0.023871672805398703, 0.04083450883626938, 0.027785198164305518, 0.023062726748841147, 0.0478272871779544, 0.0099948598404548, 0.019697354208411913, 0.06676577630319766, 0.03476201057700174, 0.010782686494556921, 0.06351480646325008, 0.046366112905421426, 0.05628666467964649, 0.022238861403561065, 0.031461511073367934, 0.03823692072182894, 0.034902772666620355, 0.03839178276913507, 0.02160741332253175, 0.0392883921574269, 0.01810607932774084, 0.04893545021436044, 0.03793534244011555, 0.029649334028363228, 0.038053509313613176, 0.04151585977524519, 0.02875383404482688, 0.01856246028494622, 0.03685261768155864, 0.04118383901992014, 0.0451437829594527, 0.06521911679634027, 0.05011384841054678, 0.026259909117860452, 0.023021605830373507, 0.02900783345103264, 0.031165082872446095, 0.03526755648532084, 0.030168369212853055, 0.020735729918149964, 0.05979471108210938, 0.03577715324770127, 0.017240473900788596, 0.04955906121592436, 0.0729963630437851, 0.05717160326561757, 0.036097818719489236, 0.05197734984436205, 0.013788025809584983, 0.08734313105898243, 0.04814939792933209, 0.025605884480423162, 0.022398196692977632, 0.020866924664005637, 0.09452923759818077, 0.013979341302599226, 0.03295369100357805, 0.019763255225760595, 0.044782907502459626, 0.027187069545366933, 0.05340120129819427, 0.055230989719608, 0.01889192296325096, 0.016000403656757305, 0.018920409559671367, 0.04283257733498301, 0.04790818551555276, 0.027848310402727554, 0.05224404803344181, 0.06311697459646634, 0.04580721039591091, 0.06269772137914385, 0.030659231623368602, 0.02133475589965071, 0.04230083997494408, 0.01047930246152516, 0.032497742612447054, 0.03605350359742131, 0.05388219780953867, 0.04558770771005324, 0.02436404156365565, 0.03190936454172645, 0.017706990474835038, 0.030940413142421415, 0.005175451215888772, 0.018383764695110064, 0.024021537442292486, 0.030665016134402583, 0.013646529205808682, 0.03462764707260898, 0.03403561169813786, 0.0539473948468055, 0.03997203654476574, 0.061401604142572196, 0.04652680356853774, 0.04475015800978456, 0.060448357436273775, 0.016292309421779852, 0.048230435366609266, 0.03348594744290624, 0.0681302695135985, 0.018322265673694865, 0.01954057190700301, 0.0494228419182556, 0.02109707865331854, 0.039151718241295645, 0.0520124674242522, 0.036626380535640886, 0.019333143751802187, 0.008784187126106449, 0.01607238774054817, 0.01718296466528305, 0.02588542564106839, 0.0236781156023166, 0.016132399073934982, 0.0021630585293418592, 0.044714304219399176, 0.025680304504930973, 0.025999394079138125, 0.031199386210313866, 0.04169003292918205, 0.08214387683463947, 0.07558129648012774, 0.054668555435325415, 0.07746607677212783, 0.049904421969716034, 0.06751590355166368, 0.05019945238849946, 0.04958616868991937, 0.09384186805358954, 0.04532338778621384, 0.015804841382695094, 0.04080631570624454, 0.0010263457079418004, 0.0032106445037892884, 0.0277872134133109, 0.06088902521878481, 0.06534999941608735, 0.03609709607969437, 0.08293987983571631, 0.05419254954904318, 0.03537157590367964, 0.026533779422087327, 0.023837057341422354, 0.02548682702971356, 0.017336410270737748, 0.0062927944070127395, 0.018452946429273913, 0.031837945338338614, 0.046131553527499945, 0.03788393323442765, 0.03127246103914721, 0.0836623567821724, 0.0717161778094513, 0.0035143896446762873, 0.030620704405009747, 0.036861119725342305, 0.03819706018215843, 0.030260979064873288, 0.037656830956361124, 0.09693482744374446, 0.04581579725657191, 0.04213327235941376, 0.028767475991376808, 0.05715233287108796, 0.0674534308324967, 0.04452995643285768, 0.0568955718273563, 0.11220772112054483, 0.025898419586675506, 0.0381088709857847, 0.03480404242873192, 0.028217967799199477, 0.0034850762957440956, 0.008754861690769238, 0.029510251312915767, 0.03832475707999297, 0.056838147408728085, 0.06857127656361886, 0.026445118643875633, 0.02273089767965887, 0.019914704241922924, 0.025532299053988287, 0.009999285585113933, 0.016113676596432924, 0.07807426806539297, 0.050653775688260794, 0.0413714709159519, 0.10303192599011318, 0.03414038768304246, 0.00030552383032045327, 0.03699736277173672, 0.0356381757051817, 0.03454808884167245, 0.025853734663022414, 0.016219377085300427, 0.004833867781729038, 0.04288375244608947, 0.03915208125753062, 0.007106407512245434, 0.024621511676481793, 0.04703605767073376, 0.04651621842224683, 0.0362760562981878, 0.02125931128726474, 0.043536771155361614, 0.008795478796985532, 0.012000052956864238, 0.04679820400529674, 0.061027751703347476, 0.0213973897708846, 0.04694452668939318, 0.08565320566828762, 0.04502835397475532, 0.016840613214299083, 0.0739065974152514, 0.04898921732923814, 0.03729317689846669, 0.012676127437901284, 0.038227580687297244, 0.0771621066544737, 0.026010226890710846, 0.05157688865438104, 0.03746874783454197, 0.12751012428530625, 0.18574569081621511, 0.17818079888820648, 0.1432013822985547, 0.04395489800455315, 0.07748910625066076, 0.10114864526050431, 0.0594779709354043, 0.11383184897048132, 0.07821583082633358, 0.138452410697937, 0.13464563925351414, 0.13770101458898612, 0.23491794296673366, 0.10208386329135724, 0.15435047261416912, 0.09469072214726891, 0.11684079893997737, 0.11209208518266678, 0.16905638921473706, 0.17022853131805146, 0.24320380549345696, 0.1703005645956312, 0.1705291766141142, 0.12690036557614803, 0.07606718862163168, 0.1328334214964083, 0.09803406774465527, 0.08902061211743525, 0.13212900715214865, 0.1551651760403599, 0.2034919328455414, 0.1144131092088563, 0.11472086555191449, 0.08071098729435887, 0.14959717196013245, 0.09671637987984077, 0.16714061344308512, 0.05847916738795383, 0.1704340460044997, 0.16205111225800856, 0.17820916165198597, 0.07771984886910234, 0.1391629318573645, 0.11222082363175494, 0.11038744915276766, 0.1297797289277826, 0.09960142256958143, 0.1557046520922865, 0.09069353342056274, 0.31447598391345566, 0.11146258788981608, 0.11794594249555043, 0.12048656759517533, 0.06632073196981635, 0.201034794694611, 0.11219090702278273, 0.15893787145614624, 0.23868131531136377, 0.09787643048912287, 0.15675883766795906, 0.1280883311160973, 0.09561480541846581, 0.13816392474940845, 0.13503781892359257, 0.10695302379982811, 0.18592050857841969, 0.13175775350204535, 0.101802047342062, 0.12305062929434435, 0.1279598165835653, 0.11303292148347412, 0.15099568691636833, 0.13425900999988827, 0.1516106432037694, 0.21863056479820184, 0.15331506888781274, 0.10345401548381362, 0.14489778769867762, 0.08884274094764676, 0.058332644536026886, 0.15750637969800405, 0.18928650367472852, 0.12707515619695187, 0.09662523905613593, 0.11522285932941095, 0.11531652430338518, 0.14402188041380473, 0.1503894565893071, 0.1937971602060965, 0.168803105662976, 0.14505243940012796, 0.1679205215935196, 0.22947117952363832, 0.10119056515395641, 0.10570186629359211, 0.14106213780386107, 0.08540919769023146, 0.15256238356232643, 0.09314775387091295, 0.12722011841833591, 0.15101596154272556, 0.17047418813620294, 0.09664515405893326, 0.19184373931160995, 0.12704008950718812, 0.13594483025372028, 0.10356498988611357, 0.15326079965702125, 0.12308284613702979, 0.12232416256197862, 0.0956021643110684, 0.13560943039400236, 0.19985043896096094, 0.16168125639004366, 0.09646060610456125, 0.1819442526570388, 0.14999971964529582, 0.15860675993774617, 0.19201361733887876, 0.19685883234654153, 0.10927670089794056, 0.14809105492063931, 0.1502471270837954, 0.11137190168457371, 0.06834043216492448, 0.0999810222004141, 0.10235232567148549, 0.15689822233148984, 0.12898352236620017, 0.1678649495754923, 0.17203825206628867, 0.11405535840562411, 0.08760623979781355, 0.16938727003123077, 0.16276790308100836, 0.10920542757958174, 0.14315218850970268, 0.15954121122402803, 0.22805388271808624, 0.15274642940078462, 0.10347745886870793, 0.08544468507170677, 0.10987042582460813, 0.14060344813125475, 0.15818411404533045, 0.12320777800466333, 0.10777618177235126, 0.08816656723086323, 0.1142932256417615, 0.13416314657245362, 0.13405114758227551, 0.08234187335308109, 0.16359220099236282, 0.14283802679606847, 0.09692832029291562, 0.08733294624835253, 0.15177347803754465, 0.1210046833647149, 0.11768941554640021, 0.151116656139493, 0.10147714441908257, 0.07889521401375532, 0.12328563311270305, 0.17489662154444627, 0.18619101334895405, 0.06425537315330335, 0.1541714072227478, 0.1403156135763441, 0.07708794277693544, 0.08955125364341907, 0.2305111022932189, 0.20604634577674524, 0.19606306004737103, 0.13351153582334518, 0.0972390825461064], [0.06411550672990934, 0.03536680240982345, 0.06224445998668671, 0.04128458111413887, 0.04442184205566134, 0.03311971155926585, 0.0345486689891134, 0.04320409222106848, 0.033944701576339345, 0.07022704450147492, 0.11074203798281294, 0.024708947698984827, 0.038556439469435384, 0.02426351829698043, 0.009207114610554916, 0.044288201191063435, 0.02892473665997386, 0.011510657878326518, 0.034058369762663326, 0.03796148639438408, 0.0963076710967081, 0.04721027832212193, 0.020464533041896563, 0.050101227659199915, 0.04207458925832595, 0.04140370472201279, 0.07256199885159731, 0.06618016665535313, 0.057257499013628275, 0.03561991293515478, 0.06020223242895944, 0.0019041651893141015, 0.024359610729983876, 0.016025193933663622, 0.04992257956681507, 0.028346414478229623, 0.01663689494931272, 0.06301929948053189, 0.016163492941164544, 0.03107278175385935, 0.07055872598929064, 0.059250587065305026, 0.0701172643208078, 0.025781082222238183, 0.054980840999633074, 0.030129557009786367, 0.005680176096835307, 0.030118669915412153, 0.04077900127906885, 0.034709916050945006, 0.06411796302667686, 0.0489041426086, 0.03883216217426317, 0.018598393803196292, 0.048407953698188066, 0.025160456774756312, 0.04389273741149476, 0.04003848208646689, 0.025901759675304805, 0.03828348518748369, 0.09449001827410289, 0.01753703271970153, 0.05731328137751136, 0.04584814980626106, 0.05517284944653511, 0.045318766962736845, 0.020609359556276883, 0.03775913368112274, 0.032228689906852584, 0.050538499373942614, 0.02827412505368037, 0.05039642431906291, 0.08914388157427311, 0.027041028453303233, 0.13572123939437525, 0.0824190770675029, 0.03793517619903598, 0.056458686877574236, 0.08759392438722508, 0.03491325603265848, 0.04438371856563857, 0.013807796623690851, 0.03201340092346072, 0.09628173070294516, 0.06924467507217612, 0.06953860287155424, 0.021323704260534475, 0.0591511477583221, 0.030627371011567966, 0.050214638002216816, 0.03546197033886399, 0.06440915632992983, 0.033327221138668914, 0.07511559754077878, 0.033655163898531876, 0.009774778703493732, 0.04229125227513058, 0.048414460849016905, 0.014379191811063459, 0.011819920569126095, 0.052586046646216085, 0.041935333516448736, 0.01617757593547659, 0.06614195156310286, 0.03469934108267937, 0.04089666942932776, 0.02135537827520498, 0.03613495833373495, 0.010482168423810174, 0.06523450597056321, 0.01583705992171807, 0.07044149549411875, 0.06803042308560439, 0.02485087008348533, 0.03417317110246845, 0.021300956374034286, 0.012638388168332832, 0.04779782518744469, 0.01983929185995034, 0.02282492397353053, 0.025811533177537576, 0.024709329374932816, 0.019455931448776807, 0.027933032285155993, 0.058464986006064076, 0.039265983538436036, 0.05524876394442149, 0.024108634197286198, 0.01489746364365731, 0.03036678981568132, 0.036385442928544114, 0.030294417270592282, 0.03841112440984164, 0.037583963080708466, 0.030055257425244366, 0.06561122182756662, 0.03474852130083101, 0.015278042061254382, 0.10215026472828218, 0.05770721845328808, 0.034605289343744516, 0.011084042556051697, 0.0398188911910568, 0.03959842498547264, 0.028664620260574987, 0.029672353328870874, 0.042298112264169116, 0.005737000860140792, 0.0164673697602536, 0.01682296791113913, 0.04537957727110811, 0.0064215387932823175, 0.011618060641922057, 0.016552973738206283, 0.03622963432488697, 0.09810120878475052, 0.011581041467642146, 0.01770797435061208, 0.09284896776080132, 0.0008691136650408485, 0.028729742658989768, 0.020471313303070407, 0.04581366665661335, 0.046981232041226964, 0.013215744285844266, 0.02515892158927662, 0.030877326349062578, 0.02852596841486437, 0.03588334058544465, 0.045559646894357035, 0.025083887490576932, 0.0353077868265765, 0.00986899244266429, 0.0297849460371903, 0.07159051312399761, 0.016060404812118838, 0.05299380887299776, 0.023836221047011868, 0.015143261257825153, 0.049347782374492714, 0.07259589846112899, 0.010321636368254465, 0.024929205255050744, 0.015960066446236203, 0.030590031229491745, 0.06738015583583287, 0.13189886164452347, 0.0065444863700707045, 0.01898392891910459, 0.01888833860201495, 0.030155426157372336, 0.019628762799714292, 0.038621633114027124, 0.023284159866826873, 0.07807338596986872, 0.047103151213377714, 0.06821865548512765, 0.018511731310614517, 0.016970311790438633, 0.020170937724677578, 0.05793217316802059, 0.03132574639416166, 0.04658137474741254, 0.045102711234773905, 0.02899842556299908, 0.052281937428883145, 0.06691533899200813, 0.04544456396251917, 0.04020316253549286, 0.025771151862240264, 0.021451726855177964, 0.03273882610457284, 0.05787787001047816, 0.020651294716766903, 0.006489605609593647, 0.02806971298663744, 0.02560738573915192, 0.030047379633677856, 0.017557035932051282, 0.0321501664418195, 0.021580675650121908, 0.026336564915254712, 0.021263197596584047, 0.03680542217833655, 0.0679048669657537, 0.005355577242361116, 0.051471542700060775, 0.01764589348541839, 0.05728261838001864, 0.006794777158315161, 0.05562642975045102, 0.06313456900949989, 0.05359495697276933, 0.010698621094759022, 0.018576796033552716, 0.031139654772622243, 0.012747338839939662, 0.026239570030676465, 0.06791543175599404, 0.025020083146435872, 0.04548428200983575, 0.008445917063259652, 0.022272737264367085, 0.022015969435285245, 0.04892069547037993, 0.0612338770713125, 0.02739324071444571, 0.02389568615970867, 0.01243342224708093, 0.022798564584393586, 0.05922943034342357, 0.04667651892772742, 0.0856510072148272, 0.015292959653639367, 0.052408843833420954, 0.03723945728104029, 0.00975908588484994, 0.0726919247369681, 0.0483393605931529, 0.07402966331158366, 0.10684542850192104, 0.05781818607023784, 0.016168587042817047, 0.04103168093466333, 0.026630784484690855, 0.012399637988502426, 0.012749577157332428, 0.052179736484374316, 0.04119567945599556, 0.026632791252008507, 0.06866576935031585, 0.020434791155691658, 0.047815816543464146, 0.033532932600272555, 0.012012191100179084, 0.051526093522885015, 0.06415287365338632, 0.03892661424885903, 0.03981343576950686, 0.0508901772887579, 0.07356994905109916, 0.05880531881536756, 0.04569040059245058, 0.037234958593866656, 0.017637706960418394, 0.025440021684127193, 0.017260343102472167, 0.09370934337909732, 0.024330925662070513, 0.046522579688046656, 0.07278779494975295, 0.018986168084666133, 0.0101004364966814, 0.11022702990365879, 0.030257406578000103, 0.03492000067074384, 0.049326846176492314, 0.0237221677920648, 0.0760319387274129, 0.039687781262078455, 0.05295366334861942, 0.038736861930894, 0.036988015951854844, 0.05238611291029623, 0.03445829490997961, 0.03277846612036228, 0.039146982066865475, 0.024290490063971708, 0.011047857979844724, 0.049558766053191254, 0.043651881228600226, 0.04532389668747783, 0.032235275089208565, 0.03251410887709685, 0.04292599464367543, 0.03328628172831876, 0.040759445899831395, 0.02618426433764398, 0.07244438837681498, 0.04531361009659512, 0.0436076678867851, 0.02718179563193449, 0.03440708587212222, 0.0501676528448505, 0.037801606580615044, 0.024793030062158192, 0.02388029868182327, 0.05243094711165343, 0.01950944072034742, 0.025800634208800535, 0.04912347226802792, 0.02929224818944931, 0.05377041934324162, 0.027719543115901094, 0.0554903902645622, 0.05335624496053372, 0.02014637306066496, 0.06527669727802277, 0.029483523818531206, 0.046018506200718026, 0.0204111492993044, 0.01980206573248974, 0.026532120403966734, 0.029748054088226387, 0.026902917739269987, 0.0030996217558692607, 0.03982639918103814, 0.03850945770474417, 0.004573051219007799, 0.01640018631171967, 0.0755839766934514, 0.02133324446289667, 0.16917012525456293, 0.11325129440852574, 0.15521024433629854, 0.11453643973384585, 0.165908190288714, 0.09342492185533047, 0.15977312092270168, 0.106709199026227, 0.12771045496421202, 0.12422648976956095, 0.2021221877740962, 0.15402096243841307, 0.08967552733208452, 0.09909904202712433, 0.08468021359294653, 0.11300730000116996, 0.08622905119721379, 0.14634061099163123, 0.29203482238309725, 0.1455073021352291, 0.17458294837602548, 0.14714580135686056, 0.11497998450483594, 0.08780656369136912, 0.14159490992980345, 0.080467936050679, 0.14791889701570782, 0.1283724337284054, 0.10182433043207441, 0.1509943434170314, 0.14089004775243147, 0.1336259911102908, 0.17828540184668132, 0.09069554188421794, 0.1624075738447053, 0.12067502391125474, 0.1751968190073967, 0.1481246424040624, 0.10919280682823487, 0.12146120172526155, 0.17164577384080204, 0.17130859621933528, 0.13639638173793042, 0.15771109371313027, 0.12445154626454626, 0.09512602271778242, 0.13314580544829369, 0.09314776744161334, 0.15398753780339444, 0.1529664240245308, 0.17620136296110495, 0.11513922310301236, 0.18287917891783373, 0.07986008402492319, 0.13469182034688337, 0.1016495262405702, 0.1898031945207289, 0.0901172197024737, 0.1464050853891032, 0.15639542788267136, 0.1653328197343009, 0.13895604653017862, 0.11277538351714611, 0.08810800965875387, 0.2639203481376171, 0.10381515217678887, 0.1433899878923382, 0.13578796652810915, 0.15818764242742742, 0.14515062341732637, 0.11953090530421052, 0.15380178205668926, 0.18773955239781312, 0.11910383536347321, 0.23967640048691205, 0.23465290718844958, 0.19789513173912252, 0.08334681085710015, 0.16529227048158646, 0.17036263697913714, 0.08749951302473034, 0.2150703186967543, 0.15091931101466927, 0.26271318005664007, 0.17593089890267166, 0.1407975498586893, 0.10302385820874146, 0.14045670814812183, 0.10180719063750335, 0.12899306256856236, 0.0878375523856708, 0.19992236367293767, 0.15001027765018599, 0.09835045505315065, 0.18334405682981014, 0.14702707129929746, 0.09426418824919633, 0.3169832522315638, 0.14407739814903053, 0.1440813336521387, 0.13661993188517435, 0.13381121759968145, 0.1407142664705004, 0.13207946052508696, 0.16823978589049407, 0.11850014275738172, 0.14170393693659986, 0.11362271769238369, 0.1187273162816252, 0.1715399766606944, 0.07509823382965156, 0.2768215244369847, 0.09727596092436995, 0.184561443648168, 0.16404551666762146, 0.1349889508315495, 0.1499801099832569, 0.21354372347039835, 0.07923503792179482, 0.12153639697602817, 0.1503149534442595, 0.08599845107112612, 0.10004162894827978, 0.082761214779956, 0.22424556421382086, 0.15064630923526628, 0.08553440775722265, 0.14652188840721334, 0.13732164566005978, 0.09599723454032626, 0.1875601884509836, 0.15486421861818858, 0.12009874411991664, 0.14206575894994394, 0.2074831843908344, 0.1301567094134433, 0.08695430335189615, 0.08319646785301821, 0.16906473519546644, 0.21871764798249516, 0.12927982503814356, 0.07393389487905161, 0.18449861130544118, 0.10410333956990923, 0.12793338085923875, 0.13576679623552732, 0.11877086465912205, 0.0921136529317924, 0.06051180724586759, 0.12980570324829646, 0.08740578019725424, 0.131680020530309, 0.04994961918730821, 0.11304068392408745, 0.19284598981695517, 0.13929646754903452, 0.13480422645807266, 0.11823763112936701, 0.21288069976227625, 0.14349377660879067, 0.11743060871958733, 0.1183615316237722, 0.07922502953026976, 0.19463270822806017, 0.051597275239016326, 0.11006104666739702, 0.07151225089494671, 0.14448610693216324, 0.1103262317233852, 0.17349408966089996, 0.110652749559709, 0.08923072727130991, 0.08180768308894974, 0.05703564520393099, 0.15419852148209298, 0.07050690626991646], [0.02971896868465202, 0.038669829456401725, 0.050920151573206694, 0.06251990449215684, 0.022039268631488085, 0.03456077405384608, 0.0771841047597783, 0.01732927717135421, 0.0788821182878954, 0.015475244693724173, 0.04757029203964131, 0.05518667799021516, 0.028893462980964353, 0.031050006725958416, 0.05794564887349095, 0.03320097630577428, 0.028375696656959395, 0.02136229763605765, 0.023659678109522377, 0.03512090131906526, 0.052509419686560116, 0.05551792860829404, 0.02726788306608796, 0.05384938046336174, 0.03826771942632539, 0.0599598732909986, 0.046492540942771096, 0.024262878777725354, 0.03275096509605646, 0.04274084957848702, 0.06516015210321971, 0.03832973413435476, 0.021515444686104144, 0.01996174537842827, 0.029072833713144064, 0.004265595975864146, 0.04455036337354353, 0.028036932959886532, 0.05992347667259829, 0.0077873988276613605, 0.04174005453075681, 0.019407404320580617, 0.043140231897788386, 0.023319482703560164, 0.10935487491743905, 0.049696980243814845, 0.015801689587533474, 0.013187527407093771, 0.04968205925875476, 0.04484905109607747, 0.00932523313843246, 0.018904136593586633, 0.019014371392716254, 0.02240701934455761, 0.02448217281406479, 0.01329928297283394, 0.030966601201466153, 0.044658671133220196, 0.018398695858195424, 0.07332175451197795, 0.030423247321907963, 0.0642197500648243, 0.051528040918388536, 0.025264688235308443, 0.05849995091557503, 0.026590740740565316, 0.01552686424526785, 0.022917116526514292, 0.02799316236217107, 0.03100427346570151, 0.029559716515775238, 0.019917409900309782, 0.04384904993431909, 0.047564782335289886, 0.014767619182488747, 0.03608194100005286, 0.004892957155659262, 0.019672112705718194, 0.09826404361852578, 0.05897123419812747, 0.01952094358525106, 0.029472816535936933, 0.0962265929473298, 0.11887062287756375, 0.142153194972447, 0.06388890317508153, 0.03841262736490794, 0.000959519762545824, 0.07812865943248783, 0.07137423008680344, 0.03007490440670933, 0.04431896596880896, 0.031169615486370664, 0.018276054046249816, 0.08828054754329578, 0.06327421830168792, 0.04466839793271252, 0.047028210413243086, 0.04626217491126486, 0.020278339640104344, 0.04875009819599135, 0.05578475911170244, 0.06030809746256896, 0.02622758031689695, 0.046345811137663465, 0.07648576330393553, 0.04868009713079248, 0.009744026648279811, 0.03216394070269806, 0.0585846592273031, 0.08386863821319171, 0.04427532259640949, 0.040423119839813025, 0.05077590181359223, 0.026250443554350307, 0.00966253289620259, 0.02823462074489466, 0.04913966211357287, 0.04005014949611255, 0.015370073462171214, 0.04269649035164288, 0.016983987663739493, 0.05799196567386389, 0.020324028795585036, 0.04321014814610992, 0.0058164038761918035, 0.006852039576707674, 0.03398753749206662, 0.03185353468039206, 0.05897974981261151, 0.02462545226860259, 0.03036301376830254, 0.05365431860887578, 0.022841307201555798, 0.05482255235048277, 0.1022248560828822, 0.04147666419989296, 0.03464588948658534, 0.04576905297913721, 0.013283186425854052, 0.04418731660449079, 0.07280917558819056, 0.019590542618451372, 0.044475785589643886, 0.009716603655501135, 0.013335754230086292, 0.04396279615217021, 0.060956926218100956, 0.08247032003211123, 0.02688628514962537, 0.027045140375516245, 0.046959756407886744, 0.013537799906251686, 0.01947490159156067, 0.04411482531577349, 0.03939410452065723, 0.044664879728640826, 0.04446630984810846, 0.04888810543343425, 0.03253995427595718, 0.0077317436890942705, 0.0522982222693307, 0.03162767072873456, 0.016407307536740388, 0.03058456562991653, 0.02932036328794701, 0.030498496855476072, 0.042120146099478006, 0.03327417666358607, 0.020053825973133956, 0.0387513215121414, 0.030520722270011902, 0.015395740745589137, 0.03754047577136329, 0.013470383211305099, 0.016481632566345588, 0.04102590320897954, 0.02297781826928258, 0.02873569680377841, 0.0260395955826555, 0.02498139986502273, 0.016337798409430043, 0.025293990770088773, 0.06664397248200007, 0.011625332840984421, 0.00792784709483385, 0.047824009853814325, 0.026014326938561032, 0.03827097300173981, 0.08169437452618565, 0.06548841377454144, 0.01770222037365394, 0.03409043393496956, 0.024319779028051665, 0.027046241298584, 0.020286456615264927, 0.023659791764138, 0.025304898220513548, 0.008972501798000718, 0.01040336421491312, 0.022600021845261966, 0.037535508895026784, 0.02318363999282675, 0.026651254189865928, 0.058126899147672315, 0.019076265660779815, 0.02181420874382768, 0.029132670323763574, 0.062461374061448235, 0.03337929530867508, 0.009122253628447652, 0.025030313758179545, 0.04939096773575459, 0.02342203987895378, 0.04015674734754222, 0.019335839232163768, 0.03237873435552631, 0.05514949427119323, 0.014522366092673369, 0.013816662531878268, 0.04119463451206684, 0.019338738273030946, 0.028666638902255466, 0.04488962070484247, 0.06378485661532197, 0.020492717690233673, 0.10501731266932827, 0.04622441104480198, 0.02754487463140062, 0.034184309254799566, 0.06786634653274502, 0.011196673431965922, 0.05034988020945873, 0.04312492414776768, 0.07456160083945308, 0.012012047759656395, 0.020469175917761664, 0.053313079955322404, 0.03583372271220599, 0.02393301067474697, 0.021931352725784694, 0.016128080198541284, 0.06126368511468172, 0.06315001246652432, 0.036499107722193, 0.0309978545244251, 0.07631180728120462, 0.020782771054655313, 0.03516824609999146, 0.03530262317508459, 0.06770272459834814, 0.01630063335012112, 0.00621554277105523, 0.024145427758672407, 0.05650164832227996, 0.042837897049529214, 0.047989965948675356, 0.08705228380858898, 0.02288535769496645, 0.10203341421272073, 0.20002965363008635, 0.04301986996350544, 0.05592928707067456, 0.015442932856136134, 0.046801942733249495, 0.04946756076865962, 0.020892378208892684, 0.030340869777968953, 0.07713001194809165, 0.016553011057632308, 0.05428315093740821, 0.029173650446214845, 0.05315648764371872, 0.06435522636664764, 0.01807150287952806, 0.06359405935342823, 0.0026748431430730435, 0.01001813868060708, 0.038290399459323714, 0.05645712624703135, 0.04335754291553583, 0.031029525146420513, 0.02557126392743417, 0.10814951173961163, 0.03549864515662193, 0.07230671362153121, 0.054574344240661175, 0.022415351754586612, 0.028173968195915222, 0.04700352870193975, 0.06763348688504525, 0.0853219245161329, 0.04390064573713711, 0.07982526839311634, 0.018586768801989298, 0.08516002606068339, 0.07067454513162374, 0.026459408591368368, 0.036231669929942915, 0.006404248448753995, 0.027949502026396136, 0.06963723472186498, 0.029407015602503504, 0.0602370887728674, 0.03957283064456923, 0.08501501634184803, 0.03498752508312464, 0.05211808479257992, 0.028443824965506792, 0.02283881528169981, 0.009297680375831468, 0.041683770050959926, 0.003560461536315935, 0.027921442907037478, 0.028047068576727594, 0.07416189621601786, 0.05982121465993779, 0.06837503066552536, 0.030070215729730468, 0.03788709520761456, 0.003024987568746188, 0.07013135749314513, 0.05141197411077363, 0.0659747062517064, 0.04975361756182142, 0.009191178367473185, 0.027588187217978493, 0.0613621948286891, 0.013855349205966507, 0.02104773897943752, 0.014783013445724334, 0.024440488711531674, 0.04498236965654152, 0.06191376915999821, 0.03138184766950352, 0.03634176902206881, 0.01234491668375475, 0.023579317510926297, 0.01262310755971287, 0.03342971385323575, 0.02814873687124678, 0.008744095884529608, 0.03457131509536079, 0.022181163874587843, 0.029554010036268404, 0.06662053588245596, 0.009218787957381989, 0.07717476811792169, 0.007873067266440817, 0.02023016195744276, 0.05981165410152503, 0.03901396206180964, 0.11898733090077128, 0.10141366746808801, 0.11650666115539414, 0.147494391937341, 0.07486698230994598, 0.06706062012485095, 0.10734478277819497, 0.10514335733439241, 0.1718731644962515, 0.0984620333516172, 0.12712639916156018, 0.15748037823608943, 0.12544315734079906, 0.11490196654839174, 0.22378964296409062, 0.08992483466863632, 0.15328148140438966, 0.1088863057749612, 0.09443991524832589, 0.14427730813622475, 0.12955438744808945, 0.2116576132497617, 0.060120095764952045, 0.16297800466418266, 0.10211547623787608, 0.13881670257874898, 0.08699979233954634, 0.0823584838903376, 0.1163763552904129, 0.05299930500664881, 0.12051792948373727, 0.10814946424216032, 0.18808378678347382, 0.06983971635677985, 0.07390239049813577, 0.096385933325759, 0.21694489382207394, 0.14280108734965324, 0.14350157976150513, 0.10952796920069627, 0.18787474371492863, 0.10148364478456122, 0.1158274340310267, 0.18389688645090374, 0.1465659931834255, 0.08100821277392761, 0.07930842148406164, 0.16242303087243012, 0.14727077393659524, 0.0847750117204019, 0.12477032201630728, 0.1580460321690355, 0.09190819252814565, 0.18115267370428356, 0.14429091954869883, 0.17635336837598256, 0.21569632153425897, 0.15958774515560695, 0.12850370311311313, 0.1328275589538472, 0.09353497345000505, 0.25222311009253773, 0.13634319816316876, 0.07137264231485979, 0.13761165152703012, 0.07143236018185105, 0.15357819119734423, 0.17092579390321458, 0.13758647787783826, 0.1897599311279399, 0.1935965581131833, 0.06862796816442694, 0.23513396137527057, 0.12156368765447821, 0.2089563381991216, 0.10455301151211772, 0.11120815761387348, 0.11351393495819398, 0.22866760407175335, 0.20071637178105967, 0.138695502653718, 0.19224089942872524, 0.19811613059469632, 0.25354123221976416, 0.43729815046702114, 0.09605547998632703, 0.14527806586452893, 0.16629925716136182, 0.1940555056290967, 0.19196221152586596, 0.18406611308455467, 0.1332884199385132, 0.2139131450759513, 0.1307321885334594, 0.23620254546403885, 0.14843237160571984, 0.10262983292341232, 0.15647544073207037, 0.3002256357244083, 0.15472847090235778, 0.13886732129114016, 0.08408175249184881, 0.11564606162054197, 0.11718008002000195, 0.22726178807871683, 0.22808172979525157, 0.1515350951147931, 0.14515002630650997, 0.12135258183947631, 0.18490763221468243, 0.1579905008631093, 0.10206177019115005, 0.1714150719344616, 0.1458380472447191, 0.12043381828282561, 0.1773082571370261, 0.1614430770277977, 0.1200796365737915, 0.1378353645226785, 0.1402766928076744, 0.11831640904503209, 0.1567838348980461, 0.13370277413300105, 0.0866176685584443, 0.11110570561140776, 0.1008481356714453, 0.10523909184017352, 0.221449986366289, 0.16491823483790669, 0.1446575184485742, 0.1585672420582601, 0.22704491471605642, 0.1800540576555899, 0.12379524005310875, 0.14945801799850805, 0.22707481096897805, 0.10948269734425203, 0.08348988675113235, 0.11739262432924338, 0.13921667183084147, 0.16779168136417866, 0.1715473048388958, 0.12991619589073317, 0.1131504505340542, 0.08207860855119568, 0.2054148739469903, 0.12972828240266868, 0.1790477495108332, 0.20781194817806992, 0.09703571881566729, 0.12823731026479177, 0.20013247882681234, 0.07212466946137802, 0.09325420922998871, 0.14293220745665686, 0.1159812579197543, 0.14029162057808467, 0.21419818406658514, 0.12000465845423085, 0.10717041963445288, 0.17667470899011406, 0.16157528279083117, 0.0913843499230487, 0.14076920066561016, 0.10143026443464415, 0.0686461121908256, 0.11791373922356538, 0.1297534289104598, 0.12815205912504876, 0.1995653999703271, 0.14735594365213597, 0.25692959183028763, 0.11971358050193105, 0.07778057096792118, 0.1156557918127094, 0.08682815690657922], [0.05806620419025421, 0.030335085266934972, 0.10274970291980676, 0.05128871822463615, 0.015207052031265838, 0.03187105106189847, 0.056448488496243954, 0.06956312512712819, 0.05499407243249672, 0.02471129543014935, 0.03562423520322357, 0.02484243589320353, 0.04737294012946742, 0.04006440890952945, 0.05187069771013089, 0.040182582568377256, 0.024536672746762633, 0.023672429478860328, 0.05281855006303106, 0.03208916275096791, 0.0073772752990147895, 0.005053817452530244, 0.0018054595483200891, 0.04176840711651104, 0.0402804069620158, 0.04096331513885941, 0.04455037015889372, 0.021602366718330553, 0.061625289996819835, 0.023218489551384534, 0.015303478642765964, 0.01409000188245305, 0.042187056437666924, 0.03750558889337948, 0.07464748301676341, 0.058690727821418216, 0.035998661004539044, 0.010573184566705354, 0.07760793130312647, 0.008284508849361112, 0.06408176996878215, 0.008714028301515749, 0.029633344350648776, 0.04523935800950442, 0.007008428327805761, 0.059251523443630764, 0.11973962267594677, 0.012831205768244607, 0.032143632149589915, 0.036115718473281176, 0.07369733043015003, 0.0028649567809355047, 0.022038323771474615, 0.02077298827602395, 0.07734138239175081, 0.025188753381371498, 0.04546335938253573, 0.017180898526151265, 0.05224497762641736, 0.002703680033196828, 0.05180148035287857, 0.06896923735205616, 0.057096950842865875, 0.02685592749289104, 0.036375963794333596, 0.05353406524019582, 0.07725827542266675, 0.046037321976785145, 0.017993055749684572, 0.013099468828711127, 0.043920710017638545, 0.011863636884040065, 0.019024230506537215, 0.03810151227350746, 0.05712382082960435, 0.04541847089837704, 0.03052087833306619, 0.019899691654635326, 0.030424777418375015, 0.029665093004171337, 0.025893452710339, 0.04105979942583612, 0.030755960182952027, 0.06662972324660846, 0.05013762088492513, 0.031587603235883374, 0.01837313374770539, 0.06560590211302042, 0.06574019776391131, 0.08696982144777264, 0.0008463273989036679, 0.027205157592626553, 0.05020518261673195, 0.055413956687386544, 0.02580587928449469, 0.014346662842269455, 0.05374118805463825, 0.028868988222841705, 0.024924665855775987, 0.08178493859512465, 0.035840477528316636, 0.015321751590818167, 0.015656452559466873, 0.07422872513000454, 0.04354643688670226, 0.01585376715021474, 0.06434240884014539, 0.037506138506744585, 0.048236908590687175, 0.0575640272083027, 0.0360606350004673, 0.040000385737844875, 0.04260599413620574, 0.06175550765224865, 0.006112061939867479, 0.00796494260430336, 0.03210612273375903, 0.007509210496209562, 0.019502360207427825, 0.03354380951662149, 0.03190905920096806, 0.05868151331586497, 0.006468434892927429, 0.07044343610427209, 0.044415260265980444, 0.01996697688342205, 0.04879418261615293, 0.046954758997474394, 0.0590085739802037, 0.079914292187563, 0.026748980195926766, 0.028739337144153457, 0.06377378292381763, 0.06719475971268755, 0.019438752638442174, 0.06534433364868164, 0.0070832978817634284, 0.054338777238237004, 0.021588283724018505, 0.07696634930159364, 0.04076865701270955, 0.05058451761890735, 0.06602391361125878, 0.05559864713411246, 0.03643392086295145, 0.019940832929153527, 0.054697891896856685, 0.015025538824764746, 0.07762536965310574, 0.03243543613435967, 0.013190670720567661, 0.03346097735421998, 0.05237097479403019, 0.025567721974636828, 0.02311043454600232, 0.009105109593032725, 0.057522623001464775, 0.04343062452971935, 0.03266609054324882, 0.03066151150103126, 0.040429260581731796, 0.01530314955328192, 0.029238036634134393, 0.04181424894237092, 0.08630785625427961, 0.017537500908864394, 0.037278228772005866, 0.057907006304178915, 0.04109374314014401, 0.004866276310557234, 0.04895581305027008, 0.032453067866819243, 0.04852770834362932, 0.06106826702931097, 0.07093630358576775, 0.0035942712399576393, 0.0289589042908379, 0.011365692264267375, 0.011526733221087073, 0.03706652923886265, 0.017380450586123124, 0.013811089214868844, 0.04547479948295014, 0.011518783335174834, 0.03976709522040827, 0.028724785960678543, 0.06164646028940167, 0.007822455339399832, 0.007368787674100271, 0.06844910633351121, 0.007233307979601834, 0.058013549872807095, 0.01649447384157351, 0.01663026905485562, 0.024771376313375573, 0.050862723761903386, 0.029246552248618433, 0.04644044302403927, 0.03744658688083291, 0.018471601053274105, 0.028977051709911654, 0.03279137864176716, 0.05394465695800526, 0.042604389400886636, 0.06753383044685636, 0.013901615964381822, 0.06276016695691006, 0.01605012670292386, 0.036035535990127494, 0.05238309682213834, 0.08132105134427547, 0.016017551933016096, 0.04087272392851966, 0.05086714441754988, 0.020978316365342056, 0.008801871445029974, 0.0721867825569851, 0.0049806866445578635, 0.05362857159759317, 0.04775895191622632, 0.06272833009383508, 0.05961895015622888, 0.07558247034571, 0.0197786902010973, 0.0306054645084909, 0.040469311111207516, 0.13618196467203753, 0.004567532184799867, 0.04407247115990945, 0.03537367936223745, 0.025554400635883212, 0.007136144309437701, 0.018886679583894353, 0.008076079006839012, 0.028423657208415012, 0.028245039650106003, 0.024724625250590698, 0.022255612736833946, 0.05859330376344068, 0.014176476929735924, 0.030277786377285208, 0.07289346999355725, 0.01379983062257192, 0.09508208757532494, 0.04501371118905289, 0.027279586098822098, 0.019634408211069446, 0.011940843991136976, 0.015534670790657401, 0.09049927563007389, 0.024503341410309076, 0.03766941099560686, 0.020584119749920707, 0.012287437982325043, 0.039530038833618164, 0.0632685050368309, 0.02915019349062017, 0.02068958105519414, 0.07405301848692553, 0.12763779743441514, 0.07482471636363439, 0.027934121333860924, 0.02779481639819486, 0.06108605821749993, 0.09884814691862889, 0.030257359080548798, 0.051303452612566094, 0.042817371365215094, 0.09483086677002055, 0.025424332258158495, 0.06399239333612577, 0.013677675659502191, 0.0035514734918251634, 0.02784488210454583, 0.06385205872356892, 0.1025529820472002, 0.020086236198299696, 0.04656481170760734, 0.05972650474203484, 0.030791515417929207, 0.044511144049465656, 0.0463167291267642, 0.04712356833208885, 0.02269311006447034, 0.010593786586209067, 0.027238746772387197, 0.02740687078663281, 0.004475335815056626, 0.08165937568992376, 0.04390948026307991, 0.04795523852642093, 0.06132051242249353, 0.04419005449329104, 0.04814008503620114, 0.025154536556718603, 0.06359653600624629, 0.04272736030231629, 0.09685541170516185, 0.026133728745792593, 0.04723773184897644, 0.025294703231858354, 0.049685116059013774, 0.018759038665198853, 0.024466571597648517, 0.034502559141921144, 0.016299742772909145, 0.015285853695656573, 0.056111433011080535, 0.0678220314106771, 0.02831564291513392, 0.018278603641582385, 0.04585358826443553, 0.01869798238788332, 0.036534167626606565, 0.028709780158741132, 0.11969253234565258, 0.021603404876909087, 0.019377306203490922, 0.019362704129889607, 0.025281599024310708, 0.026066775999165008, 0.012222537804128868, 0.062443263961800506, 0.02278569447142737, 0.02998733606987766, 0.04414732035781656, 0.020466175096641694, 0.020000102963032465, 0.04208835334117923, 0.03090696475867714, 0.026640338257753422, 0.03372049664280244, 0.016671020171738098, 0.01395266639467861, 0.05933517324072974, 0.04498190486005374, 0.03970088377328856, 0.0014670127483051537, 0.03078878092180405, 0.030636439632092203, 0.06666481707777296, 0.048780937612588914, 0.009662085063090282, 0.018361792034868683, 0.04757158804152693, 0.06718906680388109, 0.02534604288770684, 0.04276002497811403, 0.05038501136004925, 0.047514760733715126, 0.08427588136068412, 0.006153871571379048, 0.17591705678829125, 0.09850522889090435, 0.13763662161571638, 0.12426424345799855, 0.10634646777595792, 0.0983580139332584, 0.1858160820390497, 0.14994036140186445, 0.11197212019136973, 0.0763047437316605, 0.16723444126546383, 0.08681366339858089, 0.08767895161041192, 0.23932972337518418, 0.14626131738935197, 0.14064707793295383, 0.11240733255233083, 0.09353027120232582, 0.1127073128840753, 0.11314574828637497, 0.13209723814257554, 0.1099798803084663, 0.1129479349723884, 0.11922328466815607, 0.1520738654903003, 0.14846599980124406, 0.18857735315603869, 0.07651656200843197, 0.1322482121842248, 0.06396146570997578, 0.19700839503535203, 0.11180262892906155, 0.09872624131717853, 0.11712275738162653, 0.15880552998610906, 0.1316125334373542, 0.14315345058483736, 0.1818528811314276, 0.21938125523073332, 0.07421201959784542, 0.17176411034805433, 0.09111047961882182, 0.2468852922320366, 0.15525538048573903, 0.11540755656148706, 0.2095674539783171, 0.26458238118461197, 0.07829654935215201, 0.11132669768163136, 0.1492601300456694, 0.27794064581394196, 0.12426782612289701, 0.07748859734939677, 0.13099744144294942, 0.15429085652743066, 0.11028499036495175, 0.2335907556116581, 0.11481615900993347, 0.13876700667398317, 0.09260896313935518, 0.1369763934718711, 0.12118441372045449, 0.11271392181515694, 0.06220438570848533, 0.08796950709074736, 0.13477234888289655, 0.11254559763308082, 0.18126377702823707, 0.10095332895538636, 0.23503432529313223, 0.11633524963898317, 0.11418722490114824, 0.1088938375136682, 0.24675612630588667, 0.13433944354099886, 0.1161937208047935, 0.10216497536748648, 0.13214660835053238, 0.1380478274077177, 0.20761758860732826, 0.07306720209973198, 0.12591803685895034, 0.16905455717018672, 0.22241123978580746, 0.1680337419467313, 0.09533388513539519, 0.1592308221650975, 0.16969015449285507, 0.26320538935916765, 0.2204079194260495, 0.1826773826032877, 0.09532490133174829, 0.1301391760685614, 0.08972000530255692, 0.0931840758504612, 0.09837443448070969, 0.16651451561067784, 0.16675634549132415, 0.11717982217669487, 0.18091266229748726, 0.09017534979752131, 0.1520874226199729, 0.11545917950570583, 0.09633791340248925, 0.15466392865138395, 0.11654384487441607, 0.214851192597832, 0.11499675789049693, 0.09858982185167925, 0.09904234364096608, 0.08361072026725326, 0.1737658836479698, 0.14709223780248845, 0.17996005341410637, 0.11628999135323934, 0.10656559387488024, 0.11884106589215142, 0.14933470104421886, 0.11889259384146758, 0.13008388903524193, 0.11912036447652749, 0.16919751092791557, 0.05718486862523215, 0.1817179476576192, 0.10158658533224038, 0.12127560882696084, 0.0735233947634697, 0.22173597530594893, 0.13410923017987184, 0.12637144752911159, 0.15270765790981905, 0.11786856236202375, 0.1191925470318113, 0.1759689375758171, 0.10556688532233238, 0.1089098984375596, 0.11052143267754998, 0.1048757770497884, 0.06722207753253834, 0.1782874781638384, 0.08767848342124905, 0.11049106145011527, 0.10793744240488325, 0.16834512166678905, 0.11262219066598586, 0.19733892301363604, 0.2180723204676594, 0.08240096018250499, 0.13038187447403157, 0.1119735451149089, 0.09758254340184586, 0.1502965380038534, 0.1569447834044695, 0.08107332499431712, 0.10303427372127771, 0.14026101864874363, 0.08364179717110735, 0.11469928813832146, 0.20620136388710567, 0.10619457771203347, 0.08246854227036238, 0.07766166449125324, 0.12561671302786895, 0.09940221147345644, 0.10216838839863028, 0.08233909135950462, 0.09932796617171594, 0.16472170395510538, 0.09010246156581811, 0.08896155242941209, 0.12936164279069218, 0.11658252137047903, 0.14902159784521374, 0.19984414215598786, 0.19554239298616136, 0.05512690584042242], [0.1072756400597947, 0.018047496310568283, 0.06793978437781334, 0.06791672097252947, 0.04178192014140742, 0.047367715409823825, 0.037016039448125024, 0.026441005025325075, 0.019211582506873777, 0.007120869637999151, 0.0665360718433346, 0.03842472903696554, 0.025241502693721225, 0.02034386746319277, 0.07182479769523654, 0.016560654754617384, 0.024630061217716763, 0.053277724888175726, 0.020551870676821897, 0.011056919815018773, 0.02205881892171289, 0.014823657693341374, 0.016072518358539258, 0.023080331339899982, 0.013281593564897776, 0.018302486377901266, 0.03160454625529902, 0.07583590996052537, 0.04141964011692575, 0.03505164324971182, 0.05479748048154371, 0.02535376461621906, 0.06484611931123904, 0.049145792677466354, 0.04998188013476985, 0.0309725519535797, 0.020427047374791334, 0.052046017588249276, 0.02249523568233209, 0.06190184729972056, 0.049108418968639204, 0.0672884179013116, 0.026351446884551218, 0.03776533888386829, 0.023403512480269586, 0.025713447547916855, 0.01428760145790875, 0.059333198703825474, 0.05019821406209043, 0.07103681497808013, 0.044045414576040845, 0.09294787781046969, 0.025017436859863143, 0.008694420335814357, 0.015383510151878, 0.03342895728668996, 0.08643248278115477, 0.022322668960051875, 0.033996405944760354, 0.020542215123506527, 0.03317849983328155, 0.04713911356936608, 0.04765881371817418, 0.002227577455674431, 0.06776623547609363, 0.026546903985685537, 0.06296785974076816, 0.048794582951813936, 0.014730315023501004, 0.11254833212920598, 0.03670483614717211, 0.053276449242340665, 0.02104600192978978, 0.026501981574775915, 0.05553850518273456, 0.020430329787944044, 0.030276005222861255, 0.038600306758391004, 0.08224601671099663, 0.02388572526563491, 0.047513149213045835, 0.21486840024590492, 0.4448331461421081, 0.2594524121710232, 0.23919719191534178, 0.1209799846900361, 0.09442687380526747, 0.08642035057502133, 0.01070247178098985, 0.05958697758615017, 0.046078855105276616, 0.1615019060139145, 0.2900620496698788, 0.0862495768815279, 0.03410766872444323, 0.10597836931369134, 0.08177631441503763, 0.11444619457636561, 0.19178945651011808, 0.032799236077283106, 0.11449741039957319, 0.1529369620340211, 0.03368038843785014, 0.05938370885061366, 0.037519665102341344, 0.018617908470332623, 0.07435592330460038, 0.009591301138113652, 0.03776133552725826, 0.036783481748508554, 0.034942229477954764, 0.044489512353071144, 0.00966336325343166, 0.026915143243968487, 0.050698694706495316, 0.038536870519497564, 0.050256412010639906, 0.045274034541632445, 0.047120996684368165, 0.05883727102939572, 0.06704086118510791, 0.0701861899080021, 0.03516343867938433, 0.04443397426179477, 0.06020582866455827, 0.014575943217745848, 0.02027760342960911, 0.031020269928766147, 0.006889365363999137, 0.017048092259626304, 0.10677125105368239, 0.040191800466605594, 0.0341305285692215, 0.022828993487304876, 0.004715250106528401, 0.016507666258673583, 0.04597039467522076, 0.018911944835313728, 0.07040207260953528, 0.052520160895905325, 0.050172874171819, 0.05075793759897351, 0.04240382123472435, 0.04977183283439704, 0.026309316645243337, 0.0520772301991071, 0.017609775066375732, 0.015029810202707137, 0.034814420621842146, 0.023642960703000426, 0.03346882461171065, 0.05387446929567626, 0.031540964131376574, 0.05415326915681362, 0.0320990049014134, 0.04101458863754358, 0.05782248119690588, 0.010390743463566261, 0.028581750778747455, 0.011667293446537639, 0.026989027225811566, 0.016988767942945873, 0.016316064932782735, 0.03152773269851293, 0.03348771841930492, 0.016649344370567372, 0.0009984010913675384, 0.0356098604388535, 0.0416128461781357, 0.06460529366242033, 0.025174767078299607, 0.007190844409966043, 0.03630521973328931, 0.013245732140993434, 0.02590193270173456, 0.02442058558309717, 0.03638309519737959, 0.02468885966975774, 0.04714790399053267, 0.04527334922126361, 0.06511089046086584, 0.053783871299986324, 0.02045197505503893, 0.05180054397455283, 0.020270914770662785, 0.037382577279848714, 0.03159578976088336, 0.03937943798622914, 0.058080636630100865, 0.03501196591449635, 0.032110648562333415, 0.024521644892437116, 0.024515687354973385, 0.06226145050355366, 0.04310172503548009, 0.015306645704965507, 0.058148937965078015, 0.028639745166791335, 0.0032944507880269414, 0.03061585287962641, 0.012773678721194821, 0.03070545003616384, 0.027546477670382177, 0.012859830616175063, 0.020450850383245518, 0.01717925986408123, 0.031217791472694705, 0.024043460908745016, 0.043223851160811524, 0.04036567167245916, 0.04162746521511248, 0.04353576013818383, 0.06835844048431941, 0.04832542687654495, 0.024364657334185073, 0.014921383699402213, 0.04696659604087472, 0.04756543033623269, 0.0445043417359037, 0.05733347457966634, 0.023077143921649883, 0.04104904803846564, 0.017869462292375307, 0.043924642128071616, 0.007209341274574399, 0.08977447130850383, 0.011437608494556375, 0.0336485753235008, 0.01858172389412565, 0.008557782042771578, 0.03173645346292427, 0.0035979047949825016, 0.037363720791680474, 0.0020311920338177253, 0.1088785704757486, 0.044678983079003434, 0.04409335646778345, 0.02390629505472524, 0.019769711486463035, 0.05049761085371886, 0.03865056584722229, 0.006558779286154146, 0.05632597899862698, 0.008422635678601052, 0.07015698576079947, 0.11855932458170823, 0.028183445633788193, 0.030508308471845727, 0.02780582902154752, 0.07812181979949985, 0.10488382447510958, 0.02110682411252388, 0.04333547356405428, 0.018898167181760073, 0.19201093034020492, 0.0506685304322413, 0.043679996327097924, 0.1375070892806564, 0.228142255118915, 0.1939841237451349, 0.11781210824847221, 0.2021851965359279, 0.10992056277713605, 0.039115314837545156, 0.06331691172506128, 0.04675093725589769, 0.0652403278010232, 0.044162037782371044, 0.2569953283028943, 0.09597740774708134, 0.033042959070631435, 0.25021668204239433, 0.5982826192464147, 0.227988743356296, 0.1129471817985177, 0.2701215610972473, 0.13824734384460108, 0.12310685270598956, 0.03714828931593469, 0.04693449115646737, 0.06329912053687231, 0.016771090516288365, 0.0662817976304463, 0.03128076630777546, 0.012031839777981597, 0.021112001334716166, 0.028524394213621105, 0.025009194355724112, 0.07257060946098395, 0.013072784590934004, 0.05465053693790521, 0.021512481184410195, 0.02190664387308061, 0.03838673786127141, 0.042090606077441146, 0.011167593117404197, 0.028887953276612928, 0.013280412065796554, 0.029938271202679192, 0.02399993797631136, 0.011496385742378021, 0.023322554770857096, 0.02756671667365091, 0.0015426237077917904, 0.0352846453897655, 0.0050219848302991265, 0.05363294475578836, 0.02568120526016823, 0.043044633099011013, 0.04971799108066729, 0.04987950955650636, 0.059350840614310334, 0.038037509457873445, 0.020998384038518583, 0.015466878356944238, 0.011996917276909309, 0.0036962469956571503, 0.04474854988179036, 0.037025786603667905, 0.03742725881082671, 0.03072648462174194, 0.00872790434264711, 0.04384491426338043, 0.00860488339925983, 0.04362199176102877, 0.041472280863672495, 0.009506735318739499, 0.07084108476660081, 0.05808806658855506, 0.009504418121650815, 0.011674258608504065, 0.03004453657194972, 0.08037278508501393, 0.0849081538617611, 0.028128548758104444, 0.04480303285111274, 0.02288223473754312, 0.03297608605186854, 0.054841527582279274, 0.03285503201186657, 0.02354616259357759, 0.0770697376823851, 0.015895071273137416, 0.02868441991241915, 0.07751355386738266, 0.0674850098522646, 0.027820013796112368, 0.011503805522806942, 0.03824240328477962, 0.04213835119402834, 0.014242623067860092, 0.10770262857632977, 0.22795145107167109, 0.0768392054097993, 0.09008530141519648, 0.10827466752380133, 0.13867117038794927, 0.16134721360036305, 0.1902673260441848, 0.1204591276390212, 0.12816459845219338, 0.13471030364079134, 0.19040468867336, 0.2514304726251534, 0.07944553305527993, 0.11542146652936935, 0.09413938530321632, 0.09288902168295213, 0.07420017237641982, 0.08973405776279313, 0.14816036048744405, 0.09316788600491625, 0.20685971927429947, 0.08361449292195694, 0.15819602912025793, 0.15469922604305403, 0.09126820508390665, 0.16180089568453176, 0.1167534850537777, 0.2020667243216719, 0.09992331279707806, 0.13144774442272528, 0.10267188852386815, 0.15842989299978527, 0.1331708433904818, 0.09288859420589038, 0.17986321289624485, 0.1873058056724923, 0.1579525436141661, 0.09788201483232634, 0.1800045788820301, 0.1776657093848501, 0.11974065404917512, 0.2171117320124592, 0.06487398674445492, 0.14479634671338967, 0.12720288362886223, 0.1630598088460309, 0.09730097851050751, 0.1166047773190907, 0.20112650548773153, 0.17754243314266205, 0.09387806789683444, 0.21437286612178597, 0.17090733775070735, 0.1126097666897944, 0.22329887215580257, 0.1573281828314066, 0.18389633005218847, 0.09037693576621157, 0.16412026408527577, 0.10820737720600196, 0.11055063003940241, 0.190655312367848, 0.08795339188405446, 0.0992168357063617, 0.12305123997586113, 0.0860376636098538, 0.11852458358875342, 0.14907045236655644, 0.18254445759313448, 0.1791498554604394, 0.10750803830368177, 0.12408148683607578, 0.1892949039382594, 0.14535778015851974, 0.25837386718818117, 0.10631326705749546, 0.10261799248733691, 0.13693654989557608, 0.3225102727966649, 0.15638026941035474, 0.19893312746925013, 0.3581653338457857, 0.6344128176569939, 0.4111229293048382, 0.37317553269011633, 0.3932308022465025, 0.23561406561306544, 0.1875912653548377, 0.1405471432954073, 0.17520296653466566, 0.13702406734228134, 0.39628467123423305, 0.5050086985741342, 0.25264366609709604, 0.07508583699486085, 0.28010012422289166, 0.29725433087774683, 0.22212774785501616, 0.4822844522339957, 0.4308305175176689, 0.2762863231556756, 0.27252653347594397, 0.1274435328585761, 0.14013429544866085, 0.1311045414102929, 0.18445507649864468, 0.11213397114936795, 0.12776096511100019, 0.11660251101212842, 0.15303080342710018, 0.20505153201520443, 0.16993240506521293, 0.23232040234974452, 0.10269725216286522, 0.19793811014720372, 0.1440171713807753, 0.21505167255444185, 0.06928260517971856, 0.1277273776275771, 0.23864671002541268, 0.1248999357755695, 0.14812658301421575, 0.13175464581165994, 0.10601737150656325, 0.15430787418569836, 0.11322914702551705, 0.10228152732763972, 0.1139905040285417, 0.1196040649499212, 0.12430043651589326, 0.25266700770173756, 0.12357285698609692, 0.11900250294378825, 0.11133784601198775, 0.10840550264609711, 0.15492128341325692, 0.14429533002632006, 0.12380961142480373, 0.1505813327218805, 0.11665219334619385, 0.10193644477320568, 0.12745335804564611, 0.13468751843486512, 0.10167054047009774, 0.12920760177075863, 0.12705724287245954, 0.1199653712766511, 0.10688700234251362, 0.10232235477971179, 0.16820097368742737, 0.07661513279059104, 0.11667337720947606, 0.16347423089402063, 0.07169662243021385, 0.10444205068051815, 0.1252420259905713, 0.15768213383853436, 0.1882034396486623, 0.15721113554068974, 0.13283498212695122, 0.06682876470897879, 0.07645240652241878, 0.11369821149855852, 0.13362099709255354, 0.12478725825037275, 0.18746341578662395, 0.0804535239668829, 0.10241426234798771, 0.1848517752119473, 0.1525515541434288, 0.15463027331445897, 0.13631317977394375, 0.12217679832662855, 0.10991956533065864, 0.11471116250114781, 0.15826689531760557], [0.01607506625753428, 0.017156796962288872, 0.0483446803076991, 0.0696463067350643, 0.024784076792587127, 0.011068845067971518, 0.022209872691226856, 0.047013055333601575, 0.013680923297735197, 0.049284777005336115, 0.0288466508500278, 0.04512936748298151, 0.018945376255682538, 0.053213481192610095, 0.043797555911753855, 0.04957784985059074, 0.040707582075681, 0.05719618658934321, 0.08740176326994385, 0.015885919532073394, 0.045255385006644895, 0.04298491183934467, 0.04608799497197781, 0.017288483646033064, 0.027188530091994574, 0.05263365605579955, 0.02932748112029263, 0.03320207892517958, 0.016926330846867392, 0.037721522485039065, 0.030755190045705864, 0.017232915020680854, 0.04595823872036167, 0.022562861874965683, 0.056488355821264644, 0.028039485947894197, 0.011129084558758353, 0.016165952630607144, 0.030476315545716455, 0.03164364005039845, 0.026578778168186545, 0.012688632838294973, 0.023276414389589002, 0.026249133981764317, 0.07461000074233327, 0.029220527037978172, 0.02338841337976711, 0.00756159339964922, 0.01948474713468126, 0.027480963417994123, 0.03099511324294976, 0.019677483310390795, 0.06747578177601099, 0.05939343904278108, 0.02468331264598029, 0.036275577930999656, 0.09497620897101504, 0.041300903274012465, 0.014682125466476594, 0.07076320930251054, 0.03287380707583257, 0.038705673068761826, 0.041863083107663054, 0.018892689707822034, 0.05819688324949571, 0.019559370719694665, 0.09195088595151901, 0.012440607084759643, 0.04062311464388456, 0.1357835696211883, 0.03811735945886799, 0.04698820059586849, 0.06196445572589125, 0.2171259405357497, 0.23508041139159883, 0.12617110327950545, 0.06285426619329623, 0.3155633227101394, 1.0998596676758357, 0.9250079244375229, 2.1230422726699283, 7.8255980014801025, 10.995416573115758, 13.290637595312935, 8.470779929842267, 6.286850810050964, 3.1887925820691243, 3.4663038509232655, 2.01232185959816, 2.311553631510053, 2.7835215287549153, 3.2205330388886586, 5.6677719610078, 8.892043130738394, 20.24523547717503, 31.276023592267716, 34.154391288757324, 26.440683603286743, 10.116781251771108, 3.059133768081665, 0.41571731705750736, 0.26857384986111094, 0.1148580110498837, 0.06773665134928056, 0.028895837853529623, 0.035108857322484255, 0.030222075259579078, 0.016331503300794532, 0.022381978009694388, 0.009639960580638476, 0.047731199833963595, 0.10153783259115048, 0.04279794490763119, 0.015014166577852197, 0.03335787056546126, 0.07727810221591166, 0.029210142059517757, 0.017059975104140382, 0.010658984471644675, 0.0727981561794877, 0.052095272445252964, 0.03404782872114863, 0.01797121201109673, 0.028867963634963547, 0.08024571583207164, 0.02976419304364494, 0.044463938368218284, 0.041905040320541175, 0.04150970546262605, 0.08312050585768052, 0.05328693600105388, 0.03085320782182472, 0.008732738056486207, 0.02179310460841017, 0.021571668097749352, 0.020914573089352677, 0.04297206038609147, 0.03360806678288749, 0.013626398768142929, 0.00894814747984388, 0.020498101865606647, 0.06572221658591713, 0.06149357956434999, 0.009613510437442787, 0.025900448406381265, 0.02078296782981072, 0.014574262147237147, 0.00860916156255241, 0.017341777482735257, 0.036731740060661516, 0.002665818839367213, 0.0063537662915353265, 0.049792850456599674, 0.01905243720726243, 0.0608963601823364, 0.07407772394695453, 0.043932309573782344, 0.04623365608443107, 0.02518803922326437, 0.038901650945522954, 0.024166387705398456, 0.035692146380565, 0.048100475554487536, 0.02407612049553011, 0.01652561011724174, 0.03516356760103788, 0.01904622691550425, 0.04505825701302715, 0.03919462879587497, 0.029087378111268793, 0.008289308636449277, 0.02637604038630213, 0.022718975819381218, 0.0076177744028557625, 0.002378585424074637, 0.014982144813984632, 0.016945550351270607, 0.0498329009860754, 0.029564452690205405, 0.058725950574236255, 0.0704405726864934, 0.060614035331777165, 0.03474505398688572, 0.03727013724190848, 0.06449890615684645, 0.012163846221353327, 0.028551725604172264, 0.07416196406951972, 0.04921962407284549, 0.028711792015071427, 0.05577532068959304, 0.022446783192987953, 0.06187294849327632, 0.047826557752809355, 0.07352493503796202, 0.05780956189015082, 0.028140043141320348, 0.02541304991713592, 0.017690600461459587, 0.01979346021211573, 0.01915210043080151, 0.03263242502829858, 0.020535538338923028, 0.012904021905602088, 0.04403229170878019, 0.019548103645710007, 0.052506274676748683, 0.04143104289791413, 0.0330035158299974, 0.026391928283763782, 0.05609040521085262, 0.07493974161999566, 0.0291748785945986, 0.07306733780673572, 0.02452690353883164, 0.029719094213630472, 0.0406505037099123, 0.05080093975578036, 0.04312231518062098, 0.03466536004894546, 0.10450904922825949, 0.06863630057445594, 0.027116401819512248, 0.015242893947288394, 0.03191171566556607, 0.006625163759703615, 0.029914410518748418, 0.03699071652122906, 0.024814802554569075, 0.035606369376182556, 0.07380414541278567, 0.0406491975300014, 0.012639867374673486, 0.04703113829184856, 0.015411574360249298, 0.059391919124339304, 0.07242322486958333, 0.012122621826295341, 0.00975522756510015, 0.028514623309352567, 0.050841960590332747, 0.019152483803087046, 0.12912860672388757, 0.03777227011908378, 0.05511397635564208, 0.05137913980122123, 0.1427946819790772, 0.1892550332205636, 0.21195627722357, 0.35582370949643, 0.03693124292684453, 0.16410826758614608, 0.6259124566401754, 2.057736805507115, 4.11676858152662, 4.51749290738787, 9.491637059620448, 18.946238483701432, 24.335403748920985, 27.85454821586609, 18.752467121396744, 13.632476806640625, 7.697065881320408, 7.653443353516715, 5.270045782838549, 4.817816197872162, 6.810040610177176, 7.593227658952985, 13.510633196149554, 18.62974282673427, 38.83720963341849, 55.81799554824829, 59.92701080867222, 53.84099333626883, 28.036907161985123, 12.584178635052272, 1.261796446783202, 0.21036923809775285, 0.02651372192693608, 0.03341044345870614, 0.03359589047197785, 0.09067069393183504, 0.021523242749805962, 0.02268854352379484, 0.057880536653101444, 0.06086422476385321, 0.03955782823530691, 0.05523934927103775, 0.09874192904680967, 0.035001662360238175, 0.033597376463668685, 0.01959684111976198, 0.053133264782705476, 0.05278392781370452, 0.031798023730516434, 0.0657083744715367, 0.06447709804134709, 0.08352167611675602, 0.030422226126704897, 0.0011723730172629335, 0.04319614657600011, 0.08184748595314366, 0.03613825262125049, 0.007447264489850828, 0.04880891361140779, 0.027537361552406634, 0.021005486603826284, 0.020167288902614797, 0.031453826664281745, 0.03006284005407776, 0.02953188300931028, 0.011935017919833106, 0.0238559613270419, 0.0743464238143393, 0.03047563022534762, 0.026700023894331286, 0.04186054538669331, 0.05818460855100836, 0.031576546507754495, 0.03199728910944291, 0.03310239873826504, 0.03812027715944818, 0.016650636979777898, 0.09951094671019486, 0.041801085363009145, 0.12182180237557207, 0.023326500451990535, 0.024506444011681845, 0.05029471531244261, 0.02242586056568793, 0.035731616762599776, 0.06801411788910627, 0.024408645063106502, 0.007766454147973231, 0.030703248190028325, 0.09320907986589841, 0.018852800330413238, 0.008376809967947858, 0.030816427831138884, 0.005515198788738677, 0.05252237631274121, 0.028075444911207472, 0.08498951699584723, 0.025281346270016263, 0.03189804997029049, 0.03081530824835811, 0.025341226985411983, 0.021024875741984164, 0.058818984510643144, 0.03137043131781476, 0.018638152562614, 0.01281410498943712, 0.10313957557082176, 0.13038110094411032, 0.1423154462661062, 0.12160779243069035, 0.13384385513407843, 0.13503382913768291, 0.09527488651552371, 0.19385353289544582, 0.1366744182471718, 0.10514951164701156, 0.14999838971665927, 0.1542577033064195, 0.10341141705534287, 0.17542731735323155, 0.147687272301742, 0.09511127136647701, 0.10217297529535634, 0.1510724699390786, 0.21054698713123798, 0.1624171140470675, 0.13907099036233767, 0.09317030158958264, 0.16284539178013802, 0.12661856998290333, 0.11928513992045607, 0.2928236057715756, 0.05002891618226256, 0.12988855237407343, 0.15221277517931803, 0.12787349335849285, 0.1391885804810694, 0.11956226719277245, 0.12760534988982336, 0.1604834385216236, 0.16846359388104507, 0.1600987905902522, 0.07861552866441862, 0.13671880800809177, 0.14589258788951806, 0.10532884845244032, 0.10482511083994593, 0.110952058141785, 0.051463926144476445, 0.10001179376350981, 0.30011867146406856, 0.13592600769230298, 0.1486168245651892, 0.16127884441188403, 0.08538097741880588, 0.1103707571913089, 0.11204571409949235, 0.11262396842773471, 0.20637065837425844, 0.17882727991257394, 0.189661584262337, 0.1365331879683903, 0.12991675228944846, 0.12657473662069865, 0.10668044271213667, 0.1802647563495806, 0.11378735064395837, 0.15723558994276182, 0.10767719708383083, 0.13056089915335178, 0.17624362212206635, 0.10493508779576846, 0.18916200606950692, 0.08022952598652669, 0.20017769640045507, 0.1860079446009227, 0.21565512088792665, 0.2015588272895132, 0.3315433923687254, 0.531896381505898, 0.34634180686303545, 0.2892720177769661, 0.31631307676434517, 1.3581783835377013, 2.997839582817895, 3.370352919612612, 8.129707625934056, 16.209424700055802, 21.734328235898698, 25.357315267835343, 18.442026819501603, 13.058224695069448, 6.885270059108734, 8.423752784729004, 5.823109797069004, 5.8095047899654935, 7.691479529653277, 8.442481654030935, 12.808241537639073, 17.645987340382167, 39.26835577828543, 54.259080341884065, 64.11537102290562, 51.82003334590367, 22.287585496902466, 7.979472807475498, 0.6892527235405785, 0.40677113139203613, 0.220665803445237, 0.19479954641844544, 0.23496001213788986, 0.1627890190907887, 0.13097578260515416, 0.0959275286378605, 0.18362366754029477, 0.21634249043251785, 0.14618210521127495, 0.1905678492039442, 0.14165268040129117, 0.07195831981620618, 0.08534435688384942, 0.215541791969112, 0.11498516851237842, 0.149360539657729, 0.09087189992091485, 0.15289962903729507, 0.13071685364203794, 0.16919631670628274, 0.07760090168033328, 0.12343104316719941, 0.11780590643840176, 0.16856374564979756, 0.1622700755085264, 0.1200776823929378, 0.15758107283285686, 0.15329920473907674, 0.17720331491104194, 0.11413884535431862, 0.09778536430427007, 0.0868197837844491, 0.09643695915916137, 0.10446739396346466, 0.2110928414123399, 0.27767105028033257, 0.11187586999897446, 0.07597238370882613, 0.12097177441631045, 0.13343247292297228, 0.15351606453103678, 0.1573880703321525, 0.10848388701145138, 0.1038452587755663, 0.10109059658965894, 0.14328545278736524, 0.07314980695290224, 0.13652915747037955, 0.12428339171622481, 0.1423862310392516, 0.2117862363478967, 0.07939196950090782, 0.13578389531799726, 0.20371887566787855, 0.07246654254517385, 0.1191912442445755, 0.10379054171166249, 0.23516093992761203, 0.10584562750799315, 0.08448375734899725, 0.08971452952495643, 0.10118788494063274, 0.1136377743844475, 0.11019779182970524, 0.18633459135890007, 0.18970627257866518, 0.12659822750304425, 0.05891614393996341, 0.12936612112181528, 0.1455218634967293, 0.14962136851889746, 0.1087592433073691, 0.1143231490360839, 0.05099395921986018], [0.05983403218644006, 0.023305174096354415, 0.037609421714608154, 0.05086763296276331, 0.04995946812310389, 0.007340924481728247, 0.04108773131987878, 0.031120370807392255, 0.039289946002619605, 0.02988192904740572, 0.0029210849856359084, 0.060262296348810196, 0.05074238896902118, 0.0097040456686435, 0.017867033137008548, 0.04381152355511274, 0.026157021156645248, 0.030349378607102802, 0.02536698247838233, 0.044704295827874115, 0.045904369825231175, 0.021156582781778913, 0.01854774116405419, 0.0518947924886431, 0.025557737331837416, 0.02980143783081855, 0.02246454045442598, 0.03253727066995842, 0.042897706518747976, 0.014787949787985002, 0.055993747897446156, 0.05686518024387104, 0.052034655519362004, 0.024810907763562033, 0.03466279518657497, 0.035409597613449605, 0.04870291626346963, 0.029161083977669477, 0.022638004539268355, 0.05814095160790852, 0.04744195053353906, 0.04964203926335488, 0.05341687545712505, 0.039029632828065326, 0.030146320217422078, 0.010963178505854947, 0.08983825360025678, 0.09848481177219323, 0.012633023500841643, 0.04679001408762165, 0.00801798199037356, 0.060227440004902225, 0.02987554742555533, 0.0121261569937425, 0.00817109172099403, 0.04535929925207581, 0.07388732702072177, 0.04657934932038188, 0.04016788889254842, 0.01283320235753698, 0.03686017316899129, 0.11214096684541021, 0.07098991463759116, 0.04575795214623213, 0.0602154027936714, 0.12697353879255907, 0.13547280058264732, 0.02221432896996183, 0.04770426877907344, 0.22032665807221616, 0.6301698024783815, 0.49423225969076157, 2.0229975496019637, 5.441287176949637, 10.365446857043676, 25.21117901802063, 35.231195313589915, 45.48890774590628, 50.676710741860525, 69.73249626159668, 72.89611530303955, 92.8140367780413, 92.01743275778634, 90.3694520677839, 79.36818858555385, 73.99498680659703, 72.51353359222412, 59.62980161394392, 57.15967879976545, 58.46461650303432, 67.1376428604126, 64.72700704847063, 79.14683982304165, 85.52021394457135, 88.96110085078648, 99.37035696847099, 91.11709213256836, 92.14363288879395, 81.50923429216657, 75.17870276314872, 42.47331312724522, 19.706652811595372, 3.4760248150144304, 0.1680538130125829, 0.07933286231543336, 0.3072498845202582, 0.008094530918502381, 0.20637934362249716, 0.026975493844864622, 0.0520704007441444, 0.012209632916242948, 0.03794014646804758, 0.06760893070272037, 0.015765949451763715, 0.044020800718239377, 0.027814736490004828, 0.029662830089884143, 0.05244685536516564, 0.04690900198849184, 0.06370196677744389, 0.042036859318614006, 0.008486063435806759, 0.041326901343251975, 0.04786411127341645, 0.027169407278831516, 0.041076613523598225, 0.01576845663865762, 0.009663039252960255, 0.00644188721032281, 0.018815090746751854, 0.008167045955945338, 0.012895239117954458, 0.050457034459603686, 0.006751887807955167, 0.0821978407246726, 0.009857494666773294, 0.01371687208302319, 0.010650797098475908, 0.04688364513484495, 0.01258292471590851, 0.02096262524303581, 0.026178859806220447, 0.01739894745073148, 0.052476961963943074, 0.027679436607286334, 0.042201183536755185, 0.030574065300502946, 0.057452530334038396, 0.0384045663688864, 0.016890699276700616, 0.07163935407463994, 0.055672217293509414, 0.0392031478030341, 0.024105684266292622, 0.06498893736196415, 0.015552226187927383, 0.0641347635537386, 0.051346967063312016, 0.0380641385646803, 0.019168911135888526, 0.02103306057064661, 0.03644889273813792, 0.05011624363916261, 0.011910393884006356, 0.056514730477439504, 0.02409406435409827, 0.035772668131228, 0.012312753275702042, 0.05662107387823718, 0.03671669354662299, 0.021149202017113566, 0.03346919102062072, 0.07349157147109509, 0.057604277905608924, 0.057046216779521534, 0.042775322550109456, 0.057370719366839955, 0.046065647421138625, 0.0425358302226024, 0.03824498850320067, 0.03293239178934267, 0.047003331926784346, 0.02286239437359784, 0.01737804348314447, 0.026723309519833753, 0.04427979074950729, 0.05314832826011947, 0.012065213522873819, 0.0919306588226131, 0.026590747525915504, 0.0416828302799591, 0.04486538004130125, 0.06185012936059918, 0.05949374008923769, 0.029444993207497255, 0.08013851408447538, 0.018214767067027942, 0.025287480226584842, 0.02509847599347787, 0.03622879294146385, 0.015564648467781288, 0.01166504410295082, 0.013808576090793525, 0.0277450933520283, 0.04170419056234615, 0.07937922661325761, 0.07220750501645462, 0.08023795339145831, 0.03363991043131266, 0.019637397157826593, 0.01914367641854499, 0.04874520595850689, 0.013241082479778146, 0.06074452440121344, 0.009978008423266667, 0.032033027548875125, 0.014459123236260243, 0.031873663421720266, 0.02661989739031664, 0.008209467117142464, 0.04971205050657902, 0.02224394871986338, 0.08984220267406531, 0.055822176925305805, 0.017929553353626813, 0.020524807307603102, 0.04800208119143333, 0.009685992396303585, 0.012623328931762703, 0.007640455284022859, 0.03778996970504522, 0.022566695597821047, 0.018288729080398167, 0.0363283679554505, 0.10371500040803637, 0.12210524002356188, 0.06200267081814153, 0.04220697822581444, 0.06998500427497284, 0.021868888488305465, 0.11485689825245313, 0.07619904833180563, 0.13780667606209004, 0.059665674077613015, 0.13615725242665835, 0.3134292757936886, 1.8463767298630305, 4.542816919939859, 9.578223773411342, 17.740701709474834, 24.407295022691997, 45.223938192640034, 58.08895867211478, 68.3589346749442, 74.60301671709333, 93.90783609662736, 97.74075426374162, 117.4425937107631, 112.79901531764439, 110.07676669529506, 99.5486546925136, 92.31600379943848, 94.2574486051287, 76.62465763092041, 71.47408308301652, 75.69954667772565, 83.50557681492397, 82.96172046661377, 99.06683880942208, 105.67643778664726, 106.13452557155064, 116.50980499812535, 106.99256556374687, 105.58021913255963, 102.08954838344029, 102.76293999808175, 71.80307333809989, 40.89950793130057, 11.905075601169042, 0.7722944989800453, 0.1328366920351982, 0.15262129397264548, 0.15313650561230524, 0.039240911669496975, 0.0907691086509398, 0.10615659332168953, 0.017511134734377265, 0.04482096653165562, 0.04049814884950008, 0.012250910745933652, 0.024473962540339147, 0.03139890264719725, 0.11826435183840138, 0.03727709561852472, 0.036750426915075095, 0.10538446796791894, 0.02015983689177249, 0.03225969895720482, 0.05222104230363454, 0.0327078713370221, 0.036078504220183404, 0.04953724631507482, 0.035202746213014634, 0.07254472335002252, 0.026703838957473636, 0.019188157781692486, 0.01970050939624863, 0.025834033398755958, 0.058100219150739055, 0.032269476646823544, 0.06251394695469312, 0.045859790074505975, 0.023656531403373395, 0.06048862848963056, 0.014983981947547622, 0.0936400242415922, 0.01832961251160928, 0.03137389523908496, 0.026777624551739012, 0.04369407932140997, 0.021872213309896842, 0.01104772651368486, 0.023799234103145342, 0.04909529610137854, 0.03867618393685136, 0.02156710664608649, 0.06438244919159583, 0.03984413608642561, 0.05292572806190167, 0.0016713614147322784, 0.05119297354082976, 0.03602263703942299, 0.05530350136437586, 0.0232817120517471, 0.0035722158832608587, 0.011559920368849166, 0.003830380646312343, 0.02857493489448513, 0.035803561830627065, 0.047004566860518286, 0.04604513870019998, 0.027570255233773162, 0.04169477588896241, 0.045087355987301896, 0.041650080787284036, 0.05287481079410229, 0.011092848244256206, 0.06772464806480066, 0.00795576287366982, 0.05116591017161097, 0.057624633956168375, 0.0030381736245804597, 0.13217228411563806, 0.15870376330401215, 0.12739938737026282, 0.08261536367769752, 0.15975402694727692, 0.08582478003310305, 0.09207798234586205, 0.072927227110735, 0.09203940763005189, 0.0933705372735858, 0.14501548638301237, 0.1901820477630411, 0.24651828621115002, 0.0734858378501875, 0.08095034730753728, 0.10788924606250865, 0.17820426262915134, 0.14148504153958388, 0.10997439096016542, 0.16340434178709984, 0.1316163603748594, 0.12197701047573771, 0.15772398587848457, 0.10893235794667687, 0.09651840371744973, 0.08594405970403127, 0.10373417580766336, 0.24855304988367216, 0.094657541784857, 0.1969020685979298, 0.1519692896732262, 0.14559704517679556, 0.23299432333026612, 0.10354335140436888, 0.1541002153285912, 0.1565688478627375, 0.061498865352145264, 0.16711168070988996, 0.09814380042787109, 0.1922033085886921, 0.10628970832164798, 0.1432189563555377, 0.1708667477858918, 0.09617674097950969, 0.1418199935661895, 0.12327940416123186, 0.12250998616218567, 0.1541569544268506, 0.08963404170104436, 0.07729161184813295, 0.1122003590155925, 0.1433437525161675, 0.07959369796195201, 0.10097341359193836, 0.11860783983554159, 0.11104843047048364, 0.19564391539565154, 0.1756656188517809, 0.1367743257433176, 0.17317034703280243, 0.15111766037132057, 0.35804317040102823, 0.21336155038859161, 0.12356768654925482, 0.15635947909738335, 0.11797231036637511, 0.2664809764495918, 0.21301418117114476, 0.4419958112495286, 0.2675137610307762, 1.067815552864756, 2.2471978962421417, 6.489333476339068, 12.574981825692312, 17.946832180023193, 41.2583441734314, 57.40522118977138, 70.65545327322823, 78.0859819139753, 100.32318428584507, 109.23260920388358, 129.0918322971889, 125.06298882620675, 123.51472173418317, 110.9996611731393, 103.1626420702253, 102.80046027047294, 89.32987649100167, 85.47954613821847, 85.62148393903459, 95.23921516963414, 95.92719800131661, 109.84325163705009, 118.01768221173967, 122.38355500357491, 131.5811217171805, 121.5903764452253, 123.29597854614258, 118.05977439880371, 109.63760580335344, 72.04172311510358, 36.26535824366978, 9.652568629809789, 0.349811563534396, 0.18734012597373553, 0.46135430676596506, 0.2764522113970348, 0.3002814384443419, 0.19223965092429093, 0.21167156392974512, 0.11708881705999374, 0.09165591320821218, 0.15410801848130568, 0.2136127304817949, 0.19482849272234098, 0.09514295895184789, 0.19309332940195287, 0.12281212423528944, 0.14756862366838114, 0.18747081181832723, 0.08844171318092517, 0.10803528715457235, 0.1397440428180354, 0.130359876368727, 0.1491587704845837, 0.14279690757393837, 0.1338774019054004, 0.1489993826087032, 0.08636949437537364, 0.04601477765079055, 0.09980408740895134, 0.15003952250948974, 0.14795150740870408, 0.084922559160207, 0.14642382652631827, 0.15925311882581028, 0.09096177188413483, 0.13745594131095068, 0.0989710431812065, 0.15306726789900235, 0.09774507289486271, 0.12110034323164395, 0.14685765467584133, 0.18812573381832667, 0.18660971016756125, 0.10376629765544619, 0.11178886823888336, 0.1330678824867521, 0.07734638319483825, 0.17038649427039282, 0.16815866024366447, 0.09633259368794304, 0.0940205127532993, 0.11054137482174806, 0.10371780275766339, 0.10040944921118872, 0.09192695402141128, 0.16002098976501397, 0.15794259629079274, 0.11713222973048687, 0.1573432870209217, 0.08017906333718981, 0.11080216297081538, 0.0865756943821907, 0.13636329637042113, 0.14879185945859977, 0.1541247647255659, 0.12595883038427147, 0.12309119211775915, 0.12017986976674624, 0.12500494585505553, 0.13244930282235146, 0.09054080875856535, 0.11808330512472562, 0.1611079214406865, 0.08113912932042565], [0.03964261118588703, 0.005559898979429687, 0.06679249022688184, 0.06280094012618065, 0.0521006735840014, 0.062059382775000164, 0.0784274794693504, 0.025109354606164352, 0.07273311859795026, 0.03407605917059949, 0.11783948035112449, 0.034184774051287344, 0.03251088922843337, 0.01825591003788369, 0.04527677921578288, 0.03035571612417698, 0.0244678116203951, 0.02732927691457527, 0.018503690670643533, 0.056801428486193926, 0.02918248836483274, 0.03638259308146579, 0.06039471245769944, 0.05001166782208851, 0.037831821744995456, 0.05522374975095902, 0.039690196846744845, 0.03578229993581772, 0.02556593912387533, 0.025965460542855517, 0.04005683645872133, 0.017328422217230712, 0.06683415906237704, 0.04269811883568764, 0.02971197638128485, 0.027541415799143057, 0.10872511978128127, 0.06426722037472896, 0.023089060692914894, 0.036667462438344955, 0.06507773723985467, 0.06639427838048764, 0.010477047180756927, 0.04316325459097113, 0.04527668761355536, 0.037390695951346836, 0.009812910675204225, 0.062332099569695334, 0.02998672878103597, 0.07668888954711811, 0.02793340208674116, 0.008070142673594611, 0.05333643513066428, 0.019573428268943514, 0.012161934448938285, 0.06386740040034056, 0.07813973990934235, 0.016944245867697254, 0.023042874510533044, 0.04336197714188269, 0.05194145534187555, 0.03591401036828756, 0.07213891869676964, 0.09238590832267489, 0.09817538623298917, 0.06273873882102114, 0.6208505311182567, 0.6598291652543204, 2.6621095751013075, 11.832947220121111, 32.47189194815499, 57.761656829289024, 62.472497258867534, 85.74038846152169, 86.98200375693185, 93.5742461340768, 89.91151019505092, 89.65723391941616, 93.3146058491298, 79.93323693956647, 88.59771701267788, 89.08132553100586, 85.62372820717948, 80.36920860835484, 87.40204320635114, 88.10105282919747, 79.53268718719482, 86.11789798736572, 80.23186356680733, 89.14098276410783, 88.34139101845878, 89.68775040762765, 92.83741051810128, 83.01999500819615, 82.28098460606166, 76.59270286560059, 88.32964856284005, 79.97556536538261, 81.70016384124756, 89.79858807155064, 99.61128575461251, 103.26031984601701, 71.68890748705182, 41.75543567112514, 19.096079860414775, 9.036051494734627, 5.873836423669543, 3.905259771006448, 0.1297070306858846, 0.07749843610716717, 0.0512930608487555, 0.04789819408740316, 0.025223238227356757, 0.022114738688937256, 0.04719033617792385, 0.0066339312803133255, 0.0234070934488305, 0.02908054187095591, 0.025728979214493717, 0.06042804888316563, 0.005560042319952377, 0.030745721089520624, 0.026879318291321397, 0.07748787131692682, 0.04023685519184385, 0.04313808433445437, 0.026338537755821432, 0.07418214370097433, 0.05673865381894367, 0.03886780561879277, 0.03691345173865557, 0.032111320312001874, 0.030051284602710178, 0.03875314677134156, 0.06880102173558303, 0.07317443777407918, 0.00822329820532884, 0.05690212986831154, 0.04168361398790564, 0.03239404210554702, 0.03289852949923702, 0.06726057082414627, 0.0725446826379214, 0.04263290483504534, 0.03208227222785354, 0.007854056411555834, 0.10474932526371308, 0.02094212670012244, 0.012366652704908379, 0.02647546272990959, 0.018366036271410327, 0.008312266868805247, 0.07738653889724187, 0.02583379251882434, 0.05411370038720114, 0.04144712078518101, 0.04884082172065973, 0.058363042904862335, 0.00625063490588218, 0.014247194697548236, 0.01993549964390695, 0.0173320930916816, 0.03125846964706268, 0.025153873288737874, 0.019949224710996662, 0.010711929710981036, 0.12259244173765182, 0.04380985775164195, 0.0441533728901829, 0.07862877366798264, 0.04489516433594482, 0.03759606475276606, 0.10111900685088974, 0.04442102781363896, 0.03525701205113104, 0.01662940053003175, 0.018851490757827247, 0.010328640545984464, 0.038291899021714926, 0.039248976058193615, 0.016311249030487876, 0.03672291910541909, 0.007622880378871092, 0.10513811904404845, 0.025337997158723216, 0.03212715392666204, 0.02925837572131838, 0.0326282995353852, 0.016657568214993392, 0.028974938073328564, 0.02709436639478164, 0.07267574846212353, 0.028869619260409048, 0.05204643827996083, 0.03504644227879388, 0.06547698045947722, 0.013031784960600947, 0.04091154630961163, 0.0430261633758034, 0.01894488601413156, 0.014568258808659655, 0.03650263949696507, 0.07287204864301852, 0.09118270967155695, 0.03315698348784021, 0.016876015778897063, 0.027571327319102626, 0.12010677797453743, 0.03651917539536953, 0.027287368895485997, 0.026482246383758526, 0.03604161227121949, 0.054221763874271085, 0.04864020605704614, 0.026502490476039902, 0.038273154491824765, 0.031531909081552706, 0.06758223034973655, 0.023285084370789782, 0.029217555054596493, 0.056073831993022134, 0.02382029583012419, 0.019254574485655342, 0.008096033025399914, 0.04793326077716691, 0.018935668115903224, 0.0212267229466566, 0.056731200111763816, 0.037648281415126154, 0.03632081925336804, 0.008153172459320297, 0.04845875561503427, 0.13864482965852531, 0.02841602368945522, 0.04578937171027064, 0.03193142032250762, 0.049394665751606226, 0.10107568238994905, 0.07436842870499406, 0.05850008662257876, 0.08944956160017423, 0.21084782241710595, 2.0296930074691772, 2.5207641082150594, 8.375831059047155, 31.13929694039481, 58.05590956551688, 84.84644712720598, 88.00862094334194, 104.4091488974435, 101.69112477983747, 107.13673373631069, 104.39805262429374, 102.44986111777169, 111.7952299118042, 89.20711571829659, 95.56015941074916, 93.84473255702427, 94.15604659489223, 88.6289005279541, 99.3106163569859, 101.59587887355259, 93.11735343933105, 96.85693645477295, 93.21768542698452, 99.5692491531372, 98.30309282030377, 103.63980266026088, 107.52444321768624, 94.7116870880127, 97.45748315538678, 98.52072429656982, 110.3196131842477, 95.91355868748256, 97.18180642809186, 101.60022149767194, 112.52026053837368, 122.54874147687639, 96.88390936170305, 67.6483632496425, 37.24405370439802, 21.443016324724468, 15.062086037227086, 11.001441529818944, 2.5499543590205054, 0.5542849430016109, 0.03208091855049133, 0.0637398629582354, 0.057609237996595244, 0.03633900399186781, 0.06918951017516, 0.03823880704918078, 0.05856479172195707, 0.04839039999725563, 0.01380053290631622, 0.09144540450402669, 0.022975400988278643, 0.034161055859710486, 0.011464167203355049, 0.060189632033663135, 0.07572903390973806, 0.07221357111952134, 0.006381925918893623, 0.07800321866359029, 0.03139180177822709, 0.0681999007772122, 0.031583637198699374, 0.03429334643962128, 0.016138134391180108, 0.032761373823242526, 0.07594213461769478, 0.04290642569373761, 0.020181996149144003, 0.06190239012773548, 0.017060892822753106, 0.09211197016494614, 0.010003217695547002, 0.04791143909096718, 0.043325885864240785, 0.028635273621018444, 0.025684078855972205, 0.025265801032739024, 0.08222858514636755, 0.03765003542814936, 0.021549929532089403, 0.023961127469582216, 0.05311086634173989, 0.046094176425997696, 0.028565581289253066, 0.0699044553829091, 0.018793262275201932, 0.03366997292531388, 0.016622625357870544, 0.08587809931486845, 0.001092564470517183, 0.013491514488123357, 0.059441757521459034, 0.04570507051955376, 0.01603320743223386, 0.01866966881789267, 0.05139485467225313, 0.014514987024345567, 0.04443683767957347, 0.07179795484989882, 0.09196237354938473, 0.09391512269420282, 0.024907576951331327, 0.015394078334793448, 0.016272082292873944, 0.03705843770876527, 0.051296568874801905, 0.02141100457603378, 0.10280994325876236, 0.10662757804883377, 0.15195521685693944, 0.15290193605635846, 0.0966787211863058, 0.1358421950467995, 0.1755946169474295, 0.19810471763568266, 0.12933558704597609, 0.1210261657834053, 0.1767222878656217, 0.10595812861408506, 0.10092619433999062, 0.06620535387524537, 0.10139439707355839, 0.13947763639901364, 0.12709106105778897, 0.1450510144765888, 0.13751802726515702, 0.20386476069688797, 0.09116310679486819, 0.2032994596021516, 0.12674985293831142, 0.10576911589929036, 0.17488655208476953, 0.09758706923042025, 0.15110665453331812, 0.2034731102841241, 0.12150936414088521, 0.1524795615779502, 0.10615657296563898, 0.23426293954253197, 0.14203693478235177, 0.11992305783288819, 0.18889982013830117, 0.11049224210104772, 0.1988025094781603, 0.09936067834496498, 0.12943591523383344, 0.13350822457245418, 0.18007905488567694, 0.1572928854397365, 0.16703713685274124, 0.12909306505961077, 0.12107062339782715, 0.17203852348029613, 0.07690931843327624, 0.11424803520951952, 0.09134863183966704, 0.0914064362379057, 0.14775181455271585, 0.08262730589402573, 0.1059014302279268, 0.08770226607365267, 0.14324362788881573, 0.13325492744999273, 0.21757855053458894, 0.08070697036704846, 0.12707917312426226, 0.1686988826841116, 0.16066715866327286, 0.20006739374782356, 0.14393893629312515, 0.21341324118631227, 0.2195741491658347, 0.2467309119445937, 1.0767905626978194, 1.8618336490222385, 9.259522063391548, 32.23176915305001, 60.33245209285191, 89.48729487827846, 97.74499266488212, 117.64662061418805, 116.58613095964704, 122.12720816476005, 117.00434303283691, 113.92871597834996, 119.10620089939663, 100.56591960362026, 106.87111105237688, 105.8130532673427, 103.65128108433315, 99.86259514944894, 106.90770026615688, 112.04052216666085, 102.66771493639264, 110.85582651410783, 105.86266340528215, 115.7993586403983, 112.45387744903564, 115.6816075188773, 115.81556183951241, 104.42182935987199, 105.78133474077497, 101.45588656834194, 111.5341444015503, 105.27263627733502, 104.54132447923932, 116.66068513052804, 130.26117243085588, 138.57627623421806, 107.6236982345581, 69.66716235024589, 35.93648610796247, 17.894911766052246, 12.505335688591003, 8.912354452269417, 1.8701567224093845, 0.3103760853409767, 0.22008699950362953, 0.16416943073272705, 0.11798537895083427, 0.2021290274070842, 0.08189617084073168, 0.09358283731022052, 0.10471820086240768, 0.08556289265730552, 0.1254197885947568, 0.2163169775158167, 0.12461638956197671, 0.12215432524681091, 0.12427444862467901, 0.1640770278338875, 0.10240735486149788, 0.1476765243070466, 0.15624173970094749, 0.17291861054088387, 0.1563804458294596, 0.1583918814680406, 0.0935613548915301, 0.11260185497147696, 0.11508456032191004, 0.0695367640416537, 0.16126432376248495, 0.09962289141757147, 0.14800503025097506, 0.16147878154047898, 0.16076163787926945, 0.12943552168352263, 0.20347173964338644, 0.18144584154444082, 0.17126165516674519, 0.12458216425563608, 0.10576721600123815, 0.1719372724848134, 0.19840923058135168, 0.09790599425988537, 0.13910996541380882, 0.2077653735343899, 0.12775449188692228, 0.07720054566328015, 0.2203056506280388, 0.1265222994344575, 0.13064707310072013, 0.1192501817962953, 0.06365972797253303, 0.3229134040219443, 0.07145637353616101, 0.06042741784559829, 0.11813300102949142, 0.09289160011602299, 0.12637140681701048, 0.07985335974288837, 0.21504590500678333, 0.07521942696933236, 0.25266328932983534, 0.14249981780137333, 0.1435917570654835, 0.1729665422546012, 0.09321116975375585, 0.14342520385980606, 0.11741488027785506, 0.09071289202464478, 0.09166376385837793, 0.08296098906014647], [0.08147205931267568, 0.12525518956993306, 0.025085112246285592, 0.06232530064880848, 0.07551855234695332, 0.037407347200704474, 0.037782522783215554, 0.040877721338932, 0.03450678641508732, 0.01773490370916469, 0.0015438779373653233, 0.054853218740650585, 0.06067171080836228, 0.020037654787302017, 0.034191104783011336, 0.028738885918366056, 0.04892280910696302, 0.05167577834799886, 0.0672117095174534, 0.021365673347775425, 0.021628266399992362, 0.04026054284934487, 0.05461646090926869, 0.03608553723565169, 0.014786662267787116, 0.10644178159002747, 0.05965236122054713, 0.09845774501029934, 0.02766936205859695, 0.04521369920777423, 0.015802983893081546, 0.02964176157755511, 0.012354835169389844, 0.02274569483207805, 0.03167518514341541, 0.010193680778944066, 0.0083742917548599, 0.04691257108268993, 0.05409108481502958, 0.02508620129499052, 0.020946778057675277, 0.06920679246208497, 0.04634780942329338, 0.058338161025728495, 0.0137355419740613, 0.03439437012587275, 0.026748703692906668, 0.016505656098680835, 0.039235507138073444, 0.04677698282258851, 0.03263894574982779, 0.02988907402115209, 0.028893656363444667, 0.018896060330527167, 0.06888114993593522, 0.007945866440422833, 0.14553369714745454, 0.02754873549565673, 0.01753760777812983, 0.10990830164934907, 0.07383482876632895, 0.07789469377270766, 0.14353879062192781, 1.136110048208918, 8.858536311558314, 13.264013835362025, 28.8623149394989, 30.085953508104595, 34.80638245173863, 61.77339036124093, 74.78870732443673, 81.24637004307338, 81.75879274095807, 75.95373957497733, 77.54031208583287, 76.66171932220459, 71.50719819750104, 77.40111882346017, 76.79199109758649, 79.32351861681256, 80.59589358738491, 89.865797996521, 95.93885707855225, 78.60152435302734, 66.49735246385846, 85.39372893742153, 77.3735761642456, 80.40401908329555, 94.13136659349713, 85.63353906358991, 96.35155923025948, 73.75253636496407, 73.33859743390764, 88.31876073564801, 75.85890361240932, 84.88157721928188, 59.60386398860386, 80.16569587162563, 60.269230433872764, 66.1686818259103, 69.78350298745292, 72.63486998421806, 90.42088958195278, 94.15603964669364, 92.39931270054409, 84.333009992327, 80.48438194819859, 69.48964282444545, 51.28862122126988, 33.06195034299578, 9.060685464314052, 1.465451947280339, 0.2676293562565531, 0.09272356091865472, 0.04611939078729067, 0.06612072020236935, 0.007245470719811107, 0.08994028491101094, 0.04129687277600169, 0.09828583816332476, 0.020767178319926773, 0.04587948116074715, 0.056635658988463025, 0.01348809467162937, 0.06794154856886182, 0.037119604248021326, 0.051836021178002865, 0.008135622151062956, 0.026788905196424042, 0.07612950527774436, 0.005054376819836242, 0.03438397157671196, 0.016872867376410534, 0.05156444771481412, 0.024607228514339243, 0.04303633461573294, 0.06179959885776043, 0.05745470164609807, 0.02067205958467509, 0.05434343877381512, 0.038376695542995415, 0.06389950189207282, 0.09023402272058384, 0.11820278157080923, 0.05177433555945754, 0.0662162240062441, 0.026633812447211573, 0.030697209228362356, 0.040008202461259704, 0.015741661290771196, 0.034335147589445114, 0.06675426156393119, 0.08889532062624182, 0.032023263429956775, 0.05880875898791211, 0.03001246222161821, 0.054095094956989796, 0.04301498451137117, 0.019364127357091223, 0.04599249795345323, 0.05753476877829858, 0.019518122575911026, 0.04508015333807894, 0.01771059349578406, 0.02556525549984404, 0.0436587242542633, 0.0790555246972612, 0.030280921209071363, 0.029236414935439825, 0.06299166274922234, 0.04743654600211552, 0.06127201073936053, 0.0401788438404245, 0.02370001532004348, 0.03332580300047994, 0.06335161879126515, 0.08071552669363362, 0.09101953557027237, 0.03964294366804617, 0.073101732746831, 0.02672399823287768, 0.030935296988380805, 0.026806509787482873, 0.10083390000675406, 0.032282250068549595, 0.01991757274871426, 0.020874539523252418, 0.030773232291851724, 0.03622638414214764, 0.0173921841529331, 0.023438937097255672, 0.02312767442448863, 0.03957522587318506, 0.05964476162833827, 0.11074329327259745, 0.056120620375233035, 0.05498594019029822, 0.044219655583479574, 0.028398193485502685, 0.019430403265037706, 0.13286413199135236, 0.034283215911792855, 0.07986537659806864, 0.05932700367910521, 0.057270913650946956, 0.022565611638128757, 0.03251350158825517, 0.028935450727918317, 0.04591252581615533, 0.047508942295930216, 0.06059977252568517, 0.015506940760782786, 0.010623771896851915, 0.016363089105912616, 0.022425601026043296, 0.04322039741756661, 0.0683617110231093, 0.05551299226603337, 0.04521867286946092, 0.06229393197489636, 0.0756393519363233, 0.024885147976289903, 0.013752032071352005, 0.014558096050417848, 0.036497258714267185, 0.04871461081451603, 0.027444885711052587, 0.04219590114163501, 0.04288874307115163, 0.01368586388083973, 0.061846058150487285, 0.027005442684250217, 0.10236569281135287, 0.030338725607310022, 0.014138038769098265, 0.0396506586112082, 0.039827020040580204, 0.09845928528479167, 0.6420749436531747, 4.423218880380903, 19.22994211741856, 27.20763271195548, 53.94063745226179, 62.13330010005406, 70.11391067504883, 89.7993940625872, 90.38746179853166, 92.36865030016217, 94.37906292506626, 85.38926124572754, 94.96133586338588, 92.82998984200614, 92.1101495197841, 96.01573194776262, 97.15607724870954, 107.33741160801479, 114.21302931649345, 119.57760838099888, 111.13538033621651, 99.58338178907121, 83.06855596814836, 106.65079062325614, 99.00624356951032, 103.22979640960693, 121.10082026890346, 110.49757739475795, 123.47916085379464, 101.05400971003941, 100.60936668940953, 120.937926701137, 100.698623248509, 112.09032685416085, 91.13216972351074, 102.35603264399937, 91.89332403455461, 87.35414927346366, 87.86971950531006, 86.46956021445138, 99.09945365360805, 104.89524487086705, 109.17570345742362, 105.32206576211112, 102.54279327392578, 91.26583916800362, 76.128146307809, 51.896136965070454, 20.242687225341797, 4.760404969964709, 1.0562221578189304, 0.1459174087005002, 0.3066336932991232, 0.017222111046846424, 0.025995779183826277, 0.08542664282556091, 0.04942618031054735, 0.11078416143677064, 0.03496709778638823, 0.052552465948143175, 0.027573042316362262, 0.05622287220986826, 0.03175414626353553, 0.03417509135657123, 0.005249026888382754, 0.03401263989508152, 0.020829086158690707, 0.04020140173711947, 0.01619642903096974, 0.029186600287045752, 0.026468416143740927, 0.05269611181159105, 0.004909745808358171, 0.02660732244008354, 0.07020128052681684, 0.10879625060728618, 0.04859147706468191, 0.044226468075066805, 0.052329041329877715, 0.10725379123219422, 0.037882145294653516, 0.05130554250042353, 0.03755042648741177, 0.08759683530245509, 0.04832697054371238, 0.05430803960189223, 0.04836932469957641, 0.054703408386558294, 0.03133607369714549, 0.04706421008865748, 0.034280898714704175, 0.01928097289055586, 0.0299173825021301, 0.07532467453607491, 0.02846723103097507, 0.02434334285291178, 0.048983731373612366, 0.033871256945920844, 0.023710663230823617, 0.09012462251952716, 0.022772520714040314, 0.05336907605773636, 0.02382398027527545, 0.021721907625240938, 0.11079104856720992, 0.016045198842350925, 0.04919051831322057, 0.06920082813927106, 0.021387196478566954, 0.016673050687781403, 0.0066349906431111905, 0.029549962574882165, 0.0273111142284636, 0.03818437836265989, 0.14930116784359726, 0.2388402282127312, 0.07105008033769471, 0.2711695720042501, 0.2199456470885447, 0.1300188446683543, 0.14583754512880528, 0.2386619634926319, 0.1529398254517998, 0.07418394181877375, 0.07206803892872163, 0.14822217502764293, 0.08820610546639987, 0.12745380587875843, 0.1141757033765316, 0.11053121715251889, 0.15020565502345562, 0.1534707248210907, 0.2506455161741802, 0.08207968742187534, 0.11584112686770302, 0.11488933222634451, 0.15548544456916197, 0.1281070722533124, 0.22405433947486536, 0.1641574070921966, 0.14307327488703386, 0.27411962513412746, 0.17577556866620267, 0.0831669040822557, 0.11131566470222813, 0.10086056643298694, 0.15966171904334, 0.054077249485999346, 0.15448385902813502, 0.09905656573495694, 0.11847366632095405, 0.1435189638286829, 0.1462926928486143, 0.11847547122410365, 0.0917063555014985, 0.1714820433408022, 0.12503481496657642, 0.16756856547934668, 0.17695013992488384, 0.10002270460660968, 0.13279660418629646, 0.09869595829929624, 0.11918498815170356, 0.08841158622609717, 0.19528364044214996, 0.10353906984840121, 0.11276802819754396, 0.17442839166947774, 0.18555025916014398, 0.1501814584646906, 0.3734377457627228, 0.14857151199664387, 0.14728848370058195, 0.19091607337551458, 0.09554413599627358, 0.2513352334499359, 0.3891519382596016, 2.4573600590229034, 13.680149265698024, 25.608907801764353, 54.691536222185405, 69.42665045601981, 82.4828575679234, 105.67654200962612, 104.9974945613316, 102.23373740059989, 101.65733569008964, 94.55247606549943, 100.0514610835484, 94.4433685030256, 89.9754753112793, 95.51566314697266, 94.46462999071393, 102.49123069218227, 107.87337480272565, 117.68526649475098, 119.819155556815, 102.51667499542236, 90.03691823141915, 106.43243653433663, 99.02414907727922, 103.6960483278547, 117.4869510105678, 109.39910888671875, 116.6032235281808, 95.47456455230713, 92.4890695299421, 111.74338940211705, 97.32492542266846, 107.35326739719936, 84.6269952229091, 106.80542278289795, 85.77453885759626, 91.50460706438336, 90.8283805847168, 89.80875328608921, 109.74392018999372, 116.23349598475865, 118.14619609287807, 115.89452116830009, 110.7455586024693, 100.36785425458635, 80.26964787074498, 51.99656970160348, 17.847043888909475, 3.400454035827092, 0.5162855163216591, 0.18802529706486634, 0.29092870173709734, 0.18125955654042109, 0.1525221871478217, 0.15382277593016624, 0.1033654734492302, 0.22900809294411115, 0.10301994306168386, 0.10069619811006955, 0.12675176640706404, 0.12652072523321423, 0.15072647136236939, 0.1490151517625366, 0.0836587944733245, 0.09901563650263207, 0.09523443225771189, 0.1098067792398589, 0.15920876977699144, 0.11259857764733688, 0.14037252909370831, 0.16695104432957514, 0.07243506530565874, 0.1312162418450628, 0.16552274168602057, 0.18927931120353086, 0.1457545060132231, 0.17778186100934232, 0.10135219898074865, 0.1274546336914812, 0.13832160271704197, 0.3011898068445069, 0.1435379492385047, 0.17952921081866535, 0.12758276824440273, 0.11341676874352352, 0.14829708529370172, 0.0966269082522818, 0.17247723708195345, 0.08622190622346741, 0.18243488775832312, 0.11210029545639243, 0.146261100258146, 0.13557231452848229, 0.187344509309956, 0.10625289101153612, 0.10422227997332811, 0.12871456465550832, 0.10877803872738566, 0.19761223691914762, 0.1103199077770114, 0.14080747004066194, 0.1381580214947462, 0.1102768275886774, 0.26259856192129, 0.115836322839771, 0.11534727551043034, 0.14722840621003083, 0.1720808504947594, 0.128075221819537, 0.15911206496613367, 0.091656598528581, 0.06523735581764153, 0.2267716686640467], [0.01356458168343774, 0.04573959777397769, 0.018126528676865355, 0.052445874882063696, 0.0563965059284653, 0.021467803046107292, 0.041992483128394396, 0.03749044399176325, 0.07158953603357077, 0.03838333500815289, 0.008359415722744805, 0.022301663212212067, 0.026926790297563587, 0.050858961285224984, 0.009536951331288686, 0.0409411813265511, 0.05477190988936594, 0.027180321514606476, 0.030043491628021002, 0.058509301128132005, 0.03363767805110131, 0.01833356497809291, 0.016996623682124273, 0.05518141255847045, 0.063526701182127, 0.024963065848818848, 0.03724861071844186, 0.1061878873567496, 0.0570721368172339, 0.02996831334062985, 0.04735646190653954, 0.051960539139275036, 0.023066448513418436, 0.013096842898188956, 0.032151282631925175, 0.054008384966956716, 0.05512916536203452, 0.027576569002121687, 0.0473776695185474, 0.04556176392361522, 0.07583829840379101, 0.10246099984007222, 0.05391341720574668, 0.014106439393279808, 0.09616086326007332, 0.05145179733101811, 0.015942412661388516, 0.040725844845707924, 0.05479515649910484, 0.028046084700950553, 0.08000841177999973, 0.03527665563992091, 0.05217800282740167, 0.02899221357490335, 0.1134738674653428, 0.03290962693946702, 0.19894967015300477, 0.0436654994264245, 0.024620246208672012, 0.039974435166056664, 1.1611422364200865, 9.508680122239248, 31.125219890049525, 54.00335884094238, 68.78722858428955, 78.60681193215507, 77.84212793622697, 67.99270207541329, 72.4523686000279, 67.3901265008109, 68.63029657091413, 69.60808181762695, 67.46511146000454, 82.12480994633266, 63.37136486598423, 73.27379853384835, 71.26488671983991, 70.96702439444405, 50.327615874154226, 48.85527522223336, 31.70140620640346, 42.63783604758126, 89.54306806836809, 81.04763766697475, 91.27547631944928, 85.41913155147007, 84.30639839172363, 74.52575969696045, 62.928389413016184, 55.95211315155029, 48.29966252190726, 54.56771237509591, 54.88252830505371, 56.51635898862566, 58.43491990225655, 42.34922872270857, 36.40028531210763, 33.21943473815918, 38.68188960211617, 65.38780852726528, 63.11469841003418, 73.52826935904366, 79.56810910361153, 67.09497397286552, 76.03451238359723, 78.79755387987409, 76.40007100786481, 85.05612291608537, 89.20074422018868, 90.20968518938336, 88.72839873177665, 54.12683180400303, 35.49659218106951, 15.846676622118268, 0.49954198620149065, 0.18348698344613823, 0.2118750022990363, 0.09273755231073924, 0.01929136465436646, 0.16264974299286092, 0.007370194786095193, 0.023114712709294896, 0.016318860497059565, 0.0549062258963074, 0.07202640401997737, 0.03881264750712684, 0.03891723010955112, 0.03226179563041244, 0.04602462658658624, 0.031733481479542594, 0.06593133429331438, 0.028322979575023055, 0.017633374514324323, 0.014337614577795778, 0.01603507509987269, 0.06689340195485524, 0.03787291043304971, 0.04407386554937277, 0.022420674861807908, 0.033457238626267226, 0.051537543801324706, 0.024181608942204287, 0.04425502761400171, 0.053037106192537715, 0.03779008844867349, 0.09804594210748162, 0.039350919159395356, 0.015996797243133187, 0.026030593119295578, 0.01240954629611224, 0.03196890938228794, 0.009458086054239954, 0.024391715614391223, 0.01788901597527521, 0.007522724369274718, 0.06137506663799286, 0.04979718629536884, 0.02541691587040467, 0.061060993133911064, 0.08116339373269252, 0.03901963122189045, 0.006472651563983942, 0.066055431562875, 0.006540029667251344, 0.05363203551886337, 0.041616065826799185, 0.03105080739728042, 0.030745073088577816, 0.10631591334406819, 0.011637215685498501, 0.07029943740261452, 0.014757544633799365, 0.09919530579021998, 0.05615761071177466, 0.06271624538515295, 0.04601594812369772, 0.007943703610050892, 0.00465318832513211, 0.0044986515505505455, 0.026766126775848012, 0.04993649971272264, 0.05279475383992706, 0.050398602416472774, 0.05791412413652454, 0.014193942421115935, 0.041292106067495685, 0.04742998456848519, 0.012469420226157775, 0.027576711494475603, 0.05876542095627103, 0.02959656435996294, 0.07971360867044755, 0.02331820366505001, 0.049290123861283064, 0.029746642735387598, 0.05761987742568765, 0.03762976419446724, 0.014976411193077053, 0.03202321593250547, 0.01908037419031773, 0.05452587987695422, 0.05260439423312034, 0.05827258061617613, 0.02087421721911856, 0.033824024123272727, 0.044080277705299, 0.01623558559055839, 0.05227092480553048, 0.006326115989525403, 0.0283349811631654, 0.025267156406438777, 0.04159194051421114, 0.007434344334926988, 0.06468258558639459, 0.051715303012835126, 0.019909596569570046, 0.03917177573644689, 0.04621294041031173, 0.06132627997015204, 0.02911440416106156, 0.023615456286019514, 0.030024940480611155, 0.030286037363111973, 0.037369556192840846, 0.07177008063133274, 0.041750205414635796, 0.02329099101812712, 0.06529905500688724, 0.050293565195586, 0.03578574689371245, 0.045722346021128554, 0.08463677378105265, 0.1362987541194473, 0.03390647630606379, 0.09224712076996054, 0.11503732071391173, 4.200307641710554, 21.174727269581386, 51.13743536812918, 75.83876773289272, 85.77516419546944, 98.47821521759033, 92.93015507289341, 83.06631170000348, 89.81276239667619, 81.72616400037492, 86.97315870012555, 91.77324526650565, 90.57857200077602, 110.76645878383091, 85.98567376817975, 106.36148153032575, 100.59181553976876, 99.12125015258789, 60.7860027040754, 47.20205211639404, 51.16067361831665, 47.99605403627668, 98.85022177015031, 107.8904117856707, 104.00416619437081, 90.82761628287179, 96.75709778921944, 86.523499080113, 87.85359968457902, 77.93460845947266, 68.8458366394043, 84.51012652260917, 74.41975797925676, 81.15530000414167, 75.38022831508091, 65.53809111458915, 49.54338312149048, 58.84401593889509, 65.29165935516357, 93.75169617789132, 97.0972399030413, 105.26488903590611, 102.30238560267857, 95.96177223750523, 96.80098955971854, 91.21480464935303, 90.65492575509208, 97.25473472050258, 100.69990866524833, 105.37158557346889, 106.88592461177281, 76.83277007511684, 54.78739704404558, 29.83605112348284, 4.9828115957123895, 1.173816402043615, 0.19880423295710767, 0.14567171117024763, 0.010590519440094275, 0.16338189584868296, 0.054463671786444526, 0.09767478345228092, 0.031104140249746184, 0.0863514385585274, 0.012256048952362366, 0.04488369709412966, 0.04425860349354999, 0.05534381652250886, 0.03484001157007047, 0.03379118302837014, 0.046460229105183055, 0.03570930653118661, 0.05513160130275147, 0.031071031133511236, 0.03568284705813442, 0.04059885023161769, 0.015393883255975587, 0.04725340261523213, 0.008124700281769037, 0.04810844834095665, 0.05171589673097644, 0.03212096907996705, 0.04332684259861708, 0.034381379572940726, 0.034532960903431685, 0.05421169102191925, 0.07657811191997357, 0.006197081529535353, 0.061848283745348454, 0.040246069697397094, 0.02280600811354816, 0.019781031146911637, 0.02542283439210483, 0.034897887214486084, 0.051612372643181255, 0.05785426377717938, 0.0888548188709787, 0.028393079027799622, 0.04084322801125901, 0.0342806849761733, 0.029876789144639457, 0.08958560787141323, 0.0028247601543885787, 0.01573049769337688, 0.022989743522235324, 0.07687785476446152, 0.05371227567749364, 0.012393230073420065, 0.09822514320590667, 0.01693207464580025, 0.02006696241109499, 0.03347482964662569, 0.0385531180405191, 0.03289789506899459, 0.02617209481208452, 0.03345390023397548, 0.06727631283657891, 0.13332647218235902, 0.14461832626589707, 0.14234161057642528, 0.17248280106910638, 0.09539434260555676, 0.10453432465770415, 0.0855524567887187, 0.15885306814951555, 0.09612197641815458, 0.13013555269156182, 0.10752342069255454, 0.12686240832720483, 0.22925877092140062, 0.1320023110934666, 0.13145161207233155, 0.255288975579398, 0.13832884947104113, 0.12673193961381912, 0.10576737206429243, 0.0708979731425643, 0.1220399649547679, 0.08265741249280316, 0.1151541101613215, 0.07752827807728734, 0.11384779454341956, 0.2709790665124144, 0.1743477409971612, 0.13575466402939387, 0.0858049260984574, 0.11740129600678172, 0.14697671043021338, 0.13093372700469835, 0.11140105154897485, 0.09067891777626105, 0.10853743699512311, 0.15101163248930657, 0.1931794083544186, 0.0891388129176838, 0.13670677079686097, 0.12244036846927234, 0.21105867038880075, 0.21900811525327818, 0.136716487418328, 0.15107601189187594, 0.1346362754702568, 0.14417210806693348, 0.19268368424049445, 0.16921634706003325, 0.1659868596387761, 0.27687227885637966, 0.1395440785480397, 0.13024299192641461, 0.09937610144593886, 0.1850007407899414, 0.15267496609262057, 0.42068465479782646, 0.10610617816980396, 0.15835068082170828, 0.18338179694754736, 2.5057084475244795, 16.902808019093104, 49.16488695144653, 78.49696091243199, 96.47968401227678, 112.1736843926566, 107.07726410457066, 92.22195993150983, 96.42297976357597, 86.65852342333112, 88.73649338313511, 89.89525835854667, 90.98854351043701, 103.51110812595913, 80.6961283002581, 93.90329197474888, 94.87924984523228, 90.0371127809797, 67.03382287706647, 61.8999240057809, 44.229970591408865, 56.21746138163975, 107.16579805101667, 97.28725923810686, 107.18794195992606, 101.52498640332902, 99.3979274204799, 93.29205199650356, 81.0114722933088, 74.98935045514787, 65.32456602369035, 71.4302191053118, 71.40944399152482, 70.94790990012032, 76.70493711744035, 57.18456029891968, 52.20686388015747, 51.41493252345494, 53.74108171463013, 87.15926619938442, 89.47552462986538, 102.15982246398926, 106.84262343815395, 93.7886883871896, 96.01471056256975, 94.41031592232841, 93.88225282941545, 102.64943422589982, 108.21114758082798, 116.63310078212193, 117.27394703456334, 80.6069620677403, 54.69692802429199, 26.336698600224086, 3.2744732073375156, 0.5222821916852678, 0.3275522222476346, 0.4031055766556944, 0.060368873844189305, 0.4282007057751928, 0.09759945927986077, 0.2142077378396477, 0.1312182910208191, 0.19365553637700422, 0.23984171875885554, 0.1478004790842533, 0.09296959771641664, 0.14607106974082334, 0.10636526319597449, 0.12225876535688128, 0.1846981548837253, 0.09827351596738611, 0.15606639268142836, 0.08845342469534703, 0.13866620351161274, 0.13892110197671823, 0.10827637064669814, 0.12958314376217978, 0.09775664191693068, 0.14008424670568534, 0.21195284383637564, 0.1508227011987141, 0.14721474051475525, 0.10344531666487455, 0.11727533276591982, 0.14596489258110523, 0.16335484944283962, 0.08931576127984694, 0.14901234262755939, 0.142871885693499, 0.09533966625375406, 0.07342144487691776, 0.0931432144716382, 0.07538389028715235, 0.09612201034490551, 0.14518202601798944, 0.1659455911389419, 0.14288266082959517, 0.13172498026064464, 0.12991661658244474, 0.08480574257139649, 0.12583300285041332, 0.19289046100207738, 0.0889288131147623, 0.14781561041516916, 0.18230325196470532, 0.12771751172840595, 0.15258728579751082, 0.18110688616122517, 0.10115872150553123, 0.1693613092814173, 0.09632295170532805, 0.21445813083222934, 0.26036080771258896, 0.24397396988102368, 0.15624378887670382], [0.07323637445058141, 0.04946049043376531, 0.010946591717324086, 0.048611470099006376, 0.07894282681601388, 0.019764990579070787, 0.01693798298947513, 0.023444804728829434, 0.015414330908762557, 0.013800325953135533, 0.046830824576318264, 0.06537190252648932, 0.05120427793424044, 0.018622273146840077, 0.01472657629554825, 0.06440195028803178, 0.019663848149191056, 0.02921492912407432, 0.03324826680389898, 0.04978426020326359, 0.016952790319919586, 0.06289287483585732, 0.039607768412679434, 0.044385665961142094, 0.053538282335336716, 0.03569327614137104, 0.04176567601306098, 0.025540558521502783, 0.04124236945062876, 0.058228462269263606, 0.0530373640358448, 0.02311869401351682, 0.09178877715021372, 0.05640670091712049, 0.028580325855208293, 0.03186314273625612, 0.019082414884386317, 0.025323269556143453, 0.02640301893864359, 0.033063352440616915, 0.03281366512445467, 0.035587584134191275, 0.010059590384896313, 0.0099293566142608, 0.0412895887025765, 0.031355065892317464, 0.06167309278888362, 0.031904336597238264, 0.038375816840146265, 0.016042206502918686, 0.0707560507580638, 0.027710806977535998, 0.03855993392478142, 0.05411435178081904, 0.07243305684200355, 0.027372711637456502, 0.21298269714627946, 0.28622862536992344, 4.886560806206294, 16.376424653189524, 47.73367616108486, 62.81249346051897, 73.74794360569545, 75.96056270599365, 73.99351378849575, 65.42819840567452, 59.21388939448765, 65.19473893301827, 58.30367537907192, 71.77743448529924, 58.316070965358186, 45.94263901029314, 39.638594014304026, 42.497791630881174, 37.156881604875835, 30.778654166630336, 30.56407642364502, 27.596033539090836, 41.89840875353132, 52.4992857660566, 49.59379925046648, 52.842016083853586, 35.38545574460711, 30.268239498138428, 43.9226587159293, 66.45838696616036, 61.60602215358189, 50.46069472176688, 45.5400047983442, 36.587025097438264, 39.91748080934797, 30.179768085479736, 42.97858265468052, 31.29899433680943, 34.99834033421108, 30.34282146181379, 49.295797961098806, 23.576768159866333, 30.343460696084158, 22.674310071127756, 20.137336901256017, 37.08342524937221, 37.72306251525879, 45.08511665889195, 51.88493994304112, 67.9036887032645, 62.15559686933245, 59.474439893450054, 62.067389488220215, 60.00458744594029, 68.83981949942452, 78.4439253125872, 83.61740112304688, 82.39872183118547, 58.711062158857075, 39.82898160389492, 19.899533067430767, 2.2800774233681813, 0.11046043237937347, 0.3453928349273545, 0.0791910213551351, 0.0315924072638154, 0.01767788301887257, 0.0317455797589251, 0.009007119806483388, 0.03566154445122395, 0.04308745205136282, 0.06345561785357338, 0.03714654887361186, 0.0375266166936074, 0.037898586198155365, 0.007412617643629866, 0.05942478057529245, 0.04385020683652588, 0.032969229455505095, 0.029907197691500187, 0.02956279367208481, 0.030424105668706552, 0.042241681899343214, 0.010358803123900933, 0.06508794240653515, 0.033314278083188195, 0.07620325524892126, 0.055919031013867686, 0.015240846467869622, 0.06438054250819342, 0.03496487558420215, 0.06348581266190324, 0.043718764425388405, 0.04222797549196652, 0.06704817579260894, 0.0439726925854172, 0.029962847741054635, 0.013605350611864455, 0.0985462734741824, 0.025026905816048384, 0.033746555780193636, 0.028740059783948318, 0.062030945372368605, 0.06535120720842055, 0.02407447844078498, 0.01902503626687186, 0.009928076727581876, 0.024767549375870397, 0.0508911849132606, 0.026523984769093137, 0.026509939094207118, 0.014118055064630295, 0.06325787239308868, 0.0590835249583636, 0.021897200361958573, 0.033557960364435396, 0.006514526504491056, 0.04442110245249101, 0.024613974848762155, 0.0385801780170628, 0.07085378015679972, 0.029212964765195335, 0.02287984120526484, 0.018359486712142825, 0.020400297828018665, 0.04930815253672855, 0.004826961567492357, 0.01600848670516695, 0.02304929684448455, 0.023439157621136734, 0.06959980673023633, 0.05256684410518833, 0.056175842947725735, 0.05309463578409382, 0.015754421141796877, 0.02284857600794307, 0.05404141605166452, 0.047554064874670336, 0.04850019374862313, 0.04394348165286439, 0.028293237688818147, 0.032711684703826904, 0.035276343513812335, 0.0316733327428145, 0.019210771657526493, 0.03885625356010028, 0.045516597240098884, 0.04989349077056561, 0.05881774279155901, 0.02312212061536099, 0.03332885640806385, 0.052065152275775156, 0.06566514500549861, 0.065141533102308, 0.02026428548353059, 0.013414178459372903, 0.020021485297807624, 0.049556689736034186, 0.05307303462177515, 0.05444511724635959, 0.053520657388227325, 0.013808397127182355, 0.04445691892345037, 0.026057644614151547, 0.023424457159957716, 0.01718377212195524, 0.06588299545858588, 0.05287497364250677, 0.032665998941021304, 0.015663505930985724, 0.07610105430441243, 0.08394970957721982, 0.037434152726616175, 0.010579107329249382, 0.048085432433124096, 0.08855909973915134, 0.08975454952035632, 1.7707137784787585, 12.779707891600472, 33.91623830795288, 68.86532633645194, 77.43793732779366, 84.96558788844517, 82.27055535997663, 88.43651185716901, 75.07852363586426, 78.03983197893415, 90.22459602355957, 89.67238794054303, 107.0268896647862, 94.00814029148647, 72.84395517621721, 65.89581217084611, 72.23183277675084, 59.13164356776646, 47.63035992213658, 45.44659669058663, 39.6044088772365, 40.74921839577811, 50.67148222242083, 36.5708601134164, 51.92131723676409, 60.4344516481672, 45.5735958644322, 66.15625844682965, 89.62036677769252, 81.96828092847551, 67.71141815185547, 55.5997074672154, 43.923864228384836, 40.099381174360005, 26.456713097436086, 40.941370827811106, 29.38305984224592, 41.78742865153721, 28.03900030681065, 46.58347831453596, 32.21289437157767, 30.348289694104874, 35.260975292750764, 27.27894902229309, 50.59797722952706, 55.70673057011196, 67.01797403608049, 84.51943710872105, 105.51701136997768, 90.24960953848702, 93.57058443341936, 90.80595874786377, 83.65717955998012, 82.87051841190883, 89.96734591892788, 98.68416677202497, 96.9176081248692, 82.90637111663818, 62.99004077911377, 37.07620259693691, 6.2020780103547235, 0.17277366189020021, 0.3789515213242599, 0.11283916580889906, 0.11657850444316864, 0.0379335103955652, 0.09502709909741368, 0.015193998713844588, 0.026600922158520137, 0.10151922716093914, 0.0846491027623415, 0.02890428900718689, 0.010697729669378271, 0.03159544710069895, 0.05911013710179499, 0.025408669973590543, 0.0397699416748115, 0.024203467947830046, 0.04224739855687533, 0.02436654705421201, 0.048686485537993054, 0.022514229573841606, 0.027223447504054223, 0.045833354350179434, 0.011935966172521668, 0.06069897434541157, 0.02423487733384328, 0.06883485349161284, 0.05476031033322215, 0.014814472025526422, 0.01917895345416452, 0.03173446874799473, 0.0235869730822742, 0.01819667053808059, 0.05765526302691017, 0.009325018551732813, 0.008886489850868071, 0.06615150533616543, 0.08087863294141633, 0.045670790930411646, 0.056370613032153676, 0.04579235047900251, 0.05692305588828666, 0.012948154671383756, 0.04521794344431587, 0.029780725549374307, 0.05438857153058052, 0.07814294937998056, 0.027322345679359775, 0.05494223235707198, 0.036407519065375836, 0.0432183923465865, 0.024058478585045253, 0.03722052276134491, 0.03669278197256582, 0.02745041068244193, 0.02486001164652407, 0.007144070446624288, 0.03473571055967893, 0.15617327551756585, 0.09964869610433068, 0.090071493227567, 0.08910429584128515, 0.2432919064802783, 0.1910099826220955, 0.12568808134113038, 0.16861360440296785, 0.08881571489785399, 0.07254827208817005, 0.1957299264946154, 0.15254746936261654, 0.10259877637560878, 0.19254618590431555, 0.058471656005297384, 0.18932950922421046, 0.1118519991370184, 0.12133804761937686, 0.214763539444123, 0.352022827735969, 0.11929102960441794, 0.10229809036744492, 0.09507551257099424, 0.13680783180253847, 0.14935137943497725, 0.10408239319388356, 0.12707910527076038, 0.18676236697605678, 0.11495956060077463, 0.13618929285023892, 0.10559718869626522, 0.17171051965228148, 0.18453947268426418, 0.07118955999612808, 0.06326707332794156, 0.1260340663471392, 0.08485112299344369, 0.10517190330262695, 0.09403377811291388, 0.10407152306288481, 0.09175742204700198, 0.09929482652140514, 0.0938486669744764, 0.07142943569592067, 0.1462572868913412, 0.09694009287548916, 0.12228188983031682, 0.15450079526220048, 0.17241713245000156, 0.11689818943185465, 0.1967983613056796, 0.1708543984485524, 0.14521414786577225, 0.08703240273254258, 0.2422567063144275, 0.135208484051483, 0.38379308581352234, 0.6906635335513523, 9.024614759853907, 30.399612562997, 71.97355433872768, 85.99123232705253, 98.12679617745536, 94.94675159454346, 91.47482013702393, 80.16958686283657, 78.61583069392613, 86.36211327144078, 82.80494826180595, 95.47769818987165, 82.29556887490409, 64.19326032911027, 53.61326960154942, 56.8867883001055, 51.37440020697457, 39.98841149466378, 41.46789142063686, 38.31866904667446, 53.476080894470215, 71.66378974914551, 69.73934023720878, 74.9893296105521, 51.75026648385184, 39.681870869227815, 54.09627015250069, 83.24033628191266, 75.3336684363229, 68.23765386853898, 61.58506638663155, 49.331091335841585, 57.17183814729963, 40.58742611748831, 58.42854840414864, 44.11105564662388, 51.959702559879844, 41.636173316410606, 68.86488165174211, 36.694319180079866, 46.377422537122456, 35.664509296417236, 29.6811340876988, 50.520702838897705, 53.11664015906197, 59.95243426731655, 72.59957313537598, 90.943970816476, 83.60484572819301, 80.65887205941337, 82.03979873657227, 77.27200739724296, 85.6738177708217, 97.65488842555455, 106.58763149806431, 109.51062747410366, 86.95648302350725, 63.73451246534075, 33.667663029261995, 4.403168550559452, 0.14292334578931332, 0.5767942294478416, 0.1660936881921121, 0.13036868375326904, 0.14490598440170288, 0.1387256160378456, 0.10628697382552282, 0.17607590183615685, 0.157776287357722, 0.16269767470657825, 0.14390214612441404, 0.1467970750693764, 0.0896829097930874, 0.10320974287710019, 0.07927689674709525, 0.129495572032673, 0.09215366614184209, 0.17886641781244958, 0.1413325068673917, 0.11281614311571632, 0.1020757005150829, 0.11029332956033093, 0.16156032787902014, 0.06719025424016373, 0.16242267803422042, 0.1125795990228653, 0.22113935303475174, 0.1818508862384728, 0.2178380223257201, 0.16096339348171437, 0.07407401236040251, 0.1195479365331786, 0.27889203333428925, 0.1244220028498343, 0.06116088705935648, 0.12522931024432182, 0.24318499650274003, 0.18580563259976252, 0.12961731478571892, 0.1689611907516207, 0.2425434280719076, 0.16146624221333436, 0.08956390832151685, 0.08579575230500527, 0.13089424983731338, 0.15081815501408918, 0.21145882963069848, 0.08757670995380197, 0.08102712354489736, 0.07293168508580752, 0.22544323280453682, 0.182985071092844, 0.1065433786383697, 0.10097641271672078, 0.10373442008027009, 0.11022238872413125, 0.10580701886543206, 0.13287460857204028], [0.03123667510226369, 0.009668291962173368, 0.04904175629573209, 0.07084263861179352, 0.01433368755637535, 0.018302600032516887, 0.034435835400862355, 0.07115257983761174, 0.036243506973343234, 0.06371494036700044, 0.013473102440392333, 0.017983559652098587, 0.037910803221166134, 0.06234693234520299, 0.010644769163003989, 0.017681686207652092, 0.05986470875463315, 0.017803009965323975, 0.012979591198797737, 0.009560950266729509, 0.15404343551823071, 0.01326913820646171, 0.032819171436131, 0.021750214409881403, 0.02426760138145515, 0.05346166216103094, 0.030043827502855232, 0.02962808231157916, 0.04398787480645946, 0.07196382273520742, 0.029042896748121296, 0.041115541077618084, 0.005445759211267743, 0.04882023836086903, 0.07274178349013839, 0.06332303211092949, 0.027966594323515892, 0.04408387394089784, 0.03482928393142564, 0.042281474585511854, 0.05857266951352358, 0.03455691318958998, 0.031758010520466735, 0.02555101135346506, 0.0542294856027833, 0.03509644352431808, 0.0648551709683878, 0.06710076225655419, 0.006131163548811206, 0.090817108218159, 0.029094278812408447, 0.06513831006096941, 0.0474200881352382, 0.058838838445288796, 0.02797049081086048, 1.8366911581584384, 17.269011088779994, 39.75928769792829, 61.744979177202495, 76.01639148167202, 70.84495149339948, 70.42937973567417, 67.28406919751848, 66.97035108293805, 54.25798600060599, 57.83011743000576, 48.44296216964722, 53.732340880802695, 49.17555938448225, 35.07828630719866, 40.478547845567974, 29.89806032180786, 27.00726924623762, 23.665685994284495, 33.76324592317854, 42.563125542231965, 44.99124649592808, 66.62828431810651, 66.05880301339286, 31.33187668664115, 66.46546023232597, 28.8802239213671, 20.253642797470093, 43.42393091746739, 23.73249466078622, 26.383988039834158, 34.25093303407942, 33.34605523518154, 53.57245240892683, 45.48947402409145, 50.73571137019566, 82.13140378679547, 68.93676771436418, 63.498503003801616, 45.214068276541575, 70.1687319619315, 52.3549473626273, 51.00140701021467, 66.34601375034877, 50.89812898635864, 67.68230519975934, 46.27219901766096, 16.52530891554696, 66.38434001377651, 32.325774805886404, 25.047046933855327, 51.53221811567034, 33.52765335355486, 49.819431577410015, 58.73777798243931, 62.091965266636436, 59.62098434993199, 55.632141658238, 60.40861129760742, 80.7963421685355, 77.79389354160854, 76.06306253160749, 41.77569661821638, 20.407712153026036, 5.722632331507547, 0.10680947293128286, 0.18398274827216352, 0.01799450781462448, 0.06599073324884687, 0.03257852899176734, 0.04875127884692379, 0.07832533280764307, 0.004643727850634605, 0.08582529571971723, 0.0790275554837925, 0.009121247700282505, 0.04114185805831637, 0.0606291259505919, 0.05984642902123077, 0.04879638785496354, 0.06302796437272004, 0.04473255341872573, 0.028019245248287916, 0.009675070527009666, 0.05522921535053423, 0.0352289173086839, 0.03249283680426223, 0.025478793175092766, 0.008651667540626866, 0.032652699654655795, 0.04634273737402899, 0.01682556330758546, 0.01200029214045831, 0.04250126225607736, 0.011470427537070853, 0.08181900783841099, 0.03113471164501139, 0.024816714326984117, 0.09347763045557908, 0.0395517078494387, 0.0205582930107734, 0.023196376095126783, 0.01874953069325004, 0.027595520485192537, 0.026981466649366275, 0.04835884811888848, 0.04342360169227634, 0.06033510315631117, 0.04698483506217599, 0.02830629948792713, 0.06860126781144313, 0.049035361103181324, 0.007948583125003746, 0.05766716453113726, 0.0753211190125772, 0.08281471048082624, 0.041474866082093546, 0.06433212224926267, 0.030210163577326705, 0.033639187791517804, 0.039683442030634196, 0.03331682937485831, 0.02884914107354624, 0.006882379421897764, 0.0238413999655417, 0.02204948227985629, 0.012093058903701603, 0.027382740385032127, 0.01253745608430888, 0.06284200506550924, 0.06553425560040133, 0.05740776737885816, 0.056088071050388474, 0.029141450566904883, 0.02086437337233552, 0.010649922636470624, 0.009145651212228196, 0.06233123104487147, 0.019731367472559214, 0.08422577154955693, 0.03688681245382343, 0.04847115584250007, 0.007226794891591583, 0.023074367017086064, 0.12024081578212124, 0.01630227031585361, 0.06793928904724972, 0.03560968401974865, 0.06509508738028151, 0.03627231417755995, 0.07161059776054961, 0.012527212750033608, 0.05745334457606077, 0.043394261838069985, 0.05301440241081374, 0.02020777708717755, 0.026247770126376833, 0.0033009017476745483, 0.07920092118105718, 0.03353665436484984, 0.024041248884584223, 0.06584807804652623, 0.1216449218669108, 0.0774894387328199, 0.0181638073907899, 0.05307083956098982, 0.04933804539697511, 0.05962362526250737, 0.05715616659394332, 0.02932043792679906, 0.005538183314326618, 0.049634853577507396, 0.014386077245165194, 0.06897341712777104, 0.09127042389341763, 0.14417575858533382, 6.561046702521188, 35.09186656134469, 59.41658919198172, 79.95690945216587, 89.81882122584751, 80.86678300585065, 82.50425801958356, 86.73293168204171, 88.79105063847133, 83.68500709533691, 100.60024370465959, 81.46543284824916, 76.75814642224992, 71.5728656223842, 54.0263261113848, 52.73698016575405, 32.80205992289952, 34.640442098890034, 20.753916570118495, 27.53790143557957, 24.252338034766062, 20.24590597833906, 38.41726051058088, 48.99042810712542, 44.59889909199306, 57.93458359582083, 37.975264753614155, 17.11481145450047, 22.238242864608765, 13.061696188790457, 19.4508045060294, 18.115464959825786, 22.179289136614116, 30.708810874394008, 29.905817985534668, 40.68327651705061, 47.1354466847011, 48.13431971413748, 42.4244499206543, 32.132180622645784, 40.14281783785139, 38.08386162349156, 31.891797270093644, 42.62937661579677, 32.41750839778355, 45.6588328906468, 36.87759876251221, 18.434840645108903, 56.945104530879426, 31.697480474199565, 30.37179544993809, 56.35368428911482, 42.12063993726458, 70.80616664886475, 83.27797467367989, 88.01890427725655, 89.8793956211635, 78.10574953896659, 77.62624740600586, 95.80902998788017, 87.70800018310547, 87.97501250675747, 63.25906113215855, 41.65253284999302, 13.890116010393415, 0.4038724297923701, 0.35853358837110655, 0.030376862668033158, 0.040657509583979845, 0.028379898485062376, 0.055675213025616746, 0.03852214630959289, 0.10487339539187295, 0.10084648683134999, 0.0512630865643067, 0.031582585469420464, 0.08738157006778888, 0.04840201651677489, 0.061405023959066184, 0.04998417358313288, 0.053239129816315005, 0.046593462848769765, 0.015394380282876747, 0.03759471107540386, 0.03321364116189735, 0.023617795535496304, 0.004787081095855683, 0.07951583606856209, 0.025705639306189756, 0.021849099014486586, 0.0330296224648399, 0.07027418911457062, 0.036685083992779255, 0.05764123770807471, 0.03218202026826995, 0.05575654223295195, 0.05569916870445013, 0.018187880116914, 0.07129511968897921, 0.039803580048360994, 0.03491461310269577, 0.022950770167101706, 0.06687340552785567, 0.008268204501031764, 0.0628830903608884, 0.03803688859833138, 0.10470473194228751, 0.03497175932196634, 0.008759866734700543, 0.03440442601484912, 0.06723626569977828, 0.07306948876274483, 0.037901039102247784, 0.042165543484900675, 0.09988459558891398, 0.016355245241097043, 0.05739085150084325, 0.03687334353370326, 0.06080108029501779, 0.06924996764532157, 0.02261403020072196, 0.12630056776106358, 0.11812093667685986, 0.12026476806827954, 0.11358849238604307, 0.12544378159301622, 0.08556408687893834, 0.09960788900830916, 0.0756840809647526, 0.1539539774613721, 0.1571988540568522, 0.1403872940157141, 0.12378985248506069, 0.07922315677361828, 0.11826384972248759, 0.13250917675239698, 0.12232554677341666, 0.11731278789894921, 0.07377735685024943, 0.14891768699245794, 0.1806581030998911, 0.25264676021678106, 0.14683496446481772, 0.1463102533348969, 0.16261022511337483, 0.09166769257613591, 0.14641516841948032, 0.11066219476716858, 0.12500494585505553, 0.12760239147714206, 0.10241089002894503, 0.09165527538529464, 0.18453267376337731, 0.06155372490840299, 0.17102110093193396, 0.14524427482060023, 0.1441387784268175, 0.07806294331593172, 0.1769051801945482, 0.13987430797091552, 0.09953218485627856, 0.20156893746129104, 0.12177244573831558, 0.18920798360237054, 0.06740557375763144, 0.172936225309968, 0.15424201557678835, 0.1353161268468414, 0.20798061841300555, 0.16734620955373558, 0.1804905863744872, 0.20736146877918923, 0.11281193619860069, 0.19618218365524495, 0.23373886623552867, 0.13797374495438167, 3.638681926897594, 29.74505056653704, 59.62419441768101, 87.46150588989258, 102.03560256958008, 91.9440667288644, 90.53836972372872, 84.45334584372384, 85.30265195029122, 74.95872279575893, 79.95709705352783, 69.07760075160435, 71.29101194654191, 61.09826864515032, 45.59496504919869, 49.335440908159526, 41.79592629841396, 38.27087933676583, 34.27059991019112, 44.7263742174421, 59.12498719351632, 61.91550186702183, 85.10403074537004, 81.64091655186245, 40.95946046284267, 85.12637615203857, 40.34386396408081, 28.927332707813807, 56.42230817249843, 33.17087377820696, 36.7544766834804, 45.734873976026265, 43.42667893001011, 69.50627681187221, 63.03295285361153, 69.34884452819824, 110.86879185267857, 92.18320982796806, 90.75317328316825, 62.32978820800781, 92.45459256853376, 69.29073674338204, 68.83679703303746, 89.5913302557809, 67.60465908050537, 90.39770344325474, 71.96968419211251, 28.747499431882584, 92.37120028904506, 44.370741094861714, 33.33293356214251, 66.2743639264788, 45.67894097736904, 63.72774491991316, 75.00963919503349, 79.99921703338623, 78.88218293871198, 71.5994563783918, 78.41780703408378, 98.52907603127616, 97.97291442326137, 100.5555876323155, 67.72135407584054, 39.76714958463396, 10.96073203427451, 0.22297944501042366, 0.39692716247269083, 0.09565358369478158, 0.2295581948544298, 0.10681602079421282, 0.14795728852706297, 0.16060324066451617, 0.16838161328009196, 0.22850109157817705, 0.16951642238668033, 0.10034249816089869, 0.19833187758922577, 0.251265995736633, 0.13877373774136814, 0.11724751283015523, 0.19505341351032257, 0.16336215047964028, 0.10272786087755646, 0.10018740541168622, 0.1459262025143419, 0.17386786746127264, 0.10398274354104485, 0.1536960391593831, 0.09150662871875934, 0.11324604933283158, 0.12951754299657686, 0.15966661806617463, 0.09310900273599795, 0.1674162886504616, 0.12301800533064775, 0.16448138042220048, 0.16271535732916423, 0.07468076515942812, 0.16443840201411927, 0.11801218108407088, 0.10335328696029526, 0.10412600263953209, 0.17636822829289095, 0.07646694074251822, 0.1433700118213892, 0.10718358999916486, 0.21808222707893166, 0.25459005736878937, 0.10784110400293555, 0.0798734783061913, 0.12890291240598473, 0.2115345269973789, 0.12643578621957982, 0.1206102373876742, 0.17984368465840816, 0.10483405393149171, 0.10745414905250072, 0.10317177205745663, 0.11500845583421843, 0.10505815369210073, 0.10671386056180511], [0.032182261148201566, 0.02042605501732656, 0.01124224384381835, 0.01882239687256515, 0.020333848893642426, 0.05260568344965577, 0.06532174521791083, 0.032298321170466285, 0.06113972355212484, 0.07476937504751341, 0.05526951015261667, 0.04724558589181729, 0.039987215373132906, 0.08870290845100369, 0.007353088070106293, 0.07291864364274911, 0.04751067595290286, 0.013397074287890323, 0.035714626245732815, 0.009694942273199558, 0.07006794161030225, 0.05608297185972333, 0.04908979996772749, 0.04311752811606441, 0.029124239526156868, 0.020109757614721144, 0.05364671562399183, 0.07104499811040503, 0.043245330186826844, 0.09376830128686768, 0.05001415126025677, 0.02330099432063954, 0.04387646274907248, 0.06718160291867596, 0.01610907443266894, 0.03083538609955992, 0.06503305570887667, 0.05745945139122861, 0.024543751563344682, 0.023053712411118404, 0.07396180980971881, 0.02904673047097666, 0.029162888880819082, 0.004540113856949444, 0.06008114106953144, 0.049158664486770115, 0.0516429236823959, 0.012332514759951403, 0.018581242134262408, 0.024879724785153354, 0.07675621379166842, 0.08400201784180743, 0.0272031253802457, 4.257341929844447, 27.968686274119786, 60.19651058741978, 71.53086376190186, 80.53539562225342, 71.98463671548026, 69.28522682189941, 66.63379423958915, 57.75669928959438, 45.58414322989327, 45.484130859375, 34.69488818304879, 22.768737827028545, 19.37263206073216, 28.026470967701503, 27.969252552304948, 31.75588355745588, 45.557521206992014, 53.025233132498606, 61.3592985698155, 67.78060831342424, 61.29784175327846, 67.3572267804827, 70.18505328042167, 62.40718419211251, 44.70129122052874, 28.61474714960371, 33.09025035585676, 33.81983552660261, 78.21956103188651, 75.40244170597622, 90.61645357949394, 75.9520650591169, 81.73320252554757, 65.32538591112409, 67.47380365644182, 60.58806242261614, 56.01924317223685, 50.28600658689226, 57.240920611790244, 59.81367179325649, 69.79477991376604, 61.78622368403843, 63.58501502445766, 66.54581614903041, 65.09891632625035, 105.43915680476597, 96.9856379372733, 60.81333691733224, 43.02615349633353, 54.12522677012852, 99.61699022565568, 68.44933768681118, 53.95897722244263, 58.2627192224775, 34.081212861197336, 30.795656408582413, 29.209997585841588, 41.17889152254377, 54.78050095694405, 55.96062469482422, 42.64446810313633, 62.516006878444124, 66.61527034214565, 75.4570892878941, 68.69716603415353, 51.71884672982352, 19.600508655820573, 1.8590630548340934, 0.07711449385221515, 0.28687608348471777, 0.07033043966761657, 0.035764746234885285, 0.030728896813733236, 0.011223394989169069, 0.011592526521001543, 0.065860440954566, 0.043567196665597815, 0.024123936858294264, 0.029383053138319935, 0.0065675616497173905, 0.05392838229558297, 0.026258228047351753, 0.03215607987450702, 0.021993381004514437, 0.030137736749436175, 0.013783795143743711, 0.07097244236086096, 0.07386869444910969, 0.08341578394174576, 0.026305109728127718, 0.020453898701816797, 0.12544239738157817, 0.013045716132702572, 0.03152328829414078, 0.01277539795929832, 0.04161963831367237, 0.023867167332874875, 0.023472731533859457, 0.010064229019917548, 0.036696021977279863, 0.022960456254492913, 0.006817260416158075, 0.06428991058575255, 0.07612863675292049, 0.026697996770963073, 0.0444926980749837, 0.02391214741926108, 0.04566623456776142, 0.007250301040975111, 0.02350325882434845, 0.04927819521565523, 0.020894235698506236, 0.03463674622720905, 0.03400365609143462, 0.029238803378705467, 0.029226616889770542, 0.011983570493092495, 0.10044261600290026, 0.04517968085461429, 0.05180366523563862, 0.08324969892523118, 0.05092430081484573, 0.04563004490254181, 0.03763343167624303, 0.047298667686326165, 0.01776184663841767, 0.0323134253599814, 0.012407784649570073, 0.04557028293077435, 0.08645688968577556, 0.03556845623201557, 0.03483836951532534, 0.02090310415119997, 0.03398034841354404, 0.03252599681062358, 0.04981278242277248, 0.019134838499927094, 0.045751546775656085, 0.017552432071949755, 0.025969547020005326, 0.04805137336786304, 0.025710702873766422, 0.04561227407040341, 0.046995169150510004, 0.0246367685363761, 0.04143423540517688, 0.053747284691780806, 0.036146981974265406, 0.01630091494215386, 0.04982696719733732, 0.059363373156104765, 0.017531587476176873, 0.10642263333180121, 0.06443606024341923, 0.032896853517740965, 0.024580665564696704, 0.010959910511571382, 0.021158961047019278, 0.037947545892425945, 0.011402624077163637, 0.016219880897551775, 0.011734594790531057, 0.025571026440177645, 0.03757975955626794, 0.07392296367990119, 0.03115632977070553, 0.06450318092746393, 0.05831390339881182, 0.009739322704263031, 0.009116146813279815, 0.012071774108335376, 0.030700232101870433, 0.04562861319365246, 0.08958824737263577, 0.25107258611491745, 12.663708584649221, 48.05553756441389, 78.24153123583112, 82.44214112418038, 88.96333122253418, 82.5825503213065, 86.15960107530866, 86.19747570582798, 85.4914414542062, 75.758925982884, 73.98603752681187, 45.21638550077166, 26.684039047786168, 20.800118616649083, 24.956327778952463, 17.626049484525407, 11.191995876176016, 21.473489386694773, 34.81334802082607, 22.153156961713517, 35.63813393456595, 37.33128138950893, 42.483394963400706, 49.900794982910156, 46.18503039223807, 47.9037298474993, 21.735974958964757, 29.836454119001115, 26.87994350705828, 45.40684952054705, 46.44034889766148, 52.54695735658918, 44.88879878180367, 48.01515463420323, 39.204001562935964, 41.988898617880686, 40.323936530521934, 42.908739362444194, 46.50299385615757, 51.44415317262922, 52.61264910016741, 60.68348203386579, 54.4076258795602, 54.37656395775931, 63.07653890337263, 60.32028579711914, 89.13808536529541, 85.83111803872245, 49.29200077056885, 32.101320198604036, 45.14100449425833, 71.25884873526437, 43.54273121697562, 41.13523251669747, 36.54808391843523, 23.775476217269897, 28.938086782182964, 19.329575811113628, 46.85774108341762, 85.0363552910941, 78.60183007376534, 72.45666953495571, 87.95043672834123, 88.0433132989066, 91.0106040409633, 78.74501160212925, 69.97254957471574, 36.92947748729161, 7.422389694622584, 0.1106600845232606, 0.38279072674257414, 0.07196555978485517, 0.0023792452993802726, 0.17281954442816122, 0.02090220509230026, 0.06936103025717394, 0.05494446812995842, 0.041213799733668566, 0.044636537320911884, 0.017297082381056886, 0.009670471755920776, 0.0497615632068898, 0.02303768032496529, 0.03363721325461354, 0.06307183844702584, 0.029432060330041816, 0.04535018313410027, 0.04320183948480657, 0.06516946838902575, 0.0434749328664371, 0.033333579011793645, 0.009171404160692223, 0.09056161942758731, 0.10709749747599874, 0.02468479863767113, 0.06507552521569387, 0.0064676032634451985, 0.03202414552548102, 0.0666050042158791, 0.04993690683373383, 0.034789555706083775, 0.04543222819588014, 0.03261351086465376, 0.030579544470778534, 0.07018013737563576, 0.03267450777015515, 0.04227205312677792, 0.012424971941592438, 0.03486450329156859, 0.04368678167728441, 0.007682523607010288, 0.03018079318904451, 0.007594582075918359, 0.01919370480546994, 0.015468230337968894, 0.04356368524687631, 0.05001933187512415, 0.02421314555353352, 0.046495251690170596, 0.0743890425988606, 0.011845233317996775, 0.07337510093514409, 0.045131016323076825, 0.07455976879490273, 0.17826744781008788, 0.12549091263541154, 0.10145540415708508, 0.10267549154481717, 0.1555296579109771, 0.13867361311401638, 0.12197143291788441, 0.15730796248785087, 0.14911207370460033, 0.14882843249610492, 0.13260281458497047, 0.09481597292636122, 0.18087436578103475, 0.12822687439620495, 0.0961833634812917, 0.2138989501233612, 0.13796520898384707, 0.09560222537922007, 0.16999696088688715, 0.14608014853937284, 0.19612286612391472, 0.1374043726495334, 0.0824216351445232, 0.116065952660782, 0.07428353040346078, 0.1382343295429434, 0.05218382465786167, 0.1412372812628746, 0.12891621169235024, 0.17951215244829655, 0.20035822742751666, 0.11881332738058907, 0.11952519203935351, 0.1279676468776805, 0.12446407202099051, 0.14456533268094063, 0.10189460630395583, 0.12392954927470003, 0.21602646953293256, 0.15122052628014768, 0.06646602667335953, 0.15964243507811002, 0.09879230348659412, 0.16680578355278286, 0.10773518468652453, 0.2122364036206688, 0.13001623909388269, 0.14601221361330577, 0.10874346058283534, 0.1946053904082094, 0.1943629634167467, 0.1572568416595459, 8.537710189819336, 42.2995525768825, 82.551728112357, 94.45633384159633, 99.50782707759312, 87.23245852334159, 86.62565844399589, 81.93463775089809, 75.88502883911133, 61.546128681727815, 60.8218970979963, 41.87370095934187, 27.6422564302172, 26.917538472584315, 41.638111863817485, 43.37115587506975, 46.3359556879316, 62.439972741263254, 74.42405891418457, 76.44572762080601, 91.48640278407505, 84.74155017307827, 93.44826139722551, 103.37492343357631, 89.19467844281877, 65.73733070918492, 45.323589256831575, 50.73356090273176, 51.49995762961251, 111.20456354958671, 108.70427513122559, 128.99754524230957, 106.49057906014579, 114.78072493416923, 94.27902970995221, 98.08482905796596, 88.7938368661063, 80.97190925053188, 74.19478920527867, 79.87426062992641, 84.57161808013916, 99.46923678261894, 85.52560574667794, 87.76922770908901, 88.92116955348423, 84.19373335157121, 135.37654740469796, 122.11117172241211, 87.53560147966657, 60.37140369415283, 73.13662024906704, 125.33075850350517, 91.30900832584926, 74.62939902714321, 79.70336968558175, 47.54259375163487, 42.73763302394322, 41.45161179133824, 54.689246790749685, 72.13784449441093, 75.95856162479946, 60.92771816253662, 80.79629353114537, 86.97515283312116, 98.86541053227016, 92.69816167013985, 78.54456996917725, 36.374997343335835, 5.928133990083422, 0.2316501997411251, 0.5106091637696538, 0.2138441652059555, 0.1507591496088675, 0.20437885953911714, 0.09464497531631164, 0.12533346536968434, 0.1802500049982752, 0.10703360661864281, 0.1310390763516937, 0.12237018080694334, 0.16463008815688746, 0.17544373790068285, 0.19567393378487655, 0.13060891229127133, 0.14616438187658787, 0.0547165075050933, 0.11091682181826659, 0.1337986375604357, 0.19313566998711654, 0.21325451827475003, 0.08296883292496204, 0.09145291588668313, 0.3192936639700617, 0.15680231819195406, 0.0784238153802497, 0.08157932891377381, 0.059213118361575265, 0.10134305232869727, 0.1294444240629673, 0.09459808854652302, 0.08410522301814385, 0.18446734441178186, 0.080580695000078, 0.1561087875493935, 0.11232133502406733, 0.10420625976153783, 0.14278567103402956, 0.10836259209151779, 0.10116742032447032, 0.09885253704019956, 0.0881922362106187, 0.11076789016702346, 0.07430672951574836, 0.166672980678933, 0.13894231298140117, 0.14781346624451025, 0.11182354816368648, 0.09868452498423201, 0.1525398019169058, 0.097469716598945, 0.07507292447345597, 0.220988324710301, 0.18293503592056887], [0.06287864595651627, 0.021738993137010505, 0.02387746749445796, 0.03603625862992235, 0.10273635613598994, 0.03614104479285223, 0.024943155935034156, 0.043887804461909194, 0.032238382779593976, 0.015218746582312244, 0.02685427017110799, 0.032414530470435104, 0.012960709265566297, 0.052180486265569925, 0.01770125176491482, 0.018161988916939924, 0.03959377023524471, 0.009744567779957183, 0.07313091653798308, 0.032007962465286255, 0.0334223619263087, 0.010428246094046958, 0.014779580058529973, 0.020818550206188644, 0.10177767436419215, 0.015980147690113102, 0.05244213615411094, 0.032409275216715674, 0.06284963858446904, 0.019847474992275238, 0.049496975261718035, 0.11324583220162562, 0.04604198011968817, 0.06917169863092047, 0.05227472460163491, 0.03513028545837317, 0.040738285785274844, 0.054661824367940426, 0.03265086421743035, 0.031588369980454445, 0.013556032990371543, 0.03904604659016643, 0.04595589777454734, 0.022910231092412556, 0.037176848854869604, 0.010872157273947127, 0.05184678274339863, 0.04111549358016678, 0.05684377585670777, 0.11682268205497946, 0.1473896668425628, 1.84253220473017, 28.475559098379954, 64.15836647578648, 81.23815727233887, 77.924818447658, 73.17618329184396, 58.602559089660645, 62.78816086905343, 56.19664805276053, 46.820234707423616, 41.52218811852591, 30.253467627934047, 24.423823050090245, 37.00099529538836, 61.07941123417446, 81.25782067435128, 54.3505985396249, 71.40267644609723, 107.42089421408517, 61.15114443642752, 56.1752267565046, 76.4485833304269, 46.68384851728167, 45.433926650456016, 43.989163398742676, 28.301953145435878, 28.451328992843628, 28.08002594539097, 50.488598687308176, 36.443228653499055, 45.787756715502056, 37.83441434587751, 31.052572999681743, 28.439391987664358, 30.634406089782715, 25.39210316113063, 30.11495876312256, 31.2411436353411, 26.413229533604213, 24.33628269604274, 23.855156421661377, 21.295903853007726, 19.298081363950455, 20.406360728400095, 32.14678226198469, 33.32174696241106, 35.66375541687012, 34.02329267774309, 29.581621987479075, 33.06188780920846, 40.404931681496755, 49.20825413295201, 45.242159843444824, 49.43831941059658, 60.47762080601284, 55.07486139025007, 66.94583089011056, 71.67133549281529, 76.17463670458112, 91.2548749106271, 45.37081963675362, 25.605874913079397, 32.00459432601929, 30.316995007651194, 41.860235350472585, 48.226272174290244, 55.86319358008248, 63.83668572562081, 65.47400093078613, 64.9466187613351, 45.158611229487825, 22.463123049054825, 1.9230409818036216, 0.14604661533875124, 0.11055354095463242, 0.041818499964262755, 0.07702768208192927, 0.028541703641946827, 0.03750346847144621, 0.03864078815760357, 0.007600347079070551, 0.03376903225268636, 0.03465784527361393, 0.04304304193439228, 0.03148059147809233, 0.010895653245305377, 0.01451198450688805, 0.016312280403716222, 0.0526999489271215, 0.00956274159917874, 0.026395361670958142, 0.023382416826539805, 0.04911215091124177, 0.06399545352905989, 0.045958625485322306, 0.03093579231894442, 0.12016097935182707, 0.019395945560453192, 0.013625325834644693, 0.033816797725324116, 0.012504665031363922, 0.03956957706915481, 0.01507403711522264, 0.022500901449737803, 0.030549777139510428, 0.021939759774665748, 0.05558299672390733, 0.013807430214780782, 0.06493079369621617, 0.030730633863380978, 0.026334364765456746, 0.03511180216446519, 0.0363475942452039, 0.02783113159239292, 0.03681061636390431, 0.0282362560142896, 0.039897068603230376, 0.006962653507278966, 0.016084321475188647, 0.03549000740583454, 0.0032990069386349724, 0.04668348069701876, 0.01863424080823149, 0.09524041693657637, 0.07380294440580265, 0.02104716222467167, 0.012275292205491235, 0.02766876494778054, 0.06908712602619614, 0.05232830172670739, 0.011695241455786994, 0.05665282931710992, 0.032049851824662516, 0.04634594005931701, 0.011589739438412445, 0.027094332468030707, 0.051901404812399826, 0.014315390859597495, 0.006486739223224244, 0.023157865840143392, 0.04391669648300324, 0.02358720208784299, 0.04915703261005027, 0.04814658879435488, 0.035712251373167546, 0.014716886815481951, 0.006957303258656923, 0.021815452159249356, 0.020565309062866226, 0.044958590396812985, 0.06732475345156022, 0.0324353682808578, 0.0487640251272491, 0.06717080064117908, 0.08530426903494767, 0.02509673555115504, 0.0648950416860836, 0.03343753736200077, 0.09091082068958453, 0.007398792492624904, 0.029052766039967537, 0.003927869165116655, 0.04261659624587212, 0.010087958237688457, 0.06768950673618487, 0.04926528947960053, 0.01285898159923298, 0.07054359465837479, 0.013006389939359255, 0.12081140945000307, 0.05958551873586007, 0.0741343612649611, 0.04156825624938522, 0.05396869745371597, 0.09848541566835982, 0.07767195786748614, 5.55863573721477, 51.205294949667795, 83.20607471466064, 90.70671762738908, 87.40457235063825, 91.98581150599888, 75.54629026140485, 89.64699922289167, 92.06814071110317, 76.89806229727608, 62.24795927320208, 41.03417444229126, 23.453767674309866, 27.47893554823739, 36.02696555001395, 53.96403203691755, 40.233359813690186, 50.41368668419974, 80.3396440233503, 46.246803351810996, 46.752277851104736, 63.70371110098702, 47.76672874178205, 47.68702595574515, 43.64505386352539, 28.768420457839966, 28.132396255220684, 30.788148880004883, 47.955167361668174, 33.54793514524187, 47.307932240622385, 42.10869598388672, 33.33418771198818, 33.18681641987392, 31.917053971971782, 27.384367091315134, 31.0060304914202, 30.53093351636614, 27.249975034168788, 24.1735645702907, 21.322819437299454, 17.151160955429077, 12.020869067737035, 15.15217638015747, 24.93294014249529, 29.87922028132847, 28.367170674460276, 26.712240048817225, 28.53955200740269, 36.680839674813406, 41.281485148838584, 46.254606178828645, 46.62797457831246, 49.23535558155605, 55.43883582523891, 54.890463147844585, 61.59591252463204, 54.364540100097656, 55.10915422439575, 83.22507108960832, 35.70660843167986, 17.27068386759077, 29.69994980948312, 37.562805788857595, 65.34775911058698, 72.4110129220145, 78.11310768127441, 83.9698554447719, 80.4139689036778, 83.00435461316789, 66.35568564278739, 42.48533698490688, 8.19388553074428, 0.15087933173137053, 0.20855875739029475, 0.026762264215254357, 0.008970030234195292, 0.03485362637521965, 0.020289666085903133, 0.032994654162653854, 0.022480229880394678, 0.004486127490443843, 0.022902560254026736, 0.04480103456548282, 0.044806964961545806, 0.023257004895380566, 0.047950142728430886, 0.06933475059590169, 0.045287992006966045, 0.07198239423866783, 0.036633413551109176, 0.03957034720640097, 0.07742483541369438, 0.014049758818665785, 0.00905341879531209, 0.04122540607516255, 0.13219102525285312, 0.04335119861311146, 0.041748743171670606, 0.036441323680004904, 0.028104226670360992, 0.010261530888133814, 0.023820875977565135, 0.032069471664726734, 0.021709157952240536, 0.004328594983754945, 0.009105161331327898, 0.016829912717054998, 0.01881743678157883, 0.09467164174254451, 0.02486208117833095, 0.05098996604127543, 0.05883440761161702, 0.035785696003586054, 0.0257442496450884, 0.04979445519191878, 0.017695672510723983, 0.041510404353695254, 0.019651025533676147, 0.044016926283282895, 0.039580698258110454, 0.06249552472893681, 0.03011362161487341, 0.06168336580906596, 0.009315698025082903, 0.25419628992676735, 0.1335038412362337, 0.10141767082469803, 0.1465565479759659, 0.15291159839502402, 0.06467518955469131, 0.10299806030733244, 0.11828848054366452, 0.15035223215818405, 0.14944366019751343, 0.15102571887629374, 0.12379783205688, 0.09240237636757748, 0.10410644726029464, 0.13030646209205898, 0.22223935329488345, 0.14164749639374868, 0.11274972810809102, 0.10553928251777377, 0.11692143604159355, 0.1447515498314585, 0.10873974221093313, 0.1576175915875605, 0.10914568935653993, 0.13552160082118853, 0.12331027750458036, 0.09674918704799243, 0.1007461247167417, 0.11785909001316343, 0.09543053566345147, 0.07575856375374965, 0.15688976778515748, 0.07101302554032632, 0.19001607809747967, 0.15551713215453283, 0.10317616217902728, 0.14088418520987034, 0.18857552111148834, 0.0924466507775443, 0.1844384659613882, 0.17333418609840529, 0.1505526171198913, 0.1425075123884848, 0.16816167293914727, 0.18997718447021075, 0.1700453675751175, 0.19330218248069286, 0.1345766322421176, 0.11666252064917769, 0.31950637112770763, 0.2506762130984238, 3.240970079387937, 48.2016408102853, 92.04407909938267, 101.51513385772705, 94.25826154436383, 91.65944766998291, 73.44732284545898, 82.55254799979073, 73.90359715053013, 64.88104166303361, 52.52656439372471, 39.08106361116682, 31.8683123588562, 52.29703412737165, 84.58876623426164, 110.35521575382778, 76.35533850533622, 90.00638089861188, 136.02002007620675, 86.8620639528547, 81.36843599591936, 105.55702604566301, 69.15462848118374, 68.39300864083427, 70.3712580544608, 47.012508732931956, 49.42398875100272, 46.58050101143973, 81.1940084184919, 58.36929416656494, 72.01083142416817, 62.30747059413365, 51.65350239617484, 47.989915302821565, 49.90539469037737, 44.302610533578054, 52.1949268749782, 51.013337067195344, 44.64061607633318, 45.84255715778896, 42.306695325034006, 37.53465863636562, 32.284839493887766, 31.801258768354142, 50.0195049558367, 52.518653869628906, 52.273649965013774, 51.2446425982884, 45.05668115615845, 54.511157512664795, 65.59049442836216, 74.4606272833688, 66.79579843793596, 75.40685381208147, 85.64120987483433, 74.14708982195172, 87.01937116895402, 93.9533884865897, 99.137911932809, 108.90886483873639, 61.048227718898225, 34.69681283405849, 45.3108914239066, 43.98897927148001, 55.80104889188494, 66.1436266217913, 71.82595375605992, 83.1224809374128, 84.27806363786969, 91.7117259161813, 71.75606182643345, 39.42897033691406, 4.720214418002537, 0.22077744959720544, 0.26318402907678057, 0.16026739297168596, 0.12651354633271694, 0.20559251441487245, 0.09941732244832174, 0.09966609374220882, 0.14637455131326402, 0.12021873625261442, 0.08603486804557697, 0.10765904627208199, 0.09932327070938689, 0.11735002590077263, 0.1262207313307694, 0.14540021573858602, 0.12131370178290776, 0.14074542479855673, 0.1440413272274392, 0.09378915945334093, 0.1865250968507358, 0.09663477247314793, 0.09934404066630773, 0.0860614598329578, 0.2277899868786335, 0.1182576207710164, 0.07935969837542091, 0.15496078772204264, 0.06825326755642891, 0.09728997945785522, 0.06711573752441577, 0.20145587995648384, 0.1325503909694297, 0.1814752628228494, 0.16074160752551897, 0.10662145087761538, 0.0982708086126617, 0.19530766058181012, 0.09063169852431331, 0.18878071010112762, 0.11351444385945797, 0.15752092748880386, 0.14704802446067333, 0.15703992758478436, 0.18536268493958882, 0.10997749186520066, 0.08941445419830935, 0.10853399682257857, 0.08957807613270623, 0.18231390496449812, 0.12935538669782026, 0.13462018061961445, 0.16848472346152576], [0.03378517460078001, 0.030132006521203687, 0.06989660473274333, 0.07449599328849997, 0.02140232441680772, 0.037231755908578634, 0.014328513726858156, 0.06307691388896533, 0.08220026309468917, 0.04560306295752525, 0.05630319718537586, 0.0117828055517748, 0.07139983121305704, 0.049368304666131735, 0.06636295041867665, 0.045065673400780985, 0.04906307925869312, 0.05440577578597835, 0.021515434508078864, 0.009914751996153166, 0.013642013555259576, 0.043020629922726324, 0.03728987243292587, 0.03744264119969947, 0.04746574675664306, 0.04614984683160271, 0.014869840483048131, 0.03297668994803514, 0.10102082283369132, 0.005950285620721323, 0.0796544472021716, 0.013090228029925908, 0.014677245103354965, 0.10739764744149786, 0.08057408606899635, 0.03798352521178978, 0.02886205698762621, 0.021367088093289306, 0.04091158362903765, 0.0419146178423294, 0.06420539226382971, 0.06564325546579701, 0.04601031628304294, 0.03771391271480492, 0.09678855564977441, 0.04636643520955529, 0.08908484224230051, 0.0493647559279842, 0.058429491839238575, 2.095128970486777, 13.222366333007812, 44.1419403893607, 73.1787610735212, 71.76690101623535, 66.77460643223354, 65.87880992889404, 57.718192373003276, 67.22475242614746, 29.258443900517054, 37.29736375808716, 21.03546452522278, 30.846169812338694, 44.68435846056257, 68.56844370705741, 33.15060935701643, 96.25836999075753, 100.30505643572126, 42.14543458393642, 52.25778375353132, 28.4227580002376, 37.18564714704241, 43.17802722113473, 34.866390568869456, 22.306884118488856, 27.932771035603114, 8.345751438822065, 3.1063496002129147, 1.3431545325687952, 3.869075724056789, 0.6642285149012293, 0.615655178470271, 1.4304133760077613, 3.6360785237380435, 1.9966538889067513, 2.739330985716411, 0.28039691544004847, 0.3794705191893237, 0.214491338336042, 0.18428160223577703, 0.143088962616665, 0.8808048420718738, 0.9078519535916192, 0.5639585182070732, 0.20927615889481135, 0.2915512983288084, 0.9111097902059555, 3.0165261115346635, 7.523042167936053, 7.086848591055189, 6.1352346028600415, 6.565619051456451, 6.131367496081761, 12.288861087390355, 21.9219035421099, 18.53177148955209, 17.43001995767866, 20.670432226998464, 26.921493734632218, 40.05633013589041, 51.24888447352818, 54.53109884262085, 80.19120270865304, 85.89390196119035, 44.88464028494698, 41.25647163391113, 28.329032012394496, 25.945664405822754, 33.74790777478899, 47.10123028073992, 43.1609068598066, 51.64416054316929, 70.06875433240617, 70.95929104941231, 53.542331968035015, 15.743433339255196, 1.4551269241741724, 0.05458818296236651, 0.13642148753362043, 0.06135783863386937, 0.08146648854017258, 0.03497742169669696, 0.010455796312141632, 0.03168332077828901, 0.023465109889262488, 0.01564433053135872, 0.03849600914067455, 0.020518549518393617, 0.026773068189088787, 0.01718975171180708, 0.05650590952219708, 0.05076631411377873, 0.0361473857026015, 0.03332060542223709, 0.044518248311110904, 0.018875007085236054, 0.046283307884420664, 0.05843337305954524, 0.019722337867798548, 0.0506499555361058, 0.019231974180521708, 0.07342723278062684, 0.046133538242429495, 0.011795205779240599, 0.05400927724050624, 0.12649794002728804, 0.047084410076162646, 0.029440060257911682, 0.010280128684826195, 0.0445779424293765, 0.011530364231605614, 0.052436124333845716, 0.029686093662998507, 0.022191346988880208, 0.04611326361607228, 0.03692193003371358, 0.042350003229720254, 0.042272551850016625, 0.03408277666728411, 0.015116138516792228, 0.0682244501741869, 0.043920971253620725, 0.02351870058503534, 0.02406265496808503, 0.04582552066338914, 0.028266138696510876, 0.04578098162476506, 0.041673086517091305, 0.005049459137288588, 0.014881060059581484, 0.08081736122923237, 0.01218665432783642, 0.06664698517748288, 0.019476755688499128, 0.08722739334085158, 0.03724419345547046, 0.03350933315232396, 0.030246577159102474, 0.07168818823993206, 0.02224449663689094, 0.02836599699886782, 0.07877978163638286, 0.0343912827915379, 0.025360066510204757, 0.03990206940631781, 0.04098444811201521, 0.006724818077470575, 0.019800053876159445, 0.03465851702328239, 0.020502042457727448, 0.03443703301517027, 0.006258849420451692, 0.020159300849107758, 0.02584054563859744, 0.03476017853245139, 0.06495677480208022, 0.04132147306310279, 0.09678105783781835, 0.0429382591641375, 0.04729521394308124, 0.09364014637789556, 0.02370210860057601, 0.012701083955887173, 0.03416388195806316, 0.059799895089651854, 0.03630057516108666, 0.029777020748172487, 0.028255465340667536, 0.07545226626098156, 0.0398297816781061, 0.025811405952221582, 0.054358872052814276, 0.051498687493481805, 0.06536054385027715, 0.04789519835529583, 0.037524472522948465, 6.232542387076786, 28.361910888126918, 66.24463258470807, 83.0918185370309, 82.65567316327775, 81.96125629970005, 93.27451474325997, 84.1364801951817, 93.41861343383789, 39.05827004568917, 43.93785095214844, 20.93909822191511, 21.623707703181676, 21.110835109438213, 42.17766727719988, 25.910178218569072, 86.10502297537667, 92.96409007481166, 44.05149916240147, 52.6417863709586, 32.141425200871055, 38.4543708392552, 44.836124488285606, 37.09521286828177, 17.781129802976334, 20.670399223055156, 6.703693653856005, 2.2941392745290483, 0.6708072647452354, 1.5444504682506834, 0.41882726017917904, 0.24146026905093873, 0.12199974139886242, 1.3217535380806242, 1.0939035415649414, 1.528995394706726, 0.15938144336853707, 0.2481179732297148, 0.19930674242121832, 0.10898634897811071, 0.21300492595349038, 0.5045546229396547, 0.632451634321894, 0.44248340651392937, 0.3531666749290058, 0.4092984300638948, 0.6557295109544481, 0.37504861503839493, 2.0284629591873715, 2.555094506059374, 1.9548294246196747, 3.8329737527029852, 3.87246036529541, 11.541340010506765, 21.13985252380371, 17.14286654336112, 17.80693367549351, 21.627841881343297, 29.148540769304546, 44.59169033595494, 50.026359353746685, 63.4587037222726, 77.07557487487793, 66.01289626530239, 41.34853873934065, 19.07631049837385, 14.383271353585378, 28.207488911492483, 49.1062719481332, 71.9163567679269, 67.9176059450422, 69.56662191663469, 84.10870824541364, 83.07703277042934, 71.21775708879743, 33.92350959777832, 8.12832406588963, 0.19652819580265454, 0.35096111042158945, 0.04402277525514364, 0.017367351467588117, 0.02395668306521007, 0.04569580851654921, 0.04605526244267821, 0.020221985610468046, 0.09756090492010117, 0.016483461218220846, 0.04190626507624984, 0.015085146429815462, 0.014783915897299136, 0.04906126078484314, 0.035193317968930514, 0.012565533863380551, 0.012260974268428981, 0.05303448365469064, 0.028735723945179155, 0.07999108199562345, 0.11859938528920923, 0.088164375562753, 0.021979937529457465, 0.04424098872446588, 0.02804007288068533, 0.04091623837926558, 0.020060139741482477, 0.03834052284115127, 0.08845216262021235, 0.039042145013809204, 0.03437949324558888, 0.029480646830052137, 0.02236725719246481, 0.02403712848068348, 0.02841292108808245, 0.054920549770551066, 0.08301467475082193, 0.039212725324822326, 0.03537414076605013, 0.022856709946479117, 0.07219571207783052, 0.050690464076719115, 0.04869686373110328, 0.02570337469556502, 0.021817686235798255, 0.043049274278538566, 0.050449692710701904, 0.03371678166357534, 0.06845460246716227, 0.0646723329222628, 0.14241743007940905, 0.09362724742719106, 0.1446958285357271, 0.13908931080784115, 0.08924589252897672, 0.1485442891716957, 0.09725092976753201, 0.20000739768147469, 0.18890880394194806, 0.13216476594763144, 0.133835943415761, 0.11025809323681252, 0.2120617622775691, 0.14948624505528382, 0.14393350801297597, 0.13013669263039315, 0.14104263670742512, 0.14199637195893697, 0.07254979200661182, 0.10216742487890379, 0.10351581645331212, 0.09266503727329628, 0.10720296895929746, 0.15491373810384954, 0.12869495499346936, 0.15559158101677895, 0.08877710625529289, 0.10418038043592658, 0.25838399093065945, 0.06944206769445113, 0.13593269804758684, 0.12040854963873114, 0.09561188771788563, 0.17033135651477746, 0.15242719224521092, 0.16425557753869466, 0.13909195709441388, 0.091811528429389, 0.12887795588799886, 0.14289344953639166, 0.07946284248360566, 0.16431083743061337, 0.10484442194657666, 0.12977986463478633, 0.2578749811010701, 0.2139813242746251, 0.14828792507094996, 0.11508856367852006, 0.1900816381509815, 3.615703799894878, 24.668450014931814, 70.14543465205601, 96.29793303353446, 88.42761816297258, 84.22698048182896, 86.63562910897392, 73.9558059147426, 83.79664380209786, 38.82899686268398, 47.353526319776265, 27.789903913225444, 44.14652272633144, 64.17070647648403, 92.17207186562675, 47.891309942517964, 123.1895877293178, 132.2104617527553, 62.59385449545724, 77.51370743342808, 48.3802546773638, 57.09266342435564, 66.15543855939592, 53.30342858178275, 36.42201580320086, 44.550049781799316, 15.346774578094482, 6.361324642385755, 4.74329503093447, 7.973156026431492, 1.6702043946300233, 2.488729004349027, 3.0978193836552754, 7.860362444605146, 4.641609447343009, 6.204518565109797, 1.03965320118836, 1.5953485199383326, 0.8072513746363776, 1.0378925928047724, 0.6107940450310707, 2.2864052781036923, 3.4492232246058325, 2.321145619664873, 1.2521521300077438, 1.3969405378614153, 2.6896772044045583, 5.23415790285383, 13.310373084885732, 12.76063769204276, 11.147047110966273, 12.423048172678266, 11.197162730353218, 23.0645660672869, 38.20762641089303, 33.464577606746126, 36.430270263126914, 42.00202029091971, 50.51875039509365, 65.64565617697579, 74.56765038626534, 64.9873491014753, 97.27965790884835, 119.07276616777692, 68.46713202340263, 59.285615648542134, 38.143859318324495, 37.42961229596819, 48.441888672964915, 65.91069521222795, 60.229049001421245, 69.28321879250663, 87.98567799159459, 92.03279522487095, 78.40248625619071, 29.25009216581072, 5.567026121275766, 0.1148557040308203, 0.3983856327831745, 0.1495835062648569, 0.26182674190827776, 0.2203537044780595, 0.10417638386466674, 0.14475268977028982, 0.09611958797488894, 0.1788982953876257, 0.07941033744386264, 0.11905560509434768, 0.092061134321349, 0.13126064517668315, 0.18660957446055754, 0.0779787167640669, 0.1026292968807476, 0.1792179803763117, 0.17566921508737973, 0.09402191053543772, 0.12478911743632384, 0.1383218334189483, 0.17229400548551763, 0.11562008730002812, 0.1691443273531539, 0.17797001877001353, 0.13687407039105892, 0.1161661044295345, 0.11563515077744212, 0.1621130353638104, 0.12328609451651573, 0.1019847361104829, 0.08803832411233868, 0.13249840161630086, 0.10174020566046238, 0.17287860411618436, 0.10834775253065995, 0.08799138984509877, 0.18698101810046605, 0.11912922614387103, 0.09861177245953254, 0.19441090870116437, 0.16253124363720417, 0.10872395948639937, 0.11847453484577791, 0.11050988401153258, 0.12148252129554749, 0.08995365205087832, 0.13078937546483108, 0.10757985445005552, 0.20149167946406774], [0.021204784213166152, 0.00416194211824664, 0.04464100208133459, 0.03844035569844501, 0.040751700422593524, 0.010234480241446622, 0.021111258338870745, 0.00501169272631939, 0.048694604209491184, 0.03427603022594537, 0.01586331074525203, 0.014312736091337033, 0.0338109317900879, 0.025413368828594685, 0.01753937196917832, 0.05032016037564192, 0.0275810303698693, 0.02620995876246265, 0.08416164999029466, 0.03432176687887736, 0.020268234557339122, 0.017374153781150068, 0.04424659003104482, 0.013130643271974154, 0.03878287339050855, 0.01583082927390933, 0.038474350302879295, 0.03302635531872511, 0.06809356755443982, 0.005016690136731735, 0.11866323543446404, 0.0657377957499453, 0.030079063826373646, 0.06731568143836089, 0.041261297184973955, 0.020909216055380445, 0.05289334837081177, 0.032176537705319266, 0.06243208170469318, 0.04618391268221395, 0.08889602630266122, 0.036210526778761826, 0.04006716376170516, 0.026654753734224608, 0.24069005038057054, 0.028634690080902407, 0.18022351499114717, 0.7416717793260301, 15.675858633858816, 53.50430795124599, 67.49755954742432, 77.0977396283831, 68.32767472948346, 67.52861104692731, 67.1307988848005, 53.960432870047434, 47.01045901434762, 25.84462891306196, 37.74502577100481, 45.09971135003226, 50.67670726776123, 60.63809640066964, 64.08768245152065, 47.736330372946604, 46.975196906498496, 26.190496342522756, 19.379517725535802, 19.76193962778364, 15.775259562901088, 13.869438171386719, 4.309651008674076, 2.3100250278200423, 1.1935794672795703, 2.964602223464421, 1.169120179755347, 0.4218949984226908, 0.014440789220056363, 0.10083052768771138, 0.18665608125073568, 0.013137666109417166, 0.059088654683104584, 0.10923383105546236, 0.1372269086007561, 0.11560188899082796, 0.21353072273944104, 0.17960612954837935, 0.03162249689921737, 0.16996753960847855, 0.12872197425791196, 0.15609801241329738, 0.03220065623255713, 0.05826570027108703, 0.013958036151182438, 0.02489926659369043, 0.024460393536303724, 0.012452375426489328, 0.054197404467101605, 0.09835934386189495, 0.3462630696594715, 0.2730995698698929, 0.23682516919715063, 0.34450973517128397, 0.15334187102104935, 1.2779584995337894, 1.238443442753383, 2.4840936873640334, 3.455341330596379, 7.1916704177856445, 8.757518189293997, 14.93178299495152, 20.9489802973611, 31.66131510053362, 31.82728672027588, 36.14102370398385, 56.73088462012154, 70.90031473977226, 45.48853601728167, 28.33954116276332, 23.763210909707205, 29.77055045536586, 49.237783976963584, 37.326174463544575, 53.15841620309012, 61.00293241228376, 69.10272543770927, 53.4876982825143, 22.419665540967667, 0.6942679658532143, 0.17061716903533253, 0.004642805043009243, 0.05243315913581422, 0.02246120715114687, 0.021163330812539374, 0.02669374574907124, 0.08367113702531372, 0.033112366417688985, 0.07087860096778188, 0.01993677528974201, 0.028972430886434655, 0.028665929833160977, 0.010927950664024268, 0.030043243962739195, 0.032090818376413414, 0.02099407364481262, 0.024381905694359114, 0.0085002134354519, 0.03797172888049057, 0.07424102696989264, 0.09067700430750847, 0.012235894765970963, 0.02440175793266722, 0.05054462315248592, 0.02193811093457043, 0.010167616552540233, 0.035922563302197626, 0.03359961223655513, 0.014967975306457706, 0.018983197797622, 0.03784221690148115, 0.046853589426193915, 0.040851974327649386, 0.013366008410230279, 0.04539246604378734, 0.03607062982129199, 0.07090770333473172, 0.013604403207344668, 0.06406129178191934, 0.026756520416321497, 0.03497183735349348, 0.0276004093300019, 0.0545949140297515, 0.03497886697628668, 0.021485163364559412, 0.025318323035857508, 0.06130745740873473, 0.05985183694532939, 0.05283069923253996, 0.0626777656642454, 0.04068578074553183, 0.03714999922418168, 0.060737976538283486, 0.07341872395149299, 0.02461390699526029, 0.050462025084665844, 0.01540686871989497, 0.04676560039765068, 0.048443420723612816, 0.05341706544693027, 0.0730216588292803, 0.017726615403911898, 0.022577250210036124, 0.05514366226270795, 0.10684852262160607, 0.0038394183086763534, 0.05308210663497448, 0.031068768219224045, 0.015692406433767507, 0.012271884263360074, 0.027601666316123943, 0.01002322938958449, 0.02096897124179772, 0.020384839103956307, 0.019523153913074305, 0.12738610165459768, 0.01608300511725247, 0.03733582960973893, 0.08254195975938014, 0.03215330805895584, 0.016209015855565667, 0.029896761822913374, 0.06658943183720112, 0.022434472871412123, 0.031869677028485706, 0.11153837346604892, 0.0765306551807693, 0.05281348140644176, 0.005586084069883717, 0.02480493326272283, 0.10436349668140922, 0.0634075707889029, 0.16404331821416104, 0.028176736618791307, 0.11380563037736074, 3.9801891446113586, 33.36619111469814, 71.77634361812046, 81.52248450687954, 88.08232743399483, 87.89994416918073, 92.29270648956299, 90.06405094691685, 74.82090527670724, 66.87173530033657, 34.747305393218994, 29.408472878592356, 21.184029170445033, 27.746769496372767, 41.76611157826015, 51.155198437826975, 46.25954287392752, 43.47123077937535, 24.947776283536637, 18.75828102656773, 16.53493217059544, 14.098644477980477, 10.552551422800336, 3.030291578599385, 1.4769996362073081, 0.39314983944807735, 1.2538965621164866, 0.5960861199668476, 0.3402608574501106, 0.012089900323189795, 0.19448431261948176, 0.14901281760207244, 0.31737910956144333, 0.11488895224673407, 0.1404023982052292, 0.21901069368634904, 0.18589259364775249, 0.10582645210836615, 0.24463776711906704, 0.26813011510031565, 0.27789005424295155, 0.1331180262246302, 0.25614800091300693, 0.07171311083116702, 0.02730311599693128, 0.018657855523218, 0.025203699811494777, 0.03501764185992735, 0.014025970229080744, 0.03410019805388791, 0.06784730684012175, 0.1742472771023001, 0.09101017178701502, 0.10760379995086364, 0.12851398970399583, 0.03151332400739193, 0.8152752955045018, 0.8241092243364879, 1.7194878586700983, 1.766309380531311, 5.3671581489699225, 5.591365660939898, 12.611571039472308, 20.52643949644906, 30.812085424150737, 36.04077162061419, 48.41441896983555, 66.38354791913713, 63.30772631508963, 32.421020712171284, 19.909177167075022, 29.565738405500138, 45.96642616816929, 67.6552906036377, 61.38251250130789, 74.84715557098389, 74.5943523134504, 81.16807079315186, 77.01075513022286, 39.856145586286274, 4.1881053021975925, 0.07156795861997775, 0.027509914810902307, 0.05589819320344499, 0.02921830822846719, 0.054625973970230134, 0.04953293422503131, 0.1460008413663932, 0.02019262031119849, 0.08552539002682481, 0.036030674286718876, 0.059742599592677186, 0.011382859200239182, 0.0031871279643382877, 0.038974254192518334, 0.04133169858583382, 0.03331327724403568, 0.06202808195458991, 0.045445154287985394, 0.044934119031365426, 0.037172475696674416, 0.06148145414356675, 0.04163689685187169, 0.009903506126387842, 0.027655492802815776, 0.014625045404370342, 0.009059348343206304, 0.08987388347408601, 0.008684660457739872, 0.051934802306017706, 0.028469286992081573, 0.026486412588773028, 0.010892286015275334, 0.024755306907796433, 0.04260387032159737, 0.04171353398955294, 0.0384822789845722, 0.07074819332254784, 0.011148656901371266, 0.00797885172401688, 0.021945595175826123, 0.045996151864528656, 0.03217601523335491, 0.03132242835792048, 0.05473830204989229, 0.022267317465905632, 0.00864471510119204, 0.03246084387813296, 0.030359726266137192, 0.17505512732480252, 0.09705000197780983, 0.14515952579677105, 0.07753298711031675, 0.13258828036487103, 0.19940721988677979, 0.1274614461830684, 0.07168173537190471, 0.1946282706090382, 0.10009099915623665, 0.1663901401417596, 0.1509214144732271, 0.1925855680767979, 0.11985133668141705, 0.16679595836571284, 0.15325295579220566, 0.23184268655521528, 0.11086070697222437, 0.15285679990691797, 0.13129059571240628, 0.15498638206294604, 0.20135696312146528, 0.09563550752188478, 0.12151154902364526, 0.11534138582646847, 0.0811890559270978, 0.1257400842649596, 0.1627112046948501, 0.1402806147400822, 0.11046449680413518, 0.27520848384925295, 0.1255440826394728, 0.16018645731466158, 0.14192724281123706, 0.07960018475673028, 0.135115117632917, 0.1256099005362817, 0.14170982662056172, 0.14252997189760208, 0.18218032856072697, 0.12148419049169336, 0.2391528428665229, 0.24095163920095988, 0.16945079447967665, 0.3746316416987351, 0.12296222975211483, 0.3461624564869063, 2.1126896739006042, 29.851740155901226, 74.84762110028947, 93.02315671103341, 96.75689629146031, 87.31512124197823, 86.47647367204938, 84.88343238830566, 66.72227260044643, 57.82425662449428, 33.74293286459786, 54.12942348207746, 66.56097017015729, 70.57433305467877, 82.85597583225795, 89.76850931985038, 69.82631083897182, 69.60337093898228, 44.67774377550398, 34.14132867540632, 36.06800161089216, 26.97608051981245, 22.653864996773855, 10.006132057734899, 5.364998127732958, 3.521109721490315, 6.205907336303166, 3.775361027036394, 0.94095165176051, 0.11393461988440581, 0.30418431758880615, 0.3697106886122908, 0.5855715956006731, 0.2371189748602254, 0.4345987210316317, 0.5063974154847009, 0.5343904048204422, 0.44148074888757294, 0.2803907272006784, 0.35958257636853624, 0.4157427485500063, 0.3059349650783198, 0.3772041308028357, 0.2635015563241073, 0.13717566563614778, 0.12099926865526608, 0.07498069120837109, 0.17995457085115568, 0.08076613862067461, 0.19643462582358293, 0.24439962846892221, 0.6422023453882763, 0.543433431003775, 0.5631536671093532, 0.5650377688663346, 0.5239427025829042, 2.3407629898616245, 2.6317626663616727, 4.8817148719515115, 6.645708331039973, 13.678358367511205, 17.69917927469526, 28.30968475341797, 39.09322990689959, 47.96133736201695, 48.18148408617292, 50.52990572793143, 85.00633212498256, 101.9425800868443, 61.70745890481131, 38.782711437770296, 32.06315721784319, 42.03681339536394, 65.35677787235805, 53.837748527526855, 68.5874331338065, 79.3618448802403, 90.58037853240967, 81.44170475006104, 38.420418466840474, 2.3629488050937653, 0.37873382014887674, 0.12538702892405645, 0.11695191583463124, 0.08153329709810869, 0.14747076534799167, 0.16613290751618998, 0.20363974491400377, 0.3373853617480823, 0.24615250155329704, 0.15096284582146577, 0.09312754709805761, 0.09687762694167239, 0.09284694572644574, 0.07691007160714694, 0.10465807587440525, 0.07832196727395058, 0.17409238112824305, 0.13223675851311, 0.20487307730529988, 0.10847367505942072, 0.16042291319796018, 0.09401712007820606, 0.06768453985984836, 0.17460240876036032, 0.1151551143931491, 0.14839575785611356, 0.17015329535518373, 0.12733906560710498, 0.19838895595499448, 0.12408968353910105, 0.10627778646137033, 0.12242932191916875, 0.11817614228597709, 0.17393603308924607, 0.14775302234504903, 0.09916132475648608, 0.1727579470191683, 0.08656904473900795, 0.20075424760580063, 0.09314337732004267, 0.06535094257976327, 0.15524212191147463, 0.10162938732121672, 0.11246263994170086, 0.11640015829886709, 0.06132000352122954, 0.14921753161719867, 0.19599603435822896], [0.030765042374176637, 0.018397440568410924, 0.017113855873633708, 0.025600870106635348, 0.06288428458252124, 0.03231791386912976, 0.04385392860110317, 0.007586848473043314, 0.03425195919615882, 0.03744370310700365, 0.04313623532652855, 0.013708760196875249, 0.009786581820143121, 0.04696350870653987, 0.016877471236512065, 0.04013742267021111, 0.026909792995346443, 0.040056548081338406, 0.030873044793094908, 0.010510219061481101, 0.012951823001328324, 0.039332846379173655, 0.007440327317453921, 0.045493754358696084, 0.03122000688953059, 0.029577925003000667, 0.08548393153718539, 0.05215795211760061, 0.035633982358766456, 0.06825516066913094, 0.033850958570837975, 0.027189569946910654, 0.01722929334001882, 0.04816016288740294, 0.05762318867657866, 0.09116740192153625, 0.02477245348771768, 0.04847886739298701, 0.012298161380126007, 0.19552051701716014, 0.01998462388291955, 0.050107588924999745, 0.07211084770304815, 0.08422459768397467, 0.310751559478896, 0.36562381791216986, 11.544623902865819, 45.01437357493809, 72.330386025565, 69.09333147321428, 66.98616518293107, 55.07465641839163, 60.117349760872976, 50.2846690586635, 40.18455914088658, 39.19235290799822, 33.00245291846139, 36.39326068333217, 37.63544225692749, 56.805525643484934, 49.03298929759434, 39.632232938494, 34.59846108300345, 25.642559664590017, 14.685226167951312, 9.547233939170837, 4.987185920987811, 1.5560444061245238, 1.6908981927803584, 0.27870606045637814, 0.4251987582870892, 0.04412408731877804, 0.07461060463849988, 0.18949281903249876, 0.12583083153835364, 0.042729748745581934, 0.06711638891803366, 0.04536222034533109, 0.06545573552804333, 0.0758634109848312, 0.08404926423515592, 0.19281726064426558, 0.05851761318211045, 0.05443360250709312, 0.19866210701210157, 0.07483738461243254, 0.22580012865364552, 0.1037473122456244, 0.10645886710179703, 0.09148182826382772, 0.10588946765554802, 0.11353541737688438, 0.16483537214142935, 0.04704629676416516, 0.01715546703365232, 0.06527891608753375, 0.22597588279417583, 0.17616614699363708, 0.2920883452253682, 0.22412524638431414, 0.3564155005982944, 0.22919585715447152, 0.22934068366885185, 0.04377741699240037, 0.017665861074679663, 0.12800272713814462, 0.18821734961654457, 0.1383873934724501, 0.8562668987682888, 2.082496711186, 12.744140063013349, 29.817586285727366, 33.722553798130576, 13.811045510428292, 10.18209171295166, 21.164674963269913, 46.96512201854161, 46.02513149806431, 40.34956496102469, 27.62161680630275, 25.637084484100342, 36.05743340083531, 44.103836468287874, 55.66681316920689, 46.245069776262554, 66.16285923549107, 62.388743673052105, 42.653507709503174, 7.8952033179146905, 0.11588660228465285, 0.08753951266407967, 0.07835144962051085, 0.059723926308963976, 0.03699565286348973, 0.04236000144322004, 0.019243407495585934, 0.037408059662474055, 0.04150272333728416, 0.03345761860587767, 0.018870233591379862, 0.013567936190936183, 0.038979309278407266, 0.08233966132892029, 0.0335504286257284, 0.013448163733950682, 0.058696597149329524, 0.02753902565953987, 0.0807184036821127, 0.07619280580963407, 0.07157537500773158, 0.059609715294625075, 0.018102813877963593, 0.05875458475202322, 0.02950627849038158, 0.07152300567499228, 0.016653096669220498, 0.0168114362084972, 0.04305104525493724, 0.00753020861053041, 0.054914690620665035, 0.051967236279909096, 0.018998376625989164, 0.05639276720051255, 0.07535421116543667, 0.029598589786993604, 0.03557566227391362, 0.022681578361828412, 0.05465141564075436, 0.019679067689659338, 0.029674154839345386, 0.00457311822434089, 0.051009239828480143, 0.021009922526510696, 0.0386854561178812, 0.02922517161018082, 0.05158259852656296, 0.029696600777762275, 0.030433323566934893, 0.03192159852811268, 0.04890011889593942, 0.008605387211511177, 0.0070486870827153325, 0.025363165718902434, 0.07195761413978678, 0.06277074531785079, 0.13045776183051722, 0.026177222840487957, 0.07807789144239255, 0.041892226186714, 0.05983441895140069, 0.04585710646850722, 0.03234866168349981, 0.05151351348363927, 0.033090235998055766, 0.07570868464452879, 0.1000834945589304, 0.06887770976339068, 0.017936026577704718, 0.02378948185858982, 0.027536667750350068, 0.044433509465307, 0.03416084212117961, 0.011477553002935435, 0.0473247539651181, 0.02744674150432859, 0.05885109957307577, 0.01629722031897732, 0.030930615096752132, 0.02924298315442034, 0.050018035873238526, 0.028111303790605495, 0.029885179230145047, 0.05055814974808267, 0.027826339438823715, 0.023384099593386054, 0.028445499250665307, 0.029616703279316425, 0.022404406984735812, 0.07111222736005272, 0.056071887990193706, 0.060327584988304546, 2.4696106016635895, 26.853853021349224, 67.28630651746477, 85.08335290636334, 77.47870935712541, 80.71296378544399, 74.19321196419853, 86.42564065115792, 73.47776985168457, 54.598677022116526, 36.0119435446603, 16.514177901404246, 23.000307389668055, 35.2232882635934, 58.10984148297991, 53.74359348842076, 45.57640988486153, 36.37222501209804, 24.285121372767858, 10.27877937044416, 5.797713262694223, 2.175632970673697, 0.4345459038657801, 0.6199619216578347, 0.13000938589019434, 0.31983195937105585, 0.11334420620862927, 0.034673716207700114, 0.0561011599908982, 0.09665955935737916, 0.007471693446859717, 0.12692112874771866, 0.10572258875306163, 0.1620831255401884, 0.006154184121572013, 0.08874921846602644, 0.135188507980534, 0.10494286380708218, 0.18616821457232746, 0.47847352815525873, 0.14866208285093307, 0.18236444225268705, 0.14411450044385024, 0.2070304522556918, 0.055653394732092104, 0.1038911955963288, 0.14757071355623858, 0.05502732404108558, 0.08788894462798323, 0.052196350414305925, 0.09269157477787562, 0.049788026072617085, 0.12849439361265727, 0.15300178926970276, 0.2540057844349316, 0.1793216062443597, 0.25181520198072704, 0.36504934302398134, 0.044354368533406935, 0.0237455382344446, 0.07451573187219244, 0.09264395519026689, 0.1536658036389521, 0.7094306179455349, 1.030848313655172, 7.099416145256587, 21.509774616786412, 21.48022219112941, 11.05754997049059, 13.993385349001203, 33.64464712142944, 62.92551980699812, 47.049664224897114, 26.376167842320033, 15.910904032843453, 25.421462774276733, 53.423444816044395, 67.84355204445976, 82.40663582938058, 65.5214432307652, 79.19679042271206, 75.23227337428501, 63.053998947143555, 19.81255725451878, 0.6542001473052161, 0.15040152094193868, 0.03631539436589394, 0.02059733761208398, 0.028828184519495283, 0.07230454230947153, 0.04210269757147346, 0.07695088548851864, 0.04592589974137289, 0.059735305341226716, 0.06704320213092224, 0.05660896881350449, 0.0032691354946499424, 0.0365355077332684, 0.051166252831795385, 0.04548003438061901, 0.06979413915957723, 0.035815032465117316, 0.035037410977695665, 0.06314721690224749, 0.04873695497268012, 0.07500817187662635, 0.02271833799646369, 0.04399774070563061, 0.08999690865831715, 0.06341983870204006, 0.054961010813713074, 0.021560375578701496, 0.026918099960312247, 0.07527833059430122, 0.031903423967638185, 0.01917037846786635, 0.03214626147278717, 0.009861194378962474, 0.036429703767810545, 0.019438476135422076, 0.021909534432260052, 0.0708808469186936, 0.08232794302914824, 0.023958021475534354, 0.015532894725246089, 0.030917987560055087, 0.027617766255778924, 0.04713303728827408, 0.049067282783133645, 0.035654202702322176, 0.031109212299010584, 0.11794753026749406, 0.09340926805245024, 0.09030500426888466, 0.09195361366229397, 0.1618386222315686, 0.09272972201662404, 0.1989497108651059, 0.09491671502057995, 0.10712908328111682, 0.15306106608893189, 0.14407955589038984, 0.13303726698671067, 0.1176171244255134, 0.18630934985620634, 0.10974717672382082, 0.12130363232323102, 0.10298426569040332, 0.11803592980972358, 0.1273161039820739, 0.12156908879322664, 0.17797403569732392, 0.10068233563963856, 0.07583858338849885, 0.14145065338483878, 0.1365807397024972, 0.10272864797817809, 0.17573818138667516, 0.11179480542029653, 0.07734187772231442, 0.15770539401897363, 0.08205458841153554, 0.14543263614177704, 0.13609553288136209, 0.19354201746838434, 0.12273155498717513, 0.22341422310897283, 0.13110288578484738, 0.1340534138892378, 0.11477622043873582, 0.31592294627002304, 0.09491306450217962, 0.10597188930426325, 0.22001833175974234, 0.18100488877722196, 0.5007369135107312, 1.1653947510889597, 20.731619800840104, 69.75705119541713, 97.25291429247174, 87.75720732552665, 84.78761672973633, 74.56603840419224, 76.84841741834367, 63.11487211499895, 50.922600541796, 50.597973755427766, 45.48088257653372, 50.402989932468955, 56.131369726998464, 79.12670394352504, 72.44414888109479, 59.6421138218471, 55.68765081678118, 42.4317490032741, 25.02783863885062, 16.196443728038243, 8.278724772589547, 2.943252580506461, 2.7308882730347768, 0.5688030411090169, 0.5741878407342094, 0.3017857234392847, 0.2597574272326061, 0.2897656655737332, 0.30580091370003565, 0.19237739353307656, 0.3163845943553107, 0.33769151674849646, 0.5061112908380372, 0.28491544297763277, 0.32588992001754896, 0.29569522025329725, 0.6041600895779473, 0.8661372491291591, 0.8770853302308491, 0.46340625094515936, 0.6074748145682471, 0.3358301594853401, 0.35297299389328274, 0.20911742241254874, 0.23950554536921637, 0.548713356256485, 0.9103052648050445, 0.322564745587962, 0.45740724142108646, 0.45640789504562107, 0.5373243359582764, 0.41757468453475405, 0.9461693146399089, 0.6906090336186546, 0.7391591370105743, 0.6877782398036548, 0.4552486315369606, 0.17421185757432664, 0.10885331540235452, 0.1915974582412413, 0.2564701421984604, 0.31459597604615347, 2.05121157850538, 4.368955620697566, 17.788194383893693, 40.97568450655256, 49.72880274908883, 26.241483960832866, 17.654535361698695, 29.052238736833843, 67.48137024470738, 71.18592044285366, 55.34984677178519, 37.991384574345176, 35.623768533979145, 46.79829229627337, 56.326353549957275, 72.70651285988944, 59.452504430498394, 81.9049619947161, 82.69805717468262, 65.99114840371269, 16.51188325881958, 0.34735160267778803, 0.38653919845819473, 0.1846829014165061, 0.08869691020143883, 0.126768539792725, 0.203377884679607, 0.103736672816532, 0.1695161374019725, 0.1908342691936663, 0.15955907026571886, 0.0874873808185969, 0.12667134643665381, 0.10040216174508844, 0.09742584930998938, 0.14300430858773844, 0.1255881738449846, 0.2239184696227312, 0.13053028365331037, 0.19590562635234424, 0.13452378793486527, 0.10418232104607991, 0.17875808291137218, 0.09818519106400864, 0.19543029900108064, 0.1950241822217192, 0.12557194328733853, 0.1085592790373734, 0.1246154396129506, 0.06669356660651309, 0.15503842569887638, 0.08737633856279509, 0.1601531548159463, 0.15655044599303178, 0.14755989770804132, 0.20422150726829255, 0.13111600865210804, 0.08268456746424947, 0.15944160228329046, 0.21185860889298574, 0.09133316124124186, 0.1496910404946123, 0.13355496206453868, 0.13588989605861052, 0.12389320693910122, 0.09216891282371112, 0.1396848609937089, 0.15771139226853848], [0.021460904041305184, 0.017749112232455184, 0.057575901571129046, 0.054896940144577196, 0.011867791214691741, 0.02244719709934933, 0.0441809858727668, 0.03845067282340356, 0.05983289224760873, 0.06566355723355498, 0.012932261684909463, 0.023120442937527384, 0.07816922225590263, 0.017294146020763686, 0.03347058880275913, 0.031117931474000216, 0.04064490918868354, 0.05751067399978638, 0.08253674182508673, 0.04962160178859319, 0.049351958757532496, 0.01959961123897561, 0.024737975427082608, 0.011684779293968208, 0.02397416891264064, 0.08608404826372862, 0.03187810782609241, 0.0173277996613511, 0.04038736782968044, 0.022009172210735933, 0.052932791611445804, 0.01358202172975455, 0.01083848242914038, 0.06411242618092469, 0.0643370755548988, 0.051107440809054036, 0.04526359528037054, 0.034359208441206386, 0.01707727605077837, 0.03194013271214707, 0.03478303498455456, 0.049147214208330424, 0.03198733839339443, 0.127764887043408, 9.85884153842926, 33.774383885519846, 71.83921786717006, 71.74415261404855, 65.77137688228062, 57.47297307423183, 55.93093156814575, 55.48706674575806, 40.2510256086077, 34.60599293027605, 25.70893927982875, 42.61370495387486, 67.56585339137486, 69.4281165259225, 40.44765962873186, 27.554564952850342, 23.844999892371042, 28.6342351096017, 14.559447271483284, 2.3345569457326616, 0.42583807398165974, 0.14594767136233194, 0.23046026644962175, 0.07086021266877651, 0.11870919939662729, 0.07096104297254767, 0.06395767269922153, 0.08925355318933725, 0.02775398555344769, 0.09636602510831185, 0.21154520713857242, 0.19518906623125076, 0.08944433688053063, 0.022684546952535, 0.07259984074958734, 0.037690038460173776, 0.0607680899224111, 0.09270511833684784, 0.06885012731488262, 0.1500382468636547, 0.04152134233819587, 0.23616234904953412, 0.11938903720251151, 0.19407434176121438, 0.08980550071490662, 0.1376702498112406, 0.05465564291392054, 0.05137249015803848, 0.031422186576362164, 0.028067657025530934, 0.008055038484079497, 0.06459899685744729, 0.010891837333994252, 0.053846133673297505, 0.0742409930431417, 0.07856928650289774, 0.04852714176688876, 0.10664564743638039, 0.04183448285662702, 0.10945880612624542, 0.12890223387096608, 0.24776014100228036, 0.07658267846064908, 0.13408983764903887, 0.07318150132362332, 0.04971588422943439, 0.39323001514588085, 0.7828899047204426, 10.013095889772687, 28.44594587598528, 27.888307775769913, 18.63244046483721, 10.038258790969849, 24.042432955333165, 49.27076360157558, 111.56139523642403, 55.0869026184082, 21.242670229503087, 28.571859393801006, 31.697126116071427, 40.74558448791504, 37.96925456183297, 47.841480936322895, 60.60088879721505, 61.642118045261924, 27.660003866468156, 2.9053345237459456, 0.02833077254971223, 0.014282078182856952, 0.048081632637019665, 0.013642620844101267, 0.09051148247505937, 0.01299269710268293, 0.09395870499845062, 0.038722792507282326, 0.0643214692494699, 0.06570363829710654, 0.0388446981087327, 0.025706148207453743, 0.01380531064101628, 0.040851166870977194, 0.06115881074219942, 0.025268342146383863, 0.0375349999937628, 0.05816634917365653, 0.015224288517077054, 0.025630530568638017, 0.045710485229002576, 0.06057092800204243, 0.030259201303124428, 0.009448298186595951, 0.04239603843806045, 0.094633236660489, 0.08688279254628078, 0.03921831306070089, 0.04925213947093912, 0.04994116124830075, 0.09070881402918271, 0.033982305987072844, 0.05136476503685117, 0.02722447887728257, 0.05220710180167641, 0.0015172395007019596, 0.06945842038840055, 0.017481647298804352, 0.056153078097850084, 0.0861577100253531, 0.012191102973052433, 0.03315446612292102, 0.07987417041191033, 0.0642516819228019, 0.02608344590823565, 0.018966159783303738, 0.02425960484626038, 0.01410112137507115, 0.03485242197556155, 0.006342246039171836, 0.029206664567547183, 0.017406706498669725, 0.048902470019779036, 0.08113828793700252, 0.05169514713010617, 0.007180238059455795, 0.038354717793741396, 0.02208846920569028, 0.05032175832561084, 0.022815426179607, 0.01781575963832438, 0.025902136262240152, 0.009672278355407928, 0.06838539868061032, 0.029425570142588446, 0.05187960348225065, 0.03847894059228046, 0.026472662076620117, 0.039579839911311865, 0.03212079944621239, 0.06667830635394369, 0.034814342590315, 0.04375801428354212, 0.0328703770813133, 0.018244454670431356, 0.03230947628617287, 0.030101197638681958, 0.044850587977894714, 0.09624648080872637, 0.01689098765408354, 0.012586353862259005, 0.021069942341585244, 0.020972421592367545, 0.03798025467299989, 0.04997659095429948, 0.060178056226244996, 0.007153284952177533, 0.18389091534273966, 0.8239190716828618, 24.959666388375418, 57.349430629185264, 86.76562990461076, 81.57153184073312, 79.48526573181152, 77.8634033203125, 80.76403304508754, 76.50836563110352, 52.64580590384347, 34.894926820482524, 14.74639116014753, 30.57925476346697, 59.66312517438616, 73.63063716888428, 45.455073492867605, 29.697406768798828, 22.983266932623728, 21.985535144805908, 8.510193586349487, 0.44078620044248445, 0.38496155025703566, 0.18628147563764028, 0.19082429472889217, 0.06707516791565077, 0.0695074920409492, 0.05875687820038625, 0.0905720077987228, 0.07056331288601671, 0.1482498456857034, 0.1733452190778085, 0.33892916462251116, 0.20425118639000825, 0.07720347014921052, 0.02868321890543614, 0.08982405186231647, 0.20263134688138962, 0.052082515986902375, 0.067579590848514, 0.24905823277575628, 0.22620950240109647, 0.1253395721848522, 0.45494443071740015, 0.05771690114800419, 0.41244786392365185, 0.2841056250035763, 0.31152047536202837, 0.27764282322355677, 0.13643432541617326, 0.05249943504376071, 0.02509143958533449, 0.028224675117858818, 0.11825945281556674, 0.08126146918428795, 0.05978019721806049, 0.05699557092572961, 0.01491883919308228, 0.04581480659544468, 0.13597088599843637, 0.020942304815564836, 0.15520400181412697, 0.13347600772976875, 0.17180909721979074, 0.09026142196463686, 0.06216954293527773, 0.06903084833174944, 0.021748285674090897, 0.23641560545989446, 0.4896015567438943, 6.65104889018195, 16.22298410960606, 9.329615490777151, 7.5107820715223035, 10.350701911108834, 33.27823386873518, 56.45974506650652, 105.39379896436418, 42.53463792800903, 7.620405537741525, 26.073745761598857, 42.791234901973176, 61.78250639779227, 66.234696660723, 68.33344173431396, 74.17232567923409, 78.38667910439628, 46.54624291828701, 9.148894582475934, 0.34452778420278, 0.11398755918656077, 0.030688374702419554, 0.08370805611567837, 0.05060273289148297, 0.05038866187844958, 0.02709597282643829, 0.04744842375761696, 0.020816492548744594, 0.03299539376582418, 0.03245356319738286, 0.05027074267023376, 0.036854819527694156, 0.07768727918820721, 0.028346455190330744, 0.04702558787539601, 0.04557785198890737, 0.08088049891271762, 0.045823291675852876, 0.030532443962459053, 0.027712840886254395, 0.0582797255899225, 0.013354688749781676, 0.04994499836383121, 0.028052897192537785, 0.03313222035233464, 0.029799137597105334, 0.03132830447118197, 0.06672887078353337, 0.07521224128348486, 0.019942290083106076, 0.04868116243077176, 0.06314867575253759, 0.043137202238930125, 0.0293220223060676, 0.028082535602152348, 0.05206205137073994, 0.04035002465492912, 0.05280938305492912, 0.06110876199922391, 0.03121947423954095, 0.013778690864065928, 0.062180229861821444, 0.04450616020975368, 0.09599032705383641, 0.1540315882968051, 0.11824417220694677, 0.1415988861450127, 0.07051771533276353, 0.04742137056642345, 0.2213708149003131, 0.10156484507024288, 0.12492498728845801, 0.16830656730702945, 0.1918415137167488, 0.1277939012008054, 0.10862848282392536, 0.09118013123848609, 0.13261417326118263, 0.07185126056096383, 0.120717568056924, 0.13189826453370707, 0.15132236081574643, 0.1337718354271991, 0.11684702789144856, 0.2354313497032438, 0.070274094119668, 0.10559429813708578, 0.11870558959032808, 0.09980247928095715, 0.15872589711632046, 0.08443999862564461, 0.15802944877317973, 0.10643588512071542, 0.10256483605397598, 0.09454639774880239, 0.08496173777218376, 0.13731461603726658, 0.1490608850227935, 0.1646926762270076, 0.10485433534319911, 0.09153826880667891, 0.1696001264665808, 0.1455811538866588, 0.13108860940805503, 0.16314672918191978, 0.06435472425073385, 0.1845339901213135, 0.3910633442657334, 18.870560441698345, 58.43815081460135, 99.2288430077689, 90.96853964669364, 81.40813800266811, 79.17042895725795, 74.98054708753313, 69.12322262355259, 48.726764815194265, 44.83055203301566, 37.92113481249128, 59.08692496163504, 93.15286568232945, 99.64301817757743, 58.152680601392476, 45.814889430999756, 40.74816574369158, 41.8520746912275, 21.592148985181534, 5.1488739762987406, 1.214344050203051, 0.3580113878207547, 0.44463713094592094, 0.182485642177718, 0.2652535066008568, 0.22428635773914202, 0.28913804782288416, 0.21260286681354046, 0.36142412040914806, 0.7187804505228996, 0.933583521417209, 0.46165003946849276, 0.22586000258369104, 0.2114668499146189, 0.36967711469956804, 0.4571409299969673, 0.30643642959850176, 0.38552191161683624, 0.6286017351916858, 0.5480265159692083, 0.30802574860198156, 0.773378635091441, 0.494780244571822, 0.5598236343690327, 0.549021031175341, 0.5726963664804186, 0.42164301765816553, 0.28910013128604206, 0.11384760455361434, 0.15970752015709877, 0.1894693145794528, 0.2712403567773955, 0.19729631101446493, 0.14504801535180636, 0.22475014999508858, 0.20727405989808695, 0.1361685703907694, 0.2283859577562128, 0.22717847754912718, 0.47157402123723713, 0.2992171426968915, 0.4150413604719298, 0.2962121553719044, 0.23371777736714908, 0.21418822317251138, 0.08907536310808999, 0.4285939303891999, 1.2938633603709084, 13.817192929131643, 43.937298570360454, 44.500404902866904, 31.649704660688126, 17.011194705963135, 35.084713390895296, 71.72105680193219, 141.4072780609131, 69.4514833177839, 32.35968548910958, 36.173391887119834, 40.369815485818044, 53.712045192718506, 54.27505772454398, 64.63791029793876, 79.36739649091447, 84.23691640581403, 46.12733255113874, 6.995148437363761, 0.18383302273494856, 0.23308929109147616, 0.0992362621639456, 0.13212003691920213, 0.3120767655117171, 0.16720818196024212, 0.13625023886561394, 0.14045920515699045, 0.12241841107606888, 0.20351466376866612, 0.1484587394765445, 0.13382453045674733, 0.09525909022028957, 0.2173846795090607, 0.1283044038074357, 0.14193352604550974, 0.15886483394673892, 0.17296173822666916, 0.20819943238581928, 0.08022419270128012, 0.17237241699227265, 0.19103822324957165, 0.07357532983379704, 0.09403635654598475, 0.08684027554201228, 0.1733812764286995, 0.17101388131933554, 0.13715554028749466, 0.11096558134470667, 0.20435857134205954, 0.18307808467320033, 0.14126279417957577, 0.17332552799156734, 0.1162067758185523, 0.20247977572892392, 0.06710788008889981, 0.15131588759166853, 0.10296409962964909, 0.10512767639011145, 0.1454748817320381, 0.08223955027226891, 0.06781104592872517, 0.12737877347639628, 0.18733762896486691, 0.26687960220234735], [0.032482930192989964, 0.04037987680307456, 0.021702727136601294, 0.007281271923732544, 0.020861528614269834, 0.03334044239350727, 0.06434266668345247, 0.04057873506098986, 0.03810478959764753, 0.008991324359418025, 0.03959509337853108, 0.025563993424709355, 0.06338434453521456, 0.024358901660889387, 0.03440264146775007, 0.10019262334597961, 0.03231955931654998, 0.03335848463965314, 0.026020678026335578, 0.02360329863482288, 0.017996526456304958, 0.03482582340283053, 0.014082487955290292, 0.03331065470618861, 0.036232528276741505, 0.05344140449804919, 0.04200318023296339, 0.051084482576698065, 0.006720800301991403, 0.04100912982331855, 0.03001181761335049, 0.024112445867753456, 0.06095903646200895, 0.011849052621982992, 0.011006586087335433, 0.014541086873837879, 0.011306667351163924, 0.0910182192123362, 0.054687489955020804, 0.16574224776455335, 0.07301954180002213, 0.03015086640204702, 1.4863371465887343, 27.164479187556676, 72.48596314021519, 74.33573341369629, 69.43621117728097, 61.3868134362357, 60.07889148167202, 49.9402642250061, 36.89245401109968, 24.176038128989084, 29.806879111698695, 40.89635692323957, 54.85585069656372, 54.264899458204, 26.388408831187657, 21.098446471350535, 24.16706453050886, 25.573081152779714, 16.855786085128784, 4.561262650149209, 0.4699987886207444, 0.07383550051599741, 0.06951062687273536, 0.21043694232191357, 0.035615081765822, 0.14336343003170832, 0.1398662876869951, 0.08278087872479643, 0.171311242505908, 0.10704352001526526, 0.04717227018305233, 0.028254157464419092, 0.048482287209481, 0.05045370963801231, 0.0778727363795042, 0.06139034724661282, 0.029909114552927867, 0.05686566539640937, 0.07911713567695447, 0.14395241199859551, 0.042860977418188534, 0.0379375273228756, 0.568391197494098, 0.06368876248598099, 0.3128798252769879, 0.45678988311971935, 0.24156332494957106, 0.2176309877208301, 0.05410485229055796, 0.059233474412134716, 0.12492523156106472, 0.0976857892902834, 0.05557359562122396, 0.16260369760649546, 0.1442207454570702, 0.03615907686097281, 0.026608338546273962, 0.046171977251235924, 0.1359708181449345, 0.11760629500661578, 0.005306844857321786, 0.040803021418729, 0.015738533244335225, 0.04685625606881721, 0.015914577458586012, 0.09662202280014753, 0.11198922605918986, 0.18710681849292346, 0.22860091765012058, 0.07979244765426431, 0.636789427271911, 0.4101281426846981, 3.332395996366228, 17.807618073054723, 34.990103244781494, 19.242203950881958, 12.39711228438786, 20.825210298810685, 54.554649761744905, 73.08125700269426, 57.148440088544575, 34.43370539801461, 22.978387560163224, 27.327414444514684, 43.00252962112427, 49.664118494306294, 53.35432413646153, 57.861544132232666, 42.85076706750052, 23.83478777749198, 2.626962546791349, 0.0892844604594367, 0.10416104897324528, 0.0664275333817516, 0.053031660949013064, 0.037863251487059255, 0.022232228723753775, 0.03222482564992138, 0.03893997121070113, 0.06877512883927141, 0.0004233727995597292, 0.05633906115378652, 0.03984437018100705, 0.035163448857409615, 0.05364890389942697, 0.05351560230233839, 0.05315783453573074, 0.09629215978618179, 0.07718071887003523, 0.051664436635162146, 0.006166533034827028, 0.011731174974037068, 0.035012698732316494, 0.0956546693508114, 0.05088996355022703, 0.04562486428767443, 0.019830112977485572, 0.033321762324443886, 0.03407486155629158, 0.048267469807927094, 0.02591213956475258, 0.010973467641243977, 0.07126959998692785, 0.05698075172092233, 0.03033360606059432, 0.062334718714867315, 0.022634678021339432, 0.031400656660220454, 0.027873149873422723, 0.014020876975597014, 0.02596038849359112, 0.022060128494298885, 0.018573299881869128, 0.11688085964747838, 0.060611653673861704, 0.07100458456469433, 0.034156414680182934, 0.04278488310852221, 0.025954337657562325, 0.03189058269241026, 0.0038443906981098864, 0.03611626469397119, 0.03852453136018344, 0.06167387988950525, 0.03937217087617942, 0.06568419826882226, 0.06362470878022057, 0.07969987512167011, 0.013847447665674346, 0.030536128407610313, 0.03931929264217615, 0.01817266396912081, 0.053352122860295434, 0.022241295647940466, 0.019548683793150952, 0.022979095611455183, 0.0413962204807571, 0.06414207137588944, 0.03734155983797141, 0.04558524802061064, 0.024475234793499112, 0.07071207490350519, 0.03128798931304898, 0.009832751887318279, 0.04466921556740999, 0.013192613875227315, 0.009194833126717379, 0.017744730592572262, 0.013496051342891795, 0.03039022980790053, 0.016447907679581215, 0.11627199660454478, 0.02513701338986201, 0.1267035768500396, 0.15191480331122875, 0.23541180789470673, 8.255273733820234, 47.71617712293352, 87.21910408564976, 84.6420589174543, 85.70360469818115, 87.11083725520542, 87.65199075426374, 74.0495023727417, 54.850434575762065, 24.332549776349747, 16.095272745404923, 24.174262864249094, 61.618633134024485, 67.10916914258684, 36.31120940617153, 19.34322554724557, 16.241290875843593, 13.589794891221182, 9.324755225862775, 1.9185481028897422, 0.3963278532028198, 0.04315372456663421, 0.07316849380731583, 0.16929451429418155, 0.12865063308605126, 0.10307304521224328, 0.2484001080904688, 0.042041157837957144, 0.10006484841661793, 0.07165670421506677, 0.0971280810024057, 0.04341353562527469, 0.010845280501858463, 0.06979287708444254, 0.08221521122114998, 0.08705979519124542, 0.10735413299075194, 0.04933041187801531, 0.27670307936412947, 0.2059470082500151, 0.010947857185133865, 0.07955595784421478, 0.374475144382034, 0.021370121144822667, 0.27102843672037125, 0.4178006095545632, 0.13496729199375423, 0.15540152335805552, 0.11761791152613503, 0.018931635921554904, 0.05057558470538684, 0.17904770879873208, 0.0967033723635333, 0.04574738735599177, 0.1076867508568934, 0.0207104103839291, 0.027102340877588307, 0.11878739377217633, 0.01951067565408136, 0.10234074986406735, 0.0843870864648904, 0.04085027120475258, 0.039687374141067266, 0.03960514926750745, 0.014541958791336842, 0.09119393264076539, 0.18649328712906155, 0.05792926225279059, 0.1980133732514722, 0.00802816086382206, 0.6142773724028042, 0.400458068719932, 1.5235408416816165, 7.871867792946952, 12.599397795540945, 7.359166298593793, 9.884898151670184, 26.05035812514169, 70.90309401920864, 63.45377744947161, 34.31434229442051, 24.287051234926494, 19.809086629322596, 31.700603689466202, 65.785231590271, 73.58293083735875, 69.95966066632951, 73.99953092847551, 59.947431564331055, 41.4007613999503, 9.275317055838448, 0.22537783559943947, 0.17196871579757758, 0.05101289034688047, 0.16200312626148972, 0.02680033681515072, 0.07641923294535705, 0.03567120000453932, 0.0404827732459775, 0.03207331556560738, 0.007523434286537979, 0.05448156814756138, 0.027371246001816223, 0.003946369846484491, 0.023329457168334296, 0.03167701718796577, 0.022265297127887607, 0.04972121072933078, 0.07336096705070563, 0.050615519883909395, 0.0403336210708533, 0.0441347979940474, 0.03225931558491928, 0.08683999055730444, 0.12094896206898348, 0.051682302462203164, 0.012942794244736433, 0.04378277063369751, 0.03372504282742739, 0.06264822224953345, 0.036947480269840786, 0.01678927525478814, 0.015196634822392037, 0.05051187365981085, 0.016163798281922936, 0.02210513741842338, 0.02034091922853674, 0.013885750967477049, 0.028703734411724975, 0.05517851182126573, 0.06029526636536632, 0.0741984760388732, 0.00801686495209911, 0.05490891628765634, 0.1483522637614182, 0.091130170705063, 0.11013497984302895, 0.10940482866551195, 0.07998727541416883, 0.07872340894703354, 0.12719076499342918, 0.12518834029989584, 0.10998597355293376, 0.0990104524950896, 0.08814070826130253, 0.09646920992859773, 0.2661002368799278, 0.19013794298682893, 0.07699704622583729, 0.09782763703593186, 0.1382618509232998, 0.050163133801626306, 0.13607717172375747, 0.13925855101219245, 0.07931064707892281, 0.2560747462723936, 0.11616366170346737, 0.16435924411884376, 0.1038799047736185, 0.12331665573375565, 0.17246825327830656, 0.11671908332833222, 0.08317474116172109, 0.12294616204287324, 0.09188043366053275, 0.09708826456751142, 0.11260051147214004, 0.1708050010991948, 0.08207872390214886, 0.1550822997731822, 0.13165051782769815, 0.19480641319283418, 0.1309716571122408, 0.27811728204999653, 0.2130176688411406, 0.24815580834235462, 5.194194904395512, 47.469866956983296, 99.74922139304024, 95.66931561061314, 88.47901398794991, 80.02313273293632, 81.9523834500994, 65.9583112171718, 47.450314726148335, 35.6726838520595, 45.07699768883841, 55.335533482687815, 78.7266058240618, 74.72035789489746, 40.056236335209434, 35.78346593039376, 41.02265780312674, 38.27494403294155, 23.628130980900355, 6.999998714242663, 1.0442978548152106, 0.22498286036508425, 0.2163156204457794, 0.5210764078157288, 0.3745121381112507, 0.3971651925572327, 0.4742314357842718, 0.22065027856401034, 0.2755110019019672, 0.24977495574525424, 0.17481259176773684, 0.15656567231885024, 0.10204047097691468, 0.17229435832372733, 0.2987116069665977, 0.33714502464447704, 0.4545055271259376, 0.2322006816310542, 0.3550327005130904, 0.3905956707894802, 0.18770915402897767, 0.4524262786975929, 1.4279212525912692, 0.8551669663616589, 0.6567679952297891, 1.3496064777885164, 0.5887306917990957, 0.6300467433673995, 0.3665951815034662, 0.2057660293898412, 0.5560587421059608, 0.6475451301251138, 0.32088748844606535, 0.4290951234953744, 0.3027967948998724, 0.22779004116143498, 0.3294092911694731, 0.4614878424576351, 0.29946657216974665, 0.22863763996532985, 0.21556328795850277, 0.12509933007614954, 0.09848314936139754, 0.12946780637970992, 0.06920323015323707, 0.2981524941112314, 0.4045252076217106, 0.42331794063959804, 0.5138008296489716, 0.1680677772632667, 0.8186076624052865, 0.4694680113877569, 6.286921160561698, 30.9395466532026, 52.27321570260184, 29.541384969438823, 18.750862087522233, 27.277046952928814, 73.83014079502651, 99.63215814317975, 72.3848876953125, 47.8928177016122, 32.306920869009836, 34.382115023476736, 56.10778406688145, 64.12526525769914, 69.29878970554897, 77.32568223135812, 66.3682757786342, 40.81113379342215, 7.368939808436802, 0.16340886083032402, 0.41124623268842697, 0.1753184124827385, 0.28316835101161686, 0.14281414236341203, 0.11086093767413072, 0.13612426205405168, 0.15475610084831715, 0.1386891244245427, 0.1177314847175564, 0.2103444987109729, 0.13256632297166757, 0.14762480636792524, 0.11385880038142204, 0.11750562755124909, 0.1574748278196369, 0.19787162728607655, 0.21836596328232968, 0.18754900619387627, 0.12247630368385996, 0.21731046134872095, 0.07321017621351139, 0.18024095334112644, 0.25104446762374466, 0.11779320426285267, 0.08070774389696972, 0.13307040663702147, 0.11890125194830553, 0.1256786361336708, 0.11691671343786375, 0.10006886534392834, 0.09756658425820725, 0.152461688965559, 0.08607574978045054, 0.11971579252609185, 0.0736718378694994, 0.15113941420401844, 0.21684980392456055, 0.1534008357141699, 0.1658335378659623, 0.20912399063152926, 0.1061444136181048, 0.13546366750129632], [0.012850622047803231, 0.024376609728538563, 0.018628320590193783, 0.052367633009063344, 0.05350755487701722, 0.05021345395860927, 0.07014444643365485, 0.06374359490083796, 0.030286644651953663, 0.03363148641905614, 0.12290268151887826, 0.020885855791025927, 0.1086719362065196, 0.03920703920136605, 0.035655115331922255, 0.028303717662181174, 0.023056964290195277, 0.014254892677334803, 0.06459639128297567, 0.04517558928845184, 0.03911084668444736, 0.044360614448253594, 0.013312597526237369, 0.02925759201337184, 0.017980331521747366, 0.027769313659518957, 0.08133369923702308, 0.010287546768917568, 0.057442067324050834, 0.04975652847705143, 0.014189304634263473, 0.04565012614641871, 0.08594075523849044, 0.034318438664610894, 0.045868638171149154, 0.02855194273537823, 0.03255355890308108, 0.06419097339468342, 0.03905512199604085, 0.18681564554572105, 0.8668939513819558, 19.80538671357291, 57.55703238078526, 75.0592771257673, 74.49876594543457, 62.00345911298479, 59.15683773585728, 46.62337834494454, 21.705357721873693, 28.459883962358745, 27.508724212646484, 50.483199937003, 73.41238730294364, 51.685453687395366, 27.90864862714495, 13.25053346157074, 26.338836908340454, 32.09455960137503, 11.957244413239614, 2.3355329505034854, 0.2627141571470669, 0.20413985236414842, 0.12735680251249246, 0.08496015000024013, 0.025628323633489863, 0.04537979100963899, 0.03372155176475644, 0.05795651900448969, 0.0044475684657559866, 0.07183464323835713, 0.027660671721345613, 0.0220206615049392, 0.09755508987499134, 0.09809081362826483, 0.23337978550365993, 0.031124615043933903, 0.1807497324688094, 0.09476477067385401, 0.07113938233149902, 0.02502578284059252, 0.03396113569449101, 0.12716370501688548, 0.15425817828093255, 0.05819266276167972, 0.08779180555471353, 0.04993790088753615, 0.2415279054215976, 0.3031675192926611, 0.15128805408520357, 0.21466416120529175, 0.03925652476027608, 0.01514930191582867, 0.030159147921949625, 0.10071452534092323, 0.04605517762580088, 0.13465044328144618, 0.020760891692978994, 0.03150160910029497, 0.028480034986776964, 0.010537016105705073, 0.041771955854658566, 0.045221509145838876, 0.07881737247641597, 0.11579208235655512, 0.16821936198643275, 0.11118659377098083, 0.10127499526632683, 0.07532345995839153, 0.04712562429319535, 0.03818065320540752, 0.05538686278409191, 0.17399303003081254, 0.3907070590981415, 0.20690347121230193, 0.18071545287966728, 0.7035040759614536, 1.254167216164725, 16.70558340208871, 35.753783226013184, 23.89085452897208, 6.989979411874499, 20.658884320940288, 57.13191032409668, 66.88712556021554, 51.855962480817524, 44.80901609148298, 23.84618977137974, 39.6156302179609, 33.719645977020264, 48.16799415860857, 52.773173332214355, 61.5028691973005, 47.69466550009591, 15.657822847366333, 0.5431276017001697, 0.13493377236383303, 0.036325392579393725, 0.016052013030275702, 0.11863846890628338, 0.05422099034434982, 0.058856941759586334, 0.06494526684816394, 0.07827039861253329, 0.027933368159990226, 0.05333508484597717, 0.03051060192020876, 0.0423920995422772, 0.016077558177390268, 0.0722459711666618, 0.017595595380823528, 0.010851724888198078, 0.055400640437645574, 0.018650374674637402, 0.025122726835044365, 0.03967394254037312, 0.02726427834880139, 0.0206701461159225, 0.05723136863006013, 0.10607423274112598, 0.05390258100149887, 0.014462081648941551, 0.0510009243818266, 0.06129354065550225, 0.09507572970220021, 0.056941525611494265, 0.008164775408139186, 0.020014990021341612, 0.01162303684811507, 0.029437861804451262, 0.014301379111462405, 0.05255875936044114, 0.031012697477958033, 0.029228150378912687, 0.023519024585506747, 0.013562890434903758, 0.002858345941474129, 0.06816671362945012, 0.048966649254517894, 0.05382554013548153, 0.07661782657461506, 0.042782090936920474, 0.04113682672115309, 0.06444494905216352, 0.034983084071427584, 0.013950518831344587, 0.03657365497201681, 0.08203607119087662, 0.05922440918428557, 0.04080624446006758, 0.012109443828064417, 0.039137309550174644, 0.019437655108049512, 0.015378146332555583, 0.044136484153568745, 0.025701676661680852, 0.027535575308970044, 0.02464202887910817, 0.044639790896326303, 0.021256069586213146, 0.031685461556272845, 0.03767625062859484, 0.0328542618746204, 0.011349135161643582, 0.05596778714763267, 0.030290329097104923, 0.012076573047254766, 0.036145875962185006, 0.008042500005103648, 0.012190638176564659, 0.05712584286395993, 0.020269359229132533, 0.05140948388725519, 0.07061891204544476, 0.04507244857294219, 0.012348358552636845, 0.08703464868345431, 4.871478872639792, 41.25909457887922, 80.76731259482247, 88.68959999084473, 89.8460442679269, 86.32103552137102, 83.40423039027623, 66.50639901842389, 37.2117862701416, 34.123152187892366, 14.641320501055036, 34.00197907856533, 74.32326139722551, 73.09794657570976, 31.41280582972935, 9.45704458441053, 11.256812146731786, 13.657815149852208, 5.195500731468201, 0.927839206797736, 0.2882362747831004, 0.205482578171151, 0.03620691018711243, 0.12514791318348475, 0.08283735319439854, 0.03298882215416857, 0.017840887486402477, 0.03526283727426614, 0.013033784094399639, 0.06857810262590647, 0.042520240880548954, 0.023960223321669867, 0.1389656952981438, 0.014740878117403813, 0.2108568740742547, 0.07296363729983568, 0.06789025810680219, 0.041900965717754195, 0.04200784855389169, 0.03364396807072418, 0.18308694634054387, 0.15270716936460563, 0.3191775530576706, 0.11515720428100654, 0.3096250556409359, 0.14043082882251057, 0.08535891824534961, 0.29405932660613743, 0.21782722004822322, 0.042141285857984, 0.11276316988681044, 0.15811449635241712, 0.06850574365151779, 0.23991812180195535, 0.029088219494691918, 0.0363403678472553, 0.03158100448282702, 0.021488584877390946, 0.047436372975685766, 0.039696296876562495, 0.13723942078649998, 0.034458264375903776, 0.07712076351578746, 0.05179184854828885, 0.10298439461205687, 0.10790069294827324, 0.1241872568747827, 0.03776253653424127, 0.04383623240781682, 0.030525149711008583, 0.004513547938716198, 0.10505265077309948, 0.544124396783965, 0.23406879710299627, 0.09183139593473502, 0.5259133854082653, 0.3544845256422247, 6.916170001029968, 12.303454910005842, 6.405302396842411, 5.278245525700705, 24.87824044908796, 68.64109407152448, 61.67581680842808, 33.756992544446675, 26.76906415394374, 22.002606868743896, 54.74507556642805, 57.45684630530221, 75.31153842381069, 72.72542585645402, 75.30818244389125, 67.17797020503453, 30.350367205483572, 2.9238916422639574, 0.06841405999979802, 0.01941074780188501, 0.09008620386677128, 0.017889847180673053, 0.057124675783727846, 0.03144471733165639, 0.030099457196359123, 0.07334745741848435, 0.02188510717158871, 0.03170540030779583, 0.0413711180777422, 0.002823025649247159, 0.02557987792949591, 0.0633601751178503, 0.030117733537086418, 0.05720252410641738, 0.04876203362696937, 0.026515285950154066, 0.05216461193880864, 0.05417420196213892, 0.0575760779902339, 0.028551769708948474, 0.052696010031338246, 0.06683702926550593, 0.023138641246727536, 0.035990901956600804, 0.016811760208968605, 0.05144889659381338, 0.06503845684762512, 0.017718311831621186, 0.051939921852733405, 0.07562767434865236, 0.06789318937808275, 0.03335938369855285, 0.05693655873515776, 0.06830534511911017, 0.017331338221473352, 0.04955660491915686, 0.06482703890651464, 0.017087123290236508, 0.02437981411016413, 0.09432721736707858, 0.10667945883635964, 0.13669633492827415, 0.16877130951200212, 0.16848814327801975, 0.17132452822157315, 0.15049521305731364, 0.11926586952592645, 0.09647658560425043, 0.11668443733028003, 0.23376926460436412, 0.17709124806736196, 0.19438528721886023, 0.1252553252769368, 0.07941178272345237, 0.14265433379581996, 0.07728266875658717, 0.16231040763003485, 0.16121523853923592, 0.10895030519792012, 0.13353448387767586, 0.10084293130785227, 0.19652089476585388, 0.12150443797664982, 0.22449189956699098, 0.1638617558138711, 0.11967636964150838, 0.12594413331576756, 0.14844907713787897, 0.13176379246371134, 0.0910177170964224, 0.12201232143810817, 0.14531514101794787, 0.1348128302821091, 0.10738634304808718, 0.13126937113702297, 0.16739268920251302, 0.177393141867859, 0.11223813306008067, 0.2285794216607298, 2.315000806535993, 34.231446811131065, 84.68037128448486, 96.35157312665666, 94.46736758095878, 83.37195600782121, 79.81059428623745, 60.75670909881592, 28.82729775565011, 36.91584859575544, 38.541028772081646, 63.966623987470356, 97.97397749764579, 75.7889769417899, 36.38576705115182, 22.336170775549753, 40.271887574877056, 48.03760078975132, 19.376993792397634, 3.752993472984859, 0.35867656927023617, 0.32600301823445726, 0.16593451744743756, 0.36102948444230215, 0.2108862410698618, 0.20143386828047888, 0.18718502643917287, 0.20108150504529476, 0.20099180271582945, 0.1678372382053307, 0.27746428708945003, 0.2040416004934481, 0.23813143053225108, 0.2665402261274201, 0.4392848467188222, 0.4484990265752588, 0.2913789504340717, 0.21997379272111825, 0.15127014076071127, 0.3542984170573098, 0.5048040524125099, 0.3420987645430224, 0.5182639073048319, 0.3648273263658796, 0.6169039543185915, 0.42673083607639584, 0.7694624023778098, 1.4035629310778208, 0.7112353582467351, 0.5793987182634217, 0.38330421490328653, 0.32044760776417597, 0.288629987942321, 0.5816661651645387, 0.11878613169704165, 0.2012673964990037, 0.06721221841871738, 0.1908425608915942, 0.16992787245128835, 0.1700132050152336, 0.2513588193271841, 0.16945314221084118, 0.26525041248117176, 0.24146151755537304, 0.29984516756875174, 0.2747326136699745, 0.3025315962731838, 0.13249754666217736, 0.15248991602233478, 0.09702201240829059, 0.1854730283043214, 0.463816086096423, 0.9779410383531025, 0.43932781155620304, 0.38078269734978676, 1.0328452693564552, 3.2138953379222324, 27.237287623541697, 51.63759796960013, 33.42115136555263, 11.651240536144801, 27.630800587790354, 82.9398683820452, 92.86597456250871, 69.71452822004045, 64.4936865397862, 31.57371916089739, 50.82332468032837, 46.38785525730678, 63.22390324728829, 71.65465981619698, 82.81162548065186, 71.34725761413574, 29.026737110955374, 1.6367178772177016, 0.2703375795057842, 0.09340215022010462, 0.1844139029937131, 0.22571304546935217, 0.14991868899336883, 0.16491035026099, 0.15911142714321613, 0.2201584628117936, 0.13361493098948682, 0.07804771699011326, 0.1029721334842699, 0.1343068060066019, 0.13060127198696136, 0.15221114669527325, 0.171164461810674, 0.16262188234499522, 0.1417892559298447, 0.18570184388331004, 0.13633152736084803, 0.21329309977591038, 0.1505600538636957, 0.0957350011116692, 0.11104542456035103, 0.2307551849101271, 0.13230174859719618, 0.09099772745477301, 0.15770692750811577, 0.14641002512403897, 0.2325439117848873, 0.12370818401021616, 0.09933935877467905, 0.16528684220143727, 0.11174799328935997, 0.15810872880475862, 0.14357867491032394, 0.19936045525329454, 0.13682004543287413, 0.09450802659349782, 0.2760316553924765, 0.08395224051283938, 0.10642974437879664], [0.05505037048299398, 0.023316132436905588, 0.021246831331934248, 0.02143863452199314, 0.04480727708765438, 0.07738443543868405, 0.020158579905650446, 0.03512334743780749, 0.03705643603046026, 0.10159883288932697, 0.032280234819544215, 0.019627110566943884, 0.04544282691287143, 0.03734101022460631, 0.04904650943353772, 0.05614603151168142, 0.01908215873741678, 0.030679075379988978, 0.029922620792474066, 0.04558190962831889, 0.020587079858939563, 0.02745658704744918, 0.04624279255845717, 0.019675371370145252, 0.03287462471053004, 0.03286387671583465, 0.02475990737522287, 0.03946840071252414, 0.08570556143032652, 0.06760020474238054, 0.07344135309436492, 0.058571821344750266, 0.14272441289254598, 0.025215165356972387, 0.028304201118381958, 0.03373960418892758, 0.05680909253922956, 0.033443016532276354, 0.10022065362759999, 12.078406231743948, 49.78057377679007, 82.13057000296456, 80.2507974079677, 75.76071166992188, 57.6091126033238, 38.213963168007986, 40.81036254337856, 35.91574573516846, 34.19358260290963, 35.61643818446568, 88.9123592376709, 83.8388888495309, 30.1712634904044, 12.25842797756195, 32.225995200020925, 42.8445588520595, 19.464429923466273, 1.3252316543034144, 0.14913551030414446, 0.26545047174607006, 0.09241040343684809, 0.3516026788524219, 0.13714278382914408, 0.030462822876870632, 0.014652785612270236, 0.03326391042875392, 0.05312870842005525, 0.07110280929399387, 0.029235532839915583, 0.12042653081672532, 0.06311624177864619, 0.0822125445785267, 0.04025936559108751, 0.062197328944291384, 0.05166913549016629, 0.18412720837763377, 0.07568672725132533, 0.02395515127240547, 0.044162207416125705, 0.05268045800871082, 0.0892294787668756, 0.10843526997736522, 0.01102331791272653, 0.08169809968343802, 0.05314902715118868, 0.03764492945213403, 0.0916307463443705, 0.032538994148905785, 0.0489226191171578, 0.057639039254614284, 0.03117024652393801, 0.03639252004878862, 0.054930541198700666, 0.01963095786049962, 0.06427774445286819, 0.041450092768562694, 0.05582452126379524, 0.007946292221147035, 0.01354733162692615, 0.032121125143021345, 0.03605106087135417, 0.02377227590685444, 0.06615020254892962, 0.035985904546188455, 0.06530394724437169, 0.0554245214776269, 0.02239213907159865, 0.0474259642484997, 0.047879083148602924, 0.10978279981229987, 0.118972511695964, 0.06339355225541762, 0.1118896035477519, 0.0928466607417379, 0.17957031647009508, 0.3459477951484067, 0.09988367278128862, 0.7332245068890708, 0.9726912400552205, 21.641769545418875, 46.67501735687256, 21.191251822880336, 6.6570556078638345, 20.133470228740148, 48.9898270879473, 49.32693631308419, 51.663233348301475, 25.07844236918858, 22.396456820624216, 27.613687174660818, 38.70894241333008, 46.30596726281302, 59.93178422110421, 65.04242052350725, 31.940278325762065, 2.616216940539224, 0.15302419449601853, 0.018613136672813977, 0.040824283313538344, 0.0528253591619432, 0.019844455511442254, 0.046402160078287125, 0.037516350458775244, 0.05477842382554497, 0.030881265244845833, 0.030977376337562288, 0.04153582566816892, 0.020778526818113666, 0.061364210077694485, 0.015413155346842749, 0.04235880043623703, 0.015609869434099113, 0.05179895959528429, 0.016074365670127527, 0.02960801463840263, 0.034805983038885255, 0.037416195297347646, 0.03373789428068059, 0.04071550057934863, 0.039942968104566844, 0.05181509176535266, 0.010312113129267735, 0.01973588651578341, 0.03807005539004292, 0.02696127853622394, 0.027548606574003185, 0.08036101928779057, 0.11586146934756211, 0.0070805468463471955, 0.009356472890691032, 0.010532468224742582, 0.024814288564292446, 0.011291349423117936, 0.04414629916261349, 0.012263697738360082, 0.012677632089305137, 0.1131391597113439, 0.018791774587173547, 0.07270474904882056, 0.04296450150598373, 0.007582248005616877, 0.02048450741650803, 0.05490206986931818, 0.04347160125949553, 0.020236143243632147, 0.0223456509411335, 0.07256530331713812, 0.05589818302541971, 0.057946687032069476, 0.027179434330069592, 0.04669890379799264, 0.04877328373757856, 0.057744605732815604, 0.01765766946066703, 0.04034375499135681, 0.10871306221399989, 0.03527459967881441, 0.06144511180796793, 0.02495474531315267, 0.03744063952139445, 0.016405156580731273, 0.0016500008142819361, 0.001302346188042845, 0.01869965497670429, 0.014642656780779362, 0.014720997041357415, 0.04332611995882221, 0.008010119465844972, 0.10466203851891415, 0.028987887914159467, 0.07241272793284484, 0.05130692331918648, 0.06071114047829594, 0.06062594362135444, 0.4263314775058201, 28.198887041636876, 73.55433205195835, 97.59554386138916, 91.87666920253209, 96.07784884316581, 76.29481969560895, 63.38585186004639, 54.034007344927105, 32.167366300310405, 26.76095908028739, 14.093270914895193, 84.62470231737409, 109.5257328578404, 40.41661160332816, 9.882857118334089, 11.22204075540815, 21.212786027363368, 9.34273716381618, 0.29951314681342667, 0.31882479627217564, 0.11904842619385038, 0.09609161197607007, 0.37726669173155514, 0.16482222213276795, 0.03294257999264768, 0.03812410070427826, 0.04683373888422336, 0.06791730451264552, 0.04845209579382624, 0.0594057273119688, 0.04557893764493721, 0.11631181303943906, 0.01929194140913231, 0.10213909604187522, 0.07367851465408291, 0.09045999523784433, 0.061800209539277215, 0.06644056803945984, 0.0998474390112928, 0.11303512672228472, 0.08275467370237623, 0.20202783069440297, 0.1025209484089698, 0.08526940590568952, 0.02716451504134706, 0.06031206010707787, 0.09376451506146363, 0.11490174941718578, 0.08694976395262138, 0.09929368658257381, 0.1483173327786582, 0.17429573807333196, 0.03447142456259046, 0.152117698852505, 0.07871337341410772, 0.1318956318178347, 0.09339594841003418, 0.15667851269245148, 0.12384405386235033, 0.08287079818546772, 0.07778645386653286, 0.1084483317764742, 0.018525266387899007, 0.037647161832345385, 0.04576777394062706, 0.07987423148006201, 0.06491235789975949, 0.049220275466463397, 0.10157521308532783, 0.061158966805253706, 0.16170626719083103, 0.1296606867441109, 0.03432314769764032, 0.14019834915442125, 0.07821072824299335, 0.23623953919325555, 0.2933188820523875, 0.09450320899486542, 0.6087666909609522, 0.14848763149763855, 8.637790305273873, 19.59982599530901, 9.444166098322187, 6.170096320765359, 25.641744988305227, 51.15797076906477, 48.48443249293736, 38.53495257241385, 13.07754589830126, 24.12756402151925, 40.164055006844656, 59.920521191188264, 70.20572417122978, 76.05129923139299, 78.50469425746373, 52.828241280147004, 8.370931710515704, 0.10161894466727972, 0.02305134941291596, 0.037393539013074975, 0.042147009300866296, 0.027592879287632446, 0.025355695048347116, 0.017910104843654802, 0.029112063215247223, 0.03548438574320503, 0.05242678090663893, 0.03101844127689089, 0.025199146841519644, 0.03932194910677416, 0.015602341088067209, 0.02469393511169723, 0.020990077073552778, 0.010041437028641147, 0.046814268321863244, 0.04362010204100183, 0.027083440284643854, 0.03515834966674447, 0.059610298834741116, 0.014795869987990175, 0.026126217363136153, 0.04168999221708093, 0.015536404447630048, 0.034347907440470796, 0.06337232089468411, 0.04391443017604096, 0.04171836515888572, 0.058229391862239153, 0.03815668056319867, 0.01913105397086058, 0.025052378020648445, 0.08615752003554787, 0.044668883085250854, 0.040497069978820424, 0.044891669880598783, 0.016727423395163248, 0.022547906963154674, 0.27238993080598967, 0.08149647300264665, 0.11968154007835047, 0.07426998005913836, 0.21077546344271728, 0.16710800305008888, 0.16844091724072183, 0.11771312355995178, 0.11424564676625387, 0.15334876493683883, 0.11745669160570417, 0.16543059663048812, 0.11494533850678376, 0.1904943095786231, 0.16327665506729058, 0.20753647653119905, 0.18427453190088272, 0.1588408545191799, 0.10353125991033656, 0.1833170104239668, 0.11549867024379117, 0.22922359566603387, 0.10260140230613095, 0.11153337944831167, 0.09517985090081181, 0.06642386250730072, 0.07714226629052844, 0.10624946440969195, 0.26507621897118433, 0.2724884812320982, 0.2599538766912052, 0.10885835691754307, 0.24176319422466414, 0.09543194701629025, 0.13253353615956648, 0.09085910953581333, 0.10819109915090458, 0.14932037038462503, 0.15756231812494143, 21.24716397694179, 77.23925358908517, 110.98501437050956, 100.05629008156913, 95.99956348964146, 76.49808924538749, 52.37107760565621, 52.631169523511616, 47.47271571840559, 48.027654443468364, 50.189916474478586, 118.15910584586007, 110.55383695874895, 41.20950181143624, 19.563822167260305, 44.778944287981304, 62.69406141553606, 31.02283123561314, 2.9603334239551, 0.4609041394931929, 0.3747275322675705, 0.285951023123094, 0.8915476256183216, 0.4345772793250424, 0.27231719185199055, 0.17469416026558193, 0.341999562723296, 0.3215603237705571, 0.22812958008476666, 0.37222145817109514, 0.31144871349845615, 0.3094695625560624, 0.44074442982673645, 0.28854177838989664, 0.2021721415221691, 0.15326160032834324, 0.19215287986610616, 0.24138356745243073, 0.2415490485727787, 0.15448814736945288, 0.1553537409220423, 0.24197902264339582, 0.21420278453401156, 0.173887164997203, 0.2191152423620224, 0.20943645600761684, 0.22409324667283467, 0.21252395319087164, 0.19701014565570013, 0.2114717082253524, 0.1452584969145911, 0.1914545859077147, 0.16991191330764974, 0.27418340742588043, 0.18485276587307453, 0.3190996029547283, 0.12390263857586042, 0.17036108991929463, 0.15620070190301963, 0.14326699663485798, 0.1860442597951208, 0.16870458237826824, 0.14809550611036165, 0.24439607294542448, 0.1296476453010525, 0.13154645769723824, 0.35361648936356815, 0.21108258196285792, 0.20051646179386548, 0.3567353348646845, 0.40998771307723864, 0.2739121562668255, 0.0715273686551622, 0.1309680880180427, 0.20849554506795748, 0.8745048886963299, 0.7988501882978848, 0.23848022467323712, 1.2612139923231942, 2.1235755469117845, 33.119134017399375, 64.53736291612897, 29.22610351017543, 10.893367511885506, 30.813197135925293, 71.46074948992047, 69.5926012311663, 72.87987041473389, 35.10339362280709, 29.552689688546316, 36.130844593048096, 52.032398087637766, 61.44316332680838, 76.86678150721959, 86.41225147247314, 53.315105029514854, 5.476985284260341, 0.2966855285423142, 0.17739923511232647, 0.17255126525248798, 0.20102551233555588, 0.101621611309903, 0.18424766191414424, 0.14794674409287317, 0.10711985520486321, 0.11529870597379548, 0.16270796129746096, 0.11392406187951565, 0.1117349789877023, 0.10244613313781363, 0.1034888175449201, 0.10180472077003547, 0.12344943146620478, 0.12019767452563558, 0.14996896843825067, 0.14193613161998136, 0.14674845124994004, 0.10259593331388064, 0.1838521302810737, 0.21156864373811654, 0.16804102941283158, 0.13006632854895933, 0.17042689424540314, 0.1333911501403366, 0.14182130992412567, 0.14484205283224583, 0.06899392245603458, 0.16757837709571632, 0.19851114654115268, 0.08670455496758223, 0.12433698241199766, 0.19071627195392335, 0.15688927923994406, 0.0641010675047125, 0.11184722225048713, 0.04622297255056245, 0.13091744216425077], [0.05986184533685446, 0.043586799542286565, 0.04554276494309306, 0.031001450760023933, 0.051439678695585044, 0.047324519870536666, 0.033656751670475514, 0.024263548831056272, 0.048613471777311394, 0.034129534515419176, 0.06882519115294729, 0.023135825326400142, 0.02707787460115339, 0.0576624758541584, 0.06125956640711852, 0.05149493519482868, 0.012214397928411407, 0.014889646920242479, 0.0802409185894898, 0.07491723461342709, 0.029039945120790174, 0.024374326458200812, 0.003030151008195909, 0.08345577001039471, 0.06262785941362381, 0.008193440968170762, 0.02828651001410825, 0.008868008253297635, 0.05634077445470861, 0.06616538816264697, 0.02865504613146186, 0.05293468811682292, 0.06445051982466664, 0.12808199359902314, 0.05396977971707072, 0.030156776442059448, 0.056152253677802424, 1.1755408580814088, 28.369225604193552, 66.757340158735, 74.04970387050084, 71.0360061100551, 60.40492180415562, 42.63387904848371, 45.54350669043404, 21.51675408227103, 21.809853417532786, 40.589194434029714, 73.6257734298706, 87.32573114122663, 31.520388262612478, 5.348934326853071, 21.928804840360367, 57.54695749282837, 26.060299260275706, 0.9499814872230802, 0.7929365113377571, 0.05536863054814083, 0.13009607552417687, 0.17759689236325876, 0.08980489681874003, 0.03607573240463223, 0.07356747918363128, 0.057498881061162264, 0.05222628737932869, 0.028349340660497546, 0.07662083927009787, 0.04374697791146381, 0.049384633611355505, 0.026134356390684843, 0.045082806410001855, 0.03490191771249686, 0.18578286096453667, 0.061615749794457636, 0.18761396913656167, 0.0893684427386948, 0.05600713878603918, 0.08381513572697129, 0.13760577541376862, 0.10576469863631896, 0.1664822580558913, 0.2646068355866841, 0.33866719582251137, 0.1666702665388584, 0.07077576898570571, 0.11145823169499636, 0.05007875457938228, 0.027420729864388704, 0.06112152524292469, 0.2534110892031874, 0.27501008020980017, 0.05802208584334169, 0.006916544084171099, 0.06751065847596951, 0.03010974039456674, 0.062100576635982306, 0.006277905652366046, 0.07475786709359714, 0.07436800122793231, 0.06027742089437587, 0.17778342163988523, 0.01712312126931335, 0.06695631572178432, 0.0631868704887373, 0.10023481465343918, 0.09979997548673834, 0.07640703967107193, 0.027992907911539078, 0.012648299020448965, 0.05035490815394691, 0.06832306845379726, 0.0888171126799924, 0.26769636837499483, 0.18833318911492825, 0.046001203557742495, 0.11796161665448121, 0.18465326300689153, 0.2864645655666079, 0.013738524135468262, 1.2181959577969141, 0.9502264112234116, 23.045637437275477, 40.639075551714214, 16.227253777640207, 9.613881928580147, 18.523134878703527, 43.637004375457764, 72.62205750601632, 44.3664436340332, 28.885777269090923, 22.89308626311166, 37.61553566796439, 43.75161143711635, 51.09216785430908, 70.0491395677839, 50.27823850086757, 8.99453774520329, 0.1757090858050755, 0.09805607942066022, 0.018371449284521595, 0.10459210869989224, 0.005208743536578757, 0.01268033605135445, 0.07547877662416015, 0.06279439226325069, 0.020771227477650558, 0.06957501306065492, 0.032772559473024945, 0.028543274450514997, 0.02666898600624076, 0.05417015450075269, 0.019280755759349892, 0.0545176017497267, 0.004661163232023162, 0.05374364095873066, 0.02982074554477419, 0.028012481950489537, 0.027841776110497967, 0.04613124818674155, 0.038610688344176324, 0.03991754339741809, 0.016057909499587755, 0.03012880722859076, 0.02489712581570659, 0.028512214510036365, 0.07062283397785254, 0.053041218114750724, 0.027931936451100876, 0.007716344336846045, 0.010149023844860494, 0.05316592945850321, 0.020499735438664044, 0.060275595635175705, 0.02500298067129084, 0.018824978698311106, 0.040442050966833315, 0.09207357186824083, 0.0007935995028154658, 0.04033013340085745, 0.02167187414930335, 0.07338329085281917, 0.021397898672148585, 0.055855028198233674, 0.028980729369712726, 0.014248490699433854, 0.034870969730296304, 0.013983007088037474, 0.0349119362820472, 0.029101718948887925, 0.04832005627187235, 0.03421991877257824, 0.03838195079671485, 0.04873147580240454, 0.037842501886188984, 0.09549080992915801, 0.07458942077521767, 0.012978895700403621, 0.13066253012844495, 0.05808412430009671, 0.01780951372347772, 0.03229428388710533, 0.013848265300371816, 0.04580147677500333, 0.03520042901592595, 0.04084687852965934, 0.05769856713180031, 0.03333012526854873, 0.0688684613310865, 0.007748141335988683, 0.03364636329934001, 0.034470128560704846, 0.027088405464642813, 0.0631101621048791, 5.748928223337446, 53.17889254433768, 83.63570962633405, 87.62002209254673, 89.2840461730957, 85.75577177320207, 69.22463853018624, 69.85835593087333, 22.248420238494873, 13.696626918656484, 29.05005179132734, 54.77363613673619, 108.10875197819301, 50.71453673498971, 6.691688469478062, 8.945674538612366, 25.78088092803955, 13.988504239491053, 0.29530006859983715, 0.6804436019488743, 0.04105703778831022, 0.18311700544187, 0.08291964592146021, 0.10348436635519777, 0.06328233358051095, 0.0738534749086414, 0.029170614002006393, 0.08241286168673209, 0.043326988483646085, 0.07327964462872062, 0.03709866126467075, 0.10436134572540011, 0.05125852341630629, 0.09091524473790612, 0.18008972145617008, 0.6223908056105886, 0.4061725549399853, 0.5916401413934571, 0.47833564983946936, 0.23938577036772454, 0.35476815328001976, 0.2625556785081114, 0.09301838438425745, 0.5239334202238491, 0.6053361264722688, 1.4744914450815745, 0.8946575958813939, 0.6448100368891443, 0.4054434283503464, 0.3494573411132608, 0.5351383675421987, 0.45021297889096396, 0.9618985163314002, 0.7619958030326026, 0.6480114736727306, 0.5717650364552225, 0.5354435997349876, 0.20994636150343077, 0.5066714893494333, 0.13232754649860518, 0.426417488604784, 0.3191969320178032, 0.5515799767204693, 0.5688906535506248, 0.42336095975978033, 0.36792538155402454, 0.19380824746830122, 0.12477466464042664, 0.09768323799861328, 0.21283594359244618, 0.024556753990639533, 0.014951128978282213, 0.08018527193261044, 0.04488843326855983, 0.06455601844936609, 0.30205192629780087, 0.039339536734457524, 0.06067957502922841, 0.16050418812249387, 0.180061738672001, 0.23217115178704262, 0.03172953240573406, 0.8963057303002903, 0.11642477554934365, 12.256238426480975, 20.393803596496582, 10.092699663979666, 11.835112452507019, 19.561730759484426, 46.98819351196289, 63.78431715284075, 22.666839020592825, 16.195755856377737, 29.558668613433838, 58.15893398012434, 64.08205441066197, 67.61535235813686, 79.73167664664132, 66.87641838618687, 22.514953136444092, 0.8788629291313035, 0.13995622071836675, 0.10147966856935195, 0.0716677304091198, 0.017481694796255658, 0.051310282067528794, 0.02101887240340667, 0.07849854922720365, 0.016220157400571873, 0.04332976708454745, 0.019285413902252913, 0.055307229914303334, 0.023195193747856786, 0.016997787369681255, 0.00914848833677492, 0.032681584890399656, 0.013394554378464818, 0.03343459252001984, 0.022063600897256817, 0.07757716652538095, 0.034855105581560304, 0.032002540970487256, 0.010591499075027449, 0.03332138234483344, 0.01745788160977619, 0.00528637642439987, 0.022351671243086457, 0.0425959755666554, 0.045714376627334526, 0.06157007760235241, 0.047456257444407256, 0.08648655523679086, 0.03823735498424087, 0.017670285123001252, 0.03656463724161897, 0.04763956707237022, 0.06814776893172945, 0.02624489483423531, 0.025777355368648256, 0.13910688486482414, 0.19277506933680602, 0.14347245703850472, 0.0931776026263833, 0.24605278404695646, 0.09816504535930497, 0.12895045056939125, 0.09653083447899137, 0.08503263111093215, 0.1729925572872162, 0.08879248185881547, 0.13436900052641118, 0.09639174158551864, 0.17446873736168655, 0.09654193531189646, 0.18822131226105349, 0.08919159615678446, 0.12043459181274686, 0.14319467837257044, 0.2673462171639715, 0.09190308315945522, 0.22276588289865426, 0.09823788609355688, 0.22069662250578403, 0.15019866611276353, 0.17180096837026732, 0.11737678732190814, 0.07114754510777337, 0.09087141816105161, 0.20842119120061398, 0.06973571050912142, 0.20638977949108395, 0.11429817894739763, 0.2086406565670456, 0.10388818968619619, 0.10854591868285622, 0.24605579674243927, 2.946626148053578, 50.333205699920654, 96.59132766723633, 97.4680096762521, 88.12772696358817, 80.87973444802421, 59.785934584481375, 61.38474287305559, 29.759082453591482, 33.897933278764995, 60.10666343144008, 98.82236644199916, 121.38379260471889, 45.069104535239084, 9.891984445708138, 30.400022506713867, 78.04396615709577, 41.75834001813616, 1.848678320646286, 1.1782869164432799, 0.09192943067422935, 0.4338895433715412, 0.5627323240041733, 0.24223735449569567, 0.18887578642794065, 0.1942821363253253, 0.19343483607683862, 0.17383235293839658, 0.21109848682369503, 0.16347116391573632, 0.13519127640341008, 0.1739792421992336, 0.2758029076669897, 0.15763735052730354, 0.13095364879284585, 0.43751183471509386, 0.23165076971054077, 1.014850520661899, 0.31209245324134827, 0.32320691112961086, 0.20584279884185108, 0.15851157504533017, 0.3475072314696652, 0.5450299967612539, 0.39902011730841225, 1.499825771365847, 0.7435050723808152, 0.2370369535471712, 0.5935808601123946, 0.38012788391539026, 0.5055865389960152, 0.15909284885440553, 0.5020955034664699, 0.44290225261024063, 0.39639345396842274, 0.2099469043314457, 0.30802550432937487, 0.12201492701257978, 0.20570710540882178, 0.08813696274799959, 0.2899208329617977, 0.332280769944191, 0.3308708555996418, 0.37724744847842623, 0.3103494867682457, 0.27828355027096613, 0.25457407108375, 0.25095476529427935, 0.22622491871672018, 0.31516352987715174, 0.12185750688825335, 0.11146491526493005, 0.16934016613023622, 0.18764478819710867, 0.5345577044146401, 0.4880526512861252, 0.3715624106781823, 0.2165944440556424, 0.2640072549028056, 0.6606088834149497, 0.6791262669222695, 0.12395932339131832, 1.796715674655778, 1.749736732670239, 35.44474124908447, 54.27820873260498, 24.64661530085972, 18.405543565750122, 30.092217309134348, 63.15185737609863, 101.46939386640275, 59.69374588557652, 38.69150243486677, 32.33255277361189, 49.19852318082537, 55.31943103245327, 64.86436598641532, 86.63048049381801, 72.95996924809047, 18.85490788732256, 0.44612279693995205, 0.2238181278641735, 0.17246388351278646, 0.14176383800804615, 0.11632933281362057, 0.10726711087461029, 0.11530623771250248, 0.20509166057620729, 0.07052268899445023, 0.08530225378594228, 0.10131796688905784, 0.12745267951062747, 0.15465664118528366, 0.16191080478685244, 0.1734898556023836, 0.15648008191159793, 0.06363138556480408, 0.09358523932418653, 0.10217342991381884, 0.16504292243293353, 0.08681453870875494, 0.11537976376712322, 0.18200528009661607, 0.12394671621067183, 0.08678623022777693, 0.12921351859612124, 0.17449282535484859, 0.09956513451678412, 0.13355768977531365, 0.2081173975020647, 0.12703495978244714, 0.13710612936743669, 0.16290799342095852, 0.11727457280669894, 0.16792829760483333, 0.11320907595966544, 0.0875638449298484, 0.10075331718793937, 0.10005553891616208], [0.04944050418479102, 0.016918963652902415, 0.029999003479523317, 0.015880241890304854, 0.04270485668842282, 0.018976351379283836, 0.0161911517248622, 0.030993623858583823, 0.030223086276756864, 0.019056883307972124, 0.03858300411541547, 0.024871631558718424, 0.023739005638552562, 0.010827544444639767, 0.012930550080324923, 0.03384845477661916, 0.03964517604825752, 0.03667033603414893, 0.019811707715104734, 0.031181859650782177, 0.008572841279341705, 0.03103672101029328, 0.04867697926238179, 0.015277504322252103, 0.04198127712256142, 0.050071707993213616, 0.043323117441364696, 0.05100261393402304, 0.015191399924723166, 0.007029005326330662, 0.05932187395436423, 0.017661045172384808, 0.029917701413588862, 0.020405363091932874, 0.05843047571501561, 0.0689129867990102, 3.839610150882176, 51.47688961029053, 80.97675909314836, 72.25531768798828, 54.93813473837716, 65.91286999838692, 53.82273347037179, 34.27672822134835, 22.611171790531703, 47.66976315634591, 52.778155190604075, 48.503630365644185, 50.46303973879133, 9.844355412891932, 14.740429605756487, 59.66253457750593, 52.971721581050325, 5.090548191751752, 0.7044506594538689, 0.11478014237114362, 0.6816549226641655, 0.1124542328928198, 0.05125682707875967, 0.03667443777833666, 0.036999031967882595, 0.09292374910520655, 0.12380792865795748, 0.05738378116594894, 0.11360496043094567, 0.009879338405361133, 0.04781049682891794, 0.04807073536462017, 0.010166211136882859, 0.11802755668759346, 0.03742431057617068, 0.056956602659608634, 0.097615004517138, 0.04528245176853878, 0.07325456597443138, 0.0972412470728159, 0.26941021212509697, 0.04349431521924479, 0.20816676771002157, 0.08532355300017766, 0.31300269439816475, 0.17442797097776616, 0.2862974831036159, 0.24040916402425083, 0.2389567191047328, 0.11628122468079839, 0.26997942158154076, 0.4620016834565571, 0.46737356377499445, 0.19761112412171705, 0.23021990220461572, 0.05781813857278653, 0.42550966303263393, 0.2852619029581547, 0.22036621666380338, 0.5773589334317616, 1.2570417076349258, 0.4019855053297111, 0.14516689468707356, 0.5446551740169525, 0.37221676270876614, 0.11970071547797748, 0.3094570775117193, 0.3745509774557182, 0.08403846195765904, 0.026446004132074968, 0.061846641690603325, 0.13748950165297302, 0.10671049502811261, 0.1319904774427414, 0.06471869722008705, 0.05539081185790045, 0.157558409763234, 0.09620813000947237, 0.16972304987055914, 0.21427499423069613, 0.02989677878628884, 0.04153772895889623, 0.025725311732717922, 0.5791630766221455, 0.05809901814375605, 0.9443364015647343, 1.2946987726858683, 22.18156119755336, 29.03870712007795, 26.775458233697073, 17.608380215508596, 24.118345499038696, 58.01172597067696, 63.662494386945454, 38.96092925752912, 22.523103373391287, 30.582624639783585, 41.87800536836897, 36.468061515263145, 64.33745629446847, 60.03226212092808, 26.638524872916086, 0.8729204822863851, 0.0406830360713814, 0.10386079044214316, 0.011827511679647225, 0.019766196675066437, 0.04844879132828542, 0.03221976038600717, 0.04642815475485154, 0.018097456843991364, 0.030279177374073436, 0.018429007713815997, 0.02542585726561291, 0.04772546960573111, 0.030658084899187088, 0.021803515031933784, 0.016859232215210795, 0.040449915187699456, 0.0395955853164196, 0.03249786814142551, 0.024107731745711396, 0.03758384094440511, 0.018835180472316485, 0.04361202747427991, 0.060413731794272146, 0.04914150772882359, 0.03944470287699785, 0.02389898044722421, 0.02119927111613963, 0.08858190530112811, 0.03120798324900014, 0.013770978465410215, 0.04736998510946121, 0.04916939891076513, 0.040429593063890934, 0.05967518035322428, 0.0459588765432792, 0.03225261844428522, 0.04858375194349459, 0.048183796262102466, 0.013440452183463743, 0.04252764369760241, 0.03947814108271684, 0.06935313889490706, 0.03619301378993051, 0.014874203463218041, 0.030604243145457337, 0.043097484191613536, 0.046200024496231756, 0.026424216372626166, 0.04061502989913736, 0.02941541586603437, 0.016253341155658876, 0.018459048155429106, 0.08187920067991529, 0.07901534185345684, 0.036418779354010306, 0.04330317529716662, 0.06166368829352515, 0.08423045344118561, 0.008984821449433054, 0.049782360305211375, 0.027286787051707506, 0.05370897460462792, 0.013103745295666158, 0.01968399215755718, 0.06623800498034273, 0.036115776148757765, 0.009122259565629065, 0.029952388123742173, 0.008906163973733783, 0.042554011568427086, 0.04940778522619179, 0.05527689939896975, 0.022130395884492567, 12.035308292933873, 77.98473971230644, 92.46695341382707, 86.28234795161656, 76.11630657741001, 96.4865140914917, 76.44955607822963, 43.12523133414132, 21.41440885407584, 22.837302650724137, 44.274303572518484, 60.27367033277239, 69.86542919703892, 14.164066978863307, 6.243331202438899, 31.75920132228306, 29.9742751121521, 1.7789723638977324, 0.533346166568143, 0.1016466696081417, 0.677169209080083, 0.005234750935674778, 0.0335307511101876, 0.026628384167062383, 0.054760673349457126, 0.19762198068201542, 0.13159922058028833, 0.20575397860791, 0.05003357093249049, 0.14244333654642105, 0.016295135520132523, 0.09155972408396856, 0.055845959577709436, 0.16329512479049818, 0.5122599580458232, 0.52720743311303, 0.5305952227541378, 0.7396339486752237, 0.2673795739454882, 0.6911704806344849, 1.584196769765445, 0.9163334241935185, 1.5103635830538613, 0.7973250044243676, 2.6347497403621674, 2.476987200123923, 2.510352666888918, 2.390712721007211, 2.356846115418843, 0.8858964602862085, 2.0102191609995703, 2.104962408542633, 2.4032739784036363, 1.4581516704389026, 1.4748907493693488, 0.21117840467819146, 1.1165944039821625, 2.005625750337328, 2.5459469854831696, 2.5605527503149847, 2.227483251265117, 2.3646830320358276, 0.8778279189552579, 1.5196918653590339, 1.8933437296322413, 0.4743068888783455, 0.7060404398611614, 0.37456490099430084, 0.20815903241080896, 0.0798702688355531, 0.2780141175857612, 0.4710650114076478, 0.13830112453017915, 0.38088276769433704, 0.03953117877244949, 0.11674220780176775, 0.2813053924058165, 0.07126303176794734, 0.2273530781801258, 0.10051496819193874, 0.07278681785932609, 0.16514821749712738, 0.051188162727547545, 0.4688993990421295, 0.014584655607385295, 1.1266915478876658, 0.21165422057466848, 11.266737648418971, 19.89965466090611, 21.8563003880637, 16.0871034009116, 31.879328727722168, 67.78643785204206, 58.562308175223215, 25.765520198004587, 16.13716343470982, 40.26467534473964, 64.920715876988, 56.62054027829851, 79.18545096261161, 73.22021402631486, 45.40910768508911, 3.8583355460848128, 0.12962476510022367, 0.04390538191156728, 0.04788849442931158, 0.03752519177006824, 0.0166152666455933, 0.03312868518488748, 0.0499035364815167, 0.026394895178132823, 0.02463956070797784, 0.04591816104948521, 0.06235612649470568, 0.017721706203051975, 0.014661598085824932, 0.03348574727507574, 0.06806126250220196, 0.011743878845923712, 0.04224543419799634, 0.02778190896580262, 0.02724797654497836, 0.04966065147891641, 0.04670683587236064, 0.03345831410427179, 0.05660801547180329, 0.04317054544974651, 0.007035003575895513, 0.04875636785956366, 0.009762894162642104, 0.11604128112750393, 0.04950779789526548, 0.02451010131543236, 0.040349624319268126, 0.018980975595435927, 0.037598015540944676, 0.024508513543488722, 0.06399130768009595, 0.08143807149359159, 0.07201329472341708, 0.12203104900462286, 0.0677114302026374, 0.12415953193392072, 0.1345502236591918, 0.11780283946011748, 0.08646711520850658, 0.07178216534001486, 0.13510810158082417, 0.09408148591007505, 0.10350042727908917, 0.09497399694685425, 0.1180554987596614, 0.13021376063781126, 0.1503397471138409, 0.11763022015137331, 0.13195992979620183, 0.2010680293398244, 0.17218458492841038, 0.21148179125572952, 0.1129928675613233, 0.14501593421612466, 0.0864666063072426, 0.18800580953913076, 0.11855776395116534, 0.1757637078740767, 0.1600774438785655, 0.10503051017544099, 0.11710777532841478, 0.07160267247153179, 0.09940127509513072, 0.09791972102331263, 0.06742312745856387, 0.1253885624131986, 0.11858638455825192, 0.12159563308315617, 0.22955208803926194, 8.481720737048558, 82.58799770900181, 105.69186973571777, 91.2136720929827, 74.31182466234479, 85.7628311429705, 67.28745991843087, 44.18200717653547, 29.222264630453928, 69.34977558680943, 76.69028336661202, 67.54527282714844, 69.69414915357316, 13.8253926719938, 20.945419345583232, 82.71049445016044, 78.80957426343645, 9.971536108425685, 0.8826681535158838, 0.19967427769941942, 1.2268897827182497, 0.44596662532005993, 0.12293286275650774, 0.13534786871501378, 0.249689731746912, 0.4470718502998352, 0.41923199274710243, 0.3641063150550638, 0.25186826341918533, 0.3135625943541527, 0.2035658388797726, 0.18803822994232178, 0.32011968536036356, 0.24751339852809906, 0.19434585076357636, 0.3679514644401414, 0.30965192562767435, 0.24740309587546758, 0.1674322477941002, 0.214453679642507, 0.7242164388298988, 0.3417469034237521, 0.9039281755685806, 0.4301193042525223, 1.4464349448680878, 1.1226284801959991, 0.9088945090770721, 0.8521498739719391, 1.1914403992039817, 0.3470400193972247, 0.8040962410824639, 1.200067239148276, 1.0268327976976122, 0.24631621848259652, 0.38635735107319696, 0.14000332461936132, 0.6928420109408242, 1.3326978193862098, 1.811732685991696, 1.883861392736435, 2.8360764001097, 1.4873068545545851, 0.6180760828512055, 1.9367934209959847, 1.6453756583588464, 0.5397204330989293, 0.9457864037581852, 0.48623938858509064, 0.35815651289054323, 0.20632255024143628, 0.20539145091814653, 0.4502878891570227, 0.6196646147540638, 0.41254568153194016, 0.2447514081639903, 0.17201917166156427, 0.3121974090380328, 0.27934258058667183, 0.6612919239061219, 0.5815839267202786, 0.2705955042370728, 0.21953617834619113, 0.3361386757876192, 1.1570295542478561, 0.17091719007917813, 1.6012260445526667, 2.5350044412272315, 35.045233726501465, 44.04482889175415, 40.970362186431885, 27.634026288986206, 36.071486132485525, 86.1829331261771, 89.7511179787772, 54.285396644047324, 28.453291858945573, 40.89154182161604, 56.29796668461391, 52.20820835658482, 82.15619495936802, 82.94704587118966, 46.49572951453072, 2.5910366688455855, 0.1856243009013789, 0.17351759411394596, 0.16365881956049375, 0.16063009708055428, 0.1252791147146906, 0.13940936220543726, 0.15207742101379804, 0.12058027328125068, 0.14687130680041655, 0.11541883381349699, 0.1637715377977916, 0.09819224782820259, 0.07840938972575323, 0.16754151907350334, 0.14171168580651283, 0.19012083033365862, 0.1115969242528081, 0.11388571108026163, 0.08513063870902572, 0.1577099130621978, 0.09122469063316073, 0.0830493818170258, 0.18039757279413088, 0.1474349115576063, 0.06851058839155094, 0.1721584613301924, 0.1737866196781397, 0.32451222251568523, 0.18770686058061464, 0.14202690603477613, 0.136958561571581, 0.13402068135993822, 0.13952843153050967, 0.178978172530021, 0.08387057203799486, 0.17377421605799878, 0.2063406535557338], [0.05981416468109403, 0.05700700424079384, 0.054001480873141966, 0.03203301737084985, 0.0554741223874901, 0.021016399143263698, 0.04303049921457257, 0.03538433236203023, 0.039036703162959645, 0.06522523718220846, 0.020206667682422057, 0.030995306625430073, 0.05505599893097367, 0.02636114145363016, 0.03753648937812873, 0.021716141773919975, 0.04035862847896559, 0.04486029442133648, 0.018758729931765368, 0.04628410177039249, 0.051733447039233785, 0.027599055652639697, 0.03298685440261449, 0.010185328861033278, 0.03226565310199346, 0.05198492229517017, 0.030449408239551952, 0.024326596608651534, 0.10061255509832076, 0.08444415804530893, 0.033532671364290376, 0.029576143848576715, 0.03545080843780722, 0.03033193347177335, 0.06261664322976555, 6.243380274091448, 48.94840887614659, 72.3051849092756, 61.99739333561489, 60.48713288988386, 40.89200735092163, 31.028775419507706, 24.729707070759364, 35.20688704081944, 50.699521677834646, 59.95866680145264, 50.828063351767405, 25.977092845099314, 9.55709603854588, 47.70164496558053, 75.23325307028634, 18.975066559655325, 0.17948442750743457, 0.15004550718835422, 0.26362236269882744, 0.042607883856232674, 0.1331734082528523, 0.07209704630076885, 0.1316879458193268, 0.04990498176110642, 0.1817752295838935, 0.043251518426196914, 0.09363963069128138, 0.007494660160903419, 0.013967212489140885, 0.0220757093546646, 0.07808467679257904, 0.007596011240301388, 0.06595651472785644, 0.018224219059837714, 0.15158008198652947, 0.45027448130505426, 1.1351687844310487, 1.3086736627987452, 0.41914712158696993, 4.351500877312251, 2.9520344521318163, 2.44250111920493, 1.6161199424948012, 0.4708939663001469, 3.452101298740932, 2.2638392661299025, 2.5254395944731574, 5.118396137441907, 2.784760913678578, 0.5097739685858999, 0.9087880605033466, 1.8776269044194902, 1.9600620695522852, 6.214525708130427, 4.197800644806453, 4.025693765708378, 5.180491319724491, 5.147004910877772, 13.04691389628819, 7.643534353801182, 5.262041023799351, 3.151302925177983, 1.0688387836728777, 0.7697585693427494, 1.0978722657476152, 1.8766615390777588, 0.37509809381195475, 0.5010049619844982, 0.16657451167702675, 0.10828238925231354, 0.3845508194395474, 0.2619914359280041, 0.1528517244649785, 0.1307525581547192, 0.047095521087093015, 0.15359253542763845, 0.0886386443993875, 0.029823965193437676, 0.055460595791893344, 0.08262453747114964, 0.03943226872278111, 0.12602007495505468, 0.0073806086022939, 0.1387486726577793, 0.055163468699902296, 0.6925615317055157, 0.018939715577289462, 0.19439777226320334, 3.035084967102323, 20.02815464564732, 39.87966871261597, 36.483583790915354, 22.503947189876012, 28.257997104099818, 59.589314460754395, 64.64597020830426, 25.600682871682302, 19.88454580307007, 37.22222246442522, 39.7218473298209, 46.816753659929546, 64.52113887241909, 34.59413930347988, 1.4902953399079186, 0.1504595899688346, 0.08553616516292095, 0.02433440654671618, 0.02377218769730202, 0.04901821791593518, 0.05011026235297322, 0.012685397074424794, 0.05357066881177681, 0.004572086427028158, 0.02299942452061389, 0.07819496587451015, 0.01897728436493448, 0.028402374957555106, 0.029247671831399202, 0.03858574539689081, 0.023776096059009433, 0.10880285275301763, 0.050874713475682905, 0.08416010293045215, 0.04941016688410725, 0.02899996583749141, 0.01439855550415814, 0.06724914429443223, 0.03548125091141888, 0.021045825510684932, 0.02708692116928952, 0.02575441918868039, 0.0073870207582201275, 0.12199952426765646, 0.05251087175150003, 0.04161241530839886, 0.023059344251773188, 0.040612407361290286, 0.030669935513287783, 0.008539152015665812, 0.03081429044583014, 0.014482040756515093, 0.04617952934599348, 0.009630374577162521, 0.02821227489039302, 0.01534495409578085, 0.020938116558162228, 0.021845144851665412, 0.009389306352074658, 0.021210526315761462, 0.07679940254560538, 0.005766607463426355, 0.018048659998125265, 0.02493636549583503, 0.06892270342047725, 0.01481230410614184, 0.044021190875875096, 0.047989365445183854, 0.02405457022333784, 0.017518444252865653, 0.02017423540486821, 0.07933970873377152, 0.06287952126669032, 0.021390991185658743, 0.029091975186020136, 0.009133359550365379, 0.061086872459522316, 0.006541014815281544, 0.023203680524602532, 0.06574579567781516, 0.06278259932462658, 0.043192631764603515, 0.033411315376205106, 0.08039231332285063, 0.08083693696452038, 0.26272585509078844, 20.32898211479187, 71.12215682438442, 87.5359627859933, 85.74589143480573, 89.9460288456508, 66.84973730359758, 39.992034980228965, 26.387804337910243, 15.935361691883632, 26.37563977922712, 72.39724159240723, 69.12303502219063, 27.477917637143815, 6.651094053472791, 20.52770059449332, 45.674323899405344, 10.285359314509801, 0.16166137531399727, 0.04466105279113565, 0.340625312179327, 0.08446789320026125, 0.10420944209077529, 0.04589934527341809, 0.21553784289530345, 0.09055452195129224, 0.05633111550871815, 0.1510875334164926, 0.10336636911545481, 0.06185982562601566, 0.04582932724484375, 0.1276495496609381, 0.3379802741110325, 0.40939850040844505, 0.4556855538061687, 0.25205274352005547, 0.6302399901407105, 1.2404470209564482, 4.259970954486302, 2.993429865155901, 4.806559247629983, 10.842999151774816, 11.501981071063451, 7.605641484260559, 4.048970665250506, 4.2358646137373785, 9.375177434512548, 8.163822412490845, 8.24590756211962, 9.740706528936114, 7.79031765460968, 5.127212532929011, 4.939080936568124, 8.014419640813555, 5.9344698786735535, 7.605136871337891, 3.8420172674315314, 9.12277456692287, 8.196111559867859, 9.714900919369288, 18.190013919557842, 16.211698498044694, 18.167216879980906, 7.628189257213047, 9.224324226379395, 4.110936871596745, 4.70944036756243, 4.979047843388148, 2.2250767861093794, 1.3253862517220634, 1.691228015082223, 0.07818452322057315, 0.3301185502537659, 0.23059771050299915, 0.28977611501302036, 0.16284497108842644, 0.17304082826844283, 0.11573773170156137, 0.2518381636057581, 0.08657255955040455, 0.15126171335577965, 0.15278377596821102, 0.10230292832212788, 0.14378146188599722, 0.0428378020546266, 0.2158024851232767, 0.11504384822079114, 0.8842113592794963, 0.07455113782946553, 0.34541134536266327, 1.026326556290899, 12.37943606717246, 33.138265882219585, 30.964758191789898, 28.173998594284058, 42.50187717165266, 59.74124377114432, 46.428116594042095, 19.48802079473223, 22.95856956073216, 55.518802642822266, 66.19514056614467, 66.31303065163749, 74.70729528154645, 54.03192983354841, 5.952543445995875, 0.15961363805191858, 0.026158318854868412, 0.019451877202040384, 0.045863084362021515, 0.02832545792417867, 0.052701750437596014, 0.02529921888240746, 0.029690134339034557, 0.030006996622042995, 0.03160865478483694, 0.042644477249788384, 0.02690413740596601, 0.045053232461214066, 0.025269475299865007, 0.05886018515697547, 0.013927689520642161, 0.03553109948656388, 0.05605951151145356, 0.04221526653106723, 0.02430310911898102, 0.08101215506238596, 0.06246099408183779, 0.029559021017381122, 0.004974906374367752, 0.04460398799606732, 0.022787979438102672, 0.022151196375489235, 0.019667206897533367, 0.021815397876447866, 0.010283589213421302, 0.0240887022311134, 0.009249379708697754, 0.05388476945725935, 0.02010707909773503, 0.06197242172701018, 0.02344657400889056, 0.16754921366061482, 0.14390348962375096, 0.09485946702105658, 0.09334564182375159, 0.10637949207531554, 0.08682788549257175, 0.14205596090427466, 0.1466760379927499, 0.09007495375616209, 0.15041252677994116, 0.1039974745362997, 0.09964999889156648, 0.12374231432165418, 0.15070678027612822, 0.11835011866475854, 0.09531253163835832, 0.19234172973249639, 0.06748604122549295, 0.10563689656555653, 0.09447485980178628, 0.16888708115688392, 0.12831678028617585, 0.10189894214272499, 0.11078731662460736, 0.108000926141228, 0.15427926714931214, 0.12198716135961668, 0.0580167593434453, 0.19044141098856926, 0.14676078701657908, 0.28954020195773666, 0.1498162437762533, 0.2114439561430897, 0.16918646437781198, 0.23480156064033508, 15.476125717163086, 81.52073356083461, 97.74034432002476, 84.85146372658866, 86.79233877999442, 57.21799503053938, 40.04454946517944, 36.084760665893555, 50.62805598122733, 70.5690107345581, 84.30482809884208, 73.6387665612357, 39.00909417016165, 14.835341998508998, 62.44382899148123, 109.82597841535295, 33.480176312582834, 0.37621116265654564, 0.3147853415991579, 0.9140065376247678, 0.26942701265215874, 0.22807765858513968, 0.16375077462622098, 0.4861141581620489, 0.2808551165674414, 0.34991038537451197, 0.2592793585998671, 0.1541065935577665, 0.09414906121258225, 0.1006018885278276, 0.16991612022476538, 0.20665747512664112, 0.28843630690659794, 0.25316757655569483, 0.16903319688779966, 0.3921885995992592, 0.9413293514932904, 2.8250882583005086, 3.4562856342111314, 3.5031729468277524, 9.049966130937849, 6.931518137454987, 6.808271425110953, 4.681932883603232, 2.635492763348988, 7.81066632270813, 6.533719003200531, 6.826318936688559, 10.493228571755544, 4.931058807032449, 2.5286060188497816, 1.9620182045868464, 6.116780187402453, 3.6926092846052985, 12.177267806870596, 10.781357339450292, 15.215200015476771, 14.25294746671404, 11.407902462141854, 25.11288980075291, 19.025369780404226, 13.29310246876308, 9.627421362059456, 4.316727748938969, 2.385252956833158, 4.302552989550999, 5.516649075916835, 1.8388557391507285, 1.109515709536416, 2.127119128193174, 0.39927641355565613, 1.5310227487768446, 0.6509954535535404, 0.34495857251541956, 0.6485098983560289, 0.3132148044449942, 0.22659299682293618, 0.4754777689065252, 0.15188327857426234, 0.16692155519766466, 0.20884526201656886, 0.3933635779789516, 0.4007552670581, 0.16564117318817548, 0.45778597252709524, 0.415815107524395, 1.6278145206826073, 0.18134642259350844, 0.6271647065877914, 5.157107591629028, 30.50043092455183, 60.79028974260603, 51.211596965789795, 33.860906328473774, 42.8014418057033, 82.00127792358398, 89.49692508152553, 34.92674609592983, 27.685673986162456, 49.11927202769688, 53.66630172729492, 62.94552367074149, 83.5645809173584, 58.66698973519461, 3.7838504229273116, 0.38979195963059154, 0.14651145253862652, 0.10147398244589567, 0.1899546163954905, 0.11443563657147543, 0.10016122074531657, 0.17407885113997118, 0.21500056529683725, 0.11270611187709229, 0.08328623125063521, 0.2293737418949604, 0.18844528310000896, 0.13121548188584192, 0.10707672073372773, 0.1368785894342831, 0.10688158763306481, 0.263010595526014, 0.12623274140059948, 0.08943393493869475, 0.09885149888162102, 0.1678008958697319, 0.14000561806772435, 0.12533046624490193, 0.20203264829303536, 0.13185014283018454, 0.11837742291390896, 0.08317973517945834, 0.1296386072146041, 0.17308844785605157, 0.1307811244790043, 0.12155604735016823, 0.09071224741637707, 0.11177830344864301, 0.11990080188427653, 0.15538223939282553, 0.1117952736094594], [0.008675965879644667, 0.02661009255929717, 0.042306526098400354, 0.029582474580300704, 0.04008124675601721, 0.023777936585247517, 0.015090586584327477, 0.03846659464761615, 0.03654215059110096, 0.03782187442162207, 0.0412712139742715, 0.023696291859128644, 0.08080221632761614, 0.05191704165190458, 0.032505525409110954, 0.06230494459824903, 0.05944681939269815, 0.018025002874700085, 0.015379486439217414, 0.056084200008107085, 0.05226461782253214, 0.024314628947260122, 0.017264926606523137, 0.018795365733759742, 0.037237011162298064, 0.02704634647151189, 0.019947477483323643, 0.005741781987515944, 0.06601765751838684, 0.08484250559870686, 0.06203317775257996, 0.04791460106415408, 0.07486508919724397, 0.31991761763181004, 11.896716918264117, 59.10439968109131, 71.88824435642788, 64.51244667598179, 56.45808792114258, 50.12351254054478, 23.667461259024485, 49.26970747538975, 43.34347425188337, 59.07521029881069, 58.03641292027065, 33.81399209158761, 19.01648129735674, 27.365744182041713, 71.59691333770752, 46.70519685745239, 2.56677269084113, 0.18566198673631462, 0.12901005308542932, 0.20742671670658247, 0.07897953556052276, 0.06452163029462099, 0.17522055416234902, 0.13126209724162305, 0.010602411614464862, 0.04675062173711402, 0.026902458031794856, 0.07965169913534607, 0.06333867912845952, 0.07951029922280993, 0.05537709187982338, 0.20493907162121364, 0.2906171455979347, 0.12881520496947424, 0.21245770103165082, 0.23931813399706567, 2.1988720893859863, 3.1172055091176714, 6.6124090892927985, 6.737500982625144, 2.010917889220374, 5.270492204598018, 5.883522646767752, 5.505924097129276, 2.6161607035568784, 4.008836133139474, 5.449207254818507, 6.200086482933589, 9.663287963185992, 4.447674368109022, 13.078615052359444, 5.693077734538487, 5.283818415233067, 6.016918505941119, 13.318578038896833, 19.855976547513688, 15.266753911972046, 15.826660599027361, 10.319806746074132, 5.746084673064096, 8.668162618364606, 10.651117699486868, 1.8946043934140886, 5.791229290621621, 1.0654261325086867, 0.8786599114537239, 3.327819739069257, 1.3381961243493217, 0.6828546811427388, 0.8450851302061761, 0.4703175915139062, 0.09292313163833958, 0.2770702482334205, 0.18788557313382626, 0.05099623231217265, 0.2569764650293759, 0.08465930792902197, 0.1309178357145616, 0.13954083515065058, 0.10785099025815725, 0.013055237675351756, 0.04876645767529096, 0.09413578906761748, 0.04653206221493227, 0.09051609651318618, 0.2538084935929094, 0.02405293325760535, 0.24636960561786378, 0.12529359465198858, 0.2750041091016361, 0.11576476453670434, 0.3021828021321978, 7.047645551817758, 49.44399956294468, 82.7674001966204, 39.18095438820975, 27.526845114571707, 41.660339151109966, 54.225756781441824, 42.90432030814034, 19.430680785860332, 20.68213473047529, 39.43179477964129, 50.49641193662371, 60.98743098122733, 40.3863000869751, 6.788476875850132, 0.021376163499163728, 0.02189316477493516, 0.04957284226215311, 0.056549983764333386, 0.054411105678549836, 0.04451385818954025, 0.018244673497974873, 0.051360663292663436, 0.034178884367325475, 0.03955043559627874, 0.012975724397360213, 0.030360082497021983, 0.04332529553877456, 0.027131656983069012, 0.0525238894458328, 0.008515701845421322, 0.051309701920087845, 0.047921684969748767, 0.004428734454060239, 0.018338823624487435, 0.03231631252648575, 0.05102566037593143, 0.02488140924833715, 0.04619130871391722, 0.03383991202073438, 0.02213507777612124, 0.025392776987116252, 0.020752944351573075, 0.033434660373521705, 0.02781611561243023, 0.021968592423945665, 0.038142757024616, 0.06032728643289634, 0.03568030594448958, 0.0403762466407248, 0.056725252752325366, 0.04673812312207051, 0.010955968223113035, 0.03720652797658529, 0.03970222048727529, 0.03833521330463035, 0.015151839636798416, 0.05560608048524175, 0.0397684828245214, 0.018995689627315317, 0.01446627838803189, 0.01718258298933506, 0.010864747671543487, 0.024454042448529174, 0.017237359425053, 0.05036282665761454, 0.026703421658437167, 0.015196388853447778, 0.046229486486741474, 0.059243550657161644, 0.0253103689091014, 0.029354371463081667, 0.028768592181482484, 0.005181215370872191, 0.0231355216819793, 0.03274772848401751, 0.03569632615627987, 0.028281427786818573, 0.04892208307449307, 0.08748764544725418, 0.021324764471501112, 0.05126264551654458, 0.05834550277463027, 0.8741039016417095, 26.236712285450526, 82.0507629939488, 85.27240644182477, 90.68514347076416, 88.59126213618687, 73.34969370705741, 30.838776929037913, 34.68275662830898, 19.774722576141357, 45.760967935834614, 74.47180693490165, 51.847471782139365, 16.75664918763297, 15.936287539345876, 35.816786016736714, 27.495765822274343, 0.6991502695849964, 0.19938045846564428, 0.09559522289782763, 0.13294109143316746, 0.06607483766440835, 0.22604596189090184, 0.1540578476020268, 0.09548177862805979, 0.03933514661288687, 0.04898978051330362, 0.030343889258801937, 0.3292352333664894, 0.18695334744240555, 0.1792046403778451, 0.2674585282802582, 0.2855610011943749, 0.3977924846112728, 0.27243311277457644, 0.9008113656725202, 0.8017006867698261, 0.9182464586836951, 0.7404511219688824, 1.3747997773545129, 2.633989781141281, 2.883400146450315, 4.497948927538736, 9.700697932924543, 9.076264194079808, 8.34027017865862, 10.894790155547005, 11.469796146665301, 11.192799261638097, 13.83880182674953, 6.9483232242720465, 14.423189623015267, 10.633849688938685, 5.962046410356249, 7.461864147867475, 17.140071630477905, 20.354586226599558, 19.71710463932582, 16.231511286326818, 13.843493597848074, 14.35608913217272, 19.510418312890188, 17.65158585139683, 5.441148212977818, 5.007458158901759, 4.857138225010463, 2.565401724406651, 2.7450856140681674, 2.8462898177759985, 2.037978082895279, 1.1714279587779726, 1.1719028247254235, 0.7173831569296973, 1.7197950993265425, 1.1814171884741103, 0.3567139745822975, 0.7422622133578572, 0.39947948551603724, 0.3848886213132313, 0.4050430384065424, 0.3255062491766044, 0.12274313079459326, 0.09691339252250535, 0.05371591601786869, 0.05489640749458756, 0.13965805886047228, 0.3734451825065272, 0.060392215448830805, 0.29897078020232065, 0.1117319187947682, 0.4296107829681465, 0.06647010466882161, 0.1408866686480386, 2.3612545302936008, 39.21439606802804, 64.09877177647182, 36.02539873123169, 37.45796094621931, 47.55285276685442, 31.78486101967948, 20.890717915126256, 14.764901161193848, 29.167811598096574, 60.859076908656526, 71.09311335427421, 74.38717092786516, 58.515539850507466, 17.89916753768921, 0.03114042490986841, 0.1435527955847127, 0.017904181232942, 0.070191462125097, 0.01663472702992814, 0.027725266558783393, 0.02443698068548526, 0.018566733359226158, 0.03810254025406071, 0.05759258674723761, 0.03432114941201039, 0.04452755781156676, 0.018266805613945638, 0.0509723614502166, 0.031326896511018276, 0.030656195179160153, 0.06625216600618192, 0.020213617577350566, 0.039595235870884996, 0.01190861442591995, 0.02924764808267355, 0.007317763537035457, 0.09466989790754658, 0.031059384079916135, 0.05280761207853045, 0.02926021794389401, 0.06640137585678271, 0.07076870543616158, 0.059133342999432764, 0.02342035371943244, 0.09158749652228185, 0.03817271773836442, 0.02790753124281764, 0.07669570882405553, 0.03253689408302307, 0.33158049466354506, 0.1389444571520601, 0.12392642801361424, 0.14299794392926352, 0.09043371557657208, 0.20876816686775002, 0.07590216890509639, 0.15026622105922016, 0.09004971903881856, 0.10560938197055034, 0.14477065737758363, 0.07366877089121512, 0.2403666063078812, 0.24121341801115445, 0.14471256120928697, 0.13615179700510843, 0.2545665257743427, 0.13348491010921343, 0.26092320467744556, 0.16202342802924768, 0.20475940911897592, 0.10289239204887833, 0.11949478009981768, 0.11283991219741957, 0.22820671594568662, 0.14206364192068577, 0.147025307108249, 0.1317017607923065, 0.15302545657115324, 0.23911793902516365, 0.19357508926519326, 0.11500461532601289, 0.13432450219988823, 0.65782466424363, 23.800719022750854, 100.93254130227226, 96.52720969063895, 87.69800867353166, 79.80522332872663, 61.351294245038716, 33.542553765433176, 65.34012304033551, 58.49330561501639, 89.67116505759103, 89.36274147033691, 49.87499632154192, 27.139417035239084, 36.0513676234654, 97.7270941053118, 69.88421712602887, 5.067910960742405, 0.32197754138282364, 0.35269536450505257, 0.5807273441127369, 0.2056262104638985, 0.36987798820648876, 0.4559560450060027, 0.39355818182229996, 0.18831083817141397, 0.14514234529009887, 0.14387683676821844, 0.24383693294865744, 0.1826046843613897, 0.42354956535356386, 0.3940595920596804, 0.7773856286491666, 0.8109897768923214, 0.32714993240577833, 1.1550433465412684, 3.4077238057340895, 4.445554299013955, 8.263707109860011, 15.448056731905256, 13.842988116400582, 6.369376301765442, 12.387548957552228, 12.516865355627877, 12.727890832083565, 10.663384744099208, 14.466180733272008, 14.78484422819955, 14.651966878346034, 20.14978459903172, 12.114649772644043, 21.318629673549108, 17.05273277418954, 13.914097717830114, 12.242180483681814, 27.868649584906443, 40.49524436678205, 31.982801301138743, 28.070664984839304, 21.800051246370586, 17.131181410380773, 19.48128972734724, 21.052343436649867, 8.301605190549578, 12.390693017414637, 4.523570844105311, 2.778167724609375, 5.590332550661905, 3.7173057879720415, 3.58708547268595, 2.649485783917563, 0.9855300996984754, 0.3793124205299786, 1.4951797063861574, 0.5882335699030331, 0.18321451092404978, 1.3323699512651987, 0.4336789261017527, 0.2224531461085592, 0.3565462407256876, 0.22890593271170342, 0.11391311032431466, 0.2526963475559439, 0.1562853152198451, 0.18161607240991934, 0.3463608872677599, 0.7302408527050699, 0.1487427063818489, 0.4074107999248164, 0.5199046049799237, 0.7273536047765187, 0.16862712082053932, 0.6094293754015649, 10.101075717381068, 68.91478361402238, 105.58588886260986, 56.008007935115266, 42.35002081734793, 59.606816973005024, 76.43902955736432, 60.15472412109375, 26.807677030563354, 29.126299585614884, 54.8429513658796, 66.74046993255615, 79.1432615007673, 64.60875565665108, 13.039124965667725, 0.079787487563278, 0.1877651195973158, 0.12901089446885244, 0.162665973550507, 0.1374676799667733, 0.14810415064649923, 0.10474614293447562, 0.13303638489118644, 0.17312077326434, 0.2087166660598346, 0.09973801845418555, 0.126106357468026, 0.11217308190784284, 0.19961292456303323, 0.11427576015038149, 0.0926104559163962, 0.1223495262009757, 0.20309254713356495, 0.12463766842016152, 0.046178830454924276, 0.05382630009470241, 0.11730024857180459, 0.20698151631014688, 0.10930217988789082, 0.22435996521796497, 0.11779450705008847, 0.10397356974759273, 0.12357874667005879, 0.12715537260685647, 0.11191687387015138, 0.1409867661339896, 0.12105843690889222, 0.22504923466060842, 0.18022659554013185, 0.08151912250156913], [0.024017822463065386, 0.024230168300813863, 0.021924445239294852, 0.04276765849707382, 0.023753570392727852, 0.01172337691033525, 0.012382050360819059, 0.012309751606413295, 0.06165921674775226, 0.058849606796034744, 0.022274850900950174, 0.02232534747703799, 0.024210517926673805, 0.03788766856970532, 0.04079156435493912, 0.03902227072311299, 0.01753778080455959, 0.0889197818136641, 0.007791555702819356, 0.028481073145355498, 0.011539376872990812, 0.03797793408323612, 0.04277340568868177, 0.06662861044917788, 0.022981931887833134, 0.035475147488926134, 0.03532467895586576, 0.06414019861923796, 0.024479265291509882, 0.09243327006697655, 0.05994113215378352, 0.04627739105905805, 0.9266345628670284, 20.085604088647024, 55.949104581560405, 56.498755727495464, 55.00368751798357, 49.79083974020821, 39.94793128967285, 26.243222747530254, 46.456843921116416, 69.28468486240932, 83.88914516993931, 52.68576151984078, 30.130748544420513, 44.64222805840628, 64.53337465013776, 40.65648078918457, 10.76701625755855, 0.21630910650960036, 0.02416346830848072, 0.05637267577861037, 0.05733731508787189, 0.025736782367208173, 0.051190554563488276, 0.06837359217128583, 0.29767678678035736, 0.0734101336981569, 0.06382788252085447, 0.10387901589274406, 0.07123416010290384, 0.04551163375643747, 0.08361563286078827, 0.44439413398504257, 0.19610388071409293, 0.17946841408099445, 0.7370485131229673, 1.7811239170176643, 2.265157686812537, 0.9256120920181274, 2.9329896569252014, 1.3543651252985, 6.364876474652972, 3.8683153305734908, 7.980432527405875, 13.631156648908343, 24.690661668777466, 11.99732162271227, 4.3199708206312994, 8.34856459072658, 6.964363140719278, 9.733989357948303, 9.055981533867971, 10.930637649127416, 36.92826502663748, 12.899453146117073, 16.505885226385935, 11.717039108276367, 20.609689337866648, 15.777406556265694, 10.446184924670629, 23.81937493596758, 10.372244800840106, 15.397774355752126, 12.451215301241193, 13.037366202899388, 16.91255807876587, 4.285383990832737, 22.97035023144313, 6.212443419865199, 5.580377953393119, 7.940570712089539, 1.9751507341861725, 2.164633103779384, 0.9209891515118735, 0.1763182066913162, 0.21301027280943735, 0.11672410448747021, 0.32033722368734224, 0.14102973097137042, 0.041934997641614506, 0.12273696969662394, 0.10862968383090836, 0.07388132198580674, 0.0339953304667558, 0.16920041505779537, 0.024046626274607012, 0.05323516038645591, 0.04682398494333029, 0.09771076616431985, 0.10233688221446105, 0.41841970490557806, 0.06416588116969381, 0.04045084138799991, 0.15833211610359804, 0.01966965471261314, 0.01535254011728934, 0.4292022506041186, 22.28446749278477, 94.82340022495815, 73.21901893615723, 55.257543427603586, 56.627700396946494, 63.9587516784668, 53.94912120274135, 36.973219871520996, 19.875139679227555, 30.090435096195765, 39.6967191696167, 57.35282482419695, 57.54295185634068, 21.34033063479832, 0.10672712592141968, 0.0714893639087677, 0.02402131013306124, 0.0481107350039695, 0.08971412240394525, 0.006257957146902169, 0.029249629404928004, 0.03721960334639464, 0.006664473413755851, 0.02878091098474605, 0.03737149341031909, 0.010387542474615787, 0.01822308760269412, 0.05544831430805581, 0.03134022293878453, 0.0801458354773266, 0.048822959286293814, 0.01256779847400529, 0.03858906004045691, 0.04731879982032946, 0.036250808010143895, 0.05101514647581747, 0.025673391929428493, 0.03934793021263821, 0.039139223018927236, 0.05202921027583735, 0.03980164283088275, 0.02821176259645394, 0.0512349239683577, 0.0366275815426239, 0.029901348719639436, 0.03982695218707834, 0.023561180269877826, 0.03583290847018361, 0.015752092070345367, 0.0309960971187268, 0.02390442229807377, 0.05365053577614682, 0.05864329143826451, 0.014464008688394512, 0.014373191865161061, 0.04292145863707576, 0.042850300669670105, 0.027577406992869716, 0.024322932519550835, 0.03804816924301641, 0.026016688240425925, 0.038906651748610396, 0.021934920123645237, 0.014847118041611143, 0.006903482285062117, 0.040959807112812996, 0.030247700134558336, 0.01533550040663353, 0.00752587616443634, 0.06584573710071188, 0.022880236451913203, 0.07294123885887009, 0.024216977580051337, 0.041367009548204284, 0.04156157946480172, 0.03557258511760405, 0.0651078438386321, 0.12603331995861872, 0.006741705541831574, 0.014521171871040548, 1.6497519378151213, 41.045642444065635, 77.24420765468052, 72.10372189113072, 84.91249670301164, 73.5406927381243, 46.85036557061331, 21.582998207637242, 17.894225631441387, 48.317206723349436, 72.86011668613979, 66.04704666137695, 42.15900788988386, 25.732554469789775, 44.34865624564034, 28.347894634519303, 4.654563495091029, 0.28401410420026096, 0.09869781748524734, 0.024464831155325686, 0.11357933216329132, 0.013706615178047546, 0.08945887788598027, 0.1367222142538854, 0.47742597865206854, 0.2926326388759272, 0.4263676569930145, 0.3660465180873871, 0.2726657417203699, 0.2681492769292423, 0.11179865949920245, 0.20887756028345653, 0.2789812199771404, 0.05686523452667253, 0.2628334436033453, 0.13564277360481874, 0.5032844596675464, 1.1211780437401362, 0.9048600484217916, 1.2598412888390678, 1.0537713978971754, 1.3792024382523127, 2.4508265810353413, 1.306451867733683, 4.381610895906176, 6.772421760218484, 6.025816977024078, 11.813765849385943, 11.990746021270752, 14.733830554144722, 14.709534440721784, 18.887262174061366, 33.794311319078716, 10.958419152668544, 17.77169762338911, 15.85134928567069, 21.324203865868704, 17.518824883869716, 17.436834403446742, 28.59340054648263, 18.329955850328716, 17.184552260807582, 12.094945549964905, 12.163743138313293, 3.7761965479169572, 1.4750380728925978, 3.3201233063425337, 0.8392350184065955, 2.2013217636517117, 0.9759298605578286, 1.0744179700102126, 1.3950341258730208, 0.26120574665921076, 1.4353950172662735, 0.9604503597531999, 0.3327035244022097, 0.7218718017850603, 0.5695801536951746, 0.41759262500064714, 1.0763301359755653, 0.9953438873801912, 0.24816658347845078, 0.41691433425460545, 0.5922629822577749, 0.458164812198707, 0.1636103314480611, 0.04047978769189545, 0.10020176321268082, 0.20863526899899754, 0.5377763488462993, 0.12232416256197862, 0.04485920876530664, 0.20969389219369206, 0.05093934054353407, 0.0574137724137732, 0.28717485602412907, 13.341928328786578, 63.86309582846505, 63.803890228271484, 62.15988390786307, 59.90420682089669, 53.187122685568674, 31.09923015322004, 15.712790046419416, 19.1658866746085, 54.098201751708984, 59.47245270865304, 71.71697126116071, 70.54484489985875, 37.82532262802124, 0.9196119968380246, 0.014288989062021886, 0.042324653161423545, 0.03542722934590919, 0.07940045118864093, 0.07607746842716422, 0.07815813499369792, 0.040779126808047295, 0.048882690723985434, 0.03982830247176545, 0.02313717221841216, 0.04233223579025694, 0.02079139184206724, 0.05882481312645333, 0.04955316135393722, 0.08378863214914288, 0.04812183244419949, 0.04028800655422466, 0.063840272570295, 0.02124816465324589, 0.042834606154688766, 0.016295866641615118, 0.01889504083166165, 0.05195038825539606, 0.03497513842635921, 0.005881689971179834, 0.03993312256144626, 0.012764454037616295, 0.06260688589619738, 0.011474120463909847, 0.061368471277611594, 0.030547945094960074, 0.0460024554548519, 0.010606918783326234, 0.11747968037213598, 0.10398802254348993, 0.09651925188622304, 0.16335664077528886, 0.23460847671542848, 0.151632641309074, 0.15506838980529988, 0.1607496685215405, 0.13422888304506028, 0.18527383756424698, 0.07460236722337348, 0.08241734680320535, 0.10075700163309063, 0.1283768034939255, 0.14313689433038235, 0.06793943832495383, 0.17201193847826549, 0.14787203738731997, 0.058299104550055096, 0.10388551625822272, 0.09309099441660301, 0.11054487606244427, 0.0975740956408637, 0.12861061309065136, 0.14851535643850053, 0.11814426471080099, 0.1078136165493301, 0.12511086517146655, 0.14784433958785875, 0.23241618435297692, 0.1730889906840665, 0.0993442035147122, 1.1647159989391054, 42.42326872689383, 92.94979763031006, 78.83547714778355, 79.9802553994315, 73.15633923666817, 52.761465617588584, 39.32647051130022, 61.15510490962437, 92.65267181396484, 120.67357553754533, 73.54363877432687, 41.98366315024239, 55.08651351928711, 85.64225210462297, 63.78952135358538, 18.799923317773, 0.22199079234685215, 0.19177246599325112, 0.5021076085312026, 0.16491041811449186, 0.1460712325892278, 0.1745977947222335, 0.2656712127583367, 0.4455134996346065, 0.3413727049316679, 0.29679626545735766, 0.23386843928268977, 0.3315546560500349, 0.14265482234103338, 0.1641868283706052, 0.7223934052245957, 0.679517103093011, 0.7474725480590547, 2.3419246418135504, 4.228863000869751, 7.427267330033438, 7.212152404444558, 9.56519763810294, 8.570351089750018, 17.25915159497942, 11.642773287636892, 24.633035046713694, 30.75648593902588, 39.73400667735508, 20.82323006221226, 13.974603499685015, 22.7184693472726, 16.35439191545759, 20.38292966570173, 19.33022199358259, 22.25653052330017, 53.97852945327759, 25.702473981039866, 29.59861033303397, 23.855632373264857, 34.709865025111604, 29.621994495391846, 22.27901315689087, 35.62342459814889, 22.126814603805542, 28.01712042944772, 19.301274061203003, 24.242888484682354, 41.35682099206107, 10.531132732118879, 37.76338638578142, 17.33924174308777, 13.043871453830175, 16.559900522232056, 6.663609930447169, 5.758303080286298, 3.7551339524132863, 0.9632372387817928, 0.6478258807744298, 0.21614415464656694, 0.4304121328251702, 0.2939525251942021, 0.28048032096454073, 0.4166828995304448, 0.5854393626962389, 0.21397988578038557, 0.3218179228050368, 0.4121078907379082, 0.3039170019328594, 0.24735747118081364, 0.19537281351430075, 0.18585445997970446, 0.6602828609091895, 0.7669875951749938, 0.17523244209587574, 0.20321537554264069, 0.4593853067074503, 0.15940910045589718, 0.2188810392149857, 0.3406262621283531, 27.911823953901017, 116.11152730669293, 93.54076276506696, 72.47433185577393, 77.25300407409668, 88.2603680746896, 74.00858443123954, 52.04504380907331, 28.65832277706691, 43.9183543069022, 56.202706881931846, 74.92607321058, 81.7570834841047, 35.41168172018868, 0.34675590321421623, 0.12473370826670102, 0.1890213457601411, 0.09981867591185228, 0.2230976458106722, 0.14757654895739897, 0.12821905767279013, 0.20588538369962148, 0.13726688788405486, 0.1371067807610546, 0.08331933697419507, 0.11573541111179761, 0.10734578701002256, 0.21318916178175382, 0.15838949302477495, 0.19013909649636063, 0.15021967355694088, 0.12070568012339727, 0.14978805743157864, 0.11330216417887382, 0.12034395310495581, 0.11709056768034186, 0.0879266643896699, 0.12156119064560958, 0.16514988669327327, 0.18777805247477122, 0.09258006433291094, 0.0760488546054278, 0.18471228198281356, 0.15171437763742038, 0.1350316306842225, 0.19976358647857392, 0.11935031999434743, 0.14740656236452715], [0.07543053956968443, 0.04863961573157992, 0.05073003963168178, 0.0519895261552717, 0.05038799012878111, 0.10052675434521266, 0.059407844341226985, 0.04483556181990674, 0.020605452890907015, 0.02579015084276242, 0.022653461566993167, 0.0499219620999481, 0.024010351792510067, 0.054592006507196596, 0.03670994212318744, 0.030835555733314583, 0.028640830822821175, 0.05422398268378206, 0.03759701130911708, 0.06749634138707604, 0.010686715349688061, 0.050543808910463534, 0.0306673672582422, 0.09040873191718544, 0.0166980767556067, 0.0601908058992454, 0.05128644513232367, 0.026801268104463816, 0.02844376050468002, 0.02603094426116773, 0.03351906334449138, 1.6695009980882918, 26.048577649252756, 60.156509808131624, 66.86604472569057, 68.75795582362584, 47.67091308321272, 39.11140292031424, 37.6330555507115, 48.247488498687744, 62.9545841217041, 42.252172810690745, 104.76279830932617, 78.45579978397915, 55.09523350851876, 72.44999231610979, 20.64584255218506, 1.0821480580738612, 0.3347607882959502, 0.12623882107436657, 0.16711771967155592, 0.017468894233128855, 0.11387454239385468, 0.06251738712723766, 0.22555316904825823, 0.08739374977137361, 0.0601870400298919, 0.043182267142193656, 0.0320154195651412, 0.09246081858873367, 0.023906566468732696, 0.5324017001049859, 0.37468684730785234, 0.3268216300223555, 0.8405190780758858, 1.052169946687562, 0.545476635651929, 0.20746358829949582, 0.5125673072678703, 1.1314655031476701, 1.8063029944896698, 2.307147822209767, 1.7222808173724582, 1.727278960602624, 1.467221892305783, 2.297046661376953, 9.086717758859907, 8.296660678727285, 7.3515510729381015, 8.364371742521014, 13.544129593031746, 14.62433910369873, 27.58776691981724, 23.61805956704276, 23.070593629564556, 26.207335301807948, 18.09172817638942, 14.155069061688014, 18.687011616570608, 14.889463254383632, 20.233871698379517, 19.67843270301819, 15.75930997303554, 20.97866473879133, 13.677168488502502, 7.705989973885672, 3.7435895204544067, 0.7104664423636028, 2.4157234132289886, 1.4750890987260001, 0.48986352554389406, 1.811398303934506, 1.9732851428644997, 0.5461274864418166, 3.0298848918506076, 3.6143436900206973, 3.281170402254377, 4.129275773252759, 2.201225574527468, 0.41736930555530954, 0.3210364947361605, 0.892239405640534, 0.5920996995908874, 0.4572814681700298, 0.27188995906284874, 0.10194622924817459, 0.06274511705019645, 0.07633342540689877, 0.11935179920068809, 0.20653115904756955, 0.028117383464372585, 0.011243640777787991, 0.1167752660278763, 0.27420007224593845, 0.041046031950307746, 0.12487731341804777, 0.2721053532191685, 0.15987173920231207, 0.18488912177937372, 4.443954042025974, 55.665017059871126, 113.25017574855259, 103.15917491912842, 64.17388180324009, 49.511101790836875, 50.20088073185512, 33.74153627668108, 21.578622579574585, 26.25913064820426, 39.39459759848458, 53.815573351723806, 60.705966404506135, 29.756136417388916, 0.20407030252473696, 0.02218549292800682, 0.0596415318016495, 0.09777346958539315, 0.05222915079710739, 0.03720106576968517, 0.05996877567044326, 0.032752152532339096, 0.03193151531741023, 0.04660647375775235, 0.05445122066885233, 0.024917156169457094, 0.03530430933460593, 0.029816721832113605, 0.0032722720227736446, 0.025348962284624577, 0.04292951624042221, 0.033498802288834534, 0.04203086785439934, 0.14150588613535675, 0.02868358531434621, 0.02635128064347165, 0.020083469471761158, 0.0037849132869658725, 0.01929219246708921, 0.024627901780019914, 0.02393041697463819, 0.03624178010172077, 0.016002183114843707, 0.009247963266846324, 0.029624811772789274, 0.03528298297896981, 0.056866452497031005, 0.07259591203182936, 0.028128402873075435, 0.019803575472906232, 0.02787082419464631, 0.06787559496504919, 0.019869912449004393, 0.10577484952019793, 0.045221356475459676, 0.08626523068440811, 0.06454450371009962, 0.07973354402929544, 0.015092625582058514, 0.0029821262079557137, 0.06608175872159855, 0.01925475599377283, 0.034997044929436276, 0.04167188211743321, 0.02242358068802527, 0.04863761744594999, 0.050898099185100625, 0.07535607035138778, 0.04013778568644609, 0.03308913337865046, 0.04753500821867159, 0.028542103977607827, 0.08731198630162648, 0.06410872816507306, 0.0948066905673061, 0.050571391358971596, 0.059630539534347396, 0.0641878724896482, 5.358577557972499, 48.228888171059744, 82.32915646689278, 88.57614980425153, 103.17677470615932, 73.31366034916469, 42.88284690039498, 23.981245381491526, 33.46135016850063, 58.01813220977783, 48.81860957826887, 113.69408920833042, 84.23545728410993, 40.26321622303554, 46.114384583064485, 12.74776702267783, 0.6181587555578777, 0.15085023614977086, 0.20842341679547513, 0.03755383612588048, 0.035594729107937643, 0.1256950973932232, 0.23992903264505522, 0.4984134467584746, 0.8009925133415631, 0.4332316629588604, 0.5638637404356683, 0.21611043145614012, 0.3201688384371144, 0.17359732197863714, 0.3167503790131637, 0.22480287216603756, 0.2476694615823882, 0.8125043756195477, 0.7150092614548547, 0.28706088928239687, 0.760816672018596, 1.7813682981899805, 2.533058294228145, 4.400416195392609, 4.810191418443408, 4.229824892112187, 3.852208971977234, 3.7918725524629866, 2.1665334360940114, 0.870269201695919, 1.0809453683240073, 1.4727197630064828, 0.46098040682928904, 4.622924438544682, 10.613080654825483, 27.378171035221644, 28.51118424960545, 26.481561592647008, 26.1793566431318, 21.248534509113856, 18.69296795981271, 20.50730242047991, 15.880074875695364, 25.16175648144313, 27.46053671836853, 17.904783419200353, 12.625866089548383, 2.585236442940576, 1.3392333601202284, 1.39992869751794, 0.39017595616834505, 1.2848633804491587, 1.2226609353508269, 1.322309393967901, 1.3686371594667435, 0.7375547545296806, 1.0247838390725, 1.1503327935934067, 2.531569642680032, 1.4406034520694186, 0.7825388578431947, 0.6256899514368602, 1.313651504261153, 0.8900658137031964, 1.139822774699756, 0.886848689189979, 1.347204463822501, 1.6525217720440455, 1.5440429129770823, 0.7406165216650281, 0.6619096621870995, 1.0064627421753747, 0.45694491480078014, 0.06710357139153139, 0.06883474492600986, 0.15759343574089663, 0.3094635100236961, 0.01713465975730547, 0.014051759648802025, 0.2941826028483254, 0.4552316681614944, 0.2035515217908791, 1.1983077164207185, 29.74075310570853, 91.94286469050816, 108.65733310154506, 79.71757180350167, 54.628550801958355, 39.22744131088257, 15.394387108939034, 19.591356141226633, 45.57172679901123, 58.03738219397408, 68.2418714250837, 72.64365250723702, 48.96055780138288, 2.318170270749501, 0.1127392922395042, 0.01842979820711272, 0.06225309095212391, 0.05749279460204499, 0.03817223597850118, 0.10546948840575558, 0.03980465213369046, 0.04324466861518366, 0.008244433722990965, 0.09194670617580414, 0.033299475841756375, 0.06737128059778895, 0.04634804691054991, 0.028647914728415862, 0.03708730258845857, 0.07364591104643685, 0.01677220331371895, 0.06313433830759355, 0.023822699540427754, 0.04909454632018294, 0.031197818794420788, 0.01922182838565537, 0.07880925719759294, 0.020946330224562968, 0.03394826388518725, 0.001277515517098696, 0.040386546802307875, 0.06973296244229589, 0.016209570557943413, 0.05233945684241397, 0.0192490715666541, 0.052104361421827755, 0.2769440678613526, 0.18094653476561817, 0.21655742318502494, 0.2457616925239563, 0.15334537226174558, 0.13546630021716866, 0.18241785652935505, 0.13371186650225095, 0.13682465947100095, 0.16715738682874612, 0.17103324670876774, 0.14580456832689898, 0.08662255401057856, 0.18752058914729527, 0.10546465723642282, 0.12599163076707295, 0.23235712466495378, 0.1292455725904022, 0.20934745935457094, 0.13021238999707357, 0.08625054718660456, 0.12818115470664843, 0.1250725415136133, 0.14001103277717317, 0.08202490928981986, 0.17121489053325994, 0.2042494493403605, 0.1672630618725504, 0.12664944332625183, 0.08021360076963902, 0.12275499158671924, 4.434565722942352, 51.834833008902415, 99.17815589904785, 90.97077001844133, 98.0731838771275, 66.02197061266217, 50.932123047964915, 53.11124835695539, 68.46208763122559, 100.38020120348249, 61.85799857548305, 110.72737516675676, 97.19190910884312, 71.9198169708252, 101.153473172869, 33.08220434188843, 1.9002207091876437, 0.4214866831898689, 0.37891946732997894, 0.35962212138942307, 0.18102023723934377, 0.3271051219531468, 0.18513825269682066, 0.5017435337815965, 0.280348359474114, 0.24365345707961492, 0.30653769416468485, 0.1865295616111585, 0.5547065032379968, 0.230517073401383, 1.8287940961974007, 1.1705485773938042, 1.1814531236886978, 1.475222417286464, 2.219074411051614, 1.627481875675065, 2.4022434737001146, 2.2316691066537584, 1.4181425315993172, 2.4087055155209134, 3.025839303221021, 2.6372272074222565, 2.920152425765991, 3.963166058063507, 6.5542478901999335, 16.523075069699967, 16.70872572490147, 17.18219334738595, 16.809684787477764, 23.511587108884537, 25.563850470951625, 44.4136392729623, 37.27536923544747, 33.579855169568745, 40.75718797956194, 30.893469674246653, 28.396375690187725, 32.72819709777832, 28.21178116117205, 37.0657559803554, 34.71927636010306, 32.20735318320138, 32.46979706627982, 21.536636352539062, 13.215899297169276, 8.640724182128906, 3.921230205467769, 6.727639317512512, 4.197897485324314, 3.3675582238606045, 7.756766540663583, 4.051120698451996, 3.7406378388404846, 8.049752099173409, 9.257184863090515, 9.454666563442775, 9.36926886013576, 6.082348823547363, 2.50029102393559, 0.5877549584422792, 0.9258169553109578, 0.8507665853415216, 0.92882139980793, 0.7829086865697588, 0.7689387361918176, 0.3969019481113979, 0.3400079538779599, 0.7452949391944068, 0.8657065150993211, 0.18453987980527536, 0.1350254017327513, 0.42853259082351414, 0.6123596695916993, 0.1398369071206876, 0.1933600072349821, 0.6881301009229251, 0.5582365681018148, 0.24996578693389893, 5.782260903290339, 63.03852530888149, 128.92360251290458, 116.98552731105259, 80.29905959538051, 74.86296272277832, 79.10938903263637, 50.38391365323748, 31.954636778150284, 38.85551813670567, 56.08928101403372, 70.0211591720581, 82.47125407627651, 49.17979083742414, 1.326677639569555, 0.24667698198131152, 0.16594922808664186, 0.15448007280273096, 0.15241360797413758, 0.09026590708111014, 0.19373397502515996, 0.13696346059441566, 0.09080702518778187, 0.11189215483942203, 0.19005303111459526, 0.0921161092285599, 0.1724391576967069, 0.08075808441000325, 0.08734642195382289, 0.14266964154584066, 0.21143377811780997, 0.15142277042780602, 0.20537361901785645, 0.19147665186652116, 0.09639586707843201, 0.10023216158151627, 0.1526477432676724, 0.20157606207898685, 0.1884787077350276, 0.15908991758312496, 0.0921504431005035, 0.12497552457664694, 0.22588139000747884, 0.10401134379208088, 0.17899603157171182, 0.1435418033174106, 0.12013952407453742], [0.0843370377219149, 0.07706475044999804, 0.04271006105201585, 0.04435163403728178, 0.056633114482143095, 0.031416765081563165, 0.019643224077299237, 0.07703638768621854, 0.017477783041873148, 0.05502066082720246, 0.02613562185849462, 0.01322622680371361, 0.03146133804693818, 0.02204462736179786, 0.0500001768315477, 0.009505413871790682, 0.07009525943015303, 0.01588068633074207, 0.020261659553008418, 0.052334822448236604, 0.043141538077699285, 0.013395036986496831, 0.0422248745869313, 0.04285709959055696, 0.049293418148798604, 0.07071330305188894, 0.014676515678209918, 0.04233299235680273, 0.023776850929217677, 0.032329767875905545, 5.098632855074746, 31.552888461521693, 73.37447098323277, 61.982760429382324, 64.81594399043492, 42.04021453857422, 31.277906554085867, 29.2442661012922, 43.67734561647688, 49.279375893729075, 42.905147143772666, 100.78167506626674, 78.94335487910679, 34.11572456359863, 51.96611227308001, 14.307113017354693, 0.13525142174746307, 0.16343015325920923, 0.16507710702717304, 0.05514623051775353, 0.025477456461106027, 0.06456858491791145, 0.15277623065880366, 0.10625451271023069, 0.13532223366200924, 0.4839468630296843, 0.44881975650787354, 1.3686239144631793, 2.043136251824243, 1.3309051841497421, 0.32634635695389336, 1.4450589844158717, 0.21800229565373488, 0.23886489974600927, 3.454611335481916, 7.44474812916347, 17.721363135746547, 33.15746375492641, 49.429825237819124, 62.905613218035015, 71.19592584882463, 70.91528810773576, 68.06050259726388, 61.31289849962507, 48.97832781927926, 22.881613050188335, 8.461135830198016, 1.9118348402636391, 5.179942846298218, 8.961751801627022, 9.725648045539856, 11.646789346422468, 15.870503732136317, 20.927348818097794, 20.28121324947902, 20.748220784323557, 11.86983346939087, 11.522934232439313, 16.175611291612896, 16.246192829949514, 14.922121524810791, 11.101704904011317, 13.51610837663923, 4.636803030967712, 2.0155356185776845, 1.919779236827578, 3.405440236840929, 13.605888656207494, 24.039707524435862, 34.66431263514927, 31.793796403067454, 28.656851496015275, 24.146982499531337, 12.439446789877755, 4.810900134699685, 4.488451174327305, 0.9678836294582912, 1.3327325603791644, 1.3374065267188209, 3.176860353776387, 0.6841745674610138, 4.045153498649597, 3.3082401497023444, 0.6997160592249462, 1.063384773475783, 1.3025057251964296, 1.4842109978199005, 0.5541821313755853, 0.31240748347980635, 0.10750610447887864, 0.21579396272344248, 0.39100561450634685, 0.04043371855680432, 0.10044995775180203, 0.28740015679172104, 0.06318944892180817, 0.011035945449423577, 0.1526630645883935, 0.5715096358742032, 0.12748959181564196, 0.02406095014885068, 13.757789305278234, 56.901525429316926, 79.82533836364746, 77.96222754887172, 92.59819793701172, 55.89612456730434, 38.73301444734846, 27.19263849939619, 29.20105525425502, 36.6671586717878, 52.360509395599365, 60.949236733572825, 23.82983544894627, 1.2731957265308924, 0.11340017177696739, 0.023248404464019195, 0.03174160015104072, 0.07363525126129389, 0.08394311421683856, 0.050664140310670645, 0.040484710463455746, 0.0812043161796672, 0.031413793098181486, 0.0702807234068002, 0.049568608203636746, 0.028681478463113308, 0.08335434259580714, 0.029056433521743332, 0.013503083510191312, 0.03392577384199415, 0.03541338723152876, 0.00899599607302142, 0.02692473603279463, 0.018421396247244308, 0.028400212127183164, 0.029327945916780403, 0.05248885668281998, 0.03179193727139916, 0.012214706661844892, 0.025816455949097872, 0.08475720017616238, 0.07307360068495784, 0.042294421033667665, 0.009592871946681823, 0.06597881138856922, 0.030602967499622276, 0.027349753405100534, 0.03913973531286631, 0.00950569800832974, 0.07384784306798663, 0.03346073647428836, 0.03400329986054983, 0.056268954915659766, 0.05478710228843348, 0.03997507977432438, 0.02890480130112597, 0.03887709476319807, 0.03382515049140368, 0.07914538987513099, 0.0582735509212528, 0.006409991823602468, 0.05305542663804122, 0.07894880470952817, 0.04318577516824007, 0.046578870953193734, 0.0633307131273406, 0.043006563891789744, 0.02612026152200997, 0.09288977485682283, 0.03343936940655112, 0.04087461704122169, 0.019033421263364807, 0.03949766253520336, 0.04328202875331044, 0.13718042895197868, 9.70815942968641, 54.05481372560774, 89.82219110216413, 84.82551220485142, 90.44202600206647, 72.49931757790702, 29.279347555977957, 17.40909719467163, 32.29570647648403, 46.532468114580425, 50.530770778656006, 103.99874659946987, 83.64017731802804, 27.4356951713562, 32.7385116985866, 7.571509327207293, 0.0746225400694779, 0.14867699705064297, 0.10016671687896762, 0.045799909359110255, 0.023226504746292318, 0.16241240501403809, 0.4485635959676334, 0.4379655032285622, 1.1753705186503274, 1.4014647922345569, 1.0768969569887434, 1.3936060539313724, 1.2252326373543059, 0.31405683926173616, 0.7122995725699833, 1.1046390512159892, 0.13513415732554027, 0.27114585041999817, 6.4171304021562845, 12.963439975466047, 26.2236270904541, 47.006050382341655, 63.100913184029714, 77.11143452780587, 82.98697022029332, 84.03838552747453, 82.73202691759381, 78.1404696873256, 66.09774766649518, 38.81811250959124, 17.30619089944022, 5.949692947523935, 8.307257550103323, 6.400568068027496, 1.4195225089788437, 1.251335825238909, 9.926094021115984, 22.63357104573931, 22.79741825376238, 23.156645332063945, 12.622835806437902, 15.891110352107457, 16.160003900527954, 20.23865553310939, 18.22875186375209, 6.932306323732648, 3.329908324139459, 0.9898222408124379, 0.857557689504964, 2.9997783473559787, 7.16109573841095, 22.32426851136344, 34.1557913507734, 47.59587253843035, 44.4273168018886, 40.45470857620239, 34.53799785886492, 19.055830683026993, 7.825284464018686, 5.903277243886675, 1.5417388251849582, 0.20917859912983008, 1.3010976293257304, 1.8614541036742074, 1.5586326100996561, 2.3595869626317705, 1.2457034417561121, 0.6110689331378255, 1.3271407804318835, 1.3614343745367867, 2.7847092364515578, 0.8467840733272689, 1.0398563274315424, 0.5641861802765301, 0.7683275661298207, 1.6143137365579605, 0.30204174827252117, 0.12052048077540738, 0.14573219578180993, 0.16678746310727938, 0.14702388218470983, 0.13330827387315886, 0.39328676781484057, 0.0309473986604384, 0.11795341995145593, 6.488843194075993, 47.049705914088655, 78.03889397212437, 89.57967812674386, 103.01166466304234, 58.05887297221592, 17.621265649795532, 24.339701209749492, 47.099590505872456, 57.76540538242885, 71.2699728012085, 72.77308355058942, 43.55951459067208, 4.697205024106162, 0.04200515816254275, 0.023329265482191528, 0.013410320139623113, 0.03799498227557965, 0.0677878400310874, 0.07314239056514842, 0.06277088102485452, 0.0487826000233846, 0.057817303974713595, 0.0675188551789948, 0.034482362547091076, 0.07489999303860323, 0.014564547222107649, 0.018931238978568996, 0.06602303151573453, 0.05890855113310473, 0.031008263251611164, 0.02598427631892264, 0.040606286975422075, 0.04472499793129308, 0.07817091859344925, 0.04422025947964617, 0.02982047413076673, 0.026437943136053424, 0.025473922989996414, 0.07282506009297711, 0.06786910138492074, 0.06525459060711519, 0.051871603554380794, 0.022406279741387283, 0.020534561248496175, 0.2026308040533747, 0.16571786121598311, 0.12162633000739984, 0.15956890902348927, 0.25103836080857683, 0.14999753476253577, 0.15311405967388833, 0.1563283343400274, 0.09651085162269217, 0.14005106634327344, 0.08976088703743049, 0.11220080006335463, 0.11632387739207063, 0.08591659260647637, 0.17453526093491487, 0.09721703694335052, 0.18645900753991945, 0.1418300358844655, 0.1086992472410202, 0.11067505979112216, 0.11878607741424016, 0.10389302085552897, 0.1231037178742034, 0.12301248205559594, 0.12207763721900326, 0.22944455380950654, 0.1451538668147155, 0.1098136053021465, 0.09625949511038405, 0.3239476813801697, 9.418754799025399, 61.55670383998326, 106.09488609858921, 84.698255947658, 89.75960867745536, 56.687444482530864, 47.11273997170584, 47.30186646325247, 61.9596437726702, 79.09240068708147, 55.556173528943745, 115.18775735582624, 104.77611800602504, 46.55869409016201, 72.43060684204102, 23.674591847828456, 0.2924344523676804, 0.26972250108207974, 0.4711213026727949, 0.14501338292445454, 0.14115074090659618, 0.20236950021769318, 0.32193824063454357, 0.17875201680830546, 0.5653011490191732, 1.4112518727779388, 1.520225248166493, 3.5465842059680392, 3.5807567494256154, 3.8269075410706654, 3.018843335764749, 3.1867691363607134, 0.44872155891997473, 0.286971458366939, 4.771730533667973, 9.376402923039027, 21.509274346487864, 39.91598694665091, 59.174910000392366, 74.98907947540283, 82.79246234893799, 83.57885946546281, 81.50984573364258, 73.68944672175816, 59.5198255266462, 30.09351314817156, 12.152313351631165, 3.765850245952606, 9.803097878183637, 14.659748860767909, 22.04351438794817, 23.457940067563737, 25.636905567986624, 33.27150106430054, 33.58570555278233, 32.75468363080706, 20.655191353389196, 24.20251076562064, 29.710900170462473, 29.550799778529576, 30.307031290871755, 18.829635551997594, 20.811312164579117, 8.101081047739301, 6.9980297684669495, 3.3203630191939215, 5.058522207396371, 18.83645694596427, 30.568075111934117, 45.98057964869908, 40.81127623149327, 38.069753306252615, 34.21815490722656, 17.231855596814835, 6.372602002961295, 6.046432282243456, 3.1967263392039706, 3.897470840385982, 7.242099574634007, 9.387224742344447, 10.826469387326922, 16.20868124280657, 11.976321560995919, 4.7374129465648105, 3.0872329345771243, 2.4375789718968526, 4.399586754185813, 1.077226562159402, 0.767737403512001, 0.44195868181330816, 0.5021621084639004, 0.8785832641380174, 0.26582773721643854, 0.21901099224175724, 0.5727848474468503, 0.27578437009028023, 0.24863102712801524, 0.26506248542240685, 1.0517752021551132, 0.3388544172048569, 0.2202695118529456, 17.953564984457834, 66.45282145908901, 91.59075083051408, 92.41003377096993, 106.8163036618914, 80.7038130078997, 61.95945617130825, 39.70177050999233, 39.690556117466514, 55.074736322675435, 68.30326570783342, 83.99908651624406, 47.62180321557181, 4.171882995537349, 0.13668056577444077, 0.19172692272279943, 0.12280058913997241, 0.1344651896506548, 0.09828320544745241, 0.20993863977491856, 0.10068449338099786, 0.14416655765048095, 0.14415124990046024, 0.14856415667704173, 0.1418454386293888, 0.2703493045909064, 0.21884595895452158, 0.11232775396534375, 0.12168810383549758, 0.11258246244064399, 0.12045429646968842, 0.11800097168556281, 0.2597047457737582, 0.10751150561762707, 0.184048769729478, 0.12716211724494184, 0.15711228655917303, 0.18314321046429022, 0.08459840941109828, 0.14080570584961347, 0.22204347380570003, 0.15642079152166843, 0.11455413592713219, 0.1044549292751721, 0.1431764664926699], [0.05097782704979181, 0.08000930744622435, 0.026490544867036597, 0.04743146377482584, 0.035132840142718384, 0.03538649010338953, 0.02352425778683807, 0.03374257277963417, 0.037600515942488394, 0.029367887880653143, 0.04745372311611261, 0.024117090439956104, 0.050906665689711056, 0.05503448258553233, 0.03497859216960413, 0.08893336608473744, 0.05422867814611111, 0.014807662926614285, 0.021773172642237375, 0.023361224481569867, 0.07073872097368751, 0.009530080316056098, 0.009971880403879498, 0.030577169598213265, 0.05905888056648629, 0.09797728793429476, 0.016268799879721234, 0.024713276752403805, 0.2509647804711546, 4.929860242775508, 39.18874331883022, 65.42651694161552, 67.04912281036377, 53.03645099912371, 51.33055359976632, 46.427310603005544, 43.137303829193115, 44.160356589726035, 45.75218888691494, 36.3304454939706, 88.47278145381382, 71.8893074308123, 22.413736990519933, 30.365621975490026, 6.985519536903926, 0.1455710030027798, 0.2540307545236179, 0.07793700721647058, 0.12059327401220798, 0.1690285557082721, 0.1138247854209372, 0.05850727230842624, 0.4959572042737688, 0.8610539904662541, 1.0716145890099662, 2.1458935950483595, 1.8792412749358585, 2.928991837160928, 0.6365904808044434, 0.04176478034683636, 0.946295685001782, 7.463536058153425, 19.447111538478307, 43.55921234403338, 72.01318686349052, 87.45598207201276, 86.47752285003662, 91.49934727805001, 81.52201202937535, 79.91094711848667, 77.6149982724871, 79.98865577152797, 82.10465322222028, 88.17150061471122, 87.79614503043038, 94.01323332105363, 80.90255233219692, 63.30428000858852, 69.23124626704625, 45.97336047036307, 7.914599214281354, 1.6398420695747649, 6.2063376903533936, 21.835528748376028, 12.01792824268341, 10.474512730325971, 9.577592355864388, 12.040350079536438, 12.808486461639404, 16.993072066988262, 11.08652309009007, 6.101412074906485, 1.1279611140489578, 3.559064473424639, 20.052648782730103, 41.77109343664986, 65.76921599251884, 73.13275705065045, 80.49081598009381, 76.80369881221226, 81.84786864689418, 79.54438795362199, 75.02711391448975, 71.75706931522915, 65.35133048466274, 50.96300779070173, 39.113285882132395, 23.28917874608721, 9.27951897893633, 1.9292730816773005, 0.7913395113178662, 1.029519253543445, 0.49292143860033577, 2.9471631135259355, 5.008445671626499, 3.946234166622162, 2.511963563305991, 1.6770793114389693, 1.8502505677086967, 0.25450874173215454, 0.23849124408193997, 0.28798190557530945, 0.2726141730589526, 0.18763626579727444, 0.03838575059281928, 0.051960013274635584, 0.18301137111016683, 0.09710096674306051, 0.10801114487860884, 0.2528549890433039, 0.08262730589402573, 0.2756175590412957, 10.64857292175293, 28.47041048322405, 65.21057387760708, 76.731187411717, 33.22646631513323, 47.911442347935264, 34.27889953340803, 21.920168229511805, 26.22613365309579, 36.07447733197893, 48.41448845182146, 54.09532172339303, 41.01211391176496, 4.740917878491538, 0.050476521985339265, 0.030350823886692524, 0.01758786686696112, 0.008018048995706652, 0.020237485046631525, 0.06910841845508132, 0.0749359078971403, 0.1027267345094255, 0.08718925967280354, 0.018744558727900897, 0.01460663674931441, 0.04833909257182053, 0.06956669422132628, 0.03851929646251457, 0.04219440497191889, 0.06473658340317862, 0.04707764168935163, 0.027401206715564643, 0.06091390031256846, 0.03834070265293121, 0.016523498176996197, 0.008186552989562708, 0.038712906252060614, 0.02136269288270601, 0.004879081114527902, 0.04115884178983314, 0.040367334083254845, 0.07309805508702993, 0.05012253365878548, 0.016359199403918216, 0.07555803629968848, 0.11248580512723752, 0.04719158807503326, 0.016532122357083217, 0.09178600872733764, 0.01967667246104351, 0.08418302384338208, 0.013155836429047798, 0.01534135446750692, 0.005623814857764435, 0.06153098041457789, 0.044371525291353464, 0.009666044314924096, 0.02906715776771307, 0.044230637672756395, 0.09307113369660718, 0.04175841908103653, 0.010627362195269337, 0.06822117285004684, 0.05026687841330256, 0.01696964512978281, 0.07688134921980755, 0.040049871296754906, 0.04289662764806833, 0.06116070385490145, 0.03483446793896811, 0.02194040099025837, 0.023263264380927597, 0.343683089528765, 9.467816029276166, 58.96318449292864, 83.87486662183488, 88.89816406794957, 82.58637183053153, 81.16653524126325, 35.72083139419556, 29.04491012437003, 37.47830179759434, 44.02289342880249, 44.37662621906826, 90.04545061928886, 71.1230114528111, 21.333220890590123, 23.61755234854562, 2.4369138990129744, 0.13512285293212958, 0.08865220831441027, 0.04321195983460971, 0.16074281531785214, 0.23707231879234314, 0.2143468375184706, 0.12273821820105825, 1.079003455383437, 0.5180799971733774, 0.6081809795328549, 2.4407321512699127, 0.33229026943445206, 0.9063143389565604, 0.5044971917356763, 0.3929860410945756, 2.324763459818704, 13.053042207445417, 28.902685710362025, 55.665454796382356, 85.29395975385393, 96.91964394705636, 97.15643160683769, 97.33802277701241, 90.3017349243164, 83.97524724687848, 81.56937789916992, 84.57594680786133, 86.41052831922258, 90.33530167170933, 92.27423817770821, 98.06556170327323, 93.49056203024728, 77.08753967285156, 85.3900533403669, 62.3936629976545, 12.32918930053711, 1.766849820102964, 2.278050937822887, 15.150581768580846, 12.546042578560964, 8.190694570541382, 8.056459716388158, 15.335388217653547, 16.638844217572892, 18.61889147758484, 8.74909610407693, 1.079792510185923, 1.657796974693026, 6.665045601981027, 32.170847347804475, 56.19803769247872, 80.11780193873814, 85.54279558999198, 90.57824543544224, 86.41597570691789, 91.17740944453648, 89.27816104888916, 88.4207672391619, 84.90288039616176, 80.27275371551514, 65.85033621106828, 52.99265997750418, 33.286880901881624, 15.676607302256993, 3.9998234510421753, 0.8993441015481949, 0.10520262058292117, 1.6073512073074068, 2.62592921938215, 1.5065479363713945, 0.6566800028085709, 0.8778213507362774, 1.1043016293219157, 0.9414245635271072, 0.9305408618279866, 0.8700602129101753, 0.6489673938070024, 0.6983632775289672, 0.5094029999205044, 0.26752657177192823, 0.09160044975578785, 0.1937599629163742, 0.1699376976383584, 0.14014559984207153, 0.18836008624306746, 0.1293031530720847, 0.24554635265043803, 9.889433588300433, 27.721017735345022, 58.39875452859061, 79.83765057155064, 38.60320125307356, 51.85912043707711, 19.084092480795725, 21.66068254198347, 38.87032127380371, 53.58222852434431, 67.23673112051827, 67.33518709455217, 61.762474741254536, 11.935468758855547, 0.1261688641139439, 0.029502441374851123, 0.024946960820151225, 0.02380736973801894, 0.027420187036373785, 0.08723453831459795, 0.15182951145938464, 0.08477206009307078, 0.022114580929545418, 0.046261537088347335, 0.009916193034899021, 0.017821649322286248, 0.034392225955213816, 0.02625571407510766, 0.04244525936831321, 0.05071256735495158, 0.018184967505346452, 0.02001103585852044, 0.024174791361604418, 0.026101886793704968, 0.016630786437807337, 0.006544569490610489, 0.08700165831084762, 0.03263165828372751, 0.0517409719925906, 0.040763561214719496, 0.017334780090355446, 0.06245811709335872, 0.026603071418191706, 0.03254598645227296, 0.11674136641834464, 0.1804514213332108, 0.10026669901396547, 0.10708283433424574, 0.1330887135118246, 0.11796557929899011, 0.2213590626737901, 0.08724006837499992, 0.12059716880321503, 0.15692752147359507, 0.09801811538636684, 0.1540989125413554, 0.09859896850373064, 0.1277357643204076, 0.10386114328035287, 0.21091594733297825, 0.11952234219227519, 0.09204249496438674, 0.11319918291909353, 0.16595249862543174, 0.08340664407504456, 0.16615577414631844, 0.1094368826597929, 0.0970766276919416, 0.12606177771730082, 0.18265022763184138, 0.13496632847402776, 0.14221636658268316, 0.7178216534001487, 10.578526394707815, 72.939117704119, 96.39382512228829, 91.4354030064174, 78.92442103794643, 71.22606018611363, 60.068024499075754, 65.44303975786481, 64.80055373055595, 71.15500790732247, 55.16979462759835, 109.73549897330147, 98.43339238848004, 34.29924038478306, 44.57736662455967, 13.625681468418666, 0.21352496876248292, 0.4351220072380134, 0.24633969579424175, 0.33461954444646835, 0.402433664138828, 0.36214950148548397, 0.24951651532735142, 1.1342088473694665, 1.2816081494092941, 7.297083275658744, 11.725512436458043, 4.657368830272129, 6.356051828180041, 1.915422716311046, 0.3898194267281464, 1.2851142755576541, 10.173401253564016, 24.44983015741621, 52.21692834581648, 80.60063225882394, 96.85175309862409, 98.59915556226457, 102.48453957693917, 93.54748862130302, 89.08546665736607, 85.94949449811662, 87.42796693529401, 90.14328820364815, 95.59828417641776, 98.66817896706718, 105.93296527862549, 94.50110108511788, 72.7199923651559, 83.42731925419399, 55.36289896283831, 8.94969059739794, 5.994270852633885, 13.226948669978551, 34.458305495125906, 22.137804916926793, 19.26557421684265, 17.785232714244298, 24.912562813077653, 25.63394910948617, 30.277435438973562, 23.040935243879044, 13.878535968916756, 3.355992078781128, 4.665276748793466, 27.650311129433767, 53.25883156912667, 81.30836881910051, 87.41308389391217, 95.77942371368408, 89.85625117165702, 97.2255870274135, 95.02698244367326, 90.86999334607805, 87.30594267163957, 83.48676804133824, 67.66453170776367, 53.88415207181658, 32.2895781653268, 13.894647104399544, 4.046277804034097, 2.290780471903937, 4.469614173684802, 8.563091090747289, 12.302966799054827, 16.690610034125193, 14.057954958506993, 6.819693395069667, 4.902027930532183, 3.517693813358034, 0.8779427270804132, 0.7672881590468543, 0.3450895297740187, 0.3108780655477728, 0.5161149597593716, 0.3140339047781059, 0.277803364608969, 0.43852980009147097, 0.3194774383945124, 0.3794723376631737, 0.6243815730725015, 0.16911745736641542, 1.13990333037717, 20.498511212212698, 38.15842274257115, 75.32428142002651, 93.19191455841064, 47.99390009471348, 69.91534505571637, 54.43285826274327, 34.30344751902989, 37.72150959287371, 51.514875411987305, 64.39205523899624, 74.48225702558244, 68.20695672716413, 11.622298683438983, 0.1256543988628047, 0.17585532367229462, 0.12008613693927016, 0.10147270001471043, 0.09384846341397081, 0.15582914969750813, 0.2716231590935162, 0.1980936439441783, 0.1629818994551897, 0.15338702074119023, 0.14603090046771935, 0.14828857646456786, 0.13702646935624735, 0.12382177077233791, 0.11689311398991517, 0.11973454723400728, 0.1393696814775467, 0.12969687980200562, 0.10948034961308752, 0.1621793553765331, 0.12502104070569786, 0.05093827524355479, 0.18097330975745404, 0.08686595809246812, 0.11882548672812325, 0.1446801679474967, 0.11853045970201492, 0.23603766145450727, 0.09750911912747792, 0.09053623543253966], [0.020120900856064897, 0.006993048907523709, 0.02520928924371089, 0.03948488572080221, 0.11388948373496532, 0.05887311803443091, 0.013074508918050145, 0.04032897310597556, 0.004242681000115616, 0.05685177239190255, 0.04787913743140442, 0.02284919347481004, 0.006135341204104147, 0.023161348421126604, 0.06861893686332873, 0.046217737652893574, 0.016501961475504295, 0.046217825862446, 0.05405666273353355, 0.0062360302877745456, 0.02200362179428339, 0.03177105535620025, 0.04298319514574749, 0.01471288176253438, 0.02656234405003488, 0.03929735899769834, 0.011154845988910114, 0.33485279764447895, 15.008716923849923, 34.52988583700997, 55.243761675698416, 59.91336454663958, 52.774962493351524, 64.9565338407244, 27.93444207736424, 65.16482693808419, 56.31415251323155, 35.35051325389317, 32.178959369659424, 86.11870397840227, 71.64129843030656, 22.380170243127004, 32.86354800633022, 4.942414769104548, 0.18297677939491613, 0.31304777626480373, 0.039028021307396035, 0.04320836020633578, 0.0018830500277025358, 0.08227024719651256, 0.1787053064576217, 0.5670200682112149, 1.9500147572585513, 3.118443808385304, 3.491465015070779, 0.9063650390931538, 0.46894266243491856, 0.2103927018386977, 7.142792446272714, 28.053115572248185, 53.98688466208321, 74.55557441711426, 86.5699130467006, 91.74583462306431, 83.87334496634347, 74.30971240997314, 79.50470679146903, 71.03244863237653, 75.4583330154419, 80.40333815983364, 80.8115587234497, 79.12315341404506, 80.25268731798444, 78.67839922223772, 74.38666370936802, 74.04986367906842, 82.87420095716203, 93.02310807364327, 81.3034633908953, 83.1623844419207, 59.826109068734304, 25.629403250558035, 4.408143026488168, 1.689492051090513, 11.432387913976397, 12.753666043281555, 9.161001818520681, 9.718724165643964, 10.13955397265298, 7.223371139594486, 1.1250049812453133, 0.7065255652580942, 22.772029536111013, 56.91609580176217, 78.77800164903913, 78.83027989523751, 73.47792271205357, 70.81555366516113, 68.66002096448625, 68.1411920275007, 68.42945889064244, 66.78466742379325, 70.34860692705426, 69.5631547655378, 70.78520393371582, 70.27838148389543, 74.46283681052071, 73.90579972948346, 82.49712916782924, 64.23108632223946, 36.42328037534441, 12.677088209560939, 5.403839426381247, 0.8538557110088212, 0.5489583345396178, 0.2938203194311687, 1.5942289914403642, 0.7607815510460308, 2.3143787256308963, 1.3753920027187891, 1.9486251175403595, 4.00570900951113, 0.3657238339739186, 0.22229031127478394, 0.11259126982518605, 0.15551572080169404, 0.09210380060332161, 0.15663219589207852, 0.1102372214996389, 0.029735681002161334, 0.07351411918976478, 0.06283994231905256, 0.9578211179801396, 15.13229410988944, 27.59226761545454, 37.78278923034668, 28.242735385894775, 13.066477417945862, 48.18760544913155, 37.60543646131243, 27.784261975969585, 37.46666356495449, 33.67671305792672, 50.176374435424805, 56.29996429170881, 44.87469046456473, 7.127332270145416, 0.11602547126156942, 0.06415876333734818, 0.06947840324469975, 0.0103317346656695, 0.050782931436385424, 0.01925037265755236, 0.0382960787974298, 0.013943786067622048, 0.05186951705919845, 0.030257355687873702, 0.017281676243458475, 0.018724407934184586, 0.020720640995672772, 0.0699403973828469, 0.06129259749182633, 0.033414267003536224, 0.024739081439163004, 0.10088702929871422, 0.04679375960092459, 0.021189790285591568, 0.028205706671412503, 0.023521433384822946, 0.011747925459141178, 0.023418849068028585, 0.06623974881534066, 0.03648886184341141, 0.032767433140959056, 0.026392204786783884, 0.017278622835874557, 0.0337872882373631, 0.04372437930266772, 0.012204623631467777, 0.06849078873970679, 0.0658745002001524, 0.018585343878450136, 0.02465017808468214, 0.03755584119686058, 0.0047672148627628174, 0.04939461486147983, 0.05813789141497441, 0.029933134692588022, 0.04656538846237319, 0.04456811724230647, 0.03704317406352077, 0.033632229414901564, 0.010644887906632252, 0.09717418067157269, 0.024134094527523433, 0.06994923869413988, 0.0030892897879571785, 0.032303654455712864, 0.04909093651388373, 0.029744922649115324, 0.02209655225409993, 0.07132550448711429, 0.022454062177400504, 0.7392526119947433, 24.652915579932078, 56.86591591153826, 77.22736522129604, 84.13121346064976, 82.14550168173653, 83.13927473340715, 25.112528494426183, 39.89592749731881, 58.769739695957725, 34.24338034221104, 45.86333921977452, 93.30362074715751, 70.32631710597447, 24.62840928350176, 30.276737145015172, 1.1390928881508964, 0.07524512987583876, 0.10097534063139132, 0.03614153673074075, 0.07760782273752348, 0.18375314559255326, 0.16739764250814915, 0.7246900562729154, 1.2417128958872385, 1.8724795920508248, 1.5908568352460861, 0.7189208258475576, 0.7944601752928325, 0.4252242440623896, 0.7754266166261264, 13.659538303102766, 39.91721330370222, 69.05897957938058, 86.92361804417202, 94.7621796471732, 95.02291774749756, 88.11405985695976, 78.42829186575753, 84.58848135811942, 79.33605316707066, 82.98531654902867, 86.15738459995815, 88.81671728406633, 86.30994619641984, 86.99202305930001, 83.41172054835728, 79.92935984475272, 76.56745311192104, 85.82156426565987, 93.03406538282121, 89.6951710837228, 92.54385607583183, 69.38556575775146, 39.31132343837193, 8.901844433375768, 0.5406481804592269, 5.9536416956356595, 13.174894503184728, 13.610253861972264, 10.410998378481183, 9.657191787447248, 7.008792962346758, 0.38206477569682257, 2.479152432509831, 32.863739081791465, 71.57719435010637, 86.18303734915597, 83.42196914127895, 77.9150492804391, 76.43825830732072, 74.6175592967442, 73.26717690059117, 72.28758512224469, 71.97287341526577, 75.5998261315482, 75.06171594347272, 75.96168831416539, 77.76337705339704, 82.0004997253418, 85.68204443795341, 93.10890442984444, 76.00022302355084, 48.07722289221627, 23.420270408902848, 10.337280597005572, 1.5906258076429367, 0.2247594730662448, 0.31980861776641434, 1.4425268002918787, 0.9809354948146003, 1.5009700528212955, 1.8344427645206451, 0.267271171190909, 0.6097591434206281, 0.39731889430965694, 0.30707425251603127, 0.32955827031816753, 0.534161385680948, 0.08688763728631393, 0.13032155271087373, 0.1059391839163644, 0.04235283611342311, 0.04007382358291319, 0.034387605131736824, 0.8091141975351742, 14.72239555631365, 26.815724781581334, 41.446303367614746, 28.608099460601807, 14.751803806849889, 55.806663036346436, 24.20866686957223, 26.4097797530038, 47.701335770743235, 52.770130021231516, 70.4202081135341, 64.94654927934918, 63.74574770246233, 16.716167245592388, 0.09540643409958907, 0.04047804046422243, 0.04499415580981544, 0.049065294675529, 0.011920692349251891, 0.04512397652225835, 0.04950054435591612, 0.03901884751394391, 0.10376820433884859, 0.04269520792045763, 0.04068247627999101, 0.021882540612880672, 0.03930090095049568, 0.04138058703392744, 0.01776723251012819, 0.02264367539568671, 0.015639416241486157, 0.06837032163249594, 0.01451003541504698, 0.02005202615899699, 0.010473339835048785, 0.04561532747798732, 0.007101958018860647, 0.02188373653085104, 0.01076898432802409, 0.030765754835946218, 0.07227320756231036, 0.05929822700896433, 0.07300474973661558, 0.09381330851465464, 0.10303765282567058, 0.11481188423931599, 0.1315142951373543, 0.20690435330782617, 0.12247380667499133, 0.11751220934092999, 0.10900091033961092, 0.15203699389738695, 0.12358593914125647, 0.1712348258921078, 0.23597151786088943, 0.15054968584861073, 0.12358361855149269, 0.1444718169846705, 0.21021983825734683, 0.09187863554273333, 0.13239507430366107, 0.15170780941843987, 0.1331797321992261, 0.11424373329750129, 0.10163390636444092, 0.10581808577158622, 0.10235370309757334, 0.09356383832969836, 0.1505692819399493, 0.14889553960944923, 0.973389208316803, 26.034104551587784, 69.07552324022565, 88.63503578730992, 84.80541801452637, 80.40495709010533, 80.84240872519356, 41.91208628245762, 102.62328815460205, 83.7454286302839, 54.423783915383474, 56.66975089481899, 111.40434510367257, 93.17005552564348, 36.15638617106846, 52.828755446842735, 8.707304426601954, 0.6094654191817556, 0.588337955730302, 0.30547966808080673, 0.2763889990746975, 0.30994060156600817, 0.2925364768930844, 0.7700217866471836, 1.792688976441111, 4.566075146198273, 8.2487485068185, 8.909361515726362, 3.840183811528342, 1.467220263821738, 0.31996248236724306, 9.72575661114284, 33.988753182547434, 64.43940721239362, 84.97739287785122, 93.7729993547712, 99.52854660579136, 88.6963814326695, 76.72006334577287, 87.60238756452287, 81.11887754712785, 82.79663126809257, 87.76236983707973, 89.82756900787354, 88.50092165810722, 87.89999975476945, 83.49650941576276, 80.69014590127128, 77.27424471718925, 89.8096009663173, 98.55389499664307, 99.31513268607003, 98.13104847499302, 65.78856672559465, 30.585014820098877, 5.875236051423209, 4.801617775644575, 20.836508069719585, 24.0902122429439, 21.744839123317174, 21.092243467058452, 21.26300934382847, 15.115595851625715, 4.754647953169687, 1.3508223039763314, 27.503648553575786, 68.80272306714738, 89.11264106205532, 90.59738772256034, 82.31631619589669, 78.78335871015275, 76.06372261047363, 73.10619408743722, 75.14465659005302, 72.83345644814628, 75.76071166992188, 73.29493495396206, 77.71788719722203, 77.98694229125977, 84.8438207081386, 89.2016544342041, 97.45483589172363, 72.38182353973389, 44.62331158774239, 19.759445224489482, 8.814225043569293, 0.9754332814897809, 3.600127241441182, 4.008668942110879, 7.7998809814453125, 6.710605374404362, 6.745443642139435, 7.84507553918021, 6.0484776582036694, 7.47455416406904, 1.5388402321508952, 0.37240308842488695, 0.15785188972949982, 0.3472464568912983, 0.1396407155053956, 0.22535298764705658, 0.2759116089769772, 0.1933300702699593, 0.25229954027703827, 0.18912684438484056, 2.2453470698424747, 27.60468578338623, 39.18908378056118, 51.64580031803676, 42.05607727595738, 24.470843247004918, 66.502014705113, 55.29609898158482, 42.259041104997905, 48.410590512411936, 49.49410302298409, 67.6824928011213, 74.91318430219377, 74.27193505423409, 16.207272495542252, 0.1625535131565162, 0.14028554090431758, 0.15961306808250292, 0.10538381657430104, 0.09265401786459343, 0.10165758723659174, 0.16986030393413135, 0.1656497905829123, 0.1806976752621787, 0.15417721548250743, 0.12974337302148342, 0.12316740517105375, 0.10870373914284365, 0.18220224524182932, 0.17423867327826364, 0.11502859475357191, 0.0957897249609232, 0.16163523814507894, 0.09303663019090891, 0.08532415011099406, 0.10405266657471657, 0.1389973150300128, 0.10239158570766449, 0.15833416527935437, 0.08874072999294315, 0.13494405895471573, 0.18457794561982155, 0.1390481644443103, 0.13652149002466882], [0.06402833533606359, 0.058455025111990314, 0.04120133504537599, 0.0215428269667817, 0.03317986029599394, 0.03991806586938245, 0.009143461240455508, 0.030820729743157114, 0.022328634979203343, 0.019458311410354714, 0.04949521107066955, 0.06519882181393248, 0.005996002765771533, 0.03747692418151668, 0.011185737143802856, 0.006477488246413746, 0.03086123489109533, 0.02102101148505296, 0.06250867473759822, 0.05442415390695844, 0.03383259741323335, 0.03773133749408381, 0.12529820869011538, 0.04502720385789871, 0.0955361428537539, 0.06571306993386575, 1.2970065517084939, 18.561542783464702, 48.609010219573975, 60.61550085885184, 59.14972972869873, 56.99050406047276, 44.82119975771223, 36.04643440246582, 67.78673662458147, 53.52710846492222, 19.528035470417567, 39.27243784495762, 86.97399943215507, 85.43507071903774, 37.316978522709434, 23.231187343597412, 3.314402333327702, 0.03602819424122572, 0.36375632669244495, 0.028535148993666683, 0.05105590268171259, 0.10287337271230561, 0.13686482874410494, 0.1889391073158809, 0.5539037148867334, 1.0792892000504901, 0.7284440376928875, 0.3628825364368302, 0.11499063750462872, 1.6908702914203917, 14.052930542400905, 41.93261126109532, 74.86194133758545, 85.31460285186768, 90.34380626678467, 88.40910121372768, 82.30422633034843, 77.59624508449009, 75.8754403250558, 86.84378324236188, 82.87090751102993, 82.8750833783831, 86.45356546129499, 81.34164374215263, 81.04979160853794, 79.00963374546596, 83.4090941292899, 81.22184985024589, 83.17382117680141, 78.01545075007847, 78.99501473563058, 78.67114530290876, 79.62474387032645, 78.3934188570295, 85.56220190865653, 87.31268242427281, 70.16429206303188, 8.411358935492379, 0.47387219220399857, 8.433265737124852, 3.866241293294089, 10.195797034672328, 6.498796488557543, 1.1855560349566596, 3.8879939317703247, 44.38804905755179, 80.37486444200788, 80.67070484161377, 67.85675362178257, 67.19157477787563, 71.21062128884452, 74.97840704236711, 74.47249480656215, 73.75901903424943, 73.28316470554897, 77.61765248434884, 73.09566756657192, 72.22496795654297, 72.46916934422084, 69.45638874598912, 67.0481014251709, 67.84054347446987, 68.40652288709367, 74.03800310407365, 81.64290373665946, 78.59091445377895, 60.429365566798616, 48.016849994659424, 22.983100175857544, 4.628459981509617, 1.9606915329183852, 0.4705808088183403, 0.9969009352581841, 1.0528376251459122, 0.9307037102324622, 2.5359513504164557, 2.1894859416144232, 1.1505636040653502, 0.45708246741976055, 0.048762647701161246, 0.17765166370996407, 0.030559157886143242, 0.09067273632224117, 0.03042677231132984, 0.08318119402974844, 0.1438667265964406, 0.055314700584858656, 0.7400056230170386, 10.860322747911725, 40.91215017863682, 56.18447133472988, 29.828276089259557, 16.228584357670375, 62.90071473802839, 42.43957267488752, 28.25718763896397, 21.540256364004954, 33.347938196999685, 55.553522791181294, 56.96148838315691, 48.30606528690883, 11.678848334721156, 0.08886192313262395, 0.10293329413980246, 0.010505992636483694, 0.055790916816996675, 0.08109952323138714, 0.04675323409693582, 0.021062909326116954, 0.015503140964678355, 0.024399693489872983, 0.048053327548716745, 0.029277500230818987, 0.03498814254999161, 0.004094457569798189, 0.026250921921538453, 0.01661044735062335, 0.04248199864689793, 0.05224382411688566, 0.032768610399216413, 0.032431890788887224, 0.057843983971646855, 0.024375418899580836, 0.03047424601390958, 0.0039583875498335275, 0.01210680602317942, 0.022716678978343095, 0.03430349053815007, 0.022016145854390094, 0.024029498354398778, 0.043644081468560865, 0.03299077294234719, 0.05567578299503241, 0.032161738856562545, 0.026274426374584436, 0.050055158524108787, 0.04451410585482206, 0.078056076541543, 0.07449555902608804, 0.010175220385592963, 0.04354888979079468, 0.07605150089200054, 0.038297636035297594, 0.03338346151368959, 0.053753439004399946, 0.02857942340363349, 0.023674198758921454, 0.025601107593891875, 0.017969703967017785, 0.03475886556719031, 0.03531397845862167, 0.03693269838445953, 0.012606607284396887, 0.08246094267815351, 0.13644296995231084, 0.024591403381366814, 2.97681867650577, 30.50248064313616, 66.58427442823137, 78.26150035858154, 85.09264959607805, 81.37144456590924, 75.19901929582868, 32.35614538192749, 40.52019534792219, 55.130457401275635, 22.132517337799072, 64.23963260650635, 106.33894852229527, 85.30019228799003, 39.76961619513375, 21.185820068631852, 0.7965423549924577, 0.01816261656183217, 0.33831112778612543, 0.005613060077718858, 0.1931466893958194, 0.09525181632488966, 0.27811274943607195, 0.33587312432272093, 0.12506845673280104, 0.5436029019100326, 0.8676729095833642, 0.35909671815378325, 0.5178274735808372, 4.840950225080762, 25.45405329976763, 58.35222939082554, 86.75212955474854, 94.27499975476945, 94.51032134464809, 91.25394385201591, 85.75325652531215, 83.32213047572544, 82.89287076677594, 92.8680729184832, 89.63027490888322, 90.3951187133789, 90.94425569261823, 85.45197568620954, 84.25036811828613, 84.87876319885254, 83.93471145629883, 84.08139487675258, 84.98520265306745, 83.49590492248535, 83.09570258004325, 82.60178293500627, 84.05987630571637, 81.46885136195591, 86.75234494890485, 89.31793253762382, 83.42164257594517, 16.81731912067958, 0.27504514689956394, 6.269519831453051, 5.682178182261331, 6.516907836709704, 1.0239866418497903, 0.436029778527362, 7.8331567730222424, 57.66581685202462, 88.86281163351876, 85.02716977255685, 73.64540209089006, 75.20391082763672, 78.54891954149518, 82.31836591448102, 81.05876868111747, 77.75783933912004, 81.6942856652396, 83.852952003479, 79.22105353219169, 80.68552534920829, 82.00047193254743, 76.62963948931012, 73.90350682394845, 76.39005865369523, 78.0492467880249, 86.67448343549455, 90.2128883089338, 85.31397751399449, 69.16804545266288, 60.29819747379848, 33.83949892861502, 10.06576062951769, 4.425416682447706, 0.9990723558834621, 1.6737122578280312, 1.4944641504968916, 0.28611886554530686, 1.6306215929133552, 0.9450166736330304, 0.5857039370707103, 0.5953880431396621, 0.2559130106653486, 0.4884111349071775, 0.4096892662346363, 0.1880193395274026, 0.11556937359273434, 0.13670839928090572, 0.14287823678127357, 0.1016668967370476, 0.23294913289802416, 5.932873095784869, 35.34179326466152, 65.38445254734584, 27.434446232659475, 14.994712829589844, 66.25801481519426, 34.09470278876168, 27.823432445526123, 33.57007210595267, 51.415849685668945, 72.94212627410889, 71.4423576082502, 63.12352957044329, 24.261544397899083, 0.12491581349500588, 0.059914187528193, 0.012959145242348313, 0.034797206188419035, 0.07228777570916073, 0.015765011377100433, 0.0834910199046135, 0.004651010227722249, 0.02103821574045079, 0.01764703172791217, 0.05266917736402579, 0.06320902465709619, 0.021287441652800356, 0.020997045628194298, 0.03812889116150992, 0.030887419557464973, 0.050515941477247646, 0.08680706125284944, 0.03598149746124234, 0.0056544316300590125, 0.020784905047288964, 0.029869291332683394, 0.018217175866344144, 0.05614052180732999, 0.0320898718200624, 0.040464055857488086, 0.030837085829781632, 0.01655707378605647, 0.1031887557889734, 0.11800175878618445, 0.17722154036164284, 0.07804746593215636, 0.13882674489702496, 0.1738701473389353, 0.10070953132318598, 0.09604910854250193, 0.17432130527283463, 0.06900052460176603, 0.13148936576076917, 0.18394031269209726, 0.11684257670172624, 0.2402905018201896, 0.11524863008941923, 0.0807178947808487, 0.10551015300942318, 0.0957706920536501, 0.13712435481803759, 0.10343963054141828, 0.13430506895695413, 0.16069421863981656, 0.20864689908921719, 0.13078241369553975, 0.15265935978719167, 0.21789322793483734, 4.126955943448203, 36.139974525996614, 81.40310750688825, 90.06846305302211, 85.8489054271153, 82.101651600429, 59.74066012246268, 54.67691373825073, 90.98178291320801, 77.8766257422311, 36.35044240951538, 66.54181398664201, 109.3923760822841, 98.72498743874687, 54.94131701333182, 35.90278387069702, 4.453288946832929, 0.19245866845761025, 0.5678754565971238, 0.10614830840911184, 0.34146702129926, 0.3256463530872549, 0.35346935583012445, 0.8305630151714597, 1.105588783110891, 3.457364124911172, 3.9533825601850237, 2.81917382138116, 0.40613651115979466, 2.379294659410204, 21.321881430489675, 50.92772831235613, 87.5574813570295, 94.38476044791085, 97.85342625209263, 94.32121222359794, 89.1141140801566, 82.51896040780204, 82.65579128265381, 91.88064357212612, 96.54575443267822, 94.00374902997697, 95.38691997528076, 90.18419224875313, 89.83241190229143, 86.79925223759243, 89.54095581599644, 87.82862785884312, 91.04953479766846, 86.1353657586234, 86.35767337254116, 84.65373189108712, 84.55615833827427, 81.75640256064278, 89.83477428981236, 92.13629559108189, 79.09043434688023, 11.117036972727094, 2.9835373674120222, 14.69975311415536, 10.478009411266871, 18.422222716467722, 13.888863597597394, 3.7476585592542375, 5.046588242053986, 52.671608039310996, 91.00882530212402, 88.29192679268974, 76.9845187323434, 76.96708570207868, 81.79745946611676, 84.71256228855678, 83.71002061026437, 82.0844339643206, 83.54805810110909, 85.16980934143066, 82.30640111650739, 81.72836657932827, 82.37953090667725, 75.87250123705182, 74.74630941663469, 73.58038779667446, 75.26759801592145, 90.86428887503487, 99.16357857840401, 93.61201654161725, 72.90580109187535, 57.87300518580845, 28.054583379200526, 7.180459065096719, 2.8751070371695926, 0.38440458157232826, 1.358887099793979, 2.5942708381584714, 4.960706336157663, 8.932156818253652, 6.351604546819415, 5.181199601718357, 1.0444562520299638, 0.11649157053657941, 0.4601810925773212, 0.294334024723087, 0.2486060027565275, 0.22734679494585308, 0.1818182487040758, 0.29352901077696253, 0.28588401100465227, 1.1364017639841353, 15.895659685134888, 53.12780591419765, 73.20698465619768, 41.59440769468035, 25.666541372026714, 83.83169051579067, 59.108297620500835, 43.14058337892805, 30.260124002184185, 47.3396646635873, 75.46825504302979, 75.61285400390625, 70.32783876146588, 24.393824202673777, 0.23355788737535477, 0.1498033380401986, 0.09199859374868018, 0.14845120773783751, 0.1257608610072306, 0.11920594131307942, 0.13896873513502733, 0.07225667844925608, 0.11807381920516491, 0.10254431715501205, 0.16875647673649447, 0.20225822047463485, 0.1285835395434073, 0.15289029239543847, 0.07851277132119451, 0.11759661909724985, 0.10794447881302663, 0.11349562129804067, 0.10194519787494626, 0.10842711398644106, 0.09574448024587971, 0.1124356681747096, 0.14034194073506764, 0.1490099134721926, 0.21474303411585943, 0.11772582573550087, 0.07151139594082322, 0.11523723070110593], [0.16398187008287224, 0.04081677871623209, 0.045781833186213455, 0.006735724255642188, 0.01589559544143932, 0.06241657717951706, 0.025285329270575727, 0.03249881469777652, 0.02262132614850998, 0.018852635785671215, 0.01054977934940585, 0.06843916579548802, 0.029692353148545538, 0.04018088623083063, 0.03702924034691282, 0.047644048796168396, 0.0029382413194980472, 0.028694021182933023, 0.05712371226400137, 0.04315546840163214, 0.06886215095541307, 0.02006875374354422, 0.09028763377240726, 0.14703228244824068, 0.019937842286058834, 4.577006833893912, 22.89422229358128, 57.48830427442278, 60.44070502689907, 64.40835571289062, 50.003326075417654, 61.61366517203194, 40.20095688956124, 52.630954129355295, 85.2467120034354, 29.120329345975602, 73.55373450687954, 127.63361385890416, 104.06561606270927, 47.29345914295742, 15.981398718697683, 2.8829891170774187, 0.10795109452945845, 0.10350664265986, 0.047569209776286564, 0.13223830557295255, 0.086518107115158, 0.03562275260420782, 0.10727034070129905, 0.36352462055427687, 0.07921855630619185, 0.1284200804574149, 0.23234900938613073, 4.187588095664978, 26.921281814575195, 55.819208008902415, 75.58696501595634, 87.03414303915841, 86.14357158115932, 85.33272375379289, 84.50209440503801, 81.64508547101701, 79.29037570953369, 83.81242316109794, 86.53499834878104, 81.90202985491071, 74.37835366385323, 81.50402314322335, 79.28639439174107, 80.49351188114711, 78.06190640585763, 77.186190196446, 75.72803429194859, 76.03387314932687, 73.92638029370988, 74.71650164467948, 74.40118544442313, 77.11028807503837, 78.54469503675188, 78.38541453225272, 78.2226390838623, 71.89717279161725, 82.11130959647042, 70.64106355394635, 8.390125240598406, 0.641822582909039, 4.54184547492436, 2.7237641981669833, 1.3616433633225304, 6.438077483858381, 54.929539816720144, 75.16368770599365, 73.94744723183769, 72.06641006469727, 76.21064921787807, 80.10710171290806, 75.65649563925606, 72.59676606314522, 68.2899112701416, 69.33339868273053, 71.02058805738176, 73.6876471383231, 73.60883372170585, 72.99563435145787, 74.08479227338518, 75.7125050680978, 72.72853864942277, 72.39606734684536, 77.60752895900181, 70.10336330958775, 57.45419904163906, 49.809176036289756, 58.635014125279014, 73.16729654584611, 81.20273535592216, 62.46105357578823, 45.813635281154085, 37.453875405447825, 30.972540174211773, 18.414320877620153, 7.1500550508499146, 1.4931876361370087, 0.29519359288471086, 1.6676849126815796, 2.1207141918795447, 1.2017606454236167, 0.3063066122787339, 0.1277950004275356, 0.11609279550611973, 0.011556592154582697, 0.062111575688634596, 0.039334003281380446, 0.0366675404698721, 0.04993128517110433, 0.5513010174036026, 4.159175608839307, 29.775636536734446, 59.5863892691476, 41.21247216633388, 21.203732524599346, 34.317038195473806, 37.07458714076451, 30.394085271017893, 32.153963225228445, 37.3409880229405, 44.68866286958967, 60.21379770551409, 52.5641576222011, 13.553267342703682, 0.09929547791502305, 0.10039230941661767, 0.013481552745880825, 0.03292372689715453, 0.027826744863497357, 0.030589403584599495, 0.029268845516656126, 0.057135227003267834, 0.03995677289952125, 0.042713229810552936, 0.029491944438112632, 0.03243298662294235, 0.026648998060928922, 0.050511710811406374, 0.028514932042786052, 0.05635008056248937, 0.07074080407619476, 0.0972414913454226, 0.005478006163944623, 0.0352731985040009, 0.007703383469821087, 0.044628720597497056, 0.0523434059162225, 0.0523778958512204, 0.035430292931518385, 0.04093137988820672, 0.041668560688516924, 0.10221449485314743, 0.010905486914063138, 0.04453444494200604, 0.07713153186653342, 0.0178583970825587, 0.02775487443432212, 0.01353292293580515, 0.02950038880641971, 0.00980718299147806, 0.010401108085976114, 0.02253720985858568, 0.11012999261064188, 0.004538010398391634, 0.05565271958974855, 0.026188457684059228, 0.03540744665744049, 0.05109569197520614, 0.007072175420554621, 0.05965683276632002, 0.04426211830494659, 0.04910384564261351, 0.017332771626700248, 0.04636666591146162, 0.028195774615077034, 0.04186866405819144, 8.026655418532235, 35.97073725291661, 76.92046328953334, 74.31709834507534, 85.36381694248745, 73.18324960981096, 80.62105996268136, 38.06946843011038, 31.39814165660313, 85.05564349038261, 34.95998280388968, 96.55413396017892, 129.18001883370536, 90.72290693010602, 41.65265791756766, 10.264967220170156, 1.0642643719911575, 0.1463133203131812, 0.07124126436454908, 0.08804123502756868, 0.04608330629499895, 0.021096500202215145, 0.1243929344096354, 0.09024673168148313, 0.19015428211007798, 0.37691485775368555, 0.13316654147846357, 0.6277802735567093, 10.662560514041356, 45.01060765130179, 71.37696811131069, 85.94750731331962, 92.98303086417062, 90.39695998600551, 90.36325427464077, 90.46403789520264, 88.21111229487828, 86.60313933236259, 88.68333966391427, 91.42612716129848, 84.992310660226, 81.08075972965786, 84.56853307996477, 82.3808649608067, 85.61878108978271, 84.2049616404942, 83.44716330936977, 81.87807246616909, 80.40600626809257, 78.78152438572475, 79.76753629956926, 78.73926544189453, 81.62806933266776, 81.26563739776611, 82.30180835723877, 80.71982165745327, 76.75526291983468, 84.30824661254883, 80.23715809413365, 15.215974739619664, 1.2352621448891503, 1.080538573009627, 0.8927300678832191, 1.155674004129001, 12.085557665143694, 64.10589368002755, 78.88090447017125, 79.66486276899064, 79.83459336417062, 82.63161155155727, 85.04089941297258, 81.32685102735246, 75.1096168245588, 71.426682472229, 73.02363559177944, 72.96160902295793, 76.41031265258789, 78.3482277733939, 76.61588205610002, 80.05976363590786, 81.88071972983224, 78.95213045392717, 79.74089690617153, 83.87494305201939, 75.37241159166608, 67.74033655439104, 60.730514390128, 62.368302072797505, 75.56482805524553, 87.1865656716483, 74.95829200744629, 58.91315746307373, 54.52588769367763, 43.848813261304585, 26.672564097813197, 13.45604293687003, 4.329914127077375, 1.029065449322973, 0.7402048951813153, 1.5093782416411807, 0.4780455625482968, 0.3580734059214592, 0.7641032785177231, 0.40188003384641235, 0.2054999079555273, 0.10614167912197964, 0.04294308694079518, 0.0920805132814816, 0.010811954254417546, 0.2607553079724312, 2.3060217797756195, 24.44015826497759, 63.32031645093645, 30.823838302067347, 18.906400987080165, 39.10806431089129, 33.009974343436106, 23.253230503627233, 41.79045111792428, 54.61707237788609, 63.52796336582729, 74.42775535583496, 65.27344812665666, 27.148055383137294, 0.13032490467386587, 0.012799367208832076, 0.01078294009702014, 0.024258795693250637, 0.04877503775060177, 0.027905085124075413, 0.04016183975285717, 0.013458102575636335, 0.03305121684180839, 0.03570242618609752, 0.07327306283903973, 0.022734497307932804, 0.038186274868037016, 0.05421071732416749, 0.06163815502077341, 0.07583131627844912, 0.03430744639730879, 0.06599555763282947, 0.047847080044448376, 0.01325166508156274, 0.021627922043470398, 0.06397015774356467, 0.0776477273819702, 0.021540845644527247, 0.028464686524655138, 0.013001294141369206, 0.014127783560460168, 0.28817452809640337, 0.1352129623826061, 0.13824419544211455, 0.20610621970679077, 0.09783098899892398, 0.08556454149740082, 0.06698676837342125, 0.05954144788639886, 0.07801012615008013, 0.0655926571094564, 0.12820802469338688, 0.20258796135229723, 0.13856503394033226, 0.08365123559321676, 0.1619523854127952, 0.15438091169510568, 0.09325904718467168, 0.25506891310214996, 0.15770451192344936, 0.10876555368304253, 0.14538454157965525, 0.13479328847357205, 0.20629904578839028, 0.2282659113407135, 0.15487727363194737, 8.881483605929784, 44.46371841430664, 93.03588581085205, 86.3255101612636, 91.45663670131138, 74.51428822108677, 77.0249433517456, 54.62364884785244, 71.39819485800606, 115.72638865879604, 48.24633509772164, 101.62243488856724, 139.64168521336146, 113.43251732417515, 63.95656994410923, 25.316742999213083, 4.8244960222925455, 0.26025167214018957, 0.36638684411134037, 0.1766317170113325, 0.36522188090852326, 0.24248333701065608, 0.3015994520059654, 1.0305757054260798, 1.0919215679168701, 2.231379670756204, 0.9019637352653912, 0.34475303068757057, 6.5875736219542365, 36.761883463178364, 69.0588823046003, 84.71862806592668, 96.00272492000035, 93.6262811933245, 92.82265949249268, 93.72766235896519, 89.49397209712437, 88.04705142974854, 90.32285744803292, 92.57688086373466, 88.01290798187256, 85.33750411442348, 87.26258591243199, 82.85764339991978, 88.42194148472377, 86.90280818939209, 85.84408337729317, 85.28640011378697, 82.46972547258649, 82.33809879847935, 80.65262562888009, 80.64097349984306, 85.38480745043073, 88.02100958142961, 87.93321214403424, 84.5427552631923, 80.38992118835449, 89.90005956377301, 77.60821683066231, 11.099642157554626, 3.4095518333571295, 9.273276891027178, 5.712310348238264, 4.290252506732941, 8.455554689679827, 60.59233556474958, 78.44773292541504, 82.3186160496303, 81.22694287981305, 83.26386288234166, 87.48615115029472, 84.10203797476632, 77.69465936933244, 72.96207455226353, 74.70116697038922, 74.32532501220703, 78.35767037527901, 80.48901639665876, 78.53302901131767, 81.19543974740165, 82.37722410474504, 79.09134456089565, 82.73850958687919, 85.07023470742362, 74.01009219033378, 66.88693101065499, 62.916417666843955, 63.59306103842599, 75.53760501316616, 85.73747716631208, 70.17930712018693, 56.466658524104524, 51.28005756650652, 36.975012506757466, 19.9200667313167, 9.110694255147662, 1.8282625590051924, 1.3439869050468718, 4.138776566301074, 7.275018402508326, 3.5401304151330675, 0.5114463131342615, 0.35047633786286625, 0.28502615275127546, 0.37523309513926506, 0.3449719532259873, 0.11566959321498871, 0.2605789160089833, 0.13904137909412384, 0.5221223288348743, 7.100325056484767, 40.12868520191738, 73.57469722202846, 51.47254351207188, 33.34117759977068, 51.611893108912874, 51.51941953386579, 43.40215526308332, 43.526246615818565, 52.634605407714844, 61.97297041756766, 76.29857172284807, 78.75332859584263, 26.33490596498762, 0.19415868366403238, 0.1812135111540556, 0.12794858004365647, 0.18934081361762115, 0.16079059775386537, 0.0707627682547484, 0.056001116787748675, 0.09952346568128892, 0.07991153055003711, 0.18662110955587455, 0.1005858276039362, 0.07070616486349277, 0.11287275329232216, 0.14166944021625177, 0.12148181561912809, 0.15896812054727757, 0.20116234570741653, 0.19408004145537103, 0.2222662911351238, 0.13923541296805653, 0.10164001996495894, 0.13491227637444222, 0.13810937053390912, 0.19018857526992047, 0.14466842929167406, 0.1028186081509505, 0.18087074240403517], [0.060064014845660756, 0.043379015156200955, 0.06915935607893126, 0.011017415506233062, 0.0362969891035131, 0.007339667495606201, 0.08328313034559999, 0.03186473050819976, 0.025021558960101435, 0.052198202814906836, 0.03997575830934303, 0.02100398873777262, 0.04019016858988574, 0.023265354268785034, 0.007951979192772081, 0.032456029672175646, 0.01888448452310903, 0.14061667956411839, 0.03775643650442362, 0.036559928208589554, 0.04379343041884048, 0.03626361535862088, 0.04166125625904117, 0.1973629838653973, 9.783204317092896, 46.28997598375593, 57.97066906520298, 64.74043791634696, 64.45308821541923, 55.821334157671245, 58.61087608337402, 43.31553207124983, 51.62227371760777, 73.331558908735, 33.40153660093035, 82.23375770023891, 122.22766521998814, 62.24176842825753, 34.39048760277884, 6.520032789025988, 0.3942702093294689, 0.08644553779491357, 0.056811901674206765, 0.05035367661288806, 0.15461362206510135, 0.023204593154202615, 0.06651091855019331, 0.0904071916426931, 0.2804479684148516, 0.1534640344658068, 0.26678509584494997, 6.477778187819889, 33.96299968447004, 73.05918952396938, 84.35992036546979, 83.21849114554269, 86.15921892438615, 86.88463170187813, 86.72719247000558, 91.25857830047607, 86.74026203155518, 85.74749646868024, 81.77988052368164, 76.8301922934396, 78.47861071995327, 79.79452310289655, 77.01772417340959, 84.69007791791643, 82.43589469364711, 77.62301649366105, 74.57025596073696, 76.63555240631104, 74.64124570574079, 77.59636320386613, 76.56386089324951, 76.28505052839006, 75.42421736036027, 76.2821044921875, 73.56348282950265, 76.54938779558454, 74.78157152448381, 78.71233422415597, 70.57793916974748, 80.45909745352608, 59.51725469316755, 4.033915655953543, 0.15090420682515415, 0.27006950389061657, 7.77508807182312, 59.989287512642996, 84.07268183571952, 75.68540014539445, 72.63249370029995, 76.75444998059953, 77.28001867021833, 73.43366963522774, 73.11053671155656, 69.01174572535923, 68.92140524727958, 65.90648460388184, 69.34022876194545, 70.52561228615897, 73.00176266261509, 68.4152637209211, 71.64065224783761, 72.34165600367955, 72.88744395119804, 72.5953347342355, 75.71893909999302, 78.24833352225167, 73.45389584132603, 69.92628846849713, 66.42115851811, 66.75451224190849, 76.41066701071603, 76.84687491825649, 75.17340823582241, 71.36125128609794, 76.30702073233468, 72.26992974962506, 62.318615504673545, 51.73648125784737, 27.635686908449443, 6.0003691996846875, 0.10182566036071096, 1.2676265282290322, 1.5488524777548653, 1.467942442212786, 0.06480891523616654, 0.06700165543173041, 0.05385628116450139, 0.06754647155425378, 0.04695991925629122, 0.09385505198900189, 0.7256053185888699, 0.03731451343212809, 4.066921770572662, 27.1618458202907, 33.79909862790789, 25.980447087969097, 23.865118401391165, 44.44542728151594, 50.15590156827654, 27.204424381256104, 33.91504669189453, 41.83761201586042, 50.14310993467058, 58.83534458705357, 52.484222071511404, 13.2167261328016, 0.3320972126509462, 0.003805427945085934, 0.05854580631213529, 0.04030930916113513, 0.048685701830046516, 0.0482970369713647, 0.011178179111863886, 0.07073509759668793, 0.07729490952832357, 0.0568845320626029, 0.05562418719221439, 0.01985877938568592, 0.022038294933736324, 0.03353842194857342, 0.026308816225667084, 0.004450947146064469, 0.009073768060521355, 0.0762490156505789, 0.03629119780712894, 0.043544201113815816, 0.02711563677127872, 0.029499303150389875, 0.045479206567896266, 0.05718446150422096, 0.04589829693681427, 0.02902327012270689, 0.0317831298868571, 0.055433064233511686, 0.0778345280726041, 0.009472602462795163, 0.08619652222841978, 0.026482061482965946, 0.0706136669697506, 0.03026397818965571, 0.04326167609542608, 0.05172991865713682, 0.05038092318656189, 0.08961098508111068, 0.029902352951467037, 0.047637908054249625, 0.06296336105359451, 0.005913640064786055, 0.0588005826409374, 0.01666789042896458, 0.03405234097902264, 0.08692916362945523, 0.05585197479064975, 0.027936866008011357, 0.06580803090972559, 0.29584238092814175, 16.605333055768693, 61.55343123844692, 77.04619789123535, 80.45385156358991, 83.58264623369489, 71.79242174965995, 71.87259701320103, 52.646208899361746, 28.03006144932338, 64.18513093675885, 41.00702783039638, 96.4340135029384, 112.30993161882672, 56.03440066746303, 36.65628126689366, 5.278354091303689, 0.1790665720722505, 0.12604364726160253, 0.04034670661868794, 0.03815919792811785, 0.20924466129924568, 0.07168434773172651, 0.32450421580246513, 0.102766849499728, 0.5346158412950379, 0.40161260962486267, 0.8978555042828832, 13.596914189202444, 49.53578526633126, 87.41147886003766, 90.45549161093575, 87.81924779074532, 91.22654710497174, 90.47456441606793, 91.72387831551688, 95.03884996686662, 90.74470342908586, 90.30643885476249, 86.77415534428188, 79.6858880179269, 81.90394060952323, 84.61265414101737, 86.26549162183488, 88.25681059701103, 86.9545236315046, 81.64049965994698, 78.38379560198102, 81.66326890672956, 80.33483586992536, 81.52754974365234, 80.9303173337664, 81.00930445534843, 79.6456162588937, 79.49221393040249, 77.3336935043335, 80.1565659386771, 77.54937948499406, 83.26594039372036, 76.04772785731724, 82.21303122384208, 72.22506523132324, 8.74605279309409, 0.19415371678769588, 0.571988464466163, 12.909636599676949, 70.28129972730363, 85.50032125200543, 81.46172251020158, 77.65966129302979, 79.0138999394008, 81.06382696969169, 76.32117421286446, 79.06483023507255, 75.67707620348249, 75.81815242767334, 72.8326643535069, 74.13906465257917, 78.00800922938755, 77.71691444941929, 75.22955662863595, 76.85404545920235, 76.78943416050502, 77.23696763174874, 76.36931828090123, 79.0424222946167, 82.89535127367292, 77.98735918317522, 77.3283920288086, 75.24300139290946, 72.7231468473162, 77.94241823468889, 80.81676292419434, 78.35831655774797, 75.91315514700753, 80.3629343850272, 81.14054897853306, 74.77892426082066, 63.20885344914028, 43.01932341711861, 13.881062507629395, 1.806073921067374, 0.9528890912021909, 0.33584218312587055, 0.849949086351054, 0.6742784870522363, 0.6057922105704034, 0.16240985372236796, 0.07601214586091892, 0.06355302834085055, 0.2047514295471566, 0.6585717041577611, 0.07266974342720849, 3.1432827498231615, 28.589521714619227, 34.70511940547398, 21.61770793369838, 15.414517777306692, 37.60029132025582, 36.60840123040335, 24.52556378500802, 51.33711617333548, 58.961266790117534, 69.64932632446289, 70.19198758261544, 64.48906598772321, 25.140917096819194, 0.6491966843605042, 0.06800381772752319, 0.06882263307592698, 0.009688698902859219, 0.03297954658046365, 0.015541807282716036, 0.03927876713818737, 0.03773170390299388, 0.07098613519753728, 0.031827953910189014, 0.017964492818074565, 0.07364193483122758, 0.024652032181620598, 0.06564273977918283, 0.007006340560370258, 0.03985153890347906, 0.031180896131055694, 0.0612913557727422, 0.04358799715659448, 0.01763066037424973, 0.05645798798650503, 0.025880278952951943, 0.03200189975489463, 0.07450141478329897, 0.01790998949270163, 0.07561075168528728, 0.16460970496492727, 0.12225740828684398, 0.27226909728986876, 0.06349230624203171, 0.15998067121420587, 0.0717747693083116, 0.1679674626461097, 0.12802537663706712, 0.1656833780663354, 0.12009239303214209, 0.14011662639677525, 0.11911675467022828, 0.14075389291558946, 0.1339883559516498, 0.10444188783211367, 0.14146568972085202, 0.1921236485775028, 0.2408836499920913, 0.14826162505362714, 0.12137303288493838, 0.14229179253535612, 0.08186794378395591, 0.15406915199543747, 0.33460111543536186, 18.35916086605617, 69.05838203430176, 89.87669972011021, 92.38111536843437, 87.79679121289934, 80.56426538739885, 81.84361634935651, 62.27208341870989, 75.11605085645402, 105.84728704180036, 47.27230535234724, 103.55697318485805, 130.91050938197543, 76.98907675061906, 53.63040733337402, 13.135929005486624, 0.735086841242654, 0.23890596468533787, 0.36758038720914293, 0.0984369343412774, 0.6889062364186559, 0.1220842461500849, 0.35434729872005327, 0.320432435721159, 1.0786879637411662, 0.7564197650977543, 0.5560758411884308, 9.691583633422852, 42.470342772347585, 85.36685330527169, 91.1510340826852, 91.49592876434326, 95.51960972377232, 94.85182530539376, 94.65261350359235, 99.25445406777519, 94.69845076969692, 91.4656207220895, 87.00182696751186, 82.05741936819894, 83.28814683641706, 87.89164107186454, 89.18478420802525, 89.90581267220634, 90.55854729243687, 86.40940965924943, 82.56306062425885, 85.25090176718575, 83.02974333081926, 83.4104837690081, 85.1933706828526, 85.0886960710798, 85.04479040418352, 82.65454755510602, 77.85664967128209, 81.18838732583183, 80.3882188796997, 88.23851599012102, 78.56751986912319, 85.5111882346017, 70.41785267421177, 6.376593743051801, 0.7075820714235306, 0.6617116385272571, 9.97615839753832, 67.12190519060407, 86.94932637895856, 83.78426906040737, 79.51352405548096, 82.73219367436, 82.22701099940709, 81.11274923597063, 81.57337311335972, 78.75029918125698, 77.3230836050851, 72.76554475511823, 77.62885992867606, 81.49218341282436, 82.03376770019531, 75.79939923967633, 78.45511886051723, 78.62721184321812, 77.67825467245919, 76.10484204973493, 80.36222566877092, 85.33362701960972, 81.63199506487165, 80.48722376142229, 76.00476714542934, 70.67819472721645, 78.47133595602853, 82.13674000331334, 82.25741631644112, 77.80871404920305, 83.88945089067731, 84.04491683415004, 73.92497675759452, 60.44067028590611, 35.36678940909249, 8.267454794475011, 1.332829618028232, 5.692828902176448, 5.560626396111079, 3.175611197948456, 0.35117897444537705, 0.2533845991960594, 0.2531655409506389, 0.22994468840105192, 0.24265869760087558, 0.3397392268691744, 1.0418004116841724, 0.19867681765130588, 8.780278750828334, 39.583237716129844, 47.4224385534014, 35.77446106501988, 35.57052101407732, 60.5943991797311, 72.28639003208706, 43.24496964045933, 45.03439480917794, 57.02603367396763, 66.6721830368042, 74.43309157235282, 74.30061026981899, 27.070508275713237, 1.012952793921743, 0.08609815500676632, 0.1678959857672453, 0.16314964688249997, 0.08541937571551118, 0.10258868655988149, 0.0848605071327516, 0.12664952475045407, 0.16608965769410133, 0.1156863666006497, 0.17806042677589826, 0.2543625852891377, 0.11718534545174666, 0.15323524602821895, 0.08478497261447565, 0.08607775824410574, 0.08927586342075042, 0.16763549617358617, 0.2168622346861022, 0.11599474719592504, 0.14889574316995485, 0.12583000372563088, 0.14636335548545631, 0.17657125954117092, 0.11479004898241588, 0.128747555028115], [0.004320484369860164, 0.028052415432674543, 0.08965723402798176, 0.03140648188335555, 0.047408685354249816, 0.021749564712601047, 0.033832417601453404, 0.01811326670992587, 0.07442068268678018, 0.007188288029283285, 0.01476805514123823, 0.064554159263415, 0.03889282999028053, 0.07846483960747719, 0.036034168742064915, 0.030949485155620744, 0.03110421828127333, 0.020611264543341737, 0.06482487437980515, 0.01688050089537033, 0.020816093909421136, 0.0468691618048719, 0.12428363598883152, 16.025914090020315, 44.96410683223179, 74.3617752620152, 67.85654517582485, 61.33418083190918, 44.726732049669536, 51.20620516368321, 50.13564756938389, 29.84897129876273, 55.627166748046875, 48.232998030526296, 82.10577883039201, 69.92563533782959, 34.75377416610718, 33.87135294505528, 16.238905906677246, 0.8858824010406221, 0.114529532247356, 0.010379064179557775, 0.03649375068822077, 0.054250048606523445, 0.14198318123817444, 0.035326840089900155, 0.29459982046059197, 0.1483478939958981, 0.8455152671251978, 8.432904430798121, 35.48213297980172, 66.69104044778007, 90.2436271395002, 87.07171889713833, 84.82748549325126, 87.57878453390938, 86.76537976946149, 84.72155325753349, 85.20286192212785, 83.0627611705235, 84.63893917628697, 82.25648525782994, 83.49430683680943, 79.39126355307442, 80.26745918818882, 76.09467683519635, 79.3523953301566, 81.8512385232108, 75.94727080208915, 80.44715350014823, 82.1516022000994, 81.50624656677246, 77.28055368150983, 75.18182945251465, 73.01692363194057, 71.00966548919678, 69.4927625656128, 70.49884782518659, 72.902222769601, 75.94502653394426, 77.97027356284005, 76.19107614244733, 73.99717548915318, 75.1708790915353, 85.27867371695382, 43.18033054896763, 2.0033033149582997, 4.716968306473323, 45.439954212733674, 79.39079107557023, 74.83583695547921, 73.23083087376186, 72.33201885223389, 73.4218715940203, 75.58341448647636, 70.4339794431414, 71.76080049787248, 71.3661219733102, 70.57015023912702, 71.4053167615618, 71.52354036058698, 70.27575506482805, 71.97406155722481, 74.15199525015694, 74.57672473362514, 74.83460017613002, 73.8022437776838, 76.50719138554165, 72.02040604182652, 74.13907854897636, 70.60433537619454, 67.55735574449811, 69.07398074013847, 70.84013639177594, 76.54662241254533, 71.43971034458706, 71.9971365247454, 69.81930705479213, 66.89236450195312, 66.01870495932442, 70.39131750379289, 69.63104561397007, 74.83657346452985, 66.86296667371477, 36.98238107136318, 4.333955373082842, 1.2223425124372755, 3.4030459310327257, 0.8137943521142006, 0.6451304139835494, 0.6909145915082523, 0.10139645303466491, 0.06661876490605728, 0.11749857078705515, 0.10928387979843787, 0.07915899450225489, 0.38808324560523033, 11.912914037704468, 30.173028332846506, 33.66838564191546, 33.081422669546946, 30.522911821092876, 48.330786977495464, 37.27795049122402, 30.546792779650005, 31.404627799987793, 39.809804575783865, 57.29780551365444, 52.02448408944266, 48.941418988364084, 14.132027966635567, 0.4503347080733095, 0.027647903388632194, 0.1100504615211061, 0.026884975577039377, 0.011069314105303159, 0.03300392634368368, 0.033699764005307636, 0.05640840743269239, 0.007579803583212197, 0.010155719289157008, 0.0037595046950238092, 0.013977711970385696, 0.02859609161636659, 0.018858520380620445, 0.05437710089609027, 0.07967902374054704, 0.06024846780513014, 0.02501075159359191, 0.03250226165567126, 0.030143025929906538, 0.06376956243600164, 0.0368705615401268, 0.023645511994670545, 0.02403064338224275, 0.05502082367560693, 0.017769274900534322, 0.023570533875109892, 0.026706795673817396, 0.041056165870811255, 0.033492983851049624, 0.04105621676093765, 0.041248425375670195, 0.01346138583695782, 0.034035435279033015, 0.058346208451049666, 0.00951943579795105, 0.057784116826951504, 0.06892306304403714, 0.03828029268022094, 0.02516475020508681, 0.02982271329632827, 0.041480151869888814, 0.020007309004930512, 0.09158002585172653, 0.009504241702545966, 0.0640017706900835, 0.0686140310551439, 1.1000689821583884, 25.00992270878383, 61.85020269666399, 88.00768988473075, 82.45628070831299, 83.12307153429303, 65.95243304116386, 69.81414454323905, 58.36457633972168, 21.83996169907706, 44.858018262045725, 61.74939128330776, 91.01637799399239, 62.59027617318289, 36.103444371904644, 39.881124360220774, 13.687609025410243, 0.35070657836539404, 0.13692509622446128, 0.05946950960372176, 0.2623670186315264, 0.14211345996175492, 0.24074894722018922, 0.13173889022852692, 0.5321678497961589, 0.30277635742511066, 2.3073567024299075, 15.800535372325353, 52.410314083099365, 81.09983948298863, 97.35041836329869, 88.93332195281982, 92.86415413447789, 95.0789897101266, 91.10832350594657, 87.66503252301897, 87.80287088666643, 86.49426800864083, 89.55642250605992, 87.84220463888985, 86.48787566593715, 84.5925738470895, 82.6103014264788, 81.13993058885846, 82.50464017050606, 82.74636799948556, 80.26306792667934, 83.77108832768032, 87.49651091439384, 85.0695468357631, 81.53925745827812, 76.37344551086426, 76.59468310219901, 74.47457926613944, 73.3363253729684, 75.05027226039341, 74.30445262363979, 79.99930735996791, 82.8408009665353, 80.26405457087925, 77.64115824018205, 78.76855904715401, 88.243136542184, 55.03523233958653, 4.664882004261017, 9.219135659081594, 54.812883036477224, 83.76324381147111, 78.49073532649449, 77.25685337611607, 75.74244485582624, 77.3445187977382, 79.40609795706612, 75.25568185533795, 76.48833397456578, 74.06874888283866, 74.08266612461635, 73.35855960845947, 74.67941910879952, 73.92712375095913, 76.03709016527448, 78.03052834102085, 79.24453844342912, 78.99587631225586, 80.03044918605259, 79.6384526661464, 77.67310605730329, 78.18124171665737, 75.84468759809221, 71.2701187133789, 71.63872759682792, 74.5985003880092, 81.7944369997297, 75.72731167929513, 77.26002870287213, 75.96310574667794, 73.06888226100376, 68.80662100655692, 73.06615856715611, 72.65003095354352, 80.14509446280343, 76.9437119620187, 55.187071323394775, 11.713033471788679, 1.3223770303385598, 1.5581989990813392, 0.7708898772086415, 1.2382186033896037, 2.7267080630574907, 0.7339595503040722, 0.1682031178580863, 0.1046700995149357, 0.057346393886421404, 0.06183909638119595, 0.20981648990086146, 11.521199788366046, 31.114352907453263, 32.81297901698521, 26.178891113826207, 25.61595674923488, 37.197424343654085, 16.77648455756051, 30.24129090990339, 43.33959020887102, 55.71873705727713, 80.31041295187813, 62.24417250497, 67.83795874459403, 29.397022247314453, 2.9130088090896606, 0.06927457811044795, 0.09059205172317368, 0.03096934248294149, 0.013328545643681926, 0.026983576893274273, 0.044358039407857826, 0.04066911253279873, 0.01982672369506742, 0.026237763431189314, 0.0431507186565016, 0.018122618618820394, 0.0289109115089689, 0.06535538698413543, 0.025170287050838982, 0.032713123198066435, 0.034154731913336685, 0.014995835954323411, 0.03869872487017086, 0.010982351360975631, 0.04980064682396395, 0.04254528560808726, 0.037034634700311084, 0.06720843219331332, 0.02436850293140326, 0.12305807960884911, 0.13773286502276147, 0.11551032747541155, 0.08496589040649788, 0.134690205433539, 0.12412122184676783, 0.08515444850283009, 0.10586476898086922, 0.10964182059147529, 0.14652947442872183, 0.07881969985152994, 0.14993448528860295, 0.15535629221371242, 0.24070058124405996, 0.1251910137278693, 0.16849734421287263, 0.07895866382334914, 0.137058767623135, 0.14673086362225668, 0.10500469870333161, 0.17987219669989177, 0.19252402495060647, 0.9376148879528046, 26.25950411387852, 74.16983127593994, 100.87769222259521, 90.60133429936, 85.81478977203369, 65.98157378605434, 74.17730058942522, 74.37654713221959, 46.61708675112043, 89.47661549704415, 66.98639447348458, 104.5737864630563, 82.49771976470947, 50.33334813799177, 53.622517653873985, 24.848582063402446, 1.284306330340249, 0.2765640882509095, 0.1385884026863745, 0.4163838284356253, 0.273795339678015, 0.2922777922025749, 0.6712552607059479, 1.280052295752934, 0.626145275575774, 1.647154288632529, 12.41606262751988, 45.310161863054546, 75.38225718906948, 100.97948333195278, 93.69351196289062, 95.03746032714844, 97.972275188991, 93.09462588174003, 91.5366382598877, 92.11206722259521, 91.1252076285226, 92.76473236083984, 89.4897267477853, 90.30300644465855, 84.93426540919712, 85.20778819492885, 83.85530049460274, 85.31943879808698, 84.69689410073417, 81.69281959533691, 86.40816593170166, 89.70856026240757, 87.71497617449079, 85.27590833391461, 80.93759209769112, 79.68547112601144, 75.82835238320487, 77.74499211992536, 79.15296118600028, 81.48268522535051, 85.40760449000767, 86.47582054138184, 82.75767271859306, 79.66716262272426, 82.96010848454067, 87.73054708753313, 52.389337471553254, 2.8724437057971954, 7.099222029958453, 55.012014933994834, 83.65997968401227, 80.92613451821464, 79.27532591138566, 78.02328136989048, 79.01203782217843, 82.29023960658482, 77.4275289263044, 77.37806470053536, 78.18050520760673, 77.02989046914237, 77.29437364850725, 77.05377837589809, 74.39381340571812, 76.08400440216064, 79.43871974945068, 80.11155550820487, 80.08567346845354, 83.42540849958147, 81.6125123160226, 80.08665316445487, 78.27584838867188, 75.34863485608781, 71.09963771275112, 73.30191789354596, 75.83504349844796, 82.00020095280239, 76.5500339780535, 79.76739038739885, 78.47747816358293, 73.01353985922677, 70.38873972211564, 75.58182334899902, 78.63780089787075, 85.47551618303571, 82.4812455858503, 50.22319834572928, 6.5484322479793, 5.092366882732936, 9.461580889565603, 2.4765954954283576, 1.5191349238157272, 1.8983349246638161, 0.24346406438520976, 0.24611154517957143, 0.20939327403903008, 0.211011159366795, 0.1349928184811558, 0.9752385147980281, 21.885204894202097, 45.428104060036794, 45.59562165396554, 45.69275747026716, 48.09722328186035, 64.39766938345772, 54.1629832812718, 45.18763732910156, 46.01085294995989, 55.1583822114127, 75.87048625946045, 67.69943250928605, 76.52540261404855, 33.1893664087568, 2.958413766963141, 0.15295335544007166, 0.17211206310561725, 0.11209019885531493, 0.0511064026504755, 0.14813761599361897, 0.12106206028589181, 0.18908402882516384, 0.08716637268662453, 0.13147040749234812, 0.1743114800857646, 0.10858338060123579, 0.13668675401381084, 0.2000432921839612, 0.1077773692086339, 0.16294126877827303, 0.14090222067066602, 0.046922606615615745, 0.11070493568799325, 0.08458582937185254, 0.16785171814262867, 0.1314658477370228, 0.08210087128515754, 0.16451528003173216, 0.12680618491555962], [0.007226291079340237, 0.059375539288989136, 0.03140082290130002, 0.011897628095799258, 0.01177104314722653, 0.005098834434258086, 0.015641400956415703, 0.0446252329275012, 0.011847093352116644, 0.09071450015263897, 0.026999420685959712, 0.0497067918601845, 0.06542910981391158, 0.09099623467773199, 0.04170850943773985, 0.10061737269695316, 0.044465997721999884, 0.0011889408280174913, 0.018152596295944283, 0.006435773609804788, 0.042921723265733035, 1.947913578578404, 26.992799622671946, 51.29748017447335, 65.5053859438215, 64.64752660478864, 63.1612582887922, 66.89243398393903, 60.71315779004778, 34.8957918712071, 33.51023769378662, 44.388816833496094, 39.26688623428345, 58.537412779671804, 38.54307849066598, 26.599670546395437, 35.58111701692854, 15.115495102746145, 1.6030052176543643, 0.10952675462301288, 0.029492941884590045, 0.15708867354052408, 0.025310294270249348, 0.16207670659891196, 0.14003548717924527, 0.061915465497544835, 0.3292877791183335, 3.3251323061329976, 25.916815485273087, 67.95581408909389, 89.5487516948155, 88.13383443014962, 84.87974289485386, 88.60828522273472, 87.50686373029436, 81.18268980298723, 80.66809231894356, 79.8954804284232, 84.59715270996094, 85.44043472834996, 85.24000699179513, 88.07777636391776, 79.93851062229702, 80.75155408041817, 75.13318511417934, 75.69419656481061, 79.26079722813198, 79.18451295580182, 82.17214802333287, 82.11941814422607, 81.37014525277274, 77.78074060167584, 77.26599025726318, 74.36833436148507, 72.04584339686802, 70.57506956372941, 70.06899057115827, 69.4274981362479, 67.55469458443778, 68.90479905264718, 73.70152269090924, 75.55042443956647, 73.30939415522984, 76.87188148498535, 76.48622867039272, 78.12285600389752, 27.287842716489518, 22.16865144457136, 63.472572326660156, 81.42009585244315, 74.02754606519426, 76.24878787994385, 76.89985493251255, 77.35484382084438, 72.2868903023856, 71.46913596561977, 71.72439193725586, 69.75505706242153, 69.00588839394706, 69.05436597551618, 68.78167002541679, 70.37573964255196, 71.61770234789167, 71.31480257851737, 71.36559391021729, 72.51057365962437, 76.23306410653251, 76.65684168679374, 75.73691408974784, 72.758652142116, 74.00532572610038, 71.38657746996198, 66.05941445486886, 72.14443138667515, 74.48909405299595, 74.18911252702985, 71.09016731807164, 70.23365592956543, 72.68526526859829, 73.31969833374023, 68.1594102042062, 66.67275278908866, 64.40858500344413, 65.37958880833217, 69.44992692129952, 67.52742985316685, 16.62369888169425, 0.5154656831707273, 2.7677914585386003, 1.1244508624076843, 1.016980143530028, 0.7273602815611022, 0.31369151600769585, 0.1529095627899681, 0.2800137060029166, 0.06782505767686026, 0.03277213878131338, 0.7723890053374427, 11.354059134210859, 26.395172902515956, 28.060317380087717, 30.215506144932338, 40.13756847381592, 47.21388142449515, 32.28044475827898, 31.204592636653356, 32.837124007088796, 37.13858004978725, 51.647026675088064, 57.6318610055106, 60.81917340414864, 28.253395659582957, 1.9786899728434426, 0.09011439021144595, 0.035531275905668736, 0.014463167304971387, 0.03335482733590262, 0.008520521140391273, 0.02543187587122832, 0.009105593049233513, 0.022143589997930185, 0.03909526752041919, 0.023773434505398785, 0.05015365466741579, 0.00631940018917833, 0.018530182374109114, 0.02965771732851863, 0.03361019059749586, 0.01304999175148883, 0.06425025021391255, 0.026651483195434724, 0.07621475641748734, 0.04535862410973225, 0.039481493045708964, 0.02394043724052608, 0.05412494371246014, 0.005007205913508577, 0.03736687937219228, 0.022279149420293312, 0.018415884846555333, 0.04036833152973226, 0.01366099642057504, 0.042157441776778014, 0.0283780545661492, 0.023868213973141143, 0.01891240115011377, 0.047372373552726846, 0.025610676633992364, 0.04719477379694581, 0.05615832317354424, 0.019047835043498447, 0.13160620949098042, 0.03928976958351476, 0.04336974297517112, 0.043286130497498174, 0.028213168860280087, 0.038028325486396036, 4.587087801524571, 44.59935767310006, 70.38852432795933, 82.99364049094063, 82.07344886234829, 85.20446695600236, 84.21653733934674, 74.8850371497018, 49.79501213346209, 40.725556305476594, 24.08204116140093, 45.66750076838902, 74.39603682926723, 40.19410596575056, 35.80021456309727, 38.67804377419608, 12.007819482258387, 0.7872657499143055, 0.09718989554260458, 0.04273054263155375, 0.06831377252404179, 0.20085131882556848, 0.48342379395450863, 0.23129795864224434, 0.28536658734083176, 0.2531360925308296, 6.16430847133909, 37.70446218763079, 84.1419484274728, 96.32333564758301, 92.47798020499093, 88.12798404693604, 92.83921704973493, 87.91834994724819, 83.13402189527238, 82.29831341334751, 87.54992171696254, 91.00541373661586, 91.80716637202671, 90.40266445704869, 91.75174059186662, 83.14593110765729, 82.99358490535191, 78.25631005423409, 81.69618252345494, 81.71353217533657, 82.63869871412004, 87.31853975568498, 84.24874918801444, 85.35927976880754, 81.2439659663609, 80.46871376037598, 80.46218940189907, 78.33538750239781, 76.14892836979458, 75.02005454472133, 74.69139085497174, 70.2312240600586, 72.92472103663853, 75.1878604888916, 78.3069624219622, 78.78861849648612, 82.26610156467983, 81.45778288160051, 83.909058707101, 37.078617095947266, 28.460821969168528, 68.81704330444336, 84.14684690747941, 78.66505868094308, 80.42651040213448, 80.56588431767055, 78.67883695874895, 75.14961065564836, 75.22952188764299, 75.65904562813895, 72.27389022282192, 76.07502732958112, 72.49536405290876, 73.36864144461495, 75.49888965061733, 74.3749282019479, 75.19191823686872, 76.09785911015102, 75.46270343235561, 79.25049999782017, 79.66860089983258, 77.79566533224923, 77.35558727809361, 78.33502619607108, 76.64321626935686, 70.78474535260881, 77.17191164834159, 75.56447369711739, 77.3424482345581, 73.67408425467355, 74.17392376491001, 76.23769160679409, 76.4905504499163, 75.14975656781877, 71.27125821794782, 68.4582383292062, 68.08971977233887, 74.30551569802421, 80.05000141688755, 30.58549424580165, 1.3100681879690714, 2.0075797140598297, 0.9128082990646362, 1.97380365218435, 6.334018221923283, 1.1067931013447898, 0.40873084909149576, 0.22476408710437162, 0.053706911858171225, 0.11295595525630883, 0.15239421544330461, 9.074293511254446, 26.726435218538555, 28.85164945466178, 30.79456901550293, 43.22667850766863, 40.85958010809762, 12.827527131353106, 33.457803113119944, 43.25929682595389, 49.185821873801096, 66.8952271597726, 69.35365268162319, 73.79706042153495, 50.433989320482524, 4.82142231294087, 0.05026408624170082, 0.04483070011649813, 0.050222254557801146, 0.051957618046019755, 0.017842039299596633, 0.025451415983427848, 0.034567515299256356, 0.030115419732672826, 0.018176847137510777, 0.009765598124691417, 0.027414550106706362, 0.009900601148339254, 0.041434340578104766, 0.04026418658239501, 0.02777306765450963, 0.003969491351329322, 0.09017618439559426, 0.07541702315211296, 0.037859119208795686, 0.06143802111702306, 0.005467561813670078, 0.05330626746373517, 0.02511211115467761, 0.12615389563143253, 0.18522572943142482, 0.11378323193639517, 0.057953798079064915, 0.08750876824238471, 0.11600934926952634, 0.14910889816071304, 0.13054430218679564, 0.11674536977495466, 0.1843174695968628, 0.1369166009660278, 0.17724687685923918, 0.1406570795391287, 0.1906671053064721, 0.13838647066482476, 0.2446685726089137, 0.16457250767520495, 0.09788904445511953, 0.08208774841789689, 0.09488959397588458, 0.20686901520405496, 3.679266571998596, 47.33728837966919, 82.0486785343715, 93.90875325884137, 85.71807779584611, 86.49774905613491, 89.87437902178083, 82.76046589442662, 48.983719621385845, 54.8816945212228, 68.13821819850376, 56.92027166911534, 81.42568220411027, 54.97745112010411, 42.85595389774868, 53.88480520248413, 24.896561111722672, 2.4312756529876163, 0.24797225104910986, 0.1029725813173822, 0.3151372027184282, 0.19533029651003225, 0.8492297306656837, 1.7872254124709537, 0.41965621284076143, 0.6356069850070136, 4.628448256424495, 31.986695766448975, 78.38100937434605, 98.79622731889997, 96.53913279942104, 90.2398681640625, 97.50339685167584, 94.16968590872628, 86.37317480359758, 88.66342612675258, 88.75324548993791, 91.96507808140346, 92.59770461491176, 90.40184456961495, 92.5081353868757, 84.99566664014543, 84.30648871830532, 81.97661876678467, 84.9276715687343, 84.53957993643624, 85.3037358692714, 88.78383146013532, 87.6554023197719, 87.25761100224086, 84.94099126543317, 84.31313814435686, 81.88831411089215, 79.45811911991665, 80.08392947060722, 77.87586838858468, 77.75025190625871, 74.11598273686, 75.55456556592668, 80.02140263148716, 80.99976457868303, 79.55547033037458, 83.77220003945487, 84.0273448399135, 82.30046040671212, 35.43774788720267, 30.116452625819615, 69.26607063838414, 86.57258115495954, 80.36107921600342, 84.06150913238525, 85.6122567313058, 82.82724503108433, 77.93674155644008, 76.92291600363595, 77.30183601379395, 78.84744889395577, 78.59190804617745, 77.78940500531877, 77.72004808698381, 78.94753074645996, 78.22719015393938, 77.78679248264858, 78.42296954563686, 79.56562164851597, 82.31548241206578, 82.96449279785156, 79.45857075282505, 80.55227279663086, 81.30519349234444, 78.4335377556937, 69.33692141941616, 77.88702719552177, 78.39480154854911, 80.11947645459855, 75.39366613115583, 75.28190435682023, 76.96686335972377, 81.30026721954346, 74.80827345166887, 72.72502980913434, 71.13836002349854, 73.14161600385393, 80.8283942086356, 87.58796310424805, 22.932546819959367, 2.2817484651293074, 8.496318033763341, 5.415989654404776, 1.9368969925812312, 3.270069786480495, 0.829239274774279, 0.4985417170183999, 0.8612496256828308, 0.3331194392272404, 0.17851079760917596, 1.6415872616427285, 19.992305415017263, 41.342403479984824, 39.3194180897304, 42.57546901702881, 57.0834709576198, 67.91317994253976, 49.97695766176496, 48.57431091581072, 45.513334138052805, 52.88881914956229, 72.20117732456752, 73.02915940965924, 84.0992795399257, 57.23533078602382, 5.084039032459259, 0.2309171376483781, 0.14371227845549583, 0.06972581068319933, 0.11551370657980442, 0.12757617288402148, 0.1024927349228944, 0.12141436923827444, 0.14001965017191, 0.14865330260779175, 0.08907047765595572, 0.09921967198273965, 0.07187682097511632, 0.08653060573020152, 0.0831311656428235, 0.08442523370363883, 0.08463760159377541, 0.1548049689403602, 0.11492939293384552, 0.1340075313512768, 0.1791964029627187, 0.11054176837205887, 0.1244607607700995, 0.1238231278423752], [0.015342251830069082, 0.060337444102125506, 0.058432891299682, 0.051106199089969905, 0.03895310086331197, 0.0424316106364131, 0.048437527646975856, 0.04437766942594733, 0.04290106865976538, 0.021525207108684948, 0.023294288698317747, 0.01982935132192714, 0.050307464985443015, 0.06134611354874713, 0.018286588302414333, 0.03462596430576273, 0.020365543264363493, 0.04598161764442921, 0.0419939894761358, 0.029502621186631064, 0.828022471496037, 36.922178404671804, 62.513394355773926, 69.17434746878487, 68.32833480834961, 61.59060410090855, 51.95062821252005, 50.446742738996235, 67.80548286437988, 36.21258667537144, 24.391315902982438, 28.19463995524815, 38.11922448022025, 27.514704874583654, 26.817190851484025, 44.04974821635655, 13.5683570929936, 1.2385876178741455, 0.03317506644608719, 0.10264184977859259, 0.036856258021933694, 0.03469984998394336, 0.22958636762840406, 0.9742898685591561, 0.25955867075494354, 0.05661787797829934, 7.918769001960754, 40.38858257021223, 80.08080278124127, 90.92473820277623, 84.39375809260777, 86.05052130562919, 80.48354816436768, 78.66022968292236, 78.41729981558663, 81.67718614850725, 82.49205698285783, 89.80532087598527, 90.9533508845738, 90.04636778150285, 87.38971710205078, 86.57647909436906, 82.1342247554234, 80.04331030164445, 74.84049224853516, 75.50933974129813, 76.4560317993164, 77.41168008531842, 79.44211047036308, 78.64453370230538, 79.8815006528582, 79.01858302525112, 77.19816194261823, 78.3395425251552, 78.50445107051304, 75.429046358381, 72.66613687787736, 70.18861075810024, 69.65595490591866, 67.88635294778007, 72.82160976954869, 72.39812401362828, 74.8711963381086, 78.76559216635567, 76.40253067016602, 75.52584866115025, 37.722475392477854, 28.162867580141338, 67.83857713426862, 75.46711553846086, 71.37576607295445, 72.69341550554547, 71.98353890010289, 70.23733847481864, 66.96935054234096, 66.47937052590507, 67.18264634268624, 67.11731243133545, 67.44724069322858, 69.62421553475517, 69.82663740430559, 70.17442948477608, 71.94485827854702, 74.84523091997418, 71.44141960144043, 72.26940168653215, 73.18061624254499, 73.48965127127511, 73.01610374450684, 69.50362954820905, 69.85720252990723, 69.77547781808036, 68.36672360556466, 70.51024981907436, 69.88162544795445, 71.64231981549943, 72.55204745701381, 70.6116031919207, 69.51620578765869, 67.91129003252301, 72.48015444619315, 70.34538991110665, 71.97238009316581, 67.57792936052594, 64.95296246664864, 63.34761592320034, 76.70766775948661, 30.225139822278702, 0.14921355540198938, 1.715797170996666, 3.3691591322422028, 2.0213957726955414, 0.6784874669143132, 0.09095225882317338, 0.17908125557005405, 0.1138563169432538, 0.020270517827676873, 0.051251330945108614, 0.9735768096787589, 16.17178109713963, 29.508061408996582, 31.654787267957413, 33.84425149645124, 33.52688557761056, 39.99394226074219, 25.726368835994176, 30.654965809413365, 39.152338232312886, 43.820780754089355, 54.47745180130005, 54.85452011653355, 57.40719100407192, 26.963966335569108, 4.498833520071847, 0.032339779660105705, 0.012733906391076744, 0.0462583886858608, 0.01816982090739267, 0.05936230785612549, 0.007159879464390022, 0.04695512879905956, 0.015269538321133171, 0.034661241341382265, 0.03305076561602099, 0.03368873441857951, 0.046668369722153456, 0.029764148938868727, 0.03143684632544007, 0.029325611756316254, 0.04113475040399602, 0.037872869720948596, 0.024117097225306288, 0.06849838833191566, 0.02007892498347376, 0.06682658661156893, 0.037428615880864005, 0.04937227748866592, 0.027285357039155703, 0.032149484514125755, 0.02047500792624695, 0.0878983016258904, 0.02442139303976936, 0.02177671798770981, 0.026319730461442044, 0.07441561403019087, 0.06885983036564929, 0.024349373332890015, 0.025683469870792966, 0.058070791086980274, 0.1262196728161403, 0.028361198059948425, 0.02297408293400492, 0.024744847290483967, 0.05797535513660737, 0.028994123650980846, 0.10502671037933656, 3.111710786819458, 56.144637312207905, 79.11908871786935, 86.34705652509416, 82.18678787776402, 84.80473709106445, 65.99278817858014, 63.36668872833252, 81.2993083681379, 44.56692695617676, 20.095988171441213, 23.9050201688494, 52.16875301088606, 31.724279676164898, 34.920551776885986, 47.26572888238089, 13.654949017933436, 0.3399603750024523, 0.04538683420313256, 0.04923546786553093, 0.17690428452832357, 0.30556483779634747, 0.9287723281553814, 1.1271989835160119, 0.1733512580394745, 0.20513522252440453, 13.709270903042384, 55.05779314041138, 90.77558122362409, 96.00402423313686, 90.46127251216343, 91.91748292105538, 83.45905862535749, 79.80366693224225, 85.40969589778355, 88.22013800484794, 89.52894238063267, 92.45422431400844, 91.97584084102085, 91.10280663626534, 89.41876479557583, 89.91461603982108, 87.57080105372837, 85.36464377811977, 81.30242116110665, 79.34760107312883, 79.45338739667619, 81.15301404680524, 80.62129620143345, 82.40026433127267, 84.04799488612584, 82.3912525177002, 81.88884217398507, 82.01572322845459, 81.14877564566476, 78.99108900342668, 78.01388045719692, 74.75623144422258, 71.24029009682792, 71.64879553658622, 76.68291132790702, 76.19631508418492, 79.34220232282365, 82.20669446672711, 80.48616763523647, 78.34460081372941, 44.1503199168614, 35.03733015060425, 71.40546267373222, 79.42485809326172, 76.21053109850202, 73.00182519640241, 75.262254851205, 75.07092230660575, 71.59552369798932, 69.19485855102539, 70.62666688646588, 69.27481842041016, 70.69071538107735, 73.02442073822021, 73.95919663565499, 73.46697929927281, 75.4040606362479, 77.77065876552037, 76.23564883640834, 77.38575635637555, 77.22571849822998, 77.17357226780483, 74.33967304229736, 72.79719379970005, 71.40787369864327, 71.0311632156372, 72.49551691327775, 73.9229965209961, 73.77978719983781, 76.56827299935478, 77.55477128710065, 76.13014044080461, 70.77679661342076, 69.63772978101457, 72.9078369140625, 73.87615871429443, 75.66062981741769, 73.19727107456752, 69.44827325003487, 67.43891675131661, 82.28727272578648, 46.761487688337056, 1.6195718944072723, 0.9533472380467823, 0.8926148797784532, 1.7989184707403183, 1.7321933997528893, 0.19287219483937534, 0.1821672056934663, 0.0341314819109227, 0.033786904865077565, 0.17593506510768617, 0.3781885765492916, 13.990266476358686, 30.1425187928336, 32.63143301010132, 39.92707974570138, 37.55176510129656, 28.911727053778513, 13.897397722516741, 36.26338842936924, 50.09798833302089, 58.69786752973284, 68.7795855658395, 64.7606988634382, 70.94606167929513, 43.79749386651175, 8.488796608788626, 0.03248779528907367, 0.05699776937919004, 0.023934123472177556, 0.008693366910197904, 0.015003554290160537, 0.0350233381614089, 0.05513231376452105, 0.03723737757120814, 0.06611544798527445, 0.03096619408045496, 0.0353378120011517, 0.027390952355095317, 0.019866725030754293, 0.03319350563521896, 0.009364380368164607, 0.027693668879302483, 0.013394245645031333, 0.02247768028506211, 0.06319399510643312, 0.02835552889986762, 0.02961935635123934, 0.010768438107334077, 0.09701694375170128, 0.16485914800848278, 0.1333443990775517, 0.13913156996880258, 0.19491928070783615, 0.0779963383185012, 0.09564986532287938, 0.13808008496250423, 0.11350067638392959, 0.09255386609584093, 0.1407541779002973, 0.10932259022125176, 0.09585786344749586, 0.2831054643860885, 0.11371034370469195, 0.08734152971633843, 0.14794097654521465, 0.21602758233036312, 0.12288014058555875, 0.17276811147374765, 3.508172175713948, 60.87612778799874, 93.61484445844377, 94.8693208694458, 91.47892652239118, 84.25964396340507, 74.81595815931047, 69.66356318337577, 90.12001173836845, 54.46434055055891, 39.850656509399414, 43.711231981004985, 58.4825359072004, 43.56271423612322, 43.64152070454189, 65.65828105381557, 24.047374861580984, 1.8383335386003767, 0.1936717126518488, 0.17661727778613567, 0.201023951705013, 0.2601086369582585, 1.0655802956649234, 2.4666697766099657, 1.866106356893267, 0.31566857706223217, 9.988972612789699, 48.35941008159092, 89.51832553318569, 99.52059786660331, 94.37736756461007, 94.97682339804513, 87.73993410382951, 85.16754422869, 88.21577453613281, 91.19228553771973, 90.70144394465855, 93.58551611219133, 94.07470403398786, 94.03334835597447, 92.27489825657436, 93.21686553955078, 90.24589225224086, 90.2135066986084, 85.74662099565778, 82.94865090506417, 82.20836898258754, 82.47309534890312, 80.69184820992606, 84.24735954829625, 85.36172553471157, 86.54685197557721, 84.32267107282365, 85.77569920676095, 84.00776481628418, 79.07488427843366, 79.83776869092668, 78.19427653721401, 77.0760612487793, 74.86549881526402, 81.37332057952881, 79.6459150314331, 81.29885673522949, 83.42404665265764, 83.56667927333287, 78.19644437517438, 53.14424535206386, 43.70460687364851, 71.74283940451485, 81.17098208836147, 79.0459589276995, 75.58348396846226, 78.67245851244245, 76.8946646281651, 73.65485858917236, 71.63129997253418, 73.70291233062744, 73.39184842790876, 72.47491550445557, 74.03436919621059, 73.19825077056885, 75.01794229234967, 78.75667762756348, 80.18315669468471, 76.83328424181256, 80.64196709224156, 79.74649715423584, 80.8609048298427, 78.74716554369245, 72.4963298525129, 73.39409269605363, 72.8577959878104, 74.0722577231271, 78.1221125466483, 75.76142733437675, 76.84347724914551, 80.19417653764997, 78.05161612374442, 73.06022480555943, 70.32730375017438, 77.49530860355922, 78.5851057597569, 77.71691444941929, 75.1260632106236, 72.88819435664585, 70.74532127380371, 92.27983147757394, 37.18584517070225, 0.7127519111548151, 6.250318484646933, 8.801593218530927, 3.4940875257764543, 1.4566293635538645, 0.21781221085361072, 0.34847634232469965, 0.29945150869233267, 0.30505960062146187, 0.23442820353167398, 1.6004795474665505, 27.201551301138743, 45.83035612106323, 42.53206014633179, 48.324999128069194, 45.82167434692383, 57.511733600071494, 43.71647092274257, 47.678993838174, 56.19002294540405, 60.17921652112688, 76.23801817212785, 71.05557918548584, 84.5141773223877, 52.414319719587056, 8.124433943203517, 0.13538843153842858, 0.11581982086811747, 0.09213583424155201, 0.1880245235349451, 0.11501771105187279, 0.13567465117999486, 0.2214216236025095, 0.05198477301746607, 0.09214147965290717, 0.13704970239528588, 0.17639545111783914, 0.14025740884244442, 0.18047746350722654, 0.08945945464074612, 0.15064751702759946, 0.12155919575265475, 0.07578796467610768, 0.18060413242450782, 0.1265153240944658, 0.15419879289610045, 0.2273427780185427, 0.1331519801169634], [0.023173716418179016, 0.022793635027483106, 0.005782892727958304, 0.08137743081897497, 0.022774778539314866, 0.06800696613000971, 0.0423383799248508, 0.04547983082011342, 0.0584011155047587, 0.05472977965005806, 0.013502195477485657, 0.06797938368150166, 0.07477805351040193, 0.010011721435668213, 0.05993272510490247, 0.029821274802088737, 0.08904005893106971, 0.04263747476839593, 0.04754905728623271, 0.25458644756249016, 23.927664348057338, 57.32048443385533, 60.61455590384347, 62.42713247026716, 51.224200998033794, 44.81356716156006, 66.52486038208008, 49.281071254185264, 35.22811031341553, 42.853532450539724, 42.61284337724958, 45.71944202695574, 24.24280858039856, 30.68881743294852, 36.57245472499302, 19.76214807374137, 1.2776704749890735, 0.019293284908469235, 0.09834577994687216, 0.12000218858676297, 0.07018677344811813, 0.08713187596627645, 0.722732347037111, 0.2241747658699751, 0.04425318878410118, 6.939203713621412, 49.311841351645334, 82.7036713191441, 88.62688555036272, 81.65705026899064, 86.20231860024589, 80.4389476776123, 79.71010943821499, 82.97387981414795, 83.59923158373151, 85.95759609767369, 86.78187479291643, 85.70946202959333, 85.48357609340123, 88.99325016566685, 85.62572928837368, 83.01119858877999, 81.17460904802594, 76.96512631007603, 69.32230935777936, 77.1370108468192, 77.94378008161272, 79.089690889631, 81.22242655072893, 81.9536966596331, 77.20122609819684, 79.98913519723075, 76.20670264107841, 76.42539024353027, 76.68432181222099, 75.79154082706997, 72.6981680733817, 72.92453343527657, 62.37682751246861, 67.19356891087124, 71.4728810446603, 76.2929436819894, 75.76420661381313, 76.95598942892892, 69.61532184055874, 76.33983707427979, 37.155269622802734, 25.52424052783421, 71.15224947248186, 78.59843935285295, 73.98346669333321, 68.32627814156669, 70.35626384190151, 72.00675283159528, 66.49246093205043, 64.06856100899833, 62.59131145477295, 64.28015450068882, 68.09017140524728, 69.08404867989677, 72.80709498269218, 73.26311220441545, 73.08325808388847, 73.40797519683838, 71.48975821903774, 72.85347420828683, 72.67374515533447, 70.57797391074044, 71.06029006413051, 71.53419194902692, 69.83813667297363, 69.1234519141061, 69.78587232317243, 66.04334327152797, 72.56908443995884, 72.476895741054, 74.65218911852155, 71.54857472011021, 72.4393059866769, 70.96018736703056, 70.3385181427002, 69.65066037859235, 68.62792723519462, 68.84210545676095, 67.36405685969761, 67.87520803724016, 59.58966881888253, 76.23705932072231, 49.77253123692104, 0.4785438786659922, 1.116863863808768, 11.133954967771258, 0.780456406729562, 0.5844421876328332, 0.1456246886934553, 0.07808642741292715, 0.13125930167734623, 0.11120175902864762, 0.04042507402066674, 1.0809922686644962, 21.41963389941624, 33.62963901247297, 20.24416024344308, 23.096350601741246, 27.724827085222515, 32.515332085745676, 30.89971263068063, 30.585091250283376, 39.36272273744856, 58.29767908368792, 50.243285587855745, 50.32397154399327, 52.80775799070086, 37.28396763120379, 5.748483972890036, 0.1717020786766495, 0.08455290685274772, 0.03126923121245844, 0.03277565359270998, 0.03545753950519221, 0.029115466068365743, 0.01750102116992431, 0.009089147056719022, 0.04240641663117068, 0.05616969881313188, 0.04071935126557946, 0.0065214780957571095, 0.007159513055479952, 0.022044713875012736, 0.013023699367684978, 0.029494539834558964, 0.01894663324180458, 0.012337334054921354, 0.04121764024187412, 0.098462935803192, 0.05247663626713412, 0.04411785836730685, 0.04795104518000569, 0.02438404647234295, 0.03911757096648216, 0.010433116279143308, 0.030478435967649733, 0.03441588307863899, 0.049158440570213964, 0.03871247538232377, 0.04208455015239971, 0.04416932524847133, 0.028174583966444646, 0.06259332198117461, 0.05693552057657923, 0.08078139887324401, 0.013460820108386022, 0.03716931711616261, 0.048698007062609704, 0.03583224689854043, 0.7107401362487248, 40.28924070085798, 75.37097331455776, 75.4350357055664, 85.57969747270856, 74.15162004743303, 53.28361231940133, 83.32456234523228, 67.47894532339913, 44.74326876231602, 36.9122667993818, 31.24907500403268, 51.04937737328665, 26.615359578813823, 29.34762750353132, 38.54952641895839, 20.65859075954982, 0.5993029187832559, 0.025373901839234998, 0.13402206557137625, 0.14113509388906614, 0.23077022124614033, 0.15630861611238547, 0.9327029458114079, 0.28430177590676714, 0.14702325793249266, 13.442771877561297, 59.90193475995745, 90.33976241520473, 91.86826188223702, 88.07135622841972, 88.51448454175676, 81.55002021789551, 85.90573474339077, 90.03730733054024, 87.05468191419328, 87.84652641841343, 86.07765402112688, 86.24297945840019, 89.61340468270438, 89.95520046779087, 88.14575059073312, 85.7208501270839, 85.31878566741943, 80.26212297167096, 75.06624616895402, 81.60061005183628, 81.51539039611816, 82.6458067212786, 88.02044677734375, 85.51577404567173, 81.10152789524624, 81.69627979823521, 80.51969964163644, 79.95079503740583, 79.5406915119716, 79.60606016431535, 76.17656135559082, 76.71716594696045, 66.8788502556937, 70.41166877746582, 74.05489417484829, 79.64815929957798, 79.0886139188494, 80.40588120051792, 74.43508570534843, 78.96028763907296, 40.85314607620239, 29.313536167144775, 72.3574492590768, 83.82540239606584, 76.94712352752686, 73.67390360151018, 74.83218220302037, 76.07178946903774, 69.28898579733712, 65.15359170096261, 67.99709333692277, 69.06737995147705, 72.25179495130266, 74.1383559363229, 77.83032294682094, 77.66667897360665, 76.60961478097099, 77.12457357134137, 75.33038193838937, 75.02172211238316, 78.33662428174699, 75.6520835331508, 73.95946066720145, 74.18557589394706, 75.16427830287388, 72.79457432883126, 72.64354828425816, 71.34474236624581, 73.99514661516461, 75.22961221422467, 76.53945881979806, 73.66783087594169, 76.16057355063302, 74.69574737548828, 73.8842533656529, 72.45509229387555, 72.74655532836914, 72.50703007834298, 70.69796930040631, 72.15955761500767, 64.71522290366036, 79.11136926923479, 65.6926121030535, 2.3704791324479237, 0.8782916026456016, 0.42915008483188494, 0.6522203449692044, 2.4645994305610657, 0.8169248412762369, 0.14408760331571102, 0.13436776559267724, 0.07866256471191134, 0.0644721243796604, 0.542603881231376, 20.51702642440796, 30.803758008139475, 22.167286123548234, 26.122344936643326, 34.68440335137503, 22.225338322775706, 21.946041584014893, 38.57033279963902, 54.48390320369175, 77.30715138571603, 69.89029679979596, 64.0107033593314, 63.641323225838796, 54.62904412405831, 12.803170221192495, 0.37435384946210043, 0.03237979965550559, 0.01681474406671311, 0.020175422841150845, 0.0375248592879091, 0.0910321698923196, 0.020130922818290334, 0.024966821540147066, 0.10360026013638292, 0.08756774650620562, 0.0694341966882348, 0.031095797661691904, 0.01604143636567252, 0.022730041029197828, 0.025905905524268746, 0.02534790546633303, 0.037946446665695736, 0.02129951787979475, 0.05761470698884555, 0.03587526262604764, 0.029641296781067337, 0.14041584676929883, 0.14054689902280057, 0.10742251574993134, 0.0983073612941163, 0.08563492593488523, 0.16484848143798964, 0.13173650178526128, 0.08629148320427962, 0.19266978784331254, 0.16194158313529833, 0.143856480717659, 0.1114689050508397, 0.15174276754260063, 0.10401066525706223, 0.14239644977663243, 0.11660233459302358, 0.15089191177061625, 0.09565761419279234, 0.11547462296273027, 0.5284049117139408, 45.83732169015067, 91.37773990631104, 86.18461459023612, 88.99073491777692, 75.03609098706926, 63.718781743730815, 85.76498508453369, 68.68763310568673, 47.41673060825893, 63.15138489859444, 60.14742851257324, 65.07767568315778, 38.12600939614432, 47.43194021497454, 53.83024794714791, 34.4866680417742, 2.813084593841008, 0.07581469895584242, 0.3178766928613186, 0.27214880660176277, 0.2591958987925734, 0.15900967403181962, 2.3092361901487624, 1.058422674025808, 0.33599034803254263, 9.081591725349426, 55.228017057691304, 90.40660408564976, 97.28986481257847, 90.86093289511544, 91.45433684757778, 85.30414581298828, 87.38333865574428, 90.40069811684745, 88.02104432242257, 91.22178064073834, 89.94149167197091, 90.794556753976, 91.92786352975028, 95.49693080357143, 93.7081379209246, 89.18395737239292, 88.56683921813965, 87.79192052568708, 80.68603951590401, 85.26199109213692, 85.09417819976807, 84.92663628714425, 92.07861164637974, 88.12107753753662, 84.9043047768729, 87.11543001447404, 84.55210059029716, 83.93033409118652, 82.89665753500802, 83.86337430136544, 77.79980645860944, 80.79264572688511, 68.05339459010533, 74.10039792742047, 76.89092649732316, 82.89892959594727, 82.63903222765241, 81.12908445085797, 76.96920490264893, 79.52592658996582, 48.73871224267142, 38.479457310267854, 74.81229645865304, 86.30458913530622, 80.51669107164655, 78.17024966648647, 76.49283640725272, 78.1123433794294, 73.4453912462507, 71.76598385402134, 69.6857557296753, 72.86014447893415, 76.29689720698765, 76.42703696659633, 80.36446298871721, 82.68703038351876, 79.53596673692975, 81.7906710760934, 78.27905150822231, 78.6239322934832, 78.85423033578056, 77.96188708714077, 76.4759383882795, 76.48736122676304, 76.19601631164551, 75.37653882162911, 74.72511046273368, 71.93582562037876, 77.18091651371547, 77.96694537571499, 80.59181499481201, 75.67865344456264, 79.68670095716203, 78.31256267002651, 76.07805674416679, 74.83421802520752, 76.10587038312639, 74.16323743547711, 74.62467425210136, 76.82098593030656, 65.29404258728027, 86.62677015577043, 59.79960863930838, 0.7033653834036419, 6.599764670644488, 26.49029200417655, 3.96750260250909, 2.108496653182166, 0.7274562535541398, 0.29237216285296846, 0.9222595861979893, 0.3063053637742996, 0.24798907871757234, 2.2663477829524448, 35.0460536139352, 50.31109653200422, 32.26578753335135, 38.21888596670968, 40.812047481536865, 49.71393707820347, 48.05157361711775, 43.574654715401785, 55.94364677156721, 73.78801386696952, 70.38243075779506, 67.06833457946777, 76.91154180254254, 63.59212303161621, 13.136588215827942, 0.3519551642239094, 0.1184127474469798, 0.13884338257568224, 0.1796321581516947, 0.09163582178631, 0.1366588119417429, 0.08319832025361912, 0.06838433338063103, 0.15601139063281672, 0.18304856839988912, 0.12233345849173409, 0.10017273548458304, 0.10901696447815214, 0.12637698437486375, 0.14056551802371228, 0.11842971082244601, 0.1027000273710915, 0.16125614063016006, 0.14093331114522048, 0.22008303685912065, 0.12031122057565621], [0.043802105489053896, 0.05414801051041909, 0.02587678110493081, 0.06410393092249121, 0.015708543692848513, 0.04632316842409117, 0.014645937497594526, 0.05497175541573337, 0.039163504394569566, 0.012975188354695482, 0.019471167952620556, 0.020427863313151256, 0.03141673454748733, 0.09292058034666947, 0.04218695805008922, 0.02877147595531174, 0.0937213534489274, 0.09031679720750876, 0.11445051005908422, 6.484323390892573, 53.8917429787772, 58.7367913382394, 60.1526118687221, 43.396350043160574, 46.01816940307617, 51.226354939596995, 37.62763595581055, 35.616201945713584, 37.58395610536848, 47.305111271994456, 43.9066743850708, 25.80663616316659, 24.356873682567052, 27.021697180611746, 29.81809003012521, 7.9347003528050015, 0.16070169609572205, 0.0435729777839567, 0.03651850025302597, 0.2300897320466382, 0.13927039823361806, 0.38446890669209616, 0.37311270034738947, 0.5107555644852775, 5.2766969459397455, 50.025998047419954, 76.69226360321045, 86.97342273167202, 87.28572341373989, 85.57030350821358, 82.25772203717912, 82.78290857587541, 87.07614489964077, 85.46865136282784, 85.28809547424316, 84.71404920305524, 82.75084958757672, 85.86041859218052, 86.49157905578613, 82.84751292637416, 80.05581011090959, 82.65032305036272, 78.8060723713466, 72.97367109571184, 75.76895918164934, 78.5108642578125, 80.9814143862043, 78.77308927263532, 81.7694512775966, 78.8931610924857, 74.73607472011021, 74.74793529510498, 74.09797995431083, 75.05441338675362, 75.19087600708008, 73.68212332044328, 73.85426494053432, 69.99504089355469, 67.70080130440849, 63.11065455845424, 68.14540958404541, 71.8806986127581, 77.2077921458653, 74.4371771131243, 75.87995665413993, 69.05967439923967, 29.30799150466919, 20.59147116116115, 54.75793668201992, 82.37104020799909, 69.86142703465053, 71.53495625087193, 70.2827102116176, 69.98697403499058, 58.43020207541329, 65.74631472996303, 64.13946042742047, 65.75165789467948, 67.88153784615653, 71.13485813140869, 70.7760670525687, 71.03438023158482, 74.53714779445103, 75.3884619304112, 72.43624183109829, 70.39466653551374, 71.39189284188407, 72.55925968715123, 69.0686514718192, 70.81485884530204, 71.80893761771065, 69.97746195111955, 69.32233020237514, 69.0266009739467, 68.96098913465227, 70.0305392401559, 68.31397983006069, 68.01580483572823, 65.2779575075422, 63.537433760506765, 66.84700666155133, 65.92297267913818, 70.36421258108956, 72.55340235573905, 68.55381080082485, 62.96474238804409, 68.61918640136719, 60.55144541604178, 76.23086847577775, 60.60270227704729, 1.3278632845197404, 1.7190352486712592, 2.474473689283643, 0.4420684687793255, 0.07289338856935501, 0.08347320836037397, 0.05796869870807443, 0.1059158898091742, 0.17060106061398983, 0.019664053406034197, 2.6181604819638387, 24.56563057218279, 34.94471761158535, 21.371823344911846, 21.424499375479563, 35.84083720615932, 42.764661516462056, 27.69523470742362, 23.15974596568516, 31.632612092154368, 40.76242692129952, 42.83245161601475, 59.15481581006731, 52.66621623720442, 42.05400323867798, 10.901833891868591, 0.7030392523322786, 0.16725881424333366, 0.023620513068245988, 0.03322318136425955, 0.016721827177596942, 0.028019988244133334, 0.010968030879407056, 0.05680519435554743, 0.01038086908270738, 0.04489153417359505, 0.015756789229011962, 0.08245641006422894, 0.019241704372689128, 0.02736006204837135, 0.05933863376932485, 0.030897448305040598, 0.0109022053490792, 0.029057190088289123, 0.08304635555084262, 0.020487928929339563, 0.05695249752274581, 0.014985978536839997, 0.04267116063939674, 0.03395773284137249, 0.00413320743246004, 0.0369079623903547, 0.08558402223778622, 0.00903107039630413, 0.039810915011912584, 0.028889907457466637, 0.04850562881412251, 0.03513766113402588, 0.04816407464178545, 0.06992627028375864, 0.021429762676624314, 0.04843545811516898, 0.04084908037579485, 0.04396135765793068, 0.2373551321881158, 11.157758627619062, 80.02451542445591, 71.02153996058873, 82.9254925591605, 58.09492022650582, 64.54336615971157, 69.84529331752232, 50.59955447060721, 41.45768799100603, 39.38858393260411, 37.763584409441265, 44.313140528542654, 33.44893373761858, 18.55822328158787, 26.941117184502737, 32.76059307370867, 7.047861814498901, 0.16372733802667686, 0.03399506923077362, 0.039821747823485305, 0.6089329591819218, 0.7067948079534939, 0.2691318770604474, 0.6845086238213948, 0.2705720269254276, 9.707925796508789, 60.428893089294434, 82.72888633183071, 92.24026843479702, 90.34133965628487, 89.67616776057652, 85.12378447396415, 88.47544956207275, 90.94275488172258, 88.36026232583183, 89.85346494402204, 88.64274133954729, 85.88539041791643, 90.92817756107875, 89.26571682521275, 85.64332212720598, 83.94893441881452, 86.30844538552421, 82.84358719417027, 80.07065146309989, 81.07293605804443, 81.61401312691825, 83.09764112745012, 81.13803373064313, 82.95402186257499, 79.13301290784563, 80.66585499899728, 79.45536068507603, 79.12575898851667, 78.82181004115513, 78.9810905456543, 76.36125837053571, 77.57320485796247, 72.76636464255196, 72.09107616969517, 65.68083490644182, 72.68936470576695, 74.79192434038434, 80.58279623304094, 75.89312349046979, 83.1310202734811, 66.90697656358991, 33.38577808652605, 26.988302401133947, 46.5308769771031, 83.2798159463065, 71.30397033691406, 76.16106687273297, 70.7842242377145, 75.48247800554547, 62.430328641619, 70.61718954358781, 67.08900547027588, 71.2847238268171, 70.8908304486956, 73.22401469094413, 73.44357776641846, 74.35620975494385, 75.76464435032436, 79.22693865639823, 76.69941329956055, 76.02221407209123, 75.78004155840192, 77.24702862330845, 71.49412168775285, 72.76130635397774, 74.01488644736153, 73.17413357325962, 73.05836268833706, 75.11667619432721, 73.55758380889893, 74.30930246625627, 72.62277317047119, 72.60811247144426, 69.84332697732108, 66.02836295536586, 67.88299696786063, 69.54795905521938, 73.49769033704484, 74.48603684561593, 72.26948506491524, 68.88192558288574, 72.46072033473423, 65.43345124380929, 75.75334657941545, 72.56606892177037, 4.399531168597085, 1.7092084331171853, 0.7983442725879806, 0.8784948374543871, 0.7513829182301248, 0.3615628129669598, 0.07322511076927185, 0.15837904358548777, 0.44029882230928963, 0.020613966809053506, 1.0238911041191645, 23.22648515020098, 35.13268722806658, 19.331392765045166, 23.710793699537003, 39.04000323159354, 29.530517986842565, 26.81095310619899, 34.65448440824236, 48.172388894217356, 53.501848288944785, 52.831809180123464, 73.4546115057809, 63.029061862400596, 60.127424648829866, 21.937985147748673, 1.122067196028573, 0.19720565873597348, 0.06599326418446642, 0.026109325233846903, 0.015306228405929037, 0.03525241158370461, 0.04500505308221493, 0.05050341911347849, 0.04319327298019614, 0.0651431412303022, 0.019621432925175344, 0.021017018306468214, 0.019702293943347673, 0.08448859530368022, 0.014648995994191085, 0.04513816808217338, 0.045841249105121405, 0.057047153157847266, 0.02999048786503928, 0.03408359090930649, 0.10592614247330598, 0.1636080922824996, 0.10641187176640544, 0.14984573290816375, 0.0917161467618176, 0.17037327640822955, 0.21510755669857773, 0.16094120538660459, 0.15655286157769815, 0.06574867945164442, 0.08266225723283631, 0.11224461985485894, 0.10424179464046444, 0.2306809260376862, 0.10858556548399584, 0.12851633743516036, 0.21937240713409015, 0.25811102986335754, 0.31528325059584206, 13.667550444602966, 97.06816864013672, 88.5234477179391, 85.44732734135219, 66.69276360103062, 69.08250617980957, 70.08421407427106, 54.93351418631417, 48.52860566547939, 56.91895151138306, 63.39970656803676, 63.01712485722133, 40.87626273291451, 38.38877289635794, 41.4536371912275, 48.255694321223665, 15.058384384427752, 0.19475195397223743, 0.1370321283383029, 0.11603699278618608, 0.46350064873695374, 0.6669168163623128, 1.0108973213604517, 2.0297036468982697, 1.2496432874883925, 7.066613699708666, 56.556245122637065, 86.52607686179024, 96.64026382991246, 96.06532818930489, 93.06195545196533, 90.842527117048, 88.85259083339146, 94.60914557320731, 93.35266808101109, 94.59359550476074, 92.80014732905796, 88.94266033172607, 93.42160810743059, 91.98734010968889, 89.33402456556047, 87.09061104910714, 90.72504697527204, 88.24495697021484, 84.70422445024762, 83.07230104718889, 84.8935489654541, 86.48711136409214, 85.27881962912423, 88.35580853053501, 84.3358657019479, 82.79171889168876, 83.66844258989606, 80.48193618229458, 82.70237200600761, 81.54560811179024, 80.16236768450055, 80.72982706342424, 76.07119887215751, 76.46741989680699, 70.42131982530866, 75.70655741010393, 79.1294276373727, 83.2026492527553, 80.20562022072929, 83.4412225995745, 72.24461051395961, 38.98463303702218, 30.298846312931605, 60.33537033626011, 84.44386155264718, 74.65810203552246, 76.66012123652867, 72.98504529680524, 77.52113505772182, 64.55714443751744, 73.77601432800293, 72.1335644040789, 71.97657680511475, 73.50061552865165, 78.04907308306012, 76.09367629459926, 75.07113075256348, 80.03552137102399, 81.63558033534459, 80.01762975965227, 79.20852593013218, 76.50239712851388, 79.84807981763566, 73.91155978611538, 75.38673182896206, 75.84528514317104, 74.54226166861397, 74.8104829788208, 77.81450884682792, 78.6109322139195, 74.37219061170305, 75.64153616768974, 75.89233834402901, 72.00685705457414, 67.06458255222866, 71.4278428213937, 73.44924054827008, 76.17130851745605, 78.06454672132219, 73.61753981454032, 68.9513658796038, 76.54267583574567, 64.89625126974923, 83.74456010546002, 69.55185004643032, 1.718287231666701, 7.070058703422546, 11.460833839007787, 1.3444752331290926, 0.3263150086360318, 0.2163180224597454, 0.19190738589635917, 0.6430383548140526, 0.46615160363061087, 0.17196596094540187, 4.589213516030993, 38.2817428452628, 48.94020305361067, 31.630854197910853, 34.4888254574367, 49.00941058567592, 61.67580986022949, 44.74033314841134, 36.562122753688264, 44.19123091016497, 56.09431150981358, 60.635469981602256, 77.98460074833461, 73.15577643258231, 70.40681198665074, 24.54580388750349, 1.2322408727237155, 0.30288199175681385, 0.1335275356790849, 0.1425255342785801, 0.17338948670242513, 0.1600602769425937, 0.10897332110575267, 0.11237766700131552, 0.06775698025843926, 0.1603346493627344, 0.10229855855660779, 0.14971215650439262, 0.06331973443073885, 0.12322873116603919, 0.11633660670902048, 0.1919027447168316, 0.16456983424723148, 0.12508235312998295, 0.13811227466378892, 0.17779096694929258], [0.012033711686464292, 0.026186138790632998, 0.031178103959453956, 0.009347324542302107, 0.04043054301291704, 0.041675237473100424, 0.04017786674999765, 0.06689030783517019, 0.03802147228270769, 0.0694188346554126, 0.05180787215275424, 0.020700944820418954, 0.02381781069561839, 0.01668708788097969, 0.07131645282996552, 0.05870673446250813, 0.02967313364414232, 0.04346988795857344, 0.060559087565967014, 23.02741231237139, 63.48264026641846, 60.7260536466326, 49.53578526633126, 47.4624844959804, 47.12409332820347, 33.939146518707275, 36.78732776641846, 41.14639827183315, 45.19207027980259, 35.77085494995117, 29.85701731273106, 16.83106439454215, 28.913177490234375, 25.54139563015529, 12.172514370509557, 0.13931727143270628, 0.048337067144789865, 0.057154287051941664, 0.08250631631485053, 0.1469721778162888, 1.064542517066002, 0.5013019431914602, 0.5675492169601577, 1.956237520490374, 43.44508123397827, 72.55074119567871, 87.51281833648682, 86.6262559890747, 85.0655655179705, 81.25785541534424, 87.14218752724784, 86.43568079812187, 83.52526106153215, 83.02157224927629, 81.71929223196847, 84.36770234789167, 85.30759906768799, 85.36294146946499, 80.2169805254255, 75.82731015341622, 81.12795189448765, 80.50791549682617, 79.66543252127511, 74.4342519215175, 80.73521886553083, 74.93198612758091, 79.44787052699498, 76.75606891087124, 77.11757673536027, 73.9579598563058, 77.82668209075928, 73.86944675445557, 73.88511494227818, 70.15792056492397, 77.1841960634504, 66.36647619519914, 70.30299895150321, 64.30035986219133, 68.21506527491978, 62.036928585597444, 71.93606185913086, 70.33976187024797, 80.51607268197196, 65.22555419376918, 82.49817834581647, 44.98689692361014, 40.37978615079607, 45.870627880096436, 21.59331454549517, 80.00006471361432, 68.25864437648228, 73.01560347420829, 65.22951466696603, 76.3325206211635, 62.79261466435024, 67.88027327401298, 61.101214681352886, 65.73208481924874, 64.94214412144252, 70.63774926321847, 67.44101510729108, 72.52968120574951, 69.32294859204973, 70.1582749230521, 69.52235494341168, 72.61425467899868, 70.28488499777657, 72.86558491843087, 68.36894008091518, 68.66849081856864, 67.87920325142997, 69.21234716687883, 63.69122518811907, 67.23621695382255, 70.14710916791643, 74.10610934666225, 72.48775577545166, 71.86881024496896, 70.04251793452671, 68.39381463187081, 64.99613857269287, 65.31084333147321, 65.38707896641323, 69.29079232897077, 67.87941864558628, 71.81818567003522, 64.3154513495309, 73.02077988215855, 63.67089475904192, 68.86333220345634, 58.26199313572475, 3.439855532986777, 1.823468519108636, 2.9508678061621527, 0.5433372418795313, 0.08571730687149934, 0.039750790023910146, 0.1333017192248787, 0.05578115948342851, 0.02414295619486698, 0.08300477492489985, 4.0199098246438165, 29.473563602992467, 32.063855511801584, 20.184527329036168, 24.1525844846453, 35.187195846012656, 32.20019653865269, 27.52221587726048, 24.07727469716753, 42.628459453582764, 43.99912016732352, 44.354715074811665, 54.97986561911446, 49.64323568344116, 45.34198113850185, 21.68683382443019, 0.4636571460536548, 0.02111108531244099, 0.10070067644119263, 0.049325499284480295, 0.040452490228095224, 0.04156628171248095, 0.022772162786817977, 0.013851890373708946, 0.030348364197249924, 0.030150276076580797, 0.04811496227713568, 0.007429432589560747, 0.06377504499895231, 0.015656954675380672, 0.05039668894772019, 0.04694091688309397, 0.006456552048413349, 0.03308034974283405, 0.0378164902462491, 0.06305038995508637, 0.018443636928818057, 0.04339479448805962, 0.015623641998640128, 0.030915015576673404, 0.0519344528604831, 0.02610630575301392, 0.025018902495503426, 0.02326640430172639, 0.04484175005927682, 0.06453615094402007, 0.1020877987944654, 0.017437942858253206, 0.03061216164912496, 0.01963771946196045, 0.08780895213463477, 0.05236054910346866, 0.1421751795070512, 0.12210924338017191, 42.01749392918178, 81.72382940564836, 74.76538916996547, 65.65302126748222, 61.02194268362862, 66.2835008076259, 48.98127385548183, 36.41397673743111, 37.70460115160261, 33.02476358413696, 29.06492441041129, 40.23475987570626, 19.002694334302628, 23.178990738732473, 27.90966306413923, 6.421385305268424, 0.2753508404961654, 0.12217229285410472, 0.09877644612320832, 0.3645949959754944, 0.7641832370843206, 1.5957588979176112, 0.6334883815475872, 0.39362649672797745, 5.3550808770315985, 55.26792056219918, 77.73247841426304, 93.2043240410941, 86.86827564239502, 89.9882252556937, 85.78549616677421, 92.25635351453508, 88.06551279340471, 87.71026529584611, 87.10349300929478, 86.14897727966309, 86.0684893471854, 88.02884020124162, 86.5188854762486, 84.8046189716884, 81.5123540333339, 86.48779228755406, 83.65681825365338, 83.08088902064732, 78.09197126116071, 84.48739896501813, 80.27614443642753, 83.33102416992188, 82.93362889971051, 83.55767440795898, 77.53247451782227, 81.51410497937883, 77.65664577484131, 78.29591478620256, 74.49017102377755, 78.1613768168858, 72.95692593710763, 74.27208791460309, 67.66654668535504, 69.89076232910156, 67.28552831922258, 76.18211991446358, 75.64328016553605, 82.44763714926583, 68.29412187848772, 85.61463301522392, 41.562890665871755, 47.33457858221871, 56.406410694122314, 21.4046779019492, 77.50805854797363, 74.16213962009975, 74.19071756090436, 70.46091066087995, 77.6315141405378, 66.44477544512067, 71.21941770826066, 64.96727575574602, 68.33585275922502, 69.06936713627407, 73.91957800728935, 71.24430615561349, 75.12000438145229, 72.02335902622768, 72.78530543191093, 72.92524215153286, 74.94802256992885, 73.89475209372384, 75.55460030691964, 71.97220638820103, 71.2456888471331, 72.21526132311139, 70.82528809138707, 66.22885322570801, 69.40742479051862, 74.15376009259904, 78.11524077824184, 76.3263714654105, 73.8470527103969, 73.15301104954311, 73.49383408682687, 68.41780676160539, 67.91301318577358, 69.21300029754639, 71.50571823120117, 71.54402365003313, 74.7277855191912, 67.50359753199986, 75.45297595432827, 69.75086035047258, 70.8451668875558, 71.63498946598598, 10.495059422084264, 0.5738282714571271, 0.4624155898179327, 0.5041303485631943, 0.7482501491904259, 0.09362379368394613, 0.6998085028358868, 0.14770354357148918, 0.07171895301767758, 0.08689419193459408, 2.208940029144287, 29.02096836907523, 33.35561943054199, 18.97176616532462, 26.975305795669556, 36.11357137135097, 20.06003471783229, 24.731306893484934, 27.490467820848735, 55.55008690697806, 59.016963550022666, 63.836331367492676, 73.10688195909772, 60.09394127982003, 61.14945602416992, 37.583327293395996, 0.79055262782744, 0.014127995602653494, 0.02911083845953856, 0.06315949160073485, 0.001605062182144528, 0.01969555439427495, 0.02683780891155558, 0.013735253596678376, 0.06644811334886722, 0.06789186623479639, 0.01419341316380139, 0.06541750686509268, 0.028221328243879334, 0.03995639291991081, 0.035986406662102254, 0.04127370419778994, 0.06075666339269706, 0.04598825710958668, 0.043171397011194906, 0.10822863570813622, 0.1378013292061431, 0.12222287085439477, 0.15550468782229082, 0.1263282112777233, 0.18913140414016588, 0.09577253088355064, 0.139987229768719, 0.13257670455745288, 0.10998370724597148, 0.12820691189595632, 0.14499289116689137, 0.11432506250483648, 0.12601677727486404, 0.13832180627754756, 0.20695261071835244, 0.18344587779470853, 0.16175219044089317, 0.30201753814305576, 52.300542967660085, 100.61996269226074, 85.03587586539132, 77.93046038491386, 70.0791905266898, 70.42537757328579, 47.05952371869768, 57.83081919806344, 57.979632241385325, 64.08924579620361, 51.61060421807425, 45.07763344900948, 28.892739364079066, 41.326867307935444, 40.76425082342965, 21.367597103118896, 0.5302008039184979, 0.2839293144643307, 0.1814531832933426, 0.28112463067684856, 0.7123440844672067, 5.098752277238028, 3.076086721249989, 1.2548417342560632, 3.391372957399913, 52.29398386819022, 80.43806525639125, 96.82022217341832, 94.27456896645683, 93.25392028263637, 88.40143735068185, 94.17043631417411, 93.26799038478306, 90.7990174974714, 90.55607373373849, 85.90609604971749, 88.62463433401925, 90.29002720969063, 90.52774592808315, 87.11307457515171, 83.96405369894845, 88.71476636614118, 85.7799654006958, 86.5099709374564, 83.44124344417027, 89.06337138584682, 83.87664536067417, 87.41696793692452, 85.83319555010114, 87.3128352846418, 80.64979771205357, 83.664961542402, 81.77781690870012, 80.57378441946847, 77.04340471540178, 86.82961586543492, 76.56854397909981, 76.93929290771484, 71.86903953552246, 73.20275320325578, 71.50065994262695, 78.75407205309186, 78.26512731824602, 88.1370792388916, 71.75959845951625, 88.3341370991298, 49.92729888643537, 46.37293747493199, 50.56967374256679, 27.15417848314558, 82.3558167048863, 75.97624479021344, 77.85944284711564, 73.19463770730155, 81.66203907557896, 70.28346061706543, 74.37975719996861, 69.90299115862165, 72.85381467001778, 74.01303127833775, 77.21375370025635, 74.938524382455, 76.44034276689801, 76.01441124507359, 75.42306395939418, 77.9258815220424, 77.66969449179513, 74.20808805738176, 75.14455931527274, 72.89000783647809, 74.8420000076294, 75.69730240958077, 75.7033612387521, 67.8832540512085, 72.42422839573452, 74.78324604034424, 79.44373634883335, 78.90234661102295, 74.20720563616071, 75.26332487378801, 75.11272961752755, 71.46901089804513, 69.83922754015241, 71.77836554391044, 75.38957364218575, 73.68239430018834, 77.81515502929688, 68.73811176845005, 80.4557831627982, 70.78973415919712, 74.80747440883091, 70.65671784537179, 5.695137006895883, 3.7171472821916853, 8.386688487870352, 1.6097587581191743, 0.6245199399335044, 0.15447034261056355, 0.6740894200546401, 0.3319793646889073, 0.3122359226856913, 0.23582503572106361, 7.010382797036852, 47.893582003457205, 46.741178103855674, 30.991435800279888, 35.84284176145281, 49.727135181427, 47.492177622658865, 42.967284883771626, 35.93436343329293, 61.85419791085379, 63.06592900412423, 63.862185614449636, 74.4901432309832, 69.43558583940778, 73.69941738673619, 38.4791898046221, 1.0245862496750695, 0.08466586257730212, 0.2151941784790584, 0.15182842580335482, 0.15482132163430962, 0.12521428747900895, 0.1340565758624247, 0.08283603683646236, 0.13821611766304287, 0.16451631140496048, 0.11065282419856105, 0.1472319753042289, 0.15402462652751378, 0.1636768143091883, 0.13823666370340756, 0.14252671492951258, 0.1919030975550413, 0.12735127923744066, 0.11851209854441029], [0.017841304785438945, 0.05639916239306331, 0.039997071094278774, 0.007248452033049294, 0.03723700437694788, 0.039316324051469564, 0.008686572230154914, 0.006610984498235796, 0.04711131059697696, 0.057203677615949085, 0.060322794531072886, 0.035879520433289666, 0.07013315561094455, 0.04759829857253602, 0.009656690709692026, 0.07134199288806745, 0.06898100993462972, 0.048051553179642985, 0.32900512857096537, 35.99367673056466, 64.65120915004185, 58.57119492122105, 51.895383085523335, 47.34557410648891, 57.20390060969761, 38.199521337236675, 46.467262744903564, 40.861112185886924, 42.259579590388704, 51.73457745143345, 24.12293131010873, 28.25020817347935, 36.82965966633388, 11.07326419012887, 0.23064338948045457, 0.03892762865871191, 0.04179074788200004, 0.12200974300503731, 0.02313763531856239, 1.58197378047875, 0.7113487007362502, 0.07205250047679458, 1.2151912961687361, 38.13382264545986, 71.30779879433769, 87.86450835636684, 92.40325232914516, 82.54722567967006, 85.70481368473598, 84.19077341897147, 86.99654633658272, 81.72630991254533, 81.88677161080497, 85.11538410186768, 84.99119894845145, 81.51578644343785, 79.08421570914132, 77.5763245991298, 81.52460370744977, 83.06132984161377, 81.21196951184953, 79.03974723815918, 75.41043213435582, 74.00633321489606, 78.38116223471505, 76.14133398873466, 79.38995034354073, 78.7108403614589, 76.43475641523088, 72.39706788744245, 74.99975885663713, 72.66358688899449, 70.10019493103027, 71.0636877332415, 72.92955003465924, 67.26913057054792, 67.37040056501115, 63.32325553894043, 62.09215981619698, 62.19668156760079, 69.30058234078544, 73.4090243748256, 69.6616176877703, 69.99576350620815, 76.87340314047677, 36.18267468043736, 54.519293853214805, 71.90218939099992, 24.160116331917898, 53.982882499694824, 75.45649869101388, 65.77121012551444, 70.8559296471732, 67.44072328295026, 67.78850146702358, 62.56087139674595, 65.24046502794538, 62.94278608049665, 65.09528241838727, 63.51440743037632, 68.34624031611851, 70.53294263567243, 71.37529359545026, 71.74731404440743, 71.01738493783134, 69.41456753867013, 70.31488037109375, 70.64747674124581, 70.87612111227853, 65.25732135772705, 65.97291633061, 67.72935840061733, 66.47320747375488, 69.25981031145368, 71.18643460954938, 75.57764053344727, 70.37221690586635, 70.12915502275739, 67.74716663360596, 69.63305364336286, 68.19570064544678, 65.24109731401715, 65.40705503736223, 65.85098239353725, 67.16756180354527, 69.62647369929722, 69.70149339948381, 65.53529099055699, 69.21994154793876, 71.02476392473493, 63.88084847586495, 77.13397448403495, 9.759869660649981, 2.321335392338889, 4.176016739436558, 1.4112352622406823, 0.09757488274148532, 0.08407908584922552, 0.5777897760272026, 0.07299358105020863, 0.2506075453545366, 0.020286215735333304, 7.898168461663382, 31.016504900796072, 27.72269572530474, 16.49081632069179, 25.502087933676584, 39.12061970574515, 37.38275364467076, 41.13237680707659, 25.40862250328064, 28.042785337993077, 32.28968586240496, 33.66884074892317, 46.28356279645647, 53.17794411523001, 54.62268304824829, 10.696673563548497, 0.35976214387587135, 0.03957335650920868, 0.03288236679509282, 0.019786410233271972, 0.0432660831803722, 0.087987250781485, 0.042840926708387475, 0.0655652985775045, 0.06286016266260828, 0.054416849477482696, 0.03454653160380466, 0.025179618603682945, 0.010714813484810293, 0.09920814367277281, 0.01828688516148499, 0.03904278622940183, 0.010476340656168759, 0.04767255065962672, 0.020376055468139902, 0.019833680375346115, 0.06622263616217033, 0.014168922290472048, 0.09150782294039216, 0.019934147662882293, 0.025501242506184747, 0.010694793309085071, 0.02537359480213906, 0.03496567964819925, 0.06377749451036964, 0.12563743548733847, 0.02109932290789272, 0.07065988198987075, 0.05865773744881153, 0.0663453492202929, 0.06797882728278637, 0.05935737490653992, 0.0670281182974577, 54.12260729925973, 78.60935497283936, 69.62768963405064, 63.610716411045615, 58.06681823730469, 71.00154999324253, 45.510228293282644, 50.615424156188965, 28.72880530357361, 35.78573104313442, 53.03770167487008, 23.858621835708618, 21.142201014927455, 35.817592007773264, 10.007008399282183, 0.2839542574116162, 0.07587067809488092, 0.04589827658076372, 0.2316865420767239, 0.6533049696258136, 1.364058947988919, 0.8912190518208912, 0.06049599737993308, 3.596418423312051, 51.28692933491298, 80.23408699035645, 93.02522727421352, 91.9492083958217, 87.23666218348912, 89.31078978947231, 88.70250974382672, 89.1592287336077, 86.6701408113752, 85.58909838540214, 87.37176295689174, 88.02863870348249, 84.57762827192033, 82.79604761941093, 83.91984231131417, 84.5628911427089, 86.0160721370152, 83.02675560542515, 83.156144959586, 79.96574061257499, 80.9605072566441, 84.27924483163017, 80.48466682434082, 80.75477804456438, 80.50187751225063, 79.55852058955601, 79.55727686200822, 77.5883241380964, 77.10981559753418, 74.36966146741594, 75.41616439819336, 75.56243787493024, 72.3946429661342, 69.54304667881557, 67.35496861594063, 64.91271850040981, 67.03927721296037, 71.59647560119629, 76.67204434531075, 71.27122347695487, 75.57128293173653, 76.19198635646275, 40.33071102414812, 56.63165739604405, 69.97326523917062, 32.67793730327061, 48.436604567936485, 79.59631878989083, 67.47730554853166, 75.98430470057896, 69.93944140842983, 72.44765772138322, 67.81423759460449, 67.73741136278424, 65.08830642700195, 68.04347256251744, 66.48419952392578, 71.75066307612828, 70.65697492871965, 73.90509101322719, 72.56251839229039, 75.29040200369698, 72.63992827279228, 74.3626298904419, 72.00568975721086, 74.4779908316476, 67.11885493142265, 67.99071489061627, 69.34228542872837, 69.13661875043596, 74.25615569523403, 73.67095061710903, 75.65423052651542, 73.99964209965297, 72.87514563969204, 70.3469602039882, 69.9452153614589, 70.4903084891183, 68.10219873700822, 70.12155369349888, 66.6345932824271, 69.42333616529191, 71.68068081992013, 74.24993010929653, 67.91549369267055, 72.24473558153424, 77.50764860425676, 67.53890132904053, 85.50407327924455, 19.76474322591509, 1.280500345996448, 0.7133358312504632, 1.0527732457433427, 0.8560304428849901, 0.792977440570082, 0.38431764766573906, 0.04624790192714759, 0.10126531257161073, 0.07010108126061303, 5.424011783940451, 30.91954278945923, 24.8709066254752, 13.419125420706612, 31.607310226985387, 36.4553393636431, 16.85779585157122, 36.91693251473563, 31.757780415671213, 42.91530193601336, 49.06454106739589, 50.20308678490775, 67.52064841134208, 64.03989274161202, 67.87522888183594, 22.643604244504655, 0.18026242218911648, 0.04674512221078787, 0.05667928879016212, 0.056151992441820245, 0.026306622861219302, 0.03147712077147194, 0.03319532410906894, 0.06169332670313971, 0.03380127623677254, 0.038793489070875306, 0.028471892566553185, 0.029994701567505087, 0.04490906412580183, 0.06940978299826384, 0.03582619436617408, 0.033165736589580774, 0.04171286563255957, 0.025858791445248892, 0.06896142741399151, 0.1582596485636064, 0.0974880438297987, 0.11850390184138503, 0.22642819423760685, 0.07342772132584027, 0.0747945826234562, 0.13265658169984818, 0.13594336461808, 0.1138468717357942, 0.13293426537087985, 0.21168679025556358, 0.095085473465068, 0.12535109370946884, 0.11020228373152868, 0.12490160497171537, 0.16732305793889932, 0.1268439114625965, 0.6935192431722368, 68.58774580274309, 93.03504507882255, 83.35095855167934, 74.57804489135742, 64.48746790204729, 78.57009765080043, 59.05610275268555, 70.78164645603725, 60.03819588252476, 59.61591216496059, 76.82186835152763, 38.499301365443635, 40.69812829153878, 52.87697941916329, 23.38476164000375, 0.3518671989440918, 0.11244207354528563, 0.2512084016842501, 0.2731465516345841, 0.21729188305991037, 5.632039112704141, 4.19712449823107, 0.18138657829591207, 2.2208622694015503, 46.130275113242014, 81.7621626172747, 94.7450453894479, 100.75739111219133, 90.90387276240757, 94.18626431056431, 90.54961885724748, 95.09426185062954, 91.39796611240932, 88.59891210283551, 89.65145301818848, 92.29158088139125, 87.74788979121617, 85.46382236480713, 85.3051255089896, 87.2933247429984, 90.22476972852434, 87.25186484200614, 84.94516713278634, 85.70284734453473, 83.27467427934918, 84.72428389957973, 80.52838488987514, 86.59391212463379, 83.03561455862862, 81.8663786479405, 80.55932521820068, 82.43247617994035, 79.83548968178886, 77.34282343728202, 77.5635677065168, 79.5313948222569, 74.53090136391776, 74.27406815120152, 69.79331384386334, 68.18279089246477, 71.22155775342668, 76.6328078678676, 80.31613826751709, 75.67966788155692, 76.59198720114571, 84.3976490838187, 42.937699454171316, 56.999779905591694, 72.50028337751115, 33.05848666599819, 57.450096130371094, 80.1401959827968, 70.78176457541329, 78.56137071337018, 75.29587718418666, 74.377763066973, 72.10559095655168, 70.9272529057094, 68.2926002229963, 70.3902405330113, 71.33726610456193, 74.11082717350551, 75.64176545824323, 76.80947276524135, 78.06408814021519, 76.91746166774205, 76.50724002293178, 75.35832759312221, 77.2990219933646, 75.02110372270856, 68.17242418016706, 69.78309999193463, 71.22426755087716, 71.9115069253104, 77.51304735456193, 77.1651371547154, 81.51931612832206, 75.76912593841553, 76.27153628213065, 72.8173713684082, 72.93760299682617, 72.49687876020158, 69.79298727852958, 71.93784754616874, 70.7137347630092, 71.63282857622418, 75.34584168025425, 76.65547983986991, 70.15664904458183, 75.34006077902657, 78.21995013100761, 68.7476863861084, 87.58028534480503, 12.490998080798558, 5.540414520672389, 8.9504714012146, 1.9242375918797083, 0.2766309918037483, 0.24984017653124674, 0.9157844079392297, 0.21683726459741592, 0.41145313158631325, 0.33469019351261003, 12.955027444022042, 44.92241416658674, 40.822490624019075, 24.989871944699967, 39.571662017277305, 56.6944899559021, 60.10355758666992, 64.60788018362862, 41.554358278002056, 45.58393478393555, 47.446969168526785, 52.176416873931885, 66.17458084651402, 72.62611525399345, 79.65669168744768, 25.610757759639196, 0.430761171238763, 0.15924645561192716, 0.16988486690180643, 0.11709911722157683, 0.13452566069151672, 0.096454811415502, 0.14657877678317682, 0.17507124931684562, 0.20959279047591345, 0.20079772812979563, 0.17566735590142862, 0.10073528172714369, 0.09645787160843611, 0.17865267928157533, 0.12077578636152403, 0.17636626054133686, 0.08257299595113311, 0.1212867232305663], [0.05097912983702762, 0.08278915006667376, 0.010121510098023074, 0.06294937644686018, 0.036014626933527846, 0.06978836482656853, 0.021201493318325708, 0.033548253920993636, 0.03446889023429581, 0.03723867018041866, 0.040150623568998914, 0.006595904481530721, 0.009698993127260889, 0.07588570086019379, 0.013409369342428232, 0.023643854672887495, 0.028567708496536528, 0.04131739167496562, 0.24120869540742465, 45.78690903527396, 66.15397943769182, 54.07810756138393, 57.80754968098232, 41.77207660675049, 35.34051479612078, 38.574463503701345, 34.28444766998291, 54.054768562316895, 34.228618894304546, 31.109815733773367, 32.20732886450631, 39.32208619798933, 18.620652845927648, 0.4665556305221149, 0.012000049564189144, 0.14881440039191926, 0.0265008602956576, 0.1376094530735697, 0.4771907169904028, 2.1007164078099385, 0.09178174752742052, 0.5323666334152222, 35.50942202976772, 81.14587824685233, 91.87621062142509, 89.6964009148734, 80.41009875706264, 85.82133497510637, 83.45069299425397, 84.86653436933244, 79.7007919039045, 80.88078362601144, 82.6902335030692, 81.19826766422817, 76.14686475481305, 79.71068613869804, 81.65349973951066, 81.85157898494175, 81.07175486428397, 82.17052909306118, 76.61115728105817, 78.31001962934221, 76.71458121708461, 80.76340075901577, 76.15338216509137, 77.65844535827637, 75.87249428885323, 78.01952239445278, 73.22493185315813, 76.73998383113316, 73.59158829280308, 76.11645248958042, 73.72125557490757, 74.83629553658622, 69.22763320377895, 68.63260337284633, 67.40125056675502, 66.71643611363002, 62.52986853463309, 63.380696296691895, 61.92333943503243, 69.4856128692627, 64.62082467760358, 76.00535774230957, 58.85816247122628, 46.49275915963309, 63.861678395952495, 63.263799803597585, 50.86522231783186, 32.14789744785854, 77.33379077911377, 61.56707750047956, 69.03775978088379, 65.46448189871651, 69.38209860665458, 62.02949401310512, 64.56702477591378, 58.00866528919765, 61.328816822596956, 60.788948740277974, 63.70938083103725, 66.15516063145229, 68.01155948638916, 66.01384122031075, 69.43105561392647, 66.2530676977975, 70.02756541115897, 69.38410663604736, 71.77817794254848, 70.37286308833531, 65.4267531803676, 67.37189442770821, 67.75479575565883, 70.21351310185024, 72.25048174176897, 67.71037592206682, 70.09214891706193, 67.70636681147984, 68.8700372150966, 66.39613805498395, 63.55804211752755, 63.77538871765137, 66.64762115478516, 65.79789120810372, 64.42111260550362, 69.06827626909528, 68.38127313341413, 70.13172585623605, 68.09594535827637, 68.94495964050293, 73.23854337419782, 65.2776517868042, 75.52755096980503, 7.5496103422982355, 0.41803209856152534, 0.5288242463554654, 0.14965650306216308, 0.3693593974624361, 0.3955627642571926, 0.1084010853831257, 0.09274198992976121, 0.02923222498169967, 0.13630446738430432, 13.96039617061615, 27.430381536483765, 23.773577622004918, 14.131668397358485, 26.7177152293069, 36.501298223223, 24.52133059501648, 36.66679736546108, 25.52099919319153, 30.201213700430735, 40.84786891937256, 40.02411828722273, 50.3492317199707, 55.03546857833862, 45.99834966659546, 9.79408345903669, 0.09575581178069115, 0.055630840228072236, 0.015123621061710375, 0.02939515481037753, 0.05189375772273966, 0.02680468452828271, 0.06237939346049513, 0.03472003640074815, 0.011977052316069603, 0.0074976474113230196, 0.06698040371494633, 0.051620620236332924, 0.02589025172138853, 0.03316176715972168, 0.07274844670402152, 0.01971914536053581, 0.04557284440046974, 0.060511651182813306, 0.10355030638831002, 0.06543776792074953, 0.07251098658889532, 0.06748575624078512, 0.0026666566180730505, 0.019501937819378715, 0.06142949193183865, 0.034411662590823004, 0.006222788676885622, 0.030982750334909985, 0.015953121640320336, 0.07678007786827427, 0.034255246698324165, 0.053609572617071014, 0.02958827605471015, 0.06868641038558312, 0.12062792001026017, 0.43813774255769594, 62.782887186322895, 74.05485943385533, 63.525204930986675, 62.18539769308907, 54.76014273507254, 38.95683329445975, 29.034123046057566, 33.19166626249041, 31.55983666011265, 27.786514929362706, 37.59286717006138, 24.186344044549124, 36.85673679624285, 16.795187371117727, 0.25903872294085367, 0.07257609880928483, 0.08669821745050804, 0.07670670787670783, 0.6999991983175278, 1.1728869719164712, 0.5243914585028375, 0.24780826270580292, 1.750311153275626, 47.2383634022304, 88.11079420362199, 97.58571216038295, 92.39112772260393, 85.68232236589704, 89.05864661080497, 87.20804255349296, 87.84031472887311, 83.06136458260673, 85.00146838596889, 84.58724457877022, 83.96697194235665, 79.52728148869106, 84.11516312190464, 86.22991684504917, 83.97389234815324, 85.33455807822091, 84.90097658974784, 82.55120699746269, 81.87504305158342, 81.75113582611084, 83.66530895233154, 80.16138104030064, 79.94664696284703, 77.63571085248674, 79.71689088003976, 77.56029510498047, 80.99989659445626, 78.2164204461234, 80.7934934071132, 77.60754285539899, 79.30476542881557, 74.40740408216203, 74.16284138815743, 70.92491831098283, 69.58549322400773, 65.51010377066476, 64.41094739096505, 64.7933623450143, 72.80068874359131, 67.80635138920375, 78.14040715353829, 61.792296409606934, 51.890529768807546, 66.60864176068986, 64.20943573543003, 55.63835334777832, 33.869765281677246, 79.23407445635114, 65.44236578260148, 69.49625056130546, 68.24751336233956, 72.14243030548096, 65.64860916137695, 67.92550604684013, 62.03485802241734, 64.17008113861084, 61.23285525185721, 66.99717807769775, 68.23590987069267, 69.90219906398228, 69.9123295375279, 73.16250228881836, 69.28228773389543, 72.05958693368095, 71.41022913796562, 74.39910098484584, 72.66207912990025, 68.45164448874337, 69.94813360486711, 70.7761504309518, 72.84693595341274, 75.10357883998326, 69.31417996542794, 71.97181728907994, 69.81883457728794, 71.50488444737026, 69.98340266091483, 66.56042126246861, 65.71471432277134, 67.17908191680908, 68.04773875645229, 69.12682179042271, 70.38493905748639, 72.40129239218575, 72.59290286472866, 72.58367565699986, 69.42102936335972, 80.10034806387765, 67.0797643661499, 83.74783270699638, 15.364018269947596, 0.3689397642655032, 0.45544068408863886, 3.15392587014607, 2.125854556049619, 1.171953199165208, 0.14516886243862764, 0.16305043149207318, 0.1630218108849866, 0.09842596921537604, 11.19214699949537, 27.864237478801183, 17.22114494868687, 14.000334416116987, 32.448358399527415, 31.981446402413503, 13.44204579080854, 36.022289412362234, 34.79715176991054, 38.11125142233712, 52.167731625693186, 57.29179532187325, 67.27250739506313, 62.684903689793174, 63.10934829711914, 18.313514675412858, 0.04264927788504532, 0.09721103190843548, 0.028277485498360226, 0.06907099046345268, 0.01848784857429564, 0.01875358324364892, 0.03774132552955832, 0.04466698318719864, 0.05342250729777983, 0.0423109705027725, 0.0136895067657211, 0.05507010906668646, 0.015817959160943116, 0.021870064050225273, 0.038151530482407124, 0.02005275388780449, 0.029186525648193698, 0.1536151035023587, 0.19015810904758318, 0.12518536831651414, 0.0833653552191598, 0.16765045108539717, 0.1431814469397068, 0.11788476577826909, 0.11038442967193467, 0.16035917161830834, 0.07991518106843744, 0.10290258364485842, 0.1749826462141105, 0.18561480141111783, 0.11572340104196753, 0.11087941418268851, 0.06626370110149894, 0.301216079720429, 0.3054030207651002, 1.2803719128881181, 82.20425564902169, 90.96147332872663, 77.82671683175224, 80.0635017667498, 63.395829473223, 54.89287417275565, 59.5714020047869, 51.23091990607125, 79.02832439967564, 49.65116705213274, 54.05618946892874, 46.21976096289498, 54.753277914864675, 34.239395550319124, 1.7520964060510908, 0.20521011921976293, 0.3398917615413666, 0.14192193666739122, 0.5463933636035238, 1.319356192435537, 6.747373070035662, 0.31119727556194576, 1.2122326663562228, 42.45921523230416, 89.2269458770752, 101.50391946520124, 99.00716073172433, 87.93605395725795, 92.40769917624337, 89.80774579729352, 92.78269345419747, 86.71498448508126, 89.12392493656704, 89.19437967027936, 89.80688422066825, 82.65927233014787, 86.411438533238, 89.75363322666713, 88.54557773045131, 88.28857776096889, 89.24275997706822, 85.07249982016427, 85.0671775000436, 82.66488647460938, 87.52526256016323, 82.12797137669155, 85.03394426618303, 80.0698732648577, 84.27960613795689, 79.5054155077253, 83.7757088797433, 80.28475325448173, 84.65356513432094, 78.97861003875732, 83.29613031659807, 75.06615584237235, 77.21535873413086, 74.2347274507795, 73.61635167258126, 69.31954397474016, 68.62149320329938, 68.03056280953544, 76.74766159057617, 71.92045620509556, 82.92347063337053, 66.78003992353166, 52.675544193812776, 66.27886635916573, 65.66612557002476, 51.55848230634417, 41.01118632725307, 84.95086465563092, 69.99955027444022, 73.91388048444475, 71.17816625322614, 75.41314888000488, 67.76645483289445, 72.40899099622453, 65.12320722852434, 67.86524432046073, 65.56289618355888, 71.03861168452671, 72.45282718113491, 73.63548006330217, 72.58235549926758, 76.7235860824585, 69.97990771702358, 74.6616803577968, 73.78135749271938, 76.93527684892926, 76.40787383488247, 72.61317076001848, 73.23850168500627, 74.9403795514788, 75.93668174743652, 77.22635773250035, 73.04242352076939, 75.08911963871547, 73.83532415117536, 74.12648146493095, 75.11514064243862, 68.6592219216483, 68.88854721614292, 71.6792355946132, 70.41162708827427, 71.6081485748291, 74.92034789494106, 73.9774009159633, 77.11668736594063, 74.71380574362618, 73.94314629690987, 82.33855043138776, 72.72449479784284, 83.75937366485596, 9.873006309781756, 1.0404555009944099, 4.097888154642923, 1.6714971938303538, 0.5048215857573918, 0.8570407543863569, 0.34892919659614563, 0.3920104434447629, 0.17846495578331606, 0.39478187901633127, 22.344798701150076, 41.53789104734148, 33.75948347364153, 23.424552236284526, 41.18526996885027, 53.26420600073678, 39.01315539223807, 57.786913531167166, 37.80319956370762, 42.83266353607178, 57.39486142567226, 60.79501451764788, 71.81139728001186, 72.52558176858085, 75.25732857840401, 17.076222896575928, 0.13620465488306113, 0.13833401990788324, 0.08180473146161862, 0.2121636239545686, 0.12162736138062817, 0.09403499947594744, 0.081036134489945, 0.10504302236118487, 0.08570806522454534, 0.06807631919426577, 0.1904494719845908, 0.15990975073405675, 0.09829456412366458, 0.15534985970173562, 0.11355507453637463, 0.10389743133315019, 0.12442812323570251], [0.04932780291086861, 0.0392301093920001, 0.03156679256686142, 0.01155994666208114, 0.016909090968381082, 0.0811510986781546, 0.059846761503389904, 0.03833643466766391, 0.018537651348326887, 0.029683454161775962, 0.04679865523108414, 0.022584401969132677, 0.00820419829272266, 0.05230443086475134, 0.04791633811380182, 0.04514727062944855, 0.07361128540443522, 0.0407052750566176, 0.09894424783332006, 45.77484001432146, 55.66885593959263, 55.61875595365252, 46.8520678792681, 55.56613377162388, 42.34223188672747, 50.275375843048096, 31.535907064165386, 38.00462089266096, 32.66198423930577, 24.677804027284893, 37.350173541477744, 24.815341881343297, 3.3647850240979875, 0.12647172143416746, 0.03408096497878432, 0.11601731527064528, 0.06542761703687054, 0.13601900770195893, 2.6021242567471097, 0.08868669824940817, 0.06891729549637862, 24.478305612291607, 82.19106101989746, 89.57257011958531, 88.79214150565011, 81.64693369184221, 88.7666346686227, 83.11991705213273, 83.98763588496617, 81.12627043042863, 80.18178095136369, 79.23882007598877, 78.10137912205288, 73.92666516985211, 80.74767003740583, 79.30037416730607, 82.49048668997628, 79.769426209586, 81.34420762743268, 80.91951288495744, 83.72299984523228, 77.13882432665143, 78.89005524771554, 78.30309227534703, 81.19472408294678, 77.89110578809465, 77.15457589285714, 74.18817452022007, 76.4120010648455, 77.81876114436558, 76.56165136609758, 75.51632962908063, 75.35962690625871, 71.6642483302525, 71.63842187608991, 68.79659475599016, 66.67544174194336, 62.5117198399135, 58.335143770490376, 55.838999952588765, 60.0654536655971, 63.56528214045933, 63.36878708430699, 68.99038696289062, 68.25212696620396, 58.40241622924805, 63.73768779209682, 58.35761424473354, 65.96470355987549, 35.937774998801096, 61.33353464944022, 67.48777648380825, 63.78849302019392, 67.00646087101528, 65.1132504599435, 63.383475576128276, 59.95660318647112, 59.5205203465053, 57.725008555821006, 59.29618385859898, 60.74647440229143, 66.67266246250698, 64.69494806017194, 66.9802244731358, 68.78097520555768, 69.86833354404995, 70.77736636570522, 70.04788889203752, 68.98439066750663, 68.34835256849016, 66.46491132463727, 65.74470969608852, 66.76831831250871, 70.39329774039132, 68.67507076263428, 69.34675312042236, 66.55746827806745, 64.51715060642788, 63.686340604509624, 65.28623976026262, 61.716665267944336, 60.421521050589426, 58.95249816349575, 62.11468587602888, 65.66460391453334, 63.64961242675781, 70.23878370012555, 67.02018356323242, 72.04692036764962, 68.73520742143903, 64.57468863895961, 71.80158642360142, 67.44627489362443, 75.1837888445173, 4.078547409602574, 0.6046466806105205, 5.324771097728184, 4.357410320213862, 0.4158726744353771, 0.4045713480029787, 0.03882680514029094, 0.10426557050751788, 0.0466393318160304, 1.1310844378811973, 22.697159222194127, 32.91394329071045, 30.84281383241926, 18.84638592175075, 23.997422524860927, 48.55725656236921, 35.83502851213728, 41.46069656099592, 65.9264954158238, 29.958078861236572, 30.756294863564626, 35.27846738270351, 45.478200571877615, 48.54448924745832, 40.841844831194194, 5.27266959633146, 0.21354772682700837, 0.04663859560553517, 0.07115543647004025, 0.011523405854989375, 0.03089125667299543, 0.0048597004580577564, 0.023655842690329467, 0.04403934847297413, 0.03565611617107477, 0.04980790714866348, 0.0395363458166165, 0.045073547799672396, 0.028724192242537226, 0.04170733217948249, 0.023627295025757382, 0.030539507512003183, 0.026745536630707126, 0.01627893719289984, 0.03081435151398182, 0.053110683137284856, 0.0985576660771455, 0.027353878898013915, 0.007621662408512617, 0.026614743916850005, 0.04325733347130673, 0.025705147368301238, 0.040197859784322124, 0.04636724266622748, 0.007252718321979046, 0.054111203378332515, 0.035757004150322506, 0.058341940465782366, 0.04457155402217593, 0.04470843828416296, 0.17674043189202035, 56.59586375100272, 66.427460534232, 64.79165308816093, 50.11331605911255, 55.81901345934187, 47.13254928588867, 43.35780143737793, 18.29613028253828, 37.08600997924805, 37.66577809197562, 22.378464460372925, 33.395314489092144, 22.59077709061759, 2.6699428004877905, 0.18170741679412977, 0.0717907827347517, 0.09808330224560839, 0.45612991281918114, 1.2717144574437822, 1.2330779135227203, 0.26232793501445223, 0.14748035983315536, 36.21337877001081, 90.4132604598999, 91.89162172589982, 89.83758136204311, 86.32034070151192, 92.00419643947056, 85.41539342062813, 87.63862936837333, 83.76457786560059, 85.46655300685337, 82.37707819257463, 80.73535782950265, 77.98505932944161, 85.11365400041852, 82.3138495853969, 84.58221408299038, 82.72533580235073, 86.65379864828927, 85.1681695665632, 86.91734382084438, 79.65044525691441, 84.54514544350761, 81.21135807037354, 81.87465395246232, 79.32968166896275, 81.04414967128209, 78.1407893044608, 80.15518324715751, 78.48460006713867, 79.25984532492501, 78.68178994315011, 78.17454365321568, 76.12957068852016, 75.02147892543248, 71.6958487374442, 69.36545767102922, 64.88141686575753, 65.12725108010429, 61.533017430986675, 62.63602311270577, 67.9468161719186, 66.22550419398716, 70.79161712101528, 75.15690626416887, 61.598789078848704, 63.126697949000764, 58.438790048871724, 67.78557627541679, 42.46589592524937, 63.42836093902588, 73.57101467677525, 68.62578024183, 70.95829745701381, 67.35866505759103, 68.35769789559501, 64.0979449408395, 62.242734227861675, 61.46689142499651, 63.69310814993722, 64.59090573447091, 67.48895072937012, 66.53347614833287, 69.81911250523159, 71.59199401310512, 72.0816822052002, 71.592862537929, 73.05736909593854, 71.7339665549142, 72.37863431658063, 69.34029824393136, 69.80561215536935, 70.93419415610177, 70.73807430267334, 73.10759762355259, 73.20985426221574, 70.46808815002441, 68.97612925938198, 67.04730238233293, 67.17198780604771, 65.58551951817104, 64.04806382315499, 61.84160082680838, 63.986662592206685, 66.3652811050415, 65.27340643746513, 70.30932876041958, 70.62859153747559, 71.55617604936872, 71.72663620540074, 66.76319054194859, 76.85021700177873, 68.87183679853166, 84.80611283438546, 9.735788072858538, 1.6281362005642481, 1.6299692222050257, 10.118057114737374, 4.036280649048941, 1.5694518238306046, 0.17980120836624078, 0.2909228391945362, 0.11372234020382166, 0.39701149080480846, 21.032810313361033, 31.449203968048096, 23.63671200616019, 17.16028220312936, 24.925667115620204, 43.75899737221854, 31.94511774608067, 37.45907265799386, 66.27109827314104, 41.89275639397757, 38.76332943780081, 44.873530115400044, 61.18814359392439, 60.464085715157644, 56.5986465045384, 10.248329758644104, 0.3324282563158444, 0.04417252454108425, 0.0353002584805446, 0.028607158522520746, 0.03773305418768099, 0.027615387990538563, 0.02701218392966049, 0.03214872455490487, 0.05986401664891413, 0.04075917109314885, 0.045937540009617805, 0.02024981233158282, 0.05569296350170459, 0.07540094187217099, 0.04095359512471727, 0.02905332583135792, 0.11296117319060223, 0.09835131679262434, 0.17230319284967013, 0.1653158835002354, 0.13781434350780078, 0.205161183274218, 0.12846794431763037, 0.11682247849447386, 0.14432804898491927, 0.070066659179117, 0.16431652355406964, 0.16019774813737186, 0.08951619373900549, 0.16964433980839594, 0.17494534035878523, 0.13148362535451139, 0.2555283355925764, 0.15497663830007824, 1.024528818471091, 75.03901617867606, 77.52571392059326, 80.44103908538818, 66.5736436843872, 74.73122487749372, 62.55238764626639, 79.41825035640171, 45.20563316345215, 55.39260598591396, 58.66025693075997, 36.731683118002756, 52.306709493909565, 41.410808495112825, 6.874765685626438, 0.3046191499701568, 0.16207069477864675, 0.16352894795792444, 0.3626667351594993, 0.8491624742746353, 6.232561494622912, 0.8866932232465062, 0.20306799773659023, 30.240040234157018, 89.75286892482212, 97.81132016863141, 94.1942686353411, 87.9762075969151, 97.28129073551723, 91.47563307625907, 91.8831171308245, 88.09891278403146, 89.8094620023455, 88.17145197732108, 86.02666813986642, 81.18020929609025, 89.60801982879639, 86.15769726889474, 87.071503502982, 86.15513338361467, 88.95023386819022, 88.98576695578438, 91.05027825491769, 83.60232353210449, 88.27620996747697, 85.85980715070451, 88.45816939217704, 82.92343589237758, 83.9034515108381, 79.92423207419259, 81.26860427856445, 83.75781726837158, 83.45393085479736, 80.59184278760637, 82.65782015664237, 79.73944473266602, 77.97605446406773, 74.12287534986223, 73.46341487339565, 70.04791668483189, 67.18562711988176, 63.86654213496617, 66.69095012119838, 69.32738849094936, 69.46860367911202, 77.96805708748954, 75.89272049495152, 61.69159616742815, 64.68155888148716, 59.1290727342878, 68.44569683074951, 42.88082497460501, 67.75528907775879, 72.79989664895194, 70.76473454066685, 73.98549556732178, 69.9036442892892, 71.36776869637626, 66.47042124611991, 65.08791732788086, 65.13147558484758, 65.66238743918282, 66.55318818773542, 70.83657891409737, 69.85566697801862, 73.08284814017159, 75.95904799870083, 76.24507754189628, 77.07954229627336, 76.7286513192313, 73.75515583583287, 74.60203007289341, 72.77634225572858, 73.33034297398159, 74.0817072732108, 75.94715963091168, 75.09060655321393, 76.40420518602643, 72.28436115809849, 73.32943970816476, 69.6877498626709, 69.40669522966657, 67.62653200966972, 68.68210233960832, 65.29359790257045, 67.86920479365757, 70.66873822893415, 67.17440577915737, 74.86284460340227, 73.28939723968506, 77.36164610726493, 73.61212716783795, 69.864136832101, 79.82629026685441, 72.85376603262765, 83.60275432041713, 5.205693738801139, 5.914238895688738, 12.433901258877345, 10.681232929229736, 1.1398452477795737, 1.2778992227145602, 0.7033431274550301, 0.29773704069001333, 0.15974477172962256, 1.7097695001534052, 35.754693440028596, 48.48872995376587, 45.389711788722444, 30.231184755052837, 35.65721716199602, 68.0909148624965, 54.40768493924822, 59.39818341391427, 87.94455160413469, 45.23918948854719, 48.69877399717058, 55.452113832746235, 68.60966736929757, 66.36765044076103, 66.9282727922712, 9.549931577273778, 0.4886693039110729, 0.11199011494006429, 0.10973919036665133, 0.09334838310522692, 0.1515920784856592, 0.10430329026920454, 0.12039834447205067, 0.08893857044833046, 0.12482517478721482, 0.07595686561294965, 0.17482741097254412, 0.13530936863805565, 0.12884272634983063, 0.11575137025543622, 0.09587552571403128, 0.08616735200796809], [0.06618100803877626, 0.027884461052183594, 0.04346563693668161, 0.03568638901093176, 0.013258168839716485, 0.0828807455088411, 0.0120338957390881, 0.05202451142083321, 0.06783792270081383, 0.01885863403523607, 0.08399463538080454, 0.013501751037048442, 0.05741305995200362, 0.020563753521335975, 0.02753316650965384, 0.015276566247588821, 0.020880956768191287, 0.055134135631046126, 0.3464838106717382, 42.999757289886475, 66.70302609034947, 49.715670653751914, 63.429729734148296, 56.56512492043631, 35.47444827216012, 30.324294090270996, 43.38592427117484, 22.135887214115687, 22.431863103594097, 29.64018487930298, 23.45368082182748, 10.250117182731628, 0.01710400015248784, 0.06482894558991704, 0.09722346945532731, 0.1040009893476963, 0.05265907737027321, 1.581037619284221, 2.053513603551047, 0.51986590134246, 17.424827916281565, 88.97462899344308, 87.99483571733747, 86.8969578061785, 86.00830405099052, 85.77123151506696, 81.58057839529855, 81.1223794392177, 80.11115946088518, 78.72880145481655, 74.92797006879533, 74.34316103799003, 70.20649542127336, 80.64357907431466, 75.29293809618268, 78.21023654937744, 80.68164130619594, 81.07875170026506, 79.82934052603585, 80.9969436100551, 78.60989693232945, 76.46628734043666, 80.0183801651001, 78.71455764770508, 77.2746616091047, 72.38731261662075, 74.69720649719238, 76.50418281555176, 75.42557225908551, 75.54032870701381, 76.0244722366333, 78.95632716587612, 73.96260125296456, 72.92709732055664, 67.87430477142334, 66.59320981161935, 64.70908069610596, 62.10973875863211, 61.316949299403596, 60.359862736293245, 65.0550731931414, 72.1624480656215, 68.67293071746826, 65.40584605080741, 74.51973560878209, 60.22098214285714, 61.22739396776472, 56.57877465656826, 62.205450194222585, 64.85978712354387, 61.894976888384136, 75.10867881774902, 63.35664163316999, 62.813688550676616, 64.3765538079398, 63.187633650643484, 60.152361733572825, 59.71743924277169, 57.72949014391218, 60.17087868281773, 62.53726141793387, 63.64365782056536, 63.668754713875906, 66.15256895337785, 64.46257250649589, 65.67403956821987, 67.71735886165074, 68.58539036342076, 68.74945817674909, 68.57876873016357, 66.26200308118547, 62.55619525909424, 67.60525662558419, 68.03199413844517, 71.71341378348214, 71.74660532815116, 71.37741279602051, 69.7363247190203, 66.8939903804234, 63.74336447034563, 62.39845725468227, 63.28704152788435, 62.65128135681152, 56.7701210975647, 57.683454854147776, 62.284117698669434, 63.42102364131382, 67.46815477098737, 66.92764745439801, 68.50768171037946, 67.43157250540597, 67.61805520738874, 67.61104447501046, 70.31047521318708, 69.15790108272007, 0.11156744190624782, 8.58911383152008, 12.379574162619454, 1.992621545280729, 0.19313165305980615, 0.303143173456192, 0.28254114038177897, 0.10681564759995256, 0.02594475674309901, 2.4702038041182925, 27.21135347230094, 22.524116073335918, 33.449638979775564, 27.054829665592738, 29.267097881862096, 43.024267060416086, 54.76424217224121, 84.4934161049979, 31.407514776502335, 47.848012242998394, 38.87811367852347, 44.200419902801514, 41.365325587136404, 45.93797329493931, 29.97812441417149, 0.7511454852563995, 0.08462506905198097, 0.04819092766514846, 0.07676242917243924, 0.059802575302975516, 0.042277081071266105, 0.064427646409188, 0.009130002498360617, 0.0493420148268342, 0.06288742619965758, 0.021156452163787823, 0.06149676189358745, 0.04499779615019049, 0.01494136655570141, 0.045692660114062686, 0.027579759813046882, 0.08963322745902197, 0.012086664559319615, 0.012791010201908648, 0.0007950672588776797, 0.027931461476587822, 0.13076550460287503, 0.055380457413515875, 0.05203520513272711, 0.04590300936251879, 0.053383963116045506, 0.015941956346588473, 0.04159014918176191, 0.021835850618247474, 0.03523878660053015, 0.04791245689349515, 0.0341993557688381, 0.012305523485078343, 0.015879302119304026, 0.3355695477553776, 61.08831187656948, 76.69607121603829, 61.48369911738804, 66.794540813991, 57.37142167772566, 37.78507171358381, 35.14837973458426, 34.47570031029837, 26.923150879996165, 27.2318263394492, 26.569984367915563, 24.03774986948286, 9.192918368748256, 0.11607363367719309, 0.13548054945256027, 0.06515795364975929, 0.5172909423708916, 0.5053442205701555, 0.4528544885771615, 1.3723710562501634, 0.17544281509305748, 28.902732610702515, 100.67829976763043, 92.38089302607945, 90.50897189549038, 88.55789688655308, 90.9541985648019, 83.32079642159599, 85.25426469530377, 82.11845929282052, 81.7094257899693, 78.02460847582135, 76.47427082061768, 77.13328661237443, 84.73674201965332, 79.33426053183419, 81.77242510659354, 83.4723435810634, 85.65539809635708, 81.30451256888253, 83.92737415858677, 81.22655378069196, 82.58837291172573, 84.03246566227504, 82.50436919076103, 79.77073941911969, 77.34495653424943, 77.58366189684186, 79.14236518314907, 78.87715244293213, 79.45460333142961, 80.9530587877546, 81.56822449820382, 78.72655718667167, 75.8551585333688, 70.54437937055314, 68.55989047459194, 66.7139972959246, 63.7297112601144, 64.51588603428432, 63.752800124032156, 68.26940713609967, 77.36443928309849, 74.8781931740897, 71.62749930790493, 76.32168143136161, 61.48444257463728, 63.49545969281878, 59.2046343939645, 64.14240646362305, 72.69538184574672, 67.76381451742989, 74.25824710300991, 67.40526662554059, 65.0177127293178, 67.43773555755615, 65.38827405657086, 62.3321783883231, 62.78660447256905, 59.825733866010395, 63.52310657501221, 65.24962970188686, 66.46418871198381, 68.75937325613839, 69.62588310241699, 68.7354714529855, 69.59853499276298, 69.3780130658831, 71.4866315296718, 72.06694507598877, 71.82560634613037, 70.34707832336426, 66.01978887830461, 70.35105269295829, 71.89739513397217, 73.82536043439592, 72.91674450465611, 73.88032068525041, 71.35375417981828, 72.07754107883999, 66.98471995762416, 66.7288316999163, 65.64218207768032, 65.08449186597551, 60.00986807686942, 61.142306327819824, 63.331113951546804, 66.11698722839355, 70.03462478092739, 69.56512110573905, 68.32338074275425, 71.52289417811802, 69.0247666495187, 73.76304898943219, 67.92283099038261, 80.57522964477539, 0.6063657626509666, 2.633357277938298, 4.762868106365204, 4.080498116356986, 1.0101499557495117, 0.6153281788740839, 0.19306753150054387, 0.11706110568983213, 0.10178209162716355, 0.6759436119879995, 24.955549580710276, 18.364481449127197, 29.94715976715088, 32.9132137298584, 30.94704375948225, 32.07431949887957, 34.64246055058071, 66.10359804970878, 29.913693768637522, 58.19911541257586, 51.09882075445992, 58.34769916534424, 53.87683909279959, 55.98022208895002, 48.7410364151001, 2.3760928426470076, 0.12929191653217587, 0.06478084424244505, 0.06864383231316294, 0.028564566879400184, 0.006689028323827577, 0.04928783380559512, 0.0177834427117237, 0.05411460283877594, 0.0395697806296604, 0.04675952411655869, 0.006577176066847252, 0.06792658008635044, 0.00726520675899727, 0.04448677107159581, 0.04944716739867415, 0.19689256910766872, 0.21370848534362658, 0.09018077129232031, 0.22359227069786616, 0.16809843347540923, 0.1760245095938444, 0.10380237536238772, 0.12738553168518202, 0.10956306981721095, 0.08108627822782312, 0.11484357182468687, 0.11847210569041115, 0.08943107830626623, 0.09145560288535697, 0.2015496806374618, 0.12250496500304767, 0.16769393160939217, 0.18717199856681482, 0.9579761496612004, 76.10100664411272, 88.60063525608608, 72.43317072732108, 86.17206614358085, 81.53708962031773, 53.25940826960972, 50.132684162684846, 60.72479602268764, 34.11876440048218, 39.46128293446132, 46.41640887941633, 38.775148323604036, 17.811104331697734, 0.25475846976041794, 0.23445561634642736, 0.18708055918770178, 0.2857264280319214, 0.30780527900372234, 4.454757188047681, 7.103461299623762, 0.7925922498106956, 22.001998901367188, 99.56617804936, 94.47418376377651, 92.84396266937256, 93.31455721173967, 94.57106249673026, 87.88725675855363, 87.69003214154924, 87.0999424798148, 87.71054322378976, 82.68388284955705, 80.91061919076103, 77.15544441768101, 89.93949059077671, 80.80026095254081, 84.02187660762242, 86.70383957454136, 88.04114546094621, 86.86353002275739, 88.15847969055176, 84.94201959882463, 85.61698845454625, 87.1278325489589, 86.00052901676723, 84.98213849748883, 80.2028478894915, 80.54131548745292, 84.94600786481584, 82.58110509599958, 83.29639434814453, 83.06749289376395, 85.92900426047188, 82.09117371695382, 80.04657595498222, 73.29029355730329, 73.13427175794328, 72.56639548710415, 68.80247293199811, 68.91057995387486, 66.23817770821708, 70.34295109340123, 79.43265397208077, 77.95211791992188, 72.74938324519566, 80.67996679033551, 61.36586461748396, 61.587143898010254, 57.95398991448538, 62.84184265136719, 71.08210740770612, 67.68985789162772, 79.70215375082833, 70.03544466836112, 69.66706507546562, 70.26061494009835, 70.87155614580426, 65.33600970676967, 67.20048236846924, 64.58973843710763, 65.6624777657645, 69.82959733690534, 69.43316091809953, 69.98174898965019, 72.2230224609375, 70.09023816244942, 70.99523408072335, 72.59315299987793, 74.17247853960309, 76.17185047694615, 76.13592829023088, 73.22356305803571, 71.07593740735734, 71.78837789808, 74.5455551147461, 75.5713107245309, 76.10503659929547, 75.79720360892159, 74.52347373962402, 74.77364362989152, 69.25516891479492, 68.12868527003697, 68.55547836848667, 66.40560844966343, 60.737643241882324, 64.00009346008301, 67.62074416024345, 69.55710983276367, 72.28868293762207, 72.77942030770438, 72.27141666412354, 73.56840215410504, 73.19153881072998, 74.31502083369664, 72.27477264404297, 75.9974228995187, 0.18409706785210542, 23.03045736040388, 31.34298685618809, 1.7624383653913225, 0.3254065588116646, 1.2842731092657362, 0.5905244669743946, 0.3893115296959877, 0.13078990472214563, 3.7855618510927473, 39.599559034620015, 34.11498458044869, 51.084830556597026, 42.220357009342735, 42.518587589263916, 57.7852008002145, 74.45394311632428, 99.54406193324498, 47.15239681516375, 73.35027040754045, 62.34082889556885, 65.81521306719098, 60.096519061497276, 67.4702878679548, 52.7786728313991, 1.7859066660915102, 0.22994992669139588, 0.10826318671128579, 0.1424534467181989, 0.16764012378241333, 0.17914024740457535, 0.09317435244364397, 0.07022703771612474, 0.10667069894926888, 0.19597315415740013, 0.08226089698395558, 0.2032063374561923, 0.11884033307433128, 0.17256421170064382, 0.12707549546446117, 0.111067327670753], [0.023200862907937596, 0.029389587430549518, 0.07820050950561251, 0.020901987961094295, 0.031448378028081994, 0.026565921625920703, 0.006387232910908226, 0.024591766397601793, 0.05086546165070363, 0.06204398681542703, 0.031759055464395454, 0.00327008989656211, 0.08036099893174001, 0.012890416430309415, 0.03986066519947989, 0.033035216986068656, 0.04579924100211688, 0.08401668776891061, 0.7459354762520108, 53.90163721357073, 59.88435581752232, 53.873104436056956, 38.23085771288191, 37.45838826043265, 34.660206249782014, 22.24885971205575, 29.84635877609253, 26.885675770895823, 23.78506473132542, 22.200703484671457, 22.060634749276296, 0.7289433309010097, 0.07597851088004452, 0.017465233536703244, 0.04173674327986581, 0.3353368916681835, 1.591190783040864, 3.6954332930701117, 0.41668990201183725, 7.455559526171003, 89.77386638096401, 88.41383293696812, 85.92288289751325, 82.69959272657121, 85.78976930890764, 83.75838007245744, 82.01834964752197, 79.35889884403774, 76.98222582680839, 72.10087312970842, 69.47900513240269, 72.32965646471295, 77.5431330544608, 75.9246266228812, 78.36063030787876, 79.25389766693115, 80.31706932612828, 79.42196764264787, 78.61034161703927, 77.0893531526838, 76.97349888937813, 80.43714809417725, 79.91137790679932, 75.38629409245083, 76.64878177642822, 75.71285942622593, 78.32344354901994, 72.62387098584855, 75.49565873827252, 77.97902829306466, 76.44378212520054, 74.54549258095878, 73.2364867074149, 71.96745382036481, 64.87933935437883, 64.88040937696184, 58.10894863946097, 57.490777833121165, 55.84264428274972, 56.39134005137852, 67.18175002506801, 75.26605551583427, 74.88273729596818, 73.32988439287458, 71.33647400992257, 68.17639854976109, 66.51101957048688, 59.293015480041504, 68.64642333984375, 64.29609366825649, 70.2890956061227, 67.0557861328125, 67.61192689623151, 60.2683549608503, 58.98077733176095, 58.1499673298427, 57.832792486463276, 57.9029449735369, 56.909842423030305, 58.90766838618687, 59.67709800175258, 62.53702517918178, 65.80280358450753, 67.99043001447404, 68.82012830461774, 67.36000605991909, 67.32136712755475, 65.52247851235526, 66.8805456161499, 67.83146217891148, 70.38643986838204, 64.79974773951939, 68.41386713300432, 69.3545628956386, 71.43697275434221, 69.60259274074009, 68.31284032549176, 63.61064692905971, 65.8620022365025, 66.50311252049038, 65.36800616128104, 62.295950480869834, 63.42562334878104, 61.7648093359811, 60.901335852486746, 58.91699981689453, 62.731004987444194, 61.93884086608887, 68.0658666065761, 65.40353230067662, 68.37156649998256, 64.47389807019914, 73.21646199907575, 64.36361626216343, 79.06216212681362, 35.20865535736084, 1.7077099020992006, 13.794892685753958, 15.709970814841133, 3.014024760041918, 0.2481905221939087, 0.31718586278813227, 0.04373392289770501, 0.1502921546676329, 0.022073658482570733, 7.5856853893824985, 34.066340242113384, 28.01984759739467, 32.51187188284737, 35.19080196108137, 35.20503534589495, 53.080078738076345, 49.132386752537315, 30.38191202708653, 22.107901607240947, 24.276340586798533, 33.67982585089547, 44.36333778926304, 45.5859671320234, 54.60805014201573, 10.870830161230904, 0.31333694074835095, 0.05024006949471576, 0.07335089759102889, 0.038310568912753036, 0.026523899952215806, 0.031980665001486025, 0.07674130637730871, 0.08196259941905737, 0.022774669973711883, 0.04881264216133526, 0.047222132328897715, 0.05790196478899036, 0.0184950223857803, 0.07603269868663379, 0.048747492621519735, 0.027515192117009844, 0.02665823631520782, 0.011993730706827981, 0.03533934209761875, 0.049393878650984595, 0.04415210402969803, 0.00882127245755068, 0.046827089241040606, 0.04476820704128061, 0.03243276270638619, 0.047606943108673604, 0.02410901926590928, 0.0480445642689509, 0.050405978092125485, 0.04492336425131985, 0.031202734780630896, 0.02812364125358207, 0.056784923121865304, 1.3369302494185311, 66.65330478123256, 65.53574957166398, 67.65809072766984, 48.863178798130576, 43.733389786311555, 39.34602969033377, 29.479014464787074, 33.39576959609985, 31.313425745282853, 28.12388644899641, 21.41124221256801, 19.918845585414342, 0.2255825496145657, 0.012876168043086571, 0.06085071513163192, 0.19954610243439674, 1.3411607252699989, 2.1363817283085416, 0.27837238407560755, 0.7080061286687851, 17.36975302015032, 101.9589569909232, 89.24512236458915, 90.78639956883022, 85.79673140389579, 90.20039544786725, 86.6415628705706, 83.39812987191337, 82.303927557809, 80.39000456673759, 75.85767378125871, 73.32483305249895, 76.85781138283866, 80.06539862496513, 78.58753068106515, 83.34050846099854, 82.49368980952671, 83.11409446171352, 81.01080526624406, 84.34827518463135, 80.70992742265973, 80.52849606105259, 83.76489748273576, 82.45484937940324, 79.24259989602226, 80.17158099583217, 78.6109322139195, 81.12281717572893, 76.93344252450126, 80.14882564544678, 80.99581105368478, 78.31778076716832, 76.78534861973354, 76.10679449353898, 73.47816589900425, 68.39893545423234, 67.08789375850132, 62.51201861245291, 61.46547399248396, 60.04940332685198, 59.48361151559012, 69.01263509477887, 77.30906214032854, 76.817275592259, 74.54326220921108, 73.55007280622209, 71.04517773219517, 67.08170291355678, 62.610926219395225, 68.58774580274309, 66.66005148206438, 71.0951839174543, 69.58883530752999, 71.4744096483503, 65.0127934047154, 63.91934149605887, 61.37653010232108, 59.95198263440813, 59.00397041865757, 59.57106154305594, 62.629929542541504, 63.765800203595845, 66.02991935185024, 69.865206854684, 68.99377768380302, 71.33326394217355, 69.93057550702775, 71.47108840942383, 68.37919562203544, 68.4662287575858, 70.38429982321603, 73.26856654030937, 68.86146313803536, 71.34709085736955, 71.71673502240861, 74.18711839403424, 71.75153854915074, 70.35798699515206, 65.25069277627128, 67.28448608943394, 68.18157495771135, 67.25305243900844, 65.23761626652309, 67.33595834459577, 63.94167995452881, 64.83454431806291, 61.10532801491873, 64.37730421338762, 63.440944126674104, 71.16785512651715, 70.79757867540631, 70.31945923396519, 69.34990760258266, 74.91139166695731, 69.99496446337018, 78.45377785818917, 48.794270038604736, 1.8415014828954424, 2.6219828597136905, 8.406630686351232, 4.390194092478071, 0.3344479836523533, 0.581617853471211, 0.13482462322073324, 0.13251372293702193, 0.00574028624188421, 5.704570489270346, 30.498593126024517, 27.78534242085048, 38.132505961826865, 41.28929144995553, 39.33323458262852, 48.25355775015694, 36.58703899383545, 33.474002838134766, 33.28155858176095, 34.492219652448384, 41.955085209437776, 55.04706164768764, 52.21497590201241, 66.76413549695695, 16.082651342664445, 0.3475165952529226, 0.0658582289304052, 0.03702570178679057, 0.04716446363766279, 0.029209639943603958, 0.01434324641845056, 0.07474205044231244, 0.056927554575460296, 0.06507685514433043, 0.02338405209593475, 0.059698637308818955, 0.03297954997313874, 0.0608642790466547, 0.02144445974512824, 0.05019780354840415, 0.09075985343328544, 0.1285815853625536, 0.1884916134710823, 0.13265880729470933, 0.122660525941423, 0.22406700093831333, 0.14823126739689282, 0.19949202319341047, 0.12376975427780833, 0.10665562190115452, 0.11570042584623609, 0.1107823226068701, 0.16257990816874163, 0.15279493108391762, 0.11310530081391335, 0.2831264989716666, 0.16729898351643765, 0.26846837837781223, 2.904323995113373, 83.70770686013358, 78.17576653616769, 78.27122783660889, 52.95332275118147, 54.66591821398054, 54.0991883959089, 36.593757901872905, 48.42928811482021, 47.91427721296038, 41.880308696201865, 33.3209479195731, 35.80607884270804, 1.8188346134764808, 0.3044948423547404, 0.209232556234513, 0.22578635439276695, 0.9854835250547954, 2.9693126678466797, 8.690841538565499, 1.3833170746053969, 11.656636680875506, 101.3736824308123, 96.76308018820626, 94.09077521732875, 90.14827006203788, 93.782073702131, 89.04265185764858, 89.11268275124687, 85.23343399592808, 86.31475434984479, 79.16858073643276, 77.92421395438058, 79.74961689540318, 83.66476699284145, 81.82189628056118, 87.13227939605713, 87.10129043034145, 86.7387890134539, 86.4525510243007, 87.65679195949009, 83.64319283621651, 84.00237996237618, 87.4174473626273, 86.99000113351005, 83.78189972468785, 83.53543322426933, 80.49327564239502, 87.19010925292969, 79.72026770455497, 83.2373138155256, 84.55303164890834, 81.72792884281704, 81.24042933327812, 80.0652596609933, 76.83934307098389, 71.00300911494664, 71.38751547677177, 64.93491104670933, 64.73551164354596, 64.99328981127057, 62.82404831477574, 74.41444955553327, 81.94934708731515, 81.84909847804478, 78.07199519021171, 78.20820767538888, 70.78003447396415, 64.19927746909005, 60.904886381966726, 66.68127822875977, 76.02533381325858, 77.41946901593889, 74.05733299255371, 75.8317847933088, 68.56508772713798, 66.12753459385463, 66.08271871294293, 63.38943713051932, 63.195978437151226, 62.72300066266741, 64.88031905038017, 65.71621513366699, 69.8165625163487, 73.15727724347795, 73.3193439756121, 74.25681577410016, 73.43514960152763, 75.8611478805542, 73.07556642804826, 71.20238072531563, 73.63135283333915, 76.44228826250348, 68.2406415939331, 73.3121178490775, 75.06562083108085, 77.22546836308071, 75.77815164838518, 73.9428197315761, 68.81559113093785, 71.38730008261544, 71.21274743761334, 71.13397571018764, 69.36879975455147, 70.30071994236538, 67.57529599325997, 68.49853788103376, 62.65474850790841, 68.06319849831718, 65.13087803976876, 72.70567212785993, 72.71016761234829, 71.19414016178676, 71.08388614654541, 78.63450050354004, 71.37582165854317, 84.276444707598, 42.50915193557739, 3.9358770080975125, 26.21672579220363, 26.876366921833583, 6.138696977070399, 0.3280873421047415, 2.3165422209671567, 0.2963310347071716, 0.3779437339731625, 0.2053632102906704, 12.553880146571569, 46.31437458310808, 37.383302552359446, 48.43798725945609, 50.14553485597883, 53.85458748681204, 69.18913323538644, 59.87555939810616, 55.77413851874215, 35.93641315187727, 38.88799401691982, 53.888400895254954, 66.91647475106376, 61.71950013296944, 79.01064123426164, 19.78443268367222, 0.5850100943020412, 0.17449080332049302, 0.2293537115412099, 0.16197260575635092, 0.15475088969937392, 0.1494005053703274, 0.20385788035179886, 0.12895572957183632, 0.15910380040960653, 0.10643742539520774, 0.15223883092403412, 0.1879961472004652, 0.1926918402314186, 0.20848780976874487, 0.12993843826864446], [0.030441194573151212, 0.017088001993085657, 0.04594420322350093, 0.05516927695966192, 0.06312840791153056, 0.020896688602598648, 0.019389981237639273, 0.03493015155462282, 0.03635714801826647, 0.04140462752963815, 0.032759222867233415, 0.04833528599036591, 0.01339478338403361, 0.06145582587591239, 0.05174439520175968, 0.04151864176882165, 0.1465507261455059, 0.04644099942275456, 0.6355513994182859, 56.45197350638253, 60.44774355207171, 52.20011370522635, 34.43530348369053, 42.31216008322579, 39.18000248500279, 26.33849470955985, 23.774300234658376, 25.047118152890885, 18.635756492614746, 29.115917239870342, 5.012925522668021, 0.1232655756175518, 0.13677676846938475, 0.053160460466252904, 0.08592039918793098, 2.322959750890732, 1.719109941806112, 0.3456493211644036, 1.8343526550701685, 71.37432779584611, 90.83840683528355, 83.38360813685826, 83.76131221226284, 83.32228333609444, 86.47971153259277, 79.4010466166905, 77.01996844155448, 75.0402112688337, 71.04690783364433, 70.31881999969482, 70.69788592202323, 75.1084703717913, 75.69401591164726, 76.10573141915458, 76.50301551818848, 76.91725322178432, 75.19865104130336, 80.48983628409249, 78.61243997301374, 75.91091087886265, 76.3205349785941, 77.75938183920724, 77.39452498299735, 74.44860689980644, 75.06585706983293, 74.6846649987357, 72.98637935093471, 77.48899963923863, 76.98085008348737, 77.16353212084088, 74.79331398010254, 73.30391897474016, 71.78862108503068, 67.61423369816372, 65.65491812569755, 63.606172289167134, 58.61341912405831, 59.65445382254464, 56.942686557769775, 59.64313520703997, 63.047627449035645, 69.97907393319267, 69.36453356061662, 66.6520471572876, 66.91066605704171, 74.39399405888149, 69.4189726965768, 62.78846658979143, 67.96630586896623, 54.939892632620676, 62.33620139530727, 67.6397544315883, 69.6224090031215, 65.1682037625994, 65.48456219264439, 55.96035024097988, 52.600795473371235, 54.43323693956648, 57.160943371909006, 57.64145646776472, 58.742190088544575, 59.55651896340506, 63.27699443272182, 63.60232993534633, 64.76347814287458, 66.61825111934117, 68.60783304486955, 68.10688877105713, 65.9868335723877, 67.3240213394165, 66.2206335067749, 70.22302518572126, 70.76071848188127, 69.38327285221645, 70.56261839185441, 69.29540593283517, 67.58008330208915, 64.6674609865461, 61.160510608128135, 59.88542584010533, 61.23949078151158, 64.85986355372837, 62.13582229614258, 60.042649677821565, 58.62457793099539, 57.28187329428536, 58.897100176130024, 63.39717047555106, 64.1222288949149, 68.0270470210484, 67.3978112084525, 66.94597680228097, 64.01151629856655, 69.64314937591553, 69.05055141448975, 75.8280188696725, 5.798577444893973, 1.5720362280096327, 16.15805493082319, 5.78677419253758, 0.12593118686761173, 0.011413613799959421, 0.08712776404406343, 0.018963069056293795, 0.13081695112798894, 0.1512480748019048, 14.776806899479457, 40.74658850261143, 24.762665850775583, 28.749373708452495, 20.108008555003575, 28.526268788746425, 28.0658255645207, 24.833775452205114, 21.338551895959036, 24.54475470951625, 35.20689746311733, 47.791064807346885, 41.10660593850272, 59.26146371023995, 15.320743152073451, 0.11107295272605759, 0.0531552900294108, 0.031024755045239414, 0.06166097415345056, 0.06246482101934297, 0.05213860369154385, 0.03195173566096595, 0.053537664868469746, 0.046778631662683826, 0.0491247377358377, 0.044044159286256344, 0.05497720405193312, 0.061586247091846805, 0.020256246539897153, 0.031338920151548724, 0.07039711251854897, 0.039308391977101564, 0.030132630773420845, 0.04083466150664857, 0.05829710965710027, 0.07125656532921962, 0.013980264110224587, 0.048824418136583905, 0.02118161733129195, 0.027040261708732163, 0.0329942775757185, 0.06675218524677412, 0.034165958275220225, 0.009915740960942847, 0.017703764040821364, 0.04768697292144809, 0.14029410401625292, 0.09958412671195609, 2.695959027324404, 71.58464976719448, 68.63421535491943, 65.50980499812535, 43.57535648345947, 51.57850701468331, 46.39501537595476, 25.56397553852626, 30.031448364257812, 33.71213844844273, 17.94209177153451, 25.503477573394775, 2.059504904917308, 0.04630674448396478, 0.04251467689339604, 0.030513964061226164, 1.3522045612335205, 1.4531968448843275, 8.883217181478228, 0.23304312356880733, 6.641916785921369, 86.06240272521973, 92.42900235312325, 89.34051418304443, 86.72305829184396, 88.59452778952462, 88.55883489336286, 81.85711669921875, 80.84950283595494, 79.85773086547852, 73.94426495688302, 73.36275632040841, 74.77864633287702, 78.96522780827114, 79.52974809919084, 79.00325529915946, 79.11349541800362, 79.85023375919887, 78.25783865792411, 82.6175206048148, 80.64340536934989, 79.72941153390067, 80.21746689932687, 80.34374346051897, 80.13814626421247, 78.62013857705253, 77.45967129298619, 79.5962632043021, 78.00798143659318, 80.63597774505615, 78.23274176461356, 79.61150060381208, 76.29790469578334, 77.55718926021031, 73.76992075783866, 70.21871730259487, 67.76187597002301, 65.29407732827323, 62.863673891339985, 62.988706724984304, 61.02499294281006, 64.62374986921037, 68.63311753954206, 73.1743072782244, 73.42232322692871, 69.85379096439907, 69.97507871900285, 73.67159679957798, 68.45360388074602, 65.74596732003349, 69.96945762634277, 62.305573735918315, 67.24999523162842, 69.61582905905587, 71.72665010179792, 68.43370423998151, 69.32719394138881, 59.39149924686977, 55.9214438029698, 57.39936038425991, 58.996890204293386, 60.1795083454677, 59.81525598253523, 61.452522550310405, 65.66941206795829, 66.2707439150129, 67.6113224029541, 70.1538975579398, 69.8921936580113, 72.07317761012486, 68.7737351826259, 70.74004759107316, 69.71067196982247, 73.00808552333287, 71.36198084694999, 71.98687403542655, 71.59765679495675, 73.06979247501918, 70.07135990687779, 68.55046871730259, 63.30121585300991, 62.051498958042686, 63.358017376491, 66.25259522029332, 63.51507445744106, 64.59784698486328, 61.55120086669922, 62.084419522966655, 61.57796532767159, 66.36264773777553, 65.00920813424247, 69.62984357561383, 68.68117128099713, 72.05302088601249, 65.58016245705741, 72.09457806178501, 70.73452377319336, 82.22090353284563, 11.605402401515416, 1.9496410744530814, 6.411923161574772, 8.223459669521876, 0.5784993608083043, 0.12975463670279297, 0.17923613797341073, 0.006328891197751675, 0.09254717574055706, 0.18454304177846226, 10.434313927377973, 39.83761821474348, 22.812805039542063, 27.385419743401663, 28.083324602672032, 40.13035971777779, 34.51130287987845, 18.62949616568429, 27.13908699580601, 38.24603257860456, 43.88448878696987, 55.35880994796753, 50.98256002153669, 71.83293669564384, 23.658574513026647, 0.0814489076978394, 0.058348881879023144, 0.0773185429030231, 0.02257330283256514, 0.026405436219647527, 0.049214267038873265, 0.04420155905453222, 0.02585922910033592, 0.04074061994573899, 0.049595600326678584, 0.0066693151851982945, 0.053670861292630434, 0.019926037473071898, 0.0025945484895990895, 0.030995527149311135, 0.188601088310991, 0.09542838470744235, 0.1446619832089969, 0.127747312986425, 0.12107465389583792, 0.14029630246971334, 0.09464809657739741, 0.11233778949826956, 0.13087451803897107, 0.10991370278809752, 0.09479022252240352, 0.15943903742091997, 0.18485181592404842, 0.12853714131883212, 0.1510805580765009, 0.16086883284151554, 0.275824349373579, 0.3376966193318367, 4.314479572432382, 90.27412973131452, 77.61987590789795, 76.56977381025041, 51.79430069242205, 64.21583502633231, 57.80514213017055, 37.9709221294948, 35.14514882223946, 42.859980378832134, 27.308643886021205, 42.84599018096924, 8.49083764212472, 0.21249865740537643, 0.5216798154371125, 0.16869364439376763, 0.6259723848530224, 3.4286552539893558, 9.39526207106454, 0.9071571337325233, 4.919057531016214, 87.24042810712541, 95.56263991764614, 92.11536066872733, 90.38485622406006, 92.4254309790475, 93.31944179534912, 87.65272726331438, 84.8251508985247, 83.51443576812744, 76.59778199877057, 79.34088216509137, 76.41291822705949, 82.35670607430595, 84.75165285382951, 81.39775739397321, 82.78961358751569, 84.29875537327358, 82.80276652744838, 87.60165800367082, 83.82864025660923, 83.78870895930699, 81.8299422945295, 85.37804685320172, 83.26677417755127, 81.86601734161377, 81.30335916791643, 82.17182145799909, 80.72239249093192, 84.64569977351597, 83.2546078818185, 85.10366249084473, 81.12977232251848, 81.8076594216483, 78.76387596130371, 73.20944431849888, 72.65911224910191, 70.73578139713833, 64.97147246769497, 65.49021107809884, 62.01909950801304, 65.2681188583374, 70.45166955675397, 76.16221332550049, 74.08006055014474, 74.07958807264055, 75.17183794294084, 75.75348554338727, 70.74590492248535, 66.67189121246338, 72.36764226640973, 64.7314122063773, 72.02806295667375, 73.15881279536656, 76.5678630556379, 71.50896303994315, 71.54910278320312, 61.83433301108224, 58.969535146440776, 61.08093983786446, 64.85168552398682, 64.37430953979492, 63.56956223079136, 63.90545899527413, 69.54076072147915, 69.37151650020054, 70.50582381657192, 73.01964037758964, 70.73453766959054, 74.83756705692836, 72.4320798601423, 74.17582757132394, 73.06587369101388, 75.99460193089077, 75.5242644718715, 75.09826346806118, 75.98372105189732, 75.33750384194511, 72.89823450360979, 71.00529507228306, 66.594252041408, 67.38989721025739, 66.58253737858364, 69.90677097865513, 67.5875665119716, 66.20509733472551, 64.03980241503034, 64.79557882036481, 64.00891767229352, 68.8748801095145, 67.3560733795166, 73.40127713339669, 72.31179959433419, 72.0617686680385, 68.0640253339495, 74.94808510371617, 73.51402555193219, 81.34494413648332, 8.211610385349818, 9.248882634299141, 39.12664379392351, 15.951405082430158, 0.7862348652311734, 0.22965375972645624, 0.6011928830827985, 0.29527786693402697, 0.33223598663296017, 0.3026032495711531, 22.718710797173635, 56.64643621444702, 35.67366007396153, 44.53734152657645, 33.556856632232666, 42.76650626318795, 42.654400553022114, 35.03511714935303, 36.967772483825684, 41.94898469107491, 51.51246786117554, 69.11512102399553, 58.76815550667899, 83.97909654889787, 27.62359877995082, 0.18313030472823552, 0.13671675883233547, 0.17158437999231474, 0.09025268243359667, 0.18428023159503937, 0.12333846384925501, 0.14117068983614445, 0.1583044318748372, 0.12498608258153711, 0.10644225656454052, 0.0899321221347366, 0.19198628594832762, 0.12146034677113805, 0.15756258953894886, 0.11194485665432044], [0.02263482560270599, 0.05429600239066141, 0.009569516771339943, 0.01745050593412348, 0.03105691760512335, 0.10254281080727067, 0.06252239471567528, 0.004529713187366724, 0.07135684601962566, 0.029082529978560548, 0.005507460096850991, 0.0022046461526770145, 0.046764826867729425, 0.03800592704543045, 0.07961026100175721, 0.04861175508371421, 0.1308479601783412, 0.1212420891970396, 5.359766134193965, 60.03530543191092, 59.701451437813894, 60.957553727286204, 49.82288135801043, 38.88430452346802, 33.39691604886736, 38.28688103812081, 31.490861892700195, 20.46266198158264, 36.38808427538191, 9.732511128698077, 0.04877483419009617, 0.08502896023648125, 0.08868158888071775, 0.15678163644458565, 0.7389638274908066, 3.408401906490326, 3.2271149371351515, 0.1277675469006811, 35.71240322930472, 95.8346757888794, 81.47283962794712, 87.91238839285714, 79.55014106205532, 89.2439272744315, 77.22389112200055, 78.09161690303257, 76.77325180598667, 74.41194820404053, 70.35962677001953, 65.11866310664585, 70.1839485168457, 72.60917554582868, 76.34747314453125, 74.09213651929582, 73.01408181871686, 75.0212982722691, 73.28827163151333, 75.42908109937395, 74.37540762765067, 77.90862219674247, 77.93237113952637, 77.37672369820731, 77.09575939178467, 77.75254481179374, 75.76526273999895, 74.85387447902134, 76.69156878335136, 77.38528387887138, 74.0514965057373, 72.57553236825126, 73.37668051038469, 68.69915321895054, 69.2660984311785, 68.83278097425188, 65.86783872331891, 60.78199359348842, 59.10663005283901, 56.29356847490583, 59.30283328465053, 64.21597399030412, 73.39857428414481, 68.6114808491298, 72.96365874154228, 61.608968189784456, 65.15058313097272, 72.31756659916469, 63.11326013292585, 64.8753719329834, 67.60850838252476, 67.2546157836914, 64.62106786455426, 66.85800565992082, 65.26533957890102, 63.895842688424246, 67.40988717760358, 62.88050937652588, 56.084712573460166, 55.03488492965698, 52.22196578979492, 54.8806140763419, 56.3433210509164, 59.78517723083496, 59.87667110988072, 63.00091470990862, 63.836664881025044, 65.71556895119804, 68.08876092093331, 68.92788096836635, 67.79838180541992, 66.11640357971191, 67.60857091631208, 71.089736529759, 66.57237216404506, 67.7172268458775, 66.86557919638497, 66.21158695220947, 65.21639646802629, 62.582466397966655, 60.73861598968506, 60.58720779418945, 58.7493189402989, 59.03858634403774, 57.94556522369385, 64.4209041595459, 61.55247238704136, 55.760509627205984, 55.959127358027864, 61.09045886993408, 62.24765355246407, 66.7511145727975, 63.93735122680664, 64.28705406188965, 63.12714263371059, 69.79369599478585, 64.95655468532017, 78.86129665374756, 36.76372126170567, 0.7046795157449586, 4.183400068964277, 5.719503036567143, 0.34981845745018547, 0.06335007173142262, 0.16282557855759347, 0.21907750224428518, 0.05114130649183478, 0.30138337931462694, 0.21701493220669882, 14.881952251706805, 34.53675413131714, 26.170091220310756, 23.636640787124634, 14.448033775602068, 29.211234365190776, 33.92334631511143, 29.761232921055385, 25.34260072026934, 40.280944551740376, 51.30995913914272, 46.74910599844796, 54.53231825147356, 25.27339666230338, 0.12772102653980255, 0.06628697485263858, 0.030780957413039038, 0.004950516433122435, 0.11540535810802664, 0.028712260204234293, 0.07637319434434175, 0.027220673992165496, 0.02286985656246543, 0.08931117438312088, 0.05732309299388102, 0.03206090855279139, 0.06538770560707365, 0.02155688960504319, 0.02884504950738379, 0.02353450027294457, 0.01659040172983493, 0.040337536217910905, 0.004501906822302512, 0.047066839411854744, 0.07104957143643073, 0.0787810165701168, 0.02856813258092318, 0.0728352109768561, 0.046619152184575796, 0.046524269240243096, 0.0376165802590549, 0.0070913168934306926, 0.0742337666451931, 0.10772519665105001, 0.03399153406332646, 0.08937599483345236, 0.19759574851819448, 11.78737051146371, 71.39031560080392, 68.39680930546352, 68.27588285718645, 60.68407263074602, 45.524961948394775, 28.2216945035117, 27.94561651774815, 32.95742164339338, 22.986298084259033, 33.070771081107004, 6.831608252865927, 0.05108606356329151, 0.043293896330786605, 0.18417846491294249, 0.15197352373174258, 0.8261627427169255, 1.4391674548387527, 3.416442709309714, 0.3413948251732758, 50.238991601126536, 97.47668102809361, 85.44871698107038, 89.38083457946777, 84.68829223087856, 90.55108492715019, 78.94868414742606, 83.37057331630162, 80.26722294943673, 76.96729414803642, 72.50769015720913, 69.1194497517177, 75.77458722250802, 75.91207122802734, 77.1227878843035, 76.41659382411412, 76.63293988364083, 78.12562833513532, 77.72163227626255, 79.12946237836564, 78.6552825655256, 80.48432636260986, 80.30750165666852, 80.44415882655552, 80.10109152112688, 81.33877413613456, 79.72166429247174, 79.08444499969482, 79.5090285709926, 80.90365014757428, 77.21229457855225, 77.03316307067871, 77.66990293775285, 71.2146998814174, 72.09548132760185, 70.76896599360875, 68.84701783316476, 62.98968642098563, 61.55298655373709, 58.365396227155415, 61.80733231135777, 68.6985695702689, 76.31355898720878, 70.4451104572841, 75.60719122205461, 64.6835252216884, 69.92983899797711, 72.58095891135079, 65.71071216038295, 69.82765184129987, 71.94887433733258, 70.13127422332764, 66.32944924490792, 69.26964201245988, 66.16981438228062, 65.71804945809501, 68.51320552825928, 67.45710713522774, 60.31135041373116, 57.87862280436924, 53.818109444209504, 56.67294011797224, 60.221246174403596, 62.270638193402974, 62.64436789921352, 65.72431673322404, 67.64834935324532, 66.94235679081508, 69.37658868517194, 70.43149893624442, 70.20822552272251, 68.91390119280133, 69.74050058637346, 74.47897747584751, 70.39349923815045, 69.88507175445557, 68.25438513074602, 69.02454430716378, 66.9068306514195, 66.11268629346574, 65.22816671643938, 64.61453655787876, 62.82789761679513, 61.349730900355745, 61.167028018406455, 63.682637214660645, 64.21418830326625, 60.15740612574986, 58.716092654636924, 61.53586619240897, 64.79389040810722, 70.21523625510079, 66.4007933480399, 67.12607410975865, 66.58844334738595, 73.10309519086564, 68.04694666181291, 78.76766272953579, 48.35519252504621, 0.7932094995464597, 0.39610936492681503, 4.260283189160483, 1.328782400914601, 0.08090190669255597, 0.05639500297339899, 0.2177344100283725, 0.050787423338208876, 0.33349678612181116, 0.3554906030850751, 9.662601828575134, 35.19893135343279, 24.17856901032584, 23.85300769124712, 24.500668389456614, 37.72502538136074, 35.81142200742449, 33.296736921582905, 31.376074177878245, 48.993506159101216, 64.13215787070138, 55.880630084446494, 63.354654448372976, 29.442814350128174, 0.10345060923802, 0.050829811420823844, 0.02111518196761608, 0.02364847549636449, 0.08146486684147801, 0.027131081924640706, 0.03577581653371453, 0.026489084320408956, 0.05987797411424773, 0.04034169903025031, 0.06163324921258858, 0.04020677573446717, 0.0679473364725709, 0.011383882939948567, 0.01770083446587835, 0.10614011849143676, 0.10400717758706637, 0.11822381615638733, 0.1182829165565116, 0.10956045067203896, 0.22773896104523114, 0.11184486094862223, 0.1209592486598662, 0.17192305039082253, 0.12751950163926395, 0.0778319224981325, 0.13186163721340044, 0.12989980248468264, 0.18247806972690991, 0.18508078078074114, 0.15305120018976076, 0.19393932686320373, 0.41429820177810533, 15.746141399656024, 89.41291441236223, 77.99994931902204, 87.2523442677089, 70.52254118238176, 56.425962924957275, 53.72888762610299, 57.75884280885969, 48.0939541544233, 34.232537678309846, 53.90678235462734, 14.898454223360334, 0.16094628082854406, 0.23467923434717314, 0.3504208065569401, 0.2956695444881916, 1.6139277858393533, 10.631457771573748, 6.5955875005040845, 0.3287508136459759, 47.10074390683855, 103.13509941101074, 89.01177406311035, 94.71527930668422, 86.74387509482247, 95.13208784375871, 83.87648555210659, 86.48226152147565, 82.63580131530762, 81.84829248700822, 78.53136144365583, 72.19907896859306, 78.59229019709996, 79.95748615264893, 82.65931401933942, 80.31633281707764, 80.39930820465088, 82.15538896833147, 80.03955827440534, 83.42529038020542, 80.18266337258476, 84.494875226702, 83.11820779527936, 83.34367683955601, 83.99509130205426, 84.52620465414864, 81.77120222364152, 81.18390573774064, 80.46551758902413, 83.38164179665702, 79.08792604718889, 82.40006283351353, 80.24724687848772, 73.12557261330741, 76.43768855503627, 74.8034027644566, 72.89111260005406, 67.43333734784807, 64.71315234048026, 63.33957685743059, 64.36323411124093, 71.33992031642369, 78.73902225494385, 71.15548038482666, 77.81401552472795, 67.07810374668666, 71.51554993220738, 77.28467396327427, 72.73198495592389, 72.10382611410958, 73.93095220838273, 73.19941806793213, 69.00471414838518, 72.88715212685722, 70.62079565865653, 68.39926896776471, 72.63179193224225, 69.60480226789201, 63.02915218898228, 61.30005822862898, 57.77907248905727, 61.00517668042864, 63.76195090157645, 65.33933094569615, 67.46192918504987, 69.38119534083775, 72.18678760528564, 70.58398410252163, 73.79234954289028, 74.87994412013462, 74.11856051853725, 71.26329558236259, 72.17166832515171, 75.06277206965855, 73.21863678523472, 73.44321646009172, 72.91578565325055, 70.77002211979458, 70.18774918147496, 70.30720261165074, 66.04136998312813, 66.36556598118374, 66.12665217263358, 65.99893733433315, 64.67114353179932, 69.19558116367885, 67.14461885179792, 61.654597009931294, 63.09056731632778, 64.65375219072614, 68.13974680219377, 71.4361320223127, 67.07281616755894, 70.18483788626534, 68.82187230246407, 75.09014797210693, 70.5712411063058, 85.0389678137643, 45.15966388157436, 1.061690281544413, 10.664453029632568, 13.4352365561894, 2.682116912943976, 0.31286161339708735, 0.22042435354420117, 0.42798029045973507, 0.24376430256026133, 0.545119834797723, 0.9488389428172792, 21.519437823976787, 50.126535006931846, 39.225481918879915, 38.21846907479422, 26.12215907233102, 41.89426415307181, 58.91484587533133, 47.29619325910296, 37.53714261736189, 54.658049379076274, 72.56151090349469, 63.38275991167341, 74.90926551818848, 41.78938109534127, 0.19453985749610833, 0.2527520688516753, 0.08045097267521278, 0.11131083353289536, 0.1906014909701688, 0.09056587384215423, 0.15199177632374422, 0.1264591413949217, 0.1411908016140972, 0.1920718899262803, 0.18720827304891177, 0.12635759184403078, 0.20721239463559218, 0.10446848640484468, 0.15590046372796806], [0.04874131456017494, 0.05493836810014077, 0.057574347725936344, 0.025485875384349908, 0.04448585844199572, 0.03941580407055361, 0.06742498664451496, 0.025256444034831863, 0.06642976576196295, 0.062121774069964886, 0.0691737410213266, 0.033738287830991406, 0.01913915907165834, 0.016672100738755295, 0.08138059279216187, 0.07580665153052125, 0.057637824676930904, 0.06398127214717013, 12.356603418077741, 65.40163544246128, 49.48882586615426, 59.660470962524414, 63.94896166665213, 39.59253787994385, 40.044969831194194, 32.74209002086094, 26.68005425589425, 29.754267351967947, 23.36444510732378, 0.6912317659173692, 0.07822632097772189, 0.09569973764675004, 0.0501737800160689, 0.22840305683868273, 4.128861052649362, 1.4576645365783145, 0.25405265763401985, 7.142157988888877, 86.96939277648926, 80.42336981637138, 87.1124631336757, 81.29156112670898, 88.66452394212995, 80.51532922472272, 78.89359882899693, 76.51716205051967, 76.34217861720494, 70.00144018445695, 69.2841567993164, 70.56158311026437, 73.94584219796317, 71.8788503919329, 72.86154106685093, 69.95993859427315, 71.06714793613979, 71.30879933493478, 73.52066802978516, 74.64066205705915, 75.20335497174943, 73.78107956477574, 78.78753457750592, 76.04538631439209, 77.45775359017509, 76.79964801243374, 75.75154699598039, 74.75738484518868, 78.0484060559954, 75.2956895828247, 76.00381524222237, 72.33988421303886, 71.08091926574707, 71.73008251190186, 70.37121636526925, 64.43755899156842, 61.53485870361328, 57.68779053006853, 57.23981932231358, 56.92445795876639, 61.40096691676548, 64.44896793365479, 70.37350927080426, 70.8076605115618, 63.636973653520855, 59.21791240147182, 69.91576889583042, 65.13417148590088, 62.149531091962544, 63.69310814993722, 69.2899238041469, 65.60954638889858, 66.41832365308488, 66.5997063773019, 61.174017906188965, 60.44392899104527, 64.8153325489589, 64.25687108721051, 60.912987981523784, 54.601539679935996, 50.394433225904194, 52.535725593566895, 56.590416363307405, 54.59649181365967, 57.29407433101109, 59.00613825661795, 60.133323669433594, 63.11908272334507, 65.87965066092355, 66.15567479814801, 65.18462930406842, 65.05283587319511, 66.67111301422119, 64.80277715410504, 65.92065892900739, 66.5876373563494, 66.55642604827881, 63.38650499071394, 64.97724642072404, 62.802675655909944, 62.66729695456368, 62.604992457798545, 61.71257277897426, 59.086765153067454, 58.00915513719831, 56.14488397325788, 57.98367609296526, 62.35755320957729, 57.100254331316265, 57.1378093447004, 61.58601828983852, 61.43128885541643, 65.26210866655622, 63.59700066702706, 64.61810098375592, 63.20303085872105, 70.66411767687116, 66.08708912985665, 71.68119498661586, 5.06197589635849, 0.49988147084202084, 7.605069994926453, 0.2833823338150978, 0.1942035619701658, 0.016804823884740472, 0.07867981307208538, 0.08716971786426646, 0.43464155016200884, 0.3508863630039351, 0.40895913541316986, 16.710966518947057, 36.47648968015398, 20.42080429622105, 16.47910339491708, 27.68843068395342, 23.99480652809143, 25.24737392153059, 41.11664955956595, 33.963962009974885, 38.93561349596296, 44.304069655282156, 53.95578452519008, 9.443451302392141, 0.11518648985241141, 0.009702056712870086, 0.05849149636924267, 0.005977176387594747, 0.00878267060033977, 0.03894721796470029, 0.024335186861987625, 0.06780583477978196, 0.036421154226575575, 0.04413030269954886, 0.04400912652324353, 0.04736308101564646, 0.022245594167283604, 0.056186377203890255, 0.033871185699743886, 0.022686433279886842, 0.045272558727966886, 0.035172554797359874, 0.025614395005894557, 0.020367578869419437, 0.016210315250126377, 0.05550752666645816, 0.03815227347825255, 0.03503110060202224, 0.025053475551041107, 0.04142625583335757, 0.03411899347390447, 0.03954113627384816, 0.019789199012198617, 0.03440340142697096, 0.09235205621059452, 0.07081281021237373, 0.11890072269099099, 19.506525584629603, 81.0579001562936, 59.30536937713623, 78.69672162192208, 84.13168593815395, 51.323108604976106, 23.270753860473633, 28.536854369299753, 28.536189079284668, 33.36170605250767, 19.359185559409006, 0.33780768194368904, 0.05095969320141843, 0.019030167687950388, 0.16175497243446962, 0.47634309104510714, 1.73582361638546, 0.6275345353143555, 0.5324384495615959, 14.984344380242483, 94.9009907586234, 84.57229900360107, 89.32062149047852, 85.90160751342773, 90.02784388405937, 83.13507802145821, 82.33479840414864, 81.73008278438023, 80.89829308646065, 72.75420529501778, 72.37934303283691, 76.53350421360561, 76.65976687840053, 74.18455450875419, 76.37112481253487, 74.24901294708252, 75.44814695630754, 75.63342761993408, 77.81622505187988, 75.52721745627267, 79.55116939544678, 76.93223353794643, 79.9525112424578, 78.9664090020316, 80.2425846372332, 79.04698726109096, 80.00503267560686, 76.89692974090576, 80.73038986751011, 78.76682199750627, 79.15068217686245, 75.70606408800397, 75.70068618229458, 75.01855373382568, 72.44576086316789, 67.50442436763218, 66.41991479056222, 62.052992820739746, 60.639277594430105, 61.04913098471505, 64.53990595681327, 67.92664555140904, 72.74100371769497, 73.66944980621338, 64.5143713269915, 65.68874890463692, 70.95920767102922, 67.41924640110561, 66.15839154379708, 67.59245109558105, 73.49523762294224, 69.46764482770647, 68.32341548374721, 69.64258657182965, 65.9779190335955, 62.1066746030535, 64.4339598246983, 67.48400361197335, 63.50236620221819, 58.39295278276716, 53.96854141780308, 54.57306248801095, 56.639647824423655, 58.096504415784565, 61.150366238185335, 61.73268781389509, 62.900957924979075, 65.4005515234811, 68.33403927939278, 69.58656324659074, 67.44779654911586, 67.43392794472831, 69.54481846945626, 66.95060430254254, 69.32692296164376, 69.34074987683977, 69.16273008074079, 66.90401663099016, 66.51955195835659, 65.3023178918021, 66.06370149339948, 64.36916092463902, 63.72032424381801, 62.31361974988665, 61.714073589869905, 58.78840255737305, 60.10842827388218, 63.98327881949288, 60.16201278141567, 60.21119907924107, 65.49877820696149, 63.20056424822126, 68.3049819128854, 65.25658484867641, 67.59586266108921, 63.15929889678955, 74.4852100099836, 68.09088706970215, 77.63083321707589, 8.568171960966927, 0.9044716549771172, 3.757220583302634, 0.6408693226320403, 0.08007777841495616, 0.03895416955596634, 0.06082851346582174, 0.15790473403675215, 0.7807580019746507, 0.40893348678946495, 0.11602776470993247, 12.212728806904384, 36.332884311676025, 18.291758128574916, 13.969381928443909, 37.770553452628, 26.923131772450038, 16.601626191820415, 49.21784264700753, 48.47713688441685, 52.09496314185006, 49.8006123815264, 63.49230521065848, 10.91057472569602, 0.11857050683881555, 0.036285677924752235, 0.12550509401730128, 0.04965600012136357, 0.03233048373035022, 0.03692584518077118, 0.02991320611909032, 0.08354239179087536, 0.05257323251238891, 0.028628820752991096, 0.015548887795635631, 0.028730567079037428, 0.02495251632561641, 0.08416862533028636, 0.019084173986422162, 0.16539590992033482, 0.07881670072674751, 0.1033800280253802, 0.08264843547450644, 0.10867072162883622, 0.18772527602102074, 0.14830155005412443, 0.13772222559366906, 0.17092324261154446, 0.12790526236806596, 0.1206648051738739, 0.112816204183868, 0.07182031936411347, 0.11340167812470879, 0.1922817336661475, 0.156782667817814, 0.18924362026154995, 0.18270347906010492, 25.85289900643485, 98.06166376386369, 68.07529531206403, 75.99032878875732, 77.02825764247349, 61.20736925942557, 59.195448875427246, 51.14559602737427, 41.47618062155587, 44.56011077335903, 36.42496183940342, 2.3019386274474005, 0.17181907168456487, 0.2515796146222523, 0.19613594827907427, 0.8869645286883626, 7.546400274549212, 4.202042954308646, 0.6208116646323885, 12.119266850607735, 100.46096706390381, 87.37641824994768, 95.9495017187936, 86.41499601091657, 94.9569376536778, 87.6315838950021, 86.83996173313686, 84.84098584311349, 85.39760603223527, 77.20309516361782, 76.98798588344029, 78.79419095175606, 81.66973767961774, 77.96132428305489, 79.8684310913086, 77.30526842389787, 77.58822686331612, 77.88850021362305, 81.88420077732631, 77.93763092585972, 82.5729479108538, 80.20570359911237, 86.2190637588501, 82.63145869118827, 83.96879237038749, 82.85214042663574, 83.4412920815604, 80.58543654850551, 84.2188719340733, 82.80335712432861, 83.2669061933245, 78.27830805097307, 74.9074798311506, 77.74774360656738, 75.65419578552246, 72.18951824733189, 71.4083948135376, 65.84390217917306, 64.65029893602643, 66.04127270834786, 67.01232515062604, 69.69354466029576, 76.61950206756592, 77.22254317147392, 70.1480610711234, 66.66785430908203, 74.37474060058594, 71.48275443485805, 73.8179953438895, 71.30241394042969, 75.27182946886334, 70.76647853851318, 73.58368124280656, 71.48533916473389, 67.06335272107805, 66.90585790361676, 68.3571698325021, 69.8247822352818, 67.9544175011771, 60.49369893755232, 57.57023048400879, 58.50980063847133, 61.050381660461426, 61.67196750640869, 65.08837590898786, 65.79369449615479, 65.76915345873151, 69.80538981301444, 71.50180639539445, 72.50791249956403, 71.16763973236084, 69.83264064788818, 71.71783283778599, 68.29163442339215, 71.7611757005964, 72.15488147735596, 71.67682456970215, 68.04463291168213, 71.28095095498222, 67.33074719565255, 69.71809959411621, 68.60639476776123, 68.07569830758231, 65.12986360277448, 64.9521564756121, 62.09951795850481, 64.08190849849156, 68.37114265986851, 62.41911424909319, 63.47928428649902, 67.35007708413261, 66.61504799979073, 70.33501625061035, 68.0534918648856, 71.93892451695034, 65.71745886121477, 76.79799434116909, 70.0748131615775, 81.31834643227714, 6.852216175624302, 5.838421021189008, 21.70633394377572, 2.402928522654942, 0.5788242433752332, 0.14907433358686312, 0.3303320716534342, 0.14854485914111137, 1.9756253830024173, 1.4296317036662782, 0.8137117879731315, 27.466364519936697, 54.848530769348145, 32.56478588921683, 27.37216431753976, 46.170192514147075, 31.524696145738872, 32.9578663281032, 61.13641425541469, 51.266974108559744, 58.75579466138567, 59.742723737444194, 75.51521791730607, 19.54112240246364, 0.3509563335350582, 0.15803342498838902, 0.24438806623220444, 0.1013096005522779, 0.08877289933817727, 0.11017168180218764, 0.1451018638908863, 0.24373710687671388, 0.18796224759093352, 0.1629366140280451, 0.1119355403685144, 0.16642900662762777, 0.06982273941061326, 0.21122283515121254, 0.0953567246241229], [0.06262120298509087, 0.02859462598072631, 0.056211723879511864, 0.03908811915399773, 0.04820166887449367, 0.06671969020473105, 0.03281657264700957, 0.025640106394088695, 0.05158064773838435, 0.09854995113398347, 0.02805476146750152, 0.04673924609752638, 0.042785911089075465, 0.014682795519807508, 0.0861709618142673, 0.039642153174749444, 0.15921262385589735, 0.2416181234376771, 15.71869080407279, 63.770233154296875, 53.09034817559378, 44.25530024937221, 26.56301358767918, 25.400748457227433, 41.2767117364066, 40.874351978302, 31.599500451769146, 41.89355891091483, 3.6054128663880483, 0.051406664574252706, 0.08410692614104066, 0.07739758544734546, 0.05179042362474969, 0.07918804937175342, 0.9936635089772088, 0.49883815539734705, 0.13302673612322125, 48.76491042545864, 90.38518973759243, 83.45786353519985, 82.5947652544294, 82.12476825714111, 84.13873835972377, 80.28514235360282, 75.38649559020996, 77.4331361225673, 70.49577672140938, 70.87887259892055, 67.54081903185163, 70.55045209612165, 69.5401840209961, 67.80867208753313, 69.6802944455828, 69.0893223626273, 70.58474840436662, 72.92939717429024, 72.59952449798584, 71.74791853768485, 72.69964803968156, 69.90845244271415, 72.37593841552734, 72.89381544930595, 73.09008121490479, 73.48318249838692, 72.29948043823242, 75.50643539428711, 73.69727734157017, 73.19226142338344, 74.81695175170898, 71.35458796364921, 71.44734641483852, 69.00657626560756, 64.1777936390468, 62.34164878300258, 58.32600688934326, 58.17563050133841, 55.14494092123849, 56.666332381112234, 63.78663785117013, 69.25171566009521, 70.28682354518345, 62.2634676524571, 61.34073298318045, 71.64415413992745, 65.96261215209961, 67.35498251233781, 60.00457354954311, 65.66282517569405, 66.59157003675188, 68.00331197466168, 59.91840199061802, 66.2754408972604, 66.80685302189418, 61.18607303074428, 57.38739211218697, 62.2666916166033, 63.862845693315776, 56.34136165891375, 53.56936740875244, 51.32344906670706, 52.23100539616176, 54.54638140542166, 57.364994594029014, 57.168454374585835, 60.19562121800014, 62.62855379922049, 62.86508437565395, 65.69927542550224, 64.38637161254883, 66.14570413316999, 64.42234243665422, 63.30234840938023, 65.74996948242188, 64.68167005266461, 64.83378001621791, 63.013206073216026, 61.73609937940325, 59.50797189985003, 59.83281408037458, 58.54098415374756, 58.43307168143136, 57.96379729679653, 60.31362247467041, 58.36045605795724, 54.506113120487754, 54.6116805757795, 57.93621642248971, 54.38146243776594, 60.59566375187465, 60.95230088915144, 61.82722500392369, 63.35350799560547, 65.27069664001465, 62.79451152256557, 65.58907004765102, 65.02725955418178, 73.95071983337402, 21.774752855300903, 0.25003765736307415, 3.851473331451416, 0.46195918002298897, 0.08402449770697526, 0.07784983582262482, 0.10531115225915398, 0.22490016051701137, 0.2470073199697903, 0.013426372581826789, 0.06706057262739964, 0.4631141551903316, 20.725962230137416, 31.73179762704032, 41.36807359967913, 17.460027490343364, 30.811494827270508, 39.92816366468157, 25.522223813193186, 25.761491979871476, 42.6055269241333, 46.44305174691336, 55.6150039264134, 8.01366923536573, 0.34526711595909937, 0.01637182354794017, 0.026642923476174474, 0.015999623341485858, 0.007052472459950617, 0.03539383185229131, 0.05128978013194033, 0.09753083903342485, 0.020790921956566826, 0.07410076021083764, 0.06659515188740832, 0.08002572120832545, 0.03376470659194248, 0.02059882869278746, 0.06903219183108636, 0.05590080217059169, 0.028825188787387948, 0.09426276332565717, 0.01693532652487712, 0.008605646751155811, 0.08831326650189501, 0.03144135179796389, 0.03264892360727702, 0.03169887280091643, 0.028390293641548072, 0.03207719339323895, 0.09697634700153555, 0.023680660108636533, 0.02475166996009648, 0.05785155642245497, 0.0977462399750948, 0.21664097798722132, 0.35734221658536364, 26.498654161180767, 70.94252504621232, 68.17207677023751, 62.37194292885916, 39.93301698139736, 25.632660218647548, 37.480973379952566, 45.971651213509695, 32.566328389304026, 36.056589194706504, 2.0980109529835835, 0.0826962993347219, 0.05334969370492867, 0.07101058959960938, 0.12673702862645897, 0.4029449267046792, 0.8592229772891317, 0.9844423809221813, 0.713938153215817, 63.719143050057546, 91.08619349343437, 90.16053363255092, 83.33226789746965, 88.15911892482212, 87.2480502809797, 83.18590409415108, 78.53705896650041, 84.08778027125767, 73.61498982565743, 74.97332096099854, 71.84181649344308, 73.00653607504708, 72.10245731898716, 70.66922460283551, 70.99788134438651, 72.57524054391044, 73.81825937543596, 76.06315285818917, 73.95390905652727, 75.42546108790806, 74.23261519840786, 74.0924630846296, 76.476473399571, 76.5572601045881, 75.21490287780762, 77.69443702697754, 76.31597001211983, 79.26161016736711, 77.2165538242885, 73.50635474068778, 76.6724681854248, 75.42860167367118, 72.05632128034318, 72.46242959158761, 68.18289511544364, 63.838130950927734, 63.052498136247905, 60.82698317936489, 58.907501629420686, 61.92779323032924, 65.4029208592006, 72.53580951690674, 73.34542751312256, 62.17088290623256, 65.73817838941301, 73.65248230525425, 68.78402546473912, 72.13400908878872, 63.69172545841762, 70.02418163844517, 71.31066840035575, 71.14928953988212, 63.70296764373779, 66.33816923413957, 68.43138354165214, 64.66680090767997, 60.82821995871407, 64.55678313119071, 64.09506143842424, 61.378913334437776, 56.43369279588972, 55.45214509963989, 53.31070334570748, 55.45554624285017, 58.36519472939627, 60.15609291621617, 62.800104822431294, 63.750152860369, 64.96110575539726, 67.19568811144147, 66.06082493918282, 67.91237395150321, 66.5565163748605, 65.50562218257359, 65.9322624206543, 66.63082735879081, 67.05252742767334, 64.58996077946254, 63.894668442862375, 62.17196682521275, 62.59815543038504, 61.35685975211007, 63.03618376595633, 61.518113545009065, 62.3337208884103, 60.50183527810233, 59.22812625340053, 57.22754185540335, 59.58548600333077, 57.14445529665266, 63.87757587432861, 64.16579410008022, 63.65204429626465, 67.88665866851807, 68.40115887778146, 67.72094413212368, 66.68456472669328, 65.92892728533063, 77.652421270098, 31.516028267996653, 0.5110560740743364, 1.7102418690919876, 0.056827131392700334, 0.19637380194451126, 0.08125702477991581, 0.17816691606172494, 0.22617739412401403, 0.5370449423789978, 0.021299941964181404, 0.0794282779097557, 0.05510845308059028, 19.96119659287589, 32.79844338553292, 27.436937161854335, 16.547232219151088, 38.773675305502756, 29.401111262185232, 31.584169251578196, 30.86182062966483, 49.580809593200684, 52.78231716156006, 64.6101244517735, 10.491778135299683, 0.3541787234800202, 0.08350091294518538, 0.03265050798654556, 0.037939854697989564, 0.037050722765603235, 0.017195651573794227, 0.060929520188697746, 0.04430407551782472, 0.043949652928858995, 0.02059321042283305, 0.038094550504216125, 0.042809388400720697, 0.020683489507064223, 0.03173545940912195, 0.008559825281346483, 0.13563464475529535, 0.12011308835021087, 0.21066710140023912, 0.17836299911141396, 0.16212630750877516, 0.14072538087410585, 0.2108846397272178, 0.12159541595195021, 0.16152357842241014, 0.25007220836622374, 0.11444274761847087, 0.20574647401060375, 0.14430184396249907, 0.1350400580891541, 0.16405279056302138, 0.19226580166390964, 0.3496373157416071, 0.32482030455555233, 34.36794417245047, 89.2055662700108, 71.48595755440849, 62.73768220629011, 39.194287981305806, 41.67559044701712, 57.89332171848842, 59.950836181640625, 45.840743677956716, 57.44338764463152, 6.567673546927316, 0.2526853824300425, 0.21490155346691608, 0.20144665188023023, 0.20642340768660816, 0.4485935600740569, 2.4439430875437598, 1.4095227484192168, 0.7049453386238643, 61.80002280644008, 96.51649556841168, 92.96217932019914, 88.82527746473039, 89.9552560533796, 92.65413093566895, 87.70795849391392, 83.4652008329119, 86.48502690451485, 76.84265041351318, 79.9015531539917, 75.71452004568917, 77.93954862867082, 76.18804672786167, 77.3191578728812, 78.41103948865617, 76.65692506517682, 77.819518498012, 79.97382136753627, 79.0644063949585, 80.15960230146135, 77.98455905914307, 78.52113369532994, 79.9217654636928, 80.44457571847099, 81.49194717407227, 81.41539192199707, 80.75970431736538, 81.3395106451852, 81.16263730185372, 76.78258323669434, 79.72474234444755, 78.39186940874372, 76.31408705030168, 78.30393995557512, 70.82984610966274, 69.8307854788644, 65.99118314470563, 62.785416330610005, 62.0494144984654, 63.938393456595286, 70.49426201411656, 76.43313748495919, 76.49431637355259, 67.51681300571987, 69.12511948176792, 77.13472488948277, 72.27320235116142, 76.79872390202114, 69.24616404942104, 72.84423310416085, 73.97629615238735, 73.87512343270438, 66.1925766808646, 74.04076848711286, 71.86689949035645, 66.34975188119071, 64.14208684648786, 69.52830260140556, 68.07325948987688, 65.30576419830322, 58.640093258449006, 60.632676805768696, 57.248459407261436, 61.52363041469029, 63.12858785901751, 63.24936144692557, 66.76076562064034, 68.18844672611782, 68.20795726776123, 71.37501566750663, 70.2697170802525, 71.34603473118374, 69.54596492222377, 68.9847936630249, 71.02331175122941, 71.19407067980084, 70.42284148080009, 67.76866436004639, 67.847811290196, 65.3180764062064, 65.96238980974469, 63.07284940992083, 66.47666072845459, 64.485077721732, 65.87974098750523, 63.84676061357771, 61.610469000680105, 61.318971225193565, 64.03249291011265, 59.283121245247976, 67.2851322719029, 65.40261513846261, 65.14479528154645, 70.86800561632428, 70.93097019195557, 68.83495576041085, 69.85051836286272, 69.07975469316754, 82.20693070547921, 28.752682788031443, 0.6039195082017353, 10.532941869327, 2.504135114806039, 0.33780830619590624, 0.30604600054877146, 0.27878094358103617, 1.0387119374104907, 1.6296396170343672, 0.24995753594807216, 0.18784304255885736, 1.1614781383957182, 35.9388484954834, 47.77731779643467, 57.357646874019075, 28.491241182599747, 50.696638175419395, 58.368800844464985, 39.895222255161826, 38.70107010432652, 61.20285987854004, 60.98135825565883, 79.04834910801479, 13.065292750086103, 0.5028156733938626, 0.16080229569758686, 0.1676126838262592, 0.1135323029011488, 0.07825646828860044, 0.15836387154247078, 0.1562889250261443, 0.19520634173282556, 0.13903270741658552, 0.1482282682721104, 0.18271087509180817, 0.08758785828415837, 0.09094857437802212, 0.08733044245413371, 0.1931326844330345], [0.006853749484954668, 0.03463154186361602, 0.023326814274436662, 0.02115874900482595, 0.004576185626709568, 0.017344958115635172, 0.019099802344239185, 0.019666826917922924, 0.049715517820524316, 0.03396905419815864, 0.014296997471579483, 0.03517421381548047, 0.08994521786059652, 0.0496529704625053, 0.032188225471015484, 0.060102324932813644, 0.011679951517310525, 0.4687677632485117, 29.95729718889509, 61.65223462241036, 40.803977148873464, 36.42900569098336, 35.87287187576294, 36.791475840977256, 28.777284622192383, 22.157037530626567, 30.343457221984863, 9.123874119349889, 0.08096145492579256, 0.09011645974325282, 0.08882680894540888, 0.09962600589330707, 0.29299712074654444, 0.7806979651962007, 0.45833178609609604, 0.20071643963456154, 5.644816849912916, 83.22006838662284, 80.88575158800397, 86.04391356876918, 75.8409286226545, 81.14590603964669, 78.2547606059483, 78.61420481545585, 76.92567443847656, 75.0419066292899, 69.28032834189278, 67.70820808410645, 64.8081133706229, 68.03088242667062, 63.04662690843855, 65.10444709232875, 65.3475923538208, 66.19145802089146, 65.71831348964146, 67.58921323503766, 66.84185804639543, 69.14762469700405, 68.3348730632237, 69.55168328966413, 68.97120298658098, 68.99768257141113, 70.09109279087612, 72.52003710610526, 71.04330866677421, 72.42336681910923, 71.64203493935722, 71.73376505715507, 71.50733021327427, 73.24210780007499, 70.38099942888532, 67.86453560420445, 64.83569771902901, 60.005657468523296, 58.26017965589251, 56.94271435056414, 57.31265728814261, 61.28639112200056, 63.44416809082031, 67.43880558013916, 63.25597613198416, 55.71738910675049, 63.555735315595356, 63.48354353223528, 66.12400490897042, 67.82481275285993, 60.50650446755545, 66.16332476479667, 68.09716129302979, 68.38526139940534, 66.13014016832624, 59.92314761025565, 59.59492860521589, 64.98411818913051, 60.42865685054234, 57.74235820770264, 58.813353538513184, 56.6605931690761, 54.21971879686628, 50.8571207182748, 51.41082961218697, 49.2914205959865, 52.015736307416645, 51.58107437406267, 51.0176796913147, 54.65348441260201, 56.36848047801426, 56.28562668391636, 56.29967941556658, 58.170547894069124, 58.634131704057964, 59.804910114833284, 59.41402530670166, 59.14028712681362, 58.687042236328125, 57.77117586135864, 60.65703024183001, 61.02005277361189, 61.502771922520225, 59.75582109178816, 60.81351062229702, 59.8978978565761, 57.629189423152376, 56.971601486206055, 55.89950834001814, 54.84890597207205, 54.17648710523333, 56.35055412564959, 57.04524196897234, 61.2347868510655, 60.80501992361886, 63.42360142299107, 62.45871203286307, 63.341181891305105, 63.50893919808524, 64.44953073774064, 69.547014100211, 49.95372288567679, 2.414920679160527, 0.4072074294090271, 0.8422218752758843, 0.11064158765865223, 0.07672702321516615, 0.0702930727441396, 0.2520397427890982, 0.07194383309355804, 0.1142847982368299, 0.10205147681491715, 0.051572410323257954, 3.4812424778938293, 23.15715602466038, 36.55985069274902, 32.123623916081016, 25.27233532496861, 28.182041134153092, 31.325581618717738, 48.32972737721035, 54.508388655526296, 47.47779137747628, 47.41238103594099, 7.341447523662022, 0.30483353989464895, 0.036475895039205036, 0.043545714246907403, 0.10469025879033975, 0.09925823991319963, 0.016421823097126823, 0.06045698840171099, 0.04226610576733947, 0.03525277120726449, 0.05613161264253514, 0.0356737207621336, 0.008099148349304284, 0.04636860991429005, 0.02147999801672995, 0.01970038386727018, 0.010536988964304328, 0.008807851883050586, 0.05468787332730634, 0.022941177378275564, 0.014981349231675267, 0.030207001604139805, 0.007734467159025371, 0.036963995812194686, 0.12740681054336683, 0.06408865031387125, 0.060653804269220145, 0.028109274970899736, 0.00881333529417004, 0.08916366765541689, 0.03178278722667268, 0.07206465303897858, 0.040632519139243026, 0.9445730745792389, 43.49618870871407, 73.07266902923584, 57.31996331896101, 55.42937585285732, 42.8264171055385, 28.118670088904246, 36.533423219408306, 25.979432650974818, 28.07770698411124, 6.025470869881766, 0.06491201184689999, 0.1549252596284662, 0.06245266845715897, 0.05301644480121987, 0.40508375050766127, 1.0252558823142732, 0.7491691570196832, 0.8395926877856255, 10.249683788844518, 90.61715534755162, 84.28198937007359, 90.21570927756173, 79.90210206168038, 85.87844221932548, 81.2677218573434, 83.51991094861711, 80.31111471993583, 77.36594009399414, 73.68508325304303, 69.45127487182617, 69.76871027265275, 72.23414652688163, 67.91345092228481, 71.21668011801583, 69.07340403965541, 71.86025006430489, 69.64449732644218, 71.51185349055699, 70.37705980028424, 73.19550623212541, 70.4609523500715, 72.09508528028215, 71.58312811170305, 73.16024412427629, 73.5439236504691, 73.78289999280656, 72.60323483603341, 74.76815455300468, 75.0719575881958, 72.69003173283168, 74.6122717176165, 75.15653106144497, 73.27822453635079, 69.77581133161272, 67.44460037776402, 62.18008926936558, 60.517142159598215, 58.89392484937395, 59.77844442640032, 63.80193778446743, 66.76473304203579, 69.8220168522426, 63.105346134730745, 62.60466589246477, 66.60427829197475, 69.08151258741105, 68.78015531812395, 72.22526672908238, 65.98927933829171, 68.75692054203579, 71.53542872837612, 71.84009334019252, 69.23853492736816, 65.30887699127197, 62.40004144396101, 66.44010625566754, 66.60471602848598, 61.74796690259661, 60.90823541368757, 58.186337675367085, 55.55140011651175, 53.651647976466585, 52.37218584333147, 51.54901538576399, 53.04647377559117, 53.25377675465175, 52.55019521713257, 56.839637824467246, 57.07338217326573, 57.35818535940987, 57.868325574057444, 59.69575391496931, 59.35579940250942, 60.480372292654856, 61.38680648803711, 61.38969693865095, 60.81481688363211, 60.24323027474539, 64.25137506212506, 63.27722372327532, 63.16000066484724, 63.14206041608538, 63.434127943856375, 63.325541496276855, 60.78343881879534, 61.01282664707729, 59.667064802987234, 57.96505492074149, 57.49604456765311, 60.64708736964634, 57.368520804813926, 63.230768067496165, 61.65418011801583, 65.56381334577287, 64.78761618477958, 65.89599282400948, 67.57740824563163, 68.24280943189348, 71.19517544337681, 57.03529562268938, 5.044038253171103, 0.3785514027944633, 0.7703627912061555, 0.20141971403998987, 0.21123118113194192, 0.041166054617081366, 0.5527935230306217, 0.15910241619816848, 0.06737370975315571, 0.21940788094486507, 0.0687979751133493, 2.027925342321396, 23.167821509497507, 33.98149926321847, 24.201704774584087, 30.351339953286306, 28.01307484081813, 26.945148876735143, 60.821250915527344, 59.81366484505789, 52.031470503125874, 55.08842427389962, 7.8172957726887295, 0.5086776188441685, 0.1342214463012559, 0.13574858435562678, 0.09033625080649342, 0.05628252900870783, 0.06268929397421223, 0.04120975566495742, 0.05565175607002207, 0.03484353655949235, 0.05441160100911345, 0.04466792635087456, 0.02360141909282122, 0.11110341216304473, 0.10410989421818938, 0.07143189199268818, 0.10519075979079519, 0.19709146129233496, 0.178740101733378, 0.15389299073389598, 0.12519439283226216, 0.14243660547903605, 0.1968935869101967, 0.08651027003569262, 0.18952420806246145, 0.08650793587522847, 0.19341694989374705, 0.10924127458461694, 0.13995235306876047, 0.20859170705080032, 0.1514168128903423, 0.16318628777350697, 0.20874848935220922, 0.6948996548141751, 52.64551060540335, 84.69792243412563, 59.720927238464355, 53.79233162743704, 53.208227838788716, 53.02689375196184, 44.71665716171265, 37.28774397713797, 44.731675692967, 15.621445553643362, 0.5709056311420032, 0.24935377548847878, 0.27504685680781094, 0.1841597237757274, 1.166483338390078, 3.1096747475011006, 1.5441177146775382, 1.6417476130383355, 8.653725998742239, 93.335360118321, 87.11108044215611, 94.0311666216169, 84.46226733071464, 89.99785545894078, 85.26080989837646, 88.63202026912144, 84.67284638541085, 83.49545328957694, 77.1367746080671, 75.30586174556187, 73.97112669263566, 76.11732796260289, 70.0480625970023, 74.24204390389579, 73.08256326402936, 75.69639914376395, 73.81030368804932, 75.82085527692522, 73.86401326315743, 76.85204437800816, 75.6000554221017, 77.63053444453648, 76.65406935555595, 77.8922244480678, 76.10375813075474, 77.80323886871338, 76.53795106070382, 79.9094671521868, 79.39078412737165, 78.39458615439278, 76.47153323037284, 78.12881755828857, 76.0795783996582, 74.72028146471295, 72.9297376360212, 66.74579920087541, 64.40793187277657, 63.28702763148716, 64.27803530011857, 68.27656378064836, 69.75163854871477, 74.68255274636405, 69.8160205568586, 63.933161463056294, 67.83603409358433, 70.50314181191581, 71.43365846361432, 77.59193720136369, 69.221602167402, 72.57048797607422, 74.28923606872559, 74.40741797855922, 70.74810750143868, 65.2834952218192, 66.29859924316406, 70.47583539145333, 68.39724704197475, 63.87227439880371, 65.16131114959717, 63.31395190102713, 60.020568302699495, 58.40522330147879, 56.279362882886616, 54.997507095336914, 58.35638441358294, 58.512031010219026, 56.83951275689261, 62.03298200879778, 61.48777076176235, 62.82166508265904, 63.685902867998394, 67.04223714556012, 64.17501435961042, 64.54413046155656, 65.32029288155692, 64.47480133601597, 64.60461453029087, 64.2751795904977, 67.46799496241978, 66.76397568838937, 66.4800306047712, 67.5154789515904, 67.33574989863804, 66.56832136426652, 62.94470378330776, 64.58839048658098, 61.36362034933907, 61.250406401497976, 59.44645949772426, 62.83604090554373, 60.8956869670323, 67.12893676757812, 64.56610066550118, 70.20796843937465, 66.4429063796997, 68.74118287222726, 70.43841239384243, 70.52725900922502, 73.64615944453648, 62.215309688023154, 5.135199052946908, 1.4403158617871148, 2.2613611476761952, 0.33184637182525223, 0.3235318479793412, 0.23614554852247238, 1.1584036690848214, 0.499142193368503, 0.3032143653503486, 0.4817882531455585, 0.167686793420996, 7.1241061346871515, 39.071930204119, 51.15213080814907, 48.53142316000802, 40.22331271852766, 40.808924266270225, 46.22872413907732, 71.40802655901227, 75.07176998683384, 61.88181005205427, 67.93552534920829, 12.149708645684377, 0.6364953773362296, 0.3394205596830164, 0.19626808618860586, 0.2330576442182064, 0.19133460734571728, 0.13964325322636537, 0.13335028876151356, 0.16889416506247862, 0.16863596891718252, 0.19354099966585636, 0.13888630670096191, 0.09647375611322266, 0.23097277751990727, 0.20349546122763837, 0.15982063194470747], [0.06787949654140643, 0.03391369591866221, 0.07518249430826732, 0.04795517745826926, 0.04465506811227117, 0.029044715221971273, 0.07581434611763273, 0.14219275356403419, 0.017568939132615924, 0.042768079188785384, 0.02375509879285736, 0.06728845861341272, 0.06754844609115805, 0.017637043692437664, 0.025924661928521733, 0.06462211454553263, 0.09250335594905273, 7.525525280407496, 56.425070081438335, 42.33116340637207, 39.48782505307879, 32.61195026125227, 33.33872141156878, 42.626291615622385, 25.914020572389873, 27.95142694881984, 18.160074131829397, 0.18370822657431873, 0.3802330025604793, 0.05254822510427662, 0.1420603578111955, 0.030004384262221198, 0.44496092785681995, 1.3124846411602837, 0.6749020335929734, 0.7946456596255302, 26.614013365336827, 90.19915866851807, 76.15933677128383, 87.39594268798828, 75.19605241503034, 79.61252198900495, 74.28286457061768, 81.44411577497209, 71.52780655452183, 71.23086139133999, 67.52388627188546, 62.69414479391915, 66.75635351453508, 66.58453151157924, 67.26182106563023, 68.24162823813302, 69.93807261330741, 67.30144664219448, 66.03636033194405, 66.92366613660539, 66.34265082223075, 67.72962938036237, 67.36393179212297, 68.82920265197754, 66.24357645852226, 64.92915793827602, 63.50683389391218, 68.17097895486015, 67.08654580797467, 68.77113655635289, 69.71776608058384, 66.79881395612443, 64.10458047049386, 62.13948399680001, 60.943045888628276, 58.09829705102103, 56.52748652866909, 56.537387711661204, 54.11675691604614, 53.95051779065813, 53.25519418716431, 57.54565470559256, 56.317313943590435, 58.413769585745676, 57.53213003703526, 68.07464912959507, 66.87780802590507, 69.20025730133057, 67.61772169385637, 60.18644264766148, 60.886619567871094, 64.65377998352051, 65.71376241956438, 67.35262707301548, 68.23439516339982, 68.43631676265171, 63.18855081285749, 57.61656107221331, 61.24673080444336, 61.47670922960554, 57.23667526245117, 52.72608886446272, 49.80723401478359, 48.29908234732491, 47.32502480915615, 48.79146991457258, 48.13476092474801, 47.00584193638393, 48.294010162353516, 48.39756958825247, 49.365203516823904, 49.77565445218767, 49.0804454939706, 48.30011068071638, 53.391288552965435, 56.12568957465035, 55.80463416235787, 55.867563996996196, 55.96685722896031, 55.46779244286673, 56.70429386411394, 57.303940773010254, 56.6599817276001, 59.11623246329171, 55.84679930550711, 60.70566068376814, 57.431547914232524, 59.28724847521101, 58.819461005074636, 54.8692364011492, 53.54524326324463, 57.252499784742085, 55.1839793750218, 58.267836570739746, 59.80256857190813, 63.49012347630092, 62.78752858298165, 65.02504307883126, 60.793749945504324, 62.50423663003104, 65.1971082687378, 54.75618226187569, 10.950525999069214, 0.3093798602265971, 0.04753228390057172, 0.12668313937527792, 0.03613531456461974, 0.08789651707879134, 0.10907660092094115, 0.04815991522212114, 0.06745366153440305, 0.06606760448110954, 0.08681529866797583, 0.02942961760397468, 6.57629930121558, 30.685854026249476, 34.093000480106895, 24.974872520991735, 23.797698293413433, 42.738060338156565, 27.1045857157026, 54.02549580165318, 42.71594769614083, 48.40697397504534, 5.871510948453631, 0.34494079489793095, 0.11512593738734722, 0.057099868543446064, 0.02011770834880216, 0.07549405044742993, 0.02700969370614205, 0.08621005221669163, 0.01546142972074449, 0.03317080185349498, 0.015650115042392696, 0.012101915482032512, 0.043571328943861384, 0.022753080685756037, 0.027529644912907054, 0.03572135052776762, 0.06493272073566914, 0.06149799004197121, 0.019759681042549864, 0.03985835139506629, 0.04974085092544556, 0.03243118850514293, 0.03947389006082501, 0.08938030353082077, 0.060553754280720434, 0.027431678026914597, 0.04276579591844763, 0.0476980635763279, 0.033768323183591874, 0.08593192749789783, 0.013202585795495127, 0.10466691718569823, 0.21313573393438542, 12.098556876182556, 69.78628921508789, 49.94219235011509, 51.06572648457119, 41.391402176448274, 19.414746829441615, 37.417070797511506, 26.3837240082877, 24.385913678577968, 14.90984058380127, 0.12127229757606983, 0.5655406447393554, 0.15172253362834454, 0.23999053505914553, 0.05852496850171259, 0.41141651783670696, 0.37559822840350016, 0.7986259460449219, 0.8864737035972732, 37.22966398511614, 95.47575269426618, 82.02899428776333, 90.89212335859025, 79.75438335963658, 82.81204932076591, 80.04422051565987, 83.93176542009626, 75.98907116481236, 74.80568872179303, 69.21414675031389, 68.13115188053676, 71.01154845101493, 71.14050701686314, 71.46017973763603, 72.51892539433071, 72.70360156467983, 71.36125823429653, 69.58181762695312, 69.88992854527065, 69.2249789919172, 69.40412439618791, 71.1994902747018, 71.48456791469029, 70.57381193978446, 67.04758031027657, 67.53624016898019, 70.45499079568046, 70.8354046685355, 70.80907794407436, 69.85602133614677, 65.50805405208042, 65.13144084385463, 64.78541360582624, 61.500201089041575, 58.95125443594796, 58.57953970772879, 58.292669432503835, 56.977062770298545, 56.99453054155622, 58.0346029145377, 58.05601378849575, 56.88582944869995, 59.11017363412039, 62.85034029824393, 72.6020814350673, 71.04182870047433, 71.79140036446708, 69.79910169328961, 63.41381141117641, 64.8995864050729, 66.34916823250907, 70.34823172433036, 68.53109019143241, 70.23563616616386, 70.03154672895158, 69.76639652252197, 60.79218660082136, 62.314397948128835, 63.667802810668945, 60.063626289367676, 55.42125688280378, 51.24442720413208, 51.92640331813267, 51.62248911176409, 51.764979294368196, 50.10723638534546, 51.49786969593593, 50.722742557525635, 50.76340341567993, 51.35369110107422, 52.64707047598702, 51.98363215582711, 51.28747476850237, 54.98335361480713, 57.38988651548113, 59.27460970197405, 57.909351212637766, 59.916525976998464, 58.33344146183559, 59.47059753962925, 57.98466968536377, 60.89246995108468, 61.248106547764365, 59.38680921282087, 61.49652549198696, 61.73316723959786, 60.013821601867676, 60.79859283992222, 57.685014724731445, 56.9437426839556, 59.731877599443706, 57.907798290252686, 60.612429755074636, 61.355004583086284, 66.06406279972622, 67.95643942696708, 67.76496097019741, 62.913082531520296, 65.63191958836147, 69.39220823560441, 64.3193006515503, 18.28319099971226, 0.1961129866540432, 0.06417850192104067, 0.100119538339121, 0.21824903812791618, 0.19459054406200135, 0.3163123168051243, 0.03726875642314553, 0.017655891698918173, 0.12134593219629355, 0.04784928189058389, 0.027831526839041283, 4.715318977832794, 29.725279467446462, 32.17931720188686, 24.844432251793997, 27.62061105455671, 31.295808587755474, 33.33776603426252, 69.77798611777169, 53.28539800643921, 57.35626418249947, 10.913848195757184, 0.34565860352345873, 0.15534775624317781, 0.03519071239445891, 0.04784600456644382, 0.0504139542712697, 0.01053475828043052, 0.08569366671144962, 0.020176706968673637, 0.009754149542589272, 0.07234424339341265, 0.03282379565228309, 0.044512976094016006, 0.03364485016624842, 0.01813667277539415, 0.07008817552455834, 0.11657716094383172, 0.08157152576105935, 0.07805313848491226, 0.10430407736982618, 0.19764290670199053, 0.09918197936245374, 0.1754395988370691, 0.3213353758411748, 0.08489945504282202, 0.14460046722420625, 0.11136804760566779, 0.18205769014145645, 0.1395975471075092, 0.11342006642371416, 0.11409160574632031, 0.11800060527665274, 0.47392783207552774, 12.376166939735413, 81.09660162244523, 59.89431258610317, 58.54226262228829, 45.94028009687151, 45.76173223767962, 60.5529670715332, 41.508875370025635, 41.31949526923043, 31.33705656869071, 1.2841010327850069, 1.239805398242814, 0.2208825818129948, 0.5604847446084023, 0.08375572320073843, 2.051904444183622, 4.398820715291159, 2.487713698829923, 1.9389401972293854, 35.87191997255598, 104.07774761744908, 84.41399124690464, 96.155321257455, 82.8463247844151, 88.64568737574986, 82.70047514779228, 90.81873648507255, 78.33929239000592, 80.55986022949219, 76.04233605521065, 71.87929507664272, 74.23554733821324, 76.36894307817731, 76.76919405800956, 76.59572533198765, 77.7086877822876, 74.69340583256313, 72.89605276925224, 76.88043471745083, 74.65944303785051, 75.60037503923688, 76.6157500403268, 76.04693576267788, 73.29291997637067, 72.37761293138776, 69.51003578730992, 75.79610579354423, 74.8892547062465, 75.37329401288713, 75.15960911342076, 72.21994440896171, 69.7114223752703, 68.972731590271, 67.24074023110526, 64.01474721091134, 62.03437164851597, 63.03698280879429, 60.288963317871094, 60.85521371023995, 60.62379700796944, 63.758435113089426, 62.75453853607178, 64.32903507777623, 64.04927975790841, 74.04817526681083, 73.41516658238002, 74.37129429408482, 73.33180209568569, 68.4496989931379, 68.47349657331193, 70.29465416499546, 72.25703389304024, 72.22875472477504, 73.84013925279889, 74.55422646658761, 69.73575496673584, 63.871051515851704, 68.32285962785993, 68.88070269993374, 62.153338704790386, 57.604005677359446, 54.93743644441877, 54.10154036113194, 53.274322577885215, 54.95928158078875, 52.49620771408081, 55.01395000730242, 54.47706617627825, 54.25177778516497, 55.68533706665039, 55.27671698161534, 55.0570079939706, 53.49337843486241, 59.61089556557791, 60.8290467943464, 62.18852438245501, 61.21332386561802, 63.00190830230713, 62.612649372645784, 63.50442981719971, 62.67725372314453, 63.666628565107075, 65.63087735857282, 61.594064303806846, 66.7685545512608, 63.79225894383022, 64.13600717272077, 64.56269604819161, 60.09515721457345, 61.595968110220774, 61.504050391060964, 61.30315712520054, 62.815189361572266, 64.2336015701294, 70.19305760519845, 71.44996588570731, 72.33589594704765, 65.76228863852364, 70.59967313494, 73.29814502171108, 66.694014276777, 18.194610152925762, 0.47925281205347603, 0.7183344087430409, 0.8489281897033963, 0.48246966515268597, 0.4056725289140429, 0.610705781195845, 0.365188578409808, 0.09466235259813921, 0.25223051969494137, 0.3725379540451935, 0.18286967942757265, 13.041903376579285, 44.64238091877529, 50.08141687938145, 40.64176450456892, 38.63857453210013, 63.97624029432024, 40.25650773729597, 73.24444239480155, 55.147282464163645, 68.6682962690081, 11.251867634909493, 0.569086777312415, 0.2917567044496536, 0.17060164415410586, 0.1540525821702821, 0.14850068651139736, 0.04912349601675357, 0.23654192153896603, 0.09600415559751646, 0.2164426829133715, 0.1232723066849368, 0.14958373696676322, 0.12844112861369336, 0.21453563310205936, 0.11314261345458881, 0.19787873833307199], [0.027889368556705967, 0.06882709783634969, 0.04040672643376248, 0.030787193149860417, 0.025885227169575434, 0.10481495317071676, 0.04362828856600182, 0.08437904582491942, 0.024220010631584694, 0.008207113448796528, 0.020625966700858304, 0.10938321053981781, 0.0443121161577957, 0.030330952988671403, 0.03532020741009286, 0.04835078712286694, 0.06000562012195587, 29.56124292101179, 57.951137678963796, 43.31792572566441, 42.73587512969971, 31.991114820752824, 62.93832533700125, 30.426602840423584, 30.06324679510934, 30.064935207366943, 0.8748912736773491, 0.14949913722063812, 0.19560432966266358, 0.6450335734656879, 0.0595135125996811, 0.05779795894133193, 0.17932232549147947, 0.8471025505236217, 0.36998848084892544, 0.13595715244965895, 52.448584760938374, 85.56604426247733, 77.02714593069894, 79.40905788966587, 75.592745917184, 74.66551576341901, 76.57035051073346, 74.02205698830741, 72.70841666630336, 68.81019932883126, 61.83053929465157, 67.34110695975167, 64.87915870121547, 63.37935529436384, 66.09949166434151, 67.08560085296631, 67.57863112858364, 61.19183308737618, 62.93843650817871, 64.47612844194684, 63.37560326712472, 64.37130791800362, 63.05998829432896, 65.88762719290597, 65.96876825605119, 61.94180079868862, 64.4836186000279, 65.74189567565918, 63.50622245243618, 61.63320350646973, 59.066441672188894, 56.310650621141704, 56.68809413909912, 55.226078510284424, 53.98977163859776, 52.682985714503694, 53.625168391636436, 53.589367798396516, 54.1622120312282, 53.0961777142116, 54.08459023066929, 50.1387151990618, 49.469607148851665, 55.579703603472026, 65.07800224849156, 70.10478769029889, 69.01775591714042, 65.6212818963187, 57.16804790496826, 59.09904956817627, 60.43840517316546, 60.81362179347447, 68.81880814688546, 66.21852820260185, 64.79118061065674, 63.35431398664202, 67.42064298902238, 62.01327691759382, 60.67126015254429, 57.71884897777012, 56.361605235508506, 54.55751936776297, 51.09996025902884, 49.01232188088553, 48.5106897354126, 48.20603901999337, 46.906913484845845, 46.61786494936262, 46.13211291176932, 47.73724406106131, 48.44069010870797, 46.35143627439226, 46.58517367499215, 48.93060064315796, 48.76944759913853, 49.8571811403547, 53.5464175088065, 52.69142777579171, 54.012426240103586, 55.04955952508109, 55.149238382067, 56.15667854036604, 55.267847606113975, 55.54516063417707, 56.39386919566563, 57.87382159914289, 58.03509971073696, 56.37761388506208, 58.64904253823416, 55.08393226351057, 54.76423522404262, 59.04519408089774, 55.85272264480591, 56.379149436950684, 59.4737937109811, 62.88681834084647, 61.76203005654471, 63.02130767277309, 62.54442501068115, 61.22890172685896, 61.494343757629395, 65.59334318978446, 34.80870315006801, 0.4065278358757496, 0.10365063457616738, 0.011117428175306745, 0.14995131295706543, 0.1069610169423478, 0.043152557486402135, 0.0742404909272279, 0.10322543060673134, 0.11074302864394017, 0.03743111288973263, 0.0593799769080111, 0.1146188003144094, 8.761057427951268, 26.635438135692052, 26.608456543513707, 21.12734055519104, 26.83232923916408, 35.25302307946341, 46.94239098685128, 34.38399451119559, 52.50033146994454, 17.417137997491018, 0.3042323850095272, 0.13228140611733707, 0.1008834737752165, 0.07828221190720797, 0.046397257662777386, 0.03911632585472294, 0.02653616956169052, 0.008679883571208587, 0.020954470948449204, 0.012250017624215355, 0.03247950698382088, 0.07080438959279231, 0.07660384196788073, 0.027552969554173093, 0.0232988569353308, 0.08697167384837355, 0.04151991062930652, 0.048036493094904084, 0.07201099448970386, 0.04665758440803204, 0.033012143402759514, 0.049445345532149076, 0.11211085346128259, 0.020842631414000477, 0.029382004801716124, 0.04443109388064061, 0.07247020663427454, 0.05607734341174364, 0.04269438010773488, 0.043904547313494344, 0.025840934099895612, 0.04527443826996854, 37.9683895111084, 65.04456751687187, 65.03144931793213, 53.77693441935948, 18.95565676689148, 39.37650448935372, 28.2631995677948, 22.92753890582493, 23.341410091945104, 0.22566375668559754, 0.10392960746373449, 0.15459644155842917, 0.82710129235472, 0.07781180393482957, 0.08316108903714589, 0.10821846446820668, 0.6507813621844564, 0.964578892503466, 1.060213680778231, 62.86836392538888, 88.08011095864433, 85.61575167519706, 81.57292148045131, 82.24320030212402, 78.0377892085484, 78.69779859270368, 77.15026106153215, 77.19593157087053, 73.75724029541016, 66.41842092786516, 71.76121044158936, 69.73391369410923, 70.26713235037667, 71.2004838671003, 70.38037409101213, 70.31520693642753, 66.47968319484166, 66.17449746813092, 67.06426293509347, 66.40551812308175, 67.1545478275844, 65.4624947139195, 67.42244952065604, 66.59451607295445, 67.74596459524972, 64.08892617906842, 66.30378954751151, 66.01913574763707, 64.71641799381801, 60.21757057734898, 58.56517778124128, 59.45943178449358, 57.21093566077096, 56.74505199704851, 56.75598151343209, 56.53562634331839, 58.1604243687221, 57.13484246390206, 55.964609486716135, 55.090154375348774, 53.5305061340332, 53.65451410838536, 60.147171429225374, 67.61565113067627, 72.66795035770961, 70.75176920209611, 65.87418937683105, 60.19307122911726, 61.655333518981934, 65.97048446110317, 63.339021001543315, 70.3549575805664, 68.13469546181815, 64.8396998814174, 66.70595128195626, 67.22576686314174, 66.75552667890275, 64.07420294625419, 59.75819737570626, 57.52824599402291, 55.776323727199006, 54.437273842947825, 51.131307056971956, 50.39827905382429, 51.580028670174734, 50.82605184827532, 48.45626449584961, 48.187522070748464, 52.17756680079869, 51.180194582257954, 51.29424926212856, 50.705292156764436, 50.94390024457659, 51.45607280731201, 51.25507531847273, 54.21955898829869, 53.84718418121338, 54.448300634111675, 54.871949672698975, 56.91663776125227, 58.78741591317313, 58.36356885092599, 57.91090760912214, 57.918543679373606, 60.57067108154297, 60.629286084856304, 59.71586894989014, 61.321125166756765, 59.16148608071463, 57.368402685437886, 60.9923711504255, 58.842966760907856, 59.08337443215506, 62.64513914925711, 64.80017157963344, 64.07625961303711, 65.2707383292062, 63.51344163077218, 65.03606292179653, 64.72850091116769, 70.93374947139195, 45.33467510768345, 1.5209619743483407, 0.24180634905185017, 0.0706301892974547, 0.1414478849619627, 0.36270961857267786, 0.1514935823423522, 0.12089856048779828, 0.20199289971164294, 0.18019998339670046, 0.06085250646408115, 0.15499683150223323, 0.0791159685967224, 4.969029409544809, 25.45273314203535, 23.7749377318791, 22.935866321836198, 22.607694217136928, 22.17124833379473, 62.87673650469099, 50.37494700295584, 60.577688762119834, 23.582074846540177, 0.20102643514318125, 0.12175021693110466, 0.02081180047909064, 0.0645727307668754, 0.051553947385400534, 0.04340144073856728, 0.030127344985625575, 0.017176394749964987, 0.024182314618623683, 0.006404276438323515, 0.06658373892839466, 0.04934941425121256, 0.013256540355671729, 0.044671427591570785, 0.03772126464173198, 0.14866303279995918, 0.16807729032422813, 0.13850387079375132, 0.11785915786666529, 0.11443802501474108, 0.14773327697600636, 0.19116795914513723, 0.24137520790100098, 0.15759207867085934, 0.0940769397254501, 0.17412185668945312, 0.1097149055983339, 0.2712372626577105, 0.13145820743271283, 0.1123444934242538, 0.14759132745010511, 0.17506868445447513, 41.23440762928554, 78.0555488041469, 65.6162166595459, 64.19043241228376, 46.21606452124459, 89.31381920405796, 49.25070415224348, 43.14400884083339, 47.21986034938267, 1.8729635775089264, 0.21687775956732885, 0.6323939859867096, 1.986223122903279, 0.270159830472299, 0.2256804893591574, 0.5564014294317791, 2.639393959726606, 1.7363061904907227, 1.450107827782631, 63.88748400551932, 94.3346083504813, 89.8766371863229, 87.7962145124163, 86.03883443559918, 82.5385056904384, 83.62566947937012, 81.35066250392369, 83.27207565307617, 77.76477364131382, 69.93114525931222, 75.67577689034599, 73.69373376028878, 72.09595380510602, 74.04671614510673, 75.94863264901298, 76.07964093344552, 69.43758692060197, 67.74696513584682, 71.84843117850167, 71.33767604827881, 70.50785269056047, 69.66389669690813, 73.9322098323277, 73.0477944782802, 69.99054540906633, 68.4627685546875, 72.27514784676688, 69.85110201154436, 69.87683813912528, 64.45278249468122, 64.0977920804705, 63.48493317195347, 59.630003111703054, 61.23518289838518, 59.12739821842739, 58.91497094290597, 61.05827481406075, 61.863703046526226, 58.43810217721121, 59.51594843183245, 55.5373751776559, 54.232086590358186, 60.88060242789132, 71.17640835898263, 76.27651814052037, 73.5531369618007, 71.0888124193464, 62.44379425048828, 62.56991100311279, 67.62417657034737, 64.30734974997384, 72.04853234972272, 69.09029511043003, 65.77580288478306, 70.75857148851667, 72.77475111825126, 67.68197168622697, 66.04127965654645, 62.74046843392508, 61.227303641183035, 59.51371111188616, 57.946197509765625, 56.31213058744158, 53.71815960747855, 56.40137325014387, 52.81369522639683, 52.59248890195574, 51.0675608089992, 55.560484886169434, 55.079297815050396, 52.4667021887643, 54.57163463320051, 54.11619063786098, 56.50968524387905, 54.78141811915806, 58.59116404397147, 58.01833023343767, 59.131184986659456, 60.33956010001046, 62.33097634996687, 62.70512294769287, 62.60838317871094, 62.684097698756624, 61.006072998046875, 64.67663260868618, 62.59218692779541, 62.68337508610317, 65.53587463923863, 62.18759332384382, 59.790298053196494, 65.05920737130302, 61.70166410718645, 62.40640599387032, 65.56346593584333, 66.98693643297467, 66.3735842023577, 68.62476580483573, 66.72913047245571, 69.01766559055874, 68.61139747074672, 73.47487245287213, 44.14954171861921, 1.3801240516560418, 0.3666520427380289, 0.26233154482075144, 0.5827481299638748, 0.9186446773154395, 0.4388597852417401, 0.18917705597622053, 0.3796951685632978, 0.3105348896767412, 0.12495725841394492, 0.38050563793097225, 0.3533411941358021, 15.190287249428884, 38.30869838169643, 40.9904077393668, 34.32000160217285, 38.72202934537615, 53.32953296388899, 61.678220885140554, 45.72274589538574, 73.02207224709647, 27.36770531109401, 0.5163043524537767, 0.21391047164797783, 0.1590815580316952, 0.18324987616922173, 0.17394503046359333, 0.10588597998555217, 0.1654321165489299, 0.12519839618887219, 0.1585922935711486, 0.08350782721702542, 0.11499436944723129, 0.16285452486148902, 0.17948377611381666, 0.160743900973882, 0.07985353616199323], [0.05216320737132004, 0.037033494761479754, 0.0057429736646424446, 0.055856185100440464, 0.037962307421756644, 0.032391280468021116, 0.08019970437245709, 0.07235635524349553, 0.06391628884843417, 0.02138931181148759, 0.03849578183144331, 0.07766430399247579, 0.024442826264670918, 0.012001077544742396, 0.05197127017059496, 0.07330964944724526, 2.245212882757187, 47.26555517741612, 46.86776385988508, 25.063475949423655, 32.569726058415, 62.987129483904155, 27.556621619633265, 29.701881408691406, 45.07740068435669, 4.319879625524793, 0.06428750178643636, 0.21674250039671147, 0.15961537510156631, 0.2971419654786587, 0.08535098617098161, 0.022407789481803775, 0.0475017226833318, 0.23915061727166176, 0.7744933867028782, 5.304079796586718, 73.87524850027901, 75.12301989964077, 76.99619170597622, 72.9187455858503, 77.49691363743374, 71.93678447178432, 75.59116867610386, 71.75769465310233, 68.15680462973458, 66.29519462585449, 66.15129743303571, 65.03033065795898, 65.16771738869804, 67.21482345036098, 66.93203871590751, 63.956083570207866, 62.03216906956264, 62.55277674538748, 60.16215869358608, 60.4641968863351, 60.6276741027832, 61.457247325352256, 59.166996002197266, 60.589834213256836, 58.03662831442696, 61.09380790165493, 60.35205296107701, 61.50882380349295, 60.10739994049072, 57.91568449565342, 53.71829162325178, 54.511577878679546, 54.16168049403599, 52.16363566262381, 52.817273548671174, 53.42434113366263, 55.10415499550955, 54.71866198948452, 53.53630787985665, 52.66743564605713, 52.023441859654014, 51.37688071387154, 58.36445822034563, 63.103504862104145, 63.20918696267264, 65.77497604915074, 61.3516138621739, 58.114639214106965, 61.539458411080496, 66.9983662196568, 67.75579629625592, 64.88632229396275, 65.43041488102504, 66.05036790030343, 62.56995964050293, 60.07122067042759, 64.47257096426827, 64.19221115112305, 61.02168560028076, 60.351101057870046, 56.870567730494905, 50.72279119491577, 50.65173544202532, 46.8528391293117, 48.084046023232595, 48.38465288707188, 47.53400925227574, 47.81825310843331, 46.81307111467634, 47.350267614637104, 46.23909085137503, 46.68110745293753, 46.93083960669381, 49.4104779788426, 48.807412556239534, 46.698286873953684, 48.499180044446675, 50.402708530426025, 47.653622491019114, 49.92807708467756, 50.244744709559846, 50.26339020047869, 52.047169957842144, 52.60644088472639, 54.80973550251552, 55.5752671786717, 55.6577353477478, 58.351520674569265, 57.73648350579398, 54.95588738577706, 54.88033267429897, 57.30425691604614, 54.94157757077898, 54.039631911686485, 60.76178823198591, 62.98084831237793, 61.39815984453474, 62.225961276463096, 59.35422216142927, 59.11239010947091, 60.46168163844517, 62.10268633706229, 59.42002855028425, 6.371330048356738, 0.3456971714539187, 0.07826904832784619, 0.17368405232472078, 0.2273537702858448, 0.10514442263437168, 0.026895560723330294, 0.016217168453814726, 0.03832432960293122, 0.05176873764555369, 0.06180309331310647, 0.06302550129060235, 0.07374383722032819, 7.6612635510308404, 26.926183768681117, 24.077695063182286, 29.964415618351527, 45.456796646118164, 22.86563219342913, 16.318626063210623, 43.705968720572336, 22.16815291132246, 0.025578673529837812, 0.03804028466609972, 0.028817148147416965, 0.03813331520983151, 0.04063829347225172, 0.019300229714385102, 0.042183446631367714, 0.04849156956853611, 0.034448405262082815, 0.03790320362895727, 0.056311309071523805, 0.056553834450564215, 0.04148219765297004, 0.03599473907213126, 0.08994135021099023, 0.02022007553439055, 0.017321516427078416, 0.03837509420035141, 0.0314092672696071, 0.02591166628657707, 0.05163743094141994, 0.021561444271355867, 0.06046048964240721, 0.025430586654692888, 0.04414613292153392, 0.030978255040411438, 0.058132117081965716, 0.018869595768462335, 0.02560062922670373, 0.05833041894116572, 0.08650279257978712, 3.56138300044196, 60.237359046936035, 57.940538202013286, 44.93874938147408, 43.55776711872646, 44.589869907924104, 27.083148785999843, 30.053748607635498, 39.404404980795725, 2.644943181957517, 0.06406921707093716, 0.14403110849005835, 0.12578589894941875, 0.3677809350192547, 0.2764876037836075, 0.16440081117408617, 0.053345198410430124, 0.2512583690030234, 0.7941843100956508, 7.893623471260071, 81.11217948368618, 80.66335364750454, 82.00965745108468, 78.9365873336792, 82.55620275224958, 76.43315138135637, 78.7422045298985, 76.4848598752703, 70.42302908216203, 69.97152124132428, 70.65758637019566, 68.20296846117292, 69.0029354095459, 72.03066853114537, 70.24407127925328, 68.85207612173897, 65.7629348209926, 66.9383407320295, 65.04987594059536, 65.68124485015869, 63.537586620875764, 66.07677800314767, 63.20403139931815, 62.81805896759033, 62.53025763375418, 62.84303774152483, 61.87006759643555, 64.06951291220528, 62.67725372314453, 58.34110532488142, 59.60680307660784, 57.01390559332711, 57.74313988004412, 56.1849125453404, 56.37873254503523, 55.53132677078247, 56.14161484582083, 56.40295049122402, 56.323591641017366, 56.1972838129316, 54.69364152635847, 54.63784749167306, 62.43152373177664, 67.2407054901123, 68.5751348223005, 68.55921649932861, 62.97385842459542, 61.55655097961426, 65.86551802498954, 68.36122758047921, 70.17716707502092, 67.86036668504987, 68.28511701311383, 68.0375040599278, 66.52479784829276, 62.85554449898856, 66.43156691959926, 65.15014539446149, 64.26329817090715, 64.12725244249616, 62.26978356497628, 53.97865104675293, 52.903987067086355, 49.81934472492763, 50.07678590502058, 50.94986874716622, 50.60596765790667, 49.702844279153005, 49.42662559236799, 50.23013264792306, 49.33527762549264, 49.22854634693691, 49.843725953783306, 52.644082750592915, 53.45905780792236, 50.68766805103847, 50.82621513094221, 53.00766461236136, 49.915653705596924, 52.339362553187776, 52.86426421574184, 52.473306451525005, 54.199645451136995, 53.50582613263811, 56.00685453414917, 58.23045178822109, 56.29954045159476, 59.01052256992885, 59.69713660648891, 57.10606302533831, 57.028875487191335, 58.29608794621059, 58.761096136910574, 56.2007474899292, 64.24375983646938, 64.77246216365269, 62.543202127729145, 66.4688162122454, 60.89180987221854, 60.161700112479075, 62.23855141230992, 64.50315693446568, 64.60879734584263, 11.530024000576564, 0.4231826678982803, 0.26746382085340364, 0.2652826021824564, 0.5125090618218694, 0.07419579582554953, 0.030878513785345212, 0.04261218237557581, 0.06126838057701077, 0.08421663168285574, 0.07620833747621093, 0.06331533752381802, 0.052123896445014646, 4.174408665725163, 27.8684116091047, 25.198686156954082, 29.20708281653268, 31.444180420466832, 27.914783886500768, 26.400048800877162, 50.61537551879883, 30.3318988936288, 0.049516900442540646, 0.047612561378628016, 0.07488319929689169, 0.07071459905377456, 0.0748972992545792, 0.013709079108334013, 0.05494385066309145, 0.0756736450961658, 0.053340407953198464, 0.032766795318041525, 0.01852960222666817, 0.05032487280134644, 0.034016877346272976, 0.05064601664032255, 0.06940376439264842, 0.117099632908191, 0.09258408804557153, 0.08095142617821693, 0.14087853979851517, 0.10422185249626637, 0.09234505372920207, 0.1673368186290775, 0.17047333318207944, 0.10954874594296728, 0.12944108567067555, 0.11460430680641107, 0.107219762701009, 0.10703003073909453, 0.12650496965008123, 0.123983981353896, 0.30167582790766445, 3.5524031051567624, 67.52840260096959, 64.09699303763253, 38.43268551145281, 50.34501763752529, 86.7931934084211, 48.31462894167219, 46.863188471112935, 66.0000559943063, 7.415874889918736, 0.14417364155607565, 0.4205512005303587, 0.36291822737881113, 1.1102156319788523, 0.9291034532444817, 0.33017641572015627, 0.15054782666265965, 0.8191865342003959, 1.481789550610951, 7.1809176462037225, 88.40198625837053, 87.32163865225655, 86.97438158307756, 84.28510911124093, 87.38012858799526, 80.18271895817348, 83.68502099173409, 81.75515883309501, 78.38219056810651, 74.26667526790074, 74.66930253165108, 74.44382653917584, 72.64655685424805, 75.6334137235369, 75.90791620526994, 73.71665586744035, 71.79686859675816, 71.0951144354684, 69.65990843091691, 70.51778166634696, 67.81677368709019, 70.21497222355434, 67.45112473624093, 67.81396661485944, 66.86518314906529, 67.41372258322579, 65.86446189880371, 67.00949723379952, 69.42678247179303, 62.61939607347761, 61.81718485695975, 61.09929697854178, 59.6938362121582, 58.60041904449463, 59.6677804674421, 59.3961614881243, 60.88545227050781, 60.63701248168945, 60.075570242745535, 59.26894692012242, 58.04877723966326, 57.932408809661865, 65.56305599212646, 70.8514689036778, 71.31839479718889, 72.34280245644706, 66.24823869977678, 63.50144904000418, 67.98400293077741, 71.71171147482735, 72.63851084027971, 70.49075317382812, 71.7563258579799, 71.18668474469865, 66.7643300465175, 65.90307303837368, 67.11237226213727, 70.44889027731759, 66.6039308820452, 66.27760178702218, 62.96770232064383, 57.30489615031651, 57.81611680984497, 53.18084846224104, 52.83110393796648, 54.39551864351545, 52.43521295275007, 53.786099093300955, 51.9923278263637, 53.426335266658235, 52.36848592758179, 52.35831723894392, 51.87474346160889, 57.95519195284162, 55.16434029170445, 52.48958955492292, 55.80687495640346, 56.565128394535606, 53.12830965859549, 55.70422921861921, 56.78634514127459, 55.751275471278596, 58.12041664123535, 58.185212067195344, 62.1291937146868, 63.594283921378, 59.75373663221087, 63.73410946982247, 63.029902594430105, 60.96532876150948, 60.43103313446045, 60.79689053126744, 61.339287757873535, 60.13906288146973, 64.57955932617188, 67.7831027167184, 65.62134443010602, 69.43539128984723, 63.81533391135079, 64.16060379573277, 65.80677100590297, 69.9337021963937, 67.32495934622628, 10.760363357407705, 0.6639981386916978, 0.7094155816095216, 0.5066860371402332, 1.2728461452892847, 0.5686699939625603, 0.21371229871043138, 0.1324700524232217, 0.14652059919067792, 0.17361128622932093, 0.25065325147339274, 0.13969460475657666, 0.2717463810529028, 11.613407594817025, 43.311053957257954, 40.789236545562744, 44.07256957462856, 67.6018728528704, 33.14658635003226, 24.798362221036637, 61.71014090946743, 34.728441034044536, 0.24031628615089826, 0.21747890088175023, 0.1806653905659914, 0.09875543189368077, 0.17844659462571144, 0.11416009707110268, 0.1111130134335586, 0.1086955831519195, 0.17468272016516753, 0.11204489985746996, 0.14777008071541786, 0.11264419555664062, 0.11408450827002525, 0.10108111745544843, 0.19663958411131585], [0.027210667296977978, 0.021653316216543317, 0.02179895866928356, 0.08785711455025844, 0.03927173412271908, 0.021771800305162157, 0.06138415900724275, 0.04876151115500501, 0.03205723089299031, 0.03043541345479233, 0.04108347351263676, 0.03514372045174241, 0.06058667679982526, 0.04764870015372123, 0.0662598063104919, 0.06830947061202355, 17.880101680755615, 57.712439264569966, 32.58853830610003, 36.41639471054077, 22.68686546598162, 23.907924515860422, 21.071358919143677, 41.32730851854597, 12.219937562942505, 0.17136129124888352, 0.00999642301550401, 0.07632166639502559, 0.09281391464173794, 0.058693028055131435, 0.06662384034799677, 0.22546737508050033, 0.07804521319589444, 0.14322545672101633, 0.18230034783482552, 14.446551203727722, 77.74540901184082, 72.26903343200684, 74.58116463252476, 70.00995867592948, 74.04974555969238, 73.56733213152204, 74.03850337437221, 69.8223295211792, 65.80151121956962, 65.44857052394322, 65.9098892211914, 64.45259489331926, 65.3917064666748, 62.81085368565151, 65.44814668382917, 62.54172910962786, 59.279640197753906, 60.82276562282017, 60.24550928388323, 59.82432338169643, 58.971473693847656, 58.88776874542236, 60.4697276524135, 58.419557435171946, 58.65189824785505, 57.25934723445347, 58.187939235142295, 57.59774187632969, 56.46987901415144, 54.559093134743826, 57.60818154471261, 53.17179495947701, 53.1346811567034, 51.722925322396414, 52.91805369513375, 51.421199798583984, 53.37413345064436, 51.772980145045686, 52.429529326302664, 50.37181336539132, 50.98210491452898, 54.87842886788504, 60.3745025907244, 63.28997366768973, 68.68037918635777, 58.897433689662385, 58.850220680236816, 60.398091724940706, 62.62577451978411, 66.93417876107353, 67.41220092773438, 62.67436327253069, 66.1772906439645, 62.217894417899, 63.49976757594517, 60.21707725524902, 60.82742786407471, 62.71215452466692, 64.05818040030343, 63.368029730660574, 64.6761531829834, 56.90351261411394, 45.636206081935335, 47.555385385240825, 47.23197453362601, 47.15178884778704, 46.761133330208914, 46.70616265705654, 46.913705348968506, 46.37484475544521, 47.66816854476929, 45.471526827131, 45.34736251831055, 47.51793459483555, 46.10901362555367, 48.04525423049927, 47.7800623348781, 48.79146991457258, 49.577373708997456, 48.49755416597639, 48.91916043417794, 49.72196224757603, 50.15303543635777, 49.55843639373779, 49.819191864558626, 49.677497250693186, 52.848547390529085, 51.71970483234951, 55.54979508263724, 54.87857478005545, 56.197037151881624, 55.75795269012451, 58.2584182875497, 52.41498327255249, 61.737363951546804, 60.751192229134695, 59.654835973467144, 58.858106885637554, 58.71502958025251, 55.13426154000418, 59.80515330178397, 57.17622593470982, 65.175429889134, 32.97879082815987, 0.4439216021980558, 0.0724013556859323, 0.03883553110063076, 0.06911859648036105, 0.08577919605055026, 0.061729472263583114, 0.1997583889003311, 0.13098985542144093, 0.023690330928989818, 0.10777236840554646, 0.03322570212185383, 0.04508117114060691, 0.3351433463394642, 8.3921662739345, 27.156862224851334, 30.78224985940116, 23.573664052145823, 32.12335293633597, 35.20846080780029, 37.12984963825771, 34.43000895636422, 0.10291962165917669, 0.06361152484480824, 0.03740227175876498, 0.024215859693608115, 0.09176892321556807, 0.03224347857758403, 0.04363862943968602, 0.05545355599107487, 0.058947804383933544, 0.06406431126275233, 0.04539257800206542, 0.04212099426825132, 0.027919227490201592, 0.06696711121393101, 0.019482265392850553, 0.011928408988751471, 0.02141744048068566, 0.03280848450958729, 0.07217255367764405, 0.009763424268125423, 0.02655672069106783, 0.06579393773738827, 0.023374593317774788, 0.019753748950149332, 0.07174286459173475, 0.023373288834201436, 0.07684202133012669, 0.01837888263565089, 0.02402935246936977, 0.0456901393564684, 0.076204191627247, 24.387499604906353, 69.27265753064836, 46.17977408000401, 50.8145421573094, 21.67131675992693, 24.736446823392594, 28.559211935315812, 39.041896615709575, 9.950284174510411, 0.048168607255710025, 0.01265297836757132, 0.0461106444709003, 0.1328454315662384, 0.15211240627935954, 0.2299414857157639, 0.3607615445341383, 0.2704685367643833, 0.09318265771227223, 0.39741530056510654, 19.677296672548565, 86.58841609954834, 77.47277559552873, 81.66702093396867, 76.1243109021868, 79.35552201952252, 79.34922000340053, 76.71467849186489, 73.34735911233085, 73.3773683820452, 70.18802016122001, 70.74983065468925, 68.61548301151821, 68.90748800550188, 68.2850683757237, 69.05967439923967, 66.17232268197196, 62.8247709274292, 64.53107479640416, 62.11940370287214, 61.108948026384624, 64.05173942020961, 61.815364428928916, 63.01792390005929, 60.866004262651714, 61.249155725751606, 60.271898542131694, 61.81398173740932, 59.85391575949532, 57.82133143288748, 56.57398039954049, 60.54541437966483, 55.27396896907261, 58.26151023592268, 56.451157093048096, 55.04748201370239, 54.964371136256624, 56.17375373840332, 55.44643020629883, 55.07831464494978, 53.151982171194895, 53.2740272794451, 57.83815649577549, 65.2897972379412, 67.89048712594169, 71.92301314217704, 64.36439446040562, 64.08062308175224, 62.47054481506348, 65.96935190473283, 68.55949442727226, 68.00682776314872, 65.73952633993966, 69.45552022116524, 66.35200309753418, 68.48465538024902, 62.1580148424421, 62.15835530417306, 66.93892438071114, 66.36803953988212, 65.77055699484688, 67.7758001599993, 60.30781378064837, 50.2886712210519, 49.72584629058838, 49.836617946624756, 49.111705439431326, 49.17127582005092, 49.40628126689366, 49.77676963806152, 50.39956099646432, 50.19343226296561, 49.15907825742449, 49.26294687816075, 49.63851090839931, 48.94079712459019, 50.46318565096174, 49.48440681185041, 50.58816637311663, 52.41043567657471, 51.36685446330479, 52.841164929526194, 53.21304988861084, 53.44879184450422, 51.89798171179635, 52.26438454219273, 52.23476437159947, 55.28987339564732, 53.99787323815482, 57.3717725617545, 57.3132826260158, 59.415178707667756, 58.144645009722026, 60.50369739532471, 55.5158566066197, 61.553208896092, 63.2901473726545, 62.40004144396101, 61.19086728777204, 62.34463650839669, 58.333392824445454, 62.83850751604353, 62.44503102983747, 68.05174786703927, 44.66268702915737, 2.0735691445214406, 0.17816414763884886, 0.19318897569818155, 0.2970051456774984, 0.18890458345413208, 0.07557759846427611, 0.11491677218249866, 0.12989103581224168, 0.11245275368647915, 0.019719756042052592, 0.10084137067730937, 0.08476144780537911, 0.38830618507095743, 5.772476536887033, 28.31595376559666, 31.440539564405167, 26.96288936478751, 19.76234609740121, 38.92396831512451, 45.72935710634504, 46.46362883704049, 0.2367145408477102, 0.028998150756316524, 0.05769917102796691, 0.05926069723708289, 0.04952466627582908, 0.02992810674809984, 0.025236354309267232, 0.06215036753565073, 0.05194944848439523, 0.028545293092195476, 0.054159521857010465, 0.05711160719926868, 0.03189295077962535, 0.020731461932882667, 0.022481301965724145, 0.09981349868966, 0.16535727413637297, 0.08863331111414091, 0.19546433431761606, 0.14952768997422286, 0.10381224126155887, 0.21107692298080238, 0.078978307412139, 0.12005812701370035, 0.23783387935587338, 0.11252695827611855, 0.16883547178336553, 0.19380058002259049, 0.16373016073235444, 0.30882373292531284, 0.18091737133051666, 27.354449885232107, 78.1331045968192, 46.033236571720664, 52.185171604156494, 35.24863876615252, 40.22652973447527, 38.35536248343331, 61.235217639378135, 19.37341720717294, 0.38703493614281925, 0.16060138147856506, 0.14724002272955009, 0.3836740707712514, 0.4569653794169426, 0.563566053552287, 0.719433146928038, 0.4526918844452926, 0.5392585407410349, 0.485662253839629, 21.430075304848806, 93.73630591801235, 83.31015178135463, 87.10697405678886, 81.44319166455949, 84.46654047284807, 82.48552567618233, 81.53970909118652, 80.05662305014474, 76.49096039363316, 75.02424430847168, 74.01310770852226, 72.58944266183036, 72.81342479160854, 71.37850366319928, 73.11225986480713, 70.43501472473145, 67.64380523136684, 71.23858778817313, 66.89436558314732, 65.71772984095982, 69.47589233943394, 65.29730824061802, 67.73343699319022, 65.04116984776088, 67.41772474561418, 64.44532012939453, 65.73671231951032, 62.84271117619106, 62.66011946541922, 61.68644755227225, 65.94674941471645, 58.619436264038086, 61.147691181727815, 59.27970967973982, 58.825172424316406, 57.76109402520316, 59.56098665509905, 58.65521253858294, 58.752633231026785, 56.28187813077654, 57.84402772358486, 60.7108370917184, 67.04466206686837, 67.35198783874512, 74.46552576337541, 64.88031210218156, 62.65603392464774, 63.10572133745466, 66.86605167388916, 72.09293133871896, 71.98369870867047, 68.04469544546944, 73.32130336761475, 68.84907449994768, 70.51166030338833, 64.54725020272392, 66.81895678383964, 70.51387677873883, 70.5058377129691, 69.02549621037075, 70.69783033643449, 63.85913535526821, 51.98903438023159, 52.97999341147286, 51.82244437081473, 51.72564901624407, 53.6892203603472, 53.31762375150408, 53.194404397692, 53.23308154514858, 52.76734379359654, 52.18274668284825, 53.012118407658164, 53.0489855493818, 52.475647994450156, 54.109152112688335, 52.31254250662667, 54.51318291255406, 56.2145813533238, 54.250617436000276, 54.87314476285662, 56.82169757570539, 56.34905331475394, 55.95863403592791, 54.686262539454866, 55.71680893216814, 59.55094650813511, 56.80390323911394, 62.23393086024693, 62.70355960300991, 61.891641753060476, 63.12645476205008, 63.91244193485805, 58.83351721082415, 67.64538942064557, 65.74026979718889, 64.12821129390171, 64.10847840990338, 63.773853165762766, 58.888901301792686, 66.34554822104317, 64.61286899021694, 72.83787550245012, 41.58561822346279, 1.6641423084906168, 0.3988756164908409, 0.2938437153186117, 0.5496771473969732, 0.5544103362730571, 0.14131448497729643, 0.6006878901805196, 0.23656906293971197, 0.19151540978678636, 0.3265842784728323, 0.2550576494208404, 0.34485008833663805, 0.8929916567036084, 15.311048677989415, 40.712285246167866, 46.282381602696006, 34.787010874067036, 51.34902885981968, 52.42916801997593, 51.06051186152867, 54.17832142966134, 0.3365273135049002, 0.09995352117610828, 0.11790979014975683, 0.20047379551189287, 0.1638103500008583, 0.07946170254477433, 0.1146700025669166, 0.17309299404067652, 0.23077258254800523, 0.1695593193705593, 0.1028371321569596, 0.0884052012115717, 0.1761303474860532, 0.16750767374677317, 0.05369228603584426], [0.026986557358343686, 0.052069101349583695, 0.008154718670994043, 0.04244317626580596, 0.04715453327766486, 0.04646412728886519, 0.04111926962754556, 0.059515283576079776, 0.04767555656975933, 0.09437719825655222, 0.04516120434605649, 0.09873748464243752, 0.10699157137423754, 0.013087640266998537, 0.049503560444074016, 0.30621403296078953, 34.59298937661307, 44.995846203395296, 40.25299889700753, 44.34776340212141, 27.380776609693253, 31.59736040660313, 29.227930886404856, 19.850023678370885, 1.1666530264275414, 0.05882911503847156, 0.06407550030520984, 0.08279793030981507, 0.0295896059833467, 0.03291223251393863, 0.07573191768356732, 0.21108198485204152, 0.12373106421104499, 0.19801648094185761, 0.30992789939045906, 24.371275561196462, 80.44174780164445, 69.43690599714006, 72.63592611040387, 69.54231016976493, 73.7378339767456, 72.33472170148576, 69.85827950068882, 65.93575736454555, 67.303968838283, 64.17024789537702, 65.70780086517334, 61.575457027980256, 67.42138644627163, 65.51335552760533, 64.97684342520577, 59.86919484819685, 56.17972224099295, 55.624217237745015, 54.98797069277082, 55.06957728522164, 56.92702531814575, 56.17401429585048, 57.76302909851074, 56.49447216306414, 55.51187181472778, 55.52506644385201, 55.68833521434239, 57.59263147626604, 55.18593529292515, 56.317786421094624, 56.11855377469744, 52.58410242625645, 54.31444011415754, 52.89467648097447, 51.57827077593122, 52.4925286429269, 52.36218043736049, 53.01796531677246, 51.35741880961827, 51.52398450034005, 49.26169620241438, 55.15513392857143, 59.63294914790562, 67.10593823024205, 69.4744679587228, 65.6246726172311, 66.25604847499302, 61.175449235098704, 64.20664950779506, 64.68483843122209, 66.82565484728131, 64.32155186789376, 63.949461936950684, 62.35371085575649, 63.17222949436733, 62.50502872467041, 61.8839362008231, 58.95429079873221, 60.18391350337437, 63.05929347446987, 64.78885991232735, 60.09778363364083, 51.17198528562273, 48.52283866064889, 48.242138385772705, 46.59971278054373, 47.770786489759175, 46.92780671800886, 47.612537792750764, 47.82025766372681, 45.7052503313337, 46.729612827301025, 46.683136326926096, 45.456042766571045, 46.24471889223371, 47.363507407052175, 49.27416474478585, 45.62483882904053, 47.554364000047954, 49.59450796672276, 49.231492383139475, 48.91907010759626, 49.24763304846627, 49.41392775944301, 50.10260888508388, 50.57730286461966, 48.13604981558663, 49.716702461242676, 51.21939631870815, 53.04112366267613, 53.365958895002095, 53.46447740282331, 55.24944182804653, 52.95084571838379, 56.83397504261562, 60.61512565612793, 61.60019261496407, 59.33309268951416, 58.054023129599436, 60.452655928475515, 57.58877522604806, 57.458791800907676, 59.211019788469585, 63.28462355477469, 14.500405822481428, 0.13364722925637448, 0.09966091652001653, 0.1623141531433378, 0.1674795959677015, 0.06721429473587445, 0.020593027218378017, 0.042217163036444356, 0.13993062637746334, 0.06601828855595418, 0.07354368974587747, 0.03604836369465504, 0.2532472365668842, 0.5070592314004898, 17.337195498602732, 31.854527132851736, 28.49159206662859, 43.151759556361604, 35.14933163779122, 31.08799144199916, 35.78566156114851, 0.49405068371977123, 0.041709388140589, 0.03805737357054438, 0.05554847964750869, 0.05511629694540586, 0.09044727270624467, 0.042641915780092986, 0.04098498754735504, 0.03749404022736209, 0.09450961436544146, 0.09032925511045115, 0.04786646578993116, 0.03110656261976276, 0.03218747568981988, 0.014210525816971702, 0.03874799329787493, 0.0296211341129882, 0.022336704456912618, 0.023189360043033957, 0.024210395790370445, 0.036234960824783356, 0.02331914852506348, 0.02271216841680663, 0.04283417189227683, 0.06538038421422243, 0.035379178888563595, 0.08238004094788007, 0.06266449351928063, 0.03658220112057669, 0.0157791605285768, 0.5175272896885872, 44.52184009552002, 55.64808777400425, 58.48363372257778, 42.89972407477242, 20.347587653568812, 41.46362175260271, 34.080636160714285, 20.967483350208827, 1.0621083676815033, 0.09097564792526619, 0.05031860653044922, 0.045194062404334545, 0.2174413236124175, 0.06784136287335839, 0.15885281030620846, 0.197175368932741, 0.20183638882424149, 0.3123010891888823, 0.3208925096052033, 26.20769487108503, 81.62114892687116, 76.38865511757987, 76.54760210854667, 76.59181349618095, 79.68048926762172, 76.62904889242989, 74.77130208696637, 69.20750427246094, 71.24228422982353, 69.7570720400129, 69.77541528429303, 65.54149573189872, 70.80183097294399, 69.35869012560163, 69.05318478175572, 62.37261690412249, 60.158844402858186, 58.98351492200579, 60.14552470615932, 59.06641387939453, 60.81056458609444, 59.17502811976841, 62.095481055123464, 60.3658937726702, 60.344069480895996, 60.357813017708914, 58.5088973726545, 61.8078464780535, 59.1601311819894, 59.59291362762451, 58.968298367091585, 55.58662053516933, 56.28483806337629, 55.875950472695486, 54.24186965397426, 55.31353201184954, 55.27822126661028, 53.77685104097639, 54.47555841718401, 54.80383995601109, 52.59370136260986, 58.902700424194336, 61.441023281642366, 69.05037076132638, 71.1235603604998, 68.94215951647077, 67.9846282686506, 62.7463744027274, 67.57238469805036, 67.59661306653703, 69.00722244807652, 65.48580592019218, 65.75789042881557, 65.11211790357316, 63.8085663659232, 64.88975470406669, 64.47673293522426, 62.6794285093035, 62.42908491407122, 64.47282804761613, 66.22923537663051, 62.39847115107945, 55.28753185272217, 52.32432317733765, 50.985238552093506, 49.103318963732036, 51.40918288912092, 50.05658401761736, 50.868081501552034, 49.54006535666329, 48.14733716419765, 49.103336334228516, 48.262229101998464, 49.551064355032786, 49.35379804883684, 50.13250003542219, 52.60667364937918, 47.87986625943865, 50.84046936035156, 52.41982616697039, 51.94109180995396, 50.01401587894985, 51.639317648751394, 53.192354679107666, 52.09225334439959, 53.51581416811262, 52.57409702028547, 53.365288393838064, 53.830637046269004, 55.80144146510533, 57.316537857055664, 55.86066790989467, 58.60269110543387, 56.41822957992554, 60.17357458387102, 63.39443288530622, 63.3557105745588, 62.635237966264995, 60.798460824149, 63.49972588675362, 61.01502227783203, 62.45842020852225, 61.411917277744834, 66.27931104387555, 25.542710576738628, 0.02101314556784928, 0.17920132912695408, 0.23093942073839052, 0.23831078090838023, 0.07178061149482216, 0.013673259244699563, 0.1499287448823452, 0.16264552250504494, 0.07231924616332565, 0.06822432125253336, 0.14764212258160114, 1.0659673320395606, 0.6656492043818746, 15.707980155944824, 27.62685922213963, 34.1344256401062, 39.45229891368321, 38.29029607772827, 40.13178062438965, 45.998405252184185, 2.0648947528430392, 0.04494952856163893, 0.04822295791070376, 0.09966282320341893, 0.034588397214455266, 0.045106527994253805, 0.034850128527198515, 0.06913622482014553, 0.026343501239482845, 0.013073065334797969, 0.12720683270267077, 0.06428854673036508, 0.004879259654054684, 0.08727940305003098, 0.05883115742887769, 0.1801744026264974, 0.10071447105812174, 0.13030557999653475, 0.11491571366786957, 0.11203605854617697, 0.15450638639075415, 0.1469332706183195, 0.1452860590070486, 0.14487124340874807, 0.20799854530819825, 0.15478457217769964, 0.1952862460166216, 0.21986420931560652, 0.15808335159506115, 0.09571161879492657, 0.6302265280059406, 51.14384160723005, 64.42393357413155, 58.645082065037315, 62.5684449332101, 45.20069646835327, 51.38073001589094, 48.190033844539094, 32.25800207683018, 2.559658169746399, 0.11768177524209023, 0.21660893756364072, 0.2990263115082468, 0.26748887236629215, 0.16803671393011296, 0.3242876817073141, 0.9316595218011311, 0.5325285590120724, 0.7326253333262035, 0.4149276651442051, 30.274788175310405, 92.37834998539516, 81.3717850276402, 83.95461804526192, 81.5637012209211, 84.69246809823173, 82.47859832218715, 79.50755555289132, 73.92362880706787, 74.18206010546002, 73.97122396741594, 73.97948537554059, 70.16836370740617, 75.19151524135044, 74.44110284532819, 73.92563683646065, 67.27316052573067, 63.963886397225515, 64.65141759599958, 63.52685860225132, 63.00717503683907, 65.4196104322161, 63.07863031114851, 64.69156428745815, 64.30370889391217, 64.97632925851005, 62.196952547345845, 61.93938977377755, 66.14980357033866, 62.29009314945766, 61.912639209202354, 62.205929619925364, 58.63766138894217, 59.61273683820452, 59.53630665370396, 56.80467101505825, 57.98345027651106, 59.24995749337332, 57.77924619402204, 57.120553493499756, 56.98081479753767, 53.776093687329976, 62.44873441968645, 65.2529856818063, 72.99063859667096, 75.53891822269985, 72.3267104285104, 70.31144796098981, 66.05203546796525, 69.11294623783657, 71.55192375183105, 72.99612767355782, 69.59451198577881, 71.5385971069336, 68.39294610704694, 68.05974524361747, 66.22024440765381, 65.50008446829659, 63.95499965122768, 66.2325496673584, 67.93842274802071, 70.31381729670933, 65.86409364427838, 57.08328683035714, 55.9787768636431, 54.297712326049805, 52.53881059374128, 55.39135878426688, 53.32499926430838, 55.330172947474885, 54.373232296534944, 51.23125341960362, 53.467840330941335, 50.98169844491141, 50.269313539777485, 51.6081862449646, 53.45229721069336, 55.60267434801374, 50.92499419621059, 53.987075737544465, 55.33289316722325, 56.55622427804129, 54.259132453373496, 53.812648160117014, 55.163565567561555, 56.09978321620396, 57.10659803662981, 54.66858284814017, 56.223485469818115, 56.7044050352914, 59.189820834568565, 61.25829955509731, 58.896926471165244, 61.42883614131382, 57.730000836508616, 61.7875577381679, 66.551207951137, 67.38217776162284, 65.88733536856515, 61.93132986341204, 66.42464651380266, 63.02346856253487, 66.04458005087716, 67.45477948869977, 74.86165646144322, 26.722587653568812, 0.17507731541991234, 0.2954609085406576, 0.4531244369489806, 0.4069333555442946, 0.3840349428355694, 0.1257652307727507, 0.26684640826923506, 0.46549755015543526, 0.24172934889793396, 0.25076295701520784, 0.19548018489565167, 0.8421129296932901, 3.156410502535956, 27.526254517691477, 49.24825838633946, 44.35871376310076, 66.17201001303536, 54.50133275985718, 44.09219823564802, 58.66839327130999, 2.1076053295816695, 0.17626866006425448, 0.16033106669783592, 0.221529307109969, 0.0753618311136961, 0.15446753347558634, 0.1815237645059824, 0.14383370908243315, 0.14512880173112663, 0.224653743739639, 0.3066161056714398, 0.1409385630062648, 0.13449649725641522, 0.15321575850248337, 0.10810940353465931], [0.042487576204751215, 0.054195630098027844, 0.020220616666067923, 0.015182714676484466, 0.04845940700865217, 0.022941604855337312, 0.08113142794796399, 0.026903596274288635, 0.02023128662923617, 0.006855738864812467, 0.04464423190802336, 0.03740350329982383, 0.09318905629749809, 0.31405143812298775, 0.5270902908274105, 8.305377193859645, 59.06826210021973, 38.45199802943638, 33.004544326237266, 35.878989764622276, 28.638921669551305, 25.755843094417028, 25.25592715399606, 9.811224664960589, 0.08191549551806279, 0.09644738824239799, 0.06788845998900277, 0.016785098871748363, 0.04742267335365925, 0.10075233331216232, 0.06029603989528758, 0.08252620417624712, 0.2450702381985528, 0.10893508565745183, 0.5890902610761779, 28.993324960981095, 69.32531792776925, 67.09002685546875, 66.49515683310372, 71.17095402308873, 68.41415895734514, 71.92462512425014, 67.98801898956299, 64.84429264068604, 68.05094882420131, 64.55401774815151, 62.87090696607317, 65.47004740578788, 64.3293685913086, 64.6282661982945, 62.465820040021626, 56.70576688221523, 54.92224768229893, 55.06348024095808, 57.71546173095703, 56.48324040004185, 56.55516815185547, 56.01611648287092, 57.568778310503276, 56.027087688446045, 56.311473982674734, 59.46942329406738, 59.546284266880576, 56.86514466149466, 56.79128531047276, 56.979310512542725, 54.77465404782976, 53.35619667598179, 51.163268770490376, 52.419489179338726, 50.91833087376186, 51.924770491463796, 53.52507611683437, 52.061156681605745, 49.9033762386867, 50.59675782067435, 51.75816658564976, 55.38538680757795, 54.22103200639997, 63.34665012359619, 66.64297975812639, 65.36874267033168, 62.907662936619346, 64.34282030378068, 64.26772417340959, 60.80719470977783, 60.881929533822195, 60.054593631199424, 60.09862436567034, 61.253164836338584, 59.77640860421317, 61.166110856192454, 64.78485080174038, 63.25093868800572, 60.302442823137554, 62.056327956063406, 63.4915200642177, 57.75726556777954, 52.61730439322335, 52.581079959869385, 49.19294030325753, 45.06177765982491, 48.60999686377389, 46.201330866132466, 45.17673213141305, 46.88974448612758, 46.51340225764683, 46.29314088821411, 45.822435174669536, 45.37001711981637, 45.95394025530134, 46.52002041680472, 47.19235243116106, 46.40177597318377, 45.804442814418245, 48.1175537109375, 48.424170766557964, 48.311741965157644, 48.366142886025564, 47.24350159508841, 48.28149993079049, 48.291856220790315, 50.21608339037214, 49.616054330553325, 49.08332552228655, 51.83595861707415, 52.974990708487375, 53.33930560520717, 57.44132055555071, 55.074520928519114, 57.742914063589915, 61.18919277191162, 57.09765917914254, 59.49126843043736, 62.2022887638637, 58.13274621963501, 60.350440979003906, 58.39243861607143, 58.99547971997942, 54.43278183255877, 38.73053741455078, 1.3919049394982201, 0.11166253858911139, 0.06692171722118344, 0.08541499237929072, 0.046636003601763926, 0.13967422156461648, 0.16924065218440124, 0.30977362766861916, 0.011733073175751736, 0.8952713715178626, 0.38651183992624283, 3.3445523040635243, 0.790499104985169, 2.647532037326268, 14.468774148396083, 24.502495765686035, 34.31753151757376, 36.02805641719273, 24.541916370391846, 44.56839650017874, 3.504336770091738, 0.26531975876007763, 0.07431447838566133, 0.09985911659896374, 0.04811406321823597, 0.03316834555672748, 0.03615610487759113, 0.016569838726094792, 0.056043728786919794, 0.04287375083991459, 0.04826060303353837, 0.03190820424684456, 0.009049294998736253, 0.033780764123158794, 0.017564947650368725, 0.06471017482025282, 0.0353184330410191, 0.036105764364557605, 0.012824712188116141, 0.055648536421358585, 0.03293646639212966, 0.018073246714525988, 0.07415785214730672, 0.010704826297504562, 0.06944098882377148, 0.08024720182376248, 0.0451057273229318, 0.08913903004888978, 0.1960744322942836, 0.4834614119359425, 11.641633783067975, 72.52421297345842, 44.42684432438442, 43.83165468488421, 27.412510769707815, 26.989575658525737, 32.41365909576416, 26.901305743626185, 7.973067436899457, 0.11739103655729975, 0.10127538881663765, 0.0707713585080845, 0.018664321961945722, 0.19337625136332853, 0.27332041944776264, 0.3216998034289905, 0.11146665231457778, 0.44971013015934397, 0.3036849158150809, 0.6696224883198738, 38.74646963391985, 81.9801276070731, 72.5266170501709, 72.87219265529087, 75.78096566881452, 73.80030523027692, 75.97377123151506, 74.04677173069545, 70.34556361607143, 72.26463522229875, 69.46687357766288, 69.03869778769356, 68.71813569750104, 69.92452362605503, 67.55679294041225, 66.58613654545375, 60.411814417157856, 59.690834590366904, 59.54151085444859, 61.35763100215367, 60.029760769435335, 58.703120367867605, 61.99578135354178, 60.800920486450195, 59.133936473301475, 59.704272406441824, 61.81839384351458, 62.41359043121338, 60.47875336238316, 59.73069640568325, 59.419979912894114, 56.65145976202828, 56.80075570515224, 54.767803124019075, 56.494590282440186, 53.93141024453299, 55.041353702545166, 55.00229787826538, 56.26478556224278, 53.335122789655415, 51.68608944756644, 54.81262942722866, 59.19215542929513, 57.27787460599627, 65.13143389565604, 70.77473299843925, 68.01400525229317, 65.85663822719029, 67.68492467062813, 66.5675779070173, 63.36049093518938, 62.30100876944405, 61.376210485185894, 64.44506304604667, 63.906424794878276, 62.244672775268555, 64.07179886954171, 65.77792208535331, 65.11324351174491, 64.09268515450614, 64.73645659855434, 65.70308998652867, 58.46800722394671, 55.61267280578613, 54.00775705065046, 49.8673220361982, 46.85380840301514, 50.849310943058555, 49.24955769947597, 49.267807143075125, 50.713935715811594, 49.47455774034773, 49.66344799314226, 48.81305449349539, 48.297883783067974, 48.79519067491804, 49.92069114957537, 49.370442458561485, 49.02025324957711, 49.41028690338135, 51.28776659284319, 52.37480878829956, 52.7399331501552, 50.92945146560669, 50.880817549569265, 51.551680019923616, 51.56796312332153, 53.60026952198574, 53.132447310856406, 51.28822864804949, 53.72454500198364, 55.29609203338623, 57.437679699489046, 59.93690504346575, 57.1544954436166, 61.194007873535156, 62.08414854322161, 61.52622209276472, 61.561178479875835, 67.12427452632359, 60.200081961495535, 65.06105559212821, 62.95154081072126, 64.2060102735247, 58.3541818346296, 50.806169578007285, 2.9394938221999576, 0.15360966165150913, 0.8355814058865819, 0.460803390613624, 0.07626787892409734, 0.31047591141292025, 0.22586201104734624, 0.04079205968550273, 0.12707385340971605, 2.892532684973308, 2.055276926074709, 2.650537350348064, 1.1870243847370148, 1.42117064339774, 11.41311274256025, 26.004623344966344, 30.46687807355608, 37.686393397195, 35.383909770420615, 55.10008682523455, 8.82950586932046, 0.3260303224836077, 0.15198173400546822, 0.032253629461463006, 0.08695939236453601, 0.021115868984322463, 0.10734518989920616, 0.02331183391756245, 0.04439087032473513, 0.007917855666684253, 0.035979522924338064, 0.05070926628208586, 0.06438530582402434, 0.09355276463819401, 0.03514856858445065, 0.16723738610744476, 0.15926519674914225, 0.09381707438400813, 0.11887364914374692, 0.16928297919886454, 0.12960831741137163, 0.13482646883598395, 0.17731031988348278, 0.11607653780707292, 0.19051801759217465, 0.12671596689948014, 0.13006592142794812, 0.2858286696885313, 0.4114587227148669, 0.7983500808477402, 12.403825981276375, 79.70370319911412, 54.34374066761562, 48.99032735824585, 52.69986983707973, 49.194646086011616, 41.77535963058472, 40.47882924761091, 13.572148203849792, 0.3063120134174824, 0.14197425171732903, 0.21842872777155467, 0.26164649586592403, 0.1994910461029836, 0.26691920150603565, 0.5036879437310355, 0.28022619602935656, 0.6532125802976745, 1.0025764192853654, 1.059832506946155, 47.34866605486189, 95.67936965397426, 75.93409701756069, 82.24151188986642, 79.07661437988281, 80.79655756269182, 79.98431314740861, 80.70457730974469, 73.43719932011196, 79.21990707942417, 72.61503287724086, 75.25122806004116, 70.60821941920689, 73.70137677873883, 71.4824070249285, 71.86723300388881, 64.5013017654419, 63.33800656454903, 62.82274900163923, 65.31629071916852, 63.69399751935686, 62.964130946568076, 64.82939570290702, 65.49510260990688, 62.37492370605469, 65.02900355202812, 66.01821858542306, 69.39532797677177, 63.56987489972796, 63.35153470720564, 64.20737212044853, 61.20501382010323, 58.75796944754464, 57.6733660697937, 59.930373736790244, 56.815815925598145, 57.822071416037424, 59.30589049203055, 58.85456330435616, 55.4974091393607, 55.812680176326204, 57.950279576437815, 61.51674474988665, 59.185457365853445, 69.41776371002197, 73.86482620239258, 70.71789673396519, 68.4827515738351, 69.55666514805385, 71.46770463671002, 66.91123580932617, 66.81704602922711, 64.19221809932164, 65.73610782623291, 67.81663472311837, 66.83379813602993, 67.29315744127545, 72.57792254856655, 67.68932288033622, 67.25141961233956, 66.91131918770927, 69.51943670000348, 63.6203396660941, 59.52494634900774, 58.01350818361555, 54.341513769967214, 49.3773524420602, 54.68135016305106, 51.939149788447786, 52.11782271521432, 53.07252604620797, 52.192856311798096, 51.6712064061846, 51.26284340449742, 50.873838084084646, 52.64174468176705, 53.479777336120605, 54.15279722213745, 52.48840141296387, 51.77795852933611, 53.436858313424246, 55.491301672799246, 55.944397177015034, 54.24866846629551, 54.14290298734392, 55.31288235528128, 53.64744431631905, 57.330576692308696, 56.54757377079555, 54.49347087315151, 57.3125113759722, 58.315667969839915, 61.233154024396626, 64.1379804611206, 60.13601262228829, 64.05459512983049, 64.58449254717145, 63.787186758858816, 63.79670579092843, 70.7274921962193, 62.03733158111572, 68.56940255846295, 64.32308047158378, 69.90174048287528, 60.71610382625035, 57.53951249803816, 3.3363662404673438, 0.22434627238128865, 0.368136215955019, 0.38105435562985285, 0.12233641690441541, 0.5075636814747537, 1.3435091078281403, 0.2753881056393896, 0.10090366697737149, 1.7974562006337302, 3.033161618879863, 6.717233955860138, 1.1602698032345091, 2.9596292674541473, 23.80382660457066, 38.70155995232718, 49.360523905072895, 52.547638280051096, 36.10073457445417, 67.94817801884243, 9.561184184891836, 0.5249042681285313, 0.2860293803470475, 0.1524066190634455, 0.1519673354923725, 0.1919340387518917, 0.21826152317225933, 0.11747615199003901, 0.17786419444850513, 0.14165204257837363, 0.16234178308929714, 0.1868588546557086, 0.11212153360247612, 0.1852511473532234, 0.19147752039134502], [0.10133191756904125, 0.08320518702800785, 0.060707978505109034, 0.07523701459701572, 0.0009663474151498771, 0.0403187102638185, 0.04301242304167577, 0.044332747015037706, 0.04895496488149677, 0.029837980334247862, 0.050513960154993195, 0.07383897461529289, 0.05400004577157753, 0.07720311731100082, 0.045865343883633614, 29.38828488758632, 55.9937676021031, 51.47979048320225, 46.370081765311106, 39.81397002083914, 23.066042559487478, 27.601244688034058, 11.51977801322937, 0.32620068905608995, 0.20466018015784876, 0.06028803318206753, 0.07333269249647856, 0.04276153471853052, 0.11105899526072399, 0.03738371721868004, 0.05422503441306097, 0.11834703811577388, 0.18451495042869023, 0.11842549033463001, 1.505140709025519, 47.52710969107491, 62.716462407793315, 66.34589563097272, 66.46084662846157, 72.71536486489433, 67.79579707554409, 69.35234642028809, 67.2829019001552, 65.33972004481724, 64.38686493464878, 65.52385425567627, 63.16355814252581, 66.11644526890346, 62.079847608293804, 63.03364072527204, 61.37841306413923, 55.94324377604893, 58.15100261143276, 57.8014943259103, 57.00335127966744, 57.04517943518502, 59.85215091705322, 57.16212109157017, 55.95306852885655, 53.25383928843907, 56.428644929613384, 56.57511990410941, 56.32522794178554, 56.80412210736956, 56.81351259776524, 54.29374143055507, 54.87990536008562, 53.981065545763286, 52.3429582459586, 50.55703149523054, 52.307873317173545, 53.096816948481965, 52.665038517543245, 53.153594153267996, 53.5426515851702, 50.67435877663748, 53.18655988148281, 55.26456110818045, 56.841763973236084, 65.3126220703125, 65.13880593436105, 66.4574281147548, 68.04469544546944, 67.47673579624721, 63.751632826668875, 59.76424925667899, 58.11779717036656, 63.84187602996826, 61.482920919145855, 59.94738292694092, 56.95146560668945, 57.2529479435512, 61.28500148228237, 65.28678171975272, 62.252802167619976, 60.94963278089251, 61.00199440547398, 54.14364297049386, 51.98227378300258, 51.616409437997, 46.19386502674648, 47.6641629082816, 47.498531750270296, 46.79130588259016, 47.51755244391305, 48.39581169400896, 44.537758418491904, 47.70870433534895, 46.98224237986973, 47.23533746174404, 45.10086475099836, 45.777313573019846, 46.963739327022004, 48.11323887961251, 46.33314166750227, 46.42815480913435, 47.51617670059204, 48.87896163122994, 47.53942884717669, 49.53417328425816, 49.699345861162456, 48.58469499860491, 46.94315528869629, 48.52799769810268, 47.401461941855295, 49.34327500207083, 51.084719385419575, 52.296339307512554, 55.69158697128296, 52.471155984061106, 56.642527852739605, 61.57067666734968, 61.32464790344238, 58.02109214237758, 60.91167477199009, 59.29919242858887, 60.48851558140346, 60.380102838788716, 58.17253507886614, 54.775446142469136, 52.99686711175101, 10.533351813043867, 0.4120583033987454, 0.35759419734988895, 0.05886460920529706, 0.17658472167594091, 0.051190459568585665, 0.08594676705875567, 1.3284193575382233, 3.733052577291216, 4.145039064543588, 0.365210372954607, 1.6992651266711098, 1.541894182562828, 0.06334218036915575, 4.152152282851083, 20.32518492426191, 14.351536325045995, 29.297850608825684, 20.15724001611982, 44.59639426640102, 11.276496393339974, 0.3426318216536726, 0.06350075400301389, 0.1016879313226257, 0.03695383135761533, 0.03997975827327796, 0.031743791819150956, 0.023912451063681926, 0.06225444802216121, 0.014850994172905172, 0.02551500658903803, 0.036003339503492625, 0.04804990094687257, 0.041836253833025694, 0.08370875500674758, 0.03106973852430071, 0.06648261685456548, 0.010260761599056423, 0.041119381585823636, 0.01341949647758156, 0.032733387646398375, 0.06601446161844901, 0.06421831835593496, 0.05015023145824671, 0.043307887722871134, 0.015994130600509898, 0.005588994985113719, 0.047728153211729865, 0.05889960125620876, 0.02790133112908474, 37.41340562275478, 61.73464025769915, 66.81299522944859, 47.25354174205235, 28.156252895082744, 28.783668279647827, 31.863660539899552, 8.864461387906756, 0.23481347571526254, 0.1934365459850856, 0.04125264586348619, 0.20526619335370405, 0.050433964268969636, 0.7416312843561172, 0.2963194181876523, 0.24480373678462847, 0.1043541193274515, 0.2582863633121763, 0.26294331199356485, 3.241231939622334, 59.15673351287842, 74.57320199693952, 71.08967399597168, 71.28826740809849, 77.93925680433, 72.31699684688023, 71.62177399226597, 73.36643191746303, 69.63438769749233, 69.2501870564052, 69.72137914385114, 66.19791984558105, 71.81403064727783, 66.60288170405796, 68.84362016405377, 62.676906313214985, 59.92627429962158, 60.83414677211216, 61.87074851989746, 62.26009777614048, 60.43772424970354, 63.28259468078613, 62.5727458681379, 57.82477079119001, 58.66264016287667, 60.977800777980256, 60.69796207972935, 58.45060198647635, 60.605036871773855, 59.00349794115339, 56.902209826878135, 58.65369783129011, 55.42419944490705, 55.58770445414952, 53.66071884972708, 54.5302164213998, 55.274142674037385, 55.1433219909668, 56.18840054103306, 55.75230033057076, 54.52589464187622, 53.25106348310198, 59.58322089059012, 59.817125047956196, 68.84330749511719, 68.7130148751395, 68.95007351466587, 69.98364584786552, 69.74956103733608, 65.23419080461774, 61.68016638074602, 62.24039963313511, 67.23437568119594, 64.38422461918422, 62.18363285064697, 58.88195310320173, 61.159920011247905, 63.42228126525879, 65.6086848122733, 63.40769699641636, 61.96205479758126, 63.397497040884836, 57.97494568143572, 52.53508983339582, 54.78921052387783, 48.695841857365195, 50.45633820125035, 49.85296705790928, 49.77584205354963, 51.958118370601106, 51.340552057538716, 46.942175592694966, 49.54508890424456, 49.54822949000767, 50.085624013628276, 47.84217575618199, 49.01769978659493, 50.37086493628365, 50.27240548815046, 49.036063875470845, 49.16478967666626, 50.220707416534424, 51.93987240110125, 49.86279875891549, 51.38964455468314, 53.528313977377756, 51.38923461096627, 50.46745531899588, 53.09722689219883, 51.63002790723528, 51.338457175663535, 53.043086528778076, 52.14132847104754, 56.43073286328997, 56.738107272556846, 59.493999072483604, 63.876075063432964, 64.06137657165527, 61.615228516714915, 62.79315662384033, 62.77792617252895, 64.37349660055978, 63.570465496608186, 64.98485469818115, 58.82406071254185, 63.428409576416016, 16.00648692675999, 0.2955591875527586, 0.8969096807496888, 0.14341364162308828, 0.08083977324089833, 0.024164927158770815, 0.6191533793296132, 3.023510136774608, 3.1819581602300917, 1.1720382060323442, 0.32971332914062906, 2.168381222656795, 1.901275098323822, 0.15576785084392342, 2.8843466213771274, 22.72594734600612, 16.49734936441694, 25.432951620646886, 28.800055606024607, 55.670804909297395, 17.918566908155167, 0.3160609874342169, 0.1640118613306965, 0.06120273909930672, 0.09862352468605552, 0.026413736399263144, 0.07550739044589655, 0.05656517277072583, 0.0557313617984099, 0.03733151751969542, 0.04263568004327161, 0.0454888790845871, 0.0077912317023479515, 0.022214881976002028, 0.052008691376873424, 0.15828958552862915, 0.11993250304034778, 0.12005964693214212, 0.12865775770374707, 0.09800702133881194, 0.1231221468853099, 0.22809329203196935, 0.12256923584001404, 0.24109182453581265, 0.24719388995851788, 0.08682737659130778, 0.20547162661595003, 0.15821800008416176, 0.1302406984780516, 0.19328228783394608, 42.655421938214985, 72.75458744594029, 72.14983013698033, 68.42799282073975, 59.317806652614046, 42.26330035073416, 43.19586672101702, 18.939411878585815, 0.530534643147673, 0.3697782707001482, 0.10695919168314763, 0.3132636046835354, 0.17782694287598133, 0.2871715990560395, 0.1727892817663295, 0.18333972777639115, 0.49429235075201305, 0.45160601128424915, 0.43900056768740925, 3.0389446914196014, 63.30815710340227, 84.09930733272007, 79.34919221060616, 80.1249863760812, 86.07791805267334, 78.09533418927873, 77.58531556810651, 79.75689165932792, 75.49572127205985, 72.07928507668632, 74.07842077527727, 71.50373104640416, 75.59799180712018, 71.49265561785016, 71.37525885445731, 68.66377299172538, 62.754441261291504, 64.26714747292655, 65.44540214538574, 65.3349118913923, 63.97810935974121, 67.32368087768555, 64.06587900434221, 62.12936741965157, 59.763596126011436, 64.8802912575858, 63.23100430624825, 62.410825048174175, 63.73627035958426, 62.869135175432476, 59.31044156210763, 62.85657978057861, 59.210575103759766, 58.655546052115305, 55.867015089307515, 57.48921448843819, 59.56186212812151, 57.94241074153355, 58.45649405888149, 58.75651032584054, 56.095398902893066, 59.2668833051409, 62.88292040143694, 62.205227851867676, 70.75041430337089, 71.93943173544747, 70.35033702850342, 73.42349052429199, 72.53944342476981, 69.44427803584507, 66.91171523502895, 62.99759347098214, 69.75125639779228, 69.2258197239467, 63.72964177812849, 62.72988632747105, 64.64943735940116, 65.93527099064418, 70.52670315333775, 66.72112614767892, 66.27777549198696, 67.14067922319684, 59.55721378326416, 57.15029525756836, 57.569712843213765, 53.86264739717756, 53.65444115230015, 54.90264681407383, 52.78336981364659, 54.7730837549482, 54.668058259146555, 50.542791162218364, 52.90052686418806, 53.20271444320679, 52.488759245191304, 49.529872349330354, 52.02270187650408, 54.78718512398856, 54.05262156895229, 51.68645075389317, 51.91697113854544, 54.49287680217198, 54.741778646196636, 52.339438983372276, 55.66318620954241, 57.76113224029541, 54.61511298588344, 53.84050696236746, 55.4479900768825, 55.40642942701067, 54.53030327388218, 57.178237438201904, 55.95778635569981, 61.06776605333601, 57.60214008603777, 63.4334192276001, 66.78491061074394, 68.18513938358852, 64.39376449584961, 66.66932037898472, 64.6732279913766, 68.52060535975865, 66.31480939047677, 67.64385386875698, 63.96702003479004, 70.1912510735648, 17.261428867067607, 0.6875517719558307, 0.7989523485302925, 0.14423925589237893, 0.4789971943412508, 0.34732790823493687, 0.4604479468294552, 1.4718477640833174, 4.616544689450945, 7.0813838328633985, 1.6207877205950874, 2.6524237862655093, 2.9014520006520406, 0.2666241744799273, 7.081848927906581, 35.62401172092983, 25.207428727831157, 47.130819184439524, 33.28128412791661, 60.94867392948696, 21.101442881992885, 0.686234111232417, 0.2727009712585381, 0.23927191219159535, 0.2715464032122067, 0.13122329860925674, 0.16642306266086443, 0.12597624159285, 0.24029590295893805, 0.23067946040204593, 0.09071120925779853, 0.08379568891333682, 0.11644308242414679, 0.15892206159021172, 0.22791019614253724], [0.11161590966262988, 0.04238942950697882, 0.1189810883785997, 0.03407923810716186, 0.019374242617881725, 0.013372694524670286, 0.0606486541884286, 0.02014320939114051, 0.06885949788349015, 0.023257712268137505, 0.04118385598329561, 0.024468322217996632, 0.09841066146535532, 0.029841529072395394, 1.0131728563989912, 41.60955476760864, 45.507914543151855, 23.164639234542847, 33.67509412765503, 18.970088175364904, 21.449905463627406, 21.165397575923375, 0.40494389086961746, 0.05848764907568693, 0.05272499365465982, 0.07500716085944857, 0.05481541416208659, 0.07850184690739427, 0.6974302647369248, 1.9944078837122237, 0.2944266311824322, 0.048824173863977194, 0.11030787735113076, 0.021465604592646872, 16.085910047803605, 70.4028445652553, 60.33584976196289, 62.44584396907261, 64.09087167467389, 67.7316860471453, 66.39090606144497, 66.76463576725551, 64.47215407235282, 66.18874822344098, 66.23382118770054, 64.36650671277727, 63.49441051483154, 65.36721406664167, 63.49447304861886, 61.027869497026714, 58.29394095284598, 54.86333738054548, 57.021423544202534, 56.16076408113752, 58.96325397491455, 56.44748497009277, 62.5071131842477, 58.83990955352783, 56.333333015441895, 55.75284229006086, 59.46437890189034, 54.84989261627197, 59.02427305494036, 57.61535208565848, 55.42635338647025, 54.24465240750994, 51.602471351623535, 52.58689212799072, 52.58428307941982, 51.71781144823347, 50.77137994766235, 50.745793206351145, 51.54898064477103, 53.57604810169765, 56.40666430337088, 55.444078241075786, 51.56535060065133, 53.4102223941258, 57.425106934138704, 65.12088653019497, 70.02480697631836, 65.82544776371547, 64.06460053580147, 64.65027809143066, 58.19498470851353, 56.569168772016255, 59.93561267852783, 61.69580677577427, 63.03876849583217, 59.9500093460083, 59.16544655391148, 55.519393239702495, 58.84833771841866, 61.02525002615792, 58.19023561477661, 58.6214234488351, 63.407363482883994, 54.84998294285366, 50.85165248598371, 49.66312837600708, 45.08683286394392, 46.10130112511771, 44.07357358932495, 47.91317939758301, 46.661371094839915, 49.0385548046657, 46.48596034731184, 44.751950536455425, 46.71640082768032, 46.208824498312815, 47.08131674357823, 45.78888232367379, 44.92602375575474, 47.46960987363543, 46.87967307226998, 46.369498116629465, 46.06248501368931, 49.60118865966797, 45.982834339141846, 46.055234568459646, 46.57927465438843, 47.53478397641863, 46.552663053785054, 46.348504134586875, 47.428198610033306, 48.220063958849224, 50.37674311229161, 48.65098776136126, 53.24058212552752, 51.149650301252095, 55.39292560304914, 60.68240506308419, 59.51794951302664, 58.4614828654698, 59.67249829428536, 58.814117840358186, 59.73423998696463, 61.710363251822336, 61.66341427394322, 52.83219133104597, 56.65133816855294, 26.231092929840088, 0.06451081444642373, 2.5528302618435452, 1.4305540770292282, 0.13265834589089665, 1.9279846251010895, 5.446870923042297, 3.751777538231441, 0.5841957979968616, 0.05639195635116526, 0.06361012706266982, 2.0242560420717512, 1.2256495292697633, 0.15439548662730626, 0.5147113693611962, 12.944719791412354, 25.116869381495885, 21.998444897787913, 21.960005726133073, 41.544839245932444, 22.11195935521807, 0.352427071758679, 0.24512734370572226, 0.04835797620138951, 0.10348948929458857, 0.03509068954735994, 0.08601646617587123, 0.02172139872397695, 0.02232167320991201, 0.03905839253483074, 0.07995051917220865, 0.01877762713203473, 0.04168271492900593, 0.02486858663282224, 0.045593783991145234, 0.03294222376176289, 0.01883948577700981, 0.04683493649853127, 0.08655786248190062, 0.024511132688660706, 0.08902226774288075, 0.17751184478402138, 0.001934174248682601, 0.05159970439438309, 0.060043733433953354, 0.037738977798393795, 0.04210776962073786, 0.04279363960293787, 0.11032595352402755, 1.585226840206555, 52.68888473510742, 54.368490150996614, 40.44310508455549, 29.190320287431987, 17.38368763242449, 29.628018583570206, 18.99587641443525, 0.1443820468017033, 0.06572624029857771, 0.036416736963604174, 0.05990661507738488, 0.05647220329514571, 0.32604416459798813, 1.8476584553718567, 2.751779769148145, 1.0812237305300576, 0.24130735439913614, 0.591126517525741, 0.027230563640062298, 22.285938773836406, 77.07405321938651, 67.67990112304688, 71.3727297101702, 70.16306223188127, 76.12033653259277, 71.96943405696324, 72.47698606763566, 67.97736740112305, 70.48106738499233, 71.22962461199079, 69.88585690089634, 69.2487348828997, 69.9762043271746, 65.73952633993966, 67.1473217010498, 61.709710121154785, 57.59471940994263, 61.37549482073103, 60.00400379725865, 59.428838866097585, 60.86952699933733, 65.50360025678361, 60.820118359157014, 59.90549223763602, 59.60822050912039, 62.81580775124686, 59.82074505942208, 61.07286603110177, 58.66381440843855, 58.96512304033552, 58.22051239013672, 52.91628885269165, 56.169821058000835, 54.46443435123989, 56.364676339285715, 53.01659999574934, 54.5910096849714, 53.17207983561924, 54.5230632509504, 57.50340618406023, 58.62996973310198, 53.824265548161094, 56.208967208862305, 61.314600808279856, 65.53620120457241, 71.36089692796979, 68.04466765267509, 67.92574923379081, 68.52583735329765, 60.52420152936663, 59.91699845450265, 63.21796253749302, 61.813384192330496, 63.90242958068848, 61.685405322483604, 62.159196036202566, 58.77458953857422, 60.74348667689732, 63.853479521615164, 61.34549249921526, 60.467010906764436, 64.20359924861363, 59.13967568533761, 53.07975217274257, 53.03810119628906, 47.53340475899832, 50.53912946156093, 49.47132682800293, 50.81710951668875, 49.04188993998936, 51.0941550391061, 47.75745289666312, 48.990032059805735, 48.97104958125523, 48.587665353502544, 48.22521604810442, 49.23434114456177, 46.72595460074288, 50.44890710285732, 51.03538717542376, 48.47981888907296, 49.316326413835796, 52.511028221675325, 49.33216483252389, 49.627244404384065, 50.508105754852295, 51.52160474232265, 50.77262714930943, 49.653126444135395, 50.27515697479248, 52.8568365914481, 54.26965202604021, 50.06077030726841, 55.295032433101106, 54.40728541782924, 57.361968653542654, 61.28698866707938, 62.34737409864153, 60.35184451511928, 62.80137634277344, 63.826548303876606, 64.32135037013462, 64.7719202041626, 63.79758126395089, 58.7803704398019, 63.83532387869698, 34.26445770263672, 0.3975862371070044, 4.238015515463693, 3.789844112736838, 0.1339300697935479, 6.023008167743683, 6.627632592405591, 3.674183964729309, 0.587429587330137, 0.07461534081293003, 0.08151466452649661, 2.9578583453382765, 1.5276028237172534, 0.11203549536211149, 0.4922483318618366, 11.2909060886928, 31.48800618307931, 22.51519111224583, 25.55830407142639, 50.78921944754464, 31.43336554936, 0.1800298203847238, 0.11260390414723329, 0.039615479963166375, 0.040454532618501356, 0.12460313098771231, 0.05129490985668131, 0.018327812697472315, 0.017805425549990365, 0.03476335746901376, 0.03456472312765462, 0.019900258231375898, 0.023854677199519107, 0.07083726461444582, 0.04884093028626271, 0.20484961356435502, 0.1183589260493006, 0.2468030537877764, 0.1571401743484395, 0.09623800590634346, 0.1682859534131629, 0.24906607664057187, 0.10493202081748418, 0.19948481715151242, 0.11673249118030071, 0.11720612219401769, 0.11656739003956318, 0.22556615620851517, 0.22969463467597961, 1.9199824716363634, 60.38724558694022, 64.90093435559953, 35.23444707053048, 50.70565693719046, 34.76773657117571, 38.65786967958723, 33.374195439474924, 0.5028288641146251, 0.10951222040291343, 0.1102637793602688, 0.27730160153337885, 0.1255184340157679, 0.16587978681283339, 1.890260900769915, 3.864992788859776, 0.3318810042526041, 0.14584495473120893, 0.6353686292256627, 0.4240483428750719, 23.139445066452026, 85.0949980872018, 74.62463256290981, 78.4171677998134, 77.00572463444301, 82.55767577035087, 78.24517209189278, 79.35010242462158, 72.98865141187395, 76.69903114863804, 75.39155387878418, 75.53458949497768, 72.21574769701276, 74.56627464294434, 70.58340740203857, 71.06438255310059, 65.63666520799909, 62.20322677067348, 65.20716231209892, 63.26012420654297, 64.27925123487199, 65.04494271959577, 69.80686977931431, 65.63872882298061, 62.457655906677246, 62.47361591884068, 66.95155620574951, 63.746067319597515, 65.92790590013776, 61.968989099775044, 62.020329339163645, 60.41023717607771, 56.38306474685669, 59.36478342328753, 57.44736548832485, 59.58324868338448, 55.15057243619646, 56.15896102360317, 56.902126448495046, 60.13778441292899, 63.576468740190776, 63.959675788879395, 56.81707007544381, 60.22379616328648, 63.31761360168457, 71.23978287833077, 75.57925946371896, 72.21423993791852, 70.4585691179548, 71.79624325888497, 63.69985485076904, 64.04422841753278, 65.7387342453003, 66.91896220615932, 66.88350554874965, 66.67669936588833, 65.69310542515346, 62.886707169669016, 66.11313792637416, 68.17541190556118, 63.02594212123326, 64.1030935559954, 67.87076119014195, 62.293421336582725, 57.380468232291086, 56.22219657897949, 50.508199555533274, 53.935033730098176, 51.99729926245553, 56.77183035441807, 53.37156956536429, 54.603374004364014, 50.51157290594918, 50.93283176422119, 52.32571629115513, 51.271778787885395, 52.02229193278721, 51.97231354032244, 49.59659242630005, 53.0184760093689, 51.869580950055806, 51.79304306847708, 52.30487516948155, 56.05287592751639, 53.89211818150112, 52.295064313071116, 54.09138209479195, 54.29122618266514, 53.344718251909526, 53.12659692764282, 53.7193477494376, 54.49655934742519, 56.754425116947715, 53.64040926524571, 59.607921736580984, 57.47428628376552, 62.76015962873186, 64.47922733851841, 65.19316169193813, 62.42929336002895, 65.26523535592216, 66.48296969277519, 67.87456880296979, 70.11345904214042, 70.84108829498291, 62.76708003452846, 67.7547471182687, 38.31671660287039, 0.4597768485546112, 11.108270951679774, 4.8909842031342645, 0.376763218747718, 3.3741970104830603, 6.9022475481033325, 5.829004040786198, 1.256633500967707, 0.14889608243746416, 0.38830252098185675, 3.0804786341530934, 2.7938389522688727, 0.23266216686793736, 0.8134316344346318, 21.549971682684763, 39.78288378034319, 37.39100810459682, 34.427639620644705, 55.755107402801514, 35.72368710381644, 0.43876853585243225, 0.41006745451263016, 0.20827875312949928, 0.21107700440500463, 0.16565141906695707, 0.20291036048105784, 0.1643676036702735, 0.14238928444683552, 0.1485902395631586, 0.1813013678682702, 0.06293733923562936, 0.11902840941080026, 0.11862438251929623, 0.1487354189157486], [0.007047334253521902, 0.06789805447416646, 0.06372827358011689, 0.06259716927473034, 0.03177633775132043, 0.12146288449210779, 0.0750387738059674, 0.04039829224348068, 0.0982673412987164, 0.03519146217565451, 0.06402241172535078, 0.033632192095475535, 0.0736389085650444, 0.26133640536240166, 8.335702606609889, 58.18149825504848, 32.8531847681318, 29.94439091001238, 16.6174316065652, 18.82712377820696, 22.013274090630667, 3.2599191197327206, 0.06227926883314337, 0.020720785184364234, 0.057167043510292254, 0.15904890692659787, 0.07464012769716126, 0.35107377437608583, 4.550439528056553, 4.909445132528033, 1.873366355895996, 1.524899648768561, 0.18168023468128272, 1.7826975754329135, 44.06005934306553, 72.69888373783657, 60.21588216509138, 64.67231777736119, 66.15398638589042, 69.35540362766811, 64.53975309644426, 64.84195109776088, 62.39404514857701, 65.31680488586426, 66.94962460654122, 63.79437814440046, 64.43744087219238, 65.6199061529977, 63.4251925604684, 61.829239981515066, 55.22346946171352, 56.87179408754621, 57.81284073420933, 57.472608293805806, 56.35526500429426, 60.44601345062256, 61.67124489375523, 54.2515241759164, 58.0280681337629, 59.86681856427874, 58.930646078927175, 55.66477039882115, 54.65951892307827, 53.70252963474819, 56.13874176570347, 54.63026353291103, 53.482761587415425, 50.91881029946463, 51.69968359810965, 53.288350990840364, 49.80467707770211, 56.20914091382708, 53.889849594661165, 52.898293018341064, 49.093643597194124, 51.96299600601196, 52.93141508102417, 50.54969072341919, 58.16531590053013, 58.79864420209612, 63.79486451830183, 65.13581126076835, 66.69188117980957, 62.86315972464425, 53.46847261701311, 53.67457703181675, 55.14066777910505, 55.62096895490374, 56.893611431121826, 55.27163437434605, 54.148041180201936, 53.89998354230608, 56.22497933251517, 59.858251435416086, 62.49357114519392, 61.27084800175258, 62.35061195918492, 57.29689877373831, 49.39700542177473, 49.64017500196184, 47.24247326169695, 49.16702004841396, 46.88026019505092, 44.088352407727925, 45.9987769808088, 47.72628675188337, 44.64973211288452, 46.28585570199149, 44.62575387954712, 45.20358344486782, 45.815660681043354, 46.19554649080549, 45.65548038482666, 45.98607914788382, 47.87620803288051, 47.80813653128487, 47.5333456993103, 45.265415464128765, 47.91043833323887, 45.96171876362392, 47.08629512786865, 45.90217617579869, 46.057180064065115, 46.60691806248256, 44.9571829523359, 49.20033318655831, 50.51267766952515, 49.77128403527396, 50.15891361236572, 50.10784087862287, 52.93722030094692, 59.01221098218645, 60.05646269662039, 61.25375543321882, 60.34418760027204, 60.02046407972063, 59.57630743299212, 59.72662476130894, 60.22591536385672, 55.68585123334612, 57.501512799944194, 40.91398102896554, 1.0873250088521411, 0.6890203931501934, 0.343382471374103, 4.188188680580684, 9.521358847618103, 0.7367186908211026, 0.033014972893787284, 0.029207787543003048, 0.09044069770191397, 0.08152654567467314, 4.841988980770111, 0.8963525220751762, 0.17798531294933387, 0.08696807082742453, 3.030718024287905, 27.35335554395403, 25.39518642425537, 32.19061844689505, 32.724427700042725, 36.78250224249703, 0.02766781669509198, 0.026390245516917536, 0.04995073198473879, 0.061156870132046084, 0.019016406997772198, 0.006566748679948172, 0.004941180639434606, 0.03080564590969256, 0.027358457313052247, 0.027157290339736, 0.005928234080784023, 0.03540078344355736, 0.06420053395309619, 0.06749005815280334, 0.03722654815231051, 0.03307511145249009, 0.05815299560448953, 0.0239099540548133, 0.06210628990083933, 0.04571814249668803, 0.028944750050348893, 0.10637173642005239, 0.025405682723170946, 0.019152775573145066, 0.1035403251381857, 0.08446822568242039, 0.16857134524200643, 0.4355588209416185, 12.307593430791583, 67.585266658238, 47.522020135607036, 30.880754470825195, 13.95886148725237, 28.33215696471078, 27.221245970044816, 2.8875193425587247, 0.07670984949384417, 0.101001599936613, 0.027702237080250467, 0.09123201202601194, 0.2954689423952784, 1.5158655792474747, 2.9762867050511495, 4.752403685024806, 2.3539287405354634, 4.534156858921051, 0.1420037272785391, 2.3785794292177473, 52.194499560764854, 78.45825944628034, 70.23998573848179, 72.29763916560582, 72.6564997264317, 73.97834587097168, 70.1641183580671, 71.52685465131486, 68.29197488512311, 69.3290491104126, 70.18405273982457, 69.3136796951294, 68.78395598275321, 70.11339650835309, 67.03844342912946, 64.49226910727364, 59.90403311593192, 60.649859700884136, 62.22401578085763, 61.57800701686314, 59.68326800210135, 63.63026169368199, 62.83590888977051, 58.745393208095, 62.28597981589181, 64.78288446153913, 60.19760840279715, 60.369708333696636, 59.18873691558838, 57.30040066582816, 57.218693324497764, 56.271375928606304, 56.31155041285923, 53.686583518981934, 55.151510443006245, 52.76859794344221, 52.63253484453474, 57.82679966517857, 56.47225529806954, 54.32429265975952, 53.29942294529506, 54.689795698438374, 56.60481650488717, 53.32495410101754, 61.160656520298545, 62.88384451184954, 67.50971194675991, 66.7125242778233, 68.88166155133928, 65.77180767059326, 56.117640086582725, 54.12440340859549, 57.18572759628296, 59.19568511417934, 60.07462528773716, 58.34583704812186, 55.296738215855186, 56.72544418062483, 57.89776856558663, 61.14507865905762, 62.98744215284075, 63.92153712681362, 64.19162055424282, 58.78370557512556, 53.90603542327881, 52.88272557939802, 51.25571802684239, 52.31185116086687, 49.62282187598092, 48.70937694822039, 49.83487742287772, 50.73595455714634, 47.00382348469326, 48.67144673211234, 48.92387131282261, 48.876769474574495, 49.3736629486084, 49.50582115990775, 48.109643186841694, 50.29351758956909, 49.60441609791347, 50.119718824114116, 50.09687662124634, 48.72487837927682, 49.95921891076224, 49.19509424482073, 50.5818886756897, 49.89948524747576, 50.52388858795166, 49.92256716319493, 47.67033985682896, 51.37016527993338, 53.584719453539165, 52.598266329084126, 53.3369015284947, 52.98935610907418, 55.763021400996614, 60.32918643951416, 63.38198866162981, 63.703037125723704, 61.487270491463796, 62.427813393729075, 62.32030391693115, 62.201677322387695, 64.2577257156372, 59.77504675728934, 64.33708109174455, 49.55059882572719, 1.560043745807239, 2.9732334060328345, 2.9140842599528174, 6.031428515911102, 4.876037325177874, 0.3583845006568091, 0.16109629135046685, 0.2340637216610568, 0.36078559181519915, 0.19528592031981262, 6.6867087824004035, 0.3999108709394932, 0.10121287538536958, 0.04337362419547779, 2.328201298202787, 34.9677300453186, 29.614226409367152, 34.89376647131783, 40.91082307270595, 45.66495425360543, 0.1707237804574626, 0.006470557435282639, 0.05608927884272166, 0.00871297572406807, 0.0026569891903948572, 0.049711870694799085, 0.04474690104169505, 0.03431629788662706, 0.020180421947900738, 0.03206480334379843, 0.06121880680854831, 0.04308531127337899, 0.02948460608188595, 0.08009641098656825, 0.07175368722528219, 0.129929033773286, 0.19149468732731684, 0.12802629944469246, 0.11833072613392558, 0.18585295363196305, 0.14320423214563302, 0.19036738281803472, 0.223196861201099, 0.07991769164800644, 0.228775219725711, 0.13883021899632045, 0.2064281710024391, 0.4440415400479521, 13.665843793324061, 78.25797067369733, 50.502779960632324, 44.445336954934255, 28.869167600359233, 38.152753012520925, 40.62242071969168, 5.214190082890647, 0.11425946173923356, 0.35613398998975754, 0.12275622652045318, 0.3521240923021521, 0.29507430642843246, 0.8102909943887165, 8.138370292527334, 15.6188417162214, 5.627522783620017, 5.346221489565713, 0.7077623988900865, 2.8625360088688985, 57.38795491627285, 85.04634680066789, 79.54634039742606, 78.37054538726807, 79.64817319597516, 82.44922828674316, 77.49215412139893, 77.11381775992257, 73.84060478210449, 73.96822234562465, 76.97239412580217, 73.90565381731305, 73.64595794677734, 75.40116323743547, 73.59244292122978, 68.64772265298026, 64.3853919165475, 65.7323557989938, 65.63285064697266, 64.01051575796944, 64.0155532019479, 69.13223443712506, 69.24042483738491, 62.030702999659944, 64.50933388301304, 68.8955579485212, 65.33349445887974, 65.48673003060478, 61.868837765284944, 61.3867370060512, 60.78398772648403, 61.29711219242641, 59.690237045288086, 57.462599413735525, 57.29617268698556, 57.79661321640015, 54.09293849127633, 61.72832434517996, 60.00941644396101, 59.68268435341971, 57.6620682988848, 58.580477714538574, 59.57623100280762, 55.87700659888131, 67.3151068006243, 65.01353686196464, 70.57778630937848, 69.20196655818394, 71.68360601152692, 68.3881310054234, 60.5206093106951, 58.00491673605782, 61.16250474112374, 62.10088675362723, 62.52699892861502, 60.83473736899239, 58.83521951947893, 60.536555426461355, 59.14910439082554, 65.21372141156877, 67.3979571206229, 66.01679420471191, 67.89321081978935, 61.89729758671352, 56.656549317496165, 56.01848929268973, 53.673805781773154, 57.6514618737357, 54.39528587886265, 52.57866546085903, 52.38591548374721, 54.898481369018555, 50.34989527293614, 50.93837642669678, 49.90676001140049, 51.85546221051897, 50.922364303043906, 53.135834557669504, 50.87814596721104, 51.58097015108381, 52.66818952560425, 54.290138789585654, 52.800278254917686, 52.60544729232788, 53.88915130070278, 53.26141977310181, 55.33942099979946, 53.39374821526663, 54.9267327444894, 54.25103432791573, 51.21044703892299, 55.101688385009766, 57.765870911734446, 55.46941832133702, 55.15513392857143, 56.02025066103254, 58.418647221156526, 63.30138955797468, 65.94607543945312, 66.77657972063336, 65.60619735717773, 66.04680347442627, 64.82639408111572, 69.25243132455009, 67.21297522953579, 65.25878742762974, 68.09226281302315, 51.98321178981236, 1.715903456721987, 6.739133375031607, 6.395432046481541, 4.949173629283905, 11.1611693246024, 0.7291545452816146, 0.18999885687870638, 0.23941019762839588, 0.5643694390143666, 0.20688344085855143, 6.367131165095738, 1.9268025628158023, 0.5781655758619308, 0.13930870832077094, 6.2534182497433255, 40.85906941550118, 42.1066358430045, 50.588576316833496, 43.38294349397932, 54.6643340247018, 0.29095749876328875, 0.17586328967341355, 0.1825788864599807, 0.17479891250176088, 0.1712909543088504, 0.08403281654630389, 0.11586108936795167, 0.10774337460419961, 0.16513612600309507, 0.17329559102654457, 0.0867237439379096, 0.10708344501576253, 0.1670684308878013, 0.1984554659575224], [0.07118298499179737, 0.03953779788155641, 0.01876578330328422, 0.05822439105915172, 0.06561585622174398, 0.06992885550217968, 0.048041259803410084, 0.0645822234717863, 0.0927672925006066, 0.02793636728477265, 0.06984344829938241, 0.1012286716806037, 0.04657544774402465, 0.12293506120996815, 16.50121429988316, 56.82039131437029, 27.40120083945138, 40.46686792373657, 16.391820124217443, 16.139020340783254, 11.322371874536787, 0.23437601061803953, 0.05619424821010657, 0.060176482025001726, 0.04168314240606768, 0.06206917403531926, 0.3172827304473945, 2.1155388695853095, 1.2553652375936508, 2.4408793662275587, 5.087630816868373, 4.407718317849295, 0.11030407076967613, 12.430927429880414, 65.55723340170724, 65.46630927494594, 62.70472690037319, 63.16819259098598, 63.65040452139718, 62.58644771575928, 62.69782733917236, 65.34140845707485, 62.12984684535435, 63.3428772517613, 63.89330659593855, 64.1395993913923, 64.41505377633231, 65.87471049172538, 61.88089288984026, 60.017705644880024, 53.866302149636404, 57.99699926376343, 53.74960020610264, 58.62802423749651, 57.61112758091518, 60.93231092180525, 55.57248789923531, 56.03001635415213, 58.565316745213096, 58.33547033582415, 55.19837604250227, 57.02462666375296, 56.32845885413033, 54.125977175576345, 53.16987725666591, 49.82238803591047, 53.69684253420149, 52.37694188526699, 52.27497707094465, 48.66575615746634, 51.72345338548933, 55.03876549857003, 50.21423169544765, 52.69510684694563, 49.95467478888375, 50.853035177503315, 55.72904470988682, 54.39880861554827, 54.159710679735454, 58.982431003025596, 68.2245009286063, 65.19077151162284, 62.94664233071463, 58.13442768369402, 47.79155812944685, 52.029240131378174, 57.27307340076992, 59.74232769012451, 60.45936094011579, 58.61657360621861, 53.12689222608294, 50.87605455943516, 55.55610752105713, 61.12763173239571, 59.49390179770333, 61.95275115966797, 62.0681676864624, 54.81393568856375, 51.13971785136631, 47.346109117780415, 48.17780154091971, 48.08546692984444, 45.68588917595999, 46.308329650333945, 44.72447388512747, 45.50978708267212, 45.69516502107893, 45.334772382463726, 44.75031076158796, 46.36397429874965, 45.488800048828125, 46.710936069488525, 44.24477025440761, 45.3107350894383, 44.07537317276001, 47.13979973111834, 45.15340008054461, 46.65476335797991, 45.80267102377755, 47.83820138658796, 45.57554830823626, 46.53206511906215, 45.41551045009068, 44.95053352628435, 45.1780001776559, 47.014985765729634, 49.81019394738333, 49.81751387459891, 50.54403836386544, 51.86689894539969, 51.91103737694876, 57.10439198357718, 58.69545650482178, 60.233224868774414, 60.2167854309082, 60.893797057015554, 58.61406530652727, 60.54587990897042, 58.37582547324044, 55.10345670155117, 57.01165090288435, 46.3186685698373, 1.4955853074789047, 1.3823418297937937, 4.476709587233407, 2.90677193232945, 0.6310036405920982, 0.4430244160549981, 1.4934757692473275, 0.2343781819300992, 0.09464992862194777, 1.420669830271176, 7.78681663104466, 0.10728195722081832, 0.2078029372330223, 0.05190839372309191, 1.12154021859169, 33.11366925920759, 18.755826575415476, 14.526544945580618, 27.39704234259469, 44.671420914786204, 0.43362803597535404, 0.017776397821892585, 0.00751152854146702, 0.03752821125090122, 0.05683984035359962, 0.07058522956711905, 0.03405881420310054, 0.08566051349043846, 0.00340283997190584, 0.03175953043890851, 0.07794645242393017, 0.026385461845036064, 0.05767538837556328, 0.03901209948318345, 0.055647074178393395, 0.014619411867378014, 0.03942235193348356, 0.0833820743220193, 0.04893710244713085, 0.029851917443530898, 0.08177710151565926, 0.04881375835144094, 0.11905025823840074, 0.037704721957977326, 0.029006727438952242, 0.09819492125617606, 0.07961532287299633, 0.1780502080385174, 23.8539856501988, 62.457732336861746, 43.96306596483503, 35.59149415152413, 14.527425629752022, 24.419263294764928, 12.078859601702009, 0.04345701275659459, 0.05298199557832309, 0.07314746600708791, 0.0622141905395048, 0.2146200564290796, 0.604256170136588, 0.9286979607173375, 1.1075967039380754, 2.349200491394315, 0.7356924201760973, 3.7185430015836443, 0.2508779008473669, 15.875515120370046, 72.28370802743095, 73.59878662654332, 67.4463026864188, 70.37321744646344, 71.32637827736991, 69.89123480660575, 69.4153526851109, 69.87701184409005, 68.41016374315534, 68.33021777016776, 68.56863130841936, 69.21194417136056, 68.39931760515485, 68.52824143001011, 66.61402661459786, 62.583751814705984, 56.818199157714844, 62.43733242579869, 58.455382347106934, 61.55664130619594, 60.690694264003206, 63.18401363917759, 59.401303155081614, 58.7931273324149, 62.65253203255789, 61.22090435028076, 59.3970855985369, 59.98526450565883, 59.5903080531529, 56.76726886204311, 55.935840470450266, 53.93564517157418, 54.925673144204275, 54.39522681917463, 53.78476503917149, 52.315832478659495, 53.20584460667202, 55.07223844528198, 52.883465562547954, 55.44922685623169, 54.12627942221505, 54.21878426415579, 58.72727925436837, 56.881931509290425, 59.194281578063965, 60.4191586630685, 67.15622234344482, 65.95103645324707, 62.680984905787874, 58.263188225882395, 51.706822872161865, 55.92119019372122, 63.84348801204136, 63.7151825768607, 65.32396847861153, 62.60166427067348, 57.6464661189488, 51.986004965645925, 57.58166374479021, 63.19378975459507, 61.09185545785086, 62.684229714529856, 63.2690109525408, 57.0046193259103, 53.630653994424, 52.07406990868704, 52.26712908063616, 49.7283684866769, 47.616595540727886, 49.66298246383667, 47.97583130427769, 47.84477090835571, 47.849394934517996, 46.34784752982003, 48.07574987411499, 47.99255909238543, 48.34445408412388, 48.570600577763145, 47.44193172454834, 47.38955272947039, 48.72047322137015, 50.23808833530971, 48.945858887263704, 50.10923746653965, 48.92890528270176, 50.805082184927805, 49.17248828070504, 48.432480812072754, 48.968996388571604, 47.93399620056152, 47.865636348724365, 50.24065916878836, 52.29427221843174, 53.66781643458775, 53.15816954204014, 54.137966292245046, 54.45455748694283, 57.571314402988975, 61.3051095690046, 63.96239253452846, 61.99435697283064, 65.71624987465995, 61.782040868486675, 64.23992443084717, 62.200183459690635, 63.16833850315639, 61.34768812997, 53.5695480619158, 1.997443595102855, 1.7438731044530869, 6.99350779397147, 3.1472086991582597, 1.5986325208629881, 1.378493070602417, 3.356801761048181, 0.9061075757656778, 0.06713863808129515, 2.9920265461717332, 6.26398993389947, 0.13618938784514154, 0.14927195012569427, 0.026430918602272868, 1.052992005433355, 40.18775878633772, 25.383478709629603, 14.533949988228933, 35.247950894492014, 52.28205728530884, 1.0901005970580238, 0.04741741131458964, 0.008818585458876831, 0.026678812889648334, 0.05017971380480698, 0.02221163857861289, 0.047811121081135104, 0.05109017209282943, 0.04728225731690015, 0.059745666570961475, 0.017449018246095096, 0.052002445462026765, 0.024773790201704417, 0.08775021135807037, 0.09659053877528224, 0.20278043459568704, 0.09919061032789094, 0.18637215505753243, 0.08350742688136441, 0.17656195004071507, 0.13084511033126286, 0.25678631237574984, 0.31714053664888653, 0.18061479899500096, 0.1427293119153806, 0.180920329743198, 0.25694823797260014, 0.3254125842026302, 26.71296613556998, 76.68255002158028, 45.55473150525774, 59.29739284515381, 30.264973844800675, 32.78892435346331, 20.88553629602705, 0.37210865850959507, 0.1915631243692977, 0.1385246068239212, 0.2756017627460616, 0.29339457941906794, 0.41994111612439156, 5.1328253746032715, 8.133168697357178, 7.105332970619202, 12.592010123389107, 8.988068972315107, 0.35805150281105724, 17.76928833552769, 82.99949782235282, 80.1506599698748, 74.90435314178467, 75.00945854187012, 79.53318050929478, 74.7533757346017, 76.06090859004429, 75.28951263427734, 73.406724521092, 71.52648639678955, 73.35003416878837, 73.32789025987897, 72.67137581961495, 73.380446434021, 70.2663472039359, 66.05767045702252, 60.17040620531355, 66.02197756086076, 62.832184655325754, 64.35936396462577, 65.20322963169643, 66.38650785173688, 65.2045567376273, 61.53354549407959, 67.37670952933175, 66.61593736921037, 62.1987521307809, 65.06432124546596, 62.73058114733015, 60.9066720690046, 58.70382908412388, 56.51489986692156, 60.125513894217356, 57.068191868918284, 57.50959702900478, 54.79786103112357, 56.78175933020455, 62.23446587153843, 58.68248421805245, 61.76097393035889, 58.140767914908274, 57.614980357033865, 62.08683054787772, 58.92945793696812, 62.1471061706543, 64.47488471439907, 72.10313129425049, 71.3517461504255, 67.1129698072161, 63.307017598833355, 53.01676327841622, 56.158801215035574, 64.25531469072614, 65.90692234039307, 66.16389451708112, 64.3575713293893, 58.89525195530483, 55.829043184007915, 61.761161531720845, 65.86768586294991, 62.02273341587612, 65.65830189841134, 65.96518298557827, 60.79734911237444, 56.78028283800398, 53.98473072052002, 54.30081122262137, 55.98027072634016, 51.627029759543284, 53.15260403496878, 51.765931197575156, 51.350960459027974, 51.7313117980957, 49.83415133612496, 49.95433432715279, 52.13109377452305, 52.512615885053364, 51.98321873801095, 51.37801327024187, 50.776834283556255, 49.18797581536429, 54.069578647613525, 52.28766795567104, 53.12970624651228, 52.38930967875889, 54.35303735733032, 53.041102818080354, 53.187688963753835, 52.74558203560965, 52.1007753099714, 50.85452209200178, 53.51738793509347, 56.20832450049264, 56.40583746773856, 55.520887102399556, 58.53431388310024, 56.78137717928205, 61.78837067740304, 65.08681951250348, 66.57451915740967, 64.8105035509382, 69.18746566772461, 64.34895556313651, 70.1465185710362, 65.11965669904436, 66.65475000653947, 65.11514731815883, 58.54921776907784, 2.4181507229804993, 2.858326269047601, 6.940903850964137, 4.159909078053065, 1.5941118491547448, 1.0607832159314836, 2.7558077701500485, 1.2176046009574617, 0.1490851222936596, 1.415945598057338, 10.820914302553449, 0.2199343019830329, 0.34312175107853754, 0.1462564862200192, 1.8543882199696131, 47.76502990722656, 32.735079288482666, 28.301181895392283, 40.61570528575352, 63.15988254547119, 1.438731129680361, 0.13638760149478912, 0.17617503580238136, 0.14803185952561243, 0.18564054502972535, 0.1795427950897387, 0.19948476286871092, 0.16263792291283607, 0.1197470458490508, 0.1709371797208275, 0.13364641501435212, 0.15610985963472299, 0.23010552834187234, 0.24319816008210182], [0.022223005736512796, 0.057772011762218814, 0.04287474150104182, 0.027032151518921767, 0.008323229450200285, 0.028228222159668803, 0.09537712817213365, 0.14205760295901979, 0.01966953257630978, 0.02967973578987377, 0.056166452023067644, 0.05866724372442279, 0.020239919291010926, 0.05020599685875433, 33.217433656964985, 55.72006068910871, 22.36600807734898, 22.020168440682546, 17.228873082569667, 17.340681757245743, 4.4486041239329746, 0.12250980974308082, 0.2357283037688051, 0.053889122259403975, 0.20581643097102642, 0.09901790959494454, 0.5707941342677388, 2.4685208201408386, 0.4667324296065739, 2.7000565103122165, 0.9981327205896378, 2.1003420736108507, 0.638469859957695, 26.096542801175797, 69.41508865356445, 62.59290954044887, 65.00737380981445, 63.98953219822475, 65.48473589760917, 64.01490701947893, 66.68232740674699, 62.95063059670584, 63.574057715279714, 64.36761147635323, 64.64154420580182, 65.75704274858747, 67.38754177093506, 63.78425461905343, 62.105027879987446, 58.105318205697195, 56.608818667275564, 57.922125475747244, 57.38126727512905, 58.286082540239605, 58.376937185014995, 57.64234583718436, 55.52642829077584, 58.50824424198696, 57.90177420207432, 57.058794430324006, 55.65735667092459, 55.02592870167324, 54.55806827545166, 53.62632526670183, 51.83359275545393, 51.15081065041678, 50.40051637377058, 51.21042619432722, 49.069165093558176, 48.85042190551758, 53.52593421936035, 50.34496552603585, 45.91117409297398, 48.621082714625764, 50.384400027138845, 50.90250287737165, 52.15193837029593, 56.98252752849034, 55.87628051212856, 52.56599194662911, 55.439054693494526, 57.51790707451956, 64.47497504098075, 57.44810547147478, 53.535679067884175, 62.7402252469744, 64.56826155526298, 64.79708657945905, 66.31239836556571, 65.77971472058977, 61.419817379542756, 53.46921954836164, 53.85031087057931, 58.19504724230085, 60.914996010916575, 61.37147181374686, 55.31006138665335, 49.52270180838448, 49.65502677645002, 49.42153603690011, 50.180446079799104, 45.44965737206595, 44.417637961251394, 44.995502267565044, 41.99245262145996, 44.36151041303362, 46.54316486631121, 45.95684807641165, 45.70877654211861, 45.89012452534267, 46.84866326195853, 46.72031961168562, 45.433370794568745, 44.80404118129185, 46.72481162207467, 45.32457937513079, 45.57456513813564, 45.859899861471995, 44.94750758579799, 46.16985552651541, 47.38659627096993, 44.88393504279, 45.88528510502407, 46.663066455296104, 45.39357846123831, 47.987309728349956, 48.94930171966553, 54.1204776763916, 51.49916900907244, 51.77856649671282, 52.29812846864973, 54.20554099764143, 56.86226463317871, 59.200145857674734, 61.99463490077427, 63.10268497467041, 57.180981976645334, 59.94891153063093, 57.09796142578125, 58.16019855226789, 59.323525020054404, 47.59624079295567, 1.361920422741345, 1.2711427509784698, 3.6001159506184712, 0.5712091262851442, 0.28843503126076286, 1.4888066883598055, 6.069954974310739, 1.3310712895223071, 0.013781363443870629, 9.347859723227364, 1.7898587797369276, 0.06963882927915879, 0.17062708921730518, 0.05549483127625925, 0.5091903741870607, 31.719273499080114, 22.9084244115012, 20.609758819852555, 27.40223264694214, 40.3191214288984, 1.0535836879696165, 0.11788541717188698, 0.0413765429652163, 0.057988722276474745, 0.011482530905465995, 0.02121657375911517, 0.042811929514365535, 0.0526786157861352, 0.014803169328453285, 0.023405285153005804, 0.029488029291055033, 0.019983857138348476, 0.02706069579081876, 0.013825428356150431, 0.09470977541059256, 0.0834374495648912, 0.025271022359707525, 0.027589647764606134, 0.04312229482457042, 0.06039779979203429, 0.12880151213279792, 0.0687323132795947, 0.041399243354265175, 0.0712954318150878, 0.08706058907721724, 0.058423859998583794, 0.0493300183277045, 0.055477582916085205, 39.305907317570274, 67.42562484741211, 37.91295678274972, 25.397463696343557, 23.044438873018535, 23.496645007814678, 3.926334960120065, 0.08371328083532197, 0.17837163007685117, 0.055959247784422975, 0.11977137811481953, 0.33355647006205147, 1.3359279717717851, 1.3626999237707682, 0.5987970030733517, 0.8979660240667207, 1.6804932653903961, 0.6938426058207239, 0.5492635667324066, 29.86724853515625, 75.31968171255929, 68.94361863817487, 70.33909484318325, 69.14299719674247, 70.05758857727051, 70.9395442690168, 71.16454083578927, 68.60994529724121, 67.85192462376186, 68.74410111563546, 67.52248968396867, 67.50665473937988, 70.9598469052996, 66.12738173348563, 66.10556438991001, 60.78213255746024, 58.738312993730815, 59.44779355185372, 62.48988165174212, 63.00095639910017, 61.000945227486746, 61.585858481270925, 58.73536000932966, 63.389193943568635, 61.87755080631801, 60.49575560433524, 59.9587710244315, 57.3687744140625, 57.459847927093506, 56.469524656023296, 56.10083586829049, 54.28761311939785, 54.087515422276084, 54.998966217041016, 51.81268562589373, 52.77224227360317, 53.81947476523263, 52.97503587177822, 50.165834018162315, 51.7136355808803, 52.53508983339582, 56.674642426627024, 56.848958832877024, 59.502079827444895, 59.29961626870291, 55.40328189304897, 57.53540958677019, 59.41094725472586, 67.28816863468715, 59.80569526127407, 55.54984024592808, 65.88399328504289, 66.51498699188232, 69.2963786806379, 67.18189593723842, 67.0078991481236, 61.847958428519114, 56.04084859575544, 54.2482133592878, 58.38414246695382, 60.40884058816092, 61.53943756648472, 55.129342215401785, 52.33482537950788, 53.59799746104649, 52.139952727726524, 53.79084471293858, 48.536884444100515, 47.89005579267229, 47.56406021118164, 45.99802310126168, 47.64244631358555, 47.41211700439453, 49.39835684640067, 47.966899394989014, 48.29427071980068, 48.58732836587088, 48.50170571463448, 47.93573325020926, 46.666405064719065, 49.21750913347517, 48.55938618523734, 47.82231433050973, 49.47181667600359, 48.01559237071446, 48.81319693156651, 49.250589506966726, 48.11972502299717, 48.40694618225098, 48.838182653699604, 48.346628870282856, 50.08466516222273, 51.412146295819966, 54.73362493515015, 54.497521672930034, 53.645964350019185, 54.84128032411848, 58.65751934051514, 58.476470129830496, 61.80073847089495, 61.28174277714321, 64.47052819388253, 60.24133341653006, 63.91077436719622, 60.34409032549177, 62.789335114615305, 62.834053720746724, 53.28984832763672, 1.4656413942575455, 2.3553190316472734, 3.1828323304653168, 0.5366416211639131, 0.482823263321604, 1.4969448745250702, 5.5505580220903665, 0.8586390029106821, 0.019425141225968088, 8.954750623021807, 0.638827746467931, 0.09354658996952431, 0.09584972781262227, 0.04045855633116194, 0.557673764015947, 37.045557567051475, 28.864411558423722, 21.06750614302499, 32.189583165305, 47.6926713671003, 1.7471692647252763, 0.1490081221397434, 0.061776766154382906, 0.0644830691495112, 0.05200426732855184, 0.014532840977023755, 0.03607575276068278, 0.0630662337477718, 0.007772754345621381, 0.026121452350967696, 0.04984410020655819, 0.0310180850460061, 0.017362035145717006, 0.019408897097621645, 0.2852114742355687, 0.16199081763625145, 0.1740937924810818, 0.07001461554318666, 0.09315443065549646, 0.21926331227379187, 0.3063896378236157, 0.1704397728400571, 0.10803323119346585, 0.22745303995907307, 0.11779110080429486, 0.34856512184653965, 0.16553072125783988, 0.1879221461713314, 44.75554970332554, 75.8529281616211, 38.37932334627424, 37.54592514038086, 30.675563744136266, 35.871214730399, 7.036043797220502, 0.21381312901420252, 0.41394661207284245, 0.11707390286028385, 0.2940939590334892, 0.3346873979483332, 1.32846690927233, 6.834998105253492, 4.222607885088239, 11.366493804114205, 6.3318838221686224, 3.985684735434396, 0.7025075522916657, 32.66108097348894, 83.30464185987199, 75.70495237622941, 76.05571828569684, 74.80775233677456, 77.1216344833374, 77.83141381399972, 77.45054830823625, 76.11866896493095, 72.82388183048793, 72.85686492919922, 72.99782998221261, 71.30296284811837, 74.67487498692104, 71.46147905077252, 71.06395871298653, 65.11293084280831, 63.8379294531686, 64.45340088435582, 65.73797689165387, 66.43048300061906, 66.68744822910854, 64.86594322749546, 63.599918910435264, 67.4215532030378, 65.99054391043526, 64.07400144849504, 62.48861707959856, 60.76929228646414, 61.54203619275774, 59.79086085728237, 58.81281852722168, 56.76356894629342, 54.57200288772583, 57.69587823322841, 55.24790627615792, 54.54816361836025, 59.40576389857701, 56.32797942842756, 54.21419150488717, 57.05707475117275, 57.58014556339809, 59.48792634691511, 59.97359848022461, 62.80095945085798, 59.90984875815255, 57.94957433428083, 60.42681557791573, 62.59149210793631, 67.25644315992082, 62.218818528311594, 57.95533439091274, 69.5308039528983, 70.29168728419712, 73.50990527016776, 74.3039801461356, 70.91444042750767, 66.0685304914202, 58.386351994105745, 56.98645673479353, 62.72088841029576, 65.8393372126988, 68.1542546408517, 60.978210721697124, 54.20901162283761, 55.4494491985866, 55.180408000946045, 57.02454328536987, 51.96316276277815, 51.831428391592844, 53.74354485103062, 49.436095987047466, 51.32361234937395, 51.72398144858224, 53.09393344606672, 51.01969466890608, 52.21627174104963, 52.474369525909424, 51.47740725108555, 49.81212207249233, 48.696974413735525, 52.570918219430105, 50.6937164579119, 51.979803698403494, 52.79801661627633, 50.97391298839024, 53.29033122743879, 52.88995170593262, 52.523705210004536, 52.00027309145246, 51.70389768055507, 52.32059894289289, 54.67396075384957, 55.86097015653338, 58.5102870123727, 57.992691380637034, 56.83865812846592, 57.22768776757376, 59.894215311322895, 62.94804586683001, 65.53293555123466, 65.72393458230155, 69.2795501436506, 62.858483586992534, 69.01900659288678, 63.184625080653596, 67.08177934374127, 65.50353077479771, 60.217765126909526, 2.1255579548222676, 3.337880947760173, 6.605219006538391, 0.6589064661945615, 0.3207398120846067, 3.2644009249550954, 11.669252872467041, 4.865597222532545, 0.11306383553892374, 12.72313826424735, 2.3858055557523454, 0.16599561274051666, 0.2643824304853167, 0.11459087181304183, 1.0840664122785841, 45.46359198434012, 38.487305300576345, 36.30931602205549, 42.72775615964617, 59.55208601270403, 2.355801497186933, 0.3551358649773257, 0.13857679973755563, 0.13589392655662128, 0.17845872683184488, 0.10125690552272967, 0.12125300004013947, 0.16404344035046442, 0.14041511395147868, 0.13088857728455747, 0.12541593451585087, 0.09132873719292027, 0.10354261858654873, 0.21676175722054072], [0.08130670032863106, 0.2015464643814734, 0.09529437404125929, 0.033080987565751584, 0.03726568944486124, 0.03801927722192236, 0.05108542574037399, 0.035732980617987256, 0.08358011833791222, 0.055012738930859735, 0.05990757181176117, 0.0370277441771967, 0.11125233702893768, 0.31960000896028107, 45.980468477521626, 37.185317107609336, 30.967975207737513, 17.768887077059063, 14.593405723571777, 9.626794287136622, 0.5644123224275452, 0.026856049629194394, 0.03663257895303624, 0.0971028869971633, 0.03783905832096934, 0.47167178456272396, 1.2974146498101098, 0.11136378640575068, 0.23761452255504473, 1.1559257677623203, 0.6785447895526886, 2.5886438829558234, 0.12357923521527223, 38.50802482877459, 67.30435098920549, 63.769177028111045, 65.27333000728062, 64.00638852800641, 63.44099971226284, 62.65055179595947, 64.16368879590715, 60.9594783782959, 65.843172618321, 62.18620368412563, 63.7353948865618, 66.508775302342, 66.08424731663295, 63.45659146990095, 62.9171541758946, 56.64262165342058, 54.92707668031965, 56.75071825299944, 57.525025503976, 61.700997080121724, 60.8131354195731, 56.77008983067104, 57.091798373631065, 59.783697264535085, 55.61401728221348, 57.67968545641218, 55.407419545309885, 54.17465625490461, 53.24868025098528, 50.358031613486155, 52.069233962467735, 51.24913460867745, 53.297425338200156, 52.11939648219517, 50.08325815200806, 46.92225858143398, 52.70560210091727, 49.0367864881243, 47.96323422023228, 49.98182487487793, 48.302233355385916, 50.44805942262922, 51.46456003189087, 54.517803464617046, 55.67248289925711, 54.20348085675921, 56.7293073790414, 59.84976768493652, 63.3087546484811, 60.03398527417864, 56.99311310904366, 56.26354878289359, 62.34463650839669, 61.5554392678397, 64.74375915527344, 61.18160533905029, 60.96870558602469, 56.705812045506065, 48.143866539001465, 51.37465729032244, 50.88493088313511, 47.882767132350374, 48.904777663094656, 49.17739370891026, 49.84879119055611, 47.60071890694754, 47.34601184300014, 44.704067025865825, 44.12597690309797, 40.75446081161499, 43.6670310156686, 45.247624601636616, 45.409486361912315, 46.416996002197266, 45.964258330208914, 47.09479277474539, 45.88790804999215, 45.51654767990112, 44.94087553024292, 43.40221779687064, 45.6325443812779, 44.87804297038487, 44.20644399097988, 46.46293749128069, 45.082000391823904, 44.99587399618966, 45.861372879573274, 45.23596205030169, 45.188307830265586, 45.88363838195801, 45.38591807229178, 44.458840778895784, 48.27286679404122, 50.188526834760395, 53.895432472229004, 53.50307812009539, 52.46022299357823, 55.514592034476145, 53.95947401864188, 58.611091477530344, 59.30914919716971, 59.16926111493792, 57.89362743922642, 60.51837893894741, 60.392491476876394, 57.08803939819336, 58.5159706388201, 37.23565680640084, 1.2277311661413737, 2.125462199960436, 4.434187480381556, 1.6257405919688088, 2.2129237353801727, 3.700096837111882, 5.851200495447431, 1.6537626768861498, 3.8277899622917175, 5.925385977540698, 0.04350097504045282, 0.04066719567137105, 0.05996306240558624, 0.052464259788393974, 0.14188727709863866, 33.659877572740825, 25.126621178218297, 17.270164489746094, 32.88867269243513, 32.52022361755371, 2.9886182376316617, 0.17097916746778147, 0.16094277958784783, 0.023169170233554075, 0.07088718443576779, 0.05088951571711472, 0.07743333067212786, 0.052517182127173455, 0.03853134385177067, 0.080203667016966, 0.048723401235682626, 0.05843530009899821, 0.10032409629119293, 0.088346012601895, 0.06384344811418227, 0.09713763477546827, 0.07252939524395124, 0.05313579232564994, 0.039951748347708156, 0.026318797475791404, 0.09983580892107316, 0.03128747023375971, 0.059254088306001255, 0.043369525843965154, 0.09082676377147436, 0.04554858338087797, 0.11536821510110583, 1.3252760576350349, 51.68870544433594, 51.25715282985142, 41.22542013440813, 17.305148669651576, 22.651552983692714, 11.428506476538521, 0.37322973406740595, 0.047889932923551114, 0.02080933061162276, 0.07957052599106516, 0.013336951844394207, 0.9312843190772193, 2.286993703671864, 0.22878048515745572, 0.1470649606947388, 0.46812223217317034, 1.336103413786207, 2.3783655549798692, 0.44959298787372454, 43.240627016339985, 73.8750331061227, 71.25377655029297, 70.16646684919084, 70.60187571389335, 68.04396588461739, 67.17585795266288, 70.07147802625383, 67.02922316959926, 70.20327145712716, 67.52842344556535, 68.33559567587716, 69.1811775479998, 69.61292471204484, 67.83569363185337, 67.08485044751848, 59.423968178885325, 59.566253389631, 60.92894104548863, 60.43503529684884, 63.73809773581368, 64.04020541054862, 60.18142604827881, 60.005330903189524, 62.1260461807251, 57.816804681505474, 61.97938360486712, 58.79603167942592, 58.95495087759835, 57.20155211857387, 53.25640664781843, 54.16597100666591, 52.951887948172434, 54.50387927464077, 55.82239375795637, 52.11286517551967, 49.38197299412319, 55.16547284807478, 52.62401635306222, 54.20470721381051, 53.82906327928816, 50.997790472848074, 51.80250998905727, 55.706786155700684, 56.451987402779714, 56.70498868397304, 57.88613033294678, 62.53211975097656, 63.32017053876604, 65.75062261308942, 65.13403947012765, 54.82433714185442, 58.730544907706125, 64.6305730002267, 63.84195246015276, 66.13412843431745, 63.504693848746165, 66.11267934526715, 57.23910018375942, 47.22507149832589, 54.82591438293457, 55.08189296722412, 52.120549883161274, 49.753187452043804, 51.993807792663574, 52.22064563206264, 50.277776445661274, 48.19260467801775, 49.0212642124721, 47.64489555358887, 44.88811438424246, 45.790063517434255, 48.85451439448765, 48.75729867390224, 50.39858477456229, 49.57573046003069, 48.057566438402446, 47.28081342152187, 47.80837277003697, 48.75244188308716, 46.132710456848145, 48.07993268966675, 47.127192224775044, 49.210661683763774, 48.83901991162981, 47.631850310734336, 48.32861566543579, 48.85826642172677, 48.73621783937727, 48.78469542094639, 49.830684185028076, 48.735279832567485, 48.515907832554404, 51.940212862832205, 56.61421046938215, 55.44311591557094, 57.346293517521445, 54.43153463091169, 58.190933908735005, 56.32517235619681, 61.211079597473145, 62.377751622881206, 62.71827588762556, 61.49444798060826, 63.88660158429827, 63.744635990687776, 62.56069769178118, 64.80135972159249, 43.29213401249477, 1.3389517409460885, 0.4120998297418867, 0.5840442404150963, 0.9070167584078652, 1.4105942909206663, 1.0775038387094225, 1.882683890206473, 0.9709401854446956, 5.600560733250209, 5.4510489617075235, 0.007599187632357436, 0.19269557217402117, 0.16086455807089806, 0.15067031580422605, 0.2110018634370395, 35.789396217891145, 31.442460741315568, 19.56982019969395, 39.003514766693115, 46.40826211656843, 5.093789526394435, 0.2183601957346712, 0.1281667561935527, 0.07910097975816045, 0.032375005805598836, 0.0509409317081528, 0.032830346907888136, 0.04958062505881701, 0.038009547029754946, 0.03668971499428153, 0.05805830604263714, 0.047409862612507174, 0.027683974310223545, 0.044958329160830805, 0.19639434798487596, 0.34909660475594656, 0.18925685169441359, 0.12393208699566977, 0.22380263012434753, 0.18504628406039306, 0.474290061209883, 0.1759351058197873, 0.08655349271638052, 0.14670859410294465, 0.2300787397793361, 0.14703617723924772, 0.2019375991076231, 1.4284618007285255, 63.50592367989676, 52.205331802368164, 48.3799489566258, 33.775499071393696, 29.26761899675642, 21.360817398343766, 0.545910680932658, 0.1678249838628939, 0.14585799617426737, 0.29123653950435774, 0.12978363728949002, 1.1732834534985679, 2.5951708470072066, 0.5169736051133701, 0.5136667511292866, 2.8514538492475237, 8.49586205823081, 11.999595420701162, 0.43416939835463253, 48.31065109797886, 77.17730345044816, 79.1701579775129, 75.16197844914028, 77.84932626996721, 74.39504323686872, 74.500899042402, 75.97514002663749, 72.19932910374233, 73.01195566994804, 70.95369774954659, 72.43310819353376, 74.0036095210484, 73.46071202414376, 71.07955741882324, 70.64430836268834, 63.88218252999442, 61.608384541102815, 66.73114545004708, 64.76604202815464, 68.36110251290458, 68.01854937417167, 63.83459431784493, 64.22845295497349, 67.00712789808, 62.77506351470947, 66.457289150783, 61.7442843573434, 63.42939622061593, 62.031432560511995, 56.25764628819057, 59.023335048130576, 56.602124077933176, 59.031061444963726, 57.105340412684846, 54.51091085161482, 51.94531978879656, 60.53050354548863, 57.85477658680507, 57.568667139325825, 58.11868306568691, 56.39829172406878, 57.16981274741036, 58.51601927621024, 60.471263204302105, 59.90061460222517, 59.02951199667794, 62.813695498875205, 65.25270080566406, 64.45780604226249, 65.04439381190709, 57.04541219983782, 60.90820762089321, 67.95559174673897, 65.829957144601, 68.95932851518903, 66.75444970812116, 67.79861804417202, 61.1204195022583, 50.170287813459126, 55.330395289829795, 56.180472646440776, 52.978454385484966, 52.39832844052996, 54.75762401308332, 54.61739894321987, 53.02072722571236, 53.11094958441598, 52.55066769463675, 50.524399280548096, 47.26645149503435, 50.97047015598842, 53.19028064182827, 52.6409456389291, 53.08635990960257, 51.842816489083425, 51.41544669015067, 49.39108903067452, 51.788853304726736, 48.797132696424214, 48.199125562395366, 51.20806728090559, 50.08124317441668, 49.88777405875069, 52.267869063786094, 50.32243251800537, 51.62265239443098, 51.39711734226772, 51.73518194471087, 51.11123718534197, 52.921833515167236, 51.89710971287319, 52.53351606641497, 53.87808282034737, 58.469952719552175, 57.19236312593733, 58.56158556256975, 58.478485107421875, 60.27740151541573, 58.27588258470808, 66.45150130135673, 65.6449613571167, 66.5369016102382, 63.259297370910645, 66.5364430291312, 66.14962986537388, 66.5988517488752, 68.61346108572823, 51.76342289788382, 1.775568615112986, 4.267408132553101, 9.498510565076556, 3.669846986021314, 9.140191963740758, 9.802287544522967, 22.132982867104666, 2.347579389810562, 3.679828073297228, 9.339649558067322, 0.12330372285630022, 0.3523939592497689, 0.3284234069287777, 0.4180215948394367, 0.2384085985166686, 45.78805896214077, 37.975914410182405, 31.775425365992955, 49.77193716594151, 56.596565519060405, 5.7423834545271735, 0.44369969410555704, 0.420036572430815, 0.21214123229895318, 0.12359412227358137, 0.15140039234289102, 0.19380395912698337, 0.15440122703356401, 0.18454822578600474, 0.14137259471629346, 0.1502684195126806, 0.1554961111396551, 0.21378843033952372, 0.19857551237302168], [0.18325754361493246, 0.01817172419811998, 0.013536239275708795, 0.030422368619058813, 0.0469322655616062, 0.09972796935055937, 0.05687565343188388, 0.1409277200166668, 0.0448308629649026, 0.10714563275022165, 0.016890921496919224, 0.2088255709303277, 0.162626713514328, 8.946284243038722, 60.61709894452776, 30.728821686335973, 28.9012439591544, 19.66134534563337, 20.3715398311615, 8.009616698537554, 0.10808764291661126, 0.06741531752049923, 0.11205106095543929, 0.09261784516274929, 0.07087750174105167, 1.4308917160545076, 2.2047609048230306, 0.7107750943728856, 0.08106100279837847, 0.14823149809879915, 0.6207600416881698, 0.5794102805001395, 1.0492544174194336, 41.59556456974575, 66.41249411446708, 64.55765165601457, 63.17008250100272, 63.706073488507954, 62.21171052115304, 65.55704580034528, 62.379773548671174, 63.48300852094378, 64.9303252356393, 63.73327568599156, 64.93444551740373, 67.40448147909981, 62.71961688995361, 62.890716280256, 60.04009968893868, 54.782991886138916, 56.204645429338726, 58.346358163016184, 57.477784701756065, 60.389594078063965, 60.36855493273054, 53.12217092514038, 56.56902633394514, 58.110873290470664, 56.264035156794954, 56.16504764556885, 55.52510118484497, 52.94552339826311, 50.074228967939106, 51.38858495439802, 48.873542036329, 50.18971150262015, 49.835065024239675, 52.25569234575544, 48.64298343658447, 46.74094533920288, 48.29308257784162, 44.809644903455464, 48.97918939590454, 49.079163551330566, 47.66609450748989, 48.621384961264475, 51.546114512852256, 51.645723887852256, 50.42468915666853, 60.61273547581264, 64.90292154039655, 66.04772063664028, 52.34770039149693, 64.25695446559361, 60.71012837546212, 60.92355619158064, 63.763826915196006, 61.86068752833775, 61.5477545601981, 61.74847412109375, 61.32122244153704, 56.717759472983225, 52.80946029935564, 54.368636063167024, 53.870429379599436, 55.38549450465611, 53.80138513020107, 50.3386287689209, 51.819175243377686, 46.68269164221627, 47.280344418116975, 47.06993212018694, 45.37327235085623, 44.384557587759836, 43.88771275111607, 45.66232783453805, 43.6412010874067, 47.87672567367554, 46.32901096343994, 44.26271745136806, 47.025164876665386, 45.65719311577933, 44.69827570234026, 46.442325660160606, 44.71107428414481, 45.008099351610454, 44.32289579936436, 44.26587540762765, 46.76003551483154, 45.206838675907676, 44.40270628247942, 46.35354157856533, 45.994093894958496, 44.55114759717669, 44.843645913260325, 45.246603216443745, 47.40037454877581, 51.86165305546352, 54.882462297167095, 54.56522839409964, 53.56317656380789, 56.40461458478655, 57.15439469473702, 55.52229411261422, 57.795539719717844, 61.07658331734793, 59.01827675955636, 60.72655391693115, 57.986611706869944, 58.720664569309776, 54.11376919065203, 27.498654535838536, 1.1342676899262836, 1.5677438697644641, 1.0476871643747603, 1.09587085885661, 0.7453875456537519, 1.9061321062701089, 4.015073878424508, 0.2527967978801046, 7.110330028193338, 3.2583221197128296, 0.04208337628681745, 0.14569168724119663, 0.10245781072548457, 0.24759498557874135, 0.07984156680426427, 18.13740737097604, 46.731085845402305, 22.87984994479588, 15.135865483965192, 36.8078909601484, 6.955145052501133, 0.3196535589439528, 0.09886578882911376, 0.029107557742723396, 0.13451762683689594, 0.056487124280205796, 0.09293743515653269, 0.03624669948060598, 0.03034900202016745, 0.11350206738071782, 0.020636916559721743, 0.007331052645375686, 0.050995994824916124, 0.05607341469398566, 0.041068854475659985, 0.054587908155683956, 0.02378518333924668, 0.01864910581415253, 0.0320319893902966, 0.07166384918881313, 0.13981351123324462, 0.0830743315496615, 0.04631534152265106, 0.09710957735244717, 0.05579063183228884, 0.4472791020359312, 0.21041636914014816, 14.00951646055494, 68.87323338644845, 41.264149393354145, 34.40174715859549, 22.134266546794347, 29.593194212232316, 8.358573470796857, 0.05979975938264813, 0.1076541201078466, 0.15183732818279946, 0.09606628226382391, 0.12916200421750546, 1.230126557605607, 3.141442997114999, 0.2647682726383209, 0.12713494870279515, 0.1919614379959447, 0.45390863344073296, 0.6923675792557853, 1.7951964076076234, 48.04766525541033, 71.04417024339948, 71.55195849282401, 71.26791613442558, 68.33874320983887, 67.69429779052734, 71.71232291630336, 66.73691245487758, 68.90681403023856, 68.38893004826137, 68.67691203526088, 68.34685870579311, 70.97017887660435, 67.31931046077183, 66.11224855695451, 63.916312081473215, 57.43650197982788, 59.85138661520821, 62.34777709415981, 61.7748772757394, 64.69873482840401, 62.5088015965053, 56.75516857419695, 60.40799290793282, 60.33204214913504, 59.75170081002371, 59.276569093976704, 57.775706086839946, 56.279977798461914, 53.896874223436626, 52.92249359403338, 53.30885165078299, 54.75852033070156, 53.0911090033395, 53.52938747406006, 51.70685066495623, 50.93116767065865, 50.47129419871739, 49.0874353817531, 53.42558486121041, 52.55453436715262, 50.72447960717337, 53.17873968396868, 54.73398971557617, 53.23545782906668, 57.201107433864046, 63.528616496494834, 66.57091999053955, 66.2598352432251, 56.03392471585955, 66.93590886252267, 62.544709886823384, 63.86957154955183, 65.4242170878819, 66.39519309997559, 64.8449318749564, 63.90278393881661, 63.68123367854527, 58.75872680119106, 58.645519801548545, 59.1533636365618, 57.12921789714268, 59.73093959263393, 58.16861629486084, 53.56403466633388, 51.29259559086391, 49.92188623973301, 48.464921951293945, 49.13926199504307, 50.1710764339992, 48.27285289764404, 48.02316590717861, 47.88535533632551, 46.63383190972464, 51.61175067084176, 48.5328232220241, 47.14519500732422, 48.810202257973806, 47.8244126864842, 46.920994009290425, 46.17285367420742, 47.333494663238525, 47.747339793613975, 47.541964939662385, 47.26711157390049, 49.719916003090994, 47.04977192197527, 47.904129368918284, 49.423276560647146, 48.851415497916086, 48.483803680964876, 48.4113826070513, 48.586671761104036, 50.79959658214024, 54.431760447365896, 56.84922981262207, 55.72515719277518, 55.28618390219552, 58.629545892987935, 59.68633215767996, 59.22711181640625, 59.16662079947335, 61.52558980669294, 61.93754850115095, 63.77838339124407, 62.45723901476179, 61.80144023895264, 57.71306460244315, 34.354947566986084, 1.3360714954989297, 0.513183417064803, 0.6318724911127771, 0.21098468293036732, 1.2978489122220447, 0.6188200286456517, 1.4125905952283313, 0.3627212350921971, 11.055972729410444, 3.09530457002776, 0.06573167536407709, 0.38899978356701986, 0.091284191368946, 0.3563123361340591, 0.18445424868592195, 18.48742287499564, 49.94824423108782, 29.197449139186315, 18.674180030822754, 49.16730839865548, 12.208095226969037, 0.3095070719718933, 0.06956683671368019, 0.06318037690860884, 0.01420083039972399, 0.12102710216173104, 0.047251299156674316, 0.015282235407669629, 0.06494905985891819, 0.12347434727208954, 0.055127000835325034, 0.026930495098765408, 0.09641551066722188, 0.04402200851057257, 0.24219987222126552, 0.19219633324870042, 0.1044286224724991, 0.11747699337346212, 0.18168901492442402, 0.2275232140507017, 0.21920085991067545, 0.1840371803513595, 0.2526292268718992, 0.2616730401558535, 0.1671884637326002, 0.5673283945236887, 0.2950825574142592, 16.323736463274273, 80.1500346320016, 46.58840806143624, 43.13009507315499, 34.47038493837629, 39.336128507341655, 15.382095745631627, 0.15538964899522917, 0.24198035257203238, 0.25601601228117943, 0.901207412992205, 0.12858586013317108, 3.018128974097116, 6.329248283590589, 1.370063602924347, 0.344681513096605, 1.0048962490899223, 2.412516168185643, 1.6407367587089539, 2.062967279127666, 53.91449138096401, 73.00373595101493, 75.95396886553083, 75.64193221500942, 75.57017121996198, 73.45092896052769, 78.08464785984584, 72.33831392015729, 75.28525338854108, 73.01010744912284, 74.04625061580113, 73.52205766950334, 76.24378517695835, 70.41381577083042, 71.03181634630475, 67.63984475816999, 59.33797032492501, 62.58547496795654, 65.44144167218889, 63.960912568228586, 67.5801180430821, 68.43160588400704, 60.094462394714355, 62.69259534563337, 64.8931245803833, 64.81646510532924, 61.758236340114046, 61.809138842991416, 59.971785000392366, 57.12521226065499, 57.076474121638704, 55.897816453661235, 57.62719529015677, 56.47122001647949, 56.51961074556623, 54.12260382516043, 52.20108992712838, 55.123502254486084, 52.941125188555034, 58.02620601654053, 58.06621721812657, 54.201636110033306, 56.48104476928711, 58.20001867839268, 56.68035037176949, 56.87606028148106, 64.96763706207275, 68.97282886505127, 70.87088217054094, 58.335741315569194, 67.64996828351701, 66.55102729797363, 66.74673025948661, 69.8723634992327, 69.4006850378854, 68.47827693394252, 65.74814905439104, 65.79183237893241, 62.96356814248221, 54.34657900674002, 56.67272819791521, 61.79119164603097, 62.79038429260254, 58.22346190043858, 53.31192970275879, 56.10850667953491, 54.0373911176409, 52.176090308598106, 53.53436238425118, 52.6453195299421, 51.95104857853481, 52.67847980771746, 54.21817977087838, 50.6095529283796, 55.89844526563372, 50.08524186270577, 49.289881569998606, 52.65196895599365, 50.83387899398804, 49.497552803584504, 49.62958247320992, 51.76039348329817, 50.62089238848005, 50.077341760907856, 49.54256323405674, 54.255231039864675, 51.28351776940482, 51.609065192086355, 52.617102895464214, 52.59911400931222, 51.694232736315044, 51.241668769291465, 52.56885460444859, 55.19308498927525, 58.558535303388325, 59.28253064836775, 58.28952884674072, 58.42665849413191, 61.61436694008963, 61.99025058746338, 63.11651883806501, 61.889703205653596, 65.28630924224854, 65.97701576777867, 65.41121006011963, 64.5874524797712, 66.99145971025739, 62.17605236598423, 44.69529145104544, 1.9994937479496002, 5.577531363282885, 6.058338020529066, 3.151356122323445, 10.706632937703814, 13.362964000020709, 12.592842170170375, 0.542771289391177, 13.78569848196847, 5.914595859391349, 0.39421940062727245, 0.5372580023748534, 0.1969111609671797, 0.5529655452285493, 0.2286893171923501, 27.358561481748307, 62.82167897905622, 39.01162678854806, 24.640231643404277, 59.08270045689174, 13.268178411892482, 0.5533850970012801, 0.22482244111597538, 0.20043301555727208, 0.1620304440813405, 0.21125372206526144, 0.24850126409104892, 0.11570957249828748, 0.2335769406386784, 0.2922110514981406, 0.1268454042396375, 0.20219461460198673, 0.20248690034661973, 0.2828661043729101], [0.1902075471090419, 0.07203548960387707, 0.12983679372285092, 0.07560882464583431, 0.11740913987159729, 0.02360308150361691, 0.16693169251084328, 0.0824551819158452, 0.04304009030706116, 0.2047440470861537, 0.3315193722290652, 0.5108881230865205, 0.9592801311186382, 50.89826447623116, 44.81025634493147, 33.024874755314414, 40.0414331981114, 13.935367890766688, 33.05712481907436, 3.5635299938065663, 0.21249012143484183, 0.031462993672383685, 0.0751214058005384, 0.02862140436523727, 0.17457775079778262, 1.016353720000812, 2.921281942299434, 0.08916022069752216, 0.2671359527323927, 0.10374768543988466, 0.002186862810049206, 0.09016764842505966, 3.4557084994656697, 47.668474265507285, 61.36079938071114, 66.48391464778355, 64.51357228415353, 64.87355150495256, 62.65628405979702, 63.892667361668174, 60.97643198285784, 63.84068093981062, 66.16640976497105, 63.35655130658831, 65.729583467756, 67.65215001787458, 63.60187830243792, 60.62137903485979, 60.67581122262137, 55.88379846300398, 55.83173908506121, 59.87111949920654, 59.34177098955427, 58.563260078430176, 55.94123922075544, 53.66804225104195, 57.48418051855904, 56.350234508514404, 55.02546664646694, 58.16770608084542, 55.254917008536204, 51.20354052952358, 50.087802273886545, 49.14814526694161, 49.46341282980782, 49.8840776171003, 51.000861576625276, 49.59440721784319, 49.264541489737375, 52.26635435649327, 47.586787768772666, 50.09410081590925, 47.968667711530415, 46.659345694950645, 49.74355724879673, 50.00863102504185, 47.6022127696446, 53.1282262802124, 55.53454726082938, 65.89779935564313, 63.950844628470286, 61.196912220546174, 49.3492990902492, 56.04437133244106, 60.2816538129534, 56.08740847451346, 60.568670000348774, 59.363685607910156, 63.91772951398577, 59.72163595472063, 58.89181954520089, 57.436599254608154, 54.264517307281494, 50.53075688225882, 55.968260765075684, 54.520356927599224, 60.07676533290318, 57.61814873559134, 49.653209822518484, 47.47528655188424, 46.21701642445156, 45.83470221928188, 46.287665707724436, 46.01235376085554, 42.30836984089443, 39.79203455788748, 42.42376552309309, 47.82226916721889, 45.23754971367972, 43.18874134336199, 44.867134298597065, 46.06613629204886, 46.210373946598594, 45.82369974681309, 44.3587589263916, 44.634546824863975, 44.587246962956016, 44.611489227839876, 45.39098678316389, 44.53807456152779, 43.34227916172573, 46.5763008253915, 46.84823247364589, 45.93908153261457, 46.857383251190186, 43.615027223314556, 45.62460259028843, 50.34362799780709, 52.572846344539094, 56.50846583502633, 55.08425882884434, 55.041214738573345, 55.61431605475289, 55.45431293760027, 57.95062003816877, 58.29196071624756, 59.595095361982075, 62.38825035095215, 57.92187186649868, 58.31818321772984, 51.73316696711949, 21.90528518812997, 1.104626131909234, 0.07770709241075174, 0.03583550386662994, 0.12047936155327729, 0.15739626703517778, 0.22331802041402884, 0.43841643046055523, 0.05748505251748221, 4.088772118091583, 0.9799529761075974, 0.11396887233214718, 0.14788509240107878, 0.15369906542556627, 0.2543029284902981, 0.1658235498304878, 9.206326654979161, 33.917117255074636, 47.38104813439505, 17.838405541011266, 40.89647504261562, 19.06508047240121, 0.2595678988311972, 0.06144336797297001, 0.02389398473314941, 0.03276629659480282, 0.004566557214794946, 0.04974641491259847, 0.08171471700604473, 0.04255329571398241, 0.02699161074789507, 0.06160283048770257, 0.10077444676842008, 0.08115027086543185, 0.06472401693463326, 0.14129161834716797, 0.05080842738971114, 0.05272368068939873, 0.014523872440414769, 0.09355752116867475, 0.07779645547270775, 0.39813821177397457, 0.11280041467398405, 0.04338332046089428, 0.2210887207516602, 0.2925028758389609, 0.6694766304322651, 1.9323854403836387, 64.09787545885358, 50.988941941942485, 47.855867181505474, 36.369181701115195, 19.236963272094727, 41.261095660073416, 4.170726120471954, 0.21170212514698505, 0.08602680026420526, 0.05604099089811955, 0.0401934052019247, 0.09396703740847961, 0.24999960511922836, 0.924612962773868, 0.16336915296103272, 0.1580575808350529, 0.09498532169631549, 0.17172029055655003, 0.03887846879661083, 4.6167223027774265, 54.50875343595232, 64.5811435154506, 73.10654844556535, 69.36549241202218, 70.64504487173897, 68.72183908735002, 70.03135912758964, 65.09392751966203, 70.14898518153599, 68.94284043993268, 66.84055178506034, 68.68515259878976, 71.04173837389264, 66.45927633558, 63.86696597508022, 63.53154863630022, 59.03136716570173, 59.61647496904646, 62.69337354387556, 62.449345861162456, 62.10722351074219, 57.86716175079346, 57.784023080553325, 58.854917662484304, 59.618510791233604, 56.60639722006661, 59.960973603384836, 58.37187194824219, 54.417989117758616, 54.54537044252668, 53.94458055496216, 52.0593501499721, 53.41935232707432, 52.646372182028635, 52.9472222328186, 52.10448912211827, 57.017271995544434, 51.00493669509888, 52.51967872892107, 53.24976069586617, 51.427956921713694, 54.047205448150635, 54.33124433244978, 51.47976269040789, 54.12371553693499, 60.714276450020925, 67.62271050044468, 66.79278291974748, 63.75421755654471, 52.01356152125767, 56.836035183497835, 61.82355635506766, 58.18917601449149, 63.60777037484305, 62.35718495505196, 66.19436931610107, 62.84517778669085, 63.94067941393171, 58.7261050088065, 57.52481705801827, 51.54978663580758, 55.081003597804475, 54.34266022273472, 60.90026582990374, 61.953466824122835, 53.109653745378765, 50.127896853855674, 47.72853102002825, 47.83861827850342, 48.88192156382969, 49.046937806265696, 44.910042898995535, 43.02205753326416, 46.98099170412336, 49.9013022014073, 46.838251386369976, 45.51452228001186, 46.00355734143938, 47.04136460168021, 47.44249452863421, 48.285331862313406, 48.53959771565029, 46.371863978249685, 47.4863862991333, 48.01441465105329, 48.47807836532593, 48.073748792920796, 46.07688168116978, 49.43237522670201, 48.57224382672991, 49.36590528488159, 49.591443811144146, 46.81636803490775, 49.19787352425711, 53.98554365975516, 55.79924930844988, 57.96721928460257, 57.145101479121614, 58.18702902112688, 58.233911991119385, 58.09390926361084, 59.29087543487549, 62.36778790610177, 61.353684425354004, 64.27538108825684, 60.79554258074079, 62.16177381787981, 57.307765756334575, 28.26910032544817, 1.3851490105901445, 0.06388125608542136, 0.15326001255639962, 0.07129504505012717, 0.12002422740416867, 0.06564153198684965, 0.6787710945521082, 0.0548777104621487, 1.6452941255910056, 1.0185463109186716, 0.44319581400070873, 0.27978471400482313, 0.09477976629776613, 0.36919101221220835, 0.24727140579904827, 9.234261887414114, 35.932362352098735, 50.63431283405849, 19.05471897125244, 48.05045148304531, 30.38646309716361, 0.231387091002294, 0.07540720475039311, 0.1049838133954576, 0.036821856296488216, 0.02137963250944657, 0.07734826273683991, 0.08054624577718121, 0.08136655390262604, 0.010035664391969996, 0.144258105595197, 0.14172745496034622, 0.029654426433678185, 0.07544513485793557, 0.31374126619526316, 0.16568705572613648, 0.19883080438843795, 0.14302318543195724, 0.1322373691946268, 0.21264323964715004, 0.49679484218358994, 0.20944177572216305, 0.14315547261919292, 0.3385441909943308, 0.37204951739736963, 0.6994911112955638, 2.3697682448795865, 72.17539950779506, 59.700756617954795, 47.40904590061733, 60.356930596487864, 26.30718960080828, 51.73388263157436, 6.459569999149867, 0.33741239458322525, 0.22137354261108808, 0.29778011409299715, 0.21395875619990484, 0.3937506414949894, 4.090138741901942, 14.659359761646815, 0.7019957197563989, 0.3894540491913046, 0.4557591070021902, 0.3486845982926232, 0.1541489205722298, 7.419729403087071, 61.32375158582415, 69.07422392708915, 78.65633174351284, 76.5566417149135, 78.74018955230713, 74.29669843401227, 75.67718737465995, 71.55635670253209, 72.0271805354527, 73.71358476366315, 72.70422690255302, 74.50733307429722, 77.47383866991315, 69.90542302812848, 65.90622057233537, 68.30340467180524, 65.08747959136963, 64.67194257463727, 66.06474372318813, 66.19692625318254, 64.90572166442871, 63.75544738769531, 59.73340620313372, 63.886469568525044, 63.393960407802034, 59.00875077928816, 65.59453133174351, 62.459900174822124, 58.924566405160085, 58.260210922786165, 56.43059737341744, 56.430044991629465, 56.40363836288452, 55.169183186122346, 55.44693742479597, 56.34508241925921, 60.18707493373326, 53.81528500148228, 58.68585409436907, 57.285837241581504, 54.09983457837786, 58.6467079435076, 59.395550046648296, 53.73637431008475, 58.555867195129395, 61.464091300964355, 71.22552517482212, 69.55866622924805, 64.92929690224784, 53.84555830274309, 57.96446432386126, 60.70373603275844, 62.83615902491978, 65.95133522578648, 65.21594483511788, 70.99533830370221, 65.13025270189557, 65.50173813956124, 63.849234172276084, 58.30946322849819, 55.34329114641462, 59.28757504054478, 58.992318289620535, 64.90369973863874, 62.43392086029053, 54.147704192570274, 53.834291798727854, 51.69250610896519, 51.641151973179404, 52.91600745064871, 52.67663506099156, 48.756041049957275, 48.06999676568167, 49.761028494153706, 55.990908418382915, 50.93077857153756, 48.0497601372855, 49.04267856052944, 50.650470869881765, 51.19223928451538, 51.3201139313834, 50.368294102805, 49.50484841210501, 49.48351049423218, 49.52926090785435, 52.67242792674473, 52.5079779624939, 48.805279459272114, 54.21556377410889, 51.98627247129168, 52.83243799209595, 53.858645234789165, 50.46910204206194, 51.69396870476859, 56.03153453554426, 59.53161661965506, 60.14166150774275, 60.89411667415074, 61.167021070207866, 59.288985524858745, 61.05857358660017, 63.80160427093506, 66.13012627192906, 64.67631993974958, 68.66373825073242, 62.55274895259312, 66.652498790196, 59.74991512298584, 42.719185556684224, 2.1019536214215413, 0.35990965738892555, 0.46781982268605915, 0.3952341361769608, 0.3457617951290948, 1.3312585651874542, 2.743023519005094, 0.4287635370024613, 7.151984044483729, 1.1077577067273003, 0.31296608064855846, 0.6354854458144733, 0.3372427879699639, 0.5435303258044379, 0.5312834201114518, 13.937175290925161, 49.0805983543396, 71.44374029976981, 34.28335680280413, 58.313652992248535, 29.461518900735037, 0.4656412367309843, 0.16862953640520573, 0.1447976359299251, 0.2320191870842661, 0.11030331759580544, 0.16954547725617886, 0.30103550798126627, 0.2800353376993111, 0.10832974421126501, 0.19841612449714116, 0.1277291825307267, 0.0870109067431518, 0.27791269017117365], [0.6277281620672771, 0.26918624128614155, 0.2621247816298689, 0.05506279445918543, 0.05240534259272473, 0.1531289874442986, 0.4211531696575028, 0.579991052193301, 0.2391184547117778, 1.185272787298475, 9.896695324352809, 10.718761018344335, 23.03192343030657, 65.67018331800188, 45.36775895527431, 23.997907161712646, 31.53431592668806, 15.805089916501727, 32.62631566183907, 3.293031628642763, 0.13067711863134587, 0.08740409064505782, 0.041002761772168536, 0.04499333817511797, 0.23462883276598795, 0.3195042812398502, 1.3780079994882857, 0.12270046451262065, 0.17222526988812856, 0.10163753652679068, 0.08464444801211357, 0.11258523764887027, 1.6898638882807322, 24.617445026125225, 43.138804640088765, 65.09778376988002, 57.53476340430123, 61.56852967398507, 61.144939695085796, 66.32773998805455, 62.47165652683803, 67.577894619533, 65.60057626451764, 65.66229711260114, 65.1659803390503, 65.8604736328125, 65.30144241877964, 61.726191248212544, 58.55902862548828, 56.30861827305385, 59.389581544058665, 59.22871685028076, 58.48273740495954, 58.243309429713655, 53.2425206729344, 58.13995497567313, 56.95977912630354, 53.60419872828892, 57.72024556568691, 53.395721503666465, 51.262593269348145, 50.47245454788208, 49.246403217315674, 48.25329719270979, 50.668452807835166, 50.667740617479595, 51.34558950151716, 50.61083139692034, 46.90343591145107, 51.432441983904155, 50.109369482312886, 46.90463447570801, 48.640593256269185, 46.81030225753784, 47.95370823996407, 47.78769145693098, 47.111791542598176, 52.575153146471294, 60.83341721126011, 62.54354953765869, 62.67616285596575, 59.85317925044468, 61.281541279384065, 53.26955958775112, 63.096223149980815, 57.74294185638428, 56.34791381018502, 60.27362864358084, 58.33318437848772, 59.137188230242046, 56.790065901620046, 55.777918338775635, 41.191714423043386, 45.93348823274885, 52.347405093056814, 53.8326416015625, 56.352541310446604, 58.35717650822231, 56.64953163691929, 45.402086530412944, 47.21155030386788, 46.26892294202532, 44.35298844746181, 42.503263337271555, 42.25653280530657, 41.62431274141584, 44.84453875677926, 45.89820875440325, 43.209349700382774, 43.673346928187776, 45.80241741452898, 44.158616065979004, 44.594097886766704, 43.59714256014143, 45.517030579703196, 43.69572360174996, 44.52173934664045, 44.2950439453125, 45.52534062521798, 47.38950409208025, 44.36993162972586, 45.062114647456575, 46.66205896650042, 46.94660159519741, 45.28723628180367, 45.63545915058681, 46.42940895898001, 48.48058319091797, 52.49915722438267, 54.189330850328716, 55.662762369428364, 54.3163161277771, 55.97187382834298, 55.1608418737139, 53.00729635783604, 55.71689231055123, 57.748521259852815, 59.15987409864153, 58.36597292763846, 59.77251761300223, 52.37158135005406, 12.867712037903921, 2.2971389421394894, 0.14630669781139918, 0.07938091616545405, 0.12982975052935736, 0.22778073166097912, 0.08606049631323133, 0.2150565715772765, 0.054150208963879516, 0.08564498860921178, 0.0810455729120544, 0.058749095403722355, 0.34627525614840643, 0.020450718068916882, 0.1283924097993544, 0.013744917631681477, 3.0444550471646443, 24.995652845927648, 15.103813443865095, 23.888386181422643, 26.487387657165527, 45.88658094406128, 0.8721442925078529, 0.1374105473182031, 0.10419458895921707, 0.051467179719890864, 0.046336108086896796, 0.07223960650818688, 0.059950082030679495, 0.1845266076603106, 0.07287737514291491, 0.2151646622057472, 0.4007867510829653, 0.14043590426445007, 0.08983085078320333, 0.22003456231738838, 0.17997546972973005, 0.23233305024249212, 0.1356449584875788, 0.04231296539572733, 0.12370451992111546, 0.5807434661047799, 0.6497202962636948, 0.5474875420331955, 1.902397015265056, 14.185159972735814, 14.808410780770437, 35.19294548034668, 71.65428461347307, 57.44920676095145, 37.11778061730521, 31.5466559273856, 18.410191910607473, 38.40341622488839, 3.784233008112226, 0.2659664297742503, 0.11268029361963272, 0.03547048595334802, 0.02054631008234407, 0.06870428299797432, 0.11871344702584402, 1.0787438750267029, 0.07009766822946922, 0.13415820683751786, 0.11524265898125512, 0.13876009918749332, 0.07435342629573174, 2.4370196419102803, 30.91293157849993, 47.67838587079729, 69.50864614759172, 64.07145840781075, 65.44805635724748, 67.04491915021623, 70.81126662663051, 67.63744068145752, 71.5999983378819, 69.10611615862165, 68.47261415209088, 69.16467557634626, 70.65281990596226, 67.46356201171875, 66.27390534537179, 60.814545903887065, 58.738021169389995, 63.8269374029977, 62.569792883736746, 60.81365653446743, 60.83595330374581, 57.53361695153372, 61.15886388506208, 60.058873721531455, 58.76969105856759, 61.03869479043143, 56.97337327684675, 55.230855396815706, 54.05369506563459, 52.543135847364155, 50.65623092651367, 53.0798841885158, 55.0948166166033, 54.794706548963276, 54.50219781058175, 50.08453662054879, 53.856262002672466, 53.03357791900635, 50.784484250204905, 51.81496810913086, 50.82173701695034, 49.916692461286274, 51.13610826219831, 52.54612704685756, 56.97334548405239, 64.10143988473075, 65.25468104226249, 66.46994876861572, 59.447918619428364, 63.120611327035085, 56.54856388909476, 61.517884254455566, 61.25613866533552, 59.62199878692627, 63.565011160714285, 60.64414133344378, 63.047328676496235, 56.863775866372244, 58.420113291059224, 44.53929049628121, 48.00983231408255, 54.666995184762136, 56.83104290281023, 59.328270639692036, 61.238879340035574, 59.13637529100691, 48.570301805223735, 50.84069865090506, 48.44230209078108, 45.908881187438965, 45.77888734000069, 44.17299883706229, 45.39942537035261, 49.410464082445415, 48.43554844175066, 45.00495876584734, 48.12744099753243, 49.411954471043174, 47.22497769764492, 48.08403560093471, 45.67277445111956, 47.83031865528652, 46.461533955165315, 46.750280244009836, 47.80889735903059, 48.775291034153526, 50.964046546391074, 48.708095005580354, 46.827248913901194, 49.95712055478777, 50.65046044758388, 49.85846308299473, 48.877655369894846, 48.48421709878104, 51.866919789995464, 56.212423937661306, 57.0391275542123, 57.43647418703352, 58.74052946908133, 57.94904279708862, 59.26944024222237, 54.554555961063926, 58.27013989857265, 60.00147465297154, 61.49935340881348, 60.779797962733674, 63.41807065691267, 55.02654709134783, 22.187086752482823, 1.5259349303586143, 0.12168614965464387, 0.03894220359091248, 0.08491684589534998, 0.1951384882309607, 0.04625660074608667, 0.1728371727679457, 0.0857795760301607, 0.3323291359203202, 0.27689241777573315, 0.6088024090443338, 0.8813451730779239, 0.024242493889427612, 0.2196056739028011, 0.01657885136747999, 2.928916709763663, 30.024983065468923, 19.126756157193864, 29.451537813459122, 31.731721196855815, 59.749387059892925, 4.384975126811436, 0.3769726689372744, 0.22980040471468652, 0.012521630951336451, 0.06233195707734142, 0.06653252310518708, 0.07667074552071945, 0.15151507833174296, 0.12148142206881728, 0.39202181569167543, 1.2455139947789056, 0.41018364684922354, 0.3108071450676237, 0.6255930566361972, 0.37730517823781284, 0.5080865334187235, 0.20765774430973188, 0.15430885127612523, 0.22047566436231136, 0.763515830039978, 1.1161054245063236, 0.422720124146768, 1.5674345663615634, 13.941979970250811, 14.497889706066676, 39.2307243347168, 83.11866637638637, 63.15248271397182, 34.54878841127668, 51.62701933724539, 29.552974564688547, 49.69083431788853, 5.293981458459582, 0.4296425384070192, 0.20385242493024894, 0.21225331271333353, 0.19401392500315393, 0.6378111924443925, 1.7357927837542124, 5.273566348212106, 0.21695531611996038, 0.3140534737280437, 0.5241594538092613, 0.20039082424981253, 0.22404194942542485, 5.092273950576782, 54.81850412913731, 58.51119722638811, 77.23090880257743, 69.2802380153111, 71.32507201603481, 72.77892003740583, 76.42228439876011, 70.45914581843785, 76.12082290649414, 72.08037594386509, 72.44674055916923, 74.19362190791539, 76.0864918572562, 71.61467293330601, 71.91532843453544, 66.29859924316406, 63.013094902038574, 66.67719268798828, 66.676178250994, 64.16032586778913, 65.7826121194022, 60.66345732552664, 65.28954710279191, 64.53774506705147, 61.114180019923616, 64.79530089242118, 60.007304191589355, 57.48809582846505, 58.75014577593122, 54.00424473626273, 54.03655733380999, 56.14761808940342, 58.33170441218785, 56.79364422389439, 56.8366049357823, 51.610291549137656, 60.17516572134835, 56.91778073992048, 54.58799416678292, 56.12428951263428, 54.30270113263811, 53.45753615243094, 53.22096388680594, 54.130274636404856, 59.68982710157122, 64.92450264522007, 68.84196649278913, 67.7425182887486, 63.20438575744629, 63.61797727857317, 62.78539548601423, 65.22677707672119, 60.590577670506065, 62.516368184770855, 64.54330362592424, 64.5694705418178, 64.34782995496477, 61.307207924979075, 60.605842862810405, 44.92596122196743, 48.998168400355745, 56.45867504392351, 57.507276330675396, 60.10707337515694, 63.55384540557861, 60.961243220738, 48.79535395758492, 54.62715768814087, 52.88341692515782, 50.72132165091378, 50.18479912621634, 48.07216460364205, 48.24033185413906, 53.401759488242014, 51.9999361038208, 45.79518781389509, 48.557833262852256, 50.88199874332973, 49.07757241385323, 51.201494285038535, 48.30812195369175, 51.123674460819785, 49.32460519245693, 48.606488023485454, 50.694598879132954, 52.532605852399556, 55.53438050406319, 51.22684826169695, 51.83379772731236, 53.97002138410296, 54.28931195395333, 51.49769599097115, 53.84184101649693, 51.31031002317156, 54.33327668053763, 58.49735641479492, 59.01406615121024, 60.093517439705984, 60.58691596984863, 60.49212864467076, 61.95853206089565, 57.15771245956421, 63.02332265036446, 62.68725912911551, 67.15532602582658, 61.25826481410435, 67.44059821537563, 58.14202206475394, 39.01999241965157, 3.780452753816332, 0.3293011055460998, 0.21915196467723164, 0.3161008852933134, 0.4247726925781795, 0.20309817897421972, 0.4274515759732042, 0.20192254920090946, 0.1714020033500024, 0.20922153682581016, 0.4512622925852026, 0.6438017338514328, 0.16506800108722278, 0.21346244854586466, 0.15632696369928972, 4.850702456065586, 38.91488701956612, 26.698487826756068, 43.20662600653512, 37.10428374154227, 66.01197215488979, 2.29478480560439, 0.5814827978610992, 0.24666878527828626, 0.1299626212567091, 0.16314746199973992, 0.15800618859274046, 0.24260634183883667, 0.3329656289092132, 0.27171307855418747, 0.2669867564524923, 0.6348740043384689, 0.22126717546156474, 0.23992436432412692], [24.513539927346365, 12.104458502360753, 9.68566984789712, 1.027435879622187, 0.10585638228803873, 0.6684947631188801, 7.633013912609645, 19.296259198869976, 29.608876296452113, 48.02242939812796, 49.62936360495431, 57.20257002966744, 53.542349338531494, 46.18956061771938, 35.31652614048549, 36.62136309487479, 29.220548425401958, 21.3478399004255, 43.07886947904314, 0.9263874675546373, 0.15423556949411119, 0.24803155500973972, 0.08106313339833703, 0.09114147509847369, 0.025655532887737666, 0.16422661766409874, 0.4159781459186758, 0.1362175199070147, 0.13090224297983305, 0.039669240292693884, 0.05907665139862469, 0.10869149158575706, 0.2664646916091442, 4.7696187155587335, 15.549656765801565, 58.683053970336914, 57.08375235966274, 59.43209062303816, 60.911952699933735, 65.0437684740339, 64.02910218920026, 67.19786984579903, 64.90063558306012, 65.80635411398751, 65.55402333395821, 63.34262016841343, 66.38852977752686, 59.72096197945731, 56.407234055655344, 56.737144947052, 59.07951123373849, 59.508972440447124, 60.08504063742501, 54.35669558388846, 56.01161057608468, 58.46576990400042, 55.10514858790806, 57.21479885918753, 56.102583340236116, 53.06472321919033, 50.37657982962472, 49.3908041545323, 48.49030719484602, 51.059869153159006, 51.056214400700156, 50.56905535289219, 49.43818392072405, 48.69290624346052, 49.08434690747942, 47.199814796447754, 48.66506481170654, 49.37366642270769, 47.781660420554026, 49.02836527143206, 47.60092387880598, 45.64558962413243, 49.66239186695644, 57.25502545492989, 62.46073395865304, 61.292158126831055, 60.55569076538086, 54.71202993392944, 63.07943630218506, 57.96085820879255, 62.12786660875593, 60.397508076259065, 53.02527134759085, 59.75498730795724, 57.68246126174927, 60.118704659598215, 52.89568396977016, 54.067528929029194, 49.534683976854595, 53.587411880493164, 56.872155393872944, 54.30649137496948, 58.33314963749477, 57.50628273827689, 56.504991735730854, 50.359497683388845, 46.74363429205758, 45.97768919808524, 42.32868637357439, 41.54437371662685, 43.613029616219656, 43.390913077763145, 42.374221393040244, 46.55824940545218, 45.06692280088152, 44.364928926740376, 45.79660177230835, 44.27915688923427, 44.05610581806728, 43.37140253611973, 43.9408734185355, 45.28419644492013, 43.61530862535749, 43.25676073346819, 44.067580768040244, 42.72437238693237, 45.67948293685913, 43.76057808739798, 45.19689580372402, 48.292756012507844, 48.49638339451381, 46.71743263517107, 45.1975975717817, 51.02373504638672, 55.71213279451643, 56.518540722983225, 55.45553582055228, 55.63964918681553, 55.046043736594065, 57.580961976732524, 55.92802722113473, 54.96853658131191, 57.98085165023804, 61.52852889469692, 59.47475256238665, 64.41167000361851, 46.144869804382324, 17.803393568311417, 1.5621224514075687, 0.1155106531722205, 0.06331797702504055, 0.0360901037763272, 0.04012911400890776, 0.097175829511668, 0.0733738388600094, 0.004725871724076569, 0.3062118616487299, 0.6381889464599746, 1.332215462412153, 0.22239549777337483, 0.07138906964766127, 0.17597448799226964, 0.05385420484734433, 0.8427132431949887, 19.74691935947963, 23.88189308983939, 10.916158471788679, 18.62632778712681, 34.29076010840279, 34.94043057305472, 0.3017723970115185, 0.025616600244705166, 0.045526982218559296, 0.06534963979252748, 0.07530240501676287, 0.3192411725010191, 10.215429169791085, 24.663014786584036, 30.684172562190465, 32.64033017839704, 35.46896266937256, 30.524370942796978, 34.116857119968955, 19.486202103751047, 15.284843547003609, 2.26597974555833, 0.08480019215494394, 1.5783971952540534, 15.70912139756339, 31.788029398236954, 48.56293671471732, 68.6660658972604, 68.55919565473283, 72.88474805014474, 63.24783979143415, 52.89227587836129, 44.576081207820344, 33.24511180605207, 27.585298572267803, 24.07642354284014, 49.938172817230225, 0.6639066178883825, 0.04424637968518904, 0.07419684755482844, 0.08660873903759889, 0.05105326996584024, 0.08625653865081923, 0.07205818660025086, 0.17874345369637012, 0.021510649139859846, 0.12253491553877081, 0.027763004980183074, 0.06447062481726919, 0.09326226344066006, 0.16576344519853592, 4.7086278625897, 27.73595288821629, 64.85518046787807, 64.06192547934396, 65.61289542061942, 65.7131301334926, 71.18717111860002, 66.5911670412336, 72.62331512996128, 67.9877827508109, 67.78076812199184, 69.40608378819057, 68.80995614188058, 68.54036603655133, 64.89375686645508, 61.05600275312151, 61.28075613294329, 61.601860182625906, 62.27753775460379, 62.3080472946167, 56.99507597514561, 59.416498865400044, 60.743646485464915, 59.641752515520366, 60.06910146985735, 58.28072200502668, 56.2826042175293, 52.54311500276838, 53.16963406971523, 53.32467269897461, 53.52883161817278, 53.7529422896249, 52.66471890040806, 51.98968056270054, 50.70313474110195, 50.291909081595286, 50.74861070087978, 51.9395249911717, 52.89000381742205, 51.19525132860456, 53.98386914389474, 52.42373105457851, 49.754663944244385, 53.60869073867798, 59.57249287196568, 64.81173338208879, 64.03150626591274, 61.20953709738595, 58.663168225969585, 64.4391987664359, 59.965816497802734, 66.63880389077323, 63.062496594020296, 57.266500404902864, 62.52342755453927, 61.47041416168213, 61.766629764011924, 57.700801031930105, 55.729468550000874, 48.997661181858604, 56.337560994284495, 59.483111245291575, 54.696139403751914, 59.71761989593506, 60.13838195800781, 60.065099307468955, 52.24854959760393, 50.22864920752389, 47.27586283002581, 46.15045963014875, 46.751332896096365, 46.22588927405221, 47.243762152535574, 47.160797187260215, 48.43287338529314, 48.90482630048479, 46.70316103526524, 47.515975202832905, 45.264241218566895, 45.93014962332589, 45.97119958060128, 46.11871331078665, 46.96488230569022, 46.523181847163606, 47.923577376774375, 47.277401856013704, 46.99013900756836, 47.99787793840681, 49.40692744936262, 47.88743979590279, 51.53457008089338, 50.92146451132638, 50.56091901234218, 47.400061879839214, 53.23046554837908, 56.97247348512922, 58.097960063389365, 59.01977757045201, 57.84043550491333, 56.49270732062203, 60.32286357879639, 58.24284042630877, 58.62562710898263, 58.622625487191335, 62.12113380432129, 60.28067411695208, 68.26889296940395, 47.08976922716413, 33.273085253579275, 4.9279473168509345, 0.3322046383150986, 0.0586281329659479, 0.0910947783184903, 0.03017400105350784, 0.19178622668342932, 0.02552567485586873, 0.027466257867802466, 0.5247707324368613, 0.6707845202514103, 1.1982338918106896, 0.849174687904971, 0.3605259300342628, 0.06024470193577664, 0.07974120468965598, 0.8343269846269062, 21.372210706983292, 28.433208090918406, 17.3295316355569, 22.19663531439645, 36.432698658534456, 50.82923412322998, 1.1947011670895984, 0.13734737570796693, 0.03986898743148361, 0.047070320296500406, 0.015155337484819549, 0.9561814516782761, 15.491012232644216, 36.11425576891218, 43.59693758828299, 45.08459554399763, 49.43637044089181, 44.412218366350444, 28.645169837134226, 16.91649423326765, 12.492742947169713, 1.8035952597856522, 0.2699385466320174, 1.2580607043845313, 14.118408628872462, 30.36714015688215, 47.875909260341096, 70.23580292293003, 72.91658469608852, 81.99241897038051, 70.88161713736397, 65.66152586255754, 51.378426688058035, 58.01299054282052, 52.50130769184658, 35.667344161442344, 65.42120851789201, 1.2156291412455695, 0.2497745214828423, 0.35346362899456707, 0.1639287679323128, 0.22051704142774853, 0.23896179454667227, 0.30502838801060406, 0.6805410938603538, 0.23751396366528102, 0.17127514444291592, 0.14237958139606885, 0.13089195638895035, 0.23182854588542665, 0.41995286835091455, 7.146249175071716, 47.31343868800572, 71.22239153725761, 69.10594245365688, 68.82331057957241, 70.81823566981724, 75.40608256203788, 72.01277691977364, 76.44278853280204, 72.22676753997803, 72.81008965628487, 73.89136137281145, 71.80015509469169, 72.45457117898124, 68.30199418749127, 64.95434515816825, 64.37196799686977, 65.65670381273542, 67.37640380859375, 66.38368688310895, 62.50010940006801, 62.59067222050258, 65.10268224988664, 62.41402121952602, 61.177721296037944, 63.67161737169538, 59.500655446733745, 57.25385815756661, 57.32824904578072, 56.335219451359336, 58.33274664197649, 56.485981464385986, 56.67518091201782, 55.344177041734966, 53.38830777576992, 54.60085180827549, 54.21460839680263, 54.79497752870832, 57.903483458927695, 54.90502309799194, 57.79465382439749, 54.963325432368684, 53.45061574663435, 54.83401598249163, 61.85252339499337, 67.03485815865653, 67.5593568256923, 65.65266690935407, 60.60900429316929, 66.1002698625837, 63.260471616472515, 63.26209054674421, 61.60967690604073, 59.83288356236049, 64.03420911516461, 64.68837506430489, 64.26144995008195, 59.005061285836355, 57.52930212020874, 51.6338528905596, 58.04391002655029, 62.98004232134138, 59.80661242348807, 63.0364408493042, 62.051234926496235, 62.68839863368443, 54.82241249084473, 51.17196791512625, 52.01327664511544, 49.36569683892386, 49.98289489746094, 50.47161381585257, 50.967736039842876, 50.2616913659232, 53.502105372292654, 50.85276767185756, 48.9108121735709, 49.6539671761649, 46.25252171925136, 48.30763210569109, 48.542151178632466, 48.601884841918945, 49.74638169152396, 49.099177837371826, 50.178493635995046, 50.63122435978481, 49.13350888660976, 49.976572036743164, 49.916511808122905, 51.85816158567156, 52.12799487795149, 54.9147401537214, 53.535599163600374, 49.96607330867222, 55.83570303235735, 61.69839150565011, 60.5648832321167, 62.609529631478445, 61.052917752947124, 59.02906036376953, 62.60343606131417, 62.80287715366909, 60.98455442701067, 61.92978736332485, 66.4452896118164, 64.61946977887834, 71.23123659406389, 52.92983436584473, 44.39553574153355, 9.734710233552114, 0.6371015533804893, 0.1796096172183752, 0.15022527825619492, 0.2244165957506214, 0.33504124038985794, 0.09650332666933537, 0.15001015551388264, 0.4664238318800926, 0.977123322231429, 3.2085376254149844, 0.48278873945985523, 0.36212279434715, 0.2663743650274617, 0.2059867161193064, 1.1830303647688456, 31.97206633431571, 37.82890442439488, 21.379728657858713, 29.019236530576432, 48.6063733782087, 53.28121171678816, 0.5198013048086847, 0.14689072647265025, 0.16542474765862736, 0.14884763503713266, 0.1323777309485844, 0.6958332104342324, 12.918857727731977, 35.636799880436485, 42.297287464141846, 44.64785262516567, 48.958080768585205, 43.47988823481968], [34.29226091929844, 43.17683213097708, 53.02273872920445, 27.578235728400095, 1.8358449978487832, 23.554622513907297, 21.331157275608607, 17.441642556871685, 23.99700563294547, 27.83515579359872, 27.76382384981428, 49.90292113167899, 49.64237758091518, 38.467589787074495, 36.04206051145281, 47.024675028664724, 20.650381462914602, 20.86475944519043, 26.960209097181046, 0.3415776496487004, 0.04662192739280207, 0.04739494162744709, 0.035909691492893865, 0.0697844632502113, 0.05222856725699135, 0.028384105402178, 0.136752436203616, 0.09884530385690075, 0.09657185192086867, 0.06306439491787127, 0.08602509035595826, 0.06698582520974533, 0.41771565697022844, 0.5169385384236063, 7.610189080238342, 54.65869556154524, 58.092953886304585, 63.13310418810163, 62.60980061122349, 65.0407738004412, 64.5048245021275, 67.80063302176339, 63.06226035526821, 67.61226735796247, 63.67295837402344, 63.53951127188546, 62.60200473240444, 61.637094497680664, 57.42476994650704, 59.254230635506765, 59.49914768763951, 60.96405724116734, 57.50955881391253, 56.12215641566685, 56.76713684626988, 56.39975431987217, 56.120197023664204, 59.040101051330566, 52.42456831250872, 52.57671996525356, 47.99552944728306, 48.59173699787685, 47.330096994127544, 49.63276822226388, 47.74781921931675, 51.57488005501883, 50.5842719078064, 49.34475844247, 48.2953268459865, 46.995450905391145, 48.18660838263375, 47.15558951241629, 48.2425274848938, 46.94578170776367, 47.87243863514492, 48.46888242449079, 48.53012384687151, 57.578853198460166, 60.971325056893484, 58.28859083993094, 57.056254863739014, 59.30248587472098, 59.636221749441965, 64.07552310398647, 58.772185461861746, 53.12844862256731, 64.0778090613229, 60.46370356423514, 60.74432046072823, 59.73886053902762, 57.6772084236145, 51.17537948063442, 51.870918478284565, 55.50785575594221, 55.61944382531302, 50.555165903908865, 56.63901901245117, 59.412399428231375, 59.244301659720286, 56.119047096797395, 46.637882709503174, 42.628879819597515, 41.5335692678179, 45.501473563058035, 42.754652636391775, 43.02229029791695, 42.952096121651785, 42.459076268332346, 44.05934020451137, 43.75159406661987, 44.82477460588728, 44.56792402267456, 43.54354068211147, 44.620028563908164, 43.693875380924766, 43.064174039023264, 43.189363207135884, 43.726187978472026, 45.778282846723286, 45.61991950443813, 46.59535278592791, 47.54422657830374, 43.75340059825352, 47.115300382886616, 49.62171711240496, 48.26575531278338, 45.8497485433306, 49.85185187203543, 50.33406032834734, 55.13102715356009, 54.83658334187099, 54.79257345199585, 54.71148450034005, 60.80511025020054, 53.80412966864449, 55.65222890036446, 56.65910972867693, 60.3974802834647, 55.942580223083496, 65.90792288099016, 37.705393246241975, 28.261097737721034, 7.951174531664167, 0.30174596128719194, 0.11914852367980139, 0.0812372997669237, 0.2187321414904935, 0.08246507495641708, 0.055834000398005755, 0.0992633221404893, 1.5072025869573866, 2.5321313611098697, 2.464376436812537, 1.043554614697184, 0.0788371382015092, 0.2181345285581691, 0.03436524401019726, 0.20303008119974816, 9.737867321286883, 26.938357012612478, 14.411267382758004, 25.039072138922556, 25.251384769167217, 40.93313373838152, 17.381408623286656, 0.12130866705306939, 0.08043760553534542, 0.10952598787844181, 0.4725767874291965, 24.92438691002982, 48.11849866594587, 34.05721378326416, 31.602053914751323, 26.631736482892716, 26.225834880556377, 27.682432651519775, 48.00694881166731, 55.57968275887625, 68.73119831085205, 39.157886368887766, 4.898408353328705, 47.89732708249773, 38.0390214238848, 31.230485098702566, 35.98222609928676, 39.80857127053397, 38.572309562138145, 57.64516333171299, 59.1611317225865, 44.28313473292759, 43.24815191541399, 45.63772078922817, 25.109473024095806, 28.385665042059763, 31.462693895612443, 0.22114825541419642, 0.04828314396685787, 0.07520422099956445, 0.016619914610471045, 0.04619775479659438, 0.04160455108753272, 0.06245690930102553, 0.1295670081994363, 0.028194826362388473, 0.05018260097131133, 0.06315887413386788, 0.0739111096731254, 0.09361469452934605, 1.1196543255022593, 0.22764262264328344, 16.143884079796926, 65.66575731549943, 63.05729239327567, 68.81918334960938, 66.22441332680839, 70.5521057673863, 69.3541737965175, 74.55351080213273, 66.80631801060268, 69.81420707702637, 66.41015951974052, 68.67039462498256, 64.99558966500419, 63.210590498788015, 60.929121698652, 61.57936191558838, 62.69059426443917, 62.616964203970774, 59.584999629429404, 61.11549322945731, 59.68665177481515, 60.49871553693499, 60.722218241010395, 60.55536420004708, 57.06078161512102, 55.384445326668875, 51.71757868358067, 51.55560575212751, 50.13728734425136, 53.218601499285015, 50.41970729827881, 53.97258874348232, 52.911928858075825, 50.26894875935146, 49.93508781705584, 50.59566000529698, 52.23811687741961, 50.91620125089373, 50.056656973702566, 48.851516246795654, 49.85823379244123, 51.571190561567036, 52.08610418864659, 60.250331333705354, 63.977803639003206, 62.579096521650044, 59.615821838378906, 61.675837653023855, 61.97424193790981, 66.10154833112443, 62.515117509024485, 58.62045764923096, 66.14404351370675, 62.14812755584717, 64.11468315124512, 60.43827315739223, 59.8666170665196, 54.195573806762695, 54.7983786719186, 58.58979524884905, 56.84770468303135, 52.12870012010847, 58.713188307625906, 59.063836097717285, 60.60143770490374, 57.521579197474885, 48.864849839891704, 46.8027252469744, 45.502863202776226, 47.34762382507324, 46.48157950810024, 46.987905161721365, 47.399301052093506, 44.47761828558785, 45.550180435180664, 45.08833714893886, 46.550547327314106, 47.6100538117545, 45.3827531678336, 46.431660175323486, 46.30358403069632, 45.17301137106759, 44.916921615600586, 44.97938939503261, 46.85654946735927, 48.429941245487754, 48.18569816861834, 48.49596650259835, 47.56030470984322, 49.23540421894619, 53.13320813860212, 51.63988740103585, 49.158550194331575, 50.95001465933663, 52.56305285862514, 56.951201575142996, 57.14997216633388, 55.69228526524135, 57.84159585407802, 62.30328777858189, 54.5787113734654, 58.04072080339704, 59.2668902533395, 63.02637985774449, 58.285207067217144, 67.93098817552838, 41.30282654081072, 43.19548109599522, 18.29492998123169, 0.329356636852026, 0.14599389316780226, 0.07421756322894778, 0.14733288703220232, 0.07308792455920152, 0.004219129049618329, 0.06735008994915656, 0.5387583247252873, 0.3685816606240613, 0.4711880705186299, 0.903154048536505, 0.2307337974863393, 0.274820796080998, 0.007975653279572725, 0.12920898598219666, 10.866953934941973, 29.5242646081107, 21.821020909718104, 35.2069148336138, 32.491249629429404, 45.405789920261924, 34.05902031489781, 0.06636818192367043, 0.07157441148800509, 0.09476639915789876, 1.3890211113861628, 34.477753502982004, 59.35518796103341, 42.435431548527305, 42.32621281487601, 35.61719901221139, 34.07477535520281, 37.167481081826345, 60.638992718287874, 65.03114359719413, 80.50067547389439, 45.485850538526265, 6.557098388671875, 58.66350868770054, 47.472034794943674, 45.721787043980186, 47.805617809295654, 47.179859570094514, 43.94416339056832, 67.05707849775041, 70.23871421813965, 57.40172624588013, 51.82875680923462, 73.14918954031808, 40.66845253535679, 32.90730081285749, 40.89483526774815, 0.3825131787785462, 0.1932376538004194, 0.19604027484144482, 0.14657997100480966, 0.21096613178295748, 0.07462118978479079, 0.13495507836341858, 0.48313397807734354, 0.26010117307305336, 0.2143051211855241, 0.19289066456258297, 0.1410550946103675, 0.14250668457576207, 1.1082366981676646, 1.0342718213796616, 28.594842297690256, 73.025817326137, 68.99714756011963, 71.94777652195522, 71.56183883122036, 76.18661539895194, 72.30760288238525, 79.42462880270821, 70.45897211347307, 74.90697956085205, 69.56866468702043, 71.49034881591797, 69.51037624904087, 67.42468684060233, 63.29110622406006, 65.50390597752163, 67.37791851588658, 66.61451993669782, 62.709069524492534, 63.509863308497835, 61.341518129621235, 64.11381462642125, 62.884664399283274, 63.934294019426616, 58.05368266786848, 60.31245517730713, 53.753977571214946, 54.60787296295166, 53.224663802555625, 56.07624271937779, 53.10090248925345, 57.26081330435616, 56.17539698737008, 54.052555561065674, 53.316300119672505, 53.79282494953701, 54.93889209202358, 55.6842496735709, 55.559998512268066, 53.58574431283133, 53.36824137823922, 56.30054794039045, 53.65840857369559, 62.74401896340506, 66.38476385389055, 64.69040393829346, 63.14764676775251, 64.26785618918282, 66.21439402444022, 68.72971139635358, 53.29919712884085, 60.021777289254324, 69.61758695329938, 65.13420622689384, 65.75684125082833, 64.21838501521519, 61.90724045889718, 55.88009507315499, 54.160089356558665, 60.93035847800118, 59.565648896353586, 56.40298523221697, 62.76076412200928, 64.36215019226074, 62.41681439535958, 60.067690985543386, 52.99802051271711, 49.40190042768206, 47.6172764641898, 54.141152041299, 50.643724169049946, 50.105871064322336, 50.172070026397705, 47.49627358572823, 49.48622376578194, 47.26951217651367, 48.385180950164795, 49.11654485974993, 47.41330167225429, 48.85575117383684, 47.703444549015586, 48.310480867113384, 46.70252527509417, 48.57763910293579, 50.157277311597554, 51.176762172154014, 51.88598217282976, 52.330444540296284, 52.1962331363133, 52.16296168736049, 57.602973869868684, 54.813484055655344, 51.62621334620884, 54.756811073848176, 55.81263848713466, 60.279882022312705, 59.69699764251709, 60.10254314967564, 61.27171652657645, 66.10892731802804, 55.70511163984026, 59.584402084350586, 63.71785763331822, 67.3581439426967, 60.326900482177734, 70.18561608450753, 49.67357151848929, 52.3575564111982, 24.671364784240723, 0.42490495262401445, 0.14002007086362156, 0.19341172517410346, 0.2530406362244061, 0.15391094477048942, 0.32237426723752705, 0.13221083847539766, 4.250042412962232, 7.1908223032951355, 4.488416433334351, 2.1659884367670332, 0.2021542824804783, 0.6585219268287931, 0.10850453483206884, 0.5204005326543535, 15.720735311508179, 44.61140932355608, 24.77134415081569, 42.293726512363975, 40.61768899645124, 60.199206488473074, 35.66283825465611, 0.1680562285972493, 0.16820330784789153, 0.14513025379606656, 1.2569703800337655, 35.777754511152, 66.47463185446603, 47.29395246505737, 48.005718980516704, 43.1337776184082, 41.725579261779785, 41.899697644369944], [27.0586998122079, 21.134823765073502, 32.823498589651926, 29.430693217686244, 10.639455148151942, 7.306859391076224, 12.472762533596583, 41.165061133248464, 38.499763420649934, 41.46983691624233, 47.23035560335432, 57.44783101763044, 47.36197880336216, 32.225324698856895, 40.83901344026838, 29.879234177725657, 22.292522192001343, 38.13427080426897, 22.964692660740443, 0.4778797285897391, 0.18391128496399947, 0.20847073782767567, 0.0627189798812781, 0.07336355226912669, 0.022052281236808215, 0.051485405170491765, 0.11129000929317304, 0.06197795857276235, 0.13827311460460934, 0.04346979635634592, 0.03727156216544764, 0.06095158614750419, 1.6851666889020374, 2.2014707156590054, 14.167963181223188, 48.33873919078282, 62.56288637433733, 61.91304915291922, 65.94868796212333, 64.94376305171421, 64.5179774420602, 68.31183978489467, 63.745254380362375, 65.52530642918178, 64.34450871603829, 60.92925371442522, 60.519712993076865, 59.161819594247, 57.52763455254691, 59.98487540653774, 60.54852717263358, 57.59032814843314, 52.88093989236014, 58.80839947291783, 58.887574195861816, 56.19446284430367, 57.39815834590367, 57.194906166621614, 53.228085790361675, 50.89072915485927, 47.95340599332537, 48.44560248511178, 47.95370129176548, 48.19296251024519, 47.187176023210796, 49.3015649659293, 47.60045140130179, 48.143918650490896, 46.14184386389596, 48.25470767702375, 50.93161930356707, 50.086120809827534, 48.62572758538382, 48.08572053909302, 45.18979821886335, 48.4717242377145, 48.0723591532026, 54.31407185963222, 61.602096421378, 61.35480308532715, 58.22426789147513, 58.799477985927034, 57.854116507938926, 66.81592736925397, 53.51715864453997, 56.74334968839373, 62.57915905543736, 61.70434611184256, 61.87272875649588, 58.99508367265974, 56.6922595841544, 54.78295714514596, 60.496603284563335, 53.69793687547956, 56.23092699050903, 51.80322217941284, 52.70071056910923, 59.763811520167756, 58.21035412379673, 51.195706435612266, 45.81910351344517, 43.14593696594238, 43.60352448054722, 42.284346444266184, 44.34719712393624, 44.835697174072266, 45.2511751311166, 42.87051037379673, 42.93066440309797, 44.18445989063808, 43.69547694069998, 43.3373042515346, 42.37844589778355, 42.62116731916155, 42.74676990509033, 40.679086753300254, 43.79837628773281, 42.72104072570801, 44.11217778069632, 45.637012072971885, 46.02805321557181, 44.434866019657676, 46.189195837293354, 46.49270009994507, 46.80125570297241, 48.04299259185791, 46.707951818193706, 48.69047089985439, 52.83557162966047, 56.09707689285278, 55.710517338344026, 54.34283740179879, 53.07089669363839, 58.120058809007915, 56.09395367758614, 57.803891454424175, 59.42123753683907, 58.724986348833355, 59.06314822605678, 63.81179033006941, 32.83157239641462, 42.14511496680123, 25.59005560193743, 1.4208288788795471, 0.16709336026438645, 0.07205578458628484, 0.028172259984005774, 0.07267023875777211, 0.04909178128998194, 0.08666618381227766, 0.7197808282715934, 0.48726104519196917, 0.6338830717972347, 1.8162379413843155, 0.4369671068021229, 0.20188886672258377, 0.04416055518335529, 0.040302082763186524, 4.618253077779498, 17.24398194040571, 22.38183954783848, 16.88357366834368, 28.08318737574986, 30.445300442831858, 31.91675172533308, 2.378888189792633, 0.1249188669025898, 0.07400547353816883, 11.23176736491067, 40.35931328364781, 38.007928235190256, 72.40829617636544, 84.14622156960624, 87.40064661843437, 86.31613009316581, 50.38300691332136, 31.276037488664898, 27.753632579530986, 43.70520441872733, 33.55407040459769, 27.793079239981516, 17.56561405318124, 25.631512028830393, 61.04687282017299, 57.95377104622977, 54.50822189876011, 54.2950998033796, 71.66155937739781, 58.0936313356672, 44.24293940407889, 47.236404010227744, 36.05576583317348, 25.54943643297468, 44.95989274978638, 26.861857346126012, 0.4098469034901687, 0.1354570992823158, 0.3409160780055182, 0.02315823394539101, 0.09740060102194548, 0.026836514606007507, 0.012510266337942864, 0.016393762281430618, 0.0467144863546959, 0.1635998955794743, 0.03840514990900244, 0.3096654691866466, 0.0323114168963262, 2.6743457870823995, 4.298107879502433, 22.824033328465053, 55.127601691654746, 66.49712317330497, 67.63120119912284, 69.5898358481271, 69.81498527526855, 67.20447758265904, 71.70420742034912, 67.40735108511788, 67.93238476344517, 68.48639937809536, 65.75454139709473, 63.03120885576521, 64.25683634621757, 60.56230545043945, 61.70426968165806, 63.989594732012065, 60.197254044669016, 55.43545552662441, 60.12473569597517, 63.43852615356445, 60.31558186667306, 59.14162812914167, 59.66996914999825, 55.992339747292654, 53.050211906433105, 52.05324615750994, 51.43107318878174, 50.153177874428884, 52.71830688204084, 49.733628273010254, 51.484098366328645, 49.27917787006923, 52.56717314038958, 48.495963028499055, 49.071617807660786, 52.54906613486153, 53.3733344078064, 52.66679988588606, 52.609748227255686, 49.00598859786987, 51.46962526866368, 50.89784063611712, 57.098076071058, 61.3430814743042, 61.863195828029085, 58.67035266331264, 64.40518038613456, 61.38123403276716, 71.14776788439069, 57.99389341899327, 59.60124451773507, 66.24331937517438, 62.43245479038784, 64.20050035204206, 63.609833989824565, 59.42176559993199, 54.84580707550049, 61.0722267968314, 56.18917179107666, 59.42526054382324, 54.642725127083914, 56.10458442143032, 58.906952721732004, 58.98062447139195, 54.75251708711897, 47.760881832667756, 46.437302112579346, 45.065957001277376, 47.825385434286936, 49.0632313319615, 47.69179936817714, 48.147055762154714, 45.275122097560335, 43.933817522866384, 46.45930705751692, 45.454326561519075, 46.94589287894112, 44.03755760192871, 45.3124235016959, 46.20625713893345, 43.979394231523784, 44.89847762244088, 45.825117179325645, 47.03797735486712, 47.559099197387695, 46.87618507657732, 49.61105162756783, 47.572217396327424, 50.98013857432774, 50.25912748064314, 51.07310199737549, 49.524883542742046, 51.86118752615792, 55.55034746442522, 58.9111772264753, 57.27181577682495, 56.85687630517142, 56.457483427865164, 60.55903284890311, 59.08819648197719, 59.84251376560756, 61.47396469116211, 60.85934094020298, 62.96857779366629, 63.19736807686942, 39.54150683539254, 51.996990067618235, 41.93571015766689, 1.3596940679209573, 0.2186519115098885, 0.039918313534664254, 0.01707968145741948, 0.1408152731933764, 0.07306501721697194, 0.025874579258795296, 0.1951138438390834, 0.2479923085442611, 0.20015983735876425, 0.8150969222187996, 1.3924021699598856, 0.18030525131949357, 0.10354517666356904, 0.004753994456093226, 4.864574100290026, 21.215799808502197, 24.851906776428223, 23.39065544945853, 39.7808792250497, 37.23774126597813, 48.65077584130423, 5.063035062381199, 0.2394015666629587, 0.05670666767816458, 17.19200767789568, 52.30716807501656, 49.55359697341919, 80.05577536991665, 90.00533866882324, 95.73194667271206, 99.2771121433803, 56.38633040019444, 35.49648448399135, 34.47265699931553, 50.610682010650635, 41.67751162392752, 45.795267718178884, 44.39792592184884, 52.023521763937815, 93.20105143955776, 85.39043549128941, 85.40021160670689, 70.09945842197963, 82.22695541381836, 68.43638624463762, 57.14014393942696, 60.39481217520577, 49.12642519814627, 36.82630368641445, 60.12780679975237, 34.664882387433735, 0.5803363450935909, 0.34514839947223663, 0.4381369011742728, 0.1167450983609472, 0.17793823618974003, 0.12003057849194322, 0.1770056848015104, 0.19292384492499487, 0.2508070075086185, 0.31419447330491884, 0.11084344504134995, 0.3561142310500145, 0.08354846467929226, 3.1093403654439107, 6.24510429586683, 32.7555695261274, 61.30517210279192, 70.37897055489677, 70.75329085758754, 73.5167909349714, 74.47081334250313, 70.92545332227434, 76.81377370016915, 70.07372924259731, 73.3419325692313, 72.42310973576137, 68.8452182497297, 67.35823426927838, 66.13829040527344, 63.462073598589214, 67.73049095698765, 69.34279959542411, 65.02846854073661, 59.297962597438264, 64.9243289402553, 65.04720783233643, 66.01168033054897, 62.651274408612935, 63.01299067905971, 60.23785236903599, 56.39360863821847, 56.496365547180176, 55.67246552876064, 53.18355131149292, 55.72244044712612, 53.50678150994437, 55.58631134033203, 52.173363140651155, 55.05932174410139, 51.27244928904942, 53.54074430465698, 57.7845789364406, 56.47700439180647, 56.99942554746355, 57.19017096928188, 51.600439003535676, 56.86480072566441, 53.955374581473215, 60.48055294581822, 68.32383237566266, 63.48679528917585, 64.7553904397147, 64.21726635524205, 65.82318265097481, 67.67779581887382, 56.314194202423096, 63.88417666299002, 68.75899110521588, 67.66895771026611, 67.95579324449811, 65.97492436000279, 62.37992640904018, 55.94904899597168, 64.36692360469273, 61.266081537519185, 60.70987824031285, 59.22017751421247, 59.110458510262625, 64.02549607413155, 63.304745537894114, 58.98206969669887, 50.65552568435669, 49.79358775275094, 49.23936469214303, 50.20005737032209, 51.441231455121724, 52.12146009717669, 51.30459860392979, 48.556308133261545, 47.234399454934255, 47.82038273130144, 48.55183349336897, 49.18231650761196, 46.64947577885219, 47.33375522068569, 47.26854985100882, 45.3005941935948, 48.270900453839985, 48.86465529033116, 50.99428858075823, 49.45043706893921, 51.62133223669869, 51.83598640986851, 52.9168620790754, 53.99208886282784, 54.65009021759033, 54.06613234111241, 51.79838275909424, 54.43472037996565, 56.917947496686665, 63.62286186218262, 60.57922431400844, 58.10935163497925, 58.90683460235596, 62.39692170279366, 61.707848003932405, 63.68354742867606, 66.30711773463658, 61.53884696960449, 66.53416401999337, 64.52179895128522, 48.09593439102173, 56.83712952477591, 54.381483282361714, 2.3439029242311205, 0.5528725587895938, 0.1938115315777915, 0.1295294173594032, 0.22227876260876656, 0.12342309073678084, 0.17406594540391648, 0.7745598288519042, 3.191015137093408, 2.506806045770645, 5.1455292872020175, 1.3009354323148727, 0.5747347942420414, 0.4604975070272173, 0.2693055277424199, 8.218223333358765, 28.923177685056412, 41.069756167275564, 27.462207760129655, 45.42197574887957, 42.770209653036936, 63.441562516348704, 6.023471959999629, 0.27069253474473953, 0.1900422288370984, 17.788098846163066, 61.130807059151785, 53.81252656664167, 93.981139591762, 108.26572568075997, 114.2806978225708, 119.13620322091239, 70.2074612208775], [89.40964875902448, 45.88853338786534, 45.13789864948818, 19.123436655317033, 14.920688458851405, 7.716062256268092, 16.834555864334106, 20.019509349550518, 40.69507803235735, 63.16055652073452, 56.57198279244559, 66.2369270324707, 49.0296367917742, 26.834590877805436, 42.1856472832816, 52.664295060294016, 28.940254620143346, 36.77978202274868, 13.784693598747253, 0.5286383277603558, 0.24653975505914005, 0.1389921988759722, 0.04646844955693398, 0.037716416509023735, 0.06366346670048577, 0.0714414661218013, 0.037459258522306166, 0.07338188628533057, 0.0393625424642648, 0.06698346390788044, 0.07777255068400077, 0.10142594216657536, 3.5926479399204254, 11.192608186176844, 35.586293424878804, 34.58071538380214, 69.41901438576835, 62.10654953547886, 68.87771497453961, 67.59977449689592, 64.01355906895229, 64.8181882585798, 66.14710072108677, 62.799048696245464, 61.82685674939837, 64.68524142674038, 62.60222707475935, 61.87312480381557, 59.54878561837332, 60.23210620880127, 60.67474814823696, 58.26550545011248, 55.97556332179478, 58.96071788242885, 54.753861563546316, 57.56728097370693, 55.18576158796038, 54.142673696790425, 53.05276189531599, 50.46981075831822, 46.53760283333914, 46.04923479897635, 46.65679918016706, 49.82217264175415, 46.635482106889995, 47.87430075236729, 46.501770973205566, 47.93636553628104, 48.20485087803432, 45.01637118203299, 46.36697244644165, 47.81082201004028, 47.87256022862026, 49.761712891714915, 47.10672630582537, 47.70884329932076, 45.34534754071917, 53.112019606998985, 55.09072412763323, 60.87890706743513, 58.02406597137451, 62.28966930934361, 59.354569571358816, 72.9429600579398, 45.782465662275044, 55.69760411126273, 62.13257053920201, 61.59284836905343, 61.04200908115932, 61.78874588012695, 57.71293258666992, 53.86458247048514, 54.027156421116416, 54.75385114124843, 53.73431764330183, 54.11238302503313, 51.64437246322632, 54.64923906326294, 55.40077359335763, 50.23173073359898, 45.12900495529175, 43.545319420950754, 44.05861759185791, 45.63240541730608, 41.05640172958374, 45.45549038478306, 45.185153348105295, 40.67268746239798, 41.49770266669137, 42.991721698216026, 44.18846900122506, 43.26326772144863, 44.10331187929426, 42.754267011369976, 42.027905804770334, 42.718869413648335, 42.892275605882915, 43.05082654953003, 45.18078293119158, 46.202855995723176, 46.02704920087542, 46.727392877851216, 44.98196717670986, 46.65536437715803, 48.024378367832725, 48.978042943137034, 46.731551374707905, 47.682659012930735, 51.8268460546221, 51.7487587247576, 56.04954774039132, 54.90547820499965, 52.97473362513951, 55.12596539088658, 54.38029861450195, 55.80103152138846, 58.96500492095947, 55.30347449438912, 60.83532796587263, 60.802900723048616, 31.937342711857386, 66.51152678898403, 34.744460105895996, 3.7476594277790616, 0.30646316387823647, 0.07285235755677734, 0.14380806045872824, 0.2752719947269985, 0.033922628832182715, 0.07713624089956284, 0.07437283918261528, 0.018402690733117715, 0.0723706791177392, 0.660179072192737, 0.07399350418043987, 0.16905755629496916, 0.0730515279408012, 0.06243934202939272, 1.8393527524811881, 12.834742835589818, 15.428825855255127, 11.204657231058393, 16.227943386350358, 31.487179347446986, 33.18823037828718, 5.036227609430041, 0.24614297492163523, 0.4091473067445414, 29.067547355379375, 46.239754404340474, 72.8439690726144, 65.35023961748395, 53.49360772541591, 48.24340990611485, 59.08451393672398, 90.9051651273455, 97.754303250994, 44.67547171456473, 54.12036650521414, 28.749495301927837, 23.215920414243424, 19.317121165139334, 30.084918226514542, 34.87612846919468, 58.21704871313912, 78.30298805236816, 65.61857904706682, 74.2041414805821, 56.494743142809185, 36.95232663835798, 49.63402584620884, 51.27466923849923, 31.3482084274292, 40.98384516579764, 15.556968007768903, 0.3851422034204006, 0.14985718657927855, 0.21494972945324012, 0.039525736921599934, 0.07806590851396322, 0.051354529336094856, 0.09831476411116974, 0.016983499118526067, 0.12608762990151132, 0.07549517681556088, 0.0833612365115966, 0.05548874142446688, 0.06468079425394535, 5.205747153077807, 14.171122006007604, 42.82904005050659, 40.24205895832607, 73.81143624441964, 67.85846287863595, 73.25504534585136, 70.17697947365897, 64.86677701132638, 65.98695169176374, 70.1200042452131, 67.14930193764823, 63.99231147766113, 65.03112970079694, 66.51879460471017, 65.12960651942662, 63.87836102076939, 63.040998867579866, 64.19918019430978, 58.14056294304984, 57.96705600193569, 62.412728854588096, 60.014558110918315, 61.04309300013951, 60.14041083199637, 57.92772224971226, 55.09941632407052, 54.73249237877982, 48.96964257104056, 49.43594660077776, 49.49314417157854, 52.27174963269915, 51.8087077822004, 50.76959426062447, 49.46377761023385, 51.53038379124233, 48.535751887730186, 48.45088311604091, 49.69207804543631, 51.517147472926546, 51.4807528087071, 52.575507504599436, 50.01839324406215, 49.08472558430263, 47.495085443769185, 56.0381110055106, 60.015614237104145, 58.92770004272461, 58.475302832467214, 64.31217179979596, 60.641730308532715, 73.07947131565639, 52.10241855893816, 57.45803097316197, 65.58565153394426, 63.86299160548619, 62.71088300432478, 63.70102909633091, 60.595705441066194, 55.95127589362008, 60.186275890895296, 56.68297331673758, 56.931204659598215, 57.649426051548545, 54.64398275102888, 57.53195980616978, 58.994222096034456, 53.734810965401785, 48.06157207489014, 48.076354367392405, 47.57463189533779, 48.208463941301616, 45.18479551587786, 49.22290093558175, 46.641888345990864, 42.605092661721365, 43.63835232598441, 43.8273537499564, 47.03685174669538, 44.743289606911794, 46.21010296685355, 45.96318135942732, 43.728519099099294, 44.835884775434224, 43.21404668263027, 43.883265904017854, 46.28753021785191, 48.66484594345093, 50.46671533584595, 49.10261719567435, 48.408068316323416, 49.33090720857893, 49.148232119424, 51.89870432444981, 50.62951857703072, 48.49730403082711, 52.786885602133616, 53.78915977478027, 57.811753341129844, 58.74919387272426, 55.30868911743164, 58.66714954376221, 57.24019105093819, 58.55459567478725, 61.21874346051897, 57.32385778427124, 64.23173945290702, 60.38917718614851, 39.7703492300851, 71.12732628413609, 49.03684554781233, 10.117273705346243, 0.9835707076958248, 0.06983791145363025, 0.041267210617661476, 0.13166969322732516, 0.024591625601585423, 0.11858943796583585, 0.06357753702572413, 0.04329351295850106, 0.033325914958758016, 0.5245864423257964, 0.9804236079965318, 0.457126219357763, 0.30383595771023203, 0.05829686538449355, 2.158568629196712, 15.961139508656093, 14.064971770559039, 17.599564688546316, 20.127760546548025, 34.724049772535054, 47.28049380438668, 11.642446722303118, 0.3865484265344483, 0.9497058391571045, 41.65767451695034, 56.016564641680034, 81.42767633710588, 68.83035605294364, 58.61287716456822, 53.628847462790354, 58.641156332833425, 94.85798835754395, 128.4846292223249, 63.5704585484096, 71.14587797437395, 37.6081532069615, 41.1660338810512, 55.412693228040425, 68.57713590349469, 58.44020748138428, 83.20874282291958, 106.43044934953961, 88.49552290780204, 83.35453687395368, 69.42838055746896, 45.09079333714077, 64.47494724818638, 72.00524507250104, 44.60674360820225, 54.17070272990635, 20.704855339867727, 0.6910265226449285, 0.25402589621288435, 0.37956269138625687, 0.12303863279521465, 0.29270478071910994, 0.1424075641802379, 0.12376940143959862, 0.11395534234387533, 0.21596792553152355, 0.21481989856277192, 0.2940157103751387, 0.2943180927208492, 0.20118662369038376, 6.213608545916421, 16.024309056145803, 47.61784969057356, 49.032777377537315, 75.16682134355817, 71.2808119910104, 75.91544805254254, 75.04550579616001, 67.71240479605538, 71.30133696964809, 73.69017628261021, 70.84541702270508, 66.04765810285295, 69.35759231022426, 69.15663651057652, 70.219071660723, 66.38015025002616, 65.97723811013358, 67.19796017238072, 62.99982384272984, 60.83361176082066, 65.16853032793317, 62.869288035801475, 63.837158203125, 63.24886812482561, 62.28941222599575, 60.14300945826939, 57.45612716674805, 52.6830586705889, 53.355335099356516, 53.26865284783499, 56.61250121252877, 54.285337584359304, 53.681678090776714, 51.95999091012137, 54.58840758459908, 52.704389640263145, 50.16992998123169, 53.78759643009731, 56.65040363584246, 55.84894282477242, 56.86276142937796, 53.6740072795323, 53.01918125152588, 51.17102643421718, 61.27781704493931, 61.42383343832833, 64.0575064250401, 63.80556474413191, 68.28274767739433, 64.93592548370361, 69.43648910522461, 53.08146142959595, 58.70908192225865, 66.48081575121198, 65.89916120256696, 65.45116220201764, 65.74174281529018, 62.1198205947876, 57.586649077279226, 60.73088959285191, 58.612710407802034, 60.8144416809082, 60.70053291320801, 58.07940489905221, 61.145863805498394, 63.104616573878694, 55.031285762786865, 52.41817944390433, 51.19472673961094, 51.3303416797093, 53.666242667606895, 48.173358167920796, 51.94391972678048, 50.66649341583252, 45.45456280027117, 46.048717158181326, 47.285319328308105, 49.453758307865684, 47.386412143707275, 50.085047313145225, 48.351899078914094, 47.29679080418178, 46.71689762387957, 45.24855218614851, 47.2654891695295, 49.1396997315543, 50.77783135005406, 53.27340194157192, 53.38583421707153, 53.18352699279785, 52.79738433020455, 53.31492437635149, 55.0017454964774, 53.39365094048636, 50.725452354976106, 57.046437059129985, 57.643930026463096, 63.20065457480294, 60.56243746621268, 58.17608560834612, 60.22951453072684, 58.49864183153425, 59.89393738337925, 64.02631596156529, 58.40490368434361, 68.87283733912876, 62.077394894191194, 48.71243415560041, 68.96986893245152, 58.27484730311802, 20.940739733832224, 1.6653555291039603, 0.2861151471734047, 0.24912320928914206, 0.436363834887743, 0.09044510817953519, 0.2845503097133977, 0.138504223631961, 0.11645156411187989, 0.2458656169474125, 2.81185302564076, 2.7117216672216142, 0.567379963185106, 0.6191957741975784, 0.22780904014195713, 3.583511710166931, 23.942156553268433, 27.355995859418595, 22.96773770877293, 28.399075065340313, 46.94037600925991, 62.3352494921003, 16.963151386805944, 0.7165341196315629, 0.8482679479888507, 46.452563830784385, 61.80414308820452, 94.07373128618512, 84.73374734606061, 66.31526102338518, 61.36289773668562, 72.51590987614223, 121.15396009172711], [78.25958265577043, 68.70978396279472, 58.31746755327497, 7.699149472372873, 23.613051652908325, 9.10227998665401, 4.12037513085774, 8.461220945630755, 18.436006205422537, 55.12417275565011, 45.01530810764858, 69.22837666102818, 39.313592025211875, 32.48039306913103, 47.15755237851824, 51.91525840759277, 19.381240878786357, 35.29923554829189, 7.846796955381121, 0.2991839216223785, 0.16569204974387372, 0.22807923278638295, 0.052798808086663485, 0.09152935964188405, 0.03359339346310922, 0.0593483978882432, 0.0868987991873707, 0.03935326010520969, 0.08554169522332293, 0.08453236759773322, 0.06993535586765834, 0.08279047320996012, 7.095189469201224, 26.54465123585292, 50.68781396320888, 27.61320080075945, 65.032776423863, 68.7778068270002, 72.63242421831403, 63.9131714957101, 64.9055757522583, 61.69358335222517, 63.082159996032715, 64.47184835161481, 63.73989731924874, 59.05415030888149, 60.68391282217843, 59.817903246198384, 60.197921071733745, 60.64176504952567, 61.72020884922573, 54.732422896793906, 56.405382360730854, 57.93058490753174, 58.24694333757673, 57.99714170183454, 56.5167168208531, 52.410390513283865, 53.32743460791451, 49.886446952819824, 47.08247014454433, 46.19685970033918, 46.76272446768624, 48.410597460610525, 45.82114628383091, 47.59257214409964, 47.5999059677124, 47.20510237557547, 46.85325602122715, 46.79393230165754, 45.46754550933838, 46.51151234763009, 47.5093674659729, 46.621203558785574, 48.23656940460205, 47.4020733833313, 46.1567234311785, 51.4059658731733, 59.21806526184082, 55.325746944972444, 58.70576763153076, 54.416137422834126, 63.07592051369803, 62.06474917275565, 45.09374632154192, 58.77624320983887, 58.79263401031494, 66.12399796077183, 59.45312282017299, 63.067263058253694, 53.62062774385725, 55.286517415727886, 60.494185311453684, 52.96508952549526, 54.72473471505301, 54.64490686144148, 52.28632695334298, 50.84447847093855, 54.62684154510498, 51.9286892754691, 43.80665506635393, 42.67849343163626, 43.87586954661778, 45.43124117170061, 43.21066985811506, 44.23356975827898, 40.008491788591655, 44.53895698274885, 41.85531255177089, 44.09862184524536, 43.48853874206543, 42.2395201410566, 43.01952838897705, 41.91849252155849, 40.35664170128958, 43.803962639399934, 43.381661551339285, 46.607929025377544, 42.756205558776855, 44.734809330531526, 45.88550744737898, 47.739870480128694, 45.15360505240304, 46.91377135685512, 47.84744249071394, 49.91633810315813, 50.81250980922154, 51.16354669843401, 50.55815710340227, 52.81191301345825, 55.78484221867153, 56.30483150482178, 52.49082980837141, 54.19331564222063, 56.49907881872994, 56.18957826069423, 58.6650025503976, 54.91459771565029, 63.59063611711775, 55.99216604232788, 43.49566759381975, 75.10448210580009, 33.48121506827218, 8.385383095060076, 4.053860460008893, 1.4840507549898965, 1.082516638295991, 0.8417436980775425, 0.8648708856531552, 0.08532400761864015, 0.2050078615014042, 0.030331037805548737, 0.10839926690927573, 0.06949400276477848, 1.3790585888283593, 0.1327213275113276, 0.16236239698316368, 0.14999549915747984, 0.9770890155008861, 12.966641357966832, 19.92294328553336, 19.272051674979075, 23.334685972758702, 21.387409891401017, 30.98441117150443, 8.156664899417333, 0.31745635398796623, 5.4565015605517795, 40.23799426215035, 46.64843354906355, 71.71668638501848, 39.58884491239275, 57.69845254080636, 44.5707380431039, 48.609208243233816, 28.86883408682687, 74.65202236175537, 71.968079158238, 63.24796485900879, 21.459405388150895, 29.041349172592163, 14.82124410356794, 8.567745515278407, 21.74382642337254, 35.8275522504534, 68.66453729357038, 61.680631910051616, 76.5269798551287, 46.19114828109741, 46.826991830553325, 58.78082207271031, 50.75208132607596, 22.876057965414866, 42.519862583705354, 7.41730100767953, 0.34182463639548843, 0.21122584784669535, 0.05318308621644974, 0.11206111684441566, 0.09352999978831836, 0.05327475969014423, 0.03308498074433633, 0.0623261963150331, 0.03587479104420968, 0.07827318739145994, 0.01741543585168464, 0.046356586273759604, 0.06517182969089065, 7.647933432034083, 30.548276220049175, 56.84768383843558, 35.905917508261545, 64.91120379311698, 71.88014275687081, 75.7861351285662, 68.90689740862165, 68.32508305140904, 64.93282658713204, 65.1367631639753, 68.14853627341134, 67.2403997693743, 62.862541334969656, 64.68462998526437, 61.48023196629116, 63.544020652770996, 61.59803172520229, 62.69471454620361, 57.92432805470058, 61.583343233381, 62.505237170628135, 62.475380761282786, 61.73523085457938, 60.23840822492327, 55.93063626970564, 56.73779460362026, 53.07006638390677, 50.992440359933035, 48.87804446901594, 49.9067565373012, 49.75918027332851, 51.47479125431606, 50.79813746043614, 51.749081815992085, 48.14012493406023, 50.53712490626744, 49.472719941820415, 48.805098806108745, 50.34943321772984, 51.274690083095, 49.6251425743103, 51.17784609113421, 50.66863693509783, 49.76475967679705, 54.36738191332136, 61.19275719778878, 58.724242891584126, 62.296971866062705, 59.36551298413958, 65.06993538992745, 61.68145874568394, 50.855418409620015, 57.734534536089214, 60.025612694876536, 65.52133205958775, 62.38088526044573, 63.40177018301827, 55.33312245777675, 54.81688172476632, 59.870924949645996, 55.71618012019566, 58.343314852033345, 58.10036414010184, 54.78577463967459, 54.80236346381051, 55.49285112108503, 52.061990465436665, 46.31854697636196, 44.66192967551095, 46.23239973613194, 47.48660169328962, 46.440748419080464, 45.448177405766074, 42.857100350516184, 46.14415413992745, 43.917214802333284, 45.454927580697195, 45.474007334027974, 46.05457101549421, 46.70761135646275, 44.496718883514404, 46.42889826638358, 46.80227361406599, 44.027791908809114, 48.97398172106062, 46.96126576832363, 46.049978256225586, 49.74751772199358, 50.878079959324424, 49.2772810118539, 50.06175000326974, 51.04180383682251, 52.72493893759591, 53.29411799567086, 52.65745455878121, 53.67274618148804, 56.33994770050049, 58.247238636016846, 57.49145875658308, 55.17154209954398, 56.89578969138009, 56.72202566691807, 57.400215012686594, 60.80167089189802, 56.9699512890407, 66.41223008292062, 55.36368063517979, 49.29070840563093, 73.69904913221086, 44.35258545194353, 26.792476109095983, 4.015302300453186, 1.3089252093008585, 0.4489210753568581, 0.9139640884740012, 1.1010848305055072, 0.057156607641705444, 0.10168126810874258, 0.050820610485970974, 0.07593950190182243, 0.12261266208120755, 1.250660981450762, 0.7044265578900064, 0.11570813400404793, 0.1557242888957262, 0.7818052800638335, 16.84026207242693, 22.09313668523516, 23.197834253311157, 27.747603280203684, 28.44599277632577, 42.82125806808472, 13.310188089098249, 0.22449525152998312, 8.691530278750829, 52.692959853581016, 56.70185852050781, 78.79591410500663, 47.75665037972586, 61.69306918552944, 38.369234561920166, 53.62133993421282, 30.347087655748638, 95.37306526729039, 91.99993024553571, 79.36471448625836, 37.64785173961094, 44.76047250202724, 41.171641077314106, 24.74780191693987, 45.42809363773891, 52.030483858925955, 81.45438521248954, 79.81033025469098, 90.36916719164167, 54.46338864735195, 53.836341517312185, 72.59725243704659, 70.779527255467, 28.726877178464616, 55.10398129054478, 12.027996182441711, 0.3961098263306277, 0.5132215778742517, 0.38838277810386246, 0.1607393276478563, 0.22663070979927266, 0.12230477003114563, 0.2212977095374039, 0.1833017433860472, 0.13759018267904008, 0.2608743772975036, 0.13875396523092473, 0.3772464985294001, 0.16885594997022832, 9.24370275224958, 31.814099039350236, 60.1044955934797, 47.03432955060686, 65.35068430219377, 75.55833148956299, 78.5857241494315, 71.04320444379533, 68.07145990644182, 68.08967808314732, 67.18672493525914, 72.34324714115688, 72.37315913609096, 68.12987341199602, 68.38449709756034, 66.42286082676479, 66.47128282274518, 64.67102541242326, 65.64185551234654, 60.93945366995675, 64.62417370932442, 65.89495059422084, 66.44634573800224, 66.76585865020752, 65.58394922528947, 57.687227725982666, 61.327503613063264, 55.40061725888933, 54.64086300986153, 51.59682246616909, 53.02842582975115, 54.15304388318743, 52.56583213806152, 52.86865895135062, 53.40710612705776, 51.8768070765904, 52.064304215567454, 52.73273481641497, 48.632119928087505, 53.56618513379778, 53.566591603415354, 53.36203663689749, 53.45404468263899, 54.77572407041277, 53.167674677712576, 55.57831048965454, 62.73175539289202, 59.83051422664097, 61.65238748277937, 63.07830374581473, 66.03888252803257, 63.87283025469099, 56.22804001399449, 59.02145208631243, 64.02854633331299, 68.68675763266427, 63.8284729548863, 67.01871749332973, 57.16319111415318, 57.434497424534385, 66.35321208408901, 59.814602851867676, 60.48659093039376, 61.56994710649763, 57.49173321042742, 55.519928250994, 58.825693539210725, 56.521952288491384, 48.933925356183735, 47.541141578129356, 49.35593114580427, 52.42273398808071, 49.48153025763375, 48.97216476712908, 43.49376031330654, 48.72601440974644, 45.234735693250386, 47.792867864881245, 47.933732169015066, 47.904386452266145, 48.12410586220877, 47.18139164788382, 47.74361555916922, 49.319369724818635, 47.80317551749093, 52.161641529628206, 49.32816614423479, 51.68002367019653, 54.51201908929007, 54.42781734466553, 53.42411184310913, 53.138245582580566, 55.96415785380772, 56.13596943446568, 56.1454050881522, 54.61200019291469, 55.403962816510884, 57.73391614641462, 62.24398490360805, 58.925886562892366, 57.23147453580584, 57.224894591740195, 60.05510779789516, 60.78449494498116, 62.29522092001778, 58.075364521571565, 69.57190949576241, 58.93801811763218, 53.660680634634836, 73.34538582393101, 52.11366421835763, 40.45670965739659, 6.765348494052887, 3.518898240157536, 1.7509482162339347, 3.0933827417237416, 2.0357631274632046, 0.15541977595005715, 0.2993016338774136, 0.12354013802749769, 0.16410967893898487, 0.2430920372051852, 6.50842365196773, 1.1164122309003557, 0.28801053975309643, 0.43457611224481035, 1.0728287867137363, 22.611852713993617, 28.13992289134434, 39.081935610089985, 50.19730240958077, 38.73803104673113, 63.85593918391636, 22.559489352362498, 0.7263474187680653, 10.300565447126116, 58.824220521109446, 64.63761152539934, 85.96102155957902, 53.410455158778596, 81.47149167742047, 72.66833250863212, 78.17542607443673, 42.108289514269146], [36.44862740380423, 49.860919271196636, 61.413258280072895, 14.171027336801801, 8.745251144681658, 3.153446444443294, 1.250280893274716, 10.499348197664533, 29.384202820914133, 47.21836301258632, 48.011260168892996, 55.8939254624503, 44.919982297079905, 49.31848382949829, 47.82429109300886, 16.939327750887188, 23.453048535755702, 34.85850088936942, 1.5281358808279037, 0.03259696478822401, 0.21273378336003848, 0.08807895478925534, 0.0777889508754015, 0.011609057330393364, 0.02443918083528323, 0.017964331666007638, 0.05382788786664605, 0.043466115303869755, 0.08896964735218457, 0.046684552782348225, 0.03337025722222669, 0.18116457520851068, 3.182109283549445, 36.747855050223215, 51.36758402415684, 38.953633649008616, 52.997669628688264, 73.18543134416852, 70.81820787702287, 65.11997631617955, 64.3721764428275, 67.37464591435024, 63.322803906032014, 60.94613783700125, 61.84178842817034, 60.25873865400042, 59.71936389378139, 57.61101640973772, 58.45443739209856, 60.82220976693289, 60.76029436928885, 57.98344332831246, 57.592221532549175, 58.44711399078369, 60.0303305217198, 57.73916551045009, 56.3028130531311, 53.4916170665196, 51.19850308554513, 49.32066903795515, 46.67517369134085, 45.77697311128889, 47.525956290108816, 46.53240210669381, 45.06422689982823, 46.89009537015642, 46.25195891516549, 45.94173574447632, 47.72429609298706, 47.13883393151419, 45.666666984558105, 45.42856958934239, 51.494645731789724, 47.3740929876055, 48.20074796676636, 45.719438552856445, 46.6364791733878, 47.24909836905343, 55.12167835235596, 57.8781225340707, 60.83037390027727, 53.02214813232422, 66.02015018463135, 51.525686808994834, 49.929091521671836, 58.50825119018555, 56.842045375279014, 63.33736038208008, 60.09213474818638, 61.84204551151821, 52.95292670386178, 54.0786703654698, 54.765343461717876, 58.92470536913191, 52.50856161117554, 57.71984257016863, 52.80422830581665, 54.69623667853219, 55.2959634917123, 47.18308700834002, 44.803325516836985, 45.78381013870239, 42.57163708550589, 44.71428435189383, 40.86222389766148, 42.241625445229666, 40.25139038903372, 42.36730446134295, 42.27893727166312, 44.12758888517107, 44.93299627304077, 42.91533667700631, 41.60776908057076, 43.01839583260672, 42.18328489576067, 44.066305773598806, 42.70176642281668, 43.39418567929949, 44.704470021384104, 45.55158049719674, 46.81825794492449, 48.1575961794172, 48.140427180698936, 48.78659922736031, 49.27109364100865, 49.2891137940543, 51.205173356192454, 51.14320237295968, 52.07696383340018, 54.9923689024789, 54.22511059897286, 53.571239948272705, 55.56977462768555, 55.9689382144383, 52.65482813971383, 55.075302600860596, 58.9954171861921, 56.70734759739467, 58.71247264317104, 53.60660627910069, 52.91274527141026, 55.33845867429461, 38.943325996398926, 18.891941785812378, 7.277567088603973, 3.52591244663511, 2.2274337453501563, 2.995106552328382, 1.5715438830001014, 0.19812332306589397, 0.04981652454340032, 0.1946903294218438, 0.046871231336678774, 0.4101187789014408, 0.6616466077310699, 0.3248524128326348, 0.09732054746044533, 0.15769843224968227, 0.4541374625904219, 15.04586546761649, 31.34439386640276, 22.185846499034337, 17.2198543207986, 24.76505081994193, 18.467782054628643, 5.542758669172015, 0.27580054636512485, 12.13188738482339, 47.329033919743125, 56.525777271815706, 56.69596644810268, 45.52646623338972, 12.60838963304247, 3.515060228960855, 12.152168307985578, 30.512722287859233, 46.173538071768625, 50.732063565935405, 63.153163637433735, 18.98357289178031, 11.464084727423531, 3.923841425350734, 2.900500314576285, 15.040176630020142, 54.01105744498116, 61.860958508082796, 67.7038585117885, 64.86950070517403, 61.28366047995431, 61.49032769884382, 56.52249077388218, 23.30976104736328, 29.42388050896781, 38.919896670750205, 1.260654553771019, 0.026976562537518994, 0.2530241613941533, 0.2543714605271816, 0.04876242717728019, 0.0341039164257901, 0.03648359301899161, 0.06642372680029698, 0.05962675330894334, 0.013054034972031201, 0.08268122228660754, 0.04081864808020847, 0.04708376886057002, 0.1842153907886573, 4.127895253045218, 42.64332512446812, 58.16604893548148, 46.97645105634417, 54.74140691757202, 78.45106806073869, 73.50927298409599, 67.42195619855607, 66.23111139025006, 69.2710941859654, 67.38747228894914, 65.3153944015503, 65.67250401633126, 65.06417533329555, 61.3873484475272, 61.31359331948416, 61.49300970349993, 64.51000785827637, 63.50792476109096, 61.73436232975551, 62.08414159502302, 61.963333266122, 62.40607248033796, 61.031482560294016, 58.13308320726667, 57.39341272626604, 54.619643211364746, 52.75624057224819, 50.634093965802876, 49.33247402736119, 49.173016343797954, 50.53982080732073, 48.59213651929583, 49.82836348669869, 48.5906982421875, 49.45631524494716, 50.41556964601789, 48.01258727482387, 49.98786285945347, 47.17715324674334, 53.41321011951992, 50.80226469039917, 48.895008495875764, 49.33696951184954, 49.35400996889387, 49.9155946459089, 56.013358048030305, 56.115350655147004, 61.94360038212368, 59.275283677237375, 63.737319537571494, 53.03950820650373, 57.42911604472569, 60.44506849561419, 59.36847291673933, 65.11915642874581, 62.404377119881765, 64.39904512677873, 56.99966178621565, 55.3317779813494, 61.456476075308665, 61.35028675624302, 53.88042436327253, 59.23363617488316, 56.827818938664024, 54.93280547005789, 57.25637340545654, 48.80638769694737, 47.75642456327166, 47.317030906677246, 45.36335379736764, 47.6952144077846, 44.631864820207866, 44.19498988560268, 42.858705384390696, 45.16980825151716, 44.67463098253523, 45.598724024636404, 47.184577396937776, 46.22138336726597, 45.28244897297451, 46.206073011670796, 45.33008234841483, 46.20173733575003, 44.298288754054475, 46.71260016305106, 46.999025753566194, 50.365559986659456, 50.21005930219378, 52.13218116760254, 52.98356825964791, 51.736311026981895, 51.90809481484549, 53.524179799216135, 51.963690825871055, 54.969481536320274, 52.943028994968955, 55.34737321308681, 55.25605998720442, 57.2939145224435, 56.839808055332725, 58.981625011989046, 51.795985630580354, 56.56563213893345, 58.9789708001273, 59.229335239955354, 61.5244641985212, 54.03343759264265, 55.189155782972065, 56.195171560559956, 47.41451760700771, 37.32306514467512, 11.781481913157872, 8.364719152450562, 5.080753837312971, 3.209502339363098, 2.7918532873903, 0.3979770189949444, 0.07478824510638203, 0.1416804324835539, 0.026984694779717495, 0.16740118446094648, 0.7597652141536985, 0.4303743248539311, 0.15569188206323556, 0.009501541981340518, 0.44582684710621834, 16.579991238457815, 37.39354419708252, 24.358369282313756, 25.864267996379308, 31.896925040653773, 32.412728037152974, 6.467771479061671, 0.2309732117823192, 17.879325219563075, 57.2445718901498, 66.03866713387626, 69.8902690070016, 43.211402893066406, 1.3519044859068734, 2.2820989148957387, 0.6958425470760891, 30.1177693094526, 64.51645578656877, 71.91621085575649, 90.41619259970528, 27.284316505704606, 13.060401218278066, 5.958735593727656, 5.291807975087847, 31.954536029270717, 81.02757821764264, 75.99909046718052, 81.66140678950718, 74.21111052376884, 68.63315228053501, 71.2038745880127, 68.03992203303746, 30.56738724027361, 36.73100219454084, 48.46739550999233, 2.309932747057506, 0.1293964787785496, 0.7731376737356186, 0.38469187329922405, 0.16108961456588336, 0.07484984251537494, 0.1755390992122037, 0.2423169602240835, 0.17640416350747856, 0.1712090958442007, 0.16393380266215118, 0.1208905673452786, 0.13712430053523608, 0.19125078112951346, 6.090249793870108, 43.187118938991, 60.197406905038015, 53.37180927821568, 58.78421974182129, 78.00027588435582, 76.02743911743164, 71.80521338326591, 68.24752725873674, 73.72680718558175, 68.22079753875732, 68.99253395625523, 70.10501003265381, 68.60636002676827, 65.55361339024135, 64.83039624350411, 64.16124303000313, 66.95578071049282, 66.42436858585903, 66.00462790897915, 64.1182336807251, 64.86053058079311, 65.83076313563755, 63.689043453761506, 60.85956328255789, 61.43921675000872, 57.40003783362252, 57.187447275434224, 54.0508463042123, 51.92094203404018, 53.950639384133474, 54.65138953072684, 50.8669558933803, 51.56189387185233, 50.03542675290789, 52.33778531210763, 53.696189403533936, 50.902985777173726, 51.32573502404349, 49.664521489824565, 58.59232439313616, 54.6471198626927, 52.872192110334126, 51.12791633605957, 52.45980262756348, 53.59823717389788, 59.0979448046003, 58.36676502227783, 63.4872191292899, 59.723011698041645, 65.45683888026646, 64.39377839224679, 55.775482995169504, 61.379719325474326, 63.41983549935477, 69.36935561043876, 63.84326566968645, 67.21191910334996, 54.48584869929722, 59.26750864301409, 60.04094736916678, 60.720217159816194, 58.541699818202424, 64.02251529693604, 58.63771002633231, 58.949399266924175, 59.024398122514995, 50.69807297842843, 50.91802862712315, 50.890798636845176, 48.34976250784737, 51.30248287745884, 47.352306910923545, 47.21984992708479, 43.96967370169503, 46.72882768086025, 46.46258660725185, 46.65954024451119, 50.06937565122332, 49.41111373901367, 48.30441856384277, 51.474332673209055, 48.10223988124302, 50.59587887355259, 46.1827027457101, 50.80940743855068, 49.36344562258039, 53.72883551461356, 51.417871611458914, 55.19709062576294, 56.69400358200073, 57.97950369971139, 55.11998299189976, 56.073932443346294, 54.4171518598284, 55.700956617082866, 55.74574817929949, 60.917344502040315, 59.973654065813335, 59.080504826136995, 59.88721152714321, 62.271402495247976, 53.49729027066912, 57.14112710952759, 62.564998626708984, 59.781793458121165, 63.22916998182024, 58.105610030038015, 56.409214292253765, 62.8988595690046, 55.64269249779837, 47.77932582582746, 23.588618312563213, 14.872454064232961, 9.798714433397565, 4.751040969576154, 5.623709091118403, 0.6765072303158897, 0.1423881445080042, 0.2610910199582577, 0.15722326774682316, 1.323003670998982, 3.719037192208426, 1.8691481479576655, 0.3045040432895933, 0.26631044702870504, 0.7681254169770649, 21.850265877587454, 49.81449835641043, 44.05963202885219, 39.99592249734061, 47.018647466387065, 53.80192708969116, 16.808783258710587, 0.5716862721102578, 21.572841678346904, 66.22264153616769, 76.56272833687919, 78.11195428030831, 64.66005420684814, 16.31344097001212, 4.564323765890939, 23.971950428826467, 78.74239213126046], [42.59683820179531, 29.40464789526803, 52.475484711783274, 20.303030593054636, 0.5823974087834358, 0.16232327265398844, 0.09116022980638913, 8.136527282851082, 40.737041677747456, 52.12574713570731, 57.994511808667866, 62.045377595084055, 71.09923471723283, 50.53067350387573, 45.309057099478586, 17.09109898975917, 31.57533461706979, 23.149344512394496, 0.21764573907213552, 0.05307247483038476, 0.05161537516063877, 0.09584448952227831, 0.06273652001151017, 0.07426965436232941, 0.02433020302227565, 0.019939757451148968, 0.03643312697697963, 0.013453489385678299, 0.015517442786533917, 0.10150379048926489, 0.02769204548427037, 0.10914342304957764, 2.815574654511043, 39.324302673339844, 53.82250417981829, 49.445389202662874, 38.09243222645351, 75.565856388637, 68.21598938533238, 64.310608455113, 59.492199489048545, 67.32796096801758, 66.272050176348, 64.1950112751552, 60.88557733808245, 62.82923861912319, 59.80680002485003, 60.82434981209891, 60.093732833862305, 61.12866006578718, 61.746299334934776, 56.90005241121565, 58.62759344918387, 60.66815430777413, 60.82210554395403, 59.1362224306379, 55.71519347599575, 54.422807693481445, 51.96232203074864, 50.098606722695486, 47.32962451662336, 45.761523791721885, 47.15240723746163, 46.50542572566441, 48.256277969905305, 46.16104521070208, 47.259670053209575, 46.16673231124878, 46.79027754919869, 46.25183732169015, 47.31855951036726, 45.21329355239868, 49.024196352277485, 48.793557848249165, 47.727791036878315, 44.56937619618007, 46.48726313454764, 46.385447706495015, 50.76595687866211, 52.070967538016184, 56.78273555210659, 61.936249188014436, 55.75882468904768, 39.63167708260672, 61.60242993491036, 61.314350673130576, 60.53001717158726, 56.61973428726196, 61.752379008701865, 59.02843502589634, 64.80163070133754, 52.90991735458374, 69.44075529915946, 65.6345043182373, 50.19432858058384, 57.14056430544172, 55.26139620372227, 52.44592360087803, 46.678196157727925, 47.16605002539498, 42.45021036693028, 44.21198517935616, 42.215093748910085, 43.89536271776472, 40.74109247752598, 41.21697459902082, 42.53445380074637, 41.32913589477539, 43.93353612082345, 43.2576778956822, 44.01325627735683, 42.22375120435442, 42.22693695340838, 42.212064334324424, 42.98672941752842, 44.94462408338274, 41.21448366982596, 42.045151233673096, 44.52546010698591, 46.6443167413984, 47.758540289742605, 48.74793945040022, 47.78067030225481, 49.29496765136719, 50.14445441109793, 52.94353968756539, 54.357876777648926, 52.62120233263288, 50.98385238647461, 51.59232350758144, 51.291945934295654, 55.9689416885376, 55.954687459128245, 57.14354508263724, 54.836757046835764, 54.09876108169556, 56.762641361781526, 60.560429436819895, 58.27338818141392, 45.18099137714931, 50.07966940743582, 39.481547355651855, 38.8973046030317, 26.218259607042583, 7.191533190863473, 10.35889904839652, 8.356409975460597, 2.6199544199875424, 0.4705648496747017, 0.4064461131181036, 0.09487700036593846, 0.19258110331637518, 0.05770181731453963, 0.21286627410777978, 0.30301883869937485, 0.6124280116387776, 0.1266342577125345, 0.17738980347556726, 0.2676117686288697, 13.222472293036324, 26.701505081994192, 23.945234605244227, 15.888812235423497, 19.06414246559143, 4.172413664204734, 4.9668780735560825, 0.2789165691605636, 19.821840047836304, 54.99541221346174, 54.92085804258074, 71.91522421155656, 17.915356840406144, 1.2918934375047684, 0.24315400102308818, 1.2641983521836144, 2.1668888798781802, 49.23151322773525, 40.53006526402065, 63.91271986280169, 22.912049634116038, 0.5775641224214009, 0.16869482504470007, 0.4653806250010218, 23.8454167842865, 63.46588815961565, 72.8879303250994, 72.32119355882917, 68.14645876203264, 83.0775260925293, 57.37810237067086, 50.13182953425816, 23.517447914396012, 36.440657820020405, 24.989241395677837, 0.2612879036792687, 0.026126638054847717, 0.22211892689977372, 0.1515348915542875, 0.0801676232367754, 0.030847236713660613, 0.015590219059959054, 0.10473228046404463, 0.08977103113595929, 0.04997161729261279, 0.056525678639965396, 0.08557692476149116, 0.06286652053573302, 0.04891330622402685, 3.4501243191105977, 42.53133405957903, 59.570047106061665, 55.472444261823384, 41.0776493208749, 76.40497643607003, 72.29800742013114, 66.56206798553467, 63.17856625148228, 72.05823203495571, 71.75691645486015, 67.36188902173723, 63.91108703613281, 65.6133678981236, 62.827855927603586, 64.64300332750592, 62.59306240081787, 65.144225529262, 61.75894505637032, 60.01885904584612, 63.59062222072056, 64.36614540645054, 63.18459728785923, 61.99185562133789, 59.771982601710725, 56.10219771521432, 55.40888908931187, 54.20501293454851, 51.1147494997297, 50.34321805409023, 50.056674344199045, 50.12742437635149, 49.406750270298545, 49.90099648066929, 48.56846400669643, 50.2925101007734, 47.200388022831504, 49.000013147081646, 49.546860694885254, 49.387799058641704, 48.880396434238975, 52.799489634377615, 49.98340211595808, 49.00710378374372, 50.87901101793562, 49.47543321337019, 52.408358165196006, 51.92402703421456, 58.53507123674665, 64.3258250100272, 53.209933621542795, 45.51266016278948, 63.11681761060442, 62.17928327832903, 61.9937663759504, 59.54666641780308, 63.51240634918213, 62.08963067190987, 65.5230621610369, 52.76569012233189, 61.90678187779018, 64.92084094456264, 52.47913251604353, 57.589407512119834, 58.56708853585379, 54.93707166399275, 49.32971906661987, 48.004801818302695, 46.73529992784773, 47.460611956460134, 45.081823212759836, 48.475104536329, 42.83486958912441, 42.988806928907124, 44.69588899612427, 44.386492661067415, 46.66787460872105, 45.99038355691092, 45.94324002947126, 44.685004643031526, 45.20733894620623, 45.27662638255528, 47.03522934232439, 47.0722701890128, 44.250731808798655, 46.03911474772862, 46.91354554040091, 49.466862610408235, 50.35639878681728, 52.96238667624337, 52.37933553968157, 54.513745716639924, 54.27305316925049, 53.9297913142613, 57.82742152895246, 55.259541034698486, 53.48510660443987, 53.56241921016148, 51.98330559049334, 57.76062849589756, 57.32818651199341, 57.26760516847883, 55.47429595674787, 56.55755138397217, 59.70272295815604, 62.06981440952846, 59.85000392368862, 49.120519229343955, 53.356603145599365, 43.507423945835654, 44.591561794281006, 34.66889844621931, 20.474720580237253, 13.234869616372244, 12.259580510003225, 4.878638557025364, 1.01308730670384, 0.682086145239217, 0.08400359882840089, 0.10527003303702388, 0.06742129541401352, 0.16366555062787874, 0.4914991206356457, 0.3125109464994499, 0.18592403696051665, 0.19680776580103806, 0.3645694287759917, 16.383777584348405, 30.585376126425608, 29.45602982384818, 29.220937524523052, 29.12176067488534, 18.672931092126028, 5.4906710641724725, 0.2950331057821001, 25.538109132221766, 62.97997978755406, 63.744615146092, 83.10651397705078, 23.520145552498953, 1.501943126320839, 0.128557185243283, 0.7463905289769173, 2.3550241674695696, 107.442537852696, 56.44149214880807, 79.35758563450405, 30.33708224977766, 1.0401432663202286, 0.37112442989434513, 0.9212644738810403, 26.626026800700597, 85.85680552891323, 71.88450622558594, 88.60497093200684, 78.04505702427456, 88.32612582615444, 67.69809150695801, 66.26031466892788, 29.245054721832275, 45.68729618617466, 32.68189082826887, 0.5894945593816894, 0.09446409823639051, 0.345037255436182, 0.3736777843109199, 0.20744142734578677, 0.11054721700825862, 0.13189100420900754, 0.1563185905771596, 0.17167066250528606, 0.1352772739316736, 0.23189439092363628, 0.2049078182982547, 0.23341026529669762, 0.2098185797887189, 4.170642742088862, 46.1425838470459, 65.56054769243512, 59.33989497593471, 52.13398422513689, 76.99626118796212, 74.40364510672433, 65.97590405600411, 64.66145079476493, 73.05511093139648, 73.43221051352364, 69.3160629272461, 68.51223278045654, 68.88383633749825, 68.05889061519078, 66.19252804347447, 66.0192677634103, 66.87431308201381, 66.50295271192277, 61.54145949227469, 63.61401680537632, 67.37858554295131, 67.05445902688163, 65.19075066702706, 64.06597627912248, 58.64623546600342, 56.94781085423061, 58.26328550066267, 55.15379292624337, 52.73305443355015, 54.478699002947124, 53.72667115075247, 53.07700416019985, 53.06404229572841, 51.75050619670323, 52.423658098493306, 52.18438993181501, 49.54457821164812, 52.77750553403582, 51.01507759094238, 54.03100572313581, 55.46126461029053, 52.11734676361084, 51.437493324279785, 53.759543078286306, 50.82416888645717, 56.187254088265554, 53.347626073019846, 61.67744268689837, 64.90162222726005, 61.64001274108887, 51.754390239715576, 63.935065269470215, 68.63404859815324, 64.76613235473633, 59.68219797951834, 66.78454235621861, 64.7304047175816, 70.15554428100586, 54.371828760419575, 65.32908235277448, 73.57271698543003, 55.25494827542986, 60.91655240740095, 61.22919355119978, 54.344689096723286, 51.40695946557181, 51.66177075249808, 48.85579981122698, 52.74031530107771, 47.01661164419991, 50.65603290285383, 44.177490847451345, 44.336559431893484, 46.92333902631487, 46.433682101113455, 48.75742721557617, 47.910191672188894, 49.370821135384695, 48.48143434524536, 49.265149457114084, 48.220543384552, 50.6662780216762, 50.13688782283238, 45.14761570521763, 47.97780111857823, 51.6781268119812, 54.357890674046104, 53.41553776604788, 55.944226946149556, 54.490448406764436, 57.87509311948504, 57.23422602244786, 58.38150215148926, 59.81363010406494, 57.56902149745396, 58.386275563921245, 56.04382242475237, 53.68585395812988, 60.365198952811106, 58.51706845419747, 59.35520880562918, 58.42329556601388, 58.13258988516671, 61.04268305642264, 62.975442613874165, 59.54101753234863, 53.18664673396519, 55.63803373064314, 51.669990471431184, 50.18914869853428, 47.575288500104634, 35.470880372183665, 24.756707770483835, 19.33953431674412, 5.128723766122546, 0.7276399465543884, 2.5205445885658264, 0.2447286636701652, 0.23865580239466258, 0.10482460872403213, 0.5426344967314175, 2.5166750933442796, 1.8657496103218623, 0.44617930533630507, 0.8624699030603681, 0.5612366156918662, 18.957871505192347, 45.05623994554792, 37.71942860739571, 35.88306488309588, 39.85787568773542, 48.42064455577305, 7.11965320791517, 0.6157349199056625, 30.13061305454799, 76.60121440887451, 69.84350763048444, 92.26483031681606, 33.85337100710188, 1.6902773060968943, 0.21360845571117743, 2.6512074172496796, 6.926883254732404], [5.606323395456586, 26.005015918186732, 57.16224615914481, 8.181524685450963, 0.3393912469702107, 0.19497539555387838, 1.8924556629998344, 31.767803192138672, 52.78153896331787, 53.44701310566494, 66.94266945975167, 63.44033963339669, 61.059205872671946, 48.94086313247681, 48.961613927568706, 26.563025747026714, 35.92966992514474, 15.73061912400382, 0.2186609631670373, 0.07791537552007607, 0.23946676030755043, 0.25624220871499603, 0.06592125804828745, 0.03209240614835705, 0.16901246085762978, 0.03697385831869074, 0.002983640825342653, 0.11425198428332806, 0.07836321541773421, 0.08006261315728937, 0.06734761329633848, 0.1519413340304579, 1.9285574172224318, 28.148898226874216, 44.90526601246425, 50.43097727639334, 27.95472386905125, 64.50271919795445, 69.96617112840924, 65.7842241014753, 62.35081345694405, 68.10842432294572, 68.00556319100517, 66.54881082262311, 57.95651905877249, 61.0510139465332, 55.46650355202811, 60.45817279815674, 60.6833986554827, 59.88948358808245, 58.992978368486675, 57.60178920200893, 60.78191021510533, 59.485786301749094, 59.14660998753139, 58.84808758326939, 54.81982428686959, 53.691308294023784, 52.337844371795654, 49.58326925550188, 46.72149733134678, 47.649995531354634, 46.09139994212559, 47.8404734475272, 44.421883310590474, 47.27215249197823, 46.134614263262065, 47.102623394557405, 45.77366576875959, 48.14762551443917, 44.818632398332866, 45.620284284864155, 44.169653279440745, 48.15174927030291, 49.09214278629848, 47.30452414921352, 46.52984864371163, 46.98559488568987, 51.247064045497346, 52.27038778577532, 50.346626145499094, 64.94366577693394, 50.39577770233154, 51.763572284153526, 61.59767736707415, 52.37664311272757, 55.793114049094065, 58.015922682625906, 60.125659806387766, 58.016023431505474, 55.27241257258824, 53.93033674785069, 44.80917937414986, 52.66859252112252, 54.75352805001395, 51.635760171072825, 51.72442960739136, 52.345674991607666, 49.377929142543245, 45.06307349886213, 42.88331937789917, 42.925804138183594, 44.40285219464983, 44.93484796796526, 40.88681704657418, 43.17283691678728, 41.82170064108712, 45.124200275966096, 45.84432894842965, 42.595993995666504, 42.30219636644636, 43.66249731608799, 40.17195858274187, 41.25062125069754, 42.112739835466655, 43.05126428604126, 42.83896207809448, 41.64188126155308, 43.89970186778477, 48.300920145852224, 50.65954869134085, 50.68073027474539, 51.19987188066755, 51.226542540958945, 50.856009006500244, 54.56101083755493, 50.64154590879168, 54.71078968048096, 54.526634625026155, 53.75028460366385, 49.06762259347098, 53.29184593473162, 55.472812516348704, 57.66981554031372, 55.34301321847098, 51.043867451804026, 57.727047852107454, 57.29469966888428, 54.82837404523577, 37.83842693056379, 43.87232249123709, 29.82219294139317, 35.098081724984304, 29.813733509608678, 35.88366937637329, 14.062231574739728, 9.246232765061514, 2.915477156639099, 0.8001155746834618, 0.1867846500660692, 0.20361050005470002, 0.07234198387180056, 0.021301809631820236, 0.06728805149240152, 0.11885003612509795, 0.16399139671453408, 0.05453450405704124, 0.24723476490804128, 0.31034367850848604, 13.814681155341011, 17.140392984662736, 15.81926076752799, 13.374530145100184, 18.542938981737407, 7.654479503631592, 4.504815050533839, 0.4624901743871825, 18.988429682595388, 58.035301208496094, 45.840014117104666, 75.29924706050328, 19.724634749548777, 3.1418659687042236, 0.21838717428701265, 1.0755860273327147, 0.6078348723905427, 1.5687792599201202, 30.76626205444336, 54.68420934677124, 5.6784999796322415, 0.17457669228315353, 0.4245265743562153, 7.532482164246695, 58.59463814326695, 73.50005272456578, 73.58164542061942, 73.25589302607945, 77.21244049072266, 70.55423191615513, 60.17007963997977, 61.28356320517403, 29.677430697849818, 39.29113892146519, 18.433190447943552, 0.27032004616090227, 0.15481730470699923, 0.3022291867860726, 0.35759794286319185, 0.18869131989777088, 0.07911013998091221, 0.04393009076427136, 0.07440578205777065, 0.06462354625442199, 0.08456387197864906, 0.02109699892545385, 0.022608054003545215, 0.07847423053213529, 0.09040007381034748, 2.523703847612653, 32.42474842071533, 52.51836551938738, 56.968335832868306, 37.39485740661621, 65.94961207253593, 72.91215174538749, 66.22503866468156, 66.25157383510044, 69.63072599683488, 69.55223219735282, 71.54071630750383, 59.87673364366804, 63.22822502681187, 57.645799091884065, 63.021592548915315, 62.48898533412388, 64.84241662706647, 62.40714250292097, 61.699718611580984, 63.51354585375105, 62.97665160042899, 61.88833441053118, 61.87191581726074, 56.025698048727854, 56.78637988226754, 54.91393068858555, 54.229505334581646, 50.248541900089805, 53.19450167247227, 49.53871393203735, 51.04541342599051, 46.64018256323678, 50.27125208718436, 48.489438670022146, 50.66618422099522, 48.72613600322178, 49.11662128993443, 47.87374142238072, 48.96858991895403, 48.25016702924456, 49.35797739028931, 51.115461690085276, 49.30600833892822, 48.709356103624614, 50.7412108693804, 53.062190600803916, 52.20415408270699, 51.13051496233259, 65.99296188354492, 57.21778311048235, 56.06665073122297, 63.43154321398054, 56.95571790422712, 59.05061367579869, 58.99851608276367, 61.30478995186942, 60.71010753086635, 58.814222063337056, 56.00653144291469, 47.77134929384504, 57.39743225915091, 56.56504154205322, 55.045974254608154, 51.96054329190935, 53.17228133337838, 52.18173919405256, 47.3651054927281, 46.28232601710728, 47.079426833561485, 48.49260704857962, 48.46405342647007, 42.99317734582083, 44.87381499154227, 44.03719629560198, 45.46238994598389, 47.05773803165981, 45.73087528773716, 45.69175345557076, 45.51667969567435, 43.18723358426775, 43.597997188568115, 45.879264490945, 47.992017132895334, 44.42870991570609, 43.20198460987636, 46.14763518742153, 50.90482357570103, 54.417791094098774, 52.340005261557444, 54.99418933050973, 54.36293854032244, 53.02066469192505, 55.03235231127058, 54.171255111694336, 56.466599464416504, 56.28202404294695, 54.6590256009783, 52.694321700504844, 55.15355668749128, 56.57126365389143, 57.84064047677176, 58.10042667388916, 53.122844900403706, 58.804883684430806, 58.17132261821202, 55.40969508034842, 43.21082966668265, 46.03364651543753, 37.72641849517822, 41.898780482155935, 43.1282433782305, 48.77972745895386, 24.97807390349252, 13.391714777265276, 3.9012554373059953, 1.0447132268122263, 0.748502998479775, 0.3558478110602924, 0.2375957135643278, 0.01821800707174199, 0.12311654218605586, 0.21860505188150064, 0.2741605272250516, 0.02924462520916547, 0.2696153739733355, 0.16349094999688013, 16.67809632846287, 19.412049191338674, 23.206976345607213, 24.575766256877355, 30.675904205867223, 17.982400008610316, 4.637721495968955, 0.6813902940068925, 20.449107783181326, 62.83417878832136, 53.58936085019793, 84.59153161730084, 44.17739009857178, 5.616185060569218, 0.7411323711276054, 1.0486791282892227, 0.37148530195866314, 19.336975642613, 76.4459638595581, 97.263016973223, 13.746336936950684, 0.41341692049588474, 0.4845561331936291, 4.513014793395996, 79.33373246874127, 78.0199670791626, 83.04944842202323, 86.23602431161063, 83.95158863067627, 82.30394840240479, 73.30562128339494, 64.65268911634172, 38.196099349430625, 51.63056639262608, 23.220018114362443, 0.2980791580464159, 0.405229282698461, 0.632116818002292, 0.9135301517588752, 0.3981097675859928, 0.3235505484044552, 0.3456327649099486, 0.14330969005823135, 0.1530805536146675, 0.18367116499160016, 0.18743012685860905, 0.15513312204607896, 0.17678449595613138, 0.49050373690468924, 2.99281017269407, 35.29818637030465, 58.71647480555943, 61.69742570604597, 47.7084333556039, 67.6493707384382, 75.0314495904105, 66.51094314030239, 65.68858909606934, 70.56112452915737, 73.78735378810337, 74.1642518724714, 64.72610378265381, 66.92201941353935, 63.185542242867605, 67.82582024165562, 68.8366928100586, 67.35421821049282, 65.65203462328229, 63.545820236206055, 67.03686618804932, 64.26307582855225, 65.99803406851632, 67.37734876360211, 61.44557435171944, 60.14616394042969, 56.55601583208357, 55.96916055679321, 52.80317565373012, 54.2735082762582, 54.153426034109934, 55.00664745058332, 49.05565084729876, 53.17943102972848, 52.456939969744, 53.400918756212505, 52.773249762398855, 52.79839876719883, 50.70368364879063, 53.10807303019932, 50.16145665305001, 51.40855407714844, 54.2648959841047, 52.60226501737322, 50.68831770760672, 53.02829033987862, 56.7455974306379, 53.57189655303955, 54.216011932918, 67.93979849134172, 55.743378843579976, 58.45818247113909, 65.72802012307304, 56.844921929495676, 62.50091539110456, 61.85485798971993, 63.61167526245117, 62.928062847682405, 60.3353842326573, 57.01041759763445, 54.53790807723999, 59.91729027884347, 59.19016129629952, 57.451082774571006, 54.003925119127544, 55.68686219624111, 52.57639339991978, 49.66824919836861, 48.23254292351859, 49.85894250869751, 50.47649839946202, 51.40786967958723, 46.042866774967735, 46.070617880140034, 46.16273709705898, 49.34306655611311, 49.99230970655169, 48.448913301740376, 48.5913131577628, 47.640768323625835, 46.958003589085166, 46.978935037340435, 49.936251640319824, 49.883549554007395, 48.30696507862636, 47.52436515263149, 49.50663757324219, 53.64954962049212, 57.53421449661255, 55.72787741252354, 57.837239333561485, 57.20152085168021, 56.39371633529663, 57.17875507899693, 55.06889983585903, 59.10414259774344, 61.07624980381557, 59.08032417297363, 53.8628454208374, 60.508547237941194, 59.37741524832589, 61.557996204921174, 57.99818740572248, 52.44373491832188, 59.58167839050293, 63.062135287693565, 54.58182764053345, 48.366288798195974, 51.11816801343645, 44.524254594530376, 46.79072570800781, 54.43551594870431, 56.80074528285435, 38.36001777648926, 20.61689461980547, 8.522391148975917, 1.3343071958848407, 2.3280432266848425, 0.7502465077808925, 0.4996037600295884, 0.1841902035687651, 0.3135859359587942, 0.6763237544468471, 0.7766676300338337, 0.17968418821692467, 0.5821665440286908, 0.47023861003773554, 22.56587127276829, 32.151013714926584, 27.78487515449524, 29.669464588165283, 39.533641474587576, 40.40642554419381, 6.490121228354318, 0.6999982212271009, 27.632072108132498, 76.7424087524414, 64.6725401197161, 95.13530485970634, 49.42037568773542, 7.808704325131007, 0.42221054434776306, 1.6222174210207803, 1.0867639418159212], [0.24254695645400456, 2.033247228179659, 6.8517745307513644, 0.11096119122313601, 0.26735517382621765, 0.4232184131230627, 30.29840510232108, 61.58756078992571, 55.340411118098665, 55.09004667827061, 80.57881491524833, 57.98007345199585, 58.289473261152, 44.571314743586946, 42.39455877031599, 42.913568360464915, 34.577953474862234, 8.5441746200834, 0.2179391918970006, 0.11606105363794736, 0.25156009995511597, 0.14811544146920952, 0.1286727940397603, 0.024183627583884766, 0.13416279373424395, 0.04064627982942121, 0.059564931983394284, 0.11985757920358862, 0.10121563023754529, 0.11275310721248388, 0.06144452148250171, 0.018294388062453697, 1.6103516348770686, 10.173598408699036, 32.24987963267735, 41.58596215929304, 31.204453672681534, 47.4747063773019, 71.51631423405239, 64.16862896510533, 68.03899097442627, 69.98504938398088, 65.42614868709019, 68.00631359645298, 63.241023608616416, 61.06650842939104, 57.31084380831037, 61.26395538875035, 58.88355813707624, 61.603958538600374, 59.5764741897583, 59.969582421439036, 61.79727131979806, 62.94502340044294, 62.038533619471956, 62.26314803532192, 55.46574967248099, 55.169329098292756, 52.65493931089129, 51.11547906058175, 47.797676018306184, 47.102529593876426, 46.20208127158028, 45.547686031886506, 45.18355873652867, 46.567077091761995, 47.08979007175991, 46.380413736615864, 46.07235145568848, 46.09213645117623, 44.70048870359148, 45.59831060682024, 45.27245051520211, 46.04285635266985, 47.98640993663243, 47.436063970838276, 48.00972809110369, 49.14880187170846, 54.255237988063264, 51.73618943350655, 50.22801692145211, 57.65985182353428, 59.41424070085798, 52.10476010186331, 55.320243971688406, 58.30631569453648, 60.8878424508231, 58.47977747235979, 61.371013232639854, 56.54481881005423, 68.78377532958984, 52.7372476713998, 40.56468118940081, 56.75694383893694, 57.89783457347325, 54.7884635925293, 49.527138233184814, 50.91947385243007, 50.779415539332796, 46.46749203545706, 42.879911286490305, 43.91154507228306, 43.09228645052229, 40.87066943304879, 40.531166553497314, 42.75619861057827, 43.29320056097848, 44.47975833075387, 44.05025543485369, 43.58118254797799, 41.307881355285645, 39.52737419945853, 43.49197810036795, 41.97662462506975, 44.3457692691258, 45.083622796194895, 41.45482185908726, 41.38600690024239, 44.32946532113211, 49.25923654011318, 50.26855271203177, 53.0533629144941, 53.936148915972026, 53.547084535871235, 51.866200651441304, 52.99648148672921, 53.17428241457258, 55.09311778204781, 52.83982045309884, 50.19137559618269, 50.78114564078194, 52.410477365766255, 52.96184819085257, 57.06529794420515, 59.66835716792515, 55.51563426426479, 58.743141991751536, 56.36897380011422, 59.245482853480745, 32.17773648670742, 35.418390205928254, 32.79140486036028, 38.41750022343227, 52.004834583827424, 63.6410105569022, 32.86462845121111, 10.311647823878697, 4.587619772979191, 1.7861521329198564, 0.933670699596405, 0.1341985118176256, 0.0539667738069381, 0.08135940214352948, 0.06616838050207921, 0.053040264773049524, 0.15200439707509109, 0.14256609710199492, 0.12882057896682195, 0.4696301541158131, 9.258886303220477, 17.71213071686881, 16.80286165646144, 16.451988049915858, 18.595375299453735, 8.932989733559744, 1.4852652783904756, 0.3142849084522043, 7.166210046836308, 66.72174453735352, 39.24184840066092, 78.75659424918038, 50.059391089848106, 4.319037590708051, 3.9384821483067105, 0.38550022563764025, 0.06647391125027623, 0.24235512103353227, 0.43461212888360023, 2.303450729165758, 0.1272691222173827, 0.4775239591087614, 3.429983662707465, 60.441851479666575, 79.86076028006417, 72.01393032073975, 62.7836514881679, 86.4500288282122, 59.231232098170686, 71.4110837663923, 50.939206736428396, 52.02121843610491, 43.47317280088152, 41.920260838099885, 9.1065331527165, 0.1115015357998865, 0.03478305873328021, 0.17148994148841926, 0.049675650495503626, 0.0565550456355725, 0.03758567298895546, 0.11446334794163704, 0.0419679337314197, 0.0380383372705962, 0.05595570922430072, 0.06572643028838293, 0.03428717177095158, 0.09144520772887127, 0.06016805462007012, 1.3610567833696092, 11.199509484427315, 38.397274017333984, 48.88143866402762, 39.90806252615792, 49.272420746939524, 75.4995219366891, 67.19810608455113, 71.13198157719204, 73.79518440791539, 67.6214598246983, 67.42802892412458, 65.9628483908517, 65.1860328401838, 61.05207702091762, 63.8993376323155, 62.96392944880894, 62.90809372493199, 62.203324045453755, 61.293846539088655, 65.2314532143729, 64.99304662431989, 64.85563904898507, 65.21314471108573, 58.203718594142366, 56.407661369868684, 56.41453661237444, 53.959463596343994, 51.02281788417271, 50.25372525623867, 50.56844391141619, 49.423231397356304, 48.3065481867109, 48.97111906324114, 49.93735987799508, 49.06458970478603, 48.19278185708182, 48.34472853796822, 48.47644901275635, 47.814132826668875, 48.99542038781302, 48.0835040637425, 47.6305753162929, 49.38269560677664, 49.30170045580183, 52.980615275246755, 56.293123790196006, 55.08651351928711, 49.04758398873465, 55.70975651059832, 55.45854786464146, 50.633492946624756, 54.96190105165754, 60.88573019845145, 62.51231043679373, 60.56847545078823, 63.6717563356672, 60.241903168814524, 69.6228050504412, 49.56939022881644, 44.21858596801758, 56.415516308375764, 59.88181277683803, 57.02519989013672, 52.69050019127982, 52.16133233479091, 53.164200578417095, 45.96035691670009, 44.427344594682964, 45.64210162843977, 44.20770856312343, 43.919799532209126, 44.0192734173366, 44.734621729169575, 42.70324986321585, 43.88560049874442, 45.63656044006348, 44.58907086508614, 44.89219297681536, 42.93652868270874, 45.54635197775704, 45.979791028159006, 46.114488806043354, 47.11668307440621, 44.84651551927839, 46.058868476322715, 46.152467659541536, 51.20243229184832, 52.19882828848702, 56.07731621606009, 56.72655936649868, 55.228017057691304, 55.44890029089791, 56.00972066606794, 55.970327854156494, 56.2714558328901, 55.31343821116856, 51.600755146571565, 55.37260907036917, 55.6767178262983, 56.092595304761616, 58.903652327401296, 62.50163800375802, 59.72318540300642, 60.95182841164725, 61.09304359980992, 59.82952063424246, 40.92559494291033, 41.833248547145296, 41.826216970171245, 47.1990852355957, 61.48714542388916, 59.556178501674104, 40.30253955296108, 15.96280186516898, 8.34238851070404, 2.1042298078536987, 0.3727800010570458, 0.15050259551831655, 0.03677236734490309, 0.04731764970347285, 0.05208534887060523, 0.0691921700324331, 0.07954168146742241, 0.086387590904321, 0.17920715095741407, 0.4338848207678114, 11.7997339623315, 21.04096576145717, 20.08980253764561, 26.058567421776907, 32.66324533735003, 25.395038775035314, 1.0675662862403053, 0.17662585446877138, 6.320977321692875, 72.1388658796038, 47.48898492540632, 82.44729668753487, 70.34418787275041, 31.835575921194895, 4.634192679609571, 0.3720720719013895, 0.038149006332137754, 0.5760562547615596, 6.809640654495784, 14.621860333851405, 0.22019998915493488, 0.4339695562209402, 0.9988758521420615, 62.06329699925014, 88.02623462677002, 74.80060264042446, 77.74965436117989, 98.06834098270961, 79.02814374651227, 81.84638173239571, 56.330425194331575, 59.17924567631313, 56.79607261930193, 52.54323312214443, 14.103133882795062, 0.32976546777146204, 0.38491204434207504, 0.4274895467928478, 0.6618122788412231, 0.20437367553157465, 0.16727627973471368, 0.2381158513682229, 0.16276449683521474, 0.0919878389686346, 0.23006310633250646, 0.1800872515887022, 0.18482224536793573, 0.2128626507307802, 0.32373239578945295, 2.210182888167245, 20.57476248059954, 53.72155032839094, 58.29291956765311, 48.522289752960205, 57.47870533806937, 76.02834933144706, 66.5049329485212, 71.38544491359166, 73.65082168579102, 69.59054456438336, 70.93522248949323, 71.81547587258476, 68.37289360591343, 64.67217881338937, 67.23760659354073, 65.62909167153495, 66.50149359021867, 64.87199510846818, 65.91901915413993, 66.52423504420689, 68.42152404785156, 68.18957928248814, 69.2387364251273, 61.27588544573103, 59.27021149226597, 59.168684414454866, 56.81040675299508, 52.88023812430245, 53.85991675513131, 53.33210379736764, 53.442920616694856, 51.867228984832764, 52.01844263076782, 52.02574518748692, 52.275501659938264, 51.3875218800136, 50.71881682532174, 49.75840207508632, 51.203811509268625, 50.49211794989449, 49.62687267575945, 51.62244047437395, 52.79584877831595, 51.77140290396554, 55.995511599949424, 58.64018358503069, 56.285081250326975, 51.59611027581351, 59.81195558820452, 61.333645820617676, 56.11265475409371, 58.54417337690081, 63.232157707214355, 63.4799165725708, 60.869923046657014, 66.08808272225517, 62.41671017238072, 73.12675380706787, 54.33392981120518, 42.38991737365723, 59.04425607408796, 62.572252546037944, 56.36589922223772, 50.81085613795689, 52.40347358158657, 56.13668162482125, 50.02003649302891, 48.27850178309849, 48.61637878417969, 45.601075989859446, 47.010962758745464, 46.12647097451346, 46.10910047803606, 45.85848937715803, 47.643273149217876, 49.59355953761509, 46.23331342424665, 48.52325207846505, 45.83433396475655, 48.97119549342564, 48.316296509334016, 50.68463168825422, 51.36496455328805, 48.94144678115845, 49.718168531145366, 49.685960156576975, 52.89571523666382, 55.24196209226336, 59.381160327366416, 58.30703135899135, 58.508737564086914, 59.40586117335728, 59.059083529881065, 57.29712806429182, 59.606087412152974, 56.50046498434884, 56.7187044279916, 55.61297505242484, 56.39241007396153, 55.48852586746216, 61.24151965550014, 60.04432419368199, 60.339344705854145, 62.52392782483782, 63.89255619049072, 61.444059644426616, 45.40363597869873, 45.561123847961426, 46.43622514179775, 49.542024748665945, 63.42349025181362, 65.5681003843035, 50.68481581551688, 28.698465994426183, 12.607786008289882, 2.8732499139649526, 1.9798323001180376, 0.44085280543991495, 0.2207130023411342, 0.21450064783649786, 0.14667464021061147, 0.12264430895447731, 0.1674795009727989, 0.25290218793920105, 0.30118144729307716, 0.7330188836370195, 15.52570458820888, 29.309679916926793, 30.34925201960972, 35.20180443355015, 41.45832027707781, 43.086522919791086, 2.5341958446162085, 0.7975696570106915, 13.82376071384975, 90.894777570452, 53.70201199395316, 89.87395518166679, 82.37592479160854, 35.3338896887643, 4.839988333838327, 0.5232067363602775, 0.09025209210813046], [0.1134926425293088, 0.3371197288589818, 0.4196000572826181, 0.18394403106399945, 0.6350447780319622, 32.61910343170166, 60.61120687212263, 66.68106283460344, 51.41841009684971, 86.47486863817487, 52.36663770675659, 16.60691898209708, 51.80454233714512, 48.43878977639334, 21.315480402537755, 26.962347405297415, 37.04932696478707, 3.4231390357017517, 0.03953692257138235, 0.08489498349704913, 0.08602502250245639, 0.2838542956326689, 0.05226299273116248, 0.05974650116903441, 0.055590111163577864, 0.04699871449598244, 0.048004802116858106, 0.03932918229007295, 0.08433017773287636, 0.04889970159690295, 0.07826007130954947, 0.1393232832529715, 0.24112208719764436, 1.4515981078147888, 12.465215052877154, 20.029004062925065, 35.53612743105207, 31.373833383832658, 70.23692158290318, 67.71307182312012, 70.27289935520717, 68.47542122432164, 66.35560921260289, 61.232980319431846, 61.39393533979143, 58.559570584978374, 64.36213629586356, 61.260189465114046, 62.88024534497942, 62.24711854117257, 61.403079169137136, 59.28417042323521, 65.05415603092739, 60.378351892743794, 63.230691637311665, 58.157214300973074, 56.43006583622524, 53.73362282344273, 52.69408893585205, 48.78644289289202, 47.129471233912874, 44.45691612788609, 46.80110284260341, 44.73763724735805, 45.780339513506206, 48.614565304347444, 46.551443644932334, 46.64374351501465, 46.05978911263602, 46.211926868983674, 45.34196029390608, 45.56279141562325, 44.01646287100655, 47.00906242643084, 46.77445650100708, 44.22795908791678, 44.6994742665972, 46.032517433166504, 48.817643778664724, 54.128277029309956, 48.802903175354004, 48.952970368521555, 42.39380489076887, 42.00011648450579, 44.36325788497925, 49.578040736062185, 56.50559275490897, 63.0209116254534, 60.615730149405344, 64.83926214490617, 54.95346941266741, 39.47109726497105, 51.09900140762329, 52.291864667619976, 56.416245869227815, 58.19836500712803, 53.96236794335501, 52.8205600466047, 49.31949131829398, 41.75811767578125, 44.252111026218955, 42.763178076062886, 43.121646063668386, 40.85602263041905, 41.07463380268642, 40.47920445033482, 41.58351639338902, 44.23505319867815, 42.48742491858346, 42.631916182381765, 40.93917519705636, 41.20168856212071, 44.640164443424766, 41.858553886413574, 43.73160062517439, 41.83375923974173, 40.72008112498692, 40.66272027151925, 45.944184984479634, 50.10676738194057, 55.619996207101, 54.53562559400286, 55.023712226322715, 51.686756474631174, 53.37728098460606, 52.99357713971819, 56.90927961894444, 55.58695404870169, 54.36578382764544, 51.22054624557495, 55.87663834435599, 54.351588657924104, 57.62146997451782, 54.71520873478481, 60.49658938816616, 56.541219643184114, 61.80717945098877, 59.682225772312705, 56.81851530075073, 34.97184337888445, 39.999615464891704, 42.82079948697771, 55.0411695752825, 65.81626919337681, 54.619573729378835, 38.60783917563302, 25.249739783150808, 12.348993403570992, 3.639769971370697, 0.10418897747461285, 0.005950818270710962, 0.05834510922431946, 0.07504201041800634, 0.040841535066387484, 0.10745414905250072, 0.04919759204078998, 0.06392991383160863, 0.12214588427117892, 0.47347017377614975, 7.1227564471108575, 17.15536114147731, 16.31353998184204, 23.384574038641794, 29.071108307157242, 17.84754763330732, 0.1555949736918722, 0.3756744685981955, 0.22515317265476498, 52.61742598669869, 59.49379062652588, 43.04685912813459, 70.13496371677944, 47.638555322374614, 11.810641765594482, 1.409321359225682, 0.12673473517809594, 0.21928438757147106, 0.24212735039847239, 0.2917235647993428, 0.20525457683418477, 2.4126186541148593, 55.22648845400129, 74.56159155709403, 80.99770096370152, 63.30815710340227, 91.71114226749965, 50.06014149529593, 23.52899408340454, 64.43353598458427, 54.29376574925014, 26.575362273624965, 35.73067351749965, 42.40620395115444, 4.1746931076049805, 0.0690253454127482, 0.10237884282001428, 0.08016994382653918, 0.11136546238724675, 0.1287364541952099, 0.028174539861668433, 0.047439701189952235, 0.07112576413367476, 0.04723937729639666, 0.02591780702849584, 0.10910345055162907, 0.039699740441782136, 0.1532413935554879, 0.11413016010607992, 0.1196225346731288, 1.276659294962883, 12.894523399216787, 27.31766264779227, 46.15055343082973, 37.344086919512065, 74.27437387193952, 71.53248964037213, 72.80154337201799, 73.20600496019635, 68.98214639936174, 62.44449601854597, 63.3220465523856, 61.676066943577354, 66.75153146471295, 64.04744543348039, 65.86274569375175, 65.22387967790876, 63.59963403429304, 62.19796698434012, 66.26788820539201, 63.98478657858712, 66.55033942631313, 61.16538824353899, 57.73387098312378, 56.590357303619385, 56.5808104787554, 50.31123202187674, 50.09696347372872, 48.76021344321114, 49.886714458465576, 49.451058932713096, 49.20730570384434, 50.98155600684029, 50.09048080444336, 48.35717970984322, 47.61985077176775, 48.04081433159964, 47.09364284787859, 46.571607317243306, 46.566410064697266, 46.75842005865914, 47.49321985244751, 46.04209205082485, 45.27761650085449, 47.02347299030849, 50.146104608263286, 55.953975268772666, 48.27041755403791, 46.649159635816304, 44.33013582229614, 43.396120752607075, 44.85983174187796, 48.57927540370396, 55.13000576836722, 63.129359109061106, 60.81399004799979, 65.01268918173653, 53.90241193771362, 42.41650812966483, 61.65292249407087, 58.514553206307546, 58.04179777417864, 55.26724311283657, 52.10820640836443, 54.208393233163015, 47.846660818372456, 42.84599018096924, 45.02625846862793, 45.64173684801374, 44.75291633605957, 43.73883717400687, 43.07161555971418, 42.64997107642037, 44.781320571899414, 46.70203195299421, 44.33646215711321, 44.41193349020821, 46.768123217991416, 45.53786127907889, 46.25799689974104, 45.632151808057515, 44.9139860016959, 43.756225040980745, 43.71399736404419, 42.605599880218506, 47.43720000130789, 52.8244058745248, 57.87738602502005, 56.776318890707834, 57.449213709150044, 55.007463863917756, 54.95099932806832, 53.28342124394008, 56.863973890032085, 56.27211243765694, 56.95365081514631, 53.11034161703927, 55.2447691644941, 56.652005195617676, 55.993513992854524, 57.29448080062866, 60.943810190473286, 57.80842515400478, 64.36506148747036, 61.70240756443569, 58.14056989124843, 42.46853971481323, 46.07805592673165, 51.081141063145225, 63.895398003714426, 64.54839665549142, 56.74840450286865, 49.266316754477366, 34.50372586931501, 16.868028811046056, 5.770051181316376, 0.18971210797982557, 0.03127053399969425, 0.029729214563433613, 0.0366390759258398, 0.07612627545105559, 0.07429122499057225, 0.05872495312775884, 0.08011614278491054, 0.16600140742957592, 0.25305637823683874, 9.41926028047289, 19.152052811213903, 17.281576905931743, 32.30591338021414, 38.11922100612095, 24.742833954947336, 0.2573550875697817, 0.37022222259214943, 0.44517415070108, 48.934300558907644, 64.98962116241455, 51.88668046678816, 80.934298651559, 76.33273601531982, 30.721088341304235, 2.7709748191492896, 0.17077072151005268, 0.3451603145471641, 0.5727591716817447, 0.4625195413827896, 0.2136314037655081, 0.6249938830733299, 50.90291976928711, 91.30275494711739, 85.81472029004777, 79.16421726771763, 107.13121686662946, 82.88071141924176, 44.78405121394566, 75.99554688589913, 66.71424048287528, 38.84977197647095, 39.68586955751692, 51.942040239061626, 6.044704352106367, 0.2910196797123977, 0.288168801260846, 0.22817018362028257, 0.8471649214625359, 0.26415807966675076, 0.3368787132203579, 0.13775307179561683, 0.14385493365781649, 0.12422275782695838, 0.1568435188382864, 0.2160738855600357, 0.24415063325847897, 0.24983993225864, 0.193175893543022, 0.32798463904431885, 6.7652051874569485, 31.470899718148367, 51.4021235193525, 58.889297349112375, 49.07686022349766, 74.07946300506592, 72.61568600790841, 71.86460658482143, 74.10640117100307, 70.3145329611642, 67.18678746904645, 66.98742280687604, 63.23419352940151, 66.62764508383614, 67.93861034938267, 68.29135649544853, 67.16506740025112, 67.30017512185233, 65.11313928876604, 70.72238527025495, 67.60975905827114, 68.75947747911725, 64.75382014683315, 61.12525544847761, 58.709894861493794, 60.08760452270508, 54.82665089198521, 52.955000741141184, 51.45990473883492, 53.49239526476179, 52.08905717304775, 52.545730999537874, 55.14538908004761, 54.725592817579, 52.50276681355068, 51.32363319396973, 50.19769498280117, 50.646183831351145, 49.97161449704851, 49.05993441173008, 50.345142705099924, 53.184423310416086, 50.22653695515224, 48.866385391780305, 50.076028551374165, 54.86523076466152, 60.56693295070103, 49.63020781108311, 49.20700693130493, 44.72317109789167, 43.77045842579433, 46.3797675541469, 52.10588918413435, 60.45427485874721, 67.22843497140067, 67.29546424320766, 65.19611467633928, 56.283090591430664, 42.156669821058, 58.88437107631138, 57.74044050489153, 60.276623317173545, 59.67697293417794, 55.352914401463096, 58.86805670601981, 52.539720807756694, 45.588107177189414, 47.811621052878245, 45.42614466803414, 46.436193874904085, 44.984888894217356, 44.00364691870553, 43.06815883091518, 47.10553468976702, 50.47184310640608, 46.29570129939488, 47.96425213132586, 47.22059685843331, 46.341851234436035, 50.049931117466514, 48.54493740626744, 49.10699803488595, 47.461136545453755, 46.90441908155169, 45.86371442249843, 49.20923730305263, 57.224244935171946, 63.710291045052664, 59.60724776131766, 59.690014702933176, 58.46955667223249, 57.35061877114432, 58.35213906424386, 60.60028430393764, 59.98479897635323, 58.14472838810512, 52.3030686378479, 57.202187878744944, 61.148524965558735, 61.63453756059919, 59.108332361493794, 64.08898176465715, 61.289413588387625, 68.18932219914028, 67.00247260502407, 59.664896965026855, 44.57101249694824, 48.9045865876334, 54.05268062864031, 62.881912912641255, 66.09849112374442, 61.99298817770821, 56.771875517708914, 43.9381115095956, 21.20186345917838, 7.670589770589556, 0.3580330195171492, 0.09008893836289644, 0.20482213289609977, 0.16207235040409224, 0.15999935806861945, 0.2190642843821219, 0.17475016654602119, 0.12888018148286, 0.18935076094099454, 0.6516009782041822, 14.708810091018677, 26.89254753930228, 30.1000930922372, 54.67251205444336, 57.460911001477925, 35.81865855625698, 0.33883750811219215, 0.5234595856496266, 0.6963300609162876, 78.72156838008335, 71.09025764465332, 67.44282163892473, 88.68858555385044, 88.08997740064348, 33.59213958467756, 2.6649744042328427, 0.17858474435550825], [0.18281144755227224, 0.043456500462655506, 0.05716795953256743, 0.21971468733889715, 29.36323663166591, 72.85557951245988, 70.20682198660714, 52.484583377838135, 87.94467667170933, 69.73605373927525, 6.035418084689549, 5.720813640526362, 56.59098611559187, 38.18932138170515, 27.675984723227366, 40.0738639150347, 31.884967190878733, 2.1437492072582245, 0.0499759327753314, 0.14684731380215713, 0.12860848249069282, 0.03187340897108827, 0.02039543103559741, 0.07512329212789025, 0.03494122863880225, 0.041799100648079596, 0.04542513071958508, 0.07144291818674121, 0.06239174958318472, 0.041535455866583755, 0.029994151954139982, 0.12822477093764714, 0.04276337354843106, 0.4773252840553011, 4.69068283694131, 10.201097641672407, 26.247959681919642, 23.012383358819143, 63.73736122676304, 66.62772151402065, 63.994201387677876, 71.65900938851493, 66.92729309626988, 65.95368371691022, 60.70698084150042, 62.25936821528843, 61.75967461722237, 62.89883177621024, 63.52525356837681, 64.48238182067871, 61.50350843157087, 59.046625409807476, 61.343282972063335, 61.74913419995989, 64.62668200901577, 61.883811133248464, 61.6321473802839, 59.5715548651559, 54.88036394119263, 49.48876333236694, 48.490185601370676, 48.59696899141584, 47.2515788759504, 47.23179388046265, 49.61177771432059, 45.95907844815935, 46.73440361022949, 49.59661327089582, 44.41042225701468, 43.72748381750924, 42.23415265764509, 43.29184218815395, 44.94008343560355, 44.01774133954729, 42.14858906609671, 42.60763222830636, 44.745485237666536, 42.173786708286826, 43.17413970402309, 48.38426726205008, 48.24202374049595, 41.755376611437114, 44.178467069353374, 47.01778588976179, 47.61960063661848, 48.51281935828072, 45.03483254568917, 47.286371980394634, 53.832276821136475, 59.73908288138253, 54.49741050175258, 61.338078771318706, 65.40675626482282, 60.73603820800781, 53.65191200801304, 44.92778859819685, 47.02383082253592, 42.88820048740932, 38.00816099984305, 38.007625988551546, 41.68522065026419, 43.08894436700003, 44.68047441755022, 43.02176570892334, 40.52928706577846, 42.632062094552175, 44.590026242392405, 41.9539144379752, 45.31578295571463, 45.18931531906128, 43.50962652478899, 44.18909781319754, 44.657239641462056, 42.426378045763286, 42.3743325642177, 42.344569955553325, 40.95222738810948, 41.00978626523699, 45.74992030007498, 51.5377071925572, 53.859239305768696, 52.20924711227417, 52.328137738364084, 48.662038871220176, 52.69792086737496, 49.38990783691406, 52.88486909866333, 54.059715679713655, 55.79944733210972, 52.03007391520909, 53.105915614536826, 52.181680134364534, 49.973493984767366, 55.300684792654856, 58.787902287074495, 57.46030650820051, 58.25677156448364, 57.5985061781747, 53.89506074360439, 32.1941168648856, 43.87756838117327, 53.606887681143625, 62.38315732138497, 54.49703877312796, 51.23021813801357, 48.56470503125872, 29.90653017589024, 15.964903695242745, 1.7603751846722193, 0.11562307285411016, 0.04299725439133389, 0.012294443856392587, 0.04627141316554376, 0.029288068413734436, 0.02717558534017631, 0.07538338138588838, 0.0637909227183887, 0.21649244667163917, 0.32957327951278004, 5.260842025279999, 17.82586751665388, 20.995613132204326, 26.593314681734356, 26.575846910476685, 11.269285031727382, 0.18636649607547692, 0.11582092009484768, 0.3125751901950155, 13.418348090989248, 75.50242628370012, 42.51871613093785, 47.54622071129935, 64.86577647072929, 45.909617696489605, 7.080734176295144, 0.10425759093569857, 0.054919443758470674, 0.13437315316072532, 0.07682155671396426, 0.9122458206755775, 50.01973077229091, 87.4908481325422, 82.87112985338483, 72.18509919302804, 86.3553248814174, 75.94271973201207, 7.574556980814252, 14.86699104309082, 70.4489667075021, 43.96691179275513, 38.649340765816824, 42.592950684683665, 36.63780600684029, 2.632361514227731, 0.04107635907296624, 0.11443862212555748, 0.059506659395992756, 0.03358470482219543, 0.05296331211658461, 0.02836506231687963, 0.03882623177820018, 0.04717531680528607, 0.05329894267820886, 0.0767880981521947, 0.027428047864564827, 0.08996702597609588, 0.09759484524173395, 0.046329387197537084, 0.012096510950608977, 0.3078014792076179, 1.851930511849267, 15.527203662054879, 32.851614475250244, 31.99070140293666, 65.22262205396379, 72.77822521754673, 67.9974615914481, 73.75100081307548, 69.90815367017473, 69.28824234008789, 66.3094870703561, 65.70000498635429, 63.559890338352744, 65.34673077719552, 68.75400924682617, 66.43334565843854, 64.85265132359096, 61.94519846779959, 63.093582834516255, 67.06633349827358, 66.39795848301479, 64.65504455566406, 65.14305128370012, 63.48196629115513, 60.81775597163609, 54.17268296650478, 53.53286157335554, 50.53267805916922, 51.751704760960166, 49.74079533985683, 54.345502035958425, 49.451222215379985, 53.05030918121338, 51.92039312635149, 48.72799117224557, 48.17665161405291, 45.13539729799543, 44.139320918491904, 46.786758286612375, 44.83261912209647, 46.174444811684744, 43.647124426705496, 46.36898742403303, 45.92521987642561, 47.19088636125837, 50.04334075110299, 52.58206312997, 41.56593745095389, 45.183284282684326, 46.46375390461513, 52.059298038482666, 51.111070428575786, 48.63576078414917, 46.778302328927175, 51.88973420006888, 62.79807594844273, 65.21195656912667, 65.44829259599958, 62.39640753609793, 59.02849061148507, 51.840877941676546, 44.51953329358782, 46.16586031232561, 41.828016553606304, 39.320856366838726, 38.716383934020996, 41.59689514977591, 43.35855879102434, 46.10915953772408, 45.857002462659565, 44.3915752683367, 46.42382608141218, 48.47286721638271, 46.46676594870431, 46.90792792184012, 48.52080283846174, 47.991860798427034, 48.47553532464163, 49.79301452636719, 48.623149803706575, 46.42374617712838, 46.14755180903843, 43.27261304855347, 44.37744263240269, 48.370721748897004, 52.28777912684849, 53.76988547188895, 55.50275577817644, 53.68839005061558, 49.63172599247524, 55.39561455590384, 51.39601952689034, 52.47167362485613, 54.66747113636562, 55.101490361349924, 51.309542247227256, 54.42462812151228, 53.32487072263445, 52.38284437997, 57.71142135347639, 61.36571175711495, 60.31478977203369, 58.700591223580496, 58.73679828643799, 57.23197133200509, 39.80100815636771, 49.05590098244803, 56.509313515254426, 62.67769145965576, 58.57644081115723, 57.34436886651175, 54.4478246825082, 35.499545165470664, 16.361687523978098, 1.518702072756631, 0.12251823714801244, 0.06348763113575322, 0.014232385670766234, 0.015518218012792724, 0.044117474995021305, 0.030905115750751326, 0.08046068251132965, 0.048790440495525084, 0.43559543469122475, 0.21451695981834615, 6.827629974910191, 25.279325212751115, 27.835636956351145, 43.860354219164165, 38.17663744517735, 10.133852975709097, 0.15083462984434196, 0.06232861868504967, 0.31385393014975954, 5.5199816056660245, 72.05963557107108, 51.252810205732075, 57.01573644365583, 73.97722026279995, 74.1137593133109, 13.259673816817147, 0.28705261115516933, 0.2663556917437485, 0.201232587652547, 0.2662834684763636, 0.3137394477214132, 42.07599776131766, 103.85596111842564, 84.05069773537772, 77.08036913190568, 97.38539559500558, 105.27640220097133, 23.29527579035078, 23.131942749023438, 80.89828613826207, 52.460358483450754, 46.31254373277937, 50.86648688997541, 45.16551079068865, 4.1601088387625555, 0.1901377529970237, 0.2736187848661627, 0.20473502257040568, 0.14977247826755047, 0.15759369358420372, 0.24179063418081828, 0.10854653614972319, 0.12181363281394754, 0.1189686440463577, 0.14132356377584593, 0.09642641472497157, 0.16615813544818334, 0.14994116207318647, 0.22889333910175733, 0.1493206825107336, 1.9398517140320368, 7.935348272323608, 35.16788680212838, 49.55114425931658, 46.05801037379673, 69.18087877546037, 72.06540952410016, 70.31080177852085, 73.25167546953473, 71.02128287724086, 69.44333308083671, 67.23196465628487, 68.39011819022042, 65.58003738948277, 63.782691274370464, 68.47617857796806, 67.71358598981584, 65.41651153564453, 64.11466925484794, 65.8414147240775, 70.31948007856096, 68.92760304042271, 68.47071034567696, 67.84064074925014, 64.58904361724854, 61.178603717258994, 56.267047200884136, 55.33210107258388, 53.53620365687779, 54.08510787146432, 52.41665778841291, 56.043388162340435, 51.84677348818098, 54.33761235645839, 55.89382471357073, 50.53666632516043, 49.73052937643868, 47.517166818891255, 47.017952646527974, 49.99741315841675, 49.21219028745379, 48.4284473827907, 47.44058377402169, 51.22892229897635, 46.27301543099539, 48.208206857953755, 54.00220891407558, 49.516893114362446, 42.485170228140696, 46.52854585647583, 47.7131998198373, 51.15339190619332, 49.2759747505188, 45.49430649621146, 48.12377234867641, 54.601497990744456, 63.321810313633506, 63.18506976536342, 64.00230993543352, 65.47081865583147, 60.271738733564106, 54.82849563871111, 48.92578901563372, 49.79674570901053, 47.46600028446743, 42.38925382069179, 40.19374465942383, 44.700447014399934, 45.10557562964303, 48.88784490312849, 47.140560558864046, 43.788416045052664, 46.96642827987671, 48.68241098948887, 48.07851873125349, 49.10529572623116, 50.81260708400181, 48.362620149339946, 48.4486596924918, 50.16715070179531, 49.1197966166905, 49.563307080950054, 47.3318236214774, 47.74460220336914, 47.21385015760149, 53.000542708805625, 57.102700097220286, 59.7343442099435, 59.79619707380022, 57.28329420089722, 53.103772095271516, 58.538580077035085, 54.36417531967163, 56.46840599605015, 57.816033431461875, 58.59364455086844, 52.92631162915911, 57.15590592793056, 55.66653176716396, 52.82892220360892, 57.107004506247385, 63.88977691105434, 62.017876625061035, 62.432024002075195, 57.73105696269444, 60.198324067252024, 44.52184009552002, 50.185334137507844, 56.383130754743306, 62.79082202911377, 60.944991384233745, 60.27496269771031, 62.07406670706612, 46.123670850481304, 18.572309017181396, 1.2427565370287215, 0.1569953749754599, 0.09841222209589821, 0.10281624684908561, 0.1360522966299738, 0.2289785902415003, 0.2268872367484229, 0.167554750506367, 0.146899886695402, 0.4621421673468181, 0.5935868855033601, 8.837567516735621, 30.76917334965297, 35.71585300990513, 54.792722838265554, 51.44479588099888, 23.121676785605295, 0.31837650175605503, 0.560479642025062, 0.3442175308508532, 22.775449786867412, 97.31441279820034, 54.100578035627095, 74.10282284872872, 82.32057544163295, 81.42294461386544, 12.220260654176984, 0.18410116620361805], [0.197696592392666, 0.07352817165000097, 0.2497175516826766, 17.68070748874119, 74.4035061427525, 79.31750842503139, 54.143521377018516, 92.94026470184326, 79.37180859701974, 21.101102420261928, 0.9845462782042367, 27.543140377317155, 56.09026418413435, 30.497946943555558, 19.671465396881104, 42.33602019718715, 25.549799476351055, 1.2536484897136688, 0.028777548843728643, 0.06871046445199422, 0.040135458311332126, 0.009546326140740087, 0.035593005628990274, 0.04503768722393683, 0.009738676399657769, 0.06242173404565879, 0.01447746912682695, 0.18381820353014128, 0.027709682305742587, 0.030279805018965687, 0.12774849363735744, 0.004194643689386014, 0.15362427729581082, 0.0634739382990769, 0.3482064753770828, 4.371238103934696, 11.4719101360866, 16.64468765258789, 43.88665662493025, 75.09228106907436, 58.88009793417794, 65.935562814985, 68.08302170889718, 64.4883781160627, 63.96740913391113, 66.73921925680978, 64.31204673222133, 65.18097455160958, 69.42505931854248, 66.6086973462786, 66.29081726074219, 63.31661306108747, 61.31868634905134, 64.12556403023856, 64.67716761997768, 60.73514883858817, 63.41488143375942, 65.25008828299386, 61.315191405160085, 54.21051243373326, 51.83839396068028, 50.80713537761143, 50.49262169429234, 47.97373294830322, 50.52381910596575, 49.38575628825596, 49.20225436346871, 51.903675760541645, 48.381192684173584, 46.06913096564156, 43.83907536097935, 42.188714912959504, 41.28914206368582, 42.14635174615042, 40.50173051016671, 41.31596211024693, 42.58959123066494, 45.99959339414324, 47.597171851566856, 47.660852091653005, 51.737092699323384, 42.928197792598176, 39.007440498897004, 47.1049336705889, 59.741480009896414, 60.37939412253243, 61.30176053728376, 49.16267742429461, 45.2743821144104, 54.08549002238682, 61.595273290361675, 62.55041435786656, 50.109074183872764, 50.05972112928118, 40.84482560838972, 43.38351672036307, 40.87368147713797, 37.26878581728254, 38.59345987864903, 36.68678385870797, 36.46211733136858, 40.687528814588276, 43.28945548193795, 45.03361661093575, 46.15252324513027, 46.41566889626639, 46.03022452763149, 45.47224249158587, 46.52413027627127, 48.47290890557425, 50.06988634381975, 47.65465429850987, 50.15333420889718, 48.02231822695051, 45.56532403400966, 45.783598218645366, 42.59678609030587, 40.81088365827288, 47.32262420654297, 49.562389918736045, 49.08048370906285, 50.4636025428772, 48.641982895987375, 46.62937464032854, 51.49269328798567, 49.43890653337751, 50.1587746483939, 54.2199341910226, 51.659686292920796, 51.107339245932444, 53.31429556437901, 54.60532297406878, 56.56157439095633, 56.45941155297415, 52.23958642142159, 56.246046270642964, 54.35500717163086, 60.138402802603586, 44.24745920726231, 33.03209045955113, 48.9447853905814, 52.01335654939924, 50.94267736162458, 46.77095808301653, 48.887257780347554, 27.661198956625803, 13.62333037172045, 5.565424561500549, 0.4297047464975289, 0.056560436596295664, 0.15189025391425404, 0.04267621911796076, 0.07387035685990538, 0.07632413626249347, 0.016995266612086977, 0.07878665519612175, 0.11171335407665797, 0.28198170182960375, 0.034110905336482186, 6.031561400209155, 20.102462155478342, 17.875026021684917, 26.26060540335519, 27.227766854422434, 4.468209769044604, 0.8976754482303346, 1.3525164702108927, 0.9593452704804284, 0.5286347450954574, 31.858289582388743, 67.10078961508614, 33.98520612716675, 52.664833545684814, 75.34489672524589, 28.51982954570225, 0.4726830731545176, 0.1116158960919295, 0.12294703056769711, 0.1939287959997143, 33.8551219531468, 93.56956304822648, 82.86843395233154, 74.65200151715959, 86.70010839189801, 83.27984373910087, 26.811915431703838, 3.6833985788481574, 51.97231354032244, 62.93470532553536, 36.64761686325073, 27.99033338682992, 42.813503878457205, 28.3773741040911, 1.5357577289853777, 0.06103718334010669, 0.06020799997661795, 0.04024550990600671, 0.026041181658261588, 0.00889696303888091, 0.1316577238695962, 0.0380969728742327, 0.05780031345784664, 0.10536092958812203, 0.05237429283027138, 0.026269540922450166, 0.020999912438648086, 0.04017085748325501, 0.024556195895586694, 0.14820454668785843, 0.028475753430809294, 0.2250941265374422, 9.964831965310232, 21.167916297912598, 29.047706774302892, 47.74896567208426, 78.30862998962402, 65.13891015733991, 67.93127305167062, 69.62437534332275, 66.62486580439976, 64.34490476335797, 67.76444680350167, 65.3679505756923, 65.6325935636248, 69.12331295013428, 69.80668217795235, 68.44607203347343, 64.5798442023141, 62.11552660805838, 65.35797296251569, 65.624130657741, 62.145792961120605, 66.42216600690568, 69.60407270703996, 65.2746501650129, 58.38636589050293, 54.416359765189036, 54.173930168151855, 53.24442795344761, 52.90006480898176, 52.88508449281965, 52.31500564302717, 51.917582580021445, 55.61069604328701, 50.934190137045725, 49.968272413526265, 45.96635321208409, 45.33026647567749, 43.90104981831142, 45.1401880809239, 40.27714736121041, 45.02157538277762, 43.323890754154746, 47.40739917755127, 51.57422692435128, 51.15262760434832, 53.06753029142107, 45.088417053222656, 38.53241300582886, 46.66820117405483, 58.7118889944894, 64.27274772099086, 62.62630953107561, 52.82205390930176, 44.559336049216135, 54.128290925707134, 54.907930919102256, 52.94116340364729, 49.77869428907122, 47.68395485196795, 41.733597482953755, 44.157400131225586, 43.68204607282366, 40.002266202654155, 40.645259448460166, 38.079296657017295, 38.11153629847935, 42.13634634017944, 46.26236036845616, 46.047292777470176, 48.06956945146833, 47.69444663184029, 47.439927169254844, 47.83275399889265, 49.65308822904314, 50.64681959152222, 52.47889280319214, 51.30429288319179, 51.78841209411621, 52.88180146898542, 49.491705894470215, 47.506181716918945, 45.17977544239589, 45.937556403023855, 51.169202532087056, 51.43625654493059, 52.38678748267037, 52.9137909752982, 50.11146436418806, 45.27440990720476, 52.96004860741751, 54.67629187447684, 49.736845288957866, 53.86321020126343, 53.03832701274327, 53.105502196720664, 53.23787580217634, 57.64841856275286, 56.595005648476736, 55.8063816343035, 52.73979418618338, 57.399940558842246, 54.73722062792097, 62.17207104819161, 49.45786816733224, 42.93892928532192, 53.18632364273071, 54.24651452473232, 53.55882699148995, 51.55134998049055, 54.797277382441926, 31.169577189854213, 15.890929698944092, 8.789260166031973, 0.2397385271532195, 0.0885635848556246, 0.029087184728788476, 0.09255486354231834, 0.024107780939500247, 0.05902968320463385, 0.04975103573607547, 0.09437982418707438, 0.08007171909723963, 0.21356948065970624, 0.10429953118520123, 9.01421070098877, 25.355916942868912, 22.668378046580724, 40.557833739689414, 41.4768511227199, 4.138925518308367, 0.4472322016954422, 1.9060159410749162, 0.48461654995168957, 0.22444105015269347, 17.59823410851615, 71.14306395394462, 46.57535239628383, 59.87334292275565, 85.48916244506836, 44.38175398962838, 0.7727612225072724, 0.2937494803752218, 0.37901850630130085, 0.3956359917564051, 25.300666604723247, 103.28858511788505, 89.98720387050084, 80.92119434901646, 104.80618980952671, 103.8964899608067, 55.070129667009624, 5.692484532083784, 66.14932414463588, 75.80851527622768, 44.21939543315342, 30.850404739379883, 51.58982910428728, 37.609737396240234, 2.222942820617131, 0.15249579213559628, 0.12947972145463738, 0.1782668235578707, 0.1279715552393879, 0.15013381173568113, 0.2671036816069058, 0.13863923852997168, 0.15397555487496511, 0.15398143098822661, 0.34785252436995506, 0.2710284910031727, 0.10869884690535919, 0.1610317083873919, 0.12911351610507282, 0.2802489133817809, 0.17526140197047166, 0.4898081028035709, 19.468708276748657, 42.265714849744526, 46.82792288916451, 54.96855395180838, 79.02683053697858, 64.04041385650635, 69.38928999219621, 72.88583891732353, 69.44466018676758, 64.75358390808105, 69.86584608895438, 67.52895150865827, 68.74125930241176, 71.12366458347866, 67.59177017211914, 66.79985618591309, 62.32470212663923, 62.45451532091413, 67.31985936846051, 70.81685297829765, 64.86445631299699, 69.46707507542202, 72.55970437186105, 69.26458372388566, 60.96686431339809, 58.41174071175711, 55.34565353393555, 56.674454825265066, 55.07557358060564, 56.57684653145926, 55.23932177679879, 53.32566629137312, 57.05509451457432, 53.82362631389073, 52.11552633558001, 48.17206580298287, 47.63501868929182, 45.71803501674107, 47.868832520076204, 43.555901527404785, 47.00113105773926, 45.94975396565029, 48.814576148986816, 53.31321859359741, 53.394693170275005, 56.14186498097011, 42.66561147144863, 41.49444396155221, 49.35163368497576, 60.279729161943706, 62.85504422869001, 59.93291677747454, 49.060931478227886, 48.226213114602224, 63.98935154506138, 62.168541363307405, 56.5195586340768, 51.783784593854634, 51.88375874928066, 41.474120480673655, 43.86306401661464, 44.741722788129536, 41.452768666403635, 42.842307635716026, 38.86923040662493, 39.254605293273926, 42.011594908578054, 47.02697835649763, 49.06471129826137, 49.759628432137625, 47.985781124659944, 49.9477231161935, 50.06925058364868, 51.4627673966544, 53.59980051858084, 54.01323223114014, 53.3408203125, 54.31589576176235, 54.06834881646292, 52.78572525296892, 50.48050403594971, 50.206540039607454, 47.75909267153059, 52.683294909340994, 55.660695280347554, 56.59219510214669, 55.421705041612896, 53.97432926722935, 51.159794671194895, 55.58635650362287, 56.85240166527884, 55.730660166059224, 57.937817982264924, 55.2161808013916, 53.805745124816895, 57.3070570400783, 60.97284671238491, 59.66338920593262, 58.99053260258266, 55.77161284855434, 60.5725679397583, 58.782698086329866, 66.02869646889823, 51.40868609292166, 48.27532993044172, 56.656128951481406, 56.04904399599348, 56.863744599478586, 55.02652972085135, 62.54671791621617, 37.50170680454799, 20.791608810424805, 12.764286364827838, 0.5788142553397587, 0.1390580167727811, 0.2924303540161678, 0.13920307398906775, 0.11714137638253824, 0.18491943872400693, 0.11325875150838069, 0.16001866917525018, 0.20396074626062596, 0.6259277101073946, 0.18548205282006944, 12.183799982070923, 34.27181237084525, 32.78582545689174, 44.62969698224749, 64.22001784188407, 11.507769789014544, 3.3019659263747076, 2.5496527637754167, 1.4219835826328822, 1.0376742673771722, 51.68423080444336, 89.19272599901471, 51.226483481270925, 76.67537253243583, 103.89075074877057, 47.935976437159944, 1.1596409912620271], [0.19240283859627588, 0.20846997786845478, 3.0583101894174303, 62.66876302446638, 94.52910232543945, 60.09472642626081, 94.22909995487758, 77.19750881195068, 49.957568713596885, 0.6730590239167213, 4.649328027452741, 52.23640762056623, 36.526082447596956, 24.888162476675852, 31.824323313576834, 44.38620431082589, 20.665530272892543, 0.7538290641137532, 0.10131789903555598, 0.01422244428457426, 0.0882659861817956, 0.05778766556509903, 0.07527890056371689, 0.09717451315373182, 0.006972356558045638, 0.0401445065758058, 0.12020523340574332, 0.024828883852543573, 0.06453591345676354, 0.09973748241152082, 0.032646976211773496, 0.07466142691139664, 0.020334773397605335, 0.06472692784986325, 0.051289742812514305, 0.6920852544052261, 3.5514770405633107, 6.926638330732073, 30.297206538064138, 63.54513236454555, 64.13669504438127, 62.31471756526402, 62.11993176596505, 63.96622794015067, 62.25311483655657, 65.02840600694928, 63.24286488124302, 62.7690463747297, 66.39835453033447, 67.6791020802089, 67.67118113381522, 65.2034797668457, 57.84375326974051, 61.21955639975411, 61.43292168208531, 61.29924528939383, 64.61880275181362, 65.49987602233887, 63.34127221788679, 54.69322810854231, 47.98469720567976, 54.22108064379011, 52.0103097643171, 48.318464347294395, 48.50004856927054, 52.177823884146555, 48.503397600991384, 50.86740057809012, 48.593265601566856, 48.29140458788191, 46.91408749989101, 43.45746987206595, 41.0999356678554, 42.03555924551827, 38.81157772881644, 39.27596752984183, 37.25082124982561, 41.08253043038504, 43.18341902324131, 47.63236100333077, 48.30548511232649, 51.45506531851632, 43.44826698303223, 41.44706766945975, 53.68478740964617, 61.81135531834194, 63.81968348366873, 55.61760255268642, 40.32762949807303, 41.05286509650094, 36.53687994820731, 42.278704507010325, 48.02168594087873, 47.25668232781546, 46.6181081363133, 46.978782176971436, 40.16221373421805, 36.50061729976109, 38.9899206161499, 37.444220883505686, 34.024442604609895, 41.14100646972656, 42.8434853553772, 41.81142772947039, 43.48539468220302, 47.691344261169434, 41.15218264716012, 42.627980027879985, 44.916945934295654, 47.59085593904768, 47.999107769557405, 49.528913497924805, 47.44704907281058, 48.14259501865932, 45.93050398145403, 47.28425972802298, 43.609590257917134, 46.271156787872314, 53.50265775408064, 49.325174944741384, 47.88452502659389, 50.03059775488717, 46.177154609135215, 42.52552883965628, 49.833974157060894, 51.100213868277415, 45.853125367845806, 51.9418283190046, 54.54697895050049, 56.96881525857108, 51.97031593322754, 49.97747182846069, 47.56338276181902, 58.171492849077495, 49.46728992462158, 51.46785347802298, 43.3412959916251, 52.63853808811733, 36.981064387730186, 40.70546211515154, 46.28310421534947, 48.61981119428362, 48.02363838468279, 45.484711033957346, 38.20021268299648, 19.28087936128889, 12.867842316627502, 3.4316384196281433, 0.2532890614654337, 0.008452594696011926, 0.06566863946084465, 0.020381090197978274, 0.04197747393378189, 0.06970592282180275, 0.2166911352957998, 0.0880530686782939, 0.051380174567124674, 0.0493776616640389, 0.17463485630495207, 5.416830386434283, 12.621708461216517, 10.182380063193184, 24.73456733567374, 17.528003454208374, 2.42744328720229, 10.581933617591858, 12.65774963583265, 5.042916553361075, 1.3699467863355363, 1.6878472822053092, 59.411002840314595, 71.35680443899972, 36.32899332046509, 76.37341771806989, 56.19807938167027, 1.2875707894563675, 0.35385780355760027, 0.34463073153580936, 7.748564192226954, 82.52747889927456, 94.543123790196, 78.7608951841082, 91.19951861245292, 74.28785337720598, 52.532588481903076, 0.7361030695693833, 20.306713138307842, 74.16520377567836, 39.85283129555838, 31.906232152666362, 37.62309878213065, 49.576043128967285, 23.201518535614014, 1.173663324543408, 0.08791718525545937, 0.06770403417093412, 0.24039198351757868, 0.040891746657767465, 0.021837670788434998, 0.0970302362527166, 0.09234936242657048, 0.1001667779471193, 0.1011078381644828, 0.009207549721135624, 0.038835765195212195, 0.15660774149000645, 0.09687996788748673, 0.011057216674089432, 0.13306785534535134, 0.057207416343901835, 0.04014208420578923, 0.5561596538339342, 4.71712681225368, 10.670449325016566, 30.809260981423513, 65.55507946014404, 67.64222799028668, 66.8054564339774, 64.39373670305524, 66.77004146575928, 67.93874931335449, 65.73113291604179, 65.85387979234967, 64.82153729030064, 67.73189449310303, 66.727205821446, 68.02220412663051, 64.57650906699044, 60.10674680982317, 61.6572025844029, 63.02112701960972, 62.39167581285749, 66.65472221374512, 65.93181773594448, 64.87596252986363, 58.12773656845093, 49.1326334135873, 56.96380908148629, 53.87303147997175, 51.41040229797363, 50.50685855320522, 52.01086214610508, 48.80945185252598, 53.23924112319946, 51.41996649333409, 50.68286337171282, 47.46776165281023, 47.389455454690115, 42.19711875915527, 44.61497722353254, 41.995509828839985, 41.790194034576416, 38.594126905713765, 42.114515100206646, 45.93476670128958, 49.833046572549, 51.309715952192036, 52.49304975782122, 46.66723884854998, 43.13697378976004, 50.28589194161551, 60.49069731576102, 60.37999166761126, 55.27403845105852, 42.86126579557146, 36.94363791601998, 34.736827509743826, 43.726573603493826, 50.38274982997349, 49.78648321969168, 51.39941719600132, 49.259969575064524, 41.341642652239116, 37.78444637571062, 39.12479209899902, 39.69415181023734, 34.675325529915945, 41.31138672147478, 44.464930874960764, 44.539071628025596, 45.72142226355416, 49.51341554096767, 44.385294096810476, 43.37265321186611, 46.17172459193638, 48.84410946709769, 50.00538969039917, 50.78175360815865, 49.160874366760254, 53.62545674187796, 48.86096232278006, 51.38824796676636, 45.69648517881121, 50.77830382755825, 57.70068291255406, 53.38865865979876, 48.73385892595564, 53.11388519832066, 48.75393574578421, 43.252973965236116, 49.524598666599815, 51.11395045689174, 45.897312436785015, 54.71166515350342, 53.97953346797398, 58.750027656555176, 54.495294775281636, 50.30397810254778, 49.37644222804478, 59.09424836294991, 54.2347685950143, 55.86816154207502, 48.670039721897666, 55.51813561575753, 37.829554080963135, 47.62642724173409, 54.53940888813564, 53.42504290172032, 49.90337971278599, 50.17867776325771, 45.22617203848702, 22.176779099873134, 19.598663909094675, 3.804509154387883, 0.08965403134269373, 0.0037835074472241104, 0.0871405815705657, 0.03490081848576665, 0.050463731600237746, 0.05004047841898032, 0.06461446067052228, 0.08768645620771817, 0.04009719232895544, 0.17385944005634102, 0.09019299170800618, 7.249280972140176, 17.57964072908674, 11.851484145436968, 28.087566477911814, 40.62350116457258, 1.4297971576452255, 14.908647230693273, 14.923518112727574, 5.160699810300555, 1.2259937907968248, 0.5723467309560094, 52.00243398121425, 76.36553846086774, 46.70108004978725, 85.49210848127092, 71.71150997706822, 2.150739746434348, 0.49531683006456917, 0.3574022262224129, 5.267216997487204, 87.15762642451695, 109.1893288748605, 80.4884535925729, 108.10755688803536, 87.63966464996338, 78.63330541338239, 2.270615062543324, 28.339014836720057, 92.07745824541364, 45.86493035725185, 40.545924527304514, 41.4488776751927, 59.66649505070278, 30.098522799355642, 1.7217329953398024, 0.21701928840151855, 0.1991504758064236, 0.3330507443419525, 0.11950529739260674, 0.23558936693838664, 0.18743684435529367, 0.16275801004043647, 0.17300137824245862, 0.25069437069552286, 0.14011757634580135, 0.2348478367286069, 0.26198655047586983, 0.15677006063716753, 0.1976719480007887, 0.3231582465980734, 0.20495995692908764, 0.18338164766984327, 1.127345438514437, 9.515029038701739, 26.576524359839304, 49.1819725717817, 69.72269930158342, 70.44238676343645, 65.70556354522705, 64.29510007585797, 68.07227284567696, 68.31032507760185, 69.87633786882672, 68.0470369883946, 63.874060085841585, 68.74433040618896, 70.15180615016392, 68.79997158050537, 65.61212417057583, 60.01644107273647, 64.64800603049142, 65.71737548283168, 65.91196673257011, 69.21239580426897, 70.18665831429618, 66.73637744358608, 63.41884190695626, 53.00164747238159, 60.612652097429546, 57.719408307756694, 52.09110689163208, 52.553158623831614, 59.16625254494803, 53.53386558805193, 55.33511659077236, 52.83813204084124, 52.725717135838096, 51.10261794498989, 49.49251535960606, 45.47200277873448, 47.18244777406965, 44.0970515523638, 42.974236556461875, 39.38156277792794, 44.07287529536656, 50.492910044533865, 52.61318758555821, 53.013921465192524, 55.14893960952759, 44.5392244883946, 43.454680170331685, 52.82759509767805, 62.91265869140625, 62.64620917184012, 54.90193462371826, 41.636173316410606, 41.611236231667654, 36.64066171646118, 42.71613529750279, 48.119770186288015, 48.21867431913103, 51.870018686567036, 51.69983645847866, 45.00539302825928, 42.47645718710763, 43.53140217917306, 41.860509804316926, 35.590125356401714, 44.00522763388497, 46.92810549054827, 45.62944548470633, 46.45473166874477, 49.494064807891846, 44.25378901617867, 47.0522906439645, 48.28824315752302, 51.65558338165283, 51.904850006103516, 52.88269778660366, 50.628483295440674, 56.38322108132498, 51.55216986792428, 54.16612386703491, 48.60774564743042, 53.13184629167829, 59.46976375579834, 54.85874114717756, 52.643540791102815, 55.15176057815552, 52.24807712009975, 42.833816937037874, 52.667553765433176, 54.41992766516549, 49.13494716371809, 58.501045908246724, 57.59620632444109, 63.453318868364605, 57.604217597416465, 52.0811744417463, 51.093053749629426, 62.66032791137695, 55.73368610654558, 59.783989088875906, 48.98478616986956, 57.89947782244001, 49.69325576509748, 57.7270131111145, 59.22447844914028, 56.183908530644004, 51.94312763214111, 52.79803051267351, 50.30109807423183, 33.63029561723982, 27.159862109592982, 4.000317207404545, 0.24776244802134378, 0.11358864166374717, 0.09109890381140368, 0.2119531695331846, 0.15612588663186344, 0.1497430434184415, 0.26616133217300686, 0.27985910858426777, 0.19361185229250363, 0.5867876389196941, 0.21464917915207998, 9.876505596297127, 23.254442964281353, 19.140275614602224, 37.759519713265554, 48.57399129867554, 5.197510063648224, 21.83077096939087, 19.313346556254796, 8.232073698725019, 1.9030914008617401, 2.791113087109157, 76.97640323638916, 87.01618194580078, 55.52328770501273, 97.18722602299282, 75.96350179399762, 2.307108304330281], [0.31487859945212093, 0.01298291262771402, 18.604781423296245, 105.14608873639787, 56.20746987206595, 94.95184462411063, 73.08942808423723, 57.168437004089355, 7.205257185867854, 0.12298973756177084, 41.80260351725987, 55.1825966835022, 39.023820877075195, 37.27007123402187, 28.95466344697135, 31.0115647315979, 18.65519060407366, 0.548512401325362, 0.03637457958289555, 0.05042634432071021, 0.0175652852215405, 0.03906284372455307, 0.06741980263697249, 0.032211237986172946, 0.04830906739724534, 0.008900594049399453, 0.015775141904928854, 0.0516747028699943, 0.06115639515753303, 0.1021543223676937, 0.08887725802404539, 0.007258792906733496, 0.03244141063519886, 0.07796627243182488, 0.09241469856351614, 0.03498941141047648, 0.04500247125646897, 0.5038094829235757, 5.654002802712577, 48.99368681226458, 62.48390620095389, 61.05714920588902, 61.773835045950754, 62.33577755519322, 63.055687359401155, 58.69106524331229, 63.56309345790318, 62.7336869921003, 67.88565117972237, 60.56771809714181, 61.67123099735805, 63.95393657684326, 61.47991234915597, 60.2914924621582, 60.049097606113975, 59.01723452976772, 63.054874420166016, 58.44854531969343, 61.339586530412944, 55.79704672949654, 47.750428267887656, 50.97365937914167, 49.53083120073591, 50.96275765555245, 46.214310101100374, 46.782599789755686, 45.664968150002615, 47.920638288770405, 48.84088550295149, 48.56184932163784, 45.135484150477815, 44.6919458934239, 42.00502191271101, 39.69806364604405, 41.305779525211875, 39.17989478792463, 36.69710193361555, 37.829081603458945, 40.397135802677695, 45.77528122493199, 50.14098378590175, 54.89763021469116, 51.576231479644775, 43.030979020254954, 43.23844180788313, 53.98057222366333, 55.1193402835301, 53.094621317727224, 45.115230151585166, 36.35083498273577, 39.764940057482036, 47.169614451272146, 51.117483615875244, 53.57877179554531, 52.470468112400596, 46.1550350189209, 38.245983941214426, 34.030456270490376, 37.956775597163606, 37.731858934674946, 35.03380046572004, 38.58212389264788, 40.27378790719168, 41.35091502325875, 43.44274663925171, 48.06145395551409, 46.756280013493125, 42.843961306980674, 40.02150229045323, 42.0030312538147, 46.840412276131765, 45.62407105309622, 45.91598572049822, 47.57850204195295, 43.61723327636719, 42.5466513633728, 42.37030608313424, 47.402472904750276, 56.31094939368111, 53.710440158843994, 49.86141259329659, 47.291100229535786, 45.70145661490304, 47.819757393428254, 49.67803921018328, 42.58889988490513, 41.409172194344656, 51.78160980769566, 48.04277719770159, 46.80676562445504, 50.313688210078645, 43.66336931501116, 49.65878575188773, 49.85809135437012, 52.89157411030361, 51.17224931716919, 45.346914359501426, 30.05985607419695, 8.840445808001927, 15.939144986016409, 36.44007069723946, 49.2288555417742, 45.260812282562256, 46.83099399294172, 28.27848560469491, 6.203802032130105, 3.2154834355626787, 0.08196865873677389, 0.16753263026475906, 0.08740352746099234, 0.10073339539979186, 0.005848823855298438, 0.06349037241722856, 0.013580307580663689, 0.06785900478384324, 0.06098239163735083, 0.11384041208241667, 0.167918024584651, 0.07982522089566503, 3.5029569012778143, 14.864338568278722, 28.627154895237513, 30.46428292138236, 23.965097767966135, 6.630079661096845, 12.651881882122584, 26.85354208946228, 17.523966550827026, 3.6361920833587646, 0.16842438812766755, 13.84364037854331, 65.71598584311349, 51.997427804129465, 71.44832611083984, 73.2404054914202, 2.4024030651365007, 0.4140086573149477, 0.06902858881013733, 27.518588917596, 115.90667356763566, 59.793695722307476, 102.67314842769078, 72.05391720363072, 65.46765027727399, 6.191264007772718, 0.22085867023893765, 65.01088959830147, 64.17027568817139, 49.08575391769409, 46.040372371673584, 35.849578039986746, 33.9386670930045, 24.459462097712926, 0.5895717495254108, 0.037862722229744704, 0.09859189138348613, 0.028023928836254135, 0.06558067418102707, 0.09475726607654776, 0.09989616461098194, 0.04732976833890591, 0.04246925236657262, 0.05185785304222788, 0.034949974955192635, 0.04409874742850661, 0.04625023269493665, 0.11629726524863924, 0.07284274950091328, 0.03375682540770088, 0.04508683690801263, 0.044530221061514955, 0.07532784329461199, 0.03163049004173704, 0.33429170346685816, 2.4197264441422055, 44.58042730603899, 66.45171669551304, 62.573572703770225, 65.09767954690116, 64.91232245309013, 65.58180223192487, 59.383425440107075, 65.71067741939, 66.39936896732875, 69.34170872824532, 62.06791755131313, 62.34271880558559, 63.30128533499581, 61.37904535021101, 60.14979090009417, 60.25208922794887, 59.81567982264927, 62.13760798318045, 62.336590494428364, 63.463928767613, 58.773436137608115, 51.1384220123291, 52.01878309249878, 50.64780623572213, 51.400660923549104, 48.72917931420462, 50.176777430943076, 47.540415491376606, 48.72259242194039, 53.26109668186733, 49.93203755787441, 47.64547572817121, 46.033153193337576, 44.854759556906565, 43.27978358949934, 42.864792006356375, 42.52474021911621, 38.99212319510323, 39.08781726019723, 40.676884174346924, 46.73610591888428, 52.65354272297451, 53.19291748319353, 52.78426265716553, 45.86517701830183, 44.46884618486677, 51.80616126741682, 54.19176966803414, 51.61886215209961, 44.490482875279014, 38.778483458927695, 42.2485145841326, 47.543003695351736, 51.14356367928641, 55.13373695101057, 52.92153821672712, 48.213060174669536, 41.464917591639924, 36.324292864118306, 41.104643072400776, 40.40446615219116, 38.895105498177664, 39.32314232417515, 43.318137645721436, 43.42031438010079, 43.898986203329905, 48.85389947891235, 47.46519776753017, 44.79935809544155, 41.02667038781302, 42.92033243179321, 47.90240968976702, 47.62755632400513, 48.03542252949306, 48.99242571422032, 45.6501476424081, 45.45229768753052, 42.73654563086373, 50.08428995949881, 60.77980491093227, 58.02286045891898, 53.21366827828543, 47.94352218082973, 49.77189895084926, 51.693041120256694, 50.569194316864014, 42.97832557133266, 43.46670402799334, 52.52852725982666, 47.687828472682405, 46.4217346736363, 51.76767519542149, 45.95699746268136, 53.84347036906651, 53.04964215414864, 55.781170095716206, 55.692973136901855, 45.490790707724436, 20.552401440484182, 4.00630612032754, 12.103369372231619, 33.780991622379844, 48.66020107269287, 48.025441442217144, 49.22159120014736, 25.044213805879863, 6.062893867492676, 2.956892545734133, 0.0905499689813171, 0.2011996108506407, 0.024434478587603996, 0.0715738075918385, 0.018008902935045104, 0.10720252112618514, 0.09680332735713039, 0.030059233640453646, 0.05053588701412082, 0.029372369604451314, 0.119804069932018, 0.07119023174579654, 4.023298808506556, 20.951238461903163, 26.071911437170847, 31.770679746355327, 36.16000965663365, 17.674864053726196, 16.423179081508092, 29.575795922960552, 17.433957849230083, 4.409816673823765, 0.20218883348362787, 14.47549045085907, 69.45338017599923, 56.786591802324565, 79.58193601880754, 81.69578647613525, 2.81208296758788, 0.3983585185238293, 0.27294869082314627, 27.625733613967896, 132.46643338884627, 72.63310514177594, 112.16504083360944, 85.69390501294816, 85.38179193224225, 16.451235907418386, 0.3860487262053149, 77.94578811100551, 73.04924665178571, 61.04476751599993, 54.43150683811733, 38.824157442365376, 41.20728186198643, 29.81275381360735, 0.8962657781583923, 0.14064421451517514, 0.39889320411852425, 0.04624059071232166, 0.1114591612879719, 0.2594842218926975, 0.1693452008600746, 0.1506282194916691, 0.10145738547933952, 0.12521502029682907, 0.14951774265084947, 0.1973514487700803, 0.18291702760117395, 0.2364583531660693, 0.15504310759050505, 0.12650997723851884, 0.1837429404258728, 0.1648156132016863, 0.2007396455321993, 0.14918299418474945, 0.44454881282789366, 18.27373971257891, 64.3371992111206, 63.87692274366106, 67.27454321725028, 65.26215035574776, 65.26731981549943, 65.91122327532086, 60.103724343436106, 66.69367381504604, 67.64691802433559, 71.29727227347237, 63.43828296661377, 65.03647286551339, 64.45766013009208, 61.807241984776084, 60.6588020324707, 61.863418170383994, 61.83508341653006, 66.58501788548061, 64.509674344744, 66.27745587485177, 61.57258742196219, 55.15070097787039, 55.49206597464425, 53.84684024538313, 55.10563496180943, 52.14119645527431, 52.126313413892476, 51.31536136354719, 54.12726954051426, 56.42284318378994, 51.6908072744097, 50.24535962513515, 48.02776214054653, 46.673255988529746, 43.91941738128662, 46.17158562796456, 43.83468757356916, 40.257317202431814, 41.17900269372122, 43.4196195602417, 49.14847878047398, 57.06850801195417, 57.543299266270225, 54.446518421173096, 44.78157418114798, 42.81831203188215, 51.81834145954677, 54.999633244105745, 54.37971149172102, 44.9831622668675, 36.755845478602815, 40.070094517299104, 45.671777384621755, 53.78359774180821, 58.352583748953684, 55.69002710069929, 52.43058545248849, 42.37704930986677, 37.75440583910261, 42.79578249795096, 43.022919109889436, 39.78098692212786, 42.5840847832816, 45.87336894444057, 46.30616181237357, 46.3530968938555, 51.34355367933001, 50.885507583618164, 47.48964153017317, 45.168748651232036, 46.04346432004656, 53.20701885223389, 51.80918720790318, 51.59006881713867, 52.54835394450596, 48.26350062234061, 47.43724169049944, 46.87867947987148, 53.722668988364084, 62.5181747164045, 59.96188381740025, 55.510885170527864, 49.31283146994454, 50.40588733128139, 51.043436663491384, 53.22094999040876, 45.05865791865757, 46.48838874271938, 57.37634795052664, 52.41729702268328, 52.05986084256853, 57.1976819719587, 51.90142454419817, 59.58263724190848, 62.62519087110247, 59.285865783691406, 61.754324504307334, 54.76030254364014, 43.75227151598249, 17.018849883760723, 26.505241053444998, 49.08593109675816, 61.96515369415283, 58.57933126177107, 60.74671064104353, 48.090938636234824, 22.24496350969587, 5.6880494100706915, 0.161635604553989, 0.28229038098028725, 0.1748410359557186, 0.12191454454192094, 0.09082194617284195, 0.1523253441389118, 0.14728084339627198, 0.12409287265368871, 0.09013153000601701, 0.2083047545914139, 0.32096321295414654, 0.1879347533519779, 4.698451791490827, 30.098633970533097, 40.80697182246617, 46.22424602508545, 36.58788667406355, 29.999479702540807, 22.874129840305873, 38.92826230185372, 26.372167416981288, 5.931859093053, 0.15110338399452822, 29.747527599334717, 81.04191929953438, 71.89098194667271, 92.46331950596401, 96.2876010622297, 4.3436572296278815], [0.13338920953018324, 0.08903150938983474, 37.226426124572754, 98.19137968335832, 56.66018669945853, 76.74323558807373, 63.69160039084298, 27.408831698553904, 0.4700323353920664, 1.4051966262715203, 38.073397636413574, 56.47135898045131, 47.80845267432076, 48.73695087432861, 22.989661012377056, 36.69362783432007, 18.46084601538522, 1.0386560261249542, 0.059003199982856, 0.0015590296243317425, 0.04290201860879149, 0.032743769232183695, 0.024754928624523536, 0.010797078222302454, 0.01579166083995785, 0.04725872232977833, 0.01653785428165325, 0.02640940056049398, 0.07156608586332627, 0.09883452193545443, 0.024594334652647376, 0.05829008003430707, 0.062499738431402614, 0.06360655796847173, 0.05559779217998896, 0.0931279474337186, 0.038470536936074495, 0.08292901649006776, 0.3369398627962385, 10.155151809964861, 62.79965318952288, 59.06132779802595, 61.43273408072335, 59.67718138013567, 60.75179672241211, 59.329597745622905, 59.51879024505615, 64.26631368909563, 61.846964836120605, 56.27680941990444, 54.41318791253226, 62.479521887642996, 61.54939433506557, 59.92708723885672, 60.672496931893484, 61.194195474897114, 59.78247438158308, 63.439144543239046, 59.368521554129465, 52.697625568934846, 43.39371320179531, 44.21530294418335, 43.07241460255214, 44.146415029253276, 43.911565916878835, 44.9537262235369, 43.80847202028547, 44.95700577327183, 46.31410707746233, 45.653520992824006, 42.944842202322825, 44.28892605645316, 43.74626479830061, 43.407060691288535, 41.97479030064174, 42.578991753714426, 43.46993841443743, 37.728297982897075, 37.836019379752024, 41.73648445946829, 48.20452778679984, 48.896269593920024, 51.03569289616176, 48.81062609808785, 49.05975028446743, 48.49856512887137, 47.69706957680838, 44.74615921292986, 41.08928407941546, 46.72151470184326, 46.229936599731445, 47.808285917554585, 48.303209577287944, 51.221595423562185, 48.141465936388286, 46.1330509185791, 40.17504358291626, 37.20275708607265, 39.841936520167756, 38.042631013052805, 38.27733073915754, 40.98332405090332, 39.205544063023154, 39.13630526406424, 42.68962097167969, 42.60098280225481, 42.50720296587263, 39.8869434765407, 38.89536952972412, 40.359806605747764, 40.034158434186665, 39.84447261265346, 40.74490009035383, 41.45679862158639, 40.29984017780849, 40.45060913903372, 40.207349232264924, 47.93429844720023, 54.766371795109336, 52.247562953404014, 50.18005698067801, 50.561092717306956, 51.25075701304844, 52.41106448854719, 52.61910745075771, 43.73227112633841, 44.1538530758449, 41.70929615838187, 43.341393266405376, 36.46474027633667, 33.345356941223145, 34.867634296417236, 37.67216348648071, 39.52013765062605, 39.952537945338655, 22.584383010864258, 9.537557704108101, 1.2034253903797694, 0.066582768623318, 0.20202252455055714, 2.812610162155969, 14.637577159064156, 30.058146817343577, 26.607971906661987, 2.5278445397104536, 2.0774108469486237, 0.03580718520762665, 0.08329955089305129, 0.04914763490004199, 0.05298291499327336, 0.04239786708993571, 0.041553301337574206, 0.08064440943832908, 0.22492146651659692, 0.04827185992949775, 0.04861722746863961, 0.0714855980394142, 0.07185014776353325, 0.05582463661474841, 2.814266004732677, 12.235372117587499, 20.715694529669626, 20.168289388929093, 22.311534200395855, 13.35068827016013, 14.914440291268484, 34.203244073050364, 43.33222164426531, 12.953910521098546, 1.294947930744716, 14.28052920954568, 60.06151403699602, 42.21691070284162, 79.23598521096366, 64.98072746821812, 1.1606083107846124, 0.3203250914812088, 0.06438966880419425, 50.038056646074565, 104.82362283979143, 71.09710856846401, 78.57239055633545, 70.40842396872384, 30.01948356628418, 0.6699959539941379, 2.378261983394623, 44.70528643471854, 64.90752819606236, 55.45201655796596, 56.42370823451451, 27.16375310080392, 42.8370270047869, 22.29360089983259, 1.2386542771543776, 0.0924416771158576, 0.00861223108534302, 0.08393567068768398, 0.028761918789574077, 0.04298169219068118, 0.034029538809720955, 0.03898783167824149, 0.016895040204482417, 0.014908905440409268, 0.05681072102327432, 0.0315475764551333, 0.08273063320666552, 0.050694711705935855, 0.03987799159118107, 0.04886444831000907, 0.07113556896469422, 0.05210080250565495, 0.025544432956459265, 0.054494612983294895, 0.09009115717240743, 0.26035738789609497, 4.747639826365879, 51.789099965776714, 63.55836173466274, 66.77751077924455, 63.47040448869978, 64.99438067844936, 62.844302313668386, 62.03030000414167, 66.62772846221924, 64.65014607565743, 58.05680588313511, 54.62423249653408, 63.43019526345389, 62.40738568987165, 61.78084577832903, 61.859339577811106, 63.263355118887766, 63.271380288260325, 64.52753121512276, 60.568954876491, 54.34542907987322, 45.56695338657924, 45.91041326522827, 45.16663292476109, 47.171327182224815, 45.68051127025059, 46.69123445238386, 45.64375182560512, 44.079896450042725, 47.21436432429722, 48.434978689466206, 46.26629304885864, 46.71206167766026, 44.58379370825631, 46.35423639842442, 45.048273835863384, 46.06112664086478, 44.5388388633728, 41.36014570508684, 39.580666882651194, 45.23320014136178, 48.07069158554077, 50.29913173403059, 51.6415410723005, 50.14234215872628, 48.513517652239116, 48.96598087038313, 46.935057163238525, 43.94035925183977, 41.75899314880371, 45.8919484274728, 46.998452527182444, 49.90341445377895, 49.417068345206125, 51.847780976976665, 51.60847112110683, 47.1605018888201, 43.19824995313372, 39.75527163914272, 41.78466674259731, 41.621689796447754, 39.70907654081072, 43.25782380785261, 41.26259994506836, 41.20631258828299, 42.56229870659964, 43.25700044631958, 45.38855838775635, 43.72219276428223, 41.75911126817976, 41.65771273204258, 41.952726296016145, 41.74618761880057, 42.38498067855835, 44.14797142573765, 43.666186809539795, 43.14149359294346, 44.153335435049875, 52.59528207778931, 54.95757927213396, 51.448158809116904, 52.09764862060547, 53.032108375004356, 53.776135376521516, 55.37188993181501, 54.438653060368125, 47.74497045789446, 49.16588054384504, 44.255463532039094, 44.20130579812186, 41.37380933761597, 35.177523953574045, 39.52876383917672, 44.564943245479036, 50.12683377947126, 45.51088489804949, 22.099466494151525, 5.921583141599383, 0.17767712234386376, 0.0990964500233531, 0.3968394957482815, 1.420694800359862, 10.720540625708443, 27.703991174697876, 24.129144736698695, 3.110161121402468, 1.8098250797816684, 0.05011922919324466, 0.11113793602479355, 0.04172989007617746, 0.0678413560880082, 0.02179969657611634, 0.0629699971260769, 0.05653328841019954, 0.1944987518446786, 0.0470671651086637, 0.04647073621994682, 0.09413656938288893, 0.08097753620573453, 0.10766189611916031, 3.1007473979677473, 17.056474379130773, 28.481897592544556, 25.310845715659006, 39.132553236825125, 33.916988713400706, 31.115488937922887, 51.21437971932547, 49.116850580487935, 14.071205173219953, 2.128575427191598, 24.24008662360055, 69.18093436104911, 49.60758447647095, 90.36681870051792, 69.79547473362514, 0.9904304253203529, 0.4673630871943065, 0.3281114436686039, 55.77631330490112, 116.54162079947335, 77.49391201564244, 89.78288514273507, 82.18141692025321, 48.15063061032976, 1.2993783844368798, 2.8472933982099806, 66.4869579587664, 77.21544906071254, 62.132827622549875, 64.61764240264893, 33.84399788720267, 49.87218924931118, 29.87215048926217, 1.8006201280014855, 0.28667531854340006, 0.11245332365589482, 0.18189432605036668, 0.12515098016176904, 0.23740314532603535, 0.26768627177391735, 0.12061619492513792, 0.06366048793175391, 0.10496317236019032, 0.18316337652504444, 0.1508441021932023, 0.18988176887588842, 0.10913061909377575, 0.15916693130774157, 0.15381778191242898, 0.2160430529287883, 0.07483994947480303, 0.17948482105774538, 0.10596367224518742, 0.17543189067925724, 0.6133090757897922, 22.79091821398054, 67.13574600219727, 62.13551657540457, 65.63836751665387, 64.25691277640206, 68.34394046238491, 64.00933456420898, 63.65182890210833, 65.7757681437901, 66.58806119646344, 60.461195264543804, 54.38741356985909, 65.20962197440011, 62.309826033455984, 63.07027857644217, 61.95912265777588, 66.03066280909947, 64.9905035836356, 68.61720616476876, 63.207192829677034, 58.25562163761684, 46.34755917957851, 50.81874234335763, 46.297827448163716, 48.95935576302664, 48.25679908479963, 51.33673054831368, 48.8740770476205, 48.89185748781477, 51.26547677176339, 52.58073602403913, 47.13697528839111, 48.9946734564645, 48.295722893306184, 49.540523937770296, 46.15177631378174, 47.298215184892925, 46.63254301888602, 42.88327421460833, 41.296166692461284, 48.664731298174175, 53.16868216650826, 54.882076672145296, 54.84136717660086, 52.34899970463344, 50.69029794420515, 51.64282996313912, 48.33183962958199, 45.207095759255544, 41.33855070386614, 49.19506992612566, 49.51211622783116, 51.16526985168457, 50.05324540819441, 53.52479818889073, 54.37054334368025, 53.32300860541207, 45.128515107291086, 41.345234870910645, 43.46773930958339, 42.13101707186018, 41.75128064836775, 47.71432890210833, 43.94598034449986, 43.63651105335781, 45.29140520095825, 48.86426966530936, 50.05085175377982, 46.235040051596506, 43.72350597381592, 46.64121784482683, 44.12890209470476, 45.502724238804404, 45.1033695765904, 47.40143762316023, 46.26330532346453, 43.83378083365304, 46.032166549137656, 53.91046142578125, 61.49486487252371, 56.08926364353725, 53.981854166303364, 55.78182322638375, 54.3441401890346, 56.597663334437776, 55.59733465739659, 45.6947272845677, 48.03463390895298, 47.59988859721592, 50.1321838923863, 46.935185704912456, 44.27956335885184, 48.2761880329677, 53.990351813180105, 56.20759841373989, 65.27435139247349, 55.85274001530239, 26.54246950149536, 2.133370118481772, 0.22993589458721025, 0.7745755708643368, 3.9892765198435103, 19.22027369907924, 40.27020958491734, 42.84715747833252, 17.067389999117168, 3.7855266758373807, 0.1401664037257433, 0.1757948933435338, 0.17622501669185503, 0.17819352820515633, 0.09100882150232792, 0.1277058952088867, 0.12691336630710534, 0.5006853991321155, 0.1135170358632292, 0.1988946409629924, 0.16870032117835113, 0.14769602540348256, 0.16758615310703004, 4.273724913597107, 27.349421126501902, 39.59637328556606, 27.849701847348893, 34.386266572134836, 48.657484327043804, 48.48348406382969, 67.08239773341587, 64.02409253801618, 17.867443799972534, 5.554477674620492, 21.86952975818089, 88.31264632088798, 58.57368237631661, 101.75427000863212, 84.2798284803118, 1.645859643816948], [0.2151106372475624, 0.07196260815752403, 43.18551043101719, 96.2469402040754, 79.98088768550328, 91.12340109688895, 47.390792982918875, 4.826198330947331, 0.6875435209700039, 12.748503531728472, 27.28227547236851, 44.69826528004238, 52.37227616991316, 54.771885190691265, 31.36354657581874, 24.064335414341517, 16.192035096032278, 0.6194733764444078, 0.08533951214381627, 0.08090913309050457, 0.027227824054924504, 0.052412775943854024, 0.01112049600175981, 0.044782066119036505, 0.03743294832695808, 0.03222993501861181, 0.028831441487584795, 0.10655870674444096, 0.04440724676741021, 0.03889168326609901, 0.006262494425754994, 0.05874629305409534, 0.04365458858332463, 0.03906331191371594, 0.08759716778461422, 0.06612671166658401, 0.030216575733252933, 0.019024330590452467, 0.06252945147986923, 0.26559784955212046, 8.893136603491646, 42.96622180938721, 65.98529802049909, 58.400734765189036, 56.01178428104946, 58.16709463936942, 53.73140982219151, 58.78413636343819, 57.89967237200056, 52.20363296781267, 57.51555163519723, 63.16592053004673, 64.48370892660958, 63.35878167833601, 58.82718045370919, 63.110605921064106, 58.560737882341655, 56.0928384917123, 56.05653067997524, 51.00752142497471, 47.3447333744594, 42.22293479101998, 43.36503103801182, 43.85224567140852, 41.89415993009295, 43.71727691377912, 44.56010729925973, 42.09646715436663, 43.61873756136213, 42.069768701280864, 43.80643619809832, 43.046810490744456, 43.880378927503315, 41.7227235521589, 42.54220104217529, 41.502580302102224, 41.925242696489605, 42.55717441013881, 40.69245161328997, 42.7293507712228, 43.09817157472883, 48.576141766139436, 50.11769342422485, 46.35536895479475, 45.239397934504915, 45.45437519890921, 44.62078939165388, 42.67255967003958, 42.25802319390433, 42.27392414637974, 46.568758555821006, 45.44650983810425, 47.39428097861153, 49.30304493222918, 48.75354664666312, 43.735585417066304, 44.566642080034526, 40.462438447134836, 40.3947490964617, 39.88226039069039, 40.69702352796282, 39.82757459368025, 39.09253508704049, 39.50134972163609, 39.981994833265034, 40.43452058519636, 38.69989585876465, 39.98215811593192, 40.49931253705706, 41.004550797598704, 39.9839438029698, 39.87750782285418, 40.31114489691598, 39.04751770836966, 42.56046438217163, 40.53535631724766, 44.756779534476145, 45.25419412340437, 44.97482442855835, 46.26688017163958, 49.214820180620464, 52.120685373033794, 50.838739258902415, 53.2095445224217, 50.4626784324646, 53.6392628124782, 50.55817099979946, 38.327729497637065, 35.28049625669207, 31.461870534079416, 27.315489598682948, 30.900407450539724, 41.473613262176514, 28.29943789754595, 4.525978394917079, 1.5048226118087769, 0.05278368354109781, 0.016287459592734064, 0.0588027403822967, 0.06083870506180184, 0.06512629320578915, 0.27928824350237846, 1.2730935662984848, 0.6069532654115132, 0.14863916193800314, 0.10410112754574843, 0.045087725788887055, 0.09384580355669771, 0.0402696148625442, 0.12467250440801893, 0.050552887709013054, 0.025231628312862346, 0.007962750936193126, 0.021557934548971907, 0.044507812442524095, 0.006236448010895401, 0.03873972874134779, 0.06055131834000349, 0.05643209169751831, 2.5098183069910323, 15.606326273509435, 17.60568084035601, 20.784499066216604, 12.561988694327217, 12.667493615831647, 8.3022609267916, 14.088329008647374, 49.77066217150007, 25.43653515407017, 6.113930557455335, 33.880396025521414, 46.261655126299175, 53.911031178065706, 61.609774180821006, 42.36466414587838, 0.035895920624690394, 0.19515025402818406, 0.08769265123243843, 49.85230003084455, 104.72010162898472, 86.46967833382743, 96.33908721378872, 61.84013475690569, 8.625337396349225, 1.169448265007564, 25.477444410324097, 38.826109886169434, 54.16202095576695, 62.14357648577009, 62.57526806422642, 30.95545107977731, 26.332955258233206, 21.581064871379308, 0.648306283567633, 0.08245426589357001, 0.1040393944297518, 0.00920575245150498, 0.008725930653911616, 0.0339354870707861, 0.015488104628665107, 0.10331912272210632, 0.040609805179493766, 0.040276356107954464, 0.092024384864739, 0.018379779998213053, 0.03569304543946471, 0.07952503021806479, 0.02197964915207454, 0.026176062545606067, 0.021545631012746265, 0.06387698810015406, 0.030153946951031685, 0.05914104437189443, 0.07665039625551019, 0.025179864572627202, 0.18129262833723, 2.1040035571370805, 27.911511284964426, 59.231016704014365, 64.59046799795968, 60.725449153355186, 61.748863220214844, 57.64926276888166, 60.580801555088584, 62.073392731802805, 54.63596452985491, 59.43948350633894, 64.16817038399833, 67.49967179979596, 64.65629523141044, 61.62305218832833, 63.2930725642613, 59.27605492728097, 55.67152404785156, 57.511136054992676, 54.616752760750906, 51.927841595241, 45.56811720984322, 46.24591050829206, 45.91128873825073, 46.281447069985525, 46.10693958827427, 45.8603514943804, 43.67598376955305, 46.39510917663574, 44.44043847492763, 45.06457083565848, 41.636663164411274, 45.47091538565499, 43.36508662360055, 44.764231477464946, 43.91590854099819, 45.244063649858745, 44.19234609603882, 42.96019772120884, 44.26239783423287, 46.14933402197701, 49.809888226645334, 49.47992522375924, 48.191149030412944, 47.55062239510672, 49.074900831495015, 45.517183440072195, 43.84245913369315, 44.069133690425325, 42.145438058035715, 47.4801607131958, 46.35473666872297, 49.499397550310405, 50.92664439337594, 51.07222999845232, 46.773407323019846, 46.87907900129046, 43.595964840480256, 43.119679723467144, 43.231208733149934, 44.233528069087434, 42.67009653363909, 42.15599584579468, 43.513357707432334, 44.042028767721995, 43.59129217692784, 42.28364815030779, 41.698165144239155, 42.63667222431728, 42.78739949635097, 42.40767696925572, 41.747094358716694, 43.273203645433696, 40.696797711508616, 43.25240421295166, 43.41188274111067, 46.46031107221331, 47.49477277483259, 46.959118774959016, 50.561690262385774, 52.00342409951346, 51.84869466509138, 51.174371991838726, 53.431584630693706, 51.64224631445748, 55.848303590502056, 52.18672105244228, 41.18292842592512, 40.50878987993513, 37.15173993791853, 36.09232030596052, 43.044673919677734, 50.564709254673545, 28.033363580703735, 6.28710355077471, 0.775238743850163, 0.02543458661862782, 0.024223552584382038, 0.058502169725086005, 0.06324402349335806, 0.027490474782618027, 0.25835576387388365, 0.6247103640011379, 0.14803606644272804, 0.17311979617391313, 0.146198444334524, 0.046176116314849684, 0.025765187539426342, 0.03695380421621459, 0.08251236206186668, 0.01974907554020839, 0.028061037916424017, 0.04424430336803198, 0.00818794737902603, 0.03411210973614028, 0.021006524762404815, 0.016070229999188865, 0.07451705501547881, 0.0287983561200755, 3.002349180834634, 28.302839040756226, 25.997466700417654, 23.53572515078953, 31.849906580788748, 30.761353152138845, 16.115738664354595, 36.24262721197945, 59.638208934238975, 35.632283551352366, 22.585729224341257, 53.432922158922466, 53.80495997837612, 63.31401443481445, 74.07470348903111, 41.51579924992153, 0.04091025030772601, 0.33892650476523806, 0.4381516660962786, 62.150962420872276, 111.582017489842, 94.821670123509, 101.56173542567662, 80.1847756249564, 13.421024015971593, 1.1859881260565348, 28.605707543236868, 48.14625671931675, 69.21822534288678, 70.59083502633231, 74.48795454842704, 43.811828000204905, 35.71547780718122, 27.893213203975133, 1.157451223049845, 0.3756618749882494, 0.20171126696680272, 0.1738686952739954, 0.23259531759790011, 0.08592402256493058, 0.1886218243411609, 0.22461216311369622, 0.12348886792148862, 0.12280776804046971, 0.19576712378433772, 0.13864928084824765, 0.1473017694162471, 0.18775860566113675, 0.10121382533439569, 0.1345846118139369, 0.13477357024593012, 0.24962415812270983, 0.17397620236235006, 0.20008872688880988, 0.14777238773448126, 0.1167036263006074, 0.6101367345878056, 14.893628699438912, 52.63905225481306, 72.4926403590611, 64.6513203212193, 60.509638105119976, 62.77052634102957, 61.06795365469796, 70.17040647779191, 65.22698552267892, 56.3699882371085, 60.792832783290315, 67.05045686449323, 70.41134221213204, 66.25740337371826, 63.56631742204939, 65.03023338317871, 61.61850111825125, 58.22215911320278, 60.5717966897147, 56.8452137538365, 53.56787354605538, 47.384643827165874, 49.24353361129761, 47.250588757651194, 47.63363947187151, 48.95992204121181, 48.77448156901768, 46.31589623859951, 49.80459022521973, 46.6757538659232, 48.45722682135445, 45.859976291656494, 48.971285820007324, 46.73364973068237, 47.35339777810233, 46.22117492130825, 47.010657038007466, 47.50021321432931, 43.50243166514805, 46.213163648332866, 47.33925124577114, 53.22857563836234, 54.36353261130196, 49.90794120516096, 49.64567797524588, 49.8074563571385, 46.8550695010594, 45.03268207822527, 44.09895535877773, 44.476763657161165, 50.13911819458008, 48.14557926995413, 52.629185812813894, 55.728398527417866, 54.25502954210554, 48.77463790348598, 49.78750113078526, 45.73250811440604, 46.18635402406965, 44.651225975581575, 45.86834192276001, 44.2450064931597, 44.510413782937185, 45.39366183962141, 46.00143119267055, 45.41366222926548, 44.93774536677769, 44.07954556601388, 46.35158566066197, 45.58172525678362, 42.99949325834002, 46.45654167447771, 46.77614491326468, 42.068424224853516, 46.345092569078716, 46.05695424761091, 49.42297431400844, 50.205563817705425, 47.98360633850098, 52.373252391815186, 54.734952041081016, 55.75405822481428, 54.52880941118513, 56.67323889051165, 54.71580280576433, 59.778972489493235, 57.279107911246165, 44.96076474870954, 48.15116909572056, 44.65153169631958, 43.170905317579, 56.87400361469814, 66.38698727743966, 50.3928872517177, 25.83038510595049, 3.7665763327053616, 0.11279628918107067, 0.07406840766114847, 0.18582844494708947, 0.17313609458506107, 0.247320043189185, 0.48612838025603977, 1.5661242880991526, 0.6387416539447648, 0.41974311960594995, 0.3208530731499195, 0.11918878794780799, 0.18455997801252774, 0.12193382850715093, 0.25771587820989744, 0.08621335668223244, 0.14680983152772697, 0.11674186853425843, 0.22512418563876832, 0.141718823994909, 0.10177659549351249, 0.109809839432793, 0.16855159987296375, 0.10684217153383152, 3.6891516872814725, 40.605574812207905, 33.36857087271554, 25.69990314756121, 34.29114920752389, 44.06765372412545, 29.20713840212141, 52.65795830317906, 67.34456021445138, 47.14830780029297, 30.872638974870952, 69.27075372423444, 66.6061682019915, 85.30350657871791, 97.91871152605329, 65.76692308698381, 0.23840569438678877], [0.14909534103104047, 0.11629057489335537, 30.40131834575108, 91.09711606161935, 66.59193134307861, 106.24727399008614, 57.47146531513759, 21.138188430241176, 16.02841717856271, 32.47773885726929, 42.02306638445173, 43.959320885794504, 68.5036517551967, 52.469457149505615, 27.076283965791973, 32.24387638909476, 16.50493332317897, 0.7328661318336214, 0.023087951288159405, 0.08577642762767416, 0.07989675205733095, 0.11575849487313203, 0.05604201548599771, 0.020297199520947676, 0.06017972542239087, 0.03160520104159202, 0.04504387207063181, 0.07716528219836098, 0.05860898470772164, 0.019739589620647684, 0.04698575108445116, 0.05879586682255779, 0.009561406581529548, 0.04414253668593509, 0.07475762960634061, 0.054245258149291785, 0.13676912816507475, 0.0736016094950693, 0.013268873577804437, 0.06162730524582522, 0.24763906321355275, 0.23254241900784628, 11.994220989091055, 36.32634258270264, 47.97649833134243, 49.73318706239973, 43.6628794670105, 41.682000160217285, 49.54333101000105, 49.87067106791905, 60.171476227896555, 60.54876341138567, 57.41229098183768, 58.599849292210166, 57.154870646340505, 59.059660230364116, 55.033008916037424, 53.982135568346294, 51.55467816761562, 50.74937152862549, 53.08129814692906, 43.51164150238037, 43.573386669158936, 43.56579228809902, 44.98092494692121, 40.67269441059658, 42.80165719985962, 43.896370206560405, 42.58851773398263, 43.57767718178885, 41.63269574301583, 42.04241711752755, 43.34192827769688, 42.85408135822841, 42.214440618242534, 42.86412845339094, 42.46997799192156, 41.20710815702166, 43.13218995503017, 41.5881473677499, 48.368932587759836, 47.25460481643677, 42.812235832214355, 45.24382046290806, 45.531246594020296, 46.29675047738211, 42.053673199244905, 43.929454054151265, 43.88508633204869, 42.2671149117606, 45.98783009392874, 43.798834868839805, 45.59280068533761, 45.32852595193045, 46.53823511941092, 47.87405061721802, 42.42926849637713, 41.30809327534267, 39.501561641693115, 39.920468534742085, 39.623825618198936, 39.57144314902169, 37.75986017499651, 38.54580913271223, 40.49746084213257, 39.837381975991384, 38.98811061041695, 39.97330958502633, 38.551319054194856, 39.83396346228463, 38.86081613813128, 39.89874151774815, 39.417585713522776, 39.89592054912022, 39.58577380861555, 41.28590420314244, 46.44268349238804, 43.56439222608294, 44.52072490964617, 49.19357606342861, 47.799975872039795, 46.16453668049404, 46.47250863483974, 47.69299445833479, 49.08558368682861, 47.53862285614014, 46.22826555797032, 38.94972876140049, 32.77261345727103, 33.8325194631304, 28.348546028137207, 22.300399712153844, 10.393190145492554, 1.231162816286087, 0.05653251827295337, 0.1351453802947487, 0.03830098121293953, 0.04393761232495308, 0.01673865823873452, 0.07456533278205565, 0.06624028485800539, 0.11544640947665487, 0.11882046556898526, 0.07315604268972363, 0.016305642634896294, 0.09658971774790968, 0.027263062074780464, 0.03764474964035409, 0.05359712149947882, 0.008310545086195427, 0.04782188603920596, 0.033526103145309856, 0.026953334587493112, 0.07620465981640986, 0.06388912030628749, 0.056580660332526476, 0.06633976487708942, 0.08223509229719639, 0.05815530940890312, 2.673817289727075, 15.812277827944074, 27.8443169934409, 26.381125382014684, 0.7925712966493198, 4.4729801416397095, 1.8844697943755557, 9.18221206324441, 22.251993349620275, 23.66894817352295, 19.37910951886858, 17.83319091796875, 35.200428690229145, 37.98708711351667, 35.419144085475374, 6.438715849603925, 0.4066891372203827, 0.16845492220350675, 0.12400258678410735, 30.90169981547764, 100.1218671798706, 73.81645284380231, 110.07951818193708, 71.89813164302281, 31.465758051191056, 25.468628883361816, 51.195011615753174, 51.312397956848145, 54.195059640066965, 70.04485252925328, 55.80947010857718, 28.09897541999817, 38.58007764816284, 21.27784548486982, 0.6956462604658944, 0.010742179650281156, 0.0528572367371193, 0.04916694600667272, 0.07017811534128018, 0.013816341924081956, 0.027513275255582163, 0.1182381332452808, 0.028245270352012346, 0.03016476279922894, 0.03357147338933178, 0.031265458557754755, 0.038307556217270236, 0.048976362483309846, 0.025924967269280126, 0.016940956669194356, 0.04677150704498802, 0.04289323836565018, 0.01353428339851754, 0.08134648283677441, 0.05966107361018658, 0.034920621530285904, 0.05489713013438242, 0.1006883406745536, 0.5465534435851234, 2.9529405406543185, 22.846839053290232, 40.99843985693795, 50.11749887466431, 48.32201140267508, 47.253187383924214, 56.33518123626709, 54.27118757792881, 61.283993993486675, 63.74702617100307, 60.51063864571707, 60.357917240687776, 60.434646197727744, 60.214367457798545, 55.8047696522304, 55.34007065636771, 52.49462699890137, 52.69439465659005, 52.34809991291591, 46.291316986083984, 46.708448614392964, 46.413900579724995, 46.347486223493306, 44.22125407627651, 43.34522867202759, 46.184804575783865, 43.46878501347133, 46.12059279850551, 43.794103145599365, 44.19640384401594, 45.026605878557476, 45.78425482341221, 45.97650800432478, 45.0588698387146, 43.65636205673218, 44.09572097233364, 45.102351665496826, 43.785553387233186, 49.85992567879813, 48.71646063668387, 45.99190868650164, 48.510498659951345, 46.93620361600603, 47.142592906951904, 42.87306036267962, 44.543990952628, 45.94269806998116, 43.38376338141305, 46.08146054404122, 46.93640858786446, 47.6741509437561, 47.52783577782767, 48.480492864336284, 50.3448543548584, 43.205948557172505, 42.948813097817556, 41.621443135397776, 41.86041252953665, 41.499238218579976, 40.24822201047625, 41.0262257031032, 41.92814704350063, 41.070124421800884, 41.81384570258004, 42.611311299460276, 42.59297500337873, 40.05352653775896, 41.76865461894444, 40.9293087550572, 41.63982459477016, 42.48729290281023, 42.15354660579136, 43.16649668557303, 44.75630358287266, 47.35214015415737, 47.32864482062203, 46.87659502029419, 53.076913833618164, 50.83735309328352, 50.13393483843122, 50.490610190800254, 51.01026248931885, 56.29918261936733, 52.83214269365583, 51.308128288814, 48.118637629917686, 39.60174076897757, 36.56624303545271, 27.212505136217388, 19.06194336073739, 5.409677650247302, 0.10555273108184338, 0.04731115951601948, 0.06336415133305959, 0.0641421392293913, 0.0006878370446169616, 0.03530303368877087, 0.060658988276762624, 0.044973423172320635, 0.03977796874408211, 0.010810331707554204, 0.0653630272884454, 0.03771683041538511, 0.04906772383089576, 0.12434854464871542, 0.03587181566815291, 0.0273714817927352, 0.04177460553390639, 0.02711857482790947, 0.052331864035555294, 0.01992462103122047, 0.006871783673497183, 0.05141309030087931, 0.015189968215833818, 0.039771349634975195, 0.06185844819992781, 0.12543341357793125, 5.5191604154450555, 30.258390426635742, 28.010703768048966, 30.667892932891846, 19.891606909888132, 10.843839883804321, 3.4301944971084595, 17.934422697339738, 32.58435549054827, 39.5239383152553, 37.6041510445731, 26.988788775035314, 49.40796620505196, 48.49387509482247, 49.40374517440796, 4.374890685081482, 0.32127235350864275, 0.45440513108457836, 0.4796825147100857, 43.51021712166922, 111.14526067461286, 85.60445390428815, 115.0276847566877, 86.28152111598423, 43.41035066332136, 32.396966048649375, 68.99482686179024, 72.00860800061906, 65.86193970271519, 79.44241619110107, 67.47332423073905, 39.07309750148228, 52.37200519016811, 26.67898597036089, 1.0260389660085951, 0.15351434105208941, 0.2773104224886213, 0.13746538651841028, 0.14843051241976873, 0.06842650433204003, 0.1075010493929897, 0.2751506455242634, 0.14994811027177743, 0.16826599091291428, 0.18044249181236538, 0.07096873755965914, 0.108500646826412, 0.16376624522464617, 0.203676684360419, 0.1632878373243979, 0.17351589777639934, 0.26878549850412775, 0.14167352499706404, 0.2491266019642353, 0.24030686808483942, 0.08220234619719641, 0.15930265188217163, 0.3580006669674601, 1.3851037387337004, 19.59871428353446, 50.837881156376426, 63.080006054469514, 66.14701039450509, 56.36051436832973, 49.83013527733939, 63.94727325439453, 59.8894418988909, 65.93913418906075, 67.8174546105521, 63.69777733939034, 64.7787572315761, 61.703012057713096, 65.94082954951695, 57.01558705738613, 58.230792249952046, 57.19629233224051, 53.645543984004426, 56.13067143304007, 47.61618907111031, 49.18131249291556, 49.43032898221697, 48.30741671153477, 47.74521711894444, 48.34850835800171, 49.341159275599885, 47.377355166843955, 49.230821881975444, 46.636527810777935, 46.87109204701015, 47.062584400177, 48.96417433874947, 48.775033950805664, 48.462990352085654, 47.311559200286865, 44.52138498851231, 46.77049602781023, 45.76845809391567, 52.11218772615705, 52.41937105996268, 47.18306268964495, 50.560251985277446, 49.412788254874094, 51.43768439974104, 44.236890997205464, 47.69926520756313, 47.31737831660679, 46.77798271179199, 50.02364260809762, 49.18616580963135, 49.306029183524, 47.715190478733604, 51.465355600629536, 52.12582009179251, 46.19823544366019, 45.047384466443745, 42.389872210366384, 43.92207506724766, 44.61316721779959, 44.37247119631086, 41.95519985471453, 43.611511434827534, 45.43957206181118, 43.467277254377095, 45.30029542105538, 44.17452049255371, 42.178615706307546, 46.642221859523225, 44.04108728681292, 44.739680017743794, 45.36755745751517, 46.120405197143555, 45.16120638166155, 45.119270529065815, 49.89579575402396, 47.14850582395281, 48.9990508215768, 54.71853344781058, 51.446241106305806, 52.6654623576573, 51.184551102774485, 51.332165581839426, 56.96153007234846, 56.218760694776265, 57.66200923919678, 56.55342762810843, 51.07410601207188, 51.02135181427002, 44.067865644182476, 32.552317346845356, 15.675849948610578, 2.9564682713576724, 0.21084808026041302, 0.2199042293110064, 0.16545336826571397, 0.17529078253677913, 0.1118871947484357, 0.12982440367341042, 0.16013476651694092, 0.27350394959960667, 0.24018959009221622, 0.1687089657144887, 0.15641180771802152, 0.17181170279426233, 0.16201999464205333, 0.11586824112704822, 0.22859063105923788, 0.10769869307322161, 0.18998523189553193, 0.1449777598359755, 0.07469122138406549, 0.17811879435820238, 0.17717077237154755, 0.14256944906498703, 0.22662593291274138, 0.2053468440260206, 0.18016814653362545, 6.911831719534738, 46.684393950871055, 35.02649443490164, 49.56115313938686, 25.541044746126445, 18.772403240203857, 5.280264411653791, 50.38252401351929, 46.642009939466206, 46.95288624082293, 51.48111064093453, 41.589217390332905, 75.27390698024205, 71.05050005231584, 90.34259728022984, 13.05495730468205, 0.6907751389912197], [0.20403306452291353, 0.7572479035173143, 15.2492652961186, 77.35997853960309, 79.24776935577393, 63.89223657335554, 64.160735811506, 60.97076225280762, 68.02438586098808, 54.840599400656565, 51.209880760737825, 54.19565371104649, 77.98087651388985, 65.43748814719063, 20.505237068448746, 20.45955961091178, 9.923493657793317, 0.8826787386621747, 0.07255046375628028, 0.037632169601108344, 0.04716585463445101, 0.048287266067096164, 0.01565000817312726, 0.06339618497128997, 0.07613523211330175, 0.07042178405182702, 0.004520853216360722, 0.02035733638331294, 0.027585924303691303, 0.02806506332542215, 0.017219008445473652, 0.046081026417336295, 0.020795525816668357, 0.04877545844231333, 0.07329275392528091, 0.021736708170335208, 0.028625665565154383, 0.06292634018297706, 0.026105528830417564, 0.02797701153238969, 0.07287554309836455, 0.025067232848544205, 0.5255225492375237, 0.4726215164576258, 4.122845649719238, 11.715278608458382, 18.54647387777056, 24.76639355931963, 41.12295504978725, 48.90300587245396, 50.3638333593096, 54.20190014157976, 54.43559585298811, 55.40135376793997, 53.46276119777134, 55.091405051095144, 54.06628867558071, 50.101083755493164, 49.44171013150896, 54.13742780685425, 52.00236102512905, 47.8762149810791, 41.405253410339355, 41.82080084936959, 41.266428402491975, 42.20069708142962, 42.10313742501395, 43.3615847315107, 41.1207594190325, 43.66214990615845, 40.580234731946675, 42.73378372192383, 39.82757806777954, 41.88961580821446, 39.12384366989136, 43.89256954193115, 40.10325826917376, 42.26843506949288, 40.69733272280012, 43.84268842424665, 47.06373085294451, 44.75705746241978, 47.51517268589565, 45.241002968379426, 46.12833309173584, 44.68230874197823, 43.340962478092735, 43.84616947174072, 45.591883523123606, 44.85183089120047, 45.31858307974679, 48.36200870786394, 44.83016293389456, 46.89696019036429, 46.32001304626465, 45.052588667188374, 41.49201556614467, 38.14591598510742, 41.22142839431763, 39.374958515167236, 37.9347254889352, 40.37588126318795, 39.38571432658604, 40.084314005715505, 40.8794241632734, 39.41388232367379, 40.46882731573922, 38.39122561046055, 37.711104665483745, 39.75059897559029, 37.53024653026036, 41.420525550842285, 39.637701170785085, 41.79652384349278, 41.73759617124285, 46.448457445417134, 47.897219385419575, 49.62519815989903, 48.02330834524972, 50.48497520174299, 48.96349688938686, 50.46462392807007, 50.213967663901194, 52.86526823043823, 49.956849575042725, 49.94701439993722, 34.50108902794974, 22.626047883714946, 11.263249652726309, 3.801633902958461, 0.9811317814247948, 0.596127103481974, 0.10728233041507856, 0.09168395027518272, 0.1275814247450658, 0.046850637798862796, 0.11014852340200118, 0.06830484978854656, 0.10112093389034271, 0.021623430141646947, 0.03190869618473308, 0.04772487588758979, 0.021717510718320097, 0.05770043988845178, 0.03730855589466436, 0.10494789175157036, 0.029385428010885204, 0.08507147724074976, 0.04102461399244411, 0.040463228044765334, 0.006032666557335428, 0.09034425751971346, 0.06500968696283442, 0.01689630906496729, 0.012795798962802758, 0.007903734504777406, 0.045077459554054906, 0.11528892149882657, 0.14154509188873426, 5.016363143920898, 19.102298498153687, 25.84858070101057, 16.0230826990945, 1.4086129686662128, 2.4001270958355496, 1.4088357452835356, 19.323492663247244, 31.886857100895472, 16.513491766793386, 10.617276498249598, 16.408804995673044, 22.60538567815508, 17.25281831196376, 14.655041456222534, 0.09341570056442704, 0.12835086988551275, 0.1095567187294364, 0.7851239676986421, 11.750897680010114, 82.95602294376918, 87.55552891322544, 69.7559950692313, 75.41128676278251, 78.4981004170009, 76.54754652295793, 64.57687037331718, 68.99930844988141, 68.89637088775635, 87.3153713771275, 76.29998220716203, 23.120063066482544, 32.51857689448765, 15.71455488886152, 1.0363046037299293, 0.020840648395408477, 0.05907447330121483, 0.08600695990025997, 0.06105056405067444, 0.05875015391835144, 0.07739001299653735, 0.0387226534076035, 0.07708936091512442, 0.024858318701652542, 0.06633967666753701, 0.06771558283695153, 0.03566924921636071, 0.040445759160710235, 0.062202384030180316, 0.06225574402404683, 0.029963254862065827, 0.06127947462456567, 0.07463237204189811, 0.05129336958218898, 0.05043195580531444, 0.006221424821498138, 0.02809165172012789, 0.038990847766399384, 0.08920767743672643, 0.24434759840369225, 0.4833105600305966, 0.5445758125611714, 4.6961297903742105, 14.462642363139562, 24.09796816962106, 45.253096308027, 58.44079807826451, 59.02642004830496, 58.961044447762625, 58.57806668962751, 59.74837262289864, 57.206829275403706, 56.94869327545166, 58.07772690909249, 52.97569595064436, 53.425032479422434, 57.93191201346261, 55.143200397491455, 51.13667106628418, 44.51548596790859, 44.81836836678641, 43.55263934816633, 44.92927551269531, 45.33622455596924, 43.42824922289167, 44.82668536049979, 45.120142527988975, 43.615697724478586, 43.378788471221924, 42.60341467176165, 44.59772832053048, 41.79395995821272, 44.564067772456575, 42.35877207347325, 44.60711881092617, 44.28471892220633, 46.05367122377668, 48.282201698848176, 48.775978905814036, 52.56304938452584, 48.39459923335484, 48.39073256083897, 47.029323373522075, 45.09685564041138, 45.96756567273821, 46.220521790640696, 47.659316539764404, 46.335788931165425, 48.63989496231079, 45.52267599105835, 49.04327957970755, 50.28460305077689, 45.30834143502371, 44.44021960667202, 41.61780227933611, 43.75921624047415, 41.11410999298096, 40.458380699157715, 42.34698445456368, 40.950340952192036, 42.15355355398995, 42.87742383139474, 42.132761069706504, 41.51893983568464, 41.72457872118269, 39.73524693080357, 41.42971454347883, 41.18745865140642, 43.05693401609148, 41.47516965866089, 43.91279227393014, 43.212945393153596, 51.35457699639456, 51.16997030803135, 52.08241816929409, 50.52205426352364, 52.122905322483604, 50.189047949654714, 52.90577275412423, 53.80848618916103, 55.228128228868755, 54.71445138113839, 52.91118540082659, 33.51105063302176, 19.166194132396154, 8.495156816073827, 1.346188398344176, 0.8250630274415016, 0.8189597406557628, 0.07468239364347287, 0.04498589464596339, 0.033106188356344185, 0.08288613986223936, 0.062163727890167914, 0.053460830955633094, 0.034710628512714586, 0.063467465074999, 0.028088013076090386, 0.05584149142461164, 0.03939095272549561, 0.05625665307577167, 0.08642993827483483, 0.00861587651473071, 0.017923684025715505, 0.005801208932617945, 0.0568252382799983, 0.05085944983043841, 0.0520559445555721, 0.019601224455982447, 0.04926122844751392, 0.04349494625681213, 0.03292075491377285, 0.0038634965478974792, 0.10007998653288398, 0.13103629435811723, 0.3014914020895958, 9.269028067588806, 29.480282511029923, 31.314283847808838, 21.322406019483292, 6.70197571175439, 3.8269231745174954, 2.312271250145776, 29.70611980983189, 37.016875403267996, 21.99519487789699, 15.699253218514578, 32.75104277474539, 31.813359056200298, 18.187232903071813, 5.844549332346235, 0.08052296524069139, 0.15614165578569683, 0.27199374777930124, 1.2821448977504457, 22.43262219429016, 101.47665473393032, 100.07433455330985, 81.15691198621477, 77.43595014299665, 90.56455748421806, 84.71979536328996, 79.95034340449742, 82.70084340231759, 81.52764007023403, 94.57161140441895, 80.21393721444267, 27.80418767247881, 40.80773612431118, 23.216705560684204, 1.4952887062515532, 0.14208949410489627, 0.1568289031939847, 0.13876355971608842, 0.13986313928450855, 0.10094083034034286, 0.13098005737577165, 0.16910339812082903, 0.14357294807476656, 0.10740376782736608, 0.16593326894300325, 0.147008533722588, 0.05676613109452384, 0.08095779762204204, 0.18219043873250484, 0.13478938011186464, 0.12734616308340005, 0.19263181702366897, 0.2079836039670876, 0.11431702865021569, 0.12821189234299318, 0.29064160000000683, 0.20525182198200906, 0.1392841317823955, 0.18721748755446502, 0.6623476158295358, 0.9053155896919114, 7.362653425761631, 20.587547166006907, 38.20790433883667, 52.99310466221401, 61.09214728219168, 65.32747731889997, 62.13468279157366, 61.63282830374581, 61.39593642098563, 60.882297788347515, 58.45880780901228, 59.513252530779155, 59.60942254747663, 54.30789491108486, 55.26644059589931, 59.231926918029785, 55.705045631953645, 52.409438610076904, 45.590115206582205, 46.94674055916922, 46.11121620450701, 46.2770870753697, 47.45215252467564, 46.65497180393764, 46.316796030317036, 48.99363817487444, 46.86817727770124, 46.484525544302805, 44.91563967296055, 47.161992277417866, 43.62887845720564, 48.247248785836355, 44.6154705456325, 47.33554785592215, 46.392017228262766, 48.12801422391619, 52.19652148655483, 49.45771530696324, 54.36053793770926, 50.200255393981934, 50.84009763172695, 48.870606422424316, 49.24991205760411, 47.78256368637085, 49.63962262017386, 48.74896083559309, 49.8406548500061, 52.2741676058088, 47.39337076459612, 50.768833432878765, 49.63276127406529, 48.321354797908235, 46.36717741830008, 43.8738545690264, 44.796137605394634, 43.3726566859654, 43.50256715502058, 45.17310517174857, 43.001018387930735, 45.88582011631557, 46.093050139290945, 44.28332233428955, 45.29368421009609, 43.67897844314575, 41.59331335340227, 45.19793108531407, 42.6719308580671, 47.011463029044016, 43.47596250261579, 47.11357028143746, 45.01071187428066, 51.293550968170166, 52.28852258409773, 53.83918333053589, 49.49887296131679, 53.84810134342739, 51.669924463544575, 54.12328822272164, 54.11306742259434, 57.64095272336687, 55.28519378389631, 57.465128558022634, 45.092488697596956, 36.44870730808803, 17.5004277910505, 5.590147120612008, 1.6059973942381995, 1.1833372797284807, 0.22533704207411834, 0.2631879917212895, 0.10297111568174191, 0.334182757884264, 0.25716251933148926, 0.15268310851284436, 0.11156350640313965, 0.146326266761337, 0.10500765711601291, 0.2654632010630199, 0.12831513823143073, 0.12578209915331431, 0.19292304425367288, 0.1320962067693472, 0.10786737009350743, 0.3025683457297938, 0.13873614690133504, 0.1687316559255123, 0.1995853760412761, 0.22258850027407917, 0.12812631550644124, 0.1865007917263678, 0.2627889859889235, 0.1989454903772899, 0.36055374997002737, 0.2782922626606056, 0.49690899891512735, 14.752166850226265, 42.51719100134713, 47.55828625815255, 39.56411279950823, 8.330843210220337, 5.199737395559039, 4.225283810070582, 44.035202162606375, 62.395330565316335, 30.8998863356454, 37.808296067374094, 61.14037472861153, 71.96787071228027, 55.379619802747456, 30.44947283608573, 0.28168168078575817, 0.597999588719436], [0.07483668572136334, 0.15200029872357845, 1.0387255081108637, 50.57011842727661, 60.67007895878383, 81.44369888305664, 54.532689980098176, 41.38481181008475, 39.205759457179475, 28.99352819578988, 22.10808573450361, 33.09893907819475, 52.537243774959016, 30.92694956915719, 29.140162978853496, 32.54738065174648, 13.329806327819824, 0.868311763874122, 0.06745629425027541, 0.046606388940875015, 0.07753137898232255, 0.04940608549597008, 0.012209017145713525, 0.025853334327361414, 0.05720097026122468, 0.03238390479236841, 0.02817588166466781, 0.01667420080463801, 0.06024128890463284, 0.02765773027203977, 0.020486980676651, 0.02674654425520982, 0.017023368139884303, 0.06759012171200343, 0.036920650995203426, 0.0421022259896355, 0.030020099133253098, 0.06255186349153519, 0.016676351760647128, 0.04226604469918779, 0.06482655036130122, 0.04412489138277514, 0.052870532630809715, 0.033371916240347285, 0.24230512657335826, 0.19216190438185418, 0.08775251837713377, 2.1270140366894856, 11.449453558240618, 35.711215087345664, 50.312385422842844, 56.07818821498326, 53.178204672677175, 58.0305312701634, 57.16236775262015, 59.919194085257395, 56.00597211292812, 54.579955101013184, 56.059851918901714, 57.04503352301461, 53.24576200757708, 53.69007498877389, 47.72854839052473, 41.658820969717844, 41.81838982445853, 41.95218433652605, 42.347811290196006, 41.12011671066284, 40.358031341007774, 40.91583967208862, 41.51423937933785, 40.12595803397042, 41.27634348188128, 41.41028390611921, 39.79180179323469, 38.96436166763306, 40.273166043417795, 38.66498116084507, 43.07975190026419, 43.06509814943586, 45.32672984259469, 50.36104365757534, 48.63474982125418, 45.173584597451345, 45.185966287340435, 43.93230281557356, 42.81946195874895, 46.854270458221436, 45.0251259122576, 44.46829032897949, 43.43335267475673, 44.64363854272025, 43.06381620679583, 46.08182879856655, 48.35571711403983, 44.167113712855745, 41.582630498068674, 42.7904497555324, 39.51603821345738, 40.969340801239014, 37.620527948652, 38.690699917929514, 40.94041197640555, 38.769471645355225, 39.88121121270316, 39.43992069789341, 38.8285174369812, 38.82855912617275, 38.073748520442415, 37.907863753182546, 39.79127025604248, 38.15833936418806, 41.15415940965925, 41.2117669241769, 45.030618463243755, 51.57583195822579, 51.816646099090576, 51.743078572409495, 51.48364325932094, 50.37551328114101, 51.16693047114781, 51.1172855922154, 50.803306920187815, 50.53062834058489, 38.32004131589617, 28.441208941595896, 6.848582702023642, 0.9920558695282254, 0.22986258566379547, 0.6861991531082562, 1.7538762305464064, 0.9489580392837524, 0.07215164801371948, 0.031876672724527974, 0.018339753217462982, 0.024500410139028515, 0.06091411065842424, 0.0553219066267567, 0.03953822875129325, 0.011102244257926941, 0.014509168586560657, 0.031088225210883787, 0.08724436350166798, 0.04903365798028452, 0.0067181472300684875, 0.1435747936900173, 0.03181154014808791, 0.027324440656229854, 0.011686750438197382, 0.07498723907130105, 0.017046263607751046, 0.0167614095179098, 0.06640480245862689, 0.09165241875286613, 0.08333818667701312, 0.0903206445010645, 0.04770972080794828, 0.008840570841649813, 0.1507149634084531, 8.982884747641426, 17.304426056998118, 12.986429827553884, 4.9386874948229105, 0.7911525613495282, 0.8824962398835591, 0.41959441187126295, 8.903810773577009, 32.369270529065815, 23.451462609427317, 18.894986833844865, 2.303105273417064, 8.650692241532461, 8.69368508883885, 0.034091048009161434, 0.03962882674698319, 0.11573376905705247, 0.03889417348961745, 0.049790835207594294, 0.4952546219740595, 48.140350750514436, 69.50022493089948, 92.02432537078857, 57.90316036769322, 50.35551983969552, 62.5064183643886, 51.324692794254844, 40.510387965611045, 50.29076610292707, 65.30887699127197, 38.79540579659598, 27.93734121322632, 43.66858393805367, 21.62658599444798, 1.1823378247874123, 0.10186147343899522, 0.028710482442485433, 0.01182966009115002, 0.029453898979617015, 0.04147525963240436, 0.03392406054107206, 0.032421152972217114, 0.042367641747530015, 0.050908575765788555, 0.08902935164847545, 0.04562956992802875, 0.012035481814694191, 0.03232147278530257, 0.033653504880411286, 0.02341743092983961, 0.018486978353134224, 0.05666537882227983, 0.019592529029718468, 0.019292803148605993, 0.09299072051154715, 0.02499343707625355, 0.03430782976959433, 0.02154364629781672, 0.0581017051424299, 0.16771628255290644, 0.05656589201784559, 0.06117912608065775, 0.1289118147854294, 0.28736332591090885, 1.456787000809397, 10.449213470731463, 34.12017835889544, 53.884808676583425, 61.545093400137766, 57.64250564575195, 59.45094803401402, 60.060437066214426, 63.48559325081961, 60.06382083892822, 58.17465427943638, 57.511299337659565, 58.08942767551967, 52.520984990256174, 58.213348797389436, 52.47637408120291, 46.221633502415244, 43.49384369168963, 43.82861137390137, 45.04385825565883, 44.83432837894985, 41.77628026689802, 42.163565908159526, 44.21352073124477, 42.66492012568882, 44.431840079171316, 45.047804832458496, 42.65693317140852, 42.190260887145996, 43.57286555426461, 42.115484373910085, 43.70237650190081, 45.8462918145316, 48.16668789727347, 53.195790563310894, 47.82682023729597, 45.507535866328645, 46.91764497756958, 46.20574992043631, 47.64086559840611, 48.91905273709978, 48.50668062482561, 45.296842166355674, 46.2516462462289, 47.99821145193917, 45.200199672154014, 46.900000027247835, 49.218165738242014, 47.991579396384104, 44.21869713919503, 45.388127599443706, 40.869269371032715, 41.698974609375, 39.17275898797171, 40.58708912985665, 41.5446412222726, 40.38707481111799, 42.53603451592581, 42.55584730420794, 41.91669641222273, 39.80043492998396, 40.825533935001914, 40.9197793006897, 40.616806575230186, 40.78382737295968, 43.82601622172764, 43.446714060647146, 51.07660041536604, 56.10530703408377, 55.349217959812705, 53.18497569220406, 51.871130398341585, 51.339065143040244, 53.82324416296822, 53.27935307366507, 52.70487254006522, 54.23607833044869, 39.58546461377825, 22.476536546434673, 3.219322749546596, 0.34536838052528246, 0.40475764657769886, 0.9401587971619197, 2.2091037460735867, 1.003347669328962, 0.05157978260623557, 0.018823770905977914, 0.02808131423911878, 0.027882176085508296, 0.04457088227250746, 0.024529770349285433, 0.009693431684614291, 0.03369730092318995, 0.02155540361335235, 0.00222364704157891, 0.02579418134077319, 0.043319653520094495, 0.03929373901337385, 0.16658395688448632, 0.022847414016723633, 0.028631582390516996, 0.030199486828808273, 0.018906211214406148, 0.012467808705488486, 0.018229189328849316, 0.070072481009577, 0.074702810762184, 0.06152521286691938, 0.05351337670747723, 0.1531525326094457, 0.08933864148067576, 1.0189404040575027, 14.547908050673348, 25.483864545822144, 22.869867120470317, 9.606998000826154, 2.5073330232075284, 0.9452702828816005, 2.3077507955687384, 22.52217057773045, 58.33087757655552, 29.614900384630474, 37.76339680807931, 23.833267859050206, 6.632910617760249, 4.257808327674866, 0.07395444091941629, 0.045579511007027965, 0.03407306004581707, 0.2505109762506825, 0.1868078423930066, 1.3216242364474704, 82.94091756003243, 79.3488517488752, 110.45216396876744, 73.76657172611782, 55.21128232138497, 67.5677433013916, 65.59382261548723, 55.25917278017317, 64.32488005501884, 74.4088215146746, 42.56402880804879, 40.915516580854145, 54.24251236234392, 32.768298625946045, 1.1877061767237527, 0.25761341942208155, 0.1538447333233697, 0.1601651106029749, 0.14075815411550657, 0.1420324021684272, 0.16762485674449376, 0.13878086235906395, 0.11812510288187436, 0.11907218849020344, 0.08042530369545732, 0.13163394800254277, 0.09048292972147465, 0.15636032048080648, 0.1351036096790007, 0.13245209838662828, 0.18975755625537463, 0.11862735450267792, 0.1384194338960307, 0.12439647636243276, 0.15925870995436395, 0.12614466755517892, 0.12277196853288583, 0.16894175750868662, 0.12882003613880702, 0.43901085427829195, 0.15573515902672494, 0.38585781359246796, 0.22246199420520238, 0.5546867442982537, 7.307773079190936, 28.88290592602321, 50.60598502840315, 61.40804018293108, 63.61969348362514, 58.89889975956508, 62.477103914533345, 61.773543221609934, 64.03270830426897, 59.445688247680664, 58.74517086574009, 60.797369956970215, 60.346966879708425, 55.97778674534389, 59.51139736175537, 53.221130643572124, 49.033670221056255, 45.62534604753767, 48.07639258248465, 49.25604384286063, 47.8161165373666, 46.866950920649934, 45.38573394502912, 48.03247649329049, 44.39655017852783, 48.40568161010742, 47.28949866976057, 45.820378507886616, 44.33924143654959, 45.93333189828055, 43.11436087744576, 47.726126943315776, 48.61884886877877, 50.01311261313302, 56.0123609815325, 51.42859615598406, 47.7520888873509, 49.16613415309361, 49.26875557218279, 48.62483474186489, 50.60560635157994, 50.756246771131245, 47.10497188568115, 47.15769829068865, 50.56388936723982, 46.614679200308665, 49.555212429591585, 52.690225737435476, 49.46717527934483, 46.01654005050659, 47.99691908700125, 43.930781160082134, 44.73485449382237, 41.392604214804514, 42.54764495577131, 46.46832581928798, 41.91430970600673, 44.89556632723127, 43.97735840933663, 44.47131279536656, 42.74369880131313, 42.87327923093523, 42.971801212855745, 44.04039594105312, 40.94362899235317, 45.40869426727295, 44.88932337079729, 50.10525267464774, 55.408086572374614, 57.74998385565621, 54.53474317278181, 56.070948192051475, 55.474400179726736, 54.81717702320644, 56.27541283198765, 54.97380331584385, 55.19705935886928, 43.26862130846296, 33.63670880453927, 10.713377032961164, 1.7238114838089262, 0.2857770196029118, 0.8096520315323557, 2.8374011175973073, 1.5096385819571358, 0.2081167461084468, 0.2396633183317525, 0.14581969965781483, 0.146834937323417, 0.19141665580017225, 0.08800810216260807, 0.12837493073727402, 0.10332763155124017, 0.14269298315048218, 0.1540319411350148, 0.16720223799347878, 0.18474486523440906, 0.1469643475221736, 0.3239179344049522, 0.11557598252381597, 0.17702913497175488, 0.10532210381435496, 0.18854779617062636, 0.3236050211957523, 0.12954982769276413, 0.1448070811373847, 0.24781659511583193, 0.17759272615824426, 0.19738890390310967, 0.24692752425159725, 0.15877872785287245, 0.9922972108636583, 23.2059097971235, 35.30571126937866, 39.515916619982036, 18.235760859080724, 5.272822456700461, 1.8717680530888694, 10.374333603041512, 28.7148984840938, 65.38616875239781, 49.17453799928938, 82.34586688450405, 58.52958910805838, 26.938714844839915, 14.93033082144601, 0.2526063195296696, 0.15321164658027037, 0.33649186683552607], [0.0428742970606046, 0.0899346802117569, 0.5525626582758767, 9.782561608723231, 48.99552113669259, 52.34885379246303, 69.64123167310441, 47.46350588117327, 15.623380626950945, 3.1533009665352956, 10.598114235060555, 11.837715421404157, 24.349927221025737, 36.15794256755284, 71.25584711347307, 58.3780905859811, 12.62968065057482, 2.316990379776273, 0.07674661930650473, 0.07928645052015781, 0.022686797992459366, 0.049564150228564224, 0.05440950433590582, 0.04100386439157384, 0.006540173855942807, 0.04024325377706971, 0.0077694524245868835, 0.03733845214758601, 0.018055977998301387, 0.00917920476890036, 0.029378489990319525, 0.08117948858333485, 0.014722208226365703, 0.0381367825237768, 0.04156042256259492, 0.08850397555423634, 0.07829822533364807, 0.0726547749446971, 0.022944785488237227, 0.06217195851994412, 0.028322933773909296, 0.04241881346596139, 0.03720094024070671, 0.015827579091170003, 0.11296961416623422, 0.058965073100158145, 1.2870583598102843, 0.2655618057719299, 1.4519610426255634, 7.832448056765965, 28.56598469189235, 51.85291916983468, 57.24805988584246, 58.018375396728516, 57.75417709350586, 59.23635292053223, 56.84374073573521, 55.947919913700645, 55.67070416041783, 52.56006165913173, 52.520984990256174, 55.92906945092337, 56.11138323375157, 45.63217612675258, 45.21599292755127, 42.363701820373535, 42.174481528145925, 40.58366366795131, 39.64402403150286, 40.47078670774187, 41.56279339109148, 41.129045145852224, 40.547303744724815, 38.89931263242449, 41.127975123269216, 39.5745073046003, 39.918460505349294, 40.540258271353586, 42.005893911634175, 41.33144269670759, 45.46859121322632, 45.4536178452628, 44.43022462299892, 40.09642471585955, 42.666841302599224, 44.960413864680696, 48.13978794642857, 47.855387755802695, 47.369878905160085, 45.988552706582205, 45.22698845182146, 43.57320601599557, 41.160628182547434, 44.08276605606079, 45.29592500414167, 46.95023202896118, 39.80680990219116, 39.83065611975533, 40.90540000370571, 38.97463457924979, 37.524225916181294, 39.003584248679026, 38.113839626312256, 38.54227944782802, 39.420448371342246, 39.71561826978411, 39.12118598393032, 37.16744634083339, 38.832995550973074, 37.22629063470023, 39.28799486160278, 38.43906395775931, 41.01798166547503, 45.615816593170166, 55.375690596444265, 51.87756790433611, 54.26999248777117, 52.12763009752546, 48.47672346660069, 50.19156667164394, 51.7615190914699, 47.399693625313894, 51.0415050642831, 45.06002671377999, 23.642496381487163, 3.26637247630528, 0.11122105656457798, 0.29275914494480404, 0.7507282676441329, 0.8481970546501023, 0.03433729515277913, 0.08975443416940314, 0.09427966563297169, 0.037586300633847713, 0.030881462020001242, 0.041923075781336853, 0.05953501537442207, 0.04263427547578301, 0.04443093781758632, 0.043653903262955804, 0.02773749375981944, 0.027637204587725655, 0.04847915577036994, 0.03389062912070325, 0.033622889380369864, 0.025707914094839777, 0.05611127694802625, 0.06347032849277769, 0.0067289138844768915, 0.02154387530338551, 0.01364573447166809, 0.0384737972968391, 0.0231590414020632, 0.026336838025599718, 0.03161114161568029, 0.06576246049787317, 0.10164173665855612, 0.2180314590888364, 1.605813049844333, 11.278161355427333, 17.937806470053538, 5.19450627054487, 1.2312635651656558, 0.6812393878187452, 0.25482868456414765, 2.005820734160287, 8.958890012332372, 34.26617738178798, 32.39442300796509, 13.506037831306458, 6.619488000869751, 0.22598019827689442, 0.37680775778634207, 0.08446988809321608, 0.14943040162324905, 0.09569848235696554, 0.048343112891806025, 0.056284459440835884, 0.2765279087637152, 2.9052589620862688, 52.78527014596121, 52.93826600483486, 82.70643670218331, 55.954670088631765, 22.90906364577157, 28.91254346711295, 21.384297098432267, 31.31083059310913, 43.21494994844709, 46.46068974903652, 60.09451798030308, 66.13222462790353, 21.143368312290736, 2.399942968572889, 0.04195309756323695, 0.05225074178140078, 0.04345557765503015, 0.023156393419152925, 0.03422878383259688, 0.025385089185354964, 0.06482230273208447, 0.010525185847654939, 0.045380934341145415, 0.01717203516247017, 0.03020693375063794, 0.019566193389307176, 0.04818588275728481, 0.0165463376657239, 0.020994436661047593, 0.014706267742440104, 0.022396203496360352, 0.09300574327686004, 0.02565520379825362, 0.03189507120155862, 0.02464747242629528, 0.004607759981549212, 0.049460609177393575, 0.020115155360794494, 0.04807329683431557, 0.06899884862026998, 0.08482660752321992, 0.0726048754794257, 1.3309937736817767, 0.44159284287265366, 0.8699838912912777, 4.363572069576808, 21.474012238638743, 50.23009443283081, 59.80154718671526, 58.19371318817139, 58.86096259525844, 60.19021551949637, 58.066936356680735, 58.94775949205671, 58.216555391039165, 56.08746753420149, 56.63974857330322, 56.2552422114781, 58.02436474391392, 50.885028157915386, 46.63946689878191, 44.92624609810965, 43.84993886947632, 44.25303513663155, 42.95280483790806, 42.83686719621931, 44.17480536869594, 42.854314122881206, 41.24470485959734, 41.08313839776175, 42.41036244801113, 42.632437297276084, 41.82828753335135, 43.06451102665493, 44.04240049634661, 47.02834367752075, 47.527165276663645, 46.829899651663645, 46.244392326899934, 43.6204502923148, 44.357063565935405, 47.39078950881958, 51.26661627633231, 49.33924504688808, 49.83051742826189, 48.86376939501081, 48.922648429870605, 47.134446144104004, 43.81250892366682, 45.54026188169207, 46.658438955034526, 46.87603221620832, 43.030610765729634, 43.40107829230172, 43.678707463400706, 42.902454716818674, 40.528654779706685, 41.807165009634836, 40.50015326908657, 40.454673835209434, 41.765677315848215, 42.028659684317454, 42.38257312774658, 39.532328265053884, 41.84842341286795, 38.45149081093924, 41.89732136045183, 41.222960472106934, 43.13291951588222, 47.81734636851719, 57.380982398986816, 53.71169778278896, 55.26494673320225, 52.75064032418387, 51.30870498929705, 54.14795780181885, 54.85351610183716, 49.640129838671, 54.57207236971174, 42.8182738167899, 19.33746027946472, 1.3230495942490441, 0.29456825501152445, 0.5333249962755612, 0.544588569019522, 0.2346366766308035, 0.09218847498829875, 0.10055969722036805, 0.09163354869399752, 0.036188545636832714, 0.05422273078667266, 0.0463694886171392, 0.08360471523233823, 0.024015523925689713, 0.021242123995242373, 0.015693108717511808, 0.013072083155358476, 0.0406160646650408, 0.0061244265442448, 0.031275388917752674, 0.02121613610402814, 0.014155877454738532, 0.02513519661234958, 0.041696282236703804, 0.07036387787333556, 0.061228204518556595, 0.054131854591625075, 0.09978803327041012, 0.11852011882833072, 0.023682359838858247, 0.07840700128248759, 0.04965510445513895, 0.10878924812589373, 0.34857695549726486, 3.0400257876941135, 19.198965311050415, 27.563778264181956, 12.740209988185338, 4.066285576139178, 1.4521923959255219, 0.3648959126855646, 3.006601695503507, 21.21419824872698, 53.56760604040963, 45.058855942317415, 30.296518666403635, 6.177467490945544, 1.1589111047131675, 0.2773069755307266, 0.11029295636607067, 0.056239211333117316, 0.0651246172242931, 0.15690416629825318, 0.3912058366196496, 0.9275307719196592, 17.268208571842738, 94.6903144291469, 79.54966858455113, 109.81675815582275, 81.44016919817243, 39.407892976488384, 44.74877520969936, 35.474952016557964, 49.1370073046003, 55.172021525246755, 57.35868215560913, 79.92353030613491, 79.61943544660295, 36.54532895769392, 3.969658281121935, 0.22109170630574226, 0.11565642963562693, 0.1182303029511656, 0.14150530259524072, 0.13711009201194557, 0.19942093986485684, 0.15236659906804562, 0.1096376950985619, 0.08223703290734972, 0.15552079624363355, 0.10695906276149408, 0.18956050968595914, 0.12201804827366557, 0.14083518141082355, 0.09764852414705924, 0.0897638997329133, 0.1370484267494508, 0.12733370518045767, 0.14087498427501746, 0.26678998129708426, 0.10151003979678665, 0.09170106971370322, 0.1940256908003773, 0.10114133065300328, 0.17752787178116186, 0.20626145494835718, 0.28035688187394825, 0.22284593646015438, 1.9374745615891047, 0.256875499018601, 2.7305363033499037, 12.821680222238813, 33.89951746804373, 56.32700668062483, 62.1338073185512, 61.396235193525044, 61.478084972926546, 64.21819046565464, 59.887628419058665, 57.31332084110805, 60.90773514338902, 57.881488936288015, 58.789215496608186, 61.127145358494346, 59.62006023951939, 52.23196772166661, 48.29749468394688, 46.21995203835623, 47.01873084477016, 46.86823286328997, 46.17510836465018, 44.960052558353965, 46.880312306540354, 45.64183064869472, 45.98035383224487, 45.391549587249756, 46.73130818775722, 45.74142265319824, 46.140909331185476, 45.17309127535139, 46.26919044767107, 46.47814014979771, 49.745846680232454, 51.174851417541504, 49.23424734388079, 45.89210476194109, 47.628351892743794, 48.55151735033308, 54.1763585635594, 50.42426879065377, 50.60722528185163, 51.459126540592735, 49.712498801095144, 49.07186794281006, 44.23291662761143, 49.30501822062901, 50.142998763493125, 52.386217730385916, 46.10102667127337, 44.660057135990684, 45.391205651419504, 44.24618073872158, 43.31648397445679, 45.66341870171683, 43.05349465778896, 42.277134214128765, 44.23393106460571, 45.797119413103374, 43.522560596466064, 41.05987235477993, 43.39759029660906, 40.154150349753245, 44.99677031380789, 43.32844182423183, 46.26842267172677, 49.05448702403477, 58.83990260532924, 55.68945734841483, 57.625124726976665, 54.367274216243196, 51.928300176348, 56.57581124986921, 55.33575929914202, 51.08266619273594, 56.65013265609741, 46.58573300497872, 25.48211359977722, 5.053297162055969, 0.2852780249501978, 0.2789233273693493, 1.5391983900751387, 1.3773317443472999, 0.2009226328560284, 0.15904862194189004, 0.1761762707361153, 0.2282376028597355, 0.2089977559766599, 0.1342084048581975, 0.20925707849008696, 0.07274646538176707, 0.17193633610648767, 0.12068558191614491, 0.10861684594835554, 0.19814996235072613, 0.11771564771022115, 0.12189260071941785, 0.14073350972362927, 0.07779134610401732, 0.10468109856758799, 0.13395605768476213, 0.10011805913278035, 0.22646069606500013, 0.20621868010078157, 0.21416534297168255, 0.17499160287635668, 0.11985049529799394, 0.2255016275282417, 0.1440852555845465, 0.2793653522218977, 0.4497005492448807, 2.598948061466217, 29.458948067256383, 37.665767669677734, 23.022227219172887, 7.48875367641449, 4.770547602857862, 0.6066349510635648, 7.100076224122729, 38.846930163247244, 66.00337028503418, 70.61309010641915, 59.0612861088344, 15.761126926967076, 0.7572385125926563, 0.44141037123543875, 0.16888617191995892, 0.19163282348641328, 0.2160740891205413], [0.06574435039822545, 0.05916057260973113, 0.02414986877036946, 0.2535248930965151, 13.066310661179678, 22.99514487811497, 17.691411188670568, 33.541077273232595, 30.108437878744944, 9.276314990861074, 2.153390918459211, 1.2514704465866089, 1.700132131576538, 27.15880424635751, 87.43637425558907, 57.28073031561715, 10.542982016290937, 1.1856162888663155, 0.05956329671399934, 0.06509319426757948, 0.13853938531662735, 0.035230664536356926, 0.048248728670712025, 0.0430062348023057, 0.03669858005430017, 0.020568795036524534, 0.055649510119110346, 0.020533477288803885, 0.08185290066259247, 0.030484047452253953, 0.055899892933666706, 0.02584443873326693, 0.04746643207701189, 0.044862133251237016, 0.04604842959504042, 0.025659705878102353, 0.038765007563467534, 0.024831910118726746, 0.01249662269505539, 0.024755147452067052, 0.07787658367305994, 0.016705077540661608, 0.037006360146084, 0.05468012445739337, 0.15804501436650753, 0.03599601471796632, 0.05250896506809762, 0.6449003634708268, 0.5154818594455719, 0.6884467867868287, 2.113904740129198, 20.36316204071045, 51.17851659229824, 56.82086031777518, 54.613646915980745, 52.876572949545725, 58.392431667872835, 57.0787079674857, 53.8915901184082, 54.600716318402974, 57.45605421066284, 53.07424919945853, 58.445050375802175, 52.519279207502095, 52.813347816467285, 46.118622984204976, 39.42585754394531, 40.86718143735613, 40.10719789777483, 40.172149658203125, 39.92965405327933, 40.21151467732021, 38.61312675476074, 38.768495423453196, 39.20442887714931, 38.09679569516863, 38.822378703526084, 41.94511801855904, 42.879602091653005, 44.62420443126133, 39.40684379850115, 43.223603929792134, 41.95926455089024, 39.27889272144863, 41.31929724557059, 41.3031496320452, 42.03021955490112, 46.26813432148525, 44.97465072359358, 41.81817443030221, 42.063963481358115, 39.452382292066304, 39.739488806043354, 39.97799614497593, 44.656569140298025, 41.67360326222011, 42.822404520852224, 42.56757933752877, 41.01937130519322, 38.183443205697195, 37.41075488499233, 38.1552300453186, 37.09571313858032, 37.372025626046316, 38.18432215281895, 39.53363105228969, 38.37522390910557, 37.155766419001985, 37.7637094770159, 37.79147795268467, 38.86142757960728, 39.384758949279785, 42.16103676387242, 46.055310998644146, 54.86626952035086, 50.02803039550781, 52.436981269291465, 50.1264203616551, 48.148480142865864, 48.814155782972065, 49.48627587727138, 49.82364565985543, 52.897528716496055, 31.66820423943656, 6.651032388210297, 0.019272752438804934, 0.7849031995449747, 1.1613205011401857, 0.07368029920118195, 0.05259219078080995, 0.028264106484130025, 0.07256796317441122, 0.05821510870009661, 0.07041100213038069, 0.06257164278732878, 0.05957470288766282, 0.07982092576899699, 0.0304424057581595, 0.03568898780005319, 0.040164153557270765, 0.013836788728700151, 0.010303243828405226, 0.03663675872875111, 0.05567936905260597, 0.03590851423463651, 0.037617998397243876, 0.12909348575132235, 0.09883201814123563, 0.02116617387426751, 0.07463020751518862, 0.04368444412414517, 0.10307706892490387, 0.04642415139824152, 0.060625821485051086, 0.009739442296060068, 0.03371302257957203, 0.08501017160181489, 0.15914211049675941, 4.547670670918055, 13.771226252828326, 12.735270687511989, 3.305538820368903, 0.18253311248762266, 0.4567750096321106, 0.3482285141944885, 2.139069161244801, 10.999851260866437, 50.356787885938374, 36.18453679765974, 20.484286512647355, 5.672109373978206, 0.3452773211257798, 0.032070689635085206, 0.039537020958960056, 0.04349934994908316, 0.057938700674899986, 0.009543271884987397, 0.04025171510875225, 0.0847678328199046, 0.27672270259686876, 3.7690138476235524, 19.03552109854562, 22.920118229729788, 54.783815247671946, 39.28476047515869, 15.742217404501778, 7.938593081065586, 5.990703821182251, 21.021377052579606, 49.13891805921282, 95.67171273912702, 65.96439089093889, 29.65623869214739, 2.1704487460000172, 0.08197836178754057, 0.0754119816369244, 0.042500488726156097, 0.012899624998681247, 0.019534487144223282, 0.0105348320711138, 0.02196203438299043, 0.021074362997231737, 0.011653911887801119, 0.06794975205723729, 0.051094100810587406, 0.04156081272023065, 0.04207267578957336, 0.03224059819642987, 0.04411432319985969, 0.042003987689635584, 0.01155090518295765, 0.05646186242146151, 0.04365665472245642, 0.006360195834921407, 0.04081038352368133, 0.020032426674983332, 0.031034590410334722, 0.05151950494785394, 0.01473080865772707, 0.045786155454282246, 0.040554412973246405, 0.03582946151228888, 0.07645617239177227, 0.18964515014418534, 1.04377424291202, 0.7190999048096793, 1.4266457153218133, 12.870382751737322, 47.655877181461875, 61.17706816537039, 56.094975062779014, 56.90487446103777, 59.266132899693076, 59.31682000841413, 55.002283981868196, 57.005182129996165, 60.19727488926479, 55.86984995433262, 60.78178514753069, 55.536305155072895, 56.78321150371006, 49.32649857657296, 41.37454237256731, 42.68633099964687, 41.73871830531529, 44.357501302446636, 41.917978354862754, 42.96447433744158, 41.59095443998064, 42.04015895298549, 41.318772656576975, 42.75081375667027, 41.32161099570138, 43.81419038772583, 44.63672855922154, 46.78643866947719, 41.873947620391846, 48.6156005859375, 43.36937018803188, 39.82421513966152, 43.28684990746634, 41.77855232783726, 41.76541328430176, 46.97422763279506, 46.55697788511004, 42.17883110046387, 40.46212577819824, 40.722377504621235, 40.55274418422154, 41.876469816480366, 46.14195156097412, 45.478353432246614, 43.91980995450701, 45.21100064686367, 42.373401505606516, 39.38665580749512, 38.50274767194475, 39.38463735580444, 39.71242904663086, 40.15649536677769, 40.136349064963206, 42.37405811037336, 40.355057512010845, 41.25492565972464, 39.43878814152309, 39.6750442641122, 38.985918453761506, 41.74375922339303, 43.92672688620431, 49.65784427097866, 55.91432537351336, 52.810832568577354, 54.46283973966326, 53.3584200995309, 50.60599545070103, 49.9770062991551, 51.40856449944632, 55.014922755105154, 53.894421509334016, 27.3016140460968, 3.3460342245442525, 0.04032594344711729, 2.863520916019167, 1.3645694234541483, 0.08553003120635237, 0.03912852930703333, 0.03741673473268747, 0.0965066175641758, 0.10520337375679187, 0.041321608770106516, 0.07014730306608336, 0.049560526851564646, 0.020705546984182935, 0.09586279639708144, 0.025568812719679306, 0.0072732830220567325, 0.054327578017754216, 0.011530676357714193, 0.05207538119118128, 0.06428079107510191, 0.060594235679933, 0.0784473605453968, 0.04601017379068902, 0.11291263758071832, 0.03235667518207005, 0.057320955608572276, 0.054581468858356984, 0.02577884984202683, 0.05046334483527711, 0.08511946323726859, 0.0605339410581759, 0.10803574855838503, 0.11052727486406054, 0.2512986739831311, 6.53264159815652, 23.844935621534074, 19.133718252182007, 7.332682371139526, 1.9089107343128748, 1.5768528495516096, 0.37184473552874153, 5.5315073643411905, 24.654970509665354, 62.45552280970982, 49.56956393378121, 29.406586442674907, 7.669134991509574, 0.3886748467172895, 0.04301782078774912, 0.016537793213501573, 0.054743184109351466, 0.039336958301386664, 0.21729615783052786, 0.275156670915229, 0.28371497882264, 0.6726353466510773, 28.817040477480205, 70.84925937652588, 56.08108213969639, 82.28332614898682, 81.5127500806536, 26.21252386910575, 13.05002234663282, 13.084104997771126, 29.527839456285747, 55.88230112620762, 97.81503745487758, 68.34282875061035, 41.264232771737234, 4.217302066939218, 0.2343114683670657, 0.269620666546481, 0.2421489278120654, 0.1716883722692728, 0.1825651257698025, 0.09466602347259011, 0.12586251912372454, 0.10705128924122878, 0.09250155783125333, 0.2002721077629498, 0.14267604691641672, 0.14072904496320657, 0.11472790874540806, 0.1311412772962025, 0.0918440099007317, 0.16725145892373153, 0.09897381160408258, 0.1794511385794197, 0.12540530865745886, 0.10585662656064544, 0.06689247236187969, 0.19335901657385485, 0.20471691925610813, 0.1678158507815429, 0.17072247767022677, 0.18306593889636652, 0.30532034805842806, 0.1149983320917402, 0.12625932640263013, 1.669225892850331, 1.1244920087712151, 0.5988365752356393, 3.1123502382210324, 23.94221908705575, 53.687757764543804, 61.03829179491316, 56.943871225629536, 57.38407434735979, 62.18824645451137, 62.93842955998012, 56.25276517868042, 59.87869998386928, 61.05149337223598, 58.531479018075125, 62.60153920309884, 58.83130768367222, 54.25822223935808, 50.41674041748047, 44.599639075142996, 44.87833479472569, 44.66030727113996, 45.63929803030831, 44.47980349404471, 46.15446874073574, 44.62301281520298, 45.446179798671174, 43.105713844299316, 44.63869489942278, 45.092658928462434, 48.76762022290911, 47.24261917386736, 50.97719253812517, 43.75337627955845, 51.429037366594585, 46.96921798161098, 43.786161354609895, 46.03830180849348, 45.46915749141148, 46.86290706907, 50.831509658268516, 50.496321610042024, 46.009821142469136, 44.26825169154576, 44.770457063402446, 43.60832221167428, 44.02623898642403, 48.01163189751761, 47.06130593163626, 47.061583859579905, 45.227318491254536, 44.34171846934727, 43.155654021671836, 40.3670778955732, 42.111735820770264, 42.07172114508492, 41.76296057019915, 42.69712850025722, 45.411331108638215, 42.15247310910906, 42.91838346208845, 41.987783432006836, 40.621718951633994, 42.519334520612446, 44.83537755693708, 47.19417980739048, 51.618344511304585, 58.696887833731516, 55.35326875959124, 56.70327247892107, 54.558123861040386, 53.488684926714214, 52.61728354862758, 53.43119205747332, 55.31556783403669, 56.90190410614014, 34.53646230697632, 7.749260749135699, 0.2502486546124731, 1.9627668729850223, 3.998288767678397, 0.20840451280985559, 0.15181869561118738, 0.09803819323756865, 0.4756273180246353, 0.31459904302443775, 0.2074764533234494, 0.22130840324929782, 0.10377739848835127, 0.16001652500459126, 0.18708137342972414, 0.1428784267710788, 0.16876894821013722, 0.15669528607811245, 0.10760500095784664, 0.17621163598128728, 0.10540289697902543, 0.1801112445869616, 0.12608373511050427, 0.19003997610083648, 0.16673475450703076, 0.1422018323625837, 0.17849924894315855, 0.2037568600582225, 0.14130080571132048, 0.17633860345397676, 0.16280393329049858, 0.09208670152085167, 0.19833615235984325, 0.2731315152985709, 0.5708568851862634, 8.189074771744863, 33.88623251233782, 36.20815372467041, 11.99401341165815, 4.325539801801954, 2.588645402874265, 1.108154948268618, 14.100107073783875, 51.46062387738909, 80.97298622131348, 67.56142044067383, 44.68444878714425, 10.881770099912371, 0.5499936161296708, 0.18261399386184557, 0.16086226462253503, 0.19813327038926737, 0.22395198925265244], [0.042462813069245646, 0.016077524250639335, 0.18628325339938911, 0.11910380822207246, 0.4498886120106493, 2.6833560807364325, 11.336674741336278, 9.75745255606515, 11.006577117102486, 8.586275492395673, 2.536369327987943, 0.41148776401366505, 2.380800030061177, 6.594691617148263, 28.04382583073207, 24.270854984010967, 26.66529975618635, 2.679039295230593, 0.22272500794913086, 0.010060664166563323, 0.042320517490484884, 0.03615327538656337, 0.05591682577505708, 0.07652055857969181, 0.04895554842161281, 0.036325110987360985, 0.026610786361353736, 0.02618097005012844, 0.025144319515675306, 0.03825098675276552, 0.004065415422831262, 0.041654810176364014, 0.051070620106267076, 0.03025112334372742, 0.039004391325371604, 0.01901332475244999, 0.020843800190570097, 0.05350358883983322, 0.02041368023492396, 0.0530561424924859, 0.0474254621325859, 0.04317903731550489, 0.05293754814192653, 0.05776079557836056, 0.026771181861736944, 0.0925850040678467, 0.048743078751223426, 0.07358020850058113, 0.26395954032029423, 1.2738619936364037, 0.2573217579296657, 1.5546972155570984, 20.94817430632455, 55.603671414511545, 57.62746279580252, 53.59052119936262, 56.85798454284668, 53.57804570879255, 51.95065253121512, 53.79234552383423, 52.796171869550435, 53.0527514730181, 55.74622065680367, 54.09275436401367, 52.85820538657052, 47.702714988163535, 41.040320123944966, 38.31248862402779, 39.352831976754324, 38.5603551864624, 38.5511349269322, 38.7349807875497, 37.304940768650596, 38.62400763375418, 37.90573065621512, 38.51161009924752, 39.34674188068935, 41.264208453042166, 41.83579158782959, 43.601186411721365, 41.868253571646555, 42.51945263998849, 39.18802418027605, 37.39910970415388, 37.48403058733259, 34.49055208478655, 36.989468233925955, 41.773240430014475, 41.65113626207624, 37.2432998248509, 35.7842059135437, 35.87215273720877, 35.97688640866961, 37.66182109287807, 43.28022132601057, 42.26716007505144, 43.884221281324116, 43.067363262176514, 39.324816840035574, 40.94358382906233, 37.36175618852888, 37.995424951825825, 38.37954568862915, 37.31210783549717, 36.952184200286865, 37.92814901896885, 38.930975573403494, 37.83767305101667, 38.36541305269514, 36.10945803778512, 39.55311380113874, 41.31843219484602, 40.931747572762625, 48.920119285583496, 49.942692620413645, 49.42895671299526, 49.94336312157767, 51.61221272604806, 47.63547379629952, 47.874741962977815, 49.22235550199236, 50.384400027138845, 43.20017807824271, 12.770152381488256, 0.24119273626378604, 0.02586103230714798, 8.13702060495104, 1.9878435730934143, 0.054271079799426455, 0.19248559272715024, 0.05490430564220462, 0.05087809258007577, 0.04634953290224075, 0.0700099268662078, 0.06370864356202738, 0.0438333316706121, 0.042459461106253524, 0.06047912899936948, 0.03381503014160054, 0.024088283235739385, 0.07484100798943213, 0.03840767066659672, 0.030928148621959344, 0.05387132767853992, 0.04345819340752704, 0.004633272474166006, 0.010204052186704107, 0.07415994203516416, 0.04315455237935696, 0.07401514266218458, 0.053868864596422227, 0.08619944671435015, 0.028875705719526325, 0.04414603114128113, 0.028146877685295682, 0.14095273081745419, 0.06781117485037871, 0.6793615828667368, 5.2067989366395135, 19.835159744535172, 7.825589316231864, 2.079517671040126, 0.5070373011486871, 0.14947503565677575, 0.9222809736217771, 4.269161684172494, 14.804967948368617, 51.30524478639875, 47.49058301108224, 27.417784452438354, 1.9700850631509508, 0.5519934488194329, 0.2523439164672579, 0.181275854951569, 0.10957469990743057, 0.1635602827050856, 0.062035179430884976, 0.01812103423955185, 0.12045983331544058, 0.20220127781586988, 0.3968069260673863, 3.26892420223781, 2.234341557536806, 12.61634271485465, 22.79443747656686, 4.608914698873248, 0.6011317606483186, 0.7463230554546628, 5.756729313305446, 19.563544239316666, 51.68608944756644, 29.487338406699045, 46.3503349849156, 8.899004357201711, 0.37047433906367844, 0.08815472679478781, 0.027340912093807544, 0.04733196339969124, 0.06678260397166014, 0.07429564903889384, 0.06376339455268212, 0.07991634136331932, 0.00033550394592956375, 0.04785542602517775, 0.04646456494395222, 0.01903878677902477, 0.048961431320224486, 0.06250068159507853, 0.06156236944454057, 0.024645109428092837, 0.011242371069134345, 0.018345200157325183, 0.06499376853129693, 0.051977058074304035, 0.04558073915541172, 0.09009497732456241, 0.06565020366438798, 0.15924785339406558, 0.06198180586631809, 0.020135131431743503, 0.08234251117599861, 0.026864027504676154, 0.08829755163086311, 0.06869271397590637, 0.14741177351347037, 0.7833809469427381, 0.5926002955862454, 0.3087620133800166, 12.943762677056448, 53.42972251347133, 57.906082085200715, 56.16639559609549, 56.37008898598807, 54.62932552610125, 55.24260132653372, 55.97867611476353, 56.24250963756016, 56.91692958559309, 56.167986733572825, 56.012458256312776, 53.40896477018084, 52.492309774671284, 44.007308619362966, 41.910151209150044, 42.38207285744803, 40.514549936567036, 40.592515672956196, 38.60294764382498, 39.63949728012085, 41.37861401694161, 41.209790161677766, 42.113219261169434, 41.877188955034526, 44.16649879728045, 44.17971427100045, 47.91984272003174, 45.565084321158274, 45.13090181350708, 40.93210193089077, 38.5769579069955, 39.612659863063264, 38.377329213278635, 39.92709016799927, 46.04068851470947, 44.42108079365322, 39.32768644605364, 38.49826260975429, 39.24946710041591, 38.345978941236226, 40.108392987932476, 43.11367647988455, 43.98427186693464, 46.34188597542899, 44.93860346930367, 43.486468178885325, 41.908025060381206, 41.00826460974557, 41.2171448298863, 40.35997683661324, 40.5398656981332, 39.96704230989729, 39.70548779623849, 39.08371434892927, 40.22760323115757, 41.17987469264439, 41.30421618052891, 42.191143308367046, 47.05535479954311, 45.23648663929531, 53.94705063956124, 53.17358759471348, 53.6280449458531, 50.934704303741455, 53.136984484536306, 50.21985278810774, 53.28167724609375, 51.950211320604595, 50.07219661985125, 38.74465615408761, 8.24944680077689, 0.1459884920290538, 0.11390647425183228, 11.761138456208364, 3.3467021201338087, 0.05186325078830123, 0.15017034406108515, 0.12091981220458235, 0.06214829121849366, 0.03404502637152161, 0.10011007277561085, 0.021084049084622945, 0.0742731284616249, 0.029227308995489563, 0.02403540669807366, 0.019500282193933214, 0.054182853283626695, 0.06476096995174885, 0.0659541669966919, 0.03314791825999107, 0.04634601130549397, 0.06474446119474513, 0.031313312239944935, 0.035724037526441474, 0.030710454231926372, 0.027189242553764155, 0.07637451070227794, 0.10776402921016727, 0.09491628075816802, 0.08361551072448492, 0.09918489027768373, 0.07518214825540781, 0.182507436722517, 0.0883066982829145, 1.0672363553728377, 12.526152491569519, 31.09133005142212, 12.603768212454659, 4.308842846325465, 1.1405831681830543, 0.8809786013194493, 1.3522193261555262, 6.239659948008401, 35.204416956220356, 60.28542668478829, 56.08678661073957, 36.39720031193325, 4.008309372833796, 0.523539869913033, 0.1098347416679774, 0.015366865687870553, 0.03009407302098615, 0.06968105451336928, 0.12753999339682714, 0.17795332680855477, 0.3127459910299097, 0.44095862976142336, 0.6224635445645877, 9.934242521013532, 35.06323650905064, 47.21266201564244, 55.5955559185573, 17.8846093245915, 3.0861768083912984, 0.9716884195804596, 10.762868182999746, 35.32104941776821, 48.34707702909197, 31.651827335357666, 63.509793826511924, 8.48498204776219, 0.27278589670147213, 0.12104053715510027, 0.15238717224981102, 0.19042148920042173, 0.17600331215986184, 0.14849425399942057, 0.24105621501803398, 0.23348805255123548, 0.1452982183545828, 0.13027230463922024, 0.16441971515970571, 0.1103555987189923, 0.18869137418057236, 0.1602914673941476, 0.1279790869780949, 0.14550774996834143, 0.1322586073407105, 0.11198915142033782, 0.09049965560968433, 0.1252174630228962, 0.0861179478732603, 0.3523759645010744, 0.2551262085991246, 0.25730813294649124, 0.15493256066526684, 0.14406746439635754, 0.23808917137128965, 0.22778211587241717, 0.11897108677242484, 0.12308300898543426, 0.2513388432562351, 1.7572221138647623, 0.7407286699329103, 1.6611479605947221, 24.17924472263881, 58.41138635362898, 59.194948605128694, 55.73923771721976, 62.34935433523995, 55.62072229385376, 55.473868642534526, 57.29343509674072, 58.960168974740164, 60.24826771872384, 59.26117883409773, 58.67463970184326, 57.47146531513759, 52.29182297842843, 46.43023926871163, 43.88771275111607, 44.527968406677246, 42.49837875366211, 43.864634309496196, 43.68482535226004, 41.81132003239223, 43.50152839933123, 41.83948108128139, 45.51766286577497, 44.714287825993125, 46.59761095046997, 46.0257568359375, 50.12430463518415, 46.50985867636544, 48.193223067692344, 43.58100189481463, 41.050186565944124, 42.389410155160085, 39.6237005506243, 39.85059397561209, 49.08862352371216, 46.1883134160723, 41.29168857846941, 39.32706110818045, 41.3355073928833, 40.96096474783761, 42.99815920421055, 48.51465368270874, 46.32934100287301, 49.64083508082798, 47.45354216439383, 43.029686655317036, 46.06201253618513, 41.248130321502686, 43.347945417676655, 44.18276800428118, 43.35323647090367, 42.37149422509329, 43.831456661224365, 41.746778215680806, 42.38544273376465, 41.80818292072841, 42.69525596073696, 44.22885193143572, 49.13828229904175, 44.834984983716694, 52.62689290727888, 53.2507403918675, 54.18597139630999, 53.41328654970442, 55.46872002737862, 51.75208343778338, 53.2688022341047, 52.51306404386248, 54.05826003210885, 48.35626254762922, 16.42847534588405, 0.4378826676734856, 0.13550299539097718, 18.508811167308263, 4.687394601958139, 0.19031026374016488, 0.3460136944694178, 0.19931917318275996, 0.16646572894283704, 0.13578776296760353, 0.26443340203591753, 0.1649063333336796, 0.18645086511969566, 0.1913065974201475, 0.1496015688670533, 0.1909795706825597, 0.16896800324320793, 0.1610265379505498, 0.16521205407168182, 0.14330701663025788, 0.165472326534135, 0.16997626556881837, 0.12988141418567725, 0.20643758906849793, 0.29672930762171745, 0.12815391831099987, 0.14402437742267335, 0.26908959075808525, 0.20518422632345132, 0.17614230327308178, 0.12657987991614, 0.34911126111234936, 0.39662241882511545, 0.15468915658337729, 1.3415360365595137, 17.721561159406388, 38.771837506975444, 32.16565009525844, 8.201396533421107, 2.2535698286124637, 0.6064773138080324, 1.6472997665405273, 19.423663105283463, 65.6253604888916, 67.03707463400704, 77.92860521589006, 47.995866434914724, 3.6038510416235243, 1.068496693457876, 0.5058244062321526, 0.3018881008028984, 0.2781509645283222, 0.31945279400263515], [0.028455214175794805, 0.050108525303325484, 0.08192484573061977, 0.14571950717696122, 0.44467974294509205, 0.8338855568851743, 0.3741829943444048, 6.17814667735781, 9.135363834244863, 8.533926027161733, 1.0792177638837268, 0.6042754405311176, 0.4730450308748654, 2.311282651765006, 11.49362325668335, 32.537514209747314, 41.428304059164866, 16.45427574430193, 0.2512088088052613, 0.07555306263800178, 0.08566172128277165, 0.029196506898318018, 0.10071764660200902, 0.043711616058966944, 0.05683321785181761, 0.06771767272480897, 0.06976911478808948, 0.04436552364911352, 0.07721008586564235, 0.016154889117128084, 0.022458688089890138, 0.03062568824472172, 0.040199417022189925, 0.07330355620277779, 0.06660091943506684, 0.07412288045244557, 0.035366276545184, 0.02021636564417609, 0.024548633622803857, 0.013062916995425309, 0.019466319819912314, 0.08613836499197142, 0.016781171850327934, 0.05516759080014058, 0.06044908346874373, 0.028382717798064862, 0.03995053716269987, 0.11219484252589089, 0.07036617132169859, 0.30610774723546846, 3.816611179283687, 2.4831098658697943, 1.2477164651666368, 28.70906547137669, 58.803320339747835, 56.18353680201939, 50.66947766712734, 52.459500380924766, 52.526807580675396, 52.02997664042881, 51.87031398500715, 54.015382698604036, 52.60551677431379, 55.1344769341605, 47.26067754200527, 45.46131992340088, 48.11362450463431, 39.72008943557739, 38.62089484078543, 38.41075004850115, 38.93669046674456, 38.177089078085764, 38.28916004725865, 38.65860618863787, 38.832762786320274, 39.296287536621094, 40.068072591509136, 41.067150592803955, 42.49529375348772, 44.05095025471279, 47.221785000392366, 40.8037964957101, 39.452649797712056, 37.036907059805735, 41.10157544272286, 40.257695879255024, 43.173611640930176, 42.42188603537423, 43.626227719443186, 44.03875616618565, 42.37136568341936, 39.75347900390625, 38.66137851987566, 37.824905736105784, 40.1403477532523, 42.93004253932408, 43.13661943163191, 42.05565343584333, 40.23417622702462, 38.2569933618818, 38.92834915433611, 37.566741943359375, 36.87441301345825, 36.95083277566092, 36.477719511304585, 37.94178138460432, 37.93562180655343, 39.48434747968401, 38.064882619040354, 39.10411425999233, 41.53177315848214, 46.738426617213655, 44.743668283735005, 51.118411200387136, 52.52509137562343, 50.76996946334839, 48.42102323259626, 46.7499988419669, 49.2284004347665, 49.56598908560616, 46.57209369114467, 41.71282236916678, 21.256047248840332, 0.8034593409725598, 0.03829085407778621, 0.10184465934123312, 0.41924208934817997, 0.2847173107521874, 0.052810835119869025, 0.1844775631491627, 0.037236902596695085, 0.031886419880070856, 0.04435081300990922, 0.009343107447161205, 0.034883352994386635, 0.06717181844370705, 0.09335011336952448, 0.038080067174243074, 0.01633795447248433, 0.1006675096494811, 0.02692904812283814, 0.004672001132608524, 0.07839252813053982, 0.11625173554888793, 0.020785564922594597, 0.03186663379892707, 0.04708425062043326, 0.10085409999425922, 0.06819470319896936, 0.07635530816125018, 0.045123104604759386, 0.014063505089974828, 0.12187945071075644, 0.05487347301095724, 0.06930631319327013, 0.06058890239468642, 0.01828062058692532, 0.8801154504929269, 13.050885660307747, 18.07734019415719, 6.55029045683997, 2.656519966466086, 0.23329602714095796, 0.11069314274936914, 1.0704508743115833, 3.9978566765785217, 26.083888394492014, 49.28125885554722, 55.10862616130284, 18.989887067249843, 0.4367129275841372, 0.2634765048112188, 0.01483856510770108, 0.057006875319140296, 0.06285381157483373, 0.06892410798796586, 0.04331524982782347, 0.053537647905094285, 0.11485763107027326, 0.06068152242473193, 0.3795367442071438, 0.7599425560661724, 1.794091101203646, 7.36592515877315, 8.518884914261953, 3.0444891367639815, 0.2489392991576876, 0.8462549788611275, 0.6543331944516727, 7.808701719556536, 22.367802449635096, 38.87461873463222, 41.76892907278878, 33.123379366738455, 0.7355003676244191, 0.09365174254136426, 0.08955896858658109, 0.06290487133498703, 0.009725305867115301, 0.010211358312517405, 0.09315735514142684, 0.026190279550584297, 0.05018797836133412, 0.07111532826508794, 0.05977943047348942, 0.017245361049260412, 0.021702662675774524, 0.023562445737687603, 0.05146829251732145, 0.03384742679606591, 0.028973380835460763, 0.035822472601596794, 0.029304533065961938, 0.06532047635742597, 0.02731155527622572, 0.0732983314831342, 0.08838108607700892, 0.053208951971360614, 0.04213016127635326, 0.014804767278422202, 0.05642413587442466, 0.09125724674335547, 0.09580131433904171, 0.1377148838447673, 0.07631469784038407, 0.06719499719994408, 8.419065356254578, 3.820112637111119, 1.0198950214045388, 22.0869562625885, 58.67080429622105, 57.914315700531006, 52.81271205629621, 54.05104085377285, 54.20284162248884, 54.149017402103965, 54.77576923370361, 55.73834834780012, 55.64578097207205, 58.49361828395298, 53.998995372227256, 48.33782202856881, 50.16153655733381, 43.64553676332746, 41.17446552004133, 41.776919501168386, 42.337917055402485, 40.82287277494158, 41.28235714776175, 41.47873061043875, 41.567195074898855, 41.785399777548655, 43.82052714484078, 43.942249161856516, 44.963245255606516, 45.524541582380024, 48.845804827553884, 43.21276821408953, 42.26804944447109, 41.70399815695626, 43.86445018223354, 43.56104666846139, 46.76677179336548, 45.027953829084126, 45.69717305047171, 48.106856959206716, 45.978853021349224, 41.202939237867085, 40.54148115430559, 40.14051798411778, 41.52268838882446, 45.36364562170846, 46.003765787397114, 45.119558879307334, 43.2802734375, 41.361365113939556, 39.93747772489275, 39.967810085841585, 38.299721309116904, 38.70222350529262, 39.942456109183176, 40.09151928765433, 40.87064511435372, 41.04241500582014, 40.60273994718279, 40.95323487690517, 46.803642409188406, 51.697116238730295, 54.18539816992623, 51.62484802518572, 57.29085731506348, 53.64138201304844, 50.57984243120466, 49.57517460414341, 51.19020693642752, 48.8936779158456, 45.75777523858206, 38.91654416493007, 14.065008248601641, 0.6933165511914662, 0.04060119457010712, 0.022451907828716294, 0.3057304817650999, 0.3206834936780589, 0.11821392311581544, 0.06282261253467628, 0.013915398706948119, 0.17814467368381365, 0.025751542200201323, 0.04048971465921827, 0.03808965826673167, 0.0418266118504107, 0.060884241546903334, 0.06998809160930769, 0.053313341191304583, 0.04378488087760551, 0.018392538152901188, 0.04895099884431277, 0.07729944214224815, 0.08526867987321955, 0.03677264893693583, 0.06560565105506352, 0.015247757347034556, 0.05567055149003863, 0.021847222865160023, 0.050243424850382974, 0.05181598064622708, 0.09573202912828752, 0.08406131501708712, 0.02461699772227023, 0.08960624212133032, 0.014545417623594403, 0.047797468956559896, 1.583389150244849, 24.87838636125837, 29.623561314174108, 9.17120611667633, 3.380600209747042, 0.7715122295277459, 0.45719016449792044, 1.1138688645192554, 7.866967575890677, 46.05137831824166, 54.58860560825893, 74.39311858585903, 27.009178263800486, 0.820240923336574, 0.320069962314197, 0.03486009620662246, 0.04158234263637236, 0.06775201338210277, 0.027888854566429342, 0.2404271587729454, 0.14445618353784084, 0.1493055783212185, 0.24445700539009912, 0.7171110372458185, 1.5941877365112305, 1.090559720993042, 13.77425914151328, 47.87608643940517, 14.854157720293317, 0.6274636419756072, 0.6244159883686474, 0.7771443958793367, 14.40945737702506, 30.551184041159495, 48.346086910792756, 58.35890660967146, 34.44196680613926, 0.608791389635631, 0.3237371455345835, 0.2599873963211264, 0.22389537229069642, 0.17504584496574743, 0.11055006006998674, 0.19369965472391673, 0.14951348145093235, 0.15704722862158502, 0.1272892611367362, 0.12300929294100829, 0.11179224055792604, 0.045745300860809426, 0.11544753584478583, 0.115189203992486, 0.13666951922433718, 0.10620077952210392, 0.23085889220237732, 0.08829027095011302, 0.15543293952941895, 0.1525403583156211, 0.16314472071826458, 0.15006317624023982, 0.14747936917202814, 0.08148296337042536, 0.13268736004829407, 0.21324507306729043, 0.1479620247014931, 0.13114111444779805, 0.2746865547129086, 0.10746290893959147, 0.7534109236938613, 8.224304744175502, 3.7161875622613088, 1.4583892119782311, 34.64290870938982, 63.47904109954834, 60.84679249354771, 53.56938477924892, 58.47888115474156, 56.089041301182334, 57.029261112213135, 55.69825029373169, 56.94872454234532, 57.45939629418509, 60.87327207837786, 54.16352871486119, 48.1062524659293, 52.3161347252982, 45.5116457257952, 43.33348274230957, 45.54810292380196, 44.08561134338379, 44.52383770261492, 45.29830823625837, 42.8872138432094, 43.79503073011126, 45.516908986227854, 44.94991513660976, 47.68447249276297, 46.73233652114868, 48.62311506271362, 51.859443528311594, 46.24463551385062, 43.78368084771292, 42.55719525473458, 46.588345527648926, 44.062470367976594, 46.8481456211635, 47.63544600350516, 47.18314954212734, 48.3065481867109, 47.89812959943499, 44.24390172958374, 42.16283982140677, 42.070585114615305, 43.98684270041329, 49.085712228502544, 46.049891403743196, 46.915873186928884, 44.22265066419329, 42.87852512087141, 41.52660717282976, 41.33580616542271, 40.56477151598249, 42.472434180123464, 41.019857679094585, 42.737441948481965, 42.285152435302734, 45.70651142937796, 42.80558293206351, 41.62415293284825, 45.50367961611067, 50.88844319752285, 50.545674664633616, 58.381995473589214, 56.49138368879046, 55.81649126325335, 51.065816811152864, 52.35206733431135, 53.34978001458304, 53.61162635258266, 51.60208920070103, 47.913391317640034, 26.432917254311697, 2.095823573214667, 0.09910445673657314, 0.19052953911679132, 0.5889334923454693, 0.7114643773862294, 0.19742139215980256, 0.6099291571549007, 0.12375235663993017, 0.22831248598439352, 0.23455278256109782, 0.17692812824887888, 0.1405049112758466, 0.20418782478996686, 0.40689484189663616, 0.14693096359925611, 0.139227243406432, 0.15810233700488294, 0.13624304639441626, 0.12296442820557527, 0.19788196815976075, 0.17397370535348142, 0.1580139510333538, 0.33383993485144203, 0.07778605353087187, 0.18092609729085649, 0.16817246164594377, 0.18547775090805121, 0.14836886072797434, 0.17637784991945538, 0.3651798388787678, 0.125329231311168, 0.16698563604482583, 0.22286733745464257, 0.22880754513399942, 1.6299756275756019, 34.21687991278512, 36.088609967912944, 28.166367735181534, 9.385671819959368, 2.099411232130868, 0.4393578570868288, 2.3612840601376126, 15.783811058316912, 70.23467036655971, 57.94417905807495, 96.49994495936802, 29.397133418491908, 0.8870113204632486, 0.4142964647284576, 0.1800313267324652, 0.10621843500328915, 0.21112610319895403, 0.10463052056729794], [0.05818188762558358, 0.0774105658222522, 0.03929166608889188, 0.05232956719451717, 0.14466929781649793, 0.10974714279706989, 3.0320614150592258, 6.404237585408347, 7.130201441901071, 4.551212080887385, 1.2768237718514033, 0.3377634414604732, 0.5572606176137924, 1.5941428989171982, 17.34039514405387, 27.69681715965271, 35.95454100200108, 39.353450366428916, 2.4836448771612982, 0.06003447821629899, 0.0612749420106411, 0.10683972880776439, 0.08742936607450247, 0.044211686189685545, 0.06081572986607041, 0.02582644737724747, 0.021522667691377655, 0.05768887086638382, 0.07633251616997377, 0.01685971736774913, 0.014267162286809512, 0.03963879442640713, 0.04721218500552433, 0.020792394377557293, 0.02173551564503993, 0.026053634472191334, 0.06016114713358028, 0.03686618159658142, 0.013815136676255082, 0.03212749658684645, 0.023557273604507958, 0.019139199783759456, 0.10579759401402303, 0.03370906672041331, 0.05222955113276839, 0.02470499862517629, 0.06014390555875642, 0.16724581351237638, 0.06786703863846404, 0.05965090237025704, 2.8742658708776747, 0.6056357675365039, 0.09757955106241362, 2.38554738674845, 38.31451054981777, 53.049489293779644, 53.67180470057896, 52.94977569580078, 50.90513971873692, 53.21960203988211, 53.63643836975098, 55.20324672971453, 52.45689480645316, 55.930007457733154, 54.54147250311715, 47.82921389171055, 50.735287530081614, 40.82297352382115, 37.62396035875593, 38.98503603254046, 37.863572461264475, 38.632817949567524, 37.324260234832764, 36.914445059640066, 37.84266185760498, 36.228737762996126, 38.30952869142805, 40.77914081301008, 44.159036431993755, 44.656329427446636, 43.24341671807425, 43.33574785505022, 41.5714612688337, 41.77854537963867, 42.62765693664551, 44.471653257097515, 45.97515310559954, 44.28181110109602, 42.14064727510725, 46.7945784841265, 44.280616010938374, 41.61706577028547, 42.22542919431414, 40.961590085710796, 42.904591287885395, 43.638532979147776, 42.2570469720023, 41.44511522565569, 41.74023648670742, 41.48862484523228, 36.883393560137065, 38.07408203397478, 36.971305642809185, 35.663213457380024, 37.95692845753261, 37.89284174782889, 37.94660690852574, 37.80802856172834, 38.70345333644322, 40.80965730122158, 45.83796787261963, 51.06243303843907, 58.240280015128, 47.160230909075054, 52.86756113597325, 48.121201515197754, 48.44246537344796, 50.600169386182515, 51.05088513238089, 42.68571260997227, 35.74365970066616, 19.75138705117362, 2.0922359142984663, 0.08034254277923278, 0.03216811708573784, 0.04389137355610728, 0.09071371305201735, 0.07953634139682565, 0.12334195151925087, 0.08773845234619719, 0.05438999645411968, 0.07776260336062737, 0.04227160190099052, 0.02554721155736063, 0.010587506744611477, 0.020788776089570353, 0.04085235430725983, 0.04611066821962595, 0.06226839870214462, 0.038474723497139554, 0.04061518596219165, 0.08514114921646458, 0.06766110326030425, 0.05159861873835325, 0.036407200153917074, 0.06455742980220489, 0.11553612537682056, 0.09394222338284765, 0.07244435445006404, 0.0757881546659129, 0.09205372471894537, 0.02718953262748463, 0.05292793669338737, 0.07571545642401491, 0.09873161531452622, 0.07724278446819101, 0.05906255144093718, 2.8474271510328566, 25.23648088318961, 18.64000357900347, 7.137829261166709, 3.5046131781169345, 0.4669194338577134, 0.30635237268039156, 0.860092750617436, 1.399280343736921, 10.83917416845049, 48.93054853166853, 53.64151055472237, 10.158983741487775, 0.25968292408755844, 0.09390217624604702, 0.026368744438514113, 0.04832346930301615, 0.053761035203933716, 0.13371330499649048, 0.11622543553156511, 0.061961877292820385, 0.08339091563331229, 0.09142969641834497, 0.14606261519449099, 0.276337131857872, 5.609345427581242, 8.323055148124695, 12.30200013092586, 0.5135666536433356, 1.567036239164216, 0.4597106235367911, 1.5922832787036896, 2.6527572997978757, 14.178108419690814, 38.91661364691598, 36.953393186841694, 47.80721589497158, 5.608108648232051, 0.2578494953257697, 0.09296478690313441, 0.05531208483236177, 0.16906386667064258, 0.02795950193623347, 0.06338003583784614, 0.0483624511398375, 0.05244934558868408, 0.06272312573024205, 0.06467686553618737, 0.05189236672595143, 0.029078465553798845, 0.050281850288489034, 0.032218440635395904, 0.055472982448658774, 0.06076768280139991, 0.061828233035547395, 0.017144576546603014, 0.03902789917109268, 0.05259426709796701, 0.04800483604360904, 0.024438369985935942, 0.06372553229864154, 0.08196230764899935, 0.026758757885545492, 0.033154438981520276, 0.02626016017581735, 0.08802042435854673, 0.07239915044712168, 0.06311915947922639, 0.04822107497602701, 0.6019962142620767, 0.9982957861253193, 0.05333028081804514, 1.3313475889819009, 31.223269394465856, 52.756132875170024, 56.62344115121024, 57.26844937460763, 54.60473585128784, 55.23891530718122, 56.772813524518696, 57.09222568784441, 54.45248692376273, 55.37895972388131, 54.120884146009175, 50.03161914008004, 51.149024963378906, 43.858905519757954, 41.79737152372088, 41.96357938221523, 39.657107489449636, 40.08206278937203, 39.04022557394845, 40.37090287889753, 40.0659499168396, 38.037965297698975, 39.880860328674316, 43.505968298230854, 46.24674081802368, 45.692896434238975, 45.64383520398821, 44.917015416281565, 45.52235984802246, 44.10588618687221, 44.78720917020525, 46.62316642488752, 48.05565915788923, 47.62447132383074, 44.338557038988384, 48.17051982879639, 47.31854213987078, 43.81722675051008, 46.3236643246242, 44.23920127323696, 45.783844879695344, 44.78633369718279, 44.31991502216884, 44.51705626079014, 44.7257593018668, 43.92205074855259, 40.6878206389291, 41.095825808388845, 40.339580399649485, 38.463980197906494, 38.83922808510916, 39.553801672799246, 39.23709583282471, 40.27538251876831, 42.66380493981497, 43.29436785834176, 48.254221303122385, 51.28739833831787, 62.306157384599956, 52.7257935660226, 52.04519319534302, 49.21893004008702, 47.51433890206473, 51.9233843258449, 51.18155990328108, 40.20476450238909, 30.8345558983939, 13.088904465947833, 0.8880422051463808, 0.0936698933531131, 0.12246787627892834, 0.049117962563676495, 0.12730334752372333, 0.09175322191523654, 0.0376724033350391, 0.05935675743967295, 0.051290770793067555, 0.04328451219147869, 0.06825769839010068, 0.025967240000941923, 0.04478581163233944, 0.013751405274628528, 0.014539782390264528, 0.01300487935077399, 0.08661624363490514, 0.010888615140824445, 0.0483522120464061, 0.054985723059092245, 0.02627020249409335, 0.044192229198025804, 0.025922814616933465, 0.057137472954179556, 0.016398764780855606, 0.09654001505779368, 0.062166842365903516, 0.021769238835466758, 0.0726437351799437, 0.012152177963538893, 0.06363700383475848, 0.05761650510664497, 0.06892823348087923, 0.09135617714907442, 0.08221307383584124, 5.470679794039045, 40.49129778998238, 28.02495104925973, 11.85590146269117, 4.114126529012408, 0.6350889099495751, 0.8845550779785428, 1.0452525807278497, 5.361246100493839, 32.236389705113, 59.60274532863072, 77.85521139417375, 14.258552925927297, 0.09286097104528121, 0.04483915805550558, 0.057943640409835746, 0.06391646526753902, 0.022369128252778734, 0.08284156011151415, 0.22670849705381052, 0.22030395429049218, 0.23837084482823098, 0.290084251335689, 0.36846253701618736, 0.49445818471057074, 9.056320258549281, 10.82187489100865, 27.16679641178676, 32.49721465791975, 0.8828585775835174, 0.5011172731007848, 1.0289670888866698, 1.8915682477610452, 32.52552509307861, 59.75051266806466, 46.19798183441162, 57.5749100957598, 3.7897307702473233, 0.24643824622035027, 0.19330757004874094, 0.24866432962673052, 0.26089128639016834, 0.14307780750095844, 0.1564798376389912, 0.12800051511398383, 0.19745557675404207, 0.216766534107072, 0.16672939408038343, 0.14243735186755657, 0.10045111126133374, 0.13403342424758843, 0.2893618015306336, 0.13467976956495217, 0.17898091381149633, 0.13215253874659538, 0.14762458923671926, 0.12531267505671295, 0.1437208687088319, 0.10716041124292783, 0.16164827958813735, 0.18544097431004047, 0.1831955797970295, 0.11933555507234164, 0.1179125721433333, 0.06437611167452165, 0.18402815583561147, 0.49673116845744, 0.21402829246861593, 0.11140584200620651, 7.57064688205719, 5.119351949010577, 0.5597850392971719, 4.722568554537637, 41.11156347819737, 56.199885913303916, 60.70239503043038, 59.989370891026084, 56.5004232951573, 56.41089228221348, 58.43075098310198, 59.345668928963796, 57.646407059260774, 60.07869693211147, 56.99916499001639, 49.35433306012835, 53.81379113878523, 46.240782737731934, 43.56228692190987, 45.01511355808803, 42.91176182883126, 44.45836135319301, 42.18492814472744, 42.594048500061035, 42.989432266780305, 39.71889434541975, 43.723040444510325, 45.26364714758736, 49.28513247626168, 48.99358606338501, 47.718640259334016, 49.696781975882395, 46.59674589974539, 46.36261592592512, 46.68578706468855, 50.304454054151265, 50.29982655388968, 50.5690484046936, 47.115255219595774, 53.70722314289638, 50.366230487823486, 46.388824531010215, 46.68455375943865, 44.8192959512983, 48.66794831412179, 49.00940711157662, 46.328951903751914, 47.11235087258475, 47.26047951834542, 46.83006640842983, 40.522109576633994, 43.69127328055245, 44.30312817437308, 41.71610539300101, 40.74034207207816, 41.51033796582903, 40.64213275909424, 43.209832600184846, 44.151310035160606, 45.74495928628104, 47.633729798453196, 52.41857896532331, 62.94745526994978, 52.07757874897548, 54.697942461286274, 52.94235501970564, 51.49609790529524, 55.43101215362549, 55.30198757989066, 49.3673609324864, 45.53964696611677, 27.82405083520072, 3.3027421704360416, 0.22114220288183006, 0.15837890787848405, 0.20106946783406393, 0.1792693454772234, 0.3699851424566337, 0.1970573038394962, 0.1750905332820756, 0.1650800382984536, 0.19119264424911567, 0.0892800906939166, 0.16745864280632564, 0.1546002413545336, 0.1818989265177931, 0.10931342999850001, 0.19381249509751797, 0.29574814598475185, 0.2113361233579261, 0.14251507126859256, 0.2161713774715151, 0.11209009707506214, 0.30402532326323645, 0.09356295623417411, 0.13356923844133103, 0.23928920126387052, 0.16849202449832643, 0.15884056953447206, 0.18504990743739264, 0.23705087708575384, 0.16419201237814768, 0.18850081440593514, 0.10576004388609103, 0.16064000369182654, 0.20156877461288655, 0.13560347285653862, 5.2161833473614285, 51.245768206460134, 35.70258889879499, 32.69153840201241, 10.623906816755023, 1.9605823159217834, 0.7142715581825801, 1.953738123178482, 8.45698949268886, 51.41775001798357, 59.65857410430908, 88.33374105181012, 12.464470727103096, 0.24220606046063559, 0.3850284809512751, 0.11990028619766235, 0.18072753080299922, 0.13580203934439591, 0.28628258247460636], [0.05094257376289793, 0.06409825158438512, 0.024922788010111878, 0.12954108816172394, 0.07980128218020711, 0.09445343845124755, 4.994871062891824, 16.41208107130868, 11.253867847578865, 4.4825043848582675, 1.2133507835013526, 0.06555934782539095, 1.951238942997796, 0.1128772044820445, 13.06601275716509, 26.671598298209055, 29.98654910496303, 45.35187884739467, 12.36150450365884, 0.2183743364044598, 0.05309021852112242, 0.1117552603994097, 0.07635576277971268, 0.07771665296916451, 0.014256327778899243, 0.1125951646161931, 0.017662159666152935, 0.06263533686952931, 0.0100640398782811, 0.027196182270667384, 0.030045744364282916, 0.051152112162006755, 0.06432778641049351, 0.06089325249195099, 0.016847766669733182, 0.04948143341711589, 0.003481508685841358, 0.01994178457451718, 0.03287120150136096, 0.022976585031886185, 0.03168584832123347, 0.09767417955611433, 0.03420384427798646, 0.004042966939908053, 0.022153700169708048, 0.05133394936897925, 0.03282490505703858, 0.03582819943715419, 0.21831378393939563, 0.032878553428288014, 0.6030536975179399, 0.31743320237313, 0.02122683490493468, 0.10363886199359383, 7.209689702306475, 37.289324692317415, 46.73643248421805, 54.76198400769915, 51.1816189629691, 55.87480401992798, 53.53079795837402, 48.912486689431326, 47.545772552490234, 50.03232090813773, 50.67363963808332, 48.6768559047154, 50.7909426007952, 44.818632398332866, 38.8240601675851, 39.58295978818621, 36.2381352015904, 37.1550681250436, 38.24729715074812, 37.27521637507847, 36.87461798531668, 37.77287415095738, 37.00929839270455, 41.233841351100374, 41.98997211456299, 42.12824126652309, 41.10356610161917, 40.91517611912319, 45.791394097464426, 44.99493598937988, 44.87103223800659, 44.637885434286936, 45.87756218229021, 42.65818037305559, 41.768428802490234, 45.411991187504356, 43.573716708592, 42.742510659354075, 43.96289920806885, 43.822569915226524, 42.87170198985508, 37.96994243349348, 40.99722392218453, 39.9791009085519, 39.952471937452046, 38.97472490583147, 38.46747861589704, 35.739591530391145, 36.44426393508911, 35.387324810028076, 35.89483513150896, 37.59465980529785, 36.729685510907856, 36.51939133235386, 40.387206826891216, 43.27082388741629, 42.51197985240391, 43.95572519302368, 51.01300702776228, 52.63426147188459, 44.17339835848127, 43.12045444761004, 42.351233278002056, 48.05901861190796, 35.859687668936594, 22.296784911836895, 10.299001233918325, 1.567091173359326, 0.1831557633621352, 0.01925530730347548, 0.07981603353151254, 0.03528694901615381, 0.05549024777220828, 0.045532390142657926, 0.17016092208879335, 0.14375133493116923, 0.048874517769685814, 0.02138135259571884, 0.011187141711291457, 0.07541739634637322, 0.02242842033904578, 0.03601507476664015, 0.006269465524902833, 0.04738884838297963, 0.02386481112002262, 0.02836835151538253, 0.05840617737599781, 0.06683968912277903, 0.04400190691064511, 0.011468790571338363, 0.0800007918317403, 0.09098161224808012, 0.09172418740178857, 0.10109925469649689, 0.036520478182605336, 0.08309429404991013, 0.030753341037780046, 0.050376566991742165, 0.036898948052631955, 0.051928620851997814, 0.08180378151259252, 0.19684140756726265, 0.0554070525935718, 16.521676744733536, 45.31976774760655, 17.45179213796343, 10.849212578364781, 4.28032830783299, 0.8566682115197182, 0.6720533264534814, 2.3041581426348006, 2.3916166382176534, 10.761236224855695, 24.475670507975988, 28.94231649807521, 3.149980813264847, 2.9845685235091617, 0.4176609127649239, 0.21431268006563187, 0.06218726626996483, 0.03257651374276195, 0.0465409815577524, 0.019910940068906972, 0.08024989560778652, 0.031189133546182086, 0.06214492568480117, 0.011378981372607606, 0.09633775055408478, 5.667005487850734, 21.329857962472097, 11.292619688170296, 4.992857822350093, 3.1087137247834886, 0.36120981190885815, 6.123592896120889, 1.93146784390722, 19.51459765434265, 43.144359724862234, 35.082802636282786, 45.92981263569423, 20.206256083079747, 0.4959113895893097, 0.2124208022973367, 0.0783969114667603, 0.050557491569114585, 0.03930945727708084, 0.048411950269447904, 0.02603117665941162, 0.006249196835727031, 0.04019494547641703, 0.05373052487682019, 0.034854773099401166, 0.029490743431129625, 0.0042117190231303015, 0.05544212267601064, 0.04573583868997438, 0.05482969053887895, 0.017386911935838203, 0.08578000350722245, 0.04854278539174369, 0.027004609782514826, 0.043816714348005395, 0.04013520386070013, 0.05248801190672176, 0.14933923365814344, 0.05736100274537291, 0.03485709708184004, 0.05201233510992356, 0.046215834362166267, 0.06576150376349688, 0.18350655239607605, 0.05768950868930135, 0.45789670944213867, 0.201860639665808, 0.061292916403285096, 0.03042756619730166, 4.144257826464517, 32.1070350919451, 42.94158002308437, 50.56041874204363, 48.68151119777134, 52.53681993484497, 49.91643190383911, 47.06949438367571, 48.1849547113691, 49.9733168057033, 51.10587665012905, 48.73180225917271, 50.091488293239046, 48.331808362688335, 41.65860210146223, 43.386421067374094, 40.61642789840698, 39.82911014556885, 40.54965918404715, 40.77082034519741, 41.176904337746755, 40.65052965709141, 38.271494252341135, 42.30967262813023, 43.50967863627842, 43.56199509756905, 44.79820816857474, 44.3739789554051, 47.73414169039045, 46.2089078766959, 48.12809412819998, 47.48286356244768, 47.49569341114589, 45.143641335623606, 45.1717745917184, 46.934824398585725, 45.13740880148751, 44.678709575108115, 46.010634081704275, 45.387269496917725, 44.83900451660156, 42.42088202067784, 42.263852732522146, 42.817860398973735, 41.897741726466585, 42.13597808565412, 39.60214376449585, 37.14363833836147, 39.20554058892386, 38.64670392445156, 39.239948068346294, 38.5354528427124, 39.664472579956055, 40.10927193505423, 43.63321760722569, 44.685518809727256, 43.739024775368826, 44.33811930247715, 46.94366945539202, 51.328774860927034, 44.66651896068028, 41.38851867403303, 40.73642676217215, 39.92745842252459, 20.73485939843314, 12.157480205808367, 5.2541157347815375, 1.471127214176314, 0.46142856563840595, 0.30053873892341343, 0.08091782512409346, 0.09321859971221004, 0.013734612381085753, 0.028319815905498605, 0.16833307088485785, 0.02850292536563107, 0.022146008975271667, 0.07620492444506713, 0.0660975007340312, 0.09708464119051184, 0.0670811322384647, 0.0672931337196912, 0.06280746763306004, 0.037111407544996054, 0.01813713417920683, 0.029361703033958162, 0.027829879695283513, 0.0159471641028566, 0.05834780300834349, 0.025177036777936986, 0.06473944003560714, 0.08564916838492666, 0.026751711299376826, 0.06399907690605947, 0.021662976858871322, 0.134445512135114, 0.0761252644338778, 0.054111183022281954, 0.07203528604337148, 0.05168422610898103, 0.03440554899030498, 0.11322550329246692, 0.06487701979598828, 25.59558810506548, 57.03077581950596, 26.524713379996165, 15.12554567200797, 6.021408779280526, 0.9045247978397778, 1.3503372328622, 2.6041077503136227, 4.209691618170057, 13.953391517911639, 38.662597928728374, 41.367823464529856, 4.811119002955301, 4.601062800203051, 0.4102617869419711, 0.13085199067635195, 0.056005774930651696, 0.04394961560943297, 0.028760795814118216, 0.07163640244730882, 0.1484986509063414, 0.10137056692370347, 0.14850998244115285, 0.20182767643460206, 0.19931096290903433, 8.704008374895368, 31.622155053274973, 27.605175631386892, 29.45956298283168, 2.349254991327013, 0.1799085254647902, 5.393135726451874, 0.8202783241868019, 33.590538024902344, 61.62788118634905, 41.63060433523995, 62.567117827279226, 21.25116613933018, 0.5123146751097271, 0.3317078963986465, 0.17507897104535783, 0.3556202846978392, 0.18688276622976574, 0.10485330396997077, 0.21748360991477966, 0.07020982328270163, 0.14992383228881018, 0.2202015904975789, 0.1599071723009859, 0.16422550486666815, 0.10717385980699744, 0.15729606098362378, 0.16725205603454793, 0.2511719236416476, 0.1812432309878724, 0.2327951325901917, 0.1595041360706091, 0.07906269681240831, 0.15197855846158095, 0.16611978464892932, 0.1536852911646877, 0.29254358794007984, 0.12275466588991028, 0.255359380372933, 0.18831554720444338, 0.3242081845445292, 0.13110999683184282, 0.42142754207764355, 0.2238812723330089, 1.3469961264303751, 0.2886241525411606, 0.12096892456923213, 0.1857393125870398, 13.017605526106697, 43.44698851449149, 51.47674022402082, 61.20123400006975, 52.79820074353899, 56.83414874758039, 51.242502553122385, 49.47654492514474, 48.47862032481602, 51.354570048195974, 52.140248026166645, 50.62640578406197, 48.842591285705566, 49.88099261692592, 43.436552320207866, 46.085994243621826, 41.48786401748657, 42.14089741025652, 44.43528985977173, 42.48259939466204, 43.14035756247384, 41.92733757836478, 39.818475927625386, 44.21911055701119, 47.96041325160435, 45.90937450953892, 46.313679763248985, 44.92020811353411, 51.54532241821289, 49.82543134689331, 50.92591135842459, 51.37780829838344, 51.14866713115147, 48.54315519332886, 46.393851552690776, 51.5373979977199, 50.18208238056728, 48.177523612976074, 48.0695937701634, 47.842679500579834, 47.62392241614205, 44.214646339416504, 45.363694259098594, 45.77735178811209, 44.092219080243794, 43.79288373674665, 43.16673639842442, 40.528258732386995, 41.17560849870954, 41.49159172603062, 40.68626076834542, 41.38125433240618, 43.65090077263968, 42.951057365962434, 44.72328574316842, 46.98109245300293, 44.03458377293178, 44.515096868787495, 49.08015019553048, 57.423237868717735, 47.791940280369346, 44.53535781587873, 45.8213095664978, 54.87814746584211, 43.99589272907802, 26.196402311325073, 16.521478721073695, 4.079744236809867, 0.3961273053927081, 0.23695504079971993, 0.10509427211114339, 0.14953993074595928, 0.11171899948801313, 0.18301451951265335, 0.26462146480168613, 0.2087147661617824, 0.121349623426795, 0.2384999564715794, 0.17099846500371182, 0.17606644305799687, 0.09015009472412722, 0.14148003395114625, 0.18660695531538554, 0.23246566312653677, 0.13609668639089378, 0.1082285474985838, 0.13423831468181951, 0.11131081996219498, 0.14614182737256798, 0.10509630093084914, 0.1244212021785123, 0.12599358494792665, 0.160453325137496, 0.11666209995746613, 0.19738711257066044, 0.2532697096467018, 0.2095515898295811, 0.05574212675648076, 0.20993142016232014, 0.21713473434959138, 0.11322435656828539, 0.16201098369700567, 0.09242580618177142, 23.901921272277832, 71.61094869886125, 35.97330461229597, 38.658064229147776, 13.585028426987783, 2.6761160578046526, 1.4420700648001261, 3.8464871304375783, 6.158710828849247, 40.78664834158761, 47.487442425319124, 53.65606008257185, 13.280073727880206, 4.47588448865073, 0.3055121291960989, 0.23172928978289875, 0.16695613334221499, 0.1310799920133182, 0.14325903063373907], [0.06836831316884075, 0.057216006597237926, 0.04856685981420534, 0.0770180808114154, 0.20983984507620335, 0.27222216980797903, 3.453897842339107, 25.56149503162929, 11.988719752856664, 6.701824154172625, 2.4453507491520474, 2.0475733280181885, 2.3694790261132375, 0.14838209216083798, 2.498979551451547, 19.197051082338604, 25.12258427483695, 37.66407925742013, 22.959495408194407, 0.06557074721370425, 0.0729584600776434, 0.06645782997033425, 0.06037145906261035, 0.022641755141583935, 0.08307235022740704, 0.03210930506299649, 0.022825302256803428, 0.02758179372176528, 0.026468908081629446, 0.004903164866846055, 0.05188772215374878, 0.02555601385289005, 0.05491960999955024, 0.018088143950860416, 0.053297721315175295, 0.026889243562306677, 0.03695553108783705, 0.05816976899015052, 0.0384591884378876, 0.06129007334155696, 0.02547559218614229, 0.062164345357034884, 0.08428687362798623, 0.05027602167267885, 0.031111217369990687, 0.05591461035822119, 0.05381090413512928, 0.06660424425665822, 0.0397000593532409, 0.10015366186520883, 0.17806194669434003, 0.15702307277492114, 0.018941958135526096, 0.01634552183427981, 0.20051851096962178, 5.092812870229993, 22.06200701849801, 33.139242104121614, 44.01234258924212, 43.13632413319179, 44.844959122794016, 50.119468688964844, 48.465873854500906, 48.81405503409249, 49.675506591796875, 44.14035620008196, 49.06494753701346, 42.80790363039289, 41.552284240722656, 40.1787782396589, 37.75517014094761, 38.62292718887329, 38.33372579302107, 36.2121593611581, 37.027971676417756, 38.47535787309919, 40.52585118157523, 41.249391419546946, 41.58589962550572, 41.671459742954795, 42.90864903586251, 40.669310637882774, 41.28831870215279, 39.33103200367519, 43.659662451062886, 42.11911480767386, 43.31329822540283, 39.95824589048113, 40.44221918923514, 43.78607102802822, 41.29174068995884, 42.13789578846523, 42.882562024252756, 41.37860359464373, 43.15412541798183, 43.6704078401838, 39.868568965366904, 41.036613259996685, 40.622528416769846, 40.21583298274449, 35.27256488800049, 37.007596084049766, 37.294247491019114, 37.10646547589983, 35.76050908224923, 35.02922855104719, 37.83135366439819, 38.96091536113194, 41.83456175667899, 42.27063764844622, 42.09770393371582, 43.59909847804478, 39.91235303878784, 40.09567778451102, 40.444043091365266, 34.886033126286094, 30.03947353363037, 10.12348278931209, 2.2589857322829108, 2.472960936171668, 1.4437618425914218, 0.7325186676212719, 2.3095295344080244, 1.5275096744298935, 0.8678000399044582, 0.06323891412466764, 0.04100286355242133, 0.29543916827866007, 0.6976457674588475, 0.19737316189067705, 0.27452435770205086, 0.13065714256039687, 0.2659955524972507, 0.11834991510425295, 0.0926895798849208, 0.009276246302761137, 0.1098469417276127, 0.014571395336783357, 0.057539837434887886, 0.04351734130510262, 0.05859544114874942, 0.041406188160181046, 0.06747971727911915, 0.04817453765177301, 0.056368794558303695, 0.03061593769650374, 0.07449574901589326, 0.06704931573144027, 0.04106448131746479, 0.12599975961659635, 0.02956737717613578, 0.033655160505856783, 0.009531394129485955, 0.12616296085928166, 0.039069981912949255, 0.06558734418026038, 0.1779861950448581, 42.390309946877615, 39.54503304617745, 23.07474344117301, 13.210138372012548, 5.891987723963601, 1.4138120668275016, 1.3584882297686167, 1.3703806144850594, 2.209962282861982, 8.675130793026515, 16.10284628186907, 4.569136696202414, 30.449375561305455, 51.49816152027675, 5.271863171032496, 0.3122262603470257, 0.03922386008447834, 0.03040663678465145, 0.10350196076823132, 0.050597226579806635, 0.016660531716687337, 0.04883064030270491, 0.0878043652379087, 0.08288886078766414, 0.19039790332317352, 5.290810474327632, 30.62838547570365, 23.055390971047537, 5.646622513021741, 4.344964793750218, 2.560098946094513, 3.557211692844118, 1.6137341048036302, 11.556766748428345, 29.699678829738072, 32.71891777856009, 42.47778081893921, 35.16600036621094, 0.6345876082777977, 0.16136503192995275, 0.015624150899904115, 0.08494098817131349, 0.036271761171519756, 0.14509716842855724, 0.03871069422789982, 0.05215417267754674, 0.01798191081200327, 0.06756581658763544, 0.027409014957291738, 0.0995342204613345, 0.015161834457623107, 0.12361645964639527, 0.015670637334031717, 0.03245246057797756, 0.038475381676107645, 0.040702184329607656, 0.07537384796887636, 0.02089746213251991, 0.052387015361871035, 0.018290455952020626, 0.04510720992194755, 0.040372535054172785, 0.024585618870332837, 0.033642553325210295, 0.017315095789464455, 0.04346325867144125, 0.07930201611348561, 0.034233957662114074, 0.04802417768431561, 0.10881750232407025, 0.04815936560875603, 0.05876135653150933, 0.08567246927746705, 0.12184343407196657, 3.425165738378252, 16.341987643923076, 27.79824522563389, 39.271736076899934, 39.67301191602434, 43.285508905138286, 48.67981583731515, 46.51997525351388, 48.10029785973685, 46.28828757149832, 46.51632397515433, 48.68734768458775, 42.269407817295615, 43.61572551727295, 41.28673103877476, 40.486687660217285, 41.509514604296, 39.954983711242676, 37.5302152633667, 38.66535288946969, 41.375317096710205, 43.129886627197266, 44.90466151918684, 44.65000656672886, 43.51313189097813, 45.694022042410715, 43.401342323848176, 43.78336817877633, 43.345294679914204, 46.882275172642295, 45.35521745681763, 45.68361016682216, 43.43482221875872, 43.92760583332607, 48.37585299355643, 43.59395333698818, 45.7657413482666, 45.04161746161324, 44.960559776851106, 44.74545397077288, 44.28462859562465, 42.891306332179475, 42.93435042245047, 44.12147447041103, 41.89410434450422, 37.31842027391706, 40.40387555531093, 40.100836821964805, 39.646181447165354, 39.95101628984724, 38.99966893877302, 40.12631586619786, 41.87374612263271, 47.027350085122244, 46.40293632234846, 45.6306266784668, 47.04507146562849, 40.70008420944214, 39.69895648956299, 38.530061040605815, 34.99608564376831, 26.96795286451067, 3.8159380725451877, 5.455595689160483, 3.9483989647456577, 1.954414269753865, 1.2526641253914153, 1.9426375074045998, 2.0090648915086473, 0.9536348283290863, 0.1588953137397766, 0.12576737494340964, 0.30829189717769623, 1.3531596128429686, 0.8159620815089771, 0.31392015516757965, 0.17349223047494888, 0.3386020836021219, 0.10322132546986852, 0.056573644280433655, 0.006546362519397267, 0.06701163668185472, 0.0307216364890337, 0.021791415056213737, 0.045157991482743194, 0.06366814859211445, 0.03747361293062568, 0.03479882449443851, 0.024507195489214997, 0.03628177295571991, 0.05170695703210575, 0.04313060687854886, 0.0452851014477866, 0.04061662445643118, 0.05775701613830669, 0.031760982503848414, 0.03367921796494296, 0.025621816482661024, 0.053512090883616886, 0.019576435875413672, 0.08308345784566232, 0.8440583710159574, 54.80991962977818, 45.2657732963562, 28.778502293995448, 24.1299090385437, 7.167663957391467, 2.2150451072624753, 4.109733530453273, 2.37081156032426, 4.535801844937461, 14.064948320388794, 29.311614990234375, 4.737853288650513, 47.995678833552766, 72.56055205208915, 6.779554086072104, 0.20729286888880388, 0.07533707137086562, 0.04783658989306007, 0.0358087661942201, 0.13958255148359708, 0.13737903615193708, 0.15837512165308, 0.2648506467895848, 0.33836440635578974, 0.281104817454304, 5.30980771780014, 49.65594046456473, 42.109488078526084, 26.970822470528738, 2.3987491812024797, 5.694711863994598, 3.268109743084226, 2.626789058957781, 23.937487363815308, 57.14947884423392, 39.76287644250052, 50.04975741250174, 45.02214166096279, 0.381276752267565, 0.13974742192242826, 0.17296888998576573, 0.20419855921396188, 0.1454745288938284, 0.2607908089246069, 0.09024269439812217, 0.10004035330244473, 0.0809068057153906, 0.16096727470202105, 0.1306700754378523, 0.16734382111046994, 0.1021898640319705, 0.226231134097491, 0.1303727278219802, 0.13876142911612988, 0.09513660786407334, 0.14158777174140724, 0.23937190111194337, 0.1434793916663953, 0.10382140826966081, 0.11207387330276625, 0.11231326045734541, 0.1518484154450042, 0.0931914040286626, 0.09663622453808784, 0.2141578383743763, 0.176060553374035, 0.20650700320090565, 0.11406020314565726, 0.2780106434864657, 0.2420790929879461, 0.39790460573775427, 0.14925262544836315, 0.36084340299878803, 0.8549275249242783, 16.064740623746598, 26.74390820094517, 36.92454079219273, 46.49163702556065, 45.3048916544233, 50.42256300789969, 51.07504401888166, 49.4482171194894, 49.819494111197336, 49.796707493918284, 49.18087475640433, 53.882210050310405, 44.18996286392212, 47.11900724683489, 42.89845255443028, 42.46195977074759, 44.07444558824812, 44.51510729108538, 38.75487000601632, 40.794433798108784, 42.734930174691335, 45.8732716696603, 44.72295222963606, 46.89561571393694, 45.705931254795615, 48.23629147665841, 46.68291398457119, 46.13884571620396, 44.73721688134329, 49.66593197413853, 48.70101131711687, 49.74254976000105, 45.44552666800362, 46.27004855019705, 50.0052924156189, 47.53727143151419, 49.64618519374302, 47.59064401899065, 47.0312237058367, 49.17409678867885, 47.98502377101353, 44.887423038482666, 44.46870027269636, 45.046217169080464, 45.16793918609619, 39.301981585366384, 43.5498948097229, 41.69760928835188, 41.62152303968157, 42.88888488497053, 40.5271053314209, 42.5563371522086, 43.5272193636213, 47.31066288266863, 46.11286640167236, 44.2038905279977, 45.67217690604073, 42.46250173023769, 39.92700331551688, 40.83549765178135, 37.748055185590474, 36.08247818265642, 23.49970916339329, 7.536712748663766, 6.3165096299988885, 2.076627871819905, 0.9239958758865083, 2.223067888191768, 1.7336900851556232, 0.9166076609066555, 0.24429176854235785, 0.2751659261328833, 0.351224816271237, 2.1744176873138974, 1.0131780675479343, 0.4567550335611616, 0.2641001599175589, 0.5019222870469093, 0.18933244049549103, 0.17913637975496904, 0.09398746809789113, 0.17301661813897745, 0.05188240243920258, 0.1598194105816739, 0.12081292936844484, 0.22935159451195172, 0.19497204359088624, 0.12376148972128119, 0.13934072160295077, 0.23024929634162358, 0.18384678342512675, 0.17803202330001763, 0.20917546429804393, 0.11534059872584683, 0.16262828771557125, 0.11554350783782345, 0.08144747598895005, 0.10263639435704265, 0.20101369225553103, 0.11559129027383667, 0.16130879494760716, 1.0229335555008479, 56.90744529451643, 58.2058482170105, 43.07844911302839, 38.39828150612967, 17.96053750174386, 6.446322824273791, 4.257613343851907, 3.079833537340164, 4.560330288750785, 27.53701901435852, 34.39929791859218, 15.106992244720459, 66.58921459742955, 79.31477778298515, 5.873615384101868, 0.4689334886414664, 0.12780059155608925, 0.08788491412997246, 0.22543883589761599], [0.04204777694706406, 0.03620234364643693, 0.05252141957836492, 1.205037263887269, 2.43598045195852, 0.3738764322229794, 4.302694993359702, 23.812114068440028, 9.996766754559108, 4.698360162121909, 0.5193048343062401, 2.1318515028272356, 2.338140044893537, 1.2992735100643975, 1.9367997178009577, 20.309200593403407, 28.912969044276647, 33.861086981637136, 34.68646696635655, 2.405794871704919, 0.09587458255035536, 0.09567379725298711, 0.10670957222048726, 0.04229487565213016, 0.06534020137041807, 0.02205162475417767, 0.05226826834093247, 0.01907264567645533, 0.04657323232718876, 0.09194180036761931, 0.07935874164104462, 0.026548953161441853, 0.0607983118721417, 0.05920397170952388, 0.04470288786771042, 0.0564889291833554, 0.05031057267582842, 0.04678904378254499, 0.04036608897149563, 0.02594220036241625, 0.07487029356083699, 0.00845130717581404, 0.022466959431767464, 0.09488017590982573, 0.010786761945512677, 0.06374469412756817, 0.12717190171991075, 0.21552778700632708, 0.1337771958538464, 0.04783784857551966, 0.12334773263760976, 0.005590193447590406, 0.0412660944275558, 0.10367144524518933, 0.23209879281265394, 0.8536042187895093, 2.5994068597044264, 3.9341794763292586, 18.01612482752119, 25.47504207066127, 21.69210229601179, 31.627241134643555, 45.302623067583355, 44.06584371839251, 44.65551996231079, 43.813130787440706, 40.61661202566964, 41.022070680345806, 40.32675749914986, 40.3951347214835, 37.352918079921174, 38.14075347355434, 36.64428172792707, 37.039641175951274, 37.25987475258963, 38.20154673712594, 40.87767321722848, 43.795388562338694, 43.80449070249285, 42.13180916649954, 43.529335090092246, 40.88530233928135, 40.19677059991019, 39.4913512638637, 42.35723999568394, 40.953735147203716, 42.8088972227914, 41.83331455503191, 41.757728576660156, 43.248773779187886, 42.32609816959926, 43.67134237289429, 41.987363065992085, 39.59369822910854, 41.012388365609304, 42.05274561473301, 41.04091419492449, 39.85838638033186, 44.272486618586946, 37.92693655831473, 36.82695681708199, 37.78234107153756, 35.0484368460519, 37.589594568525044, 37.71128879274641, 38.38654599870954, 34.51206023352486, 41.58347470419747, 48.20306519099644, 49.96835926600865, 50.346525396619526, 45.15411574499947, 36.74010780879429, 36.56268208367484, 32.455674852643696, 27.56668782234192, 4.997616904122489, 3.715993446963174, 3.1170637224401747, 3.237298824957439, 2.374078950711659, 2.5080124267510007, 2.780758099896567, 3.689973746027265, 2.4350344112941196, 1.043347037264279, 0.0851379736725773, 0.22218774392136506, 0.19448176132781164, 17.296930687768118, 2.458643304450171, 0.7956800184079579, 0.372098833322525, 0.03473095742187329, 0.06563273817300797, 0.02323616878129542, 0.15505711255328997, 0.04710537680823888, 0.16838778794876166, 0.062410938553512096, 0.06732921142663274, 0.028055290724816065, 0.024374531715043952, 0.07166906033775636, 0.055327423116458316, 0.1577551034944398, 0.015475626369672162, 0.09159127596233572, 0.06950391616140093, 0.0758987490886024, 0.07925277482718229, 0.0757053191108363, 0.08426076360046864, 0.055103421743427, 0.01708882810947086, 0.028404855003048266, 2.661757171154022, 58.219386781964985, 29.15032993044172, 21.293680429458618, 15.011134896959577, 10.631792153630938, 5.737834990024567, 1.414236558335168, 0.022184978937730193, 0.8601981678179332, 1.1327941289969852, 0.7795717056308473, 3.836721871580396, 44.822043963841026, 65.7883721760341, 11.791807804788862, 0.08085242113364594, 0.15030890091189317, 0.04466660999293838, 0.024651431678129093, 0.04856971644663385, 0.10550836846232414, 0.015655880893713663, 2.485362167869295, 4.387321446623121, 0.27385027387312477, 3.4635723403521945, 32.761774267469136, 24.355883564267838, 4.187960258552006, 1.3010344441447939, 1.170109212398529, 2.8978656445230757, 4.353373416832515, 1.8426592264856612, 35.5095887865339, 41.022473675864084, 32.75267212731497, 47.34909684317452, 7.880894371441432, 0.2691724534545626, 0.11075980881495134, 0.11837773504001753, 0.03901218090738569, 0.10311455798468419, 0.035676367048706324, 0.10641079289572579, 0.020571042683773806, 0.026743517989026647, 0.11668403020926885, 0.08059046590434653, 0.0832175092239465, 0.02672309578130288, 0.0481526040072952, 0.08467893116176128, 0.018415893328243067, 0.032635325765503306, 0.05005498889035412, 0.06784869783690997, 0.05615915098626699, 0.017033322248607874, 0.04317950550466776, 0.09620432342801775, 0.0549463883840612, 0.041323403495230844, 0.01653137257588761, 0.07810175551899842, 0.15822321123310498, 0.07974678224750928, 0.13788257698927606, 0.1492968387901783, 0.040039985041533194, 0.03167467624215143, 0.09270546438970736, 0.16124586760997772, 1.1660029355968748, 3.43872623358454, 3.517823440687997, 13.489893691880361, 23.213153294154576, 21.007011651992798, 29.39163739340646, 43.55935825620379, 43.5387464250837, 44.26965175356184, 43.23042011260986, 43.384715284620015, 43.055460997990195, 43.264466285705566, 41.60601813452584, 40.16850880214146, 40.091929231371196, 38.74578176225935, 39.074594838278635, 38.36873776572091, 41.457003593444824, 43.29291915893555, 45.06517880303519, 43.84580816541399, 45.17378609521048, 44.04782356534685, 44.03077963420323, 43.37284081322806, 44.40993588311331, 46.22395767484392, 43.49516384942191, 45.57293231146676, 45.216878822871614, 46.36134787968227, 45.463244574410574, 44.24349873406546, 46.123594420296804, 45.61764396939959, 43.35944468634469, 43.53863525390625, 44.306143692561555, 40.49738788604736, 42.25938504082816, 45.06572423662458, 39.8635002544948, 39.198418685368125, 38.61121947424752, 38.117261614118306, 40.616368838718955, 39.91742869785854, 40.54667840685163, 38.31539991923741, 45.239630699157715, 51.528337546757285, 52.0156181880406, 54.0613693509783, 47.08124726159232, 38.316094739096506, 35.35068695885794, 31.122006348201207, 26.93166068622044, 7.522739921297346, 5.0840590085302075, 4.193341638360705, 3.400229739291327, 3.4013892199311937, 3.1734472683497836, 4.151511745793479, 4.15193384885788, 3.031568310090474, 1.4053936728409357, 0.025933628768793175, 0.1268583642584937, 1.2927478488002504, 25.257975135530742, 7.639691131455558, 1.018523512142045, 0.392858232238463, 0.04591776749917439, 0.035720780558351956, 0.011144012329168618, 0.1835758036800793, 0.08582777915788548, 0.0499362690108163, 0.08411406432943684, 0.07032653809125934, 0.05936263355293444, 0.04695153256346073, 0.06739071384072304, 0.1087637080677918, 0.2537121687616621, 0.06662763335875102, 0.025052316952496767, 0.05258203650425587, 0.12445297118808542, 0.10409067810646125, 0.0687652425840497, 0.03832494706979819, 0.1225922517478466, 0.04834177278514419, 0.1675182453223637, 7.0997031927108765, 71.30031558445522, 31.003452709742955, 27.81359553337097, 28.722174985068186, 13.468647837638855, 2.4009906266416823, 3.3620348402432034, 0.1864982404346977, 0.7510974449770791, 3.180065861770085, 2.9810523007597243, 15.645210129874092, 59.02782358442034, 81.25370039258684, 12.286071385656085, 0.0385179733192282, 0.0717402318758624, 0.10331781993487052, 0.08163358457386494, 0.09223025917474713, 0.22164710078920635, 0.12490955740213394, 4.522671052387782, 4.370369144848414, 0.4527211971580982, 4.909687885216304, 44.69228288105556, 42.1691244670323, 20.309132848467144, 0.3831346354314259, 8.331911495753697, 1.6128988010542733, 4.18737096445901, 14.438932503972735, 62.551887375967844, 49.18857683454241, 42.020408698490684, 64.24945041111538, 7.538088491984776, 0.25376248891864506, 0.18077418687088148, 0.18237345319773468, 0.11615994333156518, 0.16729336524648325, 0.11234304814466409, 0.22003726288676262, 0.07724919662411724, 0.14536174280302866, 0.18718092808766024, 0.24290109745093755, 0.2018591333180666, 0.09826547532741513, 0.15645911517952169, 0.15614294500223228, 0.14832878644977296, 0.09728776064834424, 0.21906410796301706, 0.13354329126221792, 0.15349912829697132, 0.22872006839939527, 0.11604562375162329, 0.17687493110341684, 0.24867515904562815, 0.11750906093844346, 0.16730312258005142, 0.19460169917770795, 0.2844089301569121, 0.1425745923604284, 0.16946152890367167, 0.23560983155454907, 0.17756060431046145, 0.15531552582979202, 0.22366160340607166, 0.373040531362806, 1.8050679521901267, 6.505503671509879, 8.66389468738011, 24.358148677008494, 26.861654111317225, 27.021492208753312, 41.87516702924456, 48.920633452279226, 45.998766558510916, 45.73637131282261, 44.017056941986084, 45.27028962544033, 44.31853927884783, 44.402873039245605, 45.61898149762835, 42.22483859743391, 41.85330104827881, 40.81535829816546, 40.1562556539263, 40.60531772886004, 42.385567801339285, 45.03623260770525, 47.57687268938337, 48.29067850112915, 46.61853892462594, 49.15213005883353, 47.86898538044521, 45.166542598179404, 46.59898669379098, 49.97634622028896, 45.52744592939104, 49.164786202566965, 48.70021227427891, 48.58524738039289, 48.39004121507917, 47.595712729862754, 50.55680915287563, 48.698836530957905, 45.08079835346767, 45.33957011359078, 46.512231486184255, 45.03186566489083, 44.383852345602854, 47.712980951581685, 41.344943046569824, 39.207027503422324, 40.964213030678884, 39.16502564293997, 42.766117164066856, 43.206830978393555, 43.793682779584614, 38.79726791381836, 47.581197943006245, 50.600742612566265, 49.91581351416451, 51.12402187074934, 46.77901104518345, 37.24577338354928, 37.17998089109148, 32.643925871167866, 36.28458390917097, 23.01589219910758, 6.6501030666487555, 5.648006941590991, 3.300702222755977, 2.9741225583212714, 3.0951679944992065, 3.9984733292034695, 4.066008950982775, 2.931788921356201, 1.3060483293873923, 0.19780160247215203, 0.35509830127869335, 2.227354709591184, 25.478967802865164, 9.645000304494586, 1.6117295495101382, 0.45843649762017386, 0.12190686352550983, 0.2870415917464665, 0.10390127862670592, 0.36279305123857086, 0.2548585943877697, 0.26614029758742874, 0.23279168563229696, 0.2595367133617401, 0.1317071755017553, 0.16669986423637184, 0.11385775543749332, 0.12518633183624062, 0.30779892791594776, 0.12098618650010654, 0.17532852265451634, 0.1356876247695514, 0.16099945083260536, 0.17701920121908188, 0.16000516632837908, 0.16933887691370078, 0.1913468481174537, 0.13825947605073452, 0.19920748631869042, 6.505026851381574, 84.11945710863385, 40.84036486489432, 43.16266475405012, 36.23819426127842, 28.4639538696834, 19.444045645850046, 4.474937796592712, 0.6634238266519138, 2.0636536308697293, 6.246773600578308, 0.6853208573801177, 30.460635117122106, 65.33798994336809, 83.10629858289445, 16.687384332929337, 0.23096696926014765, 0.40491001840148655, 0.2178098088396447, 0.19123787539345877], [0.08108794063861881, 0.02741971884721092, 0.4501000978052616, 10.842404212270464, 55.954763889312744, 16.947623900004796, 1.8374669679573603, 13.950562732560293, 2.672004895550864, 3.677662406648908, 2.951934354645865, 3.022382140159607, 0.981097148997443, 2.808614079441343, 3.989998698234558, 9.620082327297755, 29.30843618937901, 27.876070261001587, 28.372817822865077, 11.056512951850891, 0.19312376848288945, 0.1867894133819001, 0.06673155099685703, 0.14747352020016738, 0.0583262595215014, 0.016684928443282843, 0.09066488567207541, 0.045911548725728474, 0.09502466315669672, 0.07012316079011985, 0.026734121975355914, 0.04603056376799941, 0.01368132108888988, 0.03720761702529021, 0.05440243400101151, 0.07325652015528508, 0.022572254495961324, 0.12875667453876563, 0.06475900898554496, 0.05904037691652775, 0.01586354653617101, 0.12045022525957652, 0.036067695157336335, 0.05392430090744581, 0.06815751947994743, 0.06360687009458031, 0.04133671635229673, 1.2045128920248576, 1.6871676615306308, 0.02894776953118188, 0.018010276968457868, 0.0265216183782156, 0.1071537412436945, 0.3674177016530718, 0.5607396023614066, 0.8347272117223058, 1.432037625994001, 1.207008815237454, 0.9020914626973016, 8.943867138453893, 15.431150027683803, 11.397745064326696, 24.39123773574829, 41.964698042188374, 42.92139550617763, 42.70263842173985, 42.85956001281738, 41.39203098842076, 41.24966587339129, 40.61715398515974, 38.42088399614607, 38.18729598181588, 37.789817333221436, 35.351023946489605, 36.63966812406267, 38.790642806461875, 41.73107876096453, 42.37323822293963, 41.50702714920044, 43.78568887710571, 41.10828045436314, 38.7262920652117, 39.6927239554269, 39.45252125603812, 39.55944013595581, 41.522063050951274, 43.27330786841256, 42.40268121446882, 42.084561416081016, 43.38682058879307, 41.318592003413606, 41.03285081045968, 40.56974295207432, 38.89245128631592, 40.518329756600515, 42.10240091596331, 40.30408552714756, 40.968475750514436, 42.63410833903721, 39.51491607938494, 40.39337682723999, 38.37363971982683, 37.765144280024934, 38.502080644880024, 35.8808970451355, 33.08592510223389, 38.796062401362825, 44.35226583480835, 53.54125152315412, 55.64098671504429, 51.221612794058665, 47.30743197032383, 37.95043189185006, 31.163594790867396, 27.672963993889944, 10.162460446357727, 5.216961111341204, 3.4008209875651767, 2.929096060139792, 5.034121870994568, 5.918584993907383, 6.970223077705928, 8.495447771889822, 6.7539200101579935, 4.233492238180978, 1.5688711064202445, 0.30029674619436264, 0.04338656385828342, 0.2587702673460756, 1.9248957165649958, 3.222797065973282, 0.12584233949226992, 0.12734169832297734, 0.1257714190121208, 0.02310659403779677, 0.05648878329832639, 0.10628662098731313, 0.1447939718408244, 0.04427641164511442, 0.0626478490552732, 0.11792534217238426, 0.0172693133354187, 0.011531588987314274, 0.04527773595015917, 0.09916374712650265, 0.12656976974436215, 0.38604191371372765, 0.02916028330634747, 0.23657837244016783, 0.11743451708129474, 0.11337704730353185, 0.03174755090315427, 0.04655521043709346, 0.03769197567765202, 0.07916851434856653, 0.2493351022047656, 15.628148828233991, 53.35137810025896, 22.205716609954834, 30.819203853607178, 17.850867135184153, 15.23578405380249, 13.36033410685403, 8.417843341827393, 0.5971935976828847, 0.16493613459169865, 0.3257848285138607, 5.028751347746168, 26.431868076324463, 41.877953256879536, 41.72465167726789, 6.254370152950287, 0.07796154304274491, 0.0442142205179802, 0.03536356919045959, 0.08562897518277168, 0.04653670678713492, 0.027425316761114767, 0.2803898315344538, 17.82856341770717, 73.46883446829659, 22.07159205845424, 2.685319163969585, 21.257676601409912, 20.250920840672084, 0.6866264673216003, 9.073781950133187, 2.8062256361757005, 1.8972497028963906, 7.556864261627197, 6.698465134416308, 24.14660903385707, 46.55081135886056, 27.10607784135001, 33.660759993961875, 35.18989174706595, 0.3016505864049707, 0.1712857431599072, 0.0766056129442794, 0.1416550688445568, 0.052581089947904856, 0.03692114971844213, 0.03131721381630216, 0.08495822974613734, 0.059440902567335537, 0.061221955211034844, 0.03272490256599017, 0.0030540102078313275, 0.020712006637560468, 0.06492393370717764, 0.048633692120867114, 0.030420801203165735, 0.027657659025862813, 0.04100811541346567, 0.032778700214943716, 0.05340771523437329, 0.07558592408895493, 0.02479122855168368, 0.031170097246233906, 0.06502776313573122, 0.09854679594614676, 0.09253660416496651, 0.24414069950580597, 1.118707524878638, 2.581205836364201, 0.03214557615241834, 0.2741743421980313, 0.007875078274602336, 0.15477934745805605, 0.6833556571177074, 0.6788587612765176, 0.9292425257819039, 1.4147862259830748, 1.3989567096744264, 1.008285558649472, 6.410562183175768, 13.014888780457632, 12.506196396691458, 26.878150871821813, 40.362690108163015, 42.445054803575786, 43.89238888876778, 43.22514990397862, 40.782170227595735, 43.59687852859497, 44.59049871989659, 40.44136108670916, 40.71405356270926, 38.977264472416465, 37.20008897781372, 38.57058640888759, 41.16762154442923, 41.7065099307469, 45.56355224336897, 44.707839897700715, 45.64336620058332, 42.29415035247803, 41.220862116132466, 42.89763961519514, 42.22345243181501, 43.10314301082066, 46.88575969423567, 46.522386278424946, 46.526878288814, 46.09313351767403, 47.0099378994533, 43.86433901105608, 43.535456453050884, 43.352548599243164, 41.97075687135969, 41.78692143304007, 42.80614921024868, 43.590878759111675, 43.86292157854353, 44.81710032054356, 42.721666063581196, 42.42285530907767, 41.22622959954398, 40.54096698760986, 41.01979167120797, 39.39137363433838, 37.469790254320415, 39.56226110458374, 48.47036933898926, 56.717929703848704, 56.52709395544869, 53.69686337879726, 47.75744942256382, 36.08121708461216, 33.47680296216692, 27.91598071370806, 13.543803027697972, 5.709415120737893, 3.2929554155894687, 3.7979904413223267, 4.567189463547297, 5.881485087530954, 8.158037168639046, 8.91739102772304, 7.819008503641401, 4.216313685689654, 1.0207329307283675, 0.11532599665224552, 0.10497780157519238, 0.053571785001882484, 2.3070891967841556, 2.267232809747968, 0.10765842201986484, 0.12317186993147645, 0.06829769802945, 0.14019148238003254, 0.133779217888202, 0.1821717383073909, 0.19563398164297852, 0.21932615818721907, 0.08364907785185746, 0.0728411820850202, 0.02406304342938321, 0.0403428084350058, 0.0849737614127142, 0.07742282016468899, 0.23070225917867251, 0.33126655008111683, 0.05920917607311692, 0.12140816742820398, 0.026697477691673806, 0.07953577821276017, 0.025132708085168685, 0.10234898049384356, 0.1487225674624954, 0.13662564515003137, 0.11972540058195591, 26.619184562138148, 58.486802101135254, 24.309509549822124, 40.30604839324951, 34.74013832637242, 22.067046199526104, 10.271014758518763, 6.580985861165183, 1.1329714166266578, 0.3636828006378242, 1.0845572373696735, 17.954800026757376, 49.853689670562744, 54.34537696838379, 55.35726397378104, 6.47418292931148, 0.08031609348420586, 0.04233041053105678, 0.032839310355484486, 0.06365341081150941, 0.12956677749752998, 0.1383900533297232, 0.5515180943267686, 24.10859543936593, 92.40773391723633, 32.438787255968364, 2.664603109870638, 33.463618755340576, 44.901517459324424, 13.243445430483137, 4.95474955865315, 2.9256745065961565, 0.7513339008603777, 2.506912440061569, 9.582415274211339, 48.39668369293213, 59.11974130358015, 31.597756453922816, 45.79314504350935, 35.53801039287022, 0.2767687344125339, 0.23854210706693785, 0.23983422773224966, 0.24236087501049042, 0.10700229901288237, 0.10787246589149747, 0.21184727735817432, 0.14125127265495913, 0.21501064832721437, 0.2164334819785186, 0.15226773651582853, 0.12438426273209707, 0.056698294556034465, 0.2191251761146954, 0.14671928781483853, 0.08291596147630896, 0.20579596635486397, 0.26031613296696116, 0.3611199195895876, 0.1844139437058142, 0.18299967316644533, 0.18913286977580615, 0.14495558531156608, 0.236184794987951, 0.23955399276954786, 0.19124284226979527, 0.1745987446712596, 1.234548760311944, 2.26655536038535, 0.15799895540944167, 0.35232086745756014, 0.10035056594227042, 0.31433056028825895, 0.7400520890951157, 0.6441984868475369, 1.1993108625922884, 1.9950360442910875, 2.078087644917624, 3.0316751386438097, 11.453786628586904, 15.311448199408394, 21.108352865491593, 39.659970147269114, 45.90451424462454, 48.27656323569161, 45.249629156930105, 42.02273287091936, 42.961281640189036, 46.548872811453684, 47.94258417401995, 41.607018675122944, 42.46370376859392, 41.71193299974714, 38.250594070979524, 39.39148827961513, 43.948936803000315, 44.38655172075544, 45.34587907791138, 45.92964587892805, 48.76423992429461, 46.31163699286324, 44.864226477486746, 45.60676656450544, 45.92680059160505, 45.38120371954781, 47.902253355298726, 49.427417687007356, 49.61293111528669, 47.65826736177717, 48.94283642087664, 46.35838794708252, 46.53172813143049, 47.31348385129656, 45.4423166002546, 44.886231422424316, 45.82857738222395, 44.98201234000069, 44.57382651737758, 47.11494949885777, 45.46184451239449, 45.600919655391145, 43.669230120522634, 43.07373128618513, 46.2167523929051, 41.398579665592735, 40.358118193490164, 42.881961005074636, 50.09115825380598, 56.461985860552105, 58.39673955099923, 53.717687129974365, 48.97996759414673, 38.655542033059255, 32.65560231889997, 31.6524908883231, 20.971007823944092, 8.349218589918953, 5.953151847634997, 3.6136836111545563, 5.3149572014808655, 7.164717486926487, 6.746570987360818, 9.092524715832301, 8.80215689114162, 5.182447237627847, 1.6499950162002017, 0.4584895862000329, 0.19385737340365136, 0.35705967460359844, 3.1252278557845523, 6.033246338367462, 0.32830854452082087, 0.2092598740543638, 0.27198378688522745, 0.15630113865647996, 0.15053502949220793, 0.39246688038110733, 0.316789978316852, 0.39580939816577093, 0.31198714460645405, 0.20814468818051474, 0.16527749198888028, 0.1300750816506999, 0.11807729330446039, 0.18242709817630903, 0.28035009652376175, 0.4839556025607245, 0.16309824106948717, 0.28970739298633164, 0.2613561914435455, 0.18862977677157947, 0.13534364822719777, 0.20757108181715012, 0.18626000678965024, 0.19684372815702642, 0.40904343660388676, 26.710164274488175, 73.450074332101, 35.99007756369454, 48.56789772851126, 39.525296688079834, 33.89067588533674, 29.29771511895316, 19.891031946454728, 6.453460361276354, 0.38779687668595997, 0.6470964827707836, 18.823740005493164, 60.394325801304404, 58.19935165132795, 62.77909346989223, 7.91960973399026, 0.27827714490039007, 0.11634324278150286, 0.1740805067654167, 0.17814300448766776], [0.16030298891876424, 0.08641505121652569, 0.3960866747157914, 9.608400668416705, 76.61054583958217, 62.08386366707938, 6.24200496503285, 9.031787037849426, 11.060496875217982, 4.567265025206974, 2.5509032223905836, 2.208358117512294, 2.219346910715103, 1.8631512011800493, 5.511366707938058, 10.083409053938729, 34.79270839691162, 35.262159960610525, 22.404337814876012, 39.68302427019392, 2.9875673225947788, 0.566875730242048, 0.1951659417578152, 0.11284671111830644, 0.07385344776724066, 0.10011960619262286, 0.05023806103106056, 0.10152513720095158, 0.1202217625187976, 0.06967564658927065, 0.02242373675107956, 0.0693549302273563, 0.0456124267407826, 0.07007964633937393, 0.035046917253306935, 0.1216539056705577, 0.04797014254810555, 0.2983402583215918, 0.15001877290861948, 0.1509755208556141, 0.022528753615915775, 0.028365908789315393, 0.05942214785942009, 0.04988022541095104, 0.09188342599996499, 0.07900884827332837, 1.0991659334727695, 7.285298262323652, 0.4671660949076925, 0.18731838571173803, 0.07082336143191371, 0.05905221735260316, 0.1093529953754374, 0.5006501695939473, 1.2356824023383004, 1.7249793240002222, 2.6045876102788106, 0.7787975243159703, 0.8127351318086896, 0.9687111164842332, 2.91917142697743, 6.722695239952632, 4.256391329424722, 23.992920092173986, 38.56556633540562, 39.182778290339876, 44.286678314208984, 41.63769844600132, 40.764678137642996, 39.08289098739624, 40.65616117204939, 39.908698286329, 36.237690516880576, 37.4201523235866, 36.39905548095703, 38.88721234457833, 41.048894201006206, 42.47423376355852, 41.99733025687081, 41.30103390557425, 40.78781563895089, 37.873355524880544, 38.93953227996826, 37.98943213054112, 40.805335521698, 42.64633369445801, 41.610774176461355, 44.318997859954834, 42.46575001307896, 42.27750941685268, 38.614036968776155, 40.703666005815776, 40.387172085898264, 38.10001271111624, 34.853216784340994, 38.82082578114101, 40.253749302455354, 41.66474430901663, 40.034078529902864, 40.607638427189414, 38.667941093444824, 39.37642458506993, 37.06070811407906, 37.15735755647932, 34.31105579648699, 33.020744051252095, 33.62732873644148, 43.275621618543354, 54.68875694274902, 54.38830293927874, 50.27610540390015, 43.312975134168354, 36.178874015808105, 36.48073502949306, 18.495357717786515, 8.691753489630562, 2.3194945539746965, 2.411364938531603, 2.8020113365990773, 4.052001816885812, 5.464905406747546, 7.591553143092564, 6.312325077397483, 3.509440439088004, 1.1272341587713786, 0.171321176258581, 0.07140523913715567, 0.05905501291687999, 0.13663152126329287, 0.15162733516522817, 0.055399595493716855, 0.2066928403718131, 0.006378157505033804, 0.1518369753445898, 0.13010288801576408, 0.07175370758133275, 0.09372349083423615, 0.12462058290839195, 0.047622006586087604, 0.05741405061313084, 0.04619969879942281, 0.1923279826130186, 0.12336958146521024, 0.22285520524850913, 0.32156070375016754, 0.5536787669573511, 0.787456825375557, 0.4750067027551787, 0.05230617469974926, 0.09268964095307247, 0.04187102875273142, 0.09239145873912744, 0.08940848309014525, 0.10903723910450935, 0.09958158899098635, 0.13843883999756404, 31.427251134599956, 36.53245047160557, 24.186317988804408, 37.09466743469238, 51.85847772870745, 35.085863317762104, 19.42704861504691, 11.960774098123823, 2.8501045959336415, 0.575057885476521, 6.7381345714841565, 36.49236978803362, 53.2694206237793, 40.221943923405235, 46.270222255161826, 2.6980814848627364, 0.3129522113927773, 0.27001709384577616, 0.04491645337215491, 0.03232665679284504, 0.03965995793363877, 0.017563878957714354, 0.32590292074850624, 24.80251898084368, 89.96018927437919, 80.00487981523786, 14.193450042179652, 15.653155394962855, 10.99093759059906, 6.083476168768747, 12.543245928628103, 7.955352136066981, 4.103920928069523, 2.8069252329213277, 9.37184751033783, 16.41292006628854, 53.40889876229422, 37.79246807098389, 28.37551372391837, 69.97467572348458, 8.367846710341317, 0.21763708096529755, 0.10001578354941947, 0.007943361798035247, 0.0864608862570354, 0.022661963610776832, 0.04836598291460957, 0.040116785027618916, 0.06451590345906359, 0.031103529568229402, 0.014274660098765577, 0.050879185021455796, 0.05707244894334248, 0.05618079625336187, 0.0543287417053112, 0.15179580183965818, 0.1254647211836917, 0.17293348402849265, 0.07559323191110577, 0.09252705039190394, 0.019225701124274304, 0.0008623118815843814, 0.008152868814899452, 0.031409148525978835, 0.24397117431674684, 0.43192689440080095, 4.241368455546243, 9.763890062059675, 0.6275833355528968, 0.2085769014166934, 0.12803571751075132, 0.04422982343073402, 0.0572027683790241, 0.45793595590761726, 0.9128155729600361, 2.0840854602200642, 2.761252769402095, 1.9543580327715193, 0.8319554233125278, 1.4459947113479887, 1.3850694320031574, 4.071590960025787, 6.761629470757075, 27.191217592784337, 39.2182696887425, 39.657652923039024, 42.636898040771484, 43.32478012357439, 42.598814964294434, 43.12584972381592, 43.26355607169015, 41.22008044379098, 39.7652770451137, 38.49964530127389, 37.67505046299526, 40.09584106717791, 42.21772364207676, 44.8744854927063, 42.015489373888286, 42.703493050166536, 41.22785895211356, 41.49384641647339, 42.12337405341012, 41.10903780800955, 43.81819602421352, 46.62043578284127, 44.31222684042794, 46.28034578050886, 45.162755829947336, 44.38992159707205, 39.15697962897164, 43.24759953362601, 42.969796657562256, 40.58655411856515, 38.89588369641985, 41.08014372416905, 40.84505837304251, 42.86382620675223, 42.825656277792795, 42.56733267647879, 39.69969994681222, 39.50366694586617, 40.129376547677175, 40.12371723992484, 36.296395846775596, 38.5964788709368, 38.10977145603725, 42.27955218723842, 55.33496373040335, 52.59683847427368, 49.95969486236572, 42.99386869158064, 37.600683893476216, 32.59380851473127, 12.48301112651825, 3.861592079911913, 1.9744198705468858, 1.656500484262194, 1.3282374015876224, 1.961868166923523, 3.2606076427868436, 4.907106629439762, 4.51640681709562, 3.426805296114513, 0.6637256390282086, 0.03827348018863371, 0.07583251728543214, 0.11929151814963136, 0.09301480171935898, 0.03910129291138478, 0.13161095923611096, 0.1692099959722587, 0.040485884329038005, 0.12001604427184377, 0.08471477138144629, 0.11739489063620567, 0.1268497740051576, 0.08035589634839978, 0.05053690820932388, 0.059610895945557525, 0.07718048816812889, 0.1612969341554812, 0.09393306316009589, 0.08076721749135427, 0.6637169537799699, 0.9549498834780284, 1.0740096547773905, 0.8429530103291784, 0.051557143285338364, 0.24798069202474185, 0.006636657718835133, 0.07118148542940617, 0.03527919336089066, 0.02071901590430311, 0.11412082346422331, 0.3718746724937643, 38.35501854760306, 42.31876087188721, 32.32661553791591, 43.15250301361084, 59.31624330793108, 67.81743376595634, 38.04251289367676, 9.807648948260717, 5.96528513942446, 2.4683822904314314, 12.719495671136038, 54.54562752587454, 63.282990728105815, 56.96459770202637, 50.98897320883614, 2.26117028934615, 0.20829611005527632, 0.11633507321987833, 0.010720363053094064, 0.08550200771008219, 0.19731060096195766, 0.11406261873032365, 0.27697720751166344, 41.35849550792149, 97.74852234976632, 111.29001944405692, 17.97510440008981, 17.82503546987261, 41.26261731556484, 11.224701046943665, 7.532956378800528, 5.163892941815512, 1.8351944727557046, 0.6834470693554197, 14.103858232498169, 38.01067277363369, 57.72382041386196, 43.48304966517857, 35.844391209738596, 74.18260901314872, 8.976566229547773, 0.44388276285358835, 0.2172131865684475, 0.16805097673620495, 0.1808907049042838, 0.17544628919235297, 0.26502093193786486, 0.1920249895857913, 0.19514219303216251, 0.12030142252998692, 0.17275952122041158, 0.22036586382559367, 0.2380002018596445, 0.1778340403522764, 0.17871636657842568, 0.2558347348655973, 0.3332659756498677, 0.4341546877154282, 0.22381749004125595, 0.24438977614045143, 0.11435406309153352, 0.13401371959064687, 0.20891881521259034, 0.16630190344793455, 0.5585028252431324, 0.7975857790027345, 8.249468513897487, 15.1616450377873, 0.7099243200251034, 0.40556396331105915, 0.22950024796383722, 0.22091008962265082, 0.12831698384668144, 0.779474105153765, 1.3619783967733383, 2.044743457010814, 2.8833150310175757, 2.786008983850479, 1.590649040681975, 2.2353764048644473, 3.6979411584990363, 8.805431229727608, 20.353252172470093, 39.68451465879168, 42.99537992477417, 42.72449050630842, 47.68616437911987, 44.79013436181204, 44.549834387642996, 44.60614953722273, 44.6952462877546, 44.107508591243196, 40.2286628314427, 40.00433676583426, 38.74275582177298, 44.05959728785923, 44.46954100472586, 48.229138306209016, 43.88625015531267, 45.28495727266584, 44.20789963858468, 43.73300068719046, 43.69113431658064, 43.9387993812561, 46.757266657693044, 50.63866588047573, 47.094101428985596, 48.216641971043174, 47.77838087081909, 47.36416401181902, 42.66217906134469, 45.335296971457346, 47.91999558040074, 42.54997260229928, 38.5816444669451, 41.91435486929757, 42.485983167375835, 47.245151792253765, 43.809538568769185, 45.39539194107056, 41.68304933820452, 43.04478161675589, 44.48157181058611, 43.272397654397146, 39.643172877175466, 39.35217884608677, 37.98655557632446, 45.196121079581125, 55.40836797441755, 55.95630291530064, 49.57048109599522, 44.674036911555696, 34.521085943494526, 36.74066366468157, 26.196709769112722, 10.946918146950857, 5.233185589313507, 4.32679568869727, 4.372162648609706, 5.211607090064457, 6.07937890291214, 8.736190693719045, 7.516569920948573, 6.134920196873801, 1.804051235318184, 0.3299808076449803, 0.21883446457130568, 0.175940371251532, 0.26446412610156195, 0.22027716572795594, 0.37191180192998474, 0.19398290238210134, 0.15083562050546917, 0.22787922780428613, 0.2515954380588872, 0.11396613105067185, 0.21520906553736754, 0.20967968367040157, 0.15731649845838547, 0.2564808630517551, 0.20612360377396854, 0.26458753805075375, 0.142945493172322, 0.422384900706155, 1.1973136897597993, 1.5257597054753984, 0.8376134825604302, 0.4298014241669859, 0.1633585271026407, 0.307077699473926, 0.13552896971149103, 0.18019241094589233, 0.22213929652103356, 0.1936985554971865, 0.19551158749631473, 0.3215522899159363, 44.83715976987566, 52.86504588808332, 39.01279408591134, 54.26353761128017, 69.32838208334786, 71.91109003339494, 45.78945902415684, 21.230795758111135, 9.748796837670461, 2.0238769309861318, 9.519567949431282, 55.96570382799421, 71.8289623260498, 63.23544420514788, 63.072092056274414, 2.8958554438182285, 0.2881835119000503, 0.2600439318588802, 0.1356279408293111, 0.13194637266652925], [0.06422372628003359, 0.2113900397505079, 0.3663096811090197, 4.962829010827201, 34.626729828970774, 78.00987134660993, 44.957429613385884, 1.9093350086893355, 7.44354522228241, 4.602547977651868, 1.368887403181621, 3.534576198884419, 2.6812201610633304, 6.586339448179517, 17.380967412676128, 25.131938287190028, 22.106004749025615, 34.953350748334614, 28.43531686919076, 56.54181024006435, 13.581365857805524, 0.11019469092467002, 0.259223393031529, 0.020874892361462116, 0.05604482462097492, 0.03927265693034444, 0.05454683303833008, 0.07928079832345247, 0.04199030503098454, 0.04234817797052009, 0.03885306444551263, 0.00505879832365151, 0.023975507322964922, 0.004171048482281289, 0.05345260711120708, 0.05576759896108082, 0.40035878547600334, 0.8077311260359628, 0.8745203592947551, 0.34525707364082336, 0.1290233795131956, 0.02753757529093751, 0.12594178558460303, 0.02066586964896747, 0.04966587619856, 0.03933825430327228, 0.13344448299280234, 0.1014342542205538, 0.04535507537158472, 0.06786167821181671, 0.019935370722253407, 0.08236443464245115, 0.15108990828905786, 0.14969914220273495, 0.2889446110597679, 1.9996038334710258, 2.1936817850385393, 1.8723799288272858, 0.5856018311211041, 0.7989190188901765, 0.39379604905843735, 0.39315591912184444, 1.547238324369703, 4.119250391210828, 27.36605511392866, 39.88615138190133, 38.81658738000052, 40.569239207676475, 41.82590082713536, 42.72103377750942, 40.84694133486067, 38.976434162684846, 36.08988148825509, 36.16825369426182, 37.00067220415388, 38.74033090046474, 37.33204221725464, 41.75926065444946, 41.987807750701904, 38.647534234183176, 40.26540837969099, 36.96765783854893, 38.08445569447109, 36.567670890263145, 39.49115324020386, 37.857499735695974, 40.764771938323975, 43.215853214263916, 42.493462903159006, 41.16755553654262, 39.06735828944615, 37.75936337879726, 35.563576289585654, 37.54706117085048, 40.47055394308907, 39.45943818773542, 38.67419794627598, 39.933475562504356, 40.84713588442121, 40.59632675988333, 37.40424789701189, 35.32120227813721, 34.037786620003835, 34.65215676171439, 32.63820055552891, 36.57484490530831, 41.56591313225882, 42.17693771634783, 51.69977739879063, 47.335287298474995, 43.63452386856079, 37.78842074530465, 34.5881256375994, 14.709963491984777, 2.9159811181681494, 0.28816858412964, 0.3270005461360727, 0.1374790793550866, 0.12340339965053967, 0.0637748007263456, 0.11817420167582375, 0.06356666689472538, 0.023992307850026658, 0.015684384453509535, 0.040052005289388556, 0.16901157876210554, 0.09022237227431365, 0.053607258812657425, 0.01876108275194253, 0.10886183101683855, 0.14468088719461644, 0.03836291788944176, 0.08373593033424445, 0.08177235177052872, 0.1223387239234788, 0.06568430004907505, 0.08369139129562037, 0.015119387003194009, 0.027060904440336993, 0.015214850094967654, 0.07747414455349956, 0.3498844653367996, 0.8148022751723016, 0.9358717586312975, 1.399333758013589, 0.8014666193297931, 3.848322323390416, 1.6129028179815836, 0.2221911908792598, 0.1447524590683835, 0.05519871859412108, 0.0654724749869534, 0.03504348386611257, 0.08355402866644518, 0.022154400757114803, 2.5541699613843645, 39.69807406834194, 32.406485080718994, 35.04885721206665, 40.339142663138254, 27.550135476248606, 17.940714291163854, 25.232072251183645, 12.44311283315931, 7.2732696277754645, 8.75393031324659, 19.033024958201818, 40.342401368277415, 28.030509608132498, 44.936223711286274, 34.310743127550396, 0.5810967928596905, 0.05581652133592537, 0.016628437010305266, 0.019270531932956407, 0.07453534153423139, 0.07956472451665572, 0.05978557121540819, 0.40044010111263817, 15.129872662680489, 59.95781217302595, 81.75160830361503, 64.38906751360211, 3.3753888436726163, 2.495751027550016, 5.805768830435617, 10.191861748695374, 6.496021551745279, 6.0034003513199945, 8.926809310913086, 15.872735840933663, 27.95453279359, 27.985047544751847, 43.94105407169887, 33.877404826028005, 58.761387961251394, 28.141474076679774, 0.23351446113416127, 0.3490097794149603, 0.014635654299386909, 0.17613171812679085, 0.06628474247242723, 0.008024600251311702, 0.07331766973116569, 0.10928334375577313, 0.04662576450833252, 0.05284824275544711, 0.0520196463247495, 0.01715920745794262, 0.019402776711753437, 0.09205804020166397, 0.0400902339523392, 0.42164035780089243, 0.47707096913031166, 1.1620625470365797, 0.2033673402454172, 0.1479992355619158, 0.0545619847252965, 0.06281732674688101, 0.051284993067383766, 0.08788177251283612, 0.01045297275829528, 0.10880044395370142, 0.11926035982157503, 0.0627962446638516, 0.05971652349191053, 0.0349689705430397, 0.04051085441772427, 0.07288848954652037, 0.08046633470803499, 0.2273806809846844, 0.658269077539444, 1.4752555297953742, 1.603094458580017, 0.5686678769333022, 0.9907267008508954, 0.62604870647192, 0.4658052793570927, 1.63860442170075, 6.27062372650419, 29.80852583476475, 38.3090249470302, 39.53182104655674, 39.240653310503276, 39.98116799763271, 46.444059235709055, 42.50232185636248, 40.83662673405239, 37.54752670015608, 37.78712838036673, 40.59879684448242, 40.36942638669695, 41.51291227340698, 43.52471106392996, 45.4585336957659, 42.80300862448556, 41.79849713189261, 39.33812958853585, 40.98601647785732, 40.194512435368125, 41.9330872126988, 40.33903496606009, 44.629599707467214, 45.91709048407418, 44.41304867608206, 43.25568723678589, 41.830736773354666, 39.73138720648629, 39.19584090369088, 39.008916991097585, 41.92270312990461, 41.727208614349365, 42.8360264641898, 41.48718309402466, 43.853235789707725, 41.273776122501914, 40.92509119851248, 37.58131231580462, 38.30035706928798, 37.739154543195454, 35.6134226662772, 38.862039021083284, 47.680703095027376, 47.25601530075073, 48.59813281467983, 45.480945110321045, 37.23126207079206, 33.03801727294922, 19.85829029764448, 3.35021921140807, 0.03176523691841534, 0.4242409382547651, 0.23576668170945986, 0.12023682599621159, 0.09109616931527853, 0.12750785797834396, 0.09096762764134578, 0.09135099314153194, 0.1006849751408611, 0.028467780644340173, 0.03782664452280317, 0.38618820586374825, 0.20814649308366434, 0.09019949207348482, 0.04041435316737209, 0.13248385382550104, 0.042202248836734464, 0.09319210291973182, 0.08497899970305817, 0.010555430697942418, 0.1291011939091342, 0.1466406320354768, 0.07420009773756776, 0.044607394241860936, 0.1507317367941141, 0.06795566209724971, 0.07243598811328411, 0.5160671908940587, 1.8875576172556197, 2.0284749014036993, 2.215934259550912, 2.6310348425592696, 8.422461288315908, 2.702993644135339, 0.5379256808332035, 0.17558553814888, 0.11358748815421547, 0.04642052462856684, 0.14106439054012299, 0.1128556609952024, 0.32256650977901047, 5.380067901951926, 49.95622076307024, 39.128307887486045, 44.22596148082188, 51.46760334287371, 34.964130878448486, 33.91623830795288, 58.84903253827776, 48.39912945883614, 23.733627217156545, 11.775083490780421, 41.14301102502005, 52.872584683554514, 37.80947726113455, 58.32688931056431, 34.4948912348066, 0.34687451113547596, 0.040391337259539535, 0.07854261329131466, 0.01621490384318999, 0.04431724927521177, 0.19809584239763872, 0.2840924614242145, 0.557471017752375, 26.956290313175746, 78.87858377184186, 91.6168691090175, 89.16894926343645, 14.912043162754603, 11.593671236719404, 7.982934747423444, 9.255061319896154, 1.5905147450310844, 1.6751256734132767, 11.84556862286159, 46.26888125283377, 39.425739424569265, 32.342085702078684, 53.86664955956595, 37.53684384482247, 78.2582347052438, 44.40253605161394, 0.11864152231386729, 0.33049101169620243, 0.1833436225673982, 0.2320787353175027, 0.10244607206966196, 0.10225403987403427, 0.09273577454899039, 0.17164319540773118, 0.13847533161086695, 0.1416032694812332, 0.15533542047653878, 0.1286809771720852, 0.14461135092590535, 0.17060397831457003, 0.24920851471168654, 0.7317975748862539, 1.0131419152021408, 1.5499545271907533, 0.6523442726050104, 0.24544489809444972, 0.18814732480262006, 0.12489859227623258, 0.13307940401136875, 0.1478362243090357, 0.13556622128401483, 0.2095142975449562, 0.20461988874844142, 0.16814823794577802, 0.31900995490806444, 0.17325080771531376, 0.11351481026836804, 0.35263421492917196, 0.33767857030034065, 0.39223628704036984, 2.0730024320738654, 2.4975343261446272, 2.25458231142589, 1.6938252300024033, 1.3175895043781825, 0.9933631079537528, 1.2144409992865153, 4.614128453390939, 22.314679997307913, 42.8996650150844, 42.94640554700579, 40.71069758278983, 41.54879624502999, 42.28657681601388, 47.37413467679705, 45.40275355747768, 41.87926646641323, 38.18404769897461, 39.740510191236226, 42.866334506443565, 41.68079464776175, 43.1232510975429, 47.69182368687221, 47.66659477778843, 45.956326961517334, 45.06987231118338, 42.081997530800955, 44.26420783996582, 42.29315676007952, 44.911508968898225, 44.11061791011265, 45.555534022195, 50.08523491450718, 48.704898834228516, 47.206554549080984, 44.524039200374055, 42.18819032396589, 41.70416838782174, 44.30609852927071, 45.88417339324951, 44.27182306562151, 44.97408444540841, 43.57362985610962, 47.483131068093435, 45.82711131232125, 42.21431902476719, 40.028599875313894, 41.27488783427647, 41.0649653843471, 38.50387675421578, 41.96652889251709, 45.78666932242257, 48.30906343460083, 51.84543595995222, 50.23127910069057, 41.86086416244507, 39.60968255996704, 36.2438188280378, 19.347173861094884, 4.3686994058745245, 1.3154809432370322, 0.6174688754337174, 0.3960656129888126, 0.20571611635386944, 0.2558373947228704, 0.32077539446098463, 0.21513351744839124, 0.27445273154548233, 0.16760070089782986, 0.08238793909549713, 0.2764971304152693, 0.19176770267742022, 0.171842291152903, 0.1727671343833208, 0.1895733339978116, 0.1429274169994252, 0.2123005794627326, 0.15679432504943439, 0.22911247877138002, 0.19336846178131445, 0.2793709433504513, 0.20199528815490858, 0.11200265426720891, 0.23651830852031708, 0.09770233875938825, 0.23012306168675423, 0.845357032758849, 1.8854685979230064, 1.7993029015404838, 2.570910994495664, 1.8801962179797036, 5.245929454054151, 2.6586760793413435, 0.6672382248299462, 0.22976503946951457, 0.1344326471111604, 0.18020552024245262, 0.2766811762537275, 0.21787344185369356, 0.3616054521075317, 5.694025729383741, 59.8871350969587, 44.05413252966744, 48.124536650521414, 55.38203777585711, 42.09953130994524, 30.26836109161377, 52.03380857195173, 45.9461270059858, 27.58563208580017, 18.31069196973528, 51.06801591600691, 74.58142866407121, 41.975519861493794, 71.76143973214286, 45.9003244808742, 0.5935506788747651, 0.25930340588092804, 0.1567416028784854, 0.11898851155170373, 0.19934520178607532], [0.07846319755273205, 0.10353497149688856, 0.2966044300368854, 2.498016574553081, 14.945217336927142, 36.48353515352522, 70.27472673143659, 32.10685791288103, 8.912055679730006, 4.262561764035906, 3.533993635858808, 2.3966933829443793, 4.1875225220407755, 10.851819021361214, 38.27721609388079, 58.69065529959542, 40.3344908441816, 31.579295090266637, 41.0479006086077, 44.69449588230678, 16.008654764720372, 1.5466987533228738, 0.3785061852208206, 0.09325704550636665, 0.0845797225566847, 0.01867113445353295, 0.05586142339078443, 0.05918383279017039, 0.10373355155544621, 0.03501689886408193, 0.033545461749391894, 0.0973109258338809, 0.27186346905572073, 0.1420341527887753, 0.059627248639506955, 0.12106766498514585, 0.7292681591851371, 1.7395867173160826, 1.5214485653809138, 0.7540232879774911, 0.27601686332906994, 0.09961585500942809, 0.05976608368967261, 0.02663293544069997, 0.027295460425583378, 0.02690202716205801, 0.04292559091533933, 0.029889280974332775, 0.055464897703911574, 0.09428501248891864, 0.10594122630677053, 0.03808032162487507, 0.01349116928343262, 0.03503534823123898, 0.05202497960999608, 0.18566581367381982, 0.21897880254047258, 0.19766102358698845, 0.1490101713154997, 0.246328133557524, 0.20572465232440404, 0.2992873303592205, 0.3187435349183423, 0.12140371623848166, 6.196125141211918, 27.464905398232595, 40.14863348007202, 44.737449645996094, 41.48526191711426, 43.08217682157244, 42.39105340412685, 42.686574186597554, 39.48995467594692, 35.17607525416783, 37.55193533216204, 37.898917947496685, 39.764981746673584, 39.9086149079459, 41.61014189038958, 42.24494668415615, 37.13621071406773, 38.36318962914603, 39.642776829855784, 37.76084681919643, 38.980043751852854, 36.17031730924334, 41.48925713130406, 41.255933148520334, 40.454531397138325, 40.900234018053325, 38.5180093901498, 36.32802752086094, 34.98262698309762, 35.71400478907994, 35.022346360342844, 37.76400824955532, 40.007984570094514, 39.45491491045271, 39.57644585200718, 38.285348960331504, 36.9817487852914, 35.56375346864973, 36.493137563977925, 33.62671382086617, 32.59795658929007, 36.86320556913103, 44.616616998400005, 55.728620869772776, 52.179991722106934, 33.67283943721226, 23.919298716953822, 15.98083938871111, 3.6240359927926744, 0.39426106267741745, 0.042187338029699664, 0.033745500658239634, 0.10150870308279991, 0.06882516401154654, 0.015168574006695832, 0.01617479563823768, 0.04580767179972359, 0.05489329641152706, 0.06660159797008548, 0.041047992916511636, 0.12355536435331617, 0.5659587308764458, 0.10096432800803866, 0.09596150288624422, 0.09446725342422724, 0.03516038866447551, 0.06769649564687695, 0.03599487817181008, 0.032664112613669465, 0.07028177513607911, 0.11324414943477937, 0.06856115960649081, 0.008034674800001085, 0.0509459053698395, 0.13451059721410275, 0.6686934924551419, 0.786784858575889, 3.421547246830804, 5.357987395354679, 5.892577886581421, 7.69412853036608, 12.359083924974714, 19.002055100032262, 4.373109774930136, 0.7194073625973293, 0.24583255872130394, 0.14643142611852714, 0.05582395129437957, 0.22019133104809693, 0.03285902179777622, 0.14317513656403336, 8.065707768712725, 47.459910188402446, 38.63331127166748, 44.58613525118147, 43.91873645782471, 34.049001012529644, 17.237883159092494, 35.137297357831685, 38.293711117335725, 37.859799589429585, 20.542913675308228, 29.629304000309535, 23.156541109085083, 17.609210525240215, 49.67441919871739, 16.995500462395803, 0.4587259335177285, 0.12594403832086495, 0.04769074557615178, 0.032934546138026884, 0.052764986508658955, 0.05295908484341843, 0.154822244441935, 0.1717612197888749, 2.596848185573305, 42.144837038857595, 56.360295500074116, 82.24647290366036, 36.94673333849226, 10.014674867902484, 5.375379604952676, 3.7034528170313155, 14.170619998659406, 13.157505767686025, 11.20183539390564, 39.960590907505576, 55.43382269995553, 42.30965873173305, 40.013612610953196, 45.55836888722011, 52.295106002262656, 38.16507911682129, 1.5913201932396208, 0.25387262872287203, 0.02203450022664453, 0.11655479642961707, 0.07675915184829916, 0.060426338974918635, 0.050558970775455236, 0.08611685543188027, 0.04006623416872961, 0.03734790414039578, 0.17297921728874954, 0.2608933762780258, 0.15308994453932556, 0.10596234231655087, 0.14221477881073952, 0.9570683240890503, 2.3119479417800903, 2.1324086615017483, 0.8510207374181066, 0.271145443298987, 0.21625715786857264, 0.09208542587501661, 0.05558665402765785, 0.05278235021978617, 0.009600960932272886, 0.08822107394891125, 0.015593143545889428, 0.07210854068398476, 0.026497435390150974, 0.10201538553727524, 0.03092320549434849, 0.05602786803085889, 0.09755213824766022, 0.009866526816040277, 0.24892662412353925, 0.17139205602662905, 0.17510486394166946, 0.29562128707766533, 0.35551693024379866, 0.14335272274911404, 0.5495469229561942, 0.31521840978946003, 0.5017787633197648, 7.017805210181645, 26.144313403538295, 38.19991043635777, 42.70431988579886, 41.78217233930315, 47.11618627820696, 47.00655065264021, 44.24520799091884, 42.241170338221956, 37.80021183831351, 39.00504684448242, 40.15672813143049, 42.51924419403076, 44.04579816545759, 45.05815417425973, 44.520506041390554, 39.33935941968645, 39.53517702647618, 39.9910865511213, 40.293232440948486, 40.92298242024013, 39.25453928538731, 42.70260715484619, 43.61871671676636, 44.151011262621196, 44.41198560169765, 39.017018590654644, 39.36779144832066, 35.51064838681902, 37.7964528628758, 36.9911253792899, 40.2389600617545, 40.62115962164742, 39.9536566053118, 40.76791252408709, 41.85650416782924, 37.91777883257185, 39.99480036326817, 37.37014961242676, 35.94577237537929, 36.7344901902335, 41.45028121130807, 46.897318022591726, 57.62645878110613, 49.06016717638288, 27.886664526803152, 18.56238351549421, 9.265341179711477, 1.8504084220954349, 0.13211637283010141, 0.10233882282461439, 0.04267333873680659, 0.05217976023309997, 0.07998272922954389, 0.04625893829922591, 0.027581720779250776, 0.024434227529647093, 0.08750597267810788, 0.03891429205292037, 0.027744156973702565, 0.07174230819301945, 0.14174726818289074, 0.07096030336937734, 0.061087469570338726, 0.030598540058625594, 0.02738526962431414, 0.045721762481012514, 0.038973334777568064, 0.007319756733652736, 0.06274707801640034, 0.10836467519402504, 0.0370247857645154, 0.06652204652449914, 0.06610983650067023, 0.11444582816745553, 0.6007263766867774, 3.443676390818187, 6.253504233700888, 6.055819298539843, 7.414745807647705, 12.518140350069318, 15.929351500102452, 27.491306815828594, 13.65334050995963, 4.185973508017404, 1.0188946979386466, 0.28006264194846153, 0.3982011798237051, 0.6044544652104378, 0.04509432454194341, 0.26069969524230274, 17.733955008643015, 56.694872106824604, 49.34317077909197, 49.12334367207119, 54.93840571812221, 45.569312300000874, 20.887222971235, 53.81470830099923, 67.36902482169015, 71.26260771070207, 48.628732681274414, 41.65079927444458, 33.670338085719514, 27.604956763131277, 59.53814097813198, 16.057537078857422, 0.40297624788114, 0.09670520440808364, 0.05034850278337087, 0.03608369501307607, 0.07414774197552886, 0.20542412916464464, 0.2220479521368231, 0.45850424255643574, 7.41118311882019, 69.76116452898297, 64.16737828935895, 100.28137697492326, 62.11457470485142, 21.575349978038243, 8.847959416253225, 11.1171863589968, 9.847724420683724, 17.954617636544363, 31.014236313956125, 51.440005098070415, 68.75081307547433, 47.85767718723842, 50.123859950474326, 53.19529029301235, 58.306371280125205, 52.064613410404746, 2.364285030535289, 0.47246415061610086, 0.23766305137957844, 0.27831118021692547, 0.20721039974263736, 0.1771242655813694, 0.141389897359269, 0.15760969343994344, 0.14804133187447274, 0.18991557349051746, 0.3533370957842895, 0.3480200139539582, 0.427534710083689, 0.13412763204957756, 0.27979434920208796, 1.3793508474315916, 2.6183947665350775, 2.471098167555673, 0.9924033880233765, 0.4741414891821997, 0.4671443817870957, 0.3362043851188251, 0.1325329119073493, 0.1631516417754548, 0.1828971600958279, 0.16004164437098162, 0.1268979228500809, 0.12472570155348096, 0.26727619235004696, 0.14189573164497102, 0.1360198219439813, 0.13338641396590642, 0.3256839710686888, 0.11324606968888215, 0.3618294229464871, 0.232863148940461, 0.3212650253304413, 0.27314750158361023, 0.41050323684300694, 0.3653407873851912, 0.5144991778901645, 1.0042319361652647, 2.2998159527778625, 16.969743490219116, 37.17497818810599, 46.22354078292847, 46.767049721309114, 41.56437758037022, 47.16174909046718, 49.079111439841135, 46.58090053285871, 45.65651914051601, 39.80226230621338, 40.07146331242153, 42.18712377548218, 47.608372347695486, 44.81364706584385, 47.50274583271572, 47.386728286743164, 41.990225723811555, 41.88991110665457, 43.00542007173811, 42.01760857445853, 44.589949812207905, 42.581236021859304, 45.260614258902415, 46.97770520618984, 45.98199013301304, 47.053058419908794, 42.904872689928325, 41.81040981837681, 37.69608613422939, 40.428607668195454, 39.40875802721296, 42.49141318457467, 43.60353490284511, 43.055565220969065, 43.55878850391933, 45.29072080339704, 41.31834534236363, 42.441942010607036, 41.00811522347586, 39.01347153527396, 38.80978856767927, 43.322605337415425, 48.34177555356707, 60.74313926696777, 55.28069135120937, 34.801921708243235, 25.174928528921946, 17.30573579243251, 4.822388546807425, 0.5096100345253944, 0.3332799806126526, 0.32908090736184803, 0.2066802739032677, 0.2299882774906499, 0.16347496371184075, 0.08861674128898553, 0.08984349867595093, 0.22519381690238202, 0.09603435040584632, 0.10238860693893262, 0.38949771970510483, 1.4619132514510835, 0.18755218173776353, 0.4214490109256336, 0.2756801199700151, 0.17247521504759789, 0.1872339623847178, 0.1665799535278763, 0.1339226466204439, 0.16860802684511456, 0.183048527687788, 0.20882253109344415, 0.1450933279203517, 0.09391572659036942, 0.3824271948209831, 0.9489795352731432, 3.407318204641342, 5.496126702853611, 7.116232522896357, 6.62267678976059, 10.800429276057653, 15.423599072865077, 26.346497297286987, 12.560323732239858, 3.487134116036551, 0.5997738763689995, 0.2269314636609384, 0.6238245772463935, 0.49582214866365704, 0.24136568126933916, 0.3281641794102532, 19.483388083321707, 66.35804803030831, 51.29468699863979, 56.415964467184885, 58.76279149736677, 46.726875237056184, 26.564884390149796, 52.07767602375576, 64.63670825958252, 67.53927653176444, 60.08145536695208, 52.25243016651699, 40.79528495243618, 31.661325522831508, 79.30695411137172, 21.78336862155369, 0.595919634614672, 0.1881575978228024, 0.32792343518563677, 0.11562514917126723, 0.22811693219201906], [0.06728343745427472, 0.10729894095233508, 0.4855066250477518, 1.128373771905899, 9.673781480107989, 17.27257377760751, 31.594053064073833, 44.771235261644634, 25.126723664147512, 27.629148653575353, 23.904870782579692, 23.79126078741891, 23.969508137021744, 72.90351513453892, 82.7783088684082, 38.010627610342844, 32.93833146776472, 26.82595079285758, 40.651957511901855, 49.079827104296, 34.723785740988596, 4.457239431994302, 0.29850720507758005, 0.04395068769476243, 0.06618216154830796, 0.05612118016662342, 0.0743167039805225, 0.052695277213518105, 0.09731292751218591, 0.0629534273009215, 0.3849017848925931, 0.5727383270859718, 0.479753950876849, 0.09356524289718696, 0.20634279772639275, 0.3056517174201352, 1.4875532984733582, 2.381057547671454, 3.4690040946006775, 0.9324516164405006, 0.059415715347443304, 0.5371712584580693, 0.6827615318553788, 0.15608380389000687, 0.09699252327638012, 0.06435127729283911, 0.0536713294817933, 0.050768509174564054, 0.164685741599117, 0.0317517544275948, 0.2577824017831257, 0.6118189043232373, 0.1662106676293271, 0.1718510849667447, 0.11226579693279096, 0.21350598335266113, 0.5020400807261467, 0.222530566954187, 0.1543926503509283, 0.034333403754447184, 0.08106471438493047, 0.1439588309398719, 0.029977582128984586, 0.0666528952174953, 0.15357984682278975, 3.57825539793287, 15.045285293034144, 31.75887128284999, 43.63739694867815, 48.11883217947823, 46.47887665884835, 40.23494400296892, 39.277867862156455, 35.79418352672032, 36.451983383723665, 38.590447834559846, 40.480316162109375, 42.082219873155864, 40.7343145098005, 44.05848557608468, 38.43792445319039, 36.26623371669224, 36.586201735905235, 40.08073568344116, 35.16978366034371, 37.29127018792288, 39.326446192605154, 42.36750248500279, 40.43244654791695, 40.59905392783028, 34.01418706348964, 34.73274196897234, 34.0144476209368, 34.248042583465576, 33.820328848702566, 35.34968294416155, 38.388217040470664, 37.64483274732317, 39.851497241428916, 37.61723797661917, 35.428013460976736, 35.80707938330514, 33.03163535254342, 34.536663804735454, 35.06413630076817, 43.69924633843558, 51.36882775170462, 50.34390939985003, 32.380262579236714, 15.815711975097656, 7.373925140925816, 1.0882839688232966, 0.03943692347300904, 0.25806543231010437, 0.03391562635079026, 0.06039041733103139, 0.05027469852939248, 0.05289290053769946, 0.04263614823243447, 0.0642535953915545, 0.0045159317170535875, 0.0718150810737695, 0.04124185037133949, 0.020398048484431844, 0.03105151646637491, 0.06257217882999352, 0.3239612249391419, 0.0112477781450642, 0.01485539277616356, 0.06340160646608897, 0.05879486259073019, 0.051045551630003114, 0.17335610277950764, 0.24725615233182907, 0.7069467455148697, 0.3040101240788187, 0.4105956261711461, 0.21070302304412636, 0.6956346439463752, 2.8802232997758046, 12.28624335357121, 11.504324351038251, 6.371692223208291, 12.807070766176496, 16.395137889044626, 22.930021149771555, 41.06465966360909, 25.05778537477766, 7.287141271999904, 2.466475227049419, 0.21752814895340375, 0.30456022598913735, 1.1143869395766939, 0.18962228351405688, 0.1261099265622241, 16.809983560017177, 51.27952602931431, 41.07854911259243, 50.34480571746826, 37.32290881020682, 55.98255320957729, 48.58364234651838, 27.627554041998728, 17.714724131992885, 17.545549392700195, 21.674578939165386, 9.53453871182033, 10.113120419638497, 24.88544920512608, 47.119455405644004, 4.288100736481803, 0.2882817637707506, 0.27962897664734293, 0.10888089106551238, 0.0646941749645131, 0.08496998197266034, 0.2679564915597439, 0.07846817121441875, 0.20145777985453606, 1.69548975782735, 27.94678381511143, 40.09118924822126, 58.67182568141392, 50.84995365142822, 33.15195035934448, 22.770344597952707, 11.664971913610186, 7.073651356356485, 8.114398138863699, 59.74548217228481, 75.47468907492501, 38.26027985981533, 33.120721680777415, 35.972046988351, 43.883620262145996, 55.87097208840506, 58.26366417748587, 8.957574197224208, 0.5444425482835088, 0.070210237189063, 0.051027947038944275, 0.04482260858640075, 0.09068900759198836, 0.024462135674964105, 0.046492615581623147, 0.13820361904799938, 0.8063951720084462, 0.8113565114992005, 0.47096681381974903, 0.1611257940530777, 0.09632542157279593, 0.1644167024642229, 1.938754984310695, 3.208549350500107, 4.136509282248361, 0.7098118460604123, 0.3757202018584524, 0.14705238065549306, 0.15177412943116256, 0.08418870996683836, 0.04155342347387757, 0.02860172006434628, 0.034470891912600825, 0.08457598382873194, 0.19960354720907553, 0.16292522821043218, 0.36265766993165016, 0.782794041293008, 0.7620392292737961, 0.25580026528664995, 0.1498983736549105, 0.9688114311013902, 1.1765708199569156, 0.6297726152198655, 0.5790876235280717, 0.047514665738812516, 0.07903841204409089, 0.1201818510890007, 0.16929797482277664, 0.24440014415553638, 0.3743496154035841, 2.847889857632773, 12.498641099248614, 26.31315115519932, 40.75990472521101, 47.38289288112095, 48.90078592300415, 42.28422832489014, 40.954377855573384, 39.07403203419277, 38.88220269339425, 42.24784755706787, 43.212431226457866, 45.06792334147862, 43.78157901763916, 45.26753119059971, 42.607329981667654, 41.27500595365252, 39.28312764848982, 43.22991984231131, 38.970910344805034, 39.65627370561872, 42.94418907165527, 44.83410951069423, 43.58989558901106, 42.809807436806814, 38.08741215297154, 36.14893422807966, 38.56955112729754, 37.70074142728533, 35.336790561676025, 37.98049327305385, 42.73863009044102, 41.67979063306536, 41.51683453151158, 39.79216309956142, 39.96279001235962, 38.736603191920686, 35.2509559903826, 38.23550953183855, 38.86495379039219, 48.86513124193464, 54.31367233821324, 43.31954118183681, 23.460045371736797, 12.924526589257376, 2.3739080684525624, 1.321687313062804, 0.04032488153981311, 0.19502013815300806, 0.05322567107422011, 0.044984724173056226, 0.025429504391338145, 0.02883122435637883, 0.04509370028972626, 0.038200921046414545, 0.039843430410006216, 0.013562301805775081, 0.009906952236113804, 0.1066608534061483, 0.19237267092934676, 0.09545051173440047, 0.10046593725149121, 0.06368095933326653, 0.09614569800240652, 0.06383308009909731, 0.0859622647985816, 0.09861875458487443, 0.08547663050038473, 0.18034231290221214, 0.9012411226119313, 0.58658082144601, 0.7497874924114772, 0.2083176196153675, 1.475883581808635, 8.409840754100255, 16.11005677495684, 14.765573399407522, 9.456661564963204, 22.541799238749913, 16.724545036043438, 37.35693761280605, 47.833480085645405, 45.42942769186837, 26.46557899883815, 8.999568240983145, 0.5802221883620534, 2.2396425987992967, 3.2142703235149384, 0.08386296566043581, 0.5376374391572816, 31.56815365382603, 60.15343870435442, 50.77317258289882, 58.56611578805106, 50.499496936798096, 64.47905363355363, 44.413865089416504, 33.859318665095735, 26.8971837248121, 25.16039984566825, 33.332520144326345, 17.55070321900504, 19.448888540267944, 33.33606025150844, 52.99331310817173, 4.320315190723964, 0.340465177914926, 0.08347102347761393, 0.10919577881161656, 0.08867912579860006, 0.003344980866781303, 0.3840816260448524, 0.31667734150375637, 0.5128180938107627, 1.5512403781924928, 50.6770407812936, 53.713733604976106, 58.21711819512503, 71.86689254215786, 45.01543664932251, 48.48402949741909, 44.18040909085955, 49.3410724231175, 49.0449332509722, 88.96470696585519, 89.21024240766252, 49.5714225769043, 38.85666111537388, 42.253287996564595, 52.122745513916016, 64.3198356628418, 70.41534437452043, 13.1734162739345, 0.6824289411306381, 0.183610612526536, 0.11161521077156067, 0.15125865994819573, 0.20807087714118616, 0.2068634783583028, 0.15734980095710072, 0.42260216761912617, 1.1738278014319283, 1.5806063967091697, 1.0054488480091095, 0.3508399783500603, 0.2309700905212334, 0.4626103565096855, 3.325136865888323, 4.288397337709155, 5.1447250332151135, 1.8613683368478502, 0.7215204834938049, 0.7390155047178268, 0.7660897576383182, 0.334695214671748, 0.11766606037105833, 0.17366064286657742, 0.11099542331482683, 0.15825394886944974, 0.3843331182641642, 0.2073067788566862, 0.5228476556284087, 1.1196992716618945, 1.0787026200975691, 0.44574726851923124, 0.2457223374928747, 0.8096513801387378, 1.007015666791371, 0.42599348564233097, 0.4567881460700716, 0.16673499877963746, 0.1755719403071063, 0.2828908030475889, 0.2592520814921175, 0.1834427701043231, 0.38559948174016817, 5.281890290124076, 18.767779214041575, 35.48743792942592, 45.56502873556954, 47.32570225851876, 53.07852234159197, 42.59041806629726, 44.021635804857524, 40.42999383381435, 41.68523454666138, 44.23242677961077, 45.93357855933053, 46.728334358760286, 46.873840059552876, 48.95465530667986, 45.15406015941075, 43.31663336072649, 41.40853990827288, 45.24346610477993, 40.6988856451852, 41.886562074933735, 45.692896434238975, 48.51171459470476, 46.79717016220093, 45.05376638684954, 40.279777254377095, 39.230241434914724, 39.94465173993792, 41.38432196208409, 37.89615256445748, 41.05405323845999, 43.941870485033306, 43.973985058920725, 46.64073494502476, 43.1111056464059, 43.07507576261248, 42.741232190813335, 39.27240310396467, 40.06205197743007, 41.16696146556309, 48.604174273354666, 53.96672098977225, 48.67196089880807, 32.58743701662336, 17.950514725276403, 9.751580459730965, 2.123022730861391, 0.198578253654497, 0.4542923042816775, 0.34872718315039364, 0.2423075692994254, 0.10877311256315027, 0.17938449286988803, 0.13922919758728572, 0.09802562676902328, 0.10569191897021872, 0.07514190434345178, 0.15684730506369046, 0.16225377709737845, 0.18373462158654416, 0.17717639064150198, 0.7396126698170389, 0.14974753532026494, 0.1733478789350816, 0.1690783737493413, 0.0849545927984374, 0.20125575283808367, 0.2740049527159759, 0.4193222379045827, 0.485057706279414, 0.6706797001617295, 1.0107193823371614, 0.2466677539050579, 2.546566677945001, 7.090685733727046, 14.054412245750427, 13.824842895780291, 12.051933595112391, 21.906940596444265, 21.153260810034617, 33.516432012830464, 47.39475693021502, 43.3461458342416, 22.532158613204956, 5.586243970053537, 0.2891289283122335, 0.7249483881252152, 4.044742252145495, 0.21190875263086387, 0.5344171662415776, 37.23880781446184, 68.99695301055908, 56.68400859832764, 63.710791315351216, 52.91526746749878, 68.4102679661342, 61.69904463631766, 40.220894745418, 27.811340842928203, 29.92844132014683, 37.716062205178396, 22.690834624426707, 29.692873069218226, 49.26323870250157, 79.16771221160889, 5.294980262007032, 0.4284806421824864, 0.30471642475043026, 0.23757030921322958, 0.23149011975952558, 0.10079502673553568], [0.06949512913290944, 0.19256259288106645, 0.22940259320395334, 0.39257039768355234, 15.134793724332537, 28.516911302294048, 16.81057415689741, 40.70049067905971, 46.82892690386091, 45.894276074000764, 56.50965397698538, 45.43589646475655, 35.25966208321707, 42.91596548897879, 15.481220483779907, 29.697226115635463, 33.43468993050711, 26.035582780838013, 37.06271614347185, 54.74944945744106, 46.15819992337908, 8.181674940245491, 0.47520510639463154, 0.029324298791055168, 0.05808924723948751, 0.05466556988124337, 0.15203997945146902, 0.05939417186060122, 0.17213206631796701, 0.48232245019504, 0.9031942720924104, 0.2651180981525353, 0.6010005591171128, 0.09524744655936956, 0.11470141873828002, 1.3223275244235992, 1.338481217622757, 4.953628727367946, 10.036608593804495, 2.7271518792424883, 1.2977894182716097, 1.0105661962713515, 2.144211696726935, 2.9463197759219577, 1.8545862436294556, 0.24656572937965393, 0.08994006777980498, 0.1298068974699293, 0.15160425140389375, 0.2576194448130471, 0.2203822708023446, 0.7019895857998303, 0.43822378079806057, 0.7103339380451611, 0.22134272355054105, 1.3981537584747588, 1.8206289857625961, 0.6756559131400925, 0.7361160974417413, 0.6084633043834141, 0.4976120154772486, 0.5375451041119439, 0.2281473305608545, 0.010835071942502899, 0.01893333395543907, 0.1809283500271184, 2.719118024621691, 7.333399772644043, 23.297764982495988, 44.47502660751343, 47.543028014046804, 44.82578904288155, 41.30106864656721, 40.72581686292376, 35.060575348990305, 39.506241253444124, 39.68577575683594, 41.49057034083775, 41.92559705461775, 39.33931425639561, 40.26491158349173, 39.89436762673514, 37.74639456612723, 39.33067764554705, 37.38185732705252, 37.88201992852347, 40.55593688147408, 40.848518575940815, 39.483551910945344, 38.90739686148507, 36.317740712847026, 34.703288555145264, 33.686041014535085, 31.973782539367676, 32.567794459206716, 36.65005568095616, 39.92624943596976, 38.62118319102696, 36.78366606576102, 37.38683571134295, 35.40271159580776, 34.850465297698975, 33.83104297092983, 36.39514364515032, 39.51485354559762, 50.316415378025596, 51.183651311056956, 29.487567697252544, 11.188903059278216, 5.114992822919573, 1.2977789959737231, 0.9309034709419522, 0.14621935678379877, 0.11976354782070432, 0.05575002490409783, 0.0559179691065635, 0.09358405188790389, 0.05193263777930822, 0.0117332300869748, 0.016556430874126296, 0.015221849183685012, 0.11260587189878736, 0.2087020639862333, 0.07656747249088117, 0.3514927833208016, 0.6293713024684361, 0.2936739187155451, 0.05298107277069773, 0.010481548412436885, 0.069225859296109, 0.11192414776555129, 4.5792393769536694, 4.003594151565006, 3.4309019105775014, 4.9986890980175565, 1.4162157092775618, 1.1657331500734602, 1.1595116896288735, 5.177258670330048, 15.729724543435232, 21.57831859588623, 14.839651618685041, 7.556053059441703, 22.236366850989207, 14.545204332896642, 41.2432005746024, 46.00007281984602, 47.612892150878906, 38.76877335139683, 16.17125129699707, 6.483264224869864, 10.880622778620038, 2.911574874605451, 0.16524481374238217, 1.091776307140078, 36.13007681710379, 50.41322462899344, 50.377281597682405, 42.93472562517439, 31.44127607345581, 51.902122838156565, 66.37425122942243, 24.53208988053458, 26.237360204969132, 28.931279284613474, 19.642925671168737, 36.37314912251064, 20.439260448728287, 37.126465865543906, 36.792900221688406, 0.5898450634309224, 0.04422418141205396, 0.1214351731219462, 0.11454821910176959, 0.07323475953723703, 0.046720413358083794, 0.08467075481478657, 0.07003393343516759, 0.10149125794747046, 0.883966652410371, 17.749994925090245, 52.45683227266584, 36.53982251031058, 63.70049408503941, 46.18658331462315, 55.12424571173531, 55.919467040470664, 31.70382070541382, 36.05645717893328, 49.034854888916016, 19.92207476070949, 30.115868977137975, 38.6111604145595, 33.358537673950195, 43.24433388028826, 55.90784617832729, 62.42215061187744, 26.58946190561567, 0.43527405336499214, 0.06928331085613795, 0.03752086950199945, 0.05633116979151964, 0.09608207855905805, 0.024323141169069067, 0.0246296405260052, 1.6278499130691801, 0.8435842107449258, 0.5782401061483792, 0.49255758098193575, 0.18296209589711257, 0.2039551687027727, 2.06009333048548, 1.5886508907590593, 5.837624149663108, 10.918406214032855, 2.6737226205212727, 1.9663063287734985, 1.7439593055418559, 3.756231333528246, 3.150742075272969, 1.2400114557572772, 0.22967577140246118, 0.055817243975720236, 0.14825511111744813, 0.0691385521952595, 0.3113484803055014, 0.33585719232048306, 0.7224631586245128, 1.3911269583872385, 2.2929044493607114, 2.0826146134308408, 3.378755245889936, 2.816114442689078, 1.1203830178294862, 1.3705183842352457, 0.5822975284286908, 0.8744465889675277, 0.37424484959670473, 0.35375952454549925, 0.2548049901212965, 0.08575548803699867, 0.17811970359512738, 1.879098619733538, 7.26853095633643, 19.948917388916016, 42.32430553436279, 45.87978560583932, 45.747676031930105, 44.562817096710205, 41.827193192073274, 37.903653144836426, 41.64591121673584, 44.386270318712505, 45.32249838965279, 44.76300164631435, 41.77599539075579, 41.75602279390608, 42.627827167510986, 41.12400770187378, 39.88273286819458, 38.522654260907856, 40.799801281520296, 44.05938189370291, 43.728640692574636, 41.47138289042881, 43.18314109529768, 39.668631076812744, 37.68004969188145, 36.1987840788705, 35.52497557231358, 36.934150150844026, 38.695417744772776, 40.588002817971365, 40.564222608293804, 38.544363907405305, 39.293751444135395, 39.1975154195513, 37.70256880351475, 36.17972864423479, 40.511374609810964, 42.48707403455462, 52.42153194972447, 43.89558506011963, 21.655427966799053, 8.295898982456752, 1.9626934826374054, 2.5497037896088193, 3.293727317026683, 0.7080492834959711, 0.05410561564245394, 0.12616171235484736, 0.05821117998233863, 0.0136376590567774, 0.04088551431362118, 0.09393648297658988, 0.04175458196550608, 0.018386180279776454, 0.04989964169050966, 0.22506828792393208, 0.22220520941274507, 1.3218829482793808, 1.4434792463268553, 0.5280394798942974, 0.01358614637449916, 0.05321019369044474, 0.0621417976383652, 1.506082949893815, 5.937078492982047, 5.145990473883493, 4.027710480349405, 5.317502847739628, 1.9208494765417916, 1.7841533316033227, 0.697903285069125, 19.179982832499913, 19.331715856279644, 26.7989570413317, 18.67030988420759, 17.6998393535614, 22.498331308364868, 26.575992822647095, 48.29611546652657, 52.4428003856114, 51.901289054325645, 53.07153592790876, 48.14811883653913, 27.659875324794225, 26.746505090168544, 2.2893508800438473, 0.606670289167336, 4.309125551155635, 49.83679512568882, 57.73929752622332, 58.90339524405343, 49.654693262917654, 36.39903463636126, 62.264079093933105, 59.09289346422468, 26.8755852494921, 33.27136557442801, 34.65295927865164, 31.769960607801163, 54.5190680367606, 28.778634309768677, 44.83336952754429, 39.9689495904105, 0.4693194936428751, 0.14281003044119903, 0.02941130394382136, 0.09387521126440593, 0.06163140359733786, 0.008577509600270008, 0.21618068697197096, 0.19026324126337255, 0.7228909071002687, 0.7859758277024541, 28.45116397312709, 77.07771492004395, 37.79632084710257, 69.54123319898332, 72.45962251935686, 67.4041132245745, 75.4492586680821, 59.538085392543245, 48.36458996364048, 51.5304775919233, 26.834055866513932, 39.69860560553414, 42.955921104976106, 39.56934479304722, 52.17044142314366, 63.36047009059361, 75.36157240186418, 38.78760296957833, 0.5452874058059284, 0.18272740420486244, 0.21465246326157025, 0.12427313226674284, 0.20565545532320226, 0.17391836403736047, 0.3280477156596524, 1.9278982068811144, 2.413537553378514, 0.9849510107721601, 1.0130113107817513, 0.5524595752358437, 0.28219253623059815, 2.2303734847477505, 1.9964150445801871, 6.826331964560917, 13.404822553907122, 5.601136999470847, 3.1727415919303894, 3.267942552055631, 5.5921733890260965, 3.8234998839242116, 1.6898645396743501, 0.3760174001966204, 0.26929361266749247, 0.2998971976339817, 0.197435926379902, 0.3837213510913508, 0.4615871257015637, 1.0024073826415199, 1.4886671815599715, 2.5357259682246616, 2.1228548884391785, 3.4815484157630374, 2.528547610555376, 0.7453620870198522, 1.8240413112299783, 1.2227561473846436, 1.6741700789758136, 1.1232516467571259, 0.7129890184317316, 0.3412117564252445, 0.14099918332483086, 0.23492521686213358, 2.697375157049724, 9.307376912661962, 27.302532945360454, 46.97870227268764, 49.79497044427054, 46.904168946402415, 45.10655185154506, 45.49459484645298, 40.78272955758231, 44.672424929482595, 45.650074686322895, 48.73699951171875, 46.39659609113421, 44.2603828566415, 45.370951652526855, 46.13513537815639, 43.786401067461284, 44.05761357716152, 40.774693965911865, 43.21440798895699, 45.93860558101109, 48.635472433907644, 45.67159325735909, 44.31011806215559, 40.99971832547869, 41.6951322555542, 38.71420219966343, 36.849771227155415, 36.53776584352766, 42.04609271458217, 44.3921936580113, 43.33827352523804, 40.146225929260254, 42.67420291900635, 40.778484208243235, 39.64065415518624, 39.85756649289812, 41.47211939947945, 45.932247979300364, 55.06025627681187, 54.07069035938808, 31.423308031899587, 11.869345358439855, 6.898225843906403, 2.9763746431895663, 2.5806823330266133, 0.7358432177986417, 0.14134865600083554, 0.16039797025067465, 0.13138816904808792, 0.16406594057168278, 0.11868421573724065, 0.28753635234066416, 0.10775679602686848, 0.17217618466487952, 0.2025285488260644, 0.5393195003271103, 0.29237712972930496, 0.8589489577072007, 1.4182889865977424, 0.810788550547191, 0.16889801914138453, 0.09704382730914013, 0.09665894189051219, 1.0470116691929954, 5.009879606110709, 5.462886520794459, 3.2276649304798672, 5.766265715871539, 3.572857299021312, 3.625665996755872, 2.042821628706796, 19.737514972686768, 23.523772512163433, 29.24033342088972, 21.00054635320391, 26.87839753287179, 34.59623071125576, 34.460594926561626, 56.42291613987514, 56.574664797101704, 57.43704046521868, 63.75687871660505, 44.903139863695415, 21.025613716670446, 28.896093606948853, 5.51057939018522, 0.8276780471205711, 4.177671279226031, 58.21727452959333, 63.724569593157085, 64.91160678863525, 59.140162059238975, 43.01223278045654, 66.25164331708635, 80.97605732509068, 36.70965038027082, 41.259688649858745, 51.55128049850464, 36.66702318191528, 69.16542598179409, 39.74008635112217, 74.81121948787144, 54.13371746880667, 0.5908479924712862, 0.2733235949916499, 0.21752647975725786, 0.16276809307081358, 0.2320226611835616, 0.1944161198501076], [0.06781162946884121, 0.12628030670540674, 0.2859339511820248, 1.03476916040693, 6.182800667626517, 61.18911634172712, 45.44054133551461, 15.110923188073293, 45.10405050005232, 52.479684897831504, 49.278861727033345, 53.114868368421284, 46.105921677180696, 20.760774442127772, 28.9150413445064, 52.28921045575823, 21.03632436479841, 24.53747820854187, 37.80984551565987, 55.62109054837908, 54.94126837594168, 22.497711181640625, 2.959591486624309, 0.31462854572704857, 0.03501308549727712, 0.06567390489258937, 0.06090784099485193, 0.1596088475946869, 0.3858156901385103, 0.4867586578641619, 0.3770197049847671, 0.11385658835726124, 0.7219399267009327, 0.8323369771242142, 0.6051438025065831, 0.9190341021333421, 5.0786585211753845, 16.4569125856672, 21.893561840057373, 12.361979586737496, 4.163807885987418, 2.2030047476291656, 4.371514729091099, 10.411464776311602, 10.971869996615819, 5.743497771876199, 7.747248377118792, 11.215078660420009, 7.446552055222647, 6.798542644296374, 8.98388181413923, 5.899064029966082, 7.421977145331247, 6.259757612432752, 6.039121474538531, 5.563662758895329, 4.133368696485247, 2.8327165118285587, 1.494314655661583, 1.5402775321687971, 0.05615089660776513, 0.1556840789105211, 0.6896165811589786, 0.31678338295647074, 0.07819713718656983, 0.05216987397787826, 0.14693309419921466, 3.4197656852858405, 8.072074924196516, 26.16120273726327, 43.678707463400706, 49.010991300855366, 43.01817349025181, 38.04766845703125, 36.85824108123779, 37.817009108407156, 41.10905170440674, 42.74180541719709, 40.25391953332083, 39.168312140873496, 39.663631847926546, 39.06463459559849, 37.53223718915667, 36.20241103853498, 34.980240276881624, 38.81121989658901, 41.30120413643973, 38.24075542177473, 38.975114004952566, 40.55935192108154, 38.47634104319981, 35.100895745413645, 31.277277742113384, 33.40769270488194, 34.586485862731934, 34.73636545453753, 33.88529797962734, 35.90124831880842, 37.71603788648333, 36.20129585266113, 34.65660013471331, 33.54021222250802, 35.461086886269705, 37.596702575683594, 42.46209526062012, 49.90052400316511, 25.597629138401576, 12.09970246042524, 5.312537491321564, 0.4678950586489269, 0.8428919964603016, 1.296992763876915, 0.22396435216069221, 0.062097373950694285, 0.11238355668527739, 0.08092159099344697, 0.02195681644869702, 0.11640137966190066, 0.01754445250013045, 0.14454826073987143, 0.06420151782887322, 0.05729339351611478, 0.09399394132196903, 0.5812142065593174, 2.5909350514411926, 3.7874100719179427, 2.362327592713492, 0.9443662571055549, 1.0868490572486604, 6.078493441854205, 12.102321931294032, 18.5774176801954, 21.720126117978776, 11.714764441762652, 8.907564537865774, 2.867501365286963, 2.9137299018246785, 3.2870388073580603, 17.74478725024632, 14.652988263538905, 18.342990670885357, 14.085074646132332, 13.16733660016741, 13.866854310035706, 18.03896008219038, 30.488344533102854, 39.1228153364999, 42.654949460710796, 48.73541532244001, 59.52115263257708, 46.970454760960166, 26.341815948486328, 0.9640596232243946, 0.29223376885056496, 9.37120132786887, 53.05923066820417, 50.79563610894339, 47.69926520756313, 28.704333748136246, 34.963710512433735, 42.50431946345738, 90.4163315636771, 44.90790980202811, 32.966780866895405, 61.122135707310264, 61.19235420227051, 27.97559973171779, 18.731563465935842, 35.426887852805, 11.270106656210762, 0.5968793545450483, 0.2814893296786717, 0.0996125844706382, 0.039675326751811166, 0.013359151813866836, 0.04515342494206769, 0.07004118697451693, 0.010033060513835932, 0.17967985916350568, 0.3128012509218284, 10.513175981385366, 60.206898144313264, 48.75773293631417, 36.59703745160784, 72.29768085479736, 61.41314710889544, 62.54882322038923, 52.8229398046221, 55.13819422040667, 30.265932696206228, 29.190136160169327, 52.40585681370327, 25.036152158464702, 31.537484305245535, 46.74735505240304, 59.367951801845, 65.8960553577968, 49.90116671153477, 5.073209830692836, 0.29388339604650227, 0.09714477296386446, 0.03498447846089091, 0.17267308942973614, 0.23082681106669561, 0.8570034078189305, 1.4495546860354287, 0.46556323234524044, 0.13091062967266354, 0.39293344105993, 0.5947503287877355, 1.342167996934482, 0.8065069945795196, 8.699315735271998, 20.80955948148455, 23.71546983718872, 14.442661081041608, 4.168800166675022, 2.332343727350235, 4.246783707823072, 13.099992922374181, 12.872515848704747, 5.6664270503180365, 8.384537151881627, 13.207927976335798, 10.214648365974426, 7.548674941062927, 10.526728442737035, 8.374532614435468, 11.83342056615012, 9.183239528111049, 7.6431591510772705, 7.599129285131182, 5.77252083165305, 3.9798143761498586, 2.8437202870845795, 3.544121720961162, 1.147993421980313, 0.38599251636437004, 0.4323771430977753, 0.1474986667079585, 0.5265839951378959, 0.09493496082723141, 0.24848036521247455, 3.143814504146576, 7.983424595424107, 22.52641592706953, 43.596419947487966, 48.29669911520821, 45.46473148890904, 42.815442425864084, 39.92549555642264, 41.59303542545864, 43.15526492255074, 45.96762820652553, 44.30814477375576, 43.40987818581717, 41.771138599940706, 41.114870820726665, 39.11862904684884, 36.692408425467356, 36.26432296207973, 40.69456386566162, 43.23629828861782, 41.268881116594585, 42.384504726954866, 42.22447381700788, 40.171267236982075, 38.8743234361921, 34.501558031354634, 37.79702261516026, 37.508714062826975, 37.79150921957833, 38.05459581102644, 37.9587037222726, 40.068242822374614, 38.945330551692415, 37.68195002419608, 35.858530793871196, 37.434340545109336, 41.96927343096052, 46.65527752467564, 46.585402965545654, 20.961172648838588, 7.762279067720685, 2.285639456340245, 2.314022413321904, 3.0473619997501373, 3.564609787293843, 0.9692061756338392, 0.16861612855323724, 0.1620889880827495, 0.0812972415504711, 0.01241540374966072, 0.17311018811804907, 0.2041416165551969, 0.23843378573656082, 0.009331039701854544, 0.022920336175177778, 0.06584660562553576, 1.1224267653056552, 2.8861913681030273, 6.428198882511683, 2.4774375302450995, 0.8458640341247831, 1.4170188776084354, 10.094685980251857, 15.09799780164446, 20.662799630846294, 27.30198230062212, 15.995764119284493, 12.22991865021842, 5.144798857825143, 1.524594253727368, 18.148578337260656, 24.48072532245091, 23.574108736855642, 26.29339221545628, 27.304900544030325, 26.599858147757395, 27.135274171829224, 33.590239252362935, 39.95510877881731, 46.0687210219247, 51.804184504917686, 56.18971375056675, 67.55194309779576, 60.98524924686977, 29.529656410217285, 1.304432981780597, 0.36768433877399986, 17.13605557169233, 64.82435131072998, 59.20455796377999, 53.55865328652518, 32.98273740495954, 49.87846694673811, 47.367665903908865, 87.34274727957589, 34.45714167186192, 41.90005200249808, 70.73141098022461, 74.5755921772548, 34.464763845716206, 29.717247349875315, 41.337379932403564, 9.980407220976693, 0.771147720515728, 0.2440566425876958, 0.17209417692252568, 0.10000456058021102, 0.11878225047673498, 0.026482524583116174, 0.22854411069835934, 0.30282412629042355, 0.37050137189882143, 1.0014016308954783, 6.780543770108904, 92.21167659759521, 70.30258900778634, 30.29045636313302, 69.79486329214913, 65.70661967141288, 68.32069178989956, 67.89943640572685, 64.02926199776786, 34.84164455958775, 39.55732440948486, 60.908624512808665, 31.251520769936697, 36.14088126591274, 56.12615510395595, 68.50398526872907, 76.44977147238595, 62.01651477813721, 5.039036418710436, 0.4478593037596771, 0.23467695446951048, 0.13798320373254164, 0.18439639679023198, 0.4647381880453655, 0.9403387989316667, 2.5201500611645833, 1.0984325728246143, 0.4531682160283838, 1.1322167771203178, 1.2565617391041346, 1.7493187550987517, 2.29888293998582, 10.916135021618434, 21.615571362631663, 25.42083396230425, 19.489561557769775, 5.439954859869821, 6.1183856555393765, 8.0065256186894, 13.481806857245308, 11.929099866322108, 6.68684948342187, 9.138083185468401, 14.367712599890572, 11.53867711339678, 8.641195791108267, 11.39486677306039, 8.261443734169006, 10.96776100567409, 7.895923324993678, 7.530412469591413, 8.278326988220215, 5.527607253619602, 3.6049664446285794, 2.8458796569279263, 3.9517770920481, 1.3777704579489571, 0.24670843886477606, 0.6778712485517774, 0.6389175845044, 0.3770935024533953, 0.26533957198262215, 0.7999763392976352, 4.295654731137412, 9.976031592914037, 29.53338759286063, 46.6745205606733, 49.69621917179653, 45.83888503483364, 45.69112811769758, 43.460005964551655, 44.965173380715505, 46.08846432822091, 49.004206384931294, 45.42373364312308, 46.18513808931623, 43.877418994903564, 42.58829886572701, 42.576622417994905, 42.5674785886492, 40.951737540108816, 44.70655795506069, 47.36699192864554, 44.88709994724819, 46.1967658996582, 45.16708108357021, 42.08599621909005, 40.14989110401699, 35.93273755482265, 39.715316023145405, 39.0822309085301, 40.92735283715384, 40.33367443084717, 41.88607917513166, 43.116379329136436, 42.637763091496055, 40.232331480298726, 40.21058709280831, 39.73426376070295, 46.22559397561209, 48.11265870503017, 53.82946974890572, 26.832056522369385, 14.38827405657087, 7.1612924592835565, 3.570953058344977, 2.431406148842403, 2.9218204276902333, 1.3163386115006037, 0.25808977814657347, 0.2523181049951485, 0.21806382520922593, 0.16867640960429395, 0.2697295035634722, 0.22288060959960732, 0.2801303597433226, 0.10547852649220399, 0.11667723128838198, 0.15543971130890505, 1.224844298192433, 3.952099314757756, 6.946972668170929, 3.2632401415279935, 1.2943498428378786, 1.2382408593382155, 8.64483664716993, 15.824326004300799, 24.9791248185294, 26.63210473741804, 14.357894795281545, 18.767497811998638, 11.362250191824776, 5.854097459997449, 20.252517189298356, 34.078923429761616, 32.42734704698835, 34.640570640563965, 37.55997787203108, 36.710706506456646, 34.05982630593436, 42.872851916721885, 48.16184500285557, 54.80830069950649, 60.90471962520054, 62.26782417297363, 77.63203525543213, 69.75040176936558, 35.78065538406372, 1.4490610382386615, 1.050399893096515, 17.783374071121216, 75.00986153738839, 62.381559235709055, 64.72158745356968, 41.867207867758616, 47.24741690499442, 52.31348051343645, 103.9365463256836, 59.3728016444615, 45.041534083230154, 93.56805528913225, 97.37828758784703, 49.271941321236746, 43.62616865975516, 74.63315800258091, 14.45044914313725, 1.1464394139392036, 0.4988144338130951, 0.20370481642229216, 0.20359665794031961, 0.2115783467888832, 0.16662761382758617], [0.03014903775017176, 0.042721460440329144, 0.0558009964546987, 0.1298584389899458, 0.23147166360701832, 39.305156912122456, 77.4382152557373, 29.248928342546733, 14.351144620350428, 27.63509978566851, 50.7682671546936, 50.54767574582781, 32.001735142299104, 32.40178462437221, 30.470974036625453, 50.85039833613804, 18.938336644853862, 22.342669078281947, 42.93746321541922, 50.749531337193076, 62.209626061575754, 49.128238677978516, 10.892791679927281, 0.30373051336833407, 0.20401813675250324, 0.04567573066534741, 0.8028692326375416, 0.36013748230678694, 0.16554583901805536, 2.55050066113472, 1.6800967838082994, 0.04227721677826984, 0.47956841226134983, 0.9670447430440358, 4.016152586255755, 2.7720630807535986, 11.178851621491567, 19.14878715787615, 24.25325867107936, 25.562521627971105, 16.409593616213115, 4.379302356924329, 6.474546841212681, 12.491787569863455, 24.007853507995605, 25.81603012766157, 17.742676734924316, 17.84861591884068, 28.437974555151804, 25.648272820881434, 15.8939208984375, 19.96593873841422, 27.97925101007734, 33.826186180114746, 26.599576745714458, 12.56562520776476, 7.738844530923026, 6.5643153956958225, 3.5045215487480164, 1.8238988731588637, 0.13971379372690404, 0.11487680646990027, 0.28358551434108187, 0.49947836675814217, 0.5516868052738053, 0.16329979311142648, 0.1764456627092191, 1.5345435312816074, 5.629003618444715, 10.391294155802045, 28.847471850258962, 45.712559836251394, 44.470993178231375, 41.23446321487427, 37.68629959651402, 35.134903703417095, 39.689684118543354, 39.99314669200352, 41.69772393362862, 42.49911526271275, 41.62569195883614, 39.8916335105896, 36.112327643803184, 35.382891859327046, 35.35060010637556, 38.116136005946565, 40.408131326947895, 37.44367544991629, 38.97889729908535, 39.44728231430054, 39.141651902879985, 35.81297492980957, 33.384895665305, 34.587489877428325, 33.035759108407156, 32.63938174928938, 36.25857332774571, 37.103310993739534, 35.23416566848755, 34.87154960632324, 33.695730277470176, 31.899676527295792, 37.1360057422093, 37.37047617776053, 47.798843315669465, 32.2178692817688, 11.475601366588048, 3.870791929108756, 1.704340134348188, 1.1995970415217536, 2.7196879940373555, 2.3958435314042226, 0.7904852085879871, 0.06095311963664634, 0.0252402864197003, 0.05254777727116432, 0.05268646304362586, 0.023686802546892847, 0.022409713128581643, 0.07462721517575638, 0.23199809821588652, 0.4400087350181171, 0.2941434920898506, 4.4278155480112344, 5.490591594151088, 9.186631117548261, 6.8974654504231045, 1.1561180374452045, 10.861431854111807, 30.222165993281774, 19.3115747656141, 21.461941480636597, 34.474394048963276, 25.390831640788488, 9.652435745511736, 6.4938011680330545, 3.9421538369996205, 16.539286954062327, 13.699296763965062, 12.665780016354152, 16.091911554336548, 17.985667398997716, 17.750241586140223, 19.282896075929912, 25.54633927345276, 31.39867319379534, 38.83583389009748, 47.596761907849995, 54.317288875579834, 61.91140937805176, 57.76400532041277, 23.75408445085798, 2.2269714730126515, 0.06613857245871, 24.303527150835308, 54.98708132335118, 54.56227888379778, 39.5764354297093, 29.544775690351212, 35.900737626211985, 43.93635014125279, 80.6824403490339, 62.76910890851702, 45.7246983391898, 68.59014987945557, 23.303907190050396, 22.23525513921465, 22.31867000034877, 27.29007829938616, 1.361907720565796, 0.1592371461114713, 0.044840019794979265, 0.04820379608177713, 0.02964664702968938, 0.17969860030072077, 0.09275879724217312, 0.04193045145698956, 0.049068385402538946, 0.08467621023633651, 0.11466914761279311, 0.4205772562750748, 54.95809343882969, 63.940853118896484, 31.776092393057688, 35.962889262608115, 49.480206625802175, 50.80082293919155, 48.57904611315046, 40.36348220280239, 47.90776327678135, 34.437040533338276, 54.763661997658865, 19.14140817097255, 30.767801080431255, 52.01095942088536, 57.99192360469273, 68.34769943782261, 64.9858204977853, 26.692371674946376, 0.13508912974170276, 0.17271599998431547, 0.09004484715738467, 2.260628764118467, 0.9764756198440279, 0.36778953884329113, 2.772055698292596, 2.1971482847418105, 0.02455422135868243, 0.5062297359108925, 1.7495072249855315, 5.377000272274017, 4.490560821124485, 13.774207030023847, 24.079086439950125, 31.781678744724818, 30.381561143057688, 23.838317462376185, 5.634690718991416, 8.652241689818245, 15.663258075714111, 26.50060486793518, 27.740938220705303, 20.93889151300703, 22.063902139663696, 33.51256881441389, 32.06495680127825, 23.90835009302412, 29.963432448250906, 31.359794548579625, 37.9679274559021, 33.42146403448922, 24.107547998428345, 15.952190228870936, 10.66060893876212, 5.428355710847037, 3.150540360382625, 0.6944181663649422, 0.9626529387065342, 0.9965635133641106, 0.543890220778329, 0.6376366189547947, 0.5067416227289608, 0.5053031284894262, 1.2680402717420032, 4.0666855318205695, 9.66761495385851, 26.24711373874119, 44.28551796504429, 46.45798689978463, 44.01328754425049, 44.07620695659092, 37.77851261411394, 43.568258898598806, 43.47760575158255, 45.721957274845664, 44.61659267970494, 42.848825045994346, 41.01945468357631, 38.13520186288016, 37.45523377827236, 37.54507398605347, 39.18098218100411, 41.06456586292812, 38.657925265175955, 40.32122673307146, 40.73819160461426, 41.050377641405376, 37.480080536433626, 35.620124203818186, 35.03968906402588, 36.702361719948904, 37.532483850206646, 37.33336932318551, 38.12422718320574, 35.6557754107884, 36.19903768811907, 35.427634784153526, 35.00227648871285, 39.67348091942923, 40.41891840526036, 46.09506164278303, 26.044966323035105, 8.727285708699908, 3.047041731221335, 1.9939343205520084, 2.4148629222597395, 4.296485475131443, 2.951074080807822, 1.9249717124870844, 0.16820484133703367, 0.345259353518486, 0.042345884522157054, 0.07313420064747334, 0.030560939040567194, 0.02768489542151136, 0.0640190461916583, 0.1368662400969437, 0.6297031875167574, 1.1340369880199432, 10.836516482489449, 10.869063581739153, 9.947054130690438, 12.365098459380013, 6.352975947516305, 19.310631547655376, 38.027417932237896, 22.8224995136261, 27.929243087768555, 41.108283928462434, 31.267400877816335, 12.454315066337585, 6.4439378551074435, 16.478596176419938, 23.738694190979004, 25.49547324861799, 27.65023991039821, 31.124219349452428, 32.67819438661848, 31.683945383344376, 33.89664091382708, 37.12250886644636, 42.00288534164429, 51.19579676219395, 54.66997248785836, 58.486795152936665, 61.93192046029227, 57.413600717272075, 26.3179349899292, 2.464176676103047, 0.0793822460940906, 35.378233092171804, 61.20395769391741, 60.53379004342215, 49.29356064115252, 40.07815442766462, 48.72455528804234, 45.687890257154194, 81.43660477229527, 53.81809207371303, 47.875419412340435, 72.68606431143624, 35.9440735408238, 30.623646804264613, 32.28072963442121, 30.989330496106827, 0.9470761631216321, 0.12813050885285648, 0.047405187506228685, 0.0187297971985702, 0.04917512574632253, 0.08703633145030056, 0.07073452762727227, 0.2537103502878121, 0.0956925791023033, 0.15362382946269854, 0.18901518466217176, 0.2571254170366696, 53.759772368839805, 108.38815988813127, 48.6864652633667, 29.71083763667515, 43.07170588629586, 70.33279977525983, 62.037512234279085, 44.85959897722517, 48.341445514133994, 39.7494455746242, 59.02331420353481, 26.355750560760498, 35.93780973979405, 59.91087014334542, 68.071168082101, 78.04375076293945, 77.34036377498082, 28.160993303571427, 0.35318149413381306, 0.3301209386970316, 0.19071818542267593, 1.8315140988145555, 1.8217023738792963, 1.7280826717615128, 5.052416912146977, 2.942970309938703, 0.12402485630341939, 0.7176337263413838, 2.454669803380966, 6.883436168943133, 9.604895302227565, 19.16964738709586, 27.965788875307354, 32.79050159454346, 31.754195145198278, 25.507957424436295, 12.870495659964424, 10.577399049486433, 18.64569762774876, 28.218640770230973, 28.363371746880667, 24.882956538881572, 25.376275164740427, 41.05494955607823, 37.79861375263759, 32.962646688733784, 40.407290594918386, 37.26795550755092, 40.593054158346995, 32.18608822141375, 22.030175583703176, 16.12133370126997, 10.037821054458618, 5.271111897059849, 2.4431444789682115, 0.6817669080836433, 1.226372901882444, 0.845744503395898, 1.7410841626780373, 1.7817108226673943, 0.6273992082902363, 0.2908644580415317, 3.5035123229026794, 7.616253989083426, 11.590944068772451, 31.102395057678223, 47.16386134283883, 47.575656754629954, 45.82013879503523, 45.33296585083008, 40.100607531411306, 45.84850828988211, 45.91832378932408, 48.950955390930176, 47.68123115812029, 45.30139323643276, 44.94367218017578, 41.18044444492885, 41.863605226789204, 41.841645445142476, 43.59306744166783, 45.959328583308626, 42.195833342415945, 44.36691263743809, 45.4713704926627, 44.330455439431326, 42.29541492462158, 37.06887919562203, 37.77970770427159, 40.55288314819336, 38.701580796922954, 42.57183163506644, 43.76624434334891, 40.82550614220755, 39.63070433480399, 39.424617290496826, 36.55088056836809, 43.58585868562971, 42.26201145989554, 50.58526202610561, 34.223842007773264, 13.32217460019248, 5.755408721310752, 3.5840234884193967, 3.618233595575605, 4.582348261560712, 4.619130287851606, 2.083352208137512, 0.23693826741405896, 0.433296232351235, 0.16050348244607449, 0.20422620273062161, 0.11743535846471786, 0.10077439927096878, 0.11755235147263322, 0.6944811886974743, 0.7769378498196602, 1.125956450189863, 10.234316979135786, 11.537829433168683, 10.847900237355914, 11.42318502494267, 6.116583032267434, 14.560201151030403, 40.99034520557949, 26.024257217134746, 32.967149121420725, 43.947769505637034, 36.073845045907156, 25.081664596285137, 15.365232467651367, 25.659402097974503, 38.72066749845232, 35.698312282562256, 37.41619879858834, 37.82852227347237, 41.22402007239205, 40.107816287449424, 45.11246476854597, 45.58998319080898, 49.4793415750776, 56.506318841661724, 61.827482087271555, 63.60746465410505, 66.48676340920585, 60.06077057974679, 27.60430884361267, 3.134715620960508, 0.13070895549442085, 36.30750254222325, 70.88893359048026, 64.4647125516619, 60.27089105333601, 46.20167480196272, 44.003337723868235, 56.70108379636492, 93.76450865609306, 77.66847160884312, 61.834298270089285, 87.77398027692522, 35.847827093941824, 42.80540227890015, 52.99867711748396, 57.545376777648926, 1.6364398407084602, 0.3598037516432149, 0.2663831045585019, 0.26183909124561716, 0.18463495613208838, 0.23308261430689267, 0.1168467021946396], [0.016674609621986747, 0.09522037301212549, 0.11493442766368389, 0.2665578951793057, 0.8638865756137031, 7.066965452262333, 79.81688935416085, 51.721914359501426, 36.2274558203561, 20.020374400275095, 50.492798873356406, 61.48956339699881, 41.510393551417756, 31.7996780531747, 42.697851112910676, 55.253186907087056, 36.040358202798025, 36.411200932094026, 34.99109336308071, 52.308345794677734, 57.95240225110735, 62.04422419411795, 39.1387232371739, 0.32489320635795593, 0.1606316848524979, 0.04616873385384679, 3.2366053078855788, 0.9812223251376833, 3.955485693046025, 7.172563740185328, 3.502499188695635, 0.6673370738114629, 2.1010542639664243, 4.547678487641471, 5.510874688625336, 3.9043135132108415, 11.070629954338074, 30.85973617008754, 43.40438216073172, 32.61982257025582, 30.63853679384504, 13.358396427971975, 6.817123430115836, 13.239861028535024, 32.89288330078125, 39.01894671576363, 18.08272157396589, 22.623895679201397, 33.382581915174214, 38.34380415507725, 33.085640226091655, 30.215995992933, 25.51293580872672, 32.88151952198574, 44.84653983797346, 53.15340655190604, 46.13999216897147, 32.61055367333548, 16.83229422569275, 2.318062356540135, 0.6095214933156967, 0.8625650065285819, 0.7290182411670685, 0.9598909212010247, 0.6046100397195134, 0.8836148998567036, 0.6738969875233514, 0.4710797220468521, 1.4455006292888095, 5.659714221954346, 14.2412770986557, 33.34829255512783, 43.5519688470023, 39.894159180777415, 40.909874643598286, 35.55005162102835, 39.03082466125488, 41.262707642146516, 41.69671297073364, 42.2326831136431, 41.98144667489188, 37.96405383518764, 33.93092679977417, 34.845052650996614, 36.27722576686314, 38.109260763440815, 36.043342454092844, 35.96708944865635, 37.65670721871512, 37.19277252469744, 34.88205180849348, 34.07329191480364, 34.26337030955723, 32.36225284848894, 33.455923625401084, 32.76230580466134, 30.63716105052403, 32.62759760447911, 36.0403790473938, 32.06971979141235, 32.0196475982666, 33.141017368861604, 35.699733189174104, 43.08901732308524, 36.21035977772304, 12.985926083156041, 3.4158898932593207, 2.013922333717346, 1.7278956132275718, 2.638679163796561, 5.8082762616021295, 7.920582481792994, 1.7601955085992813, 0.38333749026060104, 0.016271301977602497, 0.09085558115371636, 0.05519476952031255, 0.11152799866561379, 0.026902717571439486, 0.047125648041921, 0.09665139658110482, 0.4278490889285292, 3.23709146465574, 8.754294225147792, 17.102200474057877, 15.249946219580513, 18.17771213395255, 26.960540873663767, 43.9350334576198, 45.21602766854422, 36.23685673304966, 42.25277382986886, 36.012044293539866, 21.967699119022914, 10.560298664229256, 7.012562794344766, 7.265391673360552, 11.79484156199864, 16.47971657344273, 18.82981273106166, 21.780023063932145, 22.261215346200125, 23.28043791225978, 24.532310485839844, 27.911801372255596, 33.89915268761771, 42.7892164502825, 48.25533996309553, 55.46565934589931, 59.470555850437705, 61.29616723741804, 31.07232325417655, 1.9399489888123103, 1.2636714833123344, 41.873381342206685, 58.793829100472585, 45.34594161169869, 44.860314641680034, 30.48796238218035, 29.339400836399623, 52.069525786808555, 71.20468752724784, 57.40421717507498, 42.516794954027446, 24.51287463733128, 24.926619018827164, 32.25034168788365, 24.136584520339966, 11.13656314781734, 0.40223249207649914, 0.17081688903272152, 0.06759755167045764, 0.0831669040822557, 0.11915511904018265, 0.08006142572100673, 0.12953773619873182, 0.04725094631846462, 0.03048958090533103, 0.13703609098281178, 0.11627946048974991, 1.10482719540596, 12.732165711266653, 83.92157241276333, 40.41807072503226, 29.480699402945383, 37.3399145262582, 67.97080830165318, 62.64531980242048, 34.90623153959002, 41.55603974206107, 49.937582220349995, 64.6242015021188, 33.739173889160156, 40.49930558885847, 48.12298025403704, 56.15365954807827, 66.04806109837124, 68.3738455091204, 52.379255635397776, 0.826002119907311, 0.09979917481541634, 0.19946777235184396, 4.870645957333701, 3.561975985765457, 6.802494432244982, 8.460780603545052, 4.613763238702502, 0.9590484521218708, 2.6113206318446567, 5.049165155206408, 7.084081905228751, 5.947956332138606, 22.108004093170166, 44.199339457920615, 50.489265714372905, 38.49987806592669, 38.066324370247976, 20.014485801969254, 7.786964280264718, 17.029499735151017, 39.26435014179775, 45.661330768040244, 24.812406267438615, 29.377706255231583, 41.015202386038645, 45.44496038981846, 43.669942310878206, 42.3247606413705, 31.749435629163468, 35.94635602406093, 48.76396199635097, 55.04221875326974, 52.050918510981965, 41.144230433872764, 22.927254029682704, 11.943470478057861, 0.8356438311082977, 1.4538466100181853, 2.058885646717889, 0.19672024835433277, 0.12148102851850645, 0.9475268189396177, 0.9668420510632652, 1.1080172870840346, 0.8647885929260934, 4.985448002815247, 13.209352357046944, 29.01539591380528, 44.304729734148296, 42.89483949116298, 42.27498027256557, 40.838304724012104, 40.35056897572109, 43.64145817075457, 45.57491602216448, 44.193947655814036, 43.24057143075125, 40.91297354016985, 38.14499534879412, 37.6663304737636, 37.16809947150094, 42.41448967797415, 39.774973256247385, 39.498664242880686, 39.652184690747944, 39.76623937061855, 37.20055798121861, 36.34985181263515, 37.59981189455305, 35.98497758592878, 36.46135302952358, 35.46779537200928, 34.62403392791748, 39.105496951511924, 37.58150339126587, 33.75459541593279, 34.48936741692679, 37.885309900556294, 40.15932675770351, 44.30204772949219, 28.48933563913618, 8.766222545078822, 3.5288765047277724, 1.6762950335230147, 3.1868670625346045, 2.586638459137508, 5.099149627344949, 5.340157014983041, 3.7551113707678656, 0.5367413929530552, 0.18159932616565908, 0.07574164787573473, 0.012669548192726714, 0.02085553715005517, 0.08942151774785348, 0.018829674160640155, 0.243282108434609, 1.7586738531078612, 7.886366946356637, 11.191813485963003, 21.627956526620046, 18.158479520252772, 22.332715783800396, 37.89019448416573, 50.97616767883301, 52.953944614955354, 47.187193393707275, 53.05883462088448, 43.66621460233416, 29.707401752471924, 21.5241573878697, 17.647995369774954, 20.714018276759557, 24.763525690351212, 28.920773608343943, 31.219371455056326, 34.18478965759277, 34.543764863695415, 35.59598616191319, 34.99444586890084, 39.13102463313511, 41.666787079402376, 47.29669352940151, 54.63734374727522, 59.45658997126988, 65.27727658408028, 65.43924604143415, 33.84852463858468, 1.616241535970143, 3.0882421604224612, 54.58494390760149, 64.50210080827985, 54.286814076559885, 52.943887097494944, 50.69927154268537, 37.15917451041085, 50.643428870609824, 80.38917773110526, 52.90692962918963, 46.50754145213536, 30.581241948263987, 35.31700209208897, 38.1641445841108, 39.71653890609741, 10.152798976216998, 0.5261802939432008, 0.33032816329172676, 0.04412086767011455, 0.09308554578040328, 0.10067898367664643, 0.06007956008293799, 0.057661078072019985, 0.2797041040446077, 0.15071398631802627, 0.39896857578839573, 0.3051311453538281, 1.3448681320462907, 8.56577570097787, 96.78274359021867, 73.11707496643066, 54.09663840702602, 33.275986126491, 62.151650292532786, 79.32000977652413, 56.82146481105259, 48.97510038103376, 48.132641724177766, 67.83573532104492, 43.29031011036464, 49.51301601954869, 50.31571013586861, 68.18343012673515, 73.66255719321114, 78.55069828033447, 55.59324564252581, 0.9347013128655297, 0.17184188403189182, 0.22210034861096314, 5.314585472856249, 5.721919272627149, 10.207788756915502, 8.539372546332222, 5.924165265900748, 2.21278064591544, 3.995869057519095, 8.261323877743312, 8.226033977099828, 16.39438053539821, 28.34726755959647, 45.342189584459575, 50.08800377164568, 41.2991509437561, 38.61393969399588, 27.79759383201599, 10.463150688580104, 24.114004611968994, 42.74285806928362, 47.7716098512922, 33.63779272351946, 35.56571980885097, 41.29737220491682, 44.947326932634624, 45.82849747794015, 48.87027985709054, 43.12149320329939, 48.111470563071116, 58.939317430768696, 64.26123455592564, 56.28339283806937, 43.84705536706107, 26.21423486300877, 12.539606809616089, 0.7781163294400487, 1.9586984855788094, 3.3259619644709995, 1.5278018244675227, 2.464830241033009, 1.3054989874362946, 1.070760611976896, 1.0608418413570948, 2.86188548377582, 6.688405879906245, 15.815262079238892, 35.43879359109061, 45.627444403512136, 42.530764307294575, 44.05862801415579, 40.912678241729736, 42.78809084211077, 47.22628048488072, 47.60606207166399, 46.90716709409441, 47.26840393883841, 43.90018824168614, 39.916848523276194, 40.229097093854634, 39.34922586168562, 45.44300447191511, 42.834334577832905, 42.47142669132778, 44.5675870350429, 44.26557316098894, 41.22556257247925, 38.905354091099326, 40.25321429116385, 39.03344760622297, 39.713231563568115, 40.329498563494, 38.62068292072841, 42.14954791750227, 43.47600071770804, 37.21752200807844, 39.45078420639038, 40.4862881387983, 42.98428017752511, 49.25316034044538, 39.47742359978812, 13.655585646629333, 5.117731715951647, 3.1937486018453325, 5.351459128516061, 4.668483342443194, 8.318988714899335, 12.683170488902501, 5.221355412687574, 0.5774308038609368, 0.28042098986251013, 0.19101796219391481, 0.1595496250582593, 0.2532376285110201, 0.2529791609517166, 0.14652458897658757, 0.4182574264705181, 1.2322328388690948, 8.450693556240626, 14.890404735292707, 23.396929672786168, 18.287347759519303, 21.83000145639692, 36.57801675796509, 49.167607171194895, 54.805167061941965, 48.20042487553188, 54.230387755802695, 46.93005793435233, 37.6330486025129, 28.37426825932094, 25.501955917903356, 31.235449586595806, 34.12291942323957, 38.19416427612305, 39.59037004198347, 41.11166075297764, 43.57297325134277, 42.826476165226524, 42.928420134953086, 45.32756362642561, 47.375315870557515, 55.272829464503694, 61.44574110848563, 64.93132577623639, 71.97445065634591, 69.45128182002476, 41.43915714536394, 2.428212365933827, 2.2136606786932265, 56.48565837315151, 72.9794728415353, 61.319186619349885, 61.62770053318569, 43.77331066131592, 38.80224977220808, 65.05187007359096, 83.4580580847604, 67.8541202545166, 58.261103766305105, 37.14917605263846, 41.61101736341204, 55.99725212369646, 72.9464133126395, 26.541566235678538, 1.0767779690878732, 0.584954671561718, 0.14016055475388253, 0.1492594379399504, 0.18122108360486372, 0.2997459928904261, 0.16521330257611616], [0.04394681325980595, 0.054511637426912785, 0.13286362987543854, 0.1240253991314343, 0.23458711643304142, 0.3532627826290471, 37.531601428985596, 76.98401151384626, 54.32631458554949, 46.88413381576538, 25.762075628553117, 61.771889550345286, 55.96989359174456, 44.29196241923741, 59.736942836216514, 64.83839362008231, 46.943210874285015, 45.81121383394514, 31.368465900421143, 41.92408929552351, 55.50749444961548, 58.82818794250488, 58.415715081351145, 3.7867443476404463, 0.16551348646836622, 0.567148989864758, 6.79297149181366, 4.015988000801631, 1.9324525339262826, 1.68438013110842, 4.791140326431819, 4.915080990110125, 3.715518363884517, 6.497468079839434, 8.400795936584473, 4.867408965315137, 15.776324374335152, 41.71014731270926, 41.8978077343532, 35.4069812638419, 24.846311739512853, 12.998183573995318, 8.31355435507638, 14.135601946285792, 36.141433647700715, 45.9816392489842, 37.28275864464896, 43.619512285505024, 43.455315930502756, 42.86036947795323, 51.693385056086946, 48.075221811022075, 33.99157067707607, 27.039677381515503, 32.97335038866316, 42.7222775050572, 49.506213733128135, 44.97494602203369, 27.59715567316328, 14.17567047051021, 7.989375727517264, 1.8725879405226027, 1.8551853086267198, 0.5934419504233769, 0.43725792691111565, 1.5783304274082184, 0.904092109629086, 0.7428912967443466, 0.8488321091447557, 3.015935948916844, 8.876565149852208, 15.099191154752459, 37.15924399239676, 44.019113608769004, 38.93205949238369, 41.93169409888131, 39.094532694135395, 39.78881059374128, 39.81266375950405, 41.89387157985142, 38.21361575807844, 34.84838431222098, 33.925941467285156, 34.18543931416103, 35.551271029881065, 38.787995542798726, 35.077643598829, 34.478378840855186, 36.59033938816616, 34.678000586373464, 34.46826573780605, 33.78960044043404, 33.876237528664724, 34.461143834250315, 32.315758977617534, 31.5228305544172, 33.159079211098806, 34.677323137010845, 29.797332286834717, 29.162715094430105, 33.596576009477886, 34.88563360486712, 39.09058959143502, 35.702092102595735, 14.868830578667776, 2.9716711470058987, 2.082001652036394, 1.7126179358788898, 1.844683540718896, 2.6385897057397023, 5.03262540272304, 5.157108894416264, 2.149571580546243, 0.12841192446649075, 0.33559172227978706, 0.08667731857193367, 0.11115862455751215, 0.16179366250123295, 0.459490995321955, 0.3636696913412639, 0.8996148641620363, 7.995877504348755, 16.68862806047712, 21.5368743283408, 29.070145981652395, 30.332475594111852, 34.46926975250244, 52.20913594109671, 45.171517508370535, 45.38203055518014, 40.57276541846139, 39.393958364214214, 30.181581565311976, 23.81602590424674, 21.56994949068342, 12.287088428224836, 14.035127520561218, 17.062323025294713, 21.031571796962194, 21.715257167816162, 26.438229152134486, 25.88515428134373, 28.986048460006714, 30.037111146109446, 35.34092126573835, 38.812144007001606, 45.12005567550659, 51.840433256966726, 55.98185838971819, 64.24239798954555, 60.978926386152, 26.76800455365862, 0.5299732504146439, 11.879910962922231, 54.47932781491961, 57.20278889792306, 35.015050751822336, 45.41516998835972, 26.119532653263636, 29.422522136143275, 51.37511239733015, 56.01340321132115, 59.64233616420201, 29.29400478090559, 32.32803297042847, 28.810281617300852, 26.752744572503225, 21.796228000095912, 0.971465425831931, 0.17362100285078796, 0.07694275663899523, 0.09627533211771931, 0.08102307269083601, 0.012478127526784582, 0.08727750993732895, 0.009168068312906792, 0.12192732814167227, 0.03750442859849759, 0.11717359322522368, 0.035730812698602676, 0.21762181392737798, 0.38049784834895817, 52.674884114946636, 71.38094248090471, 43.20896407536098, 41.38404056004116, 44.14679023197719, 90.5751256942749, 55.425564765930176, 48.39950813565935, 62.50861399514334, 71.24192987169538, 53.975249903542654, 45.59482955932617, 50.86438853400094, 46.273387159620015, 65.29845469338554, 63.800853865487234, 74.00867475782121, 6.476775910173144, 0.209278438772474, 0.6413548280085836, 9.068301558494568, 7.524629831314087, 4.124335169792175, 2.34230375289917, 6.402035874979837, 5.312837566648211, 4.768891326018742, 13.467549153736659, 12.474641152790614, 11.66182437964848, 27.435523203441075, 46.802252769470215, 48.22513266972133, 42.454761437007356, 28.963967084884644, 16.60929352896554, 14.280647328921727, 23.658741269792827, 45.38173873083932, 52.690833704812185, 44.97375093187605, 52.274139813014436, 51.2014491217477, 50.14606291907174, 56.33530977794102, 54.86950738089425, 45.22632837295532, 33.77515860966274, 39.657586915152415, 46.74299158368792, 54.49992227554321, 48.19489063535418, 37.11897918156215, 22.20257428714207, 13.737941776003156, 5.059084142957415, 1.8789357713290622, 0.42792948175753864, 0.3484164412532534, 2.0199110295091356, 2.160851546696254, 1.6242064514330454, 1.5893308371305466, 2.9434026181697845, 7.522464598928179, 13.87888251032148, 33.89196130207607, 45.05860928126744, 40.58198915209089, 44.6712715285165, 42.03674391337803, 40.96533863885062, 42.0320017678397, 45.04797853742327, 40.28186518805367, 37.92075613566807, 36.71127625874111, 36.616686957223074, 36.91684913635254, 39.70911823000227, 37.46970687593733, 36.3435845375061, 38.19322279521397, 37.636894430433, 36.31261989048549, 36.0548278263637, 36.14194434029715, 35.94426809038435, 35.44704805101667, 36.88868113926479, 36.71804033006941, 34.88390350341797, 31.070898873465403, 32.5335259437561, 37.34212405341012, 37.44575990949358, 41.46081815447126, 32.03823750359671, 11.651504567691259, 1.8448155564921243, 1.602273594055857, 2.199134818145207, 1.5682653103555952, 1.7142180843012673, 4.073657180581774, 3.099091121128627, 1.9439472428389957, 0.45284634615693775, 0.881548462169511, 0.12190021388232708, 0.15186501241156034, 0.45488832944205826, 0.8766703924962452, 0.5415153482130596, 6.77280912228993, 23.979348523276194, 31.077437128339493, 27.98244023323059, 38.55312211172921, 40.10131972176688, 44.020520618983674, 54.96027169908796, 52.099118164607454, 49.19459397452218, 48.956166539873394, 43.70546497617449, 36.48542158944266, 35.03687504359654, 34.80415207999093, 28.919550725391932, 30.036833218165807, 29.617151600973948, 31.994533334459575, 32.53783730098179, 36.65489510127476, 36.37496607644217, 38.616788455418174, 40.20056431634085, 44.579607418605256, 49.03036635262625, 52.50711638586861, 55.401697703770225, 58.92904799325125, 66.16046905517578, 59.76105308532715, 24.826888050351823, 0.28698774320738657, 20.387067317962646, 62.63653033120291, 63.2934547151838, 41.33296087809971, 48.54191493988037, 31.778854301997594, 22.97962781361171, 51.63194213594709, 57.14066505432129, 58.480423654828755, 34.35524981362479, 42.16505282265799, 33.877773080553325, 35.712406703404014, 37.28699009759085, 1.0467024743556976, 0.1494515719158309, 0.12196041350918156, 0.051780028468264, 0.11712787353566714, 0.017689681046509316, 0.026721014375133172, 0.029093888654772724, 0.2718779354223183, 0.18732907942363194, 0.2890522267137255, 0.19990799230124268, 0.3221002205141953, 0.9080683248383659, 47.79905523572649, 94.23557567596436, 74.22861998421806, 70.14033467429024, 34.7649781363351, 83.52397564479283, 71.75356047494071, 57.767805985042024, 64.46100916181291, 72.87338774544853, 55.905608858381, 58.41257449558803, 48.80218403679984, 56.29840094702584, 75.58774321419853, 71.16280378614152, 79.41800716945103, 5.726429087775094, 0.310883710959128, 0.7493505701422691, 9.849021128245763, 10.01624081815992, 6.466042680399759, 2.555894200290952, 7.969797440937587, 13.333242212023054, 6.357373288699558, 17.032345022474015, 16.417250531060354, 19.955080441066197, 36.57452876227242, 53.170898641858784, 51.51597670146397, 45.11126273018973, 34.84955160958426, 25.32681267602103, 23.987821851457866, 32.96829904828753, 50.09945092882429, 50.956417424338206, 48.08363955361502, 51.917943886348176, 51.6041875566755, 49.70914282117571, 54.1240108353751, 53.073578698294504, 50.55426958629063, 40.378177642822266, 48.56722722734724, 55.38148191996983, 61.47457613263811, 57.18352501732962, 48.57056583677019, 31.97828844615391, 17.79040912219456, 5.377188307898385, 4.259750349181039, 2.762210100889206, 1.261469121490206, 4.313725258622851, 1.915937317269189, 1.9584129580429621, 1.5903395201478685, 5.609060551439013, 10.227339250700814, 17.43885111808777, 38.650455951690674, 45.85957677023751, 41.22752891268049, 46.353649275643484, 43.403614384787424, 43.53317744391305, 44.003448895045686, 47.29532126017979, 41.84212487084525, 40.150721413748606, 38.29220683234078, 37.8667026247297, 39.87214381354195, 44.16094371250698, 42.646827016557964, 39.022243635995046, 42.24439777646746, 40.79521199635097, 39.492136410304475, 39.405631337847026, 40.310297216687886, 39.29311568396432, 40.403885977608816, 40.778887203761506, 42.74931294577462, 41.69228349413191, 35.488150119781494, 36.090805598667686, 41.041074003492085, 40.87544631958008, 47.096116406576975, 38.66443920135498, 18.257043191364833, 3.752832361630031, 3.2643633612564633, 4.105906810079302, 3.032001269715173, 6.851658582687378, 8.983109695570809, 12.146964975765773, 3.5050281158515384, 0.3244577225829874, 1.3252225347927638, 0.16005273163318634, 0.23279401979276113, 0.8835605627724102, 1.0085405792508806, 0.6993526901517595, 4.242174880845206, 20.871891771044048, 27.114499058042252, 29.910011223384313, 38.034536361694336, 36.468738964625764, 40.212143489292686, 54.870765004839214, 53.36064352308001, 51.83042785099575, 49.06502744129726, 47.33724669047764, 43.47161293029785, 42.22374078205654, 39.48998941693987, 39.58063908985683, 38.79119866234915, 38.904634952545166, 39.9860143661499, 41.015921524592805, 41.88235146658761, 43.484022412981304, 43.64672490528652, 45.111749104091096, 48.25997788565499, 54.415988036564414, 53.64382083075387, 61.66985525403704, 59.09689562661307, 68.59823758261544, 62.06385285513741, 32.1985741342817, 0.6298841120941299, 17.138516971043178, 70.09376784733364, 68.09340231759208, 47.92006506238665, 56.12841326849801, 34.12869337626866, 39.45524147578648, 66.51205485207694, 67.4920357295445, 69.87587928771973, 47.86279106140137, 45.150843143463135, 54.109454359327046, 51.40019539424351, 72.46792561667306, 3.621867937701089, 0.2436657521341528, 0.3176843688956329, 0.27889735304883545, 0.4978905405317034, 0.12842408381402493, 0.1555781460234097, 0.15867354135428155], [0.040386621441159926, 0.06403215548821858, 0.06637557795537369, 0.04918116810066359, 0.23695816206080572, 0.1382760458758899, 0.7513913320643562, 69.8888098852975, 56.83746303830828, 55.986902781895225, 35.48024654388428, 30.6504807472229, 67.30672032492501, 50.60644360951015, 68.42111410413469, 74.7183290209089, 52.69393607548305, 55.803275789533345, 28.150465045656475, 33.72102172034127, 46.482656478881836, 54.535142694200786, 68.67017923082624, 16.133373192378453, 0.1942431748445545, 0.783188025866236, 10.368180973189217, 8.967151420457022, 4.342626290661948, 2.5848369215215956, 6.003591426781245, 9.665428008352007, 6.650978973933628, 9.135299563407898, 10.237122314316885, 16.146176985331945, 22.730550527572632, 31.696382658822195, 38.15969426291329, 28.971353019986832, 17.179645095552715, 10.847657918930054, 11.5134516784123, 19.048634086336406, 35.623751163482666, 47.34777668544224, 44.49098661967686, 43.87031446184431, 37.853838035038535, 36.42941910879952, 41.01206527437483, 48.868685245513916, 46.128534589494976, 41.9765864099775, 40.25645215170724, 42.28336327416556, 43.304227352142334, 41.3970684323992, 33.03315700803484, 22.55154061317444, 21.391672611236572, 29.13491014071873, 8.284691538129534, 1.0027604379824229, 0.16364576454673493, 2.490288874932698, 2.252826588494437, 2.2175156261239732, 2.1465936260563985, 2.773352405854634, 4.463333002158573, 9.423371008464269, 18.986294848578318, 39.34398691994803, 40.45328419549124, 41.67170292990548, 40.551986830575125, 38.89106164659773, 37.01524952479771, 39.436561243874685, 37.10001754760742, 36.04833126068115, 35.29001528876168, 34.31859459195818, 33.425910881587434, 35.64913988113403, 32.82672602789742, 30.77572897502354, 33.111056736537385, 32.76928179604666, 33.2426312991551, 34.266906942640034, 30.93645817892892, 32.898118768419536, 32.32527106148856, 31.48521648134504, 30.639613764626638, 28.09226519720895, 29.663322380610875, 30.88925211770194, 32.76714522497994, 35.74104717799595, 34.45419216156006, 18.824676275253296, 3.8238420827048163, 1.289157692875181, 2.5874761513301303, 2.619987641062055, 1.9073747481618608, 1.4785090237855911, 5.158374335084643, 3.8360339999198914, 1.6839390290634972, 0.34544272082192556, 0.07385939173400402, 1.06868277490139, 1.513805438365255, 1.9434074546609605, 2.5388311616012027, 1.3013653521026884, 14.843035391398839, 36.61308084215437, 45.462643555232454, 39.64719935825893, 49.235779421670095, 50.383121558598106, 52.666247504098074, 50.828584466661724, 46.07121195111956, 39.26238032749721, 35.15789181845528, 28.985923392432078, 25.99195851598467, 26.140748977661133, 24.496539422443934, 19.776612486158097, 21.87358750615801, 21.49710283960615, 23.678673914500646, 27.023965767451696, 28.978890078408376, 30.880209037235804, 35.53737115859985, 37.153692381722585, 43.69535187312535, 48.333694798605784, 52.47966752733503, 54.802120276859824, 60.92036002022879, 61.28277111053467, 59.50150312696184, 13.039613076618739, 0.5231300890445709, 29.546783719744, 55.314765317099436, 44.62386049543108, 37.645531041281565, 31.755563940320695, 19.615266629627772, 43.1944249698094, 37.662630558013916, 37.91067082541329, 69.08092893872941, 27.313886301858084, 32.89080578940255, 41.10123150689261, 34.70548071180071, 19.300058126449585, 0.33239066547581125, 0.28014265479786055, 0.06089660445494311, 0.06908080886517252, 0.042853499962283034, 0.024417917244136333, 0.0086263607289376, 0.068979856425098, 0.08436481016022818, 0.059193868323096206, 0.031041436828672886, 0.1151932752025979, 0.09989491610654763, 0.4167254301054137, 1.7283556056874139, 83.30339118412563, 53.74140133176531, 39.168517112731934, 24.847468614578247, 47.30582693644932, 78.01793820517403, 57.405530384608674, 80.92452253614152, 79.00595814841134, 59.14538710457938, 54.16148247037615, 38.262079443250386, 47.57338121959141, 52.37486784798758, 62.81047848292759, 75.02895518711635, 26.86106698853629, 0.25370258784719874, 0.8429118639656475, 11.980971642902919, 12.590041177613394, 5.5469458273478915, 1.8211555289370673, 8.570293767111641, 11.54011104788099, 5.179462117808206, 18.324868031910487, 25.63413323674883, 41.92150803974697, 36.789419174194336, 42.27013390404837, 45.421795095716206, 35.41701446260725, 24.282218762806483, 21.81855951036726, 23.12553824697222, 29.793323176247732, 40.929013456617085, 52.416240896497456, 51.646505560193745, 47.64505883625576, 42.37808459145682, 40.40096773420061, 43.968933718545095, 51.983124937329976, 51.806001458849224, 48.0000353540693, 48.59852538790022, 51.307106903621126, 51.732555525643484, 48.596472195216585, 45.367408071245464, 36.36783722468785, 29.580798625946045, 39.26532636369978, 17.36862220082964, 2.3421719542571475, 1.1030687583344323, 2.5972422787121365, 1.8796566469328744, 2.144613823720387, 2.0351293214729855, 3.861674589770181, 4.133915867124285, 7.970160484313965, 17.069170475006104, 35.65104021344866, 41.18266786847796, 42.382798944200786, 43.63980449948992, 40.880066871643066, 41.86069393157959, 41.17570577348982, 40.110769271850586, 40.92283303397042, 38.77907058170864, 35.80382067816598, 36.4200633593968, 37.27261427470616, 35.07536458969116, 33.11985663005284, 34.951704025268555, 34.74543285369873, 35.48106295721871, 34.889225823538645, 34.619166714804514, 37.06549194880894, 35.485464641026084, 33.942738737378804, 34.38539457321167, 33.5389198575701, 34.09983055932181, 34.088053362710134, 36.83227913720267, 39.05384404318673, 33.685439995356965, 15.219811882291522, 3.5576544233730862, 2.0300523596150533, 2.401479388986315, 3.3963205090590884, 1.4050098934343882, 1.3027828931808472, 2.531782648393086, 1.9350209789616721, 1.8984806197030204, 1.3187796005180903, 0.2629116108374936, 3.2532966179507117, 4.4783428481646945, 7.6491215739931375, 9.578440036092486, 18.249778849737986, 33.631723472050254, 47.00312519073486, 52.204251357487266, 53.28930984224592, 58.74865886143276, 55.38566473552159, 55.49547406605312, 54.30976397650582, 50.91543000085013, 47.55366918018886, 42.26722608293806, 38.11735541479928, 36.805142947605674, 37.6103766305106, 34.2493314743042, 33.546257155282156, 32.97203023093087, 33.086908272334504, 34.0066864831107, 35.85430976322719, 38.92215830939156, 40.13498374394008, 45.947033745901926, 45.031004088265554, 50.71762868336269, 54.205846718379426, 59.638236727033345, 59.22796644483294, 63.452255793980186, 63.41701453072684, 58.71149294716971, 9.319400770323616, 1.9497405205454146, 39.21632766723633, 61.481121335710796, 48.88833475112915, 41.01324299403599, 39.28069577898298, 17.00616247313363, 27.732075793402537, 43.367737361363, 38.68012128557478, 68.78207302093506, 26.71207676615034, 41.953181403023855, 41.849284989493235, 48.14389780589512, 28.582860129220144, 0.45335071480699946, 0.203737630375794, 0.037402563528823, 0.07843790176723685, 0.04483531076194985, 0.07426086054848773, 0.013236835698730178, 0.051432591397315264, 0.15569895239812986, 0.13856115272002562, 0.11948080227843352, 0.16885210946202278, 0.3244495801627636, 0.27671035325952936, 1.0309932487351554, 94.34954002925328, 72.82039383479527, 78.98443957737514, 47.56936863490513, 41.39862482888358, 86.79124096461705, 59.71103995186942, 78.13105487823486, 74.63530499594552, 61.716825076511924, 67.86162430899483, 40.96233354296003, 46.33409357070923, 67.48099504198346, 67.89057745252336, 87.76473222460065, 25.627556766782487, 0.31153043625610216, 1.2988613950354713, 12.863363334110804, 17.246834175927297, 7.796702180589948, 2.878585696220398, 10.505973305021014, 20.58684539794922, 11.70960714135851, 25.61900179726737, 31.738394941602433, 46.81481858662197, 44.294977937425884, 45.528297083718435, 50.349662508283345, 41.62296479088919, 31.684852123260498, 31.307259219033376, 32.137808663504465, 38.372072901044575, 45.79391629355294, 49.444274016789024, 49.55408334732056, 44.33214037758963, 42.833132539476665, 42.37534005301339, 45.117210388183594, 50.790084498269216, 51.37792294366019, 51.24463217599051, 53.639429569244385, 56.980390957423616, 55.9385780606951, 53.819464342934744, 52.23528896059309, 49.063245228358674, 40.40679727281843, 40.01894882747105, 17.190418277467998, 2.8071966469287872, 2.6286377140453885, 6.324933886528015, 4.167704522609711, 2.745134251458304, 3.5097498510565077, 4.3178668192454746, 6.975643975394113, 10.741491181509835, 22.112027100154332, 39.62035846710205, 40.88449287414551, 44.03181144169399, 43.103483472551616, 42.8395596231733, 42.70897517885481, 43.54542711802891, 42.20573105130877, 42.34603255135672, 40.27224888120379, 38.984098025730674, 38.92135231835501, 41.57802731650216, 40.47700187138149, 36.07008259637015, 40.36638307571411, 38.174917766026084, 38.298050267355784, 39.14761693137032, 37.36780112130301, 40.74936778204781, 40.113281045641216, 39.43029049464634, 39.54783664430891, 38.10434838703701, 38.662160192217144, 37.40421315601894, 41.57821839196341, 43.60856192452567, 39.893686703273225, 22.19657278060913, 5.523560796465192, 2.5042936205863953, 4.780030591147287, 5.501161106995173, 4.030231373650687, 5.08218777179718, 9.958721893174307, 7.814731887408665, 5.363856886114393, 1.6964964866638184, 0.18196895133171762, 1.782301093850817, 1.9583369621208735, 3.7750275135040283, 6.85139194556645, 15.611497470310756, 35.35676315852574, 52.425037315913606, 54.84743642807007, 50.79085227421352, 59.67347799028669, 53.77940450395857, 57.22470004217965, 55.869544233594624, 55.31765924181257, 51.49255084991455, 49.840098994118826, 46.555904388427734, 44.015194824763704, 44.416067668369834, 43.985842159816194, 40.919886997767854, 40.76042236600603, 39.39999287469046, 41.109562397003174, 42.22073221206665, 43.7566488810948, 45.05685486112322, 49.67714636666434, 47.967517784663606, 54.60479143687657, 57.07524429048811, 64.46005725860596, 63.24030099596296, 68.23977306910923, 67.90814944675991, 69.64639418465751, 17.127957446234568, 1.2208870819636752, 39.784950869424, 68.507570539202, 54.626177992139546, 52.26745217187064, 42.2439079284668, 30.122778960636683, 57.37806068147932, 53.03825058255877, 44.97909409659249, 82.65200451442173, 40.40491083690098, 51.812237467084614, 65.42316790989467, 65.13314315250942, 55.045863083430696, 0.48661670833826065, 0.44597940891981125, 0.17706477163093431, 0.20762628742626735, 0.22568111361137458, 0.15538583562842437, 0.10609420202672482, 0.1420293351901429], [0.03829379552709205, 0.1267786499645029, 0.05042802708755646, 0.052810685842164924, 0.10709985199251346, 0.4596765882202557, 0.7385522552898952, 10.867250101906912, 79.66808673313686, 54.79672500065395, 63.07680293491909, 28.725458008902415, 42.69290746961321, 39.46432971954346, 41.626713344029014, 71.05794157300676, 59.11522497449602, 66.20192895616803, 39.307738167899, 23.967223916734966, 37.94941398075649, 44.03493465696062, 60.1797445842198, 42.02636677878243, 1.0198032834700175, 1.6063901845897948, 7.3678150687898905, 10.812739746911184, 9.637710775647845, 6.388522931507655, 13.997013177190508, 12.041583384786334, 6.93900351864951, 15.490329572132655, 36.79878534589495, 43.57758685520717, 39.8501284463065, 36.7828357560294, 32.89159093584333, 24.021458080836705, 18.94613078662327, 14.94606328010559, 16.55703091621399, 19.626152719770158, 27.134594985416957, 36.720816135406494, 38.17085654394967, 34.41651555470058, 32.83859702519008, 32.353626659938264, 35.3770102092198, 43.95913675853184, 50.136866978236604, 46.49518755504063, 47.13662093026297, 46.506672927311485, 49.040778228214805, 48.81957190377371, 48.46360526766096, 41.97417538506644, 39.19493416377476, 47.37470095498221, 42.07529599325997, 8.569524254117693, 2.348145450864519, 2.622806655509131, 3.766258452619825, 2.6618907068456923, 2.4460082224437167, 3.3896626148905074, 3.9777403388704573, 3.6239947378635406, 10.087068149021693, 26.43793559074402, 40.50777544294085, 41.69952004296439, 42.08788960320609, 39.24367925098964, 40.276355266571045, 36.85848079408918, 37.27087722505842, 37.55529478618077, 33.5769681930542, 32.725928510938374, 33.091994353703086, 33.05997010639736, 29.43338564464024, 28.519874708993093, 30.799074922289165, 33.319398471287315, 33.5262393951416, 32.816696303231375, 34.15881381716047, 32.854025500161306, 31.15704263959612, 28.408489874431066, 29.83028064455305, 29.90130513054984, 29.565186023712158, 29.709600857325963, 31.902931758335658, 35.6397111756461, 24.10926420348031, 6.633604569094522, 1.466031687600272, 3.191806363207953, 3.4248580634593964, 3.006383044379098, 3.0992696029799323, 1.6673317487750734, 3.9405661736215865, 3.5110469928809573, 2.4821822813579013, 0.1121425274759531, 4.744084519999368, 9.669220856257848, 23.75507456915719, 27.42210102081299, 24.254234892981394, 29.95825604030064, 42.42736121586391, 47.5933746610369, 47.31812524795532, 49.010449341365266, 48.636417388916016, 48.347389698028564, 49.73341982705252, 48.27966560636248, 47.67975466591971, 40.12840379987444, 33.60047047478812, 29.8948016166687, 26.806916202817643, 26.396939482007706, 26.255059003829956, 25.74496395247323, 26.6602623122079, 26.38128171648298, 28.814966440200806, 31.478778975350515, 35.061836447034565, 38.82988623210362, 44.271253313337056, 45.730722427368164, 50.19595793315342, 53.635896410260884, 56.17322220121111, 59.46475410461426, 58.78776332310268, 66.38491671425956, 35.967273575919016, 1.3135097175836563, 5.592991539410182, 36.85861280986241, 56.171356609889436, 36.905002457754954, 38.75603035518101, 33.509091241019114, 40.8764260155814, 33.87809269768851, 29.020655700138636, 27.726022175380162, 51.04651818956648, 38.25040994371687, 27.42379985536848, 27.042748485292705, 50.08562053952898, 9.925757902009146, 0.7582433958138738, 0.26398022206766264, 0.05636220259059753, 0.14138543259884628, 0.04792020915608321, 0.05732973585171359, 0.02788109382215355, 0.3151461050978729, 0.0889516593888402, 0.06554411471422229, 0.012451379676349461, 0.088652852922678, 0.0554648366357599, 0.199044936469623, 0.688841694167682, 14.487020986420767, 91.16615336281913, 49.67917176655361, 43.092970848083496, 23.499462502343313, 58.4198214667184, 46.48702342169625, 50.77722685677664, 73.21972070421491, 58.04324994768415, 72.67598247528076, 34.609126567840576, 36.13789006641933, 46.243117332458496, 53.11737666811262, 68.32105309622628, 56.33127287455967, 3.4386454607759203, 1.9904148408344813, 9.589301807539803, 16.936341762542725, 13.016442571367536, 10.67199616772788, 19.19939262526376, 12.147574680192129, 12.59603921004704, 42.97924273354666, 54.33507973807198, 53.0882637160165, 50.336464405059814, 47.4853058542524, 41.70308446884155, 34.661734853472026, 29.736782210213796, 26.75672936439514, 25.401382480348857, 28.537095819200786, 32.215996742248535, 40.00027206965855, 42.390035493033274, 37.668710231781006, 38.46421643665859, 38.74972833905901, 38.74179697036743, 46.64528948920113, 53.103007793426514, 51.01662703922817, 52.58710404804775, 51.06742531912667, 53.05664941242763, 52.644235610961914, 53.33872890472412, 51.86435243061611, 50.040585790361675, 52.38016932351248, 49.35733468191964, 20.39400335720607, 2.896953042064394, 2.451618241412299, 2.9863418340682983, 3.1511782918657576, 2.7869248432772498, 4.314774870872498, 3.3139341984476363, 2.6109547657626013, 9.3292897939682, 24.443278006144933, 40.272530283246724, 41.46821451187134, 44.679175104413716, 44.02667324883597, 41.372916494097026, 40.39130278996059, 40.733550207955496, 39.07522365025112, 37.46470764705113, 35.05610418319702, 34.480095045907156, 34.17598281587873, 32.945873737335205, 29.930980886731827, 32.57022980281285, 34.32482017789568, 35.88714347566877, 35.73753138950893, 35.370874949863975, 34.88806200027466, 32.978106430598665, 32.852865150996614, 34.03034509931292, 32.734443528311594, 32.369690895080566, 32.64690317426409, 32.55562468937465, 34.93586213248116, 19.58755895069667, 5.303151777812412, 2.2944454295294623, 3.0401669229779924, 2.600820383855275, 0.8835941638265337, 0.9518910476139614, 1.3886539425168718, 0.9921977647713253, 1.6178617690290724, 1.4244621353490012, 2.54738678250994, 7.85903012752533, 19.78674817085266, 36.30543197904314, 42.21538209915161, 48.56861686706543, 49.75623076302664, 50.83373308181763, 52.10260616030012, 50.35490492412022, 49.024564606802805, 50.7334497315543, 51.343157632010325, 56.06060579844883, 53.53709997449602, 53.46270213808332, 48.592681952885215, 44.99835797718593, 40.23783097948347, 38.742133957999094, 36.18030881881714, 38.430152893066406, 37.12074749810355, 37.76882682527815, 35.88601091929844, 37.99782902853829, 40.444282804216655, 45.57680245808193, 48.80439703805106, 51.81134114946638, 51.27151823043823, 57.74206985746111, 58.31949642726353, 60.823224203927175, 62.2269618170602, 62.59098488943917, 65.30404799325126, 23.02059265545436, 0.4122513330408505, 9.669503995350428, 43.864599568503245, 61.51453522273472, 39.5021140234811, 44.63307728086199, 44.15102168491909, 36.51957893371582, 37.403831005096436, 35.993503025599885, 27.017931256975444, 56.0793833051409, 29.630311489105225, 32.261701992579866, 30.51443154471261, 65.47837829589844, 8.504928588867188, 0.6930833522762571, 0.08187425415962934, 0.04278600269130298, 0.1302115214722497, 0.0413849228726966, 0.0714557764253446, 0.02443207148462534, 0.16171549526708467, 0.1824744599206107, 0.2589895155813013, 0.11306758783757687, 0.18326303974858352, 0.2142912247883422, 0.7956109164016587, 0.6780956536531448, 13.949219124657766, 105.75766917637416, 78.33427579062325, 86.77742794581822, 45.25454500743321, 52.02402203423636, 52.08811569213867, 48.82954256875174, 79.86724989754813, 60.92252090999058, 82.55002580370221, 50.06003379821777, 34.93496234076363, 57.16631085532052, 60.55271693638393, 73.68814046042306, 61.03470652444022, 2.5368233493396213, 1.7728929072618484, 12.0419933285032, 19.329473325184413, 17.629999535424368, 15.50064069884164, 22.996432031903947, 17.8031781741551, 21.398697240012034, 49.30026912689209, 55.58383778163365, 62.32727990831648, 54.705324922289165, 52.586242471422466, 46.67638267789568, 40.65143639700753, 36.661888463156565, 32.96541207177298, 34.997631617954795, 37.48083789008004, 38.13783870424543, 46.12625558035714, 44.36142703465053, 43.164367062704905, 43.43747990471976, 42.205616406032014, 40.62406049455915, 47.286740234919954, 54.236022744859966, 50.92409440449306, 55.06312240873064, 53.87551198686872, 55.040162086486816, 55.67663792201451, 55.86819280896868, 52.7087287902832, 55.645902565547395, 54.115301268441335, 48.596920354025706, 20.879849195480347, 3.227733761072159, 4.829060988766806, 6.325138858386448, 5.201003270489829, 3.4211876775537218, 6.303644171782902, 5.362818564687457, 6.1913690992764066, 12.861857312066213, 28.372763974326, 41.70538084847586, 41.8257132257734, 44.79034628186907, 45.87430695125035, 45.21914740971157, 41.31471838269915, 42.84749099186489, 43.36710507529122, 39.47241047450474, 37.029951913016184, 39.26480524880545, 40.065251622881206, 35.50746611186436, 32.93026460920061, 37.7596378326416, 37.68966599873134, 40.09586885997227, 39.01503835405622, 41.98283978870937, 40.02039752687727, 38.69375365121024, 38.1916629246303, 38.96657119478498, 39.044182573046, 37.282053402491975, 36.6808431489127, 37.203959124428884, 40.84240068708147, 28.514715671539307, 11.3604462657656, 4.136219194957188, 5.737052449158259, 6.29057765007019, 7.017709672451019, 7.8896360737936835, 4.89762190410069, 6.841902877603259, 5.3810193708964755, 4.63164529630116, 1.58746437728405, 6.317095449992588, 14.749370200293404, 27.14476193700518, 39.32186732973371, 48.84151084082467, 50.6361471584865, 52.328856876918245, 53.83259643827166, 51.72586441040039, 53.15870802743094, 54.53892251423427, 51.69417715072632, 56.441526889801025, 54.09254591805594, 55.36603607450213, 51.82281262534005, 48.44017941611153, 44.904897757938926, 44.449846335819785, 43.738663469042095, 43.880163533346995, 43.59776094981602, 45.45816544124058, 41.50329596655709, 42.36475099836077, 44.940066065107075, 48.925545828683035, 51.99236256735665, 55.697551999773296, 56.453446524483816, 62.76664924621582, 61.98068986620222, 62.88181563786098, 65.28703880310059, 63.38246808733259, 68.46997383662632, 43.33520589556013, 1.7538962066173553, 7.705659065927778, 49.32610600335257, 68.53933770315987, 49.41799940381731, 50.89540876661028, 45.54852328981672, 52.44997092655727, 44.494610105242046, 44.80743885040283, 34.98828281675066, 66.58672714233398, 49.11039570399693, 42.26993588038853, 44.88229526792254, 85.59615775517055, 18.855847631181987, 1.284974877323423, 0.5470604449510574, 0.14299888030758925, 0.26606861714805874, 0.200403539996062, 0.21460312019501412, 0.160338164174131, 0.3811185993254185], [0.05066515811319862, 0.04666246307481613, 0.08500171027013234, 0.057102955877780914, 0.13870876122798237, 0.04280468615304146, 0.04616148370717253, 0.5089028924703598, 28.408220631735666, 70.03490965706962, 44.458208492824006, 69.79477296556745, 28.74704258782523, 57.45663091114589, 96.78836468287876, 97.37240941183907, 97.29105295453752, 69.84552260807583, 52.642203262874055, 16.650593621390207, 30.904621532985143, 37.49179172515869, 55.5867143358503, 58.27491331100464, 14.620317833764211, 0.9516346156597137, 9.0160311290196, 13.92673214844295, 15.679374422345843, 15.836721590587072, 16.544977528708323, 12.442576084818159, 9.208916596003942, 44.126348631722585, 57.71767125810896, 51.06269359588623, 51.96808903557913, 43.659155232565745, 42.10931089946202, 31.828064918518066, 24.015545163835796, 17.705062661852153, 18.628346238817485, 20.083615166800364, 25.060733148029872, 27.214306456702097, 30.454076017652238, 28.39320731163025, 32.26899412700108, 33.48267766407558, 38.0171172278268, 39.08054249627249, 43.23215021405901, 46.897919041769846, 48.60682153701782, 49.563744817461284, 48.8017497743879, 50.237633228302, 48.44153084073748, 49.64529929842268, 47.77449682780674, 47.51978281566075, 49.07276426042829, 42.448904105595176, 12.511171306882586, 3.2258905342647006, 0.4610714933701924, 4.747115237372262, 4.607117286750248, 4.931310244968959, 3.4235481108937944, 2.1739363074302673, 3.5736426625932967, 17.655742611203873, 33.87442404883248, 38.885871342250276, 42.891094412122456, 42.572755745479036, 36.22021927152361, 37.73778574807303, 37.262949330466135, 35.439519677843364, 33.83211646761213, 31.861336367470876, 29.873415061405726, 29.06613687106541, 28.563221045902797, 27.959047385624476, 27.645855597087316, 31.11410277230399, 33.52006592069353, 34.99727031162807, 33.28320530482701, 31.85216474533081, 31.250294412885392, 30.91085406712123, 33.639227526528494, 30.6345693724496, 33.13466324125017, 30.787117072514125, 32.68599026543753, 28.506098168236868, 10.45870384148189, 2.1094924168927327, 0.9843157934291022, 2.4428452721663882, 1.858304615531649, 0.6234652793833187, 0.4099534606294972, 0.49643212450402124, 0.9128127502543586, 4.134308006082263, 6.9352975232260565, 9.53901161466326, 21.320743662970408, 44.685425009046284, 54.26638637270246, 51.43774345942906, 53.66126080921718, 53.8151981489999, 51.863497802189414, 51.392208439963206, 51.05356713703701, 49.34142330714634, 50.348033155713765, 48.54891177586147, 54.40754944937569, 49.850628989083425, 46.56585073471069, 40.14251906531197, 37.18766559873308, 30.801607540675572, 29.42016669682094, 31.361510753631592, 31.50310114451817, 29.974810123443604, 32.80130951745169, 31.691723891666957, 38.399924755096436, 41.07835108893258, 46.02402673448835, 48.46831267220633, 51.76550040926252, 52.88013390132359, 56.34451961517334, 59.46219021933419, 61.64966378893171, 64.81040627615792, 72.18710722242082, 42.84034824371338, 2.041965046099254, 0.29490904243929045, 11.914259382656642, 37.3303781236921, 47.129703998565674, 35.85928119931902, 36.5767765045166, 38.74012245450701, 18.964677265712194, 15.404533215931483, 32.06335176740374, 31.310410227094376, 39.39968020575387, 35.06641183580671, 47.1361380304609, 38.58207525525774, 58.136136940547395, 1.1447132208517619, 0.050652676461530585, 0.08317988445716244, 0.038900399048413546, 0.0320838973192232, 0.05362870391192181, 0.02932494679199798, 0.14372656840298856, 0.008322864737627762, 0.041387385954814296, 0.07057173350559813, 0.08799134913299765, 0.073955994764609, 0.1857413753334965, 0.028138872668413178, 0.361985838838986, 0.49728355024542126, 37.70834623064314, 76.98060689653668, 49.18617275782994, 63.13916301727295, 34.97432041168213, 52.8050342968532, 84.60099506378174, 96.88170678274972, 90.09907681601388, 81.98766640254429, 47.1239960534232, 21.0366405078343, 42.538240568978445, 41.99886928285871, 63.68215084075928, 68.07306494031633, 25.958806923457555, 1.5520872984613692, 14.318323935781207, 23.92008212634495, 24.246247938701085, 19.567780903407506, 19.406839779445104, 16.272109610693796, 32.98859126227242, 55.18275996616909, 61.40244688306536, 59.357682364327566, 56.966029030936106, 50.59599699292864, 50.000272342136924, 40.77126155580793, 33.099644320351736, 29.893151419503347, 31.055831704820903, 28.693841968263897, 33.73612362997872, 34.598304748535156, 35.921995639801025, 34.9799519266401, 37.29995543616158, 37.380839415958945, 43.76919732775007, 43.45119564873831, 47.30157811301095, 48.7104434967041, 51.76533712659563, 52.66848829814366, 51.77362980161394, 54.18441499982561, 51.485884053366526, 53.83098445619856, 53.04683855601719, 54.48395184108189, 51.46040153503418, 51.532353605542866, 24.61213312830244, 10.035023536000933, 4.861347964831761, 5.045008395399366, 6.268179263387408, 6.2008916054453165, 4.5021339144025525, 2.9246266313961575, 2.5228405339377264, 15.366783652986799, 30.34279019492013, 36.60883896691458, 43.480722018650596, 43.81891516276768, 41.642252990177695, 41.332113197871614, 40.218011243002756, 39.55385725838797, 38.11128616333008, 37.42171566826956, 34.26102181843349, 34.01805373600551, 32.719675132206504, 32.737743922642295, 32.29355948311942, 35.497856753213064, 36.90248373576573, 35.920091833387104, 37.436748095921104, 35.88971083504813, 33.95955337796892, 30.9649110521589, 33.21569313321795, 32.57402351924351, 34.20868798664638, 33.33417728969029, 34.17404426847185, 27.86434691292899, 7.677062886101859, 2.3558301585061208, 2.5792863965034485, 2.3168409935065677, 1.2258848994970322, 1.4377644615513938, 1.6316335328987666, 1.3495701083115168, 7.211817588124957, 14.660068477903094, 16.792283024106705, 17.39211927141462, 33.845314570835654, 51.35946158000401, 55.22526557104928, 53.342136996132986, 52.78259856360299, 52.584331716809956, 54.74180991309029, 54.27646126065935, 54.735563482557026, 55.374155044555664, 54.602303981781006, 52.017362185886924, 54.50260080610003, 53.73905978884016, 50.681015150887625, 46.39694002696446, 41.398742948259624, 38.007431438991, 37.57981150490897, 40.159382343292236, 38.258973598480225, 40.329779965536936, 36.96874870572771, 42.285503319331575, 45.43139055797032, 49.433573790958945, 52.882426806858604, 55.300229685647146, 59.273491042000906, 58.2694103377206, 59.499119894845144, 64.34981713976178, 62.282616887773784, 69.35006741115025, 64.05458123343331, 21.14055950301034, 0.39448497923357145, 1.2078069895505905, 14.768667084830147, 44.58285570144653, 50.68148762839181, 41.59610652923584, 47.545609269823345, 43.06520584651402, 21.087155648640223, 23.962393181664602, 41.60094247545515, 39.304632323128835, 42.58033970424107, 33.56047316959926, 43.51631416593279, 47.11221885681152, 60.15063163212368, 0.6047706082463264, 0.061481427002165995, 0.030534886688526188, 0.06226109087999378, 0.05238933255895972, 0.06288750083850962, 0.057991884249661646, 0.0819844686027084, 0.026172668174175278, 0.15259506180882454, 0.218078237293022, 0.13652261639279978, 0.1650823046054159, 0.3757053283708436, 0.1148786927972521, 0.8028519707066673, 0.6441035462277276, 42.05817215783255, 88.2173100880214, 63.06104442051479, 88.9487052645002, 35.44645398003714, 69.56834506988525, 94.73428262983049, 101.15621076311383, 92.76780346461705, 81.28760065351213, 69.13930075509208, 25.23135311262948, 45.06084312711443, 52.25100231170654, 68.80021476745605, 81.36585821424211, 21.192181144441875, 1.547478580049106, 18.86285662651062, 23.857577868870326, 28.836340836116246, 24.72811767033168, 25.816686732428415, 17.95219271523612, 38.11479500361851, 60.94519288199288, 65.72748511178153, 59.330334254673545, 61.16946683611189, 54.01481989451817, 53.26592567988804, 45.94555377960205, 38.77151094164167, 36.832643917628694, 37.152646677834646, 35.491377558027, 41.898405279432026, 39.347825799669536, 42.821358816964285, 38.26500116075788, 40.85769019808088, 42.30030645642962, 46.355313369206016, 45.884708404541016, 48.091737679072786, 51.41086087908064, 50.04139525549752, 53.70092460087368, 53.41083036150251, 57.274991103581016, 53.14897012710571, 56.475517477308, 51.82043981552124, 54.787379673549104, 52.27835042136056, 49.84896836962019, 21.563425132206508, 7.970425384385245, 6.565824891839709, 7.347386496407645, 5.5103049363408765, 6.890671414988382, 5.693981000355311, 3.902855260031564, 8.31082284450531, 19.85084703990391, 35.49416725976126, 39.109950746808735, 44.998899936676025, 44.15860216958182, 40.758897236415315, 42.82226208278111, 43.299957684108186, 40.24526555197579, 40.961770738874165, 37.32854379926409, 36.79180588041033, 35.858565534864155, 35.70877626964024, 34.71298476627895, 36.77996267591204, 38.513013635362896, 40.056941577366416, 39.62114013944353, 41.89001880373274, 39.67806325639997, 40.13168682370867, 36.249703952244346, 39.918314593178884, 35.3685507774353, 36.68674564361572, 35.897923605782644, 39.0622444152832, 33.386938435690745, 13.977448787008013, 5.478751863752093, 4.254271694592067, 3.965757736137935, 5.251279132706778, 3.1761277530874525, 2.085255580289023, 0.9467506834438869, 4.092762989657266, 9.09264544078282, 11.260994962283544, 13.546531064169747, 28.524187803268433, 48.04850251334054, 60.580134528023855, 57.10224846431187, 57.82424620219639, 54.69443709509713, 57.87437745503017, 58.81369400024414, 56.948165212358745, 55.36424343926566, 55.883666447230745, 52.8381598336356, 58.72666086469378, 55.89554786682129, 54.311560085841585, 49.207184110369, 48.80630431856428, 43.45232473100935, 42.12318297794887, 45.64803886413574, 46.84444917951311, 44.649700845990864, 44.63830927440098, 44.54597813742501, 50.32065725326538, 53.09774105889456, 56.86045115334647, 59.34759357997349, 62.60718808855329, 62.35098716190883, 63.37429700578962, 68.58594621930803, 65.98112215314592, 71.9645355769566, 77.68138136182512, 52.28750467300415, 3.548155801636832, 1.431544303894043, 16.014454773494176, 51.62569917951311, 58.79308564322335, 51.73874984468733, 46.845849241529194, 52.38232673917498, 26.299289499010357, 21.207333428519114, 46.5460136277335, 38.069350310734336, 54.22207771028791, 49.83447095326015, 76.02338136945451, 52.64968299865723, 87.37350000653947, 1.2790149514164244, 0.14069610887340137, 0.0935185325465032, 0.11977996836815562, 0.15031830540725163, 0.10958464044545378, 0.14693549621318067, 0.23612633241074427, 0.09961711708456278], [0.15736498657081807, 0.027866773340584974, 0.018341442769659416, 0.03859471223716225, 0.07053637504577637, 0.02124985759811742, 0.045958907077355046, 0.04449665054146733, 0.11897020467690059, 44.895646231515066, 67.32343769073486, 58.38941614968436, 38.10970197405134, 89.34054892403739, 109.14902237483433, 73.9377475466047, 82.67218208312988, 70.38630785260881, 50.798658575330464, 25.719938278198242, 27.363915068762644, 38.14636066981724, 46.22472892488752, 58.08104119982038, 41.33777945382254, 5.68677875825337, 8.977885518755231, 24.95219186374119, 20.44334077835083, 19.505917617252894, 16.591004133224487, 24.384131465639385, 40.35605110440935, 58.442048754010884, 59.05092634473528, 56.41342142650059, 51.59263617651803, 46.85846022197178, 41.049946853092735, 35.34584059034075, 30.943295206342423, 26.862328086580547, 24.736439875194005, 24.181888512202672, 24.334333726337977, 27.337180137634277, 27.201349803379603, 28.61158745629447, 29.666466440473283, 32.514883926936555, 36.331984519958496, 41.46821103777204, 43.7751658303397, 46.91153403690883, 45.94683224814278, 47.4179048538208, 50.051032406943186, 52.38278184618269, 51.28895820890154, 48.72628886359078, 48.27498599461147, 52.13298715863909, 50.39008017948696, 52.090888023376465, 44.200096811567036, 29.936456067221506, 14.683068752288818, 3.649180437837328, 9.904778684888567, 7.659265075411115, 5.536994704178401, 2.2894403381007056, 2.394532493182591, 8.610639350754873, 19.608424391065324, 31.33764716557094, 40.056667123522075, 43.33598409380232, 44.42546510696411, 39.70210402352469, 38.2424681527274, 38.421773365565706, 38.510578291756765, 34.561857972826274, 34.50097090857369, 31.538498742239817, 34.40522125789097, 32.9389602797372, 34.78223746163504, 38.21597467150007, 39.31817783628191, 36.87815809249878, 35.79474285670689, 35.805776596069336, 34.54022823061262, 32.6355185508728, 30.402162551879883, 34.641908168792725, 35.97777577808925, 34.178591864449636, 29.282015664236887, 13.36988353729248, 2.6183222447122847, 0.26011308814798084, 2.672458265508924, 2.663890050990241, 1.1059970983437128, 1.3473473361560275, 3.476493384156908, 12.158190659114293, 31.348701749529155, 36.033111231667654, 34.07658536093575, 38.06924261365618, 55.2968806539263, 53.626353059496196, 49.88571739196777, 49.15000738416399, 49.343045711517334, 50.089508056640625, 51.314371245247976, 46.738853931427, 49.102186407361714, 49.92062514168875, 48.18386384419033, 47.14115115574428, 47.852653639657156, 49.56536374773298, 45.06337227140154, 40.58357334136963, 35.93153551646641, 33.13105365208217, 33.66797569819859, 32.784814493996755, 32.78463384083339, 34.183941977364675, 35.062110900878906, 40.76937859398978, 42.6888427734375, 48.27061210359846, 50.80533579417637, 53.56487192426409, 56.33442735671997, 58.47025844029018, 57.0354380607605, 61.11342961447579, 58.441138539995464, 64.24127238137382, 19.855629137584142, 0.37601666737880024, 0.02135294403082558, 1.4749034515448978, 10.743432334491185, 38.87466389792306, 36.74252578190395, 35.37937607084002, 36.13329383305141, 46.665418420519146, 15.301540068217687, 32.515491894313264, 30.678051199231827, 52.47159719467163, 51.075381006513325, 48.266526562826975, 35.860347747802734, 71.0373957497733, 23.98683868135725, 1.0885603768484933, 0.3812632629913943, 0.057578798915658674, 0.28790333122015, 0.22211957829339163, 0.18473727921290056, 0.052266334516129324, 0.027638364882607545, 0.09898297861218452, 0.0736362487077713, 0.027741999232343266, 0.06801989900746516, 0.054109388297157626, 0.11909296523247447, 0.024360776113878404, 0.08345762241099562, 0.1180822601807969, 0.1634407519762005, 51.04404463086809, 76.48322010040283, 55.46606234141758, 38.889421871730256, 92.04001440320695, 103.47074604034424, 82.64861379350934, 85.81982026781354, 75.45745059422084, 52.25723484584263, 24.500129904065812, 40.72102607999529, 45.20011976787022, 53.24821124758039, 63.580644607543945, 53.337377480098176, 11.036458713667733, 8.086737360273089, 30.02075856072562, 34.4341778755188, 39.05090842928205, 34.625805718558176, 46.7785906791687, 55.66009078707014, 65.55348137446812, 64.98433358328683, 60.43820367540632, 56.138703550611226, 53.43481206893921, 47.9420873778207, 44.72384854725429, 41.06972490038191, 36.98878036226545, 33.102576460157124, 33.392625536237446, 31.991462230682373, 34.4815993309021, 32.73576021194458, 33.73212841578892, 35.82123286383492, 38.92919683456421, 41.33142532621111, 45.78886495317732, 46.90928976876395, 50.10927220753261, 48.749144962855745, 51.016939708164756, 52.070932797023225, 54.78200871603829, 54.242908409663606, 52.61663041796003, 52.72586652210781, 56.89512961251395, 55.723628589085166, 54.941323961530415, 49.2832738331386, 39.03935010092599, 27.50306143079485, 12.028602412768773, 13.652816789490835, 11.215728316988264, 7.66929566860199, 3.9901163833481923, 4.489001819065638, 9.135150177138192, 19.09885219165257, 28.720071417944773, 40.30037866319929, 42.840765135628835, 44.02593673978533, 45.213957105364116, 43.22402776990618, 41.73562983104161, 42.071543966020855, 38.741953304835725, 34.2697765486581, 30.52272421973092, 39.86772128513881, 37.50541366849627, 37.91485711506435, 41.15391969680786, 41.813748427799766, 39.68508441107613, 38.887663977486746, 36.72607592173985, 33.88109431947981, 35.76763793400356, 36.05740908214024, 34.272944927215576, 36.079719747815815, 32.86556298392159, 29.34998641695295, 11.674681152616229, 3.3306984645979743, 2.7405684164592197, 3.888290967260088, 2.241425463131496, 2.0558434213910783, 2.844764471054077, 4.43417010988508, 20.286789178848267, 39.97230904442923, 42.92452219554356, 42.36032152175903, 45.91434941973005, 56.304195744650706, 52.516534669058665, 53.24404580252511, 54.042703015463694, 53.64159393310547, 54.73023074013846, 53.75440488542829, 49.73537227085659, 52.21572978155953, 50.884538309914724, 50.183207988739014, 51.701882702963694, 53.23581566129412, 52.23749153954642, 48.81156063079834, 45.42932346888951, 44.05096762520926, 41.65771273204258, 39.7783396584647, 39.567958627428325, 39.739377634865896, 40.52736588886806, 42.159139905657085, 45.93449919564383, 49.10952370507376, 53.529873847961426, 55.758803844451904, 57.32537249156407, 57.821678842817036, 61.5034875869751, 58.53855923243931, 62.09869807107108, 59.243579047066824, 55.41043158939907, 11.945926666259766, 1.1848676204681396, 0.07272826707256691, 1.8431827298232486, 11.984972936766487, 46.569213662828716, 42.32558747700283, 43.22222123827253, 43.45224135262625, 41.278872626168386, 21.151490756443568, 41.97955329077584, 37.908530780247276, 54.387597697121755, 63.97810241154262, 44.842443874904085, 36.95824302945818, 72.11090632847377, 11.224166904176984, 0.7514167364154543, 0.5075311117938587, 0.0841604693393622, 0.12226717919111252, 0.12837516143918037, 0.05349061864295176, 0.11496406607329845, 0.016784574703446457, 0.023683786458734955, 0.2672804264085633, 0.15458515073571885, 0.1572545346404825, 0.10285211421017136, 0.2125444585191352, 0.09945838738765035, 0.1840797652091299, 0.25620005811963764, 0.18675005835081848, 63.79306493486677, 87.18211882455009, 71.42941311427525, 53.755930015019004, 99.3317597252982, 109.58486202784947, 76.1663544518607, 86.86603137425014, 73.4825085231236, 65.29097843170166, 36.18325138092041, 40.46678801945278, 53.86707339968, 61.28271552494594, 68.57887990134103, 55.44083343233381, 7.909157037734985, 12.28504913193839, 40.47761678695679, 38.01615490232195, 41.12870468412127, 36.864862714494976, 47.39525720051357, 56.081360067640034, 68.55541583469936, 66.54450293949672, 65.22994545527867, 59.34905964987618, 56.42966284070696, 52.13030167988369, 49.23964262008667, 46.973386900765554, 41.0837915284293, 37.740294047764365, 39.20179203578404, 36.005387919289724, 38.60496262141636, 36.431302070617676, 39.59667205810547, 40.196461405072895, 42.490304946899414, 44.98479509353638, 48.769899232046946, 48.890172549656455, 52.5008282661438, 52.071026597704204, 51.69548341206142, 53.346424034663606, 54.49053873334612, 55.27909673963274, 52.902562686375205, 56.28919110979353, 56.02626085281372, 56.46995891843523, 55.368134430476594, 51.308684144701274, 39.53508669989449, 26.16948672703334, 10.233189633914403, 12.402710795402527, 10.33106803894043, 7.451757993016924, 5.16045879466193, 4.102497850145612, 13.602513568741934, 21.940592459269933, 34.59178386415754, 40.314952509743826, 43.6404333114624, 43.90906803948538, 43.85121733801705, 43.53189550127302, 45.92747456686837, 45.90166200910296, 41.114881243024556, 40.87599870136806, 34.43522357940674, 40.19920941761562, 38.12668684550694, 40.17850031171526, 44.55994749069214, 45.99601854596819, 43.261429922921316, 43.10172210420881, 39.799712317330496, 38.78723471505301, 40.95335647038051, 40.471801144736155, 40.28260169710432, 40.760064533778596, 37.60798645019531, 35.01201786313738, 19.84934275490897, 5.035211869648524, 2.787012130022049, 5.353966559682574, 5.573681627001081, 5.039735581193652, 1.8693107792309351, 2.350814861910684, 12.862423590251378, 36.74944271360125, 45.0335054397583, 45.401794706072124, 45.19476965495518, 57.23625489643642, 55.87200389589582, 54.711105823516846, 54.64168984549386, 56.61696195602417, 58.2004633631025, 56.98587308611189, 51.719343526022776, 54.0993447303772, 54.52325780051095, 50.50798763547625, 52.23118257522583, 53.643442153930664, 55.63435813358852, 52.4757730620248, 48.34368978227888, 47.76378270557949, 45.47936092104231, 45.914804526737754, 42.622362409319194, 43.13028614861624, 45.6503005027771, 46.20016009466988, 49.77528619766235, 51.69758176803589, 58.12312296458653, 61.79590252467564, 61.152158873421804, 63.51214926583426, 64.88701711382184, 63.30237620217459, 67.03145354134696, 61.61842468806675, 69.85757078443254, 26.3820355960301, 1.216260015964508, 0.1547541738088642, 2.903939890010016, 15.13503691128322, 51.59574202128819, 51.210575580596924, 49.52017961229597, 46.8635949407305, 59.44288117544991, 20.14024124826704, 46.20784132821219, 43.86392559323992, 66.1162576675415, 65.61651543208531, 69.93805176871163, 48.0899589402335, 94.13171400342668, 31.461394582475933, 1.181752004793712, 0.7358103767037392, 0.2104272392711469, 0.49069052402462277, 0.2299404272011348, 0.2271366390798773, 0.29415660138641087, 0.11628195749861853, 0.2071829597864832], [0.05403427107791815, 0.07472693946744714, 0.07982872892171144, 0.037979179194995334, 0.0035260012872251017, 0.05009641006056752, 0.006400929564344031, 0.05245723355827587, 0.08886744640767574, 0.7323184726493699, 37.93660497665405, 53.98587717328753, 40.215968472617014, 56.35794006075178, 92.42203330993652, 83.8104498726981, 96.21687534877232, 82.46031066349575, 49.41100256783621, 23.69241224016462, 23.84200174467904, 46.44228744506836, 41.40296050480434, 55.99340282167707, 53.64175026757376, 27.784180334636144, 3.6583755101476396, 12.373318178313118, 31.972431114741735, 39.06216103690011, 40.54911722455706, 52.204070704323904, 54.51767839704241, 58.696450097220286, 55.827980109623496, 53.24058212552752, 51.07256351198469, 47.8914350100926, 42.38100630896432, 40.0168331010001, 35.572727067129954, 34.98949875150408, 30.7830627986363, 30.97801535470145, 28.49328395298549, 28.168248959950038, 28.518127237047466, 29.99375091280256, 30.513490063803538, 34.0102231161935, 37.25650487627302, 39.7104731287275, 40.153028215680806, 45.06333058220999, 47.321404797690256, 50.884614740099224, 49.98128291538784, 51.53667885916573, 49.9213616507394, 50.018890040261404, 50.05796323503767, 50.73770202909197, 52.81707552501133, 53.71401153291975, 50.6816474369594, 43.31734902518136, 40.70046983446394, 35.97910983221871, 26.203272342681885, 21.288641248430523, 7.779234409332275, 3.944710774081094, 3.4354690483638217, 4.777155773980277, 11.11316248348781, 20.590161425726755, 34.518348353249685, 37.653368609292166, 40.40793330328805, 47.93905101503645, 41.09351553235735, 38.20761946269444, 37.174307686941965, 36.1472875050136, 21.16339996882847, 21.78418329783848, 40.34531961168562, 41.987276213509695, 41.519843101501465, 40.52383620398385, 40.860650130680625, 39.07454967498779, 41.43660020828247, 32.887915338788716, 33.881938525608604, 35.62747539792742, 44.321502685546875, 48.82532501220703, 43.80955593926566, 37.38837126323155, 24.754722322736466, 3.4212037452629636, 1.132074013352394, 1.5638241086687361, 3.3454549184867313, 0.2188302440834897, 1.8806689126150948, 8.761494295937673, 16.637645653315953, 44.62430170604161, 38.767901352473665, 38.34552730832781, 37.76631852558681, 50.68449967248099, 51.71843678610665, 50.35244526181902, 53.181849002838135, 52.550209113529746, 51.68076712744576, 50.87952518463135, 48.310328006744385, 47.04301479884556, 46.38717433384487, 49.02252531051636, 49.099949087415425, 50.090116024017334, 52.621831144605366, 49.90795162745884, 46.444889545440674, 42.787830284663606, 40.34550721304757, 37.950345039367676, 35.46496050698416, 35.18029975891113, 36.25809390204293, 36.16823284966605, 39.01718187332153, 46.56313746316092, 48.61943251746041, 51.712002754211426, 53.830928870609824, 55.3682838167463, 54.19716494424002, 56.82021413530622, 59.99945272718157, 55.742614541734966, 59.18686090196882, 22.386981214795792, 8.327291812215533, 1.8397957001413618, 0.5279282544340406, 1.3065749811274665, 9.632143531526838, 41.89526816776821, 38.9377326965332, 32.31245510918753, 26.42191651889256, 29.197601999555314, 9.067471248762947, 36.24325254985264, 37.57806750706264, 31.21800265993391, 60.9905229296003, 42.36169726508004, 44.127446447099956, 53.7128963470459, 0.2031156580363001, 0.06654986646026373, 0.09286413980381829, 0.08257011896265404, 0.022430652719257132, 0.0560397593570607, 0.08961377386003733, 0.05479314803544964, 0.0691113429410117, 0.048020014871976206, 0.058891587757638524, 0.02632668544538319, 0.03236221542049732, 0.022320628265983293, 0.039609057629214864, 0.03961679632110255, 0.05388264903532607, 0.022217404429933856, 0.11161096314234392, 0.3693295419216156, 44.67003474916731, 63.66364778791155, 34.2827592577253, 60.01354367392403, 97.95043700081962, 84.22757802690778, 99.23210866110665, 84.21152768816266, 58.86017050061907, 20.806550911494664, 32.251943247658865, 55.60753461292812, 46.40435722896031, 61.15828023638044, 60.39228997911726, 36.61737135478428, 5.495585177625928, 9.406208957944598, 35.43994699205671, 50.96828147343227, 57.34347949709211, 61.229137965611045, 60.81360789707729, 59.84386171613421, 58.89555072784424, 59.203258650643484, 57.60654871804373, 54.62925951821463, 51.141708510262625, 47.65284081867763, 45.09215865816389, 44.24209172385079, 41.879064968654085, 42.22203499930245, 37.31255252020699, 36.20498187201363, 34.98661524908883, 36.56126117706299, 36.196657930101665, 37.1863454410008, 41.134568963732036, 44.62116806847708, 43.462938104357036, 46.99320663724627, 49.380503450121196, 51.63443306514195, 52.580496311187744, 52.068942138126914, 50.16594171524048, 53.020122732434956, 54.61715923036848, 56.18170942578997, 56.641885144369944, 56.85067851202828, 53.98793036597115, 47.43147815976824, 46.39705467224121, 45.37930686133248, 33.45054919379098, 23.481647321156093, 10.500968864985875, 5.591957994869777, 5.331600742680686, 7.231620388371604, 10.664649316242762, 18.9870765209198, 34.073159899030415, 37.78754179818289, 40.41432217189244, 49.066583837781636, 43.51060274669102, 41.45362676892962, 42.995734282902305, 38.39120823996407, 20.078049659729004, 21.19589843068804, 40.4779120853969, 46.31122704914638, 45.607034070151194, 42.306170736040386, 40.78337574005127, 37.049563203539165, 40.57562460218157, 35.19210474831717, 37.38296209062849, 32.82080616269793, 35.974433694567, 40.08697863987514, 42.27212803704398, 35.40059239523751, 30.839013167790004, 3.868274075644357, 3.2334718874522617, 2.9705561782632555, 4.421699396201542, 1.0216051467827387, 2.9307425660746436, 10.383071831294469, 22.967841931751796, 48.64134018761771, 41.57885415213448, 43.13199193137032, 42.81685291017805, 54.24561125891549, 52.97636645180838, 54.44981186730521, 54.52942780085972, 53.08425113133022, 50.71120854786464, 51.48394898005894, 51.70935896464756, 50.34438187735421, 47.8762914112636, 53.59265777042934, 50.51602322714669, 52.123450756073, 53.23492281777518, 51.59877838407244, 50.45158910751343, 47.165796416146414, 43.678036962236675, 44.027038029261995, 40.69985144478934, 41.49593087605068, 40.84524597440447, 41.52061782564436, 43.29548304421561, 50.26227501460484, 53.315191881997244, 55.37985951559884, 56.80234684262957, 57.775157179151265, 58.176387854984824, 57.21698406764439, 61.29836981637137, 60.260107449122835, 60.241215297154014, 27.073690550667898, 11.113261495317731, 3.973037276949201, 0.7018762433103153, 1.8229584779058183, 14.705139705113002, 48.75812898363386, 43.39720467158726, 43.973523003714426, 26.047068153108867, 29.097778967448644, 16.84130777631487, 36.93772152491978, 51.79125738143921, 34.59649821690151, 72.31620475224086, 44.341440541403635, 51.78407294409615, 44.534485816955566, 0.21392400163624967, 0.07441194315573998, 0.1586795531745468, 0.061472972455833635, 0.062471212819218636, 0.04027743158595903, 0.014275338633784225, 0.03296894447079726, 0.018937383113162856, 0.03288043975563986, 0.22187206228928907, 0.13551989091294153, 0.13093439196901663, 0.07863956237477915, 0.1270897582705532, 0.12048480340412684, 0.11689079340015139, 0.16395856919033186, 0.21672553702124528, 0.6499898646559034, 61.6571261542184, 74.05419935498918, 57.51706634249006, 68.16523974282401, 95.63747201647077, 85.97898265293666, 94.97482231685093, 87.79401888166154, 62.643770354134695, 34.47717332839966, 34.95057841709682, 59.94312368120466, 56.10255902154105, 66.59057644435337, 66.59314032963344, 36.38215051378523, 4.528051129409245, 15.03435925074986, 43.713983467647004, 60.136950629098074, 61.048095703125, 67.1915956224714, 65.54394844600132, 64.12723854609898, 62.607215881347656, 60.224213055201936, 60.1049541745867, 55.53537062236241, 53.683283124651226, 52.98725080490112, 48.89321238654, 51.26696368626186, 46.26726579666138, 46.3188214302063, 42.34415653773716, 39.5686742918832, 39.857681138174875, 38.91220154081072, 39.491271359579905, 41.68035691125052, 43.39542245864868, 47.72907992771694, 44.211533546447754, 48.8194294657026, 52.28332880565098, 53.500830377851216, 52.11380665642874, 56.199844224112375, 51.40976306370327, 54.18447405951363, 53.909426144191194, 56.82196160725185, 55.597324235098704, 57.06561756134033, 52.615602084568565, 49.94583668027605, 49.12737362725394, 47.96777834211077, 32.519556590488975, 23.150136607033865, 9.609627025468008, 6.303658936704908, 5.802963060992105, 10.460832595825195, 14.793644121715001, 23.377690110887798, 38.409356934683665, 37.73594100134713, 41.801828793116975, 51.70352595193045, 47.44683367865426, 44.88843052727835, 44.658472946711946, 42.59766156332833, 27.983230590820312, 27.9958815234048, 45.005809920174734, 45.57941845485142, 45.30244588851929, 45.9154646056039, 43.70638908658709, 40.855164527893066, 43.56183876310076, 37.90580708639962, 42.32781784875052, 38.794940267290386, 39.56801768711635, 42.78366136550903, 46.63569402694702, 40.06501191002982, 39.72274364743914, 8.232579180172511, 2.4593767736639296, 3.8204018558774675, 8.268477048192706, 2.5472284938607896, 1.876800068787166, 7.834954619407654, 17.81775549479893, 48.07146978378296, 43.63822725840977, 44.18486983435494, 43.527757849012104, 53.60125616618565, 54.12512602124895, 56.65833500453404, 58.12693405151367, 56.338804721832275, 54.72356046949114, 55.75223779678345, 55.15589823041643, 52.456398010253906, 51.35200963701521, 55.70416668483189, 54.55496590478079, 53.07604878289359, 57.175260135105674, 54.473477431706016, 52.871521609170095, 50.04255213056292, 48.764194761003765, 48.43174082892281, 45.461590903145925, 44.16217006955828, 46.93384122848511, 43.60106829234532, 47.59817934036255, 52.86010571888515, 58.31799561636788, 56.877043451581685, 60.13821520124163, 60.66643115452358, 61.91816997528076, 59.62456267220633, 63.26022842952183, 58.91194152832031, 64.49770259857178, 32.76252467291695, 9.392109325953893, 3.8291526777403693, 1.4350092836788721, 1.7683173013584954, 17.93872536931719, 54.47827863693237, 54.003925119127544, 45.20424004963466, 39.0272011756897, 39.24820252827236, 12.078622494425092, 50.622685023716514, 54.11004843030657, 39.716111591884065, 76.17130156925747, 64.29633685520717, 62.182236262730186, 68.21780286516461, 0.2051807250827551, 0.17501535160200937, 0.27719537009085926, 0.16354744482253278, 0.15197649571512425, 0.15467174537479877, 0.1801915288503681, 0.21965359204581805, 0.15364858242017881, 0.10533047693648509], [0.036300249464277706, 0.06111563555896282, 0.03527548855968884, 0.13219124238405908, 0.038689411977039914, 0.049081087578088045, 0.017272604230259146, 0.023675850991691862, 0.04112470469304493, 0.20957522998963082, 0.3712012671998569, 32.03967578070504, 60.145517757960725, 33.56980112620762, 67.76202188219342, 89.2665992464338, 77.04933152879987, 63.32918930053711, 44.61243418284825, 32.05548293249947, 21.933336802891322, 38.37700612204415, 39.563310282570974, 48.262805802481516, 51.94639675957816, 38.28093685422625, 8.447190795625959, 3.3011325768062045, 19.147275924682617, 37.7873854637146, 48.89538369859968, 54.61633586883545, 54.59832961218697, 54.00196920122419, 55.4904123033796, 53.363401957920615, 51.97939028058733, 49.133168424878804, 47.02350773130144, 42.939773491450715, 42.39082758767264, 40.390962328229634, 39.69775792530605, 37.901207378932405, 36.121297768184114, 34.752905641283306, 33.58848483221871, 32.823154653821675, 30.302914483206614, 29.649839401245117, 34.544640336717876, 35.912063189915244, 38.290386404309956, 39.13224751608712, 44.14564377920968, 44.5534405027117, 49.25531775610787, 49.76730966567993, 48.282715865543906, 48.118724482400076, 51.37106507165091, 53.81764044080462, 56.99532263619559, 52.12707076753889, 54.32802731650216, 47.60556527546474, 39.79945175988333, 35.82571792602539, 38.40537214279175, 31.39986480985369, 15.230376618249075, 4.401734181812831, 3.8549174666404724, 5.798236983163016, 5.719481323446546, 12.338102102279663, 23.8443797656468, 36.8472455569676, 37.282567569187705, 41.78667477199009, 39.81768035888672, 37.20796823501587, 45.681407587868826, 32.6823285647801, 9.144020421164376, 14.182310342788696, 37.48214415141514, 49.07030807222639, 54.31175116130284, 48.83714737210955, 42.90977464403425, 41.2941586630685, 36.44288124356951, 33.867687770298545, 31.243613719940186, 35.360560349055696, 40.36414228166853, 31.553826468331472, 36.396033014569966, 35.59189714704241, 10.794958438192095, 1.4120226885591234, 2.278841946806226, 4.840636687619345, 3.796806641987392, 2.5705811721937994, 6.518715671130589, 16.65471737725394, 36.15676832199097, 42.0589781488691, 40.95012208393642, 45.261413301740376, 46.356154101235525, 52.84542417526245, 50.168905121939524, 51.95484576906477, 48.652366978781565, 48.91695785522461, 46.911631311689106, 45.173515115465435, 45.08255624771118, 43.42076601300921, 42.86860309328352, 42.76640204020909, 45.83809641429356, 47.04022857121059, 45.221818992069785, 47.32542780467442, 45.49674531391689, 44.15708746228899, 41.36843490600586, 39.67446756362915, 38.0900559425354, 36.869931425367085, 38.71214553288051, 39.441018513270784, 44.360245840890066, 49.852240971156526, 50.28771236964634, 52.98233495439802, 55.71754544121878, 56.689733913966585, 59.68865980420794, 60.65402167184012, 60.34477819715227, 64.58465930393764, 51.65295001438686, 25.970802988324845, 17.128624473299297, 8.338685989379883, 1.601431124976703, 2.0713355158056532, 15.561347109930855, 39.062793322971885, 43.01614809036255, 29.86891610281808, 26.497099501746042, 13.284128001758031, 23.033700432096207, 44.83976534434727, 72.54201425824846, 73.50014999934605, 43.73660332815987, 27.04543743814741, 56.51975665773664, 20.2405332837786, 0.5711314475962094, 0.05424852529540658, 0.24236212351492473, 0.06326186217899833, 0.4100356990737574, 0.1369793111724513, 0.0693348930882556, 0.03290867020509072, 0.08192679312612329, 0.1488790919205972, 0.09922271860497338, 0.028921737535191432, 0.05286806615601693, 0.1077338479725378, 0.03417517617344856, 0.08271290987197842, 0.12338935397565365, 0.06536289836679186, 0.029112046251871755, 0.3200085684657097, 0.7459925274763788, 40.693024839673726, 63.70766462598528, 35.1417407308306, 76.3669489451817, 93.79155799320766, 80.47946957179478, 63.20859636579241, 56.68606526511056, 33.64556080954415, 21.582034145082744, 46.08372218268258, 45.618269307272776, 50.51622125080654, 57.29440437044416, 42.51766347885132, 11.950849464961461, 5.14252462557384, 20.744725840432302, 41.978469371795654, 53.28164250510079, 59.653870173863, 57.09442479269845, 60.43274239131382, 59.68286500658308, 55.80164991106306, 56.8605032648359, 54.084326199122835, 50.7960147857666, 49.41127702168056, 49.85994304929461, 48.41443286623274, 47.123676436288015, 44.59155484608242, 42.020992347172324, 41.40094205311367, 39.02348388944353, 37.207516602107454, 34.95874602454049, 34.33137927736555, 39.00671788624355, 40.45298194885254, 41.06354447773525, 42.372303690229145, 49.142687456948416, 47.28835221699306, 51.61950486046927, 53.657807554517476, 51.46101992470877, 50.40515777042934, 54.72573525565011, 58.25329051698957, 59.56546824319022, 54.5860139301845, 56.910968031202046, 51.952431270054404, 45.562666348048616, 38.038330078125, 41.73642887387957, 35.793110030038015, 18.842461926596506, 7.16868577684675, 3.228312632867268, 7.766491413116455, 8.498648285865784, 11.876193676676069, 28.75677875110081, 38.653106689453125, 38.7966946874346, 42.722795145852224, 38.91786779676165, 38.809413364955354, 48.29507671083723, 36.42605965478079, 16.75744128227234, 25.27277479852949, 41.17986079624721, 50.5382261957441, 57.374489307403564, 51.16227517809187, 47.34569569996425, 44.828689915793284, 37.04195492608206, 34.08053888593401, 28.640726464135305, 31.46063028063093, 41.776318481990266, 39.49493653433663, 36.91600145612444, 35.41332844325474, 13.623726419040135, 2.0979475506714413, 3.6449224948883057, 4.380189120769501, 2.407376889671598, 5.400662796837943, 9.249885780470711, 19.399841206414358, 42.42338337217058, 40.87409142085484, 46.94901262010847, 50.23514577320644, 54.266549655369346, 55.207092557634624, 53.47432994842529, 54.86065884998867, 53.7314167703901, 51.858251912253245, 48.427790778023855, 47.38914973395211, 48.346104281289236, 45.16617781775338, 46.364662170410156, 44.30681766782488, 47.17688921519688, 48.71100630078997, 48.48328256607056, 49.460835048130576, 48.74622324534825, 48.44151694434029, 46.8499174118042, 42.794306005750386, 43.72952658789498, 41.708007267543245, 43.07979358945574, 42.13763870511736, 49.47484261648995, 50.33087805339268, 53.30095154898507, 55.9155968938555, 59.16325787135533, 59.72515869140625, 61.99124417986189, 61.605890137808665, 63.76556396484375, 69.59577655792236, 54.78132431847708, 30.391736779894146, 24.165862492152623, 10.99006906577519, 3.007672803742545, 2.3683158542428697, 20.91028230530875, 44.78654909133911, 52.35814700807844, 34.09487649372646, 26.060710941042217, 20.84575264794486, 29.3685485294887, 45.49766247613089, 75.60499559129987, 77.833803994315, 55.83071422576904, 28.942943572998047, 60.61973231179373, 17.684664487838745, 0.6142382887857301, 0.23486059318695748, 0.2539180905691215, 0.06372011080384254, 0.5406036685620035, 0.12575868969517096, 0.04754226515069604, 0.03576611687562295, 0.09595359116792679, 0.09174115756260497, 0.1586613277239459, 0.1953228869076286, 0.17577202671340533, 0.20347349026373454, 0.13607927518231527, 0.1597485308136259, 0.3046522896204676, 0.11663216299244336, 0.17971947203789437, 0.398567833006382, 0.9997266807726451, 60.10688577379499, 79.32588795253209, 52.699359144483296, 72.5481356212071, 89.55548449925014, 78.61052921840123, 69.82808262961251, 56.46638059616089, 45.05044862202236, 29.60990810394287, 47.30218260628836, 53.33438628060477, 55.151055335998535, 64.3637969153268, 45.23099408830915, 12.19635363987514, 3.774102968829019, 26.31519913673401, 46.098546164376394, 60.50517736162458, 63.8504501070295, 60.93877969469343, 63.37551988874163, 64.93465396336147, 61.31157834189278, 62.92459569658552, 58.60294818878174, 57.08420746667044, 52.96834128243582, 56.521292209625244, 50.57220983505249, 52.81547743933541, 50.81812742778233, 46.99478040422712, 44.45038482121059, 41.50156239100865, 40.77166107722691, 39.42205340521676, 37.532740933554514, 43.10125657490322, 44.88880573000227, 42.749910490853445, 44.93956926890782, 50.54261745725359, 50.27720321927752, 54.35819639478411, 54.1097913469587, 52.33518321173531, 52.83724961962019, 56.61885534014021, 58.57254981994629, 61.511116709027974, 54.446129322052, 58.38919380732945, 51.42950289590018, 47.236636774880544, 39.66817249570574, 44.38928236280169, 35.82177134922573, 18.78801757948739, 6.8581069452422, 6.69926244020462, 12.782585314341954, 12.424399597304207, 15.405823843819753, 34.38505411148071, 39.59700557163784, 37.706807204655235, 47.48548650741577, 41.765298639025005, 39.05612652642386, 48.815260546548025, 36.5854617527553, 14.112137879644122, 24.613416807992117, 42.21921750477382, 50.32913058144705, 55.85748563494001, 49.15523937770298, 47.817520073481965, 49.39663021905081, 42.60058675493513, 38.76224899291992, 33.56175511223929, 35.262750557490754, 44.964933667864116, 46.474784169878276, 42.95165491104126, 39.908642700740266, 23.038468633379253, 3.354112373931067, 3.711879244872502, 7.628766826220921, 7.827229959624154, 6.395725607872009, 8.07277842930385, 18.919883966445923, 40.99150902884347, 43.25134808676583, 47.82581622259957, 52.945585932050435, 55.55764307294573, 57.86907597950527, 58.14763273511614, 59.476996830531526, 54.27622502190726, 54.769818101610454, 53.326882226126536, 49.99831642423357, 52.542816230228965, 48.52454096930367, 47.595782211848665, 48.28055150168282, 52.277561800820486, 52.30748074395316, 50.50131041663033, 53.27976996558053, 51.92958559308733, 50.97630664280483, 49.251197474343435, 46.31464556285313, 46.69645254952567, 43.492401940482004, 46.28247192927769, 45.5626802444458, 52.8850462777274, 53.447697503226145, 54.15793194089617, 57.56918478012085, 59.862948417663574, 60.82100078037807, 62.776668548583984, 64.95012065342495, 63.43502426147461, 69.8289442062378, 60.702228273664204, 31.252858298165457, 25.34044851575579, 10.786156807626996, 3.215700783899852, 2.6375283684049333, 25.19382415499006, 53.36684479032244, 59.9086606161935, 38.368341718401226, 36.25797578266689, 18.088853359222412, 34.14064080374581, 62.934364863804404, 87.87977354867118, 85.441317149571, 54.75877046585083, 35.89738164629255, 71.29534067426408, 25.15338911328997, 0.6638650372624397, 0.41036647132464815, 0.287805052208049, 0.2851600684225559, 0.7013812384435109, 0.21429013913231237, 0.12994215664054665, 0.08798813287700925, 0.1763216265078102, 0.20137767201023443], [0.07776416399117027, 0.12356170187039034, 0.27937895006367136, 0.23215280420013837, 0.27229575014540125, 0.20513800451798098, 0.1726659376706396, 0.015663315941180502, 0.10233558621257544, 0.16663707260574612, 0.5329122841358185, 1.110224751489503, 40.622483253479004, 58.22407334191458, 32.61067179271153, 74.5789828981672, 41.53826625006539, 47.33916091918945, 46.3244286264692, 29.699508598872594, 37.62264020102364, 23.634422574724468, 45.52877998352051, 42.152768407549175, 54.44822767802647, 36.27758707318987, 12.757101927484785, 10.639152032988411, 23.932901552745275, 40.87200001307896, 48.84135798045567, 51.72871317182268, 52.71411711829049, 55.51070104326521, 60.05448246002197, 49.88882671083723, 50.88659150259835, 49.7882376398359, 48.24914911815098, 46.15143585205078, 45.00939866474697, 46.22943632943289, 42.67822592599051, 37.59857511520386, 38.68900455747332, 37.81784636633736, 38.38820661817278, 36.43402576446533, 34.28012589045933, 27.86366946356637, 32.53264004843575, 36.96156774248396, 34.921698229653494, 33.19178785596575, 40.92774888447353, 44.55530956813267, 48.64241715839931, 48.656334400177, 45.42662756783621, 46.28792626517159, 51.9385209764753, 51.95530087607247, 56.63670873641968, 55.24225391660418, 52.766193866729736, 51.148364884512766, 48.08165584291731, 41.309184142521445, 37.40336894989014, 41.73558814185006, 25.362255437033518, 8.994273713656835, 5.048779095922198, 3.9132849403790066, 3.450522537742342, 6.699443527630397, 19.62899627004351, 35.804206303187776, 35.29798834664481, 37.791926111493794, 29.32637643814087, 38.460825715746196, 39.05697420665196, 36.955383845738, 35.15478597368513, 39.145845140729634, 55.98505803516933, 58.85004697527204, 58.947050775800435, 67.20693724496024, 58.582124437604634, 52.72492504119873, 33.45748002188546, 28.447101014001028, 21.54516700335911, 25.928233112607682, 25.146741424288066, 12.763302326202393, 22.82239702769688, 21.522654839924403, 6.614074485642569, 1.7602726987430026, 5.335945103849683, 6.225282388074057, 2.451907677309854, 8.43634031500135, 12.530883346285139, 26.396058797836304, 38.874431133270264, 36.69757093702044, 44.184008257729666, 42.67797926494053, 49.42851550238473, 48.64804867335728, 44.289791107177734, 44.058013098580496, 49.364526067461284, 44.07458455221993, 42.167748723711284, 43.0118784223284, 40.008707182747976, 39.1182017326355, 41.77424097061157, 42.54876014164516, 45.01406785420009, 43.407380308423726, 45.80582550593785, 47.77058499200003, 44.650350502559114, 43.113026823316304, 43.505436761038645, 40.89304610661098, 40.959814820970806, 40.11722067424229, 40.25628192084176, 37.492479596819194, 48.98999037061419, 48.4636504309518, 53.55854558944702, 56.53583478927612, 57.953024114881245, 57.28334978648594, 59.43655136653355, 58.65321145738874, 65.79138074602399, 65.98011466435024, 44.64043542316982, 28.78251835278102, 26.18778654507228, 14.225895524024963, 3.591094366141728, 4.032297159944262, 18.324133259909495, 36.35645260129656, 38.388220514569966, 26.191495146070206, 35.88688291822161, 15.531211035592214, 27.71919904436384, 47.89958872113909, 70.21784182957241, 72.13531535012382, 48.02755716868809, 31.324501173836843, 63.76804447174072, 8.487360937254769, 0.1505200881510973, 0.27800385813627926, 0.2884753905236721, 0.13197725958057813, 0.9573902211018971, 0.15828703423695906, 0.015853393955954483, 0.20031883168433393, 0.06913881003856659, 0.4053300587194306, 0.08989796468189784, 0.1460052654147148, 0.07538305568907942, 0.14801147633365222, 0.12947712945086615, 0.17675127488161835, 0.41221922476376804, 0.25547304855925695, 0.037837341627372165, 0.44134213775396347, 0.32508083486131256, 1.4439573692423957, 43.4061678477696, 59.361531666346956, 36.59807620729719, 81.1905551637922, 51.93220158985683, 55.33111790248326, 52.648060594286235, 38.5353764125279, 33.62068278448922, 28.59019568988255, 45.873678139277864, 50.4878899710519, 57.52016176496233, 44.40697247641427, 15.67557896886553, 13.511144757270813, 33.663289138248985, 52.60697589601789, 57.88351433617728, 55.49123566491263, 54.105163846697124, 59.784503255571636, 61.86924770900181, 53.754714080265586, 56.20180709021432, 53.995625495910645, 51.87122072492327, 51.16453334263393, 50.372299739292686, 51.74470445087978, 49.88557495389666, 44.809540680476594, 45.77046612330845, 43.91844463348389, 44.35328027180263, 44.89950942993164, 38.151877539498464, 30.376957961491176, 35.791626589638845, 38.98549461364746, 36.44298546654837, 39.10988473892212, 45.68948139463152, 46.968936579568044, 50.31723526545933, 50.84149421964373, 47.73076139177595, 50.51881987707955, 53.49190541676113, 55.874758856637136, 58.801520756312776, 55.52182510920933, 54.559186935424805, 54.956071513039724, 51.1914506639753, 45.8781076158796, 41.00076750346592, 42.99819394520351, 32.73511402947562, 12.490998949323382, 8.520338824817113, 3.5940645039081573, 5.972330612795694, 6.003179311752319, 17.856274570737565, 34.854658535548616, 39.13567645209176, 42.37643786839077, 32.88492413929531, 41.28648785182408, 41.33424629483904, 41.83768149784633, 65.4475838797433, 71.82570362091064, 65.4548864364624, 57.746370792388916, 60.91314084189278, 64.22310979025704, 58.09979786191668, 51.66630792617798, 30.984293052128383, 26.758469888142177, 28.894247123173304, 38.12005131585257, 40.66267858232771, 29.03503152302333, 28.535669701439993, 25.517598049981252, 6.748470016888209, 3.9205514533179144, 3.389482395989554, 6.714294867856162, 6.697187534400395, 13.541312098503113, 21.227597849709646, 36.52198995862688, 38.72468703133719, 41.238319465092246, 49.02473136356899, 47.928020749773296, 54.22993959699358, 53.76498351778303, 49.599024295806885, 48.541855880192344, 51.11333901541573, 47.012282916477744, 46.902077538626536, 45.50891508374895, 41.76431894302368, 40.5178815977914, 43.893438066755024, 46.10170759473528, 47.25665800912039, 44.74568326132638, 48.51277766908918, 50.41266877310616, 49.48543861934117, 46.379420144217356, 46.37559516089303, 45.63895409447806, 44.65060063770839, 44.690886293138774, 43.037607601710725, 41.09081268310547, 49.912172658102854, 52.14855112348284, 56.36925172805786, 59.69593456813267, 61.77439090183803, 60.14287049429757, 61.498547417776926, 58.893007687159944, 68.13174247741699, 67.20334502628872, 49.773726327078684, 37.905942576272146, 31.676000118255615, 17.350341490336827, 5.991901082651956, 6.146468102931976, 24.590253250939504, 45.520278862544465, 44.474484648023335, 31.84801319667271, 38.57913269315447, 23.272602081298828, 31.053142751966202, 46.40665013449532, 73.82051753997803, 73.51663112640381, 51.80891970225743, 35.64789267948696, 71.15350709642682, 7.0043200595038275, 0.3265334154878344, 0.2271304644112076, 0.2102028748818806, 0.21825097873806953, 0.7726038566657475, 0.10307395444916827, 0.08508972304740123, 0.2072037908115557, 0.042980019601860216, 0.3992170553122248, 0.16745332309177943, 0.7142026733074869, 0.5606649635093552, 0.4807059626494135, 0.18927631207874843, 0.3400648151125227, 0.771104457122939, 0.34539983740874697, 0.14304409788123199, 0.47577078746897833, 1.026980338352067, 2.770805673939841, 64.09876482827323, 71.3919345310756, 43.44364643096924, 81.6403329031808, 49.728107929229736, 55.074263845171245, 58.627093178885325, 38.839565072740825, 46.02902248927525, 31.954935550689697, 55.73496804918562, 54.07285819734846, 66.25372082846505, 50.58656133924212, 17.471141133989605, 10.668020061084203, 33.90248782294137, 55.260604109082905, 63.31256920950753, 63.23759119851248, 57.4198054586138, 61.046539306640625, 68.89192404065813, 59.9524690083095, 62.42369311196463, 58.47619915008545, 55.9955289704459, 52.671486445835654, 55.125482491084504, 56.690550327301025, 54.72450542449951, 49.52598135811942, 49.89457287107195, 47.0625114440918, 47.02835062571934, 45.75380434308733, 40.88542740685599, 31.601157597133092, 36.42659814017159, 43.02747712816511, 37.83247232437134, 40.019914627075195, 49.13908134187971, 49.05466072899954, 52.90666907174246, 54.368406772613525, 49.41059609821865, 50.14459684916905, 53.34505523954119, 58.6712281363351, 60.27421924046108, 57.625107356480186, 56.26491757801601, 56.02626780101231, 54.286445822034565, 49.18187877110073, 39.25101654870169, 44.006210803985596, 30.76952770778111, 12.030774593353271, 10.451469898223877, 6.827556584562574, 7.627481409481593, 9.436345032283239, 26.127074922834122, 37.4873240334647, 35.38981573922293, 42.31114217213222, 33.75160769053868, 44.421713079724995, 46.34874732153756, 40.84827191489083, 55.28221648080008, 58.2138386453901, 59.96011202675955, 55.956469672066824, 60.8412686756679, 68.01572145734514, 60.69579424176897, 54.642047677721294, 36.055105754307334, 32.481039251599995, 34.069790022713796, 50.44520371300833, 50.95500694002424, 44.19019562857491, 30.441280909946986, 31.904380457741873, 11.804323247500829, 4.0927764517920355, 9.034511600221906, 13.74298790522984, 6.759581054959979, 11.324597903660365, 18.202711752482823, 31.72770513807024, 42.67903539112636, 43.42094666617257, 55.64711850030081, 51.35753345489502, 56.418528352464946, 59.221713066101074, 54.348159721919465, 51.229679652622764, 58.00022322790963, 51.719729151044575, 49.89498628888811, 47.59618173326765, 47.608327184404644, 43.97002458572388, 45.37388379233224, 48.83845363344465, 49.80687965665545, 45.33630793435233, 51.122364725385395, 55.103557450430735, 52.93230445044381, 48.03314699445452, 48.083378996167866, 47.320956638881135, 46.979501315525596, 46.641579151153564, 45.98866735185896, 41.478254658835276, 54.531178746904644, 54.13465894971575, 58.70191832951137, 61.63419015066964, 62.57021672385079, 62.03885323660714, 65.86501080649239, 61.05422401428223, 68.19085080283028, 71.78980922698975, 57.77948590687343, 43.15221118927002, 31.073692049298966, 16.90928374017988, 6.5345475758825025, 8.308840002332415, 28.032705238887242, 53.33922570092337, 54.607063497815815, 38.3173280443464, 47.64158126286098, 21.31327956063407, 40.89259794780186, 64.04500661577497, 78.78820160457066, 81.23989432198661, 55.35834094456264, 39.62381519590105, 84.27687549591064, 10.770608476230077, 0.4773327207991055, 0.531486274940627, 0.34321832018239157, 0.34743538818189074, 1.5470189132860728, 0.25610153483492987, 0.28139612610851017, 0.32977770854319843, 0.1264676773654563, 0.3371361494064331], [0.5950486127819333, 0.1433071523372616, 0.2647684897695269, 0.2258505302348307, 0.12162977696529456, 0.19837484242660658, 0.4412512683442661, 0.30545393803289955, 0.07945486969713654, 0.0486738138965198, 0.48526256957224434, 0.21754484091486248, 4.5632763249533514, 62.478431020464214, 35.45575066975185, 31.688267162867955, 8.852597338812691, 36.11627074650356, 60.41130025046212, 22.497532265526907, 52.42880323954991, 26.367095232009888, 32.844350133623394, 39.35781730924334, 48.93578052520752, 44.38875082560948, 21.076328618185862, 22.844368968691143, 39.36424091884068, 52.53534344264439, 52.89455141339983, 50.32285983221871, 52.21954434258597, 54.59925719669887, 55.60314335141863, 43.72824811935425, 45.777233668736045, 47.801038946424214, 49.59000553403582, 52.123482022966655, 49.49811908176967, 50.240478515625, 43.98416416985648, 41.92887313025338, 42.88364246913365, 37.988271781376426, 41.57360826219831, 43.96038048607962, 35.33564758300781, 30.681980405535015, 33.829597745622905, 36.606226444244385, 36.61129515511649, 37.5103052003043, 44.669861044202534, 45.201822076525005, 47.848828656332834, 45.70609106336321, 41.960358892168315, 46.45343235560826, 51.2006778717041, 55.20570986611502, 53.8390964780535, 48.79401642935616, 50.523833002362935, 52.560172830309185, 47.41315228598458, 43.35735327856881, 43.91922630582537, 40.28592641013009, 36.1442928314209, 20.78774561200823, 15.945045743669782, 3.8452911717551093, 3.080903342791966, 1.8534048327377863, 6.105712141309466, 28.603366000311716, 38.240963867732454, 40.543145247868125, 30.25290482384818, 34.93228728430611, 28.617738349097117, 39.41592509405953, 66.18810204097203, 75.21443734850202, 66.84026690891811, 55.09780781609671, 58.49233981541225, 62.655346052987234, 55.26536015101841, 44.90734004974365, 26.51360147339957, 13.686294947351728, 11.036173837525503, 10.485709752355303, 8.722833650452749, 4.399391336100442, 5.112622618675232, 7.692579082080296, 6.744280253137861, 2.145975236381803, 4.742143367018018, 5.109984474522727, 13.38332656451634, 19.742635795048304, 31.999834809984478, 37.10474232264927, 32.24574892861502, 36.660182680402485, 40.64987652642386, 43.4966333934239, 44.40764645167759, 46.16722215924944, 45.43558726991926, 44.94452680860247, 43.65212712969099, 42.15504046848842, 42.237776143210276, 39.93602555138724, 37.24940381731306, 39.75092901502337, 41.54281037194388, 41.06351668494088, 42.75073732648577, 44.11900091171265, 45.253572259630474, 47.43648781095232, 45.68581969397408, 47.015937668936594, 45.44021477018084, 43.262638909476145, 42.51577009473528, 41.758173261369976, 39.43213176727295, 41.208622864314485, 49.386694295065745, 50.350166252681184, 52.21789761951992, 58.5677764075143, 58.33280917576381, 57.38250058037894, 57.45919132232666, 60.0326303754534, 65.58932713099888, 58.18530934197562, 41.064336572374614, 36.13162279129028, 32.03503090994698, 18.804691519056046, 6.457187635557992, 5.088233573096139, 18.715690306254796, 44.05076960154942, 32.996717180524556, 41.909456389290945, 32.554554666791645, 14.236379487173897, 40.04680068152291, 45.21846648624965, 75.40689550127301, 60.692778723580496, 46.0594972882952, 31.462249210902623, 62.5555351802281, 3.1723197059971944, 0.20976255993757928, 0.2047140694090298, 0.3535956990505968, 0.3444809110036918, 0.8451824049864496, 0.15138025342353753, 0.07762795487152678, 0.04736390204301902, 0.1634180210530758, 0.65166894027165, 0.33307196891733576, 0.09706554721508708, 0.560065029987267, 0.13796546682715416, 0.07699372140424592, 0.20748091808387212, 0.2572602555155754, 0.4548058738665921, 0.2704561602856432, 0.3290162836866719, 0.4734677310500826, 0.32229922126446453, 2.3981970165457045, 67.53564957209996, 40.297905104500906, 41.98367009844099, 13.96849342754909, 43.405295848846436, 62.51481873648507, 34.62461410249983, 45.31806543895176, 28.074654987880162, 39.65643004008702, 44.69502394539969, 56.312290396009175, 48.67529950823103, 26.39596152305603, 23.73591317449297, 42.087906973702566, 58.34391239711216, 54.58121967315674, 53.03388711384365, 55.51467541285923, 58.84533609662737, 60.271891593933105, 47.65458829062325, 49.67426981244768, 50.46812582015991, 52.82310308728899, 55.39834867204939, 55.4539828981672, 55.05714348384312, 50.273513725825715, 46.333697523389546, 49.54916054861886, 45.71826778139387, 48.10817016874041, 47.649363245282856, 40.15145097460066, 36.520544733319966, 35.17916372844151, 37.45575141906738, 40.30545779636928, 41.98833233969552, 46.101203850337434, 45.43600763593401, 50.13985122953142, 47.82069887433733, 47.75864451272147, 51.76325961521694, 53.206570693424766, 57.343795640128, 57.029212474823, 51.23968505859375, 53.12992511476789, 53.18515287126814, 53.807812213897705, 44.27154861177717, 45.85681138719831, 41.72221633366176, 40.063441617148264, 25.437985590526036, 18.515865325927734, 6.044243165424891, 4.187169032437461, 2.3329076170921326, 9.073244333267212, 34.23632444654192, 40.872072969164165, 45.50634772436959, 35.908137457711355, 38.00390175410679, 33.349918433598106, 37.03409998757498, 66.87320137023926, 80.03279767717633, 57.65884780883789, 53.7484815461295, 57.67962987082345, 56.70560359954834, 62.128804615565706, 46.83295338494437, 35.78860412325178, 23.610352277755737, 19.206842831202916, 16.721251589911326, 17.915217876434326, 8.909363252776009, 9.654026014464241, 14.320562992777143, 6.316665095942361, 4.008990730558123, 4.897338765008109, 9.755929163524083, 19.887200014931814, 26.911250352859497, 36.94694873264858, 38.7086957522801, 36.95428255626133, 40.6104211807251, 45.69215645108904, 49.08189071927752, 48.03864649363926, 49.13680928094046, 47.40459557941982, 47.66632032394409, 47.19827229636056, 46.54607963562012, 45.39652449744088, 45.22014100211007, 40.99957241330828, 41.242880957467214, 41.50381360735212, 41.00489820752825, 45.50504493713379, 45.91764286586216, 47.40643685204642, 50.73019797461373, 50.39418656485421, 48.392066614968435, 48.14797639846802, 45.89544684546334, 44.87507608958653, 46.73334053584507, 43.57788910184588, 45.14526721409389, 52.90984092439924, 53.02111285073416, 54.44591045379639, 59.12627261025565, 61.62110669272286, 61.56149114881243, 61.015154293605256, 61.56541688101632, 68.10964025769914, 61.36881760188511, 48.84540530613491, 43.61029897417341, 36.47982481547764, 21.16072838647025, 7.434047903333392, 6.5886180230549405, 25.518025364194596, 51.63832058225359, 40.45904425212315, 51.012447697775706, 38.489372389657156, 20.893210581370763, 38.68969242913382, 43.36463499069214, 72.39958313533238, 65.19161919185093, 50.28297022410801, 33.09672955104283, 68.75565596989223, 3.181254220860345, 0.29297842032143045, 0.7358169449227197, 0.6379892400332859, 0.3104631820959704, 0.5556415787764958, 0.0988513088918158, 0.16727999810661587, 0.024153787310102155, 0.08393625422780003, 0.2801440661506993, 0.5323842210429055, 0.3638205703880106, 0.689684271812439, 0.3951491564512253, 0.16653169611735003, 0.2909724536750998, 0.5857078997152192, 0.7554847438420568, 0.38691847239221844, 0.41687316074967384, 0.4657719497169767, 0.857457700584616, 6.088248712675912, 89.5341465813773, 46.57671424320766, 46.673863955906455, 11.941232289586749, 45.95383603232247, 65.91824790409633, 32.155953884124756, 56.231048583984375, 34.194239207676475, 43.57913282939366, 51.22488192149571, 61.70815372467041, 54.96220677239554, 28.520864827292307, 23.873298168182373, 46.848722321646555, 66.51867648533413, 66.07816764286586, 56.20956475394112, 56.430413246154785, 61.882706369672505, 65.39168562207902, 53.14637844903128, 55.554078647068565, 54.18179900305611, 55.740992137363975, 59.6801552091326, 59.544679233006065, 60.393728256225586, 53.770451750074116, 50.97068902424404, 50.536642006465364, 43.81844963346209, 48.36912018912179, 51.95770842688424, 42.151010513305664, 36.01750210353306, 35.53209400177002, 39.97220829554966, 40.60624531337193, 40.58738790239607, 47.60633999960763, 45.27712665285383, 50.76370913641793, 50.211514949798584, 47.458725520542686, 52.85649960381644, 54.608984674726216, 58.47443430764334, 56.77840682438442, 52.40480416161673, 55.77506957735334, 54.5374425479344, 50.68798071997506, 46.229842799050466, 47.55343294143677, 44.13049670628139, 42.51915734154837, 26.494768381118774, 16.925651959010533, 7.484846183231898, 8.581255418913704, 6.2502429229872565, 12.05863686970302, 38.13727937425886, 38.08975716999599, 47.63659593037197, 35.8483829498291, 40.66309200014387, 35.10602699007307, 44.124649797167095, 44.76554816109793, 53.722130502973286, 61.66435922895159, 54.29360246658325, 57.597144331250874, 58.06659589494978, 70.37742110661098, 56.50709703990391, 44.21814128330776, 33.36962005070278, 29.000895023345947, 24.573685271399363, 26.518526009150914, 13.22452461719513, 12.853425673076085, 16.653438908713206, 9.782583321843829, 6.904708078929356, 9.483482480049133, 12.391288825443812, 17.639961515154155, 23.368879795074463, 37.64768498284476, 41.898867334638325, 38.96211045128958, 45.788090229034424, 52.72217355455671, 53.63306501933506, 53.60062388011387, 55.023583684648784, 50.52867589678083, 48.69506018502371, 49.83445010866438, 49.4045581136431, 48.648010458265034, 46.93392808096749, 44.38114602225167, 42.30535779680525, 42.94130556924002, 42.92160395213536, 48.12034688677107, 48.07419695172991, 48.032764843532014, 53.239970684051514, 50.53064571108137, 51.98833956037249, 50.77131393977574, 50.351059096200125, 49.08208179473877, 48.8836099760873, 44.42143167768206, 48.07149062837873, 55.923799242292134, 55.8088412966047, 55.694842202322825, 62.12245396205357, 64.47214712415422, 63.308775493076865, 59.605983189174104, 62.339265550885884, 68.64178889138358, 65.52188791547502, 56.059768540518625, 47.92265674046108, 36.60068872996739, 20.619449819837296, 8.314589636666433, 9.41145919050489, 27.957916566303798, 62.18259756905692, 45.476262024470735, 54.969467639923096, 40.94264234815325, 19.307058436529978, 53.652311529432026, 59.772677421569824, 89.69371891021729, 70.31919520241874, 53.9124173436846, 40.33159344536917, 80.61222880227226, 5.441205535616193, 0.3790136751319681, 0.9229848044259208, 0.7566841766238213, 0.24606038363916533, 1.037728441613061, 0.2274019598428692, 0.1704725053693567, 0.2542969302407333, 0.21051914005407266, 0.5149012506008148], [0.18382141978612968, 0.2651271905217852, 0.1826557373361928, 0.09710481403661625, 0.039575015527329276, 0.08477303039814744, 0.11331952110465084, 0.07776248122432403, 0.22234800032206944, 0.06095651231173958, 0.3307948596775532, 0.039365880856556554, 0.6593174412846565, 23.91427516937256, 60.72979872567313, 35.287062304360525, 34.67546796798706, 31.02136516571045, 55.121025221688406, 15.093186174120222, 53.07238013403756, 56.13075481142317, 38.001796449933735, 35.43897771835327, 52.478229250226704, 45.820694650922505, 28.52093952042716, 28.011183193751744, 42.40659999847412, 50.65593910217285, 48.4060811315264, 53.841160093035015, 56.213306358882356, 57.74904237474714, 51.01701613834926, 40.40163823536464, 43.59272003173828, 47.63035297393799, 49.61451530456543, 51.849736894880024, 50.809077399117605, 50.32497555868966, 47.9064222744533, 45.863078662327354, 47.22892427444458, 46.63277578353882, 47.251797744206016, 46.56463827405657, 43.002863134656636, 37.97113404955183, 37.60234798703875, 35.55925451006208, 36.21789857319423, 40.942072595868794, 42.93419756208147, 44.002479621342246, 45.82781655447823, 41.65588188171387, 44.94771255765642, 53.57926164354597, 52.863673618861604, 54.21450417382376, 55.20483439309256, 47.56482798712594, 51.58642101287842, 49.272396428244456, 55.66603149686541, 47.35977969850813, 45.17360544204712, 37.70844350542341, 37.35870940344674, 31.929612840924943, 23.301180022103445, 8.544858149119786, 5.766485886914389, 2.9018419682979584, 5.528642969472068, 29.016054255621775, 34.47960867200579, 37.06212554659162, 33.206754275730674, 36.27326529366629, 32.119670391082764, 28.03353554861886, 55.654632977076936, 63.22085993630545, 45.69716610227312, 47.671819823128835, 49.74228572845459, 37.55560050691877, 19.74128610747201, 18.97640061378479, 12.922042608261108, 6.39072768177305, 2.7839766357626234, 2.4061639947550635, 1.3128858996289117, 0.09009349133287158, 1.1319541569267, 2.406554396663393, 2.667008706501552, 1.7889457430158342, 2.8279880455562045, 10.368544016565595, 20.732441425323486, 32.26078830446516, 29.155158928462438, 31.05512646266392, 33.87433024815151, 36.65657656533377, 39.02095127105713, 44.183990887233186, 40.395454338618684, 44.627063614981516, 45.77678550992693, 48.60354198728289, 47.51548882893154, 46.40784175055367, 45.93035806928362, 42.045467376708984, 37.94636024747576, 39.3067306791033, 41.037137848990305, 37.77269002369472, 41.52479716709682, 46.176359040396555, 44.09878165381295, 47.08455807822091, 48.972821371895925, 44.30428504943848, 42.65373352595738, 37.751734256744385, 42.716107504708425, 42.9314078603472, 41.204919474465505, 43.169908251081196, 49.11267818723406, 50.7752605165754, 53.65101221629551, 57.50461517061506, 57.422115734645296, 59.92361313956124, 62.19846725463867, 59.0258572442191, 61.268652370997835, 53.92483377456665, 43.51050894601004, 40.91089602879116, 36.287519523075645, 20.624984060014995, 6.7339417678969244, 5.92614072561264, 29.085009915488108, 44.3652902330671, 41.518786975315635, 52.25532409123012, 29.203782422201975, 21.56160123007638, 41.87444789069039, 44.61030803407942, 55.48051459448678, 53.4638729095459, 53.43095581872122, 44.412374700818745, 58.257476806640625, 1.3335437625646591, 0.2982817143201828, 0.2972082176378795, 0.4197332944188799, 0.28043583620871815, 0.4697369826691491, 0.07862826476671866, 0.05812225118279457, 0.12764399924448558, 0.15145177101450308, 0.11988633551767894, 0.18814676840390476, 0.20324774166303022, 0.1089672821440867, 0.1639804858714342, 0.05383925672088351, 0.12245068220155579, 0.01105824126196759, 0.13365434030336992, 0.4420893405164991, 0.12477196407105241, 0.3999497645667621, 0.09239064449710505, 0.698474177292415, 26.227990559169225, 66.48250416346959, 40.76800285066877, 33.058827127729145, 33.19441774913243, 62.07474068232945, 22.881418500627788, 59.27004473549979, 55.87364019666399, 47.917522021702354, 37.178740637642996, 60.59311376299177, 49.01643868855068, 31.774834769112722, 28.509283917290823, 46.190814767565044, 58.51915291377476, 56.81255374635969, 57.905283042362754, 60.308188983372276, 58.29396874564034, 52.38024227959769, 46.74086543491909, 45.25331170218331, 47.388187408447266, 54.69017437526158, 55.3576773915972, 54.13303654534476, 53.71188538415091, 53.374626772744314, 49.70678390775408, 53.81473956789289, 52.591210433415, 53.67675181797573, 51.88959871019636, 48.008831773485454, 43.371878487723215, 41.604968956538606, 37.72026933942522, 40.58161047526768, 43.44313226427351, 43.628680433545796, 45.4446234021868, 46.672012260981965, 44.48132514953613, 48.99173436846052, 55.776160444532124, 55.59495142527989, 57.62173400606428, 57.844357763017925, 52.41143274307251, 52.429855891636436, 53.36583730152675, 57.337643010275706, 50.16842917033604, 47.80220276968819, 40.89244508743286, 40.51851735796247, 35.38905143737793, 25.167987278529576, 13.934620090893336, 8.800854103905813, 2.8383703913007463, 7.304908684321812, 32.27542468479702, 36.127363545554026, 39.24497161592756, 39.03761305127825, 44.61449432373047, 36.335260595594136, 34.34258324759347, 41.76154661178589, 51.02309928621565, 47.97211054393223, 56.10199621745518, 59.133894784109934, 42.5108368737357, 34.62345027923584, 29.473438535417827, 23.88912442752293, 13.805611150605337, 6.39164354119982, 4.84218179328101, 3.4786521026066373, 0.808681672172887, 3.0134875774383545, 2.9898732560021535, 3.0993023897920335, 1.4564817143338067, 3.2810342609882355, 14.253304430416652, 24.294781105858938, 34.98721626826695, 33.614412035260884, 34.29315028871809, 38.00277614593506, 42.00229474476406, 46.48788152422224, 50.21399198259626, 44.78869261060442, 46.43986599785941, 48.51728704997471, 51.0050756590707, 50.888474464416504, 50.214825766427175, 51.71273231506348, 45.89036076409476, 41.749005113329204, 41.71789802823748, 43.00349542072841, 40.797675132751465, 44.804576192583355, 47.42920957292829, 46.505206857408794, 46.49056700297764, 49.2773574420384, 45.225661345890586, 43.29313802719116, 39.63502958842686, 44.47607578550066, 42.51350845609392, 44.40646178381783, 44.16335473741804, 50.90670306341988, 53.59551348005022, 57.24512079783848, 60.15828854697091, 59.06275217873709, 60.59566375187465, 62.91342994144985, 62.73725836617606, 63.74670655386788, 57.7430773462568, 51.76333604540144, 47.838923999241416, 38.35021039417812, 21.216807297297887, 7.893042428152902, 9.474627869469778, 36.99769490105765, 50.34530946186611, 48.33649492263794, 59.641425950186594, 39.548896244594026, 26.344897474561417, 40.228162561144146, 42.2327630179269, 63.915693691798616, 60.74689824240548, 56.95500571387154, 49.65868500300816, 67.00077029636928, 1.651791016970362, 0.36047569130148205, 0.39457468156303677, 0.265696508543832, 0.1585274256233658, 0.36121814431888716, 0.11427835215415273, 0.036749527856175385, 0.1002480121595519, 0.14050681117389882, 0.08663586008229426, 0.21185383200645447, 0.28585491542305264, 0.254982060619763, 0.3632347232529095, 0.2155120721352952, 0.26739102761660305, 0.10222788913441555, 0.1946046304489885, 0.4032505660184792, 0.23262636736035347, 0.4415268078446388, 0.13825018012097903, 0.8234330234783036, 35.47109924043928, 80.07276371547154, 46.13989836829049, 46.60952363695417, 40.209510122026714, 64.25648893628801, 20.98346768106733, 59.3990797315325, 66.7915391921997, 50.379366057259695, 44.72962597438267, 65.5028429031372, 52.61630037852696, 33.050284317561555, 29.996436391557964, 50.12768840789795, 66.26449053628104, 62.94498865944998, 64.32608209337506, 64.8547010421753, 62.791238921029226, 61.88843863351004, 50.63542454583304, 50.46048280170986, 54.42950575692313, 58.03236559459141, 62.52535915374756, 59.487683159964426, 60.01630905696324, 58.25024025780814, 53.586793490818565, 57.548145634787424, 53.07133443014962, 55.298899105616975, 55.316453729357036, 50.2134222303118, 43.436920574733186, 40.78417130878994, 38.572594438280376, 41.673551150730674, 44.50081137248448, 45.02932609830584, 46.58296414784023, 49.75796433857509, 44.38531494140625, 49.87895679473877, 57.73519808905465, 57.316958223070415, 59.07737813677107, 60.07938480377197, 51.98955202102661, 53.06461204801287, 53.43333557673863, 59.6759307043893, 51.85730695724487, 51.65272419793265, 43.176707063402446, 40.878736291612896, 34.47025292260306, 24.433084998811992, 11.593693818364825, 13.024229764938354, 4.285745297159467, 9.631479978561401, 37.05841173444475, 41.395320960453574, 46.32933405467442, 41.852182388305664, 46.73402145930699, 38.06963866097586, 36.76131023679461, 44.980146748679026, 49.58046218327114, 48.722588947841096, 54.491587911333355, 61.74635492052351, 50.5294645173209, 49.124156611306326, 42.08346707480294, 31.880669730050222, 16.45328562600272, 6.6562700271606445, 4.539113964353289, 3.798536309174129, 1.7901403989110674, 4.042071972574506, 3.4611808572496687, 5.933990887233189, 3.346006214618683, 8.37398544379643, 15.000462463923864, 24.71113279887608, 35.91192422594343, 35.49270813805716, 38.811028821127756, 44.26112283979143, 48.025715896061485, 50.70483010155814, 54.75597381591797, 47.362468651362825, 49.70468555177961, 50.552869524274556, 54.49241822106497, 54.015177726745605, 54.64829758235386, 52.55649028505598, 46.6997320992606, 44.11284828186035, 44.75000851494925, 44.526585715157644, 41.18167427607945, 46.75593260356358, 50.86348179408482, 49.42312022617885, 52.02988978794643, 54.48644277027675, 50.89153861999512, 46.534844398498535, 44.34902450016567, 48.250729833330425, 48.51562295641218, 47.59048768452236, 46.727545738220215, 54.90205274309431, 57.869722161974224, 57.15055581501552, 63.504110200064524, 61.071733474731445, 65.52838448115757, 63.795204980032786, 62.27751691000802, 65.01387037549699, 63.17025620596749, 54.334013189588276, 54.62569509233747, 41.89680371965681, 23.419181278773717, 9.61733170918056, 10.43268804890769, 38.78492791312081, 57.7170216015407, 51.50670085634504, 66.23568330492292, 36.662100383213584, 29.793889454432897, 54.49199090685163, 58.85732173919678, 72.67248058319092, 66.77158396584647, 66.64875371115548, 55.65608515058245, 77.13350895472935, 1.9842952149254935, 0.5623970191393579, 0.34992452604430063, 0.5641088272844041, 0.386846303407635, 0.42571023798414637, 0.19581576117447444, 0.1275930412645851, 0.19684591303978646, 0.17394626539732727, 0.1939378883689642], [0.07876980038625853, 0.0630575010020818, 0.012816261882627649, 0.047969348662133725, 0.04125734132581523, 0.0821043521698032, 0.031022183397518735, 0.07079177562679563, 0.08869442676327058, 0.07856284042022058, 0.15146991504090174, 0.06914409582636186, 0.2910444869526795, 9.858667833464485, 62.32427828652518, 37.372115952628, 47.024873052324565, 55.0214193207877, 52.848891326359336, 20.912347657339915, 24.07587810925075, 51.14161818368094, 28.907273258481705, 40.749492849622456, 46.45511729376656, 48.39898354666573, 27.649347066879272, 29.445531095777238, 40.62477615901402, 49.1423921585083, 51.849521500723704, 52.61716890335083, 52.49261896950858, 51.807307720184326, 43.92401361465454, 45.16441992350987, 43.18828623635428, 44.87693125861031, 44.05750240598406, 45.60127053941999, 45.82462733132498, 45.65577220916748, 46.20171649115426, 47.37757403509957, 50.11973966870989, 49.767723083496094, 50.37673616409302, 47.94003071103777, 49.071471895490376, 44.90325798307146, 42.19066388266427, 41.3127555165972, 40.41952289853777, 41.449259826115195, 41.73383372170584, 41.78717156818935, 40.68788317271641, 42.327838693346294, 46.9150185585022, 52.195625168936594, 52.94997024536133, 53.19172586713518, 53.24997956412179, 52.56933750425066, 53.68237638473511, 50.86914110183716, 51.47956466674805, 53.19144099099295, 46.12107569830758, 41.94152579988752, 44.33730288914272, 39.180214405059814, 29.492355006081716, 20.034847497940063, 10.200209140777588, 5.2073152746473035, 12.21885277543749, 25.401015962873185, 25.729941947119578, 24.246709993907384, 32.64999859673636, 36.80335031236921, 30.643490859440394, 36.77886833463396, 32.566269329616, 36.325018950871055, 33.26409428460257, 35.01776054927281, 30.049284390040807, 16.567385469164165, 2.3034040459564755, 6.158011666366032, 4.503739816801889, 0.8134022674390248, 0.31829760170408655, 0.26057218494159834, 0.24105388085756982, 0.9491124195711953, 0.6771739316838128, 1.5057528018951416, 2.8524639436176846, 0.6745544608150209, 1.8462586104869843, 13.539454323904854, 21.41634045328413, 27.076075519834244, 27.78770480837141, 29.188093389783585, 31.512929371425084, 38.44720377240862, 41.004217284066335, 45.00102955954415, 42.01332153592791, 43.115427425929475, 49.42556251798357, 46.930297647203716, 48.180122239249094, 49.54404667445591, 45.96770463671003, 43.942718165261404, 42.08558280127389, 40.90348924909319, 39.17776863915579, 39.02074977329799, 39.27009630203247, 40.62416819163731, 39.14933313642229, 39.32581043243408, 37.687154224940706, 38.85908603668213, 36.822336265019004, 38.537196840558735, 38.45320354189192, 38.8594126020159, 42.15764604296003, 45.884691034044536, 49.83376571110317, 50.604824679238455, 53.64275428227016, 58.476435388837544, 57.79991708483015, 57.41594573429653, 58.21320983341762, 59.54671505519322, 56.31952347074236, 49.62438522066389, 47.80809484209333, 43.250840868268696, 33.3991881098066, 19.02685669490269, 6.222973414829799, 13.652832422937665, 34.737598759787424, 44.54803827830723, 42.273524624960764, 53.608954770224436, 27.578826325280325, 27.356211253574916, 41.55291305269514, 43.31306198665074, 49.3449946812221, 79.77198314666748, 31.806115559169225, 57.55659811837332, 61.47840459006173, 1.9258851834705897, 0.24374649780137198, 0.19233460511480058, 0.18197314467813286, 0.0763415881831731, 0.0910143990601812, 0.09572868395064558, 0.03326028026640415, 0.06989376845636538, 0.06559784111699887, 0.050023481116763184, 0.08556414116173983, 0.03733035383213844, 0.041413462055580955, 0.007360155012325517, 0.09176852966525725, 0.10503059159964323, 0.03766604885458946, 0.01195597617022161, 0.042099898614521535, 0.035327603441796133, 0.04613444408667939, 0.03468964820993798, 0.35686580357807024, 10.416694164276123, 70.18975721086774, 38.587446212768555, 41.77184384209769, 59.65378679547991, 60.12499277932303, 24.49635008403233, 32.267670495169504, 56.46357352393014, 35.95161928449358, 46.82780129568917, 49.652525424957275, 52.053225312914165, 34.34949323109218, 31.039875166756765, 41.74130303519112, 55.70664719172886, 56.042960848127095, 57.60820933750698, 55.36339923313686, 54.33442313330514, 49.26493058885847, 45.61268295560564, 44.94056633540562, 46.325119972229004, 46.067494664873394, 46.419438294001985, 46.18729550497872, 46.64648110525948, 47.43241269247872, 49.460070746285574, 51.687089988163535, 52.60866430827549, 53.91659321103777, 52.29243094580514, 50.39205346788679, 50.73055928094046, 46.592281682150706, 44.140137331826345, 41.60763359069824, 43.42248221806118, 44.48059906278338, 43.55229888643537, 41.9903473172869, 47.146897315979004, 48.09691408702305, 53.619988509586875, 55.648337909153526, 56.258177825382774, 55.54664407457624, 54.57352106911795, 55.558959756578716, 54.95314979553223, 55.016288076128276, 54.22430460793631, 49.365092345646445, 45.51288250514439, 45.31207609176636, 42.420152459825786, 33.19523068836757, 23.370837450027466, 13.528357182230268, 8.313423207827977, 21.637567622320994, 27.780183383396693, 26.874145235334122, 30.633530616760254, 32.68731042316982, 35.608409540993826, 33.97180305208479, 44.60664633342198, 40.3937520299639, 41.43654809679304, 34.580319336482454, 34.47317464011056, 30.278258800506592, 19.745870181492396, 12.40496027469635, 10.09904076371874, 10.52598672253745, 2.1220269671508243, 0.8498200561319078, 0.38497191827212063, 0.3377055488526821, 0.545961543917656, 0.9819201848336628, 2.232692663158689, 1.0398366770574023, 1.6586503003324782, 6.224251883370536, 16.237870625087194, 25.492134639195033, 31.06296055657523, 32.67514412743704, 33.50065265383039, 38.07696206229073, 42.225033146994456, 46.7252528326852, 49.33283533368792, 47.444738796779085, 47.741802079336985, 51.2503262247358, 53.40460130146572, 51.25268513815743, 51.26264190673828, 49.78959948675973, 48.94837066105434, 45.6613689831325, 42.45094687598092, 41.89762708118984, 41.843417235783164, 41.295412812914165, 42.55401645387922, 42.391168049403596, 42.2543580191476, 40.27330500738961, 40.8639748437064, 40.666131837027415, 42.60271985190255, 41.2651047706604, 42.60934495925903, 44.476850509643555, 47.14394433157784, 52.1999226297651, 54.65996013368879, 55.55325528553554, 59.42164748055594, 62.43069689614432, 61.2935060773577, 58.96022456032889, 61.661225591387065, 59.522014209202354, 53.90961027145386, 52.249949659620015, 46.68893807274954, 34.25367062432425, 18.51669042451041, 7.595466715948922, 15.243543454578944, 38.0603141784668, 51.75907679966518, 45.23712239946638, 60.299316133771626, 39.48672376360212, 27.242338963917323, 36.70180238996233, 43.59756987435477, 57.946110657283235, 108.18597425733293, 36.53313486916678, 48.51876354217529, 66.6268390927996, 1.606908911040851, 0.11561864880578858, 0.037420219010008235, 0.08639147212462765, 0.07424274366348982, 0.030908538959920406, 0.10605135932564735, 0.059766280464828014, 0.180948529658573, 0.016373949058886086, 0.12717686859624727, 0.24375146467770847, 0.15341679485780851, 0.1020413123603378, 0.10868444839226347, 0.24548881288085664, 0.17895027117005416, 0.16129926831594535, 0.12473506533673831, 0.12078578796769891, 0.16920543621693337, 0.15571018893803867, 0.14353200527174131, 0.5970400859202657, 15.427675928388323, 81.78354917253766, 47.068066528865266, 60.314081055777415, 69.22110884530204, 66.90230737413678, 27.182365587779454, 27.340074062347412, 62.5017283303397, 41.75028705596924, 52.255831309727256, 54.64968722207205, 58.66587107522147, 34.731904711042134, 35.08457095282418, 47.96463428224836, 64.63909843989781, 61.59419631958008, 62.443085534232004, 59.21939236777169, 61.68197986057827, 49.52739879063198, 51.732548577444895, 47.73184878485543, 52.243800503867014, 50.74987179892403, 51.2958334514073, 51.306377342769075, 50.88710566929409, 53.71798937661307, 56.01914242335728, 58.73629106794085, 56.41777099881853, 56.895873069763184, 58.35081890651158, 53.06631088256836, 51.95786823545183, 48.4189908845084, 45.52765784944807, 43.77730587550572, 46.14367471422468, 46.143952642168315, 47.44693095343453, 43.95621504102434, 47.274421078818186, 50.736506938934326, 56.65263400759016, 56.6187858581543, 57.86939212254116, 57.04924413136074, 57.47451210021973, 57.24220950262887, 55.05601787567139, 54.82685933794294, 54.794626644679475, 52.662509373256135, 47.01022277559553, 46.61959157671247, 42.57523625237601, 33.10965320042202, 23.743233101708547, 14.888106618608747, 8.02549593789237, 19.754202808652604, 37.36870091302054, 32.1658342225211, 34.579909392765586, 38.68202856608799, 40.89109713690621, 36.05127729688372, 44.709778445107595, 37.37973812648228, 40.347862652369905, 39.40744481767927, 42.541773727961946, 34.70981291362217, 27.530173301696777, 19.684877157211304, 12.424019183431353, 13.587169340678624, 2.3458121589251926, 1.0855502869401659, 0.5651166417769024, 0.27145531667130335, 1.4293655008077621, 2.4322097514356886, 4.296563642365592, 4.271902748516627, 2.8929953915732245, 9.222333567483084, 18.619530711855205, 26.74792425973075, 34.57228027071272, 38.04195703778948, 37.278718267168315, 44.38002388817923, 46.64259706224714, 49.9845346723284, 54.74723993028913, 52.229327406202046, 49.50082540512085, 53.430118560791016, 55.20683547428676, 54.305275440216064, 56.4164890561785, 52.933836528233115, 51.21451868329729, 49.720996447971885, 45.55812570026943, 44.220194475991384, 46.06045961380005, 46.38804980686733, 46.75840963636126, 45.08580800465175, 46.35529947280884, 42.94575241633824, 46.49829339981079, 44.181538173130576, 44.91466345105852, 44.16126332964216, 44.80643136160714, 47.65798595973423, 50.596420833042686, 55.16879408700125, 55.75141096115112, 58.8866639818464, 62.45796857561384, 65.23493426186698, 63.13693264552525, 60.48137978145054, 63.54389558519636, 62.49940068381173, 55.75697646822248, 56.405681133270264, 49.90900080544608, 39.18345921380179, 20.832934958594187, 8.402674555778503, 17.512736524854386, 42.92493213926043, 57.48335368292672, 52.32356582369123, 64.15682397569928, 38.56056363242013, 38.74884591783796, 55.48789358139038, 56.289024353027344, 65.3472796848842, 95.87222385406494, 44.124059200286865, 70.10918590000698, 75.69084058489118, 2.5045003294944763, 0.2511919539953981, 0.21196866727301053, 0.23788661509752274, 0.20701126328536443, 0.21800832104470047, 0.2804608334388052, 0.1947209042097841, 0.2650017701089382, 0.16100080790264265, 0.305755044732775], [0.05743399275732892, 0.08221486516829048, 0.05189420894852706, 0.0825477951605405, 0.030373754977647747, 0.0565547436874892, 0.03391657629981637, 0.05917791596480778, 0.06408056896179914, 0.12002848860408578, 0.07292571397764341, 0.04199277489845242, 0.30783649161458015, 2.8969634643622806, 51.6835846219744, 50.07347856249128, 46.16074643816267, 54.1423783983503, 53.67701584952218, 32.047106879098074, 14.630022730146136, 33.309796060834614, 44.93695674623762, 34.602925300598145, 48.903002398354666, 48.347226415361675, 32.99526500701904, 21.965751886367798, 35.54024076461792, 53.86260570798601, 52.02177081789289, 54.249391078948975, 53.12355014256069, 51.83427715301514, 51.905742849622456, 48.68835517338344, 45.94285440444946, 44.96601758684431, 43.80016197477068, 43.26727335793631, 40.34390217917306, 42.57088668005807, 42.14541026524135, 40.22714812414986, 42.97263152258736, 46.858050278254915, 50.26638487407139, 47.88026230675833, 47.78697231837681, 46.44306564331055, 46.57029063361031, 40.81430564607893, 40.720018591199604, 39.544470242091585, 40.14138650894165, 41.132682527814595, 43.46849666322981, 45.34092501231602, 50.533143588474815, 51.28963565826416, 54.289120878492085, 51.83679240090506, 50.216816425323486, 52.62329374040876, 51.27215051651001, 51.250159467969624, 53.90792185919625, 52.34815549850464, 46.15190485545567, 42.45045007978167, 40.42517178399222, 41.35035569327218, 37.84777920586722, 29.870955399104528, 15.258178097861153, 6.27105929170336, 23.122892720358713, 15.82591540472848, 15.86929474558149, 23.647422654288157, 22.983980860028947, 23.655578102384293, 24.98096435410636, 31.658674785069056, 33.68645443235125, 28.488354206085205, 20.22857369695391, 17.023838690349034, 12.851301261356898, 6.388266282422202, 3.0387314685753415, 1.5668019545929772, 0.3546940843973841, 0.01547577734371381, 0.18227452279201575, 0.27034767610686167, 0.16761957774204866, 0.10740141331085137, 0.3099525166409356, 0.6591855883598328, 0.2742515323417527, 2.2874155896050588, 9.303593618529183, 14.028026461601257, 18.89247853415353, 22.878008672169276, 24.587656361716135, 28.089845487049647, 32.29776314326695, 37.40841334206717, 41.31501368113926, 41.2680264881679, 40.563486099243164, 40.704284395490376, 45.44622496196202, 47.72676270348685, 46.84243072782244, 47.50104699816023, 45.938431876046316, 47.67505768367222, 43.49958290372576, 39.75594561440604, 41.18918180465698, 40.774110317230225, 37.57876927512032, 39.46609803608486, 37.526369435446604, 37.65872567040579, 35.781336307525635, 37.32772738592965, 37.74508483069283, 37.91441590445382, 38.24783911023821, 41.45377268110003, 41.95850372314453, 42.28549984523228, 49.80004610334124, 53.230076449257986, 53.171457971845356, 57.65894160951887, 58.564733096531455, 59.703869410923545, 57.70147500719343, 57.65093033654349, 51.378923484257285, 48.156453200748985, 47.41173832757132, 41.151359285627095, 30.128479957580566, 14.317798478262764, 6.338134595326014, 12.323233825819832, 29.274000917162212, 44.381983280181885, 39.21269028527396, 45.788527965545654, 26.00536332811628, 34.23834637233189, 31.451486451285227, 40.945769037519185, 22.68938418797084, 53.48290402548653, 34.81824650083269, 33.46838174547468, 52.93367671966553, 0.6317465007305145, 0.05292382137849927, 0.21718348030533108, 0.03732081023710115, 0.02718925442812698, 0.09382874518632889, 0.039160878464047394, 0.012110077410138078, 0.028684616687574556, 0.03618818601327283, 0.09934364033064672, 0.12845859410507338, 0.054767051578632424, 0.03878257144242525, 0.03608551009425095, 0.025468326772430112, 0.0728147260046431, 0.030963184777647257, 0.047615217843226025, 0.10374828255070107, 0.010776147961483469, 0.16343330166169576, 0.03080228716135025, 0.3716204932757786, 2.935162271772112, 59.74599633898054, 53.05981084278652, 47.42193133490426, 59.38346018110003, 58.88947800227574, 31.43913950238909, 20.775482041495188, 43.159322670527864, 55.08087853022984, 40.15484516961234, 54.113241127559114, 54.62170335224697, 37.94182654789516, 24.149195500782557, 34.59041159493582, 56.431149755205425, 56.824483803340364, 58.08075632367815, 57.576195512499126, 55.314094815935405, 55.45338882718767, 54.947455746786936, 50.785519531794954, 47.82389851978847, 46.173030853271484, 45.20225286483765, 44.03151266915457, 44.67882769448416, 45.136008739471436, 43.05608286176409, 45.15504680361067, 48.265359265463694, 51.226862158094136, 52.13518973759243, 50.89936229160854, 49.9285043988909, 48.764802728380474, 44.53274876730782, 42.373022828783306, 43.76117215837751, 40.838294301714214, 43.35475812639509, 44.55907201766968, 49.52229533876692, 54.67457219532558, 55.621910435812815, 56.03982721056257, 52.13737842014858, 51.512516498565674, 56.376533440181184, 52.17091737474714, 54.56387002127511, 56.88957800183977, 54.01841558728899, 50.60523114885603, 48.23967524937221, 41.93367086138044, 41.47391550881522, 41.89610195159912, 34.90356690543038, 25.15760666983468, 16.760086808885845, 22.514819383621216, 17.06435363633292, 19.62639938082014, 24.33757679803031, 24.541304928915842, 16.609925815037318, 19.77296989304679, 29.283453941345215, 31.946361473628453, 24.521217686789377, 19.072984048298427, 15.810839550835745, 12.012545125825064, 6.34066504240036, 4.652852066925593, 1.2901340233428138, 0.9426584116050175, 0.06858425015317542, 0.11587394082120486, 0.1985211210059268, 0.11376169523490326, 0.12676391218389782, 0.30222986532109125, 1.1397844510419028, 3.263082287141255, 5.6513915828296115, 17.49107551574707, 18.30958025796073, 24.26075404030936, 28.333468437194824, 29.19326979773385, 31.96755347933088, 38.77189656666347, 43.05533593041556, 45.40659591129848, 43.246241160801475, 44.981783049447195, 43.87313543047224, 47.720818519592285, 50.440541471753804, 49.47893163136074, 49.797916480473106, 47.61614390781948, 49.354656151362825, 45.962833949497764, 42.82074390138899, 43.87365307126726, 43.5361339024135, 40.97848463058472, 41.543466976710725, 42.38285105569022, 40.7663630758013, 39.54985857009888, 39.60332843235561, 40.92160667691912, 41.21841982432774, 42.95952722004482, 45.84187970842634, 47.16014405659267, 46.203686305454795, 50.24735723223005, 57.98154647009713, 57.16720369883946, 59.82362856183733, 61.80339963095528, 61.7564298084804, 62.434372493198936, 61.86353628976004, 56.28481721878052, 52.74568278448922, 51.30270521981375, 42.110981941223145, 31.185592787606375, 15.03876267160688, 6.303665450641087, 14.683937277112689, 37.458402156829834, 50.11540399278913, 43.970966066632954, 50.34513923100063, 31.375021525791713, 36.02520418167114, 29.666539396558488, 42.760193824768066, 24.3664813041687, 56.40798793520246, 41.42145660945347, 40.55078479221889, 58.73964704786028, 0.44709967023559977, 0.050490425167871375, 0.10985049725111042, 0.031375476225678406, 0.019471461419016123, 0.020870441171739782, 0.11600157325821263, 0.0557449664255338, 0.019762352774185792, 0.02069458525095667, 0.03566956812781947, 0.15406586788594723, 0.19493544341198035, 0.08039586206099816, 0.20915992584611687, 0.10326570844543831, 0.15673960798553058, 0.12313982950789587, 0.16208277270197868, 0.2650197648576328, 0.24860982969403267, 0.2312159373291901, 0.13539360197527067, 0.6549152689320701, 5.6169193983078, 73.82237270900181, 60.33518968309675, 61.950972420828684, 65.22556809016636, 70.40118394579206, 44.21954134532383, 19.766546283449443, 40.777865818568635, 57.19210604258946, 45.484975065503804, 59.531491552080425, 57.42385278429304, 41.188035351889475, 29.776313986097062, 43.0715217590332, 63.20013345990862, 61.38802242279053, 63.135077476501465, 59.25967107500349, 56.7243081501552, 60.378685406276155, 55.70168617793492, 52.28061900820051, 50.42260817119053, 49.839584827423096, 48.365593978336875, 46.28355584825788, 48.82168763024466, 48.41161189760481, 46.4978278705052, 49.751971517290386, 51.96307591029576, 55.227621010371614, 54.535229546683176, 52.673570905412944, 53.30929980959211, 53.095660073416575, 45.87822920935494, 44.951478481292725, 45.106527532849995, 43.70474236352103, 45.66862637656075, 47.45105818339756, 48.82432794570923, 55.70437165669033, 56.2223459652492, 56.01100260870797, 55.07624408176967, 54.48100233078003, 58.31133229391915, 53.222659247262136, 56.03081539699009, 58.77178941454206, 55.90831518173218, 51.245090757097515, 49.89313111986433, 42.706880296979634, 40.738462584359304, 40.96457781110491, 34.37659467969622, 23.582470893859863, 17.92390833582197, 30.909231662750244, 24.22560657773699, 26.544427156448364, 27.382456336702617, 26.225216490881785, 30.9573792048863, 30.661514486585343, 38.377096448625835, 40.75319971357073, 38.628916536058696, 32.71037496839251, 29.807407174791607, 21.19769106592451, 12.324841465268817, 10.09186588014875, 3.526972915445055, 0.6689871624112129, 0.07356266837034907, 0.26370351548705784, 0.48379487118550707, 0.19794444766427788, 0.23478883132338524, 1.670413817678179, 5.9802228978702, 6.07035927261625, 11.887017233031136, 19.6811911378588, 22.092210837772914, 30.330259118761333, 33.481409617832725, 32.70905828475952, 34.633896895817344, 45.05711889266968, 47.14129359381539, 48.824762208121165, 47.16167613438198, 48.57685048239571, 46.73430633544922, 51.92291532244001, 54.1278566632952, 51.95127092088972, 54.292859009334016, 50.663752351488384, 53.73752771105085, 47.554648876190186, 46.12053026471819, 47.84209585189819, 47.50414589473179, 43.531864234379356, 45.14278670719692, 44.44332545144217, 42.981903893607004, 42.3879371370588, 43.19651985168457, 44.78365516662598, 44.60221685682024, 43.66739232199532, 47.51261574881417, 48.56117187227522, 46.679335662296836, 54.743932587759836, 59.629919733319966, 59.59324714115688, 62.40564169202532, 62.676767349243164, 63.521140234810964, 63.204073088509695, 64.35659163338798, 58.192938464028494, 56.01962184906006, 55.22600902829851, 47.96965435573033, 35.60277802603585, 17.990862914494105, 8.442566769463674, 15.7644134249006, 39.43117291586739, 56.3304043497358, 50.546935762677876, 55.65868725095476, 35.7454697063991, 46.16221250806536, 45.62497431891305, 51.75557490757534, 31.078517573220388, 55.3496070589338, 49.39323254993984, 47.351594720567974, 68.87817355564663, 0.8489165731838771, 0.10434527123080832, 0.32014557825667517, 0.07911911021385874, 0.15085440235478537, 0.13200092688202858, 0.11222826716090951, 0.10249301990760223, 0.10839178945337023, 0.0972774401307106, 0.16434108652174473], [0.03323300315865448, 0.058705126334513934, 0.02852171739297254, 0.010020763762960476, 0.04613872903532215, 0.0619058438709804, 0.044393940695694516, 0.027172073921454803, 0.03297433882419552, 0.05501404171809554, 0.04295245411672762, 0.08818633974130664, 0.028887240814843347, 0.3479565573590142, 39.977662631443565, 55.35512740271432, 31.74957459313529, 46.10714108603341, 54.049109254564556, 42.937623023986816, 21.64275618961879, 26.244872944695608, 42.245408739362446, 27.649430445262364, 44.2633011000497, 50.03018086297171, 36.07491159439087, 15.337173904691424, 14.84219639641898, 42.35377631868635, 60.45980562482561, 56.04388495853969, 55.296686104365754, 57.84262766156878, 56.38375609261649, 55.5524388722011, 52.75284290313721, 49.606973034994944, 46.65688950674874, 46.37855509349278, 44.16012382507324, 44.49823011670794, 44.53096308026995, 39.84085260118757, 38.23160811832973, 39.71820994785854, 43.02278709411621, 46.06409352166312, 47.919074944087434, 44.944335733141216, 44.51901912689209, 43.74102585656302, 41.93675933565412, 39.75081784384591, 39.08896371296474, 39.50761699676514, 43.17232622419085, 49.75332989011492, 50.70601824351719, 50.81686632973807, 52.275400911058696, 49.94107716424124, 47.89677470070975, 52.360089029584614, 51.3399475642613, 50.032859393528526, 51.53590760912214, 50.70727586746216, 50.05427026748657, 43.79199089322771, 41.463135378701345, 40.694970335279194, 39.10671636036464, 40.07197053091866, 32.5088563646589, 25.684877668108257, 20.647367681775773, 15.28237693650382, 15.295821700777326, 19.943400519234793, 18.298053196498326, 7.634682348796299, 10.279083354132515, 15.77821602140154, 16.073889664241246, 12.161610041345869, 9.253174015453883, 9.821443728038243, 5.908305134092059, 2.2265656547886983, 0.6045236214995384, 0.8671182479177202, 0.17394462334258215, 0.0930135939270258, 0.11450768341975552, 0.014920520263590982, 0.07924472740186111, 0.33158443016665323, 1.163923795734133, 1.3614242779357093, 0.8491288732205118, 2.6043142420904974, 12.547808289527893, 12.978831103869847, 16.637468474251882, 22.22115203312465, 23.3844142300742, 27.615210567201885, 32.04105499812535, 34.963717460632324, 37.90665476662772, 37.21035841533116, 39.112323556627544, 42.01546505519322, 43.31936052867344, 43.536248547690256, 44.0980555670602, 46.45527015413557, 44.50616148539952, 43.078879901341026, 44.92783028738839, 38.815333230154856, 40.320233140672954, 40.36582721982683, 38.260370186397004, 37.767211369105745, 39.33537810189383, 38.49603223800659, 37.2752719606672, 38.44596699305943, 37.56063100269863, 39.93990612030029, 45.40026610238211, 50.35865000316075, 50.037243706839426, 45.6221672466823, 49.36857686723982, 54.009594849177766, 55.62548180988857, 56.30229193823678, 59.01749856131417, 57.9519019808088, 60.543698174612864, 51.594237736293245, 45.29973609106881, 46.567361967904226, 46.914174352373394, 38.076656341552734, 28.55451147896903, 10.009210109710693, 4.7896660055433, 9.30514393533979, 38.096660205296104, 42.243418080466135, 42.03688287734985, 28.84920195170811, 29.628925323486328, 34.8805718421936, 30.746820994785853, 36.378308159964426, 21.096539190837316, 10.789278285843984, 34.99366419655936, 48.5919315474374, 50.04277099881853, 0.3624042235314846, 0.082506587728858, 0.02850963268429041, 0.028791319711932113, 0.08782405632414989, 0.036721416150352786, 0.01661324461123773, 0.03477954052920852, 0.02146173863937812, 0.035380586848727295, 0.06136579106428793, 0.061680590600839684, 0.035993728054953475, 0.13711534387298993, 0.024127606036407605, 0.08027755948049681, 0.036777256189712455, 0.028845979100359336, 0.04313211661896535, 0.010812117950990796, 0.07417727860489062, 0.031262632459402084, 0.08681639789470605, 0.0602855361731989, 0.28278837140117374, 45.918459279196604, 60.127820696149556, 36.44415276391165, 53.05548211506435, 57.498316628592356, 41.088613578251426, 24.62714123725891, 36.58137968608311, 43.226845264434814, 35.66610738209316, 47.3507261957441, 53.84814303261893, 39.08308553695679, 19.945022923605784, 11.138364468302045, 35.956542083195274, 61.057044982910156, 59.172234943934846, 57.43683896745954, 60.93723719460623, 59.951565742492676, 59.270009994506836, 55.96040235246931, 53.59520428521292, 53.18599360329764, 51.44014753614153, 47.92285476412092, 48.16354383741106, 46.47586808885847, 43.447544370378765, 41.19384404591152, 41.38491255896432, 45.329026222229004, 47.1320663860866, 50.49382373264858, 47.67268139975411, 47.972510065351216, 46.71592140197754, 44.519512448992046, 42.693477221897666, 42.400652340480256, 42.720488343920024, 46.7948842048645, 53.048968178885325, 53.70189734867641, 55.62521777834211, 55.14352348872593, 52.438627992357524, 50.07920387813023, 53.217712129865376, 55.3192469051906, 52.60346358163016, 53.443427835192, 52.66772747039795, 53.68342556272234, 46.98049143382481, 44.08953012738909, 41.218468461717876, 39.316697869982036, 40.93728528703962, 39.460271971566335, 35.13821799414498, 33.220028809138704, 27.456277472632273, 25.92057272366115, 29.473285675048828, 21.990626437323435, 7.474237152508326, 4.267257443496159, 9.138687678745814, 11.841131329536438, 7.3617188930511475, 6.010871401854923, 6.534347815173013, 5.36798802443913, 2.691695438964026, 1.005818622452872, 0.9403479184423174, 0.3025707613144602, 0.06632484389202935, 0.1780182354684387, 0.15491675079933234, 0.13223430221634253, 0.0636134993817125, 1.1432713610785348, 1.187911257147789, 4.045774059636252, 8.638558081218175, 18.13220317023141, 18.615780421665736, 24.751781497682842, 27.353953089032853, 26.82772258349827, 33.59801428658621, 39.27971955708095, 40.561703886304585, 42.40153476170131, 42.35531881877354, 41.37768643242972, 45.09074469975063, 45.79835271835327, 48.91196557453701, 48.558330059051514, 48.8921354157584, 48.54175165721348, 47.361079011644634, 48.42256225858416, 41.41623503821236, 40.88660512651716, 40.805384159088135, 41.20425592150007, 39.900975363595144, 42.39360339300973, 41.98114790235247, 41.021125725337434, 40.97890152250017, 41.38389464787075, 43.20542744227818, 49.334214551108225, 54.433921337127686, 55.853111743927, 50.52518442698887, 53.45522935049874, 55.037966455732075, 59.542692048209055, 57.76811170578003, 62.06096240452358, 60.67720781053816, 64.46633843013218, 51.86122226715088, 43.50458908081055, 48.82331003461565, 46.78380877631051, 40.16793210165841, 27.980916840689524, 7.277048145021711, 4.69618798153741, 14.394778438976832, 47.495418957301546, 46.75175673621041, 49.5847179549081, 34.330396107264924, 29.240983077457972, 29.757352352142334, 30.708369663783483, 36.98594897133963, 28.566368579864502, 15.725275959287371, 35.05352987561907, 53.546723229544504, 59.237165859767366, 0.8686718216964177, 0.1256841594087226, 0.04047241880159293, 0.0152102089154401, 0.05804115267736571, 0.01918179990856775, 0.00935997158688094, 0.07604106502341372, 0.03220712606395994, 0.03170970900516425, 0.020072014104308825, 0.21277281269431114, 0.21655415264623507, 0.23447817085044725, 0.06654409212725503, 0.13905291418944085, 0.0893405820908291, 0.11652244387992791, 0.10105466137507133, 0.108924358018807, 0.15875742185328687, 0.1457402974899326, 0.17363335218812737, 0.1896820217370987, 0.6410311396632875, 61.18235574449812, 66.67925630296979, 43.09366219384329, 59.536105155944824, 68.91944585527692, 58.03136157989502, 28.55768506867545, 36.05715199879238, 51.58761610303606, 38.75593308040074, 53.73825032370431, 58.253856795174734, 43.53976433617728, 21.34391243117196, 19.864795548575266, 50.151378290993826, 67.14942005702427, 61.61704894474575, 61.7919351032802, 63.625766209193635, 58.972911970955984, 61.67439242771694, 56.77073948723929, 54.332904951913015, 53.48825413840157, 51.67334645135062, 48.64170496804373, 49.7037683895656, 49.76703521183559, 44.757147789001465, 44.32257270812988, 46.16622509275164, 49.52846186501639, 52.38209744862148, 55.13930593218122, 51.93883711951119, 53.73369230542864, 50.73524931498936, 47.53148010798863, 44.07785020555769, 45.45025144304548, 44.701992988586426, 48.82011386326381, 54.79327522005354, 54.87629577091762, 55.824669292994905, 56.287061486925396, 52.94285181590489, 51.29084464481899, 57.455241271427695, 56.00226524897984, 52.66364540372576, 55.59887020928519, 52.08463117054531, 52.986163411821636, 48.03183031082153, 44.59599821908133, 41.385829721178325, 38.490855830056326, 41.26698773247855, 36.45397056852068, 36.02432870864868, 35.452349526541575, 28.482719217027935, 29.142794609069824, 32.371334144047324, 23.158781903130667, 12.123466168131147, 14.883263724190847, 25.113089561462402, 28.73850151470729, 27.176930359431676, 20.498137746538433, 17.702104466302053, 9.722887005124774, 5.817942074366978, 4.372301612581525, 2.569296189716884, 0.3406345673969814, 0.11812114023736545, 0.33851327693888117, 0.2073367429631097, 0.1650726965495518, 0.37327356742961065, 2.630531966686249, 7.223415000098092, 10.448051384517125, 19.370320047651017, 25.669900826045446, 23.23294002669198, 29.63258355004447, 31.572180134909495, 32.34928403581892, 40.18804713657924, 45.27295078550066, 44.12608112607683, 47.506112234933035, 44.52921213422503, 44.46603911263602, 49.462714535849436, 48.46390404020037, 51.64734281812395, 51.08677952630179, 52.32770347595215, 48.59754916599819, 49.063630853380474, 50.29217658724104, 43.38975967679705, 45.01723623275757, 45.530013288770405, 45.07703242983137, 43.44193022591727, 45.20749528067452, 44.57449701854161, 41.922928946358816, 45.72346155984061, 43.06011281694685, 43.61599997111729, 51.216835907527376, 57.754243101392476, 58.23727144513811, 52.2584924697876, 54.921969754355295, 58.82424136570522, 63.13453551701137, 62.83404677254813, 63.24744374411446, 61.1344826562064, 64.47159126826695, 57.72930949074881, 55.86176225117275, 55.07478148596627, 51.416843278067454, 44.47430746895926, 34.10702541896275, 10.627534644944326, 5.8477837187903265, 13.713706459317889, 46.71535859789167, 53.15424033573696, 52.385797364371165, 38.016689913613455, 40.17572798047747, 43.61159481321062, 42.0466103553772, 47.636318002428325, 33.12837164742606, 13.225187301635742, 48.39092016220093, 63.487260818481445, 64.23253154754639, 0.8788272110479218, 0.2189286859439952, 0.14050120647464479, 0.05626303469762206, 0.1847665919257062, 0.15550468782229082, 0.16384879579501493, 0.18975811265408993, 0.11428075416811875, 0.1806745779301439, 0.17410634537892683], [0.04246955092198082, 0.040862861422023604, 0.04033193151865687, 0.07087034998195511, 0.05888864291565759, 0.042927375462438376, 0.011558760073967278, 0.07319993712008, 0.017139816623447195, 0.05635931542409318, 0.021444422425702214, 0.13737614559275763, 0.02715213008091918, 0.08672563705061163, 25.307454994746617, 64.06843594142369, 33.17331954411098, 34.54348693575178, 53.6255053792681, 34.70547028950283, 26.17226426942008, 19.836639710835048, 29.432034220014298, 30.615159579685756, 35.696537017822266, 49.276784215654644, 40.31498725073678, 14.933599948883057, 2.144642702170781, 8.003705518586294, 38.854382106236045, 61.68970625741141, 61.66433143615723, 56.10432038988386, 57.9602815083095, 57.547169412885395, 59.072743688310894, 57.626715864454, 54.579569475991384, 54.28620958328247, 52.55412442343575, 49.22564547402518, 49.22974143709455, 45.88964509963989, 42.35692385264805, 38.60990973881313, 39.889114788600374, 42.49358449663435, 45.270810740334646, 44.26808146068028, 45.07140438897269, 43.09976271220616, 40.54382964542934, 39.164890153067454, 40.14400250571114, 39.19104317256382, 46.46951396124703, 52.477791513715474, 50.75169570105416, 53.51551192147391, 49.41560574940273, 45.36780759266445, 47.98186928885323, 51.33273186002459, 50.47983006068638, 52.053791591099326, 51.575519289289204, 48.94668572289603, 53.00727203914097, 44.891675336020334, 40.827705247061594, 38.254266193934846, 37.96083681924002, 36.71361085346767, 38.52473872048514, 32.43109907422747, 32.958248479025706, 27.22339470045907, 25.41224251474653, 26.07492869240897, 21.215038980756486, 4.04064324923924, 1.802613609603473, 4.7359442710876465, 4.2707719291959485, 3.4951288870402744, 1.1728577677692686, 1.333844814981733, 1.7998392156192233, 1.2309597986085075, 0.34070491790771484, 0.04902410420722195, 0.05652676768867033, 0.06268801832837717, 0.4239286764391831, 0.18107217230967113, 0.0960252716072968, 0.0275321062986872, 0.6531579175165722, 1.8350455207484109, 2.7267957840647017, 4.362478162561144, 8.96523892879486, 11.740015063967023, 17.640449626105173, 20.443088906151907, 22.272368941988262, 26.704432010650635, 36.56500278200422, 36.28246818270002, 36.77654416220528, 36.23281288146973, 38.36251217978341, 40.78747517721993, 42.259211335863384, 47.0103235244751, 45.01304646900722, 45.163954394204275, 46.410471643720356, 45.85147517068045, 43.42661987032209, 38.470532349177766, 38.03800351279122, 38.26551532745361, 37.64287335532052, 36.780601910182405, 39.214208466666086, 40.40845094408308, 37.49780191693987, 38.90091071810041, 39.00357730048043, 46.24248504638672, 51.05800356183733, 54.351897852761404, 52.936376094818115, 51.17628622055054, 51.04001814978463, 54.18566567557198, 55.54249947411673, 54.9751477922712, 58.97079277038574, 63.36455563136509, 61.31872803824288, 40.442292145320344, 27.99446756499154, 36.75328854152134, 36.54338346208845, 31.00258071081979, 15.485724653516497, 4.299164874213083, 2.8759753448622565, 18.14004421234131, 43.58842951910836, 43.42586599077497, 37.89421054295131, 22.100682428904943, 34.94589533124651, 34.61833987917219, 30.414109979357036, 30.95086874280657, 18.38947238240923, 24.47195495877947, 36.95193753923689, 35.3104464667184, 57.765210832868306, 0.7420944252184459, 0.1301259853477989, 0.049923790751823356, 0.00929743271054966, 0.027495847083628178, 0.03166248296786632, 0.012321395267333304, 0.039878191759011576, 0.02024535944552294, 0.08069966254489762, 0.041722511007849655, 0.06734867181096758, 0.01589509502186307, 0.043784260018063445, 0.030828132560210567, 0.1439799198082515, 0.05750643315591982, 0.05517793845917497, 0.03221660859084555, 0.04825138852798513, 0.019701952979500805, 0.03150163624169571, 0.12464324597801481, 0.07484713516065053, 0.06244111979114158, 29.370296001434326, 68.30606583186558, 34.946982724326, 43.83369050707136, 59.4235234941755, 36.68528304781233, 26.939689329692296, 27.202055045536586, 35.11420154571533, 34.64428097861153, 42.9476249558585, 54.957905837467735, 46.77985177721296, 18.306252070835658, 2.9893119718347276, 2.786744407245091, 28.52471239226205, 56.63728543690273, 65.8150463104248, 56.810747214726035, 57.685751233782085, 58.79688630785261, 61.974297523498535, 59.559833254132954, 57.234774930136545, 57.22886201313564, 54.94101129259382, 53.973665714263916, 53.63186992917742, 50.90598045076643, 47.89139679500035, 44.20129884992327, 42.61143636703491, 45.16859231676374, 45.89669057301113, 45.50100108555385, 45.8671989440918, 44.925151756831575, 43.674847739083425, 43.495403562273296, 43.443410192217144, 43.41336270741054, 48.85608121326992, 54.34958757672991, 53.061249119894846, 56.25845922742571, 50.57556928907122, 45.33119058609009, 51.02414151600429, 53.0868810244969, 52.33855308805193, 52.98382881709507, 53.699086802346365, 52.39181797845023, 54.073111806597026, 50.17608608518328, 43.4262238230024, 41.645452635628835, 38.16695860454014, 38.49861696788243, 38.04030336652483, 38.04058476856777, 32.57238027027675, 33.147903033665244, 29.18763828277588, 30.51937518801008, 28.470846482685634, 6.616302686078208, 0.37945095023938585, 0.4536296198410647, 2.273829907178879, 3.1085322030953, 1.2522803459848677, 0.4446274957486561, 0.696770674415997, 1.3764313012361526, 0.30436027528984205, 0.06975319635655199, 0.0837490057040538, 0.08906557863312108, 0.27058706326144083, 0.10027178124125515, 0.09904528848294701, 0.34344826212951113, 0.8869461811014584, 0.6476904451847076, 3.3802428117820194, 12.92091873713902, 17.18515154293605, 19.950086423328944, 23.79686450958252, 26.522948537554058, 27.90900124822344, 33.42364924294608, 41.49195303235735, 42.60570410319737, 40.83037335532052, 38.9730156489781, 41.708351203373496, 45.587422779628206, 46.85827956880842, 48.298321519579204, 46.722942556653706, 47.026425974709646, 49.69589608056204, 49.06083420344761, 47.484753472464426, 42.082650661468506, 42.08464132036482, 39.84828717367989, 39.85603094100952, 38.657112325940815, 41.14602306910923, 43.0877423286438, 39.47163575036185, 40.65173169544765, 42.16749511446272, 50.79079668862479, 54.50814546857561, 56.677223682403564, 56.02778945650373, 54.18007584980556, 54.96872418267386, 57.55236666543143, 57.830784457070486, 59.66352122170584, 60.56367424556187, 65.21736921582902, 62.39724131992885, 45.40617554528372, 36.009685380118235, 37.6059193611145, 35.33247225625174, 27.513259649276733, 12.527982473373413, 3.1939637788704465, 4.308235747473581, 24.312823840550013, 48.07035459790911, 48.73664167949131, 43.918375151497976, 23.252681595938547, 33.979696205684114, 28.096670355115617, 32.617408071245464, 32.21647616795131, 21.30935209138053, 20.680976118360245, 37.62193495886666, 45.68816818509783, 60.01006262642996, 0.9631013146468571, 0.08718469991747822, 0.029662171910916055, 0.04394767499927964, 0.08746042262230601, 0.04317011118733457, 0.03727727882297976, 0.048077215374048264, 0.011351432002681707, 0.1005655936896801, 0.009085188653053982, 0.17118138447403908, 0.13983487151563168, 0.20910955140633242, 0.14991723692842893, 0.28453120216727257, 0.14137118336345467, 0.25925813402448383, 0.14453926336552414, 0.08203459198453597, 0.18034774118236133, 0.15242548233696393, 0.17461208466972622, 0.1370381401585681, 0.1754034464912755, 41.53787020274571, 76.93485995701381, 43.96512957981655, 47.173265729631694, 69.80701569148472, 46.8871180670602, 33.69236734935215, 28.690102100372314, 38.03458152498518, 39.61706849506923, 48.35561983925955, 60.155689920697895, 49.34055478232247, 21.030425344194683, 2.9097776796136583, 10.248125655310494, 48.10983773640224, 69.9370025907244, 66.13679654257638, 58.64359515053885, 59.82861736842564, 63.00882870810372, 62.22451605115618, 60.76216343470982, 57.90464033399309, 58.52578844342913, 56.80794014249529, 54.35737303325108, 53.812547411237446, 52.56160415921892, 48.989920888628276, 45.13321903773716, 46.02885225840977, 49.034587383270264, 50.31974703924996, 49.24862316676548, 51.29611832754952, 49.27310861860003, 46.35472624642508, 46.92933184759957, 44.9113005229405, 46.21087769099644, 49.88740233012608, 55.992631571633474, 55.18080404826573, 59.153523445129395, 51.6763584954398, 46.911353383745464, 52.62001419067383, 55.64015640531267, 51.99938372203282, 55.2088817187718, 54.06270340510777, 52.11241006851196, 56.464233602796284, 50.382624762398855, 46.05819797515869, 41.635447229657856, 39.1850642476763, 41.08988162449428, 39.87060478755406, 38.314413275037495, 41.12812450953892, 36.853842871529714, 33.45730284282139, 33.50574915749686, 31.00961923599243, 6.031669531549726, 4.622810661792755, 10.321167724473135, 13.228829894747053, 10.449189152036395, 9.459061299051557, 5.279411520276751, 4.714295855590275, 4.360674236501966, 0.6584843631301607, 0.5420465054256576, 0.2135848698339292, 0.22048904507287911, 0.7323594561644963, 0.27577172219753265, 0.29103417322039604, 1.5049398626599992, 1.2356027151857103, 3.393901450293405, 7.761874335152762, 19.79434081486293, 23.429105043411255, 25.037826674325125, 29.44321734564645, 31.59482431411743, 33.10562671933855, 38.54153599057879, 47.034649167742046, 45.90127290998186, 45.586161681583945, 42.53755964551653, 44.295210702078684, 47.7823726109096, 48.713799476623535, 52.473299503326416, 50.89044080461775, 50.322745186941965, 51.47208840506417, 50.89631898062569, 50.097936221531455, 44.23120389665876, 44.10755722863333, 42.81979547228132, 42.77986070087978, 42.15338332312447, 45.815052713666645, 45.992360319410054, 42.10634749276297, 43.1473821912493, 44.26036548614502, 51.92445434842791, 56.02844953536987, 61.35974325452532, 59.41559559958321, 55.993576526641846, 57.511434827532085, 62.10367298126221, 63.475622585841585, 61.85937431880406, 62.11361585344587, 69.06765093122209, 67.70618615831647, 52.72645711898804, 41.86299378531319, 46.7400802884783, 41.33043868201119, 35.32261971064976, 17.461418867111206, 5.0693996122905185, 4.428904243877955, 24.109074865068706, 54.04531553813389, 54.67746959413801, 47.125580242701936, 28.986328125, 44.93229450498308, 45.040085383823936, 41.64493499483381, 43.740911211286274, 24.58343185697283, 31.719471522739955, 52.93433679853167, 49.69867188589913, 74.26457691192627, 1.0178025279726302, 0.277860307267734, 0.1108116963878274, 0.12233010652874197, 0.14827904983290605, 0.08825627634567873, 0.20013747284454958, 0.19026742103908742, 0.15416064565735205, 0.23534707565392765, 0.12153118582708494], [0.027588925124811273, 0.030809557664075067, 0.052175298865352354, 0.022392271385927285, 0.03518049026440297, 0.018749771573181664, 0.04033436067402363, 0.0522420972452632, 0.038855422354702435, 0.12422562124473707, 0.06239022287939276, 0.10515808832964726, 0.15860631210463388, 0.33948493908558575, 25.73006354059492, 54.0552201952253, 46.46481697899954, 42.89873048237392, 45.502286502293174, 38.19837835856846, 28.910778624670847, 37.91294983455113, 26.14122145516532, 26.1066472189767, 31.3734164919172, 45.14143875667027, 45.195210865565706, 22.50211807659694, 2.53848939708301, 0.759935445019177, 1.3419558597462518, 12.37502656664167, 44.775299957820344, 59.40107386452811, 58.142532757350374, 60.52418763296944, 57.18099587304251, 57.83563082558768, 55.72555324009487, 55.368565218789236, 54.880773884909495, 56.94102246420724, 52.14251661300659, 51.40172747203282, 50.40553992135184, 44.36369562149048, 39.74453319822039, 40.174432141440256, 40.00130040305001, 41.574501105717246, 43.132099628448486, 42.42302901404244, 42.32505941390991, 39.33460685185024, 39.43606792177473, 41.79905298777989, 48.72701495034354, 50.859034946986604, 50.96483864103045, 48.24616486685616, 45.35201781136649, 45.10879611968994, 51.81644460133144, 50.16442700794765, 49.26879726137434, 47.76288986206055, 48.63284254074097, 47.467129366738455, 49.77545642852783, 48.11560126713344, 42.660719939640586, 36.717470577784944, 36.655266829899375, 33.40878357206072, 33.55964285986764, 32.435650144304546, 23.595033236912318, 19.749981778008596, 15.865879705974034, 19.6190881388528, 21.09597291265215, 10.252812215260096, 1.3038656179394041, 0.5796205177903175, 0.9487308114767075, 1.30375922364848, 1.121388009616307, 0.17735675882015908, 0.250374617853335, 0.3207667092127459, 0.24096504705292837, 0.01675564536292638, 0.09435146142329488, 0.19815513278756822, 0.028939789959362576, 0.07205839694610663, 0.3304028021437781, 0.34825405425259043, 2.6226455441543033, 4.12049411875861, 0.9663978006158556, 6.47235164472035, 10.388903975486755, 12.267676898411342, 16.718314238956996, 18.794585364205496, 22.51337763241359, 28.625737462724956, 33.02543061120169, 36.49503789629255, 36.06867558615548, 35.913831506456646, 39.793055943080354, 40.382867676871165, 43.313968726566856, 44.11024965558733, 46.235199860164094, 41.5414902142116, 47.425412382398335, 46.950676713671, 48.29518788201468, 37.94360876083374, 36.735299655369346, 37.46872023173741, 36.88708652768816, 37.6930775642395, 39.126164368220735, 39.929789543151855, 38.972678661346436, 38.593247958592, 43.25793497903006, 51.563144547598704, 52.81701993942261, 52.99537672315325, 53.208123615809846, 52.446177210126606, 51.58547258377075, 54.05335112980434, 55.1593063218253, 55.57729605266026, 55.011254106249126, 58.210458346775596, 53.2767197063991, 41.51801572527204, 33.27275174004691, 31.335062435695104, 27.58639986174447, 14.815270389829363, 6.112658168588366, 1.5504899727446693, 6.354230531624385, 32.689224651881624, 43.92361061913626, 46.84389679772513, 19.270253828593663, 19.64985649926322, 27.391845090048655, 29.88174942561558, 26.687216111591884, 27.12725247655596, 23.2464143208095, 37.73809494291033, 45.97896766662598, 42.7985965183803, 51.903383936200825, 0.6541999844568116, 0.04345913317852786, 0.11391889144267354, 0.0647243969142437, 0.09049586259893008, 0.03394055572737541, 0.07277189008891582, 0.039224060252308846, 0.05030225722917488, 0.041535381227731705, 0.07376935692237956, 0.022999020792277794, 0.03063532683466162, 0.0997938686715705, 0.054437907811786444, 0.0730537942477635, 0.03111819949533258, 0.07170963673187153, 0.01437943269099508, 0.0601577680291874, 0.10318340893302645, 0.08504326375467436, 0.07301700407905237, 0.07604151964187622, 0.29667597476925167, 35.10760770525251, 61.100116865975515, 50.93769897733416, 49.50396251678467, 50.665673528398784, 36.9926609311785, 28.31912214415414, 37.44269575391497, 32.67843757356916, 30.738497052873882, 36.25659309114729, 51.66109330313546, 51.53926706314087, 27.785127026694163, 4.610184047903333, 1.6185539833136966, 4.593487526689257, 9.591247303145272, 35.37189286095755, 59.414087840488975, 60.834584508623394, 62.75409385136196, 58.40313189370291, 61.379531724112375, 59.009716578892295, 59.57138810838972, 57.53185905729021, 59.49121284484863, 55.57330778666905, 58.16340167181832, 56.99058049065726, 51.02679920196533, 42.80848033087594, 40.56542812074934, 43.9676969391959, 45.04759291240147, 46.005120686122346, 45.482960087912424, 42.67137847627912, 42.546470710209434, 43.08916670935494, 46.68606846673148, 53.66799708775112, 53.320750440870015, 54.681992871420725, 50.884823186056956, 45.27735594340733, 47.61810677392142, 53.80640172958374, 54.148975712912424, 52.69952242715018, 52.652667249952046, 51.509824071611675, 51.35862084797451, 52.704837799072266, 52.65768384933472, 45.73720162255423, 39.8356032371521, 36.26895046234131, 34.30796732221331, 35.067308153424946, 37.548357009887695, 30.172319616590226, 24.896455151694163, 23.47271020071847, 25.43138827596392, 25.297948122024536, 9.137896452631269, 1.6005002834967204, 0.708223314157554, 0.08997385203838348, 0.7469583813633237, 0.5685709821326392, 0.10291939095727035, 0.2009098899683782, 0.1995991367314543, 0.4868173918553761, 0.10205740042562995, 0.20535333082079887, 0.06591308170131274, 0.0153931487418179, 0.026907960950796093, 0.2033974536295448, 0.9383212157658168, 2.0118026988846913, 9.541585053716387, 13.12371494088854, 18.47129784311567, 18.602505888257706, 19.475632156644547, 22.011269535337174, 24.740120683397564, 28.34556003979274, 35.229909896850586, 39.22924089431763, 41.871373312813894, 39.167943886348176, 39.411512987954275, 43.02184908730643, 43.67051206316267, 47.06518302645002, 48.873118196214946, 49.570769446236746, 45.106826305389404, 50.73138264247349, 51.11225162233625, 48.19432783126831, 42.72883660452706, 38.67061267580305, 39.82645245960781, 40.393758978162495, 39.26709120614188, 41.338898113795686, 41.70097916466849, 41.09541239057268, 42.00757884979248, 48.033716746738975, 55.239405155181885, 56.0571733883449, 56.619907992226736, 56.732944761003765, 55.15583569662911, 55.70482676369803, 56.859617369515554, 59.071784836905344, 57.20695434297834, 56.89580706187657, 60.220516613551546, 53.58055400848389, 50.94781902858189, 45.64557225363595, 40.94199616568429, 31.068977696555002, 14.414211681910924, 4.922475610460554, 1.141633431826319, 8.707829015595571, 34.61105121885027, 44.32228088378906, 48.993127482278005, 22.73315610204424, 18.438412019184657, 21.325180087770732, 20.668412038258143, 28.79657803262983, 30.991581712450298, 29.82894311632429, 30.108590739113943, 46.814318316323416, 49.68539040429251, 58.48893519810268, 1.1321910470724106, 0.17931590655020305, 0.06359840197754757, 0.047202638017811945, 0.12873800125505241, 0.033008425030857325, 0.04805108159780502, 0.13369486241468362, 0.0981001638408218, 0.07054250221699476, 0.07098147366195917, 0.10945812759122678, 0.0917325537385685, 0.21223761141300201, 0.13060347044042178, 0.1649389165852751, 0.058221636206976006, 0.15443569661251136, 0.1198973006435803, 0.11871704326144286, 0.4285179344671113, 0.14892139179365976, 0.23281730711460114, 0.5587449808205877, 0.49757494032382965, 43.490748269217356, 70.63871506282261, 58.840458461216514, 55.11891644341605, 59.31059442247663, 47.91146319253104, 38.0434057371957, 49.832174573625835, 36.2278344971793, 37.00009550367083, 42.76013476508004, 57.62952641078404, 56.036801270076204, 30.01568637575422, 5.1445057306970865, 1.586949776325907, 4.077384889125824, 21.51431179046631, 56.606084551130024, 69.82815905979702, 60.32475348881313, 64.54116358075822, 58.54106058393206, 61.69337490626744, 60.048875263759065, 60.42129176003592, 58.99901635306222, 61.8613406590053, 57.740968567984446, 60.98507554190499, 57.576529026031494, 51.756790842328755, 43.75220898219517, 45.916565895080566, 45.17628397260393, 48.99006680079869, 49.51037917818342, 50.77054616383144, 46.64878095899309, 44.30385773522513, 44.62869644165039, 48.293589796338765, 55.186685698372976, 54.6461158479963, 57.00386197226388, 54.555601664951865, 46.19088077545166, 47.34515374047415, 55.51481090273176, 54.8547111919948, 51.399323395320344, 52.10332529885428, 52.15950148446219, 52.010393142700195, 54.458761147090364, 54.03879812785557, 50.82151467459542, 42.13549518585205, 37.51503692354475, 37.78676707404, 38.05130583899361, 39.701895577566965, 36.41786772864205, 29.81370571681431, 27.026670353753225, 25.165756906781876, 30.39635385785784, 15.573245900017874, 11.573678663798741, 1.9594269607748305, 1.1709667720964976, 2.5259691774845123, 1.1355928416763033, 0.3112771527043411, 0.3824244535395077, 0.3785125905913966, 1.168547387634005, 0.22948320316416876, 0.2794118182999747, 0.21361571603587695, 0.1754376989390169, 0.1623783696975027, 0.4638956104006086, 1.239164101225989, 5.320551804133824, 15.023233447756086, 17.07760385104588, 25.281062262398855, 24.471383469445364, 25.61469738824027, 26.806414195469447, 28.674260207584926, 32.93786941255842, 41.404145172664094, 45.535999161856516, 47.772381101335796, 43.743270124707905, 43.49505615234375, 46.287578855242046, 45.271033082689556, 48.94451788493565, 52.12927334649222, 52.76276840482439, 47.06477655683245, 53.58420876094273, 52.797860281808035, 51.9164708682469, 42.75150857652937, 40.93533631733486, 40.806568826947895, 42.11369521277291, 43.11297818592617, 43.93828174046108, 46.0519689151219, 43.52120222364153, 43.75040939876011, 49.04207059315273, 58.25212321962629, 58.013879912240164, 57.27230562482561, 58.07147700445992, 57.91790097100394, 56.48143039430891, 60.5364442552839, 61.14306368146624, 61.55600207192557, 60.318222182137625, 62.07114151545933, 56.26989943640572, 51.72833102090018, 44.23905536106655, 40.99623727798462, 36.45314373288836, 18.396295513425553, 9.29850058896201, 1.633146503141948, 7.992468544415065, 39.747378485543386, 51.88903590611049, 57.21332236698696, 27.1873231274741, 27.303719350269862, 38.288899489811485, 40.60996607371739, 35.58502537863595, 39.555215631212505, 35.169377190726145, 47.93709509713309, 64.79350130898612, 53.94522326333182, 66.95528044019426, 1.0085554527384895, 0.23709289197410854, 0.2286636142858437, 0.2310920368347849, 0.2232253189597811, 0.11776062101125717, 0.20526664118681634, 0.1585903258195945, 0.12409076919513089, 0.2375691421329975, 0.24394492858222552], [0.012430389195547571, 0.07994412737233297, 0.08360550233295985, 0.09437276742288045, 0.018774132676688687, 0.058150077903909345, 0.08619225424315248, 0.05931177735328674, 0.04447395693776863, 0.16596183526728833, 0.09230692006115403, 0.1052829252023782, 0.11589929088950157, 0.1937019888843809, 30.397371768951416, 57.797526904514854, 40.50186252593994, 36.088036741529194, 45.572914940970286, 44.78241491317749, 33.689942428043906, 58.110213211604524, 30.232442378997803, 22.315614530018397, 25.919217824935913, 40.2307368687221, 50.52512189320156, 34.01949896131243, 5.785127903733935, 1.7297346059765135, 4.829632043838501, 6.706177634852273, 5.913354303155627, 15.399983882904053, 36.72462722233364, 55.23670230593, 57.50149195534842, 58.40251350402832, 55.99671016420637, 59.10326712472098, 56.72417613438198, 56.38249499457223, 54.49456868852888, 57.784151622227256, 55.012084415980745, 54.308554989951, 49.46191896711077, 41.543116092681885, 42.939328806740896, 41.75728389195034, 41.60221746989659, 40.40360457556588, 40.50823402404785, 38.971355029514854, 40.421009813036235, 44.293039390019004, 47.758901596069336, 51.523682253701345, 48.829031876155305, 48.4395158631461, 48.13576493944441, 48.57967145102364, 50.22226728711809, 49.27193437303816, 49.546784264700754, 49.93230158942086, 48.05203914642334, 48.44718667439052, 51.04610129765102, 48.47289848327637, 40.83409064156668, 34.06961631774902, 31.984889234815324, 30.55649941308158, 30.366643360682897, 29.35074724469866, 20.42406300136021, 13.309614862714495, 16.782623291015625, 17.973066840853008, 14.877248321260724, 5.506874697549002, 1.6678174712828227, 0.27294301827039036, 0.26749313356620924, 0.08229206888271229, 0.09926726442894765, 0.10040194461388247, 0.2985802697283881, 0.16225384495088033, 0.3649281838110515, 0.05191892119390624, 0.011018092344914163, 0.11836199302758489, 0.08760144255523171, 0.09336291053997618, 0.5125550936375345, 1.836433857679367, 8.039784908294678, 13.311845234462194, 12.451668671199254, 8.422383989606585, 12.020162088530403, 12.376954691750662, 16.21496762548174, 19.050742864608765, 21.108788864953176, 28.17647041593279, 32.778425625392366, 36.49801867348807, 33.69461161749703, 33.52010760988508, 37.07955510275704, 38.10342427662441, 43.0795191356114, 43.48122576304844, 45.304860387529644, 41.9492313521249, 45.13048839569092, 48.80194779804775, 45.66877228873116, 39.934232916150776, 36.03824247632708, 37.30062593732561, 37.88864850997925, 38.17999342509678, 37.28051437650408, 39.242897578648154, 37.64185544422695, 43.8421117237636, 48.93936579568045, 51.4237185205732, 52.44642039707729, 54.046698229653494, 54.40071242196219, 51.58449636186872, 54.29989058630807, 55.90229109355381, 56.63836588178362, 53.04247856140137, 52.27326781409127, 55.77739722388131, 54.53374263218471, 54.68084641865322, 51.340722288404194, 46.06373221533639, 32.75955779211861, 12.81139862537384, 2.456168225833348, 1.0150212943553925, 12.058722853660583, 34.646789278302876, 46.86089556557791, 31.042897633143834, 13.698336175509862, 15.82304058756147, 16.14918555532183, 26.268145935876028, 26.90797601427351, 23.248252119336808, 21.764059577669414, 22.37004324368068, 33.46645014626639, 42.694411754608154, 50.920022760118755, 1.0574923753738403, 0.3623528720012733, 0.11893880207623754, 0.06260013447276183, 0.14846887678972312, 0.03312933997118047, 0.12800998746284417, 0.10124247308288302, 0.12664059522960866, 0.1128514947901879, 0.011474261259926217, 0.05326815415173769, 0.07898689766547509, 0.11793466524354049, 0.0759481532233102, 0.011001322351928269, 0.037849925059292994, 0.023765249676736336, 0.030739509101424898, 0.06506244984588452, 0.14222476684621402, 0.06036124711057969, 0.05225206492468715, 0.025136660551652312, 0.17170074874801294, 37.79403141566685, 66.95908110482353, 45.39595127105713, 42.51399482999529, 50.511003153664724, 39.67094482694353, 30.490894521985734, 54.12477166312081, 36.389539922986714, 28.599266563143047, 28.119597673416138, 45.26394592012678, 54.2882593018668, 39.55551092965262, 9.024185708590917, 2.9605909415653775, 5.2478858062199185, 9.30029582977295, 9.504022223608834, 15.294713463102068, 31.072417054857524, 53.200379848480225, 57.714968408857075, 59.984819820949006, 57.88721425192696, 59.66361154828753, 59.155204909188406, 58.92488602229527, 59.297879219055176, 59.10572678702218, 57.789063998631065, 56.98935760770525, 51.31842204502651, 44.53840807506016, 44.46860647201538, 43.515716620853965, 43.43104239872524, 41.97006205150059, 41.57843031202044, 40.974666595458984, 44.47185822895595, 47.530559471675325, 50.44595411845616, 52.83687441689627, 53.066967487335205, 49.824687889644075, 51.040737288338796, 50.41667093549456, 52.109325068337576, 52.621768610818044, 53.28402573721749, 50.88011925561087, 51.37223236901419, 50.917458874838694, 53.559070178440635, 52.32052598680769, 45.15495300292969, 38.14317144666399, 36.9932723726545, 35.349165303366526, 33.93448427745274, 36.80078990118844, 26.572972093309673, 26.55321489061628, 30.52192865099226, 23.119277920041764, 14.686961480549403, 8.180849841662816, 3.0448615167822157, 0.5777385873453957, 0.2586410471371242, 0.08054662575679165, 0.05645291593724063, 0.027706094551831484, 0.02465407457202673, 0.0437613357124584, 0.5532982988016946, 0.20064047085387365, 0.38239758355276926, 0.03861388085143907, 0.11443885282746383, 0.06368554622999259, 1.1784580158335822, 2.7045726222651343, 14.363079019955226, 21.97760377611433, 24.17052299635751, 22.16053942271641, 20.027112415858678, 21.3691691330501, 21.93499915940421, 25.924868447440012, 28.27651231629508, 35.741967814309255, 37.14083821432931, 40.19455412455967, 38.51137386049543, 35.56648758479527, 40.41374199731009, 40.53674248286656, 45.15011705671038, 47.956136635371614, 47.794771671295166, 43.5156158719744, 50.3926544870649, 49.56417213167463, 47.934836932591026, 41.88429348809378, 39.72964320863996, 40.865708419254844, 40.458363328661235, 41.33649403708321, 41.86538743972778, 41.019694396427695, 42.61285032544817, 50.72867284502302, 52.9086458342416, 53.77881738117763, 55.074357645852224, 54.84922211510794, 57.373134408678325, 56.50255291802542, 57.7071065221514, 57.38716976983206, 59.20830304282052, 55.329523290906636, 55.833733218056814, 58.42441422598702, 60.382638931274414, 58.08560616629464, 56.0135942867824, 49.76454775674002, 39.6177077293396, 18.476967573165894, 3.1498772416796004, 1.4066257838691985, 16.47561366217477, 38.23913649150303, 50.23308910642351, 34.6021853174482, 16.73239302635193, 18.454457146780832, 14.604760817119054, 23.59695441382272, 29.638190746307373, 30.409645761762345, 24.56776888029916, 20.43533992767334, 39.113876479012625, 49.346047333308626, 55.54556015559605, 1.1900680214166641, 0.07961039670876094, 0.09838394075632095, 0.10706763514982802, 0.03935296494247658, 0.08294417496238436, 0.09343144257685967, 0.19035648554563522, 0.003640235202120883, 0.11369864576097045, 0.0590349757777793, 0.12845364079943725, 0.176572535187006, 0.23979275567190989, 0.2116138477410589, 0.09752973980669465, 0.10457815801990883, 0.19091301996793064, 0.10983056189226252, 0.09149729207690273, 0.16535256510334356, 0.18737171856420382, 0.23358103899019106, 0.25868015789559906, 0.9623695824827466, 49.89603199277605, 75.29043674468994, 55.282539572034565, 45.87719740186419, 59.38721915653774, 55.75230380467006, 43.52931424549648, 70.13458156585693, 38.3085663659232, 30.181129932403564, 36.45162902559553, 53.066272667476106, 62.23778016226632, 44.688673291887554, 10.435213719095502, 4.406803326947348, 7.221083010946002, 9.75637297970908, 9.426932828766958, 27.579458611352102, 50.36103670937674, 65.01160526275635, 59.33953366960798, 61.88488810403006, 58.81131076812744, 62.87732710157122, 60.18581730978829, 61.53601210457938, 61.37416771480015, 66.02315875462124, 62.76594747815813, 60.25700160435268, 53.48910181862967, 45.91604478018624, 48.45731019973755, 46.56413452965872, 47.00713430132185, 45.75061164583479, 43.76315586907523, 43.27918257032122, 44.17101512636457, 49.24018110547747, 51.83258179255894, 55.92209693363735, 56.14115973881313, 52.170618602207725, 50.87370259421212, 52.64076498576573, 54.03522327968052, 54.069269452776226, 51.834294523511616, 52.73773404530117, 53.253665583474294, 52.60253947121756, 56.504074573516846, 54.43299375261579, 46.86632558277675, 39.49909850529262, 34.70188154493059, 37.618683201926096, 36.74581922803606, 41.921754700796946, 37.16048771994454, 25.767272881099156, 31.814258847917827, 22.110981396266393, 23.461195298603602, 19.73081169809614, 8.94577441896711, 3.1053877089704787, 0.7111347722155708, 0.1463677388216768, 0.3081223719886371, 0.402363476476499, 0.38475280574389864, 0.1765143983066082, 0.7342608198523521, 0.8684101243104253, 1.0396556981972285, 0.130542605849249, 0.2076230440288782, 0.13372912843312534, 1.491380887372153, 2.3840142233031134, 19.337340423039027, 29.367384706224712, 36.252816745213096, 28.98815029008048, 28.288152285984584, 25.19332214764186, 27.431460244315012, 29.904980727604457, 31.65019450868879, 37.75006321498326, 44.52276768003191, 46.135496684483115, 43.882289682115825, 38.80293764386858, 43.68432855606079, 42.15920243944441, 49.95334768295288, 48.90865823200771, 53.12632942199707, 45.55953271048409, 55.78911883490426, 54.16446672167097, 50.72989225387573, 43.22818974086216, 42.30872419902256, 41.840280124119346, 42.136603423527305, 43.780911990574424, 44.10541023526873, 43.77645819527762, 44.00463356290545, 50.1404835156032, 54.4048570224217, 54.76035465512957, 55.83553974969046, 56.80531372342791, 58.87191295623779, 57.47024243218558, 59.71204744066511, 60.145844323294504, 61.06814125605992, 57.475067956107004, 55.84721967152187, 61.201442446027485, 61.305199895586284, 58.11255475452968, 57.11027363368443, 49.404255867004395, 40.85854830060686, 20.15920114517212, 4.666519173554011, 1.0938703204904283, 16.684151683534893, 42.61698450360979, 56.594783306121826, 42.4098413331168, 20.112682955605642, 25.141636235373362, 25.77664773804801, 37.975400243486675, 39.19588259288243, 33.98076622826712, 31.456103529248917, 34.776803970336914, 46.690689018794465, 52.667036124638145, 63.8163275037493, 2.062901271241052, 0.7325122079678944, 0.28060237584369524, 0.3604357120181833, 0.32482537999749184, 0.13471862248011998, 0.32779242364423616, 0.3406277006225926, 0.3363122450453894, 0.25557531735726763, 0.23391110556466238], [0.08801192910011325, 0.117162288831813, 0.06963485306394951, 0.053454992161797624, 0.07212200281875474, 0.05315467595521893, 0.03521860696907554, 0.046760053373873234, 0.0923972534281867, 0.160124982041972, 0.1121088924950787, 0.23373710204448017, 0.41031330132058685, 0.5950664718236242, 31.216946533748082, 55.48868220193045, 34.94500943592617, 47.71379041671753, 33.208136967250276, 48.12952545710972, 32.140028612954275, 65.35320649828229, 47.025633880070274, 22.810055289949688, 32.50602844783238, 41.293210233960835, 50.929687704358784, 36.20527369635445, 10.853001083646502, 1.9303756739412035, 6.551393483366285, 8.649957469531468, 10.176583528518677, 14.211880138942174, 10.448795710291181, 13.059893999780927, 37.374134404318674, 49.53208882468087, 50.21923787253243, 54.399541650499614, 52.60495744432722, 54.85290118626186, 55.98573201043265, 53.99260302952358, 55.4889566557748, 53.92657777241298, 54.76072290965489, 50.62299074445452, 43.32551663262503, 40.830849306924, 40.14259202139718, 38.53350387300764, 38.91608558382307, 40.95833485467093, 39.388893127441406, 43.77874067851475, 45.59963771275112, 49.65114620753697, 50.246554715292795, 50.57619115284511, 49.1879688671657, 49.65370314461844, 51.635853971753804, 52.1276787349156, 50.87749631064278, 49.209779262542725, 48.447746004377095, 52.170344148363384, 48.10837166649954, 48.393900939396445, 41.41819095611572, 35.22427143369402, 34.7502201625279, 28.63870974949428, 26.764643362590245, 26.076863765716553, 17.942663260868617, 23.42701189858573, 29.524059636252268, 17.74539348057338, 6.003861972263881, 6.009722343512943, 0.3379442574722426, 0.12741142458149365, 0.2220417774681534, 0.15427816792258195, 0.038005933830780644, 0.18718045311314718, 0.052220611433897696, 0.011278855048918297, 0.12008948890226227, 0.7264448021139417, 0.09405099933168717, 0.06908021175435611, 0.17931524158588477, 0.3608019309384482, 0.2979332458760057, 4.483996944768088, 16.886914014816284, 14.009620683533804, 18.679311275482178, 16.202735321862356, 11.83130657672882, 14.414051004818507, 17.369056463241577, 19.3763302394322, 22.338719027382986, 30.07685136795044, 28.844808953148977, 33.63388783591134, 32.742222036634175, 32.65775626046317, 35.19172259739467, 39.97032185963222, 43.215328625270296, 44.90901803970337, 45.88144275120327, 42.491764068603516, 45.976702553885325, 45.778744901929585, 44.58007642201015, 40.58070720945086, 35.68195622307913, 36.410471371241975, 37.13073205947876, 38.21226780755179, 39.971138272966655, 37.772057737622944, 45.612908772059846, 51.19589751107352, 51.04311357225691, 53.279512882232666, 51.86611727305821, 50.502540247780935, 55.757073743002756, 53.64257710320609, 54.705026149749756, 56.46697814123971, 54.62027202333723, 56.197672912052695, 56.75515120370047, 59.39172853742327, 59.47459275381905, 60.63260037558419, 64.57576560974121, 57.67894894736153, 48.3093135697501, 23.366128308432444, 3.304380859647478, 2.08491598708289, 17.191203423908778, 35.275569983891074, 49.08039338248116, 21.280162709099905, 17.747912202562603, 14.698191506522042, 17.38401767185756, 23.77192047664097, 28.27129943030221, 23.337689331599645, 20.880062852587017, 27.534396069390432, 32.25542082105364, 46.737672737666536, 49.81526960645403, 1.0860011598893573, 0.13306614543710435, 0.07906062728060143, 0.2104310119258506, 0.021099492541647384, 0.059901627844997814, 0.026082204189151525, 0.016243456596774713, 0.033311435021460056, 0.12817901053598948, 0.04766803840175271, 0.05640183582103678, 0.0914435860301767, 0.03712999261915684, 0.016982309985905886, 0.011019684357701667, 0.026722398586571217, 0.005316755285353533, 0.09503644252462046, 0.07853066428963627, 0.12998733350208827, 0.10606744060558931, 0.08276495350790875, 0.19213158743722097, 0.7313721605709621, 40.25997836249215, 63.27379131317139, 43.689185346875874, 53.478147983551025, 40.45304100854056, 42.71688917704991, 28.436115912028722, 56.15777635574341, 44.79674209867205, 32.20640822819301, 38.10239246913365, 41.895195211683, 54.03445897783552, 41.689726557050435, 13.291891745158605, 3.8548775144985745, 8.63168283871242, 13.775642701557704, 14.855882610593524, 19.647424629756383, 14.810886076518468, 14.585920776639666, 36.76095935276577, 50.70440626144409, 51.69387490408761, 53.764007295881, 54.29778528213501, 54.99746193204607, 57.11357402801514, 60.05380848475865, 57.35991893495832, 56.22488553183419, 57.4551613671439, 50.96677371433803, 46.659408228737966, 44.17068856103079, 43.37660673686436, 43.29454503740583, 41.98691838128226, 42.596421309879844, 42.10744878223964, 46.56848757607596, 48.809437956128804, 53.52746977124895, 54.62315552575247, 54.062623500823975, 51.225667067936485, 53.09960665021624, 54.04651757649013, 55.06452594484602, 51.98434087208339, 50.877009936741416, 50.19384568078177, 52.37655973434448, 52.020263058798655, 50.83976411819458, 48.5713266645159, 38.76353440965925, 39.37773084640503, 30.542759350367955, 33.263993535723, 31.473943029131206, 27.6379520211901, 39.91222102301461, 42.43419129507882, 25.53527079309736, 9.142273817743574, 4.107944369316101, 1.3478560745716095, 0.19049768868301595, 0.13712435481803759, 0.008251443837902375, 0.0713815718357052, 0.1035894782149366, 0.06672536954283714, 0.13851912426097052, 0.20283770295126097, 0.23118051780121668, 0.14991696551442146, 0.11035200926874365, 0.18766694915081772, 0.08301957377365657, 1.0513267176491874, 6.0063550727708, 20.997412715639385, 11.798503262656075, 30.669515337262833, 27.782893180847168, 22.9322532585689, 21.27612927981785, 24.54223425047738, 24.867429052080425, 29.7017320224217, 35.48438767024449, 36.116378443581716, 39.35444048472813, 37.10312339237758, 37.818586349487305, 40.220762729644775, 42.69443954740252, 46.26399319512503, 46.796523979731965, 48.48965406417847, 45.67388963699341, 50.8489739554269, 47.363875661577495, 47.07617507662092, 41.197596073150635, 38.0392507144383, 37.066224983760286, 38.86174719674246, 39.298038482666016, 42.955056054251536, 41.845699719020296, 51.49362434659685, 52.781479903629844, 54.38525268009731, 56.50299412863595, 53.326976026807515, 50.86788695199149, 57.78243541717529, 54.909817355019705, 56.05181285313198, 56.28899308613369, 58.05085127694266, 59.32251058306013, 61.253748485020225, 60.06759371076311, 58.64971651349749, 62.71754632677351, 65.71871648515973, 60.807521275111604, 53.8506235395159, 28.108609097344534, 5.16083573443549, 1.965861861194883, 21.228567123413086, 38.818084716796875, 52.02348007474627, 24.60117060797555, 21.569299834115164, 19.53189172063555, 17.063097749437603, 27.607555389404297, 29.856930460248673, 29.206346307482036, 25.911112751279557, 28.119300637926372, 39.34322609220232, 50.621743542807444, 55.996678897312705, 2.863181105681828, 0.08949638730181114, 0.22421820568186895, 0.16562205207134995, 0.11844780056604318, 0.07721887289413384, 0.03325217855828149, 0.027903641540823237, 0.04960999205442412, 0.03258222361494388, 0.08409233763813972, 0.2299444984112467, 0.19330549373158387, 0.09466429320829255, 0.17055380743529114, 0.14433141451861176, 0.21594239904412202, 0.10592777774270092, 0.15235923017774308, 0.36497972533106804, 0.1916501261293888, 0.26023280886667116, 0.5366469951612609, 0.47638608302388874, 1.4141983432429177, 50.47703341075352, 70.38633564540318, 48.01334810256958, 59.330987385341096, 43.7022305897304, 60.975903919764924, 40.745118958609446, 74.36437388828823, 53.35885436194283, 30.466975348336355, 47.255904129573274, 52.89454446520124, 60.80676392146519, 45.14992250714983, 15.68798497744969, 3.8369680983679633, 9.480784841946193, 16.008342095783778, 14.84726858139038, 19.261481727872575, 14.860880102430071, 20.69814338002886, 42.15864658355713, 51.53645304271153, 53.29658808026995, 56.688413756234304, 55.20092255728585, 56.1242721421378, 60.79281193869454, 62.56791687011719, 61.72148731776646, 58.86347784314837, 60.273684229169575, 54.386558941432405, 48.25511414664132, 47.082970414842876, 45.625436374119346, 45.22852052961077, 43.448676926749094, 43.84992844717843, 43.717603479112896, 49.424923283713206, 48.21442549569266, 56.27270303453718, 59.10157176426479, 54.80407966886248, 52.16112388883318, 54.27821568080357, 53.91397721426827, 57.0335134097508, 52.177076952798025, 53.165385246276855, 50.63461855479649, 57.47208023071289, 54.40922049113682, 54.31655584062849, 47.967979839869905, 42.62786190850394, 38.531937054225374, 34.77660942077637, 32.932230949401855, 40.44957038334438, 33.15343379974365, 46.16981383732387, 51.42216559818813, 29.912859984806605, 16.716299261365617, 13.656153661864144, 2.229781367949077, 0.3390375945184912, 0.29351617289440973, 0.14931110159627028, 0.14162586469735416, 0.2590450197458267, 0.12280195978071008, 0.20773345524711267, 0.291846189647913, 1.192533871957234, 0.41967434329645975, 0.22815471302185739, 0.370951810585601, 0.5554170108267239, 1.6441865393093653, 6.575819875512805, 29.98117467335292, 18.087828499930247, 38.42902381079537, 34.73366607938494, 30.99856812613351, 25.495770284107753, 31.335576602390834, 29.59358331135341, 35.19933087485177, 41.98764099393572, 41.66203451156616, 45.16383627482823, 42.77260330745152, 40.150891644614084, 44.17561483383179, 43.360834326062886, 51.081773349217, 52.224720750536235, 51.97277212142944, 48.07185888290405, 55.21083068847656, 48.893167223249165, 49.71428448813302, 43.75563097000122, 39.65699284417288, 38.43464142935616, 40.80578368050711, 45.37794501440865, 44.73829732622419, 41.5958251271929, 52.12653228214809, 56.5166403906686, 56.88016319274902, 59.045673506600515, 54.115558351789204, 49.74190010343279, 58.698465074811665, 57.75125190189907, 58.408614022391184, 59.66262490408761, 59.062661852155415, 61.968870980399, 63.90601485116141, 65.56789193834577, 62.908948353358674, 66.84243474687848, 72.51294994354248, 63.77976608276367, 54.04167815617153, 28.34409396989005, 4.874428382941654, 2.08152483190809, 21.485575778143748, 41.4450283731733, 56.51242978232247, 31.2827980858939, 22.631090538842336, 24.10493200165885, 24.108638865607126, 35.0130739893232, 41.9899582181658, 33.162292752947124, 32.35503714425223, 42.449605873652864, 46.25481462478638, 54.77763829912458, 63.33189214978899, 3.1035086555140357, 0.3735022337308952, 0.44852616797600475, 0.43306534045508926, 0.3789218286318438, 0.34817518134202274, 0.10971021692135505, 0.14633838539677008, 0.19612900008048328, 0.1400232735489096, 0.18238435047013418], [0.07350863662681409, 0.05587836641020008, 0.15340417410646165, 0.08594792735363756, 0.1398215043757643, 0.04559174838608929, 0.036186618597379754, 0.13037865821804318, 0.12262425145932607, 0.17079908427383217, 0.02924887283838221, 0.2443120160273143, 0.3888964562543801, 0.5361429250666073, 39.44689321517944, 51.165474823543, 32.63192980630057, 42.46306106022426, 29.76496410369873, 41.88606527873448, 24.056358882359095, 49.279959542410715, 43.125474521092, 18.83574649265834, 28.200723103114537, 38.739552702222554, 43.75845888682774, 43.958532265254426, 15.602027075631277, 4.596899960722242, 7.7400005374635965, 16.675836426871165, 20.487769297191075, 21.87749934196472, 18.712686947413854, 12.147468720163618, 21.78109656061445, 45.24396637507847, 54.59425449371338, 55.42908750261579, 53.7592443057469, 54.92350878034319, 56.764656339372905, 60.95423943655831, 55.962087290627615, 56.12858002526419, 54.26092856270926, 49.834867000579834, 46.642152377537315, 42.93959283828735, 44.49944952556065, 42.84104306357247, 37.46277952194214, 41.03111376081194, 37.87456451143537, 42.98656266076224, 46.95695441109793, 50.37126098360334, 50.70612941469465, 54.87025431224278, 51.4065842628479, 52.4994455746242, 53.83870390483311, 50.48755645751953, 48.176099232264924, 49.789418833596365, 46.262256145477295, 48.47030333110264, 48.184152194431846, 46.60752950395857, 45.354057107652935, 33.09907109396798, 31.26209592819214, 24.156543220792496, 22.87686048235212, 23.245719500950404, 19.544443641390117, 38.59221615110125, 36.15611171722412, 12.449070044926234, 3.9380066309656416, 3.1940953603812625, 0.3399008810520172, 0.13437902927398682, 0.15256564053041594, 0.07771155717117445, 0.06093669230384486, 0.08096161098884684, 0.043166274071804116, 0.04493877038891826, 0.14020300390464918, 0.22044198188398564, 0.30686792358756065, 0.2892903382224696, 0.1753280476800033, 0.057029341613607745, 0.2188326053853546, 5.3245148829051425, 27.47823030608041, 21.622542142868042, 27.01497653552464, 20.421601602009364, 17.32438996859959, 16.257412433624268, 16.447325808661326, 18.315248250961304, 23.608203547341482, 25.605390276227677, 31.963537420545304, 33.244924204690115, 31.651229790278844, 32.649873529161724, 34.96013566425869, 41.212138652801514, 43.54763317108154, 46.533267157418386, 47.305503845214844, 45.02956233705793, 48.455746855054585, 44.63830580030169, 40.26015901565552, 37.01734440667288, 36.933635984148296, 37.89540910720825, 36.978121825626914, 37.824683393750874, 39.26428413391113, 43.19766630445208, 51.604621819087434, 50.38548047201974, 53.750760555267334, 50.801788738795686, 52.2880014692034, 52.11114549636841, 54.888406481061665, 51.60136658804757, 52.70638724735805, 50.91339765276228, 54.412385395595, 56.85780736378261, 55.491506644657676, 57.77607086726597, 57.841811248234336, 58.628628730773926, 61.98382350376674, 63.18706389835903, 59.429283550807405, 35.377024105616975, 8.830694879804339, 2.5048132155622755, 18.402979680470057, 44.429119859422954, 39.74151420593262, 15.718803712299891, 18.211384841373988, 12.251805475779943, 8.932478172438485, 16.132747854505265, 29.798360620226177, 27.137395109449113, 20.999971389770508, 24.062952722821915, 29.827852249145508, 36.857702595846995, 54.22795936039516, 3.727434958730425, 0.09771274748657431, 0.10260883904993534, 0.06448589185518877, 0.14446025474795274, 0.06201364951474326, 0.06148581712373665, 0.12748946967933858, 0.21884270198643208, 0.0608161369870816, 0.12205770186015538, 0.032626847470445294, 0.022638457461393306, 0.19854340409593924, 0.024715624483568326, 0.023452037912128226, 0.033274726276951175, 0.12214521930686065, 0.15402032461549553, 0.1514504003737654, 0.18825160206428596, 0.06466967985033989, 0.14598873630166054, 0.3184661769441196, 1.1497601100376673, 49.881336552756174, 61.82602991376604, 39.53504501070295, 48.669456073216026, 36.00387668609619, 40.339271204812185, 23.514124938419886, 42.667501381465364, 35.75211565835135, 23.489962577819824, 34.054226057870046, 42.08923407963344, 50.58145441327776, 51.34223352159773, 19.314077854156494, 7.799022878919329, 7.649105072021484, 18.160035916737147, 22.20516422816685, 26.88175524984087, 24.636300700051443, 20.42412379809788, 25.089045320238384, 46.76741450173514, 54.510247298649375, 53.97494418280465, 55.511840547834126, 56.06673410960606, 57.78690658296858, 64.51127937861851, 57.78692742756435, 58.008880683353965, 55.53600638253348, 53.937434332711355, 49.254772322518484, 45.472857407161165, 46.75904539653233, 43.273537158966064, 39.705341884068076, 42.46651084082467, 41.582811151232036, 45.2148186819894, 49.248300075531006, 53.20301668984549, 57.197952951703755, 57.74263613564627, 56.48599188668387, 55.175658907209126, 53.38362121582031, 55.41813366753714, 51.44896480015346, 51.960741315569194, 48.90839072636196, 51.11662551334926, 52.305514403751914, 49.912242140088765, 49.0522392817906, 39.92459576470511, 35.94941323144095, 29.550615651266916, 31.341829981122697, 28.15064569881984, 29.94589172090803, 47.477110454014365, 37.34373256138393, 24.523395947047643, 6.99870982340404, 3.6414842222418105, 0.23757419043353625, 0.110785993481321, 0.028119912703654597, 0.1151434707322291, 0.2661871165037155, 0.08571240784866468, 0.11309208295175008, 0.005182141571172646, 0.028653505856969526, 0.06567359276648078, 0.20718889018254621, 0.991123399564198, 0.1453908383846283, 0.14556485547551087, 0.2993822709790298, 5.413159132003784, 44.53234577178955, 45.824828829084126, 52.195538316454204, 33.42683151790074, 24.97817117827279, 24.645527907780238, 24.345447369984218, 26.23792127200535, 28.609331028802053, 32.46218531472342, 36.257003034864155, 36.98059885842459, 36.07045085089547, 37.61086647851126, 39.07840939930507, 44.116701057979036, 47.05725860595703, 50.8475148337228, 49.63131604875837, 47.75427756990705, 51.03386204583304, 46.09314046587263, 43.073290075574604, 40.10393224443708, 41.87775870731899, 40.37340075629098, 41.21216297149658, 41.77449457986014, 42.525146688733784, 46.248561246054514, 52.353116512298584, 52.24438762664795, 55.027658803122385, 52.666865893772666, 56.50012104851859, 54.008205209459575, 56.47149794442313, 53.33550494057791, 54.8191294670105, 52.453670842306956, 55.58335140773228, 57.5709913117545, 60.79705728803362, 59.777985845293315, 60.180411611284526, 59.363685607910156, 62.832691873822895, 63.466972078595845, 61.35089124952044, 43.410413197108674, 12.547239405768257, 3.775272003241948, 22.308539526803152, 48.10144083840506, 42.524135725838796, 19.917542798178538, 19.912095410483225, 13.667365448815481, 11.220708438328334, 18.936484949929373, 29.71163320541382, 32.56533132280622, 24.818423407418386, 19.268582786832535, 33.914146900177, 39.4501519203186, 65.72239903041294, 5.486449599266052, 0.16995193330304964, 0.228072176022189, 0.14787620359233447, 0.18085851520299911, 0.05356934227581535, 0.09812332224100828, 0.08004047255963087, 0.12569095832960947, 0.013107990380376577, 0.08541798471872296, 0.14622197592897074, 0.16648307229791368, 0.2733617829424994, 0.20608612149953842, 0.20484665515167372, 0.09425512302134718, 0.3433675436036927, 0.26568079367280006, 0.2599122146410601, 0.5315572225621769, 0.1932492567492383, 0.42233308777213097, 0.9120952401842389, 2.404502723898206, 62.52920150756836, 67.13005542755127, 44.12881524222237, 52.91269315992083, 41.77890321186611, 53.19568634033203, 33.191860812050955, 56.832932812826975, 47.986503737313406, 23.545016629355295, 42.87377255303519, 51.294002601078574, 54.176674706595286, 55.809449263981406, 21.067224740982056, 9.776835424559456, 9.853787592479161, 19.912006820951188, 22.614995036806377, 30.012625694274902, 24.79806865964617, 19.446755443300518, 26.518451316016062, 46.7548417363848, 54.2179331098284, 55.79476772035871, 53.07131358555385, 56.38658748354231, 60.966412680489675, 69.57048511505127, 61.294944354466026, 60.670843260628835, 57.55391263961792, 55.76077365875244, 51.87314885003226, 49.81251117161342, 48.328980445861816, 46.95317806516375, 39.36974041802542, 45.32281453268868, 42.15570749555315, 48.66230985096523, 52.444572176252095, 53.816542625427246, 58.183950969151084, 60.50495501926967, 56.260856355939595, 56.52152497427804, 55.805863993508474, 55.93633379255022, 50.11359051295689, 53.85983337674822, 50.37511723382132, 54.51436758041382, 55.199796949114116, 54.562007904052734, 50.26836511066982, 40.78051308223179, 40.10392877033779, 32.957664830344065, 36.19525786808559, 39.418287481580464, 39.02999087742397, 70.92842715127128, 62.81327165876116, 35.67926032202584, 17.93485348565238, 7.706376467432294, 1.5992249633584703, 0.19051250788782323, 0.452968102480684, 0.27940777423126356, 0.3655118867754936, 0.4068501671510083, 0.25717581861785477, 0.11568699085286685, 0.3469484985939094, 0.6321721864598138, 1.4891345564808165, 2.1980954110622406, 0.2956615649163723, 0.45097776928118294, 0.26383995530860765, 7.238033141408648, 52.119410378592356, 45.69496699741909, 59.653328214372905, 41.50177083696638, 36.844959599631174, 28.42949254172189, 30.839860848018102, 30.222395283835276, 32.636609418051584, 36.810041427612305, 44.79921565737043, 45.31452880586897, 42.90875325884138, 39.9200690133231, 43.12005145209176, 46.45165014266968, 51.03640161241804, 55.75832094464983, 54.69819607053484, 52.879463400159565, 58.28851440974644, 45.7539815221514, 45.49445240838187, 41.935609408787315, 41.8432400567191, 41.79923711504255, 43.157849652426584, 44.791833196367534, 45.61303383963448, 44.462092535836355, 56.660912786211284, 55.336631298065186, 59.010619844709126, 54.36898347309658, 57.43846137183053, 53.57454381670271, 58.09128284454346, 53.13298579624721, 56.23029123033796, 54.08641760689871, 58.1026987348284, 61.676198959350586, 64.66804463522774, 64.12961483001709, 62.09718336377825, 64.32458823067802, 68.56496960776192, 70.28511428833008, 66.40749835968018, 42.417185579027446, 11.9900746515819, 3.5865548040185655, 24.145547696522303, 49.35020235606602, 50.53230285644531, 24.414559364318848, 24.904612336839946, 19.483110155378068, 14.760421310152326, 24.96837248120989, 41.296826771327424, 40.97269330705915, 32.51802451269967, 33.72714308329991, 42.75722346987043, 44.474415166037424, 68.87139211382184, 7.644501890454974, 0.6487648646746362, 0.6449464495692934, 0.4859090234552111, 0.4542804706309523, 0.20879557968250342, 0.1847766206732818, 0.21368730148034437, 0.40013970008918215, 0.23426812355007443, 0.1547155515956027], [0.059727888953472884, 0.08218605457139866, 0.08726184256374836, 0.03239329232435141, 0.060084642310227664, 0.05992038933826344, 0.11732236881341253, 0.08057118193911654, 0.1765455702053649, 0.11781195897076811, 0.08000968064048461, 0.10598534465368305, 0.13902566422309193, 2.84863526906286, 50.51707935333252, 53.22928088051932, 35.36817210061209, 44.4595182282584, 21.28433336530413, 27.095381089619227, 26.17458323069981, 38.41766698019845, 26.03954151698521, 17.36726209095546, 21.576871633529663, 40.358701842171804, 44.74419287272862, 46.606153760637554, 20.113379512514385, 6.11936057465417, 5.520860118525369, 14.710413387843541, 24.348186697278702, 28.693261793681554, 31.423203808920725, 24.99941529546465, 23.020781993865967, 48.9048228263855, 57.93563972200666, 56.47678552355085, 56.50359862191336, 57.88640478679112, 56.358690466199604, 58.4748511995588, 54.96560444150652, 54.537602356501985, 53.59623956680298, 52.22085060392107, 45.012157099587576, 41.727173873356406, 41.12497697557722, 38.816882678440635, 40.25579902103969, 41.85629224777222, 40.477418763296946, 42.72292021342686, 47.646333830697195, 49.885686125074116, 53.15096426010132, 57.11606843130929, 53.67111335481916, 53.45439556666783, 53.14975527354649, 55.25411449159895, 51.68173292704991, 48.59448848451887, 48.004982471466064, 45.914436272212434, 46.37142971583775, 45.965630599430625, 42.61971861975533, 36.695298876081196, 27.159926380429948, 23.339179720197404, 17.22322940826416, 19.508830649512156, 25.263394730431692, 41.804298877716064, 22.59771834100996, 13.514772585460118, 1.5162538098437446, 1.3482810003416879, 0.5398203134536743, 0.14772383176854678, 0.26596298281635555, 0.03023136101130928, 0.18031605359699043, 0.06920831238052674, 0.043433213140815496, 0.06283441225865058, 0.0556277427157121, 0.04020946612581611, 0.15199025640530245, 0.42137125081249643, 0.1980318972574813, 0.17975638434290886, 0.18705552124551364, 0.9798223716872079, 15.06451095853533, 37.70719630377633, 28.138449873243058, 19.557448932102748, 15.26024866104126, 18.691378559385026, 20.78098848887852, 20.555651460375103, 24.700274501528057, 26.60161430495126, 28.636920588357107, 29.807785851614817, 29.505990845816477, 31.2821102142334, 34.344031946999685, 40.84852205004011, 44.1360969543457, 45.30653837748936, 45.87326124736241, 44.05886425290789, 44.7973187991551, 47.15691314424787, 40.458526611328125, 36.88305309840611, 42.03427035467965, 38.02965872628348, 36.291559900556294, 35.94136721747262, 38.60636963163103, 48.11128643580845, 51.244062423706055, 49.93771423612322, 52.175277369362966, 51.09233113697597, 54.58145938600813, 53.91422387531826, 52.84531995228359, 52.713293756757466, 52.96902567999703, 53.355540071214946, 54.620980739593506, 53.32817459106445, 58.208116803850444, 54.02976894378662, 59.22505514962332, 60.11103384835379, 63.70243263244629, 58.15383400235857, 54.11815350396292, 41.36098296301705, 18.069295917238506, 5.598518831389291, 22.08950798852103, 51.07035051073347, 35.006362029484336, 13.900520937783376, 18.36980550629752, 12.858114838600159, 10.7175772190094, 16.7884076663426, 28.758689505713328, 28.56067453111921, 21.565004110336304, 25.826257875987462, 40.979759625026155, 35.0402866091047, 60.13857650756836, 6.541005057947976, 0.2636816123766558, 0.13128571026027203, 0.1318565753421613, 0.21805390502725328, 0.026282127747046094, 0.0783393241997276, 0.4640505335160664, 0.05080718906330211, 0.05878836901060172, 0.11823840465928827, 0.09056434035301208, 0.055513636874301095, 0.08962642175278493, 0.06300843613488333, 0.046767371374049356, 0.05358554229938558, 0.08888756497097866, 0.0783733120188117, 0.11815347921635423, 0.15999620966613293, 0.0302169930322894, 0.0997253909174885, 0.11049740575253963, 3.4128200922693526, 61.47042805807931, 58.15413277489798, 43.17111723763602, 52.556486810956685, 28.030693735395158, 33.52282782963344, 26.398956196648733, 36.058006627219065, 27.274054016385758, 23.78665586880275, 28.470858642033168, 40.00357593808855, 51.25711114065987, 49.836951460157124, 26.47108892032078, 5.7685620955058505, 6.055788465908595, 14.72637861115592, 22.77594484601702, 29.277641773223877, 31.694840158735, 29.195364679609025, 26.65371537208557, 49.98840134484427, 56.41476937702724, 57.68245778764997, 58.4533326285226, 57.071217809404644, 55.32144601004464, 56.96537937436785, 54.00191708973476, 56.57281657627651, 55.22566161836897, 52.27579001017979, 47.05227674756731, 44.25300734383719, 41.72018051147461, 40.818512780325754, 42.806899615696494, 45.02138083321707, 42.24333470208304, 45.33374057497297, 47.31330667223249, 51.717283385140554, 54.98433331080845, 58.568610191345215, 54.085055759974885, 55.074434076036724, 54.089891706194194, 56.96690797805786, 52.30684150968279, 51.61835493360247, 49.11050687517439, 50.71581172943115, 48.99131052834647, 52.366203444344656, 47.57535450799124, 44.59416389465332, 31.748615741729736, 32.774868147713796, 26.303786720548356, 22.802728414535522, 35.677773407527376, 38.63794919422695, 25.363403626850673, 16.671521595546178, 14.77801067488534, 0.5684478144560541, 0.17180548741349153, 0.2517039765204702, 0.25828185783965246, 0.023916120241795267, 0.23262490172471317, 0.05757991171308926, 0.03302087614844952, 0.06326551269739866, 0.021837005824116722, 0.06307096313685179, 0.3518410346337727, 0.33210535507117, 0.2523106411099434, 0.2936100549995899, 0.012141427424337183, 0.5457368131194795, 20.629055704389298, 52.473445415496826, 34.36629744938442, 27.790973935808452, 23.02283344949995, 25.929332665034703, 26.018165384020122, 25.955885205950054, 30.4712450163705, 34.58888993944441, 34.1222801889692, 36.29258475984846, 35.80437305995396, 35.48413406099592, 39.97318799155099, 44.9246688570295, 47.34059224809919, 48.433099201747346, 48.522074358803884, 46.829795428684776, 47.14309665134975, 47.789352076394216, 42.29587697982788, 40.44285842350551, 43.390923500061035, 39.598485537937705, 40.545177595955984, 39.19209235055106, 42.07948228291103, 49.66256904602051, 55.03975909096854, 53.135164056505474, 53.74528537477766, 53.33152709688459, 59.31427001953125, 55.24528680528913, 56.32323728288923, 54.61781930923462, 56.08796085630144, 55.06786802836827, 58.10096863337925, 56.77438381740025, 58.610612051827566, 54.54960536956787, 57.92636387688773, 59.6188998903547, 65.1422244480678, 62.16669314248221, 58.23617362976074, 43.002637318202424, 21.742678233555385, 7.184263638087681, 26.414292607988628, 53.67272881099156, 39.79770776203701, 16.735354696001323, 17.798493351255143, 16.3823219367436, 13.24622905254364, 20.844373430524552, 27.94643987928118, 33.51919044767107, 24.67140473638262, 30.496647630419048, 51.049867221287315, 40.7084116254534, 68.18593147822789, 13.385906951768057, 0.2103153895586729, 0.3420658420239176, 0.18731693364679813, 0.10102696357561008, 0.10586755775979587, 0.03678446901696069, 0.1670041193387338, 0.06205333024263382, 0.05143153966803636, 0.036991493443825414, 0.16400195471942425, 0.0950558011287025, 0.16900809109210968, 0.1646030688924449, 0.24447977702532495, 0.16390539918627056, 0.22292740137449332, 0.13630377527858528, 0.2667596914938518, 0.3015474219407354, 0.22172463020043714, 0.30038213304110933, 0.4484093242457935, 4.311157464981079, 72.14268738882882, 66.9451082774571, 48.0908066204616, 63.67451477050781, 36.68397331237793, 34.01285300936018, 33.87167951038906, 45.69995927810669, 31.604843616485596, 25.237708977290563, 30.159378596714564, 52.59427111489432, 57.264051164899556, 55.80184098652431, 28.458051374980382, 7.801246302468436, 7.203980454376765, 17.48917865753174, 23.96153507913862, 32.5477489062718, 34.86569227491106, 31.92006949016026, 29.831058842795237, 52.1450457572937, 57.67499194826399, 59.25713498251778, 59.265035084315706, 60.561895506722585, 58.99233218601772, 63.39558628627232, 58.156811305454795, 59.613160678318565, 57.30489615031651, 57.37300934110369, 51.56012902941023, 48.90363121032715, 45.658287457057405, 42.42919554029192, 43.66629450661795, 46.932851110185894, 44.43033579417637, 49.18392848968506, 52.071172509874614, 55.75950561250959, 59.73578248705183, 62.943543434143066, 56.54458257130214, 58.037757396698, 56.981085777282715, 61.069058418273926, 54.55612277984619, 55.805426256997244, 51.98901006153652, 52.976765973227366, 54.220500469207764, 55.846406732286724, 50.49299342291695, 45.0772374016898, 35.13673455374581, 36.326828956604004, 33.548699447086875, 37.00742932728359, 47.653084005628315, 67.07287175314767, 49.97630105699812, 36.268029826028005, 19.821067060743058, 6.385173465524401, 1.507560202053615, 0.3662921206227371, 0.4104747926550252, 0.22207304436181272, 0.4467241960976805, 0.157645262245621, 0.06343028135597706, 0.12532077676483563, 0.08082045534891741, 0.1994404545319932, 0.7391072969351495, 1.7948311929191862, 0.9638807071106774, 0.8123975470662117, 0.18098666332662106, 1.95937636920384, 24.8214111328125, 57.03790119716099, 40.459853717258994, 33.904631342206685, 32.854341643197195, 35.14399194717407, 33.09643425260271, 32.69282381875174, 36.202977316720144, 42.03399590083531, 42.59670271192278, 42.54339960643223, 40.57614571707589, 38.06125218527657, 43.472578729902, 46.69318689618792, 52.190264633723665, 54.41677665710449, 53.46453646251133, 50.947370869772776, 50.86827605111258, 52.08548927307129, 44.15763289587838, 40.91582577569144, 46.8588284764971, 39.6555233001709, 41.745517117636545, 42.22345243181501, 43.55692638669695, 52.87191070829119, 56.43660756519863, 52.99394539424351, 56.068658760615754, 53.36552463259016, 61.251066480364116, 57.63264615195138, 56.13092851638794, 55.36887093952724, 56.803055558885845, 57.9059431212289, 60.479795592171804, 57.73038993562971, 62.97776331220354, 56.50819138118199, 62.556980405535015, 63.54152624947684, 70.84280450003487, 65.85105187552315, 63.410108021327424, 47.29441452026367, 23.569741794041224, 7.303776127951486, 28.51970100402832, 56.33118254797799, 47.370479924338206, 19.672604901450022, 25.680100781576975, 20.87172327722822, 16.783597775868007, 25.398163727351598, 38.74750491550991, 43.79704223360334, 33.03944165366036, 36.00177138192313, 54.63862221581595, 43.837897641318186, 74.33422565460205, 13.784782188279287, 0.6280596671359879, 0.7092884512884277, 0.5005690168057169, 0.3591510280966759, 0.19990109838545322, 0.1722429117986134, 0.7486650869250298, 0.19351184980145522, 0.10829195659607649, 0.18456266501120158], [0.24190077398504528, 0.0385971447852041, 0.08922086137213878, 0.02602669663195099, 0.041112199292651246, 0.09196551516652107, 0.04610115855133959, 0.04973376023450068, 0.03241274253066097, 0.06490589146103178, 0.06722811649420432, 0.06943462416529655, 0.10843882550086294, 2.9876281193324496, 50.168220724378315, 51.50287587302071, 35.084209646497456, 30.399532658713206, 33.40517050879342, 21.438814401626587, 23.61580661364964, 14.568815180233546, 14.143878987857274, 16.249626977103098, 17.551893098013743, 32.511719022478374, 42.337298665727886, 40.777737276894705, 24.529149055480957, 5.335974633693695, 4.390322634152003, 11.780752352305822, 20.6059216771807, 27.746496779578074, 28.612772124154226, 26.493590661457606, 26.179990666253225, 55.415128571646555, 53.80924701690674, 60.86001491546631, 57.54604727881295, 58.5478698185512, 54.17222091129848, 56.05057954788208, 54.198342663901194, 52.2256691796439, 50.29757533754621, 46.62077624457223, 40.52380493709019, 40.924973079136436, 39.000471455710276, 42.928892612457275, 39.58224759783064, 41.43323728016445, 41.03352131162371, 42.13658257893154, 39.99686050415039, 50.69045427867344, 53.54151208060128, 54.12274973733084, 49.524900913238525, 49.48673793247768, 50.5884929384504, 53.68959208897182, 48.51680415017264, 51.085018157958984, 46.06840835298811, 45.66955396107265, 44.48445531300136, 47.49872629983084, 40.19911561693464, 39.65339715140206, 23.872566870280675, 21.219968727656774, 12.170503735542297, 14.58142181805202, 28.114535910742624, 29.015128408159526, 10.955010192734854, 2.242593411888395, 9.68068712098258, 0.7959568606955665, 0.046569703945091794, 0.18470073331679615, 0.14990752030696186, 0.12042444092886788, 0.028406512324831316, 0.06923664800290551, 0.05510988139680453, 0.04782837283398424, 0.11512909936053412, 0.021914133203348944, 0.08442724216729403, 0.3160687227334295, 0.5176913865974971, 0.11076142372829573, 0.058524527453950474, 0.13802901841700077, 1.4536857157945633, 9.11744703565325, 10.511149712971278, 14.578435829707555, 11.033622111592974, 13.218525716236659, 19.1608179637364, 18.72096746308463, 23.461478437696183, 24.766004460198538, 28.00447644506182, 29.974302904946462, 30.210427011762345, 32.39885943276541, 35.297891071864534, 39.602644034794395, 44.88620015553066, 45.02976383481707, 45.00969396318708, 44.46804714202881, 45.8447527885437, 43.5404417855399, 38.563110147203716, 40.619954109191895, 42.48813016074044, 43.68228925977434, 38.89086709703718, 35.43703917094639, 43.48717342104231, 48.142126015254426, 52.33095523289272, 49.530181544167654, 51.12340348107474, 52.95899942943028, 53.2454389163426, 52.74422018868582, 54.46281542096819, 52.881631238119944, 52.27917725699288, 54.280220236097065, 56.03822565078735, 55.36691154752459, 55.85263579232352, 53.78499085562569, 55.639781202588765, 56.69742209570748, 58.20113386426653, 58.73766681126186, 57.02234765461513, 39.36680480412075, 17.353839908327373, 7.039297725473132, 28.56559385572161, 53.65544169289725, 29.071443557739258, 15.373662369591848, 35.40848902293614, 16.72034137589591, 16.47447763170515, 15.66413528578622, 28.797759226390294, 26.42874138695853, 26.833691086087907, 27.855427162987844, 49.22488464627947, 37.408965723855154, 63.00496550968715, 18.55955559866769, 0.28053910923855646, 0.536619745194912, 0.02673796926891165, 0.10643549157040459, 0.03830146636547787, 0.007387099637916046, 0.16521818802825042, 0.08544530253857374, 0.05002728430554271, 0.09870008379220963, 0.20390644988843373, 0.010231433619212891, 0.07510936180395739, 0.08841119946113654, 0.10694445390254259, 0.04650864936411381, 0.0467226152042193, 0.05827784604792084, 0.022523679870313833, 0.08138918304549796, 0.08238377967583281, 0.06367246407483305, 0.035683783436460156, 3.4058317244052887, 57.646775313786094, 60.30030277797154, 40.634322983878, 36.981665406908306, 41.37128366742815, 27.80934497288295, 25.467338255473546, 20.787490265710012, 20.55307194164821, 19.542188950947352, 24.27366726739066, 36.93338584899902, 44.89505216053554, 44.29375505447388, 29.975699492863246, 6.644929698535374, 4.100115920816149, 10.380822352000646, 20.523392711366924, 28.611559663500103, 28.625044379915508, 29.85076740809849, 29.62093836920602, 57.82687609536307, 55.51499502999442, 63.661132540021626, 58.288312911987305, 58.754168782915386, 56.21398033414568, 58.0840219770159, 55.80926513671875, 54.29077802385603, 50.85839918681553, 48.19278533118111, 43.091049671173096, 44.60034779139927, 42.811325618198936, 45.0073732648577, 42.07899590900966, 44.65138578414917, 41.48749923706055, 44.61456380571638, 43.49572317940848, 51.11961323874337, 54.89295755113874, 55.75338077545166, 51.767018590654644, 53.37502976826259, 52.66626140049526, 54.16879197529384, 53.284647600991384, 53.49121407100132, 50.44997712544033, 46.64413608823504, 47.69771228517805, 51.782301153455464, 44.859946387154714, 47.793948309762136, 30.98198277609689, 28.746184485299246, 23.923205341611588, 19.41147596495492, 33.480725220271516, 35.890944140298025, 22.749439205442155, 27.169212647846766, 20.327901669910975, 0.5475675548825945, 0.238419237945761, 0.1093202560607876, 0.2334966835166727, 0.07239616489303963, 0.05926890751080854, 0.10012037972254412, 0.043253096020115275, 0.017490636191463897, 0.06578587674136673, 0.043123451726777215, 0.08276632414864642, 0.17252322818551744, 0.45858441825423923, 0.052455296340797625, 0.08314510275210653, 0.17025523845638546, 2.136563684259142, 12.304161020687648, 10.996004564421517, 19.633465698787145, 17.622582333428518, 19.16252895763942, 24.0528587273189, 23.70623220716204, 32.73032324654715, 32.99948951176235, 36.49847725459507, 35.16871016366141, 37.03953695297241, 35.236468996320454, 41.48002644947597, 42.45030069351196, 48.085588523319785, 47.975928579057964, 49.554090295519146, 46.56179993493216, 46.887548855372835, 43.48989364079067, 41.40819944654192, 42.31587389537266, 46.28666516712734, 44.35662235532488, 42.53880337306431, 38.1115015574864, 44.48579978942871, 50.58460194723946, 53.40413924625942, 51.12813867841448, 53.336425576891216, 53.70487117767334, 54.98838063648769, 55.068510736737935, 54.07886144093105, 53.933755261557444, 56.386816774095806, 55.69736092431204, 58.1392879486084, 55.50372505187988, 53.455302306583945, 54.29267488207136, 54.8606345312936, 59.14620699201311, 62.23830822535923, 59.95232309613909, 61.486186572483604, 44.6558951650347, 19.4094557762146, 9.144944531576973, 33.783058711460654, 56.13998201915196, 30.87749923978533, 16.31547158105033, 42.27937500817435, 25.886120080947876, 18.722405740192958, 19.46884376662118, 28.14420645577567, 30.381147725241526, 31.02338014330183, 29.825528076716832, 50.343412603650776, 42.742733001708984, 70.53857067653111, 28.42166018486023, 0.23337560572794505, 0.5028469945703233, 0.04052616895309516, 0.14359092925276074, 0.056325860254998715, 0.046474878676235676, 0.13236952067485877, 0.016759012592956424, 0.027628113914813315, 0.07648418231734208, 0.317053955580507, 0.1128324211708137, 0.15633545895772322, 0.5763890083347047, 0.34419492206403185, 0.3380969007100378, 0.1454074489218848, 0.2209339469139065, 0.13343460352293082, 0.21031958290508815, 0.14205304320369447, 0.15742600043969496, 0.3023024414266859, 5.528501399925776, 73.09939874921525, 66.7514202935355, 47.20406709398542, 46.148409911564414, 48.649622440338135, 28.460523196629115, 29.654720510755265, 21.394700288772583, 19.798283917563303, 28.509065049035208, 22.216642652239116, 46.17844349997384, 53.619099140167236, 49.903348445892334, 32.937469891139436, 7.843534776142665, 5.291532218456268, 12.783462524414062, 22.917729786464147, 31.395963396344865, 29.8450733593532, 32.15080874306815, 33.08652612141201, 62.001367705208914, 56.33595248631069, 65.5654114314488, 60.37433583395821, 60.259954588753835, 58.78860405513218, 64.4888436453683, 61.99274499075753, 58.383753367832725, 55.724316460745676, 52.71791778291975, 45.1618595123291, 47.500494616372244, 44.93139818736485, 47.24008655548096, 42.12635483060564, 46.11621543339321, 43.83690057482038, 47.25080067770821, 46.20943941388811, 55.616695812770296, 59.801269258771626, 60.33252852303641, 52.101272106170654, 53.30351196016584, 54.25079114096505, 57.33044120243618, 55.15689182281494, 56.926882880074636, 51.125397614070344, 50.187230995723176, 49.7755571774074, 56.43860169819423, 47.90530014038086, 49.9946859904698, 32.601184027535574, 34.90584938866751, 30.618911606924875, 33.41489451272147, 54.62878704071045, 57.51701423100063, 38.72524288722447, 34.07941675186157, 35.974107129233225, 3.191071156944547, 0.7529121190309525, 0.33977212224687847, 0.17581007895725115, 0.3418902371610914, 0.1926068062228816, 0.19859855542225496, 0.12394362209098679, 0.12843067917440618, 0.31916224530764986, 0.19457562986229146, 0.1359101299728666, 0.5702752449682781, 1.209480202623776, 0.6499755882791111, 0.12345256629799094, 0.31055473004068646, 5.513508924416133, 19.13474484852382, 13.69618136542184, 26.441837004252843, 26.77439342226301, 29.474088191986084, 35.208401748112266, 32.86318670000349, 37.52308293751308, 39.13340091705322, 42.7281938961574, 42.37544775009155, 41.878912108285085, 39.89622279575893, 45.778272424425396, 48.39634323120117, 51.89204100200108, 53.61390536172049, 54.418141978127615, 48.613665512629915, 51.62152678625924, 47.33148315974644, 42.79568174907139, 44.95066554205758, 47.82911661693028, 46.99401610238211, 44.015795843941824, 40.963160378592356, 47.597884041922434, 52.223622935158865, 58.12139981133597, 53.17098896844046, 55.75082731246948, 56.540997300829204, 57.87038918903896, 60.454524993896484, 59.339742115565706, 57.201107433864046, 59.11343928745815, 59.549661091395784, 62.59639058794294, 61.89543546949114, 58.881654330662315, 58.493687765938894, 60.80105250222342, 62.76188973018101, 66.56142180306571, 65.90794372558594, 64.76895332336426, 46.94554546901158, 23.489608219691686, 10.096916351999555, 35.9273179599217, 61.275162833077566, 38.77987657274519, 19.675040245056152, 45.016402448926655, 26.05227930205209, 22.596290486199514, 22.911342654909404, 38.749457359313965, 38.187372412000386, 40.26002352578299, 35.40362180982317, 62.1910674231393, 47.83596406664167, 77.06412424360002, 27.69757103919983, 0.48766930614198956, 1.1631795785256793, 0.20147661598665373, 0.24760548930083, 0.17258683405816555, 0.11081606615334749, 0.3505802351449217, 0.14175433851778507, 0.14304978400468826, 0.20321137218603066], [0.16300008419368947, 0.06159336492419243, 0.13330083712935448, 0.05747075578463929, 0.07921493292919227, 0.05886314356965678, 0.08196891658008099, 0.07421471338186945, 0.012835992832801171, 0.09463707038334437, 0.06854020644511495, 0.13465679436922073, 0.0830992812822972, 0.8103733956813812, 43.21996654782976, 51.28907285417829, 31.412121432168142, 28.142415557588848, 24.984556572777883, 27.426983867372783, 22.016374724251882, 9.586704049791608, 13.496053269931249, 25.55825890813555, 14.583674771445137, 29.305712495531353, 34.6001877103533, 40.00337096623012, 29.98888717378889, 10.986630575997488, 2.19771152309009, 8.755057658467974, 18.04718327522278, 25.05015277862549, 26.41645176070077, 25.92442897387913, 30.68494381223406, 51.80920457839966, 54.72596802030291, 57.833612373897004, 55.89780255726406, 58.475233350481304, 51.011058058057515, 47.2536563873291, 44.74925116130284, 45.07349232264927, 43.12848309108189, 42.448845045907156, 41.881965841565815, 42.156179973057334, 39.65722213472639, 43.73248652049473, 41.166673115321565, 40.41921022960118, 41.26777287891933, 40.196958201272146, 41.04731348582676, 45.0222840990339, 49.77453579221453, 51.451486996241975, 50.55247695105416, 50.588121209825786, 51.20558329990932, 50.99434069224766, 49.26261336462838, 46.90204279763358, 43.272018977573936, 45.01053816931588, 44.83917127336775, 44.27150692258562, 40.88251263754708, 39.48156820024763, 26.043844188962662, 13.895090052059718, 13.308556999479022, 12.929524949618749, 28.19842324938093, 24.630474635532924, 14.472459299223763, 14.63686670575823, 7.90879225730896, 1.054227807692119, 0.18286411544041975, 0.1245695570749896, 0.10768367030790874, 0.10131685409162726, 0.11165936983057431, 0.09916716694299664, 0.16563501209020615, 0.024784424541784183, 0.07325044726686818, 0.017955761768722107, 0.09926113725772925, 0.2179179401802165, 0.15042558179369994, 0.2370595894753933, 0.24569221053804668, 0.08206944154309374, 0.169148005012955, 0.8717683841075216, 5.021827467850276, 9.959545254707336, 10.088836465563093, 10.398193717002869, 13.236762131963458, 16.983523505074636, 23.67149121420724, 25.260964597974503, 29.069762093680247, 29.04900435038975, 29.420302186693462, 30.99523299080985, 35.333111490522114, 38.83757788794381, 40.1682517187936, 43.36897414071219, 41.99598230634417, 45.842234066554475, 43.08511938367571, 39.82706042698452, 38.99643455232893, 41.66198240007673, 43.78034223828997, 41.372343267713276, 39.27543599264962, 36.63791717801775, 43.33352443150112, 50.371278354099815, 53.301601205553325, 51.3158859525408, 53.598893778664724, 51.769009249550955, 52.98894269125802, 49.37725864137922, 50.2671457018171, 53.129230294908794, 48.55469962528774, 48.27103246961321, 50.47267689023699, 46.542237281799316, 50.09956210000174, 50.494914599827354, 52.00037036623274, 57.811524050576345, 56.2714523587908, 58.033553736550466, 55.432464327131, 41.13820634569441, 15.577060461044312, 9.637927038328987, 35.97538559777396, 56.10235752378191, 17.945578030177526, 24.119509322302683, 34.69054555892944, 10.719728554998126, 18.94624195780073, 13.64256124837058, 32.31307002476284, 22.331873314721243, 34.947323186056956, 19.450535263334, 37.52873877116612, 37.676641600472585, 56.81614596503121, 37.78696162360055, 0.17331213371029922, 0.22973808805857385, 0.10978638247719832, 0.14494736146714005, 0.14282813375549658, 0.026904156065679023, 0.10736908111721277, 0.026122504080246602, 0.02329258218274585, 0.20950110682419368, 0.03345155928816114, 0.0851501262347613, 0.17422401692186082, 0.02877270749637059, 0.131651603483728, 0.03633915666224701, 0.03225966503045388, 0.015056271372096879, 0.04449717301343169, 0.08788175215678555, 0.05534665279888681, 0.08790720400533505, 0.09999405685812235, 2.4791554723467146, 56.18520784378052, 58.43380124228341, 38.807683263506206, 34.81509549277169, 29.59253760746547, 32.226252283368794, 26.11290407180786, 13.843814952032906, 17.586022649492534, 27.73896493230547, 16.579405852726527, 34.3114309992109, 36.60190119062151, 42.63632481438773, 34.167565073285786, 15.670015198843819, 1.892953327723912, 7.703889012336731, 17.831273215157644, 26.015813418797084, 27.227648735046387, 29.84873158591134, 36.03984751020159, 57.6327086857387, 58.20206492287772, 60.44286591666085, 58.68105288914272, 56.44161721638271, 52.73481232779366, 50.410184792109895, 48.380268573760986, 47.03680658340454, 45.19877529144287, 45.53060735974993, 44.843722343444824, 46.205687386649, 44.27417503084455, 46.75758627482823, 45.50797707693917, 42.19234882082258, 44.07279886518206, 42.776449135371614, 43.08549458639962, 46.886940887996126, 52.17338745934622, 54.79077386856079, 52.360294001443044, 52.467897278921946, 55.38893386295864, 52.87644093377249, 50.19841412135533, 48.17288569041661, 47.49769796643938, 47.65176384789603, 48.00834539958409, 48.445189067295615, 47.211856024605886, 43.8977563721793, 34.63541855130877, 26.85292022568839, 24.08897372654506, 15.985505104064941, 24.52820236342294, 31.19502149309431, 39.78051444462368, 44.15134130205427, 10.828500866889954, 0.36951451056769913, 0.17656448776168482, 0.1481945315109832, 0.08506311090396983, 0.19338390523833887, 0.0832842770697815, 0.01407709699456713, 0.10304492672107049, 0.04116013439904366, 0.04522717830591968, 0.07617105876228639, 0.054632057036672316, 0.13758913773511136, 0.3769832540835653, 0.10927993072462933, 0.10930557934833424, 0.19461174149598393, 0.26839995490653173, 1.3362304355416978, 9.768069403512136, 17.66773693902152, 18.437482697623118, 17.29201831136431, 21.370510135378154, 24.094818898609706, 32.09457697187151, 30.077664307185582, 36.17139080592564, 35.05141414914812, 35.69345201764788, 36.14190265110561, 39.66632080078125, 43.24241617747715, 45.85749578475952, 45.647851262773784, 46.523327759334016, 49.26019539151873, 45.231793131147114, 41.70045110157558, 42.90246513911656, 46.99975878851754, 47.049886567252024, 45.35685723168509, 41.19049154009138, 37.97100898197719, 46.593643529074534, 52.67822272436959, 53.82163912909371, 52.70417077200753, 54.95041915348598, 53.44679076331002, 54.26775516782488, 51.482573236737935, 50.38233641215733, 51.67334645135062, 49.777096203395296, 50.43279423032488, 48.336765902382986, 45.880727086748394, 53.15534857341221, 54.2939498765128, 53.748721258980886, 58.37299755641392, 59.460960388183594, 62.518598556518555, 59.46819346291678, 41.267251764025005, 15.446290152413503, 11.54967176914215, 40.88670587539673, 57.12880447932652, 20.416221959250315, 27.344566072736466, 42.55401645387922, 17.61271415437971, 19.491592168807983, 17.48462758745466, 29.77723809650966, 26.714402675628662, 38.27449240003313, 27.6226156098502, 45.58788136073521, 42.9542361668178, 61.68839999607631, 49.960108280181885, 0.5533653923443386, 0.16967263471867355, 0.06968062025095735, 0.12154927557068211, 0.11818471896861281, 0.05686294786365969, 0.04441406943702272, 0.10834607654916388, 0.04091917643589633, 0.09809400952820267, 0.1314612201281956, 0.1268862249063594, 0.3694659546017647, 0.22812591599566595, 0.2830043083855084, 0.13883654294269426, 0.14381313590066774, 0.10961794294416904, 0.0923157681577972, 0.21225902597819055, 0.12884862960449286, 0.33472683440361706, 0.37759214426789967, 3.7449396422931125, 68.41582652500698, 64.65994998386928, 45.615437916346956, 40.46825756345476, 36.25917434692383, 38.3140241759164, 32.20114844185965, 12.710986733436584, 16.47624942234584, 39.5586793082101, 21.40995853287833, 42.160168239048545, 48.251132828848704, 46.82644639696394, 39.2540841783796, 14.92050780568804, 3.193950968129294, 10.044856974056788, 23.027921267918178, 28.451259510857717, 30.492732320513042, 32.74693986347744, 40.92920453207833, 61.09043107713972, 60.29190240587507, 62.56080886295864, 59.23915999276297, 59.100571223667686, 55.59562887464251, 53.43866484505789, 52.04329286302839, 50.28836897441319, 47.37582308905465, 47.7730724470956, 46.65872383117676, 48.63103253500802, 44.32576887948172, 48.444417817252024, 44.450687067849294, 44.20029483522688, 46.955123560769216, 45.242469038282124, 46.3105912889753, 51.42830433164324, 57.51671545846121, 58.47970104217529, 52.73113325663975, 56.046004159109934, 58.079592500414165, 57.85506493704659, 53.54688303811209, 52.146223476954866, 49.70488010134016, 50.35269539696829, 51.781665393284385, 54.7443390573774, 52.17629875455584, 49.58549267905099, 37.43118258884975, 31.186030524117605, 32.84479134423392, 28.19595316478184, 42.94691276550293, 50.71534967422485, 48.3225359916687, 60.6754846572876, 35.35143389020647, 2.12562244279044, 0.4723873404519898, 0.30108694093567984, 0.42639075432504925, 0.17320940350847586, 0.20281064297471726, 0.12981303142649786, 0.20819304058594362, 0.15899059362709522, 0.11034712381660938, 0.20113609997289522, 0.13270163642508642, 0.3133290426007339, 1.0879906245640345, 0.6491133059774126, 0.4065671366240297, 0.2527764689709459, 0.4516100553529603, 1.871596953698567, 11.034769432885305, 21.288642985480173, 21.496946505137853, 27.058130059923442, 32.16016796657017, 32.22399411882673, 39.07757214137486, 35.64815671103341, 41.236947195870535, 42.20032187870571, 40.63945770263672, 40.66832051958357, 44.82709183011736, 45.85347972597395, 48.608461311885286, 49.39737715039934, 48.60497679029192, 52.925040108816965, 50.18453509466988, 45.29665109089443, 45.02007457188198, 48.46335513251168, 49.90672179630825, 46.92872735432216, 46.113707133701865, 41.518786975315635, 48.57091324669974, 55.05466992514474, 57.75239140646798, 55.718413966042654, 59.73969432285854, 55.06016942432949, 60.25604970114571, 54.62933594839913, 53.41079909460885, 57.31477648871285, 55.891761098589214, 55.25880452564785, 54.75093289784023, 50.31351797921317, 57.340950352805, 56.60612276622227, 55.80349465778896, 61.847326142447336, 62.25804805755615, 65.3882532119751, 63.132180077689036, 46.05129146575928, 19.09448524883815, 13.153945684432983, 42.52908284323556, 63.99195711953299, 27.35817585672651, 30.74461841583252, 42.4962352343968, 16.55619192123413, 24.017339536121913, 19.73592730930873, 44.16293784550258, 33.21946600505284, 47.40959480830601, 28.529456274850027, 51.589874267578125, 47.82504844665527, 71.37786442892892, 54.45972694669451, 0.5512541713459151, 0.44814998816166607, 0.2138324129794325, 0.2737883914794241, 0.1971806479351861, 0.1292922015168837, 0.14502613938280515, 0.15944034020815576, 0.16032462061515876, 0.24427447947008268], [0.04117696885285633, 0.05161268137661474, 0.1440796780266932, 0.09612044971436262, 0.05012311041355133, 0.046672770021749396, 0.06098691068057503, 0.05753160680511168, 0.05646699553887759, 0.013749542696002339, 0.16361809388867446, 0.046333186993641515, 0.18773275347692625, 5.601475724152156, 58.32474231719971, 46.68650620324271, 34.23151976721627, 30.194112641470774, 39.65168789454869, 25.575994185038976, 28.117778982434952, 17.41928846495492, 20.932193449565343, 20.136708089283534, 22.293548788343156, 15.839610304151263, 29.887162072317942, 48.74020957946777, 40.261107444763184, 22.40467480250767, 4.12722475188119, 4.308085926941462, 14.136317610740662, 21.707080875124248, 24.10394709450858, 26.87368491717747, 34.44531236376081, 53.28184052876064, 59.16511304037911, 56.791427748543875, 53.71370581218174, 53.69815574373518, 51.18780633381435, 43.78309025083269, 42.04152079990932, 43.26418488366263, 41.75971923555647, 44.205290590013774, 44.327495506831575, 46.24817214693342, 46.38204656328474, 44.61688102994646, 46.24044227600098, 44.851420947483604, 41.59481763839722, 39.49468639918736, 40.085102626255576, 42.594177041734966, 45.87216690608433, 50.62283788408552, 49.44965192249843, 50.69399438585554, 51.53868688855852, 49.378985268729075, 48.934387411390034, 44.929664611816406, 45.70427758353097, 42.42126417160034, 42.02878475189209, 40.80777433940342, 38.418007441929404, 37.63182919366019, 27.748754944120133, 7.8142707007271905, 10.53866023676736, 10.419489077159337, 20.2685866355896, 23.928941079548427, 35.17085368292672, 17.21878603526524, 2.2297129716191972, 0.1220472931329693, 0.07101389406515018, 0.11803576696131911, 0.04705732635089329, 0.04570110108969467, 0.08446559296654803, 0.06971896426486117, 0.03510038920545152, 0.02781201556458005, 0.0485270671280367, 0.0583939366042614, 0.06183097431702273, 0.05459184026611703, 0.1776213196239301, 0.15927225351333618, 0.4868531642215592, 0.03570579171979001, 0.0018242002614507718, 0.43513134387987, 2.168730152504785, 8.536857298442296, 8.923479386738368, 11.274801901408605, 10.166795253753662, 14.803041560309273, 22.043021065848215, 23.625794649124146, 28.221327986036027, 27.513818979263306, 29.81664480481829, 30.002641132899694, 34.66766514096941, 40.23676790509905, 41.7062771660941, 42.777470520564485, 44.51938043321882, 42.21018137250628, 37.973677090236116, 37.58864961351667, 43.383238792419434, 44.55776923043387, 44.79688801084246, 44.244110175541465, 37.93193231310163, 38.57056903839111, 47.864083426339285, 51.616336481911794, 50.24596411841256, 51.61044788360596, 50.00994076047625, 50.352226393563406, 46.456433977399556, 42.85292100906372, 42.67818076269967, 40.364006791796, 40.65165179116385, 41.1860169001988, 41.95429311479841, 45.936451639447895, 47.47072505950928, 51.26051575796944, 53.72729301452637, 56.0824613571167, 58.615232603890554, 60.35952227456229, 55.871131896972656, 32.98101077760969, 11.192275541169302, 9.822222794805255, 46.67561490195138, 44.62772021974836, 17.44980842726571, 18.314638546534947, 18.064525978905813, 23.85430005618504, 22.028485434395925, 17.38137561934335, 29.970238208770752, 26.696521486554825, 29.94558252607073, 28.286036559513636, 41.418364661080496, 42.45298964636666, 47.74022136415754, 55.919324602399556, 1.8048772024256843, 0.10701494012027979, 0.08592028383697782, 0.10426308706934963, 0.11103219312748738, 0.09075985343328544, 0.08316980821213552, 0.04114097596279212, 0.056996995849268775, 0.009659968882000871, 0.03849757994924273, 0.06952347832598857, 0.24271979289395468, 0.04220826404967478, 0.12494535690971784, 0.040743374797914705, 0.07257895544171333, 0.04969733986737473, 0.12161085940897465, 0.039877011108079126, 0.09132203326693603, 0.09238451732588665, 0.1489482210682971, 9.197678753307887, 71.108642578125, 54.39070354189192, 44.78562845502581, 33.70500612258911, 47.40017999921526, 30.893351554870605, 27.738858972276958, 22.086654015949794, 23.871667078563146, 23.83569278035845, 22.57543546812875, 20.637143407549175, 32.81531708581107, 52.027937344142366, 49.131994179316926, 27.85117139135088, 6.487128291811262, 4.093894677502768, 13.53810203075409, 21.280530963625225, 25.340719495500835, 28.74902629852295, 38.355487551007954, 55.96446010044643, 57.31054503577096, 55.82169198989868, 55.63712699072701, 54.28722749437605, 50.65092250279018, 45.52132109233311, 46.61532538277762, 47.231911999838694, 44.85892847606114, 47.30923155375889, 46.75186790738787, 46.83119201660156, 50.71771553584507, 50.41451351983206, 48.46650614057268, 46.30416420527867, 45.70036227362496, 42.905042920793804, 40.7019602230617, 43.59307091576712, 46.71415655953543, 53.18270363126482, 54.98098427908761, 52.19482265199934, 53.32009383610317, 51.737342834472656, 50.02950341360909, 47.26006957462856, 47.16290943963187, 47.42892122268677, 45.807128293173655, 46.16995627539498, 43.92864806311471, 45.89282737459455, 37.173699719565256, 25.508494172777446, 19.65180025781904, 13.83482050895691, 15.135910647256033, 33.5732022694179, 46.23474475315639, 23.181650161743164, 1.1920111285788673, 0.07472712945725236, 0.04909026476421526, 0.15903042363268988, 0.1633273416331836, 0.05219859975789275, 0.09305497099246297, 0.10775740670838527, 0.16399221095655644, 0.04400922491082123, 0.03196440730243921, 0.04622648396928396, 0.08420088967042309, 0.02073661031733666, 0.30822260518159184, 0.18228646500834397, 0.37974774145654266, 0.07129984229270901, 0.033767692146024535, 0.20651415496000222, 5.937322982719966, 13.26653950554984, 15.87797130857195, 17.207000153405325, 14.69890022277832, 21.79844273839678, 28.235526629856654, 31.020937851497106, 35.01940032414028, 34.22388022286551, 34.941549233027864, 35.423955712999614, 39.263085569654194, 42.32020957129342, 43.73744058609009, 44.63726704461234, 45.4956613949367, 41.08806814466204, 38.24192271913801, 39.94798340116228, 45.33418525968279, 48.08384452547346, 47.991398743220735, 46.64146450587681, 41.12590108598982, 42.32055350712368, 51.895449093409944, 53.226612772260395, 53.59710461752755, 54.04431847163609, 54.1421525818961, 52.161068303244456, 45.834636211395264, 43.842278480529785, 45.0624029976981, 42.68542773383004, 43.22938135692051, 43.47190475463867, 44.30661269596645, 48.9150436265128, 51.580004351479666, 56.39377539498465, 57.41599784578596, 55.55716017314366, 60.86953394753592, 61.66062109810965, 55.581496238708496, 34.13244192940848, 12.291419761521475, 11.993496639387947, 53.46250411442348, 48.136122771671836, 22.21433585030692, 23.60827476637704, 22.64123317173549, 29.08260062762669, 23.542002848216466, 20.65665568624224, 30.63415595463344, 26.071475437709264, 30.313142231532506, 32.0755215372358, 54.557679176330566, 54.81971311569214, 53.87380273001534, 64.13073348999023, 6.512069284915924, 0.099168490086283, 0.36326639726758003, 0.23725992015429906, 0.17965870244162424, 0.043592166754284074, 0.017388971289619803, 0.04406317862282906, 0.06845816477601017, 0.011446381104178727, 0.1207971873560122, 0.23533844468849047, 0.3527935620929514, 0.2515981250575611, 0.25389417899506433, 0.14214798382350377, 0.20858394461018698, 0.16785630503935473, 0.21271942555904388, 0.11862815517399992, 0.3027032384915011, 0.18083540430026396, 0.322282393596002, 11.591222865240914, 83.97921466827393, 58.02340241840908, 51.705509662628174, 42.34926693780081, 54.58477715083531, 37.931605747767854, 39.254073756081716, 23.010276317596436, 28.04436605317252, 28.335122108459473, 30.50001403263637, 26.640861204692296, 39.80947801045009, 55.45533084869385, 51.24120323998587, 27.49816468783787, 6.149266489914485, 4.727866555963244, 17.109834807259695, 23.864209924425396, 29.491562911442347, 30.101427146366664, 43.60455976213728, 58.723555019923616, 61.05842072623116, 58.48034722464425, 55.86744935171944, 56.113269669669016, 53.21048600333077, 47.08835874285017, 48.9908241544451, 49.80501406533377, 45.46649980545044, 48.23784439904349, 48.1683554649353, 49.87861633300781, 52.47690909249442, 52.502822399139404, 49.35822057723999, 48.20783512932913, 46.14549514225551, 46.51851960590908, 44.19141503742763, 45.69597101211548, 50.67975752694266, 56.57696465083531, 55.57638931274414, 55.382284436907085, 56.81789343697684, 54.24062245232718, 53.075138568878174, 49.99237224033901, 50.245755672454834, 49.607754707336426, 47.97891630445208, 49.42509698867798, 48.31896114349365, 51.290247099740164, 43.88471112932478, 32.165247099740164, 30.94438259942191, 25.240503890173777, 25.755104848316737, 45.03895282745361, 63.18078967503139, 47.40617282049996, 11.186833364622933, 0.34751884798918453, 0.1078579452420984, 1.0493964212281364, 0.4649855004889624, 0.14485714345106057, 0.22154507626380238, 0.20261054299771786, 0.2332286350429058, 0.14298742663647446, 0.12841729846383843, 0.08127143007836171, 0.11059810034930706, 0.08083520670022283, 0.32106284903628485, 0.33162869779126986, 0.7253259792923927, 0.1268950187202011, 0.09312347588794571, 0.6830155210835593, 7.027066724640982, 17.76376278059823, 25.967469590050833, 28.448716470173427, 27.53366650853838, 34.13124336515154, 37.3887916292463, 37.51361601693289, 41.81283473968506, 38.96088062013899, 40.52250909805298, 38.625383377075195, 43.011180128370015, 45.55287286213466, 47.67016615186419, 46.43171228681292, 48.40028633390154, 46.24160609926496, 43.03062118802752, 40.91246632167271, 48.23172303608486, 50.56402833121163, 48.867483207157676, 49.38817078726632, 42.33366128376552, 44.16752713067191, 54.38085099628994, 56.49766138621739, 57.089922360011506, 58.03882394518171, 55.859055927821565, 55.623136792864116, 50.01073285511562, 48.16357510430472, 48.54734148297991, 45.750180857522146, 47.19507612500872, 45.73408882958548, 47.70165538787842, 50.850297587258474, 53.86508968898228, 59.545144762311665, 60.651575905936106, 58.60451848166329, 63.85593223571777, 68.04088088444301, 61.05680179595947, 38.47474643162319, 15.992274386542183, 13.326221057346888, 56.142028263636995, 54.886895247868125, 30.588381222316197, 25.10223821231297, 24.321754012789043, 35.05921697616577, 28.371553250721522, 25.410931042262487, 43.4917105947222, 37.729743208204, 40.196166106632774, 37.76218087332589, 53.66453341075352, 57.492681639535085, 55.20911448342459, 74.7855806350708, 5.572829604148865, 0.3373783321252891, 0.3022885721709047, 0.4007839826600892, 0.25285906025341576, 0.13799002979482922, 0.20639424425150665, 0.13286985882690974, 0.1508818423109395, 0.12757553506110395], [0.02360434697142669, 0.07650706930352108, 0.08163629192858934, 0.08880111960960285, 0.06336342530058962, 0.0975475784923349, 0.04996948329997914, 0.018294187894623195, 0.08669922168233565, 0.05283833275149975, 0.05394292330103261, 0.06498777028173208, 0.16941194156450884, 14.349169594900948, 55.39743150983538, 40.83327770233154, 30.34335994720459, 36.34446348462786, 31.65785837173462, 24.512799944196427, 31.291083812713623, 18.59176049913679, 27.169235229492188, 18.97852155140468, 25.0063704422542, 19.19327994755336, 28.72147147996085, 43.44058574948992, 45.2457138470241, 36.35909639086042, 9.269636034965515, 3.8986029624938965, 7.083568172795432, 18.095445462635585, 18.38909717968532, 23.663406985146658, 33.42178365162441, 54.88508871623448, 58.484349387032644, 57.940187317984446, 54.60303354263306, 51.419622557503835, 48.07286984579903, 45.426182883126394, 41.83434983662197, 45.041200569697786, 43.79496124812535, 45.267430441720144, 47.89340829849243, 48.73341424124581, 48.172972542899, 47.48648704801287, 47.689311913081575, 48.70615645817348, 46.318630354745046, 42.141870158059255, 38.378889083862305, 40.75565242767334, 46.656114782605854, 50.532751015254426, 50.87007563454764, 51.800230979919434, 50.69238240378243, 50.190298625401084, 45.340928486415315, 45.33564438138689, 40.797522272382466, 43.95127139772688, 38.7953919001988, 40.665523869650706, 38.41844865253994, 36.152623721531455, 31.805469376700266, 7.424986583845956, 9.760389907019478, 10.334436178207397, 9.627755744116646, 27.368219477789744, 22.527369567326136, 5.085735261440277, 0.30510555101292475, 0.07165244301514966, 0.051075257893119536, 0.08152723099504199, 0.10441881764147963, 0.49108103449855534, 0.1234010790607759, 0.022548800933041742, 0.04769416878532086, 0.06638826656022243, 0.019203747123745934, 0.07893930521926709, 0.12270925832646233, 0.10842302242027861, 0.04612645094415971, 0.4241009700511183, 0.5160258273993219, 1.1337080342429025, 0.15347027698797838, 0.32126692522849354, 0.8149789656911577, 2.5847174993583133, 8.067169495991298, 7.996121559824262, 7.925725017275129, 10.70020237990788, 21.190621273858206, 21.810596874782018, 26.08977004459926, 26.03052796636309, 29.813195024217876, 30.153469153812953, 36.02522850036621, 38.35647072110857, 43.17104080745152, 41.839345591408865, 42.0379251071385, 37.661463260650635, 35.06321913855416, 40.185490199497764, 45.79636900765555, 46.8971860068185, 45.44310174669538, 44.570140498025076, 36.880100114004954, 41.026392459869385, 49.02942139761788, 48.84257391520909, 49.54703787394932, 51.62615776062012, 49.27526603426252, 46.329775265284944, 43.24636970247541, 42.39723382677351, 40.46522467476981, 42.75064352580479, 44.625594070979524, 42.80633681161063, 45.736468587602886, 52.12132460730416, 52.67335203715733, 53.85240922655378, 53.692836897713796, 58.520160402570454, 58.56612968444824, 58.29840169634138, 45.848921707698274, 27.683695486613683, 5.347011847155435, 11.628075242042542, 49.89159556797573, 37.90352112906319, 14.50759025982448, 11.167638097490583, 21.684466225760325, 28.114772149494716, 24.673560414995464, 18.413850137165614, 27.820001772471837, 28.737091030393326, 30.648952143532888, 25.96118494442531, 28.02831745147705, 37.05471181869507, 43.02527802331107, 62.81400121961321, 19.074745416641235, 0.1984150388411113, 0.13998413564903395, 0.16742885511900696, 0.07059587578156165, 0.02631703158840537, 0.06857656913676433, 0.14503124196614536, 0.02571365450109754, 0.04434666716094528, 0.030289558959858756, 0.006836232255279485, 0.08268650807440281, 0.022337267640978098, 0.06399550102651119, 0.15490760414728097, 0.10485354145722729, 0.015724311150344353, 0.05713789364589112, 0.05535486985796264, 0.09155593785856452, 0.07827528406466756, 0.1421691541160856, 21.367835078920635, 63.66894926343645, 44.65853895459856, 30.084362370627268, 39.635109492710654, 42.050501346588135, 30.77214023045131, 29.75454875401088, 23.841755083629064, 25.072777850287302, 22.030670642852783, 24.67377233505249, 24.220091445105417, 33.94532346725464, 46.472143854413716, 54.968807561056956, 46.844605513981406, 13.196268030575343, 3.9719494496073042, 5.991023438317435, 15.896246807915823, 19.487779344831193, 27.279112304959977, 37.73510374341692, 58.132638522556846, 57.58929286684309, 60.93390900748116, 56.71490028926304, 56.95999452045986, 48.56868634905134, 46.42469808033535, 44.397898129054475, 46.9140944480896, 47.54484496797834, 48.47268656321934, 49.252072947365896, 50.722058159964426, 50.3321704183306, 50.954263482775005, 53.31733192716326, 51.87435783658709, 47.718890394483296, 42.67459896632603, 40.82996688570295, 42.08483934402466, 46.1610278402056, 51.381376198359895, 53.407658508845735, 52.95791898454939, 51.18718099594116, 51.646939822605674, 49.801560810634065, 48.16464860098702, 46.62684202194214, 48.81190456662859, 44.63209758486067, 45.59171329225813, 44.408942290714805, 39.25489016941616, 33.204972062792095, 16.76471083504813, 19.293634516852244, 12.599497675895691, 15.195442812783376, 34.275849274226594, 29.49846247264317, 5.907720616885594, 0.12414231071514742, 0.03628873133233615, 0.019468642106013637, 0.07644015896533217, 0.05680381014410939, 0.382362354014601, 0.08216492499091796, 0.09225177552018847, 0.059680113302809853, 0.061950335412153175, 0.021688277733379176, 0.09891384267913443, 0.09905088639685086, 0.03855590003409556, 0.08413885121366807, 0.5376541039773396, 0.38170878908463884, 1.375733984368188, 0.2949071968240397, 0.283987179930721, 1.3586014636925288, 6.022243431636265, 11.786610552242824, 12.588508231299263, 11.124347346169607, 19.469048738479614, 28.49434702736991, 30.29390961783273, 32.67428255081177, 34.207961899893625, 34.36332014628819, 36.6232773235866, 40.236191204616, 44.042226791381836, 45.640527861458914, 46.144887174878804, 42.19400596618652, 38.73871891839163, 38.29795299257551, 43.45987742287772, 47.633059297289165, 50.10682644162859, 49.081991468157085, 46.348900181906565, 39.33266135624477, 45.41548613139561, 50.81719984327044, 52.254080363682334, 53.74037994657244, 54.547034536089214, 52.94677407400948, 47.99010637828282, 43.89478254318237, 43.72081702096121, 43.874545914786204, 46.019757066454204, 46.11219590050833, 47.04758323941912, 49.92308132989066, 53.306669916425435, 54.80942978177752, 57.07991000584194, 56.667412825993125, 61.1032782963344, 59.5953038079398, 61.59341812133789, 44.15287685394287, 24.739213943481445, 4.887101897171565, 15.658548934119088, 53.93118095397949, 42.63324328831264, 19.84637587411063, 11.209795423916407, 22.28057997567313, 27.01687686783927, 25.90383277620588, 19.845173835754395, 29.523767811911448, 25.16117283276149, 34.34385824203491, 27.508456707000732, 36.84588371004377, 43.236930574689595, 52.08734791619437, 71.46262550354004, 40.791800430842805, 0.3860490790435246, 0.05955323403967278, 0.05016725929453969, 0.09530523738690785, 0.042921085442815504, 0.061912771713520796, 0.0050061728439426845, 0.033831393013575246, 0.058282697573304176, 0.12274965830147266, 0.136212946580989, 0.13195865415036678, 0.10074724429952246, 0.26997858019811766, 0.20860731335622923, 0.214456081656473, 0.0971198028751782, 0.15742966452879564, 0.16046397813728877, 0.13949491190058844, 0.22750895124460968, 0.19056151168687002, 25.18466121809823, 74.91889572143555, 48.70208133969988, 39.746468271527974, 49.84436518805367, 46.04561826160976, 35.67322581154959, 41.34276826041085, 24.82791985784258, 37.460528305598665, 26.64372386251177, 30.581749166761124, 28.226547820227488, 40.36915193285261, 52.34041520527431, 54.843677452632356, 43.52474927902222, 13.060611401285444, 4.518805682659149, 8.490996582167488, 18.089067016329082, 23.192584889275686, 28.636576652526855, 41.96911014829363, 61.587984630039756, 60.28608676365444, 61.75115612574986, 59.606379236493794, 58.59072630746024, 50.39818525314331, 47.52357305799212, 45.768360819135395, 48.52329724175589, 49.96078225544521, 50.495053563799175, 50.81016826629639, 52.06595441273281, 51.95516538619995, 51.45825801576887, 52.79330573763166, 53.095253603799, 49.86987202508109, 45.38032129832676, 43.32699312482561, 43.296295983450754, 50.13704068320138, 56.35245098386492, 55.33863237925938, 56.903179100581575, 53.755759784153526, 55.31132248469761, 49.8430415562221, 50.704176970890586, 47.40132992608206, 52.98212650844029, 47.417119707380024, 50.25959995814732, 50.37777144568307, 46.672998905181885, 42.251179218292236, 25.016777106693812, 27.928721972874232, 25.72202273777553, 25.157057762145996, 43.002105781010215, 42.2433624948774, 13.941808002335684, 0.4487444119794028, 0.1864333182041134, 0.15229508147708007, 0.18529644635106834, 0.7008528496537889, 3.1247234599930898, 0.32979393910084454, 0.1473740062543324, 0.14805225628827298, 0.18020762370101043, 0.058270443230867386, 0.17473069259098598, 0.18125315116984503, 0.28808363154530525, 0.11909814924001694, 0.8203754904014724, 0.6315999914492879, 1.7212191543408801, 0.39343463416610447, 0.3283303662070206, 1.9946610586983817, 6.445293188095093, 20.16124565260751, 21.320623806544713, 20.81949887956892, 30.13640785217285, 36.16731916155134, 36.77139554704939, 37.631808349064414, 39.68163463047573, 38.55737093516758, 41.41265671593802, 44.899134227207725, 48.360337666102815, 49.46639360700335, 51.06828342165266, 47.313556807381765, 42.86520195007324, 40.61605616978237, 45.539025102342876, 50.55526317868914, 52.35645859582083, 51.718509742191856, 49.88176734106881, 42.039679527282715, 47.057449681418284, 54.55507012775966, 53.46114226749965, 56.29725449425833, 59.013670103890554, 56.487127917153494, 52.05355882644653, 48.28977523531233, 46.73743649891445, 44.99873317990984, 49.205790996551514, 51.26074504852295, 47.91829327174595, 52.403994696480886, 55.7051568031311, 56.3465450150626, 57.57651512963431, 58.84910896846226, 63.0994610105242, 62.329155921936035, 63.543812206813264, 50.792321818215505, 32.49539075578962, 7.393529483250209, 16.959081479481288, 60.55957480839321, 49.72806624003819, 28.180387462888444, 16.997082914624894, 29.627754552023752, 38.881007603236604, 31.144911084856304, 28.266930750438146, 39.74530444826399, 37.92432056154524, 43.320777961185996, 34.350497245788574, 33.272477286202566, 46.80081796646118, 53.953519412449424, 81.60140214647565, 42.4352057320731, 0.6450493154781205, 0.3068006671965122, 0.31501512069787296, 0.19441134296357632, 0.19938010562743458, 0.15723360862050736, 0.2445072169814791, 0.1427859017359359, 0.09762779490223952], [0.06237315093832357, 0.06994289439171553, 0.04937801789492369, 0.04094315247078027, 0.098145652828472, 0.0033884270399409744, 0.08778023653264556, 0.02068170495996518, 0.04120241052338055, 0.014684571585218822, 0.08877948791320835, 0.0370249350422195, 0.1900367462741477, 28.24218647820609, 58.916360582624165, 37.87189292907715, 51.84737798145839, 29.005602427891322, 14.337165713310242, 26.80195345197405, 30.032553127833776, 22.841924939836773, 31.67529140199934, 22.96419586454119, 14.673435074942452, 29.900964668818883, 23.19902413231986, 45.741971560886924, 30.95267527444022, 33.58240168435233, 16.24315299306597, 3.3082935639790128, 2.885390805346625, 10.770135998725891, 14.37435073511941, 21.291776623044694, 28.70579981803894, 55.98462724685669, 56.042512689317974, 57.13296297618321, 55.625811849321636, 51.677546637398855, 46.68324054990496, 44.354249545506065, 43.62712403706142, 45.21296003886631, 44.94873741694859, 48.736478396824424, 47.2846314566476, 48.464765616825645, 50.00443778719221, 52.20520673479353, 50.8176896912711, 50.031848430633545, 47.53704214096069, 43.94243328911917, 40.49666179929461, 40.21656601769583, 40.27426733289446, 48.22006743294852, 52.03569153376988, 49.761702469417024, 47.13705519267491, 49.42719187055315, 48.56492389951433, 45.07249525615147, 44.26363808768136, 42.21445451463972, 39.29195186070034, 37.56098536082676, 37.73794208254133, 32.14110210963658, 28.18586438042777, 2.306866637298039, 9.899703025817871, 7.540743572371347, 11.895297748701912, 25.053437539509364, 13.311153020177569, 0.9668090471199581, 0.22296268519546303, 0.03388969274237752, 0.06538306442754609, 0.22110157220491342, 0.04629688537014382, 0.20038718730211258, 0.6352702687893594, 0.018933715631387064, 0.05816585384309292, 0.034876045172235796, 0.02695187064819038, 0.018841668963432312, 0.0637135086581111, 0.06293330873761858, 0.12086426732795578, 0.01865320755834026, 0.15041570232382842, 0.33042722940444946, 0.3190640205783503, 0.023279934289998243, 0.15515145606228284, 1.3167481209550584, 5.252328310694013, 6.433969361441476, 5.771502486297062, 8.766627277646746, 16.430802992412023, 22.274814707892283, 27.210142748696462, 28.129085438592092, 28.241858175822667, 30.94761003766741, 35.293819427490234, 36.97663491112845, 40.2952196257455, 40.04211412157331, 35.96931982040405, 33.2207271030971, 37.9577031816755, 42.79865905216762, 44.31181689671108, 47.044136932918, 46.5632312638419, 43.076625210898264, 36.18773296901158, 43.49757487433297, 52.56296600614275, 50.945223876408164, 51.04159539086478, 49.48468126569475, 46.94341237204415, 40.97161633627755, 39.33227225712368, 42.725814138139995, 40.89816345487322, 41.21720388957432, 43.39097908564976, 46.2923765863691, 53.44717986243111, 55.87303917748587, 55.52662631443569, 55.838510104588096, 58.19311216899327, 55.78915357589722, 57.73312752587454, 55.43642132622855, 34.9459022794451, 13.766090665544782, 1.946156335728509, 27.731724909373693, 52.49242441994803, 37.00724172592163, 11.820179905210223, 10.868440849440438, 20.30666102681841, 29.742180960518972, 23.443015336990356, 23.94109000478472, 26.103061948503765, 27.36071194921221, 30.678617477416992, 26.840689659118652, 23.628601721354894, 29.114133289882115, 32.33931337084089, 59.771975653512136, 59.393799100603374, 5.154313113008227, 0.10321359695600611, 0.06301376942012991, 0.05748151735003505, 0.08374570123851299, 0.07198681828698941, 0.12702337040432862, 0.04259136492120368, 0.059614471825105805, 0.018417901791898266, 0.07375242747366428, 0.012364930074129785, 0.054775268637708256, 0.06741178913840226, 0.027171274946470345, 0.04087828452299748, 0.07156625549708094, 0.07721932072724615, 0.03384497728464859, 0.07964006225977625, 0.0497637718383755, 0.14824858361056872, 38.55776003428868, 66.27460016523088, 43.82211480821882, 54.82738740103585, 32.27306924547468, 22.73971520151411, 29.594361509595597, 28.382053715842112, 24.606102091925486, 29.85763222830636, 22.247219937188284, 19.784952061516897, 38.86977931431362, 26.28554596219744, 48.71749244417463, 31.089256014142716, 36.265122004917686, 22.752216747828893, 5.193592148167746, 3.316054484673909, 9.273036309650966, 14.684784957340785, 20.90288942200797, 30.845148427145823, 57.800212383270264, 58.017635413578574, 62.215080397469656, 57.94758020128523, 55.393088885716026, 49.54876797539847, 48.058243887765066, 45.42354951586042, 48.44695738383702, 48.04957601002285, 50.59950583321707, 50.59465251650129, 50.03792463030134, 52.91360337393624, 55.17964022500174, 53.82911191667829, 52.96547862461635, 50.06590502602713, 47.77174881526402, 44.10460424423218, 42.92198262895857, 41.723348890032085, 47.35936280659267, 52.59608806882586, 52.81529678617205, 52.58418927873884, 51.471296310424805, 51.80293730327061, 50.500917843409944, 49.78348854609898, 44.88776002611433, 44.013020038604736, 44.635008880070274, 44.607785837990896, 40.23116070883614, 34.78433929170881, 13.893250516482762, 16.888039622988018, 10.42458644935063, 18.507115806852067, 28.174009016581945, 14.163685696465627, 1.9009869652135032, 0.27783978836877005, 0.02864128883395876, 0.03655717335641384, 0.05624450729893787, 0.0664828611271722, 0.24427187389561109, 0.21990281795816763, 0.027885019147236432, 0.11934968217142991, 0.05707861004131181, 0.06498383477862392, 0.040497819760016034, 0.07331613624202353, 0.018140311419431652, 0.09497686714998313, 0.08548318514866488, 0.10281660647264548, 0.4067764239651816, 0.34652387137923923, 0.03429003858140536, 0.10284745267459325, 3.640578133719308, 7.3258861643927435, 11.345042978014265, 8.703426463263375, 16.67922714778355, 26.719325474330358, 29.84525748661586, 34.06851850237165, 35.01165655681065, 35.384819984436035, 35.559428215026855, 39.57958991186959, 42.39660848890032, 44.75762026650565, 43.765493937901084, 39.340502398354666, 37.646757398332866, 41.04138319832938, 47.7138112613133, 47.809022426605225, 51.246188572474885, 48.724127973829, 47.9378593989781, 39.096460819244385, 45.64782346997942, 52.327467237200054, 53.79173060825893, 51.957836968558176, 53.767047132764546, 47.931626864842, 44.413899830409456, 41.90853227887835, 43.606004987444194, 44.19116837637765, 43.021015303475515, 47.0838736806597, 52.07100575310843, 56.459970882960725, 58.014001505715505, 58.67288180759975, 60.08401925223214, 61.53556047167097, 57.57472249439785, 62.030848911830354, 52.83449465887887, 33.12860788617815, 10.803562913622175, 2.6428098678588867, 35.17860439845494, 58.029134682246614, 38.870908396584646, 13.66289688859667, 12.919821790286473, 22.670802967888967, 26.067276988710674, 27.033721038273402, 21.435619967324392, 27.23124442781721, 25.18379964147295, 34.318160329546245, 27.27462203162057, 31.79032925197056, 33.11368315560477, 45.92707504544939, 72.39179420471191, 68.85127013070243, 22.691928965704783, 0.12688032165169716, 0.14985779726079532, 0.09056687807398182, 0.09167953979756151, 0.05372572763423834, 0.060760422476700375, 0.03669729423043983, 0.06045383321387427, 0.08344626373478345, 0.194886127486825, 0.09927005999322448, 0.11990091044987951, 0.22341862001589366, 0.1625808716884681, 0.15447313817484037, 0.1426966336688825, 0.16377460477607592, 0.19778005219995975, 0.15145749785006046, 0.10059045521276337, 0.5688254599060331, 44.86254153932844, 76.05405071803501, 46.67828301021031, 67.06728540148053, 42.306153365543906, 21.413696663720266, 36.81851128169468, 43.06449018205915, 29.375507150377544, 43.06339236668178, 32.27702277047293, 18.41662767955235, 40.57328653335571, 33.93075656890869, 58.228878021240234, 39.59964936120169, 42.50776924405779, 21.909483637128556, 5.645096949168614, 4.481346641268049, 11.832508615085057, 18.059151547295706, 23.70450905391148, 38.433109351566856, 63.106694085257395, 62.12476771218436, 64.74392591203961, 61.19946220942906, 58.017798696245464, 50.10194533211844, 50.85063804898943, 48.25691373007638, 49.77341365814209, 49.97069386073521, 53.18381881713867, 52.46077537536621, 50.32456908907209, 54.57455287660871, 57.497149331229075, 55.033832277570454, 53.88385329927717, 54.189045974186485, 48.35514736175537, 46.30305249350411, 45.92757878984724, 45.16103615079607, 53.241283893585205, 55.88837732587542, 55.352563517434255, 52.767573084150044, 53.26630435671125, 54.230405126299175, 50.45036275046212, 51.32331357683454, 48.5646459715707, 48.504780292510986, 48.95644794191633, 51.24684517724173, 49.35457624707903, 42.56899677004133, 18.262434993471416, 27.522320100239344, 22.247235570635112, 28.71122636113848, 35.31464317866734, 17.775503499167307, 3.0521117448806763, 0.36320834181138445, 0.19049068620162352, 0.1348177157342434, 0.25724828615784645, 0.159452173858881, 0.450758656752961, 2.0227821554456438, 0.19965545513800212, 0.1372023999158825, 0.10877131444535085, 0.12794532307556697, 0.08820868389947073, 0.18254723958671093, 0.1352623054491622, 0.16708799983773912, 0.19450593074517591, 0.37335268461278504, 0.6629519462585449, 0.4764651730656624, 0.22186807250337942, 0.13183452295405523, 4.135393227849688, 12.863857524735586, 19.45590795789446, 15.870680911200386, 31.025586196354457, 34.43435852868216, 38.26999691554478, 38.04881838389805, 41.098348004477366, 39.13360241481236, 39.478278228214805, 42.770077637263704, 46.238760811941965, 48.36673348290579, 48.71967070443289, 42.16258273805891, 38.982152530125205, 42.20565462112427, 50.8311379296439, 50.26271275111607, 53.28568983078003, 49.34604038511004, 49.9255826813834, 42.087913921901155, 47.859334332602366, 56.68879590715681, 56.025673730032786, 55.697499888283865, 57.173630782536094, 51.83735867909023, 47.98304353441511, 42.48744228907994, 47.68828010559082, 46.48013080869402, 45.62552670070103, 50.37335239137922, 52.95102289744786, 58.73518630436489, 60.58659635271345, 61.78564003535679, 63.09141499655587, 64.05439363207135, 62.50352096557617, 62.952666418892996, 59.65523896898542, 39.57783201762608, 16.40286602292742, 3.872253656387329, 33.42371525083269, 61.8750980922154, 45.35382434300014, 22.10384385926383, 16.317863498415264, 29.301651273454937, 41.31978014537266, 31.405548436301096, 32.809786319732666, 34.35949863706316, 38.38055317742484, 41.01929834910801, 37.25491721289498, 30.758761474064418, 40.50601407459804, 47.424366678510395, 72.62892232622418, 82.19734913962228, 20.974030290331157, 0.41419503731387003, 0.28407446667551994, 0.16034917001213345, 0.18366348397518906, 0.12804886751941272, 0.1843871415725776, 0.09577808808535337, 0.10212910122105054], [0.07735693441437823, 0.024925128955926214, 0.048775835029248676, 0.008789497510796147, 0.05738247837871313, 0.06281770672649145, 0.03878780973276921, 0.03863418261919703, 0.02855996641197375, 0.07236204815230199, 0.034092866483011415, 0.08170469504381929, 2.8173349371978214, 53.95536068507603, 48.37943478993007, 43.25260918481009, 32.67334801810128, 31.699248790740967, 22.400538887296403, 29.91289472579956, 30.442965848105295, 27.663008962358745, 22.67140051296779, 28.45810522351946, 13.8563859803336, 23.83759137562343, 22.585706642695836, 30.637796810695104, 53.804039342062815, 25.24756325994219, 21.660713808877126, 14.06059353692191, 2.4993803756577626, 4.298659827028002, 9.013192789895193, 13.882347055843898, 19.95983474595206, 52.0807922908238, 60.27374676295689, 59.21205507005964, 58.41182409014021, 54.31522873469761, 49.6445106778826, 47.02305262429373, 45.10777473449707, 44.25340339115688, 45.980680397578645, 45.589086873190745, 48.632488182612825, 49.28325298854283, 49.80412817001343, 50.50168561935425, 53.09103257315499, 51.985567229134695, 48.89201382228306, 47.58343873705183, 44.57301357814244, 39.46179015295846, 39.884195463997976, 40.66940791266305, 48.09554181780134, 49.50560923985073, 50.58041565758841, 48.76667526790074, 49.27430370875767, 45.04516799109322, 43.906907149723594, 41.71382290976388, 38.66483524867466, 36.944826057979036, 36.425899846213206, 30.365062645503453, 25.501391376767838, 4.698049230234964, 5.76757675409317, 5.439954425607409, 15.044435875756399, 18.479161466870988, 8.092599034309387, 0.8299554277743612, 0.10965582555426018, 0.046899631419884305, 0.06593265743660075, 0.0461766082527382, 0.18929955868848733, 0.16586172421063694, 0.1099266085241522, 0.46891562959977556, 0.07245208296392645, 0.06439441854932479, 0.013158812653273344, 0.14782551702644142, 0.0394643057536866, 0.03719921676175935, 0.02125158786241497, 0.04724036795752389, 0.10956843024385826, 0.13297041771667345, 0.7149778859955924, 0.5281803980469704, 0.3980861817087446, 0.5576259408678327, 4.048289307526179, 5.375872492790222, 5.654421865940094, 7.080579578876495, 15.046489068440028, 19.925798995154246, 25.707421098436626, 28.00147656032017, 31.411614213671, 31.226027829306467, 34.87030587877546, 35.73250436782837, 37.92680106844221, 37.30608722141811, 34.71168892724173, 34.33805997031075, 40.85857261930193, 45.29755088261196, 47.21954768044608, 47.213732038225444, 50.859472683497835, 45.14530890328543, 36.57483795710972, 42.695870876312256, 47.517281464168, 49.56492601122175, 47.944560936519075, 47.14645957946777, 42.95607049124581, 40.31951747621809, 41.14642606462751, 42.22090591703142, 43.28418179920742, 41.81898736953735, 47.87702097211565, 52.64187322344099, 55.869870798928396, 55.66131019592285, 56.56839404787336, 56.78714765821184, 57.84336764471871, 57.95417404174805, 56.020639760153635, 36.873565333230154, 22.412342139652797, 3.5307896477835516, 5.990662131990705, 44.8532726424081, 52.46613243647984, 34.4351749420166, 8.033767768314906, 11.252922892570496, 22.892558200018748, 31.1740448815482, 20.68140343257359, 23.801351308822632, 27.260623148509435, 26.370944534029277, 29.153533049992152, 29.12723238127572, 26.483877079827444, 33.66812508446829, 29.977846486227854, 45.70754323686872, 54.6601060458592, 60.070074217660085, 7.70710255418505, 0.24649057484098844, 0.13029599908207143, 0.08481292825724397, 0.02954554870458586, 0.039519972766616514, 0.009099293699754136, 0.03202929899894765, 0.10435328472937856, 0.021807289382975017, 0.028445109093029584, 0.042492610934589586, 0.046058814573500834, 0.11151201238057443, 0.020211760087737014, 0.08263512261744056, 0.10363025138420717, 0.08300525668476309, 0.08170256444386073, 0.205670545942017, 5.426409346716745, 65.57060173579625, 53.14258473260062, 47.958915914808, 38.00242873600551, 36.76847035544259, 30.098234449114116, 31.424218245915004, 30.4509528023856, 28.80939745903015, 24.66164251736232, 33.35789843967983, 20.60892677307129, 36.936404841286794, 26.09155920573643, 30.828007221221924, 52.59083523069109, 26.215007850102015, 25.618694339479717, 19.22266387939453, 3.929972776344844, 3.1672709711960385, 9.016255208424159, 12.683690735271998, 20.64475863320487, 53.11277001244681, 61.73338263375418, 59.27216393607003, 60.90864535740444, 55.15296956471035, 51.35583462033953, 48.180403641292024, 48.13812732696533, 45.80639178412301, 48.98709992000035, 48.39624943052019, 51.21893078940255, 50.966106687273296, 52.21115786688668, 53.08763142994472, 54.463711738586426, 54.72184426443917, 52.36567538125174, 51.11485372270857, 48.88482591084072, 41.61223677226475, 40.70111949103219, 42.543507303510395, 48.93324095862252, 53.06010614122663, 51.70935896464756, 52.3150577545166, 53.64414044788906, 47.88345847811018, 47.528725147247314, 46.18328639439174, 42.725848879132954, 42.67821202959333, 43.290577616010395, 35.981128283909385, 34.48562233788626, 14.88119489806039, 15.246578080313546, 11.64471617766789, 18.557985305786133, 19.04069229534694, 5.222218726362501, 0.22673311430428708, 0.09820661919989757, 0.02109972833256636, 0.01747201379787709, 0.050180253240146806, 0.19098243410033838, 0.07056939934513398, 0.17093582265079021, 0.21863154188862868, 0.059907782157616954, 0.033257291319647005, 0.09094734622963838, 0.0635726855003408, 0.05366394702079041, 0.07778896444610187, 0.04269563879019447, 0.036377083377114365, 0.09370590320655278, 0.11121757567993232, 0.4526170827448368, 0.8291482967989785, 0.3838763284896101, 1.1722018143960407, 6.0259003554071695, 8.753374457359314, 9.514940449169703, 14.371217097554888, 23.954229048320226, 25.914637225014822, 33.067057268960134, 33.598205362047466, 38.30805567332676, 36.5680947303772, 38.95718765258789, 39.96334934234619, 41.40680285862514, 39.40332106181553, 38.98310095923287, 38.58131095341274, 45.926143986838206, 48.740932192121235, 50.59335320336478, 48.68497487476894, 52.18362215587071, 45.99240548270089, 38.76011937005179, 47.55966200147356, 49.790669509342735, 50.78002003261021, 50.6320789882115, 48.652290548597065, 42.93242229734148, 42.171667507716585, 44.42751829964774, 46.327006408146445, 45.170600346156526, 46.24953399385725, 51.542160987854004, 55.73273072923933, 56.43880319595337, 58.45672334943499, 59.62485449654715, 60.147609165736604, 58.83256530761719, 61.289045333862305, 55.616397040230886, 35.806916100638254, 17.74949986594064, 2.1939786033970967, 9.389331783567156, 52.22284821101597, 55.07051876613072, 37.70697743552071, 10.890340702874319, 14.983889273234777, 14.9395615032741, 28.122191088540212, 24.43793136732919, 23.19048653330122, 28.986029352460587, 26.206164530345372, 31.632653781345912, 31.2080945287432, 29.755973134722026, 39.69637523378645, 30.05763612474714, 64.45488779885429, 57.73990896769932, 80.1843934740339, 20.84231502669198, 0.16801319590636662, 0.22704118277345384, 0.08931536094418593, 0.05821612650262458, 0.0786891361432416, 0.03391038806044629, 0.04748709686100483, 0.146213507811938, 0.12963165901601315, 0.11875261206712041, 0.08503435458987951, 0.12037557283682482, 0.17943674006632396, 0.16014476812311582, 0.2256459112146071, 0.19783787695424898, 0.19700015762022563, 0.1350031186427389, 0.31576587898390635, 6.5038434863090515, 76.58925655909947, 62.00514752524239, 54.62926646641323, 44.763724258967805, 43.26778057643345, 34.30539648873465, 41.19414976664952, 44.163865430014475, 39.08930764879499, 34.186325209481375, 39.45801380702427, 17.835198947361537, 32.166775703430176, 34.57315574373518, 41.36667006356375, 64.57557800837925, 32.202277524130686, 28.26844719478062, 17.21764131954738, 4.2339469109262735, 4.962732170309339, 13.51287659576961, 14.387019038200378, 27.143024887357438, 56.02110528945923, 65.2176262991769, 62.06258828299386, 64.24555247170585, 58.22467088699341, 54.744384220668245, 51.413414342062815, 51.41878877367292, 50.12529475348336, 50.858169896262034, 50.767058168138774, 54.292824268341064, 54.277295044490266, 55.80875791822161, 53.8643080166408, 55.93115043640137, 56.560396671295166, 53.700115135737825, 53.89459521429879, 51.12804140363421, 44.83262259619576, 45.44227491106306, 45.748120716639924, 52.88469539369856, 54.13186229978289, 56.009456634521484, 53.681490489414756, 54.064749649592805, 51.25564507075718, 49.80157470703125, 50.05833496366228, 46.8793534551348, 49.63344914572579, 50.07825892312186, 45.40398686272757, 42.30651814596993, 17.90006732940674, 26.151751450129918, 22.605889422552927, 28.110910688127788, 22.131700924464635, 5.597592115402222, 0.5060819238424301, 0.203250971489719, 0.12529273969786509, 0.237968310713768, 0.23478391872985022, 0.3467624714331967, 0.22181122483951704, 0.3046682487641062, 1.2335133701562881, 0.08949990211320774, 0.1951700672507286, 0.21257063640015467, 0.16075209767690726, 0.15618791830326828, 0.20241790690592357, 0.10734129510819912, 0.12685000470706395, 0.2001568925167833, 0.3540041228490216, 1.1833715864590235, 0.6497601941227913, 0.701466896704265, 1.975080600806645, 9.543732047080994, 15.549835681915283, 17.050076825278147, 25.545317888259888, 34.19072689328875, 35.27489253452846, 38.201383454459055, 37.811391489846365, 40.90446547099522, 40.07513543537685, 44.48789119720459, 45.26690237862723, 44.81532505580357, 42.99892350605556, 40.34230061939785, 40.602607931409565, 45.752254894801546, 51.38801867621285, 52.315978390829905, 52.73076152801514, 56.361407211848665, 52.00634234292166, 40.54645259039742, 50.86159535816738, 51.73317738941738, 54.82771396636963, 52.79428890773228, 53.806043897356304, 47.499337741306846, 44.868847029549734, 45.11488968985421, 47.456033093588694, 51.157849175589426, 49.43609946114676, 54.53274556568691, 59.64877714429583, 60.206307547433035, 61.51423645019531, 60.963890484401155, 63.35580090114048, 62.15220614842006, 63.05677822657994, 59.96169621603829, 41.10899264471871, 24.045960903167725, 4.164849247251238, 8.321159158434186, 55.78921610968453, 61.87723813738142, 45.36555985042027, 17.61611877168928, 15.936315332140241, 31.05286134992327, 44.1404812676566, 26.66106309209551, 32.49911846433367, 36.27039221354893, 35.601357119424, 38.68029499053955, 40.31139850616455, 37.26824038369315, 43.119398321424214, 39.3815210887364, 63.18775871821812, 66.69948250906808, 85.70468166896275, 18.0852107661111, 0.31528392913086073, 0.3520992307790688, 0.1500680074095726, 0.18539967866880552, 0.13115399304245198, 0.142031085810491, 0.20506430204425538], [0.10302246042660304, 0.050295841680573564, 0.08438239778791155, 0.056934027799538205, 0.048297199819769175, 0.03564475749486259, 0.06159886105784348, 0.0934997574825372, 0.06445011270365544, 0.023033414036035538, 0.018687556697321788, 0.062390039674937725, 20.48005505970546, 65.68894345419747, 49.974779401506694, 40.01038517270769, 32.9822336605617, 25.760996920721873, 21.829388277871267, 34.076630524226594, 27.503572123391287, 26.707452739988053, 22.734629120145524, 20.102005311420985, 17.396496636526926, 9.742019738469805, 17.103133269718715, 15.881778921399798, 45.183006354740684, 60.589465958731516, 30.189575467790874, 32.889603751046316, 7.513703789029803, 0.42009066524250166, 4.42168984242848, 5.952940361840384, 6.596555471420288, 49.32987192698887, 61.194195474897114, 56.58530248914446, 57.04875428336007, 51.100425788334434, 51.359294823237825, 46.9924909727914, 45.484314986637656, 44.01279769624983, 44.486619676862446, 46.54383536747524, 46.67386743000576, 45.273398944309776, 47.29255240304129, 47.3632572719029, 50.93926927021572, 51.4981233051845, 51.86416482925415, 49.00487341199602, 48.008814402988975, 42.511948585510254, 37.84787648064749, 39.294144017355784, 43.031434127262656, 48.55161115101406, 50.3215639931815, 48.194623129708425, 48.352406297411235, 46.76849494661604, 43.17922231129238, 38.31027562277657, 39.696809496198384, 34.87443310873849, 32.85466820853097, 28.86641785076686, 25.795619794300624, 6.737341174057551, 4.740243034703391, 4.893747414861407, 12.34970646245139, 11.27429641996111, 2.313705618892397, 0.18417020035641535, 0.03192506923473307, 0.03769425555531468, 0.05261245522914188, 0.03990728734061122, 0.04964058380573988, 0.023690790636464953, 0.03334582656888025, 0.24360832093017443, 0.15497122359062943, 0.07316527755132743, 0.0786131334358028, 0.05535668833181262, 0.040595793431358676, 0.07149693635957581, 0.14176463867936814, 0.1472167625491108, 0.06254258113248007, 0.02755428591210927, 0.10174726921000651, 0.4110008201428822, 0.019629063051460043, 0.10409335831978492, 3.5640919293676103, 5.486282842499869, 5.719321080616542, 6.091964261872428, 10.460097823824201, 18.12518722670419, 23.363336869648524, 29.793757438659668, 31.68602636882237, 31.483201503753662, 33.52209826878139, 34.03281518391201, 35.41902249200003, 34.85456473486764, 34.49633993421282, 38.72826187951224, 43.71534531457083, 44.36058977672032, 46.28456333705357, 47.519550051007954, 48.8820674760001, 42.65583535603115, 36.64070340565273, 42.386460644858225, 48.11877659388951, 48.462451866694856, 48.092776434762136, 42.59690420968192, 39.22430419921875, 41.03416749409267, 42.80959899084908, 44.82538604736328, 44.00741284234183, 45.69651991980416, 48.78466067995344, 54.32775633675711, 54.06160906382969, 57.728284631456646, 56.338460786002024, 60.01846994672503, 60.683808599199565, 61.76228713989258, 43.65958602087838, 25.33791068622044, 8.290408168520246, 0.5674992767827851, 23.06339008467538, 49.01709181921822, 44.59589399610247, 35.306638853890554, 6.650514313152858, 11.250191381999425, 24.724563666752406, 25.114614691053117, 22.000871556145803, 22.947593144008092, 24.438855477741786, 26.01689386367798, 28.616463354655675, 30.14088944026402, 25.268710102353776, 32.00331585747855, 21.781741006033762, 30.84204258237566, 62.46823801313128, 58.843119621276855, 56.14541551045009, 2.419508444411414, 0.1689142904111317, 0.07643032020756177, 0.032816708354013305, 0.05349552445113659, 0.0070654384159882155, 0.03780831729194947, 0.10668627132794686, 0.11041883139738015, 0.015502430199246322, 0.030596864077129533, 0.025503303556303893, 0.038640143549335856, 0.02003365651970463, 0.12036901818854467, 0.034752833390874524, 0.06931790257138865, 0.08397739380598068, 0.07205501105636358, 29.809067794254847, 72.15208830152238, 61.13595567430769, 45.456428391592844, 39.997986112322124, 32.900227546691895, 27.869662284851074, 31.574973310743058, 28.69426233427865, 25.040067468370708, 22.28170210974557, 22.22614083971296, 22.044674737112864, 20.122236728668213, 27.644417319978984, 18.311902693339757, 45.80936213902065, 63.84519726889474, 33.97627421787807, 40.84158427374703, 11.187430909701757, 0.33752668702176636, 2.202742887394769, 5.269310142312731, 6.448660024574824, 48.29042836597988, 64.1132309777396, 56.966803755079, 58.72423594338553, 53.223764010838096, 53.29045976911272, 48.79673317500523, 47.51031242098127, 45.846455097198486, 47.47693674904959, 48.77067395618984, 49.79644693647112, 47.78433895111084, 50.054461342947825, 48.88510036468506, 52.44754947934832, 53.01565504074097, 54.55694266727993, 51.16231686728341, 52.38965708868844, 46.295381682259695, 41.83336666652134, 41.122673647744314, 44.971989563533235, 50.3133408001491, 53.25991201400757, 50.46433210372925, 52.43973275593349, 50.858975887298584, 47.476683139801025, 43.39498472213745, 42.04900400979178, 41.439664363861084, 40.08990035738264, 35.99572992324829, 34.103283814021516, 15.363882780075073, 15.343957083565847, 9.120812569345746, 14.104143977165222, 10.625298193522863, 3.3751810491085052, 0.1561367567628622, 0.030561006894069057, 0.027413208303706985, 0.022811180246727805, 0.027542175758363943, 0.020128888909571936, 0.10193852787571293, 0.038649900882904015, 0.12812695332935878, 0.22908940858074597, 0.13809189147182874, 0.04358893692759531, 0.06546099417443786, 0.03855531649397952, 0.10016032507909195, 0.08262507351381437, 0.1417410256607192, 0.01885034572998328, 0.03968035130362425, 0.4361433924308845, 0.8337442044700895, 0.12881183943578176, 0.2625613510608673, 4.495004628385816, 8.46895602771214, 8.518002493040902, 9.970103910991124, 22.38138791493007, 26.39354702404567, 33.61850799833025, 35.35996627807617, 38.229627881731304, 36.05227436338152, 38.501625537872314, 37.761124747140066, 39.075015204293386, 38.28916699545724, 37.93646253858294, 40.72162709917341, 46.21119383403233, 46.41830921173096, 48.83125877380371, 50.09976707186018, 51.82536956242153, 44.55560139247349, 39.65804202216012, 46.24075494493757, 49.40973104749407, 50.52051871163504, 47.485934666224885, 43.92984315327236, 41.71406957081386, 43.70213678904942, 46.24907193865095, 46.114169188908164, 45.31287860870361, 48.817438806806294, 50.786096232278005, 56.44321877615792, 58.38943699428013, 60.24829551151821, 57.9946403503418, 62.556028502328054, 62.90727383749825, 60.263359206063406, 41.46496622903006, 23.4714960030147, 5.709481997149331, 1.3362875410488673, 30.15407017299107, 52.47716964994158, 51.10638734272548, 37.91462435041155, 9.267846873828343, 13.99572081225259, 18.23025267464774, 28.597968987056188, 23.544439928872244, 22.969545977456228, 26.15556080000741, 27.267647777284893, 26.500379051480973, 33.75675630569458, 27.14381524494716, 43.82247611454555, 20.261652333395823, 36.43584271839687, 82.92919594900948, 58.856022426060264, 76.72314139774868, 7.010388008185795, 0.23100059745567186, 0.0805321458194937, 0.10537684123430933, 0.008543297864629753, 0.04356200248003006, 0.05052707962957876, 0.14883653420422757, 0.1421669963747263, 0.15199533184724195, 0.09993414900132588, 0.153073768264481, 0.11608469379799706, 0.10143097689641373, 0.20883466329957756, 0.1614238473453692, 0.1523788534104824, 0.1341419762798718, 0.18958797678351402, 37.34620264598301, 87.14695399148124, 62.18665531703404, 52.8540712084089, 47.950453008924214, 35.05856384549822, 32.12123026166643, 44.86953490121024, 38.91342442376273, 36.42769595554897, 33.09547192709786, 27.37480984415327, 25.245492696762085, 13.985242060252599, 28.46624677521842, 26.74225800377982, 55.48580912181309, 70.8856748853411, 37.18517814363752, 42.9837521144322, 10.812980328287397, 1.0265033010925566, 6.050585567951202, 6.343928090163639, 11.17189039502825, 54.341274057115825, 63.71833011082241, 60.02493871961321, 60.42565522875105, 55.71637119565691, 57.90721811567034, 51.92400966371809, 51.00143480300903, 47.86577878679548, 49.04164675303868, 50.51402562005179, 52.511191504342214, 50.706792967660085, 52.29171528135027, 52.93472242355347, 56.429555143628804, 56.599455969674246, 58.156331879752024, 53.897819178445, 54.515427180698936, 46.585524559020996, 44.222091334206716, 44.17640692847115, 48.613745416913716, 53.899427686418804, 56.37212480817522, 53.433154923575266, 54.50715882437569, 52.956390380859375, 50.74560213088989, 45.54878384726388, 47.0900992665972, 46.84689147131783, 48.532382011413574, 42.802966935294016, 41.76851565497262, 19.20367271559579, 27.13760355540684, 20.056310483387538, 21.567137207303727, 13.212704862867083, 3.7546393275260925, 0.3234286292323044, 0.12331626218344484, 0.14626776347202913, 0.15517044147210463, 0.1582160187619073, 0.12293375842273235, 0.26283352502754753, 0.11341631412506104, 0.8816029621022088, 0.5517852199929101, 0.33424778868045124, 0.1318622071828161, 0.1321150293307645, 0.14536569187683718, 0.1825220930789198, 0.2142984036888395, 0.24829718789884023, 0.1228310689330101, 0.16509506106376648, 0.8856293889028686, 1.1617606260946818, 0.27750573200838907, 0.66884988120624, 7.2517119731221875, 14.88955705506461, 16.28494988168989, 22.16625952720642, 32.08404002870832, 33.80595302581787, 38.50499888828823, 42.64313752310616, 41.73396226337978, 38.71315649577549, 40.979321888514924, 41.966567107609336, 42.200516428266255, 40.30536052158901, 39.376834528786794, 44.16264602116176, 46.42107112067086, 48.76315253121512, 50.41568429129464, 54.24072667530605, 53.57803528649466, 48.295097555433, 41.03294461114066, 47.46529851640974, 53.13513626371111, 53.9718313898359, 52.80708054133824, 47.506911277770996, 43.79079580307007, 47.62701783861433, 48.148160525730674, 50.00009863717215, 47.111739431108745, 51.676202160971506, 53.612296853746685, 60.33606515611921, 61.57845170157296, 63.88576085226876, 62.33489513397217, 65.64259896959577, 65.78908784048897, 65.45863151550293, 47.61872863769531, 28.75876940999712, 9.956413354192462, 1.6191249298197883, 27.779707431793213, 59.36907741001674, 54.46776948656355, 47.259069034031455, 15.005925485066005, 16.596432413373673, 35.312308583940776, 32.27354172297886, 29.689986092703684, 30.09365906034197, 35.39909853254046, 33.54843194144112, 41.21648475102016, 39.76870598111834, 36.479915142059326, 43.74852296284267, 31.640988145555767, 40.29188796452114, 83.94915676116943, 69.78542763846261, 86.85315636226109, 6.010460589613233, 0.2959068146135126, 0.18666851201227733, 0.14213712726320538, 0.12114561508808817, 0.1233814422573362, 0.08547832005258117], [0.022823712788522243, 0.034119655045547655, 0.07350605140839304, 0.08848497657371418, 0.021325490503971065, 0.060353063978254795, 0.040423401431845765, 0.03657357694048967, 0.08899128583392926, 0.021905105294925824, 0.04500635926212583, 0.8496045534099851, 39.892057350703645, 58.90484741755894, 44.446761335645405, 38.48524863379342, 35.45824159894671, 23.44722941943577, 27.527656316757202, 34.85479055132185, 24.38053056171962, 26.246418918882096, 23.656245129449026, 27.80207368305751, 24.182725770132883, 14.511314494269234, 5.41530134848186, 15.721268585750035, 23.54117774963379, 55.57853978020804, 40.11319071905953, 42.231019020080566, 16.072090080806188, 1.0092765454735075, 0.3073714779956, 0.903200840311391, 1.1350387228386742, 32.72124195098877, 63.35178484235491, 53.25765037536621, 59.31110858917236, 52.60091706684658, 50.8633463042123, 46.12537315913609, 45.85081161771502, 42.96226481028965, 45.464352812085835, 44.20955678394863, 45.723364285060335, 43.84054143088204, 45.603466170174734, 47.19012900761196, 48.11395801816668, 49.08766119820731, 51.36463451385498, 48.66913993018014, 48.31508404867989, 47.063546725681846, 40.19392531258719, 38.756419454302105, 40.054002489362446, 46.92423186983381, 50.959158488682334, 48.97025053841727, 47.686928680964876, 44.78480509349278, 43.0380870274135, 37.6352789742606, 36.37174906049456, 35.759272302900044, 30.895033018929617, 28.76807131086077, 23.625294378825597, 9.1035749571664, 5.292105444840022, 2.9292940837996344, 6.863851802689688, 6.01923269033432, 1.0230286589690616, 0.032837993997548304, 0.034023554130856476, 0.047626406885683537, 0.039635795301624706, 0.055435588383781056, 0.23188006026404245, 0.045968067300106795, 0.011415066713068103, 0.1379015352576971, 0.133572983954634, 0.06849929756884064, 0.023948837504056946, 0.12203995138406754, 0.13347649627498218, 0.11632159751440797, 0.032753204261618, 0.14362937504691736, 0.10783037636429071, 0.08540176094642707, 0.26458821658577236, 0.09956056797610861, 0.38765465574605124, 0.06886380658085857, 4.094272920063563, 5.8011526209967474, 5.13541271005358, 4.9598482336316785, 8.891429952212743, 18.675654785973684, 24.02970211846488, 29.367367335728236, 32.56392083849226, 35.36306864874703, 34.440066473824636, 34.68952069963728, 35.448361260550364, 35.39694806507656, 36.76937709535871, 42.75053582872663, 46.82871150970459, 45.28630174909319, 49.06284918103899, 47.57558727264404, 49.10410411017281, 40.330429622105186, 36.35339886801583, 42.54487957273211, 46.75878136498587, 44.25551911762783, 42.36887475422451, 38.039584227970664, 41.07362283979143, 44.11968878337315, 44.95861428124564, 43.926897117069785, 45.187588691711426, 47.52737372262137, 46.36111511502947, 53.2012414251055, 54.378043924059185, 56.714869022369385, 56.77489798409598, 57.48630666732788, 61.697189467293875, 47.1994708606175, 27.37143996783665, 12.943714908191136, 1.4629701375961304, 2.360320431845529, 36.10381610052926, 48.40086650848389, 46.10566111973354, 25.163285085133143, 4.156758938516889, 20.06389617919922, 43.955641814640586, 25.081829616001674, 28.142646585191997, 22.66491436958313, 29.189764431544713, 25.52837644304548, 30.51467820576259, 27.046952145440237, 29.378456660679408, 21.293758596692765, 49.07927472250802, 33.933810302189414, 34.95702634538923, 58.38747065407889, 59.12299306052071, 34.35645532608032, 0.4152429939380714, 0.0967574855312705, 0.07336573715188674, 0.02635848498903215, 0.045478134482566795, 0.06149009867970433, 0.03368153176935656, 0.0725871996421899, 0.02682362074431564, 0.061970331839152744, 0.029911089089832137, 0.05938182252326182, 0.04337476074163403, 0.02605070998626096, 0.0381152967124113, 0.06508086528629065, 0.07765616835760218, 1.294475018978119, 51.411680766514365, 68.04391724722726, 51.69169316973005, 49.34014483860561, 41.39714138848441, 30.74135971069336, 29.96484293256487, 34.96228265762329, 27.643364667892456, 24.218922410692485, 16.827486072267803, 24.933730500085012, 28.92657882826669, 18.878087077822002, 11.375364048140389, 20.726492030279978, 26.405412810189382, 57.3983598436628, 44.500088759831016, 48.60866975784302, 20.681290524346487, 2.4316091665199826, 0.3873615286179951, 1.6557058926139558, 0.6973808673875672, 30.29507691519601, 66.30021122523716, 56.48768029894148, 61.610621861049104, 54.56770542689732, 52.87808765683855, 49.385124002184185, 47.12870693206787, 45.01277896336147, 46.61200761795044, 46.32182305199759, 46.62906197139195, 45.37826810564314, 47.20901768548148, 49.40820244380406, 50.06605788639614, 52.05213097163609, 53.326882226126536, 53.284974166325156, 54.17453466142927, 50.70727934156145, 45.40009587151663, 41.163268498011995, 42.39111941201346, 45.88555955886841, 51.98992027555193, 51.687760489327566, 52.13621459688459, 49.088957037244526, 47.70749882289341, 40.32269975117275, 41.50864607947213, 40.42167336600167, 40.30863312312535, 34.29335873467581, 32.276998451777864, 16.34067096029009, 21.99816870689392, 8.651637196540833, 8.066726548331124, 5.335114359855652, 0.6182529362184661, 0.03574797624189939, 0.015326026361435652, 0.034535149178866825, 0.03287278248795441, 0.014809747725459082, 0.1071152343813862, 0.06965803182018654, 0.08676486994538989, 0.10002170716013227, 0.20392277544098242, 0.34114132449030876, 0.03941479305337582, 0.049494152556040456, 0.0698406934472067, 0.052383069680737596, 0.10246978008321353, 0.061388901967023096, 0.09233232441225223, 0.03687490077157106, 0.3029029449181897, 0.5690367828522409, 0.06358010867344481, 0.18297835359615938, 4.180932589939662, 9.339908378464834, 8.310204454830714, 9.176429424967084, 21.03730579784938, 27.215776000704082, 33.544627802712576, 33.44580010005406, 40.09729324068342, 39.89572599955967, 39.751613412584575, 37.67926801953997, 39.30460453033447, 37.27761697769165, 41.32303885051182, 46.55294445582798, 49.35725130353655, 48.8727707862854, 49.931561606270925, 50.25081048692976, 50.83278465270996, 44.20973743711199, 40.1498007774353, 42.96735436575753, 47.81928839002337, 47.260354450770784, 43.64531094687325, 40.74124881199428, 45.39872360229492, 47.02524478094918, 49.567569800785606, 48.17945173808506, 47.457405362810405, 50.86862693514143, 52.248309884752544, 54.27314349583217, 56.84462663105556, 57.871250765664236, 58.31327084132603, 61.369901520865305, 61.4247853415353, 47.14217254093715, 24.68476959637233, 10.034653544425964, 1.19213858459677, 4.452502497604915, 42.284714698791504, 52.35976593835013, 48.74143941061837, 27.619316952569143, 5.600676681314196, 15.311684438160487, 37.00702633176531, 24.280896868024552, 22.682640961238317, 19.97628460611616, 26.927950348172867, 25.829566955566406, 29.352647577013286, 30.594075271061488, 30.26569993155343, 32.016562598092214, 60.02523054395403, 37.35529088973999, 49.236971037728445, 67.48707471575055, 65.60503005981445, 53.13196093695504, 0.4028674108641488, 0.10668700414576701, 0.017267442275104777, 0.0612988875114492, 0.030572192543851476, 0.029538858349301984, 0.12888442911207676, 0.10712734623146908, 0.10844238102436066, 0.20958501446459973, 0.2054293674549886, 0.13316127604671887, 0.13883091110203946, 0.19590089017791407, 0.16800594915236744, 0.1869519225188664, 0.19146240263112954, 2.0563968888350894, 64.97145162309918, 77.12688732147217, 56.80335085732596, 52.584467206682476, 48.1715064729963, 33.94903727940151, 38.672881262642996, 48.957934856414795, 34.06588166100638, 37.533751896449495, 36.930676051548545, 40.389975684029714, 33.74099779129028, 21.32811917577471, 7.327352234295436, 32.38271181924002, 34.48460095269339, 67.051089150565, 48.2340715272086, 52.35825817925589, 18.6409398487636, 2.5263146332332065, 0.7688012378556388, 1.9312830652509416, 1.7642037506614412, 37.09677621296474, 69.80115141187395, 57.709823267800466, 64.65261268615723, 57.15594414302281, 55.38997261864798, 52.31908770969936, 50.62903567722866, 47.33162212371826, 50.0478709765843, 50.50683076041085, 50.165253843579976, 48.67074843815395, 49.95404250281197, 50.509811537606375, 52.655366625104634, 54.84097112928118, 56.42948913574219, 54.42137289047241, 54.026746477399556, 52.8230162348066, 47.051533290318076, 44.80167531967163, 45.776882784707205, 53.380397251674104, 55.230709484645296, 55.150506428309846, 53.606064319610596, 51.68561002186367, 51.34034013748169, 43.62189204352242, 45.156835964747835, 47.512542792728965, 43.2833445412772, 42.824687004089355, 40.74109942572457, 22.4145690373012, 29.353721073695592, 18.091064623423986, 13.116243890353612, 7.536465219088963, 0.44877918011375834, 0.16650688887706824, 0.0840065029582807, 0.19697034279150621, 0.16663712688854762, 0.17424696497619152, 0.29646568319627215, 0.16502059863082, 0.17095617870134966, 0.39793999812432695, 0.8035618811845779, 0.45835990458726883, 0.0994674526154995, 0.2635057360998222, 0.2064527746822153, 0.2759956387536866, 0.19029824009963445, 0.2972151386950697, 0.16788123441593988, 0.17045676335692406, 0.30449978208967615, 0.6860368475317955, 0.60114636272192, 0.15077457949519157, 6.8615389210837225, 13.84410069669996, 14.34016386100224, 18.371775320598058, 33.81432213102068, 37.53130265644619, 38.10056161880493, 39.33910928453718, 44.70098549979073, 44.145754950387136, 42.39830732345581, 40.05066735403878, 41.533246176583425, 40.98127433231899, 43.13302026476179, 47.95967326845442, 52.88748509543282, 50.651954310280935, 52.2566477230617, 53.93868153435843, 54.485939025878906, 48.05874068396432, 41.13689661026001, 46.587751456669395, 52.084200382232666, 50.46864346095494, 46.87038680485317, 44.02698939187186, 47.35079567773001, 48.31350333350045, 51.442165987832205, 49.975818157196045, 50.372153827122276, 54.40272739955357, 52.828491415296284, 57.99859387534005, 58.48091697692871, 61.183578627450125, 62.31171594347273, 62.95503575461251, 62.918099130902974, 53.922617299216135, 30.36265856879098, 14.598199980599539, 1.4527559599706104, 3.872014812060765, 43.85661956242153, 58.66654505048479, 55.8106096131461, 36.45587090083531, 11.540615660803658, 26.0017728464944, 52.22780227661133, 32.05667107445853, 39.34705107552664, 30.210680621010916, 39.86608845846993, 32.650328636169434, 41.92359944752285, 36.357460090092246, 41.543039662497385, 28.563651834215435, 65.06738540104458, 43.22057798930577, 51.303316661289756, 73.32346425737653, 75.03961372375488, 56.3917430468968, 0.5932678654789925, 0.24585744738578796, 0.20623176225594111, 0.20136023366025516, 0.10175385778503758, 0.2236688094479697], [0.03947783574195845, 0.054833873707268915, 0.04188072501814791, 0.068202513137034, 0.025911221846139858, 0.05107450132657375, 0.04576173837163618, 0.03441328089684248, 0.010441017819435468, 0.12402267142065934, 0.07300081423350743, 7.32311817577907, 57.80029923575265, 65.76028755732945, 42.74053737095424, 35.33031484058925, 33.65744570323399, 21.532938173839025, 27.963301420211792, 30.722491877419607, 26.71600249835423, 26.994307381766184, 23.036107982907975, 49.97881977898734, 27.693669625691005, 33.49213416235787, 9.973201939037867, 7.353500042642866, 23.29816276686532, 47.17950521196638, 43.078237192971365, 41.38159132003784, 34.26964800698416, 4.472377385411944, 0.2931009366043976, 0.04114956282345312, 0.10372884930776698, 10.658063292503357, 64.32788167681012, 50.25479180472237, 58.434065273829866, 50.519080434526714, 51.76519816262381, 46.177620138440815, 48.35791621889387, 42.01454094478062, 45.606134278433665, 43.370238712855745, 42.581305503845215, 41.32429300035749, 44.30528906413487, 42.906158106667654, 46.084972858428955, 48.54338795798165, 49.45627008165632, 49.82330172402518, 51.901813643319265, 49.009608609335764, 45.475758280072895, 38.81091070175171, 41.02671555110386, 39.48407302583967, 44.1443201473781, 47.50828007289341, 46.26471928187779, 47.93244675227574, 41.8667562348502, 37.76099967956543, 35.44515814099993, 32.81916986192976, 30.10094772066389, 26.93418288230896, 21.234485251562937, 8.662921939577375, 12.052290558815002, 4.333383449486323, 3.736844990934644, 2.211077468735831, 0.16523479856550694, 0.030829727117504393, 0.051042542327195406, 0.02787527538436864, 0.08667888598782675, 0.08737651498189994, 0.06480662178780351, 0.007665258283460779, 0.06865666341036558, 0.00903290752986712, 0.08378854393959045, 0.23001020774245262, 0.14070682972669601, 0.03239709212045584, 0.06612152765904154, 0.04512625639992101, 0.10288372037134, 0.058169775775500705, 0.05820820799895695, 0.006117875712724137, 0.10471162585807697, 0.7874039539269039, 0.46484550514391487, 0.13206754545015947, 2.2178467512130737, 7.007205733231135, 6.287575159754072, 5.277963689395359, 6.780245431831904, 17.195594685418264, 23.653502328055247, 29.759301321847097, 33.97254303523472, 37.24213252748762, 36.55400378363473, 34.46013287135533, 37.39013957977295, 35.99671309334891, 40.172243458884104, 44.969470841544016, 45.375537463596885, 46.50754145213536, 46.69234963825771, 47.054382051740376, 48.37490109034947, 39.317194666181294, 39.550525597163606, 39.959055355616975, 43.2758925982884, 42.337736402239116, 40.2926071030753, 39.75408697128296, 47.3006192616054, 47.413464954921174, 46.32638454437256, 45.91453354699271, 46.22427381787981, 46.67971086502075, 48.603965827396934, 53.21027755737305, 55.14864431108747, 56.17159284864153, 53.996344634464805, 60.86919348580496, 51.89076600755964, 32.70232548032488, 15.424441541944232, 3.940828468118395, 0.27621580979653765, 14.02323567867279, 46.84864936556135, 52.4247385433742, 45.262962750026155, 14.969810485839844, 4.74114499773298, 21.7021233354296, 36.47764308112008, 27.86864263670785, 27.525179283959524, 22.039698089872086, 31.96197407586234, 29.755108083997452, 28.491281134741648, 26.575982400349208, 38.58946813855852, 21.43441619191851, 27.969231707709177, 44.3687504359654, 22.549277237483434, 48.13248191561018, 54.33801187787737, 61.30206625802176, 5.272611405168261, 0.2869167413030352, 0.0490314595268241, 0.0035539512048541966, 0.06686058121600322, 0.11449295920985085, 0.04556135340992894, 0.04563978188005941, 0.0524867871510131, 0.005689544969105295, 0.05923717921333654, 0.10027197123106037, 0.015895956761336753, 0.011377892323902674, 0.06469606129186493, 0.13612709833042963, 0.1744365476604019, 10.829953040395464, 68.98436287471226, 72.26130703517369, 56.86068044389997, 37.05338818686349, 45.85570314952305, 27.42319709914071, 30.94536576952253, 35.912949085235596, 29.292424065726145, 27.283397606440953, 20.377704620361328, 47.10815068653652, 32.22945540291922, 31.223866939544678, 11.044072202273778, 11.097806096076965, 24.28776863643101, 52.78041682924543, 46.0966979435512, 47.12885979243687, 39.03489283152989, 7.631574766976493, 0.4460173254566533, 1.3409547763211387, 0.10252898226359061, 10.069506577083043, 65.24257728031704, 52.36126674924578, 59.78107779366629, 55.01770550864083, 54.35092510495867, 47.99485199792044, 49.72343526567732, 45.67952462605068, 46.563578673771445, 46.98431989124843, 46.03164543424334, 43.822778361184255, 45.301004137311665, 45.18050847734724, 47.618516717638286, 49.00701345716204, 53.099280084882466, 54.7266663142613, 54.64283282416207, 51.65765394483294, 49.74845920290266, 43.26845107759748, 44.48506328037807, 41.63209819793701, 46.87316608428955, 49.21367372785296, 49.705078125, 49.86281265531267, 47.211004870278494, 41.89286756515503, 40.930795669555664, 38.47587203979492, 38.345221587589805, 33.673718384334016, 31.155725955963135, 15.886194501604352, 27.6285354750497, 14.128524337496076, 3.9898944752556935, 2.2679925518376485, 0.4188350497611931, 0.016697418576638614, 0.03650562505104712, 0.04216760623135737, 0.14573330857924052, 0.01956499238232417, 0.024281876061909964, 0.0202811216336808, 0.050722551997751, 0.05911604035645723, 0.19146082842988627, 0.20330220088362694, 0.16188052855432034, 0.10089046947125878, 0.04696950017075453, 0.036556783198778114, 0.03748059844864266, 0.04784900029855115, 0.03354962116905621, 0.0476639773696661, 0.04053128510713577, 0.48449256803308216, 0.4867037779518536, 0.4334132932126522, 2.783445315701621, 9.704165084021431, 9.507186259542193, 7.727669222014291, 16.64017653465271, 25.365515879222325, 33.14726727349417, 34.64836651938302, 40.56581721987043, 41.400862148829866, 41.13854333332607, 36.88442884172712, 39.60211597170149, 38.60371889386858, 45.39292185647147, 47.28039305550711, 49.25472021102905, 48.93166371754238, 49.57105084827968, 49.20836877822876, 51.52842787333897, 41.61146552222115, 40.942458220890586, 41.46673801967076, 43.561748436519075, 40.40040840421404, 40.54801940917969, 42.78219182150704, 50.0671591758728, 50.67572062356131, 50.32572596413748, 47.94618681498936, 48.98277814047677, 49.67538847242083, 51.07350499289376, 56.3334059715271, 57.788765226091655, 57.291378429957796, 55.11658879688808, 61.0761455808367, 51.522508008139475, 31.58185202734811, 13.87791497366769, 2.6012212080614905, 0.31399783385651453, 20.424335718154907, 51.158380712781636, 58.674875940595356, 48.78193003790719, 17.52172749383109, 4.847782909870148, 14.564663631575447, 35.74764449255807, 22.17802456447056, 18.687273911067418, 20.350938422339304, 29.516757079533168, 27.403858525412424, 26.95491804395403, 30.52093505859375, 39.41437217167446, 25.22139981814793, 43.886295318603516, 40.90866913114275, 31.216998645237513, 58.87195464542934, 60.14237022399902, 73.66792815072196, 10.678876621382576, 0.6261966271059853, 0.14874935602503164, 0.15991106709199293, 0.11151174775191716, 0.1029973274895123, 0.21740107291511127, 0.26223706560475485, 0.15932192227670125, 0.12445032490151269, 0.24001566799623625, 0.1883312620754753, 0.22755439952015877, 0.13939843779163702, 0.26098229150686947, 0.275755871619497, 0.36202402678983553, 15.344806500843593, 81.13952759334019, 78.97303063528878, 57.66624764033726, 49.585079261234824, 47.66311025619507, 31.917943341391428, 38.60163443429129, 42.29155172620501, 36.93071774074009, 37.86653239386422, 31.899683475494385, 66.28022820608956, 37.50636557170323, 43.6276764188494, 13.3706374168396, 15.92369566644941, 33.77739940370832, 58.51076643807547, 53.933935914720806, 51.06828342165266, 41.793244293757844, 7.235299025263105, 0.4664325714111328, 1.1377981347697121, 0.22668594254979066, 12.652717403003148, 69.0318329674857, 52.63260085242135, 63.24473394666399, 56.754074232918875, 57.32352427073887, 51.31613956178938, 53.697019713265554, 46.6032772064209, 50.315258502960205, 46.94800165721348, 47.40738875525338, 46.14033957890102, 48.909665720803396, 48.44606801441738, 51.60997540610177, 53.40195056370327, 56.17539698737008, 57.623384203229634, 56.632136821746826, 54.16709661483765, 53.48786503928048, 45.04817656108311, 49.3385398047311, 44.410050528390066, 51.44871119090489, 52.147293499537874, 52.03612232208252, 53.24489000865391, 51.78106437410627, 47.67244863510132, 47.93816859381539, 43.9847651890346, 45.733380113329204, 43.41963693073818, 39.479737349918906, 22.208264861788066, 32.766832556043354, 21.596936294010707, 7.990646379334586, 3.8323128053120206, 0.562624355512006, 0.10950086172670126, 0.12453151840184416, 0.09378312727702515, 0.19519814502980026, 0.21226220152207784, 0.11924536419766289, 0.16160303487309388, 0.2733955739864281, 0.1358628903648683, 0.6159213813287872, 0.5943883167845863, 0.2507855658020292, 0.23648487031459808, 0.10347112135163375, 0.10089434390621525, 0.12356075192136423, 0.16074652011905396, 0.18236957197742804, 0.15694802680185863, 0.1436335276812315, 1.2631904291255134, 0.5586509087256023, 0.6796018928289413, 4.885499034609113, 12.13150783947536, 17.15950574193682, 17.433268240519933, 28.408010448728287, 32.80328975405012, 42.451457568577354, 39.746298040662495, 46.578697953905376, 46.491703033447266, 44.672039304460796, 39.827873366219656, 41.79574564525059, 41.0990115574428, 45.124825613839285, 51.57230922154018, 51.923293999263215, 51.85179008756365, 51.40221732003348, 50.56804091589791, 53.50715323856899, 43.67299951825823, 43.76884991782052, 45.08097553253174, 47.032297202519004, 46.58196013314383, 44.52756888525826, 43.90576417105538, 51.13283218656267, 53.246557576315745, 50.67383418764387, 51.785601547786165, 53.00347832271031, 53.200011593954905, 54.541614941188264, 59.87885979243687, 60.84453432900565, 61.60826642172677, 58.41196305411202, 63.13370173318045, 59.14547743116106, 37.82136562892369, 18.286234310695104, 4.326707533427647, 0.8045955342905862, 17.92241621017456, 56.055307797023225, 63.539997645786826, 55.55432183401925, 25.517820392336162, 10.32459579195295, 29.47435917173113, 43.700351102011545, 35.37737846374512, 40.96848964691162, 29.865240505763463, 42.802751541137695, 40.0026969909668, 38.16707672391619, 35.5068998336792, 51.748831680842805, 29.342843668801443, 38.245546204703196, 57.75009502683367, 30.451279367719376, 64.81270612989152, 69.04288755144391, 85.05344091142926, 13.49515174116407, 0.8537580019661358, 0.30253102630376816, 0.2605061227721827, 0.15202716871031693, 0.17140060556786402], [0.06586659526718514, 0.019922293656106507, 0.04723220178857446, 0.029251095040568283, 0.010546423993738634, 0.06622760982385703, 0.12586496184979165, 0.14711699075996876, 0.04918443185410329, 0.08117617733244385, 0.06565517054072448, 20.52976073537554, 72.57014056614467, 49.31031969615391, 35.08179862158639, 45.986707959856304, 24.310567413057598, 28.628746032714844, 25.616354533604213, 34.88251733779907, 29.211672101702007, 21.870969772338867, 18.573518003736222, 40.5396329334804, 31.06724759510585, 29.465180601392472, 17.901755741664342, 6.778298199176788, 13.469965389796666, 42.06931012017386, 51.77183716637747, 36.79600259235927, 53.069840567452566, 20.782701219831193, 0.4607786919389452, 1.2513561270066669, 0.23768237605690956, 2.6284959273678914, 56.26274626595633, 51.88532209396362, 56.57202795573643, 52.994112151009695, 54.146370138440815, 45.72529935836792, 46.89028991971697, 41.73600503376552, 44.27039521081107, 45.854789461408345, 44.80333941323416, 42.325462409428184, 42.45157221385411, 39.72339677810669, 43.54681328364781, 47.91140413284302, 49.82053634098598, 49.31541619982038, 50.52476058687483, 49.84705414090838, 46.42246423448835, 43.447398458208355, 40.235666615622385, 38.506152289254324, 40.124995708465576, 44.764085565294536, 45.19127818516323, 43.693302154541016, 39.620052746364046, 36.33209916523525, 35.059807573046, 32.85593972887312, 30.073870590754918, 23.71154931613377, 19.024402243750437, 10.459003482546125, 21.84059919629778, 7.92680025100708, 2.772846055882318, 0.4887299378003393, 0.08920499043805258, 0.02195341868459114, 0.026661988613860946, 0.08793133271059819, 0.08151634729334287, 0.01655673112587205, 0.11495171673595905, 0.07902174722403288, 0.011039071799522, 0.03755592940641301, 0.11069517156907491, 0.3812294176646641, 0.12116530617432934, 0.17492235159235342, 0.17230172721402987, 0.050500056972461085, 0.07574646547436714, 0.12721905990370683, 0.015321395359933376, 0.10340870291526828, 0.025070968183821866, 0.42498092140470234, 0.48295071933950695, 0.1615966973560197, 1.0683211428778512, 6.617820867470332, 6.756274580955505, 4.7546084352902005, 5.749881863594055, 16.8079286302839, 23.965309688023158, 28.9423633984157, 34.262946469443186, 34.855405466897146, 36.77425820486886, 36.855256829942974, 38.22053268977574, 37.231880460466655, 44.35424607140677, 44.02855273655483, 47.47384827477591, 45.455973284585134, 43.95443630218506, 46.99635764530727, 46.94408982140677, 41.133436407361714, 38.75807312556675, 37.31001990182059, 41.26931190490723, 38.94269718442644, 41.3067626953125, 49.11995642525809, 48.5342059135437, 49.03049489430019, 48.539979866572786, 45.97574717657906, 45.0002235685076, 46.49124445234026, 50.148050103868755, 53.703238351004465, 54.28952734810965, 53.940606185368125, 58.24075249263218, 53.30904620034354, 42.023497172764365, 22.54051729610988, 7.0282904761178155, 0.5578902438282967, 0.8366609822426523, 33.36721249989101, 49.26827267238072, 49.31283494404384, 46.93809700012207, 18.032256807599747, 2.6007013959544043, 13.600839921406337, 40.48047597067696, 22.85750801222665, 20.205441406794957, 20.485177619116648, 28.16069105693272, 30.237205369131907, 32.430195808410645, 25.597031593322754, 33.94971472876412, 44.5354585647583, 15.221762589045934, 41.50128446306501, 35.8788195337568, 35.5570137160165, 52.833351680210654, 67.52940314156669, 20.36193742070879, 0.4141855649650097, 0.1723176592162677, 0.06505565092499767, 0.03738748308803354, 0.03138621404234852, 0.06791407468595675, 0.07576143395687852, 0.09082341859383242, 0.017762372503057122, 0.07747870430882488, 0.09587779202099357, 0.11817832716873714, 0.05498872896922486, 0.038684472242104154, 0.06400381308048964, 0.050251753867736886, 29.329628195081437, 81.6175150190081, 59.779479707990376, 44.754017625536235, 46.79220567430769, 36.695750508989605, 31.850139345441544, 31.08266912187849, 34.222785881587434, 27.888399839401245, 23.663926362991333, 23.249700818743023, 41.9028034891401, 31.03512954711914, 30.45552819115775, 15.21427764211382, 8.076861364500862, 16.597862005233765, 44.10015739713396, 57.406339849744526, 42.552244663238525, 57.99686029979161, 29.689294746943883, 0.9326793870755604, 2.7227686515876224, 0.6667413200650896, 2.027677812746593, 59.134408950805664, 52.95743261064802, 59.492602484566824, 55.36153016771589, 55.97965233666556, 48.386483737400596, 49.62261343002319, 43.5448226247515, 47.35045174189976, 47.74373715264456, 46.575936044965474, 43.94966983795166, 44.15910938807896, 41.579354422433035, 44.010643754686626, 49.14390686580113, 50.48648643493652, 51.23942450114659, 53.71262884140015, 52.39609806878226, 51.42574739456177, 47.74080848693848, 43.14437709535871, 43.028227533612935, 43.682188510894775, 45.55220583506993, 48.8823801449367, 46.65920673097883, 45.453127997262136, 41.52851445334298, 42.55689648219517, 36.98040778296334, 36.64818661553519, 31.87268624986921, 28.454874311174663, 17.741217613220215, 32.09643908909389, 16.83300815309797, 1.161652060491698, 1.1117851649011885, 0.041369038367910047, 0.021142087577443038, 0.04978414485231042, 0.06393677382064716, 0.03853043122217059, 0.055482078210583756, 0.14337892777153424, 0.041810737523649416, 0.047290019757513485, 0.04160800143810255, 0.08288263183619295, 0.6491154772894723, 0.1299750655889511, 0.06717394904366561, 0.1551999577454158, 0.050855894306940694, 0.04747182643041015, 0.09988910106143781, 0.12504971559558595, 0.08003992973161594, 0.06995143714760031, 0.4211250240249293, 0.4458536356687546, 0.3497815994279725, 0.7808192872575351, 8.58200408731188, 10.089981181280953, 7.096859208175114, 16.441077641078405, 25.356832368033274, 31.590162072862896, 35.248593602861675, 40.927821840558735, 39.680602822984966, 40.99759217670986, 41.81550979614258, 42.24734033857073, 42.7221976007734, 48.35651963097708, 46.78421524592808, 49.185116631644114, 46.80748128890991, 48.39249392918178, 50.352309771946494, 49.072208404541016, 41.94677168982369, 40.93248060771397, 41.05720772062029, 41.6446327481951, 41.29056644439697, 45.889638151441304, 51.225753920418875, 52.95068938391549, 50.836672169821604, 50.27758189610073, 49.21995837347848, 47.4521872656686, 50.2660722051348, 51.63788284574236, 56.81473200661795, 57.91921418053763, 55.34644562857491, 58.91902869088309, 53.808927399771555, 42.855325085776194, 19.6766174861363, 6.110487290791102, 0.35951681275452885, 2.522755418504987, 41.994325160980225, 54.54047196252005, 53.79135887963431, 49.09037446975708, 23.14131760597229, 3.7223280327660695, 11.800100479807172, 42.546825068337576, 13.067045433180672, 17.34656514440264, 21.27035880088806, 27.007665293557302, 29.638089997427805, 30.250302723475865, 25.049772364752634, 40.49890259334019, 36.50716250283377, 25.53470277786255, 51.172673157283235, 33.770319189344136, 47.305642809186665, 57.94663177217756, 76.6881502696446, 33.25639568056379, 0.29813048243522644, 0.19104355653481825, 0.0148316016420722, 0.00544452979063083, 0.018341459733034884, 0.12541900149413518, 0.23987453271235737, 0.1446832620671817, 0.13746729998716287, 0.14939951470920018, 0.22111333800213678, 0.22651625451232704, 0.2671853500817503, 0.2791824463222708, 0.19960110448300838, 0.147790097498468, 37.775976521628245, 89.67781448364258, 64.54923043932233, 45.673781939915244, 64.7324127469744, 33.81186941691807, 40.671235288892476, 35.457237584250315, 44.93223544529506, 38.02083798817226, 31.413309574127197, 25.86179964882987, 50.61027206693377, 38.955332483564106, 38.617493697575156, 23.882157121385845, 13.280121496745519, 24.54781017984663, 52.42815358298165, 61.295263971601216, 46.37174238477434, 59.6147518157959, 25.64724622453962, 1.242051512002945, 4.0648238488606045, 0.27211037437830654, 4.022513227803366, 63.45371491568429, 54.9892178944179, 62.275508880615234, 57.97898605891636, 60.55321025848389, 51.3498661177499, 53.324676173073904, 45.05503790719168, 49.25916705812727, 49.66798864092146, 50.19282776968819, 47.40584625516619, 46.89556360244751, 42.92943457194737, 47.162040914808, 52.92016247340611, 55.05373191833496, 54.846800667899, 56.689383029937744, 54.52366427012852, 52.98759126663208, 50.75638573510306, 45.805773394448416, 44.840953486306326, 47.91230392456055, 51.120262895311626, 50.95127575738089, 52.012227467128206, 47.3832402910505, 46.229780265263145, 46.20493698120117, 44.36280625207083, 45.33486270904541, 40.74055051803589, 39.18787131990705, 26.628646271569387, 38.79128551483154, 23.12161946296692, 3.9682286892618452, 1.6992620868342263, 0.11920754265572343, 0.09938189613499812, 0.1984790518347706, 0.14678373507090978, 0.1256561494831528, 0.16544699003653868, 0.3199402807014329, 0.11109496440206255, 0.11025844607502222, 0.2234967193965401, 0.3805722972112042, 0.6610906975609916, 0.15874036348291806, 0.215109931571143, 0.27461327293089455, 0.12953434352363857, 0.17482381473694528, 0.18522201105952263, 0.2609244260404791, 0.13609671353229455, 0.15806322624640806, 0.6317177851285253, 0.6958317447985921, 0.7723672379340444, 1.6357673853635788, 12.870117851666041, 15.709279469081334, 12.228846022060939, 24.973545415060862, 33.84006173270089, 41.41839592797415, 41.06275585719517, 45.93875844138009, 42.62683357511248, 45.18227679388863, 44.50113793781826, 46.39047820227486, 44.72718368257795, 49.88582508904593, 47.8218731198992, 50.52920395987374, 49.133477619716096, 49.4148588180542, 52.95781128747122, 51.77387298856463, 44.51084804534912, 43.84107296807425, 42.7293438230242, 45.32228299549648, 43.50925479616438, 46.75128425870623, 52.98964098521641, 54.32435171944754, 52.356059074401855, 53.60397638593401, 52.87802512305123, 51.42791175842285, 52.618940693991526, 55.16132477351597, 60.09339237213135, 59.31065695626395, 58.82460267203194, 61.70166410718645, 60.193599292210166, 45.39254665374756, 25.585851941789898, 8.009573272296361, 1.2556706326348441, 1.9311818821089608, 42.05017130715506, 59.34452942439488, 60.48114354269845, 55.49152054105486, 28.81191965511867, 8.248285583087377, 20.571776492255076, 47.65412276131766, 33.65876586096627, 27.34263273647853, 28.59878018924168, 37.546658175332205, 41.214626107897075, 41.82157209941319, 33.543022768838064, 46.04733099256243, 58.18049424035208, 18.835621425083705, 59.38767773764474, 46.17321498053414, 50.601336683545796, 67.90128462655204, 87.12473365238735, 39.12317664282662, 0.4413842340665204, 0.4443638441818101, 0.18459663247423513, 0.09158057546509163, 0.16274747917694704], [0.040895861972655566, 0.016535657524530376, 0.03789479997275131, 0.011666900744395596, 0.06556086095848254, 0.046643545518496206, 0.01786829690848078, 0.07118029799312353, 0.028485666827431748, 0.06414733680763415, 0.5666739067861012, 45.21157734734671, 69.18320642198834, 42.031369481767925, 32.73647935049874, 36.67494065420968, 34.83405712672642, 29.441171101161412, 26.215054750442505, 39.483392102377756, 26.280584948403494, 28.691806146076747, 12.8240339245115, 38.17105804170881, 51.4699170930045, 24.872365747179302, 14.70919224194118, 8.124200310025897, 13.429449575287954, 34.5001232283456, 52.864986828395296, 37.48668827329363, 50.92531033924648, 29.673161029815674, 5.597965581076486, 1.9227958406720842, 1.131947751556124, 0.29658849803464754, 42.40039873123169, 54.75434793744768, 51.871936389378135, 53.40614032745361, 52.51359905515398, 47.201735973358154, 45.20598404748099, 43.597635882241384, 45.71361596243722, 44.3872743334089, 42.07776607785906, 45.03035790579659, 43.727824279240195, 41.65995352608817, 42.05669566563198, 40.838895320892334, 49.98858199800764, 50.23682376316616, 51.90622227532523, 51.92886298043387, 49.33472524370466, 47.704747336251394, 44.24815402712141, 39.86001573290144, 39.05408028193882, 39.23034913199288, 42.75919328417097, 40.11372225625174, 39.946475642068044, 34.41920450755528, 33.70681960242135, 31.159700325557164, 28.843556540352957, 21.88366413116455, 16.969719171524048, 9.783052325248718, 26.864327430725098, 11.343181729316711, 0.5937971770763397, 0.21438069641590118, 0.04983727414427059, 0.00732645217794925, 0.11607552000454494, 0.03274523826049907, 0.04300287266128829, 0.09572679762329374, 0.11145829954849822, 0.034881578625312874, 0.0573091965966991, 0.07063246238976717, 0.03465008283300059, 0.19449868399117673, 0.20046585665217467, 0.02601486467756331, 0.053506706708243916, 0.04605356610513159, 0.05940019046621663, 0.05490175435053451, 0.21044528830264295, 0.08210174659533159, 0.1926151793450117, 0.55547981602805, 0.19307202340236732, 0.061512449623218605, 0.19033758156001568, 6.279355875083378, 6.941304240907941, 5.222369849681854, 7.701210481779916, 15.119570221219744, 21.390107529503958, 28.478560720171245, 34.631121090480256, 36.15248128346035, 36.034271580832346, 38.852891717638286, 41.120224407741, 43.62615476335798, 45.0989852632795, 45.52522250584194, 45.75439493996756, 44.43234034946987, 46.76518760408674, 46.71935381208147, 44.42167486463274, 39.54974739892142, 38.40820005961827, 39.202003955841064, 38.18772677012852, 40.98916401181902, 48.40899590083531, 49.642492226191926, 51.828204427446636, 51.069711276463096, 47.80909538269043, 46.295211451394216, 45.219581672123496, 46.13956138065883, 50.24254560470581, 54.3631990977696, 55.67135729108538, 56.07828548976353, 50.48902947562081, 47.13201080049787, 36.09753145490374, 8.71169308253697, 2.1410439695630754, 0.1883374231734446, 8.228241767202105, 52.81736387525286, 45.410094329289024, 52.126869269779746, 40.84447472436087, 23.080687625067576, 1.673186908875193, 10.850991317204066, 31.07204532623291, 20.06434781210763, 15.688957725252424, 17.139864921569824, 29.521429743085587, 25.2233453137534, 28.08074160984584, 35.38538973672049, 27.496087176459177, 49.6867869922093, 30.1459025655474, 24.1143468107496, 32.710552147456575, 38.6740311895098, 45.486646107264924, 62.62364837101528, 48.18462814603533, 1.0220338723489215, 0.11541421977537018, 0.03529532213828393, 0.04643832938745618, 0.09165219483630997, 0.06610018773270504, 0.047677100236926756, 0.11992153791444642, 0.017454829898529818, 0.08474833850881883, 0.03239155527470367, 0.053391691629907916, 0.06425342575779983, 0.13000148774257728, 0.06299362371542624, 0.7670773246458599, 58.92144666399275, 75.13918835776192, 51.86648205348423, 32.985867568424766, 45.64216763632638, 41.8759035382952, 29.736139501844132, 29.6831316947937, 36.00991119657244, 28.64316007069179, 28.256360803331646, 19.830924817493983, 45.20084932872227, 49.11177839551653, 26.925572327205114, 15.577062198093959, 8.620427625519888, 16.351980890546525, 40.67430986676897, 55.48325913293021, 43.368275846753804, 51.98195416586739, 33.16138253893171, 9.750768389020648, 2.1767716067177907, 2.831827142408916, 0.5187901247824941, 42.09912484032767, 59.59201036180769, 54.26369047164917, 56.54769883837019, 55.52305146626064, 50.65493508747646, 48.780307633536204, 46.652744906289236, 48.69887474605015, 46.67723730632237, 46.13763325554984, 48.119624274117605, 47.18819393430437, 44.056324686322895, 42.836853299822124, 41.466463565826416, 49.94324152810233, 51.78139788763863, 52.577289717538015, 53.54209920338222, 52.040638651166645, 50.481772082192556, 47.353474208286826, 42.975893701825825, 42.60321317400251, 41.88292121887207, 45.092207295554026, 44.43527248927525, 43.81301266806466, 41.300679547446116, 39.698748043605256, 37.015124457223074, 36.165109634399414, 31.72080557686942, 24.027746200561523, 18.37921163014003, 32.58819784436907, 17.823871646608623, 1.2791275339467185, 1.0053973879132951, 0.15840419009327888, 0.06356753541954926, 0.03160863442878638, 0.018631406228191087, 0.17497690580785275, 0.022684609717024223, 0.15080520856593335, 0.06841482674436909, 0.06132962514779397, 0.0704571425116488, 0.21860273129173688, 0.8863351196050644, 0.2890698414828096, 0.07593723559486014, 0.053779945974903445, 0.009978391795552202, 0.04630345019644924, 0.022594198318464414, 0.196824864883508, 0.04520190287647503, 0.09222072575773511, 0.16868364278759274, 0.49529864532606943, 0.11587174236774445, 0.2212291910712208, 7.824296951293945, 10.215758340699331, 9.020921792302813, 15.211508784975324, 25.952249561037334, 30.43862669808524, 36.67997462408883, 37.9203531401498, 41.19829436710903, 40.33314289365496, 41.54292154312134, 43.23937634059361, 47.1811797278268, 46.03808988843645, 50.05888039725167, 47.431026526859824, 47.00188146318708, 48.596534729003906, 50.665392126355854, 46.460411821092876, 42.60628080368042, 41.081821714128765, 40.97961023875645, 40.14897741590227, 42.97743967601231, 50.699632849012104, 52.03099455152239, 54.24991219384329, 53.10543271473476, 49.88722167696272, 48.63780355453491, 47.39002868107387, 47.41385405404227, 52.84672696249825, 55.93392276763916, 57.57197795595442, 57.96408564703805, 51.50221232005528, 46.94865478788103, 30.045956202915736, 6.247444536004748, 1.2691722852843148, 0.19649771600961685, 13.789747544697352, 59.29537091936384, 50.891354492732454, 57.175708293914795, 48.58957610811506, 28.037238938467844, 2.228797112192426, 11.024457437651497, 32.153150285993306, 15.68037496294294, 16.81104142325265, 22.018016236168997, 22.79503675869533, 24.778874261038645, 27.953594786780222, 28.820134162902832, 33.570652280535015, 43.94126599175589, 29.63420942851475, 36.65156691414969, 34.3673848424639, 48.2998605455671, 52.6701454435076, 67.59260395595005, 61.912548882620676, 0.8883774014455932, 0.10643952885376555, 0.02191561071335205, 0.039367339706846645, 0.017892155896074007, 0.15666761542005198, 0.13882285010601791, 0.20408874510654382, 0.15994648661996635, 0.13782154954969883, 0.20255351891475065, 0.13480632991663047, 0.25430898102266447, 0.2933223018688815, 0.09448372825448002, 1.130637907556125, 71.36569118499756, 83.71189662388393, 57.77113764626639, 44.61212151391165, 54.74413408551897, 45.20547335488455, 40.49425424848284, 34.80108445031302, 52.68871797834124, 38.00830691201346, 40.43307188579014, 19.5525678225926, 47.024358885628835, 64.20719841548375, 33.586911065237864, 18.25214992250715, 16.085949999945505, 22.208306550979614, 44.71595886775425, 61.509178161621094, 45.899671350206646, 57.63500159127371, 37.79784945079258, 8.026802199227468, 8.970358882631574, 3.9606125950813293, 0.7086634391120502, 48.62738125664847, 61.35925688062395, 57.42078515461513, 57.39605304173061, 57.0159900529044, 51.10474756785801, 51.923095975603374, 48.4050805909293, 50.78312240328108, 46.93665872301374, 47.88918031964983, 50.851867880140034, 48.19023881639753, 46.523293018341064, 46.63911254065377, 44.766725880759104, 56.10495615005493, 53.98796510696411, 58.1791011265346, 57.149461473737446, 53.53436238425118, 52.34823192868914, 49.06787967681885, 46.32682228088379, 44.8260634967259, 45.20624460492815, 50.497739042554585, 47.01880727495466, 48.19133315767561, 43.892288139888215, 45.40974691935948, 41.74487093516758, 44.8597275188991, 41.124379430498394, 35.73988682883126, 26.857874291283743, 41.40758105686733, 22.73697066307068, 1.986396610736847, 1.189120352268219, 0.29394131579569405, 0.11586536413856915, 0.22624412125774793, 0.15043307282030582, 0.17297771094100817, 0.14568811814699853, 0.28511984486665043, 0.1954195238649845, 0.24013509015951837, 0.12421841520283904, 0.26123755638088497, 1.0216415162597383, 0.2739864151392664, 0.1975947714277676, 0.06947003690791981, 0.14701333775052003, 0.22222815746707575, 0.09734817062105451, 0.28334145886557444, 0.17336994489388807, 0.28672599153859274, 1.0434502831527164, 0.8418060690164566, 0.19264276857886994, 0.26550326177052086, 11.729609268052236, 17.064303261893137, 16.743861028126307, 27.295576061521256, 34.88683564322335, 38.58727250780378, 41.09051391056606, 44.86317035130092, 44.75396203994751, 41.70059353964669, 45.17786468778338, 46.281085763658794, 48.00723368780953, 49.35612569536482, 51.86079147883824, 49.95326083047049, 48.70857443128313, 50.83781167439052, 51.0984524999346, 49.33700772694179, 43.12190662111555, 42.95331900460379, 44.3008074760437, 43.10047490256173, 45.36242273875645, 53.446134158543174, 53.081329413822715, 56.15162372589111, 56.270323276519775, 52.7210305758885, 52.710101059504915, 49.16489737374442, 49.60315499986921, 54.89504895891462, 58.28105204445975, 60.61072744641985, 62.05795383453369, 55.30690343039376, 54.658865792410715, 42.20544964926583, 11.528895786830358, 2.6127126600061144, 0.5499869393450874, 11.125588468142919, 62.38454696110317, 54.52749620165144, 63.9280823298863, 51.10756158828735, 34.34353862489973, 7.021426524434771, 16.96232455117362, 38.36409636906215, 27.27460639817374, 20.569792781557354, 27.1361757005964, 36.628151484898154, 34.362434250967844, 37.16450030463082, 45.15458127430507, 35.28903559276036, 66.05501624516079, 40.38255500793457, 33.00969988959176, 46.48787457602364, 51.473947048187256, 63.048287527901785, 76.67064080919538, 73.69409506661552, 1.625807251249041, 0.3910322945032801, 0.23474866205028125, 0.11143738709922348, 0.15226186040256703], [0.0978862081787416, 0.09933563361742667, 0.08376154503119843, 0.08058085106313229, 0.04489080474845, 0.05665300234353968, 0.0403316634973245, 0.037609011200921874, 0.050853817989783626, 0.14920961989888124, 1.8002571931907108, 55.97181476865496, 57.65320239748274, 46.37465020588466, 41.29197345461164, 22.598348890032085, 36.11359569004604, 26.32958538191659, 32.89730930328369, 34.52384090423584, 26.94533995219639, 27.43350648880005, 17.825184856142315, 22.66196138518197, 42.80360269546509, 29.016973154885427, 12.480153679847717, 5.33028883593423, 9.482616560799734, 36.42009115219116, 47.187252453395296, 37.68537201200213, 54.72485283442906, 45.23799787248884, 24.818930625915527, 2.573953219822475, 3.739551314285823, 0.05096958624199033, 27.508038078035625, 53.57280329295567, 51.46840238571167, 54.583179065159385, 53.93936593191964, 50.29085642950875, 45.85979216439383, 44.41547359739031, 44.493144035339355, 43.20265163694109, 46.76540299824306, 48.97951943533761, 49.61219113213675, 45.39000013896397, 42.482707091740195, 39.3140367099217, 45.50208847863333, 47.91990177971976, 50.489633968898225, 51.125105789729524, 50.01275825500488, 50.812113761901855, 45.92502185276577, 42.24358136313302, 40.97877298082624, 37.67592593601772, 40.312996591840474, 38.5165433202471, 39.53645549501692, 35.69343812125069, 33.76103639602661, 31.045572689601354, 25.46480563708714, 21.123030935014995, 13.27743341241564, 10.548064623560224, 25.85451967375619, 14.993090425218854, 1.3035196193626948, 0.43945581040212084, 0.09584311209619045, 0.015912536764517426, 0.06408939670239176, 0.02198102488182485, 0.09034026094845363, 0.07099567539989948, 0.06025766873998301, 0.0401376296233918, 0.0022388163280473755, 0.04140830518943923, 0.028049457019993236, 0.320799387459244, 0.14722461998462677, 0.05558536481112242, 0.13932702876627445, 0.04841067123093775, 0.12593685942036764, 0.06407825515738555, 0.06399146374315023, 0.06595693541956799, 0.19588833728006907, 0.07674384409827845, 0.2021376583725214, 0.06806714540081364, 0.1328516469470092, 4.115808427333832, 5.275441493306841, 6.109919275556292, 7.698717815535409, 16.195797545569285, 21.75434947013855, 30.69552939278739, 33.95309502737862, 36.374927861349924, 37.86426380702427, 38.434311389923096, 43.61649676731655, 45.320914200374055, 47.77733169283186, 45.20475769042969, 42.88387870788574, 44.50044311795916, 49.16287544795445, 48.00973503930228, 44.76834481103079, 38.09325558798653, 40.37528371810913, 38.2847444670541, 39.89312737328665, 44.84057828358242, 51.952149868011475, 50.63766533987862, 53.38825913837978, 50.58030448641096, 48.71546009608677, 46.70699296678816, 46.41555425098964, 47.808876514434814, 52.80974170139858, 54.941014766693115, 56.5609837940761, 53.231876032693044, 48.843293053763254, 31.123336928231375, 6.9977496692112515, 1.512048521212169, 0.36072395369410515, 0.18937955796718597, 17.44366795676095, 49.400166852133616, 42.29252099990845, 48.34189714704241, 48.00756025314331, 16.468670674732753, 0.4202698256288256, 14.46055703503745, 50.577306338718955, 24.809078080313547, 13.257372226033892, 20.021934270858765, 30.02337803159441, 30.145742756979807, 28.70002065386091, 32.93430846078055, 29.500387123652867, 31.571346351078578, 45.655261516571045, 23.276828323091777, 35.53073910304478, 28.17962489809309, 50.21674346923828, 53.5403482573373, 53.088482584272114, 1.4112692432744163, 0.22939119381564005, 0.04742659867874213, 0.0188031688864742, 0.06045703589916229, 0.09066178476704018, 0.07582554873079062, 0.02619934138575835, 0.0818329585183944, 0.0033355375677014566, 0.07748348798070635, 0.016018693568184972, 0.026691403106919358, 0.04315652013091104, 0.05189967794077737, 3.143658603940691, 70.43726594107491, 64.99205303192139, 55.5828025000436, 41.57441077913557, 33.57620736530849, 39.9831725529262, 27.254696335111344, 33.688914094652446, 30.933883871350968, 28.410935640335083, 28.393374068396433, 23.44919749668666, 31.836972509111675, 46.15875925336565, 28.589101348604473, 15.397767407553536, 8.091198103768484, 10.03778544494084, 39.49095174244472, 54.080390044621055, 39.77386154447283, 60.59219660077776, 47.70107173919678, 33.007803031376426, 4.608737085546766, 3.118891967194421, 0.109917977558715, 26.358488151005336, 58.278092111860005, 54.931057998112266, 57.67045477458409, 57.228754316057476, 53.12444298607962, 47.172814096723286, 46.245493616376606, 47.685410499572754, 46.58151197433472, 50.6667366027832, 52.95351035254342, 54.31573595319475, 47.74052708489554, 44.02989721298218, 42.454716273716514, 45.38461875915527, 48.385385922023225, 53.61686529432024, 53.65761995315552, 52.822738306862966, 52.71391214643206, 49.148853983197895, 47.56449447359358, 43.76095676422119, 42.20279891150338, 44.34903492246355, 41.90452664239066, 44.36208711351667, 41.29291493552071, 42.39890834263393, 38.58919021061489, 34.302735328674316, 29.93280131476266, 23.40413842882429, 16.53449617113386, 27.275118827819824, 15.551284381321498, 0.9794630195413316, 0.4613660861338888, 0.093076840176114, 0.034077460345413, 0.06828235635267836, 0.046096334167357, 0.02165221020446292, 0.011338491491707308, 0.04515918231170092, 0.01766249554098717, 0.028137469797262123, 0.05174049362540245, 0.05929285979696682, 0.4944583475589752, 0.5556594378181866, 0.04772894370502659, 0.08204099056976182, 0.045000377975936444, 0.0747405169531703, 0.04252233076840639, 0.1154660734214953, 0.03287160522969706, 0.19281005460236753, 0.0601125368848443, 0.05759637975799186, 0.02414311225792127, 0.1254906276507037, 5.526323139667511, 9.117546916007996, 10.2828814131873, 16.300162962504796, 26.375106504985265, 31.22280386516026, 36.42087629863194, 38.71721076965332, 39.90195158549717, 40.37363352094378, 42.31168065752302, 46.74059445517403, 47.662644726889475, 50.505274363926475, 46.685595989227295, 43.11503485270909, 47.35196992329189, 50.72556005205427, 48.822444983891074, 46.70986257280622, 40.76448706218174, 42.7806145804269, 40.988816601889475, 43.61247028623308, 47.62100417273385, 53.52249486105782, 52.991298130580354, 56.10085323878697, 53.46070105688912, 52.048278195517405, 49.379610606602256, 49.242606026785715, 49.85535723822457, 55.110450063432964, 57.39592102595738, 57.28257506234305, 53.581144605364116, 48.09229353496006, 24.44100594520569, 4.095130588327136, 2.2483211159706116, 0.4616299548319408, 1.2234064553465163, 24.45992762701852, 54.754716191973, 47.76003762653896, 53.77309553963797, 52.77815171650478, 14.426850455147878, 0.10025367114160742, 19.440755673817225, 60.62476975577218, 30.271352291107178, 18.57378724643162, 25.764811481748307, 23.97622009686061, 26.49432717050825, 30.520122119358607, 29.040923595428467, 31.107672214508057, 34.77431304114205, 39.120386941092356, 29.80470085144043, 38.61416898454939, 39.74349096843174, 56.13791145597185, 60.51827471596854, 65.67717320578438, 2.5093440924371992, 0.31573545347367016, 0.023755281997312392, 0.014173231836009239, 0.09920576880020754, 0.11099758784153632, 0.15777638235262462, 0.19804233312606812, 0.21597791356699808, 0.08979891213987555, 0.18430233826594694, 0.1920369453728199, 0.1534798579024417, 0.1674006823450327, 0.2881276820387159, 5.1662991898400445, 84.87216935838971, 75.87260546003068, 60.14926283700125, 54.557411670684814, 35.95623983655657, 50.21016352517264, 33.62666170937674, 45.027206897735596, 45.468424456460134, 37.07844686508179, 38.33186714989798, 28.106041737965175, 29.988480704171316, 54.097319330487935, 40.32195976802281, 17.23258342061724, 10.949843338557653, 18.7268317426954, 47.11098902566092, 59.5096811567034, 45.064431871686665, 64.11532238551548, 53.40916974203927, 30.8990421295166, 7.718033807618277, 8.4489278452737, 0.18014238934431756, 33.79049328395298, 60.994281905038015, 58.532437869480674, 59.4513440813337, 61.47594492776053, 55.4163236618042, 49.87171329770769, 49.53599371228899, 50.73685087476458, 50.30713605880737, 51.95164612361363, 54.82797104971749, 55.652781282152446, 49.40719495500837, 47.83661372320992, 44.36394228254046, 49.6567325592041, 51.99009050641741, 58.26305273600987, 57.07651233673096, 53.87521321432931, 56.48638098580496, 50.17554065159389, 49.352950368608745, 46.744586195264546, 44.198113100869314, 47.28395748138428, 44.69059794289725, 48.03533567701067, 46.846707344055176, 46.585309164864675, 43.61490910393851, 42.96185834067208, 41.14415747778756, 34.60520430973598, 27.502166850226267, 38.993815081460134, 21.516222545078822, 1.7310072119746889, 0.5255761806453977, 0.16497608673359665, 0.12477072913731847, 0.2194983432335513, 0.1401681136339903, 0.12879426537879876, 0.17269792381141866, 0.197818592989019, 0.08349858557007142, 0.22888856221522602, 0.12733871276889527, 0.12036445843321936, 1.754640206694603, 0.5596750623413494, 0.0949604194611311, 0.2968640375350203, 0.1292170469782182, 0.15928852478308336, 0.18082424918455736, 0.2457892139043127, 0.16280397400259972, 0.4224032482930592, 0.24874797942382948, 0.22415727323719434, 0.13887189461716584, 0.2211008258163929, 7.750422835350037, 14.410246866089956, 18.53712855066572, 27.601169994899205, 34.80416945048741, 39.111062458583284, 40.83809280395508, 44.13984898158482, 43.838248525347026, 44.80740063531058, 44.062230655125205, 49.80109180722918, 50.25181450162615, 53.728415148598806, 47.72131184169224, 45.287625380924766, 47.871208803994314, 55.39108433042254, 50.68301970618111, 49.549785886492046, 41.84395572117397, 44.761066573006765, 43.332002776009695, 44.81308078765869, 47.85544681549072, 55.5498263495309, 56.43517623628889, 59.24360683986119, 56.875198704855784, 54.77495976856777, 52.75097036361694, 51.75938252040318, 53.62326805932181, 56.8576649257115, 60.29204831804548, 58.943236214774, 56.24090460368565, 53.0748085294451, 36.73988199234009, 8.776454636028834, 2.6296323920999254, 1.1139616881098067, 0.9993777509246553, 21.944431338991436, 60.923570087977815, 51.4767610686166, 59.66883659362793, 56.34282772881644, 25.540059838976177, 2.7616631473813738, 21.973346267427715, 54.908257484436035, 32.36487579345703, 20.720891782215663, 30.845144953046525, 39.09148938315255, 39.440928186689106, 36.39317035675049, 41.57378544126238, 37.72352457046509, 43.559535435267854, 57.36772176197597, 32.09839848109654, 49.50664799554007, 35.65425028119768, 70.54647772652763, 69.54260894230434, 81.30392892020089, 4.247383424213954, 0.41074094123073984, 0.1723698249885014, 0.08263252382831913, 0.27962455259902136], [0.06407877084399972, 0.09240346202360732, 0.037974242852734666, 0.08966270302023206, 0.01665744947136513, 0.038828036681349785, 0.028941923951996223, 0.06753092631697655, 0.01365079464656966, 0.02561562824329095, 6.52702875648226, 70.30818230765206, 55.05630622591291, 31.73775918143136, 28.156127827508108, 31.615873881748744, 32.87419959477016, 26.91936411176409, 31.53237043108259, 34.087247371673584, 32.69310522079468, 27.31805522101266, 28.826342378343853, 23.315244913101196, 35.9850366456168, 32.60518271582467, 16.641409839902604, 5.925679104668753, 3.0197118605886186, 21.539299249649048, 54.27247646876744, 43.1819703238351, 56.03644691194807, 52.80752175194876, 42.4545773097447, 8.73924616404942, 4.5388356021472385, 0.8365102931857109, 12.44255176612309, 55.72583811623709, 50.982938698359895, 53.995239870888845, 52.91188716888428, 51.56712933949062, 45.457911831992014, 45.3445589201791, 41.79661764417376, 47.29067638942173, 51.81545795713152, 55.07971470696585, 54.065659863608225, 53.36302675519671, 44.9651004246303, 40.978363037109375, 41.127631187438965, 47.516864572252544, 48.3266875403268, 50.95561490740095, 54.50483465194702, 49.12521621159145, 48.27828638894217, 46.984476225716726, 43.21504027502877, 39.01748411996024, 42.028677054813926, 37.953301497868125, 39.00597790309361, 36.551019532339915, 33.48677710124424, 29.67451592854091, 25.0001848084586, 21.42891148158482, 10.924080286707197, 7.560199396950858, 13.643922226769583, 6.521256106240409, 0.6736015805176326, 0.4568364577633994, 0.017698111844116023, 0.08139259607664176, 0.04143394363511886, 0.0032628880955079304, 0.046504282991268804, 0.013473262744290488, 0.007285192159802786, 0.04857325839943119, 0.01354578965609627, 0.03006224972861154, 0.05372402111866644, 0.41580085828900337, 0.5067329374807221, 0.14152725998844418, 0.0357891361761306, 0.007677678866977138, 0.104179667974157, 0.10226484215153114, 0.12474532478622027, 0.035536962029125006, 0.09432090020605496, 0.07166081613727979, 0.0997820757329464, 0.04784985525267465, 0.0662498657724687, 2.8677224048546384, 5.164454443114145, 5.118850375924792, 9.300504275730678, 16.856116124561854, 22.317492280687603, 29.303645406450542, 33.146284103393555, 36.64236055101667, 37.31145123073033, 43.1954984664917, 44.921062741960796, 45.46927561078753, 46.9974102973938, 43.518607071467805, 40.56372581209455, 47.34362513678414, 46.42978416170393, 47.67252853938511, 43.137877055576865, 40.43567746026175, 41.70487362997872, 39.47386959620884, 42.718198912484304, 50.34497594833374, 53.06895119803292, 51.8163994380406, 52.21761621747698, 50.77606650761196, 48.61244262967791, 45.132149015154155, 43.99833502088274, 47.18644993645804, 52.60439116614205, 56.586059842790874, 53.19872965131487, 54.24517352240426, 31.167530945369176, 2.5193088948726654, 0.7090602463909558, 1.2428580458675111, 0.19011498136179789, 8.138008117675781, 39.50579309463501, 37.56008904320853, 52.98853274754116, 53.9307918548584, 42.89066709790911, 4.590197120394025, 0.5855513481157166, 15.42513462475368, 40.123227391924175, 27.3534962449755, 22.85020545550755, 21.85729398046221, 26.24345030103411, 26.535719326564244, 28.05418733188084, 28.360099145344325, 39.009910583496094, 24.07236753191267, 36.1161595753261, 32.97336775915963, 32.05308927808489, 23.344392606190272, 40.017100606645855, 50.69164589473179, 59.028539248875205, 2.739719867706299, 0.18517475788082394, 0.0693883141502738, 0.10801278693335396, 0.05070821794548205, 0.05399519424619419, 0.08484989484505993, 0.05496015585958958, 0.08935045477535043, 0.045769168330090385, 0.08304166008851357, 0.062270291814846654, 0.07211970258504152, 0.05024905329836266, 0.16539494640060834, 10.339931334768023, 81.18232154846191, 60.02754429408482, 41.6931346484593, 34.61495958055769, 38.04081058502197, 35.49254832948957, 27.995356934411184, 34.001881803785054, 31.026517254965647, 30.3024628502982, 29.141288587025233, 32.929892880576, 26.635710852486746, 39.56196233204433, 29.16858979633876, 12.813264216695513, 6.617471286228724, 5.5797052809170316, 20.311971187591553, 57.552776609148296, 46.24834585189819, 59.4629545211792, 54.56930698667254, 47.551313740866526, 11.1299832037517, 4.257552547114236, 1.2961353127445494, 11.279401608875819, 59.46896471296038, 52.643353189740864, 58.05452339989798, 55.29951402119228, 54.807703154427664, 48.01814930779593, 47.66258566720145, 45.20487928390503, 51.45497499193464, 54.83051756450108, 57.40964024407523, 55.97352749960763, 55.382208006722585, 49.48189156396048, 41.4985260282244, 42.96767050879342, 47.49020433425903, 50.96236855643136, 51.01810005732945, 55.550375257219585, 53.070962701525005, 49.82646662848336, 49.05057518822806, 46.495399475097656, 42.628091199057444, 43.074849946158274, 41.65585061482021, 43.307538168770925, 43.373643330165315, 39.252684116363525, 38.77573892048427, 33.172961711883545, 31.06044183458601, 18.107427631105693, 14.855298961911883, 13.187488113130842, 4.963027034487043, 0.23052717000246048, 0.2385371673320021, 0.017933594029662863, 0.05549918407840388, 0.0055738034342149535, 0.09505893596048866, 0.015165844599583318, 0.05637932542179312, 0.019011964289737598, 0.07853685931435653, 0.05798985542995589, 0.048875674671892605, 0.025361467685018266, 0.22779476376516478, 0.44508235848375727, 0.030062005456004823, 0.07476834367428507, 0.07202104359333004, 0.10131679980882577, 0.05676774600786822, 0.0468564087391964, 0.03572194763858404, 0.10756568663886615, 0.048874290460454564, 0.11372768027441842, 0.053049903362989426, 0.04367226102788534, 3.4023665274892534, 9.050323963165283, 11.739149144717626, 18.37136537688119, 27.79104515484401, 31.23385497501918, 36.68260799135481, 38.482785497392925, 40.48192119598389, 40.1932235445295, 43.93744795663016, 47.77733864103045, 47.85299410138811, 48.7113676071167, 41.42707075391497, 42.40225042615618, 49.59506729670933, 47.562205042157856, 50.25153309958321, 45.31231580461775, 41.129121576036724, 43.90557656969343, 40.26203155517578, 45.50817857469831, 52.794507775987896, 54.56565918241228, 55.01316486086164, 52.92598853792463, 54.36584288733346, 50.740912096840994, 49.26723391669137, 47.89916835512434, 49.99427604675293, 54.50906957898821, 58.05233819144112, 54.09594358716692, 55.2749035017831, 27.284995692116873, 0.9428789083446775, 0.2260578769658293, 1.4678204144750322, 0.7296830426369394, 13.708869644573756, 44.92843130656651, 42.543212005070274, 58.9976475579398, 63.07408618927002, 45.65029355457851, 5.734294882842472, 1.5062094288212913, 16.13336103303092, 38.16555159432547, 33.42549398967198, 29.354078905923025, 23.862990515572683, 26.33574148586818, 24.123301301683696, 29.455658095223562, 25.22178544316973, 35.81643165860857, 28.3071642943791, 35.418494428907124, 34.537737301417756, 38.05165324892317, 24.06777129854475, 49.30339581625802, 54.48428882871355, 70.69480787004743, 4.274738047804151, 0.32221293875149315, 0.04146671687651958, 0.07025225207741771, 0.04842814350766795, 0.14281684293278626, 0.2098250123006957, 0.13139310878302368, 0.2713677313710962, 0.223886551335454, 0.2354929064001356, 0.12722978075700148, 0.21970905549824238, 0.17582356823342188, 0.3702691229326384, 14.576954126358032, 93.14427076067243, 69.15100152151925, 44.74508919034685, 41.80899238586426, 43.90875884464809, 46.98737015042986, 34.295950412750244, 42.51181656973702, 44.86951405661446, 45.4660690171378, 38.27683046885899, 42.47419554846627, 31.776457173483713, 44.49190378189087, 41.53186001096453, 21.711729219981603, 12.25367193562644, 11.671643052782331, 30.784070287431987, 63.61448233468192, 52.49113205501011, 63.99701540810721, 62.15553433554513, 52.03556646619524, 12.84074434212276, 11.850762401308332, 2.271348531757082, 16.004909685679845, 64.91131496429443, 55.68313448769705, 61.084955896650044, 58.193230288369314, 57.24125065122332, 51.94407606124878, 50.43461118425642, 46.86653055463518, 51.933730193546836, 56.21461956841605, 59.87270368848528, 58.34293270111084, 57.93972526277815, 50.131155558994834, 45.541998931339805, 45.463828223092214, 52.047840459006174, 52.87316138403756, 54.07177080426897, 59.62887750353132, 56.498585496629985, 51.5818977355957, 53.846562317439485, 50.548186438424246, 44.94631249564034, 47.78508588245937, 45.16317967006138, 48.8391831942967, 46.990142481667654, 45.453805446624756, 45.56620992933001, 42.01244953700474, 38.95369618279593, 30.131606646946498, 28.00217138017927, 27.921316930225917, 11.232556853975568, 1.0020214319229126, 0.6536284408399037, 0.13952822797000408, 0.12290317006409168, 0.11119689393256392, 0.2891368536012513, 0.19245784064488752, 0.1392868866345712, 0.07532020977565221, 0.16810967001531804, 0.10685492120683193, 0.12598066564117158, 0.175081997311541, 1.8441606887749262, 1.7748784635748183, 0.20224806959075586, 0.17069260855870588, 0.12509235473615782, 0.25353520682879854, 0.12626535179359571, 0.14451039848583086, 0.09977562965026923, 0.22504067154867308, 0.08281525330884115, 0.24343192896672658, 0.11459340953401156, 0.13396106527319976, 5.244796897683825, 13.595865879740034, 18.14772023473467, 27.648912804467336, 34.746836389814106, 39.12537922177996, 41.33982569830758, 43.36849124091012, 43.541734150477815, 43.50267832619803, 46.87343011583601, 49.80806085041591, 48.47182151249477, 50.490148135593955, 43.83215842928205, 45.68826198577881, 51.785688400268555, 51.526485851832796, 51.80269411631993, 46.95645761489868, 43.74996818814959, 46.28583485739571, 42.23741136278425, 47.01129627227783, 54.24088300977434, 58.019223076956614, 56.954974446977886, 54.42986706324986, 56.8349095753261, 53.80399070467268, 50.675004959106445, 49.542024748665945, 51.4245662008013, 58.9680621283395, 60.62789644513811, 56.09050389698574, 56.6451473236084, 38.80837113516671, 5.088081581251962, 2.2355418588433946, 3.227846452168056, 0.7803318277001381, 10.773409468787056, 52.285211767469136, 47.962261472429546, 60.965307916913716, 62.363327162606375, 51.801019600459504, 10.41725696836199, 3.1193844207695554, 21.543872901371547, 44.688794885362896, 32.91379737854004, 30.72828667504447, 29.43942015511649, 36.20515210287911, 35.999051162174766, 35.854525157383506, 38.49395472662789, 52.15861906324114, 33.168500968388145, 47.80330058506557, 45.61907182421003, 47.96217461994716, 29.38106918334961, 61.2573823928833, 62.87980760846819, 84.93170152391706, 6.957474436078753, 0.37172230066997664, 0.2513038579906736, 0.16356071696749755, 0.14149241042988642], [0.032489685009100606, 0.03603077945964677, 0.0700256417372397, 0.04449960895414863, 0.028838725561009984, 0.032978562704686604, 0.01396553057046341, 0.07538598696035997, 0.023354323780430213, 0.024669708018856387, 11.943211657660347, 68.95386723109654, 47.231689657483784, 32.892139843532014, 30.4917665209089, 29.299677985055105, 33.44686317443848, 29.19842188698905, 37.41281155177525, 27.45531862122672, 34.01563923699515, 24.946584667478287, 31.45230633871896, 28.35180994442531, 29.342979158673966, 30.59472840172904, 20.541824545179093, 6.404026533876147, 2.5111853650638034, 9.351352061544146, 38.076409680502756, 47.257001944950645, 47.93728617259434, 47.55423198427473, 52.30289145878383, 15.320718833378383, 1.7748232036828995, 0.32831986248493195, 4.753833711147308, 50.96100670950753, 51.94433661869594, 55.94514410836356, 51.54395709718977, 52.262914998190745, 45.123317854745046, 45.7606691632952, 43.523279735020225, 49.4507532119751, 53.35299008233206, 55.375391823904856, 54.62168598175049, 54.50871522086007, 51.37823213849749, 42.36344821112496, 41.802867548806326, 41.96933943884713, 46.75498070035662, 49.488756384168354, 52.80878632409232, 50.90720680781773, 51.04463522774832, 48.684429441179546, 47.05019923618862, 41.76666396004813, 39.680439540318076, 39.50903442927769, 40.916242667606895, 37.840890066964285, 32.18607432501656, 31.189938885825022, 22.77321767807007, 19.187250648226055, 9.498164892196655, 5.345687346799033, 7.744343161582947, 1.5731529338019234, 0.243490852947746, 0.04724592515932662, 0.08599978778511286, 0.05652626557275653, 0.08735595537083489, 0.09143699745514564, 0.03181707360116499, 0.0386314854424979, 0.12426748685538769, 0.06764559873512813, 0.10781430865504912, 0.012022351313914572, 0.10448473053319113, 0.23678155296615191, 0.9786516002246312, 0.09708413907459804, 0.04904827023191111, 0.04545234675918307, 0.07731244287320546, 0.038999471946486404, 0.05312338192015886, 0.15647058242133685, 0.14342984503933362, 0.005419048680258649, 0.05618365288579038, 0.06757963156061512, 0.19998767945383275, 1.4690969288349152, 4.335273359503065, 5.636430374213627, 11.122647643089294, 20.486890350069316, 25.68691349029541, 31.950394902910503, 35.34885958262852, 36.27176448277065, 40.076837744031636, 45.239460468292236, 45.147560119628906, 48.76549754823957, 46.72736855915615, 39.91765104021345, 39.23416369301932, 47.72559193202427, 46.24916573933193, 47.18557446343558, 43.032368659973145, 40.389461517333984, 40.300218854631694, 39.41007818494524, 45.61890506744385, 51.69151251656668, 52.80014623914446, 51.50576632363455, 50.489936215536936, 53.12632942199707, 48.13173498426165, 46.46360799244472, 43.53685304096767, 48.70354046140398, 51.17661278588431, 54.5033129964556, 56.3265654700143, 54.209147112710134, 6.531744846275874, 0.19873453383999212, 0.3856863613639559, 0.8075609494532857, 1.5213505306414195, 24.549875531877788, 50.25882175990513, 55.03890446254185, 48.71543230329241, 39.26874835150582, 37.51824351719448, 3.507094770669937, 1.3833069780043192, 8.960595795086451, 22.88370098386492, 27.925631761550903, 25.814503261021205, 26.30277749470302, 22.075608117239817, 28.525735514504568, 30.242423466273717, 28.83401666368757, 36.02758393968855, 28.75124798502241, 26.072045189993723, 32.66443000520979, 34.10412107195173, 35.79073027202061, 43.67252704075405, 51.84099606105259, 59.28490693228585, 1.5034600049257278, 0.07734290909554277, 0.05929727705993822, 0.07648147496261767, 0.023549087079507963, 0.0853740902883666, 0.04831060767173767, 0.046431136916258504, 0.020768060415451015, 0.020264334677319442, 0.01638283277861774, 0.07145555250878845, 0.030537268346441642, 0.0811470342533929, 0.20092944534761564, 15.956070797783987, 79.94089385441372, 53.82200738361904, 41.039118085588726, 38.16947385243007, 37.43239157540457, 35.94880526406424, 30.491224561418804, 35.149824959891184, 27.357501881463186, 32.90668242318289, 26.60275728361947, 35.364503451756065, 29.673557077135357, 29.63925382069179, 28.108169623783656, 15.933355399540492, 3.636643933398383, 5.334647527762821, 11.431059070995875, 41.6540093421936, 47.92092316491263, 53.28185789925711, 52.1046141896929, 62.1651645387922, 18.711940016065324, 2.571873754262924, 1.6349194880042757, 4.3677509767668585, 54.16922971180507, 55.97388185773577, 57.784033502851216, 56.27788291658674, 54.46420158658709, 48.57303592136928, 47.90625204358782, 46.18944249834333, 52.231460503169465, 56.71603284563337, 57.850652830941335, 55.4821891103472, 58.419050216674805, 54.89859601429531, 46.6127302306039, 43.76790148871285, 42.913550989968435, 48.43343618937901, 52.02011367252895, 52.88002620424543, 53.34434999738421, 52.60101434162685, 52.09559890202114, 50.92820078986031, 45.81058154787336, 42.56960473741804, 44.09260817936489, 43.733004161289756, 44.43022114889962, 38.85146733692714, 39.63811806270054, 32.261041913713726, 29.9286984034947, 17.28976535797119, 13.322367412703377, 8.29241532938821, 1.6133532566683633, 0.11966634089393274, 0.07476658626858677, 0.03609690948256424, 0.012429634325339325, 0.045017948640244346, 0.07619129946189267, 0.029840833574001278, 0.04789912368037871, 0.09191140878413405, 0.07487251237034798, 0.10963355603494815, 0.026764645873169814, 0.06576926620411021, 0.545666788305555, 0.557657424892698, 0.04516221197055919, 0.09201494644262961, 0.047727701985942464, 0.009016773663461208, 0.041096460672893693, 0.12770174257457256, 0.012148468073324432, 0.07854100516332047, 0.07341973496867077, 0.0778381514496037, 0.0530195457062551, 0.0389522832286145, 1.7920889343534196, 9.475665756634303, 14.451434050287519, 23.178474834987096, 32.067868096487864, 32.17037834439959, 40.81868648529053, 39.64100851331438, 40.73835836138044, 43.12511321476528, 49.119869572775706, 48.41190719604492, 50.985332352774485, 48.51669297899519, 41.75746801921299, 42.32090091705322, 49.933857985905235, 48.927842208317344, 50.72641120638166, 46.7754396711077, 42.13021455492292, 42.07436840874808, 42.041145597185405, 47.830888407570974, 51.5739802633013, 53.90646273749215, 53.12688527788435, 53.40521969114031, 56.163432189396445, 51.77390772955758, 49.10745314189366, 47.37625387736729, 52.61123514175415, 54.89317989349365, 56.77393913269043, 57.16128730773926, 53.11859260286604, 3.771927748407636, 0.2621675564774445, 2.627715992076056, 1.387135543993541, 2.2051751911640167, 30.757750511169434, 54.28625474657331, 57.035469327654155, 53.30349806376866, 43.06100913456508, 43.79450614111764, 5.033141306468418, 2.262392086642129, 5.038806259632111, 23.4782965523856, 23.23964156423296, 27.605333702904836, 25.50132015773228, 25.90517725263323, 24.145493847983225, 29.82467344829014, 28.074029650006974, 29.76461669376918, 31.56414454323905, 29.80287000111171, 34.206693853650776, 44.12365620476859, 32.59473957334246, 52.87224769592285, 59.039308956691194, 67.88021768842424, 1.8677213788032532, 0.16211034836513655, 0.04467377193006022, 0.0518318380096129, 0.028797809899385487, 0.3084265728081976, 0.23480655465807232, 0.1827643300805773, 0.15934691950678825, 0.17025036657495157, 0.12839730882218905, 0.28744002750941683, 0.35106099077633446, 0.29606651461550165, 0.5915201221193586, 21.449721336364746, 91.72823483603341, 63.502275875636506, 43.00785888944353, 45.14603846413748, 39.01484033039638, 46.82140895298549, 37.27766561508179, 49.97141647338867, 36.50263575145176, 46.265573910304475, 34.55220692498343, 48.10342802320208, 39.63305630002703, 42.6130622455052, 38.65962757383074, 28.748849119458878, 12.149844135556902, 9.139778545924596, 18.175968136106217, 48.66587080274309, 55.44192082541329, 57.261442116328645, 56.293467726026265, 63.518541608537944, 21.045334441321238, 5.320533999374934, 2.308611503669194, 7.829548052379063, 60.88017858777727, 59.138140133449006, 61.7904759815761, 57.180742263793945, 58.59224101475307, 49.20026370457241, 51.03153439930507, 47.67572818483625, 53.482073715754915, 57.99035678591047, 60.93532643999372, 57.94934851782662, 61.98772144317627, 56.323661123003276, 46.4296486718314, 47.5896816934858, 46.44267307009016, 54.035629749298096, 54.079198428562705, 59.204564911978586, 55.68422882897513, 56.70593016488211, 55.231025627681184, 52.7733713558742, 48.686239446912495, 45.904500348227366, 45.279412610190256, 48.35133627482823, 47.78742395128523, 43.17109291894095, 45.27670281273978, 39.34648132324219, 39.75524732044765, 28.007280043193273, 25.479372535433086, 16.41990647997175, 2.4537387447697774, 0.5551204638821738, 0.31265417167118614, 0.14774045587650367, 0.057159321781780036, 0.1695446494434561, 0.24108962608235224, 0.15544895295585903, 0.11419776933533804, 0.2125375238912446, 0.10755964089185, 0.2161232286265918, 0.10313530080020428, 0.18249230539160116, 0.6545148247054645, 2.2869361639022827, 0.14404568342225893, 0.33270889839955736, 0.12520915775426797, 0.14799995480903558, 0.12731915738965782, 0.3062814250588417, 0.18456372352583067, 0.22230232134461403, 0.12723856100014277, 0.2129478882998228, 0.1955128088593483, 0.3032737507351807, 2.7779047787189484, 11.916725993156433, 18.321506840842112, 29.571397713252477, 38.58198840277535, 40.2584810256958, 43.95305708476475, 42.87304299218314, 42.43145023073469, 44.00078773498535, 49.96080310004098, 49.02474525996617, 52.68716158185686, 51.18954685756138, 42.39298152923584, 41.930009160723, 51.73356648853847, 51.18375900813511, 52.68537242071969, 50.04366036823818, 44.47249746322632, 44.75548022133963, 43.972647530691965, 52.00428220203945, 55.09663357053484, 57.28783137457711, 57.71277625220162, 56.3792154448373, 59.84347261701311, 53.64391810553414, 50.64300850459507, 47.498173918042866, 54.78086921146938, 55.86933926173619, 59.114808082580566, 60.934402329581125, 59.58174787248884, 8.768202781677246, 0.30760435121400015, 3.748670824936458, 1.8077269409384047, 2.798926119293485, 29.145719800676616, 61.39375468662807, 63.79075813293457, 58.863554273332866, 49.363720076424734, 48.45128958565848, 7.492673328944615, 4.4249177149363925, 13.24396480832781, 29.27143008368356, 33.093255451747346, 33.79792438234602, 34.79027305330549, 31.089669431958878, 34.59219380787441, 37.98968226569039, 37.52301345552717, 48.384878703526084, 40.958623204912456, 36.47608321053641, 43.986050605773926, 51.40277665002005, 44.125893524714876, 63.43757425035749, 65.5402728489467, 86.63319723946708, 3.5792917651789526, 0.2722422815859318, 0.21506005924727234, 0.20128498412668705, 0.17202160081693105], [0.03129162286807384, 0.05757357419601508, 0.043757244146295955, 0.03123068024537393, 0.02662204664998821, 0.046307708003691266, 0.08040614865188088, 0.03645331339378442, 0.052589188263352425, 0.06822825675564152, 9.855403048651558, 72.00923333849225, 46.32900401524135, 33.38175507954189, 36.28897169658116, 31.752294812883648, 33.26472657067435, 30.974808761051722, 35.91587080274309, 28.808563675199235, 28.04198455810547, 29.300431864602224, 30.27017457144601, 33.28844077246529, 35.89201068878174, 33.5437662260873, 11.552493606294904, 3.8466734290122986, 3.4261528168405806, 10.055930665561132, 36.92689970561436, 54.11160830089024, 52.41084909439087, 51.81015995570591, 52.00335461752755, 30.421951021466935, 4.878243378230503, 0.7957235532147544, 1.1367001022611345, 39.67346702303205, 54.40804624557495, 50.12659754071917, 55.042090211595806, 50.17750699179513, 49.14017220905849, 47.11385515757969, 46.707955292293, 53.0248509815761, 54.00847271510533, 55.11095380783081, 55.091252190726145, 53.631393977573936, 52.89977298464094, 48.03677742821829, 41.632410866873606, 40.35234771456037, 43.518839836120605, 47.29511628832136, 47.228781836373464, 50.91695165634155, 51.44691160746983, 50.187369959695, 48.78298268999372, 44.071767057691304, 40.35826757975987, 40.85240956715175, 41.237391880580354, 37.920210702078684, 32.91100767680577, 27.74121962274824, 24.15122263772147, 17.26486301422119, 7.374500972884042, 4.627463349274226, 4.399693582739149, 0.26740647107362747, 0.1064907107502222, 0.031567776442638466, 0.012643850375232952, 0.10486675931939057, 0.03775322364111032, 0.01590295585005411, 0.025183231802657247, 0.08197108110679047, 0.07011131356869425, 0.04701005960149424, 0.06063469672309501, 0.06621048359998635, 0.018598901008122733, 0.04447954806632229, 0.2586634930755411, 0.08147986925074033, 0.027845989812963774, 0.038153460914535184, 0.1617392168513366, 0.15198843793145247, 0.04422775050625205, 0.07829561297382627, 0.07516905931489808, 0.0638000557997397, 0.03146729897707701, 0.0660412705370358, 0.04335872017379318, 0.39019291954381125, 6.386244356632233, 14.014948214803423, 19.636720929827007, 27.903176920754568, 27.894130366189138, 32.252825668879915, 35.61115060533796, 40.20899942943028, 41.67513534000942, 44.98084156853812, 46.38753564017159, 46.516442094530376, 41.86326476505825, 40.897353989737375, 41.817444869450156, 46.76007372992379, 45.55028118406023, 47.664204597473145, 44.570807525089805, 39.18831253051758, 39.666411127362935, 40.541748659951345, 48.55779504776001, 50.357517446790425, 50.526626178196494, 52.819854804447715, 53.305460929870605, 51.79225444793701, 49.15291520527431, 45.80606174468994, 46.73517486027309, 46.65609393801008, 52.78979689734322, 52.73667444501604, 58.956910269601, 29.138187953404017, 0.1203720715961286, 0.054782145590122254, 1.2700376617056983, 1.4016018020255225, 3.2999932893684933, 37.0167155947004, 56.82316711970738, 43.46954236711775, 37.130822386060444, 35.07990871156965, 40.37050683157784, 5.498162525040763, 1.5469360777309962, 4.982499361038208, 42.77257898875645, 41.12270491463797, 21.893474987574987, 30.819902147565568, 23.203279903956822, 26.728589160101755, 30.0060943875994, 24.635859489440918, 35.14683723449707, 28.790470566068375, 29.764536789485387, 35.618279457092285, 25.06745900426592, 35.899254185812815, 49.17585815702166, 54.934917722429546, 39.457829679761616, 0.46981911254780634, 0.03990683950749891, 0.08931431600025722, 0.08226445929280349, 0.03993274597451091, 0.046309146497930796, 0.006596420168144894, 0.09000812484217541, 0.035132989420422485, 0.015606184988947851, 0.05768028739839792, 0.08017086663416453, 0.16883938014507294, 0.1113384227667536, 0.22625039092132024, 14.127671446119036, 80.39981542314801, 56.747112137930735, 35.627847126552034, 35.61601434435163, 38.722505296979634, 35.47280502319336, 31.101734978812082, 32.724066393715994, 27.073853833334788, 28.513093267168315, 26.83620285987854, 34.273705754961284, 32.245460578373496, 39.73761279242379, 30.36577136175973, 17.02121227128165, 5.227312624454498, 4.393358996936253, 12.860809002603803, 41.21003334862845, 58.012723037174766, 56.95714923313686, 56.22837700162615, 56.770607471466064, 35.15436213357108, 8.412084153720311, 2.512318789958954, 0.9358187786170414, 43.26265975407192, 56.80490377971104, 54.42731360026768, 59.069005557468955, 51.63722276687622, 51.58442687988281, 48.56470850535801, 48.70870644705636, 54.36920581545149, 56.919052260262625, 56.46945169993809, 57.09573800223214, 55.373616559164866, 55.17871264048985, 48.96551881517683, 43.90892907551357, 41.40349204199654, 44.976971421922954, 49.0220285143171, 51.152582441057476, 53.093429701668875, 55.939335414341514, 52.009740012032644, 50.875113078526084, 47.668998854500906, 44.0557792527335, 45.382801805223735, 46.08896459851946, 42.80556903566633, 42.21156753812517, 38.216207436152864, 31.935775893075125, 26.940835782459803, 15.97816606930324, 12.323570813451495, 5.795662675585065, 0.23623326952968324, 0.12371302875024931, 0.07414046129477875, 0.014264108879225594, 0.04248771869710513, 0.03796287060582212, 0.026167679245450666, 0.07547146201665912, 0.05539883214182087, 0.019822236882256608, 0.10532859060913324, 0.037219243722834756, 0.0311086016174938, 0.010147022166555482, 0.21992724521883897, 1.0557938665151596, 0.07925571966916323, 0.022394941421225667, 0.08143503165670804, 0.15358148887753487, 0.2034342980810574, 0.05847130995243788, 0.03119920300585883, 0.019764154284660305, 0.06000692290919168, 0.05136887017371399, 0.0198271121563656, 0.038682867506785054, 0.2774362228810787, 8.726771542004176, 20.86291296141488, 27.938042981284006, 37.81590781893049, 36.23481396266392, 39.350441796439036, 40.43098395211356, 43.6712520463126, 43.74040399278913, 48.049600328717915, 48.93014901024954, 45.44673218045916, 43.188161168779644, 41.421852656773154, 43.642861706869944, 48.62734304155622, 47.349006516592844, 50.491110461098806, 46.07383142198835, 42.954969201769146, 40.69239950180054, 41.791041714804514, 48.37849678312029, 53.020584787641255, 52.234420435769216, 54.20334536688668, 55.0311016355242, 54.59742982046944, 52.46614285877773, 48.77665982927595, 50.716791425432476, 49.75810330254691, 57.2951443535941, 54.69476366043091, 62.410456793648855, 25.204882213047572, 0.27139451993363245, 0.2560034729540348, 3.137161821126938, 1.6238187636647905, 6.361344618456704, 41.43315390178135, 55.59480898720877, 41.84403909955706, 42.507199491773335, 36.81693751471383, 43.46137475967407, 10.25893531526838, 2.8716635533741544, 2.4893547764846256, 45.65164845330374, 43.73639488220215, 23.76387619972229, 28.33332426207406, 25.773338658469065, 27.29550310543605, 25.86179964882987, 27.95185947418213, 30.246710504804337, 30.76411506107875, 31.831716196877615, 38.22369759423392, 32.43451063973563, 35.83240556716919, 56.509098121098106, 60.06766319274902, 48.889984948294504, 0.4708953233701842, 0.13380976553474153, 0.00286140846687236, 0.04103821522689291, 0.0424584195549999, 0.14365956985524722, 0.12416076686765466, 0.16745482943952084, 0.14027464363191808, 0.16711415057735785, 0.20780540710049017, 0.27492363484842436, 0.4834569607462202, 0.2384729507778372, 0.5373317184192794, 22.129194361822947, 92.6158116204398, 62.83050319126674, 43.8226706641061, 50.52926649366106, 41.91868707111904, 46.39829839978899, 40.05118152073452, 48.46382761001587, 36.91150597163609, 41.295464924403596, 38.63899837221418, 43.39424821308681, 45.07175874710083, 49.51096282686506, 42.47348683220999, 14.9212304183415, 10.537189824240548, 9.721910783222743, 17.73480268887111, 46.49747698647635, 62.52471991947719, 61.954884256635395, 61.542126519339426, 63.092894962855745, 37.759717736925396, 8.64573643888746, 3.8663841656276157, 2.1820639627320424, 51.30879184177944, 60.54125935690743, 56.14679820196969, 61.830164091927664, 54.46346507753645, 54.80356897626604, 52.22965049743652, 50.97365590504238, 56.00701781681606, 56.630893094199045, 58.97872066497803, 59.22052492414202, 58.03638512747628, 58.12108366830008, 52.48259619304112, 46.73505674089704, 44.636759826115195, 47.9041919027056, 52.0675733430045, 53.18977689743042, 56.50814969199044, 59.64353820255825, 54.83340106691633, 56.05662795475551, 49.1448518208095, 45.69055489131382, 47.81486586162022, 50.41356856482369, 47.36632490158081, 49.4469838142395, 41.467200074877056, 44.15257460730416, 34.99234056472778, 24.753747837884085, 22.232463700430735, 12.508160999843053, 0.5280012105192456, 0.16328555744673523, 0.13300646149686404, 0.1227829743708883, 0.14833683387509414, 0.20110559303845676, 0.16673890714134487, 0.1585015191563538, 0.23586110664265497, 0.21755370258220605, 0.1411704727049385, 0.11948625769998346, 0.1776817770940917, 0.15554070446108068, 0.23686357427920612, 0.7117727036987032, 0.24090658447572164, 0.0734896105048912, 0.20561711809464864, 0.278377893779959, 0.3487390439425196, 0.11219056096992322, 0.13843542018107005, 0.08944521219070468, 0.17671786381730012, 0.14462771719055517, 0.07648707966187171, 0.11382502290819373, 0.667984559067658, 12.339421391487122, 23.823529958724976, 32.36203050613403, 42.12959616524832, 40.165871960776194, 42.68458700180054, 43.390461444854736, 46.76102910723005, 47.20986883980887, 49.60562855856759, 51.390714577266145, 47.79581042698452, 44.62664672306606, 42.847289494105745, 44.87681661333357, 50.99558094569615, 49.63079840796334, 53.50077131816319, 48.12543296813965, 42.81841625486101, 43.97153581891741, 44.97588055474417, 52.37996087755476, 55.3769655908857, 54.179718017578125, 55.04964290346418, 56.90721252986363, 57.84580646242414, 53.76267671585083, 51.63897371292114, 52.23690789086478, 53.90174838474819, 60.05544131142752, 55.72355215890067, 63.295921325683594, 32.42785773958479, 0.30302171568785397, 0.49767731768744333, 4.490401012556894, 5.726382621697017, 5.331731455666678, 43.3199337550572, 63.512454986572266, 51.479203360421316, 48.309351784842356, 43.49832527978079, 48.947679315294536, 9.713308913367134, 5.0947761705943515, 8.01461592742375, 49.54184409550258, 49.22053507396153, 31.822016511644634, 38.22206824166434, 31.29504428591047, 34.66200930731637, 38.87683520998274, 33.28572750091553, 47.20534208842686, 40.002360003335134, 38.81447512762887, 48.684728213718955, 37.661164488111226, 47.458690779549734, 70.62763963426862, 67.50837789263043, 66.37294496808732, 0.7973833584359714, 0.22707428171166352, 0.1581113479499306, 0.1926177849194833, 0.0967217878039394], [0.1048736193084291, 0.05705824042005198, 0.02492174306618316, 0.03199446640376534, 0.036598584348601956, 0.04529344403584089, 0.07484029552766255, 0.08801823947578669, 0.10836124180683068, 0.12287844424801213, 13.743994525500707, 74.62834984915597, 42.81367410932268, 35.92419127055577, 45.13871853692191, 51.94106749125889, 39.596512249537874, 31.550671986171178, 37.883739607674734, 31.29415144239153, 30.659423078809464, 31.042682238987513, 31.714757169995988, 34.27391072681972, 25.87241302217756, 31.15169252668108, 12.510801315307617, 1.6716726358447755, 1.5222138443163462, 8.080343280519758, 43.20057759966169, 53.11388519832066, 49.087720257895334, 38.639943327222554, 31.38816056932722, 35.77164009639195, 9.4567996604102, 0.6247853285499981, 0.20918387813227518, 25.813381126948766, 56.19050931930542, 52.09917722429548, 56.44681446892874, 52.836836201804026, 51.655235971723286, 46.03640842437744, 49.85068110057286, 53.93982103892735, 55.329050813402446, 55.782059465135845, 54.842906202588765, 54.811667101723806, 54.73970808301653, 47.25132526670183, 42.673633166721885, 40.13456685202462, 41.321746485573904, 43.98813853945051, 48.37605449131557, 48.59977258954729, 50.97774839401245, 50.02943045752389, 49.126480783735005, 46.220382826668875, 40.046838896615164, 39.154377528599326, 42.61304834910801, 38.718468393598286, 34.40565552030291, 31.3689592225211, 21.735598019191197, 16.794935498918804, 7.474951079913548, 2.5003096972193037, 0.8200619529400552, 0.057168882340192795, 0.02008372901140579, 0.04048780458314078, 0.069075149883117, 0.022335673083684275, 0.08261847136808292, 0.05440614219488842, 0.0480228273996285, 0.06874146671699626, 0.04649801332769649, 0.07678951629038368, 0.05530330798189555, 0.04395772410290582, 0.05818146014852183, 0.33521052130631035, 0.747985303401947, 0.26990174289260593, 0.030907707754522562, 0.061993639517043314, 0.039125282516969104, 0.07122073868023497, 0.07772372330405883, 0.05947088024445942, 0.048356673414153714, 0.1366153314177479, 0.017752898457859243, 0.041879524011164904, 0.023956971442592994, 0.21941770613193512, 4.345798577581133, 16.124872071402415, 23.23230426652091, 31.135986123766216, 32.152427673339844, 32.29770755767822, 38.499843324933735, 40.13803400312151, 43.13462182453701, 43.62613044466291, 46.72751447132656, 43.72417994907924, 45.36064747401646, 42.860108920506065, 44.987699440547395, 47.61650174004691, 48.09961346217564, 46.24125868933541, 46.14412634713309, 42.24569361550467, 40.387300627572195, 40.35663822719029, 49.078225544520784, 52.48820686340332, 53.914915221078054, 53.18341929571969, 52.4079829624721, 51.82342059271676, 53.048005853380474, 46.98668922696795, 47.83893094744001, 46.60945068086897, 52.930904388427734, 51.97727108001709, 53.726004123687744, 11.010625311306544, 0.018538725129993897, 0.19797101909560816, 3.2628206440380643, 1.5884534099272318, 19.07848354748317, 56.09543711798531, 49.931123869759695, 24.807884727205547, 27.273564168385096, 54.687874521527974, 45.296091760907856, 26.734962395259313, 1.7843144429581506, 1.6751777849027087, 34.18284068788801, 33.684272697993684, 20.46517722947257, 29.475047043391637, 25.934212037495204, 24.84647328513009, 30.465651716504777, 25.584669010979788, 29.44101129259382, 29.373169081551687, 32.69990403311593, 35.81385040283203, 29.381896018981934, 34.749448912484304, 42.408180713653564, 65.49836826324463, 26.246790647506714, 0.3833924787385123, 0.0687420434717621, 0.11535353160330228, 0.18405398087842123, 0.10304078087210655, 0.07131438329815865, 0.021918942320293615, 0.03279595536046794, 0.10198858340403863, 0.07336391867803675, 0.052749437878706625, 0.10717580720250096, 0.08978002172495637, 0.16384608165494033, 0.2929002530872822, 18.213417189461843, 82.37982273101807, 52.042573724474224, 35.999805041721885, 48.980891704559326, 43.79485355104719, 36.89208575657436, 31.885957309177943, 35.524364130837576, 29.636252198900493, 32.07378101348877, 30.397979736328125, 33.643431186676025, 29.268935680389404, 22.969862120492117, 25.068263258252824, 19.094877822058542, 7.219529220036097, 2.426909361566816, 9.311966197831289, 46.483462469918386, 59.428908348083496, 51.94772733960833, 41.91030754361834, 34.24446426119123, 43.949134826660156, 11.955866932868958, 0.5478656760283879, 0.1920991941754307, 25.448178597858973, 59.32645715985979, 53.20113720212664, 58.2332067489624, 54.833842277526855, 55.14996794291905, 46.68990387235369, 53.67035947527204, 54.44122389384678, 57.80818544115339, 57.33419322967529, 55.65632138933454, 56.037402289254324, 56.916985171181814, 49.16801711491176, 45.91112198148455, 41.59289298738752, 43.93820183617728, 46.28422287532261, 50.73820577348982, 49.99905988148281, 52.92005130222866, 53.241996083940776, 51.0478835105896, 50.05260269982474, 46.01325355257307, 41.90968220574515, 45.73195573261806, 43.812411648886545, 43.541015011923655, 38.34469699859619, 31.107762541089738, 24.397683926991053, 15.964617082050868, 14.38228644643511, 3.890991645199912, 0.057701240559773784, 0.008156626202565218, 0.035895438864827156, 0.03997728501313499, 0.03197976594258632, 0.08913575951009989, 0.011837208793232483, 0.09500040552978005, 0.0768061268276402, 0.020812675789264694, 0.039775034080126455, 0.047923740930855274, 0.06014206672885588, 0.05195652899731483, 0.25138259519423756, 3.3083539264542714, 0.4579131028481892, 0.1147437457527433, 0.06834268490118639, 0.05123613854604108, 0.07666955129908663, 0.05642556758331401, 0.06636897580964224, 0.08555348137659685, 0.05871916522404977, 0.0690913600847125, 0.018750602778579508, 0.015061127986492855, 0.1288926936686039, 4.584496123450143, 19.615289211273193, 25.48429533413478, 34.577619961329866, 38.27071257999965, 38.173211983272004, 42.13093369347708, 42.90699189049857, 47.06649623598371, 47.51268523080008, 47.83046456745693, 47.82988439287458, 47.35222700663975, 45.75519398280552, 48.62131895337786, 49.22864362171718, 51.02158110482352, 47.168877942221506, 48.172465324401855, 42.80963373184204, 42.07617841448103, 42.209597723824636, 50.294650145939414, 53.434721742357524, 54.49491957255772, 52.625902788979666, 56.01025915145874, 53.346166951315745, 54.460324491773335, 49.501902375902446, 51.764843804495676, 50.42247268131801, 55.527230807713096, 55.58645377840315, 52.8432354927063, 9.47333116190774, 0.15516098269394465, 0.2572232617863587, 1.851837145430701, 3.8394698841231207, 27.481191975729807, 59.011981691632954, 53.43039301463536, 27.596870797021047, 29.840987818581716, 54.14702326910836, 49.49398142950875, 33.195008346012656, 1.454020423548562, 3.310407553400312, 42.49774994168963, 32.71014220373971, 21.307448284966604, 26.887781075068883, 29.464277335575648, 25.12745496204921, 29.518105030059814, 26.811194556100027, 26.107307297842844, 30.759817600250244, 31.51386390413557, 37.70542451313564, 34.75658471243722, 31.78296763556344, 52.46910973957607, 74.61182008470807, 31.414035660879954, 0.398993437311479, 0.06699612537132842, 0.18613914613212856, 0.13581769993262632, 0.08336929750761815, 0.23649624256151064, 0.2168173970920699, 0.06600415467151574, 0.27165923001510756, 0.20743340706186636, 0.16787014715373516, 0.29913563707045143, 0.3150157449500901, 0.30865928317819324, 0.6221756285854748, 25.64332570348467, 97.40504510062081, 59.344793455941335, 47.738963740212576, 59.91405936649868, 61.780651228768484, 52.05211360113961, 39.65765987123762, 51.37053006035941, 39.78484664644514, 43.15650517599923, 41.89886038643973, 44.15042413984026, 47.23944732121059, 35.2641784123012, 42.286027908325195, 15.47930451801845, 5.6294704505375455, 8.116044861929756, 16.252672025135585, 54.171460083552766, 61.1757619040353, 57.5678368295942, 46.483976636614116, 40.337127685546875, 43.96091202327183, 13.222562619618007, 1.8969216176441737, 0.37315392813512255, 34.15445729664394, 64.93565450395856, 57.57226283209664, 62.17043822152274, 57.88785001209804, 55.55763612474714, 50.222843987601145, 54.98066813605172, 58.738646507263184, 59.01353113991873, 57.48215511866978, 57.5885910987854, 58.22445201873779, 59.60262720925467, 50.04262508664812, 47.7921313558306, 45.213442938668386, 47.51761845179966, 47.858587401253835, 55.069306305476594, 52.6655387878418, 60.500702721732004, 56.35203061785017, 54.731418882097515, 54.57774904796055, 47.36763116291591, 45.407499177115305, 49.1440805707659, 49.3351595061166, 46.86242764336722, 46.66132245744978, 39.53007010051182, 34.55458320890154, 24.923316887446813, 22.843853064945765, 8.608822396823339, 0.1244158281811646, 0.09727410852376904, 0.12025119736790657, 0.1760705414095095, 0.18476697190531663, 0.16258912267429487, 0.12856532766350678, 0.20667776332369872, 0.1572371641440051, 0.19540775806776114, 0.18793991021811962, 0.10562520540718522, 0.11256675435496227, 0.13322342985442706, 0.5269183771950858, 2.158306117568697, 0.2631379972611155, 0.2906858133418219, 0.1389831065067223, 0.1940122422363077, 0.14893292688897677, 0.258325284080846, 0.21784528265041964, 0.11117327412856476, 0.11267054307141475, 0.15349980683198997, 0.13042501573051724, 0.1365100634949548, 0.23133052832313947, 5.900838426181248, 23.25576138496399, 28.96230820247105, 40.855463300432476, 42.04775333404541, 40.63368374960763, 45.542530468532014, 46.447609765189036, 48.8512487411499, 48.1569812638419, 50.261687891823904, 48.0020294870649, 46.47884886605399, 44.08904027938843, 50.560432638440815, 51.2479429926191, 53.13830464226859, 49.96197039740426, 51.122079849243164, 47.09668615886143, 43.212799480983186, 45.64419303621565, 53.08231953212193, 56.568397521972656, 55.71669428689139, 55.82507576261248, 57.38587393079485, 57.03325285230364, 58.05357149669102, 49.954483713422505, 54.677156925201416, 52.325084005083355, 57.64612913131714, 57.973920822143555, 58.456104959760395, 14.500094890594482, 0.5450336337089539, 0.4553389309772423, 6.8223658459527154, 3.960947411400931, 23.31368156841823, 61.667673519679475, 54.42084830147879, 29.464812346867152, 32.07600096293858, 60.92723873683384, 54.61330992834908, 33.60383687700544, 5.580202511378697, 3.5935952833720615, 42.292896202632356, 40.21688910893032, 29.266875539507183, 34.70511940547398, 35.91164629799979, 31.568028586251394, 41.464344365256174, 32.76889269692557, 39.840717111315044, 41.89065456390381, 41.324921812329976, 48.725368227277485, 41.99960579190935, 46.37753370829991, 61.642368180411204, 80.30044228690011, 44.42980078288487, 0.44454058898346765, 0.22225301899015903, 0.22947587498596736, 0.2427285595663956, 0.24198423379233905], [0.10000870642917496, 0.02910999029076525, 0.009713255085184105, 0.09193112022642579, 0.08240453606205327, 0.057253027467855384, 0.01632411914345409, 0.07604940421879292, 0.10799932479858398, 0.36184106660740717, 10.83418275628771, 67.16886806488037, 49.86690861838204, 40.89123957497733, 46.782391343797954, 102.70943192073277, 42.15571444375174, 35.47081436429705, 36.04437773568289, 32.51605122429984, 27.268130677086965, 26.634877068655832, 27.927396603993007, 42.532470090048655, 52.54082209723336, 42.84759521484375, 27.707678931100027, 3.4281117745808194, 1.4359287257705415, 2.289874166250229, 28.81211941582816, 46.64356633595058, 49.93843337467739, 55.01215737206595, 57.30415269306728, 43.62157242638724, 11.220716255051748, 5.645000542913165, 0.14856398025793688, 8.958823135920934, 50.865482875279014, 46.272178173065186, 57.631478854588096, 52.35334927695138, 52.55598306655884, 50.84018101011004, 53.630546297345845, 52.41293007986886, 58.523085594177246, 54.42251239504133, 55.79240533283779, 55.02926731109619, 52.99371957778931, 46.79483209337507, 44.93006760733468, 39.61026273454939, 42.84035519191197, 42.197111810956685, 47.4429600579398, 48.61433948789324, 51.088568687438965, 49.82572317123413, 48.99768202645438, 44.74509266444615, 40.92912810189383, 40.193956579480854, 41.41549505506243, 39.09027692249843, 36.16976840155465, 28.542791604995728, 23.737278495516094, 15.020683458873204, 6.388643222195761, 6.421370106084006, 0.964712319629533, 0.14773238130978175, 0.032151034966643365, 0.03661069619868483, 0.009861983175921653, 0.004984627236678664, 0.0786798537841865, 0.036139565586511574, 0.04880098492971488, 0.036812780890613794, 0.026490509243948118, 0.006878036373694028, 0.09751986712217331, 0.0391509379260242, 0.044293293596378396, 0.10869856192065136, 3.2806666578565324, 0.1899802785898958, 0.06703630142978259, 0.03632667840325406, 0.05232854939198919, 0.06323956551828555, 0.09797539482159273, 0.0849015720720802, 0.02607012287314449, 0.04948207802538361, 0.02082945596027587, 0.07663042696991137, 0.03270954392584307, 0.014218325577011066, 1.728141297187124, 13.42235199042729, 21.967261382511683, 23.503563676561626, 28.432176283427648, 32.03272063391549, 37.19934204646519, 39.892651421683176, 43.09907136644636, 42.564765317099436, 46.484275409153526, 48.87790897914341, 47.85959489004952, 46.35026550292969, 46.23549863270351, 46.162559917994905, 48.82508529935564, 47.03016757965088, 43.80638408660889, 40.50832782472883, 38.18255731037685, 41.41448756626674, 49.82429531642369, 49.88267755508423, 52.03185960224697, 54.04647936139788, 54.498543058122905, 52.236966950552805, 52.38580778666905, 49.62457629612514, 48.91916043417794, 46.69332933425903, 49.48634188515799, 52.85933099474226, 38.84808356421334, 5.152632083211627, 0.041006700667951784, 0.06209571832524879, 2.250676772424153, 9.331483687673297, 31.58963748386928, 47.23725516455514, 45.64897687094552, 43.539573260716026, 50.11903095245361, 43.5101580619812, 51.92239768164498, 21.26451710292271, 0.20587911403604917, 5.83763153212411, 22.398725407464163, 19.55951602118356, 23.263340132577078, 24.892802136284963, 27.69575408526829, 27.953568731035503, 27.399243184498378, 29.952621051243373, 29.87556552886963, 26.3644722870418, 34.768125670296804, 34.8956424849374, 28.056381225585938, 51.827773639133994, 50.83975369589669, 68.95710509163993, 10.492499879428319, 0.3590432495943138, 0.08948992764843361, 0.15296525694429874, 0.0028090351053314017, 0.09373303782194853, 0.03003516261066709, 0.058398476003536155, 0.04172407503106764, 0.03760609010766659, 0.08919262753001281, 0.03867593287889447, 0.11985764705709048, 0.06760089684809957, 0.08096252701112203, 0.13313311684344495, 13.32245339666094, 79.46827738625663, 51.92134155545916, 47.25180121830532, 52.90237855911255, 75.74328558785575, 37.82440199170794, 32.57289443697248, 34.17079251153128, 29.54945877620152, 27.17519678388323, 28.727860348565237, 31.16076339994158, 38.72757748195103, 37.26048271996634, 34.45481055123465, 25.629097529820033, 7.142822844641549, 3.4063007278101782, 3.9210339188575745, 29.964637960706437, 52.50457681928362, 54.02561739512852, 57.35390874317714, 62.19404125213623, 49.89470141274588, 13.63805707863399, 6.186382029737745, 0.13368486080850872, 8.472347617149353, 54.42782776696341, 50.52304438182286, 60.285593441554475, 55.44551304408482, 55.376583439963206, 53.45024401800973, 56.100533621651785, 53.25668110166277, 60.357701846531455, 56.11440222603934, 57.626309394836426, 55.75276585987636, 55.53221961430141, 49.0579263823373, 46.61598546164376, 41.2836286681039, 47.336993081229075, 42.319796153477256, 49.64162370136806, 51.32175023215157, 52.65271241324288, 52.18284395762852, 52.78969962256295, 48.02709511348179, 45.147514956338064, 44.64854049682617, 47.286681175231934, 45.927266120910645, 43.278022221156526, 37.26018047332764, 32.95778294972011, 22.630836929593766, 17.697605507714407, 12.608034406389509, 2.3762858722891127, 0.11480759589799813, 0.059385283051856926, 0.03896725171112588, 0.02913756256124803, 0.018064366387469426, 0.021409881600577916, 0.01560595428704151, 0.020785685362560407, 0.04537186911329627, 0.05596234529678311, 0.12624082953802176, 0.06027875082301242, 0.03008930291980505, 0.030831240250595977, 0.13551571113722666, 3.158996100936617, 2.1863006268228804, 0.06019417821828808, 0.03500849860055106, 0.03613997949287295, 0.03846870149884905, 0.08855668415448495, 0.0556112271733582, 0.028353532310575247, 0.05874581807958228, 0.009956764340001558, 0.06096688032682453, 0.03286554251930543, 0.018988566705957055, 1.6541966136012758, 15.515803405216761, 23.1626763684409, 26.29940414428711, 33.24903059005737, 37.20034258706229, 40.587318420410156, 42.576142992292134, 44.9463472366333, 46.73638732092721, 48.43404068265642, 50.73173700060163, 49.68310792105538, 47.65275396619524, 48.067460673195974, 47.72607135772705, 50.02308675221035, 48.30137177876064, 46.84644678660801, 42.73304721287319, 39.9322943687439, 43.91886152539934, 49.16430330276489, 52.06951189041138, 52.53831727164132, 54.72198322841099, 55.111909185137065, 54.3022494997297, 53.043249811444966, 52.215243407658164, 53.579626423971995, 50.6939492225647, 52.21074444907052, 55.98321328844343, 38.75406401497977, 5.678584226540156, 0.1229635053979499, 0.06814067824078457, 2.3897008895874023, 13.372356227466039, 38.95033325467791, 49.51579877308437, 50.95891530173165, 46.53685242789132, 50.57452358518328, 49.237783976963584, 56.03824302128383, 19.950571060180664, 0.5193774104118347, 13.046939952032906, 25.550878184182302, 19.69039750099182, 24.84588095120021, 24.951910461698258, 30.51125274385725, 25.47583590235029, 27.40954736300877, 31.56440510068621, 27.719306741441997, 28.92354072843279, 33.49602515356881, 35.00372518811907, 33.559007099696565, 48.004965100969585, 58.856633867536274, 76.13571984427315, 12.238662089620318, 0.3832644527511937, 0.10531548809792314, 0.15820886700281075, 0.027170988265424967, 0.06305165203022105, 0.24894654591168675, 0.23465768407498086, 0.15121683504964623, 0.2366077122943742, 0.22332074812480382, 0.17342447196798666, 0.2044721988162824, 0.19346831499465875, 0.31145701876708437, 0.3909653095262391, 18.66955600466047, 93.89847687312535, 62.74694415501186, 55.46080602918352, 59.9254127229963, 126.28822026933942, 49.977291175297324, 47.419176374162944, 47.70725563594273, 42.47661699567522, 36.5328152520316, 37.75321422304426, 36.34346989222935, 58.64765984671456, 62.29466506413051, 55.896110670907156, 35.714981010981965, 6.653263628482819, 5.166573209421975, 7.719047376087733, 37.14099454879761, 56.79662152699062, 61.17724881853376, 61.133919852120535, 65.96993555341447, 53.42634916305542, 15.970701966966901, 10.533662744930812, 0.2727270812860557, 12.501905884061541, 59.44705009460449, 52.63143702915737, 63.772762298583984, 56.90533651624407, 58.36328397478376, 55.74580723898751, 57.274365765707834, 54.391377517155235, 62.895211764744346, 56.017242091042654, 58.68219934191023, 57.59193665640694, 57.23859296526228, 52.89842503411429, 50.71965060915266, 43.45180361611502, 50.09402438572475, 44.48869024004255, 52.442581517355784, 55.285659313201904, 57.13352925436837, 55.40064852578299, 55.74905552182879, 49.5591972214835, 47.13555438177926, 47.34081111635481, 50.89457845687866, 49.445441314152305, 50.22068657193865, 40.39749363490513, 41.00649281910488, 31.913600717272075, 26.14599139349801, 20.786564418247767, 5.5405217834881375, 0.32124266081622666, 0.2774373356785093, 0.08151195038642202, 0.1446319648197719, 0.12041823911879744, 0.1254118090229375, 0.26717243077499525, 0.167892118117639, 0.1249789579638413, 0.12161696622414248, 0.3579857663384506, 0.1214284420545612, 0.1089513162150979, 0.16780825118933404, 0.20145792913224014, 6.41712041412081, 0.4983224687831742, 0.14147722481616906, 0.055818733360086165, 0.20746269263327122, 0.13591646748994077, 0.22989170838679585, 0.18778086160974844, 0.1330743014280285, 0.17492524215153285, 0.18356152730328695, 0.16809919343463012, 0.17345550815973962, 0.112708866729268, 2.9805900284222195, 19.552762372153147, 27.839748552867345, 33.33267995289394, 41.79580817903791, 42.87789283479963, 44.950415406908306, 45.01934501102993, 47.6781496320452, 48.01929576056344, 48.552677699497764, 52.964537143707275, 50.72575112751552, 49.636832918439595, 50.393675872257774, 48.48169837679182, 51.53615427017212, 51.82572392054966, 48.41003813062395, 45.1018305506025, 42.79483406884329, 45.21510703223092, 52.831843921116416, 55.24915000370571, 56.744343280792236, 57.84456273487636, 57.402341161455425, 57.78020851952689, 56.18523563657488, 55.45947892325265, 56.05958093915667, 52.169152532305034, 55.58599172319685, 56.96879093987601, 44.15290117263794, 8.038378766604833, 0.16247001263712132, 0.7890535539814404, 5.306859510285514, 12.132206133433751, 39.673133509499685, 55.21675055367606, 54.28888463973999, 49.71809210096087, 58.27338470731463, 52.26539550508772, 61.32894189017159, 26.977228709629603, 2.3254886780466353, 9.729035292352949, 28.47415382521493, 27.034740686416626, 31.89435420717512, 32.708425998687744, 39.510299001421245, 35.249451705387656, 36.12358372552054, 39.497549057006836, 42.18912833077567, 36.870299679892405, 44.04852533340454, 48.65305485044207, 40.60234389986311, 65.54222529275077, 65.04233714512416, 86.6848223549979, 18.84038094111851, 0.5237554812005588, 0.23955860680767468, 0.4361471108027867, 0.16839667675750597, 0.2606077401765755], [0.077079121821693, 0.05435125549722995, 0.01585065437081669, 0.06643638147839478, 0.08247814354087625, 0.05274257788966809, 0.0347157955568816, 0.06607210995363337, 0.023670341287340437, 0.06934507111353533, 3.2333661445549557, 59.388921465192524, 55.76092651912144, 32.84274509974888, 62.99157633100237, 109.41869585854667, 30.313006741659983, 40.118561676570344, 33.791139466421946, 35.038330691201345, 28.2636216708592, 29.545762334551128, 28.545075825282506, 27.89775732585362, 91.5971292768206, 83.94545337132045, 47.81855535507202, 8.094044259616307, 2.431591796023505, 2.541241535118648, 22.95817177636283, 49.83749689374651, 51.3412503514971, 51.14105885369437, 49.91841214043753, 40.292082514081685, 23.853636503219604, 3.571022540330887, 0.022805156552099755, 2.899775964873178, 33.781363351004465, 50.745991230010986, 55.92584548677717, 56.30069385256086, 54.40443665640694, 53.36336374282837, 54.253302914755686, 53.971126147678916, 56.87504931858608, 55.297801290239605, 57.0731772014073, 56.48488017490932, 51.78979825973511, 48.59632280894688, 42.971877643040244, 42.72193704332624, 45.17598172596523, 43.159145491463796, 46.11028861999512, 48.15734257016863, 51.272796698978965, 50.15784706388201, 48.16504117420742, 44.661627428872244, 42.86555630820138, 42.240534578050884, 41.46903092520577, 40.957688672201975, 35.369547843933105, 34.99939298629761, 23.678065947123937, 13.548519986016409, 12.499983838626317, 6.142635302884238, 0.5709070424948419, 0.042667374413992674, 0.020514222161312188, 0.04383193728114877, 0.012420662396055247, 0.039716235628085475, 0.03576327720656991, 0.031090745968478065, 0.07219702165041651, 0.08952291123569012, 0.07662036429558482, 0.06420693253832203, 0.07468341823135104, 0.046979664625333886, 0.009443583216385117, 0.03395962934674961, 4.000209076063974, 3.927327249731336, 0.11736563220620155, 0.13541702500411443, 0.10525942753468241, 0.03760139125266245, 0.055844141103859456, 0.08784038187669856, 0.06036813424101897, 0.1159974206238985, 0.04432122549042106, 0.014698486642113753, 0.027562748940129365, 0.08270211437983171, 0.28530372785670416, 7.554027659552438, 20.25266136441912, 19.290460927145823, 21.202982119151525, 28.521665607179912, 36.040101119450156, 39.017432008470806, 42.93501050131661, 46.191613810403005, 46.86405004773821, 48.265171664101736, 46.276857784816194, 46.52114255087716, 44.77483095441546, 46.670049394880024, 45.030086926051546, 45.67321218763079, 43.07789325714111, 40.55365787233625, 39.47070121765137, 42.74277469090053, 46.85882152829851, 51.462326186043875, 52.145657198769705, 52.16643578665597, 53.677759306771414, 52.14733171463013, 53.897388390132356, 52.88705083302089, 48.60280895233154, 51.421036515917095, 48.379170758383616, 47.97097798756191, 27.793753215244838, 2.974659958056041, 0.11353618412145547, 0.07356017136148044, 1.8871769862515586, 26.417349815368652, 46.81094149180821, 45.132656233651296, 50.803056785038535, 49.14612334115164, 57.06474208831787, 47.4534900529044, 47.7704564503261, 7.920618959835597, 0.40108451939054895, 11.895885740007673, 29.335117271968297, 34.54850353513445, 20.395808151790074, 27.126793895448955, 27.064831597464426, 27.246612106050762, 30.32911614009312, 30.217500277927943, 28.920016254697526, 24.839301007134573, 28.73317572048732, 36.98254435403006, 26.727213416780742, 40.81274230139596, 49.53725133623396, 55.19652782167707, 1.6078643969127109, 0.18408747336694173, 0.0555982773325273, 0.047399348712393215, 0.04954944298203502, 0.018774013933060423, 0.03142068362129586, 0.020683665926169072, 0.01915397318745298, 0.06220893867846046, 0.04201843370018261, 0.04234361482251968, 0.04221760747688157, 0.1514607412474496, 0.05823457586978163, 0.06325642032814877, 5.407396035534995, 69.18341486794608, 61.78395162309919, 33.23207351139614, 67.66032804761613, 115.72689587729317, 30.924271038600377, 37.08900465284075, 34.873008728027344, 33.04928377696446, 26.719473123550415, 30.338221754346574, 30.364885466439382, 33.47301966803414, 69.08434745243618, 74.67789050510952, 45.33007192611694, 10.725425209317889, 3.3771680167743137, 5.514095178672245, 27.624825137002126, 52.90163510186331, 56.53762395041329, 56.572865213666645, 54.49718468529837, 45.84696578979492, 29.340703623635427, 3.953246201787676, 0.2697345790054117, 2.4527625228677477, 33.66087811333792, 51.83308553695679, 58.96355274745396, 58.185806138174875, 57.50162397112165, 56.246671608516145, 57.71951253073556, 56.854896068573, 58.343752588544575, 55.86059842790876, 60.781729561941965, 57.78874438149588, 53.362484795706614, 49.14648812157767, 44.632788930620464, 46.370036602020264, 47.939544337136404, 45.2076689856393, 47.38525526864188, 48.410527978624614, 52.646320070539204, 53.29329463413784, 49.816610608782085, 47.40475191388811, 46.450746876852854, 45.05145263671875, 45.60763508932931, 47.211564200265066, 41.373430660792756, 41.73688050678798, 28.989772694451467, 21.214741945266724, 21.631630386625016, 6.795210983072009, 0.6248955226370266, 0.13523348128157003, 0.033786511314766746, 0.01550693906444524, 0.08308113725589854, 0.041480813441532, 0.01248788061950888, 0.05146653850429824, 0.049456565108682425, 0.043427055435521264, 0.036633562828813276, 0.08223855961114168, 0.11756189167499542, 0.09736491686531476, 0.023956084258056114, 0.07602277171931096, 1.4091612249612808, 8.686725599425179, 0.9601985961198807, 0.16306576638349465, 0.04719286372086831, 0.04819753320355501, 0.0491365340671369, 0.09957402332552842, 0.02341009257361293, 0.15215647034347057, 0.03750907317070024, 0.05682409155581679, 0.06778463734579937, 0.030438887554087808, 0.3171839086072785, 7.345637287412371, 19.334403072084697, 25.53454644339425, 26.93137581007821, 34.91185958044869, 39.98560094833374, 44.16835049220494, 46.57741948536464, 48.594842842647004, 47.28026451383318, 49.51621913909912, 48.28200714928763, 48.8185088293893, 47.381833280835835, 47.57802261625017, 45.9614234651838, 47.11033936909267, 44.88795804977417, 41.56449222564697, 42.56888907296317, 44.248140130724224, 48.5848582812718, 52.1902368409293, 54.09429339000157, 51.19131170000349, 55.65122141156878, 53.611723627362935, 53.79825496673584, 54.58350910459246, 52.012328216007774, 54.31461729322161, 52.31518629619053, 47.74769415174212, 26.38506153651646, 3.9940568804740906, 0.8785492831042835, 0.4523283525237015, 4.4951852815491815, 34.05483749934605, 48.87128734588623, 50.862217221941265, 56.22667121887207, 53.07395390101841, 62.158251081194194, 51.46242693492344, 50.41231788907732, 8.313331144196646, 0.7323848605155945, 17.561158520834788, 27.99716694014413, 35.497471128191265, 23.395484447479248, 24.881686755589076, 25.245982544762747, 26.918721403394425, 29.392168930598668, 29.707627568926128, 28.20872221674238, 28.766054596219742, 29.136730568749563, 36.80930839266096, 32.89048269816807, 44.84285729272025, 56.646439688546316, 61.42331232343401, 2.157243911709104, 0.20504856003182276, 0.01898232927279813, 0.05758888873138598, 0.01409317912267787, 0.031624308587717156, 0.12756532989442348, 0.1750754698046616, 0.10846337489783764, 0.18443330909524644, 0.15491665580442973, 0.25419371149369646, 0.2162718413663762, 0.31015401440007345, 0.147822626467262, 0.2997636619423117, 8.211777142116002, 84.08648790631975, 70.49993869236538, 43.4554305757795, 76.79239409310478, 122.5781740461077, 40.40477534702846, 50.7264598437718, 44.31461354664394, 47.3885417665754, 38.82831941332136, 40.16369022641863, 40.304832458496094, 39.80012573514666, 101.05114010402134, 92.55682836260114, 61.60895429338728, 10.988053219658987, 6.57414926801409, 7.167233169078827, 30.637400763375418, 57.92956699643816, 60.121824400765554, 61.838731220790315, 60.94596413203648, 49.65052434376308, 31.12073482785906, 5.341907092503138, 0.5958405988556998, 6.212380886077881, 41.13228300639561, 56.29867887496948, 62.86676583971296, 62.80298137664795, 58.96522031511579, 59.84787777491978, 59.453449385506765, 60.5475127356393, 62.88800648280552, 57.17491619927542, 60.59092508043562, 60.34288828713553, 55.43166528429304, 52.57540328162057, 47.25090490068708, 48.112207072121755, 51.77118403570992, 47.10733774730137, 50.96358101708548, 52.556142875126426, 57.08679567064558, 54.997038091932026, 52.15138946260725, 50.81224577767508, 49.83531515938895, 49.51487813677107, 48.84361267089844, 50.866462571280344, 44.20973743711199, 49.800094740731375, 39.292163780757356, 28.94316417830331, 27.79927703312465, 13.761135731424604, 1.9815498079572404, 0.2890678873019559, 0.15229463364396775, 0.17476229875215463, 0.2004163914493152, 0.13020958086209639, 0.13436283942844185, 0.11821613513997623, 0.2284016997686454, 0.15811490347342833, 0.1390883337174143, 0.39362513965794016, 0.19147800893655845, 0.30471229925751686, 0.12699424768132822, 0.19591546511011465, 5.56074321269989, 7.878016948699951, 0.3866515638572829, 0.21297824595655712, 0.2922174840101174, 0.13940364894058022, 0.22839762855853352, 0.24894456458943232, 0.21260408817657403, 0.24949100241065025, 0.1266444900206157, 0.10283232134367738, 0.2202313103313957, 0.12787228556615965, 0.6629636170608657, 13.321181007793971, 28.686035667146953, 30.99739040647234, 33.20305435998099, 42.01858479636056, 42.273722648620605, 46.13997827257429, 46.25855622972761, 50.17440462112427, 51.36659390585763, 52.373405252184185, 48.23549590791975, 50.52891560963222, 49.87868928909302, 51.943850244794575, 48.831467219761436, 50.03158787318638, 48.26388624736241, 45.504294531685964, 44.617457730429514, 47.8789838382176, 49.15351969855172, 55.430598735809326, 55.27064773014614, 55.34479890550886, 58.78814547402518, 55.28222342899868, 59.77412959507534, 57.91847767148699, 54.98054654257638, 57.749181338718955, 52.96774026325771, 52.8127224785941, 31.45446375438145, 5.257569423743656, 1.9536219579832894, 0.6154625830905778, 2.8578900524548123, 30.88255752835955, 56.50390086855207, 53.73665918622698, 59.992101533072336, 56.416152068546836, 68.39234161376953, 56.186851092747276, 56.909644399370464, 12.018573556627546, 2.2710805918489183, 16.394415276391165, 36.394775390625, 43.361202580588206, 29.222250734056743, 34.68807200023106, 37.74748543330601, 35.803421156747, 41.18320287976946, 38.34740679604666, 41.877341815403526, 34.17318269184658, 35.680465834481375, 52.42229625156948, 37.94202109745571, 57.83509234019688, 64.59797900063651, 78.39787265232631, 4.56694540807179, 0.45157710569245474, 0.1904784454298871, 0.18396939470299653, 0.09734918842358248, 0.13057764539761202], [0.031902691149818044, 0.043846644527677975, 0.10818573872425727, 0.05924386278327022, 0.019658516560282027, 0.019088180735707283, 0.07573035026767425, 0.07816255225666932, 0.09035657971565213, 0.1524088175169059, 0.44447677955031395, 55.1284841128758, 52.604130608694895, 32.12795959200178, 41.657174246651785, 41.979806900024414, 28.41293498447963, 39.23085635049002, 35.10864993504116, 31.37829760142735, 29.777995450156077, 28.953720229012625, 38.01608542033604, 20.392408745629446, 50.96861151286534, 50.77774797167097, 30.461524486541748, 14.63255534853254, 0.7599459758826664, 8.257738607270376, 32.57213708332607, 54.51772008623396, 52.376535415649414, 53.70110872813633, 55.18044969013759, 54.68497364861624, 36.93423352922712, 12.36779522895813, 0.5406050256320408, 0.5364902264305523, 18.62777648653303, 47.965106759752544, 55.83186762673514, 54.954751355307444, 55.9083742414202, 57.567183698926655, 55.7821741104126, 56.25341830934797, 58.725792339869905, 55.418019022260395, 58.80202102661133, 56.65003538131714, 51.96586561203003, 45.906428473336355, 43.63982534408569, 45.46655886513846, 46.96348919187273, 42.86648736681257, 46.99402652468, 49.80200202124459, 49.01856483731951, 51.72994647707258, 47.72254514694214, 44.25609581811087, 40.42269822529384, 42.57229021617344, 42.23266921724592, 41.52410929543631, 34.49929986681257, 32.081684589385986, 18.080433879579815, 18.890684161867412, 16.228916134153092, 3.516459639583315, 0.12379263447863714, 0.04879148204677871, 0.021586551763383404, 0.05872140438961131, 0.009345430581431304, 0.07561178305851561, 0.04580120536099587, 0.0581862438204033, 0.028613784416977848, 0.050219669339380095, 0.047331088089517186, 0.038017533386924436, 0.030912135195519243, 0.1550876601998295, 0.0336096206280802, 0.15186015410082682, 1.1673026829957962, 10.841332452637808, 0.4540181761341435, 0.07980779611638614, 0.049128659668245485, 0.0474977566461478, 0.07030283686305795, 0.018440378264390996, 0.040583430523318906, 0.08251216528671128, 0.052612407731690576, 0.14422709654484475, 0.011385527539200016, 0.0626270587423018, 0.09427026792296342, 2.5997288652828763, 12.636984944343567, 22.91354523386274, 20.401199953896658, 24.490266936165945, 32.98659018107823, 40.59157419204712, 42.895954677036826, 44.923807280404226, 45.329311098371235, 45.74586950029646, 43.69104746409825, 46.25690255846296, 46.427741391318186, 45.07706717082432, 43.67360053743635, 41.97262246268136, 42.5886949130467, 40.44210801805769, 38.39768048695156, 40.85400765282767, 48.55293478284563, 49.7222193309239, 51.74460022790091, 50.29825626100813, 52.46978371483939, 54.877935545785085, 53.826627935682026, 51.91694334575108, 54.80455562046596, 50.80051721845354, 46.81868873323713, 39.934100900377544, 18.014959267207555, 1.00887821827616, 0.08766681940427848, 1.9163099144186293, 23.69966789654323, 44.88085004261562, 48.39518288203648, 50.41407230922154, 48.63028907775879, 44.89862353461129, 45.79303387233189, 46.52599934169224, 45.142679010118755, 4.901508552687509, 1.0160988079650062, 9.326626028333392, 42.44660772596087, 23.907999208995275, 19.15606713294983, 26.02582229886736, 27.63413051196507, 27.66092276573181, 29.396626199994767, 32.47950022561209, 30.153826986040386, 24.54397824832371, 35.74136332103184, 35.634159564971924, 26.51635296004159, 33.723995549338206, 54.20469331741333, 42.80345678329468, 0.23563930711575917, 0.03644300644685115, 0.06287292590630905, 0.1416203821344035, 0.1232883201113769, 0.09167935659310647, 0.031515447822000296, 0.04639307788706251, 0.03382327773475221, 0.0070587735057675415, 0.03848207542406661, 0.0187099161225238, 0.015909729325877767, 0.0566596689500979, 0.06166680955461093, 0.04112677422485181, 1.1268534192017146, 62.334207262311665, 61.317282812935964, 30.50125081198556, 50.79652200426374, 56.3112724849156, 29.048017706189835, 33.27463470186506, 35.110070841653005, 28.635117530822754, 29.912866933005198, 31.55733183452061, 35.05744171142578, 27.339657170431956, 52.00346578870501, 53.25109474999564, 34.878549916403635, 20.108031136648997, 2.537402004003525, 8.038817371640887, 38.203474862234934, 57.93619210379464, 58.30095863342285, 58.27307898657662, 59.99622181483677, 59.57878793988909, 43.75679479326521, 16.533106531415665, 1.133891944374357, 0.48521192371845245, 18.623927184513636, 48.605004583086284, 58.42619296482631, 59.03191607339041, 58.39935902186802, 58.88587188720703, 59.27851458958217, 57.7075685773577, 59.8879827771868, 57.38969891411917, 60.405234473092214, 56.26472997665405, 54.504845074244905, 49.26110907963344, 46.603687150137766, 48.17256954738072, 47.924873215811594, 45.727158001491, 47.61707844052996, 52.30859592982701, 51.38039650235857, 53.49832207815987, 51.385743141174316, 45.9829455103193, 44.88975068501064, 45.69889620372227, 47.23768595286778, 45.65759611129761, 43.05038186482021, 36.27445343562535, 24.286636080060685, 31.438792092459543, 22.024528435298375, 4.3570985198020935, 0.07473637788955655, 0.04705494808565293, 0.029116263347012655, 0.07250340056738683, 0.06842780711927585, 0.03427267826295324, 0.013123477942177227, 0.03864056424104741, 0.08102727282260146, 0.06478862703910895, 0.09293440889034953, 0.13445852643677167, 0.04446855579902019, 0.08879398820655686, 0.03852952877059579, 0.09788148557501179, 0.5283131737794194, 7.6226419891629895, 1.50836814727102, 0.3396996818482876, 0.04817449693967189, 0.12707065072442802, 0.012876642169430852, 0.10296142620167562, 0.051164736306028705, 0.08134615713996546, 0.1029332669984017, 0.11691870833081858, 0.011718850233592093, 0.0656345295054572, 0.03640428923868707, 1.8071042086396898, 15.28240646634783, 27.111808368137904, 28.294053043637955, 29.801650592258998, 38.5694260597229, 44.36828490665981, 46.511998721531455, 46.6644560950143, 49.465003967285156, 47.016708918980186, 47.598679610661094, 47.76340055465698, 47.36964961460659, 44.73745312009539, 44.75798852103097, 44.877052852085654, 43.860944816044395, 41.900548798697336, 40.80346993037632, 42.72274303436279, 48.891433647700715, 51.57189927782331, 52.9166327885219, 52.10812650408064, 52.362413202013286, 55.31082221439907, 55.143217767987935, 54.33958217075893, 57.825698375701904, 51.90771266392299, 47.008735861097065, 38.96700893129621, 16.66107324191502, 0.9017456269689968, 0.5602185417498861, 5.9062041725431165, 33.05359513419015, 49.381590843200684, 47.141408239092144, 56.90822696685791, 52.387124470302034, 53.025024686540874, 51.02929013116019, 52.991958209446494, 46.594133377075195, 3.338703006505966, 1.8542370966502597, 10.571251630783081, 39.22645814078194, 30.35082231249128, 18.705935035433086, 26.879486663000925, 26.745881489345006, 27.78711768559047, 26.50358043398176, 30.60632494517735, 27.416622366224015, 31.10629299708775, 31.112282344273158, 36.40898445674351, 26.817597321101598, 40.25339494432722, 60.759099279131206, 49.44167539051601, 0.20490327211362974, 0.04127700187798057, 0.04026369803718158, 0.023450392464708005, 0.1316427553870848, 0.08979955674814326, 0.16548141890338489, 0.14178005499499186, 0.1572528247322355, 0.14806261073265756, 0.2037220104996647, 0.08137898466416768, 0.19646210649183818, 0.1301799560231822, 0.09381284032549177, 0.1730589722948415, 2.245471268892288, 77.94319643293107, 70.26324830736432, 43.03372008459908, 56.28088801247733, 43.19692632130214, 39.97155169078282, 51.611389364515034, 45.17494991847447, 39.95976407187325, 40.62294183458601, 39.97378206253052, 49.78514916556222, 27.507411003112793, 63.62238243647984, 52.468995094299316, 41.481829507010325, 18.101134300231934, 4.618897523198809, 13.32394812788282, 39.90006514957973, 62.2838328225272, 64.80115127563477, 63.89923340933663, 64.39275700705392, 64.38323102678571, 45.39610065732683, 16.413877180644445, 1.3001702619450433, 1.545668357184955, 24.043798276356288, 54.96764721189226, 60.566877365112305, 62.32008157457624, 62.62312030792236, 63.02793625422886, 62.21364212036133, 57.31463405064174, 62.73855767931257, 58.75564180101667, 63.658825738089426, 58.88215460096087, 56.885534150259836, 51.60496922901699, 48.3672684941973, 50.765651157924104, 52.43975012642996, 47.081056186131065, 51.91461917332241, 57.1702470098223, 53.25577088764736, 57.494001797267366, 54.815165519714355, 48.77657297679356, 47.16477155685425, 50.46526663643973, 51.743790762765066, 49.64440298080444, 45.57242161887032, 43.68791382653372, 29.377706255231583, 33.118553842817036, 28.05002883502415, 7.062816943441119, 0.28986633302909987, 0.1296482424118689, 0.07922173185007912, 0.1623399510447468, 0.14352064659552916, 0.1295584315168006, 0.06504417011248213, 0.1266997227711337, 0.1547335327735969, 0.1785734263913972, 0.27070035146815435, 0.22857244632073812, 0.21230600774288177, 0.2912671278629984, 0.1268234604171344, 0.2963945727263178, 1.1049059054681232, 18.720102412360056, 0.49438653141260147, 0.26675559314233915, 0.1594467455787318, 0.262215678180967, 0.09909192419477872, 0.16053979764027254, 0.1779457272163459, 0.21166222728788853, 0.2841673174074718, 0.23046840886984551, 0.0895057035876172, 0.24001550514783176, 0.4391682744026184, 9.81055155822209, 22.589672327041626, 29.516913414001465, 30.69939259120396, 37.16527155467442, 43.01348345620291, 47.020071847098215, 47.55954040799822, 49.8347419330052, 50.12453392573765, 49.73814112799508, 47.67460605076381, 50.614079679761616, 49.680978298187256, 48.635816369737896, 46.47183118547712, 46.99786540440151, 46.211131300245015, 44.71344709396362, 43.953953402382986, 44.1709178515843, 51.943902356284006, 54.24942234584263, 56.277292319706504, 53.371969086783274, 55.26061800548008, 57.88100951058524, 58.14262655803135, 57.09067971365792, 59.10294055938721, 57.290659291403635, 53.277358940669465, 45.71143422807966, 20.721444164003643, 2.0432895464556555, 1.2861520541565759, 4.494704987321581, 28.831101894378662, 54.82037319455828, 56.038044997623985, 59.89973912920271, 59.92055593218122, 54.68482773644583, 55.472204548971995, 55.352525302342, 53.71270179748535, 8.262697884014674, 3.0693096220493317, 13.039632184164864, 48.65937076296125, 31.994936329977854, 25.15127512386867, 36.246907302311485, 37.20547383172171, 36.071861335209434, 39.44687237058367, 42.951839038303916, 41.23662757873535, 33.75553689684187, 43.58276673725673, 51.97225795473371, 35.548922538757324, 49.513443333762034, 67.17790767124721, 64.37293379647392, 0.5382672825029918, 0.26282820531300133, 0.16891654314739363, 0.15745365752705506, 0.25389119344098227, 0.15573556614773615], [0.03333853231742978, 0.09770970086434058, 0.06481892362769161, 0.009687787121427911, 0.057181564159691334, 0.03209401766902634, 0.03966181372691478, 0.06666356857333865, 0.10484212849821363, 0.0297556265390345, 0.08725425654223987, 42.86644567762102, 65.19355773925781, 36.701454980032786, 27.821580750601633, 24.99996941430228, 25.97421281678336, 41.285775661468506, 36.07997335706438, 33.999283177512034, 29.63065195083618, 29.404658317565918, 37.046811716897146, 23.122760704585485, 17.00949934550694, 12.186859795025416, 26.901050397327968, 15.846631458827428, 1.0979369708469935, 2.535977840423584, 34.512108870915, 53.21575621196202, 50.04288216999599, 52.07512603487287, 46.46474402291434, 47.802786418369834, 46.06712293624878, 23.529652425221034, 2.0251345549310957, 0.10607035830616951, 6.353419763701303, 35.33236803327288, 51.74340861184256, 58.939546721322195, 56.34208427156721, 58.487239837646484, 57.139907700674875, 57.5194982119969, 55.05925573621477, 58.888046673366, 55.16003588267735, 56.12246561050415, 51.66476195199149, 44.858761719294954, 44.26490960802351, 48.53117649895804, 46.34582560403006, 47.68801607404436, 45.95122003555298, 48.46757616315569, 48.24650532858712, 47.940798486982075, 47.56684643881661, 44.928813457489014, 42.21654939651489, 40.549405574798584, 44.81728097370693, 38.7492732320513, 37.177642822265625, 27.06791659763881, 19.74916362762451, 30.906271730150493, 15.606539930616107, 2.566029016460691, 0.02937173517420888, 0.07343821826257876, 0.016121734199779372, 0.037159865123352835, 0.06718234930719648, 0.030825452346886908, 0.10798662262303488, 0.09255840549511568, 0.01812746505519109, 0.09612841571548156, 0.0670893085854394, 0.027509884276826466, 0.024322230235806534, 0.03903437239517059, 0.07424061306353126, 0.10880411482815232, 0.09999942407011986, 8.654604077339172, 3.5437493409429277, 0.19369170229349816, 0.08913071120956115, 0.04764383505763752, 0.017434499293033565, 0.06734764722308942, 0.06521889287978411, 0.060674927064350674, 0.033194937344108305, 0.05802625883370638, 0.024403245620695607, 0.11838194195713315, 0.10510816172297512, 0.3117759845086506, 10.96915933064052, 19.901980570384435, 24.894195250102452, 20.338059936250957, 28.992105552128383, 35.17859050205776, 42.78715283530099, 42.92277124949864, 45.22608866010393, 42.60553387233189, 45.47491407394409, 44.15490920203072, 40.90827308382307, 41.9084905896868, 42.896340302058626, 43.83773783275059, 42.07373264857701, 39.84361451012747, 39.20075675419399, 39.8704970904759, 47.01140396935599, 48.82130547932216, 50.347122941698345, 53.410771301814485, 51.05946615764073, 55.80008656638009, 55.448827334812705, 54.21296514783587, 51.57964651925223, 51.839008876255576, 34.96497161047799, 29.39271089008876, 8.087147303989955, 1.07608542910644, 3.9242326957838873, 19.32873681613377, 25.557294845581055, 33.345322200230186, 33.7232277733939, 38.28071451187134, 42.00836052213396, 42.41539641789028, 42.839761120932444, 50.36579622541155, 29.66015747615269, 0.5537255044494356, 1.05830303473132, 16.902606521333965, 47.147328104291645, 20.384109122412546, 25.05380231993539, 22.820696456091746, 26.479666471481323, 27.885009118488856, 27.363367898123606, 31.741709232330322, 27.4690934249333, 23.986611127853394, 39.535927431924, 30.42450795854841, 33.41853884288243, 41.83448185239519, 60.85206617627825, 32.94770458766392, 0.21745755417006357, 0.13104109838604927, 0.07833336666226387, 0.03070239323590483, 0.17435694193201406, 0.05046901060268283, 0.07036238509629454, 0.028188895966325487, 0.05236051178404263, 0.051507196322615655, 0.046833609962569814, 0.02227525462928627, 0.012341356071244394, 0.12334089300462178, 0.11146105440067393, 0.04168312544269221, 0.10901802299278122, 50.97314868654524, 74.27966839926583, 34.53373166493007, 37.25140489850725, 27.883814028331212, 32.10576009750366, 39.73185273579189, 32.88424668993269, 31.37760625566755, 33.122986793518066, 31.10890899385725, 31.887600558144705, 27.342846393585205, 27.928834881101334, 18.7209883076804, 31.605204922812327, 18.4310017653874, 3.3759475222655704, 2.165586526904787, 34.219596658434185, 58.67832224709647, 55.579272815159385, 57.281466824667795, 51.32123953955514, 50.846045289720806, 51.769433089665, 27.292133229119436, 3.983872558389391, 0.8969210258552006, 5.951300152710505, 33.51013694490705, 53.12556512015206, 60.45435128893171, 56.216829095567974, 60.908958026341026, 58.8988858631679, 59.34584263392857, 53.32038218634469, 60.9344231741769, 55.836040019989014, 58.06386872700283, 52.7369384765625, 48.32149723597935, 46.498665128435405, 50.52990572793143, 47.21665028163365, 50.62294558116368, 45.67828784670149, 49.8820834841047, 50.259134428841726, 51.486054284232004, 48.25376967021397, 48.320847579411094, 45.57688931056431, 45.54440300805228, 50.066096101488384, 44.63980313709804, 44.4671299798148, 26.533971854618617, 29.424790722983225, 37.324305398123606, 21.39621499606541, 3.048099594456809, 0.042175165111465115, 0.043757172900119, 0.05369784323764699, 0.07749650228236403, 0.017035490167992454, 0.06587840856185981, 0.020743716275319457, 0.049780545224036486, 0.07109287554132086, 0.03557326025994761, 0.03547235870999949, 0.10763404225664479, 0.09340782955821071, 0.0696992256811687, 0.004994980408810079, 0.008607415183048164, 0.04510157808129277, 0.5803771114775113, 5.978363820484706, 0.49587540009192055, 0.1315871426569564, 0.060925163993878026, 0.04990134820608156, 0.09627356114132063, 0.035386608847017796, 0.05432034483445542, 0.012739366901639317, 0.027057394717953036, 0.016467378241941333, 0.04701354048613991, 0.15252772399357387, 1.000762505190713, 13.240233625684466, 29.680300303867885, 34.36791637965611, 25.161492449896677, 30.881091458456858, 38.735727718898225, 44.191658224378315, 46.271000453404014, 47.98225143977574, 45.75146974836077, 47.11321939740862, 46.50323704310826, 43.08664798736572, 44.05901711327689, 44.2666014943804, 44.244551386152, 41.61354303359985, 42.24472434180123, 41.24829707826887, 41.47495079040527, 47.8152619089399, 49.85563516616821, 51.581307138715474, 51.900569915771484, 52.97163125446865, 57.51948084150042, 56.1095940726144, 54.69934947150094, 49.43831941059658, 50.335203307015554, 32.884972776685444, 26.946198054722377, 8.28026727267674, 2.0728020199707577, 8.71020529951368, 28.49171539715358, 28.7824992452349, 34.039106777736116, 42.05635172980172, 43.953307219914024, 47.001607009342735, 47.737264905657085, 48.02405875069754, 51.38511432920183, 27.490314960479736, 0.312409654791866, 3.0042421306882585, 18.059028216770717, 46.27517284665789, 28.656959193093435, 23.72473873410906, 24.386545964649745, 26.96991573061262, 29.77788427897862, 27.12907464163644, 27.348210402897426, 27.27372223990304, 27.381777150290354, 31.762456553322927, 33.7594313621521, 28.129123653684342, 40.89812176568167, 67.50997597830636, 37.935757296425955, 0.21404872994337762, 0.08443281972514731, 0.063910351667021, 0.039254048107458014, 0.08727414440363646, 0.04220392821090562, 0.11910099908709526, 0.17277533108634607, 0.2479458696075848, 0.08958128560334444, 0.13903802713113173, 0.1025400288136942, 0.15529187209904194, 0.2800051293202809, 0.14854191429913044, 0.1456259779099907, 0.38551499055964605, 62.903626033238, 85.70987892150879, 45.45585169110979, 42.672003814152305, 29.75020612989153, 34.778554916381836, 56.23041977201189, 46.94227981567383, 42.321380342756, 41.7227270262582, 41.06882510866438, 49.10492052350725, 29.750841890062603, 24.684126888002666, 13.458434854234968, 37.72831187929426, 19.833796160561697, 4.240664081914084, 5.083460594926562, 42.48894657407488, 63.9686598096575, 61.722161293029785, 63.12217467171805, 57.97110332761492, 58.31532750810896, 55.24027715410505, 30.220373358045304, 3.4310130817549567, 1.1083564460277557, 10.637398481369019, 40.876558031354634, 58.40873214176723, 65.71465178898403, 58.3462678364345, 64.19673442840576, 60.297016280038015, 63.83027253832136, 56.7887214251927, 61.748085021972656, 58.7143486567906, 61.44363580431257, 56.379059110369, 49.946371691567556, 49.127293722970144, 54.80368709564209, 51.6219402040754, 52.56319877079555, 49.59667233058384, 52.512383120400564, 52.20178822108677, 53.386831283569336, 50.39919621603829, 51.274127279009136, 48.42655399867466, 48.056930678231375, 52.622435637882774, 50.62063530513218, 45.22075939178467, 36.169209071568076, 31.84912143434797, 43.380546365465435, 27.206434147698538, 4.810052888734, 0.11455153035266058, 0.14179822616279125, 0.11082004915390696, 0.13568045943975449, 0.15818420904023306, 0.16409046282725676, 0.2693443128040859, 0.16789958200284413, 0.0798365320744259, 0.16630606965294906, 0.15261944835739477, 0.1706662813999823, 0.23887399211525917, 0.1406942361167499, 0.3000780407871519, 0.12883514032832213, 0.2832029020147664, 12.540126187460762, 6.498218051024845, 0.4331165019954954, 0.3268070550901549, 0.1698938642761537, 0.15502779984048434, 0.16712575352617673, 0.14601825257497175, 0.1129544624792678, 0.10803723455007587, 0.10811012278177909, 0.1314898543059826, 0.2062272025006158, 0.40318263109241215, 5.603313088417053, 20.510760886328562, 29.54582486833845, 36.570047174181255, 30.079130377088273, 37.96802473068237, 44.5716621535165, 48.73559250150408, 47.014721734183176, 49.020979336329866, 45.52211318697248, 48.784365381513325, 47.18766587121146, 45.283320971897666, 46.54782015936715, 46.24387468610491, 48.46095452989851, 45.537051813943044, 42.77297503607613, 43.41920614242554, 44.28694929395403, 50.74841615131923, 50.36215884344918, 52.27434478487287, 56.013000215802876, 54.89678948266165, 59.4963058744158, 59.3429730279105, 57.481429031917024, 54.25458138329642, 54.65917498724801, 37.87810461861746, 33.901063442230225, 11.173841101782662, 2.2054246749196733, 5.810078450611659, 26.21847673824855, 34.857222420828684, 39.48355538504464, 42.36470583506993, 47.19484336035592, 51.12937545776367, 53.689595563071116, 51.81563861029488, 57.59210341317313, 35.16898461750576, 2.04800346493721, 2.695190165724073, 20.516784974506923, 54.949828556605745, 29.054345778056554, 33.883904865809846, 31.207159996032715, 35.18562207903181, 38.292338848114014, 37.593933718545095, 42.16568510872977, 38.81519079208374, 32.290797574179514, 51.098035608019146, 42.97511550358364, 46.226069927215576, 55.264960629599436, 74.97045830317906, 49.536622524261475, 0.24912782332726888, 0.21734290889331273, 0.16957248294992106, 0.16168155494545186, 0.19432203418442182, 0.2728219676230635], [0.08561161147164446, 0.04605452623218298, 0.04487729850890381, 0.026920841241787587, 0.03468290017917752, 0.05766223158155169, 0.10176177628870521, 0.026828758950744356, 0.05211151657359941, 0.1644302595938955, 0.0971863671605076, 23.239016226359777, 66.9150642667498, 43.80310453687395, 26.295573949813843, 43.190280369349885, 24.794743946620397, 32.36622026988438, 41.944659437452046, 31.24766799381801, 29.5953585760934, 27.884953532900127, 34.391512462071006, 32.06179189682007, 11.501444322722298, 22.4655636038099, 31.154357160840714, 26.763319730758667, 2.7567145100661685, 0.8578340975301606, 19.054934365408762, 62.69873060498919, 52.55426686150687, 58.92023767743792, 54.1675135067531, 51.03613063267299, 38.570235524858745, 37.36909348624093, 22.138456310544694, 4.846564369542258, 0.9209686326129096, 11.234602229935781, 41.17939526694161, 53.10653053011213, 56.23593316759382, 59.47603103092739, 59.6685517174857, 53.78006110872541, 52.466017791203086, 56.70706966945103, 57.41799545288086, 54.44925948551723, 50.111794403621126, 44.3383138520377, 45.55522830145699, 49.413208620888845, 48.48710754939488, 47.27190235682896, 44.97830547605242, 46.255950655256, 48.540400232587544, 47.09103032520839, 47.419683592660085, 46.83819580078125, 43.36438832964216, 47.21200541087559, 42.24249049595424, 39.69153233936855, 35.55028785978045, 15.650409119469778, 33.79990461894444, 26.448168550218853, 16.240894828523906, 2.059609127896173, 0.05980408165071692, 0.1466245236141341, 0.03322334081998893, 0.03513387830129691, 0.00986902043223381, 0.04366639169997402, 0.08385461967970644, 0.014617186272516847, 0.04307625283088003, 0.004486729266188506, 0.06820902028786284, 0.07918916895453419, 0.05546982047547187, 0.03508411454302924, 0.07112094653504235, 0.143425746687821, 0.22776251978107862, 2.6406856732709065, 4.6767929536955695, 0.3730187639594078, 0.2414770967194012, 0.06895782439304249, 0.034446552861481905, 0.05264373230082648, 0.05260524579456874, 0.10541369247117213, 0.0546154498920909, 0.07333331674869571, 0.045922442605452876, 0.017896814038977027, 0.34466769812362535, 1.1705326182501656, 7.818308472633362, 9.299980555261884, 27.67715723173959, 28.131291491644724, 18.478305101394653, 27.108676467623027, 34.49684367861067, 43.53266327721732, 46.55023813247681, 44.04293898173741, 44.59148188999721, 43.64356347492763, 43.610153062003, 41.61714914866856, 39.51161221095494, 41.87202296938215, 40.87491825648716, 40.22890254429409, 42.25960738318307, 43.46015535082136, 45.30271339416504, 51.75301449639456, 52.99792671203613, 53.003749302455354, 47.13963644845145, 58.477936199733186, 53.20823131288801, 41.520854064396445, 35.716328961508616, 34.32307618004935, 21.280360732759746, 11.806277428354536, 5.974190558706011, 8.038697515215192, 28.77575601850237, 43.94486515862601, 38.99219962528774, 53.19612060274397, 33.27851527077811, 36.60900224958147, 51.66587713786534, 50.22985124588013, 47.102039745875764, 48.50637142998831, 11.68512429509844, 0.09136630089155265, 2.7180586414677754, 24.672073500497, 39.85615253448486, 12.494103925568716, 24.383810111454554, 24.35540066446577, 28.462454795837402, 25.43691556794303, 26.056910276412964, 35.91365780149187, 29.164552892957413, 30.44229187284197, 43.49170364652361, 28.704528297696793, 38.186135632651194, 45.384740352630615, 60.4333746773856, 20.41480278968811, 0.27251133429152624, 0.13897564262151718, 0.1256744156458548, 0.11278441481824432, 0.1350286722715412, 0.03421172206955297, 0.1195099385721343, 0.04349749754848225, 0.045111952881727896, 0.004829882660747639, 0.04947251068162067, 0.07934588340244123, 0.04991764661722949, 0.035413058142044714, 0.034291368510041914, 0.10535804581429277, 0.10547165293246508, 30.21063198362078, 78.96688147953579, 37.39830718721662, 28.252122402191162, 43.57934127535139, 30.91829558781215, 31.453730719430105, 32.12841122491019, 30.295309679848806, 28.69443256514413, 33.665074825286865, 32.86492027555193, 30.8337915965489, 20.014557021004812, 25.816622461591447, 31.281599521636963, 28.99679732322693, 6.607981784003122, 0.9217795091015952, 20.01560272489275, 69.55220440455845, 61.613060678754536, 61.45356478009905, 60.174512590680806, 57.71605232783726, 44.52862501144409, 45.39817469460623, 29.835908685411724, 9.699280500411987, 1.8042723834514618, 9.664725371769496, 38.381925446646555, 54.823079517909456, 57.79102686473301, 58.91615213666643, 60.263671875, 54.1783561706543, 51.49217217309134, 57.17126839501517, 59.70279244014195, 55.85269137791225, 51.53628976004464, 46.514194352286204, 50.089963163648335, 50.08495698656355, 49.18795149666922, 49.26881463187081, 47.00188493728638, 47.98156704221453, 50.191313062395366, 49.45400844301496, 51.03443874631609, 49.365057604653494, 48.16326590946743, 52.62774058750698, 43.99780348369053, 48.35694694519043, 33.36081668308803, 28.158893210547312, 46.09603091648647, 28.8054005077907, 17.152192762919835, 5.719738841056824, 0.05596029951370188, 0.09076844368662153, 0.06431009021720716, 0.008223230351826974, 0.03853111654253943, 0.05261231952213815, 0.12443861338709082, 0.05690691354019301, 0.10929143867854561, 0.038169735576957464, 0.08997263067534991, 0.03842435923538037, 0.06458324127431427, 0.04110786006120699, 0.11845299814428602, 0.048410925681569746, 0.04907096383560981, 0.22133268123226507, 7.07386805330004, 0.22813443839550018, 0.150618027895689, 0.08175315601485116, 0.020022962807810733, 0.02223613708546119, 0.08928645535239152, 0.0776539020506399, 0.07276203776044504, 0.05991679310266461, 0.05967142126922097, 0.030568318108894994, 0.10335014534315892, 0.5082424879074097, 8.932937622070312, 14.858634097235543, 36.98374291828701, 36.4767085484096, 23.060523952756608, 25.534942490713938, 39.22947365897042, 43.4697299684797, 46.99099711009434, 48.601436683109824, 45.390517779758994, 47.798721722194124, 45.08242423193795, 46.292560713631765, 42.32001154763358, 43.87425409044538, 42.02574144090925, 44.44865819386074, 42.75561843599592, 43.00367954799107, 46.49745961597988, 53.04720333644322, 52.569639750889365, 52.83863925933838, 47.3500383240836, 58.25031321389334, 50.83810697283064, 38.98934391566685, 34.87094858714512, 31.695712157658168, 17.341202872140066, 10.475658314568655, 8.198722345488411, 13.496048927307129, 37.40228850500924, 48.833638531821116, 43.10746479034424, 54.359367166246685, 36.98787709644863, 40.269935131073, 55.83522013255528, 54.64966985157558, 50.539077350071494, 49.83307089124407, 10.087141973631722, 0.17129539192787238, 8.980880192347936, 24.739375489098684, 42.62410988126482, 18.755595547812327, 23.798726626804896, 21.543944120407104, 29.698313508714946, 26.647008623395646, 26.16676824433463, 29.975070680890763, 30.789924144744873, 29.653653962271555, 36.62862743650164, 37.03218923296247, 44.09993158067976, 46.80823169435774, 69.80076231275285, 26.53018856048584, 0.23654292577079364, 0.009742923180705734, 0.08459583776337759, 0.06271292734891176, 0.14529270865023136, 0.04995535959356597, 0.24678883169378552, 0.2160877412451165, 0.13456547712641104, 0.1098862017637917, 0.16829056745128973, 0.12518942595592567, 0.21064104565552302, 0.13767962716519833, 0.15033946212913307, 0.2871866896748543, 0.23615203531725065, 39.7135511807033, 92.10296508244106, 55.83480324063982, 38.45672280447823, 55.129651410239084, 34.21508032935006, 41.435617038181846, 56.47877965654646, 41.00848000390189, 38.79988391058785, 38.772883210863384, 48.40291970116751, 43.93637793404715, 15.329185213361468, 30.26192011151995, 41.26069266455514, 32.76638787133353, 5.812606726373945, 2.33932340996606, 24.846747738974436, 71.71092632838658, 66.43428366524833, 68.56291988917759, 63.977504866463796, 61.00897734505789, 50.36036968231201, 47.20971597943987, 27.289192404065812, 8.118802428245544, 2.4384822377136777, 15.111826453890119, 45.734092303684776, 59.86842359815325, 61.936798095703125, 62.63244479043143, 61.43103872026716, 54.54957062857491, 52.47141654150826, 58.14127165930611, 63.46925803593227, 58.71038818359375, 56.7861054284232, 50.9868609564645, 51.96285009384155, 52.67480421066284, 51.90795932497297, 51.242287158966064, 48.10461616516113, 51.517362867082866, 51.19502203805106, 52.35811921528408, 53.19074617113386, 52.12654965264456, 50.339862074170796, 55.17679146357945, 52.926273414066856, 47.05971826825823, 47.870979513440815, 27.081778253827775, 44.10618495941162, 36.77297626222883, 21.55922842025757, 5.755337502275195, 0.10309954879007169, 0.1453523790197713, 0.15645144773381098, 0.1687297560274601, 0.15105127250509603, 0.16694244050553866, 0.15840842415179524, 0.10177389492413827, 0.18563959508069924, 0.17163361449326786, 0.2167683390102216, 0.12461557531995432, 0.18750286581260817, 0.08085006661713123, 0.23743172522102082, 0.31658297085336273, 0.31283547622816904, 3.4301313119275227, 15.051430974687849, 0.4244877078703472, 0.3559061107890946, 0.11375293534781251, 0.2680207352553095, 0.2096683249941894, 0.0912643645757011, 0.1671464352735451, 0.14076943136751652, 0.14671778146709713, 0.10776514879294805, 0.12334596844656126, 0.847888456923621, 5.444551961762564, 15.901200873511177, 17.29713044847761, 36.68381697790963, 37.686855452401296, 27.97224027769906, 33.7537442616054, 41.118070466177805, 46.94674055916922, 47.660998003823416, 50.78514780317034, 47.32233238220215, 48.816222872052876, 47.29348693575178, 46.71477147511074, 43.164724894932334, 44.56774336951119, 44.0339549609593, 43.85839830126081, 45.12694134031023, 45.56827701841082, 49.237579005105154, 56.88170221873692, 55.46655566351754, 54.67960269110543, 48.14593015398298, 59.934466225760325, 56.63441930498396, 44.650934151240754, 40.89682592664446, 39.24146972383772, 22.105672972542898, 14.44546033654894, 9.446490270750862, 10.85229410443987, 35.44962583269392, 51.2554018838065, 46.88931369781494, 61.45359257289341, 39.93970809664045, 44.32480307987758, 62.407934597560335, 60.15799672263009, 55.29807921818325, 57.20041956220354, 15.385498625891548, 0.8841239639690944, 5.611870663506644, 30.030989783150808, 46.57927465438843, 16.67572351864406, 32.666966097695486, 32.41803298677717, 36.966257776532856, 34.35223429543631, 35.416385650634766, 47.02363279887608, 41.74159485953194, 39.33669825962612, 58.85826669420515, 41.2265179497855, 51.43911920275007, 59.01480960845947, 77.66330214909145, 34.25045360837664, 0.5763475905571664, 0.4209273803446974, 0.24772938979523523, 0.2710203214415482, 0.20889294945767947, 0.21504757420292922], [0.07494191971740552, 0.04835354536771774, 0.06048963272145816, 0.044197599802698405, 0.05872129582400833, 0.02213357312471739, 0.015954907883756926, 0.08188813698611089, 0.04846793958651168, 0.03362029737659863, 0.05508851772174239, 10.016721980912344, 73.08810097830636, 48.802739892687114, 29.15183421543666, 32.03347798756191, 45.632502692086355, 40.25542034421648, 45.25811985560826, 33.85706050055367, 34.77385793413435, 30.57026032039097, 26.079273053577968, 39.253865310123985, 23.57383602006095, 28.36649669919695, 36.4707087789263, 26.820218529020035, 9.556836349623543, 0.3926080699477877, 14.394272089004517, 42.812465122767854, 52.162937368665425, 49.45499161311558, 46.6576155935015, 45.73095519202096, 37.9624696459089, 35.19126401628767, 45.487983635493684, 22.268217393330165, 2.8987702131271362, 2.5090348975999013, 15.202060971941266, 42.43986449922834, 45.926967348371235, 46.01243713923863, 48.75814288003104, 48.30466175079346, 53.92266246250698, 55.27515711103167, 54.63487018857683, 54.842760290418354, 46.50121511731829, 44.461491516658235, 49.551637581416536, 49.42621912275042, 50.68410015106201, 50.09747764042446, 48.05831336975098, 46.945740018572124, 48.743350165230886, 46.87994752611433, 48.465787002018516, 44.79392807824271, 47.2429700578962, 42.97980901173183, 39.62306826455252, 40.71346991402762, 22.43608934538705, 35.69121469770159, 24.75984835624695, 13.064607484000069, 16.702989986964635, 3.950302771159581, 0.057165815361908505, 0.05064981982910207, 0.08656973005937678, 0.036210397857108285, 0.17567868743624004, 0.031226924554045712, 0.062061350526554246, 0.06923237323228802, 0.06700489204376936, 0.02524230506138078, 0.028883332453135933, 0.03279284088473235, 0.007826737743536276, 0.027945576701313257, 0.031584122351237705, 0.056415138500077386, 0.02365890288326357, 0.008946394314989448, 5.224137731960841, 0.22839670575090817, 0.06235080678015947, 0.012134128932042845, 0.0641675435804895, 0.11372160738600151, 0.10661098786762782, 0.05385471035593322, 0.1089687409943768, 0.04418457193034036, 0.08048645327133791, 0.016374646253617745, 0.4575230809194701, 0.3889405610305922, 7.299701009477888, 6.400940665176936, 4.22343168088368, 24.011094842638286, 23.279322726385935, 15.2237480367933, 32.310857023511616, 39.40670830862862, 45.100086552756174, 44.95274305343628, 49.15458624703543, 43.80828789302281, 43.407234396253315, 43.327038288116455, 43.04418754577637, 43.00370734078543, 41.379381792885916, 44.017314025333945, 42.86582381384713, 42.06148297446114, 47.65431036267962, 51.43911920275007, 51.33948203495571, 53.94938176018851, 48.031402996608186, 50.02830832345145, 33.85231835501534, 26.598979200635636, 20.167803015027726, 16.365569829940796, 7.468246936798096, 3.7282335673059737, 18.256018332072667, 30.3120722089495, 40.92850276402065, 41.739496503557476, 52.24177162987845, 44.83063541139875, 40.49695014953613, 50.077022143772666, 44.095554215567454, 48.57285179410662, 45.35096515927996, 42.326407364436555, 2.4422121175697873, 0.6768203335148948, 3.264168377433504, 35.474559443337576, 23.660028423581803, 19.12045761517116, 26.485497747148784, 24.91655281611851, 28.909616538456508, 31.200104100363596, 27.88828866822379, 33.517651421683176, 24.05072389330183, 35.38712331226894, 35.873604910714285, 23.100783552442277, 27.706150327410015, 42.71571145738874, 61.40401717594692, 15.488844394683838, 0.3758187251431601, 0.20337867178022861, 0.054333840895976336, 0.05518921231850982, 0.011975777518403317, 0.11544376319008214, 0.05690965821434345, 0.055361991082983356, 0.12188496041510787, 0.034243932126888206, 0.13581592217087746, 0.047724970882492404, 0.08717805027429547, 0.036058674034263404, 0.11777742153831891, 0.07430975578193154, 0.28895856173975126, 13.523995450564794, 84.93040915897915, 50.86597272327968, 23.387431485312327, 33.860381739480154, 39.66279111589704, 44.148291042872835, 32.95213059016636, 28.970328160694667, 33.83307531901768, 31.118879658835276, 32.97800915581839, 32.105624607631135, 28.853103365216935, 32.06378950391497, 31.33423560006278, 28.77282214164734, 11.005707723753792, 0.44190933874675203, 14.878314869744436, 52.10119220188686, 58.138520172664094, 55.532445430755615, 50.02159636361258, 49.177004609789165, 46.002720083509175, 38.734984261649, 50.34528166907174, 29.57680688585554, 6.696759351662227, 3.654504495007651, 13.400183762822833, 41.19643572398594, 44.98211308888027, 43.727671418871196, 48.628128187997, 46.72436693736485, 52.350347655160085, 58.950205257960725, 55.680914538247244, 55.2811290877206, 48.26369864600045, 46.42806795665196, 50.09692873273577, 51.16027757099697, 52.5540896824428, 50.11983346939087, 48.32840027127947, 49.33097321646554, 50.009106976645334, 49.23025212969099, 49.820307050432476, 49.56261920928955, 51.2544013432094, 46.170098713466096, 47.43912812641689, 41.00581884384155, 31.803582940782817, 48.878690651484895, 31.239986760275706, 18.65665146282741, 19.717392989567347, 3.873415742601667, 0.16251881287566253, 0.012130989859412824, 0.04740650047148977, 0.028338602843827436, 0.06915967499039002, 0.04066100403932588, 0.06282941145556313, 0.051978876548154015, 0.08945173969758408, 0.015111682238057256, 0.02177378671642925, 0.04734793611403022, 0.015331452945247293, 0.012029138360438603, 0.005742315909758742, 0.06904194237930433, 0.02284465407553528, 0.09121171704360417, 5.342033897127424, 0.08306372604732003, 0.04396311167095389, 0.03105715848505497, 0.044920514404241524, 0.058282392232545784, 0.1412402939583574, 0.03995521226897836, 0.12280945080731596, 0.01479907097694065, 0.15881204392228807, 0.057112930342555046, 0.5741696559957096, 1.0309301721198219, 14.395672151020594, 15.895383494240896, 12.443924903869629, 32.04402535302298, 34.89834533418928, 18.695015941347393, 29.42095184326172, 42.75202969142369, 47.18723855699812, 47.790550640651155, 50.49961853027344, 47.63693986620222, 45.02937820979527, 43.830761841365266, 45.18098095485142, 45.072516100747244, 43.76692179271153, 46.048272473471506, 44.05856895446777, 44.84269053595406, 49.993028845105854, 50.8781772341047, 51.05252143314907, 54.377366474696565, 49.85089302062988, 48.79062570844378, 34.20662089756557, 24.75439923150199, 18.972938673836843, 14.862830809184484, 6.047299938542502, 5.280076376029423, 25.640563794544764, 38.9462650844029, 44.76336990083967, 45.64705221993582, 53.105648108891074, 49.751954146793906, 40.155769280024934, 50.26516546521868, 49.134627546582905, 50.14423554284232, 49.26261683872768, 42.6943735395159, 1.4769416621753146, 1.2716939385448183, 8.22073337009975, 32.852927684783936, 30.533424445561, 22.47923939568656, 26.02545404434204, 22.606665883745464, 29.87892845698765, 30.17803450993129, 28.575878926685878, 27.272537572043284, 26.34497216769627, 33.56394379479544, 34.15023626599993, 29.846101692744664, 30.937159946986608, 47.37476348876953, 68.5562218257359, 20.019505875451223, 0.6103823099817548, 0.07726423296013049, 0.14236811415425368, 0.02153217057431383, 0.036615734321198294, 0.05227114532941154, 0.20209100230463914, 0.23313133312123163, 0.16430426921163285, 0.1375027737979378, 0.4211750456265041, 0.19762074574828148, 0.2855640138898577, 0.1501143513513463, 0.3815636640148503, 0.21128488039331778, 0.6046619883605412, 17.920312643051147, 97.14214611053467, 62.82989869798933, 41.961276054382324, 44.11793088912964, 57.93172788619995, 49.83421386991228, 59.24030644553048, 42.47136763163975, 45.89097915376936, 40.96298667362758, 37.7488820212228, 53.85360779081072, 30.657331671033585, 41.023880686078755, 47.17250142778669, 32.97355188642229, 13.825158170291356, 1.0622931463377816, 19.79874423571995, 53.4335857118879, 63.658471379961284, 61.92151205880301, 58.35289641789028, 54.03829090935843, 45.796236991882324, 43.709463664463584, 57.48084190913609, 28.488878795078822, 4.702859554971967, 4.0491096292223245, 19.973491430282593, 49.52374403817313, 51.529230390276226, 48.19437646865845, 52.01136589050293, 51.498112882886616, 54.817514010838096, 59.72585351126534, 58.92551136016846, 59.00002384185791, 48.93867097582136, 48.10251086098807, 53.85409416471209, 54.178380489349365, 56.9288318497794, 54.26027543204171, 51.055953843253, 52.37209551674979, 53.11717864445278, 51.55320862361363, 50.75868558883667, 53.14476299285889, 53.93228224345616, 53.511384691510884, 47.09897559029715, 49.26759869711739, 32.39437089647566, 48.35425451823643, 35.19489097595215, 19.498641116278513, 23.63839520726885, 9.372165390423365, 0.20379848139626638, 0.08651015468473945, 0.1545408559697015, 0.08456868279193129, 0.21814964631838457, 0.20361002508018697, 0.2767460442015103, 0.15762258560529777, 0.1921653649104493, 0.17942459428949015, 0.10821919728602682, 0.10022982742105212, 0.17732675400163445, 0.08568475076130458, 0.10708743480167218, 0.13243033098323004, 0.11308983021548816, 0.12074792571365833, 12.900268690926687, 0.18279753758438996, 0.10522301734558173, 0.0658019512359585, 0.1286571877343314, 0.12340585594730717, 0.19271435402333736, 0.0870031782292894, 0.30806708495531765, 0.1621205128197159, 0.23758005297609738, 0.18324921120490345, 1.1207756996154785, 4.409543522766658, 16.481920889445714, 13.500877056803022, 10.069575190544128, 34.51989780153547, 34.90615858350481, 22.73848189626421, 39.77784981046404, 42.70083883830479, 49.75944777897426, 47.74315350396292, 53.4154509135655, 46.599473067692344, 47.823016098567415, 46.06782470430647, 48.94375010899135, 47.26927246366228, 44.7372898374285, 48.46867397853306, 45.83008166721889, 45.566112654549734, 51.582147870744976, 52.916643210819785, 52.109332016536165, 55.732546601976665, 50.03958872386387, 52.750661168779644, 40.2365733555385, 28.560816969190324, 23.90239896093096, 19.22643675122942, 10.337979759488787, 6.70433201960155, 24.88369652203151, 35.79259238924299, 48.81516327176775, 53.05891799926758, 59.99918869563511, 54.3667357308524, 44.969408307756694, 58.86035810198103, 51.64028344835554, 57.40968540736607, 50.96409865788051, 50.41773400987898, 3.7947230509349277, 1.7780215463468005, 5.371753948075431, 40.794777733939036, 29.92258746283395, 25.20237912450518, 36.577440057482036, 34.69289057595389, 37.8073719569615, 40.33366748264858, 37.787802355630056, 43.98923635482788, 33.46670375551496, 44.41083220073155, 48.026806763240266, 29.444596563066753, 38.19318805422102, 55.50691774913243, 77.65020479474748, 25.982385635375977, 0.9410513149840491, 0.5587206621255193, 0.26340433582663536, 0.17890685849956103, 0.15279035775789193, 0.11255060522151844], [0.07398768234997988, 0.06692638554211174, 0.013211137881236417, 0.03379194298759103, 0.05886031407862902, 0.025225680953423892, 0.015605703229084611, 0.06200183622006859, 0.06757255444037062, 0.07997909228184394, 0.046129928436130285, 1.3891049240316664, 56.31466320582798, 50.96326834814889, 42.786225250789094, 36.67493370601109, 48.30895921162197, 32.38510547365461, 37.47473389761788, 32.10193511417934, 38.35866287776402, 37.15391819817679, 27.317937101636613, 33.2443961415972, 33.14851794924055, 19.678403173174175, 41.39771114076887, 27.03486749104091, 15.706208365304128, 0.688414705651147, 5.420722246170044, 36.98642839704241, 38.03120470046997, 56.850553444453645, 55.54519190107073, 58.76605715070452, 53.57618011747088, 35.28858048575265, 54.28939880643572, 46.98792600631714, 15.958250795091901, 9.245754207883563, 7.6751017570495605, 18.2586065360478, 30.62773929323469, 23.65243751662118, 27.224037408828735, 32.27201311928885, 49.96124431065151, 58.0007825578962, 54.99504395893642, 53.952991349356516, 48.32351916176932, 47.03318657193865, 50.17358473369053, 50.89797265189034, 49.45472410746983, 49.87896374293736, 47.05599750791277, 48.1185542515346, 49.105358260018484, 48.70897742680141, 49.694423062460764, 46.97415815080915, 42.65385511943272, 42.74532815388271, 46.80212075369698, 27.43781089782715, 19.620073046003068, 10.090494479451861, 3.3891339004039764, 24.592309917722428, 18.50878163746425, 3.2135457566806247, 0.23900231665798596, 0.0316150499773877, 0.22270020070884908, 0.04441433406567999, 0.03384744715211647, 0.0518248592769461, 0.054255660091127665, 0.11805726295070988, 0.04149053006299904, 0.07292000749813658, 0.021682566164859703, 0.012000762025958725, 0.041031141499323506, 0.04976360898997102, 0.013718713457430047, 0.05115622408421976, 0.047039619979581664, 0.18123312081609452, 3.4137485453060696, 0.2692742608487606, 0.05079413404954331, 0.0532633806578815, 0.024330998604585017, 0.027930316448743855, 0.00436288517500673, 0.070746707330857, 0.0010257725578932358, 0.03318539374907102, 0.04332452540152839, 0.03214860241860151, 0.1236940569111279, 2.2623026285852705, 10.357499854905264, 29.15601703098842, 5.97558193547385, 2.2153113101209914, 12.778435502733503, 13.969097920826503, 15.638922010149274, 36.62428828648159, 43.44083935873849, 46.55036667415074, 46.99340466090611, 45.01694788251604, 46.72550296783447, 44.76206016540527, 45.42847578866141, 46.03407730375017, 44.568518093654085, 44.15787608282906, 42.88699844905308, 43.10915320260184, 49.97009284155709, 51.4095824105399, 52.42178555897304, 52.80640656607491, 51.21531425203596, 41.07163565499442, 16.478604861668178, 14.21529517854963, 11.096509388514928, 6.214700715882437, 2.044556724173682, 11.066441059112549, 38.0928178514753, 37.01555177143642, 40.012136118752615, 44.23570285524641, 45.49171134403774, 44.98774807793753, 59.144984109061106, 60.594420024326865, 49.81258412769863, 46.80401413781302, 51.966206073760986, 19.537630932671682, 0.24698332697153091, 0.3663192077406815, 16.273509672709874, 44.60483285358974, 13.340958186558314, 26.28775201525007, 24.573181527001516, 27.10718607902527, 28.66508511134556, 31.971805776868546, 29.39440277644566, 34.61337191717965, 22.97130560874939, 35.534164564950125, 31.18923364366804, 25.09498255593436, 35.61852959224156, 37.86016436985561, 61.28075613294329, 7.43477920123509, 0.27728352536048206, 0.023672473583636538, 0.10257667649005141, 0.0928935000140752, 0.034960356540977955, 0.09668377627219472, 0.1360876483044454, 0.026454696165663854, 0.03305952550311174, 0.02523358249371605, 0.05455477868339845, 0.046616346442273686, 0.14292725415102073, 0.06766834322895322, 0.053406470122614076, 0.02567251831559198, 0.10923154439244952, 2.241942886795316, 66.71542862483433, 59.59406702859061, 34.93270417622158, 44.192617075783865, 43.27648319516863, 42.83482442583357, 35.21333496911185, 29.613100801195415, 41.83638913290841, 33.32072557721819, 32.48292568751744, 32.49100991657802, 28.366225719451904, 28.94361060006278, 36.02088935034615, 26.432496888296946, 17.061365910938807, 2.0779402128287723, 3.0110426800591603, 34.520818437848774, 43.03061771392822, 60.433763776506694, 59.24171692984444, 64.54371356964111, 55.235375199999126, 43.7054580279759, 59.385183334350586, 52.09743322644915, 23.95785253388541, 14.901054586683001, 10.361376081194196, 17.544802461351665, 28.632767302649363, 21.96873266356332, 27.09090644972665, 30.642413888658794, 54.205923148563926, 57.430509158543174, 57.05899592808315, 55.35072571890694, 53.24954182761056, 47.28218221664429, 51.871620246342246, 49.51905400412423, 50.677964891706196, 48.667277812957764, 48.942746094294954, 48.485578945704866, 49.86731856209891, 52.18910428455898, 52.7880528994969, 48.61488144738333, 45.40537302834647, 49.72785431998116, 41.98202337537493, 33.83971432277134, 30.26442493711199, 15.812753779547554, 8.45904529094696, 29.669600078037806, 26.674914325986588, 5.05327935729708, 0.3051016969340188, 0.0758237506129912, 0.07032659237406083, 0.022330120970894183, 0.03905343583651951, 0.06780405701803309, 0.02886676262798054, 0.04209274346274989, 0.023135735420510173, 0.01911721864183034, 0.015817316249012947, 0.049387235793152025, 0.04157744700621281, 0.015853875715817724, 0.08536458401275532, 0.045891182497143745, 0.05005297364134874, 0.13677257512296948, 3.3705904611519406, 0.13179641642740794, 0.06323355369802032, 0.06790673293705497, 0.04347917031762855, 0.022356610978022218, 0.01016065223874258, 0.05145138681733182, 0.046775374694594314, 0.05871421191841364, 0.0838556374822344, 0.11556797581059591, 0.18160064252359526, 7.151953211852482, 18.010882411684307, 28.547003950391495, 14.176275832312447, 6.145768071923937, 21.311393124716624, 25.5469229221344, 15.631713254111153, 33.427526337759836, 46.93065547943115, 49.1142623765128, 47.29260451453072, 47.0928681237357, 47.428368840898784, 46.70789623260498, 45.62062474659511, 47.37164027350289, 45.69361904689244, 46.22839757374355, 43.915707043239046, 44.76927934374128, 49.88749613080706, 53.8148125239781, 53.78733239855085, 52.377907684871126, 50.719723565237864, 41.91103710447039, 15.495148147855486, 11.648011360849653, 9.390958530562264, 6.5401191626276285, 3.462807387113571, 17.40238697188241, 42.940725394657676, 40.880313532693044, 43.26617554255894, 48.882241180964876, 51.22905084065029, 50.661806855882915, 56.69611236027309, 58.151780809674946, 51.200827257973806, 55.266871384211946, 52.73141118458339, 13.09706859929221, 0.6232382144246782, 2.2295529459203993, 17.74994628770011, 40.06858328410557, 20.709731238228933, 26.58362020765032, 24.079901116234915, 24.078485420772008, 30.296133041381836, 29.814431803567068, 28.80982824734279, 27.823831966945104, 27.66325388635908, 26.91104711805071, 31.008702073778423, 27.515754052570887, 31.069964340754918, 44.36873306546892, 67.442613192967, 10.365933230945043, 0.41541667176144464, 0.06945576731647764, 0.06420327523457152, 0.05416310112923384, 0.07296964233475071, 0.020551214194191352, 0.23597417771816254, 0.07307374996266194, 0.14813496970704623, 0.10894748927759272, 0.24650493264198303, 0.12558863524879726, 0.264044927167041, 0.17168655379542283, 0.11710582114756107, 0.20027362768139156, 0.15106109769216605, 3.6678923709051947, 81.89828477587018, 69.1577343259539, 56.78883607046944, 50.913078035627095, 65.72192655290876, 40.40368447984968, 49.8198241506304, 46.23229203905378, 49.73488242285592, 52.088529109954834, 37.03596210479736, 46.0199099268232, 43.032222747802734, 28.45231737409319, 55.80743081229073, 32.49688809258597, 19.63628145626613, 2.76843329838344, 9.849692497934614, 47.218456813267295, 48.896717752729145, 64.38957473209926, 61.70913342067173, 63.73517254420689, 56.90160880770002, 49.12462908881051, 65.24004118783134, 56.57284089497158, 21.765525647572108, 12.817633765084402, 9.47533484867641, 22.915513311113628, 37.37459298542568, 28.76338996206011, 31.451142515454972, 32.90946517671858, 55.54041154044015, 61.34891101292202, 59.30925342014858, 57.6600706917899, 55.761770725250244, 51.32745122909546, 54.45975821358817, 53.377353940691265, 52.38535615376064, 52.486032077244346, 50.044497626168386, 52.116801330021445, 52.40478679112026, 55.54925659724644, 58.62457793099539, 50.213821751730784, 50.669755595070974, 49.8641745022365, 52.94105223246983, 35.71782282420567, 30.729780537741526, 17.013152360916138, 6.059343772275107, 34.64554207665579, 23.893003259386333, 5.821472193513598, 0.2861484768135207, 0.20289750902780465, 0.35211163439920967, 0.14719260670244694, 0.13738667645624705, 0.19565607474318572, 0.08856142032891512, 0.17491153574415616, 0.20664119028619357, 0.19893057617758, 0.17915137537888118, 0.18064762651920319, 0.15430658496916294, 0.19542917263294968, 0.21584949402936868, 0.17885845181133064, 0.151802817891751, 0.31927485497934477, 9.72245100566319, 0.4857566516314234, 0.21574250262762817, 0.19740474091044494, 0.13280906208923884, 0.10680950007268361, 0.116376504568117, 0.1097735920920968, 0.14326935793672288, 0.12755280413797923, 0.15573791387890065, 0.17895084113946982, 0.1969011186489037, 7.542180980954852, 21.583482844488962, 49.187920229775564, 12.949009435517446, 3.1179140082427432, 20.55291908127921, 23.758017131260463, 19.36315471785409, 42.66597625187465, 48.15991340364729, 49.83446747916085, 50.16779341016497, 49.63210466929844, 49.10623720714024, 49.474939891270225, 49.00590869358608, 48.774127210889546, 47.76938990184239, 47.87227882657732, 46.2590252331325, 46.689514773232595, 53.20252684184483, 57.08963748386928, 56.24469484601702, 54.20965085710798, 52.36319834845406, 45.67756870814732, 20.295073168618337, 15.24843498638698, 13.977112667901174, 9.326177869524274, 3.8263985855238776, 16.74325827189854, 43.943791661943706, 43.362977845328196, 49.17885283061436, 52.75475365774972, 54.235894203186035, 52.43873221533639, 64.47974150521415, 65.30248464856828, 56.05098601749965, 55.56610597882952, 60.79134586879185, 25.55243805476597, 1.3103347165243966, 1.3787124816860472, 20.635644333703176, 56.57372679029192, 18.428396190915787, 36.43592609677996, 33.653780528477256, 35.599140644073486, 37.724511214665, 41.79147597721645, 39.09520666939871, 48.25891481127058, 31.986574172973633, 46.04570163999285, 41.410242216927664, 35.410142694200786, 48.23926877975464, 51.339367389678955, 77.90434905460903, 14.040528007916041, 0.8298529418451446, 0.18052102545542376, 0.29755003643887384, 0.21761892336819852, 0.1646634042263031, 0.20069669426551887], [0.012724171958065458, 0.043295093945094516, 0.022249836707487702, 0.05400039182443704, 0.03373729038451399, 0.06106188880013568, 0.0234362127791558, 0.08341477970991816, 0.04321516251989773, 0.06161755469760724, 0.053419637094650946, 0.103245684877038, 37.6120719909668, 62.839647020612446, 35.621889046260286, 24.535098450524465, 50.58190604618618, 24.081200429371425, 24.445527485438756, 36.1036319732666, 35.2167569569179, 39.74200405393328, 36.82284695761544, 28.14198998042515, 44.04519019808088, 23.283104283469065, 29.79879140853882, 37.582913875579834, 28.871698481695994, 4.446369409561157, 0.18147307794008935, 18.652187245232717, 44.01299571990967, 40.12723650251116, 49.06932142802647, 56.48831605911255, 52.6878251348223, 47.0879487991333, 44.224877561841694, 47.36839893886021, 40.49225664138794, 39.7734238079616, 23.763153587068828, 17.2836856842041, 8.679758293288094, 5.632161574704306, 8.434034381593976, 21.088823216302053, 54.34497397286551, 59.533728872026714, 57.44036865234375, 53.804838384900776, 50.487198625292095, 47.23978083474295, 48.87168686730521, 50.90130431311471, 50.12222017560686, 52.637541021619526, 47.54968091419765, 46.635516847882954, 51.517685958317344, 50.79971470151629, 50.47713763373238, 47.38519620895386, 43.86476979936872, 43.31110954284668, 25.32836386135646, 6.966120166437967, 1.7334466810737337, 5.435774215630122, 17.91710604940142, 21.25904539653233, 16.554906504494802, 8.80068300451551, 0.4983568297965186, 0.0886367784280862, 0.073490512956466, 0.13324470871261188, 0.21853196008929185, 0.10505245399794408, 0.07311354604150568, 0.08363431292985167, 0.052932869642972946, 0.08217688077794653, 0.07139991263725928, 0.04454755763124142, 0.09222122108829872, 0.025641899422875473, 0.056099460260676484, 0.010061000889566327, 0.055752457452139685, 0.09244834032974072, 2.2321949984346117, 0.02151470847560891, 0.0358200604096055, 0.03201185047094311, 0.01573572580569557, 0.02043917788458722, 0.049807259147720676, 0.047948660129415135, 0.05789984097438199, 0.09210182606641736, 0.014473345330251115, 0.04858351106356297, 0.8657547725098473, 5.928985578673227, 7.377433112689427, 10.240914293697902, 18.856040443692887, 11.748401539666311, 2.1674549409321378, 6.600438211645399, 10.8308094058718, 22.24351828438895, 41.03808627809797, 45.79459374291556, 46.08637639454433, 47.29663446971348, 46.93190615517752, 46.871085098811555, 46.87245041983468, 46.320627961839946, 47.80917876107352, 45.75993612834385, 46.434029511043, 45.24952493395124, 51.65346418108259, 48.91936540603638, 49.77829129355294, 49.49797316959926, 50.853205408368794, 23.430310555866786, 7.09466792004449, 4.714565098285675, 3.2667941451072693, 2.141694928918566, 6.357862268175397, 32.803338391440256, 45.603528703962056, 34.07251371656145, 43.91539437430245, 48.358923707689556, 40.60292060034615, 39.49172299248831, 45.44530779974801, 37.66296754564558, 34.87807049070086, 44.333533491407124, 14.255273376192365, 0.2497860294367586, 0.1682494075170585, 18.47367933818272, 36.97341442108154, 27.876749447413854, 11.999700512204852, 32.685212067195344, 26.46712323597499, 26.338638884680613, 25.780418872833252, 27.23776878629412, 31.420577389853342, 30.66498163768223, 21.336641141346522, 38.68484953471592, 35.22669635500227, 32.44678463254656, 34.983405181339805, 45.145260265895296, 64.75154113769531, 3.1016489267349243, 0.27588672031249317, 0.08977828467530863, 0.0220729222720755, 0.106785500289074, 0.023901521560869048, 0.04968351471636977, 0.07610936635839087, 0.04194508406466671, 0.06314809221242156, 0.05529782541894487, 0.027721456584653685, 0.0049663114561034095, 0.044216195054884465, 0.028387645658637797, 0.045229308905878236, 0.06178121055875506, 0.07205432573599474, 0.02713559927152736, 44.93371888569423, 76.25863347734723, 36.75746440887451, 28.354743821280344, 40.31366014480591, 25.230164970670426, 33.51005704062325, 31.256738867078507, 35.4218920980181, 39.919481890542166, 36.06815447126116, 29.119648422513688, 30.974840027945383, 27.277660131454468, 33.650532245635986, 33.375595501491, 37.15016964503697, 8.290396009172712, 0.15834415331482887, 10.698679855891637, 46.571141787937705, 45.276230335235596, 49.694766998291016, 58.01440797533308, 52.31555802481515, 46.61336251667568, 52.7070438521249, 54.19173840114048, 43.11565324238369, 45.09405551637922, 33.03328554970877, 21.135254553386144, 10.235845582825796, 4.590006044932774, 6.831023301397051, 20.386869294302805, 53.9029677936009, 60.03106008257185, 59.03209672655378, 56.450205189841135, 51.888462679726736, 49.13198375701904, 50.286291463034495, 54.11815002986363, 52.81027323859078, 52.60109077181135, 48.342852524348665, 48.83256156103951, 53.244087491716655, 54.00238956723894, 50.755920205797466, 49.56543322971889, 47.88055413109915, 45.54681403296334, 29.95604303904942, 18.126580340521677, 5.132978669234684, 8.770540850503103, 15.652872255870275, 17.60534037862505, 20.04331735202244, 6.384907262665885, 0.20822088766310895, 0.10888774426920073, 0.048319645758186064, 0.04530025992010321, 0.015288591584456819, 0.12786776652293547, 0.06474762316793203, 0.1495555913341897, 0.019967146517176713, 0.041621924976685216, 0.09820346401206084, 0.013710115570574999, 0.011912386232454861, 0.027213907301692025, 0.08789064096552984, 0.04613084445840546, 0.07263563347182103, 0.29522084285105976, 1.5672194979020526, 0.08071158440517527, 0.08009739486234528, 0.04230833439422505, 0.05163258959406188, 0.012493565046627606, 0.015944380412942598, 0.04710402313087668, 0.04427164154393332, 0.10329930949956179, 0.011743307180170501, 0.13901681612644876, 0.24054405678595814, 4.767387909548623, 11.669353621346609, 11.86916731085096, 20.390741177967616, 13.445707491465978, 5.662561246326991, 13.787307858467102, 22.0364602293287, 22.824597869600566, 40.780766691480366, 46.32415764672415, 48.07770231791905, 47.59486157553536, 49.03027950014387, 46.88738904680525, 48.8470207623073, 47.31523479734148, 47.54497003555298, 47.6543242590768, 49.92553404399327, 47.09544937951224, 49.966111523764475, 49.403029509953086, 51.044673442840576, 51.89058882849557, 50.24002340861729, 21.02093063082014, 6.8205254418509345, 3.8434937596321106, 2.749563293797629, 3.7985006996563504, 10.3534186567579, 36.3231429372515, 49.44668851579939, 36.001323223114014, 51.00976916721889, 52.00049890790667, 44.095307554517476, 44.69833128792899, 48.33963898250035, 40.72604962757656, 39.586395672389436, 46.3493309702192, 6.989094385078975, 0.44756617663162096, 1.3444341953311647, 32.31795808247158, 31.741507734571183, 30.243069648742676, 17.839307069778442, 31.67826870509556, 23.781354393277848, 25.859590121677943, 26.20289887700762, 29.909535271780832, 27.350326129368373, 29.579308237348283, 25.53116614477975, 27.049090453556605, 36.68169777733939, 28.8931336743491, 31.7014513696943, 50.80829572677612, 71.2882604598999, 4.480201925550189, 0.21844687179795333, 0.07294565612184149, 0.07795524623777185, 0.04790044003831489, 0.06332858252738204, 0.05527299442993743, 0.15781400033405849, 0.21204260044864245, 0.15522897190281323, 0.16192194633185863, 0.16759249062410422, 0.19008120388856956, 0.14912043325603008, 0.15619018461023057, 0.18507012778094836, 0.16795963235199451, 0.14176442154816218, 0.1638105128492628, 58.562308175223215, 81.361494745527, 50.099721908569336, 34.58816385269165, 65.05904756273542, 30.687406948634557, 31.489465304783412, 52.40154545647757, 43.91201754978725, 56.187924589429585, 49.783210618155344, 39.06415516989571, 56.87732137952532, 31.76562145778111, 41.1497368812561, 46.949523312704905, 32.30921377454485, 8.20312750339508, 0.4286223474357809, 24.46821161678859, 52.61879825592041, 50.66165052141462, 54.283544949122835, 62.25996576036726, 54.75731481824602, 54.46863453728812, 56.252622740609304, 58.6266484941755, 50.29217658724104, 49.26223121370588, 30.75643035343715, 21.466238941465104, 11.796939049448286, 9.593664407730103, 9.962884732655116, 25.829412358147756, 55.63865906851632, 66.3137115750994, 60.56987203870501, 59.751610483442036, 53.663275786808555, 51.339384760175435, 52.953354018075125, 57.723549434116904, 54.06417294910976, 55.86313452039446, 51.405903339385986, 51.016074657440186, 56.68494660513741, 58.02078989573887, 51.145328521728516, 56.04551083700997, 49.415317399161204, 56.09443310328892, 31.985549313681467, 15.848417145865303, 3.664767852851323, 6.108659480299268, 30.692916870117188, 26.904484544481548, 24.491913659232004, 14.247157880238124, 0.34953368987355915, 0.19190659879573754, 0.213732369776283, 0.20528467664761202, 0.2914050061787878, 0.25674079624669893, 0.17529303527304105, 0.1720381842127868, 0.21276803580777987, 0.22153413827930177, 0.21353384400052683, 0.102682907932571, 0.24949659353920392, 0.1310410848153489, 0.2148254354085241, 0.19341255298682622, 0.1878365014812776, 0.31230260910732405, 5.574647860867636, 0.0931188143523676, 0.23674056945102556, 0.13932310683386667, 0.12034879784498896, 0.12684085805501255, 0.09630391201270477, 0.12795140274933406, 0.17825333428169998, 0.3106139525771141, 0.09870581062776701, 0.22001582118017332, 1.7121267850909914, 13.822715878486633, 14.582262550081525, 15.69829089300973, 38.71588713782174, 18.73350375039237, 3.7090074675423756, 13.604842952319554, 18.95262908935547, 27.20708554131644, 48.93697214126587, 49.05861077989851, 50.667466163635254, 49.57985768999372, 53.28530420575823, 50.60833351952689, 50.24740586962019, 48.77874081475394, 51.6441535949707, 52.43138102122715, 51.174382414136616, 49.04673630850655, 52.85256344931466, 50.614670276641846, 51.02491624014718, 53.17066240310669, 53.23825100490025, 26.622476271220616, 11.292175003460475, 5.8219142726489475, 4.560873116765704, 4.04014037336622, 9.711039458002363, 39.495113713400706, 51.27059064592634, 40.626068523951936, 51.916390963963096, 55.99695335115705, 50.47372259412493, 48.21079158782959, 53.040442739214214, 42.95342322758266, 41.9249404498509, 54.17330135617937, 20.920907838003977, 0.6490148912583078, 0.39595959867749897, 23.857741151537212, 43.29449987411499, 35.56833927971976, 17.42539245741708, 43.829233237675254, 35.82299075807844, 34.641289779118125, 33.99491276059832, 37.38689129693167, 43.0264105796814, 41.154875074114116, 28.635510104043142, 53.81871393748692, 48.67180456433977, 44.0759186063494, 47.90559891292027, 57.43459817341396, 82.93759632110596, 6.147252815110343, 0.543860636651516, 0.15657058491238526, 0.15963423837508472, 0.19070472328790597, 0.2315637543797493, 0.13466902157025679], [0.06814895636801209, 0.08242126195026295, 0.032353116265897236, 0.019675754742430787, 0.07463909632393292, 0.0852859757308449, 0.06044012002114739, 0.09173077597681965, 0.04289442580193281, 0.07411929100219693, 0.08193064720502921, 0.07926802829440151, 20.727563789912633, 70.61614036560059, 42.77397557667324, 33.27016006197248, 42.410341603415354, 51.69767904281616, 18.62104889324733, 36.345721108572825, 45.36782496316092, 32.056507791791645, 40.40002972739083, 30.43980094364711, 36.571805068424766, 35.25576066970825, 23.887163298470632, 24.33798326764788, 30.396541459219797, 26.627119404929026, 0.18829213774630002, 0.964037150144577, 23.177601099014282, 59.07000609806606, 34.244415623801096, 42.96797275543213, 33.478588649204795, 44.78226205280849, 46.849389348711284, 49.13079214096069, 39.69832072939192, 45.804581778390066, 40.22222185134888, 25.671009063720703, 10.995384437697274, 1.0130715646914072, 1.335282332130841, 10.093048810958862, 40.93624305725098, 61.05669757298061, 55.875074999673025, 55.364945207323345, 50.31929540634155, 49.80057416643415, 49.35789053780692, 50.90677949360439, 50.109411171504426, 50.90796416146414, 49.51956122262137, 49.49956430707659, 50.115841729300364, 50.71372379575457, 50.821073463984895, 45.27797085898263, 40.917024339948384, 27.325519323349, 8.224538377353124, 5.0133107134274075, 13.246861338615417, 26.08477255276271, 14.85423936162676, 8.77902981213161, 9.29196320261274, 2.654428992952619, 0.1636822833014386, 0.041085241096360345, 0.06256046731557165, 0.0999799704711352, 0.08381831805620875, 0.018855482240074446, 0.018119234425414885, 0.07833764821823154, 0.021726638710658466, 0.027657316365678395, 0.05261584111888494, 0.018972310703247786, 0.07247481388705117, 0.08004682364740542, 0.029194634141666547, 0.08867009449750185, 0.07609828588153635, 0.10175261606595346, 1.3072706695113863, 0.020662799278008084, 0.038131890286292346, 0.029457430754389082, 0.02973852406388947, 0.04020907257550529, 0.08689380516963345, 0.05016512190923095, 0.04088728868269494, 0.03943325938390834, 0.06560698098370008, 0.04171990543337805, 0.23331698030233383, 1.3540684155055454, 8.620236550058637, 15.135858535766602, 15.374047994613647, 21.115608521870204, 11.751562970025198, 6.199957072734833, 6.9743954709597995, 21.363756486347743, 27.223528453281947, 42.23799501146589, 48.023839882441926, 47.37516301018851, 50.241736139569966, 48.833784443991526, 49.31897715159825, 45.999023641858784, 47.416803564344136, 46.14963279451643, 48.273325375148225, 50.311836515154155, 50.53921978814261, 51.13182469776699, 53.72162675857544, 51.91625199999128, 41.48216996874128, 7.527583684240069, 1.8288479447364807, 0.9746634427990232, 1.6064202572618211, 6.298318377562931, 19.537931442260742, 43.14047220775059, 44.20444638388497, 43.89633199146816, 38.87062004634312, 42.28744534083775, 44.519804273332866, 44.983190059661865, 54.100928919655935, 39.262022495269775, 47.5618611063276, 13.099676779338292, 0.6186695567199162, 0.411369726061821, 41.08390964780535, 25.15860721043178, 32.771557331085205, 21.92350857598441, 18.398930617741176, 34.16490738732474, 24.61880166190011, 23.635534286499023, 29.693234375544957, 28.408750431878225, 35.731163365500315, 24.339259999138967, 28.189404487609863, 32.44274078096662, 32.91193526131766, 23.45684920038496, 37.58575221470424, 53.21463060379028, 41.159120423453196, 0.457406752875873, 0.06580980188612427, 0.036957190105957646, 0.08415025060198136, 0.025032132232029523, 0.06018026825040579, 0.022811651828565767, 0.05599209227200065, 0.11765713085021291, 0.006321477354504168, 0.04225586328123297, 0.026128505722486546, 0.06811070056366068, 0.0559499450693173, 0.04973155499569007, 0.13367792618061813, 0.08464847851012434, 0.05779267993888684, 0.16032563841768674, 25.84713200160435, 81.80485234941754, 45.86601080213274, 31.431239400591167, 49.628376960754395, 34.32212427684239, 28.265030418123516, 32.71525607790266, 34.61983721596854, 34.61953844342913, 39.16238532747541, 31.629704271044048, 36.31071955817086, 32.60210813794817, 30.25856065750122, 22.206237724849156, 36.731165477207725, 38.639300618852886, 1.2367257177829742, 0.4870036361472947, 18.172560044697352, 63.62227126530239, 43.91717311314174, 42.90505681719099, 36.24022660936628, 52.60322734287807, 52.927096775599885, 52.86881875991821, 41.37047420229231, 51.78823838915144, 48.58255842753819, 33.12262896129063, 16.009882858821324, 1.6454806412969316, 1.1546488191400255, 8.926857079778399, 39.80644859586443, 61.65634100777762, 59.603516578674316, 58.44514070238386, 54.65690640040806, 51.13649041312081, 51.60156808580671, 51.6860477583749, 53.61567715236119, 49.99578033174787, 50.90237086159842, 51.521667276109966, 52.54026276724679, 52.002975940704346, 51.686148507254465, 48.38315207617623, 40.39562109538487, 30.661445004599436, 18.513744388307842, 6.6238510353224616, 13.305783799716405, 15.421780381883893, 8.873319472585406, 12.421302437782288, 12.815993121692113, 1.4991189007248198, 0.03385925705411604, 0.014967518991657665, 0.09988999672766243, 0.039016272473548136, 0.03799483978322574, 0.0473133070793535, 0.045520458104355, 0.09514123547290053, 0.004400757607072592, 0.029820966068655252, 0.05005721448521529, 0.0871415858023933, 0.12813730777374335, 0.09019825713975088, 0.032253646424838474, 0.011699207492970994, 0.06313728993492466, 0.02824620503400053, 0.780856362410954, 0.06058443084891353, 0.046599695192916055, 0.05541135111291494, 0.04222220115895782, 0.05418349449921932, 0.11083592008799314, 0.0387922846712172, 0.0751124219968915, 0.029203858825245073, 0.03310312477073499, 0.06186079593109233, 0.2150145974010229, 0.23136874341538974, 9.982700126511709, 19.84757443836757, 12.579620616776602, 14.605535541261945, 10.675378203392029, 7.768513338906424, 16.316241094044276, 29.08803759302412, 26.311579125268118, 43.210440567561555, 45.33299016952515, 49.682024002075195, 49.709910597120015, 48.707195213862825, 49.45372356687273, 48.24401787349156, 48.379271507263184, 46.98335061754499, 49.78067452566964, 51.998747961861746, 51.571110657283235, 52.63957684380667, 54.63867432730538, 52.62652465275356, 37.09545258113316, 7.96424583026341, 2.902779975107738, 1.0395905588354384, 3.492241693394525, 11.437286393983022, 24.51893172945295, 48.887969970703125, 47.13303565979004, 45.258734771183555, 40.91561732973371, 48.04327399390084, 49.298730100904194, 50.19201830455235, 59.070652280535015, 42.1550543648856, 39.509878635406494, 5.942304406847272, 1.2995427527597971, 4.1841252871922086, 52.784293924059185, 26.385395050048828, 28.13055498259408, 30.42408411843436, 20.725279569625854, 31.34540135519845, 22.8688439982278, 23.250084706715175, 30.694073745182582, 31.136934552873882, 26.14646734510149, 29.80900526046753, 24.99693478856768, 28.52053131375994, 37.513671602521626, 19.939184699739727, 35.26226418358939, 60.58061395372663, 48.82768045152937, 0.3932177200913429, 0.08707299269735813, 0.035827975520598035, 0.09222027792462281, 0.030310308560729027, 0.02413127012550831, 0.09524673409759998, 0.22508120723068714, 0.33258084527083803, 0.12111715732940606, 0.12253731755273682, 0.25470882813845364, 0.14050879249615328, 0.18854314142039844, 0.2010895660413163, 0.2883419362562043, 0.1487624246094908, 0.30803885789854185, 0.4744021551949637, 34.42709766115461, 92.62909657614571, 57.3380251611982, 46.87212038040161, 58.363381249564036, 68.30574621473039, 24.16211220196315, 50.034943853105815, 59.346884863717214, 42.361624308994834, 55.579884256635395, 40.18922485624041, 47.83795819963728, 44.67963021142142, 32.096981048583984, 33.63520104544503, 33.11073364530291, 38.17316334588187, 0.5263785890170506, 2.5315965669495717, 27.354746920721873, 70.73778247833252, 42.81071417672293, 51.55746439525059, 40.93964420046125, 53.46985183443342, 58.959467206682476, 61.86368220193045, 50.089619227818076, 54.52036040169852, 50.37103864124843, 33.544697284698486, 14.666021347045898, 1.8994481563568115, 2.2465180584362576, 11.19883290358952, 44.00830568586077, 66.75260148729596, 60.60696152278355, 60.72792271205357, 58.05136544363839, 56.13470833642142, 55.86570882797241, 54.85382877077375, 54.683750765664236, 54.27851445334298, 53.33604342596871, 52.509638581957134, 53.74796737943377, 55.601510524749756, 56.11673334666661, 50.759529794965474, 49.24028532845633, 37.49851758139474, 16.067464317594254, 5.62234377009528, 16.860198191234044, 33.38976982661656, 19.843195336205618, 11.58112018448966, 17.88394056047712, 4.07541116646358, 0.16011772171727248, 0.13480649276503495, 0.13508291436093195, 0.11813291960528918, 0.17475885179425987, 0.17570277542940207, 0.17465403170457908, 0.21293708602232592, 0.09465989630137171, 0.22610807498650892, 0.089760832754629, 0.28127236132110867, 0.2117097790219954, 0.11450680132423129, 0.08805595923747335, 0.15109039683427128, 0.08476265559771232, 0.16015057638287544, 3.5743984963212694, 0.13625892411385263, 0.18823352589138917, 0.07409561013004609, 0.15626721190554754, 0.11827139503189496, 0.3021327262478215, 0.1386720117713724, 0.23727910912462644, 0.18723493947514466, 0.17154623275356634, 0.13599631749093533, 0.7046424948743412, 3.314470078263964, 18.268809965678624, 24.88447298322405, 21.85035273006984, 34.26321050098964, 16.688864299229213, 7.058715769222804, 15.310805491038732, 31.609877586364746, 34.1713171005249, 50.37296676635742, 48.42756496156965, 54.25809022358486, 51.619748047419954, 52.313522202628, 51.72658354895455, 49.5871776172093, 51.410207748413086, 50.00551128387451, 50.50205387387957, 53.32447814941406, 52.5800655228751, 55.11182928085327, 56.73075955254691, 54.030234473092214, 42.39017098290579, 10.213595713887896, 3.578657307795116, 2.123824813536235, 2.8365658138479506, 10.622537153107778, 27.175948926380702, 53.35982363564627, 48.61140387398856, 52.492268085479736, 48.17536619731358, 51.66704443522862, 53.518784523010254, 51.43084389822823, 62.66143267495291, 45.19692012241909, 54.6585670198713, 16.992297342845372, 1.7112493578876768, 1.4172448026282447, 49.08340195247105, 30.294184071677073, 40.462813649858745, 29.46816485268729, 25.07457743372236, 44.96316187722342, 32.25618512289864, 32.67353214536394, 40.53489426204136, 40.94184677941458, 47.569698674338206, 34.788046155657085, 35.73944214412144, 47.646250452314106, 42.71535015106201, 31.673589093344553, 49.15058061054775, 65.58973707471574, 62.3194214957101, 0.7295076549053192, 0.24416105555636541, 0.1577069546495165, 0.2618390641042164, 0.1774272314671959, 0.1599130891263485, 0.3033682570925781], [0.11083094642630645, 0.04271481079714639, 0.03254342158990247, 0.016215283822800432, 0.02095291031790631, 0.05083669515858803, 0.03242189257538744, 0.03215256167043533, 0.10882871850792851, 0.06519674549677543, 0.023422810016199946, 0.34849341426576885, 12.081445200102669, 76.44813864571708, 51.112213407244, 37.61718586512974, 21.66404720715114, 57.94258097239903, 31.264298507145472, 26.719662461962017, 44.20932749339512, 30.590681076049805, 35.92698444638933, 30.60515069961548, 24.92593288421631, 47.86071007592337, 18.785108021327428, 32.966763496398926, 18.58219804082598, 53.36014672688076, 10.282664281981331, 0.25133542343974113, 2.7960775750023976, 27.65910233770098, 66.15780789511544, 53.25098705291748, 48.16524267196655, 53.12185825620379, 53.23948431015015, 42.112576552799766, 56.57982383455549, 38.49122061048235, 42.774291719709126, 34.38486998421805, 24.258916241782053, 11.162093435014997, 1.1080080590077808, 4.4255882161004205, 34.91787324632917, 61.455642291477744, 55.10842118944441, 55.585870129721506, 55.59130014692034, 51.23290361676897, 51.33842590876988, 53.18751525878906, 53.72855063847133, 52.623252051217214, 53.06556395121983, 50.834528650556294, 55.337513719286235, 49.49946355819702, 48.89728403091431, 43.81953007834298, 23.94782280921936, 7.547809890338352, 4.0557885851178845, 14.48546632698604, 20.476572275161743, 13.988279291561671, 8.767802391733442, 14.060401592935834, 8.685083218983241, 1.521740498287337, 0.15352602542511054, 0.03484610481453793, 0.20087346620857716, 0.02208752095300172, 0.11772038388465132, 0.14075215586594172, 0.07102720013686589, 0.23454664860452923, 0.012716244972710098, 0.012317091658977526, 0.010685573714519185, 0.08197374774941377, 0.016768669842609336, 0.0435318110643753, 0.0701350351529462, 0.035175547136792114, 0.12818783149123192, 0.06363775700862918, 0.33381363483411924, 0.1568637527525425, 0.06671473689909492, 0.056954288855195045, 0.05346030169831855, 0.30394900164433886, 0.014288259636876839, 0.18783057108521461, 0.03510680136137775, 0.11144519025193793, 0.04638000590992825, 0.08997145680976765, 0.10745780635625124, 0.4905999260289328, 2.6564248629978726, 12.173385500907898, 8.81356930732727, 14.760673182351248, 18.61271105493818, 13.500169209071569, 5.409679821559361, 5.346433409622737, 17.240318502698624, 30.438789980752126, 45.696843011038645, 48.20952354158674, 50.21282468523298, 49.54850741795131, 49.92992877960205, 50.25258922576904, 48.762245791299, 47.47974729537964, 50.504537854875835, 50.67145095552717, 50.89851113728115, 50.49943092891148, 52.0448214667184, 48.375293663569856, 21.38840695789882, 1.4072867312601633, 1.0646533625466483, 1.221403094274657, 8.180729985237122, 30.420092378343853, 40.97247443880354, 39.156854561397004, 48.99745273590088, 41.170525891440256, 38.36814022064209, 45.943497112819124, 41.752135276794434, 43.84581511361258, 42.06515857151577, 35.36327709470476, 3.6117513605526517, 0.7622374157820428, 0.2844167740217277, 35.65356240953718, 41.53802306311471, 22.085220949990408, 62.336854525974815, 13.943978445870535, 28.370745522635325, 27.752006701060704, 28.490145104272024, 24.22034158025469, 31.070513248443604, 28.668609585080826, 35.512350695473806, 20.428624493735178, 36.557245118277415, 27.506141219820293, 23.595444917678833, 37.274584089006694, 45.89330332619803, 62.48319053649902, 19.133379527500697, 0.1986548059753009, 0.11918447246508938, 0.06831151978777987, 0.02591767132149211, 0.08156813308596611, 0.05801494765494551, 0.1458192111126014, 0.09811153608773436, 0.03646154063088553, 0.04243214328640273, 0.029290606134704182, 0.01594579515845648, 0.023529406171292067, 0.018840644375554154, 0.06361756380647421, 0.16077614495796816, 0.17315543283309254, 0.10991879180073738, 0.5545136364442962, 15.387843642915998, 85.41595622471401, 58.720039231436594, 31.31499603816441, 31.15020908628191, 41.9641387122018, 32.75217185701643, 33.76064729690552, 33.320197514125276, 32.37804957798549, 36.77349042892456, 31.097058841160365, 29.110398633139475, 41.68463005338396, 25.112952334540232, 28.720415353775024, 19.248855113983154, 69.45453357696533, 20.08980601174491, 0.8493825910346848, 1.038022871528353, 19.42797793660845, 59.347239221845356, 61.31146022251674, 51.279984610421316, 57.27982357570103, 59.43288966587612, 46.61943871634347, 60.018699237278526, 44.15043108803885, 45.618651458195274, 41.12880195890154, 30.502598762512207, 15.502987452915736, 2.2801684013434818, 4.571124315261841, 32.74423354012625, 61.57485253470284, 58.45785590580532, 57.8417626108442, 56.929248741694856, 53.5327365057809, 52.14747067860195, 55.52534089769636, 54.043432576315745, 53.34279360089983, 55.053085735866, 51.993293625967844, 55.892490659441265, 50.121904032570974, 49.806261266980854, 44.050387450626914, 27.66141435078212, 15.955527101244245, 4.977867083890097, 12.377400244985308, 12.637523429734365, 8.333026681627546, 9.525629384177071, 19.533528021403722, 6.801548174449375, 0.2873336603598935, 0.08835697094244616, 0.11012663386229958, 0.03195253633228796, 0.00974879166044827, 0.010162612356777703, 0.09342467079737357, 0.037324789844985516, 0.2331671326288155, 0.01565349753946066, 0.08074125674154077, 0.00521408996844132, 0.0930253393681986, 0.0421681931641485, 0.08181220891752414, 0.02979796373152307, 0.09878836119813578, 0.531947135925293, 0.08858803925769669, 0.3774694379951273, 0.11147589396153178, 0.014743314058120762, 0.07485204775418554, 0.07429076358675957, 0.2643726867224489, 0.10724610343043293, 0.21521175253604138, 0.03923467932535069, 0.045717240045113225, 0.02498872295421149, 0.33744857407041956, 0.053796838104192696, 0.406262528683458, 4.030557938984462, 14.230409247534615, 8.84289939062936, 8.38936528137752, 9.681518299239022, 10.434296556881495, 6.495868691376277, 11.503052830696106, 19.26260038784572, 29.053605794906616, 45.49230888911656, 45.829852376665386, 50.14937720979963, 49.05049180984497, 50.590264729091096, 49.55892971583775, 50.212133339473176, 48.82439742769514, 51.460474491119385, 50.50630269731794, 52.31032255717686, 52.01908881323678, 50.543006556374685, 46.19412211009434, 17.631708792277745, 0.4067977842475687, 1.205278062394687, 3.1395682862826755, 14.358291711126055, 35.803574017116, 45.49079418182373, 43.7468067577907, 50.82262986046927, 46.608213901519775, 43.239372866494314, 49.059402874537874, 46.02740008490426, 45.86477402278355, 47.206255776541575, 26.702912092208862, 0.6944421050804002, 1.8269070088863373, 2.1106241047382355, 42.285579749516074, 45.898504052843364, 26.17830225399562, 57.349586963653564, 19.45375575338091, 29.868019785199845, 26.863547495433263, 27.80219006538391, 23.64097993714469, 33.2832852091108, 24.48687274115426, 29.781045709337505, 24.756129332951136, 23.20574130330767, 29.479921204703196, 27.571013075964792, 28.232625756944927, 47.992454869406565, 69.51669216156006, 23.494103704180034, 0.5207766581858907, 0.18709444201418332, 0.14096033040966305, 0.005431909463368356, 0.1059286869796259, 0.0452903736648815, 0.10840361631874527, 0.2080208012568099, 0.12712361716798373, 0.26018862266625675, 0.07997006776609591, 0.10631694471729652, 0.17414266057312489, 0.11351248289325408, 0.20720533787139825, 0.22788742450731142, 0.2841947302222252, 0.28450091236404007, 0.7969007300479072, 19.899871792112076, 98.64912700653076, 68.26043701171875, 50.516089235033306, 32.42475536891392, 75.07751614706856, 43.08548763820103, 37.18121419634138, 63.49229826245989, 41.183095182691304, 48.15453897203718, 40.17045777184622, 32.73408917018345, 57.29784720284598, 24.93751379421779, 45.378024918692454, 22.540538140705653, 63.43655981336321, 16.51876892362322, 0.40308038943580216, 4.427646619932992, 33.44224957057408, 77.19515337262834, 63.15437957218715, 58.67369474683489, 62.40272344861712, 61.96722425733294, 51.98240579877581, 64.16960866110665, 50.6363000188555, 55.0838280405317, 41.81586068017142, 31.11842107772827, 14.033138598714556, 1.6645511665514536, 6.909424602985382, 37.1284704208374, 62.839577538626536, 60.87202140263149, 61.680263655526296, 59.50247587476458, 55.44533239092146, 55.57807077680315, 58.98092324393136, 58.341237340654644, 56.184485231127056, 58.29152297973633, 56.286408356257844, 58.75828906467983, 54.040740149361746, 51.022616386413574, 56.18679550715855, 32.41562196186611, 12.340652091162545, 3.6473843285015652, 15.871919427599225, 24.879465069089616, 17.433518375669205, 12.526648419243948, 21.13934530530657, 12.865868159702845, 1.9850894808769226, 0.23874219347323689, 0.21038674430123397, 0.23524857951062067, 0.11608453094959259, 0.28417469986847466, 0.19097134683813366, 0.19352592261774199, 0.3611460838999067, 0.19312665904206888, 0.30179337731429506, 0.09333969785698823, 0.15300957885171684, 0.12499240652791091, 0.16571247364793504, 0.21294530986675195, 0.10429537855088711, 0.41061980915921076, 0.23267348483204842, 2.258485896246774, 0.6852959415742329, 0.22945087775588036, 0.16671050366546425, 0.27841662455882343, 0.3389138840138912, 0.16488136324499333, 0.6290687301329204, 0.15219799668661185, 0.28118043339678217, 0.11479376735431807, 0.7421174411262784, 0.18890568268086227, 1.5682982057332993, 8.221674851008824, 22.02499222755432, 14.774969100952148, 22.600464616503032, 26.819075550351823, 16.602765696389334, 5.736129641532898, 10.92771419457027, 25.283054658344813, 39.53020906448364, 48.21883412769863, 51.899360929216655, 54.630319118499756, 52.25947216578892, 52.247246810368125, 53.38365943091256, 52.05155079705374, 51.26318734032767, 53.14875473294939, 54.08034140723092, 53.07233149664742, 53.06114142281668, 51.54163292476109, 50.75701802117484, 23.950963394982473, 2.4846276129995073, 1.882265261241368, 2.212254754134587, 13.160862616130284, 39.6411509513855, 49.75793654578072, 47.13972330093384, 55.57563195909773, 50.6210869380406, 45.819690636226106, 54.22843878609793, 50.60019370487758, 52.546512671879356, 51.25408172607422, 41.14682558604649, 5.436526792390006, 1.7424530663660593, 0.7165796086192131, 43.649278368268696, 48.69303478513445, 27.95936005456107, 71.07370008741105, 19.34867467199053, 39.31364413670131, 40.562002658843994, 37.3121668951852, 33.747859137398855, 41.377512727464946, 38.53692933491298, 46.557954107012065, 29.11841859136309, 48.753442423684255, 38.69395514896938, 30.462368692670548, 51.142292158944265, 57.98587172372, 76.99333599635533, 31.19731787272862, 0.4172709994018078, 0.2796793510871274, 0.32389190580163685, 0.20034677375640186, 0.23482028820684978, 0.17453219395663055, 0.19668621303779737], [0.029819564893841743, 0.06242452282458544, 0.04778730110930545, 0.05016522029680865, 0.01569091365672648, 0.08783080096223525, 0.07879716570356063, 0.09517295698502234, 0.10160780990762369, 0.04865746120257037, 0.010937547693694276, 0.12769844489438192, 1.8960876166820526, 65.05401011875698, 60.45962497166225, 37.81101976122175, 30.047307627541677, 43.254037039620535, 51.4071991784232, 23.615162168230327, 38.238806452069966, 37.15062822614397, 34.49271297454834, 33.69607073920113, 25.859042951038905, 36.280685969761436, 25.778523751667567, 19.697304010391235, 23.724311419895717, 17.285674606050762, 44.874061652592246, 1.623676325593676, 0.6023493238857814, 0.19401106158537523, 8.974400997161865, 41.27307088034493, 64.3580299104963, 35.326816422598704, 44.918412004198345, 53.39939015252249, 53.48873356410435, 51.598913873944966, 43.0192608833313, 56.06335728509085, 41.9617520059858, 36.99446746281215, 12.722284504345485, 1.2711744521345412, 18.114790984562465, 48.28114557266235, 54.90790660040719, 56.16269220624651, 55.788979870932444, 53.68544054031372, 50.737250396183555, 54.01182174682617, 53.152058601379395, 52.98856748853411, 54.2881863457816, 54.524268763405935, 50.50864424024309, 54.42456906182425, 48.838404996054514, 15.995484454291207, 6.028562383992331, 4.158921131065913, 12.679294262613569, 15.023797988891602, 13.366919262068611, 7.464795419148036, 2.8004403923239027, 11.179396186556135, 2.837669708899089, 0.1561232946280922, 0.08972668208714042, 0.17269330977329186, 0.044086476122694354, 0.04508824486817632, 0.03901931231043168, 0.07353252105947052, 0.1352683444108282, 0.20619247507836136, 0.05639925060261573, 0.08915614948741027, 0.03492074366658926, 0.1066754079822983, 0.06389006346996341, 0.006195362291431853, 0.019575090679739202, 0.05160189945516842, 0.6118823609181813, 0.07445680789117302, 0.0916120187778558, 0.07685654197952577, 0.15826434402593545, 0.05611825568069305, 0.06860414479992219, 0.07662623362349612, 0.08621233887970448, 0.13948010626648152, 0.13766313876424516, 0.0895127739225115, 0.15441998174147947, 0.07709685872708048, 0.24031085787074907, 0.2577733908380781, 0.25011639456663814, 8.594785298619952, 4.726247191429138, 5.9956644007137845, 11.618498887334551, 14.295445254870824, 11.041427544185094, 3.6202259915215627, 3.4424365716321126, 14.348223771367755, 30.97225182397025, 42.272402490888325, 40.40757894515991, 48.76298230034964, 51.58678926740374, 52.08238342830113, 51.710321290152415, 50.37858438491821, 49.647415024893625, 51.60475730895996, 50.43848133087158, 55.43850925990513, 48.55076347078596, 26.964008024760656, 3.141996030296598, 0.1936380708856242, 6.674130371638706, 11.033041068485804, 33.65858173370361, 31.831917694636754, 36.76424585069929, 46.95740951810564, 41.679512705121724, 47.51800755092076, 47.4481851032802, 44.01860291617257, 47.48881469454084, 44.43424415588379, 25.490093605858938, 2.0478516902242387, 0.3565059086041791, 0.15348501476858342, 18.641559975487844, 45.786565099443706, 17.518569537571498, 45.561971528189524, 50.12412745612008, 19.444693565368652, 27.51380855696542, 27.134186778749736, 25.33515225137983, 23.71113763536726, 29.54584571293422, 32.74787439618792, 26.372916085379465, 27.529653923852102, 36.16416467939104, 24.50452290262495, 31.36566925048828, 39.672011375427246, 46.91164868218558, 63.26303550175258, 4.69351292507989, 0.29795357478516443, 0.020770777948200703, 0.01796148012259177, 0.07549639817859445, 0.022671549614252787, 0.02572750679350325, 0.05946136039814778, 0.09979908660586391, 0.05746622317071472, 0.04564844677224755, 0.02321761254487293, 0.009107751638761588, 0.033171666985643763, 0.030624222609081438, 0.1437693703919649, 0.022690886165946722, 0.018479322781786323, 0.038287461402692964, 0.11468704736658505, 2.8133314720221927, 73.68304048265729, 70.53629861559186, 33.445515223911826, 31.50697476523263, 44.198835713522776, 31.09286560331072, 32.826378617967876, 33.29768535069057, 32.82465893881661, 38.39435577392578, 33.07089614868164, 29.271492617470876, 34.33560378210885, 26.323220832007273, 23.994773524148123, 12.172628147261483, 19.08224425997053, 54.59146479197911, 8.43365396772112, 2.672251990863255, 0.18971552779631956, 4.02474707365036, 36.56361314228603, 66.77320289611816, 41.07974420275007, 48.630876200539724, 59.12245110103062, 59.72354670933315, 56.13723053250994, 44.3284022467477, 54.50350407191685, 48.36248813356672, 42.32552146911621, 18.69733837672642, 2.2602511729512895, 15.791214363915579, 49.14642906188965, 57.85764271872384, 58.847226006644114, 58.35386916569301, 55.971116474696565, 54.07188892364502, 52.7915825843811, 54.10109567642212, 53.68910224097115, 54.555302892412456, 54.47539513451712, 49.114783491407124, 57.35805334363665, 43.16941840308053, 18.43509599140712, 14.302290967532567, 5.863530073847089, 12.012144735881261, 11.146658880370003, 7.580610598836627, 11.543841361999512, 8.80196668420519, 16.59802876199995, 3.9952120184898376, 0.08492479154041835, 0.0983426993978875, 0.20299854289208139, 0.1133096009226782, 0.06369054703308002, 0.1227075212768146, 0.07895696070045233, 0.9452041664293834, 0.5147524071591241, 0.14117041842213698, 0.8870147945625442, 0.2785624553050314, 0.8336083346179554, 0.2877342402935028, 0.07884589808859996, 0.3487090526946953, 0.11287136229553393, 1.1856957588876997, 0.21206671558320522, 0.11124403176030942, 0.13725141728562967, 0.2914092130959034, 0.04409299684422357, 0.159343526831695, 0.3093447121126311, 0.8596568597214562, 0.560629951102393, 0.12434464985770838, 0.15700600083385194, 0.5431553944945335, 0.2527511731854507, 0.23622895404696465, 0.21290625339107855, 0.7547788502914565, 12.527955549103872, 6.0800672088350565, 8.053068995475769, 8.690416829926626, 7.742078048842294, 11.024865644318716, 5.660520647253309, 8.694551876613072, 11.477571180888585, 26.857149941580637, 41.592913831983296, 40.66356100354876, 47.95921468734741, 49.84264898300171, 52.28795630591256, 51.64019659587315, 48.822274753025596, 49.13018764768328, 52.68635559082031, 52.61189522062029, 55.13270514351981, 45.54126589638846, 21.791885375976562, 1.7469224951096942, 0.6651947487677846, 8.999725443976265, 17.370878628322057, 42.907325404030935, 37.86199869428362, 40.810115882328574, 50.117015974862234, 45.248308999197825, 51.38545479093279, 49.567604541778564, 46.21821846280779, 53.512103830065044, 47.52378845214844, 20.49343729019165, 0.6569297036954335, 1.55086550116539, 1.6030309477022715, 24.632579939705984, 45.65422970908028, 30.815333706992014, 53.42721768787929, 59.00823661259243, 24.05403992107936, 26.982724734715053, 25.183789219175065, 25.293412685394287, 24.35031632014683, 30.745094367436, 22.887294939586095, 28.924466575895035, 24.63317574773516, 26.287277800696238, 31.280713626316615, 26.92783396584647, 33.69332620075771, 53.53790943963187, 69.82298265184674, 6.411673026425498, 0.21279198809393815, 0.10239713612411704, 0.01502597308717668, 0.06986786198935338, 0.07668553079877581, 0.018749542567612867, 0.1344302450971944, 0.18970154997493538, 0.13473606083009923, 0.07420484069734812, 0.17874478362500668, 0.08802110967891556, 0.19952737486788205, 0.11538260004350118, 0.23495922503726824, 0.26876210261668476, 0.115648463634508, 0.21075258324188845, 0.23745585392628396, 4.260198073727744, 87.44939517974854, 76.26431015559605, 52.30385031018938, 45.636893953595845, 61.08710983821324, 68.64888300214494, 30.70264434814453, 56.075648648398264, 48.32357127325875, 47.87556185041155, 46.22456564222063, 36.064895766122, 47.98025383268084, 35.36262396403721, 26.061779226575577, 36.39334058761597, 21.911776542663574, 53.245786326272146, 4.844076914446695, 1.8933500264372145, 0.3120942717151982, 11.79284221785409, 49.823402472904746, 71.5784033366612, 44.73528528213501, 53.51224626813616, 61.15407657623291, 63.111196517944336, 62.864486830575125, 51.44467428752354, 62.76580156598772, 51.64232274464199, 42.90262842178345, 15.38347670010158, 2.456554936511176, 20.47253363473075, 52.63098192214966, 62.4327118737357, 61.552389008658274, 62.56875760214669, 59.80191544124058, 56.43172992978777, 57.940270696367534, 58.26490790503365, 54.67521142959595, 58.518068994794575, 59.400615283421104, 53.18916198185512, 58.46216378893171, 56.626578262874055, 22.788269213267736, 10.833719832556588, 5.83918879713331, 16.975956916809082, 15.16415160042899, 16.025141102927073, 14.665460280009679, 6.635673829487391, 19.018746410097393, 5.35361567565373, 0.29052909889391487, 0.3304573292178767, 0.2669288638447012, 0.1326973345130682, 0.18797245275761398, 0.4812289774417877, 0.3090868688055447, 0.5460139811038971, 0.542126572557858, 0.49254748438085827, 0.6254638635686466, 0.11028199124016932, 0.44554026105574196, 0.25419943832925385, 0.09404935049159185, 0.18992621291960987, 0.20669448242655822, 1.8779326251574924, 0.33229241360511097, 0.20052807831338473, 0.49748591652938295, 0.4606566642011915, 0.3027687578329018, 0.21733578427561692, 0.14560893311032228, 0.6396914401224681, 0.5406834099973951, 0.3620064663035529, 0.15786844598395483, 0.543782957962581, 0.1934349446424416, 1.6743048088891166, 0.9942227303981781, 0.4747691069330488, 13.322911977767944, 8.954938224383763, 11.597887924739293, 21.615493195397512, 19.221456629889353, 14.48170908859798, 4.205043707575117, 6.828559730734144, 19.099894421441213, 34.86648089545113, 48.40914876120431, 44.608247893197195, 53.33936813899449, 54.78912714549473, 55.2960329736982, 57.23038019452776, 52.382385798863, 51.34992517743792, 55.37715319224766, 52.68249934060233, 58.43016733442034, 50.718497208186555, 31.039729254586355, 6.2779028330530435, 1.2701434046030045, 9.48345034463065, 14.79887090410505, 42.5488018308367, 40.999867711748394, 44.40831347874233, 56.06238106318882, 49.03835678100586, 55.89849737712315, 56.21368850980486, 51.20535053525652, 54.945225375039236, 51.8187757219587, 30.93396724973406, 3.090589783021382, 1.047694872532572, 0.6005025144134248, 23.918987785066875, 51.40346104758126, 22.932456493377686, 49.25094386509487, 54.84732525689261, 27.93118163517543, 36.466897691999165, 38.60581030164446, 32.731744153159006, 33.61869559969221, 39.15264742715018, 43.34018427985055, 35.141344683510916, 37.86345781598772, 50.62376199449812, 32.8555645261492, 42.99311828613281, 53.57752111979893, 57.33579478945051, 81.04770020076207, 8.692160827772957, 0.49364584258624483, 0.2144013645925692, 0.16263852002365248, 0.2263675332069397, 0.14398481883108616, 0.09441048039921693, 0.27743785136512344], [0.05129304388538003, 0.13702702575496264, 0.030288592047457184, 0.05009651184082031, 0.027183934713580778, 0.01078754395712167, 0.03359291170324598, 0.04943429558937039, 0.09820874979985611, 0.10786058474332094, 0.040855808050504754, 0.024003810714930296, 0.1979624695543732, 33.676963193076, 70.00250325884137, 55.9181364604405, 34.212773527417866, 29.950922216687882, 56.392757483891074, 30.293850558144705, 30.774363654000418, 46.64207247325352, 30.75110455921718, 36.71542433329991, 31.919388566698345, 31.218082564217703, 36.431833607809885, 14.214447498321533, 23.37323805264064, 22.52682934488569, 21.95421266555786, 29.516097000667028, 1.9984300221715654, 1.0028236231633594, 0.126203252268689, 3.817447134426662, 30.53762810570853, 66.27664293561662, 47.286312920706614, 48.63051489421299, 44.30921132223946, 49.27841009412493, 35.58926377977644, 46.0955445425851, 37.008652210235596, 39.869385378701345, 25.477843931743077, 5.290902103696551, 6.023873218468257, 25.881631544658116, 48.52249125071934, 52.946082728249685, 51.20235586166382, 51.68539115360805, 53.33625882012503, 56.55674886703491, 54.02729191098894, 54.47553409848894, 52.7533848626273, 52.20646088463919, 62.32470907483782, 42.333345140729634, 5.863750244889941, 6.554831538881574, 6.102915057114192, 10.676237174442836, 11.323135307856969, 13.515276329857961, 12.648716109139578, 4.9070970756667, 3.098885932138988, 4.816482578005109, 1.3020467098270143, 0.0766805639224393, 0.02909104898571968, 0.10310237828109946, 0.08955717725413186, 0.066459458454379, 0.09539771492459945, 0.12545273825526237, 0.7386555011783327, 0.4837666984115328, 0.11136637162417173, 1.1591371382985796, 0.4537128625171525, 0.10458917742861168, 0.12284641739513193, 0.19500706956854888, 0.04876419136832867, 0.4532590311552797, 0.3428770442094122, 0.19852515150393757, 0.3911697385566575, 0.3319222591817379, 0.2831491348998887, 0.05795592189367328, 0.2535720377096108, 2.6418362515313283, 2.1684035871710097, 1.4245603872197015, 0.8417008146643639, 1.008284798690251, 0.7157846369913646, 1.8672124232564653, 0.7051223005567278, 0.08513937824006591, 1.0874287975685937, 9.353953293391637, 5.685620580400739, 2.4571233860083987, 12.59449757848467, 15.556868995938983, 10.032667228153773, 9.842156308037893, 3.2842805896486555, 1.0546672812529971, 6.00207758801324, 21.89682228224618, 28.592988865716116, 34.84993028640747, 34.38803488867623, 47.53785508019583, 47.3481935773577, 51.21039145333426, 48.083907059260774, 49.71895020348685, 45.27829047611782, 34.6195592880249, 19.595068216323853, 3.609595681939806, 0.119357363187841, 2.8927984535694122, 14.717345952987671, 32.72393090384347, 34.9100912639073, 42.47888558251517, 41.64411858149937, 45.71271269662039, 42.60888985225132, 43.95585026059832, 37.84650073732649, 34.806583949497764, 29.275105680738175, 22.619283812386648, 2.291790566274098, 1.5980146740164076, 0.0803484528192452, 7.435203041349139, 68.92403861454555, 35.46059703826904, 24.63401821681431, 7.383100237165179, 6.015658710684095, 19.430343798228673, 29.359119824000768, 27.359315361295426, 23.059542519705637, 22.122518880026682, 30.233814648219518, 34.26693820953369, 24.995661531175884, 32.23627853393555, 35.242899554116384, 32.738893849509104, 30.834733077457972, 39.539196559361045, 58.5718480518886, 44.09869132723127, 0.13709455356001854, 0.2684238664805889, 0.03890096562515412, 0.05794643597411258, 0.03501597944913166, 0.00570074503775686, 0.048078524946634255, 0.015749167584414994, 0.024073591256248097, 0.12086626222091061, 0.006964740426545697, 0.05958595299827201, 0.05331528180145791, 0.07289027409361941, 0.028284671184207712, 0.029261439306927577, 0.029262762450213944, 0.018067906643929224, 0.13889010649706635, 0.01926522409277303, 0.02259188112137573, 42.17469344820295, 82.3636473246983, 54.12736334119524, 28.826627254486084, 39.98068857192993, 35.00452075685774, 29.702597073146276, 34.123530864715576, 35.447649070194785, 34.664795534951345, 38.15640081678118, 32.209111077444895, 35.0323691368103, 31.84682158061436, 20.596598931721278, 20.820363930293492, 11.880642260823931, 24.001376049859182, 38.84781605856759, 8.028205735342842, 3.271411223070962, 0.2920057268014976, 1.3792500985520226, 24.718676805496216, 66.92296436854771, 49.381712436676025, 52.28565297807966, 50.62728820528303, 51.707173756190706, 43.863724095480784, 49.129051617213655, 38.99033750806536, 44.69707018988473, 35.08372674669538, 10.183607288769313, 8.055340187890188, 26.48681616783142, 47.060621534075054, 54.82924951825823, 52.385172026497976, 52.60877547945295, 52.10537501743862, 54.90118769236973, 56.592629364558626, 55.64538492475237, 54.52312578473772, 52.88076966149466, 62.012825284685405, 32.22019692829677, 6.755007837499891, 13.818401047161647, 8.246408700942993, 8.098561457225255, 11.906558173043386, 8.899752157075064, 15.732828651155744, 12.863975644111633, 5.711008429527283, 9.578275016375951, 3.52987921663693, 0.30068234407476013, 0.0331582421702998, 0.07665452853377376, 0.14425748134297983, 0.35499668387430056, 0.31649221000926836, 0.31354397535324097, 0.6610764211841992, 0.333962044013398, 0.1620462675179754, 1.641290226152965, 1.5606505189623152, 0.13075360309864792, 0.7361361820782933, 0.7353072836995125, 0.13206183218530246, 0.855493531695434, 0.19191806603755268, 0.34577132176075664, 1.5189287577356612, 1.7273896975176675, 0.9607057060514177, 0.10485676449856587, 0.8914188668131828, 4.402696073055267, 3.120467471224921, 1.2537558610950197, 0.7622225965772356, 2.2585612407752444, 0.9529603102377483, 1.21296646126679, 0.993154553430421, 0.8267750527177538, 2.7986568765980855, 12.315181732177734, 6.093889347144535, 7.341772351946149, 17.28242458615984, 16.33980938366481, 8.023917828287397, 11.448807375771658, 7.7760443176542005, 4.298416640077319, 6.573911726474762, 18.990392548697336, 29.166658197130474, 35.40117604391915, 36.79805925914219, 44.54812165669033, 45.93278646469116, 48.61155326025826, 47.308224064963206, 47.146212918417795, 44.564231055123464, 31.029775960104807, 16.188354287828716, 3.7147983568055287, 0.38704508702669826, 6.302872921739306, 22.792227949414933, 36.25934457778931, 37.85397352491106, 48.32488100869315, 46.32702725274222, 48.42692572729928, 49.514155524117605, 48.15887812205723, 42.59874200820923, 36.03627961022513, 26.67780477660043, 23.170032773699077, 1.3855645997183663, 0.8511289773242814, 0.267828818410635, 9.091386948313032, 69.2558706828526, 48.91023894718715, 25.54036382266453, 8.449231828962054, 13.175805585724966, 23.69702410697937, 27.140714611325944, 26.396671976361954, 23.06804711478097, 23.820938280650548, 28.645595414297922, 25.199176004954747, 30.709759303501674, 25.3713766847338, 38.09447847093855, 33.173569679260254, 20.52783261026655, 40.948127950940815, 65.62693078177315, 49.68617902483259, 0.094596996105143, 0.11098488566598722, 0.08312864827790431, 0.04215986753946968, 0.0905013248058302, 0.001856230294963877, 0.009916087013802357, 0.032946932794792314, 0.08314120796109949, 0.23215676684464726, 0.09368809844766345, 0.1370765452406236, 0.1279067008623055, 0.16601590093757423, 0.0887416053031172, 0.0878397576244814, 0.18708346331758158, 0.3421269915997982, 0.26223470430289, 0.11183876770415477, 0.22826631846172468, 54.4349878856114, 95.01906844547817, 67.85653127942766, 46.620800563267295, 41.773987361363, 76.6564108984811, 38.90247058868408, 42.5250563621521, 62.79474776131766, 42.465538093021934, 49.93778371810913, 44.42035470690046, 46.90212965011597, 48.149035998753135, 18.34011585371835, 34.27336181913103, 30.766328062329972, 30.04845060620989, 38.93507153647286, 4.9703960333551676, 1.7127700362886702, 0.5327700089131082, 5.814466238021851, 37.37071589061192, 74.46031461443219, 54.73001882008144, 57.58122600827898, 53.32646186011178, 58.21971334729876, 46.02325548444475, 56.05831984111241, 45.86710514341082, 47.548061983925955, 29.151406901223318, 7.199162747178759, 9.878110630171639, 33.425758021218435, 51.07246276310512, 59.139356068202424, 53.89048535483224, 55.303443227495464, 57.42967537471226, 58.967631340026855, 58.47784587315151, 59.30015822819301, 58.584764753069194, 55.336030278887065, 63.93944263458252, 48.0116423198155, 7.280926976885114, 11.693229368754796, 10.513757024492536, 14.809988021850586, 11.708947931017194, 15.113429750714984, 19.442206110273087, 10.91014654295785, 5.907203410352979, 9.93382476057325, 3.020111164876393, 0.31414029906902996, 0.06691758494291987, 0.2645653092435428, 0.23731300873415812, 0.14831753633916378, 0.7314891942909786, 0.4281982901905264, 1.8845607723508562, 1.0520021042653491, 0.2538187801837921, 4.548146622521537, 1.293439303125654, 0.31171288075191633, 0.49844341086489813, 0.3057868273130485, 0.18675244679408415, 1.4467908229146684, 0.8976599776319095, 0.5466634205409459, 1.6478088306529182, 1.2897296164716994, 0.7398829981684685, 0.17773724054651602, 0.5427214577794075, 3.4546282717159817, 7.817317485809326, 6.5176547680582315, 2.533106280224664, 1.8466444526399886, 1.5255989198173796, 4.58356636762619, 5.22314761366163, 1.722950558577265, 4.161917107445853, 14.309041142463684, 11.193041580063955, 7.86640042918069, 17.681061846869333, 25.72301459312439, 11.260100381714956, 13.71882815020425, 7.306084666933332, 2.5028551263468604, 7.950088007109506, 25.661528246743337, 34.97510208402361, 41.471452372414724, 40.118047509874614, 51.528803076062886, 51.26006065096174, 53.35057210922241, 50.42229550225394, 53.37129511151995, 49.32506029946463, 37.66905416761126, 23.832454919815063, 6.102098643779755, 0.30175866346274105, 5.590067216328212, 19.296154975891113, 40.15185744421822, 42.47276421955654, 53.747178758893696, 49.30105079923357, 53.02742876325335, 53.23043775558472, 53.75051042011806, 46.62558787209647, 41.09264005933489, 35.27407264709473, 27.042276007788523, 3.10849073103496, 2.132313992295946, 0.2391736331794943, 10.75989522252764, 82.19165856497628, 43.82088150296892, 30.87991026469639, 9.274247901780264, 10.514629891940526, 26.447859355381556, 40.375888211386545, 38.68251493998936, 32.59591729300362, 30.499593666621617, 41.231930596487864, 45.07523284639631, 36.80193287985665, 43.77293198449271, 48.71048171179635, 43.047401087624685, 44.057582310267854, 53.661201749529155, 69.68502616882324, 61.946497780936106, 0.26747288608125275, 0.42214057381664005, 0.14162864669093064, 0.12015389544623238, 0.11287035127835614, 0.1178594564220735, 0.11797613730388028, 0.13370985803859575], [0.051396584936550686, 0.08507432708782808, 0.06061021517962217, 0.05066691551889692, 0.04907759990809219, 0.06888438654797417, 0.02334161481953093, 0.041495232310678275, 0.0826651749334165, 0.030381809188319103, 0.05995096412620374, 0.08479791227728128, 0.09386299763407026, 5.940556934901646, 66.25917516435895, 55.78424119949341, 41.35432658876692, 27.417937312807354, 47.662411962236675, 45.070869377681184, 25.68922550337655, 44.46419784000942, 38.2190249306815, 31.324410847255162, 33.51579972675869, 31.343223094940186, 35.18684843608311, 20.904652527400426, 8.36195376941136, 28.17434253011431, 17.856628928865703, 27.957444088799612, 35.57436336789812, 0.6760347528117043, 0.7765691067491258, 0.06374465341546706, 0.7802803133215223, 21.417040484292166, 55.018018177577424, 54.49865770339966, 51.694823333195274, 54.27395990916661, 47.24200773239136, 47.589702538081575, 46.841072354997905, 42.19395732879639, 30.2432815687997, 22.860563482557023, 12.642812745911733, 5.774820685386658, 27.966466324669973, 49.64117554255894, 59.83052117483956, 52.58897311346871, 53.74349621364048, 48.75824015481131, 52.71170956747872, 52.82016052518572, 58.000230176108225, 54.11303962979998, 17.504843371255056, 0.7086172444479806, 6.097908880029406, 6.490349216120584, 5.085924165589469, 8.969700540815081, 9.036507470267159, 18.85265667097909, 16.790229831423076, 6.1694271223885675, 8.326387677873884, 2.5806614884308408, 0.23926656533564838, 0.6417555979319981, 0.24296846240758896, 0.05953494073557002, 0.1931848366345678, 0.10065412893891335, 0.3702233082481793, 0.4815054940325873, 0.19004434586635657, 1.2373197887625014, 0.30149949022701805, 1.9515789704663413, 2.6883068893636977, 1.4267858735152652, 0.5100445140685353, 0.17071274747805937, 3.46126640694482, 0.7813584783247539, 0.1737151156578745, 0.28341031659926685, 1.789515278169087, 0.978458679148129, 0.7319053262472153, 0.6886149006230491, 1.4719613237040383, 8.624314274106707, 1.304200325693403, 1.0113280011074883, 2.7542741724423, 1.0964558103254862, 0.797512442937919, 1.524599899138723, 1.0308605815683092, 0.07263428997248411, 0.693358240383012, 4.004354110785893, 1.4715436718293597, 7.745506116322108, 13.401774900300161, 26.62361056464059, 21.51456192561558, 8.840061920029775, 9.539521438734871, 4.779982822281974, 1.051582281078611, 2.508395880460739, 7.5428584303174695, 12.158459901809692, 21.40407340867179, 27.041376216070994, 30.851888179779053, 32.04615844999041, 26.150005715233938, 23.72283319064549, 13.041158182280403, 8.519223638943263, 2.529423952102661, 0.25973294568913324, 0.4952395313552448, 7.582972986357553, 28.727620635713848, 44.816179684230256, 42.75077206747872, 40.92479937417166, 44.059135232652935, 43.81862333842686, 42.34550796236311, 43.3533650125776, 47.31761455535889, 36.44517067500523, 11.245983379227773, 1.1696825495788028, 0.45837168395519257, 0.5379375687667302, 6.504421489579337, 66.22390610831124, 21.89789925302778, 13.990250842911856, 14.671873467309133, 26.913274015699113, 16.335524082183838, 22.365228142057145, 25.816615513392858, 25.257990768977574, 27.205077511923655, 23.17705045427595, 30.466454233442033, 29.633010864257812, 28.811890125274658, 30.643331050872803, 36.93443155288696, 30.666694368634904, 43.493447644369944, 42.42645100184849, 68.86723709106445, 12.815787281308856, 0.01992123683781496, 0.132309565320611, 0.044098394590296915, 0.046069423468517404, 0.10595396919442074, 0.07904280216566154, 0.01870098151266575, 0.04135431755068047, 0.044102231705827374, 0.010976797551847994, 0.07625506818294525, 0.12298650773508207, 0.04792213958821126, 0.019756176409178546, 0.058062336540647914, 0.08098668964313609, 0.060309658093111854, 0.1394381592316287, 0.10268987648721252, 0.13958047516644, 0.15711730771831103, 10.41094366141728, 79.32499858311245, 63.47376046861921, 31.142996856144496, 36.471559933253694, 40.72458355767386, 32.12781367983137, 30.847114767347062, 39.18038463592529, 31.826897621154785, 38.52353320802961, 31.325324535369873, 35.68018443243844, 32.70368037905012, 26.55738033567156, 15.375253507069178, 25.21957070486886, 14.115142975534711, 29.97818694795881, 42.27071755273001, 4.056744830948966, 3.089293509721756, 0.1843102771256651, 0.19862397334405354, 19.071747268949235, 56.436621461595806, 58.39653805324009, 51.86087833132063, 57.826271602085654, 51.01540763037545, 50.81427812576294, 49.76513487952096, 47.37523249217442, 32.748284339904785, 28.197490453720093, 15.354118824005127, 7.630591596875872, 25.399449144090923, 46.732579708099365, 60.23797743661063, 57.426781449999126, 55.90386486053467, 49.53940527779715, 52.99513006210327, 53.85134267807007, 56.93085377556937, 50.90643555777413, 12.726687925202505, 2.247903572661536, 11.978434681892395, 8.337041871888296, 5.854151742798941, 13.172910792487007, 9.237260035106114, 17.81399130821228, 23.237564052854264, 10.617479733058385, 10.075305717332022, 3.8661279508045743, 1.4897755278008324, 0.0867162596966539, 0.48182310270411627, 0.0305623911055071, 0.15411842720849173, 0.6507067233324051, 0.2770960054227284, 0.25855264759489466, 0.11945108244461672, 0.7400462808353561, 0.8619042219860213, 0.41795558695282253, 4.52662718296051, 3.2435682713985443, 1.1845686307975223, 0.8330383652022907, 9.969919783728463, 3.970660558768681, 0.1175825869930642, 0.40332563913294245, 1.1085029010261809, 0.25181308495146887, 0.29089037807924406, 1.0891122158084596, 0.5530927841152463, 6.495814408574786, 3.563116575990404, 1.957439124584198, 2.079399334532874, 0.2709289363452366, 0.3905704292867865, 0.1669021626668317, 0.2586010678538254, 0.762226613504546, 3.5782312963690077, 8.128709690911428, 8.193077802658081, 13.677211914743696, 19.214143650872366, 31.97436966214861, 20.254889999117168, 8.305961711066109, 13.798026323318481, 8.101048043795995, 4.187635864530291, 4.843136302062443, 7.543902397155762, 11.648570690836225, 22.798498698643275, 28.799256563186646, 31.625764642442974, 29.49879946027483, 24.741366147994995, 22.919058629444667, 13.206413269042969, 10.270903587341309, 8.115977116993495, 1.9899655963693346, 1.3508155729089464, 12.146147693906512, 32.28379378999983, 47.95632423673357, 45.55742393221174, 44.539175851004465, 45.00092881066458, 47.48472567967006, 45.871082987104145, 47.337764331272666, 50.568808691842214, 42.13871220179966, 13.218542218208313, 1.3572245261498859, 0.25769128810082165, 0.12423237945352282, 13.343059148107256, 77.04130635942731, 27.439712967191422, 17.382211140223912, 4.167327582836151, 13.41785216331482, 18.585712092263357, 27.7729937349047, 23.24546762875148, 26.65606038911002, 23.197420835494995, 28.158776828220912, 26.392935582569667, 27.089004380362375, 28.73925886835371, 25.446676049913677, 43.12069068636213, 23.043618985584803, 35.50826168060303, 47.96031250272478, 75.44019821711949, 15.402262892041888, 0.2757844515144825, 0.19529763183423451, 0.0541768753901124, 0.05121720741902079, 0.044423382330153666, 0.05062381836718746, 0.044086180959961245, 0.0521408869618816, 0.15541090071201324, 0.1672727106405156, 0.30185930377670694, 0.32596778869628906, 0.19089080473142012, 0.15229380583124502, 0.2411959118076733, 0.09820843767374754, 0.25640261439340456, 0.2543080039322376, 0.1743994453655822, 0.4513592688100678, 0.31296871336443083, 16.754307644707815, 95.46362808772496, 69.13982881818498, 57.4936717578343, 38.23386280877249, 64.04535402570451, 59.775199617658345, 33.7379857472011, 61.92934267861502, 49.950762953077046, 44.47430052076067, 45.05642754690987, 44.427052770342144, 49.69787631716047, 27.45789466585432, 12.206227898597717, 42.57392999104091, 25.617049353463308, 34.28948858806065, 44.98166493007115, 1.9156426702226912, 1.681214900953429, 0.6507923815931592, 1.196339639169829, 28.908365862710134, 61.7477445602417, 65.59997177124023, 61.18689291817801, 63.65921483721052, 55.52640049798148, 57.96161208833967, 53.61798742839268, 52.240395886557444, 34.99851751327515, 27.239264386040823, 16.308255876813615, 9.94154247215816, 32.09790168489729, 52.96299811771938, 65.26447800227574, 59.818785667419434, 58.38015420096261, 50.64520066125052, 54.78404106412615, 53.89708614349365, 61.07995319366455, 61.108135087149485, 21.299999816077097, 1.4372401982545853, 10.695212704794747, 13.412916336740766, 8.237308297838483, 11.523001977375575, 9.523489339011055, 29.8221720967974, 25.48263818877084, 12.705283999443054, 13.197292021342687, 4.374667474201747, 0.7173937420759882, 1.436305665544101, 1.261268817952701, 0.1447060201317072, 0.14638171664306096, 0.6818356301103319, 0.7075309913073267, 0.8650006758315223, 0.2947892945791994, 3.2939804920128415, 2.544034493821008, 2.9438043109008243, 13.443370291164943, 4.60358282497951, 1.5719314622027534, 1.2740991009133202, 10.65317610331944, 3.7550284266471863, 0.28117142245173454, 0.6154125343476022, 3.053195229598454, 3.0644660762378146, 0.8065295762249401, 2.3365942878382544, 4.383953741618565, 23.637554475239344, 13.345799343926565, 6.132818366800036, 5.03773797409875, 3.899702949183328, 2.1912887820175717, 3.7004021235874722, 2.423649787902832, 3.3378001749515533, 5.159072194780622, 7.110671358449118, 7.19870069197246, 14.37812100137983, 18.20671217782157, 34.84441689082554, 28.66083107675825, 11.15751804624285, 12.926830785615103, 7.765452657427106, 2.57247433917863, 5.631289141518729, 9.455587199756078, 17.709158624921525, 29.43577582495553, 31.717505182538712, 36.13986335481916, 34.66360739299229, 28.46539214679173, 27.62773643221174, 16.194843905312673, 10.206032599721636, 6.18878002677645, 1.420174011162349, 2.033348628452846, 10.334615962845938, 33.88291127341134, 53.527883189065115, 47.12012938090733, 47.10726479121617, 52.1714072227478, 51.439911297389436, 50.34355851582119, 50.25462852205549, 56.93231289727347, 42.851586954934255, 14.096091883523123, 2.511668699128287, 0.977690360375813, 0.36798601544329096, 10.461917383330208, 78.87610326494489, 28.012965406690324, 15.259588582175118, 19.909779923302786, 35.862998485565186, 24.209893226623535, 31.520092964172363, 37.013786928994314, 35.444494588034495, 37.13191325323922, 34.05028990336827, 41.838821002415244, 39.97175318854195, 40.52423919950213, 41.54943895339966, 50.720633779253276, 41.38833107267107, 60.00838116237095, 54.43519980566842, 83.68692479814801, 25.08127897126334, 0.6025411050234522, 0.29254603066614693, 0.23705532827547618, 0.2935568035713264, 0.2728793988270419, 0.18538097824369157, 0.151814570118274, 0.14438233178641113], [0.10321423477892365, 0.05483650303046618, 0.06114337407052517, 0.026695033269269124, 0.06097992176988295, 0.04196615596967084, 0.03457266877272299, 0.037820150942674706, 0.05672143938552056, 0.05145472860229867, 0.16018596876944813, 0.06507617660931178, 0.038920656711395295, 1.5022809824773242, 56.84664855684553, 67.60298456464494, 52.64072329657418, 29.286233220781597, 33.91213539668492, 44.85788972037179, 27.71155081476484, 34.39668887002127, 44.92824370520455, 30.2385151045663, 34.513613155909944, 33.66164588928223, 33.675302573612754, 27.95901264463152, 8.585918528693062, 9.795639855521065, 33.1234974861145, 16.878612654549734, 23.427237715039933, 50.83515051433018, 3.9172458478382657, 1.0225051556314741, 0.11700461086417947, 4.840934157371521, 41.15684488841465, 44.82682432447161, 48.30757304600307, 47.66841173171997, 46.32631506238665, 47.01018803460257, 50.00730391911098, 47.57166154044015, 52.03440611703055, 47.4461909702846, 32.94650949750628, 8.55678038937705, 4.305908100945609, 11.171554275921412, 31.896925040653773, 43.97993966511318, 49.5005578994751, 52.95548364094326, 54.587869099208284, 51.942373752593994, 32.84948485238211, 1.8952112751347678, 0.014297194246734892, 7.234195564474378, 6.294588931969233, 1.7184291269098009, 4.396505662373134, 5.792518181460244, 15.432577882494245, 17.097720623016357, 9.71937382221222, 7.598787086350577, 9.934358034815107, 5.517436393669673, 3.1655319673674445, 0.21851719516728604, 0.6851934013622147, 0.21097648622734205, 0.3043079195278031, 0.37476143187710215, 0.39845804604036467, 1.0579738638230731, 0.43494640237518717, 0.13287987400378498, 0.06123977354062455, 0.053369391576520035, 3.970113822392055, 0.8562520795634815, 0.13977313839963504, 1.9066226056643893, 2.828414491244725, 0.367166100868157, 0.22802535710590227, 0.09111455082893372, 1.1971657148429324, 0.9247438928910664, 0.7033746657626969, 0.49371793014662607, 0.8251900491969926, 3.328570144517081, 0.8795211623821939, 0.598835218165602, 1.039613031915256, 0.23936720564961433, 0.1990867613681725, 0.15942328183778695, 0.22648135067096778, 0.3695426562002727, 0.45460519034947666, 4.07683641569955, 0.1567713227123022, 12.975919808660235, 20.157677752631052, 21.537965195519583, 33.73851728439331, 26.587905509131296, 4.543491763728006, 8.875405669212341, 6.364320184503283, 6.4469307916505, 3.612521524940218, 1.6568401860339301, 3.8860762289592197, 9.347104106630598, 11.252659729548864, 10.768356391361781, 9.355954374585833, 5.755977605070386, 6.697663486003876, 0.8411236256361008, 0.4818622948867934, 1.6467365281922477, 3.846783297402518, 38.313367571149556, 50.0147419657026, 41.58747339248657, 53.87311833245413, 62.66341985974993, 41.1940073285784, 46.15944365092686, 42.54005404881069, 47.629209995269775, 39.187409264700754, 47.39689350128174, 24.18189893450056, 10.160841516086034, 0.35483820523534504, 11.751264197485787, 45.58350052152361, 29.822245052882604, 24.97059416770935, 15.191319056919642, 45.714411531175884, 22.382857458932058, 18.788220814296178, 23.14482297216143, 27.47821467263358, 25.843525886535645, 27.13859019960676, 22.26071333885193, 33.88005556379046, 31.136121613638743, 24.966347081320627, 40.24391760144915, 26.023765632084437, 33.03314658573696, 39.589841978890554, 54.45739235196795, 51.06372192927769, 1.3939510754176547, 0.34441753583295004, 0.036413541063666344, 0.12206288586769785, 0.0332236597314477, 0.0280164174535977, 0.061621795541473796, 0.046270256263336966, 0.044211577624082565, 0.05635595328307577, 0.0732136842395578, 0.09101156278380326, 0.015731252563585128, 0.06433565741670982, 0.04769069468602538, 0.019029436566467797, 0.03618292397420321, 0.05637645861133933, 0.003156717509097819, 0.10580710028963429, 0.02088734008637922, 0.07339141970234257, 2.52962002158165, 69.42618492671421, 75.85794476100376, 46.55586269923619, 27.7486663545881, 44.24743141446795, 28.50389906338283, 28.648214885166713, 35.79861995152065, 32.52810287475586, 36.37938860484532, 34.85904284885952, 34.587232794080464, 35.810973848615376, 30.038910729544504, 18.083465031215123, 23.545129537582397, 36.54199034827096, 15.284815754209246, 32.47238874435425, 52.44197007587978, 9.601481999669756, 3.714054899556296, 0.16694104272340024, 4.1500812854085645, 45.15970209666661, 48.21591935838972, 49.351081303187776, 52.89379753385271, 50.331260204315186, 50.60168061937605, 52.17556919370379, 49.0722952570234, 44.51130315235683, 44.42597232546125, 38.77769136428833, 12.085860780307225, 5.046116633074624, 10.362100430897303, 26.805702005113872, 39.2045122555324, 49.27181625366211, 51.06034163066319, 51.21361541748047, 48.139218194144114, 31.55850260598319, 1.7348421833344867, 0.6754303138170923, 12.677618878228323, 10.58885315486363, 6.2109443460191995, 10.359374131475176, 8.651170798710414, 12.671508806092397, 21.372410467692784, 13.627386382647924, 12.340712019375392, 9.638342193194799, 6.456384250095912, 6.160836109093257, 0.5300520690424102, 0.5041930451989174, 0.8164346675787653, 0.6265170042003904, 0.2742467554552214, 0.20912534770156654, 0.21166008311722959, 0.2747326950941767, 0.13142601773142815, 0.06825887904103313, 0.02207791120080011, 0.3603649543864386, 0.25198242015072275, 0.647781640291214, 3.558087165866579, 9.389013034956795, 2.1041297103677477, 0.30202087653534754, 0.07947293908468314, 1.521080419421196, 1.2271269985607691, 1.2157563801322664, 0.42480214099798885, 0.6345941764967782, 1.69199600815773, 0.4382418298295566, 0.09013728398297514, 0.16459014958568982, 0.11860182801527636, 0.14332197154206888, 0.06424314595226731, 0.13710964417883328, 0.21146952334259236, 1.9271228313446045, 7.035323355879102, 5.894597206796918, 19.108947924205236, 24.814442089625768, 26.899077108928136, 35.55191026415144, 22.65462061337062, 5.278898656368256, 13.964479105813162, 9.628754547664098, 11.03743406704494, 8.18697120462145, 3.8461918319974626, 3.998643560068948, 8.821433799607412, 11.966589740344457, 10.407284566334315, 9.338113137653895, 6.850522117955344, 9.336152877126422, 2.456512378794806, 1.813548771398408, 3.901537707873753, 4.892218376908984, 43.59272003173828, 45.927043778555735, 43.532541683741975, 51.3430221421378, 63.44109698704311, 43.31175919941494, 50.92805140359061, 47.58169821330479, 51.09980392456055, 43.17719343730381, 51.01199606486729, 24.82184886932373, 5.031266595636096, 0.8859037341816085, 21.66001204081944, 41.161837169102256, 36.65068449292864, 26.620324066707067, 11.517581513949803, 38.237038135528564, 17.182912485940115, 21.616386038916453, 24.433937890189036, 26.324792861938477, 27.25013484273638, 25.798190627779277, 26.643805503845215, 22.58167495046343, 33.09047269821167, 21.038603373936244, 37.42966788155692, 30.055819170815603, 27.370276144572667, 40.46647882461548, 62.25219072614397, 56.21045412336077, 1.7457207824502672, 0.4106952893946852, 0.031038946605154445, 0.09798787308058568, 0.017866929660418203, 0.017041786972965513, 0.032512507534452846, 0.025663198637110845, 0.02824036284748997, 0.16633800151092665, 0.2905682367937905, 0.20341040007770061, 0.18885631247290544, 0.1328836330877883, 0.14477319509855338, 0.12279404806239264, 0.12946517366383756, 0.21752809467060225, 0.17903044686785766, 0.22636646112161024, 0.16257627122104168, 0.21635148780686514, 3.116745408092226, 86.0277590070452, 79.4473216193063, 68.59038611820766, 42.41882535389492, 45.198580741882324, 63.17996283939907, 36.70171901157924, 49.68950373785836, 59.07099274226597, 43.67982612337385, 47.02404274259295, 48.81359992708479, 46.01089463915144, 40.49441753114973, 11.659108502524239, 21.008689641952515, 37.836200032915386, 23.151944875717163, 28.527460404804774, 62.74595751081194, 5.929769856589181, 2.6066401515688216, 0.38967633726341383, 5.46762215239661, 48.587786946977886, 54.95602634974888, 54.114488329206196, 57.76227174486433, 54.64807176589966, 56.90659761428833, 59.31239400591169, 55.64887292044503, 56.610243047986714, 56.77958454404558, 37.50485781260899, 11.851100257464818, 6.922029938016619, 15.939921447208949, 36.624455043247764, 45.22341012954712, 53.88710158211844, 53.065174852098735, 58.27156775338309, 54.008743694850374, 38.48779514857701, 4.742910708699908, 0.31405428797006607, 11.869671055248805, 14.624201876776558, 5.984001849378858, 9.00934088230133, 6.581238601888929, 25.896274873188563, 28.79928435598101, 20.415657418114797, 20.375187635421753, 15.857955285481044, 7.9350859778268, 6.423622625214713, 0.32682480556624277, 2.04419498358454, 2.189139400209699, 1.3925638241427285, 1.1906356023890632, 2.081109242779868, 2.5726984185831885, 1.1017465378556932, 0.2698272397475583, 0.2910203311060156, 0.10968306194990873, 7.185274166720254, 4.7435091223035535, 0.37601246046168463, 3.347034982272557, 14.622944252831594, 0.6191964255911964, 0.37630458335791317, 0.2636692358979157, 4.187069586345127, 3.534654800380979, 4.3831394995961865, 1.4320813779320036, 5.048116411481585, 11.334033557346888, 3.8283184596470425, 0.5925533409629549, 1.235331084047045, 0.7311881961567062, 0.3960620031825134, 0.4170100891164371, 0.40856981916087015, 0.6694235961352075, 2.0597033628395627, 6.4091165236064365, 3.9935813631330217, 20.080752508980886, 26.985799312591553, 28.262127808162145, 39.50182914733887, 35.80722529547555, 5.370457240513392, 12.368573427200317, 10.888302275112697, 12.301964521408081, 7.615426284926278, 3.0410133004188538, 5.131176045962742, 14.163204533713204, 15.957842588424683, 13.863041486058917, 11.857939021927969, 8.323114207812718, 9.870987858091082, 1.892724905695234, 0.4791043485913958, 3.1829059379441396, 4.61183728490557, 42.95643179757254, 54.9250373840332, 47.402618816920686, 53.08508838926043, 63.28857707977295, 48.423871994018555, 55.36445883342198, 51.021640164511545, 56.273213727133616, 47.17900146756853, 56.601470947265625, 28.746486731937953, 14.726727758135114, 0.8713303761822837, 13.468065057482038, 51.81530509676252, 36.186659472329275, 27.63705744062151, 22.855635472706386, 52.596053327832905, 27.028721809387207, 25.797945703778947, 32.723003319331575, 39.22162219456264, 34.09458466938564, 36.19208948952811, 31.37071364266532, 43.56245367867606, 46.58420787538801, 35.569958209991455, 51.42390264783587, 35.41479451315743, 44.753736223493306, 54.07453966140747, 64.34966427939278, 74.49276270185197, 3.0001856854983737, 0.5674315318465233, 0.13010797702840396, 0.17802286307726586, 0.10494493333888905, 0.14816748510513986, 0.11070233011352164, 0.2631906787199633, 0.1000220939250929], [0.03809037412117634, 0.028622992137180905, 0.016013099046956216, 0.026569701065974574, 0.02193563597808991, 0.0404958282597363, 0.040008860640227795, 0.04495940463883536, 0.04174529621377587, 0.09765801685197012, 0.17474355761493954, 0.06038614934576409, 0.25798384525946205, 0.34581548081977026, 22.648038932255336, 75.61461884634835, 49.36286197389875, 44.21205466134207, 24.548451151166642, 42.917452403477256, 36.09683663504464, 31.24587188448225, 46.240018435886924, 37.36700207846505, 29.250335352761404, 36.414178235190256, 32.23336376462664, 36.55255161012922, 18.31947101865496, 10.081565175737653, 39.66540363856724, 83.63654341016496, 18.68870002882821, 24.003005402428762, 33.781182697841096, 0.4642131105065346, 0.4356797901647431, 0.5011814896549497, 14.886683974947248, 32.389496735164094, 50.11076954432896, 48.10780191421509, 52.90039832251412, 47.09961135046822, 41.81597185134888, 47.97023453031267, 42.50567783628191, 47.0389084134783, 43.714782510484966, 13.770015529223851, 1.228444442152977, 1.389513999223709, 12.082245111465454, 26.39588335582188, 18.16567611694336, 14.897750718252999, 9.347837141581945, 3.5175733055387224, 0.15067910961806774, 0.9839917251041957, 10.669707604816981, 6.75299676827022, 1.222539124744279, 3.428160411970956, 6.230353270258222, 12.277334894452776, 11.221532668386187, 6.513483677591596, 1.771558853132384, 2.9701360293797086, 7.289715579577854, 5.917471545083182, 5.075582640511649, 1.267601883837155, 0.0676483196605529, 0.22204964847436973, 0.2037727242069585, 0.048518571869603226, 0.04997684879760657, 0.0484516615314143, 0.1686257366091013, 0.009934850203405534, 0.11646626118038382, 0.08635945884244782, 0.8286067172884941, 2.751507486615862, 1.9771563751356942, 0.21930639924747602, 7.7555184704916815, 6.0173362663814, 0.4448792593819754, 0.18204448584999355, 0.8730072262031692, 1.0070453052009856, 0.4943288287946156, 0.2982495246188981, 0.265452398785523, 0.7244754220758165, 0.44805005352411953, 0.5566815286874771, 0.08875236008316278, 0.021619577759078572, 0.031741623899766376, 0.026652891155598418, 0.06243972200900316, 0.037878922253314934, 0.5303335253681455, 4.905063424791608, 4.567761821406228, 14.145941734313965, 18.50453802517482, 25.604370628084453, 13.806129659925189, 30.802945068904332, 21.597698858806066, 3.9764223524502347, 5.461680574076516, 9.236660752977643, 10.542475666318621, 10.187629427228655, 3.3143673752035414, 0.13238655190382684, 1.0084840165717261, 1.0679058794464384, 1.6178680658340454, 0.7973004685980933, 2.566859326192311, 5.4819532462528775, 10.666554859706334, 3.5203864574432373, 8.347981810569763, 48.220039640154155, 40.74449014663696, 38.08074535642351, 36.69988121305193, 54.572357245853965, 50.766474519457134, 42.09752675465175, 43.53343105316162, 45.0182888848441, 44.06837286267962, 39.031185967581614, 26.269016197749547, 2.369240398917879, 1.802379759294646, 16.57735960824149, 32.97367000579834, 22.643810953412736, 33.769572257995605, 44.65994249071394, 56.55804818017142, 29.163698264530726, 15.483824321201869, 25.577798979622976, 25.682593447821482, 26.268194573266165, 28.87039395741054, 22.324016639164515, 42.975959709712434, 24.00165571485247, 38.74657733099801, 64.20282799857003, 25.274284294673375, 30.817869799477712, 40.39007990700858, 61.27032688685826, 16.07092104639326, 0.11576564663222857, 0.06114111454891307, 0.06725962087512016, 0.03373102072094168, 0.035121990367770195, 0.04103411687538028, 0.044203102721699646, 0.028387883145894324, 0.12067244547818388, 0.048814165472452126, 0.041161114882145605, 0.06432168638067585, 0.04824797210416623, 0.03318430470036609, 0.06193436269781419, 0.10076175137822117, 0.02148493266265307, 0.02906037920287677, 0.1200273758066552, 0.21773085450487478, 0.032182563096284866, 0.1597399948430913, 0.4057005931224142, 29.896792275565012, 83.71924086979458, 54.24935981205532, 29.34235382080078, 33.9921612739563, 40.66421413421631, 28.575851133891515, 34.65740959984915, 37.53691332680838, 32.53920957020351, 34.003056049346924, 33.258309909275596, 34.48925624574934, 36.04238360268729, 26.305499451501028, 22.38732167652675, 50.50458301816668, 79.27303995404924, 23.22824478149414, 33.1399438721793, 35.79367283412388, 3.831373929977417, 1.5281421776328767, 0.8337373105543, 17.45709535053798, 35.183141572134836, 54.30743285587856, 53.507775102342876, 55.60912575040545, 53.19669382912772, 45.96035691670009, 50.65822505950928, 45.11595623833792, 48.78963906424386, 45.555381161826, 17.39093460355486, 3.735479235649109, 6.6542980415480475, 22.88776568004063, 33.27610077176775, 22.944216319492885, 19.29847741127014, 11.454431074006216, 4.00712296792439, 0.3497474012630326, 2.977505245379039, 14.079933847699847, 10.81723609992436, 5.909051196915763, 12.944736293384008, 9.703362567084175, 10.199522137641907, 14.511232852935791, 8.544826882226126, 5.015171527862549, 7.0895688108035495, 7.8493556295122415, 7.293960928916931, 6.774378112384251, 1.4802027557577406, 0.26533981625522884, 0.11752054175095898, 0.11918330538485732, 0.12074450589716434, 0.09479011395680052, 0.19834187919540064, 0.17096612602472305, 0.007522729458287358, 0.13082585350743361, 0.06588993687182665, 0.3160851432808808, 0.42023712024092674, 0.9921507558652333, 0.7889142100300107, 8.652601259095327, 5.077878585883549, 1.2804017684289386, 0.9643330999783107, 2.364260494709015, 1.1050992608070374, 0.8198416190487998, 0.21117141576749937, 0.3321491341505732, 0.2672511136957577, 0.4167393265025956, 0.5021379526172365, 0.1924645852829729, 0.0170052699145994, 0.04304267552548221, 0.10674507995801312, 0.11058395289416824, 0.04383219512445586, 1.163930309670312, 4.575182931763785, 7.265263131686619, 20.292196614401682, 23.08736310686384, 28.467243841716222, 20.971421241760254, 30.473173141479492, 17.021094151905604, 6.5395216175488065, 12.315386704036168, 10.410254921231951, 9.5501252583095, 12.793640766824995, 7.007572250706809, 1.1820185333490372, 0.8370224514177868, 0.9858399459293911, 2.3071449995040894, 1.9349562738622939, 4.959783094269889, 10.929327045168195, 12.837345804486956, 4.078172206878662, 10.3590475661414, 50.41650765282767, 39.53441967282976, 40.684124197278706, 40.272134235927034, 51.680308546338765, 52.47990724018642, 47.502683298928396, 48.899177415030344, 48.98994868142264, 47.57645232336861, 38.573271887642996, 28.204016549246653, 3.0185888579913547, 2.6317559352942874, 18.442617416381836, 33.90768507548741, 24.478482791355678, 30.05279323032924, 48.827412945883616, 71.49061284746442, 37.919964041028706, 23.522688593183243, 23.971950428826467, 26.81724991117205, 22.52304083960397, 31.06347472327096, 23.561447381973267, 29.66470854622977, 29.13921454974583, 26.675339903150284, 67.49439811706543, 22.924047436032975, 29.767034666878835, 43.29472916466849, 70.50059877123151, 19.023759535380773, 0.18131721844630583, 0.1206115944577115, 0.07731715190623488, 0.04947055310809186, 0.07516952750406095, 0.06474760281188147, 0.023670741623001437, 0.019299574928092103, 0.034004344804478545, 0.16297016079936708, 0.17519909888505936, 0.10874394234269857, 0.1331507180418287, 0.11122689875108854, 0.13075563870370388, 0.3054604519690786, 0.16047729099435465, 0.07654387304293257, 0.3727687102343355, 0.39406008060489384, 0.22851401088493212, 0.4430243346307959, 0.5825882128306797, 40.27050835745675, 95.89534745897565, 62.6729736328125, 60.048910004752024, 33.10672453471592, 61.31191880362374, 48.42315285546439, 41.64744329452515, 61.26016862051827, 50.861866337912424, 40.80297660827637, 52.50423288345337, 43.70111887795584, 55.17950126102993, 25.72018493924822, 14.995873178754534, 43.89110347202846, 88.53137561253139, 24.401481117521012, 29.94576665333339, 40.88012940543038, 2.6600785298006873, 1.200415843299457, 1.2076750823429652, 20.383124215262278, 40.19266421454293, 60.17579105922154, 56.10019315992083, 64.07339695521763, 57.712790148598806, 51.63747985022408, 55.3287034034729, 51.15049450738089, 53.3149973324367, 52.20881632396153, 16.923605714525493, 3.4206593973296027, 5.2914670790944776, 21.603724684034074, 35.496140548161094, 24.744418144226074, 21.6772209916796, 13.225117819649832, 7.46128397328513, 0.5863987026470048, 2.4796709418296814, 16.16123025757926, 12.75458059992109, 5.215290069580078, 10.218591468674795, 7.063853527818408, 17.893452644348145, 25.26079089300973, 12.947237644876752, 11.794768605913434, 14.117954390389578, 14.412663102149963, 11.403129049709865, 10.38585979597909, 3.538808737482343, 0.45270542800426483, 0.2911165202302592, 0.34291911338056835, 0.17657264375260898, 0.10972307515995842, 0.48616507542984827, 0.36896348584975514, 0.14984698141259806, 0.490665608218738, 0.19627749068396433, 0.800048155444009, 9.3342673097338, 10.905354022979736, 0.9872104781014579, 19.24335561479841, 13.444125907761709, 2.640408830983298, 0.2715382607919829, 3.4936415382793973, 6.4465638399124146, 3.5480311683246066, 1.120772768344198, 0.7568756863474846, 0.4329983554780483, 1.83282014301845, 1.7691516280174255, 0.7522790729999542, 0.1717465091496706, 0.15202891933066504, 0.20277424635631697, 0.2661680360989911, 0.19556990079581738, 0.9883124189717429, 10.58272397518158, 7.536928142820086, 19.909020832606725, 26.80030151775905, 31.735775470733643, 22.27346154621669, 39.68862451825823, 27.731488670621598, 5.009873526436942, 9.106580921581813, 15.452651228223528, 15.26747305052621, 15.808268717357091, 4.979806499821799, 0.8810065569622176, 2.3810744839055196, 4.595265397003718, 5.259076748575483, 2.3837475861821855, 4.002682200499943, 10.368653450693403, 19.37737594332014, 6.045273670128413, 10.821764588356018, 49.97599186216082, 42.91260950905936, 44.27634981700352, 45.551417214529856, 55.5036347252982, 53.90122726985386, 52.27057191303798, 52.44148717607771, 54.690507888793945, 51.7645137650626, 47.331934792654856, 32.38655417306082, 4.174495952469962, 2.6647863686084747, 20.09416253226144, 37.0142628805978, 26.829947744097026, 43.20406559535435, 51.41258750643049, 57.86890227454049, 33.595693588256836, 23.778245074408396, 37.66926956176758, 36.722462858472554, 34.5510813168117, 41.16714211872646, 32.83081504276821, 58.44138172694615, 41.32665191377912, 49.007722173418315, 80.54622091565813, 33.62351417541504, 47.711831024714876, 49.293216705322266, 82.87640353611538, 31.121311528342112, 0.2218584373061146, 0.1728079414793423, 0.21159246031727108, 0.10712708160281181, 0.2148914568658386, 0.14266060345939227, 0.18892156040029867, 0.13011145112769945, 0.24194460734724998], [0.056474964932671616, 0.07646180423242704, 0.04111052331115518, 0.054769891247685464, 0.009385375937979137, 0.017911126038857868, 0.07187661062926054, 0.0315246351861528, 0.04773800554020064, 0.0425008381716907, 0.07780377686555896, 0.056216609331646135, 0.022026666539854238, 0.08844725681202752, 1.7850506263119834, 73.4722043446132, 57.94497462681362, 54.071809019361226, 30.799460547310964, 29.87824058532715, 39.36058269228254, 26.28443772452218, 36.17953062057495, 48.17637368610927, 31.11331762586321, 35.22900315693447, 35.592039585113525, 33.862893513270784, 31.078934465135845, 14.823917422975812, 22.030769654682704, 39.07279178074428, 64.65336309160504, 10.744700380734034, 18.7674491746085, 28.26301544053214, 1.290392735174724, 2.1181917786598206, 6.956718819481986, 33.89895118985857, 55.00852346420288, 48.68972396850586, 49.501301356724326, 46.17720324652535, 50.71114253997803, 48.00628178460257, 48.35444211959839, 49.89033446993147, 34.18771137510027, 33.749102864946636, 7.5231620243617465, 3.055914363690785, 19.561447620391846, 19.50393043245588, 6.606503989015307, 0.8835647968309266, 0.11462596564420632, 0.23159599836383546, 4.831149356705802, 10.24203816481999, 6.573410153388977, 5.690387913158961, 4.541940578392573, 5.124019401414054, 11.30184429032462, 14.667874779020037, 3.5364884734153748, 2.110981068440846, 2.8655163518020084, 1.6421489800725664, 7.480026738984244, 6.711434815611158, 9.7132203238351, 0.2788802539663655, 0.06189427484891244, 0.027413493288414817, 0.04234660376927682, 0.07720111563269581, 0.03539812358628426, 0.12370343426508562, 0.13122713911746228, 0.024637358861842325, 0.022516382226188267, 0.11227679598544325, 0.04613716161942907, 0.12440149752157074, 3.639319424118314, 1.7141520764146532, 3.358985883849008, 9.68035273892539, 1.4102372186524528, 2.004929844822202, 1.2686248975140708, 0.47768235632351463, 0.12080329417118005, 0.09572416490742139, 0.07431458016591412, 0.11773909788046565, 0.11927764889385019, 0.10199802182614803, 0.007908357024591948, 0.0139024302064042, 0.06456411337213856, 0.0508382659671562, 0.0828358604173575, 0.1199480007801737, 1.3905884729964393, 9.01243543624878, 7.949883903775897, 11.917699609483991, 23.652694599969045, 16.744340453829082, 21.195908852985927, 7.371757302965436, 16.789793831961497, 12.900212236813136, 3.0308965061392104, 3.3882708038602556, 6.836230976240976, 12.186802472387042, 12.87139458315713, 10.06313681602478, 1.6043863892555237, 0.018168570706620812, 0.9908930233546666, 1.747398555278778, 3.170619134392057, 5.36780389717647, 23.40789566721235, 5.934467273099082, 12.676223158836365, 50.26771545410156, 41.51384333201817, 50.70669221878052, 42.92411225182669, 42.579950605119976, 47.168534006391255, 47.75072704042707, 43.32242121015276, 44.915222781045095, 40.856251920972554, 24.733611958367483, 6.380806088447571, 1.3565596703972136, 2.3086744717189243, 34.1703200340271, 50.94623136520386, 91.58956963675362, 35.36217927932739, 26.60174458367484, 71.28154155186245, 22.12226700782776, 19.216499090194702, 30.992505822862896, 22.375360352652415, 36.69710193361555, 25.25122148650033, 24.219554696764263, 34.568615095955984, 21.315992832183838, 76.77897712162563, 36.842232431684224, 26.144690343311854, 37.80201836994716, 53.48418944222586, 40.30022580283028, 1.8446980885096957, 0.16772575490176678, 0.0594721491049443, 0.00518311102808054, 0.02037007418195052, 0.04715982585081032, 0.0384038674778172, 0.04940159020147153, 0.030872976939593042, 0.08449420678828444, 0.04455708087022815, 0.031406458134629896, 0.09911019714283091, 0.01848399619172726, 0.07947216555476189, 0.03957903923998986, 0.019698819844052196, 0.055857762694358826, 0.02632153875726674, 0.013539313039343272, 0.056055104426507435, 0.030949403731418506, 0.06524256018123456, 0.06360552659524338, 2.844705411366054, 81.83431271144322, 67.17516313280377, 41.84501879555838, 22.854539394378662, 40.301497323172434, 31.095641408647808, 26.22631778035845, 35.00351326806204, 36.64370502744402, 34.91258219310215, 35.44525194168091, 35.27617447716849, 36.52715594427926, 32.78337969098772, 24.933836460113525, 24.29176037652152, 41.61154890060425, 58.971807207380024, 12.014518414224897, 17.34284438405718, 30.878371238708496, 4.9955867273466925, 2.430000658546175, 4.50102003131594, 34.200919900621685, 61.00610773903983, 53.399383204323904, 54.43019362858364, 49.84906217030117, 52.253552300589426, 50.99470547267369, 50.09910004479544, 57.67648581096104, 37.928201130458284, 36.52307735170637, 8.151284388133458, 8.057880623000008, 31.089558260781423, 26.677914210728236, 11.550277999469213, 1.7425138631037302, 0.5036334437983376, 0.7853365934320858, 6.652867581163134, 17.790898970195226, 10.647592357226781, 11.505275385720388, 13.247166190828596, 10.317603298595973, 10.653352413858686, 15.531515019280569, 5.189052368913378, 4.543607711791992, 2.840702380452837, 5.454073165144239, 9.568597912788391, 5.03314174073083, 7.2437984091894965, 0.2034238486417702, 0.15487339241164072, 0.0855262517662985, 0.01365530351176858, 0.01879716045888407, 0.035050374389226945, 0.08435254224709102, 0.18607323324041708, 0.12486940169973032, 0.08339259840015854, 0.12088364628808838, 0.011840906809084117, 0.09736220272524015, 1.7620019316673279, 1.01206559581416, 3.5486137313502173, 5.959435624735696, 6.360819595200675, 3.6173485687800815, 1.0826766639947891, 0.11096694520009415, 0.12067540389086519, 0.017130820945437466, 0.07629527138280016, 0.02541271404230169, 0.07467511974807296, 0.0861179410879101, 0.11607005101229463, 0.06116694637707301, 0.018152635311707854, 0.028193240286782384, 0.12831109416271957, 0.20087979015495094, 1.5399330535105296, 6.387156307697296, 5.930628393377576, 14.575422048568726, 29.281042916434153, 19.40774825641087, 27.547753981181554, 12.414008566311427, 21.027955259595597, 11.250326871871948, 7.295229843684605, 10.216150045394897, 12.292429855891637, 11.97873866558075, 14.44138695512499, 15.24472985948835, 3.603164038487843, 1.1959010341337748, 0.32190398818680216, 0.11494141657437597, 4.489254994051797, 10.745338746479579, 21.210074492863246, 8.403487495013646, 15.503701380320958, 54.1985650062561, 51.61238990511213, 52.386526925223215, 48.452185903276714, 48.47741481236049, 50.479496547154014, 50.82306064878191, 48.80799967902047, 49.313832010541645, 45.85782929829189, 25.186417375292095, 9.742182152611868, 4.08157856123788, 3.9192299927983965, 39.05177000590733, 53.222099917275564, 83.89048617226737, 38.53264924458095, 25.362403086253575, 95.90740953172956, 29.136230298451014, 26.35670941216605, 28.38992428779602, 25.6698956148965, 27.909346921103342, 28.166975702558243, 19.495316403252737, 34.33503402982439, 19.82767653465271, 69.63523537772042, 45.07886675425938, 20.86798514638628, 39.90360178266253, 59.550967352730886, 51.244639124189106, 1.9808691016265323, 0.23689163848757744, 0.057248935901692936, 0.11662559477346283, 0.06047328681285892, 0.054243666984673054, 0.07651337967919451, 0.011379056011459656, 0.019187652273103595, 0.0736353937536478, 0.15358456942651952, 0.18455932661890984, 0.20554959028959274, 0.15596052764781884, 0.16803503116326673, 0.0762662368693522, 0.13726033323577472, 0.25703500903078486, 0.09859038503574473, 0.16119541174599103, 0.14485269226133823, 0.12224435327308518, 0.14673635975590774, 0.2865413485893181, 3.7383279970714023, 101.23706000191825, 71.6276660646711, 70.79340975625175, 47.016959054129465, 40.05563531603132, 57.38599552427019, 35.284411566598074, 50.03744520459856, 62.90218080793108, 42.747148581913535, 50.72024120603289, 50.18078306743077, 49.05125611168997, 44.44587891442435, 22.408402511051722, 30.686809403555735, 48.67773485183716, 81.35713127681187, 14.085777282714844, 23.090201445988246, 33.889039584568565, 2.876146227121353, 2.6889982351234982, 8.754721539361135, 39.2225775718689, 66.56649398803711, 57.61262491771153, 59.905388014657156, 55.483078479766846, 57.592582838875906, 58.34292575291225, 56.95047548839024, 59.53840500967843, 42.829067843300955, 40.01675319671631, 9.133892553193228, 5.363514253071376, 25.070959159306117, 23.858792066574097, 9.95510709285736, 1.7192331637654985, 0.6025041927184377, 1.1253375176872527, 7.08826949766704, 19.640752622059413, 11.961561850139073, 11.33624655859811, 11.027453848293849, 5.257604164736612, 15.170140947614398, 26.42859547478812, 10.658364670617239, 10.216368913650513, 10.081807494163513, 12.506440452166967, 15.078966685703822, 13.797633750098091, 13.82720354625157, 0.3593579812773636, 0.20111414257969173, 0.22446600667067937, 0.11985576072973864, 0.14330261972333702, 0.1272134959165539, 0.16535536066762038, 0.5965343873415674, 0.18741165713540145, 0.24371053544538362, 0.25381443755967276, 0.17040755599737167, 0.6521472803183964, 7.193714925221034, 1.865371150629861, 11.146730967930385, 20.104610885892594, 6.98574709040778, 3.000611479793276, 8.751350794519697, 7.148045718669891, 0.7015875673719815, 0.14787118243319647, 0.22652755890573772, 0.3167321942746639, 0.6664056352206639, 0.36533508769103457, 0.3292015508881637, 0.11295814692441906, 0.23868432800684655, 0.412383321672678, 0.2681990813996111, 0.49451366173369543, 3.1834945806435178, 12.514549868447439, 15.547329119273595, 15.035929543631417, 33.16073635646275, 21.60969318662371, 28.35815191268921, 14.827273402895246, 26.26238935334342, 17.80979459626334, 4.282254261629922, 5.276643531663077, 12.343537330627441, 17.801281315939768, 21.674770014626638, 18.135764122009277, 3.1242577135562897, 1.5485598934548241, 2.857903297458376, 5.104316481522151, 5.983436005456107, 8.275869931493487, 32.91416910716465, 10.746808290481567, 15.86662142617362, 58.42834690638951, 48.017503125326975, 57.11817373548235, 51.547323499407085, 51.05574539729527, 52.40879242760794, 56.1866843359811, 53.05322047642299, 53.341973713466096, 47.73167507989066, 31.10623046330043, 9.673197831426348, 2.6573674295629774, 4.1999359130859375, 42.440715653555735, 62.73532676696777, 108.15434605734688, 45.152903284345356, 29.47175359725952, 70.8070490700858, 26.87516835757664, 29.065204075404576, 44.40229981286185, 31.27906342915126, 47.811329228537424, 39.18794775009155, 34.84475040435791, 51.568915026528494, 31.033166681017192, 89.67291600363595, 49.580184255327495, 36.27362659999302, 55.87322677884783, 60.683627946036204, 67.88735348837716, 3.4437808309282576, 0.3391059637069702, 0.14287663543862955, 0.21856072997408255, 0.0991355539964778, 0.15578815261168139, 0.17168806014316423, 0.11322116066834756, 0.11158772331795522, 0.14564908881272587], [0.06660213401275021, 0.038930688851646016, 0.007881442084908485, 0.04638718481042555, 0.01379600283689797, 0.024658410410795892, 0.019498182128050497, 0.02904904427539025, 0.10178415437362023, 0.03620531223714352, 0.12014918641320296, 0.08462053643805639, 0.044326311110385826, 0.03736653671200786, 0.18698891624808311, 29.851827008383616, 78.0815211704799, 48.62840264184134, 41.65252937589373, 32.745178495134624, 40.97518423625401, 38.365065642765586, 31.042977537427628, 44.3038056237357, 35.780307974134175, 31.838796411241802, 32.953933647700715, 29.95450053896223, 37.54740163258144, 25.918448311941965, 18.351872205734253, 11.095248290470668, 31.515833718436106, 74.28342042650495, 44.506203174591064, 84.3593784059797, 32.508154596601216, 0.8195610855306897, 3.470329463481903, 17.573257071631296, 44.94033357075283, 49.315871306828086, 51.479648045131135, 53.88937711715698, 47.927763666425435, 49.155951568058555, 53.01705510275704, 45.981934547424316, 44.388267925807405, 55.966846806662424, 17.803951161248342, 3.5673291385173798, 3.208019984619958, 1.2612510131938117, 2.9448254789624895, 2.4177987532956258, 2.641009198767798, 10.577571017401558, 13.378158841814313, 9.230781708444868, 6.995264385427747, 7.239442757197788, 5.711464839322226, 12.922816463879176, 11.40010745184762, 2.524046697786876, 3.4800858199596405, 3.488716785396848, 1.0777895833764757, 6.851246033396039, 6.3445521252495904, 6.160439193248749, 7.019495359488896, 0.40442152747086113, 0.5042343001280511, 0.10411654386137213, 0.24510883327041352, 0.0740333002592836, 0.033627293072640896, 0.031030933106584207, 0.1632100229284593, 0.05481730727478862, 0.018826064354340945, 0.05274750744657857, 0.012693756625854542, 0.06695320124604873, 0.5570323584335191, 1.2476272242409843, 3.1927741169929504, 2.372093502964292, 3.4116986095905304, 4.194158051695142, 0.5985812289374215, 0.08774847430842263, 0.057645790678049834, 0.014247593336871691, 0.02931894175708294, 0.05434785603678652, 0.03401770855167082, 0.25494550115295816, 0.027476408751681447, 0.04567245673388243, 0.04002568152334009, 0.05052282860768693, 0.09860609312142644, 0.051572878512420824, 0.12482129356690816, 7.412782073020935, 4.3506640536444525, 10.63329383305141, 16.712410007204326, 16.430971486227854, 10.926878673689705, 10.466637815747942, 1.531154330287661, 8.23742207459041, 12.840578453881399, 4.04716500214168, 3.446595937013626, 9.756133266857692, 15.310609204428536, 16.739898817879812, 18.799176386424474, 8.051276360239301, 0.485759148640292, 1.6059626532452447, 6.882738743509565, 9.090094583375112, 9.128833396094185, 3.488423441137586, 16.95374005181449, 56.21395601545061, 36.570064544677734, 47.01542002814156, 44.667543819972444, 44.42673315320696, 38.517738410404746, 44.60283177239554, 41.27162218093872, 45.218122550419395, 45.1174362046378, 25.884813819612774, 17.256961175373622, 2.143337743622916, 22.141586474009923, 62.00484875270298, 47.461195605141775, 42.039971351623535, 54.79756573268345, 32.21699033464704, 12.140185270990644, 20.233114344733103, 22.154272147587367, 29.981473445892334, 24.492994104112896, 31.08085216794695, 19.69262613568987, 38.80158969334194, 24.047614574432373, 43.225139481680735, 65.12006664276123, 27.436591488974436, 42.0958696092878, 38.30659655162266, 69.2713234765189, 16.2663026537214, 0.2517944388091564, 0.05513475988326328, 0.08393186410622937, 0.06672019232064486, 0.08139399385878018, 0.07630365807563066, 0.0033736114398509797, 0.013338460736641926, 0.04988422876756106, 0.03860515828377434, 0.06592735807810511, 0.009900507001605417, 0.03512046705665333, 0.031085748558065722, 0.025458432035520673, 0.03487801631646497, 0.010532716738193162, 0.03668371335204158, 0.08528379084808485, 0.019452160490410667, 0.1303877912993942, 0.1344778782555035, 0.05103489523753524, 0.06795757556600229, 0.2271601435329233, 36.16722188677107, 84.81911291394914, 53.89582504544939, 29.67939008985247, 38.53428554534912, 37.50579581941877, 32.343235628945486, 30.416409833090647, 35.19696501323155, 36.452205726078574, 33.65793555123465, 33.52165705817086, 31.486734662737163, 34.14777660369873, 33.142261096409385, 24.674269131251744, 15.55386563709804, 36.52606507710048, 52.831079619271414, 45.653124945504324, 78.61513587406704, 40.44775342941284, 4.01270888532911, 1.864863280739103, 20.91633071218218, 47.70392744881766, 54.19930846350533, 53.243274552481516, 57.856680393218994, 52.021583216530935, 51.39552967888968, 53.82882009233747, 49.1695213999067, 44.067497389657156, 57.42052807126726, 17.290378536496842, 7.837674839156015, 8.305163536752973, 4.198186269828251, 4.236684935433524, 2.101810097694397, 3.463442713022232, 13.236284443310328, 19.2228810106005, 13.324532645089285, 12.727744051388331, 15.962120941707067, 11.803130762917654, 14.440798095294408, 13.519136922700064, 8.506412897791181, 1.1793827776397978, 5.2338365486689975, 1.9096292214734214, 8.675905517169408, 10.516161101205007, 3.49519967181342, 4.068578481674194, 0.5512812041810581, 0.41953060243810925, 0.03223330733765449, 0.07468943005161625, 0.0036848162250992444, 0.0688107315716999, 0.07211657453860555, 0.2205107310520751, 0.1919421540307147, 0.1301971636712551, 0.1506738034742219, 0.10133497097662517, 0.1128818728029728, 0.5925917189036096, 0.7587055053029741, 1.0974237812416894, 2.3514558332306996, 6.719423506941114, 5.693292694432395, 0.8506893951978002, 0.06725022995046206, 0.042921984501715214, 0.06119859325034278, 0.160608546808362, 0.11566943036658422, 0.22488850328539098, 0.14669681473502091, 0.07406475714274816, 0.15542092945958885, 0.09707837152693953, 0.06776603191558804, 0.1268377367939268, 0.09389963173972708, 0.4621160573193005, 6.801499537059239, 2.248644641467503, 13.680368133953639, 25.92913290432521, 16.61037049974714, 17.17619010380336, 15.807061467851911, 5.1736238939421515, 13.19461783340999, 11.869594625064305, 7.339231048311506, 11.689567668097359, 18.95647665432521, 18.682731526238577, 17.250310012272426, 22.040771586554392, 10.690635578972952, 2.67713440316064, 2.1149615177086423, 1.4795003363064356, 8.297862717083522, 14.220891952514648, 6.351141623088291, 15.625122887747628, 61.99308545248849, 40.23493010657174, 52.15387691770281, 47.57945394515991, 50.11468138013567, 42.376795700618196, 47.64918259211949, 45.16997848238264, 48.46292781829834, 48.2928706577846, 32.45452839987618, 20.61248425074986, 4.188624680042267, 30.26503985268729, 58.900289399283274, 58.64039897918701, 45.69038118634905, 60.463126863752095, 24.60549933569772, 6.893432455403464, 24.223226819719585, 24.73987228529794, 27.713461569377355, 24.625774179186138, 29.296169144766672, 21.647317681993755, 26.54753647531782, 30.018813065120153, 34.42941835948399, 76.1087955747332, 31.88672161102295, 35.603691714150564, 43.585681506565635, 75.50819328853062, 18.26585350717817, 0.28487568082554, 0.03480333335963743, 0.07636256848594972, 0.04312229821724551, 0.04344659385138324, 0.02898511609860829, 0.04107235571635621, 0.009304382605478168, 0.050570169995938025, 0.05473195096211774, 0.18414966788675102, 0.08616743343217032, 0.1327457819133997, 0.13308112749031611, 0.09342462329992227, 0.16488577372261456, 0.12383730922426496, 0.2043465341308287, 0.1915693533207689, 0.0921795115407024, 0.2771778367459774, 0.2521410887794835, 0.18109235194112572, 0.2112780271896294, 0.35764166765979355, 47.17190040860857, 100.53630638122559, 61.69527176448277, 57.878977162497385, 45.32503795623779, 56.947564193180625, 52.885018484933035, 45.33293458393642, 59.3740245274135, 49.48460830960955, 43.246241160801475, 47.48074088777815, 44.55224541255406, 53.63443381445748, 36.68839931488037, 31.26722022465297, 18.475874968937465, 42.78982094355992, 88.06463732038225, 52.33824041911534, 92.38750076293945, 39.46825197764805, 2.4906310737133026, 4.935677622045789, 22.32529510770525, 54.7218268939427, 57.03883225577218, 59.875073024204795, 63.057556424822124, 59.87255082811628, 56.72020523888724, 60.58561665671212, 52.32370826176235, 52.72232641492571, 63.774659156799316, 20.21557535443987, 9.504948939595904, 7.704914740153721, 3.6657180190086365, 6.9507216555731635, 7.807417171342032, 6.997295430728367, 14.151557615825109, 23.442918062210083, 14.570759807314191, 13.056650059563772, 13.129105005945478, 6.5124883481434415, 16.975477491106304, 21.288125344685145, 11.243998800005231, 7.750897918428693, 9.462915812219892, 6.329949617385864, 13.67343556880951, 14.31264899458204, 10.374390057155065, 8.137198652539935, 0.6459320081131799, 0.8425697194678443, 0.10699155780353717, 0.6026136268462453, 0.12711808032223157, 0.13993980017091545, 0.18576079500573023, 0.5716395889009748, 0.32501930530582157, 0.1212530814643417, 0.3772608834717955, 0.17017622983881406, 0.2866761056440217, 0.9060362481645176, 5.14180418423244, 10.351539169039045, 12.049806577818734, 7.388813393456595, 6.494988007204873, 1.72172127025468, 0.23473254005823815, 0.1620056911238602, 0.24762997084430285, 0.20535107808453695, 0.31701066504631725, 0.4199439116886684, 0.6718044398086411, 0.1734826359897852, 0.2839740977755615, 0.19327964154737337, 0.1430104018322059, 0.21296046833906854, 0.15180321144206183, 0.8560276201793126, 22.759713854108536, 11.070288624082293, 19.518968071256364, 25.317733117512294, 20.286681481770106, 19.21329770769392, 19.149834598813737, 7.271490020411355, 18.022918428693497, 18.751886946814402, 4.9025768382208685, 6.322887207780566, 15.313289472034999, 22.69305978502546, 20.884914432253154, 26.38908975464957, 12.486186453274318, 2.348774262837001, 5.996693168367658, 15.229720013482229, 16.31404546328953, 17.47343577657427, 7.707649724824088, 20.70649685178484, 63.533799852643696, 40.95418330601284, 54.135169642312185, 50.10807711737496, 52.75756767817906, 43.73192719050816, 51.451573848724365, 49.065545082092285, 52.51032645361764, 53.39787891932896, 32.18015793391636, 20.287058421543666, 3.8027985947472707, 29.09411726679121, 75.03838389260429, 57.02099275588989, 50.31197200502668, 62.306560380118235, 39.94046197618757, 12.357255680220467, 26.97313448360988, 31.53832851137434, 41.92617375510079, 32.74325384412493, 43.86743095942906, 30.785793440682546, 54.723178318568635, 39.139369419642854, 56.54790728432791, 80.1700107029506, 35.95276573726109, 60.1305513381958, 49.323476110185894, 84.65978377205985, 31.465035438537598, 0.5391568147710392, 0.3125037540282522, 0.12863744236528873, 0.11214345028357846, 0.18583611239280018, 0.20355355739593506, 0.15677665599754878, 0.0901217862431492, 0.13197639105575426, 0.1852702684700489], [0.041056148907435794, 0.01563986237826092, 0.06443135121038981, 0.03739853981616242, 0.007419856764110071, 0.011275387734973004, 0.009200809323894126, 0.02085234464279243, 0.0235180441024048, 0.0056095092191493934, 0.01970511325635016, 0.03861566539853811, 0.08752309890197855, 0.042276443248348575, 0.12064082574631486, 1.2753162298883711, 65.89384583064488, 59.46720681871687, 43.11605971200125, 25.1371077469417, 43.329386779240195, 34.30101217542376, 30.785602365221294, 41.84204149246216, 43.15204790660313, 32.429021562848774, 36.345550877707346, 30.041082041604177, 32.014384337833945, 34.58762884140015, 16.116386583873204, 20.90704791886466, 16.658910615103586, 61.81581606183733, 37.7382686478751, 44.86930561065674, 57.31453677586147, 6.35775283404759, 2.0651008103575026, 10.565904123442513, 38.913973331451416, 52.609824657440186, 51.6339327948434, 48.059306962149485, 48.74206474849156, 53.8646901675633, 48.339288098471506, 42.130662713732036, 38.93624578203474, 48.47132471629551, 17.428110940115793, 10.153793437140328, 16.16288045474461, 7.259909978934696, 6.511023581027985, 3.8858955757958547, 19.698071786335536, 21.671780552182877, 12.016523838043213, 9.02464863232204, 10.608292477471487, 4.964704590184348, 11.94661019529615, 19.754232338496617, 6.156605524676187, 6.680265196732112, 4.566111624240875, 2.5619701828275407, 3.9602895038468495, 8.333887389728002, 9.13488961969103, 5.031735164778573, 4.375690596444266, 0.24237520567008428, 0.2563182589198862, 0.029748379785035337, 0.274239970105035, 0.04422997270843812, 0.11269796267151833, 0.2506889695567744, 0.36852273664304186, 0.17760564546499932, 0.3531851853643145, 0.4482574952500207, 0.14802652624036583, 0.29540635432515827, 0.10448177890586001, 0.8845918817179543, 0.30615182487027987, 0.7844626946108681, 6.662459569317954, 2.8980341383389066, 0.019305598622720157, 0.16230602429381438, 0.10094189564032213, 0.052713777470801554, 0.07725286749856812, 0.02667993925777929, 0.048926541049565585, 0.05242489457928708, 0.07494324964604207, 0.06439403178436415, 0.022090133312823515, 0.04890576091461948, 0.08875740838370152, 0.1674362240093095, 0.10670121266905751, 2.386812610285623, 3.4532484029020583, 5.184611601488931, 14.807399817875453, 14.42987813268389, 5.38337915284293, 3.6333402820995877, 5.733215306486402, 5.849257605416434, 14.358032022203718, 15.935648305075508, 7.9909564426967075, 5.045326275484903, 12.955315794263567, 26.376588208334788, 27.955790417534963, 32.03848763874599, 24.184391600745066, 7.493737271853855, 3.452469987528665, 13.25538330418723, 12.697622741971697, 5.578965732029506, 5.661953713212695, 44.05177361624581, 43.90702526909964, 49.47370311192104, 45.982841287340435, 47.001763343811035, 39.93396888460432, 50.11147826058524, 46.87119279588972, 44.59443834849766, 41.60796710423061, 42.71792098454067, 34.22075700759888, 8.688822218350001, 36.60127585274832, 32.68984304155622, 43.31173140662057, 49.43958050864083, 34.76907409940447, 76.44169766562325, 48.527382782527376, 17.34021622794015, 26.375537293297903, 25.992592539106095, 21.57058698790414, 26.909768649509974, 20.783759083066666, 37.78517593656267, 22.11933660507202, 65.300400188991, 31.06922435760498, 23.13882667677743, 36.51010506493704, 54.4091614314488, 44.564154624938965, 1.1474058649369647, 0.2570938244462013, 0.029351470725876943, 0.06394901459238359, 0.04104334495163389, 0.09348813417766776, 0.03919031670583146, 0.015612491971946188, 0.06666863044457776, 0.10329898380275283, 0.023643634149006436, 0.1257696005382708, 0.010406852733077747, 0.0724069739558867, 0.04236712266824075, 0.019284569126154696, 0.006899411499034613, 0.024523722905931727, 0.01582894633923258, 0.05997310472386224, 0.019393440069896833, 0.0326825178760503, 0.10243946313858032, 0.07445338128932885, 0.026567205753443495, 0.15257549285888672, 2.6391242827687944, 77.50229154314313, 66.77576678139823, 38.06709214619228, 24.546022755759104, 53.89922966275896, 29.635873522077286, 35.31622389384678, 29.761684553963796, 37.30077879769461, 35.92000150680542, 31.56978648049491, 31.054831164223806, 31.111191477094376, 35.0700353213719, 23.09712185178484, 21.330229691096715, 20.623764651162283, 58.487093925476074, 42.40456765038626, 47.345636640276226, 59.31645175388881, 7.896935156413487, 2.9665336055415015, 15.09182606424604, 45.11453880582537, 55.62549918038504, 55.807872022901265, 51.16404349463326, 52.90482432501656, 56.849472999572754, 52.69623940331595, 46.53147104808262, 42.9242651121957, 52.32700170789446, 19.835948365075247, 5.950133289609637, 18.627830335072108, 8.41225699016026, 2.637309717280524, 4.265128254890442, 21.907414810998098, 24.886882271085465, 18.473222494125366, 14.848613057817731, 19.12583899497986, 11.312663504055568, 13.995494995798383, 18.26443954876491, 8.780207531792776, 5.583512025220053, 1.5689844489097595, 3.7617004343441556, 6.340013648782458, 14.44592239175524, 11.780694161142621, 7.3474941934858045, 1.8174410653965813, 0.20119089846100124, 0.7596865583743367, 0.07282515508787972, 0.5039843821099826, 0.6860322334936687, 0.2006606233439275, 0.3329067592109953, 0.49189087961401257, 0.1436204726674727, 0.3397202007472515, 1.0050701711859023, 0.4092164087508406, 0.25852857317243305, 0.15680856071412563, 1.0460905986172813, 0.5723483594400542, 1.2453225936208452, 2.8895427882671356, 7.444617850439889, 0.21619948239198752, 0.14635655656456947, 0.12274910190275737, 0.0447747888309615, 0.05407096625172666, 0.01717106655373105, 0.0772997678390571, 0.029321089320416962, 0.053415481067661724, 0.10538775207740919, 0.09816045846257891, 0.019977229547553828, 0.02797500985408468, 0.1208902687898704, 0.21660607414586203, 2.412402391433716, 7.765877366065979, 8.34305032661983, 24.657560450690134, 18.684261866978236, 10.597553168024335, 9.36259685243879, 6.026959087167468, 3.199282842023032, 11.517155936786107, 14.573645046779088, 12.371969359261648, 12.112827607563563, 25.63955977984837, 30.258536338806152, 28.78953950745719, 34.14809969493321, 28.363488129207067, 11.402442915099007, 4.865146892411368, 3.1607846106801714, 9.112317528043475, 4.6284360970769605, 7.244436340672629, 46.443510328020366, 50.1644617489406, 56.28519589560372, 51.17596312931606, 54.223297119140625, 41.589054107666016, 55.66399914877755, 51.279658045087544, 49.81430033275059, 44.45730522700718, 47.276665346963064, 27.027226209640503, 7.254188137395041, 43.43488475254604, 37.51825393949236, 52.14830446243286, 54.55739082608904, 40.632749216897146, 74.63720880235944, 28.827019827706472, 16.46555093356541, 26.29186361176627, 23.9262330191476, 20.394352504185267, 27.510419573102677, 16.139805487224034, 31.388931819370814, 25.30619215965271, 63.40919780731201, 45.782146045139854, 17.293750149863108, 36.12047093255179, 61.77844170161656, 48.73442867824009, 1.128025927713939, 0.3773852725114141, 0.15590036873306545, 0.08950802417738096, 0.04670786385291389, 0.05977553568248238, 0.03243345481210521, 0.022124463792092035, 0.10431881515043122, 0.025126572432262555, 0.10120877703385693, 0.14200045673974923, 0.1408589437071766, 0.19513787754944392, 0.1961797544998782, 0.1583929264119693, 0.11989550931113106, 0.2183556088379451, 0.11090337325419698, 0.10139244967805487, 0.053843704517930746, 0.11073368521673338, 0.21305850307856286, 0.16155248401420458, 0.13764014999781335, 0.4089468675000327, 4.982826794896807, 96.48416560036796, 72.05145059313092, 59.96190466199602, 38.49121713638306, 64.01640088217599, 46.42283943721226, 46.05986554282052, 58.62562710898263, 56.56215109143938, 46.92077514103481, 50.934541021074565, 44.23010608128139, 44.86589404514858, 47.218689577920095, 27.111902168818883, 30.036117553710938, 21.158249616622925, 73.99174894605363, 45.55129214695522, 54.65201834269932, 68.74731813158307, 9.645052415984017, 2.7736815767628804, 15.691457339695521, 47.819465569087434, 63.49249281202044, 60.49982724870954, 59.54806300571987, 59.69487844194685, 63.54675824301583, 56.8652732031686, 51.993095602308, 46.89284685679844, 54.926840441567556, 23.019913469042095, 15.578846148082189, 29.446239812033518, 18.22196694782802, 17.362813506807598, 6.871546498366764, 28.438551255634852, 29.86192968913487, 21.255404540470668, 18.28615093231201, 16.21245411464146, 5.725180149078369, 16.195457083838328, 25.49141550064087, 12.735656312533788, 9.39061198915754, 6.1690011109624585, 6.10655243907656, 10.809323838778905, 15.758908714566912, 12.027310916355678, 8.003543104444232, 8.954642925943647, 0.3424646034836769, 0.8368489635842187, 0.0979403213464788, 0.5759455721293176, 0.6436407853450093, 0.29839760810136795, 1.3048253378697803, 0.7033534411873136, 0.3122127982122557, 0.5414828870977674, 1.3672856262751987, 0.6994892656803131, 0.5900350532361439, 0.18820490528430256, 2.8666059161935533, 2.087829670735768, 1.4912647221769606, 9.966668026787893, 5.678735784121922, 0.25138783348458155, 0.3624097875186375, 0.20552886783012322, 0.17916877301675932, 0.10683955238865954, 0.19542641778077396, 0.24828711843916348, 0.1717831093285765, 0.190064009811197, 0.14608796526278767, 0.24319085904530116, 0.13954584273908818, 0.2798257789441517, 0.23937561948384556, 0.309894895447152, 8.481307319232396, 12.152533088411603, 15.238403524671282, 23.386608123779297, 21.37245041983468, 14.508985979216439, 11.087378587041583, 11.990192770957947, 5.858871306691851, 17.639112097876414, 18.392607757023402, 10.69099862234933, 6.143131230558668, 18.548539229801722, 32.94589458193098, 33.886392320905415, 36.936324937003, 35.7357109614781, 10.835552419934954, 8.572928871427264, 26.20501807757786, 21.29595422744751, 11.875256538391113, 8.460065807615008, 51.85441303253174, 50.172052655901226, 56.13608060564314, 53.083688327244346, 52.45643622534615, 45.42747524806431, 57.80720574515206, 55.30235583441598, 50.39341531481062, 50.312152658190044, 49.16585275105068, 39.39848511559622, 12.62006868634905, 45.90143619264875, 41.880934034075054, 54.577168873378206, 58.87592901502337, 41.48496661867414, 91.70444420405796, 63.52836636134556, 26.0986168384552, 36.63566943577358, 35.005205154418945, 31.587622506277903, 38.95139980316162, 31.014389174325125, 54.78508676801409, 37.071147782461985, 78.42246232713971, 44.16037048612322, 33.72506904602051, 53.44447353907994, 62.987240655081614, 68.48521818433488, 1.587156268102782, 0.4129648261836597, 0.21719258624528134, 0.17998894543520041, 0.10414486591305051, 0.1502011902630329, 0.15567993984690734, 0.12700556564543927, 0.2958794832229614, 0.16207247254039558, 0.17280897285257066], [0.03160842747560569, 0.022748626103358607, 0.013944722445947784, 0.05452668054827622, 0.044142509544534345, 0.02323037069956107, 0.07499295912150826, 0.024789640779740045, 0.030060668742018085, 0.02799699778136398, 0.023256146548581973, 0.08036707182015691, 0.06577734077083212, 0.08433564672512667, 0.0784931005910039, 0.22745230714125292, 28.7167831829616, 79.39861474718366, 54.38417223521641, 43.9896810395377, 29.627167429242814, 58.54603549412319, 22.289145367486135, 47.24765314374651, 42.6934563773019, 36.32863548823765, 33.01172181538173, 34.36564779281616, 26.876790761947632, 38.374574252537315, 18.273948158536637, 22.728202036448888, 33.13220010484968, 45.27508388246809, 51.52682283946446, 52.77232565198626, 47.93725837979998, 8.48375482218606, 0.5917402931622097, 13.118680102484566, 38.52626385007586, 55.48493364879063, 50.34122044699532, 49.76692056655884, 48.60005399159023, 51.10766233716692, 44.079003606523784, 46.88308116367885, 46.357408251081196, 48.7039851461138, 15.438695771353585, 5.373000715460096, 11.824380091258458, 5.117644429206848, 9.36643920625959, 32.23744930539812, 33.09427683694022, 21.202782358442033, 18.826335157666886, 14.059223873274666, 3.423122316598892, 11.051016058240618, 21.914833750043595, 14.252587897436959, 11.055496777806963, 10.033962198666163, 4.0987953288214545, 1.8148083495242255, 3.057956482682909, 7.354575276374817, 8.482956647872925, 2.8196182889597754, 2.2997764348983765, 0.3601634294859001, 0.8512232122676713, 1.076271836246763, 0.3912354478878634, 0.3568745973919119, 0.055176971546773396, 0.14247733115085534, 0.03655602323955723, 0.0650791757340942, 0.06979968957602978, 0.0516075312958232, 0.22055494439389023, 0.022536624622132097, 0.15486529070351804, 0.15699209086596966, 0.05109596338921359, 0.1444447027253253, 4.146969795227051, 4.280318754059928, 0.03898593856553946, 0.12573001480528287, 0.018979079090058804, 0.04385885137266346, 0.1039063065711941, 0.03579979935394866, 0.1823435840862138, 0.09818949976137706, 0.040517782260264666, 0.09100090978401047, 0.04566658062062093, 0.19432573898562364, 0.08381032491368906, 0.12249140787337508, 0.09516631412718977, 1.034000190240996, 4.446481883525848, 1.5340087371213096, 13.526048643248421, 6.518333085945674, 3.7092024513653348, 3.595810673066548, 4.424318867070334, 12.00482394014086, 14.801785673413958, 16.10196386064802, 18.54504602296012, 14.339504650660924, 5.463106257574899, 10.680251496178762, 32.650766372680664, 36.57380267551967, 39.38495697293963, 44.74443258558001, 26.762887205396378, 9.267876403672354, 10.16982901096344, 8.435113957950048, 0.7614689884441239, 37.645305224827354, 47.711976936885286, 40.46486684254238, 50.29380941390991, 45.158541747501914, 39.54411588396345, 34.3766884803772, 29.430286748068674, 34.112827164786204, 39.80341918127877, 39.48314544132778, 10.390815598624092, 9.366024051393781, 55.449720178331646, 45.29754046031407, 38.42688029153006, 51.10068981988089, 56.17831175667899, 55.202506746564595, 69.88794136047363, 18.388072320393153, 28.283578634262085, 20.962176663534983, 28.12691065243312, 23.991044078554424, 33.51287106105259, 31.908782141549246, 48.27367973327637, 72.01092175074986, 15.006953818457466, 34.74849353517805, 39.64528512954712, 62.848707471575054, 8.395616054534912, 0.11948700408850398, 0.13759607236300195, 0.02153293222987226, 0.0639391215518117, 0.11990650157843318, 0.005959478922055236, 0.01183770242745855, 0.03611598649461355, 0.024682150654760853, 0.005149638895610613, 0.007099813848201717, 0.03299182806430118, 0.03976325810487781, 0.020888281553717594, 0.0689570644338216, 0.05062073442552771, 0.09619774163833686, 0.08439176835651908, 0.055058930202254226, 0.05339725900973592, 0.033105570889477215, 0.047757075766899755, 0.02905373295236911, 0.18889008994613374, 0.14642458648553916, 0.09746015604053225, 0.2100377601704427, 35.020168100084575, 87.11222689492362, 58.92815167563302, 28.16691837991987, 36.97400849206107, 51.465362548828125, 23.771595648356847, 48.59413412639073, 25.72402208192008, 40.54300280979702, 32.68577487128121, 34.163128648485454, 27.11622221129281, 36.32569987433297, 22.90525429589408, 22.5205968107496, 26.034889698028564, 50.70666790008545, 49.54016957964216, 61.03708280835833, 48.2804160118103, 8.732999733516149, 1.3220577389001846, 12.589913504464285, 43.3529064314706, 60.23009817940848, 56.35241971697126, 55.687782832554404, 51.07851116997855, 60.37103543962751, 50.10250813620431, 47.247802530016216, 50.10115671157837, 54.87688289369856, 16.580345596585953, 6.539276693548475, 4.967640204089029, 2.3809830716678073, 10.272537282535009, 32.755041463034495, 35.15133271898542, 27.28646002496992, 23.06672521999904, 22.191335575921194, 11.497723562376839, 12.678181682314191, 20.538313967841013, 14.151477711541311, 8.697311179978506, 5.0665478110313416, 4.120130641119821, 5.445487797260284, 10.768364208085195, 14.191313471112933, 11.582214525767736, 6.137618269239153, 3.3791109068053107, 0.4600739926099777, 0.07523340479071651, 0.7245692227567945, 0.5623384479965482, 0.11948305501469544, 0.06923908394362245, 0.05020474496164492, 0.040980838305716, 0.16861390295837606, 0.0282798315331872, 0.034757997042366436, 0.7226884865335056, 0.3416172760937895, 0.5953603046280997, 2.038565857069833, 0.5550464221409389, 1.5759337331567491, 3.2271928872380937, 6.675041454178946, 0.13297203263001783, 0.2046302974756275, 0.08159280461924416, 0.06800884567201138, 0.039010006202650924, 0.1011780733242631, 0.07170233569507088, 0.4709094368985721, 0.21346042651150907, 0.034881242750478644, 0.03486179932951927, 0.0643755349197558, 0.08480847028217145, 0.22119027030255112, 0.05430627201816865, 0.02054996568975704, 8.047708460262843, 4.963252850941249, 18.5186220237187, 19.13857330594744, 10.122308543750218, 3.6119439559323445, 6.253191130501883, 7.979815874780927, 10.106914809771947, 14.971552746636526, 18.32397518839155, 17.12438780920846, 11.671108041490827, 22.87004951068333, 40.47273915154593, 37.775597844805034, 41.17635890415737, 46.5225704056876, 30.49641833986555, 11.452076503208705, 4.443244891507285, 2.5408439678805212, 0.18143046594091825, 41.11625698634556, 56.16017001015799, 50.54657098225185, 55.08261210577828, 47.151861803872244, 42.95029306411743, 38.03910827636719, 35.96073532104492, 40.040064402988975, 46.28545618057251, 42.58227130344936, 10.855987071990967, 12.836809924670629, 58.932042666843955, 49.626764978681294, 46.36922713688442, 55.33903884887695, 57.90234048025948, 59.81367874145508, 67.26251588548932, 22.416839361190796, 25.27540990284511, 21.84696200915745, 26.359519958496094, 22.41022641318185, 25.48934667451041, 32.67262887954712, 42.53022929600307, 83.53931726728166, 14.551271847316197, 26.830851009913854, 48.399553298950195, 65.4157680783953, 6.732001049177987, 0.1832327228039503, 0.02865696299288954, 0.0626819318692599, 0.07026117481291294, 0.1849703017090048, 0.013589196389407983, 0.07366860804281064, 0.11145749209182602, 0.012406788051261433, 0.06659744533577136, 0.04785339720547199, 0.15693062916398048, 0.1049524379361953, 0.0954231396317482, 0.18495827806847437, 0.2557726353406906, 0.20023394695350102, 0.10474443981157881, 0.1284968363387244, 0.16004424994545324, 0.10479780659079552, 0.25679412909916466, 0.2281353340617248, 0.24822081199714116, 0.2468060664832592, 0.2520751623170716, 0.320367160652365, 47.46003873007638, 99.05053833552769, 68.305906023298, 61.481010164533345, 41.05418178013393, 76.93413039616176, 31.83528757095337, 70.30527796064104, 56.5586005619594, 49.27878182274954, 48.505190236227854, 47.349520683288574, 41.186482429504395, 51.11732380730765, 28.1112858908517, 28.416770390101842, 38.02499648502895, 53.28485952104841, 57.57021311351231, 65.31871564047677, 59.090968813214985, 11.182073848588125, 1.3544214708464486, 17.365931510925293, 45.81387846810477, 66.1619073322841, 65.66306141444615, 62.10761955806187, 57.53872387749808, 59.9716807774135, 53.587627274649485, 54.273417949676514, 51.892680236271445, 58.392424719674246, 20.64465093612671, 11.904212287494115, 19.702725342341832, 14.697845833642141, 15.667559010641915, 41.55635935919625, 41.51863758904593, 29.338970048086985, 26.499586956841604, 19.196797473090037, 5.909252260412488, 13.853554589407784, 25.6653619153159, 20.048941918781825, 16.30185832296099, 11.537786875452314, 6.825926797730582, 8.311162437711443, 11.883497970444814, 13.25800277505602, 10.345245838165283, 6.1730371458189826, 5.647156655788422, 1.2482592931815555, 2.6916526641164507, 1.8726272412708826, 2.818961901324136, 0.43152303035770145, 0.4226137841386454, 0.17636653195534432, 0.1564443502575159, 0.23463008127042226, 0.07228276133537292, 0.07829815069479601, 1.1378267960889, 0.39529181165354593, 0.8227594824773925, 2.0395338279860358, 1.5448151401111057, 1.5436140788452966, 10.142638972827367, 7.150939643383026, 0.22012019343674183, 0.3906880872590201, 0.18483150058559009, 0.14502928778529167, 0.20469561325652258, 0.12833586069090025, 0.3991180163409029, 0.6015394787703241, 0.5772073215671948, 0.22335014226181166, 0.22299612340118202, 0.34618077693240984, 0.3750886214630944, 0.25108623823949267, 0.13858463003167085, 2.4930562121527533, 10.567255548068456, 11.450414146695818, 23.640582152775355, 17.9698098727635, 14.035851001739502, 4.572997289044516, 7.0867191808564325, 13.10040807723999, 15.499101672853742, 20.7514134815761, 24.05894534928458, 17.201068128858292, 5.864566223961966, 13.772093040602547, 40.593422412872314, 42.39276960917881, 43.28927482877459, 52.84064728873116, 32.79881511415754, 15.468597343989781, 24.282020739146642, 18.21970878328596, 1.9879879653453827, 45.08574199676514, 55.01598582948957, 54.57819025857108, 60.50168241773333, 50.73343236105782, 45.80919885635376, 42.763278824942454, 37.64106682368687, 42.19960968835013, 47.835939747946604, 45.92128372192383, 13.750725592885699, 13.791131973266602, 66.0329487664359, 53.061454091753276, 48.59952245439802, 59.712186404636924, 65.86335713522774, 63.57701069968087, 84.08096408843994, 30.63892936706543, 38.52668421609061, 30.75939723423549, 39.672730513981406, 34.50487927028111, 47.33639901024954, 50.11692564828055, 61.73789896283831, 84.7889438356672, 23.120528595788137, 50.90819692611694, 53.203638553619385, 79.03290326254708, 16.65799171583993, 0.6901666287864957, 0.25137127723012653, 0.21075650517429623, 0.17568777980548994, 0.35762847693903105, 0.09808347866471324, 0.12619762042803423, 0.28699602133461405, 0.1135179925976055, 0.14450121112167835, 0.09131010462130819], [0.010498616960830986, 0.027300468014021004, 0.02212099647814674, 0.015946419410673634, 0.02763050575075405, 0.020525952335447073, 0.046184384264051914, 0.03930935210415295, 0.06737552822700568, 0.028381023156855787, 0.06632061661886317, 0.029992126527109315, 0.010243370746528464, 0.15282979421317577, 0.03020782602418746, 0.09837061432855469, 1.3723694277661187, 72.17610822405133, 55.30836255209786, 63.16881792885916, 32.93445437295096, 82.97285842895508, 51.806147371019634, 21.918128933225358, 59.43618311200823, 28.65246023450579, 31.541757447378977, 28.513954843793595, 29.210866110665457, 32.35925817489624, 26.08295907293047, 20.404939821788243, 27.934270109449113, 43.09224476133074, 65.58556120736259, 58.860844475882395, 75.11104120526994, 41.339068344661165, 3.762432166508266, 9.446640525545392, 46.167482716696604, 53.82030160086495, 51.548601967947825, 49.15117815562657, 44.71783140727452, 37.444168772016255, 45.23540619441441, 50.88048751013619, 33.9262888772147, 42.58154174259731, 8.263348409107753, 3.802796423435211, 12.74692976474762, 9.470454607691083, 46.26962471008301, 46.29825823647635, 37.07368040084839, 29.901715074266704, 19.80864541871207, 4.025667275701251, 10.405246138572693, 22.400443349565776, 17.10326181139265, 18.037462745394024, 13.591041224343435, 13.60664427280426, 6.173917395727975, 3.57380616239139, 1.8540334275790622, 10.956947003092084, 7.029136419296265, 3.6621696608407155, 1.4459713697433472, 0.13388596501733574, 0.3799844687538487, 0.19828990341297217, 0.833035976759025, 0.15017540593232426, 0.08967170039457933, 0.11677420751324721, 0.13463988527655602, 0.2566507410790239, 0.26468142015593393, 0.1311503696654524, 0.6469442737954003, 0.3485265810574804, 0.6290039164679391, 0.8655360671026366, 0.4616876574499266, 0.2529900717948164, 3.1301652022770474, 7.3541436195373535, 0.18579344611082757, 0.04926950657474143, 0.05826205653803689, 0.09449541941285133, 0.07033212921981301, 0.09621311724185944, 0.13397531450859138, 0.17836892950747693, 0.08284622843244246, 0.043359575127916675, 0.06019113838140454, 0.02628179356854941, 0.08226061878459794, 0.06685298840914454, 0.25231264957359856, 0.2913842701486179, 3.5736826147351946, 2.546055333954947, 11.317810382161822, 4.965174462114062, 3.808830065386636, 7.283129990100861, 6.846618967396872, 7.761175172669547, 13.188817824636187, 18.15745292391096, 18.150991099221365, 21.951852015086583, 20.247429370880127, 7.50560826914651, 7.367087244987488, 28.574883597237722, 41.348510946546284, 35.61246034077236, 44.428254808698384, 37.26883445467268, 13.29563856124878, 2.8283365411417822, 0.5077430861336845, 26.52516153880528, 32.004034996032715, 38.71243040902274, 48.999592781066895, 36.923894609723774, 41.25952884129116, 35.53103787558419, 37.33223329271589, 37.33417878832136, 45.33095434733799, 38.97397102628435, 27.55550295966012, 40.5033529145377, 57.78176839011056, 47.60246637889317, 52.36266681126186, 51.29843207768032, 51.757218156542095, 43.48317125865391, 33.01202058792114, 17.873245545795985, 25.89855214527675, 22.179775510515483, 27.667535713740758, 24.09544423648289, 39.309433528355186, 30.699733052934917, 77.55913475581578, 21.729881388800486, 26.409546988351003, 47.88622038705008, 60.64924825940813, 27.714013951165335, 0.27871352434158325, 0.3154009628508772, 0.08586944799338068, 0.17443802686674253, 0.03529407363384962, 0.03258459509483405, 0.08410216282520976, 0.07709890111748662, 0.02562587072939745, 0.07510331605694123, 0.03730618780744927, 0.041851707468075414, 0.08187371811696462, 0.027795846075085655, 0.021801662631332874, 0.06191431198801313, 0.05457868007943034, 0.0515768547276301, 0.0496541782548385, 0.04011607935119953, 0.045592046941497495, 0.032881881642554484, 0.04357115252475653, 0.028872699809393713, 0.2340939843228885, 0.14166508402143205, 0.07296546255903584, 0.07027610936867339, 2.0056657024792264, 77.32102693830217, 64.31354059491838, 54.60506589072091, 28.67660869870867, 91.09188406808036, 37.43374994822911, 32.787284578595845, 39.337337493896484, 26.57176831790379, 35.21095173699515, 29.153414930616105, 31.935859271458217, 26.688775982175553, 29.044289997645787, 20.176290239606583, 20.650464841297694, 50.761930397578645, 67.8126950945173, 59.81007957458496, 76.18055656978062, 42.4635648046221, 4.5394227249281744, 7.2376918111528665, 52.2933098929269, 59.35308960505894, 58.435427120753694, 52.86896467208862, 51.232702119009836, 45.5487699508667, 48.5065347126552, 53.03681925364903, 39.94748313086373, 47.398880686078755, 9.053003362246923, 2.8003257470471516, 6.697997433798654, 12.363514270101275, 42.91004214968, 46.49060869216919, 43.640666076115195, 33.66976138523647, 29.847651141030447, 11.331591265542166, 11.34560751914978, 19.145240102495464, 18.40887870107378, 11.9346011025565, 10.597116300037928, 8.952580179486956, 6.869921488421304, 6.308759348733084, 11.85528654711587, 15.33103517123631, 10.40826860495976, 4.832215905189514, 1.7039638459682465, 0.26495967379638125, 0.14810979605785438, 0.2684348044650895, 0.2241616972855159, 0.038307708887649436, 0.09232667221554688, 0.004943958392167198, 0.1561369603233678, 0.20641654091221945, 0.19260364424969467, 0.3216494561306068, 0.34214924754840986, 0.053422741392361264, 1.3475936715091978, 0.5176320554954665, 0.4929888578397887, 1.8681046153817857, 5.737941384315491, 8.758521335465566, 0.3045103943773678, 0.13673589351986135, 0.18171912830855164, 0.08958817273378372, 0.09136170042412621, 0.08364155289850064, 0.10718515741505794, 1.1088967770338058, 0.0956578856067998, 0.005732620492511029, 0.045843705401888916, 0.042844763823917935, 0.12927610666624137, 0.13930528850427695, 0.1897008035864149, 0.5214756578207016, 9.53528824874333, 6.186907487256186, 11.892054677009583, 14.37530871800014, 6.7238490751811435, 4.1890285440853665, 5.172004529408046, 7.02176524911608, 12.821341497557503, 16.598833015986852, 16.057160139083862, 21.046263762882777, 18.74365333148411, 13.716635125023977, 19.076091630118235, 42.627990450177876, 44.13796949386597, 39.81259080341884, 43.952709674835205, 38.67831127984183, 15.677343811307635, 8.477888805525643, 1.825385136263711, 24.382140806743077, 48.26454980032784, 38.94028615951538, 54.6927730015346, 39.515426771981375, 48.92265885216849, 37.664523942129954, 42.46637882505144, 39.36586332321167, 51.13163014820644, 42.02254179545811, 30.57917833328247, 44.868614264896934, 57.95883975710188, 50.083435331072124, 57.33244923182896, 54.85388435636248, 53.2489720753261, 49.84085634776524, 43.02342980248587, 18.933848108564103, 26.116888863699778, 18.575692789895193, 28.16325146811349, 19.193615198135376, 35.517975262233186, 34.20865671975272, 79.0730152130127, 28.91056149346488, 20.873031275612966, 51.115517275674, 67.22523185185024, 24.915342092514038, 0.3501420643712793, 0.4434318356215954, 0.09950382209249906, 0.06632219082010643, 0.06521203289074556, 0.05316040279077632, 0.045751265183623345, 0.030547911168209145, 0.051045476991151056, 0.045433612407318184, 0.018800183332392147, 0.04853681767625468, 0.10599814860948495, 0.19252967036196164, 0.150649756193161, 0.17335467785596848, 0.16662044849778923, 0.1837545840867928, 0.14834539698702948, 0.13136435246893338, 0.1992759776434728, 0.17959452659956046, 0.1576958131045103, 0.13209546038082667, 0.4126484388751643, 0.3584293382508414, 0.17152754589915276, 0.2469476903123515, 3.1604945233889987, 101.79065077645438, 68.47899954659599, 86.118300982884, 45.31627280371529, 100.07022816794259, 69.54579816545758, 33.277278491428916, 86.86193888528007, 39.17966897147042, 46.07366813932146, 42.549885749816895, 42.71139662606375, 45.84975201742989, 36.42322131565639, 28.41029814311436, 34.94510323660714, 53.653885296412874, 78.20902756282261, 66.91917760031563, 88.30472537449428, 51.653450284685405, 5.486402264663151, 12.554483771324158, 55.462352003370015, 65.52312469482422, 65.11065878186906, 60.597129821777344, 55.877802167619976, 45.56671019962856, 53.59347070966448, 58.36241544995989, 40.53110749380929, 52.689051491873606, 10.992125732558113, 7.450501237596784, 24.552845886775426, 15.820068495614187, 53.73016956874302, 51.213886397225515, 46.01989950452532, 38.42264189038958, 28.278468234198435, 5.774289582456861, 11.667869312422615, 26.17594334057399, 22.92261437007359, 23.37370010784694, 18.972645112446376, 16.054650102342876, 8.544522898537771, 8.227220382009234, 11.617063215800695, 16.65000649860927, 10.60180025441306, 4.963841710771833, 1.4423446272100722, 0.21697134311710084, 0.9844019945178712, 0.6437787722264017, 1.7186205280678613, 0.25467992254665917, 0.3351426678044455, 0.4199959417538983, 0.6650996452995709, 0.36802675468581064, 0.6573812280382428, 0.4883424671632903, 1.329863280057907, 0.547558109675135, 1.5295674268688475, 2.27847130383764, 1.2559912268604552, 1.6297323320593153, 9.667987551007952, 12.808698381696429, 0.2563347066087382, 0.2960728114204747, 0.19969825712697847, 0.21554470966969216, 0.2747384219297341, 0.1605872136673757, 0.1625089741178921, 0.39652913383075167, 0.2611498353736741, 0.17639285911406788, 0.1770620032080582, 0.12705447444958345, 0.29407270731670515, 0.1691665290189641, 0.20368340185710362, 1.669044045465333, 11.315523556300572, 10.610708713531494, 21.10122922488621, 12.8789507491248, 8.443959883281163, 6.755324414798191, 5.414356827735901, 9.011063167027064, 19.11267736979893, 24.93535464150565, 23.51913980075291, 27.696261303765432, 23.879275356020244, 9.659751330103193, 10.283672639301844, 35.624505043029785, 50.22316707883562, 41.388497829437256, 49.00771869931902, 43.691888196127756, 17.776804549353464, 8.917492645127432, 2.267150951283319, 33.51717894417899, 39.79699557168143, 46.29582289287022, 60.66204684121268, 42.661181994846885, 51.7984869820731, 41.50892053331648, 43.87445558820452, 45.092856952122276, 54.98925610951015, 46.843757833753315, 33.01380974905831, 48.636400018419536, 67.20130225590297, 54.51547234398978, 64.5051371710641, 58.854215894426616, 62.486115728105815, 50.113500186375205, 41.24263082231794, 28.20197377886091, 37.3672001021249, 31.66871840613229, 37.59922824587141, 37.16603585651943, 58.451567786080496, 49.0029730796814, 90.44286673409599, 35.17695420128958, 40.466020243508474, 64.82368428366524, 70.04763875688825, 46.032201290130615, 0.29739755604948315, 0.6444426508886474, 0.15022217056580953, 0.4063576864344733, 0.1969693928424801, 0.25425195693969727, 0.19373136945068836, 0.24933914627347672, 0.2212585580668279, 0.2608167289623192, 0.08318013551511935, 0.28063082003167694], [0.03314999457714813, 0.012165447563997336, 0.07030792587569781, 0.12163912717785154, 0.01581494985813541, 0.05707793829164334, 0.0510010770522058, 0.03767635580152273, 0.07552005869469472, 0.10764658158378941, 0.06631637577499662, 0.07990878248321158, 0.0507519698834845, 0.03245725103520921, 0.046306676630462916, 0.10102255988333907, 0.3126271388360432, 19.022680827549525, 82.28122779301235, 51.06407976150513, 52.72243063790457, 29.545050144195557, 97.61017676762172, 16.80100475038801, 38.29098047528948, 43.77242129189627, 29.640758105686732, 32.64067758832659, 28.21814397403172, 30.01175022125244, 20.875697646822246, 25.068047864096506, 77.54431424822126, 77.08437824249268, 40.470831871032715, 66.95913669041225, 54.987105642046245, 81.95981802259172, 21.548392704554967, 7.923513753073556, 54.174204621996196, 51.73197535106114, 48.839666094098774, 38.41381767817906, 47.10722310202462, 46.52083683013916, 50.779519762311665, 48.51282978057861, 35.51116950171334, 32.1251004082816, 1.56914165190288, 3.4721800727503638, 10.383436611720494, 50.982577392033164, 55.7955459186009, 49.99141338893345, 40.99921805518014, 29.06364941596985, 5.874777904578617, 11.352180515016828, 19.6950250012534, 14.858210257121495, 20.922500712530955, 16.747976098741802, 11.775044407163348, 11.847449847630092, 11.640662772314888, 7.169468317713056, 5.312539662633624, 10.709116918700081, 6.320327230862208, 2.992119695459093, 1.4833333534853799, 0.12144978876624789, 0.0853616798828755, 0.2661576138011047, 0.1186657188726323, 0.05104360423449959, 0.18486956640013627, 0.10220729559659958, 0.12598484541688645, 0.06800516801221029, 0.1822015938482114, 0.052544387988746166, 0.3496041218084948, 0.09928886219859123, 1.03031482228211, 0.7608444105301584, 0.28107311629823273, 0.6830449423619679, 0.6161323242953846, 5.37968053988048, 0.13833317852446012, 0.12766328320971557, 0.04344281780400446, 0.054585044737905264, 0.03367141481222851, 0.030653477646410465, 0.1465927953166621, 2.2779621311596463, 0.5547844533409391, 0.11401983031204768, 0.04227836010977626, 0.06040501940463271, 0.11876375361212663, 0.15449685975909233, 0.05500429116987756, 0.7700583732553891, 5.209888279438019, 4.771801318441119, 8.181742685181753, 9.39474616731916, 7.943175418036325, 10.494015455245972, 12.353784186499459, 11.011261940002441, 11.29090782574245, 15.99908014706203, 22.41878138269697, 19.43448666163853, 22.756147691181727, 22.972702196666173, 10.95851729597364, 5.850695882524763, 23.824422802243912, 45.69391434533255, 35.351187229156494, 35.97700800214495, 43.49377073560442, 16.677708966391428, 0.8370756485632488, 1.635478709425245, 34.33385978426252, 44.596713883536204, 36.662513801029746, 56.45497512817383, 48.58387163707188, 55.30279357092721, 52.51663889203753, 55.48089674540928, 51.03729098183768, 48.61934219087873, 41.683320317949565, 59.74587821960449, 46.72541611535208, 53.64813566207886, 47.487967014312744, 55.427767344883506, 45.99294049399239, 54.46900279181344, 40.815323557172505, 20.4938611303057, 22.160631486347743, 26.6066152708871, 22.00764431272234, 34.6790497643607, 34.09624876294817, 65.2360737664359, 47.525483812604634, 23.550886120115006, 47.536246572222026, 49.64900268827166, 47.31294189180647, 1.0087076617138726, 0.35874333711607115, 0.09874032091881547, 0.05905869736203125, 0.04564527462103537, 0.09303104584770543, 0.014616755402780004, 0.04998889957953777, 0.0812557287780302, 0.03196723340079188, 0.05213452908875687, 0.02177781891077757, 0.027788826630317738, 0.012078723155095108, 0.005736695095298013, 0.047436820808798075, 0.0568360812695963, 0.10342471634170838, 0.11405695974826813, 0.03846550899158631, 0.019760848122781942, 0.036600711555885415, 0.130625346409423, 0.05599886405148676, 0.09745079904262509, 0.16792502706604345, 0.0868900121588792, 0.06936719814049346, 0.12809890269168786, 0.4113616650657994, 23.498425483703613, 88.26774706159318, 57.5926627431597, 43.33574090685163, 38.0333308492388, 90.07386180332729, 19.486295904432023, 46.363342012677876, 25.807061740330287, 33.27846315928868, 27.566752093178884, 32.983526025499614, 24.741710083825247, 27.2117304120745, 21.346321719033376, 80.30226271493095, 83.90955897739956, 47.874665532793315, 74.60047367640904, 63.15066228594099, 74.23256656101772, 27.340885264532908, 7.60383061000279, 55.297200271061485, 58.45897456577846, 54.501982416425435, 45.04904508590698, 48.70866128376552, 46.4587025642395, 52.164111614227295, 51.59041275296892, 38.97299827848162, 33.47422170639038, 1.1942063250711985, 2.54126780799457, 15.534323828560964, 47.030754702431814, 58.720629828316824, 54.843420369284495, 41.761869703020366, 36.408946241651265, 15.049525431224279, 12.97496964250292, 17.490424122129166, 15.141967739377703, 15.13043372971671, 14.009504301207405, 8.14877348286765, 9.185711349759783, 8.569451298032488, 6.691207306725638, 10.790397814341954, 12.882136498178754, 11.701064331190926, 4.190290076392038, 1.541552635175841, 0.5006598862154144, 0.06983616761863232, 0.06012709146099431, 0.12993865539985044, 0.3044642539960997, 0.08589094398277146, 0.3121200017631054, 0.09575385081448726, 0.0556792028115264, 0.07200407343251364, 0.23811883692230496, 0.6558016527976308, 0.0607859625348023, 1.6671508784805025, 0.529484705201217, 0.2216609971863883, 1.9930642758096968, 6.6111093418938776, 7.354449340275355, 0.33236175988401684, 0.041252075894070525, 0.11064521103565182, 0.061262572317251136, 0.09566500343914543, 0.13188892789185047, 0.3825152415250029, 3.6814639398029874, 1.0115260247673308, 0.1563238695796047, 0.04251097548486931, 0.0561986552950527, 0.0778195663754429, 0.06167141680738755, 0.06434471585920878, 0.7458570918866566, 12.343862158911568, 9.610823852675301, 9.786855595452444, 12.556909561157227, 6.729576562132154, 5.664823753493173, 9.754384057862417, 11.079106756619044, 10.530559505735125, 14.217114738055638, 19.561499731881277, 16.986559867858887, 19.66797740118844, 20.452904973711284, 15.376214095524379, 15.150649513517108, 40.34562185832432, 49.017275946480886, 39.07818358285086, 39.72542217799595, 43.551020417894634, 17.171826635088237, 5.243772038391658, 2.950305002076285, 24.9202492577689, 57.489346504211426, 40.481629371643066, 62.818225724356516, 51.9919422013419, 58.101382051195415, 51.703411306653706, 57.880794116428916, 51.21017953327724, 53.25499963760376, 46.39679064069475, 61.766991070338655, 53.14587470463344, 57.487185614449636, 50.18757493155343, 60.94820145198277, 48.520361627851216, 56.248148100716726, 44.17004932676043, 23.83762785366603, 17.274944850376674, 24.40211340359279, 21.415527514048986, 27.764001028878347, 38.88696568352835, 68.85862132481166, 52.47362606866019, 20.637777430670603, 44.336389201028005, 60.87528705596924, 42.3805581501552, 0.7735716647335461, 0.3693317946578775, 0.05936585659427302, 0.07125606321330581, 0.03802427123965962, 0.05718466506472655, 0.03144831695993032, 0.06801201443054847, 0.07982636761984654, 0.03274701262957283, 0.055579709221741984, 0.041382765131337304, 0.029423317406326532, 0.12266714844320502, 0.16010446314300808, 0.2733945426131998, 0.22405591367610864, 0.13246618477361544, 0.15878302976489067, 0.1254182822470154, 0.19219887096967014, 0.1552018305020673, 0.3359705348099981, 0.2189052900565522, 0.17337812802621297, 0.3399731586022036, 0.26772872092468397, 0.1571084460509675, 0.36613480906401363, 0.5096338646752494, 35.776747022356304, 102.66048186165946, 62.90653732844761, 75.51351560865129, 41.59941387176514, 116.36241286141532, 30.024986539568218, 58.62967790876116, 63.78983402252197, 39.986882890973774, 47.55174452917916, 39.56377233777727, 41.771388735089985, 30.603246893201554, 32.507164478302, 90.04921654292515, 89.90349892207554, 49.55259990692139, 78.11431666782924, 66.88914748600551, 93.69595772879464, 28.91580217225211, 9.411637238093785, 62.62817859649658, 64.20787933894566, 60.69193799155099, 49.449026584625244, 53.47791869299752, 52.991652488708496, 56.405896527426584, 58.60478251320975, 42.43271827697754, 37.86881487710135, 3.055627750498908, 10.105440923145839, 14.760113852364675, 60.00800595964704, 61.42488261631557, 58.767835889543804, 49.15667765481131, 33.78084223611014, 8.244627356529236, 13.710071682929993, 23.482460260391235, 17.68865622792925, 27.366498061588832, 27.18108711923872, 13.728579946926661, 14.116467475891113, 11.52571872302464, 9.599570376532418, 10.80645683833531, 14.135734830583845, 13.11433574131557, 6.156332807881491, 2.106093010732106, 0.5718824501548494, 0.17693548356848104, 0.28844138234853745, 0.5154030951006072, 0.3879280782171658, 0.5672806256583759, 0.26599427685141563, 0.2034633665212563, 0.23020774285708154, 0.33633113546030863, 0.31057864161474363, 0.8103539624384472, 0.19115744185234818, 2.319023596388953, 1.0929545696292604, 0.3252412405397211, 2.2124034890106747, 9.497688940593175, 16.08447003364563, 0.3338774985500744, 0.19374986631529673, 0.24180705472826958, 0.1563567513866084, 0.18459044423486504, 0.22791828427995953, 0.20204129282917294, 3.1074398159980774, 1.1854698338678904, 0.22210684897644178, 0.11003996458436761, 0.18370867440743105, 0.10666639025190047, 0.273665440934045, 0.09732922592333385, 2.4019777051040103, 17.691327810287476, 13.108057175363813, 19.777329887662614, 15.90561819076538, 8.2953622341156, 6.8987482615879605, 11.322924256324768, 14.033495562417166, 13.65256839139121, 17.897355794906616, 29.04230281284877, 25.60978501183646, 25.928545781544276, 26.318567276000977, 15.195962190628052, 7.744422197341919, 30.536478178841726, 53.736422947474885, 42.93597977502005, 44.29109042031424, 50.559546743120464, 19.582290479115077, 2.2045487676348006, 2.5094196540968756, 44.5539789881025, 56.52355037416731, 44.139150687626426, 62.40739958626883, 55.028489112854004, 59.78143909999302, 60.27296161651611, 62.97911821092878, 58.64816011701311, 56.86532531465803, 51.05280630929129, 69.40070588248116, 56.53752320153372, 63.87957695552281, 55.52829040799822, 63.445446559361045, 54.455804688589915, 61.10361875806536, 51.812195777893066, 29.106285299573624, 30.89503996712821, 37.64845970698765, 33.381734234946116, 53.025010790143696, 54.00590535572597, 76.96229839324951, 59.94538879394531, 32.63426440102713, 63.75058364868164, 59.736713545663015, 72.33673667907715, 2.4180775497640883, 0.6731304058006832, 0.1259124321596963, 0.19189205100493772, 0.13401312247983047, 0.19745051488280296, 0.13205211556383542, 0.2328120959656579, 0.17173121497035027, 0.11987276481730597, 0.20000044948288373, 0.10969185576375041, 0.24208107431020054], [0.004565868925835405, 0.02070140283155654, 0.10282348681773458, 0.07700214202382735, 0.03433567006140947, 0.07431035289274794, 0.08363742740558726, 0.03294409651841436, 0.07190257816442422, 0.07649809228522436, 0.043495095534516234, 0.028341698659850017, 0.05279135777215872, 0.036183646613998074, 0.11499335164470331, 0.08692289396588292, 0.052346907156918726, 0.22857339626976422, 60.88047041211809, 67.44646249498639, 60.41193948473249, 41.65533644812447, 68.10073266710553, 74.40806416102818, 18.91014085497175, 61.368407658168245, 24.745286669049943, 38.996191365378245, 25.94158407620021, 30.027786663600377, 19.811240570885793, 36.87926633017403, 25.932448932102748, 33.5635199546814, 59.5680182320731, 54.22444009780884, 66.09075777871269, 53.84015955243792, 52.803623812539236, 10.078068494796753, 14.28400330884116, 52.51467950003487, 43.19566869735718, 38.61863667624337, 41.272278785705566, 44.70818730763027, 49.43915319442749, 47.34406634739467, 45.226526396615164, 14.468675136566162, 0.32648860503520283, 12.62386153425489, 50.45465326309204, 55.343687193734304, 46.93243074417114, 43.46470294679914, 37.97036279950823, 5.897944067205701, 13.449003543172564, 20.05919224875314, 16.073599576950073, 16.486070701054164, 18.14234059197562, 8.072176541600909, 9.49152067729405, 14.79454391343253, 13.204146419252668, 11.124179720878601, 10.65443285873958, 10.04502807344709, 9.069402847971235, 4.276961471353259, 1.3478757249457496, 0.8284185730985233, 0.8672791421413422, 0.34110935192023006, 0.1724672761878797, 0.14950007359896386, 0.038056216668337584, 0.12592506648174354, 0.07633006665855646, 0.020660214059587036, 0.03800349110471351, 0.06523700976478201, 0.030884953082672188, 0.09077115782669612, 0.6575793602636882, 0.023852704358952384, 0.03997420446415033, 1.1821232991559165, 4.107993006706238, 6.939707892281668, 0.0889099362705435, 0.18088776006230287, 0.04541635726179395, 0.05256527329662016, 0.06155732114400182, 0.13118146014000687, 0.6842423123972756, 4.306053578853607, 1.7726911923715045, 0.2891844596181597, 0.04867764761937516, 0.0997142493724823, 0.1828557423182896, 0.1070008265918919, 0.05919119489512273, 0.6215088729347501, 5.833640226296016, 6.252061179706028, 8.13102604661669, 14.271010177476064, 13.040413856506348, 14.389564684459142, 14.822473934718541, 12.845701881817408, 13.582559210913521, 15.261195353099279, 18.896209716796875, 22.0150945186615, 20.120541368212017, 18.691873618534633, 22.236420699528285, 14.250249828611102, 5.991661369800568, 17.338401011058263, 35.37804201671055, 28.303471326828003, 31.71920054299491, 51.98498705455235, 21.772560698645457, 2.3700978500502448, 18.016534771238053, 36.825511591775076, 39.40540552139282, 34.978294781276155, 47.70972572054182, 49.38598905290876, 52.17487437384469, 48.28287220001221, 45.44802107129778, 47.520321301051546, 52.10366923468453, 49.6062365259443, 52.402955940791536, 49.757623876844136, 54.802651814052034, 52.92981004714966, 53.01846211297171, 52.80293246677944, 45.83508784430367, 17.6500346660614, 24.802023921694072, 23.32130547932216, 27.47090690476554, 43.52842140197754, 48.07423864092146, 58.57079192570278, 22.66609730039324, 41.17198848724365, 45.34549345288958, 60.40107945033482, 3.6718628321375166, 0.20610284060239792, 0.0463349002945636, 0.010868460954433041, 0.0628424800400223, 0.07691514704908643, 0.027128472957494, 0.03235445297988398, 0.010581731563434005, 0.05206366967675941, 0.038423110730946064, 0.06092926234539066, 0.09487031001065459, 0.06318227002131087, 0.028663537997220243, 0.033281986601650715, 0.07643748553735868, 0.06602973544171878, 0.060459342918225696, 0.059425540534513335, 0.030114571563899517, 0.049875353529517136, 0.08474113925227097, 0.02745663793757558, 0.04775284170838339, 0.10745227629584925, 0.04036468440400703, 0.07471768424979278, 0.16694672884685652, 0.20238431942250046, 0.10025952011346817, 0.37190352380275726, 67.06743131365094, 77.47630528041294, 58.02073431015015, 38.24298579352242, 82.59917041233608, 61.1762969153268, 28.456887551716395, 47.68698426655361, 23.199005024773733, 40.24145793914795, 24.68169675554548, 28.68715606416975, 21.115492139543804, 39.12607751573835, 36.91701241901943, 37.38699551991054, 61.52283832005092, 63.41041374206543, 71.058685030256, 59.23926421574184, 57.859553473336355, 14.210520029067993, 14.109421133995056, 58.52478095463344, 48.75211531775338, 44.059770992824006, 49.289812088012695, 44.38152469907488, 54.048028809683665, 52.743598324911936, 47.62852212360927, 13.229766164507184, 0.2576946536345141, 18.489545549665177, 48.23010063171387, 56.321097237723215, 52.97153050558907, 46.574598516736714, 49.14136035101754, 15.691262790134974, 15.08482575416565, 18.308406012398855, 16.3661812714168, 15.09129626410348, 15.496272018977574, 11.630068506513323, 6.996085575648716, 8.374707187925067, 9.403394068990435, 10.553009135382515, 11.175223793302264, 13.391579287392751, 13.584535973412649, 4.279916192804064, 1.9948692875249046, 0.6799238441245896, 1.7933789108480727, 0.3590454751891749, 0.2722634518785136, 0.3824024690049035, 0.04533784058211105, 0.03836316216204848, 0.11588395599808012, 0.17073764971324376, 0.007289433003669339, 0.241121272955622, 0.023803067826000706, 0.1823490530784641, 0.41893419729811804, 0.05470021248662046, 0.0211212480706828, 0.5112810220037187, 1.6659780442714691, 4.28995373419353, 0.6289718353322574, 0.053386321025235314, 0.018295668797301393, 0.055361505930445025, 0.07213601456688983, 0.1693978958896228, 2.2595157495566776, 4.800161693777357, 0.988946659224374, 0.11174864468297788, 0.060090891617749415, 0.13469315027551992, 0.2194921142820801, 0.13386096778724874, 0.03922589908220938, 0.7820258853690965, 10.939114451408386, 11.198135478155953, 9.85455276284899, 12.69483825138637, 11.319664682660784, 11.583358372960772, 11.668582371303014, 12.338618006025042, 11.763945528439113, 14.833736964634486, 17.100786515644618, 20.16883134841919, 18.835122891834803, 17.862663439341954, 19.324152742113384, 17.29682125364031, 13.412343978881836, 33.12594672611782, 42.06107650484358, 31.15970379965646, 34.210174901144846, 48.632283210754395, 18.796407529285975, 9.424731986863272, 12.297267539160591, 27.329571860177175, 56.475930895124165, 41.40746293749128, 48.220915113176616, 53.51565783364432, 56.85068198612758, 51.454908984048025, 52.318653447287424, 52.35489525113787, 54.54319218226841, 54.0573741367885, 55.69283069883074, 53.807364055088584, 57.555142470768516, 56.54966170447213, 59.08092171805245, 55.39289781025478, 48.858700684138704, 19.39724952833993, 16.33235396657671, 23.887877225875854, 21.669845478875295, 43.076298645564485, 58.426227705819265, 59.47683007376534, 29.313720294407435, 38.89678348813738, 54.39250659942627, 59.0971040725708, 1.4497110205037254, 0.08841765911451407, 0.00517455512557977, 0.014426443293424589, 0.04024077033890145, 0.01264834651790027, 0.02051707200839051, 0.023363190536786402, 0.023105104653430835, 0.024055493030963198, 0.04061198327690363, 0.08191124788884606, 0.08561328066779034, 0.022736385331622193, 0.10218693276068994, 0.1765300046120371, 0.28445555908339365, 0.14943551777728967, 0.20657310608242238, 0.13906693272292614, 0.20151385398847715, 0.08063895401677915, 0.10465999612850801, 0.1672605648636818, 0.14310060627758503, 0.25776568268026623, 0.13552956682230743, 0.11469669613455023, 0.32384172135165756, 0.26849961813007084, 0.16412305964955262, 0.8733713552355766, 90.67260197230748, 79.63589572906494, 75.48121343340192, 58.510967935834614, 85.03196402958461, 98.02235780443463, 32.74417100633894, 87.97807666233608, 36.65641328266689, 56.91647795268467, 34.6728971345084, 41.14046103613717, 28.126295736857823, 53.683359554835725, 34.47241381236485, 41.390724727085654, 70.52317346845354, 67.40377971104213, 76.6556396484375, 65.45829105377197, 62.24747289930071, 13.561324647494725, 17.595840454101562, 65.40555422646659, 51.716150828770225, 46.09772627694266, 48.9652339390346, 50.07291228430611, 60.40239265986851, 57.187419482639854, 52.58685391289847, 19.21655641283308, 0.8767037221363613, 18.583568572998047, 58.23782730102539, 61.49278736114502, 55.86911344528198, 54.744901861463276, 43.233946323394775, 8.354687690734863, 16.04009188924517, 27.71880647114345, 18.916837181363785, 23.47713099207197, 24.86576669556754, 13.87930635043553, 13.923230256353106, 17.62900768007551, 14.268709455217634, 13.614206518445696, 13.075863565717425, 15.393744400569371, 19.653301068714686, 6.434017998831613, 2.7129916676453183, 1.360224410891533, 1.8103735532079424, 0.3866028721843447, 0.3386069419128554, 0.8008578377110618, 0.2351303787103721, 0.1931941732764244, 0.176501438287752, 0.15860878197210176, 0.1364679807530982, 0.3002686548445906, 0.125900340665664, 0.2780283125383513, 0.7664238682815007, 0.188744883452143, 0.1390283512217658, 2.2020085496561865, 9.814979297774178, 23.155802862984793, 1.0009121085916246, 0.32343378609844614, 0.12225569837859698, 0.15571355447173119, 0.09749538557870047, 0.25482363626360893, 5.487870940140315, 19.62633510998317, 5.929713836738041, 0.5420288092323712, 0.10967257858387061, 0.33601268540535656, 0.2764594038682324, 0.21625141746231488, 0.15421100652643613, 1.2911149135657718, 15.89597409112113, 15.009451695850917, 17.54625289780753, 19.693428652627126, 12.904587864875793, 13.400290591376168, 15.670235804149083, 16.563944373811992, 15.600606169019427, 16.385162012917654, 20.181940862110682, 30.317300728389196, 29.45605066844395, 24.82260796001979, 26.37808554513114, 20.45349383354187, 8.563694715499878, 21.444029024669103, 42.326640129089355, 37.99327795846121, 37.95628922326224, 57.330093792506624, 26.071557079042705, 4.945032502923693, 24.342760154179164, 45.973082542419434, 57.87296002251761, 44.68131514957973, 52.0400584765843, 58.630504744393484, 57.686043058122905, 57.19197055271694, 55.30861963544573, 56.91629729952131, 59.11341149466378, 58.48612812587193, 61.634996141706196, 56.75487674985613, 64.11802523476737, 61.918260301862446, 63.93065316336495, 59.33057049342564, 56.67404835564749, 29.82123061588832, 37.107170718056814, 32.89687156677246, 41.58681331362043, 72.69296387263707, 65.87346676417759, 70.89319283621651, 35.629153387887136, 57.458510398864746, 55.142231123788015, 78.72238826751709, 9.083774328231812, 0.3338147204901491, 0.2733087215040411, 0.1316039974668196, 0.19744799073253358, 0.19247379978852613, 0.09143971159522023, 0.26346051852617947, 0.1132736996348415, 0.16825180953102453, 0.17365879725132669, 0.14392421208322048, 0.25414021579282625, 0.21540858197425092], [0.03325974761641451, 0.02882269856386951, 0.009233369674932743, 0.013700180121564438, 0.0671004094183445, 0.1010641608653324, 0.11364988623453037, 0.05274587556985872, 0.016493898783145205, 0.08351753705314227, 0.018579791765660048, 0.03342855355835386, 0.1018631426351411, 0.1385037757988487, 0.05107422651989119, 0.14819880628160068, 0.043058587171669514, 0.13653451789702686, 7.573526910373142, 86.31361484527588, 49.93296166828701, 59.03162424904959, 42.53723655428205, 101.00118255615234, 39.19506965364729, 41.70744098935808, 41.49546882084438, 23.87207702228001, 38.59183052607945, 25.50801474707467, 27.205096619469778, 24.237600905554636, 42.46869952338082, 49.66039425986153, 70.56222234453473, 40.166431290762766, 67.44082750592912, 54.95996250425066, 65.79602909088135, 26.96348864691598, 11.184997303145272, 51.113609995160786, 55.15688140051705, 45.10771220070975, 38.20639657974243, 37.23368351800101, 48.26150301524571, 43.47040394374302, 39.45738499505179, 1.497660430414336, 6.844350814819336, 51.85594858442034, 54.228046212877544, 44.26725115094866, 42.670836516789024, 44.88835409709385, 6.044051221438816, 12.165007710456848, 23.43780071394784, 19.743690184184484, 19.685111658913748, 16.870273079190934, 9.619050519806997, 11.216614212308611, 5.698080003261566, 10.948231356484548, 12.546091215951101, 13.452138917786733, 14.959631374904088, 13.04159505026681, 14.535760862486702, 5.306077837944031, 2.585620330912726, 1.083391242793628, 1.2970091572829654, 0.5928916313818523, 0.904930398932525, 0.24961080455354281, 0.24937434867024422, 0.12306177083935056, 0.04114217696977513, 0.17048481399459497, 0.049943390235837014, 0.12270735842841012, 0.02244803000108472, 0.02455996346127774, 0.12975295393594674, 0.15805804223886558, 0.0887003910860845, 3.088483610323497, 6.116962143353053, 7.460762858390808, 0.635340619300093, 0.17320017543222221, 0.08211955813957111, 0.06563366098063332, 0.03484234573053462, 0.12078002042004041, 0.49887533911636894, 2.286398764167513, 0.31319528977785793, 0.06807720128979002, 0.11541329696774483, 0.07344002995107855, 0.2820968899343695, 0.0671571349459035, 0.0685400775234614, 0.06702110903071505, 6.836111988340106, 9.83705633027213, 9.707919716835022, 15.201499904905047, 17.141200712748937, 13.945606061390468, 14.759085518973214, 18.160497971943446, 14.207695586340767, 15.060084956032888, 18.430595295769827, 17.1067567552839, 19.987693548202515, 20.412852082933696, 21.754714250564575, 21.90522960254124, 17.207891259874614, 6.778733330113547, 14.739303997584752, 29.336836951119558, 28.31776203427996, 28.625984123774938, 59.449315207345144, 21.590787138257706, 2.729445653302329, 10.281239032745361, 23.624908753803798, 48.55371992928641, 46.155076708112446, 41.312758990696494, 52.04944201878139, 49.761893544878276, 49.02760444368635, 47.43513638632638, 47.63584205082485, 48.16026776177542, 50.84605918611799, 48.2300763130188, 52.953055245535715, 52.28417648587908, 45.3586985043117, 48.701518535614014, 51.94654267174857, 15.96157203401838, 22.223707233156475, 15.619159596306936, 42.18829107284546, 36.456350326538086, 58.24891662597656, 27.340332882744924, 28.187775135040283, 40.82012823649815, 56.48732246671404, 18.864258425576345, 0.31404234575373785, 0.17295109879757675, 0.12775032568190778, 0.11436289761747633, 0.04945770844018885, 0.06336959318390914, 0.07462644164583512, 0.0733314643480948, 0.09230626188218594, 0.061513684556952546, 0.07569079167608704, 0.036077968177518675, 0.029383942019194365, 0.029401295552296296, 0.052561948475028784, 0.05565898246797068, 0.037695612625351975, 0.1254130575273718, 0.12923481102500642, 0.10422171000391245, 0.051929682759302, 0.04955972618024264, 0.05087669140526226, 0.06530160629855734, 0.054958113469183445, 0.03928745238642607, 0.044580432652894936, 0.07370388507843018, 0.041177111345210245, 0.07640423732144491, 0.016258596409378306, 0.06674493170742478, 8.641639607293264, 90.80954401833671, 61.127993038722444, 54.87962743214199, 56.630239963531494, 100.1702127456665, 36.35562229156494, 47.30956506729126, 27.79663324356079, 26.83537081309727, 35.08642264774868, 27.98528552055359, 27.331909929003032, 30.621472018105642, 41.89233602796282, 56.252098151615684, 70.86917291368756, 48.518978936331614, 68.62161827087402, 60.2140964780535, 69.20119530814034, 32.11821126937866, 12.255455885614667, 55.58457776478359, 54.40940809249878, 46.439369201660156, 41.392371450151714, 43.37760032926287, 51.67371817997524, 49.13749715260097, 37.66176550728934, 1.3026056055511748, 11.626298240252904, 49.7724061693464, 53.986030033656526, 51.98885372706822, 45.18149164744786, 58.364333152770996, 17.17803485052926, 13.245638455663409, 20.010252611977712, 16.246375220162527, 17.862875359398977, 13.42025363445282, 13.694064770426069, 7.436071566173008, 9.56316181591579, 10.240595545087542, 9.653118406023298, 12.679614748273577, 14.98476995740618, 14.588072981153216, 21.347075598580496, 7.132118276187351, 3.295182530369077, 0.8702073193022183, 0.8426461496523449, 1.0142721916948045, 0.37975990080407684, 0.18343461411339895, 0.3955355685736452, 0.26580409705638885, 0.11447925280247416, 0.6442570579903466, 0.09130925645253488, 0.06065963288503034, 0.013114788453094661, 0.05665660197181361, 0.1849437574190753, 0.17061083151825837, 0.03713675422061767, 0.851822548678943, 3.00951993891171, 1.4950410681111472, 1.0367053193705422, 0.054650408016251664, 0.5717512486236436, 0.2264577919351203, 0.0848093048802444, 1.5424265882798602, 1.1349184321505683, 0.3577429050845759, 0.11642036507172243, 0.2134842159492629, 0.05913799774966069, 0.039802887942641973, 0.2845383403556687, 0.02700254364338304, 0.11912510065095765, 0.28956351642097744, 12.066155689103262, 13.887600762503487, 11.140433294432503, 13.75633452619825, 16.062376499176025, 13.184627192361013, 14.259282486779348, 14.247864859444753, 13.505990930965968, 14.050610712596349, 14.577374492372785, 16.940444673810685, 20.862492595400127, 18.864517245973857, 17.854412453515188, 19.484466791152954, 21.143078224999563, 14.438000576836721, 33.489872523716514, 42.707825251988, 36.50778784070696, 30.611730643681117, 54.799368790217805, 14.632518870489937, 10.354507786887032, 11.49150492463793, 15.209679671696254, 54.28794315883091, 55.07720293317522, 46.53140156609671, 57.4423315184457, 54.782713958195274, 54.27262238093785, 52.0970059122358, 53.282948766435894, 52.293476649693076, 56.31993341445923, 53.82340397153582, 57.9008674621582, 56.323084422520225, 50.94300045285906, 52.6535461970738, 54.688722201756065, 17.30597029413496, 20.959977558680944, 16.04949975013733, 32.714318071092876, 44.258506843021934, 63.2059143611363, 32.722721917288645, 33.57034655979702, 47.70773158754621, 61.04542064666748, 11.70446981702532, 0.24433560190456255, 0.1410495170525142, 0.062626156290727, 0.04720053795192923, 0.08370585766221796, 0.02996418106236628, 0.02862783009186387, 0.04192072465749724, 0.0995950714818069, 0.039102286965187104, 0.0625186695584229, 0.027941069532451884, 0.021818408875593116, 0.0157922375947237, 0.14670411577182157, 0.10094656396125044, 0.13163715068783077, 0.1862664528723274, 0.18823207382644924, 0.22231153585016727, 0.19563417163278374, 0.16363384947180748, 0.22408796767038958, 0.19861638732254505, 0.11790480970271996, 0.13657612566437038, 0.16943288115518435, 0.1752878919775997, 0.14964948701007025, 0.3058719427457878, 0.16228779884321348, 0.6190783604979515, 17.358380556106567, 109.17562702723912, 62.92910507747105, 80.59467765263149, 57.93916940689087, 119.52755355834961, 55.37765693664551, 61.93713160923549, 61.31847095489502, 33.54625368118286, 54.263179779052734, 34.43253810065133, 37.629313945770264, 40.02495901925223, 49.708107539585654, 59.02669102805001, 82.76348836081368, 49.499578203473774, 79.87398965018136, 62.90691947937012, 78.07565689086914, 34.54000588825771, 15.079418318612234, 58.2124594279698, 60.149068287440706, 52.5203527041844, 44.780559744153706, 42.159192017146516, 61.578423908778596, 49.18422726222447, 45.23553821018764, 2.3669503160885403, 8.784292204039437, 62.93295437949044, 62.13916437966483, 57.27968461172921, 50.07303040368216, 52.07783930642264, 9.126934800829206, 17.226043428693497, 27.91582611628941, 23.822439091546194, 24.42714602606637, 22.001048735209874, 15.793159859521047, 16.013504607336863, 9.886240022523062, 14.503033110073634, 17.251341819763184, 14.288123590605599, 20.032910687582834, 17.844146490097046, 27.36168643406459, 11.725319623947144, 4.376612535544804, 1.2772319785186221, 4.204890412943704, 3.4021915197372437, 1.2230891180889947, 0.8925882269229207, 0.972867659160069, 0.31217645587665693, 0.12535243720880576, 0.49430917842047556, 0.17810757138899394, 0.21682161757988588, 0.15514110161789826, 0.1597207108778613, 0.20882699585386685, 0.344498200075967, 0.2997060678899288, 5.5763649344444275, 9.821967448507037, 20.850696291242325, 1.245631245630128, 0.30779214256576126, 0.2874013510133539, 0.25617020257881706, 0.09953401011547872, 0.8522589824029377, 4.072877245289939, 3.883275670664651, 5.380482188292912, 0.4039243241505963, 0.1915933463190283, 0.11407632513770036, 0.38799859157630373, 0.10523972966309104, 0.16284852661192417, 0.5082915595599583, 17.80645772389003, 16.293624707630702, 16.9714093208313, 20.433866909572057, 18.658183540616715, 16.720059973852976, 20.591160229274205, 23.6484249319349, 21.56155606678554, 20.05587100982666, 21.784582819257462, 21.516248600823538, 29.875728811536515, 28.366548810686382, 27.49267908505031, 25.28935320036752, 24.446687834603445, 9.120789987700325, 21.15093837465559, 36.80098097664969, 41.06682750156948, 37.991676398685996, 67.2630786895752, 25.160740307399205, 5.120155334472656, 15.098300048283168, 31.86571373258318, 64.80262429373605, 57.06563493183681, 47.87384564535958, 60.224761962890625, 55.93647623062134, 59.57226358141218, 56.21218075071062, 57.630391461508616, 58.49619606563023, 59.83769171578543, 58.46686771937779, 60.70164462498256, 60.288449151175364, 53.62234047480992, 58.262055669512065, 66.07226167406354, 23.590148653302872, 39.97585957390921, 23.935864959444316, 64.0403721673148, 55.23650080817086, 70.81587328229631, 38.146176542554585, 41.92892524174282, 52.52523033959525, 74.56989465441022, 31.458260944911412, 0.46861929978643146, 0.2580940122050898, 0.18084750936499663, 0.2560682051948139, 0.20335755577044828, 0.2240049692669085, 0.1612199747136661, 0.12611303425260953, 0.1826691451881613, 0.2159739373517888, 0.1587438511529139, 0.16784717195800372, 0.08226150766547237, 0.0825172746554017], [0.039277298109872, 0.06050881490643535, 0.0486608606630138, 0.019990696771336452, 0.027050271796594774, 0.042167643550783396, 0.06870988091187817, 0.024850861601797596, 0.03553555067628622, 0.024797009670042565, 0.04238533115546618, 0.012532745354941912, 0.03736739845148154, 0.03052023033212338, 0.030593074459050382, 0.18163151586694376, 0.061817485040852, 0.030331275292805264, 0.058821529016963074, 37.27598067692348, 73.1311867577689, 47.258589608328684, 28.967964036124094, 60.2543751852853, 92.47873755863735, 29.853810719081334, 58.83702605111258, 28.66054446356637, 36.572089944567, 26.430511440549576, 26.320997408458165, 27.75726648739406, 103.47104481288365, 57.97178425107683, 74.45407513209751, 56.62280886513846, 59.59229523794991, 57.561291626521516, 62.741663524082725, 42.948684556143625, 20.772768769945415, 62.36480018070766, 52.47721481323242, 54.788213457380024, 59.163410731724326, 39.266917501177105, 40.44429670061384, 48.95758744648525, 6.072785930974143, 1.475255312664168, 46.77011387688773, 49.03400026048933, 38.695167609623496, 38.19859722682408, 46.305456570216585, 6.49687704869679, 13.565492698124476, 19.338639736175537, 17.752484117235454, 17.683398178645543, 19.586287430354528, 15.525289433343069, 14.457501564707075, 13.145842347826276, 6.663265994616917, 6.715208121708461, 15.38312234197344, 15.958686794553484, 17.615000111716135, 16.11164617538452, 19.07258800097874, 7.473338229315622, 2.287741720676422, 0.24866856368524687, 0.679971558707101, 0.3946641667612961, 0.08333300945482083, 0.07246981986931392, 0.03655712925163763, 0.0999832342245749, 0.03834286378696561, 0.26983690208622385, 0.599500236766679, 0.024423413377787386, 0.04471747976328645, 0.2177571409514972, 0.19900218876344816, 0.05246116906138403, 0.026545251752915125, 0.08265358555529799, 1.6305893489292689, 8.20291645186288, 2.4338130482605527, 0.25683093283857616, 0.11445595190993377, 0.22790612493242535, 0.1621155866554805, 1.3723979805197035, 0.7907961404749325, 0.448171999837671, 0.10955898503639869, 0.15294467019183294, 0.14193605019577912, 0.05183940028239574, 0.07631847049508776, 0.1636056224150317, 0.03337794502398797, 0.2287932958986078, 7.353774496487208, 15.955683435712542, 14.374021564211164, 15.463598115103585, 15.814193793705531, 14.968950646264211, 11.780947770391192, 9.465781075613839, 11.071191021374293, 15.802201202937535, 15.900740555354528, 17.18840503692627, 17.70821714401245, 20.09701303073338, 20.727377925600322, 22.164925473076956, 21.731512478419713, 19.021372829164775, 7.002722408090319, 6.628090739250183, 19.231505462101527, 27.38273252759661, 26.363492591040476, 61.51297187805176, 15.840397187641688, 0.2965141848794052, 2.7001383687768663, 17.40607820238386, 41.16220889772688, 51.09006255013602, 44.94877910614014, 49.764585971832275, 45.46354682104928, 47.522252900259836, 55.74254158564976, 54.87962743214199, 48.151679788317, 51.73965311050415, 52.80195277077811, 55.08515862056187, 46.42668179103306, 54.784913063049316, 38.59355367933001, 18.184783663068497, 13.269310099737984, 23.76288260732378, 45.13032511302403, 47.94989367893764, 48.331749303000315, 27.94544628688267, 42.40444605691092, 51.11277273723057, 32.70676537922451, 0.3169536681047508, 0.04886116759319391, 0.097306053952447, 0.06822567832257066, 0.04500097169407776, 0.020279157274801816, 0.0818852192855307, 0.07041044573166541, 0.08562858841781106, 0.035279692084129365, 0.09700772246079785, 0.027448256333757724, 0.07828096340277366, 0.006844437864076878, 0.012643034436873027, 0.015037898340129426, 0.02904624192576323, 0.0165945848982249, 0.06650518492928573, 0.02782085009052285, 0.022822204744443297, 0.034160757304302285, 0.041397526660667996, 0.025590978762401, 0.030573851561972072, 0.06794233566948346, 0.0015189409272612206, 0.1193448645727975, 0.02681900840252638, 0.06052415658320699, 0.09231848229787179, 0.06818181781896523, 0.13296655006706715, 0.13364478653030737, 37.57328019823347, 82.96425655909947, 52.04801416397095, 30.88645546776908, 75.17946011679513, 81.0121601649693, 34.72349044254848, 51.83053207397461, 25.8250732081277, 37.231974261147634, 24.21046645300729, 28.508259057998657, 33.651824610573904, 86.79695933205741, 60.678680828639436, 77.65512411934989, 60.00162751334054, 67.44311346326555, 60.74311147417341, 66.57229573386056, 47.75197424207415, 23.772252253123693, 59.56077820914132, 54.46213797160557, 54.07430689675467, 53.49567828859602, 42.36953483309065, 50.25830064501081, 53.30587434768677, 4.619026064872742, 4.6132794703756055, 47.109456947871614, 48.74746349879673, 46.9482170513698, 43.08985458101545, 61.72293949127197, 18.23240487916129, 14.73902085849217, 19.82943616594587, 15.066760437829153, 17.373074259076798, 16.225601843425206, 14.76044910294669, 12.06464011328561, 9.731857129505702, 6.584238052368164, 7.93642350605556, 13.780912041664124, 13.5076949766704, 15.537652015686035, 17.78480887413025, 29.160477774483816, 9.60467643397195, 3.706466163907732, 0.21962041168340615, 0.7345612208758081, 0.5420701184443065, 0.09215080950941358, 0.026842516248247454, 0.12359737924167088, 0.13327282720378467, 0.19347915798425674, 0.5976830114211354, 0.7895790657826832, 0.09582446595387799, 0.08862617292574473, 0.18932184177849973, 0.42354413707341465, 0.0667702207075698, 0.05758310082767691, 0.44136895345790045, 2.607149975640433, 4.908795475959778, 3.744982634271894, 1.3478718165840422, 0.35729903461677687, 0.46791861738477436, 0.5540811653648103, 1.5365782678127289, 0.3496418483555317, 0.5953400028603417, 0.15868172448660645, 0.10196370152490479, 0.06963665796709911, 0.028251378863517727, 0.053273684212139676, 0.19779841335756437, 0.03142973527844463, 0.2618183009326458, 9.893079655511038, 17.472020081111364, 16.76445722579956, 13.72029161453247, 17.882200036730083, 15.141978161675588, 16.18001992361886, 13.012454305376325, 14.456503629684448, 15.774271181651525, 14.405749644551959, 16.218691859926494, 17.41409989765712, 20.27285804067339, 20.467833178383962, 20.4656913961683, 22.23899327005659, 18.588843992778234, 12.265085220336914, 17.368709053312028, 34.3668463570731, 38.647926807403564, 31.075067792619976, 54.28336777005877, 11.513739160129003, 8.758062754358564, 6.235206586974008, 7.944677097456796, 37.28145933151245, 53.399442264011924, 48.04265907832554, 60.285523959568565, 51.289510590689524, 50.420766898563926, 57.68801634652274, 56.661503383091514, 51.452466692243306, 58.04317351749965, 57.163409982408794, 60.17901502336775, 52.52507747922625, 60.456171716962544, 44.863927704947336, 19.70998099872044, 16.355293444224767, 22.203112772532872, 45.67736373628889, 55.254006794520784, 53.415829590388704, 33.53337172099522, 44.230870383126394, 60.59753976549421, 26.130844320569718, 0.38359647350651876, 0.23622737984572137, 0.06714903323778085, 0.09922136832028627, 0.07845185244722025, 0.07559628531868968, 0.03382526923503194, 0.1154742565538202, 0.053064834526074786, 0.038181949207293134, 0.06815187406859227, 0.055357801129243205, 0.13562411389180593, 0.04420396785384842, 0.017875467327290347, 0.17804332769342832, 0.18644535541534424, 0.15913043969443866, 0.1080548425338098, 0.13984743798417704, 0.15876361009265694, 0.14566375873982906, 0.1775096327598606, 0.19826933023120674, 0.1448628567159176, 0.10336445564670221, 0.14552037071968826, 0.16930074324565275, 0.129192551864045, 0.20536240961934837, 0.3198602135692324, 0.22408510425261088, 0.23363996297121048, 0.3309822439083031, 60.43805776323591, 90.95363576071603, 64.20812252589634, 41.93192686353411, 76.93584660121373, 109.87478256225586, 47.100660528455464, 86.34260967799595, 42.3385979788644, 49.46744278499058, 35.66997752870832, 40.215489046914236, 45.083115577697754, 119.7775775364467, 68.4020482472011, 88.37347779955182, 65.40349755968366, 70.78819165910993, 63.94911452702114, 72.7221463067191, 50.30810185841152, 24.860288040978567, 69.58893258231026, 60.71491568429129, 58.75095871516636, 63.42200333731515, 46.28206893375942, 49.5563554082598, 54.81453670774187, 7.919547200202942, 2.481364130973816, 58.96834005628313, 55.89711121150425, 54.13349165235247, 47.81666544505528, 52.713001932416645, 8.568126797676086, 20.080160175051006, 28.033627612250193, 25.38187541280474, 21.90825206892831, 23.76078598839896, 19.791356563568115, 18.34110597201756, 16.949590240206035, 9.65838166645595, 11.58972726549421, 19.296149764742168, 19.118164709636144, 22.057216235569545, 21.61093691417149, 35.37611041750227, 16.90730002948216, 7.046250266688211, 0.651141094309943, 0.8536156724606241, 1.7653911326612746, 0.5254982848252568, 0.12424709009272711, 0.8734679243394307, 0.22647387321506227, 0.1267472202224391, 0.6816556283405849, 1.515141880937985, 0.12700914831033774, 0.20880248716899327, 0.24135170344795498, 1.146509547318731, 0.12811849878302642, 0.19419083265321596, 1.2672780326434543, 6.652937063149043, 16.226948056902202, 4.156973464148385, 0.5018499823553222, 0.14146608327116283, 0.5419559074299676, 0.25839582458138466, 3.5578574410506656, 2.819594838789531, 2.927005086626325, 0.2951462854232107, 0.5694928126675742, 0.2695003215755735, 0.14566252380609512, 0.1268153858504125, 0.21736417418079718, 0.09965261125138827, 0.39476247291479793, 14.704981633595057, 19.436089958463395, 20.711935554231914, 21.253339188439504, 20.838239908218384, 20.549472774778092, 18.76663797242301, 14.195025546210152, 18.133175918034144, 21.97736406326294, 21.289657422474452, 24.007530416761124, 24.465566090175084, 28.029427426201956, 26.961319071905955, 28.692045858928136, 28.56756714412144, 27.350583212716238, 8.460128341402326, 9.439564653805324, 25.44918782370431, 36.75141600200108, 38.58850581305367, 64.55397605895996, 19.74476020676749, 3.8438411695616583, 6.245304490838732, 24.998954977308, 54.300971031188965, 60.49910463605608, 53.88687229156494, 65.320070539202, 53.71951798030308, 58.303439140319824, 63.1803171975272, 59.84372970036098, 55.665927273886545, 63.68210220336914, 62.335242543901714, 61.965466363089426, 55.643939699445454, 67.27944864545549, 51.605420861925396, 29.818760531289236, 20.27128427369254, 36.77224670137678, 74.14555427006313, 61.47276265280587, 61.37573800768171, 42.162270069122314, 58.814673696245464, 64.07131944383893, 56.001619066510884, 0.5289463826588222, 0.4612739682197571, 0.24864155799150467, 0.17373492888041905, 0.2151163233710187, 0.17651313623147352, 0.1632752844265529, 0.3381077844117369, 0.15401234504367622, 0.22778173589280673, 0.2147372258560998, 0.13173329909997328, 0.3132726970527853, 0.08855650095002991, 0.1276233582092183], [0.025543932536883012, 0.023967071436345577, 0.05157067666628531, 0.06456967735929148, 0.04212808835187128, 0.03328868034960968, 0.04526177341384547, 0.07013680612934486, 0.030417462810873985, 0.048557760659605265, 0.03666915199054139, 0.04426576203799673, 0.0341277126488941, 0.08121950179338455, 0.02410640860242503, 0.042124332660543065, 0.05789926421961614, 0.035541135019489696, 0.06003190656857831, 1.8595096937247684, 67.62298842838833, 64.70792729513985, 59.64989580426897, 34.74716990334647, 103.69677094050816, 63.38079357147217, 44.04992886951992, 39.869291578020366, 30.787791047777446, 34.107688971928184, 24.449784994125366, 25.83750353540693, 65.18809645516532, 63.524697712489534, 63.010718618120464, 68.55682631901333, 62.90974044799805, 58.80973352704729, 62.32153374808175, 61.167201723371235, 52.77777998788016, 53.813214438302175, 56.68475552967617, 50.906088147844585, 60.69534260886056, 53.66851820264544, 33.32283435549055, 20.190289122717722, 0.8726770782044956, 22.628604820796422, 56.10910422461373, 38.059918131147114, 36.65212277003697, 39.719755922045024, 5.526182872908456, 13.874358364513942, 24.668672357286724, 17.8814947945731, 22.841488940375193, 16.400795459747314, 20.875636850084575, 13.02223823751722, 15.82035858290536, 7.94679890360151, 9.615958571434021, 5.58990523644856, 12.567385707582746, 20.248000860214233, 19.371327536446707, 16.585270132337296, 28.112599100385392, 16.51899300302778, 5.253621978419168, 0.23504987731575966, 0.07865559615726982, 0.1482694282063416, 0.07175427755074841, 0.33126595297030037, 0.26211511929120335, 0.3209415269749505, 0.3640397643404347, 1.689691920365606, 0.502328593816076, 0.10151830435331378, 0.2620038938309465, 0.013002304310378219, 0.2957697776811463, 0.09358330549938337, 0.07359148575259106, 0.014406479096838405, 0.41966041975787705, 2.8902445563248227, 1.8232885173388889, 0.80987013982875, 0.5328546358006341, 0.3840152110372271, 1.0426569942917143, 3.492100558110646, 0.20162155106663704, 0.12006746365555696, 0.036673633714339564, 0.07581868874175207, 0.045734074498925886, 0.14808986069900648, 0.31016381244574276, 0.3533218151756695, 0.0674337533169559, 0.10752362425306014, 7.195856707436698, 25.176823650087627, 22.37908979824611, 19.056867701666697, 13.771743893623352, 15.095145566122872, 9.062658752713885, 8.432148814201355, 9.566785301480975, 11.887547033173696, 12.344517026628766, 14.963643959590367, 17.321772234780447, 19.948679413114274, 22.01369445664542, 23.895909343447002, 25.56649773461478, 26.473168168749126, 26.255446365901403, 14.970817974635533, 4.610830230372293, 14.617128610610962, 28.22969535418919, 25.57525941303798, 63.95427009037563, 9.691491569791522, 2.118148352418627, 2.404710952724729, 2.9071660254682814, 16.396128007343837, 19.857968943459646, 27.724877459662302, 51.02900178091866, 49.24647964750017, 41.722518580300466, 47.575698443821494, 46.13368667875017, 49.07154485157558, 48.213994707380024, 54.168010302952354, 49.02975838524954, 55.80360235486712, 32.41649743488857, 11.691202231815883, 12.853853855814252, 36.584805147988455, 43.32891777583531, 44.239069257463726, 39.49717385428292, 32.443685735974995, 43.56296784537179, 53.15146105630057, 2.083084051098142, 0.3360575501407896, 0.0301085054608328, 0.01115966443571129, 0.03323577158153057, 0.08506765030324459, 0.053421767694609504, 0.03933079041806715, 0.029267088110957826, 0.04613346021090235, 0.12427383794316224, 0.014223188128588455, 0.06128473327096019, 0.031039564072021415, 0.07606264243700675, 0.04260174311431391, 0.023185982634978633, 0.03865393477358988, 0.024934102581547837, 0.028418003315372125, 0.04824679145323379, 0.00931254368541496, 0.09414990938135556, 0.03942532391686525, 0.03447142116991537, 0.031216885628444806, 0.028737888471888642, 0.0016543034684478439, 0.05127656566245215, 0.05267742495717747, 0.061830173645700724, 0.027553512382188013, 0.07305114796119076, 0.031577052016343386, 0.05368936154991388, 1.641951933503151, 69.39167322431291, 76.26033578600202, 53.63725825718471, 43.87676586423601, 106.2038130078997, 62.06267166137695, 47.261469636644634, 31.626417773110525, 30.414693628038677, 32.91446787970406, 24.73801016807556, 31.49979727608817, 69.00075367518834, 64.69344724927629, 66.08499077388218, 69.33108493259975, 67.95508452824184, 63.046342032296316, 69.73363576616559, 61.165186745779856, 55.50057404381888, 56.784232888902935, 60.252707617623464, 51.592181069510325, 62.705664907182964, 47.61242662157331, 43.88819565091814, 14.781587260110037, 3.543600388935634, 25.729082107543945, 51.56678192956107, 46.050937107631135, 46.41478647504534, 59.74434266771589, 14.546368156160627, 16.183283839906963, 21.57313002858843, 15.429162842886788, 20.68071208681379, 16.827361004693167, 16.81290701457432, 12.846640757152013, 10.446611370359149, 6.995638719626835, 6.895588134016309, 8.165436131613594, 12.944693735667638, 19.01937174797058, 18.318305458341325, 19.839570113590785, 33.47357899802071, 21.850535120282853, 7.689823252814157, 0.4154803997703961, 0.10733565648219415, 0.21116448113960878, 0.24479119745748384, 0.42448013541953905, 0.04170008881815842, 0.15052050884280885, 1.1566812757934843, 1.87977910893304, 0.2711659079151494, 0.2466900912778718, 0.22644884884357452, 0.059146201238036156, 0.6528373775737626, 0.03240254754200578, 0.04341728113857763, 0.1734216356916087, 0.7572799303701946, 0.9991943836212158, 3.729720481804439, 2.152383863925934, 1.1626223112855638, 0.6173179149627686, 0.9287431240081787, 1.1070221747670854, 0.1341125007186617, 0.09049301953720194, 0.04178627633622714, 0.24056479281612805, 0.03611941309645772, 0.07912933573658977, 0.3079483684684549, 0.21247638788606438, 0.05872122797050646, 0.12082519728158202, 10.748062440327235, 25.33843527521406, 21.459612097058976, 15.160708768027169, 13.608225856508527, 16.4358925478799, 10.876241939408438, 11.946717023849487, 10.72563452380044, 12.857670153890338, 11.41825875214168, 16.31355561528887, 17.09605131830488, 18.58701835359846, 21.533521822520665, 22.371533632278442, 23.75266354424613, 27.48263372693743, 23.066422973360332, 18.596891743796213, 12.858438798359462, 33.141559328351704, 43.841875485011506, 28.486848184040614, 50.54517092023577, 7.011357716151646, 13.606556551797048, 8.738686834062849, 1.8844491669109888, 10.564259137426104, 12.973630377224513, 23.47470780781337, 52.72108963557652, 52.67162193570818, 44.87700421469552, 50.65633862359183, 50.89835480281285, 56.60441698346819, 56.25475583757673, 58.222645487104145, 49.926673548562185, 54.93855857849121, 37.270887647356304, 16.03838610649109, 20.08520109312875, 31.836267266954692, 51.12030111040388, 48.104188850947786, 47.86444125856672, 36.64170394624983, 54.2540602684021, 51.47526025772095, 1.7332227102347781, 0.27660580458385603, 0.07648673360901219, 0.04925870090456946, 0.043910705018788576, 0.040864320272313695, 0.09985613783023187, 0.07419025219444718, 0.02381351726528789, 0.0515192233558212, 0.07266938380364861, 0.014647184305691292, 0.03494221590725439, 0.06389864693794932, 0.04232370321239744, 0.05452109620507274, 0.09891337448997156, 0.0926689999178052, 0.14548206063253538, 0.1946090002145086, 0.13150741479226521, 0.07499134420816388, 0.22760637530258723, 0.1110674769484571, 0.19956902334732668, 0.17030068673193455, 0.11195770810757365, 0.13252012830759796, 0.19474736707551138, 0.12038451592837061, 0.22936785221099854, 0.11603891982563905, 0.22084093333355018, 0.09904954968286411, 0.28624387883714264, 4.860792543206896, 99.98511968340192, 76.28374426705497, 81.41332135881696, 49.60589606421334, 123.12723459516252, 78.7689550944737, 72.54727404458183, 56.27811915533883, 42.67795147214617, 48.632505553109304, 37.10381473813738, 39.15057338987078, 84.88305023738316, 73.79291929517473, 72.53549684797014, 76.8855972290039, 73.4366295678275, 69.12439686911446, 75.33238996778215, 66.36842863900321, 61.75428976331438, 60.14216872623989, 63.38949966430664, 56.76221057346889, 66.02836295536586, 56.32320254189627, 42.57637228284563, 25.18307876586914, 1.7626919746398926, 29.887380940573557, 62.02214281899588, 52.18286827632359, 48.733650479997905, 46.73617887496948, 6.33223557472229, 22.39445400238037, 33.903953892844065, 24.524771690368652, 28.136283772332327, 22.88575417654855, 27.61151933670044, 17.347946098872594, 19.326459544045584, 11.135557396071297, 13.089322226388113, 13.391429901123047, 17.217361654554093, 25.00605603626796, 25.315078905650548, 23.463774817330496, 40.30586426598685, 30.871718338557653, 11.08307157244001, 0.5995435544422695, 0.3319263575332505, 0.29940512403845787, 0.2205842842480966, 0.4425588867494038, 0.5024237515670913, 0.6472567256007875, 3.9594648395265852, 6.249776525156839, 1.2699445124183382, 0.2565978153475693, 0.3694029865520341, 0.16511813125440053, 2.8255759349891116, 0.19394388661852904, 0.2926453410514763, 0.3193190140383584, 1.3223350154502052, 8.355214885302953, 3.18556101833071, 1.394216301185744, 1.5575774610042572, 2.775341544832502, 2.756824161325182, 5.6069561157907755, 0.29325694537588526, 0.26739512596811565, 0.17604377998837403, 0.33254895412496155, 0.22329060759927544, 0.2971930727362633, 0.35857492472444263, 0.47332051609243664, 0.1514901625258582, 0.18435450403818063, 17.490380695887975, 27.746640954698833, 25.045097964150564, 23.59236512865339, 18.91730965886797, 23.529767070497783, 15.049558435167585, 15.38807988166809, 14.266452159200396, 17.74633148738316, 16.612734624317714, 24.341961111341202, 21.426693269184657, 25.25721604483468, 29.14282066481454, 31.4893992968968, 32.05912031446184, 36.558110169001985, 37.64876542772566, 18.885464327675955, 7.820881911686488, 22.681894029889786, 40.11814131055559, 39.79741941179548, 65.5272102355957, 13.790069767407008, 6.121684312820435, 6.274230710097721, 4.20755808694022, 22.65115519932338, 22.926635640008108, 37.59264830180577, 67.14130456107003, 56.76226268495832, 51.71796778270176, 56.049898624420166, 54.13440881456648, 59.47630895887102, 60.80394990103585, 63.97007724217006, 57.78521817071097, 65.37245995657784, 44.06462778363909, 20.628138542175293, 18.85145115852356, 61.66439396994454, 63.18866893223354, 57.12869678224836, 50.4283230645316, 46.584572655814036, 57.886755670819966, 73.46845231737409, 6.30186630146844, 0.80574909810509, 0.1195028003837381, 0.15032631212047168, 0.19620152190327644, 0.1537429802119732, 0.2400802102472101, 0.14529848976859025, 0.1578587293624878, 0.1255438383668661, 0.24270486512354442, 0.0952188123815826, 0.12297453837735312, 0.13614406170589582, 0.12651057434933527, 0.19922799164695398], [0.007300381166195231, 0.04092477095712509, 0.037838308539773734, 0.051696056367031167, 0.1404068629656519, 0.015285073380385126, 0.037471665535122156, 0.02769575876715992, 0.07149060562785182, 0.015003645892388054, 0.022511897109715, 0.0472649105691484, 0.05908609660608428, 0.10753406012164694, 0.08621024220649685, 0.08863982505031995, 0.09948529130113976, 0.011531574568445129, 0.15293149304177078, 0.2710390218666622, 13.680380293301173, 81.55668354034424, 65.38136059897286, 46.082012925829204, 53.086665630340576, 97.00733021327427, 52.929480007716585, 55.71902888161795, 30.77323109763009, 34.70784657342093, 25.508525439671107, 32.185667855399, 72.50463989802769, 74.2306627546038, 57.299625941685264, 65.97927393232072, 62.48034177507673, 60.448730196271626, 59.183880124773296, 59.54213619232178, 56.80935410090855, 60.12579877035958, 52.642887660435264, 57.988432134900776, 46.26148836953299, 49.46941259929112, 25.127743312290736, 0.6850665424551282, 9.633728589330401, 56.33436482293265, 40.98147930417742, 31.343636512756348, 28.563976662499563, 5.12128962789263, 18.256634984697612, 26.794850655964442, 19.18348298754011, 24.05481117112296, 14.939796004976545, 17.837983437946864, 15.62010281426566, 15.506466763360159, 13.512516157967703, 6.911337094647544, 4.998481520584651, 7.046345370156424, 15.716373579842703, 19.082155670438492, 15.951603106090001, 21.66102647781372, 33.83580943516323, 24.765651839120046, 11.562544175556727, 1.2662445966686522, 0.32905363025409834, 0.04152960689472301, 0.1635520588606596, 0.08918803384793655, 0.039540569697107585, 0.23939393992934907, 0.03984446856858475, 0.6030389325959342, 0.178706554962056, 0.355958955096347, 0.3921881653368473, 0.34632549488118713, 0.22703739654804977, 0.04495332496506827, 0.07866332467113223, 0.2056551974798952, 0.046712745912373066, 1.0997084357908793, 3.9796953882489885, 1.8867181880133492, 4.005398511886597, 0.4373692609369755, 0.7196750310914857, 0.14561959968081542, 0.20884211361408234, 0.0733014459588698, 0.13538544598434651, 0.17344524871025765, 0.10705470905772277, 0.10985901965094463, 0.28307889295475824, 0.17910720274916717, 0.23607875353523664, 0.18070697119193418, 6.587367781570979, 27.017754077911377, 27.838378020695277, 23.63252397945949, 16.715656552995952, 13.531012262616839, 12.537106326648168, 11.658990383148193, 13.268587487084524, 12.30520759310041, 13.128466640199933, 12.70353479044778, 15.980387755802699, 19.838058880397252, 21.10144461904253, 22.112775768552506, 22.25571584701538, 21.358791998454503, 23.172150237219675, 23.954628569739207, 22.161328043256486, 6.28708096912929, 12.07048875944955, 29.731056894574845, 33.50065960202898, 60.907749039786204, 5.644123332841056, 4.752467087336949, 3.0957116910389493, 0.025182765309831927, 0.07611157838255167, 0.2324655002781323, 6.862214633396693, 29.59802668435233, 46.316500731876914, 45.79716805049351, 50.26614516122, 46.77591562271118, 46.272341455732075, 34.79198578425816, 20.17581949915205, 19.218550545828684, 20.42335949625288, 9.444015843527657, 22.649751663208008, 48.66926499775478, 42.00214883259365, 49.926294871738975, 38.045639583042686, 40.66831357138497, 62.11854212624686, 11.980042321341378, 0.3800382087273257, 0.08959805898900543, 0.1713736948690244, 0.07159345796597855, 0.0930061571832214, 0.06933507629271064, 0.10462955704757146, 0.015053703117051294, 0.043502895294555595, 0.04899568376796586, 0.052404877796236954, 0.09123764386666672, 0.057423061558178494, 0.029814920321639096, 0.06997859890439681, 0.04975489999300667, 0.021027566133333103, 0.056301633162157874, 0.04728003511471408, 0.0550642125973744, 0.10108197919492211, 0.04937403828703931, 0.07939034101686307, 0.0642520822584629, 0.04685165899406586, 0.028596244286745787, 0.005160251607386661, 0.07168923318386078, 0.17367292435041495, 0.012961760994845202, 0.10349309231553759, 0.0742061502699341, 0.07287680517349925, 0.028240627476147244, 0.2132491171360016, 0.05128593962373478, 13.901467629841395, 91.54205090659005, 69.00448485783168, 50.32084485462734, 62.50416714804513, 96.76999364580426, 61.10327134813581, 47.289168630327495, 25.60881052698408, 33.658522674015586, 19.93364351136344, 32.82302263804844, 75.90268421173096, 73.63550090789795, 62.03695637839181, 71.27864415305001, 67.1301040649414, 66.03325448717389, 61.71691540309361, 63.095278194972444, 59.22996057782854, 63.93863664354597, 51.660481861659456, 66.73468903132847, 46.31191144670759, 50.25573328563145, 16.80579205921718, 3.2031282356807163, 14.748439141682216, 47.36369153431484, 52.693029335566926, 41.51380164282662, 48.435569286346436, 12.13777598312923, 18.21285959652492, 23.552473783493042, 17.74401078905378, 23.899421657834733, 17.255139010293142, 15.747645684650966, 13.591078570910863, 11.393337300845555, 9.307759932109288, 7.596100739070347, 7.004904576710292, 8.665908796446663, 14.665585347584315, 18.737973179136002, 15.961851699011666, 21.919030461992534, 40.76440020969936, 32.24804530824934, 15.238010951450892, 1.6656531074217387, 0.25774926213281496, 0.27232386863657404, 0.48517940832035883, 0.15276021723236355, 0.0958493071209107, 0.1280719648514475, 0.0331705406175128, 0.7416131539004189, 0.4955645224877766, 0.3313425731446062, 0.8699887224606105, 0.24618612974882126, 0.05350738524326256, 0.02582940409359123, 0.10075069804276739, 0.17828884880457604, 0.3459213322826794, 0.8474766133087022, 6.275113565581186, 5.7646997656141, 1.6913030339138848, 0.48224987408944536, 0.9150286827768598, 0.1815899759531021, 0.30985019356012344, 0.06549343493367944, 0.2661295495927334, 0.46174753137997215, 0.20218303879456861, 0.21734695296202386, 0.25507241434284617, 0.17665845129106725, 0.20111289407525743, 0.23500862238662584, 10.022541965757098, 31.146432740347727, 29.778627736227854, 17.75186746461051, 15.703753914151873, 14.382250836917333, 13.202782835279192, 12.955138615199498, 13.62191207068307, 9.800803235598973, 11.977529679025922, 9.685153075626918, 14.32755548613412, 16.588198798043386, 21.463893924440654, 20.49672031402588, 20.615699529647827, 18.460041761398315, 21.120152643748693, 18.190043449401855, 21.63400145939418, 10.02331234727587, 28.507930755615234, 46.55466413497925, 35.582107135227744, 45.58603661400931, 4.892836332321167, 16.373178107397898, 10.820362789290291, 0.7917103171348572, 0.06859793620450155, 0.15832419081458024, 3.3657065289361134, 28.202190910066875, 49.400885990687776, 48.46954945155552, 52.94847638266427, 46.59837525231497, 44.07564067840576, 32.37987348011562, 13.80570581981114, 13.9308819600514, 23.170350653784617, 16.901032754353114, 23.45134449005127, 45.93350560324532, 49.37805768421718, 58.25007350104195, 45.70195688520159, 48.97400256565639, 67.54757268088204, 6.912025834832873, 0.35370469891599243, 0.14471617101558618, 0.05802874227187463, 0.07455125996576888, 0.07321785044457231, 0.03532817680388689, 0.050496223249605725, 0.07825049718043633, 0.03837790333532861, 0.057689888668911796, 0.03875968445624624, 0.09925359194832188, 0.0188486035913229, 0.03577915153333119, 0.048581237971250496, 0.07471878347652298, 0.11912466638854571, 0.09069947060197592, 0.1432118181671415, 0.11033147679907934, 0.28563249164393967, 0.09145908377000264, 0.13012856378086976, 0.15607195666858129, 0.19507898070982524, 0.09097696428320237, 0.10850108787417412, 0.15542510923530373, 0.2758679927459785, 0.2686614623027188, 0.19735356579933847, 0.2203855277704341, 0.2752032184175083, 0.10820192856980221, 0.3393775134214333, 0.9158930821078164, 31.954966817583355, 106.74867684500558, 80.50410788399833, 70.55184173583984, 70.06024278913225, 123.3867359161377, 78.2636820929391, 85.43889222826276, 43.02098403658186, 51.06314522879464, 37.623293331691194, 48.51916306359427, 90.2443289075579, 86.43463162013462, 66.24167265210832, 77.39745017460415, 73.22031824929374, 66.95881012507847, 66.84947327205113, 68.80359159197126, 64.82191249302456, 68.44666957855225, 59.64396204267229, 65.08545766557965, 53.61937359401158, 56.09863328933716, 30.397781712668284, 1.5576194758926118, 13.234873958996364, 65.80769511631557, 59.3220658983503, 42.24562413351876, 34.56047180720738, 5.950506321021488, 25.184421505246842, 35.25416258403233, 24.796911784580775, 31.842510223388672, 23.849179233823502, 25.71040187563215, 20.02278889928545, 17.678477116993495, 16.432244743619645, 10.393902335848127, 12.481390459196907, 11.229257328169686, 23.647966350827897, 25.784553050994873, 21.728047064372472, 26.779978036880493, 44.51667410986764, 37.01730966567993, 20.929448911121913, 2.047795453241893, 0.47362949379852837, 0.18512682616710663, 0.5291634595819882, 0.17366050715957368, 0.2085978410073689, 0.38893638125487734, 0.7042278285537447, 3.2501614604677473, 0.76552657357284, 0.8722680572952543, 0.8580712590898786, 1.1553625294140406, 0.6609606902514185, 0.08680337680769817, 0.4912356862000057, 0.39849574544600075, 0.3111884003239018, 2.592088669538498, 11.402815512248448, 19.187155110495432, 8.687482953071594, 1.105555236339569, 1.2884234637022018, 0.31381612217852045, 0.5460100184593881, 0.22545442863234452, 0.3622028614793505, 0.8833571108324187, 0.30039966638599125, 0.33270564143146786, 0.43920871508972986, 0.23028886850391114, 0.37892058012740953, 0.3792715998632567, 18.0776789188385, 34.101286206926616, 35.54001842226301, 26.781588281903947, 23.257633924484253, 18.945731265204294, 21.15095921925136, 17.70056196621486, 23.62086663927351, 19.460992302213395, 19.27465203830174, 16.712118182863506, 23.90648797580174, 27.257946355002268, 28.34633650098528, 27.219936234610422, 28.581362792423793, 25.49066683224269, 34.202490193503245, 32.069368907383506, 28.83482960292271, 8.55561135496412, 17.53965732029506, 39.75200251170567, 46.617038113730295, 67.90918472834996, 9.021074652671814, 9.274767279624939, 5.608389616012573, 0.33191243399466785, 0.21012644469738007, 0.3578069587903363, 13.785829629216876, 52.322047642299104, 61.121982846941265, 54.64451081412179, 59.79425157819475, 53.55884436198643, 56.28303847994123, 44.90506451470511, 24.959683758871897, 24.55649369103568, 33.97749015263149, 17.180028983524867, 32.912421635219026, 67.53262710571289, 58.1855594771249, 60.91805321829659, 52.200197083609446, 55.1828224999564, 78.0542494910104, 24.013019493647985, 0.8308193385601044, 0.2298401397253786, 0.2048696167767048, 0.18820345321936266, 0.15227229627115385, 0.16128663399389812, 0.15088322652237757, 0.11807957318212305, 0.12515294791332313, 0.22101235842066153, 0.21655411193413393, 0.22557804414204188, 0.14264309725591115, 0.11100127228668757, 0.13107444159686565, 0.19161970061915262], [0.07604976384235279, 0.050919802127672095, 0.07015114357428891, 0.017529979348182678, 0.0352246052186404, 0.026687014681686248, 0.04466321731784514, 0.02522109914571047, 0.06502295910779919, 0.03233554899426443, 0.07516338676214218, 0.12893694772252015, 0.05432998342439532, 0.020614268757136803, 0.01272895562994693, 0.14336303648139748, 0.04883894217865808, 0.1339303683489561, 0.048689108075840135, 0.17312966207308428, 0.13733958612595284, 38.60837766102382, 69.56574644361223, 48.36033419200352, 39.39101232801165, 67.61688096182687, 68.51546369280133, 59.60215473175049, 42.95114074434553, 28.630950348717825, 35.184409618377686, 17.826960120882305, 58.23652451378958, 67.04200785500663, 58.867723192487446, 67.24887657165527, 64.79978942871094, 60.01416206359863, 60.95064721788679, 60.5974702835083, 62.25282996041434, 52.92965023858206, 60.645280838012695, 37.09264203480312, 17.230580602373394, 15.690602711268834, 4.748345937047686, 4.394663955484118, 51.465414660317556, 48.90817880630493, 29.13518806866237, 30.55422040394374, 7.25249798808779, 22.672017165592738, 25.019526856286184, 21.30494867052351, 20.922184569495066, 15.106997455869402, 18.072094304221018, 19.139221225466045, 15.097876208169119, 14.78505962235587, 9.773664440427508, 5.839639127254486, 6.286314930234637, 7.901705963271005, 14.135304042271205, 19.73293958391462, 15.974575587681361, 28.572844300951274, 33.86155251094273, 28.52858427592686, 15.187933547156197, 3.3070580874170576, 0.3254401327243873, 0.026558361049475412, 0.03731402149423957, 0.27979559770652224, 0.08794965994145189, 0.20385079644620419, 0.04691468471927302, 0.0491018439643085, 0.13578916074974196, 0.4795529416629246, 0.7135246268340519, 0.36053323107106344, 0.21556615137628146, 0.059112450906208584, 0.1537663082459143, 0.3346636492226805, 0.3505304035331522, 0.40924322445477757, 3.0488007111208777, 1.7737811910254615, 0.5283392838069371, 0.059189919249287674, 0.11751307786575385, 0.6402082666754723, 0.19982859013336046, 0.04943873660106744, 0.11354017390736512, 0.3270222863980702, 0.011959944751911929, 0.15019322426191398, 0.17618047765323094, 0.37615457283599035, 0.3665405187223639, 0.10530021427465336, 7.4286500215530396, 28.044713463102067, 33.54241132736206, 28.958771569388254, 15.672252518790108, 13.941524863243103, 12.685393043926783, 9.521757500512258, 9.491933226585388, 8.260925224849156, 9.777583224432808, 14.314254896981375, 15.5867531980787, 19.420319284711564, 22.16382244655064, 21.345302070890153, 26.73771561895098, 28.346372979027883, 32.02483442851475, 27.163009643554688, 23.798241989953176, 32.48476696014404, 9.14247270992824, 12.386539731706891, 29.575472831726074, 41.60809564590454, 55.7184556552342, 4.2300025054386685, 9.741599372455052, 6.251460160527911, 2.1628422055925642, 0.348816342651844, 0.33820459778819767, 2.8119767904281616, 16.070384298052105, 29.601483413151332, 28.902218444006785, 25.779433965682983, 17.247593266623362, 5.986351643289838, 1.4431239111082894, 0.8310447207518986, 13.193361946514674, 19.59278573308672, 46.00428342819214, 46.178724902016775, 43.15618903296334, 48.07816437312535, 40.44039528710501, 49.35822057723999, 39.573652676173616, 0.018411616861288036, 0.122164625408394, 0.17809858758534702, 0.09357142435120684, 0.04163534639935408, 0.12942641574357236, 0.04433524402390633, 0.01626170240342617, 0.03503589445192899, 0.027040924976712892, 0.03500681583370481, 0.0433572036480265, 0.007205102127045393, 0.045920549492750845, 0.01870173977554909, 0.08988608353372131, 0.10485403678779091, 0.06458446263734784, 0.06560957977282149, 0.03682323032990098, 0.034376701073987145, 0.07878105049686772, 0.06688200935189213, 0.05356315742912037, 0.014243510252396976, 0.08279447656657014, 0.02679858110578997, 0.025427377184054682, 0.13837798897709164, 0.054464903327503374, 0.030218054939593588, 0.026839362756748284, 0.11518098014805998, 0.04146901711023279, 0.12200001281286989, 0.0806176480171936, 0.14148143173328467, 0.07467754890343972, 30.375887938908168, 82.72676018306187, 52.53957142148699, 52.72739165169852, 82.20085103171212, 77.67983886173793, 60.12953690120152, 30.391684668404714, 24.58898867879595, 25.43884195600237, 20.95020318031311, 63.71833011082241, 68.93336309705461, 64.8317094530378, 71.17663070133754, 70.1180726460048, 62.77832916804722, 65.78197288513184, 63.28779193333217, 67.17879704066685, 51.529609067099436, 69.05434513092041, 37.802574225834434, 18.155700240816387, 11.212555595806666, 13.419316496167864, 13.665564996855599, 38.59711115700858, 55.16922834941319, 38.500294957842144, 52.01348509107317, 14.08564179284232, 21.154577493667603, 22.920726197106497, 18.198791231427872, 19.465135165623256, 17.227042232240947, 15.960576704570226, 16.783516134534562, 10.830612250736781, 10.939365455082484, 6.280169248580933, 4.443928420543671, 6.390372455120087, 12.656493748937335, 15.297982590539114, 19.488567965371267, 16.803862197058542, 29.925394535064697, 41.69034842082432, 36.62126234599522, 17.154270274298533, 4.211957165173121, 0.21497034334710666, 0.010747418788793896, 0.02245681363690112, 0.8968388959765434, 0.31131979184491293, 0.5245046381439481, 0.028161956429747597, 0.10427699025188174, 0.4075518809258938, 0.8909247304712022, 1.2028446729694093, 0.21950132878763334, 0.19291784667543002, 0.030835152004978487, 0.06956912337669305, 0.10209918461207833, 0.24715374782681465, 1.5862062105110712, 6.5691370112555365, 3.1821542297090804, 0.28413534483739306, 0.21217564759509905, 0.3263678529432842, 1.0527006153549467, 0.4784484495009695, 0.36552931155477253, 0.19331989224467958, 0.6824982059853417, 0.1709084641188383, 0.06703355336295706, 0.3174642249941826, 0.4078794776328972, 0.3606327585875988, 0.25286180153489113, 11.126683677945818, 34.72056525094168, 34.01583726065499, 21.06606091771807, 12.02772867679596, 14.802635090691702, 14.373840042522975, 11.412996360233851, 9.425829802240644, 7.947235771587916, 8.005958471979413, 12.41545900276729, 11.43655857018062, 14.801839521953038, 18.085716247558594, 18.781922272273473, 22.189106941223145, 25.545265776770457, 28.711136034556798, 31.158574717385427, 23.963195698601858, 33.52317523956299, 9.767534392220632, 27.281882899148123, 43.27287013190133, 37.114924907684326, 37.45225300107683, 4.138673211847033, 18.47708569254194, 15.442114285060338, 7.492635982377188, 1.2615779042243958, 0.24254535511136055, 1.706065024648394, 14.188017419406346, 26.852107286453247, 24.00761900629316, 21.991668667112076, 14.802209513528005, 5.2659172500882825, 1.204670203583581, 0.8512973625745092, 15.13244002205985, 25.776779753821238, 38.696136883326936, 50.69735731397356, 47.81536613191877, 47.364045892442974, 41.15595204489571, 54.834425926208496, 27.87399796077183, 0.20355040899344853, 0.08384340349584818, 0.1529110555670091, 0.041007755789905787, 0.04433690643470202, 0.04862495937517711, 0.08182714347328458, 0.04560779234660523, 0.03734256067712392, 0.011847804117548679, 0.008602587406390479, 0.028726356769246713, 0.07575174447681222, 0.05149077916783946, 0.042170992121100426, 0.01710138948900359, 0.052955369864191325, 0.21058631502091885, 0.17250963034374373, 0.10392633013959442, 0.10359738993325404, 0.18149046200726712, 0.17609506366508348, 0.2452937476336956, 0.10660676059446164, 0.2056111198450838, 0.17075470808361257, 0.15189101387347492, 0.3075244469302041, 0.16322314579571995, 0.1497790871986321, 0.09850870977555003, 0.24344414259706224, 0.10816581015075956, 0.26120840651648386, 0.30459806110177723, 0.28860960475036074, 0.16307930994246686, 65.93346445901054, 93.85411957332066, 68.58252770560128, 62.062664713178364, 92.7404761995588, 93.0120951788766, 92.80455943516323, 64.08904429844448, 42.15744454520089, 50.7333733013698, 32.1328580720084, 75.40736103057861, 74.92489896501813, 68.16097354888916, 78.70504556383405, 74.86806964874268, 63.42084298815046, 71.27910273415702, 69.94051837921143, 74.2321913582938, 58.23249455860683, 68.18627193995884, 46.27605874197823, 22.539205823625835, 17.709589413234166, 11.466273409979683, 8.950657265526907, 60.62491566794259, 64.49354062761579, 37.90481001990182, 39.113087858472554, 9.345638036727905, 29.82543080193656, 33.89652974264962, 28.987782035555156, 28.18450948170253, 23.386295454842703, 23.3323426927839, 24.68136497906276, 18.608463968549454, 17.049425431660243, 13.299106580870491, 9.724343521254402, 11.359421406473432, 17.26344210760934, 21.06419358934675, 27.196520805358887, 22.600978783198766, 34.449213777269634, 48.23612124579293, 45.98461307798113, 22.71117373875209, 6.374925741127559, 0.30814519790666445, 0.12647077148514135, 0.1187932291733367, 0.44048905638711794, 0.4832327184932572, 0.3778860042137759, 0.12728426711899893, 0.14885758236050606, 0.9843482545443943, 0.5537079168217522, 3.8772463713373457, 1.125300062554223, 0.3040723593107292, 0.17319932047809872, 0.2620710145149912, 0.36932297370263506, 0.4566188380122185, 4.7144304769379755, 13.682433485984802, 17.010126420429774, 1.6461042421204704, 0.5459686549646514, 0.21189671541963304, 2.6701803420271193, 1.590557411313057, 0.6748980166656631, 0.5066172065479415, 1.0449141817433494, 0.2682930449289935, 0.473234586417675, 0.3552157149783203, 0.8335406982472965, 0.5608832889369556, 0.42621086112090517, 16.793219293866837, 38.247783524649485, 39.212509632110596, 34.43935080936977, 20.071690320968628, 20.042801448277064, 19.41454185758318, 15.305521386010305, 14.60899748120989, 14.491397483008248, 15.48632219859532, 23.267542055674962, 23.452174799782888, 27.048798629215785, 30.186445304325648, 28.868615218571254, 31.95084653581892, 36.33453450884138, 37.91151850564139, 37.15357426234654, 29.42364079611642, 41.13285970687866, 12.765152284077235, 17.333273240498134, 38.138147899082725, 51.28243037632534, 61.518655504499165, 6.3043594019753595, 17.425757237843104, 11.53331744670868, 5.274279841354915, 0.7998076283505985, 0.3424528241157532, 3.6822503890310014, 36.728209018707275, 42.85943494524275, 37.02322605678013, 31.536153725215367, 22.1602041721344, 7.944133400917053, 3.450109337057386, 2.0106126027447835, 24.457127502986364, 25.476699216025217, 67.92022541591099, 69.67155361175537, 53.95525646209717, 61.67312090737479, 54.68930932453701, 63.23368631090437, 53.74910340990339, 0.5049059955137116, 0.2100640737584659, 0.32234468311071396, 0.18855322445077555, 0.1234927491417953, 0.18592167565865175, 0.16769911561693462, 0.18321657367050648, 0.05378171695130212, 0.17392582792256558, 0.22366860588746412, 0.17057370208203793, 0.19944562496883528, 0.11395348315792424, 0.13492828980088234, 0.1081131286919117, 0.2777373567223549], [0.04123562481254339, 0.10517651055540357, 0.11492597311735153, 0.059745646214910915, 0.051560854871890376, 0.03309413078906281, 0.016115539175059115, 0.03813605309863176, 0.03561225566746933, 0.055504639499953816, 0.08109264288629804, 0.05575652526957648, 0.11239625207547631, 0.07711082976311445, 0.06452261417039803, 0.12043664098850318, 0.06138178413467748, 0.03840002018426146, 0.22206157711999758, 0.06332270641412054, 0.009792506279024695, 0.9050404301711491, 41.459345136369976, 58.951845032828196, 41.1658810206822, 45.65321527208601, 67.82287420545305, 55.68419756208147, 59.39479269300188, 27.95048025676182, 31.775425365992955, 15.875035694667272, 60.68132809230259, 74.59120477948869, 70.2341423034668, 61.31114755358015, 60.85622814723423, 58.459509577069966, 59.485702923366, 57.51221302577427, 48.65832505907331, 60.86575412750244, 36.016845498766216, 3.566743318523679, 0.9441129735537938, 2.417733831065042, 4.558961927890778, 33.71626567840576, 61.151929582868306, 31.193023885999406, 27.414322512490408, 7.9694656644548685, 22.345074892044067, 23.12393147604806, 21.3510308606284, 23.727189711162023, 16.170707600457327, 20.18795279094151, 16.668688467570714, 14.620187555040632, 17.152819837842667, 14.47768955571311, 9.988237840788704, 9.068272028650556, 9.552222745759146, 12.110829131943838, 16.23140706334795, 20.737609148025513, 15.332160779408046, 29.507036549704416, 37.452871390751426, 26.42183140345982, 13.474198579788208, 2.5546374448708127, 0.025024096681071178, 0.14641659334301949, 0.3578905543046338, 0.2367369325033256, 0.05979659062411104, 0.095204854916249, 0.045713080625448904, 0.028461124215807234, 0.12028540910354682, 0.7603240555950573, 1.328507187111037, 0.22330446328435624, 0.04307106543066246, 0.22766590996512345, 0.16272911801934242, 0.03546902710305793, 0.3178443945944309, 0.7359574288129807, 2.9705164432525635, 1.2760251632758548, 0.18141936510801315, 0.21805507210748537, 0.4755793320281165, 0.5366002033863748, 0.3400259757680552, 0.15396522757198128, 0.053266108368656466, 0.5510923543146679, 0.16049783703471932, 0.12423664065343992, 0.34052586608699387, 0.09770981621529375, 0.8012605075325284, 0.2012846448591777, 12.01159061704363, 34.47841010774885, 37.29926061630249, 25.838167088372366, 17.445469277245657, 15.335704360689435, 13.77463173866272, 11.314626370157514, 10.441151823316302, 7.546752027102879, 8.087054371833801, 7.432507140295846, 11.380629914147512, 16.281144005911692, 21.035956110273087, 21.352347544261388, 21.68216289792742, 29.701144899640763, 24.526946476527623, 23.286931003843033, 20.939027002879552, 17.511161020823888, 40.90739413670131, 12.583212835448128, 15.202663728169032, 37.60458183288574, 47.328967911856516, 34.352786677224294, 6.468521884509495, 21.00299733025687, 5.57323911360332, 1.6648541731493813, 0.10908416658639908, 0.15317158587276936, 0.7863470134990556, 4.625260770320892, 4.896638299737658, 5.4360386814389905, 3.7819457479885648, 1.4843587556055613, 0.27332853472658564, 0.29914991344724384, 4.653711906501225, 28.364191634314402, 53.286627837589805, 46.5723021371024, 39.24714640208653, 29.60026400429862, 34.35485029220581, 41.86054801940918, 4.793469275747027, 0.2552200364215033, 0.0257906376916383, 0.036218065302819014, 0.058682660040046485, 0.022666143386491706, 0.09263759053179196, 0.1031840331852436, 0.041723840936486206, 0.025604622405288473, 0.07585526856460742, 0.0958516209253243, 0.05732100310602358, 0.046306656274412356, 0.07680846098810434, 0.02343998713019703, 0.03624117620555418, 0.0756272061594895, 0.051714739828769646, 0.04105103614607027, 0.09164370636322669, 0.0067420566837037245, 0.07725505238132817, 0.02098819922788867, 0.012081875798425503, 0.032384902238845825, 0.02300330065190792, 0.1164033609841551, 0.02030494499818555, 0.2522095393921648, 0.08653549796768598, 0.05012682539277843, 0.024341923018385257, 0.1088514155043023, 0.04836874455213547, 0.032429797508354695, 0.22034892759152822, 0.00806928432679602, 0.11503611292157855, 1.2601319189582552, 40.66081299100603, 74.48392459324428, 48.26809685570853, 61.253484453473774, 76.96707875388009, 66.84508201054165, 45.39457900183541, 20.437846490315028, 25.40570252282279, 22.280143976211548, 63.68579864501953, 74.80498695373535, 74.24074459075928, 72.70049571990967, 62.304844175066265, 57.765328952244346, 62.13340432303292, 60.76581123897007, 55.373401165008545, 68.88841520036969, 35.66480459485735, 2.975521968943732, 0.7521147589598383, 7.344871248517718, 17.118158749171666, 21.03339569909232, 60.408569608415874, 46.58145638874599, 54.725592817579, 14.915237597056798, 19.099670342036656, 19.121307032448904, 13.868863207953316, 19.27437584740775, 17.085821832929337, 18.259377786091395, 15.66531126839774, 12.127265964235578, 9.609623551368713, 8.275413087436132, 6.552020124026707, 10.676897253308978, 12.668137192726135, 15.865143196923391, 15.431044067655291, 19.842014142445155, 18.155055795397075, 31.42628186089652, 43.683526039123535, 32.91893209729876, 14.931762150355748, 4.170094702925001, 0.05206471122801304, 1.0458197274378367, 1.4118342186723436, 1.0516728247914995, 0.8848321373973573, 0.284221030239548, 0.391093199806554, 0.12083855085074902, 0.26635873158063206, 1.9696809819766452, 1.1888214711632048, 1.3234321794339587, 0.04258857274960194, 0.5162207569394792, 0.07928070332854986, 0.03399432962760329, 0.39245130121707916, 0.9551120804888862, 6.7755862304142545, 0.5093818296279226, 0.5870237148233822, 0.26818637922406197, 0.8116368278861046, 3.511818242924554, 0.3336397670209408, 0.230754126395498, 0.013559855687032853, 0.4186281780047076, 0.23657264560461044, 0.07063390766935689, 0.6144261072788919, 0.20852905112717832, 1.1944073885679245, 0.2886454313993454, 15.74532151222229, 38.536293574741904, 42.53015981401716, 22.53649081502642, 12.462867430278234, 17.095901932035172, 13.903941188539777, 12.114911198616028, 10.465961234910147, 7.9448264837265015, 5.607301788670676, 5.859013744762965, 6.81675170149122, 11.093039631843567, 15.740089518683297, 15.158384595598493, 13.910475969314575, 18.76544288226536, 16.686864955084665, 12.409364564078194, 16.03455764906747, 12.28193894454411, 31.63369948523385, 13.994947825159345, 28.768251964024135, 47.23237752914429, 39.490190914699006, 22.547543661934988, 8.34147047996521, 26.252628871372767, 17.407704080854142, 4.061798342636653, 0.6067113812480653, 0.10915479529649019, 0.5127682621989931, 1.8158296261514937, 1.4304801438535963, 3.066249591963632, 3.226669818162918, 0.8009564695613725, 0.39650153102619307, 1.028824976512364, 8.326351199831281, 36.03372614724295, 48.36968994140625, 58.44327858516148, 45.66464853286743, 41.04599332809448, 41.56128910609654, 37.16229772567749, 1.9465534687042236, 0.2602525678064142, 0.043738353731376786, 0.02821779138009463, 0.06222160692725863, 0.05151022598147392, 0.2066478535000767, 0.07074252076979194, 0.029277350953114883, 0.022098318141485964, 0.13354206989918435, 0.06216522066720894, 0.042906256059982946, 0.005809995112940669, 0.04330239498189517, 0.06270328536629677, 0.06096346729568072, 0.056498700087623935, 0.18617423996329308, 0.09946153579013688, 0.17268230393528938, 0.22657945326396398, 0.15180313001785958, 0.1544913500547409, 0.07907866952674729, 0.10896076820790768, 0.13928139050092014, 0.25648219298039165, 0.12020741828850337, 0.42225307492273195, 0.19272306641297682, 0.10901018591331584, 0.23506103243146623, 0.1980000739651067, 0.14129011199942657, 0.1105992877855897, 0.2116556047861065, 0.24500965859208787, 0.14806755046759332, 2.46362082021577, 74.284302847726, 83.8189058303833, 64.28815882546562, 73.28486701420375, 91.00706045968192, 87.11158766065324, 90.5488337108067, 41.087362902505056, 46.35361800874983, 29.323864664350236, 69.3620183127267, 83.45692552839006, 80.5613818849836, 75.4258154460362, 66.5621235711234, 63.293690953935894, 62.974386487688335, 61.937305314200266, 62.093459129333496, 71.99979073660714, 43.592817306518555, 5.231132830892291, 1.052663920181138, 3.585034017051969, 8.64849053110395, 36.970398902893066, 77.02199036734444, 47.51516921179635, 39.46121692657471, 9.938645073345729, 31.79974753516061, 29.869437217712402, 28.793913398470195, 30.070914132254465, 25.964983872004918, 29.30856125695365, 25.916751214436122, 20.37969527925764, 17.96533349582127, 16.033729076385498, 12.672378199441091, 15.264235189982823, 17.57685102735247, 21.21143286568778, 23.702523606164114, 23.668097019195557, 23.615664175578527, 35.32465205873762, 51.834530762263704, 41.178533690316335, 21.527079105377197, 5.512313399996076, 0.1334582029708794, 0.5048898735216686, 0.4285232541816575, 0.7502385824918747, 0.33021859345691545, 0.1740616299211979, 0.26782567000814844, 0.1346090119332075, 0.14673208498529025, 4.874931258814676, 5.313155446733747, 0.7098367618662971, 0.4468830275748457, 0.7270293736032077, 0.7508248910307884, 0.12805365797664436, 0.3602613013769899, 5.551465630531311, 17.10880126271929, 3.021074576037271, 0.46294598707130974, 0.41705888935497826, 0.5794483327439853, 6.040654855115073, 2.387309406484876, 0.7241775180612291, 0.10173882823437452, 3.807887281690325, 0.804994024336338, 0.7252317986318043, 1.3187658126865114, 0.24362327584198543, 1.4120403847524097, 0.6072114886982101, 20.937349012919835, 38.55395589556013, 45.085842745644705, 30.782531261444092, 21.66962139947074, 21.50626925059727, 21.183457681110927, 18.52655860355922, 17.582630191530498, 14.28325811454228, 15.012564488819667, 13.474389655249459, 19.147571223122732, 21.904029301234655, 28.032112904957362, 25.964117084230693, 27.060634885515483, 31.8099752834865, 28.366385528019496, 29.386388029370988, 31.40507595879691, 19.801090989794048, 45.154452732631135, 14.044649158205305, 18.72596321787153, 45.474941866738455, 54.4947840826852, 46.308503355298726, 11.313254100935799, 30.425786427089147, 15.43978316443307, 5.999799881662641, 0.8673939502664975, 0.2495322844811848, 0.47612427707229343, 9.024072800363813, 7.128594670976911, 7.315697499683925, 5.751529889447348, 2.240740631307874, 0.7416069656610489, 1.2859731380428587, 10.721469947269984, 42.31846557344709, 84.65920012337821, 60.8365022114345, 54.8689341545105, 51.23208720343453, 49.988217217581614, 64.44263812473842, 10.25495399747576, 0.41673568955489565, 0.11043141822197608, 0.2003298918051379, 0.138818996027112, 0.25939088261553217, 0.33401293413979666, 0.20929547000144208, 0.08994027812566076, 0.18559022487274238, 0.3125670477747917, 0.16790510527789593, 0.1320027724972793, 0.14213156327605247, 0.21872367337346077, 0.1186904718301126, 0.06814827783299343, 0.1414202685867037], [0.11441320420375892, 0.0483670685706394, 0.22391764181000845, 0.04852107905649713, 0.07434969435312919, 0.081984271827553, 0.08405321330896445, 0.08788336028477975, 0.025629483928371753, 0.06400460696646146, 0.14959254435130528, 0.12921214795538358, 0.051163983132158, 0.07671132870018482, 0.08725000212767295, 0.14329127461782523, 0.07554244356495993, 0.11141831347984926, 0.1587285434028932, 0.053940494145665846, 0.10456659578319107, 0.41222299741847174, 7.504992485046387, 55.079530579703196, 41.48098182678223, 36.803225244794575, 55.18450743811471, 58.36926637377058, 54.98677212851388, 27.817483050482615, 25.317978041512625, 27.154270546776907, 41.030860151563374, 41.28812067849295, 39.85521452767508, 67.12382984161377, 59.564961024693076, 64.1156975882394, 64.15514251164028, 58.010357175554546, 51.49036911555699, 25.267313514436992, 0.4971189647912979, 0.2559468831334795, 6.251946534429278, 12.77501004082816, 20.123857395989553, 72.2179433277675, 38.41848686763218, 28.25913313456944, 11.38180068561009, 29.606812681470597, 25.100329194750103, 24.61917339052473, 28.22666593960353, 19.74542202268328, 19.509521995271953, 17.05531402996608, 16.632212162017822, 18.78903201648167, 16.586887325559342, 14.093939679009573, 12.237086585589818, 10.158002308436803, 13.022719400269644, 17.69037069593157, 22.468617337090627, 23.947157519204275, 17.615232876368932, 30.419314180101665, 38.198868206569124, 30.904593740190776, 15.998718840735298, 4.643765125955854, 0.2897017204335758, 0.586087282214846, 3.0774644187518527, 3.371441181216921, 2.578354469367436, 0.3845537235694272, 0.44809622104678837, 0.13773053086229733, 0.4499549998768738, 0.7363120040723256, 1.9573544434138705, 0.674289615026542, 0.0354450442828238, 0.1409801029201065, 0.052592258634311814, 0.10128790100238153, 0.3967542717499392, 1.707146555185318, 2.9805615842342377, 0.4092846150909151, 0.19586350289838655, 0.32284280923860414, 0.79159762603896, 0.21986344935638563, 0.21168195908623083, 0.11012965334313256, 0.015200897718646696, 0.06358320279312984, 0.03701483165579183, 0.05981630885175296, 0.1158386298588344, 0.40869407249348505, 0.03453096940315195, 1.5865606772048133, 13.095460091318403, 41.057228565216064, 39.036477020808626, 25.675417695726665, 15.684896503176008, 14.869759900229317, 16.011757135391235, 9.595787950924464, 8.852289012500218, 5.883014125483377, 6.7237235733440945, 10.829396315983363, 14.73797515460423, 20.041727951594762, 27.45454910823277, 36.68305267606463, 48.29095990317208, 52.43214532307216, 59.2170786176409, 67.8550443649292, 50.73701763153076, 39.78523227146694, 28.307112182889664, 29.908701487949916, 12.044922862734113, 25.154881238937378, 45.62952538899013, 42.872098037174766, 21.143185922077723, 9.260103106498718, 22.895770004817418, 1.494828605226108, 0.46491987258195877, 0.24557566536324366, 0.2721505436514105, 0.238619541483266, 0.052855998410710266, 0.07048205153218337, 0.32903444128377096, 0.15306440448122366, 0.19138808947588715, 0.10722648698304381, 3.348420713629041, 24.629588740212576, 42.386151450020925, 54.546287604740684, 30.94359745298113, 27.175764799118042, 33.6482949256897, 12.0552122763225, 0.03575680737516709, 0.09016946689890963, 0.046305875959140916, 0.026808660743491988, 0.051692792613591464, 0.03711430488952568, 0.06001689058861562, 0.048462334887257645, 0.025635758680956702, 0.07087545256529536, 0.07208475803158113, 0.0630017254235489, 0.057625984240855486, 0.04337893033932362, 0.05341360491833516, 0.05930237964327846, 0.13911041324692114, 0.035587981077177186, 0.026128444654334868, 0.041603590960481336, 0.02248725271783769, 0.05080811187092747, 0.07853708323091269, 0.08013747592589684, 0.02740264860247927, 0.07267026589917285, 0.031189462635666132, 0.06036592221685818, 0.13513764499553613, 0.0707982692069241, 0.012467524568949426, 0.06515899859368801, 0.07384803984314203, 0.04558916995301843, 0.10253643257809536, 0.11244339668857199, 0.0820207634408559, 0.048042759365801296, 0.22077808742012295, 0.049221764850829325, 7.172976289476667, 67.99125685010637, 55.72856528418404, 47.848408290318076, 67.27253518785749, 73.1750020980835, 56.38272428512573, 21.893509728567942, 28.50893998146057, 33.09369318825858, 41.53777640206473, 37.615438393184114, 42.24776070458548, 66.50933810642788, 62.865806988307405, 69.21478598458427, 68.66273771013532, 61.299113273620605, 55.29983711242676, 23.229181051254272, 0.34767214262059754, 1.0829408041068485, 12.482559493609838, 28.158596175057546, 14.872943912233625, 62.38363674708775, 52.938922609601704, 51.13114377430507, 14.090534193175179, 17.343365498951503, 23.372414691107615, 21.04102655819484, 23.581492934908184, 13.160463094711304, 11.205851452691213, 12.904613920620509, 13.505061609404427, 12.318175537245613, 10.904052104268755, 10.920479382787432, 12.568823984691075, 10.011442218508039, 14.863714967455183, 23.275942427771433, 24.241589171545847, 24.10251750264849, 20.89955254963466, 31.04589578083583, 48.87396935054234, 41.36253588540213, 19.65750994001116, 4.519719805036273, 0.6337244031684739, 0.41849827926073757, 1.2759189861161369, 1.4104040839842387, 1.656606987118721, 0.38714559163366047, 0.5870211635317121, 0.16126941277512483, 2.7824502033846716, 4.622442407267434, 4.269323664052146, 1.9343103085245406, 0.25444645221744266, 0.13500269795102732, 0.08644837407129151, 0.061543580809874196, 1.8536221810749598, 1.0489396857363837, 3.560366175004414, 1.262057547058378, 0.8526951989957264, 0.17873455131692545, 2.182033781494413, 2.21295673932348, 0.47523099929094315, 0.0667852299021823, 0.007409198675304651, 0.250408056059054, 0.11405246784644467, 0.1826200056821108, 0.7181837196860994, 0.6400746224181992, 0.04090045565473182, 4.511069732052939, 20.396247625350952, 47.38436937332153, 37.956921509334016, 25.212250777653285, 11.045180439949036, 12.029212985719953, 12.82392622743334, 9.590826937130519, 6.43849915266037, 3.5623140590531484, 4.5874577930995395, 7.64370892729078, 15.372241462979998, 15.662318331854683, 15.287777423858643, 18.388329403741018, 28.647876160485403, 33.384760175432476, 30.673708575112478, 38.28420598166329, 22.398140021732875, 17.468584196908132, 15.822592428752355, 16.733402252197266, 11.107081941195897, 42.90792989730835, 51.77472761699131, 31.695253576551163, 15.764472484588623, 8.856542178562709, 26.587445190974645, 10.111827186175756, 0.7148272512214524, 0.5035936545048441, 0.48807344159909655, 0.31144412660173004, 0.03030581326623048, 0.16092044221503393, 0.10152859772954669, 0.06006598259721484, 0.1148152904851096, 0.22552840252007755, 4.574931059564863, 25.372519663402013, 46.54174048560006, 58.2574177469526, 38.992786748068674, 32.37394666671753, 41.45038890838623, 10.323983481952123, 0.08367478754371405, 0.04769531890217747, 0.05697568306433303, 0.01082302285690925, 0.05018875189125538, 0.040377627459487746, 0.2332106131528105, 0.04728831663461668, 0.061444161858941825, 0.026355078743238534, 0.02614664296353502, 0.0898541109636426, 0.07170842215418816, 0.07956798827009541, 0.07184232425476823, 0.09800273978284427, 0.06579064684254782, 0.05127580231055617, 0.13660261567149842, 0.12061097020549433, 0.19515826074140413, 0.5400344048227582, 0.20402028092316218, 0.1806066565747772, 0.20187141480190413, 0.17033396208924906, 0.12009982977594648, 0.1306035654353244, 0.357921196946076, 0.3249519132077694, 0.13997741815234932, 0.2234023351754461, 0.25312976858445574, 0.20284969945039066, 0.24594020151666232, 0.24536135686295374, 0.34353706879275187, 0.21369172552866594, 0.4211012210164751, 0.6196779140404293, 17.99802824429103, 95.7587319782802, 73.51035690307617, 64.79998397827148, 80.24168831961495, 88.25584479740688, 92.16677039010185, 45.93462078911917, 35.21549933297293, 43.02142872129168, 51.824052878788535, 47.37550694601876, 48.23640264783587, 72.60996764046806, 66.85514995029995, 71.00202247074672, 71.10144424438477, 68.38073117392403, 63.02474703107561, 29.589407444000244, 0.5118415462119239, 1.1939792058297565, 6.92776437316622, 14.680232150214058, 23.947272164481028, 89.21551609039307, 59.21814864022391, 40.28588472093855, 13.399752974510193, 37.00513989584786, 32.64387028557913, 33.48407425199236, 34.54068333762032, 28.746594429016113, 27.317539317267283, 24.401915379932948, 23.264319828578405, 21.345548731940134, 19.252257994243077, 16.65141871997288, 15.160620178495135, 15.629029512405396, 21.567962305886404, 29.83728095463344, 31.233236585344585, 28.399559702192033, 28.450246810913086, 32.75936324255807, 53.54098401750837, 56.39228848048619, 24.70321880068098, 9.341709698949542, 0.4798157789877483, 1.5048575699329376, 5.232715283121381, 8.842071686472211, 7.368901593344552, 3.206347857202802, 0.5995413288474083, 0.19500443685267652, 1.718014840568815, 2.2242212891578674, 8.383735503469195, 1.3739994317293167, 0.15741057055337088, 0.1701622384467295, 0.18443231843411922, 0.46250396221876144, 0.9393933010952813, 4.841144774641309, 9.938791854040963, 0.7889664843678474, 0.6691919714212418, 0.3566707383309092, 2.806763253041676, 1.5312813520431519, 0.629090660384723, 0.2686465616737093, 0.3684864214488438, 0.5722776832325118, 0.19165417019809994, 0.31949890724250246, 0.8555490630013602, 1.043646678328514, 0.08238795945154768, 4.905822949750083, 27.317822456359863, 40.47967345373971, 44.274862902505056, 33.28583867209298, 20.119349752153667, 19.94327024051121, 22.717541762760707, 15.967660393033709, 13.152758410998754, 8.136052199772426, 11.031766942569188, 16.587038448878697, 20.901987893240793, 25.592091424124582, 37.16197116034371, 44.600848061697825, 58.201745305742534, 62.48968710218157, 70.00317028590611, 88.05678585597447, 72.87826538085938, 55.03767810549055, 31.590919426509313, 37.260006768362864, 13.11693263053894, 32.50128977639334, 54.450951371874126, 51.62874249049595, 32.501911640167236, 13.149197459220886, 31.929803916386195, 7.382532221930368, 1.2786268293857574, 0.393997031130961, 0.27496830959405216, 0.20235810082937988, 0.697092245732035, 0.4283355442540986, 0.5035484369312013, 0.3375590124300548, 0.29391631856560707, 0.5607939394457, 6.565280761037554, 34.16675213405064, 65.94213581085205, 65.37444714137486, 52.83847597667149, 46.36709751401629, 64.35988507952008, 27.57623985835484, 0.23004527443221637, 0.3478494573916708, 0.1826682495219367, 0.09433837248278515, 0.18589557920183453, 0.09933159633406571, 0.21764932173703397, 0.29751271701284815, 0.20519322369779858, 0.1377815974078008, 0.15238941141537257, 0.18481972121766635, 0.3113719033343451, 0.2804473984454359, 0.10315804529402937, 0.16952258348464966, 0.17229040924991879, 0.24150070973805018], [0.04660454671829939, 0.10090046429208346, 0.11948129082364695, 0.044490112856562646, 0.03242870845964976, 0.08593222605330603, 0.05011626399521317, 0.024655611453843967, 0.05115470416577799, 0.058335752226412296, 0.13198777687336716, 0.12393226341477462, 0.11385437633310046, 0.0877041116889034, 0.05954990243273122, 0.09962859789707831, 0.11639394291809627, 0.12724127514021738, 0.05305838165804744, 0.18594304951173918, 0.06250830154333796, 0.11158173185374055, 0.08686912006565503, 20.47626655442374, 48.96365669795445, 32.11508110591343, 36.27706248419625, 59.14465754372733, 57.81615849903652, 35.95471123286656, 20.15586253574916, 28.741107089178904, 16.73683292525155, 10.9259979895183, 9.831669739314489, 35.81294018881661, 48.14347396578108, 57.1804643358503, 49.58705602373396, 30.898371628352574, 8.617056012153625, 3.990279231752668, 0.6324421348316329, 2.7892003783157895, 17.437286036355154, 14.907002244676862, 65.2718083517892, 49.39069645745413, 30.433082035609655, 22.109042848859513, 31.963370663779124, 38.830303124019075, 29.368868146623882, 29.881502764565603, 31.27454710006714, 38.42050184522356, 47.808720179966514, 36.03021730695452, 23.069608722414287, 21.517586129052297, 18.653081825801305, 19.003852946417673, 18.793317317962646, 21.79382392338344, 24.920801639556885, 22.328830003738403, 25.246244839259557, 25.138990708759852, 17.145581551960536, 21.755704368863785, 34.80082736696516, 36.74553435189383, 20.12685033253261, 4.2606814077922275, 0.344825199672154, 1.751494626913752, 3.0265263063567023, 0.1868504136800766, 1.3740196249314716, 1.2233719314847673, 0.7074257369552339, 1.532443329691887, 11.054037656102862, 4.248768721308027, 0.47003401815891266, 1.205979939017977, 0.4829784578510693, 0.3050127817051751, 0.09329656338585274, 0.5067819005676678, 3.114944739001138, 0.9018750371677535, 0.6889630162290165, 0.19804827709283146, 1.6590431992496764, 0.5898766560213906, 0.723276206425258, 5.4910284621374945, 0.16164545688245976, 0.19918251623000416, 0.05745267282639231, 0.08092053926416806, 0.1702069267630577, 0.16111408253865583, 0.050175384751388004, 0.604098587163857, 0.6022779420018196, 7.405575054032462, 21.845235381807598, 42.860762051173616, 39.033089773995535, 22.269700833729335, 16.525098732539586, 20.239023787634714, 13.392134274755206, 12.427726047379629, 9.257952639034816, 8.768631832940237, 9.316558088575091, 13.252992255347115, 17.260355370385305, 33.45234530312674, 53.65615735735212, 67.4981918334961, 66.9886109488351, 70.72491441454206, 73.79437841687883, 70.3141508102417, 79.10672787257603, 65.59767191750663, 65.92653710501534, 49.60964461735317, 40.62237555640084, 11.887685997145516, 32.22967079707554, 48.05013186591012, 33.81148726599557, 22.014076607567922, 41.749005113329204, 8.36531843457903, 1.1940351171152932, 0.31721699397478786, 0.41632995275514467, 0.8473854724849973, 0.290997423763786, 0.2768848996077265, 0.09391331100570303, 0.2805818569447313, 0.09559016781193869, 0.16666099775050366, 3.1664146057197025, 47.02271563666207, 38.69675874710083, 32.17385244369507, 21.058357102530344, 18.911328996930802, 18.06022330692836, 0.591871440410614, 0.20550325991851942, 0.06693908771766083, 0.09650823247752019, 0.05351606370615108, 0.04218032197760684, 0.08395953476428986, 0.037855916523507664, 0.04463504793654595, 0.11748509508158479, 0.07179570889898709, 0.05770486393677337, 0.05081873433664441, 0.1971080582588911, 0.03703531323532973, 0.0637485414211239, 0.05811523513070174, 0.03753531551254647, 0.05862004482852561, 0.04339194803365639, 0.04130488966724702, 0.04001167656055518, 0.015066447701039059, 0.06710458240870919, 0.022134412811802964, 0.07329226538006749, 0.008231223494346653, 0.0414032976010016, 0.09773745973195348, 0.1394430718251637, 0.014980244915932417, 0.08652240224182606, 0.14825163701815264, 0.053554892872593234, 0.03823797245110784, 0.1091316979644554, 0.10924626860235419, 0.05840612987854651, 0.13237170555761882, 0.01078270176159484, 0.1860271335712501, 0.04375225691390889, 26.323734998703003, 67.013429914202, 44.2656843321664, 51.60077599116734, 73.3065801348005, 65.84359645843506, 36.41664831978934, 26.22000186783927, 36.68631485530308, 14.250606792313711, 10.594619291169302, 9.10961207321712, 30.4255918775286, 44.8964661189488, 52.507932799203054, 46.551898751940044, 32.441309452056885, 13.5846506186894, 6.325470634869166, 1.60708207317761, 6.198604779584067, 33.68351534434727, 13.400988016809736, 47.379707132067, 53.67362860270909, 54.22568729945591, 36.44683129446847, 29.510340418134415, 35.292155333927695, 18.373821565083094, 15.788560152053833, 17.841865743909562, 24.595174312591553, 30.220686026981898, 17.346751008714946, 10.598798632621765, 10.590813415391104, 10.785275254930768, 14.323846016611371, 19.185013328279766, 22.055873496191843, 27.500756365912302, 27.461177689688547, 29.455140454428538, 22.437538044793264, 18.844228506088257, 27.040281874792917, 43.804942335401265, 59.360579763139995, 30.260537420000347, 6.355249745505197, 1.3691825930561339, 0.991464621254376, 0.6587010057909148, 0.9255676886865071, 0.6128723163689885, 1.2766468099185397, 0.6759220617158073, 2.3140041743006026, 1.8285161682537623, 3.271243380648749, 2.192500591278076, 1.160643920302391, 0.7888601443597248, 0.26638538443616455, 0.2074384553624051, 1.043172463774681, 11.148588742528643, 1.8884526320866175, 6.158716908523014, 2.083888739347458, 3.585102630513055, 1.8335097517286028, 5.510398302759443, 6.987022953374045, 0.2090208533086947, 0.08141103187309844, 0.21495439777416842, 0.26928587736827986, 0.1576827173786504, 0.37874486669898033, 0.16178512653069838, 0.3576532027551106, 1.3914070576429367, 22.643281153270177, 32.4030978339059, 48.35217005865914, 36.967532770974294, 23.35249420574733, 11.466060621397835, 12.357639568192617, 13.28300326211112, 7.323445609637669, 6.1604001096316745, 7.358545303344727, 12.089795197759356, 16.849914857319423, 19.315231255122594, 28.556312799453735, 45.429663930620464, 60.40053054264614, 67.10418033599854, 68.80719770703996, 78.48792825426374, 76.78264577048165, 80.39409010750907, 62.78738267081124, 54.28402090072632, 31.700065204075404, 21.211358172552927, 10.230483310563223, 43.27345725468227, 48.89077009473528, 26.19883939198085, 18.18521445138114, 40.72974606922695, 21.124655076435634, 1.8299060251031602, 0.5122732573321888, 0.2240385974624327, 1.0645190668957574, 0.398512708821467, 0.48020726655210766, 0.07434919902256557, 0.686868677181857, 0.11006437827433858, 0.08592002599367074, 5.333348214626312, 36.86039849690029, 42.870555537087576, 40.89862551007952, 27.17266763959612, 28.836959225790842, 17.273748023169382, 0.1806997787207365, 0.1825524778770549, 0.04154236674574869, 0.04227598862988608, 0.019153111447979296, 0.060357739084533284, 0.019482837058603764, 0.03367287026984351, 0.12715550831386022, 0.12075779161282948, 0.011539234380636896, 0.0897258882011686, 0.005158525583932975, 0.1602244417050055, 0.056435484372611554, 0.0974515929285969, 0.11747250147163868, 0.09079423480268035, 0.03238257486373186, 0.1463608584765877, 0.20312602605138505, 0.28884559922984665, 0.17596513777971268, 0.13187109599156038, 0.14216326443212374, 0.11835965886712074, 0.1632261449205024, 0.18817017786204815, 0.19398892777306692, 0.37326808486665997, 0.22934062938605035, 0.21100609749555588, 0.24867239062275204, 0.1222204009869269, 0.1752867248973676, 0.20952959172427654, 0.23081961859549793, 0.14033245481550694, 0.27842237853578156, 0.24155062277402195, 0.25927838150944027, 0.15835525414773396, 45.77206073488508, 94.55300412859235, 60.15527997698103, 66.28061730521065, 89.6640292576381, 87.99494688851493, 63.97202273777553, 29.02562713623047, 42.272367749895366, 19.979159423283168, 13.992284059524536, 12.735207285199847, 39.29467555454799, 52.77779735837664, 61.691540581839426, 54.669652870723176, 42.110502515520366, 20.92613114629473, 6.587700426578522, 2.3112446538039615, 6.315031400748661, 26.791067361831665, 20.19225719996861, 80.863295010158, 64.10548373631069, 42.86305843080793, 29.461744717189244, 40.52414887292044, 45.10729530879429, 33.58343349184309, 36.27831663404192, 42.38152742385864, 50.28392560141427, 55.900852816445486, 47.8325594493321, 26.9384560244424, 25.832426139286586, 20.18411217417036, 21.10825559071132, 24.919273035866873, 29.03826243536813, 30.53263235092163, 31.69770281655448, 35.497478076389854, 32.4055574962071, 24.428511347089493, 31.692675794873917, 47.832080023629324, 66.4425242287772, 41.04480518613543, 8.575088024139404, 2.500375270843506, 3.7743235741342818, 4.553949236869812, 3.6215758962290625, 2.8773304607187, 3.486172441925321, 2.7067995199135373, 5.321288747446878, 23.7138317993709, 9.815176452909197, 1.3819428512028284, 1.6314535311290195, 0.7080689881529126, 0.36167569405266214, 0.19116897694766521, 1.2514830401965549, 8.675213302884783, 6.961932139737265, 3.744708614689963, 0.25450198352336884, 3.0688423556940894, 0.8726983570626804, 7.874652283532279, 22.56574967929295, 0.37972477983151165, 0.4547910546617848, 0.18913954656038964, 0.8045181812984603, 0.2508790136447975, 0.5309186939682279, 0.3327417123530592, 1.8252109970365251, 0.967971567596708, 23.695822068623134, 34.76126085008894, 46.65791784014021, 38.248759746551514, 29.904497827802384, 23.73027297428676, 24.75505931036813, 20.7138706275395, 16.68177192551749, 13.87772216115679, 9.50836397920336, 11.833175642149788, 13.26052497114454, 19.592679773058208, 39.1933708190918, 65.81388596126011, 79.06926318577358, 76.68170234135219, 73.3495408466884, 80.68285724094936, 82.10507011413574, 92.9071912765503, 79.33550425938198, 77.17289134434291, 60.795584269932334, 52.69087191990444, 15.074175902775355, 36.97040237699236, 59.10901328495571, 46.95438357761928, 32.73677464893886, 60.85777759552002, 22.114276579448156, 1.952930395092283, 1.3694762630122048, 0.2408054013337408, 1.0032482232366289, 0.49413227077041355, 0.5302407560603959, 0.15985763924462454, 0.9596165759222848, 0.2539016700216702, 0.2639223023184708, 8.47568883214678, 75.79748848506382, 63.679454939705984, 55.49881614957537, 44.68678685597011, 48.49988528660366, 44.034927708762034, 1.31484811433724, 0.519281981246812, 0.23997074897800172, 0.21264889862920555, 0.11238865248326745, 0.24322975267257008, 0.20737422523753984, 0.09649192049567189, 0.2660702456321035, 0.26372913696936195, 0.23772781076175825, 0.2600823369409357, 0.12603516557386943, 0.4444030092230865, 0.20924318209290504, 0.18478111257510527, 0.16568461300006934, 0.19148840409304413, 0.15055968745478562], [0.024933578413245932, 0.01039281384354191, 0.05479396567014711, 0.1258487720042467, 0.04382009345239826, 0.07860234472900629, 0.012347590111728226, 0.020807831049231545, 0.034883336031011174, 0.018711921193503907, 0.021535169699096253, 0.048091454431414604, 0.03200487173827631, 0.013008422999908882, 0.054145079239138534, 0.05458338911245976, 0.06812657828309707, 0.0544174499809742, 0.05670441494190267, 0.09017081718359675, 0.07699370783354555, 0.08803898907665696, 0.023284414317458868, 2.685592532157898, 32.23300245829991, 35.31438609531948, 31.596387658800396, 49.30563661030361, 50.13146127973284, 37.29204838616507, 18.362499475479126, 24.25798170907157, 3.7775518809046065, 0.7410278767347336, 0.7999556575502668, 5.190049869673593, 11.330720135143824, 11.727539573396955, 11.924554875918798, 5.357852339744568, 6.202148360865457, 0.8869556805917195, 0.4961190213050161, 19.534262793404714, 16.374371460505895, 42.31383459908621, 64.64208616529191, 44.03411476952689, 25.187579461506434, 23.2529491015843, 30.824064118521555, 31.23944480078561, 61.24450738089425, 76.37137494768415, 74.79635034288678, 62.86395181928362, 62.332859311785015, 70.98911271776471, 56.2922101020813, 45.855088233947754, 33.65653201511928, 27.14126525606428, 24.02433463505336, 19.34322554724557, 18.039484671183995, 20.253918988364084, 27.81312131881714, 32.22742305483137, 20.285260575158254, 20.41009885924203, 36.672967365809846, 39.52813850130354, 26.41499263899667, 7.936880350112915, 0.5011326351336071, 0.6348781841141837, 0.21710572019219398, 0.40065389392631395, 0.10799116880765983, 0.40864861064723557, 0.12088584474154881, 0.43722988984414507, 0.6714210946645055, 5.174562769276755, 2.053580914224897, 0.5227116229278701, 0.945714207632201, 0.38168485036918093, 0.1387618226664407, 0.956896464739527, 5.11019161769322, 1.2738090136221476, 3.7018139106886725, 4.1367190309933255, 0.23743913482342446, 2.343004001038415, 1.6865359182868684, 2.6005009838512967, 0.41272492334246635, 0.08735472043710095, 0.24293515990887368, 0.05526241946167179, 0.04790275384272848, 0.27221386453935076, 0.7935334593057632, 0.8419171859111104, 0.4412270853562014, 11.53126859664917, 20.32752820423671, 39.766826493399485, 41.49158130373274, 27.40790237699236, 15.806682791028704, 17.14800647326878, 10.155832733426776, 12.579816034861974, 7.923278382846287, 8.223459669521876, 10.538181679589407, 22.38665291241237, 41.35735600335257, 62.96513843536377, 64.05237865447998, 66.37517533983502, 65.66652856554303, 63.8333922794887, 57.02430009841919, 54.28393752234322, 60.490676471165244, 62.53724752153669, 58.718399456569124, 74.0690198625837, 62.8887151990618, 53.01858370644705, 21.011262212480815, 42.541808468954905, 35.94449738093785, 17.63596977506365, 34.006057671138215, 17.37187569481986, 1.3961108795234134, 1.352461318884577, 2.1468038090637753, 0.48973487530435833, 0.29403625641550335, 0.31610297518117086, 0.15465489056493553, 0.2709197354103838, 0.05201960561264839, 0.04581591600020017, 1.1062812145267213, 25.30825924873352, 24.80653156552996, 17.451019150870188, 8.457034655979701, 16.668922969273158, 2.153790657009397, 0.21635868027806282, 0.07510793009506804, 0.10023166625095264, 0.03521785040252975, 0.11600803291159016, 0.02167103106954268, 0.017199980627213205, 0.06048654538712331, 0.0462757625750133, 0.08104925735720567, 0.0716821424929159, 0.15456411615014076, 0.07926677300461701, 0.1069518295781953, 0.06474625252719436, 0.05818031342434032, 0.018682564375922084, 0.14893915584044798, 0.019418807101569006, 0.07401485767747674, 0.04577030148357153, 0.05965411862624543, 0.013001356057689657, 0.04727216410849776, 0.03691246107752834, 0.043303623130278926, 0.08871240115591458, 0.06905739940702915, 0.054763143216925006, 0.05008531601301261, 0.00662731726021905, 0.049104955047369, 0.07476254219987563, 0.09155158844909497, 0.03412098158150911, 0.029046703329575912, 0.03071918697761638, 0.08429869370801107, 0.18041711460266793, 0.07227926688002688, 0.033196983127189536, 0.21477525095854486, 2.10619723371097, 40.833802291325156, 52.75395808901106, 47.302460534232004, 63.82970973423549, 62.04400879996163, 41.019114221845356, 18.29060820170811, 25.784188270568848, 3.949159792491368, 0.8757133867059435, 0.8626392654010228, 2.981920825583594, 8.05742985861642, 10.088816489492144, 11.048479097230093, 6.473075994423457, 5.341784196240561, 0.6742328894989831, 0.6428069472312927, 35.13494886670794, 17.319383791514806, 30.605043002537318, 57.86504602432251, 58.487232889447895, 45.51604740960257, 19.877639293670654, 18.28109438078744, 17.017067670822144, 35.906723499298096, 52.825944900512695, 63.69762447902134, 62.90261159624372, 64.19011974334717, 57.82539612906319, 46.216464042663574, 36.065705231257844, 28.18323275021144, 24.743593045643397, 24.67688512802124, 21.35193760054452, 18.918643712997437, 23.925404446465627, 29.745752334594727, 26.41924841063363, 19.655455010277883, 26.533732141767228, 43.20225558962141, 51.91002293995449, 37.60585682732718, 22.131857258932932, 0.8908203989267349, 1.1516242900065012, 0.6785933183772224, 0.23944580714617456, 0.12624910766524927, 0.1785136338855539, 0.08517154758530003, 0.34581252240708893, 0.5943521644387926, 1.4448612864528383, 2.8781887803758894, 0.6498351586716515, 2.3835050506251196, 0.5874081999063492, 0.3280916575874601, 0.2112775250737156, 13.74011308806283, 9.557129911014012, 14.621566772460938, 5.350175883088793, 1.4884721977370126, 2.4122827521392276, 2.3144456020423343, 2.543859703200204, 0.13571852525430067, 0.15595807135105133, 0.04925888410902449, 0.07742040458002261, 0.10747272055596113, 0.07427094357886485, 0.8038670048117638, 0.5960746662957328, 0.5478324549538749, 24.833598273141043, 30.348532881055558, 44.70454297746931, 38.1868964603969, 29.05721538407462, 16.04779396738325, 15.792522362300328, 6.707711883953639, 6.039632167134966, 11.43290034362248, 13.671491810253688, 14.851991619382586, 21.632078545434133, 39.40569734573364, 64.82317011696952, 72.69491631644112, 67.90595381600517, 65.18190561022077, 65.92023508889335, 61.83742495945522, 57.28241177967617, 62.65474850790841, 63.58972590310233, 61.22853347233364, 72.08922100067139, 56.848204953329905, 37.045929295676096, 17.98839977809361, 56.329250948769705, 39.25763470785958, 18.83917542866298, 36.696497440338135, 22.124990701675415, 2.5609776760850633, 0.9676933139562607, 0.9589100309780666, 0.5170442813209125, 0.7046724046979631, 0.5159356636660439, 0.644424954695361, 0.563181894166129, 0.04096756276807614, 0.5763954679880823, 5.883261655058179, 31.903428554534912, 34.47362974711827, 28.38573452404567, 19.536798885890416, 22.207029819488525, 0.36348043435386246, 0.09219125019652502, 0.03129370936325618, 0.03683593589812517, 0.054514331210936816, 0.058309431853038926, 0.0131995739481811, 0.03668726548286421, 0.05870351820651974, 0.06102358549833298, 0.05302237858995795, 0.03260261359225426, 0.11377962213009596, 0.07580141324017729, 0.020387327631137202, 0.03788927330502442, 0.09343651801879917, 0.054130304139107466, 0.01122253155335784, 0.01847408788411745, 0.14766933183584893, 0.1715780831873417, 0.31146396696567535, 0.16523610135274275, 0.11633037775754929, 0.17475590695227894, 0.19289350083896092, 0.09834930154361896, 0.1328381441001381, 0.23104006105235644, 0.1569028635110174, 0.099256652141256, 0.21259213238954544, 0.18561092019081116, 0.2740177091743265, 0.12315527296492032, 0.1275107078254223, 0.1266353569392647, 0.22685618698596954, 0.3942737919943673, 0.21441900650305407, 0.15434777204479488, 0.23815289938024112, 3.294618857758386, 62.98715727669852, 72.63025638035366, 64.35284655434745, 80.2365813936506, 77.55461147853306, 67.57262093680245, 26.717305285590037, 34.57017844063895, 4.570081651210785, 0.8581303730607033, 0.9680714479514531, 5.543410931314741, 11.44256181376321, 14.083152600697108, 15.551591839109149, 12.178163255964007, 12.3178984778268, 2.8216074279376437, 0.5116728352648872, 31.027670655931743, 19.178753001349314, 64.64613696507045, 82.92874431610107, 60.070185388837544, 37.41981186185564, 30.25142138344901, 40.50768164225987, 40.28363697869437, 78.83722114562988, 88.3109440122332, 90.44069194793701, 71.67235687800816, 75.00134304591587, 80.5353330884661, 66.2939647947039, 49.353457587105886, 36.96485424041748, 30.62878152302333, 30.072619915008545, 22.714368173054286, 20.17700069291251, 24.85484412738255, 35.159667083195274, 39.59266642161778, 28.61064076423645, 32.39275196620396, 44.63139929090227, 64.64791570390973, 43.9313509123666, 17.56005723135812, 1.0171496144362857, 1.0276922030108315, 1.211938453572137, 0.3097116638507162, 0.26558943571788923, 0.42526449475969585, 0.16178037678556784, 0.5341546003307615, 0.7175513250487191, 15.712927273341588, 7.771031192370823, 0.4937363862991333, 3.300234087875911, 0.7949070313147136, 0.2187124639749527, 4.019608446529933, 27.832216705594742, 6.787741235324314, 9.604518362454005, 6.3346010020801, 3.9939361555235724, 6.5359993151256015, 8.040801082338605, 8.748508981295995, 0.47239190020731514, 0.14238779166979448, 0.2390343706522669, 0.15733257973832743, 0.12717998985733303, 0.19045365176030568, 1.0347087979316711, 0.8808382802775928, 0.22377411808286393, 25.432129996163503, 34.96898072106497, 44.307328360421316, 39.55505582264492, 37.49445983341762, 25.0443788255964, 21.546848467418126, 15.82749959400722, 16.402928556714738, 11.783761790820531, 9.34435522556305, 11.388765386172704, 26.706276757376536, 52.44528784070696, 72.65923731667655, 73.48708738599504, 68.6175605228969, 66.20946775163922, 66.47830050332206, 58.0567433493478, 50.93526710782732, 56.79800074441092, 60.436028889247346, 56.04155036381313, 76.51374353681291, 77.12153026035854, 67.8206924710955, 27.46211048534938, 56.9155399458749, 52.86445876530239, 28.98504444531032, 49.34304918561663, 39.12308284214565, 3.8148576276642934, 3.2417695564883093, 3.111296283347266, 0.33491071739367073, 0.5751691109367779, 0.795174808374473, 0.45178522595337456, 1.1743955995355333, 0.09573387474353824, 0.5874300758753503, 11.641752770968846, 69.12903131757463, 52.00473383494786, 45.74413939884731, 40.86838347571236, 44.59062031337193, 3.973087651388986, 0.35333430022001266, 0.20157786698213645, 0.2336708227438586, 0.22558658011257648, 0.2036607659288815, 0.1110510089035545, 0.17140574886330537, 0.09549256733485631, 0.2869542235774653, 0.2587100405778204, 0.14053722311343464, 0.23521785544497625, 0.17645261090781006, 0.1893557956708329, 0.15464795593704495, 0.26930180937051773, 0.154715415888599, 0.2802842786269528, 0.13634942711463996], [0.015414492060829486, 0.004506319844430047, 0.09559231198259763, 0.04096657210694892, 0.03817864813442741, 0.08458148674773318, 0.059746284037828445, 0.12437956726976804, 0.020737638297889913, 0.04535755202440279, 0.1540961576891797, 0.04763400987056749, 0.04631532795195069, 0.12277325774942126, 0.040973442274012735, 0.042143691264625104, 0.037856703624129295, 0.03690004049401198, 0.037232414087546725, 0.06446957308799028, 0.16386680411440985, 0.025955633659447943, 0.21268373461706297, 0.28809307675276485, 2.998573486294065, 27.329269613538468, 31.390762669699534, 38.941832133701865, 48.11083132880074, 49.884869711739675, 44.227587359292166, 36.573959009987966, 0.8450697138905525, 0.1865358855575323, 0.07570201464529548, 0.6191795979227338, 1.409888397370066, 1.0981911229235786, 1.0930790943758828, 0.4205646626651287, 0.04898992639833263, 0.09192419238388538, 6.027737719672067, 20.482721430914744, 21.971515417099, 51.66554362433297, 50.83923952920096, 32.41329778943743, 23.317814009530203, 52.28273820877075, 58.713778904506135, 82.05523068564278, 80.10706002371651, 84.23872988564628, 68.71178504398891, 67.91511848994664, 71.19534914834159, 69.71659878322056, 60.808473178318565, 57.65380689076015, 49.80687965665545, 35.85533114842006, 29.728937694004603, 23.959577424185618, 23.62114109311785, 20.656162364142283, 21.46020269393921, 20.3806471824646, 23.34896625791277, 19.28726475579398, 36.02081292016165, 37.319646630968364, 31.741907255990164, 14.396642293248858, 2.292030713387898, 0.3926878928073815, 0.09568784292787313, 0.03978786857000419, 0.06680695659347943, 0.3537557790321963, 0.08657032038484301, 0.1599034946411848, 0.16503161803952285, 0.1464549848543746, 1.2583677279097694, 0.6574030497244426, 1.567718356847763, 0.33696187447224346, 0.2748102923589093, 2.7856177134173254, 9.25830352306366, 4.97592202254704, 17.71658103806632, 19.931562525885447, 3.911171385220119, 1.3627191398824965, 0.10997472344232456, 0.5356216473238808, 0.43624552552189144, 0.22859700928841317, 0.2614916813160692, 0.2972836707319532, 0.19631863704749516, 0.5704567123736654, 0.3994832310293402, 0.5300682996000562, 0.4385053456893989, 14.220489825521197, 17.587969882147654, 37.94192034857613, 44.432069369724815, 24.80646903174264, 9.55732446057456, 13.091532622064863, 9.383538722991943, 8.25071484701974, 6.562630457537515, 12.418900966644287, 27.39639789717538, 54.38416528701782, 63.07339136941092, 65.28023651668003, 62.0894569669451, 68.96130875178746, 65.64918586186, 63.94716208321707, 61.85236358642578, 62.509190695626394, 61.68744114467076, 68.11304487500871, 62.388222558157786, 60.64438452039446, 61.159517015729634, 60.85357393537249, 53.16617039271763, 30.47748449870518, 49.30331243787493, 17.9113164629255, 24.420602560043335, 23.9213536466871, 1.77162019269807, 0.42649874995861736, 2.1842133445399146, 6.088323840073176, 0.6331681673015866, 0.23015346005558968, 0.1950378343462944, 0.09192158680941377, 0.20697661728731223, 0.7676020764878818, 2.394960893051965, 8.763876659529549, 15.537301131657191, 8.802922930036273, 16.765928506851196, 3.3935392754418507, 0.08365439756640367, 0.1312699003943375, 0.09037071360009057, 0.05055698606052569, 0.08059928007423878, 0.05438719749716776, 0.03075240465945431, 0.030132149013557603, 0.038254572810339074, 0.020944348902308514, 0.02141080440820328, 0.06798977205263716, 0.06857785835329976, 0.08513169043830462, 0.16175053481544766, 0.08973292460931198, 0.016550775284745863, 0.03083919607368963, 0.01378893165383488, 0.07806683132158858, 0.055617948062717915, 0.09175272658467293, 0.06483566308660166, 0.024606388827253665, 0.0233999399933964, 0.013781897790197815, 0.020895609731919, 0.17603985805596623, 0.03038162598386407, 0.03473501506128481, 0.040940909912543635, 0.04161124483549169, 0.021260914326246296, 0.047932962221758704, 0.07286442869475909, 0.04251748263569815, 0.05004606954753399, 0.07098801473953895, 0.05219700520059892, 0.09757512022874185, 0.09968213431004967, 0.05106034030073455, 0.14262291762445653, 0.25008721756083624, 3.4784614614077976, 43.05039228711809, 50.23483657836914, 55.11056123461042, 67.53957530430385, 56.249819142477854, 36.70653411320278, 35.61052526746477, 0.6211837732366153, 0.48292688918965204, 0.48781586970601765, 0.9701345201049532, 1.4495900784220015, 1.1401723559413637, 0.9380917080811092, 0.871655638728823, 0.19321640208363533, 0.18387435908828462, 14.323476025036403, 33.854124886649, 17.46141539301191, 42.440903254917686, 56.69435099193028, 54.95701994214739, 16.73296104158674, 19.179399183818273, 36.12548753193447, 69.1133005959647, 80.97607122148786, 92.13769217899868, 75.24764278956822, 76.05808067321777, 76.00739356449672, 84.23549897330147, 69.04618794577462, 58.27757447106497, 45.3025084223066, 34.88451147079468, 24.966496467590332, 21.729659046445573, 23.588335173470632, 22.046272822788783, 21.661731719970703, 27.521498475755962, 22.840203523635864, 23.610439130238124, 43.86534649985177, 47.888068607875276, 38.802513803754536, 29.001765285219463, 6.648800713675363, 0.18998832601521695, 0.18124861855592045, 0.03278799953737429, 0.17070532430495533, 0.9910289474896022, 0.09543565181749207, 0.10415607531155859, 0.2890273651906422, 0.22922180433358463, 0.48033960802214487, 0.8029585278459958, 2.1985948128359656, 1.0827209587608064, 0.3534504111324038, 5.980613299778529, 17.82712687764849, 13.049995422363281, 17.005759477615356, 7.925644244466509, 0.14458475235317433, 1.0252564251422882, 0.020780711700873714, 0.30158911113228115, 0.6033950277737209, 0.8391166276165417, 0.7357899663703782, 0.3709844888320991, 0.12174560289297785, 0.7735774729933057, 0.9507819414138794, 0.2943226524761745, 1.1460635598216737, 21.497441564287456, 32.53948402404785, 46.99483946391514, 42.48821701322283, 27.564224685941422, 11.390718698501587, 9.679560644286019, 5.058440131800515, 8.705832277025495, 11.431667906897408, 13.49864147390638, 23.239606823240006, 49.956033161708284, 70.65427902766636, 71.96696744646344, 65.05923516409737, 67.07813153948102, 69.43285519736153, 68.58560575757707, 66.09177916390556, 68.67219420841762, 67.84551838466099, 67.36958762577602, 60.877788407461985, 64.21008886609758, 63.51931980678013, 63.71045780181885, 50.43181453432356, 32.403493881225586, 56.49412822723389, 18.75476176398141, 28.10954363005502, 24.56222074372428, 1.7586575682674135, 0.5185773904834474, 1.2923113065106528, 3.8795314601489475, 1.0833340287208557, 1.0762626081705093, 0.9454041442700795, 0.3861316703259945, 0.08849360075380121, 1.5990052265780312, 9.478524071829659, 20.375281436102732, 24.168912751334055, 21.208914143698557, 24.999686275209697, 1.8491069376468658, 0.07101284912122147, 0.026583510949941616, 0.07523940304028136, 0.00992966110685042, 0.07473909881498132, 0.019560174783691764, 0.0554223637362676, 0.03502535680308938, 0.02647842962427863, 0.03449537006339856, 0.04809391072818211, 0.06283701783312218, 0.033352231939456294, 0.10379451114152159, 0.1518953429268939, 0.1119548175483942, 0.029181243253073523, 0.06676834795091834, 0.052483452151396444, 0.07645689163889204, 0.1723523594971214, 0.16800198650785855, 0.22050191009683268, 0.10059553744005305, 0.1345134334904807, 0.19600737946374075, 0.1283001426075186, 0.26424023668680874, 0.22121556608804635, 0.1649557306830372, 0.2630188465118408, 0.21676394210330077, 0.0905029329338244, 0.2549407514078276, 0.18417937414986746, 0.07048574276268482, 0.11412744596600533, 0.14028421097568103, 0.2121172393006938, 0.20958415951047624, 0.1819370873272419, 0.30385520096336094, 0.31046320923737114, 0.43552806973457336, 8.057911889893667, 70.69351550510952, 70.124847139631, 71.4884033203125, 83.22572422027588, 76.53376824515206, 61.639616693769185, 50.52518442698887, 0.880315971161638, 0.39236879135881153, 0.42505406747971264, 0.7787096947431564, 1.8355881316321236, 3.0118443284715926, 1.996910103729793, 1.1863089374133517, 0.17060386974896702, 0.15766512975096703, 12.222149695668902, 28.338787283216202, 35.22452851704189, 68.1819154194423, 68.4893662588937, 45.342995575496126, 27.23421130861555, 66.79081657954625, 71.2419993536813, 94.91050284249442, 92.13793536594936, 95.09195504869733, 76.4031629562378, 75.42137554713658, 80.6712259565081, 76.14864349365234, 59.627911703927175, 52.88170419420515, 46.286797182900564, 35.59793513161795, 30.856341975075857, 26.88005641528538, 29.272430624280656, 26.419105972562516, 28.324098791394913, 30.472196919577463, 34.11235121318272, 25.486440590449742, 50.30948107583182, 54.5026980808803, 39.703594412122456, 26.359440054212296, 3.673523885863168, 0.7585961254579681, 0.26970827898808886, 0.15529127498822554, 0.15731344505080155, 1.5575798494475228, 0.309482536145619, 0.1776151042431593, 0.37250576434390886, 0.5023432501724788, 3.1129692792892456, 4.140050692217691, 4.465431792395456, 1.4284411732639586, 0.3182301010404314, 10.49165654182434, 25.50191249166216, 11.432195969990321, 31.01765135356358, 34.036636693137034, 14.950961760112218, 7.81558130468641, 0.22704137276325906, 1.7757797752107893, 1.5088053409542357, 1.1544950902462006, 0.5205201176660401, 0.5606585038559777, 0.5830218238489968, 1.0302228672163827, 0.9639920954193387, 0.4854541335787092, 0.684102534183434, 25.926249401909963, 28.607237883976527, 51.07073266165597, 42.717247009277344, 33.32735415867397, 13.088252203805105, 17.782328367233276, 13.84343888078417, 10.144138046673365, 7.848779797554016, 12.359895127160208, 32.742802211216514, 64.57771110534668, 71.75158718654087, 73.04268060411725, 66.52311638423375, 69.59938962118966, 62.684736933027, 64.4618707384382, 61.33919743129185, 65.10955401829311, 67.39355196271623, 69.44403484889439, 60.53200435638428, 59.02727467673165, 65.06136131286621, 65.32471193586076, 68.1688597542899, 41.16141332898821, 66.23786503928048, 31.418260165623256, 38.98352827344622, 51.698443344661165, 8.10122435433524, 0.3400090666753905, 5.844356519835336, 8.611046688897268, 0.7746446185878345, 0.707669303885528, 0.7672197627169746, 0.7008670717477798, 0.4694037405507905, 1.1465998739004135, 23.437752076557704, 40.69234044211251, 37.81477526256016, 36.376849038260325, 38.20102562223162, 6.597334103924887, 0.28930678591132164, 0.1772916465997696, 0.19510872768504278, 0.12494781320648533, 0.20697464953575814, 0.2082528873745884, 0.08825753842081342, 0.11818360617118222, 0.11223579889961652, 0.09766727885497467, 0.1240017046885831, 0.11425616405904293, 0.1309749683631318, 0.27454330239977154, 0.35179855834160534, 0.32460146344133783, 0.11748964126620974, 0.10241428948938847, 0.20645519026688167, 0.19013578524546965], [0.06110210557069097, 0.07011847211314098, 0.035988784927342615, 0.04624932345801166, 0.03512471807854516, 0.102625673503748, 0.05275668802538088, 0.043794661959899325, 0.0836556325001376, 0.04547792752938611, 0.041355884966573546, 0.04805396876430937, 0.008467122978929962, 0.057495216972061565, 0.03306432274569358, 0.04692415367545826, 0.04154187820053526, 0.08995182000632797, 0.06404609259750162, 0.20063513756862708, 0.09672570295099701, 0.06597313205046312, 0.18870689906179905, 0.0287828923070005, 0.5582162120512554, 6.86867949792317, 38.19520650591169, 34.29204205104283, 43.116723264966694, 51.723543712071006, 43.397319316864014, 19.39760388646807, 0.32212918038879124, 0.545199739081519, 0.28346188526068417, 0.0742157379697476, 0.22793986169355257, 0.03619164314919284, 0.02941986366308161, 0.23875657841563225, 0.20147832589490072, 0.8303450154406684, 12.187763060842242, 33.43293898446219, 36.60314144407, 52.04138558251517, 41.9119542666844, 19.5924939087459, 60.36754049573626, 81.5160574231829, 76.89040538242885, 69.51391288212368, 58.43177931649344, 63.80068710872105, 77.87452043805803, 76.18168217795235, 72.926819392613, 56.451070240565706, 59.3618095942906, 61.6339886529105, 61.02501378740583, 56.28580733707973, 51.03997646059309, 34.89408956255232, 21.375835929598125, 22.75374014036996, 26.61886841910226, 17.81192943028041, 19.057480880192347, 19.939202070236206, 37.8599385534014, 36.79953922544207, 36.064385073525564, 15.824082817350115, 4.012081376143864, 0.25656030593173845, 0.4385475234261581, 0.017595057641821246, 0.15711961473737443, 0.5206871458462307, 1.0199681946209498, 0.9250484194074358, 0.648803459746497, 0.46782166830130983, 0.25068687966891695, 0.21277153704847607, 0.3209581917950085, 0.1994567529431411, 1.158526673913002, 4.717090768473489, 4.722145148686, 17.345922436032975, 17.809683425085886, 1.9082593406949724, 0.14117947007928575, 0.271108476711171, 0.444640333631209, 0.23543683226619447, 0.042650295687573295, 2.266186888728823, 0.22769659331866673, 0.04397377484877195, 0.2721566233251776, 0.38085635911141125, 0.22281650161104544, 0.6161425837448665, 1.9634983880179269, 10.349030000822884, 21.021828685488018, 38.32118776866368, 43.30924047742571, 25.093650238854543, 11.818956153733389, 16.121080092021398, 6.883355396134513, 6.949470979826791, 16.095036506652832, 33.15972191946847, 54.23224292482649, 63.64613137926374, 60.87603746141706, 65.53053842272077, 63.896683420453755, 61.90961674281529, 58.73123277936663, 59.65495409284319, 58.70958914075579, 56.14801761082241, 57.652719497680664, 58.55157320840018, 66.613922391619, 61.539791924612864, 70.59503173828125, 54.913350514003206, 63.77424226488386, 34.831343855176655, 37.681029387882774, 37.14368002755301, 13.713233981813703, 28.473743881498063, 5.2620041114943366, 1.3932229259184428, 0.8140093662909099, 8.216476729937963, 1.7855156127895628, 0.522708420242582, 0.8528229264276368, 0.1753577675138201, 0.1885927151888609, 3.329278209379741, 3.2869845245565688, 9.714426704815455, 9.388121059962682, 20.036659240722656, 10.292456030845642, 0.06804634830249207, 0.07686439941504172, 0.11244740683053221, 0.08170031849294901, 0.04349607262494309, 0.16374968897019113, 0.02479784087544041, 0.03471067601016589, 0.01820460770146123, 0.04571559799036809, 0.014510495122522116, 0.03532300636704479, 0.023182859677555304, 0.04388140248400824, 0.05126367349709783, 0.03664988838136196, 0.05856021839593138, 0.051951989598040066, 0.04331369258995567, 0.0386556820012629, 0.06799391111625092, 0.07709396138255085, 0.10297901382935898, 0.05086659819685987, 0.04144954315519758, 0.04538176554654326, 0.05332328172932778, 0.024965455988422036, 0.06831000665468828, 0.07486618842397418, 0.032760064250656536, 0.02417598558323724, 0.05344397953844496, 0.05191565744046654, 0.07654417159834079, 0.021790758573583195, 0.047811680872525485, 0.05765695936445679, 0.06458385195583105, 0.08285838777997664, 0.16550326773098537, 0.2497657819518021, 0.039687520026096275, 0.12574001641145774, 0.02076815371401608, 0.6705534926482609, 14.291825243404933, 60.00673443930489, 49.27415779658726, 64.62384714399064, 62.971127782549175, 45.53625971930367, 29.095598970140728, 0.3079524668199675, 0.809820145368576, 0.3095110888992037, 0.08870234526693821, 0.23937735653349332, 0.17700284852513246, 0.5285734055297715, 0.4266935709331717, 0.3682603064392294, 1.6281536796263285, 31.599434443882533, 33.76306527001517, 25.77181700297764, 47.768778460366384, 57.83616931097848, 17.669923884528025, 34.8927971976144, 77.03758907318115, 70.98941843850272, 75.54276057652065, 61.17820766993931, 65.4780239377703, 79.93971960885185, 83.14998190743583, 77.7222854069301, 61.50610705784389, 59.502302169799805, 63.48009722573416, 62.801126207624165, 56.180351052965435, 44.96696949005127, 27.4999121597835, 17.33371271405901, 25.617683376584733, 23.8448383467538, 24.634838104248047, 22.64555495125907, 22.264074529920304, 42.82678188596453, 48.72008064814976, 49.94842488425118, 18.782243626458303, 11.832526854106359, 0.3424735330045223, 0.30536494137985365, 0.011741738067939878, 0.5882454578365598, 1.7362256348133087, 2.3110392476831163, 0.7988609905753816, 0.6615984588861465, 0.878942453435489, 0.1930331297750984, 0.723249933549336, 0.5583032816648483, 0.6060075504439217, 1.689785395349775, 16.385778665542603, 11.112649185316902, 21.758895329066686, 12.797395399638585, 1.2688185785497939, 0.7688382044434547, 0.6674378769738334, 0.5099734578813825, 0.3100544054593359, 0.06500883200871092, 0.42422207498124664, 0.3235623006309782, 0.17369081053350652, 0.40079882900629726, 0.33253912893789156, 0.3897545316389629, 0.22005114571324416, 1.6036284927810942, 14.768062591552734, 29.52782208578927, 46.71917315891811, 44.90836490903582, 25.548760720661708, 10.083531515938894, 7.775650875908988, 10.524300915854317, 10.728174090385437, 14.809541600091116, 20.3299948147365, 52.565505572727744, 67.03774166107178, 67.14034570966447, 68.76069341387067, 68.60938249315534, 63.198132378714426, 61.867184094020296, 58.13389267240252, 61.08262130192348, 59.26454871041434, 59.18448461805071, 60.35042013440813, 72.43364320482526, 64.90329674312046, 72.88783999851772, 59.55369104657854, 70.33614185878209, 40.11431285313198, 39.12936748777117, 41.76059818267822, 17.273464884076798, 38.96456663949149, 14.32194915839604, 1.1862809274877821, 1.8415155964238303, 5.943819982664926, 2.008811499391283, 0.7642252519726753, 0.624709604041917, 0.24438820193920816, 0.49208852329424446, 7.322430304118565, 14.436877574239459, 22.52483000074114, 19.184507846832275, 31.68997641972133, 9.889663747378759, 0.07350081311804907, 0.06624021700450353, 0.05530718920220222, 0.15278286673128605, 0.0900999034887978, 0.14639283104666642, 0.06142676422106368, 0.07379879177148853, 0.0649221966575299, 0.0709901385541473, 0.08351611212960311, 0.05385124304198793, 0.056229369182671816, 0.08533038584781544, 0.06601959812854018, 0.04955555658255305, 0.05589616438373923, 0.008146119935970222, 0.06550604211432592, 0.12317477406135627, 0.07339683441179139, 0.1454916958298002, 0.13570302751447472, 0.15261305655751908, 0.214979598564761, 0.1545595156827143, 0.12783901020884514, 0.2676159755459854, 0.161422639553036, 0.2234983207391841, 0.18872633230473312, 0.10741491615772247, 0.15186464600265026, 0.17263529502919742, 0.12097889903400626, 0.1731216146477631, 0.13159031820084366, 0.2756420948675701, 0.23414913564920425, 0.1989808284810611, 0.20610490334885462, 0.3294321713703019, 0.2059037855693272, 0.3256825054330485, 0.14989612091864857, 0.6586514455931527, 31.60632358278547, 88.12842873164585, 65.81569249289376, 81.51726640973772, 86.40148176465715, 68.45136656079973, 33.28868743351528, 0.45470148803932325, 0.8466943438564027, 0.4332377426326275, 0.16406522132456303, 0.6939712017774582, 0.20578003435262612, 0.3832455894776753, 0.41801415809563225, 0.4125393033027649, 2.234357190983636, 26.0158394745418, 55.99685607637678, 56.71189866747175, 69.30631460462297, 48.35119383675711, 21.48108376775469, 76.63473946707589, 103.77976717267717, 82.69337408883231, 68.04379912785122, 57.48782484872, 68.57767786298479, 85.77836731501988, 86.72732448577881, 77.40692751748222, 57.15808766228812, 53.291696548461914, 58.093749455043245, 60.12963417598179, 58.88710866655622, 50.36561904634748, 37.0991907119751, 21.014423642839702, 28.52352598735264, 39.6247045653207, 31.77229172842843, 27.21318084853036, 21.9268593447549, 47.62217494419643, 58.6616187776838, 51.9487487248012, 17.659715243748256, 12.21650515283857, 0.2775216911520277, 0.4277926890977791, 0.2416426864053522, 0.46586672748838154, 1.2917760780879428, 2.0926951467990875, 2.7138973219054083, 0.8443498153771672, 0.5567968253578458, 0.7428690407957349, 2.1825716154915944, 0.4656196321759905, 0.46245912462472916, 2.6454745020185197, 12.589209130832128, 18.61267457689558, 23.14732779775347, 33.03405679975237, 6.874051758221217, 1.2839773765632083, 2.3154869633061543, 2.1341383286884854, 0.33452563519988743, 0.22385502659848758, 4.751230307987758, 0.51801605203322, 0.21813566849700042, 0.7971861490181514, 0.4631702836070742, 0.26946188935211723, 0.5412506109901837, 1.6457345762423106, 27.73539182118007, 27.616143362862722, 51.41250760214669, 48.00517007282802, 29.756021772112163, 14.996194532939366, 20.46269151142665, 11.468053885868617, 8.79204899924142, 18.812002761023386, 35.30142423084804, 63.23061520712716, 69.54626369476318, 66.86965084075928, 68.9585155759539, 67.76574611663818, 60.58934089115688, 58.14656618663243, 54.90042686462402, 59.610812187194824, 61.217339924403596, 61.29869638170515, 57.481877190726145, 70.21165098462785, 63.091421944754465, 73.83251013074602, 61.794853346688406, 71.03918838500977, 49.73447247913906, 50.708627292088096, 50.889256136757986, 28.222059283937725, 52.307831627982004, 20.42960592678615, 1.7268491493804115, 4.558849453926086, 17.107005153383525, 2.7399730426924567, 1.1312840900250842, 1.5621701117072786, 0.6610471627541951, 0.2828167070235525, 9.55612850189209, 33.62705775669643, 44.016028608594624, 31.592520986284526, 43.86035074506487, 19.60938845361982, 0.17100116557308606, 0.25707360410264557, 0.16553568813417638, 0.20670166132705553, 0.15704420235540184, 0.24583470289196285, 0.32980905686106, 0.15448961300509317, 0.11555979267827102, 0.2897471822798252, 0.3318820899086339, 0.14508461553071225, 0.11531820707023144, 0.10187688296926872, 0.1466655478413616, 0.09798712669206516, 0.21900920090930803, 0.11970731083835874, 0.16693471877702645, 0.2246087568679026, 0.17651678674987384], [0.009674588767146426, 0.09249610240970339, 0.07353919784405402, 0.045773772190191915, 0.04047921772247978, 0.06524674674229962, 0.02200338091435177, 0.023775665189272592, 0.05646900400253279, 0.07604788430035114, 0.010923435013475162, 0.03100773399429662, 0.060200671798416545, 0.023159494324188148, 0.008333916376743997, 0.05050394497811794, 0.1370525522423642, 0.09057400269167763, 0.03409894276410341, 0.10844765324145555, 0.03479603571551187, 0.02691204912428345, 0.026334354587431465, 0.01975213742948004, 0.12716898401933058, 3.5585222968033383, 24.423065696443828, 36.08673742839268, 39.89222410746983, 46.2564127104623, 38.68884127480643, 12.050233892032079, 0.7299959829875401, 0.16374283576650278, 0.0918863844126463, 0.26659388467669487, 0.09044048735605818, 0.17407288003180707, 0.1239068726343768, 2.4574021824768613, 0.9322034354720796, 0.5499537182705743, 17.01756272997175, 51.60498659951346, 30.302744252341135, 56.03294849395752, 30.410229410443986, 55.26797267368862, 85.944443157741, 69.0528095790318, 70.53882775987897, 64.1688791002546, 73.02164145878383, 73.15805544172014, 61.63419015066964, 65.63940279824394, 66.60582079206193, 72.03655365535191, 66.04433686392647, 60.21698692866734, 60.082233565194265, 62.63787828172956, 61.406706128801616, 54.327641691480366, 42.510225432259695, 24.272831746510096, 23.94255781173706, 22.37610902105059, 20.106469529015676, 22.868849209376744, 39.03984342302595, 30.593977996281215, 37.67201410021101, 14.583930117743355, 1.3508039563894272, 1.0667699575424194, 1.755127991948809, 0.41394902765750885, 6.013038805552891, 2.072632006236485, 1.0319618710449763, 0.1297501176595688, 0.575412677867072, 0.9452363018478666, 0.2634746049131666, 0.26653531353388515, 0.3133340094770704, 0.7652049479740006, 1.8723553930010115, 5.920954763889313, 9.75410873549325, 15.965218101228986, 9.538725001471382, 0.7725901773997715, 0.2229068824755294, 0.8294870757630893, 0.3968016334942409, 0.4233977092163903, 0.1637450342199632, 0.684838283274855, 0.5451055584209306, 0.16650900590632642, 0.10515238185014043, 0.204236041488392, 0.08094234737966742, 0.4060921349695751, 1.1072670987674167, 11.683954392160688, 21.26611692564828, 40.34218944822039, 39.05745015825544, 27.40881780215672, 17.85766247340611, 13.769197378839765, 7.690073387963431, 14.781422240393502, 31.64117227281843, 57.111163003104075, 64.17254774911063, 60.494518824986045, 63.479645592825754, 61.303268296378, 61.79682663508824, 61.140284402029856, 62.147293772016255, 60.03054591587612, 62.24891117640904, 64.45030893598283, 66.56222779410226, 57.25887475694929, 62.55366611480713, 59.46522658211844, 62.46957901545933, 72.2187910079956, 58.17056179046631, 57.096773283822195, 25.202481610434397, 42.673521995544434, 26.817189114434377, 16.146038021360123, 23.787197828292847, 4.76390642779214, 0.8585950881242752, 1.9499476637159074, 3.9267184138298035, 1.4398082090275628, 2.7661271478448595, 0.37151238907660755, 1.3723901637962885, 6.577907374926975, 6.0557185496602735, 4.61470775944846, 11.1628976890019, 17.372464554650442, 0.583898762507098, 0.030306661435003792, 0.08726535737514496, 0.03514234641832965, 0.04887570181329336, 0.10734199399926833, 0.07360308870140995, 0.05280178685539535, 0.05345195571758917, 0.05566159143511738, 0.02982599740581853, 0.045189869057919295, 0.024905504026849355, 0.03043532185256481, 0.06281337767307248, 0.025367662709738528, 0.06007489176200969, 0.03190205332690051, 0.006194421248177865, 0.018529558121891956, 0.07199835338230644, 0.025236664739038264, 0.004345227573399565, 0.020849995215290358, 0.02441609707394881, 0.02548771591058799, 0.058203376829624176, 0.05087774991989136, 0.03596437802272184, 0.0398060872352549, 0.07748201555971589, 0.06054527937833752, 0.07867388267602239, 0.052801145639802725, 0.06487889255263976, 0.031131285043167214, 0.022024368002478565, 0.08712447993457317, 0.04426971111180527, 0.04490283517433064, 0.034429623412766626, 0.2069131335509675, 0.08984842484018632, 0.028461650080446686, 0.03430925130045839, 0.02361721878073045, 0.32360588972057613, 4.230684297425406, 41.542893750326975, 53.42285074506487, 60.887786865234375, 63.189697265625, 47.57246058327811, 20.084664344787598, 1.1195540108851023, 0.29085821551936014, 0.21065439922469004, 1.103551983833313, 0.7640227228403091, 0.8331245120082582, 1.0508162421839577, 2.0087294237954274, 1.633775640811239, 2.819817615406854, 32.253951277051655, 47.16448320661272, 28.201383181980678, 61.21018327985491, 36.98726565497262, 36.07822935921805, 87.3389813559396, 72.45484910692487, 75.13034330095563, 64.84504999433244, 75.46867193494523, 75.02291025434221, 63.756100518362864, 68.15979930332729, 73.01664570399693, 73.09886373792375, 67.33290808541435, 61.94710922241211, 60.738657678876606, 68.74930531638009, 62.38549191611153, 49.57807200295584, 23.326674699783325, 17.22751123564584, 25.586409534726823, 26.693050861358643, 25.60074019432068, 25.81835777418954, 42.78919560568673, 36.57649162837437, 48.11080353600638, 16.29568658556257, 5.150562388556344, 3.999550299985068, 0.6978777178696224, 0.33699349420411245, 6.193554741995675, 0.19678427491869244, 1.0238199936492103, 0.41861243599227493, 1.024349793791771, 2.5668291449546814, 0.3812258078583649, 0.15216037870517798, 1.017723166516849, 2.3290876277855466, 7.5682662555149625, 34.62527765546526, 7.372215015547616, 23.84260971205575, 9.855458634240286, 1.0626936448471886, 0.28636001689093454, 0.3012463966650622, 0.5641892743962151, 0.369318386805909, 0.5491963646241597, 0.6534823115382875, 0.610023772077901, 0.056792278441467454, 0.6690223376665796, 0.20554574978138718, 0.2803039290010929, 0.23132268445832388, 2.9350044173853735, 8.84766411781311, 27.358596222741262, 43.156202929360525, 39.94800424575806, 31.658070291791642, 12.262610793113708, 10.852128216198512, 12.583662731306893, 15.043192148208618, 17.51029075895037, 46.321083068847656, 68.10945960453579, 59.068345478602815, 69.55301039559501, 63.925719942365376, 66.67007773263114, 62.861818722316194, 64.42407253810337, 58.14829281398228, 68.95055988856724, 66.50234127044678, 68.43376677376884, 59.1508275440761, 63.552156993321006, 60.247211592538015, 65.74546704973493, 74.3202736718314, 61.26096766335623, 64.36722932543073, 32.192345074244905, 43.826346261160715, 34.39426394871303, 21.575061627796718, 34.76624618257795, 11.158984984670367, 0.5742992833256721, 0.6551803318517548, 5.056679631982531, 1.4556877740791865, 1.5583364431347166, 0.4811079810772623, 4.354282328060695, 12.06092369556427, 15.082942792347499, 14.929290328707014, 25.13700178691319, 19.503087963376725, 0.14410410528736456, 0.012849660224414297, 0.07168295673493828, 0.026451859889285903, 0.04737930478794234, 0.045039295351931026, 0.03975499354835067, 0.028297973863248314, 0.04020382410713604, 0.04838857813073056, 0.07930469632680927, 0.01710490769307528, 0.044173338783106635, 0.05243749836725848, 0.008607704408599861, 0.03220730587573988, 0.03893244286466922, 0.0375364045612514, 0.01660767723140972, 0.05060268539403166, 0.12609278676765306, 0.03468890182141747, 0.11174171005508729, 0.2357391874705042, 0.12216473397399698, 0.16581600452108042, 0.17344496372554982, 0.12069333078605787, 0.12217888821448598, 0.207130956862654, 0.23375990082110676, 0.2697815607701029, 0.14763820064919336, 0.17752599902451038, 0.18947189301252365, 0.09726545041693108, 0.10663415983851467, 0.1606022228619882, 0.21513506450823375, 0.14867563998060568, 0.0522400921742831, 0.25574318692088127, 0.22425707216773713, 0.08324180077761412, 0.14569151082209178, 0.15978354322058813, 0.5247317031025887, 6.770617399896894, 69.36740316663469, 70.6320447921753, 75.37743513924735, 75.78886577061245, 82.1753511428833, 34.62393317903791, 2.0564233788422177, 0.6267996547477586, 0.35905109345912933, 0.9426639484507697, 0.3484405428171158, 0.619051164814404, 0.5459138293351445, 5.354056452001844, 4.648180271897997, 1.8365769471440996, 40.5236451285226, 70.52461869376046, 43.738517556871685, 66.46375792367118, 42.49677719388689, 73.43608066013881, 97.56316525595528, 70.1917096546718, 72.18930980137416, 64.78856808798653, 78.78818770817348, 74.25446728297642, 56.25871283667428, 63.64850071498326, 72.07743685586112, 78.2064289365496, 66.62528964451381, 57.49748631886074, 57.342736039842876, 66.71956975119454, 64.16681548527309, 54.79039519173758, 44.45067317145211, 26.858025414603098, 31.69125141416277, 36.531800815037315, 35.980322292872835, 27.004481281552994, 51.059163911002024, 42.5252856527056, 53.293857438223704, 16.98604222706386, 8.315216711589269, 6.553604747567858, 4.406532781464713, 1.0014258410249437, 13.079943026815142, 7.381720151220049, 3.9780139241899763, 1.221764400601387, 1.8657556899956294, 2.761416486331395, 0.8238434557403836, 0.7601994765656335, 0.7773669553654534, 5.65927301134382, 5.133445067065103, 33.23177126475743, 15.680885655539376, 28.49918818473816, 14.535905906132289, 2.0311586431094577, 0.5777720798339162, 2.7022406331130435, 0.6504606051104409, 0.8225373029708862, 0.40778353278126034, 2.2342245238167897, 1.61849079813276, 0.21635747248572962, 1.0926022742475783, 0.2179124711879662, 0.28922696305172785, 0.640203272657735, 2.1694119444915225, 30.62402548108782, 25.281347138541086, 47.033422810690745, 45.705271175929475, 35.1497346333095, 23.522389820643834, 19.17481858389718, 10.413285204342433, 16.806387867246354, 39.60104594911848, 62.26441955566406, 69.66000570569719, 59.5627167565482, 66.84101731436593, 62.92185115814209, 64.85949529920305, 60.73355770111084, 61.05890015193394, 57.93401384353638, 68.9116291318621, 68.73749337877545, 67.28427764347622, 58.72314507620675, 67.09642614637102, 59.94613919939314, 66.76970100402832, 74.57854516165597, 62.45793383462088, 62.20712471008301, 40.242114543914795, 55.708689962114605, 42.723371846335276, 34.55838734763009, 41.13581616537911, 12.646367618015834, 0.9739385502679008, 7.120065757206508, 8.641034245491028, 3.329851435763495, 6.484593502112797, 0.8913454221827644, 4.595695751053946, 20.65089041846139, 31.57805483681815, 29.65356363568987, 37.958509172712056, 33.563825675419395, 1.166729890874454, 0.10151700835142817, 0.15144124015101365, 0.08816417878759758, 0.1643411543752466, 0.1334335585790021, 0.1332348563841411, 0.15013048691408976, 0.13973649750862802, 0.12804928821112427, 0.2344540964279856, 0.07742722385696002, 0.07801598869264126, 0.13803484024746077, 0.18592548902545655, 0.18277510521667345, 0.17203872704080173, 0.07421225708510194, 0.12615994816379889, 0.10748878147985254, 0.19632988715810434, 0.12398422562650271], [0.008611840927707297, 0.05202391091734171, 0.0424357734487525, 0.03054847095959953, 0.020293796667829156, 0.08043998719326087, 0.050576215742954185, 0.10261115963969912, 0.030193627678922245, 0.029185066797903607, 0.023048073785113435, 0.04881750386474388, 0.061156612288739, 0.022842820334647383, 0.056362769167338095, 0.04622417016487036, 0.13772952663046972, 0.066764697432518, 0.053606736340693066, 0.05635563437161701, 0.05606852584917631, 0.08122569003275462, 0.048184881918132305, 0.03245100172768746, 0.17850853130221367, 0.5017686124358858, 13.304000718252999, 38.195911748068674, 39.1183545930045, 49.974042892456055, 34.82628556660244, 21.085696526936122, 0.8553650985871042, 0.13742467441729136, 0.3532448964459555, 0.6927038612110274, 0.028907885242785727, 1.5487999320030212, 0.7203896641731262, 1.2606685587338038, 0.5592419941510473, 5.01223851953234, 45.553783076150076, 32.03698335375105, 34.20111097608294, 53.41021197182791, 38.97576713562012, 79.57327161516461, 66.75441496712821, 77.15912001473563, 70.17067050933838, 74.75145803179059, 67.64042840685163, 70.94314343588692, 66.29321438925606, 68.51296928950718, 68.49290289197648, 67.51870291573661, 70.22312246050153, 65.23275252750942, 61.122281619480674, 61.8776341847011, 61.04751205444336, 62.1118996483939, 60.84194265093122, 46.97772952488491, 23.93866334642683, 22.255620309284755, 25.46160078048706, 23.258217573165894, 37.24680519104004, 33.93722881589617, 37.36540051868984, 14.827848366328649, 1.7267502461160933, 0.24465486620153698, 0.8466454893350601, 2.6856952352183203, 1.277981515441622, 1.1168190262147357, 0.3102267804954733, 0.22157453825431211, 0.9725574872323445, 0.7927205200706209, 0.1692421313907419, 0.3687587854053293, 0.8757797202893666, 0.36107812183243887, 7.494881119046893, 33.70958498546055, 7.387768558093479, 16.585730450493948, 3.1894209597791945, 0.9191605810608182, 0.3753721405352865, 0.06669381766447, 0.44968317874840324, 0.1478265348289694, 0.0058915770745703155, 0.5113212998424257, 0.07266932273549692, 0.011661955920447196, 0.09485815744847059, 0.12758973001369409, 0.025842241976144056, 0.25947257823177744, 3.099853251661573, 5.63577116387231, 20.75479551724025, 44.18911518369402, 34.33347068514143, 25.50035956927708, 15.959991318838936, 14.901391574314662, 17.052651132856095, 27.966087647846766, 49.03741182599749, 62.94507203783308, 64.81073978969029, 64.5690050125122, 59.405479022434776, 59.73269053867885, 59.504678453717915, 59.27585342952183, 58.53614820752825, 57.83794457571847, 56.29607330049787, 60.91833809443882, 61.05252170562744, 63.10485976082938, 60.63093975612095, 65.34339564187187, 64.52969905308315, 69.78492041996547, 59.63231686183384, 64.08701542445591, 43.218990325927734, 25.426312616893224, 40.6652945790972, 23.663969789232524, 23.42236876487732, 20.013495683670044, 1.4460573537009103, 1.0782639064959116, 2.534802726336888, 1.2611520013638904, 0.8616982730371612, 1.3245408513716288, 4.333555851663862, 4.692954897880554, 2.905845867735999, 3.335309245756694, 15.854746954781668, 3.051386309521539, 0.11803595695112433, 0.09531249771160738, 0.05108603981456586, 0.07708039746752807, 0.0391393417625555, 0.16590269415506295, 0.08875055518001318, 0.0030307131320504205, 0.059043308187808306, 0.06310809257307223, 0.049502909050456116, 0.031400565057992935, 0.024525176667209183, 0.025026849836909344, 0.0740291883370706, 0.049409681731568914, 0.07370452968669788, 0.01288941643932568, 0.014443423632266266, 0.05747821966984442, 0.009295418309713048, 0.020407641273257986, 0.06004448660782405, 0.06362199464014598, 0.03641968180558511, 0.08206694453422513, 0.03216214597757373, 0.07902214077434369, 0.03297313442453742, 0.13622252749545233, 0.060826871411076615, 0.009021630277857184, 0.0805859672171729, 0.0347933588948633, 0.05036288433309112, 0.03351587762257882, 0.05861268272357328, 0.02181010360696486, 0.1571986097842455, 0.025152192218229175, 0.05410050966643861, 0.04148750040414078, 0.09748691746166774, 0.148912231570908, 0.11443155179066317, 0.03455703193321824, 0.08596348616161517, 0.6550059212105614, 22.538660390036448, 61.729491642543245, 51.826248509543284, 66.73208345685686, 53.158284187316895, 33.92519801003592, 3.5059950011117116, 0.22694525149251732, 0.1463425923138857, 1.4986411035060883, 1.1542398525135857, 2.2116817448820387, 3.948671681540353, 0.6953997622643198, 2.328095121043069, 13.455329009464808, 56.51841565540859, 34.24878256661551, 37.320796557835166, 59.88917786734444, 35.78552607127598, 83.43835299355644, 68.9397554397583, 76.93911920275006, 76.99737289973667, 74.91410841260637, 67.34087766919816, 70.90228802817208, 67.71437808445522, 67.29315049307687, 69.37043258122036, 71.63780348641532, 69.0159215927124, 63.51870141710554, 61.85404505048479, 63.832266671316965, 65.83455685206822, 63.687104906354634, 58.78142656598772, 23.315211909157888, 19.74779830660139, 25.92726731300354, 23.86231827735901, 27.360418387821742, 39.65100349698748, 42.86986419132778, 43.88463122504098, 17.73753333091736, 6.843124457768031, 1.3165744159902846, 0.1204098252845662, 1.4732542314699717, 0.19699714492474282, 0.157466536121709, 0.09830818232148886, 0.10875277008329119, 0.48389887703316553, 2.041098258325032, 0.3977469413408211, 0.4726253162537302, 1.6326315764869963, 1.3471996869359697, 13.894638419151306, 39.97886119570051, 7.162204844611032, 25.587677580969675, 8.461984378950936, 0.6436971851757595, 0.3630841699029718, 0.012384873066496636, 0.30928926223090714, 0.4089501787509237, 0.23257341448749813, 0.41047677397727966, 0.009352201512748641, 0.12286728913230555, 0.14347517117857933, 0.15565141423472337, 0.11730110352592808, 0.09327352712196962, 3.096928494317191, 6.168693218912397, 22.183895792279923, 51.680642059871126, 36.34042658124651, 28.84454492160252, 16.499472039086477, 20.983971425465175, 15.7770174571446, 12.778593574251447, 39.10800525120327, 64.91217654091972, 61.772480147225515, 71.1869626726423, 61.230117661612375, 64.30693285805839, 64.33544826507568, 61.73403576442173, 56.578851086752756, 59.03160340445382, 56.86495358603341, 61.16087886265346, 60.626965386526926, 64.27415820530483, 63.355495180402485, 69.45012147086007, 65.09310068402971, 71.80608885628837, 64.72232396262032, 67.35506589072091, 51.48878492627825, 33.646561350141255, 46.08418771198818, 32.14701155253819, 33.214602266039165, 31.21135323388236, 2.5291955300739835, 0.461014062166214, 2.077664239065988, 1.334072259919984, 0.7954769464475768, 2.3679914602211545, 11.839754717690603, 11.335233858653478, 10.190863813672747, 17.481485264641897, 22.91327772821699, 2.2963403335639407, 0.08340811649603502, 0.02597585739567876, 0.04718254998858486, 0.07609948010316916, 0.013535844877229204, 0.06772162858396769, 0.09302844705858401, 0.058244808177862845, 0.07658601006759064, 0.0138320330463882, 0.005604627583774605, 0.027243973188368336, 0.05040662609306829, 0.028219419864139388, 0.03676044887730053, 0.05698909770165171, 0.05530290086088436, 0.08618223228092704, 0.024616198747285774, 0.05741920069392238, 0.023765085131994317, 0.010964081805598522, 0.126869655081204, 0.17694696438099655, 0.1438190798674311, 0.20257751191301004, 0.09067322486745459, 0.29954264951603754, 0.09777507771338735, 0.18963870406150818, 0.24288948093141827, 0.12895457606230462, 0.2278439982661179, 0.1146842110902071, 0.1273145569222314, 0.17482407258025237, 0.1276728641241789, 0.17346888887030737, 0.19923446487103189, 0.21164519605892046, 0.13409601231770857, 0.2066379061767033, 0.26398212196571486, 0.287555704159396, 0.1497726139745542, 0.19085162611944334, 0.2509764241320746, 1.0196857069219862, 41.05034637451172, 82.9334968839373, 73.56277411324638, 82.03371906280518, 78.62310545785087, 60.98554107121059, 4.6233135376657755, 0.3160556677196707, 0.49444146560771124, 2.1576701402664185, 0.4092021052326475, 3.093827643564769, 4.517883309296199, 4.100395151547023, 2.8993881685393195, 14.758913551058088, 83.99527890341622, 52.3797732761928, 47.704740388052805, 72.51536791665214, 54.488106863839285, 90.39710589817592, 66.4478257043021, 77.25154495239258, 71.15800258091518, 77.69058077675956, 65.9512379510062, 69.49343654087612, 66.61712551116943, 64.73329516819545, 71.14778178078788, 69.97749669211251, 72.05158260890416, 64.87071663992745, 60.00913156781878, 59.05830533163888, 66.07948085239956, 65.84696633475167, 63.398198808942524, 55.746849468776155, 29.83762836456299, 30.295125552586146, 40.810862813677105, 30.713823999677384, 47.8054267338344, 47.523434094020296, 49.53532668522426, 20.70808972631182, 8.39574807030814, 0.7203180651579584, 0.8771747882877077, 4.9752198202269415, 1.464495592883655, 2.218177224908556, 0.6596674025058746, 0.5015871450304985, 1.5566675726856505, 3.36761337518692, 0.502528571656772, 0.7729265679206166, 4.611530261380332, 1.1718776375055313, 13.818367174693517, 49.68034601211548, 11.591842123440333, 33.651199272700715, 5.667261702673776, 1.7037540972232819, 0.34835803295884815, 0.1428645168031965, 0.6869966760277748, 0.4168154038488865, 0.40353427508047646, 1.362835630774498, 0.07977921622140066, 0.12179728011999812, 0.20938571515892232, 0.21482821740210056, 0.1444501310054745, 0.2699660951537745, 3.1740165863718306, 18.571857384272985, 24.668905121939524, 60.40952845982143, 39.07475812094552, 40.14983204432896, 21.912573848451885, 22.352139472961426, 20.34868894304548, 35.56401055199759, 59.9424010685512, 67.51283863612584, 60.81287138802664, 67.15437412261963, 58.14885561806815, 66.34915433611188, 60.566870416913716, 61.04065418243408, 54.13674340929304, 59.94705636160714, 59.768904549734934, 64.41831942967006, 57.69899102619716, 65.75867557525635, 61.114145278930664, 69.45766721452985, 64.4424157823835, 72.1144221169608, 63.9711194719587, 68.48117433275495, 48.88252258300781, 40.794923646109446, 54.091941424778526, 40.57266466958182, 41.5712354523795, 40.65598051888602, 2.021622891936983, 4.23112290246146, 6.436781210558755, 4.227571938719068, 2.8579719109194617, 1.6545610683304923, 18.946559837886266, 26.29307780947004, 27.952549082892283, 31.540704795292445, 40.863505840301514, 4.87087481362479, 0.23365000528948648, 0.1687449144997767, 0.10683286881872586, 0.3214582721037524, 0.09905092710895197, 0.18336825338857515, 0.19890380118574413, 0.10170794132032565, 0.19649003499320575, 0.1694131222154413, 0.16736105589994363, 0.10066541976162366, 0.1476409826427698, 0.12251161464623042, 0.16624843488846505, 0.23300059299383843, 0.2199815415910312, 0.18735858212624276, 0.23533613766942704, 0.1385704350790807, 0.2492675743997097, 0.12863770020859583], [0.05677882648472275, 0.03977986524945923, 0.04086666461080313, 0.03885720350912639, 0.03947243460321, 0.04169389718611326, 0.03772841300815344, 0.01987883009548698, 0.01347984538214015, 0.02689936730478491, 0.04742773522489837, 0.04580168712085911, 0.07607980258762836, 0.034465148113667965, 0.05638313539592283, 0.009453282874476696, 0.07387115753122739, 0.0661779274897916, 0.07032681629061699, 0.011697553563863039, 0.0644033480701702, 0.1024765247212989, 0.16959739875580582, 0.09965276731444256, 0.19378829853875296, 0.041300431692174504, 3.27155887229102, 26.0565732887813, 28.009883880615234, 26.196299825395855, 30.469421114240372, 12.213606016976492, 6.246532150677272, 0.7482327786939484, 0.2300435916653701, 2.1221255447183336, 1.8963433972426822, 1.3636399933270045, 3.219805432217462, 0.8159635471446174, 1.231636922274317, 15.438973699297224, 44.75394466945103, 28.926698684692383, 52.91264452253069, 38.12065233503069, 57.29719754627773, 78.52870723179409, 67.47360215868268, 77.42989826202393, 73.43442004067558, 77.27738530295235, 70.71110139574323, 71.7407341003418, 72.64056055886405, 68.64536026545933, 63.58154092516218, 74.37189878736223, 72.12730407714844, 69.29644121442522, 61.62932641165597, 64.7553140095302, 59.43778119768415, 68.1242801121303, 63.21723992483956, 61.93764577593122, 35.57057659966605, 21.207576615469797, 27.469581535884313, 26.735690219061716, 35.529953956604004, 34.85477318082537, 36.34578364236014, 15.680748428617205, 1.7228339591196604, 0.8208585530519485, 1.0356474561350686, 0.09294931630470923, 0.1438390016555786, 0.3550562321075371, 0.05519638782633202, 0.092571697996131, 0.2669967716293675, 1.5414486293281828, 0.3157464457409722, 0.04860150920493262, 1.4271615105015891, 1.8874195218086243, 11.552941765104022, 30.736638409750803, 3.299492584807532, 23.00560712814331, 8.529386247907366, 1.5605541127068656, 0.21473052193011555, 0.4567763124193464, 0.5314550623297691, 0.15277035454554216, 0.48070232570171356, 0.09651638168309416, 0.19934345116572721, 0.22989941654460772, 0.15263897659523146, 0.22554532518344267, 0.05720913303749902, 0.05283898753779275, 1.7503427458660943, 4.824321014540536, 20.537433283669607, 46.45002773829869, 32.281949043273926, 24.679242304393224, 13.945525288581848, 11.23224765913827, 39.7089375768389, 42.88585547038487, 61.40534428187779, 61.0593934740339, 63.39897700718471, 59.155684334891184, 60.37211241040911, 57.618805340358186, 57.74286195210048, 59.58787618364607, 61.75614493233817, 64.01922185080392, 64.02840042114258, 64.03692586081368, 66.87589727129254, 63.866111346653526, 63.776090485709055, 64.72603430066789, 68.03364086151123, 62.475978306361604, 70.52254118238176, 61.33944756644112, 62.02233042035784, 32.57382549558367, 35.5074348449707, 35.57354000636509, 23.9974433694567, 29.54370219366891, 5.711084859711783, 0.2118923185127122, 3.470148593187332, 1.8586335693086897, 1.8739734547478812, 4.874959920133863, 3.262881006513323, 1.2785733065434863, 2.3823868249143874, 6.712000659533909, 3.06723775608199, 0.09759449240352426, 0.03920884410451565, 0.03685311979747244, 0.048096319527498314, 0.04245889452951295, 0.1053952295333147, 0.08042111034904208, 0.04192093839602811, 0.04669941609193172, 0.024047236956123794, 0.16430682050330297, 0.03265918305675898, 0.03291422062154327, 0.04674143776563661, 0.03332885980073895, 0.05316365297351565, 0.1230524613388947, 0.020768423431685994, 0.042195779005331654, 0.022718429598691206, 0.05112192074635199, 0.04791882833732026, 0.0633940611566816, 0.037607610026108365, 0.026879728805007677, 0.029555614771587507, 0.061613714189401696, 0.04005008164261069, 0.03941977010773761, 0.05312638104494129, 0.023188528837636113, 0.016333450696298053, 0.034489259855555635, 0.022569518303498626, 0.025394536089152098, 0.08424172390784536, 0.05455106370417135, 0.026447814124237214, 0.031059852269079005, 0.04762392684019037, 0.014899241405406168, 0.08372105684663568, 0.044511591882577965, 0.03564899155337896, 0.04001863493717142, 0.050034911039152315, 0.016930033951731663, 0.035872365281518014, 0.058264438195952346, 5.307519154889243, 45.979308128356934, 45.13154452187674, 44.24696588516235, 50.554026399339946, 30.555147988455637, 13.019568392208644, 1.3241310162203652, 0.03627240238711238, 1.8745920615536826, 3.629696386201041, 2.4052765795162747, 7.119568092482431, 0.7983838990330696, 2.5475146727902547, 25.342310632978165, 51.83040353230068, 30.97120612008231, 62.15804263523647, 42.19751133237566, 63.39681611742292, 79.7329273223877, 71.94719982147217, 79.94646630968366, 72.93011283874512, 81.95289761679513, 70.69277204786027, 75.58550589425224, 75.68447603498186, 70.63498388017926, 62.93581008911133, 76.34625720977783, 72.82693208966936, 67.14944090162004, 61.239824295043945, 64.68813187735421, 63.943194661821636, 71.9441773550851, 65.90673473903111, 55.032032694135395, 13.926904116358076, 22.704512153353008, 27.19750050136021, 23.898183141435894, 41.7554669380188, 41.50609609058925, 43.876081466674805, 18.734407016209193, 7.789389201572963, 1.531661005956786, 0.39001679899437086, 0.09048726556024381, 0.5084799751639366, 0.5996859382305826, 0.09270591900816985, 0.1687501256487199, 0.36468434546675, 1.3210157262427467, 0.9575660973787308, 0.048526558226772716, 2.167272550719125, 11.621358939579554, 14.15423788343157, 38.180191448756624, 5.86462094102587, 10.773400783538818, 14.403279559952871, 0.39372651278972626, 0.5573784655758313, 0.5940652255501065, 0.7280431049210685, 0.23124967409031733, 1.2361675820180347, 0.03553604261417474, 0.09723094012588263, 0.21849534633968556, 0.2719733917287418, 0.21222072946173803, 0.09902849474123546, 0.0791877576016954, 1.7787252685853412, 8.010945541518074, 27.000268936157227, 47.72262852532523, 35.87681497846331, 29.320592062813894, 17.434395585741314, 14.76410732950483, 18.53667344365801, 28.05351161956787, 63.645394870213096, 59.92976229531424, 65.1930296761649, 62.59429223196847, 60.45224598475865, 58.47192600795201, 59.56206362588065, 59.30803748539516, 62.17683056422642, 64.48097133636475, 63.672242709568565, 64.3013812473842, 67.86783599853516, 65.07413210187639, 65.07525076184953, 65.22339330400739, 69.7909723009382, 65.95342663356236, 74.21440396990094, 64.2256806237357, 68.47927052634103, 41.13123035430908, 40.33329575402396, 43.26499434879848, 32.408705030168804, 40.01311928885323, 11.275349940572466, 0.2895139290818146, 1.1029529188360487, 1.9569618701934814, 3.931798415524619, 8.821248803819929, 10.346163868904114, 8.75639431817191, 6.264543184212275, 5.296212264469691, 1.9845338421208518, 0.1243116594851017, 0.17434628893222126, 0.03892613588167088, 0.02631182043946215, 0.05349510036674993, 0.05224690466587033, 0.0848563884251884, 0.04606692985232387, 0.05453284503892064, 0.022933260570945482, 0.04616579918989113, 0.06972384971699544, 0.04782204210226025, 0.07973735061075006, 0.033951001773987494, 0.018960376968607306, 0.10902488298181977, 0.09180747757532767, 0.005141096987894603, 0.04894619481638074, 0.02233400728021349, 0.07743895572743245, 0.032733591206903966, 0.17164367038224423, 0.17360368663711206, 0.24708898844463484, 0.1483215396957738, 0.11664987275643007, 0.25057644130928175, 0.19046062710029737, 0.19097882429403917, 0.12264516390860081, 0.1797931609409196, 0.13036271264510496, 0.11136389497135367, 0.15808869845100812, 0.1279405869011368, 0.08203987777233124, 0.18750540353357792, 0.13342871383896895, 0.16376619094184466, 0.174303052680833, 0.09704995448035852, 0.11467054539493152, 0.2861862305019583, 0.32031637909156935, 0.2285993163074766, 0.29279603010841776, 0.2168719241661685, 9.005692209516253, 72.98082774026054, 61.98783261435372, 63.22613361903599, 72.91708496638707, 52.94834436689104, 20.773908274514334, 1.196066813809531, 0.36452752245324, 4.89412522315979, 6.676899663039616, 1.261216055069651, 19.488699981144496, 2.352460499320711, 2.066462440150125, 32.154925550733296, 77.34937558855329, 44.81423071452549, 69.22753592899868, 55.60690580095564, 64.57514722006661, 80.88269438062395, 71.25947407313755, 79.53970486777169, 73.80610697610038, 80.1850118637085, 70.94656194959367, 72.04538481576103, 72.43742302485875, 70.00014781951904, 59.89695984976632, 74.55252415793282, 76.56789084843227, 70.21637575966972, 61.06672382354736, 63.653260231018066, 60.49122537885393, 71.7899968283517, 65.24159063611711, 69.25332764216832, 43.42391702107021, 27.54248377255031, 38.75548144749233, 36.757269859313965, 50.07007047108242, 48.99641398021153, 49.98964854649135, 23.568574496677943, 10.528093763760157, 1.7072583777563912, 0.6584810518792698, 0.280346649565867, 0.42065042949148584, 1.1286461630037852, 0.2989451858614172, 0.27666407717125757, 0.8295418471097946, 1.970832211630685, 0.7231407165527344, 0.09611802055899586, 4.914637608187539, 7.9013637644904, 26.305963243756974, 50.22838865007673, 10.666005083492824, 34.584488255637034, 12.265588096209935, 2.836240768432617, 0.2793640765760626, 0.4316418825515679, 1.9179364442825317, 0.1011888620310596, 3.1484715342521667, 0.45239851304462975, 0.26048780232667923, 0.4555712342262268, 0.3676522033555167, 0.4675487343754087, 0.2118430161582572, 0.16879583176757607, 2.841210901737213, 16.62233008657183, 27.16662096977234, 53.36675098964146, 38.06946495601109, 39.250815050942556, 18.116660049983434, 16.862409455435618, 43.62313229697091, 54.2572078023638, 68.94339629581997, 57.17048672267369, 62.195743560791016, 59.33002158573696, 62.70790222712925, 59.06585802350725, 58.24136740820748, 56.902501651218955, 61.70602757590157, 65.11341026851109, 62.35975578853062, 63.97521890912737, 68.922621182033, 65.14001492091587, 64.03031812395368, 63.52605955941336, 69.66070747375488, 64.82599108559745, 75.5992077418736, 66.79514530726841, 69.41381713322231, 44.21665436880929, 51.58381543840681, 51.82331984383719, 40.89329971585955, 48.54352344785418, 13.97400769165584, 0.5856062823108265, 9.87774498122079, 3.6496850507599965, 3.4021854400634766, 12.602139728409902, 24.898617778505596, 23.710324696132115, 25.183389697756084, 29.221045221601212, 7.044116301195962, 0.15754135139286518, 0.3002034069171974, 0.11828363580363137, 0.13267209301037447, 0.1428389088915927, 0.21244076479758534, 0.18856689014605113, 0.21410470908241613, 0.13396417296358518, 0.19470782205462456, 0.37029531438435825, 0.15400717460683414, 0.1238902078143188, 0.14604519041521208, 0.0965647544445736, 0.10793333048267023, 0.2699503259999411, 0.13101797391261372, 0.12405127845704556, 0.20426751194255693, 0.15872350867305482, 0.16439307587487356, 0.24509200560195105], [0.03636056783476046, 0.018167946454403654, 0.038340068222688775, 0.09460665165845837, 0.02536530649688627, 0.057023804767855575, 0.018701690581760237, 0.04246897416721497, 0.03385121302146997, 0.05900844505855015, 0.034580176762704334, 0.07700835061924798, 0.11847982741892338, 0.03533913853711315, 0.04368051540638719, 0.04607953703297036, 0.03849657232474003, 0.024452843137883713, 0.032835357889000855, 0.007367116781616849, 0.01034813146439514, 0.046812097009803565, 0.0932508504816464, 0.04821980272286704, 0.0997485357469746, 0.03287603606336883, 0.4509637643183981, 13.515144314084734, 23.576427698135376, 19.49754156385149, 27.354317869458878, 20.907978977475846, 12.30113855430058, 3.6234152146748135, 0.27817509323358536, 1.8954349202769143, 6.458502582141331, 4.540840591703143, 4.01240359885352, 0.05771261959203652, 6.751764331545148, 29.679278918675013, 41.95162500653948, 40.17230599267142, 48.28065572466169, 39.360464572906494, 86.29094982147217, 67.63289655957902, 73.14177581242153, 72.52010658809117, 73.76485552106584, 72.16836098262242, 72.55149160112653, 69.62723105294364, 71.16406835828508, 71.08078724997384, 74.48452908652169, 71.55839947291783, 68.71889305114746, 65.99314948490688, 71.90892219543457, 64.65762233734131, 62.74588802882603, 62.54225022452218, 68.69137818472726, 62.41768986838204, 55.640184198107036, 28.288282564708165, 24.41816200528826, 36.0728896686009, 34.283405440194265, 35.45512185777937, 36.6922208241054, 18.374912432261876, 4.08934360742569, 0.8117404537541526, 0.9803312186683927, 0.7785974921924728, 0.39765118647898945, 0.062043891820524416, 0.008311960679878081, 0.11871134356728621, 0.26324447297624176, 0.8109790831804276, 0.4647028499415943, 0.8213973641395569, 0.25112532185656683, 5.850444444588252, 9.258331315858022, 27.16192398752485, 2.919879926102502, 7.806595546858651, 19.0583268233708, 0.6538573514137949, 3.212122461625508, 5.44487201316016, 0.7511102557182312, 0.3068332097360066, 0.49142730448927197, 0.19982403037803514, 0.3194887563586235, 0.22342141558017048, 0.14296095020004682, 0.14837637889598096, 0.1290905409093414, 0.14316992541509016, 0.2114157019449132, 1.6499030611344745, 19.17481163569859, 47.36236442838396, 32.51927866254534, 27.94445616858346, 12.493497695241656, 41.37209660666329, 77.33627128601074, 38.875073841639924, 70.02967071533203, 59.07402910505022, 65.32160609109062, 65.29936490740094, 64.64523369925362, 59.052996907915386, 65.6758530480521, 61.067446436200825, 61.463438170296804, 61.270771571568076, 65.2345312663487, 61.925590651375906, 64.55634539467948, 65.22671454293388, 67.11964007786342, 67.11801419939313, 66.98379584721157, 64.66640486036027, 70.06354318346295, 60.21391582489014, 65.07451425279889, 51.361396653311594, 27.69253533227103, 40.659444195883616, 29.21711948939732, 31.755115781511577, 16.550032343183243, 0.3881730022174971, 0.5051015764474869, 1.1096521764993668, 7.089772479874747, 5.321547567844391, 3.7844440596444264, 6.627104529312678, 7.538568786212376, 1.4545200424534934, 0.34812955664736883, 0.20913750704910072, 0.1418010081563677, 0.047346484049090316, 0.04199578080858503, 0.093823764739292, 0.11401745543948241, 0.045634177180805376, 0.033251622159566195, 0.013060702426758195, 0.008403893693217208, 0.04751278958948595, 0.044835215767047236, 0.12754027838153498, 0.03806416570608105, 0.027931134083441327, 0.040355866841439686, 0.08725154240216527, 0.009631314348163349, 0.1247686528201614, 0.17645693996122905, 0.03451238772166627, 0.025296701517488276, 0.027264222369662354, 0.049358764463769536, 0.10729630823646273, 0.05912254072193589, 0.08807096164673567, 0.01536426689874913, 0.02949599868484906, 0.008315372014684337, 0.03807439462148717, 0.031201448956770555, 0.015053840520392572, 0.1346514882253749, 0.02539883291215769, 0.04365383880212903, 0.0642884788768632, 0.0678769995325378, 0.021073660713487437, 0.0737537234755499, 0.08719184489122458, 0.14145172547016824, 0.1715904325246811, 0.012651024186717612, 0.06343982834368944, 0.10091885937643902, 0.05048842348956636, 0.09686023608914443, 0.08089320108826671, 0.31263772398233414, 22.07969192096165, 48.559240273066926, 39.99312584740775, 47.48281839915684, 37.37902593612671, 26.383255004882812, 7.807398932320731, 0.651805787214211, 1.7706632954733712, 3.9156746864318848, 5.188574680260249, 2.642398621354784, 0.2474713564983436, 12.76063769204276, 42.05503852026803, 42.2207669530596, 48.57147257668631, 53.00068514687674, 46.829743317195344, 90.37146009717668, 72.21771403721401, 74.26035240718296, 76.46544660840715, 76.25683389391217, 75.27710315159389, 73.12782382965088, 69.79377937316895, 71.8751608984811, 71.4582689830235, 72.3051084790911, 70.81470598493303, 69.58506243569511, 67.34701987675258, 71.33879470825195, 67.65276840754917, 66.84533214569092, 69.55574798583984, 67.94952596936906, 68.48926898411342, 40.412512166159495, 17.71688675880432, 27.988601548331125, 37.233662673405235, 41.29523910794939, 47.05900955200195, 43.493200983319966, 20.17911641938346, 13.349392431122915, 2.054929733276367, 1.3295207555804933, 0.37845049106648987, 1.0090240218809672, 0.40942653747541563, 0.05335876911080309, 0.06997486017644405, 0.43413267603942324, 0.20485182558851583, 1.1894822014229638, 1.5380770159619195, 0.7702672534755298, 25.980031933103287, 10.242769462721688, 33.19898966380528, 4.599796491009848, 10.839340056691851, 6.988287091255188, 0.8576015500085694, 2.7157066762447357, 15.046169451304845, 3.287154321159635, 0.6907347525869096, 0.5323936662503651, 0.1978456936776638, 0.19798055929797037, 0.03192084196156689, 0.09367695011730705, 0.18022745049425534, 0.18933990438069614, 0.154044792588268, 1.868090501853398, 12.564698491777692, 26.04766743523734, 52.54589428220476, 39.01840475627354, 32.391143458230154, 14.411759836333138, 41.464636189596995, 71.16889040810722, 36.65772649220058, 73.84114674159459, 59.8567784173148, 65.91438470567975, 67.16178785051618, 65.65725272042411, 59.2482065473284, 67.30244023459298, 63.16922787257603, 61.93014866965157, 61.40653242383684, 66.57912581307548, 64.96826239994594, 65.88478537968227, 65.18159988948277, 69.9421512058803, 67.2560818535941, 69.10301031385148, 66.86307784489223, 73.95863383156913, 65.42405727931431, 67.71796335492814, 58.43720585959298, 33.872499397822786, 46.665213448660715, 40.81052582604544, 43.922234875815256, 27.299988167626516, 1.8658931340490068, 2.268609421593802, 7.222156507628305, 14.12902113369533, 12.95195894581931, 11.919294221060616, 13.807144096919469, 9.829514929226466, 2.356116771697998, 0.15902138554624148, 0.2418580534202712, 0.15359746159187385, 0.04430133084367428, 0.09389419667422771, 0.0962976762758834, 0.13543914524572237, 0.03607133549771138, 0.025960578483396342, 0.05112400045618415, 0.08248147514781781, 0.2910619117319584, 0.03391341432662947, 0.08634919260761567, 0.03371994363676224, 0.03973096662334033, 0.039599517426852665, 0.16088709900421755, 0.04225256560104234, 0.0397218437200146, 0.05112303354378257, 0.0167392434751881, 0.05470765262309994, 0.08330461954964058, 0.11645734523023878, 0.2579503527709416, 0.1311226175831897, 0.23056324092405184, 0.10359842130648238, 0.16983051624681267, 0.06624991326992001, 0.12715962023607322, 0.2039451670965978, 0.1696017820920263, 0.29506260848471094, 0.14790675123887403, 0.17711946155343736, 0.1797840278595686, 0.2040414647864444, 0.1610529058213745, 0.12562568326081547, 0.21611030931983674, 0.3114950710109302, 0.23758352707539285, 0.1324454758848463, 0.2241025154611894, 0.18319453485310078, 0.13989906092839582, 0.22918342639292988, 0.09303796011954546, 0.6503856948443821, 32.703305176326204, 73.9290692465646, 55.65337535313198, 70.72089835575649, 57.75333636147635, 41.184724535260884, 8.450743062155587, 0.5612885100500924, 6.549515732697078, 11.103262169020516, 10.862130148070198, 6.131277169500079, 0.8217209439192499, 14.567718233381, 59.03284018380301, 73.41593088422502, 57.16114834376744, 66.88207421983991, 51.83743858337402, 89.7349078314645, 73.57563522883824, 74.78836686270577, 75.3896153313773, 76.22355202266148, 71.76872839246477, 72.64708491734096, 69.69579587663922, 72.25828456878662, 69.99866785321916, 75.53236607142857, 68.88267598833356, 69.7311761038644, 67.73789773668561, 74.42301668439592, 62.42449910300118, 64.50963960375104, 63.98093032836914, 71.02954428536552, 64.84179128919328, 68.19373430524553, 40.116112436567036, 30.12778513772147, 47.34873901094709, 47.32866219111851, 57.15008333751133, 47.47020047051566, 26.70977691241673, 20.456693478993007, 3.193244423185076, 0.8321659862995148, 0.6780489161610603, 1.0572492969887597, 0.414826400578022, 0.11410453862377576, 0.2661407318498407, 1.2432975194283893, 0.7800983573709215, 7.322596192359924, 2.151175094502313, 0.3691653364471027, 25.972526141575404, 19.41366117341178, 48.124074595315115, 8.486814635140554, 25.03216389247349, 27.203283139637538, 0.7036019478525434, 2.8420277493340627, 13.555228471755981, 1.3152644634246826, 0.43158868540610584, 1.4768629521131516, 0.5460772748504366, 0.5133885517716408, 0.19737347401678562, 0.4291442222893238, 0.6335334362728255, 0.32863638550043106, 0.18139929404216154, 2.50322077529771, 15.675231558935982, 27.620553731918335, 58.81329100472586, 42.52076237542288, 38.227588585444856, 17.578958068575176, 45.475963251931326, 88.09737723214286, 48.15962505340576, 68.14545127323696, 59.85948126656668, 62.883080210004536, 68.12246663229806, 63.15640844617571, 56.634381089891704, 66.20320742470878, 59.509187834603445, 57.87174408776419, 60.18277399880545, 63.89277158464704, 63.07965169634138, 62.899832316807334, 62.99783665793282, 68.74274621691022, 69.4790746143886, 70.71129594530377, 65.84933567047119, 74.91329547337124, 66.88989094325474, 69.15321104867118, 59.24091788700649, 41.85022299630301, 55.725719996861045, 47.9961130959647, 53.18555586678641, 32.19053159441267, 0.9834295724119458, 3.7071796570505415, 7.614432692527771, 16.15984582901001, 25.326270716530935, 25.45184029851641, 21.455655097961426, 13.577056237629481, 1.6906565257481165, 0.9122667738369533, 0.43992532949362484, 0.4109279183404786, 0.1445414482482842, 0.20129434790994438, 0.202775739133358, 0.1906261896448476, 0.1551516189106873, 0.17295320225613459, 0.267481191349881, 0.18690180592238903, 0.5274310239723751, 0.14855931193700858, 0.2473860510757991, 0.16930820713085787, 0.12968106993607112, 0.21924705457474503, 0.32157888848866734, 0.14495653526059218, 0.15352746391935007, 0.27382087973611696, 0.13424144951360567, 0.1435691211372614, 0.14432205073535442], [0.035428789976452074, 0.03680362406053713, 0.011575765857872154, 0.1048879771094237, 0.04386034754237958, 0.14695152321032115, 0.032563842101288695, 0.08288730015712124, 0.024178167073322192, 0.015656511931281005, 0.05885154062083789, 0.061269547657242844, 0.03213279933801719, 0.05338425149342843, 0.0566972733608314, 0.07802900299429893, 0.012580514220254762, 0.031882338491933684, 0.04968380309375269, 0.006201817703965519, 0.03918728704697319, 0.029824809969535897, 0.0987114899658731, 0.03139638867495315, 0.04832697054371238, 0.04972385023055332, 0.04815560991742781, 0.599175788462162, 23.114087615694316, 21.18272464615958, 16.16909909248352, 16.65691648210798, 16.258199317114695, 11.784694586481367, 3.749653995037079, 0.3156673014163971, 3.202842491013663, 6.021764440195901, 5.5625454017094205, 0.7680198912109647, 32.33151401792254, 59.152349199567524, 39.78860214778355, 50.47256571905953, 37.58820840290615, 63.3079833984375, 79.89195769173759, 69.19895103999546, 78.49745423453194, 73.77897426060268, 75.40187195369175, 71.00262001582554, 77.12988894326347, 73.4338572365897, 71.99585805620465, 72.15394347054618, 72.35272448403495, 71.51277760096959, 72.85141059330532, 75.48827280317033, 69.72583988734654, 69.48089504241943, 60.87498133523123, 64.62816197531563, 65.16249234335763, 67.87451321738106, 56.386549268450054, 39.27287210736956, 19.31382598195757, 21.359604937689646, 34.64235632760184, 35.66314744949341, 31.456075736454554, 17.798656633922032, 4.941274396010807, 2.2642381361552646, 1.180282895054136, 0.11130234505981207, 0.06602145052914109, 0.04678154597058892, 0.04155549639835954, 0.1822765583970717, 0.11648281743483883, 0.3263391101998942, 2.4277785377843037, 0.14350474173469202, 1.810009207044329, 21.11025493485587, 5.1753431388310025, 21.004591941833496, 2.2457248781408583, 5.00705429485866, 6.685674803597586, 1.8047423639467783, 6.129809362547738, 10.594861609595162, 6.555045630250659, 2.989141958100455, 0.5252795251352447, 0.22369825786777905, 0.8281925937959126, 0.8570321777037212, 0.16911960153707437, 0.7165163148726735, 0.48975821690899984, 0.604379554944379, 0.5729788541793823, 2.780573755502701, 15.410649367741176, 35.99500036239624, 34.17686523709978, 29.292021070207866, 17.366621119635447, 30.652850082942418, 23.61140319279262, 52.86310386657715, 64.5340347290039, 64.02580874306815, 66.9413423538208, 67.62048012869698, 67.60228974478585, 64.3371992111206, 63.65900639125279, 57.95849929537092, 61.2131918498448, 62.45397336142403, 63.016172954014365, 61.399313245500835, 64.74518353598458, 61.30800001961844, 66.47266551426479, 67.11876460484096, 62.58138942718506, 65.51910168784005, 62.168854032244, 67.32865578787667, 62.783324922834126, 63.19492925916399, 34.41719300406319, 33.193267822265625, 46.09597880499703, 37.94030836650303, 27.484619174684795, 13.681379965373448, 5.8794527394430975, 14.011986545154027, 8.730183107512337, 4.918759627001626, 10.685117840766907, 20.17420404297965, 17.602550676890782, 2.8945661187171936, 0.062849455380014, 0.16121009524379457, 0.07051722000219993, 0.03936115825282676, 0.0875501317371215, 0.06662465459001915, 0.061537311146301885, 0.03533532177763326, 0.06900665855833463, 0.05346897676853197, 0.05894699014191117, 0.09480228687503509, 0.02283340735760118, 0.06386911030858755, 0.07445570866444282, 0.013956244818733206, 0.07133632033531155, 0.087369458217706, 0.07816051665161337, 0.09507077639656407, 0.06898776135806527, 0.04739231908960002, 0.047963496297597885, 0.03944242639201028, 0.07460703554430179, 0.016241895966231823, 0.02236603243675615, 0.10788905607270342, 0.04441911095221128, 0.022659215543951308, 0.03456800723714488, 0.0574375143540757, 0.02921927174819367, 0.02957055950537324, 0.09092315645622355, 0.01830695283466152, 0.04406681896320411, 0.01323910370203001, 0.10497820869620357, 0.04234460887632199, 0.025284381017887166, 0.041313130475048504, 0.017000447226954356, 0.024739071261137724, 0.03396675396444542, 0.10083966076906238, 0.05505774276597159, 0.048779166636190245, 0.03565544781408139, 0.035677808935620954, 0.06155126182628529, 2.7187363079616, 37.46367236546108, 45.61074093409947, 39.729455607278005, 39.64089386803763, 35.664088930402485, 21.54805745397295, 5.727025764329093, 0.45716899420533863, 1.615059039422444, 5.107361963817051, 1.9399268414293016, 1.7457114458084106, 45.005601474217, 62.940736361912315, 45.35890695026943, 57.87487077713013, 45.9894802910941, 71.8125228881836, 83.62432152884347, 75.05449676513672, 80.1003828048706, 77.46657085418701, 77.25333758762905, 71.69004004342216, 80.98929364340646, 75.6389444896153, 71.79136562347412, 74.81522165025983, 72.08366244179862, 70.8730778012957, 72.1178753716605, 75.16605704171317, 70.50993715013776, 67.81734343937465, 63.78582491193499, 67.38403987884521, 69.87224537985665, 68.44150011880058, 58.31758567265102, 27.857768705913, 19.24585349219186, 28.142250537872314, 41.08162369046892, 46.40722336087908, 38.90067795344761, 20.092851059777395, 11.137242334229605, 5.362248378140586, 4.152562660830362, 0.3271407314709255, 0.12038746077035155, 0.03301414508106453, 0.04228219383263162, 0.13617874841604913, 0.14910976668553694, 2.012609124183655, 2.189446423734937, 3.837356763226645, 1.513031582747187, 19.036681447710308, 5.4836017063685825, 37.17094128472464, 3.201086116688592, 3.416424036026001, 9.172176258904592, 1.962127421583448, 9.086009911128453, 11.960285118647985, 1.2238583053861345, 10.544937065669469, 5.339137366839817, 1.0592286650623595, 1.072957871215684, 1.3047304515327727, 0.0479659492016903, 0.6705721659319741, 1.1446843424013682, 0.65665595552751, 3.0474086829594205, 14.244240505354744, 20.898065635136195, 45.999951226370676, 41.6353325843811, 35.06839207240513, 19.933822427477153, 32.675230979919434, 32.25518805640084, 53.52327653339931, 63.95937006814139, 63.95643098013741, 68.8733445576259, 67.75457341330392, 68.73482527051652, 65.47862843104771, 64.16441140856061, 58.64490141187395, 62.05526488167899, 61.99950558798653, 62.74973038264683, 65.5229162488665, 65.78846945081438, 63.50422831944057, 68.44341087341309, 67.63942786625454, 68.52331515720913, 67.96325560978481, 65.45889554704938, 70.82846341814313, 67.01414557865688, 66.69052628108433, 44.48760632106236, 40.649435315813335, 55.880115917750764, 45.976007734026226, 41.95408466884068, 25.948994329997472, 11.77880425112588, 18.929373468671525, 17.628427505493164, 12.958547575133187, 18.315427167075022, 29.521193504333496, 22.13254165649414, 3.3360692049775804, 0.13905433911298, 0.1664177972291197, 0.07768510787614755, 0.052524910641035864, 0.1526504981198481, 0.03735565979565893, 0.0821782039212329, 0.025795317886929427, 0.05710317300898688, 0.04837703625006335, 0.026410257210955024, 0.022758040776742355, 0.04714627211381282, 0.045518619274454455, 0.017434046370908618, 0.03740164411387273, 0.0862994831321495, 0.02360881512452449, 0.07261833761419569, 0.02454560905295823, 0.02817690625254597, 0.031945499924144576, 0.027825109594102417, 0.031148343413536037, 0.20298863628080913, 0.17596052374158586, 0.15130599455109664, 0.22278575040400028, 0.17970393358596734, 0.20434951968491077, 0.17712183642600263, 0.18402878008782864, 0.13865085504949093, 0.1264051707195384, 0.13458465252603802, 0.2021482978016138, 0.10513231078428881, 0.1324414453868355, 0.1817807121468442, 0.16852931678295135, 0.319931296897786, 0.15197106743497507, 0.062402830060039244, 0.10397194804889814, 0.12434991528945309, 0.24375491163560323, 0.22157612602625573, 0.11849915209625449, 0.18963812052139215, 0.19829788298479148, 0.2082461155951023, 3.8541805233274187, 51.55594621385847, 72.31023624965123, 60.48110185350691, 60.29972607748849, 56.17602579934256, 32.500820772988455, 4.763905993529728, 1.9077655843326022, 9.18412629195622, 15.423878737858363, 8.191339015960693, 1.2885103161845888, 51.80800254004342, 81.64675303867885, 60.85624204363142, 67.88638768877301, 54.11368581226894, 72.16866670336042, 84.45622934613908, 75.07000514439174, 84.03297982897077, 77.46245752062116, 80.24330724988664, 71.86818490709577, 78.55729212079729, 74.50986916678292, 70.78549575805664, 73.35956014905656, 70.92308398655483, 69.57582133156913, 71.30244868142265, 76.31572682516915, 68.98795509338379, 69.5037476675851, 62.348430224827354, 65.98640278407505, 67.00872598375592, 67.64315210069928, 61.77837221963065, 59.39304869515555, 25.389318670545304, 30.244445392063685, 46.49105337687901, 52.3961432320731, 40.73399836676461, 26.230577026094707, 17.699377298355103, 8.091856445584979, 4.203705745083945, 0.19930416398814746, 0.3405571872634547, 0.1306850846324648, 0.1393691793616329, 0.3043996574623244, 0.35773641828979763, 2.889613355909075, 6.396549837929862, 4.238489295755114, 4.131625132901328, 48.62269469669887, 8.246241075651985, 48.72974559238979, 5.247320830821991, 6.569785799298968, 32.471759932381765, 2.854009483541761, 16.122210911342076, 24.368612664086477, 18.363701513835363, 13.33408989225115, 8.864109635353088, 2.1127413511276245, 1.8400223851203918, 2.02215182355472, 0.37096828541585375, 1.185347046170916, 1.956096385206495, 0.9754587944064821, 1.8700926687036241, 16.92311760357448, 24.269972562789917, 45.51893091201782, 50.16005311693464, 39.70234373637608, 25.53547576495579, 31.709587710244314, 34.15796266283308, 58.34132766723633, 60.7205993107387, 63.32361684526716, 62.565735135759624, 65.24591241564069, 65.75485406603131, 61.475882393973215, 60.14458669934954, 58.87111391339983, 59.63046864100865, 62.903167452131, 60.08873013087681, 64.36586053030831, 64.41779136657715, 62.15061501094273, 68.1595561163766, 68.31858648572648, 67.79797186170305, 68.38772106170654, 68.2904532296317, 73.15464387621198, 68.67696762084961, 67.91332585471017, 48.39095490319388, 51.21303524289812, 64.90255328587124, 56.269079548971995, 52.28819949286324, 23.479479483195714, 8.935409443719045, 21.13157548223223, 33.33648409162249, 29.791867528642925, 26.375014441353933, 36.85272421155657, 26.47556529726301, 3.5855173511164526, 0.2539953078542437, 0.3907029607466289, 0.2406967000237533, 0.1558905164045947, 0.2627444469502994, 0.24653106981090137, 0.17912445110934122, 0.12113460925008569, 0.11620512019310679, 0.143630162147539, 0.16896659189036914, 0.4270139480275767, 0.19483350031077862, 0.23805244905608042, 0.16714826731809548, 0.17644103510039194, 0.32107606689844814, 0.15846677816339902, 0.3758338429033756, 0.2705080003610679, 0.09189110701637608, 0.11574640337909971, 0.10966787633619138, 0.17962230582322392], [0.03445769101381302, 0.08105811223919902, 0.008791129387515997, 0.09885159387652363, 0.06361198624862091, 0.039474571988518746, 0.038881186329360516, 0.01845087350479194, 0.03637454904881971, 0.053067636875701804, 0.059091911651194096, 0.010115038570282715, 0.0513428076436477, 0.03610753534095628, 0.021145190178815807, 0.0478546491025814, 0.03663798348445978, 0.019389289131920253, 0.04474319963316832, 0.06716822220810822, 0.025554836594632695, 0.030068885801093917, 0.031207352211432796, 0.00490334679904793, 0.13916855012731894, 0.08476113567927054, 0.1449875578816448, 0.027411242248490453, 5.1332409637314935, 15.919820308685303, 11.273885607719421, 15.732571567807879, 18.049634252275737, 16.365125145230973, 12.334599341664996, 3.235580231462206, 1.4574319890567233, 4.502028822898865, 0.4622757573212896, 4.679667770862579, 51.71301719120571, 49.261790003095356, 49.49558298928397, 43.81088651929583, 46.202855995723176, 75.62870979309082, 75.04351166316441, 75.871597971235, 74.74180003574916, 76.03499180930001, 72.28853007725307, 72.34498419080461, 72.7083054951259, 77.040938104902, 74.14505399976457, 73.49666895185197, 72.79669352940151, 73.92241982051304, 66.09369686671666, 72.98783152444022, 71.57160105024064, 69.49784169878278, 66.40851974487305, 69.39876733507428, 65.0317689350673, 65.77895736694336, 62.596341950552805, 45.608062403542654, 28.85426024028233, 25.11175377028329, 34.755948952266145, 38.815357548849924, 26.83514847074236, 16.286197083336965, 6.030769305569785, 1.9622047202927726, 4.707563051155635, 1.916858387844903, 0.4523604879421847, 0.11037525587848254, 0.05307985729138766, 0.22527539038232394, 0.10144676640629768, 1.474114722439221, 1.5914870585714067, 4.377497128077915, 0.9383250155619213, 6.2852396965026855, 1.8171911473785127, 21.53817711557661, 4.186961455004556, 1.94779263649668, 10.254788977759224, 8.174586909157888, 13.114452123641968, 3.1197572350502014, 1.5555788768189294, 5.338568917342594, 1.1485241992133004, 0.41423680792961803, 0.704168823148523, 0.5855400030102048, 0.35593797479357037, 0.5872918175799506, 0.7460879023586, 1.1508520628724779, 4.5859118189130506, 10.687864116259984, 18.66642757824489, 21.32772833960397, 42.48822396142142, 35.60654047557286, 20.29316415105547, 21.041455609457834, 33.43634360177176, 67.90455722808838, 60.096692766462056, 66.62091227940151, 61.850015095302034, 63.96819428035191, 62.04375866481236, 64.00243500300816, 59.75122833251953, 66.89396258762905, 63.2518766948155, 66.28993483952114, 64.20257786342076, 68.37631211962018, 62.14333329881941, 68.13079752240861, 60.37262657710484, 70.53603458404541, 64.06790093013218, 68.85279178619385, 64.5178176334926, 66.3394546508789, 62.864549364362446, 66.22759560176304, 46.353708335331504, 31.415703228541783, 43.645286628178184, 36.07155214037214, 25.54717653138297, 25.177011251449585, 27.38851342882429, 14.153213892664228, 3.1916578454630713, 7.970238651548113, 19.274030174527848, 27.70230449948992, 10.920713015965053, 0.6442254653998783, 0.08204589637794665, 0.07918571521128927, 0.1837188388620104, 0.06163130181708506, 0.05930282747639077, 0.12727807887962886, 0.103778843767941, 0.04575558405901704, 0.09822409147662775, 0.03732189928580608, 0.036014504797224484, 0.017053121900452033, 0.09515040926635265, 0.03550915566406079, 0.04690120901380267, 0.09608001581260137, 0.07317756582051516, 0.04593861548762236, 0.060853680329663415, 0.07309332569794995, 0.055854152888059616, 0.07378507179341146, 0.03213552365611706, 0.050349086323486905, 0.005182214513687151, 0.0621244271418878, 0.04313730741185801, 0.05974633153527975, 0.012631060838300203, 0.045196176040917635, 0.03201932792684861, 0.03657482883759907, 0.03914821360792432, 0.002822514627561239, 0.07490404389266457, 0.009396463200183851, 0.02484386590575533, 0.03376627400783556, 0.10412593478603022, 0.02454136820909168, 0.060152332963688035, 0.04745566711894103, 0.10786013691020863, 0.06070653322551932, 0.038398154212960174, 0.07870683233652796, 0.022371857659891248, 0.04703450043286596, 0.2087474444082805, 0.09838890763265745, 0.07763182930648327, 0.07252375661794629, 7.738997391292027, 30.995830535888672, 33.89789506367275, 42.43934685843331, 38.19565119062151, 31.305761882237025, 20.730553252356394, 5.7323576382228305, 0.7717638303126607, 1.7093316550765718, 0.23331570465649876, 9.317264199256897, 67.26830373491559, 60.6441969190325, 61.603138651166645, 51.91485888617379, 53.68801484789167, 79.79455089569092, 79.06865174429757, 80.7195576259068, 75.74573135375977, 78.48579515729631, 73.27670288085938, 74.85502093178886, 74.87859616960797, 79.53310407911027, 75.97608498164585, 72.37044933864048, 73.37998785291398, 74.96398953029087, 68.91825076511928, 73.71291078839982, 73.33000251225063, 69.59489413670131, 66.48058646065849, 71.52869592394147, 66.90355804988316, 67.54935141972133, 68.2631607055664, 42.11725269045149, 20.45558524131775, 29.43408046449934, 39.276092597416465, 50.96707943507603, 34.85972377232143, 16.472149985177175, 15.01656665120806, 5.038335953439985, 15.26871851512364, 1.8441784935338157, 0.8930025132639068, 0.19238282181322575, 0.1347203052469662, 0.07132034762097256, 0.09892341002289738, 2.2961755309786116, 1.1071830689907074, 1.180289734687124, 1.1148774389709746, 23.054986238479614, 6.445907669407981, 30.544433866228374, 3.8056121809141974, 2.13830029964447, 10.313646299498421, 1.0654811752693993, 9.076439636094229, 2.485175217900957, 2.3487119461808885, 5.854619877679007, 5.703924306801387, 1.4270208094801222, 2.134186097553798, 1.6820853799581528, 0.23329339442508562, 0.13317570170121534, 0.5681110982384, 2.012602610247476, 15.039657252175466, 19.229834420340403, 21.132824420928955, 29.437870706830704, 51.28856563568115, 39.63426181248256, 25.147952147892543, 16.1316465650286, 33.82538366317749, 72.77475806644985, 57.865650517599924, 69.1815527507237, 62.161134583609446, 65.66153281075614, 63.01180253710066, 65.38336862836564, 59.47338376726423, 68.57703168051583, 62.37663991110665, 68.10777814047677, 67.10775865827287, 68.63957241603306, 64.24867221287319, 68.99923201969692, 62.03986767360142, 72.04887281145368, 68.04759284428188, 69.4806935446603, 68.01123986925397, 70.4330553327288, 66.61980751582554, 68.41515949794224, 52.95082834788731, 39.06554480961391, 52.2870773587908, 51.88515533719744, 43.021390506199424, 39.969449860709055, 30.027901308877126, 23.624894857406616, 13.473370007106237, 14.282543318612234, 30.25316538129534, 35.83165863582066, 12.970152803829738, 0.48909965796130045, 0.11889802212161676, 0.022122747098494853, 0.17392221811626637, 0.05908730439841747, 0.07560594087200505, 0.14107488069151128, 0.11554536702377455, 0.057734488775687556, 0.07361615728586912, 0.03157416145716395, 0.07791846285441092, 0.05391139177871602, 0.09629781876823731, 0.03593083464407495, 0.06341782345303468, 0.03032110066020063, 0.14013124204107694, 0.023651898705533574, 0.029039073203291212, 0.11897901206144265, 0.02061448758468032, 0.04299475738246526, 0.0148368484141039, 0.0442287275966789, 0.14352351001330785, 0.2603816794497626, 0.11429713400346891, 0.11547608859837055, 0.19740442878433637, 0.2562029351081167, 0.07299913146666118, 0.08497849758714437, 0.08013812053416457, 0.10515152689601694, 0.14378872221069677, 0.12869637991700852, 0.1120654662538852, 0.18826456208314213, 0.19966115483215877, 0.2751673646271229, 0.15647454506584577, 0.11360299946474177, 0.19954971224069595, 0.14675059542059898, 0.1897553035191127, 0.2027536053210497, 0.050657259965581555, 0.12972598895430565, 0.2817905449441501, 0.2401258892246655, 0.19890956873340265, 0.12509128265082836, 10.50581523350307, 53.181077752794536, 57.865692206791465, 63.32759121486119, 61.546962465558735, 49.89389194761004, 24.78226671900068, 5.555316669600351, 5.032319247722626, 10.041460173470632, 0.721687565956797, 9.077262129102435, 81.26622799464634, 70.21659810202462, 73.75746958596366, 63.81404849461147, 58.952428681509836, 79.72736876351493, 81.56215177263532, 80.31898008074079, 79.98220784323556, 80.5124318259103, 74.48923301696777, 74.72050380706787, 74.71206869397844, 81.68132032666887, 78.44173663003104, 73.90514659881592, 73.5914979662214, 73.91140692574638, 66.66682597569057, 74.95342826843262, 72.45255620138985, 70.87471757616315, 66.14969934735979, 70.83873285566057, 63.906501225062776, 70.96370315551758, 63.53093719482422, 60.13217026846749, 38.33958659853254, 33.219559805733816, 46.20438459941319, 54.98791510718209, 36.586358070373535, 23.909227303096227, 20.080200127192906, 7.862466011728559, 20.12029470716204, 2.015287003346852, 0.9168149126427514, 0.32260602765849655, 0.17864168701427324, 0.4121523212109293, 0.42800132504531313, 6.157774993351527, 4.228230280535562, 9.713072674615042, 5.851194850036076, 37.40311534064156, 12.641825233186994, 41.748695918491904, 7.517482740538461, 1.9657891222408839, 27.969846623284475, 16.519901479993546, 27.944961650030955, 2.5414716941969733, 11.551853503499713, 16.098653044019425, 14.31055758680616, 4.691502724375043, 4.414735998426165, 2.411451573882784, 0.7112052312919072, 1.391271133508001, 1.1490373888186045, 2.651024158511843, 12.02088817528316, 24.964627402169363, 25.0907267842974, 26.970042535236903, 58.30616283416748, 42.71913691929409, 31.015493937901088, 24.89351953778948, 45.73860168457031, 73.42567920684814, 58.0318340573992, 66.9800021307809, 60.132705279758994, 61.22808183942522, 62.81945555550711, 63.332656451633994, 56.60772780009678, 65.93506949288505, 60.827177728925435, 65.75764724186489, 68.14804989950997, 67.0228933606829, 64.3239073072161, 70.04649925231934, 64.8625386101859, 71.97382531847272, 69.99609007154191, 71.63746997288295, 72.06074728284563, 74.27434607914516, 68.35490471976144, 72.05618231637138, 56.15475736345564, 47.52005726950509, 57.31160463605608, 62.2502452305385, 61.295861516680034, 53.13364934921265, 36.67474610464913, 35.26665544509888, 29.105910096849712, 24.1444342476981, 40.023624965122764, 44.28165824072701, 14.12369099685124, 0.7619671417134148, 0.3033265679010323, 0.13908270187675953, 0.3584093621798924, 0.28333974895732744, 0.16441892805908406, 0.25354926607438494, 0.2304715844137328, 0.09492995323879377, 0.12084479337292058, 0.18625038516308579, 0.08374292603028671, 0.1564227728439229, 0.22307777830532619, 0.22387298063508101, 0.14812819792756013, 0.1853095827890294, 0.2837705915527684, 0.10313024571431534, 0.20839379195656094, 0.32161200099757736, 0.15178964074168885, 0.22757725257958683, 0.14154742604919843, 0.25109894041504177], [0.061029848376555104, 0.08317936877054827, 0.07800534247819867, 0.08763637353799172, 0.028342682535627058, 0.015203087690419384, 0.01846624062662678, 0.0727322907852275, 0.039609057629214864, 0.05634631808581097, 0.08542445115745068, 0.03695829951071313, 0.0278935941335346, 0.014588401120688235, 0.0196255465437259, 0.030970903113484383, 0.045086850478713, 0.022318161791190505, 0.045123179243611436, 0.13481508301837103, 0.05988218103136335, 0.07144983245858125, 0.0286053230852953, 0.07322137882666928, 0.034866365870194774, 0.1137708147455539, 0.038980259227433374, 0.13063067969466957, 0.6048625633120537, 10.535443220819745, 19.84125852584839, 17.266103267669678, 24.313223361968994, 18.179635047912598, 25.47485273224967, 17.62926823752267, 6.49618353162493, 0.4505667399082865, 1.1867324518305915, 19.0870680468423, 53.96286473955427, 55.21151161193848, 51.64347961970738, 42.92776700428554, 63.10770852225167, 79.66675962720598, 76.89620018005371, 79.64433084215436, 76.58889525277274, 73.09834957122803, 71.62107917240688, 73.49106870378766, 75.66230433327812, 75.88914912087577, 75.15368924822126, 72.21314212254116, 73.66842842102051, 74.08942672184536, 70.67835453578404, 74.71472290584019, 73.24666581835065, 71.99077197483608, 67.42977292197091, 69.37713759286063, 70.17298425946916, 64.76537500108991, 70.47102723802838, 56.24535492488316, 32.84823070253645, 23.752097266060964, 37.4467465536935, 39.49199744633266, 20.641630206789287, 17.871079444885254, 9.502755045890808, 1.5551706701517105, 12.79945467199598, 9.848933407238551, 1.6944325459854943, 0.04948853089341095, 0.4173602946102619, 0.21803390181490354, 0.29650737238781794, 1.952910419021334, 0.6227712194834436, 0.1256418866770608, 0.9845840590340751, 10.922910383769445, 1.3152668518679482, 19.126148189817155, 0.9284331692116601, 1.5906691253185272, 8.483002679688589, 3.769330859184265, 1.460253500512668, 0.8009069093636104, 0.761411937219756, 0.9480871260166168, 0.2744621496115412, 0.15427067689597607, 0.5220219056521143, 5.9875688808304925, 1.5996397925274712, 3.5798143999917165, 4.757257001740592, 6.5102280122893195, 9.325676730700902, 16.027680669512065, 22.14657701764788, 16.170664174216135, 40.971776144845144, 36.67762960706438, 23.624415431703838, 30.504905564444407, 45.288834367479595, 64.52124309539795, 61.779546465192524, 64.80568150111607, 69.04293618883405, 67.75533076695034, 67.66087695530483, 63.73291437966483, 62.21403816768101, 63.00409698486328, 63.65175247192383, 64.5380368913923, 66.07351234980992, 66.78934356144497, 67.90583569662911, 62.934538568769185, 64.94814736502511, 67.44209207807268, 67.96085848127092, 64.05583885737828, 65.95218290601457, 64.32752731868199, 62.7446095602853, 60.45465006147112, 53.06905542101179, 26.96895166805812, 46.93485566547939, 43.344985485076904, 29.834171635763987, 20.755438225609915, 22.0989089012146, 4.1397983857563565, 6.3098224231175015, 13.73235195023673, 11.799241508756365, 12.991360442978994, 0.26233716309070587, 0.04299233840512378, 0.0812426737642714, 0.07404462500874485, 0.07766471111348697, 0.08529052870082003, 0.12369126134685107, 0.06873675768396684, 0.0862259774335793, 0.08929225682680096, 0.03267828381753393, 0.08734107509787593, 0.09192562409277473, 0.04516406776383519, 0.08595755576555218, 0.020949534606188536, 0.12447051810366766, 0.08085824974945613, 0.06240930328411715, 0.016383402748033404, 0.013579814794606395, 0.0322144237080855, 0.08778014153774295, 0.017202927165531685, 0.06510081421583891, 0.11010466289839574, 0.021838722517713904, 0.11171101991619382, 0.10863538352506501, 0.02347154918658946, 0.09483113139867783, 0.05872810831559556, 0.03499061581013458, 0.024286318769944564, 0.04597568724836622, 0.05968347205115216, 0.05757555551826954, 0.02974003041163087, 0.019436779797875454, 0.01229751592368952, 0.06620384074215378, 0.03540148572730167, 0.08446252598826375, 0.08864945346223456, 0.016466262051835656, 0.10669488193733351, 0.050699237534510236, 0.08427708236766712, 0.15139153067554745, 0.06867585916604314, 0.0825198395177722, 0.07888921576419047, 0.131955532889281, 0.10314454244715826, 0.747594955776419, 15.114989621298653, 35.024302278246196, 39.07476854324341, 46.91070720127651, 38.842035157339915, 40.96640518733433, 28.868846246174403, 11.218231405530657, 3.0146813648087636, 3.8759514008249556, 32.87172603607178, 70.4268992287772, 65.99821472167969, 61.855538913181846, 52.28015695299421, 70.95464270455497, 82.00500215802873, 80.68626880645752, 84.67944022587368, 79.239563533238, 73.14542361668178, 74.84156227111816, 76.69971902029855, 76.99686568123954, 79.44612652914864, 76.75736822400773, 73.25701168605259, 73.27609838758195, 76.20126220158168, 70.7527766908918, 74.89192976270402, 75.01220308031354, 73.9644216809954, 65.31697859082902, 71.07892513275146, 71.89457416534424, 67.0261173248291, 71.3861049924578, 59.09680530003139, 22.159761224474224, 27.065661907196045, 43.671227727617534, 47.48343331473214, 28.044914960861206, 17.617864506585256, 15.590187345232282, 5.373658623014178, 19.23257201058524, 27.656083345413208, 1.1997986478464944, 0.05021417659840413, 0.4728377248559679, 0.2852271076823984, 0.9986529669591359, 6.7509262050901135, 0.28024478788886753, 1.1832559640918459, 2.4803850863661085, 33.66707590648106, 6.672101063387735, 19.431950569152832, 3.315910960946764, 3.2591374473912373, 12.575631482260567, 0.9307186922856739, 7.886610133307321, 4.622407666274479, 3.357594724212374, 7.97897253717695, 0.8466404410345214, 0.09940919359879834, 4.419541112014225, 11.08446294920785, 6.068662175110408, 9.129495212009974, 11.431691357067653, 13.669634904180255, 16.303284440721782, 19.726210253579275, 22.857619183404104, 22.238965477262223, 48.586404255458284, 45.171388966696604, 27.678006649017334, 22.839296783719742, 48.849046162196565, 66.67285701206752, 63.530103410993306, 66.5929318836757, 71.65205424172538, 65.66695935385567, 68.20157882145473, 64.24592072623116, 63.8240122113909, 64.13529150826591, 65.58966759272984, 67.06813308170864, 67.61175319126674, 69.36236572265625, 71.32058347974504, 66.79237297603062, 66.0511669431414, 71.70761203765869, 70.06334168570382, 68.7226311819894, 68.93211936950684, 69.09588841029576, 67.54128456115723, 62.43933350699288, 57.47332395826067, 35.952025754111155, 58.442778314862935, 54.95195817947388, 43.831404549734934, 31.455731800624303, 30.27200542177473, 17.546108722686768, 12.844265341758728, 22.393854720251902, 25.831343957356044, 16.951341186250957, 1.321326115301677, 0.043794373582516394, 0.15532134766025202, 0.030544135120830367, 0.13804830238223076, 0.024748423170032244, 0.1754401009529829, 0.08880095676119838, 0.04864460974931717, 0.021356005920097232, 0.05432259417804224, 0.04029120923951268, 0.047153081212724955, 0.038371294404246976, 0.0653954612623368, 0.03454693533214075, 0.09430238298539605, 0.017665545555895994, 0.04943776290331568, 0.01362677026606564, 0.029255651403218508, 0.04005221563524433, 0.033843979838171175, 0.05901833809912205, 0.06342387598540102, 0.12748256219284876, 0.1161824706941843, 0.24662837173257554, 0.2887957404766764, 0.15839595267815249, 0.11199728026986122, 0.1500516411449228, 0.12122192313628537, 0.12398674977677208, 0.1796982746039118, 0.21975374381457055, 0.17393683376056807, 0.13209083277199948, 0.12758293109280722, 0.11046235941882644, 0.17859674085463795, 0.17070847270744188, 0.2528896757534572, 0.14129389822483063, 0.101318190805614, 0.16913957760802337, 0.11447378381022386, 0.25513378104993273, 0.3055737673171929, 0.1678598877042532, 0.18912289531103202, 0.15838584250637464, 0.33488965566669193, 0.18626714497804642, 0.7346276087420327, 19.228034836905344, 58.135469913482666, 65.66035856519426, 72.41967732565743, 58.83773476736886, 54.05866650172642, 29.138811554227555, 10.943528294563293, 4.657939016819, 2.8551240180219923, 41.20771959849766, 86.82168102264404, 76.51316683632987, 74.90866797310966, 62.71105670928955, 74.276777948652, 84.38626098632812, 82.48273250034877, 86.11770343780518, 81.0858736038208, 75.48684842245919, 76.41878250667027, 77.00878879002163, 78.75990159170968, 78.17845548902238, 75.94761126382011, 73.18587602887834, 72.47082996368408, 74.71026216234479, 69.55248928070068, 75.12370082310268, 72.85181358882359, 75.29178469521659, 64.16498810904366, 70.3691735948835, 70.55831745692662, 70.61838463374546, 70.04830578395298, 69.37342725481305, 42.777710233415874, 33.59770509174892, 50.90880836759295, 53.0504481451852, 28.970937865121023, 24.60531347138541, 21.786719390324183, 7.461208411625453, 28.473665714263916, 34.95062705448696, 1.99404462320464, 0.14825730957090855, 0.8625435105391911, 0.6098081065075738, 0.8602635785937309, 13.176942484719412, 2.398233277457101, 1.0561478989464896, 6.272701237882886, 33.97158765792847, 16.149025746754237, 45.00757128851754, 3.980880056108747, 2.6473440017019, 15.482905421938215, 9.723089371408735, 14.540163414818899, 6.293038180896214, 2.391171302114214, 4.862039310591562, 0.7378232372658593, 0.9917414635419846, 8.885759353637695, 22.42671796253749, 12.576085720743452, 19.702897310256958, 22.978696755000524, 14.866181577954974, 19.46238889013018, 27.172759703227452, 29.263592515672954, 21.20147783415658, 56.32771192278181, 47.24513789585659, 36.35200922829764, 37.69010720934187, 57.332171303885325, 63.548821857997346, 64.91258648463658, 62.00146497998919, 72.41605036599296, 62.42299134390694, 67.47207355499268, 59.14954907553536, 61.60371535164969, 60.416365487234934, 65.4335137775966, 65.12329755510602, 69.99675015040806, 68.14744540623256, 71.16339438302177, 65.54903452736991, 70.38361889975411, 68.9297708783831, 73.5823541368757, 66.81196689605713, 70.44014944349016, 72.98750495910645, 69.66080474853516, 65.94059331076485, 63.16405841282436, 42.03958920070103, 63.151822635105674, 65.06987980433873, 59.23899323599679, 47.16433729444231, 46.43233067648751, 32.44684369223458, 28.52348950931004, 32.32136269978115, 35.88870334625244, 21.08318649019514, 1.759255004780633, 0.11467133249555315, 0.20013990199991635, 0.24582058936357498, 0.2069127807127578, 0.2080476712435484, 0.23280957181538853, 0.3525405770965985, 0.1344223062374762, 0.18161246260362013, 0.18763626579727444, 0.27164902484842707, 0.27072385592120035, 0.16232403261320932, 0.3236020356416702, 0.0873117216729692, 0.19568096340766974, 0.26661076662795885, 0.2626759963376181, 0.09890831940408264, 0.17804080354315893, 0.11404724312680108, 0.14731485157140664, 0.13881185783871583, 0.17205501188124928, 0.31059701634304865], [0.03513346778761063, 0.08433867977666003, 0.052598636863487105, 0.04853614592658622, 0.03923784808388778, 0.09374106489121914, 0.05730731026934726, 0.043084368109703064, 0.025986462898020233, 0.07760740204581193, 0.04179731270830546, 0.0686882356447833, 0.03720577819538968, 0.08408019186130591, 0.03240507169227515, 0.056641009237085066, 0.05294542593349304, 0.06257065212620155, 0.02007813618651458, 0.05429622630721756, 0.06580157804169826, 0.026990720170683095, 0.11203707634870495, 0.053176667275173325, 0.13224747936640466, 0.3344838103013379, 0.12976142205297947, 0.10841114805745226, 0.21573851284171852, 1.7278913791690553, 14.433867267199926, 21.929869651794434, 35.88970736094883, 35.25798061915806, 29.79321895326887, 33.383224623543875, 31.01360055378505, 15.115844249725342, 18.418984855924332, 36.71257209777832, 49.72509935923985, 58.01715251377651, 53.090893609183176, 46.764788082667756, 72.58644104003906, 75.22986929757255, 77.28864138466972, 77.64167240687779, 74.10039097922188, 75.33377265930176, 71.15493842533657, 72.47909137180874, 71.01046453203473, 74.71145030430385, 74.91766589028495, 72.60089329310826, 75.15292494637626, 71.87518869127545, 71.17859009334019, 66.92636203765869, 73.45539665222168, 72.80511474609375, 73.34253011431012, 68.0323484965733, 69.92548247746059, 66.68218149457658, 70.71590954916817, 58.66016660417829, 34.36052002225603, 30.683376993451798, 41.8015057018825, 39.04929297310965, 17.41361004965646, 17.902047566005162, 13.108364633151464, 3.5040006509849, 8.754519173077174, 24.982602391924175, 5.933680389608655, 0.17794469584311756, 0.4743127514209066, 0.27852917994771687, 3.2100618864808763, 2.845767400094441, 0.14244795058454784, 0.4989527463912964, 0.8928106778434345, 29.149749755859375, 2.064684352704457, 7.033457764557429, 3.845021494797298, 3.6552071315901618, 9.615050094468252, 5.497784282479968, 1.3030091438974654, 0.4041231077696596, 3.8955275160925726, 2.732543029955455, 1.105347441775458, 0.44096609364662853, 0.8373556392533439, 10.535498806408473, 6.648960087980543, 1.5736815397228514, 2.3523858061858585, 2.746098531144006, 21.170839752469742, 22.467780079160416, 20.690983261380875, 15.72367092541286, 28.65980969156538, 45.14281449999128, 27.898959364209855, 23.767089741570608, 45.32254702704293, 70.50981208256313, 63.25796331678118, 65.46531568254743, 69.22316551208496, 69.28635243007115, 64.50904205867222, 68.31624494280133, 60.32321793692452, 63.39910902295794, 69.08217961447579, 68.28420679909843, 66.6368306023734, 67.68078354426792, 69.18586758204869, 64.5223548071725, 66.37388297489711, 68.51538726261684, 67.41782896859306, 66.74874523707798, 66.76504571097237, 64.79600960867745, 65.39594486781529, 63.83059215545654, 56.51981919152396, 29.57908242089408, 43.902766023363384, 47.20383432933262, 31.193287917545863, 21.983087641852244, 6.8674322962760925, 4.401609114238194, 12.566927995000567, 9.812827093260628, 8.952266642025538, 3.125910516296114, 0.06671905238181353, 0.06887773690479142, 0.16493608030889714, 0.005410805327950844, 0.07602396594094378, 0.05280420244006174, 0.14421963265963963, 0.0821233850770763, 0.059854903923613687, 0.04071270840774689, 0.05121048652966108, 0.07094962322818381, 0.08374127719019141, 0.02998884241761906, 0.10754866898059845, 0.0489053978983845, 0.012880840604858739, 0.015738100678260838, 0.016577563847282102, 0.10898989093090806, 0.03760356256472213, 0.0944160647424204, 0.09979993477463722, 0.0266868128175182, 0.1176201371209962, 0.07462175296885626, 0.04261223665837731, 0.13776597753167152, 0.07784790199782167, 0.021276406977059584, 0.03171730859737311, 0.08499341857220445, 0.03184162639081478, 0.0685188461627279, 0.06305369442062718, 0.062056349723466804, 0.01982549893935876, 0.056995645564581664, 0.05324309246082391, 0.08289774281105824, 0.03941684901448233, 0.02321130725821214, 0.11111202955778156, 0.06559429916420154, 0.01773888331704906, 0.016875567945784757, 0.0654468195778983, 0.050866744081888876, 0.05114781703533871, 0.04816581169143319, 0.1739911844155618, 0.284925783851317, 0.08875970861741475, 0.04469882683562381, 0.10769383476248809, 3.423271485737392, 22.88497771535601, 44.851775305611746, 51.270371777670725, 53.26400450297764, 48.26147174835205, 46.295253140585764, 42.667838369097026, 22.695997135979788, 29.88939939226423, 55.38937507356916, 67.42037200927734, 73.80152116503034, 64.83074365343366, 56.153082847595215, 81.82168088640485, 82.20923055921281, 83.27593190329415, 81.32706642150879, 79.57509899139404, 77.44594165257045, 73.2111952645438, 76.32168143136161, 74.95886175973075, 75.62938376835415, 75.62193529946464, 72.85863671983991, 74.58950941903251, 73.48614937918526, 73.8531184877668, 71.13873522622245, 73.55383178165981, 74.44712693350655, 74.64925003051758, 70.33412688119071, 69.91722106933594, 69.98554270608085, 70.61367375510079, 63.690321922302246, 28.62270109994071, 29.88739483697074, 48.85050875799996, 46.59729133333479, 20.024204594748362, 19.461136477334158, 18.687068939208984, 8.545618108340673, 12.913270507540021, 35.65129729679653, 8.658614924975804, 0.2964431829750538, 0.4880665476833071, 0.4575366516198431, 2.945895718676703, 5.752625099250248, 0.5786168287907327, 0.6644971604858125, 0.8720609141247613, 36.98126588548933, 11.939604674066816, 12.423897589956011, 5.939990222454071, 5.825167332376752, 11.927121366773333, 2.963036273206983, 6.0258669172014505, 2.451402630124773, 6.162160175187247, 3.2993625232151578, 0.4326788197670664, 0.8070301722202982, 2.884571352175304, 18.9511821269989, 9.008267385619027, 2.9333422780036926, 6.383666140692575, 9.171101893697466, 18.527515717915126, 19.927367550986155, 20.38811649594988, 19.769195284162247, 35.32061515535627, 51.39986188071114, 28.472461938858032, 21.316632066454204, 49.930387360709055, 70.49512359074184, 65.06033297947475, 67.02002375466483, 69.17684882027763, 69.95010689326695, 63.71751717158726, 66.14830275944301, 62.781282152448384, 64.23279557909284, 70.21601445334298, 70.2922361918858, 68.28904274531773, 69.7745259148734, 71.35731860569545, 68.59070573534284, 68.69308049338204, 73.70765100206647, 71.246981212071, 69.6791410446167, 69.55534499032157, 65.79420171465192, 67.36208357129777, 66.46657194410051, 62.52034255436489, 35.53220864704677, 55.64630208696638, 57.051186152866904, 45.88939149039132, 27.391914572034562, 18.636110850742885, 12.93264729636056, 16.53906982285636, 22.068300349371775, 14.59383303778512, 5.98779296023505, 0.11892031878232956, 0.09389543839331184, 0.10658746984388147, 0.0627630575160895, 0.10858946706035308, 0.023273299913853407, 0.09016013025705304, 0.09344942375485386, 0.02221708042946245, 0.059572694424007616, 0.03795433124261243, 0.03848728318033474, 0.059398561982171874, 0.0023657636567285018, 0.02731433048445199, 0.08425846336675541, 0.02962342756135123, 0.10823902407927172, 0.07405477589262383, 0.03539475805259176, 0.05936359028731074, 0.029985269930745875, 0.06897799045379673, 0.035765981168619225, 0.01984615184898887, 0.030754728641893183, 0.24770593962499074, 0.22716027923992702, 0.15810176703546727, 0.2115693629852363, 0.21126343868672848, 0.13541285879909992, 0.31911518211875645, 0.16858971997031144, 0.10120148278240647, 0.2324074719633375, 0.19771147945097514, 0.21743341189410004, 0.15939265276704515, 0.17837069369852543, 0.16461407473044737, 0.15611675355051244, 0.15669136414570467, 0.24060023948550224, 0.10069323969738823, 0.16474756971001625, 0.15355764515697956, 0.15514195657202176, 0.19280322854007992, 0.1442707942000457, 0.3408160348023687, 0.2487508292709078, 0.1254570401672806, 0.203791845323784, 0.17394633325082914, 4.041478770119803, 34.84366301127842, 66.44342054639543, 76.69587666647774, 79.01538685389927, 67.21383680616105, 58.78312887464251, 44.77692583629063, 22.770520039967128, 32.489981583186555, 68.5845913205828, 88.94589819226945, 81.24071420942033, 75.55116789681571, 66.023485319955, 84.86829226357597, 83.9982179914202, 85.45148236410958, 82.76145948682512, 78.94447353907994, 77.03065477098737, 75.9370083127703, 76.0056426184518, 75.8726749420166, 77.03377451215471, 78.5403802054269, 71.73771858215332, 74.10137067522321, 73.56655393327985, 74.65744195665631, 66.7734043938773, 75.36369855063302, 74.29996408735002, 74.30007525852749, 66.0474774496896, 72.1829035622733, 72.60140051160539, 71.37531444004604, 64.55490711757115, 47.21424967902047, 41.82499408721924, 52.78929315294538, 52.273041997637065, 23.500416142599924, 27.00149529320853, 22.498333045414515, 10.28730481011527, 18.787553787231445, 48.328052861349924, 10.083437715257917, 0.8563660191638129, 1.6832347639969416, 1.1470657289028168, 9.38282219001225, 9.475895915712629, 0.7002603528755051, 0.7066727802157402, 3.306635767221451, 55.462032386234824, 17.740600960595266, 38.140763895852224, 11.273123042924063, 4.6243327515465875, 15.76965410368783, 9.127448099000112, 4.665958975042615, 1.1069025354725974, 9.887352602822439, 6.2554071715899875, 6.934281349182129, 1.7138879363025938, 2.628056670938219, 29.619142259870255, 22.43940363611494, 11.965965270996094, 17.29050534112113, 17.829148803438457, 24.972242627825054, 30.61986698423113, 27.44862229483468, 23.163002933774674, 41.380795751299175, 53.39505795070103, 37.30820989608765, 35.24602624348232, 52.40603746686663, 69.4900736127581, 65.86504554748535, 64.1357500893729, 70.07153361184257, 68.76718997955322, 62.99805205208914, 65.43766185215541, 59.087828227451865, 61.99020195007324, 69.74944986615861, 69.64314937591553, 70.13932023729596, 69.35365962982178, 71.59453705378941, 69.22053214481899, 70.11730834415981, 73.59217888968331, 74.25867094312395, 72.80811636788505, 73.70233563014439, 69.68087114606584, 70.7267209461757, 69.78821386609758, 64.81283814566476, 42.05243641989571, 67.33203261239188, 67.45209053584507, 59.864192145211355, 41.00704172679356, 31.183841841561453, 32.04801361901419, 28.372861249106272, 31.707742963518413, 19.115302051816666, 5.154613188334873, 0.14454473235777446, 0.2672024220228195, 0.21273425833455153, 0.1312789520514863, 0.2612735458782741, 0.18554795214108058, 0.3224084111196654, 0.28006497610892567, 0.15462274157575198, 0.2591851236564772, 0.1835598581071411, 0.22705194433884962, 0.24900584987231664, 0.2557579789842878, 0.21521319103028091, 0.2008036585258586, 0.16140440053173474, 0.23993798930730137, 0.11664477017308984, 0.2216581744807107, 0.1908339706382581, 0.1830407923885754, 0.1797974899943386, 0.14198607179735387, 0.16528970561921597, 0.19593052858752863], [0.08258746910308089, 0.09901231846639089, 0.04902566144508975, 0.06222330326480525, 0.05617192780066814, 0.03596578259021044, 0.09090713624443326, 0.02571438392624259, 0.04287002228998712, 0.0809756905904838, 0.017771422463868345, 0.03368832390489323, 0.08879544705684696, 0.03699298282819135, 0.10476931490536247, 0.0626196830666491, 0.08706373069435358, 0.02151323775095599, 0.048678387222545486, 0.049837209683443816, 0.012029479324285473, 0.08168659851487194, 0.06475590808050972, 0.008374318048091871, 0.0869498046647225, 0.20532552445573465, 0.25924801028200556, 0.08932520648730652, 0.16885191947221756, 0.4801543408206531, 7.811894416809082, 22.91863305228097, 51.48557833262852, 59.20417581285749, 44.26395075661795, 37.65420239312308, 45.81404869897025, 35.92798498698643, 35.713438510894775, 39.20309829711914, 47.59343719482422, 65.32528863634381, 48.878037520817344, 50.30611119951521, 78.67452212742397, 75.97771780831474, 78.4383111681257, 77.103041103908, 79.75111770629883, 74.23567935398647, 76.01452936444963, 74.9735085623605, 76.23264026641846, 69.53283977508545, 74.6752849306379, 74.47028527941022, 75.45889581952775, 73.36075523921421, 75.08342906406948, 71.89954907553536, 71.9709140232631, 72.73449325561523, 73.09318705967495, 67.865800176348, 67.47545732770647, 66.50186879294259, 71.0724355152675, 66.49788052695138, 31.503889765058243, 32.50147042955671, 44.74190691539219, 28.440625292914255, 17.625681230000087, 22.352526835032872, 15.89064655985151, 5.0193274191447665, 8.086667009762355, 12.943240693637303, 6.25611458505903, 0.34490214554326876, 0.10385296693337814, 2.9066968049321855, 2.0230338105133603, 1.0859625105346953, 0.2506128379276821, 0.3644248736756188, 0.4568547510675022, 31.598096915653773, 8.424816727638245, 2.952017298766545, 5.9393627132688245, 7.01573725257601, 5.58715374980654, 4.5504008787018915, 0.8638686622892107, 5.074878701141902, 0.38877038444791523, 1.7096499694245202, 0.4328090984906469, 0.05567310956705894, 0.45688634365797043, 4.834580898284912, 3.4635760315826962, 1.7345574157578605, 5.610026785305568, 4.353124150208064, 16.936833347593033, 18.38887310028076, 21.814823116574967, 20.7371210370745, 13.054686324937002, 41.05534560339791, 39.63690560204642, 21.61954746927534, 53.72650439398629, 62.94968564169747, 66.88313034602574, 66.43661131177629, 71.10762814113072, 64.70141683306012, 64.71208231789726, 68.42884050096784, 64.97024263654436, 62.08945001874651, 69.5439429964338, 68.52428790501186, 65.59056391034807, 67.30928421020508, 67.94173009055001, 65.38685662405831, 67.671813419887, 68.64663873400006, 65.56671074458531, 68.38051577976772, 63.351694515773225, 64.72738225119454, 62.47743047986712, 63.877089500427246, 57.912154810769216, 27.003305298941477, 44.89636537006923, 39.95186744417463, 34.28188378470284, 19.6091730594635, 11.802681735583715, 6.927785652024405, 6.329682980264936, 4.015438224588122, 1.1063188867909568, 0.6109382201518331, 0.010026133519464304, 0.08368977638227598, 0.1271291540137359, 0.04572894816686, 0.09803823394966976, 0.05593653382467372, 0.030867453664541245, 0.10302600916475058, 0.06481863864298378, 0.0338757454550692, 0.06296824650572878, 0.1081187469618661, 0.08044661648039307, 0.020160488285390393, 0.08652618846723012, 0.07199805482689824, 0.1364730561950377, 0.017551850228171264, 0.13774672070784227, 0.018479823201362575, 0.03049780474975705, 0.2382549239056451, 0.03140459555600371, 0.01299354272694992, 0.026319635466539433, 0.06028685931648527, 0.038456956057676246, 0.028499617507415156, 0.056821350274341445, 0.04299660299771598, 0.04568491802949991, 0.1909475438296795, 0.03444269199722579, 0.02467189629429153, 0.008538138453981705, 0.10182331262954644, 0.05332214518317154, 0.029842536696898084, 0.049855635301875215, 0.07907019462436438, 0.07758591284177133, 0.009625519659104092, 0.048412795045546124, 0.05069144116714597, 0.04439840545611722, 0.00931282273294138, 0.024299974287194864, 0.06127045689416783, 0.05299754760095051, 0.08052137068339757, 0.0729932960655008, 0.25914012321404045, 0.17539625402007783, 0.051826274022459984, 0.12222266729388918, 0.13644758399043763, 10.377735614776611, 34.01049757003784, 64.09397057124546, 69.59694385528564, 59.42318998064314, 54.36881671633039, 65.8304226739066, 49.88531787054879, 44.90550225121634, 55.4543650490897, 64.8416245324271, 80.58754185267857, 65.72246156420026, 58.276101452963694, 85.06946345738002, 82.00761468069894, 87.02627767835344, 79.4339324406215, 82.79378250667027, 75.43733555930001, 77.93052986689976, 76.98708261762346, 79.2243400301252, 72.496718951634, 74.59316417149135, 75.2010829108102, 76.78623104095459, 73.89318180084229, 73.6100982938494, 74.21375778743199, 72.3562263761248, 73.56630379813058, 74.25043037959507, 72.30969429016113, 67.86858640398297, 67.45074953351701, 71.56175545283726, 70.2086980002267, 31.783989020756312, 33.21095446177891, 50.139225891658235, 33.22634819575718, 18.07302188873291, 20.97143166405814, 20.63095256260463, 8.6690320117133, 12.690447858401708, 18.743142638887676, 11.996204699788775, 0.30160683446696823, 0.26420267298817635, 0.4429486372641155, 2.435666045972279, 2.4748873242310117, 0.49711728202445166, 0.28166021193776813, 0.443743391760758, 34.46641404288155, 10.111921855381556, 10.496060831206185, 5.412815196173532, 6.678477338382176, 8.689101014818464, 6.053277560642787, 0.7690376937389374, 7.753007565225873, 1.4426288519586836, 3.289447226694652, 1.0955741490636552, 0.18800576882702963, 0.6765340460198266, 11.023654920714241, 6.76953478370394, 2.363170713186264, 2.7161945700645447, 8.188709122794014, 20.499765362058366, 18.109248059136526, 23.026437827519008, 21.693088940211705, 19.197183098111832, 49.70206260681152, 38.51289899008614, 20.855692046029226, 58.977275439671104, 64.03799588339669, 65.89420018877301, 67.9715656552996, 74.83794920785087, 66.5867132459368, 65.09614399501255, 68.3556968144008, 65.28849792480469, 64.48726640428815, 72.29645102364677, 69.84332002912248, 69.19642884390694, 70.04513740539551, 71.8301226752145, 67.80595534188407, 71.3907880783081, 72.30315603528703, 69.1054630279541, 70.77041816711426, 67.12908267974854, 67.57633127485002, 63.09595217023577, 65.5790160042899, 62.129492487226216, 34.45910106386457, 58.0840289252145, 52.57229048865182, 45.610998017447336, 31.73391682761056, 24.041340351104736, 11.844040019171578, 10.983041831425258, 13.728024959564209, 3.7106676527432034, 0.8408019457544599, 0.027472880369584476, 0.0754279000684619, 0.3245919096682753, 0.11278337665966578, 0.049716918995337825, 0.015578188634078418, 0.019759360434753553, 0.10462261563433067, 0.1089616095913308, 0.02744842766384993, 0.017395003465935588, 0.020521657208779027, 0.11547908772315298, 0.06074563041329384, 0.026923182187601924, 0.08176439255475998, 0.06616958150906221, 0.04869400370599968, 0.177303887371506, 0.04926552696685706, 0.05600297936637487, 0.04298146488144994, 0.05518563643896154, 0.03448762797883578, 0.11612894785191331, 0.01975412044807204, 0.15471532089369638, 0.2034247171665941, 0.10810046722846371, 0.3543870065893446, 0.1629912360970463, 0.21806470730475017, 0.1572008082377059, 0.16292997795556272, 0.10959975820566926, 0.20657933503389359, 0.1397427400307996, 0.2418083575155054, 0.10128431833748307, 0.19285337227795804, 0.20223331823945045, 0.14002412850303309, 0.24607110449245997, 0.19946929227028573, 0.20533372115875992, 0.25105567702225273, 0.18210252773548874, 0.11823931389621326, 0.1601971917386566, 0.164772594081504, 0.19152803053813322, 0.3010278269648552, 0.2256112787872553, 0.12271126679011754, 0.19767728128603526, 0.3364149481058121, 11.190343073436193, 48.85531343732561, 81.64281341007778, 93.44969967433384, 79.00175448826381, 68.03922721317836, 78.00909314836774, 54.552454130990164, 60.61557034083775, 71.82200717926025, 81.06640475136894, 94.59759766714913, 74.47801862444196, 64.00788239070347, 87.4301278250558, 86.26630456107003, 89.3868864604405, 82.1486770084926, 86.54283591679165, 76.21102442060197, 78.66913727351597, 78.84365517752511, 80.78512777600969, 71.12809753417969, 75.15314034053257, 77.78246375492641, 75.55004228864397, 73.84492656162807, 74.47136919839042, 73.1354112625122, 73.72445174625942, 74.88997037070138, 72.82557719094413, 69.16496740068708, 70.19707366398403, 66.21431064605713, 73.27671677725655, 69.40423556736538, 42.98621525083269, 47.202541964394705, 53.86170939036778, 40.85506725311279, 22.74429406438555, 28.622176510947092, 26.343273333140782, 8.48455560207367, 14.377852627209254, 35.086582456316265, 18.40250199181693, 0.3188415967992374, 0.4614202603697777, 6.098596317427499, 8.710396374974932, 2.591780777488436, 1.2321067942040307, 0.3273795757974897, 0.4819365537592343, 52.37772355760847, 15.648642539978027, 28.119005339486257, 17.86225696972438, 8.377887725830078, 14.63390156200954, 11.741375173841204, 0.7878794169851712, 7.866643616131373, 0.9807203177894864, 5.489372185298374, 1.9887685520308358, 0.30869462128196445, 1.2123876980372836, 11.162536382675171, 11.551477432250977, 12.3246990271977, 13.839085834366934, 17.521677119391306, 25.024150882448467, 26.483545303344727, 30.082858085632324, 29.607469286237443, 26.128855398723058, 54.07303885051182, 50.79826947620937, 33.06420155933925, 61.341928073338096, 62.22070843832833, 68.55862590244838, 65.55409281594413, 76.01581478118896, 65.6945367540632, 64.93025575365338, 64.75115898677281, 66.24962139129639, 62.829183033534456, 72.56211539677211, 69.45506164005825, 72.0792989730835, 70.22910485948834, 72.4461430140904, 68.82805619921002, 73.87654781341553, 72.54486996786935, 72.83503368922642, 75.50723443712506, 70.18923609597343, 71.88656984056745, 65.84142167227608, 68.45299938746861, 67.9853995186942, 41.85046965735299, 66.70950875963483, 60.235128675188335, 64.28219727107457, 44.9552652495248, 40.94401461737496, 30.41997425896781, 24.52585560934884, 22.094258819307598, 4.4507602368082315, 0.7245012064065252, 0.07547599463058369, 0.23768959566950798, 0.4061840628939015, 0.13778309018484183, 0.140195173610534, 0.15566856759999478, 0.11694807532642569, 0.27861662954092026, 0.15597401692398957, 0.1461733521095344, 0.17785240150988102, 0.2806232747222696, 0.38027694448828697, 0.139304854241865, 0.19087050296366215, 0.19025203186486447, 0.23752726295164653, 0.16945715913815157, 0.39561319297977854, 0.09620711899229459, 0.15805273609501974, 0.31274183839559555, 0.20355296028511866, 0.09392711919333253, 0.3240471546139036, 0.12769840418228082], [0.057257465086877346, 0.15641924446182592, 0.07569499859320265, 0.14582917200667517, 0.024301553577450768, 0.015435467274593455, 0.03940253531826394, 0.1183928120881319, 0.07386211944477898, 0.058256017576370916, 0.03297485790348478, 0.054924210466976674, 0.07273341036800827, 0.025744096974709203, 0.08387517929077148, 0.10045919939875603, 0.06235077285340854, 0.09603842161595821, 0.05839135817119053, 0.021696823881939054, 0.07228728037859712, 0.09618282743862697, 0.043623857732330046, 0.03384802390688232, 0.016119534049981406, 0.2656738726156098, 0.3858822137117386, 0.08661749213933945, 0.1241695878228971, 0.39485035677041325, 1.7227028118712562, 10.425574830600194, 45.404685156685964, 63.80468232291085, 61.42829418182373, 42.098582880837576, 37.178414072309224, 47.28186954770769, 52.69086844580514, 49.60140405382429, 54.05021054404122, 63.37322003500802, 52.118065902165, 48.87076275689261, 85.18264961242676, 76.1582042149135, 80.18405301230294, 73.61782469068254, 76.5618737084525, 77.1060288293021, 72.1224889755249, 75.31232357025146, 76.80358764103481, 71.54669175829206, 71.07588182176862, 73.81604290008545, 76.51024859292167, 69.47357164110456, 69.92775453839982, 73.0118236541748, 69.5105152130127, 71.26960454668317, 78.37868867601667, 69.92951938084194, 70.6940644127982, 69.56294631958008, 68.92221123831612, 66.40140478951591, 35.4541004725865, 30.77546841757638, 52.69060788835798, 16.4878112248012, 18.25247127669198, 20.84082637514387, 14.92335135596139, 10.83883023262024, 9.252877848488943, 0.2903740129300526, 1.1924111928258623, 0.4221049100160599, 1.5978946004595076, 1.9310952467577798, 0.2039393452661378, 1.5407011551516396, 0.10983904357999563, 0.24488532383527073, 0.2177370156028441, 21.964207649230957, 5.73591902426311, 5.123450951916831, 4.495306440762111, 5.67661224092756, 3.947267711162567, 3.5288076741354804, 0.8560091097440038, 4.324519719396319, 2.022172885281699, 1.1641394070216586, 0.05713553912937641, 0.33660637640527313, 0.2369743383356503, 1.6340905896254947, 0.20736775201346191, 0.19416036643087864, 4.4440730299268445, 6.81804450069155, 12.940427541732788, 19.54979201725551, 18.521321398871287, 22.608034678867885, 10.596495304788862, 29.08285423687526, 50.84039293016706, 19.334498609815324, 55.36239174434117, 66.43110833849225, 62.28390230451311, 71.0264870779855, 67.58774716513497, 64.99542985643659, 63.06146131243025, 64.03687722342355, 65.46690682002476, 64.81028120858329, 68.10315064021519, 69.30454281398228, 64.1341450554984, 65.06399468013218, 69.07403632572719, 66.18469742366246, 67.640761920384, 69.69538593292236, 64.79127093723842, 67.10853685651506, 62.87947409493582, 61.485589027404785, 64.21635614122663, 61.667451177324565, 56.548716749463765, 27.83311997141157, 46.31683424540928, 39.58794164657593, 33.27391903741019, 17.515621764319285, 11.918839114052908, 3.600557812622615, 1.2563746805701936, 1.2726259742464339, 0.323972651468856, 0.16228261483567102, 0.2690088450908661, 0.16525235905178956, 0.1727277657815388, 0.03717618389055133, 0.03648026141205004, 0.023425291758030653, 0.17472537287643977, 0.06825927259134394, 0.10795145415301834, 0.020897987997159362, 0.052366418431379964, 0.06946241017431021, 0.046188611537218094, 0.055709970981947014, 0.05168884014710784, 0.0778521089149373, 0.06820612294333321, 0.044574841524341276, 0.09465336200914212, 0.06277078602995191, 0.04344794413607035, 0.0933102969346302, 0.13470320616449627, 0.11450951546430588, 0.037349033901201825, 0.054237984253891876, 0.11268017826867954, 0.06238372251391411, 0.011070263206160494, 0.1020277077332139, 0.038900188702557764, 0.051772062467145066, 0.05767359704311405, 0.019348512569974576, 0.014838531180950148, 0.006258970708586276, 0.04274606072743024, 0.05563331348821521, 0.06602554888065372, 0.03525859982307468, 0.05846435496849673, 0.10541999606149537, 0.041459711002452035, 0.11204653512686491, 0.09710881739322628, 0.048603147867002656, 0.12472872781966414, 0.11153804098388978, 0.06570825233523335, 0.04310703117932592, 0.02453715450662587, 0.11029491733227458, 0.25731429404446055, 0.07729569662894521, 0.07662811316549778, 0.2258809693157673, 2.3473240435123444, 17.24393504006522, 54.33774784633091, 67.6592024394444, 66.8515716280256, 59.143927982875276, 60.38963576725551, 72.31823362622941, 64.39045020512172, 58.87945869990757, 65.04195499420166, 79.33704675946916, 62.596237727573936, 60.70514651707241, 90.53488172803605, 83.12674018314907, 87.31560066768101, 81.080808367048, 80.31324086870465, 81.89732592446464, 76.53037752423967, 77.80372524261475, 78.35294560023716, 72.09448773520333, 73.6371545791626, 73.79840837206159, 77.82573018755231, 68.32650743212018, 72.75547681535993, 74.7153343473162, 72.35596929277692, 73.52183532714844, 75.65859399523053, 71.77218164716447, 70.07413223811558, 71.6883794239589, 70.11912182399205, 69.91223921094621, 39.812566484723774, 30.177631514413015, 56.042571749006, 22.668801886694773, 20.578054189682007, 20.64646441595895, 17.692227602005005, 12.90007414136614, 12.252442973000662, 2.2950974745409827, 2.5008049735001157, 0.49635656284434454, 1.150631023304803, 3.2379232943058014, 0.5200954633099693, 1.369020830307688, 0.11687530923102583, 2.363625603062766, 0.4745512157678604, 29.163621834346227, 7.658467769622803, 14.499887313161578, 7.441944531032017, 10.15743863582611, 9.716386965342931, 6.884764577661242, 0.7845397761889866, 4.650280799184527, 1.4381266364029475, 1.7858818045684268, 0.15725309614624294, 0.24259157691683086, 0.7136636993714741, 2.5687194892338345, 1.426988022668021, 1.8445480508463723, 0.5345515161752701, 12.684382949556623, 16.028245210647583, 21.103207724434988, 20.64791485241481, 25.423865113939556, 14.365087049348013, 35.47826630728585, 50.093941007341655, 18.956499235970632, 59.05220481327602, 66.67162023271833, 64.54048960549491, 71.39062132154191, 67.97522040775844, 67.94496100289481, 64.45361627851213, 65.88410445622036, 70.39593805585588, 70.00531727927071, 69.92355782645089, 72.21291978018624, 69.74660110473633, 69.59337942940849, 69.5550184249878, 72.07992431095668, 69.0943181174142, 73.18594551086426, 66.78855146680559, 70.6946828024728, 67.3198802130563, 66.79540933881486, 64.54359545026506, 65.00002261570522, 56.08890233721052, 33.84235463823591, 60.70368044716971, 55.282616002219065, 44.51546859741211, 32.10163286754063, 22.011660371507915, 9.41613359110696, 4.408997654914856, 3.1391277270657674, 1.6899967725787843, 0.04130487270387156, 0.4754103496670723, 0.6089901732546943, 0.43484812336308615, 0.2192419519914048, 0.022937888179772666, 0.04498575893895967, 0.19088043671633514, 0.12977740833801882, 0.12064185711954321, 0.05980104859918356, 0.019480918500838534, 0.07173422684094735, 0.14770959610385553, 0.05948449165693351, 0.003523148471556072, 0.09947408190263168, 0.01249234622810036, 0.07563559285232, 0.011395497763130282, 0.08188034061874662, 0.05359169661200472, 0.11850899085402489, 0.11818953656724521, 0.14289701863058976, 0.016701328634683574, 0.13587281054684094, 0.20161331365151064, 0.27081781945058275, 0.14464218355715275, 0.23026536405086517, 0.1639657209494284, 0.14416646265557834, 0.11625639029911586, 0.26959262947951046, 0.16147070697375707, 0.13890101734016622, 0.14345512725412846, 0.14880351669022016, 0.14256966619619302, 0.142678204657776, 0.18633700694356645, 0.26770755063210216, 0.12506347628576414, 0.22896390674369677, 0.16408002695866994, 0.09540668515754597, 0.19365788410816873, 0.2374109077666487, 0.1392235250345298, 0.14463709454451287, 0.18641279930514948, 0.2616823496563094, 0.3414133627499853, 0.1788887416145631, 0.12201951390930585, 0.4023052310304982, 2.413790511233466, 19.82233336993626, 62.51338740757534, 85.94179589407784, 87.88677733285087, 79.87286404200962, 80.81729098728725, 87.31401647840227, 76.21955680847168, 71.1681330544608, 79.47343989780971, 90.383515221732, 77.35917254856655, 69.1432751246861, 95.59711687905448, 86.90004975455147, 88.10019125257219, 83.61594894954136, 82.10495894295829, 83.05115073067802, 77.91368743351528, 79.55967399052211, 80.1537171772548, 74.3625465120588, 76.55915696280343, 73.98853887830461, 80.39318684169224, 66.38927323477608, 73.48847702571324, 72.04341152736119, 74.8685073852539, 71.78647409166608, 76.87224279131208, 69.82380948747907, 73.42265674046108, 70.38719722202846, 71.63209206717355, 65.70864159720284, 49.52021435328892, 42.04723916734968, 63.117936270577566, 27.85240990774972, 28.992777790342057, 26.15835050174168, 23.37241816520691, 15.127214976719447, 14.376668827874319, 4.827538899012974, 5.028228061539786, 0.3634048184113843, 4.472448604447501, 8.900721430778503, 0.3671852626970836, 4.260407822472708, 0.17675671673246793, 3.150398139442716, 0.5274971947073936, 44.9518849509103, 9.583546962056841, 24.232106617518834, 13.009451815060206, 9.223778792790004, 20.904107093811035, 12.15651614325387, 1.5872725418635776, 6.499613770416804, 6.198679038456508, 2.262759472642626, 0.12661137751170568, 0.6071130739791053, 1.0517126683677946, 3.848842569759914, 2.1249871168817793, 2.9391474979264394, 12.25121922152383, 21.95470772470747, 18.26031752995082, 27.97027220044817, 26.26918121746608, 33.596440519605366, 20.854826995304652, 43.689390318734304, 61.9176002229963, 29.857927526746476, 62.59650175912039, 67.23239544459751, 63.57988725389753, 71.13272503444126, 70.04709679739815, 65.39780698503766, 63.48175784519741, 65.41095297677177, 70.67426899501255, 70.0283922467913, 67.31478023529053, 70.67110756465367, 70.29661355699811, 70.12675094604492, 71.98571368626186, 72.88205909729004, 72.15473556518555, 76.4960742677961, 71.41050706590924, 73.15403243473598, 69.91562298366001, 71.19124971117292, 68.01554775238037, 66.54086208343506, 59.75971903119768, 42.15339721952166, 67.22846971239362, 67.20590891156877, 56.6482948575701, 47.55219963618687, 44.909681592668804, 26.615458590643748, 10.88505138669695, 6.703149088791438, 1.0787545144557953, 0.19971417555851595, 0.32193316519260406, 0.5853739519204412, 0.5425683259963989, 0.37481566039579256, 0.23315109206097467, 0.19596862154347555, 0.33788335216896875, 0.18466265393154963, 0.2510567626782826, 0.13320276167775902, 0.20774545174624237, 0.08893557810889823, 0.31000951358250206, 0.19735930620559625, 0.10790293889918498, 0.1886020518307175, 0.16890442451196058, 0.1539660689554044, 0.2199027772460665, 0.13880933368844645, 0.21189465267317636, 0.19023187937481062, 0.19551226603133337, 0.1652823638703142, 0.10817486859325852, 0.23692656947033747], [0.09274329271699701, 0.10093278970037188, 0.023692682052829435, 0.1922923188124384, 0.13210436276027135, 0.04311017279646226, 0.07223822908209902, 0.024497012374922633, 0.06708614661225251, 0.053873688980404816, 0.10457030736974307, 0.128857803397945, 0.10225488804280758, 0.05760490894317627, 0.0542063441659723, 0.12048054220420973, 0.06061211507767439, 0.1676140816083976, 0.07103088458201715, 0.06698690408042499, 0.034055862575769424, 0.05871672249798264, 0.12082119392497198, 0.05227549813155617, 0.031183406710624695, 0.1437033625053508, 0.09252083501113312, 0.08601687329688243, 0.06251899525523186, 0.07977827305772475, 0.4908866477864129, 3.803763960089002, 29.71845633643014, 53.72862706865583, 65.27324662889752, 49.17015716007778, 40.48451287405831, 43.007483686719624, 39.18511288506644, 49.171835150037495, 59.41819422585623, 63.8458434513637, 49.705078125, 49.97928878239223, 84.03220163072858, 79.47379425593785, 83.57468359810966, 76.59808771950858, 78.58115918295724, 77.34349741254533, 77.46742548261369, 75.04515838623047, 76.37309115273612, 73.19223363058907, 75.60148675101144, 74.07050677708217, 76.23947729383195, 71.90509373801095, 71.50339753287179, 74.69183553968156, 74.45675018855503, 70.19540609632219, 72.14757197243827, 74.10631779261998, 70.3667208807809, 66.5512843813215, 67.30585874829973, 77.67856039319719, 35.53939308438982, 28.694731337683542, 50.267322880881174, 10.108109031404767, 21.531223705836705, 18.96055177279881, 21.07885602542332, 11.364269512040273, 10.184316873550415, 2.552270931856973, 1.1548018966402327, 0.7856992025460515, 1.444356347833361, 0.2922281234392098, 0.555967818413462, 0.7792150133422443, 0.16570841600852354, 1.0538724724735533, 1.2977624940020698, 12.397887877055577, 6.899547304425921, 8.697626454489571, 3.4643053753035407, 7.211544437067849, 8.55561830316271, 3.9847384776387895, 1.6467878797224589, 3.031412627015795, 3.62478574684688, 1.3973448361669267, 0.08602165696876389, 0.12081537209451199, 0.2416379638016224, 0.19439698516258172, 0.049368996771850755, 15.456910473959786, 8.647001879555837, 10.02160222189767, 14.748362711497716, 20.29013647351946, 18.220881291798182, 22.19420518193926, 15.485703808920723, 18.406894990376063, 48.97499615805489, 24.67541037287031, 46.30915996006557, 72.25252451215471, 58.28478670120239, 69.11933858054024, 71.7869257245745, 64.96974236624581, 66.38950947352818, 69.21432740347726, 68.73467241014752, 68.12228597913469, 66.92311028071812, 69.4562428338187, 68.02191230228969, 68.78294154575893, 68.50540964944022, 66.97817475455147, 64.2828642981393, 66.35482406616211, 61.17052296229771, 68.67199271065849, 61.35635948181152, 63.89581489562988, 55.19869218553816, 63.4394085747855, 50.10169172286987, 26.407908950533184, 54.80807835715157, 37.989994934626985, 30.958824430193218, 17.196836675916398, 10.949876342500959, 0.903594607753413, 0.4362755710525172, 0.4892488270998001, 0.40942216770989553, 0.14146801031061582, 0.5006256880504745, 0.6800355038472584, 0.19195309201521532, 0.12969907825546606, 0.04644089424982667, 0.07253605845783438, 0.13031212107411452, 0.08608087271984134, 0.2793366637613092, 0.10313254594802856, 0.09853965097240039, 0.02629645840663995, 0.027471976221672127, 0.03966066361005817, 0.005215162477855171, 0.10365204592900616, 0.10094972593443734, 0.09748260197894913, 0.0833700710375394, 0.10817645636520215, 0.18290298192628793, 0.029939417926860706, 0.12340871936508588, 0.11404676815228802, 0.04283424653112888, 0.066537578191076, 0.029561480706823722, 0.03758905887869852, 0.11389139720371791, 0.21171090539012635, 0.025263897742011716, 0.09715997214828219, 0.037209571206143925, 0.07061747355120522, 0.03249116421544126, 0.15422711494777883, 0.06944520252623729, 0.06483353248664311, 0.07676695500101362, 0.028460401576012373, 0.016117807178358947, 0.0998724837388311, 0.08445475676230021, 0.23470151743718556, 0.00970820932915168, 0.1004254287108779, 0.026262407823066627, 0.02879817970097065, 0.048113398253917694, 0.04857658661369767, 0.09286653503243412, 0.09402024812464203, 0.06731617676892451, 0.028879115357995033, 0.029253554730010883, 0.05996771715581417, 0.3774254417845181, 7.041639702660697, 33.70637839181082, 58.07844952174595, 70.94747911180768, 57.15896313531058, 58.06654378346035, 70.06495366777692, 56.51813077926636, 59.37869371686663, 70.36470590318952, 75.96693420410156, 64.12298624856132, 56.08142607552664, 96.07117857251848, 83.19980049133301, 88.95126914978027, 80.79101290021623, 88.2938792364938, 79.54021903446743, 83.52018192836216, 80.01931817190987, 81.62320559365409, 72.20552689688546, 79.69162722996303, 75.12084511348179, 75.68227345602853, 73.24271924155099, 74.8728222165789, 74.82729067121232, 74.12234728676933, 72.91455582209996, 73.51175349099296, 72.29948043823242, 72.96735518319267, 67.45792702266148, 68.76748180389404, 75.09349700382778, 40.9821115902492, 28.25492947442191, 56.991615772247314, 13.927285398755755, 23.58565490586417, 18.98559308052063, 22.62303410257612, 11.410115463393074, 12.717432056154523, 5.148722418716975, 0.5606675690838269, 0.2978965507021972, 2.2254897696631293, 0.9104213214346341, 1.142087236046791, 1.6197261661291122, 0.3495606412844998, 1.5318262428045273, 1.9125125067574638, 22.4446964263916, 3.727000262056078, 26.029548270361765, 12.265076535088674, 8.522873180253164, 13.918918899127416, 4.33396405833108, 2.9476994276046753, 4.472776906830924, 0.5951279742377145, 0.4799604969365256, 0.3072403036057949, 0.16400437030409062, 0.9895721056631633, 1.7474919216973441, 0.4610242673328945, 19.46382543018886, 15.987968240465436, 18.5207325390407, 16.94730601991926, 22.3799444266728, 20.178180149623326, 22.072809730257305, 21.227577005113872, 22.450416530881608, 52.84981196267264, 26.86782237461635, 51.3827588898795, 71.35278143201555, 62.50229113442557, 71.12823649815151, 74.12179837908063, 66.95757334572929, 68.84432193211147, 71.19543947492326, 70.47526563916887, 71.81671265193394, 70.54399027143205, 73.25140448978969, 72.98513562338692, 72.96075439453125, 73.48501682281494, 72.07553999764579, 66.41935198647636, 73.35705184936523, 66.84537383488247, 70.03199141366142, 66.73985154288155, 68.72131102425712, 54.49142810276577, 62.30924933297293, 51.19413961683001, 36.344168186187744, 67.52849292755127, 46.9147823197501, 45.853913988385884, 31.703084196363175, 24.36680613245283, 1.8028727556977953, 0.3687494487634727, 0.936276165502412, 0.625046863087586, 0.18593166369412625, 0.6731922339115823, 1.025431324328695, 0.268249510122197, 0.30884183623961037, 0.020312525930681398, 0.12102554153118815, 0.19960479571350984, 0.1794369707682303, 0.36367218835013254, 0.06182950868138245, 0.030590743691261326, 0.03002081498769777, 0.07108735905161925, 0.02064684352704457, 0.06451944541186094, 0.03824714285188487, 0.10278941078909806, 0.049860089884272644, 0.041279702447354794, 0.2017216756939888, 0.05783278135848897, 0.1570586280098983, 0.14762374785329613, 0.0847550288641027, 0.014030171209014952, 0.09146923465388161, 0.14816120187086718, 0.1553213612309524, 0.2037871362907546, 0.2522569011364664, 0.15403627018843377, 0.1900017610085862, 0.19717770309320518, 0.13992736940937384, 0.21069816473339284, 0.12496709717171532, 0.17007868364453316, 0.16811831455145562, 0.20865919414375508, 0.09112820295350892, 0.09165825415402651, 0.30511898600629395, 0.11338403621422392, 0.2344605289399624, 0.1378805956670216, 0.2045563371585948, 0.1352781153150967, 0.1313454077712127, 0.17409710373197282, 0.09348490435097899, 0.19404425551848753, 0.19704989423709257, 0.21128422899969987, 0.08926871166165386, 0.13510878011584282, 0.08917850721627474, 0.5995363891124725, 5.940525233745575, 36.306189332689556, 63.23646559034075, 83.53966467721122, 78.07187012263707, 85.66825226375035, 89.94407640184674, 67.53145286015102, 69.89390986306327, 79.6545238494873, 89.86209460667202, 78.87286540440151, 64.30057525634766, 99.65777615138462, 84.50312273842948, 91.17305987221854, 83.77213055746896, 89.99464539119175, 81.14412035260881, 82.93055084773472, 82.48444870540074, 82.50986521584647, 71.98535932813371, 80.01941544669015, 76.41813632420131, 77.77480684007917, 71.8976800101144, 75.0418232509068, 73.44004113333565, 75.7915894644601, 72.87755666460309, 75.42976897103446, 71.86653123583112, 75.28612191336495, 63.666920389447895, 70.78962298801967, 72.89299556187221, 50.5380733353751, 38.864328452519004, 64.25843443189348, 19.6147837298257, 32.46979706627982, 24.45850498335702, 30.74723093850272, 14.9229223046984, 19.729762520108903, 8.595880508422852, 1.9947020964963096, 3.1003934741020203, 6.156760556357248, 0.3948326605771269, 4.0854269947324475, 2.482117141996111, 0.6425881875412804, 4.3614585144179205, 4.239527182919638, 33.09017392567226, 9.626186319759913, 24.594081708363124, 15.224831955773489, 11.88112689767565, 31.752628326416016, 13.570876683507647, 4.044739212308611, 3.7290773391723633, 9.989512835230146, 1.873432798045022, 0.5258440119879586, 0.36914004066160744, 1.239686084645135, 2.8180119522980283, 0.4769005754164287, 26.756197827202932, 22.882620538984025, 22.437605789729528, 22.686881099428447, 29.81085000719343, 24.73299183164324, 29.958599976130895, 26.36341094970703, 32.4207740511213, 59.354277747017996, 37.46384607042585, 54.79844467980521, 72.73887756892613, 62.73476396288191, 70.9821367263794, 71.92090088980538, 65.8663101196289, 69.65842846461705, 70.35535362788609, 71.41675349644252, 72.7973188672747, 69.11964430127824, 73.39720548902238, 71.8603264944894, 75.12756402151925, 74.57417474474225, 73.67354229518345, 69.21341024126325, 74.08550098964146, 69.90545082092285, 73.54736995697021, 71.51969105856759, 74.78590025220598, 62.28247792380196, 64.62337466648647, 56.88727467400687, 42.37305062157767, 74.67818232945034, 62.0069123676845, 57.26506560189383, 47.95270422526768, 38.483525480542866, 15.734006370816912, 1.7279108124119895, 1.0739102086850574, 0.41235748305916786, 0.14770370641989367, 0.46118733286857605, 0.9091446442263467, 0.40595246532133644, 0.42671550118497437, 0.09400528642748084, 0.18088561589164392, 0.34357577243021553, 0.2173584880573409, 0.34293952371392933, 0.24540044048002788, 0.1187396656189646, 0.10907895543745585, 0.20140798895486764, 0.10568725743464061, 0.12970599931265625, 0.1557830228869404, 0.12555617413350514, 0.12988503756267683, 0.18185391250465596, 0.17798296521816934, 0.20678407619042055, 0.22369204248700822, 0.19843521847256593, 0.14292006167982305, 0.08127772009798459, 0.11918223329952785], [0.01990624121390283, 0.09628046862781048, 0.08495788369327784, 0.07338888198137283, 0.05279522542176502, 0.13475021507058824, 0.030156606808304787, 0.025511976930179765, 0.02179804434334593, 0.12470542692712375, 0.0383275560369449, 0.027689750339569788, 0.046162755960332494, 0.02853433135896921, 0.060538589023053646, 0.23577566551310675, 0.03131648099848202, 0.07710747780012232, 0.04499793864254441, 0.027274346112140586, 0.05808756447264126, 0.03377157675900629, 0.03473024496010371, 0.08329850594912257, 0.06428032288593905, 0.2015685031988791, 0.030167962091841867, 0.028640057292899916, 0.25627274279083523, 0.12133667697863919, 0.210952615365386, 0.1120170256389039, 5.028363985674722, 23.322986943381174, 44.11901133401053, 53.752063342503135, 38.46814216886248, 32.47009583881923, 29.520880835396902, 40.586366517203196, 59.78057057516915, 61.08430276598249, 49.28278398513794, 40.80216714314052, 89.67623724256242, 75.46625396183559, 83.81618213653564, 78.88034166608537, 80.447174344744, 78.45391682216099, 78.81377792358398, 75.34552901131767, 76.656327520098, 75.191404070173, 73.03705951145717, 75.74620383126395, 72.54968506949288, 71.42066533224923, 68.2723809650966, 72.84982640402657, 72.37377752576555, 76.50803906576974, 75.70322922297886, 72.99293845040458, 72.2658997944423, 74.78756087166923, 62.781032017299104, 75.99128069196428, 37.220165797642295, 35.0422043119158, 37.60467563356672, 14.218570385660444, 27.801985093525477, 16.52208842550005, 22.111102989741735, 11.152891414506094, 5.419272243976593, 2.109222957066127, 0.46360948575394495, 0.925234717982156, 1.192479046327727, 0.5749030709266663, 1.5923044489962714, 0.6147684689079012, 0.26346306981784956, 0.05334487610629626, 0.16515787983579294, 13.06222425188337, 1.227849936911038, 24.40515845162528, 6.33469740833555, 2.8843613862991333, 7.45019725390843, 4.670698515006474, 3.8938868727002824, 6.6404072897774835, 0.7790784920964922, 0.07734651890184198, 0.434211223253182, 0.2853510896010058, 0.2312093691102096, 0.2772266369845186, 0.3521716168948582, 12.363369226455688, 8.934454934937612, 12.316268256732396, 22.420075484684535, 20.586673430034093, 19.822524445397512, 24.683009965079172, 19.096946648189, 22.764006103788102, 34.775303159441265, 28.368421350206646, 39.671632698604036, 74.39023508344377, 60.28865759713309, 69.59071826934814, 66.42128358568463, 69.37749195098877, 63.77915464128767, 69.96230098179409, 63.198729923793245, 70.60756628853935, 68.85722473689488, 72.09300082070487, 64.90797288077218, 69.72561059679303, 63.46753488268171, 69.1621881212507, 64.7304186139788, 67.43881947653634, 58.81818948473249, 70.27183628082275, 62.31376566205706, 61.63992936270577, 48.47494125366211, 68.34068870544434, 40.59229333060128, 39.47329289572579, 57.977610315595356, 32.64448520115444, 32.19256394250052, 22.55769498007638, 9.85182820047651, 0.30316358378955294, 0.4079207597034318, 0.3792457883911473, 0.4465142030801092, 0.4705033472606114, 1.3020413901124681, 0.7232398369482586, 0.42184041706579073, 0.08965131720261914, 0.044970240843083174, 0.14665091862635954, 0.11526773763554436, 0.2984948014574391, 0.2746081160647528, 0.021770512784964273, 0.09927294376705374, 0.06873008768473353, 0.08066403945641858, 0.06772566586732864, 0.057920950198812146, 0.027942260361409614, 0.15378323090927942, 0.16799406121884072, 0.09630040398665837, 0.06429084696407829, 0.13330380911273615, 0.23560092917510442, 0.08116880844214133, 0.0203387563981648, 0.0932786161346095, 0.11305623594671488, 0.004719211902868534, 0.0796459587290883, 0.11512653449816362, 0.285334723336356, 0.0020647116637389573, 0.05674160883894988, 0.043520611843892505, 0.013962359267420002, 0.0325934092647263, 0.11579327657818794, 0.03908874340621488, 0.020163222781515548, 0.08460278596196856, 0.0933472363810454, 0.033276673672454696, 0.05051157510440264, 0.08635157426553113, 0.04447226060022201, 0.009112083236686885, 0.08300231184278216, 0.037624278238841465, 0.05846605130604335, 0.032862241446439705, 0.09131272376648017, 0.18917302547820977, 0.0835617028975061, 0.08785967941262893, 0.03516164056158491, 0.060751255468598435, 0.15231194985764368, 0.12569146044552326, 1.4425160522971834, 13.28974301474435, 30.503293582371303, 62.998045103890554, 62.777981758117676, 52.97363928386143, 53.24253109523228, 54.69385344641549, 51.55055441175188, 69.76701491219657, 76.3043109348842, 67.48022379193986, 50.1015180179051, 89.5257670538766, 87.10742568969727, 88.54495239257812, 80.85966110229492, 85.68085629599435, 86.19905294690813, 80.71265806470598, 78.18049131120954, 80.91242572239467, 75.78181334904262, 74.90053858075822, 73.46476977212089, 75.00214208875383, 69.04130336216518, 71.16975198473249, 74.51109204973493, 74.22880758558, 75.74641227722168, 79.24719265529087, 72.93758215223039, 74.04406193324498, 75.2954602922712, 66.25254658290318, 74.53047057560512, 39.359307697841096, 36.624903202056885, 45.652141775403706, 17.62690758705139, 28.290294068200247, 18.356096710477555, 25.488273177828106, 14.505131466048104, 11.331829241343907, 3.7607441885130743, 0.38069872185587883, 1.4326756660427367, 2.47410717180797, 0.3985631918268544, 1.135046865258898, 0.9241873856101717, 0.3743404144687312, 0.19198349038405077, 0.5205714691962514, 18.339718069349015, 1.3506830143077033, 40.61946773529053, 13.169294255120413, 7.416066833904811, 13.531511664390564, 8.081364665712629, 3.9918629867689948, 6.701918823378427, 1.6422932637589318, 0.31234969943761826, 0.6065757285271371, 0.5837779832737786, 0.7484801997031484, 0.4755597902195794, 0.20006231830588408, 15.152186802455358, 11.857640249388558, 17.006454297474452, 25.8233448437282, 21.890080792563303, 21.301330396107264, 26.57418976511274, 23.866409029279435, 28.642548629215785, 40.86517688206264, 33.98904153278896, 43.56220701762608, 77.99004118783134, 62.37046296255929, 70.2435084751674, 68.71345955984933, 69.87881142752511, 69.28359399523053, 72.08246040344238, 64.91947909763881, 74.37368447440011, 71.78716891152519, 74.97208418164934, 68.18051188332694, 75.95164816720145, 67.25367777688163, 75.12687614985875, 68.83543518611363, 73.6743413380214, 63.463497979300364, 74.56954724448067, 65.28135517665318, 67.02069772992814, 50.23751163482666, 70.7952093396868, 41.79615906306675, 49.64665767124721, 65.98210184914726, 43.71350056784493, 45.85537658418928, 37.23963117599487, 10.891668677330017, 1.0647947149617332, 0.47557341520275387, 0.31495730951428413, 0.5296586815799985, 0.6037260442972183, 1.3293385824986865, 0.6910679404224668, 0.456802313881261, 0.022063195472583175, 0.019280728617949144, 0.1102235625897135, 0.09869204315223865, 0.28243547890867504, 0.28931245846407755, 0.09936188613729817, 0.0433449526982648, 0.1118829267631684, 0.08021789589630705, 0.013590386370196939, 0.016269495378115346, 0.024773951353771344, 0.10918987555695431, 0.17946746413196835, 0.03714754971276436, 0.04881432492818151, 0.04076693692643728, 0.22193416181419576, 0.11238177213817835, 0.038543530340705595, 0.05511240215439882, 0.16588053320135387, 0.11866358827267375, 0.18473660067788192, 0.2340372587953295, 0.4886498163853373, 0.09129398262926511, 0.17662642443818705, 0.22849997878074646, 0.10881226403372628, 0.1277369721127408, 0.1652950117630618, 0.09935714996286801, 0.125399201842291, 0.19177190959453583, 0.1086411103606224, 0.1559562257358006, 0.3234304477061544, 0.281012835247176, 0.12727360054850578, 0.08267533938799586, 0.20382060163787433, 0.11805587873927184, 0.1614596332822527, 0.26470739447644775, 0.16426040870802744, 0.30890852266124313, 0.36421602059687885, 0.1327584840889488, 0.09096703731587955, 0.24312835239938327, 0.22165387256869248, 0.305450898196016, 0.8582572862505913, 10.133558545793806, 29.551522391183035, 68.41166455405099, 78.23709828513009, 77.52469948359898, 77.12858268192836, 73.04181207929338, 64.50717299325126, 86.93190724509103, 87.51786967686245, 84.87060601370675, 58.11208227702549, 98.33587442125592, 90.62973853519985, 90.44549315316337, 84.8440499986921, 89.03578008924211, 87.57386520930699, 82.57150963374546, 80.60616302490234, 82.84622750963483, 77.00455038888114, 76.42422294616699, 75.16204793112618, 77.75674847194126, 69.02182061331612, 72.73668193817139, 73.75404412405831, 77.8994505746024, 75.52199241093227, 78.29248237609863, 71.66684695652553, 74.38866479056222, 75.99001611982072, 67.30755410875592, 72.56115654536656, 46.45320653915405, 47.77880123683384, 51.66228491919381, 23.09843679836818, 34.34947238649641, 23.275867734636577, 31.38621507372175, 19.00427678653172, 18.78254587309701, 10.873390572411672, 1.0754283900771822, 4.386110288756234, 4.286085324628012, 2.0631220936775208, 3.623754156487329, 1.0000024374042238, 0.955887998853411, 1.7212364162717546, 0.28123542187469347, 29.216692175183976, 2.8922693048204695, 50.84118849890572, 20.8702380997794, 8.607006311416626, 28.659665516444615, 16.081775869641984, 8.005949786731176, 11.889205915587288, 8.50586485862732, 1.1279230075223106, 1.2208282394068581, 1.0247273849589484, 0.7764289485556739, 0.8399783128074237, 0.8056135539497647, 25.568955659866333, 19.90651774406433, 20.43599305834089, 31.20626367841448, 28.621347938265117, 27.709054674421036, 34.129051208496094, 28.81029725074768, 37.55275174549648, 50.29419503893171, 41.92806019101824, 48.26721443448748, 80.02885110037667, 61.73727362496512, 68.93611458369664, 66.79414476667131, 70.96138940538678, 66.73937211717877, 75.19939449855259, 68.29019614628383, 74.13918277195522, 70.33303601401192, 77.47508239746094, 67.0276459285191, 76.52374199458531, 70.81132221221924, 79.26504257747105, 67.46263790130615, 77.48767948150635, 69.18088572365897, 75.43333339691162, 69.2871514729091, 75.80007321493966, 54.30944435937064, 69.21864918300084, 46.536397320883616, 52.4721565246582, 81.93879972185407, 53.58520930153983, 59.62160273960659, 52.6524657521929, 34.934792109898154, 1.324473432132176, 0.6870537815349442, 0.24911783529179438, 0.47910380576338085, 0.3855551869741508, 1.4030577753271376, 0.8909056772078786, 0.463839590549469, 0.20552789073969635, 0.10162367405635969, 0.22143372866724217, 0.20508020690509252, 0.34714893783841816, 0.2330490675355707, 0.1400056994919266, 0.27155991962977816, 0.13001359280730995, 0.23847539350390434, 0.116596092070852, 0.1547004474060876, 0.06796603689768485, 0.23863446925367626, 0.24351131756390842, 0.2536759078502655, 0.1695339557315622, 0.16065647852207932, 0.24904162223849977, 0.1295674288911479, 0.1185627036861011, 0.13932280827845844, 0.2943684943020344], [0.07638913991728, 0.10804351778434855, 0.08356247642742735, 0.12196679173835687, 0.04918735973270876, 0.1957387203084571, 0.05332985673365848, 0.07561576605907508, 0.18152007327548095, 0.12116670395646777, 0.026935344927811196, 0.021359432521941404, 0.1082821653357574, 0.028130786227328435, 0.11487706431320735, 0.1571346375026873, 0.053901166255984984, 0.07742584643087216, 0.0740650285567556, 0.0914159764402679, 0.07359858322888613, 0.04132606674517904, 0.046777359409523864, 0.057940458080598285, 0.09573787810014826, 0.10588759489889656, 0.04195490246638656, 0.0278454011838351, 0.09550184290856123, 0.21551330706902913, 0.2578222725008215, 0.1455738257084574, 1.0677861315863473, 7.737645098141261, 12.477140767233712, 23.52847123146057, 21.20310718672616, 14.626869985035487, 24.13572120666504, 36.298153741019114, 51.71016148158482, 66.27244622366769, 56.933921405247276, 34.7231638772147, 77.92074680328369, 87.92725058964321, 73.4698350088937, 82.43332386016846, 82.033705166408, 82.07283742087228, 83.58325072697231, 76.8330271584647, 81.16039303370884, 77.43633924211774, 72.86739145006452, 75.09298283713204, 73.93904685974121, 72.53100136348179, 71.58906187329973, 75.57240159170968, 71.1714334487915, 74.56964451926095, 72.82531315939767, 70.78801100594657, 71.9271125793457, 69.75102710723877, 67.46650804792131, 76.15117958613804, 33.21855231693813, 38.076037951878135, 28.320306812013897, 19.64143180847168, 27.359930276870728, 19.868747336523874, 23.1756260735648, 13.463196975844246, 6.657938897609711, 1.1210212750094277, 0.28666872318301884, 1.5666475743055344, 0.6888365373015404, 0.11341632091041122, 0.43630968779325485, 1.0934977233409882, 0.1404681618192366, 0.15279934156153882, 2.6094715424946378, 4.698938599654606, 0.4268690400889942, 32.4837212562561, 3.227342490639005, 7.741601228713989, 12.679984739848546, 5.659243047237396, 1.5289910520826067, 12.165535773549761, 2.815288475581578, 0.924893279160772, 0.37276138205613407, 0.20646464904504164, 0.24943563395312854, 0.08268815012914793, 1.371245122381619, 6.924798795155116, 2.1610156978879655, 29.89894274302891, 28.921607392174856, 23.97973414829799, 22.293036358697073, 21.6469372681209, 25.650127989905222, 20.875539575304302, 26.33403049196516, 28.540957280567714, 37.404577936444966, 66.25233118874687, 62.191025733947754, 69.02008356366838, 65.6159109388079, 63.72498648507254, 68.19400528499058, 70.28281443459647, 62.59950338091169, 69.20619801112584, 69.98678643362862, 67.53405843462262, 63.60271208626883, 71.59893526349748, 65.16750199454171, 66.68111842019218, 70.88081114632743, 66.71823569706508, 66.42217295510429, 69.87764413016183, 59.400976589747835, 60.93219975062779, 53.09159885134016, 71.81456565856934, 35.11271463121687, 52.031091826302664, 50.20198549543108, 28.519428287233623, 33.52776105063302, 18.14347835949489, 1.7070225732667106, 0.2963493008698736, 0.2392165165926729, 0.3209066774163927, 0.5604948954922813, 1.372148062501635, 0.645083025097847, 0.25696563561047825, 0.21323486790060997, 0.015456554446635502, 0.04231718249086823, 0.1780073789081403, 0.42263123605932507, 0.2399893408375127, 0.12286585063806602, 0.0911361485985773, 0.06111070939472743, 0.16143687521772726, 0.024194049881771207, 0.04967433413756745, 0.06190144696405955, 0.14066679616059574, 0.09172474380050387, 0.1959685944020748, 0.05412372913477676, 0.143458167091012, 0.15946992433496884, 0.18088895428393567, 0.027323495796216384, 0.0964408064527171, 0.10382303675370556, 0.10458330810070038, 0.11468659953347274, 0.21324447595647403, 0.021999306311564784, 0.17343378146844252, 0.0964695695521576, 0.09457220243556158, 0.0685011703254921, 0.01746835988680167, 0.04791778339339154, 0.0866650031613452, 0.06884148277874504, 0.04088233198438372, 0.06138702921037163, 0.04760703471090112, 0.08184951477284942, 0.07036133336701564, 0.08624493570200034, 0.017006813581766825, 0.05161505285650492, 0.05510009692183562, 0.048928098287433386, 0.08274518099746533, 0.05135505520073431, 0.01754117856866547, 0.0629561957237976, 0.02582827942179782, 0.015521061074520861, 0.05231432729799833, 0.04399302149457591, 0.2341810810778822, 0.07696396764367819, 0.44034289994410103, 2.6515947793211256, 11.210617916924612, 24.414753913879395, 41.32817356927054, 30.41070188794817, 27.59466995511736, 49.85442270551409, 59.7898394720895, 58.69283703395298, 75.69112546103341, 69.47553103310722, 50.297224453517366, 83.46006611415318, 93.18577235085624, 83.56644998277936, 89.95212936401367, 82.378634589059, 87.57733236040387, 86.59179987226213, 79.688722882952, 85.61873940059117, 79.57721124376569, 72.49829619271415, 79.25202860151018, 76.88239410945347, 75.67831298283168, 70.4228206362043, 79.93817710876465, 72.99154881068638, 76.0630555834089, 75.6987406866891, 78.69941752297538, 72.09631511143276, 73.03459984915597, 66.8332075391497, 80.28564957209996, 35.996317046029226, 41.16690240587507, 34.16809661047799, 24.320854221071514, 27.63731278691973, 22.702462434768677, 23.17445182800293, 18.657049247196742, 13.09452382155827, 9.46768227645329, 1.5242819104875838, 0.8982684335538319, 1.0731170283896583, 0.9722275563648769, 0.4242368127618517, 1.2482813319989612, 0.16037898484085286, 0.23692176544240542, 5.562201031616755, 13.21674176624843, 0.5643867009452411, 36.57594966888428, 6.2690156527927945, 13.559434737477984, 27.520393712180002, 5.372562978948865, 1.6414274530751365, 9.369750891413007, 4.4310807670865735, 1.2653594613075256, 0.21175642151917728, 0.5024616409625325, 0.27960251378161566, 0.14781052140252932, 1.6472784876823425, 12.661601543426514, 4.948348096438816, 31.818563256944927, 28.423438923699514, 23.475279297147477, 22.75017397744315, 25.96573427745274, 25.890052761350358, 28.5518433707101, 32.644387926374165, 35.23725414276123, 43.131078243255615, 68.26671818324498, 65.05334309169224, 68.71097210475376, 67.64332580566406, 69.1568032673427, 69.72157369341168, 71.77166053227016, 67.01672336033413, 70.8785321371896, 73.18793269566127, 71.57882717677525, 67.6222310747419, 74.02369676317487, 70.13895198277065, 71.5901596886771, 74.6191712788173, 71.42059585026333, 71.49675505501884, 73.45686967032296, 64.02100058964321, 64.53861359187535, 55.56463990892683, 72.71326650891984, 38.824918270111084, 62.0930700302124, 58.02181128093174, 38.61920295442854, 46.20332499912807, 26.996127809797013, 1.564437830022403, 0.09308811064277377, 0.14240075168865068, 0.12579338997602463, 0.4651728304369109, 1.0151619953768594, 0.7582102833049638, 0.3511381266372544, 0.09831770895315067, 0.06485287073467459, 0.05014533243541207, 0.13639612389462336, 0.18446844363851206, 0.3123246750661305, 0.11614287139049598, 0.11889049038290977, 0.09956988426191465, 0.07070351179156985, 0.09363802934863738, 0.03888257732614875, 0.048566907311656644, 0.027960758922355514, 0.16329866674329552, 0.17494637173201355, 0.05558368543695126, 0.0627888147053974, 0.1701353413185903, 0.1811647651983159, 0.05027647629114134, 0.055952737240919044, 0.11738589326185839, 0.0907719720687185, 0.38284940645098686, 0.1848430492516075, 0.16063282479132923, 0.3170087108654635, 0.282450868082898, 0.22685914539865085, 0.11526943397309099, 0.15503311955503055, 0.21808354343686784, 0.15412092421736034, 0.09697013840611492, 0.09795611764171294, 0.22092181470777306, 0.15465087363762514, 0.2621154449880123, 0.27564771313752445, 0.2321801355906895, 0.22249387178037847, 0.18943620207054274, 0.2465192633015769, 0.20559065522892134, 0.11260348345552172, 0.12257720184113298, 0.13526978290506772, 0.12526835314929485, 0.22352088881390436, 0.1386434454470873, 0.15087394416332245, 0.15497357132179396, 0.3965158888271877, 0.528083014701094, 0.6665148522172655, 2.4880252821104865, 10.554829563413348, 21.972317934036255, 41.837236813136506, 46.47827216557094, 63.288340841020855, 77.4326080594744, 80.73029259272984, 70.77020972115653, 96.36448287963867, 87.88372707366943, 60.631801332746235, 86.387911932809, 97.07412324632917, 87.35203007289341, 89.09249128614152, 86.66773673466274, 90.22083009992326, 86.46387658800397, 81.70493725367955, 88.64078194754464, 78.10677787235805, 73.89726734161377, 81.01095812661308, 76.28922639574323, 75.45413630349296, 71.5904654094151, 77.44439915248326, 72.31921332223075, 77.26757444654191, 77.81564140319824, 76.18551063537598, 71.66704845428467, 70.05297497340611, 66.90373870304653, 78.21762248447963, 41.68694032941546, 50.32853651046753, 43.681347778865266, 28.766976969582693, 33.990417276109966, 29.911150727953228, 29.506921904427664, 24.223242453166417, 21.657178912843975, 18.09147456714085, 6.928770559174674, 6.028359583445957, 3.1356990081923346, 0.573575530733381, 0.38441459674920353, 2.192266958100455, 0.3144211582839489, 0.18702030527804578, 6.524007158620017, 26.68157591138567, 0.43292824923992157, 62.61752700805664, 9.36046462399619, 13.715341891561236, 45.76802730560303, 9.292446102414813, 5.199218017714364, 23.976803745542252, 8.889108385358538, 1.4164282807282038, 0.4991305225661823, 0.6583835056849888, 0.3323485963046551, 0.26643299045307295, 2.4707190564700534, 20.553019830158778, 8.298714739935738, 41.2548040662493, 35.915321895054404, 31.1722001348223, 30.09223120553153, 31.24033417020525, 35.381842681339805, 36.56570455006191, 40.7831186567034, 44.107036113739014, 48.966981410980225, 69.33314159938267, 64.33124460492814, 68.63961410522461, 66.3924207687378, 68.11458042689732, 72.46346487317766, 75.49442890712193, 69.39863531930106, 72.05720370156425, 76.08234378269741, 74.45813982827323, 68.2603119441441, 79.3921320778983, 74.21895503997803, 72.29189995356968, 73.21617712293352, 76.76480974469865, 71.15719658987862, 76.46570369175502, 67.91834940229143, 72.96497889927456, 54.62423249653408, 74.67201927730015, 41.89500413622175, 71.76673425946916, 70.2808758871896, 46.56172350474766, 61.09160532270159, 48.863418510981965, 6.166134979043688, 2.0325964859553745, 0.26441662865025656, 0.23805386040891918, 0.4136414613042559, 0.8540702366403171, 1.0453825337546212, 0.3731417959289891, 0.6003066077828407, 0.16622851310031755, 0.14579377962010248, 0.40790952316352297, 0.2872648297676018, 0.3537954869014876, 0.25204194124255863, 0.2390718257852963, 0.13262562693229743, 0.17128534960959638, 0.15558394071246895, 0.10952109564095736, 0.14284572138317994, 0.21004098999713147, 0.2992333189717361, 0.37779888031738146, 0.104995362061475, 0.2559690847992897, 0.22881785886628286, 0.26812142985207693, 0.17146138873483452, 0.30774491652846336, 0.18030886112579278, 0.15511086609746727], [0.10184198591325964, 0.09497122852397816, 0.10495604774249451, 0.16857655639094965, 0.34152597242168015, 0.0718693978020123, 0.1966856023562806, 0.029502685647457838, 0.058930237112300735, 0.15097720362246037, 0.052361407450267246, 0.11391596017139298, 0.07915011926421098, 0.07606151606887579, 0.09201276155986957, 0.0872310913567032, 0.23112699495894568, 0.02542746369726956, 0.030847280818436826, 0.06867040374449321, 0.03918814878644688, 0.03825123102537223, 0.07858072660331215, 0.06307835916855506, 0.08444098928677184, 0.007652310987136194, 0.06809660739132337, 0.04079277553994741, 0.09754207557333366, 0.24355452667389596, 0.3194611535540649, 0.3095339962414333, 0.12030075756566865, 0.9586124526602882, 7.208322644233704, 14.294857263565063, 11.675555757113866, 12.124803696359907, 11.678551299231392, 24.381986209324428, 35.634229046957834, 54.54775367464338, 60.49075290134975, 36.817726135253906, 62.908656529017854, 85.0591036932809, 80.68947192600795, 86.55828871045793, 78.29271166665214, 88.00360434395927, 75.18322604043144, 80.09162112644741, 75.48789760044643, 75.52559157780239, 74.03168719155448, 79.42198153904506, 78.41681344168526, 70.74546023777553, 66.42289556775773, 72.41407707759312, 70.87482179914201, 71.0777508871896, 75.27766595567975, 71.76072406768799, 72.68931606837681, 73.21430110931396, 69.55809647696358, 70.31761796133858, 33.043999671936035, 30.994819572993688, 23.54073132787432, 21.893928357533046, 26.719718047550746, 27.039807660239084, 19.099807568958827, 18.796155657087052, 5.447841933795384, 4.214820257255009, 4.872436855520521, 0.7200289006744112, 0.09264368377625942, 0.3857649900019169, 0.5319096807922635, 0.577235820037978, 0.11577254054801804, 2.141807185752051, 2.7843546611922125, 7.1218123606273105, 1.0310862894569124, 18.3720897265843, 2.6126861699989865, 6.75820357458932, 26.190769059317454, 6.315472611359187, 0.3180702653314386, 16.84093257359096, 10.492869002478463, 0.5839162958519799, 0.6702377295919827, 0.4300219751894474, 0.2512424370007855, 0.6271638923457691, 1.7236513495445251, 6.57941643680845, 8.049323916435242, 30.92639718736921, 30.0740373475211, 22.557807888303483, 19.879105363573345, 25.991550309317454, 27.0174275125776, 20.014840160097393, 22.41606637409755, 27.932908262525284, 30.896926403045654, 64.95101697104317, 70.35115691593715, 61.58269705091204, 61.802475520542686, 66.0833718436105, 64.79867771693638, 60.57901586805071, 64.45338003976005, 66.3301649093628, 68.0621771131243, 65.15614863804409, 64.50497041429792, 62.874957765851704, 65.80812590462821, 71.92954444885254, 67.55825206211635, 64.0598896571568, 71.60003307887486, 63.4125120980399, 65.13891015733991, 58.79587187085833, 73.01745169503349, 64.24909605298723, 32.68851246152605, 64.615127154759, 39.470270429338726, 30.568884577069962, 34.84637975692749, 3.1635558562619344, 0.15285521213497433, 0.14529141943369592, 0.24136497559291975, 0.41132003015705515, 0.285291677074773, 0.517163866332599, 0.3301139904984406, 0.1467216626874038, 0.026294494047760963, 0.13762402800577028, 0.057317081173615794, 0.05175164195575884, 0.19014315413577215, 0.1185744966247252, 0.06358257854091269, 0.19350916280278138, 0.03824631843183722, 0.0465014738562916, 0.10269643113549266, 0.014548089355230331, 0.04042835134480681, 0.07109924019979579, 0.1405637538326638, 0.0478886369216655, 0.09110009124768631, 0.0884067482714142, 0.23025051770465715, 0.11845301171498639, 0.13751120120286942, 0.09023624831544501, 0.07810440859092133, 0.12523522706968443, 0.027028631618512527, 0.1980086099356413, 0.12037945405713149, 0.14862944531653607, 0.22544321923383645, 0.16016658980931553, 0.11236413022769348, 0.08493054551737649, 0.08322151936590672, 0.09025310991065842, 0.08086138458124228, 0.07480626021112714, 0.12027771451643535, 0.09001830965280533, 0.09633792018783943, 0.13728131353855133, 0.1273483886782612, 0.07409573905169964, 0.07229952115033354, 0.046541755087673664, 0.03898150773186769, 0.03155212942510843, 0.08175385490592037, 0.10362330318561622, 0.05161284761769431, 0.01208774936718068, 0.03420596469991973, 0.03257291750716312, 0.07600768110049622, 0.33437027782201767, 0.29833320155739784, 0.5123232517923627, 0.5663465272103037, 3.013657374041421, 6.626885661057063, 17.698976039886475, 21.938537529536656, 20.21399290221078, 15.977038724081856, 46.52107654299055, 63.53132629394531, 65.28793512071881, 67.71329416547502, 41.092876298086985, 76.47572299412319, 93.07665089198521, 80.77641473497663, 96.58398342132568, 85.07871150970459, 89.22474329812187, 80.07955210549491, 82.7917536326817, 75.55694184984479, 77.63343184334892, 75.953524180821, 79.3324887411935, 84.03047847747803, 69.41283743722099, 70.1348386492048, 74.32631860460553, 75.56321607317243, 70.37339115142822, 77.10178347996303, 74.07000650678361, 78.03828947884696, 72.44387095315116, 76.61222730364118, 68.93334920065743, 37.754666396549766, 39.152320861816406, 28.937228679656982, 28.5469240461077, 27.419922760554723, 29.15036814553397, 17.471901961735316, 26.517509835106985, 17.74438599177769, 10.302506600107465, 5.091989508696964, 1.9996455226625716, 0.26740584682141033, 0.530590608716011, 0.4026380388864449, 1.2429035348551614, 0.610003687441349, 5.9509870495115, 17.304717881338938, 11.619855523109436, 0.6763880252838135, 27.143057891300746, 1.9780602923461368, 11.739969900676183, 50.48658718381609, 9.592308640480042, 0.5385879852942058, 23.28608332361494, 10.47611950125013, 0.2783346032457692, 0.33590762104306904, 0.3335012101701328, 0.7119488513895443, 0.34452200308442116, 3.3518720141478946, 8.213627099990845, 9.296311906405858, 38.07435996191842, 28.949962990624563, 23.161828688212804, 18.62742039135524, 30.324412209647043, 28.25457685334342, 27.266886949539185, 31.499363013676234, 33.7475186756679, 38.038316181727815, 63.724972588675364, 72.19493089403424, 62.884872845241, 66.04644216809953, 69.1562613078526, 69.6296420778547, 64.66634927477155, 67.99033968789237, 67.87930747440883, 71.40222481318882, 68.11736665453229, 69.20202909197126, 64.64991678510393, 68.40132563454765, 74.34354318891252, 73.00213091714042, 69.00151797703334, 75.23387145996094, 65.60629463195801, 68.60642256055559, 60.133726664951865, 75.1266121183123, 64.76070581163678, 39.735851424080984, 75.51503031594413, 45.4723675591605, 43.035411970955984, 44.662332671029226, 4.616203793457576, 0.16275140110935482, 0.25345473257558687, 0.3045768365263939, 0.3937663292246205, 0.2529221097273486, 0.7022039485829217, 0.3201509251126221, 0.06984307510512215, 0.10125560952084404, 0.06125843325363738, 0.029595631374312297, 0.1007911048031279, 0.14338397607207298, 0.11518597416579723, 0.003180083498591557, 0.20238391230148928, 0.11883506764258657, 0.03890518272029502, 0.08939742975469146, 0.07441340200603008, 0.044728560240140984, 0.05639209205816899, 0.06645877991936036, 0.07988145787801061, 0.15005503382001603, 0.11685195405568395, 0.15769634236182484, 0.17631526184933527, 0.09998914426458733, 0.0842486856771367, 0.15464529607977184, 0.05377453126545463, 0.09549224163804736, 0.3561801846538271, 0.13960612379014492, 0.3687645122408867, 0.45649241336754387, 0.18563909296478542, 0.20228031357484205, 0.13705526638243878, 0.12047857445265565, 0.14371968805789948, 0.17570658879620688, 0.2404802744942052, 0.16117996828896658, 0.16616584360599518, 0.18113204623971665, 0.22770777557577404, 0.37389304276023594, 0.12920095212757587, 0.19931906461715698, 0.22185268332915647, 0.11982939285891396, 0.14574956627828733, 0.15306363095130238, 0.2539894724530833, 0.14045554106788977, 0.08154048278395619, 0.11171959659882955, 0.11149363086691924, 0.1838235096739871, 0.6099388737763677, 0.889189852135522, 0.676090881228447, 0.2202560090060745, 2.3596794605255127, 8.28110887323107, 20.492127554757253, 22.85596377508981, 21.075315918241227, 57.13213961465018, 75.93839795248849, 81.7500171661377, 75.39281845092773, 96.13201699938092, 65.12458992004395, 86.86466257912772, 92.03695719582694, 85.22295611245292, 98.14726557050432, 82.60759162902832, 89.94208226885114, 81.16584736960274, 80.25860023498535, 78.7460468837193, 81.49615083421979, 77.68427876063755, 80.90390723092216, 85.00695746285575, 70.55772686004639, 71.82179873330253, 75.67766680036272, 77.59575176239014, 70.84350626809257, 76.14257771628243, 76.7117533002581, 76.7438748223441, 72.14060987745012, 73.08651678902763, 69.2142162322998, 45.06177071162632, 46.97161511012486, 36.54822983060564, 33.078469685145784, 33.68575961249215, 36.73045676095145, 26.97159024647304, 32.55085475104195, 21.399395533970424, 20.842195170266287, 13.470799173627581, 4.357543204511915, 0.2693101689219475, 1.0413472588573183, 4.116521920476641, 1.8283196645123618, 1.7568200954369135, 5.952058809144156, 30.0204667363848, 18.17941791670663, 0.7106436757104737, 42.6456423486982, 2.978574399437223, 16.518068892615183, 65.42632934025356, 18.418145860944474, 2.7426005474158694, 33.04476049968174, 17.06096465247018, 0.63004712334701, 0.6789620614477566, 0.41508910219584194, 1.73520870081016, 0.5634298037205423, 5.527129130704062, 18.184048891067505, 13.580088257789612, 49.115711075919016, 42.499181270599365, 33.369015557425364, 25.959152596337454, 38.780415058135986, 37.78689561571394, 32.96158014025007, 38.62772839409964, 42.81916666030884, 44.16963243484497, 70.57712623051235, 71.29996817452567, 65.27654007502964, 66.84745134626115, 72.57533087049211, 71.74292278289795, 66.64992100851876, 70.53471442631313, 72.2149556023734, 73.39341177259172, 72.26357909611293, 71.77414798736572, 69.73010608128139, 73.28545761108398, 78.23044885907854, 75.35112231118339, 71.56198474339077, 74.35605689457485, 73.04006808144706, 74.11619118281773, 60.0550730569022, 74.04838371276855, 68.26940018790108, 43.41486004420689, 87.7110504422869, 53.32706982748849, 54.40804624557495, 60.81045341491699, 25.61683222225734, 0.33714757593614714, 0.3840021017406668, 0.1729983112641743, 0.3019452063100678, 0.16393106138067587, 0.6842333557350295, 0.5213411450386047, 0.3457371507372175, 0.26323369784014566, 0.22898111439176969, 0.19889633730053902, 0.17942055022077902, 0.2778444295482976, 0.2820152486009257, 0.2273862585425377, 0.32523510658315247, 0.21415224724582263, 0.20388841442763805, 0.20119354474757398, 0.17598875079836163, 0.1339442240340369, 0.1817243258867945, 0.27803477219172884, 0.14883624921951974, 0.10270903831613915, 0.2082933552031006, 0.3201166998062815, 0.2506130822002888, 0.17170701841158525, 0.38289554683225496, 0.16603974465812954, 0.1600720291691167], [0.056842191477439234, 0.17179300236914838, 0.07645974148597036, 0.044137210186038695, 0.1778636109083891, 0.18130151714597428, 0.02244628107707415, 0.11460451036691666, 0.07149098560746227, 0.09555327586297478, 0.13919658719428948, 0.18439239343362196, 0.2697106402899538, 0.09279522778732435, 0.13029795326292515, 0.03208659788859742, 0.08865093266857521, 0.1032042196020484, 0.01879752517145659, 0.023682061283450042, 0.1286409707473857, 0.019755238334515264, 0.2190466017595359, 0.005832705255930445, 0.058690537831612995, 0.05806460963296039, 0.09358360405479159, 0.007304988418971854, 0.046449321654758284, 0.14888494089245796, 0.11414020242435591, 0.6152022970574242, 0.5306125932506153, 0.08296552845942122, 1.481495120695659, 5.918461229119982, 7.25148355109351, 9.038232360567365, 9.711748174258641, 12.704906191144671, 24.6630425793784, 38.49280827386038, 53.46989004952567, 30.186615535191127, 50.63598040172032, 82.6511081968035, 79.32931341443742, 92.88225419180733, 88.3682666506086, 79.71247877393449, 78.87714549473354, 80.96163286481584, 75.6430995123727, 79.13415241241455, 76.08271898542131, 76.77536405835832, 74.41679109845842, 75.50153691428048, 76.76948588235038, 74.41086428506034, 72.59489004952567, 73.94163158961705, 71.05819170815604, 73.82299109867641, 70.45870808192662, 62.71721976143973, 72.81373051234654, 58.973412241254536, 28.363210201263428, 27.624675750732422, 22.719318764550344, 19.17882595743452, 27.87209415435791, 28.248002120426722, 25.162117787769862, 15.389288868222918, 4.330857345036097, 4.2197156974247525, 7.152741398130145, 6.468554888452802, 2.5744560956954956, 0.8914202781660217, 0.12301678396761417, 0.6303153889519828, 3.828630260058812, 13.389523489134652, 11.361967921257019, 14.214873944010053, 0.5588024663073676, 11.00303874697004, 1.486478064741407, 4.953334297452654, 39.12922157560076, 21.472132750919886, 4.328084145273481, 19.156900916780742, 11.165944474084036, 14.214461394718715, 2.0618542645658766, 0.7698545413357871, 0.6355784865362304, 5.468702597277505, 3.1480989371027266, 2.402467118842261, 3.5632012571607317, 12.401006749698094, 29.886651379721506, 25.673034463609966, 24.269574778420584, 28.673640080860682, 18.941899333681377, 14.732486077717372, 24.06652409689767, 23.304218121937343, 28.877790314810618, 41.39986855643136, 72.09587042672294, 59.30007484980992, 71.6892340523856, 58.57533604758126, 65.56194428035191, 62.699439321245464, 63.33412252153669, 63.22819028581892, 64.20734432765416, 61.79707677023751, 67.19956520625523, 63.103303364345, 68.91207381657192, 70.04827104296002, 73.0039930343628, 68.71412658691406, 69.04001794542584, 57.40824365615845, 68.56794343675885, 60.64837278638567, 80.91069562094552, 43.98055458068848, 42.45184319359915, 56.49574368340628, 28.30547935622079, 42.46607657841274, 15.24890398979187, 1.880907539810453, 0.2366128691605159, 0.08231655042618513, 0.3458109753472464, 0.2684706582554749, 0.5749171301722527, 0.45077977276274134, 0.029006578161248138, 0.040532825381628106, 0.1342196821102074, 0.039767814467528036, 0.04221513760941369, 0.10728559416851827, 0.06932182450379644, 0.06458084604569844, 0.038295977017177005, 0.047089997812041214, 0.08218695702297346, 0.14790197435234273, 0.014847521769947239, 0.05178211496344634, 0.05251461387212787, 0.0651558909033026, 0.044330575702978034, 0.18193034268915653, 0.3014844267496041, 0.22983178017394884, 0.06325534824281931, 0.050486849288323095, 0.03287777311301657, 0.27547894790768623, 0.158663987581219, 0.10435329830007893, 0.029014768078923225, 0.07393472947712455, 0.12827534893793718, 0.08459638059139252, 0.12744189080383095, 0.16308035488639558, 0.1768822728523186, 0.07465855670826775, 0.1497677420931203, 0.07266887490238462, 0.1415738889149257, 0.1966864980225052, 0.17091330885887146, 0.03131163286577378, 0.08893909292029482, 0.10553521130766187, 0.02638403861783445, 0.0984786031767726, 0.05558969386454139, 0.024246599026290432, 0.02172139533130186, 0.019831074800874506, 0.02802813405703221, 0.07072926219552755, 0.09912577630685908, 0.03840562827619059, 0.020715813219015087, 0.07053448871842452, 0.08722033657665763, 0.20423923060297966, 0.16841867486281054, 0.21608054877391883, 1.1176088409764426, 0.8747188714998109, 2.1984706137861525, 7.482708743640354, 16.768766845975602, 20.649158579962595, 12.286776627813067, 9.76913160937173, 39.68289920261928, 67.48652580806187, 57.125441551208496, 37.11166967664446, 50.19944592884609, 102.69308280944824, 81.2823964527675, 94.94075529915946, 96.03351933615548, 85.52450793130058, 82.7166644505092, 87.76460715702602, 79.85913440159389, 77.19132491520473, 80.04674965994698, 76.82753113337925, 75.29814229692731, 82.24661881583077, 78.47713075365338, 76.60838494982038, 77.07362243107387, 77.32875333513532, 72.2831174305507, 76.43301241738456, 71.46924713679722, 68.68342249734062, 71.47245025634766, 66.6387552533831, 31.393038204738072, 36.99145194462368, 33.857845646994456, 23.210241998944962, 25.51945321900504, 28.03009966441563, 24.984655584607804, 20.868181432996476, 10.245721578598022, 7.521485771451678, 9.747240441186086, 9.014871648379735, 2.9903754804815565, 1.1948897455419814, 0.3200914040207863, 2.126378276518413, 4.170790391308921, 26.949765954698833, 23.04149978501456, 15.265284367970057, 0.2339273632637092, 17.551177433558873, 2.3715578402791704, 8.886652197156634, 50.86133132662092, 26.16051139150347, 3.753808149269649, 21.56011778967721, 21.906947544642858, 11.219303165163312, 2.888384393283299, 1.310658024890082, 3.593962235110147, 13.675658123833792, 2.2333603416170393, 3.3179535142013004, 7.1393192155020575, 18.29704049655369, 28.692744152886526, 25.87609383038112, 22.017634085246495, 27.002528837748937, 24.539632150105067, 19.774903229304723, 36.16211496080671, 31.581584521702357, 38.43919249943325, 43.32611070360456, 78.05840451376778, 64.59374754769462, 78.01552023206438, 66.46701662881034, 67.69746616908482, 67.36941392081124, 67.39022377559117, 68.20347567967006, 70.83808667319161, 67.0677717753819, 69.10926369258335, 66.17484487806047, 73.27131802695138, 71.70896693638393, 74.82199614388603, 71.69191605704171, 71.87211758749825, 59.1821083341326, 69.85327679770333, 62.533905438014436, 82.67466953822544, 46.38354390008109, 53.958178179604666, 61.75101021357945, 40.818700381687705, 52.98875508989607, 18.153363909040177, 1.737404765827315, 0.20660073602838175, 0.09516590700617858, 0.21686070119696005, 0.15292955243161746, 0.3929427777017866, 0.4606713205575943, 0.048380225364650996, 0.07126626837998629, 0.10812619049102068, 0.053840970021805594, 0.028846711918179477, 0.12693723716906138, 0.1364870068750211, 0.10161314319287028, 0.05618252991033452, 0.015924540048997318, 0.06116754348788943, 0.14238661101886205, 0.030829655871327435, 0.03464344676051821, 0.03981862995507462, 0.16412096976169518, 0.06469743871795279, 0.07530676799693278, 0.28545550256967545, 0.2789067711148943, 0.05795750966561692, 0.04238237274278488, 0.1660139603274209, 0.07516973784991673, 0.07814757698880774, 0.22516309283673763, 0.08641259491975818, 0.2650352083146572, 0.2023966551891395, 0.22413878994328634, 0.17411617056599685, 0.29822395741939545, 0.2168488132634333, 0.22078438422509603, 0.2233908407922302, 0.11118913827730076, 0.2635394185781479, 0.44662141161305563, 0.35605158869709286, 0.19317377651376383, 0.21434581971594266, 0.12553281895816326, 0.20908996888569423, 0.29714679664799143, 0.17314761610967772, 0.10450054718447582, 0.20756027953965323, 0.09889617362724883, 0.1549777239561081, 0.0993871751374432, 0.2037576607295445, 0.15571075890745434, 0.1389002709516457, 0.13303155372185366, 0.1459818288151707, 0.2865810293172087, 0.6452517903276852, 0.9803300244467599, 0.9978165775537491, 0.7932236130748476, 2.5350413535322462, 5.7489911913871765, 13.615691695894514, 24.78095350946699, 15.644308601106916, 57.32034894398281, 64.58621570042202, 85.76978628976005, 76.96702316829136, 54.96602480752127, 68.45998927525112, 101.97513239724296, 84.45626408713204, 105.61749621800014, 95.92958123343331, 86.87202766963414, 84.5436793736049, 87.45314025878906, 76.91721153259277, 80.00706849779401, 78.51906313214982, 76.73893465314592, 78.25222451346261, 80.69545432499477, 75.30373559679303, 75.87015969412667, 77.20631912776402, 79.74480179377964, 71.86916460309709, 77.76161915915353, 75.2606428691319, 65.89608315059117, 72.66653292519706, 69.15929767063686, 36.98726912907192, 45.06362240655081, 33.8664996283395, 28.408972774233135, 34.50896828515189, 37.248799324035645, 38.12826408658709, 26.347549949373516, 15.251441819327217, 15.747531039374215, 10.842267853873116, 7.764260172843933, 3.8235094376972745, 1.2969809302261897, 0.277571115642786, 6.569298556872776, 8.894373382840838, 41.22513178416661, 37.23998206002371, 18.241359370095388, 0.3286998149539743, 26.75799741063799, 3.3363034895488193, 17.567908695765905, 65.68225233895438, 36.027674266270225, 5.315883917467935, 26.281460421425955, 34.439114570617676, 15.963937895638601, 3.62755069562367, 0.8666618381227765, 3.7556016530309404, 17.28666125025068, 8.529360192162649, 3.538047258343015, 13.078303251947675, 27.619582721165248, 49.3777345929827, 38.905447891780305, 34.115314619881765, 41.66527237210955, 31.85461745943342, 27.851921796798706, 37.41278028488159, 41.829322814941406, 47.42770528793335, 50.832367760794504, 77.19151946476528, 64.30108942304338, 76.79864052363804, 68.0295970099313, 71.8938237598964, 66.92313112531389, 69.82160690852574, 70.83706528799874, 73.78449807848249, 71.26178087506975, 76.9759099142892, 70.22072533198765, 73.52913788386753, 78.25234263283866, 81.37468937465123, 70.69696181161063, 75.74077728816441, 65.85519995008195, 70.89832755497524, 62.02346992492676, 84.4566809790475, 52.409980569567, 63.67616844177246, 71.41110461098808, 50.25438533510481, 66.47866875784737, 48.85940940039498, 3.685862583773477, 0.4291750549205712, 0.2181931132716792, 0.23251280773963245, 0.1423751302063465, 0.5201615797621864, 0.4001700441752161, 0.17242657765746117, 0.24972555839589664, 0.19724987207778863, 0.1347415569637503, 0.16953558421560697, 0.19259100992764744, 0.3698086419275829, 0.2795938013919762, 0.10108962628458228, 0.07892067264765501, 0.20856984465249948, 0.2645866423845291, 0.13012314907142095, 0.13413035976035254, 0.18531882443598338, 0.2859559085752283, 0.16070914641022682, 0.289811833096402, 0.29003431115831646, 0.4052110436771597, 0.20342517857040676, 0.1280963649707181, 0.18871523147182806, 0.24543102883866855, 0.2384546846151352, 0.25999806289161953], [0.15053623728454113, 0.07316014782658645, 0.07449553188468729, 0.02894431578793696, 0.10453874870602574, 0.058988041510539393, 0.16986100961055073, 0.16157682985067368, 0.293352157409702, 0.16553742518382414, 0.029624469112604856, 0.08512020962578909, 0.04848971377526011, 0.005598328234295228, 0.08771289871739489, 0.015847351601613418, 0.049898087845316956, 0.01866510566989226, 0.04220334127811449, 0.0717430885082909, 0.07941314657883984, 0.08428664292607989, 0.03600014699622989, 0.13196147685604437, 0.07908265931265694, 0.02305955968664161, 0.05707660836300679, 0.10902302379586867, 0.03345161017828754, 0.4021060402904238, 0.1241029149719647, 0.07769211035753999, 0.4915278362376349, 0.13462350544120583, 0.53474508864539, 0.5961083759154592, 2.2472914797919135, 3.780284260000501, 6.373961678573063, 10.604104450770787, 6.507750979491642, 29.472820145743235, 28.68395468166896, 53.129001004355295, 31.878793716430664, 85.90711743491036, 88.14941923958915, 79.34191049848283, 85.25879492078508, 89.60148157392229, 85.22552694593156, 83.4571339743478, 82.78903688703264, 82.55645288739885, 83.76284081595284, 77.73762702941895, 76.02058819362095, 78.2346247264317, 77.5767901284354, 74.58176217760358, 73.81737000601632, 71.80645711081368, 72.33110863821847, 67.43672806876046, 67.7513563973563, 67.42584718976701, 64.45706953321184, 44.663833481924875, 22.857171024594987, 23.576629195894512, 18.435505935123988, 20.773067542484828, 27.16084180559431, 33.99114336286272, 16.180940559932164, 16.072776215417043, 12.656688298497881, 1.3988823422363825, 3.4554288344723836, 3.4320355526038577, 4.78646114894322, 1.4720619640180042, 0.12142924272588321, 0.7128314354590007, 2.546090509210314, 1.8336869307926722, 15.435543026242938, 13.09102714061737, 0.5453295292598861, 4.316653490066528, 1.0072270440203803, 1.37175928907735, 37.37690673555647, 16.84484440939767, 2.9965997636318207, 3.374782396214349, 20.178534507751465, 14.03547579901559, 9.926340682165963, 9.308482544762747, 4.955549470015934, 7.027982149805341, 0.6799987001078469, 1.543003723025322, 0.5596254478607858, 11.865278925214495, 16.35305265017918, 19.495946952274867, 26.471941811697825, 26.044003997530254, 18.843170642852783, 13.790935686656407, 18.438431126730784, 19.735772711890085, 33.7380621773856, 27.804745265415736, 58.592748233250205, 78.72158922467912, 65.85494981493268, 74.29431520189557, 62.29133687700544, 61.93595041547503, 63.03134087153843, 64.99155970982143, 61.20783478873116, 52.063592025211875, 47.44179970877511, 48.054780210767476, 48.5664872441973, 53.05773680550711, 58.81017821175711, 65.86115455627441, 54.83921323503767, 64.69961030142647, 64.93549469539097, 71.28468213762555, 61.081440108163015, 24.196142741612025, 53.775791440691265, 34.58017342431204, 30.919490677969797, 24.41053114618574, 2.5732347326619283, 0.1619005181959697, 0.14492737182549068, 1.0381818115711212, 0.24784916479672703, 0.5628342128225735, 0.4932459411876542, 0.07310950197279453, 0.18549011381609098, 0.05565135234168597, 0.03902114096230694, 0.04071326141378709, 0.08816857569451843, 0.23670417283262524, 0.041904331251446686, 0.035724241086947064, 0.03822953486815095, 0.10064523334481887, 0.06605625259024756, 0.06244761337127004, 0.07355164896164622, 0.06451137084513903, 0.19576747662254743, 0.1310160333024604, 0.08241293632558414, 0.07360987405159644, 0.1512342326875244, 0.28221647494605606, 0.06752448023429938, 0.12021693134946482, 0.19617879098015173, 0.009111465769819915, 0.24343076188649448, 0.2592047740306173, 0.1786131749727896, 0.08510143456182309, 0.029731949059558765, 0.08113290715430464, 0.053180439929877005, 0.03136266887720142, 0.1815766223839351, 0.03154629063127296, 0.20457970590463706, 0.2013344629002469, 0.07544093472617013, 0.13952472672930785, 0.030566228221037557, 0.03498196788132191, 0.0493167631461152, 0.1235643345862627, 0.011173050235291677, 0.09540610161742993, 0.042724174580403736, 0.034918039704539945, 0.08559085508542401, 0.13977362694484846, 0.03246475223984037, 0.11167191594306912, 0.12416806790445532, 0.052580696397594044, 0.050183808763644526, 0.034203484654426575, 0.041717425387884886, 0.1935882799859558, 0.08092971984297037, 0.35874092153140474, 0.2511725750352655, 0.539248389857156, 0.9033148884773254, 1.7387920171022415, 4.177957892417908, 11.254008548600332, 9.342189124652318, 12.023966227258954, 20.264169318335398, 46.6859781401498, 52.14108180999756, 69.70534270150321, 37.86971466881888, 87.74911267416817, 102.33631365639823, 77.46845381600517, 90.00809710366386, 95.731981413705, 90.56261893681118, 82.58902604239327, 87.58437783377511, 84.68409551892961, 85.5409334727696, 84.38152231488908, 77.35150173732212, 82.9560854775565, 79.77612427302769, 77.65325505392892, 74.61705902644566, 74.79961599622453, 74.9620440346854, 73.35988671439034, 72.14723151070731, 72.25875704629081, 68.40407017299107, 44.9981495312282, 31.20647212437221, 28.431467567171367, 31.500026566641672, 22.516453947339738, 31.665136609758648, 34.700613498687744, 22.842011792319163, 21.65094985280718, 15.592483724866595, 0.8670419805816242, 4.597297745091574, 3.529893981558936, 7.634248086384364, 1.3726828566619327, 0.7680053434201649, 0.918006420135498, 5.884356864861079, 2.4228429283414568, 19.666952541896276, 20.6372389452798, 0.37271111618195263, 7.917890054838998, 3.7842395220484053, 4.5340200662612915, 41.45908457892281, 29.595014640263148, 8.825706073216029, 4.065804847649165, 38.71767282485962, 21.731095586504253, 17.592811039515905, 15.270723070417132, 7.8805921248027255, 7.580586280141558, 1.464094225849424, 3.4921001238482337, 4.457427901881082, 19.26038043839591, 17.692403044019425, 23.42697020939418, 29.315575463431223, 26.42821158681597, 26.07585280282157, 17.053903545652116, 29.05782856260027, 36.79902158464704, 43.573119163513184, 37.1320800100054, 55.57179307937622, 86.9486107145037, 67.52012729644775, 76.36539254869733, 68.0490311213902, 67.00537000383649, 65.62740325927734, 71.4920163835798, 64.58589608328683, 56.65875537054879, 50.50873456682478, 54.543907846723286, 50.90239865439278, 55.33170502526419, 59.5734030859811, 69.40840448651994, 56.613543442317415, 66.27441256386894, 62.25427518572126, 75.72104440416608, 61.078834533691406, 34.43390689577375, 64.23130171639579, 44.39725889478411, 46.90783412115914, 33.077347551073345, 3.5090556825910295, 0.10178540287805454, 0.10487365323518004, 0.9579744126115526, 0.22738943408642495, 0.4386642314493656, 0.36565511194722994, 0.09649720628346715, 0.12003355047532491, 0.038695189702723704, 0.07733388457979475, 0.012433641074624444, 0.09296387766620942, 0.13038629852235317, 0.06681395907487188, 0.011571123830175825, 0.02679007058031857, 0.1318065265991858, 0.03270752867683768, 0.049150403322918076, 0.09012946047421012, 0.04097661781790001, 0.055972180661878417, 0.27266886298145565, 0.05631489173642226, 0.12652518999363693, 0.1581658207412277, 0.2592058868280479, 0.04360530319224511, 0.13221699957336697, 0.17844865737216814, 0.04620047572201916, 0.11308207456022501, 0.2852395927267415, 0.27611318816031727, 0.19825681804546288, 0.15440016851893493, 0.19845466528620037, 0.17161059858543531, 0.11057382236633982, 0.2668090888432094, 0.20047877595892974, 0.4303464506353651, 0.26095311450106756, 0.11001774256250688, 0.18882393278181553, 0.1483332376394953, 0.10204232337751559, 0.10907020912106548, 0.15929581224918365, 0.08002195533897195, 0.1957441350179059, 0.13161717461688177, 0.1315868441015482, 0.16330797624375137, 0.21027636022440024, 0.07528203539550304, 0.19519708651517118, 0.26835788573537556, 0.11525293200143746, 0.13650245033204556, 0.19917111684169087, 0.12091031271432127, 0.4348702978874956, 0.3002151862851211, 0.4761678661618914, 0.7791886861835207, 0.6137661369783538, 0.8562639132142067, 2.1472552248409817, 3.18049903852599, 9.643633246421814, 11.932759829929896, 17.76515589441572, 57.121168409075054, 69.82157911573137, 58.735749108450754, 77.65366499764579, 51.29517684664045, 101.9420450755528, 94.83037621634347, 86.52681337084088, 97.5437867300851, 93.5198973246983, 87.32766274043492, 83.44246632712228, 85.33148002624512, 86.04860360281808, 89.08644635336739, 82.83715316227504, 77.89400318690709, 85.20163903917584, 79.51738030569894, 77.74300493512834, 75.21275588444301, 77.44207150595528, 76.14362689426967, 77.02568680899483, 72.59076976776123, 81.29666110447475, 69.24401010785783, 54.30334036690848, 35.51617567879813, 34.6530704498291, 33.828774384089876, 32.62442922592163, 40.89034673145839, 45.81561551775251, 27.871576513562882, 37.42715958186558, 33.13683107921055, 5.296756395271846, 5.031237934316907, 8.793422136987958, 8.909488320350647, 2.1748493441513608, 0.9031764130507196, 2.029473270688738, 11.301565493856158, 4.1120841928890774, 23.583938700812205, 32.0214124407087, 0.34682989067264963, 11.032413125038147, 6.792212835380009, 9.908636672156197, 47.06698260988508, 49.436172417231965, 11.700010810579572, 4.9709349530083795, 56.977021081107004, 33.72472163609096, 34.3074357850211, 28.400058235440934, 16.184659583227976, 11.77022409439087, 2.5135944357940128, 6.132657255445208, 7.480249949863978, 31.571870940072195, 36.72745166506086, 39.92564146859305, 46.932833739689414, 40.83313873835972, 34.15019110270909, 28.416204111916677, 36.124688489096506, 36.81885869162423, 53.39036096845354, 42.1416825566973, 68.70717144012451, 83.38547720227922, 74.98814841679165, 83.86497238704136, 67.56846591404506, 70.94074630737305, 70.84454154968262, 74.190842628479, 69.8350864137922, 64.93159675598145, 60.272662843976704, 59.45928587232317, 60.56637709481375, 67.43805517469133, 67.46503502982003, 76.27236311776298, 67.38154547555106, 64.87897109985352, 60.83771119798933, 72.8525639942714, 66.03005831582206, 47.19968625477382, 73.27947521209717, 57.38032579421997, 57.27893420628139, 60.74052674429757, 13.082143868718829, 0.26709885043757303, 0.18873284624091216, 0.7375056828771318, 0.2589929353977953, 0.3435491738574845, 0.5062466721449579, 0.22856970503926277, 0.18912461878997938, 0.08859819014157568, 0.24654806032776833, 0.14284163660236768, 0.1029884929635695, 0.24100206792354584, 0.2762143984436989, 0.12349445905004229, 0.11737849723015513, 0.20507757418922015, 0.14561436139047146, 0.09502352321786539, 0.24439667005624088, 0.10993627764816795, 0.24703492277434894, 0.3932556909109865, 0.1668926224644695, 0.24099305697849818, 0.2670626166675772, 0.40822531336120194, 0.17613216595990316, 0.2627509337450777, 0.41993338082517895, 0.20477901878101484, 0.26196934282779694, 0.2394058821456773], [0.02888516110501119, 0.14968205669096538, 0.12944869883358479, 0.13316906562873296, 0.04370115304897938, 0.05728516288633857, 0.17456793918141297, 0.1846299892557519, 0.15270148324114935, 0.18954859461103166, 0.07730976265988179, 0.1479303099747215, 0.1765551104077271, 0.08810580441994326, 0.12154786421784333, 0.0764465711212584, 0.19891142791935376, 0.037755303350942473, 0.03540556711543884, 0.02907516448093312, 0.10746792331337929, 0.11949358587818486, 0.11659279439066138, 0.0710805601307324, 0.09137767992381539, 0.09177399865750756, 0.08471749230687108, 0.052434024267963, 0.11488408036530018, 0.12486872316471168, 0.07936656514980964, 0.15244897321930953, 0.5099387168884277, 0.9942453120435987, 0.1126086131802627, 0.39699536881276537, 0.1812275161168405, 1.1837847871439797, 0.5155251228383609, 3.0750425372804915, 12.549988286835806, 17.90967321395874, 29.054182495389664, 66.46361201150077, 46.3852218900408, 53.34803254263741, 104.42565086909703, 81.51133959633964, 88.49589811052594, 81.37914316994804, 91.8869525364467, 81.15213162558419, 86.03656932285854, 79.05396325247628, 82.74993242536272, 78.20970153808594, 79.79500252859933, 80.80500657217843, 84.48951816558838, 77.59991373334611, 75.73103591373989, 76.45198099953788, 66.76997893197196, 67.0888317653111, 64.2718722479684, 62.187065260750906, 56.4457687650408, 22.653158017567225, 28.35592327799116, 18.9345828805651, 24.211944682257517, 18.751475266047887, 19.761885779244558, 14.811235223497663, 14.78668897492545, 17.887251377105713, 9.24099816594805, 1.692404757652964, 1.0577654178653444, 2.297194093465805, 2.7222284291471754, 0.2946035388324942, 0.42365579679608345, 0.07536894216069154, 0.16872736758419446, 0.31391852668353487, 16.594094344547816, 21.22754921231951, 0.9409086597817284, 2.073438648666654, 3.499459568943296, 1.9526672320706504, 17.19555994442531, 26.48127497945513, 6.22995331457683, 5.034766316413879, 18.23132790837969, 1.691681710737092, 0.6320741517203194, 0.8617834427527019, 0.8086887289370809, 0.7550729002271379, 4.054747658116477, 7.152723159108843, 6.455863569464002, 4.027037807873317, 15.989945002964564, 18.04572241646903, 7.265904971531459, 15.515520266124181, 11.217108402933393, 9.008349026952471, 13.561568702970233, 18.63665281023298, 27.39181556020464, 36.589769635881694, 27.960807016917638, 58.98222950526646, 72.60012899126325, 59.45631204332624, 68.51306656428746, 64.4150607245309, 55.77618128912789, 50.22079774311611, 40.76507765906197, 36.47561420713152, 36.17029993874686, 39.169000012534006, 35.5676201411656, 39.076901640210835, 50.484822341373985, 49.969359806605745, 62.82604244777134, 71.508761542184, 73.41752896990094, 83.26439789363316, 30.59973110471453, 41.048334871019634, 45.999596868242534, 34.75351708275931, 31.818059512547084, 2.3168427305562154, 0.4863278152687209, 0.2894188527550016, 0.3579134616468634, 0.812996829194682, 1.1484172620943613, 0.24991763808897563, 0.24773549661040306, 0.11531098745763302, 0.12084847103272166, 0.044167106438960345, 0.05874385711337839, 0.0952148497370737, 0.09215055845145669, 0.1771644755665745, 0.05538067115204675, 0.06666812832866396, 0.05201919849163719, 0.07173153984227351, 0.020756203016000133, 0.01971835656357663, 0.04303767132971968, 0.08811968724642481, 0.07718451866613966, 0.0725996575451323, 0.030498778447508812, 0.1335146299430302, 0.10145659159336771, 0.19066888306822094, 0.11901289810027395, 0.045522249436804225, 0.164787657558918, 0.10391709527799062, 0.1848669879670654, 0.0920492328171219, 0.05819078321967806, 0.1829355787485838, 0.0951829653765474, 0.13815836076225552, 0.006748684274498373, 0.07780455039548022, 0.10504185528095279, 0.1870370650930064, 0.06731292658618518, 0.31223809399775093, 0.08450474443712405, 0.07373903319239616, 0.2281594899083887, 0.04957515267389161, 0.018383221867095147, 0.10917975181447608, 0.08794144288237606, 0.08583984351051704, 0.08206296831901584, 0.05126978370494076, 0.1137920461062874, 0.08403858409396239, 0.294916994869709, 0.08043027057179383, 0.1687670075999839, 0.06648654557232346, 0.04860138028327908, 0.01951870950870216, 0.25258045377475874, 0.06370830429451806, 0.2091497749622379, 0.09071374697876827, 0.6249122417398861, 1.304615046296801, 0.1725954514529024, 0.20874857077641146, 0.9816568046808243, 3.9043469514165605, 6.766966990062168, 6.080506248133523, 7.715577619416373, 34.508193561008994, 51.150053296770366, 80.42840726034981, 59.1401481628418, 55.44682625361851, 113.0298900604248, 83.26299435751778, 90.97079086303711, 86.07500675746373, 94.20725481850761, 81.45701163155692, 88.75427382332938, 79.95093400137765, 79.57539081573486, 80.28583717346191, 76.94076592581612, 77.68160370418003, 87.66080107007707, 80.08281775883266, 78.04241670880998, 77.5090799331665, 72.36721147809709, 70.40987614222935, 65.41865852900914, 64.56937326703752, 60.17478357042585, 29.095847368240356, 40.758084297180176, 31.31992925916399, 31.128318786621094, 25.403501680919103, 28.916827031544276, 20.772115639277867, 18.415484700884136, 19.942160265786306, 13.905626126698085, 2.0549998666558946, 1.77896791270801, 2.237287159476961, 3.426890845809664, 0.29945346287318636, 0.5362093129328319, 0.15430184879473277, 0.29745854277695927, 0.7655607174549783, 19.347373621804373, 28.385239464896067, 1.2040282551731383, 2.9515380901949744, 6.50199830532074, 3.398133988891329, 24.51555837903704, 36.76074743270874, 8.820222207478114, 5.6185400656291415, 25.639903715678624, 2.336079469748906, 0.2920064596193177, 0.5245779199259621, 0.39837572617190226, 0.6300539086971964, 5.290988521916526, 10.766737461090088, 15.07574098450797, 14.049639701843262, 23.090126752853394, 17.898669004440308, 14.24658465385437, 20.888261726924352, 18.158218962805613, 21.481287002563477, 21.724797044481548, 31.028254304613384, 42.11065190179007, 51.46843365260533, 35.073196751730784, 60.52825927734375, 80.27881949288505, 66.60241617475236, 70.46158463614327, 70.17269243512834, 60.76939650944301, 54.04758759907314, 47.22451564243862, 42.30092832020351, 43.044819831848145, 47.79198544366019, 43.028491565159385, 46.028101852961946, 54.472518580300466, 55.90756130218506, 64.41415745871407, 66.73924704960415, 77.75720705304826, 79.91004385266984, 36.575063773563926, 54.673279830387656, 52.12139408929007, 49.5690393447876, 43.13108171735491, 2.9338811976569037, 0.2300490742283208, 0.3419413987014975, 0.2902134986860411, 0.7066151861633573, 0.8896579327327865, 0.24631784696664127, 0.18634398228355817, 0.056182523124984333, 0.1761801383857216, 0.1948066031826394, 0.05137089899341975, 0.0929446072716798, 0.1515201266322817, 0.1611039587961776, 0.03287938802636095, 0.07875144601400409, 0.07761029939034156, 0.00813043475084539, 0.04542884909148727, 0.10174471113298621, 0.00795684174434947, 0.1320272268993514, 0.11343086191586085, 0.08893173081534249, 0.3364824487694672, 0.13077047147921153, 0.059067009416009696, 0.17753031450722898, 0.058931621323738775, 0.08779920837176697, 0.034735038810010464, 0.18191356930349553, 0.11114567810935633, 0.08539663800703627, 0.11502033019704477, 0.16487383150628634, 0.22997630813292094, 0.1679472287318536, 0.1368996783026627, 0.11906647522534643, 0.1981471125036478, 0.19387694235358918, 0.24461952809776577, 0.3710050620138645, 0.26015233461345943, 0.15486402862838336, 0.28703271650842255, 0.12913410285753862, 0.20430004091135093, 0.2281137023653303, 0.22716259982969078, 0.16783369625253336, 0.27673545905521935, 0.21281797598515237, 0.2745871900447777, 0.19045666445578846, 0.26460751412170275, 0.1938113280172859, 0.17602921862687382, 0.24954286962747574, 0.19903194930936607, 0.24176503983991487, 0.2895535555269037, 0.2011038695595094, 0.2012975505952324, 0.2838561141065189, 1.0173984467983246, 1.634524634906224, 0.13299009523221425, 0.5711012663585799, 0.45910493603774477, 3.2262518405914307, 7.3477634361812045, 11.603541152817861, 31.935070650918142, 65.82079247065953, 68.10109397343227, 90.09214251382011, 68.16105692727226, 71.18681676047188, 113.51258836473737, 79.31718185969761, 100.99556146349225, 92.06681360517229, 91.29420866285051, 83.27200617109025, 90.39832878112793, 81.90827628544399, 81.9399322782244, 84.67361763545445, 82.3329849243164, 83.57815074920654, 88.58260468074253, 79.28169740949357, 77.55041476658413, 78.55078165871757, 75.29504340035575, 72.665191922869, 71.0314758845738, 69.5964435849871, 71.25673648289272, 34.76194177355085, 44.36735732214791, 28.553891352244786, 39.51329367501395, 28.95269536972046, 32.57387065887451, 29.01378219468253, 29.928615025111608, 38.75301831109183, 28.015880175999232, 2.633769175836018, 1.4239912863288606, 6.1247575879096985, 4.904435047081538, 0.628025577536651, 1.248336374759674, 0.2638438365289143, 0.37054192115153584, 3.6360587647983005, 23.460953848702566, 40.908269609723774, 2.119897344282695, 2.716216500316347, 8.69789743423462, 10.765011702265058, 31.426486832754954, 57.87019463947841, 15.674955368041992, 18.74981117248535, 30.078671795981272, 3.4205019772052765, 0.4121129661798477, 0.9022586537258965, 1.1697616939033781, 1.0241186576230186, 9.681166546685354, 14.554303867476326, 22.398134810583933, 30.32737214224679, 39.107685634068076, 34.800650187901084, 24.43284007481166, 31.47759083339146, 24.3325480393001, 29.062638453074864, 32.61611918040684, 34.560145241873606, 43.9780775478908, 59.0627452305385, 42.294852120535715, 74.74306460789272, 82.52760396684918, 69.55749893188477, 77.67527389526367, 70.52106121608189, 64.79755905696324, 62.10921764373779, 58.156582014901296, 51.59536681856428, 47.75940534046718, 56.152634688786094, 54.17504187992641, 50.857707841055735, 58.179750783102854, 65.4809491293771, 63.41918931688581, 64.00397055489677, 75.42475931985038, 78.74173205239433, 48.12698589052473, 56.57193068095616, 62.092284883771626, 56.24828011648995, 63.63988494873047, 31.340878077915736, 0.29340882865445955, 0.35495043492742945, 0.15519239886530808, 0.4753562297139849, 0.802161873451301, 0.35390950792602127, 0.3445084052426474, 0.22787233388849668, 0.18133825303188392, 0.4185060145599501, 0.1003902330994606, 0.18664270054016793, 0.20445279271474906, 0.3819984421133995, 0.2068690016333546, 0.18167038235281194, 0.16502965028796876, 0.29493726949606625, 0.1320395762366908, 0.2757731335503714, 0.08883069016571556, 0.20935313190732682, 0.21287789062729903, 0.2669709872986589, 0.3600659647158214, 0.17353849299252033, 0.11044164374470711, 0.3801484028143542, 0.18358488247862884, 0.24045554867812566, 0.2527213447860309, 0.18336324580013752, 0.12678854300507478, 0.15862776738192352], [0.01706354589467602, 0.0800019996240735, 0.08844795570309673, 0.352300158568791, 0.07643458819282906, 0.05265560666365283, 0.17443789115973882, 0.16766451033098356, 0.09684716750468526, 0.06844099105468818, 0.06921595947018691, 0.08731611857989005, 0.10535285502140011, 0.07325292391968624, 0.04159071575850248, 0.1642628921461957, 0.023532900626638105, 0.1321378145366907, 0.12178645070110049, 0.06248276148523603, 0.053925396741500924, 0.08441475033760071, 0.27143778332642143, 0.12117891758680344, 0.1647633117224489, 0.16670614747064455, 0.10726475635809557, 0.08617091431681599, 0.09830787698073046, 0.057647799141705036, 0.20197837906224386, 0.22009762536202157, 0.05702577930475984, 0.35844988429120606, 0.45851330778428484, 0.03649110779432314, 0.3324836790561676, 0.20155740236597403, 0.22731014048414572, 1.7833860984870364, 0.7713486754468509, 11.958558491298131, 30.93413053240095, 37.61631734030587, 72.40451635633195, 34.679296425410676, 88.83961159842355, 88.28605556488037, 84.52435643332345, 89.44167300633022, 85.05207211630685, 91.31600516183036, 78.36042881011963, 72.82042162758964, 55.19582257952009, 51.74845995221819, 49.033746651240754, 54.13920307159424, 59.29560715811593, 66.78998974391392, 70.02380643572126, 67.87392262050084, 67.94467612675258, 58.05137586593628, 52.17318596158709, 66.1675979069301, 22.003299951553345, 32.33128472736904, 33.290931701660156, 29.065567118780955, 23.40963445390974, 13.106510332652501, 14.566775015422277, 20.39561012813023, 24.368378162384033, 14.3596978528159, 4.912194447857993, 0.1843306738883257, 0.25940863309162004, 0.8806572471346173, 1.1040215300662177, 0.488651879131794, 0.771785597716059, 0.6819902818117822, 0.4980614770736013, 0.10107533633708954, 6.585407521043505, 24.106946979250225, 1.8703855787004744, 0.7808489799499512, 3.075953836951937, 1.3599411632333482, 6.070696694510324, 23.26295450755528, 27.690334490367345, 14.041360923222133, 1.886558813708169, 0.11581808381846972, 0.027889828264181103, 0.30687650027019636, 0.0683779212247048, 1.0191485243184226, 1.340318690453257, 8.527733445167542, 6.7892303211348395, 1.1343357605593545, 10.352382506643023, 15.092244693211146, 12.137304374149867, 8.711514166423253, 4.656381751809802, 8.837677819388253, 17.334077494485037, 21.987854106085642, 31.732853753226145, 45.669915267399375, 37.5744058064052, 23.062118564333232, 51.618000575474326, 76.0676691872733, 61.439272335597444, 59.750735010419575, 54.19648054667881, 36.44409370422363, 35.902624062129426, 42.047405924115864, 40.24120085580008, 33.02467673165457, 41.51163033076695, 47.999469075884136, 34.55924545015608, 52.34896496364048, 76.38162354060582, 74.75171511513847, 82.20474202292306, 43.15804072788784, 44.13111162185669, 52.91965872900826, 39.50982999801636, 49.2393924849374, 12.34259671824319, 2.2036761173180173, 0.44233089898313793, 0.5468585129295076, 0.8748709719095911, 1.2240385242870875, 0.516777155654771, 0.3001611477562359, 0.06962158091898475, 0.16048493129866465, 0.028552387175815444, 0.04592332809365221, 0.07161354260253054, 0.17306851249720367, 0.25354448918785366, 0.0962364317051002, 0.026518159545958042, 0.13961607111351831, 0.028407893143594265, 0.11542837401585919, 0.10350101081920521, 0.03445726014407618, 0.03091560590213963, 0.10394372777747256, 0.05784418074680226, 0.25741732280169216, 0.09088329930922814, 0.10141029514904533, 0.19051406851836614, 0.26506294682621956, 0.1267261720661606, 0.12253670687122004, 0.20143969011093887, 0.20624123460480145, 0.2441885769367218, 0.020630202455712215, 0.1129608339230929, 0.030231500110988106, 0.11158623732626438, 0.22558111112032617, 0.04611114997948919, 0.02642910521743553, 0.074498286736863, 0.219303305127791, 0.1548982403640236, 0.1328627070678132, 0.09069739428481885, 0.04685081082529255, 0.09246573796761887, 0.0568969288973936, 0.06198002810456923, 0.19024596576179775, 0.03312075989586966, 0.048924990597047975, 0.06853211152234248, 0.015987793083435724, 0.09991098381578922, 0.14274736094687665, 0.19502159021794796, 0.10657307811613594, 0.17994325288704463, 0.11698262632957526, 0.050262077778045616, 0.03025453976754631, 0.06846543867141008, 0.04548009544877069, 0.2034458467470748, 0.03634622021179114, 0.04116644477471709, 0.37764450002993855, 0.5587495948587144, 0.01772409294998007, 0.3625409076256411, 0.44294904438512667, 1.7346297204494476, 3.7923398188182285, 2.383531323501042, 19.358885049819946, 49.35699769428798, 54.405253069741384, 84.58594526563371, 46.59442172731672, 82.48953478676933, 94.8470379965646, 83.58859389168876, 97.41747542790004, 88.28283854893276, 91.78967080797467, 76.77677454267229, 77.0444677897862, 58.788263593401226, 53.47575780323574, 51.910637855529785, 55.7551942552839, 64.355028288705, 69.55630384172711, 70.5781615121024, 69.39971229008266, 73.81889860970634, 60.75440229688372, 63.28759043557303, 68.24584579467773, 27.165623903274536, 47.6693115234375, 45.62244864872524, 43.62471301215035, 29.145153522491455, 24.44719331605094, 21.124114853995188, 23.383887904030935, 24.226339612688335, 16.48637468474252, 8.130057641438075, 1.0255352216107505, 0.10639152928654637, 4.178039533751352, 1.9773001159940446, 0.29395442509225433, 0.6547788019691194, 0.3415631018579006, 1.0027638035161155, 0.1944866060678448, 6.31393358537129, 26.369249173573085, 2.7885984906128476, 0.7524568491748401, 5.1111465607370645, 1.5853694954088755, 14.090193731444222, 32.16438552311489, 30.262875488826207, 21.71353575161525, 3.293229869433812, 0.06396639187421117, 0.025790042277159433, 0.2287800780364445, 0.6740591302514076, 1.3721042019980294, 3.3437777970518385, 12.38723976271493, 15.77313688823155, 14.876346792493548, 18.18030207497733, 25.901915073394775, 17.725681441170828, 18.04773391996111, 15.293153592518397, 19.32904601097107, 28.248062917164393, 32.78135429109846, 45.52833529881069, 60.31869465964181, 52.64270353317261, 33.00463465281895, 47.97595637185233, 79.69362136295864, 66.9685445513044, 63.72729328700474, 58.797240665980745, 40.977160998753135, 40.278960841042654, 47.929153306143625, 48.11465631212507, 37.25978790010725, 44.98826571873256, 52.80252252306257, 42.55084807532174, 57.18113831111363, 71.45644855499268, 82.64548710414341, 80.11213220868791, 45.5532272202628, 58.53129141671317, 56.689518519810264, 50.212887219020296, 57.725119726998464, 12.309218440737043, 0.5449908588613782, 0.3565430108989988, 0.3603176197835377, 0.7832797638007573, 1.0560332536697388, 0.3188668383019311, 0.3826819711497852, 0.2095471250691584, 0.1385902211602245, 0.07351998851767608, 0.06628023021455322, 0.06799471178757292, 0.07660789960729224, 0.18950295634567738, 0.05942508591605084, 0.04446750406974128, 0.04438457691243716, 0.13105085571961744, 0.061911869261945994, 0.11292588258428232, 0.023712591966614127, 0.08025580564779894, 0.14319196423249586, 0.06137035081961325, 0.1940260843506881, 0.19609921239316463, 0.0622769957408309, 0.12797534146479198, 0.3208991592483861, 0.13968361248927458, 0.038990963117352555, 0.16645141185394355, 0.15977393516472407, 0.2802669352718762, 0.017562813657735075, 0.1089191875819649, 0.1355469508894852, 0.22498280608228274, 0.29662777164152687, 0.15366895204143866, 0.11901471657412392, 0.15321906975337438, 0.20996902457305364, 0.22177163910652908, 0.2715757702078138, 0.22491948519434246, 0.16694382471697672, 0.20544269388275488, 0.1527968038405691, 0.09231405146420002, 0.32832029674734386, 0.06523891644818441, 0.2167760200266327, 0.18581545778683253, 0.21682083047926426, 0.21808380128017493, 0.21807783017201082, 0.24207570031285286, 0.11255972473216908, 0.2273710864995207, 0.14174633180456503, 0.31004357604043825, 0.16266091167926788, 0.15602127010268824, 0.1306664656315531, 0.4315707992230143, 0.3860059513577393, 0.344307721725532, 1.194249642746789, 0.36592093482613564, 0.363017917743751, 0.26775409813438145, 0.25058431231549805, 1.7816046455076762, 4.8621335455349515, 11.067438125610352, 53.2493577003479, 72.02285875592912, 66.82718345097133, 98.6325763974871, 57.14494514465332, 94.92617103031704, 91.31993089403424, 86.48480456215995, 99.50194890158517, 89.28840269361223, 89.02282169886998, 80.48425688062395, 79.92318289620536, 62.77625860486712, 59.83458587101528, 59.113022395542686, 65.08595098767961, 71.00090381077358, 75.33346693856376, 72.77099909101213, 73.40177045549665, 76.92334679194859, 66.7432005746024, 61.89843014308384, 80.87653827667236, 39.375351088387625, 50.44677400588989, 47.78044448580061, 43.179090295519146, 33.99717787333897, 27.318428686686925, 27.667500972747803, 34.31302908488682, 41.59189592088972, 30.029270103999547, 17.923088448388235, 6.683022328785487, 1.628037188734327, 9.028435400554113, 2.0747179857322147, 1.1649339986698968, 0.913631986294474, 0.6944877569164548, 1.0382117756775446, 0.19899358493941172, 9.382830006735665, 34.74427945273263, 4.93794447183609, 0.799336345068046, 8.207472733088903, 4.836494258471897, 22.655442237854004, 45.04744005203247, 37.96047551291329, 26.864820752825054, 2.8914748217378343, 0.2843250632286072, 0.20537868088909558, 0.6194127968379429, 0.7562195158430508, 1.5214362974677766, 6.842123482908521, 18.444436107363018, 32.92782926559448, 36.954928738730295, 35.6368658883231, 47.25770371300833, 37.12960992540632, 31.582456520625524, 21.04250999859401, 19.409304652895244, 36.62290212086269, 36.70150709152222, 53.3641801561628, 68.88464232853481, 57.90575899396624, 43.73974391392299, 60.555822781154085, 83.78586019788469, 71.05450916290283, 70.41895743778774, 63.170561926705496, 50.44429349899292, 48.62746810913086, 50.56057160241263, 51.585698400224956, 52.91590322766985, 55.62526641573225, 53.35667610168457, 50.414961678641184, 63.19959150041853, 66.38443728855678, 80.19577462332589, 80.51089627402169, 58.95916148594448, 63.31434794834682, 64.21921185084751, 54.93164512089321, 70.94180243355888, 43.77687161309378, 4.571388346808297, 0.3645295037754944, 0.3294496504323823, 0.5742170991642135, 0.6665935079966272, 0.615784534386226, 0.39012056056942257, 0.3237729993249689, 0.4025211680148329, 0.24896817760808126, 0.1358083225786686, 0.11527863490794386, 0.19971659114318235, 0.17589096033147403, 0.23527102544903755, 0.11235211337251322, 0.17548685201576777, 0.29091925652963774, 0.17886207518833025, 0.17343862620847567, 0.1730441123779331, 0.2181304573480572, 0.23306206826652798, 0.1435817283179079, 0.3189112687749522, 0.16958321737391607, 0.21929061652294227, 0.1777303602014269, 0.403779497636216, 0.10950931627303362, 0.2709393857845238, 0.26088735088706017, 0.18236278662724154, 0.22788707166910172, 0.14204563360129083], [0.07754793523677758, 0.051783214190176556, 0.12504449087594235, 0.1795962229371071, 0.2371663637459278, 0.027504123514518142, 0.12124918667333466, 0.2503823260111468, 0.2969785471047674, 0.19422342947551183, 0.3250158583479268, 0.13854621137891496, 0.035381068608590534, 0.19007471709379128, 0.03119123021938971, 0.033611992107970376, 0.030661301155175482, 0.14921021700969764, 0.11256688327661582, 0.05685396745268788, 0.07633482318903718, 0.04286793918747987, 0.12177486132298197, 0.5327175174440656, 0.15739801765552588, 0.07203771519873824, 0.09464849691305842, 0.09652590831475598, 0.2441985649721963, 0.1313674465886184, 0.04587514532197799, 0.08918629001293864, 0.11940677410789899, 0.22286359194133962, 0.5540185230118888, 0.1886567281825202, 0.4396111677799906, 0.7730325822319303, 0.08550818237875189, 0.27063054378543583, 1.5936735698154993, 8.104753170694623, 25.64598686354501, 44.20154551097325, 54.71293319974627, 58.51153073992048, 32.384841442108154, 102.28083229064941, 93.49357060023716, 99.73073918478829, 89.32577010563442, 78.39522538866315, 65.30175508771623, 60.565855979919434, 56.78585876737322, 42.789692401885986, 39.214128562382285, 40.02992350714547, 41.970614433288574, 51.03670385905674, 63.047849791390554, 62.616859980991904, 62.69970335279192, 60.313830920628135, 59.19240556444441, 21.978449719292776, 30.75811529159546, 47.47549499784197, 30.396642208099365, 27.560932976858957, 24.19258873803275, 21.348830018724712, 31.436328956059047, 28.032620123454503, 12.677545053618294, 6.503764884812491, 4.223892867565155, 2.242871556963239, 0.2451632246375084, 1.1360310124499458, 0.45846564748457497, 0.20964501053094864, 0.22207579921398843, 0.119529466809971, 1.4063105093581336, 0.4096502369003636, 0.9760116104568753, 15.728241103036062, 0.513861354972635, 0.2583281339279243, 0.3528450493301664, 0.8664705455303192, 1.843968961920057, 18.47425777571542, 34.07855517523629, 3.1072715393134525, 0.03914246302364128, 0.043930307895477326, 0.08383820591760532, 0.43024282476731707, 0.7707474391375269, 0.37499039673379486, 3.588800374950681, 1.6008395510060447, 4.8407743488039285, 5.088779875210353, 9.36950249331338, 21.465599707194738, 17.70062276295253, 15.756714820861816, 4.88887803043638, 7.738797630582537, 10.378373111997332, 23.792462825775146, 33.32143429347447, 31.06949881144932, 34.95409073148455, 45.07366950171334, 27.06056887762887, 40.238768986293245, 62.13947010040283, 67.55097034999302, 53.96613386699131, 49.40890073776245, 43.8357367515564, 45.6545284816197, 32.543645995003835, 30.02613299233573, 35.67709943226406, 43.33025530406407, 57.93265199661255, 83.71325152260917, 83.93767833709717, 86.54965209960938, 46.91334751674107, 47.06078134264265, 52.566005843026296, 40.99545560564314, 52.14170714787075, 19.2374461718968, 3.053982981613704, 0.17666143684514932, 0.43460906190531595, 0.8706082520740372, 1.0882642098835535, 0.6208973771759442, 0.4757890264902796, 0.13049679116478988, 0.24056072160601616, 0.09180610014923982, 0.07105485043887581, 0.07148179145795958, 0.18698840056146893, 0.1374375665826457, 0.1332670325147254, 0.16410684266260692, 0.07813216745853424, 0.096346272953919, 0.024550167111946002, 0.06999679721359696, 0.03253928252628871, 0.004524125027403767, 0.025409669116405503, 0.06472111959010363, 0.16642569537673677, 0.231694223093135, 0.2915675831692559, 0.22207820122795446, 0.050953080877661705, 0.19022537900933198, 0.05878182114767177, 0.09893200706158366, 0.14778780405010494, 0.14850687475076743, 0.3109513744711876, 0.09119370193885905, 0.0810475813757096, 0.05036155779712966, 0.16425126205597604, 0.19188351503440312, 0.22438950863267693, 0.057104190811514854, 0.06060136029762881, 0.2343355156481266, 0.3652351259120873, 0.11307451568011727, 0.1620561062757458, 0.2769954465329647, 0.15650361350604466, 0.07826516710753952, 0.05263457547074982, 0.09868996004973139, 0.028758821277213947, 0.1012561319928084, 0.1049646854932819, 0.055032776069960425, 0.06902506721339055, 0.05705520058316844, 0.08719577360898256, 0.4122890324464866, 0.13249693598066056, 0.0501932064736528, 0.09403514196830136, 0.05704770277121237, 0.14365490153431892, 0.06492312625050545, 0.1364949457347393, 0.16744093304233892, 0.07066363428852387, 0.14578352017062052, 0.6138425128800529, 0.35515831091574257, 0.47214350210768835, 0.9297381277595247, 0.08887761764760528, 0.36583858781627243, 1.1023071706295013, 8.470655730792455, 35.613099575042725, 64.54781995500836, 63.84000696454729, 77.82234641483852, 39.74057967322213, 97.78426388331822, 97.19596685682023, 95.7516587121146, 92.01548726218087, 82.04071589878627, 68.38011973244804, 64.42375292096818, 63.08357742854527, 48.79349184036255, 45.278724738529746, 45.918295996529714, 48.89653015136719, 54.91114446095058, 69.70345973968506, 69.20778914860317, 64.73162065233502, 68.77083083561489, 60.85535267421177, 27.182422910417827, 47.45539385931832, 60.03405475616455, 46.16476944514683, 36.63784074783325, 27.006319080080303, 21.190860986709595, 30.770201683044434, 36.82815190723964, 16.80640697479248, 13.088392036301748, 4.610225737094879, 0.8664271735719272, 0.9332415397678102, 1.4599137987409319, 4.761114120483398, 0.3534392560166972, 0.16495680276836666, 0.23002350702881813, 0.712572669344289, 1.1532083707196372, 0.8148326735411371, 17.052803993225098, 1.618632584810257, 0.519849670784814, 2.6463775507041385, 0.23985884498272622, 5.185312935284205, 21.213095222200664, 41.506210735866, 4.388111369950431, 0.13476010811116013, 0.12195278677557196, 0.1559014543890953, 0.34955184747065815, 0.708400981766837, 0.6495464827333177, 5.160253822803497, 6.595214034829821, 11.682405812399727, 24.90267378943307, 12.24581960269383, 21.28448796272278, 21.315584625516617, 25.983556406838552, 11.75150043623788, 15.53090705190386, 19.628636700766428, 34.67508929116385, 42.45304870605469, 44.887662751334055, 56.28947598593575, 59.723456382751465, 42.12428426742554, 42.74076318740845, 66.23626000540597, 78.59231798989433, 59.863316672188894, 54.37223523003714, 48.56414917537144, 51.22894661767142, 39.56707968030657, 36.393726212637766, 43.27083430971418, 53.206014837537495, 64.3544932774135, 83.60993180956159, 93.2804068156651, 83.83063438960484, 51.87417023522513, 62.57963153294155, 57.6234085219247, 53.99270377840315, 59.72483212607247, 20.773892641067505, 0.48229748010635376, 0.29169832329664913, 0.44175772688218523, 0.685011445411614, 0.8957173590149198, 0.5061650850943157, 0.43760737244571957, 0.11344861917729888, 0.2969990388623306, 0.14432715331869467, 0.09307310823351145, 0.005825882162233549, 0.22752685099840164, 0.26308439299464226, 0.04034588559131537, 0.10248630241091762, 0.01538783750895943, 0.08304780761578254, 0.06079787760972977, 0.05818706484777587, 0.08546873235276767, 0.06001798302999564, 0.0852296437535967, 0.027761668266196336, 0.15890820590513094, 0.05389680327581508, 0.24677735088127, 0.11643734201788902, 0.14039623710725987, 0.07449053108159985, 0.062206400957490714, 0.10755597001739911, 0.10447504105312483, 0.17185534616666182, 0.2630224291767393, 0.07391414951000895, 0.17971502084817204, 0.15393845258014544, 0.23805600457957812, 0.26345723441668917, 0.24375037902167865, 0.16074846072920732, 0.1624642993722643, 0.29974914129291264, 0.29256847660456387, 0.18588572687336377, 0.358368487230369, 0.34308299315827234, 0.166065922539149, 0.23611604581986154, 0.08568515109696559, 0.17755091483039515, 0.15925827569195203, 0.22877847669380053, 0.13624452560075692, 0.09130525309592485, 0.23402488231658936, 0.11227813948478017, 0.2689938358962536, 0.3491129981619971, 0.1867519718195711, 0.18337898781257017, 0.12143106119973318, 0.18421186240656034, 0.2296412746821131, 0.12584676354059152, 0.18083670708749974, 0.21376020328274795, 0.1475542387259858, 0.5303990989923477, 0.6536616619144167, 0.29670341472540585, 0.80319373522486, 0.5424410328269005, 0.14551442675292492, 0.566110505589417, 2.861958656992231, 29.376591069357737, 74.50827802930559, 73.69293471745083, 78.96016951969692, 85.5267869404384, 49.73747410093035, 103.92768737248012, 93.1004832131522, 104.18965530395508, 97.16725690024239, 85.6224844796317, 66.79597909109933, 67.26823425292969, 65.23156438555036, 53.41710805892944, 52.7845127923148, 52.62037549700056, 54.65885189601353, 62.70996584211077, 70.53710460662842, 72.0829050881522, 72.40632288796562, 73.78420625414167, 74.20893573760986, 36.977135181427, 47.71560042245047, 72.15895312173026, 49.00464064734322, 41.28955895560128, 35.33417803900582, 39.92381061826433, 49.08414888381958, 50.928899083818706, 30.29650477000645, 21.748724903379166, 12.077914646693639, 3.872668811253139, 2.0070060534136633, 3.7892886911119734, 7.5558819600514004, 0.30386926020894733, 0.6532399931124279, 0.34860401547380854, 1.8954197210924966, 1.372981737766947, 0.985032217843192, 20.972010101590836, 3.556659093924931, 0.9110709237200874, 6.0337261983326504, 2.6380881326539174, 9.973171540669032, 34.551473890032085, 42.74517181941441, 4.626803704670497, 0.13122973112123354, 0.11874224405203547, 0.5193163422601563, 0.40371091131653103, 2.028338543006352, 1.0777377975838525, 9.69288728918348, 14.305340358189174, 21.03454910005842, 40.19018370764596, 28.812074252537318, 32.69980328423636, 36.58610098702567, 49.656520639147075, 17.956790685653687, 19.14580464363098, 22.263376235961914, 42.40237201963152, 49.637381826128276, 52.410536425454275, 64.11885901859829, 65.72739478519985, 46.29698324203491, 57.43255540302822, 76.22180107661656, 79.3544728415353, 66.77935900006975, 61.72808115822928, 51.34315415791103, 53.26969507762364, 50.67408084869385, 47.27461215427944, 44.87611831937517, 56.14931344985962, 68.6619873046875, 70.76026684897286, 85.19225897107805, 84.12502956390381, 58.19638129643032, 69.51653235299247, 62.61534527369908, 59.05824974605015, 72.1371705191476, 55.81466041292463, 11.281311494963509, 0.3759735939758164, 0.3221822418272495, 0.5113068063344274, 0.4741585339818682, 0.7768781930208206, 0.6490305247051376, 0.24892380141786166, 0.4848227703145572, 0.22561180804456982, 0.14092181676200458, 0.12859742236988886, 0.2201557079596179, 0.2655381927532809, 0.2848554604819843, 0.2883411762969834, 0.1426719349942037, 0.14325179745044025, 0.06632389394300324, 0.1710432076028415, 0.09464367931442601, 0.08186465288911547, 0.2561985653425966, 0.31130307274205343, 0.2123936473258904, 0.2240234525608165, 0.3279352145535605, 0.18307991671775067, 0.16323329667959893, 0.2722713500261307, 0.21345130700085843, 0.3856784632163388, 0.20413637826485292, 0.33716779627970284, 0.26553140740309444, 0.19033945431666716], [0.08424595796636172, 0.019169800016762953, 0.09636890888214111, 0.04957390756213239, 0.16552256526691572, 0.10728906148246356, 0.005240896342521799, 0.2566022665372917, 0.14299684470253332, 0.07000846123056752, 0.059168145060539246, 0.042542320410055776, 0.09572119970938989, 0.18104063400200435, 0.10617690187479768, 0.1413797057632889, 0.10561712405511312, 0.10801957228354045, 0.11169144418090582, 0.2893994195120675, 0.03969553013199142, 0.07004417931394917, 0.04401244116680963, 0.3025798536837101, 0.2108415120414325, 0.05475826794281602, 0.07778133092714207, 0.12251336526657854, 0.12054299456732613, 0.2180155406572989, 0.0614511032721826, 0.05473092637423958, 0.061073172837495804, 0.2501558038805212, 0.5062852672168187, 0.5825669882552964, 0.4555727541446686, 0.48331745394638603, 0.8410960499729428, 0.15011019871703216, 0.6287769600749016, 1.8912232262747628, 17.355154854910715, 37.869190079825266, 48.58871800558907, 60.26514489310128, 49.41474764687674, 40.18544503620693, 107.0790775844029, 91.60458469390869, 90.60313388279506, 67.9665629523141, 65.1923418045044, 63.75102833339146, 59.74555860246931, 43.50909151349749, 32.778467314583914, 35.26121500560215, 38.02266189030239, 40.17383459636143, 55.93604891640799, 63.89891379220145, 71.44587339673723, 55.71986613954817, 28.034381491797312, 39.874770232609336, 47.61618559701102, 34.23821088245937, 25.40042015484401, 27.39506558009556, 30.67355224064418, 26.76770578111921, 20.710698774882726, 21.601289340427943, 27.6104736328125, 9.868129542895726, 3.255120085818427, 2.911149514572961, 0.8400486633181572, 1.9405632529939925, 1.3806628627436501, 1.1877188788993018, 0.1747575490070241, 0.005279165717573571, 1.6716868579387665, 2.5498859626906256, 0.32669452684266226, 13.665530255862645, 2.5620316309588294, 0.09854604955762625, 0.49649883806705475, 0.4784759708813259, 0.7212873388613973, 10.238326089722769, 23.137645483016968, 0.8772504042301859, 0.21954252943396568, 0.6612426894051688, 0.14746007163609776, 0.5312356512461389, 0.30249481967517305, 1.9281316229275294, 1.511613933103425, 3.23785120674542, 6.216427343232291, 11.155284200395856, 20.406904424939835, 12.298399227006094, 13.190898810114179, 17.239488192967006, 20.011081184659684, 21.22648961203439, 16.75184450830732, 23.234652757644653, 25.135363749095372, 24.64108279773167, 27.661641904285975, 23.855648006711686, 36.44553892953055, 35.28514460154942, 29.381854329790386, 50.06363296508789, 61.28839915139334, 81.49358000074113, 72.81916400364467, 63.94047096797398, 66.745653288705, 70.36027990068708, 67.47933442252022, 82.9777499607631, 92.76948492867606, 93.74155875614711, 79.40786974770683, 46.66785723822457, 50.46171610695975, 55.55401611328125, 52.41515697751726, 56.5185580934797, 15.757751839501516, 6.305937511580331, 0.3678611107170582, 0.6197818656052861, 0.7816932403615543, 1.9086256410394395, 1.1105314493179321, 0.22254264487751893, 0.18974104071302073, 0.2411917591733592, 0.06247511439557586, 0.08256923008177962, 0.12705649648393902, 0.3699638093156474, 0.1490171602261918, 0.3008977925138814, 0.22797145428402082, 0.09143684139209134, 0.05271826258727482, 0.11824575997889042, 0.11604007333517075, 0.06492830347269773, 0.05750931014439889, 0.05632693234032818, 0.11957739852368832, 0.09774956479668617, 0.12394169505153384, 0.16830746297325405, 0.21310369351080485, 0.19737907871603966, 0.07223596277513675, 0.16320121554391726, 0.13321893795260362, 0.08685441621180091, 0.04414070464138474, 0.0882322494206684, 0.2796416516814913, 0.06072490795382431, 0.03950398987425225, 0.06573653367481061, 0.042816166965557, 0.07371238033686366, 0.1895275871668543, 0.055455791763961315, 0.034740575655762634, 0.2380356213876179, 0.0613452246678727, 0.11708408088556357, 0.07060383499733039, 0.008771575704616095, 0.14223651907273702, 0.1646915227174759, 0.042862086822944026, 0.06260108442178794, 0.05511412563334618, 0.09728482937706368, 0.08507293609103986, 0.12276825016098362, 0.051479420491627285, 0.012432600371539593, 0.0601590776017734, 0.23305737280419894, 0.10952475973005805, 0.053090086206793785, 0.07925172309790339, 0.10490190743335656, 0.07852107658982277, 0.1054707911929914, 0.051496010672833235, 0.047375532133238654, 0.15795183793774673, 0.13837195001542568, 0.3219559096864292, 1.1488855055400302, 0.41806526535323685, 0.3629380134599549, 0.8973473629781178, 0.036702875180968215, 0.4334592707455158, 1.5195252171584537, 14.552486045019966, 51.029286657060894, 64.87458678654262, 68.6774262019566, 69.7599902834211, 45.266384737832205, 101.26854923793248, 97.67076505933488, 89.30821895599365, 77.92276178087506, 72.09334823063442, 66.88421426500592, 62.593882288251606, 50.403615270342144, 38.988079343523296, 38.718252999441965, 46.729432174137656, 50.42089196613857, 61.84409523010254, 70.16359029497418, 79.00227560315813, 57.90185758045742, 33.89840228216988, 58.218341078077046, 59.11029175349644, 45.74897534506661, 34.65118401391165, 31.891640935625347, 40.27407625743321, 40.98276472091675, 26.664578880582535, 19.274269887379237, 18.09026731763567, 9.764478053365435, 3.252087197133473, 0.9465351807219642, 1.475857743195125, 1.7895060500928333, 1.1489199208361762, 0.8514791556767055, 0.06074707569288356, 0.07779784646949597, 0.9158245772123337, 1.6666426828929355, 0.32835585198232103, 13.605470027242388, 2.647228705031531, 0.6493017758641924, 1.6331232701029097, 0.4236662733767714, 0.6791081907493728, 15.128099134990148, 29.985805647713796, 1.4549017591135842, 0.26124027052095955, 0.7936029955744743, 0.7174348884395191, 0.3949298539331981, 0.3364860585757664, 2.69814966406141, 8.922742877687726, 4.923563872064863, 12.806423715182714, 20.335659333637782, 36.40626423699515, 17.878213507788523, 21.893561840057373, 23.036118405205862, 15.271273715155465, 22.234725339072092, 20.90968128613063, 25.201858009610856, 39.75423288345337, 40.321716581072124, 39.00952843257359, 36.95479324885777, 50.60144090652466, 51.998369285038535, 39.38747569492885, 51.53113419669015, 67.68503584180559, 82.91645295279366, 81.16827229091099, 74.1225835255214, 68.10039220537458, 71.08323301587785, 75.43474388122559, 84.06949261256626, 86.27920041765485, 93.17594064985002, 76.21048246111188, 53.06512968880789, 59.659338406154085, 59.07949733734131, 65.25132506234306, 61.870922224862234, 18.054779393332346, 3.0824619105884006, 0.4645348446709769, 0.46328498316662653, 0.7832427429301398, 1.928996456520898, 0.668956384062767, 0.3172670698591641, 0.2486135752073356, 0.495521964771407, 0.1015642343887261, 0.056747043904449256, 0.1255060846784285, 0.37717242964676445, 0.1064388028212956, 0.15955079213849135, 0.14076004044285842, 0.06449201224105698, 0.07793435414454766, 0.11325906363448926, 0.009163325353126441, 0.053638295004410405, 0.08999029972723552, 0.06641260561134134, 0.036109526841236014, 0.09655583170907837, 0.11117765067943505, 0.14917410537600517, 0.16309832249368938, 0.1611979901790619, 0.12159038122211184, 0.19769427180290222, 0.056701809367431064, 0.05092051798211677, 0.05897411797195673, 0.1623826173267194, 0.16277388775987284, 0.08365703028227602, 0.15365660270409925, 0.16290783057255404, 0.1926318034529686, 0.10582753776439599, 0.3272785555039133, 0.09728083959115402, 0.29180439189076424, 0.4071485054280077, 0.1646702302885907, 0.22681068442761898, 0.1915568139936243, 0.1280841784817832, 0.18911213374563626, 0.2916597825075899, 0.1864772058491196, 0.27788712297167095, 0.14716249331831932, 0.16868227214685508, 0.19612796870725496, 0.2921741934759276, 0.09479567794395344, 0.09382069097565753, 0.13077855961663382, 0.5555124399917466, 0.19830310770443507, 0.15513739681669644, 0.14369771709399565, 0.21084751029099735, 0.1094479767073478, 0.31879950048668043, 0.18014527990349702, 0.1706535927951336, 0.17844960732119425, 0.2219520751386881, 0.9004012048244476, 0.8988743381840842, 0.4415950413261141, 1.1098356523684092, 0.6821612726364816, 0.22813666399036134, 0.688210548034736, 5.018475830554962, 49.108092376164024, 89.84908063071114, 68.81425012860979, 80.83795492989677, 68.41271373203823, 55.61658116749355, 106.73784460340227, 98.6717781339373, 98.9074262891497, 84.86247662135533, 71.50034727369035, 70.6888324192592, 68.33877795083183, 54.8060599054609, 47.06063543047224, 50.479774475097656, 53.79978009632656, 57.297322613852366, 67.93952056339809, 73.78046117510114, 84.0092100415911, 78.07224532536098, 43.088673387254985, 59.64253766196114, 62.423936298915315, 52.18822533743722, 44.98642097200666, 48.77013199669974, 53.82845183781215, 48.15312153952462, 41.1117719241551, 35.330547605242046, 38.623899936676025, 16.966721023832047, 12.940303342682974, 12.538502046040126, 8.51712875706809, 4.745796382427216, 6.946256135191236, 1.3973140035356795, 0.1998491497444255, 0.16113815696111747, 2.582768529653549, 6.155481653554099, 0.22870074372206414, 15.059430088315692, 4.776382352624621, 0.47550409606524874, 8.65098580292293, 0.9328053231750215, 2.598254544394357, 22.516947269439697, 34.150104250226704, 1.7181829001222337, 0.23622648417949677, 1.1811871379613876, 1.0147606283426285, 0.4015014384474073, 0.22708840881075176, 3.6885354689189365, 19.50452971458435, 11.971469981329781, 26.37251135281154, 36.89811331885201, 58.48013877868652, 33.666575636182515, 33.96254110336304, 36.14565467834473, 34.295717648097444, 40.82424851826259, 32.994278362819124, 41.58185229982649, 50.826569489070344, 51.13380493436541, 43.88562829153878, 37.9529367174421, 53.86763620376587, 52.865233489445274, 46.361135959625244, 70.54668617248535, 76.91479355948312, 86.96908010755266, 78.2765223639352, 85.07566819872174, 77.32843371800014, 68.89217417580741, 74.08563995361328, 86.78398704528809, 80.88254846845354, 93.02209363664899, 82.0186345236642, 58.83336435045515, 68.57651751382011, 61.98453916822161, 66.3384541102818, 81.44407408578056, 51.39454998288836, 17.226854630878993, 0.6462546108024461, 0.3329169915190765, 0.33112701613988194, 1.2124817158494676, 1.325354767697198, 0.7648923333202089, 0.33630868952189175, 0.4368632366614682, 0.1657203717955521, 0.23320350210581506, 0.19815491565636226, 0.4698929914406368, 0.22441859064357622, 0.4668729677796364, 0.2722370432955878, 0.1525158632014479, 0.145597316590803, 0.2247584688344172, 0.12091279615248952, 0.15768334163086756, 0.1632191560098103, 0.1702887173742056, 0.19704598587538513, 0.212473171630076, 0.22374285118920462, 0.22055585363081523, 0.24877645075321198, 0.3334552054958684, 0.2273748591542244, 0.2971444624875273, 0.18989675092910016, 0.28121368161269594, 0.2512464267866952, 0.35370138766510145, 0.26210825251681463, 0.21482616822634423], [0.0699056563898921, 0.04368271725252271, 0.08517586306801864, 0.10705538759274141, 0.08379515287067209, 0.06050096425626959, 0.27400248284850803, 0.21204279043844768, 0.0812901576448764, 0.12893844049956116, 0.09407898211585623, 0.06644068339041301, 0.1980657290135111, 0.11967227128999573, 0.031196644928838526, 0.10460268027548279, 0.06396869210792439, 0.11196944676339626, 0.02102926416721727, 0.28104092659694807, 0.2728605626949242, 0.16669824932302746, 0.19302316888102464, 0.01663757348433137, 0.11605031921395234, 0.07432124337979726, 0.08118750886725527, 0.06541936605104379, 0.14705547477517808, 0.22096604162028857, 0.15777497099978582, 0.18346658668347768, 0.25947901074375423, 0.12300619882132326, 0.18892191323850835, 0.584954454430512, 0.5350369129862104, 0.4670198570404734, 0.4235670986984457, 0.20320720598101616, 0.38094606144087656, 0.1595551347626107, 9.713396634374346, 24.03921593938555, 50.50584411621094, 56.46279879978725, 68.55170549665178, 52.342801911490305, 44.477930954524446, 85.50844369615827, 101.08202484675816, 97.56836250850132, 82.45546082087925, 81.4047542299543, 67.47213608877999, 63.405883516584126, 57.6521532194955, 53.25415195737566, 60.96514810834612, 74.91888182503837, 80.0537325995309, 72.28876631600517, 53.84872668130057, 34.78120912824358, 45.682606152125764, 36.79443229947771, 23.102169718061173, 27.69569502558027, 25.983556406838552, 29.13476596559797, 14.532230309077672, 10.324133736746651, 18.439270121710642, 30.430643217904226, 26.388073580605642, 5.273717471531459, 12.587852495057241, 9.300189001219612, 2.3295475116797855, 1.9643788550581252, 1.5818026810884476, 0.46889250512634006, 1.3947685744081224, 0.2267114826078926, 0.18994285059826715, 1.2122645846435, 0.8066421587552343, 4.285413954939161, 2.7428079077175687, 0.9858436371598924, 1.2320559855018343, 0.3572921949837889, 0.35744182552610126, 13.510324001312256, 13.690482105527606, 0.16029342157500132, 1.3430276193789072, 0.8683342369539397, 0.30081821392689434, 1.4201179913112094, 0.22091420154486383, 2.964826737131391, 4.412782251834869, 6.248246618679591, 8.208427241870336, 11.759805270603724, 23.655517305646622, 4.5671473400933404, 4.232818262917655, 6.4324728931699475, 16.716408695493424, 35.03410618645804, 45.132597173963276, 45.04896518162319, 34.253083501543315, 23.1724750655038, 27.076607057026454, 37.73184156417847, 32.85699585505894, 34.86704369953701, 41.850810119083945, 30.125221252441406, 44.973775250571116, 64.82101617540631, 68.76807934897286, 76.20614678519112, 78.22111048017229, 75.25884328569684, 72.7235220500401, 79.22238063812256, 79.62619604383195, 70.3538041796003, 48.0135634967259, 56.47774090085711, 56.3783677646092, 58.67354188646589, 49.00162165505545, 7.740652799606323, 10.513770920889717, 1.2787108591624667, 0.2974939894463335, 0.5305228094969476, 1.2059166452714374, 0.878475512777056, 0.617077605000564, 0.5132165838565145, 0.5584817635161536, 0.20917169164334024, 0.15613949804433755, 0.10148843524179288, 0.33024749904870987, 0.08769332976745707, 0.23392326491219656, 0.2719288526901177, 0.06727242483092205, 0.07047950702586345, 0.07642158746187176, 0.061984567503843985, 0.06710567485008921, 0.04418248204248292, 0.07945261696087462, 0.16901338366525515, 0.19665277483207838, 0.0880260154871004, 0.20694825452353272, 0.11143385193177632, 0.21379773983997957, 0.15665977155523642, 0.48754657272781643, 0.09555871771382433, 0.07900979822235447, 0.051006712285535674, 0.07201039059353725, 0.022786430681922605, 0.07686694392136165, 0.111670565658382, 0.009521540952846408, 0.004324122165728892, 0.09820405433752707, 0.04359113198838063, 0.07264421693980694, 0.13305264259023325, 0.12124974307204996, 0.18106972958360398, 0.12189644122762339, 0.07892083549605948, 0.07266721249158893, 0.04254808456503919, 0.20067400405449526, 0.09476031269878149, 0.11361696371542555, 0.08412586405341115, 0.055725478899798224, 0.10434675722249917, 0.031110610081148998, 0.20874584306563648, 0.16569633808519157, 0.12927113978990487, 0.13756635252918514, 0.046252125807638676, 0.15674232212560518, 0.03249485544594271, 0.05206335076530065, 0.11345736549368926, 0.21558092986898764, 0.07906319214297192, 0.058827791895185194, 0.15217385441064835, 0.14330331182905606, 0.1468254378331559, 0.16863562964967319, 0.7840981313160488, 0.7749840489455632, 0.24486960896423884, 0.07728828702654157, 0.304256975118603, 0.19239114065255436, 0.0727263128917132, 5.341322141034262, 31.095075130462646, 63.64768777574812, 73.64322035653251, 78.36965601784843, 72.41231223515102, 48.934592383248464, 80.8170964377267, 105.65386308942522, 103.29674230303083, 93.53094496045793, 83.65615817478725, 73.1576316016061, 74.06983280181885, 70.62237984793526, 63.33537319728306, 68.72176265716553, 84.37553991590227, 94.8880810056414, 79.32126045227051, 54.24643462044852, 42.0631296975272, 58.943173680986675, 42.70599787575858, 35.976688385009766, 43.47966936656407, 47.89677470070975, 54.79474823815482, 37.25884294509888, 25.54727554321289, 26.994965723582677, 31.853703771318706, 38.3979549407959, 16.13861734526498, 17.95155348096575, 8.932338339941841, 0.6279562041163445, 1.2726165290389742, 1.6185648398739951, 1.8053346978766578, 0.7794186824134418, 0.10469031307314124, 0.16168726821030888, 3.000028048242841, 0.3596799054316112, 4.883138818400247, 5.276244444506509, 1.3174160165446145, 0.6379503192646163, 0.26762495934963226, 1.6079668828419276, 14.14497332913535, 16.71530393191746, 0.4163746275007725, 1.1485379870448793, 2.022695085832051, 0.48940054752996986, 2.3256925642490387, 1.2322571575641632, 7.690581474985395, 8.378511326653616, 11.506801383835928, 15.749493905476161, 23.00302587236677, 43.930207933698384, 32.855515888759065, 18.075356483459473, 16.135063341685704, 30.49277400970459, 41.232333592006135, 51.5400834764753, 54.78394031524658, 45.13114152635847, 39.131583963121685, 38.516564164842876, 43.24957282202584, 40.0226800101144, 46.46179798671177, 56.0859945161002, 41.81724337169102, 45.61148091724941, 67.15632656642369, 78.21984590802873, 78.71425887516567, 75.67285864693778, 76.5574129649571, 73.55147634233747, 73.57955401284354, 79.58441652570451, 71.72262014661516, 57.64429828098842, 67.4759020124163, 59.839720589774, 69.01321874346051, 52.865535736083984, 14.939504180635724, 0.06399095484188624, 1.2323086176599776, 0.31272967904806137, 0.38415051091994556, 1.0085824855736323, 0.7523987665772438, 0.5026610759752137, 0.7722268626093864, 1.1321426268134798, 0.3019572299505983, 0.06606051379016467, 0.05180002489526357, 0.20141756986933096, 0.07573625352233648, 0.062143636468265734, 0.013349502197732883, 0.1390217151492834, 0.07831056788563728, 0.09578848324183907, 0.048399044533393214, 0.07082642162484781, 0.07826494997633354, 0.10439520462283067, 0.08547007585210459, 0.10147340569112982, 0.12489809016031878, 0.14371168134467943, 0.05054812100050705, 0.141971958268966, 0.16077756988150732, 0.2976333876805646, 0.08603057970425912, 0.04897883574345282, 0.0992301417780774, 0.11042993223028523, 0.09200441557914019, 0.08521968285952296, 0.1274197841329234, 0.09772031315203224, 0.11242616189909832, 0.16460781863757543, 0.15324598045221396, 0.14011125239942754, 0.3092515356838703, 0.28922001485313686, 0.28033877855965067, 0.481551145868642, 0.2066491562873125, 0.24940938821860723, 0.11914464245949473, 0.24473838029163225, 0.14176956484360353, 0.3383551239967346, 0.18180972630424158, 0.13701441857431615, 0.3431026435324124, 0.1738290281168052, 0.3042260339217526, 0.3703092379229409, 0.16408352819936617, 0.2924251700086253, 0.15522613562643528, 0.2086292707494327, 0.10852605117751019, 0.2646224961749145, 0.21613409875759057, 0.23256994038820267, 0.5761996699231011, 0.2102153870676245, 0.2583788883473192, 0.23291403906685965, 0.17275539572749818, 0.10130301876259701, 0.8369236024362701, 0.42390832038862364, 0.8399405862603868, 0.5505675481898444, 0.39880770870617455, 0.7202054826276643, 0.18612340411969594, 20.890825612204416, 60.94274016789028, 88.51633971078056, 80.48842579977853, 99.6052964074271, 72.79348346165249, 56.21468905040196, 84.35628645760673, 102.65065016065324, 111.71604129246303, 96.28300830296108, 81.52420766013009, 74.33974947248186, 80.17574296678815, 68.08319541386196, 59.165863445826936, 71.0586086000715, 84.6402176448277, 94.15809631347656, 93.30774102892194, 64.17667497907365, 46.400077138628276, 59.83927590506417, 48.86142437798636, 38.87525449480329, 43.14631216866629, 59.042859486171174, 73.81956563677106, 44.165553842272075, 29.305121898651123, 41.58655623027256, 56.12850359507969, 60.65646743774414, 23.861213513783046, 42.50839805603027, 22.389102152415685, 4.491302107061658, 6.502056062221527, 5.313703051635197, 5.141241380146571, 3.665740166391645, 0.1862266907202346, 0.23021010415894644, 7.222908215863364, 2.4744482849325453, 6.16802271774837, 7.2916037525449475, 3.539645561150142, 2.4740075085844313, 0.8078523395316941, 2.372149957077844, 18.393651723861694, 17.580580472946167, 0.88177547284535, 5.4440608109746655, 3.276428908109665, 1.259605918611799, 3.0070146790572574, 2.2009965011051724, 17.08957212311881, 22.28710780824934, 27.930165461131505, 27.01178731237139, 39.2593126978193, 56.50485624585833, 44.815193040030344, 19.21612909861973, 22.928230251584733, 48.07840756007603, 67.33025387355259, 79.28505338941301, 80.40945257459367, 59.080129623413086, 47.485747064862935, 45.68153265544346, 50.48341185706002, 42.16115140914917, 47.93382249559675, 52.74403953552246, 43.65209238869803, 49.08234235218593, 71.45610809326172, 86.74438231331962, 88.43004308428083, 72.683486529759, 71.77250126429966, 75.6324965613229, 75.75355502537319, 74.64193357740129, 73.26125703539167, 60.986993244716096, 74.93867724282401, 62.56512369428362, 76.1659653527396, 84.37789535522461, 48.042318616594585, 21.101142372403825, 1.152989502464022, 0.27367371906127247, 0.2701239766819136, 0.8195413265909467, 0.9433398778949464, 1.579267457127571, 0.841365672647953, 0.9677855947187969, 0.4564809054136276, 0.3484729496496064, 0.14029639746461595, 0.2110708433070353, 0.08879907721919672, 0.26634535087006433, 0.3719289552952562, 0.1628450389419283, 0.17993068641849927, 0.21869631484150887, 0.11854947225323745, 0.12432493163006646, 0.15581639323915752, 0.28224209642836023, 0.20742079988121986, 0.4185708553663322, 0.20885127383683408, 0.18017703534236976, 0.19934613816440105, 0.4004740278635706, 0.4733112337333815, 0.6685765673007283, 0.22300153811063084, 0.10126654750534467, 0.20215325110724994, 0.1581616952483143, 0.18258170916565827, 0.3307012489863804, 0.30874382864151684], [0.11672753787466458, 0.0513722289220563, 0.007195553442995463, 0.03058540022798947, 0.127262947548713, 0.18819898845893995, 0.18811315377908094, 0.20886831863650254, 0.06353234659348216, 0.11764768564275332, 0.06768525910696813, 0.056735654694161246, 0.14442520162888936, 0.09779825646962438, 0.19645749245371136, 0.06318254143531833, 0.039557071668761115, 0.16503838981900895, 0.07698234237198319, 0.0687765876895615, 0.14705202781728335, 0.23948543359126362, 0.018284875001492243, 0.205313093694193, 0.2826108666402953, 0.1723395080438682, 0.05624612560495734, 0.3969832094652312, 0.2795737710382257, 0.15720515086182527, 0.1353769235845123, 0.16563388572207519, 0.4267942112471376, 0.29684034309216906, 0.24141529574990273, 0.3795999565294811, 1.1678756922483444, 0.21784274492944988, 0.7692900002002716, 0.2517124446375029, 0.08533987176737615, 0.7440919237477439, 0.8873041218944958, 19.930803435189382, 39.93968377794538, 54.17636203765869, 49.828273160117014, 62.82543795449393, 58.13540390559605, 49.82422930853707, 78.34932558877128, 96.13498388017926, 107.19885063171387, 103.44892869676862, 107.51955168587821, 97.80230140686035, 96.79976667676652, 108.95686994280133, 99.53375080653599, 80.16560554504395, 77.33542360578264, 52.38520676749093, 41.55227034432547, 51.66103771754673, 37.38149602072579, 28.371787752423966, 28.412384339741298, 18.095443725585938, 18.41735897745405, 13.882269757134573, 12.095609102930341, 19.984486954552786, 15.348619324820381, 17.43749621936253, 12.98676073551178, 4.146045684814453, 16.971807105200632, 19.485340527125768, 0.7846853083797863, 1.2943432203360965, 3.948830621583121, 5.006007722445896, 4.5099115542003085, 0.5475698347602571, 0.3645460871713502, 1.411705134170396, 2.173303369964872, 0.07992352704916682, 4.314897767135075, 1.959062614611217, 1.2102048780236925, 1.3549160957336426, 4.013024159840175, 12.41171305520194, 3.680904609816415, 1.8811828621796198, 0.5477389799697059, 0.1252801732293197, 1.6702043946300233, 1.0587057045527866, 2.176897542817252, 6.7536755204200745, 3.419262375150408, 3.253550010068076, 7.248055483613696, 18.60150534766061, 21.61576417514256, 6.064914056232997, 2.267094280038561, 3.319354227610997, 17.51918271609715, 21.405711446489605, 24.21956511906215, 30.74375683920724, 37.54864536012922, 36.97154882975987, 31.546999863215856, 25.12648916244507, 40.963108267102925, 37.401402609688894, 45.009850297655376, 60.3182430267334, 46.60847793306623, 48.976893016270225, 62.604804856436594, 64.99055916922433, 71.325850214277, 74.1808441707066, 78.70962442670549, 72.52397673470634, 68.76189545222691, 59.848767144339426, 64.8122614451817, 58.42960453033447, 53.45767511640276, 31.09738540649414, 4.90274316072464, 7.195225289889744, 1.8679476295198714, 0.3239888277437006, 0.7050812084759984, 1.262150913476944, 1.0958542483193534, 0.4583303747432572, 0.9745166621037892, 1.0817511422293526, 0.3898678741284779, 0.2768676648182528, 0.3555281939251082, 0.41924179079277174, 0.09094769228249788, 0.21066145598888397, 0.34294155931898523, 0.03175642953387328, 0.02631220720442278, 0.021935400187170932, 0.1513616887054273, 0.059049163945019245, 0.038105172969933064, 0.06564707561795201, 0.2001947412001235, 0.17925964242645673, 0.06038747927440064, 0.09893003252467938, 0.2561002591890948, 0.06410549833838429, 0.15177469940057822, 0.15346654504537582, 0.1373042751635824, 0.09518335214150803, 0.08622975008828299, 0.027440593977059637, 0.048269088113946576, 0.1016306018989001, 0.029620645567774773, 0.0773480591763343, 0.0806279346080763, 0.035243923110621314, 0.02103096729011408, 0.016874107399157116, 0.07656704501381942, 0.3259490882711751, 0.27464109286665916, 0.19374918778027805, 0.0582971435838512, 0.061193422813500674, 0.05371800251305103, 0.10713684572173016, 0.24360167128699167, 0.06987190605806452, 0.1373674196324178, 0.108438900139715, 0.015210571931675076, 0.12193339424473898, 0.11407860501536302, 0.20383083394595555, 0.18405269166188581, 0.43685327576739447, 0.1710155505154814, 0.1781420816800424, 0.18071273873959268, 0.09213380542184625, 0.07290690498692648, 0.24218147035155976, 0.16506436413952283, 0.11396216840616294, 0.05290451366454363, 0.2945323469383376, 0.3611368015408516, 0.340326403932912, 0.16703066362866334, 0.23720463312097959, 0.700077799814088, 0.3015431064580168, 0.5934619264943259, 0.3944998527211802, 0.1262015559311424, 0.8795770736677306, 0.4980220134769167, 13.82006253514971, 56.53909349441528, 64.81201131003243, 60.55154269082205, 71.41795553479875, 80.96596159253801, 62.23566790989467, 73.54458372933524, 95.84488269260952, 113.59406294141496, 114.97100830078125, 106.9926906313215, 96.04744352613176, 98.4870046888079, 114.63566739218575, 108.17944989885602, 86.50620501382011, 73.21794891357422, 48.43445757457188, 50.63091516494751, 61.06711292266846, 41.57301419121878, 48.75051723207746, 66.07166412898472, 49.343757901872905, 34.528503145490376, 23.467129060200282, 16.815470899854386, 19.709845508847916, 25.20857344354902, 43.65545531681606, 40.90365947995867, 19.348930018288748, 31.50796835763114, 17.379285948617117, 0.874791501888207, 1.2984182302440916, 2.983279198408127, 2.7578307815960477, 2.0169786725725447, 1.9650851828711373, 0.27396586909890175, 1.6398769191333225, 1.6402735092810221, 0.13328985843275273, 1.3566314322607858, 1.8513981061322349, 1.9006669138159071, 0.8042597408805574, 3.092193296977452, 15.841072899954659, 6.4174018161637445, 1.5498024267809731, 0.7425640800169536, 0.9099498753036771, 1.28083407666002, 0.32483498805335587, 3.606657462460654, 7.669082880020142, 7.8042661632810315, 14.055238212857928, 11.231922830854144, 28.544921227863856, 45.217222758701865, 24.717092616217478, 11.107528362955366, 23.162056241716655, 31.833039828709193, 37.870885440281455, 47.97802693503243, 46.269732407161165, 38.54727520261492, 33.41611739567348, 45.51844106401716, 50.18231167112078, 61.89599132537842, 54.0475354875837, 53.51170083454677, 72.28944723946708, 65.38070746830532, 56.833446979522705, 61.559858322143555, 66.10172203608921, 72.99884441920689, 76.45346096583775, 74.66300746372768, 68.19319929395402, 70.26178918566022, 65.51170880453927, 70.43759945460728, 68.2483263015747, 63.97731726510184, 32.21627467019217, 10.097130009106227, 4.987793019839695, 2.521415718964168, 0.6515729682786124, 0.5812757632562092, 0.9300727269479206, 0.7535889169999531, 0.5114152633718082, 0.8398487940430641, 1.569555503981454, 0.3998796311872346, 0.1748401810015951, 0.3026261840547834, 0.14991038372474058, 0.0359332705847919, 0.04485949714268957, 0.18805382267705031, 0.15905122751636164, 0.044833095345113955, 0.02272256018061723, 0.07449059893510171, 0.030917414197964326, 0.06288897325950009, 0.2635805920830795, 0.17884707956441812, 0.1595457981207541, 0.117626569632973, 0.16868870465883187, 0.23530761205724307, 0.020774598100355694, 0.10022171214222908, 0.09722571540623903, 0.08058763641331877, 0.08638421179992811, 0.09131982802812542, 0.05070705086524997, 0.10381752026400395, 0.0489609224189605, 0.03668202379984515, 0.05540615692734718, 0.2719698090638433, 0.19579959847033024, 0.12269466982356139, 0.09585048777184316, 0.29094118678144043, 0.5513230019382068, 0.302558601966926, 0.23516989658985818, 0.1878769150269883, 0.2612153818564755, 0.18954326132578508, 0.2384546846151352, 0.32608506668891224, 0.2657516598701477, 0.2256317026913166, 0.2571718016905444, 0.13946482565786156, 0.2854413076170853, 0.2992956627692495, 0.22123308586222784, 0.14057207267199243, 0.3269394779843943, 0.23717914734567913, 0.3865822990025793, 0.3354627734848431, 0.10256452392786741, 0.1148498822003603, 0.4238889957112925, 0.21963787717478617, 0.2949548842651503, 0.2376003818852561, 0.49247279124600546, 0.538663709802287, 0.44902787676879335, 0.37378689274191856, 0.35382949507662226, 1.0235433684928077, 0.40310074548636166, 1.1252971312829425, 0.5129843620317323, 0.17795483315629618, 0.5546439694506782, 0.4571961356060845, 44.16903141566685, 69.78072370801652, 74.20474597385952, 61.97615964072091, 87.102096421378, 79.65050084250313, 66.05758013044084, 71.20186655861991, 89.6226874760219, 119.07605961390904, 113.94202872685024, 107.3044285093035, 94.08258329119, 95.54731913975307, 102.90189007350376, 103.36169406345913, 106.86451026371547, 91.77761568341936, 63.01325471060616, 53.208665575299946, 57.886224133627756, 42.00912829807827, 48.563141686575754, 71.47258227212089, 63.949427195957725, 54.682788440159385, 42.12568780354091, 36.05240985325405, 35.38362489427839, 34.84946475710188, 52.846320492880686, 48.73309462411063, 25.671163661139353, 42.93465266908918, 29.851806163787842, 10.841082317488533, 6.515695376055581, 12.724758063043867, 14.691620247704641, 11.535105739321027, 3.414253158228738, 0.2702299367104258, 4.014442895139966, 5.6796594602721076, 0.32678352349570816, 3.9508651409830366, 4.098355855260577, 3.463239912475858, 2.210670564855848, 4.868238840784345, 20.18293445450919, 9.784100634711129, 1.9320784168584006, 0.5728308249797139, 0.939936020544597, 1.8982600143977573, 2.454395132405417, 12.398698210716248, 20.37980123928615, 20.970969608851842, 23.19528947557722, 25.888194118227275, 52.936032158987864, 47.01872042247227, 33.36374882289341, 15.557888644082205, 36.13008376530239, 62.7867225919451, 69.26440307072231, 70.67518615722656, 64.17451408931187, 49.74525955745152, 43.027411120278494, 61.546017510550364, 65.01410661424909, 78.24468571799142, 63.03131307874407, 53.6689316204616, 60.00314916883196, 55.96033981868199, 55.554756096431184, 68.55241421290806, 67.7075480052403, 68.19173322405133, 76.1548273903983, 78.60208020891461, 70.33060414450509, 80.84738363538469, 78.1320971080235, 75.76506124223981, 67.07212829589844, 79.12016568865094, 73.04484149387905, 35.49616486685616, 20.22871960912432, 1.4592186531850269, 0.8445488161274365, 0.46456784861428396, 0.9543034838778632, 0.8066345591630254, 0.5997676881296294, 0.5346494966319629, 1.4791405498981476, 1.3927331864833832, 0.5140128039887973, 0.4238161753330912, 0.2912608581994261, 0.20310554786452226, 0.2431665403502328, 0.4273357093334198, 0.20507070741483144, 0.08920220844447613, 0.10363538110894815, 0.15002550397600445, 0.25510807814342634, 0.11880685415651117, 0.4912412773285593, 0.4239252566226891, 0.15353481923895224, 0.12933325288551195, 0.1949757891041892, 0.24426530567663057, 0.09683804799403463, 0.18313707650772162, 0.2434067146054336, 0.26682944489376886, 0.14902808463999204, 0.1091929425352386, 0.1822297666221857, 0.14253484377903597, 0.2294286218072687, 0.24289184223328317, 0.20821231098047324], [0.03423756407573819, 0.01006640202831477, 0.06277922022023372, 0.08167927712202072, 0.07833127677440643, 0.04110339190810919, 0.12953864543565682, 0.10240876621433667, 0.04111282693754349, 0.10042687399046761, 0.08548800953264747, 0.08438190245734793, 0.5247604187045778, 0.2996428555675915, 0.031393284377242835, 0.11722189134785108, 0.22820620025907243, 0.36695176522646633, 0.21498784955058778, 0.2725105471909046, 0.6757098702447755, 0.5758409691708428, 0.11066201834806375, 0.0685384693954672, 0.09945002105087042, 0.30607789169464794, 0.09087063784578017, 0.1248241298432861, 0.03597545510690127, 0.11124075443616935, 0.06208182192806687, 0.06063894435231175, 0.16563687127615723, 0.28809340244957377, 0.0843879414190139, 0.12993077082293375, 0.4599926769733429, 0.372377656932388, 0.16059775810156549, 0.2420043455702918, 0.2963283748498985, 0.21740774969969476, 0.414851180676903, 2.0936646376337325, 39.320640972682405, 42.299629007067, 46.29227236339024, 43.573105267116, 61.50985213688442, 70.05778312683105, 57.736295904432026, 86.92709214346749, 97.86717673710415, 110.7613935470581, 104.64641598292759, 101.81255149841309, 107.08749880109514, 96.116286277771, 94.64313616071428, 80.45245497567313, 54.40640994480678, 47.527224336351665, 55.19900138037545, 43.027293000902446, 30.30061115537371, 30.67521980830601, 25.184329441615514, 21.050877366747173, 16.262107678822108, 23.495161567415508, 26.852998392922537, 24.163771084376744, 21.31746585028512, 12.357665623937335, 8.769289306231908, 4.213006777422769, 8.07985256399427, 23.56142827442714, 4.826854935714176, 3.651344801698412, 4.741287435804095, 1.9208253749779292, 2.808335065841675, 3.5866030071462904, 0.3159016402704375, 0.9968595717634473, 1.6334501611334937, 0.47829379779951914, 1.191898654614176, 2.3459250671522955, 0.6949592030474118, 1.0804075343268258, 0.9531778757061277, 5.813304151807513, 1.6388729044369288, 0.5076427172337259, 2.235685382570539, 0.32107975812894957, 0.5841862442237991, 4.199116459914616, 0.357373266347817, 3.6627789310046603, 2.695712583405631, 3.7207668593951633, 4.377296933106013, 16.75096035003662, 33.38498599188668, 14.286945002419607, 2.773823146309171, 4.945072455065591, 8.169996755463735, 21.2566100529262, 25.622621808733257, 29.00220649582999, 41.75810030528477, 42.21741097314017, 50.344308921269004, 53.06736700875418, 47.30958938598633, 48.10961191994803, 46.04587187085833, 43.31091499328613, 61.16278266906738, 47.76851095472063, 52.763070651463096, 64.10165527888707, 61.392802783421104, 51.530936173030305, 49.8883055959429, 47.67669745853969, 46.62535163334438, 47.42913661684309, 55.84986693518502, 44.980351720537456, 11.925933224814278, 7.619650789669581, 5.812232392174857, 0.9257510559899467, 1.063473905835833, 1.196580437677247, 0.5915732106992176, 0.7950467552457536, 0.8445481104510171, 0.999126204422542, 1.025524365050452, 0.43859537371567314, 0.10618133270846945, 0.6327810223613466, 0.3974842940058027, 0.366479830550296, 0.08602139912545681, 0.47083740362099236, 0.005775127742838646, 0.07153364510408469, 0.04373818749029722, 0.01579633424989879, 0.03552294010296464, 0.012126304575109055, 0.30480949261358803, 0.089627297062959, 0.1412560631121908, 0.2633936421147415, 0.1664100755006075, 0.29940808245113915, 0.12350627913006715, 0.41667825835091726, 0.2309932421360697, 0.13109584259135382, 0.0721564656123519, 0.10207721364817449, 0.08921422529965639, 0.15213865201388085, 0.3215055252824511, 0.10093750551875148, 0.046973099799028466, 0.14526199815528734, 0.35279310068913866, 0.14374682945864542, 0.07301246467977762, 0.17389963647084578, 0.10895458675388779, 0.08752596910510745, 0.01840237182165895, 0.026386084400915673, 0.04464864917099476, 0.09596881749374525, 0.12594249126102242, 0.1757835346673216, 0.13699654596192495, 0.17578664235770702, 0.031148496083915234, 0.1027982249589903, 0.30447201643671307, 0.40133894288114136, 0.15557374911648886, 0.278872301535947, 0.1040239848994783, 0.17345624097755977, 0.08391604745494467, 0.11295849297727857, 0.13703077126826557, 0.2838498444429466, 0.023729389101000767, 0.10711471869477204, 0.30691886799676077, 0.07893667928874493, 0.06561681295612029, 0.07201919119272913, 0.020508800666513186, 0.060368331016174386, 0.5821116641163826, 0.7080661654472351, 0.27914450264402796, 0.40052508083837374, 0.22045574257416384, 0.19684452882834844, 0.2187283688357898, 0.2706555952983243, 0.9276004710367748, 1.088848727090018, 23.805824211665563, 57.32900987352644, 59.1731173651559, 64.37912464141846, 73.86233874729702, 85.63495649610246, 82.2472233091082, 101.37813622610909, 94.33862440926688, 106.43993364061627, 107.2080500466483, 107.90596185411725, 107.84225382123674, 99.54711219242641, 86.72544152396065, 68.63015065874372, 61.78460475376674, 67.24068464551652, 66.15034552982875, 55.59174830572945, 62.15152522495815, 63.38544191632952, 37.163819381168906, 20.272772925240652, 11.599290592329842, 15.730506215776716, 29.32493816103254, 27.28035776955741, 29.79010616030012, 34.47652019773211, 25.63402901376997, 20.939756563731603, 36.53248521259853, 23.936622313090734, 7.960635372570582, 5.4440547313008985, 4.826930063111441, 3.604713486773627, 0.2653777870748724, 3.552195744855063, 0.43703099765947884, 0.6397412717342377, 1.555688745209149, 1.8743697191987718, 2.4183168283530643, 1.6353016389267785, 2.501917770930699, 1.2433091359479087, 3.703663000038692, 8.529167379651751, 0.6978140984262738, 0.805564916559628, 0.8505365891116006, 0.65779773997409, 0.3785620422235557, 1.1660648179905755, 7.654293639319284, 4.953451982566288, 2.788687514407294, 7.545380626405988, 12.668957080159869, 20.103389739990234, 42.19799770627703, 17.931537457874843, 1.8074385906968797, 7.7467420271464755, 14.868337256567818, 23.965221098491124, 33.50242097037179, 41.87180062702724, 52.488262448992046, 48.80864238739014, 36.61217062813895, 47.13814605985369, 49.09633255004883, 60.689520018441335, 69.8040349142892, 54.388712882995605, 63.02625479016985, 62.75968715122768, 57.62989466530936, 65.90815217154366, 64.49832793644497, 56.09702130726406, 49.143312794821604, 49.13914734976632, 47.70619603565761, 50.91027443749564, 60.32980482918875, 54.74177517209734, 21.003754683903285, 5.6847381591796875, 5.234262560095106, 0.953970730304718, 1.207516142300197, 1.6163514043603624, 0.7948216987507684, 1.0642651319503784, 0.8202329980475562, 0.8399810812302998, 0.8832005049501146, 0.20662143134645053, 0.10612139092492205, 0.21819699449198587, 0.2865982641066824, 0.19718565552362374, 0.1041827756645424, 0.45453692972660065, 0.009038072877696582, 0.17224373961133616, 0.033089693170040846, 0.11118303824748312, 0.05924093151198966, 0.10490985307842493, 0.2075623558568103, 0.3166589124926499, 0.09180027831877981, 0.06104231306484767, 0.39230359771421974, 0.49662618551935467, 0.35164428661976543, 0.31794096369828495, 0.13776681891509465, 0.182986781001091, 0.20559197158685752, 0.07017688040754624, 0.14831609784492425, 0.06411881119545017, 0.15329834978495324, 0.11479397091482367, 0.04258428101560899, 0.19897408384297574, 0.49060253160340445, 0.1487954556941986, 0.19782140212399618, 0.22020567527839116, 0.17124215407030924, 0.27953770011663437, 0.3350992687046528, 0.32061376741954256, 0.14496688970497676, 0.1349519571023328, 0.2409094614642007, 0.6879114497985158, 0.7022435750280107, 0.29593582877090996, 0.10527892184576818, 0.24360324548823492, 0.4611930868455342, 0.4178102990346295, 0.434606917734657, 0.6741861520068986, 0.6884733310767582, 0.43845030292868614, 0.1966377520667655, 0.14654396793672017, 0.20033103174396924, 0.2601983392877238, 0.09764599999678986, 0.24277092729296001, 0.26085526975137846, 0.17911519589168684, 0.3139202908745834, 0.37704071242894444, 0.268745519220829, 0.29506228278790203, 0.5780991879957063, 0.5039013294237, 0.6475529468485287, 0.6697632436241422, 0.31864441452281816, 0.3227788640984467, 0.6864324605890683, 0.22257697874946253, 0.7934125172240394, 1.6392296510083335, 65.70642512185233, 75.5876042502267, 74.89558451516288, 71.4966299874442, 86.34417302267892, 89.61258479527065, 82.87474986485073, 98.49931689671108, 104.28121171678815, 107.63570472172329, 92.38713250841413, 98.732408114842, 97.5138191495623, 108.64088671548026, 102.5885819026402, 83.76545333862305, 63.44164589473179, 62.781177929469514, 62.084711347307476, 54.53882871355329, 62.95359052930559, 80.95126615251813, 69.26669597625732, 58.98620387486049, 37.649175371442524, 43.19825690133231, 47.645958627973286, 43.39102077484131, 36.498814242226736, 37.22030823571341, 23.805660928998673, 26.193232195717947, 36.64430257252285, 35.64732640130179, 22.826190744127544, 13.969520023890905, 12.438024146216256, 12.674602491515023, 16.881814037050518, 9.675967557089669, 0.4216018170118332, 2.4017644822597504, 2.9300900868007114, 1.9295123602662767, 3.355917602777481, 8.214633720261709, 4.05876328263964, 1.1749206227915627, 4.849512577056885, 7.922494973455157, 2.1860461490494862, 0.5772736008678163, 1.9657048753329684, 0.822835912661893, 0.2526640492890562, 13.748229452541896, 22.825598410197667, 17.619639771325247, 14.28881927898952, 18.88778328895569, 27.190121514456614, 43.077629225594656, 48.14675351551601, 27.18023075376238, 3.291891038417816, 7.569748827389308, 20.74195350919451, 56.56048699787685, 75.90100274767194, 79.36959212166923, 80.88499423435756, 71.49132851191929, 70.68654646192277, 76.53419208526611, 71.52377659933907, 85.56803144727434, 85.29780905587333, 67.64273520878383, 71.43900162833077, 56.21893439974104, 51.618024894169395, 65.81165558951241, 74.87308624812535, 67.98657376425606, 57.02594334738595, 57.60314410073416, 52.89573608125959, 50.71076386315482, 70.05357946668352, 99.78248936789376, 65.32219668797084, 25.098588671003068, 14.626618112836566, 0.8231322424752372, 2.986488397632326, 1.251983093363898, 0.37124553482447353, 0.4989648514560291, 0.6900340159024511, 0.6216531566211155, 1.3259464502334595, 0.805051401257515, 0.5349714479276112, 0.6358348642076764, 0.3349950185843876, 0.15999582968652248, 0.16950256670159952, 0.47362715963806423, 0.124473259385143, 0.16520427806036814, 0.16262272372841835, 0.3739237125430788, 0.20742607888366493, 0.40254070982337, 0.6875095942190715, 0.5048086121678352, 0.1637172142841986, 0.44537461708698955, 0.6180349364876747, 0.609225543481963, 0.5257864179355758, 0.2971966825425625, 0.15535026682274683, 0.3108026667365006, 0.2555411463337285, 0.25557686441711014, 0.24950446454542025, 0.21532052169953073, 0.4298470217202391, 0.20200922526419163, 0.08311210559414965, 0.20513822164918694], [0.1350760475865432, 0.24616989919117518, 0.07861441586698804, 0.15541487692722253, 0.07482291146048478, 0.13783849935446466, 0.12793107384017535, 0.23512356621878489, 0.12206865341535636, 0.31680132342236383, 0.19067625195852347, 0.0961874821888549, 0.1195256941552673, 0.5592956255589212, 0.129705225782735, 0.18366152979433537, 0.06932618069861617, 0.24537232198885509, 0.12390979033495698, 0.2952864978994642, 0.2701023449855191, 0.16349344700574875, 0.10519985216004507, 0.06104390083679131, 0.23201283599649156, 0.30496096877115114, 0.33846634945699144, 0.30781418138316696, 0.08856889099947043, 0.07844147086143494, 0.01960970614371555, 0.18080497879002774, 0.17285258908356937, 0.30452760202544077, 0.3245977722108364, 0.502759327845914, 0.05240281844245536, 0.24537348906908715, 0.5787962877324649, 0.0986987945756742, 0.5283976921013424, 1.3426590391567774, 1.4339991893087114, 2.0779200196266174, 7.007020737443652, 37.499135971069336, 41.400372300829204, 27.011929750442505, 29.443964276994976, 44.97769056047712, 72.61310127803257, 78.76860073634556, 80.36913912636894, 94.3772633416312, 118.38721520560128, 119.7164750780378, 101.44811848231724, 92.71906185150146, 74.24999959128243, 60.690840176173616, 56.13443388257708, 66.38506262642997, 55.024716241019114, 47.34375715255737, 51.45042044775826, 38.4250077520098, 20.24922374316624, 22.571224859782628, 20.218953916004725, 20.43792986869812, 12.43676131112235, 13.285982302256993, 4.8320565308843335, 5.045260267598288, 5.606342068740299, 3.906797928469522, 10.139532259532384, 17.128667899540492, 15.142188344682966, 6.049102561814444, 2.558270049946649, 1.074220923440797, 6.088465843881879, 5.745825852666583, 0.39670294736112865, 0.8007328787020275, 1.0182248481682368, 0.5421801496829305, 0.3585610826100622, 3.417165756225586, 0.5050824689013618, 0.8969708574669701, 0.5163639006870133, 5.251731634140015, 0.781347567481654, 0.30527654183762415, 0.303956356963941, 0.8347100040742329, 3.260101075683321, 1.1276408455201556, 1.7805542732988084, 3.893222885472434, 1.4804369317633765, 4.7251893281936646, 3.7116008826664517, 18.943749291556223, 14.49229988030025, 13.226632526942662, 3.022427086319242, 2.4632914321763173, 4.158228916781289, 6.312520929745265, 9.11330417224339, 14.379280482019697, 8.969393951552254, 14.75037247794015, 32.321446078164236, 53.39899410520281, 56.621460914611816, 52.88468844549996, 43.81670910971505, 49.640974044799805, 72.35811628614152, 91.7625241960798, 73.55332456316266, 59.05107920510428, 52.69146599088396, 52.13158014842442, 41.38195262636457, 41.41389002118792, 42.61154406411307, 33.63755995886666, 11.130972453526088, 2.656276128121785, 3.295665213039943, 1.1290597979511534, 0.23615363665989467, 0.28920020163059235, 0.07157967013439961, 1.2809652239084244, 2.18158540555409, 1.454382164137704, 1.0387695857456751, 0.9272280910185405, 0.7761131854993957, 0.10189930176628487, 0.13202198860900743, 0.2448621993618352, 0.04925790362592254, 0.05601363575884274, 0.1527924747871501, 0.3028983308800629, 0.021676223558772887, 0.34670333032097134, 0.1784782822110823, 0.1457330643066338, 0.1190331591559308, 0.2259937146944659, 0.15118769875594548, 0.36406628148896353, 0.46004565698759897, 0.21702787865485462, 0.5976258516311646, 0.25523105583020617, 0.11961466366691248, 0.20769059897533484, 0.11400391188051019, 0.09683172404766083, 0.0760884199823652, 0.039067474726055346, 0.03204698162153363, 0.06138290371745825, 0.09666160853313548, 0.03377432821850691, 0.061911367146032195, 0.181846272200346, 0.12179163470864296, 0.2536562303347247, 0.06026005039789847, 0.04384425947708743, 0.035550804143505435, 0.05635026376694441, 0.1708777536238943, 0.1894134304353169, 0.06027833691665104, 0.20121563784778118, 0.10074237241808857, 0.349606455968959, 0.12546098924108914, 0.38369138698492733, 0.28175650962761467, 0.3963645483766283, 0.11365451384335756, 0.134651528937476, 0.08080386516771146, 0.26340173025216373, 0.0639829006312149, 0.22453680501452514, 0.0537572795126055, 0.07577391221587147, 0.10914482083171606, 0.3047611266374588, 0.24637172264712198, 0.2859681493469647, 0.19063624553382397, 0.10543518167521272, 0.040465063481990776, 0.1540189404040575, 0.3571400131498064, 0.17752483194427832, 0.36752442164080484, 0.32709353257502827, 0.10548643821052142, 0.25700805761984413, 0.5085363207118851, 0.08166851555662495, 0.5533141493797302, 1.0047268867492676, 1.0667818997587477, 1.642806996192251, 4.759203800133296, 17.651191541126796, 43.95018400464739, 33.137699604034424, 49.52457087380545, 68.930910382952, 82.21463625771659, 80.25801658630371, 91.43634796142578, 103.81609235491071, 123.0519300188337, 124.99728666033063, 104.95431845528739, 87.01527173178536, 69.99770205361503, 68.70291914258684, 63.458592551095144, 64.38252231052944, 60.360043389456614, 75.48541014535087, 66.76200934818813, 47.764696393694194, 33.07380396979195, 26.481717927115305, 24.177514621189662, 24.335252625601633, 26.250610419682094, 15.832253898893084, 11.50233108656747, 11.139883518218994, 6.830761441162654, 9.607965537479945, 19.73197204726083, 24.4093690599714, 19.30880069732666, 6.190954378673008, 2.689186705010278, 2.4350467877728597, 4.900274813175201, 1.3366347338472093, 2.6763646730354855, 1.1436786992209298, 0.7232566103339195, 0.20396443749112741, 1.3842094838619232, 1.5250781306198664, 0.3795994951256684, 0.6223673554403442, 0.9623676283018929, 3.9081219945635115, 0.4719517209700176, 0.5853564185755593, 1.3613972451005663, 1.2187011135475976, 1.817769693476813, 2.4060782279287065, 4.763285432543073, 4.033853556428637, 3.544395740543093, 3.158156454563141, 12.692920548575264, 22.818559885025024, 21.45276291029794, 9.828406691551208, 5.2501044528824945, 5.41942206450871, 3.5726627494607652, 6.923563318593161, 10.815621512276785, 11.855584451130458, 27.232312713350566, 50.06277138846261, 51.443427085876465, 47.54191977637154, 49.74077102116176, 49.155722277505056, 46.797948360443115, 67.28033801487514, 74.90775775909424, 82.1937221799578, 82.70884772709438, 66.85223170689174, 55.34770325251988, 54.27093744277954, 53.08902106966291, 51.65460021155221, 51.23376866749355, 41.88060399464199, 16.20658462388175, 2.224973431655339, 3.692317460264478, 3.1376256133828844, 0.7423823411975587, 0.25060445123485153, 0.04364450216027243, 1.1899107098579407, 1.7170877988849367, 1.691133888704436, 1.5440677745001656, 1.0890749778066362, 0.8788350277713367, 0.11597676601793085, 0.16714867443910666, 0.13416819487299236, 0.19031122725989136, 0.13347094585852964, 0.19830526544579438, 0.43982542199747904, 0.036186489675726206, 0.20722540893724986, 0.21714116686156817, 0.11504756659269333, 0.38839493745139664, 0.12624777773661272, 0.08530781098774501, 0.38890837132930756, 0.48092054256371086, 0.29367516721997944, 0.2819341772368976, 0.7780005442244666, 0.49263167700597216, 0.09714625217020512, 0.33935295045375824, 0.23565029938306126, 0.04915441685755338, 0.05205717270395585, 0.08148723814104285, 0.12806868074195726, 0.08771696992750679, 0.0277786045002618, 0.09901771960513932, 0.13246466485517366, 0.32902996295264786, 0.2289068012365273, 0.12781611643731594, 0.1480827225106103, 0.1366306934505701, 0.1673669862960066, 0.5003527541245733, 0.3903953401105744, 0.1571986097842455, 0.30518797944699017, 0.38496616429516245, 0.6095192677208355, 0.2801933820758547, 0.55836228707007, 0.275124508355345, 0.4188370853662491, 0.21530897303351335, 0.420677760882037, 0.5514118086014475, 0.39544084508504185, 0.49428703103746685, 0.2619023849921567, 0.1093664982223085, 0.09879123818661485, 0.283606440361057, 0.4166643076709339, 0.2710343264043331, 0.38553833216428757, 0.43757214290755136, 0.15209222664790495, 0.2107783675725971, 0.42237420699426104, 0.7858170505080904, 0.5651429146528244, 1.3081562391349246, 0.7373714957918439, 0.1345381728772606, 0.1807237852896963, 0.5194385871291161, 0.2015075029007026, 0.4028205376650606, 1.3791919073888232, 0.8456991229738507, 1.7837779117482049, 5.022318184375763, 56.17159284864153, 66.08788817269462, 66.90764359065464, 74.92687225341797, 94.48491178240094, 115.12459823063442, 104.19845867156982, 91.04209327697754, 103.61292702811105, 115.26024096352714, 112.84813213348389, 111.31395598820278, 95.61651624952043, 73.44591236114502, 73.68837669917515, 74.33899211883545, 65.27576187678746, 59.1937187739781, 81.17443534306118, 94.51186384473527, 84.57315363202775, 74.0976116997855, 69.05353913988385, 62.057981627328054, 48.00596216746739, 39.71663965497698, 21.163401705878123, 14.157717193875994, 13.99554363318852, 7.961354511124747, 13.769677673067365, 16.886314732687815, 24.613924026489258, 38.6931665284293, 15.456111431121826, 7.5067208494458875, 8.503938470567975, 15.767689500536237, 10.353027820587158, 4.221781049455915, 1.4216202135596956, 0.999634400010109, 0.7142918056675366, 1.4711000727755683, 8.532698801585607, 3.5865943218980516, 1.2432961080755507, 1.8509705747876848, 6.8555599961962015, 1.2282675887857164, 1.4791062431676048, 0.8535009729010719, 1.7843700285468782, 5.310200725282941, 11.851438113621303, 12.086442691939217, 8.875938074929373, 8.598937715802874, 8.407342008181981, 25.177016462598527, 47.55120256968907, 26.82149178641183, 12.337994405201503, 5.507367151124137, 4.215096448149, 3.364773299012865, 10.889735341072083, 26.21737371172224, 40.95752886363438, 56.59762511934553, 66.14388370513916, 61.91613415309361, 68.67648819514683, 78.42196205684117, 86.1872340611049, 91.2585644040789, 100.55840860094342, 90.02482836587089, 84.2721507208688, 66.49779714856828, 59.999758447919575, 59.389331408909385, 55.19118813105992, 45.6730489049639, 46.322934763772146, 53.81570884159633, 67.29652731759208, 54.85373149599348, 27.385619504111155, 11.060812149729047, 6.3360709803445, 1.0981221837656838, 0.7134366344128336, 0.13019694654004915, 0.9264053808791297, 1.506652376481465, 1.258743364896093, 1.0330694573266166, 1.2697443174464362, 1.2298872790166309, 0.3832038188619273, 0.24989996903709003, 0.3412723903145109, 0.17021638554121765, 0.09961247590503522, 0.17612284288874694, 0.3156105487474373, 0.17091101541050843, 0.19409168511629105, 0.1648400133209569, 0.2402107332433973, 0.34726057041968617, 0.35764698737433975, 0.7961470133491925, 0.4088965744844505, 0.421775223421199, 0.2123682972575937, 0.4376739774431501, 0.8848393027271543, 0.555075137742928, 0.40464623112763676, 0.2286260234458106, 0.2294262062226023, 0.1139377411454916, 0.10826977528631687, 0.21100324764847755, 0.30014738706605776, 0.22822262080652372, 0.317923864615815, 0.18906523340514728, 0.20749585942498275], [0.29511200583406855, 0.4678267166018486, 0.30603017711213654, 0.20868447635854992, 0.09622090682387352, 0.28828781630311695, 0.1355265405561243, 0.018820279843306968, 0.026011517803583826, 0.24546093866229057, 0.13236722722649574, 0.1560062744787761, 0.042171117650078874, 0.16132582617657526, 0.24716278591326304, 0.2491030975111893, 0.33959136051791056, 0.40185430379850523, 0.23015261867216655, 0.3214596291737897, 0.07359544839709997, 0.10129738692194223, 0.25279894205076353, 0.4132994796548571, 0.2831995907638754, 0.1501116914940732, 0.3473111619906766, 0.10251745395362377, 0.13726645362164291, 0.05379497213289142, 0.07988565800977604, 0.18140257815165178, 0.08241632900067739, 0.07755390634494168, 0.058401522625769885, 0.2767685172813279, 0.3031683335346835, 0.1509313482259001, 0.47755419462919235, 0.6022064515522548, 0.5311085752078465, 1.273005193897656, 0.9427341903959001, 1.5172275347369057, 1.8821258630071367, 2.782287572111402, 22.889702490397863, 30.009158543178014, 7.0889608434268405, 9.684726629938398, 13.317283936909266, 25.4442389692579, 41.22555562428066, 65.42093058994838, 82.72298036302838, 95.22867475237165, 82.41673156193325, 76.855393409729, 60.42111805507115, 51.0286682673863, 49.01068558011736, 54.41639450618199, 67.87481893811906, 64.870299748012, 41.76677860532488, 12.075219614165169, 1.1827398432152612, 13.347685779844012, 12.935110432761055, 7.52999210357666, 5.926052570343018, 1.446866818836757, 2.6527505687304904, 2.08554653610502, 4.575162521430424, 4.0367149114608765, 8.784039463315692, 12.89634643282209, 12.45184758731297, 9.273634723254613, 2.808694417987551, 2.0812460354396274, 2.160311107124601, 7.987220917429243, 3.695599615573883, 1.2956445962190628, 1.8662201336451938, 0.021628436033747027, 2.1793860835688452, 1.067440350140844, 2.9290530681610107, 0.7217547680650438, 0.5521996148994991, 2.2928430012294223, 0.5506923443504742, 0.9850426401410783, 1.5462334411484855, 3.9727159227643694, 2.32444058571543, 4.029609075614384, 2.3867005705833435, 0.604262249810355, 1.4856403725487846, 2.7027350408690314, 3.14947663460459, 18.462372882025583, 4.811183708054679, 6.495324560574122, 2.726146561758859, 0.7691498420068196, 0.2425676110599722, 0.903244537966592, 0.23751770917858395, 1.3619190113885062, 6.938845447131565, 7.997439980506897, 9.170323695455279, 13.164817878178187, 11.457509994506836, 23.021138089043752, 22.372575862067087, 16.574236392974854, 16.350770166942052, 31.33703919819423, 57.32026209150042, 48.71237857001168, 37.49806594848633, 41.17812374659947, 44.274338313511436, 43.67600114004952, 24.920388221740723, 7.766491413116455, 1.3041938117572238, 2.884323388338089, 2.036160043307713, 1.463520348072052, 0.5267150881034988, 0.2927149587443897, 0.9323160180023738, 1.1191121488809586, 0.22086484490760735, 0.8172356103147779, 0.781815268099308, 0.19141320884227753, 0.08699961592044149, 0.009217570835192288, 0.26244765573314255, 0.32401930753673824, 0.03610449211139764, 0.042150880343147686, 0.1162927190640143, 0.2656556064529078, 0.3418787292071751, 0.2926815205386707, 0.34478627890348434, 0.2337071650794574, 0.3556383065879345, 0.170646658167243, 0.16636004032833235, 0.29291311811123577, 0.536118497805936, 0.5622467643448285, 0.29781021390642437, 0.2934800205486161, 0.1732679203684841, 0.07638634435300316, 0.1297091341444424, 0.04404576741425054, 0.035426248862807236, 0.11753271466919354, 0.10690433891224009, 0.25563049582498415, 0.10563131222235304, 0.0037806151917071213, 0.2582004064960139, 0.09808043204247952, 0.20758078486791678, 0.4293995957289423, 0.3378823479371411, 0.11993380582758359, 0.08088410193366663, 0.16750285614814076, 0.11154167793158974, 0.07043669825153691, 0.05342896016580718, 0.08687875526291983, 0.062356065426553996, 0.11696189029940537, 0.1787221205553838, 0.1956050760511841, 0.32795573345252443, 0.3246894287211554, 0.27245327883533066, 0.30281487107276917, 0.2882561151470457, 0.30668775896940914, 0.034427455493382046, 0.18415941164961883, 0.2376901384975229, 0.3190118276647159, 0.36287414974399973, 0.16430217932377542, 0.2758956498333386, 0.08979114291391202, 0.12282224797776767, 0.1298923385994775, 0.04383249367986407, 0.05447575988780175, 0.1310797884528126, 0.02927079630483474, 0.1052318654422249, 0.33652459936482565, 0.20237715409270354, 0.23734992103917257, 0.35851130528109415, 0.6886627237711633, 0.5817323901823589, 1.3921945925269807, 0.9635826945304871, 1.484656116792134, 1.6409936249256134, 2.386804359299796, 9.046585832323347, 13.995195354734149, 7.092839241027832, 13.847676413399832, 30.627013206481934, 42.52854783194405, 60.20789173671177, 81.41564900534493, 97.33278383527482, 105.55613667624337, 91.00944369179862, 77.33309595925468, 63.04224954332624, 49.66296509334019, 45.06499120167324, 60.36423315320696, 76.91847610473633, 69.69454520089286, 52.823363644736155, 30.416395936693462, 21.94778905596052, 21.752947671072825, 17.33131558554513, 8.854648794446673, 9.58125753062112, 3.6082488170691898, 2.021934909479959, 1.1062001160212924, 2.14286852308682, 1.9164545238018036, 10.721227628844124, 16.304592439106532, 28.861583641597203, 10.253058007785253, 1.7250713876315524, 4.35683057989393, 4.738416961261204, 1.74860081076622, 3.816404036113194, 2.2361884755747656, 1.6557274971689497, 0.139107061283929, 0.22098145793591226, 5.0280495796884805, 4.489171615668705, 4.234813264438084, 2.6323328529085432, 0.845968419952052, 0.5389620480792863, 1.1964853342090334, 1.4065578218017305, 5.090277212006705, 10.307029008865356, 8.662294864654541, 1.429218394415719, 2.059781312942505, 3.5622417543615614, 5.521460269178663, 9.714451023510524, 18.169744287218364, 17.84688581739153, 8.685838835580007, 1.9040545948914118, 1.156689309648105, 1.201758365545954, 1.0118290313652583, 0.17883228750101157, 1.428998006241662, 1.9849424830504825, 1.8089117173637663, 11.585830194609505, 26.82967155320304, 28.850060054234095, 29.60732684816633, 24.27193716594151, 19.95845205443246, 24.13269179207938, 37.912105628422324, 51.40856449944632, 50.85968460355486, 47.60138245991298, 47.36016879762922, 50.48410667691912, 47.781101090567454, 27.67724061012268, 5.697381275040763, 3.2984034546783993, 1.6896869263478687, 1.0919805190392902, 1.1910793100084578, 0.49368145210402353, 0.589333068047251, 0.8262225623641695, 0.6997777244874409, 0.17963062466255256, 0.4707180900233132, 0.8268982746771404, 0.3653942830860615, 0.049252034298011234, 0.07950217037328652, 0.22230724750884942, 0.35125678884131567, 0.07002613028245312, 0.08791108522564173, 0.094319373502263, 0.1760936523122447, 0.18157992006412574, 0.4296929399882044, 0.31488657902394024, 0.1239367960286992, 0.17026380156832083, 0.2633898694600378, 0.13781817044530595, 0.22018839977681637, 0.2391727375132697, 0.7722895049623081, 0.3708164021372795, 0.2862423046358994, 0.06734121471111264, 0.11322935737137284, 0.2915760241448879, 0.059765568003058434, 0.07296845489846808, 0.10622717453432934, 0.13069923887295382, 0.1866178118756839, 0.09158351352172238, 0.04013147870344775, 0.02413011322330151, 0.10537591164133378, 0.6351715826562473, 0.7502859170947755, 0.3487240347479071, 0.21947979208614143, 0.2677523068019322, 0.3295517563819885, 0.21540143021515437, 0.3247870834810393, 0.17699195125273295, 0.3689873702824116, 0.2465069139642375, 0.2914342103259904, 0.41777821789894787, 0.21962381792919977, 0.7256265431642532, 0.42048804249082294, 0.2892775274813175, 0.29219283961824005, 0.32282375597528046, 0.24098097905516624, 0.13224651584667818, 0.19171568618289062, 0.23449879831501416, 0.5501301373754228, 0.3257388781223978, 0.3090585603245667, 0.37749424523540903, 0.1513206237660987, 0.1192138394606965, 0.14232109167746135, 0.10766669336174216, 0.16352734661528043, 0.17385562668953622, 0.17952564172446728, 0.2172020993062428, 0.3742068516356604, 0.3997209354170731, 0.3892301597765514, 0.38775953011853354, 0.5078797159450394, 0.7435115863169942, 0.8513470313378743, 0.5895331001707486, 0.8711950491581644, 1.4366292996065957, 1.7138046664851052, 23.260750191552297, 44.64755385262625, 60.148845945085796, 73.0566325868879, 72.09721837724958, 83.98776095254081, 97.45976911272321, 107.45721244812012, 110.76704243251255, 107.94063336508614, 89.68715981074742, 85.71536105019706, 63.552407128470286, 53.5596364566258, 48.145787715911865, 67.45415415082658, 91.52058097294399, 106.32350962502616, 100.05366366250175, 88.03252274649483, 62.509336607796804, 47.9712107522147, 24.07074339049203, 17.067164182662964, 8.67970791884831, 2.9345128323350633, 3.7807836617742265, 3.473876301731382, 3.7691271901130676, 12.342465570994786, 13.373419301850454, 12.455828036580767, 29.026054450443812, 19.67830068724496, 11.993655579430715, 10.872331840651375, 19.841567720685685, 35.470991543361116, 7.617079087666102, 5.471130124160221, 3.4212252412523543, 0.2540904927466597, 2.712890701634543, 11.658932191984993, 10.336524980408804, 6.535604136330741, 4.867099770477839, 5.971058223928724, 1.3025933376380374, 1.7674274976764406, 2.4114198727267127, 6.362372951848166, 22.054183346884592, 18.8164895602635, 7.09978483404432, 3.9238331743649075, 8.335972717830114, 12.183604563985552, 23.480525187083654, 42.447344235011506, 14.200417348316737, 5.384268956524985, 3.705310591629573, 0.6297087243625096, 0.5113417101757867, 0.6493911253554481, 0.1340851014746087, 1.7228660945381438, 6.9626647404262, 13.309022528784615, 19.982207945414952, 31.976151875087194, 39.73704998833792, 50.189725399017334, 48.44836091995239, 40.55458198274885, 59.64612293243408, 81.27261338915143, 96.68459333692277, 81.23533630371094, 59.749970708574565, 58.183704308101106, 59.72445692334856, 63.37153162275042, 48.859722069331575, 23.42934823036194, 7.412960120609828, 5.470424013478415, 2.128956926720483, 1.0007230958768298, 0.3140402558658804, 0.36349897193057196, 0.574610595192228, 0.6752427667379379, 0.48593822760241373, 1.1512231401034763, 1.9809003685201918, 0.8246990069746971, 0.18562903707580908, 0.3101526301886354, 0.44170526255454334, 0.3476464939968926, 0.09304558006780488, 0.1809145486248391, 0.29501426964998245, 0.6014975181647709, 0.3983346883739744, 0.5267565601638385, 0.3296995141676494, 0.29699692183307236, 0.48466670726026806, 0.31427654890077455, 0.22523371476147855, 0.6454565450549126, 0.982012791293008, 0.8790800060544695, 0.6216329091361591, 0.3421989977359772, 0.27009762238178936, 0.1356840149632522, 0.39518042334488457, 0.18201794156006404, 0.14290696595396313, 0.3047945105603763, 0.3178616836667061, 0.3012724795511791, 0.3231439430798803, 0.2390084234731538, 0.32901772218091146, 0.41151471542460577], [0.18532927387527057, 0.17105419987014361, 0.12764332070946693, 0.04006575580154147, 0.0768430255619543, 0.08113106153905392, 0.033453628819968016, 0.06744159718177148, 0.06278589700481721, 0.053861061443707774, 0.0686987190108214, 0.03872000372835568, 0.14041151771587984, 0.2967239607657705, 0.26374895019190653, 0.32517433698688236, 0.14645066937165602, 0.4488942325115204, 0.4944776179535048, 0.32073432952165604, 0.5363956657903535, 0.38638777658343315, 0.1743722768234355, 0.28114927506872583, 0.21395598777702876, 0.42087133335215704, 0.24538087153009006, 0.16947530316455023, 0.15814680819000515, 0.1571609510907105, 0.04607155067580087, 0.0905520317277738, 0.07108108260269676, 0.04289421545607703, 0.10145268323166029, 0.35226020642689293, 0.1601228785834142, 0.18409143601145062, 0.32094698239650044, 0.8444040438958577, 1.7407746421439307, 2.027102849313191, 2.3724637116704668, 1.5210422043289458, 1.0610164148466927, 2.039540559053421, 2.338190419333322, 2.026341370173863, 2.0230607347829, 2.325624167919159, 5.4648832593645364, 12.368552582604543, 14.242308037621633, 14.427579147475106, 25.491059405463083, 45.706087589263916, 60.85373374394008, 56.98830148151943, 53.56429869788033, 47.963487829480854, 45.79115438461304, 40.13437925066267, 39.735774993896484, 17.50418676648821, 12.193700296538216, 5.858364522457123, 4.81041636637279, 2.5243836854185377, 0.950718104839325, 0.28890598884650637, 0.7926386073231697, 0.4779888370207378, 0.2701326347887516, 0.5049882339579719, 1.1813974295343672, 1.1885690561362674, 0.21489218968365872, 5.698160341807774, 8.314513206481934, 8.048372881753103, 5.136877042906625, 2.8795645236968994, 3.8399814452443803, 9.406672750200544, 12.324431521551949, 0.37082090760980335, 0.5670801592724664, 0.11622471628444535, 2.0343598084790364, 3.5745124902044023, 4.971340988363538, 2.8624949710709706, 1.9685193300247192, 0.5144871271082333, 0.13723602811140673, 0.27102954951780184, 0.6525813798819269, 0.10058256385049649, 2.7364631167479923, 1.1850278632981437, 0.8981537339942796, 2.1570806290422166, 0.7383341469935009, 2.799154758453369, 4.722506020750318, 6.013708872454507, 1.363002604671887, 0.30751234186547144, 0.5585469571607453, 0.09212095396859304, 0.10284971219620534, 0.1590946673282555, 0.23444969952106476, 0.14075835767601216, 0.20300235625888619, 0.8878895619085857, 2.521283051797322, 3.2003222491059984, 2.1864007243088315, 3.8288122160094122, 5.4131521838051935, 9.698865345546178, 10.011170370238167, 9.21687923158918, 6.327775265489306, 9.099720443998065, 17.517770494733536, 15.561020544597081, 17.16823615346636, 15.334356410162789, 7.507678832326617, 5.280465040888105, 2.8909176630633215, 0.2626848987170628, 0.4473860391548702, 1.3019373842648096, 2.1153458399432044, 0.6407248218144689, 0.22037168565605367, 0.007471863080614379, 0.046705451660922596, 0.08044327130275113, 0.13063289171883039, 0.2508057047213827, 0.10921143939984695, 0.13527800674949372, 0.039698183203914335, 0.18402852224452154, 0.22135835699737072, 0.10666159300931863, 0.21564863409314836, 0.1689879521727562, 0.08895645663142204, 0.11706912597375256, 0.08682938505496297, 0.10729544649698905, 0.22140031760292395, 0.008458435186184943, 0.04549973225221038, 0.21343165662671837, 0.1719056120408433, 0.07338797274444785, 0.27451176409210476, 0.22026446355240686, 0.12867765235049383, 0.09198140645665781, 0.01206364356247442, 0.06724103580095939, 0.0422311985333051, 0.18462951428123883, 0.1093452600762248, 0.28202455810138155, 0.14822928607463837, 0.07818539174539701, 0.12829056169305528, 0.1911395149571555, 0.09092557204088994, 0.16594637823956354, 0.10903409070202283, 0.09461019361125571, 0.04175397128398929, 0.10730599093117885, 0.0860830508172512, 0.12699122141514504, 0.07285350428095885, 0.11246757967663662, 0.09114207899464027, 0.07714212379817452, 0.30426036779369625, 0.0753653459250927, 0.0374961402932448, 0.1775836337889944, 0.12196497326450688, 0.48485718561070307, 0.4724753871560097, 0.6083657581891332, 0.40605774681483, 0.32561961880752016, 0.31077837518283297, 0.3166387735732964, 0.2568972664219992, 0.4883637460214751, 0.2526658677629062, 0.24266447871923447, 0.12281534049127783, 0.16383617504366807, 0.12101472568299089, 0.0373893592373601, 0.0643750870866435, 0.14569723765764916, 0.02605878794565797, 0.38473920790212496, 0.4565362738711493, 0.27706449425646235, 0.3125939449029309, 0.8341426402330399, 0.9936780567680086, 1.9109300545283725, 1.7198189837591988, 1.2776041414056505, 1.3428021286215102, 1.6984221147639411, 2.431085011788777, 2.6413066685199738, 4.546907237597874, 4.630034617015293, 10.7857312304633, 18.494094882692607, 26.192956004823955, 35.81584800992693, 52.580350399017334, 63.87154483795166, 75.42422430855888, 72.60427706582206, 62.42409610748291, 53.305554730551584, 48.68794175556728, 39.01689004898071, 34.71191126959664, 25.8063964503152, 15.555303914206368, 5.507295497826167, 7.247886989797864, 3.750681459903717, 2.1027203117098128, 0.8592028383697782, 0.6021558599812644, 0.7771982444184167, 1.4993558994361331, 0.6758295095392636, 1.4990000213895525, 3.337855326277869, 3.7925604241234914, 8.877758502960205, 16.355173587799072, 17.95203811781747, 3.966432579926082, 0.8749332342829023, 2.8030485723699843, 4.242858844144004, 3.1405151954718997, 2.2222388812473843, 3.893716641834804, 0.1069462045228907, 2.5406040378979275, 4.347122643675123, 6.595128919397082, 4.96097514459065, 1.6167938091925211, 1.1586451189858573, 0.13686729861157282, 0.8226167729922703, 4.837602496147156, 1.154438853263855, 8.619308965546743, 2.938749062163489, 1.0649229309388568, 1.414984466774123, 1.0337061945881163, 5.937686894621168, 13.754627874919347, 14.905741146632604, 3.931081448282514, 1.0975674135344369, 1.2275296683822359, 0.37525331548282076, 0.18048726155289582, 0.25195834572826115, 0.4331910322819437, 0.17837385567171232, 0.23384770325251988, 0.6586637677890914, 1.7352554925850459, 2.1966480144432614, 3.128295919724873, 5.350302687713078, 7.423503143446786, 7.631249938692365, 9.723046813692365, 9.978848218917847, 9.604056307247706, 11.917289665767125, 17.544672182628087, 17.444057055882045, 18.676703963960918, 17.983793122427805, 10.460062214306422, 8.140972392899648, 3.8608160529817854, 0.35758097948772566, 0.4949660003185272, 1.5689638214451926, 2.003066207681383, 1.1553686090878077, 0.22253189688282354, 0.1790066302887031, 0.0327916093436735, 0.04615590954199433, 0.22514775794531616, 0.118522385135293, 0.18285545733358177, 0.0235876244758921, 0.06899775617888995, 0.11237922763185841, 0.19545674829610757, 0.03558256636772837, 0.09306628895657403, 0.14655048187289918, 0.13728477406714643, 0.11254961456039123, 0.01291263336315751, 0.2171145547181368, 0.12666956867490495, 0.07994014437177352, 0.10365335550159216, 0.06992256548255682, 0.010088847966731658, 0.15782330983451434, 0.10252138945673193, 0.20259592735341617, 0.12764538345592363, 0.08596849375005279, 0.06074388657829591, 0.07430083304643631, 0.043881887636546574, 0.07872939362589802, 0.17319926619529724, 0.19537043864173548, 0.20932505412825517, 0.07363902391599757, 0.10505031661263534, 0.16576199313359602, 0.2905128683362688, 0.32409014659268515, 0.22246621469301836, 0.14930355628686293, 0.1907630908702101, 0.31482285101498875, 0.1659003599945988, 0.29347733354994227, 0.23248797335794993, 0.18079845128314836, 0.16448950927172387, 0.47529841853039606, 0.41124311142734116, 0.39596000579851015, 0.3367858353470053, 0.517425075173378, 0.4564876364810126, 0.5348336238946233, 0.4284532836505345, 0.5300452294094222, 0.5734361867819513, 0.3843715233462197, 0.4261877095060689, 0.637504114636353, 0.42310070086802753, 0.4306595538343702, 0.22630456515720912, 0.22071062746856893, 0.2942805833050183, 0.2701358103326389, 0.109232107576515, 0.16852563912315027, 0.36575705504843165, 0.3116647590483938, 0.29523164512855665, 0.8024708511573928, 1.1347562351397105, 0.6305345829044069, 0.4664833258305277, 0.9025321847626141, 1.7132060357502528, 1.7204530068806239, 2.276100231068475, 1.522917783686093, 1.3281012603214808, 1.6094522774219513, 1.6397700905799866, 2.955309876373836, 17.880384819848196, 24.094733783176967, 43.809382234300884, 50.476925713675364, 59.692543847220286, 82.29220594678605, 108.06956413814, 120.93265996660504, 101.26020445142473, 74.66918441227504, 62.7734306880406, 54.581851959228516, 68.99189472198486, 84.18215765271867, 87.23281288146973, 70.76217065538678, 49.03609166826521, 26.08878861154829, 12.321305700710841, 5.324769360678537, 2.9343888504164557, 0.42622730880975723, 0.5568719527551106, 0.7135130645973342, 1.5503264729465758, 0.9832460965429033, 0.9448208212852478, 3.4826633845056807, 2.812868765422276, 9.810122506959097, 16.521115677697317, 24.391411440713064, 11.990390794617788, 15.041540213993617, 25.081360612596782, 34.393246037619456, 31.77721800122942, 10.414490716797964, 5.087530502251216, 0.46386586342539105, 4.853734041963305, 13.81629661151341, 13.465773020471845, 12.154425604002816, 11.20144716330937, 6.920593397957938, 0.43986325711011887, 2.2536590695381165, 11.407998868397303, 20.80503273010254, 28.408276217324392, 14.004669223512922, 8.348010471888951, 9.932447280202593, 6.732206889561244, 14.06922059399741, 25.748134068080358, 15.363000358854022, 2.5598086416721344, 0.5652335669313158, 1.1212311323199953, 0.4497056518282209, 0.21793334292513983, 0.22500244288572244, 0.28228647261857986, 0.18286194412836007, 0.5139312712209565, 1.2019288135426385, 2.1463460964815955, 4.904574445315769, 7.54495678629194, 10.021145377840314, 18.207429579326085, 21.76021201269967, 19.62503058569772, 21.491158655711583, 24.52638714654105, 29.856100150517054, 39.6959479195731, 33.235561507088796, 30.460885252271378, 20.812324864523752, 8.385645389556885, 7.2108695932797024, 4.165214027677264, 0.4922809015427317, 1.4240774874176299, 1.4436485001019068, 2.005868285894394, 1.9474500034536635, 0.5704033523797989, 0.30800954518573626, 0.21203106535332544, 0.09638386379395213, 0.14835279301873275, 0.22169454395771027, 0.29195695370435715, 0.1894639948649066, 0.31551539099642206, 0.42337444903595106, 0.3314009814390114, 0.27529786048190935, 0.27993306890130043, 0.4078388198145798, 0.34813080515180317, 0.2947860104697091, 0.2951266350490706, 0.32592688660536495, 0.3573979650224958, 0.23527232823627336, 0.29504428803920746, 0.3807857371866703, 0.6331328291978154, 0.4190810051347528, 0.7160515998091016, 0.5087437352963856, 0.3175080312149865, 0.18789953738451004, 0.13811475810195717, 0.1467102632990905, 0.20290936981993063, 0.3693025905106749, 0.35583798587322235, 0.4295620912952082, 0.23114916948335512, 0.17801374356661523, 0.41517956448452814, 0.5531519523688725], [0.07216964276241404, 0.03759336079071675, 0.06079308036714792, 0.05759087683899062, 0.038594006560742855, 0.07283909898251295, 0.0863761915160077, 0.04994983971118927, 0.0812804749501603, 0.04383932313482676, 0.008913105386974556, 0.08389511464961938, 0.011598450131714344, 0.04579130553507379, 0.1603947268532855, 0.14185368961521558, 0.02813792271938707, 0.17182835404361996, 0.09325002266892365, 0.1093991764688066, 0.17834120456661495, 0.20253352927310125, 0.2029275138463293, 0.18845242128840514, 0.18787010253540107, 0.15550740196236543, 0.3282937524574143, 0.1790860460272857, 0.2608717174402305, 0.2575339494006974, 0.08776028081774712, 0.0023371670104097575, 0.06841418892145157, 0.09480391535907984, 0.04656202971403088, 0.01464501129729407, 0.25437121625457493, 0.15248048438557557, 0.16940476266401155, 0.10744673945009708, 0.4657720039997782, 1.0261043225015913, 1.052558611546244, 0.1294576690665313, 1.1374800375529697, 0.5933682886617524, 1.1770472058228083, 1.3653640151023865, 0.39184363239577835, 1.5528165336166109, 3.880422132355826, 6.963907165186746, 9.896692718778338, 8.066321815763201, 6.879301122256687, 6.1214128988129755, 12.47086306980678, 20.020681858062744, 20.637496028627666, 16.088262013026647, 9.50747287273407, 11.15297566141401, 8.408790707588196, 4.529310056141444, 1.6095242564167296, 1.2048099275146211, 0.3081327128623213, 0.2282130941748619, 0.368336519492524, 0.7260422951408795, 0.6178445124200412, 0.316382531608854, 0.18913286977580615, 0.174135970217841, 0.14069928441728863, 0.35452263216887203, 0.5612126226936067, 0.5468899969543729, 2.2114018627575467, 1.3432620125157493, 3.4686154297419955, 1.9810818902083804, 1.2398257000105721, 4.2136447089059015, 6.768337087971823, 7.093204021453857, 2.0732219517230988, 0.41552770723189625, 0.7002957995448793, 1.7626453999962126, 3.2786742619105746, 3.311214630092893, 1.1889863823141371, 0.4230574374752385, 0.0684005639382771, 0.9033256907548223, 0.5943141664777483, 1.9380886086395808, 2.7024280173437933, 3.358936595065253, 1.619927229625838, 0.25409673526883125, 1.3586174228361674, 4.671261753354754, 3.0803985127380917, 1.085956756557737, 0.23013112268277577, 0.03167237600843821, 0.2300282839153494, 0.5593316150563103, 0.06878719997725316, 0.1645827806953873, 0.06739487326038734, 0.1027857738413981, 0.22171998902090959, 0.1947331449815205, 0.09152469810630594, 0.8703546971082687, 0.5956634197916303, 0.08105695872966732, 0.26064147693770273, 0.9693694583007267, 2.129229643515178, 3.123224820409502, 1.9459107603345598, 2.905565985611507, 4.182301819324493, 6.008088214056833, 8.814919863428388, 5.813740585531507, 3.723870098590851, 1.8802079430648257, 0.39963351296527044, 0.5736222682254655, 0.21278516203165054, 0.8537886717489788, 0.6055169967668397, 0.17582362251622335, 0.08861305005848408, 0.13582852935152395, 0.12436109754656043, 0.06877386676413672, 0.14735621506614344, 0.0883577037602663, 0.020074809668585658, 0.06987650652549096, 0.11184789400015559, 0.14970094710588455, 0.12579603626259736, 0.023447089695504734, 0.02436426717654935, 0.04433623807770865, 0.030433367671711103, 0.07318784562604767, 0.01670604445306318, 0.02614653779060713, 0.07612735432173524, 0.13022780631269726, 0.02408234096531357, 0.023846285417675972, 0.12939390034547874, 0.05108333585251655, 0.10855768448007957, 0.19363220834306308, 0.22686412584568771, 0.08364794469837632, 0.04260888469538518, 0.01845779286564461, 0.067112908033388, 0.11756461938577038, 0.043602178538484235, 0.027147602556007247, 0.097511887550354, 0.11101864278316498, 0.04786354808935097, 0.09934825436877352, 0.21961153644536222, 0.026536634358178292, 0.07006333435752563, 0.04888108598866633, 0.04498596249946526, 0.013689890986175408, 0.06838689824300152, 0.03566871317369597, 0.0861358679831028, 0.016329357433798056, 0.04922656548608627, 0.10419802913176161, 0.026093052267762165, 0.06371705739625863, 0.11776488221117429, 0.14669738470443658, 0.23490458939756664, 0.12020402561341013, 0.15359636236514362, 0.09899415408394166, 0.057900702713855674, 0.09264189922916037, 0.274715460304703, 0.270787773919957, 0.16711104288697243, 0.07761694903352431, 0.3069887299622808, 0.18383437980498585, 0.20439506295536244, 0.16263573803007603, 0.10515492635646037, 0.06334745258625064, 0.08458466907697064, 0.09869318309106997, 0.12478500551411084, 0.0305517482837396, 0.1987869438848325, 0.334727051534823, 0.14120085750307354, 0.29016298853925293, 0.46727726608514786, 0.6325493433645794, 0.5157931713121278, 0.44180329729403767, 1.295917530144964, 0.6301521062850952, 0.37525423829044613, 1.4352406369788306, 0.48619558236428667, 1.6416717256818498, 5.611857201371874, 12.690121293067932, 15.217908075877599, 16.053091968808854, 16.88970719064985, 22.531833784920828, 27.805982044764928, 29.599586554936, 20.595530646187918, 11.859923601150513, 6.63164040020534, 5.498232007026672, 2.7173503594739095, 3.375836785350527, 2.583384096622467, 1.3406434101717812, 0.32970499673060005, 0.230640566774777, 0.439626719802618, 0.6935314568025726, 1.1152694693633487, 0.16622520184942655, 0.2591707387140819, 0.16006236683045114, 0.20968668615179403, 0.6797603986092976, 0.7115668090326446, 2.8717944834913527, 9.472814389637538, 12.965629526547023, 4.656574998583112, 1.4147223894085204, 2.7129072036061967, 3.3558413897241866, 8.002226420811244, 2.1001097432204654, 4.347349762916565, 0.22094170935451984, 0.48673949603523525, 3.2826972688947404, 4.39056191274098, 7.66285468850817, 5.917624839714595, 0.532731468124049, 0.15133104606398515, 2.5662196576595306, 5.814732440880366, 14.107504299708776, 3.6210469646113257, 3.830136716365814, 1.9416217676230838, 2.550934272153037, 1.3431495385510581, 9.5662659236363, 14.86334150178092, 4.544400240693774, 1.2175059148243494, 0.09514583594032697, 0.2120669191437108, 0.37429625540971756, 0.027799064027411596, 0.06875028767223869, 0.03578176389315298, 0.04847612950418677, 0.3066967156316553, 0.40347510682685034, 0.1431028861552477, 0.14788104833236762, 0.6544881175671304, 0.2654456134353365, 0.13359855115413666, 0.4002757327897208, 1.014408984354564, 1.074340562735285, 1.4445717419896806, 2.5817187002726962, 3.237590649298259, 0.9878362502370561, 3.8005421672548567, 3.685873874596187, 0.7848035363214356, 0.6179185541612762, 0.2283470369875431, 0.34656642909560886, 0.33392347608293804, 0.7259683619652475, 0.27810441702604294, 0.023988523320960145, 0.15830521897545882, 0.0695922342794282, 0.037080727584127865, 0.06726578875843968, 0.14261961994426592, 0.10053236582981688, 0.11452072486281395, 0.02503414748103491, 0.06167202070355415, 0.27513313932078226, 0.07538566126355103, 0.03459663802225675, 0.02975986399022596, 0.04796527745202184, 0.07316044638199465, 0.067499069097851, 0.051428292877972126, 0.06882433619882379, 0.024565262819773385, 0.1482532655021974, 0.02928518463990518, 0.04773718790550317, 0.09681242651173047, 0.02481929784906762, 0.1720940140741212, 0.11146330035158566, 0.039747383778116534, 0.041420685060854466, 0.02737756655551493, 0.050808037232075415, 0.09837790179465498, 0.08360440989157983, 0.13264121966702597, 0.04665158615846719, 0.10245720004396779, 0.14697783679834434, 0.03641532900344048, 0.155132687783667, 0.43291983540569035, 0.11318703714225974, 0.22474123404494353, 0.19966120911496027, 0.12004090579492704, 0.1463952466313328, 0.1573649730001177, 0.13208115686263355, 0.14556812601430075, 0.11302873492240906, 0.16068148932286672, 0.32933055396590916, 0.1092130746692419, 0.17071979067155293, 0.6667833892362458, 0.343092112668923, 0.3384859726897308, 0.39914833328553606, 0.32311199765120235, 0.234893977109875, 0.33272955300552504, 0.5391730453286852, 0.4839933291077614, 0.5983923247882298, 0.340213170009, 0.45511325023003985, 0.6587232617395264, 0.5121087804436684, 0.4316302388906479, 0.2999388596841267, 0.1932305698948247, 0.20502099793936523, 0.25981065151946886, 0.2596603695835386, 0.25455292793256895, 0.1481048020401171, 0.810140956725393, 0.48578232739652905, 0.33247987926006317, 0.43912848510912483, 0.8741816346134458, 1.0003461561032703, 1.4691293899502074, 1.9650652068001884, 2.8912791865212575, 1.4179547131061554, 1.3233604175703866, 2.5111929646560123, 1.064013911145074, 2.6732253900596072, 7.55851445879255, 17.192325557981217, 25.63239097595215, 37.61636945179531, 51.26797464915684, 70.44562462397984, 76.87976769038609, 75.06035409654889, 74.68889645167759, 63.3504090990339, 42.47429977144514, 33.41600622449602, 28.977929489953176, 19.423454659325735, 5.998482329504831, 2.201232739857265, 0.5028937320624078, 0.2491426153906754, 0.4343264384993485, 0.5932701453566551, 1.1676155690635954, 0.3990391977131367, 0.4836177464042391, 0.37774321330445154, 0.19499531734202588, 0.5878319314547947, 0.593174010515213, 1.3784307539463043, 9.971677677971975, 18.349179778780254, 13.145979574748448, 11.12243832860674, 20.424662283488683, 23.278393404824392, 38.850532804216655, 30.754182611192974, 8.58177479675838, 0.38875084263937815, 1.7481095514127185, 12.597732833453588, 19.018183606011526, 28.659387588500977, 14.690586703164236, 1.8283494114875793, 0.24428368040493556, 2.804865960563932, 19.52050014904567, 60.31793730599539, 25.531979084014893, 9.983579073633466, 11.604374068123953, 6.95460352727345, 7.942008989197867, 16.672155618667603, 18.244920321873256, 3.9168068085397993, 0.7828735655971936, 0.2990622738642352, 0.5031317078641483, 0.7233605618987764, 0.107601703277656, 0.2262784687003919, 0.13857673188405378, 0.5709458004151071, 0.5767865212900298, 0.7653662764600345, 0.565559806568282, 1.1388559980051858, 0.6315428859421185, 0.39714301803282326, 0.5071267049227441, 1.5063349306583405, 3.3949326063905443, 7.234427894864764, 9.677228655133929, 14.301743796893529, 18.520506722586497, 17.992803198950632, 18.118527378354752, 9.341473460197449, 5.20899760723114, 2.0080467632838657, 0.6554994604417256, 0.6461157553962299, 0.36303669959306717, 0.891835595880236, 0.38692048085587366, 0.2219294799225671, 0.32691578354154316, 0.3408655950001308, 0.2648337376969201, 0.2813163303903171, 0.3438928654151303, 0.2630976379982063, 0.19458222522267274, 0.19104013671832426, 0.19693769168640884, 0.3796899031315531, 0.22311690263450146, 0.1365370149058955, 0.16261192145092146, 0.24426682559507235, 0.35645727121404236, 0.27176529860922266, 0.15438108811421053, 0.09733208255576235, 0.2726929916867188, 0.287091857620648, 0.15348292488072598, 0.2473514186484473, 0.2974032557436398, 0.15595918414848192, 0.3304820550339562, 0.6826136112213135, 0.43263381932462963, 0.2196421248040029, 0.12396301462181977, 0.19878205843269825, 0.38081442564725876, 0.24251593383295195, 0.23460266845566885, 0.22661456066582883, 0.2602227936897959, 0.40671996985163006, 0.4013988439525877, 0.26191522287470953], [0.015096255744408284, 0.03593671075733645, 0.009429862390139272, 0.06747827199952942, 0.053001411857881715, 0.08965377349938665, 0.06455884794039385, 0.05848494850631271, 0.04360677222056048, 0.04892434598878026, 0.04757261602208018, 0.06710986819650445, 0.030020842129098516, 0.05054421603147473, 0.05980703327804804, 0.1738005703581231, 0.047166085336357355, 0.01331997659456517, 0.04077434313616582, 0.06849343502627951, 0.14123322362346308, 0.03594519244506955, 0.06862158993525164, 0.06356577122850077, 0.016201589289786558, 0.02560947053799672, 0.07173469503011022, 0.031249000690877438, 0.03773162587146674, 0.09540977927723102, 0.039235731054629595, 0.1112622639962605, 0.09011111288730587, 0.12399398296007089, 0.03887163255629795, 0.1393802666238376, 0.07233718662921872, 0.08605591620185546, 0.09990101613636528, 0.20961729916078703, 0.0846723968695317, 0.21113746187516622, 0.1566023810633591, 0.09652847317712647, 0.11784363298543862, 0.6769749852163451, 0.6757144300001008, 0.5192320953522409, 0.04284688085317612, 0.2275930895869221, 1.2142998640026366, 3.9436585562569753, 5.940829217433929, 6.093509367534092, 6.421868639332907, 8.204617891992841, 8.515861579350062, 8.741890822138105, 8.311024342264448, 8.419352837971278, 3.461886099406651, 0.7209301037447793, 0.12499322076993329, 0.24178637298090117, 0.46083324615444454, 0.10335469831313406, 0.048266743775457144, 0.07635726912745408, 0.2110367129955973, 0.7419289712394986, 0.3571977971919945, 0.017747190282014862, 0.014166820528251784, 0.12074404449335166, 0.11009064436491046, 0.050847419404557774, 0.10849768841373068, 0.20145433289664133, 0.1620746302817549, 3.0172947560037886, 0.3639367627246039, 1.2489160065140044, 1.4839365439755576, 1.8112813787800925, 3.555211914437158, 2.756055299724851, 5.0172321030071805, 1.178184104817254, 0.08334700763225555, 0.5299990890281541, 1.7756591588258743, 3.2186064336981093, 2.741989105939865, 0.4289303480514458, 0.352826077491045, 2.506171154124396, 10.236621175493513, 7.269556684153421, 2.7791048628943305, 1.8535461851528712, 1.8310724539416177, 0.4400329180061817, 0.6827669058527265, 1.8109194210597446, 0.6853864310043198, 0.9363888565983091, 0.06530460542333977, 0.06677688392145292, 0.10617701722575085, 0.11212255819035427, 0.02060689138514655, 0.017276855252150978, 0.03963009900014315, 0.04505147844819086, 0.14380754477211408, 0.09560229323272194, 0.12326932113085474, 0.055387022239821296, 0.10274972327585731, 0.05740470040057387, 0.0740494222513267, 0.04741299405161824, 0.04173333024872201, 0.018421616771125367, 0.12480690862451281, 0.051766861496227126, 0.03531498608312436, 0.03156250761821866, 0.13508456998637744, 0.08061059803834983, 0.10205949709883758, 0.09856046164142233, 0.03978660310219441, 0.05890963678913457, 0.03373176032411201, 0.06865914006318365, 0.03664524380915931, 0.08308965965573277, 0.0828680976160935, 0.02024568005331925, 0.0803754652983376, 0.01835038246853011, 0.042852916422166994, 0.07146452274173498, 0.11009396240115166, 0.02780906224091138, 0.09505922773054667, 0.010590567785714353, 0.04511422597404037, 0.022996391469080533, 0.0234082249059741, 0.024287107566903745, 0.03622144101453679, 0.07229133801800863, 0.00696186555848856, 0.05456667679495045, 0.03485810470634273, 0.06279349659702607, 0.014658324154359954, 0.06272139546594449, 0.021263779440362538, 0.11104792156921965, 0.1071971199874367, 0.16161729767918587, 0.06047863366880587, 0.034233343587922196, 0.03988611365535429, 0.04765613011217543, 0.08937671408057213, 0.02974974024774773, 0.128681479287999, 0.03264484561181494, 0.08980033706341471, 0.029427565035543272, 0.03448082227259874, 0.06146452469485147, 0.01217216590885073, 0.03768761269748211, 0.04624451943007963, 0.014259479574060865, 0.06828673290354864, 0.024633540406024883, 0.08036237635782786, 0.03277257304372532, 0.01557453302666545, 0.06985942101372139, 0.04587905029101031, 0.12184358334967069, 0.09721287073833601, 0.01827551800358508, 0.08885395713150501, 0.27286566527826445, 0.05796426108905247, 0.07862532671008791, 0.013985681364179721, 0.04083561824102487, 0.022874916737367, 0.03664111153089574, 0.08576864483101027, 0.04029149083154542, 0.10765379441103765, 0.05312494933605194, 0.06641301273235253, 0.07156856930149452, 0.10619235890252249, 0.13212830147572927, 0.07546237643275942, 0.032831768438752205, 0.014730433767129267, 0.029911119623907974, 0.0346463610684233, 0.08049080946615764, 0.055408348595457416, 0.08067094015755824, 0.07958730616207634, 0.12422950246504375, 0.032740722609949965, 0.15433996889208043, 0.14016349959586347, 0.11576855076210839, 0.24453218707016536, 0.3558759024100644, 0.36350228318146294, 0.6461303031870297, 0.08534365799278021, 0.22523375547357968, 0.536108021225248, 2.091268811907087, 4.564461427075522, 6.446869560650416, 3.103428534099034, 4.3673727342060635, 3.1075770429202487, 0.7595464001808847, 0.4548430847270148, 1.8747716290610177, 1.4915364618812288, 0.3967205621302128, 0.7363379512514386, 0.504599460533687, 0.174996854737401, 0.05137970298528671, 0.029147102763610225, 0.10194476361253432, 0.18175602704286575, 0.38267581005181583, 0.08018339239060879, 0.04945625298257385, 0.02714405721053481, 0.04418415463130389, 0.41960079010043827, 0.020862498919346502, 0.13505091464945249, 0.2473518257694585, 1.840502027954374, 8.042170745985848, 8.264055388314382, 2.6731417945453098, 2.4192413730280737, 4.779938093253544, 9.153451732226781, 10.291947943823677, 15.160818202154976, 4.139686346054077, 0.18773360843104975, 1.0980624726840427, 0.4995991459914616, 2.575582572392055, 1.3847401525293077, 0.3161956359233175, 0.6644826126950127, 3.7165631992476325, 10.713032228606087, 1.4571348450013568, 0.7961697578430176, 1.125040916459901, 3.0012485427515845, 0.9749470161540168, 5.642573016030448, 7.122297866003854, 5.0611351643289835, 1.9016922073704856, 0.2895442188850471, 0.04225151047908834, 0.049404110959065814, 0.07518535772604601, 0.05753785611263343, 0.03166823694482446, 0.10952676140836307, 0.3154868653842381, 0.1075490964576602, 0.04056007534797702, 0.12562359337295803, 0.08278699232531445, 0.12360569808099951, 0.06520465721509286, 0.03115859947034291, 0.08183186607701437, 0.02914621727541089, 0.03842507508982505, 0.09615395577358347, 0.050954149570316076, 0.09195765094565493, 0.05613284757626908, 0.23208193800279073, 0.24027085144604954, 0.1056375615298748, 0.1601266512381179, 0.026530215416901877, 0.07245192690087215, 0.0930357820221356, 0.15553611756435462, 0.06586062415902104, 0.060275426001421044, 0.08377600461244583, 0.07849345342921359, 0.10534228344580956, 0.05088473543790834, 0.0749514667051179, 0.10574033922914948, 0.03682905894571117, 0.028634510269122462, 0.11789330174880368, 0.040616614278405905, 0.03276686656421848, 0.017271465987765362, 0.06092007498123816, 0.00918791291769594, 0.025721691748393432, 0.06943579803087882, 0.09183590140725885, 0.046165636341486654, 0.01497868767806462, 0.029355080532176153, 0.03940274566411972, 0.053765428718179464, 0.0722337303949254, 0.01774030315157558, 0.025104080692731907, 0.06006562297365495, 0.06122741063258477, 0.03853660589084029, 0.05140386561730078, 0.023224233350317394, 0.07104389209832464, 0.11211761167006833, 0.05616442320336189, 0.06291510364306824, 0.040421660989522934, 0.04066556718732629, 0.03461881933201637, 0.11118518920349223, 0.2038357736808913, 0.13211737706192903, 0.0704700889598046, 0.23539650014468602, 0.25244333541819025, 0.2267472685447761, 0.22203283437660762, 0.21170905977487564, 0.18832174901451382, 0.1527568788400718, 0.17749553280217306, 0.19032588361629418, 0.27037237478154047, 0.17464546859264374, 0.39676314698798315, 0.5420548649770873, 0.164878730529121, 0.1571899652481079, 0.13874641992151737, 0.2237893036965813, 0.21126897553248064, 0.10817328760666506, 0.22489683569542, 0.16665634300027574, 0.2618913384420531, 0.1297279702765601, 0.22489056603184768, 0.42401840591004913, 0.31752817013434, 0.5456159253205571, 0.3107543279017721, 0.21820171709571565, 0.15391169115900993, 0.2289379324231829, 0.19858969375491142, 0.3605869710445404, 0.15324220779751027, 0.2811150226209845, 0.1971467211842537, 0.3092626636581761, 0.1871132238634995, 0.454985359949725, 0.21635158280176775, 0.35321466092552456, 0.7748350969382695, 2.015874126127788, 1.458636307290622, 1.043225335223334, 0.1009091834670731, 0.6946764439344406, 4.463749025549207, 9.689925619534083, 13.299327186175756, 14.830417462757655, 15.158113615853445, 15.465359483446393, 21.306741305759974, 28.727976730891637, 30.01646109989711, 17.898630789348058, 8.689007214137487, 3.32219169821058, 1.6331518228564943, 0.9177046077592033, 0.9349345117807388, 0.3681412642555577, 0.14162928451384815, 0.5217960891979081, 0.6553300438182694, 1.0792608644281114, 0.4214704526322228, 0.1714119099612747, 0.12048185856214591, 0.17469672512795242, 0.5187600521104676, 0.13741513421492918, 0.11901569366455078, 0.3796998368842261, 1.3978459749902998, 14.822406189782278, 16.606460400990077, 10.509480408259801, 12.701456410544258, 15.107996259416852, 18.338696684156144, 34.78775085721697, 53.01875046321324, 4.322514729840415, 0.1376179890441043, 6.036270107541766, 11.10687175818852, 19.68248176574707, 9.558639407157898, 0.6504064851573536, 0.7869766397135598, 11.39578914642334, 27.136472736086162, 17.97112308229719, 13.477154169763837, 5.8626498239380975, 8.307065606117249, 5.128909196172442, 12.208618078913007, 13.603342141423907, 7.713950003896441, 1.613381375159536, 0.20825769140252046, 0.13969900166349752, 0.19239831955305167, 0.14146855313863071, 0.2205799144825765, 0.10191112863165991, 0.22777123217071804, 0.5089573381202561, 0.45394386297890116, 0.17717826339815343, 0.2906461868967329, 0.3984477865908827, 0.2018993025911706, 0.4207988658121654, 0.24549215127314838, 0.21051752514072827, 0.06102239806205034, 0.1634304653853178, 0.2942157967814377, 0.0841774937829801, 0.15916831551917962, 0.23447095123784883, 0.4213634340890816, 0.42591648548841476, 0.2213678564876318, 0.28835382418973105, 0.13597666711679526, 0.23837174049445561, 0.24589544534683228, 0.2605743833950588, 0.18491721312914575, 0.2699726090899536, 0.2070638904614108, 0.26228217461279457, 0.41372204412307056, 0.25890570293579784, 0.24250266168798718, 0.36315946014864103, 0.27479843156678335, 0.12999646658343927, 0.25341868879539625, 0.1482462358794042, 0.2662884624941008, 0.0627578395817961, 0.1373041665979794, 0.08193868105965, 0.17819869864199842, 0.1672846121447427, 0.2689654731324741, 0.143760386588318, 0.18054393279765332, 0.18905334547162056, 0.13147191384008952, 0.2686847224831581, 0.2822628324585301, 0.33086806003536495, 0.21809117017047747, 0.39537046743290766, 0.24670605042151042, 0.12685562297701836, 0.12297396840793745, 0.13681711416159356, 0.1921203373266118, 0.2873706540891102, 0.23924520505326136, 0.18207390712840216, 0.1554589138499328, 0.3320487109678132, 0.16576328235013144, 0.21000356200550283], [0.028099644862647568, 0.09937367229057209, 0.013292446732521057, 0.050852036835359674, 0.061752691731921265, 0.043738682820860825, 0.016195675857099037, 0.019373519978086864, 0.06708192612443652, 0.04224472852157695, 0.04500025583963309, 0.05456048177023019, 0.022675788761781793, 0.012963093467988074, 0.08454884921333619, 0.032154196939830265, 0.01703487609380058, 0.060370909449245246, 0.060665237584284375, 0.06423198405121054, 0.0952330684023244, 0.03861691051029733, 0.04431904060766101, 0.12832224927842617, 0.010487605185647095, 0.015926312721733536, 0.024626926385930607, 0.07179046382329293, 0.037478583199637275, 0.07895691320300102, 0.09941278983439718, 0.029104745215071098, 0.0418446846306324, 0.08128339943609067, 0.08805547069225993, 0.027722333591165285, 0.030859426595270634, 0.060006522573530674, 0.053511079866439104, 0.0841358724449362, 0.018711417381252562, 0.01484401713657592, 0.03572507568502, 0.07727834648851838, 0.06454625433044774, 0.03727157573614802, 0.13507538262222493, 0.14189984356718405, 0.06093820543693645, 0.06799334114683525, 0.10722605950598206, 0.039695642090269496, 0.09703830403408834, 0.06554475253713982, 0.28724718785711695, 0.08184256657425847, 0.2752502273236002, 0.05296097456344536, 0.30058756630335537, 0.20158599583165987, 0.04424281398366604, 0.22334566393068858, 0.05448087604184236, 0.05310028458812407, 0.0756829749526722, 0.06117863753544433, 0.22181115698601517, 0.03862913092598319, 0.05319640585886581, 0.055260780799601755, 0.10252223762550525, 0.021951805467584302, 0.02971295007903661, 0.11438484143997942, 0.08493601450962679, 0.07418286294809409, 0.04418363215933953, 0.03520078185413565, 1.4104813826935632, 0.14189472741314343, 3.3214771194117407, 0.43057484552264214, 1.000723421573639, 2.70570952125958, 4.775827365262168, 6.994592147214072, 6.11921900510788, 8.321253827639989, 0.34927845214094433, 0.1632356715521642, 1.3128851396696908, 0.4293360034269946, 0.1533346785498517, 0.08816332383347408, 4.810052020209176, 12.279400246483938, 14.295519948005676, 5.903477004596165, 1.0799820657287325, 2.117171261991773, 0.3350819524909769, 1.9049205141408103, 2.132195655788694, 2.564194909163884, 2.1795458921364377, 0.16306135590587342, 0.002651743054489738, 0.04610223402934415, 0.03934876820338624, 0.012919701153545507, 0.06553409953734704, 0.1059308515063354, 0.0498091047629714, 0.03648047175790582, 0.04369197247017707, 0.014477289315047008, 0.016762876849887625, 0.0024873808807959513, 0.0191199751903436, 0.020724812289699912, 0.009320486785977014, 0.043315029303942404, 0.1046942892883505, 0.02213091157110674, 0.08569794148206711, 0.014623762973185097, 0.03853241254442504, 0.0383979913645557, 0.09331096868429865, 0.017100091790780425, 0.05131881803806339, 0.06479799760771648, 0.09669189833636795, 0.062235944372202666, 0.01888627415922071, 0.03191987504916532, 0.11824776844254561, 0.01277537505874144, 0.052131658885627985, 0.03556658008268901, 0.0607834994526846, 0.05045900221115776, 0.04067571467853018, 0.03638876775013549, 0.031015618571213315, 0.03823913613866482, 0.04415867903402873, 0.015207854398925389, 0.0891844986804894, 0.031638805488390584, 0.03911043617076107, 0.09331899575356926, 0.04760266833805612, 0.07501673498856169, 0.02778925919639213, 0.06604233583701508, 0.08337467829031603, 0.04666976411161678, 0.11140183186424629, 0.032112962366747, 0.1586608663201332, 0.058961388655006886, 0.03178294328972697, 0.06520625855773687, 0.06101678657744612, 0.030161702606294836, 0.010642809044968869, 0.03170465731195041, 0.039468417675899606, 0.05712389546845641, 0.10846116287367684, 0.04492909447955234, 0.051225220917591026, 0.05972397380641528, 0.022995149749996405, 0.030755295218633752, 0.09016428289136716, 0.04620586329006723, 0.07150134005184684, 0.033087613460208685, 0.04484193665640695, 0.05100105669615524, 0.055887818403009853, 0.029291101465267793, 0.10572583215045077, 0.03669738922534244, 0.06635040430618183, 0.06786429057163851, 0.028490372467786074, 0.03741218515538743, 0.05098919251135417, 0.022229964113129035, 0.03974849318287202, 0.09302692035479204, 0.02515745595363634, 0.0038063202186354567, 0.08011943367975098, 0.03825256773935897, 0.06567904140268054, 0.03677141400320189, 0.011845688784628041, 0.007141510673266436, 0.06967589086187737, 0.03616521760289158, 0.03364272974431515, 0.07090458885899611, 0.07612523729247705, 0.006771759554145059, 0.00962135345408959, 0.03769549048904862, 0.06941542840961899, 0.01786405945728932, 0.042003634851425886, 0.039386196195014885, 0.07280386944434472, 0.11780460365116596, 0.0197298170200416, 0.016967176958652477, 0.038446068963302035, 0.053051955931420834, 0.049622222648135254, 0.03647895183946405, 0.10501404213053839, 0.09964823470051799, 0.05542811092787555, 0.07891783637127706, 0.051758403557219675, 0.06639524868556432, 0.12371221450822693, 0.3181818707713059, 0.32222118973731995, 0.19586939258234842, 0.27778455561825205, 0.10290679056197405, 0.16889059596828052, 0.04845796512173755, 0.13965830313307898, 0.10211051614688975, 0.13570251182786056, 0.10245400414402996, 0.07288291877401726, 0.15692152322403022, 0.21732182002493314, 0.06607964169234037, 0.13321348253105367, 0.084431571220713, 0.08438057931406157, 0.023953039332159927, 0.09286174457520247, 0.009261436427810361, 0.07608328347227403, 0.05761957887027945, 0.07522068225911685, 0.15325520852846758, 0.6860341333917209, 4.907095338617053, 7.829662697655814, 4.961690374783107, 0.32033695227333475, 5.162003900323596, 12.115794488361903, 8.427317210606166, 16.736846821648733, 16.431056601660593, 0.5421036652156285, 0.5540654233523777, 0.6112768362675394, 1.8559376682553972, 0.3633221728461129, 0.1566744279116392, 11.637201700891767, 14.683218138558523, 17.61728780610221, 7.253934962408883, 1.0916254009519304, 2.365924371140344, 2.069488597767694, 2.26612674338477, 4.937029480934143, 6.10116845369339, 3.4002106317452023, 0.4489375501871109, 0.07784001742090497, 0.10647338775119611, 0.05597235029563308, 0.07527041209063359, 0.028986391744443347, 0.04371808249769466, 0.05767810930098806, 0.06762735971382686, 0.04946058203599282, 0.04723752489579575, 0.020374825623418604, 0.007965982459219438, 0.02691879715504391, 0.047058123629540205, 0.10775882484657423, 0.042129418280507834, 0.06312232823776347, 0.0381723784708551, 0.026913377356582453, 0.03912540126059737, 0.0492094290841903, 0.04128686099180153, 0.06658433603921107, 0.027312793602634753, 0.04067353318844523, 0.038679352695388455, 0.0943626979632037, 0.05181630634303604, 0.003236942400690168, 0.041370083311838765, 0.03641141724905797, 0.05229369644075632, 0.061880819499492645, 0.0291869259838547, 0.053617528440164666, 0.036524328868836164, 0.0219002978743187, 0.06667724105396441, 0.03454758333308356, 0.03705503824832184, 0.06352560195539679, 0.013262771003480469, 0.05663671411041703, 0.03378100161041532, 0.025465605847005333, 0.05055766459554434, 0.011531963029743304, 0.050108023187411685, 0.013771885157828885, 0.04786886101854699, 0.06145431952817099, 0.017008340285558785, 0.021823053447795764, 0.013218321870746357, 0.11373972427099943, 0.04508831611435328, 0.015754185350877897, 0.07577100808599166, 0.11394677923193999, 0.03543170428435717, 0.020251255914834992, 0.05100189807957836, 0.08001996044601713, 0.083573197280722, 0.046449379330234866, 0.06773332652768918, 0.07208132464438677, 0.06280858721584082, 0.04976644526634898, 0.055826872387634854, 0.20404644523348126, 0.14143644486154827, 0.11420342831739358, 0.14125832941915306, 0.19664932787418365, 0.20374413074127265, 0.14618361155901635, 0.15949811067964348, 0.23572681099176407, 0.12062319740653038, 0.1296708919107914, 0.1807516866496631, 0.09150927500533206, 0.12654014490544796, 0.312089169131858, 0.17060662460114273, 0.12113850404109273, 0.15097998561603682, 0.12270836266023771, 0.21019930578768253, 0.12180580251983233, 0.0890179726162127, 0.15308353916874953, 0.2216028603059905, 0.09200263103204114, 0.08060495262699467, 0.189836198464036, 0.16598172991403512, 0.12042235104101044, 0.4034323862620762, 0.323414569986718, 0.1434557107942445, 0.11046812696648495, 0.28726219705172945, 0.13141425193420478, 0.10847525604601417, 0.20701234894139425, 0.17877385206520557, 0.3238420199070658, 0.19155526693378175, 0.13442757166922092, 0.18063253590038844, 0.1987959819712809, 0.1430865198905979, 0.18296436220407486, 0.11755756262157645, 0.33897728632603374, 0.3249538131058216, 0.10004685366792337, 0.22606819069811276, 0.18648355693689414, 0.2666148378380707, 0.38173365060772213, 0.6150216438940593, 0.5076309921486037, 0.48622386370386395, 0.4775431752204895, 0.32071201929024284, 0.34610488957592417, 0.5182434426886695, 0.17390080355107784, 0.2720688208937645, 0.15960953970040592, 0.14278993223394665, 0.11989354155957699, 0.30714292025991846, 0.4223790110221931, 0.20380473748913833, 0.395297891327313, 0.2153194360435009, 0.2715676006461893, 0.1158744700785194, 0.20727040937968663, 0.3411399674202715, 0.29727465978690554, 0.3164280748793057, 0.13350280986300536, 0.2081640399992466, 2.807918825319835, 6.0717232908521375, 15.49619037764413, 12.430162259510585, 6.601656751973288, 16.22160141808646, 16.989896740232194, 17.35873317718506, 49.616182872227256, 31.864021846226283, 0.4601080279265131, 0.8477677862559045, 7.786306806973048, 5.18452605179378, 1.6305713270391737, 0.2035365125962666, 19.634525299072266, 48.37596416473389, 26.19283788544791, 18.604121344430105, 6.27026936837605, 6.151140766484397, 9.615797894341604, 9.045065913881574, 8.553675413131714, 9.385754329817635, 5.762506306171417, 0.2568912138896329, 0.15566430640007767, 0.12813444435596466, 0.22096534951456956, 0.21570018918386527, 0.2335781077189105, 0.17610385747892515, 0.18858827756983892, 0.17089660332671233, 0.17016031140727655, 0.16742737591266632, 0.1661724661077772, 0.10197199322283268, 0.12313555473727839, 0.3346159617815699, 0.1578980843935694, 0.25218541068690165, 0.3045247250369617, 0.15899409486779145, 0.14879909264189856, 0.20750633600567067, 0.13025694260639803, 0.12910487156893524, 0.2838412406189101, 0.3259519381182534, 0.13824439900262014, 0.22804462750043186, 0.18439455117498124, 0.1734485056783472, 0.09336966874876193, 0.11331094442201511, 0.28247518677796635, 0.11406132951378822, 0.1530070547014475, 0.12283349808837686, 0.42449935153126717, 0.20898779508258614, 0.14870958030223846, 0.14049974083900452, 0.1465021837502718, 0.10409704276493617, 0.09995719883590937, 0.14628172772271292, 0.16363863992903913, 0.08949965105525085, 0.13221410901418754, 0.3219260812870094, 0.09168458809810025, 0.19587938061782292, 0.13282019006354467, 0.13301559457821505, 0.114230624000941, 0.1019065620909844, 0.17716469269778046, 0.09177255337791783, 0.29869241799627033, 0.2454137940491949, 0.19234875935528958, 0.1831345252160515, 0.11932787405593054, 0.11494512137557779, 0.09723854650344167, 0.15348886884748936, 0.16000357855643543, 0.18915710704667227, 0.2617334026311125, 0.11473386628287179, 0.14861092131052697, 0.2203422100948436, 0.09779321495443583, 0.1414511962128537], [0.019602086195456128, 0.03449140741888966, 0.07838087089891944, 0.03482388957802739, 0.03490472345479897, 0.044969589449465275, 0.047882007634533305, 0.021289757153551494, 0.02535027016087302, 0.04440857669604676, 0.06605203888778176, 0.014173616056463547, 0.055184364185801575, 0.03812127799860068, 0.02178371707642717, 0.020546064113399813, 0.02845105984514313, 0.02379339191663478, 0.023802572495437095, 0.04184124106541276, 0.022481761673199277, 0.020877411422718848, 0.007468328761335994, 0.03913133165666035, 0.021756334795749614, 0.05321249731683305, 0.03548322205564805, 0.028166606090962887, 0.038142081882272444, 0.02523577755450138, 0.031802963465452194, 0.04425482066082103, 0.027696878349940692, 0.13011876573520048, 0.08598421540643487, 0.03313843234043036, 0.04316163289227656, 0.10773755277373961, 0.04514745383390358, 0.046337940131447146, 0.05385565012693405, 0.032543387663151534, 0.022005486069247127, 0.08601331777338471, 0.07215117303920643, 0.05234534652637584, 0.014667299476319125, 0.06969803145953588, 0.06050719999309097, 0.04760143679699727, 0.03253173382420625, 0.02672566064367337, 0.03907048063618796, 0.062070490393255434, 0.08835159015974828, 0.11868629205439772, 0.07085154099123818, 0.037140672760350366, 0.07595020239906651, 0.07031263490872723, 0.10851454322359391, 0.18408885757837976, 0.06039207295647689, 0.02850867934258921, 0.027846746379509568, 0.11432750523090363, 0.003400587659728314, 0.06642599989260946, 0.03934989796419229, 0.01098325296438166, 0.013116663754252451, 0.040531247787709744, 0.03634448655481849, 0.130257960408926, 0.038545033295771906, 0.014902673096262982, 0.053697222378104925, 0.033660368262124915, 0.8396242260932922, 3.156865175281252, 2.6725299188068936, 5.558909756796701, 2.343404173851013, 3.6671272005353654, 2.3078504587922777, 5.0251413243157526, 2.8739951082638333, 10.360560536384583, 7.366830161639622, 0.12571896825517925, 0.4696515415396009, 0.3330345409257071, 0.3931377072419439, 5.6553207891328, 14.051864862442017, 14.326396005494253, 17.888842514583043, 5.067887510572161, 2.934615101133074, 1.8611575024468558, 0.7681997844151088, 2.8238451821463446, 2.764529279300145, 0.9641660175153187, 0.7195218993084771, 0.11974471168858664, 0.058871421696884293, 0.08360120042094163, 0.13958848187966005, 0.017078363403145756, 0.08656261222703115, 0.028383233484679034, 0.018685882412163273, 0.041691420533295186, 0.05058939628569143, 0.07675109085227762, 0.015137712537710155, 0.10683849387403045, 0.09546491024749619, 0.01463117596826383, 0.058195458325956545, 0.1219911240041256, 0.021107017495004193, 0.045682478696107864, 0.061000162469489236, 0.03723077881815178, 0.04959681490436196, 0.06991882675460406, 0.041835785643862825, 0.06837834870176655, 0.011204487610874432, 0.023848558509988443, 0.020404832138280784, 0.03912626300007105, 0.0647602371339287, 0.08156212126570088, 0.0058948213201282275, 0.047979475797287056, 0.04455246343942625, 0.01751216101859297, 0.008993114843698484, 0.064535275633846, 0.06923708905066762, 0.01952464838645288, 0.03192900813051632, 0.013108203270738679, 0.015500576102307864, 0.048854389028357606, 0.034353125374764204, 0.006069467328156212, 0.05991239619574376, 0.008329633972607553, 0.019072045172963823, 0.04382191192624824, 0.048993258005274196, 0.04876058156202946, 0.036220050017748556, 0.038769760701273165, 0.04698736939047064, 0.03976454732141324, 0.03834431924458061, 0.11467558012476989, 0.018019303180543438, 0.0417809260876051, 0.04320077418482729, 0.02589603792876005, 0.018421411514282227, 0.1000991076497095, 0.03345190194834556, 0.026832587584587078, 0.03781108571482556, 0.03622647235170007, 0.024450541207832948, 0.05585087217124445, 0.034736836927809885, 0.04639505920931697, 0.11905069250081267, 0.008905080862210264, 0.04919651656278542, 0.03840488188767007, 0.08099067264369555, 0.002849827570441578, 0.03514495199280126, 0.05317122542432376, 0.019787068412240063, 0.04578633526606219, 0.043814695706324916, 0.12417110774133887, 0.05025551634441529, 0.046868727542459965, 0.02025793948476868, 0.0524670078552195, 0.027502720643367087, 0.05744668814752783, 0.0648010578006506, 0.06679754531277077, 0.05701371495212827, 0.035657215397804976, 0.032778693429593525, 0.03994475943701608, 0.04379852282415543, 0.06284791510552168, 0.04179589796279158, 0.058104432853204865, 0.009321770913499807, 0.029179987963289022, 0.03348955724920545, 0.03994629631883331, 0.04224232990028603, 0.11287089410637106, 0.05812122659491641, 0.04579372451241527, 0.034731544354664426, 0.10456982560987983, 0.0383607906821583, 0.07114806079438754, 0.03456534059452159, 0.04923191573470831, 0.07132196931966714, 0.04755319295717137, 0.021211462694087198, 0.06591568727578435, 0.051331927334623675, 0.07836541387119464, 0.04657130189506071, 0.08677646610885859, 0.10707735855664526, 0.016118258404146348, 0.031629716511815786, 0.11691515280732087, 0.06217605008610657, 0.06614193120705229, 0.10816581015075956, 0.058361434776868136, 0.06249518546142748, 0.054957099059330564, 0.08836886566132307, 0.15002368550215447, 0.11571348085999489, 0.04757057363167405, 0.05855413872216429, 0.0387714027560183, 0.053224721125194004, 0.07621291080223662, 0.0236548214951264, 0.07187230193189212, 0.021410704324288026, 0.03707507878009762, 0.0667945190465876, 0.023617118696815202, 0.020953721167253594, 0.08178980369120836, 0.07617120803999049, 0.18018227363271372, 1.250020335827555, 3.681999385356903, 8.849134530339922, 6.16158173765455, 2.0245337528841834, 3.2092604551996504, 12.042021989822388, 11.711216517857142, 11.59007033279964, 21.14760845048087, 16.511150223868235, 0.09418685561312096, 1.16596200636455, 0.7042717433401516, 0.26934170722961426, 11.46628817490169, 28.372180325644358, 26.24201376097543, 31.953507695879253, 11.028699312891279, 4.539648107119969, 3.307316690683365, 2.1104034994329726, 6.374415917055948, 7.347462926592145, 5.210826286247798, 1.9386277454239982, 0.10086364019662142, 0.01590483878473086, 0.06307564502848045, 0.034334173891693354, 0.031169951361204897, 0.046930481014507155, 0.061115303076803684, 0.02369324693323246, 0.04486056922801903, 0.09313236469669, 0.07109743529664618, 0.020698413884799396, 0.0018978348816744983, 0.06062820992831673, 0.07802295724728278, 0.05376105895265937, 0.058273564491953166, 0.051697142023061, 0.017025795598913516, 0.007862080936320126, 0.04244652822879808, 0.009204939057651376, 0.02381657576188445, 0.033186781353184154, 0.04221402481198311, 0.06726845540106297, 0.002607170301156917, 0.031714323043291054, 0.04196495496268783, 0.05900210075612579, 0.12352135617818151, 0.09834176980491195, 0.015165712285254682, 0.032503540694181404, 0.03942979885531323, 0.07236070465296507, 0.06270744478596108, 0.02437011105939746, 0.04877159757805722, 0.018387503423062817, 0.048786627128720284, 0.03833600040525198, 0.021148231712036898, 0.07824614098561661, 0.009395710026313151, 0.009891759837046266, 0.029222342119153057, 0.08162456005811691, 0.07969452148037297, 0.13087514229118824, 0.01966212467024369, 0.07277155760675669, 0.03789435553231409, 0.025951835559681058, 0.036793249260101996, 0.018870705173217824, 0.046963237292532406, 0.023649347413863455, 0.030596881040505, 0.1048203000266637, 0.0365129634072738, 0.04034203829775963, 0.06618317935083594, 0.05861678107508591, 0.03122064471244812, 0.08674932470811264, 0.04029440853212561, 0.08562033743198429, 0.06838157852845532, 0.05564315903133579, 0.01919347919257624, 0.14256909622677735, 0.09896811190992594, 0.16760332004300185, 0.121595918067864, 0.19095332494803838, 0.2018752417394093, 0.15541218992854866, 0.16194878917719635, 0.10988823736884765, 0.11550971679389477, 0.14514474730406488, 0.14380715122180326, 0.17873267856027397, 0.11642786966902868, 0.12601315389786447, 0.15765306539833546, 0.10755352729133197, 0.13144811083163532, 0.14187196934861795, 0.18475178629159927, 0.12673743574747018, 0.14686769699411734, 0.17144658310072763, 0.1579202724886792, 0.17592548419322285, 0.1387331070644515, 0.1519826568130936, 0.19715086024786743, 0.09217080593641315, 0.11563148668834142, 0.15323236903973989, 0.13019168110830442, 0.08215347131980316, 0.2826626795743193, 0.21681080173168862, 0.09175056884331362, 0.1292116865515709, 0.22731308532612665, 0.16182609647512436, 0.08186778093555144, 0.17351794695215567, 0.1372803771602256, 0.13219823129475117, 0.16763379983603954, 0.1563057934067079, 0.1545265931636095, 0.077649430504867, 0.178598925737398, 0.12264516390860081, 0.21926050313881465, 0.23799895335521015, 0.10051954830331461, 0.08673104497471026, 0.2611908460302012, 0.22637012521071093, 0.20342340080865792, 0.3796216696500778, 0.26749975606799126, 0.23902541399002075, 0.3142411293728011, 0.240303068288735, 0.40125412600381033, 0.11808753918324198, 0.19540950868810925, 0.20064864041549818, 0.3050139216440064, 0.1387831965195281, 0.19585198137376988, 0.17337465392691748, 0.16044704190322331, 0.23219818462218555, 0.18112800217100553, 0.13123176672628947, 0.13097146712243557, 0.10140004248491355, 0.14354001198496136, 0.10341537969985179, 0.3169090205005237, 1.0496074727603366, 6.594528768743787, 12.136152710233416, 17.928045988082886, 14.95190497807094, 17.130851370947703, 26.823934078216553, 35.047780241285054, 36.70947667530605, 48.70007678440639, 20.451560497283936, 0.4521574159818036, 2.2370596059731076, 1.5299737879208155, 1.3206332496234348, 14.384003520011902, 45.877280780247276, 41.50769765036446, 32.715054580143516, 25.435548509870255, 18.662817989076885, 18.565947941371373, 15.585229805537633, 14.091799633843557, 13.997529949460711, 9.825854097093854, 2.188688201563699, 0.15234101829784258, 0.14242782523589476, 0.2566954701074532, 0.24270144530705043, 0.10976165666111878, 0.11437629189874444, 0.1179340545620237, 0.20080854397799286, 0.09860289043613843, 0.25616805840815815, 0.20357624760695867, 0.1032902646277632, 0.20447363731052193, 0.19908117023961885, 0.2179566981004817, 0.17392684572509357, 0.23633800819516182, 0.14761584970567906, 0.12666107341647148, 0.1387124117463827, 0.202879365001406, 0.21976886157478603, 0.16180629682328018, 0.15460572391748428, 0.2596469074487686, 0.21414717180388315, 0.07382553283657346, 0.14335880242288113, 0.2150756519820009, 0.203820370935968, 0.2262866654034172, 0.2003227671874421, 0.06973083862768752, 0.12609294961605752, 0.0705597030797175, 0.19540739165885107, 0.19106038420328073, 0.12617304388965878, 0.12031219766608306, 0.15823086510811532, 0.1079447977244854, 0.10891442426613399, 0.25016628046120915, 0.197071050958974, 0.12653536801891668, 0.1387689472841365, 0.14228498004376888, 0.18321704864501953, 0.16096325777471066, 0.19324328564107418, 0.1031520063323634, 0.20007932239345141, 0.1128875385703785, 0.11497836959149156, 0.18841134277837618, 0.13476284939263547, 0.18689521056200775, 0.2034281369830881, 0.12249212712049484, 0.18795559794775077, 0.13023985709462846, 0.05268336213859064, 0.12368511381958212, 0.1306476837822369, 0.229386389787708, 0.16376729016857489, 0.24024224440966332, 0.14397784349109444, 0.1301280345235552, 0.1422697672886508, 0.14637782185205392], [0.09733581449836493, 0.08989046008459159, 0.03317462539832507, 0.024915470009935752, 0.032076372365866385, 0.07650483692330973, 0.03360301169699856, 0.030568592915577546, 0.037478226968752484, 0.017904240604756132, 0.043893812889499326, 0.031349379768861194, 0.013646019456375922, 0.06002552155405283, 0.06274346821010113, 0.06326956355145999, 0.06721970944532327, 0.08876886205481631, 0.06666862365922757, 0.028827767220458815, 0.02923601459977882, 0.037566002258764844, 0.005409969457624746, 0.020091270928138068, 0.004487233078439853, 0.014630536449008753, 0.020558998687192798, 0.056169485074601004, 0.019262911984696984, 0.024994783968265568, 0.06494520578001227, 0.005218871095816472, 0.03205991449898907, 0.02518685517965683, 0.04191212422613587, 0.03269509452262095, 0.02661556494422257, 0.020773463250537003, 0.04278615875435727, 0.05581057397648692, 0.05324382527864405, 0.05935179056333644, 0.013557976145031196, 0.03581956847171698, 0.026011984296409146, 0.08919251217905964, 0.09504772656198059, 0.1085819760337472, 0.046212577394076755, 0.033058395742305687, 0.049216360319405794, 0.042605312208512, 0.06539451131331069, 0.03532718614275966, 0.022852443657549362, 0.03136672651661294, 0.03151855551238571, 0.09593766595103911, 0.06494774350098201, 0.09663718805781432, 0.01004095102793404, 0.04899090009608439, 0.031885259585188966, 0.04083586251363158, 0.03825899346598557, 0.049795320324067555, 0.043569530826061964, 0.19531080898429665, 0.06115296855568886, 0.06329227411853415, 0.013632112881168723, 0.10315453048263278, 0.0495960413744407, 0.033433333837560246, 0.03685835808781641, 0.025052096428615705, 0.042931419531149526, 0.039935205663953505, 0.510361199932439, 3.5803068535668507, 4.216357111930847, 4.217372417449951, 1.0088639961821693, 0.9530569336244038, 0.5053916094558579, 5.341623953410557, 2.887366916452135, 6.464977868965693, 11.588216032300677, 6.669745624065399, 1.2107245815651757, 2.271711358002254, 5.870189922196524, 24.737160750797816, 13.643511414527893, 22.926712070192607, 11.893884658813477, 4.005365073680878, 6.446892576558249, 4.30269021647317, 3.046951187508447, 2.6971962409360066, 2.5157935406480516, 1.4890275107962745, 0.5248317463057381, 0.10555464455059596, 0.04016863867374403, 0.11796300086591925, 0.1144886165857315, 0.09369440882333688, 0.014197390227179443, 0.06537581088819674, 0.025580098453376974, 0.07249440997838974, 0.03352906834334135, 0.09438242297619581, 0.048653430704559596, 0.05337234998920134, 0.0415292574491884, 0.054270984804523845, 0.06885363534092903, 0.03564980918807643, 0.01026444010702627, 0.04220092908612319, 0.1371244498129402, 0.12969941752297537, 0.024489300824435692, 0.007831237278878689, 0.018001416997451867, 0.06629316309200865, 0.058918769870485575, 0.056595642385738235, 0.030159392194556336, 0.03693359744335924, 0.00922667931964887, 0.03997633167143379, 0.06191214067595346, 0.0760490106684821, 0.032153671075190814, 0.07025921384670905, 0.0862642400232809, 0.06380200319524322, 0.0681137607565948, 0.04764762806839176, 0.02804273273795843, 0.045242533553391695, 0.025484475905873945, 0.03048896004578897, 0.1145482055310692, 0.05155814073181578, 0.006068961819567318, 0.03807691877175655, 0.02413370436988771, 0.031889636136059246, 0.07500084369842495, 0.01790810316534979, 0.048193149867334535, 0.019844092495207275, 0.06835204189909355, 0.04652022856420704, 0.03097061812877655, 0.025131920984547054, 0.03765534496467028, 0.02120233470174883, 0.07688959342028413, 0.03704476862081459, 0.04968303974185671, 0.03973427787423134, 0.04633156190227185, 0.0309188832262797, 0.07401524444243737, 0.07733433919825725, 0.07920309927846704, 0.03667338265638266, 0.011049125992160822, 0.04967289903600301, 0.0688599728580032, 0.028690570832363198, 0.07550583660070385, 0.04466241664652314, 0.12421361117490701, 0.023595904299457158, 0.026797015386234437, 0.05994228566331523, 0.004249909094401768, 0.07664536152567182, 0.016499629011377692, 0.1158397833683661, 0.006411875182363603, 0.011327489046379924, 0.04147961921989918, 0.042145696335605214, 0.02049277875838535, 0.08113449492624827, 0.022339919016563466, 0.014977442566305399, 0.05906305355685098, 0.04658216524070927, 0.017731719683589678, 0.07579765415617398, 0.00940282446598368, 0.09169260838202067, 0.02956027291449053, 0.028040237425427352, 0.02114055578463844, 0.08792553123618875, 0.07396560960582324, 0.04653145492609058, 0.06662350786583764, 0.02729912960369672, 0.013430595614149101, 0.016179521634642566, 0.04099393742425101, 0.030151507617639642, 0.12003308907151222, 0.061335996591619084, 0.022680224684466208, 0.06680880220873014, 0.03943484376317688, 0.0529509152817939, 0.01585239650947707, 0.05661471600511244, 0.08877977289791618, 0.028295738090361868, 0.016846109347950135, 0.06103687121399811, 0.068030518080507, 0.021661529882944057, 0.04805843013205698, 0.020874184988705174, 0.058367941927696974, 0.07017873959349734, 0.031863797522549114, 0.01753429483090128, 0.04156713666660445, 0.07649545278400183, 0.04187471319788268, 0.015854216679664593, 0.08597561158239841, 0.05468282502676759, 0.12468342882181917, 0.02095217750008617, 0.06387155303465468, 0.042975059510873895, 0.032132236153951714, 0.024167812628937618, 0.030517366914344684, 0.01438689318352512, 0.06992581566529614, 0.06471448351762124, 0.04086341782073889, 0.058600984779851775, 0.06691062317362853, 0.07818325436008827, 0.6392268879073006, 4.76275954076222, 7.913900920322963, 7.8110076529639105, 2.446541713816779, 0.8337244998131479, 4.898755763258253, 7.132650247641972, 12.081907255308968, 14.357934747423444, 27.90805803026472, 17.041725090571813, 2.965508529118129, 3.6590555650847296, 16.343375546591624, 43.527809960501536, 28.28618941988264, 31.941994530814036, 23.59111097880772, 9.258893251419067, 5.929260901042393, 3.9322144389152527, 2.8121374675205777, 4.0144719907215665, 8.204429422106061, 2.746926886694772, 0.7897890859416553, 0.245965660150562, 0.0519300355975117, 0.08935660908796958, 0.02940435235255531, 0.1865999392632927, 0.0432605632979955, 0.08015588458095278, 0.04774799696835024, 0.11631231515535287, 0.04486386690820966, 0.0645037983943309, 0.02864805722076978, 0.043617520215255876, 0.03652012534439564, 0.026270864065736532, 0.023783263085143905, 0.023531143220939806, 0.05196807087798204, 0.019791511120274663, 0.0787774474759187, 0.09219458858881678, 0.004771902691572905, 0.06807785268340792, 0.06327075098774262, 0.03889074010242309, 0.06596097270292894, 0.026986433525702784, 0.04488884378224611, 0.06040042572255645, 0.03841058158182672, 0.0367482657810407, 0.019920415810442398, 0.010542762449144252, 0.037720060242073875, 0.05935623496770859, 0.04422135192102619, 0.04838523295308862, 0.015305230959451624, 0.024550818505563905, 0.01842199675073581, 0.01640286822138088, 0.05910892252411161, 0.05471546256116458, 0.04350048988791449, 0.02751671542812671, 0.025430676560582857, 0.016367226473188827, 0.02244892736364688, 0.059982393868267536, 0.08439575814242874, 0.04144964832812548, 0.030104481748172214, 0.017317697971260974, 0.03600759391805955, 0.029886312383626188, 0.04880428260990551, 0.01548280187749437, 0.10120269057473966, 0.01643408931392644, 0.07740057100142751, 0.054315598481999974, 0.051207840243088346, 0.014690627510260259, 0.11390655567603451, 0.05570551979222468, 0.04626869563279407, 0.02075997906337891, 0.06078752316534519, 0.0249432594116245, 0.02666335755826107, 0.055758666047560315, 0.23551521663154873, 0.13103005183594568, 0.1644044616924865, 0.11032000955726419, 0.19522386150700705, 0.18951721915176936, 0.0646612388747079, 0.15579991840890475, 0.06701955518552236, 0.11385008799178259, 0.20226178956883295, 0.13252748362720013, 0.08063891330467803, 0.11227639564978224, 0.1444882239614214, 0.09623243513384036, 0.19348225210394177, 0.2158206562910761, 0.19113019188599928, 0.08916636143944093, 0.1935313373271908, 0.35402586311101913, 0.14132511083568844, 0.25859061841453823, 0.16074220463633537, 0.2657872422465256, 0.15250438238893235, 0.21955143181341036, 0.14957605595035212, 0.14574523722486837, 0.2609159307820456, 0.12400800149355616, 0.17685681421841892, 0.14820538807128156, 0.17921518481203488, 0.09620145322488886, 0.0843086749581354, 0.25889880902000834, 0.20759035221167974, 0.10072371949042593, 0.2188004156840699, 0.12066272885671683, 0.11671810623790536, 0.14827408295656952, 0.1433960132833038, 0.20365516122962746, 0.19458263234368392, 0.19068066243614468, 0.13581206809197152, 0.2139957770705223, 0.17078278586268425, 0.1738305887473481, 0.11626050222132887, 0.12311061178999287, 0.11960884183645248, 0.15486373007297516, 0.26758679854018347, 0.20319256319531373, 0.11321839224547148, 0.21824001361216816, 0.15176349000207015, 0.12400545020188604, 0.19633972591587476, 0.15649791381188802, 0.2609896739678723, 0.11130787512021405, 0.2121875626700265, 0.24842518674475805, 0.10513906899307456, 0.09638667971427951, 0.08970557286271028, 0.13502834657473223, 0.1918386910110712, 0.21901716691042694, 0.13282481767237186, 0.08700881006994418, 0.12781443367046968, 0.20126579515635967, 0.7779229741011346, 5.5054016794477185, 10.45806200163705, 14.241192851747785, 13.773333294051033, 23.22230407169887, 29.961389677865164, 33.47284596306937, 30.448712008340017, 42.186692987169536, 50.697180134909495, 23.89967005593436, 2.6524101069995334, 4.495331193719592, 16.483395644596644, 61.87387520926339, 47.28643798828125, 42.58622482844761, 31.887513705662318, 22.54282409804208, 33.263840675354004, 31.5657183102199, 14.898059913090297, 14.44541777883257, 18.68231463432312, 6.7548080767904, 0.4734403182353292, 0.3549315987953118, 0.12278788696442332, 0.2796256382550512, 0.18753159498529776, 0.35400889973555294, 0.14350444317928382, 0.20830958576074668, 0.14136165673179285, 0.19979365915060043, 0.18788850440510682, 0.30446205554263933, 0.1569876532469477, 0.1977400050631591, 0.12813016958534718, 0.13130542848791393, 0.1325940072004284, 0.12647971457668714, 0.1340048714940037, 0.11222929174878768, 0.2394646161368915, 0.18646989124161856, 0.16266616354031221, 0.13884714165968554, 0.1546396099563156, 0.19324428987290176, 0.27993762865662575, 0.10051412680851561, 0.13722217242632592, 0.20692358299025468, 0.13970713051302092, 0.16466998601598398, 0.21098377369344234, 0.1512057613581419, 0.16571725053446634, 0.12115516886115074, 0.2959822677075863, 0.16650382189878396, 0.09350702459258692, 0.17562281686280454, 0.05766211623059852, 0.11863158856119428, 0.1302924028464726, 0.17348020683441842, 0.22030107730201312, 0.12358061942671027, 0.08780641441366502, 0.13365195186010428, 0.06692540166633469, 0.15586602129042149, 0.261437642787184, 0.10063195441450391, 0.11358718959880726, 0.07830019987055234, 0.17417993928704942, 0.125184744064297, 0.12403879341270242, 0.09833634152476277, 0.23189439092363628, 0.06742630978780133, 0.14602321945130825, 0.20239000554595674, 0.21706666371652059, 0.13248694794518606, 0.23951290068881853, 0.17671509539442404, 0.32392873668244904, 0.10676570742258004, 0.28376619464584757, 0.14937047341040202, 0.23338760222707475, 0.2119484469294548], [0.034852842667273114, 0.04193475676168289, 0.04117152700200677, 0.04963246852691684, 0.07889176705586058, 0.036559012186314375, 0.057840503087001185, 0.03121250568489943, 0.012935768014618328, 0.032975088605391126, 0.03722781362012029, 0.046820256393402815, 0.0814105976106865, 0.06688615520085607, 0.07428445999643632, 0.053265823383948634, 0.04738718597218394, 0.034601598113243065, 0.04326898731025202, 0.10905271648828473, 0.03490906607891832, 0.021903061208182147, 0.06202764090682779, 0.026694880598889928, 0.013789778126270642, 0.02701015510995473, 0.0834965363943151, 0.03157148124384029, 0.04309063098792519, 0.037280637571322064, 0.039309813507965634, 0.012997305203628327, 0.05949334653892687, 0.03498288390359708, 0.06156495466296162, 0.01847231521138123, 0.04332935657086117, 0.03535388310306838, 0.008576054142655005, 0.04325038866539087, 0.026574997031795125, 0.03639046069500702, 0.048109713808766434, 0.08120402440960918, 0.04966032578210745, 0.03382645667131458, 0.04375882174021431, 0.07189839838870934, 0.013856793637387455, 0.039755784041647396, 0.0612674102719341, 0.06756846965955836, 0.015069575747475028, 0.014065667920346771, 0.03513518787388291, 0.02159259411772447, 0.04323557285325868, 0.03531213962872114, 0.10797012065138135, 0.047614261108849726, 0.09612326563469001, 0.0729212560025709, 0.027605247284684862, 0.04678220414955701, 0.018646435778854147, 0.08282900721366916, 0.02723197329656354, 0.0669858455657959, 0.027802107256970236, 0.014746099444372314, 0.037067801492022615, 0.023626014290909682, 0.06641005431967122, 0.06682831687586648, 0.13018706707017763, 0.02423836330750159, 0.15931223279663495, 0.039993593602308204, 0.1177193389407226, 1.015832822237696, 6.117121517658234, 4.727850488254002, 1.7006782165595462, 2.2074930667877197, 1.267654755285808, 6.135296268122537, 4.313933270318167, 9.763312493051801, 7.5860883849007745, 15.283019644873482, 14.185100044522967, 11.43224287033081, 21.22265246936253, 19.541947501046316, 16.027428797313146, 22.703598465238297, 2.8161650342600684, 1.6239591389894485, 7.63148878301893, 2.4665796671594893, 2.0891943403652737, 2.9596598829541887, 1.5100803353956767, 0.5340318669165883, 0.14096749573946, 0.04690355335229209, 0.0880553824827075, 0.06796066968568734, 0.0261418067051896, 0.0700498382960047, 0.026863133534789085, 0.03885472007095814, 0.0309080402366817, 0.04273823382599013, 0.03920835216662713, 0.08606965653598309, 0.055197330990007946, 0.005597165394907019, 0.03266763760309134, 0.03491644175457103, 0.02044423297047615, 0.06092768135879721, 0.0014038731564401782, 0.04384259706629174, 0.047304971276649406, 0.05998746252485684, 0.05180097145161458, 0.04601235528077398, 0.02298941443275128, 0.09779143719268696, 0.03255903468068157, 0.0623396991619042, 0.07214855389403445, 0.016601704426908066, 0.012947007099033465, 0.029293737573815242, 0.04012283416731017, 0.0012317403785086104, 0.014850710884534886, 0.08353546394833497, 0.06622086518577167, 0.01624133956751653, 0.05601023290572422, 0.02588194136374763, 0.061988591216504574, 0.08841653953173331, 0.07228870530213628, 0.02994404892836298, 0.022852353751659393, 0.016185396051566516, 0.05863599718681403, 0.07880749300654445, 0.017324269582916583, 0.0454724585371358, 0.02022666241308408, 0.03299307996141059, 0.011771370540373027, 0.014785010035016706, 0.05303659050592354, 0.08735816739499569, 0.012229525866652173, 0.05754423434180873, 0.08582945513938155, 0.057854813390544484, 0.030421316889779906, 0.05406180263629981, 0.019601095534328903, 0.062232259927051406, 0.04311071223180209, 0.080910021971379, 0.12291904778352805, 0.08865818620792457, 0.01651797829461949, 0.0968892163197909, 0.13557319662400655, 0.08017064950295857, 0.06613912207207509, 0.04279025032051972, 0.05419357413692134, 0.05489649909681507, 0.1142837397222008, 0.07191734308643, 0.05762240157595702, 0.019020937915359224, 0.05970625047172819, 0.031871916194047244, 0.027506376250780055, 0.010313871383134807, 0.05792718593563352, 0.02986736429323043, 0.07023221493831702, 0.047974105192614455, 0.046138905454427004, 0.06984141269432646, 0.0659341434282916, 0.0764949099559869, 0.019619251435090388, 0.06873653376741068, 0.01443624303543142, 0.02075901554365243, 0.04574485981304731, 0.036211215491805754, 0.026743714764182056, 0.04259674231122647, 0.029604367512677397, 0.02149298687332443, 0.10189624835870095, 0.05436886687363897, 0.051544373256287405, 0.000861074986460153, 0.049033047298767736, 0.039459321913974624, 0.02505640682232167, 0.07491129743201391, 0.04866315071870174, 0.058361455132918696, 0.05956727292920862, 0.018270104990473816, 0.022578547908259288, 0.05170656008911984, 0.019511321958686625, 0.04094764097992863, 0.08948543574661016, 0.01545564690604806, 0.025292119709774852, 0.03848472510331443, 0.03882653372628348, 0.06373172053801161, 0.03670511095385466, 0.04134227355409946, 0.02163183379785291, 0.033775247633457184, 0.03295582838888679, 0.00725341127586684, 0.07544563697384936, 0.0892565930262208, 0.04577052540012768, 0.040625218102442365, 0.07033993915787765, 0.0038103719208655612, 0.04654765155698572, 0.03542698507330247, 0.022310058386730294, 0.038074499794415066, 0.03244701872712799, 0.015568400766434414, 0.08326938322612218, 0.07372656850410358, 0.08951155255947794, 0.08717629286859717, 0.043378034673099, 0.05940505556230034, 0.11054741378341403, 0.06596769019961357, 0.05433598167396017, 1.8791207671165466, 10.121989795139857, 7.014405804021018, 4.7070202231407166, 1.8498482235840388, 1.192172999892916, 7.890946677752903, 19.18581063406808, 25.377004725592478, 23.098381212779454, 30.63817548751831, 33.17640107018607, 30.647864750453405, 39.39625474384853, 29.99837146486555, 25.725206749779836, 28.34935028212411, 14.095477836472647, 4.739545609269824, 6.122104244572776, 5.130565473011561, 4.0480482918875555, 8.503276654652186, 5.979703954287937, 1.9785229989460535, 0.18670062028935977, 0.08139519486576319, 0.12859841303101607, 0.15890446039182798, 0.03950520445193563, 0.030920321720519235, 0.020486631231116395, 0.09818091629339115, 0.008726455670382296, 0.07920594234019518, 0.05165217890005026, 0.010290020029060543, 0.08619038148650102, 0.09353673764105354, 0.0323644308373332, 0.06772943852203232, 0.06952603640300886, 0.08853613811412028, 0.01783516234718263, 0.0222345510098551, 0.029779219201632907, 0.026761315962565795, 0.046822200396231244, 0.02551315418843712, 0.031880021294845004, 0.0581686765487705, 0.04713907285726496, 0.08875700126269034, 0.11583123382713113, 0.07984359562397003, 0.015048712491989136, 0.022358595692951764, 0.044043521463338814, 0.057952651354883394, 0.027690420392900705, 0.038103361281433275, 0.08165209500917367, 0.0227626124064305, 0.06455080730042287, 0.05870250718934195, 0.08670754730701447, 0.028535841099385704, 0.014126755579906915, 0.017176104676244513, 0.008303182981243091, 0.037553829340530295, 0.020141384131940346, 0.031637533235230615, 0.060647819590355666, 0.003688259366234498, 0.03856685158929654, 0.0866573289302843, 0.026451237333406295, 0.014131301764531859, 0.035491727492106814, 0.04936896963045001, 0.03096409740724734, 0.01530414360708424, 0.03509436720716102, 0.07429479408477034, 0.0389909393686269, 0.06041718553751707, 0.029383785956140076, 0.0812177647437368, 0.03361759680722441, 0.030807125116033212, 0.04863267092566405, 0.06397622384663139, 0.017751831461542418, 0.019610550919813768, 0.0600666543468833, 0.025136161828413606, 0.15420671818511827, 0.12722581811249256, 0.1357741922672306, 0.18279162075902733, 0.17484322083847864, 0.22601010810051644, 0.1895683535507747, 0.08625172783753701, 0.19687019102275372, 0.1578103226742574, 0.0867163139794554, 0.17535147070884705, 0.18470073331679615, 0.15101600225482667, 0.13783719656722887, 0.134460358481322, 0.12071888441486017, 0.20544585585594177, 0.15986275539866515, 0.15196323714085988, 0.11044969795537846, 0.14850246427314623, 0.2329237014055252, 0.13338399838124002, 0.21777555639190332, 0.1598948093929461, 0.1596157415104764, 0.21866103102053913, 0.11776621213981084, 0.13309050484427384, 0.1443279811314174, 0.20200634827571257, 0.15826388262212276, 0.09262852530394282, 0.20326850483460085, 0.14365562078143868, 0.11685289043400969, 0.2202991366918598, 0.14881225622126035, 0.12930441514721938, 0.11168011264609438, 0.14422588875251158, 0.13226662762463093, 0.16612998981560978, 0.17543358701680387, 0.07783479948661157, 0.1960607258869069, 0.1094529435836843, 0.09848420109067645, 0.22527266267154897, 0.13892745306449278, 0.1357906942388841, 0.10587881465575524, 0.09910298431558268, 0.1513254413647311, 0.059555147508425374, 0.14227853396109172, 0.12377427332103252, 0.24208232281463488, 0.20647950896195003, 0.15510731057396956, 0.09783512806253773, 0.15887098147400788, 0.11775907395141465, 0.15676999278366566, 0.15780622432274477, 0.13087060967726366, 0.14281488875193254, 0.1630735695362091, 0.13627514110079833, 0.0891565837498222, 0.10162833559193782, 0.19868539433394158, 0.2092947100422212, 0.2627591847309044, 0.17537220673901693, 0.22251869259136065, 0.17766275097216877, 0.2932786856378828, 1.543016208069665, 10.833963888032095, 9.939705542155675, 9.974803498813085, 18.944075856889995, 29.516097000667028, 23.72145049912589, 31.006586347307476, 45.42401851926531, 48.05020482199532, 50.793652398245676, 47.12801211220877, 41.62753323146275, 58.444758551461355, 51.61437708990914, 45.45693908418928, 39.283450739724294, 29.739933218274796, 20.651560919625418, 36.78842558179583, 21.07597599710737, 10.378226331302098, 18.814055953707012, 11.979003565652029, 2.599134360040937, 0.19282906715359005, 0.2514641551034791, 0.2031972043748413, 0.3608406345759119, 0.12856449985078403, 0.13329034697796616, 0.19548155553638935, 0.12625678868166038, 0.1627006602606603, 0.1824931874871254, 0.16845143453351089, 0.1633702250463622, 0.17429139544921263, 0.24111272341438703, 0.09190185501107148, 0.2038363165089062, 0.24962223108325685, 0.19616819226316043, 0.12976318624402794, 0.13450461253523827, 0.10521455601389919, 0.10202185876135315, 0.18275244214705058, 0.1046413771275963, 0.07076954003423452, 0.14630852985594953, 0.14241291103618486, 0.15889815001615457, 0.1516276608620371, 0.158091968989798, 0.1026878815942577, 0.15554690627115114, 0.2700069972446987, 0.19658420208309377, 0.18284228018351964, 0.29028854465910364, 0.16812667410288537, 0.23505237432462828, 0.08102894880409751, 0.13160368534071104, 0.17394992948642798, 0.2135197576135397, 0.22642728500068188, 0.15902796733592237, 0.09519789314695767, 0.157780399279935, 0.09223536854343754, 0.10090653039515018, 0.10812574265790836, 0.13749060087970325, 0.14945244044065475, 0.14648132558379853, 0.09735043014266662, 0.08748007299644606, 0.12249101432306425, 0.19475707012627805, 0.20079821667500905, 0.1715142194713865, 0.1610308127211673, 0.4048317154603345, 0.1541142745741776, 0.2741167481456484, 0.14270367686237606, 0.2018441241234541, 0.17588251935584204, 0.17507567336516722, 0.21947261318564415, 0.13757845759391785, 0.15130838299436228, 0.16626097421560967, 0.2796626591256687, 0.13361236612711633], [0.031477018991219144, 0.048773263381528, 0.08516209559249026, 0.027051905369652168, 0.035967350006103516, 0.07855515261845929, 0.026347728512649025, 0.038630542278821976, 0.06671552399971656, 0.026939490776775137, 0.08002395023192678, 0.03449553969715323, 0.019797453390700475, 0.08653853101921932, 0.0302253797251199, 0.04425111246694412, 0.013480369550442057, 0.05487246877912964, 0.05777316527175052, 0.029150817742837325, 0.042038837248193364, 0.008836626008685147, 0.06903631053864956, 0.06175288172172649, 0.017773968666525822, 0.024611564353108406, 0.0018831151246558875, 0.028728575578757694, 0.053556935262999365, 0.04446153635425227, 0.03545288136228919, 0.040883848510150395, 0.028349717247432897, 0.026678568617041622, 0.06445285398513079, 0.052309828610824685, 0.09536602055387837, 0.006887813215143979, 0.11241155304014683, 0.005127483879082969, 0.0494930770780359, 0.025230255975787128, 0.029912632756999562, 0.0811064171471766, 0.020218041625672152, 0.03830081157918487, 0.04390034718172891, 0.024826244351321032, 0.08807038489196982, 0.020455325321693505, 0.030974872543343475, 0.00547863550517442, 0.06297739315778017, 0.07804540997104985, 0.019135366060904095, 0.056449014360883405, 0.020708390045911074, 0.04014949041551777, 0.0317985936999321, 0.007395142822393349, 0.027988828219739453, 0.020597743036757623, 0.02565717324614525, 0.04795437678694725, 0.10415470467082091, 0.09376125809337411, 0.030612969105797153, 0.06586935690471105, 0.0264694593913321, 0.018311985868162343, 0.037625608167478015, 0.042698078123586516, 0.08686407176511628, 0.008095287485048175, 0.08344135792659861, 0.018355549512697116, 0.01968624659015664, 0.10475297578211341, 0.04339469610048192, 0.12853110235716614, 1.163850296820913, 5.500920959881373, 2.615514303956713, 1.5135900442089354, 1.3217470241444451, 2.0987546273640225, 10.948389428002493, 4.20605206489563, 5.759443453380039, 13.297200168882098, 18.30226727894374, 17.857648577008927, 14.899519034794398, 10.698432326316833, 17.084274121693202, 13.70171126297542, 5.932093594755445, 8.218980687005178, 2.642700650862285, 3.098222379173551, 1.4609593940632684, 2.1400208473205566, 0.6785879986626762, 0.03355368220114282, 0.08295858026083026, 0.04346066666767001, 0.10243822820484638, 0.04835936380550265, 0.13807133186076367, 0.0952684132914458, 0.07428253295698337, 0.03496975764366133, 0.10195699081357036, 0.06316688084708792, 0.11307968611695937, 0.10590663459151983, 0.05725384849522795, 0.05954339528190238, 0.014490468161446708, 0.06639543867536954, 0.056329303820218356, 0.013591054727190306, 0.04976049451423543, 0.05033932559724365, 0.01766607820588563, 0.07870735480849232, 0.032349676093352694, 0.037270350980439355, 0.08173923247626849, 0.03936787914218647, 0.013091620723051684, 0.10235113823520285, 0.01480471299562071, 0.07150548590081078, 0.04095990889306579, 0.058733909790005, 0.02776020941590624, 0.027777169398697357, 0.07047605328261852, 0.014656537910923362, 0.07649497780948877, 0.028668080789170096, 0.02706495190172323, 0.02910947460415108, 0.019544651598802636, 0.04123762309817331, 0.11720271594822407, 0.04616428944947464, 0.06923841219395399, 0.040575176144817045, 0.040724555629172494, 0.017023391888609955, 0.05077062959649733, 0.029776790046266148, 0.01997978932091168, 0.01262837044695126, 0.014086024819074996, 0.03913010690095169, 0.042287611934755526, 0.06695117921169315, 0.06308040155896119, 0.01779249606521002, 0.021617567599085823, 0.06979652081749269, 0.047253015850271494, 0.0589565099882228, 0.029971176758408546, 0.02375393171262528, 0.037309767079672644, 0.03511325762208019, 0.04516217125845807, 0.008724068075285425, 0.017436814793784703, 0.007056899476862911, 0.04220414534211159, 0.06108032459659236, 0.015151954987751586, 0.13328277452715806, 0.08261262918157236, 0.11601352904524122, 0.09543331765702792, 0.11566031085593359, 0.05155548765989287, 0.06539375813943998, 0.08609126787632704, 0.040716888183461766, 0.02686200207764549, 0.04691794168736253, 0.05702005246920245, 0.022126116024862443, 0.026210026615964513, 0.028853320849261115, 0.03882452526262828, 0.030899880853082453, 0.0746441717658724, 0.034396080034119744, 0.11317698803863355, 0.03554731647350958, 0.0395142561090844, 0.014616833434307148, 0.00657006332351427, 0.018055224824430685, 0.015530808230063744, 0.021422130854002068, 0.02486834575289062, 0.03148367881242718, 0.019274202807407294, 0.07003400128866945, 0.10865048092922994, 0.027515227740098323, 0.05165673526270049, 0.017254502612299154, 0.013423755132992352, 0.049338954633900096, 0.07959107203142983, 0.02860515345154064, 0.05400504996734006, 0.0017273054607877775, 0.019414625629516583, 0.10042948635028941, 0.02367032432396497, 0.11270635614969901, 0.023154001583212187, 0.014144186296367219, 0.05196619133598038, 0.03929348795541695, 0.04200829977967909, 0.042104468547872136, 0.016389667322593074, 0.040926368907094, 0.03884284910080688, 0.06647494940885476, 0.033542299776204994, 0.07579150662890502, 0.010583248937369456, 0.04605518101847597, 0.035512229427695274, 0.054788734165153334, 0.011996308291730071, 0.05141921068674751, 0.11159330087580852, 0.08640747876571757, 0.022463653269889097, 0.12255744290138994, 0.03176273651687162, 0.04105144326708146, 0.06645055607493434, 0.06775996581252132, 0.06316973069416625, 0.009491381767605032, 0.053938940300473144, 0.044511686877480576, 0.05778385219829423, 0.09913341661116906, 0.04797865476991449, 0.17250615624444826, 2.955676393849509, 7.9874423912593295, 3.64497286932809, 4.770196284566607, 0.8358472287654877, 5.767037834439959, 15.215853146144322, 15.425164154597692, 21.002755880355835, 31.17802619934082, 35.51223605019705, 36.65285927908761, 30.705930846078054, 19.022765942982264, 20.261935472488403, 15.816832372120448, 6.4944299800055365, 6.738013412271227, 5.816649275166648, 2.082965063197272, 3.9698680298668996, 5.5899569136755805, 1.3602314676557268, 0.14690893835255078, 0.16397880310458796, 0.05438356733481799, 0.13956553382532938, 0.04891506702240024, 0.05967459681310824, 0.08153934963047504, 0.06969203320997101, 0.062144294647233825, 0.03845423513225146, 0.006200810079462826, 0.053574818053415844, 0.07802016846835613, 0.021885510899924805, 0.08756700011768512, 0.03811472674299564, 0.07905308197119407, 0.05468319482835276, 0.015490526998681682, 0.033022060192057064, 0.05909012031874486, 0.02254065851281796, 0.04926972709862249, 0.019345028292653815, 0.015195954591035843, 0.08300430673573699, 0.04894309051867042, 0.062034724812422476, 0.03283157505627189, 0.05931768739329917, 0.07575164269655943, 0.0924133143520781, 0.04722223071647542, 0.007914152561819978, 0.041473610792309046, 0.0758886049900736, 0.049600482386137755, 0.1066601477297289, 0.01658790302462876, 0.02296891588983791, 0.04502103936725429, 0.01899899578919368, 0.07886581309139729, 0.03406545706093311, 0.03758402414886015, 0.023499927217406884, 0.01357424317393452, 0.019399764016270638, 0.02372366056910583, 0.026395144539752176, 0.03665494346725089, 0.054007808212190866, 0.12478382486317839, 0.07101962090070758, 0.044110146816819906, 0.029697873030922244, 0.07021930241691214, 0.02291981709588851, 0.047294437020484886, 0.06502745779497282, 0.01925180945545435, 0.07006728343133416, 0.09925249950694186, 0.01533093216962048, 0.0573827430073704, 0.030492427359734262, 0.034600515849888325, 0.04695171916059085, 0.026839115091466477, 0.0060163545754871196, 0.03045271270509277, 0.03870502167514392, 0.049516598494457345, 0.12895454892090388, 0.2484212512416499, 0.18063329585960933, 0.25554806739091873, 0.17162745339529856, 0.16372086480259895, 0.16051869520119258, 0.22733964318675653, 0.17280406025903566, 0.18635865221066134, 0.17169134425265448, 0.1244876171861376, 0.11459775215813092, 0.10949714335479907, 0.1958570975278105, 0.11470278937901769, 0.1212631780654192, 0.14537315576204232, 0.20910192467272282, 0.14561014090265545, 0.22706707566976547, 0.20907706314963953, 0.16126863924520357, 0.1768970920571259, 0.11794664817196981, 0.10025405112121787, 0.0809514397489173, 0.05674903879740408, 0.13176494597324304, 0.14251375491065638, 0.08702441637537309, 0.15181272450302327, 0.2138041044984545, 0.08974566071161202, 0.14467556748007024, 0.21573602940355027, 0.1881953922233411, 0.21974138090653078, 0.2834940749619688, 0.11511684501809732, 0.13929179922810622, 0.13481387522603783, 0.07985667777912957, 0.26397156396082466, 0.14911712200513907, 0.27143669767039164, 0.13023008619035992, 0.1905318054237536, 0.2061460225709847, 0.12479245582861559, 0.1832654553332499, 0.09952114509152514, 0.15292710970555032, 0.22401066896106514, 0.11045337561517954, 0.15912506569709095, 0.1468436632837568, 0.13929038787526743, 0.13081590618406022, 0.17361188334013733, 0.10615233890712261, 0.17001366641904625, 0.20179560886962072, 0.16641661657818727, 0.20197452498333796, 0.21020824887922832, 0.08244235760399274, 0.21770988777279854, 0.3355250901409558, 0.1352158665124859, 0.14997264609805175, 0.11240322063011782, 0.19926033062594278, 0.13471502624452114, 0.22868082193391664, 0.1052200725036008, 0.13004753312894277, 0.28366259591920034, 0.3044591514127595, 0.20240992733410426, 2.4709798310484206, 9.441748993737356, 5.96513922725405, 12.007482494626727, 26.653776168823242, 28.862981966563634, 31.327527114323207, 21.965868268694194, 42.70564351763044, 51.152068274361746, 59.347767284938264, 56.81989104407174, 54.43009982790266, 50.87944180624825, 34.28524671282087, 28.720509154456003, 25.250326905931743, 37.31248303822109, 24.42789122036525, 11.91422290461404, 12.477316209248134, 12.827470677239553, 5.065864716257368, 0.18585291291986192, 0.2730089175914015, 0.15153349377214909, 0.27062744966575075, 0.20230560936033726, 0.2669171116181782, 0.1760187963289874, 0.14313906564244203, 0.23383448539035662, 0.2771146787064416, 0.2426785651062216, 0.2055634052625724, 0.27004990779927796, 0.15553072999630654, 0.16606504044362477, 0.09983876054840428, 0.14751481584140233, 0.16007236843662603, 0.1431348044425249, 0.23044582722442492, 0.15285329866622174, 0.13348047249019146, 0.27277740144303864, 0.16931849372174057, 0.21494484400110586, 0.42608682491949623, 0.17535258350627764, 0.11699408000069005, 0.20273775474301406, 0.15032270231417247, 0.07892195507884026, 0.2440463559968131, 0.14006630623979227, 0.11248542514762708, 0.07931651640683413, 0.22373370453715324, 0.09753326140344143, 0.21122108453086444, 0.0877501435045685, 0.12154228665999003, 0.1118479889950582, 0.10896749248994247, 0.1899503009127719, 0.1945815873997552, 0.21215245526816162, 0.15911271635975155, 0.12552669857229504, 0.05979004276118108, 0.12513274114046777, 0.17655322408037527, 0.15457350707479886, 0.15246988566858427, 0.1996890969042267, 0.14012414456478187, 0.15727493140314305, 0.14963838617716516, 0.1607353650033474, 0.15779232792556286, 0.12879009917378426, 0.3477579637297562, 0.31429970051561085, 0.1439538640635354, 0.1655789650976658, 0.1264685730316809, 0.16785836778581142, 0.1896264497190714, 0.09218561835587025, 0.21551788039505482, 0.1691906170121261, 0.09282553794660739, 0.2069654893130064, 0.24437672112669262, 0.12462724612227508], [0.06827042770705052, 0.06492611858993769, 0.1351146697998047, 0.08906545649681773, 0.03678673532392297, 0.11015570230249848, 0.02217860919024263, 0.039472536383462806, 0.028442849571417485, 0.04131550874028887, 0.01810395551313247, 0.035066632088273764, 0.07191306831581251, 0.04930124165756362, 0.06264430031712566, 0.04085228306108287, 0.028826135343738964, 0.026095890240477662, 0.009798253470632647, 0.023552189680880735, 0.08226649489785944, 0.01926318509504199, 0.038169979849564176, 0.014792472223884292, 0.017647048691287637, 0.020175651846719638, 0.03796613435926182, 0.007385525436672781, 0.02103797486051917, 0.01709256344474852, 0.00475409157141777, 0.01692034786434046, 0.09765588625201158, 0.05614030467612403, 0.06755147914269141, 0.07313616161367723, 0.03257848149431603, 0.04789923903133188, 0.04304838879033923, 0.071265203080007, 0.023106782331264446, 0.04617380929578628, 0.07636290775345904, 0.05494387101914201, 0.01804170840685921, 0.037418427677559, 0.03276822024158069, 0.02319715471406068, 0.03378946633477296, 0.032892734810177765, 0.03613602363371423, 0.09076849118407283, 0.005828456354460546, 0.04575930582359433, 0.02566818586949791, 0.02815592764610691, 0.037018641629921537, 0.06402519371892725, 0.12094886707408087, 0.10655680006103856, 0.0717631731448429, 0.03838184901646205, 0.024391564640349576, 0.010563428929474736, 0.059076644613274505, 0.04588174407503434, 0.0744567671790719, 0.010940612127472247, 0.09309041087648698, 0.018114184428538595, 0.05632545991933771, 0.06569284959031002, 0.07015507229204689, 0.07116874932710614, 0.02756113063410989, 0.035154536299939664, 0.04986765894240566, 0.09564652693058763, 0.03013891400769353, 0.038942787131028514, 0.12416603229939938, 2.468951174191066, 5.149547951562064, 1.5835248572485787, 1.7537477974380766, 2.047556608915329, 6.397435298987797, 13.750819393566676, 9.419746654374258, 6.73876381771905, 11.550953711782183, 12.153951389448983, 5.922191543238504, 4.04763400554657, 7.593245029449463, 3.752599596977234, 2.432746934039252, 4.323602557182312, 1.499904372862407, 2.584050689424787, 2.417973978178842, 0.7845940589904785, 0.23860374518803187, 0.07405331704233374, 0.13357139618269034, 0.08071881080312387, 0.07232922741344996, 0.06140739204628127, 0.05105491880593555, 0.06092739637408938, 0.04687943482505424, 0.08514202452663865, 0.027785566269553134, 0.06917611589389187, 0.04312746865408761, 0.07789950458598988, 0.018615275754460266, 0.053694620196308405, 0.04846206008057509, 0.04128485931349652, 0.035119164269417524, 0.05871847311833075, 0.029584177703197514, 0.010349181497336497, 0.01755647105164826, 0.004305469662150634, 0.05139265621879271, 0.033489173876919916, 0.03046351158991456, 0.042100163243178806, 0.03935774861435805, 0.07591021633041756, 0.10136333374040467, 0.06201797178281205, 0.1361709859754358, 0.01715139582354043, 0.054357918711113076, 0.054418976684766154, 0.02491021984522896, 0.03623260630826865, 0.10615325492939778, 0.057243466909442625, 0.072842084536595, 0.017851102831108228, 0.03596393018960953, 0.06212415572788034, 0.023692013695836067, 0.024418127589992115, 0.05920058581978083, 0.035054452384689024, 0.025646421858774762, 0.04441345875550594, 0.06519802114261047, 0.07587081380188465, 0.06731883662619761, 0.04821461192997439, 0.011558835560988103, 0.010151605670606452, 0.02105161002171891, 0.03851724050140806, 0.005235424381680787, 0.0386847504414618, 0.0683172262672867, 0.018406894257558242, 0.13113131640212877, 0.05821677789624248, 0.00948187634016254, 0.012480026576668024, 0.03328221730355706, 0.09058117480682475, 0.050860606732645204, 0.12467650776462895, 0.05015693199155586, 0.05330955496590052, 0.019931145145424774, 0.055829230296824656, 0.002117830777673849, 0.07434805229838405, 0.08791471538799149, 0.07317747082561255, 0.014292476732017738, 0.08113727013447455, 0.06332626872296844, 0.048315177605088265, 0.06694340998572962, 0.05990890174039772, 0.059490042073386054, 0.02231415843458048, 0.054336643245603354, 0.014527894456737807, 0.045380727387964725, 0.031825918305133066, 0.025149574769394736, 0.0061456400934340695, 0.01578967782136585, 0.010412364981935492, 0.0038020615632246646, 0.03833151189610362, 0.09017966528023992, 0.06760498841426202, 0.03603678449456181, 0.0436971293363188, 0.028806756383606365, 0.015915486695511, 0.03475411242938467, 0.0548334326595068, 0.09890445175447635, 0.0395473923667201, 0.035200914168464284, 0.0508463032144521, 0.07452092266508512, 0.04016879473679832, 0.057919484563171864, 0.05775681257780109, 0.0020529670707349268, 0.04154823946633509, 0.024430392110454183, 0.011225032803070332, 0.022313563020101616, 0.07024663380746331, 0.033928986705307446, 0.05227594257199338, 0.038370581942477396, 0.04224184814042278, 0.028085894350494658, 0.02150092912571771, 0.0854999449636255, 0.01123142714745232, 0.050186539867094586, 0.025496394373476505, 0.02248064717943115, 0.04637603308739407, 0.029508473551166908, 0.01719759388028511, 0.022431275275136744, 0.058074122693921836, 0.03559387754648924, 0.03643312358430453, 0.054219443284507306, 0.018322048542488898, 0.056753886930112324, 0.09398301012281861, 0.07387176142739398, 0.013997056155598589, 0.16849130525120667, 0.058443544299474785, 0.062288978669260225, 0.10378738652382578, 0.034548709701214514, 0.0959177916603429, 0.030973820814064572, 0.08861558777945382, 0.021231160565678562, 0.14911888619618757, 0.0316589274443686, 0.06542235839047603, 0.13752327912620135, 4.507475776331765, 9.328191978590828, 3.5846314557961056, 3.622515205826078, 3.0036871433258057, 8.66134990964617, 13.880413719585963, 17.088236331939697, 23.362874814442225, 33.02819946834019, 28.845211948667252, 19.719932556152344, 5.065893377576556, 4.883786737918854, 4.863561400345393, 6.279290301459176, 10.338715400014605, 3.785048987184252, 7.010428828852517, 2.7529483692986623, 1.7536573622907912, 0.48800048551389147, 0.17985212563404016, 0.11462520568498544, 0.21364810929766723, 0.07303909039390938, 0.02307650100971971, 0.06568288869623627, 0.02614931469517095, 0.03429019803713475, 0.030349778942763805, 0.034098986868879626, 0.05252321091081415, 0.03557932297033923, 0.16925614992422716, 0.012420128049728061, 0.013132561829739382, 0.04697951195495469, 0.051959830070180554, 0.04800683772191405, 0.014505928581846612, 0.01054977426039321, 0.021239928934457045, 0.029708108731678555, 0.020303501414933374, 0.07046720518597535, 0.03714462522683399, 0.053051151867423735, 0.050059660603957515, 0.05431373590337379, 0.046338201367429326, 0.044059782555060725, 0.04837213722722871, 0.03185153978743723, 0.034022034212414703, 0.054676372158740244, 0.10973068832286767, 0.042896617470043044, 0.09215990866401366, 0.03706343172650252, 0.10915716338370528, 0.04599234189039894, 0.04402354199971471, 0.003966912070089685, 0.005203292779957077, 0.019112280603232126, 0.003445500104654846, 0.02230707792166088, 0.0011031290487153456, 0.06164882159126656, 0.012090622962984656, 0.05446237239188381, 0.04125926836526819, 0.03975068485098226, 0.03781110607087612, 0.05271043229315962, 0.04419191028656704, 0.02702126951356019, 0.037525707456682406, 0.006342864778291966, 0.04746488840984447, 0.018431852471881678, 0.029507048627627746, 0.01712994054625077, 0.036530333903751204, 0.0012862457182823814, 0.05252877829064216, 0.015715978740315353, 0.040133263250546794, 0.013542902489591922, 0.05124735472989934, 0.07598757610789367, 0.03822668841374772, 0.12257706613412925, 0.017281832306512764, 0.16321576333471707, 0.14208125668976987, 0.15330125391483307, 0.17952771804162435, 0.19817601809544222, 0.31160105818084305, 0.17980739660561085, 0.20438993323062146, 0.17266474344900676, 0.1352599034351962, 0.11055389379284211, 0.1189044817749943, 0.21261745531644138, 0.13478678810809339, 0.15716795357210295, 0.12443851839218821, 0.1479911067123924, 0.12542493189019815, 0.1720279519047056, 0.17247853986918926, 0.16511937975883484, 0.11928752836372171, 0.24891066497990064, 0.23985751505408967, 0.11486570563699518, 0.09843223887894835, 0.10225350383136954, 0.14436777042491095, 0.17413223827523844, 0.1617835523294551, 0.2350777786757265, 0.08387832090790782, 0.23643012610929354, 0.13959796779922076, 0.17763943650892802, 0.24598123931459018, 0.16498859891934053, 0.16396436387939112, 0.14098508336714335, 0.14310606169913495, 0.12008507842464106, 0.14231643692723342, 0.2029519003948995, 0.21093767402427538, 0.08920834240104471, 0.18444667623511382, 0.09503031535340206, 0.09071183351001569, 0.09823833392666918, 0.13929877456809792, 0.1919332245098693, 0.20878928287753037, 0.09688357769378594, 0.13600870754037583, 0.07436044234782457, 0.1713450878326382, 0.13294224494269916, 0.18367664755455085, 0.2497742229274341, 0.26735080406069756, 0.12153235290731702, 0.22629682985799654, 0.13717824406921864, 0.13523432266499313, 0.20546462413455757, 0.2187855150550604, 0.20827214419841766, 0.15671727061271667, 0.1793798788317612, 0.22710297017225198, 0.11705195903778076, 0.2652882475938116, 0.097551147586533, 0.18409780066992554, 0.09379438417298452, 0.16845524790031569, 0.1031835785667811, 0.20782353755618843, 0.09870047734252044, 0.15277442575565406, 0.20659902612013475, 4.617329401629312, 11.114626816340856, 6.539822561400277, 20.414905275617325, 45.76842335292271, 49.47776780809675, 47.671065943581716, 23.561485597065516, 39.24910926818848, 49.59990324292864, 54.59666551862444, 37.31762817927769, 17.780183110918315, 12.569544860294886, 15.599520512989589, 29.479889937809535, 45.1806891305106, 16.475740466799053, 18.20810181753976, 8.949253729411534, 4.6753221069063455, 0.4975649522883551, 0.3414180582123143, 0.23655997057046207, 0.301939533757312, 0.33918977635247366, 0.14036134683660098, 0.20427508439336503, 0.1259530492659126, 0.18299082506980213, 0.25299311163169996, 0.16709984705916472, 0.15215668747467653, 0.3324390585933413, 0.25532605073281694, 0.1281802590404238, 0.14052187465131283, 0.17086376223180974, 0.31470958994967596, 0.15064598353845732, 0.16990496510905878, 0.1239528094551393, 0.09719041801456894, 0.11189331513430391, 0.06981521445725646, 0.1775205164615597, 0.09822069201618433, 0.1882692032626697, 0.13316917419433594, 0.1487994319094079, 0.15347947792283126, 0.12880585475691728, 0.20829444085913046, 0.22562442879591668, 0.17207088960068567, 0.20251701373074735, 0.2846878623323781, 0.23466463227357182, 0.23291124350258283, 0.19924381508358888, 0.2437823244503566, 0.20317794755101204, 0.1715080312320164, 0.08948658247079168, 0.19239792600274086, 0.14779389729457243, 0.13664537694837364, 0.18377469586474554, 0.2171811597155673, 0.17389120906591415, 0.19327000635010855, 0.25545597661818775, 0.09795173430549246, 0.22610886208713055, 0.15010915377310344, 0.10505357358072485, 0.15453065080302103, 0.13958632413830074, 0.11584397671478135, 0.06941339280456305, 0.11842848945941244, 0.3546747868614537, 0.12539286432521685, 0.21056047640740871, 0.16935527031975134, 0.12497404537030629, 0.09057878636355911, 0.10800796254937138, 0.14357156386332853, 0.11519142958734717, 0.16778199188411236, 0.2607973500021866, 0.13315861618944577, 0.2752889852438654, 0.126950577167528], [0.026451155909204056, 0.0725494052416512, 0.04408150924635785, 0.035637249504881244, 0.03303550875612667, 0.007063700094087315, 0.151947413704225, 0.021886009623163512, 0.02631211729853281, 0.018674074206501245, 0.016740792231368165, 0.03225475922226906, 0.012457543318825108, 0.03721137610929353, 0.01413348749546068, 0.021503641569454755, 0.027553291858306954, 0.008444870422993387, 0.04013425051899893, 0.007073140636618648, 0.09070823727441685, 0.06216013165456908, 0.04515942658430763, 0.03384638524481228, 0.0704350426260914, 0.019265061244368553, 0.0493160608623709, 0.020921964032043303, 0.03676811293033617, 0.041368227518562756, 0.08313666856182472, 0.018940546782687306, 0.03881089010142854, 0.013292666408233345, 0.06022903456219605, 0.05223724232720477, 0.028271125928897942, 0.03471903216892055, 0.011554682926673974, 0.03187754464202693, 0.03814821583884103, 0.08045045020324842, 0.0705623154395393, 0.08335005425448928, 0.0330673761532775, 0.042378647585532496, 0.05734004279864686, 0.0357097679349993, 0.04461244932774987, 0.0501514901407063, 0.0387074406524854, 0.14919686344053062, 0.029451951584113494, 0.04158778787989702, 0.05457225435280374, 0.05618470122239419, 0.1027195081114769, 0.01750285321447466, 0.009431546853323067, 0.06007964829249041, 0.024875436443835497, 0.08281496832413332, 0.034048588680369515, 0.03969003739101546, 0.060581262090376446, 0.005603777718663747, 0.0672001133539847, 0.02888266070346747, 0.03962251637130976, 0.04458783546994839, 0.08207772645567145, 0.03116598871669599, 0.01606310368515551, 0.04559434378253562, 0.013464999035932124, 0.07728389690497092, 0.10693219277475562, 0.03480577269302947, 0.03177126570205603, 0.10260788910090923, 0.018010892738987292, 0.08703897773687329, 1.4111998698541095, 1.0972207635641098, 2.2099201594080244, 1.706905213849885, 4.47046880211149, 4.8737804634230475, 13.272580095699855, 13.722323962620326, 8.45865271772657, 8.75588275705065, 8.03790715762547, 13.55233975819179, 2.2681829759052823, 1.5756622105836868, 3.4129206240177155, 2.758355804852077, 0.6510921312229974, 4.634847547326769, 1.8063862643071582, 0.11228501982986927, 0.003579871878693146, 0.02186331432312727, 0.007994860061444342, 0.033890917498086176, 0.013255112039457475, 0.044001978156822066, 0.08905292395502329, 0.006916069533742432, 0.07299660053104162, 0.07884021196514368, 0.08177589372332607, 0.03271233270476971, 0.03580482390576175, 0.046806153043040206, 0.012924232919301306, 0.028168604376592805, 0.04582663346081972, 0.07508242396371705, 0.03711042366921902, 0.06981819322598831, 0.029890960348503928, 0.019075202057138085, 0.0054427524529663575, 0.015876511644039835, 0.05053778691217303, 0.016281256086326072, 0.04957886765311871, 0.12195510736533574, 0.017902523911158954, 0.05741998779454401, 0.01847011166890817, 0.022586556317816888, 0.08379240480384656, 0.014789493455152427, 0.027618035973448838, 0.03743917727842927, 0.029797098599374294, 0.04970186569594911, 0.017190526938065886, 0.06085999070533684, 0.028618076150970798, 0.032832443581095765, 0.0231642372839685, 0.06296242467526879, 0.00728998685787831, 0.042345494364521334, 0.06652807191546474, 0.020565848498206054, 0.04473410726391843, 0.013663055774356638, 0.04455301983814154, 0.07385331884558712, 0.01606983644887805, 0.027627443861482397, 0.011893811336319362, 0.005962876262076731, 0.06815163658133574, 0.017577056107776504, 0.011633828947586673, 0.023993875265919735, 0.0349081738053688, 0.051627324162317176, 0.036176406645349095, 0.03326707240194082, 0.05010028788819909, 0.04125413864052721, 0.038334680654640706, 0.0055690023748736295, 0.031714143231511116, 0.053069526595728736, 0.05309959926775523, 0.04682648195219891, 0.05081602019656982, 0.04582490998187235, 0.04764893085562757, 0.0794640299198883, 0.07206511444279126, 0.027774560431550657, 0.03768499694498522, 0.012674602430446871, 0.12136961306844439, 0.05032945291272231, 0.09576543340725557, 0.03370972829205649, 0.022995984348069345, 0.050253996425973516, 0.06592423003166914, 0.039543212591005225, 0.09089294807719332, 0.025166801077180674, 0.046572122922433276, 0.028026468253561428, 0.019518550052972775, 0.017282943407605802, 0.13366658107510634, 0.03973449161276221, 0.05038759997114539, 0.06741954479366541, 0.07099930556224925, 0.009761028191340821, 0.06369446218013763, 0.030414752063474486, 0.02928782414112772, 0.05081081583297678, 0.05718148273548909, 0.06295616858239685, 0.08756055403500795, 0.016918527694152932, 0.01346014835871756, 0.06410693683262382, 0.04519361796389733, 0.027179765115891184, 0.039316568324076276, 0.027533836562984755, 0.027874671488202045, 0.04696021441902433, 0.046320763017450056, 0.016648542002907822, 0.03260536505175488, 0.016721830570272038, 0.018054140864738395, 0.0908745394221374, 0.04678455866607172, 0.03966510462175522, 0.029540636111050844, 0.0885043487484966, 0.05316040279077632, 0.04086646444297262, 0.022246639111212323, 0.04936482038881097, 0.050558237957635095, 0.06293984981519835, 0.02488832691285227, 0.01800118459920798, 0.05985961974199329, 0.09972380314554487, 0.06155071221292019, 0.015856425311150293, 0.06831529244248356, 0.03319749542112861, 0.03438816153045211, 0.050146821819778, 0.10868724395654031, 0.06576406184051718, 0.04360957117751241, 0.021385722361238937, 0.007472980118888829, 0.05419764873970832, 0.0957957978493401, 0.06005342969936984, 0.10409653386367218, 0.04139285155438951, 0.025742127526817576, 0.10097578167915344, 0.012308664254045911, 0.22868679304208073, 2.645570691142763, 4.644866415432521, 3.9190962399755205, 1.7310376103435243, 5.872984835079738, 13.352750148091998, 14.492307697023664, 16.650472027914866, 21.242972476141794, 24.890592609133037, 20.354838098798478, 13.198178785187856, 4.725023874214717, 8.501168744904653, 11.638911826269966, 4.108513687338148, 4.78344953911645, 3.9449391961097717, 2.999802666051047, 0.2604093365371227, 0.02920075792020985, 0.11508434319070407, 0.10424270387738943, 0.06066442334226199, 0.037506606695907455, 0.028270367666014602, 0.06372642796486616, 0.02482757088728249, 0.07400326829935823, 0.05543623299204877, 0.10762363352945872, 0.03196857011477862, 0.030563286771731715, 0.02653125866449305, 0.011441920584599887, 0.05264680267178586, 0.04791783428351794, 0.008967656209798796, 0.028365610233907188, 0.013921567438436406, 0.07954833789595536, 0.08907871507108212, 0.019192736196730818, 0.03617448639124632, 0.03151760217068451, 0.08043253009340592, 0.026318872114643455, 0.13074179658932344, 0.07717465276696853, 0.07745504379272461, 0.01374914066400379, 0.06526596285402775, 0.04776047522734318, 0.037691755153770955, 0.0983157886990479, 0.054119620605238845, 0.05604537423434002, 0.027182107758043066, 0.035503191341246874, 0.023604204479072775, 0.041173912052597315, 0.08644216547587089, 0.034804089926183224, 0.049814370194716115, 0.03768688666501215, 0.03253430547192693, 0.0837358014125909, 0.02188823352168713, 0.04892975052020379, 0.020151171999584352, 0.024841871012800505, 0.09173271658697299, 0.04288394582856979, 0.037692372620637925, 0.06330051831901073, 0.02588016869101141, 0.04107340066028493, 0.03442998303632651, 0.015777983270319443, 0.013152446298460876, 0.03049858845770359, 0.04638721873717649, 0.05490037353177156, 0.05832610345844712, 0.022358103755063245, 0.0010730489552120811, 0.009273838351613708, 0.014659077328230654, 0.07988090147929532, 0.013350027214203562, 0.031518141606024334, 0.04072324266391141, 0.04477711281340037, 0.08691042927759034, 0.12845905550888606, 0.21088496542402677, 0.13251005884792122, 0.1801941751369408, 0.11604312674275466, 0.09883039644254105, 0.3189224238906588, 0.22487136349081993, 0.10716909649116652, 0.16643815327967915, 0.11048556531646422, 0.16539417287068708, 0.077810182236135, 0.16416616019393715, 0.16768017091921397, 0.1365735743727003, 0.186361841325249, 0.16206230808581623, 0.19635956627982004, 0.1575470646577222, 0.3463097800101553, 0.1952331302953618, 0.1767770049295255, 0.12588820845953055, 0.24510858899780683, 0.12284367611365658, 0.14418623516602175, 0.12382916680404119, 0.14222807809710503, 0.12416117398866586, 0.16139891796878406, 0.23060430586338043, 0.17230646338846, 0.09957053565553256, 0.16484937710421427, 0.24595143805657113, 0.12274127160864216, 0.1266767340047019, 0.19040510936507157, 0.11364149954169989, 0.16046017834118434, 0.12905185084257806, 0.16298218443989754, 0.21961734470512184, 0.1430607084184885, 0.1601469394351755, 0.19654283858835697, 0.12868164213640348, 0.1588332142148699, 0.20492095473621572, 0.12719015431191238, 0.2773047499358654, 0.12818089686334133, 0.22772283905318805, 0.21154299511441163, 0.14071438860680374, 0.22778746272836412, 0.1349731816777161, 0.11987845094076224, 0.23388171142765454, 0.10940748173743486, 0.2236375425543104, 0.2516878545284271, 0.10748230825577464, 0.22984222961323603, 0.06942410008715731, 0.2633797185761588, 0.1926210554582732, 0.23429187227572712, 0.14172132100377763, 0.1399059955562864, 0.17131554441792624, 0.11602575624627726, 0.11450682846563202, 0.22244353805269512, 0.20061902914728436, 0.3008724424455847, 0.10362397493528468, 0.1787887934063162, 0.20715537055262498, 0.14396505989134312, 0.3275925543691431, 3.9725205046789984, 4.322097837924957, 13.364109584263392, 25.61000040599278, 47.05377408436367, 47.77368041447231, 50.833705289023264, 33.77684007372175, 30.918101038251603, 33.17354883466448, 34.54774618148804, 38.29036208561489, 21.03700007711138, 23.27742760522025, 46.68732956477574, 18.334022283554077, 17.840411833354406, 18.182985816683086, 4.6086728147097995, 0.4883269965648651, 0.13948079837220057, 0.21730841217296465, 0.2021334514554058, 0.3061117370213781, 0.2382839380630425, 0.1363986480448927, 0.18189499101468495, 0.1333424856087991, 0.18622465511517866, 0.22713054583540984, 0.17496585925774916, 0.1527926783476557, 0.1102104057957019, 0.18836206756532192, 0.09539377942149128, 0.16228129847773484, 0.1983596703835896, 0.21991044469177723, 0.20128419702606543, 0.1159777431083577, 0.23466533794999123, 0.20741142252726213, 0.09428385219403676, 0.1298499030194112, 0.15418729851288454, 0.15882938727736473, 0.1247335589889969, 0.2599286623299122, 0.2306893127305167, 0.14949494387422288, 0.09741917252540588, 0.20598146425826208, 0.1496550374265228, 0.1167973591280835, 0.21768479554780892, 0.12547719265733445, 0.09608545087810073, 0.1494622113449233, 0.164702514984778, 0.17084397615066596, 0.11136218506310668, 0.1264418658933469, 0.16681908283914837, 0.11396337619849614, 0.22874889256698744, 0.22128891572356224, 0.1789101833211524, 0.13852418613220963, 0.12701624578663281, 0.16079603960471495, 0.18444321570651873, 0.17424262235207216, 0.1261786485889128, 0.14034886179225786, 0.08262915829462664, 0.14327232992010458, 0.23909413601670945, 0.20898831076920033, 0.1350920203008822, 0.09945057744958571, 0.08105444136474814, 0.12666483250047478, 0.183749970048666, 0.23223881529910223, 0.08685797173529863, 0.10608086202825819, 0.14363500688757214, 0.058249598635094504, 0.1923998530421938, 0.12592719708170208, 0.17077449416475637, 0.1344217091266598, 0.1473837907293013, 0.2144074985491378], [0.010679639925781106, 0.042301379410283904, 0.008275768470152147, 0.031989628449082375, 0.03675192647746631, 0.02727733166622264, 0.04053829098120332, 0.06660958432725497, 0.020667537148775797, 0.01933401058028851, 0.03894940624013543, 0.06693019212356635, 0.04602607525885105, 0.03926765273458191, 0.08495070479278054, 0.02854269091039896, 0.04306177289358207, 0.039740462720926316, 0.04952527017199567, 0.047958258007253916, 0.0563063388025122, 0.058894152620009015, 0.032189613075128624, 0.031755672967327495, 0.03841268843305962, 0.05838243543569531, 0.06092654141996588, 0.0311737647280097, 0.08548221484358821, 0.03068206432674612, 0.05217916990763374, 0.01836541710820581, 0.010090696126488703, 0.08412536193749734, 0.04378338470788939, 0.014727968988674027, 0.017632404209247658, 0.0679843844845891, 0.016297249156715612, 0.032496433039861064, 0.019831917880635177, 0.08519519453069993, 0.05326837806829384, 0.03771694576633828, 0.04311712099505322, 0.04669617269454258, 0.01725970527955464, 0.0557639450500054, 0.03712213518364089, 0.08086316234299115, 0.05650963467944946, 0.03703913338748472, 0.03563293402216264, 0.03359540531943951, 0.010891152013625418, 0.08422592761261122, 0.042539847149912796, 0.02954558263133679, 0.05592061200046113, 0.06842695895050253, 0.035414703589464934, 0.04748973296955228, 0.07206739432045392, 0.06893506632851702, 0.03594218992761203, 0.013583785072634262, 0.032726096787623, 0.019753385933914354, 0.051223982591181993, 0.05317432972203408, 0.05151171536583986, 0.03078361727031214, 0.038966250871973376, 0.03147089860535093, 0.0022936455622714546, 0.045934076088347604, 0.06022220171455826, 0.0661606112761157, 0.02970519781644855, 0.030518890225461552, 0.013243546410064613, 0.10239140250320945, 0.03562280688700931, 1.0234061415706361, 1.59098396556718, 3.026422300509044, 2.906901559659413, 1.457495282803263, 4.422111076968057, 6.781877824238368, 16.283367429460796, 15.174725021634783, 10.94349615914481, 1.6992529673235757, 1.8279915792601449, 2.4241009865488325, 3.2733185035841803, 1.5472945613520486, 2.3530161380767822, 0.4654300223503794, 0.1075573270874364, 0.05409503388883812, 0.05997652454035623, 0.0774093105324677, 0.031231033083583628, 0.05550649529322982, 0.08230088305260454, 0.11115338626716818, 0.05241985645677362, 0.03878135686474187, 0.040585537374551804, 0.06023022199847868, 0.04015502386859485, 0.044181538878807, 0.055127207788505724, 0.05449291325307318, 0.06997946742922068, 0.00994689080731145, 0.03781170318169253, 0.14358233899942466, 0.06976828019001655, 0.012133799842558801, 0.020300617641104118, 0.01558316229576511, 0.048155623488128185, 0.006095960303874952, 0.029084881102400165, 0.012201275061150747, 0.02113052025171263, 0.0493517043069005, 0.026164892162861567, 0.03780108071597559, 0.04279334783287985, 0.021114454238808582, 0.023287630573447262, 0.051219738354640346, 0.024654334111671363, 0.03777930652722716, 0.048261746365044794, 0.1447554174810648, 0.03511581909177559, 0.018373985309153795, 0.025591670868120024, 0.01982040483770626, 0.012274786696902342, 0.060840788164309094, 0.021452537704525248, 0.032757126194025786, 0.028383896752659763, 0.03909790023629155, 0.030205848094608103, 0.04556532623246312, 0.05387161605592285, 0.00349234913093304, 0.04864318482577801, 0.0118797478498891, 0.02439065879609968, 0.029926135603870665, 0.0488128728632416, 0.029006649407425096, 0.015954382019117475, 0.06197681863393102, 0.03942560550889798, 0.033512552800987444, 0.02064479944030089, 0.038029054911541085, 0.07942563162318297, 0.025391133236033574, 0.03283160559034773, 0.058919909809316905, 0.021394494122692516, 0.06812915671616793, 0.12840995671493666, 0.004792732444392251, 0.09266105427273683, 0.017116553050332835, 0.01791028126275965, 0.03347690935645785, 0.03978909332571285, 0.047437119364206276, 0.100003468138831, 0.05375340847032411, 0.05935215697224651, 0.027639123145490885, 0.011483275597648961, 0.02312139288655349, 0.0285312236685838, 0.011763319722376764, 0.029686493998659507, 0.03126260531800134, 0.014906006399542093, 0.026625973671408634, 0.047941644077322314, 0.06070126100842442, 0.06343647638069731, 0.009734378728483404, 0.06474331447056361, 0.05682729084842971, 0.020901731814124754, 0.03987280419096351, 0.06538322049060039, 0.059689748500074656, 0.01555933553858527, 0.0026458497658105834, 0.06672459601291589, 0.04305238536159907, 0.03337079326489142, 0.02846758047650967, 0.0039804208541422016, 0.07271108656589474, 0.034018017285104306, 0.058243410395724435, 0.06726099151585783, 0.08135187040482249, 0.037445396051875184, 0.043242320884019136, 0.011656254529953003, 0.044501203511442454, 0.011963092306229686, 0.017662320818219866, 0.025175009654568772, 0.038913884931909185, 0.0732836751267314, 0.03356278135574289, 0.02627644671260246, 0.029664356793676103, 0.05097465829125472, 0.008319814722718937, 0.007573796003790838, 0.021374026113854985, 0.018940752039530447, 0.030459888212914978, 0.08830544977848019, 0.019532860356516073, 0.021211925794237425, 0.052997371181845665, 0.037821867636271884, 0.0468990309163928, 0.05538226570934057, 0.03329018669735108, 0.07745764936719622, 0.03981700147102986, 0.013452768442220986, 0.044585745582090955, 0.06844618184758083, 0.08075948219214167, 0.06487404781260661, 0.10212767629751138, 0.08506525507462875, 0.021136359045548097, 0.01849661355039903, 0.04285543378708618, 0.033881306049547026, 0.06171653938612767, 0.07128856504069907, 0.043989180986370356, 0.04601655201986432, 0.018860983462738137, 0.04805749375373125, 1.596908716218812, 1.5533858516386576, 3.2168669956071034, 4.1852704371724805, 2.649095816271646, 10.562071323394775, 19.71085126059396, 19.9002400466374, 17.91353120122637, 15.28993831362043, 9.709685427801949, 7.570040651730128, 12.228562882968358, 7.863516058240618, 7.808114596775599, 5.5899777582713535, 1.4196814490216119, 0.030618132757289068, 0.12209747758294855, 0.10476439552647726, 0.025871415589270846, 0.08302379426147256, 0.03295042385746326, 0.05903937268470015, 0.039981824412409744, 0.11391776507454258, 0.029227197037211487, 0.0884679996275476, 0.05580139000500951, 0.05290445938174214, 0.08027375968439238, 0.05250497528218797, 0.02511343260162643, 0.05010580777057579, 0.03483214395652924, 0.04461445100605488, 0.05965928227773734, 0.06120833022786038, 0.018146072181739976, 0.04721802719203489, 0.08788118897272007, 0.026401500716539364, 0.07642244241599526, 0.05604001720036779, 0.01249686103048069, 0.0386526218083288, 0.037232054463986836, 0.031214799133262465, 0.021282944661964263, 0.04154679418674537, 0.05873287163142647, 0.0688629923388362, 0.07534197039370026, 0.024765506985464265, 0.013548555534466036, 0.029653422201850584, 0.05514340102672577, 0.03037491866520473, 0.024159386920343553, 0.07545392188642706, 0.07257979682513646, 0.0319560782850853, 0.025733432100553597, 0.03633531954671655, 0.0413515898399055, 0.02168788418306836, 0.051079919428697655, 0.03004740338240351, 0.09245967186455216, 0.03632810671946832, 0.07358098203050238, 0.045144190080463886, 0.028235373918765357, 0.029694863728114536, 0.021267200953194072, 0.06192202014582498, 0.02132320892997086, 0.008445353879194175, 0.03289710118302277, 0.04429191277761545, 0.029597470204212835, 0.03727752309558647, 0.08720632482852254, 0.030472810912345136, 0.03947884675913623, 0.06826086036328759, 0.02932008508858936, 0.0345340601301619, 0.03155625152534672, 0.06204921153507062, 0.03148578566366008, 0.04434148993875299, 0.03761315365721073, 0.2867647223174572, 0.21359142448220933, 0.24628462589212827, 0.17427848971315793, 0.36746568764959064, 0.32710444341812817, 0.27762702692832264, 0.30297557530658586, 0.0884006821683475, 0.10018140037677117, 0.18182966166308948, 0.19684872217476368, 0.1166712466095175, 0.10668460213180099, 0.2234454085784299, 0.1016693055363638, 0.09340131562203169, 0.22260326519608498, 0.16159559812928947, 0.10778746580971138, 0.16267699295920984, 0.23006826319864818, 0.08156825522226946, 0.18062484131327697, 0.1397575456649065, 0.12867514177092484, 0.264653953058379, 0.07357049187911407, 0.1848160842699664, 0.1361519055707114, 0.27584304979869295, 0.10454139499259846, 0.20098321246249334, 0.15550379215606622, 0.13929682038724422, 0.169354021815317, 0.16998265736869403, 0.2067682527537857, 0.1407869104295969, 0.12182549360607352, 0.11764156525688511, 0.26901978307536667, 0.3182725230497973, 0.16444801006998333, 0.11269846478743212, 0.1743639037013054, 0.12835278335426534, 0.149441678875259, 0.11087959060179335, 0.2477606838302953, 0.17844829096325807, 0.22246446407267026, 0.10061239224991628, 0.1069870726870639, 0.10106795387608664, 0.10094782603638512, 0.17738282813557557, 0.1882317481296403, 0.1497750295592206, 0.16016988748950617, 0.13515554474932806, 0.14523735376341002, 0.1516955415053027, 0.15293929619448526, 0.18570896850100585, 0.20703957176634244, 0.12618776809956345, 0.12160138706011431, 0.14564155707401888, 0.20031154421823366, 0.363096220684903, 0.18210093996354512, 0.1797952643994774, 0.10198321619204112, 0.09564357530325651, 0.21122701492692741, 0.21249352768063545, 0.21964027918875217, 0.23529154434800148, 0.08091254612164837, 0.21539624620761189, 0.16161155727292809, 0.14740330539643764, 1.9149791172572543, 3.9124828577041626, 22.956587587084087, 28.266015325273784, 51.088054520743235, 51.28366020747593, 57.80360310418265, 51.76941571916853, 56.57941736493792, 47.03617777143206, 26.042345115116664, 29.836294310433523, 45.81503186907087, 25.02440275464739, 14.786348513194493, 22.34450340270996, 4.052872513021741, 0.64997591397592, 0.12685708861265863, 0.19702444917389325, 0.3182714373937675, 0.22110170791191713, 0.16151397036654608, 0.2480301707983017, 0.1918479326580252, 0.1974834781140089, 0.09953210343207632, 0.2231483052351645, 0.22577929762857302, 0.17674520877855165, 0.18758472427725792, 0.3045987124953951, 0.14258821734360286, 0.22995315651808465, 0.09963496934090342, 0.14582788279013975, 0.27567784009235247, 0.33867457828351427, 0.1187281169529472, 0.1923515142074653, 0.16603351570665836, 0.15403563236551626, 0.14543129264244012, 0.14994011712925776, 0.1481781109635319, 0.106292510671275, 0.12302493995853833, 0.12501729519239493, 0.10931658518633672, 0.2173873529370342, 0.12587550628398145, 0.1432677023112774, 0.31359909953815596, 0.09917320590466261, 0.15576938433306559, 0.13838693206863745, 0.32373747123139246, 0.2074677273631096, 0.13470050559512206, 0.15265079667525633, 0.17140686166073593, 0.10969725011714868, 0.1978870571724006, 0.07990915567747184, 0.20587220654955932, 0.12247137751962457, 0.14533392286726407, 0.12188824452459812, 0.15086676526282514, 0.25238487284098354, 0.1753639964652913, 0.12004119077963488, 0.04905898769253066, 0.15044084883161954, 0.12305702109422002, 0.13408630926694187, 0.20129641065640108, 0.21772348561457225, 0.1519853166703667, 0.1291616785206965, 0.11585173915539469, 0.08528634892510516, 0.13639764381306513, 0.21223728571619305, 0.19492279551923275, 0.21449572167226247, 0.10837042917098318, 0.08350534377885716, 0.12841432648045675, 0.27263661899736946, 0.11252775216209036, 0.1594869555639369, 0.11487018396811825], [0.1009561245196632, 0.08854763249733619, 0.03078509647665279, 0.05509792900245104, 0.051276199253542085, 0.036937855250601254, 0.0496387653318899, 0.023870651610195637, 0.03605826012790203, 0.04105748562142253, 0.009354483086748846, 0.06804452982864209, 0.0413271897206349, 0.046044226070599895, 0.022921737349991287, 0.020127051776008945, 0.04893791329647813, 0.03249558826376285, 0.03427950432524085, 0.07733433241290705, 0.018169508781284094, 0.06267559435218573, 0.016390900559989468, 0.03503155182780964, 0.044398707404200516, 0.03555847158921616, 0.02874101312564952, 0.04969517534066524, 0.04409955149250371, 0.031044357921928167, 0.025501571595668793, 0.06875191615628344, 0.050147195014038255, 0.05209506209939718, 0.03118423791602254, 0.04928395597796355, 0.06236221295382295, 0.059249243565968106, 0.021240302128717303, 0.021921639496992742, 0.06791690417698451, 0.02265967525142644, 0.04118081953908716, 0.008783283826362873, 0.025391494555931007, 0.016299780092335174, 0.027822154574096203, 0.05905697388308389, 0.027186141648728932, 0.022201993203322803, 0.04099573554205043, 0.019210386588903408, 0.04788037236513836, 0.02321284244369183, 0.06269877310842276, 0.016226539022422264, 0.023346970157165612, 0.010785052037265683, 0.015059638602126921, 0.003912295514185513, 0.046387812455317805, 0.05205828889406153, 0.06529942820114748, 0.025499369749533277, 0.05373642473880734, 0.019006876973435283, 0.05418626631477049, 0.03453634340049965, 0.061743076890707016, 0.046274242656571526, 0.03496685351378151, 0.01429927904557969, 0.0467134821228683, 0.04076237038576177, 0.015923349220039587, 0.06737221019076449, 0.027322415229199187, 0.04731666922037091, 0.1185475452137845, 0.004550003504846245, 0.08220442929970366, 0.05072681319766811, 0.1288316933704274, 0.04766173481142946, 0.5146257653832436, 0.5119622168796403, 1.1423912197351456, 0.963409423828125, 3.590753687279565, 2.7821379687104906, 5.634561308792659, 3.6801181605884006, 2.4703792461327145, 0.7410788482853344, 3.9620699797357832, 2.4027930327824185, 2.4005237945488522, 3.304669644151415, 1.7015199256794793, 0.1869299922670637, 0.07025451838438, 0.11180207931569644, 0.05888734691377197, 0.08312767118747745, 0.005023069214075804, 0.04692370244967086, 0.07702926306852273, 0.025724456778594425, 0.039142982102930546, 0.05819857958704233, 0.058749726441289694, 0.0623702739498445, 0.028748758602887392, 0.043549313875181336, 0.05154636814924223, 0.06520523396985871, 0.05007510406098195, 0.027148884987192493, 0.04254031194640057, 0.04920192448688405, 0.0437743398360908, 0.013630056920062219, 0.03619781103251236, 0.00872588824547295, 0.019434798475621, 0.01970217011070677, 0.04078227860320892, 0.04608760481434209, 0.03516549124781575, 0.05252777745148965, 0.03134381238903318, 0.02819555239485843, 0.06596748663910798, 0.027679012522899678, 0.10645081967647586, 0.07014196978083678, 0.02230755119983639, 0.014247757881613714, 0.05370123591274023, 0.02096257944192205, 0.04585548476981265, 0.026104131048279147, 0.061557606128709655, 0.04982479588527765, 0.013677305857917028, 0.08043165478323187, 0.02079388376192323, 0.029895150302244083, 0.013535001797468534, 0.01901408301533333, 0.0602980890710439, 0.05269611859694123, 0.050821848812380006, 0.05873419477471283, 0.07088029051997832, 0.0495914748337652, 0.021416833191843967, 0.05230229687211769, 0.03779998827459557, 0.03711199447778719, 0.02922596888882773, 0.03964161713208471, 0.006361577925937516, 0.052434163367641826, 0.01720374819290425, 0.01835734423782144, 0.0792082900713597, 0.053871541417070797, 0.016497252442474877, 0.024792030919343233, 0.012737723150556641, 0.026862931670621037, 0.01817598539803709, 0.015074970100873282, 0.06730585625129086, 0.008557629372392381, 0.08549977532987084, 0.04530841591102736, 0.00959260731802455, 0.0441026693609144, 0.06023438820349319, 0.04969409307731049, 0.015412200308804, 0.019949046595554267, 0.04000599043709891, 0.03394138693277325, 0.04476411886779325, 0.06833917687513999, 0.018607837314318334, 0.057141082760478766, 0.019498662191576192, 0.018203579720907977, 0.036058809741267135, 0.015969618522961224, 0.027025293226220777, 0.017255294801933423, 0.008354478532315364, 0.019948123787928904, 0.031852031725325754, 0.01373671244696847, 0.04823491709040744, 0.021861222738932286, 0.05329377902671695, 0.02277275820129684, 0.05045608451057758, 0.029592594930103848, 0.021389247350660816, 0.035753404522048574, 0.058059459552168846, 0.0668189666633095, 0.026522534400490776, 0.0243897936639509, 0.007472035258875361, 0.019702621336494173, 0.046902606795941076, 0.04159324669412204, 0.03543340740725398, 0.031088622153869698, 0.01835155294143728, 0.013702950240778071, 0.06002177604074989, 0.04014749212988785, 0.022655802512807504, 0.07326185344053165, 0.08999840822070837, 0.044316055053578954, 0.0445778406491237, 0.02164250715369625, 0.09639634883829526, 0.08418330882808991, 0.022064752710450972, 0.016402233791138445, 0.014795968375567878, 0.04335257264652422, 0.021924394349168454, 0.05095611732187016, 0.03977257778335895, 0.07379672902503184, 0.07863997628114053, 0.009408574202097952, 0.11348421512437717, 0.029298582313848392, 0.10364252608269453, 0.1012410210179431, 0.0053891460660712, 0.02875023102387786, 0.013005379770350243, 0.028722445014864206, 0.04615947185084224, 0.06471196615270206, 0.07400829624384642, 0.05768072844616004, 0.021234314057177732, 0.010127895960717328, 0.02858372192297663, 0.032390791922807693, 0.04569704345028315, 0.05360793734767607, 0.06000359130225011, 0.028564047800110917, 0.46148453120674404, 1.2359173383031572, 3.0770992040634155, 10.43054974079132, 4.294774915490832, 8.309948240007673, 9.52504747254508, 12.414906620979309, 4.974044706140246, 3.9548117177827016, 7.861581853457859, 6.617143852370126, 8.703033890042986, 7.734980463981628, 0.766150771507195, 0.12401722956980978, 0.05400523995714528, 0.06636920651154858, 0.037949886838240285, 0.033038881075169356, 0.053798972096826346, 0.06818237421768052, 0.0366888770035335, 0.03386020361046706, 0.017417707247659564, 0.06679988625858511, 0.08214509141232286, 0.062356065426553996, 0.05656888096460274, 0.0401164423674345, 0.028709311969578266, 0.06183894710349185, 0.022301081368433576, 0.012515437622953738, 0.04524959371026073, 0.03367384736027036, 0.019780213512214165, 0.006874021142721176, 0.03084747420091714, 0.07531911054892199, 0.07330563930528504, 0.04469452831628067, 0.029693275956170898, 0.024135188665241003, 0.04349278512277773, 0.025425976009241173, 0.06405379396996327, 0.023581526142411997, 0.020726345778842057, 0.03793603115315948, 0.026047402128045048, 0.08707256522029638, 0.0779519078454801, 0.011924451433255203, 0.03443560469895601, 0.005650216231255659, 0.05460769084415265, 0.019046710371705036, 0.05556984332257083, 0.03747414558061531, 0.011931934826342123, 0.05021729785948992, 0.06487381711070027, 0.02424703668137746, 0.01863702280180795, 0.05053562577813864, 0.059618692312921794, 0.02955644597698535, 0.10028865640716893, 0.05161285440304449, 0.0433824078312942, 0.03428749068241034, 0.02957505140719669, 0.05676455350060548, 0.003703998410076435, 0.02920904283278755, 0.020385683880054524, 0.014804251591808029, 0.04599881172180176, 0.03979734431153961, 0.019012084729703407, 0.021712087527183548, 0.03852401567356927, 0.07139039957629782, 0.03034734639472195, 0.07753186074218579, 0.06374938280454703, 0.038542821271611113, 0.06352080471281495, 0.026664302418274537, 0.14302106840269907, 0.012910595213595246, 0.2304282667381423, 0.333050581493548, 0.22143041741635117, 0.1764286993337529, 0.12366284430027008, 0.15145151317119598, 0.11763828114739486, 0.10955970428351845, 0.14094380129660877, 0.10621994135103055, 0.19051250788782323, 0.1512329163295882, 0.1062603752527918, 0.2020796843405281, 0.11773539307926383, 0.08582834912730114, 0.11073315595941884, 0.07483184776668038, 0.13793935679963656, 0.19071872825069086, 0.08891803119331598, 0.14577967966241495, 0.1299108626054866, 0.11289129086903163, 0.13216891858194554, 0.15235328621097974, 0.16296592674085073, 0.1979502694947379, 0.12068721040018968, 0.15816979695643696, 0.2086790616491011, 0.1828468127974442, 0.2151626401713916, 0.1480546718729394, 0.17108777378286633, 0.11622406489082746, 0.1534280992512192, 0.15634593553841114, 0.09558245286877666, 0.1715424329574619, 0.229196020002876, 0.08770227285900287, 0.10645352703120027, 0.08005827731852021, 0.14871473716838018, 0.08997882570007018, 0.07757836753236395, 0.26466353397284237, 0.22917189129761287, 0.11131083353289536, 0.1538058261254004, 0.15859480415071758, 0.20483726422701562, 0.205785815470985, 0.14436957532806055, 0.11555300732808453, 0.11352249128477913, 0.14610290660389832, 0.1193140862243516, 0.155171255714127, 0.14331627184791224, 0.2117965772215809, 0.1893386830176626, 0.11264148820191622, 0.2593611084989139, 0.12995629731033528, 0.248544201787029, 0.18561929331294127, 0.27605136004941805, 0.18404845760336944, 0.2068115704293762, 0.11179216591907398, 0.12663315848580428, 0.14103068092039653, 0.15556861939174788, 0.22507716316197598, 0.1332034402127777, 0.18872968426772527, 0.22052462744925702, 0.21623753463583334, 0.2701408586331776, 0.1807024385780096, 0.31372481850641115, 0.11501055929277625, 1.1355110917772566, 8.685189179011754, 32.46315458842686, 31.32577269417899, 44.461543628147666, 58.73876462663923, 62.73413167681013, 58.04614387239729, 47.180384159088135, 41.8410826410566, 35.943632330213276, 24.3577595778874, 22.612821987697057, 26.173806769507273, 5.290048343794687, 0.6630674600601196, 0.15342657933277742, 0.3328647171812398, 0.2864224692540509, 0.2530907392501831, 0.13251873052545957, 0.1762106181787593, 0.21382690327508108, 0.17473184610051767, 0.11813901284975664, 0.2845009666468416, 0.21808495478970663, 0.24771204644015857, 0.1851092113980225, 0.18274406902492046, 0.18458322462226662, 0.16771787032485008, 0.20699930749833584, 0.19373001238065107, 0.19793262758425303, 0.12741412515086786, 0.11121086496859789, 0.11804602641080107, 0.11328076318438564, 0.16434009586061749, 0.13835405026163372, 0.13468385434576444, 0.09910417853721551, 0.2512059860995838, 0.09369531806026186, 0.10032947707389082, 0.20747171714901924, 0.13117371127009392, 0.15678019795034612, 0.11580737653587546, 0.2276841082743236, 0.177371564454266, 0.08997609120394502, 0.07464757122631584, 0.10202209624860968, 0.1106027483141848, 0.16266388366264956, 0.08882962486573628, 0.1925207001290151, 0.1317929151867117, 0.11871835961937904, 0.2305493445268699, 0.11133622431329318, 0.09732969411249671, 0.11089049465954304, 0.13524672628513404, 0.24966223750795635, 0.12496500728385788, 0.22440356787826332, 0.19257145454841001, 0.2000358011573553, 0.14438045902975968, 0.10949317392493997, 0.2258610882397209, 0.12938376303230012, 0.10375729349574872, 0.1339728853532246, 0.09527199595634427, 0.11151600895183426, 0.15329714199262007, 0.14123274864895002, 0.12391767491187368, 0.26997350475617815, 0.14003319373088224, 0.109081798499184, 0.26866105518170763, 0.15861655798341545, 0.10681183423314776, 0.22882996393101557, 0.14775100031069346, 0.3146605182971273, 0.17313871373023304], [0.03193396822150264, 0.03631657501682639, 0.023585380221317922, 0.03313912105347429, 0.03934516518243721, 0.07248214206525258, 0.06773443253976957, 0.04119206964969635, 0.0225833112240902, 0.020386530352490287, 0.009955662568765027, 0.06492406262883119, 0.043494084517338445, 0.030325039555983882, 0.03792454355529376, 0.0024520601644845946, 0.020262299072263495, 0.011095846520869859, 0.01252717203793249, 0.0276857045745211, 0.05939756453569446, 0.10754621946918112, 0.07666753605008125, 0.04038444334375007, 0.06258404640746967, 0.026564259215125015, 0.0354982075015349, 0.037196980988872905, 0.028852184303104877, 0.012339768299300755, 0.02293403070819165, 0.03065158792638353, 0.03454816008784941, 0.0656199206465057, 0.03090193002883877, 0.03779634454154542, 0.026633303545947586, 0.04196367592417768, 0.05910946535212653, 0.056464071052947214, 0.025626461054863672, 0.01271976317678179, 0.017605943039857914, 0.04599842495684113, 0.03079760866239667, 0.049562392822865925, 0.021951764755483185, 0.0029795780969184955, 0.030022976121732166, 0.03146586387551256, 0.042702997502471716, 0.03139017329418233, 0.03092027422306793, 0.00225278121485774, 0.013881002918684056, 0.06843031091349465, 0.009524693596176803, 0.013268701399543455, 0.05195047985762358, 0.013579140500431615, 0.06251542616103377, 0.05685769260994025, 0.07347297961158411, 0.004325283308779555, 0.023238124658486674, 0.05524350190535188, 0.0954417654180101, 0.04132386829171862, 0.06441910365330321, 0.054623660165816545, 0.017157765571027994, 0.07193065594349589, 0.07239167299121618, 0.04476652088175927, 0.0558584785488035, 0.008033052253137742, 0.05040504849914994, 0.07659016270190477, 0.06177612154611519, 0.048700090165116956, 0.046179050978805335, 0.04450261486428125, 0.028749589808285236, 0.01186771148682705, 0.1122254648112825, 0.08329758992684738, 1.8266488398824419, 4.7676549809319635, 3.6912543858800615, 2.24549754176821, 0.9673880274806703, 0.8449092539293426, 2.581368250506265, 2.1469749084540775, 2.7950692176818848, 1.6340195877211434, 2.5762472110135213, 1.3047785460948944, 0.04210849226053272, 0.04826026715870414, 0.06446001252957753, 0.045955436370734654, 0.10236827124442373, 0.04950079880654812, 0.09175508788653783, 0.02079654870820897, 0.06773433075951678, 0.06869562489113637, 0.06174656456070287, 0.05079399834253958, 0.07727278250136546, 0.02592697742927287, 0.060457619439278326, 0.07853284917239632, 0.020134651368217807, 0.007650774953487728, 0.03049789635198457, 0.0348209175946457, 0.0640507744891303, 0.035166790642376454, 0.018671309176300253, 0.04308547412178346, 0.013825502146833708, 0.020566574530676007, 0.023349051563335315, 0.004565366809921605, 0.06949092221579381, 0.01796192117035389, 0.02618604040305529, 0.019958635991705314, 0.017092901015920297, 0.03270591037081821, 0.02382622452984963, 0.05114986281841993, 0.05583554067249809, 0.02474201949579375, 0.035584795355264626, 0.036746406595089605, 0.04307000691603337, 0.018057888074378883, 0.01476643344254366, 0.020628158368968537, 0.05157834071932094, 0.032391317787447145, 0.09668163888688598, 0.0348307597450912, 0.016104989651856676, 0.05984959777976785, 0.057046888529189994, 0.05887637500252042, 0.05600694201088377, 0.035472290856497626, 0.03378986327775887, 0.06480070496244089, 0.08020874924425568, 0.06442183136407818, 0.03977814516318696, 0.0647962809141193, 0.03732393149818693, 0.036711892911366055, 0.01576889768641974, 0.05097074992954731, 0.03945804287546447, 0.015282237104007175, 0.07461285737476178, 0.04802110392068114, 0.019814354001677463, 0.029814306247447218, 0.019639134207474332, 0.05011096802939262, 0.022947810058082854, 0.03039667589057769, 0.024601286243913428, 0.033709473841424496, 0.02992458175867796, 0.06450587471148797, 0.009430787742270954, 0.017623769851135354, 0.07070346429411854, 0.03792490657152874, 0.038929284284157414, 0.005809691044435437, 0.08626086091888802, 0.016051303961181214, 0.042855515211288414, 0.015006315927686436, 0.01919654617086053, 0.05073456546025617, 0.05053787851440055, 0.025553644069337418, 0.04183467963178243, 0.023053552955389023, 0.02850107296503016, 0.07029756464596305, 0.02395284764601716, 0.04274150775745511, 0.028232627548277378, 0.08262600310678993, 0.06424757678593908, 0.025293005197974186, 0.04038846027106047, 0.03372546012646385, 0.013841072829174144, 0.02238899066911212, 0.10269076536808695, 0.01663429446385375, 0.03829797191013183, 0.03671224574957575, 0.025526168490094796, 0.08254797836499554, 0.07878438210380928, 0.041952354567391534, 0.03139110627983298, 0.029341089140091623, 0.008212459456574703, 0.019035349999155318, 0.019822199562830583, 0.03048872934388263, 0.034009189544511695, 0.052628231168325455, 0.05865176634064742, 0.023442745375047837, 0.011212700429106397, 0.024290858169219325, 0.011599865725396999, 0.016951255134439895, 0.044282443821430206, 0.03863788742039885, 0.0347138379833528, 0.001572921356585409, 0.1302936649216073, 0.07420107482799462, 0.015474170912057161, 0.02653054959539856, 0.08230508318436996, 0.035957507855658016, 0.003871967633520918, 0.03552313009276986, 0.08848473230110747, 0.02293385937809944, 0.007965873893616455, 0.005661921808496118, 0.02593455496909363, 0.0551826915969806, 0.006027970246837607, 0.03267934911751321, 0.03422625968232751, 0.02328735407042716, 0.03664403262415102, 0.053208490567547936, 0.01080687711614051, 0.05181233012782676, 0.050768281865332804, 0.06823884190193244, 0.053553807216563394, 0.08016396593302488, 0.1272795716566699, 0.04682649552289929, 0.07566673760967595, 0.021523807630208985, 0.13609067457062857, 0.007483841768199844, 0.5860584580472538, 4.364457096372332, 7.952136857169015, 14.375432048525129, 11.514565127236501, 8.632826685905457, 4.778150234903608, 5.440294018813542, 8.320306267057147, 9.930797951562063, 8.906387686729431, 1.088060649377959, 0.10622147484017269, 0.07775635405310563, 0.11946814081498555, 0.06887139260236706, 0.08299448154866695, 0.0636618924992425, 0.030004818524633135, 0.013733183216702725, 0.03454208719943251, 0.04033434710332325, 0.0809552056182708, 0.03943821268954447, 0.04696984961628914, 0.035010096550519974, 0.032792335376143456, 0.04645876346954277, 0.04019001252683146, 0.04427208259169545, 0.07269778049417905, 0.03461009676435164, 0.029541097514863526, 0.01194431893860123, 0.019116904819384217, 0.08496831277651445, 0.031898674222507646, 0.03887247393972107, 0.011566839729701834, 0.05130021260785205, 0.09215089093361582, 0.019562549656257033, 0.05479550255196435, 0.04393665219790169, 0.06300670587058578, 0.04333213856443763, 0.06069000411246504, 0.020181533048993776, 0.03195497905835509, 0.023678711016795466, 0.052472738083451986, 0.04607089928218296, 0.012192513477722449, 0.05258125279630933, 0.051152987472180805, 0.05878588557243347, 0.04556696828720825, 0.05147073185071349, 0.10225733755422489, 0.031381817135427675, 0.03426320252141782, 0.06229418981820345, 0.025020296884966747, 0.03203442193833845, 0.01584197590792818, 0.0452304318813341, 0.045849327064518414, 0.0150874619305666, 0.03847569040954113, 0.005931403263405497, 0.039410776126065424, 0.03700195984648807, 0.11779460204499108, 0.05044439335220626, 0.009984345092172069, 0.02172569215430745, 0.043352803348430564, 0.044861512391694953, 0.0028502062777988613, 0.04215827637485095, 0.01792855081813676, 0.05640521492542965, 0.017291961138003638, 0.040629601438662837, 0.015107572012181793, 0.02508758720276611, 0.05068413334499512, 0.009109521766991487, 0.06685503758490086, 0.04846456048211881, 0.3241025230714253, 0.3103793965918677, 0.14504819177091122, 0.09074047447315284, 0.1460477959896837, 0.13525903491037233, 0.18494687868016108, 0.16765491584581987, 0.1286638102361134, 0.10739714532558407, 0.11526585130819253, 0.10187992280615227, 0.14745396482092993, 0.10070337022521667, 0.15046110988727637, 0.05606213065662554, 0.1516723491783653, 0.1954962390341929, 0.14167827474219458, 0.19626693267907414, 0.31812435814312523, 0.18208587648613112, 0.18619796154754503, 0.10835546747382198, 0.25927167758345604, 0.14037081918546132, 0.1596680972725153, 0.09588867572269269, 0.21258510276675224, 0.14891886764339038, 0.2029221262782812, 0.12698458534266266, 0.1174180693924427, 0.19605772676212446, 0.1523641427712781, 0.11241489821778876, 0.09173589213086025, 0.15402122028172016, 0.099821430764028, 0.1070027332752943, 0.15154645379100526, 0.12958060604121002, 0.10365792204226766, 0.1800505564148937, 0.189755968483431, 0.18910480556743486, 0.06914539861359767, 0.13385226896830968, 0.09452132587986332, 0.11262494551816157, 0.1518085040152073, 0.12270955688187055, 0.15827298856207303, 0.08530904592147895, 0.23759698921016284, 0.2357458642550877, 0.09328295875872884, 0.1160669026098081, 0.17586043982633523, 0.11969791991370064, 0.14450606943241187, 0.20604683432195867, 0.1486462458435978, 0.08045617703880582, 0.14298247333083833, 0.11057595975164856, 0.20333087577351502, 0.21553795146090643, 0.14833216555416584, 0.1585050475384508, 0.13545571507087775, 0.17354933598211833, 0.1448597761669329, 0.13853496126830578, 0.13491136713751725, 0.1319784809436117, 0.2249943818897009, 0.19781116981591496, 0.15435785507517202, 0.12099777587822505, 0.26092591881752014, 0.170932212844491, 0.17712866248829023, 0.19471103831061295, 0.3073674610682896, 0.36934913801295416, 7.539649231093271, 28.9795241015298, 29.71873426437378, 39.43648133959089, 37.88211720330374, 40.00187710353306, 34.670513902391704, 29.999587399618967, 25.31709909439087, 26.525449889046804, 21.00748586654663, 4.731884786060878, 0.28436900515641483, 0.16802785226276942, 0.1828603292150157, 0.20600792712398938, 0.31339225492307116, 0.135500986927322, 0.1620708576270512, 0.10094507118420941, 0.22391910744564875, 0.24921730852552823, 0.34011426674468176, 0.2281955879713808, 0.15576016982751234, 0.24373602122068405, 0.2033428315605436, 0.16752100017453941, 0.2319444396666118, 0.3030141975198473, 0.1717762696955885, 0.12583625981850283, 0.0816722067871264, 0.1767226814159325, 0.09048937580415181, 0.2122889222311122, 0.10119400532650095, 0.09659792802163533, 0.10194755917681114, 0.16936293776546205, 0.23747919553092547, 0.11179757384317261, 0.11708201813910689, 0.2581809732530798, 0.16853352370006697, 0.19913765149457113, 0.10806114612413303, 0.1199246591755322, 0.24042705020734242, 0.13231104452695164, 0.14050470771534102, 0.14759617219013826, 0.19524740667215415, 0.11251100591783013, 0.11474864477557795, 0.12034163251519203, 0.2466606699994632, 0.12769663999123232, 0.17580026734088147, 0.07912187185138464, 0.1182427065713065, 0.13593731208571366, 0.11840446931975228, 0.14794374496809073, 0.10442008650196449, 0.16430025228432246, 0.1657184176146984, 0.20519729490791047, 0.13334557972848415, 0.11140682588198356, 0.11436524534864084, 0.19758069861148084, 0.22812643168228014, 0.1602298564144543, 0.13914547993668488, 0.1527707345251526, 0.12946452227021965, 0.13967682713908808, 0.16573763372642653, 0.12281795963644981, 0.06831453926861286, 0.1937692045633282, 0.11130615842661687, 0.12952317483723164, 0.1981749731515135, 0.13726261311343738, 0.14453524643821375, 0.08175809574978692, 0.12732012090938433, 0.22657889686524868], [0.07613481142159019, 0.03730398935398885, 0.0141013105167076, 0.10536246986261436, 0.04216713125684431, 0.05015623988583684, 0.052035347625081024, 0.0767407024811421, 0.06047403998672962, 0.035304577355938296, 0.04948669206351042, 0.03961450965808971, 0.028209776185186844, 0.04289324175832527, 0.03779855317303112, 0.044179493095725775, 0.015457802951069815, 0.021695176738181284, 0.0728910340528403, 0.05619896063581109, 0.04761710756325296, 0.040157564982239685, 0.03721195286405938, 0.11274936848453113, 0.020834495779126883, 0.0341313801306699, 0.11977762063699109, 0.016553620042811548, 0.021930307781855975, 0.053326175681182315, 0.00884477945510298, 0.09941901878586837, 0.023598776198923588, 0.029759633288319622, 0.010741677534367357, 0.052233727515808175, 0.028340183830420886, 0.08716962965471403, 0.03340358007699251, 0.05937341547438076, 0.04882489650377205, 0.013546596264599689, 0.022453600773587823, 0.03515180180381451, 0.034631304376359494, 0.026130580343306065, 0.056000129519296546, 0.041115490187491686, 0.07188590655901603, 0.030504875084651367, 0.05827669932373932, 0.027054217477728213, 0.0221049016275044, 0.041076745837926865, 0.03901772793116314, 0.03281468292698264, 0.02161276187481625, 0.041602356026747396, 0.026980603213555047, 0.04536749595510108, 0.0405552679273699, 0.050707240855055194, 0.03552666186754193, 0.0073644560761749744, 0.021438186688880836, 0.03685259393283299, 0.037784996043358526, 0.010346997462745224, 0.01956334863124149, 0.05247751496998327, 0.007431327398600323, 0.10682267722274576, 0.061855184446488104, 0.015209869647930776, 0.05185339506715536, 0.049618894433868785, 0.02773218591963606, 0.06516329372035605, 0.023052448639646173, 0.006417525258647012, 0.029280828445085456, 0.09206743791167225, 0.04842028946482709, 0.08576749810682875, 0.014212217065505683, 0.017242733422400694, 0.011231114173174968, 0.12770546094647475, 0.8449883439711162, 5.754931032657623, 2.502123828445162, 3.046580978802272, 5.2097362875938416, 2.328829675912857, 2.8264042905398776, 1.5640402627842767, 1.4877050731863295, 0.027596380528328673, 0.027326362606670176, 0.020225334180785075, 0.08390680580799069, 0.032396969984152486, 0.030268039221742322, 0.027066059610141174, 0.0565657902375928, 0.04382578296852963, 0.01917788476151015, 0.020121976334069456, 0.003427850560651028, 0.048693314992955754, 0.03454496758058667, 0.030241535643913915, 0.04576050343790224, 0.03150735968457801, 0.08293750496315104, 0.0384831882214972, 0.026250178925693035, 0.052618538295584064, 0.03036257272054042, 0.100083189218172, 0.042028306384703944, 0.048248749026762586, 0.04473565432376095, 0.00916234402185572, 0.061850156501999924, 0.05925256160220929, 0.0756145039839404, 0.06181368524474757, 0.010752168533924435, 0.03437533721859966, 0.05639603773930243, 0.05505942892549293, 0.048082643654197454, 0.050204928166099956, 0.06978843946542058, 0.06603526550212077, 0.06910478829273156, 0.039699082262814045, 0.013166519962916417, 0.05675769690424204, 0.03139495696606381, 0.023353462040956532, 0.028726502654275725, 0.01432253752968141, 0.04235753836110234, 0.09598768076726369, 0.06422890350222588, 0.02590296237862536, 0.036109676118940115, 0.021300856290119033, 0.031062352670622722, 0.05285600519606045, 0.0027901478710451295, 0.036303224840334485, 0.03951306528012667, 0.020650103887809173, 0.04747365168961031, 0.04494341496112091, 0.06446195992508105, 0.006180044363385865, 0.052188920455851724, 0.0324291936121881, 0.03176991202469383, 0.01358899028439607, 0.04882701014035514, 0.07533237590853657, 0.0048315683961845934, 0.03274050547874399, 0.015054174698889256, 0.024839713271441202, 0.04802317005981292, 0.05343945710254567, 0.0704120606450098, 0.00450730456837586, 0.03401233455432313, 0.05271261378324457, 0.029082954062947204, 0.02343789893867714, 0.06769369329724993, 0.04999925402392234, 0.03812836190419538, 0.027653285867667625, 0.03568241618839758, 0.08678285112338406, 0.048835739493370056, 0.05810655666781323, 0.019065999425947666, 0.009920346517381924, 0.03906316602868693, 0.04431705250005637, 0.03639656072482467, 0.014753885633711303, 0.0681541743023055, 0.043622721186173816, 0.04608653272901263, 0.04648832384763019, 0.037820873582469564, 0.023385616119152734, 0.022535952872463634, 0.03897120078493442, 0.01934463983135564, 0.014311490979577814, 0.07280328590422869, 0.01286684412376157, 0.005517137278470078, 0.034668684870536835, 0.039781731220760515, 0.041013944029275856, 0.04313804701502834, 0.0511935570809458, 0.02491843011895461, 0.06303651391395501, 0.05740085989236832, 0.01555649926220732, 0.04919117988486375, 0.05165702364008341, 0.032139530405402184, 0.024191641082455004, 0.0678465808076518, 0.0046946413016745025, 0.028454366007021496, 0.049659172272575755, 0.08495964788432632, 0.026990046724677086, 0.01887512413252677, 0.02660457437325801, 0.022156831608819108, 0.029055958547230278, 0.06640179654849426, 0.01890765649399587, 0.03537281762276377, 0.03845869989267417, 0.03349198979724731, 0.012440153314465923, 0.015499429378126348, 0.06012882851064205, 0.021905205378841077, 0.017908707061516385, 0.03290884323152048, 0.017568701645359397, 0.040434922956462414, 0.03055120206304959, 0.03959121215822441, 0.03332261727856738, 0.049325461965054274, 0.04198210154260908, 0.06441581275846277, 0.046316966614020724, 0.03591241581099374, 0.03463759778865746, 0.04415979522413441, 0.02197009028999933, 0.02804815423275743, 0.02762898413597473, 0.05327120077397142, 0.01571522217376956, 0.025299799029848406, 0.04444933629461697, 0.03279278660193086, 0.028176100492211323, 0.04159836284816265, 0.04446591969047274, 0.05008501745760441, 0.11823650476123605, 0.7594879918864795, 3.374208518436977, 7.519357017108372, 7.835328953606742, 8.319392578942434, 3.1428096209253584, 4.299788909299033, 1.0809122558150972, 0.09029847676200525, 0.04221673555938261, 0.04418875849140542, 0.06379792519978114, 0.042635832713650804, 0.02275827826399888, 0.050354433179433854, 0.05953295262796538, 0.030216419670198644, 0.01641004203286554, 0.07320582001869168, 0.06903525880937066, 0.07580540981143713, 0.03925918122487409, 0.02024649938435427, 0.05012716805296285, 0.02372332808694669, 0.017023057710113268, 0.06783728487789631, 0.02887878966118608, 0.08663697966507503, 0.029079866728612354, 0.02642104761408908, 0.01998862554319203, 0.05637097604838865, 0.009103531150945594, 0.07010829408786126, 0.025470489602802054, 0.03902848610388381, 0.013520746624895504, 0.0511856250065778, 0.032444928839270554, 0.05108478791745646, 0.026027375166969638, 0.06547664119196789, 0.09682875206427914, 0.02952528086357883, 0.041383908462843726, 0.03313141628833754, 0.023152897267469337, 0.030736252133335386, 0.04218353144824505, 0.03797090446044292, 0.008055852726101875, 0.014980804707322801, 0.005992764033310647, 0.03817788138985634, 0.011461410654841788, 0.04916895447032792, 0.06752847680555922, 0.028118913560839634, 0.022745333512180617, 0.021758451825007796, 0.004386457905638963, 0.040133083438766856, 0.02506790799088776, 0.018333683721721172, 0.046129962362881215, 0.0592791669602905, 0.007483165777687515, 0.05318324567217912, 0.025108150206506252, 0.04957559032897864, 0.06354918104729482, 0.063059109130076, 0.044116952523056946, 0.01805474984991763, 0.020512731080608707, 0.029005037886755805, 0.033223249217761416, 0.06708746975553886, 0.026240971205489974, 0.020634168492896215, 0.04880329194877829, 0.005147065551552389, 0.011580790409685245, 0.04313118363331471, 0.0405100842804781, 0.023053581793127314, 0.07523488399705716, 0.2655579245516232, 0.18650280019002302, 0.20299193396099977, 0.22712948732078075, 0.14704693880464348, 0.12021815271249839, 0.1525711773761681, 0.23934796239648545, 0.2225931550243071, 0.1615430795188461, 0.1745546670364482, 0.2181907926819154, 0.11007750114159924, 0.1772470125662429, 0.12959018695567334, 0.1610764374158212, 0.15659331583550998, 0.10815483823950801, 0.0813362980261445, 0.16978422658784048, 0.12662264119301522, 0.08004554121622018, 0.170649168746812, 0.2068811066980873, 0.140605022332498, 0.14606816561094352, 0.15829783651445592, 0.10323533721800361, 0.1305555658681052, 0.26113260058420046, 0.06289121921041183, 0.1388885322958231, 0.14328866904335363, 0.10258553815739495, 0.1291444573019232, 0.19720295816659927, 0.1106545544628586, 0.1096301633598549, 0.14873995152967318, 0.20439663715660572, 0.11733245184378964, 0.12940548972359725, 0.11789373601121561, 0.09588153753429651, 0.09107179633740868, 0.10119456851056643, 0.2964371575840882, 0.13311922044626304, 0.12843333903167928, 0.09174178860017232, 0.10655498158718858, 0.1786616359438215, 0.28800600713917185, 0.1419249086507729, 0.17478156914668425, 0.1445566067206008, 0.08309060960475888, 0.1795781874763114, 0.1421967569206442, 0.11682279062058244, 0.09969218341367585, 0.17927670079682553, 0.15346539153584413, 0.12322841903993062, 0.15089506017310278, 0.2125110610255173, 0.11001492664217949, 0.17463993174689157, 0.13748338126710483, 0.09310978983661958, 0.2072333749383688, 0.37874120260987965, 0.17310397273727826, 0.04858618788421154, 0.12236157698290688, 0.1210628202451127, 0.17249630391597748, 0.23497773547257694, 0.11988204717636108, 0.16196881953094686, 0.12480734288692474, 0.17479522127125943, 0.2082495761236974, 0.18011146171816758, 0.17712950387171336, 0.1233499175203698, 0.08067913007523332, 1.6246601470879145, 5.958016455173492, 39.93025507245745, 44.43956995010376, 35.144989013671875, 31.831466061728342, 26.222348621913365, 21.78909567424229, 9.129373618534633, 1.6726641654968262, 0.12555430137685367, 0.11338632287723677, 0.08207949743207012, 0.16313442055668148, 0.094668785110116, 0.17461630515754223, 0.17340293526649475, 0.18219255576176302, 0.2176211489630597, 0.1628768758050033, 0.24514897540211678, 0.2267694566398859, 0.11097646504640579, 0.12318937613495759, 0.1903806413922991, 0.11620190393711839, 0.11927270915891443, 0.1529660847570215, 0.14964051677712373, 0.3043243672166552, 0.09565850985901696, 0.21252423817557947, 0.21851553954184055, 0.17532628348895482, 0.10609567444771528, 0.10571540985256433, 0.1191613208502531, 0.17574400321713515, 0.12570888522480214, 0.22543643388364995, 0.13340470727000917, 0.08934387298566954, 0.15282816572913102, 0.23815439215728215, 0.31464795182858196, 0.1241755046482597, 0.10319802457732813, 0.15120817694280828, 0.16514637188187667, 0.19822701678744384, 0.1440248116850853, 0.10327618502612625, 0.17213913665286132, 0.15481695186878952, 0.04823695269546338, 0.1437578217259475, 0.11870444965149675, 0.07859956273542983, 0.2533096617885998, 0.16628679925841944, 0.14724912866950035, 0.15306094395262854, 0.2110928414123399, 0.12813068527196134, 0.1685519798525742, 0.14024561590382031, 0.1645370881472315, 0.1383328256862504, 0.1588064120816333, 0.14015667353357586, 0.1120995015704206, 0.15987017857176916, 0.1363948346780879, 0.13030682850096906, 0.14328282007149287, 0.08104701819164412, 0.07139368368578808, 0.1272882433342082, 0.23070671036839485, 0.16079457396907465, 0.15178229899278708, 0.08439148337181125, 0.10272775909730367, 0.12905683128961495, 0.075053131606962, 0.18692528323403426, 0.0637547160897936, 0.1196466905197927, 0.15168412854628904], [0.02816720659445439, 0.020339470556271926, 0.034250327319438965, 0.0548200790903398, 0.031010563485324383, 0.03437737960900579, 0.05372426539127316, 0.008998554998210498, 0.07573175483516284, 0.019424993644601533, 0.07025601116142102, 0.033076763685260496, 0.04974511551803776, 0.023249914204435687, 0.06027467961290053, 0.030513163389904157, 0.009245343273505569, 0.02137712192987757, 0.043170345281916, 0.020867682926888977, 0.01515231461131147, 0.05796945866729532, 0.009163565384889287, 0.019439705980143378, 0.013843851430075509, 0.03697002459583538, 0.05562847553353224, 0.05841682359044041, 0.01564682075487716, 0.059653609724981446, 0.073098821831601, 0.04192108088838203, 0.04927802897457566, 0.019200257757412534, 0.0648184757945793, 0.03171353254999433, 0.00864595512393862, 0.05240496939846447, 0.028659531247935126, 0.056395192963204215, 0.05056017178243824, 0.032708804322672744, 0.0289151286041098, 0.028970001731067896, 0.042155874360884936, 0.01440026201973004, 0.08669570687093905, 0.05875554148639951, 0.05449944754530277, 0.025911025070984448, 0.03775522871209042, 0.003964643218621079, 0.035522051222090206, 0.021997801660160934, 0.04384616616048983, 0.02951222924249513, 0.014738355663471987, 0.010069103445857763, 0.0261588023110692, 0.05931160093418189, 0.05678966947432075, 0.074369663638728, 0.019128407684287856, 0.030090493748762777, 0.015030710957944393, 0.05071362586958068, 0.012839808744112296, 0.034058834559151104, 0.048429592179932764, 0.04745304797376905, 0.02745377960880952, 0.025340387298326408, 0.016789036071194068, 0.008703904559037514, 0.028816822450608015, 0.024639713378357034, 0.04141272584508572, 0.05152079077171428, 0.08137810256864343, 0.02779311666797314, 0.014059220989500838, 0.0508655770016568, 0.013957853794896176, 0.021828793854053532, 0.05182341399735638, 0.019420338894373605, 0.054585421324840615, 0.047488755879125426, 0.0500494757933276, 0.15724382735788822, 0.616199363555227, 1.069712519645691, 1.0285652875900269, 0.5141600732292447, 0.1394914106598922, 0.027781512022816708, 0.19190829513328417, 0.029620404687843153, 0.05682244271572147, 0.01952029049529561, 0.10277235241872923, 0.02800143200771085, 0.06200169372771468, 0.033394718409648964, 0.0526728414531265, 0.027680272901696817, 0.032503432128578424, 0.04126551088743976, 0.028053613046982458, 0.05941196304879018, 0.021743407007306814, 0.022751038295349905, 0.03897692422781672, 0.07967406364956073, 0.06605513979281698, 0.023886089978207434, 0.0076619716294642004, 0.00951103977526405, 0.08547903251435075, 0.03303344940234508, 0.04463909879060728, 0.018541943082319837, 0.05119482933410576, 0.06258713374180452, 0.09545990944440876, 0.017964743876031468, 0.023867822119167874, 0.02905868286533015, 0.024275865937982286, 0.05641374411061406, 0.03078043833374977, 0.006166235327587596, 0.051165930527661524, 0.036312486843339035, 0.019442873042342917, 0.03419703857174941, 0.007287199775289212, 0.030827029940805266, 0.04564447734238846, 0.03813846868329814, 0.0460205757325249, 0.042050453767712624, 0.024150618551565067, 0.009401562390848994, 0.061638535000383854, 0.020364371095118777, 0.04795405787548848, 0.019423931737297347, 0.06918207343135561, 0.03566966651539717, 0.007725554601555424, 0.010282853002926069, 0.016019740208451237, 0.06182715416486774, 0.07188545194055353, 0.062214841933122704, 0.07487618324479886, 0.031228685352419103, 0.02122847017432962, 0.024861360234873633, 0.024249528601233448, 0.09748260197894913, 0.024955037083210688, 0.031148625005568777, 0.04939718311652541, 0.01844616616810007, 0.034864554181694984, 0.04784216745091336, 0.0242202837419297, 0.06643142817275864, 0.06549631192215852, 0.01908041999143149, 0.01894550008832344, 0.01632743887603283, 0.043377949856221676, 0.030240928355072225, 0.028116467442097406, 0.037951325332479816, 0.034847136187766276, 0.046798533094780784, 0.023971963673830032, 0.015623221306928566, 0.04121413900117789, 0.016348831388833265, 0.07023678147899252, 0.011263512523977883, 0.03854230897767203, 0.04281596679772649, 0.04417605970853141, 0.03920131915115884, 0.02146042906679213, 0.024515784046213542, 0.03436802261109863, 0.018229063799870864, 0.024902058765292168, 0.03662820918751614, 0.030398436688951085, 0.022407165229586617, 0.0441317852985646, 0.04233433585613966, 0.03116468253678509, 0.04310920588406069, 0.048028822256518264, 0.06909011836562838, 0.06350873357483319, 0.03207769890182784, 0.028175466061968888, 0.07609763448791844, 0.040066458085285764, 0.03354176373354026, 0.06650171082999025, 0.02758469106629491, 0.04684891431991543, 0.04181548387610486, 0.028184841719589064, 0.020753999473527074, 0.08009481642927442, 0.029717699824167148, 0.03440695016511849, 0.01744097930246166, 0.014561454798760158, 0.0616903207930071, 0.06535992638341018, 0.05672099494508334, 0.03392178744875959, 0.012851035105995834, 0.03319788557876434, 0.036607093177735806, 0.013700980792886444, 0.04736695884327803, 0.03952899049701435, 0.03209509653970599, 0.03130173982520189, 0.03384463462446417, 0.028490481033389057, 0.05731505235391004, 0.020305268998656954, 0.042058202637625594, 0.020146563050470183, 0.017528625670820475, 0.06326904786484581, 0.010940450127236545, 0.023938235394390564, 0.0773402831650206, 0.05833110426153455, 0.046079452216093025, 0.07317741654281106, 0.03678402118384838, 0.027499073517641852, 0.063494972884655, 0.027662522425608974, 0.018904984762359942, 0.08434202495430197, 0.04437993234023452, 0.05218997897048082, 0.029045149484383206, 0.004008527895036552, 0.08751093955444438, 0.03763743842552815, 0.0453720048203, 0.05308869181733046, 0.04150861641392112, 0.056462825941188, 0.023824329720810056, 0.04791445517912507, 0.1282452626952103, 0.5911619099123138, 0.404908254210438, 0.5289451341543878, 0.06292312392698866, 0.18424916826188564, 0.05616625864058733, 0.0736630033435566, 0.010725424076164407, 0.050907920979495556, 0.04654942253338439, 0.07571325797055449, 0.03921999243487205, 0.028530894579099755, 0.038053655198642185, 0.030670020330165113, 0.04430985324350851, 0.01799528982623347, 0.0509767312157367, 0.016988318413496017, 0.03166160765769226, 0.034252064369086704, 0.02664140016505761, 0.0437562195584178, 0.02649035657356892, 0.02130313786411924, 0.024455131497234106, 0.071431376306074, 0.028139798868713633, 0.04336860642901488, 0.016174497082829475, 0.04564605832898191, 0.021511865413880775, 0.0433659872838429, 0.060707964934408665, 0.09576446310217891, 0.017760998469644358, 0.007671559329277703, 0.0007211659955958437, 0.025958035673413957, 0.022493130527436733, 0.03289179503917694, 0.03862564664866243, 0.007827661399330412, 0.016534790696044053, 0.06019712306026902, 0.04675506953416126, 0.02603515626729599, 0.02972336219889777, 0.051335313224366734, 0.014855123058493649, 0.03697033332926886, 0.018176346717934524, 0.01602964342704841, 0.05416975077241659, 0.03512318119672792, 0.02088559964405639, 0.02421516758788909, 0.053058300233845196, 0.020455566201625124, 0.030340435515557016, 0.03196239883878401, 0.1124612150181617, 0.015377060676525747, 0.03857500418754561, 0.010566787677817047, 0.00804387149401009, 0.02804946550168097, 0.01569561760074326, 0.03903319174423814, 0.0452503638475069, 0.011169183433854153, 0.031228363048285246, 0.023964772898969904, 0.03309793397784233, 0.029402096223618304, 0.014956299415124314, 0.005196719471963921, 0.02497093176602253, 0.03664241431813155, 0.05380912637338042, 0.059027179410415034, 0.07825991524649517, 0.0045949742613759425, 0.06393711987350668, 0.03315013028415186, 0.009504530079928892, 0.2668071618037564, 0.07438030306782041, 0.1552192009985447, 0.35380677772419794, 0.08096707319574696, 0.12452390523893492, 0.13924299898956502, 0.19279971372868332, 0.1971574013254472, 0.11679246010524885, 0.14930252491363458, 0.1084283014227237, 0.10919396712311677, 0.21504226805908339, 0.12389194486396653, 0.0914802404918841, 0.12956398193325314, 0.1049279903194734, 0.09858912296061005, 0.15420985301690443, 0.15971490261810167, 0.08430790821356432, 0.12039071773844105, 0.15455429096307072, 0.054605868977627585, 0.1163660144167287, 0.10879831335374288, 0.23568376473018102, 0.18990006217999117, 0.11054299652044262, 0.1863544045814446, 0.15051805254604134, 0.12071994292948927, 0.1922981949256999, 0.16690596246293612, 0.1294888002531869, 0.06696597806044988, 0.1643857748380729, 0.10869471462709562, 0.1550987067499331, 0.11672626222882952, 0.11308860885245459, 0.11657232977449894, 0.17554755375853606, 0.08740472846797534, 0.17462737884904656, 0.15553839744201728, 0.14354891436440603, 0.12431440076657704, 0.11164286785892077, 0.10752368532121181, 0.1353182845882007, 0.13429748293544563, 0.08853991076882396, 0.1007919122598001, 0.2250834871083498, 0.08235650935343333, 0.0970947038648384, 0.2759600563773087, 0.13368173954742296, 0.14858322351106576, 0.2311001249722072, 0.12449115913893495, 0.12765793635376863, 0.12398651907486574, 0.12306810835642473, 0.11960608698427677, 0.1128366823707308, 0.22839323165161268, 0.12173733833645072, 0.1656380519270897, 0.11226264174495425, 0.07552481522517544, 0.13592100010386535, 0.11723763336028371, 0.12520925274917058, 0.14620255625673703, 0.12273091716425759, 0.24746866949966975, 0.14935641416481563, 0.06340525019913912, 0.17221919021436147, 0.1519488114863634, 0.11915530902998787, 0.17695645030055726, 0.08484983377690826, 0.13045789753752096, 0.18576258633817944, 0.24793039900915964, 0.773999630340508, 4.711451871054513, 5.537447639874049, 4.602597483566829, 1.059960505792073, 0.5203438071267945, 0.2188226580619812, 0.15008062816091947, 0.24087444905723843, 0.15466282942465373, 0.10592684814972536, 0.18748153267162188, 0.13621661067008972, 0.09370845449822289, 0.14344329360340322, 0.08818121680191585, 0.10928250237235002, 0.17234621196985245, 0.0875820703804493, 0.07629516281719718, 0.17632725834846497, 0.1269262313310589, 0.07931992943797793, 0.1110528680895056, 0.12862167321145535, 0.14920575224927493, 0.07948091865650245, 0.12232725668166365, 0.11419976422829287, 0.14674101450613566, 0.1362378488161734, 0.11918745801917144, 0.058882705734244416, 0.1420536403145109, 0.13014121167361736, 0.24041624792984553, 0.14413643069565296, 0.10925553060535874, 0.09660695932273354, 0.1422254860933338, 0.1371409110724926, 0.2199302850557225, 0.10004976458315339, 0.11421372847897665, 0.16131016558834485, 0.17256970783429487, 0.12358429708651134, 0.0746979388807501, 0.07964818432394948, 0.09810705775661127, 0.1893640873687608, 0.09447214566171169, 0.11350903593535934, 0.09590283674853188, 0.19434065318533353, 0.16060439417404787, 0.08464377626244511, 0.1362890510686806, 0.09611978475004435, 0.13126083516648837, 0.11129276414534875, 0.08654052591217415, 0.16079719311424664, 0.07831366200532232, 0.16534434125891753, 0.14318291257534707, 0.09171507467648812, 0.18294396544141428, 0.10383976942726544, 0.08132843380527836, 0.14267167715089663, 0.12132461262600762, 0.17482101917266846, 0.10824520553329162, 0.11277568207255431, 0.16731304276202405, 0.08772254748536007, 0.06823658238032035, 0.08942710209105696, 0.11721834939505373, 0.15324114928288118, 0.2549529107553618, 0.17071695439517498, 0.13532633201352187, 0.15892557640160832, 0.24099837669304439, 0.0973341181608183], [0.01764479765136327, 0.04764830660341041, 0.01352041244639882, 0.03427256291200008, 0.0507195393022682, 0.023094261663832834, 0.0045947142976469225, 0.007700784680699664, 0.052790407823132615, 0.034557432268879244, 0.04723807790183595, 0.05117905339492219, 0.02397404677633728, 0.04054811956094844, 0.01001482573337853, 0.058514519062425406, 0.03490652157259839, 0.05705099366605282, 0.01584657298267952, 0.04338741541973182, 0.03485275785039578, 0.029330334360046045, 0.026364123615037118, 0.026398935854168873, 0.036158557781683545, 0.0637402157964451, 0.04076192933799965, 0.013427031608963651, 0.00960411866461592, 0.012843911336468799, 0.03709831860448633, 0.029302568707082952, 0.03159221388133509, 0.09811319849853005, 0.014931853494739957, 0.02221485992361392, 0.029982549005321095, 0.06514605893088238, 0.015325018736932958, 0.010028825607150793, 0.035097987191485505, 0.02409710588731936, 0.014733563509902783, 0.01593153235236449, 0.0028400797787721133, 0.010997240115622324, 0.058635556139051914, 0.014696769948516573, 0.07965733776135103, 0.023386021543826376, 0.054305817399706156, 0.014951692162347692, 0.012235175518851196, 0.030326308416468755, 0.010789405687579086, 0.021132618621257798, 0.023731423009719168, 0.019393428195534006, 0.022869590237470608, 0.04006566419931395, 0.03383646167016455, 0.05547915033197828, 0.015046877054763692, 0.03838199829416616, 0.0303211651210274, 0.01361690606323204, 0.041904952110988755, 0.007044308411423117, 0.02242247128326978, 0.021223828994802067, 0.019448493008634875, 0.02934271762413638, 0.024192699597084096, 0.04785215548638787, 0.04948472770463143, 0.04091789400471108, 0.04846060801563518, 0.024181936335350786, 0.038404179603925774, 0.030367129083190645, 0.005815184633580169, 0.04705322799938066, 0.03937262888731701, 0.0054895891807973385, 0.030348920595965216, 0.029347158635833433, 0.11319110156702143, 0.03155717094029699, 0.025198676956019232, 0.10551941501242773, 0.015873887409855212, 0.088449021003076, 0.029937972647270987, 0.12035639743719782, 0.03525009438661592, 0.02868275750162346, 0.0831498389265367, 0.018419097709868635, 0.029338280005114417, 0.05240466405770608, 0.06999513480280127, 0.007613153579378766, 0.037067109386303594, 0.017786774318665266, 0.05580686578261001, 0.05502904412735786, 0.040178016027701755, 0.08863871225288936, 0.01895703687997801, 0.04054857757208603, 0.03783092947144594, 0.010492082668601401, 0.02430338053298848, 0.02561995051135974, 0.05442213187260287, 0.004281110254981155, 0.05223896919882723, 0.03245201613754034, 0.021823234955913255, 0.011472453812270291, 0.052330724096723964, 0.025871435945321406, 0.06264193222991057, 0.0036309867698167053, 0.04687155703348773, 0.0389405886775681, 0.03189190922837172, 0.029659447592816184, 0.040004110895097256, 0.03447402674438698, 0.03389589115977287, 0.07876018554504428, 0.02041077271236905, 0.014973905702520694, 0.04985553352162242, 0.013652607183238226, 0.09300931915640831, 0.07438748196831771, 0.017007802546556507, 0.017527602779279863, 0.019421363482251763, 0.03530561551451683, 0.06390695220657758, 0.038079300429672, 0.07545510253735951, 0.026871070698169724, 0.023189638242391602, 0.0435406455903181, 0.044662450573274066, 0.014038730080106428, 0.03536786092445254, 0.04441747907549143, 0.021424984093755484, 0.02346824132837355, 0.008554840593465736, 0.026262256849024977, 0.06391694702740226, 0.03264716620157872, 0.043431472698492665, 0.05400056824354189, 0.06175877819103854, 0.054200101643800735, 0.05818399786949158, 0.10493389357413564, 0.08781098095434052, 0.05699962856514113, 0.06445193117750542, 0.03487492558945503, 0.0470389957273645, 0.008912466715888252, 0.0230084812667753, 0.013966572969885809, 0.02102053820687745, 0.032414330302604606, 0.011592335683027548, 0.02271555091387459, 0.038232517029557905, 0.035202732642314265, 0.045130660092192035, 0.026387999566005807, 0.038521420277122936, 0.04623037197494081, 0.00569318955032421, 0.04442599808265056, 0.0718683460727334, 0.019852779439783523, 0.01995695322485907, 0.040690917255623, 0.021029466031385318, 0.031500085789178095, 0.05451660769592438, 0.023223044217697213, 0.04388582313965474, 0.019048725620710423, 0.07980647297309977, 0.006078375644782292, 0.030140752837594067, 0.02707540982269815, 0.05177280207031539, 0.06400502087282282, 0.06407013987856251, 0.04167162088145103, 0.035997582133859396, 0.01635815785266459, 0.027107804780825973, 0.03797063983178564, 0.059819911872701984, 0.03306069258334381, 0.018587174226662943, 0.018447699657242213, 0.01443806999096913, 0.05246548793677773, 0.05746950049485479, 0.01962010808555143, 0.05336000065186194, 0.040087133047303984, 0.018672732403501868, 0.042048475838133266, 0.024278320538412248, 0.02407480583393148, 0.04887207165094359, 0.072325699031353, 0.02128102949687413, 0.03759907744824886, 0.02011136743905289, 0.02500849207197981, 0.08546212342168603, 0.015261216089129448, 0.026587928212913017, 0.10617365169205836, 0.010559107509574719, 0.03178394412887948, 0.04840369928362114, 0.04936924782980766, 0.03504734133769359, 0.04164583655074239, 0.0035621498162592097, 0.04838542972824403, 0.05237839457445911, 0.009685624291055968, 0.03145725326612592, 0.008368871956398445, 0.041635889227369, 0.005336122371123305, 0.02511841813767595, 0.018766689147534113, 0.011231016633766038, 0.06846453621983528, 0.021821606471868496, 0.02829688142186829, 0.017698717436620166, 0.009580354671925306, 0.027725359857348458, 0.03081118275544473, 0.08329017353909356, 0.016058747490335788, 0.027522450745371834, 0.03112695598974824, 0.04596160425405417, 0.022730198788589666, 0.049199281592986414, 0.06561726078923259, 0.04431449103036097, 0.010724600504285522, 0.013147833956671613, 0.10396611943308796, 0.1108245410557304, 0.05695283679025514, 0.10744494811764785, 0.03628470761967557, 0.038146013992705514, 0.05434800870716572, 0.045607327550117455, 0.05287362335781966, 0.014247008100418108, 0.0522431014770908, 0.010686086856627038, 0.0666200676932931, 0.06032671646348067, 0.019821692357904146, 0.03731257621464985, 0.0073521822258563975, 0.03468735136889985, 0.05199869655604873, 0.02598593194436814, 0.04235521098598838, 0.019668290857225657, 0.04473290964961052, 0.05999459392790284, 0.01686288951896131, 0.04150914227856057, 0.08184155555708067, 0.013706667764511491, 0.034441837043102295, 0.051401911436447074, 0.025154595928532735, 0.05622276703694037, 0.03746231532256518, 0.023779507393815687, 0.03322566819510289, 0.06106517969497612, 0.021448502117501836, 0.006059379632850843, 0.02680159549761031, 0.04745831340551376, 0.0318788168951869, 0.03289076366594859, 0.06326969247311354, 0.01099701619906617, 0.00565859444239842, 0.036762979812920094, 0.02625715935469738, 0.07234185495014701, 0.08802979492715426, 0.03213121835142374, 0.029870183606232916, 0.03222266790856208, 0.038106316301439486, 0.028024588711559772, 0.03757656365633011, 0.08775141236505338, 0.0400693011470139, 0.021165066165849566, 0.010199290567210742, 0.0277776511585606, 0.03979623829945922, 0.02796381402627698, 0.0547836790792644, 0.029471286439469883, 0.011306987958960235, 0.03482874449608581, 0.03276256125952516, 0.05508525396830269, 0.04769682864259396, 0.027918637164735367, 0.049871370528957674, 0.05662737746856042, 0.02437141045395817, 0.02032579468297107, 0.03521319565230182, 0.06765259443117039, 0.07881290093064308, 0.04819662057395492, 0.015143663289823701, 0.03141419343384249, 0.03522773326507636, 0.04371925975595202, 0.06204526246126209, 0.01579584231201027, 0.057435689094875536, 0.06620515710008995, 0.01968683521928532, 0.13095169461199216, 0.1036607651039958, 0.14927846406187328, 0.1281737858163459, 0.11935623681971005, 0.10212778486311436, 0.07798189909330436, 0.14782339999718325, 0.15853893357728208, 0.1640466023236513, 0.22246100354407514, 0.08780241784240518, 0.07700699354921069, 0.09086537919938564, 0.11186799899275814, 0.10033960081636906, 0.06375105878604309, 0.12072752895099775, 0.17756060431046145, 0.1103645350251879, 0.10184222340051617, 0.10944816669715302, 0.16164848314864294, 0.10191484021821193, 0.13990199219967636, 0.17882267944514751, 0.09134723405752863, 0.06290316821209022, 0.11380844629768815, 0.18250435617353233, 0.1691701795373644, 0.18132559156843595, 0.10311362160635845, 0.1326878485935075, 0.041973121131637266, 0.09271651772516114, 0.1790929263723748, 0.15621740743517876, 0.1655620831464018, 0.13438884089035646, 0.1071106678407107, 0.12363989624593939, 0.09692390302994422, 0.15817367817674363, 0.13395836470382555, 0.13748704535620554, 0.18320361365165028, 0.1204759960195848, 0.15063197857567243, 0.06743667101753609, 0.17374759034386703, 0.10779630033565418, 0.22684077067034586, 0.20619270578026772, 0.07310583788369383, 0.12912746678505624, 0.10410968387233359, 0.10966814775019884, 0.12417482611324106, 0.1757526613239731, 0.07508561307830469, 0.11816631709890706, 0.1746624048267092, 0.07085207024855272, 0.1656905026840312, 0.07221402573798384, 0.20095377761338437, 0.07119838095137052, 0.0523124816827476, 0.12050836213997432, 0.09169237089476415, 0.15325286079730305, 0.08134324622473546, 0.1369431181145566, 0.15628137971673692, 0.10337367015225546, 0.11120796762406826, 0.08343086098986012, 0.14562004751392774, 0.06463578024080821, 0.1299848636346204, 0.09270922347371068, 0.08880112639495305, 0.08211883210710116, 0.11992718332580157, 0.1841118327741112, 0.34962586207049234, 0.16993699196193898, 0.11446686275303364, 0.2797798556940896, 0.380199700061764, 0.25286969968250816, 0.28671719772475107, 0.3539051381605012, 0.1620144849377019, 0.16490424344582216, 0.16533746091382845, 0.13539707607456616, 0.0976091284038765, 0.12831170484423637, 0.13474383684141295, 0.08297312805163008, 0.09653777589223214, 0.08529464062303305, 0.14702048950961658, 0.12632225374025957, 0.1036384752286332, 0.227124439020242, 0.08620764341737543, 0.08834825176745653, 0.13023014047316142, 0.1137039994022676, 0.14926318345325335, 0.09601444897374936, 0.1146513292832034, 0.21871720014938287, 0.10371485113033227, 0.12021801700549466, 0.16531798695879324, 0.08945942071399518, 0.13179746137133666, 0.1262070792061942, 0.11016510001250676, 0.105450401215681, 0.1550654178219182, 0.26384294086268967, 0.11303380357899837, 0.13485667721501418, 0.133680613179292, 0.15979601469423088, 0.09940458634602171, 0.14706829908703054, 0.07722489149974925, 0.10813879767166716, 0.08134778562401022, 0.07338141131081752, 0.19453543344778673, 0.1446181634174926, 0.11405484271900994, 0.14255655689963273, 0.16034465096890926, 0.08533717119800192, 0.1818777969373124, 0.13680571477328027, 0.23305156454443932, 0.0785357668729765, 0.11623539642563888, 0.08777953764157635, 0.1241171234952552, 0.12513010842459543, 0.10469302721321583, 0.09733220469206572, 0.11242699649717126, 0.14196153597107955, 0.13019884643810137, 0.08639760608119623, 0.15351079909929208, 0.1059448496837701, 0.13447333207087858, 0.09063049751733031, 0.1570502548877682, 0.12661535372691496, 0.1749127706778901, 0.19347702738429817, 0.15572057052382401, 0.1416589364941631, 0.13928536671612943, 0.10561656087104764, 0.06533800291695765, 0.15914455322282656, 0.13458869659474917, 0.1383646625493254, 0.1277082022279501, 0.12440107682985918, 0.11693884725017206, 0.09606229247791426], [0.024500152295721427, 0.011628918898557978, 0.024308221880346537, 0.09095108495759112, 0.008737870325733508, 0.051142080021756034, 0.02320589085242578, 0.10897038304912192, 0.06574907300195523, 0.03914411186373659, 0.022884858971727744, 0.030673925299197435, 0.028946656733751297, 0.09538474812039308, 0.007174417925333338, 0.0007078433315785203, 0.039766579533794096, 0.0459608883996095, 0.01882194903945284, 0.02091027796268463, 0.030498988793364594, 0.028882735342319523, 0.02699750043185694, 0.09103707570050444, 0.0346896380319127, 0.052227569810513935, 0.025856808426656892, 0.03372216583894832, 0.010374383136097873, 0.07462678769869463, 0.02157671470195055, 0.03237102619771447, 0.0071509363728442365, 0.041043073537626436, 0.06405392289161682, 0.03318220802715846, 0.025719004749719585, 0.02238057683488088, 0.05493645802406328, 0.04194744197385652, 0.03740288583295686, 0.022094442010191933, 0.017954433536423103, 0.010751584145639623, 0.01206454516588045, 0.1102684408958469, 0.03289418008976749, 0.06506482471844979, 0.039248266989099126, 0.03266215843281575, 0.033445696745600016, 0.04736317940322416, 0.02328285199057843, 0.005660944718069264, 0.022523774865216444, 0.014014364735755538, 0.06759935657360724, 0.047277375257440975, 0.04511037189513445, 0.05717248536114182, 0.02981739697445716, 0.05121536519644516, 0.02427861400480781, 0.027383490166227733, 0.01773275275315557, 0.03921440130631838, 0.01620375720917114, 0.020529852215466753, 0.04371980258396693, 0.02154008229263127, 0.038428891849304946, 0.03854552523366042, 0.10544303911072866, 0.046260733024350235, 0.041627587351415835, 0.05071298126131296, 0.024331507505849004, 0.03963618206658533, 0.044422279710748365, 0.0338385447726718, 0.05703488524471011, 0.009182827297731169, 0.0372053676817034, 0.028566168222044195, 0.059083823513771803, 0.018816732801496983, 0.02449129062837788, 0.008218172721431723, 0.044528426336390634, 0.06646188082439558, 0.05460153653153351, 0.016236849362030625, 0.016307617171800563, 0.0338112337381712, 0.08316815258669001, 0.0520734677224287, 0.024297076942665235, 0.030330033573721136, 0.007645881019665727, 0.08810321920152221, 0.012717888723792774, 0.016216864809393883, 0.005894387905885066, 0.02667106401973537, 0.09653118053185088, 0.02582949060680611, 0.06876087960387979, 0.03548230603337288, 0.04598005362121122, 0.027005815878510475, 0.022488913432295834, 0.045802263875624964, 0.017154467890837362, 0.03886344263862286, 0.033418253396770785, 0.02200356242246926, 0.033876719152820964, 0.111241833306849, 0.02141093502619437, 0.018539754806884697, 0.0047498999213400695, 0.04147588388462152, 0.03214324199195419, 0.037188238065157614, 0.023453961558906094, 0.018443126331216524, 0.10453893869583096, 0.10250291973352432, 0.041143510291086774, 0.026244843944108913, 0.033098259674651284, 0.057355696601527076, 0.026077418820932508, 0.06247621362230607, 0.007040654500347695, 0.011755156946102423, 0.038505708798766136, 0.025442225226600255, 0.005594135311964367, 0.06250166547085557, 0.08047596311994962, 0.042860309061195166, 0.05019900116271206, 0.07220182567834854, 0.05976228389356818, 0.04536189464852214, 0.024989102933821932, 0.00898799444881401, 0.1522084189844983, 0.012001521137010838, 0.033931924761938195, 0.02619619807228446, 0.018786154620881592, 0.048465160985610316, 0.07732684138630118, 0.02942947850429586, 0.059354769332068305, 0.024444329219737222, 0.057465992468808375, 0.03095360386318394, 0.025339506899139712, 0.06030443337346826, 0.03622441978326865, 0.026855773126174296, 0.03494348816041436, 0.04279210611379572, 0.023598240156258856, 0.05053436031032886, 0.04240842509482588, 0.013610402305078293, 0.019007233204320073, 0.031000114046037197, 0.026855900351490294, 0.036893635123435936, 0.04680175274344427, 0.01618930441327393, 0.0887301652027028, 0.010209973252910589, 0.0390047950537077, 0.0421406344643661, 0.02088890241325966, 0.013841073677342917, 0.01838114724627563, 0.06711114384233952, 0.08423932867922954, 0.06269834563136101, 0.025462170763473426, 0.027148465991818478, 0.0447079700950001, 0.020258378836193254, 0.037278506971363506, 0.045580430421978235, 0.034902497859937806, 0.023981120503906692, 0.04456371355003544, 0.03440565077055778, 0.02250008551137788, 0.025329768225284557, 0.007298483812649335, 0.040201625653675625, 0.03568189710910831, 0.05131835324157562, 0.00402113253117672, 0.04323967120477131, 0.035678843701524396, 0.017744459178564802, 0.0400608194592808, 0.04652270521702511, 0.03408729571050831, 0.056459060071834495, 0.017798828493271555, 0.03102366260385939, 0.05244028036083494, 0.01857564422035856, 0.08996369436915432, 0.03669059369713068, 0.060614768149597306, 0.025770380028656552, 0.03575293294021061, 0.029592866344111304, 0.05245603933664305, 0.05974137144429343, 0.017507545284128616, 0.041055528047893725, 0.08387149484562022, 0.014712554369387882, 0.00864884483494929, 0.04620560883943524, 0.04409743446324553, 0.019804578008396283, 0.07353569660335779, 0.04518162825011781, 0.02944117984069245, 0.03395058786762612, 0.038169735576957464, 0.033361531261886866, 0.03597818281767624, 0.039232368913612196, 0.0217766229928072, 0.02467366387801511, 0.009112467457141196, 0.06930995692632028, 0.017433315249426023, 0.02006765451681401, 0.05047250845070396, 0.049905287101864815, 0.0023607999610248953, 0.03606119818453278, 0.042083345752741606, 0.021641691215336323, 0.04185770232496517, 0.014521470426448753, 0.023943728135366524, 0.03007598327738898, 0.025927354016208222, 0.031132557296327183, 0.029531380893396478, 0.05176387254946998, 0.0786185549306018, 0.0712790587650878, 0.07718797240938459, 0.011906430391328675, 0.007251594498354409, 0.0312693533487618, 0.03610814941514816, 0.019757774359147464, 0.09856124874204397, 0.0252303204366139, 0.05919135095817702, 0.08833884727209806, 0.036780173890292645, 0.0098428951376783, 0.0619542369885104, 0.005371326464228332, 0.029849318654409478, 0.052713482308068445, 0.06783437396266631, 0.03672675961362464, 0.007727884521175708, 0.02645112876780331, 0.03394940721669367, 0.06694069584565503, 0.10799280407705478, 0.04291303462481924, 0.03682740332026567, 0.026709175635395304, 0.012077837666895772, 0.06068569541509662, 0.02696230821311474, 0.024390913246731673, 0.02465532986181123, 0.06832950775112424, 0.04912529413455299, 0.055626965793115754, 0.03660176328516432, 0.04634249988677246, 0.044803131238690445, 0.04257534810208848, 0.016292536731011102, 0.05601770018360444, 0.029263885425669805, 0.04563901513548834, 0.02741595806687006, 0.053082262698028765, 0.038676153402775526, 0.0433121217813875, 0.08588662171470267, 0.04972530908084341, 0.058333228076142926, 0.0382708237240357, 0.055084429548255036, 0.05200678130079593, 0.051595107319631746, 0.05247157100321991, 0.0131034484365955, 0.007079808939514416, 0.06628362967499665, 0.020313465701682226, 0.06167113182267972, 0.11457044790898051, 0.07249278149434499, 0.031085212515400987, 0.007312175801156887, 0.04165908833965659, 0.07633794445012297, 0.06903202898268189, 0.019422196383987154, 0.02005732891016773, 0.023683521830077683, 0.014888349222019315, 0.02091966549466763, 0.03673055601705398, 0.02644468947047634, 0.018489066544654112, 0.03481764366318073, 0.03331282941092338, 0.03635380284062453, 0.019684187236375043, 0.07180846535733768, 0.05891941447875329, 0.03822778085512774, 0.044559370925916095, 0.04944631244455065, 0.021178492677531073, 0.07640471908130816, 0.06231678503432444, 0.051640979679567475, 0.08923316999737706, 0.007992902487915541, 0.00900553203453975, 0.03216569132304617, 0.049178776264722855, 0.11942942360682146, 0.08499094191938639, 0.17000196847532476, 0.13197126133101328, 0.10276861369077649, 0.13962438995284693, 0.08970659066523824, 0.29376220969217165, 0.23349809486951145, 0.16316480535481656, 0.16976435908249446, 0.0880180766273822, 0.09627571209732975, 0.20275117616568292, 0.1530259179749659, 0.13468131662479468, 0.06815259331571204, 0.1394154690206051, 0.10329768780086722, 0.08032639364578895, 0.07524012907275132, 0.17052304265754564, 0.08746137257133212, 0.1394890493580273, 0.16375800780951977, 0.13004823880536215, 0.1349248428429876, 0.13798836059868336, 0.11952695623040199, 0.15104391718549387, 0.11657102698726313, 0.15686084862266267, 0.09060799729611192, 0.19103820967887128, 0.22888473527772085, 0.11360636499843427, 0.10616153984197549, 0.11005366420639412, 0.16741622079695972, 0.14649911677198751, 0.14580964376883848, 0.07205286688570466, 0.08693032392433711, 0.0810970262225185, 0.17540077306330204, 0.23748804362756865, 0.14871023169585637, 0.1403083261102438, 0.18561257581625665, 0.15163968450256757, 0.1282214325453554, 0.1207000482827425, 0.10372380779257842, 0.14072468876838684, 0.11268936563283205, 0.08525591662951879, 0.1463136595806905, 0.17388055606612138, 0.10235074468489204, 0.12914312737328665, 0.1995319617646081, 0.13529999128409795, 0.16654781810939312, 0.11271588956671101, 0.10349090743277754, 0.159496455054198, 0.1363501056496586, 0.09870368681315865, 0.12084753465439592, 0.13027738008115972, 0.09708287699946336, 0.09220104824219431, 0.17187338162745747, 0.14290811946349485, 0.0877048648627741, 0.09201592353305646, 0.12504445016384125, 0.12207826147122042, 0.08618824410119227, 0.12029713418866907, 0.21249250987810747, 0.11098518422139542, 0.17601560721439974, 0.16766904294490814, 0.17663472970681532, 0.12339619360864162, 0.1068247128278017, 0.14864332814301762, 0.19516682385333947, 0.23578470359955514, 0.13217046564178808, 0.11629304476082325, 0.09172675226415906, 0.19580406323075294, 0.26691336610487526, 0.12093693842845303, 0.2277157822889941, 0.09112400282174349, 0.09917948913893529, 0.15279889372842653, 0.13369680302483694, 0.1790343823709658, 0.12107525100665432, 0.08908129350415298, 0.1539583065147911, 0.18485786845641478, 0.21079571092767374, 0.10885086589093719, 0.16956393340868608, 0.17798357589968614, 0.09190288638429982, 0.17007978287126335, 0.15641978728984082, 0.1558734037514244, 0.17961923884493963, 0.17381852439471654, 0.13915807354663098, 0.21413123980164528, 0.1191686490284545, 0.1569037998893431, 0.09951226306813103, 0.15193008391984872, 0.11395070116434779, 0.16681130682783468, 0.13971923557775362, 0.07235214154102973, 0.11463534299816404, 0.1570366977580956, 0.1422471177897283, 0.10069312434643507, 0.16111643026982034, 0.14189934145127023, 0.10225753432938031, 0.11924137441175324, 0.11776227663670268, 0.1685187994901623, 0.13331777336341993, 0.23917678158198083, 0.1514175728495632, 0.12462818250060081, 0.22693761118820735, 0.1607222014239856, 0.1130189708034907, 0.30687967581408365, 0.11987098705555711, 0.15452942943998746, 0.09798350331506558, 0.11325063622955765, 0.3193859447325979, 0.1110267648473382, 0.08876456692814827, 0.06382313956107412, 0.09948761189090354, 0.07871175850076334, 0.16916177927383355, 0.08671680252466883, 0.1451637191431863, 0.10364946071058512, 0.08942227770707437, 0.09567065563585077, 0.0737822830144848, 0.13097488693892956, 0.1175368537328073, 0.14553461995507988, 0.10460667006139245, 0.10553901788911649, 0.12084153640483107, 0.1463029251566955, 0.18028763655040944, 0.13215141237846442, 0.10379529824214322, 0.17558903938957623, 0.09981910338891403, 0.07497554791292974, 0.12091249759708132, 0.13183138812226908], [0.015093010650681598, 0.052497463899531534, 0.007483821412149284, 0.05903163060013737, 0.005767104490327516, 0.02230964448036892, 0.0434884832107595, 0.022867123762677823, 0.01148145882013653, 0.028579650712864738, 0.014462617691606283, 0.060325671519551954, 0.05566816643944808, 0.0191778101226581, 0.023006245493888855, 0.050957342077578814, 0.023915305999772887, 0.03230775619990059, 0.022168010473251343, 0.02743301134822624, 0.04143529052713087, 0.1099362572921174, 0.05584435144971524, 0.02377757865802518, 0.009627318625072283, 0.009345639230949538, 0.0371637972337859, 0.04869899772373693, 0.014070718765391834, 0.023266294039785862, 0.006626415656813021, 0.058266195601650646, 0.025402564854760255, 0.022068625449069908, 0.025692022804703032, 0.060337423746074946, 0.04469660124076264, 0.07304774171539716, 0.05041976931637951, 0.019251093601009676, 0.037072049121239355, 0.017839416761749556, 0.03426262237397688, 0.048460831932191334, 0.043056198728403876, 0.03397699645055192, 0.01997617951461247, 0.018552139767312577, 0.044477057842803855, 0.08540619178009884, 0.01871422821256731, 0.021966086933389306, 0.023925504381103174, 0.04693998729011842, 0.02639909361356071, 0.03688372511948858, 0.03566302026488951, 0.0056247402098961174, 0.05485198041424155, 0.03257477669311421, 0.12225221070860114, 0.01984052679368428, 0.0071942794934979504, 0.01495188384849046, 0.020957955225769962, 0.005633879228428538, 0.008941991470887192, 0.032477203357432566, 0.08652566599526576, 0.016914205426084142, 0.0463663775340787, 0.02877515022243772, 0.021458016874800836, 0.0325744306402547, 0.047609759029001, 0.010873848522481109, 0.0632811529295785, 0.07454136692519699, 0.04456987464800477, 0.048772846082491536, 0.009275530448316463, 0.04652067639731935, 0.015649416151323488, 0.0327471822633275, 0.021256181544491222, 0.04455010213756135, 0.03040800742538912, 0.020860666874796152, 0.03383334380175386, 0.01513754968930568, 0.02908081328496337, 0.042513672661568434, 0.022231475549883077, 0.07501745423568146, 0.03395729518628546, 0.025561435347689048, 0.030638159718364477, 0.0693637647532991, 0.019494699547067285, 0.005870426289870271, 0.03792733233422041, 0.03909466701692768, 0.04847624824781503, 0.040959376243076155, 0.07770872089479651, 0.010590287041850388, 0.013429705885105898, 0.029350887185760906, 0.02969845657103828, 0.014193415708307709, 0.025047986202740243, 0.05692054530871766, 0.04374567851690309, 0.02954888031152742, 0.01103457311234836, 0.007672943540715745, 0.11181257625243493, 0.022068944360528673, 0.008391853937480067, 0.03765076146061931, 0.031224261304097514, 0.02557801195819463, 0.04257033372830067, 0.07183996973825352, 0.023365538267950927, 0.04453617859897869, 0.012637048909839774, 0.09965622784303767, 0.05107495594503624, 0.04069263055654509, 0.029849963262677193, 0.016775869099157195, 0.05313559215781944, 0.07717779438410487, 0.025923175936830894, 0.01960603696560221, 0.04348991831232395, 0.013878212443419864, 0.02672094482529376, 0.03558177248175655, 0.023282020785180584, 0.01719199596638126, 0.044056732540151904, 0.03879894788510033, 0.014279923834172743, 0.05261573255328195, 0.04062478384003043, 0.037651704624295235, 0.12056055505360876, 0.04394470980124814, 0.04193457355722785, 0.030558041696037565, 0.055598714987614324, 0.021600580474893962, 0.05190728431833642, 0.03371296151142035, 0.014306868459763271, 0.05058224452659488, 0.041250481336776695, 0.02423761522264353, 0.06603162176907063, 0.02828230140065508, 0.017754572743017758, 0.023487908665889075, 0.08538852272821323, 0.028068043790491562, 0.032667685100542646, 0.03816793067380786, 0.09632861068738358, 0.0427086293431265, 0.05091518808954528, 0.04660649411380291, 0.053666844365320036, 0.01211039547342807, 0.04979738985587444, 0.05188109965196677, 0.039911188916968446, 0.043875553512147496, 0.018669943624575223, 0.06250524813575403, 0.04249600700235792, 0.028398693905078938, 0.017352267634123564, 0.030285165445613008, 0.031925683308924944, 0.05224064518032329, 0.014708354237622448, 0.05429330860663738, 0.053683339551623376, 0.06505520309188537, 0.018370429785656076, 0.03462821025667446, 0.05908989640218871, 0.05644631379150918, 0.0072961216626156655, 0.030510293186775277, 0.011159442215492683, 0.026728383265435696, 0.02241607609071902, 0.021747888731104986, 0.044385835594896755, 0.04102739259334547, 0.0067098741918536165, 0.05302122508042625, 0.02132732085218387, 0.03513636173946517, 0.04627355733620269, 0.014045087953231164, 0.01920335696611021, 0.05579998543752091, 0.028189610124432614, 0.03554993222600647, 0.026729664000283395, 0.07180965279362031, 0.05089640624022909, 0.027083825353266935, 0.05885456010167088, 0.007299859542399645, 0.029978481187884296, 0.057371167199952264, 0.009765269035207374, 0.024961951355050718, 0.03396387697596635, 0.05193813730563436, 0.03248616001967873, 0.0274567515921912, 0.012498553127183445, 0.023660241293587854, 0.023210696576695358, 0.007926645239682069, 0.01484327922974314, 0.12316465031887804, 0.028933387981461625, 0.035007161886564324, 0.020768019703349898, 0.026278623113674775, 0.045877913744854074, 0.043004694527813365, 0.03741893657882299, 0.04106547197859202, 0.03681883342298014, 0.05482979231913175, 0.030388560611754656, 0.04030568239146045, 0.08659345842897892, 0.05070364122678127, 0.05915948695370129, 0.007529335844862674, 0.047393482777157, 0.03249721335513251, 0.05070129010294165, 0.08978198947651045, 0.05674581236339041, 0.046473453752696514, 0.05345017795584031, 0.028604156005063226, 0.03522662725299597, 0.04616104944476059, 0.03665790866528239, 0.07425940848354783, 0.02051159962346511, 0.03533969493582845, 0.06568451039493084, 0.016657510539516807, 0.04571234780762877, 0.02952245476522616, 0.03133099486253091, 0.1049110269440072, 0.1250706280448607, 0.040969662833958864, 0.01870889662365828, 0.018355083019871796, 0.02270389028957912, 0.05762460681476763, 0.06326859324638333, 0.0527387068473867, 0.026028694917580912, 0.06516414867447955, 0.057036486587354114, 0.011664447840303183, 0.0733362887320774, 0.038357336938913376, 0.03981269955901163, 0.018578743429056237, 0.01598655984603933, 0.03148053380261574, 0.0193658440506884, 0.034723140698458464, 0.02821066845873637, 0.019515864750636474, 0.021737337511565005, 0.016347957774996758, 0.019855278144989694, 0.009751609277113207, 0.029879024917525903, 0.01342095447970288, 0.018782760249450803, 0.022465678696919764, 0.006946672311252249, 0.02405366437908794, 0.026369696083877767, 0.004846624240079629, 0.042158381547778845, 0.06427622453442641, 0.012738137056918016, 0.06433394750846283, 0.08119850791990757, 0.047186868863978555, 0.02394230830084, 0.04237813189891832, 0.04036686589409198, 0.027054532996511886, 0.05844449424850089, 0.011216032884216734, 0.03240385711459177, 0.011688911572231777, 0.01850588573142886, 0.05765350562121187, 0.10956883736486946, 0.06699468687708889, 0.024280027053984146, 0.014221093151718378, 0.0470885491397764, 0.03555675828829408, 0.024675728320809345, 0.06803847729627575, 0.029412939213216305, 0.029346157796680927, 0.003669117045189653, 0.04932473932525941, 0.04873054620942899, 0.027649613296879188, 0.05697436670639685, 0.01798729838005134, 0.03911532501557043, 0.018322506553626487, 0.062045615299471786, 0.04446640145033598, 0.007179277084235634, 0.048839254304766655, 0.011807692519921278, 0.03680195825706635, 0.08112691569008998, 0.07301654946058989, 0.12833700062973158, 0.023107023211196065, 0.021206970792263746, 0.03212014805259449, 0.035752417253596444, 0.024886216668944274, 0.041323332249053886, 0.023796964403507963, 0.13810063100286893, 0.18703052401542664, 0.07365393811570746, 0.13354500117046492, 0.09039594831743411, 0.10507156154406921, 0.10518966056406498, 0.14971104370696203, 0.11178655443446976, 0.10782295997653689, 0.14569788905126707, 0.1685223685843604, 0.09049860388040543, 0.12207045831850596, 0.08414536514984709, 0.14420334781919206, 0.15193689641143593, 0.11247707238154751, 0.10137837007641792, 0.10592947408024754, 0.09638727003974573, 0.18957596671368393, 0.10858741109924656, 0.12703962810337543, 0.1408785805106163, 0.06798281706869602, 0.08735666104725429, 0.19908868840762547, 0.10434025007167033, 0.10642973080809627, 0.1787807188395943, 0.1364399708275284, 0.09062280971556902, 0.11124018446675368, 0.12583191719438347, 0.16336607241204806, 0.09379690832325391, 0.19675319801483834, 0.13294793106615543, 0.2028911986521312, 0.1799794595156397, 0.10667472944727965, 0.1014452532732061, 0.18207854830792972, 0.13908929723714078, 0.12776537558862142, 0.08944446580218417, 0.11809227535767214, 0.1483216346906764, 0.24963821736829622, 0.16113629777516636, 0.05254140243466411, 0.12148117779621057, 0.13911607222897665, 0.11683394573628902, 0.2515051114772047, 0.15424307409141744, 0.054345966316759586, 0.17259353798414978, 0.11696578509041242, 0.23344791041953222, 0.10002047901174851, 0.07864936720579863, 0.07114583519952637, 0.10396063008478709, 0.14862188643642835, 0.05547652779413121, 0.18600525760224887, 0.17856571823358536, 0.1401991226843425, 0.1229627997215305, 0.08136198736195054, 0.09653381324772324, 0.07643774338066578, 0.08902239666453429, 0.11165472186569657, 0.11751742048987321, 0.1768628124679838, 0.16551453141229494, 0.13256572586085114, 0.1665865217468568, 0.16730073413678578, 0.11835615762642451, 0.13175233879259654, 0.14876733720302582, 0.16397623824221746, 0.1613189186900854, 0.07635318434664182, 0.1301949109349932, 0.149707949587277, 0.18208803422749043, 0.24991394685847418, 0.3750330630157675, 0.25763173986758503, 0.1396948897412845, 0.09865603329879896, 0.08046239920492683, 0.13921802890087875, 0.10718005483171769, 0.13473918209118502, 0.10638692203376975, 0.09807598085275718, 0.17666457167693547, 0.06769169161894492, 0.10580974657620702, 0.09558767080307007, 0.12620764917560987, 0.12385503255895206, 0.10975655407777854, 0.14515827729233674, 0.0957358085683414, 0.0803917772801859, 0.1991919885788645, 0.0943450221259679, 0.09314323482768876, 0.106626967367317, 0.24228159497891152, 0.13247805913644178, 0.1471746526658535, 0.06796606403908559, 0.12047239978398595, 0.12123729873980794, 0.14359523116477899, 0.07905237629477467, 0.10589328780770302, 0.10592905338853598, 0.09282456085618053, 0.23321479292852537, 0.1096348791782345, 0.11555589788726398, 0.12229442915746144, 0.16511123733861105, 0.2114393421049629, 0.1265103436474289, 0.08524806597935301, 0.043086481746286154, 0.19966196907418116, 0.13400944482002938, 0.2068469628159489, 0.12153195935700621, 0.16152790747582912, 0.09224800286548478, 0.22267862329525606, 0.17395674197801522, 0.15508814874504293, 0.09731487490768943, 0.10902911025498595, 0.1143962951110942, 0.19994508102536201, 0.0828846674412489, 0.13230136861758574, 0.12311017752758094, 0.09989616461098194, 0.13071627010192188, 0.1044530225917697, 0.10191323887556791, 0.1901836355349847, 0.06832849673394646, 0.10278792479740721, 0.12029921050582613, 0.18906935889806065, 0.10274573348994766, 0.0868891164926546, 0.13998850541455404, 0.11727495278630938, 0.13176016908671173, 0.13512441356267246, 0.0876108809773411, 0.19681706173079355, 0.0901646628709776, 0.10204273049852677, 0.12166782920914036, 0.0920668136594551, 0.12420987923230443, 0.16425122134387493, 0.2964213884302548], [0.071861017894532, 0.05553433558504496, 0.05023000342771411, 0.03174014808610082, 0.020882610697299242, 0.06971540874136345, 0.03362787322008184, 0.1369806003889867, 0.04260167186813695, 0.03621416033378669, 0.026727114404950823, 0.03201769605012877, 0.017148483211972883, 0.003371943940042651, 0.06003283616155386, 0.02116178036002176, 0.023260048124939203, 0.041452579599406035, 0.042112393836889944, 0.041886244900524616, 0.012602696378183151, 0.08531049798641886, 0.00894721194968692, 0.03351050701790622, 0.02863884950056672, 0.010071207752584346, 0.10671732109040022, 0.022466867829539945, 0.023023777142433182, 0.0162476804772658, 0.04165168212992804, 0.030097363915826594, 0.026470877529521073, 0.012577601608687212, 0.034033616805183034, 0.034978799122784815, 0.04217973504481571, 0.021349061114181365, 0.008678858983330429, 0.04809865368796246, 0.037144560766007216, 0.025926541470523392, 0.09155457400317703, 0.02099375134067876, 0.04784028451623661, 0.008401354275909918, 0.05655230435409716, 0.033566062072558064, 0.02745904164787914, 0.040311850274779966, 0.1001850033977202, 0.026733419691611613, 0.022893213434144855, 0.02183880563825369, 0.04627759801223874, 0.010415314064760293, 0.07821546441742352, 0.050540144821362834, 0.03336072719788977, 0.06560056882777385, 0.0353622596178736, 0.016988851063485657, 0.06653793781463589, 0.04818306005160723, 0.019703647620709877, 0.03527708650965776, 0.06969010617051806, 0.025282594774450575, 0.05301946767472795, 0.03859134670346975, 0.036611395089754036, 0.027860688577805246, 0.07763759685414177, 0.044464952778071165, 0.031615962606987784, 0.04334127843113882, 0.008696023374795914, 0.026778474416849867, 0.08571965460266386, 0.02246760743271027, 0.05647956540009805, 0.055503136544887505, 0.058828958975417275, 0.04046147742441722, 0.05611766196255173, 0.05418076678844435, 0.022134689314823066, 0.04845164456803884, 0.07561778809343066, 0.04884897431890879, 0.05183077610230871, 0.019077441222699623, 0.020787276527179138, 0.050178567080625465, 0.0320628627336451, 0.02639634724307273, 0.03647661428632481, 0.0042066762356885844, 0.029661625690226043, 0.026570927518020784, 0.04968226621193545, 0.07683427246021372, 0.019165764429739544, 0.003941291011869907, 0.011576930393597909, 0.07279591701392617, 0.06687594324882541, 0.039749500807374716, 0.04078830060149942, 0.03830309145684753, 0.05100545021040099, 0.013686254886644227, 0.015936982684901783, 0.04500854753756097, 0.0356222606663193, 0.057457185084266324, 0.017946491284029822, 0.09494310324745518, 0.04843750050557511, 0.06281887380672352, 0.01665608731231519, 0.03846884738387806, 0.05008446445156421, 0.06271957020674433, 0.024261876242235303, 0.03946553050939526, 0.04347836286095636, 0.061445118593318124, 0.031608909235468934, 0.02226367712553058, 0.03773193460490022, 0.035884175183517594, 0.029619936498680284, 0.020316985602091466, 0.017042141507512758, 0.03242189596806254, 0.026907287504790083, 0.06665985020143644, 0.020507984728153263, 0.03751095949805208, 0.01748594581814749, 0.01679569249972701, 0.009449288847723177, 0.005088382874548967, 0.03328360490767019, 0.03556962331224765, 0.01764489264626588, 0.02015037980995008, 0.006620780423483146, 0.04423799977770873, 0.01949027380240815, 0.008284832001663744, 0.022341287960963588, 0.08106679070208754, 0.021232152923143337, 0.039564291281359534, 0.07420006381081683, 0.03720213106966444, 0.03168967186606356, 0.03766338560464127, 0.00896028138231486, 0.02113453548268548, 0.037585666203605275, 0.04202217242813536, 0.026052216334002357, 0.024929851559656005, 0.016657858288713863, 0.0531103574404759, 0.053151313814201524, 0.03900169075599738, 0.024216450019074336, 0.028173287964559028, 0.03929532678531749, 0.021018970790984373, 0.05317052992592965, 0.010205340555070766, 0.02436535113624164, 0.025378517573699355, 0.028992111794650555, 0.004385733569506556, 0.07306245235460145, 0.040018193889409304, 0.07427239564380475, 0.0710296021508319, 0.010293476316811783, 0.08021166015948568, 0.01906354312918016, 0.04125648976436683, 0.005323842583623315, 0.03664948804570096, 0.020992317935451865, 0.020717068508799587, 0.005417749285697937, 0.02843367408162781, 0.042852655186184814, 0.08498522186917917, 0.030404380655714443, 0.05472435136990888, 0.022280939056405, 0.03002851636015943, 0.012191522816595222, 0.017966492800042033, 0.06806856353900262, 0.03042598521070821, 0.04057798867246934, 0.05770968832075596, 0.03200337556856019, 0.04927398490586451, 0.013430600703161742, 0.019533635582774878, 0.048086100790117464, 0.03163034076403294, 0.04752840607294014, 0.015702114573546817, 0.04383700593773808, 0.031713878602853844, 0.032566105015575886, 0.02094958210363984, 0.04132691491395235, 0.033003098530960936, 0.07289974644247975, 0.01722516106175525, 0.025652942580303977, 0.03865599412737148, 0.01810617432264345, 0.05205548654443451, 0.15103528622005666, 0.027986366833959306, 0.11242318991571665, 0.020023914453174387, 0.01834041309276862, 0.005025456809172673, 0.08323031996509858, 0.022211470641195774, 0.036159833427518606, 0.028680901708347455, 0.05068269145808049, 0.0418406202058707, 0.021973672954897796, 0.05965681241026946, 0.022920560091733932, 0.06555277960641043, 0.029053088344101394, 0.026213085112561072, 0.02928231782945139, 0.02629843294354422, 0.02109155198559165, 0.04270122652607305, 0.046466342705701075, 0.026170220359095504, 0.006677203578874469, 0.03942530695348978, 0.049474020422037156, 0.06216970578368221, 0.0576491222849914, 0.02996742445975542, 0.02956738735416106, 0.09406573032694203, 0.054757287459714074, 0.03621171760771956, 0.05700154881924391, 0.019579317952905382, 0.031141296827367375, 0.046616214127945046, 0.02661081180641694, 0.03779535727309329, 0.05443344983671393, 0.008907504928564387, 0.0312372213229537, 0.020984063556950008, 0.02846514114311763, 0.028379046923613975, 0.017581388553870574, 0.05092270625755191, 0.026040092609556656, 0.04167898977175355, 0.031620827703071494, 0.025914746835561733, 0.011843117136907364, 0.04287138275269951, 0.03805954488260405, 0.04081703316686409, 0.054590506944805384, 0.027896781551784704, 0.030467796538557326, 0.01914224131698055, 0.04003095713311008, 0.08601398952305317, 0.026943533149148737, 0.03539600994970117, 0.04307536734268069, 0.04460315339799438, 0.047219737100281885, 0.02565419447741338, 0.02943014007593904, 0.04798469373158046, 0.010694139370960849, 0.04103960622368114, 0.024502951252673353, 0.020941722971786345, 0.0249794813072575, 0.001011834282378134, 0.06371957476117782, 0.06563651761306183, 0.05564172053709626, 0.04447195865213871, 0.008652799845939236, 0.03053129045292735, 0.015130662558866399, 0.020652281985219036, 0.018198024215442792, 0.053999794713620625, 0.006509825529064983, 0.05898843506085021, 0.04123247641005686, 0.036352276136832576, 0.009284642325448138, 0.015073507857908095, 0.030830643139779568, 0.006437634068009044, 0.0302293457623039, 0.025200705775724988, 0.019542605815721408, 0.03207314932452781, 0.02027167133720858, 0.004167146905924061, 0.0296307218128017, 0.019863673319507922, 0.04302049421572259, 0.05753689259290695, 0.0437545096501708, 0.011249549121462872, 0.0159479172767273, 0.014215551216953566, 0.009669809336108821, 0.016147393001509563, 0.024053425195493867, 0.055632614597145996, 0.0130223830097488, 0.040489891078323126, 0.015397939199049557, 0.020079535664990544, 0.05511726046513234, 0.026871947704681327, 0.050367606936820915, 0.044866998347320726, 0.011249026649498513, 0.029293561154710393, 0.030816339621586458, 0.03619385856602873, 0.13320529939872877, 0.028988403600773642, 0.2082428043442113, 0.1261055025139025, 0.09440407502864089, 0.10199622370834861, 0.19959665329328605, 0.20138816216162272, 0.15534120159489767, 0.13178127152579172, 0.05286025621795228, 0.11237363650330476, 0.06471730622329883, 0.13241433112749032, 0.05823090499533074, 0.08463959648673024, 0.09195720989789281, 0.14684872515499592, 0.16702283333454812, 0.17427612841129303, 0.13309912223901066, 0.13468624278903008, 0.12759927021605627, 0.1808134876191616, 0.14671508089772292, 0.11054127982684545, 0.08797409398747341, 0.1029786067083478, 0.25593567373497145, 0.13310963953179972, 0.1753130384853908, 0.07262677858982768, 0.1442096581948655, 0.15715279509978636, 0.09338829453502383, 0.1038605733109372, 0.09483352662729365, 0.12134009679513318, 0.1551925345723118, 0.12689625365393503, 0.09013270387159926, 0.11167882342955895, 0.1309891226036208, 0.15065223963132926, 0.11793072974043232, 0.08454078143196446, 0.20215170404740743, 0.09673255615468536, 0.13888075628450938, 0.17074074383292878, 0.1385555887328727, 0.188664544905935, 0.3094276562333107, 0.19615789210157736, 0.21323241160384246, 0.15274048543402127, 0.17211242951452732, 0.08281796066356556, 0.17301990224846772, 0.12037143377321106, 0.1383221319743565, 0.10684611382228987, 0.08235173246690206, 0.06747556464480502, 0.11360380013606378, 0.09911854312356029, 0.08126266340592078, 0.12529697375638144, 0.15571613290480205, 0.09597756381013564, 0.12910215742886066, 0.10009507715169873, 0.07574589550495148, 0.18080345887158597, 0.15224047297877924, 0.133382397038596, 0.14660902587430819, 0.15632146756563867, 0.1189798398741654, 0.09965687923665557, 0.15878544534955705, 0.08257803068097148, 0.1015961119639022, 0.17560734626437935, 0.26049336631383213, 0.12346836259322506, 0.09372437971511058, 0.14567863222743782, 0.13858453503676824, 0.1482618964676346, 0.18049684246735914, 0.17326105359409535, 0.22495727959488118, 0.10794217857931342, 0.1644154539597886, 0.07545874627040965, 0.09285728660012994, 0.1667465745870556, 0.10853766091167927, 0.16182061391217367, 0.1415183168968984, 0.11766273554946695, 0.08118768528636013, 0.16742318256625108, 0.07741466417376484, 0.11997313371726445, 0.06149069579052074, 0.15696253388055734, 0.19693800381251744, 0.14869824876742704, 0.1574126197291272, 0.17146756340350422, 0.15138019914073603, 0.09539706353098154, 0.09297600987234286, 0.11259170408759799, 0.07764678421829428, 0.11073401769889252, 0.10457205799009119, 0.21636588631996087, 0.10616960083799702, 0.16847283552799905, 0.0766713290608355, 0.13234845894787992, 0.08189667295664549, 0.11180823362831559, 0.12027012849492685, 0.16450025726641926, 0.13110802908028873, 0.14089156767087324, 0.1605396755039692, 0.11762370621519429, 0.1454158356147153, 0.13106837549379893, 0.10683955238865954, 0.0921740425484521, 0.10321578862411634, 0.1979734618216753, 0.0725272578586425, 0.16400948645813124, 0.12942442085061753, 0.12387557859931674, 0.1392041460743972, 0.11202784148710114, 0.16335304453969002, 0.07267397748572485, 0.10880920384079218, 0.20877443653132233, 0.07993758629475321, 0.10816281102597713, 0.10556069708296231, 0.12588796418692383, 0.13677204586565495, 0.09205659492207424, 0.10224932405565466, 0.16035334978784832, 0.22358133271336555, 0.10592672601342201, 0.12406039796769619, 0.12040381346430097, 0.1175900644489697, 0.1194227739636387, 0.12462525122932025, 0.09484256471374206, 0.07440057769417763, 0.18791105890912668, 0.15500819017844542, 0.15131230492677006, 0.17129007221332618, 0.12433102487453393, 0.15084255513335976, 0.12777870201638766, 0.1201944989817483, 0.11366446116673094, 0.12943245470523834, 0.11850546247192792, 0.271305468997785, 0.08178614638745785], [0.049838332658899684, 0.03148348542994686, 0.03662773421300309, 0.017733594136578695, 0.009578558250463434, 0.014655842412529247, 0.03674624713936022, 0.031003883308065788, 0.029181307713900293, 0.05030041500659926, 0.056366473968539915, 0.037965934191431315, 0.05301447704966579, 0.021389165926458578, 0.06006567047110625, 0.08026948491377489, 0.04580785161150353, 0.03969640204949038, 0.030367580308978046, 0.06316138471343688, 0.06201698790703501, 0.061697974668017457, 0.023351214393707256, 0.03707157753940139, 0.028006276747744, 0.025934315785499554, 0.015339817585689681, 0.03942865552380681, 0.0164684978247221, 0.014079367542373282, 0.03691424223195229, 0.06182536283241851, 0.01558510969126863, 0.03953572156439934, 0.03017609433404037, 0.03233048373035022, 0.01020096824504435, 0.012295691512658127, 0.032160704090659104, 0.04327310601781521, 0.01853225869126618, 0.10146817418613605, 0.022922777204907367, 0.03125575889966317, 0.03924845019355416, 0.0713944775717599, 0.0522509826613324, 0.021121066562565308, 0.04429696447082928, 0.04017478280833789, 0.049351561814546585, 0.05695939143853528, 0.024382190679066947, 0.043605917266436985, 0.007341394367228661, 0.02403399195255978, 0.040344738867133856, 0.07257358144436564, 0.023306149490443722, 0.04865007195621729, 0.056813533550926616, 0.012272741761989892, 0.0491631428178932, 0.007245282426343432, 0.09673848655074835, 0.023691779601254633, 0.024172167127419795, 0.03722902819780367, 0.010022393095174005, 0.00729248471491571, 0.013203044654801488, 0.030778887881232158, 0.006364987140321838, 0.04891821203221168, 0.012298121516193663, 0.04265418030055506, 0.02182969800196588, 0.03310070240071841, 0.061317791497068744, 0.04700694851843374, 0.058507000894418786, 0.03167376700522644, 0.0328864956806813, 0.04804842174053192, 0.015909077932259867, 0.04002393090299197, 0.039274251487638266, 0.0814684359356761, 0.01474049304878073, 0.029955533133553605, 0.03457365943385022, 0.049096877087971995, 0.11740981840661593, 0.0263403596223465, 0.010195994583357657, 0.03514637013099023, 0.02441761190337794, 0.017384430194007497, 0.01031535058947546, 0.05996225494891405, 0.02391961300080376, 0.022721661121717522, 0.04692186701244541, 0.043925666715949774, 0.05055236862972379, 0.01582330771322761, 0.05741128219025476, 0.17143100393669947, 0.021848968396495496, 0.07897703855165414, 0.032464463862457445, 0.04409320379740425, 0.0950186513364315, 0.030657884731356586, 0.013305197253690233, 0.027835984814113805, 0.10893800335803203, 0.027741922897153666, 0.0027347433663505527, 0.022850369036729847, 0.039477004536560605, 0.016509235370904207, 0.010297804522061986, 0.027658466482535005, 0.029303311702928374, 0.017589325717251216, 0.06108719137098108, 0.03869857219979167, 0.020526495163461993, 0.021863584040797183, 0.033719892746635845, 0.03521776558565242, 0.10060365950422627, 0.036590370682201216, 0.03526271853063788, 0.010639084735885262, 0.030662871963743652, 0.02448647642242057, 0.010573423750299429, 0.017493087399218763, 0.01765534038921552, 0.019734724524563978, 0.0691709318863494, 0.02114831652891423, 0.016725243601415838, 0.011507260114220636, 0.026453771661700945, 0.03558098538113492, 0.029573171865195036, 0.010591513493896594, 0.020006077463871667, 0.02961356844753027, 0.07157416721539837, 0.02656069351360202, 0.05079088725947908, 0.008287496947949486, 0.03701432275452784, 0.06052237203610795, 0.08139246036963803, 0.09891595970839262, 0.014536550867238214, 0.02787388438758041, 0.03986837335729173, 0.031855047813483646, 0.04828347305634192, 0.033489455468952656, 0.03227649609159146, 0.03722497395106724, 0.039708921020584445, 0.07990332706166164, 0.06273837241211108, 0.010616327519528568, 0.005697192482849849, 0.03837482617901904, 0.019255071512556503, 0.03096946461924485, 0.05192128928112132, 0.02884170432974185, 0.03159053450716393, 0.0484001573308238, 0.009880233223416975, 0.07463839743286371, 0.08925471348421914, 0.040434756715382845, 0.10813359330807414, 0.07740025887531893, 0.05026493101779904, 0.03282504076404231, 0.03874413582629391, 0.009713084603260671, 0.046107641953442774, 0.029939862367297922, 0.030407752974757125, 0.052654931521309276, 0.03048808134293982, 0.009567761061979192, 0.025316957484132478, 0.026162931196657673, 0.06066079996526241, 0.02262054244056344, 0.05476545023598841, 0.033819861310933313, 0.025473799157355512, 0.018479290551372936, 0.0413237291920398, 0.009323599565375065, 0.042407902622861524, 0.047148643593702994, 0.028562246289636408, 0.017163276971716965, 0.05977542033152921, 0.02963051146694592, 0.05452092657131808, 0.03388700235102858, 0.06192803875144039, 0.09409688865499836, 0.010776252286242587, 0.11078331326799733, 0.03469363460317254, 0.02562925492280296, 0.024173656511785727, 0.07807969634554215, 0.023653494959164943, 0.06766769183533532, 0.05427469639107585, 0.03264073708227702, 0.0334358138830534, 0.04332138717706714, 0.011623596639505454, 0.04648238327354193, 0.05757569122527327, 0.02039805187710694, 0.052640672107892375, 0.026115554185318093, 0.07009717289890562, 0.02056476623485131, 0.07534239787076201, 0.06379878015390464, 0.05692895235759871, 0.06694450242710964, 0.037888727084334405, 0.0350743945288871, 0.020265627286529968, 0.011859198416849332, 0.07785629547600235, 0.020366491517052054, 0.023614385897027593, 0.05452907916956714, 0.021311358315870166, 0.014219937945849128, 0.06164526606776884, 0.036457564415676255, 0.023886836366727948, 0.06891217934233801, 0.04355950207848634, 0.03914090917844858, 0.0631729130234037, 0.05951234551944903, 0.06487340320433889, 0.03319116808207972, 0.02632673633550959, 0.05592236601348434, 0.025571087508329322, 0.021331705884741883, 0.04239808761381677, 0.09252285026013851, 0.0438159577814596, 0.05868261932794537, 0.05445757854197707, 0.057980830914207866, 0.027830142627603242, 0.06478490866720676, 0.020424687769263983, 0.07414001346166645, 0.03190996504521795, 0.044293032360396216, 0.02742109288062368, 0.0340241444563227, 0.10353102920843021, 0.01964784659711378, 0.04444093263841101, 0.014596049906685948, 0.02449259171927614, 0.039129533538860936, 0.015102147124707699, 0.02591035162497844, 0.08918989981923785, 0.014671094183410918, 0.029064840570624386, 0.024856271222233772, 0.007720381620207003, 0.03670617625383394, 0.08805554533111197, 0.06320622909281935, 0.03111252694257668, 0.036425574882222075, 0.02778373422500278, 0.0030645308932954712, 0.07052792049944401, 0.010877090223532702, 0.03899430490231939, 0.08611418200390679, 0.02198474495006459, 0.048332093483103175, 0.02884178914661918, 0.014068666196960424, 0.03901082383734839, 0.014966558864606279, 0.03297767382381218, 0.01769840870318668, 0.03210268595388957, 0.07196638759757791, 0.04318544947143112, 0.03474808703841908, 0.023593519248866608, 0.04415187672046678, 0.034563515335321426, 0.025260172584759336, 0.036285321693867445, 0.04113646370491811, 0.035334599137838395, 0.006906139597828899, 0.05458079371601343, 0.012127000073503171, 0.013027726473020656, 0.028182376941133822, 0.04471747297793627, 0.009000188571267893, 0.031109880656003952, 0.07353561517915555, 0.027636149465771656, 0.03441208328253456, 0.041893237203891785, 0.04174372201253261, 0.03765026952273079, 0.06859070980655295, 0.03467183666569846, 0.029729957559279034, 0.03887483184891088, 0.047510770947805474, 0.04808867243783815, 0.02749906842862921, 0.05357271120218294, 0.017481394544509903, 0.04618475067296198, 0.049060846878481765, 0.012337478243612816, 0.027691017503717115, 0.053732574052576504, 0.05752208695880004, 0.02998493066323655, 0.03571835479566029, 0.12686793160225662, 0.12317895383707114, 0.09787670190313033, 0.09399295744619199, 0.08336600661277771, 0.16306953903819832, 0.18936760218015738, 0.11256046433533941, 0.19138251191803388, 0.11481769249907561, 0.1568654626607895, 0.10397160199603864, 0.23716337819184574, 0.14416665264538356, 0.19722616406423704, 0.1868817484272378, 0.10502415908766644, 0.10085736374769892, 0.12862172749425682, 0.12396431740905557, 0.07520337283079113, 0.1610590669193438, 0.19798123783298902, 0.13737340431128228, 0.17681452791605676, 0.13256747648119926, 0.1424140509750162, 0.145627552111234, 0.1490795447358063, 0.06819080840796232, 0.2069852075406483, 0.08926386692162071, 0.17430895593549522, 0.09720657393336296, 0.12673639080354146, 0.11668854925249304, 0.1232604051807097, 0.11480201834014483, 0.11788574286869594, 0.16272645816206932, 0.13731012413544313, 0.16455520503222942, 0.09200797788798809, 0.1616862639784813, 0.13083879995558942, 0.18676746955939702, 0.08928603466067996, 0.09415381774306297, 0.10394650977104902, 0.14600849524140358, 0.13582249038985797, 0.16894319600292615, 0.0759499106290085, 0.10036719683557749, 0.11943030570234571, 0.11609523823218686, 0.17172392750424997, 0.18735220389706747, 0.11227078416517802, 0.11065786571374961, 0.12703339915190423, 0.25541602447628975, 0.16677296959928103, 0.23039252151335987, 0.11496387608349323, 0.1340007595717907, 0.08004866247730595, 0.19560969008931092, 0.13946649485400744, 0.17026430368423462, 0.12939715731356824, 0.11715321003326348, 0.06430546939373016, 0.1462151770080839, 0.1634419597685337, 0.14793163990335806, 0.127888380416802, 0.1366273279168776, 0.10647994239947625, 0.19163694897932665, 0.19469377637973853, 0.18577055233929837, 0.14065105414816312, 0.2032732545797314, 0.08079588559589215, 0.19801200261073454, 0.1029625932819077, 0.2063960355839559, 0.07574178358273846, 0.11093077928360019, 0.10239518194326333, 0.1492185087076255, 0.21414922097963945, 0.09161203913390636, 0.07530549235109772, 0.14402565306850842, 0.1688666029700211, 0.13508462426917894, 0.11135853454470634, 0.12943610522363866, 0.10053250153682061, 0.11120587095086064, 0.20583898547504628, 0.1484065872750112, 0.16623457920338425, 0.09542766546032258, 0.14988876559904643, 0.22429622363831314, 0.07293467063988958, 0.24242780570472988, 0.16223480525825704, 0.11796108739716665, 0.11103575543633529, 0.11164348532578774, 0.0920709730791194, 0.2266716118901968, 0.18642026319035462, 0.2481935348893915, 0.08384259603917599, 0.08157852145710162, 0.1263981003846441, 0.054395034576633146, 0.1342204963522298, 0.10751626893345799, 0.08741673853780542, 0.1327728826020445, 0.1453701023544584, 0.14311338987733635, 0.13957140993859085, 0.07855385661657367, 0.10418489269380059, 0.07242948096245527, 0.2098099488232817, 0.15397911039846285, 0.22509154810437135, 0.10979274713567325, 0.0965554720855185, 0.10330212541988917, 0.11829770861991815, 0.10838123144848005, 0.09814482501574925, 0.09160925035497972, 0.1339347381144762, 0.1723995448223182, 0.12379380155886922, 0.095080051970269, 0.1301481191601072, 0.12679298062409672, 0.09780965585793767, 0.09526643196919135, 0.15719934260206564, 0.1339904186981065, 0.1073380381401096, 0.13158410282007285, 0.11079737251358372, 0.10304721338408333, 0.11073591081159455, 0.14170696320278303, 0.16994058819753782, 0.21981498838535377, 0.1124587587213942, 0.15239744526999338, 0.09232576976397208, 0.11203893553465605, 0.09324992767402104, 0.09534211576517139, 0.10193872465086834, 0.08732287678867579, 0.21021782979369164, 0.13631981584642613, 0.15210604162088462, 0.10787141416221857, 0.07994202391377517, 0.1628265692187207, 0.1949312500655651, 0.144576881346958], [0.00889597661859755, 0.009572302157591497, 0.042940579753901274, 0.017990002342100655, 0.0062555640387082735, 0.013994006140689765, 0.03645898933921542, 0.04535467842859881, 0.006758764336284782, 0.07157973798790149, 0.03614848492933171, 0.009722218532780451, 0.001779071957571432, 0.026037653276164616, 0.018391761230304837, 0.04271146222682936, 0.02178185958681362, 0.04098843111257468, 0.02202693625752415, 0.027313414462176815, 0.006098589627072215, 0.0497419806862516, 0.053187927563807795, 0.03339330027145999, 0.015011688228696585, 0.015155049107436622, 0.055089026623006375, 0.04433459263028843, 0.029852965780134712, 0.05583036005763071, 0.037986721111727614, 0.018690934105377113, 0.04279705263408167, 0.04609284310468605, 0.022642630451757993, 0.001644011470489204, 0.05293407064995595, 0.0338631959498993, 0.012043101762953614, 0.007962254757460738, 0.03419594613036939, 0.06158926657267979, 0.014787481598822134, 0.00977324606252036, 0.003444053340769772, 0.060337220185569355, 0.05557296797633171, 0.0738509168316211, 0.0887059143611363, 0.01846107867147241, 0.018083122791722417, 0.03462668016020741, 0.046649157003100426, 0.033725222639207325, 0.03994821657293609, 0.02122676874777036, 0.03577856120786496, 0.021264388425541774, 0.04355227568053773, 0.054700785848711214, 0.05656781566462346, 0.08529976356242384, 0.030997342230486016, 0.08272747123347861, 0.046947128871189694, 0.05301983408363802, 0.04467524095837559, 0.037990442876304896, 0.038863286575568576, 0.01635219861886331, 0.05178915476426482, 0.018987272400408983, 0.00587675956610058, 0.04228213615715504, 0.005092208115716598, 0.055533334745892456, 0.01856889110058546, 0.10568140846277986, 0.024126455919550996, 0.05449834153322237, 0.028627039598567144, 0.06460214525993381, 0.06432719608502728, 0.03357800428888627, 0.0631396851635405, 0.05473657178559473, 0.06037892294781549, 0.010674969908515257, 0.046593188042087216, 0.028631378830011402, 0.05266986607706972, 0.033406263682991266, 0.009382048571881439, 0.04771275385948164, 0.012488314033752041, 0.039550299889275005, 0.01669255008787981, 0.028050652937963605, 0.03764668685783233, 0.051566693665725846, 0.03947233282295721, 0.04606818514210837, 0.02022049792243966, 0.02532806510238775, 0.020839515241927335, 0.028662662687046186, 0.08870909669037376, 0.03549888264387846, 0.07668436371854373, 0.019536337848486643, 0.02622356847859919, 0.03953298706827419, 0.03650948930797832, 0.039404173980333974, 0.03015198598482779, 0.07207114661910705, 0.07706226022647959, 0.05106527664299522, 0.011544076576163726, 0.0763987208317433, 0.012884575940136398, 0.03188025199675134, 0.013448962708935142, 0.08168247980730874, 0.07922483954046454, 0.027494411982063736, 0.07266234739550523, 0.030756587827844278, 0.05776403219039951, 0.009892941336147487, 0.049249364262712855, 0.06556903730545725, 0.07811932957598142, 0.012328748042429132, 0.06685125814484698, 0.02268970212233918, 0.016649188307513083, 0.016488706293915, 0.02518185946558203, 0.04642163742599743, 0.018926704668306878, 0.03186923937339868, 0.08610302010285002, 0.012059784394555857, 0.026047132410375134, 0.06035421748778649, 0.07188826786088091, 0.03822075801768473, 0.02283087302930653, 0.013687768019735813, 0.01760797355590122, 0.013884423583346819, 0.05366006919315883, 0.03137048899329134, 0.05859320876853807, 0.060372592216091495, 0.06087247574967997, 0.01775534966561411, 0.029446570801415613, 0.022017514798790216, 0.023621541048799242, 0.038550956906484704, 0.01983821129293314, 0.04450485742251788, 0.046715941812310896, 0.02831123922286289, 0.014883779288668717, 0.09874469746968575, 0.045393653480069976, 0.04213498905301094, 0.05570718898837056, 0.026123655893440758, 0.051981339630271704, 0.009678347851149738, 0.049581866777901135, 0.043558589448886256, 0.01881518234897937, 0.01197676987586809, 0.02440830409925963, 0.02775222814774939, 0.032457376564187665, 0.029733384161123207, 0.041599007456430366, 0.040200370363891125, 0.022686326410621405, 0.07399893246058907, 0.03116681652941874, 0.009900100728763002, 0.01229239468063627, 0.02034824062138796, 0.053547917532601526, 0.025353993621787856, 0.060294927097857, 0.0033773993615925845, 0.005484470058166022, 0.029394930893821374, 0.04642674679468785, 0.07573762416307415, 0.05353383793096457, 0.026775427794616138, 0.041296486011041064, 0.04560967528128198, 0.04260544791551573, 0.06795349757054023, 0.014771044087995375, 0.01283924131920295, 0.03329505518610988, 0.009226547005320234, 0.056461322986121686, 0.017320817536009208, 0.07409347274473735, 0.03615651199860232, 0.016756289971194098, 0.02733657116602574, 0.016870217697162713, 0.043769966677895615, 0.037090909002082686, 0.053926573999758275, 0.011759012721345892, 0.007288442342542112, 0.08112796741936888, 0.03380766125129802, 0.06524225484047617, 0.09906586166471243, 0.05283783742093614, 0.025319177989981005, 0.012685509032702871, 0.007875722034701278, 0.02590689618539597, 0.0372440747118422, 0.026773789132546102, 0.02595312986522913, 0.046494763144957166, 0.05461633538029023, 0.040148825451199494, 0.00678747909010521, 0.04622448229097894, 0.03266029924686466, 0.026687177530090724, 0.02974971310634698, 0.033312629243092876, 0.04290394904091954, 0.028384071475427066, 0.016851697083828703, 0.049057250642882924, 0.02082719304598868, 0.06021779802228723, 0.03300768203501191, 0.07007868281964745, 0.04720899249826159, 0.04468950715714267, 0.02011268718966416, 0.042011977439480166, 0.037087767384946346, 0.02274965069123677, 0.029209863860160112, 0.03508883714675903, 0.061983950036977015, 0.05433130317500659, 0.03801181333671723, 0.06514980444418532, 0.06498886950846229, 0.03321713561724339, 0.06075491277234895, 0.009498720123831714, 0.021916903322562575, 0.047207486150520186, 0.037848920827465396, 0.021672812223966633, 0.04183843871578574, 0.03857259878090449, 0.09979504932250295, 0.052538939352546415, 0.013088464687046195, 0.03424472262018493, 0.012834762988079871, 0.016759482478456836, 0.02097058106612946, 0.03840678857107248, 0.0025271606323907948, 0.0472964895889163, 0.09351253429693834, 0.05166166142693587, 0.03391225063907249, 0.08000920566597156, 0.012035723542794585, 0.0220175215841404, 0.07240900956094265, 0.008673503645695746, 0.014742918811472399, 0.04697186825796962, 0.03916465790410127, 0.046531746696148596, 0.03774499301133411, 0.021305760401966314, 0.018583924043923616, 0.0243845248395311, 0.024031584849581122, 0.03952029846342547, 0.06286787082042013, 0.025161466095596552, 0.052059934341481755, 0.01440097448149962, 0.030184548880372728, 0.03825467459059187, 0.01660571456886828, 0.05990444376532521, 0.07144356279500894, 0.0586054902523756, 0.012541954771482518, 0.02887202805972525, 0.025384678671668683, 0.012574220807956797, 0.037288701960018704, 0.06482102708624941, 0.06005591992288828, 0.042969766937728436, 0.010423916192459208, 0.044496711609619, 0.01916912317808185, 0.038022734357842376, 0.047912775804953914, 0.08069534027682883, 0.04620001092553139, 0.03685933517824326, 0.02045633633887129, 0.022919886645727923, 0.023347083811781237, 0.031253801326134374, 0.01692773711069354, 0.02409459021873772, 0.0178598779852369, 0.022070141974836588, 0.06071821081319025, 0.02830867775316749, 0.0487558962777257, 0.01031856345278876, 0.02958148731184857, 0.04221845903832998, 0.007461724919266999, 0.07275880114840609, 0.01786671083287469, 0.03413646914330976, 0.02230558344828231, 0.041747036656098704, 0.07047084891902548, 0.03376626043713518, 0.033962533476629427, 0.021142392918201428, 0.06079021016401904, 0.037838539241680076, 0.06380996241101197, 0.09805502090603113, 0.0744284519127437, 0.10247915743717126, 0.10823527178061859, 0.05799201995666538, 0.1987796699894326, 0.20237534918955394, 0.09867315273731947, 0.06917834148875304, 0.20241887042565004, 0.1243433877825737, 0.06778365347002234, 0.11515487012054239, 0.11773787651743207, 0.10534531649734293, 0.1901411321014166, 0.07180270459502935, 0.12771805455642088, 0.13095286169222423, 0.08913741513554539, 0.15096290010426724, 0.1427739052368062, 0.1064940762839147, 0.08421816517199789, 0.10575126364294972, 0.11842572103653635, 0.10116036356027637, 0.14096841854708536, 0.1814176416290658, 0.09757821434842688, 0.16558414910520824, 0.08682450638817889, 0.12075726235551493, 0.07688407014523234, 0.14577806474907057, 0.17930713987776212, 0.17644313855894975, 0.08514710675392832, 0.10636144304381949, 0.13903179817966052, 0.08785415613757712, 0.17097118789596216, 0.12035390042832919, 0.15557194421333925, 0.07365099327372653, 0.13524304862533296, 0.10387843235262803, 0.20093320443161897, 0.1758342890867165, 0.10865691344120673, 0.06999444269708224, 0.13593212807817118, 0.16563003164316925, 0.115114904407944, 0.1563053320028952, 0.121098307626588, 0.12690065056085587, 0.09354841522872448, 0.17951105322156632, 0.11525327126894679, 0.12934201955795288, 0.2527127409619944, 0.13167988482330525, 0.1817325633019209, 0.1573235552225794, 0.12642046489885875, 0.12865861265787057, 0.10940470652920858, 0.14691497731421674, 0.10718002769031695, 0.13377929931240423, 0.09328777635736124, 0.17704841893698486, 0.22997505962848663, 0.1552531820322786, 0.18154945384178842, 0.08788993528911046, 0.23054937166827066, 0.13173342123627663, 0.18259237573615142, 0.1420260239392519, 0.13388611429503985, 0.28302702573793276, 0.14104506586279186, 0.15365254506468773, 0.24189431433166775, 0.10745473937796694, 0.12094426660665444, 0.08329009890024151, 0.08005755807140044, 0.18501128522413118, 0.12393318622239999, 0.07001474446484021, 0.11740962841681071, 0.1088988043900047, 0.19832958414086274, 0.1454375215939113, 0.06180783627288682, 0.11387576375688825, 0.1168584544211626, 0.1007755934926016, 0.0899729902989098, 0.06934812452111926, 0.08061258614595447, 0.07715264787631375, 0.15682736970484257, 0.2049550036234515, 0.1208029141915696, 0.27517762407660484, 0.07962921927017824, 0.20323662725942476, 0.11036361221756254, 0.10976692887821368, 0.10778488737664052, 0.13464409219367163, 0.14024659299424716, 0.14664654886083944, 0.11094077410442488, 0.08601205569825002, 0.18634649286312716, 0.14255429059267044, 0.08417701202311687, 0.13326008431613445, 0.16411035747400352, 0.13358701605881962, 0.10094302200845309, 0.12961081442024025, 0.11920699982770852, 0.10108058819813387, 0.1014161848330072, 0.12928177921899728, 0.15554903687110969, 0.1609836681080716, 0.12554326839745045, 0.22669800690242223, 0.08684932719916105, 0.10210412434701409, 0.08975391169743878, 0.10877071054918425, 0.2725456953048706, 0.11707386214818273, 0.08295419013925961, 0.12906160817614623, 0.09542166721075773, 0.11439929423587662, 0.18550941135202134, 0.1569685728422233, 0.12174506006496293, 0.07363120719258275, 0.09386831056326628, 0.10283669110919748, 0.1817144871290241, 0.15153672359883785, 0.10599542768406016, 0.08920954340802771, 0.09467035252600908, 0.12780975177884102, 0.13057186427925313, 0.13360426441899367, 0.13590288321886743, 0.15358861349523067, 0.12169885183019297, 0.1191309496228184, 0.14673957601189613, 0.130911118217877, 0.09918723122349807, 0.12812641050134385, 0.18727776860552175, 0.2071382850408554, 0.0940946698454874, 0.2197703000690256, 0.09807850500302655, 0.09009697221751724, 0.09457399376801082, 0.08563709046159472, 0.16209833829530648], [0.04323665172393833, 0.07410714522536312, 0.03172998023884637, 0.018544387504724518, 0.017134069431839243, 0.038388630973973444, 0.018660103170467273, 0.0564413876272738, 0.020613692002370954, 0.013670066737436821, 0.03424048177631838, 0.035978851174669604, 0.030358162242919207, 0.07006983472300427, 0.018951678149668232, 0.011868637687127506, 0.07623834229473557, 0.0827923866787127, 0.04068386388410415, 0.052514786898557625, 0.02499921480193734, 0.024885324395394752, 0.02843154687434435, 0.02143400691316596, 0.06764171751482145, 0.009393182483368685, 0.045062619993197064, 0.013563504509095634, 0.029835272979523455, 0.010957249806129506, 0.019316305905314426, 0.029465922620147467, 0.013101010799541004, 0.05000395287892648, 0.010046261412623738, 0.04653527847092066, 0.024322255680869733, 0.025378412400771464, 0.007815420627593994, 0.06037281613264765, 0.036362467732812674, 0.057253706002874036, 0.05292919537584696, 0.04035228417654123, 0.021362826893372194, 0.0453693415703518, 0.11014384829572268, 0.010383384751289018, 0.08128827131752457, 0.015295359971267837, 0.03153123054653406, 0.016167579418314353, 0.02894556089969618, 0.04203099677605288, 0.030549020572964634, 0.04591036468212094, 0.02232938815307404, 0.05100793704124434, 0.037730163628501553, 0.03423855812954051, 0.035115924264703474, 0.021667977661958764, 0.037453606325600824, 0.035055164846458604, 0.045952223507421355, 0.06979564550731863, 0.06574494072369166, 0.059645114466547966, 0.05904230395598071, 0.08636553173086473, 0.008700163286578442, 0.02600330244084554, 0.0071288865292444825, 0.007326900011061558, 0.034215155456747325, 0.028364064870402217, 0.027127002232841084, 0.03584454534575343, 0.024552737063329135, 0.06289844560836043, 0.09516252790178571, 0.08571827039122581, 0.027722031643081988, 0.11517754676086561, 0.02225485277761306, 0.006979313238324332, 0.01475963621799435, 0.0362716390352164, 0.01597473637333938, 0.020102612640974776, 0.07580224105290004, 0.11159929234002318, 0.041373784720365486, 0.06409821765763418, 0.019518701027014425, 0.05591628973239234, 0.027251696613218104, 0.018129963760397265, 0.016528841640268053, 0.03081424973372902, 0.013592701870948076, 0.1021616030484438, 0.04112471147839512, 0.023342932873804654, 0.036239581648260355, 0.031430926107402356, 0.040881304003830464, 0.034165883636368174, 0.032362876992140494, 0.00469198398890772, 0.03325762380180614, 0.010267679263571543, 0.0402271894605032, 0.030351756872343164, 0.030165614360677342, 0.054894341355455775, 0.028506691234984567, 0.005224734910630754, 0.062069615083081384, 0.025689461335007633, 0.022530144612704004, 0.018103131093084812, 0.014678798948547669, 0.00951199057245893, 0.06456119567155838, 0.03824031000424709, 0.03893710779292243, 0.048002403495567184, 0.02596316539815494, 0.019363808445632458, 0.0636392090735691, 0.03847927985978978, 0.02854680283261197, 0.0487374197691679, 0.0592295660504273, 0.04676083708181977, 0.0299253145764981, 0.088580555016441, 0.0570168158571635, 0.05340810199933393, 0.001064985732747508, 0.04469058263514723, 0.027060129214078188, 0.029727019502648284, 0.00653599323205916, 0.02580393528166626, 0.03050658160022327, 0.022302950732409954, 0.021312170861554996, 0.0383015511823552, 0.07868729731334106, 0.04748661170846649, 0.010227381916982787, 0.014842816129592913, 0.03665441760261144, 0.06958407828850405, 0.006745756395892906, 0.015260179626888462, 0.020237152564472387, 0.017453420242028575, 0.030297077127865384, 0.06328411134225981, 0.06628874582903725, 0.041946539522281716, 0.052287528557436805, 0.025337718959365572, 0.04974372452124953, 0.029618009459227324, 0.0545253845463906, 0.05500614696315356, 0.019378788802506666, 0.004944388837819653, 0.01215027891365545, 0.03854810705940638, 0.031671154645404646, 0.04781000489102943, 0.031014624517410994, 0.06021188119692462, 0.010070594526561243, 0.03690047814909901, 0.014304186550102063, 0.01840173908775406, 0.009029474990841533, 0.07230157711144004, 0.07508545022990022, 0.03316776540928653, 0.0991040835423129, 0.05387616563322289, 0.048369562186832936, 0.04365763859823346, 0.03177614436884012, 0.011919214839248784, 0.07790801341512374, 0.06440570937203509, 0.016957741929218173, 0.03875014425388404, 0.08890701178461313, 0.05577650473320058, 0.02973157586529851, 0.05445069480421288, 0.01915894854547722, 0.04599735965686185, 0.022218870065574135, 0.030496047344058752, 0.04535465128719807, 0.026485888420471122, 0.03291595767119101, 0.008432029995934238, 0.010752311026278352, 0.05571259351979409, 0.05113087062324796, 0.02069332487215953, 0.0037206742563284934, 0.029125345538237264, 0.023556422043059553, 0.038849441068513055, 0.009181409159542193, 0.023744527217266814, 0.09232503694615193, 0.03169231815263629, 0.07007220959556953, 0.0307468372796263, 0.02833513722621969, 0.07128042262047529, 0.0405200248185013, 0.02993611346131989, 0.018999448711318628, 0.02467512442464275, 0.0483067739488823, 0.06383700203150511, 0.054987748486122916, 0.035510695938553126, 0.030665620030569177, 0.010179233920228268, 0.011289517378567584, 0.01266123868325459, 0.02604978039328541, 0.02053713289621685, 0.04890137757839901, 0.05966745862471206, 0.05950199786041464, 0.04619689644979579, 0.03511152735778263, 0.06682336357023035, 0.06482915593577282, 0.014448239534561123, 0.011778308560938706, 0.023548647728083388, 0.035022880150271316, 0.026667450820761066, 0.021461575790973644, 0.029371769100959812, 0.03301358189699905, 0.006111273991077074, 0.026688261489783014, 0.07586314635617392, 0.08241420518606901, 0.0648495526984334, 0.01950910993452583, 0.08352047510977302, 0.010101813074600483, 0.042424730291324, 0.05389647079365594, 0.03643622788201485, 0.033801476404603036, 0.07560110291732208, 0.051502748525568416, 0.07872592631195273, 0.034489938390574286, 0.053335790522396564, 0.01071936560661665, 0.05721781150038753, 0.061073281403098784, 0.059755505328731875, 0.06166474002280405, 0.04461205577743905, 0.034900228160300424, 0.06243731999503715, 0.005635499654869948, 0.008123523023511683, 0.10905199045581476, 0.02342976669647864, 0.04830688590716038, 0.01125027345759528, 0.046004212860550196, 0.027463061967864633, 0.05228674824216536, 0.044973721727728844, 0.016476022778078914, 0.043771140543477874, 0.04654557184715356, 0.07799707792167153, 0.03196572366037539, 0.02083158995290952, 0.012761315813155046, 0.03572204941883683, 0.02439996151120535, 0.04225507278793624, 0.054020900545375686, 0.02085536581996296, 0.057797511108219624, 0.06581202069563524, 0.05317850949774895, 0.0064565601060166955, 0.04201531922444701, 0.04641124905486192, 0.07261520956775971, 0.03758477053738066, 0.07041997914867741, 0.054760764951684644, 0.06482215345438037, 0.02740025507020099, 0.015546175351898586, 0.01912883176867451, 0.022325793613812754, 0.03423482618693795, 0.024338213128170798, 0.08417658454605512, 0.03254609841055103, 0.056611001025885344, 0.06421630989227976, 0.023145738723022596, 0.05355529999360442, 0.039218503050506115, 0.03718646030340876, 0.06646445925746645, 0.013567702096354748, 0.05444305789257799, 0.044279994310012886, 0.03610990682084646, 0.032877603479261906, 0.03809957844870431, 0.009435442492498882, 0.009828969902758087, 0.042387122487915416, 0.03036999928631953, 0.0714608450819339, 0.041323539202234576, 0.05288983016674008, 0.04811750339078052, 0.028124869401965822, 0.05989754306418555, 0.006255178970085191, 0.0977554205538971, 0.06592598065201725, 0.03819937398657203, 0.016710426092946103, 0.027145841757633855, 0.004982215892856142, 0.053394643257239034, 0.0672176331281662, 0.04110525109406028, 0.1119789666097079, 0.19835885614156723, 0.07370089273899794, 0.05610915991876807, 0.07282083960516111, 0.13995974910046372, 0.19756769788052353, 0.15398889487343176, 0.20703018084168434, 0.16420301821615013, 0.23688501598579542, 0.12230255800698485, 0.11684771999716759, 0.19607264096183435, 0.10608143199767385, 0.08579748256930284, 0.2969566439943654, 0.17097185286028044, 0.07660434408379452, 0.14347002788313798, 0.160750414910061, 0.1431188452988863, 0.0813586353989584, 0.1185604916619403, 0.12437803378062588, 0.08239228850496666, 0.1821759045124054, 0.1278694085776806, 0.17258603338684353, 0.06298492489648716, 0.12696661773536885, 0.07523820203329835, 0.11607400008610316, 0.14864001689212664, 0.1269854810088873, 0.14770452066191606, 0.11301836012197392, 0.12418477343661444, 0.12244369329086371, 0.24008243584207126, 0.17682047188282013, 0.17802564507084234, 0.12186222949198314, 0.09322149705673967, 0.14950038572507246, 0.17361001058348588, 0.25290023375834736, 0.0734535531540002, 0.22973502108028956, 0.11158898539308991, 0.07651301327028445, 0.06983664937849555, 0.12477922439575195, 0.13901326060295105, 0.1417833391044821, 0.12349690177610942, 0.09108811510460717, 0.11897533440164157, 0.13816883734294347, 0.11238219282988991, 0.09237832908651658, 0.05742777059120791, 0.1497335574988808, 0.12884932171021188, 0.10063970328441688, 0.18346109054982662, 0.19431997143796512, 0.12464729004672595, 0.17724135358418736, 0.20718795380422048, 0.17406943307391234, 0.11408419614391667, 0.1285587323031255, 0.08349964408470051, 0.09381094042743955, 0.14522041752934456, 0.10655249136367015, 0.10396742900567395, 0.11622280281569276, 0.16049429508192198, 0.1794840203864234, 0.19840798207691737, 0.1276689286210707, 0.20443372588072503, 0.10818007974220173, 0.10899183832641159, 0.07245603203773499, 0.1995506893311228, 0.12227323172347886, 0.18149386825306074, 0.13852855589772972, 0.24580180751425879, 0.2527755733047213, 0.20078702084720135, 0.12224286049604416, 0.12240298118974481, 0.1272238775023392, 0.16707748254495008, 0.13565557077527046, 0.1009836798267705, 0.12280597670802049, 0.2037062006337302, 0.10070267811949764, 0.19640935717948846, 0.1641255702291216, 0.08626515604555607, 0.13871515302785806, 0.1037075568788818, 0.1469404630895172, 0.10288403249744858, 0.0862000777519175, 0.15709136053919792, 0.09911393587078367, 0.1454325547175748, 0.1469088297869478, 0.14824350816862925, 0.12865836838526384, 0.07612272671290807, 0.11639200230794293, 0.08759669281010117, 0.13476149232259818, 0.06280630055282797, 0.09597933478653431, 0.10612043419054576, 0.1579981275967189, 0.1194430078778948, 0.13433088042906352, 0.06367656921169587, 0.09723607663597379, 0.10506350733339787, 0.19281686709395476, 0.13866893122238771, 0.11420931800135545, 0.14306298829615116, 0.09288577150021281, 0.06828556582331657, 0.21230986182178768, 0.12634140199848584, 0.13001881752695355, 0.13781789903129849, 0.09857612222965274, 0.18703850358724594, 0.10196696527834449, 0.1350974485810314, 0.19509312137961388, 0.05848994252404996, 0.13066257084054606, 0.09790499002805778, 0.14496269635856152, 0.16389287342982634, 0.0951277461967298, 0.13838075739996775, 0.08417129197290965, 0.10054654721170664, 0.08531154293034758, 0.14254690813166754, 0.1049774894490838, 0.07378775879208531, 0.09611867873796395, 0.16030692442187242, 0.10103134691183056, 0.13394239198948654, 0.14164873132748262, 0.17684454630528176, 0.1366742146866662, 0.09276757748531443, 0.11208417346434933, 0.1620668406997408, 0.112794518204672, 0.1776644065976143, 0.09919607253479105, 0.0852952173777989, 0.07884433067270688, 0.13892534960593494, 0.17031980784876005, 0.1355806062264102], [0.029163937217422893, 0.011239020802479769, 0.02399350207165948, 0.043410777380423884, 0.018025164026767015, 0.02570321354349809, 0.040266744659415314, 0.044186505755143504, 0.03317143628373742, 0.0453510211248483, 0.011964549460182232, 0.02704015653580427, 0.05863597683076348, 0.07261437496968678, 0.08816843320216451, 0.010397143745129662, 0.04947472609845655, 0.040445813443511724, 0.04359468411920326, 0.04124098184651562, 0.03775314221690808, 0.027634217337306057, 0.019198003324813077, 0.04759667348116636, 0.030459175751145397, 0.021416409107457315, 0.04206732893362641, 0.04731680492737463, 0.033326009953660626, 0.04721597123092838, 0.026061115320771933, 0.06385178052421127, 0.04485322069376707, 0.030258349741676023, 0.017797406962407485, 0.019370631115244966, 0.06510588287242822, 0.009677728687945222, 0.02822493974651609, 0.06408155283757619, 0.017101893301254938, 0.039676687214523554, 0.030444200483283827, 0.0395593413683985, 0.11456605100205966, 0.024446502228134444, 0.10551336248006139, 0.0606604539124029, 0.038057119119912386, 0.023122936553720917, 0.08568076097539493, 0.024474082980304956, 0.061514838066484244, 0.028344721533358097, 0.07387374274964843, 0.04252917718674455, 0.04977212460445506, 0.08197906067860977, 0.050379973237535784, 0.034153703932783434, 0.009863171460373061, 0.015050703992268868, 0.01813741068222693, 0.01209986800261374, 0.03428330412134528, 0.056746372154780796, 0.04472889272230012, 0.03194455336779356, 0.015363345787461315, 0.010635641170665622, 0.028506932114916186, 0.05094249573137079, 0.03364479588344693, 0.03700217019234385, 0.05432486727035471, 0.04401755392817514, 0.033048288963202915, 0.016212559504700557, 0.04847207525745034, 0.02060337148473731, 0.031696480964975696, 0.035668641927519014, 0.006938276712649635, 0.02285878626363618, 0.014957047499982374, 0.01899457852622228, 0.012991945625149777, 0.0260957714968494, 0.05573970777913928, 0.09136122544961316, 0.047175140386181216, 0.02173638077718871, 0.016130948705332618, 0.024064312289868082, 0.04209407339138644, 0.03491363601226892, 0.012991212807329637, 0.07057520081954342, 0.10663791213716779, 0.08044888278735535, 0.02802582873430635, 0.016989700928596512, 0.014055605246020215, 0.056154448738587756, 0.06398252065160445, 0.04405423213860818, 0.016388788619743924, 0.026788701635918448, 0.05149045007835541, 0.011665463098324835, 0.0182406429999641, 0.03282813149105225, 0.06417483783193997, 0.02460927769009556, 0.027816997707954476, 0.025779689529112408, 0.02474745286495558, 0.048782701803637404, 0.02206004028474646, 0.01791908186195152, 0.07041965345186846, 0.019011842153434242, 0.049775154263313325, 0.04684788294668708, 0.038112233126802106, 0.022636082588828037, 0.027469309579048837, 0.02887264552659222, 0.014769067854753562, 0.0411713607609272, 0.06215683397437845, 0.013527575231689428, 0.0779182253671544, 0.03639505776975836, 0.053336031402328184, 0.04495503826599036, 0.019864553718694618, 0.039177553462130685, 0.013471977768598922, 0.03706279729626008, 0.009701956628954836, 0.10577845932649714, 0.043449260494006534, 0.026360145703490292, 0.02256764385050961, 0.0463637651742569, 0.03968623759491103, 0.06897960536714111, 0.06987184498991285, 0.05517268320545554, 0.02666919635209654, 0.0075044471803786495, 0.04699785275650876, 0.03182901921016829, 0.011561096778937748, 0.03034681035205722, 0.02811204000110073, 0.01711294494037117, 0.03909053134598902, 0.08708369319460221, 0.036234058373208554, 0.016312882603545274, 0.019612732409898723, 0.018576414357604723, 0.054968026865805895, 0.10691746856485095, 0.02101733721792698, 0.02387022752580898, 0.03389833388584001, 0.0426138956764979, 0.03813823798139181, 0.04847958664010678, 0.022087378460647802, 0.046753692108073404, 0.046115411179406304, 0.03085356405270951, 0.02753336837382189, 0.052456025765942674, 0.06416117892201458, 0.06392132357827254, 0.016423683979415467, 0.016450854217899696, 0.0451016120080437, 0.023146033885755708, 0.012603671772272458, 0.012566785760489958, 0.028256333865491406, 0.07466747944376298, 0.03508096953321781, 0.019718398972015296, 0.04154618689790368, 0.04694962248738323, 0.04669655606682811, 0.023862264917365143, 0.06951686939490692, 0.0368483700523419, 0.029478539978819232, 0.064726554655603, 0.0455691022798419, 0.026358734350651503, 0.021840288237269436, 0.024297746995996152, 0.03456810223204749, 0.038741777917104106, 0.042618550426725826, 0.027009200071915984, 0.01923244067334703, 0.019152841730309383, 0.0031087217586381094, 0.028254569674442922, 0.07831920563642468, 0.028697576706430743, 0.061107092803078036, 0.044667220674455166, 0.052583933009632995, 0.04375921868320022, 0.01644390432297119, 0.02897407972652997, 0.06862281129828521, 0.04406250348048551, 0.03025683660858444, 0.03559724647285683, 0.059579751188201566, 0.02654871397784778, 0.05021160834335855, 0.03239770958732281, 0.05781308348689761, 0.028651806126747812, 0.050424200150051286, 0.03382461444873895, 0.0610013838325228, 0.018012297306475893, 0.05578017560765147, 0.02622399595566094, 0.05887203237840107, 0.08670914186430828, 0.023769873892888427, 0.018897140897544365, 0.03860007605648466, 0.02754343274448599, 0.0370144923882825, 0.02190897803354476, 0.009649588144384325, 0.03420056356117129, 0.043459679399217875, 0.006733457524595516, 0.07756548893771001, 0.040346642157861164, 0.052617272827774286, 0.03518359795478838, 0.04702359298244119, 0.03849821098681007, 0.02473268624661224, 0.030530354074601616, 0.09140041763229029, 0.054011787820075235, 0.02623168545375977, 0.04325241069974644, 0.002454860181647486, 0.04262044693210295, 0.049578633558537276, 0.04863439779728651, 0.05058742853413735, 0.035114004010600705, 0.0113263838824683, 0.07030964935464518, 0.03313025599345565, 0.060954008517520766, 0.026913295932380215, 0.03172721181597028, 0.021830941417387555, 0.030225593463650773, 0.046253696616206846, 0.05273788582001414, 0.08612046523817948, 0.062236996101481576, 0.05065887827160103, 0.050124654080718756, 0.016668494325131178, 0.0257528840032007, 0.06984045595995017, 0.027167892449402382, 0.011339545765492533, 0.031288504999663146, 0.074479511672897, 0.04951934656128287, 0.024724952643737197, 0.028118173957669308, 0.02709190670533904, 0.07961887161114387, 0.02705724544024893, 0.015314367433477725, 0.022556286870634983, 0.006987031998245844, 0.06014379020780325, 0.010810588702692516, 0.08880295165415321, 0.037018095409231525, 0.008860808148581003, 0.07198566477745771, 0.016460871091112494, 0.041524853756917376, 0.07547586570893015, 0.022976262727752328, 0.07693095691502094, 0.060887166032833714, 0.06311515612261635, 0.03847795671650341, 0.03881667800513761, 0.05024068696158273, 0.07715822543416705, 0.01574177833806191, 0.01266796890247081, 0.06237672681787184, 0.03567626866112862, 0.018279740187738622, 0.07020704128912517, 0.05657700981412615, 0.00964302840709154, 0.01922751620544919, 0.037912374029734304, 0.009463253098406961, 0.047949409910610745, 0.05316846378679786, 0.05716802060071911, 0.029780084333781685, 0.029997011979243586, 0.01573752222715744, 0.022851831279695034, 0.029089023558689014, 0.01163308255906616, 0.01949870290367731, 0.0708727180691702, 0.01525246977273907, 0.0570780129304954, 0.03978666756302118, 0.02298028813675046, 0.012797399457277996, 0.05139304298375334, 0.025804411952516863, 0.04418929453407015, 0.03831825332183923, 0.019466535254780735, 0.04119719937443733, 0.018025669535355907, 0.08505356391625744, 0.026599490449630787, 0.03134575639186161, 0.01928606190319572, 0.0054374726023525, 0.0039280968984322885, 0.02508597059308418, 0.15319403181118624, 0.11336564791521855, 0.16934516014797346, 0.1508298258164099, 0.08494212132479463, 0.07744565286806651, 0.10330898540892772, 0.08303057961165905, 0.0879128562020404, 0.1446875368377992, 0.0558245416198458, 0.21950962048556122, 0.24753036190356525, 0.14846445274140152, 0.1908309172306742, 0.12975345605186053, 0.07991060774241175, 0.09592915033655507, 0.16740121160234722, 0.11994029262236186, 0.1266290329928909, 0.17067732795008592, 0.058065905634846, 0.14523576599146637, 0.08666488102504186, 0.11526689625212125, 0.13097775035670825, 0.14315752179494926, 0.1697881892323494, 0.06552747025021485, 0.14933753732059682, 0.17851724369185312, 0.11618194143686976, 0.08853884546884469, 0.10410599942718234, 0.15659293585589953, 0.22388872264751367, 0.12148522186492171, 0.27422259960855755, 0.17534976080060005, 0.10066936883543219, 0.07584144680627755, 0.1773440023618085, 0.13904127052852086, 0.21042019607765333, 0.10971378601555314, 0.18562442303768226, 0.14472314635557787, 0.16298465430736542, 0.11195703635790519, 0.21197271134172166, 0.08328222789402519, 0.19147483339267118, 0.11927851741867405, 0.1830956315887826, 0.10896883598927941, 0.13856941727655275, 0.25096380338072777, 0.13310634185160908, 0.13857428915798664, 0.1425211238009589, 0.08862678360726152, 0.10690201153712613, 0.0967101441430194, 0.1495650772537504, 0.0942981353561793, 0.1202162935265473, 0.08590436540544033, 0.10819774879408733, 0.15760693858776773, 0.19620082979755743, 0.1265135599034173, 0.18570601008832455, 0.17186818404921464, 0.1514519474336079, 0.18092094042471477, 0.07302895308073078, 0.10302963932710034, 0.18526275030204228, 0.12677736074796744, 0.22521922125348023, 0.15991350981806005, 0.09128774010709353, 0.07932670800281422, 0.12743216061166354, 0.10645552870950528, 0.11270208816443171, 0.126066405326128, 0.11710994664047446, 0.20616542867251805, 0.14657746042524064, 0.0803532772032278, 0.13798815703817777, 0.17444513791373797, 0.12444484233856201, 0.0869161696838481, 0.11880008237702505, 0.18489787488111428, 0.3129024883466107, 0.11510530992278031, 0.09752615714179617, 0.051256511559976, 0.06349072525543825, 0.12680113661502088, 0.1732165009847709, 0.16626303696206637, 0.09114427066275052, 0.19962482606726034, 0.271968560559409, 0.13319102302193642, 0.12325809816164629, 0.14977797440120152, 0.12436621370060102, 0.12525160690503462, 0.2369003508772169, 0.09093114959874324, 0.13714272954634257, 0.12070226030690329, 0.11407194180147988, 0.11192551840628896, 0.26860929653048515, 0.0720869293436408, 0.1398700467709984, 0.1788116464657443, 0.12703194708696433, 0.08991116218801055, 0.1550270670226642, 0.14967790405665124, 0.20398560778370925, 0.08900987769344024, 0.18700015278799192, 0.09227466250636748, 0.13630382956138679, 0.14263651546623024, 0.12308230330901486, 0.16539448499679565, 0.11363271251320839, 0.0942125381635768, 0.11683393216558866, 0.0833478354449783, 0.15847625051225933, 0.14861791022121906, 0.16055495611258916, 0.13474303617009095, 0.07163823449185916, 0.07098546344786882, 0.18909033920083726, 0.1698100652013506, 0.1608858640704836, 0.12408753936844212, 0.1543241725968463, 0.12791516897933825, 0.12478332274726459, 0.06499900003629071, 0.13218257070652076, 0.1071022879332304, 0.0984951187191265, 0.13583645464054175, 0.22098152578941413, 0.234619957527944, 0.10184628782527787, 0.15353887687836373, 0.18445142598024436, 0.11828662135771342, 0.09973201341927052, 0.23312677336590631, 0.11410691349634103, 0.0817054414323398, 0.13011616016072886, 0.21140329832477228, 0.1917120356644903, 0.14144735570464814, 0.04949855285563639, 0.11965639357055936, 0.09590639905737978, 0.13819520521376813], [0.038028216920793056, 0.02349930296518973, 0.045614567518766434, 0.023889482653300678, 0.022635716179917966, 0.0061774867104499465, 0.005251824148997132, 0.014102429251319595, 0.038604201549398046, 0.046379561469491036, 0.013260492822155356, 0.08011673989572696, 0.043382699601352215, 0.035482092294842005, 0.034210894256830215, 0.025890691072813103, 0.03269137615071876, 0.02475321532360145, 0.030898204871586392, 0.019908914641876305, 0.05252523294516972, 0.03413892544007727, 0.08160218875855207, 0.07111257341291223, 0.01881941980017083, 0.03390108195266553, 0.06579348990427596, 0.008846143310490464, 0.034012310805597475, 0.005273672976597611, 0.05683681069474135, 0.03972207102924585, 0.09435783965247017, 0.04436339644183006, 0.042308076550917964, 0.029069834588361636, 0.09579598105379514, 0.08792067292545523, 0.02358399092086724, 0.01557375440773155, 0.081186843902937, 0.04830633629379528, 0.0919414543147598, 0.063967185760183, 0.020650059783032963, 0.06698689050972462, 0.02074669165137623, 0.03415376500093511, 0.007630001603891807, 0.029267546122095416, 0.03517772523420198, 0.0641953024481024, 0.02137329668870994, 0.14290601600493702, 0.04664800688624382, 0.06186601386538573, 0.06995873818440096, 0.03331848160762872, 0.024841891368851066, 0.01548709870049996, 0.015090992009001119, 0.06558950192161969, 0.04586032611717071, 0.05483053192230208, 0.019267668515177708, 0.02942533265533192, 0.03739151019336922, 0.031074030258293663, 0.045826470612415245, 0.05952820966818503, 0.021494576341605613, 0.03900002834520169, 0.035591380537620614, 0.020041413871305327, 0.016711985027151446, 0.05949044919439724, 0.03776002595467227, 0.05611499871260353, 0.052354540675878525, 0.024972103935267245, 0.026028964635250822, 0.012233976208205734, 0.05035198027534144, 0.042274573884372196, 0.08081278790320669, 0.017559566867670844, 0.04746618101905499, 0.015656330423163514, 0.02298369098986898, 0.044626695170466385, 0.04443019821441599, 0.0450790201845978, 0.04377006506547332, 0.03470587198223386, 0.015208558379007238, 0.0169133233305599, 0.06438282917120627, 0.030154011411858455, 0.03924573605347957, 0.007972203777171671, 0.043475299275347164, 0.057852777785488536, 0.05992610938847065, 0.030322885207299675, 0.06760290531175477, 0.044820773149175305, 0.0048153658281080425, 0.014499402771304761, 0.013321030868350394, 0.02381067759623485, 0.005692015260657561, 0.030043243962739195, 0.07162412774882146, 0.047349493351898024, 0.03319112058462841, 0.029421950158263956, 0.028516787836062055, 0.02804770470330758, 0.06099795723067863, 0.034603301236139875, 0.021093036280944943, 0.04450390408081668, 0.028470511747790233, 0.07010760198214225, 0.04007283631446106, 0.03517197464991893, 0.01955801364965737, 0.014929268276318908, 0.041529240485812934, 0.024156569303678613, 0.03246736799233726, 0.0981306436338595, 0.01062155478367848, 0.028731612022966146, 0.05490909270676119, 0.03135765450341361, 0.04491136435951505, 0.0759262636836086, 0.08067332860082388, 0.053701354656368494, 0.026194471200661998, 0.027241131822977747, 0.05092987498002393, 0.05708918161690235, 0.04194163710677198, 0.04832334716671279, 0.009436260127196354, 0.01775318174622953, 0.07648235027279172, 0.03072190111769097, 0.04823582632733243, 0.02564918519263821, 0.03526905265503696, 0.06179608404636383, 0.04232504331905927, 0.0069494097759681085, 0.05254656608615603, 0.010593689046800137, 0.017157143015148382, 0.030999357479491403, 0.009901389945298433, 0.026629211979785135, 0.05655405158177018, 0.036455654339598756, 0.02065366110764444, 0.015975562489724586, 0.09253086375870875, 0.042838307563215494, 0.0598311484126108, 0.026765595822195922, 0.039419702254235744, 0.06622891261109284, 0.06547337065317801, 0.052086627909115384, 0.009406991519166954, 0.019995592401496003, 0.05054654001391359, 0.08221090930913176, 0.023959264890956025, 0.04324146253722055, 0.06325458149824824, 0.06158719704087291, 0.06927081224109445, 0.025954999229205505, 0.039968786362026415, 0.06882098423583166, 0.016765808121168187, 0.05822574134383883, 0.02728694141842425, 0.01599953682827098, 0.08387843625886099, 0.026901199349335263, 0.04743441200948187, 0.03846268289323364, 0.014086370023765733, 0.035103697063667436, 0.022596783536885465, 0.03431357017585209, 0.0705484529691083, 0.029572774922209125, 0.019268971302413514, 0.040613096074334214, 0.03252660749214036, 0.04297231144404837, 0.04192025986100946, 0.006757827533874661, 0.03952112288347312, 0.0570210295596293, 0.0407420245132276, 0.029311162353094136, 0.05112330156511494, 0.03975972972278084, 0.010446101743062692, 0.01178915155053671, 0.03367354880486216, 0.0599052512219974, 0.028790339228830168, 0.039284388800816875, 0.10173228715679475, 0.03755669954365917, 0.007402057094233376, 0.062069615083081384, 0.037907719279506376, 0.01226402513150658, 0.012542761379985936, 0.011281032298159386, 0.05802717485598155, 0.08754895108618907, 0.014954759140631982, 0.036886714066245725, 0.03543308849579521, 0.01769304318752672, 0.05416260579867022, 0.037378801232469935, 0.02349750484739031, 0.03884144453331828, 0.04783673577808908, 0.023230945757989372, 0.035143747593143156, 0.03546099324843713, 0.07057006430945226, 0.050111632993710895, 0.008538601554131933, 0.006987700779323599, 0.019136901246383786, 0.02338467295547681, 0.016954393358901143, 0.09023338489766632, 0.044117512314447334, 0.014050440746359527, 0.07204437162727118, 0.1267240278955017, 0.0567279940338007, 0.028038227265434604, 0.02208039633530591, 0.05832258864705052, 0.07436151443315403, 0.023952620336785913, 0.01665260812400707, 0.023609203585822667, 0.03820065302508218, 0.025210525873782377, 0.06892708675669772, 0.01732442225329578, 0.007209841694150652, 0.036009069731725116, 0.04780226619914174, 0.03407785389572382, 0.005032401191004152, 0.05433886205511434, 0.0512365795938032, 0.04215289219947798, 0.022097895753436854, 0.04420786264485546, 0.07310114920671497, 0.03186981273548944, 0.05003660398402384, 0.01094758661929518, 0.030589749637459005, 0.02630164919953261, 0.03532406148899879, 0.0469426098279655, 0.03691747545131615, 0.04999679094180465, 0.025593441844518696, 0.005708352263484682, 0.01538729976995715, 0.024022134553108896, 0.09427893281515155, 0.012768486231964613, 0.03248857899702021, 0.012489260590103055, 0.03372221672907472, 0.014264856964083654, 0.03982292508174266, 0.051608613559177945, 0.08443336933851242, 0.06650105265102216, 0.03644589700603059, 0.010994023011465157, 0.02365630748681724, 0.060286533619676314, 0.029553297574498823, 0.04516159789636731, 0.011271222378127277, 0.019991806176091944, 0.012463124269353492, 0.056532843969762325, 0.01635049719230405, 0.05923480434077127, 0.05506849415334208, 0.010541217933808054, 0.03568554762750864, 0.03009724517219833, 0.018534158589318395, 0.015825687674805522, 0.024299010767468383, 0.030952297683273042, 0.0027923017956449515, 0.04349635421697583, 0.06674564416919436, 0.010379482326763017, 0.02601682734010475, 0.013039522804319859, 0.0571364483663014, 0.03437199882630791, 0.0556366281317813, 0.05633582114907248, 0.028844065631606748, 0.012900430759015893, 0.08588808735034295, 0.025806878427309648, 0.041408953190382035, 0.007098809616374118, 0.02756124428872551, 0.06731013102190835, 0.012730189715512097, 0.009678254552584673, 0.032588249005909474, 0.04470172418015344, 0.04808992433494755, 0.011896476282605102, 0.015779487921723297, 0.041473088320344687, 0.013855318671890667, 0.030804115813225508, 0.04198496835306287, 0.04697667907125183, 0.015057541928919298, 0.0425590734396662, 0.032954023485737186, 0.028068990346842577, 0.11583668924868107, 0.17026449367403984, 0.07924748225403683, 0.12289407769484179, 0.10897655771779162, 0.17432435868041857, 0.18880369886755943, 0.09470776694693736, 0.21606814515377792, 0.1718057452567986, 0.07496142759919167, 0.14278667526585714, 0.07984292387430157, 0.10455455857196025, 0.1804974124367748, 0.09822501428425312, 0.11984757759741374, 0.15838101133704185, 0.1499665935656854, 0.13149791530200414, 0.10713438942496266, 0.14784172044268676, 0.2555021441408566, 0.1318095935774701, 0.20984625044677938, 0.10582443685936076, 0.10532796635691609, 0.10999749507755041, 0.15352351484554155, 0.13273149196590694, 0.15483713150024414, 0.2222044358828238, 0.15589715247707708, 0.1908525489270687, 0.1724558767995664, 0.1747359987348318, 0.14906507836920874, 0.12765974125691823, 0.0814445379323193, 0.17796088568866253, 0.15814520684736116, 0.113763832620212, 0.14090733682470663, 0.1178461028529065, 0.1161784537668739, 0.07692213595977851, 0.15542262579713548, 0.09651705343276262, 0.07701128867587873, 0.09896766407681362, 0.12390052154660225, 0.1691847408988646, 0.19313058097447666, 0.1759124156087637, 0.09058859797992877, 0.10020162750567708, 0.23005211406520434, 0.1711889976369483, 0.17345284830246652, 0.09497439049716506, 0.18075184949806758, 0.1664262382047517, 0.17588684840926103, 0.16464141969169888, 0.23094973447067396, 0.15841495165867464, 0.10390574338712863, 0.11287432070821524, 0.19888473435172013, 0.12288708878414971, 0.11307955719530582, 0.09994892749403204, 0.15707457358283655, 0.18753857032528945, 0.13865123502910137, 0.27364866754838396, 0.160115848960621, 0.1033814325928688, 0.09969937588487353, 0.09621747343667916, 0.13917039574256965, 0.10357216878661088, 0.12438332635377135, 0.09717143260474716, 0.14713445625134877, 0.08875022269785404, 0.20970869782779897, 0.08683395838098866, 0.0967510055218424, 0.13881139643490314, 0.08507179615220853, 0.17526136125837052, 0.13006806559860706, 0.12023027134793145, 0.1036032321197646, 0.1220240058111293, 0.16243827076894896, 0.13155743639383996, 0.15038244053721428, 0.18342108412512712, 0.1995556154953582, 0.15472940728068352, 0.13308115463171685, 0.16374586203268596, 0.3095521538385323, 0.07177786342799664, 0.07122681835400206, 0.1318175731492894, 0.09135431796312332, 0.06347019957112414, 0.1269470623561314, 0.15013957928333962, 0.15623589072908672, 0.0787628861144185, 0.1958463495331151, 0.11604281461664609, 0.13395394065550395, 0.16405984732721532, 0.14439713742051805, 0.19656334391662053, 0.11839461699128151, 0.17316790430673532, 0.07817843676145587, 0.17828723389123166, 0.06612584992711033, 0.13703736662864685, 0.08135786186903715, 0.1055615045396345, 0.07408018024372202, 0.13507380842098168, 0.0920212296769023, 0.20004436426929065, 0.08412677329033613, 0.11748251664851393, 0.11353786010295153, 0.12577933073043823, 0.13692339988691465, 0.13681882406984056, 0.14812310891492025, 0.14475414183522972, 0.0640532307858978, 0.07798510856394257, 0.0802279110731823, 0.16284221623625073, 0.1049249776239906, 0.10627134037869317, 0.10407843054937464, 0.1288467568478414, 0.14749587114368165, 0.1293562687933445, 0.1364584948335375, 0.10891916044056416, 0.1368255279958248, 0.17422536042119774, 0.173357134152736, 0.06730005477688142, 0.054889493222747526, 0.05898762081882783, 0.11496355038668428, 0.10207643333290305, 0.15307741878288134, 0.08499994607908384, 0.13991275376507215, 0.1471385003200599, 0.14599943001355442, 0.11126930718975407, 0.13150323501655034, 0.06556998046913318, 0.2603630875902516, 0.09473954952721085, 0.20013181386249407, 0.11425369419157505, 0.0984680587425828, 0.10740741156041622, 0.06133385242096015, 0.11415508948266506], [0.006285251218027302, 0.01463341513382537, 0.03220326519970383, 0.07694929771657501, 0.018592071553160037, 0.05289956035890749, 0.048329993417220454, 0.04538468663979854, 0.011863961732680244, 0.03177584242075682, 0.010733327312794114, 0.0057233304999369594, 0.02175620587409607, 0.056155473326465914, 0.05473230040765234, 0.09168567375413009, 0.0265199118626437, 0.05629515993807997, 0.020343355169253688, 0.024627302972865955, 0.04443989447983248, 0.03156916743942669, 0.010620860133453138, 0.015868262354550616, 0.00817082285149289, 0.04094081152496593, 0.011217436603536564, 0.024136623766805445, 0.03132230622161712, 0.030402280589831725, 0.011288122140935488, 0.023090853721701672, 0.03313294977747968, 0.02108347402619464, 0.07660680038056203, 0.011201886277246689, 0.04019041625516755, 0.06686066942555563, 0.011505100676523787, 0.007338290069518345, 0.03320438255156789, 0.05791368308876242, 0.04546680634043046, 0.033722718844988515, 0.03806618434776153, 0.045765090334628306, 0.04676560039765068, 0.06011724591787372, 0.006116481323260814, 0.07531199950192656, 0.059657999846552096, 0.053071976107146056, 0.045411108793424707, 0.05216765856104238, 0.047340119390615394, 0.02831324768651809, 0.04429081355088523, 0.046856958352561505, 0.058274799425687106, 0.02279791997612587, 0.041656048502773046, 0.03368954526792679, 0.051472736921693595, 0.061980150240872584, 0.02704800379329494, 0.06357109094304697, 0.026488929953692213, 0.018273322942799756, 0.04119085507201297, 0.04924585623666644, 0.06153954352651324, 0.031944916384028535, 0.03854301465409143, 0.05775550979056528, 0.02548279653170279, 0.055343697778880596, 0.006986344981539462, 0.059357103492532454, 0.008585833528611277, 0.03689542306321008, 0.08470172993838787, 0.08118557504245213, 0.05211610686300056, 0.028296698217413256, 0.04797968275046774, 0.009220500410135304, 0.014531073393300176, 0.04114456880571587, 0.03224069319133248, 0.05783828427749021, 0.05121817093874727, 0.04756617672475321, 0.026665077644533346, 0.026432882961151854, 0.01730197461854134, 0.02091261381948633, 0.00428653514245525, 0.02038254395925573, 0.03285236536924328, 0.03588483336248568, 0.022063763745661293, 0.08101470635405608, 0.04773085717377918, 0.01864476827904582, 0.018135380166183625, 0.05458653751494629, 0.05865561363420316, 0.06083751762551921, 0.016840146721473763, 0.021303260000422597, 0.07572703223143305, 0.015216281803857003, 0.005259494987382952, 0.024427895101585557, 0.08643438946455717, 0.07041223027876445, 0.0446264882172857, 0.03673153989283102, 0.033161638238068135, 0.05960645154118538, 0.010813155261400555, 0.04286484506779483, 0.0411871265220855, 0.008506545863513435, 0.009193789030957435, 0.10172226519456931, 0.08245766535401344, 0.03817290772816964, 0.03291704671989594, 0.02753178738722844, 0.041443453303405216, 0.022959004189553003, 0.028018074775380746, 0.020012384446870004, 0.017516557925513813, 0.030306468052523475, 0.02992650879813092, 0.015726116053493958, 0.044605820040617666, 0.01219078915060631, 0.07263697018580777, 0.03604458086192608, 0.04343428522614496, 0.08546850843621151, 0.014729365074474896, 0.0860959497679557, 0.06872462547783341, 0.012392252134824438, 0.09831378023539271, 0.07617173051195485, 0.06847589489604745, 0.041883001503135474, 0.04080446330564363, 0.07932299641626221, 0.06838921204741512, 0.09808811305889062, 0.033000883114125044, 0.0169073742747839, 0.01950127455139799, 0.036385833086179833, 0.020992070270170058, 0.02440086905179279, 0.04848881810903549, 0.027006725115435462, 0.05618834834811943, 0.041114757369671545, 0.03706081258133054, 0.044415582570114305, 0.05656994965725711, 0.03228981912668262, 0.0409172324330679, 0.05385210817413671, 0.021790227619931102, 0.01868916312897844, 0.055601500373865874, 0.027879017504996488, 0.025236437429807017, 0.031202073208987713, 0.03973242547363043, 0.008920232549176683, 0.026526982197538018, 0.08266918507537671, 0.03669931287212031, 0.010042749993902231, 0.053682311571070125, 0.04473010051463332, 0.0730239183508924, 0.037089114276958365, 0.027772102438445603, 0.040773237124085426, 0.012758423557638057, 0.04389727341809443, 0.07510107010602951, 0.04520691046491265, 0.02947819053328463, 0.04655772101666246, 0.03472098634977426, 0.012170922493429055, 0.013913445374263185, 0.00658641813788563, 0.028239987956892167, 0.015553410231534923, 0.01780216518922576, 0.016034284606575966, 0.03156408860481211, 0.01642693585849234, 0.027706175976033722, 0.03954854926892689, 0.026737889541046958, 0.009768703270570507, 0.035545803340418, 0.032653188199869225, 0.05979915548648153, 0.03880922090528267, 0.02814207026468856, 0.04300647907491241, 0.025223094038665295, 0.05872638483664819, 0.09388300084642001, 0.060743940861097405, 0.044494306202977896, 0.023418843979015946, 0.025265782373026013, 0.0392211696931294, 0.02060710682001497, 0.060179867914744785, 0.050348434929869006, 0.0656633943851505, 0.017338188032486608, 0.045044099379863055, 0.017383738088288476, 0.010772854522136706, 0.033083688135125806, 0.03820939934147256, 0.03648050229198166, 0.034931508624660115, 0.047091100431446514, 0.04438776263434972, 0.04564199051154511, 0.01692305182638977, 0.023494134224685173, 0.10120351838746242, 0.021407482979286994, 0.025979087222367525, 0.05857732426375151, 0.007766371027433446, 0.008871041304830993, 0.041275118943303823, 0.05728523073984044, 0.037154569157532284, 0.021843964200732962, 0.07971819556717362, 0.048979056267333884, 0.05346409810174789, 0.042992962657340934, 0.059317673822598796, 0.026857907118807946, 0.01935385094423379, 0.06396934350154229, 0.03928602407021182, 0.04352009615727833, 0.035210291522422006, 0.04453267396560737, 0.01330798348811056, 0.01001655514950731, 0.06264511455914804, 0.023151959192806056, 0.023308675337050642, 0.014874895568937063, 0.03946127609482833, 0.0470525019669107, 0.04007835280416267, 0.019109507091343403, 0.030841296139572347, 0.0048176071140915155, 0.08075998430805546, 0.018629830330610275, 0.03879157220944762, 0.0786260391718575, 0.07770686170884541, 0.05729474380080189, 0.03095236553677491, 0.05722758240465607, 0.02430446618901832, 0.019323065810437714, 0.04400445141696504, 0.05763570086232253, 0.05017928632774523, 0.014721178549474903, 0.04679261287674308, 0.10462164532925401, 0.047198576985725334, 0.04669054424656289, 0.025037182228905813, 0.06253460834601096, 0.030744133317576985, 0.054677888684506924, 0.03212753390627248, 0.031037369011236087, 0.05101461721850293, 0.020323285799739615, 0.05843150030289378, 0.04241931897455028, 0.09057373127767018, 0.0464592045173049, 0.03117525071970054, 0.006907481400828276, 0.03835296378071819, 0.01915448548139206, 0.010765157390518912, 0.015862791665962765, 0.011259434528515806, 0.023754893536014215, 0.025850304668503146, 0.059543252789548466, 0.016007231415382454, 0.028650435486010144, 0.02942964813805052, 0.044536382159484286, 0.04028897685930133, 0.03729147716824498, 0.050535822553294044, 0.0659290204889008, 0.024126591626554728, 0.012331710695954306, 0.03767364166144814, 0.04061727585004909, 0.010963474516756833, 0.07370438719434397, 0.03954926851604666, 0.021070743012907248, 0.04011429141142538, 0.0314169007885669, 0.012554358391623412, 0.020385746644543748, 0.027764217861528908, 0.018340721826202104, 0.02465030361366059, 0.024586238033537353, 0.09820031560957432, 0.06016773570861135, 0.017698887070374827, 0.016685362705694776, 0.0592174134882433, 0.03864606037469847, 0.019683445936867168, 0.040814634545573165, 0.045434545392968824, 0.008880925863715155, 0.052163573780230114, 0.02533384961342173, 0.01870692378309156, 0.0859267638464059, 0.10890318772622518, 0.08374577587736504, 0.14965863366212162, 0.2980211568730218, 0.2769828529230186, 0.18351066431828908, 0.21315561501043184, 0.13755455959056104, 0.15082142555287906, 0.2865365988441876, 0.09584417061081954, 0.11829945924026625, 0.09241489533867155, 0.05358941334166697, 0.11864536282207284, 0.15688866855842726, 0.13872257620096207, 0.134848629789693, 0.11606854466455323, 0.17097094362335546, 0.20089448722345488, 0.0979378107669098, 0.14101331042391912, 0.06746068437184606, 0.11595759061830384, 0.12685350594776018, 0.1178442436669554, 0.21697507505970343, 0.14188497007957526, 0.08197966457477637, 0.12231057829090528, 0.07750889233180455, 0.07168520268585, 0.094599106349051, 0.10216123663953372, 0.21464704855212144, 0.14696988436792577, 0.12614725955895015, 0.11736354231834412, 0.17176029698124953, 0.1634680697960513, 0.17243223663951668, 0.16591028017657145, 0.1253801214375666, 0.10613707186920301, 0.1423741259745189, 0.13212992995977402, 0.07741553269858871, 0.18781755678355694, 0.18151455000042915, 0.16506516481084482, 0.14510213530489377, 0.09632370487919875, 0.13019360814775738, 0.0684775776628937, 0.14111198298633099, 0.17525047755667142, 0.1403193048068455, 0.09179666172713041, 0.2037922524447952, 0.08820675686001778, 0.16297751611896924, 0.09589024313858577, 0.08180625816541058, 0.10941198720995869, 0.11105936166963407, 0.10573824934129204, 0.1251197811216116, 0.12262833624013833, 0.15710275992751122, 0.10774973247732435, 0.14570888131856918, 0.1493976962353502, 0.08560718742332288, 0.1872338131070137, 0.0889988989968385, 0.1813821406768901, 0.1111776710354856, 0.19338874997837202, 0.14533945971301623, 0.12335354089736938, 0.16303000758801187, 0.09515302841152463, 0.1068821440317801, 0.08815173445535557, 0.08431367576122284, 0.09696721392018454, 0.1032322838104197, 0.20420671520488604, 0.1548708411199706, 0.1139839765216623, 0.05729198216327599, 0.1307384039142302, 0.12960615967001232, 0.06756753328123263, 0.13961327554924147, 0.08771322441420384, 0.09490220794188124, 0.16160128425274575, 0.11180353138063635, 0.15633081777819566, 0.14497315936854907, 0.09741894182349954, 0.16188849455543927, 0.09535015640514237, 0.15586536989680358, 0.13335605630917208, 0.12515658486102307, 0.08246605204684393, 0.17765102588704654, 0.1598138873066221, 0.10920898310307946, 0.09996082899825913, 0.1488439438066312, 0.2055248509028128, 0.15394054246800287, 0.11962115046169076, 0.1764386330864259, 0.170047131766166, 0.14859146092619213, 0.08834408556244203, 0.11608336386936051, 0.13254528838608945, 0.13835118684385503, 0.21001620989825043, 0.1860815520797457, 0.17820692248642445, 0.1855182594486645, 0.09239483105817012, 0.11174718583268778, 0.1751983253551381, 0.0881714051855462, 0.1223252753594092, 0.08182173554918595, 0.1235541429902826, 0.08055824227631092, 0.0810082738420793, 0.14650320155279978, 0.12155782511191708, 0.11164995854986565, 0.10846239780741078, 0.0635492896128978, 0.19961633080882685, 0.12700747911419186, 0.17127355667097227, 0.13138478994369507, 0.1921280047723225, 0.15270643654678548, 0.14768952503800392, 0.2031578357730593, 0.08415326329746417, 0.2648789552705628, 0.18696812593511172, 0.15109104822788919, 0.20120199929390634, 0.08644452677773577, 0.04849533543788961, 0.16321515265320027, 0.18243773760540144, 0.09228968527168036, 0.060564101939754825, 0.061256954047296724, 0.15239743169929298, 0.09160663120980773, 0.09934699907898903, 0.1376093037958656, 0.14056593871542386, 0.13179174810647964, 0.12802767008543015, 0.1093951120440449, 0.20972491481474467, 0.1508931059922491, 0.24248827674559184, 0.09210131037980318, 0.15788401157728263], [0.02714198428605284, 0.08331722673028708, 0.023304303875193, 0.008680925970630986, 0.039868179974811416, 0.010072350235921996, 0.054695249002959044, 0.039314508970294676, 0.03496653460232275, 0.025569440364571552, 0.02343116787129215, 0.04771135947001832, 0.0657121946236917, 0.049128303437360694, 0.07002912262188536, 0.047537970024027994, 0.014576564077287912, 0.0034847514471039176, 0.07959848841918366, 0.055014197781149826, 0.04125883749553135, 0.044556242879480124, 0.016636857629886696, 0.018995153584650586, 0.02046666873086776, 0.04406906830679093, 0.020574694898511683, 0.03212876544733133, 0.04913508878754718, 0.018109203981501714, 0.008848039815867586, 0.04092222645080515, 0.05076420386987073, 0.08413667990160839, 0.021366189034389596, 0.06701166382325546, 0.014174497303819018, 0.045631839627666135, 0.0379463618488184, 0.024318578021068658, 0.02366128284484148, 0.035188575009150166, 0.029163628483989408, 0.025191269049953138, 0.07493549399077892, 0.03608482477388211, 0.012708290845953991, 0.1065790695803506, 0.04523608747071453, 0.06737573857286147, 0.03768296812527946, 0.01604842866903969, 0.046736671057130606, 0.0250258693538074, 0.03291060742256897, 0.015002127670283829, 0.04131768683769873, 0.06357149806405817, 0.032765451818704605, 0.04048406246251293, 0.01403014237127666, 0.04100568286542382, 0.03417323895597032, 0.030504671524145772, 0.025360573715131198, 0.05213117373308965, 0.06461830117872783, 0.019911057116197686, 0.10122607289148228, 0.048316565209201405, 0.031643667191799195, 0.02612388998802219, 0.0036944429406763186, 0.018296004672135626, 0.04599212136651788, 0.011155784063573395, 0.014150042901746929, 0.029945894543613707, 0.08360339887440205, 0.045125649111079316, 0.03166262546022024, 0.0547676622601492, 0.022653836457590972, 0.04370340917791639, 0.009530199907853134, 0.014998012355395725, 0.021302690031006932, 0.04896543128415942, 0.011857990624516137, 0.04395168174856475, 0.017558805212112408, 0.08042346486555678, 0.026089227026594535, 0.006635604293218681, 0.049451761080750396, 0.03654102422297001, 0.015028653300500341, 0.032516880692648034, 0.07459517475217581, 0.011054633152005928, 0.043926674340452464, 0.01707960681856743, 0.005028969076062951, 0.026493282755836844, 0.021712808470640863, 0.03018980413409216, 0.04293146702860083, 0.045530758265938075, 0.06372449414006301, 0.023773419238360863, 0.03458461777440139, 0.02509443531744182, 0.03085359458678535, 0.0190351311716118, 0.03410851350054145, 0.04661779172186341, 0.02316364356582718, 0.022069363355902687, 0.038071541381733756, 0.012170458545110055, 0.07311661301978997, 0.0469909011652427, 0.02822889051666217, 0.06841836191181626, 0.03456436689676983, 0.03674691888902869, 0.01026752998586744, 0.03148539211334927, 0.09155396332166024, 0.0679811682286007, 0.0035436067264527082, 0.028663717809000185, 0.13314461122666085, 0.050944175105541945, 0.025669987379972423, 0.0182622051465192, 0.007661311754158565, 0.012494857655838132, 0.05243350858134883, 0.026782633836514184, 0.03350512623520834, 0.03605186493535127, 0.03921196197292634, 0.027280161157250404, 0.02872138310756002, 0.023349572338962128, 0.015479682312746133, 0.003811256560896124, 0.05148421434153404, 0.0497590526273208, 0.008838768483006527, 0.07611098805708544, 0.04567434984658446, 0.024105903093836138, 0.023413637919085364, 0.05685734994975584, 0.050419670928801806, 0.026204935906987106, 0.02914268889331392, 0.016094414683591043, 0.016559518208461146, 0.022482686177162186, 0.06585299064006124, 0.006448070360680244, 0.029757719819567034, 0.02951422074277486, 0.030921074894389937, 0.04513860234458532, 0.052737353170024495, 0.06777412683836051, 0.09608630583222423, 0.012848000358124929, 0.09682869099612747, 0.030910639025803124, 0.02303659975794809, 0.03584531887567469, 0.022396564816257784, 0.0193376560096762, 0.004533259805092322, 0.01858162211387285, 0.0059522889953638825, 0.025593706473175968, 0.026608274085447192, 0.032270728543932946, 0.049005936432097635, 0.025582452969891683, 0.013730639558551567, 0.018848696889887964, 0.03339246906606214, 0.055062801244535615, 0.1132355998935444, 0.013315013110903757, 0.024398684169032743, 0.01797458772281451, 0.02973562671935984, 0.07529954838433436, 0.012688532754379724, 0.03792408893683127, 0.09682907097573791, 0.060886752126472335, 0.03380730841308832, 0.01899368455633521, 0.02538029703178576, 0.0640738650358149, 0.07029587509376661, 0.06950687457408224, 0.027649750700220466, 0.04309541126713157, 0.03699990049270647, 0.05235916149935552, 0.023147485950695615, 0.014228735152365906, 0.03089214555386986, 0.0346415909672422, 0.046641672761844735, 0.028276844282767603, 0.04841434210538864, 0.036304215501461706, 0.01404485131414341, 0.012800448624018048, 0.027891432999500206, 0.012591949231656534, 0.0193357238812106, 0.05236120728243675, 0.03016932594722935, 0.027085394465497563, 0.05586171516084245, 0.036761259726647816, 0.03786343808418938, 0.025265811210764304, 0.012823227044594075, 0.030791054014116526, 0.029745255131274462, 0.012810826817128276, 0.05929792845355613, 0.016760883653270345, 0.04329642726640616, 0.02568212976413114, 0.03286689280399254, 0.09160066688699381, 0.04311446113778012, 0.041112453743283234, 0.04567839730797069, 0.025325780135712454, 0.004719623688807977, 0.029711816925555468, 0.05153055149795754, 0.06658320288572993, 0.01656282945935215, 0.0052338302484713495, 0.016908641438931227, 0.011589163531815367, 0.047770337733839235, 0.049335005560091565, 0.09607559176427977, 0.03512541696961437, 0.04715687083080411, 0.040729736244039874, 0.010043226664752831, 0.053743074381990094, 0.019551116341192807, 0.011808242981455155, 0.04906189182241048, 0.018036012105377655, 0.05723895465156861, 0.03898662727858339, 0.036309043278119395, 0.07593245192297868, 0.030357242827968936, 0.03203948041690247, 0.04032084086377706, 0.05690173971067582, 0.016912217318479503, 0.041289283361818106, 0.009936218299636883, 0.044676849086369784, 0.02500242766525064, 0.03706794059170144, 0.029399565287998745, 0.017144561279565096, 0.039653094551925144, 0.0669822289741465, 0.014972492653344358, 0.036049476492085626, 0.007267261023766228, 0.024818490392395427, 0.021341500537736074, 0.020873613322951963, 0.011637644010729023, 0.003976653288451156, 0.012262282992846199, 0.04015378893486091, 0.008577977789432874, 0.017244048083999326, 0.007729657193911927, 0.021931663155555725, 0.08563663584313222, 0.04006687199164714, 0.007431307890718537, 0.048224501577871184, 0.0348891442907708, 0.044045319581138234, 0.055672444602740664, 0.03441741317510605, 0.0436873889661261, 0.018547680095902512, 0.060046128662569184, 0.03515063472358244, 0.08400058613291808, 0.03081366280093789, 0.012037944896811885, 0.017321613118318573, 0.05555140074076397, 0.0030491468080851647, 0.05331956675010068, 0.021440827886440923, 0.00996273968900953, 0.0365324441476592, 0.004324651847127825, 0.061423771881631443, 0.02854778670838901, 0.03714082882340465, 0.006144900490263743, 0.025985582498833537, 0.041329849577908, 0.015771796727286916, 0.09053910563566855, 0.028638747720313922, 0.03925371562529888, 0.028552729835999862, 0.00933897856157273, 0.047608948179653714, 0.0628595519810915, 0.006113297721770192, 0.02914900266166244, 0.02635446806172175, 0.005128962237254849, 0.04389923099162323, 0.04032036588926401, 0.05219133943319321, 0.011722884124277957, 0.02966368504400764, 0.04917631657528026, 0.05298387851299984, 0.03388986237613218, 0.03919826574357493, 0.07637172870870147, 0.013330225017853081, 0.0346929017853524, 0.04356115770393184, 0.003051695767291156, 0.03430664911866188, 0.10236415932221071, 0.14905756020120212, 0.09324293197797877, 0.084669533451753, 0.1355362164654902, 0.20010886580816337, 0.139573744099055, 0.1509587610406535, 0.1980944988983018, 0.1485805500830923, 0.05259820938642536, 0.12876476267618792, 0.0873403897775071, 0.13835890857236727, 0.19588128051587514, 0.08375986226435218, 0.10887388179876975, 0.07363932247140578, 0.23522358228053364, 0.19662492775491305, 0.11036895907350949, 0.16340474890811102, 0.13065088646752493, 0.21983043184237822, 0.10023622600627796, 0.09356465257172074, 0.09897672251931258, 0.1800785663404635, 0.19175789106105054, 0.13961585398231233, 0.09740307767476354, 0.13417785721165792, 0.13575612966503414, 0.15664265890206608, 0.09670950632010188, 0.15194277252469743, 0.13063291886023112, 0.11730759032070637, 0.11160408958260502, 0.22441074677876063, 0.08635162854833262, 0.10681440588086843, 0.09282608755997249, 0.10244806696261678, 0.15233415152345384, 0.12581701656537397, 0.09929149491446358, 0.19378092964845045, 0.09754931554198265, 0.10874482443822281, 0.17696490484688962, 0.15398525792573178, 0.17820868667747292, 0.11328912273581539, 0.1403549686074257, 0.15764115032340797, 0.10004453307815961, 0.11044666490384511, 0.08085485707436289, 0.11696251455162253, 0.14679427950509957, 0.08062499655144555, 0.10059348147894655, 0.19468936590211733, 0.09046998327331883, 0.11885602080396243, 0.19436076496328625, 0.1663086073739188, 0.14196711352893285, 0.14850165003112384, 0.13197883378182138, 0.11000685207545757, 0.12766350034092153, 0.11950863578489848, 0.11725252041859285, 0.08379463039870773, 0.09318681713193655, 0.19694252285574163, 0.25305542828781263, 0.10035241155752114, 0.07909140562904732, 0.182505034708551, 0.14453698348786148, 0.11802185699343681, 0.14784607663750648, 0.13597592072827475, 0.14747433444218977, 0.10036904245082821, 0.16821454438780034, 0.14840646513870784, 0.12692921688514097, 0.1518425393317427, 0.10701515725148575, 0.07771209999918938, 0.18677041440137795, 0.0860559433432562, 0.13562536239624023, 0.13294273348791258, 0.10245565298412528, 0.11019581050745078, 0.18466836719640664, 0.1682080440223217, 0.12489525388394083, 0.07439343272043125, 0.12426775826939515, 0.14667872499142373, 0.12874401307531766, 0.06992589708949838, 0.1337895994739873, 0.1026790945657662, 0.11471104036484446, 0.13502447892512592, 0.13759714444833143, 0.11355153936892748, 0.1561301342610802, 0.1783480713410037, 0.13382982302989277, 0.1227488304887499, 0.11598900678966727, 0.10514318091528756, 0.1921507492661476, 0.1176675802895001, 0.11688263740922723, 0.12232029491237231, 0.1028153443975108, 0.1524343304336071, 0.1349479808871235, 0.130270513306771, 0.09736427225704704, 0.08314751155142273, 0.21746424452534743, 0.06334942033780472, 0.19824526937944548, 0.1366876768214362, 0.09130744476403509, 0.12594981943922384, 0.06700882754687752, 0.12673793786338397, 0.1496291309595108, 0.12584320801709378, 0.14705843318785938, 0.21789463928767613, 0.08939850862537112, 0.12579317284481867, 0.07734226448727505, 0.14768326894513198, 0.07436632524643626, 0.10583403134452445, 0.1478288418480328, 0.16197536060852663, 0.18278434686362743, 0.22676645751510346, 0.18567270758960927, 0.06768553052097559, 0.14109254974339688, 0.16075090345527443, 0.16300286618726595, 0.16517991865319864, 0.1300759773169245, 0.07660979950534445, 0.06958565927509751, 0.11088498495519161, 0.16359937989286014, 0.14582563005387783, 0.08047384609069143, 0.06827403072799955, 0.21192119696310588, 0.13098467141389847, 0.10955725477210113, 0.13483287420655998, 0.19074833951890469, 0.07084947145943131, 0.1621055579079049, 0.15581053069659642, 0.08877161012164184, 0.12443532927760056], [0.051488713028707674, 0.020009882348988737, 0.024571837824104086, 0.04860671017585056, 0.07337970140257052, 0.029594884985791783, 0.020914476398112516, 0.01820682142195957, 0.039059488368885856, 0.0054418330380160895, 0.014938492959897434, 0.00971508797790323, 0.040768317745200226, 0.02076866940063025, 0.056996826215514114, 0.023903117814500417, 0.025669034038271223, 0.027807834092527628, 0.0622791534821902, 0.0061558656161651015, 0.018555795374725546, 0.05095442098432353, 0.010748685952941222, 0.0361441728392882, 0.0894515768491796, 0.024412544943126183, 0.0064613713433833, 0.08803746915821518, 0.030650549767804996, 0.032726422484431944, 0.05707371101847716, 0.03585685397099171, 0.03895297194165843, 0.029191166827721254, 0.01971646853988724, 0.014023585178490196, 0.036680609054331265, 0.07706353587231465, 0.017672722760055746, 0.03424126887694001, 0.020224270577143346, 0.054764714025493176, 0.02962363451453192, 0.024932070369166986, 0.030451596514987092, 0.015516747288139803, 0.008669916739953416, 0.035653785403285704, 0.08148296337042536, 0.004059547367173114, 0.023000311705150774, 0.030866887087800672, 0.03310575409393225, 0.026217963779345155, 0.017874619158517038, 0.028893934562802315, 0.08683467762810843, 0.04512949640463505, 0.04617012145795992, 0.020165467036089728, 0.012518070338826095, 0.07607847265899181, 0.02713814377784729, 0.039257752908659835, 0.0648993028860007, 0.010721930468987142, 0.04227830243429967, 0.04176889226904937, 0.043025776610842774, 0.044314928685448, 0.03269755081938846, 0.05122595373541117, 0.009439859755470284, 0.037760846982044835, 0.01576774756956313, 0.052101389438446076, 0.06360719579138926, 0.03346948618335383, 0.010979079974016972, 0.019357603242886916, 0.018521607387810946, 0.04135538963600993, 0.017870680262733783, 0.015079636725464036, 0.03660397870200021, 0.021807291079312563, 0.026450519782624075, 0.04261866917035409, 0.023442772516448582, 0.056910550487892966, 0.05048340233042836, 0.049302225533340654, 0.023596413200721145, 0.0501998866509114, 0.0177023900074086, 0.03772276420412319, 0.03302603301459125, 0.013604909564102334, 0.05730384974075215, 0.03094638425058552, 0.030667513143271208, 0.01229431917558291, 0.04560448448838932, 0.009341378879201199, 0.05312215377177511, 0.05423348217404314, 0.02254840568639338, 0.07488767084266458, 0.04288900430713381, 0.06919248894389186, 0.03155879942434175, 0.02459101322373109, 0.02775657586088138, 0.04470399048711572, 0.022294173881943737, 0.06091391388326883, 0.09987363724836282, 0.023212642275861332, 0.03463182345564876, 0.03176539298146963, 0.0450985484224345, 0.015578682268304484, 0.017804100710366453, 0.08839759483401265, 0.02202946549680616, 0.04017612970034991, 0.030653501395136118, 0.029146705820624317, 0.0793212525812643, 0.06470104173890182, 0.05410350200587085, 0.0335703097017748, 0.08745911304972001, 0.08315898557858807, 0.047823263465293815, 0.05806792088385139, 0.05830791871994734, 0.039296212273516824, 0.045965095316725116, 0.01941605394573084, 0.05161429628995912, 0.04376125428825617, 0.03488212823867798, 0.03758382737370474, 0.01798811092573617, 0.02273782721853682, 0.061401210592261384, 0.03448217594996095, 0.013097309391014278, 0.035826235078275204, 0.013089430751278996, 0.03938355669379234, 0.005088168711933706, 0.04591189477858799, 0.008641656604595482, 0.059952178703887124, 0.056937820810292444, 0.022555560838165026, 0.0031097652182714747, 0.04634643538988062, 0.046896584797650576, 0.05600086572979178, 0.030376577683325325, 0.03259343301345195, 0.02546440314368478, 0.01881558438097792, 0.07499364444187709, 0.01877089436831219, 0.045493907029075284, 0.1146484658654247, 0.044858835571046383, 0.03658859970580254, 0.024745899019762874, 0.08545475453138351, 0.027751001695703183, 0.04757844803056546, 0.014261391346475907, 0.024279601273259947, 0.020505397813394666, 0.03116800735837647, 0.013958364392497709, 0.03962779198107975, 0.027505219348573258, 0.007080005290585437, 0.0389993735589087, 0.04436339644183006, 0.040098953127328835, 0.07271715945431165, 0.009380696590856781, 0.009396682875896139, 0.028608610587460653, 0.0151973320171237, 0.015550735107223903, 0.015365696911300932, 0.017386861045711806, 0.039874330894755464, 0.01625906629487872, 0.02714622682625694, 0.012009649986534246, 0.07392738772822277, 0.03248690640819924, 0.05065793510792511, 0.0030862711552929667, 0.03257817615355764, 0.09641736985317298, 0.011721611871117992, 0.022564921228747283, 0.07261901614921433, 0.08657872743372406, 0.018222347999523793, 0.0324964635739369, 0.0049433214174184415, 0.032819344462560754, 0.05474846650447164, 0.08857585955411196, 0.04070532933941909, 0.03589559153520635, 0.09993674100509711, 0.0669313727744988, 0.04122821181746466, 0.012692815158516169, 0.031798156044845066, 0.03182402179975595, 0.05027069178010736, 0.02097892535052129, 0.048976063927901645, 0.037011398268597465, 0.02396724107010024, 0.07990330670561109, 0.021209282900339792, 0.04152627868045654, 0.02200215106963047, 0.07082213328352996, 0.038055748479174714, 0.0389179425713207, 0.021058198596749986, 0.05194791838792818, 0.05214079875232918, 0.01400633342564106, 0.01655319595842489, 0.03961808893031307, 0.02588125773971634, 0.05602166622078844, 0.020616701305178658, 0.0474253603523331, 0.02756552754103073, 0.022992781662781323, 0.08695089032075234, 0.06884311126278979, 0.02789901732467115, 0.03863240146477308, 0.07555726276976721, 0.10028446984610387, 0.029109226938869272, 0.03485393510865314, 0.036444991161780696, 0.07482011589620795, 0.013932696260911013, 0.034778590580182414, 0.0747463862810816, 0.024940569020275558, 0.020368167498548116, 0.025722012356189743, 0.012051551220273333, 0.040992804270769866, 0.00932425435166806, 0.02536917245015502, 0.0298670284183962, 0.0711746932938695, 0.013339596434629388, 0.04044595254319055, 0.01713825429656676, 0.050663614446031194, 0.030949264631739686, 0.017379108783123747, 0.02365665353967675, 0.071102850006095, 0.02752349229662546, 0.09841745360089199, 0.026406852661498954, 0.055501335034413, 0.015310129982286265, 0.0389091080453779, 0.019961792875879576, 0.08665019074188811, 0.025699556239747574, 0.045444183982908726, 0.0754044498982174, 0.05559197034952896, 0.0264050969521382, 0.02121520142203995, 0.035820511635392904, 0.01924367212424321, 0.03780077198254211, 0.04049388086423278, 0.06944324834538357, 0.05491953196802309, 0.04261542916564005, 0.026972445526293347, 0.13039141467639379, 0.06458233882273946, 0.01837856033151703, 0.0685910355033619, 0.01654479230221893, 0.12831737739699228, 0.037751920853874514, 0.040977540625525374, 0.036092220805585384, 0.04141743827079024, 0.016549828728394847, 0.025119875291628496, 0.0661377582166876, 0.06881360856017896, 0.040007795340248516, 0.03221134315910084, 0.02476195146196655, 0.09394131414592266, 0.02424701802166445, 0.025607097361768996, 0.018946957242275988, 0.005678673989937774, 0.04183342434199793, 0.06101023871451616, 0.033186764389808686, 0.09496883329536233, 0.01948530353339655, 0.03535591531544924, 0.01330437877082399, 0.04234929076795067, 0.01910032142352845, 0.02628450601228646, 0.03867915252755795, 0.006435864787947918, 0.028220832913315723, 0.03440736746415496, 0.03842368409303682, 0.06764110004795448, 0.040447981362896304, 0.048091769950198274, 0.03006918096382703, 0.036627405123519044, 0.06437125336378813, 0.053683902735688856, 0.04165886781577553, 0.030730454051601033, 0.05384591314941645, 0.04147917817213705, 0.05367047113499471, 0.041733442207000086, 0.024570879393390248, 0.037396365111427646, 0.03433679642954043, 0.1170865778944322, 0.09988485343222107, 0.10163008621228592, 0.1188503618219069, 0.2946949510702065, 0.07746625997658287, 0.11093009396323136, 0.08589363098144531, 0.13755077336515698, 0.13484174944460392, 0.15436526467757566, 0.14337381161749363, 0.1432057927761759, 0.08826903280402933, 0.161762409178274, 0.09305953074778829, 0.07216095072882515, 0.07427105214446783, 0.13580001731004032, 0.10181202180683613, 0.08492375338183981, 0.09564858967704432, 0.04725632031581231, 0.10210382579160587, 0.15758013645453112, 0.13529902776437147, 0.0835541711587991, 0.14886291564575263, 0.19680545878197464, 0.07060057802924088, 0.12595733760723046, 0.15062181412109307, 0.11385360280317919, 0.13993196987680026, 0.12840751398886951, 0.1329436834369387, 0.07957116381398269, 0.24306782707571983, 0.14963366357343538, 0.1071748301120741, 0.07982859321470771, 0.2713513379650456, 0.11062549959336009, 0.10411232337355614, 0.10338747833988496, 0.06838353270930903, 0.10610616459910359, 0.11144302572522845, 0.19419130762772902, 0.07918980677745172, 0.1534728282796485, 0.09497257880866528, 0.1405573891741889, 0.12048759896840368, 0.06393633277288505, 0.11433967814913817, 0.14069662456001553, 0.0908055527667914, 0.16300862016422407, 0.07331513879554612, 0.14702492712863854, 0.13419781971190656, 0.12691165639885835, 0.13494069342102322, 0.11870742163487844, 0.08185608299182993, 0.1747018548526934, 0.10575279713209186, 0.2540124612195151, 0.0905597195295351, 0.09295302789126124, 0.13750793066407951, 0.13295033308012144, 0.1511866402413164, 0.23012273598994526, 0.2154402152768203, 0.194102053131376, 0.12827893160283566, 0.08855437713542155, 0.08737874057676111, 0.21949275210499763, 0.08527722262910434, 0.22689524346164294, 0.19970891012677125, 0.10477152014417307, 0.11348513114665236, 0.08687975949474744, 0.1119192216013159, 0.13088529317506722, 0.11162633196051631, 0.13667650813502924, 0.11573181487619877, 0.19091411919466086, 0.14243279211223125, 0.2121708842792681, 0.07548953140420572, 0.18279208216284, 0.09521199988999537, 0.07224941133920636, 0.09588685724884272, 0.12588966052447045, 0.09760964409049068, 0.20777149392025812, 0.08764672119702611, 0.21260377605046543, 0.09361523735736098, 0.09436872335416929, 0.12264388826276575, 0.15632259393376963, 0.129417160525918, 0.14794023015669414, 0.16205785689609392, 0.1702187875551837, 0.2567925548979214, 0.09864998076643262, 0.185649555974773, 0.2165227907576731, 0.10585590731352568, 0.092958367961858, 0.07878727944833891, 0.08280573346252952, 0.2215270000909056, 0.07503608002194337, 0.27588859306914465, 0.16034515308482306, 0.16485365187483175, 0.16895346902310848, 0.12609598945294107, 0.1675651456628527, 0.1683501699673278, 0.09627876550491367, 0.1133133600066815, 0.21652988823396818, 0.10401181198124375, 0.11717139477176325, 0.10033799268837486, 0.16638304266546453, 0.08546785704259362, 0.09595420184944357, 0.16371022537350655, 0.24856159942490713, 0.10124551291976656, 0.17718291814838136, 0.11084800479667527, 0.058039910958281586, 0.1199867587004389, 0.10318052515919719, 0.12389003139521394, 0.14726518280804157, 0.0726934310847095, 0.11250523158482142, 0.09660419089985745, 0.11921477583902222, 0.11709170761917319, 0.13084515104336397, 0.17477558446781977, 0.08899669375802789, 0.1331315426422017, 0.061448389132108004, 0.19326415737824781, 0.14341517511223043, 0.08691738426153149, 0.09799963209245886, 0.17877347208559513, 0.12047752950872694, 0.18643341319901602, 0.1211924340043749, 0.14003605714866094, 0.1094480784876006, 0.13237356474356993, 0.20416965362216744, 0.2086875976196357, 0.10833319795450994, 0.13235802629164287, 0.13189165560262545, 0.1379590614565781], [0.043673641846648285, 0.03500139433890581, 0.013298752019181848, 0.045369650303785286, 0.04384978614481432, 0.026343462223719274, 0.024282396837536777, 0.09023544085877282, 0.05468333392803158, 0.007439900688560945, 0.03752091699945075, 0.03460024782855596, 0.04032301217583673, 0.03803178262231605, 0.04052729871390121, 0.010873462605689253, 0.05370127323216625, 0.028623212661061968, 0.08157550876161881, 0.02940866444259882, 0.021328191073345285, 0.02388842753134668, 0.04010184029383319, 0.05417705520189234, 0.01759152756338673, 0.08913691980498177, 0.06721385368811232, 0.033008665910788944, 0.06652374964739595, 0.029883299688143388, 0.031796134010489495, 0.07017653435468674, 0.1189870187746627, 0.057810457556375434, 0.02177698940171727, 0.02123416817214872, 0.037453365445669205, 0.022056403337046504, 0.03183005736874683, 0.04540028615987726, 0.013193917510631894, 0.08113070191549403, 0.022628803604415486, 0.04023313342726656, 0.12314042661871229, 0.0904236596875957, 0.04621347306030137, 0.004352430646706904, 0.024507926610697593, 0.024113611251647984, 0.04839119388322745, 0.046126749499567916, 0.043414125950740914, 0.004719085101636925, 0.08490400801279716, 0.030805126830403293, 0.06412755072649036, 0.04019858581679208, 0.04578423859285457, 0.026933770726567934, 0.06001729092427662, 0.025318507936650088, 0.03494093347606914, 0.03592288221365639, 0.016111539211124182, 0.01834329347392278, 0.020321453755189265, 0.008032891949239587, 0.03181915331099715, 0.019119870017415712, 0.03181417625663536, 0.025773927070466534, 0.0072136296158922565, 0.045199972444346974, 0.013640194233240826, 0.06020037324300834, 0.03972860871415053, 0.03819887187065823, 0.020963336008467844, 0.08032595259802681, 0.033002908541155715, 0.05295000604486891, 0.022540134344516054, 0.02238022060399609, 0.0386919293419591, 0.12911039484398706, 0.02441689435259572, 0.028003671173272387, 0.010435438565244632, 0.021116596713129963, 0.009379717804092382, 0.02787039502124701, 0.03811862153400268, 0.036201023895825656, 0.04391259813149061, 0.019470657355019023, 0.05786500498652458, 0.014157036901451647, 0.03173647042629974, 0.019072856022311107, 0.05855681893548795, 0.020217458085556115, 0.018357267902631844, 0.10657078466777291, 0.01932699792087078, 0.06084996195776122, 0.03186835388519934, 0.04965074486764414, 0.03706908731588295, 0.019350018917715976, 0.04224988878039377, 0.06399096841258661, 0.02029354900254735, 0.013829977933450468, 0.026972248751137937, 0.043955128706459484, 0.01811476966499218, 0.0074693745534334865, 0.011874620669654437, 0.02610815645727728, 0.023297891719266772, 0.055344440774726014, 0.052232526508825164, 0.05386960759226765, 0.032578077765979936, 0.03174477908760309, 0.008628290312896882, 0.02430262735911778, 0.05706748885235616, 0.02904211643284985, 0.0469911556158747, 0.022028881956690123, 0.023128198592790535, 0.014516946294211915, 0.021588516122262393, 0.02853604805256639, 0.054123627354523966, 0.030776842098150934, 0.05573420825281313, 0.03826365500156369, 0.05253773834556341, 0.009459479595534503, 0.04455130992989455, 0.030276476804699217, 0.06669790923063244, 0.04413181922531553, 0.06320638515587364, 0.030383946573627845, 0.031079234621886696, 0.0381606805271336, 0.07432605419307947, 0.03290692297741771, 0.047499771895153184, 0.0317037073629243, 0.06702051870524883, 0.07198239423866783, 0.07759522234222718, 0.08933386459414448, 0.026210372668824027, 0.04778527568227478, 0.027952002427939857, 0.02108227980456182, 0.0344362119877977, 0.04372808410386954, 0.02069252250449998, 0.022942341065832546, 0.05673340874324952, 0.022222082928887436, 0.03692013191591416, 0.03523858304002455, 0.01583504636905023, 0.042636921762355735, 0.034719965154571195, 0.00953720323741436, 0.03751662865813289, 0.0476323474597718, 0.021967004652002027, 0.04672221486855831, 0.0508962026797235, 0.05087986355647445, 0.07269896793046168, 0.04591712289090667, 0.032870085311255286, 0.06967728864401579, 0.08671533688902855, 0.044805506111255715, 0.07847737214927163, 0.06523768829980067, 0.050980595472667894, 0.04527408203908375, 0.058086675591766834, 0.02571733046456107, 0.0845623452748571, 0.023715228075161576, 0.060590910858341625, 0.04221205027507884, 0.020889606393341507, 0.02589304050031517, 0.03516425631408181, 0.0484849979568805, 0.021544245104970675, 0.02759085894961442, 0.008264995878562331, 0.027196718313332115, 0.06577092182955571, 0.028324190760031343, 0.061252787842282226, 0.061490112250404697, 0.029280652025980607, 0.028945642323898416, 0.036316802326057634, 0.015391123314787234, 0.027428890944325497, 0.016636957713801945, 0.014692607136177165, 0.013596559342529093, 0.01729792376448001, 0.06088212451764515, 0.018041711799534302, 0.014275649063555258, 0.012122963638310986, 0.04948031383433512, 0.0470389991200396, 0.028224915997790437, 0.08578453612114702, 0.014317984559706278, 0.016134724752711396, 0.04479788616299629, 0.0432512741535902, 0.023468843528202603, 0.10923695231654815, 0.038078537077776024, 0.013669657920088087, 0.013765012446258749, 0.017981834476813674, 0.048094562121800015, 0.018112398185102, 0.04899506630109889, 0.07305507667894874, 0.014114831175122942, 0.010673991121750857, 0.04524026385375431, 0.05616934936759727, 0.03257649677938648, 0.04362603582973991, 0.026612565819440142, 0.06674535918448653, 0.01566781971736678, 0.056216677185148, 0.034284932605390034, 0.07282272593251296, 0.008981058972754648, 0.036194272472390106, 0.024148470988231044, 0.04266307928732463, 0.053888019639998674, 0.046206796275717874, 0.030293260368385484, 0.07842840227697577, 0.04837357572146824, 0.02163502630511565, 0.054527986728187115, 0.1050324643562947, 0.04870556594271745, 0.05469671463859933, 0.03608510636591485, 0.015311532853437322, 0.08849887975624629, 0.02401893356415842, 0.014868851518258452, 0.016829064548281685, 0.03812957987455385, 0.018862871486427527, 0.008807676312114512, 0.02350385593516486, 0.003147520391004426, 0.05467010249516793, 0.013800466749151903, 0.015250954943309938, 0.026752159132489135, 0.018531412218830416, 0.02827264415100217, 0.04422916525176593, 0.05267162009009293, 0.011862757333022143, 0.057300524919160774, 0.024477000680885146, 0.013380101582567607, 0.08060791103967599, 0.04159478696861437, 0.02914149806435619, 0.007292094557279987, 0.024248095196006552, 0.03799993558121579, 0.03394735125558717, 0.04718908428081444, 0.06736495665141515, 0.0413494795959975, 0.018123261530750563, 0.015037185878359845, 0.034878057028566084, 0.046104744608913145, 0.02599912436146821, 0.026061958400532603, 0.04846607700788549, 0.025102073925414255, 0.01800060784444213, 0.010059318970888853, 0.048506989276834896, 0.02366143890789577, 0.010891161343481923, 0.03326651600322553, 0.04150045703032187, 0.04926621228722589, 0.03967880763645683, 0.01947343595592039, 0.0352463420879628, 0.013259304537703949, 0.029371697854782854, 0.04523758364043065, 0.01127776684838214, 0.030289311294576952, 0.036768465768545866, 0.04364489571058324, 0.07107596644865614, 0.05807550012000969, 0.08534041459539107, 0.018952505962390984, 0.052569062914699316, 0.020723823324910233, 0.04034620789544923, 0.030662960173296075, 0.006145018385723233, 0.026530581825811948, 0.033450819684990814, 0.04467959376052022, 0.01774422508398337, 0.04292470881981509, 0.026271876779251864, 0.021425486209669282, 0.04168278956785798, 0.010550859916423048, 0.03338634528751884, 0.04676329337858728, 0.0410911375656724, 0.04768102216933455, 0.04137955566069909, 0.05313291533717087, 0.02527186713580574, 0.061034543838884146, 0.02715770763877247, 0.012234669162093528, 0.10126130242965051, 0.10475170013627835, 0.1678767425141164, 0.1543995849788189, 0.13570447957941464, 0.14329990558326244, 0.12646997081381933, 0.19705376188669885, 0.10496272452707801, 0.10828148680073874, 0.1823218438242163, 0.12926340449069226, 0.10945698086704526, 0.13913101357008728, 0.13181183274303163, 0.1551575900188514, 0.1921972424856254, 0.13661591495786393, 0.13349112548998424, 0.10240226584885802, 0.15070531464048795, 0.15552827369953903, 0.20843902310090406, 0.1272216790488788, 0.08074361804340567, 0.15913305883961065, 0.13301123838339532, 0.12665021685617311, 0.18424193507858685, 0.1453515647777489, 0.09524826080139194, 0.10434181070221321, 0.21464030391403607, 0.18780755517738207, 0.10762357246130705, 0.11865121179393359, 0.11155328088040863, 0.09383537447346108, 0.11725291396890368, 0.14929841299142155, 0.14133702591061592, 0.19137936351554735, 0.08466287023786988, 0.14986356480845384, 0.16320943938834326, 0.17344961847577775, 0.16352182334022863, 0.1443729137203523, 0.1581928264349699, 0.07397586226995502, 0.1432060913315841, 0.12908292774643215, 0.13070405647158623, 0.08789335510560445, 0.21707642105008873, 0.1572884749621153, 0.1061828187001603, 0.12746254540979862, 0.07972850251410689, 0.14848104970795767, 0.11673445893185479, 0.14655250390725477, 0.09642830783767359, 0.14105778160904134, 0.07781920675188303, 0.1536014106656824, 0.12608836271933146, 0.12864019721746445, 0.1844060184167964, 0.07952780542629105, 0.11670612330947604, 0.0992956068366766, 0.11768253520131111, 0.10112257594508783, 0.09704536079828228, 0.14745283845279897, 0.11941202596894332, 0.10626285190560988, 0.10555004408316952, 0.17214985750615597, 0.1365545889628785, 0.10450549370476178, 0.12682132981717587, 0.12919515743851662, 0.10399405471980572, 0.20099691886987003, 0.22300619286085877, 0.11271922795900277, 0.138824817857572, 0.11613468825817108, 0.11156643767442022, 0.2025416309812239, 0.10173636515225683, 0.12544451441083634, 0.11942269253943648, 0.11915243204150881, 0.19050778528409346, 0.15161548794380256, 0.09932980500161648, 0.10399640245097024, 0.17928914512906755, 0.08685340519462313, 0.11535917701465742, 0.12286173871585301, 0.0956526676725064, 0.10481154692492314, 0.1814000132892813, 0.13474910227315767, 0.05866106905575309, 0.10525731729077441, 0.11115122174045869, 0.18917415184634073, 0.27998727027859005, 0.07431586259709937, 0.13771325536072254, 0.14050793754202978, 0.10015678312629461, 0.1381121796688863, 0.1267073902168444, 0.14342744302536758, 0.2942711923803602, 0.10945238718496901, 0.1719368789345026, 0.14214406189109596, 0.15227400617940084, 0.07528944499790668, 0.10626010383878436, 0.06912209772105728, 0.13574422816080706, 0.08941161113658122, 0.13205947088343756, 0.11584304033645562, 0.14163368142076901, 0.16237363352307252, 0.1661429905465671, 0.13587149418890476, 0.14673393060054096, 0.22535655674125465, 0.18365501585815633, 0.1091854107965316, 0.12845011241734028, 0.09877484478056431, 0.11986654943653516, 0.08854278775730304, 0.0686698066336768, 0.16423151668693337, 0.12992805668285914, 0.1057435419144375, 0.15046880447438785, 0.1127833698743156, 0.15726255492440291, 0.08637471909501723, 0.1806078100843089, 0.08024361237351384, 0.18431873167199747, 0.11968897682215486, 0.17412405514291354, 0.17378347127565316, 0.14125592740518705, 0.14784850579287323, 0.0631085064794336, 0.14752814226916858, 0.09920928361160414, 0.17731542246682302, 0.14530908848558152, 0.12688636061336311, 0.11277414179806199, 0.1420549973845482, 0.08666984790137836, 0.10567954249147858, 0.0814794757004295, 0.18982363199549063, 0.13752870740635054, 0.132973457553557, 0.11356325088334934, 0.1280108695583684], [0.010187397544671382, 0.1032169692750488, 0.09071921597101859, 0.06385339543755565, 0.02769022192140775, 0.028808707171784978, 0.04730082542768546, 0.02002508153340646, 0.018314353955377425, 0.05975414825869458, 0.04659462992900184, 0.018273894608552967, 0.028530731730695282, 0.0207073467983199, 0.022269029070490172, 0.0733809159802539, 0.06273161420332533, 0.07903271234993424, 0.02576176093758217, 0.08608157839626074, 0.03746836446225643, 0.07529513790671315, 0.011243579709636313, 0.04082098224067262, 0.04138218159122126, 0.007938596785866787, 0.060100506458963664, 0.049734130036085844, 0.026436187426692674, 0.025796417113659636, 0.016404072621038983, 0.038613494086478434, 0.027033562871760557, 0.030196036478238444, 0.08030569154236998, 0.06466993769364697, 0.055162111629865, 0.0488520345118429, 0.03275556895615799, 0.021484031907415817, 0.024285987984122973, 0.02902735151084406, 0.0420476548107607, 0.00907123033955161, 0.04181072395294905, 0.006665722766358937, 0.015051630192569323, 0.04187018058395811, 0.05565093504264951, 0.057763129738824706, 0.0446505354983466, 0.06624118052423, 0.07510547379830054, 0.06070550185229097, 0.0591097299807838, 0.12768092512020043, 0.022703993766169463, 0.024632714289639677, 0.02114503750843661, 0.037135319119053226, 0.05364363846768226, 0.03881563984655908, 0.01554856718783932, 0.05056545417755842, 0.016547547154394642, 0.01908218248614243, 0.06602301794503417, 0.013616278418339789, 0.07607414360557284, 0.02687863975630275, 0.016724461589806845, 0.025619251620290533, 0.029800616803445985, 0.002616019033926672, 0.026186530644606267, 0.03930646154497351, 0.0056037679647228545, 0.024675333074160984, 0.044100864457764795, 0.01455385351021375, 0.031145883724093437, 0.02794857582609568, 0.0471581804033901, 0.0039841468595633546, 0.006848038340519581, 0.034181143888937573, 0.05620435838188444, 0.012765096101377691, 0.04703610177550997, 0.03757529479584523, 0.04577181122398802, 0.05075472812833531, 0.01805267862177321, 0.004482278924634946, 0.017496106880051748, 0.040649519834135256, 0.06407503890139715, 0.033976487549287934, 0.01030030322726816, 0.023347577446007302, 0.05413739483005234, 0.032930675095745494, 0.08503366248416049, 0.04500923285792981, 0.017413503723219037, 0.0538756058418325, 0.025572809290939143, 0.02495980209537915, 0.08140109133507524, 0.04672461009717413, 0.0757890096200364, 0.06040814745106867, 0.0304619848861226, 0.009413418942131102, 0.05481940055532115, 0.017258843540080955, 0.03743018329675708, 0.03613407284553562, 0.04219930060207844, 0.0248773685723011, 0.04415734571271709, 0.04360583244955965, 0.06469593915556159, 0.03288700118927019, 0.03884207557088562, 0.0419683374597558, 0.008310419557216977, 0.011371920367569795, 0.043181775204305134, 0.015894475858658552, 0.023343470612806932, 0.0998088303687317, 0.03974211495369673, 0.017342598510107825, 0.07430694664695434, 0.042230557317712476, 0.049344973239515505, 0.06747760024986096, 0.048342939865376265, 0.032721825409680605, 0.05065546524045723, 0.04123428809855666, 0.07123480471117155, 0.016648906715480343, 0.011683793721853622, 0.053362687650535784, 0.015264238962637526, 0.13905740609126432, 0.018310116504185965, 0.0257863442613078, 0.08510491544646875, 0.0399100591561624, 0.016108828463724682, 0.030049343992556845, 0.05368303421086498, 0.048504102110330544, 0.0665175953347768, 0.04388852031635387, 0.06616967650396482, 0.007569820636750332, 0.06386620617870774, 0.03757718451587217, 0.0410797890674855, 0.011153714531766517, 0.0261709005904517, 0.010813787147136671, 0.029499187799436704, 0.05976564942726067, 0.053933854680508375, 0.04199697503021785, 0.05308280891871878, 0.07637081947177649, 0.032330914600087066, 0.056121329444327524, 0.05628225759470037, 0.04600923741236329, 0.03444108726190669, 0.039761113934218884, 0.026085744445611323, 0.04564271654401507, 0.08063844511551516, 0.036009480245411396, 0.030367030695612942, 0.05972473376563617, 0.03886048761861665, 0.04223783799846258, 0.06916151382029057, 0.05313341745308467, 0.025898657073932033, 0.0495593936980835, 0.09474020092082874, 0.024311775707506707, 0.020421898990337337, 0.018648873415908644, 0.02340169231008206, 0.049066855306071896, 0.08121278429669992, 0.05726317835173436, 0.01889406713390989, 0.040497741728488884, 0.08534755278378725, 0.06554865411349706, 0.044536375374134095, 0.06082065603030579, 0.0558084773032793, 0.02419321528369827, 0.02633654455920415, 0.0590396983815091, 0.04329403882314052, 0.04243613985766258, 0.03815581543104989, 0.028826216767941202, 0.1165080860789333, 0.04300316103867122, 0.030775254326207296, 0.057507301680743694, 0.020683112920128872, 0.04324124540601458, 0.05116300943440624, 0.01191493752412498, 0.0340062243464802, 0.02333537908270955, 0.015808983838983943, 0.08475597881312881, 0.015647521342283914, 0.03424615432907428, 0.02610466878728143, 0.06645128889275448, 0.060049439913460186, 0.05196369093443666, 0.07240397483110428, 0.05273081887779491, 0.05715221752013479, 0.027883836799966435, 0.04911847825029066, 0.07324185701353209, 0.050036091690084765, 0.03647081281191536, 0.031029168915535723, 0.06471361499279737, 0.08013858193797724, 0.05053998875830855, 0.058449135428028445, 0.016511484714491025, 0.0324874288801636, 0.04109509681750621, 0.03388645613033857, 0.07780763772981507, 0.061584808597607274, 0.032196123618632555, 0.0825805344751903, 0.05482939876882093, 0.07029683182814292, 0.03456448903307319, 0.046893928333052566, 0.07042524458042212, 0.044993066761110506, 0.049482566570597034, 0.11878024201307978, 0.02628833464612918, 0.03417935934183853, 0.08525472240788595, 0.08248752768018416, 0.02144080413771527, 0.10186312906444073, 0.020771448001531616, 0.04852888899456177, 0.05371069469090019, 0.0168959273890193, 0.046871102415025234, 0.01066172999396388, 0.02234839561528393, 0.02488381295864071, 0.04031621325494988, 0.005758211864823741, 0.015585223345884254, 0.062499365237142356, 0.02789849994171943, 0.03246175650773304, 0.022425938597215072, 0.031863207197082896, 0.043778248197798214, 0.01837874692864716, 0.027214333082416227, 0.0555159438933645, 0.02123971519592617, 0.04944155252139483, 0.04666144527228815, 0.015985094210399047, 0.028511240812284604, 0.054082240111061504, 0.0043102762345889846, 0.024282239078144943, 0.014064075059390493, 0.031181391461619308, 0.02424047015873449, 0.00817588557090078, 0.03354354149528912, 0.0749817972204515, 0.03392963131357517, 0.020643355857048715, 0.026459271188027093, 0.006636302760203502, 0.019418138744575635, 0.005771009459359837, 0.0360553627833724, 0.04955004687820162, 0.050747318525931666, 0.026439434216756905, 0.06662527205688612, 0.07431542154933725, 0.05707103759050369, 0.052055330481380224, 0.0308856994711927, 0.040898535400629044, 0.03878946875088981, 0.06239951202379806, 0.0904963579294937, 0.04724709902490888, 0.04758442931675485, 0.04139622387343219, 0.016170570061409047, 0.039538530699376545, 0.05626366234251431, 0.005569808983377048, 0.017604256880336573, 0.04208717608292188, 0.01431680899778647, 0.04021637700498104, 0.032612998570714674, 0.044990929375801764, 0.03459441921274577, 0.027581435794542943, 0.04683448527274387, 0.03829722212893622, 0.018817112781107426, 0.07421235886535474, 0.050240619108080864, 0.015539293310471942, 0.0422944515677435, 0.05672499490901828, 0.015379494920905148, 0.025569779632080878, 0.03190079464444092, 0.031112096072839837, 0.03167433697464211, 0.02698332753165492, 0.06505288928747177, 0.039219497104308436, 0.023009443090164235, 0.03987766928704722, 0.011222635878116956, 0.15625149703451566, 0.10098342876881361, 0.24785958709461348, 0.20656463796538965, 0.1443947489772524, 0.09850662667304277, 0.1720068087535245, 0.13271167874336243, 0.13772639179868357, 0.17123977919774397, 0.10203293923820768, 0.10285657897059407, 0.15053075472159044, 0.13656034293983663, 0.2927821879940373, 0.14315860745097908, 0.1258928496390581, 0.13307371788791247, 0.11421744685087885, 0.22907958339367593, 0.14083401433059148, 0.17901953602475779, 0.06922785418906383, 0.11379568983933755, 0.20064569557351725, 0.08421735092997551, 0.11675849264221531, 0.13361119904688426, 0.16322853336376802, 0.11720718070864677, 0.07178088969417981, 0.1719353725867612, 0.17560753625418457, 0.11384889377014977, 0.2231680913163083, 0.14972530651305402, 0.23791400077087538, 0.15214010407882078, 0.16818395602915967, 0.15924140731138842, 0.1274728048592806, 0.074071264293577, 0.13473591155239514, 0.1295760598565851, 0.20095726528338023, 0.21906106812613352, 0.11488576313214642, 0.16001085245183536, 0.09769396563725811, 0.15491630296622003, 0.15600536524185113, 0.15821377959634575, 0.15194972072328838, 0.15365489279585226, 0.17973110212811402, 0.20239713016365254, 0.23947617837360927, 0.09468162977801901, 0.13732187636196613, 0.13269533962011337, 0.19895722903311253, 0.21847988931196077, 0.09833323383437735, 0.18428768190954412, 0.11750671320727893, 0.10991383170975105, 0.10694165833826576, 0.06260492492999349, 0.19631569220551423, 0.0718380766255515, 0.144388330035976, 0.13126314218555177, 0.09961676424635307, 0.14401776849159173, 0.14298431894608907, 0.156661685023989, 0.13521834995065415, 0.06456235596644026, 0.14425627355064663, 0.12146346803222384, 0.08722621268991913, 0.14746224294815743, 0.174211871145027, 0.10842427092471293, 0.11988077153052602, 0.15347575955092907, 0.12058384237544877, 0.10709447799516575, 0.28164493132914814, 0.1899190340191126, 0.1953641011246613, 0.11880819765584809, 0.10642046880509172, 0.09974188610379185, 0.07556319995118038, 0.08861920437110321, 0.08985041294779096, 0.1559687243508441, 0.095110871030816, 0.07317033263721637, 0.14598131312855653, 0.2150747970278774, 0.0886353806459478, 0.15463301459593431, 0.08621251529880933, 0.07666626040424619, 0.12980597466230392, 0.10692224545138222, 0.16595272932733807, 0.15569139351802214, 0.15823045798710414, 0.09638622509581701, 0.1218287641448634, 0.10906492333327021, 0.09738494721906525, 0.12030671510313239, 0.07814290866787944, 0.16970671074731009, 0.11235891229340009, 0.09171040635555983, 0.13825668048645767, 0.1433666462876967, 0.1680766117892095, 0.1358701099774667, 0.12055226335568087, 0.08145555734102215, 0.19631865061819553, 0.07307520881295204, 0.14653745400054113, 0.07691408853445734, 0.060931148672742505, 0.12145513562219483, 0.09072228294930287, 0.16191364106323036, 0.109021653155131, 0.15780471797500337, 0.13854873552918434, 0.11026591674557754, 0.12677939635302338, 0.10181718545832805, 0.10714207044137375, 0.2022550856428487, 0.14357887847082956, 0.09998304423476968, 0.13233494253030845, 0.13098878333611147, 0.15061987351093972, 0.1829481723585299, 0.12097538422260966, 0.09543114634496824, 0.2239355415638004, 0.10880526155233383, 0.12037672634635653, 0.1778455211647919, 0.11395410741014139, 0.09519768958645207, 0.18399944023362227, 0.10753795491265399, 0.1526786708938224, 0.09924435708671808, 0.17917971100125993, 0.13268369595919335, 0.1652377298367875, 0.09954989462026528, 0.23928903841546603, 0.050301738149885616, 0.0982456621048706, 0.10800787433981895, 0.16849414152758463, 0.19049608734037193, 0.1585309404347624, 0.23729392832943372, 0.11522802976625306, 0.17412134100283894, 0.12537619950515883, 0.1392657570540905], [0.03044193417632154, 0.058529093994625976, 0.018815838831609914, 0.03088194038718939, 0.02791732589581183, 0.041499615646898746, 0.01263101418901767, 0.002883298642700538, 0.02699032492403473, 0.02826749746288572, 0.026873750911493386, 0.02835600048170558, 0.049906430433371236, 0.038108355299170525, 0.04258896290723767, 0.012058931136769908, 0.0639160785025784, 0.029159743871007646, 0.023850526261542524, 0.054722190235874484, 0.0327765492589346, 0.04564880978848253, 0.019394116908577935, 0.03383763553574681, 0.04370079003274441, 0.04835365732599582, 0.012882279947267046, 0.04470300321866359, 0.03967176444296326, 0.015005742565595677, 0.033807369481239996, 0.01525344347049083, 0.04678208540592875, 0.08646111017359154, 0.04611038662759321, 0.07230372128209897, 0.06695960661662476, 0.06683156705860581, 0.009111581968941858, 0.09182435274124146, 0.02433592307248286, 0.05001142015680671, 0.04048957216686436, 0.07381535481129374, 0.07174760076616492, 0.0068586854031309485, 0.04470615501382521, 0.02642743262861456, 0.042702865188143084, 0.036893088902745924, 0.03898566375885691, 0.01456796534226409, 0.06922488899103232, 0.04048992839774915, 0.018850189666928988, 0.01637972508823233, 0.023055337502488067, 0.0509145774080285, 0.013163113717122801, 0.04984135213973267, 0.04148987866938114, 0.03872060083917209, 0.015199711978701609, 0.015174840277593051, 0.06766556802072696, 0.04104459345606821, 0.018301426166934625, 0.02960308168881706, 0.03863260841795376, 0.02145242235357208, 0.02766387101395854, 0.06613598724028893, 0.03689128399959632, 0.045106436392026286, 0.0504923182805734, 0.0517673262927149, 0.041169348904596906, 0.07245312112250499, 0.012043929575676364, 0.04694779383550797, 0.035936951637268066, 0.0361534619836935, 0.0803582915770156, 0.010213958797976375, 0.01073159959300288, 0.0646831759118608, 0.0035923442005046775, 0.014410324694056596, 0.039476577059498856, 0.035360777018857856, 0.028608301854027168, 0.0063493880443274975, 0.03175045842570918, 0.020340963333312954, 0.03276871217946921, 0.03247754601761699, 0.07755168075008051, 0.030635225054408823, 0.027666434179991484, 0.03661312874672668, 0.030746162137282745, 0.05110678602276104, 0.017527556978166103, 0.0236582854163966, 0.0200402230423476, 0.03131701364847166, 0.029503601669733013, 0.03105239516922406, 0.11642987813268389, 0.03588021932435887, 0.002108813895444785, 0.008491007411586387, 0.026797322423330376, 0.003097375380873148, 0.02989618167547243, 0.012107091856056025, 0.006906426278874278, 0.0016455004307707505, 0.04630218133596437, 0.05796675131257091, 0.0261742152340178, 0.026238185819238424, 0.06861398355769259, 0.043913805923823795, 0.030867440093840872, 0.04579108501119273, 0.037419767784220834, 0.0392411491567535, 0.007660018296779266, 0.016056822147220373, 0.04075402779770749, 0.021994502283632755, 0.045903918599443774, 0.04938242158719471, 0.05045709552775536, 0.0671165246250374, 0.01741483704453068, 0.02881282927202327, 0.024996746630807008, 0.03570927260443568, 0.06588587244706494, 0.03866056066804698, 0.007736079527863434, 0.013203464498344277, 0.053135639655270746, 0.022977502750498906, 0.041442520317754576, 0.03650385746732354, 0.0310732092309211, 0.031396466706480296, 0.02224385711763586, 0.03981096250936389, 0.051070304587483406, 0.06327539895262037, 0.030787915789655278, 0.07124222788427557, 0.019951049970196824, 0.03913242070536528, 0.03799088392406702, 0.037003710466836176, 0.03523636423051357, 0.0818418473271387, 0.050791843993855376, 0.03460932323443038, 0.038955811610711474, 0.06798310883875404, 0.012463922396169176, 0.02481084330273526, 0.021876942698976824, 0.06338918248989753, 0.03144903959972518, 0.015230693887653095, 0.049516076022492986, 0.08580180483737163, 0.02595075499266386, 0.028711680056793348, 0.061925134621560574, 0.03723254979455045, 0.05236998074022787, 0.0004638958385580086, 0.005802824694131101, 0.0613364919221827, 0.01724996660569949, 0.005960446258541197, 0.03413019269438727, 0.004522811638058296, 0.019353442126885056, 0.0041583904115084025, 0.00917712929991207, 0.07481497938611678, 0.02662313400235559, 0.0108454891513767, 0.03965180194271462, 0.023982274013438394, 0.03476501309445926, 0.06629782462758677, 0.039156783505209854, 0.017800104139106612, 0.009254639203261052, 0.045401490559535365, 0.0440620556473732, 0.02921808770458613, 0.04177814409402864, 0.0442691445350647, 0.028516360359000306, 0.06926218127565724, 0.022506139740081768, 0.023438909955854927, 0.026387945283204317, 0.027591225358524492, 0.04093412456235715, 0.04749048953609807, 0.028785799829555408, 0.03336376703477331, 0.03229465368869049, 0.04332045079874141, 0.04054738335045321, 0.03860963322222233, 0.02022201444820634, 0.046283161999391656, 0.16131924438689435, 0.03403236151539853, 0.022646165619205152, 0.013132457504980266, 0.02473884225556893, 0.066044079672013, 0.019462167185598185, 0.010735974447535617, 0.043204231320747306, 0.04045794904232025, 0.04447733943483659, 0.07099116314202547, 0.020859650768605725, 0.06053180367286716, 0.07929188558565718, 0.033701976029468436, 0.03400298094909106, 0.10152760706841946, 0.02236296036945922, 0.021017213385286074, 0.035382252652198076, 0.04516294478837933, 0.0238035987796528, 0.017613627448944107, 0.048898785574627776, 0.04197772838441389, 0.016230885039216707, 0.020332398525040065, 0.012879655713082423, 0.02097123415608491, 0.026462672344808067, 0.007652047206647694, 0.029476836855922426, 0.06813664774277381, 0.06477779083486114, 0.02939570103106754, 0.009459578831280981, 0.03230866204415049, 0.014931429410353303, 0.02463316042641444, 0.011627386257584606, 0.017160924151539803, 0.030136766444359506, 0.04991513943033559, 0.05215602507814765, 0.041747338604182005, 0.038647006931049485, 0.07770561998976128, 0.011144534801132977, 0.043963623964892964, 0.04547893176121371, 0.0733971261818494, 0.03892832415710602, 0.034989560688180585, 0.019832135011841143, 0.027154136848236834, 0.034580047841050794, 0.023981084880818213, 0.03444899219487395, 0.08357628461505685, 0.05159055095698152, 0.027393244107120802, 0.03801811692704048, 0.023366055650902644, 0.10896348234798227, 0.034264451025852134, 0.023587337794846723, 0.01330214214976877, 0.014568170599107231, 0.02023571407023285, 0.03999367841918554, 0.043761864969772954, 0.03164477659655469, 0.021334672779110924, 0.023760644120297263, 0.034302784861730676, 0.03868699978504862, 0.012230709910259714, 0.04252677856545363, 0.03255932305806449, 0.015544791140460541, 0.056646376449082575, 0.016065548107560192, 0.022935233411512206, 0.01081867259927094, 0.10482132461454187, 0.07244635612836905, 0.021027228562161326, 0.03437032284481185, 0.05248235971001642, 0.06396588975829737, 0.03690196414078985, 0.0323884272282677, 0.016255354708326713, 0.011050717156779553, 0.03337534284219146, 0.044741092781935415, 0.028972793902669634, 0.04337344438369785, 0.04960088272179876, 0.0381837235763669, 0.06711222271301917, 0.05747056579483407, 0.036471311535154066, 0.01340326591993549, 0.03156201907300523, 0.022289536095091274, 0.04654740049902882, 0.04048200989408152, 0.010796337770963354, 0.011626574560068548, 0.037316447256931236, 0.006290132853402091, 0.03347173552694065, 0.023266928470028297, 0.043336827241416485, 0.03403280595583575, 0.022070092781047736, 0.029398486417319094, 0.03842854918912053, 0.05076268395142896, 0.05012030467124922, 0.013056769468156355, 0.012753047863952816, 0.016226403315418532, 0.018969252206651226, 0.03865812812000513, 0.02063842460380069, 0.06050580899630274, 0.04206674200083528, 0.10899123443024498, 0.03561150588627372, 0.09959076956978866, 0.1525878964790276, 0.10940441475915057, 0.14305937848985195, 0.0531630728260747, 0.24118890932628087, 0.15600613877177238, 0.09325308964720794, 0.09681191761046648, 0.10871678058590208, 0.10411370758499418, 0.13291489998144762, 0.0846916740494115, 0.1779123025813273, 0.11638884033475604, 0.0765207689255476, 0.18022815617067472, 0.1480586209467479, 0.1406205472137247, 0.1422345648918833, 0.1691751057015998, 0.0944927731262786, 0.14541253793452466, 0.13287718700511114, 0.1351248071129833, 0.1540338546037674, 0.24257455925856317, 0.09414549890373435, 0.10354764653103692, 0.07980990636029414, 0.08761712349951267, 0.10968079564294644, 0.11827104219368526, 0.1406123097985983, 0.1629509718290397, 0.12362419494560786, 0.24185761915785925, 0.10916128209126846, 0.1061461710238031, 0.15028416152511323, 0.09788542786347014, 0.12426026724278927, 0.10555077690098967, 0.14201588662607328, 0.17930448002048902, 0.08497131868664708, 0.10846495588443109, 0.090675531886518, 0.11492595954665116, 0.14962805887418135, 0.11909383375729833, 0.08247825210647923, 0.1527005468628236, 0.0816489194652864, 0.16134084894188813, 0.128451849466988, 0.045141849134649546, 0.12903488746711186, 0.16225559557122843, 0.15976762478905066, 0.08437950044338192, 0.1481355939592634, 0.08754352280603987, 0.07466347608715296, 0.17769333933080944, 0.10618722239243132, 0.19286697011973175, 0.11315445389066424, 0.09880227116601807, 0.10287847529564585, 0.11799679190984794, 0.2094347189579691, 0.08858886707041945, 0.12246685847640038, 0.10387034421520573, 0.1149633332554783, 0.13594731369188853, 0.1511491715375866, 0.16541497675435884, 0.13437041187924997, 0.11535013892820903, 0.17087981637035096, 0.20461842311280115, 0.1334763334265777, 0.0869972003357751, 0.19364052718239172, 0.062385235647005696, 0.1056821480659502, 0.11976301856338978, 0.09822624243263688, 0.09357725296701704, 0.1792521106877497, 0.13077201853905404, 0.13350119494966098, 0.08641030147139515, 0.0949677476393325, 0.22853908953922136, 0.07912231289914676, 0.10880442695426089, 0.11437494839940753, 0.0968315340578556, 0.193424006657941, 0.11421659189675536, 0.14440754614770412, 0.1374589947185346, 0.07056331288601671, 0.1885569699640785, 0.09501589648425579, 0.15589781744139536, 0.11269281259072678, 0.11312911060771771, 0.10061749483325652, 0.12710285399641308, 0.07960717366742236, 0.1267408284225634, 0.1100764629830207, 0.17219284948493752, 0.0968433337818299, 0.1276144286883729, 0.14424130506813526, 0.09470256258334432, 0.0729264807222145, 0.15516639740339347, 0.13658517732151917, 0.1038633824459144, 0.16854341674063886, 0.14130555545645102, 0.16427108884922095, 0.06313236377068929, 0.22366646171680518, 0.22891231094087872, 0.07778957512761865, 0.13577024319342204, 0.11177938910467283, 0.11892755196562835, 0.13918285364551203, 0.0645342781873686, 0.16271541161196573, 0.06901127259646143, 0.09685750159301929, 0.10978868271091155, 0.179209403693676, 0.192233394831419, 0.1347875344966139, 0.18363027647137642, 0.12942824778812273, 0.16671447988067353, 0.13578914717904159, 0.07054020876863173, 0.06709073350897857, 0.13655671956283705, 0.1361368963760989, 0.25534276983567644, 0.14214719672288212, 0.12892313274954045, 0.18437211880726473, 0.12639123361025537, 0.10402992208089147, 0.09640356166554348, 0.15543094463646412, 0.14995551987418107, 0.12744300360126154, 0.07384955297623362, 0.11392735955970627, 0.28072014238153187, 0.13608607410320214, 0.08008044505757944, 0.0578039979029979, 0.13664049149623939, 0.0966150067480547, 0.14255981386772223, 0.132764604474817, 0.1373689259801592, 0.21852498474930013, 0.28308627541576115, 0.13857641975794519], [0.01928215523782585, 0.027292822620698383, 0.025945521791332533, 0.06654945933925253, 0.04312846949324012, 0.03638157867161291, 0.02812969378594841, 0.04242448601871729, 0.03864409940849457, 0.061744142190686295, 0.09930634126067162, 0.014288254547864199, 0.011669463062259768, 0.08649139997682401, 0.04389675773148026, 0.04481516166457108, 0.03332930763385125, 0.03644395639587726, 0.08065165619232825, 0.023780574390132512, 0.05250318394973874, 0.03830494725012353, 0.07311615840132747, 0.04767215371664081, 0.03810639772564173, 0.03856554540938564, 0.04461892594450286, 0.00952389377302357, 0.019401638469259654, 0.03635833206187401, 0.017379454835983257, 0.04809435856129442, 0.041984683368355036, 0.06215229457510369, 0.04041027856458511, 0.023643953060465198, 0.02940779591777495, 0.009180784907325037, 0.02840921119786799, 0.044997219395424636, 0.004187132730813963, 0.046548621862062385, 0.018865675532392094, 0.033625722264072726, 0.053054897380726676, 0.08058762284261839, 0.09544399101287127, 0.03403956416462149, 0.04732162591868213, 0.03034214542380401, 0.03932140627875924, 0.03750219621828624, 0.07437781284430198, 0.03044096047856978, 0.010641805661310042, 0.025692725088447332, 0.043325197151196856, 0.04383988292621715, 0.0359648462118847, 0.04843989912686603, 0.029647434130311012, 0.0498816469418151, 0.018787579544420754, 0.020352237192647796, 0.03671635088643857, 0.018097979315955724, 0.047262539089258225, 0.05635690323210188, 0.029131021483668258, 0.05481740226969123, 0.030611968266644647, 0.047383538846458705, 0.023805135661470037, 0.06698809151670762, 0.012174344854429364, 0.017088639816003184, 0.011938092531636357, 0.040677696000784636, 0.023701292662216083, 0.026340050888913016, 0.04100485844537616, 0.013124837556720843, 0.02900281229189464, 0.00338612256538389, 0.07736099883913994, 0.03607013449072838, 0.019498560411323394, 0.10566335264593363, 0.01723757994893406, 0.013007512066646345, 0.03314017278275319, 0.054866538383066654, 0.0628820386316095, 0.027867453571941172, 0.04857148742303252, 0.0024525050290061957, 0.01978570794952767, 0.032109674864581654, 0.038046717178076506, 0.032379796262830496, 0.023359806343380893, 0.028116961076323475, 0.029145369106637578, 0.04080253965886576, 0.018480913946405053, 0.012705375689880123, 0.04644594255036541, 0.053367196515734704, 0.024738192558288574, 0.05104241340554186, 0.033660025601940494, 0.04641692839296801, 0.09914159974349396, 0.15263618103095464, 0.016701362561434507, 0.04704440025878804, 0.04958440449887088, 0.053000831710440774, 0.04036559024825692, 0.03837716033948319, 0.05208704520815185, 0.020277023282168165, 0.02727484653171684, 0.04954107664525509, 0.05511468881741166, 0.02356797919076468, 0.03420735230403287, 0.0574499179742166, 0.08169050687657935, 0.054720714422208924, 0.049955590295472314, 0.11324571685067245, 0.06772190678332533, 0.006929658893828413, 0.027056716182934384, 0.01004478135811431, 0.010916130583999413, 0.03478076189224209, 0.012805763249551612, 0.052576879638114145, 0.06215453374066523, 0.012345515490908707, 0.11639303368117128, 0.054627867082932165, 0.026206616977495805, 0.01371702814607748, 0.019766257743218114, 0.035911577820245705, 0.011329791824599462, 0.005647447384295187, 0.015881999296003153, 0.03131464556125658, 0.011143425396377487, 0.07993815626416888, 0.02988482978461044, 0.06070037212754999, 0.04446897649073175, 0.06937262642064265, 0.018184602792773927, 0.07720718173576252, 0.05547134717926383, 0.10551630053669214, 0.013639715017883905, 0.059247330097215514, 0.06579220068774053, 0.040275032964668105, 0.03852879595277565, 0.025572486986805285, 0.08047992576445852, 0.018354791249813776, 0.04405786230095795, 0.04638903381835137, 0.05358624458312988, 0.0278493672210191, 0.023501917021349072, 0.027880669737766896, 0.008985254015507442, 0.012502773614999439, 0.07001243066042662, 0.06505299106772457, 0.07537512361471142, 0.017504788735615354, 0.06498310196080379, 0.03043592574873141, 0.0031223225690025303, 0.026753017479287725, 0.053818690324468274, 0.017640388870079602, 0.0026639757686228093, 0.06193122108067785, 0.05476988785501037, 0.015170178742014935, 0.009453584822559995, 0.01678566205581384, 0.023144985549151897, 0.02093117344858391, 0.02959866781852075, 0.006351429162480469, 0.043928418175450394, 0.025271353145529116, 0.008334238680877855, 0.0380196605942079, 0.01002748210781387, 0.02167793346701988, 0.03256097189815981, 0.04559548032869186, 0.032124975829252174, 0.03777943205620561, 0.029283057432621717, 0.057301278093031476, 0.06579404630299125, 0.024827879620715976, 0.09782476683280297, 0.012634164287841745, 0.0357301986244108, 0.016404225291418176, 0.029295630686517273, 0.05333959371117609, 0.008837026344346148, 0.020605960095833455, 0.03468884414594088, 0.007899768467593406, 0.030142296504761492, 0.05308372154831886, 0.02746751146124942, 0.05498975016442793, 0.014084096083284488, 0.0437892506431256, 0.006853189269479896, 0.04683038013588105, 0.025423865765333176, 0.04442716177020754, 0.06489158794283867, 0.0037038253836466795, 0.015991959288450222, 0.010662655346095562, 0.02142222584890468, 0.063854426810784, 0.04930175734417779, 0.08208289010716335, 0.02938345686665603, 0.03969924511121852, 0.030805218432630812, 0.04277599090710282, 0.04362751842875566, 0.042335971125534604, 0.033870266284793615, 0.07626489337001528, 0.007691093504295817, 0.04586819712338703, 0.036864414012857845, 0.005467764526006899, 0.02225540917632835, 0.03599640487560204, 0.05388774144064103, 0.04976105769830091, 0.011010877821328384, 0.007259915034020585, 0.024664910776274543, 0.02422092665385987, 0.05113623444257038, 0.00825943613225328, 0.040591566158192496, 0.009977809951773711, 0.044501824370984516, 0.04175862603421722, 0.024161894107237458, 0.06871879007667303, 0.06790604761668614, 0.03161507372611335, 0.04163891888622727, 0.028548183651374917, 0.03312553678240095, 0.08422153070569038, 0.016614820508818542, 0.046740151941776276, 0.045635130522506576, 0.037420273292809725, 0.024238600794758116, 0.02713027616430606, 0.08017257654241153, 0.024431571065049087, 0.04706637461536697, 0.07483044319919177, 0.021478213469630907, 0.014667026365974119, 0.024797030026093125, 0.06115281927798476, 0.04268302143152271, 0.05730510503053665, 0.05255776530663882, 0.025781206054879085, 0.02739860114109303, 0.036258031015417407, 0.06744860644851412, 0.01688322182079511, 0.03435602950464402, 0.045638163574039936, 0.04928780666419438, 0.06367691526455538, 0.06940167450479098, 0.013620079910781766, 0.04842667787202767, 0.04121386419449534, 0.0661506639527423, 0.008499753727976764, 0.03266619910885181, 0.01425544059436236, 0.0567056532683117, 0.012462578896832253, 0.03096893196925521, 0.05308028476844941, 0.05459136529160397, 0.025852942473388145, 0.030791902182889835, 0.07255369358296905, 0.007486212399921247, 0.02767431197155799, 0.09410599459494863, 0.029720603954046965, 0.03225245559588075, 0.049273662601730654, 0.029009105704192604, 0.022458681304539953, 0.04738175090668457, 0.01093496841245464, 0.025188107076766234, 0.03397335611017687, 0.016584810601281266, 0.01646398556684809, 0.07413797107126031, 0.03262277965300849, 0.023027549797136868, 0.1170934582395213, 0.04177673952654004, 0.03229920665866562, 0.0008473320018051059, 0.0720338679051825, 0.006413200446071902, 0.023594238495986377, 0.06154567748308182, 0.017486721044406295, 0.030540599953383207, 0.03085363529888647, 0.033736879870827706, 0.017878725991717408, 0.05762590281665325, 0.036728106505636654, 0.08182073810270854, 0.031064486663256372, 0.05165047916982855, 0.024954592642773474, 0.1084249426743814, 0.0903766711375543, 0.17341527103313378, 0.1789796245949609, 0.1268924945699317, 0.13195817917585373, 0.13828682101198606, 0.09133969553347145, 0.09330649713852576, 0.1398749186524323, 0.1694011121456112, 0.1355896850249597, 0.11694069286542279, 0.17111125109451158, 0.13584903467978748, 0.14334474317729473, 0.1356810022677694, 0.1715661816831146, 0.12272126839629241, 0.10593359278781073, 0.12827461612011704, 0.13141646395836556, 0.13394957088998385, 0.08669219205954246, 0.07021075966102736, 0.13852448468761785, 0.13843776791223458, 0.07157147343137435, 0.10533384247017757, 0.1853986337248768, 0.13167065674705164, 0.18914197571575642, 0.1497457439878157, 0.189109541741865, 0.1554025411605835, 0.07764193269291095, 0.1326773584421192, 0.08757658103214842, 0.1409258201186146, 0.07713628839701414, 0.08241169460650001, 0.12531138584017754, 0.08969485200941563, 0.10983926071120159, 0.1356206533632108, 0.18679006477551802, 0.19533035079283373, 0.13016004780573504, 0.2201150365706001, 0.11444714452539172, 0.16547765981938156, 0.1119924151737775, 0.15856440578188213, 0.08688448209847723, 0.12078874638038022, 0.12601170183292457, 0.17902750202587672, 0.1176303287169763, 0.10798041402761425, 0.06643498369625636, 0.11356477080179112, 0.16844208432095392, 0.0984864809683391, 0.1521702988871506, 0.10708819476089307, 0.22393836426947797, 0.14365031463759287, 0.1315383017063141, 0.14989894362432615, 0.1244305931031704, 0.18170794605144433, 0.1809961356754814, 0.11668519728950091, 0.16173373428838594, 0.1234736687370709, 0.0873663912394217, 0.12503495067358017, 0.09652053431740829, 0.10774780543787138, 0.18230365908571652, 0.0978802777826786, 0.047730938597981415, 0.15107840033514158, 0.08792318350502423, 0.21014984058482306, 0.09774531038211924, 0.0983980203579579, 0.10424870891230446, 0.10458789499742643, 0.18383820674249104, 0.12936979878161634, 0.13469543015318258, 0.15666217356920242, 0.14004684585545743, 0.19137023043419632, 0.1211539339274168, 0.15812015533447266, 0.1438295157360179, 0.11248744718198266, 0.07937214270766292, 0.16256389474230154, 0.11180627266211168, 0.14204788633755275, 0.10691701394638845, 0.126858703526003, 0.19844735067869934, 0.11406670351113592, 0.12904282632683003, 0.15371913649141788, 0.17142071734581674, 0.09455314917223794, 0.15220939607492515, 0.13838573784700461, 0.15246229964707578, 0.12213052223835673, 0.15121599366622313, 0.13767072478575365, 0.2161446160503796, 0.19789201047803673, 0.11953934627984251, 0.12938080461961882, 0.15963277273944446, 0.08929887254323278, 0.13324618791895254, 0.17939937992819718, 0.11787525271730763, 0.1048692020454577, 0.11919607541390828, 0.17667491255061968, 0.11494402214884758, 0.1387084491018738, 0.18174648684050354, 0.13378290911870344, 0.12014860287308693, 0.101128621692104, 0.13896902011973516, 0.15899819321930408, 0.08877811048712049, 0.14542319093431744, 0.1678950765303203, 0.12827555249844277, 0.10892570830349411, 0.3400419077702931, 0.12351831634129797, 0.1285884114248412, 0.14310420251318387, 0.1461378647280591, 0.2100412342697382, 0.08218829373696021, 0.13121052858020577, 0.1006566123770816, 0.15462377294898033, 0.15689249549593243, 0.16463216447404452, 0.11453874675290925, 0.08090213739446231, 0.16993966538991245, 0.2329610479729516, 0.13558645519827092, 0.13644629477390222, 0.07960070722869464, 0.1457985836480345, 0.10223616726164307, 0.08634377111281667, 0.19868795919631208, 0.10797600354999304, 0.1780793307615178, 0.08060287630983762, 0.18634227237531117, 0.1165249544594969, 0.1695716144250972, 0.15498426503368787, 0.1732188622866358, 0.0953240938750761, 0.18306572176516056, 0.0866696307701724], [0.008827870362438262, 0.018042295339650342, 0.023540004888283353, 0.015145700591217195, 0.003392471108652119, 0.03407681912982038, 0.014398351943652545, 0.05376663990318775, 0.017187958683020303, 0.04853085335344076, 0.02844761967259858, 0.0827049370855093, 0.0360825245401689, 0.02255996792311115, 0.025876231491565704, 0.011941071300368224, 0.021758782610829388, 0.09365842611129795, 0.03233997643526111, 0.029167852364480495, 0.06724848611546413, 0.02012571506202221, 0.060327937826514244, 0.03872087564585464, 0.03810123746682491, 0.030094208727989877, 0.056032526173761914, 0.016794667911848853, 0.0657967875844666, 0.023667145387402604, 0.09203370115054504, 0.030832824629864523, 0.06303377941782985, 0.054351218177803924, 0.07181847374886274, 0.05859626896147217, 0.02800999003063355, 0.025892974343150854, 0.05862911005637475, 0.0706487608009151, 0.03147201140278152, 0.0217713762207755, 0.052930881535368304, 0.005785315097974879, 0.044299352914094925, 0.08904773994748082, 0.03394711037565555, 0.02325496420131198, 0.01599093130789697, 0.02257255305136953, 0.01813744630531541, 0.0060304897321787265, 0.016197058372199535, 0.08911057229020766, 0.05005230867703046, 0.06587568763643503, 0.02761146436179323, 0.01669764588586986, 0.007808843926925744, 0.0065616465206923226, 0.021613087571625198, 0.03697466916803803, 0.058563163237912316, 0.03372095465394003, 0.10262936473424945, 0.02863231860101223, 0.02661506791732141, 0.05636098462023905, 0.03838150974895273, 0.012277367674479527, 0.06993609547082867, 0.058748572931757996, 0.038622291292995214, 0.032757272079054794, 0.013111148960888386, 0.022558417470593537, 0.020917865680530667, 0.05790541174688509, 0.034884760954550335, 0.04042868043429085, 0.0797431045877082, 0.03622921024050031, 0.0009037971945612558, 0.027982874074950814, 0.017385161315490092, 0.018398488905014734, 0.07804925726460558, 0.00662383298289829, 0.025630352453195622, 0.01791554839084191, 0.043398577320788584, 0.03931764719475593, 0.02385687904565462, 0.031681044293301444, 0.06595901173672505, 0.015819334890693426, 0.056677076766001325, 0.03480629177231874, 0.023028150300628374, 0.013225305692425795, 0.01688111157688711, 0.06322344352624246, 0.004367024238620485, 0.01808248836147998, 0.04570125715274896, 0.026342441028516208, 0.038297004997730255, 0.028833209071308374, 0.03800558777792113, 0.017007643090827123, 0.01236186224767672, 0.03629565917487655, 0.022094900021329522, 0.02598773006216756, 0.01850845568281199, 0.028558432922831604, 0.017724271065422466, 0.029759195633232594, 0.06497195363044739, 0.04592104821598955, 0.05167196158851896, 0.05388722236135176, 0.03073229288150157, 0.01201694254164717, 0.03377477605161922, 0.027850685275292823, 0.04929327226376959, 0.022126044778685485, 0.01020297161968691, 0.024483261862769723, 0.04082353013966765, 0.013759984501770564, 0.026621782021330934, 0.01854703888030989, 0.04054148009579096, 0.047804708925208876, 0.013013113373225289, 0.03786346522559013, 0.03914704313501716, 0.0285888584330678, 0.03887744081605758, 0.07365239105586495, 0.0279615697717028, 0.017608194079782282, 0.053236157832933326, 0.08005143090018205, 0.024553469881149273, 0.04505361922617469, 0.04622736267213311, 0.02060545119456947, 0.040638707378613095, 0.004414651883832578, 0.05592016077467373, 0.026892692216538956, 0.02383113033803446, 0.014601975213736296, 0.08649082322205816, 0.030363027339002917, 0.005517002419635121, 0.02588845869260175, 0.04356652491592935, 0.06508099420794419, 0.02367160845148776, 0.00908470434868442, 0.02819340313518686, 0.024930555539737855, 0.04184809087642601, 0.04164988061945353, 0.10308047517069749, 0.08710738085210323, 0.03565330025074737, 0.03331225604883262, 0.0579512942848461, 0.0763970652062978, 0.014518242296097534, 0.014047580721255924, 0.03207595506682992, 0.05010765677850161, 0.051211205776780844, 0.01750732136757246, 0.027623386222070882, 0.006328156259509602, 0.059340513311326504, 0.06345334476126091, 0.020692916054810797, 0.027579944713839462, 0.03123145377529519, 0.07185077201575041, 0.015732261884425367, 0.03517352510243654, 0.02744018007069826, 0.03541890711390546, 0.029233293674354042, 0.04309541126713157, 0.05249046141813908, 0.04013994003513029, 0.016679576498323252, 0.05555754487535783, 0.06475300395062991, 0.07321254430072648, 0.00769333860703877, 0.05140501573415739, 0.013521638898445027, 0.04581686934190137, 0.04318650120071002, 0.06418444588780403, 0.02814678269039307, 0.04391749036897506, 0.026456758912120546, 0.04094883859423654, 0.016916434413620403, 0.023516147597027675, 0.041049970846090994, 0.032951383984514644, 0.051859854720532894, 0.033000811867948086, 0.022546633013657162, 0.0893818980881146, 0.06983816251158714, 0.035059731387134106, 0.004332608518390251, 0.017755190209884728, 0.030217752991510288, 0.026634095735581856, 0.018809777817555835, 0.04569184247936521, 0.00727450692959662, 0.05532593373209238, 0.027381133953375474, 0.026692258061042855, 0.034610731194594076, 0.051188423963529725, 0.019829414086416364, 0.020980984704302888, 0.029606827202119997, 0.011273410653562417, 0.01660629641264677, 0.015765734016895294, 0.011613259158496345, 0.04089375172874757, 0.03589542529412678, 0.009592733695171773, 0.03717382598136153, 0.032551421517772336, 0.041076708518500836, 0.011671996542385646, 0.03323150698893836, 0.017328766573752676, 0.016492750362626145, 0.0085829853778705, 0.04308443257052984, 0.0454792371019721, 0.027355013747832606, 0.04974125465378165, 0.025108218060008118, 0.06950471004737274, 0.05982419342866965, 0.07456655414508921, 0.021557067720485584, 0.024295100709423423, 0.01383702112694404, 0.04812776962561267, 0.02465796597035868, 0.1014543388571058, 0.09208996527429138, 0.009720398362592926, 0.04359299795968192, 0.04380780518321054, 0.035996757713811736, 0.04807437909767032, 0.09594287031463214, 0.024257151942167963, 0.028996169434062073, 0.028183961320402365, 0.08243707181619746, 0.028231368865817785, 0.016145308202664767, 0.014297701451661331, 0.04301931017211505, 0.020795430821765746, 0.04476867523044348, 0.026278307594891106, 0.010553617313105081, 0.04763253405690193, 0.08482867026967661, 0.014178708461778504, 0.017689667475808944, 0.0341634069835501, 0.04100573036287512, 0.04489780383716736, 0.036960718488054614, 0.015762656860585724, 0.051254686300775835, 0.019319135396342193, 0.10644735236253057, 0.014141468763617533, 0.05926866323820182, 0.0783578007082854, 0.006260614883753338, 0.019592966684805493, 0.04817366573427405, 0.04011472567383732, 0.03766521086384143, 0.029694117339594022, 0.01507544846806143, 0.08357314299792051, 0.04781827284023166, 0.01661492737808398, 0.022167070702250515, 0.02107270567544869, 0.02618412354162761, 0.008800579683988221, 0.017100463288703134, 0.04272657998704484, 0.03320002635674817, 0.009770058644270259, 0.0033337076435730395, 0.058510603915367804, 0.021146996778302958, 0.04348833732573049, 0.044910977594554424, 0.10960357157247407, 0.03375625204561012, 0.05924047010817698, 0.027669811588046805, 0.014539197153810943, 0.042245949884610515, 0.01863356227321284, 0.007669361723986055, 0.0968312897852489, 0.05284992212961827, 0.08771712599056107, 0.02747521792272372, 0.018381520440535884, 0.04649875293086682, 0.03721898248685258, 0.03589020057448319, 0.052985775018376965, 0.01971973568600203, 0.013433585409075022, 0.033070399026785574, 0.02110192339335169, 0.04324193072638341, 0.036611415445804596, 0.06292967178991862, 0.06133843931768622, 0.07060431675719363, 0.041511808921183856, 0.031389681356293817, 0.0813976918746318, 0.06489471598927464, 0.03067219503489988, 0.18700571677514485, 0.1375753227621317, 0.13319008664361068, 0.10117428031350885, 0.05909508040973118, 0.10609604085662536, 0.12878794143242495, 0.13949531902159962, 0.1794612623218979, 0.08582051204783575, 0.08812595690999712, 0.193269585658397, 0.10641464018928153, 0.09655919724277087, 0.09131572967661278, 0.24705047479697637, 0.11338566469826869, 0.1742470735417945, 0.14567834724273, 0.12937335430511407, 0.15086111985147, 0.12150160170027188, 0.13719671379242623, 0.14897481964102813, 0.07676559793097631, 0.14554285737020628, 0.1785927510687283, 0.06604390325290815, 0.13536496779748372, 0.16413534113339015, 0.15622739547065326, 0.13079565869910376, 0.15189707997654164, 0.09779384599200316, 0.1396716974143471, 0.13904355040618352, 0.10658778875534024, 0.09774552072797503, 0.15456949014748844, 0.10312502778002194, 0.10582854199622359, 0.12002159468829632, 0.18118024936744145, 0.18378818514091627, 0.05954653689903872, 0.19398158602416515, 0.08877268899232149, 0.08280035267983164, 0.09573139809072018, 0.12155953502016408, 0.13399747546230042, 0.11207048062767301, 0.14896688078130993, 0.16928363059248241, 0.13902822908546242, 0.11670510550694806, 0.11185577857707228, 0.1167996661471469, 0.2161717303097248, 0.06306736690125295, 0.05674974447382348, 0.07352106060300555, 0.13408054171928338, 0.1728325044470174, 0.13936837869031088, 0.11013187215264354, 0.1403968749301774, 0.12702782159405096, 0.24721980999623025, 0.055771296976932457, 0.13122624345123768, 0.07497986339564834, 0.18078857181327684, 0.13186840899288654, 0.10266299292977367, 0.15535114891827106, 0.15296905674040318, 0.14532458622540745, 0.08531602126147066, 0.10565635016454117, 0.16073583997786045, 0.12035360187292099, 0.1170284952968359, 0.08273754069315535, 0.10054386699838297, 0.09398324761007514, 0.196923361026815, 0.1459384025739772, 0.15773896793169634, 0.08791791807327952, 0.17637084743806294, 0.2837774854685579, 0.12839825877121516, 0.1285727915487119, 0.1585579054164035, 0.11721805083964552, 0.12611463559525354, 0.14104586653411388, 0.19112434291413852, 0.1585200431623629, 0.13168073977742875, 0.06854539045265742, 0.13808749456490788, 0.0843798600669418, 0.11654806536223207, 0.21676116010972432, 0.11607288728867259, 0.1316115834883281, 0.19545084504144533, 0.09274754713156394, 0.11478314149592604, 0.07288267450141055, 0.09378939694059746, 0.10535925360662596, 0.0803902777177947, 0.18950447626411915, 0.1468801006142582, 0.13690934064132826, 0.13048559533698217, 0.10864870995283127, 0.1018881398652281, 0.24475895347339766, 0.13782289304903575, 0.07324286803070988, 0.1044518147994365, 0.07920026300208909, 0.1404922226709979, 0.07771017295973641, 0.0837921333898391, 0.13192113116383553, 0.19829477529440606, 0.1575311462261847, 0.07756271372948374, 0.1232546376330512, 0.16204691891159329, 0.11306730963821922, 0.09242541263146059, 0.19616676733962127, 0.10339038925511496, 0.09158605124269213, 0.1417639194322484, 0.10310051230979816, 0.05040596112875002, 0.12898701003619603, 0.12251734148178782, 0.21192050485738687, 0.1611575223505497, 0.15120584278234414, 0.05481996713206172, 0.0985949244350195, 0.1484577895275184, 0.07279430210058178, 0.08520784242344753, 0.1844731933836426, 0.10866324417293072, 0.17240904431257928, 0.15941405376153334, 0.11490785623235361, 0.0740457988743271, 0.10448285777653966, 0.10388324995126043, 0.19717821877981934, 0.10247047218893256, 0.11053872174982514, 0.10466458302523408, 0.07762431113847665, 0.1381453736019986, 0.13126334574605736, 0.14364662340709142, 0.1962907085461276, 0.21613134390541486, 0.13476255083722727, 0.13359776405351503, 0.09913934700723205, 0.18846463491874083, 0.10333578075681414], [0.0329646595221545, 0.08201157607670341, 0.05689550397385444, 0.03463116527668067, 0.03667783723878009, 0.011496821701127504, 0.026349004158484082, 0.031043329941374913, 0.02923109182821853, 0.009483682091480919, 0.011451920494437218, 0.012059158446001155, 0.013505769660696387, 0.010332936520821281, 0.014629438918616091, 0.03925566980615258, 0.05046830153358834, 0.02312381864924516, 0.016577692768935646, 0.020800862494590025, 0.04463751441133874, 0.03158458714772548, 0.0226232989890767, 0.01710735211547996, 0.07528878003358841, 0.0448592291213572, 0.031192258199942962, 0.02095277969991522, 0.013324807763897946, 0.023179499232875447, 0.014732128408338343, 0.004871462862606027, 0.09485139245433466, 0.011453675355629196, 0.019419204044554914, 0.03558640687593392, 0.03295129577496222, 0.00579855840520135, 0.036849187687039375, 0.021773247281089425, 0.00376218618060063, 0.07818155123719148, 0.06168140484286206, 0.07447537260928325, 0.039353568838643174, 0.0047195944269852975, 0.07752739598176309, 0.038471283324595006, 0.019365872888426696, 0.06075171687241111, 0.02035645768046379, 0.013601921465513962, 0.06484879273921251, 0.028522039697106396, 0.04593382163771561, 0.07403609582356044, 0.009731333802587219, 0.009132613161844867, 0.038720502451594384, 0.042039885584797175, 0.029408525342919996, 0.018918397703341076, 0.013335147789413375, 0.05904097402734416, 0.06232313612209899, 0.05343678367457219, 0.022026177994640808, 0.011610930087044835, 0.018778421018006544, 0.017217379961428896, 0.045440740417689085, 0.0526598373294941, 0.017552818836910383, 0.018001657877383486, 0.015117979043030312, 0.07081779065941061, 0.03612239186518958, 0.0096804877809648, 0.0138374799862504, 0.016276601336098144, 0.05423263061259474, 0.02558815775306097, 0.017622833472809622, 0.02949488249474338, 0.09755660300808293, 0.033860427527023215, 0.02693829994781741, 0.017405646287703087, 0.030823871360293457, 0.0299892732873559, 0.04427095961623958, 0.043139556755444834, 0.03520762487979872, 0.032932751412902556, 0.015615033085591026, 0.023302860291940824, 0.05074018033753548, 0.04458831383713654, 0.0608922414747732, 0.032088328152894974, 0.04696072671296341, 0.020945850161037276, 0.04127599086080279, 0.002835420363615932, 0.049114481679030826, 0.044585803257567544, 0.010171619060981487, 0.0358145371345537, 0.05116620533434408, 0.03403638183538403, 0.0055997506133280694, 0.03861249324732593, 0.11727833189070225, 0.02647941858906831, 0.02188811308172132, 0.02189744633090283, 0.012903328103545521, 0.03494490629860333, 0.03596751963985818, 0.026212233551112667, 0.03415636718273163, 0.04757633778665747, 0.0449096815926688, 0.009215376622575735, 0.024448359717747996, 0.08089274646980421, 0.05849520795579467, 0.031211043441934243, 0.041012244299054146, 0.037785335310867856, 0.044842323421367576, 0.023170254193246365, 0.0611000835363354, 0.005109842816766883, 0.03574875655717083, 0.04078455848087158, 0.06773334009838955, 0.01749533335013049, 0.007944283757491835, 0.0055927977498088565, 0.023811624152585864, 0.02716587041504681, 0.04990473070314952, 0.02155260804907552, 0.04364556406757661, 0.06625801497804266, 0.04670400977400797, 0.022099061137331382, 0.029237595586372272, 0.02776122891477176, 0.02450263064487704, 0.07393181856189456, 0.050159188120492866, 0.011582261134338166, 0.019859466402392303, 0.010181797934429986, 0.029875991865992546, 0.05028724803456238, 0.05524765453966601, 0.03464553325570055, 0.034894820236201794, 0.02490881867041545, 0.0408801810283746, 0.02261476980389229, 0.03156864496746233, 0.04319182430793132, 0.02225851347403867, 0.007579336242218102, 0.012001376100150602, 0.09536278394183942, 0.028045967653659836, 0.01506413220028792, 0.03091034386307001, 0.02634441726175802, 0.04216592685718622, 0.035766893798219304, 0.04769807714702828, 0.04226573257307921, 0.02095990771028612, 0.08057710554982934, 0.01578002396438803, 0.030288948278341974, 0.050788322397108586, 0.05659788155129977, 0.013304552645422518, 0.030058782414666245, 0.031160570614572083, 0.05648692411237529, 0.04107475094497204, 0.0949909942490714, 0.052943939941802194, 0.035516310815832446, 0.03556785233584898, 0.01826377086607473, 0.019171616794275384, 0.024851836995886903, 0.015188969073018857, 0.03087464613573892, 0.052493687852152755, 0.02504543660740767, 0.01778560214942055, 0.0652426416054368, 0.07429673469492368, 0.0133845222382141, 0.02156203968583473, 0.03680729493498802, 0.039146666548081806, 0.01496651815250516, 0.05189568136951753, 0.005334012975384082, 0.013261799850235028, 0.010131381934375634, 0.006293333842352564, 0.031458403382982524, 0.057409952261618206, 0.014678325670372163, 0.02581042716545718, 0.026806243462488055, 0.04054484562948346, 0.042790304603321214, 0.01845925341227225, 0.020489041726770144, 0.061758337143276415, 0.0418415735475719, 0.07568045758775302, 0.06406248600355216, 0.043770845380744765, 0.037891590502113104, 0.04226367661197271, 0.03509790237460818, 0.037549958298248906, 0.06382928030299288, 0.049878383188375404, 0.06284704658069781, 0.03011475137567946, 0.0369383370104645, 0.03280023352376052, 0.025951046762721877, 0.03488804506404059, 0.028270406681778174, 0.06720631516405515, 0.0544631357437798, 0.0599799511422004, 0.03742154554596969, 0.0368191523344389, 0.031483770414654694, 0.05767473019659519, 0.035432087656642706, 0.037089952267706394, 0.020736401667818427, 0.0424414493941835, 0.022833627881482244, 0.08174611960670777, 0.02948805982513087, 0.020041245933888212, 0.02765991854747491, 0.08387896551617555, 0.014761904221294182, 0.03257737887491073, 0.012786647221738738, 0.07643268150942666, 0.02870320515441043, 0.029756478100482906, 0.0469413036480546, 0.04662332856761558, 0.04710675762700183, 0.006359364629523563, 0.013961955539083906, 0.07014287223241158, 0.014569509009431516, 0.009841933314289366, 0.03447770779686315, 0.046292756484555345, 0.018141639651730657, 0.03626217347170625, 0.050172975952071805, 0.00884081850693162, 0.018836720746808817, 0.00628259644976684, 0.05021621220346008, 0.05265196632327778, 0.047662060508238416, 0.01779815843994064, 0.04224764961483223, 0.019897108132551824, 0.01641835747951908, 0.013984282733872533, 0.03263585163014276, 0.019752743021984185, 0.012205466711228448, 0.011523198901808687, 0.02200984226406685, 0.01287707982451788, 0.03452687105163932, 0.039049761569393535, 0.05417730625984924, 0.028446729095386605, 0.01891207036429218, 0.018353753091235245, 0.0935951459354588, 0.043238409129636626, 0.04967549782512443, 0.033461428580007384, 0.04571420020822968, 0.05759911425411701, 0.02229428753655936, 0.015388158116755741, 0.16799235131059373, 0.022686156776866744, 0.01256926919865821, 0.06756269532654967, 0.04797749786770769, 0.03105035956416811, 0.03923779380108629, 0.0016689087226820576, 0.0314489276414471, 0.02214844661232616, 0.04026355893750276, 0.031707558049155135, 0.019356237691161886, 0.02061873351755951, 0.018257312909034745, 0.00892338010349444, 0.035363094215946536, 0.052882471454462836, 0.06017209190343108, 0.02955891245177814, 0.07964487985840865, 0.008431306507970606, 0.030826639783169543, 0.016558865118505697, 0.0563507183854069, 0.02739127805190427, 0.02769563832719411, 0.030613281231905733, 0.046051340510270426, 0.04723643245441573, 0.06218323577195406, 0.0463411767434861, 0.03481465471642358, 0.05067961769444602, 0.028740768853042806, 0.018965508389685835, 0.01914019892657442, 0.06182651634195021, 0.011371570073866417, 0.04203772784343787, 0.032467795469399006, 0.004859807751407581, 0.0103778970993257, 0.04931286156975797, 0.052954847392226966, 0.1687218714505434, 0.19009382463991642, 0.10456069252852883, 0.14531348539250238, 0.05381965723686984, 0.11751770547458104, 0.09665191905306918, 0.1696371337664979, 0.09971109418464558, 0.107233916941498, 0.13863298243709973, 0.19878251983651093, 0.09950004943779536, 0.2321791856416634, 0.16138377306716783, 0.13588430493005685, 0.12295013825808253, 0.09314729246710028, 0.1175678763538599, 0.10715724926974092, 0.07964816396789891, 0.13111826138836996, 0.07156179752200842, 0.060617007315158844, 0.19052214308508805, 0.11007140789713178, 0.10431234192635332, 0.07685400425855603, 0.12490269062774521, 0.18279524413602694, 0.08737711887806654, 0.10861504783055612, 0.1544337152902569, 0.06539898285908358, 0.09782309085130692, 0.17780706179993494, 0.1552916278264352, 0.10636731915708099, 0.10493854153901339, 0.10669461052332606, 0.10114229417272977, 0.18982361842479023, 0.17558457462915353, 0.10096015501767397, 0.09973544002111469, 0.07970370884452548, 0.20165961688118322, 0.11316163279116154, 0.176113166979381, 0.292533844177212, 0.15968001234744275, 0.1113882747345737, 0.13024776881294592, 0.17078946264726774, 0.11409801111689635, 0.28484829515218735, 0.12630904944879667, 0.19790521476949963, 0.142118847529803, 0.13035877714199678, 0.14987367498023169, 0.07430885333035674, 0.08814631296055657, 0.12641629869384424, 0.1167006678879261, 0.17198002019098826, 0.0912903185401644, 0.07707563415169716, 0.15957266810749257, 0.1870496587029525, 0.18175077518182142, 0.17082572355866432, 0.215907359495759, 0.05632361430408699, 0.13452760130167007, 0.18840624019503593, 0.13690228387713432, 0.11334478296339512, 0.1197887621819973, 0.06623833067715168, 0.269381686512913, 0.0632365799642035, 0.10939534953130142, 0.07679587416350842, 0.1416490434535912, 0.11995804309844971, 0.1425916100186961, 0.1343889630266598, 0.1311829529170479, 0.18271158076822758, 0.08989400882273912, 0.08874908275902271, 0.1842169649899006, 0.06610678987843649, 0.05350760915981872, 0.11050379076706511, 0.11932194365986756, 0.13088314900440828, 0.13951572935496057, 0.11391195681478296, 0.17504950905484812, 0.08082654859338488, 0.13749632771526063, 0.13640795754534857, 0.13895307454679692, 0.13045983814767428, 0.10888418196035282, 0.11044382184211697, 0.1846160250050681, 0.08106157276779413, 0.08398343276764665, 0.10090520725186382, 0.21763423111821922, 0.0671666751482657, 0.05385731593040483, 0.18728207051753998, 0.15935009505067552, 0.10044282634875604, 0.0998283111091171, 0.1763707117310592, 0.07902376925838844, 0.10348034942788736, 0.12288244760462216, 0.0858220998197794, 0.1746249496936798, 0.2046612115310771, 0.11840674919741494, 0.14338344681475843, 0.1349785013922623, 0.1355016247502395, 0.10061983577907085, 0.21483208505170687, 0.14074414915272168, 0.12485064699181489, 0.18112532874303205, 0.11852447502315044, 0.183830091463668, 0.11406308013413634, 0.06086810598415988, 0.13510685307638987, 0.07702618251953806, 0.15022940374910831, 0.1186187778200422, 0.11814104845481259, 0.12795662746897765, 0.15072131449622767, 0.09771770757756063, 0.1551596527653081, 0.13616805470415524, 0.0941830218902656, 0.12561526096292905, 0.2730990813246795, 0.08856334058301789, 0.13981716175164494, 0.06804304383695126, 0.1463661374790328, 0.09789447273526873, 0.13598300463386945, 0.1816009817911046, 0.1598290050668376, 0.13597813275243553, 0.1275242106722934, 0.10565084046018974, 0.1298595924994775, 0.13693232940776007, 0.1510887819209269, 0.14765304699540138, 0.08663275239190885, 0.14360971110207693, 0.10193993244320154, 0.17415384283023222, 0.09689734516931431, 0.12233013367014271, 0.08954794239252806, 0.13287232869437762, 0.09001819430185215], [0.10488290166748421, 0.010545049112157097, 0.05388146499171853, 0.05563510482066444, 0.07185762521943875, 0.0566355198887842, 0.02072708707834993, 0.02037847274914384, 0.03139445145747491, 0.02163949445821345, 0.03554428681465132, 0.03962683863937855, 0.0360072682212506, 0.025964983872004917, 0.055552767988826544, 0.021394685808835284, 0.04172442447660225, 0.016897226783580015, 0.08439674201820578, 0.015459434827789664, 0.04176919421713267, 0.05034924577921629, 0.05447477601202471, 0.04601872333192399, 0.03584050806239247, 0.044610403544668636, 0.06036418516721044, 0.05755955566252981, 0.04232887025656445, 0.06997737754136324, 0.038288642053625414, 0.055415195013795576, 0.021366541872599294, 0.0366307435158108, 0.052789077894496064, 0.043343263146068366, 0.04490992586527552, 0.04540372633242181, 0.038339806986706595, 0.01968477077649108, 0.006079293363395014, 0.01203394154020186, 0.03761206800118089, 0.025847941670300703, 0.03698879965980138, 0.055040596186050346, 0.03801293631217309, 0.05294898484966584, 0.0216246837350939, 0.021293670604271547, 0.03269996979672994, 0.013129730642374073, 0.027368316426873207, 0.021090936215062226, 0.03335016240764942, 0.0815274752676487, 0.013171485142915376, 0.020063700353992835, 0.03051982999646238, 0.04253251218636121, 0.04468210434008922, 0.015083847035254751, 0.05953064560890198, 0.06076849704342229, 0.026145258752096976, 0.0154360219769712, 0.022968646172167997, 0.016000247593703013, 0.027654078057301894, 0.05186538138825979, 0.027145685694579567, 0.0380587679600077, 0.016449500540537492, 0.025921895201983194, 0.05894287143434797, 0.022316886145355444, 0.022666436852887273, 0.04534326207691005, 0.018960548298699514, 0.011911662744491227, 0.03973496658727527, 0.029015090383057083, 0.04267728781061513, 0.034943539050540755, 0.04355859623423644, 0.11445797394428935, 0.02763556592565562, 0.05542780558711716, 0.04215988789552024, 0.03653028979897499, 0.02585842164366373, 0.04225774960858481, 0.012818791970078434, 0.10666349290737084, 0.0395175198625241, 0.02921103433306728, 0.047598844793226035, 0.0154447326702731, 0.01711894997528621, 0.030974709694939, 0.020425001591710106, 0.014522883475625088, 0.028635063275162662, 0.0180169622347291, 0.03181344343881522, 0.08967025511498962, 0.005095128360803106, 0.05826515744307211, 0.11032861338130065, 0.04702238519010799, 0.0379614219335573, 0.060062908833580356, 0.004045658603510154, 0.02666582742572895, 0.03956128197855183, 0.01700738864019513, 0.010638642839954367, 0.024273699714935253, 0.05311085616371461, 0.03935155358963779, 0.012305567589854556, 0.039975561534187624, 0.03511123898039971, 0.0768325829080173, 0.027303555348355855, 0.0765254847439272, 0.04907400027981826, 0.040550721742744954, 0.020182603437985693, 0.024245140176000338, 0.029090021005166427, 0.07711407994585377, 0.03492768507983003, 0.021405245510063002, 0.028787038155964444, 0.04979151034993785, 0.04867864167317748, 0.011677259429624038, 0.010575129417702556, 0.04546757308500154, 0.0181570542710168, 0.034777301363646984, 0.01747073306302939, 0.06064095960131713, 0.023010823908927183, 0.047729897046727796, 0.01839444992531623, 0.024610178445332816, 0.011606987798586488, 0.0702560790149229, 0.04950233908104045, 0.027963518863543868, 0.035654297697224786, 0.0399893765071673, 0.05570655795080321, 0.01769075313183878, 0.018733003276533315, 0.035191129693495374, 0.030521061537521224, 0.057370807576392374, 0.052092107079390965, 0.011871802204820727, 0.01810484948301954, 0.057829449751547406, 0.019042556041053364, 0.05138710580234017, 0.048391692606466155, 0.07133012531059128, 0.014849369081535509, 0.02941485946731908, 0.046631457417138984, 0.036501092437122545, 0.0389748750520604, 0.01691099425910839, 0.06646098515817098, 0.07810002525470086, 0.06719736528715917, 0.06481080834886857, 0.04646601022354194, 0.039907857310026884, 0.026963850183944617, 0.07398494785385472, 0.019646048479314362, 0.015549367859161325, 0.017029876987050687, 0.026621044114498154, 0.04580352255808456, 0.022559021366760135, 0.03952436288818717, 0.022277437815708772, 0.027316120120563676, 0.03888389368408492, 0.08387022598513535, 0.05098077867712293, 0.042920132101114304, 0.011764722593527819, 0.030159358267805407, 0.0399335025410567, 0.023920637588681917, 0.056751478130796125, 0.016913533676415682, 0.039960016296910386, 0.052705886108534675, 0.04898934964356678, 0.012446112548267203, 0.037119346404714246, 0.041152059832321744, 0.04731169216600912, 0.03377677772992423, 0.0325287957675755, 0.027774670693491186, 0.02754143445885607, 0.01703553766544376, 0.06525431919310774, 0.022186816071293185, 0.018988251187173382, 0.008497006509320011, 0.01816917460278741, 0.015348372215937291, 0.09287783942584481, 0.016171694733202457, 0.03564214513504079, 0.015158747123288257, 0.049158569491867504, 0.056926190720072815, 0.03262197558901139, 0.028331408676292216, 0.04316631478390523, 0.02632174062143479, 0.018295034367058958, 0.038214430678635836, 0.04391012826402273, 0.05084701906889677, 0.02582122605027897, 0.049908262477921586, 0.03382859744929841, 0.041895316913723946, 0.03748014722285526, 0.02696590275237603, 0.011762410485451775, 0.030932301256273474, 0.015985823635544096, 0.032094896371875486, 0.03395703395030328, 0.05796947902334588, 0.040287121066025326, 0.04006010699751122, 0.028861100253249918, 0.03177561850420066, 0.002849914295698649, 0.03829042660072446, 0.01026421703863889, 0.04075169363724334, 0.036695088991629224, 0.027483385788010697, 0.04836914488779647, 0.051816431872014485, 0.05845110996493271, 0.017710486626518623, 0.06560504037354674, 0.043273336719721556, 0.0484219925877239, 0.023874561668240597, 0.04376783607793706, 0.05189954562644873, 0.019526471949315498, 0.010741825963902687, 0.01953284508947815, 0.016343932365998626, 0.024742854093866687, 0.026614316439788257, 0.011745098512619734, 0.06769608852586576, 0.03762709076649376, 0.0030578485956149442, 0.02708380838989147, 0.01581952827317374, 0.08730691764503717, 0.02441008864635868, 0.14077998937240668, 0.020804852280499678, 0.013708213976185237, 0.03978691862097808, 0.07027463016233274, 0.029574128599571328, 0.03464823043239968, 0.02144756234650101, 0.03672292249809418, 0.012818692734331956, 0.03167474748832839, 0.0221338937325137, 0.010218322626315057, 0.022926290319966416, 0.022877997286351662, 0.029796114723597254, 0.08049488067626953, 0.020910125292305435, 0.026371433133525506, 0.0649237505027226, 0.04347572335973382, 0.010667644274820174, 0.01640709040553442, 0.030500939581543207, 0.09208019437002284, 0.05226787139794656, 0.0529508135015411, 0.019279724386121546, 0.052286483613508086, 0.02418427219215248, 0.037772745093596835, 0.03336485269080315, 0.008110742816435439, 0.028473568548049246, 0.03939062363601156, 0.04629894811660051, 0.07347860466688871, 0.042271859744297605, 0.05297344603708812, 0.0812949345314077, 0.04131437897948282, 0.02289803442545235, 0.028930151369422674, 0.022610116750001907, 0.03903183128152575, 0.03266597519229565, 0.04523310191663248, 0.024723015426258956, 0.011819961281227214, 0.024470668252823607, 0.03966288920491934, 0.016233792561771612, 0.016895995242521167, 0.05321110292736973, 0.03357512051505702, 0.027184542002422468, 0.016001748852431774, 0.02477236358182771, 0.030011356209537814, 0.059854110037641864, 0.02943166338705591, 0.022465091764128635, 0.027979003032669425, 0.013754942986582006, 0.07869861527745213, 0.045896980578878095, 0.03810452836166535, 0.05247215115066085, 0.026802553928324153, 0.05269313304285918, 0.060476292722991536, 0.028766163026115725, 0.05309812345408967, 0.31739200172679766, 0.21857587487569877, 0.18937376327812672, 0.13093429697411402, 0.1412243348147188, 0.21806130105895655, 0.0982511310971209, 0.07944013191653149, 0.11889209172555379, 0.0889896641352347, 0.1099350494997842, 0.1550357522709029, 0.14709519621516975, 0.15229843344007218, 0.21766089754445211, 0.12752544560602733, 0.2058364748954773, 0.09547869807907514, 0.1407400779426098, 0.10795266873070172, 0.13141345126288279, 0.11105997913650104, 0.12687224708497524, 0.17178339431328432, 0.09908642806112766, 0.2223076953419617, 0.15015363852892602, 0.10084242240658828, 0.10713725962809154, 0.1879806358899389, 0.10465127695351839, 0.17095870285161904, 0.14405465365520545, 0.10498365054705314, 0.10154186987451144, 0.104707296804658, 0.17831812080528053, 0.18932234389441355, 0.0660582881953035, 0.07414587600422756, 0.08143280606184687, 0.08728774224541017, 0.12161137509558882, 0.15785072264926775, 0.13835272033299717, 0.12385666104299681, 0.10977910179644823, 0.14404036370771273, 0.17479275140379155, 0.11830735738788332, 0.13351766977991375, 0.2302274475140231, 0.14244231874389307, 0.11766850309712545, 0.09914902970194817, 0.11854749093098299, 0.09236395771482162, 0.093997469704066, 0.17582687948431286, 0.10380206323627915, 0.12066941921200071, 0.12531332645033086, 0.1652808575225728, 0.11485657255564417, 0.199394965544343, 0.08963759043919188, 0.19049686087029322, 0.11762104635792119, 0.1791407223790884, 0.1553944530231612, 0.08338169434240886, 0.07531725814832108, 0.1344606163246291, 0.13961148421679223, 0.1563281443502222, 0.07656792032399348, 0.07736832023199115, 0.10652449500880071, 0.060246337205171585, 0.07964656262525491, 0.1833662177835192, 0.2232480498829058, 0.16658359047557625, 0.0852825152022498, 0.13941974379122257, 0.15123269919838223, 0.1441983673721552, 0.10565155970730952, 0.12430572908903871, 0.128505263743656, 0.08320612340633358, 0.0988514106720686, 0.07908715799983058, 0.1429796777665615, 0.06355572212487459, 0.09920512419193983, 0.1102371672168374, 0.08278025447257928, 0.09737077940787588, 0.09767226608736174, 0.11027154180088214, 0.16034321247466973, 0.13185529969632626, 0.22075452868427548, 0.08938287517854146, 0.1286861611796277, 0.10272574384829827, 0.16012803544955595, 0.25142330729535645, 0.17960446035223349, 0.1771306980933462, 0.14865843233253273, 0.0753359246466841, 0.07602406772119658, 0.16014343819447927, 0.07802722523255007, 0.09595866660986628, 0.19269867986440659, 0.1437844881521804, 0.18250265983598574, 0.11563482508063316, 0.09763734867530209, 0.09952073797051396, 0.1962646392307111, 0.09618056113166468, 0.12976178846188954, 0.24189979689461844, 0.14840075187385082, 0.09127864095249347, 0.16034906144653047, 0.12841195160789148, 0.12220395329807486, 0.10477893653192691, 0.12986892914133413, 0.1203238277563027, 0.16132161925945962, 0.16568827708917006, 0.08875605809901442, 0.1319944400872503, 0.13998921109097345, 0.13013929820486478, 0.1925624707447631, 0.16787340412182467, 0.13425667583942413, 0.09487222347940717, 0.09282584328736578, 0.06944575892495257, 0.09628029899405581, 0.16393860669008323, 0.12373658748609678, 0.1790370965110404, 0.06889169437012502, 0.14263111432748182, 0.11563196166285447, 0.10005766951612063, 0.07292576826044492, 0.20036934183112212, 0.11301527957298926, 0.08552589214273862, 0.1428090397800718, 0.11958379032356398, 0.18831864132412843, 0.0884217099685754, 0.12120310057486806, 0.12075183407536574, 0.16208182275295258, 0.1598147829728467, 0.14250935800373554, 0.11537950592381613, 0.09213145769068173, 0.1484272690223796, 0.10695009252854756, 0.15268381418926374, 0.15761577311371053, 0.12728060302989824, 0.14653343707323074], [0.028170086975608553, 0.01832762610034219, 0.027880717235218202, 0.035218501796147654, 0.02597891419593777, 0.05557836911508015, 0.0476952544413507, 0.08343510183372668, 0.02025481652734535, 0.040159434346216064, 0.008872608720724071, 0.045871908709939034, 0.03713208589968937, 0.021071677694895437, 0.02120712855165558, 0.043460914332951815, 0.04270072780283434, 0.060000592177467685, 0.05610436267618622, 0.008826425931017314, 0.03644059764753495, 0.03110451005133135, 0.016270143379058157, 0.003432717565114477, 0.009232722522158707, 0.037844093050807714, 0.036236870900860856, 0.0435031463525125, 0.060742237738200595, 0.059116997090833526, 0.05791144392320088, 0.003191911000093179, 0.02894506896180766, 0.08142920304089785, 0.05719761151288237, 0.010692750070510166, 0.09659422322043351, 0.04288934018196804, 0.08015750627964735, 0.029072606403912817, 0.015387393068522215, 0.09533140848257712, 0.041895632432507615, 0.005570281413383782, 0.02641483223331826, 0.008170363144017756, 0.038417743518948555, 0.02674867146249328, 0.03287959837221673, 0.013065536988766065, 0.05118446471169591, 0.04621975290189896, 0.03804586900930319, 0.028057724969195466, 0.05852161653872047, 0.011728576184915645, 0.06595215174768652, 0.04319845698773861, 0.0917416461078184, 0.03976673220417329, 0.06482566148042679, 0.04332961780684335, 0.049701560355190716, 0.04912474112851279, 0.019507060758769512, 0.08589931710490159, 0.026845282974785993, 0.018167393448363458, 0.030267547283853804, 0.06407518817910127, 0.005039404944649765, 0.03508440970576235, 0.01117852601289217, 0.04646001536665218, 0.033521645170237334, 0.0055299420824407464, 0.04590702289715409, 0.07064407890928642, 0.03702753722401602, 0.022957301066656197, 0.032110475535903654, 0.01865098365981664, 0.058078953863254616, 0.01606126655159252, 0.02503482431971601, 0.01695908373221755, 0.031098935886153152, 0.08357338048517704, 0.03821599130917873, 0.06419824050473315, 0.015781693160533905, 0.05107871502903955, 0.024782410989116346, 0.06870728212275676, 0.007187009838941906, 0.07706616180283682, 0.03197884313496096, 0.043691226081656556, 0.030946211224155765, 0.03443272092512675, 0.10566830595156976, 0.015679030812212398, 0.038118998120938025, 0.005267501276518617, 0.044466974812426736, 0.03767717004354511, 0.006439528028879846, 0.03394398232921958, 0.03363976115360856, 0.017827567843986408, 0.03617927006312779, 0.07067284200872694, 0.06020309416843312, 0.03944390220567584, 0.051691659460110326, 0.03581577206828764, 0.049339602634842904, 0.00813364252514605, 0.02888365475726979, 0.020392043449516808, 0.05093579180538654, 0.0388593578578106, 0.026579392242378423, 0.010748648633515196, 0.012512638666001814, 0.015214565110259821, 0.0618363618850708, 0.030418110811816793, 0.07698677999100514, 0.010287750329423164, 0.05477046460977622, 0.030841462380651916, 0.007743211779078203, 0.009007607503528041, 0.04446509187774999, 0.015293760324961372, 0.02855808686997209, 0.02488188083017511, 0.03363845158102257, 0.023134011941562806, 0.04736083845740982, 0.03300125291571021, 0.026112802725817476, 0.037222161423414946, 0.037611535351191244, 0.06870040177766766, 0.04913337887930019, 0.06985613690423113, 0.022509384833808457, 0.007235346977332873, 0.02398681002003806, 0.03758875014526503, 0.10996530537626573, 0.04391579403142844, 0.05051005179328578, 0.02128699721236314, 0.06354179858629193, 0.030144437282745327, 0.05876700872821467, 0.051682807970792055, 0.04215265131954636, 0.08472860671047654, 0.015257231392232435, 0.00964587995050741, 0.059567680050219805, 0.020394294489441172, 0.022957200982740948, 0.02129354846796819, 0.010191629906850201, 0.08246263901570014, 0.009118349507584103, 0.052604244955416234, 0.03309777452211295, 0.06780105110790048, 0.03560546013925757, 0.02604001627436706, 0.04436410211824945, 0.05676869595689433, 0.015457266908405083, 0.04589571850374341, 0.016903582960367203, 0.02716553962922522, 0.08767277015639202, 0.06099056798432555, 0.045537048285560947, 0.014402306106473719, 0.00877750525251031, 0.04045373194717935, 0.010117178500097777, 0.029274911619722843, 0.016352071393547312, 0.01312594611330756, 0.03397517797670194, 0.03850732371211052, 0.0218899824456977, 0.023822021005409103, 0.013799864549322851, 0.02069528923103852, 0.014254551713487931, 0.008436692379681128, 0.061814926963831694, 0.015575859562626906, 0.06077971322728055, 0.05290034406685403, 0.01230469482418682, 0.048504760289298635, 0.04303551358836038, 0.03911024957363095, 0.061623478308320045, 0.07804432431502001, 0.02642596360029919, 0.012004006271516638, 0.02627427370420524, 0.04024691108082022, 0.04379865513848407, 0.03491088116009321, 0.055711728387645314, 0.054181055165827274, 0.016882667118417363, 0.04231826814689806, 0.03013206080400518, 0.014806660391124231, 0.04442053587575044, 0.03865898985947881, 0.05406770928363715, 0.029622854199260473, 0.06375603244772979, 0.02829912567644247, 0.01533452161986913, 0.03314447469477143, 0.007778964637379561, 0.021140913711860776, 0.06582879408129624, 0.024352440311174308, 0.02191483209441815, 0.0487045854596155, 0.009642339694047613, 0.05232474620320967, 0.0552185894921422, 0.0489032910471516, 0.043823187572083304, 0.06619269919714757, 0.035620041856808324, 0.052114709080862145, 0.07229736340897423, 0.0875139861766781, 0.003291721592956622, 0.012566334534702557, 0.04092082527599164, 0.00781806861050427, 0.035614878205316405, 0.025779024564794133, 0.06388015007334095, 0.04871565575844475, 0.04257491383967655, 0.04137386953724282, 0.03811506261782987, 0.030574604735842774, 0.009860702441073954, 0.03862415047894631, 0.02644825686833688, 0.018703466647171547, 0.07764171556170497, 0.010488035207215165, 0.011394322201210474, 0.05351013670276318, 0.024358592927455902, 0.0448782552432801, 0.047164643449442725, 0.040430152855281315, 0.007416097680106759, 0.03989669880164521, 0.02852455706202558, 0.02497801567161722, 0.051338736433535814, 0.029144612540091788, 0.04136181536263653, 0.02822152162635965, 0.030015888823462383, 0.03538813894348485, 0.025547652605122755, 0.030045954710138694, 0.013587279527980303, 0.024002640242023126, 0.013113587446111654, 0.009985309460067322, 0.022380383452400565, 0.02217718935571611, 0.050810598701770814, 0.006576364369331194, 0.0033859164603719754, 0.03919484592708094, 0.04417218866625002, 0.05653791601902672, 0.028424730990082026, 0.03844418602862528, 0.036287248733320406, 0.04778110608458519, 0.02150113438256085, 0.00958055314341826, 0.041763148470116515, 0.08033353183418512, 0.02907780398215566, 0.05024448336501207, 0.027710296379934465, 0.03620097300569926, 0.023667301450456892, 0.013161273190884717, 0.0315557595874582, 0.007644399268818753, 0.03100127773359418, 0.04405607096850872, 0.019174388609826565, 0.02583610123422529, 0.03441038355231285, 0.06101838792009013, 0.004472980026288756, 0.11541255057922431, 0.015907749699960862, 0.07170370633580855, 0.02978884082819734, 0.03678209075172033, 0.009148146524759275, 0.002631035225931555, 0.027049191229577576, 0.06300868040749005, 0.045917801425925324, 0.026227135876459733, 0.08646544601236071, 0.05789755431136914, 0.06591623010379927, 0.002070573146089113, 0.03538262923913343, 0.009576158781003739, 0.039219588706535954, 0.03127274263117995, 0.01423957644562636, 0.03200701930161033, 0.054373647152845345, 0.008114066789858043, 0.022432310041040182, 0.02537877711334399, 0.009056336495892277, 0.029887530353984663, 0.025353427045047283, 0.02865523612126708, 0.049241466115095785, 0.04403467336669564, 0.02027369337156415, 0.03747613029554486, 0.08064060285687447, 0.11658455697553498, 0.10275978595018387, 0.15615962339299067, 0.1383494497942073, 0.14491684096200125, 0.08492244380925383, 0.09534945751407317, 0.22862542633499416, 0.1929265319236687, 0.12766854864146027, 0.14458686938243254, 0.09436295580651079, 0.18173473461398057, 0.13532076802636894, 0.10731407228325095, 0.10137921145984105, 0.10826600941696338, 0.09203655778297357, 0.1334397875304733, 0.1339569804923875, 0.11998968997171947, 0.08559152683509247, 0.09119416334267173, 0.07273153082600661, 0.08472003002784081, 0.15629048565668718, 0.14589674052383217, 0.08358626586518117, 0.1486488649887698, 0.11299670806952886, 0.11897354306919233, 0.13888614385255746, 0.11939054355025291, 0.13014311157166958, 0.13215407223573752, 0.16622343765837805, 0.052295070474169085, 0.2069614588149956, 0.1265627129801682, 0.1302574718637126, 0.15118905582598277, 0.12522745105837071, 0.14557400212756225, 0.1025597606120365, 0.10061864155743803, 0.13788644463888236, 0.08300100905554635, 0.16043372904615744, 0.13588110224476882, 0.12534818957958901, 0.08925244039190666, 0.1391348133661917, 0.1309526309903179, 0.06710882325257574, 0.0756294656811016, 0.15738132569406713, 0.13125124068132468, 0.09593371687723057, 0.07976259211344378, 0.182434955611825, 0.1344003759856735, 0.25829727415527615, 0.1996931681143386, 0.10490998878542866, 0.2001103992973055, 0.13232290531907762, 0.14366855365889414, 0.08687451441905328, 0.09751711905534778, 0.12988931233329432, 0.2162022508148636, 0.098594870152218, 0.1617948974349669, 0.09382310656032392, 0.06588836267058339, 0.11652837427599089, 0.10460537405950682, 0.12979632589433873, 0.13338238346789563, 0.24423889709370478, 0.08727423261318888, 0.13577350016151155, 0.13228122969823225, 0.12633175323052065, 0.16699049435555935, 0.08118809240737132, 0.1514856977654355, 0.09075304094169821, 0.12849429861775466, 0.09975789953023195, 0.18286931301866258, 0.10192360010530267, 0.13325692234294756, 0.11760918556579522, 0.15233018887894495, 0.08686086229447808, 0.17376167673085416, 0.19016272308570997, 0.14865233908806527, 0.12134918916438307, 0.14049230409520014, 0.15975049856517995, 0.12052968171026025, 0.13795611661459717, 0.08740734082779714, 0.10804344993084669, 0.1717758218624762, 0.11086205725691148, 0.09086205437779427, 0.08349642782871212, 0.1273929277168853, 0.1602674201130867, 0.17225839596773895, 0.16477597318589687, 0.10805398079433612, 0.2143714547689472, 0.14642633710588726, 0.25871549599937027, 0.11040234978177718, 0.10814985779247113, 0.10671730073434965, 0.11017651297152042, 0.21514687101755822, 0.09401019902101584, 0.09939185024372169, 0.1246750285582883, 0.16586918809584209, 0.14704213477671146, 0.12009723777217524, 0.11632159751440797, 0.1326017967824425, 0.09690174207623516, 0.17204001625733717, 0.08422566976930414, 0.09480337253106491, 0.15468446112104825, 0.11905838708792414, 0.07256055357200758, 0.08588322903960943, 0.16712082736194134, 0.15707347435610636, 0.08492152778697865, 0.1621862764337233, 0.07574202106999499, 0.12429044848041874, 0.1344776339828968, 0.1497283870620387, 0.2154856092695679, 0.11560897289642266, 0.09805504126208169, 0.07634544226207904, 0.09472093052629914, 0.10203309530126196, 0.2646679851625647, 0.156106222687023, 0.19784606008657388, 0.12578836881688663, 0.16070607943194254, 0.09921282556440149, 0.17007633591336863, 0.1018286052026919, 0.10777242947369814, 0.17144882226628916, 0.16053275444677897, 0.09950164399508919, 0.10229196319622652, 0.15219355906758988, 0.11696620578212397, 0.09474320004561118, 0.10989641371582236, 0.11440025775560311, 0.10088501404970884, 0.17600517134581292, 0.12761309875973634, 0.1680394552115883, 0.13203161023557186, 0.2999968065747193], [0.04509708278679422, 0.030296147534889833, 0.020202637184411287, 0.03438916576227971, 0.0187704618022378, 0.049076052848249674, 0.03697586678234594, 0.03763769966151033, 0.043248414128486595, 0.034931861462869813, 0.023237888867567693, 0.020829671395144293, 0.01230443358820464, 0.04338847393436091, 0.03884327997054372, 0.03506885089778474, 0.04907701636797615, 0.03745504142716527, 0.037050200293638876, 0.02298847126907536, 0.07151428650000266, 0.0315469759516418, 0.008034269375327443, 0.038181484410805364, 0.010731688650724078, 0.03503367564241801, 0.038358982386333604, 0.01860856673946338, 0.030957376517887627, 0.0037305138622676687, 0.013279161865024694, 0.03001562080213002, 0.009079337136686912, 0.02489395027181932, 0.03542268316128424, 0.006972560966720006, 0.03014639824894922, 0.020567444751837423, 0.05292157203491245, 0.02235241254259433, 0.04059696051159075, 0.022994920744427612, 0.038852077177060504, 0.0425896482276065, 0.010605788174351411, 0.04955037936036076, 0.035156263171562126, 0.0213708573553179, 0.018915573301325952, 0.07213024701923132, 0.049850977158972194, 0.024306203238666058, 0.08348505558179957, 0.042149007586496215, 0.02180492808111012, 0.01040678148690079, 0.02602412668056786, 0.04079840738060219, 0.01858072984032333, 0.07079978912536587, 0.04084122294027891, 0.05913597571530512, 0.023064134709004844, 0.040204712988010476, 0.015435984657545174, 0.025119127206770436, 0.02599849841291351, 0.03424801690770047, 0.018944813071617057, 0.03616593685001135, 0.06437564348535878, 0.0942146009100335, 0.033170689895216904, 0.01708683660919113, 0.009383997663722506, 0.007478701017264808, 0.020601578455950533, 0.05407377877937896, 0.06053392748747553, 0.03624374785327485, 0.037662557791918516, 0.04766180605760642, 0.041353598303560696, 0.03935034579730459, 0.012177201486857874, 0.08540424438459532, 0.0201083734032831, 0.08628844336739608, 0.022305554610544016, 0.04264975625223347, 0.016684575605073144, 0.016793449941490377, 0.008831807561883969, 0.08967994459505592, 0.05793340810175453, 0.04440163867548108, 0.010199612871344601, 0.15501492124583038, 0.03358076253373708, 0.020893323068906153, 0.052196645577039034, 0.12713204457291535, 0.026218084219310964, 0.02693355020268687, 0.12345848312335354, 0.0509058412696634, 0.06055813083159072, 0.02192083712933319, 0.05970156179474933, 0.03431126654946378, 0.016556055983528495, 0.027304824208840728, 0.02951971348375082, 0.004995475739373693, 0.04823734285309911, 0.02083479263819754, 0.05775343347340822, 0.039692761709115336, 0.14337094819971494, 0.04646010357620461, 0.06817106303891965, 0.02443724192146744, 0.10747611323105437, 0.059215547516942024, 0.021278518917305127, 0.039373945245253186, 0.04982307579900537, 0.011518740926736167, 0.011443623707496693, 0.04272429671670709, 0.013372956608821238, 0.06486041604408196, 0.018779579616550888, 0.030108447785356214, 0.05133812914469412, 0.04297951748594642, 0.03390040681032198, 0.022563267299639325, 0.09274100605398417, 0.05773574406547206, 0.022152521215113144, 0.00413318707640948, 0.052861681141491444, 0.04724572838417121, 0.014725558493020279, 0.04002573580614158, 0.03917981298374278, 0.060301766730844975, 0.009607153412486826, 0.03508888464421034, 0.06823456713131495, 0.0615407648895468, 0.038435755231018574, 0.007849816415858055, 0.03652954001777938, 0.08862050715833902, 0.014952022948169282, 0.030208009228642498, 0.0378671903828425, 0.048387034463563135, 0.05452928273007274, 0.01115867801542793, 0.013814665942585893, 0.06620348790394408, 0.04061302143548216, 0.01258567363090281, 0.022970335724364434, 0.053015739124800475, 0.030376455547021966, 0.01908723757203136, 0.11186048082475152, 0.09240513121975319, 0.052441552613994906, 0.027059303097692982, 0.009569866216874548, 0.0048681151404577705, 0.039183314224439006, 0.053552948869764805, 0.01779389724002353, 0.06102547182568482, 0.024564543572653617, 0.005279714482769902, 0.007548702930632446, 0.04900652336488877, 0.03365863460515227, 0.023067227132352333, 0.02017323286937816, 0.06182844338140317, 0.010584773096655096, 0.04818318897326078, 0.03734685580379196, 0.025656727109370486, 0.04775185783260635, 0.0382603335726474, 0.014728367627997483, 0.020303391152992845, 0.07288031319954566, 0.05274309018360717, 0.024516449010531818, 0.028194807702675462, 0.023677145297239934, 0.04945866856724024, 0.020507340119885545, 0.04430065230865564, 0.046079360613865514, 0.015210648266864675, 0.07560191715934447, 0.0048740260286389715, 0.03570151016382234, 0.04432868937562619, 0.03365604938673122, 0.029012030190122978, 0.050912039687058756, 0.013337516724797232, 0.008347882323765328, 0.01930038577743939, 0.022081147812839066, 0.01860752858088485, 0.04978458590007254, 0.031679463306708, 0.05175293456496937, 0.015684213123417327, 0.019256364121767025, 0.04768866925899472, 0.013734126380378646, 0.0264243266345667, 0.024561312049627304, 0.05319871287792921, 0.018020948627963662, 0.034738502731280665, 0.015181859722360969, 0.011922754247539809, 0.016246835701167583, 0.08591538481414318, 0.021090622392616103, 0.01418084160624338, 0.04792661113398416, 0.007829730931137289, 0.027193362957664897, 0.015770229311393838, 0.03627188330782311, 0.013145154591516724, 0.012438436620868742, 0.032534315649952204, 0.007083554876901741, 0.0509433439001441, 0.02613157100443329, 0.08390270067112786, 0.06551666797271796, 0.029490583975400244, 0.06846910954586097, 0.04461499722674489, 0.02307282674259373, 0.07033180352300406, 0.03489825362339616, 0.09963139346135513, 0.025393358830894743, 0.04116264497861266, 0.031780330929905176, 0.03615410319928612, 0.04822318521993501, 0.03598741089392986, 0.0206270981580019, 0.033661823719739914, 0.02729378953309996, 0.030208392600928034, 0.05433555758957352, 0.026199188715379153, 0.012982647999056747, 0.05961587639259441, 0.03295715492484825, 0.048106120965842686, 0.06111961855952229, 0.03882884753069707, 0.02662991595986698, 0.029125457496515343, 0.025907498385225023, 0.04806141907881413, 0.050703780326460085, 0.012417366412202162, 0.07442466568733964, 0.03318559391690152, 0.05672223666416747, 0.06239395482199533, 0.018231567594089677, 0.017901582443820577, 0.018388512743903056, 0.014729524530204279, 0.006347844377160072, 0.08231567511601107, 0.05446848599240184, 0.022791582459051694, 0.05340807485793318, 0.026356744546709315, 0.04198177245312503, 0.07714852238340036, 0.06396931636014155, 0.06562500287379537, 0.024552129774487445, 0.044809787667223384, 0.012605082276942474, 0.06951609586498567, 0.029257961814957004, 0.009337271197832056, 0.028907423838973045, 0.0312683457242591, 0.06719929911196232, 0.05082446795755199, 0.012667741593239563, 0.0608353123867086, 0.044013465754687786, 0.0492000924423337, 0.03574005434555667, 0.04975758699168052, 0.022972152501876866, 0.07735767401754856, 0.025600435844223415, 0.036401873654020686, 0.028709783551416228, 0.02759272152824061, 0.019850382514830147, 0.011037794457349395, 0.052324271228696616, 0.019111228873953223, 0.006686227670538106, 0.020494117168709636, 0.015184500919921058, 0.07229260009314332, 0.012210880572508489, 0.015619957553488868, 0.024941719137132168, 0.05668144992419651, 0.014098100197900618, 0.031552092105682404, 0.004385423987904298, 0.006464398033650858, 0.05466612967263375, 0.03276007442868181, 0.04054449957662395, 0.07649410249931471, 0.022957871036071862, 0.03939036240002938, 0.015751435587714826, 0.04498769276376281, 0.03649138938635588, 0.048851861485413144, 0.03720627352595329, 0.02717024866225464, 0.009089782335130232, 0.040431950973080735, 0.036057442493204556, 0.03332717024854251, 0.11044562674526658, 0.11068933616791453, 0.1421291341206857, 0.12046613012041364, 0.11068821658513375, 0.13229250695024217, 0.09383243641683034, 0.1054480466991663, 0.06366949209145137, 0.15612131330583776, 0.058264750322060924, 0.10882171602653605, 0.09695080694343362, 0.10459638347050973, 0.13040457825575555, 0.14755562293742383, 0.14785734031881603, 0.15963813316609177, 0.1622946656176022, 0.13353448387767586, 0.1123862640400018, 0.08966806344687939, 0.10373880341649055, 0.26673442284975735, 0.07887094281613827, 0.1136602678203157, 0.1180661924715553, 0.17539016077561037, 0.13025785184332303, 0.06265938415059022, 0.12396864646247455, 0.07516807543912105, 0.20111003065747873, 0.1318609993904829, 0.09712415228464774, 0.053095266821661165, 0.14886329562536307, 0.10336540559572832, 0.09913161849336964, 0.07757033367774316, 0.0998926701556359, 0.10945635661482811, 0.10366677013891083, 0.08432861031698329, 0.09470909009022371, 0.08684422461582081, 0.10484375698225838, 0.16967977290706976, 0.10630966403654643, 0.1460692241255726, 0.11672096965568406, 0.16149077803960868, 0.11517667823604175, 0.11850645313305513, 0.11256959741669041, 0.07393116038292646, 0.0993202037311026, 0.1844361453716244, 0.12222042812832765, 0.15850404330662318, 0.09930693837148802, 0.11985540789152895, 0.11411426881594317, 0.15791628270276956, 0.10114073354218688, 0.06387432145753077, 0.15613686532846519, 0.060713949613273144, 0.1380586296852146, 0.09806331260395901, 0.10239763145468064, 0.15450627782515117, 0.1221694430070264, 0.08840923170958247, 0.08469861546265227, 0.12977299786039762, 0.1315724320177521, 0.14183436493788446, 0.11367529737097876, 0.262892231877361, 0.13830203376710415, 0.15229091527206556, 0.15268675903124468, 0.130995242989489, 0.12561927789023944, 0.17926824625049317, 0.08983589229839188, 0.24401704328400747, 0.16084654975150312, 0.0853651471968208, 0.11569155060819217, 0.14087206657443727, 0.06874772959521838, 0.18546633794903755, 0.1955377653773342, 0.13271144804145607, 0.11248073647064821, 0.19723932764359883, 0.11805267605398383, 0.12088459623711449, 0.15844890555100782, 0.22524652550263063, 0.09390252229890653, 0.17259010459695542, 0.2591637633740902, 0.18000972217747144, 0.19627371802926064, 0.1922204348125628, 0.17721741486872944, 0.13635465183428355, 0.15565866098872252, 0.0931419048990522, 0.08796857071242162, 0.18390728160738945, 0.14476400773440087, 0.1644852887839079, 0.19085428597671644, 0.11950502597859927, 0.21609079465270042, 0.13602045976689883, 0.19657002070120402, 0.17393705089177403, 0.19501039439014026, 0.16053365011300358, 0.09214034649942603, 0.13735513814858027, 0.067535818554461, 0.07860907579639129, 0.1777487892125334, 0.08412848998393331, 0.17786348877208574, 0.20794627097036156, 0.03946980188733765, 0.14859348296054772, 0.17547687755099364, 0.11763065441378526, 0.11365330605102436, 0.158164558666093, 0.1951011959463358, 0.2147867317710604, 0.14689327776432037, 0.0973207170942, 0.1154006083628961, 0.19549147571836198, 0.07471202526773725, 0.12962673285177775, 0.1389060520700046, 0.1426471820367234, 0.11809758150151797, 0.08119290322065353, 0.1866918129048177, 0.17562967006649288, 0.11257018095680646, 0.08046676897044693, 0.1231100961033787, 0.1464411291692938, 0.05709240465824093, 0.11701181690607752, 0.08363712885017906, 0.10297594006572451, 0.16089015241180146, 0.10721070425851004, 0.1283081221793379, 0.18325918566967758, 0.16176329127379827, 0.07631059270352125, 0.14853744953870773, 0.16399507437433514, 0.12192298551755291, 0.07974218178008284, 0.22149168912853512, 0.23304502346685954, 0.10387767917875733, 0.06872600968927145, 0.10717514902353287, 0.06715600179242236], [0.036106883947338374, 0.03995688485779932, 0.09665948471852712, 0.07285155010010515, 0.020547299047133753, 0.07416040343897683, 0.006468919621381376, 0.0051054632973058945, 0.026188084489798973, 0.05925804416515997, 0.09894264649067606, 0.036516026992883, 0.04826241132936307, 0.05731430596538952, 0.036584996684853516, 0.005526164762808808, 0.04941533732094935, 0.030827280998762165, 0.04388874762558511, 0.006172207708004862, 0.03424771495961717, 0.028243214390905838, 0.059244208836129734, 0.02092406918693866, 0.032968354145331044, 0.05298877753583448, 0.05273167383191841, 0.04708895626078759, 0.04995852156675287, 0.011085135845600494, 0.024450252830450023, 0.0641060411663992, 0.0720358220860362, 0.03094662173784205, 0.034318889890398295, 0.009586127308596457, 0.03067961142265371, 0.013566183874250522, 0.03303580391885979, 0.009539541638722377, 0.04090142256713339, 0.04387995720441852, 0.04112857573532632, 0.04117117755647216, 0.021092423903090612, 0.05120994709432125, 0.021190424715834003, 0.06465102013732706, 0.05340682635349887, 0.0471394528368754, 0.03428531258500048, 0.048495647563998184, 0.09087826457938977, 0.04543860303238034, 0.08872493369770901, 0.029193310998380184, 0.03207146995035665, 0.04653525472219501, 0.009241878504066594, 0.06376462948641606, 0.09230822963374001, 0.014413669871698533, 0.036791508817779164, 0.009044235672003456, 0.037364426468099864, 0.019015214472476925, 0.008157922204450836, 0.0659797206254942, 0.047779545454042296, 0.024025664631543413, 0.0671082397124597, 0.010366540119451071, 0.013271185685880482, 0.04873809491151145, 0.02202501261074628, 0.019315600228895034, 0.03653614894886102, 0.043856113483863216, 0.0289485125270273, 0.008488730926598822, 0.01046700231797461, 0.037123794201761484, 0.0913362553609269, 0.007040133724720883, 0.017635503417945335, 0.030083833927554742, 0.01054170647902148, 0.020941151306033134, 0.01925311902804034, 0.015192524596516575, 0.06434644612350635, 0.07961590641311236, 0.02867883556921567, 0.05181872871305261, 0.09130845578121287, 0.02787526690268091, 0.03533413094867553, 0.010208312538452446, 0.06951353100261518, 0.011543232648234283, 0.02862161471109305, 0.06789929619325058, 0.037889144383370876, 0.018533931280087148, 0.01972340147144028, 0.023573429523301975, 0.021077591127582958, 0.005601073756614434, 0.020260507739814262, 0.033019912628723044, 0.053124545607715845, 0.05530128255486488, 0.039049127139151096, 0.026671026700309346, 0.012021621888769525, 0.06547318744872298, 0.036023508956921954, 0.05398677023393767, 0.06850344341780458, 0.006535432168415615, 0.022745196108839343, 0.033511976046221595, 0.08729037496128253, 0.048853676566588025, 0.03478529450616666, 0.06088477758956807, 0.08918889558741025, 0.033418904790388684, 0.02885481362630214, 0.05101540092644947, 0.03397868600274835, 0.04470499471894332, 0.04481523969609823, 0.048131230154207776, 0.05435336913381304, 0.01759654193717454, 0.03218232221635325, 0.043661180551030805, 0.07307214862001793, 0.03667903146041291, 0.015062155967046107, 0.02125127743264394, 0.04200461872720292, 0.011872454446607401, 0.020992809873340384, 0.02716396882065705, 0.10948627322380032, 0.013643424059929592, 0.02540770306118897, 0.019385292560660412, 0.018838138884997795, 0.04819255614919322, 0.054147515179855485, 0.01704293200080948, 0.06460103924785342, 0.05054751710434045, 0.04097570179562483, 0.022095537844247053, 0.03904706100001931, 0.02205672224850527, 0.048554781890873394, 0.046975284681788514, 0.08193633332848549, 0.05213520423110042, 0.04630857313584004, 0.048353871064526696, 0.03650256146543792, 0.04647430870682001, 0.021300902091232792, 0.050200378588799915, 0.010638445216630186, 0.010812907596118748, 0.03381695378837841, 0.005181594502313861, 0.053549546016646285, 0.04165073557357703, 0.013500699307769537, 0.01702611959938492, 0.026266463766140596, 0.05141245926331196, 0.04128357009696109, 0.041935594752430916, 0.034480696743620295, 0.027054588975650922, 0.0262127695937774, 0.03551313866462026, 0.052613398392817805, 0.0044419612219956306, 0.051054647391928096, 0.012905307729462428, 0.08086327090859413, 0.03865908146170633, 0.0066988666575135926, 0.016640386011983668, 0.011833432745853705, 0.03321519839976515, 0.009681565803475678, 0.04850226328043001, 0.05680934698986156, 0.0717288257021989, 0.005890405753494373, 0.06018193066120148, 0.07798966831926789, 0.03646028194842594, 0.07580716043178524, 0.09044526424258947, 0.04372878638761384, 0.026824743719771504, 0.030728367556418692, 0.020039934664964676, 0.009617708024701901, 0.04388265438111765, 0.024996141038302864, 0.001914188635834892, 0.01568165504639702, 0.06024190637149981, 0.04818769105310951, 0.015313203745920743, 0.05555952280493719, 0.019016759835981896, 0.045909811676080735, 0.04079512327111193, 0.03758358310109802, 0.01883905829994806, 0.011567892307149512, 0.06092504185757466, 0.03581667791253754, 0.004290669541140752, 0.03404570829921535, 0.03747524141467043, 0.03250085369550756, 0.06846371519246272, 0.009307512348251683, 0.040537252822624784, 0.03323544927739671, 0.06131927748875959, 0.0891066367870995, 0.022898634928943853, 0.03572829872635858, 0.007080201641656458, 0.03825664234214595, 0.04008428659290075, 0.028729474637657404, 0.03869045692096863, 0.006560184701811522, 0.011246868908139212, 0.060889805534056256, 0.049016972804175954, 0.03941703900428755, 0.026924610503816178, 0.048527643882802556, 0.044527469602014334, 0.04865249093355877, 0.046758143297795735, 0.02497174431170736, 0.04382415109180978, 0.008557742178839232, 0.04520978066804154, 0.045721616595983505, 0.02332399326509663, 0.029801156238785813, 0.03965293848887086, 0.033940606617501805, 0.055742917249777486, 0.07163400721869298, 0.02983211100633655, 0.037296135311148, 0.03882501380784171, 0.03811287434239473, 0.03173782071098685, 0.03999785480222531, 0.03909747615190489, 0.02582196395711175, 0.03424311788486583, 0.03182061216128724, 0.038460294449968, 0.03883873378591878, 0.07719652195061956, 0.060923209813024314, 0.04557286136384521, 0.04727621835523418, 0.02760937956294843, 0.03954733469124351, 0.025689264559852223, 0.03215132673670139, 0.049400429906589646, 0.08956685316349779, 0.02772191459579127, 0.030921807712210075, 0.01749851567936795, 0.034531033863978725, 0.033944867817418914, 0.09685929971081869, 0.0556220192728298, 0.06909282572035279, 0.02552318972136293, 0.029583885933139493, 0.023161331457751136, 0.09521419155810561, 0.020874446224687353, 0.04304469416716269, 0.06837197725794145, 0.028787818471235887, 0.016954868333414197, 0.038529277712638886, 0.029532442800700665, 0.06228663093809571, 0.01865161130470889, 0.016936432536957518, 0.03705890929060323, 0.06158217588173492, 0.0349835794019912, 0.03324280798967395, 0.06455267327172415, 0.07138572447001934, 0.003990118391811848, 0.030896355863660574, 0.01113111846747675, 0.07471118388431412, 0.036273718745048554, 0.04644302824246032, 0.019415120960080197, 0.043438163053776534, 0.027289540207545673, 0.027244931619082178, 0.01656417635136417, 0.03271054815767067, 0.029157087406409637, 0.04718449738408838, 0.024249389501554624, 0.07403969884450946, 0.02765385414074574, 0.014514586688684565, 0.05463466261114393, 0.0062156224989199215, 0.04824130210493292, 0.025114178990146944, 0.06870799458452634, 0.05884951180113213, 0.04708546519811664, 0.020101007905655673, 0.04176118750391262, 0.023427951615303755, 0.020187074983758584, 0.04518989959199514, 0.0044647252237025115, 0.012570551629843456, 0.024710545648953745, 0.017609311966225505, 0.01512449128287179, 0.08563051545726401, 0.0654396949602025, 0.17978634844933236, 0.09630018007010221, 0.21508986050529139, 0.1463138631411961, 0.12128904382033007, 0.18200627075774328, 0.10360023299498217, 0.11288189994437353, 0.07456725303615842, 0.18762934474008425, 0.19624044267194612, 0.08813823839383465, 0.12491353361734323, 0.10219285637140274, 0.24880277791193553, 0.09068960470280477, 0.16834953214441026, 0.07011144249034779, 0.12457721094999995, 0.08010194783232041, 0.06929743795522622, 0.1373052115419081, 0.12911392322608403, 0.1511996816843748, 0.14126538618334702, 0.0963639895032559, 0.16006197328014032, 0.18470415313329014, 0.21607532405427524, 0.20076794044247695, 0.12408881501427718, 0.31612612679600716, 0.12462727326367583, 0.15517004792179379, 0.08363824843295983, 0.10505457102720227, 0.14348579703697137, 0.1251360931034599, 0.15070676670542785, 0.1738724679286991, 0.18785840459167957, 0.15165039178516182, 0.14566810136394842, 0.19656561022358282, 0.21468363516032696, 0.2058699131011963, 0.07954426668584347, 0.13408667567585195, 0.15286140037434442, 0.15758010931313038, 0.19080961123108864, 0.0831462223348873, 0.18503609246441297, 0.1493545142667634, 0.1433783442314182, 0.1652743707277945, 0.07504226826131344, 0.1324593179992267, 0.12694603098290308, 0.17097371204623155, 0.22043625504842826, 0.1292827698801245, 0.12873131089976855, 0.16375240311026573, 0.15182976930269174, 0.10281831638089248, 0.06946996905441795, 0.15176726265677384, 0.18905293835060938, 0.1372132021933794, 0.1356141394270318, 0.08252443998519864, 0.19902059063315392, 0.1526108038212572, 0.10515826474875212, 0.11455697220351015, 0.17276481379355701, 0.09139075529362474, 0.1582527139357158, 0.09785202358450208, 0.0792484050616622, 0.12914031823830946, 0.13899679934339865, 0.10423393720494849, 0.07812680024653673, 0.12496389448642731, 0.09216935387147324, 0.18957976650978836, 0.1771331951022148, 0.08666441283587899, 0.11895039145435606, 0.181750978742327, 0.1377412381448916, 0.11754562040524823, 0.1810502420578684, 0.13877554264451775, 0.17020422619368347, 0.08484766925019877, 0.13355740479060582, 0.11718582042625972, 0.17507248425057956, 0.16253851753260407, 0.17098275013267994, 0.14964471012353897, 0.10395963263830968, 0.07571781094052962, 0.15600554166095598, 0.08292907077286925, 0.08907899327043976, 0.15627198879207882, 0.22192922207926, 0.1612202189862728, 0.11781362816691399, 0.08968811415668045, 0.11938035195427281, 0.11359504024897303, 0.23817792375172886, 0.14079468644091062, 0.1575739210737603, 0.11989344656467438, 0.13151683285832405, 0.0612162555168782, 0.18141564673611096, 0.08160211411970002, 0.12019866518676281, 0.13264506017523153, 0.21014201029070786, 0.07863699072705847, 0.1053991921778236, 0.09747021871485881, 0.1224329045840672, 0.125602124524968, 0.12294451998812811, 0.12005382510168211, 0.173549105280212, 0.09540528737540756, 0.18576493406934397, 0.19282614945300988, 0.15606243003691944, 0.09722481295466423, 0.1279455537774733, 0.05524296586268714, 0.18556986882218293, 0.09442679916641541, 0.08606755307742528, 0.08990367116140467, 0.19984967900174005, 0.0709125752161656, 0.11849780859691755, 0.12282408002231802, 0.12951029624257768, 0.12241731184933867, 0.12210978620818683, 0.11660050254847322, 0.1281351228909833, 0.14394916860120638, 0.14155771264008113, 0.19562088591711863, 0.09306941700301, 0.141191303730011, 0.1267397699079343, 0.16488614013152464, 0.1404986416122743, 0.2011387191180672, 0.11352462867008788, 0.18259521201252937, 0.13104829085724695, 0.16499896693442548, 0.14794825044061455, 0.09176300639020545, 0.10186308156698942, 0.09216209354677371, 0.07493579254618712, 0.06452270237995045, 0.1538145520857402, 0.19728455878794193], [0.03787923098674842, 0.14056790646697792, 0.037487997873021026, 0.05191872102607574, 0.06830290917839323, 0.029833854841334478, 0.06744860644851412, 0.043084069554294856, 0.04228523027684007, 0.0059216103067488545, 0.03187803318724036, 0.06393825302698783, 0.0200308609554278, 0.03553720969440682, 0.02640477125532925, 0.058396399686379094, 0.025062469532713294, 0.031753427016415765, 0.029738731017070155, 0.09575213412089006, 0.03090150255177702, 0.032874346511172395, 0.014477874551500593, 0.05162633350118995, 0.05708790597106729, 0.011912454085956727, 0.05724426758076463, 0.04396604633490954, 0.04891753688986812, 0.0917262840749962, 0.015309062985969442, 0.013050846705612327, 0.044921644165047576, 0.0077956735622137785, 0.06834924633481673, 0.016362356288092475, 0.08432154676743916, 0.015610882147614445, 0.053805855834590535, 0.04680706227996519, 0.05545716579737408, 0.02929746951641781, 0.03344929298119886, 0.029392406743552004, 0.05959512000637395, 0.05677869077771902, 0.06198099162429571, 0.040148174057581594, 0.03797885010551129, 0.03739088933382716, 0.01771016262604722, 0.025206824465255653, 0.03431044891476631, 0.0438838859221765, 0.03545125627091952, 0.031350747016923766, 0.01955430206310536, 0.014363309002614446, 0.05630035751632281, 0.06101809615003211, 0.013658853098084884, 0.02670648354770882, 0.022529391438833306, 0.01928440967042531, 0.0259661221144987, 0.05601858227912869, 0.03012006769755057, 0.054024584990526946, 0.003163465963942664, 0.03151472518220544, 0.030122391679989438, 0.014787291609016913, 0.028871190068977218, 0.03943785306598459, 0.020734328743336455, 0.06884489580988884, 0.04564024667654719, 0.04089991621939199, 0.04743707186675497, 0.11665621027350426, 0.0158354382230235, 0.09165796238396849, 0.00873679484772895, 0.04185433679127267, 0.03856179989608271, 0.06782161750431571, 0.0376459506473371, 0.004197000750407044, 0.028615015958036696, 0.024592494126409292, 0.03206641486446772, 0.02937559603846499, 0.04101072438061237, 0.033491487681333504, 0.027179227376888906, 0.044278925617358515, 0.007173809788322875, 0.03242928521441562, 0.061916714001979144, 0.01761745099377419, 0.03613934845530561, 0.039847956238580604, 0.005327320499678275, 0.03730138038684215, 0.0182833924024765, 0.050587716911520274, 0.018253928715629236, 0.0672925841063261, 0.02596367260308138, 0.015994522454483167, 0.07537355619881835, 0.04446406389719673, 0.02962661667593888, 0.026493067320968424, 0.018864248912515383, 0.03073115972802043, 0.02695434051565826, 0.01848832524514624, 0.07957936730235815, 0.024690673054595078, 0.008134231154274727, 0.012558932565817875, 0.013776268494049353, 0.1193126884422132, 0.06911322248301335, 0.0041983866581826335, 0.015751983504742384, 0.04942054846989257, 0.04998685379645654, 0.03645345249346324, 0.09598469521318163, 0.039724059136850495, 0.025768544591431106, 0.027436777217579738, 0.03105033581544246, 0.010614861883888287, 0.03766840337110417, 0.006809812222075249, 0.029490787535905838, 0.02570087938303394, 0.017400372374270643, 0.011795417821433927, 0.043820928050471206, 0.05847610040966954, 0.05708966337676559, 0.033900647690253596, 0.05722190306654998, 0.11318036714302641, 0.08264395714338336, 0.034939328740750036, 0.06470003750707422, 0.031263358491872034, 0.02000907658865409, 0.051597838423081806, 0.053032821243894954, 0.013869902933947742, 0.03625270790819611, 0.015995703105415617, 0.01976911267930908, 0.04256828794521945, 0.006401218789895731, 0.0767985408061317, 0.038673194990094216, 0.02784780828681375, 0.011246961358535503, 0.07196602118866784, 0.015708448697945902, 0.018502701705853854, 0.0446548034836139, 0.056877061392047575, 0.028071612884689654, 0.0318185222734298, 0.03788076447589057, 0.04682632928181972, 0.01089117321784475, 0.009163723992449897, 0.02924458110438926, 0.04720006976276636, 0.039876746479421854, 0.03879713619660054, 0.08163760150117533, 0.010589358297043612, 0.09196086041629314, 0.02675598606999431, 0.05185502694387521, 0.03140537587127515, 0.06044248132301228, 0.05807571725121566, 0.016469152611015097, 0.024766857270151377, 0.015665558499417136, 0.02955581493941801, 0.01274754833762667, 0.037026777264795134, 0.03581283740433199, 0.03995095446173634, 0.03407892598105328, 0.0023789548015754136, 0.026687226723879576, 0.012566072450551604, 0.05524850610111441, 0.007391600021427231, 0.01659077492409519, 0.01502946245351008, 0.012321848189458251, 0.05079105689323374, 0.033819549184824736, 0.05486471312386649, 0.022798445840765322, 0.026281498405816298, 0.032715277546750646, 0.039339913321392875, 0.07045916454600436, 0.028797053332839693, 0.024361743026279976, 0.0186174674225705, 0.03406009663428579, 0.044552863775087256, 0.03151494909876159, 0.03623701000053968, 0.021531583641522696, 0.032457054260053804, 0.046478970242398124, 0.01822931146515267, 0.07456819619983435, 0.024248088410656368, 0.05449005662064467, 0.011391825192341847, 0.04097393421190126, 0.054710706030683856, 0.026048720182318772, 0.032001974393746684, 0.012272745154664984, 0.007826850549983127, 0.009090405739178615, 0.04669987071039421, 0.021437825368983403, 0.03266627714037895, 0.007685756826374147, 0.03525285941681691, 0.047191733960062265, 0.013933308638765343, 0.029906715931636945, 0.017166691699198315, 0.01471036609395274, 0.048426263965666294, 0.047924209120018144, 0.014838917945910777, 0.034302448986896446, 0.02712819815081145, 0.03260859827111874, 0.03335388756490179, 0.02402203107651855, 0.023983829554968646, 0.04757983224200351, 0.051457008479961326, 0.0561300757607179, 0.023878086657662476, 0.06635295559785195, 0.015586219096024121, 0.020850604200469594, 0.02264621142031891, 0.03124580139826451, 0.042109649162739515, 0.06367769557982683, 0.00661331950686872, 0.06689032140587058, 0.046815781454954825, 0.020111129951796362, 0.023950952836977582, 0.02319951431958803, 0.06653716428471462, 0.020388421768854772, 0.01536500989459455, 0.02668269580629255, 0.008608463519651974, 0.009242127865685948, 0.0195600560400635, 0.030838985727833848, 0.04181304454271283, 0.014709850407338567, 0.005188891722355038, 0.010540049157238432, 0.017127180605062416, 0.021949500144858445, 0.05863626181547131, 0.015686167304271033, 0.036336632511977635, 0.02584390777961484, 0.04945258889347315, 0.0185185675509274, 0.026769242947921157, 0.03276243233787162, 0.016886108987299458, 0.033848899217056375, 0.03537412380267467, 0.06685795528548104, 0.017633766368297592, 0.03735998206372772, 0.06325903268797056, 0.011385722618017877, 0.006292037840466946, 0.007741123587558312, 0.037143963655190806, 0.039543046349925656, 0.032127374450543096, 0.03993277311591165, 0.0062790706121761885, 0.054682156669774225, 0.026416811859235168, 0.013659727560090167, 0.008253125756579851, 0.09566779221807208, 0.012758633903493839, 0.03751821982275162, 0.01892535268728222, 0.017691602996949638, 0.005196840760098504, 0.04552698561123439, 0.028470450679638555, 0.04583564440586737, 0.034347120339849165, 0.021068246004038622, 0.04492404957168868, 0.009864937347759093, 0.0220060526459877, 0.02398584989298667, 0.056712380943021605, 0.03974709200805851, 0.09141910448670387, 0.05316767329350114, 0.09004971225346838, 0.036197152853544266, 0.02117205846921674, 0.02210715945277895, 0.028298710073743547, 0.007175720712569143, 0.039590180784996064, 0.03015354322269559, 0.029946773246462857, 0.07347973103501967, 0.06799049808510713, 0.018389554295156683, 0.039514100046030114, 0.07489206774958543, 0.036572016309946775, 0.016713045238118087, 0.01720925959359322, 0.013692609367093869, 0.03338533766301615, 0.023735348334802047, 0.0329794719416116, 0.08577642084232398, 0.2969821026282651, 0.10499896508242403, 0.1656187136790582, 0.1525340886520488, 0.08994088202182736, 0.19058720102267607, 0.13805371709167957, 0.13234950389180863, 0.1278318448790482, 0.17092903730060371, 0.1714754072683198, 0.09697977360337973, 0.1060884887618678, 0.1525103806384972, 0.1510624819036041, 0.05420029841895614, 0.1478574624551194, 0.1845532062330416, 0.25433099269866943, 0.19586454784231527, 0.12557784654200077, 0.10842636759792056, 0.12175688014498778, 0.1282946600445679, 0.06552284264138766, 0.09813961386680603, 0.09662272847656693, 0.16095170910869325, 0.24719369996871265, 0.13636910463018076, 0.060499898956290314, 0.11802144987242562, 0.10702961683273315, 0.16055108846298285, 0.132998454783644, 0.16725479731602327, 0.07732440544558422, 0.1697881892323494, 0.22069004071610315, 0.18609296503875936, 0.07178981242967503, 0.17151260455804213, 0.0684502666283931, 0.19232697838119098, 0.08365133058811937, 0.12323367090097495, 0.14695587940514088, 0.19491601016904625, 0.21876378836376326, 0.21061144795800957, 0.1738028366650854, 0.14237318959619316, 0.17047990140105995, 0.10426105824964386, 0.09685541170516185, 0.08791519036250454, 0.09818688740155526, 0.24335864718471253, 0.28052830696105957, 0.08336067332753114, 0.14308628918869154, 0.13692196139267512, 0.1392155047506094, 0.14190220486904892, 0.16882506305617945, 0.10678315934325967, 0.0734764537108796, 0.08647596330514976, 0.09519659035972186, 0.1707814966461488, 0.08867732089545045, 0.09300743282905646, 0.12373855523765087, 0.07592461484351329, 0.15057317673095635, 0.07341940248651163, 0.0724256472395999, 0.146135896976505, 0.2625954949430057, 0.15692312456667423, 0.13062968903354236, 0.11150485383612768, 0.13086781411298684, 0.10606217517384461, 0.1912453935614654, 0.12067935296467372, 0.12831549106964044, 0.09903648109840495, 0.15209628428731645, 0.2629335953720978, 0.08700098656117916, 0.1666393931955099, 0.13940595595964364, 0.08964829093643598, 0.09575297550431319, 0.11174569305564676, 0.14923901403588907, 0.18439038496996674, 0.1983479724398681, 0.1059567511879972, 0.12460357882082462, 0.17058069099273, 0.19444138849420206, 0.170448648078101, 0.13255708132471355, 0.0683645201580865, 0.0904447960534266, 0.11204397026449442, 0.13330545116748127, 0.1830131353012153, 0.15838775597512722, 0.19155749252864293, 0.10126455261238984, 0.08226103269095932, 0.16644051458154405, 0.12691682683570044, 0.08420298634363071, 0.1617718001029321, 0.0923266586448465, 0.2049741925937789, 0.20729501305946282, 0.119547841538276, 0.19502305585358823, 0.17908405113433087, 0.048148417446230135, 0.0971042372818504, 0.17065652406641416, 0.2171487393123763, 0.12867332329707487, 0.15743853976683958, 0.060908716305025985, 0.13285992507423672, 0.13212522092674459, 0.1188285265650068, 0.04568011060889278, 0.2692785763314792, 0.08203991169908217, 0.09488109193210091, 0.09799763041415385, 0.06930889841169119, 0.0667553607906614, 0.20075735529618605, 0.18075754919222423, 0.1810960296009268, 0.10138584753232342, 0.15741917437740735, 0.27694341646773474, 0.12011349547122206, 0.12651760397212847, 0.11636946137462344, 0.1055986068344542, 0.12021336225526673, 0.14941661379167012, 0.11510862117367131, 0.15641209270272935, 0.08245924634060689, 0.14546038822403975, 0.17923917781029428, 0.06793295153017555, 0.11874199977942876, 0.07611429930797645, 0.12225814110466413, 0.11251345542924744, 0.15686690115502902, 0.13475548050233296, 0.08368722509060587, 0.0951320073966469, 0.2342250230056899, 0.2038888351193496, 0.09147284446018082, 0.12263371023748602, 0.11509107425808907, 0.12973327642040594, 0.1042684203545962, 0.09677157191825764], [0.04031621325494988, 0.04939906265852707, 0.009605259451616024, 0.06793677168233053, 0.02042035193049482, 0.02159566109600876, 0.06113521807960101, 0.037997140016938956, 0.02672043253135468, 0.003985679500536727, 0.05703770795038768, 0.04060013605547803, 0.09770499183131115, 0.03685576608404517, 0.030673908335821967, 0.03708745186616268, 0.017144812337521995, 0.03552321830232229, 0.014981871703639627, 0.038743684600506506, 0.0580988417246512, 0.034601659181394746, 0.027728533704898188, 0.017790882848203182, 0.01960656452657921, 0.034146575922412534, 0.034109368454664946, 0.051112991225506575, 0.02820911122086857, 0.04492885359962072, 0.053822920990309546, 0.0851809995781098, 0.013090703004438962, 0.04945340992084571, 0.037066627626440356, 0.029509474390319416, 0.08178771380335093, 0.02665013460708516, 0.03264532058632799, 0.10763700745467629, 0.020836658609498824, 0.0364268674914326, 0.00941645453817078, 0.009917433057645602, 0.04750299832916685, 0.031428245894078694, 0.031018139328807592, 0.011976703718703772, 0.01841704174876213, 0.02845668829312282, 0.0758818807080388, 0.042232182409082136, 0.016728749931124703, 0.03431370588285582, 0.011453077396644014, 0.016488994671297923, 0.03417437889480165, 0.028047160178955113, 0.011374779544504625, 0.027383793810648576, 0.0542798939693187, 0.05601167818531394, 0.07509857309716088, 0.02457305070544992, 0.05007979613063591, 0.09282183314540557, 0.04495106544345617, 0.030355054552533796, 0.05294635891914368, 0.029024050437978337, 0.04844773281365633, 0.01741494900280876, 0.02769811498001218, 0.03783435268061502, 0.03147664240428379, 0.03488060153488602, 0.09153301694563457, 0.05036860777597342, 0.018750884370612245, 0.06532359761851174, 0.023788935637899807, 0.0139929467778919, 0.011213973530435135, 0.05329593337540116, 0.05181771769587483, 0.06561190714793545, 0.024040524548451816, 0.02601247453796012, 0.03280751759718571, 0.04885483346879482, 0.011070535468336726, 0.01994164377850081, 0.01633978312435959, 0.029954267665743828, 0.0416527576079326, 0.014900281260322248, 0.01488403373930071, 0.03161937224545649, 0.041172212322375605, 0.0328718834290547, 0.02227977367251047, 0.048040720368070264, 0.03697677941194602, 0.056172066900346956, 0.03888938981773598, 0.03281957855714219, 0.03152639937720128, 0.020467443957126567, 0.04413716608126249, 0.03782509746296065, 0.02107308735139668, 0.08834421448409557, 0.05868183222732373, 0.037321047724357674, 0.03257585556379386, 0.02361474552058748, 0.014845352154225111, 0.04556497339425342, 0.02530547327894185, 0.05526215144033943, 0.019631007054288472, 0.015262412007099815, 0.034128676168620586, 0.01247671787028334, 0.033330389897206, 0.0371449237822422, 0.031182548363826106, 0.019814511761069298, 0.009010217318843518, 0.04765015561133623, 0.035485664781715186, 0.05285613751038909, 0.02082429061244641, 0.023520323980067457, 0.015749096338238035, 0.013164424137877566, 0.059145733048873286, 0.019300981191918254, 0.0889796218169587, 0.012911164334842136, 0.03764379629865289, 0.005575175347205783, 0.04501933963703258, 0.039028228260576725, 0.01836218049616686, 0.019234204864395515, 0.020593410590663552, 0.04086813024644341, 0.005211048435220229, 0.02940462376656277, 0.05278241128793784, 0.0450328323058784, 0.02303736310984407, 0.022067755227908492, 0.03951571835204959, 0.045565909772579155, 0.038322860574615855, 0.019684473917420422, 0.020148924352335076, 0.10334813687950373, 0.043076154443302324, 0.024426797571192895, 0.03836235809805138, 0.02115428933341588, 0.0446986809505948, 0.02322583638929895, 0.029938674931015288, 0.01945284750711705, 0.05477575379024659, 0.11458453429596764, 0.05358071791540299, 0.08241445624402591, 0.029397482185491493, 0.009053188093405749, 0.06078841883156981, 0.026424481001283442, 0.021434994181618094, 0.04415076731571129, 0.019187686199854528, 0.019017843795674186, 0.025267563527449965, 0.04995088465511799, 0.024819335168493644, 0.01827960617707244, 0.03432839955868466, 0.05342378633628998, 0.021345987350546887, 0.010302851974431957, 0.047865841537714005, 0.02085843788725989, 0.024839852371120026, 0.07550456774021898, 0.01118134447772588, 0.03904461148860199, 0.035645853328917704, 0.0008535198701013412, 0.04792081983759999, 0.016085305350965688, 0.0370862338958042, 0.04612530761265329, 0.04654335643031767, 0.05294236234788384, 0.06213143640863044, 0.038259923058961115, 0.06724195860858474, 0.028386271625225033, 0.005535180372784713, 0.04481893092659967, 0.03157927082585437, 0.02807547544528331, 0.04754579353279301, 0.0061148447816127115, 0.08176482681717191, 0.016298479001436914, 0.022774593638522283, 0.02384650254888194, 0.00898396479897201, 0.04864489134134991, 0.005602482989031289, 0.028264099698779837, 0.009245327158298875, 0.03547547657841018, 0.02981564974678414, 0.048339119713221274, 0.02005320680992944, 0.027439716970548034, 0.022594169480726123, 0.015517408859782984, 0.02013039864998843, 0.009364374430983194, 0.03060698781960777, 0.019915739007826363, 0.02456585144890206, 0.0498169384497617, 0.015477224319641079, 0.02499136924078422, 0.004352268222386816, 0.05407555314845272, 0.02180066179218037, 0.004313789773732424, 0.05111487076750823, 0.1013049865141511, 0.04225892347416707, 0.017153017522235, 0.0065223826677538455, 0.00927094864060304, 0.02764441741497389, 0.03380620918635811, 0.04091237412233438, 0.03132759540208748, 0.02559435277778123, 0.04063713317736983, 0.05291020318067499, 0.08003745986414806, 0.056231299614799876, 0.02997559741405504, 0.039203090127557516, 0.014685718309400337, 0.07874860973762614, 0.018157147569581866, 0.006428241447013403, 0.046810359960155826, 0.04661214291783316, 0.02140970857414816, 0.023545226215251853, 0.04514367439384971, 0.04016097801338349, 0.05953998225075858, 0.010228744076032723, 0.02684337629138359, 0.020613951542015587, 0.006476866962787296, 0.02251610572316817, 0.01309006433335266, 0.05808085376130683, 0.011959439243323036, 0.02496533385211868, 0.04345987617437329, 0.029825332441500256, 0.039899216166564395, 0.03580185531505516, 0.07042843369500977, 0.04553010347964508, 0.023015181800084453, 0.03223792816113148, 0.013837780237996151, 0.03714565999273743, 0.06310133436428648, 0.05221643505085792, 0.03701059081192527, 0.030238444916903973, 0.034600139262952974, 0.02328356954136065, 0.04413939167612365, 0.04007116372564009, 0.05374205997213721, 0.04131258425435849, 0.018063399475067854, 0.018797494637380754, 0.05128531876419272, 0.019326690883774842, 0.01422958925832063, 0.025093057891353965, 0.03223373142204114, 0.027271340202007974, 0.0428205299457269, 0.03525502055085131, 0.10547506596360888, 0.03113181430048176, 0.009046964230947196, 0.058708349375852516, 0.07183004955628089, 0.04244868257748229, 0.013727727795152791, 0.03268826846033335, 0.079366178384849, 0.039677046838083437, 0.005183494824450463, 0.0322330019968961, 0.029964798529233252, 0.0416170123831502, 0.04421043089990105, 0.010157659899310341, 0.04468644357153347, 0.05331084418243595, 0.03296979603224567, 0.0371157026716641, 0.03692612677280392, 0.04117629031783768, 0.010659965802915394, 0.08023787875260625, 0.02641707988056753, 0.05712502183658736, 0.012840075917275888, 0.0011265180447870599, 0.021599354022847753, 0.029369112636361803, 0.0042297035937995785, 0.02025683008001319, 0.026253305275791457, 0.05798699201217719, 0.024593934316986373, 0.02152044209651649, 0.07180773253951754, 0.012577170738950372, 0.06998431895460401, 0.03116065203877432, 0.05015091338594045, 0.07145780524505035, 0.025036473159811327, 0.039850388786622455, 0.0542110124869006, 0.1437772006860801, 0.15959305129945278, 0.1283745371869632, 0.15379201115242072, 0.11902921008212225, 0.1193043017493827, 0.12321250060839312, 0.1688883975148201, 0.1381625405379704, 0.10367375226425272, 0.14209482739014284, 0.15339562456522668, 0.2252338911805834, 0.15264740400016308, 0.10527491170380797, 0.11850965581834316, 0.07311646374208586, 0.1278337583478008, 0.16687248354511602, 0.07847118390990154, 0.14161753228732518, 0.10782873430954558, 0.10819215766553368, 0.09746139775961637, 0.08457609917968512, 0.13683585529880865, 0.07194993990872588, 0.13011065045637743, 0.13439078150050981, 0.09984920320234128, 0.13521187672657625, 0.12384265608021192, 0.12118286666061197, 0.1358885389885732, 0.19047604341592106, 0.15665576819862637, 0.2911126661513533, 0.15089461233999046, 0.14854595836784157, 0.1324459644300597, 0.16003818384238652, 0.137505691498518, 0.11563071315842015, 0.06233627934541021, 0.12917857404266084, 0.1388078001993043, 0.07818011274295193, 0.11307915007429463, 0.14020744152367115, 0.1391909417829343, 0.11712321878543921, 0.13285368255206517, 0.13158254218952997, 0.12639948459608213, 0.06811735020684344, 0.09019882032381636, 0.11423776218933718, 0.10681496906493392, 0.08159224143517868, 0.12546250915953092, 0.07573394650327307, 0.1632128320634365, 0.13039700580494745, 0.11950566380151681, 0.14484254137745925, 0.19772011041641235, 0.11714840600533144, 0.13200718297490052, 0.09165792167186737, 0.09368397295475006, 0.12877941903259071, 0.11540459814880576, 0.1922173678342785, 0.12889251724949904, 0.09230621438473463, 0.15811744119439805, 0.20809662075979368, 0.1809701749256679, 0.10283166995005948, 0.12828034295567445, 0.191408350531544, 0.11947185918688774, 0.20746178339634622, 0.21774411307913916, 0.16412998070674284, 0.3321460671722889, 0.11938717801656042, 0.13359552488795348, 0.1394454331270286, 0.059490381340895376, 0.17999982913689955, 0.1870546391499894, 0.08986295227493558, 0.0994920020124742, 0.1200275793671608, 0.10216989474637167, 0.07491393693323646, 0.08225976383047444, 0.1326957874532257, 0.1176460978708097, 0.07946198074413197, 0.08378635227148022, 0.1540420920188938, 0.27048799714871813, 0.12569770296769484, 0.16946667219911302, 0.11244696578277008, 0.12111670949629375, 0.22867376516972268, 0.18549856836242334, 0.16494347634060041, 0.19786754250526428, 0.11047094288681235, 0.11229582210736615, 0.08250665558235985, 0.108451744807618, 0.09728364194078104, 0.25351506790944506, 0.1400343065283128, 0.14023786703390734, 0.07666879812521593, 0.10100131495190517, 0.11904819549194404, 0.18412708624133042, 0.06924240197986364, 0.10424123145639896, 0.08252055197954178, 0.10580828094056674, 0.08558281444545303, 0.25684113800525665, 0.17705268013690198, 0.1739037348223584, 0.07912516953157527, 0.06711495720914432, 0.17938685417175293, 0.1440274172595569, 0.10382124542125634, 0.09408726702843394, 0.1713624040463141, 0.1956251471170357, 0.0727581904668893, 0.11490750339414392, 0.10801199304738215, 0.1371742407126086, 0.06362154680703368, 0.07289783975907735, 0.10869145087365593, 0.11491583580417292, 0.12904779320316656, 0.11687692414437022, 0.15408106707036495, 0.12763733603060246, 0.0658179714477488, 0.11550014945013182, 0.12816463916429452, 0.13178466420088494, 0.2047486746949809, 0.07944465774510588, 0.10223173642797129, 0.14560482118810925, 0.1200789851801736, 0.07627122410173927, 0.12703877314925194, 0.10128643536674124, 0.21324349886604718, 0.07232280168682337, 0.09597871731966734, 0.111937854172928, 0.11765029121722494, 0.2465678464089121, 0.13345186545380525, 0.21006811782717705, 0.15777461816157612, 0.10166562109121255, 0.1932049212711198, 0.08121154936296598]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05539543268137744, 0.01592608541250229, 0.03459231914686305, 0.03849355284390705, 0.044747942592948675, 0.10872868209012918, 0.051799017270760875, 0.04147337330505252, 0.030845272354781628, 0.015185844419257981, 0.02613683134716536, 0.0020314068325595664, 0.053955964744091034, 0.046423469470547776, 0.08851501531898975, 0.05079847328098757, 0.0081776327985738, 0.07313049584627151, 0.033574513226215325, 0.0776204163474696, 0.05509113686691437, 0.03236609324812889, 0.04593549083386149, 0.05109830433502793, 0.05563686561903783, 0.043467445232506306, 0.034507112111896276, 0.002613229406831254, 0.060278662613459995, 0.0055047523180421975, 0.006196218093724123, 0.051058067208422084, 0.013310727314092219, 0.016668501110481362, 0.010701698251068592, 0.04226297093555331, 0.02742734388448298, 0.03567509479554636, 0.06649478298744985, 0.04549288922654731, 0.06217850638287408, 0.032591061533561776, 0.0404853347156729, 0.07866151976798262, 0.03526544284873775, 0.02939343811678035, 0.033185044303536415, 0.04120051062532833, 0.02128072245977819, 0.05201882190470185, 0.03345958635743175, 0.032886658529085774, 0.041315474813537936, 0.024712672856237208, 0.07106829221759524, 0.04593389288389257, 0.03933234087058476, 0.09578395741326468, 0.015027425152116587, 0.03964179015851446, 0.07135757205209561, 0.05973986509655203, 0.010386637478534664, 0.013336816137390477, 0.06952002458274364, 0.03987915188606296, 0.011122171983255871, 0.0535924124664494, 0.09551358156438385, 0.05049982627055474, 0.08445394930562802, 0.0296647096318858, 0.05167077075956123, 0.03670100920966693, 0.056814578494855335, 0.039754715348993025, 0.04446357195930822, 0.04577846086717077, 0.05387971776404551, 0.04727325315720268, 0.02281544653565756, 0.01105576884999339, 0.03678891681400793, 0.031231209502688477, 0.007850189610118312, 0.02726855142308133, 0.047402564968381605, 0.02834431441234691, 0.028815400919743946, 0.01235372237195926, 0.06325459506894861, 0.04491151702989425, 0.01834620099647769, 0.04267747440774526, 0.028213677761544074, 0.024868669753362025, 0.012511469889432192, 0.03363957116380334, 0.004390175853456769, 0.00822311160819871, 0.054323153969432623, 0.004688562900160572, 0.03326589175100837, 0.04662932003183024, 0.01924448806260313, 0.06861654842006308, 0.007317266510134297, 0.0262329271728439, 0.02056771786218243, 0.01828342632922743, 0.049164951113717895, 0.014991929288953543, 0.03355904941314033, 0.04757473644401346, 0.0694344477461917, 0.04688513112653579, 0.008014339105492192, 0.033522377988057475, 0.057465395357991965, 0.04813432088121772, 0.028920984361320734, 0.03398907437388386, 0.06567205927733864, 0.027910827226670723, 0.03522201321486916, 0.06380559264549188, 0.01639319909736514, 0.06708908466888325, 0.028427616460248828, 0.0815739549164261, 0.03537269887913551, 0.023636524798348546, 0.041598071078104634, 0.05202902028603213, 0.018624773548383797, 0.02796168681899352, 0.013611917982676199, 0.07352262123354844, 0.048097011633217335, 0.04060895361804536, 0.03998466408146279, 0.02571974435288991, 0.02044005149842373, 0.029457980367754186, 0.00299850816372782, 0.03372651864109295, 0.049289655672120194, 0.025099624413996935, 0.04189797677099705, 0.0638229970687202, 0.03157004274960075, 0.05050810439778226, 0.04486603143491915, 0.009070993700463856, 0.027966209254892807, 0.024120035281937038, 0.0141322729177773, 0.01684198385503675, 0.06977915032101528, 0.03335933280842645, 0.002940787946239912, 0.05061471921258739, 0.020377293794548938, 0.0595794797741941, 0.01636576253388609, 0.020910523931628892, 0.029186674925897802, 0.034403092693537474, 0.04317343940160104, 0.008838886378466018, 0.027990795971293534, 0.03075952927715012, 0.007930628240241535, 0.03554479232324021, 0.056329286856842894, 0.036895022727549076, 0.019514833377408128, 0.06692224647849798, 0.026533560594543815, 0.02248794482355671, 0.02883632354704397, 0.10223387381328003, 0.01739984142061855, 0.0480507423302957, 0.026266850531101227, 0.008555364761767643, 0.02341276260891131, 0.01626849453896284, 0.030989647643374543, 0.006112615794076451, 0.03658032836392522, 0.004138437241116273, 0.04057924735492893, 0.04999204798202429, 0.010247063673367458, 0.04855636287746685, 0.07252230455300637, 0.0188349480740726, 0.04109340726530977, 0.018617932219058275, 0.04083870557535972, 0.011366146034561098, 0.031787699820207696, 0.05059234452034746, 0.012179212495019394, 0.031930999630796056, 0.02630390363213207, 0.0568213231329407, 0.04094404474432979, 0.04709614533931017, 0.04154264494510634, 0.013428108783305755, 0.019061941786536148, 0.04286303337929504, 0.03762770823336073, 0.04484723601490259, 0.02151817239687911, 0.0029117103882267004, 0.07186498732439109, 0.03356578726587551, 0.02495836020846452, 0.039844268400754244, 0.01887610461562872, 0.08129686835621085, 0.05746413328285728, 0.007351785282870489, 0.02543691229740424, 0.039157892909965346, 0.0571987514517137, 0.049089033223156414, 0.029438638727047613, 0.04026636807247996, 0.044509624131023884, 0.026621385078345026, 0.04550873301923275, 0.04856134332450373, 0.06876984305147614, 0.009121624287217855, 0.066530847123691, 0.027507304147418057, 0.03588988844837461, 0.033523310973708115, 0.0867973378460322, 0.023742846146758114, 0.0719394361866372, 0.05951189090098653, 0.04012018109538725, 0.052620210884405036, 0.06301177452717509, 0.004109711037017405, 0.03672338729458196, 0.03406258346512914, 0.05146057418148432, 0.010007818162973438, 0.019087113739390458, 0.04266741851876889, 0.03141868194299085, 0.04480724994625364, 0.09380025350089584, 0.02974083786830306, 0.011587328942758697, 0.03312032902613282, 0.007352276372590235, 0.06085218755262239, 0.02956105662243707, 0.031991704766239436, 0.05193287865923984, 0.041414493428809304, 0.04733676742762327, 0.01122536274072315, 0.04740480074126806, 0.011884579019221877, 0.0070765104111550105, 0.018375045520120432, 0.010256873593399567, 0.07473809458315372, 0.03699877751725061, 0.0234383959655783, 0.027962758904322982, 0.03018935290830476, 0.07057039000626121, 0.06503612268716097, 0.04579834533589227, 0.04451574790956719, 0.029511699985180582, 0.062188915110060146, 0.10728058658008065, 0.06548129594219582, 0.04575699880453093, 0.012727911534186984, 0.05162690347060561, 0.046029953086482625, 0.03992312095527138, 0.02413728364211108, 0.04743172161813293, 0.05787586833217314, 0.015553439069273216, 0.08030349987425975, 0.10581615873213325, 0.018153983900057416, 0.042195762041956186, 0.02136037907829242, 0.06222189869731665, 0.02242187756512846, 0.02055546351974564, 0.0306982914917171, 0.010062642096142684, 0.025281315735940422, 0.032916792269263945, 0.037761688365467956, 0.007606877978625042, 0.022380115431068198, 0.04452480635206614, 0.03152496088296175, 0.010112574639996248, 0.029374127010149614, 0.04922078436772738, 0.02286688966809639, 0.062215160844581466, 0.05212851048314145, 0.049228801258972714, 0.040304101404867, 0.028307196850489293, 0.02614119941634791, 0.049603644359324656, 0.012330417238575007, 0.0485306837196861, 0.028690465659435307, 0.011681527414891337, 0.05970644046153341, 0.027156386191823652, 0.029472857248038054, 0.04453021088348968, 0.03235752674351845, 0.019501079472580125, 0.014214862503909638, 0.017512415469224964, 0.008216481472897743, 0.005349978056204106, 0.055890776815691164, 0.00861399358005396, 0.04920879465394786, 0.01620745861769787, 0.01741273867498551, 0.023008528764226606, 0.016747219654332315, 0.028198409027286937, 0.03148310884301152, 0.08804909924843482, 0.0528221971887563, 0.06268206757626363, 0.04252771494377937, 0.1271604344780956, 0.10237062576093844, 0.11915320557143007, 0.14927317148872785, 0.11939993447491101, 0.22273486027760164, 0.10615390632301569, 0.19451036836419786, 0.12956197346959794, 0.10342869255691767, 0.08294064658028738, 0.1787569701139416, 0.12383273589823927, 0.1289204050387655, 0.15893090968685492, 0.13097770964460714, 0.10496541152575187, 0.14863544356610092, 0.06332862323948316, 0.1502947331007038, 0.23300249289189065, 0.10294673591852188, 0.10610634780355863, 0.11946618663413183, 0.12453249549227101, 0.13435266140316213, 0.06625869351306132, 0.2555643522313663, 0.11653681525162288, 0.12563962037009851, 0.08914984589708702, 0.16924166998692922, 0.08971965246434722, 0.04324683653456824, 0.14457727489726885, 0.11975852666156632, 0.06991200069231646, 0.16020373281623634, 0.18187437712081841, 0.11230351669447762, 0.13770819348948343, 0.09494379535317421, 0.12755531471754822, 0.12003507039376668, 0.1358484239982707, 0.11395285890570708, 0.11199155343430382, 0.15533246206385748, 0.0977028612313526, 0.13815846932785852, 0.0802889656541603, 0.18587906365948065, 0.1710213723459414, 0.10719279093401772, 0.16133010094719274, 0.15908932047230856, 0.11819002511245863, 0.25377019707645687, 0.16253308925245488, 0.18168695217796735, 0.10317437763192824, 0.07421653185571943, 0.2243587574256318, 0.13707893368388924, 0.10544733423739672, 0.10791380224483353, 0.16903862516794885, 0.12192712458116667, 0.16529273188539914, 0.19072547288877623, 0.19297470790999277, 0.17680318281054497, 0.36627114031996044, 0.11558065084474427, 0.1257714597242219, 0.16324052986289772, 0.11822301548506532, 0.14099998399615288, 0.11944057872252804, 0.12776245788804122, 0.15109243243932724, 0.13932176333452972, 0.1695990136691502, 0.13983853560473236, 0.10721220382090126, 0.17068894446960517, 0.12381737386541707, 0.14153764157422952, 0.08154265409601585, 0.12386762616889817, 0.14102731538670404, 0.11983758956193924, 0.1357663891145161, 0.1155749104384865, 0.2782113812863827, 0.06268237291702203, 0.07533433008939028, 0.1912090512258666, 0.11240821464785508, 0.1718984738524471, 0.19399157405963965, 0.09833907602088791, 0.10088692751846143, 0.16126436447458609, 0.1511253278170313, 0.13747392248894486, 0.12776305499885762, 0.09845302240656954, 0.1012954463117889, 0.15117741216506275, 0.23592871587191308, 0.08996417612901755, 0.16077792271971703, 0.11301969005061047, 0.1820595357567072, 0.14660965012652533, 0.21118390081184252, 0.11704800996397223, 0.14103676059416362, 0.2214895449578762, 0.11007131968757936, 0.26062245081577984, 0.1512436643242836, 0.07383390595870358, 0.15320184853460106, 0.1757896143410887, 0.14510765857994556, 0.11570514844996588, 0.1651199904403516, 0.18583115908716405, 0.10049731949610369, 0.04290376244378941, 0.11590739259762423, 0.0889388554330383, 0.09223163660083498, 0.088419803285173, 0.1986578865242856, 0.18551106697746686, 0.11455968634358474, 0.1614507987563099, 0.10643456197742905, 0.11156186434839453, 0.1671947469668729, 0.13596441277435847, 0.1871917032237564, 0.11626404417412621, 0.09038361933614526, 0.08529219111161572, 0.11764886629368577, 0.11834889730172497, 0.08073985217405216, 0.10692370430167232, 0.05641458549403718, 0.0666661470064095, 0.13971965626946517, 0.1057810920423695, 0.10259637436164276, 0.15721561387181282, 0.10512409372521297, 0.09660524262913636, 0.10133889290903296, 0.09379090328833886, 0.1449562231344836, 0.1364050805568695, 0.10219760611653328, 0.12435421720147133, 0.13724092713424138, 0.16647456346877984, 0.13504370860755444, 0.11647399647959641, 0.10523589594023568, 0.08460488942052637, 0.1987480502575636, 0.18279654692326272, 0.29120179851140293, 0.15918926868055547], [0.03599545153390084, 0.07208779786846467, 0.06542099453508854, 0.007335558117899511, 0.034159966811005554, 0.023086278699338436, 0.0983972196866359, 0.03888081652777536, 0.012335294209021543, 0.00915166303249342, 0.010305399873426982, 0.024030312596421157, 0.008368711652500289, 0.056986519268580844, 0.013106621435976453, 0.03119454486295581, 0.04287490774212139, 0.039114056155085564, 0.03593686003504055, 0.05632419105885284, 0.05345206767586725, 0.015449251713497298, 0.03703289086531315, 0.01897197143573846, 0.023059328984735266, 0.05031471513211727, 0.028232654689678123, 0.025386564999020526, 0.03237123993624534, 0.0312159865695451, 0.050685412383505275, 0.01803662278689444, 0.008209107493582581, 0.1047832587999957, 0.04781391664541193, 0.03755385648193104, 0.036142659706196616, 0.05297604821888464, 0.011937457253225148, 0.007144218027990843, 0.048914737932916195, 0.04898340228412833, 0.04890930626009192, 0.016224272715459977, 0.04339444164984992, 0.017010584540132965, 0.0395017574940409, 0.03040931360530002, 0.0036149830973174956, 0.045457914139011076, 0.05789895887885775, 0.014849844056048563, 0.026063695450180342, 0.024304400031854, 0.041009075540517054, 0.03664694353938103, 0.03102895856967994, 0.018625121297580854, 0.03371466802699225, 0.07589235050337655, 0.06398087181150913, 0.0209270106362445, 0.03085315353902323, 0.033145848728184185, 0.02265953954442271, 0.030928460748067925, 0.04200016075213041, 0.037130627049399276, 0.0106383875411536, 0.013813124819924789, 0.05594710540026426, 0.022932522664112703, 0.06001160480082035, 0.019065061351284385, 0.04909166254635368, 0.04035783798566886, 0.014142448398550706, 0.026906234079173634, 0.011043833419015365, 0.0639225992241076, 0.042045388503798416, 0.037712840629475455, 0.035947499464132955, 0.09100604629410164, 0.033429286376174004, 0.03953815750511629, 0.04745969083160162, 0.06479517490203891, 0.04382438857906631, 0.0678820681891271, 0.03413926810026169, 0.07829802855849266, 0.06558252658162798, 0.01905103094343628, 0.038967462056981664, 0.027875748662544147, 0.058053434161203246, 0.020173385539757352, 0.028086145408451557, 0.032597846883748255, 0.04716978674488408, 0.026192177752298967, 0.03321412631443568, 0.039187259905572445, 0.06360493626977716, 0.0210543021094054, 0.021848987056208507, 0.02229886086258505, 0.031875156198761294, 0.06853298683251653, 0.026176411991140673, 0.013580604439734347, 0.0733320207468101, 0.029005485719868114, 0.02300622344150075, 0.0213690999496196, 0.043453545442649295, 0.017811031945581948, 0.036175714539630074, 0.02704954576412482, 0.03472051816061139, 0.016680104059300253, 0.0285560750136418, 0.027164418350106904, 0.026063647952729037, 0.00580389508312302, 0.013158133270085921, 0.053237538651696274, 0.05251002697540181, 0.04565480125269719, 0.04586017344679151, 0.06134767417929002, 0.054266811814159155, 0.015785521794376627, 0.01946299839099603, 0.05844003627342837, 0.02413163992709347, 0.025872401161385433, 0.09046084340661764, 0.062199072779289315, 0.011507146459605013, 0.018805927131325006, 0.018546373915991614, 0.06769095201577459, 0.021645826886274984, 0.10507153440266848, 0.010063318934823786, 0.005390267769273902, 0.043623749166727066, 0.004990929554748748, 0.011268751662490624, 0.020560467715508172, 0.06467985787561961, 0.011249755226474787, 0.017965117070291723, 0.017035508827705468, 0.03205395017617515, 0.05737967602908611, 0.045732656360736916, 0.021287723244833093, 0.05199496800612126, 0.007029124069958925, 0.03201545688456722, 0.06502324409250702, 0.05325157754123211, 0.042247279813247066, 0.04322601229484592, 0.015035535341926982, 0.03801269543224147, 0.03300295943128211, 0.025286464120394418, 0.04886266376291003, 0.022771129717252085, 0.02476863163922514, 0.009657644899562001, 0.026874711038544774, 0.021367632617641772, 0.08293293163712535, 0.026724904077127576, 0.04648896845589791, 0.02653222218421953, 0.047252646048686335, 0.0334522310378296, 0.06321141988571201, 0.03748497499951294, 0.020719942104603564, 0.017748208084542836, 0.04003410553559661, 0.04741806949355772, 0.04451928986236453, 0.06465000912014927, 0.055618806409516504, 0.04881642160138913, 0.047249653709254096, 0.03597552974575332, 0.0716772231140307, 0.04458229862419622, 0.05307207449472376, 0.05152185607169356, 0.02719963262123721, 0.03268670104444027, 0.0241090854230736, 0.008561427472159266, 0.011787825862744024, 0.07339385564305953, 0.02315255460728492, 0.08179608014013086, 0.024884352393980538, 0.029070513123380284, 0.02101051285197692, 0.11625249550810882, 0.005644069128071091, 0.0229101598462356, 0.02496074525905507, 0.0644979765638709, 0.056416814481573443, 0.005978471541311592, 0.04125328029372862, 0.04630597434671862, 0.017399337608367205, 0.030462225766054223, 0.04050400460671101, 0.019446274199123894, 0.019775847139369165, 0.020467739119859676, 0.07834051842136042, 0.08725258056074381, 0.05165383791817086, 0.038940001744776964, 0.0339960836406265, 0.049377715946840386, 0.00224658937077038, 0.034912631780441315, 0.066146395967475, 0.02342975651845336, 0.006165665358171931, 0.01558384083078376, 0.04652143296386514, 0.0023113419675999986, 0.025507103352408324, 0.010486142942681909, 0.04757790859522564, 0.034719978725271564, 0.050283648406288455, 0.06558546463825873, 0.05438756051340273, 0.07241431570478848, 0.09138704370707273, 0.021787555888295174, 0.03068283785666738, 0.031201258966965333, 0.027707804460078478, 0.018874525325372815, 0.035744824446737766, 0.022703189702172364, 0.0447346263432077, 0.030411657943789448, 0.017017578539837683, 0.02324938664345869, 0.06238940863737038, 0.024513310786070566, 0.004918799585928875, 0.033792139762746434, 0.015303191961720586, 0.0610720193279641, 0.024120995408988426, 0.04015413498772042, 0.028385878074914217, 0.01665635872632265, 0.03924591586525951, 0.003903352846724114, 0.0457149907015264, 0.04910526717347758, 0.013529078186755734, 0.01940017961896956, 0.01613320822694472, 0.016124606099245802, 0.012382148748396762, 0.058332685248128006, 0.04044630877407534, 0.05225865010704313, 0.034596044304115434, 0.04400369145774415, 0.0665353729522654, 0.04236451709376914, 0.023001305758953094, 0.022743643959984183, 0.05301475524902344, 0.043210422952792475, 0.05536944479016321, 0.01252873266847538, 0.034222341142594814, 0.01677259516769222, 0.013098420492107314, 0.06176274083554745, 0.06286871898919344, 0.027943220488461, 0.02394264078299914, 0.011921720329805143, 0.02757495578511485, 0.030016034708491394, 0.034486287872173955, 0.020385141052039604, 0.025031974472637688, 0.02851668944848435, 0.020737171805064594, 0.06560362223535776, 0.037654415371694734, 0.04886259590940816, 0.039554656084094725, 0.02054374013096094, 0.04041536757722497, 0.05402878512229238, 0.06678105691181761, 0.015380083550033825, 0.05152586282097867, 0.019241960519658666, 0.033837431975241215, 0.0372117425182036, 0.02754361934161612, 0.010923038918658026, 0.04962200212425419, 0.04964240227958985, 0.03721782219197069, 0.07742408902517386, 0.07127561859254326, 0.02617278352512845, 0.03334416415808456, 0.019743806715788584, 0.014719843531825712, 0.029217015619256666, 0.04789694558296885, 0.0321185874220516, 0.0316097777602928, 0.03670227128480162, 0.02544860345577555, 0.017318866747830595, 0.03066162345930934, 0.019647212166871344, 0.019455556558179002, 0.057147087795393806, 0.025880942220932672, 0.02616230015909033, 0.033022959250956774, 0.09184698866946356, 0.007176019267977348, 0.03851557469793728, 0.03242232005244919, 0.046606446616351604, 0.027243978277380978, 0.05347862553649715, 0.04413582258192556, 0.1527470943651029, 0.22675626591912337, 0.19168127088674478, 0.09879879028137241, 0.13535265917224543, 0.10725913130279098, 0.136309149275933, 0.18618504224078997, 0.1512270402163267, 0.09447697004569428, 0.0637156121166689, 0.10008767433464527, 0.11939563256289278, 0.12732229222144398, 0.11076491818364177, 0.20134559087455273, 0.14411935875458376, 0.12734323181211948, 0.1545831694134644, 0.14015827487621987, 0.14054345206490584, 0.1017899422773293, 0.2595601635319846, 0.1523488350212574, 0.13969805171447142, 0.0894562994529094, 0.13365763798356056, 0.10205502555306468, 0.11671706129397665, 0.06617588509938546, 0.15075815894774028, 0.10963093688977615, 0.0792832885469709, 0.16457887233367988, 0.2886500454374722, 0.1038140868768096, 0.13116608453648432, 0.14367916594658578, 0.133672972874982, 0.16493340688092367, 0.13584748761994497, 0.17691071704030037, 0.12813991334821495, 0.12442724114017827, 0.18983626631753786, 0.12622618675231934, 0.1927620278937476, 0.08102550184620277, 0.06667420800243105, 0.17283367152724946, 0.24052196368575096, 0.1151130995047944, 0.06871296824621302, 0.17354033860777104, 0.15829866432717868, 0.1394179660294737, 0.12388414171125207, 0.14867094451827662, 0.10578056957040514, 0.19749669597617217, 0.13797888824982302, 0.10999068258596317, 0.06136355868407658, 0.10494430908667189, 0.09202794038823672, 0.09491051999585969, 0.10481179119752985, 0.09501681929188115, 0.13055097897137913, 0.09152225538023881, 0.24725750940186636, 0.23208248083080563, 0.12870625938688005, 0.10150518827140331, 0.08596877194941044, 0.20147710453186715, 0.1437257541609662, 0.18629579272653374, 0.10928658036781208, 0.19069515594414302, 0.16755139854337486, 0.09384344904018299, 0.1349041610956192, 0.3028536561344351, 0.08763359154441527, 0.11714798531361989, 0.21802767286343233, 0.12485983435596738, 0.14249103755823203, 0.07554582945470299, 0.08131778759083577, 0.1834614976708378, 0.161802578451378, 0.12023781665733882, 0.08912290805684668, 0.1479535023016589, 0.22063658572733402, 0.12756283288555487, 0.08470103104731866, 0.10856795750026192, 0.14571406532611164, 0.07832343290959086, 0.10633653402328491, 0.08235893850880009, 0.23959014511534146, 0.0861696522416813, 0.11495980487338134, 0.1989836511867387, 0.12746530026197433, 0.12719669538949216, 0.05227650575605886, 0.08996892587414809, 0.1336530510868345, 0.18009966877954348, 0.06997446662613324, 0.09971864627940313, 0.08767621711428676, 0.06417977756687573, 0.17940115768994602, 0.12968174847108976, 0.09652001863079411, 0.14317421375640801, 0.0959856655182583, 0.16354280364300522, 0.13627195198621067, 0.11712058606956686, 0.08082288450428418, 0.21437201116766247, 0.2360132070524352, 0.12899296757365974, 0.18355103715189866, 0.1240986944841487, 0.1456086074135133, 0.09092914113508803, 0.08209853033934321, 0.11673102554466043, 0.10065153014979192, 0.11654570406036717, 0.20715096007500375, 0.22139973406280788, 0.15648962211396011, 0.10072350235921995, 0.09557586429374558, 0.13256477591182503, 0.15923813677259854, 0.12856859820229666, 0.13887429663113185, 0.08568881518606629, 0.1541964451649359, 0.11645520105957985, 0.08600588102958032, 0.17847193112330778, 0.12619510984846524, 0.13053686544299126, 0.0667427128979138, 0.14571011625230312, 0.15497338133198874, 0.1253937871328422, 0.15559844779116766, 0.15556993574968406, 0.13979030533560685, 0.09908887757254498, 0.06625497514115912, 0.11769089475274086, 0.17613380801464829, 0.14679826929100923, 0.14343215205839702, 0.06245636647301061, 0.18979153728910855, 0.11346444261393376, 0.11537726675825459, 0.11376221092151743, 0.14686471144003527, 0.11321251613220998, 0.07646267954260111, 0.16481306191001618], [0.07125856700752463, 0.05645797780847975, 0.06794807607574121, 0.04008954863197037, 0.05248284825522985, 0.048188939557543824, 0.046609981783798764, 0.03925075721261757, 0.00578564842830279, 0.02680555305310658, 0.025283232597368102, 0.03902816379974995, 0.05249441049194761, 0.05246256005817226, 0.017659601589132632, 0.048162072963480435, 0.04982872799571071, 0.04589380842766591, 0.03336375346407294, 0.02802291781907635, 0.0021294704097921825, 0.011645122314803302, 0.019363331774781858, 0.05061117047443986, 0.04508246035714235, 0.02922278316691518, 0.047600683623126576, 0.030604429742587463, 0.08766450559986488, 0.03370909386181405, 0.06375563889741898, 0.019773748769823993, 0.020913731705929552, 0.02603857947646507, 0.01330208617062973, 0.04335517143564565, 0.05625189993796604, 0.02589875885418483, 0.04386052056880934, 0.04460206774196454, 0.03151154624564307, 0.06884187632905585, 0.03616318539051073, 0.030557736355279173, 0.02726539284256952, 0.012203342048451304, 0.030903534764157872, 0.01955221896059811, 0.04683784741376128, 0.07579425469573055, 0.038850187457033565, 0.08628789375403098, 0.06108356120863131, 0.004613061036382402, 0.015659885946661234, 0.009287305575396334, 0.01725321339576372, 0.09424102984900985, 0.019664180631350194, 0.035856060085019896, 0.03427840509851064, 0.07387678937188216, 0.030977759709847823, 0.028405285872785107, 0.02545680185513837, 0.03530647725399051, 0.035643580236605236, 0.006110873655416071, 0.0370078698865005, 0.04958123913300889, 0.025879810763789073, 0.03620378892602665, 0.04267821401091559, 0.04318514752334782, 0.03988734858908823, 0.04179266135075262, 0.1438854948750564, 0.06176895621631827, 0.05354919657111168, 0.04970132286793419, 0.015621679336098688, 0.02339265591997121, 0.027954843793330447, 0.006144557830079326, 0.02479449230512338, 0.05084071208589843, 0.0195075442149703, 0.038173850891845565, 0.04340481645028506, 0.03734650635825736, 0.00882950987267707, 0.05809774249792099, 0.0014117713040572458, 0.010910620879647987, 0.017717548479725207, 0.030643828878445283, 0.04675987695476838, 0.042360608732061725, 0.02242808446421155, 0.061293432089899264, 0.0790392127154129, 0.026600932336545417, 0.01972677039780787, 0.022109451204804436, 0.031314920367939134, 0.021466839526380812, 0.0509038836961346, 0.030042752024850676, 0.028424405293273072, 0.05475483794829675, 0.027392401027360132, 0.01362064988019743, 0.06631803140044212, 0.032497464413089414, 0.038553053579692326, 0.015811435046738813, 0.018669261696881483, 0.01576847699470818, 0.02100356126071087, 0.012804782766449665, 0.08404245852891888, 0.0945531695282885, 0.051527291137192927, 0.010443658168826784, 0.05453435817201223, 0.05996615652527128, 0.027399277979774133, 0.03436748996110899, 0.017060692654922605, 0.041719410102814436, 0.04199891903304628, 0.02860569967223065, 0.04316735972783395, 0.017304468234734874, 0.03773086251957076, 0.05679296376183629, 0.02203383356598871, 0.04171171212302787, 0.007723533415368625, 0.015087268548086286, 0.025278940863375152, 0.030410996372146264, 0.0323003737388977, 0.04357902692364795, 0.04258344641753605, 0.05081233914409365, 0.06304178613104991, 0.06069919147661754, 0.047360695965055905, 0.03924139342936022, 0.021183878549241593, 0.03437526936509779, 0.0462872094607779, 0.03154089627787471, 0.027131740103608797, 0.014669253657172834, 0.0170035888440907, 0.050543140553470166, 0.026899369001122456, 0.05778217621679817, 0.04076277750677296, 0.015550582436844707, 0.040831082234425206, 0.09593871768031802, 0.03764227977288621, 0.07034557099853243, 0.008989067382312246, 0.04468399406011615, 0.025439690898305604, 0.023654387232714465, 0.03301417561514037, 0.015022203825148088, 0.021104802078168308, 0.04231120120467884, 0.022943484397338967, 0.019744800769590905, 0.09267708805522748, 0.08901997429451772, 0.001437372006226464, 0.0067566422180139595, 0.127591874184353, 0.01064885309564748, 0.06942366582474538, 0.04932962817006877, 0.013158617574455482, 0.012946135181534504, 0.038994477928749154, 0.06742766007248845, 0.03793073179466384, 0.0650722071794527, 0.040270578382270675, 0.0577546480510916, 0.04063570825383067, 0.037845012465757985, 0.015686406487865106, 0.047815202469272275, 0.03642111690714955, 0.05260618895824466, 0.028071417805871794, 0.03692101740411349, 0.06887572165578604, 0.04600236724529948, 0.022897656142179455, 0.014439898642844387, 0.02287463514533426, 0.05235283076763153, 0.06726867253226892, 0.019032666393156563, 0.01876578330328422, 0.03351208461182458, 0.024284105049446225, 0.025090762746653388, 0.043132357498896975, 0.005024790996685624, 0.05566877033561468, 0.017535241387252296, 0.07956766257328646, 0.020868953483711396, 0.013556904059701731, 0.024398841928424578, 0.035051666998437474, 0.014688335758234774, 0.06420311238616705, 0.004056145362223366, 0.07215143088251352, 0.02464953686908952, 0.06570680705564362, 0.03206744284502097, 0.018188933542530452, 0.0631919459306768, 0.0717072415032557, 0.017394898293007697, 0.009351277856954505, 0.12291223529194083, 0.03537659367014255, 0.053212884081793685, 0.031047737026321034, 0.03803735678749425, 0.0402377813921443, 0.00540413532871753, 0.05076044139319232, 0.020594372414052486, 0.016035290534741113, 0.05876369747732367, 0.040878376125225, 0.03902657263513122, 0.03400179351280842, 0.05534353153780103, 0.029768698516168764, 0.010617290191086275, 0.013269792144585933, 0.0437603823707572, 0.04804254223459533, 0.06183052648391042, 0.03284076920577458, 0.015762083498494964, 0.07955739633845431, 0.023804886299850683, 0.022227555313812833, 0.020689258751060282, 0.04458535203178014, 0.03799939614587596, 0.013872371105078076, 0.002835593602087881, 0.006963731105705457, 0.0756548632468496, 0.029621466595147337, 0.058918077764766555, 0.02904862697635378, 0.02223364177293011, 0.02207463726933513, 0.057071526135717116, 0.04251679731532931, 0.004171550174110702, 0.039205390361270735, 0.019765750538291674, 0.04918411972799471, 0.037003374592001946, 0.027309115942833678, 0.01783889768246029, 0.04888676871944751, 0.03417247560407434, 0.01496573444455862, 0.0750513674159135, 0.026852865603619387, 0.06289240664669446, 0.03298612158479435, 0.05098302802070975, 0.02629867212713829, 0.06163084041327238, 0.0737443800483431, 0.010404850206603962, 0.014036183877448951, 0.013794292080482202, 0.06477380104895149, 0.020460219255515506, 0.06161197713975396, 0.007842087053826876, 0.02196167645576809, 0.027914206331063594, 0.045655635850770135, 0.044568551504718404, 0.04602543404325843, 0.05038909274818642, 0.024903039248394113, 0.02082259936391243, 0.06048540544829198, 0.039206459053925106, 0.04959591584546225, 0.00848036289348134, 0.02330313340228583, 0.0257345856100853, 0.023899886291474104, 0.015189325303903647, 0.029157772726778473, 0.022701456045199717, 0.017334751252617155, 0.01784656003915838, 0.01040748377064509, 0.009451483060339732, 0.10633720577295337, 0.01764410045663161, 0.04986885316403849, 0.010804249489280795, 0.021064843150920103, 0.013788210710377564, 0.025402293440752795, 0.038856959236519675, 0.01846253582542496, 0.03008725374404873, 0.026076258526050618, 0.014100635374364043, 0.018968320917338133, 0.027070970507338643, 0.07362246766154255, 0.021262787082897763, 0.0189593761294548, 0.02424020892275231, 0.026168298408655182, 0.03812834494081991, 0.02927741880661675, 0.05745961423963308, 0.04566319812355297, 0.018372914920161878, 0.05006947561300226, 0.02640265252973352, 0.0883124183331217, 0.021752541784995368, 0.03380524227395654, 0.05666220327839255, 0.0313865261684571, 0.036004876385309866, 0.15392861382237502, 0.11236437450030021, 0.09392654922391687, 0.10977906108434711, 0.22254234632211073, 0.15567190599228653, 0.10998972585158688, 0.14722634346357413, 0.11600857573960509, 0.09050939937255212, 0.22096081690064498, 0.1270972764385598, 0.12505017699939863, 0.12062352310333933, 0.18852891932640756, 0.1350406687706709, 0.10495673984821353, 0.13812169272984776, 0.05324508396110364, 0.17900673885430607, 0.14301872067153454, 0.15139233134686947, 0.11786464042961597, 0.0930727825367025, 0.1587632436837469, 0.08119273358689887, 0.1179569483335529, 0.06991130858659744, 0.1030306164175272, 0.140018958066191, 0.18028443386512144, 0.14588931735072816, 0.05834217795303889, 0.11171764920332602, 0.07618146070412227, 0.08713226273123707, 0.124015709651368, 0.0918318573385477, 0.16574659038867268, 0.10618029454989092, 0.14694348935570034, 0.08858705538191966, 0.08535247216267244, 0.20733170823327132, 0.07849321594195706, 0.14209351103220666, 0.16901459145758832, 0.09903242345899343, 0.20397765535329068, 0.1276562807283231, 0.14697224566979067, 0.18428294573511395, 0.24976195501429693, 0.18261104901986464, 0.17886233303163732, 0.11698608685817037, 0.08085507420556885, 0.25932680176837103, 0.07992274673389536, 0.2428899151938302, 0.112864196965737, 0.17640957821692738, 0.081208930217794, 0.07272973270820719, 0.18786998039909772, 0.14108860066958837, 0.1689016968011856, 0.1815354624497039, 0.12638789521796362, 0.17105922102928162, 0.1217913632946355, 0.1080347578972578, 0.09664581223790135, 0.13901915028691292, 0.09420617350510188, 0.08851312220628772, 0.30913976739559856, 0.1527601900909628, 0.1059955566057137, 0.11930390819907188, 0.21304656086223467, 0.16098753575767788, 0.08608141554785625, 0.13286958741290228, 0.12159555165895394, 0.19738351633506163, 0.11095222099018948, 0.0908032525330782, 0.09801202214189939, 0.13129796460270882, 0.14782966966075556, 0.10707465798727103, 0.06339178806436913, 0.10889484853084598, 0.10957446920552424, 0.09441294348133461, 0.11924308432000023, 0.20906358744416917, 0.08907996357551642, 0.11783740403396742, 0.17218909040093422, 0.08523505167769534, 0.0911546658192362, 0.10283069964498281, 0.10865565815142222, 0.2024589582745518, 0.14070264995098114, 0.0979487080393093, 0.11292185208627156, 0.1359593780445201, 0.11989453222070422, 0.29829544786896023, 0.17870939123843396, 0.10793759168258735, 0.19599835494799273, 0.08671693144632237, 0.08103162223207099, 0.11925696714648179, 0.11711270149265017, 0.10295906489981071, 0.19169679576797144, 0.10953217611781188, 0.12133614772132464, 0.09557805596185581, 0.17495627834328584, 0.2177212600197111, 0.15109098037438734, 0.14858642619635376, 0.1746410174029214, 0.07300562504678965, 0.13380603359213897, 0.06621911456542355, 0.10153783937650067, 0.08410785573401622, 0.10845016382102456, 0.1830847750284842, 0.10894293630761759, 0.10495633951255254, 0.1251779587141105, 0.12269068003765174, 0.05684914306870528, 0.09160511807671615, 0.08816400915384293, 0.1291920497481312, 0.25349897305880276, 0.10423250549605914, 0.127033209162099, 0.10434233317417757, 0.10343687568924256, 0.12349221988448075, 0.06300340819039515, 0.21013564563223294, 0.0873262355370181, 0.1331170762756041, 0.09681910329631396, 0.09857307560741901, 0.20733539946377277, 0.09682499298027583, 0.18061604749943527, 0.12350209935435227, 0.097994543079819, 0.14854015010808194, 0.1004041430673429, 0.13872691882508142, 0.0862148833860244, 0.10862152105463402, 0.1391751861998013, 0.06038737749414785, 0.08400539016085011, 0.10652271724705185, 0.16516747432095663, 0.08368248213082552, 0.09846834372729063, 0.06923888038311686, 0.11728624360901968, 0.0749515684853707], [0.04426986038950937, 0.03048235790005752, 0.013905175728723407, 0.02909250444333468, 0.1188953486936433, 0.08122734565820013, 0.07519480971885578, 0.08723499293306045, 0.02610104880295694, 0.05168108109916959, 0.04076192933799965, 0.03681964087965233, 0.0039556712893370006, 0.0038582056710895684, 0.013978347248796905, 0.015677027437569838, 0.060970904039485116, 0.011364857666194439, 0.013062363141216338, 0.07328554788338286, 0.025177308191944445, 0.08632146766675369, 0.023448696127161384, 0.027919766925541416, 0.015305220781426345, 0.08148885983973742, 0.040120018246982775, 0.12022012046405248, 0.045053775289228985, 0.03381204798019358, 0.011777358611912599, 0.04130122557814632, 0.050710477467094145, 0.07829783856868744, 0.03332721096064363, 0.05861639431012528, 0.04211067035794258, 0.006381515829291726, 0.014905222691595554, 0.01752732627625976, 0.019062097849590436, 0.056629111125533066, 0.08784040901809931, 0.06813578600330011, 0.01339979690965265, 0.029077386683119193, 0.03072112419509462, 0.03933719918131828, 0.0952345272526145, 0.07600146571972541, 0.004407729130304817, 0.026194403347160135, 0.022296268858813813, 0.05650540740628328, 0.09765323996543884, 0.03080069599673152, 0.06831199476229292, 0.02147895816181387, 0.03503518199015941, 0.029550912523908273, 0.013233304772126888, 0.02253087912686169, 0.02436032997710364, 0.021461882828069583, 0.029052996741873876, 0.058786116274339814, 0.11241239442356996, 0.027855960885062814, 0.04175257689452597, 0.08424924886120216, 0.017849462472700646, 0.04072256752156785, 0.02937655955819147, 0.026175957372678176, 0.0171037948956447, 0.06871943468494074, 0.04732311869572316, 0.017478351314951266, 0.07658685823636395, 0.012883908431311803, 0.003304451546033046, 0.054559806627886634, 0.06281014784638371, 0.02950276028630989, 0.018487399044845785, 0.015696326669837748, 0.047364963950323205, 0.043403462772922854, 0.027418280352971384, 0.043939807385738404, 0.009762477711774409, 0.028664243673639636, 0.02564802489775632, 0.058141528362674375, 0.05199089340333428, 0.01076958907235946, 0.028756174990641217, 0.0318005987709122, 0.018846827525911585, 0.011045915673353841, 0.03546645545533725, 0.054708232770540884, 0.03221830153571708, 0.047002880700996945, 0.09775137648518596, 0.03385934526366847, 0.026044798249910985, 0.03993373324296304, 0.012259756298070508, 0.03276976051607302, 0.05307640354814274, 0.0586469080299139, 0.1035826996501003, 0.025276472692244818, 0.09395838608699185, 0.05778593530080148, 0.007395768770948052, 0.05849050570811544, 0.04627223080024123, 0.0514390001605664, 0.005368924450262317, 0.020538506929629614, 0.09210072683968715, 0.027183519110881856, 0.028951111316148723, 0.02843565710021981, 0.06932422651776246, 0.02618393694449748, 0.04415318290037768, 0.05481476955381887, 0.036445740942976305, 0.044588269732360325, 0.04833556418972356, 0.046996258199214935, 0.030049187929502556, 0.0440100459381938, 0.03211149673110672, 0.0138025642705283, 0.03320343599521688, 0.01871487621351012, 0.08704665875328438, 0.057115997320839336, 0.07366378365882806, 0.07601399147616965, 0.0096405636286363, 0.017692013510635922, 0.02834798867947289, 0.01656218315474689, 0.029000715618687015, 0.027929397033793584, 0.025152955570125153, 0.01219122256484947, 0.010489452497235366, 0.007262697027597044, 0.01713835946949465, 0.05487141026450055, 0.03590677718498877, 0.038660530133971145, 0.02774508317400302, 0.033045113419315646, 0.07247798264558826, 0.06947471879954849, 0.017084363349048153, 0.04338754773406046, 0.05052603807832513, 0.15423524379730225, 0.02193073695525527, 0.0342534248317991, 0.020484146096610596, 0.029273605439811945, 0.0848002600084458, 0.03728102772895779, 0.03604965969654066, 0.05831834101783378, 0.03601144799696548, 0.030782141456646577, 0.019796215064291443, 0.003154223468819899, 0.03344132358740483, 0.009739149677833276, 0.035839653108268976, 0.03395937489611762, 0.03202856957380261, 0.022504911591698016, 0.05123987388131874, 0.024754373922145793, 0.04015852850196617, 0.040267833708120246, 0.027422034347962056, 0.0046949301031418145, 0.022329829200836163, 0.030176016302513223, 0.015729625775877918, 0.03164264938927122, 0.01927342588481094, 0.004201333196501115, 0.03795412428943174, 0.03409641522115894, 0.039548091257789304, 0.024797996938494698, 0.013353369847339178, 0.03418688090252025, 0.03955008615074413, 0.07365998386272363, 0.02855960000306368, 0.03696877269872597, 0.029380780046007464, 0.023604436877316663, 0.010211248050576873, 0.059817618424338956, 0.0339101844999407, 0.030083216460687772, 0.08372393383511476, 0.026039395414824997, 0.025362538074010184, 0.013592994489174868, 0.024153833111215915, 0.02715921398651387, 0.01470199297182262, 0.053145810895200284, 0.052220553758421114, 0.04481797758489847, 0.05671088138063039, 0.03898485969485981, 0.025721028480412703, 0.09579779952764511, 0.022148872393050363, 0.023898559755512645, 0.08289458762322154, 0.0067436987384488535, 0.06998140803937401, 0.011000424141197332, 0.06169204427195447, 0.04571359291938799, 0.0024004191966793898, 0.06126871305916991, 0.03935619476916535, 0.04307238518127373, 0.004573057580273598, 0.0636657126513975, 0.04739945049264601, 0.056257799799953184, 0.13337524527949945, 0.016952634256865298, 0.010800404740231377, 0.03852582736206906, 0.02786623390524515, 0.04271313820832542, 0.02960533442507897, 0.04256054586065667, 0.050953867978283336, 0.07702536149216549, 0.035697808755295615, 0.041316560469567776, 0.03205967701173254, 0.017428892897441983, 0.015841760473059754, 0.02073842709484909, 0.044538380445114205, 0.05843833315053156, 0.02192022305514131, 0.02560600492038897, 0.012769518453361732, 0.04258645572034376, 0.07557096917714391, 0.03445997089147568, 0.04636490511308823, 0.03238326357677579, 0.05310896644368768, 0.035583804694137404, 0.02833443324613784, 0.008343072358651884, 0.07436828621264015, 0.022135808897603835, 0.011960367139961039, 0.022788603690319827, 0.02735574317297765, 0.038157277674015076, 0.03218582345704947, 0.030524637417069504, 0.04026657502566065, 0.04453623288178018, 0.05834586239819016, 0.07388394113097872, 0.04095271981454321, 0.04683626303449273, 0.09131628607532807, 0.04673148026423795, 0.07138511378850255, 0.07523665497345583, 0.03203229812373008, 0.01822682802698442, 0.01715022704697081, 0.020546969957649708, 0.008353833075878876, 0.06897237218384232, 0.056669521278568676, 0.026216357347688506, 0.12121384856956345, 0.029002975140299116, 0.018940618028864264, 0.01707847705776138, 0.06924170308879443, 0.019449346266420822, 0.05873863917908498, 0.021377274600256766, 0.032678965745227675, 0.028340024374691502, 0.05007171477856381, 0.05585950313668166, 0.020981563155406287, 0.09247141052037477, 0.02765798641900931, 0.027202597819268703, 0.0069633579114452004, 0.026914420604173626, 0.04939619245539818, 0.044981395958789756, 0.07333265178437744, 0.015372185402416756, 0.02331521811096796, 0.09897436121744768, 0.06103048619947263, 0.003357265531251739, 0.0300482617292021, 0.05602968989738396, 0.048675374527062686, 0.054799024148711135, 0.04320671136624046, 0.04149225014927132, 0.04146123092089381, 0.03832735247643931, 0.014903629830639278, 0.021702772937715054, 0.028111710911616683, 0.0641283785392131, 0.07771005082343306, 0.08819837016718728, 0.0027292143661595348, 0.0653383286137666, 0.027871903065325956, 0.025949657462271195, 0.0169927204094295, 0.011235360954222935, 0.05062022552426372, 0.035190888813563755, 0.0700101779241647, 0.06827616811330829, 0.03592023253440857, 0.017096471806455935, 0.009087795923863138, 0.03144487000203558, 0.10020966136029788, 0.10742055478372745, 0.15521636472216674, 0.08980776023651872, 0.19995922169515065, 0.0876595319381782, 0.15065127611160278, 0.19304733829838888, 0.09230631616498743, 0.16264525109103747, 0.13443897105753422, 0.15141228027641773, 0.12302720626550061, 0.10731413335140262, 0.11255982651242188, 0.14016356744936534, 0.10118273485984121, 0.08898541650601796, 0.0833518523722887, 0.07466475173298802, 0.07367374455290181, 0.16601759727512086, 0.08813441824167967, 0.1707228033670357, 0.20533498323389462, 0.19528001706515039, 0.12024002868149962, 0.2954628627215113, 0.10032334990267243, 0.10386530270001718, 0.09267163941902773, 0.11458087020686694, 0.1218859917883362, 0.16919163481465407, 0.11635996188436236, 0.06325137881296021, 0.17669765704444476, 0.07609477785548993, 0.08951928107334034, 0.12420857644506864, 0.14140021109155246, 0.13276300313217299, 0.2207211854734591, 0.15221114669527325, 0.13224566089255468, 0.16244238269116196, 0.16113119519182614, 0.09931947091328246, 0.1689914127013513, 0.17432335444859096, 0.08390656153538398, 0.06368262174406222, 0.1508479562721082, 0.12404122256806918, 0.17128600100321428, 0.12868864461779594, 0.13405409242425645, 0.0846718947536179, 0.12023816949554852, 0.16408837293939932, 0.09231962223670312, 0.1326375962900264, 0.1067259181290865, 0.19204580704016344, 0.1227453156773533, 0.08432205566870314, 0.25539705263716833, 0.11443479518805232, 0.14688660097973688, 0.210697988314288, 0.07676843420735427, 0.13538935434605393, 0.09667028021067381, 0.10899370429771287, 0.08434167211609227, 0.15542384716016905, 0.1261260892663683, 0.16284664028457232, 0.09865804176245417, 0.10308235471269914, 0.08837143052369356, 0.15203015426439898, 0.1257185475634677, 0.09583607568804707, 0.08378050329961947, 0.0727071917748877, 0.10850195639899798, 0.11539769066231591, 0.16926469946546213, 0.12922067035521778, 0.11052591100867305, 0.1814290817294802, 0.1336294109267848, 0.15876986618552888, 0.11207031777926854, 0.06463899649679661, 0.1483565249613353, 0.1297714372298547, 0.1182003388447421, 0.12472415449363844, 0.13848332475338662, 0.09347138793340751, 0.14939073446605886, 0.10735673856522356, 0.18063629498439177, 0.12497469676392418, 0.1432280351540872, 0.10074734607977526, 0.1078731579972165, 0.1261532170964139, 0.12410970032215118, 0.15282864070364408, 0.3013391116900103, 0.1881465512726988, 0.14795931056141853, 0.2066352598901306, 0.10417706239968538, 0.16003465546028955, 0.13432864126350197, 0.18177912437490054, 0.12975883004920824, 0.08877804941896882, 0.27303082070180346, 0.13133316699947628, 0.0958892728335091, 0.08351866342127323, 0.18108533588903292, 0.14964161600385392, 0.2711499487715108, 0.1745012527597802, 0.10922146814742259, 0.2213237788528204, 0.08467616952423539, 0.13342560614858354, 0.10470266241048064, 0.17014290019869804, 0.08420959527471236, 0.12353538828236715, 0.07294995124850955, 0.07887094281613827, 0.1523116241608347, 0.15901230674769196, 0.19847778975963593, 0.1252885056393487, 0.16078181751072407, 0.1535150602992092, 0.15342472014682634, 0.14369504366602215, 0.12164097279310226, 0.2098164220473596, 0.07401343953928777, 0.11980782901602131, 0.10604700313082763, 0.10164438973047904, 0.12596667424908706, 0.11773105045514447, 0.08210304259721722, 0.10134916592921529, 0.161748254937785, 0.22276395585920128, 0.23777601388948305, 0.2017533089965582, 0.0976186686062387, 0.12168050424328872, 0.22780068059052738, 0.27124795636960436, 0.1348765447203602, 0.1313865269933428, 0.09998332243412733, 0.07968629085059677, 0.15130165192697728, 0.12154585575418812, 0.10290928757084267, 0.1470694254551615, 0.11630729399621487, 0.12770741512732847], [0.02384288256455745, 0.03391236259735056, 0.030640029082340852, 0.05322887375950813, 0.02898278533081923, 0.011639570202013212, 0.009547970739991536, 0.033315319634441815, 0.0305314159819058, 0.05124790095058935, 0.043628071434795856, 0.010526441137439438, 0.056697154617203135, 0.0184950223857803, 0.0126727805639218, 0.08248923758843116, 0.013261251085038697, 0.10246971222971167, 0.097051026565688, 0.03550225496292114, 0.03195857868662902, 0.02860034942360861, 0.007745850432131971, 0.03360870799848011, 0.028780344408005476, 0.008999491376536233, 0.003972315753344446, 0.038922515897346396, 0.023680722873125757, 0.025321557951558913, 0.025843985811141983, 0.028684881316231828, 0.020034813421911428, 0.03893888894734638, 0.035754473214702945, 0.046575390068548064, 0.029754300003073046, 0.012758414227781551, 0.04591392699096884, 0.009234096555571471, 0.013815715127358479, 0.025191611710137556, 0.03922460986567395, 0.05387957527169159, 0.04670363657974771, 0.04840132101838078, 0.05528496378766639, 0.04679358657449484, 0.08810624546770539, 0.001156521591058533, 0.043763208469109874, 0.016280636923121553, 0.018145052682874457, 0.01717057970485517, 0.025926558433898857, 0.02309168831977461, 0.055080572076674016, 0.040033932509166856, 0.06613787356764078, 0.07715235610625573, 0.008146744188187378, 0.04123921087011695, 0.06555700687957661, 0.014461342045771224, 0.048770539063428126, 0.022201141641874398, 0.046173212184969864, 0.05443254738513913, 0.07383940209235464, 0.03831556632316538, 0.08725249235119138, 0.02984422624909452, 0.02922305797359773, 0.041576839717371125, 0.03623706428334117, 0.006894554884638637, 0.008174067097050803, 0.03020053177273699, 0.014561249541917017, 0.06365034383322511, 0.06418317024196897, 0.01835379719601146, 0.06530331620680434, 0.01873571572027036, 0.04469115938991308, 0.02118295574161623, 0.016303072683513165, 0.04709739723641958, 0.01717086977857564, 0.046582168633384366, 0.029832395991044383, 0.04733581408592207, 0.019207450228610208, 0.05514794381867562, 0.03042570361867547, 0.05099081760272384, 0.013976119957598192, 0.04917235732344644, 0.042159189004451036, 0.026818784485970224, 0.0655680602150304, 0.059244358113833835, 0.015469433041289449, 0.055688922825668535, 0.04166447251502957, 0.03807948363412704, 0.0689006917444723, 0.07733015263719217, 0.03474146792931216, 0.015009796812332101, 0.02525817938814206, 0.02887151576578617, 0.003226515225833282, 0.035541040024587085, 0.03297011833637953, 0.016602050479767577, 0.004579240730631032, 0.024178119575870887, 0.01659684781251209, 0.04219781800306269, 0.016994549061304758, 0.0664773378521204, 0.040987755970231125, 0.019257558343399848, 0.05019435319783432, 0.018454902306465164, 0.024542806703331213, 0.04231497725205762, 0.041552334425172636, 0.030338793460811888, 0.040440595509218316, 0.004942789191513189, 0.010299795174172946, 0.03740376114313092, 0.04767532926052809, 0.018854890218270675, 0.06484753066407782, 0.042657776536153894, 0.08130265625991992, 0.07455400124724422, 0.056242634542286396, 0.02683089124704046, 0.03538684294159923, 0.02644724415482155, 0.058236468982483656, 0.020403414000091807, 0.05089335283264518, 0.02924360062128731, 0.01522082120313176, 0.038806656042912176, 0.028604091544236456, 0.015776495582291057, 0.020386606687679887, 0.04153211068894182, 0.015815063512751033, 0.01853109839638429, 0.04200884260769401, 0.08678462209978274, 0.036741521142955334, 0.03830008554671492, 0.05521855895806636, 0.037467360230428834, 0.01557537101741348, 0.018577252348352755, 0.012729381410671132, 0.02579618980442839, 0.035007891311709366, 0.010082302648308021, 0.014169354008377662, 0.031001155597290823, 0.03754429931619337, 0.04717773238995245, 0.007770070739622627, 0.03829733747988939, 0.020926846091502478, 0.011800639148402427, 0.019078962837478945, 0.047187370979892354, 0.06522846700889723, 0.026382279515798603, 0.06373636850288936, 0.024197812358449613, 0.03145298867353371, 0.08990835305303335, 0.04028078015627606, 0.04989305990082877, 0.06431420892477036, 0.08647366985678673, 0.021917308747236217, 0.06644387250500065, 0.03286946445171322, 0.01891123746255679, 0.06430135747151715, 0.010392545822209545, 0.0008107292783928902, 0.01859329121985606, 0.011601985299161502, 0.012216139218903013, 0.02056070859543979, 0.06393270939588547, 0.020328736132276908, 0.03548196337318846, 0.03553205282826509, 0.07068844831415586, 0.019272550574636886, 0.034914806485176086, 0.014858227356203964, 0.08234215155243874, 0.08546441008469888, 0.011414804628917148, 0.056357252677636485, 0.02481960827883865, 0.0396218446216413, 0.034092645959130356, 0.037008551814194234, 0.034677064778017144, 0.039022053591907024, 0.07260699929403407, 0.02214268924269293, 0.07033663469233684, 0.048705755932522674, 0.023960555803829005, 0.025025472410821488, 0.03676102223939129, 0.02686094695569149, 0.0444112670873957, 0.06002858853233712, 0.028641563640641313, 0.01024460737659995, 0.04145225729527218, 0.03940820787101984, 0.05306873270975692, 0.0051412890981217575, 0.030831029904740195, 0.028565771279058287, 0.03822065284475684, 0.018466892020244683, 0.012144047417677939, 0.044695111856396706, 0.06251543294638395, 0.009059175316776549, 0.024518476133900027, 0.025995684188923666, 0.03931761666068009, 0.05696694353329284, 0.026135435261364495, 0.03569477231108716, 0.007755215063558093, 0.03908972388931683, 0.03108341439760157, 0.03522215570722308, 0.027600455131115656, 0.07541533359991652, 0.07255240436643362, 0.04094643318759544, 0.042246119518365176, 0.008029983578515905, 0.005318742968873786, 0.015988641252209033, 0.01205361311856125, 0.09488341930721488, 0.05657317948394588, 0.04560943779402545, 0.02070878698889698, 0.04235249345323869, 0.02018129895441234, 0.024104785207392912, 0.0632062019514186, 0.023077333911455104, 0.008903840839463686, 0.03590262794334974, 0.0520276292892439, 0.08112899200724703, 0.005829352020685161, 0.09500149118580989, 0.05573671204703195, 0.016772720696670667, 0.018386370269581676, 0.010476239724084735, 0.027219500126583234, 0.025312886274020587, 0.05544248569224562, 0.020550691722226993, 0.019376878726429174, 0.0692579336464405, 0.034559695183166435, 0.010246508122820939, 0.025479456443073492, 0.010180589293928018, 0.06165346955614431, 0.010060464846901596, 0.007126836505319391, 0.040926711567278416, 0.02553250770350652, 0.011106278996781578, 0.008271952558841025, 0.04734274871381266, 0.013414582187708999, 0.05013759035084929, 0.015257567267066665, 0.04708286301632013, 0.029459554568997452, 0.05016311005290065, 0.013107817353946822, 0.049361587169447114, 0.031114297918975353, 0.021806697361171246, 0.045097683290285726, 0.012440769084995347, 0.006476658737353448, 0.008674750453792512, 0.07931353763810225, 0.07402205693402461, 0.03978602295475347, 0.01523163026597883, 0.05682506525356855, 0.05056467725496207, 0.016423529612698724, 0.034992254472204616, 0.02870139685858573, 0.03432021303368466, 0.049161361663469245, 0.04917247606707471, 0.042119993429098807, 0.03792570724285074, 0.009560421857583736, 0.03890679424096431, 0.03339577353160296, 0.026081841172916547, 0.013098154167112495, 0.037627304505024634, 0.023745797774089233, 0.030789401781346117, 0.025986573159960762, 0.009614356909878552, 0.016804683088724102, 0.008372895669059029, 0.018434227344446948, 0.024110456063811268, 0.045201319336358986, 0.04196817121867623, 0.02664315757075591, 0.027795888483524323, 0.0459674125138138, 0.04327038509239044, 0.016867523913138678, 0.012704045761243572, 0.03797945739435298, 0.014510942955634423, 0.10712650484804596, 0.05794077020670686, 0.04708226929817881, 0.07534055904086147, 0.0815376600782786, 0.18145044201186725, 0.1759523813213621, 0.1374756052557911, 0.06806969669248376, 0.10080052965453692, 0.17988318896719388, 0.0893767751487238, 0.09285811441285269, 0.15538082803998673, 0.24839858817202704, 0.12053854337760381, 0.14010418206453323, 0.12333934594477926, 0.08955671585031919, 0.24225377504314693, 0.14463101487074578, 0.18899215518363885, 0.14325155317783356, 0.137948177754879, 0.11823867607329573, 0.15664127469062805, 0.12334813975862094, 0.1629351076803037, 0.13298577974949563, 0.09302641823887825, 0.21043886936136655, 0.10173468917076077, 0.07208446626152311, 0.08700230291911534, 0.14175418924008096, 0.11286648362874985, 0.10238317187343325, 0.1996027058256524, 0.15360344627073833, 0.1314209151480879, 0.12853985545890673, 0.20731583051383495, 0.11767587198742799, 0.11476278544536658, 0.15730321274272033, 0.08765185770711728, 0.12869125019226754, 0.12466783608709063, 0.13977267699582235, 0.133723876572081, 0.08262514815266643, 0.24199332616158895, 0.12826892999666079, 0.1609603672155312, 0.12855554318853787, 0.09503649002207176, 0.1125471175515226, 0.18229797296226025, 0.111900595815054, 0.1441766678222588, 0.08479225329522576, 0.1545180164809738, 0.10216141984398876, 0.20734894302274498, 0.1164263633212873, 0.15078487965677465, 0.0945103471832616, 0.10725524329713412, 0.17250602053744452, 0.10233406629413366, 0.29197326568620546, 0.21677534149161407, 0.16055841664118425, 0.1683895792812109, 0.11473622758473669, 0.1324062565607684, 0.09007867891341448, 0.1371071200285639, 0.14525186084210873, 0.15443530306220055, 0.1503916686134679, 0.11344813063208546, 0.13881180355591433, 0.16224252698676928, 0.09320065924631697, 0.14037342475993292, 0.09447922956730638, 0.14084782930357115, 0.07887548900076322, 0.08413705988121883, 0.13054651421095642, 0.090457545726427, 0.13229614389794214, 0.12305463265095438, 0.20871904093239987, 0.07293839579714195, 0.18495223910680839, 0.13274021792624677, 0.10685811710676976, 0.10754687764814921, 0.1355028868253742, 0.1544575182987111, 0.13170361997825758, 0.10640114412776061, 0.20511688850820065, 0.06929348209606749, 0.11983877021287169, 0.07913783099502325, 0.14860592729278974, 0.12364980285721165, 0.127999320892351, 0.11086168406265122, 0.09606499983263866, 0.18673171076391423, 0.1483702856515135, 0.21427016306136334, 0.19628803511815412, 0.1777734471751111, 0.06870112102478743, 0.12337315055940833, 0.08980945657406535, 0.10586432114775692, 0.14984101030443395, 0.12634479467357906, 0.09937495472175734, 0.3300977870821953, 0.13528688198753766, 0.12698515531207832, 0.12133503492389407, 0.20320815593004227, 0.10454713539885623, 0.1266607070075614, 0.06385280511208943, 0.19839472350265297, 0.13155650001551422, 0.07906374854168721, 0.08819079093102898, 0.1816544503505741, 0.17634462884494237, 0.2546732729034764, 0.1503775686557804, 0.11377508951617138, 0.13708338487361157, 0.15006175131670066, 0.09258068858512811, 0.10689787925886256, 0.07986163108476571, 0.12623431560184273, 0.17690636084548064, 0.13051908782550267, 0.09487900204424347, 0.0957585937742676, 0.054908034192132096, 0.0859459460313831, 0.09936954679765872, 0.11380025638001305, 0.12133892971490111, 0.10096698107996158, 0.11729237756558827, 0.11444390112800257, 0.11682721466890403, 0.13858266228011676, 0.06183092003422124, 0.18243391066789627, 0.2493396619600909, 0.09865819782550846, 0.18295753614178725, 0.06272083228187901, 0.0951339208653995, 0.19045751940991196, 0.13077959098986217, 0.09553061279335193, 0.15286860641624245, 0.1504138431378773, 0.1513479415859495, 0.1112947454676032, 0.2137293027979987, 0.2244174507047449, 0.19002840029341833], [0.04391059645318559, 0.03093235893175006, 0.014163034302847726, 0.026960728922858834, 0.06907389459333249, 0.015429092438093253, 0.03770101037142532, 0.02750963661154466, 0.0301041865854391, 0.04918093739875725, 0.028660216568303958, 0.09023654687085322, 0.06246765051037073, 0.031016700834568058, 0.03848410763644746, 0.02400365295553846, 0.057228858050491126, 0.016193038052214042, 0.04312081222555467, 0.017334649472364357, 0.055384908603238206, 0.021376735164916942, 0.053384672185139995, 0.016509871497484188, 0.028014999315408722, 0.08888770067798239, 0.02012982189522258, 0.031321206994886906, 0.03835195954889059, 0.013749940487157022, 0.06984073415930782, 0.02207081881351769, 0.07837232135768447, 0.04909033261771713, 0.02700124933783497, 0.019504304210256253, 0.03201589114697916, 0.018979174084961414, 0.028281188603224497, 0.03749163142804589, 0.042785717706595144, 0.044796261071626625, 0.022307951535497392, 0.05972885925854955, 0.03163949080875941, 0.05509752866679004, 0.036419549491256475, 0.010494138629707907, 0.013977353194994586, 0.023733478970825672, 0.02978842692183597, 0.035901905303554874, 0.024632805891867195, 0.05819286632218531, 0.03079973586968013, 0.017216370640588657, 0.031060228856014352, 0.027800456720537374, 0.030786619787769656, 0.007796073049706007, 0.07353861430393797, 0.04807410089831267, 0.015318837282913072, 0.06951892535601344, 0.03959499838362847, 0.02316947727065001, 0.021665295752297555, 0.017413201775135737, 0.056311081762292554, 0.04628421372867056, 0.05958377490086215, 0.04063291608222893, 0.027797323585088764, 0.03635186901582139, 0.035131605208984444, 0.014286914441202368, 0.032393136261297126, 0.015239530109933444, 0.02836587486256446, 0.033502829394170215, 0.013388150704226323, 0.012307627791804927, 0.0301317486778966, 0.05848779156804085, 0.04598256080810513, 0.027204392544393028, 0.06059905327856541, 0.04621874867007136, 0.009762006978105222, 0.019941596281049506, 0.054013938776084354, 0.03472828399389982, 0.015363340698448675, 0.038356570194342306, 0.010494790871494582, 0.05450676893815398, 0.04690603679046035, 0.008624863711052706, 0.03209751212437238, 0.09673632880938904, 0.03249096744028585, 0.03192679271368044, 0.05030769229467426, 0.04208029234515769, 0.05484116456604429, 0.01525267502958221, 0.08924021319087062, 0.05559307636160936, 0.014978171991450446, 0.03795919633869614, 0.016063934890553355, 0.026325562469927326, 0.020095399813726544, 0.022601373826286623, 0.016723543871194124, 0.014840994263067842, 0.011307162681727536, 0.031734180370611806, 0.027115287325744118, 0.032909141786928685, 0.05966352990695408, 0.019537101200382625, 0.00868843141610601, 0.01128744360591684, 0.025780668315876807, 0.06100251020065375, 0.03953487000295094, 0.036066701103534014, 0.032968391464757066, 0.0064634459642028165, 0.03885581251233816, 0.03937569925827639, 0.028510813335222856, 0.015796598878556063, 0.06831219832279853, 0.005768006093733544, 0.021760931870500957, 0.02021383979756917, 0.0723925211599895, 0.0334279869816133, 0.011230780842847057, 0.035898166575602124, 0.021250463190621564, 0.056453353592327664, 0.019553314794653227, 0.05035244846450431, 0.039102456598941765, 0.05334472343591707, 0.042079793621918986, 0.013613442990130611, 0.03540054934897593, 0.008433015568048825, 0.02683328477931874, 0.061032582872680256, 0.0053794095126379815, 0.05101185558097703, 0.027003517341134802, 0.023035293578037193, 0.02963065056662474, 0.0810000839244042, 0.03460516042209097, 0.0016377391563894758, 0.04393999059019344, 0.021910565805488398, 0.09198848357690231, 0.011734381900168955, 0.024889845134956495, 0.06468902488372155, 0.04026259881045137, 0.03184691557128515, 0.06303471579615559, 0.012619467219337821, 0.022636023217013905, 0.06318547949194908, 0.01882168780347066, 0.014807369460218718, 0.017796799673565795, 0.07429514692298003, 0.021905310551768968, 0.09905476083180734, 0.04783150088042021, 0.05119605748248952, 0.01175005266642464, 0.014143163404826607, 0.04271433921530843, 0.06357631566269056, 0.01614820893986949, 0.10343591216951609, 0.06196198585842337, 0.04045489563473633, 0.03649401531687804, 0.010918223016363169, 0.04939047579786607, 0.04066332123641457, 0.05415390697973115, 0.04220029804855585, 0.04270796437880822, 0.03200564866087266, 0.08922312767910105, 0.020257481473631093, 0.02651363711005875, 0.04618465228538428, 0.025372682172538977, 0.05888931466532605, 0.04410504423347967, 0.017492600550342883, 0.02114286958905203, 0.019318180358303443, 0.0126735082927293, 0.05728768025125776, 0.06128450256905385, 0.036196331826171706, 0.04153574424396668, 0.026567857147061398, 0.05152224622932928, 0.011474458035081625, 0.04117621907166072, 0.027482334058731794, 0.04210994093279753, 0.03183879011443683, 0.037672019962753565, 0.02045401235643242, 0.03230218882007258, 0.061238620031092844, 0.029666514535035406, 0.036325989690210135, 0.01071715443062463, 0.012730171903967857, 0.02985576812976173, 0.029242840662066425, 0.02507011662237346, 0.04775100627115794, 0.0570410124159285, 0.06689475902489253, 0.05079073119642479, 0.04274382834721889, 0.03288152541166969, 0.06540422114942755, 0.018844037050647394, 0.03851237540532436, 0.01545714307576418, 0.015032549787844931, 0.021288781759462187, 0.01928893380266215, 0.06499408065740551, 0.06676421567265477, 0.03717069114957537, 0.027106953219377568, 0.05534639834825482, 0.06530056135462863, 0.028607504575380256, 0.04851137600573046, 0.024884152226150036, 0.006092037947382778, 0.01932453823142818, 0.05874715479356902, 0.06896684212344033, 0.018536894781781093, 0.02734717327569212, 0.04345772521836417, 0.02602392651273736, 0.03427610486479742, 0.008563069526904395, 0.03406978611435209, 0.04788571582841022, 0.02443285858524697, 0.015233969515455621, 0.04409501887857914, 0.010821938897216958, 0.03151259458224688, 0.04903240608317511, 0.0359705187646406, 0.02743827169095831, 0.02382376484040703, 0.02130745504317539, 0.10606005135923624, 0.029386109938578944, 0.054873707105538676, 0.024844186513551643, 0.058209734702748914, 0.017752253849591528, 0.01273080039702888, 0.041339830828032324, 0.03825451513486249, 0.02224508187334452, 0.02332520275376737, 0.051115874999335835, 0.004246792074159852, 0.04195414589984076, 0.02037169418430754, 0.03489158023148775, 0.031372354964592626, 0.01751147230554904, 0.014893758842455489, 0.016681703705606715, 0.02949382398011429, 0.06133892107754946, 0.0313051969611219, 0.08112003534500088, 0.08544096669980458, 0.026511781316782747, 0.03506507485040596, 0.04381919100082346, 0.09699590238077299, 0.025966332460354482, 0.025560534592451792, 0.040335962016667636, 0.03543951761509691, 0.04048575201470937, 0.020811269525438547, 0.08211853355169296, 0.04037276914875422, 0.03498269391379186, 0.059479043020733764, 0.04708273748734167, 0.02496447041630745, 0.02448492088089032, 0.04746590621237244, 0.012950649135746062, 0.037377545942685435, 0.0489039424407695, 0.020654370176738927, 0.02251113036514393, 0.041498377320489714, 0.007309498980508319, 0.03628075515319194, 0.03159341488831809, 0.019935503036582043, 0.06537043689084904, 0.05045854080734508, 0.033136386557349136, 0.025027016077988913, 0.03940177535904305, 0.02805230177805892, 0.05350083398765751, 0.043147824704647064, 0.018366950597347956, 0.044213375741881986, 0.07937696030629532, 0.06440629969750132, 0.02693845940354679, 0.05508473149633833, 0.014011293516627379, 0.029550502010221993, 0.08426481445452996, 0.02615833072923124, 0.040372891285057576, 0.013066722728711153, 0.018618237559816668, 0.02145353175832757, 0.010038566825512265, 0.021093407778867652, 0.07977296691387892, 0.12993761045592173, 0.09769334817039114, 0.11975279982600893, 0.10895666307104485, 0.15565920381673745, 0.14073754022164003, 0.10433423146605492, 0.16890145252857888, 0.11477453767188958, 0.11314409266092948, 0.22480657696723938, 0.1434868419809001, 0.11903442123106547, 0.10709010144429547, 0.13553359732031822, 0.14161685375230654, 0.09464084303804807, 0.1494122033140489, 0.11359689943492413, 0.12140020142708506, 0.06181845534592867, 0.17984886866595062, 0.08936434438718216, 0.09919975697994232, 0.1528888131890978, 0.06550376902201346, 0.14772315323352814, 0.19635478939328874, 0.07578027008899621, 0.13147244309740408, 0.08827528889690127, 0.1181137306349618, 0.12478932099682943, 0.08142786632691111, 0.0994926466207419, 0.14583902433514595, 0.11743786904428687, 0.11728396373135702, 0.09800820198974439, 0.15288673687194074, 0.11176624588136162, 0.1338914204388857, 0.14075856123651775, 0.13768793243382657, 0.07814567709075552, 0.15610205648200853, 0.12251126180802073, 0.10958875915301697, 0.17530367470213346, 0.09271409535514456, 0.09527520542698246, 0.11175492113190037, 0.14938707037695817, 0.14543834940663405, 0.06027330218681267, 0.11117769817688636, 0.16319799928792886, 0.13545139958815916, 0.14076981134712696, 0.13654646011335508, 0.15417897967355593, 0.10714703731771026, 0.1710974904043334, 0.07222195102700166, 0.10728458993669067, 0.08570961228438786, 0.10884260811976024, 0.20914480808590138, 0.13263561496777193, 0.1927975152752229, 0.10867669273700033, 0.1411669443228415, 0.16290407148855074, 0.10552330980343477, 0.09599551784672908, 0.14860727079212666, 0.13960586594683783, 0.07559088417994124, 0.1156837067433766, 0.13028303906321526, 0.09553632605820894, 0.0917478139911379, 0.0877210275669183, 0.07380203516887766, 0.13385020622185298, 0.10395810593451772, 0.14122058930141584, 0.16273362349186624, 0.09343883860856295, 0.13896751377199376, 0.11586832255125046, 0.2078618612140417, 0.1010798689510141, 0.21381591100777897, 0.13329897794340337, 0.09796203446707555, 0.08552871484841619, 0.13383997391377175, 0.30713863191860064, 0.1140123935682433, 0.07821967133453914, 0.11416324547358922, 0.1451711016041892, 0.12612086454672472, 0.11796624426330839, 0.2099560781248978, 0.12339983055634157, 0.1398099557097469, 0.0810089252356972, 0.07127177129898753, 0.08931736940784113, 0.1576262225529977, 0.11255618956472192, 0.07304761279374361, 0.08567166860614504, 0.07540136934923274, 0.10835163375096661, 0.06398526193307978, 0.10469800087490252, 0.22204944491386414, 0.14197474026254245, 0.11298656397100006, 0.1117430128423231, 0.09325108796890293, 0.1276396701910666, 0.09801449200936727, 0.22486617948327745, 0.10853260582579033, 0.14727937776063169, 0.07869960593857936, 0.08995588443108968, 0.09258211350866727, 0.1181698590517044, 0.14109729948852742, 0.1337528093052762, 0.07868518706943307, 0.119485986285976, 0.09715631484453167, 0.10255472588219813, 0.14029996655881405, 0.17247277232153074, 0.07271906613771405, 0.15368989163211413, 0.1484441238322428, 0.14663759219859326, 0.16308172552713326, 0.2284509614109993, 0.08009048737585545, 0.07159602961369924, 0.13737398785139832, 0.0909320724063686, 0.21830518011535915, 0.14461397007107735, 0.12415832414158753, 0.0710376360054527, 0.12340116048497812, 0.10916416586509772, 0.11764953125800405, 0.16761370162878717, 0.09658399769770247, 0.10847452322819404, 0.19238035194575787, 0.11134014624570097, 0.1694818035300289, 0.12535264076931135, 0.11624898069671222, 0.10993853716978005, 0.15432875949357236, 0.10946788492479495, 0.1313431414642504, 0.07819280134780066, 0.09881834566060986, 0.15141589008271694, 0.09333863255700894, 0.16854923857109888], [0.04141544337783541, 0.03520290906141911, 0.02016652555071882, 0.05325296175267015, 0.04054872006443994, 0.033975028698997836, 0.03193478246352502, 0.026038533675351312, 0.017981863314551965, 0.035004695411771536, 0.06804526264646224, 0.05779251709048237, 0.006804009899497032, 0.045414772882525406, 0.07450455640043531, 0.03678940535922136, 0.04273387763117041, 0.02068721127164151, 0.0178451419009694, 0.0690106347735439, 0.04310889375795211, 0.04163581458851695, 0.07130721118301153, 0.057956172951630185, 0.06371172411101204, 0.020425400231033564, 0.031576919702014754, 0.02089873099300478, 0.023672780620732477, 0.029874505874301707, 0.008345432812348008, 0.01938114671169647, 0.028984033835253546, 0.03883994836360216, 0.01696500734293035, 0.04347737219982913, 0.019210831029340625, 0.0421592568579529, 0.08577919605055026, 0.02898819325491786, 0.027811727187197124, 0.02803145718228604, 0.020826300772439157, 0.04488416528329253, 0.0062250647377888, 0.09119858739099332, 0.05176375719851681, 0.05306816613301635, 0.019162280152418783, 0.04024907221485462, 0.034578962185020955, 0.03693544305860996, 0.036871613269405704, 0.042945427886609516, 0.06775381828525237, 0.034925937852157016, 0.012026404712482222, 0.009788553812541068, 0.040808534515755515, 0.004385301003432167, 0.03199745195784739, 0.04200210814763393, 0.03767831676772662, 0.04339488269761205, 0.02473873708264104, 0.035333269209201844, 0.026002632387514626, 0.049909137788095644, 0.022871230595878193, 0.021119655209726522, 0.02919778593682817, 0.026347202648009573, 0.02478989353403449, 0.04848448566294142, 0.04157983884215355, 0.02358184166119567, 0.06464146636426449, 0.060143050604632924, 0.01838776974805764, 0.00646273435060201, 0.047872745631528754, 0.024536548914121728, 0.028190266607063155, 0.08223465803478446, 0.04915735830685922, 0.03879862558096647, 0.07639327219554357, 0.013553064399664956, 0.03727852054206388, 0.030034131237438748, 0.03590388662580933, 0.02790870001938726, 0.02386101471659328, 0.10355762778116123, 0.04069410637021065, 0.021659316162445715, 0.040420816213424714, 0.0166842974057155, 0.01653491792136005, 0.12343427299388818, 0.054426332004368305, 0.026756193023175, 0.0429816345152046, 0.041627855372748206, 0.06515985354781151, 0.10601306959454503, 0.023138239214728986, 0.07882046659610101, 0.004723531202346618, 0.015626456222629974, 0.05878974643668958, 0.014826437990580286, 0.07662332270826612, 0.006852107854293925, 0.019189957595829452, 0.04564730344074113, 0.008066841600728887, 0.02666590884993119, 0.020588884762089168, 0.06811117553817374, 0.01559581358118781, 0.02185988093593291, 0.04759200516023806, 0.022280128207057714, 0.0036729545848044965, 0.04264498954372747, 0.04557005222886801, 0.08161006655011858, 0.06699963339737483, 0.03441598825156689, 0.04430149708475385, 0.03810733749664255, 0.024547188343214135, 0.05481376192931618, 0.04185486604858722, 0.06772618155394282, 0.07016792374530009, 0.058520334107535224, 0.013963103111434196, 0.01787572686693498, 0.00983420734493328, 0.030615666282496283, 0.02638904281359698, 0.06539609908525433, 0.05208210547321609, 0.009894934532764767, 0.0025006653242079274, 0.042587873858532736, 0.062498557780470164, 0.03140090771817735, 0.036118500466857634, 0.02640171954408288, 0.0738981089421681, 0.04156368292335953, 0.11782088849161353, 0.039247439176376374, 0.029561531596950123, 0.010256569100809949, 0.022902536505301083, 0.050783287667270215, 0.05394721503502556, 0.04393541047881756, 0.05548434451754604, 0.012164234682651502, 0.04369394700708134, 0.04403096178014364, 0.026803617531965886, 0.021210896117346625, 0.023496012070349286, 0.04630739587758269, 0.0391089162523193, 0.04831576793055449, 0.03163711254351905, 0.03651756387470024, 0.024884734069928527, 0.06954274193516799, 0.028877381701022387, 0.004673213589869971, 0.01415704283863306, 0.01589257935328143, 0.0600823149351137, 0.04018096086968269, 0.004830592578010899, 0.033947117161005735, 0.013913818568523442, 0.020432031214503304, 0.020126215481598462, 0.05715824291110039, 0.02570361896817173, 0.036531382240355015, 0.0510753800294229, 0.027095804889021174, 0.02359346835874021, 0.0451320341256048, 0.021163746415238296, 0.052738998617444716, 0.022055690875276923, 0.038869881935949833, 0.022468141779037457, 0.039867447156991274, 0.06358586943575315, 0.04589491104707122, 0.029577124331678663, 0.016553599686760987, 0.039081900380551815, 0.02129484446985381, 0.06773230872516121, 0.060115793852933815, 0.029239271567868333, 0.05718357940869672, 0.0023756274354777163, 0.049349461748663864, 0.00870804616715759, 0.026833401826609458, 0.06876934093556233, 0.03308229035298739, 0.04977296259520309, 0.043405617121607065, 0.024098985429321016, 0.02448738396300801, 0.03654166204588754, 0.054612057216997655, 0.01774247785631035, 0.030442409150834595, 0.0315250864119402, 0.052694666532001326, 0.013772019168495067, 0.032973555116248984, 0.092929550579616, 0.10824301386518137, 0.06945067830383778, 0.054643208759703805, 0.02918290566386921, 0.02222200998637293, 0.064787100335317, 0.015406890772283077, 0.06043522099831274, 0.022201821873230592, 0.04811603436246514, 0.03631371838439788, 0.005193516362591514, 0.02043917279557458, 0.03516470753986921, 0.024252461568851556, 0.04585940670222044, 0.0314972223713994, 0.07628890672432524, 0.036871392745524645, 0.07161654172731297, 0.03745787091819303, 0.03243718336203268, 0.02996784515146698, 0.04075064530063953, 0.10851492998855454, 0.025693934577118074, 0.0058007292931766385, 0.04197657487488218, 0.09449454410267727, 0.03666059905663133, 0.05806323220687253, 0.07404279974954468, 0.037916584339525015, 0.04766280689675893, 0.04701954212837985, 0.011976394985270287, 0.07627218083611556, 0.03420454316905566, 0.03798616810568741, 0.04213635630107351, 0.05137085149596844, 0.019705895267959152, 0.033827443939766715, 0.004038544163839626, 0.07166642762188401, 0.04044500259416444, 0.008726614277942904, 0.015164180492450084, 0.03471932054630347, 0.061600340264184136, 0.04970435252679246, 0.04959136966083731, 0.03970548763339009, 0.03801817799519215, 0.0795402361878327, 0.03535880248195358, 0.022997896120484387, 0.020254065049812198, 0.04564314062840172, 0.030016367190650532, 0.06628172977694444, 0.07302101422101259, 0.05659888578312738, 0.04591277687411223, 0.026689951041979448, 0.051936685240694454, 0.08931068583790745, 0.042077316969100914, 0.04053397210580962, 0.009584877107824599, 0.013446663323390697, 0.05219981433557613, 0.012775303812564483, 0.03689955873414874, 0.08015412717525448, 0.07870614023080894, 0.016782306700146625, 0.04958252834954432, 0.07345743437430688, 0.04068749065377882, 0.019886443258396218, 0.022819108928420713, 0.027318043767341545, 0.06335889947201524, 0.038376885532800636, 0.02917774540505239, 0.056627726914095025, 0.04647001018747687, 0.04209401571590986, 0.054042600095272064, 0.07859186136296817, 0.09201574711395161, 0.06014121177473238, 0.0635902595573238, 0.032437393707888465, 0.020419490191021135, 0.030855877857123102, 0.03400665521621704, 0.05916121043264866, 0.0809375908491867, 0.04342518946421998, 0.09912728265460048, 0.023819510425840105, 0.023702563219038502, 0.022500112652778625, 0.027014701294579675, 0.05107098990785224, 0.0063041535073093, 0.06281162705272436, 0.03288460935332945, 0.01943272046212639, 0.041349839219557386, 0.019595326290332844, 0.07407403950180326, 0.01598186099103519, 0.014419954802308763, 0.06381053238042764, 0.02678064233623445, 0.023222876280280094, 0.040873226044433456, 0.005411329920337136, 0.03443459028910313, 0.0519912326708436, 0.1521629707089492, 0.14074383702661308, 0.052778886298515966, 0.11827917104320866, 0.12047751593802657, 0.1637286136725119, 0.08954647675688777, 0.1309599998806204, 0.0768856443464756, 0.08022329024970531, 0.16179420532924788, 0.21879489240901812, 0.07548282747822148, 0.18018672482243606, 0.1724536104926041, 0.12374694193048136, 0.11018973083368369, 0.1781001075037888, 0.07492193007575614, 0.1313177099717515, 0.19078850879200868, 0.10366459882685117, 0.20001389804695333, 0.1259238315480096, 0.16121397646410124, 0.18817400479955332, 0.12529066338070802, 0.05333367010046329, 0.13573072531393596, 0.09395270674888577, 0.10234553353594882, 0.07794966867991857, 0.07953438721597195, 0.1931154089314597, 0.06447004806250334, 0.16110321240765707, 0.09776035350348268, 0.14866466128400393, 0.16800077871552535, 0.08473081194928714, 0.11162029299885035, 0.1169094124010631, 0.12047203337507588, 0.09187702741473913, 0.13239643137369836, 0.20567860693803855, 0.0955982966614621, 0.18008220328816346, 0.07321073261222669, 0.17606572381087712, 0.17006561506007398, 0.1510282973093646, 0.11359202076814004, 0.20143935084342957, 0.13558645519827092, 0.17950221869562352, 0.12434991528945309, 0.04424000824136393, 0.10842748039535113, 0.0635828228135194, 0.13474520748215063, 0.09548921537186418, 0.1810691189020872, 0.11359084690255777, 0.07739240143980299, 0.17686914998505796, 0.13938756766063826, 0.13653843982943467, 0.08502771851739713, 0.1385119589311736, 0.22634010682148592, 0.07072324358991214, 0.10212602067206587, 0.10788555483200721, 0.09373970103583165, 0.12283029540308885, 0.15308482838528498, 0.2212843152561358, 0.10907503350504807, 0.1358652516667332, 0.17227970196732453, 0.2520259278161185, 0.11223812627473048, 0.12646181482289517, 0.14800762225474628, 0.1315236860620124, 0.08864965023738997, 0.0861510264554194, 0.08289226703345776, 0.17310177428381784, 0.10307136244539704, 0.12562766458306993, 0.15511218245540345, 0.20014131335275515, 0.13861520481961115, 0.11382108061973538, 0.09451587724366359, 0.1452739539423159, 0.12620249230946812, 0.18591607095939772, 0.20959414754595074, 0.1119727376582367, 0.2244264209376914, 0.21397687308490276, 0.18830888399056026, 0.23273566578115734, 0.10234277189842292, 0.19030730532748358, 0.09634800321821656, 0.05592515139973589, 0.16905068952058042, 0.17226309143006802, 0.1857853036906038, 0.18684917874634266, 0.19151931814849377, 0.1451682246157101, 0.08730919073734965, 0.09012597280421428, 0.07448200868176562, 0.13997987444911683, 0.12067237762468201, 0.08606996866209166, 0.09357056939708334, 0.10598535822438342, 0.15884559069361004, 0.12586697031344685, 0.13687877942408833, 0.14791565361831868, 0.12562390549906663, 0.14784197828599385, 0.22287702693470887, 0.1448363938501903, 0.09913974055754286, 0.12144518829882145, 0.12649556515472277, 0.16923477607113974, 0.15911334061196872, 0.15080201945134572, 0.04820304969325662, 0.24720157097492898, 0.12068944956575121, 0.06353224481322936, 0.08529881361339774, 0.16912051077399934, 0.2457349311028208, 0.152939323335886, 0.09640890852149044, 0.1518068891018629, 0.13158145653350012, 0.14064857070999487, 0.08527645588453327, 0.1413923129439354, 0.13163725925343378, 0.16082715722067015, 0.18889963014849595, 0.12050729005464486, 0.09842319400714976, 0.08571525769574301, 0.1113024807668158, 0.08358237107417413, 0.07140217894422156, 0.21865415067545005, 0.1840679044170039, 0.11433933888162885, 0.11377377315823521, 0.11273467141602721, 0.17675443685480527, 0.0687350206343191, 0.09356725136084215, 0.19723560927169664, 0.14404727119420255, 0.08135406207293272, 0.0825284162004079, 0.16972063428589276, 0.10194160163934742, 0.10207716615072318], [0.03343880622248564, 0.03416929666751197, 0.0678741361147591, 0.022318641854716197, 0.06605743324118, 0.05635532903085862, 0.10636296974761145, 0.0766449747607112, 0.04809640095170055, 0.06420730573258229, 0.03878431188474808, 0.015462540821837527, 0.018921479948663285, 0.030865699651518037, 0.0063335438275576705, 0.06124787524874721, 0.019806505047849247, 0.028740229417702982, 0.05466803635603615, 0.017177329431953173, 0.007647723242241357, 0.03361220923917634, 0.051384775034551106, 0.041849084930228334, 0.05271899201241987, 0.05711609910109213, 0.05902070618633713, 0.015149111926023449, 0.020765705898936306, 0.0745723827608994, 0.022809222673199007, 0.07137830129691533, 0.01979520743978875, 0.01556637873207884, 0.025143552771104232, 0.07948625872709922, 0.09371880215725728, 0.028699055912771394, 0.006962516528022076, 0.03907820236470018, 0.01899574221377926, 0.01711999491921493, 0.015093176891761166, 0.045112180190959146, 0.07588838785886765, 0.0459882978216878, 0.04310202359088829, 0.006993146446932639, 0.03790727144639407, 0.018481806219954575, 0.04466945644734161, 0.06409776982452188, 0.039489706712109704, 0.0491797058576984, 0.09434282367250749, 0.03860535166625466, 0.030036757167960917, 0.01597274826573474, 0.025361639015110474, 0.053943713794329336, 0.04800108713763101, 0.02970962525744523, 0.017137692808838825, 0.04611592008067029, 0.01130273608889963, 0.045863460948956866, 0.04656405853373664, 0.03487449132704309, 0.036249929307294745, 0.033687957495983155, 0.02409787941724062, 0.03671225592760103, 0.05172377112986786, 0.07963902410119772, 0.030630254785397222, 0.06679438333958387, 0.038063660197492154, 0.03980276580633862, 0.04581925439249192, 0.017928433770846044, 0.06715207986001458, 0.019676608000216738, 0.06317674674625907, 0.04108597052150539, 0.006181428574823907, 0.05368303421086498, 0.03821479369487081, 0.016534955240786076, 0.011805138683744838, 0.020173041183235388, 0.027014116058126092, 0.02069553011097014, 0.004922493360936642, 0.06743810951177563, 0.018206197169742415, 0.053749001385377984, 0.028922551777213812, 0.03349384219784822, 0.025138199129807096, 0.012469299786191965, 0.030801527202129364, 0.020973402075469494, 0.04110980745671051, 0.08423924046967711, 0.04769295081496239, 0.05426478299445339, 0.023584489644105946, 0.03611826297960111, 0.009872373243394707, 0.05894340069166251, 0.034495655048106394, 0.02667179174854287, 0.04018202956233706, 0.03418482833408883, 0.027708574597324644, 0.03391651523166469, 0.006299914783864681, 0.012134969467297196, 0.09746182523667812, 0.016931073806647743, 0.0376679894647428, 0.031247168646327088, 0.05473902468968715, 0.015205147044200982, 0.02993613381737045, 0.00868367318928774, 0.04554780645828162, 0.044185141899756024, 0.03747623207579766, 0.0237344187418265, 0.031882338491933684, 0.05805417376437357, 0.045390807025666745, 0.02065202753458704, 0.020820061642942683, 0.039508827828935215, 0.0612419584233846, 0.016074386026178087, 0.024192473984190395, 0.05532479718593614, 0.07157416043004819, 0.08180416827755314, 0.0885695627491389, 0.023175214284232686, 0.02616904310083815, 0.043508265899228196, 0.02538975072093308, 0.0077683616795444065, 0.030178163865847246, 0.00846385837732149, 0.01703384641690978, 0.03614948916115931, 0.008646531878704471, 0.0046642679538178656, 0.02364911331928202, 0.047041757364890406, 0.03596892420734678, 0.02798496905182089, 0.0335072025523654, 0.04315473897648709, 0.008644111205025442, 0.022838776265936236, 0.019328682384054576, 0.031791085709950755, 0.02838725210832698, 0.024845782767183015, 0.02312383900529572, 0.015479022437440497, 0.03643951538418021, 0.053599214780011346, 0.022843493780653392, 0.026541406155696938, 0.06267160456627607, 0.03961206014667239, 0.057419675668435435, 0.046940431730555635, 0.02620884426869452, 0.03820724838546344, 0.0446224746826504, 0.09634031541645527, 0.04259412995140467, 0.025584067883236066, 0.06982138912592616, 0.05485148847635303, 0.03144824232107826, 0.030041116755455732, 0.04348337384206908, 0.07332419723804508, 0.0304399969588433, 0.0486478090419301, 0.024183312065101097, 0.016261960246733258, 0.02301384338976017, 0.0649291245000703, 0.05045057480622615, 0.04016466924388494, 0.03147205890023282, 0.013713863628384258, 0.04778656489881022, 0.02047559485903808, 0.06616727448999882, 0.05477177078968712, 0.052646531257778406, 0.03961045541135328, 0.03804532278861318, 0.03539533820003271, 0.07864673448992626, 0.051309325333152495, 0.05352901354698198, 0.04316665744408965, 0.040347317300204716, 0.05429716607821839, 0.058148300142160485, 0.011374558172454792, 0.025557995175144503, 0.022726063117651, 0.03567651632641043, 0.06449745409190655, 0.04281603465122836, 0.02266901358962059, 0.020278438027682047, 0.06188404254083123, 0.036157373738076, 0.03963683346020324, 0.009877411365908171, 0.053978824588869295, 0.05093048566154071, 0.07659689376928977, 0.0890262643141406, 0.0010106193866314633, 0.07692657357880048, 0.05236481708873596, 0.061396576198084016, 0.08621009971414294, 0.0406367973025356, 0.06825580527739865, 0.031133720983884165, 0.032530444607670815, 0.020770786429888437, 0.018723006759371077, 0.04248530311243875, 0.016616781475022435, 0.009317323116452565, 0.01837971044837364, 0.028678638794060265, 0.04371913761964866, 0.03537857838507209, 0.061744026839733124, 0.05228836994085993, 0.011347424405227815, 0.02850798045152, 0.0353319867780166, 0.03806124122015067, 0.011628054614577974, 0.025330984499305487, 0.031019208021461964, 0.0478466152479606, 0.05566804769581982, 0.01589207723736763, 0.025826399879796163, 0.041876290791801045, 0.02675354334392718, 0.024755793756672313, 0.03879734993513141, 0.019914758524724414, 0.03274499738056745, 0.028612512163817883, 0.033480118827096055, 0.01806262764148414, 0.04131535606990967, 0.04185476426833442, 0.0221293746892895, 0.03182809300986784, 0.022105703995163952, 0.037386465285505564, 0.04264065031228321, 0.05653659287574036, 0.04370868139501129, 0.03808263542928866, 0.04189782749329295, 0.07654416481299059, 0.011351168222193207, 0.015299499034881592, 0.04249705533896174, 0.02568335791251489, 0.027209115148122822, 0.038335986834551604, 0.010426548908331564, 0.02028938619020794, 0.008390160992608538, 0.015419369031276022, 0.00945722940377891, 0.0243982787443591, 0.053060580111507855, 0.014199095046413797, 0.004116350078090493, 0.029827727670116082, 0.07444955435182367, 0.02246982284954616, 0.05326867323102696, 0.03072524629533291, 0.04454558648701225, 0.029849997189428126, 0.06173844928187983, 0.039589434396475554, 0.027285129729924456, 0.04726316334147539, 0.07160928140261344, 0.05793105358523982, 0.031566012251589975, 0.04799301257090909, 0.013045901033495153, 0.05104857789618628, 0.012310825388080307, 0.037629255293203254, 0.05747479985335043, 0.01455135310867003, 0.052972994811300717, 0.034218208864331245, 0.039986187392579656, 0.02979253205869879, 0.07483351696282625, 0.03635248987536345, 0.01576615810128195, 0.027164937429396168, 0.01842427662839847, 0.06474575041128056, 0.05464243183710745, 0.03832162903355701, 0.043501585721969604, 0.05504902698365705, 0.052220350197915516, 0.01680946845694312, 0.03754223996241178, 0.08453543457601752, 0.08798174107713358, 0.026630769217652932, 0.07339299390358583, 0.044999370351433754, 0.029196581537170068, 0.0345445502815502, 0.028378443027447377, 0.04438158457300492, 0.03608965594321489, 0.07911740030561175, 0.022949185787833164, 0.05035238400367754, 0.04086731600442103, 0.025182865393747176, 0.038468891488654275, 0.014962916827893682, 0.05159085290506482, 0.15090158767998219, 0.16495893336832523, 0.10306715552828141, 0.1851300559937954, 0.24183568890605653, 0.06429762552891459, 0.16651656478643417, 0.15052798629871436, 0.11989069171249866, 0.19115711615553924, 0.10643045005521604, 0.15367974074823515, 0.08934416475572757, 0.18450108117290906, 0.08299933985940047, 0.14560672108616146, 0.10970921947487763, 0.26186962532145636, 0.27574409225157326, 0.12324299397213118, 0.12718119764966623, 0.09702861455402204, 0.1958647242614201, 0.07389613440526382, 0.19522255871977123, 0.20569391468805925, 0.19004266309951032, 0.09841295491371836, 0.13467651259686264, 0.1742267446326358, 0.13337991360042775, 0.3049104857657637, 0.16774243329252514, 0.09497998162571873, 0.08220296366406338, 0.200740799041731, 0.1920827736279794, 0.10937440994062594, 0.18614694928484304, 0.12951668804245337, 0.06735305514718805, 0.13634888428662503, 0.10090959737343447, 0.13131879562778132, 0.17295468146247522, 0.1212056382958378, 0.16216779313981533, 0.12751087067382677, 0.1316027489623853, 0.162147369235754, 0.1935055258550814, 0.1725652702152729, 0.17660272999533586, 0.1780818956238883, 0.17449480667710304, 0.22637343646160193, 0.15608719656510012, 0.13954296575060912, 0.15319234904433998, 0.16703523695468903, 0.11553122635398592, 0.10184229125401803, 0.1508429893957717, 0.16343887921954903, 0.15961802138813905, 0.14285539729254587, 0.14448826467352255, 0.08746819184826952, 0.13478301545338972, 0.0792215418602739, 0.17299371079674788, 0.13528656986142906, 0.11469314061105251, 0.11821058472352368, 0.0983884326581444, 0.1158644820430449, 0.1590252939079489, 0.08670967112162284, 0.14172813349536487, 0.09174122541610684, 0.13339353858360223, 0.11757705014731203, 0.14977963002664701, 0.1345201509871653, 0.1533782947808504, 0.1107510014304093, 0.12238567854676928, 0.18420732979263577, 0.06540085561573505, 0.15042915088789804, 0.11074589884706906, 0.10584189556539059, 0.1779585922402995, 0.11049226245709828, 0.14112946204841137, 0.17294584693653242, 0.10116286735449519, 0.11868351006082126, 0.09073654575539486, 0.08700910862535238, 0.16248959515775951, 0.0718245194958789, 0.13438497324075016, 0.12384393172604696, 0.18370832156922134, 0.1373113454984767, 0.17572281935385295, 0.10283355627741132, 0.08451100731534616, 0.11822013849658625, 0.10284774444465127, 0.1726232035351651, 0.13024413186524594, 0.1883286836424044, 0.1502101333545787, 0.14476361418409006, 0.09926208720675536, 0.15614909252950124, 0.15114795017455304, 0.12377185773636613, 0.09131195023655891, 0.14397940412163734, 0.1533283003206764, 0.0947019247604268, 0.074144254305533, 0.08853630774787494, 0.1913923913879054, 0.12095580170197145, 0.27508292772940224, 0.10794156111244645, 0.1443286868078368, 0.11649762306894575, 0.19757642384086335, 0.07824177122009651, 0.07009581582886831, 0.08917267181511436, 0.17622641447399343, 0.1051994382536837, 0.12863415825579846, 0.15555240240480217, 0.10544872523418494, 0.18961947437907967, 0.22133335976728372, 0.10729843883642129, 0.12482121214270592, 0.20114479879183428, 0.09603025883968387, 0.20428998502237455, 0.10717905738524028, 0.12350716122559138, 0.195261737331748, 0.15717024702046598, 0.1841394898614713, 0.0918978787958622, 0.14542294666171074, 0.14167085156909057, 0.1066067877358624, 0.16359654361648218, 0.12855187909943716, 0.21826653076069696, 0.08364150540104934, 0.1263654085674456, 0.0981907821925623, 0.14349222954894814, 0.12430275710565702, 0.060821463486977985, 0.16074101041470254, 0.15350984915026597, 0.19955785466091974, 0.1577341231916632, 0.13967773637601308, 0.06920553038695029, 0.1140258964151144, 0.10221411487353699, 0.12350907469434397, 0.11169164095606122], [0.011507042983014668, 0.06780457270464726, 0.050434245861002376, 0.05929732455738953, 0.03577583349709, 0.047700017757181606, 0.009924116627579289, 0.04707774346960442, 0.005211695587994265, 0.0275933288170823, 0.12082844067897115, 0.04603837709873915, 0.018430719318400537, 0.03864715960142868, 0.1308256635176284, 0.026225256334458078, 0.046656637851681025, 0.05791170855185815, 0.055210548852171214, 0.019818036750491177, 0.059908535331487656, 0.05547177465632558, 0.05109285909150328, 0.07083870310868536, 0.04759032578606691, 0.03691771633124777, 0.016192376480570862, 0.051589322808597765, 0.05349053043339934, 0.1028304078749248, 0.006569051882252097, 0.025245830050802658, 0.0486592559276947, 0.07106744404882193, 0.044452847713338475, 0.01156362856272608, 0.04278143275795238, 0.0026382688333147337, 0.06106579716184309, 0.05288169453186648, 0.04348573514393397, 0.04930903463225279, 0.015545958220692617, 0.05495264447693314, 0.052093623605157645, 0.053933875036558936, 0.00601599961685549, 0.04925345243620021, 0.02286786336584815, 0.10005007670926196, 0.049855017835008245, 0.02981011290103197, 0.041350531325276406, 0.04336656743128385, 0.04734549338796309, 0.03223180777526327, 0.026539238236312355, 0.016025901306420565, 0.08751342299261264, 0.04924806147547705, 0.0427187191588538, 0.0634583727057491, 0.03742439200037292, 0.02645260118879378, 0.016975275274100046, 0.01740495248564652, 0.016874650227172033, 0.023903772600793412, 0.06794334668666124, 0.013995347095520368, 0.07245105837604829, 0.0329136540448027, 0.011297193305966045, 0.05048105459926384, 0.002451998248164143, 0.022181257173152905, 0.10741906200668641, 0.037177500248487504, 0.08635496015527419, 0.11303175440324204, 0.0651996156999043, 0.04618434355195079, 0.08803138269909791, 0.04091725618179355, 0.019050874880381992, 0.022538156414936696, 0.015293717916522707, 0.009213735415999378, 0.031080958100834062, 0.03774539673967021, 0.06603164891047136, 0.059065570921770165, 0.06228616274893284, 0.054055417621774335, 0.02363317962070661, 0.010789907803492886, 0.011650727862226111, 0.037582463518317254, 0.039759149575339894, 0.0464044331705996, 0.02522011018092079, 0.044063022559774775, 0.038071839937141964, 0.024228650078709637, 0.012222536955960095, 0.01663576009949403, 0.025440357558961426, 0.12652126806122915, 0.03418054338544607, 0.06297100814325468, 0.056986987457743714, 0.03049777082300612, 0.025446040289742605, 0.04168378022898521, 0.031207715227667774, 0.03302964621356555, 0.06666434888861009, 0.03532457717561296, 0.02993673432086195, 0.02969279758898275, 0.03928142021011029, 0.025561779704211012, 0.03277655943695988, 0.03798287042549678, 0.01744367478282324, 0.016677099845505187, 0.034582914651504586, 0.03170954954943486, 0.027197008387052586, 0.05429664021357894, 0.012549606950155326, 0.00763594896333026, 0.008150000308108116, 0.01545422537518399, 0.013493440679407545, 0.05632309183212263, 0.040941825934818814, 0.046868391667625735, 0.04187429929152131, 0.06012400412665946, 0.055531448418540616, 0.024347453078787242, 0.015610916074365377, 0.028896194084414413, 0.065400380641222, 0.015291455002235515, 0.06143044188086476, 0.03014270362577268, 0.016633091760533195, 0.02515006670728326, 0.022618596741397465, 0.027937951664041196, 0.029326280113309622, 0.039183741701500754, 0.11424036776380879, 0.03849722711103303, 0.051271703959043534, 0.060412347582834106, 0.009370412544480391, 0.055710059191499434, 0.039255768193730285, 0.030020180557455336, 0.02966090983578137, 0.0343331459111401, 0.025262567813375165, 0.05213580134191683, 0.016444301265957098, 0.04522161092609167, 0.032816352123128514, 0.05849535044814859, 0.023108188595090593, 0.024470113550445864, 0.06437896830695015, 0.01342101045884192, 0.013499109839488353, 0.03923189393909914, 0.03594573866575956, 0.05551757577008434, 0.03533320814105017, 0.020171005578179444, 0.04071200951667769, 0.025342270233003155, 0.06892551255545445, 0.025100995054734603, 0.017179901079673852, 0.046157521062663624, 0.03199725518269198, 0.022319199949769036, 0.0746268555521965, 0.020083606875102435, 0.0930281485031758, 0.021958427969366312, 0.029447965190878937, 0.03382651773946626, 0.09829330883388009, 0.02731295645103923, 0.02369783043728343, 0.021261526704100624, 0.009678118845580943, 0.061076368737433634, 0.02678836406474667, 0.09397295423384223, 0.04297967015632561, 0.033149312649454386, 0.014995186257043054, 0.02247723754096244, 0.03876234770619443, 0.01970434990445418, 0.011399346753023565, 0.014040949737786182, 0.028399715100282004, 0.014940501423552632, 0.024131361727735827, 0.018435433440442597, 0.024200577388650606, 0.045045992492565086, 0.03130065416917205, 0.017625691801575676, 0.05131722687344466, 0.06445860796208892, 0.028333049034699798, 0.07142132041709763, 0.021122443988653164, 0.06354233462895666, 0.05352750041389039, 0.07871818422738995, 0.004118999333253929, 0.044432545945580514, 0.021479428047314286, 0.07214377022215299, 0.021087655498247062, 0.029549911684755768, 0.047477716114372015, 0.047638952998178344, 0.016535598152716244, 0.01280974455377353, 0.05696204451045819, 0.02354802856487887, 0.01553870807401836, 0.0275629066995212, 0.04054086941427418, 0.03863288661731141, 0.02989105534340654, 0.03643613288711224, 0.005814793627775673, 0.01885789443206574, 0.048651283141225576, 0.031875715990151675, 0.020781383450542177, 0.04617497298334326, 0.00688364658604509, 0.028414398598085557, 0.04807279471840177, 0.02828592647399221, 0.031043703135635172, 0.04719466183866773, 0.025268876492711048, 0.0075967135240456885, 0.050047199308340035, 0.07611056736537389, 0.012380168274311083, 0.06553089006670884, 0.020648824849299023, 0.07773323636502028, 0.057489266219948015, 0.036896820845348496, 0.06387046059327466, 0.03089769257764731, 0.041249361753995926, 0.027434746701536433, 0.031751384626009634, 0.05273932770692876, 0.09860105839158807, 0.03637889845828925, 0.046587980285819085, 0.014250560231240732, 0.041351650908057175, 0.11550221219658852, 0.05306339942451034, 0.021801942527028065, 0.005309130672165858, 0.027952972733016525, 0.03535791699375425, 0.06866901274770498, 0.02565870843162494, 0.015933698575411524, 0.036218034768743176, 0.06032796496791499, 0.021709268214181066, 0.032430099456437995, 0.031822491703288894, 0.0035511700594465113, 0.02814607022862349, 0.05763339384325913, 0.02276468533091247, 0.02272432776434081, 0.012092252295198185, 0.018409408229802336, 0.05789211246051958, 0.021716572643656815, 0.021957523821453964, 0.04619126460914101, 0.03119581372344068, 0.02560542816562312, 0.015102077574868287, 0.0797419985756278, 0.01654583215713501, 0.01537391566671431, 0.05638865867097463, 0.025153337246073142, 0.020810446801728437, 0.035050455813429186, 0.025849373379190053, 0.027461533567735126, 0.03684412581580026, 0.058780749062342305, 0.02273177638250802, 0.04189386824145913, 0.019168062967115214, 0.037525860127061605, 0.018932596048606292, 0.08106576611420938, 0.037561700346746614, 0.010092205866905195, 0.015207389602437615, 0.03826504599835191, 0.006023182334112269, 0.02263007076856281, 0.031349569758666415, 0.03029614074953965, 0.013401184513765787, 0.025162833343659128, 0.025171806969280754, 0.021689527934151034, 0.023177231229575615, 0.02285392116755247, 0.05157431022131017, 0.039650760391460996, 0.021767478037093366, 0.026317577809095383, 0.015089478875909532, 0.06173494125583342, 0.058528496883809566, 0.007978970467645143, 0.09324349516204425, 0.03230858401262334, 0.0016777607421058097, 0.01887521912742938, 0.05751670617610216, 0.014744879777676292, 0.029690351470240524, 0.039939962194434235, 0.17075221107474395, 0.14091049879789352, 0.174242106665458, 0.12205559840159756, 0.13508687700544084, 0.07762319155569587, 0.11494866332837514, 0.15039660834840365, 0.10454710825745549, 0.16140940812017235, 0.16925621777772903, 0.21091643587819167, 0.17632254931543553, 0.1508098090333598, 0.25699760818055695, 0.14189331606030464, 0.13647974655032158, 0.08585310887013163, 0.20447560506207602, 0.11946667517934527, 0.0881782787452851, 0.08250319505376474, 0.06653855528150286, 0.15518378147057124, 0.09068425784685782, 0.22976764504398617, 0.20922843074159964, 0.11049651008631502, 0.14729023432093008, 0.14345231811915124, 0.0864014398040516, 0.18011450155505113, 0.12828045152127743, 0.17974440141447953, 0.17625054317925656, 0.06737114489078522, 0.10403129950697933, 0.10391349904239178, 0.11842209765953676, 0.12961374569152082, 0.10694858618080616, 0.10529948824218341, 0.08963153790682554, 0.1171039483909096, 0.14864526875317097, 0.1202620267868042, 0.09486672056040593, 0.1004177951919181, 0.25676367644752773, 0.2276994160243443, 0.16200487688183784, 0.10906424479825155, 0.18097678385674953, 0.10578527181808438, 0.0971693020047886, 0.11847187498850481, 0.14864852572126047, 0.1226396949163505, 0.13265227978782995, 0.08719482365995646, 0.1597161375518356, 0.14244960620999336, 0.11294787390423672, 0.09534140330340181, 0.17215143170739922, 0.08870227062808615, 0.10325124207884073, 0.08724436350166798, 0.10330669196056468, 0.11141988089574234, 0.13474207265036448, 0.09237700594323021, 0.10852314026228019, 0.18262383261961596, 0.12345753317432744, 0.1210555327790124, 0.1542526957179819, 0.12117466995758669, 0.11805521377495357, 0.10822554837380137, 0.1583895337368761, 0.10090377554297447, 0.23258152976632118, 0.13103839781667503, 0.05571563335667763, 0.18081777596047946, 0.08538156095892191, 0.14667112539921487, 0.11481934812452112, 0.17517674794154509, 0.1564387319875615, 0.17811004125646182, 0.1723132487386465, 0.11808273515530995, 0.10874149961663143, 0.09592186287045479, 0.19486482148723944, 0.11447590083948203, 0.10318813153675624, 0.21903726511767932, 0.15986221257065023, 0.12444830286715712, 0.1987357959151268, 0.07068839403135435, 0.095680779378329, 0.08050459051238638, 0.0669104874666248, 0.27461262153727667, 0.12992422974535398, 0.15822283125349454, 0.11332623860133545, 0.1068383649523769, 0.08746705869478838, 0.1417708269187382, 0.08504462761006185, 0.08724027872085571, 0.18613706981497152, 0.08117037585803441, 0.11823962602232184, 0.11425591978643622, 0.15635118739945547, 0.1357936526515654, 0.12249071576765605, 0.11910637308444295, 0.170356082330857, 0.1574474150048835, 0.1348869941596474, 0.1727269243981157, 0.1392384935170412, 0.231699352817876, 0.12940812243946961, 0.11084335683179752, 0.09210380060332161, 0.09604883712849446, 0.08650100803268806, 0.14269123253013405, 0.11936460994184017, 0.1293148917279073, 0.10752420779317617, 0.14440310852868216, 0.07279005447136504, 0.17190276219376496, 0.11619211946214948, 0.13486472464033536, 0.13081572976495537, 0.11958514739360128, 0.07651871974979128, 0.17692906462720462, 0.08922481044594731, 0.0829418475872704, 0.09224160428025893, 0.12316443318767206, 0.1212855154382331, 0.1506234018930367, 0.2605237646826676, 0.1342831929879529, 0.10260505282453128, 0.08191856928169727, 0.11324482118444783, 0.12223489449492522, 0.13045580764966352, 0.12826933711767197, 0.076346968965871, 0.1415936614253691, 0.1548023633658886, 0.09190774469503335, 0.14149410676743301, 0.15702672329332146, 0.2129688821732998, 0.16874044973935398, 0.06405974472207682, 0.15431909715490683, 0.19820967343236717, 0.10224072701696839, 0.08826986740210227, 0.06843818191971097], [0.014333470425169383, 0.027782850433140993, 0.03175243974796363, 0.0719179944800479, 0.01996389463809984, 0.0545962202096624, 0.07584688187177692, 0.028235280620200292, 0.06524263482008662, 0.03922103059345058, 0.028533863169806342, 0.009472520190424152, 0.03366867692342826, 0.09767787078661577, 0.01553730181019221, 0.015062695402385933, 0.04568694345653057, 0.021342615031504204, 0.07989749166050128, 0.0407173258385488, 0.05333972263282963, 0.03992751446951713, 0.019758737878873944, 0.02038350238996957, 0.031041236660842384, 0.049658140899347405, 0.03898098525990333, 0.022881736014304415, 0.03118505555072001, 0.053174214371080906, 0.033783556294760535, 0.02724766102619469, 0.05861416871526411, 0.04254084120371512, 0.04074645534689937, 0.01401253608388028, 0.011043858864078564, 0.020043995697051287, 0.04548885872853654, 0.01805371847668929, 0.02762277384421655, 0.03519094648904034, 0.019176290204216326, 0.057789809735757966, 0.03660811437293887, 0.021299090402733003, 0.008128335533131446, 0.016883773130497763, 0.026601992547512054, 0.05028895455013428, 0.04576426252190556, 0.017938136821612716, 0.021609026539538587, 0.02239181676746479, 0.05010786033900721, 0.0358613255167646, 0.015213452312829239, 0.03132876926766975, 0.10910293486501489, 0.0034428453363943845, 0.012512611524601067, 0.01100225788208523, 0.052871265448629856, 0.027683417911508253, 0.04067136526906064, 0.05614417911108051, 0.01810001322467412, 0.05185464017891458, 0.02836040247763906, 0.01744167140818068, 0.03297928873715656, 0.06387231977922575, 0.02248322730883956, 0.009620234719477594, 0.06777794699051551, 0.02486930587994201, 0.008565653897156673, 0.0437990419034447, 0.0519493127773915, 0.019650331731619577, 0.04856203203754766, 0.004489350955866809, 0.07824329113853828, 0.038184849944497855, 0.0972182040235826, 0.01920810162222811, 0.004371783737691918, 0.05575203336775303, 0.006285496338802789, 0.01938650883468134, 0.06398511265537568, 0.030087894959641353, 0.020978477517408983, 0.012525303522124887, 0.04963993241212197, 0.06054318270512989, 0.032181233167648315, 0.037053776173187156, 0.04892548932028668, 0.12404743794884, 0.030368594718830924, 0.03365721985963838, 0.0867754550916808, 0.02171602303029171, 0.018361634275476848, 0.0367522318182247, 0.07266967557370663, 0.042273603579295535, 0.036486802489629815, 0.05711142399481364, 0.00862607913690486, 0.01326628666304584, 0.01636728923767805, 0.05692872165569237, 0.01532693559836064, 0.04754183767363429, 0.028885666613600085, 0.030766986377005066, 0.00755676392665399, 0.0004431769573004983, 0.029758242291531393, 0.019480065243052583, 0.045408879805888445, 0.07648475907210793, 0.005928353672581059, 0.03031490902815546, 0.08326591591217689, 0.03567334756787334, 0.05470257718116045, 0.041521684998380284, 0.07679127369608198, 0.025932334463245103, 0.055514271304543526, 0.002857543361772384, 0.07546656977917467, 0.031143485102802515, 0.012576097805452133, 0.04522601801103779, 0.041376665101519654, 0.03372065270585673, 0.029104653612843583, 0.017449338853891407, 0.02642134277682219, 0.03319254211549248, 0.07252981593566281, 0.029255481769463847, 0.04256370783384357, 0.03812187850209219, 0.053506330121308565, 0.014546701751117195, 0.06566213231001582, 0.021341022170547928, 0.0169430431643767, 0.06381473929754325, 0.031696277404470105, 0.022408451053446958, 0.11210704009447779, 0.04135383579081722, 0.024217228638008237, 0.02305834850163332, 0.01715134154073894, 0.029099371217723404, 0.06694650410541467, 0.027367541200614402, 0.03342800733766385, 0.025813548426542963, 0.08259907205189977, 0.11716897918709687, 0.0548785145261458, 0.039056438353977034, 0.03444214238386069, 0.03028072104124086, 0.029794157150068452, 0.04232550472287195, 0.050932819822004864, 0.05651643360033631, 0.015941946168563197, 0.05500224877947143, 0.04147745469318969, 0.029682334578995193, 0.055138739491147656, 0.03872101813820856, 0.03323629405349493, 0.044989473918186765, 0.0018457819158876581, 0.007504153713983084, 0.012249507026613822, 0.019845022088182823, 0.05025135013940079, 0.027128912308918576, 0.05182980579723205, 0.012845912166605038, 0.012143213667773774, 0.0073450397966163495, 0.033577451282846074, 0.09066889581403562, 0.0655457703396678, 0.02526057292042034, 0.07315359996365649, 0.00905549171979406, 0.005767034516403717, 0.05680961161851883, 0.06294461991637945, 0.01405344920099846, 0.03211539152211376, 0.07170888355800084, 0.054533615176166804, 0.024440130784309337, 0.05422130925580859, 0.06911187219832625, 0.025689697125926614, 0.03945864337895598, 0.03490369886692081, 0.020366942742839456, 0.014675528409757783, 0.0344618165067264, 0.09457862816218819, 0.03503201323162232, 0.019505632442555258, 0.09803431201726198, 0.030923300489251102, 0.013286264430332397, 0.040203196462243795, 0.06526158630315747, 0.020582028165725724, 0.026121688141886677, 0.04277156685878124, 0.030251269228756428, 0.03525123093277216, 0.021851774138797606, 0.021837151709145734, 0.027365071333146522, 0.014181126590951212, 0.03466527183939304, 0.034769633917936256, 0.008347141024257456, 0.014457706794408815, 0.038930091740829606, 0.03218616611723389, 0.019282273981454115, 0.029747375553207736, 0.02261257135043187, 0.020644460172791566, 0.03679090831428766, 0.04824314432750855, 0.02247640972823969, 0.023701784600104605, 0.022222218635891165, 0.008522941814070302, 0.018766855388613682, 0.04503621141027127, 0.005514326871239713, 0.00950525950507394, 0.014867737024490322, 0.030527205672115088, 0.05007276311516762, 0.02793700510769018, 0.06137904963855233, 0.054191307829959054, 0.05482073387663279, 0.062330491441701136, 0.026162593625485897, 0.05430080641859344, 0.07348873519471713, 0.03140412736684084, 0.05079671926796436, 0.04966162856934326, 0.06070691320512976, 0.01958927884697914, 0.04652475439278143, 0.008042896948089557, 0.04002192243933678, 0.025640588153951933, 0.035128314314143996, 0.018837590967970233, 0.030572067014873028, 0.03957868300910507, 0.04087153309956193, 0.0034546702933896866, 0.04588401038199663, 0.025665095142487968, 0.0628098967884268, 0.028123432604063834, 0.06987462019813911, 0.047726093857948265, 0.0296012530369418, 0.016860131274110506, 0.015441307764766472, 0.04644882971686976, 0.05777103467179196, 0.07424836193344422, 0.03366364558626499, 0.019034562898533683, 0.030784241522529295, 0.059915096765117984, 0.031523471498595815, 0.019221102353185415, 0.022276279217164432, 0.014055646806290107, 0.018283494182729294, 0.013909017933266503, 0.034023404853152375, 0.07542605445321117, 0.016085732828027437, 0.044209558982402086, 0.04972426752958979, 0.038931170611509254, 0.025269992682816725, 0.11671992471175534, 0.02973475480186088, 0.04283164095665727, 0.048359794675239494, 0.022714892734906504, 0.030161190312355757, 0.02193689126787441, 0.018809669251952852, 0.03722456343738096, 0.02570325934461185, 0.08265002324645009, 0.05120852556345718, 0.029292299079575708, 0.018256544468126128, 0.046108412090688944, 0.004261755467658597, 0.058288600827966414, 0.032676743543041606, 0.00758747018075415, 0.035772437429321666, 0.021770877497536794, 0.09328087565622159, 0.014618617981406195, 0.025498426585857357, 0.05250040874151247, 0.029257052578032017, 0.0419284226372838, 0.009916119244215744, 0.024362411383273344, 0.05748138164303132, 0.02046677390379565, 0.02613511974258082, 0.025320156776745404, 0.005225748896399247, 0.00840203620360366, 0.027997382849987065, 0.006177831066971911, 0.027965644374489784, 0.045487226851816685, 0.04109214519017509, 0.07909747173211404, 0.01845064789189824, 0.04496454793427672, 0.043451988204781494, 0.1122660276346973, 0.15240720260356153, 0.1287514633898224, 0.18955337149756296, 0.10441289403076683, 0.17402314341494016, 0.17831182400030748, 0.11869340310139315, 0.13549797423183918, 0.08996166554944855, 0.10403503823493208, 0.12420845430876527, 0.10266221261450223, 0.19130251263933523, 0.11535841705543654, 0.09230302527014698, 0.12972159204738481, 0.06869261219565358, 0.11151544576776878, 0.11455471946724824, 0.150972168892622, 0.06796342453786305, 0.13028978370130062, 0.07523818846259799, 0.12634961227221148, 0.11295602989516088, 0.17808694392442703, 0.07933182415685483, 0.17882084740059717, 0.1585200024502618, 0.07728147453495435, 0.08154841485832419, 0.08330753046487059, 0.20464407173650606, 0.14606063387223653, 0.12090316095522471, 0.0705965000337788, 0.03563282545655966, 0.08468236454895564, 0.07617526567940201, 0.20245310930269106, 0.20680912770330906, 0.15872721347425664, 0.21702386172754423, 0.09333743833537612, 0.15522693629775727, 0.11266931492303099, 0.15428131632506847, 0.11256431841424533, 0.17525040970316955, 0.16429234056600503, 0.10283456050923892, 0.06732959819159337, 0.13720101570444448, 0.141858290082642, 0.08013044630310365, 0.10273252919848476, 0.11075795641435043, 0.2506517858377525, 0.10090144138251032, 0.07564541803939001, 0.14877157126154217, 0.12298520494784627, 0.0699238275576915, 0.15442446007260255, 0.10773008888853447, 0.12395556430731501, 0.13384990766644478, 0.10190476397318499, 0.060982439134802134, 0.1035071447757738, 0.20304669173700468, 0.08458042823310409, 0.09043399377592973, 0.19437950610050134, 0.13485812927995408, 0.0890997089445591, 0.07425632793456316, 0.11594963818788528, 0.09764250554144382, 0.09007551694022757, 0.11423223891428538, 0.12923293826835497, 0.13187798990734986, 0.140496375305312, 0.1197971895869289, 0.2346511972802026, 0.2189471149551017, 0.16434724761971406, 0.16665959996836527, 0.11546814973865237, 0.10859661203409944, 0.11087143461086921, 0.14203423421297753, 0.11873978775526796, 0.18385299880589756, 0.0812970854874168, 0.078762540061559, 0.28538721480539864, 0.25359801203012466, 0.10645066361342158, 0.17983917918588432, 0.12181220789040838, 0.17212306894361973, 0.11134305037558079, 0.12724510207772255, 0.16652045957744122, 0.11320024143372263, 0.1397745090403727, 0.09847511550677673, 0.1519314952726875, 0.1052690220198461, 0.08808224568409578, 0.13070014810987882, 0.17206889470773085, 0.13091299097452844, 0.1692671286208289, 0.09178691117891244, 0.12131303681858949, 0.07878093514591455, 0.06474271057439701, 0.1078618128917047, 0.15020188236875193, 0.13150858187249728, 0.15103173069655895, 0.0982174893308963, 0.19651965983211994, 0.18122944315629347, 0.17835525024150098, 0.10970814738954816, 0.14356367928641184, 0.13128231758517878, 0.09017046434538704, 0.07141679458852325, 0.25479475781321526, 0.1436662466398307, 0.1681632607110909, 0.07692611896033798, 0.1584341541997024, 0.11802738026848861, 0.07759368885308504, 0.10251274492059435, 0.1521658884095294, 0.17463371636612074, 0.242861308157444, 0.17494467539446695, 0.1269779899822814, 0.08183013581271682, 0.14332110301724502, 0.083924318796822, 0.11923738462584359, 0.09780538108732019, 0.09434293223811047, 0.16590213775634766, 0.1336458179035357, 0.10118258558213711, 0.18598198385110923, 0.10610444790550641, 0.20541215980691568, 0.08533494560314075, 0.08886599434273583, 0.10888741178704159, 0.16732950402157648, 0.0701598831053291, 0.08209424878337554, 0.09372601498450552, 0.24964516556688718, 0.17515009508601256, 0.15644778364471026, 0.22015154175460339, 0.09273360323693071, 0.13371616841426917, 0.12646615744701453, 0.1180058978497982, 0.12086599080690316, 0.07605116162449121], [0.023248475710196153, 0.02730209649806576, 0.039591154482747824, 0.070978847731437, 0.08681936987808772, 0.011734727953028466, 0.039250604542238374, 0.019295946462079883, 0.03378591759662543, 0.04849607504105993, 0.04659908790407436, 0.03273055476269551, 0.04495298909023404, 0.028160349998090948, 0.03741433271872146, 0.026004065792741518, 0.08896091460649456, 0.013143433657075678, 0.040176068632198234, 0.03475111669727734, 0.013987480330147913, 0.046320895331778696, 0.038120273766773086, 0.025205687919099416, 0.026854894423325146, 0.022863517349053706, 0.04385387771097677, 0.05479288001411727, 0.010280171941433634, 0.024756565590256026, 0.05900695228150912, 0.06823956793440239, 0.04271960125437804, 0.02144872603405799, 0.020763704220631292, 0.0354840498683708, 0.030000520005289997, 0.09897022215383393, 0.01513048613976155, 0.017196657501959374, 0.028092867994148816, 0.0028511886692805482, 0.08727852095450674, 0.037240454727517705, 0.05796577422214406, 0.04568626831418701, 0.021312248893082142, 0.03196002735889383, 0.01978894116889153, 0.0372461306729487, 0.02236156937267099, 0.03965327436370509, 0.049127743645970307, 0.05492953357419797, 0.03613656646172915, 0.02278303970316691, 0.02895476861989924, 0.039405537835721455, 0.03136272655267801, 0.06961217642362628, 0.06946148058133465, 0.03263202129996248, 0.02816859250222998, 0.05220619595742651, 0.03284072170832327, 0.02684876725210675, 0.030619958016489233, 0.027937028856415833, 0.008152166531155152, 0.05992767001901354, 0.023238574187936525, 0.04567662972424712, 0.011827381909824908, 0.08906762780887739, 0.035144928244075606, 0.06724020798823663, 0.021117986013580645, 0.08937075654310839, 0.05227098248100706, 0.03413244203797408, 0.0707999180470194, 0.06465854509068386, 0.01834729852687035, 0.01453461534609752, 0.028633343188890388, 0.006747584199599389, 0.0499882278298693, 0.07134459846253906, 0.015600207095433558, 0.029471367863672118, 0.0031288017302618493, 0.06526336406490632, 0.008989085193856486, 0.008115540059017283, 0.03585566992738417, 0.04475216308076467, 0.07795880854661975, 0.060261563530990055, 0.04085236448528511, 0.018530095860894238, 0.05732006672769785, 0.0011332726488555117, 0.04375447572341987, 0.06488510793341057, 0.028746712819806168, 0.032748502013938766, 0.03998399233179433, 0.05234359929870282, 0.01804762183954673, 0.05412753571623138, 0.03256934841296502, 0.019633261486887932, 0.028636393203799213, 0.02830917478006865, 0.014848804201132484, 0.045512953507048745, 0.07689878756978683, 0.021459336625412107, 0.03974982650418367, 0.03993334647800241, 0.020909092222739543, 0.06127505736159427, 0.022891566290387085, 0.01909937825985253, 0.06420683754341942, 0.044688696307795386, 0.02955158766625183, 0.01457710690530283, 0.03942515428311058, 0.06615691326026406, 0.04461760958656669, 0.03125369615320649, 0.00998934674342828, 0.015538501120837671, 0.026840209229184047, 0.014852344457592283, 0.06006725145769971, 0.05350667956684317, 0.027766394262601222, 0.038970529035265954, 0.01219420218175011, 0.01381740637589246, 0.026971658425671712, 0.02536367122749133, 0.036907456881765804, 0.034526921941765716, 0.02061505925043353, 0.00856423151812383, 0.057685023572828086, 0.05513285319986088, 0.026649237244523, 0.045373714728546996, 0.048327733895608356, 0.015510922065004706, 0.00930283300112933, 0.010779141149084483, 0.011809810397348233, 0.10530665357198034, 0.053967452341956754, 0.016632433581565107, 0.05448559186022196, 0.017302174786371843, 0.04181062217269625, 0.046674876872982295, 0.031740368609981875, 0.03551394272861736, 0.01183398235921881, 0.019559577672875354, 0.04131292012919273, 0.021881943502064263, 0.040951983604047976, 0.04772595136559435, 0.041129427296774726, 0.07228295132517815, 0.06130461434700659, 0.018756550138017962, 0.022321776686502353, 0.02215126253265355, 0.060444788342075687, 0.030073221639863083, 0.04693434187876327, 0.032877661154738495, 0.03480044619313308, 0.03863588234941874, 0.005995701241772622, 0.050286060598279746, 0.037281105760484934, 0.0015379680033739923, 0.024136988479377966, 0.06102971266955137, 0.0177948895974883, 0.05273352623251932, 0.040449633595666716, 0.065031685068139, 0.04784308686586363, 0.01517500142965998, 0.023644663825897232, 0.05804998041795833, 0.041809862213475366, 0.014810181987871016, 0.077908786945045, 0.0193161193081843, 0.010867370209390563, 0.024730430117675235, 0.04299367172643542, 0.024060712661594152, 0.041231529853705845, 0.06357922657792058, 0.059410965602312765, 0.022295895664553558, 0.02187793336010405, 0.03851449582725763, 0.03482179969016995, 0.02957758234281625, 0.015813477437144945, 0.01777524091968579, 0.026643540943041444, 0.035239936717386754, 0.009219489392957516, 0.059881034307181835, 0.020553600941119448, 0.028771516667412858, 0.02212471654638648, 0.04071874736941286, 0.04004778480157256, 0.09343509988061019, 0.03290126399536218, 0.0314127311908773, 0.03642870292865804, 0.003336615802254528, 0.03651393710502556, 0.054765141502554925, 0.024493270254294788, 0.048120712861418724, 0.07951251124697072, 0.046980017463543584, 0.04430602291332824, 0.03477308087583099, 0.02708929943452988, 0.0736972422205976, 0.08320519381335803, 0.019431024124579768, 0.06531555019319057, 0.01730628331590976, 0.009481213072181811, 0.022089510756943907, 0.03296610140906913, 0.029487761269722666, 0.01271051389630884, 0.07380460681659834, 0.021064905915409327, 0.08572019743067877, 0.06310447598142283, 0.061229588729994636, 0.04736393936244505, 0.017970869350912314, 0.027780199057555625, 0.08130388440830366, 0.010654639303019004, 0.02065206315767552, 0.03259083761700562, 0.07648104070020573, 0.029857267692152942, 0.0384647083202643, 0.0511380834504962, 0.023482553328254392, 0.011415626504458487, 0.021333100274205208, 0.03878014228705849, 0.01786233258566686, 0.07431153354368039, 0.07496771083346435, 0.06977283994534186, 0.05360618672732796, 0.013223893491418233, 0.04823524278721639, 0.05098868361009019, 0.06646395035620246, 0.05459584701540215, 0.06651612969913653, 0.034156940544822385, 0.08199432771652937, 0.02013789815828204, 0.06334047724625894, 0.058398007814373286, 0.05117892108059355, 0.039186306563871245, 0.04910464631393552, 0.01064376238667007, 0.05899447402251618, 0.05803794999207769, 0.01897999850500907, 0.05004265990906528, 0.03611817477004869, 0.02337749914399215, 0.06102321230407272, 0.07741015191589083, 0.02211956476925739, 0.01736782644210117, 0.015222032388140048, 0.01840501810823168, 0.0617196402911629, 0.005314051323304219, 0.005021927154822541, 0.06152592532868896, 0.060905696824193, 0.0261687174040292, 0.06973958494407789, 0.014998483937233686, 0.012291738198005726, 0.020624244918248484, 0.018437923663961034, 0.02596252757523741, 0.020734895320077027, 0.01981946167403034, 0.038944975406463654, 0.044862452162695785, 0.05020744553101914, 0.05767957493662834, 0.029879170802554915, 0.027981991979426572, 0.01719552943749087, 0.023779481948752488, 0.017302832965339934, 0.015283282047935894, 0.018055221431755593, 0.016775059946147457, 0.06360794896525995, 0.02379520021245948, 0.0856962858566216, 0.039449897062565596, 0.05054412103657212, 0.019923674474869455, 0.045456604566425085, 0.04515543340572289, 0.014588762440585663, 0.006437956796227289, 0.03230379694806678, 0.027194372278505137, 0.04020954755001834, 0.05104024548615728, 0.033175561776650805, 0.03760176444692271, 0.02288648915211005, 0.01892537813234542, 0.07477717820022788, 0.03814533545768686, 0.03772575993623052, 0.02025398701828505, 0.0060563631206085634, 0.03436810064262577, 0.00037516956581384875, 0.16686948442033359, 0.05591604545978563, 0.10096457228064537, 0.07581611030868121, 0.13577240093478135, 0.12793966409351143, 0.11503896276865687, 0.0881936950609088, 0.11040992223258529, 0.078510315024427, 0.094379518846316, 0.09566788721297469, 0.11075465873415981, 0.1879285786833082, 0.1377992257475853, 0.15020188236875193, 0.19496430829167366, 0.15559709072113037, 0.11038223121847425, 0.13281557602541788, 0.1441674940288067, 0.18681390849607332, 0.12180368549057416, 0.09875149639057261, 0.16093501714723452, 0.1574948038905859, 0.0802552763904844, 0.10827825697404997, 0.1079288317954966, 0.09929611573794059, 0.11580684727856091, 0.18839701211878232, 0.09553572216204234, 0.10144219986562218, 0.10646369148577962, 0.08956179129225866, 0.17456050243760857, 0.11806890661162989, 0.16562249990446226, 0.12439848482608795, 0.09976761615169899, 0.10252898226359061, 0.10179457667150668, 0.09263293578156404, 0.1722635935459818, 0.13700236779238495, 0.1065052721117224, 0.09051842388830014, 0.15715169587305614, 0.21694264108581202, 0.11207008029201201, 0.08227564154991082, 0.12743753460901125, 0.15701077772038324, 0.14451753667422704, 0.11888553707727365, 0.12369043353412833, 0.15125389663236483, 0.10138826990234, 0.10728523454495839, 0.10622622458530323, 0.13179096100585802, 0.06933169040296759, 0.17836089565285615, 0.13483208710593836, 0.07975850054728133, 0.12969610627208436, 0.057466019610209126, 0.06317437865904399, 0.17313510392393383, 0.10752483883074351, 0.20316173056406633, 0.1684663351625204, 0.20236082854015486, 0.1405097424451794, 0.15590836187558516, 0.1458103765866586, 0.12571259002600396, 0.11426468645887715, 0.10197304495211158, 0.18484287283250264, 0.13825917749532632, 0.08579508055533681, 0.046282334186668904, 0.14719975846154348, 0.15746042930654117, 0.10640236549079418, 0.18196535509611877, 0.13074301795235702, 0.12798013192202362, 0.0582516613815512, 0.17837119581443922, 0.17335222155920096, 0.13348488296781266, 0.11814060062170029, 0.17447717833731854, 0.1537144681704896, 0.1093581590269293, 0.1171025913208723, 0.11531751496451241, 0.13050878766391957, 0.21344140038958617, 0.12076570333114692, 0.20664542434470995, 0.13852419970291002, 0.21952769665845803, 0.14347517117857933, 0.2595253139734268, 0.13387517631053925, 0.08239025968526091, 0.1842066783990179, 0.17831882648169994, 0.18795605935156345, 0.1472533627280167, 0.11296909847962004, 0.11202448952410902, 0.17701804770955018, 0.16727397271565028, 0.14700168051889964, 0.16160280417118753, 0.14078457626913274, 0.09087603219917842, 0.09648375093404736, 0.12368064905915942, 0.10344793581004653, 0.15537644470376627, 0.14481728630406515, 0.11077316916946854, 0.1427841375448874, 0.13048189053578035, 0.14010126436395304, 0.1632742259119238, 0.09197532678289072, 0.08615872782788106, 0.10353214879121099, 0.09390554177973952, 0.1523183009454182, 0.09767894965729543, 0.062030667173010964, 0.10894035787454673, 0.12973422636943205, 0.20435962985668862, 0.178865413580622, 0.13469096539275988, 0.10566012960459505, 0.14452747042690003, 0.09455737644540411, 0.1843774520925113, 0.07196015864610672, 0.08500411228409835, 0.1198370060218232, 0.16718481321419987, 0.1267605195088046, 0.10613975208252668, 0.10978621284344367, 0.12594026566616126, 0.06270312930324248, 0.15905172963227543, 0.175373590950455, 0.062147958736334524, 0.13642273603805474, 0.10868609044700861, 0.12328116835228034, 0.09763886859374386, 0.20075628321085656, 0.093577069762562, 0.12880726610975607, 0.10074705430971724, 0.09950367281479494, 0.17069742615733827, 0.18620020071310656, 0.14477210944252356, 0.1848748589732817, 0.13155457297606127, 0.10927403425531727, 0.10771542574678149], [0.06329032672303063, 0.0863190588674375, 0.030920236903641905, 0.024314477973218476, 0.014776246755250862, 0.02346428038020219, 0.02855429725189294, 0.028478895047945634, 0.07749684154987335, 0.03425408301076718, 0.034124991723469326, 0.03703164914622903, 0.02197496047509568, 0.03248994963775788, 0.04541354473414166, 0.06125655371163573, 0.031971257113452466, 0.028154609591833184, 0.020955534552090933, 0.0843130922211068, 0.034394264952944856, 0.02573771874553391, 0.044646281083779674, 0.016675634209864905, 0.05007395733680044, 0.028109736374712417, 0.01702884222114725, 0.016267532715573907, 0.040713108743407896, 0.041075365019163916, 0.0278510228464646, 0.0420393732908581, 0.05072346802002617, 0.041610515410346646, 0.020253252504127364, 0.04536864607195769, 0.02623692374410374, 0.052818319361124716, 0.01814009598456323, 0.013306670522849475, 0.05071451135778001, 0.016628879754404937, 0.09199980832636356, 0.034135498838233094, 0.03171930009765284, 0.02014272254226463, 0.04113604640588164, 0.049096018741173406, 0.018470067564131956, 0.04135836161939161, 0.02139117439011378, 0.03165698004886508, 0.03705522484545197, 0.01015428249125502, 0.04024716213877712, 0.035830486100167036, 0.030977878453476087, 0.03291701279314501, 0.027992000370951634, 0.059928721748292446, 0.03948679240420461, 0.04032293753698468, 0.018603825476020575, 0.02066612409959946, 0.030561213847249746, 0.009744483811248626, 0.03393976523407868, 0.06034927775285073, 0.02326347303044583, 0.029568574790443693, 0.029355256951281, 0.026761212485975454, 0.03559444073055472, 0.04901406528162105, 0.04274316677557571, 0.020469893468543887, 0.03505820468334215, 0.028579114670200006, 0.06644299040947642, 0.015250128826924732, 0.005991400602007551, 0.021864025088559304, 0.026856365147978067, 0.02001279665689383, 0.05888138259095805, 0.06641692109405994, 0.017713265227419988, 0.018601199545498406, 0.07744969015142747, 0.0593709388215627, 0.04764478500666363, 0.037403455802372525, 0.051507253998092244, 0.03846766673294561, 0.033766324897961955, 0.05309572144012366, 0.05044199473091534, 0.028910864011517594, 0.0221197360993496, 0.025625395754884397, 0.026959268376231194, 0.051302031081702025, 0.05968780788992133, 0.058354439080825875, 0.0242543224511402, 0.03914043420393552, 0.03106329244162355, 0.05782307830772229, 0.040587430487253835, 0.024647691253838793, 0.011971675774215587, 0.04169739503413439, 0.03744626457669905, 0.0288111566832023, 0.03210895222478679, 0.016407424584031105, 0.05306039351437773, 0.08263221170221056, 0.016325846015076553, 0.03296276640945247, 0.018346665792965462, 0.03913930783580456, 0.007437050841482622, 0.040932397690734694, 0.05336176823558552, 0.014868198428303003, 0.05514993531895535, 0.03356838605499693, 0.025765628587188463, 0.02005807699502579, 0.015753589936399033, 0.04320401079686625, 0.034452686818050485, 0.050720004098755975, 0.019072630409417406, 0.04957490161593471, 0.04648808975304876, 0.031494915352336, 0.010278512075144266, 0.0803242019776787, 0.016322412627882192, 0.02805036286424313, 0.02623002982831427, 0.03077185825843896, 0.028741949503975253, 0.04447752603196672, 0.04006969130464962, 0.04177256992885044, 0.015753615381462232, 0.038910516005541594, 0.01306238688994199, 0.019485758151859045, 0.03435276235852923, 0.032206376282764335, 0.05591924475239856, 0.029430686296629052, 0.020568754324423413, 0.036774297777031145, 0.0245926400114383, 0.029004983603954315, 0.054148129254047356, 0.04637322734509196, 0.044453913013317754, 0.00555621792695352, 0.01507420844531485, 0.049568587847586186, 0.039686434370066435, 0.010011064104868897, 0.028413443560046808, 0.046127814799547195, 0.022725158969738653, 0.0463031719970916, 0.025700825100232447, 0.04339221605498876, 0.017393383463578563, 0.03638443530404142, 0.020651890131245767, 0.01708323528457965, 0.01094171220237123, 0.02535594440996647, 0.04878416743927768, 0.04743434415598001, 0.06433005950280599, 0.012849838339856692, 0.12934613148016588, 0.037086959928274155, 0.021320152129711847, 0.04849560345922198, 0.04704163183591195, 0.036128050847245116, 0.05726182806704726, 0.020085423652614866, 0.01192816810881985, 0.016025263483503034, 0.024597476269783716, 0.00781964959709772, 0.04295638622716069, 0.05592555173539689, 0.010721076363032418, 0.018289833396141018, 0.028178672139932002, 0.06399389968386718, 0.03170242832441415, 0.058331463885094435, 0.017301411434475864, 0.03913319084261145, 0.019886643426226716, 0.008986678090877831, 0.027757088154820458, 0.006437970791012049, 0.09102319965937308, 0.07342702922012125, 0.023632865798260485, 0.025395285870347704, 0.03390199797494071, 0.028677810981337513, 0.06899550344262805, 0.0069802118731396535, 0.0677458658548338, 0.0327761964207249, 0.013479884397903723, 0.009899842885455914, 0.046611912215926816, 0.015184716354789478, 0.005804734346124211, 0.05389234530074256, 0.009800671599805355, 0.007995117904751428, 0.08584834555430071, 0.06842779354857546, 0.013690991909243166, 0.0536333756255252, 0.03323363758889692, 0.0340093354295407, 0.04217146709561348, 0.03619571775197983, 0.038332438096404076, 0.004203797974956355, 0.04052036747868572, 0.04618680663406849, 0.02090471736820681, 0.032430811918207576, 0.0688158477257405, 0.01235238989881639, 0.041194603977991004, 0.04093409063560622, 0.034060856593506675, 0.014545612702412265, 0.013910976354964077, 0.030435420240142515, 0.007439548698520022, 0.02816733721244548, 0.05285299928592784, 0.030069822179419652, 0.060955297734056196, 0.04935368223647986, 0.04798329255676695, 0.04647636806060161, 0.030551330984703133, 0.0244868631873812, 0.04364517730261598, 0.01093951374891081, 0.05921839736402035, 0.04754868069929736, 0.01765493835721697, 0.014290970384276338, 0.021668547631374428, 0.03533939977309533, 0.007592044354948614, 0.026151825274739946, 0.06679083460143634, 0.03408666806561606, 0.02012906702501433, 0.022010013594159057, 0.020684067958167622, 0.01162549653755767, 0.041072969790548086, 0.032385685946792364, 0.03127705811389855, 0.02812835537562413, 0.05856675947351115, 0.04705543663086636, 0.025950816060815538, 0.04513340476634247, 0.0562413758598268, 0.031074657903185914, 0.02866731065192393, 0.018291797755020003, 0.01201444722911609, 0.023842609454212443, 0.05354399899286883, 0.03641310001590422, 0.007976425961325211, 0.05600563243829778, 0.019866689407665814, 0.055396168891872676, 0.04694073707131403, 0.01561812890161361, 0.01182319619692862, 0.01978100909452353, 0.03335866445143308, 0.030894930940121412, 0.040383815698857815, 0.019573065252708535, 0.012036367302893527, 0.04278558199959142, 0.005758996420939053, 0.02659181791490742, 0.04177945027393954, 0.026820090665881122, 0.021681436404053653, 0.04067373335627573, 0.03639821974294526, 0.005213545868173242, 0.02637540765239724, 0.05424333450251392, 0.01937230200772839, 0.005395780866300421, 0.018234179953911474, 0.011952774333102363, 0.02713886641764215, 0.04125915301431503, 0.021560813233788525, 0.07990036186363016, 0.00909911812881806, 0.019158378576061556, 0.03202417945223195, 0.025476952648854682, 0.01760063350333699, 0.0095810985159395, 0.026450082127537047, 0.04387011505397303, 0.008766631728836467, 0.050840142116482766, 0.01719653875833111, 0.03815780693132963, 0.02318521080139492, 0.038563397846051624, 0.052817925810813904, 0.01756063216765012, 0.033103402970092635, 0.03199312290442841, 0.05093177148540105, 0.01874057063832879, 0.05321490950882435, 0.029680024167256694, 0.012021688894102616, 0.009746097876424236, 0.025905484832557182, 0.007710249396041036, 0.02679701877890953, 0.04869753548077174, 0.19778499193489552, 0.1591963797275509, 0.0730498316032546, 0.0941836800692337, 0.08828664078776326, 0.10573123328919921, 0.2738157771527767, 0.12539863187287534, 0.17894324154726096, 0.13564402210925305, 0.1292203175170081, 0.13262013079864637, 0.07607234548777342, 0.1082422946180616, 0.20233504420944623, 0.13342756032943726, 0.10929872614464589, 0.1191033875303609, 0.1486520812447582, 0.1594164286340986, 0.12098326879952635, 0.1457484806222575, 0.07857832458934613, 0.129792078265122, 0.1760221482919795, 0.16818543523550034, 0.20506894322378294, 0.12516710215381213, 0.09506861865520477, 0.09802167769521475, 0.08431584028793232, 0.1761028803884983, 0.10015782807022333, 0.08946609749857869, 0.1651939914694854, 0.1701401589172227, 0.13582365747009004, 0.14314804944608892, 0.13062864408961364, 0.14513674059084483, 0.18373644006039414, 0.11838500893541745, 0.2068544809839555, 0.10941757155316216, 0.1441029789192336, 0.11653627242360796, 0.13696157426706382, 0.17115253316504614, 0.07179741880723409, 0.15046938801450388, 0.11646879890135356, 0.0784864170210702, 0.19804571223046097, 0.2194833340389388, 0.1040073675768716, 0.12881987329040254, 0.1409671971840518, 0.10860404199255363, 0.11518138726907116, 0.13024196055318626, 0.060477425876472674, 0.09842515497335366, 0.09062823121036802, 0.09309122511850935, 0.07411652936467103, 0.10651986061462335, 0.17023110975112232, 0.14803460080708775, 0.08970119631183998, 0.10078989022544452, 0.11094773587371622, 0.1299260210778032, 0.1359044574201107, 0.14826752830828938, 0.1115966731948512, 0.15584554310355866, 0.11689544815037932, 0.10035834195358412, 0.1412091627717018, 0.09407097540263619, 0.17150410929960863, 0.19579225672142847, 0.11185957158782653, 0.10951835435948201, 0.12855092915041105, 0.15308340346174582, 0.19420128209250315, 0.12962557934224606, 0.11643065166260515, 0.09413161607725279, 0.08831968544317143, 0.11850661598145962, 0.11559460152472768, 0.104520747171981, 0.19129736934389385, 0.08529820293188095, 0.12116272774125848, 0.08383674706731524, 0.21875038051179477, 0.1183918078563043, 0.15614153364939348, 0.11178180468933922, 0.1179685919944729, 0.16509500678096498, 0.18463377548115595, 0.1573331497077431, 0.07379611834351506, 0.0924834952290569, 0.17561166174709797, 0.13126512350780623, 0.05366999616048165, 0.0710429557199989, 0.18169251616512025, 0.12287091250930514, 0.12314733410520212, 0.11926745729787008, 0.11998556447880608, 0.16249370707997254, 0.17240067119044916, 0.11562832471515451, 0.08689455155815397, 0.08227392485631363, 0.12387844201709543, 0.12193351638104234, 0.19202203117311, 0.14445075525769166, 0.09464192869407789, 0.15956390143505164, 0.06741729884275369, 0.08523613054837499, 0.1499560491314956, 0.14325166174343654, 0.15041097972009862, 0.12516347877681255, 0.15023015013762883, 0.09292798994907311, 0.1424600285078798, 0.13260759147150175, 0.2522383907011577, 0.19787759839424066, 0.16522187925875187, 0.09015224568013634, 0.0791377563561712, 0.09697895936135735, 0.08854986487754754, 0.13477320383702004, 0.13438405043312482, 0.14750949612685613, 0.07823337095656566, 0.14703822641500405, 0.13117656111717224, 0.054485479901943884, 0.11902650951274804, 0.14796872862747737, 0.11648382166666643, 0.1413990847234215, 0.13506158121994563, 0.08262188439922673, 0.07548742116029773, 0.17919868284038135, 0.09017091896384954, 0.13733402213879994, 0.12835218624344893, 0.052776396074997525, 0.09965987157608781, 0.1571266172187669, 0.14089699595102242, 0.07363973637776715, 0.11403634585440159, 0.17312549586806977, 0.06058793208960976, 0.1347609902066844, 0.07916493168366806, 0.12021557427942753, 0.07236949846680675, 0.10282851476222277], [0.06980263441801071, 0.019778763143611804, 0.0794302388759596, 0.03128870516749365, 0.02002153788427157, 0.05396360165572592, 0.08258919258202825, 0.03136345937049814, 0.048633128936801634, 0.056464037126196284, 0.018171406982998763, 0.0639452419376799, 0.026904312128733312, 0.07466146762349776, 0.033073157271636386, 0.019121776700818112, 0.02193343752462949, 0.0595490067665066, 0.038858998234250715, 0.10526632823582206, 0.020720218607623662, 0.05519233697227069, 0.009322969375976493, 0.009246069305975522, 0.036407220509967635, 0.059774938571665964, 0.06869642556245838, 0.043014329725078175, 0.011710380420221813, 0.0020929192126329455, 0.0416026070847043, 0.03143355543059962, 0.050321100146642754, 0.05744233873805829, 0.07057771139911242, 0.023473864687340598, 0.020865545541580235, 0.020640872418880463, 0.05737892285521541, 0.03985284169071487, 0.0550171765498817, 0.009862668496290488, 0.03064044638137732, 0.038811446500143836, 0.035633514169603586, 0.012226846501497286, 0.01705683857601668, 0.023248446872457862, 0.04513112488867981, 0.06793075986206532, 0.00976529872111444, 0.039047983807644675, 0.0956447830955897, 0.0475698950966554, 0.04667940270155668, 0.03479563198717577, 0.1200152300298214, 0.06641035966042962, 0.01520410379660981, 0.05126352082671864, 0.016426667837159972, 0.057597716471978595, 0.027672803927479044, 0.05272073584741779, 0.050021347124129534, 0.052061518720750294, 0.03753112555880632, 0.030724598294390098, 0.02562079528745796, 0.04273524148655789, 0.046144499975655756, 0.02830806198263807, 0.03157904690929821, 0.06837619774575744, 0.03071092242108924, 0.02370142497654472, 0.042160892127347846, 0.06966158055833407, 0.034906202661139626, 0.058105124958923886, 0.032237320872289796, 0.062446222374481816, 0.026396830699273517, 0.00371447838343946, 0.022598032041319778, 0.03767044236883521, 0.05879893380084208, 0.06810435626123633, 0.10701645325337138, 0.03495275016341891, 0.012704776882726167, 0.006166633966911052, 0.021826288363497173, 0.07493313268891402, 0.08076686465314456, 0.012372047058306634, 0.04392256581091455, 0.028519956594599143, 0.01562657157358314, 0.006353312521241605, 0.0970575472872172, 0.01268082544473665, 0.02307151717000774, 0.03336580603250435, 0.031239362100937536, 0.05380894656160048, 0.04070756171963044, 0.024105266967256154, 0.019822574453428388, 0.09181292621152741, 0.03742678722898875, 0.05003122320132596, 0.01931085896545223, 0.05206315738282033, 0.013372028712183237, 0.04891329265332647, 0.04271218825929931, 0.03913325530343822, 0.04369692238313811, 0.003916018551015961, 0.03605905401387385, 0.041262084285595586, 0.07468166082565274, 0.025187481128211533, 0.03112133771979383, 0.04289622391973223, 0.006792083374291126, 0.04954060845609222, 0.09515614288726024, 0.09130300035966293, 0.0353790771083108, 0.0116270877021764, 0.014749868706400906, 0.04283994283261044, 0.039504393602588346, 0.03190916437389595, 0.01802906221044915, 0.050808807369321585, 0.04395314399152994, 0.023091740906238556, 0.01944617411520864, 0.06482671320970569, 0.014162184437736869, 0.10390817254249539, 0.03658923413604498, 0.09079663003129618, 0.056414666918239424, 0.0847288713391338, 0.039565471932291985, 0.07453355698713235, 0.017137621562661867, 0.06012410590691226, 0.03043062978291086, 0.014432395741875683, 0.05586143696148481, 0.018885558304776038, 0.03053768564547811, 0.029591424457196678, 0.028934663627296686, 0.036420221240924935, 0.017614699534273574, 0.0199855025857687, 0.032084402827812095, 0.03856251235785229, 0.026514899185193435, 0.02300897490100137, 0.04644693321149264, 0.009419883684521275, 0.045120017270424535, 0.042413195196006975, 0.03960893549291151, 0.030567083175161054, 0.009595136557306563, 0.03132976671414716, 0.0692722439499838, 0.02481761677855892, 0.021758046400334154, 0.11842169053852558, 0.04605006147176027, 0.022078613484544412, 0.02407169305453343, 0.057799499215824265, 0.03853541845455766, 0.06375483144074678, 0.010793556625555669, 0.011461263073475232, 0.02805918381948556, 0.007163410390993314, 0.044046259352139065, 0.015016346371599605, 0.04844060819596052, 0.059646966867148876, 0.03468422332246389, 0.03718842126961265, 0.09279955684074334, 0.01564957051804023, 0.036669406441173384, 0.025981506199709008, 0.060870759056082795, 0.03314030170440674, 0.00856769289488771, 0.04704199145947184, 0.04177206442026155, 0.025050717306190302, 0.03004798013716936, 0.008883054767336165, 0.03510754435722317, 0.03380125588072198, 0.012916983620795821, 0.03628873472501125, 0.13998874968716077, 0.04521317673580987, 0.030125546867826154, 0.00871895785842623, 0.10907057552997555, 0.015371025107534868, 0.05412176138322268, 0.017034497810527682, 0.009515925227398319, 0.04263738316616841, 0.031053823485438312, 0.05683884969247239, 0.017748287812407528, 0.05070657928341201, 0.0496891194156238, 0.058983949944376945, 0.04946568461933306, 0.06524740492126771, 0.016490636726043055, 0.04106691725818174, 0.02132584503851831, 0.06090654499296631, 0.09986203429954392, 0.07513294089585543, 0.03556641044893435, 0.03486341763553875, 0.025143988729853715, 0.02102545588942511, 0.06470636145344802, 0.03498376939179642, 0.0389200528152287, 0.017178552491324287, 0.007029501080978662, 0.02319735148921609, 0.02386172378568777, 0.05496249341272882, 0.04378114893500294, 0.020149402719523226, 0.036497319782418866, 0.018332475929387977, 0.018517756701580117, 0.035934139109615765, 0.031656169199517796, 0.05605726556054183, 0.025887993896113973, 0.03278055600821972, 0.027920304664543698, 0.008772454407465245, 0.006067425785918853, 0.037565985295389376, 0.0356535377380039, 0.01325045304838568, 0.023294541452612196, 0.053834160922893455, 0.11338285556329147, 0.025995085381769707, 0.058875520048396926, 0.04167877942589777, 0.03057983284816146, 0.010609270755334623, 0.013327716134621628, 0.041168487165123224, 0.043921683715390306, 0.03094981424510479, 0.05016718465568764, 0.023691228291551982, 0.07750346405165535, 0.06975849571504764, 0.010657959883766515, 0.00911421129213912, 0.028106759302318096, 0.04592144515897546, 0.011249165749177337, 0.02277014244879995, 0.035603488995028396, 0.040181910818708796, 0.01106222256618951, 0.02318612512733255, 0.020125998350392495, 0.038068474403449466, 0.02410547561677439, 0.06456602684089116, 0.024186055042913983, 0.02795196171583874, 0.028152358551908816, 0.09913136743541275, 0.08211099502763577, 0.055118756634848456, 0.0908609822924648, 0.0681823877883809, 0.05508967462394919, 0.03866439099822726, 0.014425227019403662, 0.04710414187450494, 0.05197867638032351, 0.05328633549756237, 0.03660700157550829, 0.008848801471426018, 0.005275591958447227, 0.035466543664889674, 0.007800983098734702, 0.023354939550959637, 0.03189209921817694, 0.04908727242478302, 0.035594898741692305, 0.01567052537575364, 0.028791882895997593, 0.07113763849650111, 0.00598448420974559, 0.051645763351448944, 0.04882568360439368, 0.03541480876239283, 0.02175351039373449, 0.03658536309376359, 0.030971632538629428, 0.07690953556448221, 0.029440545410450016, 0.04785074074087398, 0.019986386377630488, 0.022522492434031198, 0.05345268514273422, 0.03494962550965803, 0.029739195813557932, 0.04995463356109602, 0.049062977478440316, 0.031310204549559524, 0.0627934355288744, 0.04802342790312, 0.016564111890537397, 0.027938986429944634, 0.01583018127296652, 0.008308653669830943, 0.023093688301742077, 0.037487265055200884, 0.03223941754549742, 0.032681662921926806, 0.022362042650846497, 0.020670173257323246, 0.07289428423557963, 0.027703059803960577, 0.11018623637833766, 0.016801739943080714, 0.14934760678027356, 0.11523461155593395, 0.18090169717158588, 0.06543990530605827, 0.10493660092886005, 0.1266483033874205, 0.1355587031160082, 0.1191804012549775, 0.14902109572929995, 0.1853349735694272, 0.12720719911158085, 0.16200734674930573, 0.11772328801453114, 0.1321510188281536, 0.06939445489219256, 0.09321752762688057, 0.10677741215165172, 0.10131006195609059, 0.17113639760230268, 0.20494725475353853, 0.09124947751739196, 0.11433472484350204, 0.14175897969731263, 0.1154767128505877, 0.07247874939015933, 0.16899051703512669, 0.1240178673927273, 0.10938939877918788, 0.1142725438943931, 0.12476545013487339, 0.13859600227858337, 0.12012270997677531, 0.1626585368067026, 0.1317047192049878, 0.24699898755976132, 0.1402028953390462, 0.1796479273055281, 0.09663640774254288, 0.2975097857415676, 0.10033153303499733, 0.12314751052430697, 0.07716529576906137, 0.07614981383085251, 0.12567797116935253, 0.13684524622346672, 0.113308393130345, 0.08266809263399669, 0.1746298758579152, 0.11027425594095673, 0.19936486573091575, 0.053310457417475324, 0.15971077712518827, 0.10932538578552858, 0.13728087927613938, 0.07097445760986634, 0.14300500069345745, 0.2060335757476943, 0.11523486939924103, 0.09119444832737957, 0.10775052636329617, 0.10862424198005881, 0.13833560767982686, 0.1553636882454157, 0.10097331181168556, 0.16289653974984372, 0.1649998626006501, 0.2120943862412657, 0.10445114983511822, 0.09910335750984293, 0.13190899895770208, 0.1731058047818286, 0.06168071273714304, 0.053795606563133855, 0.10704542669866766, 0.0726996057533792, 0.10907409034137215, 0.15418444866580622, 0.13857088291219302, 0.14771696499415807, 0.12616669280188425, 0.07617911975830793, 0.18350396039230482, 0.13172918717776025, 0.1697798025395189, 0.09636151963578803, 0.08596528427941458, 0.10855276510119438, 0.1263886551771845, 0.22000545316508838, 0.12035000563732215, 0.14997639161135468, 0.11804954122219767, 0.13006198592483997, 0.1905239344175373, 0.10189814825675317, 0.1363937897341592, 0.17550168479127543, 0.16046191539083207, 0.12151861935853958, 0.09635592850723437, 0.16671597265771457, 0.1480083279311657, 0.15737574813621386, 0.13188778795301914, 0.07510523631104402, 0.2782605343631336, 0.06645588257483073, 0.10314501063632113, 0.11014323082885571, 0.1689861472696066, 0.11068080698273011, 0.12807811237871647, 0.1525252948382071, 0.1210103559174708, 0.10426654081259455, 0.1105338702244418, 0.12406981603375503, 0.10603429416992835, 0.12075669238609926, 0.1818392425775528, 0.1467383410781622, 0.11995858592646462, 0.22919580287167005, 0.11179177236876317, 0.13955345590199741, 0.23751580928053173, 0.11755757619227682, 0.25498317341719356, 0.11613132272447858, 0.16685982208166802, 0.13501303882471152, 0.09568388028336422, 0.118066436744162, 0.12436014759753432, 0.17511897747005734, 0.10033860336989164, 0.075379147327372, 0.13211189449897834, 0.11325552846704211, 0.09524860006890126, 0.11767184148941721, 0.1350543208952461, 0.0912626546674541, 0.20284839666315488, 0.2243097943386861, 0.15367132691400393, 0.08236334220107112, 0.1592514632003648, 0.13053856178053788, 0.23409922261323246, 0.06157976029706853, 0.20227413890617235, 0.11975830953036036, 0.10005082988313266, 0.1379496841026204, 0.1388069452451808, 0.14970837027898856, 0.10140221379697323, 0.12479113947067942, 0.11645104842526571, 0.07591460645198822, 0.0813403149534549, 0.13160698302090168, 0.21145623762692722, 0.1390158933188234, 0.12015229410358838, 0.117512901446649, 0.17269297050578253, 0.08809449324118239, 0.09917281913970198, 0.13895483873784542, 0.05927265980946166, 0.11664909922650882, 0.09893610541309629, 0.1554683047745909, 0.19191061572304793], [0.03521612013823219, 0.05289317534438201, 0.049652811006775925, 0.04708867806142994, 0.016530310668583428, 0.0236877796373197, 0.01278688301265772, 0.01232036474227373, 0.08499139653784887, 0.0029577254525585367, 0.0345024302202676, 0.009189174144661852, 0.05384762645033853, 0.06515300712947335, 0.041087181706513674, 0.03135402773373893, 0.025391408042716127, 0.010603912873193622, 0.044784871861338615, 0.004790279964384223, 0.02687270936023976, 0.03310761327988335, 0.06064901381198849, 0.0762324526107737, 0.045542768335768154, 0.038510757099304876, 0.05188175104558468, 0.05425103926765067, 0.022172488804374422, 0.03802352145846401, 0.06201408377715519, 0.03819282612364207, 0.02502095336759729, 0.07857054179268223, 0.07672327091651303, 0.0428886073641479, 0.025908836795549308, 0.010481469532740968, 0.02953406110672014, 0.06132081776325192, 0.06320442418966975, 0.05183095930676375, 0.03858788278219955, 0.0627243538786258, 0.011244259092823734, 0.0394049135835043, 0.04050438119364636, 0.023411912743800452, 0.007982744818686374, 0.03815369161644152, 0.03198636130296758, 0.027432387096009085, 0.07306597395134823, 0.08086782387856926, 0.003272890125767195, 0.027140289644843767, 0.010781040198967924, 0.04535088202516947, 0.006836643193050155, 0.11794363547648702, 0.04428180939118777, 0.04162258994100349, 0.071922364245568, 0.0029390239672336194, 0.0181561263743788, 0.04697479274389999, 0.016865875073043362, 0.043196970996047766, 0.029471143947115967, 0.007542743696831167, 0.04016404499166778, 0.06936789703156267, 0.020096293783613613, 0.03827070498040744, 0.044705177923398356, 0.012429862482739347, 0.022505885289449776, 0.03355822838576777, 0.03963006168071713, 0.015842890233865807, 0.12860614833022865, 0.05292112759447523, 0.03727641369083098, 0.02847877291164228, 0.05598208388047559, 0.054865605397416015, 0.05548732328627791, 0.05042402373094644, 0.04686228824513299, 0.012978565762750804, 0.017491345260558382, 0.030360472654657703, 0.01817810921264546, 0.08117097296885081, 0.020598857530525753, 0.0647677213751844, 0.00936425568735493, 0.07018500247171947, 0.04438423764492784, 0.03090315478454743, 0.0238042756183339, 0.03224766513864909, 0.002065561952934201, 0.024465876099254404, 0.022576586942055395, 0.006364138547464141, 0.03006203259740557, 0.027363471686840057, 0.04150563764518925, 0.021234493868957673, 0.02091239159926772, 0.019267354692731584, 0.018847850417452197, 0.015114141927499856, 0.038913474418222904, 0.08548926482243197, 0.003052753221709281, 0.01634935725347272, 0.040638782017465146, 0.04256761958822608, 0.0371245880877333, 0.05379759467073849, 0.01720043015666306, 0.010209317618448819, 0.053752224426716566, 0.013140190259686537, 0.04853386604892356, 0.03429409282814179, 0.054166612547955344, 0.01602719900464373, 0.012690014505226697, 0.04711627408063837, 0.028797351888247898, 0.01673429356222706, 0.02307657225589667, 0.009659135132096708, 0.08540503827056714, 0.04800558243212955, 0.0738748148349779, 0.06871786048369748, 0.03874521130429847, 0.018805570900440216, 0.06678268539586238, 0.03675655408629349, 0.019192843065996255, 0.02000656770542264, 0.03363046183117798, 0.02569521700830332, 0.07014340827507631, 0.07348555965082985, 0.03938224033585616, 0.13939229026436806, 0.03893090598285198, 0.019138086986328875, 0.026160622481256723, 0.03448483919990914, 0.03136482661856072, 0.07295048050582409, 0.04548491644007819, 0.0542432937904128, 0.030954608095011542, 0.041505203382777314, 0.06180094235709735, 0.05061879042269928, 0.016861191485077143, 0.018424710890810405, 0.02976328380671995, 0.07479969199214663, 0.04785646418375628, 0.07628468623650925, 0.008095605548338165, 0.02910392079502344, 0.08376578587506499, 0.019226802047342062, 0.05018063661243234, 0.021033571168248142, 0.04373933760715382, 0.025698993055682098, 0.03164244243609054, 0.017213059389697652, 0.021122879947402647, 0.04434184616963778, 0.049279518358941586, 0.028922324467982565, 0.08305117314947502, 0.03440181365502732, 0.04414912526096616, 0.03433493385091424, 0.010379434829311711, 0.019571519889203564, 0.019672938822103397, 0.04300207877531648, 0.05752248050911086, 0.10016344634017774, 0.05596619937568903, 0.02395873563364148, 0.02040014855031456, 0.0340180240704545, 0.02136537479236722, 0.04796881601214409, 0.0305342793996845, 0.0217396224782403, 0.03154039416196091, 0.015292321830721838, 0.020557857052023922, 0.04419847511287246, 0.062237606782998355, 0.05095199861430696, 0.015816557986129607, 0.04102364368736744, 0.05970816394048078, 0.06254352429615599, 0.03781124177787985, 0.013900137606209942, 0.044553460885903666, 0.0020771002288841245, 0.028840774736766304, 0.0671319884381124, 0.013919101811812391, 0.0176033408580614, 0.04388782481795975, 0.09186560767037527, 0.012652449110256774, 0.02471295784094504, 0.04025764550481524, 0.05660311984164374, 0.05875185025589807, 0.02716335135379008, 0.020857135100024085, 0.014374737228666033, 0.02483291774322944, 0.07612945778029305, 0.03561201478753771, 0.026760723940762024, 0.01303952619699495, 0.043227053846099546, 0.05511151666619948, 0.031595046765037944, 0.06904981338552066, 0.030859039830310003, 0.003741435731561588, 0.037622351199388504, 0.06129859574139118, 0.06059327894555671, 0.04489018049623285, 0.010559138043650558, 0.08285261344696794, 0.0744205198383757, 0.010863427072763443, 0.03332610494856324, 0.018062941463930265, 0.08330434135028295, 0.05416306380980781, 0.025118428315701227, 0.018175859869058644, 0.04150639421173504, 0.027323261701634953, 0.021358012687414885, 0.009325184792812382, 0.0754024414345622, 0.02484119078144431, 0.05702132811503751, 0.03657425547550831, 0.013013032797191824, 0.04205949863951121, 0.03290048707276583, 0.03297306317836046, 0.07686177348451954, 0.02191745802494032, 0.019381279026025107, 0.0104410899137812, 0.040652060947780094, 0.015126671076619198, 0.04009712447545358, 0.05895558039524725, 0.02822938415088824, 0.01915355758475406, 0.05555410131013819, 0.0374237982822316, 0.02069303479843906, 0.038092416511582475, 0.024967038671353033, 0.03865303910736527, 0.10627538444740431, 0.03148657615695681, 0.011615614523179829, 0.019239943574315736, 0.023248409553031837, 0.05916970569108214, 0.0480744367731469, 0.03357879138950791, 0.1385136145566191, 0.028731944505125284, 0.034819726765687974, 0.06578155447329793, 0.06804712861776352, 0.01095339742356113, 0.015016286999785473, 0.023441554546090107, 0.04753326438367367, 0.0008957532679362755, 0.033275476058146784, 0.02970461766900761, 0.03981516942647951, 0.009573976442750012, 0.035979339719883034, 0.024646215440173234, 0.06803636026701756, 0.011433646698216242, 0.04421568615362048, 0.02542724147705095, 0.049404558792178116, 0.01665286935998925, 0.05680137420339244, 0.04107458470389247, 0.03385495514209781, 0.05734668565647943, 0.0042574756080284715, 0.06819757340209824, 0.045050949190876315, 0.006100988672447524, 0.027315906382032802, 0.055939794185438325, 0.013223702653444238, 0.1537239540900503, 0.07676367089152336, 0.021890593127214482, 0.1421934999525547, 0.019943209498056343, 0.03303827717900276, 0.041709099763206074, 0.013857290664288615, 0.04412055893668106, 0.019050998713022897, 0.05732534573014293, 0.03281252518562334, 0.07694546399371964, 0.046576068603566716, 0.09114662517926522, 0.0458906532398292, 0.010127371792415423, 0.01574828039987811, 0.036645589862018824, 0.145670815504023, 0.0235672412839319, 0.05178334650450519, 0.01598557597026229, 0.031018502345042567, 0.015261913283861108, 0.05074791902942317, 0.09585294406861067, 0.027736175705545714, 0.10634367221168109, 0.15226536164326326, 0.10106173849531583, 0.12684186228684016, 0.09012277690427643, 0.14269339027149336, 0.12699162853615625, 0.11540113762021065, 0.16211462313575403, 0.08885150762008769, 0.11957416869699955, 0.10597256105393171, 0.1829350630619696, 0.23045272114021437, 0.06402550584503583, 0.06367556497986827, 0.1389466691762209, 0.23583228247506277, 0.1089403714452471, 0.14223881252110004, 0.05887893307954073, 0.16600410799895013, 0.10676137158381087, 0.1541569951389517, 0.14979994536510535, 0.13283382861741952, 0.13301171335790837, 0.12312115622418267, 0.13028393472943986, 0.0834595358797482, 0.16973142299268926, 0.1343157219567469, 0.1049661918410233, 0.14262797949569567, 0.23342017190796988, 0.19371511175164155, 0.09929009713232517, 0.08260614917214427, 0.13384115456470422, 0.10801266479705061, 0.1451901684382132, 0.17544946473624023, 0.10640914405563048, 0.12620608854506696, 0.08586379579667534, 0.18516071220593794, 0.11561710174594607, 0.15403532023940766, 0.10711096639611892, 0.126615828701428, 0.11235155697379794, 0.09479757105665547, 0.223149160189288, 0.08260274971170084, 0.07851826745484557, 0.11993955980454173, 0.13692364415952138, 0.10935410817286798, 0.10461538245103189, 0.17707277834415436, 0.16318771269704613, 0.08116798062941857, 0.16532945420060838, 0.18506038401808056, 0.10852046004895653, 0.11595524288713932, 0.15585832670331, 0.10691201314330101, 0.09812450289194073, 0.11986439169517585, 0.15923872031271458, 0.199357415416411, 0.07697823044977017, 0.09369120613804885, 0.1443697110350643, 0.15582540418420518, 0.09499182884714433, 0.09518194078866925, 0.10558042209595442, 0.11532538597072874, 0.2054725901356765, 0.1295140960386821, 0.10493539313652686, 0.10547106939234904, 0.10514387980635677, 0.1598819579396929, 0.16103401540645532, 0.14470272245151655, 0.1029589766902583, 0.10132156991000686, 0.14488276493336472, 0.23075428924390248, 0.11425639476094927, 0.27807236303176197, 0.17842376870768412, 0.135534208001835, 0.08568702385361705, 0.23553437846047537, 0.19414397302482808, 0.13617378153971263, 0.1473543830215931, 0.12432862286056791, 0.1701605963919844, 0.10571986104228667, 0.10061950329691172, 0.1488661997552429, 0.0997913105945502, 0.12126703214432512, 0.18398494672562393, 0.0965463322188173, 0.15620519380484307, 0.09528879648340599, 0.09987719955721072, 0.17656690334635122, 0.08843629847147635, 0.18090511698807987, 0.12734024625803742, 0.06657971521573407, 0.20774357898959092, 0.13102900689201696, 0.1351998666567462, 0.1470694254551615, 0.09050595241465739, 0.19109245176826203, 0.11326624253498656, 0.15092817268201283, 0.11191674494849783, 0.11635648778506688, 0.15529047431690352, 0.07278474832751922, 0.0793357053771615, 0.12548879560615334, 0.06669715605676174, 0.2078800866646426, 0.09403283494923796, 0.17641291660921915, 0.1274463962763548, 0.08643815533391067, 0.1467683051845857, 0.11192154897642986, 0.1273057223962886, 0.12908298202923366, 0.15392416263265268, 0.16721787144030842, 0.11889108749372618, 0.13043462378638132, 0.10656152945011854, 0.23599458805152349, 0.23964421078562737, 0.13200541878385202, 0.1609483300043004, 0.25565288748059956, 0.1488696060010365, 0.0799272997038705, 0.12382437634680953, 0.08070800174027681, 0.10443968259330307, 0.11700963202331748, 0.162791176832148, 0.16254017315804958, 0.1851400033171688, 0.13104694735791, 0.1288822442293167, 0.15144541992672853, 0.15346592079315866, 0.09273352859807865, 0.10601790754922799, 0.2496145772082465, 0.10323349160275289, 0.13101570760565145, 0.1228756486837353, 0.07386955618858337, 0.1480596930320774, 0.09846579243562051, 0.1681698425007718, 0.08388444129377604], [0.06712720476623092, 0.028392763509015952, 0.046634839914206944, 0.03781220869028142, 0.06432956417224237, 0.0505304248072207, 0.08586770415838275, 0.05665623217022844, 0.1080446509378297, 0.04521599265613726, 0.022026401911196963, 0.062046192054237635, 0.0961131283215114, 0.02798112515094025, 0.0536069704352745, 0.0344497182273439, 0.05023025109299591, 0.023729838630450622, 0.032162220616425784, 0.0974743849198733, 0.021583518711850047, 0.11489600901092802, 0.03639656072482467, 0.05369528176795159, 0.05537206393533519, 0.05162038614175149, 0.045801480167678425, 0.04604938293674162, 0.013536497967184653, 0.043527685571461916, 0.04060617840981909, 0.011859639464611453, 0.04549215640872717, 0.008517153062192457, 0.04284039405839784, 0.04861726818074073, 0.042912630896483145, 0.030928104517183135, 0.030811325247798647, 0.10542553969259773, 0.06501285572137151, 0.03142763181988682, 0.013650066069593387, 0.021531972102820873, 0.0322698973385351, 0.02943740040063858, 0.05863537293459688, 0.008455939025485089, 0.023841859673016837, 0.03327825465904815, 0.028253299117620503, 0.08844036968158824, 0.04086434741371444, 0.03146917512640357, 0.016770050661372285, 0.03412059820922358, 0.016908395469986966, 0.06102132597672088, 0.11794862949422427, 0.039374281120087416, 0.012612781104897814, 0.034023143617170196, 0.053762731541480334, 0.06888529578489916, 0.014804899592750838, 0.0821215258911252, 0.036469401459076574, 0.02995199796610645, 0.00907819634968681, 0.04870999677638922, 0.04926807147317699, 0.04349998437932559, 0.04348432718377028, 0.019476489363504306, 0.04315211643864002, 0.04482185201985495, 0.009299683750474026, 0.04289113151441727, 0.04252026462927461, 0.0506856023733105, 0.0260740091824638, 0.05464669642969966, 0.03948606297905956, 0.04466352265860353, 0.05468509811908007, 0.05452210382957544, 0.006641894312841552, 0.029798815292971473, 0.03680129668542317, 0.004000601757849965, 0.017460644943639636, 0.02756954277200358, 0.0245222555739539, 0.02675478675934885, 0.011857311241328716, 0.020344847946294715, 0.03846740549696343, 0.05565419201073902, 0.04618860475186791, 0.05837702751159668, 0.038867809011467865, 0.019182210422254035, 0.043924547133169005, 0.049321102377559455, 0.0896571593891297, 0.01905453048779496, 0.02497969165311328, 0.042846314276435545, 0.003857582267041185, 0.019855303590052893, 0.040968468612326045, 0.010511387838050723, 0.019285442739991204, 0.03604901508827295, 0.11532678375286715, 0.018305482110008597, 0.01677722447285695, 0.037174602903957875, 0.020949327653007846, 0.024376458754496913, 0.03730704954692295, 0.03891486541501113, 0.054159844161144326, 0.008259032403917184, 0.03752253530547023, 0.029996730387210846, 0.011593925999477506, 0.03760820035157459, 0.01253473770339042, 0.05087911377527884, 0.01797810083787356, 0.04339378007820674, 0.01903199973250074, 0.04419612059635775, 0.05436045643208282, 0.02488165521728141, 0.05098919929670436, 0.008922351274772413, 0.022059991090957607, 0.018857285446886505, 0.027387941355950067, 0.023673379427886436, 0.09134610090404749, 0.038259702535080056, 0.016517608493034328, 0.044635322743228505, 0.04127310369429844, 0.03373759572527238, 0.005190321310822452, 0.05670448958075472, 0.07509279876415219, 0.007608697300643793, 0.04468531381072743, 0.046700338899557076, 0.038904287054070404, 0.025718684141923274, 0.05255578398438437, 0.040404209068843296, 0.05533620335959962, 0.03822326520457864, 0.0077770409906016925, 0.049917650009904585, 0.0645831259233611, 0.011978994622560484, 0.09096673197512116, 0.03231561363541654, 0.026416869534711753, 0.009880470710673502, 0.08169478164719683, 0.062227639103574414, 0.03901942766138485, 0.0768773662192481, 0.016042537288740277, 0.023709816758387854, 0.019416006448279535, 0.005401602272676038, 0.012346039659210613, 0.05388059985956975, 0.03764026791655591, 0.021034358268869773, 0.04081349799941693, 0.025238450982474854, 0.03516389669052192, 0.06330705939659051, 0.08424826498542513, 0.022663273183362823, 0.018594037608376572, 0.05072394638721432, 0.05374257905142648, 0.10162318551114627, 0.02643537488100784, 0.04457817313128284, 0.0406370483604925, 0.03834895703143307, 0.053044715962771855, 0.04068350426054426, 0.021459507955504314, 0.058612621655421596, 0.03431726140635354, 0.01971748294974012, 0.02006389882548579, 0.03677415528467723, 0.04517587427315967, 0.06241804960050753, 0.03279389939936144, 0.05895263555326632, 0.003359614322627229, 0.017252728243225386, 0.04454863310924598, 0.03479272107194577, 0.039007142784872224, 0.03087482594751886, 0.02976409126339214, 0.00596861624425011, 0.04490030084603599, 0.055528021816696436, 0.0642984669123377, 0.04521456094724791, 0.0228911082792495, 0.020413030537643602, 0.03993218957579561, 0.04987046807738287, 0.003318542809990634, 0.022559316529493247, 0.021069781189518313, 0.011009895641888891, 0.05127906945667096, 0.025153106544166803, 0.050721045650009594, 0.016109323794288293, 0.0161108521944178, 0.03709510234849794, 0.02495775800863547, 0.02263704271587942, 0.0464563410995262, 0.04415594793057867, 0.04230166778766683, 0.03181072251339044, 0.03039217720340405, 0.0510113670357636, 0.06281536578067712, 0.07998087004359279, 0.045375285537115166, 0.024408945314852253, 0.01999017599570964, 0.010146880522370338, 0.02987088928265231, 0.08601647296122142, 0.02032461403203862, 0.023845510191417167, 0.015083584102935024, 0.06609181461057492, 0.03621247417426535, 0.01958852567310844, 0.05248424943004336, 0.02783535377654646, 0.06436456979385444, 0.06378141644277743, 0.027854288296241845, 0.05539830966985651, 0.04204754963783281, 0.016947601223364472, 0.033090083327676566, 0.04117700617228236, 0.07662898847567183, 0.02073634059966675, 0.04164598922112158, 0.05681692283334477, 0.03199442229898913, 0.021359186552997147, 0.04040825313755444, 0.04874744851674352, 0.03931899069409285, 0.011339221765021128, 0.028470847622624466, 0.04123874607362917, 0.11441727541387081, 0.015973440371453762, 0.0018595209777621286, 0.07747592231524841, 0.0466772856722985, 0.01809509045311383, 0.02716809431357043, 0.023309499757098298, 0.005370454970813755, 0.03449413173698953, 0.04585340505998049, 0.05466856900602579, 0.04940812449370112, 0.06310130043753556, 0.029120765426861386, 0.04857124315042581, 0.02406250569038093, 0.01928741218788283, 0.07644178744937692, 0.033579904186938486, 0.03372693594012942, 0.022449158065553223, 0.043160302963640006, 0.06086206023714372, 0.04130017724154251, 0.026828764039756994, 0.015072888694703579, 0.017631481401622295, 0.02066506219229528, 0.04599591098459704, 0.056485285450305255, 0.033507714846304486, 0.029609276713537316, 0.06032685895583459, 0.0437660583161882, 0.004099173812262181, 0.05303215288690158, 0.02444772359116801, 0.011750778698894595, 0.08984168698745114, 0.05928773685757603, 0.017544990239132727, 0.07835785499108688, 0.03248410405857222, 0.02968357629807932, 0.03200054268485733, 0.028923019966376678, 0.01634697220288217, 0.054494127830756564, 0.025723800295963883, 0.0870485586513366, 0.030989406763442924, 0.05374744075483509, 0.09466689878276416, 0.03168820962309837, 0.029950528937791075, 0.025053336451362287, 0.04214433587289282, 0.04334911551060421, 0.03442703140899539, 0.018085628282278776, 0.05563536605664662, 0.04635162618277328, 0.02594200019458575, 0.0113994790673522, 0.08661571437759058, 0.018950190461639847, 0.010403576257106448, 0.027716627111658454, 0.041869586865816794, 0.03616831511525171, 0.053021408284881284, 0.03807576186954975, 0.0748195391414421, 0.008570442658050783, 0.02450032701848873, 0.13467189855873585, 0.1127998379192182, 0.13026215375534125, 0.20591701700219087, 0.13460618922752993, 0.10594919230788946, 0.1502705229712384, 0.19987669826618262, 0.18036736441510065, 0.140079103410244, 0.10181663584496294, 0.18095208518207073, 0.16181214579514094, 0.15987054498067924, 0.1457320057920047, 0.13573485080684933, 0.15679230301507882, 0.0939547491392919, 0.12001003245157854, 0.13245382186557564, 0.1311015287148101, 0.2544677310756275, 0.12780763474958284, 0.10594387937869344, 0.1675260891871793, 0.23434281668492726, 0.1055326396599412, 0.11036734416016511, 0.15285880837057317, 0.1267611709024225, 0.05805819747703416, 0.09156625837619815, 0.23630655131169728, 0.17267543716090067, 0.18315222140933785, 0.12822148682815687, 0.18596413838011877, 0.12171846149223191, 0.12678509604718002, 0.15078232836510452, 0.12746335965182098, 0.18469710993979657, 0.09886889651949916, 0.11415021760123116, 0.15764781353729113, 0.1502212341874838, 0.08876781711088759, 0.06580433967922415, 0.05020050751045346, 0.11486225867910044, 0.1000604515096971, 0.09478393928813082, 0.25732118796025005, 0.09287179367882864, 0.12688534281083516, 0.14163246005773544, 0.143398130312562, 0.11678222779716764, 0.21214598204408372, 0.13584655124161923, 0.14993790510509694, 0.17376002110540867, 0.12987038120627403, 0.15503306527222904, 0.1541483641735145, 0.20249158223824842, 0.14137933935437882, 0.08938984373318297, 0.09264219778456859, 0.22074406567428792, 0.13942789978214673, 0.12356200042579855, 0.12361905165016651, 0.07191173160182578, 0.1129579230078629, 0.16380842296140535, 0.05139303280572806, 0.15966725588909217, 0.10270199512264558, 0.1438297192965235, 0.20669867577297346, 0.13626503092902048, 0.14956518581935338, 0.163492619193026, 0.11864651633160454, 0.16982345948261873, 0.17416361373450073, 0.09078531206718513, 0.2106886516724314, 0.08887374321264879, 0.08148360119334289, 0.09803002367594413, 0.15808179096451827, 0.09262855244534356, 0.13929839458848747, 0.12313843172575746, 0.1676759911434991, 0.12514428980648518, 0.10970684460231236, 0.16373020144445555, 0.1667653021535703, 0.09160612230854374, 0.11347624912325825, 0.1368290428072214, 0.15936062591416494, 0.11830230908734457, 0.1712215808885438, 0.14107853120991162, 0.14621478345777306, 0.07503597145634038, 0.13701904618314334, 0.0952379402837583, 0.13385178042309626, 0.10471517459622451, 0.20413396268018655, 0.17836379978273595, 0.12631936318108014, 0.09278916168425765, 0.14003706138048852, 0.11120376070695263, 0.09406101450856243, 0.12308522100959506, 0.09469392483255692, 0.1432196484612567, 0.11845924066645758, 0.11687463069600718, 0.12305157924337046, 0.12262510641344956, 0.12269449340445654, 0.11225914050425802, 0.1761704489056553, 0.09049005433917046, 0.11132610057081495, 0.1444189998188189, 0.1949294858745166, 0.13336630218795367, 0.13076659025890486, 0.15855300639356884, 0.09255564385758978, 0.17971960774489812, 0.15538138443870203, 0.11821179251585688, 0.19010265916585922, 0.18843566147344454, 0.08112638643277542, 0.11742402692990643, 0.06655875526900802, 0.059663278848997185, 0.0907157418717231, 0.11682481265493802, 0.18263448561940873, 0.12099732804511275, 0.10131042157965046, 0.2303356874201979, 0.17353196548564093, 0.1184164115360805, 0.15674182000969136, 0.1580641083419323, 0.1361322280551706, 0.10296842189771788, 0.04835524849061455, 0.13500011951795646, 0.1386999131313392, 0.1228455760117088, 0.2190012349081891, 0.19861623804484094, 0.08275528438389301, 0.10422738934201853, 0.11178113293967076, 0.12102060179625239, 0.12237506625907761, 0.13470377613391193, 0.14679380453058652, 0.1506396731627839, 0.09173935944480555, 0.12732165439852647], [0.06056988305811371, 0.026730379854728068, 0.017644711138148392, 0.05267389996775559, 0.02388204590949629, 0.02780381716521723, 0.06119360601795571, 0.01259797377445336, 0.010266757304114955, 0.02723854490821915, 0.011276740564166434, 0.02572105562181345, 0.03552822589075991, 0.029235997636403357, 0.03162921778857708, 0.04759881765182529, 0.01657326702427651, 0.04045901094962444, 0.014092952661615397, 0.050175554385142665, 0.05471554398536682, 0.02005783950776926, 0.05339210892894438, 0.04599700342597706, 0.03684278231646333, 0.02399830101057887, 0.06061604379543236, 0.03004468245697873, 0.0104239577527291, 0.004834398311296744, 0.12635312708360807, 0.07946968890194382, 0.020549064934519783, 0.024944272125139832, 0.04228949486943228, 0.01001394194151674, 0.06521426527095692, 0.014976816617750695, 0.0666326138057879, 0.03312692438651409, 0.026645398432654992, 0.02312463628394263, 0.05924590517367635, 0.02166655782743224, 0.013201690129270511, 0.03302080150959747, 0.02707057526069028, 0.06959283139024462, 0.040522362371640544, 0.032032745956842384, 0.01803171188969697, 0.06519786507955619, 0.03226321376860142, 0.020277767974351133, 0.04288419349385159, 0.020422933756240776, 0.09627423967633929, 0.07349475380033255, 0.019979977614379356, 0.07983973475971393, 0.045366193167865276, 0.019098586070218256, 0.038619950347180874, 0.0156669800302812, 0.05775291778679405, 0.03353890710111175, 0.03786329219916037, 0.023668634771768535, 0.055660037589924674, 0.08183691437755312, 0.03717094899288245, 0.009876791354534882, 0.10332582664809056, 0.02279331611602434, 0.004698828710908336, 0.019582403590902686, 0.01694647655157106, 0.048326797517282624, 0.014331713019471084, 0.07585339580795594, 0.04958997527137399, 0.005565817925214235, 0.0659244946603264, 0.028222727722355297, 0.011823810271120496, 0.03026416478678584, 0.039575276763311455, 0.007781188535903181, 0.04464092744248254, 0.04024241239364658, 0.015218938268455011, 0.056776621245912144, 0.03491241804191044, 0.07915646356663533, 0.028628756292164326, 0.02856549647237573, 0.012695547110135002, 0.028868214692920446, 0.06166406827313559, 0.023457540831129466, 0.08191426058432885, 0.020018769461395483, 0.03494227358273097, 0.06898482330143452, 0.021764229550691586, 0.022420932705114995, 0.07478416032556977, 0.017228375621406094, 0.0455390804979418, 0.037068473241691074, 0.013852076970839074, 0.03229347303775804, 0.015110851032659411, 0.01734322785133762, 0.026415478537923524, 0.01945211468929691, 0.029208642497126545, 0.016966510297996656, 0.05806135945022106, 0.054782742700938664, 0.02353228146343359, 0.006799876348980303, 0.02982138336769172, 0.02194155619612762, 0.07833664398640394, 0.05893660855612584, 0.10765114133911473, 0.03999985308785524, 0.03979069806103196, 0.03639933593305094, 0.01106478997306632, 0.024103060032108, 0.056536905001848936, 0.020672322516994815, 0.008313882630318403, 0.13836007565259933, 0.03393498156219721, 0.06095330284110137, 0.03918805718421936, 0.03942782771108406, 0.026383148040622473, 0.04596035235694476, 0.061617418990603516, 0.04883991587640984, 0.021958276995324662, 0.017121881246566772, 0.003317295365767287, 0.020605356199666858, 0.03485176718926855, 0.024020353398684944, 0.035454441992832084, 0.03879070029194866, 0.02675461203658155, 0.1015179990125554, 0.03183093946427107, 0.04633579256811312, 0.01622558059170842, 0.060554894219551764, 0.025331081190545644, 0.021900747403768555, 0.05499173827203257, 0.013086538495762008, 0.020665257271113138, 0.01936472107523254, 0.05762889515608549, 0.014782048229660307, 0.04312007940773453, 0.017303686223125885, 0.02208985172079078, 0.019997181869777184, 0.009861900055381869, 0.026384839289156452, 0.02471560243118022, 0.11378481292298862, 0.019885418670518056, 0.02163725359631436, 0.01674052929904844, 0.06544160842895508, 0.03988078376278281, 0.02836569844345961, 0.02590649584973497, 0.08612646348774433, 0.025690122906650816, 0.030316490014748912, 0.02489444729872048, 0.024016192282683084, 0.04906659067741462, 0.08324495596545083, 0.015428125525691679, 0.01701131566161556, 0.015465319422738892, 0.12105102730648858, 0.012845058060650314, 0.045408655889332294, 0.01249217998702079, 0.020623752980359962, 0.04846593451553157, 0.030009768437594175, 0.04498250536354525, 0.022247936809435487, 0.04475872790707009, 0.08385548141918012, 0.05737512305911098, 0.02306935264329825, 0.05052204489974039, 0.034271358512341976, 0.03269842952223761, 0.04833300272002816, 0.10704265149044138, 0.05601988506636449, 0.07425190388624157, 0.027625191125220487, 0.041315698730094094, 0.022457195312849114, 0.055732847790100744, 0.02599733811803162, 0.03694859306727137, 0.03464270715734788, 0.02830529016708689, 0.058935421119843207, 0.048257970317666016, 0.03115184126155717, 0.006110169675334224, 0.03348237156335797, 0.022526314282523732, 0.04897990443610719, 0.03321844518982938, 0.03768389432557991, 0.035183614918163846, 0.0254816362368209, 0.018170139818851436, 0.0605838948062488, 0.04409973469695874, 0.09499675501137972, 0.03741884158392038, 0.03761958956186261, 0.030426511075347662, 0.024538252037018538, 0.04984320793300867, 0.03159173551414694, 0.04270162346905895, 0.0022170654639402138, 0.01594243641011417, 0.05306459025346807, 0.05774248870355742, 0.02341271680779755, 0.034939332133425136, 0.038582895549812486, 0.04939286084845662, 0.021258656500971744, 0.0449868479876646, 0.0020707275128058556, 0.0438324767164886, 0.08182799842740808, 0.06720205396413803, 0.07596097074981246, 0.055733675602823496, 0.025869005093617097, 0.026164980372413993, 0.021506147060011114, 0.05348137021064758, 0.02863591144393597, 0.03483579108225448, 0.030597620643675327, 0.0487181900867394, 0.12286289222538471, 0.02191695590902652, 0.03169968704293881, 0.017943263153678606, 0.0787102725090725, 0.007203468553987997, 0.024261633665966134, 0.02177870100630181, 0.0344799401770745, 0.06094116384961775, 0.03507330208750708, 0.08109474634485585, 0.03205440140196255, 0.03410422855189868, 0.01854380396460848, 0.019902689083080207, 0.02165409822815231, 0.02832421620509454, 0.030830850092960254, 0.03409137370597039, 0.014726795123091765, 0.027420740042413985, 0.028926938506109372, 0.03739843464323452, 0.036553024114774804, 0.04324004779170666, 0.017640392262754694, 0.012903311988338828, 0.03218507028317877, 0.017934771287920218, 0.05920479952224663, 0.08505933824926615, 0.08788518554397992, 0.015423000889963337, 0.023975641333631108, 0.0427414127625525, 0.06774489554975714, 0.021478997177577445, 0.029651166072913578, 0.029752844545458044, 0.04035058105364442, 0.008200479920820465, 0.05678933020681143, 0.07563779130578041, 0.04786246243332114, 0.040659864100494554, 0.09080749337694474, 0.0870438903304083, 0.06544871269060032, 0.044979017693549395, 0.024711819598451257, 0.01616949967241713, 0.05553117700453315, 0.02665577153675258, 0.03571194942508425, 0.05849081783422402, 0.025874122943995253, 0.030993637429284196, 0.03943695739975997, 0.033599456173500845, 0.020155782645036067, 0.05008560778307063, 0.016323313383119445, 0.0450929233671299, 0.05234126513823867, 0.051964783375816684, 0.06888950270201478, 0.03545388898679188, 0.03245145634614995, 0.016474360367283225, 0.026951395673677325, 0.046096890566072295, 0.03661220254642623, 0.04572978276493294, 0.03347886014463646, 0.02909579873085022, 0.014961449495915855, 0.04718225482585175, 0.056588589014219384, 0.046103058449391804, 0.029404308247779096, 0.039675421746713777, 0.06765482002603156, 0.0365214009902307, 0.05105053546971508, 0.017377839922638874, 0.019644253754190037, 0.10502747033855744, 0.10570038030190126, 0.186133704281279, 0.11444571960185256, 0.11178004728364092, 0.14109139623386519, 0.21969203783997468, 0.2100837648447071, 0.13125236704945564, 0.16283346313451016, 0.1613523568958044, 0.14078537694045476, 0.0983455153182149, 0.17814143028642448, 0.11557723102825028, 0.20039698534778186, 0.10376548341342381, 0.16846543949629578, 0.1139781546912023, 0.1574440901832921, 0.08549030976636068, 0.1305658117468868, 0.13809172862342425, 0.15754285774060658, 0.09793937818280288, 0.18028277823967592, 0.1511418026472841, 0.11691275079335485, 0.15878847161574022, 0.06326938713235514, 0.20338739774056844, 0.18860349032495702, 0.19891259499958583, 0.13249156198331288, 0.17302987671324185, 0.10931879721049752, 0.1919763929077557, 0.11468600242265634, 0.1448042584317071, 0.10956554647002902, 0.13480771412806852, 0.13879934565297194, 0.10138769314757415, 0.15652551661644662, 0.13268536515533924, 0.09074815548956394, 0.1668196799499648, 0.19493158933307442, 0.14162290628467286, 0.07828206262950387, 0.09773085758622203, 0.1352783324463027, 0.16587032803467341, 0.0859330470806786, 0.137448857405356, 0.21980631670781545, 0.21331543714872428, 0.2881674984736102, 0.0671947868540883, 0.20094696512179716, 0.10311674286744424, 0.14038645263229096, 0.12915760731058462, 0.07956220715173654, 0.19370243671749318, 0.08313941662865025, 0.1218326317944697, 0.15816385298967361, 0.13833357207477093, 0.17046957409807614, 0.11096947613571372, 0.10884991594191108, 0.1367936504206487, 0.059237437056643624, 0.14413518219121865, 0.11978006336305823, 0.135704493150115, 0.12336382748825209, 0.25675838387438227, 0.16771563115928853, 0.10382696547146354, 0.05442774335720709, 0.1548803270395313, 0.1974811710949455, 0.09053808783314057, 0.14152306664202893, 0.05019842440794621, 0.08681711714182581, 0.22400917618402413, 0.25572839485747473, 0.135697069977011, 0.1208261608013085, 0.11483831996364252, 0.23005968651601247, 0.10607958638242312, 0.13472992687353066, 0.13196448955152715, 0.1809937743736165, 0.1874303575605154, 0.16367903990404947, 0.2109903283417225, 0.10486642005188124, 0.12969312071800232, 0.13996160828641482, 0.14070332848599978, 0.13412923339222158, 0.1289401232664074, 0.14999102082635674, 0.08878357269402061, 0.12725418087627205, 0.09807378918464695, 0.11450787340956074, 0.12247073969670705, 0.1442434356680938, 0.1933581344783306, 0.10039797518402338, 0.10864476766437292, 0.10455966115530048, 0.16045726064060414, 0.1365955996194056, 0.18978149497083255, 0.1483224489326988, 0.06975160179925816, 0.10172138309904508, 0.16793364446078027, 0.18042761832475662, 0.3666708788701466, 0.1965196191200188, 0.1143601970481021, 0.14945915793733938, 0.08079464387680803, 0.15770006073372705, 0.14333229884505272, 0.12181398565215723, 0.10254358433719192, 0.18189788157386438, 0.14152953986610683, 0.23709796741604805, 0.12827282478766783, 0.14122855530253478, 0.11676375807396003, 0.12221356135393892, 0.16613373532891273, 0.14284136518836021, 0.15718970740480082, 0.08355727206383433, 0.16091229979481014, 0.09927805313574416, 0.0880662254723055, 0.12248641385563783, 0.11322665001664843, 0.06692919467708894, 0.08760926606399672, 0.1692847976727145, 0.14400544629565307, 0.16533569672277995, 0.06805996650031634, 0.13117428123950958, 0.10813404792653662, 0.12805618212691375, 0.127083420753479, 0.10239576548337936, 0.15145529939660005, 0.10285186993756465, 0.1346027829817363, 0.08883026947400399, 0.17329679881887777, 0.11060293151863984, 0.21477073191532067, 0.09725855650114161, 0.08522154204547405, 0.16038184825863155, 0.11507762569401946, 0.17460139095783234, 0.12827144057622977, 0.12229004582124096], [0.007527580135501921, 0.03372915814231549, 0.031789175633873255, 0.01603028124996594, 0.025449366807671528, 0.018057167130921568, 0.06472610682249069, 0.0449050641618669, 0.05226431248177375, 0.03994079000715699, 0.049351711092250686, 0.08780001582843916, 0.006029350217431784, 0.05364344847787704, 0.034115709364414215, 0.02139864845334419, 0.025759869521217685, 0.014615133704085435, 0.03174478926562837, 0.03504613693803549, 0.04363554210535117, 0.02128009820756103, 0.02174019075131842, 0.010694958701995867, 0.08356012191091265, 0.036455579700746706, 0.05698209522025926, 0.02476486237719655, 0.03859955019184521, 0.03528558176809123, 0.037876605056226254, 0.04272773688925164, 0.06538604998162814, 0.027001261212197796, 0.07013514371854918, 0.04341276888070362, 0.02589471817814878, 0.03941467430974756, 0.057189889784370146, 0.04112735437229276, 0.025304799832935845, 0.011741721104564411, 0.02546387049369514, 0.050554702790187936, 0.05874773833368506, 0.09835514373012952, 0.019144241298948015, 0.08374735007860831, 0.052129745416875393, 0.05232665967196226, 0.019676143203728964, 0.03821589292160102, 0.017221342605937804, 0.029937653735812222, 0.02484767248720995, 0.03320835537410208, 0.05220086945753012, 0.021832632665921534, 0.025364610998492156, 0.03338146322805967, 0.0235666407804404, 0.04882695246487856, 0.04323728276150567, 0.036132407042064836, 0.05203172764075654, 0.02438868595553296, 0.08871306612023286, 0.02378717314318887, 0.010374050653938736, 0.03882541075082762, 0.07657156405704361, 0.0508025716325002, 0.03207230794110468, 0.04120652923094375, 0.0046211381476106385, 0.04495924857578107, 0.0540124595697437, 0.05279355961829424, 0.02049165408659194, 0.008342848442095731, 0.06572512071579695, 0.00695628800063527, 0.044826476236007044, 0.02214963235227125, 0.015315749948578221, 0.04603221260809472, 0.033301124681851695, 0.030809544093374695, 0.037921958336872716, 0.013630082365125418, 0.019297471469534293, 0.01500538972738598, 0.04627017144645963, 0.03599334468266793, 0.0031865698692854494, 0.06509934179484844, 0.05009880868185844, 0.01614304698471512, 0.06248811512653317, 0.04505210270040801, 0.029326704197696278, 0.034312420058995485, 0.03436896238209946, 0.017449768027290702, 0.08899775905800716, 0.07629894225725106, 0.05305516879473414, 0.0674905874101179, 0.006122387122429375, 0.013931790416661118, 0.01798122888430953, 0.02082786649199469, 0.025424613850191236, 0.03340690489858389, 0.017497089059491242, 0.012908321273114, 0.07814029630805765, 0.026316191901319792, 0.030387474955724816, 0.04232995591259428, 0.037291456812194416, 0.0332126131813441, 0.010576490728583719, 0.05182514426165393, 0.02742614796651261, 0.01126749298003103, 0.019400639326444695, 0.03294318388881428, 0.03766159427219203, 0.0672101013894592, 0.07994329955961023, 0.015090537390538623, 0.06557292531111411, 0.01919718399377806, 0.01807050034403801, 0.04734469950199127, 0.03833220060914755, 0.057660684521709166, 0.02748278358818165, 0.034726750504757674, 0.05522117131788816, 0.040050671968076906, 0.027315935219771097, 0.04784608259797096, 0.04391675076580473, 0.026395044455836927, 0.05663852919159191, 0.019748551371906484, 0.04096858735595431, 0.054328039421566894, 0.0470959282081042, 0.03704127077279346, 0.052081633891378126, 0.05602613776656134, 0.025290101068094373, 0.021219952863508036, 0.0825457934822355, 0.016259554840092148, 0.043605411757848093, 0.03702912838863475, 0.016030605250437344, 0.00985401971930904, 0.04744024741064225, 0.030070955332900797, 0.03171168354206851, 0.03565348006252732, 0.048184074461460114, 0.02343546469429774, 0.021216914722962037, 0.016629085011248077, 0.03517130629292556, 0.020420111050563197, 0.0238631911176656, 0.02418317466175982, 0.06589953135699034, 0.06479238612311226, 0.014527780802122183, 0.05622638362858977, 0.01052101540179657, 0.05388782286484327, 0.040403628921402354, 0.04042329965159297, 0.06546617818198033, 0.023356790255223, 0.03896643068375332, 0.035835531008030684, 0.07344659138470888, 0.022407333167003732, 0.0360049578095121, 0.045036655850708485, 0.027644242692206587, 0.01182406981076513, 0.017074141218992214, 0.04203587205016187, 0.014306943098615323, 0.05882573593407869, 0.0613899061988507, 0.016950030378731232, 0.006174030846783093, 0.03519555713449206, 0.031193523667752743, 0.018659640070317045, 0.020168467857209698, 0.02419021785525339, 0.049699460289308, 0.0070728034895312574, 0.022911413439682553, 0.08181170001626015, 0.04668921431792634, 0.03922059972371374, 0.043901100355599604, 0.03165007595505033, 0.05718649710927691, 0.02179635818382459, 0.07310752743589026, 0.052536734113735814, 0.05486765796584742, 0.026919529972864047, 0.08133131079375744, 0.08923978571380888, 0.08256559991942984, 0.02476696583575436, 0.003125370463489422, 0.09645772911608219, 0.03362241101318172, 0.004905388341285288, 0.049356311559677124, 0.1113490146983947, 0.03385923330539039, 0.004643442441842386, 0.054079698997416666, 0.017488193465396762, 0.032630569235022576, 0.0672140165365168, 0.020992166961410215, 0.012813772507277983, 0.032537589581417184, 0.010723016973185753, 0.026400123290451508, 0.02741933717126293, 0.012931245578719037, 0.060231239801006656, 0.026879375966797982, 0.06750297745955841, 0.018886318263996924, 0.023546379724783555, 0.020026078979883875, 0.053101794328540564, 0.03889116757948484, 0.004940336711505162, 0.02600759587117604, 0.043959905592990775, 0.024376277246379426, 0.07093121457312788, 0.03820936202204653, 0.012460595878240253, 0.027860861604235003, 0.056798673634018214, 0.0014879162918077782, 0.015954722982964346, 0.031239806541374752, 0.031007700067545687, 0.03305223125166126, 0.02337264422593372, 0.044422412025077004, 0.05387699005327054, 0.08553291498018162, 0.0009378414168687803, 0.03935070202818938, 0.01405053913393723, 0.012252311920747161, 0.05994411092251539, 0.010263110178389719, 0.03456110653600522, 0.05054413799994758, 0.00670643147480275, 0.05992941385401147, 0.023988312975104367, 0.05073413798319442, 0.017910881766251156, 0.03270578823451485, 0.043684661255351136, 0.10428056613143001, 0.02590431266331247, 0.03970565048179456, 0.052866960143936534, 0.022061558506850685, 0.10651993525347539, 0.07519559681947742, 0.06354320315378052, 0.03380947293979781, 0.01084279197467757, 0.03264997533655592, 0.062438134237059524, 0.022665390212621008, 0.021322959568351507, 0.05015466907726867, 0.02598609309643507, 0.061240377436791144, 0.04977392272225448, 0.03864305107189076, 0.015485334509451474, 0.012525498600942748, 0.029727718393717493, 0.05007853405550122, 0.03200406767427921, 0.06218314756240163, 0.038807365112006664, 0.0025595695853033768, 0.00450791058496439, 0.05742772309375661, 0.06111818685063294, 0.039383336169911284, 0.03795124051560249, 0.016750468140734092, 0.011450537979336721, 0.05827528118555035, 0.018631662375160625, 0.042488325985946825, 0.05648973664002759, 0.0064301362560529795, 0.03230066550895572, 0.05217534636280366, 0.08329028210469655, 0.024238616061796035, 0.013808450561815074, 0.06679107887404305, 0.06694780010730028, 0.02955204907006451, 0.05923093669116497, 0.023101589842034236, 0.054452543812138696, 0.00976172199339739, 0.05074959161824413, 0.0409225521476141, 0.026297800209639326, 0.03851514043552535, 0.030686427306916033, 0.017189860277410065, 0.13438045419752598, 0.06416108392711196, 0.014153211660284017, 0.07670379017612763, 0.03899940409298454, 0.037542267103812525, 0.05110677584473576, 0.035944880318960974, 0.01531222665549389, 0.061978358908423355, 0.01973406125658325, 0.028554117440113, 0.02526243041003389, 0.1600397444729294, 0.19495896143572672, 0.047542818156736236, 0.12147914219115462, 0.12248549104801246, 0.12288144337279455, 0.13675592387361185, 0.17011491741452897, 0.14285307670278208, 0.09822716524026223, 0.18203459280942166, 0.21963608584233693, 0.1502887484218393, 0.15402278091226304, 0.06786116931055274, 0.06563003081828356, 0.10053607741636889, 0.09900323288249117, 0.089253179995077, 0.11314369911061865, 0.08589020437960114, 0.1843584802533899, 0.09069214242377452, 0.10056870816541569, 0.1051234830436962, 0.14496281849486486, 0.13955280450837954, 0.13063720720154898, 0.14774413353630475, 0.14965119691831724, 0.07408023452652351, 0.13224412740341254, 0.15487130252378328, 0.09706486189471823, 0.15561509904052528, 0.13141266416226113, 0.1652168852410146, 0.13703424536756106, 0.19421745836734772, 0.1798349722687687, 0.18841773457825184, 0.0958422842834677, 0.14352972539407866, 0.13227109238505363, 0.24460544171077864, 0.16172203634466442, 0.1685847123818738, 0.3046545423567295, 0.10829549176352364, 0.13321778444307192, 0.06345305977655308, 0.13584261573851109, 0.11714688608688967, 0.14220139810017177, 0.10144346872610704, 0.10210725239345006, 0.12909986398049764, 0.14910043004368032, 0.11007235784615789, 0.06679392872112137, 0.11653427753065314, 0.10070254919784409, 0.10678195833627667, 0.12974391584949835, 0.10229878247316394, 0.08023489998387438, 0.19374859066946165, 0.18700598818915232, 0.07061406730541162, 0.1644274097468172, 0.24484567024878093, 0.17287502145128592, 0.14070144215864794, 0.1694747603365353, 0.06006828961627824, 0.11750338838568755, 0.089383004100195, 0.12027909872787339, 0.2221484567437853, 0.12710731875683579, 0.19977179675229959, 0.1122417767931308, 0.11003305031252758, 0.13693811052611896, 0.11383344352777515, 0.06486768993948187, 0.1421641329569476, 0.11720928416720458, 0.15677000635436603, 0.15878092630633286, 0.14434498521898473, 0.08909470814147166, 0.10264633489506585, 0.1999005555574383, 0.07592858427337237, 0.11482180442128863, 0.09166771971753665, 0.12800603838903563, 0.18055230591978344, 0.17913586406835488, 0.08237591545496668, 0.10720928612032107, 0.13309198405061448, 0.10581078473478556, 0.1445615735969373, 0.15662978030741215, 0.17866512361381734, 0.09378307299422366, 0.09944597698215928, 0.10703728427844388, 0.08322029800287314, 0.17110589066786425, 0.1716457466994013, 0.13153180134083542, 0.15215393262250082, 0.0917164453172258, 0.1320909277669021, 0.13464331866375037, 0.17043169827333518, 0.10206842661968299, 0.14048642798193864, 0.11707629130354949, 0.0917234206572175, 0.1803302756909813, 0.09640518336423806, 0.18787331879138947, 0.11158528737723827, 0.12036629047776971, 0.19542116591972963, 0.1475317927875689, 0.11762597252215658, 0.13314751535654068, 0.159897170694811, 0.12055932011987482, 0.1697093163217817, 0.09810693562030792, 0.11814745382538863, 0.12444854713976383, 0.07126141006925277, 0.16054924284773214, 0.1108407105452248, 0.0739362629662667, 0.09477775104876075, 0.10697878098913602, 0.11321006662079267, 0.13403345138898917, 0.11552977428904601, 0.1991317075278078, 0.16771732749683516, 0.10447455929326159, 0.14904213031487806, 0.12078812212816306, 0.10808853179748569, 0.22684830240905285, 0.055435679986008575, 0.10625129645424229, 0.1530953049659729, 0.1241072847374848, 0.12143600093466894, 0.08772581123879977, 0.15495841284947737, 0.06385275761463813, 0.17251048529786722, 0.1994887390839202, 0.15015860540526255, 0.05884088083569493, 0.17299991260681832, 0.14070640903498444, 0.14676014919366154, 0.19546965403216227, 0.0888753988380943, 0.11056052307997431, 0.11546572058328561, 0.17398623110992567, 0.15842506183045252, 0.15188664410795483], [0.06308521915759359, 0.03363485873809882, 0.01925528864376247, 0.02061775981980775, 0.012902761526804949, 0.0076113478280603886, 0.026542641089430878, 0.02635626957219626, 0.026966145328645195, 0.063242347511862, 0.016656969407839433, 0.021934212750888298, 0.045605685495372326, 0.021996059521500553, 0.03021516098773905, 0.028180205629074147, 0.03742725541815162, 0.01293119553676141, 0.01877965934441558, 0.025000844982319644, 0.028692402876913548, 0.026203098773424114, 0.040808890746640306, 0.013936698769352265, 0.022515101491340568, 0.028953224952731813, 0.030694172784153904, 0.06701487329389368, 0.017569364913340126, 0.031210005283355713, 0.048969868903181384, 0.042563718011868854, 0.03972131446270006, 0.02996966362531696, 0.009767322451807559, 0.03434933575668505, 0.013870346526216184, 0.011140573852961617, 0.012996725904356157, 0.024953211824010526, 0.027948796349976743, 0.006086304326475198, 0.07664411302123751, 0.022311147435435226, 0.007998540265751737, 0.013372882818137961, 0.003762180243419217, 0.0262823754123279, 0.08569687618208782, 0.028106101123350005, 0.02788634568319789, 0.03140073808442269, 0.007492236942718071, 0.04955991956272295, 0.03918489860370755, 0.02067914857928242, 0.03926511162093707, 0.0615174707823566, 0.015634186432829926, 0.02043842979972916, 0.03410635236650705, 0.009690006779107665, 0.07013701647520065, 0.01290719151230795, 0.046841260444905074, 0.029684326079274927, 0.05391168694144913, 0.07266848135207381, 0.04396145265283329, 0.02787472407466599, 0.042179297389728684, 0.04288214771077037, 0.04298057260790041, 0.038551557409976206, 0.07830487497683082, 0.05225307254918984, 0.03814992913976312, 0.017337302544287274, 0.06054930987634829, 0.021100028584312116, 0.02893302496522665, 0.06863836332091264, 0.134710873610207, 0.06861642628375973, 0.03244061674922705, 0.058671511709690094, 0.05476270556183798, 0.04336861660704017, 0.04294729046523571, 0.030493981204926968, 0.03144876818571772, 0.04887040245479771, 0.06333530002406665, 0.025453512656635473, 0.050876399635204246, 0.04870040907657572, 0.04995759875912752, 0.04028586238356573, 0.07021377914186035, 0.04296294426811593, 0.030744516689862524, 0.014640373510441609, 0.058793430881840844, 0.04010467317753604, 0.018489185288282375, 0.04789131034963897, 0.04314899857022932, 0.0095044630745958, 0.014047400909475982, 0.08069715196532862, 0.05489735405093857, 0.029487289687884704, 0.037385386414825916, 0.04243745282292366, 0.011266844979088222, 0.08271803281136922, 0.030165672036153928, 0.02360455901362002, 0.07353560160845518, 0.020097686476739388, 0.0025236144387495835, 0.01825092959084681, 0.019929051864892244, 0.018557739377553974, 0.02185605569476528, 0.029735328163951635, 0.11710713750549726, 0.03169653185510209, 0.02187467978468963, 0.04208258579352072, 0.012686071368599576, 0.01297251577489078, 0.008000673410216612, 0.06638450069086892, 0.022809955491019145, 0.04187044521261539, 0.012247327232866414, 0.008030778312656497, 0.014951400392289673, 0.008490682562946208, 0.034213605004229715, 0.028535128637616123, 0.03833716409280896, 0.011958145785943737, 0.09587467075990778, 0.02279306166539235, 0.008251256392603474, 0.058564825648708005, 0.034383204832140885, 0.07657906186899968, 0.043925951700657606, 0.020406828727573156, 0.028787808293210607, 0.01932574263108628, 0.05662347589220319, 0.011736338625528982, 0.052448524561311514, 0.01924722934407847, 0.023801502106445174, 0.04278129365827356, 0.01047197004247989, 0.02452282893604466, 0.0025762505205680747, 0.08924887808305876, 0.03309499252853649, 0.06318685013268675, 0.028580108724002327, 0.020081040316394398, 0.020518513895305138, 0.028764079923608472, 0.05504037905484438, 0.028615063455488, 0.03997409589854734, 0.013996725369776999, 0.024370530054771473, 0.0713171652917351, 0.03776325238868594, 0.05201942580086844, 0.04506119167698281, 0.014256061453904425, 0.031120567582547665, 0.015042264712974429, 0.028255226157073463, 0.017456901126674244, 0.048296433075198104, 0.014721728162840009, 0.029969751834869385, 0.02438765627864216, 0.0698373754109655, 0.036337100701140504, 0.030510873334216218, 0.01939299562945962, 0.014454286977914827, 0.00960027561190405, 0.04508219912116017, 0.04577042022719979, 0.045677708594926765, 0.025049175335360423, 0.0572873070569975, 0.02819814609496721, 0.012833232043444045, 0.020818248258105347, 0.04092069296166301, 0.03273792365299804, 0.030417968319462876, 0.04550746076607278, 0.027899678896314332, 0.00981116938471262, 0.05580409735973392, 0.024580658779346516, 0.024355644692799876, 0.02441656356677413, 0.037166898138821125, 0.06758309208921023, 0.02644392442224281, 0.021859395783394575, 0.003959645808208734, 0.01347242305720491, 0.02785578276962042, 0.022803673953084008, 0.057059780694544315, 0.03158763037728412, 0.020680095135633434, 0.045627385045268705, 0.012121055258571036, 0.00518262799596414, 0.018216190294229558, 0.002197250545058133, 0.049061372743121216, 0.10612621530890465, 0.026078502780624797, 0.043188740366271565, 0.042046192567795515, 0.030342067392276864, 0.03940100522179689, 0.04172969330102205, 0.007503621912162218, 0.034941781644842455, 0.0388311918691865, 0.03701791220477649, 0.031116336916706393, 0.04241754460547652, 0.013389839408253985, 0.023827678291127086, 0.06548186591161148, 0.10706070730728762, 0.04804604686796665, 0.018392446550673673, 0.08204905156578336, 0.05998392735740968, 0.03961855372680085, 0.01763905894144305, 0.02314868865401617, 0.03876970302579658, 0.06085217398192201, 0.03507104595857007, 0.02320382640963154, 0.03270618857017585, 0.053250970252390416, 0.004231490685404944, 0.027296773390844464, 0.03449607913249305, 0.022308433295360634, 0.022284082369878888, 0.06712747618023839, 0.040065111193273745, 0.04893633909523487, 0.017052355155880963, 0.02070795408716159, 0.05745062365063599, 0.07732789990093027, 0.04001053662172385, 0.008498679946309753, 0.04175975240234818, 0.05842067088399615, 0.03652479027264884, 0.05198364664933511, 0.019022486671539288, 0.022505644409518157, 0.04099373386374541, 0.04074220771768263, 0.08364392777106591, 0.031107600778341293, 0.0139842869747164, 0.030320415339831795, 0.07978460378944874, 0.025037755590996573, 0.08061636558600835, 0.02024379202962986, 0.06458356697112322, 0.017641058923410516, 0.025015536961810927, 0.050032159579651694, 0.035695003012993505, 0.110458267852664, 0.027877107428918992, 0.03035898327029177, 0.044527710481945953, 0.03225742925756744, 0.03334272905652012, 0.0915232121146151, 0.024181625905579755, 0.01977221867335694, 0.02725637680850923, 0.035757485910185745, 0.044066700219575844, 0.044976456223853996, 0.0421161834549691, 0.01945120545237192, 0.042199388811630864, 0.12303088392530169, 0.11938559024461678, 0.020373767108789513, 0.0467729726806283, 0.041262118212346516, 0.02628894872032106, 0.025460362467648726, 0.01838753734981375, 0.033942757573510916, 0.08090112637728453, 0.014825639015595828, 0.023813240762267793, 0.03337168553844094, 0.045913275597350936, 0.02685786471036928, 0.02293991530314088, 0.05857121744858367, 0.020112466665783098, 0.03796959149518183, 0.005698083060061825, 0.04179703450894781, 0.03977680505652513, 0.04455235826649836, 0.011237377051397093, 0.018188877563391413, 0.025824014829205613, 0.026427790555836897, 0.013756993858675872, 0.050749001292777915, 0.09964180218854121, 0.02280369770180966, 0.00954077487611877, 0.024838729395664165, 0.0031995924405886656, 0.010604800057730504, 0.007865751810771014, 0.08425427002034017, 0.01671042778928365, 0.0465727641380259, 0.020745027544242994, 0.015517458053571838, 0.04515829682350159, 0.14017916018409388, 0.14840860930936678, 0.11708138031618935, 0.13743577525019646, 0.11371797722365175, 0.16988892454121793, 0.20158153107123716, 0.12506461622459547, 0.11827253497072629, 0.09691928220646721, 0.06331812630274467, 0.11403602015759264, 0.23698780047042028, 0.08858573902398348, 0.09003220604998724, 0.09581785023744617, 0.11881659791937896, 0.10905861974294696, 0.13901053289217608, 0.1470300161412784, 0.17258084937930107, 0.10697333235293627, 0.12340698231543813, 0.13868947726275238, 0.10804403347096272, 0.262438210525683, 0.13067987348352159, 0.13590683229267597, 0.13820622462247098, 0.17106668491448673, 0.11079045145639352, 0.11846271476575307, 0.1616836041212082, 0.10930230202419416, 0.07433047145605087, 0.08725967125168868, 0.08676628129822866, 0.14625461346336774, 0.0751868708591376, 0.0877413632614272, 0.11372082028537989, 0.1376867246414934, 0.16500796430877276, 0.13409374601074628, 0.09726897201367787, 0.11037915745483977, 0.11310152137385947, 0.19265186094811984, 0.13394251412578992, 0.14589542416589601, 0.10447880692247834, 0.11155591359628098, 0.1308423826204879, 0.24661602239523614, 0.13783346462462628, 0.07744584285787173, 0.11399619015199797, 0.12503254865961416, 0.10259531584701367, 0.10867089126259089, 0.11854707023927144, 0.18466525950602122, 0.19222097764057772, 0.1129715751324381, 0.11273100732692651, 0.15715424716472626, 0.1216826212725469, 0.1498285795428923, 0.14821557966726168, 0.17496907551373753, 0.13002740778028965, 0.10461019844348941, 0.16820258860077175, 0.189125405890601, 0.15087751325752052, 0.215114260624562, 0.08212599065154791, 0.10455303186816828, 0.17328320097710403, 0.21245927523289407, 0.12823220768145152, 0.1572991143912077, 0.2437384639467512, 0.08635671756097249, 0.2110355594860656, 0.15769273255552563, 0.1437198237649032, 0.1731392972703491, 0.14424281141587666, 0.16300631314516068, 0.11711785835879189, 0.23585472841347965, 0.16095940369580472, 0.18333932065537997, 0.1580308736967189, 0.15078318331922802, 0.23784886140908512, 0.09907990733959846, 0.14866254425474576, 0.10387757061315434, 0.10912349447607994, 0.11132369855684893, 0.15470663564545767, 0.09948742190109831, 0.09796892838286501, 0.1617890348924058, 0.14712874298649176, 0.08805982688707964, 0.12680576422384807, 0.1268250753304788, 0.16741125392062323, 0.17771241973553384, 0.10775175451167993, 0.20159282189394745, 0.18812323680945806, 0.14784011910004274, 0.11612280032464437, 0.07393504160323314, 0.1786661007042442, 0.1984916047326156, 0.12128793102289949, 0.1098330792571817, 0.18928510589259012, 0.09151588393641369, 0.12401782668062619, 0.10163775365799665, 0.18817352982504026, 0.06604410681341376, 0.09234370344451495, 0.12319556437432766, 0.09878898545035295, 0.19180853691484245, 0.27965869648115976, 0.19535701721906662, 0.18419257844133036, 0.23205476946064404, 0.17871137256068842, 0.18280713206955365, 0.15848256088793278, 0.09677964648497955, 0.1453802939504385, 0.10647353702890021, 0.09085873634155307, 0.22897432904158319, 0.1454879231750965, 0.1012316368786352, 0.1848675307950803, 0.14939541635768755, 0.11199951943542276, 0.2190830119486366, 0.1436833864344018, 0.12654194980859756, 0.13572740049234458, 0.10226837053362813, 0.10610802378505468, 0.12460030828203474, 0.17958987184933253, 0.14006193647427218, 0.13728180208376475, 0.1232921334781817, 0.1353667319885322, 0.12160160419132028, 0.08455258115593876, 0.1917436553963593, 0.14833129702934197, 0.15883580621864113, 0.10221977385559253, 0.13361626091812337, 0.13110391715807573, 0.14042514269905432, 0.16142230028552668, 0.18092304388327257, 0.11181164665945939, 0.06183254173291581, 0.09316101923052754, 0.09141655998038394], [0.03276225591876677, 0.07701735477894545, 0.0330576866732112, 0.027055806946009398, 0.05223312022696648, 0.029192612107310976, 0.008610588182429118, 0.009473085918995951, 0.04834078212401696, 0.022174052827592407, 0.06140111559735877, 0.03287807845377496, 0.050551876691835265, 0.03829218400642276, 0.006429102338318313, 0.007562730793974229, 0.050243462169809, 0.024650286650285125, 0.02194794629966574, 0.028394388600385616, 0.022854898257979324, 0.005766588803713343, 0.0037832161012504783, 0.005572442547418177, 0.01891096944122442, 0.025028758216649294, 0.004823949296093945, 0.026820988028443286, 0.031299073182578595, 0.07627560065260955, 0.03061983248751078, 0.12394830398261547, 0.05790245333420379, 0.020474683925775543, 0.04862784314900637, 0.011463422511172081, 0.028512221295386553, 0.005352132404888315, 0.020578744056235467, 0.01791797754620867, 0.020648439780675938, 0.021762372061078037, 0.015615474133353149, 0.0222057590726763, 0.03458533362884607, 0.07226993702352047, 0.03856997285038233, 0.048531888119344196, 0.04061205791575568, 0.020604195904784968, 0.014693346739347492, 0.0436643934143441, 0.038332176860421896, 0.08864724143807377, 0.05461320733385427, 0.00495986919018573, 0.050483728027237315, 0.011645825446716376, 0.032669968370880396, 0.027381325639518242, 0.05649336340970226, 0.017041429045743177, 0.024956037922363197, 0.038487764940197976, 0.05493678372087223, 0.00795585023505347, 0.04314608426232423, 0.013572172793958868, 0.014107652274625642, 0.06878224667161703, 0.047157932738108296, 0.018033839096980434, 0.08492804850850787, 0.024773266033402512, 0.011731200419100267, 0.03969249029510787, 0.017732830784682716, 0.008518024131522646, 0.012546587469322341, 0.034413118048438, 0.026106958842969367, 0.02155240618490747, 0.06636213617665426, 0.026091296558401415, 0.06406247921820198, 0.11140008802924838, 0.006628016151288258, 0.06561173072883061, 0.022922884074172804, 0.07152854252074446, 0.03383836496089186, 0.02534847882842379, 0.04829447210899421, 0.0843869914699878, 0.05526077740692666, 0.030266458235148872, 0.034324392809399536, 0.049677319691649506, 0.00916084021862064, 0.026529280734913688, 0.004415176052134484, 0.016326929974768842, 0.05057467207578676, 0.05640658556616732, 0.043200485807444365, 0.058558128508073945, 0.03684564234156694, 0.04555849677750042, 0.03126993349620274, 0.05096986783402307, 0.0653551969943302, 0.04717847877847297, 0.09654870709138257, 0.007508114662154445, 0.045329114621771235, 0.01592804298603109, 0.00594049648082416, 0.061699725288365564, 0.05092992926282542, 0.04825012306017535, 0.043378228055579324, 0.05313685084027903, 0.03503651191879596, 0.01173541581790362, 0.02486930418360446, 0.011249281100130506, 0.020848319233794297, 0.05724287658397641, 0.037491475364991596, 0.025242613794814264, 0.013432314852252603, 0.04503614016409431, 0.06193851533212832, 0.025871150960613574, 0.01858537271618843, 0.05999046164963927, 0.0901613516200866, 0.03777297240282808, 0.013917749830787736, 0.026844034470351677, 0.06246248685887881, 0.02705880267811673, 0.030328693467059305, 0.0875862840829151, 0.025914685767410055, 0.06741572464151041, 0.020874617554779564, 0.027276100125163794, 0.0630859180486628, 0.008981031831353903, 0.024321444831522446, 0.04212638862164957, 0.026402399775439074, 0.03526027241189565, 0.029924354449446713, 0.015901892246412377, 0.03417123727766531, 0.05981315366391625, 0.08190816733986139, 0.017702359473332763, 0.018352825194597244, 0.03436476903568421, 0.003730523192124175, 0.022205200977623463, 0.03495714028498956, 0.0345678443887404, 0.02905347171638693, 0.04080544378874557, 0.044011423364281654, 0.0516060758382082, 0.03344612082998667, 0.035923818591982126, 0.016213232950706567, 0.052097308050308905, 0.0463513649467911, 0.020986146659457257, 0.016324317614947046, 0.02507397748662957, 0.04817753677655544, 0.06035932685647692, 0.031579311537955485, 0.07606440662805523, 0.03807410963677934, 0.02704168323959623, 0.04103576571547559, 0.0587745268962213, 0.0726825405976602, 0.07935559323855809, 0.06296720156180007, 0.024230968972135867, 0.021729398651846817, 0.009110269003680773, 0.07879495367939983, 0.019749285886064172, 0.03320020277585302, 0.019759772644777383, 0.07032805800970111, 0.017766679504087994, 0.05464375498039382, 0.02715266781992146, 0.04312944997634206, 0.033883602890585146, 0.0925777776698981, 0.01712584219473813, 0.05885947269520589, 0.08413183516157524, 0.03985574582059469, 0.060769603055502684, 0.02220288717320987, 0.03506646923986929, 0.03185136676100748, 0.06353478931954928, 0.0561753102977361, 0.025880238240850822, 0.030698444162096297, 0.036304252820887735, 0.04077893681824207, 0.023438725055062344, 0.026001419506168792, 0.036519032903015614, 0.043241703417152166, 0.049131149891763926, 0.05899026710540056, 0.056717710835593085, 0.047221474149929624, 0.022725544038361738, 0.021157639600070458, 0.04403828995834504, 0.04414597346580454, 0.05891090564961944, 0.06510827810104404, 0.035537986617003164, 0.07070944897298302, 0.03455350694379636, 0.034627569041081836, 0.03361727789576564, 0.01919052077989493, 0.03619471012747713, 0.040602229336010556, 0.038930366547512155, 0.029265069469277347, 0.024705107190779278, 0.08251540189875023, 0.033789127067263634, 0.02348331328747528, 0.05428635701537132, 0.018536172141986232, 0.04996291168832353, 0.035031182026224475, 0.02391744847409427, 0.01320690127821373, 0.04403897527871387, 0.05555095290765166, 0.010550167810704027, 0.12395854986139707, 0.053014449908265045, 0.012006575374730995, 0.031210198665836027, 0.011671626740800483, 0.03511798022580998, 0.031191474491996423, 0.056924989713089805, 0.0363760112917849, 0.04593993184555854, 0.04265649410496865, 0.05879454367927142, 0.02030565745995513, 0.02861580645133342, 0.06082742102444172, 0.046423801952706914, 0.03711121076984065, 0.012944865472880858, 0.039678929772760184, 0.043964390709464035, 0.03142135876363941, 0.09234324882605247, 0.014845589641481638, 0.008763133880815335, 0.05401604223464217, 0.0632106667118413, 0.05476702782990677, 0.020888266286679676, 0.022140919962631803, 0.018861392280086875, 0.024500830830740075, 0.02333199997831668, 0.05478623715628471, 0.06842007182006325, 0.03796377984274711, 0.05456239863165787, 0.04442464440528836, 0.026736717371802245, 0.042784336887832196, 0.03217274469456502, 0.04447061515280178, 0.05262669089383312, 0.01704683866617935, 0.012710919320982481, 0.05741196751062359, 0.0069107154683609095, 0.05802801623940468, 0.021320867984156524, 0.035161837336740324, 0.0023734947150972274, 0.012912314451698746, 0.043342550684298785, 0.042434243352285454, 0.025667451355340223, 0.06583632582000323, 0.018093645173524107, 0.027664732753432224, 0.01606134288678212, 0.012172299071348138, 0.03229797172493168, 0.03135425165029509, 0.02943255566060543, 0.05512653264616217, 0.04805075590099607, 0.07087420406086103, 0.06236597203782626, 0.0247779156946178, 0.0688680542100753, 0.029360556309776645, 0.02624150724815471, 0.007304588083310851, 0.011056466892893826, 0.017047452740371227, 0.03766653400712779, 0.053689364942588975, 0.06396658864936658, 0.0168905313392835, 0.044666959438472986, 0.044477583707443306, 0.062328360841742585, 0.04152533890945571, 0.047653470254902325, 0.03826862866325038, 0.03152829248990331, 0.02125671419448086, 0.0037757742684334517, 0.01492134468363864, 0.030780947235013758, 0.07036117730396134, 0.027463808356385146, 0.03851507258202348, 0.01861923330995653, 0.015781937433140616, 0.04217606756303992, 0.011028941271693578, 0.049221300054341555, 0.03383744554594159, 0.008947373949922621, 0.09922459136162486, 0.12234390793102128, 0.14617016299494676, 0.18968886137008667, 0.29384623946888105, 0.11338614645813193, 0.11601297264652592, 0.12190579144018036, 0.19352086074650288, 0.12880711683205195, 0.14849210982876165, 0.16706682954515728, 0.14677234925329685, 0.12049789912998676, 0.07435829817716565, 0.12610873234059128, 0.15732886136642524, 0.07262261238481317, 0.15231759526899882, 0.1461854571742671, 0.11857718362339906, 0.06720351281442813, 0.1460362066115652, 0.09549680139337267, 0.058722340767937045, 0.13925658326063836, 0.19120465431894573, 0.1056710947304964, 0.11132103191422564, 0.26400285799588474, 0.15549670825047152, 0.18876635230013303, 0.11634918674826622, 0.21249554971499102, 0.21587966169629777, 0.13427765614220075, 0.14022671191820077, 0.1540580918746335, 0.12857911549508572, 0.1470260534967695, 0.06579726934432983, 0.1654269325413874, 0.08102868417544024, 0.11868456857545034, 0.14288950046258314, 0.06236744445881673, 0.13333895722670214, 0.1119384987811957, 0.13700683255280766, 0.1483173327786582, 0.08426754895065512, 0.12911320397896425, 0.09795193786599807, 0.18841662178082125, 0.17349662738186972, 0.11882277258804866, 0.13740539045206138, 0.09653360290186745, 0.08378998921918017, 0.11509026001606669, 0.1811755539051124, 0.13205896876752377, 0.12982239520975522, 0.11695121015821185, 0.194811610771077, 0.22442462960524218, 0.14542624434190138, 0.10526684392243624, 0.0717591562175325, 0.13014799702380384, 0.15175454691052437, 0.1036892771454794, 0.19378985916929586, 0.09408390149474144, 0.0818875263045941, 0.10964864665376288, 0.10470768356961863, 0.09850131374384676, 0.21535102863396915, 0.09053278847464494, 0.11157033246542726, 0.0815113057781543, 0.09101079603923218, 0.08351359476468392, 0.18787673860788345, 0.2975650727748871, 0.11370995015438114, 0.24231446321521485, 0.09681711518870932, 0.12685491730059895, 0.16136888600885868, 0.14249228606266634, 0.15553538474653447, 0.11273435928991862, 0.16766628809273243, 0.10295949237687246, 0.08930183774126427, 0.12074392235704831, 0.09924478456377983, 0.16366587632468768, 0.11988340424639837, 0.08419430788074221, 0.14352224793817314, 0.12624772345381124, 0.18310868660254137, 0.12275694576757294, 0.2253568417259625, 0.11035068612545729, 0.13154553488961288, 0.08407823768045221, 0.17796148279947893, 0.1298143206430333, 0.18306265478687628, 0.10135705729148217, 0.12364525667258672, 0.08135735296777316, 0.07595923370016472, 0.11453143214540822, 0.1354809972856726, 0.1727550293185881, 0.14417776704898902, 0.12579268429960522, 0.1119157610727208, 0.10850388343845095, 0.10713483047272478, 0.08753423366163458, 0.09042042307555676, 0.2334538001034941, 0.07746075705758163, 0.11484518673803125, 0.08518878916012389, 0.21724752044039114, 0.1361933233482497, 0.07545308050300394, 0.08998981796737228, 0.13994642267269747, 0.1860416813620499, 0.16893064310508116, 0.11926426818328244, 0.09340845381042787, 0.13549924987767423, 0.09865346843642847, 0.0941092719190887, 0.17253507540694304, 0.10393198912164994, 0.15073823715959275, 0.1256638847823654, 0.08112408619906221, 0.17644197147871765, 0.17873160647494452, 0.09473342235599246, 0.08290698445801224, 0.08186195910509143, 0.10108380445412227, 0.08798493019172124, 0.08421705237456731, 0.18407758032636984, 0.112327326488282, 0.16910319456032344, 0.11170901823788881, 0.1713232932878392, 0.16413449974996702, 0.1369498356112412, 0.08750082938266651, 0.0985651503184012, 0.1214409949524062, 0.1800452774124486, 0.09456950186618737, 0.24876575704131806, 0.08875246864876576, 0.07842523351843868, 0.13041603192687035, 0.11766699674938406, 0.24193052096026285, 0.1597253791987896, 0.05296581591080342], [0.03380719306213515, 0.019259973928066235, 0.02814993618189224, 0.03297386724235756, 0.03566892012687666, 0.027215854697195545, 0.04352903924882412, 0.017622655357367227, 0.031051167020840303, 0.060481659934989045, 0.05705514630036695, 0.047009482846728394, 0.00569170101412705, 0.04478738583358271, 0.01396430072574211, 0.022867439281461493, 0.012176455946506133, 0.052730696741491556, 0.05390689309154238, 0.03664823954126664, 0.07549669673400265, 0.02947557478078774, 0.022537596623546312, 0.05536394865651216, 0.09324441796966962, 0.06290869148714201, 0.04561635545854058, 0.031671341242534776, 0.03145682578906417, 0.03835302145619478, 0.035967987829021046, 0.025731840935934867, 0.02903020814327257, 0.051510290442300696, 0.025609412862520133, 0.056221247118498595, 0.03955329901405743, 0.019309294942234243, 0.007984972109885087, 0.07402203657797404, 0.03408247471920081, 0.023030296167624847, 0.04235761299995439, 0.028863268172634498, 0.053488050387906175, 0.031072242318519523, 0.016556698895458664, 0.02310794941149652, 0.019436041891042675, 0.04428598916690264, 0.0191074256851737, 0.015138742214600955, 0.021246688839580332, 0.07084845365690333, 0.004284369767576988, 0.042997193323182206, 0.03840700230960335, 0.023819082948778356, 0.039310169738850424, 0.06780220461743218, 0.026047337667218277, 0.040565859859011004, 0.05230533331632614, 0.021509052886228477, 0.05751034151762724, 0.03840422710137708, 0.04645544882597668, 0.05142662368182625, 0.051209170171724896, 0.03174299454050405, 0.038122258481702635, 0.10101224615105561, 0.04530471110982554, 0.07265410998037883, 0.03189913223364523, 0.029184439153011357, 0.04653254058212042, 0.02048160837564085, 0.03852357801848224, 0.01711989313896213, 0.0991878690464156, 0.052859553934207985, 0.031000456706221615, 0.012839760398492217, 0.020635393248604875, 0.03433614842859762, 0.0031437273802501814, 0.061941053053098064, 0.08137808221259288, 0.05838527849742344, 0.032650341745465994, 0.044927479566207955, 0.009773593811717416, 0.06612929688500506, 0.008648670112181987, 0.02343228236506028, 0.07446959149092436, 0.06127020583621093, 0.10303115924554211, 0.02043018051023994, 0.06023381823407752, 0.04400902474299073, 0.1434417872556618, 0.02298458495975605, 0.025323364551046064, 0.06850988271513156, 0.019218523920114552, 0.043320403301290104, 0.02649033791385591, 0.033760075590440204, 0.02013635279477707, 0.01304698923403131, 0.05587114001225148, 0.015886245228882347, 0.006555966758501849, 0.025441751948424747, 0.036602709841515334, 0.0646792132673519, 0.07517958339303732, 0.0654608720381345, 0.01090307641840939, 0.023697711693655168, 0.039932749367186, 0.006126448578600372, 0.024683170153626373, 0.03737089290682759, 0.10659012970115457, 0.07934565948588507, 0.005926243852757449, 0.020606367216844643, 0.019508785934054425, 0.009619132948241063, 0.03482509397768548, 0.03491069456296308, 0.07738277302788836, 0.02109971476186599, 0.03011265809514693, 0.04097462971029537, 0.019827568471165638, 0.025992768184681023, 0.028938605915755033, 0.04127666939582143, 0.03245112047131572, 0.07926586376769201, 0.01862564546588276, 0.05149446700566581, 0.01568163638668401, 0.037163658134107075, 0.004781297432990479, 0.07729679585567542, 0.0449195237431143, 0.021447492796661596, 0.017014704944033707, 0.03475053994251149, 0.010943017534113355, 0.05761089362204075, 0.032594518669481785, 0.03399283345788717, 0.051706132612058094, 0.02890651799472315, 0.08501264825463295, 0.024558645407004014, 0.043799730616488626, 0.012787821935489774, 0.030684198319379772, 0.06689581075417143, 0.02908839930647186, 0.02521178455624197, 0.04570573548387204, 0.014696998954085367, 0.004958252156419414, 0.030071152108056203, 0.03937453217804432, 0.032585612897362025, 0.037480567914566824, 0.006735472349516515, 0.04785524282072272, 0.07854765480650322, 0.05982031220836299, 0.002295811997360683, 0.05773668722914798, 0.03647684838090624, 0.062106656309749396, 0.05277047585695982, 0.03932930103370121, 0.03304225339421204, 0.0014886941685940006, 0.0230721889196762, 0.017252232912661772, 0.03655161276193602, 0.012378701790502029, 0.03619185349504862, 0.02804370643571019, 0.005497526344177979, 0.02449809803095247, 0.03626386641657778, 0.026921604593683566, 0.026882280096677796, 0.03752317312838776, 0.0331866083267544, 0.07158581766166858, 0.02575354048583124, 0.03325563230152641, 0.10320188544158425, 0.027642361453867385, 0.004536138065824551, 0.04880747511716826, 0.011114551186827677, 0.07865206777517285, 0.02270810229570738, 0.01427738441686545, 0.06951484057520117, 0.08151830147419657, 0.011534585567590381, 0.025622559478506446, 0.05153747934049793, 0.06930721564484493, 0.03621981592316713, 0.04331093095242977, 0.022160819698391215, 0.10310233756899834, 0.009935737387942416, 0.016740661613377075, 0.028878969472966025, 0.06911377209637846, 0.06405078127448048, 0.036243120208382607, 0.012556599253522498, 0.016081439397696937, 0.0229909614925938, 0.02807842707261443, 0.062208931893110275, 0.037720491111810715, 0.056619964473481686, 0.054163990010108264, 0.05402022201035704, 0.034575070786689005, 0.10500792174467019, 0.02339102404325136, 0.010725833741681916, 0.054591178694473844, 0.030059423630258868, 0.026318593915285807, 0.022225205886310766, 0.01979640675043421, 0.057108628430536816, 0.013162791412988943, 0.05781152285635471, 0.0518690895821367, 0.011998186985562955, 0.07078783333833728, 0.03865118331408926, 0.04152783252564924, 0.04975430627486535, 0.002965481743948268, 0.023794894871701087, 0.057002349490565915, 0.024821277474984527, 0.006278399286592113, 0.059285965881177356, 0.04104152647778392, 0.03654300554522446, 0.0049049116704346874, 0.03209046893087881, 0.047797353605606725, 0.030471226533076594, 0.032311209943145514, 0.04443600308150053, 0.036426521438573084, 0.03935498358415706, 0.02218614941063736, 0.035897681423063786, 0.018387328700295517, 0.05708406546286174, 0.08016700576990843, 0.03905004316142627, 0.03220987752346056, 0.07615947616951806, 0.02126355213113129, 0.015587454029758061, 0.018859824864193797, 0.01729167445695826, 0.0764243762407984, 0.030080543032714298, 0.01896975262622748, 0.008921419137290545, 0.011351351426648242, 0.06915390744273152, 0.03736452485567757, 0.00938483904714563, 0.04001607346747603, 0.011195405419649822, 0.006103240136456276, 0.04049464760880385, 0.07191410647439105, 0.03729264424847705, 0.011157570307009985, 0.06750166788697243, 0.0616055785545281, 0.030353432853839228, 0.02134569558048887, 0.043908045161515474, 0.05412046877401216, 0.07454532956970589, 0.03835474832781723, 0.034393942648811, 0.037304640747606754, 0.03613617291141834, 0.03681005657251392, 0.026932281342201998, 0.023795291814686995, 0.03193903348541685, 0.049043971712567976, 0.05258340035964336, 0.03205104943897043, 0.01169439752785755, 0.033177353109100034, 0.010577724814148886, 0.021679797741983618, 0.0441429811263723, 0.008253529484915947, 0.013853276281484535, 0.028554802760481834, 0.040687063176717074, 0.013974986804117049, 0.041539086028933525, 0.021500352370951856, 0.05100943321096046, 0.019939221408484236, 0.013828324004342514, 0.06815072734441076, 0.060460876407367845, 0.025492287540276135, 0.11025204748979636, 0.05712961551866361, 0.013661746201770646, 0.026825647867683853, 0.048443498755139966, 0.03011865295203669, 0.04608334022174988, 0.05250886328784483, 0.06266926362046174, 0.05137763684615493, 0.03667749797127076, 0.022534360011507357, 0.018735734379983375, 0.004534606273019952, 0.028907780069857836, 0.01143284178605037, 0.0641193947355662, 0.04026894311287573, 0.02950665507731693, 0.1092039890853422, 0.15757370394255432, 0.17531107073383673, 0.05648061712937696, 0.11828704204942499, 0.18608909738915308, 0.1571778737540756, 0.13733643772346632, 0.10875402537307569, 0.16121928260794707, 0.15717593314392225, 0.1327816221330847, 0.1068181921062725, 0.13015727938285895, 0.09724371015493359, 0.14513584492462023, 0.11532506027391978, 0.15727850049734116, 0.11171835487974541, 0.12140265772385256, 0.1390782506870372, 0.11726864241063595, 0.10202403685876302, 0.2343750335276127, 0.21224347395556314, 0.10972643390830074, 0.15046690457633563, 0.16267178181026662, 0.13676557264157704, 0.12543984608990805, 0.1435456709670169, 0.11834074131080083, 0.1970697074596371, 0.13119151602898324, 0.1264120646353279, 0.17976493388414383, 0.13913371413946152, 0.11504378036728927, 0.06613542405622345, 0.17457355745136738, 0.13179811276495457, 0.15415740225996288, 0.15459866715329035, 0.09672717537198748, 0.2031092255243233, 0.12006598444921629, 0.13769523347062723, 0.12275341738547597, 0.09811981421496187, 0.1626390628516674, 0.12837369580354008, 0.09064043127000332, 0.08603999777031796, 0.1583330389112234, 0.0798279961038913, 0.13586987927556038, 0.10552422582570996, 0.15650142862328462, 0.12853620494050638, 0.121274523170931, 0.14428595267236233, 0.1394204901797431, 0.11537984519132546, 0.10139618840600763, 0.21956340117113932, 0.08593141181128365, 0.11803553625941277, 0.14896673150360584, 0.10456384093101535, 0.13856890158993856, 0.18843061317290577, 0.16498629190027714, 0.2567205216203417, 0.1321082982633795, 0.1775886956602335, 0.1395806244441441, 0.11059358809143305, 0.1280413900635072, 0.1376880138580288, 0.14459870303315775, 0.16636831845555985, 0.12166735423462731, 0.10233300099415438, 0.11144599092325994, 0.13313146121799946, 0.1470558683254889, 0.07808757413710866, 0.13162982250962937, 0.12052999383636884, 0.1551906889570611, 0.15049747936427593, 0.14238148129412107, 0.07238341522003923, 0.18311958387494087, 0.09417777681457144, 0.09635649169129984, 0.16820058013711656, 0.13616392921124185, 0.25913154653140474, 0.1629357590739216, 0.15537534547703608, 0.1495549806526729, 0.23332240858248302, 0.14665296780211584, 0.16594382694789342, 0.11057096573391131, 0.17602138833275863, 0.10416256889168705, 0.12190714851021767, 0.12260285046483789, 0.09525049996695348, 0.13252304600817816, 0.12503921187349729, 0.08968429400452546, 0.14554353590522492, 0.10170932553176369, 0.1551332984651838, 0.12674247047730855, 0.1378994317991393, 0.17403946896748884, 0.11160770617425442, 0.16476071971867765, 0.09813126788607665, 0.07802819553762674, 0.1558466423302889, 0.13167909772268363, 0.19577599902238163, 0.1585050882505519, 0.14721425196954183, 0.07360745846693005, 0.10235961313758578, 0.18303843108671053, 0.1697269310908658, 0.16196093495403016, 0.12837280013731547, 0.08603509196213313, 0.1376207031841789, 0.12839350902608462, 0.10301307628729514, 0.04351603851786681, 0.10599281532423836, 0.0817908418497869, 0.12844190214361462, 0.09179534536919423, 0.07280118923102107, 0.09885212991918836, 0.11282610400979008, 0.14110426125781877, 0.07517183452312436, 0.19249929913452693, 0.07819819570119892, 0.18082808969276293, 0.11769082689923899, 0.12172507042331354, 0.1274316856371505, 0.07376299226390463, 0.2459580334169524, 0.15346872992813587, 0.11421701258846692, 0.12604269731257642, 0.1849899792245456, 0.17955739716334002, 0.16417603966380867, 0.2176868175821645, 0.1685478272182601, 0.17290776755128587, 0.1638555404331003, 0.12509102480752127, 0.13410762883722782, 0.10251300954925162, 0.06597868925226585, 0.13409031262355192, 0.1229001437979085, 0.17726681221808704, 0.13726547653121607, 0.12490446838949408], [0.024446587045011774, 0.03747131948226264, 0.0213380739358919, 0.037912523307438405, 0.02257102125856493, 0.023078202436278974, 0.07917698925094944, 0.051542466572885, 0.011039152375555463, 0.03167000113587294, 0.04489235859364271, 0.02044766296499542, 0.04410702555573412, 0.03329315868073276, 0.005274796376137861, 0.04335392293121133, 0.016798332000949552, 0.027996124167527472, 0.03371117017897112, 0.027276525905887996, 0.030872803913163285, 0.010886403116663652, 0.0478238741468106, 0.0172679087679301, 0.030218458667929684, 0.06044653217707362, 0.021388336417398283, 0.08343813488526003, 0.04914051367502127, 0.03243409263502274, 0.03582501710791673, 0.06818149890750647, 0.03839934843459299, 0.034413084121687074, 0.03623786834733827, 0.041159058921039104, 0.019228148939354078, 0.01748533683296825, 0.023246200921546136, 0.06515171791293792, 0.028420144093355963, 0.009575010360484677, 0.023078412782134752, 0.016114316115688, 0.04007423409659948, 0.012747656903229654, 0.06832931097596884, 0.012339655492853905, 0.01758640292765839, 0.03554994918938194, 0.010878764508691217, 0.021122817182913423, 0.05956850107759237, 0.013114411017990537, 0.06648412320230689, 0.0275038419224854, 0.007179467922209629, 0.08227395878306457, 0.04892703298745411, 0.05664547399750777, 0.052655057050287724, 0.03111779915967158, 0.029539319753114666, 0.07241302648825304, 0.044709893741777966, 0.032614274216549735, 0.027431121628199304, 0.041177413293293545, 0.009865911045510854, 0.02503720428129392, 0.00780541986958789, 0.04353184159845114, 0.07199252476649624, 0.00610224565856957, 0.03586401590811355, 0.0659191274483289, 0.07017901779285499, 0.03034072050026485, 0.028449811340708817, 0.02270104213883834, 0.10589230393192597, 0.037623338467840634, 0.02265717145720763, 0.038892283769590516, 0.01844356398630355, 0.060412198305130005, 0.00944563324031021, 0.0724549735231059, 0.014550074070159878, 0.02464933500492147, 0.010076780221424997, 0.045601790704365285, 0.0052038161000902096, 0.06495767725365502, 0.04466906289703079, 0.01875424142261701, 0.04249877203255892, 0.07097225915640593, 0.02899919230757015, 0.01338843144809029, 0.08344206360301801, 0.09441845997103623, 0.04933362813400371, 0.10157528772417988, 0.04432663680719478, 0.02409923479094037, 0.0481203702012343, 0.02779915732597666, 0.006370547310715275, 0.028621438291988203, 0.04689934643517647, 0.01645849791488477, 0.02577205092113997, 0.04056963251371469, 0.03141553693317941, 0.04572573869622179, 0.016010359461818422, 0.036146384863448996, 0.010401661092016314, 0.02834997169806489, 0.01934794260055891, 0.026752052263223698, 0.038160758558660746, 0.03294007280575378, 0.02193170047498175, 0.060996980140251775, 0.06518590250717742, 0.008214568004145153, 0.009612421388737857, 0.024815168963479142, 0.012681723655467587, 0.04156760146309223, 0.05939881304012878, 0.060728246346116066, 0.01826862239145807, 0.07162010403616087, 0.013036117406695016, 0.046671022794076374, 0.026696585418124284, 0.03686320622052465, 0.0107849434716627, 0.0601310133934021, 0.01782219045396362, 0.04120262086923633, 0.06581076540585075, 0.02492799237370491, 0.04704566911927291, 0.018879410777507082, 0.03369066485070756, 0.005682683707813599, 0.04137798485213092, 0.02504403543259416, 0.01448243430682591, 0.017473080794193914, 0.005930981723525162, 0.0557625879799681, 0.0208636558215533, 0.03396282524668744, 0.042890968666012795, 0.07371088077447244, 0.019872326337333237, 0.07194658116038356, 0.004499640939424613, 0.021533641298966746, 0.08475786514048066, 0.013097941276750394, 0.040216719665165455, 0.03458003766302552, 0.07420898654631206, 0.052268746708120616, 0.04528109809117658, 0.043466695451310704, 0.08031392217214618, 0.056775240427149196, 0.019342938404796377, 0.016588065873033235, 0.012396696539196585, 0.024231527067188705, 0.040182558819651604, 0.025722614556018795, 0.014929364967559065, 0.06392187997698784, 0.04197682932551418, 0.0430078870350761, 0.052155824910317145, 0.0690046161679285, 0.04754374774971178, 0.020609539368056824, 0.0422888807952404, 0.04508743741150413, 0.040157341065683534, 0.07757020475608961, 0.00343111389000634, 0.04205773105578763, 0.04703436472586223, 0.028023667600271956, 0.06275718140282802, 0.035307983601731915, 0.06258822618318455, 0.04762098878355963, 0.02589243321147348, 0.01128425618766674, 0.05661919094356043, 0.015641718171536922, 0.01592696750802653, 0.011363099412327366, 0.03816162708348461, 0.045087712218186686, 0.026383651852873818, 0.032082886302045414, 0.06732121828411307, 0.027900464300598418, 0.006009449633503599, 0.0464483072449054, 0.034323924620236666, 0.05885182560554572, 0.02341811285753335, 0.0076012605568394065, 0.04368891566991806, 0.011539791627520961, 0.09981664030679635, 0.058303386106022766, 0.08684023482991116, 0.047617012568350346, 0.01438237922931356, 0.025222747985805784, 0.03984122517119561, 0.06971353598471199, 0.024655804836324284, 0.08254896224077259, 0.0674478125625423, 0.03910539126289742, 0.025630510212587457, 0.047862601532999954, 0.10350288357585669, 0.036019617558590004, 0.03448227773021374, 0.03007138959531273, 0.03718557820788451, 0.04219765176198312, 0.010149938170798123, 0.0557794597532068, 0.019956937957821146, 0.03938256942534021, 0.0689014381329928, 0.023569343046152165, 0.020063115117539252, 0.0973792475249086, 0.022413572296500206, 0.047878601388739686, 0.032415544880287986, 0.04294699869517769, 0.06497628268386636, 0.05283216486818024, 0.01928567683457264, 0.018211633931579332, 0.03891273481505258, 0.029693364165723324, 0.04316254212920155, 0.037413202957915406, 0.031207267394555465, 0.053194828264947445, 0.022954507198716913, 0.058178454238389216, 0.05581909976899624, 0.03272264304437807, 0.040682147190506966, 0.03466542450977223, 0.022973107539915612, 0.029203275285129036, 0.04418061946385673, 0.039972362241574695, 0.02177874171840293, 0.03778748965955206, 0.032166529313794205, 0.021316355726282512, 0.07715710585138627, 0.03011457495657461, 0.016816333534994295, 0.06597298277275902, 0.04337288798498256, 0.023700357980227897, 0.05239101532580597, 0.013541721838659473, 0.033595113549381495, 0.009721709631516464, 0.06801356149039098, 0.056895826277988296, 0.04352269833907485, 0.04052308161876031, 0.009116759191134145, 0.030958988038556914, 0.03503757043342505, 0.02953237833987389, 0.08705298948500838, 0.10587857716849872, 0.058286904490419796, 0.02755236396166895, 0.02309496734025223, 0.03156132696728621, 0.0638138164899179, 0.06588476643498455, 0.02693454595282674, 0.019176593848637173, 0.05815251384462629, 0.09511131207857813, 0.03333302600575345, 0.004791928380395153, 0.019698633246922066, 0.0259135339542159, 0.025531866487913897, 0.08075864759406873, 0.03151631295414908, 0.04209361198757376, 0.02654155543340104, 0.04812609025144151, 0.021572556978623782, 0.02921513607725501, 0.03310754203370639, 0.025484211277216673, 0.022574678562315445, 0.03583584652681436, 0.04919904410572989, 0.033590153458395174, 0.04321667904566441, 0.039192501588591507, 0.01338432970390256, 0.029773919843137264, 0.03478552181539791, 0.019364622687654834, 0.05959768486874444, 0.049467730402414284, 0.029824090722416128, 0.01423449591467423, 0.04465697140299848, 0.027864900583933507, 0.009252933535857924, 0.07450083802853312, 0.029696851835719178, 0.032371789549610445, 0.022023519833705256, 0.04462393353294049, 0.040313285376344404, 0.028670947599623884, 0.05568680240373526, 0.05139940085687807, 0.02113805538309472, 0.003249566544712122, 0.014489888014005763, 0.031992044033748765, 0.014591883701671447, 0.059695115712072165, 0.08214703880782638, 0.10110193490982056, 0.15385470778814384, 0.15510228941483156, 0.09987845484699522, 0.11477301775344781, 0.12309871028576579, 0.16172799388212816, 0.14645957175110066, 0.13391568485115254, 0.11403664440980979, 0.09007884176181895, 0.17233341479940073, 0.10628749629748718, 0.09028561173805169, 0.16469103417226247, 0.12779101064162596, 0.09214234139238085, 0.12613892714892114, 0.09221064951270819, 0.12054412093545709, 0.11447113752365112, 0.12569648160466126, 0.17716922531170504, 0.0996434645993369, 0.11423113968755517, 0.14575974430356706, 0.1905537899583578, 0.2805096608187471, 0.06492477509060077, 0.1087133064866066, 0.2535590369786535, 0.06485928289060082, 0.1337674113788775, 0.1477527373603412, 0.17483794183603354, 0.1296406699610608, 0.1015862732061318, 0.09224716148206166, 0.1529273268367563, 0.09916965038116489, 0.07494776868926627, 0.1603871544024774, 0.08670568133571319, 0.16729673078017576, 0.1780869982072285, 0.16138096393219062, 0.08012006471731833, 0.07171046454459429, 0.060399720046137056, 0.13562080264091492, 0.17271123666848454, 0.17706555873155594, 0.22131868984018052, 0.18407147351120198, 0.25170373224786347, 0.1571531750793968, 0.16814445172037396, 0.15102765948644706, 0.17373887795422757, 0.09929351694881916, 0.08125603411878858, 0.13168154044875077, 0.13879075539963587, 0.0787991334551147, 0.1848300892327513, 0.08421692345291376, 0.12831196268754347, 0.13252038615090506, 0.16186959056981973, 0.11458939260670117, 0.1735340825148991, 0.15031120793095656, 0.13475443555840425, 0.11085227956729275, 0.11966908217540809, 0.16034299534346375, 0.1564043845449175, 0.13337629022342817, 0.05773714863296066, 0.1971465176237481, 0.20547090736883028, 0.08254796479429517, 0.10879015057746853, 0.13710178674331733, 0.16654457471200398, 0.1456231280629124, 0.14514881851417677, 0.09566167183220387, 0.1339397049908127, 0.11962508596479893, 0.125696508746062, 0.18899698635297163, 0.1447313159172024, 0.12288897511150156, 0.13402704601841314, 0.13265781663358212, 0.20662272056298597, 0.14804631232150964, 0.12887744020138467, 0.18843992267336163, 0.15824542646961554, 0.19901057545627865, 0.11788747991834368, 0.17514116556516715, 0.0687433055468968, 0.15117279812693596, 0.2524192067129271, 0.10310733837208577, 0.1155253638114248, 0.14070787467062473, 0.12496127534125533, 0.15069504162030561, 0.12667714112571307, 0.11326700249420744, 0.17310313135385513, 0.16469532251358032, 0.1392862488116537, 0.21024323414478982, 0.13737268506416253, 0.18867073314530508, 0.10565351388816323, 0.12298390216061048, 0.1541529782116413, 0.24576473236083984, 0.14308461999254568, 0.10915710231555359, 0.15431886645300047, 0.1453612542578152, 0.13687249618981565, 0.08343169558793306, 0.151895600770201, 0.13239255015339169, 0.20003672396498068, 0.08434126499508109, 0.10962676389941148, 0.15328319131263665, 0.11563300660678319, 0.16980528831481934, 0.12715994593288216, 0.05974230103726898, 0.12193186075559684, 0.1732321615730013, 0.08347849414816924, 0.140018958066191, 0.0793167742501412, 0.12083819801253931, 0.1026761361530849, 0.16859479541225092, 0.08375515323132277, 0.11522192295108523, 0.11848733201622963, 0.14695274457335472, 0.1274135551814522, 0.12532890561435903, 0.14298030201877865, 0.13647317833134107, 0.07584062577890498, 0.15807743476969854, 0.20015929453074932, 0.10213601549289056, 0.22182945029011794, 0.14330507602010453, 0.14190585538744926, 0.1624410663332258, 0.14843077026307583, 0.11315684233392988, 0.11900584133608, 0.14040127183709825, 0.18777582687991007, 0.09512854008270161, 0.12251806072890759, 0.12961088227374212, 0.17800085140126093, 0.1463383582553693, 0.15900283439883164], [0.027959162668724145, 0.028168448313538517, 0.014767203579789825, 0.06832517191235508, 0.03603456907772592, 0.04594302935791867, 0.03186618935848985, 0.05108731546040092, 0.002754500609756048, 0.050832545916948996, 0.034866874771458764, 0.018545580030019795, 0.011080665147996374, 0.006140944631105023, 0.03398037894761988, 0.05134054472936051, 0.03014770442886012, 0.041887177886175256, 0.04676964107368674, 0.08757156665836062, 0.0940577168283718, 0.09088119585067034, 0.0926175330366407, 0.024605505035391877, 0.017644402404714907, 0.017853664300803627, 0.06324301926153046, 0.03820523992180824, 0.00436115321437163, 0.019096682779490948, 0.031465945299714804, 0.06340951139905623, 0.02024202444590628, 0.07228310738823243, 0.04338817198627761, 0.07878278754651546, 0.010066866824802543, 0.019915477771844183, 0.030125645255403857, 0.027800329495221376, 0.012692596330972654, 0.05986946528511388, 0.032489193071212084, 0.04098611730816109, 0.005298531531090183, 0.031259338171886544, 0.010000428916620356, 0.05968670866319111, 0.034227409799184115, 0.04615553295505898, 0.08230211120098829, 0.07589722238481045, 0.05106005531602672, 0.04686532808201654, 0.04553469376904624, 0.046418044583073685, 0.028166721441916058, 0.013717062072828412, 0.03859210327001555, 0.04480411511446748, 0.009916081924789717, 0.03898899197312338, 0.023030367413801805, 0.03841763834602066, 0.04876424225845507, 0.0077052859123796225, 0.01774173994947757, 0.01230723933050675, 0.040287568899137635, 0.05090952232213957, 0.02450528202046241, 0.028196378511243632, 0.041793455236724446, 0.07872552597629172, 0.016073970423479165, 0.011090263025835156, 0.04178569279611111, 0.05397978471592069, 0.02732002000058336, 0.02886917142729674, 0.03657007230711835, 0.07869501904185329, 0.152157650994403, 0.03671880718320608, 0.0038807220075146426, 0.04304096222456012, 0.07423830604446785, 0.0981158312144024, 0.040269720035472086, 0.0064613255422695404, 0.009778523368627896, 0.05051037749009473, 0.025369389581360986, 0.017015106976032257, 0.024966853770560453, 0.030095470803124563, 0.03906521859711834, 0.008828632017996694, 0.04950841536213245, 0.06341025778757674, 0.04729868804237672, 0.06637076035674129, 0.041565165522375276, 0.04740849875711969, 0.03137941512146166, 0.03720442112535238, 0.0670013025935207, 0.01405772312344717, 0.024611510070306913, 0.030235174378114085, 0.019456077333805815, 0.03506379241922072, 0.04250036319717765, 0.038613629793482165, 0.018804627736764293, 0.0020488364888089044, 0.02573780865142388, 0.022583061862470846, 0.01579312647559813, 0.02285142076600875, 0.047693391862724505, 0.002307965831797836, 0.014643296300034438, 0.01844035112299025, 0.019331686597849642, 0.04237175706241812, 0.0504396571777761, 0.056669053089405806, 0.03751003329775163, 0.038174193552029986, 0.024490700302911655, 0.0075288557813369805, 0.059136973161782534, 0.062463131467146535, 0.04766956510554467, 0.06682753656059504, 0.040537931357643435, 0.059699234419635365, 0.03429444905902658, 0.03862688497507146, 0.040956472113196335, 0.05887986945786646, 0.002719777216303295, 0.026543582556769252, 0.09605085237749986, 0.0806297395112259, 0.021924896465082253, 0.02081791577594621, 0.05357100807928613, 0.005716198248722191, 0.023470926630709852, 0.04903507611847349, 0.02662623151471572, 0.01069008173154933, 0.031066115147301128, 0.02311587130783924, 0.014504966758457678, 0.06360513304493257, 0.01190455339383334, 0.045980769475655894, 0.06828319773610149, 0.03141252084502152, 0.02317372489986675, 0.09270165102290255, 0.10693640647722141, 0.013487496712644185, 0.007192818098701537, 0.06100107170641422, 0.03936426933588726, 0.02496322530454823, 0.00681014173564368, 0.06218113909874644, 0.02967542709250535, 0.026693593078692044, 0.009865818595114564, 0.01126951671072415, 0.025842384468497973, 0.029473023489117622, 0.045852475467004945, 0.014729622917781984, 0.021087769152862684, 0.06311766670218535, 0.06375396291592292, 0.06543154575462852, 0.023655271024576256, 0.03609437854694469, 0.019187577634251544, 0.02431954662980778, 0.04524070829419153, 0.024230320971193056, 0.036464424404714785, 0.015846369422173927, 0.020698167915855135, 0.022298160275178294, 0.03479250054806471, 0.07917662284203938, 0.04304495540314487, 0.04835119763655322, 0.06870337376104933, 0.03299411811998912, 0.06535981103245701, 0.04083139096785869, 0.012103367546972419, 0.028512078803032637, 0.02720097781691168, 0.006556864545148398, 0.008928302875054734, 0.044487659952470233, 0.004263515841947603, 0.059180935445640764, 0.057570249374423704, 0.0636730408295989, 0.031471353223813434, 0.04624386464378663, 0.02896790505786027, 0.007625502068549395, 0.032057180002863915, 0.028094048645081263, 0.026878956971423965, 0.020862112154385874, 0.038396322168409824, 0.055016162140028815, 0.008935602215517844, 0.02333529426583222, 0.02494392776861787, 0.019315374616001333, 0.019054878236992017, 0.04330528893374971, 0.03214360840086426, 0.03474409385983433, 0.06521775972630296, 0.012275535629929175, 0.012645645100357277, 0.013473548577167094, 0.10456947277167014, 0.03204293416014739, 0.07543301622250251, 0.022389128072453395, 0.04564903709771378, 0.08217434984232698, 0.022246065749121562, 0.015321536155949746, 0.0290542893510844, 0.026128202078065703, 0.02094786032103002, 0.03954430503238525, 0.024810370024559752, 0.044074201424207, 0.026934447565249035, 0.08836767822504044, 0.06602398825011083, 0.017849991730015193, 0.020288851843880754, 0.039784523392362256, 0.030234729937676872, 0.1077753539596285, 0.05619302684707301, 0.028919668003384556, 0.06962506180363041, 0.009059217725215214, 0.009266263356299272, 0.03138289939878242, 0.0710240313783288, 0.0208187486776816, 0.01793751087305801, 0.01995729249236839, 0.019946186570450664, 0.03063531665663634, 0.05814234260469675, 0.029669445806315968, 0.037199874940727434, 0.018677853646555116, 0.036024652288428376, 0.02085027002197291, 0.0277203692322863, 0.029383439903280566, 0.05770245513745716, 0.0504642031820757, 0.050050066118793826, 0.07722504756280354, 0.036738810395555835, 0.004125819882444505, 0.06411729806235858, 0.016410873238263384, 0.024233781499788165, 0.08018391486257315, 0.018843054871207902, 0.026463729163099612, 0.021488425421661565, 0.02257229690439999, 0.04619954612904361, 0.05496539754260864, 0.0254933087354792, 0.04588877709050264, 0.032615546469709704, 0.047358697679425986, 0.01406666197414909, 0.056192925066820214, 0.05169778323865362, 0.025524387335670844, 0.0428342397457787, 0.04212320629241211, 0.019183764267446737, 0.02455641981214285, 0.08358565518366438, 0.040155509021133184, 0.019890541609908854, 0.022364765272608826, 0.043704128425036154, 0.09985568999711956, 0.010309231051776026, 0.023389982491997734, 0.029342106942619597, 0.052236981091222594, 0.03472103045455047, 0.0410777839965054, 0.0980332467172827, 0.033040716512394805, 0.026533903254728233, 0.018821480850289975, 0.04832129120560629, 0.05010941418419991, 0.025157958069550138, 0.030795959822301353, 0.04076478257775307, 0.04298707975872925, 0.0018031851837544569, 0.08620422360088144, 0.021836066053115895, 0.009023681998119822, 0.035672010853886604, 0.03431222328384008, 0.04814044805243611, 0.03407162155157753, 0.031149524064468484, 0.03809585668412702, 0.02953664632514119, 0.04364860051178506, 0.03062985444973622, 0.03212659074259656, 0.08276694840086357, 0.03527332742565444, 0.018852060727242912, 0.013152075648706938, 0.054978561121970415, 0.08810281208051102, 0.03329791521121349, 0.045022532144295316, 0.033035888735737116, 0.0037727522430941463, 0.005930167481502784, 0.014835805166512728, 0.13155321590602398, 0.14598053959863527, 0.1136834126498018, 0.20916667048420223, 0.10133758333644696, 0.1751385871320963, 0.12444094754755497, 0.1397721070264067, 0.10032580619943993, 0.15266800432332925, 0.12929327360221318, 0.2353605106472969, 0.06769749987870455, 0.07668193456317697, 0.1484895178249904, 0.09106343000062875, 0.07279397640377283, 0.11138893969889198, 0.14476009937269346, 0.15468775880123886, 0.125269085967115, 0.1563341968825885, 0.1515664298619543, 0.09533208023224558, 0.0941046578809619, 0.2020372487604618, 0.0697536916871156, 0.10348516024116959, 0.12761513436479227, 0.11842369900218078, 0.07744291837194137, 0.13333697590444768, 0.07012721842953137, 0.21171569584735803, 0.08480424300900527, 0.19795841191496166, 0.13541029393672943, 0.10874530619808606, 0.10731920200799193, 0.10475696556802307, 0.13996485168380396, 0.09448541102132627, 0.10904939166669335, 0.10644540496702705, 0.1603664183723075, 0.10367398975150925, 0.13575504400900432, 0.10383575928530522, 0.13224772363901138, 0.1220764158559697, 0.12084277133856501, 0.19931956673307077, 0.17195606790482998, 0.08666458925498383, 0.14538618363440037, 0.12621865501361235, 0.1638540340853589, 0.10670827621860163, 0.1324321087449789, 0.10412133431860379, 0.0809579740411469, 0.1057747138131942, 0.1653199547103473, 0.15459325244384153, 0.19248750619590282, 0.1571766116789409, 0.267260911741427, 0.13139294593461923, 0.10079132871968405, 0.17093347491962568, 0.06327016744762659, 0.15509783822510922, 0.0700102797044175, 0.1866894651736532, 0.15450302085706166, 0.05619263329676219, 0.06692783082170145, 0.1494683317307915, 0.16468048973807267, 0.18349291384220123, 0.09011525195091963, 0.18234722103391374, 0.23961698796067918, 0.14503626312528337, 0.08409096699740205, 0.17542762947934015, 0.19918419899685041, 0.2935669001724039, 0.11737344892961638, 0.09587399222488914, 0.10051224048116378, 0.11160799794431243, 0.08044616186193057, 0.11018447218728916, 0.17549716574805124, 0.16073805200202124, 0.1790946362806218, 0.1057894719498498, 0.18381702287920884, 0.15971180849841662, 0.12661168963781425, 0.16391571291855403, 0.13116008628691944, 0.11666480052684035, 0.09525311232677527, 0.08597387453275067, 0.1490720265677997, 0.08327919484249183, 0.09268629577543054, 0.13877182427261556, 0.10917504956679684, 0.19117464950042112, 0.14552893383162363, 0.08465780158128057, 0.11879662184842996, 0.13365280681422778, 0.11715700982936791, 0.12411990548883166, 0.08785188983061484, 0.1517763143139226, 0.13239936264497892, 0.06218168192676135, 0.1456401457211801, 0.1089314826365028, 0.09902419961456742, 0.18889823236635753, 0.15043877251446247, 0.17442797097776616, 0.15292309277823993, 0.15460596819009098, 0.09549847737486873, 0.09443764215601341, 0.1038825171334403, 0.149983570511852, 0.08936609500753027, 0.14915298936622484, 0.07743067081485476, 0.1106345783919096, 0.0998428724706173, 0.06596776483846561, 0.2291034406849316, 0.17964875511825085, 0.11920865545315401, 0.052329974315528355, 0.12158272734710149, 0.138721300555127, 0.10966229199298791, 0.15484542319817202, 0.13808742671140603, 0.15379283896514348, 0.07396149768361024, 0.12895334112857068, 0.19212938898376056, 0.12031683884561062, 0.0778873995212572, 0.08131209468202931, 0.11601308121212892, 0.13552588916250638, 0.11743761120097977, 0.1253677313881261, 0.17668251214282854, 0.13703717663884163, 0.12380849862737314, 0.1445288953504392, 0.1307210877005543, 0.10649234601961714, 0.09893421230039426, 0.09265502888177123, 0.2011642727468695, 0.09774102204080139, 0.07432712627840893, 0.13052637529160294, 0.1094912536708372, 0.12517673735107693, 0.10606845162276711, 0.06281127421451466], [0.024761009994628172, 0.005897006202888275, 0.042980864377958436, 0.03871306910046509, 0.04247881631766047, 0.025322416298357502, 0.06629542261362076, 0.06231890206358262, 0.027530223364010453, 0.025247076858899424, 0.05518893411915217, 0.028507664932736328, 0.04033873722489391, 0.019236988554309522, 0.04321396490558982, 0.03088660870811769, 0.0826866098546556, 0.036330668189163716, 0.03976307829309787, 0.01883733651733824, 0.038561345277620215, 0.006800267778869186, 0.023450087123949612, 0.01280890910753182, 0.03197309594335301, 0.01008522798240717, 0.01536685720618282, 0.01055996585637331, 0.036749158054590225, 0.039392798340746334, 0.020981191657483578, 0.04924531001597643, 0.015501464983182294, 0.028250339008601646, 0.0267749935322042, 0.02632346240404461, 0.07004561102283852, 0.01939644937270454, 0.03745322295331529, 0.022923537164128253, 0.03553496374349509, 0.03397924918681383, 0.023494671963687454, 0.08388577122241259, 0.031291327705340724, 0.03288737777620554, 0.03763212549633213, 0.019740558229386806, 0.034799547134233375, 0.0497014212555119, 0.035721845858331235, 0.008019090546960277, 0.057159213216177056, 0.03927154413291386, 0.0069856986769342, 0.04321609550554838, 0.010321244514281196, 0.07121280660586697, 0.045127165636845996, 0.0562381121063871, 0.015023162255861928, 0.08511562951441322, 0.025004022222544466, 0.01652493667123573, 0.02454548861299242, 0.04108239124928202, 0.02491207224582987, 0.008262865278603775, 0.026705805012690167, 0.05243087586547647, 0.05697161185422114, 0.05337540339678526, 0.02431782484719796, 0.04842004519222038, 0.03702386974224022, 0.019397903133981993, 0.04608093820778387, 0.05406833014317921, 0.05430851457640529, 0.03634345518159015, 0.0411429437143462, 0.019898914732038975, 0.016791509331337044, 0.06655051106853144, 0.033998882597578425, 0.03632882935926318, 0.04385956383443304, 0.05625699234328099, 0.038449770371828756, 0.0063897791135657045, 0.024460072928507413, 0.020380225065829496, 0.01396772139040487, 0.10074780748358794, 0.036548688276005645, 0.04593307185652001, 0.032999427656510046, 0.004888145918292659, 0.0648424755781889, 0.021164748950728347, 0.03830933737169419, 0.0434398390352726, 0.01988090980531914, 0.020784843979137282, 0.031371588220021555, 0.013321231036180896, 0.054177034845841784, 0.03923970387716379, 0.038563346955925226, 0.023701117939448783, 0.012187341344542801, 0.01204956735351256, 0.020233758193041598, 0.06751213768231017, 0.0031843839263144347, 0.010677856226850833, 0.027686925937554667, 0.03780708575089063, 0.03231516919497933, 0.06017675343900919, 0.03779050574770995, 0.06703463223363672, 0.04021708607407553, 0.037238938201751025, 0.037304830737411976, 0.022108752313735228, 0.013098390806200249, 0.021701853522764783, 0.03957519533910921, 0.01326613059999155, 0.024441406430144395, 0.05290789616161159, 0.05752676885042872, 0.02651490257786853, 0.04411649790459445, 0.02716374320776335, 0.026674721323485886, 0.010317579577011722, 0.026885874635939087, 0.032214230325605185, 0.038578257762960026, 0.049733828088002544, 0.03080341013680611, 0.09765827469527721, 0.03607029055378266, 0.01687487923274083, 0.04563373613304325, 0.03355564656002181, 0.035221025946417024, 0.010701588837296834, 0.019185167138597796, 0.019208674984318868, 0.04078309623790639, 0.022608590046209947, 0.06277538649737835, 0.055633249027388434, 0.028963101029928242, 0.008201400183939507, 0.0557750899876867, 0.018606291950813363, 0.021231657592579722, 0.06291228093739067, 0.044363291268902164, 0.0362249490405832, 0.04330386061753545, 0.010832190713179963, 0.05333689992715206, 0.030745836440473795, 0.023012560958574926, 0.01479875885083207, 0.05980119787688766, 0.005545094617575939, 0.0354572952325855, 0.008364012797496148, 0.049507316135402234, 0.10289075677948338, 0.028740538151136467, 0.03494184949834432, 0.0830680076032877, 0.024412631456341063, 0.05043381838394063, 0.03581831318193248, 0.04017471495483603, 0.012257780912997467, 0.022648214794961468, 0.01582688868178853, 0.025176344672217965, 0.018521610780486038, 0.030735149513930082, 0.06062339911503451, 0.01321523029556764, 0.03298078151419759, 0.04452154938397663, 0.04730752596099462, 0.07082872185856104, 0.017048472239236747, 0.10764615410672766, 0.03087568768699254, 0.053740417917392085, 0.07504835472043071, 0.07330348156392574, 0.0037546684366783923, 0.032103181284453185, 0.013538331708072551, 0.04743370972573757, 0.01313812327238598, 0.015459480628903424, 0.018039165596876825, 0.00924577159873609, 0.006028139456507883, 0.009509893899251307, 0.025543092849797437, 0.046179780403950384, 0.02834457904100418, 0.08331466865326677, 0.05687933448436005, 0.02742310134427888, 0.021212061501241157, 0.05966631190053054, 0.034530531748064926, 0.034899149289620776, 0.05199482551376734, 0.028931389695831707, 0.011050208255515566, 0.028621082061103413, 0.0403758429123887, 0.04457019016678844, 0.01358720997814089, 0.08510021998413972, 0.04082254287121551, 0.03569252296750035, 0.03801245455230985, 0.04803298167618258, 0.05290114473817604, 0.050945969830666266, 0.031534731787230284, 0.03199968773073383, 0.03298671869561076, 0.048279317029352696, 0.012908940436318517, 0.03699065206040229, 0.026460877619683743, 0.007710190024226904, 0.011291153496131301, 0.03711375527616058, 0.02659220976888069, 0.05892851363335337, 0.0678789537133915, 0.04646561328055603, 0.032451235822268894, 0.012310240999795496, 0.07223341148346663, 0.043992509200636826, 0.02542561468934374, 0.03014880365559033, 0.04653070175221988, 0.03080721332558564, 0.018019014803160514, 0.04434248059988022, 0.0033444208633487244, 0.012021645637495177, 0.014548021501728466, 0.0465461553872696, 0.05830199510923453, 0.03783675130190594, 0.030201047459351163, 0.017818561987951398, 0.013482936957318867, 0.03814300468989781, 0.06102893913963011, 0.07179532891937665, 0.023004734057134817, 0.02572770696133375, 0.0526533098226147, 0.023663418533812677, 0.005464000777075333, 0.06808324025145598, 0.04001525244010346, 0.032035816327801774, 0.021010083678577627, 0.017898959905973504, 0.04711090008329068, 0.021940646959202628, 0.04796172192852412, 0.04788444357525025, 0.0761467536379184, 0.04188993273835097, 0.0656452707148024, 0.020061803848615715, 0.033901767273034365, 0.04004965416554894, 0.0097722723647686, 0.05390628919537578, 0.06353896230991397, 0.016668099078482816, 0.018067323103813187, 0.049555227493069, 0.020570014703220556, 0.09927839918860368, 0.023830841960651532, 0.014903578940512878, 0.042497849224933555, 0.06055715374116387, 0.06269119387226445, 0.07592839428356715, 0.049515176963593276, 0.014848958567849227, 0.025798544320943098, 0.08447119088045188, 0.04493924875610641, 0.06028561759740114, 0.04300072170527918, 0.0048099299144398954, 0.04830806655809283, 0.052760365685181956, 0.050128304599119086, 0.01272252990332033, 0.0426852843458099, 0.005569635956947292, 0.05397815623187593, 0.07828514996383872, 0.06673424478088107, 0.00387500407772937, 0.026833871712109873, 0.022199949116579125, 0.03896922964070525, 0.007399433708217527, 0.025186344582055296, 0.09618817429457392, 0.03723429362954838, 0.07082694409681217, 0.04446702230987804, 0.028023151913657784, 0.029188459472996846, 0.05059766084221857, 0.0241569289272385, 0.041181640566459725, 0.017982733535713384, 0.038132789345192056, 0.050539924297481775, 0.05036216169329626, 0.023613456304052045, 0.08749868521200758, 0.01764470265646066, 0.024725872058687464, 0.01180210308770516, 0.026284902955272367, 0.026885720269222344, 0.06659543687211615, 0.013324978245821382, 0.027992298926359842, 0.08266986361039536, 0.0919031985104084, 0.13514034556491034, 0.14692890085279942, 0.14085903870207922, 0.18823714926838875, 0.07997316188578095, 0.13397583019520554, 0.1344690030174596, 0.09221965367240564, 0.1004228638485074, 0.16089488858623163, 0.11459776572883129, 0.12575250145580086, 0.1149585699396474, 0.1377659911023719, 0.1483407693782023, 0.14865495823323727, 0.14561176938670023, 0.14444878750613757, 0.13159770066184656, 0.17292414738663606, 0.1918744362358536, 0.08782859572342464, 0.10624295725886311, 0.17359889617988042, 0.08647580045674529, 0.15225757206124918, 0.07486187294125557, 0.14380249647157534, 0.18073966300913266, 0.09096772263624839, 0.11749474384954997, 0.17675447756690638, 0.11995399902973856, 0.10107996394591671, 0.11149427547518696, 0.1375207956880331, 0.08296390676072665, 0.20181387503232273, 0.17436607501336507, 0.15055550767907075, 0.15171821814562592, 0.09500089407499347, 0.1906227291162525, 0.15586212649941444, 0.10912523831107787, 0.08950200557176556, 0.1271388027817011, 0.1342773168746914, 0.13166777975857258, 0.11334860990090029, 0.08991948102733918, 0.1224798456366573, 0.16731908172369003, 0.11660420734967504, 0.14734838477202825, 0.13333590381911822, 0.1938529493553298, 0.09684842957981996, 0.17088836591158593, 0.17827092190938337, 0.14181817509233952, 0.11085793854934828, 0.08597373204039675, 0.11720110103487968, 0.14962838457099029, 0.07923497685364314, 0.07237726769277028, 0.10145641517426286, 0.10913447317268167, 0.16849092527159623, 0.24036693200469017, 0.1462524285806077, 0.16205442350889954, 0.0769431773307068, 0.12177285285932676, 0.14389658213726111, 0.08902329233075891, 0.12915323754506453, 0.18147828908903257, 0.13934861975056784, 0.0949148286932281, 0.09336018282920122, 0.11901770212820598, 0.08714410995266267, 0.09935561647372586, 0.1197955882442849, 0.16969714340354713, 0.08747074992528983, 0.11319858580827713, 0.09084776443030153, 0.08901739586144686, 0.1199149696954659, 0.18148583439843996, 0.16827635892799922, 0.11945064818220479, 0.25831203907728195, 0.1358785102409976, 0.13070008025637694, 0.12405659817159176, 0.15766591685158865, 0.1302759958697217, 0.11437055149248668, 0.18770975113979407, 0.1615070357386555, 0.10757165096168007, 0.11291061554636274, 0.1461480427533388, 0.10167930714253869, 0.22753276782376425, 0.06459827761032752, 0.1856326468821083, 0.10143567235874278, 0.2847345455416611, 0.17343934545559542, 0.07348207876618419, 0.1160681104021413, 0.15192749191607746, 0.07937906376485314, 0.11307399320815291, 0.13794060530407087, 0.14320345861571177, 0.1046836973567094, 0.1622830219566822, 0.13943289379988397, 0.12538898310491017, 0.09726690248187099, 0.15066825305776937, 0.13611534610390663, 0.18882875038044794, 0.06843891473753111, 0.12370830614651952, 0.11072643167738404, 0.13178646910403455, 0.14420465060642787, 0.10405455290206841, 0.10083830369902508, 0.09597051383129188, 0.11597080848046712, 0.12083627097308636, 0.17439591698348522, 0.18797048500605992, 0.13922866832997116, 0.13353064336947032, 0.1261467303016356, 0.07047582936606236, 0.14215505415839808, 0.11419449879654817, 0.14760394820145198, 0.15532484890094825, 0.19558872335723468, 0.14198498614132404, 0.2146978165422167, 0.12517850154212543, 0.17194808833301067, 0.17625768136765274, 0.06740775864039149, 0.09369706189525978, 0.17458617820271424, 0.05538753453376038, 0.14394570807261126, 0.1194196662732533, 0.14925257116556168, 0.1698228352304016, 0.22270698605903558, 0.17625933699309826, 0.12799022852310113, 0.12728447067950452, 0.1115927037649921, 0.06659896525421313, 0.14627195681844438, 0.06015122016625745, 0.09318951091596059, 0.17361262972865785, 0.12876926814871176, 0.21274474848593983], [0.0703737505578569, 0.0542372683994472, 0.018508464164499725, 0.03634310234338045, 0.0784674451819488, 0.0220301983146263, 0.06354819038616759, 0.04345013241150549, 0.007984425041026302, 0.0234590047704322, 0.04742959101817437, 0.060277461606476984, 0.02842699220803167, 0.05037437532363193, 0.05860784476889031, 0.018869495684547082, 0.030540599953383207, 0.028062135446816683, 0.004694768951074886, 0.012486054512139941, 0.08518448046275548, 0.0452102522498795, 0.022158702669133033, 0.006615045530322407, 0.0022384961443354507, 0.09585201447563511, 0.09663131194455282, 0.04644162028229662, 0.024106583325192332, 0.016165514975520115, 0.03196125889995268, 0.034015720444066186, 0.0477080550044775, 0.06821771910680191, 0.02206171117722988, 0.05802384324903999, 0.00738964753691107, 0.007845309246996683, 0.04192533530294895, 0.04328322297494326, 0.02716268808580935, 0.020552206551656127, 0.03908774595973747, 0.016652509736429368, 0.0403172039160771, 0.005236407409289053, 0.04215632897934743, 0.023607880442536304, 0.0012865473483023898, 0.012684812686139984, 0.02906563106392111, 0.04858956020325422, 0.026302248006686568, 0.01810800127818116, 0.010943882666262133, 0.07847209993217673, 0.05087947679151382, 0.010304434657362955, 0.012347881881786245, 0.011035914915347738, 0.03933822037652135, 0.04425844403782061, 0.013126075883129877, 0.03399424820340105, 0.009089271737528699, 0.04064276162534952, 0.019519910515685166, 0.06514913947986704, 0.03779430215113929, 0.04789262670757515, 0.04281608893402985, 0.020904291587482606, 0.032183177170476744, 0.011967901423174356, 0.004669344243926129, 0.0233022190763482, 0.0455977669917047, 0.0676308541691729, 0.026424679472776394, 0.01352571859024465, 0.02262904278800956, 0.04243989894166589, 0.01679799103710268, 0.10239731254322187, 0.04943525571642177, 0.044539221828537326, 0.08095424209854432, 0.04757399344816804, 0.02911129986335124, 0.051194954863084216, 0.08948040780212198, 0.05914920036281858, 0.06988936476409435, 0.021982414182275534, 0.010013289699730064, 0.038564768486789296, 0.019531946030578444, 0.0404977349431387, 0.011843788886575826, 0.03398709983697959, 0.028871363095406975, 0.016410311750535454, 0.07142026868781873, 0.04590940794774464, 0.1468385471297162, 0.026467914027827125, 0.051764517157737694, 0.03763083967247179, 0.01956209334145699, 0.02346168498375586, 0.06432570330798626, 0.03307374081175242, 0.04576027273599591, 0.01807392355320709, 0.06095384566911629, 0.0221503838298044, 0.03800534350531442, 0.007458751239547772, 0.023495226666065197, 0.03362567137394633, 0.08116460831037589, 0.026855550905955688, 0.02789498004131019, 0.026504358143678734, 0.053067134759788, 0.04465202149003744, 0.06394123179571969, 0.026573590767968978, 0.01200700200362397, 0.030492627527564764, 0.07022578921169043, 0.020591797373656715, 0.042550191416272094, 0.0390384334272572, 0.03818572186199682, 0.03202780282923153, 0.08560428329344306, 0.011785415367090275, 0.025759643908323984, 0.03595844084130866, 0.023050116175519567, 0.02246868799972747, 0.03976572797234569, 0.05167705060115882, 0.020983242529577444, 0.050937328687203784, 0.035050435457378626, 0.03249000731323447, 0.038145264211509905, 0.07386587174343211, 0.03955152464498367, 0.02687236330738025, 0.03448977214949472, 0.019497162629184977, 0.04220295451315386, 0.041694375553301403, 0.039348836056888103, 0.04601208386676652, 0.026484300648527484, 0.022539759453918253, 0.05987729557922908, 0.049903193821332285, 0.008558195100964179, 0.003527105178883565, 0.06578933048461165, 0.06411188335290977, 0.037575321937245984, 0.013773685820134622, 0.006979928160684982, 0.03875530112002577, 0.01016786930683468, 0.026626942280147756, 0.023338159379948462, 0.028789134829172065, 0.026765086920931935, 0.025741630499916415, 0.029865304939448833, 0.018969574510785084, 0.04020399034821561, 0.05136967423771109, 0.036584548851741214, 0.010583175146686179, 0.03335630654224327, 0.021140391239896417, 0.049699989546622546, 0.030841211322695017, 0.07172686473599502, 0.03971868853217789, 0.05295787365841014, 0.03239299376894321, 0.07808766913201128, 0.03579416751329388, 0.01665413482779903, 0.06689226201602391, 0.0444826048665813, 0.030238465272954533, 0.07683529704809189, 0.04250378640634673, 0.0308960403448769, 0.058134939787643294, 0.04525881839383926, 0.03659859452662723, 0.03495707582416279, 0.05580414824986032, 0.04614260007760354, 0.027695098891854286, 0.028689542851809944, 0.018564348308635608, 0.061243749755833826, 0.055585846570985656, 0.07141031457909516, 0.04132139842425074, 0.07270030464444842, 0.031972006894648075, 0.02350987454078027, 0.047105529478618076, 0.03993707163525479, 0.040758305961000066, 0.019621736569596187, 0.04061569147078054, 0.03997176852343338, 0.027350279269739985, 0.03176832425275019, 0.020352269423061183, 0.06065314609025206, 0.026043963651838045, 0.024415542371571064, 0.048561540099659135, 0.027223951316305568, 0.029194179523204054, 0.021424726250448396, 0.06432075000235013, 0.0319105451926589, 0.010430016222276857, 0.023390338722882525, 0.02533776984949197, 0.004118832668089973, 0.012327525831226791, 0.027611863001116684, 0.016043527949867502, 0.04377751537997808, 0.052793586759694984, 0.04198256294642176, 0.0549323291384748, 0.07068790548614093, 0.04088863557470696, 0.019749548818383898, 0.06263758960579123, 0.040291962413383384, 0.041548198754233975, 0.03356985169063721, 0.02036466965052698, 0.050958933242197545, 0.07323585876396724, 0.10519655447985445, 0.0032653734420559234, 0.03345339472538658, 0.09654652220862252, 0.03339546819084457, 0.05264362712789859, 0.04090535807024155, 0.008117657088275467, 0.06829265651426145, 0.05639482994696923, 0.010621087442684387, 0.04993659810030034, 0.03236910594361169, 0.038745648959385495, 0.023007073306611607, 0.016688463610730002, 0.02024039426552398, 0.022731348905446272, 0.0621305000303047, 0.028120268934539387, 0.051803393821631155, 0.01626064388879708, 0.036406358770493946, 0.04760674972619329, 0.05476166061790926, 0.02217256005055138, 0.01965561751941485, 0.011008621692391378, 0.012591101062883223, 0.037149215516235144, 0.012526261952838727, 0.014373044283794505, 0.08788172501538481, 0.011375402948553008, 0.05312870502738016, 0.031359523867389986, 0.0251899068909032, 0.041415857284196785, 0.0075619784682723025, 0.007281814751747463, 0.053659950449530563, 0.04151202265971473, 0.02700547152198851, 0.06097551129226174, 0.03379219065287283, 0.058183170056768825, 0.051453693836395226, 0.02500891954904156, 0.050675719510763884, 0.037045199490551434, 0.011249416807134236, 0.04228423622303775, 0.09960959213120596, 0.05689560575410724, 0.053387087769806385, 0.01933982053638569, 0.021434125656794225, 0.029925633487956863, 0.009660395510893847, 0.01777745464018413, 0.03546083718538284, 0.07465380696313721, 0.07697881398988621, 0.04236271897596972, 0.026018601709178517, 0.015533770035420145, 0.016786510224587152, 0.027166294499433467, 0.07022277651620762, 0.029657805538071052, 0.0461541216022202, 0.05237872366394315, 0.02831707801669836, 0.05724304621773107, 0.0650137649582965, 0.007527635266472186, 0.03582454891875386, 0.04769617046362587, 0.027062728003199612, 0.027162749153961028, 0.030579619109630585, 0.02916683116927743, 0.023021502353783165, 0.02438581405606653, 0.04806488639275942, 0.029037587211600373, 0.006021571237527366, 0.040766872465610504, 0.05379916887198176, 0.0462836946493813, 0.008650845665085529, 0.07909768207796983, 0.02734710372585271, 0.011269707548698145, 0.04276365514046379, 0.06248447817883321, 0.013342643905031894, 0.02959514282909887, 0.09982358172003712, 0.11098516386534486, 0.08756514771708421, 0.13308768213859626, 0.0868585892021656, 0.1634882494275059, 0.15093137536730084, 0.07956091114985091, 0.1596093632813011, 0.08030556940606662, 0.1716753715383155, 0.1725429735545601, 0.08917679730802774, 0.10615327528544835, 0.22209824515240534, 0.08389618673494884, 0.07958939604993377, 0.127371486010296, 0.12359717568116528, 0.08924572289522205, 0.19515789433249406, 0.16254956408270768, 0.15393383854201861, 0.11493429195668016, 0.21297614249799932, 0.1414457815034049, 0.14961614379925386, 0.17639790741460665, 0.18732029918049062, 0.07937720457890204, 0.06545914855918714, 0.07973783915596348, 0.17250987461635045, 0.22526821148182663, 0.1474500700299229, 0.10476060930107321, 0.10847989044019155, 0.10741964554680244, 0.09782950300723314, 0.14415149417306694, 0.1375885677656957, 0.14839651781533444, 0.07669719481574637, 0.09431620474372591, 0.19212431354182108, 0.11116515884974174, 0.13356918415852956, 0.17608994751104287, 0.09289499957646642, 0.08119287607925278, 0.09439403949571507, 0.13036632245140417, 0.16203355177172593, 0.06702940072864294, 0.10230980866721698, 0.1620839669236115, 0.12328745158655302, 0.12590104634208338, 0.08321026246994734, 0.18255737689988955, 0.0671766631837402, 0.18251053084220203, 0.12547854972737177, 0.08144506040428366, 0.11334585504872458, 0.13718823210469314, 0.10670491068490914, 0.1935330472354378, 0.15001501382461616, 0.11344990839383431, 0.13413691440863268, 0.15572456030973367, 0.09429540764540434, 0.12116101783301149, 0.12304114337478365, 0.07596905888723475, 0.14711429019059452, 0.22418305756790297, 0.1707195463989462, 0.09508400782942772, 0.09081219562462398, 0.2165229128939765, 0.09685404106442418, 0.2468290009668895, 0.15422836345221314, 0.10892958952380077, 0.24326324516109057, 0.2022451383194753, 0.18821169063448906, 0.20238331519067287, 0.1750114160989012, 0.16040654693331036, 0.1881388295441866, 0.1375941860356501, 0.07309048263622181, 0.12160357194287436, 0.12528744712471962, 0.06908613536506891, 0.06999928743711539, 0.12083480533744607, 0.11399062616484505, 0.1314768400043249, 0.15462214446493558, 0.1249017949615206, 0.1985266985637801, 0.05281818704679608, 0.09489559901079961, 0.13907346022980555, 0.11957517292882715, 0.0939443539828062, 0.1819638894604785, 0.113332189353449, 0.14557685197464057, 0.10904557829988853, 0.13014106239591325, 0.13491173354642733, 0.07493643036910466, 0.1435155982949904, 0.13048691169491836, 0.10436136608145066, 0.1426909068333251, 0.173297680914402, 0.10175459060285773, 0.10350048834724085, 0.12507011235824653, 0.15360059642366, 0.13786237021642073, 0.17567669254328522, 0.11881008398319994, 0.12287383020988532, 0.2505444415978023, 0.08570864197931119, 0.11802172128643308, 0.11297331896743604, 0.09835576798234667, 0.09023174284292118, 0.13066867765571388, 0.06665849991674934, 0.13754240024302686, 0.1661248193787677, 0.25344862576041904, 0.13747780370925153, 0.11386701065514769, 0.17691854733441556, 0.07935996300407819, 0.19690471488450254, 0.12811089919081756, 0.1597187024142061, 0.12717262096703053, 0.19793741804148468, 0.06596141375069108, 0.11617712383823735, 0.11903302344892706, 0.09641375326152359, 0.10755740851163864, 0.14717603687729153, 0.1476514727941581, 0.07432912795671395, 0.1048202525292124, 0.23750462702342443, 0.10117429388420922, 0.1389423944056034, 0.09744576431278672, 0.09780901124966995, 0.12259193962173802, 0.17605078246976646, 0.07805608332689319, 0.1161527508603675, 0.06963253925953593, 0.1829937156289816, 0.08509578236511775, 0.05317988692383681, 0.1735115958643811, 0.12555043372724736, 0.0685864214652351, 0.06163347991449492], [0.027791333817211644, 0.014647845877334476, 0.03743528588009732, 0.04420344877455916, 0.024123460187443664, 0.0619102136365005, 0.04012398089149168, 0.03750881872006825, 0.05278499650635889, 0.026110663644171188, 0.04856322625918048, 0.017444792669266462, 0.07228706324739115, 0.019095812558329532, 0.01674627649065639, 0.0042967691468740144, 0.02469085286637502, 0.044175771331148486, 0.013066325785725244, 0.06163532552974565, 0.09279032876448971, 0.01370705961848476, 0.066563884993749, 0.05573579941743186, 0.0456028899310955, 0.024575123629931892, 0.031042973710490123, 0.06758819467255048, 0.031181730729128634, 0.013736104309958006, 0.024994453182443976, 0.01605823519639671, 0.03755713380607111, 0.03571841586381197, 0.06881570523338658, 0.011102033912071159, 0.03542509535327554, 0.03229760192334652, 0.0035237697551825215, 0.0873772342290197, 0.02735631653506841, 0.02601911230678005, 0.05987724129642759, 0.04040095888610397, 0.062610292141991, 0.04724910070321389, 0.048309474518256526, 0.016375526652804444, 0.06775159947574139, 0.0159831094954695, 0.051635290163436105, 0.03777158819139004, 0.0605749585000532, 0.04871743352019361, 0.033285559088523896, 0.010849398361252887, 0.06519817042031459, 0.021438583631866744, 0.12128449763570513, 0.07893728997026171, 0.10287764069757291, 0.056890720301972966, 0.051988528708794286, 0.0249289525007563, 0.03438314037131412, 0.1114635853362935, 0.046249954495579004, 0.04814024788460561, 0.008447769463860562, 0.03425335019294705, 0.04375005167509828, 0.045679672953805754, 0.05009794694238475, 0.04688978926943881, 0.0818183021619916, 0.07188962493091822, 0.02306216356477567, 0.04876461545271533, 0.0653884791369949, 0.03982672827052219, 0.08995644761515514, 0.05584444644461785, 0.013996268206808184, 0.017649099563381503, 0.005626714746800384, 0.009633131973844553, 0.02473911875858903, 0.025600510483075465, 0.04218619469819324, 0.007519587841151016, 0.030265240264790397, 0.00902701445323016, 0.027897928275966218, 0.057741708388285976, 0.09725397638976574, 0.01570563786663115, 0.02805091587028333, 0.019215468816193085, 0.034425280788647275, 0.05933773810310023, 0.03932017473770039, 0.08906595182738133, 0.01450586412101984, 0.040034414269030094, 0.09668231063655444, 0.05515696154907346, 0.0497701500675508, 0.055983230604657104, 0.018003259220027497, 0.013561351008580198, 0.02862973338259118, 0.022352370134155666, 0.07775206571178776, 0.02994883938559464, 0.012840685750623899, 0.03596668164911015, 0.08790383168629237, 0.03469475079327822, 0.04674324606146131, 0.045986367389559746, 0.01083515421487391, 0.03904242321316685, 0.006926923549534487, 0.011883423813352627, 0.020722400097708617, 0.06520484720489808, 0.023425195066790496, 0.04212335217744112, 0.07170299387403897, 0.018975952739960382, 0.013598654319399169, 0.03262405529884355, 0.018564256706408093, 0.07240078571651663, 0.039162154109882455, 0.03306040081328579, 0.024169459772695388, 0.013836201795909022, 0.06432182887302977, 0.03211472655779549, 0.010532371533502425, 0.007476706124309982, 0.022724144559885775, 0.01324135813462947, 0.017890693653108816, 0.03844847436994314, 0.028083280294335315, 0.01574141362548939, 0.04056327124791486, 0.04133368330076337, 0.04649382337395634, 0.017165947007015347, 0.023621052503585815, 0.007663874072022736, 0.038243013966296396, 0.003892496710510126, 0.028417869304705943, 0.038861376499491077, 0.04587560672579067, 0.029160588647105863, 0.04457856668159366, 0.0577356219291687, 0.04706777918285557, 0.021890732226893306, 0.03552389005199075, 0.03911432756909302, 0.010481414401770701, 0.02385707582081003, 0.003832753822540066, 0.040287307663155456, 0.05859852169773408, 0.006876006705819496, 0.015040220626230751, 0.0431197910303516, 0.04977735271677375, 0.01011159161238798, 0.03628611897251435, 0.04131694044917822, 0.026933412799345594, 0.05290431688938822, 0.04154841588543994, 0.13332104390220983, 0.024407269333356192, 0.04136810877493449, 0.049713556854320426, 0.04049302251743419, 0.022774088129933392, 0.04922831949910947, 0.09642784643386092, 0.034839431422629526, 0.0993792973458767, 0.07092039872493063, 0.07005517158125128, 0.029899163836879388, 0.03531993260341031, 0.04432362411171198, 0.024314537345032607, 0.005617484126040446, 0.021472099869112884, 0.043559257805879624, 0.06325568072497845, 0.03452596181471433, 0.02748838659109814, 0.04257006570696831, 0.05566371185705066, 0.054209736841065545, 0.053292764616864066, 0.015123298757576516, 0.01578329111050282, 0.02666096232964524, 0.0022486078004086657, 0.022667262969272475, 0.011455857693882925, 0.056803525159401555, 0.035992038502757034, 0.04903210074241672, 0.037650764853294404, 0.024626526050269604, 0.022608986989195858, 0.020062289001154046, 0.05916289319949491, 0.01865318211327706, 0.039187015632965734, 0.007311836533647562, 0.007809214576679681, 0.030538055447063277, 0.05064738388838513, 0.02650159311347774, 0.040549133970801315, 0.047985233166920285, 0.01653247689163046, 0.03759094520605036, 0.018929557908060293, 0.05785523408225604, 0.09262272382953338, 0.05696173916969981, 0.01589381767969046, 0.10648941474833659, 0.027672323863953352, 0.016207707979317223, 0.05782967366810356, 0.030550248721348386, 0.009200199490546115, 0.035012457852384875, 0.049947882137660465, 0.021137551570843374, 0.03514366616894092, 0.054742861805217605, 0.08037100732326508, 0.056087026106459756, 0.0682973994740418, 0.04603306416954313, 0.042210839090070555, 0.029597314141158546, 0.046844931319355965, 0.05229410356176751, 0.05219534957515342, 0.03622323573966112, 0.02478108275681734, 0.011835444602183998, 0.022295902449903742, 0.03703257195385439, 0.03503878840378352, 0.06769879588059016, 0.008275229034812322, 0.0009138770443054714, 0.048715370773736916, 0.04702068206721118, 0.05060707551560231, 0.07226978774581637, 0.016239415920738662, 0.053566248156130314, 0.031188170026455606, 0.07969969191721507, 0.012274443188549151, 0.05048693749787552, 0.039241434141461334, 0.1001100999170116, 0.028888272188071693, 0.013913400421318198, 0.0390008799066501, 0.046730642273489914, 0.0877166645867484, 0.024772611247109513, 0.05113395117223263, 0.06511044941310372, 0.012901321336227869, 0.045594890003225634, 0.01713473439615752, 0.026145374103050147, 0.04408967202263219, 0.03348985580461366, 0.01360953293208565, 0.0980466070717999, 0.015689222408192496, 0.024246834817209413, 0.0559092329681984, 0.08735581966383116, 0.011422462744771369, 0.02312315707760198, 0.09240301419049501, 0.006651800924113819, 0.026096343162602613, 0.04839418622265969, 0.009277004565644478, 0.02764834274005677, 0.011581507112298692, 0.017828092012288313, 0.10024552872138363, 0.03341585138280477, 0.034671582215066464, 0.005106023512780666, 0.03901845396363309, 0.006970113151640232, 0.04274259002080985, 0.06545456844781126, 0.04476413922384381, 0.022558661743200252, 0.008604891880947565, 0.04022652788886002, 0.01817565630855305, 0.02927865374035069, 0.11917383303599698, 0.013854846241883934, 0.06294909146215234, 0.051112546785069365, 0.046017176272081475, 0.01687658405197518, 0.051832126386995823, 0.02690978960267135, 0.06208334184650864, 0.006152161663132054, 0.05933866769607578, 0.03099911320688469, 0.01405145091536854, 0.03200355538034013, 0.010098495886528065, 0.009097866231708654, 0.05027339913483177, 0.01928194658830762, 0.06360263603606395, 0.04283001247261252, 0.02354665962047875, 0.026498722910348858, 0.028198425990662405, 0.062052332796156406, 0.056271947255092006, 0.026596029921035682, 0.03618959058076143, 0.04326365402500544, 0.029319688145603453, 0.02399312039571149, 0.10698235686868429, 0.12311358377337456, 0.14033400187534945, 0.09160106722265482, 0.1325295056615557, 0.13647867446499212, 0.07411475838827235, 0.1389263402670622, 0.07710750494152308, 0.16470408918602125, 0.07565668850604977, 0.10015309868114335, 0.21389327757060528, 0.07549644567604576, 0.18946092788662228, 0.13658121467701026, 0.12503926615629876, 0.13434932301087038, 0.14108941491161073, 0.16553997647549423, 0.15229136310517788, 0.07302326017192431, 0.15770992663289818, 0.15266624013228075, 0.16283116968614714, 0.08440131534423147, 0.13867042399942875, 0.19039878541869776, 0.11427403667143413, 0.08952626319868223, 0.12817109881767205, 0.11340310983359814, 0.11483726144901343, 0.13594488453652176, 0.1424155437520572, 0.1274249545697655, 0.10750634875148535, 0.15115951241127082, 0.0811570222888674, 0.12907008986387933, 0.1770928358393056, 0.09013954350458724, 0.16490539695535386, 0.1494002475270203, 0.2191561580236469, 0.13543523688401493, 0.18436576771949018, 0.07872986860041108, 0.10489901687417712, 0.22464161153350556, 0.14369513866092476, 0.16520049183496407, 0.15444317406841687, 0.19105206536395208, 0.09540726191231183, 0.08394140430859157, 0.16224507827843937, 0.18534091753619059, 0.1848782787897757, 0.15690802037715912, 0.1742505340703896, 0.21149659688983644, 0.09975374011056763, 0.10949460563382932, 0.1665525542838233, 0.2146834044584206, 0.1211848072707653, 0.19469924537198885, 0.16466664762369224, 0.11008176912686654, 0.16004043657864842, 0.13015411740967206, 0.23199397272297315, 0.11548565594213349, 0.16485625744930335, 0.1567036456295422, 0.14628108989979538, 0.16816161865634577, 0.19524599531931536, 0.14789603038557939, 0.3061346986464092, 0.1565574484744242, 0.10466309703354325, 0.1057330992605005, 0.08457537314721517, 0.13094243939433778, 0.26879630078162464, 0.14009898448629038, 0.14327983451741083, 0.12058198318949767, 0.13447775611920015, 0.2065795657357999, 0.10056536298777376, 0.15338341093489102, 0.14487728237041406, 0.12581412600619452, 0.1845487414726189, 0.15593984590045043, 0.12000977460827146, 0.1699268003659589, 0.10556302445807628, 0.1750300893826144, 0.1388619744351932, 0.06890318875334092, 0.1358262359031609, 0.1912332342139312, 0.19028036748724325, 0.12780304785285676, 0.13707668094762734, 0.09568029083311558, 0.11372539361140557, 0.12947312609425612, 0.15163166421864713, 0.14529380787696156, 0.13519711180457047, 0.142201479524374, 0.14734583348035812, 0.15625520183571748, 0.09511030784675054, 0.10322262147175414, 0.2284996530839375, 0.19182331540754863, 0.07242903312934296, 0.09018801804631948, 0.12424285603421074, 0.12977226504257747, 0.08071022733513798, 0.11614278996629374, 0.13133658681597027, 0.11395884358457156, 0.09521953162870236, 0.10870278919381754, 0.21088037852730068, 0.17248041262584074, 0.06334026690040316, 0.08138649604682412, 0.13027024189276354, 0.12230816270623888, 0.18222114922744886, 0.09237713486488376, 0.08010007507566895, 0.12408759365124361, 0.13162406853267125, 0.08817877407584872, 0.11763666623405047, 0.07792180124670267, 0.20422941898661, 0.07702589074948005, 0.14082216710916587, 0.10422919424516813, 0.10859731771051884, 0.12102639648531165, 0.1561701406857797, 0.10642869264951774, 0.285054406949452, 0.10802066472492047, 0.13818060314016684, 0.1702722561146532, 0.1014326053804585, 0.07879041428012507, 0.11873889208904334, 0.1330372534160103, 0.16557445962514195, 0.08769402865852628, 0.1279316030974899, 0.12119430676102638, 0.05360092808093343, 0.10268470605037042, 0.12369136991245405, 0.21701430795448168, 0.17964735733611242, 0.0790360914543271, 0.1369694181318794, 0.11088166013360023, 0.14170515829963343, 0.1385663638689688], [0.0350218318136675, 0.042029242763029676, 0.06541785970330238, 0.02635319920123688, 0.015182565398780363, 0.05445504421368241, 0.028307983951110924, 0.021153598924034407, 0.039154262747615576, 0.04159873604242291, 0.03933189643014755, 0.0187999305780977, 0.03170165479449289, 0.006244120969703155, 0.04419039376080036, 0.008550991603572453, 0.041086323359715085, 0.07197469286620617, 0.023532011745763675, 0.05604887886771134, 0.014168942646522607, 0.07571504930300371, 0.07766167127660342, 0.02752986882946321, 0.03312498377636075, 0.027880167621853094, 0.006825921915671123, 0.0184570685295122, 0.07049465192747967, 0.031926151498087814, 0.012307973844664437, 0.06684688837932688, 0.01998557213560811, 0.08425615634769201, 0.04665780153923801, 0.03471839434600302, 0.04382839532835143, 0.04270945376317416, 0.028092382841610482, 0.03954710738201227, 0.03606499458796211, 0.05105952266603708, 0.08252326611961637, 0.029025940158005272, 0.02214357812356736, 0.026013590728065798, 0.04930014243083341, 0.0491779009545488, 0.045950242185166905, 0.08860964381269046, 0.04229600541293621, 0.01016441301908344, 0.05198547190853527, 0.03948008169287017, 0.031646120095891614, 0.025192587104226862, 0.02613834448025695, 0.02143581520899066, 0.043519899382122924, 0.027449104502531033, 0.010418906907684036, 0.021163692132436802, 0.07409006649894373, 0.05727615872664111, 0.011702189654377955, 0.09429486481738941, 0.015881800824510198, 0.0272482581370111, 0.03902698993416769, 0.06519084224211318, 0.023400635491790514, 0.04247486045850175, 0.04478908556380442, 0.06285413727164268, 0.011461364005559256, 0.023774806842474, 0.07424529495515994, 0.04931393704776253, 0.035435225881103954, 0.058435442591352124, 0.03624226525425911, 0.05024429337520685, 0.013879801063532276, 0.016065950139558742, 0.08415827088590179, 0.03270176112917917, 0.052425159207944355, 0.06714382887418781, 0.02940598762195025, 0.060547810313957076, 0.04660552041605115, 0.04755502500172172, 0.03965961866612945, 0.050011226774326394, 0.08272314218005963, 0.019712626335344145, 0.03850915236398578, 0.036468834882336, 0.07116752117872238, 0.029242077310170447, 0.01896036509424448, 0.041299814225307534, 0.02113903416985912, 0.00427500216756016, 0.010226209747738071, 0.052766014489212205, 0.030954794692141668, 0.008557873644999095, 0.01939051558396646, 0.011459687175894422, 0.04125417935262833, 0.03711270693955677, 0.01521735219284892, 0.01398983145398753, 0.013176911726727017, 0.008314329615261937, 0.0770615613354104, 0.03356169569971306, 0.07508823222347669, 0.0411573049080159, 0.043574375566095114, 0.033327838605535884, 0.09005235854004111, 0.05279990731339369, 0.030249559320509434, 0.04691357192184244, 0.022419762232207825, 0.03547090325238449, 0.037571766413748264, 0.06085051835647651, 0.05143892891438944, 0.036661233486873765, 0.034590839940522394, 0.025475734678496207, 0.03167710539751819, 0.04577051182942731, 0.02016747380340738, 0.03496971693156021, 0.016990973181756477, 0.023046516547245637, 0.019080911929320012, 0.03439999178850225, 0.053349917621484826, 0.06664484779217414, 0.09860740947936263, 0.023130414009626423, 0.0365353041727628, 0.012968981455612396, 0.026485343896118656, 0.0422931487805077, 0.04233186598867178, 0.03373706986063293, 0.034402963771883927, 0.05279891325959137, 0.013382956518658569, 0.030977328840110983, 0.020196547332618917, 0.008003486786037683, 0.03521516679653099, 0.010514124030513423, 0.05718185592974935, 0.059472440875002315, 0.005404349067248404, 0.024475950647943785, 0.03382608008437923, 0.0578514410715018, 0.035275149292179515, 0.1026017755003912, 0.029758584951715808, 0.026670963935820118, 0.03735941209431205, 0.004789396596606821, 0.04476083815097809, 0.024525697442835996, 0.027166665997356176, 0.05906296534729855, 0.023447459497089897, 0.04338397863986237, 0.04195408143901399, 0.034377352467605045, 0.020123713383717195, 0.016328203924266354, 0.0498026281462184, 0.04247379855119756, 0.01398778397456876, 0.02050628499793155, 0.01655802712775767, 0.06644486316612788, 0.03630194580182433, 0.03577438143215009, 0.034694123148385964, 0.02536928271209555, 0.028797901501613002, 0.0310034761870546, 0.03350271065054195, 0.04592643239136253, 0.032995787316135, 0.007698834740689823, 0.031774393748492, 0.020163071807473898, 0.01555330166593194, 0.018552175390401056, 0.04569734539836645, 0.04604883332337652, 0.053861271789563556, 0.0253852214996836, 0.019850514829158783, 0.04818064107426575, 0.02816252639916326, 0.043001915926912, 0.03831070801243186, 0.042977590446493456, 0.043875383878392835, 0.028160874166392853, 0.04483852023258805, 0.05961358294423137, 0.03185382305777498, 0.030065808644784347, 0.008218862282644426, 0.04617074571017708, 0.022003769375649945, 0.04833701625466347, 0.03935930245955076, 0.031237265427729914, 0.07825239029313837, 0.0198781685238438, 0.04519672565428274, 0.03120660243023719, 0.005974888028244355, 0.03352235084665673, 0.04743209820506828, 0.007669620415461915, 0.039079545864037106, 0.036683944053947926, 0.027505551830732396, 0.07039174530655146, 0.06940418508435998, 0.05935257087860789, 0.029494058074695722, 0.06518273374864034, 0.027466514014772007, 0.091926289057093, 0.030221077813101665, 0.021323553286492825, 0.06597315919186388, 0.027645357185974717, 0.042586764453777244, 0.06574504928929464, 0.02231747138180903, 0.025919494884354726, 0.03085349959188274, 0.027371435991621444, 0.012436141476168163, 0.053899877039449554, 0.07423845532217196, 0.012231918550761682, 0.08454456765736852, 0.057487359536545615, 0.002399065519317186, 0.025250518727781515, 0.06939598159598452, 0.03956432860078556, 0.06282393567796264, 0.045846694348646064, 0.008174887276254594, 0.03531258746183344, 0.04102340620011091, 0.06323792346354042, 0.022028152531545078, 0.04293778079694935, 0.04869769832917622, 0.04437781870365143, 0.0618514728599361, 0.06093818508088589, 0.05470309965312481, 0.02922526660508343, 0.05845535080879927, 0.02378780078808112, 0.010144776215643754, 0.030003281642815897, 0.023482297181284854, 0.015791933950302855, 0.052873996552079916, 0.053893071333212514, 0.05114024458453059, 0.020580382718305503, 0.014941846619227102, 0.03171631454357079, 0.02874999014394624, 0.03420119459873863, 0.06131303496658802, 0.0028187799284101595, 0.09940816901092019, 0.02299979092952396, 0.0646161570080689, 0.0498817487220679, 0.00510848405039204, 0.019513189626325454, 0.03985313006809779, 0.034484174235590866, 0.0021221502891941263, 0.008544848317147365, 0.019698307550113116, 0.02728786422604961, 0.046246008814445565, 0.026621335884556174, 0.03408294630103877, 0.02922339384843196, 0.03063570342159697, 0.023055188224783967, 0.03318694420158863, 0.03929447861654418, 0.05073914896430714, 0.04569869229037847, 0.016550878761336207, 0.012813090579584241, 0.033659316532846005, 0.027383424009063413, 0.023651920757921677, 0.04639192098485572, 0.0539148149878851, 0.027456122250961404, 0.05268555719937597, 0.04524163788716708, 0.014299557244937335, 0.056707631197891066, 0.03498894661398871, 0.04869342016588364, 0.027995599999225566, 0.03806717500888875, 0.03184033717427935, 0.015674372669309378, 0.027052453286679726, 0.026039213906707506, 0.02214723203464278, 0.05430139674405966, 0.0603063739836216, 0.04885831096076539, 0.0046681122787828955, 0.03791479639975088, 0.05390568529920919, 0.023763208982667754, 0.07177827733435801, 0.02198808334235634, 0.028796059279037372, 0.013224634790926107, 0.04161296831443906, 0.028437054882358228, 0.04527269782764571, 0.014418363637690033, 0.04655063711106777, 0.0306618948733168, 0.12813676494572843, 0.14686004311910697, 0.13586854934692383, 0.09640385343560151, 0.13174655767423765, 0.2151866060282503, 0.09383784434092896, 0.13425506092607975, 0.20599929615855217, 0.09976922427969319, 0.09532127795474869, 0.11599151736923627, 0.1353968046605587, 0.10571879574230739, 0.14366050623357296, 0.11179894448391028, 0.1004490145881261, 0.17265962729496614, 0.1441747543535062, 0.15783200865345343, 0.10990214055137974, 0.1769212479037898, 0.14591332391968795, 0.1171554084867239, 0.06450899597257376, 0.13916776302669728, 0.12215516663023404, 0.15287107628371033, 0.12940915381269796, 0.08488251880875655, 0.07696563683982406, 0.1553237225328173, 0.09554439383958067, 0.18312718346714973, 0.2426360345312527, 0.1750465099300657, 0.17945059575140476, 0.10305379517376423, 0.1292996789727892, 0.1778951763574566, 0.12448670794921261, 0.14906904101371765, 0.20421230633343967, 0.10499027983418532, 0.06882419370646987, 0.1341263564037425, 0.13016106560826302, 0.26716985234192436, 0.19300813254501137, 0.16776232793927193, 0.10721434120621, 0.09837849890547139, 0.13963095817182744, 0.1928648395197732, 0.1457368369613375, 0.11616166681051254, 0.15612071619502135, 0.19096745204712662, 0.13854357866304262, 0.2754511008305209, 0.13539232632943562, 0.13728869599955423, 0.135889841775809, 0.15493437913911684, 0.12088505764092718, 0.3242068003330912, 0.08335292445761816, 0.1746993035610233, 0.1613863922123398, 0.13476535997220448, 0.1741933471390179, 0.1819897009325879, 0.15506374862577232, 0.15552826012883866, 0.08162302656897477, 0.06996288403336491, 0.14333600364625454, 0.29035843376602444, 0.13937722678695405, 0.14063601781214985, 0.1723081868674074, 0.09178468558405127, 0.12551776905144962, 0.08499385283461638, 0.1930318676999637, 0.12623796612024307, 0.15626525772469385, 0.18731749004551343, 0.12134251237979957, 0.18938033149710723, 0.10858136535223041, 0.23266634664365224, 0.13014351869268076, 0.185140084741371, 0.12786646373569965, 0.12988412832575186, 0.14807038674397127, 0.10236498713493347, 0.12910177744925022, 0.12199014691369874, 0.16515635991735117, 0.16550668754747935, 0.11941331518547875, 0.07482771548841681, 0.12637120325650486, 0.14709245493369444, 0.11128213150160653, 0.11015497627002852, 0.19116951977568014, 0.09587089131985392, 0.08677088855100529, 0.15067357277231558, 0.11023418166275535, 0.13678196604762757, 0.10333101065563303, 0.10628585424274206, 0.1401713706020798, 0.11038307938724756, 0.21827647808407033, 0.12938153743743896, 0.12148614467254706, 0.0689566166007093, 0.11282367485442332, 0.29599578412515776, 0.1374612067426954, 0.12955578523022787, 0.09593314012246472, 0.208148080855608, 0.09168297318475586, 0.147107830537217, 0.16362787836364337, 0.12248641385563783, 0.12683711254170962, 0.10625990706362895, 0.1294164141373975, 0.15297243584479603, 0.14280994901699678, 0.1501777536634888, 0.1935838016548327, 0.09636157391858952, 0.09112745656498841, 0.11456256333206381, 0.2070617734321526, 0.21876581039811882, 0.18402336537837982, 0.05788228727344956, 0.11022762022912502, 0.11917601791875702, 0.10141758261514561, 0.08450765535235405, 0.1620311633284603, 0.17634889004485949, 0.12591046440814221, 0.1258615284625973, 0.10856306526277747, 0.07873208740992205, 0.1102350637582796, 0.096168856402593, 0.09565044207764523, 0.11079666683716433, 0.19648827080215725, 0.16345086214797838, 0.05842220437313829, 0.1306283183928047, 0.11448002633239542, 0.098199867776462, 0.15750703109162195, 0.12075282473649297, 0.11229793913662434, 0.09638403342770678, 0.17105987242289952, 0.10108666787190096, 0.08360189252666064, 0.10372526664286852, 0.1312547419220209, 0.10103210687105145], [0.06935446203819343, 0.027638113824650645, 0.029075588565319777, 0.02877994067966938, 0.008481311146169901, 0.07042666950396129, 0.03457421922524061, 0.03391252883843013, 0.032114126054303985, 0.0015000363055150956, 0.0484385115227529, 0.04312200644718749, 0.05417173209467104, 0.0734210309705564, 0.042451976864997826, 0.012084192995514189, 0.037260044033506086, 0.04476932662406138, 0.030804207415453026, 0.044570407297994406, 0.012403535324015787, 0.00302452574084912, 0.024796144537893788, 0.06969786182578121, 0.057148885913193226, 0.041879900598100255, 0.043558742119265456, 0.029590803597654616, 0.018842625697808604, 0.02711086327742253, 0.037957445718348026, 0.021372170320578983, 0.028781850755746876, 0.008828480195786272, 0.0359802082447069, 0.11100410177771534, 0.03418130334466696, 0.0810231880417892, 0.020843430388984934, 0.0498904339703066, 0.022668221399986317, 0.011521619611552783, 0.0687291445210576, 0.03404067356937698, 0.08126659212367875, 0.03147546175335135, 0.0836803854576179, 0.08418565655925445, 0.05438939595062818, 0.01613742532208562, 0.02739135269075632, 0.05238369054027966, 0.05013666754322393, 0.012200780578755906, 0.10454943563256945, 0.016905464198706404, 0.028298023057037165, 0.02741582066352878, 0.018246018693649342, 0.10897001664021186, 0.04014493405286755, 0.027265253742890697, 0.0706916374287435, 0.014069101307541132, 0.031990883738866875, 0.033679784541683536, 0.05967797591750111, 0.08788665117962019, 0.044314412998833826, 0.02263906814291009, 0.06837087803121124, 0.011795750303593065, 0.04383000345634563, 0.0023821829319266336, 0.06564382543521267, 0.012868702461543893, 0.075127831527165, 0.019722556695342064, 0.11243158339389733, 0.0361166616369571, 0.07086495562855687, 0.01720966841094196, 0.09683332539030484, 0.021376597761575664, 0.06537203823349305, 0.029048464127949307, 0.06701960946832385, 0.04264804295131138, 0.05938564946076699, 0.029530149352337633, 0.05939742882869073, 0.03737885212259633, 0.027068163068698983, 0.025985724991187453, 0.024054166495001743, 0.016506933440853442, 0.07432973185288054, 0.037422481924295425, 0.07145921659788915, 0.03671589626797608, 0.05723406241408416, 0.07312455866485834, 0.037397315060453754, 0.05353376329211252, 0.0421278813986906, 0.008589033669392978, 0.016976040322333574, 0.03413517992677433, 0.08961480523326568, 0.04260415869898029, 0.05295008407639606, 0.04751088969143374, 0.029668265155383518, 0.05795341809945447, 0.025015146804175208, 0.03530503536707588, 0.031266995439571996, 0.044393849093467, 0.01232224767695048, 0.07875259952353579, 0.007781593960576824, 0.07086289966745035, 0.10015727845685822, 0.03840105834283999, 0.0427911629501198, 0.028811065080974783, 0.04609068536332675, 0.04448192972423775, 0.05037425318732858, 0.021499829898987497, 0.03591948275321296, 0.02033116189496858, 0.021473594342491457, 0.031198001998875822, 0.06247034429439476, 0.036977688648871014, 0.014024373975449374, 0.07593175981725965, 0.049936150267188034, 0.009740455009575402, 0.040415523640279255, 0.012224793933065874, 0.03352032541962607, 0.006404115710340972, 0.020351957296952605, 0.03349763860127755, 0.029125009663403034, 0.05721065295594079, 0.04989017951967461, 0.018270691923264946, 0.0920350853619831, 0.02600070704439921, 0.030517869030258486, 0.021991182551054016, 0.04955486108415893, 0.03249064852882709, 0.016935480891593864, 0.04306677369666951, 0.045907233243009875, 0.03429805886532579, 0.002243697115253391, 0.03278693084471992, 0.040860937775245736, 0.044541053873087676, 0.050379450765571425, 0.068320293245571, 0.05016595311462879, 0.06592429109982081, 0.0684445465781859, 0.07763913034328393, 0.023268085372235094, 0.040732287535709996, 0.05936164289180722, 0.06349837913044862, 0.0326719768345356, 0.03892964730039239, 0.020858646536778127, 0.03262088314763137, 0.026325911915461932, 0.01734995043703488, 0.0402242276551468, 0.049859994889370034, 0.030760391016623805, 0.007603635429404676, 0.01677665619977883, 0.013498526299372315, 0.1041358346119523, 0.018680072456066097, 0.052576316454048665, 0.03423909077953015, 0.016976018269945468, 0.019297888768570762, 0.016652701422572136, 0.02574616141750344, 0.011700685851142874, 0.03407849171864135, 0.018243357140038694, 0.04153710470667907, 0.04822025734132954, 0.06532857128019844, 0.0173813666083983, 0.021467555380825485, 0.03667603912098067, 0.04253520257771015, 0.058242548656250746, 0.02381510503723153, 0.012856156349049082, 0.058964062082980356, 0.05693384459508317, 0.015552619738238198, 0.026808932157499448, 0.047280574550053904, 0.031150664003299813, 0.0332936913307224, 0.04220743623695203, 0.060547599968101294, 0.027879701129027774, 0.02452900360471436, 0.04353317491976278, 0.01846265626539077, 0.07176304422318935, 0.02761964070876794, 0.04403892099591238, 0.055033468175679445, 0.012678846666988517, 0.011858124635182321, 0.008814991767784315, 0.05461721747581448, 0.02687275516135352, 0.03217967932245561, 0.055974199303558896, 0.007830265277464474, 0.021585199782358747, 0.03347021221582379, 0.017098962029974376, 0.0869282204657793, 0.0024508072071642217, 0.07588974492890493, 0.03852687569867287, 0.07731818327946322, 0.026736082941559807, 0.02101921845626618, 0.045652266924402544, 0.031192383728921413, 0.007215769545707319, 0.055450892741126676, 0.03364593921495335, 0.04064030872125711, 0.0993051945364901, 0.021594816319910542, 0.03527005688686456, 0.020702464738860726, 0.044337330519088676, 0.0816081462960158, 0.0668806658525552, 0.02595368117493178, 0.04037698624389512, 0.1241113016647952, 0.05969955333109413, 0.05666555863405977, 0.0835382527272616, 0.03050713799893856, 0.0562816401278334, 0.0816297372803092, 0.03389975880937917, 0.02060437571656491, 0.061738157511821816, 0.07288323768547603, 0.047889115288853645, 0.07222034289900746, 0.03924234677106142, 0.05498620821163058, 0.04042204775448356, 0.05237181278477822, 0.03978950044672404, 0.07263252578143563, 0.05031392124614545, 0.054899315017142465, 0.04073359710829599, 0.02821686178711908, 0.07487858525876488, 0.009514396827268814, 0.03537683455007417, 0.005176116604291434, 0.04694645372884614, 0.06433940293001277, 0.04832594934850931, 0.046617686548935514, 0.0288484082557261, 0.04449285413803799, 0.02941340740237917, 0.03571950151984181, 0.021354989813906804, 0.018358104197042327, 0.05081811686977744, 0.0614352391234466, 0.027165090099775364, 0.0209780161135963, 0.0047360917337105745, 0.014255647547543049, 0.04503019619733095, 0.00636081414995715, 0.09668033609965018, 0.06801364291459322, 0.04767239798924752, 0.018137252922835093, 0.018193249025249054, 0.02379740884394518, 0.011957655544392765, 0.03884623499054994, 0.040016962348350456, 0.02698237758262881, 0.013208754526983415, 0.05239895757819925, 0.023234901617148092, 0.015386931664709533, 0.017478446309853877, 0.02947116769584162, 0.05008458658786757, 0.023855116550943682, 0.022781350150970475, 0.026981071402717913, 0.02964707450675113, 0.06238074374518224, 0.029890169855207205, 0.013589547531280135, 0.04668037300663335, 0.03487801970914006, 0.0884566070245845, 0.011759909235739281, 0.04409198582704578, 0.01380308419798634, 0.045291896975998364, 0.043132075906864235, 0.020531602835814868, 0.036981111858040094, 0.027517933398485184, 0.06431779158966881, 0.025904726569673846, 0.02963807373972876, 0.028323364643646137, 0.017551341326907277, 0.033135579100676944, 0.03185090874986989, 0.04358540515282324, 0.052124018581318, 0.016911131662449667, 0.01556655006217105, 0.05206117945324097, 0.014434902928769588, 0.028216271461652856, 0.03474351031971829, 0.1302152398441519, 0.14256837697965757, 0.09051435267818825, 0.19842635680522236, 0.10194394937051193, 0.13263752843652452, 0.13344612504754746, 0.13026942765074118, 0.1751531349228961, 0.07883265308503594, 0.21497737296989985, 0.13409711154443876, 0.14847483432718686, 0.18454271608165332, 0.08991862607321569, 0.13061005223010266, 0.10042260600520031, 0.06866455477263246, 0.13189196772873402, 0.12141276789563042, 0.1229415615754468, 0.1316543719066041, 0.0725187761709094, 0.15541209493364605, 0.12040397631270544, 0.0871800926647016, 0.14716404037816183, 0.09144179469772748, 0.11554527202887194, 0.21135865072054522, 0.11287637666932174, 0.15924569565270627, 0.11879162783069269, 0.0591257976900254, 0.0930742888844439, 0.11048289867384092, 0.12719255632587842, 0.1329215903367315, 0.10785645246505737, 0.15174265897699765, 0.11323520634323359, 0.1241342361484255, 0.17986218152301653, 0.12310476281813212, 0.14699433876999787, 0.16601041837462358, 0.14267914103610174, 0.16109854408672877, 0.09131429118237325, 0.1768486446567944, 0.1664829230202096, 0.15258170823965753, 0.1083315151876637, 0.12313495762646198, 0.14825337406780037, 0.11254754502858434, 0.13572028944534914, 0.16255694654371056, 0.10499631879585129, 0.18007894632007393, 0.06337782381368534, 0.12143719515630177, 0.14697536693087646, 0.18352112732827663, 0.07917108599628721, 0.10697267417396818, 0.1686603826071535, 0.12647467984684876, 0.09004374793065445, 0.12748717623097555, 0.23275542472090038, 0.3197358516710145, 0.17618962430528232, 0.09081142209470272, 0.1594423893839121, 0.1444470097443887, 0.15733481890388898, 0.17461950784283026, 0.3700025943773133, 0.20671510989112513, 0.15595765065933975, 0.2828899888055665, 0.14750701268868788, 0.18093155271240643, 0.17732374130615167, 0.15826595893927983, 0.10975236751671348, 0.10703733856124537, 0.10159086688820805, 0.11799867823719978, 0.15719612634607724, 0.224288868318711, 0.183761505143983, 0.19772681434239658, 0.1362063376499074, 0.13531247632844107, 0.11466452000396592, 0.13723259472421237, 0.13307115302554198, 0.18615920362727983, 0.21741243159132345, 0.14359709035073007, 0.11009234070245709, 0.10523646590965134, 0.2965765558183193, 0.10731766173349959, 0.1719671551670347, 0.13430979156068393, 0.23504898164953503, 0.23462647146412305, 0.29709118391786304, 0.1787549073674849, 0.10225606190838984, 0.14485178302441323, 0.12424246248389993, 0.1243737590100084, 0.12024050365601267, 0.14318600669503212, 0.2033235068832125, 0.20760808911706718, 0.11834364544068064, 0.1446835199104888, 0.14139460639229842, 0.24223860300012998, 0.1590635904244014, 0.13359258004597255, 0.20137077809444495, 0.1587369165250233, 0.23047150298953056, 0.0767270503565669, 0.12058956921100616, 0.13689032809010573, 0.1179351673594543, 0.1335706226527691, 0.14807225950062275, 0.12465331543769155, 0.10491794121584722, 0.12164482687200819, 0.16157788836530276, 0.09439531514155013, 0.06626105481492621, 0.08941988247845854, 0.13566887006163597, 0.11894959078303405, 0.10031274440033094, 0.1060960679980261, 0.11631205731204577, 0.19550299724297865, 0.1031867948227695, 0.0749897767922708, 0.3330448546579906, 0.13110184084091867, 0.14702617563307285, 0.11132787154721362, 0.0990411222779325, 0.10077719483524561, 0.08266007235007626, 0.1352062313152211, 0.11052034702152014, 0.14234387688338757, 0.13894270653171198, 0.10921451994883162, 0.18047149239906243, 0.12131401390901633, 0.1731844334197896, 0.14454276460622037, 0.1364006565085479, 0.17139611366604054, 0.11817654940698828, 0.11184823326766491, 0.14532573973493917, 0.1478335644517626, 0.23278568738273211, 0.2153154191161905, 0.17273772667561257, 0.09420347972107784], [0.03467664069363049, 0.025248756233070577, 0.03329763701185584, 0.01660627605659621, 0.042008608513112576, 0.030747522599995136, 0.02617920925175505, 0.016461076347955635, 0.07539100133414779, 0.11617073203836169, 0.03937990278271692, 0.03630460226642234, 0.02616681411330189, 0.0919453694618174, 0.027540740656799505, 0.013862930138462355, 0.0262584299115198, 0.021008263508390104, 0.024665229687733308, 0.04082337407661336, 0.008619753494193512, 0.032175804887499125, 0.05938079793538366, 0.006001258867659739, 0.08580375223287515, 0.020433468012405292, 0.02519904506126685, 0.020297053635918667, 0.021536715062601224, 0.039388666062482765, 0.020334629208913872, 0.04222265238474522, 0.044227384097341976, 0.040006787715745826, 0.020468816294201782, 0.03931622566389186, 0.03600999932470066, 0.025066749392343417, 0.039645708698247156, 0.07119161595723458, 0.06272678981934275, 0.005592799870230789, 0.014924360771796532, 0.030409805543188537, 0.03177298578832831, 0.02214451619823064, 0.018447301017918756, 0.044295817746647766, 0.011086596392228134, 0.10266751197299787, 0.013817919518000312, 0.07753237642879997, 0.00470091266158436, 0.022919389618826762, 0.0354419806972146, 0.052805820746081214, 0.030873180500098636, 0.048629444491650374, 0.047642477987600226, 0.06122547002243144, 0.02857310963528497, 0.035652214594717534, 0.034779415000230074, 0.03950212051027587, 0.04524690671158688, 0.048033592357699356, 0.08356084115803242, 0.04845270986801811, 0.07523063636784043, 0.09537600858935288, 0.07767480771456446, 0.021509001996102076, 0.032393957288669686, 0.07325742260685988, 0.024740419849487286, 0.10679627542517015, 0.032948164335851154, 0.05548329618094223, 0.18155431215252193, 0.058972950891724656, 0.01756450829894415, 0.05670439797852721, 0.038571815072957955, 0.05211452587640711, 0.03163388610950538, 0.1290725190192461, 0.11772639570491654, 0.04963562371475356, 0.05612465765859399, 0.08287677607898201, 0.05682081762435181, 0.07120227574237756, 0.015433811649147953, 0.020180879959038327, 0.13341316181634152, 0.1920451827879463, 0.18913310047771248, 0.14595257038516657, 0.09989737240331513, 0.004427913426687675, 0.028328075373013104, 0.06703900199915681, 0.010075042323608483, 0.0319282176372196, 0.025161503415022577, 0.018288483111453906, 0.04434441103200827, 0.09264016217951264, 0.07413535871143852, 0.02329831919632852, 0.020057602020512735, 0.02582598427709724, 0.036488743099783144, 0.037574965706361194, 0.026515543793461153, 0.025812423754749552, 0.045882236012922864, 0.040625533621226034, 0.02566501371828573, 0.055328861610697846, 0.03634027624502778, 0.007358771649056247, 0.029336970432528427, 0.01867698003271861, 0.06522011424281768, 0.01731985231994518, 0.054016764874437025, 0.028148226273645247, 0.03812127799860068, 0.016207587539351413, 0.005379585507658443, 0.07267228793352842, 0.043236872247819386, 0.04469434171915054, 0.03211847207109843, 0.014199405476184828, 0.06720930750348739, 0.0383871483749577, 0.028087516049189225, 0.05768088450921433, 0.07462630593883139, 0.02846615555297051, 0.018121002009138465, 0.015553941185187017, 0.06611001291977507, 0.014173207239114811, 0.028828099702617953, 0.0383549654590232, 0.017621598539075682, 0.018483734955745082, 0.016414418583735824, 0.03762493981048465, 0.03531143734497683, 0.021995632044438804, 0.04386811337566801, 0.025246398323880773, 0.07953703350254468, 0.06477154152733938, 0.022597211013947214, 0.04774116751338754, 0.008929202782123216, 0.019830727051677446, 0.04074085743299552, 0.09812892015491213, 0.05531491432338953, 0.03536831554291504, 0.026984615051852803, 0.025243219387318407, 0.07574404310435057, 0.04401760142562645, 0.06285049353859254, 0.008024725780290152, 0.046020823397806714, 0.01805209168898208, 0.02793176851368376, 0.0424442076390343, 0.006224513428086149, 0.022029468889481256, 0.03682970016130379, 0.04520383330860308, 0.027474235743284225, 0.024249781355527893, 0.0716952992869275, 0.03269653980221067, 0.02921785700267979, 0.06105181255510875, 0.022621443195800697, 0.05716576107910701, 0.049412602824824195, 0.04735002260921257, 0.028413986388061727, 0.011508630754958307, 0.028066335578582118, 0.017306420719251037, 0.043047438841313124, 0.0670013568763222, 0.049363103695213795, 0.015461207500525882, 0.06140171270817518, 0.03289244982546993, 0.040450848173350096, 0.03366384914677058, 0.025529006462810293, 0.029426794898297106, 0.016304484036351954, 0.06280277895608119, 0.037613313112940104, 0.02666669086154018, 0.03079795471525618, 0.04119420024965491, 0.05682189649503146, 0.040562172021184645, 0.08231308311223984, 0.00908961015686925, 0.05309272910069142, 0.0743320117305432, 0.03990328398400119, 0.0761370641578521, 0.018361062609723637, 0.07652785961649247, 0.02357202665215092, 0.007265585890438939, 0.03314707687656794, 0.06432741321623325, 0.024333085099767362, 0.08309747637914759, 0.013869252388498612, 0.014248906302132776, 0.04805468801142914, 0.05572601494246295, 0.0528958419870053, 0.09268967487982341, 0.011344623751938343, 0.05196328381342547, 0.011079986612977726, 0.03488757348220263, 0.038709974980780056, 0.042038816892142804, 0.06164435004549367, 0.01627729513815471, 0.02792355484728302, 0.04268535559198686, 0.03256863595119544, 0.0503469828649291, 0.09734629786440305, 0.01650048735817628, 0.08073106514556067, 0.06999917208616223, 0.04871411548395242, 0.08376877142914704, 0.012974725254545254, 0.04337378704388227, 0.07062615879944392, 0.01733648999860244, 0.15261688349502428, 0.01905660850128957, 0.08092179455395256, 0.18719900426055702, 0.07907786885542528, 0.0841773377199258, 0.07563596604658024, 0.0848426820178117, 0.10600274229156119, 0.04348358418792486, 0.06462252166654382, 0.17978756981236593, 0.057991721401257176, 0.044726300718528886, 0.043581819095249684, 0.04450271664453404, 0.1373635112707104, 0.14287548192909785, 0.13321387608136448, 0.12798576376267842, 0.10427162982523441, 0.02396724107010024, 0.09891704536442246, 0.1446043620152133, 0.03552859229966998, 0.022313367941283753, 0.08213918137231044, 0.01972971354345126, 0.07848136872053146, 0.10091849975287914, 0.07287871185690165, 0.06975403773997511, 0.024219854568530406, 0.004503625636321625, 0.06893848614501101, 0.011190071286234473, 0.03738728292020304, 0.022418537476499165, 0.015006651802520667, 0.07360555178352765, 0.016975251525374394, 0.03584708985207336, 0.04221477459317871, 0.06431506387889385, 0.014670497072594506, 0.018618354607107382, 0.05893232021480799, 0.017197336036978022, 0.0791579834850771, 0.03214156601045813, 0.06405006202736072, 0.0375913285783359, 0.052910749401365004, 0.0631127744647009, 0.02621626913813608, 0.042017134305621893, 0.03967911297721522, 0.03179548940222178, 0.03894966747611761, 0.025023253601310507, 0.02484023235073047, 0.024719772028869817, 0.04333703080192208, 0.023490198721577014, 0.0797800033220223, 0.05863766638295991, 0.07426411751657724, 0.0226090904657862, 0.009341191433902298, 0.04146330723805087, 0.00420832380353074, 0.07404802446918828, 0.012324440193229487, 0.061148680214371, 0.04082066332921386, 0.05452807493773954, 0.02915148949250579, 0.025759648997336626, 0.014867077149184687, 0.0443245197779366, 0.0683945385473115, 0.06365941584642444, 0.017408915130155425, 0.056248503870197704, 0.03770947509578296, 0.0511178495362401, 0.040351225661912134, 0.04057797170909388, 0.024961635836267045, 0.026087720678853135, 0.028736114102814878, 0.04482609286372151, 0.009063360181504061, 0.033814236255628724, 0.050523401969777684, 0.016651943159688796, 0.05990235387746777, 0.03154120501130819, 0.11950278681303773, 0.07408216156597648, 0.10312643234751054, 0.06993950171662228, 0.09126027300953865, 0.13180082690502914, 0.10913488029369287, 0.0501987297487046, 0.19530061738831656, 0.16714667954615184, 0.06959249890808548, 0.19325540427650723, 0.10357827560177871, 0.1344672523971115, 0.08667938810374055, 0.0967323322381292, 0.1413026513265712, 0.08127626124769449, 0.06770487555435725, 0.16139563385929379, 0.1479382352637393, 0.14760169546519006, 0.0805295334596719, 0.09455895743199758, 0.1896938553878239, 0.14517980042312825, 0.13199762920183794, 0.09126450706805501, 0.11538156867027283, 0.12761299019413336, 0.13837336136826447, 0.12642490251788072, 0.045212691583271535, 0.12885948616479123, 0.136081012231963, 0.12809096383196966, 0.1425560140716178, 0.09020450644727264, 0.16547746982957634, 0.19136679704700196, 0.12268667668104172, 0.2115617905344282, 0.12582385619836195, 0.14472606405615807, 0.11688417089836937, 0.11335306109062263, 0.10727542292858873, 0.16729928207184586, 0.12072481481092316, 0.2689709828368255, 0.07579114700534514, 0.23234827656831059, 0.10475549993238278, 0.1379270888864994, 0.1667718296604497, 0.16436673514544964, 0.1165197297398533, 0.15511078467326506, 0.16440357959696225, 0.3050533580992903, 0.1809737847319671, 0.24389433701123509, 0.12037424290818827, 0.2423662490078381, 0.14623849147132464, 0.11608579302472727, 0.15493645545627388, 0.10710057123963322, 0.2783540364887033, 0.20328587533107825, 0.26496518350073267, 0.19013408890792302, 0.1607875850583826, 0.15804652071424893, 0.12378569985074656, 0.12222299299069814, 0.1612177084067038, 0.10292891758893218, 0.2918476281421525, 0.12017182234142508, 0.15970887722713606, 0.3160563733960901, 0.21306805685162544, 0.18322455324232578, 0.15371202544442245, 0.2306897741343294, 0.29658985510468483, 0.14734733982809953, 0.24222885923726217, 0.32925309240818024, 0.18160297668405942, 0.20433121281010763, 0.1691206871931042, 0.20548090897500515, 0.2200691540326391, 0.333566349531923, 0.455930694937706, 0.11941623288605895, 0.21279162168502808, 0.13097932455795153, 0.2009816246905497, 0.294608261436224, 0.15395751941416944, 0.12373900307076317, 0.1278306913695165, 0.13079640508762427, 0.1443962553249938, 0.15050695171313627, 0.1390415962253298, 0.13792514827634605, 0.03795709288013833, 0.11202772613614798, 0.1806407868862152, 0.08139151042061192, 0.07899609181497778, 0.1654310987464019, 0.10443123483232089, 0.1753597759774753, 0.06253956843699728, 0.08448492442922932, 0.1406532254602228, 0.1571029227759157, 0.1639891304075718, 0.05937859269657305, 0.13904900582773344, 0.10866938491484948, 0.12679412056292805, 0.10142993195248501, 0.1808146818407944, 0.11098623595067433, 0.11000291657234941, 0.24026813730597496, 0.0668215247403298, 0.15242255106568336, 0.15542262579713548, 0.10683548117854766, 0.13304626436105796, 0.10435620242995874, 0.07046694734266826, 0.14890436056469167, 0.11261115768658263, 0.1610480746520417, 0.17630713299981185, 0.14530862708176884, 0.1962868816086224, 0.06299350157912288, 0.12067301544759955, 0.17291026456015451, 0.09706180170178413, 0.1693920333470617, 0.13704147855085985, 0.1750887690910271, 0.19753064986850533, 0.12083504961005279, 0.1726498563906976, 0.1544528906898839, 0.13329310183014187, 0.14532955310174397, 0.1750771797129086, 0.1453793847135135, 0.1519066473203046, 0.10121244790830783, 0.18688752954559668, 0.2173650019935199, 0.13849454772259506, 0.07682288664260081, 0.11727137012141091, 0.12410022797329084, 0.23966141843370029, 0.15143562188105925, 0.07854918829564538, 0.13891044897692545, 0.24406087664621218, 0.09967403938727719, 0.12879763091249125, 0.1435871837394578], [0.04533845465630293, 0.08072789638702359, 0.0290770338449095, 0.03204246936365962, 0.08256689592131547, 0.0188584677941565, 0.03566223994961806, 0.03611739445477724, 0.07661980789686952, 0.007717842202899712, 0.022176361542993357, 0.03344368488926973, 0.043520927362676175, 0.04309360636398196, 0.01956068368495575, 0.004162844569821442, 0.01303152202828122, 0.030171487081263746, 0.02016179446530129, 0.024026528067354645, 0.020271460991352797, 0.03838065479482923, 0.058083662896284034, 0.06079028480287109, 0.016333365879420723, 0.07948151576731886, 0.08021602313965559, 0.031201811973005533, 0.037081813240157704, 0.05176668168444719, 0.06410788678164993, 0.024547203610252057, 0.013092036325750607, 0.052542474519993575, 0.008773130397977573, 0.05372107627668551, 0.05490676533164723, 0.027550038282892535, 0.04154698417655059, 0.012975230763134147, 0.03617836421887789, 0.03358118322544864, 0.04602099981691156, 0.07338753169668571, 0.02926583621384842, 0.012612570759042032, 0.025519072710137283, 0.0053867737380122495, 0.04100218841007777, 0.06216232332267931, 0.011208341689780354, 0.03379655363304274, 0.049783293290862014, 0.06695674998419625, 0.039625708878572495, 0.028069823248577968, 0.04856622877663799, 0.06841328646987677, 0.04456352356023022, 0.06926382333040237, 0.034284410133425675, 0.04575261886098555, 0.027857165284720913, 0.021469348409612263, 0.08268167011971984, 0.02514954762799399, 0.010849112528376281, 0.018578527994187813, 0.027208019314067702, 0.14695172677082674, 0.14785200703356946, 0.05623696877488068, 0.1038939572338547, 0.0815806384863598, 0.03222674251134906, 0.09506481207375016, 0.38663636467286516, 0.1014107633382082, 0.19375601384256566, 0.05644947915737118, 0.059981063939630985, 1.2572923856122153, 0.5185142053025109, 0.8248946964740753, 1.5359611809253693, 1.0722225563866752, 0.22976072398679598, 0.3813116561089243, 0.839969627559185, 1.2084084429911204, 0.9268728643655777, 1.9385656458990914, 0.7708151297909873, 1.8859671311719077, 4.22212107692446, 5.063151010445186, 6.631925276347569, 2.2547458112239838, 0.29665187320538927, 0.09803193714469671, 0.15930609884006636, 0.1299227098269122, 0.030910710271980082, 0.05720799309866769, 0.07183939976883785, 0.041801180357911756, 0.017996217722871473, 0.03871534897812775, 0.03086907197056072, 0.046282690417553694, 0.021661775851888315, 0.012043050872827215, 0.08086235488631896, 0.019794060715607235, 0.016591227846220136, 0.06700899039528199, 0.053779440466314554, 0.05275274234424744, 0.05872268003544637, 0.03189782266105924, 0.028540696017444134, 0.0542246680041509, 0.21427664985614164, 0.03440542685400162, 0.03562314954719373, 0.04560573299282363, 0.040401060666356764, 0.07621622205312763, 0.05406855405973537, 0.050498089220907004, 0.019728495573092784, 0.04624765765454088, 0.03299119024138365, 0.027681614704696194, 0.037337363098881075, 0.03941367007791996, 0.06253946665674448, 0.1335972212255001, 0.07054249543164458, 0.01572095579467714, 0.057003767628754885, 0.10010653082281351, 0.01555440598167479, 0.023912445974669287, 0.033998170135808845, 0.05834559776953288, 0.030223903911454335, 0.011477592018699008, 0.04798344861982124, 0.033298583568206856, 0.08667772569294487, 0.006852251618901002, 0.05851530616304704, 0.06444770390433924, 0.028761477741811956, 0.029306633131844655, 0.05953643351261105, 0.017599834528352534, 0.014463601567383324, 0.05000133712642959, 0.0380148429955755, 0.04830115907160299, 0.022929832272763764, 0.06949667619275195, 0.018048237610076154, 0.047593033140791316, 0.07010301508541618, 0.08702214328306061, 0.06537586517099823, 0.016872838538672243, 0.029120918097240583, 0.06428398018968956, 0.037814648023673465, 0.07839246027703796, 0.033412099084151645, 0.02848725120670029, 0.03207920864224434, 0.08289703034928866, 0.019484774276082004, 0.03986998148528593, 0.05269769958353468, 0.023377558515806283, 0.04454665517966662, 0.023146834557077715, 0.03891694512484329, 0.027547537881348814, 0.014268531231209636, 0.010340922877990773, 0.041792925979409895, 0.00498428415240986, 0.03924458593662296, 0.038194970294300995, 0.03166382307452815, 0.03385564724781683, 0.009019412316514977, 0.03721814449610455, 0.06642077517296587, 0.05638528974460704, 0.005528206305046166, 0.03864129027351737, 0.03490171075931617, 0.049744420019643645, 0.07641961971031767, 0.007611656561493874, 0.046627063902893236, 0.03824201312714389, 0.028303179923178892, 0.04872760476012315, 0.03410728535215769, 0.043265289294400384, 0.07789848678346191, 0.03943606512621045, 0.018554967562002794, 0.05934800433793238, 0.11413298281175749, 0.002678335690039343, 0.07296814277235951, 0.06867878365197352, 0.02963545120188168, 0.08073930256068707, 0.02248090841541333, 0.011938062845729291, 0.043796266695218425, 0.024918732067037905, 0.02342232147098652, 0.024117041246167252, 0.044625779148191214, 0.03619628772139549, 0.025446131891970123, 0.05898337997496128, 0.05860255219574485, 0.02844468331230538, 0.06297595466354064, 0.06035025484327759, 0.04999084697504129, 0.011864159356004425, 0.01898307566131864, 0.023705122992396355, 0.05907646140881947, 0.03394622149478112, 0.030034853877233605, 0.035385974416775365, 0.03724842072863664, 0.03599438623392156, 0.03058891503938607, 0.06595420092344284, 0.02031524176709354, 0.0194098232979221, 0.08036938562457051, 0.02432399781953011, 0.037302862985857894, 0.0854575704517109, 0.019645091744938066, 0.13312171745513166, 0.2714799339217799, 0.191268775878208, 1.2912791733230864, 3.9132858089038303, 3.2714750596455167, 4.85678734098162, 5.950502412659781, 3.7229616216250827, 1.9565729882035936, 1.3875923880508967, 3.284991477216993, 4.670233419963291, 4.4085434164319715, 5.270569937569754, 3.0855955481529236, 6.561449263777051, 12.624848178454808, 14.903618471963064, 19.23250252859933, 8.520274553980146, 1.9660464227199554, 0.20069801062345505, 0.17292983351009233, 0.20373464482171194, 0.016073799093386958, 0.04043888220829623, 0.09920416745756354, 0.08096383658370801, 0.030861818431211368, 0.03154145606926509, 0.046472744683602026, 0.019041003892198205, 0.02015795056442065, 0.027054860389658382, 0.026520603968362724, 0.014401479990088513, 0.01916370677229549, 0.04549917585349508, 0.01859642774797976, 0.04877652034961751, 0.04271406101595078, 0.030153495725244284, 0.01837173935824207, 0.049226032836096625, 0.07645507995039225, 0.06459920720330306, 0.04252689052373171, 0.05924222751387528, 0.01042214606422931, 0.048007492508207045, 0.017660775454714894, 0.0341454868737076, 0.05313503575910415, 0.04109336994588375, 0.033221115225127766, 0.02068624266290239, 0.00639724257468645, 0.025402765022590756, 0.07170139931674514, 0.08839625133467571, 0.011778778446439122, 0.012008534644597342, 0.009432032005861402, 0.02524027624167502, 0.02560672247117119, 0.030297328185822283, 0.031252515502274036, 0.03696260142273136, 0.07985901872494391, 0.0193049489254398, 0.04619745284851108, 0.033371037537498136, 0.0303438078345997, 0.07023241171347243, 0.06111839719648872, 0.06643487513065338, 0.07611294902328934, 0.009281303933156388, 0.048684507608413696, 0.04336991260892578, 0.009245844541250594, 0.04516237142628857, 0.01662767705108438, 0.04821524636021682, 0.08404386309640748, 0.015528799766408545, 0.07805628688739878, 0.03239392675459385, 0.06714792044035026, 0.06981995063168661, 0.04015563115743654, 0.017529297420488935, 0.014669594621019704, 0.06645964165883404, 0.06749216161136116, 0.04804248795179384, 0.0639860558190516, 0.04659261807267155, 0.10493478924036026, 0.20807925026331628, 0.10026873461902142, 0.07596177142113447, 0.1393946787076337, 0.11842574817793709, 0.08670912150825773, 0.1001123594386237, 0.2302982322871685, 0.1418467956994261, 0.10997410597545759, 0.034960807766765356, 0.14897836159382546, 0.0773463628387877, 0.15755334789199488, 0.0928723704335945, 0.06986071023025683, 0.11556066120309488, 0.1211626191756555, 0.14508671898927006, 0.11815126719219343, 0.12703842031104223, 0.13325434390987667, 0.12018345243164472, 0.13059971135641846, 0.09242176889841046, 0.25289230846932953, 0.09284698643854686, 0.09970643264906746, 0.19110454326229437, 0.11387337531362261, 0.10755269269325904, 0.06703999266028404, 0.19163720682263374, 0.1598582634968417, 0.14536501334181853, 0.12719550116785935, 0.13577415155512945, 0.19385957185711178, 0.16014531095113071, 0.1793110075273684, 0.14672301975744112, 0.094068057702056, 0.2231447904237679, 0.06025703091706548, 0.07944528878267322, 0.09532712692660944, 0.11969673926276819, 0.12884430055107388, 0.1766025942883321, 0.09277188618268285, 0.13285064271518163, 0.13196984997817449, 0.12396753366504397, 0.16551758481987885, 0.10355934447475842, 0.14410996782992566, 0.15190842508205346, 0.1507768729435546, 0.15406757779419422, 0.18049016568277562, 0.09673477496419634, 0.12479693415973868, 0.17350193352571555, 0.19041869363614491, 0.12035953226898398, 0.1933648655457156, 0.107443971027221, 0.12348231327320848, 0.25519949038113865, 0.19606310075947217, 0.1636026097195489, 0.25657479943973677, 0.1428179285888161, 0.12141214364341327, 0.26988374814391136, 0.5078457349113056, 0.1688919123262167, 0.29499087376253946, 0.1290551892348698, 0.7823393142649105, 2.2924751809665134, 2.0530176758766174, 3.900543681212834, 5.407567134925297, 3.0489889638764516, 1.2615962518113, 1.2181465604475565, 2.6953758129051755, 3.984783640929631, 4.112080284527369, 4.870317654950278, 2.8227171855313435, 6.530958831310272, 11.336308223860604, 12.551051361220223, 16.419201237814768, 5.7526116371154785, 0.8549983096974236, 0.2859283329120704, 0.2977903464010784, 0.3743871791022164, 0.22430401322032723, 0.21152405041669095, 0.2066517618617841, 0.16414536988096579, 0.08380661332713706, 0.13969588040241174, 0.1346509861094611, 0.09588761042271342, 0.08839243118252073, 0.11359409029994692, 0.17211542863930973, 0.09821093468261616, 0.09902553632855415, 0.13264375738799572, 0.16492466734988348, 0.14538106748035975, 0.12248545033591134, 0.1035529798162835, 0.17133697255381516, 0.20530434059245245, 0.35015590648565975, 0.11166918144694396, 0.1729820535651275, 0.1733560756381069, 0.12363619144473757, 0.19893242179283074, 0.12665641866624355, 0.14420193646635326, 0.09032399646405663, 0.14464757112520082, 0.18096987637025969, 0.07262222561985254, 0.11229249728577477, 0.1465216984174081, 0.21133117005228996, 0.22602209102894577, 0.06365036418927567, 0.13174260860042913, 0.09462062269449234, 0.16782008484005928, 0.0910478372659002, 0.12757599646491663, 0.11667746199028832, 0.16969384572335652, 0.13679369113274983, 0.08922755851277284, 0.20366760556186947, 0.1540009185139622, 0.1660573865686144, 0.1228052167487996, 0.09833849248077188, 0.18545529139893396, 0.10890358127653599, 0.07313255180737802, 0.15120145944612368, 0.08894123709095375, 0.10083358109529529, 0.1272476397986923, 0.11089677789381572, 0.10948915699762957, 0.11237234728676931, 0.11195312121084758, 0.21108418330550194, 0.07991056703031063, 0.15288774110376835, 0.12255744290138994, 0.24466735124588013, 0.07653406821191311, 0.0749235110623496, 0.19000348448753357, 0.18182747678032943, 0.1578795603875603, 0.12382639838116509, 0.16028921465788568], [0.050127137518887005, 0.08781311833964926, 0.08334290249539272, 0.035407880919852426, 0.022956312101866518, 0.026766092849097083, 0.022218135551416447, 0.043116266040929725, 0.025077644968405366, 0.049910678062587976, 0.0387303344240146, 0.09004165804279701, 0.07719734297799212, 0.04905482488019126, 0.05576333776116371, 0.07908645232341119, 0.04658660285973123, 0.010477471265143581, 0.06053143726395709, 0.040206433074282746, 0.07414751127362251, 0.04206829923870308, 0.052582341845014265, 0.025455171674756066, 0.0318683742412499, 0.02694097507212843, 0.023227279972551123, 0.041552426027400155, 0.02373707520642451, 0.0315708705623235, 0.009780466523287552, 0.034887230822018216, 0.04529813949816993, 0.04783999613885369, 0.055869942397943566, 0.03082015977374145, 0.025028245922710215, 0.045649291548345766, 0.04823680681043437, 0.007951226018901383, 0.05919004138559103, 0.07782786485872098, 0.05935749025749309, 0.04089426741536174, 0.016337070680622543, 0.04318279300683311, 0.02310580524083759, 0.07101474901927368, 0.09899536866162505, 0.04627486351611359, 0.07722015532531909, 0.06502260626958949, 0.060646489661719115, 0.04719045152887702, 0.025565148630578603, 0.053765072487294674, 0.08749187272042036, 0.0756306666880846, 0.020162600225635936, 0.01888096801537488, 0.05458660536844816, 0.029598630499094725, 0.053843643449779065, 0.06197217745440347, 0.07578565087169409, 0.01114117944546576, 0.05787417199462652, 0.07196003650980336, 0.0879820396325418, 0.1621778490287917, 0.3169785567692348, 0.11816926194088799, 0.09608840250543185, 0.15052723991019384, 0.6210432893463543, 4.6170419199126105, 13.536159140723091, 17.833057165145874, 32.37894589560372, 33.3513115474156, 53.322456223624094, 62.01937048775809, 61.58693545205252, 68.22284725734166, 67.51707703726632, 66.29106739589146, 57.38546398707798, 52.09355960573469, 60.672705377851216, 61.761529786246165, 61.725941113063264, 71.5311416898455, 65.52133900778634, 68.70539964948381, 88.72047083718437, 86.30275481087821, 97.21519252232143, 77.78173419407436, 62.4831349509103, 22.46838457243783, 6.702024349144526, 1.4859203632388795, 0.21987407521477767, 0.027927519188129475, 0.16830039263835975, 0.0662938484123775, 0.10428442699568612, 0.08542511612176895, 0.10774691655699696, 0.12294373288750648, 0.027756068655954938, 0.032999010357473574, 0.02173611954120653, 0.01323277551481234, 0.060117069498768876, 0.061657506839505265, 0.04472199880651065, 0.07136257285518305, 0.047633416152426174, 0.07216874031083924, 0.10426400987697498, 0.017119097556652765, 0.0595469983028514, 0.07099269663116761, 0.05666849669069052, 0.07208152141954217, 0.03382361700226154, 0.06140002315597875, 0.025721008124362146, 0.05195796409887927, 0.011413160877834474, 0.006909379178458559, 0.05589698880378689, 0.01996441202105156, 0.05676186310925654, 0.04651112262425678, 0.036497221394841156, 0.049207122065126896, 0.0734087766281196, 0.03042542202664273, 0.028295322487662946, 0.10181529234562602, 0.03275026281231216, 0.035605751909315586, 0.021836773425872837, 0.02984058590871947, 0.02335765538737178, 0.014417042190741216, 0.057832611724734306, 0.039054287397967916, 0.030339112372270653, 0.015465171841372336, 0.010328927227029843, 0.03446234576404095, 0.0786391823951687, 0.0049336489007276085, 0.05332064562078033, 0.016991003715832318, 0.015918384040040628, 0.016558259526001554, 0.016174927952566316, 0.037303802756858725, 0.03520017456529396, 0.036498924517737966, 0.009790283228669847, 0.048940634221902916, 0.13069822107042584, 0.04633886972442269, 0.028307907615921328, 0.030226563768727437, 0.04434349840240819, 0.08077685947396926, 0.06573708328817572, 0.04866949841380119, 0.05270403031525867, 0.012398433588844324, 0.03468629624694586, 0.04798784552674208, 0.017870727760185088, 0.007352539304909962, 0.003461114255644913, 0.01925159741326102, 0.06434014931853328, 0.027261794910633137, 0.06829555385879107, 0.03013170457312039, 0.03709297853388956, 0.03381020575761795, 0.03318949888593384, 0.08603205212524959, 0.007549824209750763, 0.05886710621416569, 0.04591983024563108, 0.026297530491969416, 0.054728575250399966, 0.04179415073511856, 0.041679485102317164, 0.07753240357020072, 0.03221330073262964, 0.05241330859384366, 0.017108680347778966, 0.03808846743777394, 0.02343299482682986, 0.05307851718472583, 0.05868601200303861, 0.01995872929027038, 0.047300835605710745, 0.0444048922508955, 0.06913773795323712, 0.033903677349111865, 0.033639598305204084, 0.023613809142261744, 0.028475763608834574, 0.006455580895167908, 0.046293787857783694, 0.015927074377291968, 0.07374156412801572, 0.03941170232636588, 0.023334037279710174, 0.03289428526269538, 0.020021264773926566, 0.028350156598857472, 0.035714965513242145, 0.0647936753396477, 0.05709847754665783, 0.08733703781451498, 0.025050766499979154, 0.03540168928780726, 0.01443680452315935, 0.0415769991731005, 0.03435708462659802, 0.011069904430769384, 0.01527823374739715, 0.025786758167669177, 0.012671873871503132, 0.04534692277333566, 0.051675021781453064, 0.07934113365731069, 0.033459148702344725, 0.017699718275772672, 0.06544730133776154, 0.0585754718631506, 0.05659073318487831, 0.03858818133760776, 0.0882100545402084, 0.14113860870046274, 0.09171656745352916, 0.10064410019133772, 0.1712236843471016, 0.55551037724529, 2.787310685430254, 13.58572324684688, 28.32742871556963, 38.05229595729283, 55.726998465401785, 55.02780818939209, 78.5343769618443, 83.90443120683942, 84.94245038713727, 90.9674070903233, 92.263489314488, 87.83469363621303, 79.93218776157924, 73.5440000806536, 82.7062907900129, 81.151200566973, 84.25455788203648, 93.13524505070278, 88.9404855455671, 93.0410761151995, 113.3461581638881, 111.99194036211286, 123.05804443359375, 107.0547102519444, 90.07487624032157, 46.249488830566406, 17.80597482408796, 8.117359808513097, 0.7544705239789826, 0.03577085305005312, 0.21538917587271758, 0.09905083889939956, 0.17483146861195564, 0.0011037314605865894, 0.09099779530827488, 0.06900359836540051, 0.031773423443415334, 0.07081333946968828, 0.05990779572831733, 0.06856971593307597, 0.03465512774086424, 0.08973458023475749, 0.0699820594329919, 0.03927349492109247, 0.02284281694197229, 0.03776551191029804, 0.06677115708589554, 0.010792839074773448, 0.043443893282009025, 0.10337765993816511, 0.0503646010266883, 0.02417245550480272, 0.02359089331834444, 0.03926152217068842, 0.03504476968997291, 0.03600364823692611, 0.07224712467619351, 0.04660230755273785, 0.013945772478889142, 0.05317534073921187, 0.015931322006508708, 0.004711686525427337, 0.05354550873328533, 0.03635779941188438, 0.039707340033991, 0.048375326341816356, 0.043327510955610445, 0.04119720615978752, 0.02630290448931711, 0.05294138186478189, 0.05833974201232195, 0.023843864743996943, 0.02848109689408115, 0.09260733465531043, 0.06476495295230832, 0.01416846173482814, 0.12519203153039726, 0.07558384098644767, 0.021813199422987442, 0.02596290416217276, 0.06394696541662727, 0.037884615162121396, 0.04036748336095895, 0.022610098090288893, 0.049170060482408316, 0.027800762061295763, 0.07272098639181682, 0.06244105193763971, 0.10115779869790588, 0.04401297042412417, 0.010797365751516606, 0.03560562298766204, 0.1251632616456066, 0.021250827903194085, 0.02544813017760004, 0.04794664827308484, 0.0993129230503525, 0.04429059302700417, 0.015337926169325198, 0.0526873994219516, 0.038088867773434947, 0.07313410565257072, 0.08030119964054652, 0.17513258888253144, 0.18521130377692835, 0.09436051308044366, 0.09850780053862504, 0.07488136046699115, 0.0971803485548922, 0.10308890936097928, 0.19333287940493651, 0.12448901496827602, 0.10455226512359721, 0.2176931822406394, 0.11787929678601877, 0.2133533265441656, 0.16416769368307932, 0.12305149781916823, 0.12673150535140718, 0.08545347888554845, 0.1914518717676401, 0.1856142043003014, 0.2802893540688923, 0.1528185848146677, 0.20073417653994902, 0.16929116233118943, 0.16229450276919774, 0.10784536520285265, 0.1022485505257334, 0.13307873904705048, 0.18101774023047515, 0.08724502846598625, 0.05813566582011325, 0.15602687480194227, 0.17910931977842534, 0.16077689134648868, 0.1586839229400669, 0.0622465227331434, 0.09803870213883263, 0.1521097599927868, 0.12681385236127035, 0.1176098505301135, 0.17992210973586353, 0.10560254233756236, 0.14123478425400599, 0.10728932611112084, 0.10924693356667246, 0.14903519568698748, 0.08542444437210049, 0.16567864189190523, 0.1541979108005762, 0.1757471923317228, 0.17264066902654512, 0.1721954686301095, 0.2233967033347913, 0.2006511374243668, 0.1163543164730072, 0.13427724902118954, 0.13327218938086713, 0.16065613925457, 0.1259043983050755, 0.1515517599348511, 0.27860615296023233, 0.18646362157804625, 0.16239960784358637, 0.10283044858702592, 0.14064060470887593, 0.10050850175321102, 0.13892040987099918, 0.1468101707952363, 0.1922456356031554, 0.37633766872542246, 0.3938556787158762, 0.19612700518752846, 0.1143263110092708, 0.3745098039507866, 1.5513820563043867, 10.022433400154114, 23.678557532174246, 36.959379059927805, 53.455027852739605, 55.05710874285017, 82.33891868591309, 88.66154316493443, 91.3076673235212, 100.45756939479283, 99.74018873487199, 96.86532293047223, 87.61024597712925, 81.6538610458374, 95.10207162584577, 92.89954825810024, 95.80184555053711, 103.30496897016252, 95.0165879385812, 103.38804163251604, 124.6487511226109, 123.47907747541154, 136.74863597324915, 118.08772005353654, 91.90804031917027, 43.20105355126517, 14.886753456933157, 6.406007204736982, 0.3466562128492764, 0.11252791501049485, 0.4145750712071146, 0.20041933629129613, 0.26790345726268633, 0.16271474664764746, 0.22393265100462095, 0.1480392419866153, 0.17444129740553244, 0.10581226394112621, 0.15436371761773313, 0.14356833403663977, 0.12568187953105994, 0.31447772096310345, 0.12460591298128877, 0.18349425734153815, 0.1491634523762124, 0.09595929086208344, 0.15760569008333342, 0.08640230832887547, 0.13348143600991794, 0.22961684742144176, 0.18535319902002811, 0.1385540281023298, 0.11866437537329537, 0.16828979392136845, 0.12943235971033573, 0.1130546210333705, 0.24595811484115465, 0.21864866811249936, 0.14562276165400231, 0.15132484425391468, 0.16953247652522155, 0.08551644014992885, 0.12312463032347815, 0.25843553245067596, 0.17243942911071436, 0.1288418849664075, 0.12533034410859856, 0.20878508953111513, 0.09588801075837441, 0.12283291454826083, 0.1400586116526808, 0.10613168430115495, 0.1048681978136301, 0.2229758080627237, 0.17896594532898494, 0.11054870978529964, 0.22383316420018673, 0.18727475591003895, 0.14833163629685128, 0.13448313011654786, 0.1943094948572772, 0.14819736778736115, 0.1162560646023069, 0.14711689576506615, 0.09904623164662293, 0.11285486710923058, 0.16614414405609879, 0.07524747082165309, 0.16694853375000612, 0.1334231769932168, 0.16038758866488934, 0.09124141652137041, 0.2728719620832375, 0.23630383717162268, 0.07843746071947472, 0.12006937712430954, 0.21591884030827455, 0.10891716554760933, 0.14956302807799407, 0.28100735268422533, 0.13620605266519956, 0.14847632710422787], [0.05298554431647062, 0.06213396055889981, 0.056561108345964124, 0.052225232257374694, 0.056028750126383135, 0.08467017806002072, 0.09584024189306156, 0.06413686022694622, 0.08464455657771655, 0.054743258748203516, 0.055695901558335335, 0.04974970241476383, 0.0794755243031042, 0.04235970288781183, 0.03549980205882873, 0.031244976978216852, 0.04542299333427634, 0.045048889837094715, 0.06374672294727393, 0.024917432672477195, 0.15985141029315336, 0.10410717329276459, 0.042343139848006625, 0.056638987202729495, 0.055282239469566515, 0.07118336497140781, 0.050269260071218014, 0.061728121978896, 0.02280747883820108, 0.022411117696070244, 0.025385625228019695, 0.029976374336651394, 0.06308870682758944, 0.050569969828107526, 0.03700898607660617, 0.02016737711216722, 0.06363655600164618, 0.02202767925336957, 0.03169028254758034, 0.05841092712112835, 0.02777662657068244, 0.061556975091142316, 0.026790625282696316, 0.10085321111338479, 0.023877883097156882, 0.027709933363699486, 0.043157833096172125, 0.02328919798934034, 0.015629295891683017, 0.026540469777371203, 0.026919095710452114, 0.02951008846451129, 0.11532837152481079, 0.023903194149690013, 0.02276902795503182, 0.05894534808716603, 0.014030280622786708, 0.0079190490401483, 0.014676600495087249, 0.01697795548742371, 0.0415860881496753, 0.03461138937356217, 0.17020244843193463, 0.08451509209615843, 0.07564193715474435, 0.0647809256666473, 0.07166452772383179, 0.07703189578439508, 1.6369105811629976, 7.4297738926751276, 18.89914185660226, 19.54770929472787, 26.00509408542088, 35.96124948774065, 50.94349724905831, 83.39891501835415, 89.23253917694092, 97.24433326721191, 92.59348011016846, 92.55522332872663, 91.6047306060791, 101.95256464821952, 90.1498611995152, 91.77250180925641, 92.42024067470005, 99.23480456215995, 97.94637925284249, 99.67998259408134, 95.13800076075962, 92.36665616716657, 96.91487748282296, 92.4467202595302, 96.44066987718854, 100.58158084324428, 90.79499449048723, 93.05407619476318, 93.61212771279472, 95.67174748011998, 94.616607938494, 89.34308501652309, 81.85811723981584, 62.69078186580113, 47.929153306143625, 24.82395417349679, 5.043279596737452, 1.714527387704168, 1.9100960535662515, 0.12842070470963204, 0.24283427532230104, 0.24739669050489152, 0.033768886367657354, 0.042376605195126364, 0.0805876771254199, 0.07169054275644676, 0.16322858764656953, 0.0214147348222988, 0.09089799637773208, 0.039541563750909905, 0.034897758292832544, 0.03688089902113591, 0.009581596391009433, 0.10117552203259297, 0.007186578969205064, 0.03315930747027908, 0.04321992244305355, 0.020984535138787966, 0.014630251464300921, 0.06963923640016999, 0.018234553148171732, 0.06410068752510206, 0.05772545068923916, 0.05199699343315192, 0.04723837645724416, 0.035935319760548215, 0.0432069454608219, 0.09378063026815653, 0.036183419304766824, 0.01731849355357034, 0.06524754062827144, 0.037056110333651304, 0.004979044589812734, 0.04570396450747337, 0.06028029788285494, 0.05413145425596407, 0.06809153194938387, 0.01123224223764347, 0.01804074488713273, 0.05764754129839795, 0.04671801473679287, 0.05668937860588942, 0.061548398408506594, 0.05875801813921758, 0.0285615473985672, 0.0358656986749598, 0.02646146115979978, 0.006799453112762421, 0.04893069029120462, 0.03916606247158987, 0.04196802533364721, 0.03158667703558292, 0.014263128396123648, 0.013993399700016847, 0.01266896041176681, 0.06770366776202406, 0.06674227863550186, 0.0535805143548974, 0.0540493074139314, 0.06763770737286125, 0.036628721481455226, 0.011131213462379361, 0.021336993368874704, 0.04031060516302075, 0.07264399302325078, 0.009566475238118852, 0.040085107620273314, 0.01785726223274001, 0.025959411403164268, 0.009135481668636203, 0.05529801880142518, 0.06345301906445197, 0.03912067526419248, 0.010048287687823176, 0.0701124942196267, 0.033616307590688975, 0.019353333561282073, 0.0210559068447245, 0.02106638003273734, 0.05066345838297691, 0.009765801685197013, 0.040262276506317515, 0.04214725357347301, 0.0733789075165987, 0.018462316997881447, 0.07585087165768657, 0.06910484936088324, 0.007661175198986062, 0.07707327284983226, 0.006389551804334457, 0.06944485647337777, 0.01694379124923476, 0.04707876466480749, 0.06629877457661287, 0.037900530200983794, 0.022914066511605467, 0.003150595002807677, 0.02181008833992694, 0.0019402418360446713, 0.0304758914613298, 0.011359374255074986, 0.06608487319733415, 0.015325178192662341, 0.039379387096102746, 0.03383576277909534, 0.06203643472066947, 0.06196817409779344, 0.04233922470094902, 0.026612935621025305, 0.01121980553892042, 0.036866381764411926, 0.047868219802954366, 0.05185559352061578, 0.027333641591082727, 0.0687376262087907, 0.0492733369049217, 0.05728517645703895, 0.028482202906161547, 0.005845718285334962, 0.045369104083095274, 0.06362482413117375, 0.07052681448736361, 0.02502057678066194, 0.024863100677196468, 0.018333391951663152, 0.029076301027089357, 0.02059240635883595, 0.07643447284187589, 0.021741398543651615, 0.11277134623378515, 0.14830872895462172, 0.02470603848009237, 0.04228043642693332, 0.029626447042184215, 0.06256227900407144, 0.7524944128734725, 5.816028279917581, 18.213893141065324, 37.04389347348894, 39.11737142290388, 50.31989642551967, 59.31627804892403, 76.9118127822876, 105.15161255427769, 109.10325459071568, 115.81791727883476, 104.34485721588135, 105.36022526877267, 102.329421043396, 112.92490972791398, 99.7935300554548, 100.93506349836076, 102.17326028006417, 106.48604883466447, 106.78975459507534, 110.2301412309919, 105.10155078342983, 106.47797502790178, 109.1935394832066, 103.46481922694615, 106.27050876617432, 108.24037170410156, 101.35006550380162, 102.22129317692348, 101.65384769439697, 107.086838722229, 105.11653804779053, 108.76940059661865, 104.79899842398507, 87.9975802557809, 74.01604679652623, 44.77021040235247, 13.908095342772347, 5.687301175934928, 5.432432132107871, 0.25911528883235796, 0.03588843299075961, 0.2719097180025918, 0.05155506018283112, 0.009167487317297076, 0.11858774162828922, 0.13320396947009222, 0.11797748080321721, 0.02825715658920152, 0.023391753468396406, 0.03153766305851085, 0.10393933765590191, 0.031335384984101565, 0.01845266653357872, 0.04809945775195956, 0.06684239647750344, 0.004672990097398204, 0.06730601909969534, 0.06044567043759993, 0.06604408645736319, 0.012584464990400841, 0.04546185303479433, 0.0037228994271052735, 0.005469255606710378, 0.043583749527377744, 0.05009042538170304, 0.02581674771915589, 0.017036949018282548, 0.08621997918401446, 0.08260655629315547, 0.05028599613745298, 0.05078956072351762, 0.004474725981708616, 0.041724872309714556, 0.04687917358907206, 0.035953881085983345, 0.03365581529214978, 0.04920450631263001, 0.031055394294006482, 0.025303748103656938, 0.10658103733190469, 0.02810703750167574, 0.02079690833176885, 0.0065219225361943245, 0.024940631784764782, 0.016854830219277313, 0.052262422761746814, 0.05007199297792145, 0.05134579319772976, 0.041068230223442824, 0.026521718462130854, 0.017064400848799517, 0.049697411113551686, 0.07598243281245232, 0.04284883503402982, 0.034918172018868585, 0.03701739312548723, 0.009891653815949602, 0.024695996161816374, 0.04598990934235709, 0.09024887585214206, 0.11245720487620149, 0.026801347832328508, 0.054338275122323206, 0.03705503824832184, 0.02987241598644427, 0.0438762015130903, 0.00879915221594274, 0.022110089027721967, 0.09670173030878816, 0.07825583046568291, 0.13890470857066767, 0.23386447663818086, 0.10536326374858618, 0.11908833762364728, 0.15455990923302515, 0.14873963940356458, 0.14359785030995095, 0.13576063513755798, 0.14598505864185946, 0.10249501480055706, 0.18881690315902233, 0.1080457501645599, 0.12255038613719599, 0.20969727129808494, 0.07659802013742072, 0.18269282606031212, 0.1872872273836817, 0.12788865183080944, 0.2220243119767734, 0.19831221364438534, 0.14869514107704163, 0.11594503772045885, 0.13509325523461613, 0.18145881513399736, 0.13363174508724893, 0.15694238139050348, 0.14154739890779766, 0.10514698071139199, 0.10959159542939492, 0.08219100109168462, 0.1419240536966494, 0.13689723557659558, 0.10006157787782805, 0.13802942553801195, 0.1844967792608908, 0.11429037579468318, 0.1298288820045335, 0.1606423785643918, 0.10760844113039118, 0.127985058086259, 0.09908497599618775, 0.13497456588915416, 0.11820553642298494, 0.11252760966973645, 0.11569834952907902, 0.157328779942223, 0.08120991409357105, 0.14871821126767568, 0.12017129308411054, 0.10497696019176926, 0.20752817126257078, 0.1898366870092494, 0.15428207628428936, 0.20334758130567415, 0.14374627305993012, 0.1965737390731062, 0.11903588686670576, 0.3389030545949936, 0.11964510274784905, 0.17284447380474635, 0.2638064356786864, 0.15212632981794222, 0.23219612187572888, 0.12361238843628339, 0.12357125564345292, 0.5103079485041755, 4.87435325554439, 16.417493718011038, 33.52415493556431, 34.10989849908011, 49.15436043058123, 58.505624771118164, 79.11921378544399, 116.98034395490373, 120.32169096810478, 130.65484346662248, 118.61326789855957, 121.56372315543038, 120.3752337864467, 129.80834443228585, 114.94158267974854, 114.1176027570452, 117.27139009748186, 121.85026686532157, 121.13725662231445, 127.67765154157365, 121.04647145952497, 121.14987455095563, 122.64918463570731, 117.74301992143903, 121.40654100690568, 123.51354054042271, 115.28967353275844, 113.78335271562848, 112.45822702135358, 117.8239803314209, 124.75304358346122, 123.67454419817243, 117.49273191179547, 95.71201229095459, 74.87196063995361, 42.09638030188424, 12.275742019925799, 4.655782903943743, 3.9783009716442654, 0.3016797634107726, 0.38604519782321794, 0.44159824401140213, 0.159482992919428, 0.1498330578740154, 0.2014891281723976, 0.2742722955133234, 0.4382925571075508, 0.1322365142405033, 0.19442367873021535, 0.16672340940151895, 0.130177838993924, 0.14454173323299202, 0.23667475155421666, 0.13559129993830407, 0.1649147200265101, 0.1423687655478716, 0.19969168890799793, 0.12613436739359582, 0.13498033343681268, 0.14802221075764724, 0.15361978539398738, 0.15585041498499258, 0.1462849032666002, 0.1471873005586011, 0.14672130984919413, 0.09350289909967355, 0.1313933530556304, 0.18590962487672055, 0.13173276984265872, 0.08743380369352442, 0.18091468433184282, 0.20588811141039642, 0.1231316328048706, 0.1505301711814744, 0.1344578071896519, 0.12293826389525618, 0.19106977512793882, 0.11019371383424316, 0.07637399501566376, 0.15001764654048852, 0.12382641195186547, 0.10909849046064274, 0.14832848789436476, 0.14027286587016924, 0.0922906148646559, 0.12203929999044963, 0.18729547836950847, 0.11078932508826256, 0.20640268522713864, 0.1508911789527961, 0.06697467687938895, 0.10519622878304549, 0.1533202257539545, 0.19463679300887243, 0.06564327582184758, 0.1059456028576408, 0.12063675453620297, 0.14557947111981256, 0.13299335220030375, 0.20728445505457266, 0.19768538299415792, 0.12753547435360296, 0.12607589124568871, 0.16300309688917228, 0.2564358354679176, 0.170351970408644, 0.11703518565211977, 0.12203548662364483], [0.026026002829894423, 0.03797047019803098, 0.03365869567330394, 0.036237613896706274, 0.018644442582236867, 0.02535620564594865, 0.02578054617957345, 0.06034018538360085, 0.08652787801942655, 0.04826208563255412, 0.07395925851804869, 0.033561515887933116, 0.012991233163380196, 0.018080778453232985, 0.058282412588596344, 0.030840173164116483, 0.10146228450217418, 0.05041059891560248, 0.02722094370983541, 0.020917679083400538, 0.0490517409385315, 0.01588071177580527, 0.06936963408121041, 0.03346259566023946, 0.04103477166167327, 0.031031255410718064, 0.0013914429250040225, 0.02786546037532389, 0.045879002793559005, 0.02706192563554006, 0.0406006517420922, 0.07205646990665368, 0.03779196799067514, 0.07968456058629922, 0.06854332092085055, 0.08462292488132205, 0.03422583559794085, 0.04982544049354536, 0.023369158252275417, 0.05980060076607125, 0.030441533840660537, 0.029986348801425526, 0.017551633096965294, 0.007187389818552349, 0.03132683883554169, 0.04160658669258867, 0.02017096147340323, 0.0307332835426288, 0.05822426892284836, 0.04833397302510483, 0.04167778876477054, 0.057523186185530255, 0.037287470418959856, 0.04093807702884078, 0.05338641941281302, 0.02434454216355724, 0.03754389898053237, 0.08782131504267454, 0.018266515540225164, 0.12257346989853041, 0.055987793752657514, 0.07572205856974636, 0.11517230847052165, 0.12753718426184996, 1.0625858392034258, 5.972863018512726, 20.06878423690796, 33.184596470424104, 57.52542849949428, 79.48319516863141, 88.91338062286377, 88.49735028403146, 87.71193286350795, 93.78285190037319, 88.05750152042934, 81.55937944139752, 82.23839214869908, 65.77176598140171, 84.79264027731759, 78.94837147848946, 80.95623411451066, 90.87654549734933, 80.87566975184849, 97.09040287562779, 84.9194587979998, 98.79268373761857, 86.56471579415458, 84.28450461796352, 80.87147998809814, 83.57143878936768, 82.85684435708183, 92.76886653900146, 93.63699531555176, 88.1346195765904, 90.9291364124843, 68.67250687735421, 93.46762602669853, 86.67303126198905, 92.23771844591413, 78.37322044372559, 86.28790651048932, 92.01803030286516, 92.55905178615025, 92.2268236705235, 72.25518567221505, 64.71388190133231, 62.591429574149, 36.031012875693186, 17.18639005933489, 4.278035836560385, 0.7377114146947861, 0.07960609479674272, 0.18392144941857883, 0.15107042076332228, 0.0743130873888731, 0.07566632370331458, 0.04212133692843573, 0.02206637610548309, 0.050796196796000004, 0.12334226364535944, 0.04735595979062574, 0.040259806638849635, 0.03910767453323517, 0.07561380509287119, 0.04795020718925765, 0.042393792487148724, 0.022735745812367116, 0.07764466040368591, 0.02861459526632513, 0.028036739577406218, 0.045967972305204184, 0.02499231749347278, 0.015249630103686025, 0.07182660938373633, 0.025649809444855367, 0.016902034204187136, 0.10962570538478238, 0.04574781144037843, 0.0432848616370133, 0.03304849252370851, 0.004370026756078005, 0.04263956465625337, 0.08088495688779013, 0.0561082405038178, 0.02518707400720034, 0.03499249874481133, 0.016443313997504965, 0.04076782241463661, 0.014996522971029793, 0.09128727191793067, 0.03171177514429603, 0.04583852139434644, 0.04224808726991926, 0.008315941135931228, 0.04809383948200515, 0.038645714321838956, 0.025597046561805264, 0.033070762043020556, 0.05198665255946772, 0.057229699433914254, 0.041460759339055846, 0.069750176875719, 0.052112408847148926, 0.01463245670311153, 0.04138133002977286, 0.007147407990747264, 0.011840861856139131, 0.036249495044882805, 0.029927082160221677, 0.0326321637923164, 0.06917172577232122, 0.02693562482350639, 0.08436407055705786, 0.047948510851711035, 0.09743270251367774, 0.028817243142319576, 0.07997529927108969, 0.08154249803296157, 0.04009742642353688, 0.01423894371172147, 0.04134227694677455, 0.04158942654196705, 0.05729561911097594, 0.04113478772342205, 0.11439621368689196, 0.04411203653684684, 0.07629020272621087, 0.040692715373422415, 0.03129563979538424, 0.05722108203917742, 0.05404854406203542, 0.040656576598329205, 0.012828481450144733, 0.058858122410518784, 0.019271814364141653, 0.07390378828027419, 0.04790210923446076, 0.051906232589057515, 0.054287649624581845, 0.0390097653227193, 0.05395505550716605, 0.03687269892543554, 0.022812135284766555, 0.0066432314509126756, 0.0301553956232965, 0.09726311625646693, 0.03324359169762049, 0.009116760887471693, 0.037564044685236046, 0.0652932467471276, 0.07606611653630223, 0.07457008931253638, 0.0198912710350539, 0.036904115096798966, 0.06428837709661041, 0.05647745515619006, 0.03813216170029981, 0.053804244313921244, 0.04947949619963765, 0.014707604456426842, 0.026592730544507504, 0.008601306671542781, 0.07142624658133302, 0.02291050589909511, 0.034736948886087964, 0.0407312799112073, 0.048329732181238275, 0.07035710609384946, 0.06964087166956492, 0.051326912960835865, 0.05101659514808229, 0.0401272853570325, 0.04581824676798923, 0.049025342533630986, 0.010084120273989226, 0.12136651894875936, 0.02030847338028252, 0.1848564978156771, 0.07158086435603243, 0.2578646945101874, 3.5467151360852376, 15.711416040148054, 36.019444125039236, 53.20321471350533, 79.32677732195172, 97.35907581874302, 103.22949763706752, 104.54909951346261, 99.37796524592808, 107.61775057656425, 99.48482159205845, 93.29408087049211, 98.38449791499546, 83.1328615461077, 110.49667412894112, 92.70798642294747, 102.60369423457554, 103.87026051112584, 97.1687160219465, 113.89779649462018, 99.63231100354875, 114.29292665209088, 104.90973881312779, 102.28574466705322, 97.30886813572475, 102.66842365264893, 98.14841897147042, 112.31042494092668, 114.19232368469238, 105.83456489018032, 115.86148248400006, 91.94816616603306, 119.85995537894112, 111.07780061449323, 107.0479427065168, 99.45322813306535, 99.52109813690186, 101.97944028036935, 103.54428577423096, 106.10984557015556, 93.8344144821167, 85.16142981392997, 83.67459869384766, 60.44399847303118, 34.26814719608852, 13.330869402204241, 3.7684688482965742, 0.6077301065836633, 0.060290265562278886, 0.17443440348974296, 0.19933023330356392, 0.17452346799629076, 0.03417288272508553, 0.043343975607837947, 0.06026558045830045, 0.1014451514929533, 0.1254071814141103, 0.058287576240088255, 0.0741940587759018, 0.07231417750673634, 0.02347129473595747, 0.03492238572133439, 0.038617653506142754, 0.052647688159985204, 0.044590671746326346, 0.04916168057492801, 0.0449971379712224, 0.020678376745698706, 0.017267438882429684, 0.061620519895638735, 0.04018410248681903, 0.001495400002957987, 0.05474976929170745, 0.028518582561186383, 0.05784421467355319, 0.06416641721235854, 0.03413236739912203, 0.018434770172461867, 0.025851576921663115, 0.03429562970995903, 0.0753510356215494, 0.035490455238946846, 0.09014928048210484, 0.009506314627027937, 0.010503750926415836, 0.05016071143160973, 0.025416155911183784, 0.04758699078645025, 0.012035875365005007, 0.03930314350873232, 0.03533287226621594, 0.058682775390999656, 0.013592621294914611, 0.02417097969113716, 0.04467403995139258, 0.0455795958239053, 0.01938061066903174, 0.12848707900515624, 0.06323451043239661, 0.0445862748394055, 0.009056042181327939, 0.029844453558325768, 0.03652297858414905, 0.08796017044889075, 0.014029839575024588, 0.05443281879914658, 0.034495828074536154, 0.07144800041403089, 0.03753301188615816, 0.020225315521072065, 0.012342345884202846, 0.04450392443686724, 0.12380712798663548, 0.10077682164098535, 0.1623490434139967, 0.1968442845557417, 0.13246641547552176, 0.19274141399988107, 0.11733104049095086, 0.1717400359255927, 0.2687231275652136, 0.13517929347498076, 0.14628243339913233, 0.20912716617541655, 0.1300182339868375, 0.15172482707670756, 0.11363389316414084, 0.1091414892247745, 0.10441870229052645, 0.2028090144906725, 0.1191700060984918, 0.15565925809953893, 0.16356138193181582, 0.10957632160612515, 0.1570798797266824, 0.1890250098492418, 0.1747248029070241, 0.15264531411230564, 0.06372932530939579, 0.11658349846090589, 0.10778652264603547, 0.17194530633943422, 0.09263537172228098, 0.21363122734640325, 0.2042426232780729, 0.09633361827582121, 0.18448396851973875, 0.21273070281105383, 0.1541220098733902, 0.11851258708962373, 0.15341576348458016, 0.20950844857309545, 0.13715661237282412, 0.09819622404341187, 0.09105017142636435, 0.0948854142001697, 0.09541837631591729, 0.11462725486074175, 0.12383215235812323, 0.12904247348862036, 0.08281905310494558, 0.13445400739354746, 0.13069972741816724, 0.127885869837233, 0.14175690338015556, 0.21017198796783174, 0.1278247202613524, 0.09720738139003515, 0.10146064244742904, 0.2911282724567822, 0.13026440649160317, 0.31222552752920557, 0.19084861342396053, 0.19730207856212342, 0.21905664407781192, 0.18614532080079826, 2.2604908858026778, 13.563942381313868, 33.7726503099714, 53.585834639413015, 85.13523510524205, 108.45395238058907, 118.12369782584054, 119.79674066816057, 116.84981509617397, 121.70661980765206, 112.56479154314313, 102.35294069562639, 101.80036435808454, 86.41986669812883, 106.49598475864956, 100.4567425591605, 102.33960710253034, 107.64056846073696, 101.21145589011056, 119.82800756181989, 105.51177937643868, 122.75383840288434, 108.62614263807023, 105.11792073931012, 104.34938744136265, 108.06962667192731, 104.90749454498291, 116.26315784454346, 117.80758258274624, 112.30258737291608, 115.66351440974644, 94.54613930838448, 117.8985345023019, 114.81953062329973, 113.65060043334961, 100.09160777500698, 111.9469438280378, 116.7333493913923, 117.9201989855085, 122.36440576825822, 105.30228424072266, 92.20462417602539, 90.47977556501115, 60.0669127873012, 31.78233882359096, 10.701321039881025, 2.674144072192056, 0.35377453374011175, 0.19546181016734668, 0.2553051789956433, 0.20151177767132009, 0.2597219262804304, 0.12831346903528484, 0.20959927727069172, 0.1782209410199097, 0.23661436193755694, 0.35168567725590294, 0.1275345922580787, 0.12569566736263887, 0.17474367975124291, 0.07717428635805845, 0.1244381655539785, 0.12783394833760603, 0.22821341987167085, 0.09690584721309797, 0.09218256494828633, 0.1370355345840965, 0.15385430066713265, 0.05582620403064149, 0.19380580474223408, 0.1633098218590021, 0.08025475391852004, 0.26397454951490673, 0.1541764690939869, 0.15431030334106513, 0.12554928021771566, 0.12677295027034624, 0.1465306957917554, 0.1687667497566768, 0.11710906454495021, 0.14477912549461636, 0.15332375413605145, 0.24405466126544134, 0.08597768111420528, 0.1423150934278965, 0.19629705963390215, 0.08661703073552676, 0.18490593587713583, 0.07118837934519563, 0.14007321372628212, 0.14536632969975471, 0.2240608941231455, 0.11720167100429535, 0.13727808371186256, 0.14802126080862113, 0.16082531160541944, 0.13053936245185987, 0.15374967056725705, 0.14791255949863366, 0.07984433522714035, 0.08470660181982176, 0.1647129508533648, 0.1447501384786197, 0.2027136938912528, 0.15852473862469196, 0.06337806808629207, 0.18712794807340416, 0.16617731084781034, 0.14279176427849702, 0.11195013565676552, 0.1627061971064125, 0.15775971753256662], [0.05547368812507816, 0.04651625234899776, 0.0602882503132735, 0.06875814510775463, 0.024582366991255964, 0.03155883335109268, 0.00694491617780711, 0.07218408198761088, 0.03048511953758342, 0.11276110035500356, 0.09858225618622132, 0.04852811207196542, 0.03864501203809466, 0.024040385448772992, 0.04943586979061365, 0.05909022209899766, 0.003816267117924456, 0.0623397466593555, 0.06963914140526738, 0.08436494586723191, 0.07219181728682347, 0.03217286004551819, 0.06414372700133494, 0.022790177891563092, 0.052271308177816014, 0.0408978534729353, 0.024016132910868952, 0.0629135158711246, 0.0515339814924768, 0.05305777097653065, 0.04136367454858763, 0.028854925584580218, 0.047522669059357474, 0.06905685657901423, 0.010106987752286451, 0.03456642285787633, 0.04639379034883209, 0.0324252784651305, 0.042654146373804123, 0.08503583379622016, 0.023387819661625793, 0.04232081604589309, 0.033770270579095395, 0.026167540145771842, 0.11431162751146726, 0.0300862155854702, 0.08056097677243607, 0.05428318825683423, 0.07088679767080716, 0.032158481888473034, 0.02234004793821701, 0.020318235802863325, 0.006484774864345256, 0.06622076340551887, 0.0400728668485369, 0.05853497689323766, 0.02348489427406873, 0.10609739114131246, 0.033704476431012154, 0.06518841308674642, 0.07028509995767049, 2.689366055386407, 16.230229343686783, 26.206098522458756, 45.62877498354231, 74.32030841282436, 79.7126385825021, 87.39503942217145, 81.72334303174699, 79.87972886221749, 78.9478781563895, 68.20622716631208, 69.78280121939522, 75.5451785496303, 84.37784671783447, 81.90568460736955, 70.12921060834611, 80.84035205841064, 47.64126859392439, 77.9045227595738, 64.04378373282296, 98.71733747209821, 72.58598940713065, 61.68999808175223, 64.39226368495396, 71.68768460409981, 58.08268097468785, 72.18211841583252, 66.5215391431536, 68.2169690813337, 80.25567504337856, 60.25340243748256, 69.76040717533657, 74.49008764539445, 53.76397602898734, 41.254036290305, 52.8851991380964, 62.96037891932896, 68.06789548056466, 61.751051902770996, 78.00644588470459, 80.26904337746757, 85.52328504834855, 77.63149329594204, 90.12008122035435, 79.77362986973354, 84.49291583469936, 89.7264518737793, 92.62624086652482, 77.01689733777727, 59.2862548828125, 41.845553806849885, 17.148597070149012, 3.2677395343780518, 0.25540948339870995, 0.29724884831479614, 0.06731128453144006, 0.03636203007772565, 0.05746458790131977, 0.11322337269250836, 0.047089943529239724, 0.03982701325523002, 0.06550461040543658, 0.04459146563229816, 0.07363453201417412, 0.08584815556449549, 0.006656965423774506, 0.03498517735196011, 0.09579100739210844, 0.07241872618240969, 0.04217167744146926, 0.039474544847118, 0.05470661446452141, 0.013091547780537179, 0.016242231841066053, 0.04790726610060249, 0.022126256820878813, 0.05603959311598113, 0.030292602189417397, 0.05186465535578983, 0.06034639397902148, 0.01613180196311857, 0.06139514448919466, 0.03838803047048194, 0.025924568629956672, 0.0412631801196507, 0.013699001166969538, 0.0758258065740977, 0.03513703348913363, 0.02742936591883855, 0.02400179037691227, 0.008749193378857203, 0.004548588335247976, 0.022114341745951345, 0.020696227305701802, 0.06320622909281935, 0.06457457638212613, 0.02586312049866787, 0.10214115200298172, 0.025324838668374077, 0.04261729513694133, 0.045166727621108294, 0.02180310112557241, 0.020943129235612493, 0.06949855573475361, 0.012916455211650048, 0.02724806814720588, 0.034495268283145766, 0.08385698098157134, 0.05922910464661462, 0.06546468540493931, 0.048457432471747906, 0.06956117094627448, 0.0575473623882447, 0.03699307443041887, 0.05827583758426564, 0.05654921701976231, 0.08604370257151978, 0.02555696040924106, 0.030964104192597524, 0.028098737322060124, 0.03138472465798259, 0.06271473903741155, 0.0876469858256834, 0.07273512027625527, 0.024370864233268157, 0.020438818261027336, 0.07855478620954923, 0.014420563787488001, 0.048611415816204886, 0.05374361721000501, 0.055091160615640025, 0.042674879011298926, 0.011767102555105729, 0.03927242283576301, 0.038200191621269496, 0.03503399794655187, 0.06243210206074374, 0.03769165676619325, 0.0595361553132534, 0.04069214879668184, 0.04015440640172788, 0.07095779278980834, 0.07516224682331085, 0.010421817822914039, 0.06300957607371466, 0.03301479308200734, 0.039404645562171936, 0.03349707880988717, 0.0821531049108931, 0.054770172839718204, 0.025631636580718414, 0.020095318389524306, 0.0235987439685102, 0.0263428956469787, 0.09017818607389927, 0.03276497684419155, 0.03670645784586668, 0.023136366458077515, 0.06292688301099197, 0.10495292648140873, 0.02955154695415071, 0.018951091216877103, 0.008693107370553272, 0.06814247635858399, 0.032038489755775244, 0.034149625937321355, 0.03747148572334221, 0.02822374043587063, 0.04984474142215081, 0.056763749436608384, 0.026496074927438582, 0.07841046859643289, 0.12035863660275936, 0.0139810232212767, 0.18000425318522112, 0.13766947628131934, 8.554660320281982, 30.20003250667027, 43.704037121364046, 67.40608651297433, 93.20559556143624, 93.11396271841866, 98.06550611768449, 89.73714515141079, 92.56659752982003, 95.14856897081647, 84.91075965336391, 88.65651266915458, 95.23454598018101, 107.76308604649135, 104.58734239850725, 97.83279010227749, 95.44331155504499, 49.60143532071795, 99.58206857953752, 89.63124070848737, 125.37018258231026, 93.32654285430908, 88.62384918757847, 96.98529052734375, 101.43361759185791, 83.7887853894915, 101.75846672058105, 91.78339658464704, 92.90646171569824, 106.42422376360211, 82.45808029174805, 99.55023888179234, 101.39936992100307, 77.34784003666469, 58.91982078552246, 81.70079612731934, 86.3750091280256, 98.00977461678642, 86.96170112064907, 96.25031008039201, 97.94581644875663, 108.55186639513288, 94.38827623639787, 101.316714150565, 88.40972655160087, 94.43785163334438, 99.75014550345284, 106.13422679901123, 99.20232173374721, 82.16921588352749, 61.22241905757359, 31.285792759486608, 9.025009070123945, 0.8561078501599175, 0.19016660430601665, 0.17737252797399247, 0.022464713480855738, 0.03977577707597187, 0.035898485487060885, 0.07500059264046804, 0.08726194434400115, 0.026049430947750807, 0.05981727915682963, 0.09964723725404058, 0.06957307245050158, 0.06347201125962393, 0.09909511330936636, 0.019466940679454377, 0.07163504537727151, 0.04212950649006026, 0.09895587113818952, 0.023623944759102802, 0.03896989460502352, 0.061962535471788475, 0.06292820615427834, 0.0099125136787604, 0.04171129143131631, 0.008219902985729277, 0.047927374485880136, 0.13015339816255228, 0.07593788020312786, 0.06806799356958695, 0.050687129077102454, 0.061869372613728046, 0.01542622223496437, 0.06472918737147536, 0.06386009257818971, 0.04150529498500483, 0.024452140854139413, 0.01725177320518664, 0.05276377532365067, 0.02092607595425631, 0.02031181855792446, 0.05436673288100532, 0.058134899075542174, 0.07871231489947864, 0.043767666444182396, 0.09624735611890044, 0.011279643845877476, 0.03772467088752559, 0.07350655352430684, 0.024859470514846698, 0.0521792411538107, 0.02148862898216716, 0.09420489107391664, 0.08375442719885282, 0.03272214432113937, 0.013574195676483214, 0.01468824754868235, 0.06824078251208578, 0.03392327004777534, 0.02998346502759627, 0.06307972302394253, 0.0362029611133039, 0.1264032708214862, 0.13054659563515866, 0.1380345281213522, 0.10781791846134833, 0.10414107290229627, 0.14585735835134983, 0.08781301655939647, 0.13594066404870578, 0.15883248139704975, 0.14346170904380934, 0.21139257747147763, 0.1938880838985954, 0.13807496880846365, 0.1119551703866039, 0.17603540686624392, 0.17299638422472136, 0.2951755167118141, 0.11246981884219817, 0.11345865471022469, 0.16359988200877393, 0.12888753680246218, 0.1795730306101697, 0.1254690909492118, 0.1593838318118027, 0.15751349074499948, 0.14689364417323045, 0.12965947895177773, 0.2265290788241795, 0.16223887646836893, 0.08715417941233941, 0.14869599603116512, 0.1509300997214658, 0.18624031570340904, 0.1039544011333159, 0.2087662669696978, 0.1425733302852937, 0.1454411314002105, 0.10215202891933066, 0.11001967638731003, 0.11431816858904702, 0.15312108929668153, 0.13998644266809734, 0.11438182874449662, 0.151341848341482, 0.1947680895349809, 0.22584625546421322, 0.0879203879407474, 0.13817064224609307, 0.16128727181681565, 0.1325318669634206, 0.15928396502775805, 0.1091722132904189, 0.12716247008315154, 0.07190623546817473, 0.2305092295365674, 0.10943258753312485, 0.19464261483933243, 0.19323844090104103, 0.38131067901849747, 0.10011392685451678, 0.3074486952807222, 0.22920397243329457, 5.372361046927316, 26.010077680860245, 42.83256278719221, 68.76308359418596, 102.52690274374825, 105.5280659539359, 115.37714440482003, 99.73223999568394, 98.87270614079067, 97.0354356765747, 88.03753239767892, 89.21678066253662, 96.74019977024624, 103.82493046351841, 103.53252247401646, 91.30708367483956, 99.24580356052944, 63.51360143933977, 99.8575438090733, 82.20650686536516, 119.97815813337053, 92.49384989057268, 79.61836542401994, 84.59897313799176, 93.92781216757638, 76.65242958068848, 90.9302203314645, 87.1325295312064, 87.18281364440918, 98.56009973798479, 79.82770769936698, 91.99073083060128, 92.04472528185163, 70.54248251233781, 55.18799890790667, 66.34471443721226, 81.40461526598249, 91.30097620827812, 81.52882126399449, 100.64703287397111, 101.52261011941093, 107.48544992719377, 96.02246475219727, 109.9082589830671, 102.96841212681362, 108.28532654898507, 115.38896329062325, 122.12091309683663, 111.71103164127895, 87.82727296011788, 61.26230866568429, 27.165045465741837, 6.412458607128688, 0.6064856190766607, 0.39059176242777277, 0.17713143091116632, 0.08957209145384175, 0.15176635341984884, 0.1785626241139003, 0.18753857032528945, 0.30241887803588596, 0.11245618028832333, 0.17685025957013878, 0.27716654592326706, 0.22053757389741285, 0.2319649857069765, 0.23636343968766077, 0.18550238172922814, 0.13870018454534666, 0.17241409261311802, 0.15260955531682285, 0.21704393279339584, 0.1116916545267616, 0.1321916902171714, 0.11918779728668076, 0.14834249285714968, 0.1279418354055711, 0.08961372636258602, 0.10017589067241975, 0.17793142369815282, 0.18124874069222383, 0.15568264041628155, 0.17622565451477254, 0.1752843771662031, 0.13100585527718067, 0.1534189118870667, 0.15422961195664747, 0.0914140697568655, 0.15884276798793248, 0.07614625830735479, 0.172573059797287, 0.09531914056943995, 0.07509893950607095, 0.06802553763347012, 0.14649386491094316, 0.19929850500609192, 0.15169536508619785, 0.2643508378948484, 0.07054580668253557, 0.09375412669032812, 0.20852355499352726, 0.07937844629798617, 0.12428970209189824, 0.24267617666295596, 0.17690566873976163, 0.23459186617817196, 0.12064782822770731, 0.12988046423665114, 0.1262744984456471, 0.21335191519132682, 0.16110973991453648, 0.14090239708977087, 0.1391917967370578, 0.11723003376807485, 0.21258841401764325], [0.031142908348036662, 0.037025396446032185, 0.09571460434900862, 0.07658794389239379, 0.07485725211777858, 0.04859379765444568, 0.027608806200857674, 0.05361065148775067, 0.029962216703487293, 0.09011791859354291, 0.06418791320174932, 0.09977075776883534, 0.029363056711320366, 0.043916984860386164, 0.03366961669442909, 0.03018438603196825, 0.0353702900798193, 0.019346604190234627, 0.016904716113848344, 0.03355648794344493, 0.048744177977953634, 0.0098627253235983, 0.01930687596489276, 0.033171609310167174, 0.0206273237708956, 0.044624564570507834, 0.07778723418180432, 0.03879895806312561, 0.06400336524737732, 0.06326144827263695, 0.044456739111670425, 0.03313255961984396, 0.03520650868969304, 0.00807659893429705, 0.03308115380683115, 0.01980590963337038, 0.047591401264071465, 0.03616068498896701, 0.0335661434967603, 0.02252822944761387, 0.014561198651790619, 0.041068566098277054, 0.019498947176284025, 0.03730837269020932, 0.00698877074423113, 0.010748378915845283, 0.04439744532906583, 0.09576940962246486, 0.016244732242609774, 0.07819261135799543, 0.01046711257991514, 0.047623594358031235, 0.007780093550016838, 0.02960156516305038, 0.01629559862028275, 0.038695532362908125, 0.022200383378991058, 0.322446164808103, 0.29895389825105667, 7.690010854176112, 25.580269064222062, 60.98848710741316, 80.57257543291364, 82.9361024584089, 85.24454416547502, 70.03684820447648, 73.72236728668213, 66.02417319161552, 75.69080584389823, 69.42502457754952, 72.02597154889787, 59.4444306237357, 52.85845899581909, 56.166864599500386, 48.00948143005371, 51.865043776375906, 25.353295734950475, 54.008111408778596, 106.30799429757255, 58.61510753631592, 30.785963671548025, 35.12632615225655, 36.81437362943377, 32.04377521787371, 21.26244306564331, 30.240464074271067, 31.660998957497732, 30.310929230281285, 29.808591842651367, 35.92356940678188, 31.31202915736607, 34.81987237930298, 27.35849721091134, 33.74663972854614, 37.13506426130022, 37.650985377175466, 26.595399141311646, 43.306961468287874, 20.587105955396378, 42.20481388909476, 45.036705085209434, 55.32677527836391, 60.683370862688335, 71.18914440699986, 63.348616463797434, 76.94102300916398, 78.03113283429826, 79.75297287532261, 74.00395693097795, 81.07456193651471, 83.72929491315568, 79.2832954951695, 77.58742782047817, 70.85669394901821, 27.997601202556066, 7.348398327827454, 0.9689646171672004, 0.1408130611692156, 0.14476042506950243, 0.07118527844016041, 0.12342404068580695, 0.03266019407393677, 0.0748726005799004, 0.02465819158325238, 0.04966589994728565, 0.020450036141223142, 0.04300461310361113, 0.0378085581718811, 0.00894408899226359, 0.03683097580713885, 0.029055483572717224, 0.04312347208282777, 0.013834985521888095, 0.01147313743630158, 0.021478143919791495, 0.025306796422228217, 0.051202394999563694, 0.010367127052242202, 0.06385211979172059, 0.021685431278975945, 0.024903556631345834, 0.037265994785619636, 0.038988286296703985, 0.05988499695169074, 0.05551196428548012, 0.017565217368038635, 0.026185343208323632, 0.02638414379076234, 0.06014226350401129, 0.04178145873759474, 0.009158915723674, 0.08432070538401604, 0.02529477617437286, 0.014374801689492804, 0.017877429989831786, 0.04238282736124737, 0.0699141448629754, 0.04825166333466768, 0.05643798138148018, 0.033397934665637355, 0.11932710052600928, 0.03903141398248928, 0.021308542395542775, 0.04438205954751798, 0.03731149055862001, 0.04247015142547233, 0.038310775865933726, 0.040417637276862345, 0.045242085720279386, 0.01660746518921639, 0.10927288074578557, 0.05997456357415233, 0.06255463191441127, 0.01605073908077819, 0.06378380488604307, 0.06125911857400622, 0.03750602654846651, 0.06865663626896483, 0.0992862159120185, 0.06935725081712008, 0.0822020001443369, 0.11339076049625874, 0.014246555178293159, 0.029354327358305454, 0.039571493930582485, 0.059280388323324065, 0.0507513659873179, 0.05553556712610381, 0.031138681074870483, 0.025445171764918735, 0.07312012104583637, 0.029530234169214964, 0.020980423216574957, 0.07274267915636301, 0.07124626516763653, 0.02697848279162177, 0.02048538442301963, 0.018791189350719963, 0.04308050385277186, 0.05341060579355274, 0.023414601438811848, 0.05460838294987168, 0.0044638214998745495, 0.07466133870184422, 0.03549993098048227, 0.031247738615742753, 0.05043264112568327, 0.057378834645662985, 0.022196344399292554, 0.03456238218184028, 0.026267734322963015, 0.05640229383217437, 0.02828933441612337, 0.010856199826646065, 0.018193454282092195, 0.022752439470163414, 0.05792711129678147, 0.003380096114207325, 0.03777895029634237, 0.02090447988095028, 0.05543253497619714, 0.02466732127192829, 0.0272540324700198, 0.06617057895553963, 0.011855781144861664, 0.04118730294119034, 0.060052995436957905, 0.05077246503372278, 0.014653623603018267, 0.03865819936618209, 0.08702743585620608, 0.06866298735673938, 0.06291707817997251, 0.2033750076911279, 1.4264023112399238, 18.899822780064174, 47.16255508150373, 80.02704456874302, 91.73505796704973, 95.0527811050415, 92.00436319623674, 78.74532427106584, 90.10640021732875, 85.36235782078334, 96.15691934313092, 89.97724710191999, 97.88616616385323, 87.95074939727783, 80.75613294328961, 90.21368040357316, 68.76640483311245, 77.79962580544608, 46.23397350311279, 80.03463894980294, 96.39728532518659, 61.37687751225063, 41.049040113176616, 48.077726636614116, 61.69684900556292, 47.08204630443028, 37.416282176971436, 43.70479447501046, 47.29226057870047, 38.80989279065813, 39.33948448726109, 44.19679989133562, 45.64017350333077, 49.041559900556294, 39.05292688097273, 49.69801875523159, 48.221505710056846, 51.737384523664204, 42.73521505083357, 62.61724213191441, 40.720567498888286, 66.2330846786499, 73.83130809238979, 87.86295195988247, 88.2654333114624, 98.40639168875558, 93.6296580178397, 100.45200388772147, 101.64810848236084, 97.67366940634591, 89.79434967041016, 87.82882240840367, 92.42827974046979, 89.10776342664445, 91.52329771859306, 88.37629876817975, 47.62589223044259, 18.025456258228846, 4.660911977291107, 0.15529056931180613, 0.19141745647149427, 0.009543585707433522, 0.05880758512232985, 0.030358976484941583, 0.06943203216152531, 0.026831025257706642, 0.04531208678547825, 0.05630592828882592, 0.11538255933140006, 0.05755011045507022, 0.009471920535101421, 0.042762114865971465, 0.06076459546706506, 0.014220686030707188, 0.05126152254108872, 0.10496432586972203, 0.07533165666141681, 0.01914412255531975, 0.07115752635789768, 0.011673248439495052, 0.12525699447308267, 0.04269888558025871, 0.019930422505629913, 0.023116868754316653, 0.08790459843086344, 0.07738136846039977, 0.024836770125797818, 0.0152644527011684, 0.02275681432469615, 0.08567332423159055, 0.06732969997184617, 0.038027348395969184, 0.015255529965673174, 0.057830589690378735, 0.046865056668009074, 0.04295002156868577, 0.05865137957568679, 0.04179832372548325, 0.006907333819461721, 0.10244771412440709, 0.027554022979789546, 0.03032380122957485, 0.048991493814225705, 0.02117594817121114, 0.019110021081620028, 0.00510439502873591, 0.028750743317816938, 0.12151392389621053, 0.01679542108571955, 0.03985733698521342, 0.03063466526301844, 0.04844872008210846, 0.06131763543401446, 0.02214967136803482, 0.10271988130573716, 0.04124904623521226, 0.06688181936208691, 0.043408891053072045, 0.11430869624018669, 0.1744329378541027, 0.13251126664025442, 0.09883859993091651, 0.25640703844172613, 0.1812801297221865, 0.12011133772986275, 0.11204363778233528, 0.11893943989915506, 0.18166931026748248, 0.16374535991677217, 0.22709868183093412, 0.1132797793086086, 0.15732274098055704, 0.1284338411475931, 0.15668767291520322, 0.09548792615532875, 0.2513544224202633, 0.11359453134770904, 0.15692537730293615, 0.1206922179886273, 0.09668965917080641, 0.10771041137299367, 0.1254349606377738, 0.11826215338494096, 0.27479506603309084, 0.13903775571712426, 0.23615255100386484, 0.13185801383640083, 0.1007509898128254, 0.18273006406213554, 0.17993961593934468, 0.12622990512422153, 0.15191503401313508, 0.1434601212718657, 0.13693528782044137, 0.13613723564360822, 0.10268499782042843, 0.08790168751563344, 0.10711910881634269, 0.33058616944721764, 0.05084669676476291, 0.19738742469676904, 0.1233701514346259, 0.12411427364817687, 0.07444601918437652, 0.11875419983906405, 0.1890662376369749, 0.14495141910655157, 0.21860438691718237, 0.12621566945953028, 0.2697868804846491, 0.11756128099347864, 0.16370042732783727, 0.14906085788139276, 0.19628378748893738, 0.20235317466514452, 0.4117848809276308, 0.6793496949332101, 15.377725328717913, 44.53479848589216, 88.80425916399274, 106.06342465536935, 108.39004284994942, 106.54255853380475, 89.70025716509137, 92.31807436261857, 85.91342639923096, 95.68658188411167, 90.07067952837262, 92.29950182778495, 79.95071860722133, 72.78768866402763, 77.23212473733085, 64.52901812962124, 67.15449919019426, 35.93787227358137, 65.19990144457135, 117.58888108389718, 73.02883979252407, 42.22399091720581, 46.170553820473806, 53.39939710072109, 46.748890604291645, 31.180482387542725, 43.42636973517281, 44.41241291591099, 44.374104022979736, 41.87173114504133, 51.78963845116751, 43.31550775255476, 49.274873461042134, 39.21486854553223, 45.44769103186471, 53.83482681001936, 54.51903329576765, 39.337921142578125, 62.644055230276926, 32.861501761845176, 54.906388419015066, 60.776976994105745, 73.56851332528251, 80.74835096086774, 93.5073766708374, 87.77755165100098, 101.82113252367292, 101.39720903124127, 98.21981866019112, 93.53305721282959, 99.25755296434674, 101.1824541091919, 104.2000845500401, 103.17272390638078, 94.57340403965541, 48.40798841203962, 14.823332037244525, 2.6215568482875824, 0.2757504161979471, 0.3620069548487663, 0.17267650924623013, 0.3267239209796701, 0.19369722556854996, 0.22056236756699427, 0.1350295272256647, 0.18450634660465376, 0.1468885415898902, 0.21983450305249008, 0.25095291967902866, 0.08401107628430639, 0.10972678674651043, 0.18232968768903188, 0.18973737662392004, 0.17039675371987478, 0.18557438786540711, 0.17889492985393318, 0.08411144518426486, 0.1316517527614321, 0.1325487217732838, 0.14812389601554188, 0.08210792804935149, 0.2577115627271788, 0.13390116420175346, 0.20095760455088957, 0.18739835784903594, 0.12452002401862826, 0.07540424633771181, 0.09398747488324131, 0.14076069183647633, 0.14387945591339044, 0.07789200677403382, 0.10964762206588473, 0.10323789529502392, 0.14639973853315624, 0.07565991833273854, 0.14688658740903648, 0.10725285485386848, 0.19268729404679366, 0.23664313182234764, 0.14625491201877594, 0.14084848069718905, 0.1699151024222374, 0.15900237299501896, 0.11988221002476555, 0.1069383267313242, 0.11052300009344306, 0.17804757532264504, 0.08971967282039778, 0.14817618392407894, 0.11902736446687154, 0.14399389762963566, 0.15371672090675148, 0.1500523468213422, 0.152170203892248, 0.15734403340944222, 0.19151223424289907, 0.17309492108012947], [0.05493648855813912, 0.09228636723543916, 0.12124204848493848, 0.057917143617357524, 0.060920834940459044, 0.009249156640310372, 0.07711877540818282, 0.055315691245985885, 0.06456196241612945, 0.03102415454174791, 0.0681097913267357, 0.02498591721190938, 0.09037458124969687, 0.011086835575822209, 0.02131297662188964, 0.012195242884834962, 0.05889165561114039, 0.042031227477959225, 0.03601109176608069, 0.03190333575808576, 0.004362013681592154, 0.027144910468320762, 0.03347966420863356, 0.043954908182578425, 0.02606631120267723, 0.016172086587175727, 0.01430606609210372, 0.019536303921735713, 0.08603961100535733, 0.06530467327684164, 0.03911457184169974, 0.03647568130067416, 0.04736940496202026, 0.033583907543548515, 0.041709103155881166, 0.027541546417134147, 0.02245834712604327, 0.016888007189014127, 0.03186554814289723, 0.05703224574348756, 0.019519343938944594, 0.024224561905222278, 0.019124294065737298, 0.0032299388590867496, 0.04079202236607671, 0.015491030810933028, 0.02456034004821309, 0.03847997535818389, 0.02669953365278031, 0.11418136235858713, 0.025082204723730683, 0.0409229049858238, 0.05567095182569964, 0.05017862475610205, 0.07140372600406408, 0.05323444113933614, 2.434210832629885, 20.944241625922068, 45.30391543252127, 66.3629743031093, 74.81427669525146, 70.88839857918876, 67.516708782741, 60.33143765585763, 64.35986423492432, 79.48538385118756, 63.405668122427805, 56.0296550478254, 58.03193480627877, 54.772837093898225, 36.4629476411002, 25.808517387935094, 34.746113777160645, 25.494338955198014, 29.646295819963726, 18.38075934137617, 35.12726763316563, 21.146597487585886, 73.37787560054234, 131.32833235604423, 50.94097852706909, 47.22866371699742, 28.17863651684352, 46.88776772362845, 49.585947786058696, 40.702363218579976, 41.723710196358816, 57.33751446860177, 32.01876517704555, 38.22776576450893, 28.316233430589946, 34.61199269975935, 45.30659048897879, 31.107561043330602, 44.23361144747053, 30.90274551936558, 49.772715364183696, 41.47037887573242, 37.24790300641741, 36.86461952754429, 25.40370317867824, 15.28544282913208, 33.769141469682964, 22.131707872663224, 24.652434417179652, 48.285418714795796, 48.86953639984131, 52.97880179541451, 57.68791559764317, 71.05292497362409, 68.93789332253593, 77.50532790592739, 73.5442293712071, 71.6879277910505, 78.96379647936139, 64.88930307115827, 57.2401111466544, 24.37287712097168, 0.8514698190348489, 0.15475076756307057, 0.3651875470365797, 0.05834573347653661, 0.09067190172416822, 0.0459130923928959, 0.03452775653983865, 0.056630458017545085, 0.06491891254803964, 0.06847060910825219, 0.05221160388152514, 0.06923013406672648, 0.049656872038862536, 0.05199653542201434, 0.062185305303760936, 0.03611232579818793, 0.0032470135567044573, 0.03777368825727275, 0.007085136287579579, 0.030799271073192358, 0.027759435885984982, 0.056377513733293326, 0.01940442555184875, 0.028712029502327954, 0.03608320646786264, 0.020308139201785837, 0.027068816158654432, 0.07964938533093248, 0.033269806898065975, 0.03779044807223337, 0.008800285369423884, 0.012778636267674821, 0.031828048905091624, 0.03412297308178885, 0.02396890178455838, 0.005613266606815159, 0.04288929946986692, 0.0289228096205209, 0.024738457186945846, 0.04729032849094697, 0.06014156461294208, 0.0630906338670424, 0.016720807678731422, 0.04906803934967943, 0.02386882295832038, 0.06232133121894939, 0.035933579318225384, 0.08633041754364967, 0.10954631000225033, 0.04656612128019333, 0.021327495574951172, 0.045778019819408655, 0.05123294943145343, 0.034852133598178625, 0.07053589328591313, 0.08263417266841445, 0.037730910017022064, 0.036351543319012435, 0.07128063296633107, 0.07698016427457333, 0.1717681544167655, 0.09159017673560552, 0.05710514754589115, 0.05998074502817222, 0.05052135279402137, 0.04396276901076947, 0.10181489879531519, 0.014332556099231755, 0.04352572121258293, 0.03738670955811228, 0.06323912447052342, 0.026166951516643167, 0.019449851775009717, 0.06444819244955267, 0.03212148815925632, 0.056841146533510516, 0.02237868881119149, 0.05616783962718078, 0.017593900739614452, 0.0342351484910718, 0.044476175747279606, 0.039807213603385856, 0.054038131942174265, 0.012299609204222049, 0.021887804348287836, 0.014867580961436033, 0.10074447587664638, 0.036885533415313275, 0.041424233799002, 0.024645362182387283, 0.05090653337538242, 0.005935847243693258, 0.033196084068289826, 0.06148678742881332, 0.052760888157146316, 0.01910125949819173, 0.028446790163538287, 0.02999613666906953, 0.04202729876020125, 0.02231547818519175, 0.047360600970153294, 0.0394294154830277, 0.005223738312322114, 0.012488348808671747, 0.032421325998646874, 0.005809807243557381, 0.016754020271556716, 0.08193230283047472, 0.022455923059689145, 0.0234081485707845, 0.10113170902643885, 0.0620785446039268, 0.13813666121235915, 0.14754288004977362, 8.043974672045026, 38.82510587147304, 66.65037958962577, 81.95985276358468, 84.08072090148926, 77.66824231828961, 82.48146098000663, 73.99255493709019, 83.87054484231132, 104.63524327959333, 86.48165702819824, 94.13135964529855, 84.580963407244, 83.7935379573277, 56.071410247257774, 43.17696762084961, 54.59901053564889, 31.98739058630807, 29.32931900024414, 22.866895028523036, 34.593948228018625, 29.53004550933838, 92.84086377280099, 134.33408137730189, 48.071379457201274, 52.75816522325788, 33.849938596997944, 42.065043926239014, 46.15374265398298, 39.6808112689427, 38.91165263312203, 57.033273696899414, 30.366657257080078, 43.75646127973284, 27.506844724927628, 34.5178758757455, 35.99737317221505, 18.846410240445817, 35.198841026851106, 23.16379155431475, 31.495722157614573, 28.450255496161326, 18.25492572784424, 27.544078384126934, 23.335377318518503, 22.219467094966344, 47.7947438785008, 34.66743237631661, 45.77654232297625, 67.91677910940987, 77.23180512019566, 83.62758023398263, 86.95302976880754, 100.77612345559257, 94.8360459463937, 101.30035809108189, 92.34598527635846, 82.13404410226005, 90.54542214529855, 81.40369115556989, 78.99594579424176, 43.97648293631417, 6.790487510817392, 0.1757815262036664, 0.36270370174731525, 0.15595603574599537, 0.03364523353853396, 0.013136085970992488, 0.0382448222621211, 0.019921521822522794, 0.027876506925427487, 0.06749193769480501, 0.08463270257094077, 0.04294205896024193, 0.07118957356682845, 0.030364587969545807, 0.10568870949958052, 0.040012674007032595, 0.013812261384113558, 0.010497046152262815, 0.0158956310645278, 0.007157338350745184, 0.02570660112957869, 0.04247863989855562, 0.05122298175202949, 0.06488852096455437, 0.017503865927989994, 0.01998232025653124, 0.07207215763628483, 0.019486764080024192, 0.012864337785036435, 0.07222909600074802, 0.02603405195155314, 0.09133542076285396, 0.006458956606885684, 0.03627144904541118, 0.01593544241040945, 0.030170479456761053, 0.021326866233721375, 0.0468552552296647, 0.03789758196632777, 0.01864825255636658, 0.04316466933648501, 0.10360116258795772, 0.03309306548908353, 0.02687359315210155, 0.056318884915007014, 0.04016064213854926, 0.008445790686112429, 0.040944580786994526, 0.10153730333383594, 0.026056745555251837, 0.021281874272972345, 0.06702852541846888, 0.07621078020227806, 0.03429049998521805, 0.049060022458434105, 0.025753208003672104, 0.05169004454676594, 0.023985525892515267, 0.11885359164859567, 0.17702519946864673, 0.1641407829842397, 0.14042054223162787, 0.08697919201638017, 0.08998637100947754, 0.19776488015694277, 0.1296377522604806, 0.14638447149523667, 0.09759413277996437, 0.25771085705075947, 0.11724479869008064, 0.18379080428608827, 0.11848792912704603, 0.10953013372740575, 0.10072268133184739, 0.09349014264132295, 0.09899778424629144, 0.11047813535801002, 0.08937676836337362, 0.13460230800722325, 0.11741300752120358, 0.13065735969160283, 0.06465083693287202, 0.14983959895159515, 0.11532948432224137, 0.12164599395224027, 0.1909458746335336, 0.19950267619320325, 0.10516446655882256, 0.17274497342961176, 0.12569644089256013, 0.12064047290810517, 0.11642457198883806, 0.11777356745941298, 0.16031087349568093, 0.14848997922880308, 0.18923929120813096, 0.15487891568669251, 0.10478605436427252, 0.10227519659591572, 0.12522263345973833, 0.11568707227706909, 0.08780526090413332, 0.08069577453924076, 0.10899183832641159, 0.14212912054998533, 0.22769700043967792, 0.124574374673622, 0.24406937190464564, 0.08642024200941835, 0.20137262370969566, 0.16333183353500708, 0.15996439994445869, 0.2532375199454171, 0.08372337065104928, 5.02793276309967, 33.11041750226702, 67.3925861631121, 94.28105163574219, 99.19360869271415, 91.06903839111328, 85.81189932141984, 77.95026969909668, 82.63689218248639, 100.15958895002092, 81.5045164653233, 75.37660135541643, 74.30384118216378, 70.85649245125907, 46.97178534099034, 34.526220662253245, 45.27863788604736, 33.60939196177891, 44.086921078818186, 25.865442241941178, 48.3664208139692, 27.991462469100952, 79.32321984427315, 136.3891361781529, 66.03051689692906, 68.03944260733468, 42.59371846062796, 61.912632261003765, 69.36703491210938, 58.47425365447998, 55.28709759031023, 79.68779877253941, 45.53053092956543, 56.138172013419016, 40.93771260125296, 48.315817083631245, 62.88016196659633, 44.71789394106184, 61.02952316829136, 44.702399458204, 64.07244505201066, 53.305158683231895, 51.72376605442592, 51.53855834688459, 33.934025696345735, 23.7599105153765, 47.808122634887695, 32.62682288033621, 37.19996738433838, 63.079922676086426, 65.0079574584961, 73.01069109780448, 79.45303998674665, 92.88870212009975, 89.35227748325893, 95.24648993355888, 91.73147964477539, 90.86232948303223, 104.89103426252092, 90.99187169756208, 84.37647792271206, 41.04670204435076, 5.610252167497363, 0.16763253776090487, 0.7538980032716478, 0.1748828879956688, 0.19080213377518312, 0.21924372975315365, 0.14115857120071137, 0.17184047267905303, 0.16062823789460318, 0.1465839607907193, 0.16324876727802412, 0.14739453872399672, 0.16644158666687353, 0.21230857260525227, 0.19086682530386107, 0.23976998403668404, 0.11789592089397566, 0.0936997149671827, 0.14968501510364668, 0.07502943037876061, 0.08952449900763375, 0.06083156687340566, 0.10423757415264845, 0.14536755106278829, 0.13262994241501602, 0.09180455987474748, 0.15103097073733807, 0.20064733762826237, 0.10773265375090496, 0.18565353218998226, 0.11920313217810222, 0.1600375867315701, 0.11109245382249355, 0.11061310275856938, 0.09171504074973719, 0.1652056079890047, 0.09469741250255279, 0.14938265989933694, 0.1369784019355263, 0.09030797625226633, 0.16284577175974846, 0.17882677779666015, 0.09803874285093375, 0.1447410596800702, 0.11369825899600983, 0.1112533819728664, 0.13027356671435492, 0.1641350697193827, 0.11157030532402651, 0.0985543548262545, 0.14140980557671615, 0.11382078206432716, 0.10500145530594246, 0.1144689390701907, 0.13728017359972, 0.14783774422747747, 0.10828878105218921, 0.1932364867201873], [0.10089097158717257, 0.04805060662329197, 0.13511534833482333, 0.10231138286846024, 0.060408683493733406, 0.09566239786467381, 0.14113442892474787, 0.05710610428026744, 0.03858574539689081, 0.05345676653087139, 0.027454307169786522, 0.03158136749906199, 0.021808590473873273, 0.07184749469161034, 0.08526909377958093, 0.07823084002094609, 0.05586929778967585, 0.03786033039380397, 0.013495167551030005, 0.04822272042344723, 0.027152588092056767, 0.06289920556758131, 0.049507468805781434, 0.05985999293625355, 0.0404811685106584, 0.029821339262915508, 0.03125189125005688, 0.0369860787343766, 0.07670406837548528, 0.019178746500983834, 0.02259005416583802, 0.05952894248600517, 0.05045686821852412, 0.021183552852432643, 0.019097491932500685, 0.05753761184002672, 0.05231484637728759, 0.022939145165894712, 0.04362296885145562, 0.02031958948022553, 0.1212422927575452, 0.0977554748366986, 0.018833253432863524, 0.05722303622003112, 0.03518379472994378, 0.022204320578436767, 0.01829957715900881, 0.05375237370442067, 0.005241332301271281, 0.022452474405456866, 0.03519793879240751, 0.061172659641930034, 0.10900534117328269, 0.23009258189371654, 4.928869690213885, 27.621670654841832, 53.20031384059361, 75.12992640904018, 75.77777644566127, 71.3558247429984, 65.25121389116559, 70.32634489876884, 59.07161113194057, 77.55735601697648, 69.25798293522426, 55.23337064470564, 45.235051836286274, 26.863825423376902, 26.005860124315532, 15.938278198242188, 29.29716968536377, 37.651061807359966, 32.42539807728359, 50.3299435206822, 50.699247223990305, 50.84341887065342, 67.28468063899449, 63.75541959490095, 31.54907042639596, 44.64994750704084, 50.16398927143642, 51.6802772794451, 55.870530877794536, 51.0883845601763, 52.72984436580113, 38.5691932950701, 52.610929421016145, 38.733299323490684, 41.90928268432617, 46.36021184921265, 60.71861212594168, 62.93916606903076, 43.69312150137765, 56.44581045423235, 52.69834818158831, 68.6834363937378, 82.97838224683488, 72.19079671587262, 91.82955346788678, 106.16750867026192, 112.12597806113106, 75.14198848179409, 59.31258855547224, 39.14012677328927, 37.471725327628, 21.002411944525583, 20.75989202090672, 17.68011862891061, 18.880866357258387, 24.739382437297277, 40.24904189790998, 38.94583082199097, 45.26801756450108, 68.88091809409005, 69.87285682133266, 67.09607873644147, 79.23583929879325, 73.09215177808488, 53.529383999960764, 25.243072986602783, 5.462055776800428, 0.10859029487307582, 0.20044619270733424, 0.015965255542791316, 0.022437146299385598, 0.09310287556477956, 0.05758447825376477, 0.046873870837901316, 0.07970982923039369, 0.04757855659616845, 0.08094151956694466, 0.028562463420842375, 0.027400794505540813, 0.06973380382571902, 0.03169252171314188, 0.07703144795128278, 0.02059019433467516, 0.06538419079567705, 0.06127538984375341, 0.03543240317542638, 0.0401873289208327, 0.033196440299174616, 0.11933806565191064, 0.009395302057133188, 0.021902793186849782, 0.05341799503990582, 0.03830973092200501, 0.038198600456650765, 0.017776867707393, 0.07458661164024047, 0.037384989471840005, 0.036337962440614185, 0.03567888102095042, 0.07688618038914033, 0.025667154496269565, 0.07801565621048212, 0.012122490360135478, 0.030444678850471973, 0.05800153301762683, 0.04394596509103264, 0.029384023443396603, 0.024580080328243117, 0.08413050523293869, 0.1476463702108179, 0.06187137429203306, 0.08383928478828498, 0.028812764811196497, 0.026625400309317877, 0.05540048437459128, 0.07288779744080134, 0.05381481249683669, 0.043369977069752555, 0.07056006270327739, 0.11454026667135102, 0.04072097635694912, 0.10216167768729584, 0.047531500192625184, 0.016549241795603718, 0.031084255781024694, 0.037900720190789015, 0.042434613153870614, 0.06804921850562096, 0.024938346818089485, 0.037101494148373604, 0.07364920872662749, 0.018684035100575005, 0.08518542362643139, 0.026521099298926334, 0.01933867041952908, 0.04160511087892311, 0.06785383434700114, 0.032774428837001324, 0.05304255482873746, 0.0267225071521742, 0.029577626447592462, 0.018114505036334907, 0.018224575290722505, 0.018073775971840535, 0.018873756884464195, 0.03313244426889079, 0.036003943399659226, 0.012048954975658228, 0.010991719385076846, 0.022734303925452486, 0.05693330176706825, 0.0339910624814885, 0.004374217982071319, 0.02497294531869037, 0.003933734252184097, 0.03204214705952576, 0.04187014326453209, 0.0643709683790803, 0.07001689542084932, 0.020923750275479894, 0.08373009493308407, 0.08471649486039366, 0.11019963065960578, 0.04896658140101603, 0.06816847103514842, 0.030355600773223808, 0.012608121265657246, 0.023408637115997926, 0.05626344521130834, 0.03881123276161296, 0.03717484717656459, 0.025614868284070065, 0.084081250375935, 0.0834331340821726, 0.08281055106116192, 1.817395684974534, 14.422623344830104, 48.43314436503819, 72.54232692718506, 88.91037900107247, 85.65989358084542, 83.16524709974016, 81.89722170148576, 90.49532563345772, 87.71940217699323, 107.26198891230992, 94.60345499856132, 86.60863535744804, 63.50763293675014, 32.67924356460571, 29.26992232458932, 12.06728650842394, 18.580919572285243, 24.152737345014298, 16.67291123526437, 25.32951205117362, 35.52568081447056, 21.945801871163503, 24.401258775166102, 19.340991701398575, 23.817544085638865, 39.00880929401943, 32.068083490644185, 33.0255799974714, 19.933132818767003, 22.428010327475413, 16.627407482692174, 20.095757143838064, 20.426734583718435, 21.093565361840383, 21.851672887802124, 24.91317425455366, 23.286345618111746, 31.872672353472026, 22.19347562108721, 30.558198247637065, 30.41622223172869, 45.177058696746826, 41.23081888471331, 48.26826361247471, 57.57269014630999, 64.21812793186733, 83.73693098340715, 43.78156859534127, 40.969795908246724, 29.344764845711843, 23.317228623798915, 21.028293984276907, 20.037480865206035, 18.28437740462167, 26.812259367534093, 42.02741248267037, 64.4704031263079, 61.10060323987688, 65.81417083740234, 96.37597520010812, 87.32662745884487, 81.60816969190324, 90.09311526162284, 82.73219367436, 77.78279032026018, 48.96310779026577, 14.008643593106951, 0.15771310217678547, 0.2939381402518068, 0.06646245757916144, 0.07806609171841826, 0.024340292838002955, 0.10330908718918051, 0.0236959118795182, 0.10112787530358348, 0.005034440188735191, 0.04406253062188625, 0.027000906677650552, 0.05776323830442769, 0.041348078421183994, 0.0316843284027917, 0.020912079473159144, 0.04148978367447853, 0.06619789677539042, 0.012267533157552992, 0.019338307403294102, 0.01941583681452487, 0.005929344333708286, 0.027788592535736303, 0.008291234827733465, 0.028497541190258095, 0.01536632964520582, 0.096437345924122, 0.04785463892455612, 0.03283334942534566, 0.02200874643001173, 0.027296466353748525, 0.010486787550949624, 0.04006691270374826, 0.03199941970940147, 0.07400465251079627, 0.007743143077407564, 0.014327441641528691, 0.028560258182031766, 0.04529030581137963, 0.06554666600589241, 0.06538054027727672, 0.03331115682210241, 0.07713303142892462, 0.049262541412775, 0.16007821740848677, 0.0519372619954603, 0.03558495141831892, 0.03607309629608478, 0.04663397138938308, 0.028814552750970637, 0.014409154221149427, 0.06210915331861802, 0.053312370886227915, 0.12694597670010158, 0.2023619684789862, 0.07255173940211535, 0.10330027980463845, 0.09850389217691762, 0.1404201758227178, 0.17583682680768625, 0.0998549707499998, 0.1927979766790356, 0.14863009671015398, 0.10302715588893209, 0.14634930981057032, 0.10231378488242626, 0.12032941888485636, 0.11095218706343855, 0.23081649733441217, 0.18712137985442365, 0.13195277803710528, 0.14869298333568232, 0.11896538707826819, 0.12736183724233083, 0.12302370502480439, 0.1743921578994819, 0.17582093551754951, 0.15730721609933035, 0.11028423040573086, 0.10871610883623362, 0.12721241026052407, 0.0871484118646809, 0.10504622504647289, 0.17432537648294652, 0.1505838025893484, 0.15686128288507462, 0.09452068127159562, 0.1383423251765115, 0.11880666416670595, 0.0731739288728152, 0.08370350993105344, 0.22838055661746434, 0.14972548293215887, 0.1390968696879489, 0.19307920230286463, 0.2543775402009487, 0.25916327482887674, 0.16532256028481893, 0.13786550504820688, 0.11973431653210095, 0.0994076601096562, 0.17526802447225365, 0.1763643335018839, 0.31995184293815065, 0.10936486973826375, 0.09904099335627896, 0.11223452325378146, 0.13515183994812624, 0.16196470760873385, 0.8408097624778748, 10.936127594539098, 44.69825138364519, 78.75124413626534, 100.65307085854667, 95.60612869262695, 93.35862963540214, 83.05206789289201, 89.48740604945591, 81.51725946153913, 100.24993637629917, 85.34737055642265, 68.98778138841901, 54.03809288569859, 36.26883234296526, 36.65873050689697, 23.10348813874381, 41.14752388000488, 50.85632514953613, 43.64032908848354, 66.66831289018903, 64.93527235303605, 68.2661553791591, 82.81937272208077, 84.20785903930664, 42.60187217167446, 53.85054016113281, 69.37453896658761, 68.07312747410366, 76.39979307992118, 67.50546659742082, 72.70256628308977, 56.52651725496565, 73.0675412586757, 53.73586361748831, 59.90006569453648, 58.291210310799734, 81.87810025896344, 82.5554940359933, 64.62364564623151, 85.83229923248291, 74.71206174577985, 94.7375135421753, 113.03275271824428, 94.14812564849854, 110.42823437282017, 120.45750045776367, 128.45739228384835, 91.9850263595581, 75.47320216042655, 53.61973490033831, 49.57443809509277, 33.68348407745361, 30.93420696258545, 25.654821498053415, 27.546883719308035, 34.635991777692524, 52.770758833204, 53.45058100564139, 62.39150210789272, 91.14409283229283, 87.25214971814836, 88.1941864831107, 98.44085475376674, 95.0251898084368, 86.34800148010254, 49.104270866939, 10.104570661272321, 0.12963296180324896, 0.24928828328847885, 0.2114940591688667, 0.12302599847316742, 0.1593758658106838, 0.08210739200668675, 0.18244612429823193, 0.11061781857694898, 0.09224349060761076, 0.1968709916940757, 0.14033550822309085, 0.09819097896771771, 0.19659260234662465, 0.12215839645692281, 0.10579916821526629, 0.1459564651761736, 0.08710132831973688, 0.13815894430237158, 0.07098796724208764, 0.0985774996557406, 0.05878605520618813, 0.18945754878222942, 0.10968534861292158, 0.07458024019641535, 0.07952052474554096, 0.1985571647861174, 0.10469025879033975, 0.1107239346685154, 0.16722403253827775, 0.092928641342691, 0.10487712733447552, 0.07149999655250992, 0.12197137863508292, 0.11672221816011838, 0.2204857338219881, 0.11588851575340543, 0.11890028842857905, 0.08233787678182125, 0.20490399136074952, 0.14167895327721322, 0.18388338360403264, 0.20524460236941064, 0.22521505504846573, 0.18140837284071104, 0.16452572947101934, 0.1318031203533922, 0.13652376990233148, 0.21480571718088218, 0.1255902773035424, 0.11667507354702268, 0.19078620177294525, 0.08531224182141678, 0.1621982865035534, 0.2645238914660045, 0.1307877062686852], [0.1512140937681709, 0.0978510600647756, 0.1488950103521347, 0.05228864135486739, 0.07574384632919516, 0.1150821175958429, 0.058751524559089115, 0.12489015130060059, 0.061249286601586, 0.03091207073469247, 0.056130404850201945, 0.04824921382325036, 0.08457588204847914, 0.022603660489299467, 0.09135481329368693, 0.030679933726787567, 0.03147295795913253, 0.033999720588326454, 0.03359562584332057, 0.03248000231438449, 0.0315234816766211, 0.011911503288761845, 0.08109711443207093, 0.06176671026540654, 0.00569529428113518, 0.05498652373041425, 0.057202761593673906, 0.0698113264515996, 0.06173347562019314, 0.006801413654881928, 0.030475426664842025, 0.032935319667948146, 0.01929324589270566, 0.048006037050592046, 0.032858536645237885, 0.03793101338669658, 0.038106241662587435, 0.11679482140711375, 0.01771895813622645, 0.06342433060386352, 0.031297281850129366, 0.01800053150925253, 0.047095239495060275, 0.024747634373073066, 0.041095710891698084, 0.09203772486320563, 0.0726488513339843, 0.07640074286609888, 0.08737690853221075, 0.1400875172444752, 0.03795958988900695, 0.2540218250027725, 10.702243413243975, 45.328845569065635, 66.02752917153495, 76.75319930485317, 74.62080410548619, 69.48448726109096, 64.46790872301374, 61.96668924604143, 59.371710777282715, 58.40541090284075, 46.30015856879098, 34.4389408656529, 21.289263112204416, 17.63614000592913, 28.482015711920603, 65.6308982031686, 46.593334334237234, 66.19881616319928, 61.49341269901821, 77.40395368848527, 83.77037961142403, 58.260964802333284, 46.97293874195644, 58.6256479535784, 69.9725148337228, 81.74579960959298, 91.34051840645927, 49.28000470570156, 65.08797291346959, 63.52450316292899, 74.19237123216901, 66.1071972165789, 83.14774458748954, 65.49944523402623, 80.17049707685197, 68.07836641584123, 65.99592876434326, 76.40247508457729, 70.06505789075578, 62.7813446862357, 62.426680837358745, 51.59098250525338, 61.233529227120535, 47.50828354699271, 53.82646812711443, 43.002991676330566, 54.97591209411621, 63.731093951633994, 60.44363021850586, 80.23867280142647, 75.84380517687116, 76.25566659654889, 71.59448146820068, 53.452370166778564, 79.74835232325962, 68.81407642364502, 43.371148926871165, 32.02984060559954, 32.160265241350444, 36.35109554018293, 38.246515478406636, 34.612187249319895, 44.812379019601, 53.41213662283761, 64.87550394875663, 68.95023332323346, 71.5475741795131, 72.3449216570173, 59.56301552908761, 19.965747662952968, 1.5840163337332862, 0.13377651731882775, 0.11185579214777265, 0.04339789878576994, 0.040617140143045356, 0.048849449293421845, 0.045505187673760314, 0.0716641206028206, 0.08950161202145474, 0.0862659974289792, 0.06222167478076049, 0.04076062994343894, 0.02629172562488488, 0.04751036721946938, 0.04181071038224867, 0.05116786774513977, 0.0848559880895274, 0.004496120614930987, 0.022812532227752463, 0.023340993959988867, 0.06327926660222666, 0.027112284808286598, 0.062062558318887434, 0.03268656873011163, 0.05324366921558976, 0.06008229457906314, 0.03999888278277857, 0.019500076937090074, 0.04993691701175911, 0.08788983350885765, 0.059770806293402395, 0.015672927389719656, 0.05606995077271547, 0.043866851300533326, 0.017784670860107456, 0.008364795657273914, 0.005119492008816451, 0.06570802163332701, 0.04146241496450134, 0.06666064408740827, 0.016976942773908377, 0.018671901198104024, 0.0010823809321404301, 0.07490189972200564, 0.08090884810579674, 0.03998619417792984, 0.10092170243816716, 0.052101199448640854, 0.12587937393358775, 0.07457352269973073, 0.07969002279319934, 0.13750254309603147, 0.1352274694613048, 0.08128939090030533, 0.11854926869273186, 0.03933170983301742, 0.016074387722515633, 0.13695463963917323, 0.03329364722594619, 0.05739106184669903, 0.07210567048085587, 0.06164500143911157, 0.023253910775695528, 0.03422264648335321, 0.040617367452276606, 0.03602473031995552, 0.1108334366498249, 0.03968464982296739, 0.0621398909549628, 0.06912073386566979, 0.01726512677435364, 0.02908474878807153, 0.047950868760900836, 0.0627856527322105, 0.040958697708057504, 0.06907903788877384, 0.0579639964603952, 0.09498344893966403, 0.02450097332309399, 0.03152255547632064, 0.0554380277171731, 0.027933805815077255, 0.04224472173622676, 0.025942639713840823, 0.0561844976618886, 0.06925667157130581, 0.02970168979040214, 0.05112354923039675, 0.018792558295120085, 0.02938047131257398, 0.045125218241342475, 0.010312420166363674, 0.02772882717129375, 0.04598766339144536, 0.02578005933069757, 0.03070522951228278, 0.010766264250768083, 0.020903541806287, 0.03881210807178702, 0.08547737688890525, 0.0358238737764103, 0.07269691196935517, 0.06836525297590665, 0.09527046246720211, 0.028696772642433643, 0.7487416256751332, 23.297426257814678, 68.21867138998849, 84.44464669908795, 90.38125010899135, 84.3259506225586, 88.19050393785749, 87.14393152509416, 91.47307613917759, 79.84630802699498, 92.22314807346889, 73.56475434984479, 43.56479869570051, 20.386791127068655, 14.894971438816615, 17.72565712247576, 32.82742779595511, 26.603992325919016, 39.15458597455706, 33.68215349742344, 45.32579183578491, 52.57213068008423, 45.73541940961565, 42.21025085449219, 44.93529265267508, 52.90493549619402, 55.784744943891255, 81.31602573394775, 39.14189508983067, 43.60550471714565, 41.69138370241438, 56.00461721420288, 52.611332416534424, 55.32422181538173, 43.09835570199149, 50.581107003348215, 44.21172114780971, 44.85485683168684, 51.765872137887136, 56.2450179372515, 54.681162561689106, 55.86682401384626, 47.12649393081665, 57.29603719711304, 48.2526718548366, 57.13095842088972, 53.90034137453352, 64.67911311558315, 72.38936233520508, 63.99330507005964, 70.38990007128034, 60.877538272312705, 60.623998505728586, 47.9996532031468, 40.77403736114502, 55.58252109800066, 47.73805700029646, 29.608935356140137, 22.076737199510845, 27.02828754697527, 26.739471776144846, 40.617039339882986, 58.21416868482317, 72.38800048828125, 74.80069296700614, 83.17611408233643, 84.81194932120187, 81.65866225106376, 81.94071047646659, 78.14552102770124, 38.59283454077584, 8.15563656602587, 0.1860827598720789, 0.17902797700038978, 0.020520720830453292, 0.032729024666228464, 0.09880503280354397, 0.0067411224257999235, 0.04491434312824692, 0.04180253742794905, 0.14532040644969257, 0.06604879549039261, 0.03058193630671927, 0.03337370078744633, 0.038409082019435506, 0.018276858110246912, 0.03140618332794734, 0.04057354426809719, 0.017430314428306053, 0.0064143382644812974, 0.024654564813577702, 0.07808380826775517, 0.033051603606769016, 0.013395363531474556, 0.06015276044074978, 0.09618892068309443, 0.05299075546541384, 0.031766390427947044, 0.01271369877005262, 0.014743875545848693, 0.05116188306627529, 0.05208473479641335, 0.06033832619764975, 0.052729271817952394, 0.02008476716998432, 0.034804391874266524, 0.08793525464300599, 0.06202268760119166, 0.09480130978460823, 0.08975870894002062, 0.08275366947054863, 0.03353572816454938, 0.023019724592034305, 0.034826447655047686, 0.0783614647973861, 0.03291841396795852, 0.06083080691418477, 0.07649555456425462, 0.06652295576142413, 0.06602135553423848, 0.04553027989874993, 0.0849458532673972, 0.11783838112439428, 0.15264217928051949, 0.04322324726464493, 0.21450613039944852, 0.14808942643659456, 0.24565195984074048, 0.1883260780679328, 0.20472455956041813, 0.2595101147890091, 0.12866500445774623, 0.2733036460621016, 0.14622763491102628, 0.15088495000132493, 0.15337302934910568, 0.21087797651333468, 0.24109329017145292, 0.1485273257962295, 0.14037372331534112, 0.21853646556181566, 0.14241565231766018, 0.11028397934777395, 0.19580566457339696, 0.14623941427895001, 0.12375908770731517, 0.1349842417985201, 0.15977374517491885, 0.2776427689407553, 0.16507615707814693, 0.11443019472062588, 0.18203295075467654, 0.18562823640448706, 0.21081789902278356, 0.14594088601214544, 0.13995391369930335, 0.11840024883193628, 0.11402280229542937, 0.21407212583082064, 0.16331895494035312, 0.12576183809765748, 0.1255016334887062, 0.238758206899677, 0.11178551627589123, 0.11654871675584998, 0.11740599146911077, 0.09472243687404053, 0.11868945402758461, 0.07562314852007798, 0.12466691327946526, 0.2827805003949574, 0.23840895135487827, 0.2840694726577827, 0.17338259278663568, 0.29886169891272274, 0.07448181190661021, 0.37768380077821867, 18.955045325415476, 68.40138816833496, 95.18483856746128, 100.45588098253522, 93.7403289249965, 89.33429554530552, 82.66957650865827, 82.19743251800537, 74.48687062944684, 74.5495503289359, 57.62951946258545, 44.89463874271938, 30.49698461805071, 23.501663344247, 36.16694048472813, 85.58634689876011, 62.84571974618094, 87.76671940939767, 81.01204204559326, 99.27568776266915, 106.92142990657261, 80.91043853759766, 63.530923298427034, 79.17657811301095, 97.38612515585763, 111.38673142024449, 120.17462539672852, 69.56113283974784, 84.8951609475272, 90.62625748770577, 102.07610361916679, 94.57058307102749, 114.6420041493007, 93.17233453478131, 116.231995173863, 99.36331149509975, 93.66206441606793, 110.14424760001046, 99.8638527733939, 89.56423228127616, 88.58414718082973, 73.58295168195451, 86.38812037876674, 64.16233389718192, 77.34320558820451, 61.285529545375276, 75.70454938071114, 87.77495302472795, 79.16237599509103, 102.45828233446393, 95.22921671186174, 92.94647639138358, 92.34721510750907, 70.61521625518799, 105.13822337559291, 90.87438460758754, 62.5722108568464, 44.40437037604195, 43.164297580718994, 46.794689655303955, 49.04033701760428, 46.87146030153547, 62.07512978145054, 69.38354383196149, 85.23661627088273, 86.54730360848563, 89.18287345341274, 93.9991979598999, 86.15605054582868, 38.07517984935215, 5.3639784795897345, 0.1951168022517647, 0.26615033990570475, 0.1386883101825203, 0.10914784709789924, 0.2092897024537836, 0.12437846804303782, 0.10606156449232783, 0.1452001157615866, 0.12687023862132005, 0.17948628669338568, 0.2200135277318103, 0.10016224533319473, 0.09941329873566117, 0.18076346601758683, 0.14485650562814303, 0.2015516755304166, 0.08541183040610381, 0.07578997313976288, 0.10634639313710587, 0.16186359232025488, 0.0928856765053102, 0.10609719436615705, 0.12692164443433285, 0.19931972958147526, 0.16684773058763572, 0.0815339009942753, 0.10415931192359754, 0.1790774150618485, 0.17763888011021273, 0.17762182173984392, 0.19771622919610568, 0.3338262827268669, 0.16381006501615047, 0.11034529177205903, 0.18106207570859364, 0.11105430658374514, 0.1801649709897382, 0.12031379900872707, 0.2182418592274189, 0.15832155809870788, 0.1531961081283433, 0.1529855044292552, 0.22061874025634357, 0.08837983078722443, 0.14433123809950693, 0.21131105827433722, 0.12382092938891479, 0.14748095694397176, 0.12362769618630409, 0.17569635648812565, 0.24619771912693977, 0.1942453190152134, 0.16604498294847353], [0.018824481671409946, 0.06081080370183502, 0.08736156685543911, 0.0850891802193863, 0.08256834798625537, 0.040204543354255814, 0.09494484029710293, 0.019468126419399465, 0.06605725003672497, 0.0630998687286462, 0.06205684505403042, 0.06304946036211082, 0.04671557540340083, 0.006097590484257255, 0.032604343856551816, 0.016955317862864052, 0.04249073817793812, 0.07835165996636663, 0.045531172172299454, 0.07662681037826197, 0.0063212352023193875, 0.05395519799951996, 0.04112967156938144, 0.02276276677314724, 0.04267227343682732, 0.015288584799106632, 0.026703749051583663, 0.033517272012042146, 0.07151870376297406, 0.0308903169019946, 0.005742279862585876, 0.008985820592248013, 0.0071765417399417076, 0.0505536646316094, 0.03594866993704012, 0.05191348273573177, 0.024424612688432847, 0.0585797873458692, 0.016812387853860855, 0.04942873160221747, 0.0944627004542521, 0.03703921141901186, 0.02589025511406362, 0.05448876740410924, 0.039356547607375045, 0.04666096351242491, 0.07739177718758583, 0.23041708448103496, 0.1568866465240717, 0.09701780549117497, 3.5157368097986494, 31.738561698368617, 68.25644179752895, 72.49298776899064, 68.4670000076294, 63.81427778516497, 58.0797245161874, 52.996634347098215, 56.42367001942226, 39.914962087358745, 26.038459335054668, 28.809180327824183, 20.068202325275966, 41.32607521329607, 64.3754768371582, 67.55437496730259, 64.31838348933628, 53.401981830596924, 60.973006520952495, 47.910827432359966, 45.86355461393084, 49.319755349840435, 55.15078783035278, 56.023359979902, 39.51689979008266, 24.854255267551967, 13.960186856133596, 9.323799848556519, 12.518632803644453, 25.700943640300206, 21.21307785170419, 18.52260160446167, 22.140210730688914, 19.622998237609863, 18.729921954018728, 20.259368113109044, 22.06628016063145, 24.51804062298366, 23.726550476891653, 22.79812002182007, 18.29535208429609, 14.261630977903094, 9.340188911982946, 6.863843985966273, 7.426344088145664, 23.602646725518362, 26.41754957607814, 21.22313015801566, 26.651465892791748, 26.61580773762294, 27.374973126820155, 33.52971696853638, 38.67414583478655, 44.59375395093645, 43.72877270834786, 45.11353826522827, 55.41004596437727, 46.030717849731445, 58.322407722473145, 69.4883782523019, 137.1937653677804, 125.86422729492188, 35.87625912257603, 29.851479598454066, 13.23008143901825, 34.907430103846956, 46.54236929757254, 55.01151466369629, 57.73419060025896, 60.804471015930176, 64.91262122562954, 71.64340373447963, 51.17805106299264, 16.308499063764298, 0.3109506959361689, 0.2529113074498517, 0.22946347136582645, 0.039238594472408295, 0.016173569186191474, 0.10783662567181246, 0.04678057227283716, 0.028925289666014056, 0.10412917818341937, 0.014490610653800624, 0.03701529984495469, 0.05197994863348348, 0.0534267413562962, 0.053948036062398126, 0.03187329022746001, 0.005185497350924249, 0.04063984053209424, 0.08281871383743626, 0.027732908559430922, 0.05818254580455167, 0.025795718222590427, 0.058484867082110474, 0.04733586158337338, 0.03451458278245159, 0.016475323887009705, 0.04183108339618359, 0.014774112762617213, 0.07537873342101063, 0.031320721842348576, 0.024339481988655667, 0.021388395789212415, 0.051186530850827694, 0.017251091277492896, 0.04492653640253203, 0.06517191111509289, 0.012956508285632091, 0.02806548571347126, 0.018159804034179876, 0.09775940355445657, 0.06915983105344431, 0.08791996046368565, 0.011960462983032423, 0.054758580068924596, 0.04288564216611641, 0.07508507703563996, 0.027559658213119422, 0.04122935175629599, 0.07602115680596658, 0.03554937243461609, 0.10509041803223745, 0.06030289988432612, 0.07034850226981298, 0.030703875834920576, 0.03758204621928079, 0.012650195525826087, 0.06913130544126034, 0.04190862298543964, 0.02248615349110748, 0.04168366827070713, 0.038612825729485066, 0.06802792607673577, 0.08832317989851747, 0.06947126505630356, 0.10207240283489227, 0.1041032038629055, 0.030935086642525027, 0.008191172116702157, 0.029837495181709528, 0.054867647787822146, 0.007717447804420122, 0.057099325715431144, 0.039987493572490554, 0.08725595966513668, 0.06145721687270062, 0.00960451306309551, 0.08440428732761315, 0.01638860541528889, 0.06426711859447615, 0.010510315752721258, 0.011063042745393301, 0.05815234421087163, 0.02463172362851245, 0.01671620212229235, 0.05476045621825116, 0.06671380730611937, 0.08358165861240455, 0.029551865865609477, 0.02885776186095817, 0.04413352234821234, 0.05085640660087977, 0.02867691870778799, 0.08496024499514274, 0.08990063132452113, 0.03915969102776476, 0.03844852526006954, 0.046299507907990894, 0.04885527790923204, 0.02656269010289439, 0.11175013067466871, 0.1783188400524003, 0.12028863893023559, 0.1341950377183301, 11.393108010292053, 53.40894392558506, 84.00672258649553, 78.39440550122941, 80.29386929103306, 80.54159341539655, 81.38966274261475, 76.24186052594865, 80.80605575016567, 69.52293164389474, 39.437811919621055, 29.54244109562465, 19.087490149906703, 27.913670437676565, 46.92086894171578, 42.17170572280884, 40.88115079062325, 47.01325913837978, 58.41917528424944, 51.39102724620274, 45.86360672542027, 46.848204680851524, 58.20941611698696, 59.648714610508506, 39.23261077063424, 20.606908321380615, 11.001610892159597, 8.781459944588796, 11.85024562903813, 23.202975920268468, 19.591839041028702, 16.56953419957842, 22.0668968132564, 21.20877344267709, 20.733582666942052, 24.37406873703003, 25.096191542489187, 28.07567811012268, 27.186399017061504, 24.852122170584543, 16.831958975110734, 12.32334760257176, 6.795329102448054, 4.46013422523226, 4.833999420915331, 14.325517058372498, 19.62980399812971, 13.080092413084847, 21.892936502184185, 21.819530521120342, 19.074839217322214, 26.989157029560634, 30.383815833500453, 33.552260398864746, 39.96332849775042, 42.78603764942714, 54.86432402474539, 48.10566186904907, 47.140289579119, 48.101753507341655, 103.40811497824532, 103.64874499184745, 23.575734615325928, 19.241092239107402, 17.41440909249442, 50.12598957334246, 58.38732474190848, 75.56489753723145, 83.47120407649449, 83.72399343763078, 82.39984743935722, 84.14797946384975, 69.62381948743547, 34.665903772626606, 3.5615460659776415, 0.07890645733901433, 0.28344747317688807, 0.06749960514051573, 0.03498577107010143, 0.08835777161376816, 0.028057434895474995, 0.05332110023924282, 0.10028750289763723, 0.043480917545301576, 0.04352196552125471, 0.04165399254166654, 0.0276348738199366, 0.015177841098713023, 0.03084072277748159, 0.054053921452058215, 0.032948167728526254, 0.05695972392069442, 0.01414325415888535, 0.07009842140333992, 0.051199385696755986, 0.033026887968714745, 0.07833762786218099, 0.028507400304079056, 0.0028166260038103375, 0.07646006039742913, 0.04881030460819602, 0.03121899247967771, 0.00919977795066578, 0.004215769877191633, 0.01636749449452119, 0.011662373219483664, 0.04240830974387271, 0.011712611952264394, 0.052387914420770745, 0.049573656504175494, 0.03167676613000887, 0.039577295404991934, 0.016974533974592174, 0.016190140707684413, 0.022325647728783742, 0.044073519496513267, 0.09966548306069203, 0.05345238998000111, 0.03727414059851851, 0.03118697241214769, 0.04230309949655618, 0.04923539661935397, 0.023326018692127297, 0.09935617965779134, 0.04322277568280697, 0.06718566055808749, 0.13212940070245946, 0.14601530773299082, 0.15932804266256945, 0.12949198936777456, 0.13301942151572022, 0.12445944441216332, 0.153551402634808, 0.23382316742624554, 0.10941768690411534, 0.17740023934415408, 0.1678910188909088, 0.16539384717387812, 0.11381401707019125, 0.09664833638817072, 0.11005565909934895, 0.15678599263940537, 0.15562552133841173, 0.22092591305928572, 0.12961845472455025, 0.14422231965831347, 0.1501129807106086, 0.1143630604658808, 0.10220321081578732, 0.1521717102399894, 0.14529987398002828, 0.12048168214304106, 0.14763558150402137, 0.1934943843100752, 0.17065646978361265, 0.12858140894344874, 0.06863510635282312, 0.32199255057743614, 0.117749153769442, 0.19653788528272084, 0.16086109754230293, 0.09105825956378664, 0.12107759873781886, 0.20214757855449403, 0.15943654041205133, 0.23941676584737642, 0.2803158440760204, 0.09696400444954634, 0.1395004487463406, 0.15176270290144853, 0.16744497711105005, 0.154202524838703, 0.1481426100113562, 0.34984931722283363, 0.1409757331545864, 0.18593454068260534, 8.026968955993652, 52.754281180245535, 95.18939658573696, 91.71091297694615, 86.89112826756069, 81.07606969560895, 77.26870700291225, 72.20720141274589, 70.77401038578579, 51.62176997320992, 38.72274153573172, 36.491251128060476, 28.866740942001343, 53.36924886703491, 80.38977527618408, 86.21934863499233, 85.9012531552996, 72.77043628692627, 84.45428385053361, 68.96407413482666, 65.44538824898856, 71.4996316092355, 77.31291144234794, 77.82714762006486, 57.90660320009504, 40.43577126094273, 22.763043778283254, 16.997075966426305, 21.800659213747295, 42.626437527792795, 37.487275396074565, 30.52510745184762, 37.298141956329346, 36.42603186198643, 36.885005542210166, 43.894296169281006, 44.77115535736084, 49.62989861624581, 48.6016069139753, 43.509817600250244, 35.60921900612967, 28.3174615246909, 18.50048201424735, 14.625103405543737, 14.38611924648285, 37.74342768532889, 38.19708946772984, 30.900393554142543, 36.24477073124477, 36.7262669972011, 40.54205090659005, 49.283878326416016, 56.28441422326224, 61.18869250161307, 63.20508057730538, 65.94704818725586, 75.66819640568325, 66.09855365753174, 76.36448928288051, 90.84952395302909, 154.24846621922083, 134.14629936218262, 45.02552195957729, 39.83785445349557, 18.679464135851177, 45.77839401790074, 60.80540207454136, 71.52612509046281, 78.36933640071324, 80.86301708221436, 83.4195442199707, 95.89313098362514, 76.7424851826259, 30.538048471723283, 1.8313551587717873, 0.2895018240170819, 0.33006793154137476, 0.15992978108780725, 0.1763756921780961, 0.21183213245655808, 0.08255000039935112, 0.17566700306321892, 0.20660845775689396, 0.08743454329669476, 0.1337211760027068, 0.17022642785949366, 0.15920619134392056, 0.2588636337646416, 0.10952914306627852, 0.09093464405408927, 0.10407951620540448, 0.2235959076455661, 0.12376648373901844, 0.11519343805100236, 0.1622616345328944, 0.08447161835751363, 0.17085236284349645, 0.18273074259715422, 0.05732523037918976, 0.17136977293661662, 0.15581192847873482, 0.14142124567713055, 0.16428354675216333, 0.09511746639119727, 0.09021196354712759, 0.17376631791038172, 0.1624048189925296, 0.1688199197607381, 0.1728636763457741, 0.10468312738729374, 0.1052478856540152, 0.11261034344456025, 0.14710679916398867, 0.1267347623194967, 0.11397504700081688, 0.1289283846105848, 0.2054981980472803, 0.21054229166890892, 0.15651346583451542, 0.12571225075849465, 0.08218480606696435, 0.19167105214936392, 0.14586172811686993, 0.15880417291607174, 0.12571978249720164, 0.12091715234730925], [0.02339151767747743, 0.03030257665419153, 0.05501448615853276, 0.10351347550749779, 0.009938435412810316, 0.06689549862806286, 0.0628833007067442, 0.0347411456251783, 0.10979094223252364, 0.04546018723132355, 0.020678558253816197, 0.03295850181686027, 0.01254087929347796, 0.011884660443424113, 0.03586229582184127, 0.006796776292113853, 0.027560162025370767, 0.02811457772207047, 0.1145749669522047, 0.011127191446056324, 0.06551799111600433, 0.03471946643133249, 0.030714766321969882, 0.035734890694064755, 0.03654891558523689, 0.012868045130744576, 0.010971315837066089, 0.0664695550554565, 0.046096086502075195, 0.054833422481481514, 0.04186943758811269, 0.023549231268199425, 0.03302928998268076, 0.04448967520147562, 0.13702656435114996, 0.02231617707626096, 0.0521860706087734, 0.01683255221827754, 0.07934956784759249, 0.045583724709493775, 0.011698872466305537, 0.06345407757908106, 0.04831859742158225, 0.027736808439450603, 0.07177689990827016, 0.1365284246525594, 0.07241387465702635, 0.2558612791555268, 2.0275987769876207, 25.267810310636246, 64.29612146105084, 74.91575513567243, 70.84005996159145, 64.8842864717756, 59.05535234723772, 64.04259559086391, 47.90914249420166, 40.23067780903408, 33.09088611602783, 19.37299336705889, 27.833015748432704, 52.357344491141184, 56.23393208639962, 67.14612661089215, 87.10821083613804, 68.96078068869454, 55.55481168201992, 31.157438686915807, 27.50662238257272, 22.653642654418945, 20.630111830575125, 17.27473119327, 20.477683986936295, 16.576895815985544, 4.568124864782606, 0.11765426743243422, 0.15986354249928678, 0.10161288534956318, 0.306723667042596, 0.36355786877019064, 0.45147453833903584, 0.3110337486224515, 1.3754499767507826, 2.1818103534834723, 0.856281935104302, 0.7529234098536628, 1.1310825922659464, 1.1075221193688256, 0.821557064141546, 1.5517888516187668, 4.213445382458823, 1.2601268163749149, 0.9105478546449116, 0.3119795178728444, 0.5622357449361256, 1.0559292478220803, 2.3370743649346486, 5.014294752052852, 2.4475018680095673, 2.687756027494158, 3.40726500749588, 3.546351441315242, 2.9414601624011993, 4.908102827412741, 8.87328907421657, 12.504126702036176, 21.837686164038523, 38.57304607118879, 52.74259083611624, 47.69107328142439, 42.87524904523577, 24.767081430980138, 50.935201099940706, 79.75787830352783, 61.29328373500279, 22.42316743305751, 18.88646834237235, 25.905220678874425, 33.157404695238384, 36.69768558229719, 34.963102545057026, 47.609914847782676, 58.375172342572895, 66.3960268838065, 44.55447925840105, 13.45774871962411, 1.0865346512624194, 0.1533643983836685, 0.2673200528536524, 0.05598301347345114, 0.1155100017786026, 0.1273337730339595, 0.049806360088820965, 0.07022752626133816, 0.014447274318497096, 0.025566147773393562, 0.05958733042435987, 0.0034958749685236917, 0.02068863110616803, 0.09155020423765693, 0.0017663206942545781, 0.016083244300846542, 0.0010571550145479186, 0.02606918988749385, 0.018868661086474146, 0.04583629919216037, 0.048493371079010625, 0.06691814134163515, 0.07968246391309158, 0.06370134931057692, 0.03455168507727129, 0.07399674079247884, 0.017860030655616095, 0.04194727573277695, 0.007216165640524456, 0.03217969289315598, 0.05915010959974357, 0.052665869505809884, 0.05721435775714261, 0.0558847344613501, 0.03269198004688535, 0.02120154590478965, 0.05865891131439379, 0.037304674674357684, 0.031624250912240574, 0.012108557491696306, 0.02841377943488104, 0.036135138145514896, 0.06458133459091187, 0.10223660830940519, 0.020029217204345123, 0.05889883451163769, 0.02740257396362722, 0.07235237902828626, 0.051986432035586665, 0.0004993323829174706, 0.09505110566637345, 0.05802782624959946, 0.060736646609646935, 0.02356750930526427, 0.04118391705144729, 0.003971318306867033, 0.04041661608165928, 0.021337926354525343, 0.07691113690712623, 0.006937303438982261, 0.062273453788033555, 0.058367663728339333, 0.012968510721943207, 0.07706633143659149, 0.0006487332835344464, 0.014874032133125832, 0.038622949471963305, 0.018258826042126333, 0.07693862436073166, 0.0825283687029566, 0.039146015154463906, 0.05825775462601866, 0.07937078563762562, 0.05273656267672777, 0.046562949128981145, 0.07569659315049648, 0.010574757919779845, 0.03210521688950913, 0.022866177206326808, 0.04201572295278311, 0.0168501686836992, 0.0688230741236891, 0.02273594937287271, 0.04107467630611999, 0.03155968491254108, 0.06797954652990613, 0.047977789637765715, 0.022892183757254055, 0.04371107662362712, 0.04397936597732561, 0.10812486734773431, 0.03130486108628767, 0.015494140197655984, 0.006326925566619528, 0.12754030552293572, 0.07563245123518364, 0.08358851860144309, 0.21836296415754727, 7.348915100097656, 45.9153082711356, 84.86836869376046, 89.07596846989223, 82.99837916237968, 86.71086420331682, 79.8506714957101, 90.27688816615513, 73.60589463370187, 60.47745404924665, 35.39243173599243, 14.817721366882324, 19.12490793636867, 28.454844781330653, 27.910555907658168, 66.97342218671525, 85.86548382895333, 64.08179037911552, 54.92332465308053, 31.525533403669083, 28.15296639714922, 18.457074880599976, 16.671891587121145, 13.25856123651777, 13.926057304654803, 11.75760269165039, 2.6322125622204373, 0.4465373546949455, 0.3895828622792448, 0.3959250476743494, 0.41967795310275896, 0.6998178394777435, 0.4284413142928055, 0.7399686564292226, 0.9263109288045338, 0.7377051721726144, 0.6995857805013657, 0.4963112367050988, 0.7314462565949985, 0.47675194910594393, 0.3971413624073778, 1.069478343640055, 1.5170964960541045, 1.335601840700422, 0.8544136296425546, 0.5587036716086524, 0.33623999463660376, 0.6847992539405823, 0.44811560000692097, 0.2866376462791647, 0.9549869043486459, 0.45539606362581253, 0.38078416298542705, 0.8177581908447402, 0.7856684784804071, 0.8611902945808002, 3.386041734899793, 6.667886112417493, 14.747327429907662, 30.886066368647985, 43.373257705143516, 45.636695929935996, 44.397453444344656, 33.8780266898019, 54.7657082421439, 63.08418192182268, 32.180734634399414, 9.983558229037694, 23.58717656135559, 35.13637672151838, 46.22691065924508, 61.906413623264854, 57.08334936414446, 66.09578827449253, 68.10103838784354, 78.54850264957973, 66.49174526759556, 31.17467369352068, 7.046612441539764, 0.08604576531797647, 0.28916554206183975, 0.048440519986408095, 0.09157805131482226, 0.17083716365907872, 0.056333778758666346, 0.03522558570174234, 0.04453088263315814, 0.06320378636675221, 0.03577082930132747, 0.007109438867441246, 0.0509201006830803, 0.013669089647009969, 0.030112447749291147, 0.034842905521925004, 0.02757022639603487, 0.021880494829799448, 0.03788505620988352, 0.023370343992220502, 0.02132030649642859, 0.029611505701073577, 0.029649822573576654, 0.029134780567671572, 0.010916605558512467, 0.06472160134996686, 0.06463928826685462, 0.029177840399955, 0.03300271855135049, 0.04213306201355798, 0.05844194295683077, 0.0011598000814306683, 0.034797528492552895, 0.04287646497998919, 0.021417713591030667, 0.02022150045792971, 0.03722281960238304, 0.04095060617796012, 0.04010833726663675, 0.07186259888112545, 0.017811189704973782, 0.011271012032271495, 0.008283128030598164, 0.055363097095063755, 0.019844565773382783, 0.06892169240329947, 0.03576645953580737, 0.04143851017579436, 0.05003989487886429, 0.019397921793695008, 0.12228286692074367, 0.1058205488537039, 0.15259956728134835, 0.19572681880423, 0.14290906941252096, 0.1303283923438617, 0.1705798360386065, 0.09472053019063813, 0.1687451044895819, 0.12375517934560776, 0.09093446763498442, 0.16286806842046125, 0.0781297315178173, 0.17647559967424187, 0.12405263552708284, 0.13425796505595955, 0.19704325816461019, 0.14363664894231729, 0.2344086617231369, 0.16531316936016083, 0.08411245620144264, 0.09227997543556349, 0.15406004605548723, 0.18602579007191317, 0.13456752630216734, 0.1726160789174693, 0.0693727010594947, 0.13310639613441058, 0.15231904733393872, 0.1706546377390623, 0.09708523830132824, 0.13761885756892817, 0.095406868362001, 0.07801473340285675, 0.25991663868938175, 0.11945409514009953, 0.20574646043990338, 0.10268739983439445, 0.1930295199687992, 0.11087746678718499, 0.17848204129508563, 0.19538481001343044, 0.21949200571647712, 0.13441868286047662, 0.2121610998042992, 0.2089736137006964, 0.14789331624550478, 0.20666378550231457, 4.660975813865662, 40.20704003742763, 91.81708145141602, 95.30636256081718, 85.30569526127407, 84.98167991638184, 79.17671707698277, 80.95655373164585, 60.2208640234811, 51.19678340639387, 43.83165121078491, 24.58785959652492, 37.973381791796, 68.60916015080043, 75.84141499655587, 85.3326473236084, 103.59972545078823, 90.272371837071, 75.22510978153774, 48.17056499208723, 44.03064414433071, 36.88362979888916, 32.197472844805034, 26.497636250087194, 27.94325934137617, 21.843680722372874, 8.134115389415197, 1.1910045083080019, 0.8059603124856949, 0.7795002151812825, 1.1342064589262009, 1.570884781224387, 1.92566978931427, 1.1470538952520914, 3.202949102435793, 5.472921022347041, 2.8174534908362796, 2.273667493036815, 3.2348437224115645, 2.957419523171016, 1.8570778242179324, 3.7349138259887695, 11.957409432956151, 4.62464759179524, 2.7553910953657965, 1.4270959368773868, 1.444468604666846, 2.7288676500320435, 5.06197589635849, 8.800502351352147, 5.192166464669364, 4.960589953831263, 6.084626964160374, 5.687978625297546, 4.907436234610421, 7.845309172357831, 12.895465748650686, 18.862406730651855, 31.938305037362234, 54.93301044191633, 68.96132959638322, 66.74388149806431, 58.48813615526472, 38.397454670497346, 67.48766531263078, 105.91131469181606, 78.38879830496651, 31.916223662240164, 30.729870864323207, 38.145394870213096, 44.1932041985648, 48.68866784232003, 51.057183674403596, 63.47394806998116, 74.89162404196603, 89.64394896371024, 71.13882555280412, 26.95076823234558, 5.048190670354026, 0.275603961199522, 0.38102216592856814, 0.22365342027374677, 0.24662454479507037, 0.25246504853878704, 0.19365162801529678, 0.14817237055727414, 0.12535223364830017, 0.09980404669685022, 0.19965479017368384, 0.06413390181426491, 0.14605523273348808, 0.2163293675652572, 0.08519843792808907, 0.1275637556931802, 0.09979612140783242, 0.15289512356477125, 0.09880378429910966, 0.09753604339701788, 0.07340642889695508, 0.15606841471578392, 0.1544104822512184, 0.09183951799890824, 0.07648004325372831, 0.11542924254068307, 0.09874165084745203, 0.08954235804932457, 0.06832344843340771, 0.112155731767416, 0.13224066687481745, 0.2284426832837718, 0.09782792880598988, 0.13902205441679272, 0.09705603415412561, 0.12807340334568704, 0.12479306651013237, 0.09390827627586466, 0.09007053649319069, 0.15489727684429713, 0.1215602271258831, 0.09364834308092083, 0.09861559261168752, 0.18596344627439976, 0.10331036283501557, 0.11213747917541436, 0.09246811284018414, 0.11090992111712694, 0.13769207149744034, 0.08108790671186787], [0.016384461262662495, 0.031469334582132955, 0.018668074260598848, 0.035802381179694615, 0.03204054571688175, 0.08813597887222256, 0.038434150495699475, 0.04061912146529981, 0.03488883895001241, 0.01748577448805528, 0.07251002306916884, 0.005299168929923326, 0.045774335374257395, 0.026906283272962486, 0.04147451324388385, 0.019942505517974496, 0.029993958571659665, 0.09568933570491416, 0.028173956321552396, 0.04612916508423431, 0.024794414273596237, 0.015367142190890653, 0.011122216936200857, 0.007640519744849631, 0.062209698637681346, 0.04820628630529557, 0.03839473778914128, 0.02205307681911758, 0.03320494234295828, 0.054943351939852746, 0.01235157311228769, 0.01681556848676077, 0.014181194444453078, 0.014120601267287773, 0.06760767541293587, 0.045151972877127786, 0.03767864585721067, 0.053717429150960276, 0.02747750628207411, 0.03570034647626536, 0.08549408242106438, 0.016950863280466626, 0.03993174174268331, 0.10215953351663691, 0.0962368795382125, 0.1509138691638197, 2.0127428770065308, 23.135050330843242, 57.206415857587544, 80.94863973345075, 70.9193389075143, 72.9814669745309, 57.56795842306954, 47.826788970402305, 42.82307849611555, 33.92951284136091, 22.692418813705444, 32.67401851926531, 56.82085336957659, 91.79755701337541, 64.80436829158238, 53.7132020677839, 60.51783003125872, 33.859603541237966, 35.99578898293631, 34.10131399972098, 12.13616486958095, 4.845526048115321, 2.6144686000687734, 0.8159192523786, 0.10554405261895486, 0.1595775399889265, 0.5238885283470154, 0.6621678854737962, 0.15133768213646753, 0.06941993388214282, 0.025219816714525223, 0.07015997810023171, 0.08715843382690634, 0.05063518722142492, 0.020995417144149542, 0.03706902964040637, 0.00927315981659506, 0.10551778652838298, 0.06586570638631072, 0.05932840146124363, 0.04635100532323122, 0.07778674563659088, 0.004088153555390558, 0.05633001628198794, 0.10960427724889346, 0.05527403598119106, 0.07280418835580349, 0.045930171119315286, 0.06767990546567099, 0.09867460480225937, 0.17198565203164304, 0.24232708396656172, 0.0685479621003781, 0.0423886831184583, 0.20624715143016406, 0.14657933318189212, 0.15143577115876333, 0.11151578503527812, 0.16275741292962007, 0.14044244534202985, 0.6678705109017236, 1.3353097992283958, 5.909365602902003, 17.31303834915161, 32.634208815438406, 34.52677651814052, 26.8131365776062, 32.79018892560686, 56.96079356329781, 82.64711298261369, 47.619819504874094, 30.474514143807546, 26.135332856859478, 25.239663158144268, 38.702730723789756, 41.298747948237825, 40.40331622532436, 54.108620575496126, 57.9924829346793, 70.66202626909528, 48.76138768877302, 17.426426001957484, 1.2985577370439256, 0.19211291415350779, 0.13400037959218025, 0.08307202453059809, 0.033255907108208964, 0.02549434350138264, 0.08057380786963872, 0.032185982912778854, 0.04308435453900269, 0.11377477739006281, 0.043969968267317326, 0.03247429244220257, 0.05722227626081024, 0.01846889709122479, 0.03787489514797926, 0.08832826212580715, 0.03389583687697138, 0.017567699109869342, 0.07795924280903169, 0.06786907424351998, 0.03787162121651428, 0.04154403594189456, 0.026319567613037567, 0.0703920235059091, 0.040281017643532584, 0.02902474593637245, 0.04185105607445751, 0.026587568589353135, 0.04354235210589, 0.030028278872902905, 0.05472905361758811, 0.006557012974683727, 0.05014181762401547, 0.14446942854140485, 0.037552306029413424, 0.014131767409188407, 0.09856563207826444, 0.05103460007480212, 0.030608965749187127, 0.05753286209489618, 0.01091371160665793, 0.04936288656400783, 0.0952851256089551, 0.016664638549887707, 0.0478227172446038, 0.039325942285358906, 0.03362954580890281, 0.03906108971152987, 0.013951930184183376, 0.0410215063020587, 0.01648087939247489, 0.01933014632335731, 0.024409717148435966, 0.022113091545179486, 0.03934843911390219, 0.07135263910251004, 0.03250508775402393, 0.04675132062818323, 0.020560701810089604, 0.03972241708210536, 0.0285315256166671, 0.01875692163594067, 0.0676808011318956, 0.05666881899482437, 0.03193050430023244, 0.05375990544312766, 0.007113112286398453, 0.018089365313893983, 0.03525661510814514, 0.02104868383945099, 0.0076698731697563615, 0.03161204406725509, 0.06229399304304804, 0.02890897768416575, 0.01349188937872116, 0.007607196041915033, 0.058333051657038074, 0.07056683448276349, 0.008843463945335575, 0.020331591068367873, 0.07296721996473414, 0.018353273027709553, 0.026173445096771632, 0.013728765953731323, 0.09676036251974957, 0.0470592771390719, 0.05533597944304347, 0.06892331410199404, 0.15875678403036936, 0.05692038246031318, 0.019761803160820688, 0.07852570419864995, 0.028069975918957164, 0.04110853859622564, 6.4580122998782565, 43.736169065747944, 79.94584792000907, 93.14789077213833, 82.61440086364746, 92.01108210427421, 82.11964743477958, 74.33366979871477, 63.610598291669575, 40.00044924872262, 18.74995882170541, 20.016589369092667, 41.988089152744834, 55.23194973809378, 58.84455789838518, 57.13098621368408, 53.94948598316738, 33.00941153935024, 30.78587681906564, 24.84019558770316, 6.315260691302163, 1.2874958791903086, 0.6678646483591625, 0.19627412515027182, 0.37880490347743034, 0.4958934762648174, 1.0208904594182968, 0.9429456761905125, 0.13574828580021858, 0.02122234639578632, 0.05902159506721156, 0.11995751384113516, 0.045190547592937946, 0.06184839231095143, 0.0733991414308548, 0.19482343085110188, 0.02157825667278043, 0.23460568115115166, 0.010512202080073101, 0.32102314116699354, 0.18530408665537834, 0.2553263492882252, 0.26370538824370926, 0.07275847545159714, 0.0366636728202658, 0.013805948463933808, 0.035735782967614274, 0.07575611424233232, 0.04088878145973597, 0.056908453814685345, 0.01537954920370664, 0.027703527993123447, 0.024130974962775196, 0.04329349260245051, 0.136387560782688, 0.09030840372932808, 0.07111080922186375, 0.08261137389178787, 0.204251104965806, 0.26305016768830164, 0.38972521892615725, 0.11074766303811755, 2.579135707446507, 11.515094927379064, 23.75052523612976, 26.309904609407695, 22.955395971025737, 37.899348735809326, 67.85006250653947, 80.33481502532959, 38.374431814466206, 23.168238401412964, 21.473492860794067, 32.725379603249685, 51.20924152646746, 61.66484560285296, 62.968299865722656, 69.56921359470913, 67.46901634761265, 84.9402825491769, 70.23395470210484, 36.36421026502337, 4.5722030230930875, 0.07555526787681238, 0.04206940185810838, 0.07735638480101313, 0.02284106971429927, 0.0814909225861941, 0.073314697747784, 0.022369443771562407, 0.06631778034248523, 0.09713886970920221, 0.0329509056173265, 0.03759417164006403, 0.027939452922769954, 0.0522788975919996, 0.006387909325504941, 0.10302024161709206, 0.08057171798178128, 0.0516143064679844, 0.07588058470615319, 0.023314420832321048, 0.03138596298439162, 0.05157325849203127, 0.03421973217544811, 0.04423760962007301, 0.062789818937225, 0.022058739193848202, 0.03322380222380161, 0.05438549437427095, 0.029108460194298198, 0.017628894486863698, 0.06869242220584836, 0.046402516309171915, 0.018890570982226303, 0.029880239495209286, 0.04319487093016505, 0.06740031511123691, 0.052451343874314, 0.08149451882179294, 0.007459266926161945, 0.05700050387531519, 0.05913902233753886, 0.04826016877112644, 0.06421757875276463, 0.01116421740568642, 0.03261899682027953, 0.029964438905673366, 0.01802698928596718, 0.01976606944975044, 0.15223330764898232, 0.14134900883904525, 0.08892540686896869, 0.056415318311857324, 0.11541078638817583, 0.15320634043642453, 0.11930101763989244, 0.10482926347426005, 0.19245048532528536, 0.15617290910865578, 0.17162862047553062, 0.16785121602671488, 0.165513079347355, 0.0905721163643258, 0.15750803532344954, 0.19518732918160303, 0.1117323734132307, 0.14891616707401617, 0.11934390105307102, 0.10169357673398086, 0.11247258726507425, 0.24398764914699964, 0.053899541164615324, 0.10525268968194723, 0.14059655421546527, 0.13033107934253557, 0.11034144447850329, 0.10544687961893422, 0.11436183910284724, 0.0984679094648787, 0.1110634600211467, 0.10886102356016636, 0.16097355793629373, 0.08591514054153647, 0.17437994426914624, 0.12556768208742142, 0.1748886284019266, 0.12828346421676023, 0.21071895504636423, 0.10802708366619689, 0.22752277978828975, 0.18708834876971586, 0.13398015924862453, 0.20585588099701063, 0.16051686315664224, 0.19745312045727456, 3.780500088419233, 38.77889687674386, 84.92086928231376, 104.55399799346924, 87.35053621019635, 90.43919808523995, 79.73205184936523, 63.346198490687776, 55.666893073490684, 41.49578148978097, 29.437478133610316, 41.96381909506661, 75.21896757398332, 112.10825320652553, 82.98543466840471, 71.2744265965053, 87.03909710475376, 52.234660148620605, 52.61922557013375, 46.663215841565815, 17.554939883095876, 8.838252782821655, 4.57891628571919, 2.0186833696705953, 0.8257334200399262, 0.7690753117203712, 1.3632635963814599, 1.2362170879329955, 0.45117492441620144, 0.11274622686739479, 0.22344660280006273, 0.17473470951829637, 0.29265918316585676, 0.21890022818531307, 0.1493309283895152, 0.2433572629732745, 0.1085303598748786, 0.32252406062824385, 0.1947716043463775, 0.5511225355522973, 0.23589962029031344, 0.4271169767848083, 0.2858559196548802, 0.2471407199544566, 0.2620029167405197, 0.16026378316538675, 0.1946257600294692, 0.3550347089767456, 0.161835215985775, 0.26314423978328705, 0.19702372992677347, 0.26366937160491943, 0.13101900528584207, 0.2540998293885163, 0.36392886457698687, 0.4787140552486692, 0.35660543612071444, 0.15678436415536062, 0.5475743945155824, 0.8300316408276558, 1.3830306785447257, 2.3692319308008467, 7.385969843183245, 21.484837532043457, 41.731804847717285, 49.09706211090088, 39.448574679238455, 45.07705674852644, 81.39057295663017, 112.14576653071812, 65.5264459337507, 44.91624764033726, 36.17747742789132, 33.891099725450786, 48.66853543690273, 56.080759048461914, 59.02540561131069, 70.24456460135323, 75.2270622253418, 95.462829044887, 76.50307805197579, 33.43048627035958, 3.0681004183632985, 0.2885887601545879, 0.16657843360943453, 0.19027871186179773, 0.12579642981290817, 0.19561544406626905, 0.19728253675358637, 0.13061895460954734, 0.1494003425219229, 0.31241646728345324, 0.13138489850929805, 0.21441892507885182, 0.14101117982396058, 0.11817745864391327, 0.09089996412928615, 0.24070717660444124, 0.1638603037489312, 0.09228595332907778, 0.2739658962403025, 0.12736312645886624, 0.14864592014678887, 0.10489479638636112, 0.06167155929974147, 0.22934288212231227, 0.24664373376539775, 0.1631337691630636, 0.12376690443073, 0.1304680077092988, 0.15399190756891454, 0.0947177889091628, 0.1123590480004038, 0.1453209492777075, 0.07469595077314548, 0.18894275783428124, 0.13780062352972372, 0.16084999670939787, 0.2752770430275372, 0.21800818533769675, 0.07577065524778195, 0.13943480726863655, 0.19411296397447586, 0.14117895439267159, 0.13292311025517328, 0.07850937186075108, 0.16449890019638197, 0.08232785481959581, 0.1263939748917307, 0.13161015856478894], [0.054188966884144714, 0.05410122212820819, 0.12860405844237122, 0.022770992313910807, 0.021067501311855655, 0.04698015656322241, 0.03817621558638556, 0.024678741016292145, 0.022961309512278864, 0.04729072204125779, 0.0261436404460775, 0.04028574703261256, 0.11522801619555269, 0.050346507890416045, 0.059617613442242146, 0.008919171490041273, 0.04188656720465847, 0.039547999655561786, 0.05662635288068226, 0.0311479091511241, 0.04589151158662779, 0.08771040170852627, 0.055858339449124675, 0.010119207319803536, 0.047488508213843615, 0.053632829404835186, 0.030264649939324175, 0.026624279030199562, 0.03219006769359112, 0.028228802307109748, 0.06184329651296139, 0.051180753125143905, 0.07494076620787382, 0.025924590682344775, 0.02197642102172332, 0.06673769173877579, 0.07462604131017413, 0.035705591551959515, 0.059280252616320334, 0.0890013077961547, 0.06653503368475608, 0.058734072638409476, 0.005382654182280281, 0.2084105382008212, 0.2140341821525778, 16.099365234375, 57.783731256212505, 76.12857014792306, 75.68804046085903, 70.54984760284424, 64.52285507747105, 56.71695695604597, 39.16775975908552, 33.85190493719918, 35.926376479012625, 37.27951036180769, 59.74669115883963, 62.54772540501186, 49.09131595066616, 51.941334996904644, 29.531522001538956, 23.092638526644024, 23.865028074809484, 26.358382190976823, 7.6622224024363925, 0.35833458762083736, 0.11491868565125124, 0.06654945255390235, 0.11987619820450034, 0.05947514822972672, 0.05215759249404073, 0.077580660980727, 0.18793403410485812, 0.37836078873702456, 0.07829728895532233, 0.0845288595716868, 0.029093912403498377, 0.05738188126789672, 0.12906954703586443, 0.1091104055355702, 0.09119636179613215, 0.2985403175864901, 0.1599698146539075, 0.15653573535382748, 0.3524947352707386, 0.16319931564586504, 0.16131654381752014, 0.08531910181045532, 0.05600647382172091, 0.06151681260338851, 0.21619626613599913, 0.21763959154486656, 0.11835813894867897, 0.15462807486099855, 0.11759201862982341, 0.16321462339588574, 0.2511554759527956, 0.14800477240766796, 0.16939678309219225, 0.18063143667365822, 0.2217994454715933, 0.22112872717635973, 0.24286179670265742, 0.07144436346633093, 0.07411262778831379, 0.05565638028617416, 0.06272518847669874, 0.0127057259835835, 0.18454214611223765, 0.3739964786384787, 0.1918288522533008, 4.64690397466932, 13.246806621551514, 22.464399780545914, 14.452043754713875, 17.478705985205515, 40.52674055099487, 54.17759534290859, 50.42941393171038, 39.78659759249006, 30.995041915348597, 22.02990981510707, 32.62386989593506, 49.41888877323696, 45.24450486046927, 46.43006208964756, 58.71656513214111, 67.30598381587437, 41.159735339028494, 9.603318929672241, 0.059538367337414196, 0.38481248968413895, 0.05331671690302236, 0.03899138380906411, 0.06940680422953197, 0.07639451391462769, 0.028913293166884353, 0.030519063251891305, 0.04235560792897429, 0.028075076805959855, 0.051751129661819766, 0.03932112129405141, 0.05705024049218212, 0.04200875100546649, 0.02250152061294232, 0.039432594419590065, 0.02417294744269124, 0.048552620756839, 0.030651771130838563, 0.086365796359522, 0.02847616733717067, 0.01877886545844376, 0.030189464866582836, 0.01833481348252722, 0.03586859941216452, 0.03438938628616078, 0.033130978633250506, 0.04101916535624436, 0.00975511730315962, 0.05097007817987885, 0.09408419326479946, 0.04724896499621017, 0.04838012697707329, 0.04310004905398403, 0.032847089759473286, 0.010532127260895712, 0.07659755194825785, 0.047932215833238194, 0.03535818840776171, 0.02528299850278667, 0.005076590360009244, 0.00040871840454721157, 0.12685307168534823, 0.015286028418423874, 0.06882675856884037, 0.03068437473848462, 0.014430668870253223, 0.03252302821991699, 0.05324668191107256, 0.022640755998768976, 0.04069415386766195, 0.0028533504394415233, 0.051977770536073616, 0.06943147576281003, 0.054219836834818125, 0.018659731672544564, 0.052994921670428345, 0.034960672059761624, 0.04322166967072657, 0.011935443700557309, 0.04016872009794627, 0.05276130884885788, 0.03778215976698058, 0.038045217615685294, 0.028517520653882196, 0.07061737177095243, 0.011848555595081831, 0.008041468631875302, 0.04708219126665166, 0.006712962374357241, 0.04104553322706904, 0.02720400069041976, 0.03286742206130709, 0.03026221739128232, 0.07972346099891833, 0.011459483615388828, 0.03538727041866098, 0.023333207770649875, 0.011443152125658733, 0.018482635729014874, 0.02090805915317365, 0.059240673668682575, 0.05340300280866878, 0.07871701714715787, 0.023002844337107878, 0.08028652971344334, 0.04386212191145335, 0.05652671340586884, 0.01405170451783176, 0.14444501485143388, 3.143992985997881, 35.543117318834575, 79.43322372436523, 86.33677319117955, 86.1023062297276, 86.81011227199009, 87.8387930733817, 78.69124644143241, 56.49083130700247, 43.83561863218035, 35.74221447535923, 21.14431847844805, 37.760704381125315, 55.108865874154226, 56.69682802472796, 55.71739952904837, 31.080004487718853, 16.73753990445818, 14.142062902450562, 15.477492775235858, 3.753313958644867, 0.27109352179935997, 0.2105403917708567, 0.07213230298033782, 0.055742184431957345, 0.040802135930529664, 0.04621408713449325, 0.09417783788272313, 0.12290878833404609, 0.17630014408911976, 0.08903503098658153, 0.08620106162769453, 0.09074829798191786, 0.06600858550518751, 0.08723352051206998, 0.1335360309375184, 0.30807908145444735, 0.39818660489150454, 0.32692742720246315, 0.4809049633996827, 1.0060625693627765, 0.4504656381905079, 0.47431242572409765, 0.3248764601136957, 0.10292339431388037, 0.3770405224391392, 0.29864568050418583, 0.37725192680954933, 0.2995845286973885, 0.2778933383524418, 0.190134998144848, 0.29028061937008587, 0.17966404929757118, 0.15843838825821877, 0.07428154908120632, 0.02777280132951481, 0.09650663792022637, 0.1723583306052855, 0.18763085108782562, 0.11625120629157339, 0.10334365854838065, 0.10688216438783066, 0.04116066026368311, 0.007523651417743946, 0.1333881238741534, 0.4626377150416374, 0.10272899403103761, 2.0598714223929813, 4.182584089892251, 9.906276021684919, 10.576336843626839, 22.602747099740164, 50.49674892425537, 56.766671316964285, 33.42626871381487, 16.45125675201416, 22.98233413696289, 24.55052866254534, 50.168870380946565, 76.42402839660645, 73.24968133653913, 65.24982425144741, 71.2159366607666, 78.04885074070522, 62.08289786747524, 20.661495106560842, 0.6413055935076305, 0.32535927849156515, 0.030537471906947236, 0.02695393339464707, 0.013047584648510175, 0.04675897789586868, 0.025957765955744044, 0.04044236648561699, 0.014576201061052936, 0.02353554860954838, 0.03802966898573296, 0.06509103652622018, 0.08830289170145988, 0.05021036323159933, 0.012257678284575897, 0.04720644120659147, 0.06920599179076296, 0.05874651697065149, 0.07129450900746243, 0.030904427037707398, 0.08050969988107681, 0.019323827465996146, 0.08754967711865902, 0.04751565979261484, 0.08354963854487453, 0.0618081483989954, 0.04446693070765052, 0.0555567577747362, 0.029626117952700173, 0.029860314314386675, 0.115271035315735, 0.04008470389193722, 0.028983280661382844, 0.027716314985549877, 0.08204345365187951, 0.02104076703212091, 0.04521685100293585, 0.0349187148468835, 0.03801412035578063, 0.0412523880201791, 0.0409661785566381, 0.01897507912612387, 0.06780871176826102, 0.03827943094074726, 0.037693532915519815, 0.03394218760409525, 0.1333058311470917, 0.1399926444781678, 0.21696501917072705, 0.07907428619052682, 0.12724264578095504, 0.10443643919591393, 0.15680602299315588, 0.13827105185815267, 0.13834058812686376, 0.13211380796773092, 0.11769474883164678, 0.1891192855047328, 0.11725839653185435, 0.15789691731333733, 0.0911583366936871, 0.1422828087317092, 0.15624914930335113, 0.08115101725395236, 0.1054043694000159, 0.11989400296338967, 0.1598093139805964, 0.16769408088709625, 0.17954637775463717, 0.0877804197371006, 0.11341544560023717, 0.14341305808297225, 0.07211576029658318, 0.1636031118354627, 0.13321584383291857, 0.0706677326400365, 0.1531880878444229, 0.12243198177644185, 0.1891292735402073, 0.11836942977138928, 0.24466604845864431, 0.16411305804337772, 0.30115330166050364, 0.12302126229873725, 0.11428360401519708, 0.1376615102802004, 0.1596455563391958, 0.20764289796352386, 0.07775258818375212, 0.21814102892364773, 1.615138292312622, 29.831545216696604, 83.40329933166504, 99.91214275360107, 92.23060349055699, 86.2764002936227, 85.76108019692558, 71.1430778503418, 48.05474546977452, 39.403967244284495, 49.51483992167881, 50.75176518304007, 79.95059353964669, 85.12552847181047, 65.58713844844273, 71.9306492124285, 45.85913903372628, 36.90602036884853, 34.51312678200858, 34.36819083350045, 10.657194767679487, 1.1723300303731645, 0.6874004315052713, 0.2861615318272795, 0.19561188854277134, 0.2220131704317672, 0.12200196699372359, 0.23256331788642065, 0.22871420585683414, 0.37256403693131035, 0.16004927110459122, 0.32590463065675324, 0.2506902723440102, 0.400814028190715, 0.5173502191901207, 0.5481176567929131, 0.732114097901753, 0.4987820269806044, 0.7005626537970134, 1.0704439261129923, 0.8552021416170257, 0.6056529209017754, 0.44660032274467604, 0.6247141637972423, 0.6141798262085233, 0.4916692429355213, 1.0215861478022166, 1.1710183407579149, 0.7575176890407289, 0.6001685123358453, 0.6888632987226758, 0.6019791694624084, 0.6840447772826467, 0.5422562541706222, 0.5757242068648338, 0.7772589868732861, 0.5842368900775909, 0.6449050860745567, 0.5720637004290308, 0.28024728489773615, 0.2772233528750283, 0.2557620501943997, 0.13113253776516232, 0.1047276799966182, 0.2694630021495478, 0.715565388756139, 0.6645697365914072, 6.381187805107661, 18.265174320765905, 30.95203604016985, 22.053844622203282, 24.64251238959176, 57.61609901700701, 74.12653705051967, 66.53977121625627, 50.819291251046316, 44.584495476314, 31.908691814967565, 41.205141816820415, 66.42719650268555, 63.85976069314139, 61.68452984946114, 76.16968958718437, 88.17563479287284, 66.33810670035226, 17.95221355983189, 0.2971613444387913, 0.5689895025321415, 0.10612730096493449, 0.14428311639598437, 0.14435429471944058, 0.14713978953659534, 0.15500977795038903, 0.09465972666761704, 0.21208943293562957, 0.1321832492415394, 0.14479414825992926, 0.11960517774735178, 0.13687727307634695, 0.19256817043891974, 0.15916081092187337, 0.18327066648219312, 0.10249396985662834, 0.1589056003306593, 0.08570373617112637, 0.12506167138261454, 0.12240427040628024, 0.1251910680106708, 0.21738406882754394, 0.11294714108641658, 0.15987924379961832, 0.1803173292428255, 0.13884442751961096, 0.2087425182440451, 0.08761128131300211, 0.1332909440887826, 0.16756214653807028, 0.11566208861768246, 0.1665258471454893, 0.10933956716741834, 0.1808198658483369, 0.06901804437594754, 0.15294796787202358, 0.1339488380721637, 0.1395727398672274, 0.09390639673386302, 0.1646080764808825, 0.16272910444864205, 0.2303539535828999, 0.06394051254859992, 0.20825788139232568, 0.11439400166273117], [0.023453164280259182, 0.026770655997097492, 0.03705544197665794, 0.06090594109679971, 0.010501730588397809, 0.07151303799556834, 0.039054796299231906, 0.02764353871212474, 0.03470036227788244, 0.09594715187059981, 0.008063999387169523, 0.03901654728023069, 0.014305502908038241, 0.048826677658196004, 0.008698192990518041, 0.04623881634324789, 0.04285399529284664, 0.011211321306680995, 0.021164630207100084, 0.04014440140287791, 0.016441302141174674, 0.033794087158249955, 0.031497768592089415, 0.020813026931136847, 0.07130573197667088, 0.041364000245396576, 0.02539381684203233, 0.027331828206245388, 0.04739362187683582, 0.011020243300923278, 0.05309468667422022, 0.04021971539727279, 0.018774395609008412, 0.0462502598363374, 0.030255883266883235, 0.06873578737889018, 0.033622801170817444, 0.09269617524530206, 0.07176288137478487, 0.08693721784012658, 0.33670774953705923, 0.03351928047569735, 0.22845006574477467, 10.307321701731, 44.8675650869097, 82.62018176487514, 72.68020698002407, 71.21891048976353, 58.06059612546648, 54.24493728365217, 45.02352087838309, 38.01449080875942, 36.086021763937815, 35.42709629876273, 47.510691097804475, 55.14581639426095, 37.80876507077898, 28.84623680795942, 26.304356472832815, 23.847949402672903, 18.950016566685267, 9.976010748318263, 2.295530434165682, 0.24449391769511358, 0.5716420859098434, 0.03148745146713086, 0.06664281897246838, 0.01736559745456491, 0.0709301017756973, 0.07866742302264486, 0.1264005566814116, 0.07735793186085564, 0.14706971043986933, 0.24342631069677217, 0.12348485099417822, 0.06933992781809398, 0.07687900148864303, 0.11844847910106182, 0.02657637615422053, 0.22140578659517424, 0.08531862683594227, 0.07454933971166611, 0.19429565274289676, 0.41034847657595364, 0.03173987667209335, 0.3036731093057564, 0.33520522873316494, 0.17145724967122078, 0.2739706188440323, 0.08974819843258176, 0.18228894844651222, 0.08384433987417392, 0.01505735024277653, 0.13693298080137797, 0.0616132595709392, 0.09756503041301455, 0.05040597469945039, 0.04519074436809335, 0.05618709645101002, 0.059618285191910605, 0.06696360318788461, 0.07015693826334816, 0.04980728968179651, 0.007504978134030742, 0.076157399852361, 0.01906752952241472, 0.1288509773356574, 0.02561802007923169, 0.1791895090469292, 0.3115989954343864, 0.018040826311334968, 0.03225252005670752, 0.1554563489875623, 2.7455993465014865, 21.75351221220834, 24.218595845358713, 13.0406813621521, 19.161248752049037, 41.461909021650044, 66.46515451158795, 87.33984293256486, 50.103227274758474, 20.095593861171178, 21.07662912777492, 32.166244166237966, 36.76794924054827, 46.66629041944231, 50.625655378614155, 59.89105388096401, 60.647261074611116, 31.929136889321462, 6.14297446182796, 0.07049580543701138, 0.12566923163831234, 0.016508767181741338, 0.06764093719955001, 0.02192386339551636, 0.03417060624009796, 0.023531952373949543, 0.05343381169119051, 0.03230472993371742, 0.030339458425130163, 0.04220779246783682, 0.034701274907482524, 0.021885824722370932, 0.028756256414843456, 0.04247686892215695, 0.02695036769312407, 0.04067108028435281, 0.03166227601468563, 0.05070860131776758, 0.029933616452451264, 0.07084014838827507, 0.07771538410867963, 0.007645424704865685, 0.06810976418533496, 0.012461688319620277, 0.023037999236424054, 0.06762830966285296, 0.053734412882477045, 0.02020450315571257, 0.06072849740407296, 0.029840518055217605, 0.03370889708665865, 0.09298270701297692, 0.06801359541714191, 0.04353477965508189, 0.023130135810268775, 0.04357062326744199, 0.012987149230736707, 0.04960599548316427, 0.055875177295612435, 0.041653222404420376, 0.03771289151960185, 0.06956151699913399, 0.029464246638651406, 0.10579980603818383, 0.05354444343330605, 0.08159482665359974, 0.05418448176767145, 0.020711892982944846, 0.030645491289240972, 0.020176801963576248, 0.037038342894187996, 0.010046001872979105, 0.02503616612271539, 0.05963815948260682, 0.0249333952087909, 0.060545415085341246, 0.049183023893939595, 0.04247529132823859, 0.04490631605897631, 0.09385200536676816, 0.04391704932121294, 0.0789776017357196, 0.08941496988492352, 0.010271457007287868, 0.04685913644997137, 0.005176268426501858, 0.03402380179613829, 0.029893257189542055, 0.022196332524929727, 0.014053648520660187, 0.012353650277613528, 0.06077539095921176, 0.04442135351044791, 0.0423958111288292, 0.039190533837037425, 0.01525730942375958, 0.013640747239281024, 0.08087055837469441, 0.02958555512928537, 0.13364801635699614, 0.005339514622132161, 0.08186787593045405, 0.14103673345276288, 0.13289249475513185, 0.17343018523284368, 0.6379213322486196, 26.258211748940603, 71.003801209586, 93.49710723331997, 85.02221570696149, 93.13544654846191, 80.29716968536377, 77.41514723641532, 65.57034465244838, 37.3581987108503, 30.010110446384974, 15.478924104145594, 30.009533745901926, 64.41611685071672, 50.424935817718506, 34.43125268391201, 21.563489403043473, 11.605471014976501, 6.834437472479684, 3.020457272018705, 0.5776432124631745, 0.570355692080089, 0.5507473328283855, 0.03441345053059714, 0.05906243608998401, 0.0606061846816114, 0.06523413277630295, 0.05517039993511779, 0.04737643458481346, 0.04887328962130206, 0.15898861230484077, 0.20023955165275506, 0.033964779427541156, 0.09992971138230392, 0.14429330799196446, 0.11929587434445109, 0.10368102615965263, 0.27206018992832726, 0.057179766041891913, 0.15373432210513524, 0.1925272276358945, 0.2972027893577303, 0.17430446403367178, 0.608053197818143, 0.7080546574933189, 0.6990448523844991, 0.41920390139733044, 0.2348104901611805, 0.26360738064561573, 0.08429530103291784, 0.13708867744675704, 0.16071314976683684, 0.02786462238457586, 0.04544838072199907, 0.04252306019355144, 0.02620987394558532, 0.024409301545737044, 0.0821803073797907, 0.05338582230199661, 0.08616424431758267, 0.05619901152593749, 0.04700916054259453, 0.08998740916805607, 0.04450385658336537, 0.15390721282788686, 0.0245190172655774, 0.12150952698928968, 0.24076561204024724, 0.03471344443304198, 0.01689306566757815, 0.15984938825879777, 1.0319602425609316, 8.024086322103228, 7.336370127541678, 8.703164168766566, 22.580156769071305, 48.686305454799104, 55.06372342790876, 63.4962100982666, 33.30220167977469, 18.856017862047466, 28.15395998954773, 46.19698476791382, 59.37152317592076, 72.78652831486293, 68.18519496917725, 72.70292064121791, 75.0910164969308, 51.51920413970947, 16.08389159611293, 0.3182541754628931, 0.11981690781457083, 0.04204361413472465, 0.029457905728902136, 0.07957219518721104, 0.014594657213560172, 0.048069568284388096, 0.02260185219347477, 0.019815069856122136, 0.015396102065486568, 0.06429696056459631, 0.08553338995469467, 0.03221291396766901, 0.040301353338041475, 0.03076138167775103, 0.0030995515699032694, 0.030305877727057253, 0.01144713003720556, 0.06811694308583226, 0.029490438090371232, 0.022685415477358868, 0.033704530713813644, 0.04507768347061106, 0.098498375687216, 0.07990226176168237, 0.08192069988165583, 0.03167094769222396, 0.021908353781327605, 0.014293043308758309, 0.029384579842111895, 0.04578338363873107, 0.05348933281909142, 0.025650082555200373, 0.027597454309995686, 0.008946167853926974, 0.08156038421605315, 0.048450250178575516, 0.03554920619353652, 0.008136188727803528, 0.049721315902258666, 0.026888213885415877, 0.014952911829043711, 0.060147915700716634, 0.06544877375875201, 0.2161485379827874, 0.1403752975165844, 0.10798167610274893, 0.13636062294244766, 0.1318208301173789, 0.11475498229265213, 0.16124408984822886, 0.1438852506024497, 0.17201337697250502, 0.16167912579008512, 0.1796038496707167, 0.09171979049486773, 0.13423621122326168, 0.14678226943526948, 0.11006566749087401, 0.15339419964168752, 0.2013952053551163, 0.10368576911943299, 0.12610115988978318, 0.13515504263341427, 0.06126053671219519, 0.1669484387551035, 0.10786006227135658, 0.09419907602880682, 0.22929134060229572, 0.13554354464369162, 0.11713745445013046, 0.13730529296611035, 0.13728713536901133, 0.07192890532314777, 0.13465606155140059, 0.1399382259696722, 0.09842047986707517, 0.15647797845304012, 0.11163036924387727, 0.1470298668635743, 0.18732413968869618, 0.20506909250148705, 0.2093785498291254, 0.1825730103467192, 0.3995027185550758, 0.17482567392289639, 0.2768258942025048, 19.730090822492325, 75.27919455936977, 107.54963043757847, 91.43953023638043, 90.19895022256034, 78.67341041564941, 76.17676285334996, 58.118377344948904, 47.60856342315674, 48.98822900227138, 50.49717971256801, 64.47986657278878, 78.00399317060197, 53.19360882895333, 41.048755237034385, 38.949780872889924, 32.20936121259417, 25.638175351279124, 13.906065600258962, 3.8087740455354964, 0.8033988699316978, 0.7383508660963604, 0.1495509230132614, 0.262356162071228, 0.24654059644256318, 0.31435360333749224, 0.28397773472326143, 0.25427429431251114, 0.24000364435570581, 0.3120515782918249, 0.29568040104848997, 0.3268539554306439, 0.20610297630940164, 0.23825961936797413, 0.2783338432865483, 0.244574636220932, 0.49358162603207995, 0.4659254071967942, 0.2558196713881833, 0.817612170108727, 0.9025227395551545, 0.24677593952843122, 1.2895943437303816, 1.551854208111763, 1.2193178747381483, 0.5800336099096707, 0.7084670982190541, 0.4271133398371083, 0.5487731216209275, 0.22769713614668163, 0.33238887414336205, 0.10675065073051623, 0.2186024055949279, 0.18108674724187168, 0.1201207557959216, 0.1337392521756036, 0.32645106847797123, 0.12251298528696809, 0.3374423858310495, 0.23362156110150473, 0.13905633400593484, 0.28831756327833447, 0.24997637208018983, 0.5148817630750793, 0.2968485126537936, 0.303799751081637, 0.3663961264703955, 0.16920139214822225, 0.14525836120758737, 0.31240764632821083, 4.812801335539136, 30.45498275756836, 32.265714577266145, 18.93651795387268, 28.817228078842163, 60.14185605730329, 93.5422010421753, 106.10171617780412, 60.72937488555908, 30.036763736179896, 26.920760699680873, 40.6066517829895, 49.8098326410566, 64.60773427145821, 67.13418960571289, 78.7017799104963, 84.25218159811837, 52.56657559531075, 12.14589147908347, 0.13920740304248674, 0.22210633328982762, 0.28475688291447504, 0.115002946129867, 0.15091183355876378, 0.10091727160449539, 0.1449655054935387, 0.15242350101470947, 0.09921415549303804, 0.18485470648322785, 0.11300630255469254, 0.1681069287338427, 0.1491030491888523, 0.1874409969896078, 0.1760720070451498, 0.09964524236108575, 0.12376549307789121, 0.10798402383391346, 0.1288392658212355, 0.16798070764967374, 0.2057218567601272, 0.13909003005496093, 0.11182184504078967, 0.17393266755555356, 0.0825428825670055, 0.1616364595081125, 0.09250469266303948, 0.18267112651041575, 0.09872803943497793, 0.17506230622529984, 0.21583529907677854, 0.11842231479074274, 0.17344727074461325, 0.1984537560492754, 0.09917685642306294, 0.16783921952758515, 0.2094601368797677, 0.09448762983083725, 0.10186224696891648, 0.11654628760048322, 0.08436100357877356, 0.10461449357015745, 0.13400162809661456, 0.14806221718234674], [0.026279812246294956, 0.01910882007463702, 0.03983487747609615, 0.027887297328561544, 0.019473698888240114, 0.04627342502187405, 0.06750898249447346, 0.029656071881098405, 0.06560292334428855, 0.030868461289043938, 0.021654622396454215, 0.034737359399774244, 0.04193934026573386, 0.033246648497879505, 0.048475132057709355, 0.028602900715278726, 0.048227649980357716, 0.05933973299605506, 0.02976417268759438, 0.02272070778001632, 0.03691261374790754, 0.048135996862713776, 0.03377345630100795, 0.04501560090907982, 0.06374820893896477, 0.05891582502850464, 0.009968017843285841, 0.04304917589096086, 0.029330062946038585, 0.04112333405230727, 0.019357313169166446, 0.04385621865679111, 0.022936695654477392, 0.013764878435592567, 0.018800761783495545, 0.017268755240365863, 0.07217340863176755, 0.07270822993346623, 0.13911345308380468, 0.03199356055951544, 0.1743948720395565, 1.3906930216721125, 25.500661815915787, 75.52755096980503, 75.52007470812116, 65.06537737165178, 74.01503235953194, 49.94744518824986, 40.83937127249581, 33.88739633560181, 30.797831194741384, 40.5529283114842, 39.51082706451416, 60.523736000061035, 51.92475312096732, 20.036697455814906, 22.07917080606733, 36.24965531485421, 34.589119229997905, 9.130808421543666, 0.5511562994548252, 0.21233529331428663, 0.23919298499822617, 0.14492089860141277, 0.46967488314424244, 0.1045358038640448, 0.09931782885853734, 0.03177914349362254, 0.06332283533577408, 0.06394933350384235, 0.08365748490073852, 0.1762465533933469, 0.13322340271302632, 0.16188263201287814, 0.028979606394256865, 0.01617124181107751, 0.05704604036041668, 0.045015007190938504, 0.16770112408058985, 0.11386023887566157, 0.07397956707115684, 0.4781077706388065, 0.0664473669603467, 0.12240767665207386, 1.302169388958386, 0.36922651316438404, 0.8231807712997709, 0.5070118967975888, 0.44879945474011557, 0.10884149532232966, 0.35978548548051287, 0.06417651381343603, 0.1883818129343646, 0.1249450176422085, 0.03367555048316717, 0.015987129815454994, 0.036385459891919575, 0.05295337836391159, 0.03540403362629669, 0.030255482931222235, 0.07522858040673391, 0.05857816564717463, 0.07118134972240243, 0.025905108245621835, 0.031256817414292266, 0.04733246212292995, 0.05876520382506507, 0.040152174021516523, 0.04563193801524384, 0.08291203275855098, 0.1106503407603928, 0.08158125595322677, 0.06081230326422623, 0.09552265357758317, 0.48072235605546404, 4.381619581154414, 18.595813035964966, 22.465612241200038, 16.038129023143224, 20.732780150004796, 45.5553742136274, 70.2072388785226, 54.94238008771624, 34.290298053196494, 28.038321120398386, 18.56541814122881, 32.67182288851057, 39.80450657435826, 54.17406913212368, 46.34619038445609, 61.605855396815706, 54.245163100106375, 28.216964517320903, 1.414016604423523, 0.19195432694894926, 0.05939620068030698, 0.020688534414927875, 0.06502673854785306, 0.03117655011426125, 0.027954899772469486, 0.04730589747694986, 0.0072023862906332526, 0.08407094342900173, 0.019669525790959597, 0.03820552151384098, 0.0497899768607957, 0.024461674271151423, 0.0809493362903595, 0.056958441489509175, 0.06342051045170852, 0.03749015561438032, 0.07206670900008508, 0.01663228091118591, 0.045819288319242854, 0.05590708879753947, 0.03605393446715815, 0.05244522688112088, 0.011823466762767305, 0.026230513284515058, 0.05751838215759822, 0.027840106914352094, 0.036032021178730896, 0.05745371098497084, 0.062476593601916514, 0.03553988990773048, 0.05138635941381965, 0.023135480969878178, 0.010821504634805024, 0.028962897469422648, 0.03162054271836366, 0.01740144276326256, 0.056384417827108076, 0.05349144306299942, 0.0403764943060066, 0.024892067337142568, 0.029299505121473755, 0.04797867851864014, 0.04702084830829075, 0.014971328965787376, 0.01594046696222254, 0.03067527219120945, 0.12771094350942544, 0.06229820674551385, 0.047778439441961904, 0.01869500701182655, 0.009355494103926634, 0.01869572965162141, 0.016372612344899347, 0.004079118437532867, 0.08475220615842513, 0.07765477736081396, 0.02608195143485708, 0.04063338766406689, 0.006511480306341712, 0.007067425251339695, 0.04638244863599539, 0.05894031335732766, 0.05221996343295489, 0.044116413087717125, 0.029981534595468214, 0.044575927180371115, 0.06348843180707522, 0.05835893776799951, 0.013558793779728668, 0.023883268968867402, 0.10933010838925838, 0.015007818882752742, 0.039846477032239945, 0.02622380935853081, 0.03296903607302478, 0.013149441236497035, 0.025569832218544822, 0.03423642074423177, 0.11190225822584969, 0.030017293390950987, 0.08858506048896483, 0.18011011821883066, 6.655847924096244, 47.96902206965855, 90.21516036987305, 83.07565702710832, 83.12629549843925, 98.24431106022426, 75.3086827141898, 57.001770564488, 56.00230346407209, 39.1204321043832, 25.559638125555857, 26.32110857963562, 60.680619376046316, 70.15441172463554, 24.291784695216588, 15.109959125518799, 15.440233060291835, 13.612595404897418, 2.322908942188535, 0.3434696766946997, 0.2561633900872299, 0.006541710737760046, 0.1544067503086158, 0.5399088487029076, 0.04073766492573278, 0.09956126686717783, 0.04129117986719523, 0.09359887109271117, 0.03740761861471193, 0.14597067369946412, 0.11266413091548852, 0.27535203471779823, 0.1354262259389673, 0.055300709192774126, 0.04167285242250987, 0.13053259067237377, 0.04403933829494885, 0.18600983092827456, 0.059177793828504424, 0.16262075597686426, 0.06553937175444194, 0.09688973200640508, 0.32155826102410046, 0.12182387869272913, 0.37685807794332504, 0.3493783324956894, 0.2959030962416104, 0.41384309477039743, 0.17380834636943682, 0.3198636605271271, 0.511475951543876, 0.703223813857351, 0.33206697713051525, 0.21580418146082334, 0.14744496744658264, 0.0188560589948403, 0.13864007991339478, 0.06259714213332959, 0.09392054418900184, 0.15327103196510247, 0.18896352100585187, 0.03349850373342633, 0.049383435997047594, 0.017080276871898344, 0.04061118260558162, 0.06163276745272534, 0.01289439179734992, 0.061732342466712, 0.1934170313179493, 0.049186392820307186, 0.09639653882810048, 0.1035612647288612, 0.11980606482497283, 0.3676652583692755, 1.7900773222957338, 6.683305033615657, 7.870722208704267, 11.434654763766698, 22.416370357785905, 47.83333764757429, 61.892558915274485, 24.85187724658421, 17.735910926546367, 19.28046246937343, 17.978045225143433, 44.76932798113142, 60.42710740225655, 80.91381536211286, 62.302572114127024, 71.2167079108102, 69.11081314086914, 47.951404912131174, 7.772643174443926, 0.14411189486937864, 0.05392070806452206, 0.03223182813131383, 0.07304057638560023, 0.007708548817650548, 0.04796718752809933, 0.024611510070306913, 0.025115719264639274, 0.026393811218440533, 0.05615610097135816, 0.04866031104964869, 0.06003306007811001, 0.02376601642130741, 0.005310339736752212, 0.04712521717218416, 0.07182494018759046, 0.03517241569768105, 0.014042612996750643, 0.06187435306076493, 0.0675190044566989, 0.02859474133167948, 0.008980255756926323, 0.017398469083543335, 0.04848341697028705, 0.02076653201532151, 0.022644143584849577, 0.03782698379031249, 0.04290943838922041, 0.05299887413691197, 0.028635053097137382, 0.017603639413469603, 0.059393608676535745, 0.014759899150314075, 0.023387782342199768, 0.013911927152158958, 0.019085117150098085, 0.035121539141982794, 0.05365861712821892, 0.03143671740378652, 0.05187327275052667, 0.030902846051113944, 0.0269597416544067, 0.10171312532786812, 0.13601473293134145, 0.11016255550618682, 0.059904959451939375, 0.09000488823013646, 0.1612024006566831, 0.1614555756428412, 0.11680490443749086, 0.22888598378215516, 0.14505724342805998, 0.15853883858237947, 0.11376660782843828, 0.09247648596231427, 0.08656419321362462, 0.1620024341557707, 0.12372184970549174, 0.15702139000807488, 0.07888160938663141, 0.11985235448394503, 0.18682076169976167, 0.12648588924535684, 0.11405735329857894, 0.18208430228488787, 0.11884379360292639, 0.12134678715041705, 0.14162602754575865, 0.12529089408261435, 0.09884115122258663, 0.1173196682440383, 0.1522714684584311, 0.0838679393221225, 0.0704124066978693, 0.13179510006947176, 0.12959144903080805, 0.08505496169839587, 0.15039238786058767, 0.15728497372141906, 0.15394109886671814, 0.24947539610522135, 0.2996702140995434, 0.2599892147949764, 4.040545540196555, 45.74904830115182, 104.34615652901786, 94.67636939457485, 82.3627301624843, 94.08887141091483, 66.96693951742989, 53.72898837498256, 43.0531507219587, 42.758699962071006, 58.715196337018696, 51.36403349467686, 83.42351164136613, 76.34806374141148, 28.748628514153616, 33.7203824860709, 50.47040830339704, 44.02551984786987, 14.545616882187979, 1.3625049399478095, 0.6045789899570602, 0.39337071616734776, 0.285124703177384, 0.8543326397027288, 0.304685999240194, 0.3157597721687385, 0.24632433376141957, 0.28388287552765434, 0.17416129314473697, 0.30483543979270117, 0.3737491933362824, 0.3401201564286436, 0.2916095166334084, 0.19778838460998877, 0.200875352535929, 0.257354734731572, 0.2020144635545356, 0.47154590274606434, 0.6721275853259223, 1.0764672543321336, 1.0497050732374191, 0.8174440019897052, 1.0462398763213838, 2.9140840428216115, 1.668610651578222, 1.7314973856721605, 1.5558166354894638, 1.4597015529870987, 0.24960757472685405, 0.7877152115106583, 0.706172509917191, 0.8971701296312469, 0.5982453269617898, 0.3907675029976027, 0.2703862983201231, 0.32935454696416855, 0.34039330748575075, 0.4586573200566428, 0.28123916738799637, 0.5608418168766158, 0.5781285007085118, 0.29083932510444094, 0.1299369726330042, 0.1945096898291792, 0.1407112537750176, 0.14541469567588397, 0.12456727719732694, 0.13508687700544084, 0.27452316348041805, 0.347223305276462, 0.3891264796257019, 0.21554844161229475, 0.3243144159870488, 1.095094506229673, 8.82165787901197, 27.71045126233782, 31.529445239475795, 23.92036005428859, 30.019233431134904, 63.78906972067696, 92.95838560376848, 72.2758218220302, 47.59567104067121, 40.08158336366926, 25.898395810808452, 40.82505103519985, 51.757193837847026, 71.90237004416329, 61.88269942147391, 79.54302610669816, 76.69998305184501, 48.83377054759434, 6.1263934544154575, 0.17818712283458027, 0.1373488956264087, 0.2709475282047476, 0.1194541087107999, 0.13798309516693863, 0.12413891804005418, 0.14782779690410408, 0.1273398119956255, 0.14373614931745188, 0.08920541112976414, 0.10964755421238286, 0.13140898650246008, 0.09468742446707827, 0.12647758397672856, 0.13970589557928698, 0.21558365757976258, 0.165133249014616, 0.11857664079538413, 0.11964252431477819, 0.17238391137548856, 0.15553319986377442, 0.1439948340079614, 0.14103431786809648, 0.10772188540015902, 0.09437063682292189, 0.1826868685228484, 0.16996436406459126, 0.09242201317101717, 0.13888047129980155, 0.11359508774642434, 0.10759639713381018, 0.13370730674692563, 0.07320501934736967, 0.07266560436359473, 0.10398680796580655, 0.14096027612686157, 0.10987531806209258, 0.11911874956318311, 0.09677514101245574, 0.11715774264718805, 0.10284216010144778, 0.11607406793960504], [0.04104639835921781, 0.040842189852680476, 0.06335689779371023, 0.03417924399088536, 0.04064477008900472, 0.004235074622556567, 0.02097570739819535, 0.018489536430154527, 0.02491967353437628, 0.04257622680493763, 0.036002800068152804, 0.041043972596526146, 0.12303196958133153, 0.05048992644463267, 0.01369824884126761, 0.022626498281689625, 0.04368599118398769, 0.13519768177398614, 0.04926500788756779, 0.05439840689567583, 0.11429903390152113, 0.08723701496741601, 0.008547868646149124, 0.051475583376096826, 0.08597291101302419, 0.03101901463898165, 0.04230255327586617, 0.03445780975744128, 0.020747512678748796, 0.04243474207552416, 0.08231839604143586, 0.047911361059440036, 0.03641622806234019, 0.017316206890557493, 0.024631214727248465, 0.10138201380946807, 0.14316380502922194, 0.03708381152578762, 0.08672707554485116, 2.103860250541142, 23.94316577911377, 52.91810580662319, 74.99784115382603, 59.725429671151296, 72.41118662697929, 59.23949350629534, 48.05896650041853, 30.54563937868391, 38.14432137353079, 33.17339597429548, 38.05134057998657, 82.41351454598563, 60.994573729378835, 28.327182054519653, 14.01732623577118, 37.85192033222744, 29.41245072228568, 9.76697506223406, 0.0901659249461123, 0.4934778373156275, 0.16724164730736188, 0.2553887202271393, 0.09924340713769197, 0.11696718287255083, 0.1462529171258211, 0.07514867612293788, 0.06049364964876856, 0.0055544706992805, 0.051109642655189545, 0.018942580691405704, 0.03676740046856659, 0.046533802657255104, 0.06532781810632773, 0.09783129433968238, 0.06433244116072144, 0.022629193762051206, 0.053044888989201615, 0.05343166412785649, 0.06956409543220486, 0.12224256194063596, 0.03164988596524511, 0.11668116679149014, 0.18446627232645238, 0.019782759714871645, 0.046833725313522985, 0.012722969254744905, 0.023853744213868464, 0.16954838138605866, 0.12516437444303716, 0.0342247092298099, 0.0894137756632907, 0.07543639532689538, 0.052279094367155006, 0.04540748541642513, 0.06934929838670151, 0.012450833455659449, 0.03223087478961263, 0.0734317246824503, 0.015425316390714474, 0.03127490376521434, 0.09005495732916252, 0.10028830356895924, 0.037187718985868354, 0.03888026691441025, 0.12105155656380312, 0.007939132828531521, 0.0545984288411481, 0.03324604120903781, 0.10906878419752632, 0.13795091903635434, 0.03568303704793964, 0.03457073834059494, 0.06651336806161062, 0.18553124660892145, 0.22904421814850398, 0.30659650958010126, 0.47337268186467035, 4.172591277531215, 14.590801886149816, 18.652166400636943, 14.426563841956002, 22.924667562757218, 58.38855457305908, 60.26318550109863, 53.743016787937705, 43.11975962775094, 23.79463413783482, 27.87127947807312, 34.79160015923636, 41.81067384992327, 50.428218841552734, 57.43730102266584, 72.32035977499825, 48.79292556217739, 19.00231044633048, 0.18258557681526455, 0.06468886203531708, 0.023334152630663345, 0.060269122411097796, 0.10490226027156625, 0.023527457079451, 0.06544350154165711, 0.059435196087828705, 0.024183440986754637, 0.02422968654095062, 0.09901040499763829, 0.010418216498302562, 0.04048479188765798, 0.002304760177919109, 0.04042028356343508, 0.07173724632178034, 0.03291157433497054, 0.05506116258246558, 0.03686504844310028, 0.046393664819853644, 0.1141174715012312, 0.03647150152495929, 0.03714290514056172, 0.042996494432113, 0.03807102230244449, 0.18226853811315127, 0.03387899903048362, 0.0661677358938115, 0.034170993005058596, 0.016060209733300974, 0.022838116390630603, 0.012261967474062527, 0.02479075188083308, 0.06593693220721823, 0.046797993659440956, 0.07749044974999768, 0.021224709393988763, 0.03997058108715074, 0.04161729058250785, 0.021242665126919746, 0.04556495303820286, 0.08528036424624068, 0.028516312861549, 0.013943719062288957, 0.01819152045728905, 0.02237711121727313, 0.04273285982864244, 0.010829409567772277, 0.025101985715861832, 0.030238885964666094, 0.09570273677153246, 0.019788296560623815, 0.019828771174486195, 0.09201619494706392, 0.0971819566828864, 0.050852019871984205, 0.014906732432012047, 0.04946980332689626, 0.04795960829194103, 0.003476670731158395, 0.038028301737670384, 0.024385215248912573, 0.03938835393637419, 0.023767322601218308, 0.043043231924197504, 0.054490439992930205, 0.00950113994934197, 0.10102371339287076, 0.013974914709771318, 0.04375008899452431, 0.05042753514966794, 0.11075675540736743, 0.031600006856024265, 0.03520689545465367, 0.06279259414545127, 0.0101721143915451, 0.026164892162861567, 0.06455555026020322, 0.04344893140452249, 0.07571001457316534, 5.997244247368403, 46.893406186785015, 78.46739632742745, 88.07434395381382, 72.40650354112897, 96.14661516462053, 79.37021051134381, 66.7404282433646, 48.69031803948538, 43.567880221775596, 19.816753966467722, 17.486668620790752, 88.02637359074184, 77.87287371499198, 35.33171142850603, 13.031759875161306, 14.901186602456228, 11.280758244650704, 3.2156432441302707, 0.23358671154294694, 0.4696161491530282, 0.05881406513175794, 0.09239299901361976, 0.2472880163363048, 0.04848673839920333, 0.06556960727487292, 0.032963953845735104, 0.07511767385793583, 0.014452936693227716, 0.03523809788748622, 0.037259816724274836, 0.03686183557978698, 0.08565776542361293, 0.09370014244424445, 0.19077506022793905, 0.08376064936497382, 0.06376463627176625, 0.012214157048479786, 0.04894266304160867, 0.052437847812793086, 0.17643670604697295, 0.07248450336711747, 0.09933876844921283, 0.5838175554360662, 0.049843608268669674, 0.38062044605612755, 0.507475960467543, 0.34461691656282967, 0.9025863047157014, 0.3786143437027931, 0.2662852869502136, 0.09484626272959368, 0.08159852466945137, 0.04537050186523369, 0.04438522491337998, 0.1292906001742397, 0.060262106359004974, 0.12853217444249562, 0.1121974006029112, 0.04885015496984124, 0.1055361544713378, 0.08546214377773659, 0.22851135102765902, 0.09397444022553307, 0.03781568278957691, 0.0837464001295822, 0.10294092087341206, 0.046494800464383194, 0.03052068155791078, 0.06287538898842675, 0.07907147027019944, 0.05482459134821381, 0.05936377349176577, 0.046266731273915083, 0.26480097802621977, 0.25053817193423, 0.32936323221240726, 0.583648681640625, 1.1201345111642564, 4.445838740893772, 8.954701117106847, 14.641297919409615, 28.410904373441422, 55.653500420706614, 40.81741149084908, 34.40639550345284, 30.371416773114884, 13.720970800944738, 29.30617802483695, 49.085712228502544, 62.82265172685896, 71.03854220254081, 75.09560230800084, 85.19685867854527, 70.31790283748082, 35.01737492425101, 0.8321659320167133, 0.07496327999979258, 0.00827605345485998, 0.039161031134426594, 0.07607693916984967, 0.035601500887423754, 0.07926673907786608, 0.022555827163159847, 0.03932373026119811, 0.010127929039299488, 0.020027770228417854, 0.044345126886452944, 0.03074302730549659, 0.027808990994734422, 0.12220977512853486, 0.0547586275663759, 0.06114930446658816, 0.051018746104091406, 0.024657943917970573, 0.03863435225295169, 0.0400562970233815, 0.01985288122003632, 0.07267366535961628, 0.004724527800655258, 0.07300764708114521, 0.025560368351372223, 0.06290010123380593, 0.05995632455285106, 0.007341389278216022, 0.0410729596125228, 0.07084082692329373, 0.04889549467978733, 0.07657939435115882, 0.1263546198606491, 0.018237297822322165, 0.0934939356520772, 0.04689034227547901, 0.045126884044813256, 0.07409362880779163, 0.013268967724538274, 0.06448943380798612, 0.1424100747598069, 0.1316809704793351, 0.09034665953367949, 0.1396051738411188, 0.12075842943574701, 0.13309720877025807, 0.07589584495872259, 0.08889354286449296, 0.11196559268449034, 0.15757484388138565, 0.12272516318729945, 0.11320165957191161, 0.2304539153618472, 0.1376276242413691, 0.11580623659704413, 0.11948479206434318, 0.17046204235936913, 0.22308571716504438, 0.08893535419234208, 0.1047058922371694, 0.1573676871401923, 0.23578421505434172, 0.08666093873658351, 0.1828965222729104, 0.22450371964701585, 0.10851679595985583, 0.21589669292526587, 0.07923562824726105, 0.14679319384906972, 0.1617923325725964, 0.22012752161494323, 0.08539975926812206, 0.1599346258278404, 0.1141860985330173, 0.04121862072497606, 0.16992105995970114, 0.32782103068062235, 0.10733865560697657, 0.15358102747372218, 3.748409833226885, 43.10801717213222, 82.48482390812465, 101.42837865012032, 75.40884099687848, 96.27648394448417, 78.287125314985, 59.81180272783552, 38.12665210451399, 52.222233295440674, 45.02796425138201, 47.00683552878243, 92.28397955213273, 84.07848358154297, 38.84892429624285, 19.57926106452942, 52.601761272975374, 42.2940148626055, 14.87307071685791, 0.6527106815150806, 0.9662890178816659, 0.2798357398382255, 0.5370275175997189, 0.6219805904797145, 0.46746177332741873, 0.37411041823881014, 0.1841520427593163, 0.2024127093276807, 0.2354515700467995, 0.24715016516191618, 0.19162177693630966, 0.1426915039441415, 0.2020290656281369, 0.16832878254354, 0.26929420977830887, 0.2711545356682369, 0.2597530303256852, 0.13507405269358838, 0.26658734359911507, 0.2467739853475775, 0.4025906228593418, 0.24639772410903657, 0.315806509660823, 0.5536828924502645, 0.1283894513866731, 0.6980266698769161, 0.37665229184286936, 0.18537959403225354, 1.064421792115484, 0.7427774114268166, 0.38908112634505543, 0.2254876768482583, 0.1302765929805381, 0.1565244716725179, 0.16731566190719604, 0.22692029497453145, 0.13001537056905882, 0.15186642376439913, 0.24426891548292978, 0.15100416860410146, 0.26060185049261364, 0.18596876598894596, 0.5191857921225684, 0.26452793553471565, 0.1940694698797805, 0.20736795557396753, 0.17002262308129243, 0.2039808173264776, 0.24919187703302928, 0.232975107218538, 0.33553578385284966, 0.1518770224813904, 0.22924910858273506, 0.37297601625323296, 0.6638936985816274, 0.4365585201552936, 0.6880719640425274, 0.81157662825925, 7.640832373074122, 22.05159514290946, 25.247167212622507, 23.4619265965053, 39.28824152265276, 84.33631038665771, 81.74464620862688, 74.29009764535087, 60.19216101510184, 36.24591023581368, 37.43756798335484, 41.103955200740266, 55.93607323510306, 66.67997196742466, 72.8992280960083, 92.1862461907523, 75.36443505968366, 32.48851898738316, 0.3803878442517349, 0.22408336720296315, 0.09203015919774771, 0.11149332552616086, 0.1708287905369486, 0.14593230932950974, 0.29469706809946467, 0.08433328542326178, 0.15779192080455168, 0.09693534991570882, 0.11768672854772635, 0.12701792855347904, 0.1566311509481498, 0.055810879317245314, 0.16150865065199987, 0.16082043972398552, 0.19834327697753906, 0.1404900649296386, 0.1729047412851027, 0.08564852377665894, 0.18746884406677314, 0.10166341585240193, 0.20872342426862034, 0.243532623563494, 0.10190976477627244, 0.2275362012109586, 0.16269079436148914, 0.1396744115544217, 0.06329044207398381, 0.109060512855649, 0.14009945946080343, 0.07643589098006487, 0.25121201149054934, 0.16451943266604627, 0.07854169048368931, 0.22129053063690662, 0.12011623675269739, 0.15596276681338037, 0.09101617682193007, 0.07334204949438572, 0.1433869887675558], [0.05941947443144662, 0.0364700901721205, 0.037044887364442856, 0.012683749082498252, 0.019325454253703356, 0.01761920839947249, 0.029360580058502297, 0.03172546119562217, 0.08525322284549475, 0.03208480316347309, 0.030120532494038343, 0.01813816385609763, 0.049057196360081434, 0.0807486188464931, 0.06936231947370938, 0.024160889875409857, 0.013093728422453361, 0.036142398470214436, 0.07961848484618322, 0.03265240788459778, 0.052493050029235225, 0.025776340958795378, 0.0036908361029678156, 0.03248137974047235, 0.010543265413226826, 0.0025544765438618405, 0.028025038241009628, 0.018732809894052998, 0.02895805612206459, 0.08061750552483968, 0.024116591716717397, 0.04090949374118021, 0.029722968648586954, 0.011075023977485086, 0.05017795979178377, 0.013982607600545245, 0.053602224082819054, 0.44749661322150913, 9.049191406794957, 46.41803823198591, 77.17562893458775, 75.40467207772392, 64.9697493144444, 60.89557579585484, 55.1591534614563, 48.39998756136213, 33.0118225642613, 30.61459677559989, 28.756115198135376, 70.14571952819824, 70.9905093056815, 21.154136283057078, 11.293952873774938, 25.58042539869036, 39.923195702689036, 6.404949341501508, 0.20448757441980497, 0.6677247615797179, 0.03376410608845098, 0.505972435431821, 0.222446116485766, 0.07778816377477986, 0.0367307426141841, 0.08817031274416617, 0.22496323713234492, 0.09339370245912246, 0.10182891054345028, 0.02951881442485111, 0.03813912346959114, 0.1361686246735709, 0.09325707943311759, 0.0545966714354498, 0.05620959327955331, 0.18274265767208167, 0.039509930448340516, 0.09700608040605273, 0.07421695933278118, 0.060939433585320196, 0.09948053477065903, 0.0413573132827878, 0.11476528245423522, 0.08826696327222244, 0.07032538458172764, 0.06835455926401274, 0.09966394957154989, 0.08807267834033285, 0.10249510301010949, 0.08187426773032971, 0.12912540403859957, 0.2090310449046748, 0.17054483720234462, 0.23347877019218036, 0.8833992342863763, 0.5516793142471994, 0.10190418721841914, 0.1560792169932808, 0.0869833446506943, 0.05109877930954099, 0.03979592617335064, 0.029048409845147814, 0.5042641013860703, 0.8895959417734827, 0.04141251549922994, 0.03780849031837923, 0.02522955199570528, 0.021637170475774577, 0.06997045648417302, 0.10415819912616696, 0.06352874357253313, 0.02661489149821656, 0.03183825746444719, 0.06895038086388793, 0.040474491726074896, 0.060020778594272475, 0.1391012937362705, 0.44211376777717043, 0.1851470193692616, 0.30984460243156975, 0.4464870073965618, 1.067614272236824, 8.5746876341956, 17.833147491727555, 18.472383499145508, 30.893243857792445, 37.4935496194022, 55.852350916181294, 50.50739009039742, 27.42769432067871, 23.885931730270386, 25.75114263807024, 39.35360322679792, 37.07302379608154, 42.661928926195415, 61.39233030591692, 62.396247727530344, 32.56348657608032, 1.2297246477433612, 0.1683365042720522, 0.08994776236691646, 0.022031114336901476, 0.057407292404345105, 0.05124169235516872, 0.02878441901079246, 0.01169798952261252, 0.0073284971128617015, 0.017425637625690018, 0.023708139080554247, 0.01151306922214904, 0.045631388401878734, 0.018444766689624106, 0.029415317478456667, 0.10191223464374032, 0.03641060979238578, 0.0741523424429553, 0.051281976979225874, 0.02410826100302594, 0.07782242300787143, 0.11427235390458788, 0.04914609123287456, 0.010450301874828125, 0.023043861778985177, 0.017540125143049017, 0.009691617451608181, 0.019187872796984654, 0.061897226476243565, 0.10090248632643904, 0.06566032740686621, 0.023016281026814665, 0.027571313748402253, 0.057883657914187224, 0.033630485579903634, 0.05321646674669214, 0.00936045334674418, 0.007358861554946218, 0.041922556702047586, 0.004217138821591756, 0.03415576328656503, 0.021800878923386335, 0.08574940836323158, 0.02494926275020199, 0.026824385792549168, 0.021784689077841382, 0.035327457556767125, 0.0022939685025318924, 0.03644386479364974, 0.030561319020177637, 0.0312637791835836, 0.04003494691901973, 0.08702748335365738, 0.08544277160295419, 0.030985271092504263, 0.022835008700245192, 0.041045278776437044, 0.067294945408191, 0.01468448676834149, 0.00221955356703672, 0.012067537505312689, 0.04331328546894448, 0.009840348086852049, 0.015700112895241806, 0.05494796597797956, 0.02468687665116574, 0.02593004271121962, 0.03811687769900475, 0.026954501667725186, 0.04875725334776299, 0.03422990680805274, 0.04038226185366511, 0.06324186575199876, 0.041639953652130704, 0.023412228262584125, 0.12326997252447264, 0.1000920712415661, 1.4465778172016144, 23.108965056283132, 66.8368136542184, 92.10619599478585, 88.20633888244629, 85.80960641588483, 82.68186092376709, 68.87378229413713, 70.45197527749198, 37.551831109183176, 17.04024338722229, 12.782891035079956, 42.76317112786429, 80.88823209490094, 32.522919518607004, 10.306357639176504, 10.93303564616612, 16.32956600189209, 3.1151132328169684, 0.28466305509209633, 0.4146604309124606, 0.02741208193557603, 0.4236915691622666, 0.2191581664873021, 0.07867414730467967, 0.1031889525641288, 0.07473373160298381, 0.20052847186369555, 0.10035017239195959, 0.08998671027698688, 0.1048228716743844, 0.1391293036618403, 0.042140570003539324, 0.15294306884918893, 0.09583551928933177, 0.05903791383441005, 0.008813722059130669, 0.06285197953028338, 0.22242656110652856, 0.34173392983419554, 0.21585218102804252, 0.3229888028332165, 0.09543823703591313, 0.5829877342496599, 0.4424201399087906, 0.48261183180979317, 0.41102370034371105, 0.27013404614159037, 0.46743343770504, 0.8989301409040178, 1.1105766126087733, 1.2232024605785097, 0.9778319299221039, 0.1232470516115427, 0.8862451187201908, 0.7837875251259122, 1.9433829188346863, 1.1976252730403627, 0.8720990206514085, 0.323745315096208, 0.0353433827736548, 0.42941053371344295, 0.04683295178360172, 0.5317371700491224, 0.966749227472714, 0.05297281499952078, 0.0954370495996305, 0.013639770997022944, 0.0034482765851342784, 0.03856260056740471, 0.03041180722149355, 0.058610450343361924, 0.0368893366040928, 0.036026949129466496, 0.05224994450275387, 0.06416681754801955, 0.059624195231923034, 0.0734778582783682, 0.31199949394379345, 0.1515676240835871, 0.39225737590874943, 0.3908605980021613, 0.33740457785981043, 2.9438242869717732, 12.250652943338666, 21.323594161442347, 33.95581177302769, 33.288802078792024, 46.259125982012065, 36.12869759968349, 15.925743647984095, 19.98173894201006, 36.12208638872419, 57.385019302368164, 58.02964537484305, 60.76187855856759, 70.83974729265485, 74.74528803144182, 49.739905970437185, 4.894238131386893, 0.030007386779678718, 0.06876727818910565, 0.021298601857519577, 0.0385929276900632, 0.013155105307565203, 0.046476656437984536, 0.014119959203526378, 0.06251462548971176, 0.07643545671765294, 0.009614289056376686, 0.020342522267518297, 0.07288568041154317, 0.02605676930397749, 0.045338356268725226, 0.040563634264149835, 0.019125077773683836, 0.034979925490915775, 0.00988194567617029, 0.044838503269212585, 0.027768029531996165, 0.07340638818485395, 0.02570590902385967, 0.042411739738391976, 0.052321170323661396, 0.07784126592533928, 0.02572675870864519, 0.018492786612893854, 0.019737542141228914, 0.04540172126144171, 0.0494655149855784, 0.028610357815133672, 0.012595877101245736, 0.05556732935032674, 0.044191258892949135, 0.034933225318257294, 0.039545475505292416, 0.08082104567438364, 0.02429307358605521, 0.026550349247242724, 0.11470593778150422, 0.11352275591343641, 0.15531581081449986, 0.10993525306028978, 0.048341426732284684, 0.18316246728811944, 0.18378765588360174, 0.13469856498496874, 0.13264073112181254, 0.1121824864032013, 0.24432585814169475, 0.07900502812117338, 0.18809738462524755, 0.14023093240601675, 0.3082820719906262, 0.1308398720409189, 0.11713787514184203, 0.17548120660441263, 0.2129779066890478, 0.10839280047054801, 0.13635946943291596, 0.13296733716768877, 0.08231100679508277, 0.10962762563888516, 0.13210475631058216, 0.1330492092030389, 0.15117525442370347, 0.11052840801754168, 0.1234770342707634, 0.18055947124958038, 0.08678647450038365, 0.10628788984779801, 0.1139035022684506, 0.1886579766869545, 0.13827786434973988, 0.18264973908662796, 0.21408420375415257, 0.8563810012170247, 17.926454850605555, 74.75801018306187, 103.58934484209333, 95.84739099230084, 83.64694486345563, 85.02871922084263, 68.65863132476807, 60.26806313650948, 43.522414684295654, 40.52536480767386, 39.469377585819785, 92.62660217285156, 101.95626108986991, 31.512505531311035, 18.588032790592738, 34.77717917306082, 56.79068776539394, 11.249780569757734, 0.7098571721996579, 1.267473342163222, 0.10041673667728901, 1.1311798670462199, 0.6072094259517533, 0.18013503402471542, 0.17080914016280854, 0.20642066640513285, 0.45931826744760784, 0.31913746520876884, 0.19034812599420547, 0.2880051928971495, 0.2182206210813352, 0.24987551463501795, 0.23231831246188708, 0.19917946282242024, 0.1368142778852156, 0.4012149338211332, 0.13891285099089146, 0.18651609947638853, 0.2357954787356513, 0.21103546449116298, 0.37795841747096603, 0.1335939642574106, 0.33290065239582745, 0.33870090544223785, 0.2910227195492813, 0.36451321893504685, 0.16468521234180244, 0.2849975185734885, 0.6967229055506843, 0.7196801879576274, 0.7175258121320179, 0.7687926068902016, 0.19199902883597783, 1.8517930677958896, 1.8832705787249973, 1.2935637193066734, 0.6086888494236129, 0.4569649451545307, 0.2573050388268062, 0.11874577243413244, 0.28538064658641815, 0.16027716387595448, 1.7158544936350413, 1.6095326159681593, 0.17800718891833509, 0.19018335055027688, 0.12996220056499752, 0.1429013748254095, 0.2103297880717686, 0.2934808076492378, 0.1573368545089449, 0.10409223873700414, 0.21734088685895714, 0.29024411418608254, 0.22846586204000882, 0.10392621478864125, 0.2783198654651642, 0.9232827084405082, 0.4404387633715357, 0.7720161910567964, 0.8281546501176698, 2.6066147472177232, 13.302926353045873, 25.379744052886963, 31.26963472366333, 48.83214814322335, 55.76982021331787, 75.07413237435478, 69.83526011875698, 39.563508306230815, 33.86721876689366, 34.008364473070415, 49.83933121817452, 50.06886148452759, 58.080853598458425, 74.85914816175188, 86.74464634486607, 50.13151339122227, 3.388107304062162, 0.23307004783834728, 0.19840216024645738, 0.15929493015365942, 0.08497911505401134, 0.10004883499017783, 0.16264401615730353, 0.08091897863362517, 0.14557721838355064, 0.21182702987321786, 0.12625247319894178, 0.08587832323142461, 0.1473552379757166, 0.11169196665287018, 0.13189454616180488, 0.12186617856579167, 0.0956651120047484, 0.13906890047448023, 0.14162321841078146, 0.07590731898588793, 0.11859281707022871, 0.14407800883054733, 0.07969474539692913, 0.1213228212935584, 0.11037613797400679, 0.09927031105118138, 0.07767148289297308, 0.11587799846061639, 0.15882778593472072, 0.1560864501765796, 0.09129966875272137, 0.08717452189219849, 0.07987480144947767, 0.1510420987116439, 0.13543417836938584, 0.13459933602384158, 0.14736951435250895, 0.1801351833024195, 0.06342971817191158, 0.1144196909985372], [0.029734544456005096, 0.0034753210825978643, 0.0299111060532076, 0.030518391502222846, 0.04501698512051787, 0.045067447769854746, 0.039084295609167645, 0.020245371319885765, 0.007433094134155128, 0.08201318420469761, 0.03317404864355922, 0.035193263686129024, 0.055030289239117076, 0.018074383260682225, 0.03814882312768272, 0.01114789694215038, 0.06163362240684884, 0.013591882539913058, 0.016770518850535154, 0.04899091366678476, 0.03163179282897285, 0.0020619300942468855, 0.09887852493141379, 0.011426949557582182, 0.032781838439404964, 0.04532882285171321, 0.03948377292337162, 0.010335747352136033, 0.09963762919817652, 0.018816488528890268, 0.02060554618947208, 0.015857719616698365, 0.006145196925250015, 0.004563605163379439, 0.023602000936599712, 0.03928439897884216, 1.3346375610147203, 26.53962074007307, 76.2240731375558, 76.14930357251848, 67.44783823830741, 67.41618919372559, 59.42740753718785, 40.817672048296245, 37.135547161102295, 16.821759019579204, 49.23418133599417, 75.49176774706159, 52.28034108025687, 45.7463732446943, 12.296321715627398, 18.354276282446726, 40.54117195946829, 28.76058636392866, 1.0823011355740684, 0.3568695219499724, 0.25674671307206154, 0.2679169736802578, 0.059422154644770284, 0.09863014040248734, 0.05186924225251589, 0.08979178073682956, 0.14520190709403583, 0.07260155744318451, 0.1439361542995487, 0.06134528573602438, 0.04407515137323311, 0.09572394099086523, 0.06505270608301673, 0.06083006052566426, 0.1271303075232676, 0.058742601823593886, 0.12257182784378529, 0.22071262236152375, 0.08955010691923754, 0.0911223404109478, 0.1643773338624409, 0.04072647927595036, 0.08523283286818437, 0.24029815569519997, 0.2893816147531782, 0.47899714005844934, 2.526592126914433, 0.49566130872283665, 0.974898270198277, 3.9775583829198564, 1.0348660009247916, 2.1525141426495145, 2.194632819720677, 0.17907790360706194, 0.3270088785461017, 0.2149281520396471, 0.43053804178323063, 3.506813802889415, 3.037816043410982, 2.407044678926468, 0.6347898117133549, 1.7656996761049544, 1.0568013553108488, 0.09488297825945274, 0.37921967836362974, 0.3084881566464901, 0.08152870341603245, 0.07133129239082336, 0.10596559928464037, 0.042840702791831324, 0.036312205251306295, 0.030931561653103148, 0.12954686928008283, 0.20766807161271572, 0.035965175301368744, 0.09654198280934777, 0.04347198123910597, 0.19348913244903088, 0.07026461498545748, 0.07332009210118226, 0.051790376127298386, 0.247506993157523, 0.22165484965911933, 0.2597220619874341, 0.6251593913350786, 0.2911996271993433, 6.2917076008660455, 15.190598181315831, 31.789582320622035, 24.53271869250706, 43.19046449661255, 64.88996315002441, 52.23721708570208, 27.857615845543997, 24.197857209614344, 35.8441549709865, 47.78934860229492, 48.737002985818044, 54.029695987701416, 58.19006538391113, 42.55323478153774, 10.879300015313284, 0.08379560748913459, 0.06972431790615831, 0.01005936986101525, 0.08599952315645558, 0.039116400493574996, 0.029523570955331837, 0.017433126955958347, 0.08670931828341313, 0.07676531973161868, 0.034436731067086966, 0.007687538828966873, 0.04132646029548986, 0.02397662860208324, 0.04856832205717053, 0.02116378373466432, 0.045322336056934934, 0.012297199556737073, 0.04124678671360016, 0.06908323802053928, 0.07866869188312973, 0.062449397918369086, 0.029259980456637483, 0.019365039986691306, 0.02113647778917636, 0.08620895977531161, 0.018237372461174215, 0.00887834997515061, 0.015932573903618113, 0.04170319650854383, 0.03832570702901908, 0.036496210377663374, 0.041318714818251986, 0.037048649841121266, 0.020102139362799268, 0.026911628432571888, 0.04373082538534488, 0.020504118774884512, 0.025740149597238218, 0.03778614955289023, 0.030787003160055195, 0.01467789480063532, 0.011409382285949374, 0.03517484146037272, 0.03047883969598583, 0.01535734414522137, 0.014662624370040638, 0.03302040795928665, 0.05098960981039064, 0.050811389195067544, 0.054786301617111476, 0.017094127467966506, 0.024627676167126213, 0.05622595954420311, 0.03469596876363669, 0.06482701176511389, 0.06218520352350814, 0.07146430561052901, 0.04590381342651589, 0.037529636174440384, 0.03730125825053879, 0.019700465291472416, 0.032467846359525404, 0.040289696106421094, 0.044337683357298374, 0.07612872496247292, 0.006342743490157383, 0.100175062859697, 0.03924126450770667, 0.03305370027997664, 0.027318963182291815, 0.008481540999907469, 0.038717381190508604, 0.07741765651319708, 0.11011493591857807, 5.074342821325574, 48.099832330431255, 98.76435593196324, 93.41415269034249, 88.96803515298026, 99.28267765045166, 89.05810465131486, 72.35582338060651, 46.83183125087193, 10.97044735295432, 29.0824772971017, 50.28062868118286, 54.96585457665579, 65.22283744812012, 13.918057322502136, 9.908294473375593, 15.221269266945974, 13.515519516808645, 0.1415355381156717, 0.5250820985862187, 0.14336385072341987, 0.30046320440513746, 0.05519356851332954, 0.1748914239662034, 0.020634283843849386, 0.1499362223382507, 0.09235249047300645, 0.16516697220504284, 0.14955285005271435, 0.08926253699298416, 0.09242202674171754, 0.16131065413355827, 0.12528743355401925, 0.18587158620357513, 0.450693815946579, 0.8913221891437257, 0.4671607751931463, 1.2061909905501773, 0.9019634638513837, 0.4498176101062979, 0.946628981402942, 0.576668239065579, 0.6987200783831733, 0.7298522964119911, 1.41094408929348, 1.6904183328151703, 5.777009802205222, 2.69865905387061, 3.9491198403494696, 9.696692296436854, 5.048731761319297, 9.483295747212, 8.4014664377485, 2.938796179635184, 1.3239686020783015, 1.8863686067717416, 3.2291175382477895, 6.751174168927329, 2.420980376856668, 7.074071288108826, 3.0837523213454654, 2.9175307835851396, 1.9325610995292664, 0.09704527258872986, 0.38328833718385014, 0.28832198732665604, 0.027737385194216455, 0.09107276664248534, 0.0700041593185493, 0.06363120914569922, 0.025778649674196328, 0.0929823134626661, 0.2895773856767586, 0.07029295739318643, 0.032158878831458945, 0.06991280136363846, 0.024775471272213117, 0.1132871617696115, 0.03784688861508455, 0.21298336211059773, 0.10826170071959496, 0.16893185089741433, 0.17474357118563993, 0.1122967517003417, 0.537007215831961, 0.2852136998304299, 3.4460446408816745, 13.960468258176531, 35.56924949373518, 29.233663150242396, 40.93935932431902, 60.732876777648926, 46.30727699824742, 20.90119927270072, 26.37403300830296, 50.092252595084055, 66.86749689919608, 74.01380252838135, 74.70530114855084, 70.52129745483398, 60.79910005841936, 23.851852553231375, 0.10811425506004266, 0.13206013584775583, 0.00184235955488735, 0.14473480358719826, 0.06531481059002024, 0.056934129579791, 0.030999116599559784, 0.041508606235895834, 0.0693272188571947, 0.036915131112826724, 0.05683656642213464, 0.04565749842939632, 0.03223469154909253, 0.034173903920288594, 0.09082238722060408, 0.02723633627673345, 0.00873553701343813, 0.059216185339859555, 0.07228875958493777, 0.02818485359395189, 0.014218548645398446, 0.029517878046525375, 0.025811758790431277, 0.03983400895127228, 0.028159225326297537, 0.03100164414250425, 0.028942018946898834, 0.01305811042298696, 0.06671514402010612, 0.057844750716217926, 0.024280400248244405, 0.025034668256661723, 0.026392393080251556, 0.08512814848550729, 0.026788491290062666, 0.02836822429006653, 0.05804924760013819, 0.01714459859899112, 0.07176903568740402, 0.1070308517664671, 0.06733677030674048, 0.1608232624296631, 0.17137461767664977, 0.0914792837575078, 0.15200825115399702, 0.07457635897610869, 0.1140330753156117, 0.23689454261745724, 0.06279673999441521, 0.0809558095144374, 0.09615377256912844, 0.09531730173953942, 0.10685039537825755, 0.09759970355246748, 0.15069540802921566, 0.161290013098291, 0.15439186325030668, 0.30632954676236424, 0.08374806932572808, 0.11134450244052069, 0.141120206830757, 0.08267231990716287, 0.14899149803178652, 0.11840863552476678, 0.2036620280040162, 0.16793635860085487, 0.18951711058616638, 0.12960002571344376, 0.09148549235292844, 0.1350906225187438, 0.1442166335348572, 0.10858682755913053, 0.09802179304616791, 0.18938639760017395, 3.637640131371362, 48.56330844334194, 112.1620739528111, 100.6087760925293, 87.50241688319615, 90.69614246913365, 79.07172284807477, 55.492576667240684, 53.429090227399556, 24.75122216769627, 65.98051071166992, 102.57370580945695, 75.64163344247001, 67.51907811846051, 19.07752295902797, 26.4172751222338, 57.48363855906895, 43.48714910234724, 2.513899939400809, 1.2623166931527001, 0.5483604637639863, 0.9467797790254865, 0.29453136984791073, 0.3574077087853636, 0.1163247459168945, 0.37583804982049124, 0.47416260519198006, 0.25312409603169983, 0.26914335787296295, 0.3023003786802292, 0.26724875239389284, 0.1598986363304513, 0.16814279609492847, 0.13970478278185638, 0.25193709401147707, 0.4643174963338034, 0.2632787254239832, 0.2720858928348337, 0.41650477051734924, 0.275263499468565, 0.5260337846619743, 0.2719449746821608, 0.3248895965516567, 0.4858655429312161, 1.0464309517826353, 1.1906718633004596, 5.105038659913199, 1.8535598644188471, 2.8579630085400174, 8.872714979307991, 3.6432054213115146, 8.39203860078539, 6.753964739186423, 0.988258570432663, 0.6452908196619579, 1.7145527920552661, 2.055987162249429, 6.942405096122196, 5.979368703705924, 5.995897599628993, 2.596424562590463, 5.206152319908142, 3.5224224967615942, 0.2720332385173866, 1.5915160455874033, 1.068769844514983, 0.30064364043729647, 0.20845709927380085, 0.22707034620855535, 0.30680696400148527, 0.3098899557122162, 0.16308897228113242, 0.4349004791251251, 0.2713248479579176, 0.14478585656200135, 0.21090925697769436, 0.255626560321876, 0.458468850169863, 0.2859040956412043, 0.2976525495094912, 0.38758316529648645, 0.7734029537865094, 0.5202231907418796, 0.372968850923436, 1.082818016409874, 0.9660310660089765, 10.36957495553153, 24.019234657287598, 46.736522810799734, 39.53027854646955, 57.16748857498169, 86.61684117998395, 68.12834480830601, 38.72539574759347, 34.6445380619594, 44.39039754867554, 57.59502860477993, 67.186676297869, 69.70895576477051, 79.97108377729143, 65.70210334232875, 20.594380719321116, 0.1155033249940191, 0.1723154200507062, 0.15570355286555632, 0.20003756534840378, 0.13202630409172603, 0.11837411166301795, 0.05316742562821933, 0.28267413324543406, 0.1594744162367923, 0.11206920498183795, 0.11045346382473197, 0.10329619502382618, 0.09277145192027092, 0.1598372831940651, 0.18052844862852777, 0.09798528786216464, 0.1402513020272766, 0.14440868608653545, 0.1472327895462513, 0.131132198497653, 0.11733486742845603, 0.11636511875050408, 0.08556502325726406, 0.07801096074815307, 0.17221423690872534, 0.1120260094425508, 0.08656652058873858, 0.10295757890811988, 0.16412095619099482, 0.1582488598568099, 0.08430864781673465, 0.06433897545295102, 0.17954825051128864, 0.15658043724085602, 0.20029954771910394, 0.10728125154439892, 0.1397356561252049, 0.14383089994745596], [0.05857665251408305, 0.04197361646220088, 0.02987926240478243, 0.02106653609579163, 0.03119823948613235, 0.03241039479949644, 0.028152981107788425, 0.05843045535896506, 0.043933262915483544, 0.023200577923229763, 0.02202045624809606, 0.019100338386903917, 0.017315172124654055, 0.037379320311759195, 0.051205204134540896, 0.01612354419194162, 0.02941723433988435, 0.04670048478458609, 0.020062190613576343, 0.019837977198351706, 0.04282565627779279, 0.051000317092984915, 0.05596504925883242, 0.02500343698609088, 0.021436866938269565, 0.009570792417175003, 0.03572863460119281, 0.051193336557064734, 0.012090940178105873, 0.05784883549703019, 0.03565861996529358, 0.055491655732371976, 0.023477701802871058, 0.09140240573989493, 0.05622392054647207, 9.99288705417088, 48.28493928909302, 78.45901679992676, 65.67453289031982, 60.1469212940761, 46.55856902258736, 37.45390667234148, 32.28067404883248, 22.487040485654557, 28.075023242405482, 60.240833146231516, 62.45978900364467, 38.53686680112566, 17.359664235796245, 8.041285719190325, 34.2769992010934, 34.61103384835379, 6.127815663814545, 0.4774937235883304, 0.029105966578104665, 0.33225181006959503, 0.0773144784782614, 0.10613276317183461, 0.01468692101272089, 0.016670799647857035, 0.11398145237139293, 0.08076486297483955, 0.04270463277186666, 0.1216837747820786, 0.12237472699156829, 0.07683870329388551, 0.09107426620487656, 0.10644690452941827, 0.09210719327841486, 0.0977581346939717, 0.15920328721404076, 0.05809034646621772, 0.19984886475971766, 0.4284660672502858, 0.20373699255287647, 0.5170294078333038, 1.9397802778652735, 2.1351862038884843, 1.5718248507806232, 2.236541748046875, 5.567523351737431, 6.730945357254573, 3.0833966604300906, 2.217295889343534, 6.3468941024371555, 6.044398197105952, 4.805599961962018, 11.58270524229322, 24.03471350669861, 14.348711013793945, 4.138037885938372, 0.8867040255240032, 3.705866013254438, 10.432661993162972, 4.968418402331216, 9.666888867105756, 3.2604860493115018, 2.018598905631474, 1.6346338519028254, 0.22362911514937878, 0.017487769381010106, 0.36632536883865086, 0.10011165376220431, 0.05206386645191482, 0.004792103951331228, 0.1387118689183678, 0.057955535128712654, 0.08845166728964873, 0.23459338609661373, 0.03492884537471192, 0.16930950991809368, 0.11674846389463969, 0.06955695045845849, 0.07589344294475657, 0.08616870907800538, 0.12544634645538671, 0.0437347303543772, 0.11262177675962448, 0.08071530956242766, 0.11722945022795882, 0.4253458103963307, 0.068359953617411, 0.13218497272048677, 0.5916733081851686, 7.171012120587485, 22.93758773803711, 29.87059756687709, 33.8783324105399, 39.547833170209614, 61.13038321903774, 38.97398839678083, 21.01172079358782, 24.421894924981252, 37.97082832881382, 34.633177757263184, 54.53772394997733, 57.33004515511649, 66.59590571267265, 22.47384238243103, 0.6036723043237413, 0.09249399895114557, 0.01691514689342252, 0.10804499020533902, 0.02213630422816745, 0.03612019680440426, 0.022668709945199744, 0.0437177601935608, 0.036618312754269154, 0.026366277963721325, 0.03628535901329347, 0.11011013189064604, 0.0698176978954247, 0.0712382448837161, 0.01936414771314178, 0.031105853550668274, 0.02901381134454693, 0.010031898522616496, 0.05253912934235164, 0.08823700595114913, 0.005045804802128779, 0.039363862214876075, 0.027181656532255665, 0.06880167991455112, 0.0635505991854838, 0.02229996687466545, 0.04852710784013782, 0.05220357681225453, 0.044565633804138215, 0.02113028785346874, 0.011446212318592837, 0.07120066761438336, 0.006790642335545272, 0.0986197181046009, 0.028369778135259236, 0.018914372294342945, 0.030115606329802955, 0.012606441043317318, 0.021202041235353266, 0.06341092275189501, 0.035081095062196255, 0.048077741238687716, 0.08996347723794834, 0.039049924417798004, 0.04561403826145189, 0.03569649239735944, 0.049979050643742085, 0.02304874044576926, 0.015392875631472893, 0.06257255880960397, 0.02351230030347194, 0.06078772672585078, 0.048708225799990554, 0.019835843205718056, 0.06565271424395697, 0.019112618174403906, 0.014024987201472479, 0.02183143505161362, 0.08284476279680218, 0.050646403405283175, 0.036650383711925576, 0.04870761851114886, 0.021893649927473495, 0.029745082104844705, 0.08288263183619295, 0.13962322287261486, 0.06383339901055608, 0.03427180973812938, 0.0453420848186527, 0.07921103813818522, 0.01785528939217329, 0.37991642526217867, 19.743434837886266, 71.13308634076799, 94.53863525390625, 83.61225250789097, 85.84042862483433, 70.31627695901054, 60.3306941986084, 45.77218580245972, 25.79717445373535, 25.515183550970896, 41.22372824805123, 64.68692289079938, 39.66399662835257, 20.045983723231725, 4.080194132668631, 11.996016229901995, 15.767420257840838, 2.1803212676729475, 0.4519351821924959, 0.03142450377345085, 0.2567434289625713, 0.0426832758821547, 0.22005033147122177, 0.05118861056065985, 0.033765130676329136, 0.13657119950013502, 0.04347244603559375, 0.10728040337562561, 0.06740931927093438, 0.34932081986750874, 0.7368754595518112, 0.27035158446856905, 0.45657226336853846, 0.9326206530843462, 0.8976478725671768, 1.8141454479524066, 0.6834216650043214, 1.224369432244982, 1.9979086901460374, 1.4398442528077533, 5.266612069947379, 5.713591856615884, 6.171005231993539, 5.043013393878937, 6.111780524253845, 11.593924845967974, 17.369627952575684, 12.092106342315674, 7.242978521755763, 13.004186817577907, 12.215516771589007, 10.816379734448024, 18.021195275442942, 29.29772206715175, 21.85548918587821, 11.478747163500104, 5.939817820276533, 5.643000764506204, 7.389462181500026, 4.8863193563052585, 9.789457695824758, 3.4015889806406836, 0.8243828639388084, 0.43808096274733543, 0.33414250718695776, 0.2530197916286332, 0.28707578991140636, 0.12357737602932112, 0.0769091352288212, 0.04328334850392171, 0.07648433159504618, 0.018768164961199676, 0.07627826050988265, 0.40123919823340004, 0.05146876409915941, 0.08843021879770926, 0.06649502726005656, 0.05158385042367237, 0.11475087037043911, 0.14903615920671395, 0.07449530118278094, 0.05144564301839896, 0.05459243059158325, 0.10179565554218632, 0.2319812434060233, 0.32904377792562756, 0.11180101401571717, 0.16533695879791463, 0.2619758296225752, 5.0020003489085605, 20.514363527297974, 29.912106105259486, 35.15016194752285, 40.650988238198416, 55.577122347695486, 24.54194242613656, 8.960192799568176, 29.56616571971348, 48.07187625340053, 55.75501707621983, 77.31435666765485, 70.42131982530866, 79.67983613695417, 41.25905288968767, 2.10869619676045, 0.16488386025386198, 0.16239652729460172, 0.06603265992764916, 0.03583345469087362, 0.034817504563501904, 0.13541298093540327, 0.01997341787708657, 0.057839342792119296, 0.014342527171330792, 0.03377927473879286, 0.12540625860648497, 0.08267272024282388, 0.039841689967683384, 0.05458161813606109, 0.011429483885876834, 0.02467362825492663, 0.033963727698262246, 0.028503932990133762, 0.05300794954278639, 0.04154012079483696, 0.07055284309067897, 0.016375009269852723, 0.02288585132919252, 0.03967140142672828, 0.05002354897026505, 0.03993245081177779, 0.02720108298983957, 0.020332047383167913, 0.037068344320037534, 0.07201738628957953, 0.042366372887045145, 0.020499523396470716, 0.05514826612280948, 0.018170733536992754, 0.04503105454412954, 0.011620618718942361, 0.15534532708781107, 0.10392476950905152, 0.11296722572296858, 0.1045496595491256, 0.12765865560088838, 0.18538218603602477, 0.14663831144571304, 0.17040128633379936, 0.14104085894567625, 0.09400318975427321, 0.14236458577215672, 0.17834024104688848, 0.16080021938042982, 0.1160420003746237, 0.14572353767497198, 0.11088763802711453, 0.14320831692644528, 0.2214464172720909, 0.1065837853987302, 0.06712110473641328, 0.11430824840707438, 0.2295437827706337, 0.13150391355156898, 0.08014211032007422, 0.2213718734149422, 0.09245876941297736, 0.12089541208531175, 0.15639913268387318, 0.23911261931061745, 0.2070931624621153, 0.15655739419162273, 0.1507346409239939, 0.11422742131565299, 0.11693480318146092, 0.4013195096382073, 17.842930555343628, 78.16926302228654, 107.03238568987165, 82.42982196807861, 82.15388815743583, 65.78562068939209, 49.43666573933193, 40.93689618791853, 29.872949532100133, 42.36748511450631, 84.52080590384347, 90.84139456067766, 60.04179504939488, 27.981347629002162, 12.80148788860866, 45.4078882762364, 52.871000494275776, 11.717194574219839, 0.7454528478639466, 0.06607368415487663, 0.7771840223244258, 0.14314057199018343, 0.24471278595072882, 0.1360638588666916, 0.34275705207671436, 0.6112273303525788, 0.22345112184328692, 0.20253578200936317, 0.18351398913988046, 0.3099289850464889, 0.4074427182120936, 0.22665189366255487, 0.4146499271903719, 0.3944282265646117, 0.3213982353253024, 0.5437794295804841, 0.22980002473507607, 0.4769425360219819, 0.6480066967861993, 0.37581747663872583, 1.6874027060610908, 6.8968053715569635, 5.267144909926823, 5.121591440268925, 7.249965803963797, 14.310972741671971, 15.199102776391165, 9.664171252931867, 7.0342594129698615, 14.871092217309133, 12.668768610273089, 12.09413434777941, 20.426032815660747, 39.299528871263774, 26.910444361822947, 13.15523978642055, 6.266777898584094, 10.75537976196834, 21.01671133722578, 13.077693547521319, 18.93644326073783, 9.12800829751151, 5.871408028262002, 3.547947572810309, 0.9479761719703674, 0.4162509984203747, 0.987223397408213, 0.21102337299713067, 0.26156870861138615, 0.21683623322418757, 0.4431979310299669, 0.32740962132811546, 0.35768745520285194, 0.7428500418152127, 0.22720504898045743, 0.5563605544822556, 0.42538779814328465, 0.17199786566197872, 0.18018772905426367, 0.19177858637911932, 0.35536119288631846, 0.27510789781808853, 0.2169722252126251, 0.22565877623856068, 0.5861599668860435, 0.5488990034375871, 0.18088976852595806, 0.369652226035084, 1.3554101777928216, 10.997888394764491, 34.35354403087071, 44.58091367994036, 46.90000350134713, 55.110495226723806, 84.91933373042515, 52.3394216128758, 29.698393412998744, 35.2013076373509, 45.749468667166575, 48.60502542768206, 69.02561432974679, 76.5986088344029, 92.12292725699288, 40.33228479112898, 1.1086189576557703, 0.2120872616235699, 0.2614415240074907, 0.29847178554960657, 0.1375020138387169, 0.1760206962270396, 0.11460832373372146, 0.11763468491179602, 0.1276280672422477, 0.1191839160663741, 0.11654737325651304, 0.23472952736275537, 0.16648468721125806, 0.10159097545381103, 0.1079451980601464, 0.129984157958201, 0.0969899312726089, 0.1757593381085566, 0.1291029988122838, 0.13876446895301342, 0.06729819559093032, 0.1413276485566582, 0.1333926429173776, 0.13741163297423295, 0.09709834759788853, 0.10045681774084057, 0.10973214717315775, 0.08479363072131361, 0.08850106463900634, 0.09268765284546784, 0.1337630958961589, 0.2505388233278479, 0.048297257495245764, 0.14270985153104576, 0.0826630171920572, 0.10676302720925637, 0.11802999941366059], [0.05668333625154836, 0.03393919526466301, 0.03972769947722554, 0.05170712327318532, 0.023902983803834234, 0.0343938917586846, 0.020940318404297744, 0.04311313120914357, 0.10098945415977921, 0.07338049528854233, 0.03966751002839633, 0.032159886455961635, 0.035008413783673725, 0.02066573903097638, 0.01895842109141605, 0.009583314780944159, 0.04755474340968898, 0.010605453995854726, 0.02690310264006257, 0.05949158913322857, 0.11742815242281981, 0.11643337937338011, 0.10357708138014589, 0.024880150565877557, 0.048734654738966904, 0.03699340351990291, 0.04230603416051183, 0.040910823669816763, 0.11425802324499403, 0.007293940172530711, 0.07399913602109466, 0.09827338704573256, 0.032549677682774406, 0.4049739906830447, 20.307305472237722, 69.13871710641044, 79.06959669930595, 67.98251601627895, 64.3523393358503, 55.773836272103445, 47.88413940157209, 31.134196962629044, 35.21799373626709, 51.72065326145717, 46.671077728271484, 50.31892715181623, 25.217840603419713, 26.369824137006486, 28.16735785348075, 56.34432506561279, 12.968702367373876, 0.17240844720176288, 0.36819956398436, 0.5051497252924102, 0.056960721367171833, 0.06487768476030656, 0.0712667094277484, 0.20088496059179306, 0.10274095660341637, 0.17050544145916188, 0.06981492268719844, 0.016711998597851822, 0.10336911039693014, 0.12459521926939487, 0.03970815088333828, 0.03859996409820659, 0.2933668680489063, 0.24608999490737915, 0.5728626347013882, 0.4797403801764761, 1.8257090960230147, 2.2893634736537933, 2.302258027451379, 8.253848484584264, 3.755871764251164, 4.388763197830745, 3.0865116247109006, 9.324452110699244, 7.220547999654498, 9.25835997717721, 8.211064951760427, 6.512035846710205, 8.8344338791711, 6.9316184520721436, 5.871870517730713, 8.363944428307668, 9.794252821377345, 13.223339080810547, 11.648859041077749, 15.80746967451913, 7.0736830575125555, 7.13457099028996, 10.965194514819554, 4.663132795265742, 2.657685092517308, 2.490780242851802, 1.743156028645379, 0.4199635892042092, 0.28537814957754953, 0.5103697766150747, 0.5123261830636433, 0.8170089253357479, 0.6891163651432309, 0.421915164483445, 0.359935143164226, 0.2026401949780328, 0.023045288398861885, 0.06052170028643949, 0.024306033604911396, 0.1014878720577274, 0.10119814439011471, 0.03364058557365622, 0.023078853829896877, 0.028608274712626423, 0.06545352350388255, 0.05888707549976451, 0.05215529226032751, 0.17524086950080736, 0.03525926139471786, 0.05391732217477901, 0.05661125547651734, 0.05672327143007091, 0.22260147386363574, 0.06922654461647783, 0.19744685079370225, 0.43121619682226864, 6.372971126011439, 18.066921370370046, 28.68644561086382, 22.732405696596416, 45.96904216493879, 68.06483132498605, 36.181924274989534, 18.924832820892334, 31.99617658342634, 33.590221881866455, 48.607415607997346, 50.79029294422695, 67.39970111846924, 29.25352805001395, 0.479951160294669, 0.09970877359488181, 0.0703722442101155, 0.03295855609966176, 0.01945183309726417, 0.03871906056467976, 0.05440984699609024, 0.05455182705606733, 0.05329171967293535, 0.0687253311542528, 0.12060387272919927, 0.1162557660468987, 0.03250158990600279, 0.021157721024272696, 0.02026994276924857, 0.02644991927913257, 0.010583570393334542, 0.1020233922504953, 0.032485657903764925, 0.04577921743371657, 0.030936793158096925, 0.03178959293290973, 0.0384733460710517, 0.03884787025994488, 0.06912767527891056, 0.044129922719938416, 0.03317582640530808, 0.046554552258125374, 0.052584981346236806, 0.061783646499472, 0.06127781221376998, 0.008473211134384786, 0.02267200592905283, 0.08050068893602916, 0.010916664082157825, 0.006436107364217085, 0.010638296787094857, 0.009651784901507199, 0.018944578977035623, 0.08064661467713968, 0.05729076758559261, 0.021801793249323964, 0.015865556696163755, 0.03509299995909844, 0.06826795783958264, 0.02290216161470328, 0.043837128074041436, 0.0747667219755905, 0.01862507888914219, 0.08118738673095192, 0.010762580653785594, 0.035405936917024, 0.02251928805240563, 0.012061051558703184, 0.009076148022099264, 0.04524775827303529, 0.0963574212842754, 0.02450663230514952, 0.07627947508756604, 0.04875481401437095, 0.04204735964802759, 0.07311236539057323, 0.017922751040064862, 0.02878230537420937, 0.0330853471532464, 0.0370259392740471, 0.06682837794401816, 0.03420287736558488, 0.030049920747322694, 1.2164024540356226, 35.40689788545881, 89.97035448891776, 93.522127696446, 90.00869464874268, 103.52308682032994, 84.25516932351249, 67.62635830470494, 24.54089151109968, 20.910318783351354, 17.847436462129863, 44.45847599846976, 64.1271482195173, 28.37509683200291, 24.390942437308176, 15.70676074709211, 29.814397062574113, 6.832898012229374, 0.027291139853852134, 0.17251777276396751, 0.4465458228119782, 0.08094515651464462, 0.08679447442825351, 0.051102087167756896, 0.1823511022542204, 0.13995753707630293, 0.12264183908700943, 0.07026489318481513, 0.06409975793212652, 0.19996313005685806, 0.7791406459042004, 0.45885197818279266, 0.3562136228595461, 1.0602423420974185, 0.4591795748897961, 1.3608593025377818, 1.5273867781673158, 2.1139386125973294, 2.7134513344083513, 3.910675891808101, 5.432763908590589, 7.541906527110508, 9.093507017408099, 10.515673858778817, 15.052534001214163, 11.985018968582153, 20.76260529245649, 16.358513934271677, 13.747558082853045, 11.459354741232735, 11.828300612313406, 7.4167130163737705, 11.097858207566397, 13.557756747518267, 13.26880635534014, 17.599210330418178, 16.249204874038696, 8.617472035544258, 10.476845588002886, 7.532444817679269, 4.32310836655753, 2.586336429630007, 1.448251138840403, 2.4214105137756894, 1.4372108855417796, 1.08636366043772, 1.0322348049708774, 1.4175936239106315, 1.556403106876782, 1.6351813482386726, 0.8075554668903351, 0.7233451998659542, 0.20061351944293293, 0.14383906950908049, 0.1352391131222248, 0.0459828763268888, 0.07178084898207869, 0.02661274223854499, 0.06715376262686082, 0.11736450583807059, 0.05160288672362055, 0.10240474928702627, 0.1191843638994864, 0.061748444102704525, 0.1029957193615181, 0.06364232354930469, 0.017407303609486138, 0.08736424706876278, 0.09844166373035737, 0.12043381828282561, 0.006714166774015341, 0.19039200006851129, 0.13220801576972008, 4.6063872916357855, 12.691074064799718, 16.9963116645813, 29.62097658429827, 58.9632887159075, 51.62830127988543, 13.750427688871111, 14.202860508646284, 36.63604811259678, 57.023052896772114, 73.30405793871198, 61.7110789162772, 78.1637739453997, 45.19318546567644, 2.108288207224437, 0.19462688639760017, 0.04463116671623928, 0.08260048340473856, 0.038244808691420724, 0.03992703949500408, 0.030838833057454655, 0.03873494167679122, 0.014504471427894064, 0.049099923710205724, 0.0769874517406736, 0.04908013762906194, 0.03653567736702306, 0.04641243988381965, 0.013674590021504887, 0.05283107242680021, 0.08089227828064136, 0.029133650806865523, 0.01812645573435085, 0.032354649755039384, 0.04483067297509738, 0.04471742208780987, 0.06089061977607863, 0.026945361801023995, 0.021146369133410708, 0.02625514580202954, 0.04369693595383849, 0.026222196141523973, 0.04740850893514497, 0.013011186333772327, 0.05062544006588204, 0.024775379669985602, 0.035530953601534875, 0.053314783078219206, 0.002469733457214066, 0.019915399740317037, 0.1107532541666712, 0.09746629678245101, 0.09857860566782099, 0.1464014213000025, 0.1607241284634386, 0.06976866016962699, 0.08323015033134393, 0.1286434813269547, 0.2046738187117236, 0.12347199954092503, 0.10420334884630782, 0.1379256775336606, 0.08630501997790166, 0.21266943109886988, 0.0828027343377471, 0.10931457672268152, 0.0935138642255749, 0.09337041513728243, 0.09726230201444455, 0.10856974204736096, 0.19269025245947496, 0.19980166586382048, 0.18395087069698743, 0.09871243991489921, 0.12755800171622209, 0.10684166263256754, 0.13294071145355701, 0.11793687726770129, 0.21887614019215107, 0.12097858690789767, 0.23862038286668913, 0.13054511642881803, 0.09927202774477856, 1.1777249808822359, 36.72637816837856, 100.37902695792062, 104.06652627672467, 87.68851048605782, 90.40901511056083, 72.15917546408517, 62.06791755131313, 42.700192655835835, 50.011973108564106, 70.66782106672014, 68.36948898860386, 70.7526307787214, 38.53989621571132, 35.64494316918509, 36.095558166503906, 76.29814788273403, 21.412796872002737, 0.2827264347246715, 0.5791270328419549, 0.8540550917387009, 0.30638144112059046, 0.16696405863123281, 0.2268951620374407, 0.4710763565131596, 0.3709589759153979, 0.35630386801702635, 0.14413387940398284, 0.23164083595786775, 0.34092142486146515, 0.42088110425642555, 0.212897283158132, 0.1731980312615633, 1.031777635216713, 0.8326203333480018, 1.0131035915442874, 1.3502288843904222, 1.9768480488232203, 4.756058871746063, 4.4229874185153415, 13.69081735610962, 9.869586059025355, 13.158300467899867, 10.028181297438485, 19.785033702850342, 16.75030721936907, 18.556752000536235, 19.323402336665563, 15.493056740079608, 18.42963818141392, 14.544937695775713, 12.60311942441123, 14.892537832260132, 19.674868277141027, 21.516441413334437, 27.05544110706874, 31.355830601283483, 17.683577094759258, 21.76415511540004, 22.167268753051758, 8.864378878048488, 5.401934317180088, 3.4704356406416212, 3.132903878177915, 1.7602452316454478, 0.7558906706316131, 1.2817201891115733, 1.5215101220778056, 1.456373582993235, 1.4350223115512302, 0.6864930401955331, 0.8657686146242278, 0.29557053265827044, 0.22046001734478132, 0.29263766003506525, 0.10848731361329556, 0.3533332145639828, 0.19675992908222334, 0.22785398630159243, 0.17152413965335914, 0.11139343838606562, 0.2111722164388214, 0.20186988131276198, 0.19049429600792273, 0.36251623609236305, 0.13364982126014574, 0.23256098372595652, 0.23752460309437343, 0.2954669882144247, 0.6137822589703968, 0.08740803293351616, 0.46456182322331835, 1.3079638608864375, 12.0151880468641, 28.839139223098755, 38.83471870422363, 36.81489127022879, 67.54151385171073, 94.35718304770333, 50.193567752838135, 30.116973740713938, 42.14299924033028, 46.88084384373256, 65.95322513580322, 65.89149733952114, 89.56679616655622, 49.30081108638218, 1.1330856276409966, 0.24969013886792318, 0.18449481150933675, 0.14568468475980417, 0.1734307144901582, 0.15364061641905988, 0.12319059749799115, 0.14335668539362295, 0.13335023447871208, 0.1599879451096058, 0.13828944015715802, 0.18863452651671, 0.15213563931839807, 0.1541776226035186, 0.12061292438634805, 0.10823018955332891, 0.249910119920969, 0.14920951133327826, 0.1203357699726309, 0.1849417353847197, 0.18669888323971204, 0.10209348491792168, 0.1760746669024229, 0.09587105416825839, 0.14227862895599433, 0.11768990409161363, 0.15100790054670402, 0.2313446147101266, 0.19509850894766195, 0.1421885330762182, 0.16672978763069424, 0.08127447670059544, 0.11945941485464573, 0.1929528997944934, 0.09723049229277031, 0.14706859764243874], [0.037476357604776106, 0.05483461331043925, 0.11005557088979653, 0.011368560771058713, 0.03970612884898271, 0.01418765664233693, 0.08009429395731006, 0.04173095537615674, 0.037220512583319626, 0.04779928743040987, 0.03996162781757968, 0.04569568298757076, 0.041841230887387476, 0.061051025454487116, 0.002293971471122599, 0.029194895377648727, 0.07677470387092658, 0.028409640371267284, 0.019656223111918995, 0.030323187155382972, 0.04982199353565063, 0.0153911657232259, 0.13748654324029172, 0.03177607651533825, 0.116182823532394, 0.076857132304992, 0.03524926996656826, 0.025126553772549545, 0.07070311145590884, 0.06320908572524786, 0.055929765437862704, 0.06199778536600726, 2.070119146789823, 32.72438948495047, 79.24813066210065, 70.02275725773403, 59.74186216081892, 53.42568908418928, 43.36127553667341, 40.80667652402605, 28.787025996616908, 52.356204986572266, 57.903973306928364, 83.77926635742188, 45.52239806311471, 11.981077602931432, 38.202206815992085, 38.92139400754656, 26.305490766252788, 0.9971230604818889, 0.5428710068975175, 0.13975978483046803, 0.13047943423901284, 0.018705788933272873, 0.08959853396351848, 0.15838466185544217, 0.013299176103568502, 0.13097969096686157, 0.07447438194815602, 0.09118657732116324, 0.09988611550735575, 0.05964301100799015, 0.11944614270968096, 0.12873889692127705, 0.7440154392804418, 2.766682569469724, 1.0853627941438129, 0.7385049749697957, 3.762221549238477, 2.6682111791202, 10.16149812085288, 9.443999341556005, 7.379530600139073, 9.636674625532967, 10.205215317862374, 16.52940140451704, 5.058515693460192, 11.534129517418997, 7.069894986493247, 20.765104906899587, 15.345348460333687, 17.08915523120335, 17.98080713408334, 13.543071729796273, 20.21230275290353, 11.588094438825335, 9.940786855561392, 11.565124562808446, 8.995977759361267, 8.47952423776899, 8.222967215946742, 7.565634625298636, 1.7695148885250092, 1.6903145440987177, 1.7937673585755485, 2.293186719928469, 1.453628067459379, 1.4160920530557632, 2.311156064271927, 1.5992028159754617, 2.6767155570643286, 2.642150874648775, 2.6657825665814534, 2.347907257931573, 2.0419352991240363, 1.3314580002001353, 1.1619564784424645, 0.8448214243565286, 0.5093673904027257, 0.24120402708649635, 0.2218194758253438, 0.035708061419427395, 0.04946901961894972, 0.0211809133512101, 0.135682006499597, 0.016989107210455195, 0.06190308901880469, 0.11704904133720057, 0.05667126172089151, 0.18229299251522335, 0.26902160154921667, 0.04864116618409753, 0.11338310662124838, 0.09248026540236813, 0.09254463123423712, 0.027280853262969425, 0.07801794965884515, 2.6650000257151465, 28.830952508108957, 27.985709360667638, 8.706172738756452, 23.090609652655466, 62.44958904811314, 49.63797589710781, 32.647730009896414, 21.374083246503556, 30.25052853993007, 48.96681465421404, 51.10527563095093, 60.2668194089617, 38.28574848175049, 3.010812520980835, 0.2416209461433547, 0.015598364872857928, 0.09058917473469462, 0.012582571029530039, 0.04641284021948065, 0.029061061130570512, 0.07786811555602721, 0.05129693867638707, 0.02569109490806503, 0.005029745998659304, 0.002643469804232674, 0.037324827164411545, 0.02248750377579459, 0.02444420029808368, 0.01720499839367611, 0.024328530433454683, 0.014792165186788355, 0.07018459535070828, 0.044476735538669994, 0.04610368609428406, 0.029589422778891664, 0.04112588195130229, 0.02789953979663551, 0.07020194549113512, 0.021096841166062013, 0.0062672742808769855, 0.04606830727841173, 0.04795101125325475, 0.0511366279928812, 0.07688224488603217, 0.03141001705080271, 0.011583993094973266, 0.050014538025217395, 0.060994171005274565, 0.027503178654504672, 0.03072042191135032, 0.052117762488446066, 0.06895196185048137, 0.0682934300441827, 0.03738291994003313, 0.00041308806404621076, 0.04553878194253359, 0.03425523652029889, 0.022983098968065212, 0.08267626219562121, 0.029016617086849043, 0.014390760833131415, 0.03102011386571186, 0.014625481363119823, 0.014835335281012314, 0.03477235484336104, 0.03373187228239008, 0.028752018963651996, 0.04365731290142451, 0.012588331791838365, 0.06679377944341727, 0.02510652850781168, 0.08662187547555991, 0.05707455240190029, 0.018663105687924793, 0.041673588633005104, 0.024738901627383063, 0.10477310113076653, 0.06879062657909733, 0.06385918334126472, 0.07831951776253325, 4.86438215630395, 48.22396189825875, 95.24075766972133, 84.69515705108643, 80.63050256456647, 76.66745158604213, 49.14740528379168, 37.19063942773001, 13.969104869025093, 35.17442853110177, 53.483018670763286, 83.37647928510393, 55.227322237832205, 6.262853903429849, 22.23677679470607, 28.92615498815264, 14.88993399483817, 0.19490119096423897, 0.47628110008580343, 0.316423026578767, 0.13832441185201916, 0.0027528808194412185, 0.047796359551804404, 0.19775614062590258, 0.16180959450347082, 0.23679699642317636, 0.16678037920168468, 0.4277282554124083, 0.26764319837093353, 0.5907285160252026, 0.7282563277653286, 0.1336946724248784, 1.5868356738771712, 0.854294587458883, 0.4925474300980568, 0.5738011300563812, 2.40736169048718, 1.0879186455692564, 2.3848013239247456, 1.6692493430205753, 1.3913412668875285, 2.4626228851931433, 4.300966194697788, 4.045861346381051, 5.177033722400665, 7.670195460319519, 10.62687543460301, 28.793569462639944, 21.946071113858903, 20.465425627572195, 21.257237127849034, 18.057647262300762, 23.707026038851055, 15.581943307604108, 11.178740450314113, 15.349506957190377, 21.013409205845424, 15.206870862415858, 12.67224531514304, 4.597582186971392, 3.174214175769261, 2.9153939953872134, 3.9368853654180254, 2.358587941953114, 1.3930592089891434, 1.2255485632589884, 1.9611720442771912, 1.3136613837310245, 2.2288233850683485, 2.6602871928896223, 3.2841388029711585, 2.4618409957204546, 2.9411251289503912, 2.53776678442955, 1.8569657845156533, 1.176482121859278, 0.9060665379677499, 0.41120180221540586, 0.4162962431354182, 0.10312381998768874, 0.032535123106624396, 0.12336088264627115, 0.12330136155443532, 0.16115826873907022, 0.1485549828835896, 0.12062074110976287, 0.15114906297198363, 0.1786615273782185, 0.5134320322956357, 0.028160134563222528, 0.06542233124907527, 0.10422517053250756, 0.044856633724910874, 0.040984495609466515, 0.2808701257620539, 1.17252707694258, 16.99051512990679, 10.775128279413495, 10.325820411954608, 27.620060409818375, 46.317925112588064, 32.31465768814087, 14.079522166933332, 15.47240148271833, 41.83877583912441, 74.58527101789201, 71.04025145939418, 75.24400888170514, 57.621504715510774, 9.092355353491646, 0.09681832298104252, 0.026955220914844955, 0.07428207155317068, 0.09459099785557815, 0.06821859441697598, 0.0370910039969853, 0.016373477477048124, 0.02042741548003895, 0.04711499843480332, 0.03313919569232634, 0.0472097388867821, 0.08351181021758489, 0.029610155416386466, 0.05130009725689888, 0.0854583236255816, 0.015685534570366144, 0.02285889313290162, 0.02276959453177239, 0.038602053986064026, 0.009608999027737548, 0.022556587122380733, 0.08115977714104311, 0.03539791324042848, 0.04656965984031558, 0.07785485019641263, 0.021809894957446625, 0.010722798993811011, 0.0369850270050977, 0.03968691612992968, 0.07060952790613685, 0.05761720399771418, 0.0032669991695521666, 0.016699018222945075, 0.026642401004210114, 0.15163834100323065, 0.14590473366635187, 0.17084514323089803, 0.1018145934545568, 0.17685705849102565, 0.14638692779200418, 0.14963012162063802, 0.10353315302303859, 0.06757979440901961, 0.10516647502247777, 0.26485816495759146, 0.10408615906323705, 0.06629135818885905, 0.1287449901657445, 0.145290075934359, 0.1367733757942915, 0.22708899235086782, 0.14015663282147475, 0.10434450448623725, 0.1562570474509682, 0.09163192699530295, 0.13714996272964136, 0.18264764919877052, 0.1589518492775304, 0.21015801014644758, 0.16505406397793973, 0.2065447433186429, 0.15018736171935285, 0.2135400322398969, 0.1562168374657631, 0.13733547420373984, 0.16573110621954712, 5.280901040349688, 52.5863744871957, 108.33048983982631, 91.41385664258684, 84.53197165897915, 75.51631573268345, 53.949611050742014, 51.77906676701137, 39.54285478591919, 74.37308692932129, 83.45410455976213, 116.61042186192104, 70.05309309278215, 18.735682010650635, 54.603770051683696, 56.31305122375488, 39.19973189490182, 1.4504473124231612, 0.9610570243426731, 0.6845075924481664, 0.6310898416808673, 0.1623049114963838, 0.2208090964704752, 0.4658713958093098, 0.1276673408491271, 0.44061444965856417, 0.16026267036795616, 0.3858811823385102, 0.4328418310199465, 0.21125722330595764, 0.4335909608219351, 0.25173497200012207, 3.0157596383775984, 7.516971179417201, 3.108811433826174, 3.4386513233184814, 12.126298427581787, 12.337094613483973, 28.0360803263528, 23.894135815756663, 20.147133861269268, 28.707693202154978, 22.179876259395055, 32.866355078560964, 11.619821650641304, 20.068049464906963, 18.20128389767238, 34.602077620370046, 29.428365571158274, 27.004059178488596, 32.43005337033953, 25.95092592920576, 32.820941652570454, 22.587158816201345, 18.06729483604431, 21.86640133176531, 18.37773166384016, 18.203022684369767, 17.937045642307826, 17.061529193605693, 7.041045197418757, 5.367427391665323, 4.616464350904737, 4.201752432755061, 1.915803347315107, 1.798820978828839, 4.967714462961469, 2.7217976408345357, 3.5737349433558325, 4.711185668195997, 5.03683123418263, 3.8608208298683167, 3.2881057901041846, 2.5632716672761098, 2.1552102608340125, 1.2782932072877884, 0.9141317137650081, 0.5920631672654832, 0.5988601882542882, 0.1509968132844993, 0.10914127887891871, 0.22157687241477625, 0.2867857569030353, 0.29876480411205975, 0.3621376949761595, 0.23110623178737505, 0.23759177806121962, 0.349793297371694, 0.6834318158882005, 0.12204090133309364, 0.40821060272199766, 0.3528705622468676, 0.18597422141049588, 0.11342848704329558, 0.5244466098291534, 5.8373088751520426, 44.70120089394705, 37.56273978097098, 15.767573118209839, 36.72728143419538, 89.53388254983085, 65.22135748182023, 48.94462558201381, 28.399427686418804, 40.70468739100865, 70.50397559574672, 67.38724299839565, 82.05718312944684, 64.26668194362095, 7.223916573183877, 0.3950759289520127, 0.13790557932640823, 0.178346700700266, 0.20766134054533072, 0.19843971037438937, 0.09354736349944558, 0.17132342899484293, 0.1581500515873943, 0.12604146237884248, 0.09519954877240316, 0.2841957344540528, 0.17335314436682633, 0.1251846897814955, 0.211872043886355, 0.10965446848422289, 0.08812229282089643, 0.07784547284245491, 0.1936603132635355, 0.1622415498963424, 0.13923396090311663, 0.17024793741958483, 0.15633592036153587, 0.09994923962014061, 0.13069484196603298, 0.15051484986075334, 0.08709231737468924, 0.1478926512811865, 0.09268449765763112, 0.12901993255530084, 0.26162969533886227, 0.1426671038248709, 0.07277848544929709, 0.10099418354885918, 0.10089198938970055], [0.01721817554373826, 0.050140141642519405, 0.017559855245053768, 0.015617307874241045, 0.07349094721887793, 0.006317546940408647, 0.04957861998783691, 0.0580929181139384, 0.021427085855975747, 0.03677354121048536, 0.009839316713623703, 0.040366526626582654, 0.04332856947023954, 0.014403210254386067, 0.05286376763667379, 0.02792019779527826, 0.03497061259778483, 0.044133250934204886, 0.04121223231777549, 0.03361957812947886, 0.020981686988047192, 0.058315491170755455, 0.07375385239720345, 0.07593807019293308, 0.07284460868686438, 0.06334474523152624, 0.019650630287027786, 0.042310682125389576, 0.033306943119636605, 0.045133713499775956, 0.20738580104495796, 3.023550523178918, 41.58203295298985, 71.98672117505754, 66.993453843253, 68.3704617364066, 56.8595791544233, 45.723708220890586, 49.90864644731794, 54.504337855747764, 69.27699320656913, 49.74173334666661, 42.959426471165244, 32.71169165202549, 29.789463451930455, 48.4075472014291, 16.72662775857108, 1.8636245472090585, 0.34562597955976215, 0.008832852505812687, 0.39504973750029293, 0.0546463232354394, 0.05656692339107394, 0.09294060391506978, 0.03877725512055414, 0.13942608130829676, 0.06923977604934148, 0.06453896686434746, 0.0347811079451016, 0.0990631610953382, 0.09239647989826542, 0.16832566128245421, 0.18433817848563194, 2.250487651143755, 4.971831270626613, 3.816617258957454, 2.267007210424968, 1.3454387528555733, 4.098475277423859, 4.3678617136819025, 3.7535632252693176, 2.8782521826880316, 3.4881945848464966, 4.5545415707996915, 8.270931499344961, 9.11474244935172, 12.167118225778852, 9.529663681983948, 9.663036090987069, 26.22957648549761, 7.7820128202438354, 13.573431883539472, 10.948306918144226, 22.42738846370152, 18.41391440800258, 14.201207705906459, 15.314785071781703, 16.64300271442958, 16.867431265967234, 8.414318868092128, 10.996264253343854, 5.666262899126325, 1.0867947744471687, 0.6414602994918823, 1.3634734536920274, 1.3274307591574532, 2.0829370532717024, 1.3147102360214507, 1.1126707345247269, 1.618885651230812, 3.3294818784509386, 3.9394687925066267, 3.809028957571302, 3.1618774320398058, 3.2336553633213043, 3.5543186366558075, 3.0042002243655066, 2.4529837795666287, 2.5144006439617703, 1.6187485328742435, 1.0697902526174272, 0.6207510307431221, 0.1945516097226313, 0.04667950448180948, 0.08765378474657025, 0.0071803686774468845, 0.05746510358793395, 0.12445530534854957, 0.0788888493552804, 0.036074487292873006, 0.027904991825510348, 0.08085157296487264, 0.17119081611079828, 0.05467530346608587, 0.19945823214948177, 0.05173437663220933, 0.03934992171291794, 0.3243169129959175, 1.0857550416673933, 28.590511832918438, 43.33417756216866, 24.053678614752634, 47.47054788044521, 66.66688850947789, 57.70590100969587, 53.070010798318044, 24.786136865615845, 23.916653190340313, 36.89648396628243, 46.10554300035749, 54.55855117525373, 44.63736431939261, 12.242735471044268, 0.11840886622667313, 0.03332152483718736, 0.037205323576927185, 0.01594393257983029, 0.09489875419863633, 0.12525062981460774, 0.054095020318137746, 0.07400119198220116, 0.07010097269501005, 0.1352527245346989, 0.02731286993782435, 0.027742119672309076, 0.02256224610443626, 0.1072373299726418, 0.06032484370682921, 0.021554589371329973, 0.0575246178944196, 0.03505673226235168, 0.038534624568585835, 0.013231972298984016, 0.055271891810532124, 0.03671645945204156, 0.038908181845077446, 0.04416899276631219, 0.03647067371223654, 0.011679704700197493, 0.053481675551405976, 0.033129126232649596, 0.03999978184167828, 0.04946579657761114, 0.053850347375763316, 0.0457831190100738, 0.011861299330900823, 0.019369772768446376, 0.0590373370796442, 0.027754927020786063, 0.05806579028389283, 0.08118389906095606, 0.013011643496741141, 0.017608850562412823, 0.08489435245948178, 0.11590984889439174, 0.053196290507912636, 0.042958879843354225, 0.030439521984330246, 0.041180103684642484, 0.08481087908148766, 0.030150537312562977, 0.11851463626538004, 0.008472743793390691, 0.07387203284140144, 0.013859353410745305, 0.06127083008842809, 0.03430656769445964, 0.06353978333728653, 0.049059048760682344, 0.04045028159660952, 0.02107996939282332, 0.02689545724673995, 0.050362015808267255, 0.04668216433908258, 0.015005874879924315, 0.017392513242417147, 0.48618999123573303, 7.049835102898734, 61.56884929112026, 86.81201607840401, 85.68141215188163, 91.13025202069963, 85.26833479745048, 58.51702676500593, 29.59242296218872, 36.60561152866909, 57.63426855632237, 57.58653095790318, 43.15409762518746, 37.09221472058977, 20.48808891432626, 23.00018753324236, 10.311216167041234, 0.28411314317158287, 0.22010040735559805, 0.0333434924084161, 0.5477295347622463, 0.045052350365689824, 0.027135807921045592, 0.14326239616743155, 0.18433042961571897, 0.20638094496514114, 0.21504424938133784, 0.4323481289403779, 0.4147451120827879, 0.5322355404496193, 0.16908415486770018, 0.3906596159296376, 0.8199458420276642, 0.5582048669457436, 1.613549326147352, 1.0254898411887032, 0.8486458105700356, 1.2761289519923074, 2.180556203637804, 1.810222647019795, 1.4732144964592797, 1.2584601172379084, 1.5108690645013536, 2.021262454135077, 2.3947400706154958, 2.994186133146286, 2.7389863984925404, 0.6073898619839123, 6.191648330007281, 16.88300391605922, 12.372124825205121, 20.528659445898874, 14.553713270596095, 30.08596740450178, 23.646785157067434, 18.565595320292882, 22.42492011615208, 26.773761136191233, 17.918214287076676, 11.476758241653442, 14.976918492998395, 7.446208119392395, 2.4360240953309193, 0.8944426359874862, 0.623843847640923, 1.0164910554885864, 2.9849367780344824, 2.4388498408453803, 3.5614915660449435, 4.651810705661774, 5.013936051300593, 5.252786457538605, 5.305541089602879, 5.235828944614955, 4.765410278524671, 4.554078212806156, 4.149502847875867, 2.8801299333572388, 3.0549216398171017, 2.34858210171972, 2.3549724902425493, 1.6084082020180566, 0.5025177693792752, 0.3119469481919493, 0.21490312766815933, 0.05960201392216342, 0.016700741701892445, 0.03249276555808527, 0.06737544001745326, 0.03502568928524852, 0.11614800111523696, 0.04098572036517518, 0.24136237001844815, 0.15142393750803812, 0.1285661147641284, 0.019848747245435203, 0.06136029493063688, 0.3916698188654014, 0.148342031453337, 13.579796433448792, 13.918184127126422, 16.575874430792673, 57.4291855267116, 65.98530496869768, 47.539109230041504, 26.240697077342443, 13.657697030476161, 38.81447512762887, 61.983128683907644, 64.65936633518764, 65.66898127964565, 62.44280760628836, 24.456033161708287, 0.4996313356927463, 0.04701228519635541, 0.12459634563752583, 0.060277875512838364, 0.12276898297880377, 0.06940354047609226, 0.04260754458872335, 0.06400586904159614, 0.06591889674642257, 0.038437872260276756, 0.026120397229013697, 0.03308012243360281, 0.00710445163505418, 0.02110841018812997, 0.027845781163445542, 0.005282497324515134, 0.028935121638434272, 0.033687194144087176, 0.0667776031685727, 0.06003624240734747, 0.022843548063454882, 0.06795452894376856, 0.03552317080487098, 0.06766203285327979, 0.07350900303572416, 0.06754185073077679, 0.038370802466358454, 0.036748445592820644, 0.051297620604080815, 0.08861989647682224, 0.04631402177203979, 0.014794448457126106, 0.0409460498153099, 0.11735823617449828, 0.18844137473830155, 0.1791763047554663, 0.11300761891262871, 0.14077669169221604, 0.04582149016537836, 0.11502988397010735, 0.1740928018199546, 0.1685676404408046, 0.1698209081909486, 0.11122191830405168, 0.09606044686266355, 0.1887472311833075, 0.14987493705536636, 0.17846129169421537, 0.16448968569082872, 0.10307784245482512, 0.1821621981050287, 0.16841263590114458, 0.1100500136879938, 0.1255081474248852, 0.16041862485664232, 0.1474199023629938, 0.18324290082923003, 0.13460473716259003, 0.1668440257864339, 0.13313853155289376, 0.18286909588745662, 0.10283566652131931, 0.10973933964435544, 0.5271148266536849, 9.545908570289612, 70.32032775878906, 102.05316761561802, 90.11054134368896, 97.54864352090019, 76.13028635297502, 61.33037321908133, 69.91806180136544, 71.7637117930821, 93.38672815050397, 68.73218495505196, 64.22679233551025, 44.23621007374355, 41.97965056555611, 68.80045100620815, 28.66929050854274, 3.151930868625641, 0.4973383758749281, 0.10317236916827303, 0.9151365969862256, 0.15590262146932737, 0.09447509050369263, 0.24925709781902178, 0.3807355527366911, 0.21968171053699084, 0.29836123862436836, 0.3820203723652022, 0.22444366929786547, 0.2979399769433907, 0.13989788027746336, 0.7056518835680825, 1.4033898775066649, 6.138011710984366, 15.701660769326345, 12.780285460608345, 6.329656490257808, 5.7609264595167975, 11.891707267080035, 11.722326687404088, 10.976967368807111, 9.92696167741503, 15.890432902744838, 15.507039989743914, 19.73266860416957, 22.297599588121685, 22.91866605622428, 20.188133444104874, 18.484822511672974, 38.4581367628915, 14.723698343549456, 25.09165436880929, 22.11754744393485, 36.52753809520176, 30.330648217882427, 27.390359912599834, 30.716537271227153, 33.53904492514474, 26.57004690170288, 20.21405369894845, 21.498280559267315, 12.130694031715393, 3.7127086860792975, 2.1399072876998355, 2.0997156500816345, 3.4796187707356045, 6.34159653527396, 3.973192308630262, 5.122641486780984, 6.454682375703539, 6.725025926317487, 7.216517175946917, 7.24447021314076, 6.381483103547778, 6.195951001984732, 5.3716162868908475, 4.725630973066602, 3.2860287129879, 3.889380531651633, 2.27948574083192, 2.061785651104791, 1.6412530967167445, 0.5297371202281543, 0.3014802469738892, 0.345018880707877, 0.1118105338620288, 0.16540889708059175, 0.33059433900884216, 0.14352752694061824, 0.15250628228698457, 0.1534549013844558, 0.22424872618700775, 0.485128002507346, 0.22280882059463433, 0.35017362982034683, 0.23444492263453348, 0.21412587937499794, 0.749448224902153, 2.8520915635994504, 51.8353020123073, 63.26033265250069, 29.115338802337646, 59.68626962389265, 93.407315662929, 77.23356996263776, 81.9470819745745, 38.08579322269985, 32.78507852554321, 51.57153102329799, 60.79768262590681, 73.04432037898472, 71.38638292040143, 21.559575830187114, 0.29458842107227867, 0.12137609986322266, 0.16706639528274536, 0.17833142009164604, 0.34794485941529274, 0.15267770737409592, 0.21006791426667146, 0.16735653685671942, 0.14090718754700252, 0.15366813779941627, 0.12262818696243422, 0.09824560782206909, 0.1243077375526939, 0.12483692701373782, 0.11224854857261692, 0.0869078915566206, 0.09887624505375113, 0.1115665937374745, 0.19367910868355206, 0.23926406832677977, 0.14102617544787271, 0.15053103970629828, 0.0719268832887922, 0.15859739615448884, 0.14695111608930997, 0.18212168956441538, 0.11305937077850103, 0.08951600374920027, 0.1328295674175024, 0.16831190059227602, 0.16492439593587602, 0.09008441253432206, 0.1183597267206226], [0.03602443176454731, 0.05034021447811808, 0.01309851887968502, 0.005798310315835157, 0.059280313684472015, 0.02685812085733882, 0.0382712749498231, 0.06866304842489106, 0.019317992064835768, 0.04277963124747787, 0.023262285594163195, 0.03150175159264888, 0.024578143110764877, 0.04733395489997097, 0.03321860125288367, 0.020281703477459292, 0.03656979750043579, 0.06998508569917508, 0.12210924338017191, 0.048843742813915014, 0.011114245846069284, 0.05346792843192816, 0.024576667297099317, 0.05545455343755228, 0.044312374001102786, 0.05678001392100539, 0.014824085170403123, 0.05867947092545884, 0.06670262504901205, 0.4523643691624914, 15.743219682148524, 49.962338651929585, 75.0926284790039, 68.17418902260917, 70.31115613664899, 56.88350527627127, 35.05914054598127, 28.453257117952617, 47.096491609300884, 37.218776157924104, 32.93428066798619, 33.80340651103428, 99.7428776877267, 69.86371994018555, 31.143868855067662, 7.925568682806833, 0.48021464901311056, 0.06485871970653534, 0.22638166030602797, 0.10222115806703057, 0.15827076296721185, 0.11584137114030973, 0.12189197646720068, 0.08496215846389532, 0.03368363183523927, 0.17267177307179996, 0.09482198474662644, 0.04737973565767918, 1.0521553988967622, 1.1193871455533164, 0.18821956164070539, 3.89363717181342, 2.358184729303632, 0.4872128420642444, 1.7290677960429872, 0.3048488205032689, 1.2304095881325858, 3.228006043604442, 11.15840915271214, 12.851964814322335, 12.686397927148, 8.246990612574987, 6.5063022800854275, 4.025679869311197, 3.288263210228511, 1.7739630384104592, 3.0186494375978197, 3.45107187969344, 2.2812284358910153, 6.56284715448107, 10.36574649810791, 16.875588451113018, 22.243596451623098, 23.096597262791224, 12.305813823427473, 19.2362892968314, 22.81803182193211, 22.28350169318063, 15.800240073885236, 13.000969801630292, 12.450155700956072, 3.467969898666654, 1.3358198404312134, 1.9109263632978712, 2.539662991251264, 1.1183571836778095, 1.4338771615709578, 2.6532575700964247, 5.172034927776881, 5.354750837598528, 5.61191018138613, 6.75664804662977, 7.979147979191371, 7.361175196511405, 7.1732485720089505, 6.644624412059784, 5.327037513256073, 5.423207529953547, 4.0106552583830695, 2.816448824746268, 2.652600096804755, 2.1102369597979953, 1.3034439491374152, 0.4166344521301133, 0.4532357438334397, 0.3979108211185251, 0.15010293839233263, 0.22824077840362275, 0.33495148377759115, 0.19703294443232672, 0.2664150228457791, 0.046953826011823754, 0.06184936940137829, 0.09559275981570993, 0.1904792461012091, 0.03292090079880186, 0.055666364928973575, 0.24127565324306488, 0.11890488889600549, 0.3229340857693127, 5.647933551243373, 33.90107386452811, 70.31405353546143, 76.77499580383301, 69.98061643327985, 96.91541944231305, 56.660211018153596, 20.028396095548356, 23.052090576716832, 43.32213633401053, 45.057441983904155, 60.59353065490723, 52.082706519535606, 28.547761304037913, 0.6577919317143304, 0.1184503925698144, 0.09488504779125963, 0.0395911680534482, 0.041779965960553715, 0.05359767450551901, 0.07405504730663129, 0.08453174334551607, 0.05294118169695139, 0.06467376463115215, 0.0950281440413424, 0.02408459879058812, 0.025724707836551324, 0.02265258795315666, 0.02109741622449032, 0.0319513624667057, 0.04384044271760753, 0.062445659190416336, 0.0556996877837394, 0.1081966156406062, 0.021564051542165022, 0.04342028365603515, 0.06163463342402663, 0.039526181362037144, 0.0413643904030323, 0.019986433875081793, 0.03261798580310174, 0.09018637599157435, 0.08265449479222298, 0.022889188025146723, 0.05114304354148252, 0.12635672331920692, 0.040073983038642576, 0.04036693374759384, 0.11267209013125726, 0.04554947904710259, 0.03976693915735398, 0.08350611730877842, 0.013423230964690447, 0.01436379415515278, 0.04620189046753304, 0.02423629377569471, 0.009773134104242283, 0.03899061027914286, 0.0693390660786203, 0.0551027703498091, 0.04339694544406874, 0.021686330337875655, 0.05274286287437592, 0.04249956252585564, 0.03238513972610235, 0.09303528669157199, 0.03770909850884761, 0.07402855729950325, 0.028341483224981597, 0.06857940541314227, 0.03373635061351316, 0.009081020751701934, 0.04190282490370529, 0.1004575030612094, 0.0024338663081705037, 1.0849140925066811, 22.79223837171282, 72.01623017447335, 89.62047794886998, 92.62736647469657, 95.74571800231934, 86.79236657278878, 47.761215346200125, 19.782846757343837, 43.92954438073294, 37.12153264454433, 44.408445494515554, 33.45512110846383, 89.93070111955915, 55.42039878027779, 18.246018137250626, 4.738266272204263, 0.18000144405024393, 0.041995136200317314, 0.28767718906913486, 0.021950619727639214, 0.12290911403085504, 0.30267856695822304, 0.19195334985852242, 0.42100598184125765, 0.1967902188854558, 0.9095690271684101, 0.6093106589147023, 0.20541021919676236, 0.12045141948120934, 2.250851563044957, 0.27780781579869135, 0.8387933735336576, 1.7954188585281372, 0.5528544283338955, 0.8605442206774438, 0.675523083124842, 2.2154502740928104, 6.092751579625266, 17.106777599879674, 20.024091686521256, 18.583231585366384, 13.81773315157209, 11.502132194382803, 8.758231248174395, 6.6920463017054965, 4.327685492379325, 3.6858656236103604, 0.8454872029168266, 1.4651409068277903, 2.680352504764284, 3.1816789294992174, 8.603028467723302, 23.947972195489065, 21.216176748275757, 15.543613570077078, 20.624402148383005, 24.460321937288555, 25.138193402971538, 14.283760121890477, 14.739472491400582, 12.699325919151306, 2.0691429248877933, 2.137881019285747, 1.8113123199769428, 2.77596948828016, 1.6971427776983805, 0.9041083401867321, 1.3441456279584338, 0.9150953420570919, 1.4395114992346083, 1.5905478575399943, 3.152750756059374, 5.671663386481149, 7.852472765105111, 8.665783728872027, 9.8005131483078, 9.601178015981402, 7.583543607166835, 5.982829340866633, 4.566526779106685, 3.3347344994544983, 2.0884706420557837, 1.5125812526260103, 0.7749748208693096, 0.33368183619209696, 0.727982253900596, 0.6090006498353822, 0.2779395601579121, 0.2695109067218644, 0.3370208255946636, 0.2619118301996163, 0.021925442685772265, 0.031181669660976956, 0.11376341871385064, 0.03326798163886581, 0.02573482140100428, 0.04166687113632049, 0.14351593756249972, 0.08778922033629247, 0.38965266996196335, 1.892845413514546, 18.65677653040205, 62.40208421434675, 78.12966523851667, 72.77214554377964, 97.78299931117466, 56.37156547818865, 6.55587854555675, 28.45654708998544, 60.60099996839251, 66.98139871869768, 76.28276457105363, 67.3660579408918, 43.44313226427351, 1.6617049021380288, 0.15994166902133397, 0.12299456873110362, 0.03954476643619793, 0.04279063030013016, 0.05782547353633812, 0.10044020041823387, 0.12887499747531755, 0.05885235486286027, 0.013285673256697399, 0.07036349789372512, 0.07859407338712897, 0.04057588182123644, 0.029055598923670392, 0.055833159014582634, 0.019795070036447475, 0.05602710807163801, 0.09786427114158869, 0.02255087046484862, 0.02334467161978994, 0.022342695921127285, 0.04704234769035663, 0.0033697845023458023, 0.02828688151203096, 0.05422489870605724, 0.052480157863880904, 0.020299214769953063, 0.040625893244785924, 0.06667351589671203, 0.016605175133528452, 0.016001667428229536, 0.08840814605355263, 0.1250017431697675, 0.266264089516231, 0.20222133531102113, 0.18156546726822853, 0.14242546393402986, 0.1308679905320917, 0.09525668820632355, 0.1718461045197078, 0.14573214149900846, 0.14477031811007432, 0.09256310774279491, 0.12191343174449035, 0.1035622146778873, 0.12902750500610896, 0.14689044148794242, 0.16245489487690584, 0.17787069481398377, 0.13692293848310197, 0.16451890340873174, 0.11962813937238284, 0.12338484850312982, 0.2164668794721365, 0.0935653243213892, 0.190485719325287, 0.1401177527649062, 0.1542521393192666, 0.15274064828242573, 0.1868405206395047, 0.10040758323988744, 1.6240114676100867, 27.263266938073293, 84.06253051757812, 101.33472388131278, 94.17345878056118, 96.5470745904105, 80.42920630318778, 49.426337242126465, 43.194226946149556, 67.34366389683315, 58.33488668714251, 48.95655216489519, 55.042673860277446, 124.61815125601632, 86.03947366986955, 45.40999010631016, 13.063689453261238, 0.41439080823745045, 0.13977583896900925, 0.38260483528886524, 0.29646321332880426, 0.29906680647815975, 0.2823643141559192, 0.36956702917814255, 0.23786140073622974, 0.24965338941131318, 0.7770357759935516, 0.4132706012044634, 0.2716553487948009, 1.7556365132331848, 3.5529355108737946, 0.849779452596392, 13.0982471874782, 10.168483666011266, 3.897671035357884, 5.6801610333578925, 0.6313900255731174, 1.348359601838248, 3.293168855564935, 12.64036784853254, 13.518869417054312, 13.949887020247322, 9.274854132107325, 7.688292912074497, 5.034761539527348, 4.302595113004957, 3.424050118241991, 7.488461852073669, 9.645114949771337, 10.295436808041163, 16.12418246269226, 20.291454894202097, 26.403555904115947, 35.75212608064924, 34.977464471544536, 21.85741557393755, 33.20101853779384, 36.0837253843035, 34.872022083827424, 28.56889946120126, 26.819457701274327, 22.893735919679912, 6.879419241632734, 4.29089651788984, 3.5444652225290025, 4.1015611461230685, 3.089339107275009, 2.8678053489753177, 4.48497360093253, 6.362989604473114, 6.1123815434319635, 6.546846321650913, 7.695402656282697, 8.892982006072998, 9.669851405279976, 10.80598088673183, 10.330354980060033, 10.798931070736476, 7.730107171194894, 6.608403018542698, 5.3002999765532355, 4.339889568941934, 2.7085456890719275, 2.207029708794185, 0.5031712800264359, 0.6848828494548798, 1.318120715873582, 1.035036774618285, 0.8219802528619766, 0.744084324155535, 0.45183228914226803, 0.2774924055806228, 0.08433489355125598, 0.1718313124563013, 0.3066223481936114, 0.24994610941835813, 0.12552257307938167, 0.09664758321430002, 0.5546438608850751, 0.3075730028961386, 0.5474317393132618, 10.815852539879934, 50.40557813644409, 81.30781296321324, 86.68772670200893, 88.42851448059082, 102.11800125667027, 83.04564775739397, 30.72012254170009, 30.40496962411063, 57.12780393872942, 62.71673338753836, 80.32467065538678, 80.56345244816372, 45.54153340203421, 1.3463344190801894, 0.3483729878706591, 0.3377943012331213, 0.21159693864839418, 0.23582538855927332, 0.1475362168358905, 0.12572487150984152, 0.27448912816388266, 0.22147606925240584, 0.10534832919282572, 0.25014543586543625, 0.17219046104167188, 0.08446275669017009, 0.12346492920603071, 0.19079826612557682, 0.12423433363437653, 0.1798600373523576, 0.19048535291637692, 0.10412048614983048, 0.17077473843736307, 0.10929747764021158, 0.1591340359300375, 0.20165638705449446, 0.10521488849605833, 0.11381697548287255, 0.18484800255724362, 0.12493235617876053, 0.16284431969480856, 0.24377570194857462, 0.10436376809541668, 0.16535266009824617, 0.20591560564935207], [0.03668181345398937, 0.1355036874966962, 0.05950815217303378, 0.043053915458066125, 0.07117093420986619, 0.033633108117750714, 0.04614373662375978, 0.04310897518215435, 0.02940299528251801, 0.05582434484469039, 0.09903395694813558, 0.0380887388517814, 0.027801213287083164, 0.010093874214882297, 0.07293469778129033, 0.09453323416944061, 0.02588493879219251, 0.12098853423127107, 0.07131783025605337, 0.05661766423976847, 0.031582792422601154, 0.11587955909115927, 0.014323263562151363, 0.07233069983444043, 0.01584984182513186, 0.027508976736239026, 0.09175782916801316, 0.08984349867595093, 0.7184726127556392, 22.473948342459543, 62.42654882158552, 74.29863003322056, 68.59136581420898, 56.14065599441528, 44.15026780537197, 30.612223965781077, 37.37793506894793, 61.250552313668386, 27.23839065006801, 47.32796737125942, 49.80212361471993, 112.88314410618374, 88.26519012451172, 27.379267113549368, 2.3873988645417348, 0.09122190185423408, 0.13598577305674553, 0.07888806904000895, 0.07428074162453413, 0.039471630539212904, 0.26309389248490334, 0.057665990665555, 0.33285407775214737, 0.06989067433668034, 0.15267398900219373, 0.2896004287259919, 0.2856067887374333, 0.17715482679860933, 3.7409066472734724, 3.7182746274130682, 0.4279170238545963, 0.40878021929945263, 3.180514020579202, 14.974840981619698, 35.83779042107718, 42.82111215591431, 56.393521785736084, 79.17364597320557, 91.57115691048759, 93.72348649161202, 93.9418614251273, 84.2493953704834, 85.21170003073556, 85.38696834019252, 71.08858312879289, 59.84559876578194, 41.34797593525478, 17.663005215781077, 4.048456932817187, 5.260978817939758, 2.945878565311432, 8.381560717310224, 12.713323933737618, 19.83212685585022, 14.53488712651389, 14.85519300188337, 14.857581445149012, 15.336213316236224, 14.739602770124163, 9.521679333278112, 3.8910281232425143, 0.7722290882042476, 1.2946759739092417, 1.1662524193525314, 7.614428349903651, 16.95858989443098, 21.79556097303118, 28.01960267339434, 34.21713352203369, 33.328299113682334, 28.317597014563425, 21.07246368271964, 14.22350708075932, 5.2611790129116605, 7.894676123346601, 10.186094743864876, 12.368312001228333, 8.281344243458339, 9.480248962129865, 7.755567976406642, 7.409071734973362, 3.6338019030434743, 2.4384483652455464, 1.0974902233907153, 0.994924715587071, 0.4588164229478155, 0.20143202266522817, 0.041480321503643475, 0.12608516003404344, 0.02045313534992082, 0.09824347722211055, 0.13671677240303584, 0.032669327155287774, 0.06720934143023831, 0.09204705471971206, 0.08311075530946255, 0.0414181100204587, 0.1325515444789614, 0.06378237996250391, 0.4095562462295805, 0.502645876790796, 0.14155600273183414, 3.76766676562173, 27.381629501070293, 39.5641371182033, 93.00823198046002, 46.03648138046265, 65.5815520967756, 37.74312891278948, 24.527804579053605, 35.822323731013704, 35.79459694453648, 52.24044452394758, 52.837357316698345, 31.373089926583425, 1.0146841981581278, 0.08972620032727718, 0.03487169915544135, 0.11528996644275528, 0.013970127645214754, 0.043350723638598404, 0.1513249935316188, 0.05600600563255804, 0.09894364393715348, 0.08701792279524462, 0.07118065761668341, 0.08478004645024027, 0.05234364340347903, 0.018458369620410458, 0.05915746491934572, 0.020010051982743398, 0.020197305595502257, 0.015335015254095197, 0.0259599220007658, 0.012862931521210288, 0.016946128802374005, 0.001997223510573219, 0.05387917832870569, 0.04804837763575571, 0.04245814474831734, 0.04959872837311455, 0.07959419329251562, 0.07825624437204429, 0.06874308841569082, 0.0605831416323781, 0.08848260170114891, 0.04639746122328298, 0.09977484933499779, 0.06932788382151298, 0.07625101732888392, 0.038614623847284486, 0.07919993051992995, 0.0436877893017871, 0.01712297708062189, 0.04812844476795622, 0.07640468515455723, 0.07123645355126687, 0.06559803789215428, 0.04599800765780466, 0.04447289503046444, 0.022336032707244158, 0.04555804215903793, 0.03769720039729561, 0.11021003260144166, 0.026132994231634905, 0.017664783900337558, 0.05867782887071371, 0.018998310468824844, 0.01932994106651417, 0.08440639757152114, 0.034897218857492716, 0.03970586082765034, 0.17390852527959005, 0.032796603361410756, 1.3577202366931098, 34.59770720345633, 81.703214100429, 87.74107360839844, 88.4790209361485, 79.52562086922782, 71.56368705204555, 47.79348972865513, 22.610982452120098, 57.672407218388145, 35.21658672605242, 52.122436319078716, 47.41978086744036, 101.41314819880894, 69.7699053628104, 15.782532589776174, 1.0115273275545664, 0.02197278237768582, 0.04798969114199281, 0.07955737598240376, 0.055755673708128076, 0.08246651345065661, 0.4616563362734658, 0.3455330745450088, 0.532500929066113, 0.6043311889682497, 0.15716127678751945, 0.3165021166205406, 0.653832978435925, 0.879407602761473, 0.5490821536098207, 2.547614118882588, 0.16764282435178757, 1.08008531161717, 6.2607572845050266, 22.407514878681727, 45.73851135798863, 56.09968941552298, 69.63306753976005, 91.95733083997453, 101.37915761130196, 103.56872953687395, 100.53371470315116, 94.45568071092877, 97.82138116019112, 97.04449612753731, 83.22509888240269, 74.7174049104963, 58.73297677721296, 29.08756685256958, 9.572858895574297, 9.089879189218793, 5.951558973108019, 3.2482830584049225, 5.47032630443573, 19.127339805875504, 18.228725808007376, 18.522476536887034, 15.536595889500209, 14.98244057382856, 14.296316385269165, 10.321791325296674, 4.2965076225144525, 0.04494609856711967, 0.36950245978576796, 2.734789469412395, 14.446336678096227, 28.422316789627075, 39.10501405170986, 48.27441276822771, 55.93542357853481, 56.268221446446006, 52.98475292750767, 48.24005740029471, 39.35049738202776, 30.159830229622976, 19.367947237832205, 4.086607754230499, 9.41912305355072, 13.273551106452942, 10.501509955951146, 10.492452110563006, 8.385084322520665, 6.695197744028909, 3.4327720616544997, 1.9814961765493666, 0.599389771265643, 0.20210871206862585, 0.16636692067342146, 0.22959144307034357, 0.15413254073687963, 0.04029838474733489, 0.12424276103930813, 0.4998081347772053, 0.23841649666428566, 0.1736728022141116, 0.12158552291137831, 0.042396700009703636, 0.028963470831513405, 0.0483222411546324, 0.012160276278986462, 0.2618926955120904, 0.5852959475346974, 0.24659021092312677, 1.3014146408864429, 22.176053013120377, 43.90520484106881, 91.54791518620083, 52.38529361997332, 55.502345834459575, 14.801466056278773, 37.36674152101789, 57.15552725110735, 56.23043366840908, 66.20868955339704, 62.619229316711426, 49.70764895847866, 4.6202862943921765, 0.09758552217057773, 0.02309165778569877, 0.1746316807610648, 0.039424421465290446, 0.027693183726764152, 0.10692162119916507, 0.05682792527867215, 0.07943720064525094, 0.050932935172958035, 0.031684715167752335, 0.047571781424007246, 0.01009036788517343, 0.073196917639247, 0.046758787906063456, 0.029867873194494417, 0.10333270699317966, 0.07885442727378436, 0.040469368786684105, 0.06928340585104056, 0.02562625749435808, 0.03085028672856944, 0.023301269127322093, 0.01545887503639928, 0.018898677779361606, 0.035223980966423235, 0.022974361133362566, 0.03271690263812031, 0.10128847097179719, 0.04059396477948342, 0.1313051435032061, 0.14454306316162857, 0.21317363690052712, 0.146007382443973, 0.13230256283921854, 0.1782701483794621, 0.12234974333218165, 0.11676071823707648, 0.2811183067304747, 0.18322567961045674, 0.14782388854239667, 0.20575731700020178, 0.08701881167611905, 0.10554897199784007, 0.2228398703570877, 0.15268160216510296, 0.24151292336838587, 0.12742412675704273, 0.20765667222440243, 0.2004685436508485, 0.10319003822015864, 0.14398525309349808, 0.303165185132197, 0.0740585553326777, 0.16395973627056393, 0.0699057038873434, 0.1924509602997984, 0.3181435471134526, 0.09190700509186302, 2.2787943950721194, 43.607464109148296, 93.59495176587785, 98.96930694580078, 93.42493629455566, 81.2714113507952, 64.80960723331997, 44.60679919379098, 53.53378568376814, 87.64854444776262, 45.495901107788086, 68.22605037689209, 71.95052106039864, 139.58219473702567, 95.1633825302124, 37.856308119637625, 3.8260646377291, 0.20457195703472408, 0.3495733434600489, 0.2633083909749985, 0.3048994392156601, 0.39321354031562805, 0.7150852030941418, 0.19552321758653435, 0.4589203745126724, 0.30329641380480354, 0.5029211991599628, 0.5371582848685128, 2.7901405564376285, 2.621750746454511, 10.400661196027484, 8.833232709339686, 2.154638337237494, 0.5964521488973072, 4.133074700832367, 18.894778387887136, 42.98445735658918, 56.85636908667428, 70.65481403895787, 95.35850879124233, 104.11421176365444, 109.7376320702689, 105.80256843566895, 103.07934706551688, 102.49360697610038, 100.42908872876848, 86.78453595297677, 75.41047382354736, 52.91835246767317, 23.13963266781398, 7.1002338613782605, 7.848250865936279, 11.341666153499059, 19.375769172395977, 20.73518248966762, 32.47270488739014, 27.9032655102866, 27.882325376783097, 25.79454629761832, 27.108332531792776, 31.886610439845494, 18.624498673847743, 8.835178204945155, 2.5134910813399722, 2.3930514412266866, 3.1192220066274916, 16.724977561405726, 31.029737745012554, 45.32506922313145, 55.85722507749285, 59.948084694998606, 64.0727299281529, 62.25975036621094, 58.20505959647042, 52.00476162774222, 43.128854819706504, 32.23026834215437, 13.599438122340612, 16.730259929384502, 17.317276750292095, 14.152080467769078, 13.242925184113638, 10.950562477111816, 8.716506447110858, 4.8830645595278055, 3.5955713944775716, 1.7418068838971001, 1.0251660985606057, 1.5888835468462534, 0.7547289101140839, 0.4571912501539503, 0.23341867913092884, 0.1452755688556603, 0.4578932353428432, 0.24327760296208517, 0.2280405020075185, 0.19944057666829654, 0.14854749185698374, 0.10472848745329039, 0.1645881954048361, 0.16401032784155437, 0.49988999324185507, 1.1095535989318575, 0.26430868729949, 7.564441272190638, 38.510595662253245, 55.12691381999424, 112.54041031428746, 60.86929076058524, 97.84971591404506, 53.76819705963135, 36.89491367340088, 49.61355645315987, 52.340786933898926, 68.82756287711007, 74.95899377550397, 54.26530940192086, 3.95960510628564, 0.34078142951641766, 0.13081142785293715, 0.3257367882345404, 0.10639104074133293, 0.10781239518629653, 0.3344223350286484, 0.14059339224227838, 0.18626994054232324, 0.1404674154307161, 0.2215929536947182, 0.1828855707177094, 0.11346309232924666, 0.15055448987654277, 0.1326338236353227, 0.11644434449928147, 0.18544474696474417, 0.11935622324900967, 0.1551277209073305, 0.11840828268655709, 0.06240382072116647, 0.09659895939486367, 0.08597994742116757, 0.16825920556272778, 0.13597757635372026, 0.1978541753653969, 0.14386414816336973, 0.16508668794163636, 0.22772609602127755, 0.20550180785357952, 0.1999011526682547], [0.08661020467323916, 0.027903522797194973, 0.08231262849377734, 0.01880868198350072, 0.009349665488116443, 0.010650862407471453, 0.04925765935331583, 0.049383229043866904, 0.057416588334100585, 0.05283386120572686, 0.031085439824632237, 0.07777538017502852, 0.07011227030307055, 0.06214949901082686, 0.026369852146932056, 0.05396901297249964, 0.01688904534759266, 0.025367837432505827, 0.07793731255722897, 0.017042965927560414, 0.029028549125151973, 0.05961053632199764, 0.03109406739739435, 0.020900010031514933, 0.0016619805620783673, 0.0581744983792305, 0.06332906428724527, 1.258029437490872, 28.58937406539917, 75.43051242828369, 81.56090109688895, 70.15504401070731, 66.15743269239152, 55.925171511513845, 37.43365614754813, 29.35506902422224, 69.27105944497245, 29.765398366110666, 48.74147415161133, 97.86641243525914, 125.07734380449567, 61.90043122427804, 4.217425397464207, 0.04328492949051516, 0.1160146418426718, 0.03428316502166646, 0.0554226147942245, 0.0847702891166721, 0.07413525693118572, 0.1342063421117408, 0.06194336685751166, 8.008707353046962, 4.912026388304574, 2.9295552926404134, 0.2539844241525446, 1.4932602665254047, 1.7189181063856398, 1.2751524043934686, 0.12700633917536053, 8.797765629632131, 25.722026211874827, 51.995565686907085, 67.68622398376465, 83.78944546835763, 83.63007463727678, 86.2391162599836, 80.08642387390137, 78.33658954075405, 70.8149630682809, 67.31100041525704, 62.09029769897461, 68.26068714686802, 72.05179105486188, 75.29194450378418, 73.75664969852993, 77.56442928314209, 83.90755789620536, 78.07998561859131, 74.75994178227016, 97.05165972028459, 39.51892171587263, 5.512324256556375, 2.51027232834271, 8.70715504033225, 13.50626712185996, 12.311870915549141, 8.530464087213788, 10.16200794492449, 13.13541657584054, 4.535428379263196, 1.7648641552243913, 0.8803808391094208, 15.075419630323138, 43.112314632960725, 59.98256165640694, 65.59207861764091, 71.1758941922869, 78.36158915928432, 78.52613639831543, 75.76826436179024, 72.77937861851284, 73.70393371582031, 62.6225575038365, 49.4978654725211, 40.33796146937779, 28.17022224834987, 16.056371518543788, 14.18276458127158, 9.624785389219012, 4.858438840934208, 5.3332244498389105, 4.948042809963226, 4.207821684224265, 3.3769951803343634, 2.6880461147853305, 1.5553445922476905, 1.27060024866036, 1.5841069860117776, 0.6343159228563309, 0.17009813045816763, 0.3000632215823446, 0.1660197821578809, 0.1979790258088282, 0.15667853983385222, 0.11646256994988237, 0.061341642002974234, 0.04005380001451288, 0.010382418687056218, 0.03854288233976279, 0.056529587001672814, 0.22442866010325296, 0.44378307248864857, 0.06008727502610002, 1.3745532248701369, 26.37171925817217, 43.528820923396516, 42.16842269897461, 23.994019644601003, 54.26878350121634, 24.892598901476177, 19.09766231264387, 32.65307664871216, 40.71327189036778, 46.84312554768154, 60.20998314448765, 40.21718788146973, 3.155985793897084, 0.1272999955607312, 0.07698624394834042, 0.09390837127076727, 0.05755436486963715, 0.0731696608875479, 0.1179800456655877, 0.09595655636595828, 0.004180295642332307, 0.061483672953077724, 0.04489164273919804, 0.00888529817374157, 0.056535178130226474, 0.0415772027336061, 0.01768446311221591, 0.029380908967661004, 0.043629157090825696, 0.11430086594607149, 0.018693750025704503, 0.047273558497961075, 0.027682717324101498, 0.061306398894105635, 0.08597012223409754, 0.022887218577255095, 0.07058114478630678, 0.037564716434904506, 0.03174657042005232, 0.023865450639277697, 0.03448203006493194, 0.05145544445674334, 0.055134376510977745, 0.04845762585422822, 0.08344500844499894, 0.02631764905527234, 0.03900139559326427, 0.02847378228658012, 0.1034691875268306, 0.05215480371511408, 0.05109422294689076, 0.03357617902968611, 0.037996152748486826, 0.06551743471728903, 0.05730123059558017, 0.05526642621095691, 0.06502340015556131, 0.03485859325155616, 0.006544725129580391, 0.03452914075127669, 0.04092100169509649, 0.026259551190638115, 0.044527286397559304, 0.03527674384947334, 0.017130483374265686, 0.055032158603093455, 0.03913466665627701, 0.04347550283585276, 0.01742367326681103, 2.3427076169422696, 43.919042178562705, 87.81500244140625, 94.59192793709892, 92.8547671181815, 90.2214137486049, 74.79001358577183, 57.96828235898699, 18.977689504623413, 55.58290324892317, 36.992101601191926, 54.80077232633318, 104.98985154288155, 111.884854725429, 46.21678018569946, 2.217950974191938, 0.12296389894826071, 0.09687038018767323, 0.07195838766970805, 0.1977934329105275, 0.10463974864355155, 0.09166005227182593, 0.1417429255587714, 0.27503021912915365, 6.061426060540335, 7.558670793260847, 1.9749822403703416, 1.5028317357812608, 0.6296713235122817, 0.5897291696497372, 0.5071664399334362, 0.6788305885025433, 13.785554306847708, 37.69218472072056, 64.39218030657086, 80.29928193773542, 92.77671800340924, 90.5406139918736, 91.79490974971226, 86.21549933297294, 82.55000495910645, 75.30381897517613, 73.67970534733364, 69.68315710340227, 78.55215740203857, 78.71109744480678, 81.6876779283796, 81.36389187404087, 82.4000836781093, 89.24004323141915, 85.69063241141183, 84.87532384055001, 112.71970857892717, 54.26147052219936, 12.277676224708557, 1.3023737094232013, 3.8549843430519104, 12.150017840521675, 13.832388639450073, 12.13399008342198, 11.468411718096052, 10.628304157938276, 2.856661741222654, 0.36531166466219084, 1.1832064581768853, 21.461701767785208, 55.32990196772984, 72.50133950369698, 80.41603251865932, 80.91657379695347, 86.83554267883301, 87.19377095358712, 86.53819452013288, 85.03602177756173, 86.43911320822579, 76.59270981379917, 64.21787084851945, 61.15166555132185, 55.22628695624215, 46.42461470195225, 41.599719592503135, 34.252680506025044, 23.12203461783273, 15.448977368218557, 10.208890046392169, 6.104917006833213, 3.662313835961478, 4.814375536782401, 3.217035923685346, 2.2457754697118486, 1.4865015149116516, 0.5923458178128514, 0.2960109833095755, 0.3739963157900742, 0.2450912727841309, 0.28806691244244576, 0.29412853717803955, 0.29546354125652996, 0.03791206868897591, 0.11093900312802621, 0.012480121571570635, 0.030685341650886194, 0.024782758738313402, 0.09150176362267562, 0.2808489554694721, 0.10051424215946879, 1.1196615993976593, 25.407863412584575, 50.809362275259836, 40.823935849326, 27.074989863804408, 49.55656385421753, 17.556438956941875, 25.99884418078831, 47.443995339529856, 62.25201007298061, 62.88281617845808, 69.00602735791887, 58.299416133335654, 9.054734332220894, 0.17675056920519897, 0.1142300676022257, 0.06520422295268093, 0.027017668188948716, 0.041468423392091475, 0.078324566063072, 0.033872848110539575, 0.08969779685139656, 0.10657005863530294, 0.049059048760682344, 0.023540970104347383, 0.050707115326076746, 0.031865164770611694, 0.012963929762398558, 0.04559519534398403, 0.051568149123340845, 0.03889832951660667, 0.03149307991511055, 0.0436506395095161, 0.009052939579955168, 0.026779273391834328, 0.041329839399882724, 0.07412625955683844, 0.04786203156358429, 0.05781819285558803, 0.020484504023832933, 0.03830428567848035, 0.11057839569236551, 0.03690644247191293, 0.1709106761429991, 0.12507326076073305, 0.18132818357220717, 0.11194471416196652, 0.1191175417708499, 0.13092870584556035, 0.24368939229420253, 0.23269745068890707, 0.10676118159400565, 0.17443957392658505, 0.12140833027660847, 0.1420529346380915, 0.17665718921593257, 0.26638961849468096, 0.13892456250531332, 0.15027895037617, 0.09019434199269329, 0.11137412727943488, 0.17428614358816827, 0.10627184927995716, 0.2484369661126818, 0.16561574169567653, 0.26961455973131315, 0.15138887081827435, 0.11587403581610747, 0.18351761251688004, 0.13315982398177895, 3.1195005859647478, 52.766791411808555, 101.19038200378418, 104.3035501752581, 94.68966824667794, 92.33340208871024, 71.11877305167062, 50.40393488747733, 44.96446813855852, 100.60573972974504, 48.307368074144634, 69.36104556492397, 118.87503433227539, 152.84442983354842, 67.17088999067033, 8.68172115939004, 0.2558606820447104, 0.22043469441788538, 0.21128667172576698, 0.300504920738084, 0.1918334120086261, 0.3957756614046437, 0.4809669000761849, 0.4519904963672161, 13.515182529176984, 10.883692145347595, 7.276889204978943, 4.28417934690203, 6.002622587340219, 5.723433545657566, 2.985988561596189, 0.3943094829363482, 11.764686380113874, 33.207810401916504, 68.41250528608049, 84.89651584625244, 98.78265748705182, 94.791230065482, 95.72003051212856, 86.28280653272355, 84.8548058101109, 76.65276309422084, 72.62999929700578, 69.88446726117814, 77.08371121542794, 77.83952930995396, 83.68172754560197, 82.62519836425781, 88.81256920950753, 97.6903520311628, 93.3556558064052, 87.14649541037423, 123.81934465680803, 51.071486541203086, 8.00510036945343, 7.398983819144113, 18.52056404522487, 26.54279954092843, 24.043497766767228, 18.4614748273577, 22.448252167020524, 25.3433233329228, 10.577194077627999, 4.36875455720084, 1.0050101344074522, 20.939516850880214, 53.336526325770784, 74.38432911464146, 80.2620951788766, 80.39024080548967, 87.98740809304374, 87.80193287985665, 86.1244431904384, 85.85472106933594, 86.35447025299072, 80.42271668570382, 71.79962703159877, 68.54188074384416, 66.10229178837368, 61.973241397312705, 56.642837047576904, 44.98479161943708, 32.825374603271484, 22.440668208258494, 16.212881428854807, 9.600454534803118, 6.893119352204459, 5.169800213405064, 3.940549237387521, 3.222882832799639, 1.9972794439111436, 1.1055840062243598, 1.1106301354510444, 0.6559802432145391, 0.3686449000877993, 0.5162138630236898, 0.5551413084779466, 0.5783385208674839, 0.17158005093889578, 0.17479938747627394, 0.14696518890559673, 0.1462566897805248, 0.2563763143760817, 0.5730122381022998, 0.8515184564249856, 0.2757466435432434, 5.2100706696510315, 40.8985595021929, 64.67019162859235, 61.41374465397426, 34.63607515607561, 78.8960029057094, 36.49792487280709, 29.01237518446786, 44.22462395259312, 61.19552952902657, 65.74323667798723, 79.2849074772426, 67.44643470219204, 8.91808237348284, 0.26340493293745176, 0.20575254011367047, 0.12294651488108294, 0.25258300506642883, 0.14583025766270502, 0.38191066682338715, 0.2177715937473944, 0.20512881715382847, 0.1574386211910418, 0.13327716982790402, 0.0960021335631609, 0.10998909481401954, 0.0940794503050191, 0.08929790223815612, 0.06875969216759716, 0.11244754932288613, 0.15310903851475033, 0.1420662882072585, 0.21054872418088572, 0.11274959918643747, 0.20556911852742943, 0.24991416398968014, 0.13117827102541924, 0.2028930578380823, 0.12966308875807694, 0.12503885903528758, 0.1538197768053838, 0.19953625010592596, 0.15059997886419296], [0.07881296199879476, 0.112491389470441, 0.04268272966146469, 0.022476779529824853, 0.04114693010758076, 0.08643089500921113, 0.019208664806293588, 0.04983544549239533, 0.09453020111790725, 0.021526392848630036, 0.04738262282418353, 0.07631460963083164, 0.014324591794450368, 0.04954435736207025, 0.08855825835572821, 0.07010364612298352, 0.03880226931401661, 0.07196005686585392, 0.05600089965654271, 0.0876947750470468, 0.01593326261666204, 0.057758678549102375, 0.039847525368843756, 0.03082738956436515, 0.05386335149939571, 0.10555001694176878, 4.0794980100222995, 34.545831952776226, 77.53617095947266, 80.016768183027, 65.81808962140764, 55.4143260547093, 52.408153193337576, 39.090210914611816, 33.23682260513306, 71.31365612574986, 33.18186582837786, 44.507745674678254, 65.71087891714913, 65.67693696703229, 47.40088176727295, 2.323821544647217, 0.16982746283922875, 0.07008119339921645, 0.08370526055140154, 0.033803274522402456, 0.13109728108559335, 0.1715006080589124, 0.2673872278204986, 0.20187369467956678, 0.2534773142210075, 1.1456041101898466, 2.1095197754246846, 3.0179587432316373, 0.402416890753167, 0.24656999057957105, 3.2156495409352437, 21.740694522857666, 49.34670046397618, 72.6129275730678, 85.5081866128104, 83.09908635275704, 83.3847267968314, 76.84817423139299, 79.07819856916154, 81.74598026275635, 82.28596646445138, 81.86050742013114, 83.15295573643276, 85.633316721235, 84.15384374346051, 88.8096648624965, 88.87979997907365, 87.5707037789481, 83.83902086530412, 76.88194247654506, 69.4800056729998, 68.81446552276611, 70.36658191680908, 66.42611953190395, 77.88026659829276, 75.37678895677838, 20.789286375045776, 1.0678178327424186, 3.3023413462298254, 15.412419421332222, 6.925263021673475, 2.794119702918189, 5.228508583136967, 0.22049774389181817, 3.1578722298145294, 27.572169951030187, 63.85771097455706, 77.32282652173723, 79.82697119031633, 79.2078936440604, 76.27523272378104, 75.15944930485317, 74.01409435272217, 71.98410170418876, 72.94982487814767, 71.55960845947266, 72.16602638789585, 69.68346977233887, 67.91702924455915, 72.02524893624442, 74.70534283774239, 64.67472880227226, 54.447161129542756, 44.5798783983503, 37.31835774012974, 30.97215107509068, 23.342384576797485, 12.30382490158081, 4.758244514465332, 0.7994893682854516, 2.9512232499463216, 3.2067827710083554, 2.9978749752044678, 0.43461001185434206, 1.0032085967915398, 1.1837766447237559, 0.1263783143035003, 0.7335659457104546, 0.38585879068289486, 0.04943882481061986, 0.021248342768688287, 0.021838456192719083, 0.03201880206220916, 0.03916093613952398, 0.026321995072066784, 0.2056513298302889, 0.08276302646845579, 0.09592643619648047, 2.3929500409535, 41.93844427381243, 63.32234532492501, 34.90583201817104, 27.767881597791398, 52.61237812042236, 38.021939277648926, 22.989534207752772, 25.886957338878087, 39.97661345345633, 47.75028582981655, 58.63869667053223, 48.889161586761475, 7.824491500854492, 0.15246601801897797, 0.037543705598052056, 0.13509028325123446, 0.10714256577193737, 0.02532160884168531, 0.09340381263090031, 0.058720359445682595, 0.07482793261962277, 0.012299410732729095, 0.014037462915959103, 0.08944148024810211, 0.02976498692961676, 0.025662353861012628, 0.011662115376176578, 0.05797930421041591, 0.05722626604671989, 0.04277735136981521, 0.054702214164925475, 0.02860403386875987, 0.013149900095803397, 0.004610094990182135, 0.05478932109794446, 0.04728432684870703, 0.038315915768699985, 0.034761491497712474, 0.07996806608779089, 0.027941994036414793, 0.1174371497971671, 0.12531723481203827, 0.05253200811733093, 0.027300944684871604, 0.053038208811943016, 0.07663384000105516, 0.12890207102256163, 0.06462427907224212, 0.01872830611786672, 0.05307492434180208, 0.03944085219076701, 0.048699153786791224, 0.047176857079778395, 0.026684151263907552, 0.0568379404555474, 0.03087657317519188, 0.08087863972676651, 0.03651824580239398, 0.06110959659729685, 0.037513680423476865, 0.1076234435396535, 0.015281930066911238, 0.0692668699526361, 0.049504948048187156, 0.0510120218220566, 0.02424816135317087, 0.08508238808384963, 7.113933103425162, 51.73305927004133, 91.24577971867153, 93.9947372164045, 83.80385603223527, 80.44106687818254, 76.31693581172398, 55.50928708485195, 18.087019034794398, 42.43941286631993, 38.36014631816319, 49.584950719560894, 63.859441076006206, 64.23880577087402, 34.26215090070452, 1.2895933666399546, 0.2572359096791063, 0.08636850371424641, 0.08954287373593875, 0.029251702329409972, 0.16076956316828728, 0.17256092759115355, 0.30854341653840883, 0.352377077298505, 0.47938987612724304, 0.4745247800435339, 0.3376635339643274, 0.4081713291151183, 0.5483838596514293, 0.39796019132648197, 5.749542704650334, 31.00924403326852, 64.44376373291016, 83.23802947998047, 94.4059316090175, 88.59366621289934, 88.5272136415754, 82.41470268794468, 84.01292732783726, 87.14798927307129, 88.00773157392229, 88.88234301975795, 90.69821303231376, 92.35673413957868, 91.56136689867292, 94.34597560337612, 93.91916166033063, 92.93988949911935, 91.19757311684745, 82.84723499843052, 77.3119317463466, 77.4243744441441, 75.74560628618512, 77.86679404122489, 86.84009374891008, 81.16568061283657, 35.532913889203755, 2.1584789540086473, 1.3093924756561006, 11.24934457029615, 9.860962476049151, 3.0179042432989394, 2.135642396552222, 0.5341947696038655, 4.6679956657545905, 39.109513010297505, 76.31356593540737, 84.78808920724052, 84.57364000592912, 82.90186173575265, 81.78278487069267, 80.44035121372768, 78.40291704450334, 78.11799921308244, 79.42277363368443, 79.19431686401367, 78.54892648969377, 77.95300034114292, 77.7366612298148, 83.06405353546143, 88.68477099282401, 79.95244176047188, 67.90208366939, 60.09469863346645, 57.40401915141514, 54.6030717577253, 46.35765838623047, 24.961505923952373, 7.380576304027012, 8.550487927028112, 9.216263447489057, 8.480987702097211, 6.473349145480564, 1.0347467958927155, 0.7655411756464413, 0.7468976389084543, 0.6021244845220021, 0.22096950214888367, 1.2136122094733375, 0.15739326791039535, 0.05860369213457618, 0.1729893410312278, 0.08128871236528669, 0.07683300359972886, 0.07015454982008253, 0.3129150005323546, 0.07415882923773356, 0.040528557396360805, 1.4784642947571618, 41.34297670636858, 71.61099733625139, 35.514080796922954, 25.22155441556658, 42.45878096989223, 27.13099581854684, 27.98586048398699, 42.22551604679653, 55.02828414099557, 66.15291636330741, 70.4372034072876, 64.7965168271746, 15.659695386886597, 0.15202727727591991, 0.012281734895493304, 0.0788675162142941, 0.0798965756382261, 0.05550169126529779, 0.03211557811924389, 0.04458144706274782, 0.07683772620345865, 0.01828488178684243, 0.02562902252455907, 0.032770310129438124, 0.035021618075136624, 0.06190893120531525, 0.036878856630729775, 0.053975479411227364, 0.02694253739900887, 0.02228253531003637, 0.028676891566387246, 0.059171809149639945, 0.032063056116125414, 0.04840118531137705, 0.07283983858568327, 0.043438108770975044, 0.030144338895167624, 0.029830777685024908, 0.015420217200049331, 0.05661943182349205, 0.046065403148531914, 0.2609021972332682, 0.20250864060861723, 0.11111066570239407, 0.10609492127384458, 0.20354271440633706, 0.1569063240396125, 0.11149249092808791, 0.2001085536820548, 0.2255517712661198, 0.12615092364805086, 0.15497388344790253, 0.11249769984611444, 0.10159287535186325, 0.17536688702447073, 0.12080166568713528, 0.11938307966504778, 0.14598946911948069, 0.12505738304129668, 0.11001154075243644, 0.17094484716653824, 0.11280245706439018, 0.1488909391420228, 0.18844976143113204, 0.12917298291410717, 0.16987030554030622, 0.13310822817896092, 8.317758883748736, 61.37274333408901, 103.77826636178153, 100.2977955681937, 88.21653188977922, 77.78513881138393, 68.37516566685268, 52.44332150050572, 46.92143521990095, 97.22483662196568, 49.57986811229161, 66.95980371747697, 89.07985251290458, 80.61131858825684, 51.43842090879168, 5.019874589783805, 0.7171502837112972, 0.1986490519983428, 0.3006986831980092, 0.1183526970978294, 0.47903171820299967, 0.3183998705020973, 0.4438506545765059, 0.5879496165684291, 1.8414754271507263, 4.79990200485502, 4.075224867888859, 7.002988176686423, 2.5141728733267104, 1.0052867595638548, 4.20729752949306, 29.31802122933524, 64.24469784327916, 86.63137681143624, 101.77894306182861, 89.91289288657052, 88.74640151432583, 81.23271683284214, 84.17064448765346, 87.6386502129691, 90.68394838060651, 91.40139852251325, 91.29409749167306, 95.97817693437848, 93.89975534166608, 97.05982385362897, 97.89281558990479, 95.37041105542863, 91.82997730800084, 83.48125811985561, 76.71918092455182, 78.01537431989397, 76.32325172424316, 84.16742052350725, 96.46152142116001, 85.94668742588588, 28.23501593726022, 3.29850572347641, 9.879359568868365, 25.36982897349766, 15.117753267288208, 10.316996199744088, 10.932813303811209, 2.484742041145052, 3.718190814767565, 36.54141364778791, 75.50741509028843, 82.79397010803223, 85.51175103868756, 82.50494589124406, 82.27126407623291, 78.87692315237862, 80.67405387333461, 76.76367024012974, 79.84078420911516, 79.43519701276506, 80.722475869315, 76.84219878060478, 76.94667189461845, 80.56432792118618, 90.85969611576625, 82.69210951668876, 74.10166944776262, 68.7797384262085, 68.60928521837506, 62.697271483285085, 51.76519816262381, 28.25118613243103, 9.736789481980459, 11.455552339553833, 10.448701041085378, 9.85231283732823, 7.410338912691389, 1.9829238142286028, 1.5103370930467332, 2.2248288222721646, 1.593870290688106, 1.420783824154309, 1.4931041491883141, 0.38242087087460924, 0.1194385431174721, 0.22344349510967731, 0.38270970966134754, 0.13481011614203453, 0.13418207769947393, 0.4904212270464216, 0.133950303707804, 0.20164117429937634, 4.671835848263331, 54.488158975328716, 77.36822605133057, 48.30510296140398, 38.40493788037981, 77.95326437268938, 53.90345416750227, 34.99293116160801, 36.05479655947004, 55.89348772593907, 65.49071829659599, 74.44069984980992, 74.59729140145438, 16.6104382446834, 0.2193072677722999, 0.13246560123349937, 0.19300000369548798, 0.2041842964078699, 0.17604088942919457, 0.14822571698044026, 0.10795807665480034, 0.1343299304800374, 0.06759316833423716, 0.13034781201609544, 0.16249625837164267, 0.1602797151676246, 0.18889113489006246, 0.1042354367673397, 0.11271641203867537, 0.12162177025207452, 0.14633791042225702, 0.17506249621510506, 0.12241125931697232, 0.08504809492400714, 0.146335508408291, 0.15178282825010164, 0.09970821041081633, 0.16092520553086484, 0.20680577574031694, 0.12725479155778885, 0.09675458140139069, 0.2869495009737355], [0.1453338143016611, 0.012229293468408287, 0.06327548037682261, 0.10488836387438433, 0.11006835448954787, 0.03216629182653768, 0.06041359608726842, 0.02707375928626529, 0.034245930412518125, 0.05722323978053672, 0.02660853023241673, 0.0348693141048508, 0.09067969130618231, 0.16863538537706646, 0.08728168971304383, 0.038067989250911136, 0.0498469602316618, 0.05847565257655723, 0.028374210665268556, 0.016162291934181536, 0.08468055286045585, 0.06239603113915239, 0.06830845959484577, 0.04898750402831605, 0.15567801280745439, 14.509080648422241, 56.41651337487357, 82.276120867048, 72.30972208295549, 71.42083208901542, 68.59205368586949, 48.464612756456646, 34.908878803253174, 30.495428221566335, 92.90998445238385, 60.274267877851216, 29.902083328792028, 68.77452032906669, 65.41205774034772, 49.14738096509661, 2.718142236982073, 0.28250124252268244, 0.13969140207128866, 0.07091517400528703, 0.07195317652076483, 0.07866504815007959, 0.13516173298869813, 0.0887805192864367, 0.1733790101217372, 0.16239322961441108, 0.2976318677621228, 0.47578169831207817, 0.26602052258593695, 0.7465646682041032, 10.431287118366786, 33.669678006853374, 54.19930498940604, 74.56879683903286, 80.73522581372941, 80.91481590270996, 76.86548914228166, 82.3256893157959, 83.22049917493547, 89.673951285226, 86.43823773520333, 83.38090528760637, 81.23286274501255, 78.91126114981515, 79.92620536259243, 75.98634052276611, 76.5448019845145, 79.51483031681606, 82.50557817731584, 81.66152490888322, 77.9022993360247, 77.12047413417271, 81.95917184012276, 82.18185465676444, 78.86748055049351, 80.88038063049316, 75.40674264090401, 72.44293294634137, 88.91945334843227, 46.678932666778564, 0.5787979162165097, 4.249787066664014, 4.204794875213078, 3.82133378301348, 0.4881878154618399, 10.101125223296028, 42.9824423789978, 83.09921142033168, 77.77354226793561, 76.19624560219901, 74.5783714566912, 77.3328388759068, 75.21656349727085, 77.86621039254325, 77.00675296783447, 78.69463716234479, 76.94861044202531, 75.38213212149483, 72.78183828081403, 69.38416222163609, 70.2629703794207, 71.38166509355817, 65.94043350219727, 66.14610712868827, 64.17336068834577, 63.954033851623535, 63.19119807652065, 63.76332664489746, 66.37025601523263, 61.02144241333008, 55.07154015132359, 46.349980626787456, 36.14030803952898, 44.0823005267552, 40.15327835083008, 29.626114777156285, 10.33258535180773, 0.9074514007994107, 0.9056328726666314, 0.21234072159443582, 0.11524138333542006, 0.1369112269686801, 0.10651945349361215, 0.02486073598265648, 0.0573922832097326, 0.021094961624060358, 0.07637714341815029, 0.2032909779144185, 0.04751255549490452, 0.08844024754528489, 0.0766025527513453, 3.2578754808221544, 53.75983837672642, 75.5307262965611, 46.05017975398472, 28.007154975618633, 43.02164758954729, 34.07154791695731, 23.83171146256583, 32.21618086951119, 40.451856340680806, 46.402786936078755, 56.202140603746685, 54.58079235894339, 11.700108085359846, 0.3174870237708092, 0.11122904970709767, 0.09199760308755295, 0.06372163072228432, 0.0686814027971455, 0.03488340388451304, 0.028984295071235726, 0.06426920848233358, 0.04501548895080175, 0.009768104463416551, 0.05024880224040576, 0.03303922373535378, 0.0006201486175996251, 0.03313192518960152, 0.06271323947502033, 0.019477585197559426, 0.05549330796514239, 0.10000888963363, 0.07048598703529153, 0.05313394331772413, 0.06575633332665477, 0.05213474282728774, 0.02438574959523976, 0.0647609903077994, 0.06105156149715185, 0.08764988317021302, 0.07468757765101534, 0.04948910086282662, 0.009842569440869349, 0.0843291599303484, 0.1168140239481415, 0.12902591723416532, 0.06895647410835538, 0.04285141685977578, 0.044737221739654026, 0.0134044160367921, 0.016481001528778245, 0.05890531452106578, 0.005673343249197517, 0.1211906291012253, 0.09712964841829878, 0.061624597891100814, 0.017928277707791755, 0.03200431533956102, 0.12108082856450762, 0.02568963266509984, 0.03928812752876963, 0.02913264318236283, 0.04066994034552148, 0.05399286687108023, 0.04807623489094632, 0.30304440589887754, 21.741245167596, 73.67598806108747, 94.73033605303083, 89.47070952824184, 95.94986997331891, 91.16284602028983, 68.58876718793596, 46.66932330812727, 13.415482827595302, 60.10282802581787, 69.73888860430036, 40.093284130096436, 74.18716703142438, 68.251939364842, 40.2085234778268, 1.2056675957781928, 0.29292696022561615, 0.24838808444993837, 0.04651433888024517, 0.09332548933369772, 0.08664191940001079, 0.18836987071803638, 0.1607163388814245, 0.191795821168593, 0.11790239411805357, 0.30044843948313166, 0.5609610761914934, 0.4065692807946886, 1.5781121019806181, 17.109794855117798, 51.99367925098964, 74.22272791181291, 86.3810818535941, 87.15454142434257, 88.54484122140067, 83.37960597446987, 88.49234758104596, 89.1942059653146, 96.01621832166398, 90.70215960911342, 87.55557755061558, 86.78115218026298, 83.19364438738141, 83.75691400255475, 80.5686149597168, 78.61555276598249, 84.35723836081368, 85.74503680637905, 83.6471949986049, 81.23635768890381, 80.5615486417498, 83.82288714817592, 84.87781824384416, 85.99305970328194, 84.68355355943952, 80.05155781337193, 75.24277905055455, 90.91955484662736, 62.22727448599679, 1.9080532831805093, 1.7286579608917236, 2.067609978573663, 0.9147252419165203, 1.0961023207221712, 14.881026404244558, 55.77460057394845, 86.47395842415946, 83.02459471566337, 80.46532303946358, 80.5395575932094, 82.94314793178013, 82.60106032235282, 82.02301188877651, 83.38820784432548, 85.01788003104073, 82.78954410552979, 82.42595876966203, 81.10742691584996, 76.43077509743827, 75.0309840611049, 76.84092726026262, 74.340256690979, 75.35729231153215, 75.2671046938215, 77.92189325605119, 78.46941825321743, 77.23808629172188, 77.88026659829276, 75.48702212742397, 76.15275682721818, 65.68418393816266, 51.32890340260097, 56.78524037769863, 50.106941086905344, 40.59700768334525, 18.280380453382218, 2.567701361009053, 0.44651585870555466, 0.4356840242232595, 0.15910252476377146, 0.17388568579086236, 0.24537139918122972, 0.1945015745503562, 0.1798988359847239, 0.16510043506111416, 0.061999142436044555, 0.21721504575439862, 0.03518602711015514, 0.04509792077754225, 0.028958042551364218, 0.8429344456110681, 49.30079024178641, 84.81881414140973, 45.71444627216884, 18.999039581843785, 29.121025902884348, 23.91268403189523, 28.565505266189575, 50.40474782671247, 59.33157103402274, 66.69310406276158, 66.8525721686227, 69.90868868146623, 22.08087832587106, 0.46379203881536213, 0.08784296030976943, 0.08732423385871307, 0.03359929332509637, 0.0984486797824502, 0.05577316294823374, 0.040296474671257396, 0.026662843567984443, 0.028678109536745718, 0.0029282757604960352, 0.01616303832270205, 0.03570783750287124, 0.04398946936375328, 0.03364329292838063, 0.019337964743109684, 0.02980526476832373, 0.048367519796426804, 0.06518246233463287, 0.07661010484610285, 0.05860665054725749, 0.05232717875125153, 0.09257343504577875, 0.08990253800792353, 0.0899381000282509, 0.0070437626148174915, 0.03283748848895941, 0.024023927581895674, 0.2915552609733173, 0.13249196910432406, 0.1494568916303771, 0.1584241661642279, 0.14745944738388062, 0.1891448391335351, 0.19086457256759914, 0.13110284507274628, 0.10501307861081191, 0.08847831335983106, 0.14653028867074422, 0.0886463729132499, 0.2396017073520592, 0.1876269020140171, 0.18806033661322935, 0.0709861759096384, 0.15413708692150457, 0.16506933101585933, 0.16860885465783731, 0.14466692294393266, 0.16072330065071583, 0.11895045930785791, 0.19213370446647915, 0.12312505101518971, 0.49803053587675095, 26.405270372118267, 87.61416476113456, 106.85969516209194, 96.00963142939976, 94.43051433563232, 90.13726411546979, 65.17533261435372, 48.49266610826765, 46.69881493704659, 130.1347291128976, 88.61444132668632, 48.72435031618391, 90.72545691898891, 84.4755939756121, 63.96533162253243, 5.33467401776995, 0.575044966169766, 0.31128551225577084, 0.1474887193845851, 0.19930378400853702, 0.2508674514080797, 0.3688744349139077, 0.43976728511708124, 0.5713562326771873, 0.7828858335103307, 0.7476592266133854, 1.1516635907547814, 1.0363749542406626, 0.7556500349725995, 14.533931749207632, 52.58735418319702, 76.27984632764543, 89.44509152003697, 90.43763474055699, 89.03436960492814, 83.02915273393903, 88.38382366725376, 91.46421023777553, 99.76850959232875, 93.84895011356899, 89.47152246747697, 89.39897632598877, 83.52708148956299, 85.66049112592424, 82.39337866646903, 83.10260214124406, 86.35642269679478, 88.08348083496094, 86.63235650743756, 84.02648326328823, 86.35790961129325, 89.95930685315813, 88.57542024339948, 89.97546836308071, 87.59270872388566, 81.24686336517334, 78.51025281633649, 98.12847764151437, 57.34401103428432, 1.1976459005049296, 6.654441782406398, 12.282202107565743, 9.133788330214363, 1.779509112238884, 13.676074147224426, 53.93108715329851, 86.09130723135812, 82.27864306313651, 82.15313080378941, 82.85030610220772, 85.60314764295305, 81.53362941741943, 85.13436658041817, 84.98601559230259, 86.61884226117814, 84.42660222734723, 83.17261913844517, 81.73023564474923, 77.02997384752545, 77.35275936126709, 78.22444561549595, 75.1745616367885, 75.85636751992362, 74.90782724108014, 78.12263366154262, 79.66946247645787, 78.66408593314034, 80.34991346086774, 76.38431249346051, 78.52710914611816, 67.23256220136369, 51.874493326459614, 54.87673698152815, 44.66180113383702, 36.9463164465768, 16.217293534960064, 2.4722207358905246, 1.3726723257984434, 2.0193653787885393, 0.33068960532546043, 0.5022407642432621, 0.5847550194178308, 0.2797745359795434, 0.16370536706277303, 0.1510880355324064, 0.3280452186507838, 0.5392791139228004, 0.1366746760904789, 0.13081549906304904, 0.11086113444928612, 5.667075404099055, 66.55785042898995, 90.3268735068185, 59.02166053227016, 41.80055727277483, 64.18370655604771, 48.793418884277344, 37.038741384233745, 42.64351272583008, 55.79764774867466, 64.43272999354771, 73.95784868512834, 82.37991305759975, 24.21162506512233, 0.5950890534690448, 0.16868231285895618, 0.15271669599626744, 0.15956110587077482, 0.1751201581209898, 0.1415707269417388, 0.11208382741148983, 0.18496511770146234, 0.18505967834166118, 0.14799540862441063, 0.16557432391813823, 0.08541461239968028, 0.10332151795072214, 0.117674162079181, 0.1358643967126097, 0.06689632644078561, 0.0916718587811504, 0.13379870541393757, 0.1494884027966431, 0.1353356550846781, 0.10807573462703399, 0.17658781579562596, 0.1655695741730077, 0.14806551486253738, 0.07693097048572131, 0.21611670111971243, 0.16236713315759385], [0.07562080078891345, 0.03474562395630138, 0.04464964322479708, 0.15132386716348784, 0.05042948933052165, 0.08113486812050853, 0.05800259153225592, 0.07668918131717614, 0.029912632756999562, 0.06526919268071651, 0.06763158020164285, 0.04261666409937399, 0.04826611952323999, 0.1041785076792751, 0.035900711081922054, 0.03093042510694691, 0.10049727878400258, 0.03385910438373685, 0.03338141573060836, 0.03061136437047805, 0.039728133739637475, 0.06806110643914767, 0.09102589344339711, 0.0838984666126115, 13.742861100605555, 72.96315152304513, 81.77486392429897, 81.91155583517892, 65.07010909489223, 50.07705341066633, 44.06083059310913, 44.64143596376692, 30.544041293007986, 75.27576909746442, 64.55012675694057, 27.73933318683079, 51.610378401620046, 65.63594954354423, 38.28961862836565, 2.0152781009674072, 0.10732014517166785, 0.07596473661916596, 0.19113897212914058, 0.1401183091636215, 0.02514036704919168, 0.040533551414098055, 0.07936228359384195, 0.12825077239956173, 0.03496733866631985, 1.443807331579072, 4.369032919406891, 9.273694651467459, 24.91175161089216, 49.57970482962472, 74.98593194144112, 77.90416840144566, 79.91558851514543, 80.36214923858643, 81.18421145847866, 82.71348912375313, 87.04800469534737, 85.93600109645298, 84.32895919254848, 80.97484833853585, 81.6151248386928, 83.95754323686872, 83.63157544817243, 82.43665899549211, 84.48065226418632, 81.16479124341691, 79.73566491263253, 80.9990975516183, 78.59076854160854, 79.40804345267159, 78.45862770080566, 74.65919290270124, 69.19303117479596, 65.76403958456856, 69.47095911843437, 71.85338524409703, 75.20827429635185, 76.31251675742013, 71.24659211294991, 80.35304015023368, 43.26733589172363, 0.9668910141502107, 0.4384983703494072, 0.19292148362312997, 16.195893083299907, 49.437655857631135, 79.95499869755336, 69.79883071354458, 74.02587154933384, 76.1977881022862, 75.36850670405796, 77.24949523380825, 75.16329860687256, 74.08898203713554, 74.3068219593593, 75.03577136993408, 77.13466235569545, 77.08572619301933, 78.58849648066929, 75.49651336669922, 74.95211505889893, 72.89760916573661, 76.91694055284772, 73.61815125601632, 73.2354861668178, 73.05898802621024, 71.56306866237095, 73.2507791519165, 70.87767056056431, 72.74770178113664, 76.65048408508301, 73.96401868547711, 68.47061307089669, 78.27180453709194, 70.39839771815709, 69.43889318193708, 63.067103249686106, 40.864544595990864, 12.444664018494741, 0.18287092793200696, 1.7965643342052187, 0.06300716048904828, 0.07844039199075528, 0.10651741110320602, 0.07723361746008907, 0.07018690236977168, 0.056180433237126896, 0.17848689960581915, 0.05860765477908509, 0.038369930548859496, 0.08871289648647819, 0.4477918030960219, 3.872928934437888, 58.499871662684846, 80.24880327497209, 73.38445554460797, 41.00396714891706, 43.95574951171875, 30.695584978376115, 16.455925941467285, 32.86596597943987, 40.07333237784249, 47.25268363952637, 50.715606757572715, 52.0570433480399, 20.451567445482524, 0.7451323079211372, 0.05113490790660892, 0.05995212442108563, 0.039108030764119964, 0.05716705708099263, 0.03619347858641829, 0.01479483352574919, 0.019558822802667106, 0.047092416789382696, 0.016752817568236163, 0.0592215321958065, 0.02865568395437939, 0.02068225966234292, 0.05417298059910536, 0.04417702662093299, 0.11788803631705896, 0.16802090406417847, 0.08794282030846391, 0.06601270421275071, 0.08016407449862786, 0.04232260398566723, 0.015017954499593802, 0.049753739698124785, 0.06823076054986034, 0.019676575769803355, 0.011756467366857188, 0.023559187073260546, 0.022599875960232954, 0.016475842966298972, 0.047942054591008594, 0.025610712257080843, 0.05206050091822233, 0.04667150116126452, 0.06847987111125674, 0.03665344729753477, 0.045738189813813994, 0.04480564860360963, 0.05501204003979053, 0.011082126542792788, 0.06951969888593469, 0.08961238964859929, 0.0653860228402274, 0.07122134257640157, 0.024918267270550132, 0.04609048180282116, 0.05137985226299081, 0.0651569494179317, 0.04006430373660155, 0.0709387327411345, 0.0894566997885704, 24.851095574242727, 90.35864067077637, 93.74234390258789, 94.8548755645752, 80.98037215641567, 69.4020607812064, 63.83537251608712, 56.94091476712908, 16.68615276472909, 41.69490991319929, 57.96626738139561, 36.55355215072632, 56.3964330809457, 64.94996084485734, 31.440772329057964, 0.2382135604109083, 0.16053233375506742, 0.11815362849405833, 0.19085413669901236, 0.28337020160896437, 0.20648577862552234, 0.06829199154994317, 0.1529959131564413, 0.05226655504001038, 1.1659768798521586, 5.219722151756287, 8.734430193901062, 16.267330987112864, 37.9740766116551, 68.70836653028215, 90.34536961146763, 88.48628180367606, 87.56704207829067, 87.32215281895229, 89.36641706739152, 89.48578711918422, 91.69452217647007, 89.48652362823486, 87.54377950940813, 84.50515161241803, 87.05190958295549, 88.16100188664028, 89.74626813616071, 88.21391936710903, 89.89281259264264, 85.96323803492955, 85.64932537078857, 84.27749388558524, 83.05336025782994, 83.91342912401471, 82.76099395751953, 79.43107673100063, 74.95309475490025, 70.84964847564697, 72.36785071236747, 76.60563346317836, 79.16719804491315, 81.55804538726807, 76.59940787724086, 81.37272303444999, 58.502873284476145, 3.0296176033360616, 1.165955166731562, 0.6966018549033574, 23.73878104346139, 59.833647864205496, 84.37686702183315, 76.34509686061314, 79.06748444693429, 80.10183497837612, 81.1473582131522, 80.74919864109584, 76.42554310389927, 77.7796219417027, 77.1911928994315, 76.78475107465471, 76.7055277143206, 79.68843105861119, 79.60004302433559, 78.80127811431885, 77.99533571515764, 81.27004255567277, 81.35390036446708, 79.86815316336495, 78.4031046458653, 79.75266715458461, 77.25732585362026, 77.8932249886649, 77.49105630602155, 80.35031645638603, 81.87989289419991, 80.39849526541573, 75.90965325491769, 83.59358964647565, 76.71055126190186, 75.33466897691999, 73.52340562002999, 57.7154096194676, 20.341358593532018, 0.5313316232391766, 1.4595767025436674, 0.1011993046849966, 0.19834227274571145, 1.0368170333760125, 0.5631461217999458, 0.08595682973308222, 0.17669923124568804, 0.3738714110638414, 0.02186081392158355, 0.06449636843587671, 0.13055578299931117, 0.29972864953534945, 1.7714470305613108, 54.904474190303254, 85.047041620527, 68.70820672171456, 32.24670083182198, 33.74485404150826, 18.962829044887, 21.399779421942576, 51.8679689679827, 55.992252894810264, 65.20817674909318, 58.85595294407436, 65.64040333884103, 32.70988859449114, 1.1148692965507507, 0.07299473455974034, 0.019063392155138508, 0.03420764746676598, 0.028999599428581338, 0.08225316168474299, 0.04553016794047185, 0.10305423622152635, 0.05482445564121008, 0.02206244908406266, 0.03739216497966221, 0.032045583839395216, 0.05158470198512077, 0.07918181363493204, 0.07650717108377389, 0.031997879434909136, 0.09370816272816487, 0.013031480468011327, 0.1467976857508932, 0.10697066571031298, 0.04616780426087124, 0.1061025955049055, 0.043407690046089034, 0.06279117600726229, 0.07315387816301414, 0.035812301361667256, 0.1317093332431146, 0.11994747152285916, 0.08065756623234067, 0.17114023811050824, 0.10475577134639025, 0.11511175600545746, 0.1628881259156125, 0.17452287088547433, 0.135494147294334, 0.2351923425282751, 0.18949598100568565, 0.09109583004776921, 0.14879537426999637, 0.26840888442737715, 0.18039532005786896, 0.1268953172756093, 0.172897765945111, 0.09831477768187012, 0.10170534931655441, 0.15546191297471523, 0.14717993166829857, 0.10347292625478335, 0.2601386824888842, 0.3025987169572285, 28.48648166656494, 103.97194044930595, 103.73932865687779, 99.54061562674386, 84.21958759852818, 69.61213261740548, 58.84560707637242, 61.35600512368338, 46.111341272081646, 109.34013257707868, 95.75392382485526, 44.62222072056362, 68.48114653996059, 80.10435022626604, 48.197496209825786, 2.941781299454825, 0.38134094168032917, 0.171688670824681, 0.5404193784509386, 0.40360991816435543, 0.3035700262657234, 0.263354911335877, 0.3755371059690203, 0.603307632463319, 0.8869456382734435, 3.862000286579132, 6.02802346433912, 13.180638057844979, 33.35906226294381, 67.28231825147355, 95.95570646013532, 92.1430561883109, 89.30498804364885, 88.02760342189244, 90.44885608128139, 90.99673543657575, 93.44124371664864, 91.46075698307583, 90.81851414271763, 85.43428557259696, 88.71086842673165, 89.25815023694719, 91.703186580113, 89.22735582079206, 89.81561810629708, 90.05838121686662, 88.63657828739711, 87.73092229025704, 83.66801180158342, 85.87592697143555, 84.23674270084926, 81.07533318655831, 77.6609536579677, 73.97899900163922, 78.21123708997453, 80.81576933179582, 84.04652881622314, 84.98836408342633, 79.39564786638532, 84.22524343218122, 58.59668091365269, 1.4481468072959354, 3.9599881257329668, 1.1411889642477036, 21.06690686089652, 58.71773937770298, 83.15853513990129, 77.26376683371407, 80.5131891795567, 81.00034127916608, 79.02683748517717, 82.1021866117205, 78.635146686009, 78.13190255846295, 77.94009058816093, 79.02281447819301, 80.26560401916504, 80.64605958121163, 80.67194162096295, 79.28387219565255, 78.07028593335832, 79.79145199911935, 81.6417989730835, 83.21853978293282, 80.86948585510254, 82.56965446472168, 79.18935585021973, 80.7819663456508, 79.43641989571708, 79.72128908974784, 83.10784803118024, 80.61391026633126, 73.65817982809884, 84.68371336800712, 74.99522168295724, 75.31462342398507, 70.74905940464565, 53.25052152361189, 18.4800751549857, 0.8052727122391973, 3.6153911309582845, 0.8604405405265945, 0.7397382802196911, 1.2812086279903139, 0.40528999801192966, 0.1781861593148538, 0.179596657199519, 0.3744145647755691, 0.18981878725545748, 0.19220334930079325, 0.2871706762484142, 0.7453310915402004, 6.338951442922864, 69.80959347316197, 91.23759474073137, 89.70166764940534, 58.28982067108154, 67.27009637015206, 45.057744230542866, 26.23355606624058, 43.21435240336827, 53.06029026848929, 66.89802728380475, 65.8328753880092, 76.53818035125732, 40.58557094846453, 1.5632772637265069, 0.23224720199193272, 0.1771548403693097, 0.1556814054825476, 0.15613449045589992, 0.24953068313854082, 0.0829458102317793, 0.17059200895684107, 0.09502610843628645, 0.08147643586354596, 0.13244675153068133, 0.18242373264261655, 0.16367488726973534, 0.14021265267261437, 0.16048898893807614, 0.12997830898634025, 0.22783924852098736, 0.2010986991226673, 0.2550791725516319, 0.21051852937255586, 0.09599397757223674, 0.14708375611475535, 0.13737226437245095, 0.21185759109045776, 0.19584643095731735, 0.0756945711161409], [0.07061577042830841, 0.012336675875953265, 0.030304595295872008, 0.02789374001856361, 0.03047757762085114, 0.09045708432261433, 0.08861703305904355, 0.07674973378224031, 0.13870675276432717, 0.022563784682591046, 0.03898393349455936, 0.03960521712100931, 0.13267794198223523, 0.19299418186502798, 0.03491913553859506, 0.055425050734941445, 0.0832237313900675, 0.0025015202783314244, 0.045063332454966645, 0.06346631156546728, 0.04887659069416778, 0.028009214804374745, 0.10857965544398342, 13.390040261404854, 65.36870792933873, 81.68281418936593, 79.65926252092633, 69.12698854718889, 58.3740884235927, 66.52323450360979, 33.43214341572353, 36.4645665713719, 70.24475915091378, 65.17338711874825, 65.69433525630406, 136.97677312578475, 99.57121549333844, 34.9814110483442, 1.9258947372436523, 0.03755167838452118, 0.05831720107900245, 0.044311156030744314, 0.07225703128746577, 0.028329958307689855, 0.12406298997146742, 0.15496819732444628, 0.05449159350246191, 1.62286653476102, 19.797288588115148, 40.239825112479075, 46.83467306409563, 62.70355265481131, 77.33183138711112, 82.23008210318429, 78.65118312835693, 83.68153299604143, 80.1239788872855, 82.5721002306257, 81.98444938659668, 86.67704732077462, 81.70156737736293, 81.73412663596017, 80.04933438982282, 83.17660740443638, 79.7543694632394, 83.99250657217843, 83.546140398298, 82.5925418308803, 77.62080696650914, 72.87996768951416, 70.61691856384277, 73.83653313773019, 75.84044919695172, 81.56706414903913, 77.88909081050328, 79.44852365766252, 78.6460553577968, 76.90237018040249, 70.21816144670758, 74.04318646022251, 71.86442593165806, 74.93489742279053, 74.70031929016113, 76.57335213252476, 63.04090854099819, 46.96488577978951, 2.5195544702666144, 8.799747603280203, 50.84484325136457, 70.20538370949882, 75.27432387215751, 75.64521871294293, 79.40847424098423, 71.43182413918632, 73.10549926757812, 71.67800576346261, 72.36785071236747, 76.07989106859479, 77.06725093296596, 74.56504481179374, 74.04134518759591, 72.08524663107735, 73.80898353031704, 68.90366649627686, 69.20471804482597, 75.02533517565045, 71.96086692810059, 73.64262281145368, 76.3349038532802, 72.75161361694336, 73.90267998831612, 71.06994111197335, 69.85017790113176, 71.55294513702393, 71.04457323891776, 73.99901676177979, 76.22151620047433, 74.80745356423515, 73.60080160413469, 71.47753633771623, 71.44580391475132, 75.44719505310059, 60.18602575574602, 28.867444447108678, 4.320127589362008, 0.6910345564995493, 0.2478854257081236, 0.9322623865944999, 0.5192162447742054, 0.1727778416659151, 0.15231330692768097, 0.12109807692468166, 0.06241311665092196, 0.07617615456027643, 0.06943360636276857, 0.2047347104442971, 0.1720063609204122, 6.723946349961417, 58.77569430215018, 65.07568155016217, 58.695574624197825, 28.818207774843486, 45.84607989447457, 41.336101463862825, 22.624519280024938, 35.99600437709263, 36.81090995243618, 47.11462640762329, 58.93421745300293, 57.5487014906747, 31.280119555337087, 2.292787632771901, 0.12929601488368853, 0.0960248169888343, 0.07772105666143553, 0.037520883072699816, 0.06678277360541479, 0.029072484267609458, 0.028102562563227754, 0.08604230478938137, 0.07944749402148382, 0.011239835044502147, 0.0948160339945129, 0.032928876977946074, 0.03889750848923411, 0.06610379753900425, 0.0270347944128194, 0.01171701479636665, 0.12763131063963684, 0.10105754514890057, 0.05991050986839192, 0.025810230390301774, 0.14584640679614885, 0.028245646938947693, 0.025759021352444376, 0.09619649991925273, 0.05720825094197478, 0.16152253347848142, 0.01295589336327144, 0.02387530805676111, 0.07529870700091124, 0.0985382464049118, 0.08170578748519931, 0.08054898027330637, 0.12451196302260671, 0.023419447875182544, 0.0465586031121867, 0.02409645788637655, 0.09731938716556345, 0.06446123389261109, 0.045256172107266526, 0.0724796247003334, 0.03427187419895615, 0.009063576464541256, 0.05569714327741947, 0.01264035252721182, 0.03653007606044412, 0.03634151457143681, 0.8132362706320626, 25.569582734789165, 86.13845770699638, 91.74772453308105, 94.3355324608939, 89.38029261997768, 75.48421505519322, 70.86448982783726, 38.885655948093955, 20.816816874912806, 42.14743219103132, 69.94636876242501, 79.93480723244804, 143.98346165248324, 84.95728479112897, 27.3357401234763, 0.8420862768377576, 0.03478249554921474, 0.11266397485243422, 0.10191538304622684, 0.02122778824663588, 0.07418765340532575, 0.08079971931874752, 0.09211116949362413, 0.05346734828448721, 4.927969898496356, 29.850697926112584, 52.38368163790022, 61.2357109614781, 74.84179156167167, 88.06025300707135, 89.17531381334577, 85.32036985669816, 89.56933225904191, 88.12748377663749, 89.04691110338483, 87.45163249969482, 89.22875935690743, 85.76949446541923, 86.3381906236921, 82.22425256456647, 85.34356989179338, 83.64133766719273, 87.43105888366699, 87.50199999128068, 86.65163775852749, 78.60709680829729, 75.12750148773193, 73.22190243857247, 75.44256755283901, 79.25696182250977, 82.90248012542725, 82.2723479952131, 83.57319668361119, 83.57252965654645, 81.64126396179199, 76.83015060424805, 79.59475544520787, 75.6701488494873, 77.92805630820138, 77.8569484438215, 85.38455731528146, 69.16136128561837, 60.56648826599121, 6.39240871156965, 16.91877497945513, 58.850192887442454, 75.35235214233398, 81.81840828486851, 80.70805140904018, 80.85940401894706, 72.56879956381661, 77.7480354309082, 75.9117238180978, 77.17030661446708, 80.0931705747332, 79.69282232012067, 79.12060342516217, 80.60201495034354, 77.26887375967843, 76.2521230152675, 73.33610997881208, 72.05834320613316, 77.92187935965401, 73.58768340519497, 76.40125914982387, 79.8213778904506, 77.962783404759, 79.75666236877441, 76.88156727382115, 76.9939682824271, 76.87156186785016, 75.73205729893276, 78.98509965624127, 79.07885864802769, 78.61829035622733, 76.16656984601701, 74.98785659245083, 75.84321457999093, 79.62657819475446, 71.11998898642403, 43.827468395233154, 9.481531773294721, 0.6638453326054982, 0.06478375515767507, 0.2527609983725207, 1.7988984946693694, 1.51478003178324, 0.7889631731169564, 0.19500196698520864, 0.1580379983144147, 0.019515557713540535, 0.030247981726591076, 0.12137856973069054, 0.11936068800943238, 3.742694071360997, 59.37413569859096, 70.81630407060895, 61.93460941314697, 22.687885114124843, 30.275865146092006, 18.528370346341813, 24.572323424475535, 50.45325320107596, 52.2949983051845, 68.6855000087193, 69.50982734135219, 68.70788710457938, 45.00277703148978, 4.307782811777932, 0.11776022746094636, 0.030584117796804224, 0.02004121370347483, 0.0751999733703477, 0.06327769918633358, 0.03711302245834044, 0.1040604290153299, 0.038732661799128563, 0.06723106133618525, 0.022126786078193357, 0.04400164906733802, 0.04282890306785703, 0.03259483079559036, 0.13022495646561894, 0.025674100998522978, 0.0038968423032201827, 0.028700755642993108, 0.06116700744522469, 0.06496360086436782, 0.08312936752502408, 0.08416656936917986, 0.03425053087994456, 0.0625825739864792, 0.034061046583311896, 0.13968472528670514, 0.22510176684175218, 0.13259513356855937, 0.18800803513399192, 0.09683240936802966, 0.1445229785250766, 0.14114021004310676, 0.10053349219794784, 0.21963084755199297, 0.13742349376635893, 0.13918288078691277, 0.1567511430808476, 0.2487138355416911, 0.20185667702129909, 0.18934937672955648, 0.10554110099162374, 0.19422817922064237, 0.13073041077171052, 0.15888254371072563, 0.15865291388971464, 0.1131662739706891, 0.09637738378452403, 0.8492751110877309, 30.926532677241735, 103.43260043007987, 102.46557099478585, 99.49360411507743, 91.87283379690987, 82.04865074157715, 83.31443881988525, 45.9130778993879, 51.934793267931255, 92.56274822780064, 94.44761385236467, 83.37717410496303, 166.57024874005998, 114.17773246765137, 48.67178719384329, 3.495933792420796, 0.160065053829125, 0.2606016605028084, 0.4198230510311467, 0.18366180120834283, 0.12510869385940687, 0.15969804780823843, 0.4863585393343653, 0.18112675366657122, 3.059112706354686, 24.21202458654131, 50.3636075428554, 62.09439713614327, 78.19369983673096, 91.62677724020821, 89.95790331704276, 83.1752872467041, 91.32444027491978, 89.86073970794678, 92.17838777814592, 88.80418273380825, 92.65672956194196, 88.09996891021729, 89.78026567186627, 85.9253008706229, 88.74617222377232, 85.50165530613491, 89.4463005065918, 91.0839283806937, 87.08698408944267, 79.99115017482212, 77.35546221051897, 74.17779391152519, 76.85052272251674, 78.72701576777867, 87.69970403398786, 85.7162504196167, 86.6435500553676, 86.83796065194267, 85.03808539254325, 79.88812228611538, 82.40596185411725, 78.40724577222551, 79.54125431605748, 82.26355157579694, 87.17430904933384, 69.5699223109654, 58.6692340033395, 3.4977053659302846, 14.193106974874224, 61.028661591666086, 74.20484324863979, 84.10933358328683, 80.97540419442313, 84.51795019422258, 76.03658294677734, 80.23863111223493, 79.86395645141602, 79.25099331992013, 81.82223674229213, 81.06491783687046, 79.1675385066441, 81.14233466557094, 78.78260135650635, 79.44960062844413, 74.2397996357509, 75.65890666416713, 81.37949057987758, 76.71603339059013, 78.4528329031808, 81.68500287192208, 77.81307056971959, 80.81721455710274, 77.76765714372907, 77.50204140799386, 78.59509726933071, 78.37957109723772, 81.76578957693917, 81.32510702950614, 80.54651968819755, 77.477646282741, 75.85095487322126, 75.81415721348354, 79.41533211299351, 70.39329079219273, 41.23156581606184, 7.519205025264195, 1.3370422891208102, 2.269782147237233, 1.6675273839916502, 1.7478923116411482, 1.186007450733866, 0.675298840871879, 0.21754722935812815, 0.32112665846943855, 0.06250262220523187, 0.3039446861616203, 0.5136448208774839, 0.3040543645620346, 10.635876825877599, 72.41312517438615, 75.28990868159703, 72.44020925249372, 42.10145248685564, 68.63269369942802, 58.55606174468994, 34.10608393805367, 46.42409011295864, 51.82778753553118, 66.38093539646694, 75.29054791586739, 79.05673558371407, 50.656911849975586, 4.999020874500275, 0.2432640865445137, 0.16272088060421602, 0.23472426193101065, 0.2180004771798849, 0.15627653497670377, 0.13352350518107414, 0.1961349304765463, 0.17935250672910893, 0.12619679261531147, 0.09278974522437368, 0.19986057627413953, 0.07665110871727977, 0.07432574206697089, 0.1591095950986658, 0.08717429797564234, 0.09344008711299726, 0.25740804044263704, 0.18085156700440816, 0.15234713868371078, 0.1059363204985857, 0.13396368441837175, 0.08400867427034037, 0.10534216130950622, 0.10564649105072021], [0.053359003205384524, 0.07578700115638119, 0.12803091348281928, 0.024188497768981115, 0.08405583923948662, 0.051191745392446, 0.05080422725794571, 0.08475645378764186, 0.08279185063604798, 0.06482673356575624, 0.04785498158474054, 0.04160466643848589, 0.09507961092250687, 0.04708280534084354, 0.058567777276039124, 0.05428509833291173, 0.07537746456052576, 0.04928369474198137, 0.05444506635623319, 0.07781658760671105, 0.16577453246074064, 2.9930911404745917, 33.018506731305806, 76.48607581002372, 81.14615617479596, 78.11508096967424, 57.665806429726736, 57.80092109952654, 48.805665084293906, 57.719571590423584, 49.78571196964809, 66.79580538613456, 48.85517447335379, 63.85657841818673, 129.94661358424594, 77.072601045881, 22.68700964110238, 1.4857894331216812, 0.04042810707220009, 0.07854899152048997, 0.12288084626197815, 0.04606884332107646, 0.03069494292140007, 0.34921176571931156, 0.2119373460965497, 0.11189374939671584, 3.6049121618270874, 34.55742849622454, 63.64100360870361, 65.70404883793422, 61.0612347466605, 69.92302976335797, 87.15587547847203, 91.44007219587053, 87.62690080915178, 82.67918586730957, 83.47871507917131, 85.07648113795689, 83.61231504167829, 79.17967700958252, 78.3096444266183, 79.781724521092, 77.88321263449532, 77.72933782849992, 81.17064162663051, 84.27696582249233, 79.56320367540631, 77.00945581708635, 76.09550367082868, 73.69189248766217, 74.16195896693638, 73.57050745827812, 76.43730640411377, 77.19473648071289, 76.27391256604875, 76.20183195386613, 72.23693970271519, 74.12026977539062, 74.36888326917375, 69.04857812608991, 70.45552580697196, 77.62101541246686, 72.43964644840786, 73.39255714416504, 74.1421843937465, 61.79821627480643, 41.99752133233206, 39.516910212380544, 58.51472691127232, 74.37173203059605, 73.42148249489921, 73.21538502829415, 72.3389948436192, 67.90982396262032, 71.04654652731759, 74.50805568695068, 77.84071050371442, 76.71091256822858, 71.88832773481096, 76.70340851375035, 79.2029812676566, 74.00966835021973, 72.94432885306222, 72.52875709533691, 73.59224142347063, 71.25645855494908, 67.67168140411377, 71.8572553907122, 70.65653024400983, 73.00256170545305, 71.47028936658586, 72.1609889439174, 72.63015910557338, 73.00940568106515, 70.49871580941337, 70.27732535770961, 71.77502346038818, 77.90724645342145, 74.53668226514543, 73.87450504302979, 71.86386312757219, 69.52146557399205, 70.76295580182756, 75.17337349482945, 62.43994494846889, 19.277981962476456, 0.23361990547605924, 1.4733889613832747, 0.5031672630991254, 0.2838556527027062, 0.6868495696357318, 0.3716663351016385, 0.03323419398761221, 0.053342596228633604, 0.04578700701573065, 0.3172647085572992, 0.12418739258178643, 0.22051147744059563, 14.34767312662942, 66.36906787327358, 64.27576323917934, 54.52042988368443, 36.165331976754324, 54.9676958492824, 48.72592755726406, 27.69490987913949, 32.06303562436785, 38.99573278427124, 45.5536093711853, 60.53511714935303, 56.70209475925991, 41.14501210621425, 5.344429722854069, 0.07736333299960409, 0.022232500137761235, 0.041973080419536145, 0.11263467571032898, 0.07906560094228812, 0.042164610499250035, 0.05756569640444858, 0.07426377824906792, 0.04983186961284705, 0.06418105999806098, 0.05040959129109979, 0.08193619083613157, 0.1506748212767499, 0.012693449588758605, 0.04972169588186911, 0.0677029417295541, 0.07715062584195818, 0.16046574232833727, 0.10888070786105734, 0.06398923814828907, 0.024769408561821495, 0.0691909622400999, 0.11571547575294971, 0.07596262637525797, 0.07467703321682555, 0.06487787475011178, 0.1356499253639153, 0.033552650827914476, 0.05293269661654319, 0.09084870080862727, 0.08800951351544686, 0.02945271832868457, 0.04231504510555949, 0.01053618744481355, 0.01312511066706585, 0.0281782463592078, 0.03920543446604695, 0.12972208059259824, 0.07241462104554687, 0.07134217609252248, 0.12313821459455149, 0.296145957495485, 0.13347129869673932, 0.06758726507957492, 5.834090990679605, 53.23996720995222, 93.38257312774658, 93.87131636483329, 97.44938850402832, 78.25224535805839, 74.17027596064976, 71.08675575256348, 70.62522166115897, 25.572514874594553, 31.066024712153844, 46.41933059692383, 81.2067653111049, 130.92594827924455, 64.94156047276088, 17.445246934890747, 0.9763166798012597, 0.0479643410736961, 0.113925093252744, 0.13645997403987817, 0.12562887237540313, 0.31534385734370773, 0.10158542503735848, 0.14889009775859968, 0.07726597000977822, 9.231034449168614, 44.29413720539638, 74.40938431876046, 73.12254319872174, 70.82025064740861, 78.10142775944301, 91.47172124045235, 95.07678018297467, 94.32670130048479, 87.61861855643136, 88.97236388070243, 90.01946435655866, 85.89288057599748, 82.76075771876744, 83.59097712380546, 83.210875919887, 82.78521537780762, 82.44225924355644, 83.39598982674735, 86.07481220790318, 83.64224788120815, 79.49817548479352, 79.93748923710415, 77.6317503792899, 78.73354012625558, 76.99455193110875, 79.62475081852504, 81.22108554840088, 82.12285055433, 79.51142569950649, 77.41321563720703, 76.0974908556257, 78.16209942953927, 73.33436598096574, 75.88778032575334, 79.3248735155378, 76.05687863486153, 75.70795399802071, 81.5099013192313, 65.76981353759766, 51.60193286623274, 46.78162704195295, 63.509349141802105, 77.87765407562256, 77.66346890585763, 77.27316774640764, 75.72883333478654, 72.28783525739397, 74.96772071293422, 77.48106479644775, 79.11003521510533, 78.54776614052909, 75.67779186793736, 78.08081245422363, 78.94914272853306, 74.46048137119838, 74.03300734928676, 75.6231998716082, 77.2605984551566, 72.76691355024064, 73.01146929604667, 74.60325990404401, 75.62119879041398, 75.71048314230782, 74.33018180302211, 75.53927952902657, 73.77278341565813, 77.36076368604387, 76.20623016357422, 74.78959669385637, 74.31272097996303, 79.59210818154472, 77.54826082502092, 77.88064180101667, 76.98042624337333, 73.42774282182965, 74.45897361210415, 81.72940186091832, 76.02422904968262, 32.14371810640608, 0.8558310621551105, 0.4704190460698945, 0.5951221659779549, 0.7622881159186363, 1.0013489765780312, 1.5988556231771196, 0.044641812930681875, 0.12128923381013529, 0.11667292937636375, 0.37191457035286085, 0.022967095719650388, 0.24118225968309812, 11.60167121887207, 69.83809498378209, 71.64746148245675, 55.5274600982666, 34.99853835787092, 44.27386931010655, 20.384765727179392, 25.54237880025591, 45.69714873177664, 52.39714724676949, 61.23216043199812, 75.40472766331264, 63.68585423060826, 58.548432622637065, 9.875471183231898, 0.030734952738774673, 0.09565655567816325, 0.08521859041814293, 0.07114457990974188, 0.1097662639138954, 0.00836023929462369, 0.04420432069205812, 0.0177958938293159, 0.020871092565357685, 0.038261083353843005, 0.05164562425177012, 0.10020778181829623, 0.0891508162021637, 0.049147577224565406, 0.054389345060501776, 0.11356565968266555, 0.042569237894245555, 0.09552817685263497, 0.10097137120153223, 0.004269673971326223, 0.05989728522087846, 0.0964156531595758, 0.10118071282548563, 0.11852983544979777, 0.12145255718912397, 0.15173860133758613, 0.19486512004264764, 0.1479001830198935, 0.09324379371745245, 0.1512870362826756, 0.16223811650914804, 0.22048591024109296, 0.1864983897124018, 0.09153510004814182, 0.1474565432540008, 0.1374576376484973, 0.08907780583415713, 0.16118625152323926, 0.19931610620447568, 0.17250182719102927, 0.14623853218342575, 0.34906845912337303, 0.19714046509138175, 0.19953040113406523, 5.385503998824528, 58.20911039624895, 105.90242099761963, 104.33719335283551, 101.514557157244, 78.01786177498954, 74.86759717123849, 66.19622448512486, 81.1598093850272, 71.55077729906354, 92.32042285374233, 73.09464618137905, 80.46513543810163, 141.16963577270508, 81.6945219039917, 34.81365721566336, 3.76177556174142, 0.18589681413556847, 0.2703710177115032, 0.27128828849111286, 0.16169100015291146, 0.23135848396590777, 0.5834741081510271, 0.4222529392157282, 0.20957270583936147, 6.390396773815155, 42.82910605839321, 80.34719671521867, 85.36818041120256, 77.69205379486084, 79.64564405168805, 91.20593179975236, 96.91121578216553, 95.2220183781215, 90.03126239776611, 91.36043889181954, 91.25142860412598, 87.24267932346889, 86.24861444745744, 86.77050059182304, 86.48951544080461, 83.36101259504045, 82.48688752310616, 84.48482813153947, 89.2156481061663, 83.86759185791016, 82.83652087620327, 81.82138211386544, 80.30956527165004, 80.81242030007499, 79.28577600206647, 83.37206717899868, 85.64133494240897, 84.7834061213902, 83.35254274095807, 80.20448766435895, 78.31343814304897, 81.29987117222377, 77.69424247741699, 80.1691699709211, 86.3009204864502, 76.53151008061, 80.12784208570207, 80.5141271863665, 68.69309438977922, 56.76418386186872, 51.9607378414699, 64.30111721583775, 79.53183255876813, 80.73248822348458, 78.62885856628418, 79.74577454158238, 73.54641110556466, 73.593339238848, 76.77478735787528, 80.6747486931937, 80.90044702802385, 77.02199731554303, 79.6635912486485, 81.11645957401821, 74.45420019967216, 74.82098865509033, 77.33996077946254, 78.43526785714286, 74.50563771384103, 75.12266554151262, 76.05532223837716, 76.49556010110038, 80.52536242348808, 76.16248430524553, 77.48269762311662, 76.92328425816127, 78.36781474522182, 78.1906704221453, 74.93628011431012, 76.93965421404157, 83.94924013955253, 80.10595526014055, 80.63675594329834, 77.61040551321847, 74.64005756378174, 73.27026884896415, 82.45868478502545, 76.08839566367013, 28.5077257837568, 0.6736006577100072, 4.086250356265476, 2.4061266481876373, 1.5045828989573886, 2.883535202060427, 1.0407497137784958, 0.12807671459657805, 0.15667772559182985, 0.4212745188602379, 0.4619209106479372, 0.21776330204946653, 0.2919469656688826, 20.508620841162546, 81.47156810760498, 75.8874329158238, 70.60343905857631, 50.550131934029714, 78.63040801456997, 65.97298581259591, 41.14250380652291, 43.82279920578003, 54.14424051557268, 61.24415302276611, 78.43366977146694, 74.2632428577968, 67.93344783782959, 12.33773558480399, 0.19295846378164633, 0.18484675405280931, 0.2058027381343501, 0.20958189320351395, 0.22465827635356359, 0.13971749852810586, 0.09561118204146624, 0.27769650891423225, 0.08300031016447715, 0.1757340423230614, 0.12022896856069565, 0.19064147025346756, 0.16809482366911002, 0.1066028658034546, 0.13905873601990087, 0.18001580185123853, 0.12934440800121852, 0.1750807080950056, 0.20709557804678166, 0.1260904118950878, 0.107515359696533, 0.2540670968592167, 0.17290130789790834], [0.08364560375256197, 0.18641387139047894, 0.13578685373067856, 0.05858791619539261, 0.09651600170348372, 0.06595008221587964, 0.06228220010442393, 0.08044795997972999, 0.08149462738739592, 0.047129196780068536, 0.20156572120530264, 0.00872640308391835, 0.07834777196070977, 0.08073525170662574, 0.07842638702797038, 0.02588180056773126, 0.12161317999873843, 0.03993839477854116, 0.050956504086830785, 0.06891177900667701, 4.673505587237222, 51.307193756103516, 85.4304849079677, 73.0457239151001, 69.22217191968645, 59.95975766863142, 48.63749435969761, 43.74693529946463, 36.619862283979145, 24.580246107918875, 44.925349780491416, 58.963900157383506, 77.27783693586076, 100.41287858145577, 45.34728261402675, 17.977395568575176, 2.8543883774961745, 0.09242082573473454, 0.1382321718015841, 0.04036918309118066, 0.21294148292924675, 0.12095422750072819, 0.31200193666986054, 0.12615575481738361, 0.1534481296049697, 3.1185938460486273, 40.63571957179478, 69.15490640912736, 66.74893978663853, 60.64893559047154, 76.43577085222516, 91.54061262948173, 91.04890251159668, 87.1395958491734, 82.25983428955078, 84.77422060285295, 84.6886465890067, 79.36816774095807, 79.04112992967877, 80.60372420719692, 77.9160498210362, 79.28107901981899, 82.27484239850725, 83.77085208892822, 81.56764779772077, 78.66123022351945, 77.96996089390346, 76.3655732018607, 80.79111712319511, 77.47102464948381, 76.45253685542515, 75.20432077135358, 73.25664343152727, 72.73096357073102, 77.01796041216168, 75.33110455104283, 76.13002926962716, 71.54093170166016, 73.92374692644391, 70.54342746734619, 69.08525766645158, 71.24228422982353, 77.31211934770856, 68.24436582837785, 78.61653246198381, 63.655428068978445, 42.42386974607195, 40.692885875701904, 64.79286902291435, 77.02618707929338, 68.1346607208252, 74.02257115500313, 69.65590626852853, 70.60475226811, 71.33309718540737, 75.6229636328561, 71.74467372894287, 73.9322098323277, 71.91399438040597, 77.66535186767578, 74.15391295296806, 71.35717269352504, 70.1777229309082, 72.98460756029401, 72.39121055603027, 72.27369567326137, 72.30904115949357, 73.26466165270124, 72.89344024658203, 75.0203880582537, 72.20519338335309, 70.38456385476249, 69.4730088370187, 72.08358601161412, 70.04132284436906, 70.4717915398734, 68.97072356087821, 70.00056471143449, 70.49354634966168, 74.63068444388253, 71.46709319523403, 75.78778879983085, 68.43656689780099, 71.43404756273542, 69.22616018567766, 77.42313071659633, 37.583719866616384, 0.6329513617924282, 2.9587785473891666, 1.6720223256519862, 1.6293169600622994, 1.3035172309194292, 1.3926589276109422, 0.07479415514639445, 0.041710989483233006, 0.11031095790011541, 0.018583438891385282, 0.20910579232232912, 0.05935853520142181, 20.41637829371861, 63.58340999058315, 59.11523192269461, 60.56453582218715, 43.52011830466134, 55.80703476497105, 39.496166365487234, 23.928475550242833, 30.788986137935094, 42.447455406188965, 46.11100428444998, 57.24371378762381, 60.93739700317383, 44.18497405733381, 12.322615436145238, 0.05705595375703914, 0.07339453417807817, 0.05987466286335673, 0.11556801652269703, 0.03620618076196738, 0.021346676063590815, 0.05677507757874472, 0.060078155515449386, 0.041107032248484235, 0.07693570666015148, 0.05139827109607203, 0.07979845947452954, 0.06582453966672931, 0.11942828366799013, 0.05409430107101798, 0.12439924478530884, 0.10267046360032898, 0.061239692116422315, 0.019860845524817705, 0.08422058075666428, 0.00498515013272741, 0.11803668976894446, 0.1051908547856978, 0.1574200971850327, 0.041749564199043174, 0.04083236466561045, 0.07255709304341249, 0.006585233670193702, 0.025880324754065702, 0.090432148160679, 0.07763438738350358, 0.05969047453254461, 0.08405832267765488, 0.02271890626954181, 0.04465007409453392, 0.15620832863662923, 0.08836960526449339, 0.05355748148368938, 0.06963136539395366, 0.019477227270337086, 0.04408774159050413, 0.008055813710338302, 8.307454705238342, 73.37940420423234, 96.30789675031389, 83.72465351649693, 84.07094478607178, 80.4514822278704, 62.287925311497276, 61.032656805855886, 41.260734353746685, 13.752159527369908, 27.113729545048304, 53.897798333849224, 83.26558603559221, 99.62170805249895, 43.05129555293492, 22.043827056884766, 2.5406439900398254, 0.08445120802415268, 0.0839131772518158, 0.06434694823942014, 0.2469906008669308, 0.4171278827956745, 0.17726582155695983, 0.1536393950560263, 0.07112405422542777, 6.413454370839255, 52.837134974343435, 79.66016578674316, 75.21179008483887, 75.30654266902378, 89.0175063269479, 98.20681858062744, 96.53663144792829, 89.97699001857212, 85.14207213265556, 89.38467693328857, 88.8111378805978, 82.62173121316093, 83.4253181729998, 85.06237629481724, 81.95410660334996, 82.86165945870536, 87.81744820731026, 86.69516822269985, 84.67317295074463, 80.53081675938198, 82.77024895804269, 81.00137656075614, 83.10248402186802, 81.07452024732316, 79.9429852621896, 78.74012007032121, 76.95207064492362, 74.24270398276192, 81.10567596980503, 79.21766975947789, 81.13939557756696, 77.35186304364885, 78.44336250850132, 73.04001249585832, 72.27590520041329, 73.64527702331543, 80.52197865077427, 72.52892385210309, 81.42971910749162, 70.77152987888881, 44.2709059034075, 44.92640938077654, 70.2980101449149, 79.33095318930489, 70.22219835008893, 77.0221015385219, 73.87866006578717, 72.52219799586705, 73.35086795261928, 75.23316969190324, 75.66097027914864, 76.55686405726841, 76.96463993617466, 80.94499887738908, 77.6993771961757, 74.41438702174595, 72.99295929500035, 75.9043448311942, 74.91945157732282, 74.98768288748605, 75.56524494716099, 76.85312134878976, 75.97891984667096, 77.10018539428711, 75.88471617017473, 73.83846473693848, 72.7069228036063, 73.54677936008999, 71.37055492401123, 73.7423016684396, 72.6243782043457, 70.51714938027519, 72.28911372593471, 75.89140728541783, 73.08997004372733, 77.85359941210065, 72.9611782346453, 75.68910353524345, 72.67646190098354, 84.6971720286778, 49.9631724357605, 3.084935252155576, 1.1031970828771591, 0.4961609276277678, 0.6558709176523345, 2.1441026968615393, 4.030273931367057, 0.24494761334998266, 0.11633063560085637, 0.11076448392122984, 0.12777488864958286, 0.07649708126804658, 0.14932558153356823, 14.998272044318062, 67.85251522064209, 65.82002122061593, 63.193081038338796, 43.48594011579241, 36.57321555273873, 24.683543239321025, 31.853533540453228, 42.17305019923619, 58.346726417541504, 64.09419986179897, 70.83155536651611, 70.31494290488106, 60.88485472542899, 18.041758469172887, 0.12499028949865273, 0.03983533887990883, 0.07175377543483462, 0.07005304098129272, 0.009885344288444944, 0.04640547472185322, 0.01547577734371381, 0.04816756909713149, 0.04503752098285726, 0.027377222198992968, 0.030050602675016438, 0.06979669045124735, 0.07743727296058621, 0.14439246909958975, 0.059246604064745564, 0.09864272044173308, 0.0897567140470658, 0.005129024577659688, 0.024843448606718863, 0.06657634289669138, 0.03920685599691101, 0.02394969415451799, 0.3038488227341856, 0.2102218602917024, 0.13821850610630854, 0.24716465866991452, 0.1698739289173058, 0.16479620710015297, 0.08964252338877746, 0.15028581715055875, 0.10812127111213547, 0.1265646671610219, 0.30983211738722666, 0.14417877128081663, 0.2266770808824471, 0.19078632390924863, 0.2230199399803366, 0.09817453806421586, 0.1805194376834801, 0.12317452978874956, 0.13930379572723592, 0.15914206978465828, 9.595899990626744, 80.4248080934797, 111.19336305345807, 92.62858935764858, 91.60700961521694, 83.19916820526123, 67.4517639705113, 60.740387780325754, 51.40952335085188, 42.5773207119533, 70.83753081730434, 80.70468153272355, 91.72963837214878, 118.66858945574079, 59.07839952196394, 36.4335115977696, 5.949361605303628, 0.29299478658608025, 0.21096172130533627, 0.1302654514355319, 0.37918643014771597, 0.3426843945469175, 1.1380807310342789, 1.0750691464969089, 0.23889608521546635, 4.818553575447627, 52.99660308020455, 85.67656230926514, 82.407393183027, 78.19878591809953, 87.33708449772426, 99.12958104269845, 99.04881518227714, 92.18224402836391, 87.56706987108502, 91.32655252729143, 92.12946551186698, 85.31915392194475, 85.96444702148438, 88.95391641344342, 84.20078577314104, 85.7570571899414, 89.59110791342599, 90.67353997911725, 86.60468878064836, 82.36730207715715, 85.49499893188477, 81.84289373670305, 84.65853309631348, 82.21372604370117, 81.76524066925049, 80.79861422947475, 77.84938880375454, 75.75456251416887, 82.53897816794259, 82.07669367109025, 83.40919835226876, 79.69906180245536, 82.91522312164307, 75.44297749655587, 75.2159173148019, 78.11669989994594, 83.91654191698346, 76.12157331194196, 87.82199232918876, 72.920058795384, 54.10174880708967, 51.33981554848807, 70.51045826503209, 80.53646564483643, 73.15028735569545, 79.16844872065953, 75.61404909406389, 75.36900697435651, 75.50071007864815, 79.04804338727678, 80.91116115025112, 81.08642945970807, 79.42677579607282, 83.67497389657157, 79.70958832332066, 74.99114309038434, 73.66656630379813, 77.27992834363664, 77.1416244506836, 78.3679050718035, 76.83603572845459, 78.21091052464077, 79.63126128060478, 80.57723767416817, 78.14534732273647, 75.83011722564697, 75.42088917323521, 76.2200014931815, 73.79736614227295, 76.13440663473946, 74.2559403010777, 73.72962120601109, 75.40517234802246, 79.62457016536167, 75.12946087973458, 80.42075034550258, 74.64335795811245, 77.80523300170898, 72.31728867122105, 86.00719233921596, 45.42633921759469, 2.107427716255188, 6.204760883535657, 3.611447593995503, 5.497694390160697, 4.337645300797053, 4.000664183071681, 0.23145608444299015, 0.2424503873501505, 0.19062210486403533, 0.16256242910666124, 0.2789076124983174, 0.24302418370332035, 28.743785619735718, 78.13036700657436, 71.98157950810024, 74.86340740748814, 57.211012090955464, 76.17567198617118, 59.40242181505476, 37.53450925009591, 43.95392560958862, 56.54503073011126, 64.49243586403983, 76.76178727831159, 78.6276078905378, 71.10903862544468, 21.03245074408395, 0.301830561033317, 0.1465950073408229, 0.14351718606693403, 0.24154530305947575, 0.12890555869255746, 0.1070811515673995, 0.04904884020132678, 0.14937009343079158, 0.10074656576450382, 0.14826640194015844, 0.07481942379048892, 0.17716433985957078, 0.11280061823448964, 0.22414827586284705, 0.1352323413427387, 0.1538833962487323, 0.20743422130388872, 0.09659434535673686, 0.07479777852339403, 0.11051362273948533, 0.11101559616093125, 0.11685983863260065], [0.1190222618835313, 0.101081029245896, 0.03795952203550509, 0.16669911784785135, 0.05983603386474507, 0.06405568029731512, 0.06610012666455337, 0.07961314477558647, 0.04445570095309189, 0.09108837973326445, 0.04765630313860519, 0.024119414422394972, 0.013093148275012416, 0.0544995798596314, 0.07110154043350901, 0.06668976002505847, 0.03847578540444374, 0.18179312933768543, 0.06596437216337238, 1.5885966079575675, 44.80860614776611, 82.35205772944859, 69.70737852369035, 71.20520169394356, 62.63217381068638, 57.93881504876273, 45.21408912113735, 38.970243317740305, 47.54169395991734, 57.74221576963152, 54.776276452200754, 79.74166815621513, 45.20109598977225, 30.38650131225586, 26.09987793649946, 7.234737958226885, 0.10312038660049438, 0.05023020359554461, 0.013395981846510299, 0.20138022330190453, 0.0549341374342995, 0.6976348023329462, 1.811952097075326, 0.14644273051193782, 1.1145354573215758, 32.06549528666905, 75.45186424255371, 73.15462303161621, 69.87703268868583, 85.8104054587228, 95.22092056274414, 89.87836033957345, 88.25205108097622, 87.43426200321743, 83.90004689352853, 83.65663760049003, 84.2372499193464, 84.96281555720738, 80.37303011757987, 79.16357108524868, 80.07704380580357, 82.26568467276437, 80.51416192735944, 76.71856948307583, 79.05754852294922, 78.78080872126988, 78.93147345951625, 79.56343991415841, 81.36487851824079, 79.86267103467668, 78.84507955823625, 77.8911474772862, 74.66052000863212, 76.68000003269741, 79.07189655303955, 78.51310157775879, 78.10139301845005, 77.6031585420881, 74.76097706386021, 71.84706238337925, 64.11821283612932, 68.2755354472569, 70.87760107857841, 70.32615729740688, 71.36605249132428, 76.14215387616838, 35.02661255427769, 31.996572630746023, 71.38189438411167, 72.42564582824707, 70.16511195046562, 70.05907549176897, 70.98018428257534, 69.93816988808769, 72.10120664324079, 70.28475298200334, 74.56043120792934, 72.9477265221732, 76.19086074829102, 73.4638317653111, 75.3976057597569, 72.33700765882219, 72.08532306126186, 71.64495318276542, 72.48932606833321, 72.3272454398019, 74.97002751486642, 71.94607421330043, 70.14801243373326, 69.14679091317313, 69.93317413330078, 70.24871962411063, 69.74789346967424, 67.26922784532819, 67.63502270834786, 66.17589405604771, 67.03031403677804, 68.66311291285923, 67.83400521959577, 69.61394609723772, 70.53656264713833, 70.89777864728654, 73.50361715044293, 70.73381505693708, 67.48483044760567, 69.38136209760393, 75.58771542140416, 53.5991404397147, 3.1354666778019498, 1.9575446503502982, 0.4504319557121822, 3.0761420897075107, 2.088563574211938, 0.12427005171775818, 0.026052063663623164, 0.10033449144767863, 0.058054458749081404, 0.03674423528302993, 0.06828208493867091, 0.10525507133986269, 21.138980524880544, 51.62061309814453, 54.11040278843471, 55.118829590933665, 37.45553949901036, 32.18295805794852, 27.571456023624965, 27.61798116139003, 45.65945822851998, 48.03122929164341, 57.356232915605815, 52.80582986559187, 60.39547920227051, 50.63884653363909, 12.210788522447858, 0.43971748064671246, 0.11760400155825274, 0.09528117653514658, 0.06928948552480765, 0.06436902098357677, 0.05421247812254088, 0.021382991257788878, 0.10524561934705291, 0.11621257050761155, 0.014110312980067517, 0.055162288048969846, 0.0978343952447176, 0.006328447181398847, 0.09424914512783289, 0.058590827110622606, 0.03529756469652057, 0.08179722007896219, 0.058919780887663364, 0.04367241369826453, 0.1099408238327929, 0.012015130004978605, 0.0773869731596538, 0.044154234629656584, 0.0380345680085676, 0.09897955879569054, 0.06412147783807345, 0.01920283110147076, 0.12824495056910173, 0.04327677349959101, 0.03521651029586792, 0.06183649080672434, 0.0404950241957392, 0.023070289021623985, 0.03277943642543895, 0.07582654617726803, 0.10706671912755285, 0.09391118040574448, 0.024457189154678156, 0.10393038777900593, 0.03796586973060455, 4.320847162178584, 66.80373328072685, 91.22248240879604, 85.77034214564732, 90.19364874703544, 81.71318476540702, 67.95507758004325, 58.91916070665632, 44.422397477286204, 37.4620395387922, 31.10346508026123, 52.27277796609061, 85.92534950801304, 48.18463509423392, 33.88930361611502, 32.230952739715576, 6.754806774003165, 0.10466591973922082, 0.045950069158737145, 0.026817076274060776, 0.19114300262715134, 0.22788609457867487, 1.1292898484638758, 0.9728765615395137, 0.0824303746755634, 2.4289708052362715, 46.01868009567261, 83.85991409846714, 80.39083140236991, 77.19783537728446, 95.30645983559745, 98.03467001233781, 92.17587947845459, 89.61303642817906, 90.78077152797154, 88.0655961717878, 86.99924223763603, 84.58303397042411, 85.07156876155308, 84.20460728236607, 83.20605387006486, 83.55237988063267, 86.7072650364467, 83.28330394199916, 80.68455954960415, 81.79609067099435, 83.01325525556291, 83.21300206865583, 84.29648331233433, 84.60882568359375, 84.00062206813267, 83.49277128492082, 81.97647285461426, 77.79601274217877, 79.06627546037946, 79.58910655975342, 80.98540265219552, 81.05876868111747, 81.95903287615094, 78.88651166643415, 77.1917973927089, 69.6527795791626, 72.23236778804234, 73.64203221457345, 73.33246912275041, 74.84539767674038, 78.2672256742205, 40.116838523319785, 33.617997305733816, 74.89515372685024, 73.93125792912075, 72.66691507611955, 70.57207489013672, 71.99580247061593, 73.01694447653634, 74.16023581368583, 73.45862756456647, 76.35641547611782, 74.71785654340471, 77.31043788364956, 73.99934332711356, 75.69704532623291, 74.413587978908, 73.47447640555245, 74.46806185586112, 75.43668937683105, 74.77042661394391, 78.54516056605748, 75.11332021440778, 73.82734761919293, 73.48109109061105, 72.6383718763079, 69.19871480124337, 71.85715116773332, 69.79739938463483, 71.79836940765381, 69.04035145895821, 69.86754839760917, 71.36390549795968, 71.47071320669991, 72.2523785999843, 73.26687812805176, 73.03507927485875, 75.85247652871269, 75.52620301927838, 72.33224119458879, 71.22091157095772, 80.51401601518903, 68.69073895045689, 7.081488490104675, 0.684063124869551, 0.658054877604757, 1.5285665605749403, 4.811583663736071, 1.141859682542937, 0.09484502101050955, 0.36532219552568024, 0.24816044952188218, 0.6458522123949868, 0.04756314706589494, 0.1894769413130624, 16.90295566831316, 57.06392567498343, 62.19665377480643, 59.6068308694022, 37.95877667835781, 15.86487569127764, 16.916749579565867, 34.02408824648176, 55.4406110899789, 61.49553189958845, 74.46832588740757, 68.61023712158203, 68.92058535984584, 64.56157044001988, 20.118983234677994, 0.4081966520420143, 0.05070243343444807, 0.08106227165886334, 0.04126878821157983, 0.024843497800507715, 0.05311546680916633, 0.0820615366101265, 0.07691915719104664, 0.09937431689883981, 0.04733377169551594, 0.056183011670197756, 0.04213994575132217, 0.02885814184056861, 0.09035223030618258, 0.06674143046672855, 0.03381048734965069, 0.04067310910405857, 0.08951533199953181, 0.005407992800298546, 0.11930039338767529, 0.02639820982169892, 0.17021433636546135, 0.18611114977725915, 0.1915986660335745, 0.14805612393787929, 0.10224383470735379, 0.1699171108858926, 0.17492864839732647, 0.14205657158579144, 0.155154590894069, 0.10811612781669412, 0.12102237955800124, 0.09188560409737484, 0.09677015378006867, 0.13278996811381408, 0.20530147717467376, 0.1840981670788356, 0.11078636667558125, 0.3063447188053812, 0.17012825741299561, 4.121489448206765, 77.54381397792271, 105.5275934764317, 92.70755563463483, 92.97371332986015, 87.07595729827881, 78.67482089996338, 63.83987494877407, 57.24721220561436, 71.2719669342041, 79.61270264216832, 70.24885858808244, 96.16964844294957, 62.77518163408552, 47.81779105322701, 47.050101961408345, 11.554275819233485, 0.182916701904365, 0.12533898864473614, 0.22231220081448555, 0.27058212352650507, 0.14638679208500044, 1.6061459119830812, 4.71901672227042, 0.19852475795362676, 1.6354245351893562, 47.52246829441616, 92.05984456198556, 86.93254647936139, 82.08792196001325, 97.28943402426583, 103.62743486676897, 95.4032621383667, 92.15836306980678, 93.52432332720075, 92.87339523860386, 88.82600702558244, 87.63805961608887, 88.74708938598633, 87.16914653778076, 85.4874323436192, 86.80094759804862, 89.07523890904018, 84.92524664742606, 82.50594643184117, 84.60678291320801, 87.71878378731864, 85.7436193738665, 86.69905921391079, 88.83744376046317, 89.36477729252407, 87.75495610918317, 84.5356889452253, 81.82986586434501, 80.16200637817383, 82.29615947178432, 80.93097046443394, 83.8148272378104, 84.22869668688092, 81.2144639151437, 79.5464585168021, 73.35150718688965, 77.3725895200457, 77.53815814426967, 76.41440514155796, 79.19855526515416, 78.84326607840401, 48.34315129688808, 42.308348996298655, 74.50691618238176, 80.30218628474644, 74.04830728258405, 73.98115294320243, 75.17421422685895, 75.6930570602417, 76.3918512889317, 76.53269127437046, 77.82731437683105, 76.20025471278599, 76.86524595533098, 73.80036776406425, 74.58805029732841, 77.19525759560722, 74.240035874503, 77.74845927102226, 78.68291555132184, 79.28613036019462, 82.23300729479108, 77.75489330291748, 75.6352619443621, 76.25314440046037, 75.73031330108643, 73.44644042423793, 73.46397767748151, 73.50998170035226, 75.25532054901123, 69.88146563938686, 72.36074965340751, 74.29923452649797, 74.18012155805314, 75.92529364994594, 74.65421799251011, 75.0500499180385, 77.46074826376778, 78.38758931841168, 74.80659893580845, 73.52476746695382, 80.81170463562012, 65.43094989231655, 4.490869581699371, 3.960408926010132, 3.611501008272171, 5.655824099268232, 4.525146348135812, 1.3079750431435448, 0.11899453694266932, 0.29474252994571415, 0.5703257279736655, 0.33264340619955746, 0.16429186559149198, 0.4243255380008902, 31.750377110072545, 68.1961453301566, 67.95453562055314, 75.02443190983364, 53.69392776489258, 44.419552189963206, 45.64272696631295, 41.3525686945234, 58.3134514944894, 61.534733636038645, 71.30998747689384, 69.46315629141671, 78.25795677730015, 76.60156181880406, 23.984241792133876, 0.6958608946629933, 0.16770622666393006, 0.14330164263291018, 0.1420429873147181, 0.09157972729631833, 0.1988474013549941, 0.07627298150743757, 0.2525444914187704, 0.24192248710564204, 0.13978632912039757, 0.10135515739342996, 0.1269073544868401, 0.06370603798755578, 0.1721390009458576, 0.20673081119145664, 0.08758779721600668, 0.09653209655412606, 0.14581893969859394, 0.10321033320256642, 0.2077331838331052, 0.10567513201385736], [0.04183473052190883, 0.13623874448239803, 0.07401948528630392, 0.20377516693302564, 0.03902561929343002, 0.07061879669449159, 0.1611141368214573, 0.048610123206994364, 0.03531708275633199, 0.05730263516306877, 0.06567793539060013, 0.09225258976221085, 0.13049394131771155, 0.03915584712688412, 0.052781295097832165, 0.0695593049749732, 0.11354671498494488, 0.06922559466745172, 0.14986099994608335, 28.267535243715557, 84.18850135803223, 68.42127391270229, 74.5799000603812, 43.65809563228062, 54.832014901297434, 64.84960801260812, 47.51554788861956, 48.30882372174944, 33.77391835621425, 36.556849070957725, 65.01676082611084, 27.031440292085918, 25.825391088213237, 31.450791631426128, 9.392653022493635, 1.2548816863979613, 0.09074043376105172, 0.07730772705482584, 0.1594080962240696, 0.10547930002212524, 0.4959666494812284, 0.5330285036138126, 0.24796698561736516, 0.36339132913521355, 21.689199686050415, 79.09862627301897, 76.65575081961495, 75.08384595598493, 85.30046326773507, 97.51215853009904, 92.2856193270002, 91.24153436933244, 84.86166368212018, 82.93979890005929, 80.99176025390625, 83.87196227482387, 80.02379281180245, 77.01304803575788, 73.41647284371513, 79.2466367994036, 77.7628698348999, 79.59540162767682, 76.81076513017926, 77.73042174748012, 79.6542250769479, 78.9949174608503, 78.38288538796562, 79.58868966783795, 74.75917053222656, 73.65081473759243, 75.46746294839042, 74.18401254926408, 73.06245517730713, 75.19168199811662, 73.04340321677071, 76.51909364972795, 73.94176360539028, 76.50763607025146, 78.6921636036464, 76.91594001225063, 68.81098447527204, 61.85553196498326, 74.26668916429792, 67.78411020551408, 71.47082437787736, 72.3276275907244, 29.253962312425884, 23.49617600440979, 58.72124126979283, 75.30684838976178, 66.54003524780273, 70.8671509878976, 71.21277523040771, 68.79022325788225, 68.42243426186698, 74.72349153246198, 73.17780222211564, 73.13723169054303, 75.3807772227696, 75.65750312805176, 73.57925524030412, 70.77633803231376, 70.76525565556118, 71.66380364554269, 68.58548763820103, 68.96574865068708, 70.05649076189313, 72.36976841517857, 73.08387647356305, 73.97920049939836, 70.20321587153843, 68.78605433872768, 66.19366754804338, 67.65486676352364, 68.6443041392735, 69.88475908551897, 64.62351363045829, 63.50741754259382, 66.54646927969796, 67.67784445626395, 68.15884045192173, 70.66242926461356, 71.54547582353864, 69.3345729282924, 68.3311766215733, 71.77021530696324, 66.38317966461182, 73.23504148210797, 61.21976484571184, 5.318859917776925, 0.8361351447446006, 1.6098656952381134, 5.902956758226667, 0.8651123898369926, 0.01552232654233064, 0.062025836003678184, 0.17869729974440166, 0.25379847841603415, 0.1327977441251278, 0.10112552757241897, 0.4019244371780327, 17.07142516544887, 54.72721522194998, 65.05728272029332, 48.68035432270595, 53.91892780576433, 43.24331944329398, 31.063940252576554, 26.439921038491384, 40.72510119846889, 46.613331249782014, 43.98190253121512, 53.835809980119976, 53.16187293188912, 52.18484851292202, 17.068736212594168, 0.4327220017356532, 0.03788077804659094, 0.06384737683194024, 0.04133470110329134, 0.06144241123859372, 0.09661588205822877, 0.152835005362119, 0.027922118049381033, 0.09718954270439488, 0.01905675438631858, 0.08475497458130121, 0.05038750158356769, 0.1834856942296028, 0.15797341535133974, 0.059923985573862276, 0.07833813676344496, 0.051442694783742936, 0.07221741841307708, 0.14470964350870677, 0.10930063961339848, 0.009327771707570978, 0.08390340634754725, 0.10010750791324036, 0.13665369578770228, 0.03958450483956507, 0.06185426842421293, 0.06451401713171176, 0.04753757308104208, 0.11656027899256774, 0.02684253321162292, 0.04160004222233381, 0.09302641823887825, 0.024751780222037008, 0.047023552270340066, 0.03811473352834582, 0.017314629296639135, 0.07597723523420946, 0.06904295339648213, 0.0937104561765279, 43.57244866234915, 99.63525009155273, 78.93951252528599, 99.05529090336391, 59.39136723109654, 76.31856169019426, 85.99535955701555, 62.27939987182617, 47.07531002589634, 24.50262257031032, 43.932181222098215, 75.13249724251884, 34.05012662070138, 31.93584190096174, 35.396798678806846, 7.361797060285296, 0.573261884706361, 0.05456242238038352, 0.12355777993798256, 0.0580449728295207, 0.41597904158490046, 1.6226631913866316, 0.4295204835278647, 0.20156204354550156, 0.40690689267856733, 35.51602281842913, 88.73549979073661, 83.40700966971261, 81.54519816807338, 94.19014835357666, 96.97582708086286, 93.69984177180699, 93.3196085521153, 89.85582733154297, 84.2620827811105, 84.85642474038261, 87.00357791355678, 80.77086312430245, 78.3250207901001, 80.03540325164795, 83.3804953438895, 82.67161233084542, 82.61093371255058, 81.24425084250313, 83.38870116642543, 83.77929415021623, 82.41252095358712, 83.65379578726632, 80.62523583003453, 77.20690972464425, 77.6624197278704, 78.27248546055385, 77.41242354256767, 76.96527917044503, 78.1330212184361, 77.24087251935686, 78.85188879285539, 78.03601741790771, 80.719724382673, 83.33515139988491, 77.59450803484235, 73.05282497406006, 67.13544722965786, 77.68578651973179, 71.9500207901001, 79.10437938145229, 71.9448652267456, 33.966817719595774, 27.862866946629115, 55.98034020832607, 82.35236345018659, 68.53720460619245, 76.04779733930314, 73.32389504568917, 70.76284463065011, 70.61632101876395, 79.35625852857316, 73.3709829875401, 76.35417120797294, 76.81408636910575, 78.36261054447719, 75.95001534053257, 74.23581831795829, 72.00345243726457, 74.68730531420026, 72.21523353031704, 71.69310419900077, 72.97368499210903, 74.3868304661342, 75.08196994236538, 76.88082381657192, 74.58076858520508, 71.65623705727714, 68.98093741280692, 71.35667937142509, 69.7812865121024, 71.77937303270612, 68.07175173078264, 65.54597731998989, 68.56432342529297, 69.83191108703613, 71.43491608755929, 75.11061041695731, 72.83075359889439, 71.44747148241315, 71.90910284859794, 76.26546355656215, 70.16064425877163, 75.18441418239048, 76.0245556150164, 13.854417034557887, 0.8505562937685421, 1.1316424650805337, 0.743048825434276, 2.438760382788522, 1.659506231546402, 0.021380782626303177, 0.22865997733814375, 0.09466841191585575, 0.35693998102630886, 0.05219224188476801, 0.24308367765375546, 15.278560638427734, 60.078384263174875, 69.86468573978969, 54.43575913565499, 51.76367998123169, 21.9697835786002, 24.318741968699864, 33.676195417131694, 50.37998444693429, 64.57366030556815, 60.11131872449602, 66.67286396026611, 59.52689184461321, 66.10901069641113, 27.721854993275233, 1.2183341618095125, 0.03510221785732678, 0.012297817871772816, 0.029509705092225755, 0.04824560062427606, 0.07665131906313555, 0.054841731142784865, 0.029333923810294697, 0.038588228835059066, 0.09038674738258123, 0.0813381572120956, 0.06450755069298403, 0.08276175082262073, 0.14328234509697982, 0.10818123325173344, 0.01558462284239275, 0.06676289931471859, 0.038037604452776055, 0.05529502985466804, 0.0662870155647397, 0.0978919282289488, 0.20863252771752222, 0.10337871166744403, 0.23868120674576077, 0.10364821899150099, 0.14941951792154992, 0.18642372371894972, 0.1601684218538659, 0.14161798012043747, 0.12602041422256402, 0.14369224810174533, 0.3490308140005384, 0.3466352325464998, 0.19667845059718403, 0.10043078235217504, 0.11078569492591278, 0.2687721720763615, 0.15735225725386823, 0.23753244695918901, 48.96853085926601, 112.18985285077775, 89.85419450487409, 99.45633397783551, 62.8522093636649, 74.65185560498918, 80.5248829977853, 66.71922928946358, 70.96899768284389, 50.720838751111714, 48.70271362577166, 79.70793465205601, 44.62460742677961, 42.59010887145996, 51.27247013364519, 14.943923234939575, 1.5629969473396028, 0.1519539412111044, 0.19767344077782972, 0.23148526144879206, 0.15898143340434345, 1.3242079892328806, 2.567667705672128, 0.29684376290866304, 0.3464866333774158, 35.15927103587559, 92.96079662867955, 85.84728649684361, 86.02181134905133, 97.43597848074776, 101.54328101021903, 96.39165728432792, 96.54380893707275, 92.2310481752668, 87.5596422467913, 85.49176107134137, 89.5673520224435, 86.19185461316789, 83.85851751055036, 80.00933361053467, 86.97438158307756, 85.58562428610665, 86.27706732068742, 83.71429375239781, 85.56004796709333, 86.59669835226876, 87.15927314758301, 86.8694429397583, 85.55435044424874, 82.57103020804269, 81.4494103022984, 81.58281571524483, 79.28279522487095, 78.29414299556187, 81.81442696707589, 79.51111997876848, 84.04811300550188, 80.03279072897774, 84.57146521977016, 83.63607093266079, 82.67055620465959, 76.8558658872332, 70.63549109867641, 82.59165246146065, 76.3489739554269, 79.85862023489815, 79.14001669202531, 38.24593530382429, 33.65494087764195, 63.51354585375105, 83.66792842320034, 73.04266670772007, 76.77603803362165, 77.62931156158447, 74.85953031267438, 74.33292634146554, 79.36570113045829, 76.65921797071184, 78.19975171770368, 78.99634878976005, 82.3970125743321, 78.63429205758231, 76.2846405846732, 74.2302667072841, 76.2933188847133, 73.81406961168561, 73.51860441480363, 77.12746402195522, 76.30528368268693, 78.19084412711007, 79.28031471797398, 76.65358298165458, 74.82584544590541, 70.37378025054932, 73.97508716583252, 74.12864235469273, 77.03808239528111, 69.60386426108224, 68.219817842756, 72.76588521684918, 71.84934139251709, 72.96752193995884, 79.13905089242118, 76.90222426823208, 73.76627295357841, 71.76651886531285, 80.26952280317033, 71.96925340379987, 79.81387383597237, 77.42923818315778, 12.300811988966805, 3.1373442113399506, 4.44583352974483, 10.67104252747127, 2.406861420188631, 0.7155415043234825, 0.13569012177842005, 0.46534061857632225, 1.0857144381318773, 0.30027229179229054, 0.2103918468845742, 1.238704760159765, 28.262374469212123, 70.73669855935233, 75.85483196803501, 67.31804588862828, 75.36092621939522, 60.62941115243094, 51.32419947215489, 39.02883400235857, 55.286395822252544, 62.81297288622175, 60.015072277614046, 71.53536619458879, 68.68149089813232, 76.33476488930839, 34.37994023731777, 1.6689532846212387, 0.13784201416586125, 0.16139305542622293, 0.11170408528830324, 0.1723190298570054, 0.1662237090723855, 0.13017881608435086, 0.08526880200952291, 0.15699024525071892, 0.15037827433219977, 0.13484666203813894, 0.20990007184445858, 0.2383904137781688, 0.2783627760197435, 0.26973186486533707, 0.1930602304637432, 0.10294121264347009, 0.2273073720612696, 0.16910570513989243, 0.17647581680544785], [0.05349292226934007, 0.12279384450188705, 0.044124233203807046, 0.11511658717479024, 0.14294058057878697, 0.04989577064822827, 0.14753783174923488, 0.11016360045011554, 0.12493241046156202, 0.022175067237445285, 0.048518751681383164, 0.07470284468893494, 0.1668682223451989, 0.10537388960697822, 0.08771517859505755, 0.08701096102595329, 0.045688687291528494, 0.05616961060357945, 0.9182164945772716, 61.2932767868042, 81.37850393567766, 68.11831855773926, 53.31686987195696, 48.09513534818377, 34.77732855933053, 34.0580267224993, 32.0851274217878, 34.35431528091431, 27.873237133026123, 26.951296295438492, 20.505862406321935, 24.98658197266715, 36.02543347222464, 11.146892513547625, 1.474134372813361, 0.07173348045242683, 0.05330705117168171, 0.13837074222309248, 0.07862168297703777, 0.3163679838180542, 1.5585118851491382, 0.7450270535690444, 0.10529439244419336, 11.995802572795323, 74.92390537261963, 82.84774221692766, 81.57918875558036, 80.99486609867641, 91.35304600851876, 95.30784252711705, 92.56427683149064, 81.16794572557721, 82.78973865509033, 83.63985770089286, 80.06113937922886, 73.70662266867501, 76.06219400678361, 75.33737182617188, 80.27363613673619, 77.62850557054792, 78.69149657658168, 75.1525080544608, 80.06261934552873, 74.80919756208147, 78.21312699999127, 77.59123543330601, 78.88895048413957, 73.95094912392753, 77.0966557094029, 74.66780866895402, 79.34556525094169, 75.85631888253349, 75.12304769243512, 71.96521650041852, 76.59771251678467, 70.71106665475028, 75.58129528590611, 71.1371510369437, 77.05204827444894, 68.5070355279105, 69.84220136914934, 61.03989682878767, 72.9851564679827, 63.64510999407087, 84.76183196476528, 45.87144429343087, 41.159280232020784, 43.15535524913243, 23.357906852449688, 82.81321661812919, 62.45190279824393, 74.70148658752441, 61.96772452763149, 65.78857367379325, 68.91660404205322, 73.6605144228254, 69.99299812316895, 75.43851675306047, 69.94530568804059, 74.98973260607038, 73.94701644352504, 73.59474277496338, 69.44912093026298, 72.71189076559884, 69.46261433192662, 73.67122854505266, 68.99366651262555, 70.17044816698346, 68.40502902439663, 67.92399133954729, 69.22861289978027, 69.84316716875348, 65.53194195883614, 65.53969614846366, 62.25663757324219, 63.386921882629395, 63.43385001591274, 63.512788500104634, 59.58380453927176, 65.94611712864467, 66.01357024056571, 67.94307109287807, 68.72575787135533, 70.99537304469517, 69.40149797712053, 70.22372695377895, 70.24387672969273, 64.2010075705392, 66.27416242871965, 60.73740005493164, 6.295060975211007, 1.6212155776364463, 7.907565900257655, 2.3539259178297858, 0.5910888452615056, 0.24491344232644352, 0.14224380653883728, 1.8360692943845476, 0.3177937758820397, 0.16535257867404393, 0.02318826420897884, 1.0372727917773383, 18.62301002229963, 47.84634814943586, 49.24032006944929, 30.226612840379985, 37.36006082807268, 37.99376433236258, 32.92397648947579, 26.773021153041295, 31.476367950439453, 46.52367516926357, 49.58362013953072, 55.018904072897776, 54.7039144379752, 55.83848578589303, 30.91574559892927, 0.8915485484259469, 0.0837999636839543, 0.12344526526119028, 0.03623101514364992, 0.035155269117759805, 0.09393083077988454, 0.048787885811179876, 0.05645338751907859, 0.06922152345733983, 0.08922194024281842, 0.055960594676434994, 0.03653601324185729, 0.14929685236087867, 0.09579585891749177, 0.016688153180958967, 0.06730321675006833, 0.060782359513853274, 0.13875986848558697, 0.13432480075529643, 0.08914681963090386, 0.13404367012637003, 0.08127285500190087, 0.0796318519860506, 0.10912224597164563, 0.020643942789839845, 0.21317537395017488, 0.025979472290990607, 0.09367142684225525, 0.09644373772399766, 0.08409143518656492, 0.029399147988962274, 0.15742388341043675, 0.0442161305940577, 0.08121992248509612, 0.03866037407091685, 0.10791514574417047, 0.04757648367168648, 3.182797806603568, 79.50943851470947, 90.6828783580235, 83.93721975599016, 69.13749422345842, 63.31772477286202, 50.76587002617972, 48.29411785943167, 36.67371777125767, 30.870460714612687, 27.351389203752788, 43.31292649677822, 28.557476622717722, 32.28723662240164, 37.61426762172154, 9.248688953263418, 0.918454144682203, 0.021865295645381724, 0.1678029043333871, 0.29159895862851826, 0.2531053413237844, 0.6911724348153386, 1.0660963079759052, 0.8272398763469287, 0.3273121565580368, 20.982991729463848, 87.38845252990723, 85.3984398160662, 86.70164394378662, 88.9247270311628, 93.31328569139752, 96.98226806095668, 92.20479093279157, 85.65264660971505, 85.95227377755302, 85.23159272330147, 83.61067526681083, 78.3095679964338, 80.5859785079956, 79.18285233633858, 83.22126347678048, 80.14371177128383, 82.12551866258893, 80.50260012490409, 83.19367912837437, 79.64699895041329, 81.0937111718314, 81.14924117497036, 82.10768263680595, 77.50980254581997, 82.43684659685407, 80.42038903917584, 83.14249174935478, 79.75662067958287, 78.12462779453823, 75.77881867544991, 78.60777078356061, 74.47988074166435, 78.69734001159668, 73.38317012786865, 80.16247885567802, 74.03202765328544, 74.83933884756905, 67.77942017146519, 75.21572971343994, 68.2670030593872, 88.3461366380964, 44.432517528533936, 47.29329933438982, 51.59625618798392, 21.481924499784196, 81.66095515659877, 64.50639479500907, 75.80834851946149, 65.05703953334263, 70.06271634783063, 71.70948805127824, 73.56333691733224, 70.50664370400565, 77.30211394173759, 71.4264531816755, 76.53277465275356, 73.31475816454206, 74.92184870583671, 72.31502355848039, 74.2220539365496, 74.32467188153947, 75.21805735996791, 73.69967447008405, 73.3850530896868, 70.43477153778076, 72.3701227733067, 71.87329878125871, 71.8623275756836, 67.59872531890869, 69.35874571119035, 67.1865929194859, 66.80023833683559, 65.37177208491734, 67.24315820421491, 63.43466295514788, 68.02216243743896, 70.21435383387974, 71.73693343571254, 70.86860316140312, 73.54610538482666, 73.12122304098946, 73.37970297677177, 74.96672712053571, 70.72306619371686, 70.39632715497697, 74.1011483328683, 15.892319338662283, 0.7024001266275133, 0.8089008661253112, 1.6941832793610436, 1.2663488196475166, 1.5136087174926485, 0.43409025403005735, 0.9924726528780801, 0.3042666103158678, 0.08043347325708185, 0.03371220833754965, 0.588260602738176, 16.111536741256714, 51.499808243342805, 55.561780725206646, 33.72028521129063, 31.616311618259974, 23.80561055455889, 25.982908487319946, 36.86589452198574, 43.66822263172695, 57.89897755214146, 66.28987230573381, 70.69047219412667, 63.447392054966514, 67.99641936165946, 44.545408385140554, 1.712323071701186, 0.081380925274321, 0.04752679115959576, 0.0812753045133182, 0.055938264088971276, 0.12138061890644686, 0.050275621337017844, 0.03679123740377171, 0.060592817541744025, 0.03665566271437066, 0.1174117454460689, 0.030851528447653567, 0.08750412706285715, 0.013522043474949896, 0.020692045833649378, 0.10840219139520611, 0.07094043586403131, 0.08961113435881478, 0.06793094306652035, 0.13492345863154956, 0.23249579008136476, 0.14576263486274652, 0.22906150722077914, 0.23852430230804852, 0.16899050346442632, 0.2510828727058002, 0.10907008019941193, 0.22190009935625962, 0.1993398277887276, 0.17076340690255165, 0.1348956658371857, 0.24004259226577623, 0.22849050643188612, 0.1130842865843858, 0.20780615348901066, 0.19810602042291844, 0.19715368295354502, 3.9779444422040666, 90.74726036616734, 100.5386687687465, 91.9535162789481, 73.17789949689592, 68.73094817570278, 50.384049143110005, 49.09069756099156, 53.255353995731895, 51.56561115809849, 37.787434101104736, 38.3605180467878, 38.59384897777012, 44.88487999779837, 57.28149461746216, 18.54592670713152, 3.3035855080400194, 0.26582849717565943, 0.2710069678723812, 0.42033686488866806, 0.21704524915133203, 0.4158119319805077, 3.9336570586477007, 3.118798600775855, 0.32925985061696594, 18.440559012549265, 92.03633185795375, 90.21015071868896, 90.2181897844587, 91.3576248713902, 96.42793382917131, 99.00607681274414, 98.27867685045514, 86.9153218950544, 86.49351760319301, 89.9762465613229, 85.71094199589321, 81.54890850612095, 82.76672622135708, 82.1129424231393, 86.11172798701695, 83.99509825025285, 85.10708100455147, 84.51423985617501, 87.79463032313755, 81.12112181527274, 84.62080437796456, 86.88987759181431, 84.76871762956891, 82.42208167484829, 85.49315765925816, 83.56171825953892, 87.52378259386334, 84.92512852805001, 81.3498009272984, 77.98742171696254, 81.06869070870536, 76.60822514125279, 79.96155779702323, 77.89188398633684, 84.93361227852958, 76.12798649924142, 77.87975243159703, 70.62396403721401, 76.77521814618791, 72.87678541455949, 89.92162677219936, 53.30667686462402, 48.910127776009695, 47.70997585569109, 30.995834009987966, 87.07866014753068, 68.23399911608014, 79.3361712864467, 67.29183728354317, 73.09631374904087, 75.89116409846714, 74.93021433694022, 71.79353346143449, 81.26627663203648, 74.26995481763566, 77.84213488442558, 79.09011472974504, 77.9015280859811, 72.36393887656075, 76.64594691140312, 76.59377983638218, 78.34767886570522, 76.32858099256242, 76.07539558410645, 75.37533678327287, 74.49311705998012, 74.88322366986955, 75.14859621865409, 70.5085266658238, 74.07150731767926, 69.51687281472343, 69.44582748413086, 69.98332623073033, 69.8026522227696, 67.17165429251534, 71.59689249311174, 72.62788704463414, 73.51306670052665, 74.57409831455776, 77.93416377476284, 76.68796266828264, 75.01390538896833, 77.16775662558419, 70.96116011483329, 70.81540775299072, 78.38785334995815, 13.96145577090127, 3.1322876598153795, 15.60404552732195, 7.655041439192636, 1.23323945913996, 1.739878541656903, 0.2056434452533722, 5.86937654869897, 1.5474578440189362, 0.2490231389445918, 0.11382790668202297, 2.9529878752572194, 31.606851645878383, 61.74709837777274, 62.72684301648821, 44.10287414278303, 53.98517887932913, 53.39356061390468, 47.494175229753765, 41.10534831455776, 41.148288181849885, 61.515980448041645, 69.52493272508893, 74.27534661974225, 72.09548827580043, 79.18820244925362, 52.81989301953997, 2.1844157108238766, 0.22792409253971918, 0.1566091664135456, 0.1589105264948947, 0.12611677976591246, 0.14750961826315948, 0.1089731582573482, 0.11919729677694184, 0.13181032639529022, 0.14874924745942864, 0.1568053580288376, 0.13297984935343266, 0.1603328851716859, 0.144730718806386, 0.11414928122290544, 0.2299635788159711, 0.23427319899201393, 0.18940732362014906, 0.11327667161822319], [0.02155014157428273, 0.012013712714958404, 0.22056493242936476, 0.09596936032176018, 0.11422910408249923, 0.09281881366457258, 0.11962230397122246, 0.10937742263610874, 0.08234468248805829, 0.027417919033073952, 0.04137542677511062, 0.10421393399259873, 0.19974240261529172, 0.08859626310212271, 0.16696644707449845, 0.05913959909230471, 0.0769099969682949, 0.09035351952271801, 4.222236590726035, 76.86048643929618, 73.51027352469308, 76.59796265193394, 47.83350787843977, 46.60509763445173, 47.49924046652657, 39.98042801448277, 43.152343205043245, 36.03354549407959, 29.040654352733068, 16.22281387874058, 23.668013640812465, 36.89334685461861, 17.396364620753697, 1.8888154583317893, 0.043744538578071764, 0.0740818562252181, 0.07293011088456426, 0.09159933695835726, 0.08311535577688899, 2.1170240470341275, 3.5225000126021246, 0.31058917247823303, 3.1375637309891835, 57.80367953436715, 84.0504059110369, 72.18062455313546, 82.55645288739885, 100.0320269720895, 90.65554414476667, 89.00926576341901, 85.15489850725446, 87.56304686410087, 77.683472769601, 76.43500655038017, 73.86820997510637, 74.80267320360456, 79.06911032540458, 80.06373800550188, 76.18486445290702, 77.66353143964494, 74.27420711517334, 73.74682494572231, 77.04813643864223, 75.2215939930507, 72.29802826472691, 73.06103774479458, 76.656327520098, 75.15678814479283, 77.83631924220494, 74.52123641967773, 77.27473109109062, 74.06385040283203, 74.07407815115792, 72.81350816999162, 73.3211088180542, 73.37588841574532, 74.19745036533901, 70.52503558567592, 70.24655178615025, 75.52067920139858, 69.38548237936837, 66.40631021772111, 69.78394767216274, 70.89615971701485, 77.3893346786499, 30.663876874106272, 47.78620801653181, 64.14735358101981, 18.63287820134844, 58.002512659345356, 69.96146719796317, 67.12112004416329, 65.30682032448905, 62.823290961129324, 67.44929736001151, 66.36901923588344, 72.76409952981132, 70.06090981619698, 72.03023079463414, 70.0950949532645, 71.65058122362409, 68.9575845173427, 69.94393689291817, 68.85318783351353, 69.69808878217424, 68.69043322971889, 69.90087890625, 69.40809876578194, 69.77415071214948, 68.71322332109723, 65.80465875353131, 64.12769017900739, 63.773644719805034, 60.4589718409947, 63.8709750856672, 62.86263860974993, 61.16042028154646, 62.1904490334647, 61.618452480861116, 61.16180992126465, 65.97451441628593, 68.68741076333183, 67.90964330945695, 66.39855602809361, 69.5294212613787, 69.97854587009975, 68.482668195452, 70.76649243491036, 69.89949621473039, 60.9577830178397, 61.09179292406355, 11.023125120571681, 0.5726099482604435, 4.697859891823359, 2.7610061083521162, 0.3520882656531674, 0.01591638575441071, 0.178253225716097, 0.536338885979993, 0.05368991794862917, 0.03172660791980369, 0.0283922121993133, 2.403936662844249, 33.22327014378139, 56.58297831671578, 55.754645347595215, 35.4198944909232, 41.79298721040998, 42.074493476322715, 24.58416141782488, 36.60875906263079, 43.943072523389546, 40.54734195981707, 41.940223012651714, 54.541899817330496, 53.112099511282786, 59.90552697862898, 33.45766414914812, 0.5672234115856034, 0.089988352331732, 0.10048598796129227, 0.08259610685386828, 0.06951340208096163, 0.11141003535262176, 0.03825993662966149, 0.12128901667892933, 0.054194133928311725, 0.07995383042309966, 0.05413494531863502, 0.037860201472150426, 0.04249028016680053, 0.0712361889226096, 0.07045652504478182, 0.03734034526028803, 0.22776390399251664, 0.14160188526979514, 0.016766040519412075, 0.009301064569236977, 0.06887120939791203, 0.07666393302913223, 0.0278822999181492, 0.0853261925014002, 0.04366724326142243, 0.09014727201844965, 0.09415973456842558, 0.02059483721054026, 0.0206922358234546, 0.07238727608429533, 0.11700362020305224, 0.09538687872035162, 0.1873228640428611, 0.027408495878002474, 0.1716275212488004, 0.23222057627780096, 6.4003630961690625, 93.07207897731236, 78.13550867353166, 89.95289366585868, 56.01665844236101, 59.420160566057476, 63.67345864432198, 42.61391339983259, 33.91831234523228, 32.50666420800345, 32.82646199635097, 17.774058273860387, 24.480103458677018, 39.437203952244346, 16.354320696422032, 1.1949173212051392, 0.1376878781510251, 0.06125151898179736, 0.03747052898896592, 0.21181991882622242, 0.05137741292959877, 1.153489772762571, 1.3632977945463998, 0.3021605461835861, 6.740586851324354, 76.17452553340367, 85.38050651550293, 80.37338447570801, 87.19268703460693, 101.21760504586356, 92.42697347913469, 91.19193117959159, 87.21915967123849, 90.68220438276018, 79.44576522282192, 79.86967481885637, 75.92735726492745, 80.18344851902553, 83.03267547062465, 81.85155814034599, 78.07134900774274, 80.23368399483817, 77.00052738189697, 78.8030846459525, 79.8535133089338, 80.13723605019706, 78.56234346117292, 78.43537902832031, 77.98675468989781, 80.28762980869838, 79.63135855538505, 79.55782576969692, 79.06881850106376, 78.75536441802979, 76.94207913534981, 77.86876038142613, 75.9697482245309, 78.8071562903268, 78.81632096426827, 76.51428549630302, 73.33859743390764, 78.00477831704276, 70.85367843082973, 71.17032173701695, 71.71131542750767, 74.53749520438058, 76.00116797855922, 34.820084299360005, 48.96213504246303, 64.79764938354492, 25.451407773154124, 53.95958866391863, 77.5173066002982, 69.56059782845634, 70.61468819209507, 64.22715364183698, 71.74331188201904, 69.61994239262172, 76.53934070042202, 72.54739911215646, 74.20878982543945, 71.92286028180803, 74.02857439858573, 71.01951108660016, 74.7582186290196, 72.13853236607143, 72.92932074410575, 70.84923158373151, 74.52655179159981, 73.88050133841378, 74.26476451328823, 71.97378362928117, 70.16190188271659, 69.39442471095494, 66.95628098079136, 65.54388591221401, 65.22412981305803, 66.64491135733468, 64.15345409938267, 62.656596728733604, 65.16240896497453, 63.92695672171456, 67.48201642717633, 71.20406218937465, 71.83249895913261, 68.98077760423932, 72.92795889718192, 73.92966679164341, 71.96086692810059, 74.39918436322893, 76.62309428623745, 66.62236445290702, 74.53122792925153, 20.458347150257655, 0.2220608035900763, 2.6968225581305365, 1.3258744712386812, 2.096036361796515, 0.7775994486042431, 1.088521184665816, 0.9473821009908403, 0.13647553963320597, 0.06397730950266123, 0.07391598833990948, 1.0170292151825768, 32.379953384399414, 62.244193349565776, 61.82450131007603, 35.94871146338326, 28.80739116668701, 22.302862848554337, 15.615249497549874, 37.99889210292271, 61.39408820016043, 55.90353829520089, 56.75453628812517, 71.89078739711216, 64.17151941571916, 70.85597133636475, 46.81136533192226, 1.2998091727495193, 0.062035077650632174, 0.0540656736785812, 0.05244404962286353, 0.03515881107055715, 0.06737944337406329, 0.06863702660692589, 0.06704580770539385, 0.09753700691674437, 0.02376128703222743, 0.07479265558400325, 0.012248937057198157, 0.013198563779172088, 0.04033511724056942, 0.17135484516620636, 0.004564551719730454, 0.14811086814318383, 0.06273039962564196, 0.11779970462833132, 0.09854419037167515, 0.20599841406302793, 0.16586200919534477, 0.10816509768898998, 0.17536794553909982, 0.18102714472583362, 0.15158798013414654, 0.15137221956891672, 0.1835572389619691, 0.18855492078832217, 0.12000254142497267, 0.26636842106069836, 0.13321615595902714, 0.2818446648972375, 0.14639091757791384, 0.44007447149072376, 0.5264476367405483, 9.175830142838613, 107.79251166752407, 90.58394295828683, 101.5925645828247, 70.03203310285295, 63.4394085747855, 67.46139417375836, 62.42751462118966, 66.96445206233433, 56.13739381517683, 44.99912575313023, 28.530840703419276, 42.88100215366909, 57.32187407357352, 26.40822856766837, 3.1351131881986345, 0.17242203147283622, 0.14494873210787773, 0.21296527236700058, 0.1947533788957766, 0.4191875351326806, 4.853363616125924, 8.921681540352957, 0.47987863847187584, 5.731031835079193, 78.6978541782924, 90.70762089320591, 81.49522672380719, 91.96484184265137, 105.39172840118408, 96.21459633963448, 95.99648543766567, 89.43066705976213, 93.22268812997001, 85.03900255475725, 82.82224927629743, 78.24046121324811, 82.89222458430699, 86.04380239759172, 86.55645438602993, 80.76720142364502, 83.35432147979736, 81.85141222817558, 81.55252156938825, 84.35782895769391, 83.50983606066022, 82.9051273890904, 80.71424920218331, 82.74892493656704, 81.27006340026855, 83.7134599685669, 82.9424809047154, 84.119811466762, 81.15341009412492, 80.64891529083252, 80.30855083465576, 79.55064133235386, 80.19619151524135, 82.1299307686942, 78.93426663534981, 79.39247253962925, 82.84654712677002, 75.33045142037528, 73.66304356711251, 77.99516201019287, 77.41435514177594, 82.8889102935791, 38.04103292737688, 49.888531412397114, 64.48572390420097, 25.609863179070608, 63.61139733450753, 77.66342721666608, 75.20977510724748, 74.3009785243443, 69.66096455710274, 72.50288200378418, 72.11207362583706, 76.8679210117885, 75.35492297581264, 77.02383163997105, 76.04485130310059, 75.91420432499477, 75.10751152038574, 75.01803956712995, 72.25733266557965, 74.00178909301758, 75.38120106288365, 77.64987128121513, 75.72746453966413, 76.43767465863908, 75.62652805873326, 72.7580337524414, 70.66752924237932, 70.9209508895874, 66.8187483378819, 68.1478692463466, 70.49151747567313, 66.90202249799455, 66.69942692347935, 66.24003982543945, 67.51952975136894, 71.63145978110177, 73.3267924445016, 73.86499295915876, 71.74167210715157, 74.48573112487793, 77.68068654196603, 74.66345909663609, 77.95737770625523, 79.62723132542202, 67.58289732251848, 81.78610610961914, 19.03152241025652, 1.499751621059009, 9.745595455169678, 5.2329089641571045, 0.8162882125803402, 0.33285535339798245, 0.6689053039465631, 1.5954246244260242, 0.35898473273430553, 0.224705665239266, 0.1406607571989298, 6.063838388238635, 48.19692645754133, 67.93693583352226, 72.39320468902588, 49.38877528054373, 59.50396278926304, 58.29531669616699, 36.226337160382954, 51.455791405269075, 61.633029801504954, 54.967459610530305, 57.976734842572895, 73.31798212868827, 69.68076692308698, 81.14232771737235, 52.99375431878226, 1.3479677885770798, 0.12614841306848185, 0.13460401791547025, 0.16477989511830465, 0.1206007921802146, 0.1726483636136566, 0.13975426155541623, 0.14292567994977745, 0.19095518413398946, 0.1546367329678365, 0.134434669145516, 0.18142479338816234, 0.09401245854262795, 0.08585356348859412, 0.22363860106893949, 0.07013658221278872, 0.23283467761107854, 0.14931747982544558], [0.12224318619285311, 0.044709815710250816, 0.07347918820700475, 0.06833326683512755, 0.04019424319267273, 0.03785567903625114, 0.1177587482546057, 0.05009553135771837, 0.08879399499190704, 0.07568552624434233, 0.15615943340318544, 0.1281937211751938, 0.05032385499881847, 0.0784651313775352, 0.3128950244614056, 0.09435267600097827, 0.3128129760069506, 0.24220163641231401, 4.825967303344181, 72.36740602765764, 62.62057031903948, 57.91290174211775, 53.598518575940815, 44.06716040202549, 40.84467969621931, 35.72747734614781, 45.046234539576936, 32.80282769884382, 35.0546554837908, 39.8426730292184, 32.67968130111694, 20.50928439412798, 5.612680997167315, 0.02338699184890304, 0.04515014422525253, 0.15250654013029166, 0.022535330316584026, 0.2782509263072695, 0.2541013764483588, 2.8760962869439806, 0.17087756363408907, 0.34024655393191744, 50.06213910239083, 82.39629690987724, 70.33160468510219, 87.55841241564069, 90.6429887499128, 91.28894192831856, 86.15556417192731, 91.08738163539341, 86.53579044342041, 77.59359087262834, 73.09916251046317, 79.53003992353166, 77.2897947856358, 80.22833388192313, 78.09928076607841, 77.83773667471749, 76.0678220476423, 75.54565102713448, 70.26700033460344, 73.14958558763776, 69.9639754976545, 72.91809245518276, 75.61787755148751, 77.9370333807809, 74.67331164223808, 77.25296238490513, 74.60733154841832, 76.76745006016323, 72.73163754599435, 76.88433960505894, 73.17087486812046, 71.75133010319301, 68.45420837402344, 75.46193218231201, 74.98401423863002, 76.41843509674072, 69.01303809029716, 65.76827103751046, 61.09596879141671, 67.02030863080705, 62.93881171090262, 75.19330092838833, 64.23768711090088, 45.76685653414045, 55.59190811429705, 60.91469723837716, 42.22241367612566, 30.608336448669434, 79.06907558441162, 61.839585849217, 67.29608958108085, 58.083657196589876, 68.38496262686593, 64.57507078988212, 71.04201630183628, 67.43744373321533, 69.9847992488316, 69.98744651249477, 73.89871951511928, 71.54602473122733, 72.18291051047188, 70.64669854300362, 72.70657539367676, 68.07676138196672, 71.90845666612897, 71.13594205038888, 69.14267063140869, 67.03076566968645, 69.86449813842773, 70.04832662854875, 67.45817715781075, 65.12789031437465, 64.2550298145839, 62.06356797899519, 64.97385569981166, 60.03236634390694, 62.89113317217146, 61.26024505070278, 59.534680775233674, 63.79559407915388, 68.51482445853097, 69.25685037885393, 67.10595212663922, 68.58816964285714, 67.17487130846295, 69.07607909611293, 65.29106181008476, 72.14964948381696, 56.783934116363525, 49.65748643875122, 7.138961383274623, 0.842942262334483, 3.6292595182146346, 2.6436436516898016, 1.0352218789713723, 0.21199495371963295, 0.06280078406312636, 0.09505964842225824, 0.039868637985949, 0.0878535658121109, 0.04656013320865376, 7.495674082211085, 33.61002424785069, 49.458896500723704, 49.60388456072126, 39.31678124836513, 44.528354031699045, 45.96551595415388, 32.463911942073274, 26.522361414773123, 37.996588775089805, 41.27663878032139, 36.05283369336809, 53.01497064317976, 54.14863872528076, 57.08606958389282, 14.970757177897863, 0.12668835052422114, 0.12931533956101962, 0.04048300734055894, 0.24091296270489693, 0.030621705244162252, 0.0063664506555401856, 0.0774918475321361, 0.043942206007029326, 0.05447379552892276, 0.11862198050533022, 0.06872197240591049, 0.055622216047985215, 0.09629578994853155, 0.07370238551603896, 0.06128951015749148, 0.17205142921635083, 0.09708377945103816, 0.10429239299680505, 0.08857697913689272, 0.10029625599937779, 0.06413666345179081, 0.06317232269793749, 0.04865157491128359, 0.1009551202878356, 0.041688373911061456, 0.07391136751643249, 0.07758999762258359, 0.07501310482621193, 0.10394651655639921, 0.09277401678264141, 0.06836814353508608, 0.22520094152007783, 0.10681675361203295, 0.2461095909987177, 0.12986208950834616, 9.046763011387416, 85.62135192326137, 72.38654136657715, 70.31346988677979, 56.19224984305245, 52.44592707497733, 41.37675884791783, 31.750547340938024, 26.9612808568137, 24.224996873310634, 30.319670064108713, 29.605648858206614, 34.58756978171212, 22.821710893086024, 3.788255146571568, 0.061410560804818354, 0.06100653391331434, 0.09851060288825206, 0.20404831799013273, 0.7297073070492063, 1.5874016263655253, 1.014823162129947, 0.27183442775692257, 2.028072774410248, 69.99235194069999, 88.15969562530518, 77.38788945334298, 92.87280464172363, 93.88968740190778, 92.15219306945801, 89.9689301082066, 92.14662061418805, 88.92748546600342, 79.07390458243233, 77.01789093017578, 84.59773635864258, 79.94695268358502, 83.43964535849435, 82.18373761858258, 81.68877574375698, 79.60798481532505, 78.45773833138603, 75.29892744336809, 78.38802705492292, 75.49377577645438, 77.43490791320801, 78.07346820831299, 80.0371403012957, 78.43312781197685, 79.26686300550188, 79.09279673440116, 81.5549395424979, 77.63618332999093, 79.34252193995884, 73.62183380126953, 75.69030557359967, 72.79126003810337, 76.61980778830392, 77.02633299146379, 80.72909750257219, 73.84963049207414, 70.2400621686663, 65.33889320918492, 70.42418943132672, 68.84821292332241, 78.68276269095284, 68.70682403019497, 52.405193260737825, 59.280341965811594, 58.635917391095845, 47.15336956296648, 29.015852757862636, 77.87123394012451, 66.31100177764893, 69.67814745221818, 60.54978479657854, 71.23211901528495, 67.23905181884766, 70.33644757952008, 69.6042811529977, 73.48876885005406, 71.70718124934605, 75.52966322217668, 73.50538199288505, 74.04059478214809, 71.69094330923897, 75.82509367806571, 71.9315663746425, 75.81261471339634, 71.51494543892997, 72.32040841238839, 72.22105612073625, 72.29923030308315, 71.13902010236467, 70.16545936039516, 68.3327886036464, 67.61604022979736, 64.55346189226422, 68.23490238189697, 64.28157193320138, 66.85543482644218, 65.03764711107526, 63.77281788417271, 64.9078756059919, 69.76673698425293, 71.83146367754254, 70.48495142800468, 70.399384362357, 70.56846182686942, 73.10164301736015, 69.6164960861206, 75.2651036126273, 65.96485642024449, 59.519776889256065, 16.00850190435137, 1.079203216092927, 0.8742955742137772, 2.7463543117046356, 3.9850963098662238, 0.9978227657931191, 0.22527547180652618, 0.15939109213650227, 0.15821201540529728, 0.08262727875262499, 0.10530941520950624, 5.569798452513559, 33.39126368931362, 54.25474466596331, 54.12714794703892, 41.678981167929514, 37.0934271812439, 24.278322560446604, 23.425978354045323, 37.18631417410714, 49.58097287586757, 55.18508761269705, 53.403458322797505, 67.78222029549735, 62.162788254874094, 66.52503408704484, 24.546668938228063, 0.10420539802206413, 0.09361810756048985, 0.011133607842826417, 0.13748879597655364, 0.04617503744417003, 0.030130211796079363, 0.02563213530395712, 0.06607334488736731, 0.09791252855211496, 0.024699960502662828, 0.061974504829517434, 0.06490643428904669, 0.06815914796399218, 0.08585494091468197, 0.010579202324151993, 0.07481922022998333, 0.03642698284238577, 0.1875348383826869, 0.13254257424601487, 0.1059976125668202, 0.2575591637619904, 0.09428846623216357, 0.13699064270726272, 0.1575054433196783, 0.15975964521723135, 0.2119464384657996, 0.20523475004093988, 0.20527664279299124, 0.16167706304362842, 0.21090465651026793, 0.11173974230353322, 0.394913623375552, 0.3065793833562306, 0.4488756406520094, 0.40835947330508915, 14.836026396070208, 103.11000946589878, 80.10896383013043, 83.96676349639893, 70.81560230255127, 65.12959957122803, 60.719147137233186, 56.97549942561558, 67.71215466090611, 50.81282942635672, 53.74442032405308, 65.29457759857178, 48.681340966905864, 34.761007240840364, 8.185495580945696, 0.30422025280339376, 0.17064333334565163, 0.293532593441861, 0.21865906326898507, 0.5776279589959553, 2.3041561884539465, 7.566419771739414, 1.1592914100204195, 1.1838145341191972, 63.35345935821533, 92.19350011008126, 79.79635047912598, 94.34631606510708, 95.40595803941999, 98.02057211739677, 92.3588672365461, 95.37061255318778, 92.35422583988735, 83.82148361206055, 78.79390607561383, 87.26646995544434, 83.6719583783831, 89.91160052163261, 85.80552087511334, 85.06580175672258, 84.63875157492501, 83.30783803122384, 77.68826702662876, 82.74627767290387, 78.7682602746146, 82.3399817602975, 81.5501800264631, 84.32088538578579, 83.38940293448312, 84.74453095027378, 83.12385668073381, 84.3184118270874, 78.60257353101457, 84.6077139718192, 77.31392587934221, 76.07401289258684, 74.30127729688371, 79.76112311226981, 77.15472180502755, 82.44856820787702, 74.92376640864781, 74.85379804883684, 70.26490892682756, 74.40503474644252, 70.24841390337262, 81.73951843806675, 73.83695697784424, 49.202525343213765, 56.64823579788208, 60.61333996909005, 45.52630295072283, 37.016548837934224, 84.35677977970668, 69.3569391795567, 70.63182939801897, 62.54514067513602, 74.71214512416294, 69.57791273934501, 73.27841908591134, 73.5509135382516, 73.82158061436245, 74.49111597878593, 77.0691477911813, 75.24004146030971, 75.63707542419434, 74.35064424787248, 77.63232013157436, 74.24142551422119, 78.33272634233747, 75.36535917009626, 75.67870903015137, 75.18468516213554, 75.36953503744942, 76.00514929635185, 73.01587445395333, 71.6252133505685, 70.83776010785783, 67.51184504372733, 71.47884259905133, 66.9654039655413, 69.1740209034511, 68.61689349583217, 64.91620649610246, 70.30789743150983, 73.26961571829659, 73.69719396318708, 72.4963298525129, 73.77514580317906, 72.5140130179269, 75.84759194510323, 71.19229194096157, 78.41361727033342, 66.53232969556535, 64.85213715689522, 14.092503138950892, 2.9604945353099277, 13.263775859560285, 5.752397980008807, 3.3402654826641083, 0.3961496970483235, 0.13298145069607667, 0.4967734547598021, 0.301281137658017, 0.28684451803565025, 0.20330505073070526, 13.89435180595943, 50.555106844220845, 61.91209030151367, 65.67932019914899, 57.86819008418492, 61.4876526423863, 64.59158665793282, 53.74420492989676, 38.16274104799543, 53.35708604540144, 56.923123904636924, 55.051796845027376, 72.85234860011509, 71.6162918635777, 79.24826962607247, 28.77249036516462, 0.2084803730249405, 0.23848945274949074, 0.12397404760122299, 0.4326083878321307, 0.13472862408629485, 0.09549054530050073, 0.12206770346633025, 0.1653354253087725, 0.13590182470423834, 0.12353867239185742, 0.07964916141437632, 0.09261570777744055, 0.19017307753009455, 0.11102014234555618, 0.11969515149082456, 0.1672512282218252, 0.1644406954624823], [0.06768614120249238, 0.1237537001392671, 0.09198124360825334, 0.016514146268101673, 0.032147241955889125, 0.09963870128350598, 0.13042361794837884, 0.11212146574897425, 0.08528714281107698, 0.0520292849146894, 0.1888682275478329, 0.0550437310178365, 0.11112524741994483, 0.05820819442825658, 0.13525245312069142, 0.0546451222284564, 0.3333014223192419, 0.09903066605329514, 4.627441201891218, 67.61123207637242, 60.68066801343645, 59.10783209119524, 58.42548424857003, 55.60135766438076, 46.41382414954049, 35.64610699244908, 44.41350030899048, 49.96896723338536, 29.354412419455393, 36.695177282605854, 27.372850452150615, 12.64075173650469, 0.31202193988221033, 0.006647989253646561, 0.15933005112622464, 0.0422858206023063, 0.09770002495497465, 0.17822972126305103, 0.5253396161964962, 0.709185748228005, 0.20406994968652725, 29.980674403054373, 108.27202074868339, 76.43422140393938, 91.3022824696132, 89.64319161006382, 90.20046492985317, 88.3135495867048, 87.48656804221017, 82.21062019893101, 77.09461293901715, 72.04158415113176, 81.18282181876046, 76.17499106270927, 74.79521778651646, 79.63505499703544, 76.64780902862549, 75.59992340632847, 73.51069041660854, 71.16171291896275, 69.02140372140067, 69.2266674041748, 70.2319119317191, 76.09466988699776, 74.72082342420305, 70.61612646920341, 77.70816666739327, 77.56437369755336, 77.95561981201172, 75.15686457497733, 77.79761777605329, 75.11867032732282, 75.30278369358608, 73.07371125902448, 73.8212332044329, 76.1411463873727, 73.55873720986503, 74.78228024074009, 75.52987166813442, 70.97916984558105, 60.5585812159947, 62.98949187142508, 73.31789180210659, 72.94962338038853, 66.19784341539655, 65.20660645621163, 63.44783673967634, 50.69666944231306, 58.46664537702288, 29.215792383466447, 55.81978818348476, 64.78771345955985, 64.41130869729179, 60.44328280857631, 63.619339125497, 68.30486379350934, 65.50324589865548, 67.1470229285104, 69.30400085449219, 68.57176494598389, 68.11300318581718, 68.77971063341413, 70.50692858014787, 71.18510055541992, 69.190856388637, 67.90914303915841, 67.93272522517613, 69.2972194126674, 68.86607674189976, 71.19246564592633, 67.52479648590088, 65.67542920793805, 63.343634605407715, 63.85912145887102, 62.61838858468192, 61.08636638096401, 62.20454692840576, 62.01805033002581, 60.267576762608115, 60.840073585510254, 63.6044282913208, 61.573476791381836, 63.227113315037315, 66.0818988255092, 70.45813832964215, 65.17642348153251, 66.49660205841064, 66.28353554861886, 69.7641522543771, 67.17208508082798, 68.55295617239815, 62.84966632298061, 58.41574287414551, 4.314533855233874, 0.789500464286123, 8.912932889802114, 2.3186106128352026, 1.4604599922895432, 0.5456932240298816, 0.035372413894427676, 0.11572295320885521, 0.0885157956342612, 0.1634474423314844, 0.06461092550307512, 8.686492834772382, 27.995608806610107, 36.88643339702061, 33.87128346306937, 39.02509239741734, 41.59977517809187, 35.00760228293282, 35.60432400022234, 23.884307588849747, 31.813393797193253, 37.36462926864624, 43.695094789777485, 49.577748911721365, 55.59575741631644, 49.63109023230416, 10.265386717660085, 0.1839739137462207, 0.14002175363046782, 0.05328597587400249, 0.030658061150461435, 0.021844276326841543, 0.09160495522831168, 0.05998804606497288, 0.07746228376137358, 0.0756711820140481, 0.0267906320680465, 0.07740768204842295, 0.06742428775344576, 0.023608346935361624, 0.06883771012404136, 0.021582824909793477, 0.04365724504792264, 0.06333374617887394, 0.06447458746177809, 0.0771360576951078, 0.018845061638525555, 0.05464024016899722, 0.07882352678903512, 0.0995121816439288, 0.12854882569185325, 0.11162293250007288, 0.10259391806487526, 0.10415681491472892, 0.08231238422117063, 0.061895597992198806, 0.07017507550439664, 0.1387337041752679, 0.040133137721568346, 0.2304695216672761, 0.23888929986527987, 8.380924088614327, 81.28668349129813, 66.57737486703056, 72.63334138052804, 64.46687344142369, 61.89444882529122, 45.404299531664165, 19.76106415476118, 40.48096581867763, 53.145826067243306, 28.352527345929825, 38.15969426291329, 28.809604167938232, 11.447639209883553, 0.08705105566020523, 0.02220771834254265, 0.09722486045211554, 0.09816849910254989, 0.4638142947639738, 3.1502837112971713, 0.746749284011977, 0.7101847689066614, 0.1924720084560769, 44.07772166388375, 107.16299097878593, 82.0039529800415, 97.06240163530622, 92.16563783373151, 93.0469056538173, 91.46175752367292, 91.65079021453857, 83.83454622541154, 79.31321443830217, 78.36117921556745, 84.25051403045654, 80.12620231083461, 79.87436485290527, 80.23309339795793, 79.24521241869245, 78.16692147936139, 77.42818205697196, 74.37122481209892, 71.65213762010846, 72.53534398760114, 76.8335621697562, 78.83726283482143, 77.56861904689244, 76.66729177747453, 80.05025850023542, 79.96781812395368, 78.74285766056606, 78.2028923034668, 79.57402202061245, 79.08372238704136, 80.1546551840646, 78.57043811253139, 78.250077520098, 79.1065263748169, 78.26477990831647, 77.20174721309117, 77.70036384037563, 75.04088524409703, 66.0380140032087, 66.51696028028215, 77.22845608847481, 74.73581068856376, 71.52335275922502, 69.371169090271, 63.189467975071494, 52.76450892857143, 60.38493878500802, 36.91889190673828, 57.508659022195, 68.03463445390973, 65.65778773171562, 63.71155561719622, 63.425602504185264, 70.18872192927769, 67.9426611491612, 71.26474775586809, 71.34267180306571, 70.95717879704067, 70.82170282091413, 73.02917330605644, 71.54713644300188, 72.59962177276611, 72.43360151563371, 69.56420394352504, 70.07644598824638, 73.07772731781006, 71.73959459577287, 71.94873537336076, 70.68832520076207, 69.17252009255546, 66.23283454350063, 68.33128779275077, 64.4878431047712, 65.25384725843156, 64.08438205718994, 64.6121324811663, 63.04697431836809, 64.64089107513428, 66.42955889020647, 66.55562005724225, 65.59938117436, 69.18425559997559, 72.70015525817871, 71.19108990260533, 68.37792410169328, 70.12405504499162, 73.43077918461391, 69.59029442923409, 73.8594969340733, 68.32517337799072, 69.75633553096226, 10.08248668057578, 1.1115619540214539, 1.558960912483079, 6.30572863136019, 4.370309216635568, 1.2306849105017525, 0.2618977709540299, 0.07814586708056075, 0.08893869258463383, 0.09702362732163497, 0.06952457755271878, 7.345296825681414, 32.69307395390102, 38.753674915858674, 37.793409551892964, 39.72427225112915, 39.77206890923636, 17.958689280918666, 30.352284908294678, 27.738330909184047, 42.56024203981672, 52.90531069891793, 57.62280055454799, 66.85926328386579, 65.30187320709229, 64.50986194610596, 17.863420792988368, 0.23791451645748957, 0.1293147967330047, 0.09497436335576431, 0.030785181293530122, 0.019345957885629365, 0.058531468867191246, 0.020413732821387903, 0.05586020881310105, 0.038937043332095654, 0.06480998732149601, 0.05832616452659879, 0.07955208340925829, 0.03160686005971261, 0.026291013163115298, 0.0542280810352947, 0.05369500356859394, 0.09184369777462312, 0.20317479914852551, 0.1365410318332059, 0.09828018596661942, 0.07853875921240874, 0.1594454020793949, 0.12869150803557464, 0.21739877946674824, 0.17404117887573584, 0.17374687109674725, 0.19173453588570866, 0.12022419167416436, 0.1511808998350586, 0.11743565702012607, 0.35799002753836767, 0.12937814476234571, 0.45431206322142054, 0.4507245400122234, 15.253581864493233, 98.85036073412213, 80.47719751085553, 92.53038351876395, 75.51640605926514, 83.22886480603898, 69.87310695648193, 53.399178232465474, 60.207989011492046, 76.67483752114433, 46.11019481931414, 57.037338393075125, 42.1154739516122, 20.66062831878662, 0.5465576776436397, 0.1784474224384342, 0.20023142280323164, 0.12640169662024292, 0.3786503332001822, 2.181612546954836, 2.3725918190819875, 1.343397285257067, 0.39277099977646557, 39.49738230024065, 115.51630292619977, 84.86721529279436, 98.98231397356305, 93.42898709433419, 96.60705144064767, 97.23662076677594, 93.4407434463501, 88.39503111158098, 83.56749221256801, 80.67098276955741, 86.62713841029576, 83.34716483524868, 82.41614096505302, 84.09464509146554, 81.56666115352085, 82.35032067980084, 79.83241162981305, 79.41071156093052, 76.05776800428117, 77.16861125401088, 78.20700563703264, 83.97581699916294, 82.09537042890275, 77.46614701407296, 82.73976026262555, 82.65778541564941, 83.02868720463344, 80.61578627995083, 83.22115925380162, 81.90237726484025, 82.21352454594204, 80.86861733027867, 81.78766250610352, 84.62361145019531, 82.89534432547433, 81.3677898134504, 81.33532782963344, 75.95765141078404, 67.25456714630127, 70.12260287148612, 80.46241869245256, 77.70661721910749, 75.65534918648856, 70.11849648611886, 63.795948437282014, 53.78500475202288, 58.06699194226946, 39.254594870976035, 61.24536200932094, 69.22740391322544, 69.38348129817417, 66.04514980316162, 67.03620610918317, 74.3724615914481, 71.45867892674038, 71.75878552028111, 72.86242348807198, 73.1207366670881, 74.66459165300641, 75.57028239113944, 74.439101764134, 74.93623147691999, 76.46280629294259, 73.89587075369698, 71.86479418618339, 74.49507645198277, 74.04756382533482, 75.25562626974923, 75.59883948734829, 71.84000996180943, 68.14884199414934, 70.2862468447004, 66.5594207218715, 68.54821750095913, 69.54577037266323, 67.33956445966447, 65.4352925164359, 67.553603717259, 69.6609228679112, 67.51488140651158, 68.00748089381626, 73.42804159436906, 74.21184008462089, 71.48242786952427, 72.8492705481393, 72.59458432878766, 76.22057819366455, 72.63755198887416, 77.47183064052037, 69.84767654963902, 72.31029183523995, 7.449778624943324, 2.875751265457698, 18.417207854134695, 8.392311317580086, 5.242854007652827, 0.9324464052915573, 0.31570084818771904, 0.32508023775049616, 0.44074668256299837, 0.2370472401380539, 0.2670658193528652, 16.739745957510813, 43.47327702386038, 47.44060461861746, 49.41657502310616, 55.65413965497698, 55.33898673738752, 51.03826720373971, 53.62766626902989, 35.40370866230556, 46.23272630146572, 52.52897889273507, 60.593898909432546, 69.17666816711426, 73.66949844360352, 73.88123784746442, 19.591323137283325, 0.36808006039687563, 0.2371707335114479, 0.12316276399152619, 0.0650630673127515, 0.13050262656595024, 0.10392204179827656, 0.11360251091952835, 0.15524232547198022, 0.12355461796479565, 0.22204833211643354, 0.16019480329539093, 0.20955688240272657, 0.1385790253324168, 0.10940387193113565, 0.10641846034143652, 0.19587976059743337], [0.18315671331116132, 0.10289994414363589, 0.10305596648582391, 0.09230515587010554, 0.16011749101536615, 0.04437075854678239, 0.05510195271511163, 0.06272260325827769, 0.09380100667476654, 0.05091427206727011, 0.0765293048960822, 0.049824578754071674, 0.2388203064245837, 0.06003010166542871, 0.28503187958683285, 0.05906911287456751, 0.30160610164914814, 0.21983573798622402, 6.893360367843083, 66.38570880889893, 57.851097515651155, 52.22135782241821, 43.76812730516706, 40.10702766690935, 34.68359736033848, 44.694144998277935, 34.99238920211792, 38.17714466367449, 31.502760682787212, 36.66440371104649, 16.03778508731297, 1.3523130182709013, 0.019992486407448138, 0.05781621153333357, 0.0537402584616627, 0.10572328085878066, 0.21561411023139954, 1.879331384386335, 0.308595528027841, 0.08774101720856768, 5.267383319990976, 85.12285341535295, 70.59155763898576, 87.62432997567313, 91.54514285496303, 91.00152274540493, 83.16657420567104, 88.33920233590263, 83.18602916172573, 81.35114192962646, 75.64683764321464, 81.23439829690116, 80.19217545645577, 76.94273921421596, 75.65710708073208, 75.87030560629708, 74.6483815056937, 73.2082005909511, 68.29064777919224, 67.92965412139893, 68.0464950289045, 71.6867743900844, 72.22077124459403, 73.5092521395002, 72.71717834472656, 76.11059515816825, 75.13770144326347, 72.49513476235526, 73.8389024734497, 74.80918366568429, 74.14604759216309, 75.47464043753487, 76.97255393436977, 73.8236859185355, 76.16019139971051, 74.86187185559953, 71.14001369476318, 70.20541150229317, 69.62345818110875, 67.86481353214809, 62.651531491960796, 59.97817734309605, 73.44225760868618, 66.87029702322823, 70.35390840257917, 70.29651628221784, 62.04029846191406, 53.26242726189749, 63.27672345297677, 61.294395446777344, 60.30231775556292, 65.99205861772809, 61.60422257014683, 61.73254884992327, 58.10446357727051, 62.117492948259624, 65.83101327078683, 71.16687543051583, 68.9920267377581, 71.98411560058594, 68.40814181736538, 70.48993328639439, 68.0332726069859, 66.60190895625523, 67.28272819519043, 69.47286292484829, 68.02237783159528, 69.02293232509068, 67.44373880113874, 66.96229117257255, 66.22041116441999, 65.85343510763985, 63.12695503234863, 63.2646335874285, 59.94182436806815, 60.780319077628, 60.04267747061593, 58.94949654170445, 60.81907612936837, 62.13171591077532, 59.358349391392295, 64.59401852743966, 64.78857503618512, 64.11402307237897, 62.71057728358677, 67.99164594922746, 68.0850019454956, 64.71437522343227, 63.20519174848284, 68.699875831604, 64.76497895377022, 63.71700300489153, 63.767419133867534, 47.066291264125276, 1.5694446585008075, 3.6727582812309265, 6.882854691573551, 4.945133686065674, 2.3612760262829915, 0.19430531508156232, 0.32617441618016785, 0.16749402162219795, 0.07284417442445244, 0.11209165092025485, 0.12153805260147367, 17.776484932218278, 25.661957298006328, 27.785387584141322, 29.89063617161342, 34.87923083986555, 39.63182994297573, 40.311016355242046, 37.481734207698274, 32.38319819314139, 28.581852640424454, 36.26933261326381, 37.77891560963222, 47.00098861966814, 53.394126892089844, 44.740444319588796, 2.2633492009980336, 0.14227058153067315, 0.1232160289904901, 0.036613359448633025, 0.12487297079392842, 0.05303606464128409, 0.09613699918346745, 0.18140613367514952, 0.09191415006560938, 0.019474577591089264, 0.04840279004669615, 0.07890047266014985, 0.0575986664210047, 0.05141092577416982, 0.0968917268993599, 0.08407329116016626, 0.1655987783202103, 0.07980237462158714, 0.042723238202078004, 0.08485667340989624, 0.06532952801457473, 0.08585699009043829, 0.12414467201701232, 0.04685489221342972, 0.055029983898358684, 0.1109702360949346, 0.1840252788471324, 0.0533500804698893, 0.1940848726247038, 0.050065516361168454, 0.2045833021402359, 0.06465597344296319, 0.3487111697239535, 0.24312102422118187, 12.708182266780309, 82.46145711626325, 67.39183575766427, 62.426458495003835, 46.791809626988, 46.16670799255371, 30.40292337962559, 36.9280218396868, 39.785176685878206, 49.61285121100289, 34.33914041519165, 39.02650982992989, 15.341486998966761, 0.5272790864109993, 0.02268016870532717, 0.004374646731386227, 0.04338046382846577, 0.32192670553922653, 1.1791700976235526, 3.1574373160089766, 1.1969848445483615, 0.4876854824168341, 12.849142108644758, 95.12129034314836, 76.42309733799526, 94.8379636492048, 91.15450123378209, 93.70880494798932, 88.4030910219465, 90.53556265149797, 83.86652878352574, 84.29547582353864, 79.36665998186383, 84.9311387198312, 82.12543528420585, 80.94999463217599, 79.80320835113525, 78.80381420680455, 77.08338465009416, 76.85918712615967, 71.97615991319928, 70.45201001848493, 71.51561246599469, 76.47650119236538, 75.45554678780692, 76.34287343706403, 77.17646966661725, 80.15442589351109, 77.43792343139648, 77.8511883871896, 76.34195627485002, 79.5144134249006, 76.88483987535749, 77.49628829956055, 78.72366673605782, 77.50058923448834, 78.47471278054374, 78.1653025490897, 74.49837684631348, 73.95315865107945, 74.28047439030239, 72.01978070395333, 68.57757364000592, 63.979742186410085, 73.80653776441301, 70.4188323702131, 73.72188786097935, 73.44065257481166, 63.45436109815325, 52.70948266983032, 67.52588040488106, 70.5407246180943, 64.5769259589059, 69.22107410430908, 63.1179084777832, 65.16924599238804, 59.56569753374372, 64.2056906563895, 66.3250927243914, 71.812363079616, 68.95263739994594, 74.22502776554653, 71.53226729801723, 73.04474421909877, 71.00965854099819, 69.69940199170793, 70.07728672027588, 72.54404313223702, 72.05600166320801, 71.74223491123745, 69.3658606665475, 68.77014991215297, 67.51627799442836, 68.12203584398542, 64.87255791255406, 65.61981582641602, 64.35544518062046, 63.91300473894392, 62.00009618486677, 62.79235063280378, 62.351827893938335, 65.45886080605644, 62.13271645137242, 66.68709387098039, 68.36578559875488, 69.25320257459367, 66.17080102648053, 71.03359508514404, 70.6771524974278, 68.66256400517055, 65.43671689714704, 71.68489837646484, 68.76960795266288, 70.64398179735456, 66.1015761239188, 63.74906894138881, 4.893119037151337, 1.169695686016764, 0.38326304139835493, 8.248949136052813, 6.324693305151803, 1.670033729502133, 0.4326208728764738, 0.04956542926707438, 0.04331580622653876, 0.047588147688657045, 0.3003008988286768, 14.452837586402893, 29.71910946709769, 33.14647170475551, 38.29652166366577, 38.720028264181956, 37.86087308611189, 14.897669076919556, 27.021605116980417, 43.42702633993966, 37.097095830099924, 48.28177091053554, 51.921904359545024, 62.85823345184326, 59.99194867270333, 61.34918894086565, 5.113355653626578, 0.11621343903243542, 0.0873971220904163, 0.03421757443408881, 0.052989398395376544, 0.06820550547646624, 0.07518903538584709, 0.031659066544047425, 0.09992092435381242, 0.04501105133177979, 0.08376117862228837, 0.03274339943059853, 0.03858046639444573, 0.07431998809001275, 0.06815727520734072, 0.01599214249290526, 0.24881751569254057, 0.12832879035600595, 0.1444547450436013, 0.14051107237381594, 0.21532580070197582, 0.19877170398831367, 0.14065543748438358, 0.1278280857950449, 0.16232844309083053, 0.18022985250822135, 0.2632525068308626, 0.15695629135838576, 0.3510104263467448, 0.16572983057371207, 0.5144070056932313, 0.16003582254052162, 0.49993303950343815, 0.3588770085147449, 17.221862350191387, 99.39367512294224, 78.46978650774274, 77.93697084699357, 62.258812359401155, 64.26060226985386, 52.731942721775596, 62.82790456499372, 52.125660283224924, 59.09224033355713, 46.18377276829311, 56.571833406175884, 25.773807661873953, 2.069605414356504, 0.14269390595810755, 0.1752473155834845, 0.1346834200833525, 0.33253918322069304, 0.7764999504600252, 8.145480905260358, 3.454937900815691, 0.6676973487649644, 9.463615843227931, 101.24082592555455, 78.99394471304757, 95.74896975925991, 95.72425501687187, 98.8500758579799, 87.55743271963937, 95.78849111284528, 89.70629514966691, 88.63234683445522, 82.6241352898734, 89.44558484213692, 86.8649821962629, 85.55596242632184, 82.72972706386021, 82.91964912414551, 81.35970905848912, 81.86971378326416, 74.42708138057164, 73.68194961547852, 74.12787805284772, 80.68130084446499, 79.67338126046317, 79.43814304896763, 79.29143878391811, 82.80629621233258, 83.02670001983643, 81.70583357129777, 81.36368342808315, 85.02461283547538, 80.51594066619873, 82.12772124154228, 84.59406076158795, 80.64104298182896, 83.43924931117466, 81.70320715223039, 77.76670524052211, 77.7265238080706, 77.40387031010219, 75.53884179251534, 71.15405600411552, 69.05710356576103, 79.54114314488002, 74.83079951150077, 77.86127022334507, 74.54335253579276, 64.78641414642334, 51.041515486580984, 71.90675435747418, 72.92483220781598, 64.27876486097063, 69.8985790525164, 65.65327140263149, 68.05565970284599, 61.186399596078054, 69.52673925672258, 68.51124613625663, 73.94060325622559, 71.78700910295758, 76.92538956233433, 72.26049409593854, 76.50927584511894, 70.8303324835641, 72.14598778315953, 73.21346732548305, 75.73683765956334, 75.07566097804478, 75.12901619502476, 73.49197891780308, 73.07040391649518, 70.59110600607735, 71.55708626338414, 68.70799827575684, 69.41156591687883, 66.82730851854596, 68.83232934134347, 67.94591290610177, 66.23348072596959, 67.18270887647355, 67.10277679988316, 64.44762693132672, 70.44810513087681, 70.66859231676374, 69.68037782396588, 68.72625814165387, 72.41914231436593, 74.53419481004987, 70.24792058127267, 67.65278230394635, 75.54493536267961, 70.66473606654576, 72.91818278176444, 69.91146796090263, 63.77820273808071, 4.047843320029123, 7.555001275879996, 15.479334047862462, 12.32905467918941, 5.346031716891697, 0.57164887126003, 0.8332787294472966, 0.23570705205202103, 0.21802326238581113, 0.2515787460974285, 0.861989825963974, 27.43639520236424, 41.20558302743094, 43.14493295124599, 48.20197432381766, 50.534988335200715, 60.219891275678364, 54.71992656162807, 56.79620116097586, 50.20142616544451, 41.6018248966762, 49.545283453805105, 55.14914805548531, 66.52827889578683, 71.94291973114014, 68.60433115277971, 4.649060087544577, 0.2957133778503963, 0.1513452817286764, 0.07329390064946242, 0.26537059460367474, 0.2493000626564026, 0.18852008480046475, 0.25905850902199745, 0.22870731194104466, 0.0906039464420506, 0.11286678218415805, 0.1627295794231551, 0.11931749247014523, 0.1656995950532811, 0.13856951227145536, 0.18254533968865871], [0.04176734520920685, 0.06059615593403578, 0.17853897038315023, 0.08703403121658734, 0.1269700646932636, 0.13509852066636086, 0.05415344896859356, 0.014475966171760644, 0.07916698085942439, 0.08383790736219712, 0.12269595904009682, 0.09206264066909041, 0.2259717301598617, 0.02830558702615755, 0.07014520639287573, 0.07781941031238862, 0.28215714384402546, 0.1626676156052521, 12.476344329970223, 65.84747355324882, 57.413746629442485, 57.26992586680821, 56.0566349029541, 54.35657399041312, 42.278794833592, 28.138733012335642, 32.24768052782331, 28.92391766820635, 35.57490880148751, 26.946821655545914, 1.9522273242473602, 0.11431742220052651, 0.0222095249420298, 0.01682120541642819, 0.061429926194250584, 0.11044185409056288, 2.24791790332113, 5.329234446798052, 0.19393146942768777, 0.57341539646898, 51.78252002171108, 78.93410682678223, 84.39707238333565, 93.26529448372978, 90.04124001094273, 89.3117208480835, 85.87756674630302, 83.41714709145683, 79.60451071602958, 75.17836924961635, 77.2938733782087, 83.13358415876115, 75.11690548488072, 80.27202415466309, 74.57146494729179, 74.83341898236955, 71.62711715698242, 71.07376956939697, 68.59072657993862, 66.7554155077253, 71.15251350402832, 70.22729137965611, 69.71707126072475, 75.404755456107, 72.70159353528703, 72.69322790418352, 69.94636181422642, 75.71397808619908, 72.76655919211251, 72.32803058624268, 71.64078426361084, 75.81836782182965, 71.64708627973283, 71.83925955636161, 70.91361359187535, 72.2335489818028, 69.12756524767194, 70.15418243408203, 70.20548098427909, 68.11780439104352, 60.75208854675293, 57.5051988192967, 63.79360689435686, 65.51179913112095, 68.55125386374337, 66.03051689692906, 60.301775796072825, 56.73018285206386, 59.926823207310264, 58.90681375776018, 67.38912596021379, 68.33139896392822, 63.609618595668245, 66.58602537427629, 57.628418173108784, 59.59483133043562, 68.57476656777519, 66.34253965105329, 66.65402044568742, 65.5289750780378, 66.1000336238316, 65.75782789502824, 67.67298766544887, 67.59249973297119, 68.29515021187919, 67.2327220099313, 69.34427956172398, 64.92849091121128, 65.70257581983293, 65.17133740016392, 64.14886134011405, 60.88505622318813, 59.24580247061593, 59.52817031315395, 59.63506140027727, 58.26196534293038, 58.81433323451451, 58.60436562129429, 59.00488063267299, 61.23507867540632, 64.28134264264787, 64.07468932015556, 65.01943588256836, 66.28101335253034, 67.10097026824951, 63.1658718926566, 64.12512629372733, 68.57574626377651, 66.8597218649728, 65.29634938921247, 64.79892785208565, 69.42005661555699, 65.26325511932373, 64.6713102885655, 35.80492544174194, 0.19842951877840928, 7.029581972530909, 6.989041405064719, 3.7529148714882985, 0.30687194051487104, 0.14639604730265482, 0.13089357130229473, 0.1611454308565174, 0.04133652636249151, 0.12906251741307123, 0.48519390182835714, 18.92894789150783, 30.34002481188093, 23.43939879962376, 28.247986486979894, 32.7896226474217, 49.91869354248047, 35.389277253832134, 34.669777393341064, 57.270645005362375, 50.432068143572124, 49.2855042048863, 39.792962142399375, 50.45728315625872, 52.44015659604754, 22.989923306873866, 0.10000257925795657, 0.03994210636509316, 0.034862233591931205, 0.08201517231230225, 0.019906017297346677, 0.06376606119530541, 0.05298310498307858, 0.11531108245253563, 0.016347350486155068, 0.08060697466135025, 0.05055114048134003, 0.032434808489467414, 0.05975399219564029, 0.11786850807922226, 0.0835442781182272, 0.046937459747173955, 0.011840841500088573, 0.033813808778566976, 0.06164152055446591, 0.11524770728179387, 0.10804095292197806, 0.08014746396137135, 0.016788371106875793, 0.09449550083705358, 0.027270917813958864, 0.0999532158353499, 0.09968621230551175, 0.19591243884393147, 0.01289912627544254, 0.1098468874448112, 0.13950063873614582, 0.271697852228369, 0.33536891852106365, 14.480883121490479, 78.62551648276192, 67.74323395320347, 76.6076762335641, 58.18026842389788, 60.7811667578561, 32.923253876822336, 31.649954795837402, 45.855338369097026, 34.87440879004342, 40.10616609028408, 26.710424831935338, 0.881441199353763, 0.10763537218528134, 0.09351955034903117, 0.0466295948385128, 0.10895010163741452, 3.116032566343035, 2.395675254719598, 2.0885340443679263, 0.6727595457008907, 2.325951384646552, 65.86316953386579, 84.2674537386213, 89.1164903640747, 94.19758987426758, 91.44130202702114, 93.13900402614048, 88.10909884316581, 86.14325196402413, 84.2971989767892, 77.24500669751848, 82.5930768421718, 87.05271557399205, 80.08880710601807, 81.71728420257568, 76.9253409249442, 77.45492567334855, 74.07312624795097, 74.75680119650704, 70.61740493774414, 71.07252584184918, 74.55828421456474, 73.0184383392334, 74.49718870435441, 78.10902214050293, 74.45760481698173, 76.48326178959438, 74.521486554827, 77.6366627556937, 75.50865186963762, 74.78139781951904, 75.2380542755127, 79.20976270948137, 73.92739473070417, 75.9738198689052, 74.62681429726737, 74.39327144622803, 72.03100899287632, 75.39263084956578, 73.11862441471645, 71.45457254137311, 66.17986147744315, 64.23250375475202, 68.33034978594098, 71.05340439932687, 71.37778799874442, 66.62899998256138, 62.1078280040196, 58.80032566615513, 64.12002631596157, 65.56019333430699, 68.52057756696428, 71.54626791817802, 66.25202546800885, 66.94105747767857, 61.98100253513881, 61.72762952532087, 67.83526979173932, 69.48555728367397, 68.8658196585519, 68.3603104182652, 70.14940902165004, 68.33818735395158, 70.02803788866315, 71.26924324035645, 69.541017804827, 71.11576448168073, 70.50608784811837, 68.28375516619, 66.44128744942802, 67.45967102050781, 66.83549349648612, 63.6464718409947, 61.60117925916399, 61.60227707454136, 61.223086084638325, 62.343295506068635, 60.887168475559776, 62.67146587371826, 60.31948675428118, 64.34208379473004, 67.01871749332973, 65.9697618484497, 68.54037298474992, 69.80083179473877, 70.01715700966972, 69.61744798932756, 67.63213225773403, 71.40089770725795, 70.0718115397862, 68.9904008592878, 68.7406131199428, 71.90255764552525, 69.9297069822039, 68.283908026559, 52.87384230749947, 0.652226804622582, 1.5571157314947672, 1.2282011466366904, 6.084203992571149, 2.535167072500501, 0.35311697902423994, 0.10877968756748096, 0.09063881635665894, 0.032948839478194714, 0.0631828128493258, 0.3416189860020365, 17.476251534053258, 32.79399653843471, 29.29478645324707, 34.26266854149954, 38.64402191979544, 38.16696902683803, 30.66788251059396, 27.621057476316178, 49.16320201328823, 64.55414281572614, 54.100550242832725, 51.84777750287737, 61.70474215916225, 61.81728213174002, 34.95817627225603, 0.2718975586550576, 0.06332612623061452, 0.15688324027827807, 0.070602220083986, 0.027597503503784537, 0.033888505306094885, 0.06329098490199872, 0.03992674433227096, 0.031148112711629698, 0.09600619798792259, 0.04086510058758514, 0.04262774457622852, 0.03217033928792391, 0.09284227740551744, 0.05752631423196622, 0.23882489332130977, 0.07652676038976226, 0.23882288485765457, 0.08208455251795904, 0.14264129235276155, 0.24848915902631624, 0.1113839592518551, 0.08496040105819702, 0.1867314257792064, 0.10791349011872496, 0.1909025026751416, 0.2353094033896923, 0.40539305391056196, 0.20575560709195478, 0.16517485678195953, 0.24946331818188938, 0.41635017309870037, 0.7140658806477274, 20.271119253976003, 96.86141804286412, 78.38214193071637, 86.52348518371582, 80.22021838596889, 82.95844786507743, 65.22408117566789, 43.79793855122158, 50.54352419716971, 47.69438757215227, 53.81354447773525, 41.6057436806815, 4.202714758259909, 0.37346901265638216, 0.25959976283567293, 0.4495296669857842, 0.13305507174560002, 2.4075473376682828, 4.503038048744202, 17.15218234062195, 3.394573037113462, 1.3592959578548158, 74.34441171373639, 88.48316901070731, 90.18881280081612, 98.51348427363804, 97.07504040854317, 97.46725927080426, 92.35537229265485, 90.99545001983643, 88.58208356584821, 81.75768797738212, 85.10559409005302, 91.00089045933315, 83.15563079289028, 85.18555395943778, 79.99367237091064, 81.1732680456979, 77.551283291408, 77.11378996712821, 76.50764301845005, 74.88148662022182, 78.41262367793492, 78.38275337219238, 77.03483063834054, 81.46836498805455, 81.05047948019845, 80.28555924551827, 77.31398841312954, 81.87601579938615, 78.75447504861015, 78.22536972590855, 76.97383935110909, 80.15544033050537, 77.24964809417725, 76.79626423971993, 78.7322130203247, 79.11264773777553, 75.54888193947929, 78.40962205614362, 76.16962010519845, 75.48379816327775, 69.27538122449602, 67.04481492723737, 69.95901448386056, 73.83240590776715, 75.36284392220634, 68.40703705378941, 65.37086187090192, 59.16138185773577, 64.61400154658726, 71.21990408216203, 74.91210733141217, 76.03565883636475, 68.56707491193498, 71.29190131596157, 64.43997001647949, 65.03538199833461, 73.31389658791679, 71.0742767878941, 72.20958464486259, 71.36923476627895, 71.42508438655308, 71.81704616546631, 72.41864899226597, 73.55688898903983, 71.55420276096889, 72.75436510358537, 74.38562842777797, 69.73011302947998, 70.28715011051723, 71.88681302751813, 70.01582990373883, 67.82613291059221, 64.87962423052106, 64.71295779091972, 65.3927139554705, 64.5517248426165, 63.668990952628, 63.73857021331787, 64.00451251438686, 68.13235391889299, 70.69095856802804, 68.2107434953962, 71.30199704851422, 71.86504432133266, 71.61123357500348, 72.05940628051758, 71.67959690093994, 76.28905963897705, 71.95354352678571, 73.30730274745396, 72.40537098475865, 75.610581942967, 73.25164072854179, 75.2090038572039, 54.26470838274275, 0.4269641435572079, 13.238074472972325, 11.500316108976092, 7.074527697903769, 0.9482949205807277, 0.28284634543316706, 0.25825775627579006, 0.33034379673855646, 0.21413993862058434, 0.20367519158337796, 1.3039052443844932, 28.95963662011283, 45.49984073638916, 39.59881905147007, 47.35399879728045, 46.893090043749126, 67.95917701721191, 51.20212657111031, 47.731855733054026, 75.2557235445295, 65.69450896126884, 64.69660867963518, 58.17265667234148, 66.8046851839338, 77.02282415117536, 38.81565284729004, 0.3308082403881209, 0.21117254213563033, 0.23798625117966107, 0.15925006541822637, 0.11255337364439454, 0.15594341499464853, 0.14946635040853704, 0.16613479384354182, 0.07922029335583959, 0.11341687052377633, 0.1288369588021721, 0.18234088351683958, 0.12562348480735505, 0.18154299418841088, 0.1659753652555602], [0.13709850263382706, 0.04589480248146823, 0.027655849033700566, 0.026912094925397208, 0.030005530986402715, 0.021833519850458418, 0.06096633071345942, 0.05151370347344449, 0.21526277836944374, 0.07764100988528558, 0.11569677532783576, 0.09517154563218355, 0.1609921905079058, 0.1261627980108772, 0.19461628768060887, 0.02201630361378193, 0.22067948271121296, 0.17344580510897295, 7.241488567420414, 52.40256336757115, 52.28932857513428, 57.98658043997628, 54.15128598894392, 41.969784123556956, 27.29366704395839, 39.52597761154175, 38.25042731421334, 41.036623682294575, 29.75888442993164, 8.439714533942086, 0.06802101180489574, 0.0393905082850584, 0.10001697777105228, 0.125169680586883, 0.043159984052181244, 0.2922903315297195, 3.4043235310486386, 1.5125051481383187, 0.044603014298315556, 24.437227862221853, 68.89327199118478, 81.754853112357, 94.10297625405448, 86.13595635550362, 90.6777366910662, 85.11261871882847, 82.5598783493042, 79.34776782989502, 74.73256587982178, 80.72021075657436, 84.38354424067906, 78.31635638645717, 81.01040227072579, 75.48493071964809, 76.98679079328264, 73.51256643022809, 69.93007523672921, 69.13053212847028, 66.49780409676688, 65.5527240208217, 65.9401694706508, 67.82281861986432, 72.41569600786481, 69.51320416586739, 68.49938556126186, 70.2859411239624, 69.32092666625977, 69.4604048047747, 69.43033300127301, 72.25162124633789, 74.06731755392892, 72.63894162859235, 72.78967584882463, 73.37239347185407, 71.25641686575753, 71.40037659236363, 67.6782613481794, 71.14359896523612, 66.98819405691964, 64.98447949545724, 58.1582669530596, 61.71419170924595, 68.62364714486259, 67.02130917140416, 67.1700006212507, 64.47948442186627, 57.78345332826887, 63.39102131979806, 68.62735053471157, 64.27804919651577, 65.35026046207973, 66.97408921377999, 65.42029135567802, 62.0382695879255, 59.05756187438965, 60.09364945547921, 62.54912199292864, 68.9828690120152, 67.85906737191337, 68.41033049992153, 67.52090549468994, 68.52215480804443, 68.13669654301235, 70.00913184029716, 68.83728340693882, 68.47266973767961, 64.21519579206193, 62.64265169416155, 61.927570887974326, 58.959682600838796, 57.97015489850725, 58.56102275848389, 56.14381742477417, 56.8653426851545, 58.398441859654014, 59.67123372214181, 58.8028895514352, 60.580829347882954, 59.60595539637974, 59.84897559029715, 61.51322896139962, 64.12503596714565, 62.16189888545445, 64.67137977055141, 66.50717026846749, 66.20632716587612, 67.07810374668666, 65.09592165265764, 64.61464772905622, 65.1195455278669, 66.0636875970023, 61.52340112413679, 66.69552203587124, 61.9415784563337, 61.35924298422677, 19.957343816757202, 0.9173313592161451, 6.260328667504447, 9.408132740429469, 6.7396679520606995, 0.47910586850983755, 0.03692724635558469, 0.07977283799222537, 0.07803905888327531, 0.07337760472936289, 0.107101982592472, 1.5717614484684808, 22.272205659321376, 27.22334780011858, 22.062102556228638, 26.1907707963671, 32.87421696526663, 53.81663295200893, 122.70418657575334, 68.20986107417515, 27.391473361424037, 53.85493837084089, 31.775685923440115, 46.16644048690796, 43.59204258237566, 42.85607201712472, 4.990480235644749, 0.08041682200772421, 0.05206863655309592, 0.04783638633255448, 0.12623394919293268, 0.00973208952096424, 0.09313014588717904, 0.02649807999841869, 0.13901270420423575, 0.03308846502165709, 0.04328444433797683, 0.08504531971578087, 0.1812332429523979, 0.063175179330366, 0.04134887569983091, 0.07773167573447738, 0.0831257848601256, 0.09652501943388156, 0.06816929206252098, 0.10102223418653011, 0.023556796933657358, 0.07138265749173504, 0.04995406359168036, 0.158542896221791, 0.04430684054802571, 0.1763599230242627, 0.04270353354513645, 0.13295770197042397, 0.05428094230592251, 0.15213433653116226, 0.0379674473245229, 0.24887782388499805, 0.23540993513805525, 13.442540849958148, 65.071047101702, 64.41358075823102, 68.10057980673653, 61.83773068019322, 54.41964973722185, 35.766852787562776, 44.78279359000069, 44.06886271068028, 42.43970469066075, 31.681944302150182, 7.940996289253235, 0.050059552038354535, 0.07900762012494461, 0.13825999173734868, 0.10341308625148875, 0.5770579352974892, 1.034248588340623, 1.9487914400441306, 0.5621249537382806, 0.2728788288576262, 41.02833795547485, 78.77406896863664, 88.38296209062848, 94.69881902422223, 92.32361207689557, 92.780442237854, 87.63604463849748, 85.04845905303955, 84.49021298544747, 77.8123618534633, 84.6321507862636, 85.233962059021, 83.29978506905692, 81.55996309007917, 81.53982026236397, 79.11908176967076, 75.16469519478935, 74.60545553479875, 74.27406120300293, 68.19007955278668, 70.1635069165911, 69.05452578408378, 72.25941712515694, 73.18503529684884, 71.99287727900914, 70.7069672175816, 74.01069668361119, 71.03738185337612, 71.10955974033901, 72.17940861838204, 75.79984392438615, 75.32710933685303, 75.06282765524728, 74.72203241075788, 76.14370332445417, 73.73493657793317, 74.84100641523088, 72.58881037575858, 75.04626314980644, 71.03837544577462, 67.64183889116559, 62.010004316057476, 64.73690128326416, 72.3384598323277, 68.80343178340367, 69.21950381142753, 67.31091703687395, 63.16472543988909, 68.63033131190709, 69.86549173082624, 69.19853414808, 68.55085781642369, 69.79470348358154, 67.28250585283551, 65.71907779148647, 60.09653295789446, 61.51845400674002, 65.82264069148472, 70.1232282093593, 70.70818315233502, 70.40783337184361, 70.32962444850376, 71.21772929600307, 69.07047189985002, 71.32019438062395, 70.14896433694022, 69.88579436710903, 66.03433840615409, 66.41022900172642, 64.71546609061105, 61.84010696411133, 61.07665974753243, 61.75526251111712, 59.68296228136335, 58.656685556684224, 61.789294787815635, 62.56487355913435, 61.77890028272356, 63.29913139343262, 63.50372804914202, 63.12124361310686, 64.41511631011963, 66.65641757420131, 66.65187345232282, 67.19725145612443, 67.74072565351213, 68.75686495644706, 70.08351925441197, 68.25335679735456, 68.19311591557094, 68.8326142174857, 68.86118521009172, 65.44844545636857, 69.50818061828613, 67.59558473314557, 69.19409424918038, 33.50096879686628, 0.10678894724696875, 0.6815926602908543, 5.322259323937552, 6.2022161058017184, 1.362020411661693, 0.14201995783618518, 0.05885633107806955, 0.05007652559184602, 0.020613310326422964, 0.04645376266645534, 1.2781773677894046, 22.775517531803676, 28.394310338156565, 25.52355091912406, 33.72123711449759, 42.223480224609375, 41.13054595674787, 88.41957214900425, 59.692252022879465, 25.58067032269069, 60.87514809199742, 45.028825828007285, 63.79247433798653, 52.61344466890608, 59.27954292297363, 8.23738385949816, 0.17128190265170165, 0.09855946419494492, 0.07018388967428889, 0.07674694500331368, 0.050825048104992936, 0.03232491635052221, 0.029314571991562843, 0.05474101618996688, 0.06339363367961985, 0.025322760654879466, 0.047300197782793214, 0.0504144563871835, 0.06360003724694252, 0.04126768219949944, 0.17892307548650674, 0.12991515094680445, 0.20073760992714337, 0.14428831397422723, 0.17315754986235074, 0.10171176825783082, 0.11358438724918024, 0.1293572187423706, 0.2380358385188239, 0.1639267187565565, 0.20483037031122617, 0.14518258241670473, 0.25867046841553276, 0.22455968521535397, 0.3637326593909945, 0.1738994193396398, 0.40313013962336947, 0.36169613152742386, 19.41594886779785, 88.91952977861676, 74.47343976157052, 80.22208050319126, 76.27204350062779, 64.81027426038469, 45.045376437050955, 53.86729226793562, 56.35649136134556, 57.63963951383318, 44.487012250082834, 15.191015073231288, 0.2319805377296039, 0.1978313765887703, 0.37140675474490437, 0.25455162514533314, 0.4155319684318134, 0.9629721215793065, 11.400453993252345, 5.25747822863715, 0.2141281592526606, 43.53864915030343, 82.31213338034493, 86.40592861175537, 101.66875852857316, 94.54207461220878, 96.88320759364537, 90.40155969347272, 88.37472152709961, 86.06823226383754, 83.61909648350307, 88.30681678227016, 89.4945626940046, 84.78158569335938, 85.26525674547467, 82.38112204415458, 83.22499465942383, 77.85468333108085, 76.59908131190709, 77.5160767691476, 73.48926217215401, 73.56026581355503, 72.84483759743827, 74.7363943372454, 79.90092781611851, 75.28997816358293, 75.49993188040597, 77.50440379551479, 75.10458632877895, 74.75071457454136, 76.8351046698434, 80.51268196105957, 81.70019163404191, 80.28042452675956, 79.00651400429862, 81.37051350729806, 77.30360780443463, 77.38094125475202, 77.33778599330357, 77.53005654471261, 73.83847168513707, 73.70457989828927, 66.2414642061506, 69.55529635293144, 75.63383061545235, 72.82461833953857, 71.47075489589146, 68.49138123648507, 66.78833607264927, 70.27568558284214, 75.32780415671212, 69.71689755575997, 71.05040277753557, 71.82247270856584, 70.76334490094865, 68.62646116529191, 64.55997235434396, 65.8491758619036, 66.84576293400356, 71.23082665034703, 72.2315479006086, 71.73966407775879, 71.8603959764753, 73.71459225245884, 72.23799582890102, 74.35852350507463, 73.91925144195557, 74.08516747610909, 70.09500462668282, 69.1064705167498, 69.51480225154332, 64.63747950962612, 64.3972246987479, 64.04477037702287, 63.17220170157296, 61.70417240687779, 65.84415926252092, 64.52072198050362, 64.89554255349296, 67.45302854265485, 66.74303381783622, 65.53306756700788, 68.02872848510742, 67.094133240836, 68.46701390402657, 69.5979721886771, 72.07036358969552, 69.30065877096993, 73.73806326729911, 70.89816079820905, 72.87027495247978, 69.6193378993443, 72.49038219451904, 67.1284990310669, 74.55178764888218, 68.29303795950753, 76.70629896436418, 33.146860803876606, 2.7604441727910722, 15.185171638216291, 21.162838901792252, 14.353300298963275, 0.710077451808112, 0.24786588389958653, 0.16285495912390097, 0.19312351063958236, 0.16335077823272773, 0.21997646614909172, 3.7096423591886247, 33.875535760607036, 42.817259379795615, 37.74992077691214, 45.972311292375835, 49.13153559820992, 67.68941320691789, 143.57371248517717, 83.26327923366001, 39.68338210242135, 70.20596040998186, 47.53237989970616, 64.67996079581124, 63.01493617466518, 69.09403324127197, 8.71659677369254, 0.2818618725453104, 0.21446700607027325, 0.14590083887534483, 0.24280401266046933, 0.1423938170607601, 0.20033173742038862, 0.19227562685097965, 0.10260164657873766, 0.12620897910424642, 0.1262928731739521, 0.17071466094681195, 0.2143490631133318, 0.0813208342130695, 0.1277140783412116], [0.035548184998333454, 0.0459156538625913, 0.036810650290655236, 0.14296734199992248, 0.16965898259409837, 0.08213211103741612, 0.13059891068509646, 0.053839718124696186, 0.07635724877140351, 0.04146011473078813, 0.060651300475001335, 0.037131166484739096, 0.07197185658982821, 0.08398413844406605, 0.08253561545695577, 0.07632691825606994, 0.07269897471581187, 0.17162330076098442, 19.914093017578125, 55.5127785546439, 52.317795344761436, 41.09329319000244, 33.49228007452828, 41.95674235480172, 16.158596890313284, 23.3808810710907, 37.386189528873985, 42.97995144980294, 19.072515044893535, 0.699593542941979, 0.04158117894881538, 0.04791590724406498, 0.08866560259567839, 0.021909071332109824, 0.29754173117024557, 5.60204677922385, 1.76240807558809, 0.08816412450479609, 9.922693746430532, 68.16559410095215, 82.57573413848877, 93.11242021833147, 88.19544410705566, 89.2988805770874, 86.0425864628383, 83.71833760397774, 82.01052597590855, 78.6284486225673, 79.18441568102155, 83.20774923052106, 80.04877853393555, 79.06398255484444, 77.58669825962612, 75.6404036113194, 72.00184740339006, 71.78040831429618, 68.9206965310233, 66.0677661895752, 62.43042591639927, 63.996695790972026, 65.67795835222516, 67.13099343436105, 64.52771186828613, 65.03437450953892, 65.37155669076103, 62.44574669429234, 67.30990259987968, 66.95539161137172, 68.15138503483364, 67.39389937264579, 68.02680383409772, 71.40100193023682, 67.61442129952567, 68.85143688746861, 69.3610942023141, 68.51697840009416, 70.81633186340332, 72.17288425990513, 68.61068875449044, 66.15725203922817, 55.112277439662385, 62.37323529379708, 70.16692543029785, 64.35718223026821, 67.78498567853654, 67.93944413321358, 61.04142543247768, 65.107636315482, 64.08508382524762, 67.21792929513114, 65.07960728236607, 66.38222081320626, 62.33057335444859, 61.683487619672505, 56.88750396456037, 58.046175139290945, 65.72123868124825, 67.76861572265625, 68.35050651005336, 66.86680902753557, 66.11597973959786, 67.97025244576591, 68.93966511317662, 65.87345286778041, 65.75098391941616, 64.58388805389404, 59.6596371786935, 58.814340182713096, 57.433538573128835, 59.07348019736153, 57.551678793770925, 55.99023791721889, 58.15015493120466, 56.55154466629028, 55.61052928652082, 56.37663071496146, 58.47283622196743, 59.507909366062705, 59.73244735172817, 60.71210861206055, 61.111984389168875, 59.977941104343955, 62.37862709590367, 64.13871697017125, 62.81268106188093, 66.20122718811035, 66.8550248827253, 67.52348327636719, 64.6610825402396, 62.99282005855015, 65.34911400931222, 64.64614391326904, 61.54007680075509, 63.46826444353376, 60.250324385506765, 56.66681528091431, 5.458873501845768, 3.3768820549760545, 5.886232878480639, 9.707211869103567, 1.1450415232351847, 0.05548445986849921, 0.3077618527625288, 0.004190628882497549, 0.22116010263562202, 0.07223143016121217, 0.2511533589235374, 4.220567720276969, 19.74758291244507, 21.771016461508616, 27.326629298073904, 27.013560840061732, 37.234777859279085, 30.641277858189174, 27.922150714056833, 79.07263306209019, 52.02447714124407, 40.595395701272146, 46.514381953648154, 44.64072377341134, 51.82460873467581, 13.331878628049578, 0.29378194149051395, 0.10120294841804675, 0.05493344193590539, 0.061073566387806616, 0.11439923995307513, 0.17759750304477556, 0.03673404707972493, 0.0683493074029684, 0.050032631161489656, 0.04766266101172992, 0.08423027023673058, 0.029687033433999335, 0.1771239127431597, 0.06732761008398873, 0.023667396445359503, 0.08169900892036301, 0.006261436335210289, 0.0524361311191959, 0.10869781553213086, 0.04013356859130519, 0.08399814340685095, 0.0542181438899466, 0.18293027260473796, 0.022357767880229012, 0.042726434102015834, 0.014530038627396737, 0.05796643240111215, 0.03478171523394329, 0.08882902096956968, 0.05120588606223464, 0.06541267569575991, 0.25871970291648594, 34.257002285548616, 70.7371779850551, 67.42126832689557, 46.46580362319946, 39.91972507749285, 50.596309661865234, 18.07386088371277, 26.097414800098964, 39.60105289731707, 45.70034837722778, 20.276988744735718, 0.3606576201106821, 0.12242041953972407, 0.1003415889239737, 0.07306502400232212, 0.1229492968746594, 3.486687694277082, 5.418700754642487, 2.390550741127559, 0.5603892068777765, 19.96173507826669, 83.87366458347866, 86.80629076276506, 96.65046378544399, 90.78805324009487, 93.68065779549735, 89.89164529527936, 87.64336109161377, 84.71619619641984, 81.08560262407575, 84.83839416503906, 86.02234636034284, 82.08529554094586, 82.24894646235875, 80.43113095419747, 78.9688617161342, 75.81765910557338, 74.2628607068743, 72.32090173448834, 68.11647033691406, 65.47978183201381, 67.81933757237026, 67.96653515951974, 70.57103960854667, 66.72264085497174, 68.02079364231655, 66.78527886526925, 65.34743254525321, 69.658768926348, 69.55427496773856, 69.91721412113735, 70.26105267660958, 69.32129492078508, 73.22518198830741, 71.72799805232457, 72.30970818655831, 72.81071499415806, 73.96637412479946, 75.47511291503906, 75.81801346370152, 74.34221608298165, 69.24855422973633, 59.3016242980957, 66.58804035186768, 70.1326013292585, 64.87881823948452, 71.68159798213414, 68.99503530774797, 66.81257138933454, 68.90104007720947, 68.97560814448765, 68.90019239698137, 69.17029666900635, 66.00683743613106, 63.56041840144566, 64.1756396974836, 61.59361267089844, 61.57625607081822, 68.35930987766811, 69.78638648986816, 69.37579659053257, 68.10756274632045, 68.43411418369838, 69.90073299407959, 70.05118928636823, 69.59813894544328, 67.22967869894845, 64.87423937661308, 62.375813075474326, 61.22215502602713, 60.6472749710083, 60.43146392277309, 59.672915186200825, 57.52727672031948, 60.2706617627825, 59.567955698285786, 58.35874680110386, 58.11471217019217, 61.227088247026714, 61.34326212746756, 60.98090662275042, 62.886165210178916, 61.844296727861675, 64.2030781337193, 64.97278567722866, 66.66496385846818, 66.21312250409807, 69.30311148507255, 70.14182158878872, 70.37829657963344, 67.43137795584542, 64.76019164494106, 68.13215936933244, 70.1630413872855, 65.26938343048096, 68.21594074794224, 63.09226267678397, 68.68472181047711, 12.102828281266348, 1.7452174723148346, 1.4997827793870653, 7.454741375786917, 1.937853455543518, 0.1636425754321473, 0.1631846185773611, 0.00901878297528518, 0.179368737286755, 0.15471913426050118, 0.2322093125964914, 3.2359658564840044, 18.686384541647776, 23.177760907581874, 31.212933949061803, 31.14501530783517, 46.122489656720845, 32.23975958142962, 17.98753646441868, 57.948709283556255, 60.22844450814383, 42.77356563295637, 54.051579339163645, 52.26145240238735, 64.15830394199916, 17.556433745792933, 0.31755216313259943, 0.018682734009676745, 0.09851895565433161, 0.1222331981573786, 0.02754253877459892, 0.08738472525562559, 0.016898794199473093, 0.04154146768684898, 0.04052540899387427, 0.023392973135092428, 0.09434198228908436, 0.059012943745723793, 0.10370748902537993, 0.047586705801742415, 0.0730134756969554, 0.17771813300039085, 0.11099933846188442, 0.13725715769188745, 0.2150441679571356, 0.14843447506427765, 0.22984475376350538, 0.131319257031594, 0.27108179671423777, 0.10181601837809597, 0.18055345942931517, 0.0641526836635811, 0.13080424895243986, 0.09913539114807333, 0.12446230782994203, 0.16706187623952115, 0.1302310632807868, 0.39494844579270905, 40.725333963121685, 88.16107831682477, 75.97780118669782, 67.40530136653355, 46.393792493002756, 61.7713406426566, 25.701331002371653, 35.58750935963222, 59.68479660579136, 62.490284647260395, 30.208519731249126, 1.0277709130729948, 0.20637798655245984, 0.2123999169894627, 0.2070265438939844, 0.12046062041606222, 2.2951539286545346, 13.83347863810403, 4.714477377278464, 1.087292113474437, 19.27631265776498, 88.59664004189628, 84.74799810137067, 101.70008795601981, 92.97348403930664, 95.90181623186383, 91.14213344029018, 90.22189317430768, 89.25166061946324, 85.7964117867606, 84.77905654907227, 91.15258353097099, 84.10169056483677, 85.79583508627755, 81.47433349064418, 81.73291070120675, 78.89805957249233, 80.12182494572231, 76.9678430557251, 73.09370122637067, 69.30356311798096, 71.67204420907157, 72.6857099533081, 74.6019536427089, 70.50386442456926, 72.25838879176548, 72.58443995884487, 68.93645504542759, 75.20589801243374, 74.06325285775321, 74.13928699493408, 74.58910642351422, 73.06664494105748, 78.85682201385498, 74.56708758217948, 77.31835883004325, 77.05691201346261, 77.91332612718854, 79.53821100507463, 78.12888704027448, 76.21028096335274, 72.70158658708844, 63.457897731236045, 69.38799067905971, 75.20565482548305, 66.57469286237443, 75.0662670135498, 72.94125080108643, 67.64427770887102, 72.58517646789551, 72.60957854134696, 71.13609491075788, 73.3472409929548, 70.44827188764299, 65.36913871765137, 66.83404132298061, 63.32462433406285, 65.05665738242013, 71.12795162200928, 72.08037594386509, 73.5898790359497, 71.85211372375488, 71.56815474373954, 73.15740925925118, 74.40868255070278, 72.6972439629691, 69.89994784763881, 68.37756279536656, 64.01487227848598, 64.51860972813198, 63.62338992527553, 65.58362265995571, 64.03800283159528, 62.6801233291626, 64.49728570665631, 62.5538398197719, 62.944321632385254, 61.32687827519008, 63.637710162571494, 64.70555101122174, 65.34641810825893, 65.35641656603131, 64.94762625013078, 67.29463045937675, 68.11778354644775, 68.9533530644008, 66.955488886152, 72.71270370483398, 71.90158489772251, 73.35400853838239, 68.2433305467878, 68.79760224478585, 71.43180329459054, 71.73009640829903, 67.58843503679547, 72.90815653119768, 66.13893658774239, 74.95555441720145, 11.126976370811462, 6.028199774878366, 14.558259998049055, 18.74565441267831, 3.7550062792641774, 0.14719255241964543, 0.6059779663171087, 0.08742712012359075, 0.42149553128651207, 0.23473058587738446, 0.7819639486925942, 6.763192815440042, 31.463954993656703, 37.249692167554585, 47.68694257736206, 43.092043263571604, 61.7342928477696, 45.582173415592735, 35.92054694039481, 95.8754061290196, 67.44867202213833, 55.387902055467876, 66.5070868900844, 61.563401903424946, 77.172516141619, 21.016666173934937, 0.5372918748429844, 0.21191933777715477, 0.17737853979425772, 0.1700238308736256, 0.16654236268784317, 0.2627234123647213, 0.11545850097068719, 0.22531861306301185, 0.13932958005794457, 0.16969000521515096, 0.15854191913136415, 0.11461916672331945, 0.25149957463145256, 0.1413982840520995], [0.06142751739493438, 0.05125314263360841, 0.0360869384104652, 0.056704353873750994, 0.08666828727083546, 0.0845119436936719, 0.04080908752179571, 0.04317549875538264, 0.10446120572409459, 0.10585873680455343, 0.0879132565377014, 0.12195578590035439, 0.02882155862503818, 0.037216098713023324, 0.09455344772764615, 0.09936207612710339, 0.022315949767029712, 2.3055139098848616, 47.28548608507429, 57.3674681527274, 42.535332747868125, 52.86712687356131, 47.88898229598999, 37.808518409729004, 33.88866090774536, 32.72710623059954, 35.22386843817574, 28.73628851345607, 5.197381521974291, 0.0395566272283239, 0.04799512620749218, 0.08403734916022845, 0.04335555820060628, 0.09564299176314048, 1.6178600319794245, 4.72000857761928, 0.2834041283598968, 1.2050036085503442, 51.512182985033306, 77.21729033333915, 87.54212583814348, 86.98975099836076, 88.78310884748186, 86.19255638122559, 86.78593948909214, 83.01586777823312, 77.33651447296143, 79.83985315050397, 83.24316419873918, 79.58764743804932, 81.59541279929024, 79.19110679626465, 79.15180778503418, 75.6277300970895, 72.45565509796143, 69.04101848602295, 64.6869923727853, 60.77134895324707, 62.76261929103306, 63.212973730904714, 61.98845795222691, 60.924667903355186, 60.56238188062395, 62.45687770843506, 62.5523042678833, 62.72947638375418, 63.05877235957554, 62.04646151406424, 62.224064418247764, 65.13944516863141, 66.80421270642961, 66.98870822361538, 69.59872954232353, 70.48581995282854, 68.69608211517334, 70.84811292375836, 71.68602398463658, 69.84657178606305, 67.41054725646973, 61.752636092049734, 56.65264095578875, 63.15475477491106, 63.682935987200054, 63.878229004996165, 64.3019162586757, 66.18199457441057, 67.31808062962124, 66.55997657775879, 68.12666334424699, 66.51486887250627, 66.64621761866978, 64.15041773659843, 59.48049872262137, 57.54338959285191, 60.407610757010325, 53.603097438812256, 60.813225746154785, 63.855383328029085, 65.50917271205357, 66.05920600891113, 65.237380027771, 64.98800223214286, 65.941711970738, 63.510002272469656, 62.68425055912563, 60.60011754717146, 59.8487879889352, 61.15912791660854, 59.39768314361572, 55.27789122717721, 55.586321762629915, 55.247399057660786, 53.26059641156878, 52.96657296589443, 54.17019203730992, 51.83209541865757, 52.93593488420759, 54.57675545556204, 57.73473603384835, 57.194583075387136, 60.539438928876606, 61.501014028276714, 61.46821853092739, 63.364069257463726, 63.48109081813267, 63.43721989222935, 63.65721375601632, 65.54290621621269, 66.03273337227958, 62.842551367623464, 62.39414242335728, 64.44839818137032, 65.48165089743478, 66.99255752563477, 60.47382708958217, 60.70521599905831, 40.44520691462925, 0.06872711570135184, 2.583250343799591, 4.435577120099749, 2.303874352148601, 0.4223782510629722, 0.12205976460661207, 0.1403897503124816, 0.061495581242655, 0.12484786499823843, 0.08793425719652857, 0.5077027540121759, 3.358216805117471, 10.831623213631765, 20.98186264719282, 18.849047081811086, 15.495695318494525, 22.320705822535924, 42.37182079042707, 30.758400167737687, 34.33320665359497, 48.284070764269146, 48.61993278775896, 50.94983748027256, 46.33347518103463, 12.298927290099007, 0.14870576693543366, 0.07909561254616294, 0.034064130524971654, 0.030706508550792933, 0.03910278568842581, 0.13770075674567903, 0.07660613541624375, 0.1372606996446848, 0.04392845888755151, 0.05777731790606465, 0.03451993642374873, 0.06576602280672107, 0.025325337391612784, 0.022006564939926778, 0.0730391311060105, 0.07414072592343603, 0.06370747648179531, 0.06664441352976219, 0.036484352978212495, 0.021543914319149086, 0.03116713204820241, 0.02435966331644782, 0.05286363532234516, 0.07790698204189539, 0.06482026034167834, 0.12859184481203556, 0.008038264250249734, 0.04379646686304893, 0.04139048346717443, 0.11917850135692529, 0.13259258227688925, 5.170860247952597, 65.03583363124302, 68.32970360347203, 56.7085531098502, 76.6404230935233, 67.90829535893032, 26.65060431616647, 21.493861504963466, 37.0244072505406, 40.763451780591694, 31.16250044958932, 4.192774057388306, 0.04956157858084355, 0.07134149077215365, 0.07102344105286257, 0.5340197618518556, 1.5479554001774107, 1.2425861975976398, 3.8088643721171787, 0.6230870911053249, 4.130566835403442, 69.8679861341204, 81.01197951180595, 90.96445410592216, 90.67657634190151, 93.23149844578334, 87.81982449122837, 88.47444902147565, 86.92107500348772, 81.3487239565168, 84.59645094190324, 84.70058359418596, 82.88251100267682, 83.21158463614327, 81.04093960353306, 81.17957006181989, 78.18350682939801, 75.49328940255302, 72.27285494123186, 68.50012901851109, 64.36234474182129, 66.51544557298932, 67.13239002227783, 65.4731810433524, 63.70556627001081, 63.94487612588065, 66.10224315098354, 67.06449917384556, 67.4895830154419, 64.57256943838937, 65.46500301361084, 66.7770174571446, 70.18031460898263, 70.56831591469901, 72.70063468388149, 71.62057195390973, 75.43121419634137, 72.8941559110369, 73.56494889940534, 72.46092878069196, 71.81216853005546, 70.07944066183907, 64.63004493713379, 61.42843314579555, 67.48055035727364, 64.77754129682268, 67.84492778778076, 66.59197998046875, 69.8114069529942, 70.97673102787563, 70.15578051975795, 68.41982868739537, 67.9371998650687, 67.01540320260185, 67.30192606789726, 61.22446182795933, 59.14915997641427, 62.77972575596401, 60.020206996372764, 61.64999730246407, 66.56541006905692, 66.85191208975655, 68.37019075666154, 68.48348808288574, 68.05686174120221, 67.91378443581718, 65.2654229572841, 64.1755702154977, 63.96577630724226, 61.550221170697895, 60.42439065660749, 60.48033060346331, 57.52494559969221, 56.631313460213796, 57.67110095705305, 57.21447229385376, 54.805167061941965, 56.984987190791536, 55.563212054116384, 54.18975816454206, 57.92712123053414, 59.77817344665527, 60.73262664249965, 61.04619884490967, 64.87671293531145, 63.23464516230992, 65.19576031821114, 65.86752605438232, 66.73760032653809, 66.17865943908691, 68.46085780007499, 68.31732886178153, 65.67561680930001, 67.71139730725969, 63.7305519921439, 69.39325046539307, 68.27240180969238, 66.92115088871547, 64.79647513798305, 55.66515949794224, 1.6346805351121085, 0.3329899204628808, 2.907388584954398, 3.681278509753091, 0.2200875694730452, 0.15731928045196192, 0.16090015401797636, 0.06826793748353209, 0.12656576638775213, 0.17258774329509052, 0.6535741580384118, 2.4555763261658803, 10.986472504479543, 24.884493827819824, 24.352817671639578, 19.22891899517604, 31.970370973859513, 46.1855480330331, 38.68780599321638, 49.82112346376692, 56.4827436038426, 55.76163176127842, 57.666209425245015, 56.52640955788748, 14.061117257390704, 0.23369017456259045, 0.11774329122688089, 0.011686428982232298, 0.047157067605959516, 0.0520657833133425, 0.06641030537762813, 0.07960761471518449, 0.0882427395720567, 0.02291419034424637, 0.03185469497527395, 0.00824617755798889, 0.06009488140365907, 0.040063954291066954, 0.07279308073754821, 0.1103725145970072, 0.16155399036194595, 0.11976072511502675, 0.19464399905077048, 0.13254146144858428, 0.1645395037318979, 0.10407557391694613, 0.1287296281329223, 0.17510362900793552, 0.12399958765932492, 0.10630459537995712, 0.2230585350521973, 0.14349042464579853, 0.15602764833186353, 0.10324630234390497, 0.18856933287211827, 0.2551399692893028, 6.158126311642783, 79.86998053959438, 77.91921819959367, 68.31202043805803, 77.49334921155656, 64.166884967259, 56.55881943021502, 45.45450374058315, 51.310615743909565, 55.184556075504844, 43.03319896970476, 7.6360520124435425, 0.11358896057520594, 0.2168456105781453, 0.17984434962272644, 0.23005300973142895, 1.4642452406031745, 5.643260453428541, 12.211007390703474, 1.1650224796363284, 2.843855994088309, 72.92718764713833, 79.69340596880231, 93.31888593946184, 93.88342707497733, 96.87715571267265, 90.66698782784599, 92.46498012542725, 90.56224373408726, 83.660799571446, 86.62112127031598, 87.59446661812919, 85.88712746756417, 85.37733813694545, 84.62755107879639, 84.71264566693986, 83.20260061536516, 79.7565928867885, 74.96018191746303, 72.34509536198208, 68.10404000963483, 70.4451243536813, 71.05780260903495, 70.15569019317627, 67.8658696583339, 68.35788549695695, 68.85704408373151, 70.50328772408622, 70.10364818572998, 70.1800227846418, 71.02969714573452, 69.88476603371757, 74.16623905726841, 74.17406272888184, 75.76094096047538, 77.07604040418352, 81.23133414132255, 77.06600720541817, 77.64080388205392, 77.11306040627616, 76.08089855739048, 74.07714230673653, 69.34742709568569, 65.68144634791783, 70.09635257720947, 68.45418058122907, 69.61669063568115, 71.78496633257184, 72.99172251565116, 73.57926218850272, 72.44425310407365, 72.30188451494489, 70.80133070264543, 71.38455554417202, 70.32950632912772, 59.78802599225725, 61.68719795772007, 64.37832559858049, 61.906552587236675, 66.04141167231968, 68.05813326154436, 69.52307060786656, 71.20301301138741, 70.18328148978097, 70.54440716334751, 71.70047623770577, 69.17286055428642, 68.34228679112026, 66.33896827697754, 66.47099099840436, 65.37271009172711, 65.12855039324079, 62.23246479034424, 60.949757848467144, 60.19344643184117, 60.128272329057964, 58.27815464564732, 60.76636014665876, 58.380230631147114, 58.37037113734654, 60.56077684674944, 62.355308941432405, 63.15739509037563, 65.81005750383649, 66.2836606161935, 67.52612359183175, 68.68190779004777, 68.22436196463448, 67.49781663077218, 69.23620728084019, 70.0733470916748, 69.5178803035191, 66.95022909981864, 68.55923734392438, 68.73741000039237, 73.77069200788225, 71.91723224094936, 70.24729524339948, 69.04026808057512, 58.93475941249302, 1.4319759607315063, 6.2386398656027655, 11.037833588463918, 8.783380252974373, 0.999587608235223, 0.39892588236502236, 0.2522585839033127, 0.19911924962486538, 0.6246296997581209, 0.45897536299058367, 0.9312048490558351, 5.625347128936222, 19.671894448144094, 37.23546225684029, 36.04098354067121, 26.705378702708654, 34.58081265858242, 59.66595309121268, 41.88655512673514, 49.259583950042725, 69.66413293566022, 72.02476256234306, 67.70557471684047, 72.554659979684, 20.104298216956003, 0.4200105709689004, 0.1902794311089175, 0.11399245820939541, 0.19558552067194665, 0.14191623697323458, 0.2356154498245035, 0.14751819494579518, 0.16600980769310678, 0.119480164455516, 0.1275067723223141, 0.10056322560246501, 0.09394206731979336, 0.11398610712162086, 0.1919363864830562], [0.12060061576110975, 0.057891589988555224, 0.1000496017347489, 0.014284188426764948, 0.07837087607809476, 0.06159373811845269, 0.1083224228184138, 0.08348932356706687, 0.08171616228563444, 0.11408663886998381, 0.0877034535099353, 0.15126256830990314, 0.08857241259621722, 0.10465265437960625, 0.11085397590483938, 0.004012114800778883, 0.08115130902401038, 3.0876040118081227, 53.02438545227051, 52.862242289951865, 54.34881632668631, 70.84947477068219, 19.199293613433838, 38.1545421736581, 46.00243868146624, 35.71275758743286, 27.795907156808035, 10.96297630241939, 0.36481475989733425, 0.021574991223003184, 0.15732808783650398, 0.1056347048974463, 0.13722074750278676, 0.2579699760036809, 8.787636024611336, 0.6236437069518226, 0.31994728318282534, 33.688278334481375, 81.80791650499616, 87.18339729309082, 91.09767191750663, 87.93764509473527, 89.61840738568986, 84.11218234470913, 81.49018927982875, 78.97997188568115, 81.25803606850761, 80.72626958574567, 82.08375304085868, 82.33974552154541, 79.39598832811627, 77.1045002256121, 76.45928355625698, 74.81297043391636, 69.88288307189941, 65.21135902404785, 61.12851415361677, 61.87804412841797, 63.06708935328892, 60.73114667619978, 62.3767580304827, 61.686419759477886, 59.81609671456473, 62.423568044389995, 63.45957224709647, 60.726880482264924, 61.70346369062151, 61.66464410509382, 61.86136845179966, 63.186709540230886, 63.57572528294155, 64.5323463167463, 66.48219844273159, 65.65493897029332, 67.96869604928153, 68.26436969212124, 68.72511168888637, 66.70552744184221, 65.33473818642753, 58.03193480627877, 58.04145383834839, 64.24917943137032, 66.6296809060233, 66.18234893253872, 60.4180816922869, 63.56445530482701, 63.62652356284005, 65.45124558040074, 64.1815595626831, 61.28319495064871, 63.07966559273856, 62.88482420785086, 62.396581241062705, 58.20480251312256, 55.993138790130615, 54.80701528276716, 56.675041948046, 62.282978194100515, 64.77185072217668, 66.2181043624878, 63.95369338989258, 62.34438637324742, 60.42645427158901, 60.85615866524832, 58.52596909659249, 56.25953272410801, 55.05799811226981, 53.286311694553916, 55.61081068856375, 54.17408650262015, 54.49035460608346, 56.15811334337507, 53.31710263660976, 51.987571784428184, 50.910298756190706, 51.31546558652605, 50.730812890189036, 50.18508052825928, 54.70452240535191, 55.834883144923616, 58.069792066301616, 59.736491203308105, 61.85108511788504, 60.384431566510884, 63.44446686335972, 63.44460582733154, 63.88583033425467, 65.46744877951485, 65.72670691353935, 65.40829181671143, 64.33769948141915, 60.29327120099749, 62.23987851824079, 60.96638488769531, 64.20540578024728, 57.06262288774763, 56.947376591818674, 14.950035912649971, 1.0903205509696687, 2.3933484767164503, 3.404158294200897, 0.20393137926501886, 0.01575079946113484, 0.04918259980955294, 0.0893364091004644, 0.3972295176770006, 0.10380159504711628, 0.17050226591527462, 0.08431396753128086, 2.9873625678675513, 15.34426280430385, 27.63871111188616, 21.48551150730678, 18.693661042622157, 16.05646879332406, 12.270351954868861, 29.391894476754324, 32.25736631665911, 44.340144702366416, 46.298862729753765, 39.906394958496094, 2.7987693505627766, 0.1531367227435112, 0.11890339611896447, 0.09324026533535548, 0.09658956847020558, 0.033716730773448944, 0.045004143845289946, 0.0869772717622774, 0.08959699368902616, 0.07390965760818549, 0.10882283560931683, 0.038316590911043544, 0.046279698078121455, 0.09575504503612008, 0.09933901950716972, 0.056190478948077986, 0.028307115426287055, 0.138828129108463, 0.006911385097607438, 0.13794374013585703, 0.013640485155130071, 0.021987537121666328, 0.09401103361908879, 0.03993813354255898, 0.08062720857560635, 0.05980816643152918, 0.03412114442991359, 0.016461958443479877, 0.06880174776805298, 0.09451706467994622, 0.16493456039045537, 0.08562511431851558, 4.534798264503479, 62.17355796269008, 60.95781775883266, 70.07202693394252, 90.03131103515625, 33.89448697226388, 31.23079776763916, 44.055278982434956, 40.65193319320679, 31.12745373589652, 10.312703950064522, 0.1571872103959322, 0.005924757436982223, 0.23262672019856317, 0.015175015000360352, 1.01092164005552, 0.82858728404556, 3.281806596687862, 0.32684003189206123, 0.7132305768983704, 58.398511341639924, 88.50809914725167, 92.16010011945451, 91.91312640053886, 92.24998201642717, 91.12785489218575, 86.54409354073661, 83.98166738237653, 83.9080651147025, 81.76303114209855, 85.18741607666016, 83.23927320752824, 83.5651854106358, 81.08820819854736, 81.35406712123326, 78.30708054133824, 79.35391698564801, 73.36456285204206, 68.1082923071725, 64.43713515145438, 67.78284563337053, 66.06436852046421, 63.72733497619629, 65.0372371673584, 65.14769962855748, 64.53747408730644, 68.65652602059501, 66.33703667776925, 64.90351908547538, 63.57351575578962, 65.12479836600167, 65.42703110831124, 65.251206942967, 66.09014633723667, 68.18993364061627, 68.54044246673584, 69.00065640040806, 69.87333624703544, 69.14945902143205, 72.62856101989746, 69.87692151750836, 67.9850937979562, 61.62037713187081, 61.417184012276785, 67.043869972229, 67.99955299922398, 66.10308388301304, 63.98543276105608, 66.01179844992501, 65.74420942578996, 67.87477724892753, 66.30114923204694, 64.41922269548688, 63.7927314213344, 65.41947841644287, 64.96143926892961, 59.894444601876394, 59.57421602521624, 57.6383957862854, 59.43347331455776, 65.26302582877022, 65.0533778326852, 68.18711962018693, 67.17838709694999, 65.55654553004673, 62.97458798544747, 62.08381502968924, 60.340894154139924, 58.923989704677034, 58.050086975097656, 56.74024731772286, 57.637377875191824, 56.86513423919678, 57.445312295641216, 59.15694195883614, 56.16985927309309, 57.0225248336792, 53.975809233529226, 53.67298936843872, 54.46520560128348, 53.34893928255354, 57.10572951180594, 58.458891187395366, 59.49873079572405, 62.1862245287214, 64.35354137420654, 62.630367279052734, 66.0368675504412, 65.32981191362653, 66.57392161233085, 67.42325551169259, 68.37298393249512, 66.8234453201294, 66.13707447052002, 63.40634209769112, 65.7440357208252, 65.99840232304165, 67.28141498565674, 62.588407107761924, 66.08864552634103, 26.930286679949077, 0.4938023399029459, 0.5595168822578022, 0.8435748198202678, 0.2629085438592093, 0.018548043112137487, 0.10011444932648114, 0.05259835187877927, 0.6461424625345639, 0.171215365507773, 0.3825804351695946, 0.22129825236541883, 2.2117227826799666, 11.736099754061017, 31.4056213923863, 20.415723426001414, 21.813218082700455, 21.097147158214025, 14.633281435285296, 39.240618569510325, 38.915686062404085, 53.077025004795615, 51.88367189679827, 49.93317706244332, 3.4106752702168057, 0.16375294593828066, 0.09213449752756528, 0.07682878311191287, 0.07577328796365432, 0.011722393882726985, 0.014014625971737717, 0.04746166876118098, 0.06698748762054102, 0.04446245916187763, 0.038438903633505106, 0.061726256007594724, 0.021840227169117758, 0.0381677067572517, 0.07458811120263167, 0.14418521736349377, 0.26422194338270594, 0.1585547434432166, 0.08208187908998557, 0.22191443001585348, 0.16656090026455267, 0.17374531046620437, 0.24781379955155508, 0.18357097251074656, 0.14538931846618652, 0.0764069582468697, 0.22280333803168365, 0.13479620617415222, 0.12040964886546135, 0.17836962161319597, 0.343053110476051, 0.21117799755718025, 6.962735959461757, 78.89272335597447, 71.13219002314976, 78.72017874036516, 82.92494365147182, 32.500813824789866, 63.52651119232178, 67.80844974517822, 52.75516707556588, 43.27742467607771, 17.911752462387085, 0.5586654022336006, 0.1556657584650176, 0.4064094179442951, 0.18533831196171896, 0.6301519977194923, 0.9147423952817917, 17.081597328186035, 4.421818818364825, 0.517785512975284, 54.29468985966274, 89.5622034072876, 92.84440735408238, 97.44865894317627, 94.82989679064069, 95.90774999346051, 89.09613214220319, 85.78809479304722, 87.0162444795881, 86.67587307521275, 89.01140580858502, 86.41492652893066, 87.7693180356707, 86.51767648969377, 83.85996968405587, 83.17414774213518, 82.23894105638776, 77.05190931047711, 72.12474714006696, 69.4118299484253, 70.86870043618339, 69.69611549377441, 68.04250676291329, 69.90489496503557, 69.08053289140973, 67.5829668045044, 71.6091421672276, 72.14695358276367, 67.23430619921002, 69.08529935564313, 69.48156206948417, 70.15133367265973, 69.3235113961356, 71.24971185411725, 71.97817489079067, 72.79744393484933, 73.53748267037528, 74.23371996198381, 74.93339661189488, 77.16516494750977, 74.30986527034214, 73.9937083380563, 67.03399658203125, 65.18166242327008, 69.04179668426514, 70.32868644169399, 71.22305161612374, 67.65457493918282, 68.23930753980363, 69.02587141309465, 72.78216484614781, 69.159957749503, 66.80380971091134, 68.31138815198625, 67.4218658719744, 67.20328944069999, 62.01108823503767, 60.38308361598423, 60.77293314252581, 61.84032235826765, 67.10093552725655, 70.39172049931118, 75.06883089882987, 70.85512365613664, 68.50008732931954, 65.23717853001186, 65.21406882149833, 63.688716888427734, 62.38364369528634, 60.10690661839077, 60.72774205889021, 60.89117758614676, 60.589841161455425, 60.199574742998394, 63.306802204677034, 58.10814959662301, 58.97401673453194, 57.46790088926043, 57.3065185546875, 57.099069663456504, 55.96743392944336, 61.40123094831194, 61.80349690573556, 63.43173081534249, 66.59868499210903, 66.65891892569405, 66.43217141287667, 68.08469622475761, 66.47634805951799, 67.93063381740025, 69.81326212201799, 70.35977963038853, 69.25172955649239, 68.66660785675049, 66.60135310036796, 68.89213943481445, 68.33350426810128, 70.96651717594692, 65.96360574449811, 70.81688771929059, 30.84947715486799, 1.8572571745940616, 9.01037963799068, 7.882177182606288, 1.2834219549383437, 0.14644602819212846, 0.28269144945910996, 0.24894280039838382, 1.8901299706527164, 0.6983319020697049, 0.585863257093089, 0.8156241710696901, 6.482479078429086, 23.21523949078151, 40.84177187510899, 37.452339853559224, 33.302121775490896, 26.364020654133387, 18.772582156317576, 43.83809566497803, 44.92655529294695, 65.08704880305699, 63.12327248709542, 66.60504954201835, 6.698167230401721, 0.28988655337265556, 0.19557954956378254, 0.25125139366303173, 0.18958797678351402, 0.08376153146049806, 0.12303965059774262, 0.13588726334273815, 0.16906747647694179, 0.13022950265024388, 0.10334170436752693, 0.12124303914606571, 0.08792103254901511, 0.10824588406831026, 0.16206175168710096], [0.09758981051189558, 0.07013439733002867, 0.09900971967726946, 0.1152189781091043, 0.058133894843714576, 0.07554468951587166, 0.028080062342009375, 0.0808135885745287, 0.0860521774739027, 0.13088869942086084, 0.06537510521177735, 0.027957339105861526, 0.14328590062047752, 0.059747573254363875, 0.05780684096472604, 0.07532531235899244, 0.17375604489019938, 6.3862760577883035, 50.7147729737418, 51.31454842431204, 42.00784982953753, 21.883351462227957, 23.86508366039821, 19.962605340140207, 25.961355175290787, 24.782829523086548, 19.061396190098353, 1.044775652033942, 0.08666981397462742, 0.03952296510604875, 0.133543657671128, 0.030092783804450716, 1.3259973675012589, 2.107312419584819, 0.6004963261740548, 1.2926314664738519, 16.78419532094683, 91.52673707689557, 85.49149009159633, 89.6630426134382, 85.85879966190883, 87.70816693987165, 82.03610229492188, 80.70085307529995, 81.86508628300258, 80.88338225228446, 76.24420901707241, 80.99808311462402, 81.57112189701625, 79.34446048736572, 76.1234632219587, 78.73242146628243, 74.44819000789097, 73.89725344521659, 64.46123845236642, 62.300987924848286, 64.38774040767125, 66.53884710584367, 60.107358251299175, 66.01731531960624, 61.908706528799875, 62.97182955060686, 61.33721719469343, 62.15472834450858, 59.92662865774972, 58.90252671922956, 60.02834333692278, 58.35557842254639, 56.91505009787423, 59.57060991014753, 59.744662284851074, 62.27203478131975, 62.82593127659389, 61.16304670061384, 63.320455414908274, 63.844064712524414, 65.59931169237409, 63.688091550554546, 57.283599921635215, 55.11550487790789, 56.54950884410313, 64.16755199432373, 61.398277963910786, 59.58763299669538, 60.7042293548584, 63.84628118787493, 61.59203542981829, 63.86678532191685, 62.37010860443115, 61.41589164733887, 58.7104993547712, 59.70666258675711, 57.28398207255772, 58.62151377541678, 60.19705254690987, 58.589635440281455, 53.98825345720564, 59.618274552481516, 59.97933769226074, 60.959533963884624, 62.78731318882534, 62.222299575805664, 58.89310496194022, 56.90035465785435, 55.755830015454976, 54.10588993344988, 53.44883700779506, 51.42918675286429, 53.14815371377127, 56.34890740258353, 53.63103267124721, 54.70377894810268, 51.781536851610454, 54.63463394982474, 55.1783652305603, 52.056355476379395, 51.07176794324602, 51.506634848458425, 51.85445819582258, 52.98293249947684, 57.91300596509661, 58.24002987997872, 59.06025777544294, 59.929199491228374, 61.270736830575125, 62.781754629952566, 62.923622948782786, 65.30310303824288, 62.85849053519112, 64.43263271876744, 62.4031194959368, 62.83126054491316, 61.96255506787981, 62.22871276310512, 62.51640292576381, 59.985306194850374, 60.9789194379534, 41.16102422986712, 2.068196667092187, 2.4500436059066226, 1.9186814214502061, 0.17945316061377525, 0.08205033399696861, 0.015629231430856243, 0.1422229212309633, 0.4124181983726365, 0.08850507478096656, 0.04914077151832836, 0.20282823060240063, 0.11440458680902209, 2.357934159891946, 18.59635499545506, 30.94105441229684, 18.560243470328196, 28.147030898502894, 34.80692441122872, 32.19294956752232, 37.022802216666086, 42.58143057141985, 45.014394419533865, 28.899458272116526, 0.47737761267593926, 0.05662496527656913, 0.01724761717819742, 0.021997715146946054, 0.07571366509156567, 0.10952853917011193, 0.038381282439721484, 0.07814761091555868, 0.03982261974098427, 0.015546336503965514, 0.142783540434071, 0.16308593244424888, 0.16053632354097708, 0.07952414812254054, 0.0897785018065146, 0.05505233144919787, 0.06435979290732316, 0.055406496194856505, 0.1283128854951688, 0.08053625774170671, 0.013548703115832592, 0.018334631974409734, 0.06015280793820109, 0.049672956711479595, 0.15181166598839418, 0.12121686126504626, 0.07911579896296773, 0.09179927408695221, 0.16380508456911358, 0.03455546112465007, 0.0692476945530091, 0.18267674478037016, 8.54333301952907, 65.0541490827288, 65.15602357046944, 63.6344028200422, 31.352214063916886, 20.521077224186488, 19.748489652361187, 32.898219517299104, 26.25389518056597, 17.340521948678152, 0.7173161176698548, 0.05990094252462898, 0.08103446529379912, 0.12729995484863008, 0.10424977421228375, 0.4039873464831284, 2.3220521424497877, 1.9845970273017883, 1.3110680771725518, 23.85905957221985, 97.54408550262451, 84.05750696999687, 91.66402653285435, 87.47190734318325, 90.26587527138847, 86.0663423538208, 83.80658667428153, 82.38659722464425, 82.88885470799038, 80.91895702907017, 84.4281655720302, 82.84682505471366, 81.77427332741874, 81.40305192129952, 81.12805611746651, 75.96538475581578, 75.51432854788644, 69.98069286346436, 65.32412133898053, 69.19622734614781, 68.23808465685163, 65.07841219220842, 69.04625742776054, 66.0304126739502, 65.83177062443325, 65.77571255820138, 65.25019250597272, 64.51975618089948, 63.83818653651646, 63.782281330653596, 60.39601421356201, 60.3350715637207, 61.72295338766915, 62.95762743268694, 65.7125186920166, 65.95795685904366, 66.60283306666783, 65.86414922986711, 67.18879549843925, 68.17866366250175, 66.18923459734235, 60.50596250806536, 57.54919828687395, 61.2523866380964, 66.19252804347447, 61.29778616768973, 62.4089629309518, 64.48114504132951, 66.55990709577287, 65.25824546813965, 66.55721119471959, 66.57248333522251, 65.06298719133649, 61.950930731637136, 62.550907679966514, 58.60690171377999, 59.63105923788888, 60.836224283490864, 62.00864941733224, 56.45331103461129, 61.05099310193743, 61.6373724256243, 63.64825752803257, 62.71435710362026, 64.7323363167899, 58.678655760628835, 57.98402002879551, 57.88691895348685, 56.8731107711792, 55.068125111716135, 53.91411965233939, 55.53060415812901, 57.56508534295218, 57.392839499882285, 57.39529916218349, 54.32004036222185, 57.03102248055594, 58.61853299822126, 55.96812527520316, 54.311758109501426, 56.33764089856829, 55.31449086325509, 55.687782832554404, 59.648200443812776, 61.666756357465474, 63.639197077069966, 62.809992109026226, 63.70077201298305, 65.19245992388043, 65.75068514687675, 66.84312261853898, 64.90753514426095, 67.99163205283028, 63.71089553833008, 65.80833435058594, 65.16189479827881, 65.9566992350987, 64.7592327935355, 67.0360324042184, 64.83004883357457, 56.82155861173357, 4.901738277503422, 1.1037002844469888, 0.6104667740208762, 0.09491221633340631, 0.04717150343848126, 0.035609992753182135, 0.17644881111170563, 0.5942938647099903, 0.12698662094771862, 0.04941814306325146, 0.20716234589261667, 0.09989867519055094, 1.3865591692073005, 19.71152002470834, 34.388486521584646, 17.216322898864746, 28.778856652123586, 31.801140648978098, 35.653850759778706, 43.239932196480886, 49.652011258261545, 53.670505387442454, 36.711745262145996, 0.5102955720254353, 0.05892807937094143, 0.01953366950952581, 0.009059802113500024, 0.037486681515084844, 0.05549372187150376, 0.0759321397968701, 0.09080202438469444, 0.04492974926584533, 0.036110239303005595, 0.048215449920722415, 0.08054446123008217, 0.04206451640597411, 0.08717705282781806, 0.019678453615467464, 0.1644580659589597, 0.23695414513349533, 0.27619789647204535, 0.20178794142391, 0.08950662639524255, 0.1879752211804901, 0.08897966931441001, 0.17148451320827007, 0.11098853618438755, 0.13638582373304026, 0.13476113948438848, 0.17206898970263346, 0.2062131975378309, 0.2092031349561044, 0.10428451520523854, 0.23775185804281915, 0.2504042291215488, 10.181460295404706, 83.04266003199986, 71.14331408909389, 67.8862556729998, 39.85573564256941, 39.51704570225307, 30.973384380340576, 49.19060570853097, 38.838835511888774, 28.791606596538, 1.615886635013989, 0.1759281169090952, 0.09557993550385747, 0.34599073284438675, 0.18098640548331396, 2.790884230818067, 5.408437396798815, 6.657257105622973, 3.103506701333182, 22.84765546662467, 98.6624675478254, 85.45588057381767, 97.84421988895961, 90.99497059413365, 95.43054076603481, 87.9706004006522, 86.43292236328125, 86.93136528560093, 87.42723042624337, 82.75965295519147, 87.0302381515503, 85.42168848855155, 86.47641113826207, 83.83830520084926, 84.65288421085903, 79.26115158626011, 79.56880392347063, 72.96147005898612, 68.63006728036063, 71.92856475285122, 75.21343680790493, 69.14487321036202, 73.76498753683907, 69.45390823909214, 70.42618356432233, 67.75146756853376, 69.06041785648891, 69.08478518894741, 68.973648752485, 67.74935531616211, 63.891013690403526, 63.97631672450474, 68.47332981654576, 67.72500188010079, 70.01366901397705, 70.57773767198834, 70.8945129939488, 70.18772833687919, 71.01580769675118, 73.77284594944545, 69.53004659925188, 63.61132090432303, 62.10750143868582, 62.22455079214913, 70.21114376613072, 67.4942661012922, 64.03383391244071, 67.10341603415353, 70.23645605359758, 66.66938291277204, 69.05668667384556, 68.6809003012521, 67.56003774915422, 64.3929168156215, 65.07140840802873, 62.10857840946743, 63.14613206045968, 64.54606206076485, 63.50442286900112, 61.002265385219026, 65.15812192644391, 65.28746959141323, 68.1402679170881, 66.7108428137643, 69.04700088500977, 64.68187849862235, 61.29034464699881, 62.03324604034424, 60.01900495801653, 57.94646154131208, 58.00223820550101, 58.30612114497593, 61.804156984601704, 58.8431613104684, 61.09045192173549, 58.652947425842285, 62.11857686723982, 61.76462868281773, 58.49550819396973, 58.45033795492989, 58.397184235709055, 59.005283628191265, 58.03253582545689, 64.45719460078648, 64.77820832388741, 67.76473862784249, 65.44405419485909, 67.55977371760777, 67.08158479418073, 68.73311601366315, 69.52858052934918, 68.04268046787807, 69.76305443899972, 67.279219354902, 68.37681933811733, 66.75953578948975, 69.64663042340959, 66.03913266318185, 69.70487022399902, 68.61489936283657, 62.48709542410714, 5.838831399168287, 5.77439033133643, 5.142034777573176, 0.3233749164002282, 0.31735614793641226, 0.18030540059719766, 0.7188207283616066, 1.939810893365315, 0.4842391759157181, 0.2350179318870817, 0.3870280965098313, 0.30148646235466003, 5.033146517617362, 32.19255004610334, 44.37360027858189, 32.69080536706107, 44.57036631447928, 53.17248283113752, 49.565450600215364, 52.761844294411794, 58.68185888017927, 61.26515742710659, 48.457751410348074, 0.8296878135630062, 0.1248246862420014, 0.09949451937739338, 0.15588651304798468, 0.10023904192660536, 0.1433248213891472, 0.11198978245790515, 0.15996530918138369, 0.11226545087993145, 0.1343489158898592, 0.15728638507425785, 0.1601923062865223, 0.2409475137080465, 0.14662375008421286, 0.1965582413332803], [0.12684024737349578, 0.04215304147718208, 0.14666647064898694, 0.07331110829753534, 0.03989983024075627, 0.14669707257832798, 0.04061115546418088, 0.02223705650041146, 0.0366079481318593, 0.059033523712839396, 0.12961784404303345, 0.048728802374431064, 0.07949372261230435, 0.10358192612017904, 0.009602040651121309, 0.03845191454248769, 0.0814800320991448, 19.374089445386613, 54.21956941059658, 42.31281668799264, 32.305451325007844, 37.42479024614607, 37.6900828906468, 25.084367445537023, 21.418980768748693, 21.35439726284572, 4.629034076418195, 0.06205295704837356, 0.11515227811677115, 0.08356650014008794, 0.17245625677917684, 0.010293303290382028, 2.9960554156984602, 1.868843947138105, 1.121540327157293, 0.189008643584592, 47.98209163120815, 93.00878783634731, 80.73357909066337, 87.89165496826172, 83.86430535997663, 85.5001961844308, 80.69468307495117, 79.9352936063494, 77.1422428403582, 76.8498626436506, 81.33885751451764, 84.37552601950509, 78.14073371887207, 77.0892836706979, 77.15278325762067, 77.8540927342006, 71.25269263131278, 70.20874663761684, 61.98332323346819, 65.38441780635289, 67.14018590109688, 62.93364225115095, 64.27731268746513, 65.96938664572579, 62.024241174970356, 65.26833425249372, 63.07335662841797, 61.32227856772286, 58.776145935058594, 61.0309544972011, 59.846543720790315, 57.08250168391636, 57.56033277511597, 58.60917377471924, 58.60396957397461, 61.442371232169016, 60.28953307015555, 62.22751767294747, 59.27233764103481, 61.051271029881065, 58.69827052525112, 57.13460969924927, 51.94062975474766, 53.93497119631086, 59.25493240356445, 60.39081696101597, 58.73309489658901, 66.1333919252668, 64.0801089150565, 64.90762547084263, 66.73131220681327, 64.28915241786412, 63.317092486790244, 64.4990644454956, 64.43065248216901, 63.93243190220424, 58.87581784384591, 55.43883582523891, 53.58113070896694, 54.99180262429373, 51.76497234616961, 54.32314968109131, 54.46809605189732, 56.26294081551688, 55.75152908052717, 54.323719433375764, 54.03487934385027, 50.91935225895473, 51.19946888514927, 52.93602868488857, 55.276817730494905, 52.7295594896589, 52.63258000782558, 55.285881655556814, 56.510143824986045, 54.17868273598807, 55.31837490626744, 54.311476707458496, 55.22172546386719, 54.940490177699495, 51.65655960355486, 52.451826095581055, 52.09588030406407, 52.36594636099679, 52.63391406195504, 56.22268295288086, 57.46976300648281, 58.36415944780622, 61.20095607212612, 61.55479308537075, 60.53957789284842, 61.94293335505894, 62.89491299220494, 64.14385168892997, 62.83426911490304, 61.32261208125523, 61.723738534109934, 62.036518641880576, 60.070372990199495, 65.62372766222272, 57.80466617856707, 61.520121574401855, 15.522108895438057, 0.281193271279335, 0.3853166954857962, 0.03937600799170988, 0.11512428176190172, 0.09390411007085017, 0.12197813684386866, 0.1299143231340817, 0.0917594169399568, 0.15030256339481898, 0.09646355773189239, 0.10334616234259945, 0.17654909858746187, 4.554911996637072, 26.312833275113785, 26.240292344774517, 22.080821003232682, 24.316713094711304, 37.21687235151018, 43.690644468579976, 47.887776783534456, 41.27883093697684, 30.705333300999232, 0.06599163570042167, 0.04008338753400104, 0.08524256306035177, 0.06599802071494715, 0.04959708292569433, 0.12926710929189408, 0.060425273674939356, 0.15457689974989208, 0.03935654082202485, 0.061708763374813964, 0.06477219292095729, 0.07286188418843917, 0.0543232659277107, 0.04549073148518801, 0.026495742445279444, 0.06538922552551542, 0.05315794649400881, 0.20098560090575898, 0.10829273012599774, 0.010927073657512665, 0.12491980328091554, 0.036114147664713006, 0.03840748406946659, 0.03313371652205076, 0.07471611004854951, 0.050802408784095726, 0.029168907486434494, 0.07739334460347891, 0.06566681420164448, 0.06879273682300534, 0.10165333282202482, 0.11862557674092905, 27.885738679340907, 64.34597478594098, 55.23158148356846, 51.62872164590018, 42.02348327636719, 30.069785049983434, 28.61081968035017, 23.241715601512364, 22.569984606334142, 4.0225236501012525, 0.026788084169051478, 0.13254021294414997, 0.06882854311593942, 0.19560494034418038, 0.04217967397666403, 1.4627081687961305, 1.3240879156759806, 0.1638676726392337, 0.510876018021788, 57.468130179813926, 91.32962363106864, 85.27758979797363, 89.43362004416329, 86.68985285077775, 86.11167934962681, 84.43997750963483, 84.16252204350063, 80.69022927965436, 81.98793043409074, 85.06112561907086, 85.1327268055507, 81.88540976388114, 80.89292907714844, 79.438323702131, 80.33553068978446, 74.52603762490409, 71.60233293260846, 66.55862862723214, 68.57253619602749, 71.1733511516026, 65.07321493966239, 69.5389402934483, 70.61074161529541, 67.8503543308803, 67.23627948760986, 65.03547927311489, 64.46949986049107, 61.93328925541469, 64.72224753243583, 64.67147704533168, 60.8199793951852, 61.32953248705183, 60.83518900190081, 61.82739176068987, 64.58123384203229, 62.76616287231445, 61.964882714407786, 61.68310546875, 62.248522077287944, 60.58931309836251, 59.65683010646275, 55.725299630846294, 57.135318415505544, 61.464834758213584, 61.77396011352539, 64.3212947845459, 70.37141786302838, 67.75885350363595, 69.4354190826416, 68.21981089455741, 66.41236209869385, 67.652907371521, 68.32850851331438, 67.99616227831159, 68.22749560219901, 65.15357085636684, 58.53445284707205, 56.53174230030605, 55.80683674131121, 53.80510936464582, 54.53986399514334, 57.071262972695486, 57.74870538711548, 56.70370326723371, 54.275384289877756, 55.09091172899519, 54.81900439943586, 51.93463345936367, 57.86862087249756, 56.94874538694109, 56.22692482812064, 55.435663972582134, 56.707656792231965, 57.05138417652675, 57.64774806158883, 59.22681999206543, 58.05783421652657, 57.64972134998867, 57.014082772391184, 54.61823967524937, 57.152219908578054, 54.51521873474121, 54.29758725847517, 54.840950284685405, 58.84314741407122, 60.58644349234444, 59.93561267852783, 60.87981033325195, 64.03992748260498, 63.02341297694615, 64.14300400870187, 66.2053474698748, 66.56456238882882, 65.6821620123727, 65.05941581726074, 64.73890931265694, 65.39566693987165, 62.29095472608294, 69.2700936453683, 61.42518138885498, 68.95306818825858, 24.352419887270244, 0.1092802496360881, 0.34639036282896996, 0.27143482491374016, 0.1842125952243805, 0.2005898385707821, 0.4275524334183761, 0.0695212527311274, 0.1514043685581003, 0.033830904468361817, 0.09663135265665394, 0.2136924040636846, 0.048339777892189364, 3.5949645127568925, 33.285689285823274, 30.061120646340505, 23.115546737398418, 17.211410522460938, 32.007387501852854, 52.87962668282645, 53.403079645974294, 49.22648968015398, 35.68131351470947, 0.1187799298869712, 0.08134046423115901, 0.09599117522260972, 0.014550649128588182, 0.04405083946351494, 0.05905985765691314, 0.16866997709231718, 0.1556753936622824, 0.050370371967021904, 0.06708096260471003, 0.053811151800411086, 0.03883955481329134, 0.05223334075084754, 0.026827800520030514, 0.07352353725582361, 0.19475864432752132, 0.1510227604636124, 0.3129551426640579, 0.18934844035123075, 0.08945633337966033, 0.2540237791836262, 0.08951676370842115, 0.1473913360387087, 0.17103103468460695, 0.13527272774704865, 0.19878539682499, 0.1821559691535575, 0.11359167471528053, 0.2747679517737457, 0.15329312506530965, 0.18904570516731056, 0.16173361215208257, 33.00031982149397, 78.69269861493791, 62.66130065917969, 52.4870673588344, 57.18144055775234, 57.542614868709016, 43.056027276175364, 38.66304956163679, 34.80896718161446, 8.095228927476064, 0.10110542936516659, 0.32785601594618385, 0.10716552061161824, 0.6457434839435986, 0.10298705446932997, 6.40942702123097, 8.04019832611084, 1.7182771350656236, 0.995626049382346, 59.52656527927944, 97.38031646183559, 88.63696738651821, 92.59727382659912, 89.00403376988002, 89.21111093248639, 87.22078554970878, 88.31170831407819, 84.68484592437744, 86.1392011642456, 86.6671391895839, 90.49537427084786, 84.44796793801444, 83.6136977331979, 83.4010898045131, 84.86320618220738, 78.82105963570731, 76.35264260428292, 68.70142527988979, 72.11828531537736, 74.67069217136928, 69.1323595046997, 72.35450322287423, 72.4594418661935, 70.73919296264648, 69.69510105678013, 68.42226750510079, 69.20482226780483, 65.64771284375871, 68.36493791852678, 67.62219633374895, 65.461348261152, 64.29420375823975, 66.42145729064941, 65.86691461290631, 67.86892686571393, 65.8664699281965, 67.48708861214774, 65.36975710732597, 67.03125899178642, 65.60042340414864, 65.58551256997245, 59.203835351126536, 61.11354078565325, 65.71857057298932, 68.02041149139404, 64.72179589952741, 73.46999481746128, 68.7439968926566, 71.3546643938337, 71.09016731807164, 67.67640617915562, 69.77147565569196, 70.31228174482072, 70.09330926622663, 69.40792506081718, 64.93097141810826, 59.44691807883126, 59.82499735695975, 60.33158356802804, 57.52867678233555, 60.17680549621582, 61.197426387241904, 61.89970166342599, 61.137845584324424, 60.371952601841514, 59.26889133453369, 56.63661840983799, 55.60284457887922, 59.597589765276226, 60.11020006452288, 59.1122441973005, 58.27130719593593, 62.20107977730887, 61.31143937792097, 59.883125986371724, 60.322279930114746, 60.70682103293282, 62.02792372022356, 59.42555236816406, 56.55080120904105, 60.26338005065918, 58.08560964039394, 58.86973122188023, 58.66222327096121, 64.01128005981445, 62.63603006090437, 62.370393480573384, 64.5408717564174, 66.99858856201172, 65.37227235521588, 67.77182579040527, 68.13351426805768, 68.78258718763078, 67.73661926814488, 67.78667409079415, 66.99018124171666, 67.9012359891619, 65.28767108917236, 74.36690998077393, 64.40231772831508, 75.14769295283726, 27.04626601082938, 0.5578756417546953, 1.9269215507166726, 0.5071379957454545, 0.3106853616024767, 0.5335571095347404, 1.0546328659568514, 0.216541925445199, 0.30133520332830294, 0.19795728554683073, 0.36413953612957684, 0.4280281678906509, 0.396678872938667, 6.999619168894632, 43.66036421912057, 43.471470492226736, 39.06478745596749, 35.9116393498012, 56.062064920152935, 59.85957159314837, 62.796846117292134, 56.10510901042393, 46.70160116468157, 0.3430671968630382, 0.13288463731961592, 0.2629445604979992, 0.0987004909132208, 0.2711479945906571, 0.27313596648829325, 0.19725063203700952, 0.19583971346063273, 0.12678206978099688, 0.1691991529826607, 0.14063472859561443, 0.15639697494251387, 0.1382387943033661, 0.09461337594049317, 0.09882420820317098], [0.0664038932217019, 0.0834894117766193, 0.05573558907157608, 0.07981439826211759, 0.10767539896603141, 0.053407219903809686, 0.022512850451416204, 0.06888423727027007, 0.0806785329644169, 0.029467048988278424, 0.17025882112128393, 0.08194689811872584, 0.017784665771094815, 0.10858224066240446, 0.044548931664654186, 0.15430667996406555, 1.6144797333649226, 42.73012202126639, 50.32791117259434, 42.27931594848633, 36.10038021632603, 23.48055645397731, 21.896895238331386, 23.742633819580078, 24.58031211580549, 9.79191996370043, 0.5441577807068825, 0.09685861439044986, 0.10079685199473586, 0.16266965121030807, 0.13321374037436076, 0.032841739510851245, 0.047505519086761136, 0.7210070767572948, 0.6814292147755623, 2.576517539364951, 70.86233588627407, 77.06532628195626, 83.9308135168893, 81.77940109797886, 78.94536985669816, 80.91540649959019, 79.02644143785749, 78.15458842686245, 74.17814132145473, 80.2066068649292, 82.16362953186035, 75.22173295702252, 79.97962311335972, 76.70215783800397, 73.91246305193219, 75.70371559688023, 69.47280039106096, 67.50207587650844, 65.61517442975725, 70.82223783220563, 63.690773555210654, 65.0400720323835, 68.77820982251848, 66.68837928771973, 65.5120770590646, 66.18024362836564, 63.69232300349644, 59.41841656821114, 60.744237082345144, 65.05789416176933, 60.59572628566197, 59.35850919995989, 59.30933679853167, 58.692093576703755, 58.018246855054585, 57.926172801426475, 55.60228872299194, 55.832593713487896, 54.58858476366316, 55.799339635031565, 54.324407305036274, 53.39471401487078, 52.60134090696062, 54.62524693352835, 49.75602231706892, 55.64240067345755, 66.24894741603306, 65.94616576603481, 65.76665210723877, 66.13812364850725, 65.8024422781808, 65.34009524754116, 64.72015612465995, 64.73911081041608, 64.0073195866176, 66.31452451433454, 67.29331030164445, 62.38876451764788, 55.601225648607524, 52.22510984965733, 48.011107308524, 49.71563243865967, 48.61084801810128, 48.26862144470215, 50.39817483084542, 51.633453369140625, 50.17387308393206, 51.6097217968532, 52.674772943769185, 52.855297565460205, 54.62732097080776, 56.53582089287894, 53.93828548703875, 53.63850545883179, 54.88365738732474, 56.63380438940865, 55.78065940311977, 57.07787765775408, 56.34871285302298, 57.471850940159385, 56.44228424344744, 56.48400122778756, 52.94864313943045, 52.187693800245015, 52.426889010838096, 50.85668992996216, 56.44936793191092, 58.56730393001011, 58.00290870666504, 59.69348880222866, 60.575771059308735, 59.512599400111604, 61.101471764700754, 61.61198370797293, 63.63330500466483, 64.05498422895158, 60.41560813358852, 62.20642294202532, 62.34556756700788, 62.72044372558594, 61.198843819754465, 62.64881474631173, 44.00353227342878, 2.2942801926817213, 0.0719501298985311, 0.025677676878071258, 0.10331345016935042, 0.02410088193469814, 0.05581501838085907, 0.05643538937770894, 0.08354320603289775, 0.050014334464711804, 0.11220345992062773, 0.09023010757352624, 0.08255557117185422, 0.5718369611671993, 8.34569411618369, 40.79524673734392, 22.86428771700178, 30.998488221849712, 33.78603254045759, 41.45635741097586, 38.08560562133789, 46.42525046212332, 31.502729415893555, 0.21813564135559968, 0.08270656556955405, 0.053005527172769816, 0.049658347852528095, 0.06538811951343503, 0.056093977697725804, 0.09846580600632088, 0.06233748035239322, 0.06332742223250014, 0.025449494032987525, 0.08729785241718803, 0.07176394667476416, 0.021839877723583152, 0.03321895409109337, 0.029401617856430154, 0.02256346577113228, 0.04260025033727288, 0.05849398659276111, 0.07521061279944011, 0.029019904589014392, 0.005867673134032104, 0.03351269529334136, 0.03183715484504189, 0.07834228261240891, 0.10862718682203974, 0.10595430846193007, 0.0573076902489577, 0.014548535492005093, 0.12684829479881696, 0.03700303193181753, 0.16249153576791286, 2.198998894010271, 55.575406142643516, 62.99798257010323, 62.311201776777, 47.87591620853969, 20.810763256890432, 17.10260694367545, 27.8479300567082, 25.872637101582118, 7.930507114955357, 0.6923246415598052, 0.0850677927955985, 0.2275822465973241, 0.1577268357255629, 0.09621395862528256, 0.24095823456134113, 0.10347638678337846, 0.7924353182315826, 1.2746256440877914, 3.997653007507324, 78.65395545959473, 78.92443493434361, 85.9017812183925, 83.01917512076241, 84.33796405792236, 83.27841241019112, 81.82219505310059, 80.07821805136544, 78.8524168559483, 84.41107300349644, 84.1490911756243, 80.77777658190045, 81.89563751220703, 79.29523944854736, 77.82853725978306, 77.28077602386475, 71.2286240713937, 71.15065138680595, 70.46354402814592, 72.54081221989223, 69.41139221191406, 69.00722244807652, 71.35688781738281, 71.09082739693778, 69.43146555764335, 69.1981450489589, 65.32624748774937, 63.49099200112479, 66.28874669756208, 70.20771830422538, 63.664182799203054, 62.922712734767366, 63.154671396527974, 64.33914470672607, 62.83280304500035, 60.44150406973702, 58.22925669806344, 58.88945715767996, 57.68731457846505, 57.64053930555071, 55.92383050918579, 57.555844238826204, 54.344702993120464, 56.12161445617676, 54.6594876561846, 58.58572360447475, 68.29215553828648, 68.1358141217913, 68.69313607897077, 67.64622320447648, 67.69738279070172, 66.55670397622245, 67.07667936597551, 66.44560922895158, 64.98203372955322, 65.43914876665387, 67.52114173344204, 65.40752751486642, 60.762066159929546, 56.459258692605154, 51.2453339440482, 51.760709626334055, 51.744551590510774, 52.53196314402989, 53.304498604365754, 53.62478971481323, 52.90205199377877, 54.75383029665266, 55.09839146477835, 55.35081257138933, 57.902024337223594, 57.73172746385847, 58.915922846112935, 56.94149841581072, 57.50997223172869, 58.380195890154155, 58.64735412597656, 60.032421929495676, 60.29575865609305, 60.11323642730713, 59.58838340214321, 59.47519724709647, 56.09349857057844, 54.43942778451102, 55.75086900166103, 53.98270532063076, 57.3574731690543, 61.334451811654226, 59.29650347573416, 61.48410211290632, 63.47255843026297, 61.1431679044451, 63.03602395738874, 63.95804296221052, 65.77156448364258, 66.12249714987618, 64.64373288835797, 63.23755645751953, 64.38945661272321, 64.56075055258614, 66.49925627027238, 66.31735243116105, 55.31315680912563, 4.567251997334616, 0.15414009961698735, 0.07006209942379168, 0.2092870425965105, 0.11582584625908307, 0.00777975088983242, 0.024221902047949176, 0.016042301497821296, 0.04028374196163245, 0.053499948499458175, 0.03373748376699431, 0.33381347198571476, 0.33201174437999725, 8.667334045682635, 48.29680333818708, 26.684591429574148, 27.898144687925065, 20.07983534676688, 48.60343081610543, 47.96338708060128, 55.83648817879813, 40.441385405404226, 0.11977099813520908, 0.03415077266150287, 0.029834998172840903, 0.04667101600872619, 0.05149232283500688, 0.04123322958392756, 0.059976293838449886, 0.051995171566626856, 0.059494608614061556, 0.04885763581842184, 0.06717985908367805, 0.053985599761030505, 0.030673789592193704, 0.03237473439159138, 0.049272461594747644, 0.11953519364552838, 0.19901364243456296, 0.10741940127419573, 0.12806382243122372, 0.17086336868149893, 0.14984371087380818, 0.15176469779440335, 0.17158969970686094, 0.18740916012653283, 0.1797789524176291, 0.23337992121066364, 0.30146339216402596, 0.08933049906045198, 0.18487137130328588, 0.12443549212600503, 0.239521395947252, 2.9001023130757466, 65.9447135925293, 73.60088498251778, 66.54250185830253, 56.77553374426705, 39.524508067539756, 32.7043890953064, 43.03007575443813, 37.158125332423616, 14.746879271098546, 1.769140662891524, 0.1488894327942814, 0.4033641256392002, 0.29864234211189405, 0.43715440960867064, 0.5503832580787795, 0.1305750533938408, 4.743185596806662, 4.4067568608692715, 4.076402153287615, 82.33197743552071, 81.98394911629813, 92.3461172921317, 87.8400159563337, 87.42495836530412, 85.79317392621721, 86.51543222154889, 84.37140573774064, 81.7338695526123, 86.40695694514683, 90.15831020900181, 81.86493342263358, 87.07704816545758, 81.80583899361747, 81.03706945691789, 83.96659673963273, 74.67080334254673, 74.30091599055699, 73.09654998779297, 77.57286439623151, 72.33219255719865, 71.55266720908028, 74.38678182874406, 74.23818070547921, 72.39906202043805, 73.55566610608781, 70.50838770185197, 64.44036606379917, 68.67270142691476, 72.14194393157959, 67.55693190438407, 67.59723840441022, 66.93348394121442, 68.04800973619733, 67.66618537902832, 65.49879210335868, 63.046745027814595, 62.2700753893171, 62.509260177612305, 62.04667690822056, 60.168585777282715, 60.73883138384138, 58.74115480695452, 60.276908193315776, 57.82667112350464, 59.32881259918213, 72.22095884595598, 71.66276836395264, 72.57787391117641, 70.53242152077812, 70.73400265829903, 70.33981745583671, 69.20674691881452, 69.86488028935024, 69.34590544019426, 70.84609794616699, 72.21147455487932, 67.04692023141044, 60.45875644683838, 56.944444452013286, 53.87658200945173, 54.978291852133616, 53.89053051812308, 53.91554403305054, 55.06398745945522, 57.96770913260323, 56.173826694488525, 57.676815850394114, 58.82768767220633, 58.376054763793945, 61.842281750270296, 60.461327280317036, 59.370828356061665, 58.061085973467144, 60.47469561440604, 61.266116278512136, 60.53089264460972, 62.69153921944754, 62.35436398642403, 64.05364322662354, 63.40257617405483, 62.47781263078962, 59.88950443267822, 57.55050802230835, 58.93443979535784, 56.587699617658345, 62.092944962637766, 64.06790787833077, 61.85722732543945, 64.92077146257672, 67.01106752668107, 63.9851895741054, 66.95490523747036, 65.64810889107841, 67.07091236114502, 67.59391716548375, 67.04674652644566, 67.56572832380022, 67.77557781764439, 68.3433290209089, 69.22298485892159, 69.56688594818115, 58.93855312892369, 4.711051915373121, 0.2441379310829299, 0.27311932880963596, 0.704676475908075, 0.6578797070043427, 0.30167341232299805, 0.15240090579858848, 0.23611208317535265, 0.2281041485922677, 0.17387268505990505, 0.8453457962189401, 0.5182275378278324, 1.0341443653617586, 13.51137752192361, 56.64225687299456, 38.23090982437134, 48.027046476091655, 49.50803416115897, 57.9691230910165, 54.18338666643415, 64.88840675354004, 45.81325660433088, 0.3693244664796761, 0.1776524915226868, 0.15995205060711928, 0.10980783775448799, 0.13958403068993772, 0.14010598696768284, 0.18178464764995234, 0.083118158126516, 0.2341828452689307, 0.26071342879108017, 0.13953596326921666, 0.09142050226884228, 0.08777543250471354, 0.116877534825887, 0.13479704755757535], [0.049199485153492005, 0.07364445219614676, 0.08067606988229922, 0.038877552774335654, 0.03424161492979952, 0.13972763584128448, 0.04467929181243692, 0.06469207150595528, 0.07655386107840709, 0.09510849615825073, 0.054142945246504884, 0.06268004554190806, 0.056146750758801184, 0.02237769475738917, 0.06204042450657912, 0.26900469245655195, 6.496562208448138, 46.9995607648577, 40.4961302621024, 36.651657240731375, 33.52443633760725, 32.38751302446638, 40.99291951315743, 28.967686108180455, 11.06697346482958, 1.0148523662771498, 0.06124749526913677, 0.3262826018035412, 0.14609340711363725, 0.3448462613991329, 0.09737360889890365, 0.16129309364727565, 0.4167163377361638, 0.9923666928495679, 0.5750356838107109, 14.92033931187221, 77.17907524108887, 75.81501879010881, 83.22434847695487, 77.08698381696428, 83.43348925454276, 79.09693091256278, 79.73078727722168, 73.07780374799455, 79.57127748216901, 78.4349273954119, 77.39416367667062, 76.62463678632463, 78.68105343409947, 74.7861225945609, 74.56034088134766, 69.80924606323242, 63.54795333317348, 66.14951869419643, 69.23315007346017, 69.30070740836007, 67.74661077771867, 69.00818129948208, 67.41404914855957, 70.05827644893101, 65.91448892865861, 64.84689126695905, 61.766803468976704, 66.64566176278251, 67.43046774183, 67.52237156459263, 61.41778155735561, 65.17071206229073, 63.295594760349815, 61.45521150316511, 59.19155093601772, 57.8687424659729, 54.507374218532014, 56.6418399810791, 53.94964231763567, 56.0478002684457, 54.46838092803955, 54.90644400460379, 51.72625698362078, 49.86396605627877, 52.54106528418404, 61.347014154706685, 63.63705703190395, 63.67708560398647, 63.49820423126221, 64.04688957759312, 63.052567618233816, 64.04264422825405, 62.78054564339774, 63.526928084237234, 61.67139080592564, 62.03390611921038, 58.657706941877095, 61.7226893561227, 64.63454736982072, 59.347906248910085, 51.52853904451643, 47.85119104385376, 49.26427050999233, 50.652760301317485, 49.87572240829468, 50.681967054094585, 51.853895391736714, 51.538165773664204, 53.71598482131958, 53.13155794143677, 54.83021184376308, 55.23849146706717, 57.84535830361502, 55.89537068775722, 56.23684338160923, 57.38788196018764, 58.68640995025635, 56.76511492047991, 58.05962685176304, 54.3987842968532, 56.72821651186262, 56.48311880656651, 57.01082754135132, 53.93748297010149, 50.4676707131522, 50.458728381565635, 53.55122218813215, 55.47585235323225, 58.02457666397095, 60.14597633906773, 61.2379343850272, 58.19380351475307, 62.482572146824424, 61.505294118608745, 60.38486235482352, 62.120814187186106, 62.04455075945173, 60.22676999228341, 62.73255443572998, 61.9205184664045, 60.91614941188267, 63.00531986781529, 53.06593567984444, 13.408519864082336, 0.08530829274760825, 0.026449390021818023, 0.07739799935370684, 0.12420867143997125, 0.11083530940647636, 0.055051897186785936, 0.09399060971502747, 0.04102897697261401, 0.12415019529206411, 0.21327433149729455, 0.1910294158650296, 0.1133439347946218, 0.6728953612702233, 29.894169330596924, 36.84120062419346, 19.129040377480642, 35.27452775410244, 31.275547640664236, 33.943836552756174, 42.29051644461495, 44.87865093776158, 0.7088319329278809, 0.015868825538616096, 0.04121647316164204, 0.06122544966638088, 0.023308051084833484, 0.05580801929214171, 0.08925675587462527, 0.07712528255901166, 0.06793314151998077, 0.08170745668134519, 0.10988535359501839, 0.15149785711296967, 0.068654241040349, 0.04109381438632097, 0.05244337108784488, 0.06223308773977416, 0.09364048564540488, 0.0965711801712002, 0.0603520597464272, 0.00836651150270232, 0.07851319201290607, 0.12305041216313839, 0.025811628172440187, 0.0699714200038995, 0.06946767560605492, 0.02632768967721079, 0.08182021563074418, 0.075692318379879, 0.01917958109905677, 0.0759316308956061, 0.3450964508312089, 9.49995926448277, 59.72867447989327, 54.090767179216655, 55.03398166384016, 31.531144074031285, 24.237646068845475, 38.46818038395473, 33.17194727488926, 8.915827683040074, 0.6317158309476716, 0.07659620166357074, 1.4958096040146691, 0.3913331026477473, 0.5490440470831734, 0.09769652371427842, 0.1856697898890291, 0.29617274605802124, 0.674577205308846, 1.021617523261479, 21.700841392789567, 84.93449469975063, 77.32741233280727, 88.31067303248814, 79.48684297289167, 86.64033303941999, 80.81736046927315, 82.40792124611991, 77.49749728611538, 85.1489508492606, 79.79052094050816, 82.0194752556937, 79.72383213043213, 82.25847244262695, 78.33982045309884, 76.31837408883231, 72.16385160173688, 68.694796698434, 68.66815035683769, 72.9275072642735, 72.11930670057023, 73.00486850738525, 73.1384059361049, 71.96828065599713, 72.07996600014823, 70.73926244463239, 68.5024219240461, 65.33349445887974, 71.38128989083427, 68.22687026432583, 70.91890117100307, 66.41289016178676, 69.48045035770961, 66.11403424399239, 65.19408580235073, 65.28409276689801, 62.24989782060896, 57.77731112071446, 60.46259185246059, 58.33582469395229, 57.63826724461147, 58.21812220982143, 56.96251671654837, 54.9856847354344, 54.903359004429404, 56.39369549070086, 64.92703873770577, 67.11405372619629, 67.3237086704799, 66.60290949685233, 66.67565713609967, 64.55656773703438, 66.09849807194301, 65.61561911446708, 67.05656433105469, 66.6004776273455, 65.9574635369437, 64.16131251198905, 63.29292665209089, 66.25918906075614, 60.44081619807652, 53.78205871582031, 50.57363074166434, 51.73103734425136, 52.11362600326538, 51.404023851667134, 50.95489229474749, 54.84788458687918, 53.643056528908865, 55.36336101804461, 56.393077101026265, 57.68578944887434, 58.04005377633231, 59.594476972307476, 61.14207703726632, 60.4146214893886, 59.25874696459089, 60.22389343806675, 58.581207275390625, 61.83599363054548, 59.61678763798305, 59.3221492767334, 58.551434244428364, 59.85641016278948, 58.26083973475865, 54.97675977434431, 53.25962713786534, 56.15404517310006, 56.979404313223704, 60.903357778276714, 63.09327711377825, 62.45079108646938, 62.26458631243025, 63.68668106624058, 61.64022118704659, 61.725281034197124, 65.39923136574882, 65.23505238124302, 62.57604626246861, 64.64722088405064, 64.84284046718052, 65.20823233468192, 65.39388820103237, 57.353352887289866, 19.659842797688075, 0.2214152453733342, 0.0478212651796639, 0.1841404398104974, 0.0748793723593865, 0.20651614985295705, 0.11515033750661782, 0.07532587554305792, 0.04174179497307964, 0.07579780343387808, 0.2534747900707381, 0.019700185395777225, 0.12788432277739048, 0.335649099200964, 33.540236541203086, 41.226622172764365, 21.330080304827007, 21.893275226865494, 30.311360018593923, 49.17220687866211, 45.995129176548545, 54.83852883747646, 1.1314300021954944, 0.05274720549849527, 0.028068656168345894, 0.009015035765644695, 0.059213810467294285, 0.06250635414783444, 0.1119368499411004, 0.0940973772002118, 0.06065545989466565, 0.10705480405262538, 0.06673356624586241, 0.15646522199468954, 0.07131473613636834, 0.04712787702945726, 0.0487759232388011, 0.15731237296547207, 0.1299955437758139, 0.1620426984237773, 0.13607729386006082, 0.1484834924340248, 0.1879189841981445, 0.2108233951564346, 0.1553280380155359, 0.10929759299116475, 0.14752352823104176, 0.15099698970360415, 0.12189311640603201, 0.24542500344770296, 0.09783997958792107, 0.19895279141409056, 0.4573183261922428, 11.350378326007299, 73.98571790967668, 56.55322960444859, 53.00822741644723, 53.672787870679585, 47.485927718026296, 60.636526107788086, 45.865354197365896, 14.540205104010445, 2.4542780986854007, 0.2323943083839757, 3.1646788588591983, 0.7849149246300969, 0.9613691504512514, 0.24311293608375958, 0.32207668891974855, 1.1004284428698676, 3.8470920579774037, 1.1385823041200638, 22.155005182538712, 90.27072511400495, 81.90068885258266, 91.3141291482108, 83.94168049948556, 90.33607986995152, 85.34511239188058, 85.50401074545724, 80.65187522343227, 87.38677106584821, 85.1487215587071, 84.17880167279924, 82.4435099193028, 86.04107870374406, 81.88054602486747, 79.82863180977958, 76.70841816493443, 71.46798256465367, 70.34579985482353, 74.81755624498639, 76.86365481785366, 75.58523491450718, 76.12205273764474, 73.33228152138847, 76.22127996172223, 74.29806722913469, 71.95525278363908, 69.18092046465192, 73.13190242222377, 73.68968990870884, 75.40478324890137, 68.79906136648995, 71.88540254320417, 70.91159861428397, 67.05944088527134, 68.34517724173409, 66.3543654850551, 61.49268313816616, 63.383517265319824, 60.77099459511893, 63.71437658582415, 63.35958766937256, 61.80516447339739, 58.313618251255576, 59.28720678601946, 59.121401923043386, 65.07992689950126, 71.57716655731201, 68.27736282348633, 67.50040136064801, 69.22043487003872, 67.38959148951939, 68.42223971230644, 68.65950679779053, 68.64221273149762, 67.56674970899309, 68.45171397072929, 64.69806780133928, 66.11911337716239, 70.66652870178223, 63.47187055860247, 56.70513459614345, 53.102312973567415, 53.918698515210835, 55.640569823128835, 55.353379930768696, 54.52723911830357, 58.315890312194824, 55.46713236400059, 57.87913349696568, 58.47065448760986, 60.0613750730242, 60.47122846330915, 62.79822186061314, 62.36381353650774, 62.83773626599993, 63.25781740461077, 63.52708789280483, 61.361000878470286, 65.8188956124442, 59.82243347167969, 61.99849115099226, 61.423326219831196, 63.03983851841518, 62.258805411202566, 57.132636410849436, 55.77640363148281, 59.74409948076521, 60.63695689610073, 62.9515824999128, 65.80398477826799, 67.2050473349435, 65.05161299024309, 67.07378196716309, 64.84575176239014, 64.33778285980225, 67.90208366939, 68.46267822810582, 65.74295180184501, 68.42076669420514, 67.5700431551252, 68.03132016318185, 68.93869236537388, 64.1891678401402, 21.98856803349086, 0.5494621332202638, 0.26947008605514255, 0.4463638940027782, 0.3700109267873423, 0.3218263637806688, 0.138949329033494, 0.17058823630213737, 0.11159353836306504, 0.35038687980600763, 0.37841311735766275, 0.24717774082507404, 0.21304901715900215, 1.086886078119278, 45.901599475315635, 48.995427336011616, 31.469819273267472, 48.69418818610055, 48.844752175467356, 49.04136882509504, 56.211718695504324, 63.670033182416645, 1.8964005027498518, 0.24500602164438792, 0.15852624497243337, 0.1517057873840843, 0.09663681486355406, 0.14336983540228435, 0.17921671830117702, 0.12122423015534878, 0.08182710276118346, 0.13839366313602242, 0.1944429762661457, 0.3112320979791028, 0.1748487576842308, 0.08036093786358833, 0.15198326749461039], [0.10349096850092922, 0.08596626136984144, 0.11021088755556516, 0.10710799441273723, 0.1181897401277508, 0.06983464770019054, 0.049546532066805024, 0.017540437269157598, 0.03791184816509485, 0.07188681579594101, 0.08310264003063951, 0.057860553796802244, 0.04003711823107941, 0.0572021644828575, 0.11005327744143349, 0.05462668303932462, 21.423537049974712, 54.75707857949393, 42.58519302095686, 34.57723433630807, 38.660266808101106, 34.80351284572056, 32.26773302895682, 21.93289906638009, 1.9733348659106662, 0.024636624347684637, 0.056314281054905484, 0.24865721857973508, 0.2757860528571265, 0.47092306188174654, 0.1812608050448554, 0.09498352357851607, 0.14030257213328565, 0.6054487632853645, 0.7299878405673164, 35.858641965048655, 80.75944028581891, 75.06109755379813, 81.47843292781285, 74.41540145874023, 78.19639573778424, 77.68087414332798, 77.49471105848039, 75.15844181605748, 80.49834782736642, 74.74802562168666, 77.00676686423165, 72.47729873657227, 78.84061881474086, 72.73425701686314, 69.68015548161098, 68.58467469896588, 65.83908707754952, 69.76863384246826, 71.80968107495988, 65.5207553591047, 72.05160345349992, 71.60152694157192, 73.45213794708252, 69.34320953914097, 68.63667501722063, 63.375783920288086, 66.15763419015067, 68.92003645215715, 69.19775594983781, 68.04616846357072, 67.7384535925729, 65.90906238555908, 62.57153688158308, 60.4714994430542, 61.954710551670615, 60.275588035583496, 55.62682628631592, 56.97544036592756, 53.91823993410383, 52.594055720738, 55.26301860809326, 51.95439761025565, 50.64204270499093, 51.42076901027134, 55.190277917044504, 61.521698815482004, 67.10848821912492, 65.87993553706578, 66.70686149597168, 65.74344512394497, 65.19658020564488, 63.94911452702114, 62.06645842960903, 64.22201197487968, 60.674650873456685, 64.96600423540387, 63.61732414790562, 58.93232754298619, 56.4778208051409, 54.163278579711914, 52.871778692517964, 45.91149718420846, 47.888016496385845, 48.027595383780344, 48.04943009785244, 48.47098078046526, 48.84939009802682, 52.3733183997018, 53.17771829877581, 55.05082062312535, 56.21898998532976, 56.51238809313093, 57.672118868146626, 57.960733141217915, 57.652382510049, 56.049478258405415, 56.058121817452566, 57.73889453070504, 57.21872806549072, 57.7948032106672, 59.23653357369559, 56.48821531023298, 55.964077949523926, 54.95073182242257, 53.42262492861067, 51.58663640703474, 51.511342253003804, 51.29533665520804, 55.54600831440517, 60.254166739327566, 58.17778444290161, 61.17121083395821, 59.801797321864534, 58.675654138837544, 59.417013032095774, 60.78288296290806, 63.367216791425435, 62.29427596500942, 61.464390073503765, 59.85702855246407, 63.235576220921104, 62.9701828275408, 53.26511968885149, 30.58303110940116, 0.04800342469077025, 0.15390443083431038, 0.19350642152130604, 0.09566916285880975, 0.02740195649676025, 0.1886953775371824, 0.04687570288245167, 0.02939040506524699, 0.01936339114659599, 0.15467311601553643, 0.117725866447602, 0.18698588998189994, 0.12924554544900144, 15.049348252160208, 62.901395661490305, 23.879673140389578, 27.52290722302028, 38.542838777814595, 17.98695281573704, 34.963262353624614, 43.58875955854143, 1.2528610633952277, 0.1181209095354591, 0.04979407521230834, 0.036026837171188424, 0.0549622016426708, 0.07693692802318505, 0.06686698658657925, 0.03867919663233416, 0.1236979788435357, 0.047530977720660825, 0.1047155342197844, 0.05267906022657241, 0.18845995302711213, 0.014219549484550953, 0.06689759530127048, 0.11730624682136945, 0.055931078403123786, 0.0703090318877782, 0.033181770372071435, 0.08364056223737341, 0.05015852654884968, 0.036530201589422565, 0.046122111712715456, 0.10625781039042131, 0.14327912884099142, 0.06305446795054845, 0.0544904908830566, 0.02804330949272428, 0.03965273492836526, 0.12774831721825258, 0.05539223678143961, 30.430288859776088, 63.87952136993408, 64.59222589220319, 46.79687833786011, 25.71577630724226, 34.42253964287894, 38.21617616925921, 23.794168608529226, 1.2816378963845116, 0.02340375166386366, 0.16344178334942885, 0.24110265395471028, 0.3394073418208531, 0.8241106356893266, 0.4756120645574161, 0.09480612059789044, 0.297600329454456, 1.5638065210410526, 0.6006101572087833, 42.8641597202846, 84.67981542859758, 79.7233110155378, 85.16079057965959, 77.50081852504185, 81.6641652243478, 80.05963856833321, 81.01113183157784, 79.76274899074009, 80.96455805642265, 78.45145715985979, 80.17444365365165, 76.6099135535104, 80.5055044719151, 74.76743194035122, 72.81924738202775, 70.90154457092285, 70.8862863268171, 73.90604986463273, 74.84098557063511, 69.45704187665666, 74.83605234963554, 74.98889882223946, 75.77600465502057, 70.92092309679303, 72.51848765781948, 69.10431657518659, 70.59841551099504, 73.12732355935233, 72.3068733215332, 68.9566673551287, 71.88401985168457, 68.69221891675676, 65.93358257838658, 64.52688503265381, 66.20881462097168, 62.61408764975411, 57.57411452702114, 58.71826049259731, 57.26298461641584, 55.21980776105608, 55.696537562779014, 54.53092513765608, 54.249596050807405, 53.89794077192034, 58.672277314322336, 63.84421757289341, 67.68967723846436, 68.13186754499162, 68.72264507838658, 67.36615521567208, 67.9164594922747, 65.43057468959263, 66.51611954825265, 66.15387521471295, 61.11076845441546, 63.728592600141255, 65.12864766802106, 62.40512752532959, 61.60056781768799, 58.84471075875418, 55.038428510938374, 48.40233257838658, 50.305312156677246, 50.314282281058176, 51.333930424281526, 50.41234220777239, 52.6467022214617, 54.52578347069876, 55.149846349443706, 54.879273074013845, 58.73419966016497, 58.114305700574604, 60.56063788277762, 60.39411040714809, 61.0220399584089, 58.887435231889995, 58.5530948638916, 60.87115287780762, 59.86670739310128, 60.750789233616416, 63.237250736781526, 59.90999467032296, 59.392075947352815, 58.60400431496756, 57.933874879564556, 54.150886467524934, 54.23907995223999, 53.74734551565987, 58.01439755303519, 64.03579330444336, 60.806048257010325, 62.92342145102364, 60.805791173662456, 62.06176144736153, 62.2831449508667, 61.24695314679827, 65.43602207728794, 64.49631990705217, 65.59840842655727, 63.32319300515311, 64.99562440599713, 66.35020351409912, 59.666627066476, 40.46560682569231, 1.3732370840651649, 0.20748597995511123, 0.13021751972181456, 0.42135781581912723, 0.1531132182904652, 0.4853645126734461, 0.3061148039996624, 0.04471191916880863, 0.03702826325648597, 0.09418102699731078, 0.05517796899325081, 0.3191042441342558, 0.06223302667162248, 19.388275929859706, 64.01035594940186, 30.43682016645159, 26.273789610181534, 30.12952218736921, 33.1880601474217, 43.72795976911272, 53.32970666885376, 2.620044312306813, 0.12247139109032494, 0.08396501732724053, 0.05514379118436149, 0.06693828026098864, 0.12032413988241128, 0.06789373899144785, 0.036232636842344484, 0.1292576640844345, 0.02436166669109038, 0.06582612065332276, 0.056296774851424355, 0.1632587824548994, 0.05511893305395331, 0.06836150746260371, 0.1907122821680137, 0.10643598690096821, 0.17634507667805466, 0.1412184587014573, 0.17073051152484758, 0.18608679037008966, 0.1343051775225571, 0.10591850895434618, 0.17009152152708598, 0.20018754872892583, 0.12044223211705685, 0.22336265444755554, 0.15671648351209505, 0.14239293496523583, 0.29924884385296274, 0.29196637177041596, 35.588197231292725, 78.3759719303676, 64.23902811322893, 58.81058815547398, 58.12321329116821, 57.18477916717529, 52.20307016372681, 33.269989831107004, 3.0531444208962575, 0.26489697716065813, 0.2010062419410263, 0.6976610209260667, 1.0696329410587038, 1.647621663553374, 0.8565510692340987, 0.2426909687263625, 0.3614139152424676, 2.4619823481355394, 1.2642794506890433, 44.77413613455636, 90.87317562103271, 83.02720029013497, 89.23102446964809, 82.06825855800084, 85.44303335462297, 83.2381545475551, 85.35322788783482, 82.17878355298723, 86.32428727831159, 81.24712739671979, 85.09248978751046, 80.19970035552979, 84.90964794158936, 78.08154896327427, 77.1049588067191, 74.51972171238491, 73.04214559282575, 75.2912288393293, 78.47109971727643, 71.30358123779297, 77.96572944096157, 80.11115946088518, 79.14861161368233, 75.87100042615617, 75.22097560337612, 70.63576902662004, 72.7797051838466, 74.65113299233573, 76.32796260288784, 72.2910383769444, 75.130982535226, 73.2086591720581, 71.13194683619908, 66.69194371359688, 70.22844478062221, 67.17221709660122, 62.68115861075265, 62.51734788077218, 61.56359645298549, 57.56588438579014, 61.419775690351216, 57.76724318095616, 57.94615234647478, 56.83523614065987, 61.99672630855015, 68.02788775307792, 71.94138417925153, 72.48166220528739, 74.10282979692731, 72.26726858956474, 71.01980291094098, 69.47929000854492, 67.96538175855363, 70.4464306150164, 65.76080172402519, 68.81525761740548, 68.14745235443115, 65.48449271065849, 62.61216994694301, 61.1446339743478, 57.90249334062849, 50.144047941480366, 53.88295350755964, 52.30954435893467, 53.906907422201975, 52.71973821095058, 56.058274677821565, 58.303953307015554, 59.286637033735005, 59.5642523084368, 60.75299876076834, 62.1064453125, 62.201093673706055, 63.92344788142613, 61.93030847821917, 60.59728268214634, 61.501667158944265, 63.17751012529646, 63.00677898951939, 62.825882639203755, 64.70360551561627, 62.65301145826067, 61.41310541970389, 60.89834117889404, 59.86275386810303, 57.24945647375924, 59.12794017791748, 56.38441269738333, 62.68537616729736, 66.8913014275687, 64.69769954681396, 66.63373865400041, 64.97033296312604, 64.71290915352958, 63.308990887233186, 62.97975049700056, 67.96811934879848, 66.04826954432896, 67.69681303841728, 65.07698781149728, 68.01283795492989, 70.26238673073905, 63.209277289254324, 44.59803751536778, 2.1431073674133847, 0.6231048415814127, 0.719555771776608, 1.1518694311380386, 0.40208139589854647, 0.5281333348580769, 0.30337292541350636, 0.19746162928640842, 0.18055597000888415, 0.2612811726118837, 0.19958548460687908, 0.5668604224920273, 0.4257959776691028, 22.063839605876378, 73.00287437438965, 37.85603713989258, 43.51341676712036, 51.34162902832031, 28.330610990524292, 49.69811603001186, 62.94973427908761, 3.6404765163149153, 0.3473730443843773, 0.2538710545216288, 0.16645280963608197, 0.25119187257119585, 0.20324229981218064, 0.14462737792304584, 0.18014214507171086, 0.15364113210567407, 0.09791412310940878, 0.12968246771820954, 0.17624503347490514, 0.20106118970683642, 0.0626362461064543, 0.14869086630642414], [0.10321736282535962, 0.14319162496498652, 0.0593104949221015, 0.12274021309401308, 0.030598472205123732, 0.03178923670202494, 0.10258861192102943, 0.06799574994615146, 0.015250284889979022, 0.08732196076640061, 0.032967377054904184, 0.05824930686503649, 0.03457213951540845, 0.04627841225426112, 0.19862436689436436, 3.7187905311584473, 48.990897110530305, 40.701553753444124, 25.25156889642988, 28.135172060557775, 24.077239956174576, 29.651854378836497, 35.56266260147095, 4.398337381226676, 0.036666146080408774, 0.09210606012493372, 0.09970535377838782, 0.026504517599408115, 0.057729569396802356, 0.24665958434343338, 0.28182726725935936, 0.27661980954664095, 0.8455096217138427, 0.9810855324779237, 0.1938028870416539, 44.6420647757394, 78.22792666299003, 77.3090135029384, 75.60300840650285, 74.76893275124687, 81.81166853223527, 76.91466154370988, 75.34673104967389, 75.66758496420724, 76.41415500640869, 75.07429913112095, 72.52449784960065, 73.3836703981672, 77.08189078739711, 69.90046201433454, 69.29715687888009, 67.36466135297502, 66.99462114061627, 72.09316062927246, 67.62044538770402, 71.84881332942417, 70.99799946376255, 72.17855398995536, 70.6194407599313, 68.46627044677734, 65.11329214913505, 67.67359215872628, 70.22504711151123, 70.55654566628593, 68.8254645211356, 69.13658400944301, 67.6005665915353, 65.85582528795514, 62.90052713666643, 61.24638339451381, 59.13148375919887, 56.4905811718532, 54.05411195755005, 53.36294337681362, 51.52384901046753, 53.724993160792756, 51.55417789731707, 51.74939101082938, 50.609017917088096, 51.26633487428938, 59.616301264081685, 66.47381196703229, 63.455479758126394, 65.1733454295567, 60.77879047393799, 57.98974534443447, 59.691529410226, 55.92032861709595, 60.75197042737688, 57.31861884253365, 51.03868062155587, 53.13628619057791, 60.52573708125523, 60.10517651694161, 62.41321522848946, 58.296741076878135, 51.92260265350342, 47.5203595161438, 48.25861256463187, 47.91891166142055, 47.87383869716099, 46.65705278941563, 47.86010210854666, 47.855773380824495, 49.221278531210764, 53.01732955660139, 53.9642265864781, 54.02961608341762, 55.7496600151062, 57.34773179462978, 59.54504748753139, 61.0055935723441, 59.06979070390974, 57.343670572553364, 56.917544501168386, 57.84358303887503, 60.05251611982073, 58.02123805454799, 56.79339061464582, 55.15912914276123, 56.5434569631304, 54.037259101867676, 51.47563198634556, 50.96209410258702, 52.04425171443394, 58.42276055472237, 60.044956479753765, 56.63826165880476, 58.75496782575335, 58.807781083243235, 59.42753260476248, 59.29039600917271, 61.218472480773926, 60.92101315089634, 60.785356521606445, 61.31992312840053, 62.22898374285017, 60.02010972159249, 64.285858971732, 51.722602231161936, 7.9172230277742655, 0.3670123176915305, 0.13440557356391633, 0.08650143550974981, 0.013800051994621754, 0.06915320176631212, 0.07421705432768379, 0.14727944561413356, 0.09957605893058435, 0.15320533620459692, 0.4079520265970911, 0.061523618309625556, 0.08321081886866263, 17.17925947053092, 23.59848996571132, 34.01433992385864, 24.105251618794032, 33.006413391658235, 28.382826702935354, 29.581135613577707, 48.93041998999459, 3.8837729011263167, 0.26756370120814865, 0.14910720182316645, 0.08071805762925319, 0.08795347330825669, 0.08204647991806269, 0.15524869013045514, 0.028168288857809136, 0.17852314694651536, 0.013994321659473436, 0.1753328652786357, 0.015131247795319982, 0.20943500394267694, 0.04765130572819284, 0.08391587782119002, 0.09595605425004448, 0.13993262127041817, 0.04519017439867769, 0.10351199630115714, 0.014736284435327564, 0.0808490284585527, 0.017382523510605097, 0.02539923833683133, 0.035927503037133386, 0.0396031170551266, 0.017545690826539482, 0.046448551517512114, 0.041472314790423424, 0.12514830673379557, 0.22152476092534407, 6.377204316002982, 60.00763075692313, 55.233676365443635, 47.97669635500227, 29.881707736424037, 20.9683484009334, 36.740041800907676, 37.39393329620361, 4.698170389447894, 0.04422492780057447, 0.14314861941550458, 0.050375705252268484, 0.1380312711532627, 0.056548816684101305, 0.3086131970797266, 0.277773237654141, 0.27247738039919306, 1.588318897145135, 0.8347145638295582, 0.47171939057963236, 53.84443964276995, 81.45255088806152, 81.92668901171002, 80.3325777053833, 79.7587468283517, 84.52282782963344, 77.51285280500139, 81.21702780042375, 77.52080849238804, 80.45379597800118, 79.90968254634312, 76.71711036137172, 77.26990209306989, 80.44243567330497, 71.91490459442139, 73.40263203212193, 68.84730965750558, 70.56810052054269, 75.05717182159424, 71.78002616337368, 73.91235188075474, 74.03737081800188, 77.69122001102993, 72.20499883379254, 72.22637149265834, 68.60116972242082, 73.11747796194894, 74.46726976122174, 74.7722887311663, 71.70365156446184, 71.84320613316127, 69.0369815826416, 69.40762628827775, 66.64450141361782, 65.87280668531145, 60.79380553109305, 59.47603103092739, 57.21975639888218, 57.607118470328196, 53.24993092673165, 57.36903844560896, 53.96536956514631, 54.409411566598074, 52.51983853748867, 55.314275469098774, 62.680429049900596, 68.67338235037667, 66.4003347669329, 66.63342598506382, 63.474483081272666, 59.51979078565325, 59.657830647059846, 57.67541578837803, 62.520724705287385, 59.05422673906599, 54.5740248135158, 55.057952948978965, 64.13854326520647, 65.16659872872489, 64.61993530818394, 61.536310877118794, 53.81796700613839, 49.83644076756069, 50.213119983673096, 50.340376240866526, 50.469192368643625, 49.8263589314052, 50.4881922176906, 51.340670176914756, 51.83630950110299, 53.67264543260847, 56.7094772202628, 56.059844970703125, 58.60348320007324, 60.075049127851216, 62.6130245753697, 62.06939056941441, 61.154604639325825, 59.95544283730643, 58.12523174285889, 60.653417178562705, 61.662837573460166, 62.632125173296245, 60.425995690482004, 58.410142626081196, 57.095126560756135, 58.115848200661794, 53.49068600790841, 53.040529591696604, 55.13472012111119, 61.47828647068569, 60.89574950081961, 59.7835305077689, 60.13651289258684, 60.97336087908064, 61.64579364231655, 61.34157371520996, 62.12648391723633, 64.04412419455392, 62.68056106567383, 62.83696501595633, 63.809087480817524, 63.50259549277169, 67.31619071960449, 58.60747146606445, 17.871586663382395, 0.3546643645635673, 0.09872900974005461, 0.2277171393590314, 0.1002198461709278, 0.134386968133705, 0.41065821424126625, 0.38878121386681286, 0.06282331142574549, 0.07925152632274798, 0.4486892335116863, 0.08223469874688558, 0.2655636513871806, 23.603798389434814, 19.154448202678136, 32.25823136738369, 30.117765835353307, 22.926786763327463, 31.609446798052105, 38.52875477927071, 57.80657345908028, 6.488482322011675, 0.40770419846688, 0.29131584667733734, 0.12317401410213538, 0.10096103032784802, 0.1133903262338468, 0.1289156281522342, 0.03960903388048921, 0.08611897924648863, 0.04640813457912632, 0.1112771781959704, 0.021452766710094044, 0.12694839228476795, 0.04389616401333894, 0.08439067591513906, 0.16470849966364248, 0.36097425169178415, 0.10377895911889416, 0.19043378425495966, 0.09778643638959952, 0.13148686875190052, 0.1932129958378417, 0.12382022371249539, 0.12988931233329432, 0.19313485574509415, 0.1089194386399218, 0.17947912136358873, 0.1386050810771329, 0.24623327436191694, 0.29304404822843416, 6.794337681361607, 75.42667007446289, 59.74767780303955, 44.042098249707905, 44.04223721367972, 39.11331020082746, 47.449095317295615, 53.58378144672939, 8.932069965771266, 0.10907885365720306, 0.2539969634796892, 0.2033862035189356, 0.22644519832517418, 0.24400029703974724, 0.9493698286158698, 1.615418283002717, 0.37806530030710356, 1.8078729616744178, 3.1962523417813435, 0.769815132021904, 64.98491723196847, 85.51880346025739, 86.86136218479702, 83.60460254124233, 84.7006322315761, 89.12390409197126, 82.85627460479736, 82.98003591809953, 81.0614298411778, 85.19790785653251, 81.76652608598981, 79.50869505746024, 80.68875626155308, 84.80364622388566, 76.7806099482945, 76.823424748012, 73.77284594944545, 73.68939113616943, 77.91277027130127, 74.9837293624878, 76.87740530286516, 76.72616386413574, 79.80040822710309, 75.94536699567522, 75.01387759617397, 70.93916906629289, 73.45734909602574, 77.17655999319894, 77.05108942304338, 75.37013258252824, 74.76593807765416, 74.17098467690604, 72.35667106083461, 70.52971867152623, 70.64397484915597, 65.86626148223877, 63.88860266549246, 60.71074676513672, 60.01145921434675, 56.414418492998394, 61.7936304637364, 59.53531306130545, 57.794997760227744, 57.04670803887503, 58.628670419965474, 64.22105312347412, 72.03967339651925, 68.67863518851144, 70.91938059670585, 65.97919750213623, 62.99234758104597, 61.85962445395333, 59.84178420475551, 63.7064208984375, 61.23288999285017, 55.723406246730256, 59.16726003374372, 66.91327857971191, 66.18070220947266, 67.55316598074776, 62.78084441593715, 56.20008046286446, 54.123851026807515, 54.76273788724627, 53.300871644701274, 53.36620903015137, 51.8332314491272, 53.2263001033238, 54.09531824929373, 54.28601155962263, 57.55920021874564, 60.02220112936837, 58.973057883126394, 59.95176029205322, 62.918536867414204, 65.25542449951172, 64.98718234470913, 62.84026541028704, 62.63561316898891, 61.111685616629465, 64.20540578024728, 65.53885541643415, 63.23690332685198, 62.69984231676374, 61.80184323447091, 60.651499475751606, 59.271295411246165, 56.96711294991629, 56.81650032315935, 57.58750370570591, 64.1294480732509, 65.7991418838501, 61.38214424678257, 63.01542254856655, 63.32857091086251, 64.79077761513847, 65.88903072902134, 65.06978252955845, 66.95363371712821, 65.42195197514125, 65.90237127031598, 67.77728012629917, 67.73226969582694, 68.36447933741978, 61.85237748282296, 17.792658601488384, 0.48616523827825275, 0.19967216067016125, 0.4858281420809882, 0.20849622360297612, 0.15048489932503017, 0.38819202833942, 0.40146886876651217, 0.23011196085384913, 0.49045417670692715, 0.61782627339874, 0.17130495927163533, 0.31862237570541246, 28.24012460027422, 33.956131390162874, 41.35082817077637, 36.79440450668335, 44.73442023141043, 41.410165786743164, 40.16350609915597, 69.1777868270874, 6.712807084832873, 0.5090599868978772, 0.3727408360157694, 0.1949206513485738, 0.16464652227503912, 0.17183239811233111, 0.18905926229698317, 0.1381141474204404, 0.22907168524605886, 0.1020474870290075, 0.21678357890674047, 0.16645207681826182, 0.22398940367358072, 0.11928622557648591, 0.20882498739021166], [0.06945183859871966, 0.02724758469100509, 0.019140853712867414, 0.08185860035674912, 0.025596629262768796, 0.038281008534665616, 0.07437723608953611, 0.031601611591343365, 0.05988923101020711, 0.06702453563255922, 0.0751687471887895, 0.080413320767028, 0.018735540997503058, 0.04657253682879465, 0.06266695660139833, 14.213043093681335, 53.04065465927124, 33.815756934029714, 37.98243529456002, 38.18445764269148, 21.30889524732317, 38.6435147012983, 14.85654616355896, 0.9436763226985931, 0.06805104376482111, 0.10500328056514263, 0.06436663254031114, 0.2051439077726432, 0.06625443231314421, 0.11190990531550986, 0.0619717092652406, 0.3392789901367256, 0.8242312520742416, 0.11090848262288741, 1.5131604501179285, 49.71139751161848, 79.06679657527378, 75.07653645106724, 75.53070545196533, 72.76214708600725, 73.45356927599225, 74.61661434173584, 74.54714625222343, 73.94466795240129, 74.01005744934082, 75.10914434705461, 72.30082144056047, 73.53605828966413, 72.16788850511823, 66.70763969421387, 71.37789222172329, 65.05535112108502, 72.48273917606899, 72.1133451461792, 71.31125204903739, 69.54883452824184, 70.17486027308873, 68.86063630240304, 68.42672824859619, 66.92755017961774, 66.80442115238735, 73.90559823172433, 69.56312002454484, 69.94867556435722, 67.91488919939313, 69.75932325635637, 66.94609492165702, 64.5614731652396, 61.578097343444824, 60.04648508344378, 57.14107847213745, 57.289269651685444, 51.88043056215559, 54.67218548910958, 51.99321372168404, 50.90912103652954, 52.44729239600045, 51.565847396850586, 49.356466157095774, 51.213132517678396, 58.42977128710066, 61.52021884918213, 65.04821532113212, 60.45694991520473, 54.96187673296247, 55.598696504320415, 57.983172348567415, 59.442756107875276, 59.44910676138741, 57.29878173555647, 57.88486576080322, 58.74546269008091, 59.93251378195626, 62.53428064073835, 61.60212421417236, 60.037299564906526, 50.96638808931623, 45.98311921528408, 46.66882651192801, 45.556604044778005, 46.34900787898472, 48.40337480817522, 47.46915476662772, 46.85997840336391, 46.618153299604145, 49.375796045575825, 49.31758056368147, 56.65327671595982, 57.30478497913906, 57.8015707560948, 57.488436290196006, 58.31680052621024, 59.87747015271868, 59.624131883893696, 57.621584619794575, 57.16014085497175, 57.233187266758506, 58.59255368368966, 57.592461245400564, 58.889151436941965, 54.73210675375802, 57.781038829258506, 53.57465846197945, 51.89211048398699, 49.021159989493235, 54.98423603602818, 57.94303955350603, 58.624056816101074, 56.262631620679585, 58.33344841003418, 59.19639383043562, 56.580890383039204, 58.091821329934255, 59.75327805110386, 59.032194001334055, 60.97632775987898, 58.422301973615376, 60.63938876560756, 63.95450632912772, 59.42280782972063, 51.97405753816877, 4.107922221933093, 0.583792042519365, 0.10290181690028735, 0.16815861953156336, 0.4022460899182728, 1.4572183319500513, 0.17818959270204815, 0.03531961029927645, 0.053956656849810054, 0.7100312571440424, 0.177817361961518, 1.341693130987031, 18.344776357923234, 2.3988838025501797, 10.459656613213674, 30.338451044900076, 31.44936725071498, 55.09133904320853, 24.188633475984844, 51.9675783429827, 14.162390725953237, 0.34827031195163727, 0.05911264768136399, 0.08925527666828462, 0.06795871550483362, 0.06432606971689633, 0.06189105859292405, 0.09652442910841533, 0.0972432487511209, 0.07411806285381317, 0.08369002744023289, 0.0997404543949025, 0.049453165648239, 0.06717924161681108, 0.09474919150982584, 0.05545166627104793, 0.0507804853176432, 0.029010150648121322, 0.0411198531676616, 0.027971776634720818, 0.026081552795533623, 0.046912913742874346, 0.06739251195852246, 0.06426196851368461, 0.04990987399859088, 0.041141868236341646, 0.08070947416126728, 0.03489699154826147, 0.05574006061734898, 0.18906189501285553, 19.25849747657776, 63.32084451402937, 50.027415479932515, 41.50519977297102, 22.389077833720616, 25.531715052468435, 46.85164056505476, 14.699595042637416, 0.390131091432912, 0.13630591944924422, 0.06581954564899206, 0.10956247270639453, 0.20852477635656083, 0.07709451099591595, 0.1911755587373461, 0.06360196428639547, 0.5187193400093487, 0.8485029925193105, 0.2064005003443786, 3.889225934232984, 58.91060747419085, 81.25478431156704, 80.81842354365757, 78.61027908325195, 77.56441538674491, 78.3277861731393, 79.49709156581334, 76.91797583443778, 78.07823467254639, 76.72047328948975, 79.11924157823834, 76.18381527491978, 74.68639510018485, 73.99930163792202, 71.01258373260498, 73.31652995518276, 67.16677665710449, 74.23290702274868, 74.99046216692243, 75.05759566170829, 72.05579321725028, 75.37799099513462, 72.21692194257463, 71.55655125209263, 68.93248067583356, 70.45476150512695, 76.0983315876552, 73.13755130767822, 73.36025496891567, 72.05101285661969, 70.80044133322579, 70.18449742453438, 67.36888585771833, 65.21886307852608, 62.73245021275112, 59.160999706813264, 59.26486832754952, 56.71219744001116, 56.5806610924857, 54.483871936798096, 51.6995724269322, 54.57433748245239, 52.98483977999006, 52.71953671319144, 52.78329338346209, 61.732639176504954, 65.12683418818882, 66.36238370622907, 63.14732715061733, 57.057738304138184, 59.21847520555769, 59.46096733638218, 62.536434582301546, 61.20017787388393, 61.48977184295654, 61.43480464390346, 61.05339023045131, 63.610049383980886, 64.81138597215924, 65.89945302690778, 60.999006680079866, 53.44493212018694, 48.308250495365684, 49.76874794278826, 48.77265419278826, 49.1024226461138, 49.87550701413836, 49.54203864506313, 49.506661891937256, 49.2260172026498, 49.26918288639614, 52.54952819006783, 58.30854606628418, 58.35459872654506, 59.10702610015869, 58.650717054094585, 61.1734551021031, 62.963436126708984, 61.38837678091866, 60.47219426291329, 60.101348059517996, 61.175810541425435, 60.63245446341378, 59.2744151524135, 60.365351813180105, 57.85861546652657, 60.307459422520225, 56.758430753435405, 55.21715007509504, 50.931591510772705, 57.845274925231934, 59.07337597438267, 59.88000624520438, 59.01592826843262, 61.78557055337088, 60.313240323747905, 59.95692975180489, 61.39512348175049, 61.119564873831614, 62.27924701145717, 62.611030442374094, 62.33918217250279, 62.79280226571219, 66.66714559282575, 63.81058134351458, 60.39896024976458, 9.75346429007394, 0.7986271945493562, 0.4479279172207628, 0.07601705845445395, 1.0782373079231806, 1.635552534035274, 0.5468613899179867, 0.08887973467686347, 0.30850080453923767, 1.0431481450796127, 0.17353446249450954, 4.884855891977038, 28.114358731678553, 2.0626431022371565, 6.190279100622449, 36.875093936920166, 28.02296733856201, 44.422321047101704, 34.70138822283064, 58.82738195146833, 20.529894488198416, 0.3380081211881978, 0.03819535366658654, 0.12691347487270832, 0.05228158798334854, 0.09436784804399524, 0.04996755965320127, 0.05833698037479605, 0.03714196536956089, 0.041157410080943785, 0.022483244272215024, 0.09113330553684916, 0.041809237961258204, 0.008207529899664223, 0.10098887740501336, 0.1828795046146427, 0.1785523782351187, 0.18229743013424532, 0.21309806167015008, 0.10293217455702168, 0.2763768397271633, 0.14571326465478965, 0.09485997592232057, 0.13210555698190415, 0.16394507991416113, 0.17583397696060793, 0.14177713729441166, 0.09062553742634398, 0.1191283440483468, 0.3006788156926632, 23.83989817755563, 78.93302290780204, 48.93363005774361, 56.56452737535749, 59.77569988795689, 38.84837886265346, 64.74210548400879, 22.49982864516122, 1.3928437062672205, 0.21829633201871598, 0.1320803426206112, 0.16625431100172655, 0.3240703876529421, 0.24546853825449944, 0.17464189949844564, 0.2591318722282137, 0.833894784961428, 2.547580246414457, 0.522137853716101, 4.4147603171212335, 66.40831824711391, 82.06203992026192, 84.92036206381661, 82.51197746821812, 80.6752211706979, 80.35940470014299, 81.95754596165249, 80.1267442703247, 82.84866632734025, 78.69246237618583, 82.5192869731358, 79.87451076507568, 77.13588523864746, 78.03266838618687, 74.33763722011021, 77.10783536093575, 68.97437831333706, 76.91961560930524, 79.22348540169853, 76.99731036594936, 73.64277567182268, 77.93681798662458, 75.15022209712437, 75.43698814937046, 73.213043485369, 72.84221812656948, 78.65360110146659, 75.44652802603585, 76.6802293232509, 73.67918423243931, 74.19515051160539, 73.92809649876186, 70.86974961417062, 69.1640293938773, 66.25274808066231, 62.78627095903669, 63.60352502550398, 58.61880397796631, 62.833497864859446, 57.73167187826974, 56.53467444011143, 59.94494410923549, 58.63685539790562, 53.89856610979353, 57.260962690625874, 64.90889699118478, 68.60541507175991, 69.47296714782715, 64.6161276953561, 57.75119284221104, 59.51393345424107, 60.32174491882324, 64.17628587995256, 63.53926113673619, 61.52479771205357, 62.161878040858674, 61.17956951686314, 64.96818596976144, 66.6192238671439, 68.40652983529228, 64.51114736284528, 54.951982498168945, 50.04663072313581, 52.59669256210327, 51.04605613436018, 51.24476766586304, 52.06163610730852, 53.33955921445574, 51.703220231192454, 52.24935211454119, 52.80868904931204, 54.392860957554404, 61.86479391370501, 60.950841767447336, 61.539229120527, 60.78427260262625, 66.10991396222795, 65.14896420070103, 63.93234157562256, 64.11589213779995, 62.35988780430385, 64.80400003705705, 64.18345642089844, 62.435720443725586, 63.05091394696917, 60.76406724112374, 62.951269830976216, 58.551712172372, 58.09289482661656, 54.55583790370396, 62.217178753444124, 63.16460732051304, 63.52266883850098, 60.844944272722515, 63.01959146772112, 62.96452004568917, 61.14795521327427, 62.43021747044155, 63.497558048793245, 64.09204592023576, 66.32571806226457, 65.20614787510463, 65.02251393454415, 70.24194513048444, 68.1932270867484, 63.83320467812674, 10.98707526070731, 0.9356093555688858, 0.8142579272389412, 0.25041736555950983, 1.7451795829193932, 2.5764311211449757, 0.6887450164982251, 0.22312423081270286, 0.6380740840520177, 1.884061153445925, 0.17668857824589523, 5.3823690584727695, 30.46258408682687, 3.370030696902956, 15.559048993246895, 48.233227321079795, 46.23521375656128, 77.41442462376186, 34.218207018715994, 70.61038725716728, 20.915291956492833, 0.43482258330498424, 0.2859601154923439, 0.22952312816466602, 0.2078716999718121, 0.26559966802597046, 0.1574133796883481, 0.174312185762184, 0.18295049294829369, 0.09481053107551166, 0.2214382884225675, 0.1497050997401987, 0.12295981416744844, 0.09394657279231719, 0.17295400292745658], [0.06513539236038923, 0.11262459946530205, 0.050090808753988574, 0.02346822097232299, 0.04399338111813579, 0.008443815301039388, 0.0732518925464579, 0.020651498277272497, 0.013310978372049118, 0.09524129224675042, 0.07252839779747383, 0.06011949186878545, 0.04838606755116156, 0.07627640132393156, 0.10559921751597098, 28.517984798976354, 49.39138780321394, 32.381395135607036, 55.9031457219805, 31.55890907560076, 38.22451400756836, 18.415823425565446, 1.8756488391331263, 0.09392098523676395, 0.074247371272317, 0.06248897008065667, 0.0874723241265331, 0.04392990416714123, 0.29123070410319735, 0.041307488456368446, 0.3568191203687872, 0.237093163388116, 0.056740981194057634, 0.2706617835376944, 10.811045254979815, 66.3119397844587, 73.51866694859096, 83.83997971670968, 73.32909229823521, 75.56130531855992, 73.63894026620048, 74.6015853881836, 73.0536379132952, 74.17937810080392, 73.62012454441616, 75.0225419998169, 70.09292016710553, 72.47655527932304, 67.67360605512346, 68.05365167345319, 67.20998055594308, 67.54127761295864, 73.40101310185024, 70.20373698643276, 70.0801910672869, 70.76098251342773, 70.76042665754045, 68.37235164642334, 66.22567095075334, 68.41046946389335, 69.71638338906425, 72.35403769356864, 69.45294938768659, 68.8515966960362, 69.34524536132812, 67.9917015348162, 64.28556714739118, 64.87239810398647, 62.063255310058594, 57.861620562417166, 57.74431759970528, 56.38416951043265, 52.34655393872942, 50.389892578125, 49.708503586905344, 48.836372647966655, 49.706189836774556, 49.22840390886579, 50.0357984815325, 48.231882844652446, 55.33756583077567, 63.403667041233604, 62.57237066541399, 65.08809103284563, 59.296850885663716, 58.662806919642854, 62.28215830666678, 60.6591911315918, 60.01091030665806, 61.514486585344585, 59.574118750435964, 62.336882318769185, 59.20422445024763, 59.594338008335654, 59.54510307312012, 60.809459822518484, 50.96074267796108, 44.48830461502075, 45.2965156010219, 48.05668749128069, 48.97925540379116, 42.74782255717686, 46.98132174355643, 44.25180530548096, 46.46498720986502, 45.038619313921245, 48.29072366441999, 48.72933912277222, 53.51792642048427, 57.16306604657854, 55.73991169248308, 59.92684405190604, 58.49572358812605, 59.02657985687256, 57.40449857711792, 55.34208910805838, 56.0038355418614, 56.24275629861014, 56.806175300053184, 58.10136815479824, 56.215713909694124, 55.205157484327046, 54.64651536941528, 53.919716426304404, 47.93972151620047, 52.31795515332903, 56.71834659576416, 57.93386098316738, 56.12039157322475, 60.85756914956229, 57.76004137311663, 60.26678466796875, 58.89825357709612, 56.729925768715994, 59.841707774571006, 60.01892852783203, 61.34627069745745, 61.76460089002337, 63.3504090990339, 58.867368834359304, 55.37507220676967, 29.224481105804443, 1.415392890572548, 0.16561602668038436, 0.2818544629429068, 1.7103383839130402, 0.7956233471632004, 0.11234428307839803, 0.07399606225746018, 0.08249610436281987, 0.8828961955649512, 1.0051872049059187, 5.879450568131038, 21.514136348451885, 0.3062582734440054, 0.3202495298215321, 16.884416137422832, 45.06851046425955, 37.55023302350725, 23.014585937772477, 49.04610749653408, 26.227728264672415, 0.17130862336073602, 0.20531369080500944, 0.037047971306102614, 0.11235571639346224, 0.01600627807368125, 0.0348634922743908, 0.03870831596265946, 0.07194689328649215, 0.06648465245962143, 0.059027722238429954, 0.12498017932687487, 0.19999104498752526, 0.0610990793045078, 0.02413034901422049, 0.034836737638605494, 0.09530103725514241, 0.09483431372791529, 0.11273426429501601, 0.06271024035023791, 0.11689928865858487, 0.06329050992748567, 0.10643253994307347, 0.08684395998716354, 0.07778770237096719, 0.03726407453151686, 0.08817449930523123, 0.1023403766698071, 0.024139958766422102, 0.06712898252797977, 38.27718482698713, 64.66484151567731, 45.81660911015102, 49.655568735940115, 26.520276955195836, 47.21591029848371, 23.595929554530553, 1.5041041246482303, 0.08690020375485931, 0.31043940622891697, 0.029864243032144647, 0.1086630541831255, 0.03623021786500301, 0.9949998429843357, 0.5054196736642292, 1.1134482813732964, 0.6397070735692978, 0.19492624247712748, 0.4795112524713789, 18.594492878232682, 78.11317716326032, 74.54164327893938, 83.60739571707589, 78.84452370234898, 80.3182783126831, 77.38631221226284, 78.4149443762643, 74.97919913700649, 76.49911063058036, 77.05543204716274, 78.10685430254254, 72.9023825781686, 76.39333125523159, 71.00700432913644, 71.33876691545758, 68.06206594194684, 70.81791605268205, 75.33417565482003, 73.78443554469517, 72.86648123604911, 73.50529861450195, 73.34890856061662, 71.44303853171212, 68.09281866891044, 68.99192251477922, 74.79890033176967, 72.31649657658168, 71.86456489562988, 70.53991862705776, 71.31527505602155, 69.90196977342877, 69.30978175571987, 68.70463534763881, 64.98477826799665, 59.90518651689802, 60.89893872397286, 58.91004467010498, 54.88909087862287, 51.618420941489084, 52.79577929633004, 50.13428919655936, 54.95159339904785, 52.02432428087507, 52.254229749952046, 52.06142766135079, 57.92767013822283, 65.10791424342564, 66.83777250562395, 69.18184457506452, 62.918648038591655, 59.513099670410156, 65.6030637196132, 64.1575048991612, 63.91941097804478, 64.3105320249285, 62.30943693433489, 62.41193675994873, 61.92939131600516, 63.844801221575054, 62.05247170584542, 62.50306238446917, 52.93136991773333, 48.03375843593052, 50.22865962982178, 51.2848344530378, 49.260407311575754, 46.1516512462071, 49.7528087752206, 46.954744883946006, 47.65361901691982, 47.58818088259016, 49.425006662096294, 49.247518403189524, 54.656722273145405, 59.17008795057024, 58.3075316292899, 60.509415762765066, 62.69007314954485, 61.383533886500764, 59.00442205156599, 58.84958144596645, 59.06882490430559, 59.851219858442036, 58.9718211037772, 59.991295542035786, 59.64169692993164, 57.41142593111311, 58.11136661257063, 57.4726117679051, 52.0551186970302, 52.75718205315726, 60.3124760219029, 60.207002367292134, 60.054871559143066, 62.753225326538086, 60.261747223990305, 61.90210574013846, 61.701031821114675, 60.528175898960654, 62.32705061776297, 61.557002612522666, 65.01883833748954, 63.18735572269985, 64.98516041891915, 58.42665154593331, 59.07648876735142, 37.75620889663696, 3.7952658789498463, 0.5607593070183481, 0.4157736354640552, 1.285530298948288, 3.4735249834401265, 1.765594584601266, 0.08604519534856081, 0.024195116878088032, 1.0900031051465442, 0.08503796439617872, 5.361041562897818, 16.914684227534703, 0.23759658208915166, 0.543085586811815, 18.05658766201564, 52.92066969190325, 27.593313319342478, 29.15417923246111, 55.86991943631853, 30.942635127476283, 0.12892012005405767, 0.10182882233389787, 0.044718758801796606, 0.07351644656487874, 0.10441881085612945, 0.019254306464322975, 0.12681088037788868, 0.11599170735904149, 0.06072584433215005, 0.03034242701583675, 0.13899476373834269, 0.08575004618614912, 0.04531746417550104, 0.03975256100030882, 0.1938947606831789, 0.143753655520933, 0.18152331667287008, 0.2280914464167186, 0.11963843953396593, 0.2083650899252721, 0.2183637105460678, 0.1933540768389191, 0.1166266668587923, 0.24369145504065923, 0.13756656966039113, 0.18380912473159178, 0.08587348527674164, 0.144704703773771, 0.12068370915949345, 48.09264094488961, 71.20750154767717, 48.140058926173616, 76.76471941811698, 49.38613496507917, 61.19440392085484, 32.70074129104614, 2.550772075142179, 0.17094388364681176, 0.31206113206488745, 0.13820930517145566, 0.3139224350452423, 0.14703005685337953, 0.7038400322198868, 0.18544117787054606, 1.2491268409149987, 0.6330566161445209, 0.5169098771044186, 0.6914589394416127, 19.68998408317566, 89.05228206089565, 84.9024635042463, 90.17271382468087, 82.18159757341657, 85.50707490103585, 80.88604341234479, 82.26311383928571, 77.60433973584855, 80.09930583408901, 80.96387713296073, 82.61911869049072, 76.23002774374825, 78.76332010541643, 74.8732807976859, 74.70209108080182, 72.5828766141619, 72.77338927132743, 79.22488893781389, 78.37822314671108, 76.20025471278599, 77.06084469386509, 76.20492390223912, 75.9230910709926, 70.83362592969621, 72.8017657143729, 77.77113124302456, 76.16284561157227, 74.45267854418073, 75.82069546835763, 75.63997282300676, 73.82244219098772, 70.9044280733381, 72.16453947339738, 69.42122391292027, 62.52885409763881, 65.1307738167899, 63.999259676252095, 57.81363977704729, 57.20781591960362, 56.262270314352854, 55.18902724129813, 58.53589807237898, 53.048950808388845, 55.24425152369908, 54.39895452771868, 61.5513676234654, 67.3524603162493, 67.9151393345424, 70.34490353720528, 64.58777209690639, 62.41577911376953, 68.73881353650773, 67.18202100481305, 65.42311232430595, 69.35151958465576, 64.54852172306606, 67.61613055637905, 64.27672903878349, 65.80794525146484, 66.73106207166398, 66.6897063936506, 56.178652218409944, 50.71432828903198, 51.2718517439706, 53.980259554726736, 53.402162483760286, 47.89099727358137, 51.377759660993306, 48.372514384133474, 50.68560791015625, 49.53471524374825, 51.41174330030169, 53.21216399329049, 58.76608494349888, 63.48307800292969, 60.61443778446743, 63.3378050667899, 64.20434965406145, 64.5280453818185, 61.31360026768276, 59.65670503888811, 61.06443091801235, 62.45607171739851, 64.428818157741, 64.62157508305141, 60.91907460348946, 60.90622738429478, 60.70803001948765, 60.54489326477051, 54.9822974886213, 57.91866527284895, 64.47248758588518, 62.968459674290244, 61.71308694566999, 66.69314575195312, 64.8637614931379, 64.80147089276994, 64.18021856035504, 62.35851206098284, 64.41640867505754, 63.48202187674386, 67.9564185823713, 66.24809973580497, 68.92612307412284, 59.31380449022566, 64.37653296334403, 39.70415721620832, 4.4072688562529425, 0.5925189799496106, 0.8885445381913866, 4.627394735813141, 4.617404963288989, 2.3789379128387997, 0.3073444723018578, 0.19899825326034, 1.3016121217182703, 1.3516376316547394, 8.627982922962733, 24.39468056815011, 0.2636828880224909, 0.9103972741535732, 25.008428846086773, 65.27141925266811, 51.213511194501606, 34.24674327032906, 65.8965208871024, 38.271202428000315, 0.29121355073792593, 0.34236730156200273, 0.15824225092572825, 0.2999337842421872, 0.20520493521222047, 0.12271423877349921, 0.15282002330890723, 0.13843626156449318, 0.18233766726085118, 0.15595416298934392, 0.17767382466367312, 0.32582947611808777, 0.09535781706550292, 0.12328910721199852], [0.008976284630729683, 0.0197732432612351, 0.07674752854342971, 0.0163554657649781, 0.15395431672888144, 0.036210343574306796, 0.021598129267139093, 0.1024389745933669, 0.010928763209709098, 0.028684606509549276, 0.03438614967412182, 0.21624982969037124, 0.05603454481544239, 0.1664799510368279, 2.601485456739153, 48.21756955555507, 35.245883805411204, 43.48653071267264, 33.56468725204468, 22.059319802692958, 42.64615304129464, 3.807254127093724, 0.0929093709481614, 0.05155525017263634, 0.09841474624616758, 0.015121166461280413, 0.10538540434624467, 0.06896519328334502, 0.31164654716849327, 0.67926018259355, 0.18134730468903268, 0.13404878628041061, 0.23538835772446223, 2.1771813333034515, 45.28970289230347, 74.64175987243652, 74.62753690992082, 75.97614751543317, 72.17558016095842, 72.50664792742047, 69.35452120644706, 77.16630445207868, 72.40384932926723, 73.90320805140904, 73.3454761505127, 73.89876815250942, 69.94098390851701, 70.46367604391915, 65.9329502923148, 69.84048516409737, 66.02161625453404, 70.31559603554862, 71.8983678817749, 71.42073481423515, 70.27130821772984, 72.43434497288295, 67.74985558646065, 65.88465336390904, 66.15293025970459, 70.74562699454171, 73.19237954275948, 69.52677399771554, 67.50531373705182, 69.42624746050153, 68.16957541874477, 67.5175564629691, 64.36416516985211, 62.01241534096854, 59.01348945072719, 56.449242864336284, 54.256481715611045, 51.09597199303763, 46.43145520346505, 50.99601868220738, 47.67578724452427, 45.463821274893625, 50.11837087358747, 53.99684143066406, 53.24761022840227, 50.73545776094709, 51.54266473225185, 61.43278271811349, 63.3312668119158, 64.30259023393903, 61.72543389456612, 59.53318691253662, 64.22661168234688, 62.73322146279471, 58.886122022356304, 59.85096277509417, 60.12843908582415, 56.317803791591096, 60.7916168485369, 60.518385887145996, 59.62310355050223, 57.0862398147583, 47.83300413404192, 46.63084765842983, 47.79998629433768, 47.89247376578194, 46.030665738242014, 45.992745944431846, 48.7614780153547, 45.20516068594796, 44.53086927958897, 44.89048024586269, 46.98564004898071, 48.73505401611328, 48.22422245570591, 50.736711910792756, 55.23623330252511, 55.734776973724365, 58.791994776044575, 58.20029313223702, 58.54875223977225, 59.002789224897114, 57.391092027936665, 55.97842597961426, 56.26021712166922, 56.20459679194859, 57.573381492069785, 56.295156138283865, 51.89337158203125, 56.13386760439192, 52.36555726187569, 50.693911007472444, 55.801990372794016, 58.029134682246614, 55.82264389310564, 55.42974410738264, 57.90536642074585, 59.94352667672293, 59.779125349862234, 57.86715827669416, 58.12388379233224, 58.86951582772391, 62.24458244868687, 61.97735473087856, 62.8900214603969, 60.4257663999285, 55.19201149259295, 53.727477141789024, 11.524877990995135, 3.6588857684816634, 0.08890577685087919, 0.29424000691090313, 1.5206483283213206, 1.0080005739416396, 0.14513779910547392, 0.20777352952531405, 0.9579807094165257, 0.06377610351358141, 2.6248998003346578, 8.194963370050703, 0.23713927662798337, 0.16632755207163946, 5.585159182548523, 36.445465973445344, 30.086870670318604, 28.61464466367449, 32.51814610617501, 27.461940254483903, 0.03739358311785119, 0.04541633690574339, 0.047745849405016215, 0.07096471384699855, 0.05261652643925377, 0.08144861592778138, 0.05914926143097026, 0.11058259582413094, 0.058829569656934054, 0.056552728438483815, 0.10735916772059031, 0.026497895097626106, 0.1250752420829875, 0.03518726543656417, 0.03308763720893434, 0.006787166539912245, 0.02784185074935002, 0.029162766744515727, 0.13562772369810513, 0.048641868467841826, 0.028551057247178893, 0.09602581443531172, 0.03365749127364584, 0.08630081984613623, 0.001733934217814489, 0.1004617710464767, 0.041509902237781456, 0.13248489876942976, 4.14714697429112, 57.396108627319336, 50.904458795275005, 49.82993377958025, 21.03182714326041, 27.470392738069805, 49.1978874206543, 4.317937169756208, 0.061143421567976475, 0.0919152967897909, 0.11642107074814183, 0.06439777729766709, 0.23121135043246405, 0.19117341456668718, 0.8667291487966264, 1.701008255992617, 0.40584232551710947, 0.1911035661718675, 0.5302931389638356, 3.591509086745126, 55.91224438803536, 80.51175785064697, 85.87909534999302, 80.49322700500488, 78.55565929412842, 75.37490599496024, 74.45466572897774, 78.08386271340507, 75.37999207632882, 76.2166177204677, 76.98968124389648, 76.91764232090541, 73.80002035413469, 73.17705876486642, 70.11966378348214, 70.72307314191545, 70.52559838976178, 73.70476055145264, 75.97539016178676, 73.63787719181606, 73.93840067727226, 73.99130426134381, 70.5099788393293, 69.1253001349313, 70.07170731680733, 71.48768765585763, 75.73761585780552, 70.04974406106132, 72.08392647334507, 71.93546431405204, 72.78688962118966, 68.70514951433454, 68.3276469366891, 64.78211321149553, 60.87082631247384, 59.54523508889334, 53.99542399815151, 53.20434726987566, 50.44290733337402, 51.522344725472585, 53.327695165361675, 48.79282481329781, 54.29819869995117, 58.39178548540388, 57.19787652151925, 53.628659861428396, 56.0089042527335, 62.06000355311802, 65.68410055977958, 66.41515527452741, 62.219075611659456, 61.23299421582903, 68.69281646183559, 65.90277426583427, 63.04697431836809, 62.81136090414864, 63.42678369794573, 59.09855624607631, 62.69642380305699, 61.9983799798148, 62.737821170261924, 57.91055672509329, 50.16490990774972, 48.963406562805176, 51.81761884689331, 49.190133231026785, 50.00340945380074, 47.29220151901245, 50.86085884911673, 47.167425768715994, 46.66726664134434, 46.11481189727783, 48.171117373875205, 49.48190893445696, 50.606103147779194, 52.758662019457134, 56.45647941316877, 58.7126532963344, 61.49312782287598, 59.9048946925572, 61.6023257119315, 60.656995500837056, 61.738350595746724, 57.51333515984671, 58.63229043143136, 58.63381903512137, 60.991398402622764, 56.41253205708095, 56.4902719770159, 58.534299986703054, 54.19273199353899, 53.30095502308437, 56.566184520721436, 58.88902636936733, 61.01377855028425, 58.64736802237374, 60.486097608293804, 62.28756400517055, 61.757027353559224, 61.76675483158657, 62.421441895621165, 60.2093300138201, 62.470996447971885, 66.8222849709647, 63.21945640019008, 61.9148348399571, 56.81657675334385, 59.93917710440499, 14.74190262385777, 5.8052220940589905, 0.7084939139229911, 0.4078608586319855, 3.58834222810609, 2.671570633138929, 0.9991643109491893, 0.4932408928871155, 0.3396212160587311, 0.06953552232256957, 3.689326695033482, 7.1899281569889615, 0.18506953067013196, 0.4151731862553528, 4.234936594963074, 44.558794089726035, 26.690450498035975, 33.360792364392964, 45.601503304072786, 31.377717426845006, 0.20556054184479372, 0.04510197502427867, 0.04499573679640889, 0.07948370065007891, 0.05317138148737805, 0.11258561084313051, 0.03377737144806555, 0.12436850714896407, 0.06825768481940031, 0.0643847697813596, 0.051644793046372275, 0.043661146624279876, 0.06398839676486594, 0.017288388651130453, 0.08398966171911784, 0.15577918237873487, 0.15441874680774553, 0.0979099433336939, 0.2908240987786225, 0.09442827158740588, 0.12443234372351851, 0.25334006015743527, 0.1916587163827249, 0.13501617365649768, 0.1313897025372301, 0.25761119382722036, 0.1773270796984434, 0.28556499098028454, 4.959684950964792, 74.1381196975708, 49.388827392033164, 61.5698915209089, 51.28446272441319, 35.64932400839669, 67.20623547690255, 7.413741792951312, 0.2708468607493809, 0.1703563808862652, 0.24580951567207063, 0.09999611960457903, 0.4201680453760283, 0.19821506100041525, 0.6257149215255464, 2.449420005083084, 0.39725158363580704, 1.2313672453165054, 0.8203571428145681, 4.140650408608573, 57.8202475139073, 83.32375635419572, 91.07468032836914, 87.49025058746338, 84.5644336427961, 79.6476868220738, 78.03789343152727, 82.489472252982, 79.25049304962158, 79.51800564357212, 80.42906039101737, 83.69195529392788, 77.26279408591134, 78.04611315046037, 74.2886802128383, 74.64075933183942, 74.51239136287144, 77.5843289239066, 78.53532191685268, 77.08908912113735, 75.29953193664551, 78.31448037283761, 73.78252479008266, 73.24683952331543, 72.91098444802421, 76.34490231105259, 78.0856831414359, 72.75083541870117, 73.91258117130825, 74.9505864552089, 74.8958693913051, 72.6943952015468, 72.74203205108643, 67.78234536307198, 66.07779938834054, 65.24362645830426, 59.677417618887766, 58.24634231839861, 53.70588214056832, 56.022998673575266, 54.991993699754985, 52.75349950790405, 57.60339423588344, 62.372700282505576, 60.91599655151367, 56.73901053837368, 58.78952816554478, 67.38630499158586, 69.03180517469133, 70.13793754577637, 65.64072295597622, 62.61507429395403, 71.13181482042584, 68.43257863180978, 67.12234987531389, 66.33960056304932, 63.94259016854422, 61.03579044342041, 67.34927109309605, 65.70124176570347, 65.62654168265206, 61.62754767281668, 53.13451092583792, 50.862585476466585, 55.63970129830496, 52.60242830004011, 52.94494669778006, 50.90203734806606, 53.88411733082363, 51.83929375239781, 50.103262015751426, 48.09123740877424, 51.46348653520857, 53.66219881602696, 52.159831523895264, 56.29057032721383, 60.73023646218436, 62.538741384233745, 63.30169527871268, 63.41761902400425, 63.73253917694092, 63.7778970173427, 65.74434838976178, 60.36590766906738, 61.48205934252058, 62.15349851335798, 64.06783144814628, 59.58135182516915, 58.381627219063894, 61.53905541556222, 58.43272427150181, 55.18924263545445, 61.40914494650704, 63.640968867710654, 62.74069077627999, 62.10918985094343, 62.9250681740897, 65.53575651986259, 65.22883374350411, 63.640670095171245, 64.4453409739903, 61.556564876011436, 66.97902243477958, 68.71795504433769, 67.62034811292375, 64.70921966007778, 62.35759489876883, 65.34071363721574, 16.90373386655535, 6.825242400169373, 0.7640886221613202, 1.9106310648577554, 5.463274317128318, 2.5967081359454562, 0.35655704300318447, 0.8022106736898422, 1.6607740606580461, 0.06997454126498528, 2.9292550001825606, 11.149296590260096, 0.20165146089025907, 0.672967611679009, 8.270920208522252, 51.26105076926095, 45.31887490408761, 41.722852093832834, 47.91753591809954, 40.49449396133423, 0.21661465082849773, 0.13928949220904283, 0.10455191228538752, 0.1642842117164816, 0.14167116369519914, 0.19584542672548974, 0.12736497207411698, 0.30331495138151304, 0.12352880649268627, 0.10682277900299855, 0.1592905196760382, 0.15455715438084944, 0.14136044893945965, 0.1405606461422784], [0.05645651895818966, 0.04444303609696882, 0.07476279325783253, 0.052915339690766165, 0.04844308824145368, 0.08022006042301655, 0.024904409889131784, 0.024892150457682352, 0.08110998624137469, 0.013834687814648663, 0.016017945483326912, 0.03398622113413044, 0.10042328454021897, 0.2343459650874138, 13.08009762423379, 58.76413944789341, 31.43389708655221, 32.038720403398784, 24.088815655027116, 41.38588878086635, 19.56239604949951, 0.24165129022938864, 0.03220875794067979, 0.07849401661327907, 0.03446962305211595, 0.055644736625254154, 0.0495757090726069, 0.2352762637393815, 2.206627581800733, 2.5615554622241428, 0.11756258378071444, 0.2516129714037691, 0.1295509540608951, 21.75055227960859, 71.09309250967843, 68.91920961652482, 79.33839470999581, 73.66092436654228, 73.69385882786342, 71.20067146846226, 76.04194695608956, 73.35969911302838, 74.08218669891357, 70.40685367584229, 72.86096436636788, 71.94207899911063, 68.34366948263985, 69.72874423435756, 67.26139722551618, 67.34859711783272, 66.53350394112724, 72.74497808728898, 71.27575370243618, 71.42980916159493, 71.70026084354946, 68.44352204459054, 68.59406171526227, 65.02304199763707, 69.42722715650285, 69.54542991093227, 66.80351093837193, 66.94968714032854, 68.32239409855434, 67.71865122658866, 66.99079268319267, 65.0248554774693, 62.008621624537874, 59.17229747772217, 57.17907469613211, 54.47978292192732, 51.77234091077532, 50.07812343324934, 50.01332105909075, 49.65881701878139, 51.77863597869873, 48.59436689104353, 48.29129689080374, 49.13110828399658, 49.928810119628906, 50.18647364207676, 53.88670553479876, 58.23000015531267, 61.9370482308524, 63.66057668413435, 63.90773105621338, 62.03478159223284, 61.948081970214844, 60.004420689174104, 59.964315686907085, 59.84541811261858, 60.58223983219692, 59.226354462759836, 57.042903900146484, 57.34856905255999, 60.20727334703718, 55.321220193590435, 49.19128315789359, 50.403907094682964, 47.96296671458653, 45.31171478543963, 46.24452781677246, 47.16432339804513, 44.83127464566912, 43.92931509017944, 45.717208181108745, 45.57781342097691, 45.53859083993094, 45.61458328792027, 48.23040982655117, 48.504220962524414, 52.80140733718872, 54.58699015208653, 56.2448650768825, 56.34818478993007, 60.22686726706368, 58.31657818385533, 56.104726859501426, 54.70839950016567, 55.31480700629098, 54.265913895198274, 57.76900454929897, 56.107495716639924, 55.949577059064595, 52.92174318858555, 54.45246607916695, 53.953668798719136, 52.94680881500244, 55.21379062107631, 57.767500264304026, 55.773391587393625, 59.67889758518764, 60.017997469220845, 59.335274423871724, 57.236619676862446, 61.24668216705322, 57.93006379263741, 60.53320639474051, 63.510849952697754, 64.047452381679, 63.286582946777344, 51.325946944100515, 48.9338732446943, 20.446863515036448, 5.763433022158487, 0.475889612521444, 0.6568459453327316, 2.157050882066999, 2.001010843685695, 0.23980874195694923, 0.05977852123656443, 0.07208727539650031, 0.08028815819748811, 6.117938799517495, 4.574720008032663, 0.1986412624163287, 0.18573924473353795, 0.2634788661130837, 34.65651675633022, 26.627223627907888, 24.98514195850917, 27.07200734955924, 32.09790863309588, 0.19614096943821224, 0.07173286298555986, 0.0422848163704787, 0.08743578501577888, 0.06441844547433512, 0.18339695541986398, 0.14590796349304064, 0.08180992225451128, 0.04721373885071703, 0.0628768206973161, 0.08444552190069642, 0.05328857805579901, 0.14071936905384064, 0.029236699920147657, 0.06420209458363907, 0.01376304978371731, 0.13050327795956815, 0.09600876285029308, 0.007299803563260606, 0.12695287061589106, 0.02630296046845615, 0.010457412921823561, 0.048523596421416314, 0.03333244585831251, 0.018289982673845122, 0.11363832399781261, 0.0598851190879941, 0.2229054304105895, 17.567877428872244, 69.00229617527553, 43.37761769975935, 37.51052059446062, 23.657669510160172, 50.086033957345144, 22.07683621134077, 0.37645844795874184, 0.027292062661477497, 0.03994228617687311, 0.04236495814153126, 0.03334478162495153, 0.0559914171296571, 0.30617120383041246, 3.1522211730480194, 3.4124183995383124, 1.3777491790907723, 0.6944836314235414, 0.030758789673979794, 26.102443558829172, 74.75654411315918, 69.05454662867955, 82.89788041796002, 77.52319172450474, 80.68573379516602, 76.45230756487165, 77.69511795043945, 77.18962955474854, 78.36239515032086, 75.44100420815604, 76.77219567980084, 75.03517382485526, 73.15355995723179, 71.14992877415249, 68.76559884207589, 69.90554114750454, 70.35827881949288, 73.47918033599854, 73.33739539555141, 71.30730547223772, 74.59283760615757, 71.49282932281494, 69.7982679094587, 70.36440713065011, 71.23810141427177, 72.36481434958321, 69.02915791102818, 71.11514609200614, 70.86855452401298, 70.62231731414795, 69.49953011104039, 69.62401403699602, 65.3615721293858, 62.76602390834263, 62.0971416745867, 57.579384735652376, 54.00313997268677, 52.230088233947754, 51.0200594493321, 50.96653400148664, 54.79996633529663, 52.27441079275948, 52.70383031027657, 50.930775097438264, 53.89268445968628, 53.45076165880476, 57.90404278891427, 60.01869228907994, 66.59540544237409, 68.00179726736886, 66.7116835457938, 64.19903428213937, 64.72659015655518, 62.80776868547712, 64.66281958988735, 62.56267098018101, 63.00333963121687, 62.02134377615792, 59.193989753723145, 60.11591843196324, 62.984419686453684, 57.79796116692679, 51.417298385075156, 51.782026699611116, 50.83162430354527, 48.21615559714181, 48.23692723682949, 48.56020607267107, 47.95596293040684, 45.630796909332275, 47.906463963644846, 47.19125461578369, 46.9538311958313, 48.047043391636436, 51.08339575358799, 50.11468138013567, 53.59815032141549, 55.768340247017996, 59.02082674843924, 58.467319352286204, 63.912914412362234, 61.26488644736153, 58.76778030395508, 56.52901513235909, 58.08441802433559, 56.36204297201974, 59.972076824733186, 58.05741037641253, 59.21056120736258, 57.3072828565325, 56.429503032139365, 55.95597634996687, 56.24306549344744, 57.2668582371303, 61.0573159626552, 58.13091189520699, 62.442460196358816, 61.601867130824495, 61.28967067173549, 61.231368337358745, 63.76332664489746, 61.35332311902727, 61.74280439104353, 65.34823158809117, 64.64942346300397, 64.62022018432617, 52.94969926561628, 53.492311886378694, 21.767088992255076, 5.00556868314743, 0.30862763630492346, 0.8748094152126993, 2.6704784631729126, 3.8857301218169074, 1.3603723858083998, 0.10560326837003231, 0.20724121880318436, 0.17492549999483994, 4.929180187838418, 3.403239829199655, 0.14115576206573419, 0.5563666884388242, 0.04532182037032076, 39.24225834437779, 32.56194060189383, 26.81406937326704, 36.938385077885215, 38.59454379762922, 0.30146116656916483, 0.10045729950070381, 0.06521932714219604, 0.05648904114163347, 0.08003747343484845, 0.04359437199309468, 0.06385249298598085, 0.06192812017564263, 0.04936253711847322, 0.009652583876491656, 0.054967334760086875, 0.0920776023662516, 0.10679665540478059, 0.09307298609720809, 0.2051996969218765, 0.14172651858202048, 0.18637245361294064, 0.14264572997178349, 0.08068501975919519, 0.27086189708539415, 0.32175034071717945, 0.1152668691107205, 0.16830472169177874, 0.06635710144681589, 0.10684192726122481, 0.14574500652296202, 0.22308100813201495, 0.27667631794299397, 22.0815783568791, 84.94163744790214, 46.61507524762835, 50.4391587802342, 42.34523698261806, 61.1337183543614, 29.148519924708776, 0.46568363159894943, 0.13586582163614885, 0.2337637006172112, 0.120304299518466, 0.21455315287624085, 0.18029812670179776, 0.8006754474980491, 6.967046448162623, 13.513269168989998, 3.609375293765749, 1.190663829445839, 0.20801477586584433, 28.37864909853254, 87.39736706869942, 73.9859402520316, 86.26278182438442, 81.01815646035331, 85.23058523450578, 80.97461904798234, 81.35681165967668, 80.8587508882795, 80.3202099118914, 78.42522076198033, 78.57022966657365, 79.19401114327567, 74.82949325016567, 75.60722596304757, 72.33018452780587, 74.56840079171317, 71.71715886252267, 77.30354527064732, 77.9550222669329, 74.53588322230748, 78.7091588973999, 75.11746134076799, 73.04405634743827, 72.4548282623291, 72.90691975184849, 73.90853731972831, 73.39923436301095, 76.0632014955793, 74.23578357696533, 74.770662852696, 72.93582425798688, 71.07760497501918, 67.491500718253, 64.6717688696725, 66.01721804482597, 61.49851962498256, 59.375490597316194, 54.355535234723774, 55.7666448865618, 55.66097320829119, 59.987494877406526, 55.13353197915213, 56.49937759126936, 56.06973225729806, 57.62059102739607, 56.197929995400564, 60.37136895315987, 64.0195484161377, 68.93738610403878, 69.06028584071568, 67.4343934740339, 66.1480734688895, 69.73720714024135, 64.89823845454625, 68.21314062391008, 66.89588029044015, 64.96334307534354, 64.23583889007568, 61.552646092006135, 64.02744851793561, 64.89487552642822, 61.887146268572124, 53.08483478001186, 55.86140441894531, 56.4070360319955, 51.04668147223336, 52.515985761369976, 52.47809028625488, 50.59826905386788, 47.96774360111782, 49.92377962384905, 49.983509813036235, 49.891324588230674, 49.386437211717876, 53.72975615092686, 52.818399156842915, 57.22041647774832, 58.352034841264995, 59.76374898638044, 61.41589164733887, 66.18399565560478, 64.68350437709263, 61.48820155007498, 59.88573850904192, 60.99255180358887, 58.40989249093192, 63.92772102355957, 59.309753690447124, 62.72214603424072, 58.86764676230294, 61.2138797215053, 59.28278078351702, 58.264591761997764, 59.98964187077114, 65.06022875649589, 61.34682655334473, 65.25178364345005, 64.82283660343715, 64.44671671731132, 63.67193004063198, 65.96236201695034, 62.67131301334926, 64.78224522726876, 68.39646189553397, 68.60362243652344, 65.71695164271763, 59.150229998997276, 62.40983145577567, 26.364659888403757, 8.275952441351754, 1.53564829485757, 2.147499931710107, 9.194453052112035, 4.553767715181623, 0.5447710677981377, 0.1218521600323064, 0.2351587414741516, 0.2943409186388765, 6.684000287737165, 6.508359381130763, 0.17978182940610818, 1.638938043798719, 0.29408877502594677, 46.497841766902376, 39.35058076041085, 34.68518154961722, 41.70174694061279, 47.77543136051723, 0.39583062274115427, 0.20520622442875588, 0.11170523879783494, 0.09542029657002006, 0.3021918945014477, 0.16713373309799603, 0.16869861127010413, 0.14124766284865992, 0.17301338831228869, 0.07522570341825485, 0.1483894203390394, 0.10280257436845984, 0.2955674928213869, 0.15262004546821117], [0.06484866381755897, 0.06130244303494692, 0.037864801939576864, 0.08741235520158495, 0.007928877619893422, 0.07580399167324815, 0.03386196440884045, 0.03310641905825053, 0.13053415130291665, 0.05021792211170707, 0.07851395875747715, 0.09929944055953197, 0.06964403364275183, 0.12872532622090407, 31.492011819566997, 47.85227843693325, 38.4605165209089, 26.89399971280779, 12.889763883181981, 39.98667791911534, 2.7336840544428145, 0.69365180177348, 0.08339738207204, 0.07429767785859959, 0.08715497329831123, 0.09034853229033095, 0.05239817047757762, 1.0700816426958357, 1.6571461239031382, 0.6248851003391402, 1.1006477453878947, 0.048982757675860605, 2.221392938068935, 44.020822865622385, 64.72064249856132, 75.8364748273577, 72.47324793679374, 73.06333759852818, 73.36736992427281, 72.20737511771065, 70.74808665684291, 74.79653794424874, 70.35894584655762, 68.80466161455426, 72.39352430616105, 71.17923627580915, 66.64563396998814, 67.38775021689278, 65.59381566728864, 68.99958637782505, 68.75281415666852, 71.75949423653739, 69.01372596195766, 71.17378888811383, 70.62015642438615, 65.5438928604126, 67.09127058301652, 67.31063216073173, 69.8665200642177, 71.07873058319092, 67.37665394374302, 68.9736557006836, 66.86439105442592, 66.17030770438058, 66.89741584232875, 63.53250748770577, 59.285949162074495, 57.20464406694685, 53.778296266283306, 51.16023588180542, 48.326107365744456, 50.361495290483745, 45.66573940004621, 48.388099193573, 47.13928209032331, 46.77137150083269, 50.169700690678184, 47.705622809273855, 49.24057715279715, 51.43827152252197, 50.42175006866455, 56.91709286825997, 62.409873144967214, 66.43467276436942, 62.68168667384556, 61.69477844238281, 59.39043617248535, 60.57853644234793, 60.67014149257115, 59.35381916591099, 58.50886263166155, 62.53168201446533, 58.72965553828648, 60.60345268249512, 60.947152273995535, 51.722018582480295, 48.46181958062308, 49.18721498761858, 46.884213720049175, 45.11902734211513, 44.24356821605137, 44.508708000183105, 45.49499436787197, 44.8600367137364, 45.52250228609358, 46.403050967625205, 45.09429175513131, 45.8640444619315, 46.22353730882917, 48.74638305391584, 49.74330363954817, 51.93569653374808, 54.56636095046997, 56.95969574792044, 56.22146354402815, 58.41983536311558, 58.45777947562081, 52.828911781311035, 55.552150521959575, 54.642033781324116, 56.284327370779856, 58.51878465924944, 55.83889920370919, 55.959978512355256, 50.14504848207746, 53.51166956765311, 54.67971733638218, 54.4957081930978, 58.25873095648629, 55.358122076307026, 59.84704399108887, 60.09339237213135, 58.0772579056876, 60.61450726645333, 59.31482587541853, 59.87202276502337, 56.517623560769216, 61.60971164703369, 61.31085572923933, 66.39498465401786, 46.63749361038208, 24.242567130497523, 5.406502323491233, 1.9907987288066318, 1.8341872010912215, 0.03153893531167081, 3.5217550354344502, 3.713975429534912, 1.912703799349921, 0.17410011642745563, 0.06903225968458823, 0.04054960894531437, 3.5706343097346167, 1.3669723059449876, 0.3952172270842961, 0.7029396976743425, 0.08890037571213075, 26.810696022851126, 28.58534411021641, 25.682583025523595, 30.955590043749126, 30.181803907666886, 0.8124751171895436, 0.21603393341813767, 0.2729317274476801, 0.050951303115912845, 0.054075397085398436, 0.07016749626823834, 0.03754778698618923, 0.06600245833396912, 0.025355099633868252, 0.03853394603356719, 0.028942666947841644, 0.04684284482417362, 0.10875505674630404, 0.03668343176000884, 0.04186784303081887, 0.08636170479335956, 0.034637295840574164, 0.07157343439757824, 0.08041610276060444, 0.02762534379559968, 0.03082428526665483, 0.050504525125558884, 0.16675013011055334, 0.057748235895165374, 0.09296525509229728, 0.05644818654816065, 0.06787247370396342, 0.040734580984073024, 38.69027260371617, 57.228969710213796, 48.958688735961914, 26.26873653275626, 17.070587907518657, 47.66835962023054, 3.0454905458859036, 1.4085698681218284, 0.5450710345591817, 0.18297842144966125, 0.06131523342004844, 0.050999624987265894, 0.1160067572657551, 0.49026234128645485, 0.7740111382944244, 2.2243424483707974, 1.034155439053263, 0.0973173515605075, 3.435847508055823, 51.46579333714077, 69.8390121459961, 77.371276310512, 77.30339241027832, 74.93841321127755, 76.29866899762834, 76.71544279370988, 74.38082027435303, 75.80523572649274, 74.56703894478935, 70.09756851196289, 74.2673978805542, 75.33375876290458, 69.61079161507743, 72.01055349622453, 68.30650356837681, 72.08712264469692, 71.19293812343052, 76.51519571031842, 71.03010708945138, 74.0270666394915, 72.13514164515904, 69.23793738228935, 70.2851698739188, 70.55997112819126, 73.28627055031913, 72.03831849779401, 70.22062110900879, 69.75333390917096, 69.78042493547711, 68.68335996355329, 69.19073826926095, 66.36571189335415, 62.10673713684082, 61.02122701917376, 56.808089528764995, 54.526669366019114, 50.940200328826904, 53.606491633823936, 48.110268524714876, 52.13923358917236, 52.34613357271467, 50.31958375658308, 53.37172589983259, 52.88682849066598, 54.54090275083269, 53.39028801236834, 53.409006459372385, 57.36788157054356, 65.38699558803013, 68.26509925297329, 65.02036694117955, 63.2979918888637, 61.985324314662385, 64.05518572671073, 64.00392191750663, 62.1093635559082, 60.052787099565776, 65.75783484322685, 61.28396620069231, 63.10912595476423, 63.284046854291645, 54.95527941840035, 51.697397640773225, 50.579852853502544, 49.83393941606794, 47.69523177828108, 47.33777127947126, 47.43087714059012, 48.856894152505056, 46.899642195020405, 47.98324155807495, 47.27959401266915, 46.24916226523263, 47.74657549176897, 47.171483516693115, 49.122363976069856, 50.147306646619526, 55.23751524516514, 57.3940554346357, 60.082087653023855, 58.32540239606585, 60.7299793788365, 61.163873536246165, 54.9606990133013, 58.2475026675633, 57.30147416251046, 58.02751922607422, 61.09027821677071, 57.71314450672695, 59.404999596732004, 54.43604053769793, 56.7679671560015, 56.295149190085276, 57.24868869781494, 60.77830410003662, 59.856500489371165, 62.82151917048863, 62.30285004207066, 57.51905352728707, 64.20758056640625, 62.10427747453962, 62.95666858128139, 58.45573670523507, 62.330809593200684, 63.72528525761196, 70.51296656472343, 49.3890323638916, 27.899450949260167, 6.197570366518838, 3.4409678961549486, 2.328455124582563, 0.34297184912221773, 1.9860072944845473, 4.110070952347346, 4.261727111680167, 1.9082031037126268, 0.8029558137059212, 0.05697392565863473, 3.396572164126805, 0.672159015067986, 0.3794771416911057, 0.37143940585000174, 0.10658229262168918, 28.65565119470869, 31.795116560799734, 23.752779926572526, 37.26626014709473, 40.807312284197124, 2.191981213433402, 0.22264177884374345, 0.1792870552412101, 0.031588668535862646, 0.09131877629884652, 0.021731493628716896, 0.025297268094228845, 0.03866306106959071, 0.04990420823118516, 0.025783509681267396, 0.05541599229244249, 0.028464937582612038, 0.059232721238264015, 0.03977829783356615, 0.09647831586854798, 0.1603391141231571, 0.11963405619774546, 0.18221099834356988, 0.10273583366402558, 0.14795148026730331, 0.13298135570117406, 0.07731571341199533, 0.22028224116989545, 0.18212386087647506, 0.17155847352530273, 0.21214972755738667, 0.22105663961597852, 0.18798450353954518, 46.582366602761404, 67.280289377485, 57.27866670063564, 42.0505291393825, 24.727973495210918, 57.79783609935215, 4.549201011657715, 2.1865138496671404, 0.8102173869098935, 0.27680876797863413, 0.2277212105691433, 0.1472799205886466, 0.1876812662397112, 2.777326124055045, 5.840328301702227, 4.851699088300977, 2.1413583755493164, 0.2461198775896004, 4.374330486570086, 58.4511022567749, 78.18142236982072, 80.47239630562919, 84.60188443320138, 78.4343923841204, 80.67901488712856, 79.49083123888288, 80.15581553322929, 79.90887655530656, 77.73753670283726, 75.81207275390625, 79.04106044769287, 78.71751758030483, 72.36288275037492, 76.89444923400879, 71.08956977299282, 77.09748254503522, 75.48495851244245, 77.4107003893171, 73.26738534654889, 75.71702834538051, 77.36706570216587, 72.76116739000592, 74.17302049909318, 73.70222445896694, 75.8439997264317, 73.66411358969552, 74.69990934644426, 74.63684054783413, 74.06892953600202, 72.25631822858537, 73.53124318804059, 70.25045667375836, 64.84223597390312, 64.7328713280814, 60.14047336578369, 59.220392908368794, 55.087298665727886, 57.93150206974575, 50.86477068492344, 56.10647085734776, 55.75917557307652, 54.98957225254604, 56.29821334566389, 55.92410148893084, 59.48446614401681, 59.41387939453125, 57.352863039289204, 61.871061188834055, 68.65412194388253, 69.8551528113229, 68.2524813243321, 66.46291024344308, 65.41505241394043, 66.78582082475934, 67.23868356432233, 65.23193264007568, 63.80452251434326, 67.41686316898891, 61.197204044886995, 66.26287160600934, 67.34740897587368, 57.98387064252581, 54.26666777474539, 56.10166270392281, 53.84492254257202, 51.461725166865754, 51.28221150806972, 49.97068343843733, 52.16332646778652, 49.385099683489116, 51.91551896503994, 50.624745164598735, 49.094477381025044, 51.14016253607613, 51.374497481754844, 54.18690940311977, 53.35148927143642, 57.913207462855745, 59.52804524557931, 63.10879244123186, 62.47642993927002, 65.3367531640189, 63.27745301382882, 57.0594927242824, 63.08843421936035, 60.50279412950788, 63.24103055681501, 63.83341312408447, 60.51479366847447, 61.16162926810128, 57.34618582044329, 60.30411039079939, 59.91426086425781, 59.189820834568565, 65.72406659807477, 61.712531089782715, 66.41513442993164, 65.43599428449357, 61.36307144165039, 66.97732707432338, 65.24493966783795, 66.11518069675991, 61.65330464499337, 65.15801770346505, 66.81312029702323, 72.32008879525321, 55.385998249053955, 39.51693800517491, 13.721170561654226, 5.859026338372912, 5.008621113640921, 0.6509132151092801, 8.164101208959307, 8.035049710954938, 3.9789063334465027, 0.7074082578931535, 0.3728814013302326, 0.14148766068475588, 6.28870815038681, 1.7272865601948328, 0.7476388162800244, 1.1928631514310837, 0.22230731536235127, 38.1856666292463, 41.152901785714285, 42.09368440083095, 44.361642428806846, 49.29482521329607, 1.8801986064229692, 0.46608966695410864, 0.3780263795384339, 0.1915120171116931, 0.22554485020892961, 0.18935332580336503, 0.19608143477567605, 0.1540937963873148, 0.1407223410372223, 0.10301255381533078, 0.1741156413086823, 0.10013200981276375, 0.08491023696426835, 0.33373742178082466], [0.07321677157389266, 0.08734790116016354, 0.14115866619561399, 0.055002262350171804, 0.06611206888088159, 0.012421235758146005, 0.05795584725482123, 0.04316815361380577, 0.07395256816276483, 0.05538740221943174, 0.07338192699743168, 0.05075714371300169, 0.20245245790907315, 1.3589831803526198, 47.27365330287388, 42.54260056359427, 32.42471367972237, 25.422723872320994, 24.64125997679574, 35.13645315170288, 0.528246568781989, 4.3230019722666055, 1.4707228073051997, 0.16231366459812435, 0.07525076171649353, 0.07307480847729103, 0.05338173073583415, 0.39919876200812204, 1.3948305653674262, 1.5141442716121674, 1.1595981078488486, 0.5034921456660543, 15.09990508215768, 56.205725874219624, 61.167903491428916, 72.53334985460553, 73.20015457698277, 72.57205132075718, 73.42257336207798, 72.11507524762834, 72.28063692365373, 69.64615794590541, 68.43859577178955, 66.10220146179199, 68.43036910465786, 68.62705871037075, 63.96001625061035, 66.70928641727993, 65.38427189418248, 67.9820921761649, 67.9937026160104, 71.48638834272111, 68.04047788892473, 72.0861429486956, 67.69312354496547, 65.70622362409318, 64.22672285352434, 68.87008585248674, 67.54369558606828, 66.94225951603481, 67.71898474012102, 64.50433812822614, 63.668164116995676, 64.84560585021973, 64.28505298069545, 60.48687580653599, 57.70803758076259, 54.39039087295532, 51.60733509063721, 50.39351258959089, 48.950510706220356, 47.9501507622855, 47.43591111046927, 46.79130935668945, 49.25301790237427, 45.16282878603254, 46.56345360619681, 47.05756432669503, 48.46814938953945, 51.08635221208845, 50.187686102730886, 55.770070348467144, 60.15778827667236, 64.79538427080426, 59.025051253182546, 56.93115602220808, 56.87521954945156, 56.857303619384766, 55.83910070146833, 54.92824397768293, 55.978860242026194, 58.48908805847168, 62.020774023873464, 60.14986733027867, 59.61830929347447, 53.25807074138096, 47.78919226782662, 45.93823732648577, 47.05299241202218, 40.94572734832764, 43.44981295721871, 45.629553181784495, 44.781459535871235, 43.447304657527376, 46.1551114491054, 43.88819565091814, 44.47583259854998, 45.48267521177019, 45.948576245989116, 47.95921816144671, 47.31413698196411, 50.928916454315186, 50.88769279207502, 55.24004438945225, 56.968926429748535, 55.17155599594116, 57.899352754865376, 57.70615809304373, 53.69656808035714, 54.28293350764683, 55.45111329214913, 57.395980085645405, 57.49348068237305, 55.49596043995449, 56.97058704921177, 51.457285267966135, 54.00950799669538, 55.031337874276296, 54.42969683238438, 59.70912919725691, 58.4178203855242, 57.85434579849243, 56.236013071877615, 60.46223749433245, 59.49213695526123, 60.631551197596956, 57.113744258880615, 60.045692988804404, 60.61948912484305, 65.70050525665283, 41.79578038624355, 8.956538915634155, 1.7034775806324822, 0.8545726239681244, 0.8768028968146869, 0.241941187530756, 0.8563841496195111, 4.816123877252851, 7.248217897755759, 2.2683054379054477, 0.32260483343686375, 0.403889746006046, 2.7433791799204688, 0.23532430401870183, 0.0850255268492869, 0.19266594733510697, 0.48254794095243725, 22.107581990105764, 28.03841665812901, 25.400753668376378, 23.334352459226334, 37.26142072677612, 4.782089863504682, 0.4449913805084569, 0.2759226012442793, 0.09569864520537001, 0.08232318649866752, 0.09556086866983346, 0.1612827256321907, 0.07194288992988211, 0.10035334115049668, 0.0068745113842721495, 0.10453876906207629, 0.04857513115608266, 0.04455292823591402, 0.11413641619895186, 0.026405431130634885, 0.1132517625976886, 0.11429136645581041, 0.04448592968817268, 0.03796470943572266, 0.022821105517713085, 0.10897247972232954, 0.047140711519334993, 0.03291205609483378, 0.08207008615136147, 0.11182008763509137, 0.048827451188117266, 0.24880242507372582, 2.084761606795447, 57.04576655796596, 52.18560586656843, 47.894978591373985, 24.10087251663208, 30.817042963845388, 40.825905663626536, 0.5686925213251794, 5.700676892484937, 2.846815709556852, 0.2280719317495823, 0.2569126827376229, 0.07228204887360334, 0.4048825784453324, 0.3544576013726847, 0.9887475499085018, 1.6063719455684935, 0.9944374731608799, 0.9516050858157021, 18.04732745034354, 64.28821441105434, 67.78442287445068, 75.93586880820138, 78.055173601423, 76.26215621403286, 78.1943668637957, 74.8544442313058, 75.92842033931187, 72.79506765093122, 72.43194089617047, 70.1849421092442, 72.03683158329555, 71.2426038469587, 67.5363096509661, 68.36771024976457, 68.33975764683315, 70.08762563977922, 70.83461952209473, 73.28641646248954, 72.04233455657959, 72.89212008884975, 68.17816339220319, 69.27995313916887, 68.58994143349784, 73.16718537466866, 72.24428394862584, 70.10661506652832, 69.05828475952148, 69.08217961447579, 67.62225191933769, 68.37715979984829, 66.57442883082798, 62.38809749058315, 62.777627399989534, 57.31954295294625, 55.03772326878139, 53.147823674338206, 52.22453314917428, 50.637342248644146, 50.25179713112967, 49.36953919274466, 54.23341369628906, 49.78368656975882, 51.05897978373936, 50.801590715135845, 50.70935337884085, 54.3575119972229, 52.44778224400112, 57.10000419616699, 61.40988840375628, 66.55315344674247, 61.052841322762625, 57.85672903060913, 56.44957637786865, 59.65411336081368, 58.482772145952495, 57.45768356323242, 58.44525187356131, 59.82531697409493, 64.87533719199044, 61.82270867483956, 62.652010917663574, 55.60912922450474, 50.928787912641255, 49.018550940922324, 49.21136692592076, 44.896184716905864, 47.49065249306815, 45.84181022644043, 47.73926598685128, 46.79283101218087, 49.47756283623831, 46.64235734939575, 47.229160513196675, 47.12324912207467, 48.32727118900844, 49.4457539830889, 48.931514331272666, 51.1022184235709, 54.478494031088694, 57.48483712332589, 59.23169067927769, 58.3245130266462, 57.96699694224766, 59.7626233782087, 56.41603742327009, 57.16519219534737, 58.120805740356445, 59.40989112854004, 59.66520963396345, 59.122027260916575, 60.13779136112758, 55.56639780317034, 55.45765502112252, 57.786013739449636, 57.047336850847515, 61.325259344918386, 60.24068028586251, 59.89152635846819, 56.931812626974924, 62.88907650538853, 61.57365049634661, 64.06776891435895, 58.837185859680176, 64.78673376355852, 61.68039567129952, 69.82540757315499, 47.57949216025216, 11.56626580442701, 2.142637929746083, 0.6626651159354618, 1.6172438136168887, 0.7609522161739213, 1.155781266944749, 3.162555967058454, 5.234649053641728, 3.8241425922938754, 0.8323221579194069, 0.5579897442034313, 2.990177022559302, 0.20169367933911936, 0.2025025745055505, 0.152665303753955, 0.6189591011830738, 24.76498654910496, 32.433155741010395, 24.744074208395823, 31.131674766540527, 49.223765986306326, 6.925134914261954, 0.5272371800882476, 0.27441166660615374, 0.09571349155157804, 0.12212201340922288, 0.016255198645272424, 0.11375639587640762, 0.06642405249710594, 0.13385739869305066, 0.07550515128033501, 0.0737043736236436, 0.030676999062831913, 0.021996712611456002, 0.08430354523339442, 0.10706464959574596, 0.1707820530448641, 0.1821654007903167, 0.11277982792151825, 0.13670740861977848, 0.13820101347352776, 0.13788073137402534, 0.12953104584344796, 0.15851142576762609, 0.24273865616747312, 0.25117827472942217, 0.21786812213914736, 0.3820347844489983, 2.6365454154355183, 65.68004281180245, 61.709383555821006, 46.94636188234602, 42.277787344796316, 42.380843026297434, 50.228246212005615, 0.5709750588451112, 8.600542749677386, 4.113123382840838, 0.33275889285973137, 0.3067281182323183, 0.21329723883952412, 0.6278339592473847, 1.2448378482035227, 2.8229849083083014, 2.980124933379037, 2.833703156028475, 2.3634816450732092, 18.952603033610753, 71.00387069157192, 75.66516699109758, 81.69876030513218, 83.17465496063232, 81.43003872462681, 81.4567962374006, 77.96765409197126, 77.75499057769775, 78.71457154410226, 75.4656286239624, 74.44833592006138, 76.22617149353027, 75.00649860927037, 72.41937855311802, 73.11545603615897, 71.55612046377999, 74.79027761731828, 73.39945670536586, 75.58548504965646, 72.34542192731584, 75.24985231672014, 71.58710942949567, 71.54000759124756, 71.37991414751325, 75.84572287968227, 74.24861689976284, 72.62938785552979, 72.95509856087821, 71.87110315050397, 69.89386122567313, 71.277726990836, 68.77130331311906, 66.86973421914237, 65.58546393258231, 60.43871784210205, 57.187919752938406, 57.37793908800398, 55.61139781134469, 54.62738350459507, 52.690826756613596, 52.82720252445766, 57.90185063225882, 51.3331869670323, 56.16756289345877, 54.65358516148159, 55.577730315072195, 58.32454081944057, 56.59055880137852, 61.99113995688302, 64.54301180158342, 70.59225245884487, 64.33410031454903, 64.33769948141915, 61.571281160627095, 62.78469371795654, 59.87930447714669, 60.098638262067524, 62.07119015284947, 65.21412440708706, 68.3067467553275, 63.7765907560076, 64.9680678503854, 58.31377111162458, 54.21680055345808, 52.62987715857369, 53.81498275484358, 47.81674534933907, 49.91562591280256, 50.47613361903599, 51.22816494532994, 48.66410248620169, 53.66432843889509, 47.546373571668354, 49.884946141924175, 50.64653818947928, 50.155314445495605, 52.44966173171997, 51.62146077837263, 54.523160525730674, 55.824172496795654, 60.948548861912315, 63.07283551352364, 61.09362030029297, 61.4838102885655, 62.27778788975307, 58.82950810023716, 61.660530771527974, 59.97063159942627, 62.90657206944057, 61.61044815608433, 62.31623922075544, 61.7546580178397, 59.374232973371235, 59.5226742880685, 61.75466496603829, 60.56363950456892, 66.0610681261335, 62.54872594560896, 63.21002074650356, 59.767619132995605, 66.9478041785104, 63.8670563016619, 67.36388315473283, 60.346605573381694, 65.34356239863804, 64.4822359085083, 72.48190539223808, 52.72796140398298, 23.467233283179148, 4.580266841820308, 1.5144205710717609, 1.9074021066938127, 1.321413402046476, 4.351887370858874, 8.387121881757464, 14.745022365025111, 6.2832446949822565, 0.40411051415971344, 0.549320780805179, 6.802526567663465, 0.18403084283428534, 0.3777655235358647, 0.20898186468652316, 0.6170849874615669, 29.211672101702007, 42.154595783778596, 41.628061294555664, 37.35844537190029, 58.12256710869925, 8.870918001447405, 0.6546443977526256, 0.3281069110546793, 0.24338535432304653, 0.21556811912783555, 0.22615368611046247, 0.23190340186868394, 0.16627835828278745, 0.22883020820362227, 0.12322962683226381, 0.23543007405740873, 0.15976345858403615, 0.14527122623154096, 0.2972360647150448], [0.0764903909127627, 0.06507627160421439, 0.0819133377767035, 0.04101734688239438, 0.06380192177104098, 0.07887205561356884, 0.03981947473117283, 0.05055068925555263, 0.0701440664540444, 0.02470267973175006, 0.08851724091385092, 0.131085623853973, 0.04803775177736368, 5.571767832551684, 55.14035858426775, 30.465099334716797, 37.792252676827566, 20.252404281071254, 38.273345947265625, 14.501390729631696, 0.6743747847420829, 0.8747624063066074, 1.1786697187594004, 0.02199370670132339, 0.09869626364005463, 0.026779924785452228, 0.15283818090600626, 0.7550004869699478, 0.28634172358683174, 1.9314504734107425, 0.8513839979256902, 3.985061134610857, 27.692877531051636, 61.8226044518607, 51.65167154584612, 74.4597031729562, 69.72153895241874, 73.67830181121826, 73.5271576472691, 71.00748375483921, 72.69123377118791, 70.40602684020996, 70.66056714739118, 65.45507403782436, 71.13012640816825, 65.4568875176566, 63.47608116694859, 64.01561573573521, 66.18300206320626, 68.14434650966099, 68.01019069126674, 68.02995136805943, 69.49067115783691, 69.24330139160156, 65.86514282226562, 65.12650762285504, 70.04820156097412, 69.37280191693986, 66.06069292340959, 65.45026588439941, 65.56352152143205, 63.25234917231968, 66.64377185276577, 63.214808055332725, 61.17754759107317, 57.70828424181257, 57.03736271177019, 51.571110657283235, 49.602703366960796, 48.56244339261736, 47.83990022114345, 47.861269405909944, 48.10531793321882, 45.649181842803955, 46.905565534319194, 48.63172388076782, 47.5063693182809, 48.47315556662423, 45.97194651194981, 49.50959055764334, 47.385314328329905, 50.22808640343802, 53.240321568080354, 54.183765343257356, 48.81186287743704, 50.51983778817313, 56.135142598833355, 57.56956345694405, 57.802870069231304, 55.305305344717844, 52.82598311560494, 53.94294078009469, 59.14845820835659, 63.49054731641497, 60.45684569222586, 53.172347341264995, 45.69801378250122, 45.99926682880947, 43.65106405530657, 42.06870910099575, 45.30450255530221, 44.7292924608503, 44.16863536834717, 45.77659443446568, 44.61863892418997, 44.26300927570888, 44.225013051714214, 44.90272991997855, 44.610836097172324, 45.35596786226545, 47.550334044865195, 49.153054169246126, 50.78859410967146, 51.91158281053816, 55.53457852772304, 56.99994318825858, 55.73289053780692, 55.54362508228847, 57.93555634362357, 54.03543867383684, 55.41552461896624, 55.52302367346627, 57.786041532244, 54.87263754435948, 55.91304343087332, 56.13580615179879, 52.74081904547555, 55.589222635541645, 52.095998423440115, 57.197695868355886, 56.97383533205305, 56.979671818869456, 56.074078355516704, 60.47890622275216, 56.728254726954866, 60.05332905905587, 54.87655980246407, 61.52875123705183, 59.63199724469866, 64.20229298727853, 46.20002807889666, 3.2811745277472903, 0.04555383184924722, 0.3763626930969102, 0.9488062645707811, 0.4247793150799615, 0.1800728937877076, 4.076613204819815, 6.954880586692265, 8.066271441323416, 2.3805155881813596, 0.931366394673075, 0.3103428642664637, 0.2339700838284833, 0.1953933188425643, 0.5152557172945568, 0.2924606166779995, 13.671661172594343, 33.647287436894004, 15.892949887684413, 21.641324860709055, 38.37678377968924, 8.35401805809566, 0.6311773998396737, 0.3930045243884836, 0.02272685700362282, 0.1859748728041138, 0.11210786790720054, 0.13491693112467015, 0.04303543555683323, 0.10707184206694365, 0.03303668262170894, 0.14681061862834863, 0.012029191795071321, 0.10540998088462011, 0.025343461061960885, 0.09839916029678923, 0.08500139135867357, 0.07891867096935, 0.024652220475088273, 0.07099976696606193, 0.04144204534324152, 0.05843172421944993, 0.0648051697228636, 0.1008601864533765, 0.07996035792997905, 0.08403694203921727, 0.05029834886746747, 0.2995553788329874, 7.776100771767752, 62.664128576006206, 40.54825564793178, 38.61149392809187, 20.329524074281963, 49.667564800807405, 15.093827145440237, 0.6861595266631672, 1.3090595049517495, 1.7882114052772522, 0.11818152985402516, 0.13344429300299712, 0.24845333237733158, 0.5540117919445038, 0.4483676350542477, 0.666975876050336, 0.5965634286403656, 0.9436019552605492, 5.03723509822573, 33.81201185498919, 68.97876262664795, 57.88846492767334, 78.00508403778076, 75.8467720576695, 76.8636965070452, 77.43727030072893, 73.36940574645996, 74.19989613124302, 72.6439790725708, 73.36443778446743, 70.5278218133109, 73.84041718074253, 69.43899045671735, 66.81449604034424, 66.97533294132778, 70.94918142046247, 70.68847111293248, 72.38176795414516, 70.46772684369768, 73.613009589059, 71.69955212729317, 70.08394309452602, 68.14551380702427, 73.04768330710274, 72.23312514168876, 68.63381235940116, 69.54498522622245, 69.84083257402692, 67.12747764587402, 70.83050618852887, 66.59649630955288, 62.279198374067036, 60.596469742911204, 58.28741659436907, 55.84914779663086, 51.1952235358102, 50.217417444501606, 50.214909144810264, 52.298698220934185, 52.37822035380772, 48.621968609946116, 51.26963874271938, 52.52970150538853, 49.794907910483225, 50.75750092097691, 47.55298478262765, 52.35543026242937, 50.652357305799214, 50.406359808785574, 53.50947393689837, 55.1721396446228, 50.931223256247385, 53.38116502761841, 58.26145812443325, 61.39754145486014, 61.22027901240757, 55.667622634342735, 55.201957838875906, 54.76554148537772, 60.34743935721261, 65.33416148594448, 61.171926498413086, 54.77603326525007, 48.13902711868286, 48.859645639147075, 47.21191161019461, 45.495310510907856, 49.33062580653599, 47.0970196723938, 47.768844468253, 49.69822372709002, 46.39271552222115, 46.16606528418404, 46.38734803880964, 46.71722418921334, 47.504826818193706, 48.26255566733224, 49.63816697256905, 49.67329706464495, 53.59609365463257, 53.57884127753121, 55.00540024893624, 59.595762389046804, 57.61378526687622, 58.48179939814976, 59.62215859549386, 55.90051930291312, 57.07162427902222, 57.53946386064802, 59.63584654671805, 58.48765672956194, 58.411504473005024, 60.65458447592599, 56.05674260003226, 56.849542481558665, 55.20236430849348, 60.535012926374165, 58.055374554225374, 60.3373019354684, 58.36450685773577, 61.96252727508545, 59.22381142207554, 62.75579616001674, 57.998600823538645, 62.8838723046439, 59.885460581098286, 67.73955140795026, 51.79406097957066, 12.080901503562927, 0.9186059193951743, 0.27870388914431843, 2.276853024959564, 1.022805773786136, 1.327178344130516, 2.8341867072241644, 3.266977620976312, 6.134686129433768, 2.115295248372214, 0.4654408246278763, 0.7368722025837217, 0.24845645363841737, 0.076566556468606, 0.5632767805031368, 0.38777198802147594, 14.790486165455409, 37.18684918539864, 20.132987328938075, 27.7392897605896, 45.97644199643816, 10.930348430361066, 0.5937737269060952, 0.29273224781666485, 0.12692464355911526, 0.07396674275930439, 0.050633012516690154, 0.11375442133950335, 0.029796918787594353, 0.12227312315787588, 0.015271726596568311, 0.15683514571615628, 0.04611770462776933, 0.02055871539882251, 0.02632039881843541, 0.1692339346877166, 0.2527177892625332, 0.1664702072739601, 0.10811070632189512, 0.16985658556222916, 0.1584853564522096, 0.11304170172661543, 0.15111330417650087, 0.1410260261701686, 0.1409395265259913, 0.21756153287632124, 0.26135388442448204, 0.48222142990146366, 9.302705117634364, 77.96798760550362, 46.56179993493216, 51.834228515625, 34.40326533998762, 56.353020736149375, 21.53678921290806, 0.9814503129039491, 3.656108660357339, 2.2098150679043362, 0.17491936603827135, 0.31043072098067825, 0.20473856452320302, 0.3125672106231962, 0.9907398372888565, 1.0700219316141946, 5.207258820533752, 3.867973566055298, 6.539653633322034, 36.490101201193674, 79.0302004132952, 64.46235016414097, 82.63976873670305, 78.78343514033726, 81.36671979086739, 78.77953720092773, 76.2630455834525, 76.66118431091309, 76.95831707545689, 77.78695923941476, 73.36565371922084, 79.12500163487026, 73.99053301130022, 70.92219461713518, 70.61636965615409, 73.77252633231026, 75.27535220554897, 73.43781076158795, 73.05169241768974, 74.69899913242885, 75.97091552189418, 73.72903755732945, 72.48630360194615, 77.16520663670131, 75.19495459965297, 71.77389785221645, 73.74562290736607, 71.43220629010881, 70.78470366341728, 72.59250681740897, 70.02926077161516, 66.75154536111015, 64.58244977678571, 61.98292023794991, 58.58495235443115, 55.171059199741904, 53.79041392462594, 53.48674290520804, 57.0060749735151, 56.65605252129691, 53.22923224312918, 54.00006192071097, 55.81616817201887, 55.112131527491975, 55.10347407204764, 51.60989897591727, 56.04242583683559, 53.06825637817383, 55.38764844621931, 58.690961020333425, 60.190674100603374, 55.12618773324149, 56.06645270756313, 60.17039230891636, 62.66900621141706, 65.80714620862688, 58.550885336739675, 59.53341620309012, 60.021256174360005, 66.63335650307792, 67.57859638759068, 65.9072072165353, 60.0225624356951, 48.56384692873274, 53.264480454581125, 49.79466472353254, 48.71389675140381, 51.7107173374721, 50.421083041599815, 50.56440700803484, 53.09176213400704, 50.83926037379673, 50.43105023247855, 48.19593633924212, 49.66559498650687, 50.5598281451634, 50.5717373575483, 52.9878830909729, 55.19738245010376, 56.419025148664204, 56.9972368649074, 58.70794241768973, 61.95409216199602, 61.03140613010952, 61.33288846697126, 62.97367777143206, 58.175849369594026, 61.70101792471749, 62.260452134268625, 63.920668601989746, 60.60441153390067, 60.837287357875276, 62.36690548488072, 58.33656815120152, 60.189096859523225, 58.75327246529715, 62.60927949632917, 60.720946720668245, 61.671147618974956, 59.86843054635184, 65.81625529697963, 62.08216830662319, 66.20905780792236, 59.74732344491141, 65.05228696550641, 63.03283473423549, 71.49233600071499, 56.59007937567574, 26.11856164251055, 1.6527733185461588, 0.4860397364412035, 2.5469751017434255, 1.1019732228347232, 0.9414888343640736, 7.36745810508728, 9.639892510005406, 18.466776302882604, 3.9344534959111894, 1.1498040791068758, 1.7765142215149743, 0.5011120076690401, 0.5380125333155904, 0.6579072283846992, 0.5545293784567288, 20.266917330878123, 49.55072389330183, 26.731450080871582, 33.12742321831839, 55.1377078465053, 13.030572601727076, 0.7953569814562798, 0.5618605964950153, 0.3114482792360442, 0.23243415196027073, 0.261711553803512, 0.1946750216718231, 0.1100449925288558, 0.16275248676538467, 0.2618507891893387, 0.29832283354231287, 0.1514626004334007, 0.13852411827870778, 0.09812729167086737], [0.11506832976426397, 0.05681225451241646, 0.08651959310684885, 0.09550598875752517, 0.0010771145462058485, 0.029305673004793267, 0.041738225878881555, 0.0560592909875725, 0.021463687731219188, 0.11854012204068047, 0.04883703888793077, 0.06924411188811064, 0.07321291749498673, 11.706975511142186, 48.968972069876536, 30.01800012588501, 52.07890932900565, 20.931797402245657, 51.3650027683803, 3.6399065468992506, 0.3939575675342764, 0.07045117818883487, 1.2669783915792192, 0.02264909858682326, 0.014701660489663482, 0.12527735052364214, 0.1536291627479451, 0.327841902417796, 0.7242836952209473, 1.4525766095944812, 1.679613015481404, 14.022098779678345, 39.028417110443115, 59.23988955361502, 51.88600301742554, 70.58497769492013, 68.52355834415981, 71.18070929391044, 73.17442539760044, 69.39477906908307, 71.37124279567173, 71.38060201917375, 68.0242121560233, 68.41825839451381, 67.63543265206474, 64.67217881338937, 63.49910054888044, 66.42521626608712, 65.06181294577462, 66.45148045676095, 72.00968497140067, 69.48331301552909, 69.36552020481655, 66.38889108385358, 64.65389810289655, 65.11896882738385, 70.53390148707798, 67.33253288269043, 66.04858916146415, 67.08538545880998, 67.9892349243164, 63.97766467503139, 64.81090654645647, 61.02890477861677, 59.931360380990164, 57.61432375226702, 54.22394330160958, 48.20192568642752, 51.221998419080464, 48.315445355006624, 48.77837603432791, 49.097624914986746, 47.13685369491577, 46.52998065948486, 48.07064642224993, 48.22441005706787, 46.19089814594814, 46.525968074798584, 46.85288776670183, 46.615783963884624, 49.787952763693674, 47.29600913184029, 48.04213101523263, 45.456101826259065, 46.61089243207659, 52.43807213647025, 57.380919865199495, 59.57516098022461, 59.25732258387974, 55.015377862112864, 49.72226102011544, 46.88005869729178, 49.1292461667742, 50.853368691035676, 49.392440455300466, 44.58426965985979, 46.735786301749094, 45.680448736463276, 42.52861383983067, 41.25602347510201, 44.9116861479623, 43.92461115973336, 46.7365506035941, 45.04392426354544, 43.97640650612967, 42.881728240421836, 42.397032329014365, 45.31710311344692, 45.65899269921439, 45.41800137928554, 46.24102939878191, 46.42898164476667, 50.09710938589913, 49.67431844983782, 53.633718150002615, 56.107558250427246, 53.918764523097444, 55.37677798952375, 55.52470861162458, 54.804864815303254, 51.55191625867571, 54.94405460357666, 55.986937522888184, 57.31676714760916, 57.703896454402376, 56.69339561462402, 55.06503316334316, 51.167357785361155, 52.49188593455723, 54.85903991971697, 54.14943776811872, 58.328709738595144, 57.759131159101216, 58.81196389879499, 55.90023790087019, 60.181919370378765, 58.35040201459612, 61.26501151493618, 58.38552515847342, 63.67819036756243, 47.12741109303066, 5.278648955481393, 0.22803792357444763, 0.877730915588992, 1.293130759681974, 0.16099229907350882, 0.026286034412415962, 0.3626972420939377, 3.095954877989633, 3.021479308605194, 1.971893114703042, 0.11106318860713925, 0.02489343797788024, 0.06863701303622552, 0.06274610092597348, 0.12137110584548541, 0.17134666203388146, 6.055290366922106, 34.00582490648542, 22.907224110194615, 21.28048927443368, 41.667832783290315, 9.638696551322937, 0.3148883432149887, 0.15765153190919332, 0.13644748899553502, 0.0907181506710393, 0.044400994067213366, 0.12105190940201283, 0.06526544716741357, 0.010446998257456082, 0.07130440883338451, 0.11200345493853092, 0.0423409922846726, 0.08765719777771405, 0.05073362568925534, 0.036517913320234845, 0.04923301835411361, 0.06599751859903336, 0.07514809258282185, 0.051211355054484944, 0.0901623015691127, 0.047075222712010145, 0.03834858722984791, 0.10776221752166748, 0.042310532847685475, 0.03554879907252533, 0.0771132114210299, 0.18130945600569248, 15.307461670466832, 57.102356161390034, 45.6233241217477, 54.426375593457905, 24.018538100378855, 61.06604290008545, 4.608549918447222, 0.3199675849505833, 0.13286002006913933, 0.7711892468588692, 0.5294067550982747, 0.023715694567986896, 0.5013406468289239, 1.6604582433189665, 0.9911537979330335, 0.7449281503047261, 1.4796148730175835, 4.548980840614863, 15.827855689185006, 44.97396632603237, 66.38499314444405, 58.05062893458775, 74.31533350263322, 74.1360421861921, 75.67183031354631, 75.36062049865723, 73.26425170898438, 73.38632461002895, 73.86890479496547, 70.916184425354, 72.91948904309953, 71.82317447662354, 69.61799689701625, 67.62251595088414, 69.87738009861538, 67.78406851632255, 70.7717591694423, 71.45740740639823, 69.60105718885148, 72.48409407479423, 69.00442232404436, 68.00739751543317, 68.17152786254883, 71.05002062661308, 69.502135685512, 67.60443673815045, 69.04821681976318, 70.10625376020158, 67.05574444362095, 66.73218073163713, 64.61170169285366, 62.96109458378383, 60.32188388279506, 55.86711931228638, 52.39447913851057, 53.17278160367693, 49.57660593305315, 52.86919048854283, 53.20328766959054, 49.896813665117534, 50.24261508669172, 50.552421365465435, 53.614596707480295, 50.752129963466096, 49.289631434849326, 48.248596736363, 49.01309660502842, 53.6403397832598, 50.94621399470738, 51.661458083561485, 49.61639131818499, 51.22925581250872, 57.718088150024414, 59.98453494480678, 62.55978052956717, 63.029242515563965, 59.77087088993618, 52.25565760476248, 48.33394145965576, 51.35532392774309, 52.41521603720528, 48.19120461600167, 46.915907927921836, 48.948905672345845, 48.587821687970845, 44.32226698739188, 44.57149887084961, 45.74026925223214, 47.24215364456177, 49.935654095241, 48.8513251713344, 47.399026598249165, 45.08416128158569, 44.73583418982369, 46.78243998118809, 47.606802054813926, 49.537206172943115, 48.331207343510215, 49.1108021736145, 50.644992215292795, 53.24968079158238, 55.84082038061959, 56.300051144191194, 57.06391525268555, 58.23538153512137, 58.56243324279785, 57.81859731674194, 54.615060874394004, 56.647322109767366, 58.436003821236746, 59.07645402635847, 59.923265729631694, 58.06199618748256, 57.589091369083945, 54.255821636744905, 54.716678278786794, 56.80441740580967, 56.556939942496165, 59.913183893476216, 59.691418239048545, 59.243947301592144, 58.24786744798933, 61.61575657980782, 61.779143469674246, 63.72147764478411, 62.44595514025007, 66.02684129987443, 52.21845347540719, 19.49016431399754, 1.1528533611978804, 0.5012378894856998, 1.4633523970842361, 1.585038153188569, 1.4775662400892802, 1.7521692535706928, 2.4570317566394806, 4.058703788689204, 1.597930644239698, 0.3566971740552357, 0.21655303984880447, 0.19178424536117486, 0.0887537035824997, 0.16311786430222647, 0.2032586932182312, 6.325504073074885, 37.5907792363848, 27.850179536002024, 24.751246486391338, 51.11433955601284, 12.765616944858007, 0.4227429772061961, 0.18906398490071297, 0.08803471430603947, 0.08526947375919137, 0.02366781883340861, 0.09424860908516816, 0.02204580631639276, 0.032558434177190065, 0.06242271113608565, 0.10986157094261476, 0.07198073182787214, 0.06841992254235915, 0.07288216560014657, 0.13363774333681377, 0.1370031548930066, 0.2156674973666668, 0.16082584086273397, 0.14368371213121073, 0.27103427212153164, 0.1734869514725038, 0.08667917775788478, 0.37327014761311667, 0.18096842430531979, 0.08599135359483105, 0.29490442840116365, 0.23004926421812602, 18.323938710348948, 72.54264654432023, 46.247772625514436, 73.16566371917725, 35.448232718876426, 70.10639967237199, 8.133714999471392, 0.5468888570155416, 0.22250307271523134, 2.0948047935962677, 0.3579340619700295, 0.08548835558550698, 0.9496273462261472, 0.8651400197829519, 0.5148402910147394, 2.798705513988222, 8.379405038697378, 7.5034282718385965, 19.575213738850184, 46.283496788569856, 72.15133094787598, 64.84577955518449, 80.0958525793893, 76.61414500645229, 79.88746220724923, 76.40412875584194, 76.24525124686105, 75.21896062578473, 78.12447493416923, 74.26367364610944, 77.99686431884766, 75.40809753962925, 73.86482620239258, 71.67264175415039, 75.22548498426164, 69.8769701548985, 74.25544697897774, 76.27815791538784, 74.43547480446952, 76.0060178211757, 73.22600187574113, 70.00729751586914, 70.81202398027692, 73.2581511906215, 74.54357487814767, 70.12532656533378, 73.93940121786935, 74.26684897286552, 71.67060593196324, 72.01200566973004, 68.62128475734166, 66.01930250440324, 63.32918235233852, 59.88379996163504, 56.26233632223946, 57.49937275477818, 54.13201168605259, 55.96693365914481, 57.82496881484985, 52.308783531188965, 52.51611777714321, 55.541328702654155, 56.8605032648359, 54.3723464012146, 55.990387303488596, 53.06939588274275, 53.57079873766218, 55.49742303575788, 53.70317929131644, 54.5042336327689, 50.469619682856965, 50.89286920002529, 59.42772715432303, 62.86725221361433, 65.37775448390416, 65.4870079585484, 61.02040713174002, 53.47600793838501, 49.969867025102886, 54.76628494262695, 57.024630137852256, 52.58463396344866, 50.01472112110683, 50.12952273232596, 51.762328556605745, 47.282790184020996, 48.5393580027989, 51.04433298110962, 49.69170979091099, 50.71174703325544, 51.903442995888845, 49.42427362714495, 47.269522598811555, 47.64074053083147, 48.89522736413138, 50.58860758372715, 52.83668681553432, 51.76129674911499, 51.32100330080305, 55.38091911588396, 55.91024330684117, 57.89669506890433, 59.46000848497663, 58.02529927662441, 60.9969083241054, 61.07304668426514, 59.73403154100691, 56.031315667288645, 59.960105078560964, 61.18923446110317, 61.94765813010079, 63.426179204668315, 61.16693074362618, 60.372167995997835, 58.859267234802246, 57.85825068610055, 59.99909142085484, 60.58806242261614, 63.47673429761614, 63.85885047912598, 63.697874614170615, 60.2917287009103, 65.16306209564209, 64.22185216631208, 66.81243242536272, 63.42198944091797, 68.62298706599644, 56.457483427865164, 30.48903587886265, 1.9229454440729958, 1.1198676569121224, 3.5718202803816115, 2.0490341867719377, 1.1863125200782503, 2.9984974903719763, 6.116652514253344, 10.695631333759852, 4.674993804522923, 0.5499732600791114, 0.27595848217606544, 0.36994676451597897, 0.3703007155231067, 0.196493210537093, 0.3107970213251454, 9.5044139283044, 49.08315181732178, 37.35388387952532, 34.183650153023855, 58.731503759111675, 14.564502954483032, 0.7100379339286259, 0.23790908817734036, 0.20165874835635933, 0.2727529470409666, 0.121910799028618, 0.31159033732754843, 0.14866045436688832, 0.15190075763634273, 0.2075306818421398, 0.18585983397705214, 0.1607806368597916, 0.18243844328182085, 0.10468504764139652], [0.054983555139707666, 0.11850555746683053, 0.03428066462012274, 0.019252710210691606, 0.061738150726471624, 0.12116654110806328, 0.12940003430204733, 0.07569014706781932, 0.05013794658173408, 0.09969327585505587, 0.11943939807159559, 0.15724773571959563, 0.26509519081030575, 19.052380902426584, 49.473689215523855, 25.146845647266932, 27.320388078689575, 20.400486026491436, 49.7081527028765, 0.589196329670293, 0.14315853959747724, 0.7275333351322583, 0.1447485914187772, 1.6911846974066325, 0.023444177083937184, 2.32692608663014, 3.3166915476322174, 0.2636490969785622, 0.3271524565560477, 0.08776524769408361, 1.8643745183944702, 6.000023092542376, 36.66252769742693, 57.20293133599417, 53.3357446534293, 66.60298592703683, 70.9211732319423, 68.51248291560582, 69.58660493578229, 66.73269489833287, 67.43476867675781, 69.80462551116943, 68.488205909729, 69.78124482291085, 65.6739283970424, 66.75884791782924, 62.19804341452462, 62.14177690233503, 64.46065480368478, 68.92404556274414, 67.9910067149571, 65.47183309282575, 67.86861419677734, 64.42890153612409, 65.29391751970563, 65.21774441855294, 68.6406215940203, 63.79633753640311, 66.39306000300816, 67.20291423797607, 63.99284648895264, 63.458147866385325, 63.95801516941616, 59.32881954738072, 58.36610494341169, 53.959446225847515, 51.20664290019444, 48.483907903943745, 47.947194303785054, 46.11824778148106, 45.634330068315776, 47.04612064361572, 46.140162399836946, 45.49568918773106, 45.472979000636506, 48.04230472019741, 48.61747659955706, 44.942953041621614, 44.30052954810006, 46.0953117779323, 50.692736761910574, 51.54888684409005, 52.28582320894514, 51.86650289808001, 55.73678847721645, 58.10710389273507, 61.982100350516184, 60.93276950291225, 62.18755858285086, 58.73147596631731, 54.03065136500767, 47.62405095781599, 45.82110112054007, 43.410413197108674, 45.66071237836565, 46.780685561043875, 47.57613270623343, 43.557805333818706, 39.74666976928711, 42.0685909816197, 42.46892186573574, 44.96604190553938, 45.98734719412667, 44.42729248319353, 44.00708975110735, 45.10756628853934, 44.42826523099627, 44.98000431060791, 46.328660079411094, 45.11079372678484, 44.86850309371948, 45.54138401576451, 46.407501288822715, 49.95947599411011, 50.06966747556414, 53.63994721003941, 56.01956278937203, 56.621502603803364, 57.08989109311785, 56.77609307425362, 53.94898918696812, 53.61775813783918, 53.347994327545166, 57.24377979551043, 59.122548375810894, 55.63794340406145, 55.87448787689209, 52.97648804528372, 51.81135157176426, 54.35325969968523, 52.64766802106585, 59.32202420915876, 57.82369729450771, 55.9313554082598, 56.82773208618164, 59.34140968322754, 59.624215262276785, 62.43919454302107, 61.75614493233817, 62.635099002293174, 49.450065340314595, 10.413440670285906, 2.2129141816071103, 1.707393107669694, 1.2545672804117203, 0.9156140685081482, 1.4715253242424555, 0.5070488633854049, 1.45915763931615, 3.429816254547664, 0.8724451820765222, 0.07549718527921609, 0.06366631654756409, 0.09943237914038555, 0.034049202754561386, 0.13865329777555807, 0.07803889603487082, 1.6332569143601825, 26.04223394393921, 35.42017241886684, 17.44858033316476, 37.029403005327495, 19.677710090364727, 0.3118370255189282, 0.17085160288427556, 0.04085039673373103, 0.13707064198596136, 0.05501383137223976, 0.032474102452397346, 0.02915526893255966, 0.046415140453193865, 0.035666117777249644, 0.018601722017462765, 0.055037267971783876, 0.09659095268164362, 0.1523397019399064, 0.01656374378528978, 0.09287041625274078, 0.06437271221407823, 0.03149199425908072, 0.07407726932849203, 0.10325655500803675, 0.006061279530903059, 0.07787583049918924, 0.12048696114548615, 0.12623833252915315, 0.0899162104885493, 0.1238019982618945, 0.22348804771900177, 25.09768714223589, 60.518976484026226, 38.26455647604806, 25.299745968409947, 23.477792807987758, 55.353293078286306, 0.48015135526657104, 0.0706660837999412, 0.8007416725158691, 0.20744655707052775, 1.9009561325822557, 0.07068237542573895, 1.5013535065310342, 5.040216743946075, 0.14104552726660455, 0.49370023395333973, 0.06542705385280506, 3.898867428302765, 12.929957474981036, 42.740992477961946, 65.44244221278599, 57.69492285592215, 71.79694502694267, 74.08965601239885, 71.59760120936802, 70.83217375619071, 68.7677388872419, 68.97181442805699, 73.06226062774658, 69.62607070377895, 71.32794162205288, 69.00797980172294, 68.82412351880754, 66.89579691205705, 67.9471913746425, 68.05432564871651, 71.16068458557129, 68.87658936636788, 68.4892828805106, 69.33393369402204, 66.31889493124825, 67.41912828172956, 67.77730791909354, 71.45677512032645, 67.86904498508999, 69.59033611842564, 68.95101846967424, 68.12859494345528, 67.10164424351284, 66.22238445281982, 62.39362825666155, 59.61714199611119, 58.35980987548828, 55.24736084256853, 49.99202135631016, 51.35500431060791, 48.46928889410836, 48.35232291902815, 49.57771069662911, 50.221360547201975, 49.20811169488089, 50.24698897770473, 49.25415393284389, 51.72188656670706, 49.38238293784005, 47.33506495612008, 48.51903452192034, 52.79268387385777, 55.60511663981846, 55.662880488804404, 54.0498492377145, 60.300059591020855, 61.97593035016741, 65.24428653717041, 63.86231763022286, 64.16202122824532, 63.268156324114116, 56.87133550643921, 51.18881034851074, 49.561215673174175, 46.792990820748464, 48.84620434897286, 51.01810700552804, 49.8556421143668, 46.06463548115322, 43.25051777703421, 44.450954573495046, 46.747688565935405, 48.41568354197911, 48.58394806725638, 47.095890590122764, 47.04951136452811, 48.481524671827046, 48.19027703148978, 46.74297421319144, 46.614720889500205, 46.911499295915874, 47.7473224231175, 46.05011722019741, 46.65227590288435, 50.807517528533936, 52.77309342793056, 55.849915572575156, 59.54209450313023, 58.213150773729595, 61.242464610508506, 57.23581715992519, 55.94248989650181, 56.18124737058367, 57.69695520401001, 59.131296157836914, 59.85423537663051, 57.00530024937221, 59.73297541482108, 54.531265599387034, 55.610487597329275, 56.771997111184255, 54.60604558672224, 60.57455512455532, 59.31804289136614, 58.47126592908587, 57.28475679670061, 61.09112589699881, 61.687851088387625, 64.37421921321324, 62.759888648986816, 64.54893166678292, 52.07618563515799, 22.992355176380702, 2.1392209359577725, 1.8906515198094505, 1.2738122705902373, 0.8019322029181889, 1.4741320929356982, 1.4141840125833238, 0.9522314007793153, 1.345494121313095, 0.551565591778074, 0.8311047575303486, 0.07256560187254633, 0.0920076182644282, 0.07146261605833258, 0.10022123038236584, 0.03859214398211666, 1.1818928143807819, 29.64295721054077, 37.512862137385774, 21.262516021728516, 46.441227844783235, 26.943655014038086, 0.25556302230272976, 0.09068384394049644, 0.044847561711711545, 0.09091539401561022, 0.1012663303741387, 0.11193725706211158, 0.0730366273117917, 0.02926113735884428, 0.012631184670941105, 0.027129589147599678, 0.056924202612468174, 0.09739268251827785, 0.07707969179110867, 0.12325028143823147, 0.1258874349296093, 0.17995336305882248, 0.08323253198925938, 0.10868786142340728, 0.24731084225433214, 0.12435929264341082, 0.15617095492780209, 0.15223550610244274, 0.3080939006592546, 0.21101143078080245, 0.47573436370917727, 0.3099331919636045, 30.600356442587717, 72.36610671452114, 37.401319231305806, 42.98504100527082, 34.22471400669643, 65.54886082240513, 0.8850142019135612, 0.1808766863707985, 0.7714223914912769, 0.45110324397683144, 2.5686256885528564, 0.19153307883867196, 8.21057162966047, 7.477336049079895, 0.4977683499455452, 1.8544870146683283, 0.22056755157453672, 5.106664972645896, 20.45284938812256, 58.79555920192173, 75.58864648001534, 62.64001137869698, 74.44697407313755, 79.15630326952252, 76.29513931274414, 74.5254122870309, 70.25822475978306, 71.87131159646171, 76.35679067884172, 73.36259651184082, 76.8942824772426, 75.03201239449638, 73.92925684792655, 70.60719803401402, 71.26075254167829, 70.98219231196812, 75.90132931300572, 73.23889078412736, 71.68507902962821, 71.87186745234898, 68.39045865195138, 71.0191706248692, 69.59835433959961, 74.77252496991838, 71.49844346727643, 71.9243471963065, 72.21465682983398, 68.60056522914341, 68.31236784798759, 71.2834939956665, 63.19425528390067, 64.5104455947876, 62.91896765572684, 57.926131112234934, 53.32931409563337, 54.30339247839791, 53.59951564243862, 51.87853022984096, 54.73841919217791, 53.865318979535786, 53.16075079781668, 53.32350887571062, 52.65981347220284, 55.75053201402937, 52.06475584847586, 51.937735830034526, 51.7007987839835, 54.6355094228472, 59.06186975751604, 57.725505352020264, 55.97473301206316, 61.49168259756905, 62.904438972473145, 68.5337027141026, 65.58037785121373, 67.66931206839425, 65.76191343579973, 58.949538230895996, 51.49461099079677, 49.91416679109846, 47.873918601444785, 51.119953700474326, 52.95389250346592, 51.8355313028608, 47.739040170397075, 45.01435620444161, 46.61588818686349, 48.186184542519705, 51.28388602393014, 52.61986480440412, 49.61086055210659, 51.403252601623535, 53.358145645686555, 50.37127488000052, 49.02798312050955, 49.83878231048584, 48.34492308752877, 49.4415294783456, 48.01182644707816, 49.44467353820801, 54.896473339625764, 54.75011995860508, 58.11538961955479, 61.802941049848286, 61.27120235988072, 63.23775100708008, 59.85929366520473, 59.43676676068987, 57.77752998897007, 61.51675864628383, 62.854154859270366, 64.94293621608189, 60.714345932006836, 62.55062975202288, 57.263012409210205, 59.85192857469831, 59.894736426217214, 56.972782679966514, 64.38480131966728, 63.241864340645925, 61.52609702519008, 61.31221062796456, 64.71850940159389, 64.16177804129464, 66.84053788866315, 65.42749663761684, 67.0333365031651, 55.212984630039756, 32.0667633329119, 3.938712307385036, 2.299171507358551, 2.247235242809568, 2.602081264768328, 3.8832261647496904, 2.1878548519951955, 3.4751070014068057, 7.746690784181867, 1.1076158114842005, 0.475779689848423, 0.16321701183915138, 0.22409532298999174, 0.20845496867384228, 0.33951639596905026, 0.19173506514302321, 2.718116832630975, 38.38198798043387, 53.36821011134556, 34.293918064662385, 49.67876182283674, 30.247071811131068, 0.7421933827655656, 0.19389474711247853, 0.1529247076915843, 0.1832788089024169, 0.15918044772531303, 0.20045547506638936, 0.27890348700540407, 0.20275359175034932, 0.1327768995293549, 0.1428621962134327, 0.16655762972576277, 0.09957540753696646, 0.21583951956459455], [0.03910283997122731, 0.04593492425712092, 0.0591110870508211, 0.09091295128954308, 0.08606868623090641, 0.09373879179890666, 0.0225734724663198, 0.15950005128979683, 0.1381679145353181, 0.1388577946594783, 0.17347979971340724, 0.11998523878199713, 1.3909095014844621, 52.42447451182774, 33.15929807935442, 40.67826339176723, 27.29534329686846, 31.67956801823207, 39.91321808951241, 0.25208482465573717, 0.06584339615489755, 0.2388867757150105, 0.0781963975833995, 0.3950835828270231, 1.1671800038644244, 0.5409730630261558, 5.2317599058151245, 1.2521810084581375, 0.13054320296006544, 0.14312207512557507, 0.8128765385065759, 6.975149350506919, 17.380864926746913, 47.168085847582134, 51.51982600348336, 63.48530142647879, 66.19941370827812, 68.3986644744873, 68.60018307822091, 69.42971461159843, 70.68404511043003, 68.26694052559989, 65.28985977172852, 67.74749319893974, 63.73000308445522, 62.58442578996931, 65.14492729731968, 67.04792772020612, 66.6624972479684, 65.97001893179757, 66.20191505977085, 64.5807683127267, 65.86269705636161, 62.36703750065395, 63.69586658477783, 66.53193364824567, 66.17888872964042, 65.2811050415039, 66.7500445502145, 66.0456987108503, 66.15860693795341, 61.64293098449707, 60.7189108984811, 57.29091984885079, 54.79765258516584, 50.125548362731934, 50.65122127532959, 48.527170862470356, 49.598193986075266, 47.43178040640694, 46.08950655800955, 44.66069637026106, 46.60080712182181, 44.96803603853498, 46.25368554251534, 46.31636871610369, 45.287795611790244, 43.3138610294887, 43.10577637808663, 43.279668944222585, 50.09333651406424, 55.14167179380144, 50.43848480497088, 50.3184095110212, 58.21419300351824, 59.853936604091096, 61.166611126491, 62.21234975542341, 62.56476933615548, 60.03223432813372, 58.60202407836914, 52.42288337435041, 48.98596041543143, 49.38758019038609, 50.71898010798863, 51.47781024660383, 47.58981023515974, 44.150000299726216, 40.571480001722065, 43.01958050046648, 44.43683583395821, 44.09303896767752, 46.2652473449707, 45.83941657202584, 44.629808153424946, 42.89578444617135, 45.75178936549595, 44.76827185494559, 46.526002815791536, 45.33200005122593, 44.92792061397007, 44.45366089684622, 47.09020001547677, 46.30247579302107, 48.80859375, 52.45253481183733, 54.54854924338204, 55.698382309504915, 57.53191464287894, 56.340218680245535, 53.49471248899187, 53.167320319584434, 53.564045088631765, 54.66977446419852, 56.93772554397583, 56.685731751578196, 54.4573506627764, 55.28947387422834, 52.13425867898123, 53.38161318642752, 53.48632948739188, 54.19840519768851, 56.87527166094099, 56.06418759482247, 56.389193058013916, 57.65112141200474, 60.13667270115444, 59.777992793491904, 62.69999517713274, 60.8233562197004, 51.74071618488857, 22.7507506779262, 2.7391883305140903, 2.077635360615594, 1.4612480700016022, 1.6001816434519631, 1.4036267676523753, 0.5093596279621124, 1.4925019357885634, 2.9782465313162123, 0.5231233036943844, 0.03563006381903376, 0.3436807825097016, 0.038023484139037986, 0.07337321460779224, 0.19051994463162764, 0.08406834463988032, 0.414103272237948, 13.539090412003652, 42.64324174608503, 20.192929438182286, 25.910315445491246, 31.603836127689906, 0.11429770397288458, 0.04163521408502545, 0.02325682169092553, 0.07436270865478686, 0.07490903112505164, 0.03124028830123799, 0.1980435952012028, 0.03893110275800739, 0.02288033314315336, 0.04060760672603335, 0.02652471249790064, 0.014617878378235867, 0.018249574217147062, 0.026547297535996352, 0.016858555376529694, 0.04738474324611681, 0.06735570143376078, 0.02514207356476358, 0.32736638507672716, 0.0939940566729222, 0.14001591822930745, 0.14048611585583004, 0.010991079017652996, 0.08348881466580288, 0.17780570472989762, 2.8779666551521847, 63.034960883004324, 46.48856244768415, 50.25640031269619, 18.45335759435381, 36.673283508845735, 43.702723911830354, 0.23252320289611816, 0.02774651997190501, 0.2300834081002644, 0.12048697471618652, 0.20996905171445437, 1.2753206810780933, 0.4308235150362764, 2.8881983118397847, 0.8652724698185921, 0.025445743430671946, 0.11772031603114945, 2.9871085243565694, 17.088974578039988, 30.580345630645752, 55.20126649311611, 58.531076022556846, 65.37050751277378, 71.3137811933245, 69.45236573900495, 74.12798227582658, 70.777845791408, 74.23465102059501, 70.12750829969133, 70.2581205368042, 71.60032490321568, 68.7453865323748, 66.55126353672573, 70.36355945042202, 70.01553113119942, 70.3013174874442, 67.35224492209298, 68.31529303959438, 66.9832330431257, 69.3292714527675, 67.21000834873745, 66.42091533115932, 70.22681195395333, 67.39332267216274, 67.88798577444894, 69.73744337899345, 67.9519647870745, 67.6312289919172, 64.98960726601737, 62.90360518864223, 61.700746944972444, 58.880327224731445, 53.16421447481428, 53.31511892591204, 53.20965569359915, 50.368631090436665, 50.53403295789446, 47.6288799558367, 47.257432733263286, 50.69466836111886, 47.46220656803676, 48.96425076893398, 48.47720636640276, 49.74192442212786, 46.31183501652309, 45.40590109143938, 45.74736336299351, 52.345820903778076, 58.16308552878243, 53.9620691708156, 50.676693371364046, 61.834513664245605, 64.08068561553955, 63.84620475769043, 63.62105533054897, 66.56117861611503, 61.18355083465576, 62.117451259068076, 55.42850037983486, 54.891654763902935, 52.046245847429546, 51.33965226582119, 54.40817131314959, 48.89683239800589, 46.70052419389997, 43.58173492976597, 44.88497379847935, 44.77217326845442, 45.11444500514439, 47.446274348667686, 47.202465534210205, 47.45089142663138, 46.6147278376988, 46.78970432281494, 45.83362872259957, 47.75161640984671, 47.29202781404768, 47.06515523365566, 46.469295092991416, 48.738931110927034, 48.901133332933696, 51.972660950251985, 52.78736502783639, 56.94257538659232, 56.442572593688965, 59.225701332092285, 59.68064853123256, 57.91508000237601, 55.76382391793387, 55.66978699820382, 56.23032944543021, 60.46425942012242, 56.845665386744905, 57.8446078981672, 57.52168689455305, 55.481678417750764, 55.657686710357666, 55.64322403499058, 56.22563941138131, 58.908787046160015, 57.64127581460135, 58.83412865230015, 59.38355050768171, 61.20072678157261, 62.5929651260376, 65.53994628361293, 61.19462626320975, 53.702567849840435, 32.50204018184117, 10.2927964925766, 4.307173107351575, 2.719009893281119, 2.4267903736659457, 1.048223804150309, 0.27166908234357834, 2.400051317044667, 1.6078936010599136, 0.4801835449678557, 1.575299818600927, 0.4614536442926952, 0.06314072332211904, 0.056326925554977994, 0.08089911112827913, 0.03768657793157867, 0.2941565199622086, 15.593604121889387, 48.54833507537842, 21.42646745273045, 30.120447840009415, 40.21080943516323, 0.21330596479986394, 0.035104460415563414, 0.02472373467337872, 0.040999518374779394, 0.09619115984865598, 0.015574609361855047, 0.09443294669368438, 0.0402155457995832, 0.03755001936640058, 0.04011055268347263, 0.1612426242125886, 0.13633964263967105, 0.02495138317213527, 0.10143640517656292, 0.10480613900082451, 0.2149515479270901, 0.15335407108068466, 0.16721621581486293, 0.5173437595367432, 0.14918318417455467, 0.3745824343391827, 0.23691723282848084, 0.3065346543278013, 0.2872594829116549, 0.26280103677085465, 4.0065123949732095, 76.81377370016915, 47.53163644245693, 60.41744245801653, 47.5232048034668, 46.620380197252544, 56.171749183109824, 0.34761522710323334, 0.10771254875830241, 0.39287489705852097, 0.33340578100511004, 0.7767259297626359, 1.4017977629389082, 0.9924614706209728, 18.919227361679077, 2.8775719106197357, 0.2569415883294174, 0.379428287169763, 5.286208161285945, 30.024760723114014, 50.38199247632708, 67.21233599526542, 66.62396253858293, 70.77785968780518, 74.46802016666958, 73.65071746281215, 77.62476743970598, 75.04017652784074, 77.89919349125454, 74.2981367111206, 74.73456696101597, 74.58504867553711, 73.67231246403286, 69.198228427342, 73.3327887398856, 74.48142324175153, 74.95735400063651, 69.65139688764299, 71.38603551047188, 69.66810035705566, 75.4842289515904, 67.40928268432617, 69.85304750714982, 72.9437313079834, 70.36375399998256, 69.48131888253349, 73.79269000462124, 72.26348182133266, 71.57440117427281, 65.96332781655448, 67.48017515454973, 64.44466699872697, 62.211752210344585, 55.69515139716012, 56.88850450515747, 54.996367590767996, 55.89554786682129, 55.12330770492554, 51.18060105187552, 51.99286978585379, 54.50686700003487, 52.580308709825786, 53.66058683395386, 52.790818282536094, 54.17304079873221, 48.0376945904323, 48.68237624849592, 47.287445477076936, 55.84885944638933, 61.164457184927805, 57.098548548562185, 55.52864129202706, 64.09485299246651, 65.8125866481236, 66.17047446114677, 68.02419825962612, 67.98252991267613, 63.06925024305071, 63.55898707253592, 58.86746610913958, 55.06026322501046, 53.39082302365984, 55.97053977421352, 56.85747732434954, 52.901079245976035, 49.866422244480674, 45.31564746584211, 49.316489696502686, 48.25306442805699, 49.446695463997976, 51.892252922058105, 50.82214001246861, 50.49863536017281, 48.70524624415806, 51.81997428621565, 49.109638350350515, 51.53961794716971, 50.62441859926496, 50.21977635792324, 47.60153879438128, 51.752451692308696, 50.76784678867885, 54.68434831074306, 55.96625620978219, 59.767334256853374, 59.59021772657122, 60.85467869894845, 61.240963799612864, 59.82513632093157, 58.963274819510325, 58.295490401131765, 58.396148954119, 63.36734880719866, 61.137873377118794, 60.53556183406285, 58.98226424625942, 57.81571728842599, 58.447141783578054, 59.303382192339214, 58.476185253688264, 62.31086131504604, 59.73536559513637, 61.111143657139365, 61.69427122388567, 63.9954868044172, 65.95196056365967, 68.26206983838762, 64.54740306309291, 57.32246814455305, 44.9312870161874, 15.537042311259679, 4.7716849361147196, 4.279746830463409, 3.9583713667733327, 2.1836207934788296, 0.684163222355502, 4.824623261179243, 5.344141372612544, 1.7354065073387963, 0.9262997465474265, 0.7126291777406419, 0.2936290811215128, 0.2337523555116994, 0.21688318784747804, 0.16954159603587218, 0.6795317594494138, 22.775880575180054, 62.5911933353969, 34.23333672114781, 38.387918267931255, 47.27630056653704, 0.289840358708586, 0.09058397715645176, 0.1328104463006769, 0.14373792707920074, 0.22417483372347696, 0.11509176636380808, 0.23892249379839214, 0.11243364614035402, 0.13384338015956537, 0.12267259029405457, 0.2774097871567522, 0.1941707751580647, 0.09846212156116962], [0.0362246470924999, 0.06511340104043484, 0.10243416378008467, 0.10511013625987939, 0.08451201154717378, 0.21484395941453321, 0.05218798068485089, 0.03189705252381308, 0.1605353057384491, 0.09739754761436156, 0.04807688967723932, 0.33066113399607794, 25.61464180265154, 69.2721642085484, 25.78272567476545, 30.746292931692942, 15.379262617656163, 34.08620514188494, 22.968696560178483, 0.3738703525492123, 0.023669477851529206, 0.16405425619866165, 0.16784761979111604, 0.0738696443981358, 0.9244227558374405, 0.12607456131705216, 2.67156411920275, 0.5649661155683654, 0.11139723139681987, 0.20401251848254884, 1.6587549575737544, 3.6139493797506606, 8.898296509470258, 45.37608984538487, 49.96452733448574, 60.887342180524556, 66.90175151824951, 66.6043199811663, 65.92568247658866, 68.32923807416643, 67.94170924595424, 66.82523100716728, 66.84445667266846, 66.82913589477539, 62.169236183166504, 63.45887047903878, 64.67910616738456, 66.74862016950334, 68.3823709487915, 62.74478326525007, 66.68772615705217, 66.30308083125523, 64.97304276057652, 63.66104916163853, 65.7276588167463, 67.69063608986991, 64.30485534667969, 67.18127754756382, 64.60054983411516, 64.81420694078717, 61.48761790139334, 60.05462837219238, 58.47296823774065, 58.28347001756941, 52.49378974097115, 49.68047455378941, 48.40351377214704, 48.767738342285156, 48.87427854537964, 45.63290221350533, 47.3197546005249, 44.87109129769461, 43.946654319763184, 47.3040759904044, 46.99752146857125, 47.58157661982945, 45.997206687927246, 44.80432258333479, 45.15139899935041, 46.187479632241384, 48.72437116077968, 52.831107412065776, 52.10672991616385, 46.04302658353533, 55.43002898352486, 63.4754558290754, 60.59363487788609, 59.774873052324565, 59.300700187683105, 60.611262457711355, 61.52395003182547, 53.32318231037685, 50.25564643314907, 51.270000049046104, 48.509452956063406, 48.370655741010395, 44.88931294849941, 44.02350834437779, 42.03971079417637, 44.758554799216135, 40.299009868076865, 45.02977773121425, 41.490174293518066, 42.860195772988455, 43.682650566101074, 43.98803431647164, 42.94745472499302, 44.522281306130544, 43.07502365112305, 43.50968905857631, 44.62828302383423, 45.05757747377668, 45.005031721932546, 45.690402030944824, 47.694509165627615, 49.5944766998291, 53.224611691066194, 54.878192629132954, 54.72655166898455, 58.441277503967285, 56.92432941709246, 55.08796221869332, 53.5609427179609, 52.40085063661848, 55.08650309698922, 56.64582824707031, 56.31653921944754, 55.66344329289028, 55.386460304260254, 51.10551186970302, 53.34576742989676, 55.80878571101597, 56.31020246233259, 57.493452889578684, 55.7614198412214, 56.90802199499947, 56.400313649858745, 59.15724767957415, 61.21228163582938, 62.34731156485421, 44.971305165972026, 36.31487110682896, 17.99859278542655, 1.8068385486091887, 1.689176776579448, 0.21815321541258267, 0.4703761083739144, 0.24462435926709855, 0.415419195911714, 0.6322188153862953, 0.6250647221292768, 2.563252559729985, 0.4622892737388611, 0.09845261528555836, 0.05816450355840581, 0.06713178487760679, 0.18077770168227808, 0.08460609721285955, 5.001399329730442, 41.12977818080357, 36.12344823564802, 25.48465837751116, 35.06555025918143, 0.3336421554642064, 0.06957363563456706, 0.05675287252025945, 0.05156271745051656, 0.037662381372813664, 0.06710036192089319, 0.0789786127528974, 0.04025012733680861, 0.07468188474220888, 0.10544828418642282, 0.1280087118170091, 0.1763337587139436, 0.1013126132477607, 0.003872472293941038, 0.055494067924363275, 0.06630967863436256, 0.027597003084208285, 0.07261203402387244, 0.14701118000916072, 0.1369360342089619, 0.16526818248842443, 0.42884026574237005, 0.3574624801320689, 0.09682603792420455, 0.18650570431990282, 39.07634231022426, 75.79068619864327, 37.78594371250698, 39.00220503125872, 19.94484748159136, 43.07692398343767, 28.368054832730973, 0.2889266163110733, 0.021234940005732433, 0.21581627295485564, 0.3671414293348789, 0.09927425333963973, 1.0436385359082903, 3.212635976927621, 0.7739533271108354, 0.16906398880694593, 0.26262089929410387, 0.3800816892513207, 4.117935878889901, 12.41410149846758, 20.67770004272461, 52.94689219338553, 56.048585414886475, 64.34357070922852, 69.95076002393449, 70.14315564291817, 68.52775505610875, 73.4483859198434, 70.77189813341413, 70.54210730961391, 69.94112982068742, 70.27414308275495, 63.23109463282994, 68.2527800968715, 69.74572563171387, 70.88281917572021, 72.47106620243618, 66.91731548309326, 68.41381849561418, 69.34175736563546, 67.84530299050468, 65.91573960440499, 66.98871517181396, 70.0375291279384, 66.81017426082066, 69.57082557678223, 66.94674110412598, 68.66169548034668, 63.55814634050642, 63.94837801797049, 61.46045044490269, 60.85725648062569, 54.19924592971802, 52.939558369772776, 50.67233337674822, 51.900045326777864, 50.378671237400596, 51.60274927956717, 48.716304302215576, 47.639938013894216, 47.55502755301339, 51.43735088620867, 49.192645004817415, 48.49659184047154, 49.37151248114449, 47.66084514345442, 47.878532205309185, 47.16928441183907, 50.33953550883702, 54.51038973672049, 55.63966308321272, 49.74682290213448, 57.35843896865845, 64.05266353062221, 63.20713029588972, 61.30370603288923, 61.470615659441265, 61.034011704581125, 61.9931549344744, 53.67536217825753, 53.214460372924805, 55.32604571751186, 49.58143493107387, 53.33083922522408, 45.91985934121268, 47.94380358287266, 46.18882758276803, 47.096314430236816, 42.414079734257285, 48.76561566761562, 43.494013922555105, 45.596038545881, 46.07093054907662, 46.19869749886649, 46.73659576688494, 46.186510358537944, 46.65796300343105, 46.20924139022827, 46.415276323046, 46.12738813672747, 46.969468116760254, 48.546806471688406, 49.705321311950684, 51.7182491847447, 56.083639076777864, 57.17993974685669, 56.64309065682547, 59.7374917439052, 59.80935001373291, 57.69282449994768, 57.38119431904384, 53.766605922154014, 59.30610588618687, 58.76454939161028, 59.55510153089251, 58.10664183752877, 56.980029651096885, 54.166940280369346, 55.16616071973528, 57.588816915239605, 59.17386777060372, 59.30225658416748, 58.352493422372, 58.8435504095895, 57.13016980034964, 62.1850711277553, 63.83345481327602, 65.39266531808036, 46.467992305755615, 43.68988364083426, 31.440765380859375, 5.928461858204432, 2.785427723612104, 1.3657395435231072, 0.475054851600102, 0.2550455443561077, 0.554788524551051, 0.9295847245625087, 0.9444115289619991, 1.8770638832024165, 0.8772815082754407, 0.11725492243255888, 0.11937375659389154, 0.06180426717868873, 0.17924392755542481, 0.050416661625994105, 3.8980028118406023, 46.5146598815918, 36.35832861491612, 27.77581991468157, 50.19918189729963, 1.1683696657419205, 0.050157335719891956, 0.0346147854413305, 0.05082392852221217, 0.0133637259880613, 0.06438325664826802, 0.07265177581991468, 0.03915359439062221, 0.03805353306233883, 0.1574141803596701, 0.18607791513204575, 0.09690758426274572, 0.05122976710221597, 0.1499134778444256, 0.09668153710663319, 0.17893269711307117, 0.1892663783260754, 0.12502688967755862, 0.4103237236184733, 0.4036535072539534, 0.22298844238477095, 0.45457959600857323, 0.49591415801218575, 0.12438106004680906, 0.4053730235568115, 43.817219802311485, 89.71332672664097, 37.4499705178397, 45.65471955708095, 29.146091529301234, 50.865236214229036, 36.20089980534145, 0.3386425514306341, 0.16718854515680245, 0.32199189918381826, 0.8764675376670701, 0.21319691065166677, 2.1502946274621144, 4.48663422039577, 6.190559199878147, 1.239032085452761, 0.12815703957208566, 0.340790793299675, 5.464222746235984, 17.27762164388384, 42.35662160600935, 65.31847245352608, 64.54972376142229, 64.46430260794503, 76.82878875732422, 71.29299913133893, 74.5666081564767, 74.1145236151559, 75.7730655670166, 72.23483439854213, 75.77487209865025, 73.29244055066789, 69.66564764295305, 70.4358971459525, 72.34524822235107, 74.25116688864571, 76.07905728476388, 67.92319229670933, 72.40362003871373, 73.42139216831752, 70.76271261487688, 70.73913737705776, 70.33612796238491, 73.88428810664585, 69.23677703312465, 72.48893696921212, 71.04256520952497, 71.32637132917131, 65.65150656018938, 68.01479039873395, 66.20568098340715, 65.7380324772426, 55.44918169294085, 57.66334329332624, 55.24899366923741, 55.491669927324565, 55.30271019254412, 53.63616739000593, 52.51574604851859, 51.28791945321219, 51.268527030944824, 56.06838778087071, 52.78933136803763, 53.16972092219761, 52.85875082015991, 53.96227414267403, 50.318510259900776, 51.32600252968924, 53.225709506443565, 57.953194345746724, 58.63439573560442, 52.582716260637554, 62.225773675101145, 67.87562492915562, 65.44379711151123, 65.54601206098283, 63.49716894967215, 67.09814929962158, 65.13132272447858, 58.57352951594761, 52.221350874219624, 53.36751529148647, 53.209134578704834, 54.59834003448486, 50.2951260975429, 48.446974754333496, 48.047585351126536, 49.20025328227452, 46.52877862112862, 52.94325828552246, 46.95524862834385, 48.960679394858225, 51.80197497776577, 50.620260102408274, 50.07144968850272, 49.754500661577495, 49.210818018232075, 48.72634097508022, 47.67194141660418, 47.60502331597464, 49.739093031202046, 49.486929007938926, 52.11973694392613, 54.648506028311594, 58.929332869393484, 59.92120211465018, 59.29607963562012, 61.157099042619976, 63.67589051382882, 60.55075754438128, 58.88460731506348, 57.001999855041504, 60.65543910435268, 61.15444483075823, 60.8436519077846, 60.300789151872905, 60.085457529340474, 57.90734665734427, 59.26754338400704, 61.590076037815635, 61.03454671587263, 63.45256846291678, 60.595629010881694, 62.41461876460484, 59.091267585754395, 64.43941416059221, 66.24531350816999, 68.10862582070487, 50.12844923564366, 51.86802107947213, 40.79593113490513, 9.94743193898882, 3.494710475206375, 1.6392624378204346, 0.9319310443741935, 0.6056927101952689, 0.6641264089516231, 1.6441383361816406, 1.0271976866892405, 5.333587058952876, 1.333825707435608, 0.20851728532995495, 0.2851402280586106, 0.189718309789896, 0.3155940739171845, 0.14653054651405129, 7.4427036217280795, 60.27455275399344, 56.62901013238089, 41.01142256600516, 54.06937020165579, 1.3931437815938676, 0.20833509867744787, 0.1987108393971409, 0.13847132825425693, 0.14511061699262687, 0.17833344212600163, 0.10410252532788686, 0.16631194576621056, 0.17922794127038547, 0.23900543791907175, 0.2723897136747837, 0.2076247946492263, 0.12372887932828494], [0.1329663736479623, 0.0811394007344331, 0.12121428283197538, 0.055580893265349526, 0.07770755381456443, 0.30752306271876606, 0.2278745323419571, 1.8219816046101707, 6.497372542108808, 16.946665048599243, 23.76445984840393, 15.286783831460134, 54.911662101745605, 48.428176403045654, 31.440365859440394, 27.950186695371354, 20.669188499450684, 42.0774256161281, 15.03068539074489, 0.2456558139196464, 0.10115948825010232, 0.10313225417797055, 0.09555043958659683, 0.1539104019424745, 0.029939088837376664, 1.0171277927500861, 0.9689987067665372, 0.3473105105970587, 0.04808018735742994, 0.08436049467750958, 0.8587754698736327, 2.097394300358636, 5.446848775659289, 37.800482818058555, 53.01704815455845, 56.666315010615754, 68.22093650272915, 64.10710961478097, 67.4455383845738, 68.4211905343192, 67.33426993233817, 66.05770519801548, 66.290344783238, 65.43725885663713, 60.09087017604283, 64.60478823525565, 63.60285105024065, 68.38046714237758, 65.55732372828892, 63.464234488351, 64.61849008287702, 65.38116604941231, 63.66870607648577, 65.48527785709926, 64.77285126277378, 67.18372331346784, 64.7104355948312, 66.2749684197562, 63.19925103868757, 64.27307428632463, 63.10875770023891, 61.88873045785086, 57.460164070129395, 57.644162791115896, 49.03935384750366, 48.210975715092246, 48.30658640180315, 48.12015928540911, 50.00285012381417, 50.78118732997349, 48.61069515773228, 46.89773838860648, 45.359827586582725, 46.306349413735525, 47.86520208631243, 46.22032029288155, 45.141428334372385, 41.87847784587315, 43.42497662135533, 47.282446248190745, 48.624060017721995, 51.15865516662598, 51.86528696332659, 51.3481707572937, 48.77532924924578, 51.870772566114155, 53.43284225463867, 56.35491064616612, 56.819512367248535, 56.387278829302105, 53.27749443054199, 51.854666641780305, 44.985420431409565, 49.07438319069998, 50.301184926714214, 48.46608230045864, 47.88441732951573, 45.56609875815255, 44.471267632075715, 42.98149742398943, 41.649517331804546, 42.593249457223074, 41.5819912637983, 42.858034883226665, 42.78595079694475, 45.1750819342477, 42.22842386790684, 42.44088241032192, 44.27035699571882, 43.73587029320853, 43.79626750946045, 43.87271853855678, 45.17525563921247, 44.007718563079834, 49.7531144959586, 49.575862475803916, 51.95828512736729, 54.31441232136318, 55.80202511378697, 54.279320444379536, 55.52680001940046, 55.47467810767037, 54.91274949482509, 52.01723711831229, 53.49250643593924, 53.65065090996878, 57.32648072923933, 53.55427939551217, 54.94781010491507, 52.89779969624111, 52.921378408159526, 54.080330984933035, 53.891249656677246, 53.228558267865864, 57.78064278193882, 55.78868109839303, 54.471858501434326, 59.91482366834368, 61.21227468763079, 62.79828439440046, 36.373958587646484, 45.106843675885884, 35.655480112348286, 11.329584973199026, 0.32870928730283466, 0.28773586877754753, 0.299514395317861, 0.06149688402989081, 0.09697553954486336, 0.6015214025974274, 0.37037738998021397, 5.58847781590053, 0.29608855343290735, 0.07306877630097525, 0.08155208573277507, 0.0179060149738299, 0.28965509150709423, 0.015491663544837917, 1.173295721411705, 27.136872257505143, 32.17624262401036, 18.955457006181987, 36.02276883806501, 16.208632605416433, 0.14752203545400075, 0.0581737452053598, 0.040389651100018194, 0.023071790280352746, 0.10091682377138309, 0.005367238714825362, 0.048394834223602495, 0.17334459482559136, 2.02387758237975, 3.691011198929378, 4.325911096164158, 1.9150698781013489, 0.3658624993903296, 0.035083995799400976, 0.14459083202694142, 0.03549267404845782, 0.12678884156048298, 0.5018307119607925, 0.20555353936340126, 1.9483647772244044, 6.4380844320569715, 20.27073884010315, 26.51379428591047, 24.855370453425817, 64.71516036987305, 55.71302911213466, 40.30638190678188, 24.935625621250697, 22.284651620047434, 48.81379795074463, 18.309856448854717, 0.3392196590346949, 0.08559688047638961, 0.15139621256717614, 0.25879548170736855, 0.11555497507963862, 0.13526196618165287, 0.9662075936794281, 0.34562234261206215, 0.645576781460217, 0.33536411449313164, 0.37615362288696425, 3.2127458453178406, 7.036765107086726, 9.932607957295009, 44.27819456372942, 59.73753343309675, 64.21628665924072, 67.3985824584961, 70.56682205200195, 69.27738925388881, 74.18652084895542, 68.75289058685303, 70.10591329847063, 68.71361242021833, 68.86321408408028, 63.12466212681362, 67.58339759281704, 66.81025763920375, 69.57989992414201, 68.80742004939488, 66.71296201433454, 67.5277772630964, 67.81399440765381, 66.93515150887626, 67.89327335357666, 68.06866673060826, 69.17106097085136, 67.85617692129952, 68.35345254625592, 66.89319828578404, 65.85315717969621, 64.9336325781686, 65.03729275294712, 59.91824913024902, 60.02158273969378, 52.226051330566406, 51.54594775608608, 51.84842021124703, 51.76312065124512, 52.04217072895595, 52.61521993364607, 50.64986637660435, 47.39082077571324, 49.907156058720176, 48.74884271621704, 49.27037797655378, 47.495349475315635, 48.08208663122994, 44.80774457114083, 46.13859558105469, 51.55967739650181, 51.86002022879464, 52.35703182220459, 54.343810149601524, 56.50396340233939, 53.02876281738281, 54.91371529442923, 57.429345335279194, 59.39436190468924, 59.6192820412772, 58.0856374331883, 56.164703709738596, 54.248046602521626, 48.713934966496055, 52.47839948109218, 51.27562461580549, 50.980871609279085, 50.62483549118042, 48.55350800922939, 47.95373950685774, 45.217392989567344, 44.024071148463655, 45.242281436920166, 43.04323216847011, 46.32935837336949, 46.79733344486782, 47.819072995867046, 44.48170730045864, 43.57775361197335, 47.74197578430176, 47.313866002219065, 45.47838817323957, 46.42902333395821, 47.84683799743652, 45.3688428742545, 50.30108070373535, 51.93626628603254, 54.37384373801095, 57.46196712766375, 58.79384994506836, 57.804353509630474, 59.87922804696219, 57.54601601191929, 56.6743540763855, 54.62985011509487, 56.570016452244346, 58.570076261247905, 59.49803597586495, 57.09289271490914, 56.111886978149414, 55.19961282185146, 55.50896399361746, 55.54972560065133, 56.84065920966012, 57.38639504568917, 60.83752359662737, 58.15338931764875, 56.75254562922886, 60.920158522469656, 62.64987087249756, 64.54570075443813, 39.81416457039969, 51.4344812801906, 46.33691453933716, 21.025254147393362, 2.8674874688897813, 0.5416342275483268, 0.4876057952642441, 0.05057377640956214, 0.31485843339136665, 1.2522216119936533, 0.5083382970520428, 0.7495494080441338, 0.8922531391893114, 0.06972211266734771, 0.14665371419063636, 0.07906963822564908, 0.13839318816150936, 0.021960621333814094, 0.8241270290953773, 29.990453992571148, 40.6016525541033, 25.732286964144024, 46.19529288155692, 33.561313901628765, 0.16789876776082174, 0.06341521787856307, 0.047555747641516585, 0.03068931108074529, 0.12366626411676407, 0.017010542131694298, 0.08161014118897063, 0.35177223118288176, 3.2444732742650166, 6.130272720541273, 6.728512184960501, 3.015854741845812, 0.3201194682291576, 0.1802099035786731, 0.198956591210195, 0.2863124651568276, 0.20517525609050477, 0.6092881858348846, 0.338645021298102, 2.7817792679582323, 8.684153028896876, 26.511574336460658, 34.164073603493826, 34.61876719338553, 76.33732877458844, 65.39896038600376, 49.24126502445766, 41.433140005384175, 35.64598887307303, 61.26627608707973, 25.086768048150198, 0.30920395680836266, 0.2598159983754158, 0.22337329387664795, 0.49515115895441597, 0.22205924295953341, 0.23200520926288196, 1.866474177156176, 3.4110111721924374, 1.0583248564175196, 0.30867497090782436, 0.340548719146422, 3.2908592309270586, 13.301746027810232, 23.768225772040232, 54.09482145309448, 68.44804532187325, 66.44903469085693, 75.31700665610177, 73.24898651668003, 73.85246535709926, 78.94075625283378, 72.79716600690568, 73.88270391736711, 73.53188937050956, 73.66808101109096, 64.32309436798096, 73.37070505959647, 68.88974925449916, 73.39109802246094, 71.31565025874546, 69.04818207877022, 71.12128829956055, 71.86590589795793, 71.0977269581386, 71.7407341003418, 69.73469189235142, 71.41927569253104, 71.23656586238316, 74.19811739240373, 68.67206219264439, 69.24737303597587, 68.65049498421806, 69.46606758662632, 63.092304365975515, 65.87740639277867, 56.382366452898296, 54.08542748859951, 54.063078607831685, 54.65316479546683, 55.70910337993077, 56.95660032544817, 52.90560252325875, 53.57438748223441, 53.284425258636475, 52.7021974836077, 54.488346576690674, 51.94542748587472, 51.789607184273855, 47.84982224873134, 50.177034514290945, 52.67013502120972, 55.41112640925816, 55.068253653390066, 57.15025009427752, 57.245381355285645, 52.62181724820818, 58.193584646497456, 60.08280331747872, 63.27092865535191, 62.61511598314558, 63.65364238194057, 58.54816859109061, 58.67655740465437, 50.104196548461914, 51.73648125784737, 54.81833042417254, 52.700960704258506, 53.50793491091047, 51.41209071023123, 51.56677845546177, 49.03059564317976, 46.972257818494526, 49.15555899483817, 46.48344162532261, 50.00414596285139, 48.79788657597133, 51.79906715665545, 47.66097021102905, 44.91384008952549, 49.21228756223406, 49.83167082922799, 47.87357813971383, 47.647584506443565, 50.69384152548653, 47.0491361618042, 52.8210950578962, 54.17303385053362, 57.81666224343436, 59.27099663870675, 61.64061723436628, 58.28039196559361, 61.1710649217878, 60.75521523611886, 59.16761439187186, 57.61567865099226, 58.70617757524763, 60.811176027570454, 61.454315185546875, 59.327659198216026, 58.91435950142996, 57.65794801712036, 58.99313817705427, 59.18294906616211, 59.26593140193394, 59.463079588753835, 64.44659164973667, 59.71638311658587, 59.80411107199532, 64.68952151707241, 65.29136753082275, 64.11136886051723, 46.8252443586077, 54.438746861049104, 54.159404958997456, 27.07743910380772, 6.549747628825052, 2.08937977041517, 0.9004551619291306, 0.17412345803209714, 0.4969019421509334, 1.8635066449642181, 1.3423650435038974, 7.800021682466779, 1.4962473405258996, 0.14093948581389018, 0.23671573506934301, 0.1300020712826933, 0.4496962609035628, 0.1553366689809731, 2.12614420907838, 39.04151446478707, 52.212929657527376, 32.09583459581648, 54.30753360475813, 32.0666069984436, 0.22716854379645415, 0.1352081854960748, 0.19702675619295665, 0.11211560320641313, 0.12885090948215552, 0.1253294755837747, 0.17990262221012795, 0.26451078216944424, 2.5971929899283817, 5.572116545268467, 6.080964829240527, 2.536335889782224], [32.76164919989449, 23.135514123099192, 18.843260969434464, 7.312537806374686, 0.5530254191585949, 12.17143132005419, 23.011223009654454, 31.106650829315186, 34.54074239730835, 33.24710941314697, 38.88195603234427, 39.128318309783936, 48.425956453595845, 39.38836506434849, 28.879206010273524, 30.66796588897705, 21.380576338086808, 34.21739755358015, 4.768119641712733, 0.23732799078736985, 0.11308235954493284, 0.050149308650621345, 0.11227555426635913, 0.10530389193445444, 0.017557972310377017, 0.1437008519257818, 0.3470551371574402, 0.04761189641430974, 0.05213328058432255, 0.02718101192398795, 1.3148229271173477, 1.9709542393684387, 8.400897553988866, 27.812546355383738, 54.98542070388794, 54.595710141318186, 65.59136990138462, 66.29013633728027, 67.23323617662702, 62.51232433319092, 65.33585684640067, 64.62659863063267, 63.92833941323416, 62.34644998822893, 63.6074229649135, 63.84309196472168, 66.47290175301688, 66.73202092306954, 64.30467469351632, 64.95708274841309, 63.58455644335066, 62.105687958853586, 64.34433501107353, 64.7428628376552, 66.10516139439174, 65.2257001059396, 64.86447020939418, 62.39696339198521, 63.45596613202776, 64.97507858276367, 61.65727206638881, 59.83380767277309, 57.589873041425435, 53.85195411954607, 48.02843958990914, 47.489203793661936, 47.912689549582346, 48.06740508760725, 44.504094396318706, 47.529291425432476, 48.48064572470528, 48.100572313581196, 44.78116076333182, 44.18231289727347, 47.1525114604405, 47.03707756314959, 45.09797082628523, 43.00796658652169, 44.840282985142295, 49.18017646244594, 46.66982705252511, 47.937591893332346, 50.03929689952305, 56.06625815800258, 57.9837212562561, 58.27776902062552, 57.56436620439802, 59.42983940669468, 59.53065082005092, 57.84453494208199, 56.87319414956229, 59.38136877332415, 43.152405738830566, 43.23040621621268, 51.94447210856846, 48.73813901628767, 50.269087723323274, 45.558052744184224, 44.54580095836094, 40.606036867414204, 42.090238094329834, 41.48510210854666, 42.57149117333548, 45.40833296094622, 44.63795491627285, 43.27852596555437, 41.87701872416905, 43.812856333596365, 46.5110433442252, 44.094998359680176, 44.47278928756714, 43.02631330490112, 45.50307164873396, 42.95149857657296, 45.08489431653704, 49.79367460523333, 51.559131962912424, 53.22279821123396, 54.90322004045759, 56.95746190207345, 55.55427319662911, 57.18259743281773, 54.62114749635969, 52.12003571646554, 54.36300107410976, 54.40956442696707, 57.37472554615566, 54.697153840746196, 54.475426401410786, 52.222379207611084, 51.417110783713206, 52.972089835575645, 52.21515655517578, 56.51020288467407, 56.470125675201416, 53.84402969905308, 55.07056392942156, 58.27827276502337, 58.81124128614153, 60.15555790492466, 29.589487348284038, 47.09744003840855, 39.83143779209682, 20.612095151628765, 6.406041511467524, 0.8116893193551472, 0.24805880497608865, 0.07849602507693426, 0.08089809332575117, 1.2187058904341288, 3.452413316283907, 1.8200305721589496, 1.5053775991712297, 0.09665023628622293, 0.0514597836881876, 0.18983699913535798, 0.06914020103535481, 0.26130483991333414, 0.13892366683908872, 16.38083154814584, 23.138267346790858, 13.6199483360563, 23.338842732565745, 45.969869000571116, 20.8913345677512, 0.14331366627344064, 0.06777806234146867, 0.04733466396906546, 0.03565128839441708, 0.16223093760865076, 5.974930107593536, 26.333716085978917, 30.410826955522808, 31.555368968418666, 33.46091938018799, 33.76300968442644, 43.009370122637065, 30.08449786049979, 25.190490756716045, 10.819805196353368, 0.16391142457723618, 14.512055345943995, 31.03968061719622, 46.50455720084054, 53.56273535319737, 53.499534538814, 51.04000077928816, 50.77170303889683, 55.59149122238159, 48.53436919621059, 37.453163215092246, 23.02479110445295, 24.324081659317017, 42.2173866544451, 5.853058270045689, 0.1656909640878439, 0.10316855580146823, 0.0727282195751156, 0.3014320709875652, 0.06479213506515537, 0.1427898643804448, 0.2714984172156879, 0.6597342246345111, 0.1123246598456587, 0.1669798277850662, 0.1999345501618726, 2.1087409257888794, 4.617820118154798, 9.194978509630475, 40.56120709010533, 57.434525217328755, 61.83366598401751, 65.09822845458984, 73.81758540017265, 69.89527865818569, 70.49952180044991, 67.53823430197579, 70.95845031738281, 67.51684079851422, 65.26934174128941, 64.72044100080217, 67.55898857116699, 68.24246897016252, 71.30572128295898, 67.24430465698242, 68.14789009094238, 68.20083536420549, 63.65622016361782, 68.52261338915143, 68.55426243373326, 67.74523503439767, 66.08862468174526, 66.91347312927246, 66.1091079711914, 67.01202637808663, 65.32593481881278, 64.17446545192173, 61.58419091360909, 60.99194731031145, 56.696407658713206, 51.79761150905064, 50.04322957992554, 50.46514851706368, 51.69978434698922, 47.838409832545686, 49.82679319381714, 51.66719034739903, 49.400750500815256, 48.97979041508266, 46.53903068814959, 50.12770925249372, 49.85991873059954, 47.837628160204204, 46.87731415884835, 47.75273159572056, 51.10743652071272, 45.80718387876238, 48.846902642931255, 51.10274648666382, 57.87055247170584, 58.36376340048653, 61.89872891562325, 62.160411970955984, 63.86663246154785, 63.20336437225342, 62.18927478790283, 59.92964417593819, 62.28622300284249, 45.17039884839739, 47.00410141263689, 50.96481779643467, 51.88118444170271, 51.321805817740305, 49.44804341452462, 48.81814752306257, 42.96184097017561, 44.64476415089199, 44.918130602155415, 44.46284988948277, 46.98366328648159, 45.71441500527518, 44.756272315979004, 43.69762045996529, 46.48527247565133, 47.77673414775303, 46.54802165712629, 47.05269363948277, 46.59826408113752, 48.25954362324306, 45.30080263955252, 47.512174538203645, 51.66449097224644, 54.38466208321707, 56.49826240539551, 58.30141026633126, 59.34883730752127, 57.25276729038784, 59.026711872645784, 55.68262032100132, 53.36377021244594, 54.952934401375906, 57.930487632751465, 59.30609198978969, 57.39908593041556, 55.59170661653791, 56.41608606066023, 54.21751969201224, 54.947848320007324, 53.171892234257285, 59.66366713387625, 55.11621012006487, 55.314633301326204, 57.72064856120518, 59.327951022556846, 60.76865305219378, 60.51459217071533, 36.849778175354004, 50.89759744916643, 49.048848560878206, 30.512979371207102, 10.981851083891732, 1.3097148069313593, 0.8075624693717275, 0.0524482327912535, 0.27595085544245584, 2.32398504444531, 6.561234303883143, 3.0948744331087386, 0.8417276303683008, 0.20047439262270927, 0.30339195153542925, 0.09046015130089861, 0.07291743585041591, 0.313276361141886, 0.15893523874027388, 16.91204217502049, 28.61937986101423, 18.393575293677195, 27.78965551512582, 55.05684471130371, 35.66611780439104, 0.13352476725620882, 0.051051709335297346, 0.06665649823844433, 0.1257651900606496, 0.19551702934716428, 10.83200102193015, 35.10410928726196, 42.99349001475743, 45.65948602131435, 47.66324922016689, 48.81891877310616, 48.42176668984549, 33.45207779748099, 26.797779321670532, 12.182536278452192, 0.4057013530816351, 20.54613242830549, 35.945713315691265, 53.1575858933585, 56.226733752659385, 61.138241631644114, 59.78728253500802, 67.10196386064801, 66.35670007978166, 57.38770478112357, 47.76440804345267, 53.572261333465576, 38.52152170453753, 52.64784172603062, 8.97451651096344, 0.24423781143767492, 0.3156339174934796, 0.110872737398105, 0.5904227410043988, 0.17719167125012192, 0.5583008932215827, 0.5300033230866704, 1.2997480503150394, 0.5373256387455123, 0.26955707424453323, 0.2654491418174335, 2.582910967724664, 13.307041423661367, 21.150276558739797, 51.13914462498256, 66.58352402278355, 64.75350747789655, 71.43802193232945, 75.74018669128418, 75.60960919516427, 73.84003502982003, 71.44641535622733, 73.39979021889823, 72.27445997510637, 70.50847802843366, 67.56728472028459, 71.9962888445173, 70.14990929194859, 72.80987426212856, 67.6118574142456, 69.40827247074672, 69.44571631295341, 68.82957785470145, 71.45244639260429, 72.97458825792584, 69.69078622545514, 70.22767353057861, 70.30944687979562, 68.59493718828473, 68.9150754383632, 69.38014616285051, 67.95047787257603, 65.46669142586845, 65.7056747164045, 60.82138293130057, 56.02647277287075, 53.29804025377546, 53.26132944652012, 54.64447954722813, 51.03013433728899, 53.45667110170637, 53.51537643160139, 54.0404691696167, 52.51307794025966, 50.25494466509138, 52.56251784733364, 55.37513474055699, 52.512073925563264, 50.88080712727138, 51.27857412610735, 56.266178676060264, 50.4381617137364, 52.62101125717163, 54.164352076394216, 62.66275978088379, 62.90687779017857, 62.86065142495291, 63.27953747340611, 64.78355843680245, 63.92553234100342, 65.75997488839286, 61.229610443115234, 63.894383566720144, 47.36399030685425, 45.60384137289864, 53.622743470328196, 56.20585788999285, 53.31536558696202, 51.25904968806675, 50.94396277836391, 45.029579707554404, 47.204626423971995, 47.93202986036028, 45.69300413131714, 49.68799945286342, 49.56731619153704, 47.02881268092564, 46.787640707833425, 47.60097599029541, 50.82357481547764, 48.75217090334211, 48.58561563491821, 48.33043956756592, 50.64819533484322, 47.78778525761196, 49.98727226257324, 55.079888411930625, 56.57122891289847, 59.95258017948696, 59.7018266405378, 61.86676025390625, 60.85601275307791, 63.6576167515346, 59.083534240722656, 56.3260235105242, 60.434708731515066, 60.84220668247768, 63.17317444937569, 58.84812927246094, 61.03517205374581, 56.80841956819807, 56.38138328279768, 57.5400891985212, 59.175167083740234, 61.00345352717808, 61.20864772796631, 57.1903828893389, 62.680755615234375, 60.72150257655552, 66.42378493717739, 59.79379994528634, 44.417346136910574, 55.26462364196777, 55.07124137878418, 38.58238097599575, 15.288236004965645, 3.7657447201865057, 1.1462075178112303, 0.2451266651707036, 0.2511610670813492, 3.7662150263786316, 7.830045717103141, 4.256666651793888, 2.0362180173397064, 0.2993383290512221, 0.2078029236623219, 0.9333723613194057, 0.12076625972986221, 0.644034064241818, 0.18488178003047193, 23.290858473096574, 36.31231416974749, 28.201662846973964, 33.78378479821341, 67.19180406842912, 31.227042266300746, 0.3894104058189051, 0.09955602857683386, 0.16780867188104562, 0.24495722140584672, 0.3261203776512827, 9.63552643571581, 36.282092979976106, 46.58348526273455, 49.522531577519004, 53.56239489146641, 50.61459037235805], [19.604140826633998, 29.958082335335867, 32.49063123975481, 37.35238306862967, 26.665694066456386, 27.455950907298497, 22.621161563055857, 16.575434957231792, 14.518299170902797, 23.432356800351823, 38.32291439601353, 50.45865889957973, 52.58437688010079, 38.20459699630737, 33.981019837515696, 23.6904684816088, 25.48509090287345, 35.961784499032156, 1.885029775755746, 0.10428171964096171, 0.00962258584331721, 0.0537927193966295, 0.09159213091645922, 0.09234558298651661, 0.15659160592726298, 0.17114444502762385, 0.09594296530953475, 0.11916592131767954, 0.07291667589119502, 0.07674392552248069, 2.562430283852986, 6.311030975409916, 10.551999909537178, 45.39909880501883, 52.728263650621685, 46.19624825886318, 59.52309117998396, 68.88730348859514, 65.37634399959019, 63.25217546735491, 68.6799761908395, 65.39527089255196, 64.4035336630685, 58.986738886152, 62.988560812813894, 61.94989545004708, 67.3901959827968, 66.23327228001186, 63.28689561571394, 65.27353150503976, 61.296806471688406, 63.12353651864188, 63.46728474753243, 59.8372539792742, 62.104228837149485, 67.1864400591169, 63.59320000239781, 63.166427748543875, 63.397441455296104, 61.90027836390904, 61.00562136513846, 60.05216176169259, 54.79821538925171, 49.41605043411255, 48.16465554918562, 48.00757762363979, 46.85346794128418, 47.54149941035679, 46.90366172790527, 46.77501930509295, 47.598537172589985, 46.005454199654714, 47.604787077222554, 43.980408668518066, 45.37861551557268, 47.495120184762136, 44.534381593976704, 42.73014286586216, 44.88184016091483, 43.663727147238596, 41.6054344858442, 43.103045736040386, 45.25354446683611, 48.93877867289952, 56.53027275630406, 58.3407301221575, 59.75365325382778, 60.168585777282715, 58.85546657017299, 59.64639391217913, 59.61202812194824, 56.426991258348735, 45.88085215432303, 42.33395658220564, 52.62936299187796, 48.010752950395855, 50.06911161967686, 45.406522955213276, 43.694184575762065, 41.80228042602539, 41.50923320225307, 41.83158792768206, 45.91252204350063, 41.30447326387678, 43.414915629795615, 40.10111474990845, 42.32834243774414, 42.126844678606304, 43.7220572744097, 43.42579998288836, 45.43230077198574, 43.12228182383946, 45.287135532924104, 43.606741496494834, 46.1444216455732, 50.064664772578645, 52.31814970288958, 51.80765860421317, 55.239756039210725, 56.14359508241926, 54.97397007261004, 53.98557145254952, 57.11210100991385, 53.23092065538679, 52.57323544366019, 53.18105343409947, 57.44585425513131, 54.24934591565813, 53.68775429044451, 53.47586897441319, 51.079212938036235, 52.342475346156526, 49.98486123766218, 54.59897926875523, 51.53953456878662, 56.77176087243216, 55.49232653209141, 55.42114918572562, 55.978026458195274, 59.822621073041645, 27.231393814086914, 49.92514841897147, 47.80760151999337, 32.75535760607038, 15.291984558105469, 5.865678369998932, 1.6690755294901984, 0.5756926142743656, 0.7614870646170208, 1.5694106774670737, 8.840304238455635, 19.764969042369298, 3.3235505052975247, 0.713019742497376, 0.21398409269750118, 0.5122983902692795, 0.12690025701054505, 0.09698531723448209, 0.11471346952021122, 5.229521717344012, 41.96746342522757, 17.19070315361023, 34.945839745657786, 27.30714307512556, 57.492441926683696, 4.981330326625279, 0.07518563592540366, 0.103922421777887, 0.12367733780826841, 6.794299900531769, 38.57412999016898, 29.548694474356516, 22.757118701934814, 24.003403186798096, 21.82676706995283, 14.228340421404157, 32.798978396824424, 45.92151996067592, 47.85522794723511, 52.7779814856393, 39.69191101619175, 51.729477473667686, 38.13523660387312, 31.24482618059431, 26.62445477076939, 33.25648600714547, 45.84940808159964, 60.802685328892295, 59.44764069148472, 48.189658641815186, 38.70839350564139, 23.298421587262833, 30.38407986504691, 43.72336006164551, 3.3264227168900624, 0.14851157021309647, 0.21032725035079888, 0.044598281516560485, 0.1500509354685034, 0.12989421135612897, 0.21987550013831683, 0.16143099910446576, 0.07045993129057543, 0.07947340048849583, 0.20553599244781903, 0.06179704078074012, 3.191621801682881, 10.60897079535893, 16.67255687713623, 54.3006340435573, 59.359405517578125, 52.52978835787092, 61.93230955941336, 74.91866643088204, 67.66763755253383, 69.18652766091483, 70.01400252750942, 70.8478558404105, 67.0654649734497, 62.39722047533308, 64.5777666909354, 64.30511243002755, 69.32802772521973, 67.77067933763776, 64.47743470328194, 66.05496760777065, 64.06391266414097, 64.51645578656877, 68.60567215510777, 65.75776536124093, 64.20256396702358, 68.53468935830253, 66.61129597255162, 67.63420976911272, 65.86648382459367, 63.79318305424282, 64.30534172058105, 63.083619117736816, 59.640064103262766, 51.5214136668614, 51.78554596219744, 50.03278991154262, 49.17792524610247, 49.270749705178396, 49.268991810934885, 49.94489867346627, 51.16729177747454, 49.07459511075701, 48.821725845336914, 46.932260513305664, 47.6955201285226, 50.9036979675293, 50.07225915363857, 47.30465963908604, 48.557183606284006, 44.44389867782593, 43.31650481905256, 45.05024365016392, 46.638733863830566, 50.26496049336025, 57.94109058380127, 60.5157664162772, 64.11744158608573, 64.00456809997559, 60.98704188210623, 63.686111313956125, 57.60151127406529, 55.83021395547049, 47.7827582359314, 47.596682003566194, 53.73300095966884, 49.11156300136021, 51.98671020780291, 47.75101886476789, 45.436181340898784, 44.281644344329834, 42.11269119807652, 44.23533460072109, 48.87987879344395, 44.208198411124094, 44.45726701191494, 42.22118731907436, 42.614406721932546, 45.58769375937325, 45.41917215074812, 45.55036803654262, 47.286212171827046, 45.61926637377058, 46.55056817190987, 45.79885298865182, 48.07770231791905, 50.05769920349121, 54.09785781587873, 55.3486898967198, 56.71473700659615, 58.363603591918945, 57.850499970572336, 56.027532373155864, 58.628927503313335, 55.496728215898784, 55.41002859388079, 54.260143416268484, 58.37504032679966, 57.534040791647776, 57.2720832824707, 55.80661787305559, 54.381663935525076, 54.32695729391915, 51.93654768807547, 55.77099098478045, 54.399235929761616, 58.073022978646414, 57.61515406199864, 54.87583371571132, 60.567606925964355, 57.7794303212847, 35.82943173817226, 57.65949051720755, 54.859901496342246, 41.68849672589983, 21.028132438659668, 6.393146089145115, 0.17064463613288744, 0.5674431483660425, 0.41248043360454695, 2.6692762076854706, 17.36376714706421, 29.256553990500315, 6.09459285225187, 0.5907851329871586, 0.549401770745005, 0.22061480475323542, 0.142851000385625, 0.08215609725032534, 0.08825020345726184, 6.028775606836591, 45.04408407211304, 23.818798235484532, 47.048531668526785, 33.31671299253191, 68.45420142582485, 12.74644078527178, 0.19757919226373943, 0.1426848407302584, 0.021849597737725292, 12.518325345856802, 51.85160943440029, 43.21390424455915, 36.23451171602522, 37.82033382143293, 31.723987851824077, 23.978176014763967, 37.00659554345267, 54.52346624646868, 61.04066807883126, 68.17943491254533, 53.68266820907593, 55.31135722569057, 45.81814466203962, 40.13357673372541, 32.69852828979492, 42.05317292894636, 56.51208584649222, 74.59406743730817, 69.8679861341204, 60.72424711499895, 53.53022820608956, 46.827585901532856, 39.790749141148154, 57.68542119434902, 4.94237698827471, 0.22015684789844922, 0.25836173498204773, 0.13739350251853466, 0.3165085491325174, 0.36487604518021854, 0.5009092071226665, 0.6419687122106552, 0.12083350255021028, 0.14204522648027965, 0.2554180057985442, 0.11774726744209017, 3.4538863343851904, 15.728399174554006, 35.589663301195415, 60.307640075683594, 66.16776466369629, 59.641419001988, 66.52593040466309, 76.82389027731759, 69.864136832101, 71.57957758222307, 73.63658482687813, 74.75723893301827, 71.30677740914481, 66.07042734963554, 67.91160270145961, 66.17485877445766, 71.48187896183559, 72.38944571358817, 66.90041051592145, 70.3936243057251, 64.9217928477696, 68.14988422393799, 70.09503241947719, 68.1665599005563, 66.45406518663678, 73.59915488106864, 69.22369357517788, 69.79052761622837, 67.27026312691825, 67.51226888384137, 67.58817100524902, 66.57673563276018, 62.879675592694966, 55.32928010395595, 54.547336782727925, 54.80290194920131, 52.42667361668178, 51.979042870657786, 51.77062470572335, 54.50237498964582, 53.142206055777415, 52.10248456682478, 53.6166672706604, 50.61828681400844, 52.15925134931292, 54.08748762948172, 52.68582057952881, 50.06449454171317, 50.7559723172869, 47.725286211286274, 45.32189737047468, 45.80436985833304, 47.38647815159389, 52.32181140354702, 62.48977048056466, 64.90191405160087, 64.99794510432652, 66.39453302110944, 62.97230897630964, 66.84875065939767, 63.723103523254395, 61.47311006273542, 48.67405925478254, 46.56935262680054, 55.90313182558332, 53.48315763473511, 54.3377547945295, 50.931872912815635, 47.30410725729806, 47.45095048631941, 46.2783898626055, 47.98456171580723, 50.222833565303254, 46.766448702131, 48.816142967769075, 43.93355696541922, 44.557543413979666, 46.525436537606375, 48.35045037950788, 48.3760301726205, 49.955769130161826, 48.82154866627285, 49.6022378376552, 47.758224146706716, 49.95770072937012, 53.6818448475429, 58.298172405787874, 57.568347522190635, 60.21768869672503, 61.458748136247905, 59.292904308864046, 59.14294828687395, 61.2084253856114, 58.118662221091135, 57.483190400259836, 57.20707941055298, 61.91941370282854, 58.0714179447719, 61.770284516470774, 58.07328701019287, 57.41116884776524, 57.23326022284371, 55.94406713758196, 61.218694823128835, 57.26343624932425, 60.329283714294434, 61.6970921925136, 56.07316814150129, 64.58303342546735, 58.18518427440098, 44.79925734656197, 60.26019777570452, 58.36274201529366, 54.75312158039638, 29.184344836643763, 10.171059710638863, 3.693595494542803, 0.4980411210230419, 1.4745503962039948, 5.104815014771052, 24.881379297801427, 34.74160787037441, 5.168883919715881, 1.876159748860768, 0.5621682171310697, 0.9133789198739188, 0.27582358941435814, 0.39091238379478455, 0.19837805868259498, 8.902384655816213, 55.80834797450474, 31.561528546469553, 53.93196957451956, 39.478948729378835, 81.21440832955497, 10.849574753216334, 0.35886854039771215, 0.31407211987035616, 0.19531644082495145, 12.374875443322317, 59.202452659606934, 49.29537412098476, 45.66989094870431, 49.02769129616873, 42.67427934919085, 33.73688793182373], [35.71634285790579, 18.0526636668614, 16.294015543801443, 23.623934268951416, 26.268802540642874, 16.661945240838186, 39.12071350642613, 46.45563840866089, 56.817573819841655, 42.94124303545271, 47.58764239719936, 40.206081186022075, 45.68731008257185, 45.10256358555385, 34.93035568509783, 17.249985183988297, 33.9568817956107, 20.479026726314, 0.5711532692824091, 0.06070230595235314, 0.14806995248155935, 0.14951405142034802, 0.041821231067712815, 0.10851177480071783, 0.01697709714062512, 0.49550817693982807, 0.028880424930581024, 0.18221798725426197, 0.01642420475504228, 0.038171852606215646, 4.0734105195317944, 8.334871428353445, 26.049638986587524, 50.710145473480225, 56.77586030960083, 44.26044539042881, 52.0718777520316, 66.81273814610073, 65.38703727722168, 65.0021140234811, 63.61064692905971, 63.3404940196446, 64.09085083007812, 57.17673315320696, 64.17085933685303, 63.7173365184239, 66.60475076947893, 62.543028422764365, 63.89175714765276, 65.25202683040074, 62.887742451259065, 63.16721984318325, 67.97177410125732, 65.27492114475795, 64.26147774287632, 61.89449746268136, 63.26095799037388, 64.4171451841082, 62.20130211966378, 62.32517460414341, 61.19045039585659, 58.25505188533238, 53.80796160016741, 48.7979108946664, 49.64680010931832, 47.13655839647566, 46.3882269859314, 46.87208563940865, 45.2176570211138, 46.444993768419536, 44.74169846943447, 44.49147646767752, 45.124714442661826, 44.80132443564278, 43.52197347368513, 45.20993757247925, 46.19209671020508, 41.733889307294575, 43.34468323843819, 41.878620283944265, 41.86005122320992, 43.21374443599156, 43.949760164533345, 44.10416998182024, 51.24244696753365, 54.178877285548616, 59.21787071228027, 61.1067384992327, 61.55728054046631, 60.611929484776084, 56.028946331569124, 49.23863513129098, 50.072279998234336, 46.517883845738, 50.33674233300345, 51.092761925288606, 45.64296667916434, 44.23389284951346, 41.54741702760969, 39.348395551954, 40.38449008124215, 45.22223588398525, 42.85229914528983, 43.86909852709089, 38.444233417510986, 38.62933342797415, 41.485088212149485, 43.18013947350638, 42.76907362256731, 42.22334820883614, 43.34680243900844, 43.17619637080601, 43.23351206098284, 43.856272152491975, 41.37877035140991, 48.923308508736746, 50.4240151814052, 53.402555056980674, 52.91784872327532, 55.358118602207725, 55.22105496270316, 57.47996991021292, 53.6670104435512, 57.57184941428048, 52.0111574445452, 51.962224755968364, 54.20899077824184, 59.00524193899972, 53.37792716707502, 51.80438600267683, 49.19806807381766, 54.20419304711478, 50.14260966437203, 52.21231474195208, 53.058237075805664, 52.16307633263724, 52.975650787353516, 53.5624053137643, 56.883199555533274, 53.35944495882307, 32.27459784916469, 75.32329477582658, 50.04608528954642, 38.30416120801653, 29.37304401397705, 15.785853828702654, 2.08221834897995, 2.255153149366379, 2.3874218804495673, 4.400694991861071, 3.2564133192811693, 7.5038356099809915, 7.422756212098258, 2.441518600497927, 0.38341584748455454, 0.5044628850051335, 0.09114491527101823, 0.0982545984110662, 0.11631232872605324, 1.6336315742560794, 38.26772485460554, 20.02742334774562, 15.565512554986135, 30.856779711587087, 45.26120138168335, 32.78100340706961, 0.060088781373841424, 0.0980514178850821, 1.7613426127604075, 29.686511993408203, 26.491947412490845, 41.37763779503958, 58.29851286751883, 58.428972244262695, 62.12259292602539, 54.85276917048863, 44.23873574393136, 26.4240756716047, 27.802765028817312, 54.37438917160034, 56.245549474443706, 22.378212588174, 47.54794039045061, 54.70327867780413, 62.898060526166645, 56.34022215434483, 55.150822571345735, 48.81693853650774, 53.602506841932026, 55.24071489061628, 40.41286652428763, 19.61555150577, 40.463584899902344, 24.498234782900127, 0.4325668343475887, 0.19410201241927488, 0.1744978872260877, 0.1220190796468939, 0.10820549087865011, 0.27797734098775045, 0.10007829019533736, 0.3449848453913416, 0.08785134700259992, 0.06607183853962592, 0.011152501650420683, 0.02413828108858849, 4.18122832264219, 12.539327144622803, 41.45203563145229, 54.939899580819265, 62.59339591435024, 49.12373277119228, 53.82820865086147, 72.55602877480644, 67.40363379887172, 67.85018757411412, 66.37673868451799, 69.05160059247697, 66.36947086879185, 62.336006845746724, 65.7338844026838, 65.65787805829729, 68.29239872523716, 65.44465173993791, 66.53162097930908, 67.9249085017613, 63.230372020176475, 63.80621092660086, 68.22648116520473, 69.9265386036464, 67.51930740901402, 64.83875492640904, 65.08435985020229, 66.47660514286586, 65.28102166312081, 65.49425492967877, 61.87922532217843, 60.18699850354876, 56.85084874289376, 51.385510376521516, 51.76645578656878, 50.33112818854195, 47.6903715133667, 50.41263403211321, 48.54034464699881, 49.71257175718035, 47.17760835375105, 46.07939692905971, 46.74294294629778, 49.27786118643624, 48.812814780644004, 48.62818724768502, 48.60495247159685, 45.337308474949424, 46.848506927490234, 44.81062807355608, 43.322431632450645, 44.161437034606934, 45.939682551792686, 44.73822784423828, 52.3179794720241, 58.386532647269114, 61.37110355922154, 62.627831186567036, 62.88342067173549, 64.22509002685547, 57.85668734141758, 52.10002837862287, 49.172589029584614, 48.67714078085763, 52.422466482434956, 49.80711242130825, 49.051155362810405, 46.40260975701468, 42.31921597889492, 43.48506811686924, 42.385192598615376, 47.99470608575003, 45.93960959570748, 42.65369531086513, 42.772926398685996, 43.22429527555193, 41.53733171735491, 47.19761221749442, 46.72465181350708, 45.734196526663645, 46.15260314941406, 45.995660713740754, 46.35914530072893, 44.893082346235005, 42.964769635881694, 50.25044223240444, 52.61504275458199, 57.36955261230469, 57.30485446112496, 55.553349086216514, 57.71369341441563, 60.117724963596885, 53.669167859213694, 58.74206502096993, 54.80280120032174, 52.67372029168265, 57.784707478114534, 60.0984992980957, 56.32891048703875, 55.41510077885219, 51.16471746989659, 54.683973108019146, 53.45661204201834, 53.99134540557861, 56.576850005558555, 53.53667613438198, 55.804981572287424, 55.78191702706473, 58.85606411525181, 54.979980264391216, 38.165899004255024, 78.9389705657959, 60.48706340789795, 49.86629717690604, 37.521668979099815, 19.662092276981898, 5.3476667148726325, 1.35943437899862, 1.7644405322415488, 6.116259941032954, 9.474108491625104, 18.51728970663888, 16.647157737186976, 3.8156349573816573, 0.41673465818166733, 0.6054487632853645, 0.21655783030603612, 0.11901724072439329, 0.035382700485310385, 1.0883027506726128, 43.591538837977815, 24.38130181176322, 24.058811596461705, 41.42218617030552, 53.84854602813721, 43.0823644229344, 0.11365726869553328, 0.06695942341216973, 3.163324611527579, 44.777891635894775, 40.15401485988072, 53.045160566057476, 67.91340923309326, 69.20687893458775, 75.69295978546143, 73.05128942217145, 67.58958843776158, 35.03454392296927, 35.0992351259504, 84.59977912902832, 63.471696853637695, 42.30575384412493, 85.2226642881121, 94.62441076551164, 109.83151612962995, 82.77889251708984, 68.74779060908726, 63.408565521240234, 66.57908412388393, 64.9096543448312, 54.71689019884382, 35.39390127999442, 48.875810623168945, 35.262014048440115, 0.6810422869665282, 0.19952505427811826, 0.3715697931391852, 0.22248704571809086, 0.3225330715732915, 0.3739948501544339, 0.3071414546242782, 0.8077742808631488, 0.16505793162754603, 0.1694783837135349, 0.11371547342943293, 0.03882875932114465, 4.559420508997781, 18.24390067373003, 56.53597722734724, 64.696900503976, 70.17721571241105, 54.882392815181184, 61.69146415165493, 74.01749202183315, 72.22396046774728, 72.21489306858608, 69.25522450038365, 71.11511829921177, 71.12189279283795, 64.40490245819092, 69.52531487601144, 67.75562259129116, 68.37840352739606, 69.3122900554112, 68.67319474901471, 70.66260991777692, 67.47238622392926, 65.17654854910714, 72.04562800271171, 70.87523869105748, 69.12345886230469, 67.14700208391461, 67.71095262254987, 69.72399166652134, 68.75546836853027, 68.35415431431362, 65.99676254817417, 66.91875376020158, 59.86489391326904, 54.38414444242205, 56.40233557564871, 54.350560324532644, 50.42342111042568, 54.201636110033306, 49.685359137398855, 53.133440903254915, 51.32071842466082, 48.74853352137974, 50.30798026493618, 52.47407422746931, 51.202060563223704, 53.306669916425435, 52.77808918271746, 46.42678253991263, 48.02863761356899, 46.90898404802595, 46.125387055533274, 45.192636557987754, 47.78680556161063, 46.76865128108433, 55.58734662192208, 58.86012881142752, 62.344289098467144, 64.72473498753139, 66.5103178024292, 66.31446892874581, 57.79038763046265, 53.10954604830061, 51.92193910053798, 47.840786116463796, 55.27857909883772, 51.65110526766096, 51.54269599914551, 47.78573553902762, 46.62647376741682, 46.19503927230835, 45.37113925388881, 50.79242604119437, 50.44714573451451, 49.32816961833409, 46.673641613551546, 43.49300990785871, 43.8873861857823, 49.035084179469514, 50.02040127345494, 46.37264217649187, 47.88140875952584, 47.02121829986572, 49.29957430703299, 47.14775889260428, 44.85024670192173, 53.79953343527657, 56.340236050742014, 59.73230143955776, 57.962678636823384, 59.04039287567139, 61.82764189583914, 63.08292429787772, 56.78511183602469, 60.9952199118478, 57.63006837027413, 56.67392676217215, 60.60753127506801, 62.526762689862935, 60.50953388214111, 56.88781663349697, 53.06632130486624, 58.11669588088989, 56.425250734601704, 56.55517510005406, 60.19459983280727, 58.10839278357369, 57.84518459865025, 57.43475450788225, 61.4621388571603, 57.27823938642229, 46.51439585004534, 73.0436464037214, 65.76368522644043, 58.93142427716936, 41.37097447259085, 29.458062171936035, 15.478218861988612, 7.975895353725978, 11.542857323374067, 17.419832161494664, 10.889579875128609, 25.702856131962367, 25.023881639753068, 7.33131878716605, 1.5606064413275038, 1.0857087927205222, 0.6684351063200406, 0.20624245596783503, 0.17544147159372056, 1.9470020617757524, 54.455641405923025, 31.832087925502233, 24.84236342566354, 43.93243830544608, 63.43221718924386, 47.3505733353751, 0.15971810530338967, 0.11555597931146622, 2.5612154347555975, 51.356466906411306, 47.748816285814556, 68.11222498757499, 90.90790271759033, 93.88776969909668, 101.71558243887765, 102.30647114345005], [43.95253249577114, 35.50107724325997, 20.519473927361624, 11.248355320521764, 26.06868573597499, 50.01870938709804, 37.9411803654262, 36.150480202266145, 40.3448714528765, 36.21097469329834, 48.94412531171526, 31.442908900124685, 24.189258813858032, 43.06174216951643, 24.728586673736572, 23.06278211729867, 31.0038035937718, 9.929231132779803, 0.2315536034958703, 0.05115710278706891, 0.023457171029544303, 0.08665924918438707, 0.044784366352749724, 0.04908341495320201, 0.06386038434824773, 0.08315366586404187, 0.05161571782082319, 0.10299989913723298, 0.05178675275029881, 0.03162225601928575, 4.579820854323251, 19.371251106262207, 44.654495103018625, 55.97761998857771, 57.0104523386274, 47.332362106868196, 44.75326027188982, 66.74550737653459, 61.926876068115234, 66.17813832419259, 66.63806738172258, 64.79381397792271, 59.02200099400112, 60.043017932346885, 63.75512777056013, 62.48162719181606, 65.12039320809501, 62.434226581028526, 64.88057613372803, 62.052770478384836, 62.67616980416434, 65.0145651953561, 64.13409641810826, 65.39560440608433, 66.89302458081926, 62.94841412135533, 64.86466475895473, 63.524176597595215, 61.87212426321847, 62.87570817129952, 60.23213400159563, 57.493515423366, 49.30455616542271, 47.27680778503418, 46.759427547454834, 46.19793667112078, 46.69472592217581, 44.351018633161274, 47.63689122881208, 45.7695072719029, 45.882780279432026, 44.29907737459455, 43.40391315732683, 43.439373288835796, 44.719724791390554, 45.63274935313633, 44.78380107879639, 42.9234174319676, 43.180142947605674, 43.33128016335623, 40.162140778132844, 42.39756734030587, 44.38575962611607, 42.51242801121303, 46.28780467169625, 54.62527820042202, 59.776339122227256, 62.615525926862446, 59.984020778111045, 59.86866678510393, 56.62863492965698, 49.511633328029085, 44.159046854291645, 48.884454182216096, 47.33250107084002, 48.372722830091206, 43.90211636679513, 42.617853028433665, 39.926169531685964, 38.10869448525565, 44.07649878093174, 45.012164047786165, 42.40729481833321, 42.77921799251011, 41.59433821269444, 41.822951316833496, 39.48534107208252, 41.28440686634609, 41.01103694098336, 42.436505045209614, 40.948520524161204, 41.73882600239345, 41.721566677093506, 43.50790337153843, 43.21160786492484, 44.63150698798043, 49.56024987357003, 52.15944937297276, 53.679357392447336, 53.757639271872385, 51.874774728502544, 59.6737003326416, 53.6551707131522, 56.14790643964495, 53.72167887006487, 50.64691686630249, 52.117273807525635, 55.88933617728097, 54.03871127537319, 58.03096900667463, 49.4419845853533, 51.28210033689226, 50.97243997028896, 51.55085318429129, 53.57331051145281, 54.03990289143154, 53.80147545678275, 57.21969039099557, 55.581906182425364, 54.49254676273891, 35.23840059552874, 79.31044905526298, 52.61297913960048, 52.33634008680071, 38.86937631879534, 26.53924032620021, 10.85075855255127, 9.582253728594099, 11.669769644737244, 2.15176807982581, 0.17809210079056875, 0.46137015734400066, 0.7209804781845638, 0.5388028366225106, 0.32559321022459436, 0.12335366303367273, 0.1618535364312785, 0.31084164178797175, 0.1587485737566437, 0.9645768297570092, 22.553317614964076, 31.61766651698521, 29.201854297092982, 31.0494567326137, 40.63576473508562, 43.82920544488089, 0.3456359404538359, 0.10842445412916796, 14.998430115836006, 27.246620791299, 30.317269461495535, 54.1180979183742, 28.505729913711548, 16.834561075483048, 12.832150288990565, 26.91333828653608, 65.12997477395194, 54.509364877428325, 31.899634838104248, 56.361073698316304, 34.346578461783274, 67.16948645455497, 61.724544525146484, 54.8152072089059, 58.822504316057476, 50.176589829581125, 56.82732561656407, 39.904956681387766, 31.655096462794713, 55.888564927237375, 31.15105676651001, 28.090639318738663, 39.71830027444022, 12.966670887810842, 0.24902563595346042, 0.16443347584988388, 0.1663375808192151, 0.25157931606684414, 0.01508563497502889, 0.06291069995079722, 0.11909588293305465, 0.11176299569862229, 0.03543832678613918, 0.05245828528755477, 0.11117126566490956, 0.11814898731453077, 5.066790997982025, 21.74677072252546, 52.784894943237305, 61.140722138541086, 65.77696323394775, 52.772290910993306, 49.59009238651821, 69.3803824016026, 65.71278967176164, 69.68192032405308, 69.80797454289028, 69.02876881190709, 62.407267570495605, 65.84408978053501, 65.6699470792498, 65.7670064653669, 64.81041322435651, 64.64373983655656, 68.3110476902553, 62.50901699066162, 62.210174969264436, 66.7142196382795, 65.8884470803397, 68.33790942600795, 66.77388381958008, 65.52033151899064, 67.2224178314209, 66.270674433027, 64.82680402483258, 63.36807836805071, 63.064511571611675, 61.35912486485073, 54.08433314732143, 49.555316652570454, 49.74958828517369, 47.894662448338096, 48.561897959027974, 49.517285687582834, 49.50971909931728, 50.22516468593052, 48.56347867420742, 46.33161653791155, 44.15046582903181, 46.77563074656895, 47.155686787196565, 50.6507487978254, 49.027281352451865, 47.79793310165405, 45.32191474097115, 45.835546425410676, 40.51078748703003, 44.59419516154698, 45.29272535869053, 44.17293282917568, 45.80559621538435, 56.27807399204799, 60.786537715366904, 62.43442807878767, 63.32238006591797, 62.44272422790527, 58.68369320460728, 53.259540285382954, 45.08603729520525, 49.798218727111816, 48.30887235913958, 49.779559339795796, 43.80259037017822, 46.678477559770855, 43.669306550707134, 40.986388206481934, 45.565435205187114, 46.909192493983674, 43.05973414012364, 45.336589336395264, 43.93069083350045, 43.39616938999721, 41.36525957924979, 43.39132302148001, 45.746175221034456, 45.290540150233674, 43.84750352587019, 44.6505936895098, 44.31964751652309, 44.737150873456685, 44.86482054846627, 46.49885272979736, 52.41911050251552, 58.28143766948155, 57.92574896131243, 56.94211333138602, 54.18130220685686, 60.18582425798689, 55.992093086242676, 56.41788911819458, 56.06957939692906, 54.959931237357004, 54.272869041987825, 62.547120911734446, 57.97299671173096, 59.70039531162807, 51.732882090977256, 52.3745482308524, 53.21572494506836, 52.209163733891074, 57.302648408072336, 53.536141123090474, 57.445027419498985, 57.269088608878, 60.72194726126534, 52.82323857716152, 44.6552038192749, 79.66660676683698, 61.91034630366734, 62.0013816016061, 48.467982632773264, 34.88839898790632, 19.913363456726074, 12.427396007946559, 17.96643304824829, 7.577196427753993, 1.607936593038695, 2.9862449935504367, 3.264142321688788, 2.408393497977938, 0.5813219579202789, 0.2349361548466342, 0.039558157324790955, 0.2250933801489217, 0.0635806175747088, 0.5497746393084526, 25.122554744992936, 32.05111598968506, 30.210420063563756, 38.57616581235613, 46.703869751521516, 52.84348215375628, 0.4522036106458732, 0.1754484333630119, 23.080156087875366, 41.180753639766145, 40.03702456610543, 64.5560883113316, 39.71218238558088, 30.292648519788468, 22.42891185624259, 30.909658976963588, 99.18993309565953, 95.52109663827079, 54.32474776676723, 111.86039706638881, 65.81117616380963, 114.99274226597377, 84.46754796164376, 71.09110532488141, 84.07332106998989, 71.14017350333077, 71.23067378997803, 52.96087544304984, 41.78062983921596, 66.25531196594238, 47.70841251100813, 38.53793682370867, 48.58218322481428, 19.715320689337595, 0.4698927200266293, 0.3329980086003031, 0.2416883111000061, 0.4071292078920773, 0.176676161055054, 0.26273247759257046, 0.14773129565375193, 0.2728491633066109, 0.1733268579202039, 0.27094500405447824, 0.27466644293495585, 0.25034250957625254, 5.325066830430712, 32.2645194871085, 61.169188908168245, 63.53613444737026, 68.97590691702706, 59.46181501661028, 56.50559622900826, 72.10664013453892, 67.60415881020683, 73.88043880462646, 72.78396442958287, 70.82387065887451, 65.38418156760079, 67.97610977717808, 67.062317439488, 66.2048749923706, 66.77507196153913, 66.31313487461635, 68.84684412819999, 66.80620683942522, 67.09728077479771, 68.19984872000558, 69.94208867209298, 68.59968280792236, 70.80854988098145, 69.51539284842355, 68.60675607408795, 68.94165229797363, 65.31437301635742, 66.93793773651123, 65.07252011980329, 65.5286763054984, 56.98616491045271, 54.114870480128694, 52.426451274326865, 52.372505460466655, 51.34481477737427, 51.020531926836284, 54.16162838254656, 52.07009553909302, 49.8621039390564, 50.458440031324116, 45.49756520135062, 49.12515715190342, 49.961720262254985, 52.7918153490339, 51.197655405317036, 50.089035579136436, 46.477090971810476, 48.813724994659424, 43.15849583489554, 47.20478275844029, 45.98901128768921, 45.050702231270925, 47.203341007232666, 58.9470716203962, 64.05333055768693, 67.18848282950265, 65.59143938337053, 65.8188886642456, 62.372074944632395, 54.79069743837629, 47.917577607291086, 50.08211169924055, 50.04384796960013, 52.80027478081839, 48.907289436885286, 49.20073618207659, 45.41037573133196, 43.975913184029714, 48.53279195513044, 49.210637365068706, 46.95902150017874, 50.78681189673287, 48.43551370075771, 46.62194006783621, 42.42084380558559, 45.095677920750205, 49.11762877873012, 47.86709199632917, 45.87617254257202, 46.99628816332136, 44.97168036869594, 46.51432984215872, 47.647046021052766, 49.225020136152, 57.06151812417166, 58.552900314331055, 58.92938845498221, 59.706752913338796, 55.5469081061227, 64.11379378182548, 58.85265254974365, 61.06509794507708, 58.71671799251011, 54.61264984948294, 58.46093395778111, 65.0569075175694, 61.57768045152937, 62.24237986973354, 54.30692563738142, 53.56925276347569, 59.13515935625349, 57.349486214774, 60.90911088671003, 55.42296961375645, 57.396459511348176, 60.97852339063372, 63.43651812417166, 54.77473395211356, 48.691210883004324, 75.28276593344552, 64.77603353772844, 67.94576699393136, 52.39690753391811, 41.2854768889291, 27.059153182165964, 36.02280010495867, 31.928094659532817, 10.338532141276769, 1.71377937069961, 6.044557137148721, 15.601757832935878, 5.600092164107731, 3.415801303727286, 0.994984426668712, 0.21997213709567273, 0.6908547718610082, 0.3282560259103775, 1.3977405577898026, 34.570821149008616, 43.76398965290615, 43.95887272698538, 42.72275693075997, 58.73592281341553, 58.02382973262242, 0.9464476768459592, 0.2457575670310429, 27.08086630276271, 48.85851308277675, 53.104741368974956, 90.5745906829834, 56.92628880909511, 46.90062189102173, 40.59337030138288, 58.621312277657644], [17.835171154567174, 43.26215600967407, 29.603731155395508, 8.367584415844508, 48.66823319026402, 26.606903621128627, 13.13253046785082, 18.75343292100089, 35.327358382088796, 35.68469728742327, 41.419702189309255, 23.016845839364187, 23.23978747640337, 39.43456711087908, 22.154850585120066, 38.80771453039986, 25.6872661113739, 2.5787431342261176, 0.33134314311402185, 0.03928138628335936, 0.14618870057165623, 0.33742764805044445, 0.25125790759921074, 0.10493189868118082, 0.28032699919172693, 0.40681713606630054, 0.12158772136483874, 0.05264762709183352, 0.019433957092197876, 0.10096413123288325, 1.3706944776432854, 30.649320398058208, 53.66748639515468, 55.546397413526265, 52.96727820805141, 52.444624287741526, 38.097434929439, 65.31991767883301, 60.548047746930806, 62.78989097050258, 64.44315923963273, 65.8146641595023, 60.793527603149414, 61.28457069396973, 65.94524165562221, 64.95462308611188, 63.06820106506348, 61.50214658464704, 64.77034296308244, 60.70870399475098, 62.06634725843157, 64.09784071786063, 64.11360618046352, 64.34126390729631, 63.10850756508963, 60.99403871808733, 62.43230193001883, 64.51387105669293, 63.9044098172869, 61.059942381722585, 58.259971209934776, 55.64495413643973, 48.743503025599885, 44.25480692727225, 45.552959714617046, 45.76053714752197, 45.409719126565115, 45.51778098515102, 47.54239572797503, 45.50302301134382, 45.96766642161778, 44.993129457746235, 42.186425481523784, 43.35126665660313, 43.556346212114605, 45.13435159410749, 47.799315793173655, 42.751831667763845, 43.60760654721941, 41.30475466591971, 40.77371426991054, 39.78996052060808, 44.21499374934605, 42.37655598776681, 43.17885405676705, 51.726312569209504, 59.313443183898926, 58.86841801234654, 60.455991063799175, 54.63500220435006, 58.45504188537598, 52.00189549582345, 46.051941122327534, 48.960026264190674, 44.073448521750315, 43.980071680886404, 39.79899665287563, 42.99133259909493, 40.29766539164952, 40.807294913700645, 44.09636715480259, 42.5571848324367, 41.54434939793178, 41.638848372868125, 41.70360558373587, 39.83620078223092, 40.88002865655081, 41.3875389780317, 41.00005531311035, 41.20972415379116, 42.28465911320278, 42.40156602859497, 40.73990780966622, 42.39079632077898, 42.65528992244175, 45.82180636269705, 48.220400946480886, 50.708283356257844, 52.521735395704, 52.89373847416469, 53.53605079650879, 56.85828678948538, 52.16550472804478, 53.031250272478374, 55.576847893851145, 54.50367430278233, 51.44680738449097, 55.60990742274693, 52.55402020045689, 54.399156025477815, 52.10348163332258, 52.001954555511475, 48.423941476004465, 51.348542485918315, 53.399803570338655, 55.4695850781032, 52.37812655312674, 59.14895847865513, 55.17418588910784, 56.655399390629356, 35.91483204705374, 67.17392635345459, 50.86312396185738, 60.961903299604145, 43.50447790963309, 33.542578084128245, 18.45639569418771, 17.173376083374023, 6.356508237974984, 0.07462793442287616, 0.516225588108812, 0.8318496804152216, 1.2085083233458656, 0.7347962111234665, 0.8108204688344682, 0.3099500739148685, 0.05906667693385056, 0.22471000786338532, 0.05609824229031801, 0.6556264821972165, 12.552418419292994, 38.499079023088726, 26.466965164457047, 31.939958708626882, 43.784028257642476, 47.997857093811035, 0.22230582258531026, 1.212973626596587, 24.587802273886545, 19.335226433617727, 39.28397185461861, 25.29038848195757, 18.15833534513201, 12.54744177205222, 11.194953203201294, 5.56890343768256, 19.455866268702916, 59.21875313350132, 41.29797669819423, 34.709927558898926, 68.52464226314, 51.99652453831264, 28.980559383119854, 33.799001353127615, 52.15925134931292, 53.50478390284947, 51.231378487178254, 29.310451166970388, 34.008347102573936, 53.73838233947754, 29.46055657523019, 41.03153412682669, 33.81227936063494, 2.850701923881258, 0.251204357615539, 0.21605495443301542, 0.20688409225216933, 1.2602789167846953, 0.9903053577457155, 0.2827634827366897, 0.3647797746317727, 0.5134253012282508, 0.1045926311718566, 0.07279142511210271, 0.035446306357958486, 0.1900202850145953, 2.3966275921889713, 37.50772394452776, 60.3160126549857, 61.064625467572895, 59.96752575465611, 59.42646953037807, 46.257211753300254, 67.7820187977382, 63.506514276777, 68.31624494280133, 68.15222576686314, 70.25091525486538, 65.6457187107631, 64.17388875143868, 66.0729009083339, 65.68178680964878, 64.0383780343192, 65.06427260807583, 66.79249109540666, 64.18820204053605, 64.30816963740757, 65.58937576838902, 65.44071905953544, 66.67593506404332, 64.81804234640938, 62.81388310023716, 65.37373147691999, 66.13933958326066, 64.15485763549805, 65.29670374734062, 62.28909260886056, 57.67010041645595, 50.87498106275286, 49.294998918260845, 49.3755076953343, 49.47870234080723, 48.61146640777588, 48.91200726372855, 48.991703101566856, 48.48759044919695, 47.95697389330183, 47.207714898245676, 43.77212946755545, 45.56839861188616, 45.45521593093872, 48.87974330357143, 49.56675338745117, 46.002400466373985, 45.09189462661743, 43.764236313956125, 40.4220346723284, 41.153964860098704, 46.227063519614084, 41.972525187901084, 42.81323289871216, 56.164856570107595, 60.41796357291085, 59.041059902736116, 60.89825085231236, 58.234724930354524, 60.4994728905814, 55.801198278154644, 46.2783898626055, 47.630075045994346, 45.23537492752075, 45.15917750767299, 40.33102716718401, 44.498949255262104, 41.58992958068848, 44.59041881561279, 45.79170329230172, 45.90438570295061, 44.73494482040405, 43.69756140027727, 42.23383304050991, 42.41473633902413, 41.48021752493722, 42.76121173586164, 42.699720178331646, 45.74757528305054, 44.10747732434954, 44.80076163155692, 42.947954995291575, 44.925957747868125, 43.39761461530413, 49.7106853212629, 52.487842082977295, 54.526342800685335, 54.343897002083914, 56.68128490447998, 55.52412148884365, 58.84193842751639, 55.737743854522705, 55.07044928414481, 55.97071347917829, 56.759921142033164, 51.727726527622764, 57.38211842945644, 55.094681126730784, 57.808025632585796, 55.379532950265066, 52.749917711530415, 50.74578625815255, 54.19958291734968, 55.399571555001394, 55.83119365147182, 53.56126928329468, 59.42582334790911, 59.32507446834019, 55.05810580934797, 45.464095728737966, 69.5569291796003, 59.28547668457031, 64.36472797393799, 52.695224966321675, 47.93279068810599, 27.260265316282, 32.46370349611555, 20.688855375562394, 1.2276721064533507, 0.9756159973996026, 0.9987553443227495, 1.2982132583856583, 0.4618361751948084, 0.942715191415378, 0.3890049675745623, 0.08207118537809167, 0.12201817040996892, 0.05276675069970744, 0.3970923993204321, 14.250769206455775, 41.48365340914045, 25.833840097699845, 36.49716404506138, 52.67959499359131, 57.12403106689453, 0.212530005723238, 1.568286046385765, 36.65455116544451, 31.19650493349348, 54.696868964603965, 36.21176331383841, 23.777077777045115, 14.893168381282262, 15.058719635009766, 7.48970992224557, 38.594116483415874, 82.9426268168858, 93.6426442010062, 106.47527912684849, 101.551910672869, 61.56386743273054, 39.409942695072715, 52.2628698348999, 70.05658108847481, 74.72619438171387, 70.72879150935582, 38.75913272585188, 46.022432122911724, 67.50785677773612, 45.728846413748606, 54.855649198804585, 45.20245088849749, 4.666163946901049, 0.40979435773832457, 0.38986494285719736, 0.1870233586856297, 0.7876334616116115, 0.5478007537978036, 0.38095694514257566, 1.0176143837826592, 2.327653693301337, 0.261222167206662, 0.24742972158959933, 0.21101668264184678, 0.29262376363788334, 2.3466620104653493, 33.22529206957136, 61.77867794036865, 68.19578402382987, 62.805934361049104, 61.9891597202846, 54.00650290080479, 68.5786714553833, 67.71226583208356, 68.69351822989327, 74.02660805838448, 71.60988562447685, 71.26529666355678, 67.32134628295898, 69.58126177106584, 66.82437637874058, 65.93516676766532, 66.26988233838762, 70.3192160470145, 66.40128667013985, 67.57664394378662, 68.23575006212506, 69.42324583871024, 68.7574486051287, 69.03402859824044, 65.00631768362862, 66.96017892020089, 68.65910380227226, 69.26507009778703, 67.7817964553833, 64.4026095526559, 60.448007583618164, 56.16370664324079, 50.812857219151084, 53.52767126900809, 53.02184241158621, 50.79325982502529, 50.30009058543614, 54.34185423169817, 52.91169956752232, 52.27276406969343, 51.087675843920024, 45.799839632851736, 49.516893114362446, 49.70691244942801, 52.67008638381958, 52.71661499568394, 48.919851779937744, 47.11517531531197, 45.92032139641898, 42.37235232761928, 40.602135453905376, 46.77247279030936, 43.07206719262259, 41.77130535670689, 55.773329053606304, 64.35871083395821, 64.2616444996425, 64.23280252729143, 59.74325180053711, 63.54210294995989, 58.51391397203718, 46.781939710889546, 54.77033574240548, 46.39056505475725, 49.168764046260286, 43.95147289548601, 46.72728170667376, 43.85577188219343, 46.76182467596871, 47.63573782784598, 48.35805170876639, 47.06648233958653, 48.29749468394688, 46.4671585219247, 45.870318685259136, 44.02217776434762, 43.51006078720093, 44.57422603879656, 47.83334459577288, 48.729346070970806, 47.0087045942034, 44.82276657649449, 47.70834650312151, 47.72681828907558, 53.36759172167097, 55.13057552065168, 57.557980809892925, 55.597220012119834, 57.995091983250205, 56.86036777496338, 60.22724941798619, 62.047357831682476, 57.623571804591585, 58.1857088633946, 58.58819716317313, 55.456706592014854, 62.227239745003835, 57.73150164740426, 61.98152365003313, 58.023888792310444, 53.34136574608939, 53.94729035241263, 56.13085903440203, 58.13622031893049, 57.14144325256348, 58.07682711737496, 60.582406588963096, 62.25319821493966, 58.89744758605957, 45.57909883771624, 72.73488235473633, 60.495276178632466, 66.30589485168457, 53.423291955675396, 52.81058243342808, 40.52452754974365, 44.34893764768328, 19.185784578323364, 1.3483863089765822, 2.3068705456597463, 2.4151762425899506, 4.883474937507084, 2.9294282708849226, 3.234505649123873, 0.8741432023899895, 0.3182734458574227, 0.39095792706523624, 0.166573575298701, 0.7932674192956516, 20.931005307606288, 55.09107501166207, 42.382138865334646, 49.29481479099819, 58.950059345790315, 67.11862564086914, 0.3381149226001331, 1.750537512557847, 46.33635173525129, 46.12197549002511, 79.80300685337612, 56.43582936695644, 45.204549244471956, 36.820255279541016, 40.466457980019705, 38.01922253199986], [12.642313344138008, 29.744199412209646, 34.51920645577567, 27.0905590397971, 15.690847635269165, 2.312991040093558, 1.797545007296971, 8.120206832885742, 22.59633043834141, 22.44160795211792, 36.870556763240266, 38.849820613861084, 33.440505572727744, 26.50430304663522, 29.095140389033727, 39.578849928719656, 15.66251982961382, 0.5555313304066658, 0.16498749969261034, 0.1611257940530777, 0.2411503413958209, 0.02504023054747709, 0.4537375611918313, 0.17447240145078727, 0.6252952611872128, 0.2296515612729958, 0.014935380180499383, 0.06436597436134305, 0.032110326258199554, 0.13929026573896408, 0.32590142797146526, 15.17917707988194, 45.236594336373464, 56.75772898537772, 49.600799560546875, 51.97143806729998, 36.38479430334908, 58.70048005240304, 60.186345372881206, 61.818227086748394, 62.60598605019705, 67.97260093688965, 59.64480972290039, 61.50619738442557, 62.251037325177876, 60.691243171691895, 64.77510247911725, 62.94115325382778, 62.98084136417934, 61.3880432673863, 63.484439849853516, 62.81138869694301, 62.43527575901577, 62.08564240591866, 61.78525788443429, 58.251859188079834, 61.686857495989116, 61.149629729134695, 60.637478010995046, 61.49629620143345, 59.28147452218192, 53.79384633472988, 43.54014648709978, 45.38785661969866, 43.90024035317557, 46.83867870058332, 43.8624838420323, 45.79862717219761, 46.5015104157584, 47.49731234141758, 46.7720558983939, 45.135039465767996, 45.61340209415981, 45.042392185756135, 44.472382817949565, 45.29206527982439, 45.00436469486782, 44.64149154935564, 42.14774833406721, 40.808257239205496, 39.24747296742031, 44.0217330796378, 45.43355144773211, 42.883298533303396, 41.13730307987758, 49.797735827309744, 55.72981595993042, 55.67142677307129, 55.19071912765503, 55.8653370993478, 56.01369503566197, 49.30836377825056, 42.600583280835835, 39.69875846590315, 44.40981428963797, 40.394735200064524, 39.488888127463206, 39.79053374699184, 40.70399604524885, 43.67590386526925, 43.19056524549212, 39.65138564790998, 41.61654812949044, 40.45205089024135, 40.23040335518973, 39.79638065610613, 39.03468438557216, 42.359039579119, 38.913903849465505, 39.84769657679966, 43.39383479527065, 41.62571627753121, 41.404874733516145, 42.24947690963745, 41.241887365068706, 44.898397718157085, 49.95927102225167, 51.07578747613089, 52.70338562556675, 53.505725383758545, 54.55992691857474, 55.63904816763741, 52.970453534807476, 52.15910196304321, 52.99097156524658, 54.393771171569824, 51.179002966199604, 53.2581193787711, 52.80669491631644, 53.05788966587612, 53.164527143750874, 53.38774149758475, 48.11016777583531, 53.501650265284944, 51.95267098290579, 57.38835791179112, 51.25860152925764, 58.660055433000835, 54.712828976767405, 57.78086859839303, 34.740127904074534, 59.703355244227815, 52.263411794389995, 59.931610516139436, 49.24736554282052, 38.22186326980591, 28.453898089272634, 15.73242391858782, 2.202481461422784, 0.4276799437190805, 0.46398566556828363, 1.1917098590305872, 0.13005422348422663, 0.16201194721673215, 0.2649556840104716, 0.07618968454854828, 0.10027505856539522, 0.1171488809798445, 0.20220917596348695, 0.31966172850557734, 8.216760737555367, 29.533453600747244, 32.018098149980815, 37.29079423631941, 50.36024114063808, 39.311629159109934, 0.07985743095300027, 4.5228286896433145, 26.58730796405247, 22.39253282546997, 33.86573532649449, 12.607809458460126, 1.4715904636042458, 0.11295624024101666, 0.5683591706412179, 2.349843199763979, 15.114588362830025, 35.132228646959575, 34.92669745853969, 17.404143129076274, 30.583514009203228, 8.583466683115278, 5.583331372056689, 14.156039203916277, 45.07565668651036, 36.2708785874503, 47.95438568932669, 50.44355351584298, 50.17538431712559, 35.12056956972395, 40.0634103502546, 45.46962996891567, 21.54294879095895, 0.7679215307746614, 0.08007091164056744, 0.33333057218364304, 0.33851680532097816, 0.32504449252571377, 1.0180856670652116, 0.16625401244631835, 0.06389918298061405, 0.13074087378169807, 0.07720211307917323, 0.08612632099539042, 0.02396752266213298, 0.10264145622828177, 0.43324911487954004, 22.926654747554235, 53.38396167755127, 64.58610452924455, 57.78545788356236, 59.68477576119559, 42.707960741860525, 60.85631152561733, 64.83323805672782, 66.18206405639648, 65.78252179282052, 71.88638223920549, 65.72221142905099, 63.66423838479178, 67.1145887374878, 61.882824489048545, 66.55202089037213, 65.66650077274868, 65.43604987008231, 62.70050239562988, 62.91188049316406, 64.39741924830845, 62.99817711966378, 63.91969585418701, 63.57703154427664, 62.19983604976109, 64.38387026105607, 63.905410357883994, 62.15373475211007, 64.7341775894165, 62.332414627075195, 57.08771283285958, 46.87307228360857, 49.21410799026489, 46.16031912394932, 48.70805331638881, 46.390693596431184, 47.80886261803763, 49.1506917817252, 51.472856181008474, 49.91440302985055, 47.91027157647269, 44.62010151999337, 46.80798503330776, 45.799339362553184, 47.73678200585501, 47.671510628291536, 47.65811102730887, 44.86019652230399, 43.039931774139404, 41.777398926871165, 45.29725905827114, 45.294597898210796, 44.65269899368286, 40.70972830908639, 48.860264028821675, 56.47557653699602, 57.95792606898716, 57.184292793273926, 56.62153387069702, 57.14805098942348, 52.71865776606968, 43.24109949384417, 42.496061529432026, 44.25449078423636, 41.74249465124947, 37.09727300916399, 42.57390219824654, 43.00110176631382, 45.97813388279506, 46.18884147916521, 44.37508371898106, 43.97424909046718, 42.807785511016846, 41.26966973713466, 42.80610057285854, 42.23462860924857, 43.038886070251465, 41.788769653865266, 42.961264269692556, 45.20771414893014, 44.019714627947124, 44.42975909369332, 44.68365321840559, 43.77457870755877, 46.06676510402134, 51.59191356386457, 54.97448076520647, 55.52059875215803, 55.70040076119559, 55.44458198547363, 57.491420541490825, 53.84334530149187, 54.02556528363909, 56.34179244722639, 54.49202217374529, 53.39283105305263, 55.59216867174421, 57.05372224535261, 55.27801282065255, 55.258613450186594, 54.54319565636771, 52.07635586602347, 55.68122720718384, 54.33512837546212, 58.61808136531285, 53.82339702333723, 59.63522120884487, 59.659039633614675, 55.785867077963694, 42.544004099709646, 65.20085334777832, 58.26004764011928, 64.81221280779157, 56.579611914498464, 48.30760431289673, 39.358647618974956, 27.308795009340557, 10.115706886563983, 0.533834060387952, 0.30585888773202896, 1.993368910891669, 0.07646069822034665, 0.0801865475784455, 0.181741954226579, 0.09187035063015563, 0.1162711280797209, 0.060435594192573, 0.12238345295190811, 0.17777757266802446, 9.20572476727622, 38.230513777051655, 34.06981781550816, 45.07673018319266, 54.64315244129726, 48.12267453329903, 0.2701257951557636, 7.832194447517395, 38.547056334359304, 38.04756423405239, 48.30034691946847, 16.35680988856724, 2.0064606198242734, 0.016300562103944163, 0.5040597266384533, 4.239201486110687, 52.79695006779262, 50.987329959869385, 76.75312982286725, 73.39544064658028, 35.026230403355186, 9.035785726138524, 4.913115518433707, 37.75019175665719, 66.37708609444755, 53.94856882095337, 64.554247038705, 60.07288128989083, 64.97289684840611, 46.241880553109304, 53.249291692461284, 53.32432876314436, 27.648579290934972, 1.1185871256249291, 0.22405272456152098, 0.42949727763022694, 0.527277946472168, 0.9945060866219657, 1.989609066929136, 0.4041541303907122, 1.1874243404184068, 0.4532749360161168, 0.14411264125789913, 0.11792109454316752, 0.09480592382273503, 0.17031028121709824, 0.9790659951312202, 28.195551906313213, 51.53819704055786, 58.43448216574532, 64.47737216949463, 63.20721367427281, 50.58686705998012, 65.68378094264439, 68.251022202628, 69.81695161546979, 68.52031353541783, 73.85879516601562, 67.8736377443586, 63.006396838596885, 66.091126033238, 63.962934494018555, 72.26088319505963, 67.16137095860073, 67.27300071716309, 65.62679876599992, 65.86743572780064, 66.4257721219744, 66.28064509800502, 65.70803015572685, 66.26578984941754, 63.22664778573172, 66.44968782152448, 65.36968067714146, 64.42591381072998, 67.21517780848912, 65.43023422786167, 61.020170892987935, 48.66647182192121, 51.64779445103237, 52.06874411446707, 52.218057428087505, 48.4697961126055, 51.37335797718593, 53.848209040505544, 55.66996765136719, 54.017988273075645, 51.50679118292672, 49.058343274252756, 50.393866947719026, 49.42214400427682, 50.07961729594639, 52.21839094161987, 50.54296139308384, 46.78516020093645, 45.33993141991751, 42.273430824279785, 45.34231465203421, 47.68846423285348, 43.38813379832676, 42.16618537902832, 54.06390196936471, 60.81524767194475, 59.611472266060964, 60.26791027614048, 60.565119470868794, 60.94243444715227, 54.57196467263358, 45.65969794137137, 48.565465859004426, 45.97950267791748, 44.19334316253662, 39.80961002622332, 43.844053745269775, 46.31950235366821, 49.89344726290022, 46.29233142307827, 46.536171504429404, 47.342464787619456, 44.249032974243164, 45.31584201540266, 44.87761913027082, 43.1575265611921, 44.91297156470162, 42.96601683752877, 44.939277444567, 48.05098649433681, 45.043781825474326, 47.13800362178257, 45.70979445321219, 46.483855043138774, 50.07526077542986, 55.26695128849575, 55.18864509037563, 56.76677206584385, 56.35812766211373, 58.22169010979788, 61.180312974112375, 58.8309394291469, 58.751966203962056, 60.00820745740618, 58.5275046484811, 57.12157140459333, 60.85143389020647, 57.92824683870588, 57.27556085586548, 57.85320281982422, 56.660905838012695, 53.91925089699881, 57.42974485669817, 55.69373396464756, 59.79010350363595, 53.740890639168875, 63.896759850638254, 63.1836245400565, 60.086041178022114, 43.970587389809744, 68.19102450779506, 62.120529311043875, 68.67901733943394, 59.2216157913208, 56.54598610741751, 51.43588481630598, 34.9611223084586, 15.350538764681135, 2.7914774332727705, 0.5043403687221664, 4.027388257639749, 0.5412376374006271, 0.37949779629707336, 0.550987859921796, 0.19084018601902894, 0.6632911594850677, 0.3619159497320652, 0.24901898631027766, 0.46251433023384636, 14.39482273374285, 50.311562061309814, 44.87756354468209, 56.32409538541521, 63.50104604448591, 59.497466223580496, 0.27291720679828096, 9.315890192985535, 52.60836900983538, 55.08345283780779, 69.0264481135777, 37.33353955405099, 3.9391235538891385, 0.19021961146167346, 1.105175799557141, 12.337217075484139], [6.582228720188141, 25.336885826928274, 38.80448709215437, 31.192450659615652, 0.6634306120021003, 0.45248156573091236, 1.0730340842689787, 4.325921084199633, 16.07652129445757, 20.748743636267527, 32.07253728594099, 36.94868925639561, 32.23177262714931, 45.92841952187674, 61.29995400565011, 34.34243733542306, 9.884117347853524, 0.3167487776705197, 0.031138389304812466, 0.3368526574756418, 0.0989823340039168, 3.102673568895885, 4.716256984642573, 0.38486310839653015, 0.0710771945970399, 0.11475758786712374, 0.06570521928369999, 0.1472896100687129, 0.0892795342952013, 0.10403134700443063, 0.09278916168425765, 5.387590195451464, 23.598119974136353, 45.36748450142996, 45.76272235597883, 46.96595580237252, 33.91792324611119, 45.4516202381679, 60.24455738067627, 61.43178217751639, 63.34695584433419, 60.844728878566194, 57.55313444137573, 59.72555473872593, 64.05061381203788, 58.38244710649763, 64.10555321829659, 63.315543038504465, 61.953605788094656, 61.16037164415632, 61.638845443725586, 61.70558983939034, 61.81662900107247, 59.52945572989327, 59.61807305472237, 59.7620119367327, 60.49233014242989, 59.81092725481306, 61.531586102076936, 62.561600957598, 61.48763179779053, 50.164058753422324, 44.77385125841413, 45.73642689841134, 45.662609236580984, 45.23607669557844, 44.75538294655936, 43.04448979241507, 45.22560576030186, 45.36170360020229, 43.897638252803254, 44.52834013530186, 42.67048563276018, 41.032979352133616, 42.30801548276629, 41.853770051683696, 43.649875913347515, 46.20775100163051, 39.731831891196116, 42.537347725459504, 39.402011326381135, 42.940648964473176, 46.13922439302717, 44.424745968409944, 42.93224164417812, 40.42862156459263, 49.69632339477539, 57.20258740016392, 55.41247435978481, 54.72046504701887, 51.51853711264474, 46.302343777247835, 42.00315979548863, 42.90126657485962, 42.970251764569966, 38.54371772493635, 37.91281087057931, 39.73613977432251, 39.408014569963726, 43.357057980128694, 40.90090104511806, 40.244205951690674, 40.49435499736241, 38.80804456983294, 40.03662851878575, 42.19637182780674, 40.327490534101216, 42.73547213418143, 42.568406173161094, 42.16460118974958, 41.592757497514995, 41.28379889896938, 42.13902834483555, 42.070866516658235, 42.5358156476702, 43.16786200659615, 45.46971682139805, 52.405297483716694, 52.88071755000523, 53.202370507376536, 51.20110171181815, 58.99384689331055, 49.78167854036604, 49.063933100019185, 53.52628510338919, 53.256354536329, 49.91184956686837, 51.56217179979597, 51.161493505750386, 50.36642156328474, 52.01258877345494, 55.464933259146555, 50.808785574776785, 50.58390712738037, 53.14346367972237, 56.05173642294747, 51.85533019474575, 56.689452511923655, 59.5072979245867, 53.04927042552403, 36.92546837670462, 48.86953639984131, 46.92833825520107, 49.86385488510132, 49.727402687072754, 53.60803760801043, 38.227758816310335, 12.078830071857997, 1.2273472781692232, 2.3364544553416113, 1.9901664427348544, 1.0453429073095322, 0.13845804253859179, 0.15878967940807343, 0.07765618871365275, 0.08436747001750128, 0.08090757924531188, 0.11380273981818131, 0.12342488206923008, 0.10569154577595846, 4.577256969043186, 28.160343647003174, 22.171873671667917, 40.73544359207153, 50.53089237213135, 33.8445120538984, 0.46804080797093256, 8.168197172028677, 27.83953489576067, 25.34715700149536, 40.72882890701294, 4.093822589942387, 0.04428707143025739, 0.04104891911681209, 0.10345997980662755, 0.324867774865457, 2.181904588426862, 34.856433800288606, 48.72406196594238, 27.64748842375619, 0.8428631722927094, 0.3215315267443657, 2.562182971409389, 19.335773604256765, 36.43988309587751, 39.10574013846261, 42.09312507084438, 53.34150471006121, 44.84854439326695, 55.65766933986119, 67.03483036586216, 43.47271769387381, 12.84993507180895, 0.2683087869414261, 0.09625155625066587, 0.5192756844418389, 0.1765484879059451, 0.8157730687941823, 0.6930847636290959, 0.22963337653449603, 0.08179914711841516, 0.046490406950137446, 0.11016760380672556, 0.19412681965955667, 0.11533219846231596, 0.0428284620200949, 0.13955108102943214, 7.9787580115454535, 28.598933049610682, 49.098017488207134, 52.709142208099365, 55.152528354099815, 42.25723457336426, 49.73445510864258, 63.88564968109131, 65.62447806767055, 68.34786619458879, 67.27710015433175, 62.483405930655344, 63.30080590929304, 65.59075151171002, 59.9304084777832, 67.34163502284459, 66.24409757341657, 66.57477624075753, 64.76731354849679, 62.641539982386995, 65.03140762874058, 62.59578609466553, 59.41396277291434, 62.127331597464426, 62.54648167746407, 61.827558517456055, 61.17359406607491, 63.47886739458357, 62.45270878928048, 63.515797070094514, 52.60118109839303, 47.90284742627825, 49.3884209224156, 46.61018718991961, 47.18086358479091, 48.41935566493443, 47.439809049878804, 48.75030878611973, 47.81113815307617, 46.577669620513916, 45.666048594883506, 43.17480673108782, 43.60446943555559, 44.869423730032786, 46.160871505737305, 46.45024313245501, 49.16938591003418, 43.27601766586304, 43.88326937811715, 41.76133469172886, 43.828864983149934, 45.34849507468087, 44.94685445513044, 45.398226806095664, 42.192737919943674, 52.15842798777989, 60.93661880493164, 57.032047339848106, 58.04214171000889, 52.74496364593506, 46.15112318311419, 45.29843330383301, 47.14872816630772, 42.90503944669451, 39.268668447222026, 38.904822553907124, 42.713533197130474, 40.729322229112896, 48.43988759177071, 43.78924982888358, 44.937988553728374, 42.75166143689837, 43.3021741594587, 41.05229187011719, 45.254472051348, 43.77566957473755, 44.9700162751334, 42.62265770775931, 46.23255607060024, 43.65422201156616, 44.80597278050014, 44.271621567862375, 44.0995911189488, 44.24925184249878, 45.77908188956124, 50.327820846012656, 55.670155252729145, 55.478926931108745, 56.491606031145366, 55.80959170205252, 59.13369328635079, 51.960157666887554, 52.23510830742972, 54.62155049187796, 54.11305005209786, 52.374152183532715, 55.35081951958792, 56.43605170931135, 53.135542733328684, 55.865753991263254, 55.518354484013145, 52.25369126456124, 51.665762492588584, 56.44998632158552, 56.889588424137656, 56.55149950299944, 59.669295174734934, 64.23424080439976, 53.884231976100374, 43.569749287196565, 55.53873355048043, 50.308233874184744, 56.17342717306954, 57.765398434230256, 61.05216039930071, 49.711668491363525, 25.996071849550518, 7.860883559499468, 3.054082210574831, 1.724140003323555, 0.6918685031788689, 0.050484084258122106, 0.17258493416011333, 0.09841626616460936, 0.0936295340902039, 0.029036742435502153, 0.11237685954464333, 0.1124086081981659, 0.04002785622807486, 5.879293365137918, 33.73545660291399, 30.738889626094274, 48.954523290906636, 58.708546910967144, 39.559728486197336, 0.517862431704998, 10.048681957381111, 40.33554349626814, 40.32968963895525, 60.154599053519114, 19.003211975097656, 0.05074339320084878, 0.03900113435728209, 0.0589903960270541, 0.34048007854393547, 22.468059744153702, 65.74546704973493, 72.00659302302769, 59.71872465951102, 1.8686279015881675, 0.7161433377436229, 4.686335870197841, 55.06858369282314, 54.272629329136436, 62.606861523219514, 61.1825989314488, 68.05558327266148, 57.478448254721506, 70.85476234980992, 77.9768396105085, 52.39363145828247, 19.535885197775706, 0.39634280811463085, 0.44511921650597025, 1.0006453629050935, 0.6124809373702321, 6.2674840092659, 11.91421856198992, 0.8513085448316166, 0.17705657492790902, 0.19761135482362338, 0.3144954442977905, 0.47705658418791635, 0.1831670677555459, 0.258672368313585, 0.3392969306026186, 12.961893132754735, 47.82421118872506, 52.68968377794538, 53.42445230484009, 58.85344464438302, 52.35855000359671, 54.771207741328645, 69.17180442810059, 67.67496790204729, 71.98416423797607, 68.61066790989467, 65.04010677337646, 63.74380915505545, 68.1160534449986, 62.09982367924282, 71.3778783253261, 67.21229430607387, 68.22800976889474, 66.44971561431885, 66.05764961242676, 65.53822313036237, 65.69592639378139, 61.29034464699881, 64.28629670824323, 64.11619091033936, 65.85288619995117, 62.680241448538645, 64.42693519592285, 66.90580231802804, 69.20394679478237, 55.73411342075893, 50.918254443577354, 51.99418994358608, 52.05121728352138, 49.16769054957798, 51.6319386618478, 49.704543113708496, 54.179502623421804, 51.45744160243443, 51.54152870178223, 48.632498604910715, 46.802819047655376, 45.311138084956575, 49.22391537257603, 47.42516572134835, 48.646662507738384, 51.40656689235142, 45.83467442648751, 47.0271520614624, 42.096901416778564, 45.28710426603045, 48.16131346566336, 46.20355428968157, 45.05659777777535, 43.28335148947579, 52.34110655103411, 62.22113227844238, 60.0224095753261, 60.20388262612479, 55.3840388570513, 47.40143067496163, 43.23132685252598, 44.76207753590175, 45.47017887660435, 39.3127304485866, 39.740037713732036, 46.00474200929914, 43.986356326511924, 48.58750901903425, 45.58924320765904, 45.26240342003958, 44.7110777582441, 44.75685249056135, 44.24371412822178, 47.02335834503174, 44.72033623286656, 45.954808780125205, 45.88435752051217, 49.06874820164272, 46.00139992577689, 45.7818090575082, 46.515893186841694, 45.08831977844238, 47.25756127493722, 48.97282484599522, 53.562731879098074, 58.52262701307024, 59.04843194144112, 56.19378192084176, 58.64237226758684, 63.31348637172154, 55.29433066504342, 57.18030105318342, 59.383578300476074, 55.22896201269967, 54.15719543184553, 57.122936725616455, 59.13472856794085, 55.96769101279122, 57.80867528915405, 56.01578991753714, 54.60004234313965, 54.70246573856899, 59.34238937922886, 57.84626504353115, 57.44349881580898, 62.1137478692191, 64.55761691502163, 58.90239470345633, 44.90171548298427, 59.34090941292899, 54.67267533711025, 58.483689308166504, 59.92790712629046, 60.82457215445382, 55.162245409829275, 37.455556869506836, 11.683849300657, 6.882353987012591, 4.371480856622968, 2.8872325122356415, 0.3367886037698814, 0.23347771167755127, 0.37629296683839386, 0.11913462728261948, 0.19879104223634514, 0.3351967606161322, 0.2295381102178778, 0.2867739503937108, 9.5665169273104, 46.54723303658621, 36.53188419342041, 54.872380461011616, 65.28147329602922, 47.768854890550884, 0.8042780884674617, 13.653560246740069, 57.71395397186279, 60.67280265263149, 73.8513605935233, 20.091001101902553, 0.22955062240362167, 0.1179249214806727, 0.25080179635967526, 0.9691470073802131], [0.09290144565914359, 13.584400483540126, 29.761715820857457, 7.10150625024523, 0.14942235419792788, 0.09072376215564353, 5.451586578573499, 15.792831557137625, 6.737712034157344, 21.125699043273926, 20.294147321156093, 21.49189169066293, 36.52765621457781, 20.96200816971915, 37.87666286740984, 28.291263341903687, 3.2639857700892856, 0.24903062997119768, 0.15708978633795465, 0.34469459525176455, 0.05210725537368229, 0.7807481225047792, 2.0897621384688785, 0.29079880299312727, 0.060513401803161414, 0.05847434300397124, 0.058298500653888495, 0.09255307220986911, 0.08039787731000356, 0.02367818175948092, 0.013055124868904906, 0.8306368397814887, 9.986056974955968, 18.434679099491664, 29.25411864689418, 35.52169254847935, 32.92565100533621, 38.08964947291783, 51.922932692936485, 58.51954896109444, 63.67020688738142, 61.18495437077114, 60.034165927342, 60.13868767874581, 59.80133179255894, 58.74971498761858, 62.11857686723982, 63.263514927455354, 62.7577486038208, 61.87958662850516, 59.708552496773855, 61.31744262150356, 58.85611275264195, 56.3776764188494, 59.582025800432476, 59.59508146558489, 59.5367374420166, 56.24191556658064, 60.28735133579799, 57.50475760868618, 53.500020912715364, 46.43492235456194, 44.84061302457537, 44.50927427836827, 43.65296786172049, 45.71994924545288, 43.517655168260845, 43.86215727669852, 45.450914996010916, 45.646204539707725, 43.726795945848735, 45.31730808530535, 44.55383307593209, 42.19199793679373, 41.40019859586443, 41.70486668178013, 43.14563471930367, 44.586013657706125, 45.118523597717285, 40.787812164851594, 39.75008133479527, 40.72098091670445, 40.53821202686855, 40.94572040012905, 45.268820081438335, 44.61766617638724, 51.43397058759417, 59.462565422058105, 56.06125545501709, 55.11020687648228, 49.28218296595982, 44.250370502471924, 51.60479204995291, 44.41781514031546, 39.419069153921946, 39.38109030042376, 39.078385080610005, 36.315895966121126, 40.38985756465367, 44.51062570299421, 39.30599069595337, 40.879052434648784, 39.7662741116115, 39.900565419878276, 41.28428527287075, 43.39098603384835, 42.8489396912711, 42.83246203831264, 41.86043337413243, 41.3644049508231, 42.58253880909511, 41.29095901761736, 40.65521969114031, 40.76163830075945, 41.03489705494472, 42.532511779240195, 42.29604721069336, 49.597617285592214, 53.00260284968785, 54.03776632036482, 53.99305118833269, 54.39906569889614, 49.467883995601106, 45.74648788997105, 49.39899260657174, 51.50287587302071, 53.76522670473371, 51.177554266793386, 51.240074157714844, 51.86583239691598, 50.64009026118687, 52.67705890110561, 49.98320409229824, 51.012138502938406, 54.233090605054585, 54.683920996529714, 52.500140394483296, 55.52326338631766, 56.91946915217808, 49.2271671295166, 34.45192704881941, 47.181721687316895, 46.41841343470982, 52.40639877319336, 62.426534925188335, 56.57636710575649, 41.74659756251744, 19.35594596181597, 1.6139289800609862, 2.9386704606669287, 0.9765256685870034, 0.28898176763738903, 0.14486824428396566, 0.0807634312659502, 0.09672831531081881, 0.06168310796575887, 0.09959736493016992, 0.07773747720888682, 0.18356245011091232, 0.028775750725929226, 4.828318400042398, 22.69049068859645, 18.429414102009364, 33.68500920704433, 57.86261762891497, 21.388481651033672, 0.4805790494595255, 4.754146380083902, 36.281210558755056, 25.04804573740278, 51.78630331584385, 28.47010476248605, 0.6591517701745033, 0.15920659846493176, 0.053595883173069785, 0.027614351528297578, 0.041417146500732215, 4.15797313622066, 21.08476894242423, 3.808021903038025, 0.07911463866808585, 0.5766744815877506, 20.357002462659562, 38.32030187334333, 24.62135512488229, 33.43528747558594, 33.96897166115897, 36.12789855684553, 53.91384172439575, 35.0512751851763, 45.525184290749685, 34.78801836286272, 4.316065064498356, 0.3033672800021512, 0.166217832959124, 0.3817597877766405, 0.15471819788217545, 0.2716758948351656, 0.5208201387098857, 0.19838112566087926, 0.05816033735339131, 0.03786143979855946, 0.024828697255413448, 0.12609077830399784, 0.07714158775550978, 0.012271734137487198, 0.05755744541862181, 0.26124474885208265, 10.92322826385498, 16.010716642652238, 30.748172419411794, 40.357235772269114, 42.89950520651681, 42.26420709065029, 57.25415693010603, 61.543307713099885, 67.25217001778739, 65.58525548662458, 63.22525814601353, 64.16628047398159, 61.58646297454834, 61.66044044494629, 65.19639955248151, 64.57027653285435, 64.45599951062883, 63.347185134887695, 62.187002726963584, 63.80139582497733, 61.11094215938023, 56.10548768724714, 59.87325259617397, 61.79001045227051, 62.22414779663086, 58.906556674412315, 61.82209028516497, 59.62314523969378, 55.08233070373535, 47.57478822980608, 49.11123991012573, 47.50430917739868, 46.32871566499983, 48.13870750154768, 47.0015548978533, 47.89338397979736, 48.39305673326765, 48.839332580566406, 45.47758913040161, 48.77233804975237, 45.98562056677682, 47.12150165012905, 44.62756388528006, 44.259847845349995, 45.623817443847656, 47.352254799434114, 47.760006359645296, 42.93150166102818, 40.38288852146694, 43.33265938077654, 40.922701018197195, 41.30040161950247, 44.88403926576887, 47.24168116705758, 53.697304589407786, 60.911702564784456, 56.70235879080636, 54.6072233063834, 46.73935420172555, 45.32217877251761, 51.951455048152376, 43.65724795205252, 39.49140337535313, 37.82462780816214, 39.4474629674639, 38.900785650525776, 43.16283845901489, 46.200889655521934, 43.013615471976145, 43.318582330431255, 42.34960739953177, 43.13204056876046, 44.9993064062936, 42.55198757989066, 45.28614888872419, 43.99181066240583, 45.63681404931204, 43.99453435625349, 45.62666620526995, 42.797939913613455, 42.594493184770855, 42.133115427834646, 42.75735895974295, 43.56223828451974, 44.506272656576975, 51.19534512928554, 55.30756350925991, 56.85349948065621, 54.72123977116176, 53.91605125154768, 52.802345343998496, 48.14233446121216, 51.921244280678884, 52.20959799630301, 55.86882509504046, 54.35322495869228, 57.15609005519322, 53.92025491169521, 52.14063365118844, 53.05542305537632, 51.45549610682896, 54.27241046088082, 55.67072153091431, 56.21606131962368, 55.075181007385254, 58.72843265533447, 60.872959409441265, 51.76941224506923, 41.074182169778005, 53.715217045375276, 51.315795625959126, 59.95876407623291, 66.85360050201416, 63.725861958095, 54.6292074067252, 32.7140679359436, 8.151055097579956, 3.167761904852731, 1.065009132027626, 0.39096864791853086, 0.10682042448648385, 0.1551855049495186, 0.08974304156644003, 0.09629627849374499, 0.049358574473964315, 0.03816733695566654, 0.13746770710817405, 0.04110623157716223, 5.011963631425585, 25.91770659174238, 24.752165385654994, 43.68815006528582, 61.862980433872764, 24.74644180706569, 0.6268115426812852, 6.808370871203286, 49.48885713304792, 41.70910160882132, 62.65917451041085, 51.74795968191964, 2.6609859211104254, 0.18185773944216116, 0.018795070571026633, 0.08515736620341029, 0.14327779891235487, 33.51585531234741, 66.12259442465646, 16.356130702154978, 0.24314045746411594, 0.4782012456229755, 33.389151436941965, 63.83444145747593, 39.761250564030235, 58.63816165924072, 57.29556471960885, 55.57334252766201, 62.77554988861084, 39.88168021610805, 54.6697154045105, 45.33119058609009, 7.0723146966525485, 0.2886781096458435, 0.6714967106069837, 0.8641854567187173, 0.933971534882273, 3.0740309229918887, 6.4614573035921365, 0.7540691569447517, 0.221629513161523, 0.1730405025716339, 0.15624582448175975, 0.25028952956199646, 0.10028228496334382, 0.15752680360206536, 0.5857050227267402, 1.1877598081316267, 24.641827992030553, 42.43155445371355, 45.601065567561555, 50.794114453451975, 50.60458844048636, 49.51046255656651, 62.08425276620047, 67.81614140101841, 68.89161137172154, 68.84061159406389, 67.18156937190464, 66.3484525680542, 62.01555592673165, 62.698084422520225, 69.19582435062954, 66.30303219386509, 68.04037366594586, 67.95689800807408, 63.99598707471575, 67.29795169830322, 64.43409184047154, 60.87523147038051, 63.30435643877302, 64.58939102717808, 66.15347221919468, 60.62365109579903, 66.51506342206682, 64.45281028747559, 61.498992102486746, 49.44881813866751, 51.88832718985421, 52.041048594883506, 50.66261979511806, 51.28539725712368, 49.40131677900042, 50.714057309286936, 51.07268163136074, 51.83478437151228, 49.32320165634155, 52.226040908268516, 50.01676736559187, 47.84000791822161, 46.57014124734061, 44.36539445604597, 49.494193349565776, 50.26497786385672, 51.47219262804304, 45.46965428761074, 42.32608427320208, 42.80105965478079, 42.50515324728829, 42.603300026484895, 47.17523206983294, 48.019062995910645, 54.611975874219624, 62.89146668570382, 60.66828632354736, 58.57991491045271, 49.78315850666591, 46.022425174713135, 56.54102856772286, 46.80592141832624, 41.61077765056065, 37.98500265393938, 42.81315994262695, 41.85579892567226, 45.68392630985805, 50.998683316367014, 44.3885041645595, 44.928462573460166, 45.218494279044016, 43.60920810699463, 46.4271890095302, 46.899402482169016, 46.00554800033569, 48.2562814440046, 47.75012602124895, 44.68852390561785, 47.73486082894461, 45.83498362132481, 45.71488053458077, 44.848884854997905, 45.14078215190342, 48.532375063214985, 47.12739372253418, 54.96682037625994, 57.28216859272548, 57.34093298230852, 57.14706087112427, 58.205518177577424, 55.066047600337434, 51.25766004834856, 54.29420348576137, 54.67150109154837, 57.57299586704799, 54.43422358376639, 57.03600433894566, 55.70205790655953, 53.74598714283535, 54.48611273084368, 52.205168519701274, 55.85009969983782, 57.97114501680647, 57.5729124886649, 53.53598826272147, 61.798369135175435, 60.818277086530415, 56.099692889622276, 44.58858796528408, 56.3195721081325, 55.452985831669395, 61.016432762145996, 68.19741685049874, 64.98079000200543, 56.214140142713276, 43.148563385009766, 26.492503268378123, 6.561602124146052, 1.9259583566870009, 0.48512425699404305, 0.21958094808672154, 0.3148909759308611, 0.2327247549380575, 0.2599471727652209, 0.13404897627021584, 0.3630741004432951, 0.3615358886974198, 0.2466644969369684, 7.573126520429339, 36.9005069732666, 26.810987847191946, 49.48008850642613, 73.1869113104684, 34.66434390204293, 1.1601920702627726, 12.905703919274465, 66.24925313677106, 55.29024165017264, 71.36832455226353, 56.64301422664097, 0.8335747335638318, 0.28640881712947575, 0.2226978258362838, 0.23451394321663038], [0.04191202583855816, 0.2011841402522155, 0.3308014821793352, 0.12519527492778643, 0.046705183639590225, 5.896785455090659, 21.64935871532985, 19.006587062563213, 12.299350261688232, 10.751442738941737, 8.56070785863059, 25.38525571141924, 37.5884724344526, 16.08221013205392, 30.274767330714635, 29.769473484584264, 1.5868466390030724, 0.12723199278116226, 0.34755562458719524, 0.28071417127336773, 0.15216826328209468, 0.36080190379704746, 0.17858129739761353, 0.04004101641476154, 0.11345315179122345, 0.02705378830432892, 0.06250362643705946, 0.12465919155095305, 0.0833115406068308, 0.04211722839889782, 0.06892019284090825, 0.29314183869532173, 1.722943393247468, 5.26377329656056, 12.306598101343427, 16.243941613606044, 29.94196946280343, 32.8388853754316, 44.940118176596506, 51.95895562853132, 57.686626706804546, 63.15319837842669, 56.14253200803484, 61.87090832846505, 57.06219904763358, 60.21864059993199, 63.32340839930943, 59.4161445072719, 62.78599303109305, 60.51943506513323, 58.31151989528111, 57.859279019492014, 57.47679110935756, 55.5205431665693, 57.63965688432966, 59.04309572492327, 59.66367408207485, 57.34685632160732, 56.6272418158395, 54.18522793906075, 49.10914502825056, 45.11273922239031, 45.95148059300014, 44.14085994447981, 45.26820169176374, 46.66564423697335, 43.678773471287315, 44.6223909514291, 43.741029330662315, 45.26871585845947, 44.584297452654155, 45.12255007880074, 45.341967242104666, 44.074605396815706, 43.01429639543806, 43.539229324885774, 40.019588061741416, 44.017254965645925, 43.94424329485212, 41.840512888772146, 39.08933891568865, 39.251506396702354, 40.426359925951274, 40.84382854189192, 40.147900445120676, 42.00616489137922, 49.30627931867327, 53.50894587380545, 49.38150399071829, 44.817020416259766, 42.071561336517334, 42.56251062665667, 42.797589029584614, 38.25870261873518, 36.151682240622385, 38.179646015167236, 38.59451600483486, 37.830214159829275, 41.06465966360909, 40.86796658379691, 39.89200871331351, 40.273961612156455, 40.55105924606323, 40.85351085662842, 41.06884595326015, 42.19675397872925, 40.82284498214722, 42.90654025759016, 40.38717903409685, 41.387459073747905, 39.617916175297324, 42.10710832050869, 39.69939770017351, 41.40892205919538, 39.92101396833147, 41.49569811139788, 39.15992913927351, 47.1751070022583, 52.198644161224365, 54.484323569706504, 52.03924901144845, 51.152658871241975, 47.99872561863491, 45.95820297513689, 46.03822537830898, 49.57764121464321, 52.61533457892281, 52.007287297930034, 54.08489942550659, 52.98350919995989, 50.24658945628575, 49.6605749130249, 48.32725034441267, 51.871071338653564, 50.497085911887034, 50.46622896194458, 51.55741228376116, 56.76624400275094, 57.98113652638027, 43.30359854016985, 34.424294063023154, 46.10010256086077, 50.42690910611834, 51.73614774431501, 57.64357219423567, 56.21851750782558, 48.01293815885271, 33.274620805467876, 13.911756174904959, 3.6030055327074866, 0.12902240242276872, 0.20030562739287103, 0.05091085225077612, 0.09235822409391403, 0.05169377648936851, 0.11017098969646863, 0.0553423407088433, 0.08938519576830523, 0.046235379563378434, 0.04991052539220878, 4.523995987006596, 21.007359061922344, 22.493545736585343, 30.100489139556885, 44.92087861469814, 11.686632054192678, 0.14843490932668957, 1.9190490245819092, 30.485551357269287, 36.33321782520839, 53.636778831481934, 58.31887803758894, 23.14510784830366, 0.17355107303176606, 0.026609627762809396, 0.07195764128118753, 0.02839489241263696, 0.0277862600716097, 0.745206675359181, 0.17547625329877647, 0.32226054476840155, 18.485390526907786, 50.72114099775042, 40.49902418681553, 30.970949036734446, 21.67802698271615, 12.3986964736666, 38.968971797398154, 50.730468954358784, 20.51742594582694, 35.4794579233442, 38.550384521484375, 1.7754091322422028, 0.15661832663629735, 0.3209861202963761, 0.3152275021587099, 0.06153499734188829, 0.19105795504791395, 0.05265225130798561, 0.017092054543484534, 0.06376212569219725, 0.024999910300331454, 0.03453940020075866, 0.027179422455706766, 0.05906247680208512, 0.057963691119636805, 0.1598377310271774, 0.4038467811686652, 1.780076910342489, 7.583844985280718, 11.978494610105242, 16.876681055341447, 39.83215693065098, 39.871984004974365, 48.96173204694475, 57.91599369049072, 60.82661492483956, 65.31513037000383, 61.43742411477225, 64.31015682220459, 57.68402113233294, 61.98584542955671, 64.316299029759, 64.21602262769426, 64.53327737535749, 65.52739088875907, 61.92571571895054, 58.39724676949637, 60.635365758623394, 59.860266413007466, 60.01935931614467, 60.667813846043174, 62.298910413469585, 60.714345932006836, 58.359142848423545, 56.76429155894688, 50.727630615234375, 46.668326241629465, 48.973276478903635, 46.83348839623587, 46.87691811152867, 48.401780196598594, 46.14754138674055, 46.85902302605765, 46.71439627238682, 46.97421721049717, 47.782216276441304, 46.1783184323992, 46.49047320229666, 45.73856346947806, 43.34174067633492, 44.91064044407436, 43.2714388029916, 46.23177439825875, 45.13025215693882, 44.19583756583077, 42.48553153446743, 41.02173716681344, 41.27373095921108, 39.785194056374685, 40.6797433580671, 42.847230434417725, 48.05671180997576, 51.78437866483416, 52.000446796417236, 43.86135128566197, 42.20540101187569, 43.1230218069894, 43.063034534454346, 37.71889359610421, 36.99008314950125, 38.1779020173209, 41.3320506640843, 38.90232467651367, 42.27573067801339, 42.245714460100444, 40.69631133760725, 43.19892045429775, 44.12955869947161, 44.719141142708914, 43.11118902478899, 44.04185506275722, 43.109879289354595, 44.44073724746704, 42.59303753716605, 43.99520485741751, 43.17118671962193, 43.354101521628245, 41.61977904183524, 42.15876817703247, 41.99451623644148, 45.29269061769758, 43.04223510197231, 49.25995567866734, 55.41527795791626, 56.1872957774571, 53.8488586970738, 52.91900907244001, 51.46829121453421, 48.702703203473774, 47.615859031677246, 49.93109955106463, 53.445328167506624, 53.96994147981916, 55.34981550489153, 56.31167548043387, 53.36124454225813, 52.29710708345686, 51.069419452122276, 55.31756544113159, 53.412581307547434, 52.373860359191895, 54.29914018086025, 60.710878780909944, 56.450194767543245, 48.010256154196604, 42.07541758673531, 52.70667907169887, 55.515217372349326, 55.88417713982718, 61.61875125340053, 64.34371662139893, 58.73378276824951, 44.99583925519671, 19.068261010306223, 5.111185210091727, 0.23012395735297883, 0.16187594165759428, 0.024679991217064004, 0.07511706996176924, 0.14113809301384858, 0.09602772790406432, 0.014029545260460248, 0.0941642943237509, 0.02611225480878992, 0.06486148134406124, 6.405946842261723, 27.530607564108713, 25.129758289882115, 36.59335838045393, 50.49966369356428, 15.919719559805733, 0.21764781538929256, 2.0700422823429108, 37.524052211216514, 51.38145957674299, 62.122280257088796, 75.22526959010533, 39.13831329345703, 0.48882395561252323, 0.09983578177967242, 0.0580272019973823, 0.12993910323296273, 0.31305936564292225, 1.9992998497826713, 0.291044758366687, 0.2428025198834283, 18.95181962421962, 74.49077551705497, 52.00717960085188, 52.10840443202427, 57.96921689169747, 24.72066399029323, 54.9178911617824, 64.60550389971051, 31.786379201071604, 45.71838937486921, 49.28069952556065, 2.8747003504208157, 0.3967184993837561, 1.119562913264547, 0.9304690999644143, 0.27225544516529354, 2.0213334560394287, 0.7355051445109504, 0.17445683585745947, 0.19426211954227515, 0.06219953418310199, 0.25405539891549517, 0.22131573142749922, 0.16210186667740345, 0.13399805900241646, 0.20851125993898936, 0.41840504854917526, 2.2847262024879456, 19.514033113207134, 30.97703913279942, 31.927764620099747, 50.50957529885428, 47.05585159574236, 54.567177363804404, 57.20308767046247, 66.37354251316616, 68.13944108145577, 63.407974924360005, 67.8109997340611, 59.68297617776053, 64.97181292942592, 66.46639129093715, 66.77800410134452, 66.51465347834996, 67.59462588174003, 63.55804211752755, 61.82900374276297, 62.84319060189383, 63.36482661111014, 63.85258320399693, 65.38195814405168, 64.57236099243164, 62.95264557429722, 60.40539428165981, 59.523181506565635, 54.63934135437012, 50.1320345061166, 52.853720324380056, 51.21689149311611, 51.01515054702759, 51.633255345480784, 49.91600111552647, 49.95157936641148, 49.87921735218593, 51.86231313432966, 52.183500562395366, 50.83188486099243, 50.22038779939924, 49.29467930112566, 45.52398572649275, 48.475736822400776, 44.927580152239116, 50.55348791394915, 47.38272959845406, 45.7014079775129, 42.826778411865234, 41.40993997028896, 43.16482216971261, 39.61252089909145, 40.14673662185669, 44.0028270312718, 52.485920906066895, 57.32729714257376, 53.848209040505544, 47.777147565569194, 43.95407152175903, 45.02231189182827, 45.981288364955354, 39.43139178412301, 36.783294337136404, 38.590628487723215, 42.726116384778706, 42.62988730839321, 47.422820704323904, 44.65218482698713, 42.21974209376744, 44.55906159537179, 45.5821282523019, 47.95203372410366, 45.21208109174456, 47.204702854156494, 44.72217403139387, 47.10465921674456, 43.756756578172954, 45.45187037331717, 44.88811091014317, 47.71610764094761, 42.747718334198, 43.74983617237636, 45.29857921600342, 48.50122281483242, 44.89639663696289, 53.67759255000523, 56.99017749513899, 57.60161549704415, 55.84369346073696, 56.22312068939209, 54.900103773389546, 52.483089515141074, 49.90737840107509, 53.05272020612444, 56.26410811288016, 56.78845044544765, 57.18212495531355, 56.94656365258353, 51.721254280635286, 52.314536639622276, 49.47282069069998, 55.13656139373779, 53.19202811377389, 54.4879401070731, 57.15971006665911, 62.22144494737898, 54.86386544363839, 51.58638974598476, 44.505174841199604, 54.73164469855172, 58.117168358394075, 57.62603841509138, 62.16924313136509, 60.76611695970808, 61.81224468776158, 49.80215835571289, 34.45939636230469, 9.728119867188589, 0.5066164465887206, 0.2959879945431437, 0.15045911499432155, 0.21073528059891292, 0.29303807712027, 0.17033506131597928, 0.11638725256281239, 0.21441490815154143, 0.20285218288855894, 0.22005110500114305, 8.267500826290675, 36.03995868137905, 35.89404303686959, 48.31752634048462, 66.54883166721889, 22.41164905684335, 0.44134976448757307, 3.804454871586391, 57.90326806477138, 64.285858971732, 71.28114550454276, 86.8273993900844, 30.73010015487671, 0.2500417557145868, 0.1192385381353753, 0.2527914510241577], [0.17608107227299893, 0.08621360774018935, 0.13836060490991386, 0.1542410384863615, 5.711865663528442, 29.924164703914098, 30.878002984183176, 13.531106063297816, 12.35708110673087, 8.086583631379263, 7.815900053296771, 24.373295749936783, 27.593375853129796, 25.68424538203648, 44.053486347198486, 24.20328548976353, 0.4727095088788441, 0.06891585021678891, 0.10984283659074988, 0.24191754737070628, 0.14390118260468754, 0.08585319707968406, 0.01722019418541874, 0.02571690807651196, 0.1033105935369219, 0.10073820621307407, 0.07004717165338141, 0.1263437225882496, 0.04433098282398922, 0.021209004700982144, 0.04272595912750278, 0.1614972376929862, 0.7275700303060668, 1.0330849822078432, 3.921484248978751, 5.8587601355143955, 15.573793070656912, 33.48221213476998, 36.005766596112935, 51.990180832999094, 52.09757913861956, 61.85532351902553, 50.92903109959194, 59.07532841818673, 54.586121627262656, 59.33137648446219, 60.13083621433803, 63.591997964041575, 55.88772072110857, 57.30158880778721, 60.069705963134766, 56.37038081032889, 56.13642801557268, 59.245121547154014, 56.415123735155376, 55.64277240208217, 54.702427523476736, 58.31784970419747, 53.5680125100272, 55.03208133152553, 49.48618902478899, 48.97638232367379, 45.343398571014404, 44.555160181862966, 44.132265022822786, 44.99682937349592, 44.41222531454903, 44.45711415154593, 45.28074666431972, 42.15146909441267, 41.155121735164094, 44.18108654022217, 43.56724098750523, 43.348681926727295, 42.05271782193865, 41.146968024117605, 42.875846590314595, 40.00367668696812, 41.41795471736363, 41.09883090427944, 43.735321385519846, 39.40210165296282, 39.42244250433785, 41.479428904397146, 40.77772338049752, 42.577456201825825, 40.61330468314034, 40.40661314555577, 44.268269062042236, 43.01435545512608, 43.73445633479527, 41.50489057813372, 38.633015973227366, 38.36355440957205, 34.893168926239014, 36.614157812935964, 37.29791613987514, 35.38847126279558, 35.76173543930054, 37.368422985076904, 38.86084393092564, 42.67470318930489, 41.108902318137034, 42.88596664156233, 41.672943183353965, 42.20981659208025, 41.48090539659773, 42.08146946770804, 42.00347941262381, 41.413254261016846, 39.68230165754046, 42.211466789245605, 39.31389774594988, 42.42748975753784, 41.02175106321062, 41.24669899259295, 40.57883466993059, 45.789771693093435, 48.738177231379915, 51.28131866455078, 49.514534200940815, 51.51787008558001, 50.8399030821664, 47.39924546650478, 43.70819909232003, 45.99333654131208, 47.18528611319405, 49.44695602144514, 53.21614531108311, 53.457171372004915, 53.71378571646554, 50.176975454602925, 47.55128942217146, 55.48874820981707, 52.598874296460835, 49.73084551947457, 49.49551003319876, 53.04492780140468, 52.452861377171104, 42.88293375287737, 29.800149781363352, 42.119771412440706, 57.63059295926775, 58.23335266113281, 64.44631372179303, 53.81226600919451, 42.02311502184187, 34.70670012065342, 24.836936882564, 3.2618974021502902, 0.035983421108020205, 0.0282279236042606, 0.04709776025265455, 0.07801914388047797, 0.07815911886947495, 0.09547420617725168, 0.1577000878751278, 0.16116251636828693, 0.058972930535674095, 0.11404656459178243, 6.862143414361136, 20.56561517715454, 24.1762535231454, 21.92315595490592, 31.83590943472726, 7.7027304002216885, 0.267379818218095, 0.3387258212481226, 18.374837739127024, 43.75308445521763, 38.85914857046944, 76.35441439492362, 66.40797778538295, 7.5514698539461405, 0.3377942198089191, 0.10100694679255996, 0.20666736816721304, 0.05036117781751922, 0.4469860020492758, 0.3928174929959433, 14.375505004610334, 53.15494557789394, 55.112353869846885, 25.294027600969585, 27.470034905842372, 7.760198950767517, 9.586795244898115, 48.11295052937099, 41.37692560468401, 35.14915098462786, 52.771550927843364, 30.383544853755406, 0.5872063221676009, 0.10367683959858758, 0.3722834491303989, 0.11312749569437333, 0.08122902842504637, 0.05184943242264645, 0.018776594062468836, 0.04878718352743557, 0.016787448299250433, 0.05661023428131427, 0.14512162283062935, 0.11346028997961964, 0.012201605846972337, 0.028931074177048037, 0.0747073773028595, 0.04169524407812527, 0.4789169100778443, 0.4947464263864926, 1.878222712448665, 4.173543180738177, 17.96562532016209, 41.67778260367257, 41.771395683288574, 55.37611443655831, 55.40721804755074, 66.26288550240653, 57.210970401763916, 63.975093841552734, 57.788490772247314, 62.53048692430769, 63.76143673488072, 64.58134501320976, 61.55735002245222, 60.52477822984968, 61.0224221093314, 59.67437430790493, 58.15290641784668, 61.21819455283028, 60.97058159964425, 59.48943410600935, 58.400220598493306, 59.52678762163435, 55.036232880183626, 56.66517898014614, 51.800738198416575, 53.44778782980782, 49.496663434164866, 47.83897263663155, 46.20341532570975, 45.70129680633545, 47.3721718106951, 46.990205015454976, 49.07038450241089, 47.6065171786717, 45.15346956253052, 45.256146567208425, 46.999421800885884, 44.818983282361714, 44.154071944100515, 44.733325890132356, 43.976590633392334, 43.25577408926827, 43.36905057089669, 43.78762395041329, 44.35237005778721, 40.764257771628245, 41.3971518107823, 42.18074880327497, 41.71843998772757, 43.63426678521292, 40.924469334738596, 40.17729132516043, 44.253973143441335, 45.58126320157732, 45.710520539964946, 41.97777107783726, 40.194366523197715, 38.50291095461164, 35.081027371542795, 37.11839205878121, 38.17736005783081, 37.06669398716518, 37.14344726290022, 38.420230865478516, 38.59992517743792, 44.05102668489729, 42.07464286259243, 43.947960581098286, 44.8003933770316, 44.52383075441633, 42.472871916634695, 44.712248529706685, 45.381061281476704, 45.284762723105295, 42.511479582105366, 45.199310302734375, 42.25751597540719, 43.60889891215733, 43.29539966583252, 43.82539783205305, 42.17172656740461, 48.38370098386492, 50.03031635284424, 52.15377269472395, 51.71691860471453, 54.40611812046596, 53.07000732421875, 49.72094086238316, 45.24589797428676, 49.134019579206196, 47.13580799102783, 50.63797106061663, 57.30722379684448, 54.13595131465367, 56.003814697265625, 51.6213287625994, 48.20667130606515, 57.68332283837454, 54.257958207811626, 53.26704433986119, 51.95948716572353, 55.500553199223106, 54.7905341557094, 48.19731903076172, 38.59849384852818, 49.958298274448936, 62.269943373543875, 61.76798466273716, 68.89435591016496, 59.317216055733816, 49.25859383174351, 42.67988307135445, 36.697362491062705, 3.4718519874981473, 0.0566457148774394, 0.03191182762384415, 0.06764587014913559, 0.10606596818459885, 0.013187092296513063, 0.04376679113400834, 0.07730168130780969, 0.05216339396845017, 0.1310767214745283, 0.223431512181248, 9.682882751737322, 27.26609832899911, 32.23743193490164, 30.55054133278983, 38.197655745915, 10.237382003239222, 0.09621315116861037, 0.41847944312861984, 21.92486868585859, 55.67524133409773, 48.14915411812918, 75.97099890027727, 78.05198437826974, 16.923603977475846, 0.2738815136253834, 0.19461053370365075, 0.43056393467954224, 0.14662981618727955, 0.8286484064800399, 0.4324339771909373, 10.398439509528023, 69.10770729609898, 72.69452721732003, 39.481974669865195, 63.25697667258126, 23.468454429081508, 11.389751161847796, 71.28846195765904, 50.31926761354719, 51.70107671192714, 62.65502643585205, 37.4377555847168, 0.9898011790854591, 0.5187724828720093, 0.7394723487751824, 0.5972822957805225, 0.33126869425177574, 0.34358728038413183, 0.26222729470048634, 0.14741083713514463, 0.1562683789857796, 0.17938143946230412, 0.18270299051489147, 0.3407352619937488, 0.09306348660694701, 0.14932617864438466, 0.13980926360402787, 0.22234850243798324, 0.7663367443851062, 1.0413052439689636, 5.949497095176151, 16.266236645834788, 34.89289447239467, 53.46478312356131, 50.296943051474436, 59.228737694876536, 58.05377994264875, 67.48396887098039, 57.57379143578665, 64.0224666595459, 58.47816549028669, 63.81727940695626, 64.78139754704067, 64.77350439344133, 62.08567714691162, 62.723966462271555, 63.04866273062569, 61.923832757132395, 59.58392265864781, 63.185695103236604, 63.19007246834891, 61.690414973667686, 60.78804547446114, 64.64938177381242, 56.71783242906843, 61.61798695155552, 54.94738279070173, 54.56032991409302, 50.59958226340157, 50.50300577708653, 49.07665525163923, 50.465211050851, 48.687781946999685, 49.71157121658325, 52.08157743726458, 49.7690988268171, 47.351150035858154, 49.34508500780378, 49.456204073769705, 48.79055275235857, 45.651676246098106, 48.996177741459434, 46.74461398805891, 45.185358319963726, 47.06132330213274, 45.64505461284092, 45.75559350422451, 40.21685784203665, 40.80912923812866, 42.89202894483294, 41.9509197643825, 43.665742124829976, 40.5839798109872, 41.72763245446341, 46.852724484034944, 46.120835985456196, 44.75303792953491, 42.550521509987966, 39.86485515322004, 40.31586272375924, 36.07302515847342, 37.54433747700283, 40.417320319584434, 38.93078449794224, 38.62521314620972, 40.25070946557181, 41.05937555858067, 46.22715732029506, 44.23927770342146, 45.80466168267386, 45.43219307490757, 45.23758792877197, 43.71446289334978, 47.42030198233468, 46.56548248018537, 47.10213702065604, 45.088139125279014, 48.36778613499233, 42.862863881247385, 45.43806777681623, 47.75107792445591, 47.294417994362966, 44.54333087376186, 49.95577260426113, 54.54442548751831, 54.61077036176409, 53.577663557870046, 59.01519175938198, 55.61156456811087, 51.988627910614014, 48.244452135903494, 49.961352007729666, 48.90496179035732, 52.362274238041465, 56.88655553545271, 55.805617332458496, 58.233783449445454, 54.210922377450125, 49.001427105494905, 56.81137602669852, 56.47634431294033, 52.47165625435965, 49.81978246143886, 57.51089286804199, 56.017895221710205, 50.25859246935163, 43.5173841885158, 51.11162281036377, 63.48869909558977, 64.11148003169468, 68.56559494563511, 60.223921230861116, 57.156003202710835, 50.60055501120431, 54.88821540560041, 4.791117310523987, 0.12774736726922648, 0.1356493825359004, 0.2439370575760092, 0.26961521112493103, 0.1388847596411194, 0.197040231898427, 0.181867958179542, 0.1891644216541733, 0.16021583788096905, 0.333922417568309, 14.285201004573278, 34.79171480451311, 43.97709437779018, 42.56784336907523, 58.40126282828194, 16.10074966294425, 0.3558294363319874, 0.3214334105806691, 40.150127342769075, 73.54497282845634, 55.268601485661094, 90.34872559138707, 85.79301411764962, 11.756827967507498, 0.4763616014804159, 0.3839582683784621], [0.04256778243663056, 0.23118551181895391, 0.09264129533299378, 1.716050237417221, 36.46865906034197, 41.5009891646249, 22.80657250540597, 21.04781494821821, 26.621691124779836, 2.3070522844791412, 5.153379014560154, 19.413501364844187, 20.97804982321603, 25.47155581201826, 43.94034882954189, 21.323809555598668, 0.14220260589250497, 0.059778460168412755, 0.17948163194315775, 0.1683714488255126, 0.035390276328793595, 0.07366372937602655, 0.05065694105412279, 0.0736771100865943, 0.09406557426388774, 0.05173895335091012, 0.08102110493928194, 0.09952805257801499, 0.02957600474889789, 0.053123738151043653, 0.05748770558940513, 0.12900139497859137, 0.052385220636746714, 0.09571153058537415, 0.13543328270316124, 0.30014616570302416, 2.6403721358094896, 9.44468547616686, 21.641832079206193, 44.62003551210676, 46.34344932011196, 57.946659564971924, 55.53112874712263, 58.444682121276855, 57.282717500414165, 57.35141086578369, 64.5270448412214, 60.584789821079795, 59.03082520621163, 59.00351183755057, 57.81704439435686, 60.50328050340925, 57.633017880576, 57.24662160873413, 58.739806856427876, 56.944607734680176, 55.5084741456168, 59.00606182643345, 52.18528972353254, 49.60112959997994, 51.06319734028408, 54.42478445598057, 48.389613900865825, 46.30038438524519, 44.4486095564706, 44.64783525466919, 44.62019879477364, 45.38781145640782, 45.85941001347133, 44.58654866899763, 44.230554240090505, 42.64227942058018, 42.732564313071116, 42.82681662695748, 40.876224517822266, 41.39712749208723, 39.81058277402605, 40.89501939501081, 41.69157477787563, 42.64958545139858, 41.37850979396275, 42.44190379551479, 39.28060892650059, 42.880654743739534, 43.971403803144185, 46.36139651707241, 44.74682623999459, 41.68234757014683, 36.7937513760158, 40.83529962812151, 43.13156809125628, 41.17643533434187, 38.55643292835781, 36.44971479688372, 33.419619287763325, 38.05967494419643, 36.02319267817906, 35.03945977347237, 38.5945576940264, 35.6861355645316, 36.97182675770351, 39.891859327043804, 39.495881489345, 39.864076954977854, 42.50683123724801, 42.204435212271555, 42.99386869158064, 42.914381299700054, 42.817207268306184, 42.65064852578299, 43.05478007452828, 42.53684745516096, 42.01673310143607, 42.5163711139134, 39.26273468562535, 40.563666752406526, 43.105078084128245, 42.9291045325143, 46.157793453761506, 47.9048832484654, 47.806336947849815, 50.617192472730366, 49.64862748554775, 48.13739081791469, 48.2842583656311, 49.12395511354719, 42.85917438779558, 48.8035945211138, 51.00728171212332, 44.42301934106009, 51.19865942001343, 49.952124800000874, 46.890293393816265, 52.815345423562185, 48.78340653010777, 52.57575763974871, 48.08306285313198, 42.789056641714915, 48.89274685723441, 37.50358976636614, 43.20739030838013, 39.41607448032924, 50.82049676350185, 50.16603899002075, 52.76332426071167, 44.98002862930298, 51.24383660725185, 80.6775905064174, 23.470193215778895, 0.4260799310037068, 0.1097461860626936, 0.10692247615328856, 0.07859224134257861, 0.10264849942177534, 0.0745474873110652, 0.11057450768670865, 0.23678228578397206, 0.07731823077691452, 0.3603510579892567, 0.2422657444008759, 5.085728747504098, 25.722536904471262, 23.358579090663365, 24.135029860905238, 25.317126887185232, 7.090043459619794, 0.14980989268847875, 0.12938531009214266, 4.951220308031354, 52.65894842147827, 41.78624745777675, 48.11437838418143, 81.12934153420585, 40.40921177182879, 0.19034166634082794, 0.08190400113484689, 0.09432734628873211, 0.43514689590249744, 0.04126796718420727, 4.6510485751288275, 53.69510548455374, 58.87741592952183, 40.850790636880056, 33.58725847516741, 41.52225412641253, 2.141301921435765, 7.077948382922581, 38.60082496915545, 28.56610107421875, 37.82949849537441, 54.880926745278494, 24.737212862287247, 0.14232586856399262, 0.1124363127829773, 0.09767038654536009, 0.16230322872953756, 0.01679304621315428, 0.06676285860261746, 0.037760673955615075, 0.09121118778628962, 0.04437072462003146, 0.023575276834890246, 0.04275899699756077, 0.10460489229964358, 0.05301780865660735, 0.07945055421441793, 0.09735019265541009, 0.05819261526422841, 0.03230736943493996, 0.0548369474709034, 0.02674919054178255, 0.2713163526994841, 0.6567444907767432, 8.196353878293719, 25.568260840007238, 48.09652846200125, 50.989334515162874, 60.16248525891985, 61.271577562604634, 62.35659435817173, 59.793987546648296, 60.30124078478132, 67.71901948111397, 62.81473772866385, 60.07932921818325, 60.366783142089844, 60.434382166181294, 63.67725930895124, 59.87647656032017, 60.83119378771101, 61.386424337114605, 60.7358158656529, 57.115724495479036, 60.51391819545201, 56.040577616010395, 52.4668550491333, 55.96454347882952, 56.74845314025879, 51.77976506096976, 49.76162256513323, 47.81460183007376, 47.6573988369533, 46.81673281533377, 47.09119013377598, 47.716864994594026, 46.18772281919207, 46.4814579146249, 47.600920404706685, 44.85330738340105, 44.87599325180054, 42.31047861916678, 42.54567166737148, 40.508056844983784, 41.70078461510794, 45.24198613848005, 45.058710030147004, 46.46010610035488, 44.844444956098286, 40.54815489905221, 42.6845383644104, 45.91967173985073, 48.063646112169536, 45.38666500364031, 43.855629444122314, 37.40805203574044, 40.910757064819336, 41.24575751168387, 41.5816890171596, 37.9793051310948, 36.82776280811855, 35.042558670043945, 39.14030047825405, 38.58344405038016, 37.35457522528512, 40.330585956573486, 36.664563519614084, 37.75542722429548, 41.08116858346121, 40.2525611604963, 41.85482965196882, 43.61036845615932, 47.448212896074565, 44.35582331248692, 46.891332149505615, 44.60738284247262, 45.608441080365864, 46.85655641555786, 46.04069198880877, 44.69228982925415, 43.54162645339966, 43.114631857190815, 45.35356378555298, 46.178485189165386, 47.667907987322124, 48.13657440458025, 49.90263278143746, 49.23055785042899, 50.93418318884713, 52.342124462127686, 51.05143404006958, 50.736788340977256, 52.260163511548726, 43.46098566055298, 49.32265969685146, 50.89228555134365, 45.74224601473127, 53.33705786296299, 53.376085894448416, 46.24163041796003, 53.61722660064697, 51.379677363804404, 56.58025114876883, 50.9196822983878, 45.85489368438721, 51.36848381587437, 38.3518362726484, 50.792544160570415, 43.55309445517403, 54.27490486417498, 52.540391308920725, 56.64924676077706, 54.38782351357596, 60.757716587611604, 87.22094535827637, 21.137790645871842, 0.6362499647906849, 0.07066519491906677, 0.14648998369063648, 0.06557135110987083, 0.039552620479038784, 0.054565625065671544, 0.10790494057748999, 0.15958695805498532, 0.05375006329268217, 0.29436982423067093, 0.4515490143426827, 8.640535712242126, 33.74225888933454, 29.103304522378103, 32.85200010027204, 37.721995966775076, 9.314198306628636, 0.05011429963633418, 0.1326645477009671, 3.175743213721684, 66.22134917122978, 50.31150300162179, 59.651973315647666, 82.65170574188232, 58.5235789162772, 0.7212464096290725, 0.1680103867713894, 0.12466486410370894, 0.3136466512722628, 0.24324261769652367, 2.575862237385341, 60.96436991010393, 78.53394617353166, 54.76760857445853, 51.0730151448931, 71.80397660391671, 1.3615369690316064, 26.32734111377171, 59.502045086451936, 43.76246452331543, 47.27022436686924, 57.95330899102347, 36.057252747671946, 0.4448225609958172, 0.40513132938316887, 0.5953239351511002, 0.6920246747987611, 0.15908896763409885, 0.2706954117332186, 0.12387492720569883, 0.25100372838122503, 0.13994985605989183, 0.21657513294901165, 0.07976196107587644, 0.15546882046120508, 0.14117847941815853, 0.23267828885998043, 0.2914866203708308, 0.22187472214656218, 0.2296709402331284, 0.24548756437642233, 0.17479630692728929, 0.41356201842427254, 5.479058887277331, 26.666540009634836, 41.39942387172154, 54.26598685128348, 54.82823160716465, 64.45800059182304, 66.37252112797329, 66.37881619589669, 60.508172035217285, 58.47366305759975, 68.49738448006767, 64.44063009534563, 61.36330073220389, 62.78855691637312, 63.35482120513916, 66.02470820290702, 64.54681246621269, 64.17168617248535, 62.737376485552105, 63.46135793413435, 61.0779938016619, 64.19068949563163, 57.423856258392334, 54.78680297306606, 57.69211230959211, 60.60713522774832, 54.26500020708357, 51.54691008159092, 49.769387177058626, 50.23206772123064, 50.76306642804827, 49.76381472178868, 49.920680727277485, 50.09595251083374, 50.252693448747905, 48.88369682856968, 48.29500028065273, 47.568666866847444, 45.42459174564907, 47.38073546545846, 43.61434282575335, 44.33180686405727, 46.85586854389736, 49.1705983706883, 45.58215257099697, 44.30649110249111, 39.23293038776943, 43.2818854195731, 43.47917257036482, 46.34382799693516, 45.67864220482962, 42.88662324632917, 36.48786735534668, 42.03311347961426, 41.65942546299526, 41.91477523531233, 38.19305256434849, 36.30229139328003, 35.379838126046316, 39.332654408046174, 40.666903087071006, 39.11182676042829, 42.00269079208374, 38.238410404750276, 39.44164732524327, 42.65685674122402, 42.54048483712332, 43.95459263665335, 46.347510542188374, 45.55178199495588, 45.74431310381208, 48.16345351082938, 45.909079211098806, 47.69778871536255, 47.507071086338584, 47.43484456198556, 45.4700642313276, 46.64494555337088, 46.01995856421334, 46.68135758808681, 49.60380465643746, 49.21646690368652, 52.45700945172991, 52.94087505340576, 52.88606071472168, 54.597954409463064, 55.01533269882202, 52.82464558737618, 52.72043997900826, 52.30861677442278, 46.44413913999285, 51.438907282693044, 52.04342140470232, 46.61350495474679, 54.071576254708425, 52.6349458694458, 46.71674476351057, 54.38830988747733, 53.13318034580776, 56.997011048453196, 52.44214378084455, 44.39600474493844, 50.30653851372855, 45.095848151615684, 54.04368271146502, 52.346668584006174, 58.2907725742885, 53.72061579568045, 55.31474099840437, 54.641154834202354, 62.47430379050118, 90.21830790383476, 22.188446862357004, 0.6777472123503685, 0.3990339865641934, 0.2757840172520706, 0.27434207605464117, 0.19131596120340483, 0.21507605910301208, 0.2025983157966818, 0.44877166194575174, 0.2128785148795162, 0.43425692937203814, 0.5638647175260952, 13.728169134684972, 44.100261620112825, 37.67111430849348, 47.13711772646223, 48.13340255192348, 11.58968905040196, 0.19607231526502542, 0.2933687950883593, 7.580365674836295, 89.35464681897844, 57.86429909297398, 69.35782854897636, 93.59261717115129, 58.943979672023225, 0.4011041969060898, 0.25390180572867393], [0.03413764300889202, 0.3702178256852286, 0.13575003642056668, 22.25296609742301, 61.763357162475586, 38.81159162521362, 27.281961066382273, 48.99857834407261, 21.993270226887294, 1.1519194798810142, 6.132941697325025, 20.06109779221671, 39.59060975483486, 26.55563633782523, 29.146480628422328, 20.387677022389003, 0.2634932781968798, 0.13285776733287744, 0.19521266567919934, 0.06649342591741256, 0.09811218069600207, 0.06746273354760238, 0.055137538484164646, 0.025278971397450993, 0.06338469058807407, 0.031513184907713106, 0.07675997966102191, 0.06786030757107905, 0.0651550834466304, 0.11854217121643679, 0.05369484411286456, 0.09413393666701657, 0.16561371966132096, 0.07582656653331858, 0.07784792913922242, 0.041586003332797966, 0.0619712071493268, 0.39058641557182583, 6.684585239206042, 26.60474099431719, 43.681948798043386, 52.90298305238996, 51.06649078641619, 56.00853599820818, 54.32537310464041, 54.69610813685826, 63.35596765790667, 57.21409361703055, 55.354637554713655, 58.90275600978306, 59.02414798736572, 56.76577499934605, 57.36253840582711, 55.27056435176304, 56.46246181215559, 54.39968408857073, 58.28627014160156, 52.66017130443028, 55.61599404471261, 53.637327739170615, 55.44978271211897, 54.68122509547642, 47.07467426572527, 46.76316915239607, 47.557931900024414, 44.485726833343506, 45.465002468654085, 47.25378840310233, 43.91286870411464, 43.78218003681728, 44.419774532318115, 43.236715180533274, 41.48698854446411, 42.975205830165315, 41.46698120662144, 39.96538863863264, 38.625320843287874, 38.46534899302891, 41.86822577885219, 38.63368647439139, 45.16126891544887, 46.67395428248814, 41.04000398090908, 40.28002044132778, 43.92510100773403, 46.14843075616019, 44.035289015088765, 44.11551639011928, 40.91659007753645, 37.57136596952166, 37.615980352674214, 38.446863310677664, 38.05336945397513, 35.7196432522365, 36.07564810344151, 39.81168058940342, 35.30587107794625, 35.38129724775042, 35.791240964617046, 34.764206886291504, 36.86695064817156, 37.30327320098877, 37.241065979003906, 40.08891371318272, 41.5456417628697, 45.75521830150059, 43.0690655708313, 41.87844657897949, 42.976765700748985, 41.575692721775596, 43.076454980032786, 42.97353131430489, 42.53037173407418, 42.70025518962315, 42.61717905317034, 41.82574796676636, 44.12746034349714, 46.61367865971157, 45.536992754255024, 46.56748008728027, 48.73417854309082, 48.23219551358904, 46.816830090114046, 46.724929741450715, 50.48444366455078, 50.72977760859898, 38.07094839641026, 42.98341165270124, 45.96858358383179, 43.65233557564871, 47.02267394747053, 52.42455094201224, 41.70812538691929, 50.14099768229893, 48.54630272729056, 52.30113009044102, 46.8511437688555, 47.04477269308907, 35.589347158159526, 12.939025742667061, 41.548716340746196, 44.450721808842246, 49.08868258340018, 57.48470163345337, 55.66479819161551, 57.98536450522286, 63.63679300035749, 23.843191623687744, 0.4838514881474631, 0.06115830862628562, 0.19072263661239827, 0.028948828045810972, 0.3898486580167498, 0.18428145295807294, 0.12125822475978307, 0.22776857231344494, 0.21438126638531685, 0.03551921494571226, 0.11290228313633374, 0.24609631885375294, 5.619166706289564, 26.580194745744976, 17.759583439145768, 24.3200204372406, 36.94672291619437, 7.52531509740012, 0.14685774967074394, 0.06433065661362239, 0.07732742492641721, 38.48699263163975, 67.11170523507255, 46.51763023648943, 69.07929611206055, 71.62323311397007, 7.27725659097944, 0.26619905872004374, 0.1056482552417687, 0.27598858198949267, 0.14394612876432283, 33.616315841674805, 80.27603326525006, 54.82787724903652, 40.58193356650216, 62.01027529580252, 19.27812613759722, 0.6654713196413857, 26.900345155170985, 37.16753666741507, 55.63736322947911, 35.6279548236302, 38.055825642177034, 23.857249566486903, 0.15186332964471408, 0.19398340449801513, 0.07806838516678129, 0.03962303205792393, 0.13604865968227386, 0.04617928846606186, 0.0693728503371988, 0.023290600860491395, 0.04151355614885688, 0.026082188922113607, 0.07669397855975799, 0.04156069058392729, 0.04437670251354575, 0.14865676313638687, 0.04471932877121227, 0.08145316211240632, 0.10357500506298882, 0.07867667145494904, 0.0864157976050462, 0.03141547925770283, 0.08002691542995827, 0.5138590750949723, 7.259178681032998, 28.45088083403451, 48.93942485536848, 57.590362889426096, 55.81006417955671, 61.34900828770229, 57.657934120723176, 55.7042361668178, 63.43931824820382, 59.47742761884417, 57.20308767046247, 59.629565375191824, 61.559239932468955, 58.423698561532156, 59.4807071685791, 58.2468912260873, 59.17592443738665, 57.54431370326451, 60.61652224404471, 55.21830347606114, 54.872071266174316, 55.78853518622262, 57.62467656816755, 59.3664996283395, 50.73350879124233, 48.99551766259329, 50.657863753182546, 47.326240743909565, 46.7778993334089, 49.705057280404226, 48.38016087668282, 46.156858921051025, 47.5916098185948, 44.38047204698835, 44.99472059522356, 45.437605721609934, 44.51336676733834, 42.90655762808663, 40.43678569793701, 41.45018393652779, 43.54276595796858, 42.35866437639509, 45.89004462105887, 47.62535374505179, 41.432743958064485, 39.720648765563965, 43.47415597098214, 45.70785937990461, 43.70807402474539, 43.818977696555, 41.01181166512625, 38.37135376249041, 38.83531972340175, 38.48528684888567, 38.300940717969624, 37.19320331301008, 37.34369434629168, 42.71102837153843, 37.62525272369385, 35.808330059051514, 36.47817809241158, 36.89315230505807, 39.12206493105207, 38.51474026271275, 37.593555041721885, 40.95855719702584, 43.064677783421104, 47.09248597281319, 45.685180459703716, 44.51840421131679, 44.73547635759626, 44.744557653154644, 46.278608730861116, 45.22885056904384, 44.327120304107666, 43.47810254778181, 44.642033508845735, 45.08882352284023, 47.161432947431294, 50.01739270346505, 48.74391991751534, 50.298572404044016, 52.41316631862095, 49.97988632747105, 48.38403449739729, 48.60786029270717, 53.0594391141619, 52.428080626896445, 40.64937973022461, 44.86714472089495, 49.07843746457781, 44.07998330252511, 48.53224304744175, 50.91220603670393, 43.305092402866904, 57.70728022711617, 53.45690386635916, 57.19145291192191, 51.18355056217739, 49.8066851070949, 26.14330244064331, 8.1701591696058, 44.76801477159773, 50.91494710104806, 55.228281089237754, 61.910325459071565, 60.41571930476597, 64.33731038229806, 58.22304153442383, 19.069278921399796, 0.21504397796733038, 0.001130460121203214, 0.05056642787531018, 0.03093295943524156, 0.08699315626706396, 0.1364817821553775, 0.10473684700472013, 0.10748570093086787, 0.21794413163193635, 0.04097977979108691, 0.17491159002695764, 0.314004836337907, 8.457614830562047, 33.84436961582729, 19.69949790409633, 40.71102067402431, 46.27860525676182, 9.372002107756478, 0.05085719030882631, 0.4335511986698423, 0.09303557846163, 35.90082100459507, 72.74699306488037, 54.78074066979544, 71.35487283979143, 86.7263378415789, 10.664195077759878, 0.2932214172823088, 0.2592191861144134, 0.44200050671185764, 0.26041243065680775, 28.325745514460973, 101.69445296696254, 62.616672379629954, 53.38139084407261, 90.97684274400983, 38.11244651249477, 1.7153036317655017, 54.95908008302961, 49.92954315458025, 73.181991985866, 41.58104630878994, 46.191742352076936, 32.22246898923601, 0.3713928854891232, 0.4462319867951529, 0.39545851413692745, 0.16776136441954545, 0.19816444228802407, 0.16177174582013062, 0.11966478026338986, 0.1604581834482295, 0.11122783512941428, 0.13430768810212612, 0.2480462927903448, 0.1800948783223118, 0.10435990723116056, 0.3704514317214489, 0.13790749279516085, 0.20072490775159427, 0.24583220588309423, 0.12418428489140101, 0.12554286127643927, 0.23907972393291338, 0.11801218108407088, 1.7316652280943734, 20.04802301951817, 42.21092135565621, 49.985979897635325, 62.27135385785784, 57.48358992167881, 62.51114313943045, 56.76367664337158, 57.80342245101929, 64.09216403961182, 59.9541574205671, 57.61540767124721, 62.774799483163015, 61.1096567426409, 59.842180252075195, 61.20297104971749, 61.11846705845424, 60.5088529586792, 58.3189058303833, 63.96529688153948, 58.828917503356934, 60.369819504874094, 59.08685547964913, 61.09694153921944, 60.88721016475132, 52.211557388305664, 51.61959866115025, 53.5970664024353, 49.35792875289917, 50.79880796160017, 53.016888345990864, 49.717240946633474, 48.91115263530186, 50.35751397269112, 48.39865003313337, 46.67904036385672, 49.21796771458217, 46.59206281389509, 44.71261331013271, 42.33695820399693, 43.618810517447336, 46.95102412360055, 43.264233521052766, 48.9696877343314, 48.62975059236799, 41.980887344905305, 40.36158881868635, 43.824682167598176, 46.55948618480137, 44.94668075016567, 46.21379940850394, 41.29985966001238, 37.70248889923096, 38.570760113852366, 40.17305639811924, 38.64258016858782, 36.81761496407645, 37.478993143354145, 44.37497254780361, 38.86021164485386, 38.662205355507986, 37.3499789919172, 38.77841050284249, 40.144589628492085, 41.49962036950247, 39.06619446618216, 43.064149720328196, 45.11084931237357, 50.11512606484549, 46.667280537741526, 47.35581227711269, 48.06893021719796, 46.1445814541408, 48.499589988163535, 48.3689603805542, 46.027476515088765, 48.85066509246826, 47.39296429497855, 47.77355882099697, 50.679274627140586, 53.24338919775826, 51.843570368630544, 53.82984495162964, 52.414823463984895, 52.09659249441964, 52.19425984791347, 50.57560403006417, 57.124496596200125, 55.50965533937727, 39.513884271894185, 43.94491727011544, 48.66951860700335, 43.506166321890696, 50.826791831425254, 56.08048112051827, 45.52608755656651, 58.183780738285606, 54.45231669289725, 55.93878650665283, 46.906656401497976, 45.554453577314106, 36.50902114595686, 20.114772626331874, 51.754081044878276, 54.87014314106533, 59.070061683654785, 64.85504845210484, 63.46495015280587, 65.01552404676164, 67.56246961866105, 18.070982592446462, 0.3717415439231055, 0.13322356556143078, 0.28976647981575554, 0.177371564454266, 0.4961041478174073, 0.3346376749021666, 0.27471725163715227, 0.2634195621524538, 0.3524569272994995, 0.1446505431085825, 0.37837199813553263, 0.6629416325262615, 12.70581727368491, 44.35991580145699, 26.672366074153356, 49.69466972351074, 59.630225454057964, 14.718704325812203, 0.3674801268747875, 0.4344336741736957, 0.30584594128387316, 56.09074360983712, 83.72197846003941, 64.35479899815151, 82.33388819013322, 93.57191848754883, 8.507584537778582, 0.315567746758461], [0.1635984435145344, 0.11800148737217699, 1.1854265161922999, 57.012429101126536, 65.06683649335588, 36.76126159940447, 46.63631936482021, 46.239636284964426, 1.4935104016746794, 3.077836364507675, 21.300206524985178, 25.27358600071498, 88.24743052891323, 55.24247278485979, 34.49475227083479, 18.301211152757915, 0.2045412329690797, 0.18305804074874946, 0.09574711296175208, 0.05214933133018868, 0.03675906805853758, 0.03368912796889033, 0.03360142731773002, 0.02392016600684396, 0.08367665351501533, 0.12274766340851784, 0.07680416586143629, 0.03311766577618463, 0.044724950433841774, 0.04964781020368848, 0.05239628415022578, 0.02532208720887346, 0.047000244592449496, 0.038202189906899414, 0.12298010236450604, 0.03942291172487395, 0.08003922405519656, 0.17424016605530465, 0.29074153463755337, 8.750172206333705, 34.78198037828718, 42.70897170475551, 50.57974168232509, 53.68916130065918, 56.53088419778006, 49.31417942047119, 59.49980776650565, 54.70730168478829, 53.00277655465262, 55.46518686839512, 58.73854228428432, 53.8310296194894, 59.47334902627127, 54.95849296024868, 56.626046725681846, 56.583669662475586, 56.83242212023054, 51.19790554046631, 53.20409018652779, 54.84307643345424, 53.70030968529837, 52.0717978477478, 48.943124771118164, 47.26839004244123, 46.91912146977016, 45.03902925763811, 45.59908185686384, 45.65340634754726, 43.90715033667428, 43.83013997759138, 43.17492485046387, 43.16189002990723, 42.85812520980835, 42.3681104523795, 41.90002768380301, 41.17628942217146, 39.79567193984985, 39.78688941683088, 39.296398707798545, 38.765827315194265, 44.44729634693691, 48.25498560496739, 42.603223596300396, 39.32009553909302, 42.19380446842739, 42.06907388142177, 43.34868540082659, 40.62465109143938, 38.651307106018066, 36.51481246948242, 38.3111754144941, 36.86333758490426, 37.49878856113979, 37.55483620507376, 40.66015986033848, 41.63762548991612, 36.55879456656319, 34.56164952686855, 35.83859988621303, 37.23474311828613, 38.73540810176304, 37.30226223809378, 36.26651511873518, 37.58924715859549, 41.77516508102417, 42.628726959228516, 41.809624671936035, 39.17164380209786, 42.34366321563721, 41.929693017687114, 42.471586499895366, 42.254469190325054, 42.30246039799282, 41.010303906032014, 41.92012187412807, 42.379317896706716, 42.501640932900564, 45.446756499154226, 46.74688604899815, 43.60091890607561, 47.951481342315674, 46.12832614353725, 45.86175850459507, 44.29707976749965, 52.541506494794575, 49.07225704193115, 43.25871665137154, 45.047151701790945, 47.163037981305806, 36.98784235545567, 41.9551477432251, 42.225710596357075, 39.52050590515137, 47.31559262956892, 46.66695397240775, 51.82001250130789, 51.17428861345564, 29.380558490753174, 3.4990637387548174, 0.34443544915744234, 15.112967695508685, 42.373179163251606, 28.342407294682094, 20.6120308807918, 22.79339177267892, 22.189409187861852, 3.4791560641356876, 0.3230576877083097, 0.19690319496606076, 0.03267695049622229, 0.07090319786220789, 0.12999995425343513, 0.05683670212913837, 0.2200590574315616, 0.15788654929825238, 0.05939618032425642, 0.06611778893108879, 0.16002356819808483, 0.11498298362961837, 0.27872883209160393, 5.770340400082724, 25.18707745415824, 37.29708930424282, 46.444708892277305, 38.32176794324602, 5.414371592657907, 0.05554321760843907, 0.4552420090351786, 0.4648033274071557, 9.86254232270377, 64.3303621837071, 71.00682367597307, 54.26017468316214, 92.53094632284981, 19.500383377075195, 0.1789450328797102, 0.14247245926942143, 0.12443534284830093, 2.636118535484586, 75.36845806666783, 73.80657250540597, 49.33107049124581, 57.629359654017854, 52.401892866407124, 0.35270912519523073, 5.4307154927934915, 42.33741331100464, 42.05692843028477, 110.18222645350865, 65.22500528608049, 39.53798062460763, 23.179343359810964, 0.16052524984947272, 0.1066171693216477, 0.10825771771903549, 0.06331102204109941, 0.01831568218767643, 0.04231400355430586, 0.0405962853692472, 0.06043334145631109, 0.073388596996665, 0.0209518619813025, 0.07638767428163971, 0.017864412295499017, 0.09461611043661833, 0.009533531514794698, 0.10683120640793017, 0.03843359748965927, 0.07017237493502242, 0.04441667840416942, 0.06546085846743413, 0.020969349525070617, 0.0651885759351509, 0.016320765484124422, 0.5156356426221984, 7.170661236558642, 32.22307695661272, 46.17000491278512, 53.425376415252686, 55.93333217075893, 56.04811988558088, 50.34845004762922, 62.33316503252302, 57.39600787843977, 54.23888887677874, 55.975945472717285, 60.67162840706961, 56.650299412863596, 58.41449219839913, 57.31227861131941, 58.59725066593715, 58.84434945242745, 58.608715193612234, 54.10746022633144, 56.459112780434744, 57.27820117133004, 56.549967425210134, 53.73776394980294, 50.889693873269216, 49.3515294619969, 48.21497440338135, 47.02662399836949, 47.14846066066197, 47.123179640088765, 46.09282432283674, 45.7833446093968, 44.841391222817556, 45.57770224979946, 44.37457997458321, 45.30228955405099, 43.94297524860927, 44.41699872698103, 41.234966959272114, 41.09727798189436, 41.138220242091585, 41.27679511478969, 46.65482589176723, 50.43290887560163, 42.035375118255615, 38.981926713671, 41.88073948451451, 42.008850370134624, 42.064057282039094, 40.913584981645855, 39.626587527138845, 37.388058594294954, 38.76460443224226, 36.620744705200195, 38.49604960850307, 39.120300088609966, 41.284771646772114, 42.90871156964983, 37.91725424357823, 35.89284447261265, 37.783025469098774, 39.71878317424229, 40.47287464141846, 37.89156675338745, 37.77628919056484, 40.04033885683332, 43.9716991015843, 43.262569427490234, 44.578235149383545, 42.54969814845494, 43.7389691897801, 44.33767809186663, 43.33060271399361, 42.68306882040841, 43.749332427978516, 44.494036878858296, 44.62022311346871, 47.095164503370015, 47.38866336005074, 47.233662945883616, 49.54473802021572, 45.2971305165972, 48.999464239392964, 47.55091074534825, 48.25862298692976, 48.433741910117014, 56.11183139256069, 50.7887087549482, 47.63974346433367, 48.08563716070992, 46.96691812787737, 38.05614178521292, 45.14955425262451, 46.79353972843715, 42.630071435655864, 48.876470702035085, 50.959082058497835, 54.74498871394566, 43.02577134541103, 13.86600055013384, 0.8845709285565785, 0.32678851751344545, 10.0193510055542, 38.85815497807094, 30.64475543158395, 21.4630149773189, 21.256589208330425, 14.563821162496295, 1.876760985170092, 0.6822482336844716, 0.020393677022574202, 0.030896260868757963, 0.1527632706399475, 0.04257028962352446, 0.021504610178193877, 0.15967265702784061, 0.141331461923463, 0.05319371546751686, 0.13842107595077582, 0.120368556784732, 0.00964283078376736, 0.2382281624845096, 9.015461376735143, 34.0179877281189, 35.13899619238717, 61.059282302856445, 51.16097933905465, 6.952759649072375, 0.14921227975615434, 0.18489320656018599, 0.2964014123593058, 7.0087799344744, 65.86892264229911, 77.22857420785087, 61.00537122998919, 98.03919328962053, 26.4382951600211, 0.2194029547806297, 0.26323196079049793, 0.2374257541128567, 1.6468725608927863, 81.11756433759416, 89.21727398463658, 62.20894513811384, 72.01424993787492, 81.72765786307198, 3.1560496304716383, 9.817480649266924, 66.38478469848633, 49.007791655404226, 110.03627259390694, 69.91534505571637, 52.190111773354666, 30.917152609143937, 0.5012362067188535, 0.4312712667243821, 0.20001055965466158, 0.14685688114592008, 0.10024827000285898, 0.1844287764813219, 0.1512542494705745, 0.1614357488495963, 0.18514490234000341, 0.17487915605306625, 0.13154999965003558, 0.0790081765236599, 0.17136051771896227, 0.10910796280950308, 0.20641032553144864, 0.0631475154576557, 0.11992431990802288, 0.251559991389513, 0.19114720954426698, 0.0894971676170826, 0.18232838490179606, 0.250077202383961, 2.0912318996020725, 21.737718956811086, 47.75899887084961, 49.34382043566023, 58.58221476418631, 59.31754262106759, 61.56834207262312, 50.43641076769148, 64.8684584753854, 59.88609981536865, 55.73766047613961, 57.87350198200771, 63.468507630484446, 57.8304648399353, 62.32378496442522, 58.127528122493196, 63.138551575796946, 63.27564648219517, 63.364764077322825, 57.058544295174734, 59.6275087084089, 60.30757059369768, 59.27622863224575, 57.715027468545095, 53.65586205891201, 52.19296053477696, 51.992084639413015, 49.994553974696565, 49.764978545052664, 50.06156587600708, 48.115226064409526, 49.51548263004848, 46.096076079777305, 48.45920010975429, 46.48697478430611, 46.502799306597026, 46.99656956536429, 44.890337807791575, 42.322318349565776, 43.99917575291225, 43.7180620602199, 41.74442277635847, 49.81531824384417, 51.95983110155378, 43.24342714037214, 39.26727185930525, 43.23741347449166, 42.53277928488595, 44.9275940486363, 41.26378461292812, 40.01085417611258, 36.31398868560791, 40.12821272441319, 37.063386644635884, 38.27930402755737, 40.26814249583653, 42.20467839922224, 45.81056765147618, 41.10085283006941, 37.01950182233538, 41.56500291824341, 42.665298802512034, 42.526974064963206, 41.6553955078125, 39.172213554382324, 43.47057070050921, 47.714582511356895, 45.95175504684448, 46.16600622449602, 44.77436889920916, 46.848670210157124, 46.88122252055577, 47.34783921922956, 46.50566891261509, 46.4312606539045, 46.78947850636074, 47.63414669036865, 45.07852976662772, 47.873206411089214, 49.56412696838379, 52.12516696112496, 48.15399701254708, 51.64787088121687, 49.20012126650129, 49.117868491581504, 49.04585041318621, 57.50415658950806, 51.12868063790457, 46.051503385816304, 47.45545639310564, 47.98552404131208, 38.243614605494905, 47.24409219196865, 48.333514145442415, 42.189058848789756, 52.08372095652989, 51.188709599631174, 55.42839615685599, 54.65832730701992, 33.542654514312744, 4.962837261813028, 0.38750801075782093, 25.072803906032018, 56.596280642918174, 50.75710487365723, 41.10247870853969, 31.72069787979126, 21.80877297265189, 3.327629097870418, 0.6405662074685097, 0.2310802031840597, 0.13730947274182523, 0.2315737424152238, 0.11936953610607556, 0.19267745528902325, 0.33034344390034676, 0.35284928338868277, 0.15436123417956488, 0.2500118730323655, 0.1825229073209422, 0.3350704445370606, 0.46551633200475145, 13.246842231069293, 45.04845448902675, 51.38008383342198, 63.99115112849644, 62.754177229745046, 17.87019007546561, 0.549437434545585, 0.49044885699238094, 0.652564172233854, 14.422101361410958, 87.60552815028599, 81.280027117048, 69.42578193119594, 110.79225049700055, 26.539528676441737, 0.29507009951131685], [0.3848425894975662, 0.24602832964488439, 7.680587359837123, 77.55425712040493, 57.27846867697579, 47.82654925755092, 59.396689551217214, 23.76314663887024, 0.7518201661961419, 13.946070722171239, 34.57749489375523, 35.63058819089617, 54.97903183528355, 30.08750295639038, 30.17732231957572, 17.88200201307024, 0.061212978192738125, 0.05368916138208338, 0.07585237122007779, 0.02963224851659366, 0.09264276775398425, 0.042024455698473115, 0.02214561033594821, 0.022136266908741424, 0.044597701369119544, 0.04758242763844984, 0.07235961899693523, 0.04389705628688846, 0.11293316326503243, 0.09259036449449402, 0.04525677261075803, 0.02964967329587255, 0.05802712057318006, 0.13967629788177355, 0.014778606360778213, 0.05729279640529837, 0.013380449331764663, 0.03668527737525957, 0.10388084793729441, 0.16310225799679756, 6.579743870667048, 31.967233862195695, 36.41417128699166, 44.76644447871617, 46.2779347555978, 47.759207316807334, 53.352649620601106, 53.30262606484549, 51.11304024287632, 54.24195998055594, 57.29794447762625, 57.27210760116577, 52.953784806387766, 54.07519974027361, 54.279000827244346, 54.08848122188023, 53.47843633379255, 49.96295704160418, 53.124943256378174, 54.36644738061087, 55.154835156032014, 45.53864989961897, 48.59440163203648, 44.47525242396763, 43.832186222076416, 42.880022457667756, 43.16202899387905, 41.71166549410139, 42.988994530269075, 42.82508652550833, 42.62268202645438, 42.72437933513096, 42.24107306344168, 42.08825438363211, 42.22921943664551, 41.805156980242046, 41.21668972287859, 41.84041213989258, 37.676846572331016, 40.255733013153076, 44.86751644951956, 49.57962839944022, 45.28048610687256, 38.263097354343955, 40.20122439520699, 38.67226982116699, 38.6827199118478, 37.97245420728411, 37.02078376497541, 35.98156254632132, 35.2569522857666, 34.59197841371809, 37.61996167046683, 38.97312682015555, 44.71928358078003, 44.155280930655344, 39.01240151269095, 34.40461329051426, 38.10744033540998, 37.82076113564627, 38.13064384460449, 38.475548948560444, 38.97473185403006, 40.70051499775478, 40.8689740725926, 39.02012096132551, 41.154659679957796, 39.93569898605347, 39.992635999407085, 41.753542287009104, 40.272571972438264, 41.884039878845215, 41.43725333895002, 41.50256640570504, 43.95816401072911, 44.71831430707659, 48.90632711138044, 44.877507959093364, 47.2000093460083, 42.9803718158177, 46.194195066179546, 46.99042388371059, 49.59424046107701, 47.55513177599226, 47.28710501534598, 47.30196721213204, 49.610943930489675, 45.135272230420796, 39.96077503476824, 40.26411254065377, 36.83370351791382, 33.912604400089805, 32.855363028390066, 39.01721314021519, 42.59588629858834, 30.800336020333425, 10.21130107130323, 0.35504684118287905, 0.19065111902143272, 0.05048498670969691, 0.28938042053154533, 2.1600145058972493, 2.616890047277723, 2.4312799956117357, 1.6351651719638278, 0.8721025490335056, 0.11928722980831351, 0.1830116289534739, 0.08172634709626436, 0.15378838777542114, 0.1075191730633378, 0.06271711390997682, 0.08056008789156165, 0.10316959396004677, 0.12617997851754936, 0.059224714525043964, 0.0688148434939129, 0.05608014915404575, 0.1332335400262049, 0.2076058363808053, 12.025266408920288, 27.382676942007883, 28.224082946777344, 36.0282335962568, 31.374535151890345, 4.982055979115622, 2.5765134138720374, 0.3672547718243939, 0.05387132089318974, 0.623273281114442, 41.906420026506694, 77.42896025521415, 54.90133360454014, 88.24397032601493, 30.020741190229142, 0.21979009972086974, 0.36318168895585196, 0.2792202542935099, 11.168068017278399, 90.33139678410122, 71.72243254525321, 57.64912380490984, 67.74884809766496, 26.806714705058507, 1.324754617043904, 22.520277193614415, 53.19611365454537, 48.11922822679792, 62.06038570404053, 41.242787156786235, 36.457465512411936, 23.363399403435842, 0.14399787384484494, 0.06362353491463832, 0.03627455334312149, 0.04123644923259105, 0.044011609961411784, 0.02850108653573053, 0.021404624650520936, 0.022661154457767094, 0.016394249130306498, 0.03238495991432241, 0.13336816137390478, 0.025705189776739905, 0.04183880512469581, 0.08072729249085699, 0.08233065038387265, 0.07291559702051537, 0.011843548006644207, 0.032415823079645634, 0.039318553039005825, 0.037475760493959696, 0.02649299268211637, 0.03149523087111967, 0.10188932051616055, 0.2511082499154976, 3.136024270738874, 31.93071413040161, 42.05219323294503, 47.01391921724592, 50.55390133176531, 51.370033264160156, 57.163573265075684, 54.89420127868652, 54.83689601080758, 58.160386153629844, 59.61400835854666, 57.354012966156006, 56.88943556376866, 56.41075679234096, 56.98668255124773, 56.175525529044016, 53.97304732458932, 52.39670256205967, 56.3079651423863, 58.778126171657014, 57.73982906341553, 50.06496354511806, 48.68865394592285, 46.66687406812395, 46.339999539511545, 44.82779707227434, 47.06947701317923, 44.97319507598877, 45.31502907616751, 46.2565655708313, 44.8604918207441, 43.67890896115984, 45.586599418095176, 44.82787697655814, 44.01457643508911, 43.43130643027169, 42.57625763756888, 43.52605554035732, 39.867464201790945, 43.0088837487357, 47.39173446382795, 52.85557549340384, 49.45275776726859, 39.14692905970982, 41.34323378971645, 39.848728384290425, 39.441157477242605, 36.692338943481445, 36.89828354971749, 37.659524713243755, 37.7314316204616, 36.02385623114449, 38.64083964484078, 39.96268926348005, 47.540995665958945, 48.7404979297093, 42.75155373982021, 35.4770746912275, 41.629134791237966, 39.58859825134277, 40.4958245413644, 41.26300294058663, 40.90373938424246, 41.699714592524934, 43.32462726320539, 41.49777214867728, 45.21264736992972, 43.374261719839915, 43.86846276691982, 43.44196844100952, 40.99824183327811, 44.746607371738975, 43.239372866494314, 43.92866890771048, 45.55355378559658, 47.156287806374685, 51.268089294433594, 48.25241477148873, 48.544353757585796, 46.54296336855207, 49.43810054234096, 48.17240973881313, 51.99062899180821, 48.474027565547395, 49.56548186710903, 49.97126361301967, 52.29474817003523, 46.1717072214399, 45.24284076690674, 46.40466294969831, 39.90427575792585, 33.13719238553728, 32.66882126671927, 35.77319649287632, 31.017046860286168, 13.923863410949707, 1.7079031488725116, 0.34715097344347406, 0.03545682365074754, 0.036761561674731116, 0.448851539088147, 1.4484384145055498, 1.2834107726812363, 0.9116417616605759, 0.8389424341065543, 0.5810378960200718, 0.10005246515252761, 0.08498046533869845, 0.09316842883293118, 0.06469323180083718, 0.10899341252765485, 0.09480895008891821, 0.029423520966832126, 0.021748441737145185, 0.05358686204999685, 0.046057399827986956, 0.08647954597004823, 0.028480526924665486, 0.13099968060851097, 0.16578751962099755, 17.758819137300762, 34.95231894084385, 28.85814254624503, 39.9787152835301, 47.049348081861226, 3.020530662366322, 1.7822867631912231, 0.07208036112466029, 0.25691694393754005, 0.15739881832684788, 47.66075134277344, 80.43560559409005, 62.73823806217739, 96.99017511095319, 33.51012304850987, 0.2431642333311694, 0.567737741129739, 0.42244238619293484, 10.173873731068202, 105.54176085335868, 79.04327692304338, 66.77023601531982, 86.30300494602749, 42.94352899278913, 1.7482484068189348, 31.82186017717634, 72.47506836482457, 57.797752720969065, 73.10094819750104, 50.7647374698094, 45.762579917907715, 32.16371849605015, 0.618651209133012, 0.12614887447229453, 0.09334216093910591, 0.11100025448415961, 0.2392620870045253, 0.07343208430601017, 0.14588612823614053, 0.15409041728292192, 0.1904209463724068, 0.1500950673861163, 0.24232841389519827, 0.08927673873092447, 0.2742022978407996, 0.1938701027206012, 0.16403864989323275, 0.17271962336131505, 0.11275670344808272, 0.13332814137850488, 0.11621071132166044, 0.17969523476702826, 0.11390272873852934, 0.11177260375448636, 0.13858524071318762, 1.0452619173697062, 21.42692255973816, 46.6558438028608, 44.689319474356516, 51.26126616341727, 52.66825205939156, 52.76465484074184, 59.93388952527727, 55.423924991062705, 55.37199762889317, 59.15624713897705, 60.102376392909456, 61.67936733790806, 58.92974281311035, 58.867660658700125, 60.12236636025565, 59.06945719037737, 57.03939505985805, 54.71115098680769, 57.486275400434224, 60.70898192269461, 60.38269451686314, 53.285026277814595, 51.75576598303658, 50.77566351209368, 51.37655067443848, 47.028750147138325, 50.883732318878174, 46.73232609885079, 47.9693729536874, 48.40076575960432, 47.953979219709126, 46.77809040887015, 46.15559434890747, 47.3980781691415, 46.306915691920686, 48.42638029370989, 45.15752036230904, 47.13002014160156, 41.87311036246163, 44.097371169498985, 49.42097323281424, 52.873758929116384, 48.141868931906565, 37.86666440963745, 41.93174621037075, 39.835460799080984, 41.35689742224557, 38.90610102244786, 37.82129267283848, 36.747160230364116, 36.73565748759678, 35.75908817563738, 37.49773243495396, 39.590495109558105, 48.683717250823975, 48.94714082990374, 44.44132089614868, 37.12787982395717, 43.955482006073, 40.58812441144671, 43.31299597876412, 42.04426186425345, 42.084648268563406, 44.73218638556344, 45.385365690503804, 43.61243554524013, 47.35148007529122, 45.55925478254046, 46.8304694039481, 46.600126198359895, 45.20457703726632, 47.263401235852925, 45.967791489192415, 46.16586031232561, 48.01200362614223, 49.210884026118684, 52.63618612289429, 49.13346372331892, 50.32040364401681, 48.38100855691092, 51.59049960545131, 50.555773871285574, 54.477371897016255, 50.587839807782856, 51.03881958552769, 51.236342975071494, 53.1773430960519, 47.57560116904122, 47.81617907115391, 43.14624268668038, 38.05287613187517, 35.40838827405657, 39.33008010046822, 53.861997740609304, 52.878768580300466, 35.97291203907558, 13.226509196417672, 0.559607480253492, 0.25899138833795277, 0.14500445340360912, 0.9987162607056754, 7.298835958753314, 5.602196165493556, 2.3734071467603957, 1.6482718629496438, 0.7175390028527805, 0.16474170716745512, 0.19814597256481647, 0.1990331978138004, 0.22476883684950216, 0.14171762977327618, 0.18739845284393855, 0.22559654100665025, 0.17879568732210568, 0.1410273289574044, 0.12145508133939334, 0.2105386818626097, 0.1357512984957014, 0.30334410124591416, 0.34092831877725466, 23.944152423313685, 44.69996411459786, 42.01852226257324, 47.30566712788173, 69.14092663356236, 8.97335876737322, 5.658810521875109, 0.35687041761619703, 0.28788400654281887, 0.9513430084500993, 57.856593540736604, 91.35284451075962, 71.1963357925415, 107.68083327157157, 38.25313711166382, 0.31986385051693234], [0.4053550830909184, 0.23447686806321144, 16.177912882396154, 82.45620427812848, 60.58395603724888, 63.24659606388637, 54.21049853733608, 3.49864684683936, 0.0902901172105755, 23.80261414391654, 40.76065165655953, 51.2632394518171, 71.15471608298165, 25.66214316231864, 25.274775879723684, 21.111298901694163, 0.09689077016498361, 0.1594536802066224, 0.04478637481640492, 0.04062232754326292, 0.04139770647244794, 0.057031960758779726, 0.03086800327790635, 0.0020185920626058108, 0.046485636848956347, 0.055833142051207166, 0.05162332759105733, 0.05524316603051765, 0.026473386412752525, 0.013099211833572813, 0.04430033678987196, 0.024380190697099482, 0.02497903856315783, 0.06920082135392086, 0.03800458354609353, 0.046638958621770144, 0.025067103926890662, 0.11097744892218284, 0.01710260406668697, 0.008148967238542224, 0.22556547767349652, 8.295631476811, 28.166409424373082, 31.623381410326274, 40.580088819776265, 45.4918155670166, 53.0057156426566, 52.43062366758074, 53.493058817727224, 56.63072286333357, 54.16259070805141, 52.411057540348594, 55.984846115112305, 53.429114546094624, 55.714762687683105, 54.611058712005615, 50.61582020350865, 55.981990405491416, 55.29479272024972, 55.57294995444161, 53.85009895052229, 49.13669810976301, 48.79252256665911, 43.030798367091585, 42.24473128999983, 43.04947859900338, 40.58661665235247, 41.61894178390503, 42.69471747534615, 41.70352220535278, 40.538034847804475, 41.98777995790754, 41.02885907036917, 41.15972491673061, 41.23825693130493, 43.57791689464024, 41.92877238137381, 43.195477621895925, 38.08454949515206, 41.50209392820086, 46.546239444187705, 49.1859712600708, 51.70945623942784, 44.82949938092913, 41.42634466716221, 42.22036395754133, 41.468544551304404, 37.69818101610456, 34.91399267741612, 38.62024865831648, 40.55542618887765, 41.07375832966396, 40.52725124359131, 43.993929862976074, 49.819337776729036, 44.309367656707764, 43.87622390474592, 38.07093102591378, 39.26242201668875, 39.672181606292725, 39.75122431346348, 38.07166058676583, 40.03469344547817, 39.657708508627756, 38.959925242832725, 39.814126355307444, 39.86311115537371, 40.44410562515259, 38.59237943376814, 39.77501147133963, 38.92264815739223, 42.44688217980521, 39.43490757261004, 39.710487025124685, 44.49891104016985, 46.22954055241176, 51.773150375911165, 47.7604649407523, 45.666726044246126, 45.97285325186593, 46.24156093597412, 48.58411829812186, 47.120032106127056, 44.48014395577567, 46.37582792554583, 45.350190435137065, 47.093733174460276, 43.56948872974941, 40.01343890598842, 36.785062653677805, 28.23526954650879, 21.278740065438406, 17.750901665006364, 12.10742712020874, 4.222747717584882, 0.6363515279122761, 0.31038981888975414, 0.1151973328420094, 0.051094562214400084, 0.013852236426568456, 0.04715980549475976, 0.22830618917942047, 0.049435391423425505, 0.17384016966181143, 0.08987526768552405, 0.11027469698871885, 0.12122197741908686, 0.041010853302265914, 0.07749081615890775, 0.006666777040144163, 0.05008218457390155, 0.014816565306058951, 0.07563142664730549, 0.04664775582828692, 0.08221297884093863, 0.05075097922235727, 0.0753084100516779, 0.03389058501592704, 0.11323536919163806, 0.06170235800423792, 14.7341171673366, 29.79975025994437, 24.81397134917123, 23.756285292761667, 19.791618858064922, 4.225741956915174, 8.028752037457057, 6.062551668712071, 0.4032527101891381, 1.3312840781041553, 50.818579060690745, 72.37644563402448, 64.76921735491071, 89.4823477608817, 25.13748468671526, 0.2705916772995676, 0.4024189534996237, 0.35089268695030895, 19.07080578804016, 95.66630704062325, 71.61934212275914, 75.29359122685024, 62.38763196127755, 2.917912934507642, 0.1471221883382116, 35.513910566057476, 53.118537017277305, 61.58477456229073, 73.08502292633057, 31.122937406812394, 28.16133029120309, 29.855492183140345, 0.17018030104892595, 0.11076510138809681, 0.027415795218465582, 0.04056674873988543, 0.07223927402602774, 0.039189186945025406, 0.015231972926163247, 0.0633104724277343, 0.03305654673437987, 0.03250682480367167, 0.0879991047882608, 0.0618970093450376, 0.021357807430571744, 0.006306763746709163, 0.01617651402817241, 0.03058122723762478, 0.0059852238129159165, 0.10396400240382977, 0.018403433728963137, 0.07612382593963828, 0.017032487650534937, 0.01803950995339879, 0.07501565611788205, 0.032681642565876245, 0.13085599403296197, 2.332317671605519, 22.17975640296936, 29.592482021876744, 38.771094049726216, 48.01966054098946, 57.574976103646414, 57.48887750080654, 56.46273626599993, 62.474546977451865, 57.0309773172651, 55.507748058864046, 57.87918560845511, 56.97520065307617, 57.53008379255022, 57.601594652448384, 52.038828645433696, 58.119259766169954, 58.54665388379778, 56.456191062927246, 54.713909421648296, 53.06652627672468, 52.12424285071236, 46.52868134634835, 44.99665914263044, 45.7253931590489, 43.62534529822213, 44.65817417417254, 45.48370007106236, 44.51612172807966, 43.18618788037981, 43.68006236212594, 43.47198118482317, 43.53353180204119, 43.41844878877912, 45.235017095293315, 44.8815518106733, 44.936796937670024, 41.19384057181222, 45.48544406890869, 50.180755274636404, 51.55396597726004, 50.75900520597185, 47.04151051385062, 42.920360224587576, 45.50785548346383, 43.44165924617222, 38.761446475982666, 36.157289436885286, 39.21680014474051, 42.49057592664446, 42.00582790374756, 42.580162525177, 46.53217281614031, 49.78158473968506, 47.8727582522801, 46.74490928649902, 40.57955380848476, 39.64343343462263, 41.272758211408345, 42.3700316292899, 39.97376469203404, 41.13539579936436, 41.35540703364781, 41.029498304639546, 42.326296193259104, 42.00851338250296, 42.56527600969587, 40.390934535435264, 41.69092164720808, 39.74104520252773, 43.4701155935015, 42.22989688600813, 42.03691414424351, 46.10363571984427, 51.03431715284075, 52.99989652633667, 51.669896670750205, 48.854003701891216, 50.84545816693987, 50.772015707833425, 52.89611823218209, 48.27036544254848, 48.34763635907854, 49.90492221287319, 50.63225269317627, 49.22330740519932, 49.55440296445574, 45.278519766671316, 34.06679882322039, 24.879624877657207, 18.192779302597046, 10.69358856337411, 5.5498102222170145, 0.21227102247732027, 0.24936989748052188, 0.1861582672489541, 0.14175007731786796, 0.03074007567816547, 0.057836167248232026, 0.061740545955087454, 0.1992920453527144, 0.11181472042309386, 0.08970087740038123, 0.06627355342996971, 0.10873021557927132, 0.16822373175195285, 0.1910330799541303, 0.043174857539790015, 0.03287500808281558, 0.08092280557113034, 0.046622555037694316, 0.105682941951922, 0.04808149353734084, 0.11622121504374913, 0.03007245489529201, 0.04373219941875764, 0.04168654865186129, 0.09862081733133111, 0.13605859343494686, 24.241511004311697, 35.837425640651155, 34.90073551450457, 27.134320531572612, 35.10370976584298, 4.4434963294437955, 5.434432779039655, 7.397628051894052, 0.1606558814112629, 5.61542900971004, 61.05366815839495, 75.5427188873291, 72.13318225315639, 96.23104967389787, 24.639642783573695, 0.43428244228873936, 0.5506387672254017, 0.40132113812225206, 22.00851457459586, 106.83201353890556, 78.60922295706612, 85.83380004337856, 87.47242845807756, 9.869042362485613, 0.353128188422748, 51.9843304497855, 66.60263156890869, 73.26381397247314, 87.07472051892961, 41.60863413129534, 35.8697486604963, 38.79501322337559, 0.37171478250197, 0.2750228638095515, 0.11636894568800926, 0.14132467657327652, 0.12503230438700744, 0.19715277371662004, 0.06615050110433783, 0.12856373989156314, 0.17505959208522523, 0.12140691892376967, 0.18980774070535386, 0.13446024991571903, 0.1200807900833232, 0.059167446169470034, 0.16121958116335527, 0.10959568699555737, 0.08652629024748291, 0.2688854874244758, 0.10575686834220376, 0.1338627455489976, 0.08351612570030348, 0.2126272397914103, 0.15846364333161286, 0.12150617502629757, 0.5842169682894434, 20.310499906539917, 43.88725069590977, 44.80513899666922, 48.63588237762451, 47.034819398607524, 59.643037932259695, 60.41338471003941, 56.51121037346976, 62.299494062151226, 59.05639457702637, 57.32946498053414, 59.12293747493199, 57.68743617194039, 60.561158997671946, 58.11982257025582, 55.84241846629551, 60.788399832589285, 61.349279267447336, 58.45400660378592, 57.60460669653756, 55.96162176132202, 55.233172621045796, 48.770496777125764, 47.65942076274327, 48.49558087757656, 46.78499691826956, 46.51293325424194, 49.93586948939732, 47.16130093165806, 45.14980091367449, 45.49775627681187, 44.04272706168038, 44.52853468486241, 46.43549905504499, 49.55711971010481, 47.58269527980259, 47.0085517338344, 42.56364665712629, 47.178824288504465, 51.82435165132795, 54.165706975119456, 54.50865963527134, 48.04481301988874, 42.1512884412493, 44.80037948063442, 42.80800437927246, 39.38724987847464, 35.779988356998985, 37.96564844676426, 42.7384911264692, 43.12327889033726, 42.06713533401489, 47.72135353088379, 53.71533516475132, 50.222003255571636, 48.76914882659912, 41.680739062173025, 41.4729323387146, 44.22875465665545, 43.716575145721436, 42.05265876225063, 44.48910018375942, 43.81259230204991, 43.148407050541465, 45.68768875939505, 44.58026054927281, 43.637647083827424, 42.41563613074166, 43.76329483304705, 41.65873064313616, 46.63062184197562, 44.08056000300816, 44.26899862289429, 47.998225348336355, 51.01338570458548, 55.99450758525303, 54.31865767070225, 50.87893111365182, 49.93375723702567, 50.96714544296265, 52.78478724615914, 49.23352820532662, 49.46532358442034, 51.53625501905169, 50.55764641080584, 52.10878310884748, 51.14561339787075, 44.68217672620501, 42.85065937042236, 40.40948969977242, 39.41306243624006, 36.6220440183367, 20.583456414086477, 7.107885130814143, 0.8154598027467728, 0.4647809628929411, 0.23067739765558923, 0.1689068265259266, 0.13986286787050112, 0.11750545113214425, 0.536075234413147, 0.267203860517059, 0.15597546898892947, 0.122688033751079, 0.19389629417232104, 0.3327435308269092, 0.22000434036765779, 0.2140573337674141, 0.1183933142040457, 0.13530613881136688, 0.12489089768912111, 0.17027046478220395, 0.1427784649921315, 0.18558216387672083, 0.08574887232056685, 0.15274379668491228, 0.10105501421328102, 0.1908333735274417, 0.22113278481577123, 33.451699120657786, 45.72060585021973, 39.0826929637364, 29.46094220025199, 48.73056895392281, 12.95484071118491, 14.023113216672625, 7.147593651499067, 1.3005404706512178, 4.183916841234479, 73.77406883239746, 83.36973258427211, 80.15208435058594, 108.54369531358991, 32.68034485408238, 0.46640960978610174], [0.2745972866458552, 0.22719540021249227, 13.275163088526044, 93.08346012660435, 41.59707580293928, 53.30795185906546, 34.62675762176514, 0.5466802482094083, 0.35702167664255413, 16.426847730364116, 45.88843263898577, 47.74258027757917, 69.23549161638532, 63.698784828186035, 30.937566416604177, 28.39524139676775, 0.6738915592432022, 0.07599094164158617, 0.033799922559410334, 0.03206895258543747, 0.0452829437064273, 0.04881957000387566, 0.0638718448047127, 0.04168379379968558, 0.043304125246192725, 0.025220179730760198, 0.045137808458613496, 0.04581784303965313, 0.02279564518747585, 0.11517257988452911, 0.06480212310062987, 0.055995223711111715, 0.10058923384972981, 0.04495942160221083, 0.022669016982295682, 0.04520409454458526, 0.06595563941768237, 0.03903479647955724, 0.032285490073263645, 0.028789823542215993, 0.04050803849739688, 0.04856257825823767, 0.7055949409093175, 5.485390433243342, 11.338099122047424, 32.72799212591988, 48.152089732033865, 53.75187921524048, 52.42568697248186, 53.598956312452046, 52.763390268598286, 53.903134550367085, 55.00125217437744, 53.83337116241455, 53.392480169023784, 56.28697116034371, 53.2737250328064, 53.736037322453086, 55.01151466369629, 51.880840505872456, 50.5649003301348, 50.844294343675884, 49.69242892946516, 46.16537046432495, 41.6002059664045, 40.841167381831575, 42.405495234898154, 41.48980603899275, 40.85665144239153, 40.454958711351665, 39.82947840009417, 41.265639781951904, 42.47264610018049, 40.35115262440273, 39.195007119859966, 40.76494911738804, 41.812223298209055, 41.387306213378906, 43.440418992723735, 44.01469802856445, 47.0475172315325, 48.482921259743826, 44.51944644110543, 43.89264249801636, 42.301883697509766, 42.57021965299334, 39.368309089115684, 40.98924739020211, 39.61100966589791, 38.680013588496614, 41.8719048500061, 42.58579751423427, 40.65317692075457, 40.51696790967669, 42.828331334250315, 43.96652616773333, 42.75414194379534, 41.995652266911094, 41.8779741014753, 39.19524335861206, 37.786179951259065, 38.58281176430838, 39.16378191539219, 37.86004625047956, 41.0456737109593, 39.3217214175633, 40.51286499840872, 38.922272954668315, 39.31837933404105, 38.51555667604719, 39.87268229893276, 41.42531633377075, 40.832780906132285, 39.073041915893555, 42.054222106933594, 51.8159373828343, 53.45542390005929, 50.818672861371724, 48.010256154196604, 46.57510920933315, 46.36735807146345, 47.27339621952602, 49.42545829500471, 47.62086868286133, 47.28875868661063, 45.18740803854806, 44.31007637296404, 37.20603663580758, 25.617789336613246, 13.646521721567426, 8.758590817451477, 3.892580611365182, 0.454831522490297, 0.026952091172071438, 0.058680794068745205, 0.04545130520792944, 0.11571829845862729, 0.06809833765562091, 0.07699389103800058, 0.024997448914551308, 0.040886097853737216, 0.07967369724065065, 0.0582433764689735, 0.16130447946488857, 0.1394433839512723, 0.03533154912292957, 0.06028467443372522, 0.03861691729564752, 0.0830967774880784, 0.08157233321773154, 0.0333645778841206, 0.013098511246166058, 0.06686651161206619, 0.1119134540536574, 0.07992444985679217, 0.10066729930362531, 0.047993480760071955, 0.11982560663350991, 0.1079122619703412, 0.3385106713644096, 19.425579071044922, 29.7887373651777, 18.65087056159973, 17.559713295527867, 11.71924602985382, 7.33294813973563, 9.918210421289716, 14.879402262823922, 13.860566190310887, 33.021456241607666, 49.97184031350272, 59.42275224413191, 71.7410328728812, 78.10367897578648, 9.72557943207877, 0.41839079931378365, 0.20052354569946015, 0.21557293672646793, 14.372291462762014, 102.96752275739397, 50.99497297831944, 62.63707229069301, 51.14739908490862, 0.1036029267790062, 0.9568440275532859, 31.83911255427769, 56.32006890433175, 56.50526966367449, 78.33814593723842, 64.1895569392613, 33.688417298453196, 35.945345061165945, 0.6537811926433018, 0.10023178838725601, 0.05179625563323498, 0.03250199363433889, 0.07451917883008718, 0.06787307081477982, 0.04531067203996437, 0.05875030319605555, 0.031092774788183824, 0.022547364135139754, 0.012309146013909152, 0.04654100869915315, 0.0830199605386172, 0.07806116555418287, 0.0507550300764186, 0.05560854696003454, 0.031650964835924764, 0.00716057072194027, 0.10679588866020952, 0.03186579580817904, 0.0030954010560110745, 0.03686953016689845, 0.05229383893311024, 0.05949034741414445, 0.05423241687406387, 0.25700629342879566, 0.904289644743715, 2.0904280798775807, 7.854300141334534, 26.63114067486354, 47.23377759116036, 56.66591548919678, 59.11764989580427, 53.407599449157715, 57.27165249415806, 55.498256819588796, 56.938809462956016, 57.665160247257774, 54.729942389896934, 58.39240387507847, 56.41789606639317, 56.75337593896048, 57.24229635511126, 55.726004873003276, 53.74516378130232, 55.15012775148664, 53.24770055498396, 47.027110372270855, 43.95037160600935, 42.23658800125122, 44.97508846010481, 43.530846323285786, 43.86364071709769, 41.01619250433785, 43.85208586284092, 42.318406513759065, 43.4691914830889, 41.10816928318569, 42.85170160021101, 42.10475288118635, 44.79467848369053, 45.021881103515625, 46.866891860961914, 46.301169531685964, 50.186167921338765, 49.12222153799874, 47.72747489384243, 45.828111852918354, 45.81696694237845, 42.22220523016793, 41.579903330121724, 41.45742743355887, 41.04486077172415, 40.91107668195452, 43.833068643297466, 43.333614758082796, 42.7686219896589, 43.22165496008736, 44.760253633771626, 46.049488408224924, 45.49461221694946, 45.30439485822405, 44.22284173965454, 41.529240540095735, 41.37765169143677, 40.99902697971889, 41.06506960732596, 39.69829988479614, 42.30935648509434, 39.92063181740897, 43.663296358925955, 41.702580724443706, 40.550555501665386, 41.19897529057094, 40.69757243565151, 41.660064697265625, 43.08787781851632, 41.016289779118125, 45.42188194819859, 53.76995842797415, 52.263429164886475, 51.61152832848685, 50.27251665932791, 47.29116971152169, 49.96401316779, 49.998875754220144, 52.596317359379356, 50.21438455581665, 48.875098432813374, 48.44923639297485, 48.955423082624165, 40.69187838690621, 21.625660146985734, 3.971429637500218, 2.5606430768966675, 2.4047886856964658, 0.33715194570166723, 0.048689759469458034, 0.049097457235412936, 0.04475794419912355, 0.06826003933591501, 0.07907501222299677, 0.06769803592136928, 0.051910347903945615, 0.033696171162383895, 0.18120136537722178, 0.07820641954562493, 0.06579794787934848, 0.1454179390732731, 0.06937327102891036, 0.04558236424678138, 0.021997453910963874, 0.09372364689729043, 0.07149858519967113, 0.04176689059074436, 0.011267755064181983, 0.047473878998841555, 0.13675297903163092, 0.028591905055301528, 0.1129839855379292, 0.01768817300243037, 0.23084084317088127, 0.09541978088340589, 0.6938976485814367, 31.872189453669957, 35.204792158944265, 27.620513779776438, 23.881641217640468, 20.172131742749894, 22.429144620895386, 26.70240487371172, 24.025951828275407, 32.59800175258091, 54.019027028764995, 57.858146463121685, 65.57895347050258, 79.57903861999512, 79.34587097167969, 6.328733682632446, 0.38282221076743944, 0.40095899041209904, 0.4715999684163502, 19.1867938041687, 116.41187708718437, 65.27669988359723, 74.94055325644356, 72.54328577859062, 0.7301930295569556, 2.0141800684588294, 48.392761434827534, 72.30007103511265, 70.7433271408081, 87.99707303728376, 74.21152741568429, 47.69156660352434, 46.87552152361189, 1.0582801273890903, 0.24147896947605269, 0.15429538914135524, 0.09088424925825425, 0.12791721815509455, 0.12335843992020402, 0.13208517378994397, 0.11596411812518324, 0.09641600599778549, 0.1274283065327576, 0.12316428390996796, 0.15253022100244248, 0.17585476727357932, 0.21608475569103444, 0.11892334504851274, 0.2348285120512758, 0.21115381456911564, 0.09247659452791725, 0.1885916973863329, 0.19757216264094624, 0.1491331761436803, 0.24400466680526733, 0.11365584377199411, 0.21610300828303608, 0.17364743857511453, 0.5447059284363474, 2.651811693395887, 10.84123604638236, 22.203230891908916, 41.38857773372105, 53.41593728746687, 57.73482983452933, 61.11331149509975, 56.8546598298209, 57.01490960802351, 58.872677258082796, 58.00348540714809, 58.31927408490862, 56.812487738473074, 61.25957107543945, 57.67179577691214, 56.96189832687378, 58.562822341918945, 56.86383145196097, 56.15744284221104, 56.25545065743582, 56.406549658094136, 50.24087456294468, 46.082975251334055, 44.76386669703892, 48.03221940994263, 44.64540338516235, 46.61825057438442, 44.6070875440325, 45.93870632989066, 44.826060022626606, 46.10009561266218, 44.79189920425415, 44.195045471191406, 44.17578853879656, 47.727551324026926, 46.269357204437256, 48.22259657723563, 47.99174267905099, 53.17133290427071, 52.34193338666643, 50.416650090898784, 49.028413908822195, 47.66994380950928, 46.14324392591204, 44.202007566179546, 43.42149209976196, 39.70184694017683, 44.34209367207119, 45.93322767530169, 47.247493335178916, 45.47871126447405, 45.87720087596348, 48.31852340698242, 47.999503816877095, 49.98964854649135, 46.39861454282488, 45.4930453981672, 43.30696494238717, 42.4349764415196, 43.572955880846294, 43.86175428118025, 41.802867548806326, 44.794716698782786, 43.75189978735787, 45.22306619371687, 44.48598044259207, 42.80938359669277, 44.97694362912859, 44.698022093091694, 43.60827704838344, 44.04321690968105, 44.82702234813145, 47.22549186434065, 54.74094138826643, 56.012399196624756, 53.603406633649556, 51.52297701154436, 48.5606438091823, 50.62708670752389, 50.60472045625959, 54.43287215914045, 51.803739820207866, 49.60115739277431, 49.349462372916086, 51.986817904881065, 45.29564012799944, 46.20232793263027, 42.587169783455984, 25.74603918620518, 12.538915463856288, 1.9785583913326263, 0.11859029291995934, 0.13511552475392818, 0.20969314580517157, 0.26526360320193426, 0.1465597235198532, 0.21537514376853192, 0.13143177170838627, 0.14648182769971235, 0.3814425862261227, 0.15616879718644278, 0.2440220915845462, 0.13891929707356862, 0.11958513382290091, 0.1437527191426073, 0.08924741244741849, 0.1945811938494444, 0.14925791802150862, 0.11102466817413058, 0.08404958314661469, 0.1591152540807213, 0.1988406702876091, 0.13003749081066676, 0.19141529873013496, 0.08596404934568064, 0.35365961704935345, 0.21355497358100756, 1.172575171504702, 41.74721942629133, 44.43567548479353, 32.43279790878296, 26.937813316072734, 27.385426691600255, 26.553432021822246, 37.48773397718157, 31.771312032427105, 33.82297611236572, 61.882490975516184, 67.39394801003593, 74.69792910984584, 85.50633144378662, 96.08035714285714, 12.546675733157567, 0.5631397707121713], [0.1353149190545082, 0.25402478341545376, 7.680472714560373, 73.3380207334246, 58.937100955418174, 46.40983240944998, 50.59814051219395, 10.598888090678624, 8.8215970822743, 33.97003126144409, 36.08931868416922, 49.825750964028494, 46.32436956678118, 44.42918586730957, 22.375356878553117, 25.340222699301584, 1.073793174965041, 0.04829225329948323, 0.08841645132218089, 0.02491138522912349, 0.02811964807499732, 0.07092612556048802, 0.04258245575640883, 0.0322527779000146, 0.09696580256734576, 0.004387946017751736, 0.09823332633823156, 0.023847791765417372, 0.010254157756987427, 0.040019113304359574, 0.023970435273700526, 0.11710526474884578, 0.024111618055030704, 0.08921642375311681, 0.04763629314090524, 0.015008283679240515, 0.011992974140282189, 0.012029561596656484, 0.03820321110210248, 0.023278517848146812, 0.011961484178235489, 0.17339423644755567, 0.23992433718272618, 0.08071400677519185, 0.30642443309937206, 3.5909571392195563, 20.875513519559586, 39.85723992756435, 48.314837387629915, 47.838392462049214, 52.308637619018555, 53.35579368046352, 55.06749282564436, 54.63822616849627, 55.035263606480186, 57.26149770191738, 53.208533559526714, 55.62262610026768, 55.09719984872, 53.23279666900635, 50.03867850984846, 54.52380323410034, 51.35904816218785, 43.75389739445278, 41.96618843078613, 39.69567346572876, 40.164287771497456, 41.13364485331944, 41.2395145552499, 39.03009162630354, 39.41379199709211, 40.6191029548645, 40.22771092823574, 40.91140672138759, 40.653347151620046, 39.93518481935774, 41.815944058554514, 41.3923019681658, 43.15001208441598, 44.606396198272705, 44.77012702396938, 47.459489822387695, 48.030305181230815, 45.15310825620379, 43.38761615753174, 42.13944523675101, 42.22870179585048, 40.67401456832886, 40.165006910051616, 39.796453612191335, 41.09602383204869, 41.5463331086295, 40.86817502975464, 42.67173630850655, 44.29472085407802, 45.63901662826538, 42.01406151907784, 42.4392009462629, 39.50359398978097, 38.48452949523926, 39.89187669754028, 38.29072686604091, 37.70931550434658, 38.84493603025164, 37.41693878173828, 39.056998525347026, 39.49400894982474, 39.283579281398225, 41.0718024117606, 38.79617357254028, 39.693964208875386, 38.91826384408133, 38.9554123878479, 39.11263622556414, 42.73084115982056, 54.51445095879691, 49.00261524745396, 50.190034593854634, 51.24549375261579, 47.19926241465977, 45.52790798459734, 46.58372497558594, 46.856122153145925, 46.218659673418315, 48.19233022417341, 44.96928671428135, 36.698196274893625, 23.076530865260533, 11.706596834318978, 2.371835333960397, 0.4902433423059327, 0.13040584033089025, 0.02440199033091111, 0.04517668512250696, 0.06734426811869655, 0.052505677565932274, 0.08090989983507565, 0.02931557283071535, 0.06689590574907404, 0.08014662936329842, 0.026520302020279423, 0.04725194037226694, 0.01816227050897266, 0.07650805996464831, 0.004940910921764693, 0.042800353706947396, 0.050119001884013414, 0.08775200269051961, 0.026941991178318858, 0.042808730221752606, 0.003957503333887351, 0.051375686057976315, 0.07995960475610835, 0.12814061902463436, 0.00945876628559615, 0.021074598788150718, 0.04640386998653412, 0.057141998782753944, 0.0736571340156453, 1.034488844020026, 24.964578764779226, 24.748290027890885, 15.628048079354421, 12.69003530911037, 6.366729472364698, 9.724195872034345, 17.90540180887495, 25.648389203207834, 36.44885322025844, 44.784759930201936, 56.94924913133894, 73.39079230172294, 73.12146622794015, 43.06734936577933, 0.20326997047024115, 0.004220953036565334, 0.14448992029896804, 0.24860692556415284, 7.228952280112675, 81.3852367401123, 69.84878826141357, 47.80990832192557, 77.48227378300258, 17.60878494807652, 12.490519523620605, 56.92026819501604, 48.74778659003121, 56.54729584285191, 53.941505977085654, 48.19233022417341, 28.89895452771868, 38.42299277441842, 1.6514490353209632, 0.11215759773871728, 0.030194051763308898, 0.0236689791282905, 0.060953669250011444, 0.02801794246105211, 0.07736990800393478, 0.047521098250789304, 0.08381200089518513, 0.05030288487406714, 0.013888497337965029, 0.04900633676775864, 0.047974905863936455, 0.03484445258176752, 0.029692821337708404, 0.06977415630327803, 0.0446067598116185, 0.03191875546638455, 0.06720041869474308, 0.006183631693212581, 0.030786229630133936, 0.07541897733296667, 0.05340970673465303, 0.12926548080784933, 0.0908923102542758, 0.045509343700749535, 0.0239981602145625, 0.06942249874451331, 0.10248020916645016, 0.2262586826192481, 10.218792097909109, 33.69588661193848, 49.339008808135986, 53.9795960017613, 55.37708371026175, 57.19153281620571, 57.786896160670686, 55.74637699127197, 56.088812010628835, 58.298450333731516, 54.902709347861155, 57.769084453582764, 56.70052099227905, 53.627954619271414, 53.626353059496196, 57.15373461587088, 54.91659532274519, 46.87012277330671, 43.42705760683332, 43.551089899880544, 42.83698878969465, 42.220051288604736, 41.744325501578196, 42.22235461643764, 41.602516242435996, 41.61198663711548, 41.84359788894653, 42.95114074434553, 42.887394496372764, 42.87528726032802, 43.11274194717407, 43.22356571469988, 43.961231640407014, 47.76777444566999, 47.112541948046, 51.83392626898629, 49.85177196775164, 45.793082509722026, 45.54204062053135, 45.37900114059448, 43.74792889186314, 43.07315458570208, 43.17625890459333, 43.59038543701172, 44.48170035226004, 43.12133339473179, 43.575099400111604, 45.47661290849958, 47.57625777380807, 47.29935121536255, 42.876840182713096, 44.01016780308315, 42.81073154721941, 41.38562822341919, 42.217365809849326, 39.79384108952114, 39.054768153599326, 40.84089640208653, 39.918307644980295, 41.685995374407085, 41.753809792654856, 42.32051529203142, 41.91755451474871, 42.529124532427105, 41.785979952131, 41.86435910633632, 41.763360091618125, 43.38670941761562, 46.00851835523333, 56.95022535324097, 49.78690011160714, 50.483710629599436, 53.15466070175171, 52.36238888331822, 46.993755544934956, 50.86093875340053, 47.86896106175014, 48.264963218144004, 52.21218272617885, 50.14043140411377, 40.561238356998985, 18.851939269474574, 8.440663831574575, 1.5930749390806471, 0.48194708462272373, 0.08616566924112183, 0.056548202609909434, 0.0189846023651106, 0.021060317322345715, 0.030599452688225677, 0.032631600608250926, 0.05369068469320025, 0.0303675022774509, 0.07020117874656405, 0.058383005405110974, 0.07842612239931311, 0.021838023626644696, 0.03918390454990523, 0.046957866687859805, 0.0733956741169095, 0.04209968487599066, 0.023155148307393705, 0.004827161311238472, 0.0393776534391301, 0.03960329686690654, 0.03277650854683348, 0.10852768644690514, 0.06251178921333381, 0.051918877089130025, 0.04499487505693521, 0.04550942173227668, 0.1159442099077361, 0.17938639276794024, 2.8407588345663886, 39.233062403542654, 30.879125118255615, 22.610263313565934, 14.76316932269505, 7.595446739877973, 15.070535046713692, 25.808668511254446, 38.85593155452183, 43.90849481310163, 54.56611776351929, 73.31353528159005, 72.69372817448208, 77.07873630523682, 28.302154643195017, 0.2156064970684903, 0.03585877761776958, 0.3826178088784218, 0.5761495668973241, 11.600324136870247, 96.31033556801933, 87.17009149278913, 65.11907305036272, 85.9127037865775, 24.140291384288243, 16.26631828716823, 75.43777329581124, 61.89943068368094, 69.55227388654436, 59.78587205069405, 57.934621810913086, 35.78234379632132, 53.73343869618007, 2.7681738265923093, 0.36834482476115227, 0.17922293368194783, 0.10954141776476588, 0.16046348959207535, 0.12460858640926224, 0.22696301553930553, 0.1478339580020734, 0.20118750578590802, 0.13492235940481934, 0.12745239452591964, 0.08763229554252965, 0.11257556173950434, 0.19043940252491406, 0.1794696083026273, 0.25070590579083984, 0.10899248972002949, 0.19941241746502264, 0.18847226165235043, 0.0927642798051238, 0.20494645408221654, 0.10929132332759244, 0.10071465426257678, 0.34589725786021774, 0.18578094749578408, 0.24466517993382045, 0.5739178380795887, 0.24118524523718016, 0.9983639653239931, 7.692970786775861, 30.754957335335867, 49.13595117841448, 53.99586868286133, 56.10461916242327, 57.50803368432181, 56.69838094711304, 59.61477266039167, 56.90855005809239, 57.22970274516514, 59.18811157771519, 57.3087454523359, 58.988114629473, 59.7071350642613, 58.4904568535941, 55.06505053383963, 58.79803276062012, 56.941133635384695, 48.85621670314244, 47.67781959261213, 46.43709019252232, 44.853369917188374, 45.14887680326189, 43.793654986790244, 43.97187628064837, 43.40954119818551, 44.22865390777588, 45.18021665300642, 45.18401036943708, 46.50942093985421, 46.40880407605852, 45.87635319573538, 47.300376074654714, 46.52848332268851, 49.24924503053938, 49.85450608389718, 52.913196904318674, 53.45451716014317, 48.23244912283761, 46.79051726205008, 47.53000361578805, 45.79560817990984, 44.7661908694676, 43.71972962788173, 44.180978843144004, 46.10975360870361, 44.403790201459614, 45.76042250224522, 46.548744269779746, 50.11615787233625, 50.60618652616228, 43.979626996176584, 45.85380629130772, 45.03367567062378, 43.386824062892366, 43.397750105176655, 42.48400640487671, 41.5869140625, 43.771695205143516, 42.761760643550325, 42.28339801515852, 43.35526534489223, 44.01091820853097, 44.86020347050258, 44.372884614127024, 44.58877556664603, 44.70389679500035, 43.30150365829468, 45.910371576036724, 47.41118941988264, 59.41607502528599, 52.2112968308585, 53.94109255926949, 54.92207397733416, 51.94955818993704, 48.56136989593506, 51.7848094531468, 47.39064359664917, 50.86306142807007, 52.807257720402305, 53.388332094464985, 48.79748010635376, 46.756717750004356, 27.637338842664445, 6.319204662527357, 1.5528722277709415, 0.3045427197856562, 0.15172743265117916, 0.11128309502133302, 0.16481828662965978, 0.15544504459415162, 0.20307932927140168, 0.15808309375175408, 0.18623323179781437, 0.10552050066845757, 0.11799757901046957, 0.1972832695714065, 0.14928907634956495, 0.21150144162986959, 0.1664832622877189, 0.17655281695936406, 0.15125213244131633, 0.17143206245132855, 0.1288568398782185, 0.09055086464754172, 0.07429896028978483, 0.15502349792846612, 0.18516945173697813, 0.22129377403429576, 0.1548883066113506, 0.18922714543129715, 0.14246024563908577, 0.29302686772176195, 0.2828065561396735, 3.5182666054793765, 51.96847466060093, 40.07142857142857, 30.229812485831125, 19.06927718435015, 9.94995413507734, 19.61915762083871, 34.8746589251927, 43.00999893460955, 54.845261641911094, 65.48945372445243, 75.48090771266392, 84.00689629146031, 90.68847165788922, 59.87328038896833, 0.4007663136082036, 0.22186448983848095], [0.1471965964883566, 0.05695209718708481, 1.3767018467187881, 45.06538030079433, 58.62004770551409, 33.406410762241904, 57.93112339292254, 42.69931370871407, 26.510295867919922, 65.31155899592808, 52.21174498966762, 61.0325734274728, 39.662520136152, 45.07377372469221, 34.963244983128135, 11.072551999773298, 3.439300545624324, 0.3226514623633453, 0.07761500842337098, 0.03579036093183926, 0.023597678668530922, 0.08172293406512056, 0.028601245089833225, 0.042931975929864814, 0.10483683592506818, 0.03311799486566867, 0.05062935521293964, 0.00295981894513326, 0.027005054222952043, 0.017371037609076927, 0.024075732034231936, 0.08433190799717392, 0.05748342403343745, 0.04551175928541592, 0.011532474475513612, 0.06481717979269368, 0.023727087170950005, 0.1174256554139512, 0.028925642504223754, 0.025512896345130036, 0.05282800205584083, 0.029402330318199735, 0.039937190378883054, 0.001648914098041132, 0.06463016875620399, 0.05134875161041107, 0.41204584549580303, 8.051871299743652, 28.577058383396693, 42.73961673464094, 50.64542647770473, 53.306121008736746, 51.99652106421334, 53.29413536616734, 55.60994216373989, 55.92141948427473, 53.234363487788606, 55.89771570478167, 52.862954480307444, 52.16397612435477, 52.85538441794259, 55.02757542473929, 50.611640862056184, 45.12871313095093, 41.36005537850516, 41.22454118728638, 39.29377228873116, 39.34766251700265, 41.86824662344796, 41.293707030160085, 41.22185918263027, 39.21160636629377, 41.237822668892996, 40.5929707799639, 39.954330580575125, 40.41208137784685, 40.45648384094238, 40.311547892434255, 42.03051137924194, 42.520164830344065, 45.60614470073155, 49.754500661577495, 44.94167457308088, 45.38506691796439, 45.127003874097554, 44.77595656258719, 42.91469744273594, 43.33721392495291, 42.14041451045445, 42.38916349411011, 41.57591506413051, 44.85128198351179, 42.86985376902989, 43.37577642713274, 45.058025632585796, 47.49013832637242, 43.55839245659964, 42.67673206329346, 38.47497919627598, 37.0329326902117, 36.81640945162092, 36.190741539001465, 37.651732308524, 38.33959354673113, 38.30450166974749, 38.454249245779856, 39.170115198407856, 38.63494757243565, 39.99378245217459, 38.294225284031455, 39.442779881613596, 38.823195116860525, 41.63104207175118, 39.22678123201643, 43.85260350363595, 49.325115885053364, 48.845367091042654, 48.45687593732561, 46.537484713963096, 48.546462535858154, 43.666179861341206, 45.48655578068325, 45.80750002179827, 45.92234679630825, 44.54949740001133, 34.95796087809971, 21.754198346819194, 10.853994676045009, 2.876932893480573, 0.5582511158926147, 0.1198732533625194, 0.09760367298232657, 0.05214106338098645, 0.04508518806791731, 0.053805574242557795, 0.04627324521009411, 0.007752850369018103, 0.015110940938549382, 0.03430466779640742, 0.018321207159065774, 0.046229099721780846, 0.07737621837960822, 0.0332495628057846, 0.0493622962385416, 0.07545423401253563, 0.07535862842840807, 0.04732748846124325, 0.0704181267480765, 0.056486635734992366, 0.0596240595249193, 0.002632165834906378, 0.027526040195620487, 0.054205322970769236, 0.0608008224517107, 0.02523110923357308, 0.04421155048268182, 0.05457643073584352, 0.03358123411557504, 0.07739604517285313, 3.730292405400957, 37.59821728297642, 17.505022287368774, 16.332115990774973, 6.7884760073253085, 7.175455493586404, 7.397311040333339, 12.018478887421743, 17.105382749012538, 39.189080306461875, 62.22801794324602, 75.5826084954398, 58.89755875723702, 42.128981249673025, 2.1791244404656545, 0.1889434363692999, 0.019551474268415144, 0.09661844013524906, 0.09364069599126067, 0.8142174865518297, 45.077748094286235, 72.96242891039167, 41.788196427481516, 65.32016086578369, 57.83847263881138, 37.12394366945539, 76.4306639262608, 60.65962886810303, 68.4151178087507, 49.37099831444876, 47.33131292888096, 37.739849363054546, 24.33920267650059, 3.2671055112566267, 0.3169847721500056, 0.07813418270753962, 0.05085204701338496, 0.05819009789930923, 0.03891269749562655, 0.00925449755907591, 0.03582446749455162, 0.02984123390966228, 0.03873958285631878, 0.03806817924071636, 0.10604861804417201, 0.05396741841520582, 0.019495844574911252, 0.03220849331202252, 0.034385209903120995, 0.022613105696759055, 0.02412631342719708, 0.024759870055796843, 0.046510101429053714, 0.018841972607853155, 0.10231663472950459, 0.07051374590290443, 0.04932212018008743, 0.04508377332240343, 0.022681778529658914, 0.0818169450919543, 0.024265771033242345, 0.1230197830923966, 0.091715033964387, 0.2697417714766094, 1.6360440105199814, 20.511787482670375, 43.635889189583914, 56.31286014829363, 54.643979276929585, 55.30584730420794, 56.49425329480852, 58.95465210505894, 57.01909589767456, 55.643158027103965, 57.03215503692627, 53.649949141911094, 53.971536091395784, 55.36934689113072, 57.94537762233189, 54.55677243641445, 47.31943498338972, 42.526442527770996, 43.094659260341096, 40.75846297400338, 42.162322180611746, 43.88551712036133, 43.13390963418143, 42.959711347307476, 41.25929260253906, 42.21512501580374, 42.57719217027937, 42.7351108278547, 41.816913332257954, 41.669687952314106, 42.548291138240266, 43.35219424111502, 45.874897548130576, 48.45505550929478, 51.44790519986834, 47.351806640625, 48.334320136478965, 46.09474202564785, 45.71103818075997, 44.38744803837368, 45.694699491773335, 44.484868730817524, 44.17232138769967, 44.27279928752354, 46.93416779381888, 45.93740701675415, 45.195648602076936, 45.790087836129324, 49.07662745884487, 44.002729756491526, 44.078697885785786, 41.00457511629377, 40.136845861162456, 38.801620960235596, 39.284128189086914, 39.85532917295183, 40.086784090314595, 39.60390165873936, 38.60759251458304, 42.350976194654194, 40.089459146772114, 43.04325301306588, 39.85914373397827, 41.860586234501426, 40.090692452022004, 43.58193642752511, 43.14903586251395, 48.18168558393206, 49.90735060828072, 52.08193874359131, 51.85996116910662, 48.491759368351524, 50.62533228737967, 47.74828127452305, 48.26744025094168, 49.48360429491316, 49.0524650982448, 49.272490228925435, 38.82821519034249, 18.05821180343628, 5.140910472188677, 1.1493299731186457, 0.2904821442706244, 0.11409103577690465, 0.14547277827348026, 0.059427691490522454, 0.06273269307400499, 0.04320556464205895, 0.04685678193345666, 0.05565043971208589, 0.04164399093549166, 0.027740438601800373, 0.04095976979338697, 0.06486116921795265, 0.05419010682297604, 0.03321887945224132, 0.06697667855769396, 0.022403060092723796, 0.027624353134472455, 0.07994571514427662, 0.04805810782792313, 0.018815170474616543, 0.03696987531813128, 0.04754741523148758, 0.030070012169224874, 0.009746954526885279, 0.12895209262413637, 0.021052408996703367, 0.053860688249447515, 0.07265270541289023, 0.1308434275644166, 0.2727232543485505, 9.403686761856079, 49.46407985687256, 29.364761761256627, 18.281537328447612, 7.180554168564933, 9.179256473268781, 6.617064816611154, 11.687755925314766, 19.189051968710764, 54.43791307721819, 71.92693192618233, 66.05145876748222, 57.57830081667219, 27.278386218207224, 0.6897670530847141, 0.05787544085511139, 0.03884245555049606, 0.3606669838939394, 0.48526995203324724, 2.76851515684809, 68.29740142822266, 98.11168384552002, 62.80342606135777, 74.95602689470563, 70.62060805729458, 47.04975455147879, 93.90932301112584, 70.27242687770298, 82.43615177699498, 56.56214414324079, 57.734065532684326, 47.02350425720215, 39.88519600459507, 5.7533763732228955, 0.4272845477930137, 0.2225885816982814, 0.2045937922916242, 0.18615589237638883, 0.28454827410834177, 0.08972229875091996, 0.15528903582266398, 0.1597040867699044, 0.11668498015829495, 0.11479268169828824, 0.1601012468870197, 0.1876054195953267, 0.09516499776925359, 0.12589233395244392, 0.17318109502749784, 0.14284796054874146, 0.13616980532450335, 0.08468387089669704, 0.12339471440230097, 0.09421285707503557, 0.23091523775032588, 0.1674110232187169, 0.14380989250327858, 0.14060093755168573, 0.10811135771551303, 0.1912458956773792, 0.1019342327490449, 0.19738574192992278, 0.2044690368430955, 1.3198196589946747, 17.41695213317871, 40.21002776282174, 50.711844308035715, 55.83069338117327, 57.52951751436506, 55.61679308755057, 56.962461130959646, 59.28829070499965, 59.828124046325684, 56.765993867601665, 61.33117921011788, 56.007208892277305, 57.171462944575715, 58.720622880118235, 59.65645490373884, 54.4222275188991, 50.61106068747384, 45.302143641880576, 45.80720124925886, 43.30565520695278, 43.71074560710362, 46.74858488355364, 46.110535281045095, 46.536105496542795, 41.70742014476231, 46.15010527202061, 46.6749826158796, 45.50091075897217, 44.34975058691842, 43.564955030168804, 44.71662589481899, 45.44236871174404, 47.26893547603062, 51.8018672806876, 55.10568012510027, 48.246974331992014, 51.066685335976736, 49.213458333696636, 49.69152218954903, 47.03427396501814, 45.74386147090367, 45.56522328513009, 48.89935111999512, 46.8445325578962, 48.59546818052019, 45.877075808388845, 48.28281661442348, 48.305429526737754, 52.48735223497663, 47.23745666231428, 46.54738589695522, 41.88755219323294, 43.11937747682844, 39.43244096211025, 40.612321513039724, 40.873417445591514, 42.005282470158164, 42.053520338875906, 40.914033140454976, 46.39322621481759, 43.46595014844622, 45.26109021050589, 41.25109372820173, 42.49534933907645, 43.371593611580984, 44.796043804713655, 44.14146096365792, 47.98283508845738, 53.46007571901594, 52.7695255279541, 51.926879269736155, 49.83916098730904, 53.00499650410244, 48.65452092034476, 48.80302129473005, 49.7776312146868, 48.72398553575788, 50.8120755468096, 47.2513495853969, 42.42738206045968, 24.970568111964635, 7.699040906769889, 1.1388195199625832, 0.2126390463007348, 0.1734151488968304, 0.18360198156109878, 0.23871782049536705, 0.20364524104765483, 0.1603589951992035, 0.13546896007444176, 0.11597493397338049, 0.20563722987260136, 0.09065345914236136, 0.13444277085363865, 0.17340308454419884, 0.08795229265732424, 0.21580236298697336, 0.18919445361409867, 0.14491745164351805, 0.14433233732623713, 0.1384002992085048, 0.16023729315825871, 0.19568849514637673, 0.1613544603543622, 0.1239602869110448, 0.19939036507691654, 0.14063098308231148, 0.20573497962738785, 0.2711604524935995, 0.1334235162607261, 0.25826375452535494, 0.6023275564823831, 11.985434123447963, 61.23236887795584, 38.62437241418021, 34.80352326801845, 11.430158410753522, 11.181775076048714, 6.181146562099457, 28.119423968451365, 37.29847199576241, 67.60547201974052, 79.657212802342, 89.84722546168736, 84.35027626582554, 63.29578236171177, 2.672238311597279, 0.33539844836507526, 0.20638346911541053], [0.04709328192153147, 0.09870541029210601, 0.0262941242461758, 9.865370239530291, 26.98768401145935, 40.83515024185181, 32.71862595421927, 38.206938539232524, 43.32835149765015, 63.15553297315325, 65.51660033634731, 61.86012472425188, 42.76774304253714, 61.44305215563093, 38.523199694497244, 17.565763439450944, 7.305089337485177, 0.12676636848066533, 0.12122337520122528, 0.029649350991738693, 0.034848055602716546, 0.05092811078897544, 0.08647787677390234, 0.034575980023614, 0.0436264904482024, 0.04332767380401492, 0.06463675054588489, 0.03806556009554437, 0.15613898235772336, 0.07521657033690385, 0.05040152011705296, 0.005029114537007574, 0.07567375366176878, 0.059020896176142354, 0.05580557995874967, 0.022945635353348086, 0.019082206234868084, 0.08383728989533015, 0.03489875573930996, 0.030318613829357282, 0.05640982557088137, 0.02004837733693421, 0.1330759706241744, 0.03018768031948379, 0.053049431781151464, 0.044375776313245296, 0.03428818957347955, 0.06244089587458542, 1.9133241432053703, 21.48863298552377, 46.290486676352366, 47.94829559326172, 55.65255199159895, 54.62546580178397, 54.87869984763009, 53.53172901698521, 54.10676540647234, 52.41539321626936, 53.99931846346174, 52.51538821629116, 52.28935636792864, 51.947664805821006, 54.20569733210972, 42.128543513161794, 43.705913134983604, 41.48214912414551, 39.62317943572998, 39.56688860484532, 39.97733606610979, 38.940091609954834, 40.57731648853847, 39.88501187733242, 40.47747087478638, 38.15440320968628, 39.02749994822911, 37.652218682425364, 38.23847988673619, 39.63068001610892, 40.80758326394217, 44.450044359479634, 44.701999936785015, 43.8495636667524, 47.00055088315691, 41.98329489571707, 42.85122912270682, 42.53310932431902, 44.02525234222412, 42.22187866483416, 47.651152406420024, 43.6294447353908, 43.91115597316197, 45.0047607421875, 43.081266607557026, 42.25500420161656, 44.85990122386387, 43.909919193812776, 45.319687843322754, 40.763177326747346, 38.610924175807405, 33.982107230595176, 37.46191099711827, 37.00635583060128, 39.34759303501674, 37.2977910723005, 39.3542355128697, 37.87026357650757, 37.85806253978184, 37.64902251107352, 39.80621930531093, 37.07199893678938, 39.94467258453369, 37.350475788116455, 42.960388796670095, 40.160434995378765, 45.74577569961548, 45.98688861301967, 48.08814893450056, 49.4854907308306, 45.65354878561837, 46.04830721446446, 45.97221401759556, 45.05575704574585, 47.35919952392578, 44.11729512895857, 39.79758964266096, 20.765754563467844, 6.900358072349003, 1.4897709680455071, 0.3622035671557699, 0.18740090914070606, 0.05414515727066568, 0.08905584844095366, 0.02928921513791595, 0.015202088547604424, 0.01646887101898236, 0.03476702495078955, 0.05043948754402144, 0.003750211309774646, 0.07232595008930989, 0.0690240426255124, 0.02173636042113815, 0.042643303384206126, 0.015276174393615552, 0.024845204316079617, 0.07490480385188546, 0.03619802477104323, 0.033839525255773745, 0.030344713678849593, 0.02470580947452358, 0.037412300506340604, 0.026731173740699887, 0.07745688940797534, 0.07441228920859949, 0.07687927968800068, 0.05596712218331439, 0.029523092588143687, 0.05002875333385808, 0.08691079568650041, 0.08902728890201875, 10.129380941390991, 38.53005061830793, 16.833972215652466, 7.886577997888837, 2.9825144623007094, 2.5013048095362524, 3.871999178613935, 17.224615573883057, 35.61486094338553, 40.43619510105678, 35.41525656836373, 31.603162152426584, 20.885432073048182, 1.437001571059227, 0.3854139974074704, 0.03068867325782776, 0.04777977615594864, 0.03200288363067167, 0.07139936980924436, 0.06272844544478826, 13.528162632669721, 40.57722616195679, 49.94462769372122, 47.412120478493826, 50.88041107995169, 51.80767250061035, 67.88756888253349, 72.37171391078404, 70.49370615822929, 50.03321722575596, 60.13125310625349, 45.04342746734619, 25.672520296914236, 5.533202724797385, 0.09170144290796348, 0.05826379358768463, 0.009523500222712755, 0.015303975669667125, 0.09176597158823695, 0.02540841043394591, 0.04416317432852728, 0.04107424543638315, 0.04850622931761401, 0.03487313425700579, 0.08473567704537086, 0.08467290577079568, 0.06710937286594085, 0.08805051738662378, 0.028152930217662027, 0.05021508922800422, 0.08726658552352871, 0.08436447089271885, 0.026265395073486224, 0.06365651171654463, 0.012702571643915559, 0.07259617666048662, 0.03429467636825783, 0.07671103014477662, 0.018338901656014577, 0.07646310701966286, 0.05859276772077594, 0.010670211681696986, 0.044630491573895724, 0.023690946699519242, 0.07043079499687467, 1.504788087947028, 13.202574389321462, 43.782937390463694, 52.92414379119873, 56.97313008989607, 56.07718767438616, 57.39230101449149, 56.033570357731406, 55.531622069222585, 55.138743128095356, 55.8877763066973, 56.21673876898629, 54.29431813103812, 54.071009976523264, 55.75187301635742, 46.50246579306466, 44.85087898799351, 43.165482248578755, 41.42152261734009, 43.77241434369768, 41.4084461075919, 42.893383843558176, 41.45979676927839, 43.28995227813721, 42.62442602430071, 41.06704289572579, 41.702295848301475, 40.77907133102417, 42.07341650554112, 42.89592688424246, 43.9054410798209, 45.21946702684675, 47.66519818987165, 44.72344207763672, 48.87141241346087, 43.57561009270804, 45.10264348983765, 45.66022253036499, 46.122788429260254, 45.69888925552368, 48.656216280800955, 46.03437955038888, 47.161999225616455, 47.21619864872524, 45.55927562713623, 44.606403146471294, 46.21262516294207, 46.12025581087385, 45.62199354171753, 42.09121084213257, 39.3777551651001, 36.5574883052281, 38.51142249788557, 40.084991455078125, 40.42335830415998, 38.41946308953421, 39.76242133549282, 40.725128991263254, 40.29262099947248, 40.55565200533186, 42.00521993637085, 38.84977197647095, 41.27213634763445, 39.126327650887625, 44.788334778376985, 43.76117563247681, 48.88178259985787, 49.82518121174404, 52.208187511989046, 52.17720896857125, 49.312039375305176, 47.49769449234009, 46.899478912353516, 48.339989866529194, 51.40982212339129, 46.39650229045323, 45.06382737840925, 20.465542009898595, 4.415762160505567, 1.1513604755912508, 0.29992357907550676, 0.10766406743121998, 0.03464759600215724, 0.08916264306753874, 0.048433788919023106, 0.015330810033317124, 0.025293101889214346, 0.04775816481560469, 0.04398346093616315, 0.010624701489827462, 0.06253745140773909, 0.09175086061337165, 0.03680212789082101, 0.061691705004445145, 0.047215173952281475, 0.06516359227576426, 0.0775401456547635, 0.04264903021976352, 0.012680288553903145, 0.08430042397230864, 0.010916002510514642, 0.032728824498397965, 0.042123776261827776, 0.022062096245852963, 0.03456806830529656, 0.03884231984349234, 0.017003254665594016, 0.06634368002414703, 0.029006252464439188, 0.0773094573191234, 0.3390978212867464, 18.939811400004796, 49.47291101728167, 28.793767486299785, 14.950706413814, 3.3095422855445316, 6.695320206029074, 2.4378658022199358, 16.281239543642315, 46.23218434197562, 46.70522117614746, 32.00791903904506, 30.553251130240305, 7.397757462092808, 0.6709724473101752, 0.09530530524040971, 0.03452135456193771, 0.023241040662729313, 0.16672377581042902, 0.24002736593995774, 0.25691368696945055, 30.510578768593923, 74.98337500435966, 84.6848737171718, 66.22368376595634, 65.68771362304688, 62.609751973833355, 79.27086516789028, 81.78069346291679, 77.58045877729143, 55.68677881785801, 71.60529286520821, 57.194951329912456, 44.849187101636616, 11.809883543423243, 0.21672400353210314, 0.25526989517467363, 0.12771806812712125, 0.13745227722185, 0.13585330945040497, 0.1407464426010847, 0.1113197969804917, 0.1042206311332328, 0.11828830412455968, 0.14893238406096185, 0.1110680333471724, 0.24484496457236155, 0.13439216571194784, 0.14573762406195911, 0.14903454429336957, 0.16487360080438002, 0.18022112654788153, 0.1276498617870467, 0.08607718148933989, 0.32261642281498226, 0.2799938384975706, 0.13709766125040396, 0.09676342271268368, 0.15870117130024092, 0.1518185463334833, 0.19597098284534045, 0.11511630219008241, 0.152185375935265, 0.100104074526046, 0.1807883411113705, 0.11465989239513874, 6.531682312488556, 36.421595437186106, 52.05370821271624, 53.835674490247456, 59.423863955906455, 58.52494771139962, 57.26996408190046, 54.87819957733154, 56.419153690338135, 54.35239117486136, 58.14610760552542, 58.04845414842878, 54.39634200504848, 54.771791390010286, 58.059355872017996, 46.40539598464966, 47.78727456501552, 46.1860031400408, 43.93315396990095, 45.79791150774275, 45.5407760483878, 44.747576645442415, 44.52962555204119, 46.5657708304269, 46.55611630848476, 42.93140091214861, 43.45775474820818, 43.52054214477539, 45.69132614135742, 46.0805538041251, 45.3331812449864, 48.51370872770037, 50.550722530909944, 48.056475571223665, 50.998572145189556, 45.98622506005423, 47.1411372593471, 48.764264242989675, 48.980033602033345, 47.434594426836284, 52.19242204938616, 47.77301338740757, 47.36086361748831, 48.2161625453404, 46.724339144570486, 48.293700967516216, 48.98402534212385, 48.55030141557966, 48.406515393938335, 45.47998973301479, 41.8197204044887, 38.01979923248291, 41.036613259996685, 42.16928080150059, 44.32656444822039, 39.99033267157418, 42.59431947980608, 42.100674288613455, 41.85276256288801, 43.3387633732387, 43.394772802080425, 40.536193575177876, 43.15590763092041, 40.33901759556362, 46.672314507620676, 44.90943145751953, 50.8983131136213, 51.29581608091082, 54.44786984579903, 54.28287097385952, 49.103336334228516, 47.937317439488, 49.42526027134487, 50.82089281082153, 49.98483344486782, 50.486771311078755, 45.86103241784232, 36.52517223358154, 17.49757902962821, 3.7204520191465105, 0.39042025591645924, 0.19223705892051968, 0.18559441821915762, 0.16754183119961194, 0.11682570832116262, 0.06355117594024964, 0.1190566500382764, 0.07860457710921764, 0.15491046756505966, 0.13852662885827677, 0.23389718202607973, 0.18029271199234895, 0.11952918182526316, 0.12064052719090666, 0.10638730201338019, 0.13439804182520934, 0.13965229131281376, 0.2428348452917167, 0.07039884278284651, 0.2060159066958087, 0.14592659606465272, 0.09587374795228243, 0.07283156045845576, 0.24013004185897963, 0.18187321004058632, 0.16780597131167138, 0.10246582422405481, 0.1671811355543988, 0.09637256618589163, 0.1756090290312256, 0.4811489103095872, 24.592464515141078, 59.1729645047869, 37.99953828539167, 31.886422838483536, 3.69383043050766, 7.672072342463902, 8.153654592377798, 43.605723585401265, 79.99544416155133, 80.90204511369977, 64.36862591334751, 61.539277757917134, 37.31532832554409, 2.290606766939163, 0.4341883159109524, 0.11132331857723848, 0.2361219355038234], [0.05981103663465806, 0.1447071736412389, 0.022322382279006497, 0.7761923841067723, 7.212433806487492, 4.645598581859043, 23.151767696653092, 39.34390006746565, 48.162268842969624, 51.369157791137695, 55.51612063816616, 48.08121115820748, 33.840881620134624, 69.4734604699271, 52.76070826394217, 17.01080560684204, 11.030737740652901, 0.010062544556733753, 0.020997086340295415, 0.05901238056165831, 0.09349489917180367, 0.0516587369410055, 0.02983704734859722, 0.0612310611509851, 0.030566540347146134, 0.03670351978923593, 0.022849933077980365, 0.024611879871892076, 0.0333964554592967, 0.019683929393067956, 0.00796309020370245, 0.07278689928352833, 0.04708484433857458, 0.020818804656820636, 0.06602796446532011, 0.05569264119757073, 0.05524249088817409, 0.044315345984484465, 0.023432855727151036, 0.03475996479392052, 0.06399560959211417, 0.03518882267443197, 0.018803297808127742, 0.038838944131774564, 0.12337196990847588, 0.06009920367172786, 0.046549972146749496, 0.007512326668282705, 0.3149424360266754, 0.739823232804026, 20.949798447745188, 50.98770516259329, 52.85761826378958, 56.571756975991384, 52.79251364299229, 52.81000573294503, 53.38778666087559, 53.755665983472554, 51.35852009909493, 52.56063835961478, 52.09820447649275, 56.65877621514456, 52.43713412966047, 49.59056486402239, 44.387024198259624, 41.49007701873779, 40.388269901275635, 39.858073711395264, 39.11534949711391, 39.81047855104719, 38.96552201679775, 40.25538212912423, 39.146651131766184, 39.993956157139365, 37.49599191120693, 36.09767041887556, 37.656873975481304, 37.516343184879844, 39.48706769943237, 42.19824089322771, 40.82541928972517, 44.53414535522461, 41.961088453020366, 41.58538198471069, 41.94656324386597, 42.95766510282244, 44.90909794398716, 43.891937255859375, 42.889607497623985, 45.46420342581612, 44.5223959514073, 42.59098087038313, 40.46257046290806, 39.993143217904226, 42.875735419137136, 43.27890116827828, 39.65661416734968, 39.88714497429984, 35.278762681143625, 34.8263897895813, 34.24569409234183, 35.24944128308977, 36.9483904838562, 36.566197872161865, 37.31333071844918, 36.52098594393049, 38.41521079199654, 38.722633838653564, 38.78157540730068, 38.304053510938374, 36.73323951448713, 38.38323865618025, 42.64358568191528, 43.36641025543213, 44.01333965573992, 47.012626852308, 47.41694252831595, 49.690031800951274, 45.28093426568167, 46.28910051073347, 43.34427329472133, 45.47602925981794, 45.04555709021432, 39.85309532710484, 31.208765029907227, 8.135097690990992, 0.7327109915869576, 0.20123885731611932, 0.05398316042763846, 0.07636893314442464, 0.0025108289306185073, 0.016662165289744735, 0.06144942729068654, 0.05693750189883368, 0.02085182217082807, 0.050928816465394836, 0.01856545262437846, 0.049023876897990704, 0.04961978331474321, 0.08132387404995305, 0.08878898061811924, 0.08459349681756326, 0.035398506958569796, 0.11013858286397797, 0.028088700092796768, 0.037915295122989585, 0.01881149790382811, 0.01759940365861569, 0.09456101339310408, 0.015761199706633176, 0.14076694792934827, 0.14813069493642875, 0.030408451865826334, 0.12799994514456817, 0.04911768775699394, 0.0656679677111762, 0.16062917427292892, 0.14659557731023856, 0.561587988265923, 18.326257671628678, 37.37447139195034, 21.128337621688843, 4.329701338495527, 2.5117800874369483, 1.065082956637655, 2.7140173954623084, 15.352692706244332, 10.187196033341543, 12.260607974869863, 14.951123305729457, 6.3341463293348035, 0.21404961203890188, 0.12014280818402767, 0.08267077284732036, 0.12916462336267742, 0.19972420430609159, 0.030204965999083858, 0.11464550745274339, 0.0538104427313166, 0.7282981798052788, 19.445575986589702, 16.478662184306554, 32.71513101032802, 51.99761193139212, 62.27174295697893, 59.61794103894915, 66.38122722080776, 56.82650572913033, 43.0902784211295, 75.25554983956474, 67.61153084891183, 25.23346015385219, 6.591664373874664, 0.020047581754624844, 0.05785012471356562, 0.020813608774915338, 0.043978212467793903, 0.046406648587435484, 0.06102734458233629, 0.01811158224674208, 0.029289384771670614, 0.003143323015787506, 0.022888485741402422, 0.02960896458742874, 0.02755887620151043, 0.05890377424657345, 0.04319656387503658, 0.03905534591259701, 0.010540611493135137, 0.09316504972853831, 0.03143091592937708, 0.09429776216191904, 0.04234442227919187, 0.03233150831822838, 0.012387757688494665, 0.06597155106386968, 0.07824992721102067, 0.022925915429368615, 0.05907099920191935, 0.01969037208307002, 0.0681659197434783, 0.03801344182076199, 0.014240031064088856, 0.08003159732158695, 0.14757744462362357, 1.0473381259611674, 15.243866545813423, 47.92743362699236, 55.20999343054635, 58.07798399244036, 56.26420191356114, 53.49199226924351, 54.85027824129377, 53.87626586641584, 53.55526603971209, 54.19273199353899, 54.7423449243818, 56.86871950966971, 51.95752777372088, 52.67717702048165, 48.301552431924, 43.4874826158796, 42.26095880780901, 41.45547846385411, 40.90354830878121, 42.42908089501517, 41.81484624317714, 41.193659918648855, 40.72213431767055, 42.59668186732701, 40.047509397779194, 39.37795318875994, 38.17386163984026, 40.736961773463655, 43.96935061046055, 45.60862520762852, 42.93566015788487, 46.60748086656843, 43.978914805821006, 42.95034864970616, 44.45338991710118, 43.649962765829905, 45.96267066683088, 47.43520934241158, 44.50930207116263, 47.98395722252982, 45.22998659951346, 44.07566499710083, 41.36243861062186, 42.132538727351594, 46.00800766263689, 45.216555731637136, 41.67766448429653, 42.460934911455425, 38.71758597237723, 37.57613590785435, 37.58398389816284, 39.12775897979736, 38.930152211870464, 36.9603830746242, 38.47762645993914, 37.44643041065761, 40.687459332602366, 41.74968951089041, 41.53348241533552, 41.30988591057913, 39.98189755848476, 41.18915401186262, 45.48232085364205, 47.27300712040493, 47.756969996861045, 49.66012328011649, 50.64524582454136, 50.323936803000315, 46.48356669289725, 48.565566607883994, 47.333647523607524, 48.96675559452602, 49.4821903364999, 46.78585154669625, 26.778025593076432, 4.770737375531878, 0.34545447304844856, 0.16106103467089788, 0.06387894906635795, 0.06146687242601599, 0.030455942531781535, 0.08170721240873847, 0.01535433144973857, 0.03675773134455085, 0.0745746490678617, 0.006274493045306632, 0.05265714354547007, 0.028557672963610718, 0.021429425105452538, 0.07587317510374955, 0.020546776575169394, 0.0529714986415846, 0.02324262334566031, 0.08104517936174359, 0.043981360870280435, 0.007606052710408611, 0.10769825881080967, 0.06368363954659019, 0.02267673022912017, 0.017869419883936644, 0.15333716198801994, 0.07453986057745558, 0.032572110050490925, 0.11126724444329739, 0.0835648105878915, 0.08902386230017457, 0.2561010734311172, 0.2627095973917416, 1.801418628011431, 33.300902366638184, 48.457452637808665, 30.6212739944458, 9.411625947271075, 4.164652960641043, 3.5978367243494307, 2.8599532331739153, 16.62383610861642, 12.189363752092634, 1.1400890861238753, 5.897698274680546, 1.4363501774413245, 0.1989645707820143, 0.005646186157329274, 0.04198245098814368, 0.08301896987748997, 0.026353038049169948, 0.1446228860212224, 0.19927725328930787, 0.12989704763250692, 1.924847947699683, 40.94488661629813, 47.01855019160679, 65.63194043295724, 68.92823532649449, 76.58122444152832, 67.9405766895839, 72.75898565564836, 64.5107513155256, 52.00158282688686, 86.73967143467495, 73.76452200753349, 42.49626302719116, 18.75580746786935, 0.102363915049604, 0.14415586393858704, 0.12889224583549158, 0.2062682674399444, 0.15057537518441677, 0.16654670531196253, 0.10879081554178681, 0.11305897044284002, 0.1339890616280692, 0.0849156788151179, 0.1534528522086995, 0.12146000750362873, 0.10363979158656937, 0.11241017561405897, 0.12802772436823162, 0.17623169347643852, 0.169792504715068, 0.23953130255852426, 0.1614672193037612, 0.15310222602316312, 0.1250176073185035, 0.21120650959866388, 0.15858620032668114, 0.13875737147671835, 0.13860343902238778, 0.1107305639556476, 0.1576298595006977, 0.2709368887756552, 0.11216636441115822, 0.11224434165550129, 0.1581691862749202, 0.4109934376818793, 4.49977456671851, 31.876031807490758, 53.29045629501343, 57.01572602135794, 59.23750632149832, 55.36577899115426, 56.18109451021467, 54.9048285484314, 56.35741547175816, 55.99411153793335, 56.21024567740304, 57.84312098366873, 59.51419053758894, 55.1432455607823, 53.990212849208284, 50.30529478618077, 45.435298919677734, 44.60158109664917, 44.53773062569754, 43.16594777788435, 45.07620906829834, 44.53904383523123, 44.78211614063808, 43.29024062837873, 45.50697653634207, 43.09071963174002, 40.08542571749006, 43.49345459256853, 41.97585684912545, 44.476944310324534, 47.124260084969656, 45.84257105418614, 49.05280555997576, 47.371661118098665, 47.1739501271929, 46.61831658227103, 47.46006652287075, 49.12862082890102, 48.88785879952567, 46.11013228552682, 50.037688391549246, 49.3772725377764, 46.38626411982945, 44.912103039877756, 44.07890633174351, 48.51953479221889, 48.46925067901611, 44.82288816996983, 43.973769664764404, 39.724223613739014, 40.79556288037981, 40.37252180916922, 42.64138657706124, 41.72850445338658, 38.577659675053184, 40.35069751739502, 39.66757147652762, 43.11085203715733, 43.11424970626831, 43.922154971531455, 43.389516489846365, 41.358568464006694, 42.278617654527935, 46.17782858439854, 47.732703413282124, 48.75097581318447, 51.0949957711356, 53.239439146859304, 51.26071378162929, 49.448932783944265, 49.765030656542095, 49.24663250786917, 48.083660398210796, 53.914692878723145, 44.91385746002197, 37.546804087502615, 15.834909847804479, 2.7580913390432085, 0.3130387110369546, 0.1866240408271551, 0.1520641352981329, 0.14046352063970907, 0.13915632292628288, 0.20721980423799582, 0.09671128408185073, 0.13366299841020787, 0.09147709208939757, 0.13919600365417345, 0.10868999880871602, 0.09882827262793269, 0.28334273451140946, 0.19120023027062416, 0.2545549363962242, 0.057690560418580256, 0.29439034312963486, 0.10487724268542868, 0.19597903027066163, 0.13268731933619293, 0.15421532200915472, 0.20438553632370063, 0.16487267799675465, 0.31985125690698624, 0.2712558816586222, 0.1743434662265437, 0.27371861093810623, 0.18454135901161603, 0.21744935746703828, 0.33538970883403507, 0.5125161728688649, 1.6134375035762787, 41.820206778390066, 54.75075224467686, 42.65346949441092, 19.368661165237427, 4.88256732906614, 4.116372534206935, 6.202783686774118, 34.65682247706822, 48.08334425517491, 39.547728947230745, 42.597804001399446, 15.899767807551793, 0.2596164547971317, 0.3224373438528606, 0.24372462183237076, 0.20857439083712442, 0.25393798521586824], [0.09728867667061941, 0.01934045666296567, 0.12968249485961028, 0.03901084419339895, 2.1573279414858137, 4.046666034630366, 3.2815605870315006, 21.522470712661743, 43.20214441844395, 50.654629366738455, 34.7771201133728, 34.16097123282296, 28.95010369164603, 27.905414240700857, 19.932806253433228, 18.19559506007603, 7.14419207402638, 0.5626497055803026, 0.06651551223226956, 0.11039650080991642, 0.008447188468250846, 0.08703185311917748, 0.050853071601263115, 0.0575082041323185, 0.026865964722154394, 0.03545780074117439, 0.016997768709968244, 0.06985313099409853, 0.03359293205929654, 0.052249554345118146, 0.03508466076371925, 0.01099278383688735, 0.038153555909437795, 0.10704131477645465, 0.07245342646326337, 0.06257250452680246, 0.07137640139886312, 0.02755778206379286, 0.0613451228876199, 0.005044876481406391, 0.026707820261695554, 0.03180780142013516, 0.020365913065948656, 0.015034710921879326, 0.03268784437594669, 0.02677643541911883, 0.03812292344602091, 0.05228021734261087, 0.07151980977505445, 0.31334451319915907, 1.9733003420489175, 25.722632442201885, 52.91868250710623, 54.07443196432931, 56.90580551964896, 51.9032484463283, 52.87111513955252, 54.66669293812343, 53.58139474051339, 51.884550843920024, 52.506647382463726, 52.994619369506836, 51.244809355054585, 49.06283181054251, 48.38841881070818, 44.953201634543284, 38.56567055838448, 39.48642151696341, 39.48516041891915, 39.73662962232317, 38.58587939398629, 38.33115495954241, 37.681752000536235, 37.52928073065621, 38.03870528084891, 36.943669182913645, 37.37957831791469, 38.28805528368269, 42.969664641789024, 47.296655314309255, 42.43385778154646, 39.56269884109497, 38.06368752888271, 37.394652434757774, 39.545561109270366, 38.63895320892334, 41.235352584293906, 41.81811884471348, 41.375324044908794, 41.0341466494969, 38.12070792061942, 37.61057118007115, 36.565374510628835, 36.23612022399902, 37.68749121257237, 39.5859648840768, 39.36348703929356, 43.363867214747835, 39.86523035594395, 34.03544855117798, 35.11528199059622, 33.95532192502703, 34.41446583611624, 35.70453439440046, 36.87379462378365, 36.48388951165335, 36.302277496882844, 36.31309584208897, 40.825217791966026, 36.19567128590175, 36.877897535051616, 39.32476472854614, 45.034030028751914, 48.92646993909563, 47.54660633632115, 47.98845965521676, 45.15525524956839, 44.64089400427682, 41.40916524614607, 44.71380492619106, 47.20007535389492, 46.79409211022513, 42.33777461733137, 33.96376051221575, 11.618052465575081, 1.3933395253760474, 0.4525890185364655, 0.04543359883661781, 0.05172877532563039, 0.20564548085842813, 0.06544213768626962, 0.052164279456649504, 0.05604049217488084, 0.04429072534133281, 0.035017512938273807, 0.020033659912379723, 0.09312604753566639, 0.05975005669253213, 0.02576482113051627, 0.03641362248786858, 0.03714660654908844, 0.055834078429532905, 0.10336951073259115, 0.06251007251973663, 0.10370603017508984, 0.03746934833803347, 0.047488077344106774, 0.032380427300397835, 0.03956684596570475, 0.0434737250741039, 0.06714512487607342, 0.01406744568209563, 0.024446230814126984, 0.09143521290804658, 0.0605241023004055, 0.047660001154456816, 0.07450804407043116, 0.34228677302598953, 3.2461262941360474, 30.779355934688024, 38.74216175079346, 22.275056157793315, 7.4507531097957065, 2.145561384303229, 1.4452532082796097, 4.924120596476963, 2.9556236309664587, 8.138789790017263, 3.4591593657221114, 0.04856798957501139, 0.2746720612049103, 0.03384258884138294, 0.1180954644722598, 0.14711909421852656, 0.1787899469158479, 0.04255082245383944, 0.06762231141328812, 0.09596951638481446, 0.20041089531566414, 0.13610814006200858, 2.4597448110580444, 11.355751020567757, 6.454340611185346, 31.553941113608225, 54.805775029318674, 60.24301488058907, 42.96819857188633, 47.72756174632481, 37.92160381589617, 41.64967366627285, 30.76483072553362, 25.846940926143102, 18.835280963352748, 1.325202233025006, 0.1126697084733418, 0.11257425895226852, 0.04153163571442876, 0.051776360986488204, 0.04004454818953361, 0.044201084080019167, 0.03829793119803071, 0.020134471556437866, 0.006926255192541118, 0.021003386537943567, 0.03571325560499515, 0.07694735710642167, 0.044328777585178614, 0.03338309510477951, 0.031959888259215016, 0.04503759562170931, 0.054170354668583186, 0.02221104146779648, 0.052673445349293094, 0.015911814124722565, 0.029269449412822723, 0.02192732901312411, 0.0642427931140576, 0.04428161261603236, 0.07661697162049157, 0.024538036602150117, 0.03149959724396467, 0.020272190416497842, 0.05213660879858902, 0.034998178082917414, 0.05047486296721867, 0.2520365672452109, 1.2078677862882614, 16.361977611269268, 49.790877955300466, 55.04108272280012, 58.28763198852539, 55.696683474949424, 54.02438061577933, 55.3209422656468, 56.55375419344221, 54.289617674691335, 56.49656009674072, 55.25009148461478, 52.6633084160941, 51.71479593004499, 52.99698870522635, 47.62762233189174, 43.39750344412667, 41.008393151419504, 41.47691365650722, 39.958694049290244, 42.207777295793804, 41.385117530822754, 40.80234432220459, 39.70141615186419, 40.078293391636436, 39.28979097093855, 40.60344518933977, 42.664527552468435, 45.90167243140084, 47.77305507659912, 46.560184478759766, 42.9056647845677, 38.50750371388027, 39.004466669900076, 38.7368290083749, 40.30172661372593, 42.78496067864554, 44.42284911019461, 45.55677774974278, 43.63898808615548, 40.95684446607317, 39.4896593775068, 38.898631708962576, 38.64669697625296, 37.36443819318499, 42.237466948372976, 43.96044649396624, 46.05988638741629, 43.71866307939802, 37.457578795296804, 37.205751759665354, 38.151356424604145, 38.2001953125, 36.878008706229075, 39.17512137549264, 38.65370076043265, 40.898948601314, 41.060178075517925, 41.762939725603374, 38.41682972226824, 39.57429191044399, 41.092706067221506, 49.96674380983625, 53.08859722954886, 50.8867096219744, 54.00648900440761, 48.1201627595084, 49.073629311152864, 45.11331592287336, 48.70781012943813, 50.07257529667446, 50.40815939222063, 46.7712846483503, 26.71673379625593, 6.578797612871442, 0.5189618755664144, 1.004002102783748, 0.031117690594068596, 0.11876083591154643, 0.04750851821154356, 0.09699882686670337, 0.03914446809462138, 0.0067265941428818875, 0.055194779698337824, 0.03990141801269991, 0.045453296708209176, 0.010274461221082934, 0.08728055655956268, 0.020103638925190483, 0.031368107335375886, 0.05959843125726495, 0.07332353905907699, 0.06616272152002368, 0.014226607945082443, 0.011108410444908907, 0.06507312998707805, 0.09160780507539, 0.026396728919020722, 0.024277753961671675, 0.039777819466378005, 0.03553334204480052, 0.02825213543006352, 0.038940246017383676, 0.07939455471932888, 0.07018823908375842, 0.0699894961767963, 0.24031853888716015, 0.5576940115009035, 7.620002542223249, 43.76240198952811, 45.6741293498448, 28.107641560690745, 9.17558695588793, 3.7847337126731873, 1.8663113287517001, 3.208298998219626, 10.259966254234314, 11.348990423338753, 7.403190953390939, 0.25196580961346626, 0.1915551855095795, 0.0019897835861359325, 0.04888992729995932, 0.08401025525693383, 0.08166645281016827, 0.054958055793706856, 0.2136458158493042, 0.18801982807261602, 0.32490368293864386, 0.21972692811063357, 5.742258386952536, 21.666105610983713, 31.489694595336914, 55.709058216639924, 68.06761755262102, 73.2293370110648, 48.378184114183696, 50.85231603894915, 48.54337058748518, 42.884111472538535, 35.31717579705374, 38.72834873199463, 37.47120768683297, 2.541233718395233, 0.2720980793237686, 0.2161199173757008, 0.09255263116210699, 0.16509588887648924, 0.1273189673998526, 0.11760360800794192, 0.14800522024078028, 0.09713513776659966, 0.1680511531553098, 0.07801533729902335, 0.09482532992426838, 0.17814924700983933, 0.1374018620699644, 0.14277644295777592, 0.14806343854538032, 0.18420523990477833, 0.2024429855602128, 0.18127177017075674, 0.25536594859191347, 0.0757315716307078, 0.09934799652546644, 0.13257628386574133, 0.18011059319334372, 0.3029569291642734, 0.2601349912583828, 0.09331519595746483, 0.12248990152563367, 0.15658639477831976, 0.16205322928726673, 0.14037012707974228, 0.25322023087314194, 0.43016623173441204, 4.642685549599784, 32.97580310276577, 55.35389757156372, 59.744884627205984, 59.51444067273821, 55.07938814163208, 54.700162410736084, 59.38106305258614, 57.39841195515224, 57.60383544649397, 57.65238945824759, 58.28943157196045, 54.96644517353603, 54.90458883558001, 50.42711060387747, 47.73461764199393, 44.632396357400076, 44.3992669241769, 44.08070591517857, 43.761561257498606, 44.4893468448094, 43.484366348811555, 41.36446401051113, 43.13513599123274, 43.16035100391933, 43.568522930145264, 42.853730474199565, 45.066940171378, 48.53792667388916, 51.65848772866385, 49.636370863233296, 45.786016191755024, 42.60287618637085, 41.97425181525094, 42.129290444510325, 43.702366079602925, 45.61658089501517, 45.64766713551113, 47.654925278254915, 46.876511641911094, 41.20917524610247, 43.004388264247346, 41.20918914249965, 40.910927295684814, 40.565692152295796, 45.34265858786446, 44.27755185535976, 49.49543012891497, 45.66880355562483, 40.853490012032644, 41.26106786727905, 41.072399956839426, 39.77343075616019, 38.85387488773891, 41.18821600505284, 41.06105007444109, 42.168763160705566, 41.96963473728725, 44.57979849406651, 41.61795513970511, 40.42444222314017, 42.45848567145211, 47.904928411756245, 54.657674176352366, 51.84109680993216, 54.58392252240862, 48.873281478881836, 49.8887745993478, 44.45589821679251, 48.57444640568325, 50.62239319937569, 55.175071784428184, 45.591143539973665, 39.31006581442696, 20.427290439605713, 2.158808993441718, 2.825299092701503, 0.0964765991749508, 0.19157471374741622, 0.5125443456428391, 0.24454915044563158, 0.19673474186233111, 0.241202995713268, 0.17726450519902365, 0.17679688600557192, 0.10674355325422116, 0.13764135779014655, 0.19346439306225094, 0.1301199056740318, 0.12879331542977265, 0.1323859276516097, 0.14856638227190289, 0.3043263756803104, 0.1624570797596659, 0.1263859003250088, 0.17248757795563766, 0.28235872302736553, 0.16122438519128732, 0.1640314981341362, 0.12064180283674172, 0.16238991836352007, 0.14626871342105524, 0.1516278237104416, 0.17672764829226903, 0.22421321166413172, 0.09088233578950167, 0.45507340665374485, 0.5843294422541345, 9.13660843031747, 57.31952558244978, 55.62867450714111, 42.560374055589946, 13.01410710811615, 2.6046436301299503, 1.7728127858468463, 6.664800677980695, 40.40156527927944, 38.512954575674875, 10.790254507746015, 0.22346486896276474, 0.7487435798559869, 0.08134997050677027, 0.18960055682275975, 0.21988733378904207, 0.22314781668995107, 0.12442303422306265], [0.0561174753654216, 0.05166796840993421, 0.07007905601390771, 0.03313894463436944, 0.2166217075926917, 0.592650018632412, 1.6364301783697945, 5.660589260714395, 39.38772235597883, 57.92516878673008, 39.480216775621685, 25.713625839778356, 25.873177324022564, 8.945792657988411, 26.08326131956918, 21.518918446132115, 27.02754235267639, 9.545553343636648, 0.09739604805197034, 0.08179257889943463, 0.04079152025016291, 0.031914409449590106, 0.050087931765509505, 0.05208969149472458, 0.03036066603713802, 0.04685436974146536, 0.013407077590402747, 0.06319166773131915, 0.010156108598623956, 0.0978060324809381, 0.016161957755684853, 0.02038661008035498, 0.20585312614483492, 0.013650530017912388, 0.02306276067559208, 0.16831443831324577, 0.39957040920853615, 0.21283868487392152, 0.12172892450221948, 0.05656895899612989, 0.027386107615062168, 0.04032812832987734, 0.039282967269952805, 0.018023276003077626, 0.005842994391319475, 0.06381871551275253, 0.055681163777730296, 0.057028615581137795, 0.04571603564545512, 0.10379139666578599, 0.1349835768342018, 1.5964634886809757, 24.502963032041276, 49.43434156690325, 51.98465354101998, 55.40854515348162, 57.24101441247122, 51.285925320216585, 52.1406683921814, 47.070397649492534, 51.105230467660085, 50.778310775756836, 51.47813333783831, 53.47402422768729, 55.001780237470356, 50.04286132540022, 43.12604079927717, 40.372466223580496, 38.05124677930559, 38.63380111966814, 37.800114563533235, 38.3662120955331, 36.46711308615548, 36.26191193716866, 36.546610900333945, 36.99695144380842, 36.67028188705444, 41.296020780290874, 44.35290854317801, 45.07035868508475, 44.36602674211775, 40.369412490299766, 38.18445416859218, 37.18752663476126, 38.89706836427961, 37.756914138793945, 42.059669494628906, 41.36001368931362, 42.14341960634504, 44.06263712474278, 39.858914443424766, 37.55412401471819, 36.02209486280169, 37.35283817563738, 36.1298371042524, 39.837597370147705, 43.27177579062325, 40.8900340625218, 42.50087315695626, 35.580331870487754, 36.01900291442871, 34.01573998587472, 34.411328724452424, 35.22439302716936, 37.41248498644148, 35.31652961458479, 37.484833104269846, 36.24530226843697, 36.89626162392752, 38.07940782819475, 40.330540793282644, 42.986045019967214, 51.85072701317923, 48.44830533436367, 47.76925441196987, 47.29160744803292, 45.71930306298392, 46.093102250780376, 43.81290149688721, 44.705244745527, 45.93330757958548, 43.6275999886649, 34.3308755329677, 12.893343942505972, 1.4664015706096376, 0.1327692320836442, 0.19521761898483547, 0.43589730135032106, 0.06019062269479036, 0.06108571894999061, 0.022558073114071573, 0.05761759076267481, 0.07170608799372401, 0.042840980991188965, 0.024840887137023464, 0.013831457987959896, 0.06320383386420352, 0.04121354528303657, 0.039481021463871, 0.059120308341724534, 0.025492005948243395, 0.023016130052773014, 0.043048280224736245, 0.05726380938930171, 0.09130057798964636, 0.04778619509722505, 0.036521282246602435, 0.007139364806269961, 0.01636305857183678, 0.020941843411752155, 0.020445344071569185, 0.05193221369492156, 0.032254922070673535, 0.015020480346200722, 0.024127370245488625, 0.035135343936937194, 0.08297087531536818, 0.5148013702460698, 8.79613367148808, 28.860968726021902, 37.76793050765991, 24.670635223388672, 4.116561438356127, 4.487241319247654, 2.5612447474684035, 2.205066191298621, 4.4769827382905145, 8.783512268747602, 4.500889318329947, 0.3232658351106303, 0.17637979052960873, 0.09261694949652467, 0.1171498309288706, 0.051206062481339486, 0.0863362733008606, 0.029715657433761016, 0.011067179264500737, 0.0679239880825792, 0.034908275585621595, 0.04675176167594535, 0.18512715186391557, 1.968762299844197, 1.9706365764141083, 10.406489866120474, 53.5750857761928, 65.56543227604458, 44.004598821912495, 31.33790077481951, 32.42462682723999, 14.135767834527151, 30.279033524649485, 29.379081998552593, 44.53570522580828, 19.340694665908813, 0.11240821464785508, 0.06819256581366062, 0.09467242205781595, 0.029496551690889255, 0.03301550554377692, 0.031523040628858974, 0.039128461453531466, 0.025078947755641172, 0.0429602504840919, 0.05073969857767224, 0.04996716271021536, 0.06653621433568851, 0.010331580298952758, 0.015026193611057741, 0.10702262113669089, 0.11933289521506854, 0.09144363352762801, 0.13080454750784806, 0.34617941986237255, 0.187259366735816, 0.046550884776349576, 0.029356800618448427, 0.0833271536976099, 0.05750437040946313, 0.05401158765224474, 0.02600024564058653, 0.01903689536266029, 0.04536953495283212, 0.04991133284888097, 0.02667236341429608, 0.04430931380816868, 0.031200770421751907, 0.5043262551937784, 1.5231986429010118, 15.796557528632027, 45.605276175907676, 55.04959079197475, 55.02726970400129, 57.842582498277935, 54.41476515361241, 54.09419958932059, 50.828594888959614, 53.8998932157244, 53.32112911769322, 52.22395992279053, 55.05728939601353, 55.09518139702933, 50.58100972856794, 44.94328308105469, 42.08208090918404, 40.445415360586985, 41.12048149108887, 40.788180419376914, 41.15850898197719, 38.046772139413015, 38.81860930579049, 39.872585024152485, 39.2072811126709, 40.10139962605068, 44.09815631593977, 46.05449458530971, 46.24861683164324, 46.80299622671944, 44.472323758261545, 41.16600261415754, 39.17688969203404, 42.89531544276646, 40.50662899017334, 45.376517159598215, 43.00276585987636, 44.37645598820278, 45.4600761958531, 40.72885322570801, 40.741387775966096, 38.668952056339805, 39.642835889543804, 40.08534928730556, 42.004264559064595, 44.737665040152415, 42.66505561556135, 43.81141805648804, 38.49892616271973, 37.05934279305594, 36.432003838675364, 37.94928543908255, 38.32036440713065, 39.017741203308105, 37.83663082122803, 40.44774300711495, 39.7084755216326, 40.38273218699864, 40.25920711244856, 43.01808316367013, 48.59561061859131, 52.3097562789917, 48.45421477726528, 49.57986116409302, 49.281210218157085, 48.22609152112688, 48.90862001691546, 48.42425414494106, 46.951889174325125, 50.41938073294503, 46.18426956449236, 27.49845651217869, 5.59976646729878, 0.4978578622852053, 0.28812350226300104, 0.6063609314816338, 0.8512925314051765, 0.013249450512895626, 0.05948096327483654, 0.0937858617731503, 0.016141052091760293, 0.05482462188228965, 0.017185834868411933, 0.03760068557624306, 0.023684373391526084, 0.0037620606516221805, 0.05275643357474889, 0.0408094471453556, 0.060531701892614365, 0.08905592307980571, 0.07929800597152539, 0.10661138820328883, 0.07891538007450954, 0.07954181038907596, 0.11856490213956151, 0.042649586618478806, 0.009720065032265015, 0.06341447827539273, 0.04600522048505289, 0.05707918679607766, 0.030422955551849942, 0.05236526152917317, 0.02225103771447071, 0.09159197485340492, 0.020074127740891914, 0.08189859999609844, 0.48256851413420265, 18.69765451976231, 43.71592548915318, 46.459261894226074, 30.4623304775783, 7.173613352434976, 2.7917699090072086, 2.169328783239637, 8.042551159858704, 4.755832186767033, 9.770509089742388, 9.25801604134696, 0.5848996288010052, 0.4359835024390902, 0.1152690811348813, 0.060845938245100636, 0.09611342009156942, 0.029525453890008584, 0.07427472301891871, 0.13254424344216073, 0.11576625731374536, 0.17160008129264626, 0.10224007562335048, 0.17684606622372354, 4.440875555787768, 8.849209223474775, 35.614874839782715, 74.11294637407575, 76.07509681156704, 59.18958459581648, 36.32054778507778, 45.60242394038609, 15.781202009746007, 42.52154752186367, 39.075115953172954, 58.94595990862165, 21.40916817528861, 0.33508029686553137, 0.19609754319701875, 0.2366695132638727, 0.1484275675777878, 0.12074519800288336, 0.1298479624092579, 0.05691560896645699, 0.15254399526332105, 0.1495821356241192, 0.19198650307953358, 0.11609574034810066, 0.16965383929865702, 0.13211321085691452, 0.09990668190377099, 0.1958318967372179, 0.17466836236417294, 0.4316057844885758, 0.8063038140535355, 0.8698080692972455, 0.32075113004871775, 0.20121673707451138, 0.13602919929793902, 0.22317187754171236, 0.13247714989951678, 0.16531797338809284, 0.14747090105499538, 0.1627485648329769, 0.1100442868524364, 0.18568703824920313, 0.2005495335906744, 0.10211651439645461, 0.3728770044233118, 0.828277166400637, 3.8204574414661954, 30.130658217838832, 49.81101730891636, 57.21601479394095, 59.325164794921875, 59.752416474478586, 55.44957079206194, 55.14028910228184, 50.67712068557739, 53.169981479644775, 55.755965505327495, 56.14074632099697, 57.39011928013393, 56.916898318699424, 52.08231047221592, 48.82323013033186, 44.42429780960083, 43.67342683247158, 43.71718658719744, 42.61684553963797, 44.46371841430664, 41.67728580747332, 41.581053256988525, 43.00309937340872, 43.094607148851665, 42.488206590924946, 46.769314834049766, 49.30259329932076, 49.8333557673863, 51.354337283543174, 45.673636027744834, 42.95534440449306, 40.415538106645855, 46.14170142582485, 40.97851242337908, 49.11411299024309, 45.80362292698452, 47.80343607493809, 48.85496950149536, 43.28322989600045, 40.97244317190987, 40.45945072174072, 41.32050970622471, 41.24223477499825, 43.86186892645699, 47.61821099690029, 45.65315273829869, 47.269762311662944, 41.3493447303772, 40.883606978825156, 39.24620839527675, 39.79900360107422, 41.09105587005615, 42.89927591596331, 39.40771232332502, 43.441464696611675, 40.808222498212544, 43.802600792476106, 43.52051435198103, 45.90667166028704, 47.92463002886091, 55.89071886880057, 53.3553455216544, 52.284687178475515, 50.24745798110962, 49.21652943747384, 50.7763409614563, 48.004141739436555, 47.76411969321114, 51.928362710135325, 47.99076993124825, 44.95796462467739, 24.30359489577157, 2.656614418540682, 0.4591656242098127, 1.3704680097954614, 1.485036096402577, 0.1387187492634569, 0.20608514440911158, 0.16939961936857018, 0.1794077530503273, 0.15813122902597698, 0.17227742208966187, 0.17036894735481056, 0.196670335318361, 0.1300120186060667, 0.110252834590418, 0.1529783798115594, 0.1720679040466036, 0.20366482356829302, 0.17682192394776003, 0.252744089279856, 0.145205734031541, 0.22224703431129456, 0.2075781792934452, 0.2203414908477238, 0.09759272142712559, 0.11065376057688679, 0.1644142054553543, 0.16663275712302753, 0.1173629452075277, 0.1078407783061266, 0.1477021865014519, 0.26132905004279955, 0.17394367339355604, 0.24293743978653634, 0.6557099148631096, 24.754458291190012, 59.072444915771484, 56.13784544808524, 44.86087397166661, 7.386089699608939, 2.67225980758667, 1.3960976345198495, 10.281909533909388, 29.904206003461564, 18.900576659611293, 16.191630363464355, 0.7359506977455956, 0.7549793709601674, 0.20702087134122849, 0.1836963522114924, 0.1550568818513836, 0.27990340335028513, 0.2402444700045245], [0.06926826773477451, 0.0194864587392658, 0.17288126397345746, 0.01929682007591639, 0.02230353427252599, 0.09831753931939602, 0.21496807704014437, 5.060671806335449, 19.320581368037633, 53.779043197631836, 49.27896595001221, 34.32170738492693, 18.432125636509486, 13.793317181723458, 22.756373507635935, 25.68948953492301, 38.01944487435477, 32.23023360116141, 0.542033966098513, 0.09960734618029424, 0.04198513798681753, 0.07916098260985953, 0.05187213959704552, 0.03727997260700379, 0.03912973031401634, 0.0763681053317019, 0.05420832209555166, 0.028904641845396588, 0.056015993668032546, 0.07484173402190208, 0.03878981141107423, 0.018268111793856536, 0.09032624241496835, 0.05623212742752262, 0.974097490310669, 2.398565922464643, 3.086245204721178, 2.2222970724105835, 0.4691955660070692, 0.06476523115166596, 0.06053810726319041, 0.017409890524244735, 0.02548754118782069, 0.06040959273065839, 0.004069627853043909, 0.03290669566818646, 0.0524304619591151, 0.235424917191267, 0.1823712411735739, 0.04583601081477744, 0.812926641532353, 1.417476481625012, 1.9423508942127228, 20.967485087258474, 46.80747086661202, 48.26530020577567, 54.067931924547466, 55.1454689843314, 52.17085484095982, 54.785458496638704, 53.27773414339338, 50.24879550933838, 53.250681332179475, 53.018781730106895, 52.43458414077759, 50.319194657461985, 43.652603081294465, 42.340967314583914, 37.32108838217599, 37.01090342657906, 35.95485019683838, 35.82897663116455, 35.56068583897182, 34.33739989144461, 35.608340059007915, 37.55367585590908, 38.190130846840994, 42.04053068161011, 44.11896617071969, 41.142430850437705, 41.21294811793736, 39.90543958118984, 43.496904373168945, 40.00435413633074, 40.0617983681815, 42.13746847425188, 42.23995092936924, 41.21342754364014, 40.74240568705967, 42.85038491657802, 41.67223794119698, 41.088783809116904, 40.773662158421104, 39.35147360392979, 40.025132724217, 40.71900068010603, 41.65415178026472, 42.958415508270264, 39.86371217455183, 41.748834882463726, 35.24509171077183, 35.13761002676827, 35.69133281707764, 35.4096736907959, 36.20624644415719, 35.931941986083984, 37.16488592965262, 36.62567792619978, 37.38577611105782, 37.604394231523784, 41.457896436963765, 46.355202198028564, 51.49915163857596, 46.8994129044669, 46.55919088636126, 45.997925826481406, 47.260587215423584, 46.85119240624564, 43.37123577935355, 40.09915883200509, 45.44507156099592, 30.893921307155065, 12.492676070758275, 1.3523373369659697, 0.015818822596754347, 0.05320553894021681, 0.05994747645620789, 0.6102631592324802, 0.037903247733733485, 0.0866449728075947, 0.012570985892255391, 0.03397266400445785, 0.05125289836100169, 0.045367536667202196, 0.09422495535441808, 0.03216635289468935, 0.025953679478594234, 0.047795708158186505, 0.060424059097255976, 0.03065849541287337, 0.1631400931094374, 0.32984349929860657, 1.4685139315468925, 1.6169452582086836, 0.5867321618965694, 0.10769136489502021, 0.06285939591803721, 0.12444466591945716, 0.0583954904494541, 0.044403294300926585, 0.01980343128421477, 0.007515473374431687, 0.05454440049028822, 0.00939291955104896, 0.019740989099123647, 0.042228386005652804, 0.07776804521147694, 0.12433861089604241, 16.863960640771047, 31.672609397343226, 41.09951182774135, 26.34458133152553, 6.729493618011475, 12.04564460686275, 2.0996483394077847, 2.6335772318499426, 3.682694639478411, 12.289895500455584, 8.390805295535497, 0.19965795214687074, 0.05371389737618821, 0.10211959494543926, 0.026247542817145586, 0.06168621565614428, 0.07109815454376595, 0.07374193732227598, 0.050365679897367954, 0.02135598217137158, 0.11224138324281999, 0.07031053823551961, 0.027554569200479558, 0.19897951212312492, 0.1866991410830191, 4.713646633284433, 30.027685914720806, 64.80197811126709, 52.84759201322283, 37.93317256655012, 24.488983256476267, 11.401213083948408, 30.16071959904262, 32.82361323492867, 47.64598989486694, 43.92175545011248, 0.7460469731262752, 0.15892974260662282, 0.01624484420088785, 0.03200793532388551, 0.06298869076584067, 0.045706838103277345, 0.021836249257570932, 0.013110179503980492, 0.028709990504596914, 0.04642199365688222, 0.0037638023661981735, 0.005410787092322218, 0.05767227389982768, 0.05586085681404386, 0.054205730091780424, 0.10692975004868847, 0.510410868695804, 1.771018196429525, 1.6879265350954873, 1.2302220953362328, 0.2724623169217791, 0.04399490782192775, 0.05187933546091829, 0.02723943718176867, 0.012238748005724378, 0.02558451741268592, 0.09959197057677166, 0.02074992487074009, 0.05554640333035162, 0.12450325063296727, 0.20436568238905498, 0.09862872904964856, 2.3033295699528287, 1.8359318503311701, 2.2587414596761977, 16.17335139002119, 42.04830918993269, 51.63073662349156, 52.14169672557286, 57.42409944534302, 56.34264360155378, 57.390928745269775, 56.0747002192906, 53.69082192012242, 55.713553701128276, 55.192713260650635, 54.20987319946289, 49.88012409210205, 44.40055581501552, 44.682576247623985, 41.393997328622, 40.352691650390625, 38.609913212912424, 39.408837931496755, 36.879749229976106, 37.40951810564314, 38.48438010896955, 39.0413407598223, 42.79701927730015, 44.208344323294504, 45.17046138218471, 42.619009903499055, 44.9885436466762, 42.73380109242031, 45.32891852515084, 42.34549754006522, 42.595386028289795, 46.667416027614046, 45.22829123905727, 43.85752977643694, 42.824009554726736, 45.81513956614903, 44.05659566606794, 42.868026392800466, 43.28947980063302, 43.97978333064488, 42.47522388185774, 42.813656738826204, 43.070889472961426, 44.05641848700387, 42.22258390699114, 45.48431846073696, 38.01729440689087, 36.541834013802664, 38.66428634098598, 37.37389121736799, 37.31157282420567, 37.39723021643502, 38.96280527114868, 40.835268361227854, 38.64232308523995, 40.52485064097813, 45.06787470408848, 49.6092346736363, 53.0734293120248, 48.34367935998099, 49.40391887937273, 49.84371900558472, 49.53316926956177, 47.601142747061594, 46.77679109573364, 44.6751833643232, 46.62853390829903, 26.193218299320765, 6.108969977923802, 0.6741736669625554, 0.055715697817504406, 0.04168607707002333, 0.06330668620233025, 0.672503222312246, 0.25151045833315167, 0.10952161132757153, 0.10209102862115417, 0.016010361158155968, 0.0032653952824018362, 0.034026509150862694, 0.052763676936072965, 0.05309165023001177, 0.04199372824015362, 0.0065119090556566206, 0.06556299834379128, 0.007174507831223309, 0.05099774883793933, 0.30025334709456986, 1.2821786616529738, 1.0070400940520423, 0.575041220656463, 0.35915366081254824, 0.06241986807435751, 0.03561553977695959, 0.10919945647141763, 0.0628091503999063, 0.04929107041763408, 0.020601637827764665, 0.09498756086187703, 0.057194286691290994, 0.08410643081047706, 0.017988891241007617, 0.09545384334134203, 0.7296635008284024, 35.89704813276018, 44.41776302882603, 48.70629889624459, 33.37368474687849, 10.774272782461983, 9.097581267356873, 0.9264013639518193, 3.33921217918396, 6.47547789982387, 19.874894755227224, 12.066654222352163, 0.38928061564053806, 0.2405162097087928, 0.26142523916704313, 0.031908838677087, 0.0705513638843383, 0.04896239483995097, 0.03014925488137773, 0.18863550360713685, 0.1029380913823843, 0.4315966378365244, 0.15602040157786437, 0.15643101025904926, 0.17383531135107788, 0.32251917517610956, 14.889694281986781, 57.41853741237095, 77.99782317025321, 67.91987105778286, 47.67356382097517, 30.63711588723319, 17.237219606127056, 40.32059097290039, 43.94355194909232, 57.55158846718924, 49.98971455437796, 0.5306367490972791, 0.18112691651497567, 0.11242991419775145, 0.12479983828961849, 0.1732112355530262, 0.1666860356926918, 0.06762267103684799, 0.18897711884762558, 0.13651460967957973, 0.14582317375711032, 0.15461777469941548, 0.1571443269827536, 0.11211547428475958, 0.13498758019081183, 0.2316101933164256, 0.33165640916143146, 1.7508944762604577, 3.5914443816457475, 3.0874765557902197, 2.971454232931137, 0.7364505880645343, 0.17988409820411885, 0.1363100042300565, 0.09544082225433417, 0.1388685562248741, 0.18679345745061124, 0.12900816675807747, 0.1199179281081472, 0.214081272482872, 0.39532877824136187, 0.7964026853442192, 0.15790790958063944, 2.404511192015239, 2.7731066133294786, 4.818288241113935, 29.22485978262765, 49.42104271480015, 52.92280626296997, 56.94208901269095, 59.76467309679304, 55.41048717498779, 58.86782046726772, 57.19589628492083, 54.64609847749983, 57.68463257380894, 56.32260847091675, 57.727245875767295, 53.571017605917795, 43.21942458833967, 49.278545583997456, 42.365869658333914, 41.16701705115182, 40.00341612952096, 41.81425217219761, 40.06903491701399, 39.66296829496111, 40.15060329437256, 41.45655196053641, 43.54127556937081, 46.02334581102644, 49.13464144298008, 44.98921067374093, 47.23340238843645, 44.395386355263845, 48.0971850667681, 44.786483083452495, 44.321596486227854, 49.33744893755232, 47.68126242501395, 46.57434490748814, 45.943851470947266, 48.26170103890555, 46.762575081416536, 45.43345069885254, 45.56029006413051, 46.94564274379185, 43.852481910160606, 45.81838437489101, 47.09967041015625, 48.489129475184846, 44.39284678867885, 46.867621421813965, 37.78879247392927, 40.32984944752285, 41.274307659694124, 41.08199541909354, 38.68725708552769, 41.71625130517142, 41.748688970293315, 42.768604619162424, 42.223709515162874, 44.031061036246165, 45.768437249319895, 51.10512624468122, 54.74877895627703, 53.46991784232003, 54.831504208701, 52.36011682237898, 49.07720068522862, 52.43556036267962, 46.074741636003765, 43.94269732066563, 47.91409655979702, 42.47104106630598, 26.615130288260325, 2.913233322756631, 0.535310118326119, 0.13858929835259914, 0.16145227796265058, 3.23699614405632, 0.13192442884402616, 0.2922979039805276, 0.21742518804967403, 0.06388069968670607, 0.18612279343817914, 0.11115308092640978, 0.12628361795629772, 0.08859588990786246, 0.18466170398252352, 0.07257804620478835, 0.14471361972391605, 0.1485503145626613, 0.4619709593909127, 0.8203435721141952, 1.8764140095029558, 1.8024019066776549, 0.8563344808561462, 0.4505263535039765, 0.16093680847968372, 0.24713230612022535, 0.19742512410240515, 0.14481211586722306, 0.16423904842564038, 0.10418765433132648, 0.20777836069464684, 0.14089167623647622, 0.14497207371251924, 0.17614522097366198, 0.14194932234074387, 0.888455080134528, 46.62482009615217, 53.47254426138741, 58.593366622924805, 47.91406876700265, 11.19378764288766, 13.635232635906764, 0.5012589512126786, 3.4103493562766483, 21.07000228336879, 41.36841058731079, 19.363321474620275, 0.39376947762710707, 0.29286461642810274, 0.26445829070040155, 0.1390742744718279, 0.1158493235707283, 0.202226315758058, 0.18089302549404757], [0.06117571983486414, 0.36094303908092634, 2.358369073697499, 2.648746235030038, 0.05417188137237515, 0.23430023182715687, 0.32522308294262203, 1.738688662648201, 8.739724721227374, 37.862756047930034, 49.87636511666434, 27.78795494352068, 12.14794727734157, 15.134958744049072, 22.604350396565028, 29.782334600176128, 38.35271174567086, 38.244010652814595, 3.2136488940034593, 0.1718973746257169, 0.18113733881286212, 0.09053132962435484, 0.04347855285076158, 0.018861611107630388, 0.03134370721610529, 0.042294139441634925, 0.05614255741238594, 0.017974675932366933, 0.06522299123129674, 0.029131279326975346, 0.042469693414334736, 0.10559437956128802, 0.14221315032669476, 0.33595083015305655, 2.9390608625752583, 5.506866880825587, 6.396250631128039, 3.889695806162698, 1.6048612552029746, 0.2962537631392479, 0.06692438386380672, 0.032713129983416626, 0.016668453613030057, 0.015341278132317322, 0.0306702272833458, 0.10434383952191897, 0.006376855565966772, 0.03079063332240496, 0.1182069613465241, 0.2866546910788332, 2.3923518444810594, 0.4002438416438443, 0.9937154033354351, 4.639657872063773, 18.538728373391287, 38.879319190979004, 47.360762868608745, 51.59759371621268, 53.3296024458749, 50.00502838407244, 52.58286912100655, 48.64960854394095, 48.63780008043562, 54.74468994140625, 51.02983556474958, 48.06303467069353, 44.07359790802002, 40.453860895974294, 40.490321568080354, 39.17695222582136, 35.64008290427071, 35.60605410167149, 36.841023445129395, 35.37390783854893, 36.47862972532, 35.805655002593994, 40.64293875013079, 42.39672660827637, 41.353433745247976, 42.72156184060233, 41.343827860695974, 40.43684475762503, 39.50530672073364, 39.02712821960449, 40.730590275355745, 41.08950989586966, 40.88870348249163, 37.83038091659546, 36.71939522879464, 41.62768956593105, 41.169580936431885, 40.07501384190151, 39.39077608925955, 40.62473446982247, 40.467486313411165, 39.4370128767831, 39.58075720923287, 39.42258146830967, 40.598095076424734, 41.31600379943848, 37.732473850250244, 36.27177490506853, 36.647352831704275, 36.10421214784895, 34.47781603676932, 35.866854735783164, 36.810649394989014, 38.287624495370046, 36.592958859034944, 39.310069288526265, 43.594943455287385, 45.267902919224326, 46.53121049063546, 43.52597563607352, 38.79763616834368, 49.16369880948748, 44.39484439577375, 43.447620800563264, 38.62606430053711, 40.71977193014962, 31.76286997113909, 14.253967114857264, 2.327941175018038, 0.1679741530013936, 0.10636267797755343, 0.04490371387717979, 0.11454665847122669, 0.16394562274217606, 0.8753136481557573, 0.16758005986256258, 0.06915676407516003, 0.04048156545364431, 0.06783304403402976, 0.03916150950161474, 0.02819813252426684, 0.033668931374060254, 0.040119346497314315, 0.10197693974311862, 0.004602411005180329, 0.04962344401116882, 0.3328695754919733, 1.7389507400138038, 3.397834130695888, 0.641358844935894, 0.7886467586670602, 0.4426107539662293, 0.22441575436719827, 0.04273557057604194, 0.05030849635867136, 0.0177787489457322, 0.021880691604954854, 0.024445767713976756, 0.02562472061254084, 0.05562881140836647, 0.02631773896116231, 0.061712542814867835, 0.09313150974256651, 0.6169190992202077, 36.99499552590506, 41.801314626421245, 49.041413988385884, 27.339512995311193, 6.6786362784249445, 7.176512488297053, 7.881825430052621, 1.8535637727805545, 5.240491185869489, 13.31986345563616, 9.326229112488882, 0.06714110794876303, 0.5119952751057488, 0.775259479880333, 0.18868555235011236, 0.1934428427900587, 0.03125026276601212, 0.2548930368253163, 0.06247387946184192, 0.3394130957978112, 0.6904427111148834, 1.444195019347327, 0.07869010644831828, 0.15707613421337946, 0.2942912227341107, 2.0330359595162526, 13.300077591623578, 53.355289936065674, 54.03772463117327, 36.6680133002145, 16.071700981685094, 16.553443908691406, 30.04462562288557, 36.90600994655064, 44.73422220775059, 51.503751346043174, 4.759070915835244, 0.35204725499664036, 0.13255743416292326, 0.03642365802079439, 0.07872394498969827, 0.04657259789694633, 0.015224951785057783, 0.030151789209672382, 0.01885817602409848, 0.0561894170407738, 0.08999252532209669, 0.01428474482548024, 0.02829831652343273, 0.12159314964498792, 0.031901439252708635, 0.39642922633460587, 2.2944942840508054, 5.266752336706434, 6.203012108802795, 4.755286753177643, 1.611365637608937, 0.3484527293060507, 0.030375905933656862, 0.058193517715803215, 0.0145983331770237, 0.022504696156829596, 0.02139644999988377, 0.047398320731839964, 0.04250878042408398, 0.08951317425817251, 0.0942792110145092, 1.9644552852426256, 2.4957738263266425, 0.17672501557639667, 1.8051945396832056, 4.008203412805285, 16.71045756340027, 32.145086901528494, 47.79437214987618, 51.011784144810264, 52.919318267277305, 49.00615188053676, 51.074335302625386, 49.37532009397234, 51.64070381437029, 52.74627685546875, 52.511413846697124, 50.97157839366368, 44.544157709394185, 42.5799367087228, 43.173747130802695, 40.42069714409964, 37.8054473059518, 38.20600748062134, 38.65601103646414, 38.61089638301304, 39.03251654761178, 39.015667166028706, 42.968973296029226, 45.10333830969674, 43.92171376092093, 44.124788761138916, 43.943506785801475, 41.63119493212019, 42.185671601976665, 41.34978594098772, 42.473834242139546, 41.702469553266255, 43.97754948479788, 40.425109250204905, 39.521892070770264, 42.51085077013288, 43.72625398635864, 41.3303587777274, 41.26470177514212, 42.74261488233294, 41.97409895488194, 41.75744717461722, 41.87518092564174, 40.43797731399536, 43.18937362943377, 45.00093923296247, 41.09727103369576, 39.43423359734671, 39.82031372615269, 37.35877193723406, 36.678025654384065, 37.56627641405378, 38.360639640263145, 37.818072182791575, 39.90591900689261, 43.6622645514352, 43.80215263366699, 45.21631949288504, 49.50723164422171, 48.483299936567036, 41.797986439296174, 47.31467546735491, 46.67589282989502, 45.58201708112444, 40.65052618299212, 37.75614288875035, 23.55112930706569, 4.560276005949293, 1.0447398253849574, 0.16225482204130717, 0.0779490919251527, 0.09817856856222663, 0.05033166154420801, 0.09224619796233517, 0.9002535556043897, 0.6011896803975105, 0.12454465483980519, 0.06283988125090088, 0.05453289592904704, 0.033541383753929815, 0.02916045972545232, 0.01817769360994654, 0.019497659656086137, 0.04374920689900007, 0.07874182438743965, 0.08307472509997231, 0.5789663557495389, 2.0087181329727173, 3.6245744781834737, 1.746504734669413, 0.8275712185672351, 0.4305746555328369, 0.1805475697453533, 0.012418268015608191, 0.05341085685150964, 0.02226051175966859, 0.03471007550667439, 0.007455840324317771, 0.020375337917357683, 0.06629132426210813, 0.06954819735671793, 0.17040173416691168, 0.10366391350648232, 6.656933145863669, 53.3090739931379, 51.910842827388215, 56.7637357030596, 32.538810048784526, 12.498912947518484, 6.891064422471183, 3.8795327629361833, 6.0089137469019205, 10.528066839490618, 28.237329687391007, 14.840516669409615, 0.1562681889959744, 3.137212629829134, 5.249349270548139, 0.30892760306596756, 0.14471473252134665, 0.07349669441048588, 0.18608277344277926, 0.22867718498621667, 1.0558565088680811, 3.08365461230278, 3.7738237380981445, 0.14323354485843862, 0.3856356883687632, 0.529798894056252, 3.868231952190399, 35.14610767364502, 76.26497718266079, 66.78002602713448, 41.372631617954795, 15.618478672845022, 24.339053290230886, 46.47129617418562, 46.7411607333592, 53.53301443372454, 62.82450689588274, 5.043398584638323, 0.46149658198867527, 0.2855972892471722, 0.3054196855851582, 0.13149630038865975, 0.2203955158059086, 0.14890548693282263, 0.09810899158141442, 0.12114558794668742, 0.19575993131314004, 0.09806162983711277, 0.0687672510477049, 0.139366818059768, 0.44062590332967894, 0.48050327066864285, 1.131700656243733, 5.029722358499255, 7.730159282684326, 7.440978731427874, 5.8307845166751315, 2.792928521122251, 0.6667110845446587, 0.1603858516152416, 0.2220484542527369, 0.106950872843819, 0.1142987489168133, 0.14700379754815782, 0.16169853189161845, 0.21447721123695374, 0.15339425392448902, 0.23688184044190816, 1.3790147283247538, 4.61584335565567, 1.4634176450116294, 2.948211205857141, 8.718962635312762, 28.397800070898874, 44.57408707482474, 48.51282630647932, 56.57606485911778, 55.6422895022801, 53.1249988419669, 56.98001575469971, 51.62712703432356, 53.3509646824428, 57.36910792759487, 53.763573033469065, 54.113988058907644, 44.829607078007285, 43.57909461430141, 44.22874076025826, 43.79779611315046, 39.647699628557476, 40.47634874071394, 40.54289511271885, 40.12162235804966, 42.74167340142386, 39.966757433755056, 45.76195805413382, 47.866939135960166, 45.69228499276297, 49.2239396912711, 45.27467393875122, 43.94102280480521, 44.82772759028843, 44.581149918692454, 45.21260915483747, 45.86986705235073, 47.34115852628435, 43.03226096289498, 43.714431626456125, 47.546491691044395, 46.68368870871407, 45.14052506855556, 42.865608419690815, 45.449518408094136, 47.18637350627354, 45.76761041368757, 44.65273720877511, 44.04023265838623, 45.903968811035156, 46.62903765269688, 43.63749769755772, 41.54841409410749, 41.50393172672817, 40.31394502094814, 40.10390445164272, 39.58815704073225, 41.6461683000837, 42.035083293914795, 42.43078667776925, 43.95771932601929, 43.99988794326782, 49.9032199042184, 53.12090287889753, 47.84283583504813, 44.34053380148751, 51.79863289424351, 49.64717878614153, 43.63865457262312, 39.313300200871055, 40.68164369038173, 40.74019615990775, 25.10227469035557, 3.3271071144512723, 0.34199378160493715, 0.15937669362340653, 0.13992305392665522, 0.2108521514705249, 0.5394958108663559, 1.358779402715819, 0.47290302706616266, 0.1767808318670307, 0.25327616930007935, 0.12301135568746499, 0.09698929344969136, 0.1446128437029464, 0.10785371796893221, 0.13864435468401226, 0.23009201192430087, 0.25887250900268555, 0.320330411195755, 1.199635039482798, 3.716481992176601, 4.7017161420413425, 1.8789084127971103, 2.127973105226244, 1.0130382350512912, 0.41031045147350853, 0.15786327554711274, 0.11436502821743488, 0.17540139731551918, 0.19166771375707217, 0.08991227498544113, 0.15184380140687737, 0.15771923613335403, 0.10720400033252579, 0.20823900454810687, 0.25445378039564404, 5.750072939055307, 66.22754001617432, 55.875057629176546, 67.78884887695312, 44.915952341897146, 13.712810141699654, 10.488139016287667, 6.2265543426786145, 6.680033300604139, 16.520695311682566, 46.054591860089985, 19.61226327078683, 0.17905255353876523, 2.177866382258279, 2.328475534915924, 0.395540074046169, 0.2701841763087681, 0.18853377763714108, 0.3218374917549746], [0.08556112168090683, 1.2382939479180743, 9.317778365952627, 13.603878021240234, 1.8888230579239982, 0.13072619028389454, 0.08906495438090392, 0.48715644223349436, 4.082413213593619, 26.927870443889073, 43.78731822967529, 13.109174966812134, 4.721939308302743, 10.5681631565094, 27.758671760559082, 30.802795682634624, 38.2652200290135, 41.53544528143746, 5.658420554229191, 0.17515436985663005, 0.2251199787216527, 0.037052147689142396, 0.10678393287318093, 0.13168266681688173, 0.07884716016373464, 0.09700595148439918, 0.056502652554107566, 0.05304894662861313, 0.051880078456763706, 0.04417719625468765, 0.11275899011109557, 0.09664180888129131, 0.3379048210169588, 2.2136789177145277, 5.88340539591653, 11.45099605832781, 11.685665386063711, 9.301883493150983, 5.67024074281965, 1.528949037194252, 0.3470081825341497, 0.044103113801351616, 0.030691363649176698, 0.0667293050459453, 0.03836568970499294, 0.053472226951271296, 0.09022351221314498, 0.07427333202213049, 0.23058717963950975, 2.94161519408226, 1.293064426098551, 0.12029032169708184, 1.0517045259475708, 1.839440473488399, 6.135360538959503, 11.515190465109688, 29.488436222076416, 40.71439749853951, 39.5478401184082, 39.72267416545323, 40.270574365343364, 41.697949750082834, 41.2705591065543, 42.67620400020054, 42.79655722209385, 44.52458463396345, 39.9752585547311, 40.12054191316877, 41.578607491084504, 37.94105529785156, 37.2778844833374, 36.57853787285941, 36.36368220193045, 37.225432532174246, 37.06862211227417, 38.85513251168387, 42.40287228993007, 41.3880045073373, 42.56397322246006, 42.13716970171247, 40.589573110852925, 38.84554399762835, 39.03584820883614, 36.693332535879954, 40.13724190848214, 41.00044788633074, 40.227433000292095, 37.07436827250889, 38.229158878326416, 39.785346916743684, 39.878570897238596, 38.78183943884713, 39.669652462005615, 37.87672192709786, 38.805848939078196, 40.75899451119559, 40.076261043548584, 40.17648533412388, 39.80226230621338, 40.520980494362966, 38.70144183295113, 37.245599678584504, 35.078720569610596, 35.578994342258994, 34.353533608572825, 34.71680974960327, 35.51650224413191, 37.51957062312535, 35.654955523354666, 41.84952122824532, 40.96230227606637, 40.09014354433332, 39.719908782414024, 41.78978409085955, 36.92420033046177, 37.8476437159947, 40.06228126798357, 36.390905244009836, 31.22955404009138, 23.233183213642665, 12.823786394936697, 0.9960569462605885, 0.12699031217822007, 0.06356233784130641, 0.0016002356777400045, 0.047087005472608974, 0.062025727438075204, 0.01767680075551782, 1.502135504569326, 1.0632847845554352, 0.1021144041525466, 0.05829132853874138, 0.011051081021183302, 0.05109676066786051, 0.09090361464768648, 0.002487203825564523, 0.015338180619957191, 0.01763255687962685, 0.08035740269614117, 0.75871918456895, 2.670781144074031, 5.597177829061236, 3.592288587774549, 4.197255211217063, 5.594212685312543, 5.041998956884656, 1.904314066682543, 1.5565381624868937, 0.2915836237370968, 0.0564320509854172, 0.06573336491627352, 0.11651705631187984, 0.04281910162951265, 0.0698843707463571, 0.04393637399854405, 0.13945479691028595, 0.3183636638735022, 13.163343123027257, 51.45718799318586, 58.989504269191194, 52.74758311680385, 28.18575668334961, 7.473705615316119, 6.320240378379822, 1.9288442475455148, 4.080337005002158, 4.7929312246186395, 10.993713395936147, 6.345754597868238, 2.7048792115279605, 22.947150196347916, 49.79268796103341, 6.610451868602207, 0.03227001268948827, 0.05017373930396778, 0.15752235241234303, 0.13797464062060627, 1.6167358351605279, 8.223509175436837, 11.816843032836914, 2.7526283179010664, 0.14321801997721195, 0.09405492126409497, 0.4527208443198885, 6.289954049246652, 39.60975899015154, 54.161986214774, 17.33505892753601, 11.598390800612313, 12.879031521933419, 35.21128872462681, 36.112991196768625, 42.1147027015686, 57.99595703397478, 9.371694649968829, 0.19038217488144124, 0.17632284787084374, 0.06204572386507477, 0.11524666233786515, 0.23199975384133203, 0.1080388291073697, 0.02116886935462909, 0.047019972998116694, 0.04633678322924035, 0.03332066309771367, 0.0378310991052006, 0.05809768142976931, 0.03201975879658546, 0.17636696621775627, 2.4791037951196944, 6.152002777372088, 11.402354325566973, 11.948720710618154, 9.077282105173383, 5.98181186403547, 1.6997344557728087, 0.2664465068706444, 0.07504097225942782, 0.020654449904603616, 0.0647386054375342, 0.039029819425195456, 0.028444009866299372, 0.05748585318880422, 0.21322850324213505, 0.9531863438231605, 3.281384276492255, 0.16311562513666494, 0.35826464423111504, 1.1345609256199427, 2.2970659860542844, 8.359230944088527, 14.837832927703857, 24.953444276537212, 39.31220585959298, 40.81405551092965, 38.87317698342459, 39.48539318357195, 40.15158993857247, 41.765479292188374, 41.7968156678336, 43.04126582826887, 43.99297101157052, 41.977388926914756, 40.44061068126133, 42.60216747011457, 41.12920148032052, 38.69914197921753, 39.43257645198277, 40.02180453709194, 39.60497515542166, 41.22469752175467, 42.53640277045113, 45.928655760628835, 43.53733594076974, 44.5416841506958, 44.30286066872733, 43.619870117732454, 40.58815915243966, 42.67413691111973, 39.920666558401926, 42.49698216574532, 43.59707655225481, 43.00053201402937, 40.727143968854634, 40.46124683107649, 42.663259506225586, 43.244851521083284, 41.84067269733974, 41.96715423039028, 41.58887345450265, 41.637236390795024, 41.27562434332711, 43.432838508060996, 44.19661576407296, 43.07605198451451, 41.66282313210623, 40.65739100319998, 38.520121642521445, 37.902795042310444, 37.337645939418245, 37.29983384268624, 36.2747973714556, 39.46016080038888, 39.1989745412554, 39.68054723739624, 41.771850790296284, 42.00087036405291, 40.137926306043354, 42.45200995036534, 44.136878626687185, 42.31156601224627, 36.86801719665527, 37.82224805014474, 29.360589368002756, 21.182828869138444, 10.81491105897086, 2.123897986752646, 0.07292827205466372, 0.17606440745294094, 0.010446144151501358, 0.03403103158676198, 0.00440702769472929, 0.0402647938712367, 0.046819431973355155, 0.19021864794194698, 1.2324901393481662, 0.4385300986468792, 0.05190752519826804, 0.014692943011011397, 0.033221356105059385, 0.0051032767182083005, 0.11918642664594309, 0.03417240435789738, 0.1013274731646691, 0.040887872222810984, 0.656494735607079, 3.59540832894189, 7.137304672173091, 5.762149342468806, 5.474547335079738, 5.363558982099805, 6.11525114945003, 1.732696927019528, 1.1260871631758553, 0.15466221874313696, 0.03574619848015053, 0.037892021371849945, 0.12482037075928279, 0.03618365339934826, 0.0801342868113092, 0.01827959599904716, 0.07438480854034424, 0.28278639007891926, 23.627886056900024, 64.89795357840401, 63.05208124433245, 61.057496615818565, 38.01172195162092, 11.249717167445592, 4.606053778103419, 4.821318089962006, 9.259013107844762, 6.753038023199354, 29.425951072147914, 7.954299483980451, 1.771706936614854, 54.47319950376238, 73.5588344846453, 10.303386415754046, 0.09143385583800928, 0.04780583529333983, 0.16188420621412142, 0.2293633467384747, 2.5322394924504414, 20.462474380220684, 31.734437942504883, 7.378874863897051, 0.25023540960890905, 0.25424574155892643, 0.3959579973348549, 18.438337326049805, 59.259031840733115, 65.87156295776367, 16.636261224746704, 11.069618122918264, 22.286899362291607, 46.44536897114345, 47.327619961329866, 51.03109318869454, 69.23908383505685, 16.300678866250173, 0.263757554015943, 0.3267783937709672, 0.18743639652218136, 0.20662362979991095, 0.29952025786042213, 0.2296201858137335, 0.15181309091193335, 0.19048102386295795, 0.1826557373361928, 0.12552422870482716, 0.16563092730939388, 0.24529154918023519, 0.43126290717295235, 1.8421837091445923, 5.374784665448325, 7.0476420777184625, 13.826630319867816, 14.258276735033308, 12.947741389274597, 10.278889673096792, 3.7616131475993564, 1.0975177990538734, 0.15657058491238526, 0.1246763856283256, 0.1212489695421287, 0.27408268568771227, 0.08390816287802798, 0.23073336322392735, 0.5065095094697816, 0.34831992643220083, 3.7898823278290883, 1.896479538508824, 0.5495072422283036, 2.407605528831482, 3.628782480955124, 13.502436058861868, 22.283041375023977, 37.831774030412944, 42.069417817252024, 40.5777507509504, 39.21966975075858, 38.55345215116228, 40.486402784075054, 41.80054685047695, 42.713946614946636, 44.79350076402937, 46.918669836861746, 42.1834203856332, 41.15532670702253, 44.482544558388845, 43.934623513902935, 41.96438537325178, 42.85826069968087, 41.721438135419575, 41.023331778390066, 43.44681828362601, 44.59589399610247, 48.32066692624773, 47.45753043038504, 47.58309480122158, 47.59303419930594, 45.90192951474871, 44.30616453715733, 45.98315743037632, 42.056032112666536, 46.11026777539934, 46.57090207508632, 45.008689948490684, 42.36468846457345, 43.30773966653006, 45.09175566264561, 45.68561472211565, 43.916992459978374, 44.18177093778338, 43.14921651567732, 43.21060037612915, 46.900670528411865, 45.485548291887554, 45.1029839515686, 45.1936023575919, 45.660142626081196, 43.0617664882115, 40.78037411825997, 40.43619857515608, 40.20444141115461, 39.390831674848286, 40.81495877674648, 40.74808236530849, 43.42466395241873, 42.42866052900042, 43.96576533998762, 46.34254605429513, 42.919460432870046, 45.890735966818674, 46.04639645985195, 43.12323720114571, 41.4564859526498, 40.10705198560442, 38.09031997408186, 38.149570737566265, 33.10619299752371, 20.279363291604177, 1.417223415204457, 0.5338400857789176, 0.10525448779974665, 0.1218020570065294, 0.14069194266838686, 0.27641852891870905, 0.16089980117976665, 1.4584280784640993, 2.1600425158228194, 0.3086175668452467, 0.13517519512346812, 0.11810177484793322, 0.21339322440326214, 0.20828617630260332, 0.2208840474486351, 0.06251689179667405, 0.08434408091540847, 0.1624816155859402, 0.9660764464310237, 5.346127688884735, 8.014531680515834, 8.963077170508248, 8.935997435024806, 6.246856544698987, 8.170365009989057, 2.741501429251262, 2.1201943797724585, 0.37087918019720484, 0.24035621115139552, 0.23137813434004784, 0.20880107581615448, 0.1279953039650406, 0.21790561798427785, 0.1411802978920085, 0.17549761358116353, 0.5012571055974279, 21.831455366952078, 73.7369862965175, 69.127683367048, 65.55897045135498, 50.1934357370649, 14.594538279942103, 10.791290657860891, 11.084280558994838, 12.836241040910993, 17.037603071757726, 55.85139553887503, 10.979929906981331, 7.498383011136736, 77.0714476449149, 74.11560753413609, 9.59429929937635, 0.15614705692444528, 0.23735629926834786, 0.2282071230666978], [0.04924024814473731, 2.969143956899643, 10.933831214904785, 5.254075348377228, 0.2920452446809837, 1.982387500149863, 0.12730861295546803, 0.579653901713235, 3.057142023529325, 25.169048615864344, 30.313242980412074, 10.674560053007943, 8.389981065477643, 13.959946274757385, 29.079937730516704, 34.650930404663086, 37.47576223100935, 50.26083673749651, 7.403503622327532, 0.8707897194794246, 0.26452185586094856, 0.01761038405155497, 0.037833443443690024, 0.08791077988488333, 0.042629043970789225, 0.10663959490401403, 0.0655790049848812, 0.068807861368571, 0.09507192312074558, 0.10252680416618075, 0.23541701904364995, 0.28548090692077366, 2.5586522008691515, 8.174269897597176, 20.28918978146144, 16.869197845458984, 14.95807671546936, 23.51125533240182, 12.764981184686933, 1.9122823476791382, 1.0289945559842246, 0.21211012825369835, 0.020422879473439286, 0.038755189161747694, 0.052175173336373906, 0.05436137584703309, 0.02820703151103641, 0.027489677503971115, 2.3660355423177992, 1.5730590245553424, 0.28935748604791506, 0.037719649728387594, 0.8609893939324788, 2.3214695794241766, 4.607621465410505, 10.620014957019261, 8.240589584623065, 22.26736797605242, 42.415778568812776, 37.03457941327776, 42.481935841696604, 37.329276834215435, 40.49296188354492, 37.70733526774815, 39.65396690368652, 39.12195028577532, 39.916515009743826, 39.262251785823274, 42.08913680485317, 36.87395790645054, 36.31513166427612, 35.121768133980886, 37.25933974129813, 36.691164697919575, 38.58536522729056, 37.917956011635916, 40.336835861206055, 39.809068066733225, 41.07229920795986, 41.94603518077305, 39.540304797036306, 38.92618131637573, 38.49416317258562, 36.240476744515554, 38.63035828726632, 37.691392626081196, 38.99874482836042, 37.90268734523228, 40.135087966918945, 40.54571955544608, 40.36038678033011, 39.952221802302766, 37.757959842681885, 37.79431629180908, 39.609265668051584, 40.62990045547485, 40.15097502299717, 41.66281965800694, 38.90057373046875, 39.62195307867867, 40.97553859438215, 36.93443850108555, 36.58285617828369, 35.72703613553728, 34.590765953063965, 31.822770391191753, 35.3697041784014, 34.98258876800537, 37.4806363923209, 37.95026513508388, 36.47875826699393, 34.492553165980745, 35.1461215700422, 33.60353115626744, 38.96799904959542, 34.851055894579204, 26.810890572411672, 13.81942069530487, 8.174956032208033, 2.5458282147135054, 0.055990619851010184, 0.25085075944662094, 0.07354419864714146, 0.07220292490507875, 0.031038600552294935, 0.0431397738866508, 0.020940589818305204, 0.06283293983766011, 0.0855390014392989, 0.18618247737841948, 1.5988449837480272, 0.09100105227636439, 0.05284981695669038, 0.00889916149234133, 0.027524136904893175, 0.09388348260628325, 0.17321532033383846, 0.10420235818518059, 0.0382012467432235, 1.4569082685879298, 4.371811764580863, 1.985480968441282, 3.64911356142589, 14.264121907097952, 12.814377665519714, 5.7829770020076205, 2.1790723289762224, 1.104439181940896, 0.5477441368358476, 0.21233203634619713, 0.5552876006279672, 0.10250745913279907, 0.05738249873476369, 0.05272830829822591, 0.02602334297262132, 0.0320031211179282, 0.10169903894088098, 34.87315116609846, 60.28762231554304, 61.59965760367257, 52.60282434735979, 27.42936188834054, 12.066020199230739, 19.914247614996775, 7.650206361498151, 1.105701582772391, 13.853772589138575, 9.14787493433271, 4.479905324322837, 3.3991985831941878, 40.8430711882455, 62.94426604679653, 16.598346642085485, 0.2989669261234147, 0.10965412921671357, 0.144821791776589, 0.12263157963752747, 3.2669576449053626, 17.897618089403423, 19.83605432510376, 11.909796033586774, 3.5257541579859595, 0.17178327217698097, 0.3948159414742674, 5.422556136335645, 38.132387842450825, 43.68731280735561, 14.524611609322683, 10.103874972888402, 20.71891154561724, 40.292058195386616, 44.95762068884713, 40.72513246536255, 62.25044672829764, 26.129378250667028, 0.571768401988915, 0.04401537922344037, 0.05105787721861686, 0.07976518411721502, 0.0436073150485754, 0.05366979938532625, 0.11040992901793548, 0.07699042372405529, 0.04869862113680158, 0.07335969819022076, 0.1560094500226634, 0.3340768792799541, 0.7433347872325352, 3.970659690243857, 10.606597117015294, 19.295091901506694, 20.954170601708547, 19.254180908203125, 23.981434719903127, 14.605274983814784, 2.6304998312677657, 0.7659126328570502, 0.0465533817852182, 0.1532921479748828, 0.09085512653525386, 0.22923461507473672, 0.025167036868099655, 0.04019057571089693, 0.6530356726476124, 3.283622464963368, 2.1747522865022932, 0.5367462784051895, 0.5968454820769173, 1.0427797819886888, 2.5696598844868794, 5.105039962700435, 13.808087314878192, 13.487323726926531, 19.24914346422468, 40.250629561288015, 36.83651059014456, 42.04514428547451, 38.92675106866019, 41.00734049933297, 36.77502598081316, 40.26896585736956, 37.715058190482004, 40.72642135620117, 38.82356684548514, 43.74910313742501, 40.17450509752546, 38.99667426518032, 38.36864396503994, 38.58739410127912, 39.34274666649954, 41.283580030713765, 41.544325079236714, 43.87406301498413, 43.12863595145089, 42.54921177455357, 44.1399427822658, 42.29428931644985, 42.4546537399292, 39.418485505240305, 39.90376853942871, 39.54860094615391, 41.15768909454346, 42.11826017924717, 42.007575375693186, 41.11573934555054, 43.12412657056536, 43.594453607286724, 42.443366391318186, 40.28256695611136, 38.93008967808315, 43.047178745269775, 45.78791652406965, 43.27415207454136, 43.319860798971995, 42.30492353439331, 40.948134899139404, 40.95764350891113, 39.6937175478254, 39.987747941698345, 38.2451571055821, 37.6385064125061, 34.52763114656721, 36.95913239887783, 37.390177794865195, 39.18603352137974, 40.32884195872715, 39.271781240190776, 35.654656750815256, 35.40877389907837, 33.41055188860212, 41.66804470334734, 39.6450697353908, 19.737078973225184, 5.56260142156056, 1.7183656160320555, 0.9205751908676965, 0.1615525654384068, 0.15994654090276786, 0.08401902192937476, 0.011987988604232669, 0.10940269806555339, 0.09728932806423732, 0.01027165208610573, 0.02426444788995598, 0.07044420284884316, 0.08287655216242586, 2.6173147559165955, 0.05313906625711492, 0.029425885661372116, 0.10692110551255089, 0.027386835343869667, 0.07580665831587144, 0.08944648105118956, 0.11801746008651597, 0.03474304213055542, 1.9368685483932495, 5.989275097846985, 4.530078700610569, 7.244925320148468, 16.347897086824688, 15.777972834450857, 6.3931964635849, 1.5537496549742562, 1.9349087221281869, 0.5151849325214113, 0.1037873797384756, 0.6842459493449756, 0.10087422534291234, 0.021976706006431153, 0.14258730810667786, 0.10386087865169559, 0.037808473355003765, 0.14058497840804712, 48.024472168513704, 66.68843487330845, 65.68908241816929, 61.051847730364116, 35.67869404384068, 9.683864184788295, 16.025736910956248, 12.907163909503392, 1.702804799590792, 15.290349994386945, 25.69366887637547, 1.7974006150450026, 30.591587815965923, 70.29110363551548, 72.99558571406773, 20.930610997336252, 0.11470406502485275, 0.12885787125144685, 0.1353765707463026, 0.18143422502492154, 4.197956545012338, 25.67283817699977, 37.505601269858225, 36.353937353406636, 8.613209315708705, 0.5669206764016832, 0.6430144703813961, 17.424379757472447, 60.83730125427246, 47.376945223127095, 21.000294481004985, 19.163807426180156, 22.292233841759817, 44.97422340938023, 55.47496993201119, 47.30964149747576, 73.31615475245884, 37.914492334638325, 0.8632733428052494, 0.22687747941485473, 0.16539173014461994, 0.14946675752954824, 0.16095191266919884, 0.1868780707674367, 0.3265705992068563, 0.14064418737377438, 0.3127928913703987, 0.14259534196129867, 0.18006693625024386, 0.9164799877575466, 1.267393980707441, 7.713023287909372, 13.602649058614459, 20.0562253679548, 23.578939471926006, 21.24810893195016, 27.6810291154044, 17.465200424194336, 5.676817212785993, 3.9671043838773454, 0.329294673034123, 0.22551985297884258, 0.4026680029928684, 0.34998659842780655, 0.2461540757545403, 0.12224116415849753, 0.4903693326881954, 5.582000357764108, 4.312482399599893, 1.4024650071348463, 1.314279230577605, 1.726924602474485, 3.5098927233900343, 7.484573466437204, 21.39104379926409, 20.841781752450125, 30.313298566000803, 43.92941583905901, 38.1462390763419, 43.63201904296875, 38.46056515829903, 41.32691594532558, 36.712054456983296, 38.536748681749614, 36.8706887790135, 40.264341831207275, 38.242534160614014, 44.4572149004255, 42.65620361055647, 42.67602334703718, 40.30114991324288, 40.87462990624564, 41.76793548039028, 43.53302110944475, 42.6043769972665, 45.282695634024485, 45.814913749694824, 44.529458795275005, 47.324757303510395, 45.2963627406529, 44.933239459991455, 42.74320547921317, 42.23745305197579, 40.54652554648263, 42.50063344410488, 43.32640252794538, 44.60992240905762, 45.663561139787944, 46.27466215406145, 44.767934867313926, 44.355958802359446, 43.88625710351126, 41.521343912397114, 44.336003576006206, 48.342852524348665, 45.684621129717144, 47.86649792534964, 43.86610732759748, 43.00178616387503, 42.49343858446394, 41.40358236857823, 40.10047551563808, 40.90467044285366, 38.506968702588765, 35.99337100982666, 39.95284366607666, 40.958710057394846, 41.089728764125276, 40.881050041743684, 42.25957611628941, 38.78513635907854, 37.166873114449636, 37.29331643240792, 42.15887240001133, 40.494309834071565, 35.26598146983555, 23.9555926322937, 14.657211031232562, 5.26198022706168, 0.38175096682139803, 0.6855994910001755, 0.16669115184673242, 0.16761980844395502, 0.2417331486940384, 0.1805662430290665, 0.10591075329908303, 0.18019587147448743, 0.16443467007151671, 0.7615127946649278, 6.835320762225559, 0.12524531010006154, 0.1837722531386784, 0.11397550840462957, 0.11424586389745985, 0.13528621702321939, 0.258951191923448, 0.2431087563080447, 0.12474489052380834, 2.2827170874391283, 8.102928400039673, 7.607043283326285, 13.229114770889282, 20.316810607910156, 18.205569199153356, 12.54243733201708, 4.745822003909519, 2.478650208030428, 1.4315874044384276, 0.596196422619479, 1.1256228280918938, 0.4525209479033947, 0.17951424233615398, 0.11415291817060538, 0.23948814773133822, 0.10031827446073294, 0.16011099064988749, 50.17997360229492, 75.1258269718715, 72.28347178867885, 67.46739741734096, 44.48330886023385, 25.35219097137451, 33.84088509423392, 17.522281612668717, 5.858696733202253, 37.179348605019705, 44.46733842577253, 5.7819347722189764, 50.80641276495797, 81.31522669110979, 80.41298920767647, 28.11592207636152, 0.509228806410517, 0.2389165498316288, 0.22622668290776865], [0.028591552217091833, 0.8190828540495464, 6.354795507022312, 6.988194593361445, 6.419730765478952, 4.882173887320927, 0.13592384995094367, 0.23968207303966793, 6.0057132329259595, 35.02894367490496, 22.31548077719552, 8.148530295916967, 20.536863531385148, 11.341361301285879, 17.864436967032297, 30.83616440636771, 44.07206235613142, 52.470065116882324, 28.98001742362976, 0.7907985832009996, 0.244429348302739, 0.08781870268285275, 0.1305409637945039, 0.030173414120716707, 0.017896086310169528, 0.04799283615180424, 0.09294234775006771, 0.07635367967720542, 0.05135047169668334, 0.5188648722001484, 0.9340899799551282, 3.0620557027203694, 10.714420999799456, 17.568591356277466, 14.297702550888062, 7.831225173813956, 23.74506742613656, 30.338159220559255, 17.424143518720353, 5.955023952892848, 5.222399379525866, 4.402410328388214, 0.09113328518079859, 0.6270015867693084, 0.0496438373811543, 0.14388366283050605, 0.2172093324895416, 1.2253554250512804, 2.1898670068808963, 0.5775317155889103, 0.2698799212064062, 0.12151552523885455, 2.045031807252339, 5.083232172897883, 4.75510436296463, 6.222123997552054, 8.617691772324697, 9.08131640298026, 22.048445871898107, 34.84458017349243, 39.17918954576765, 38.097014563424246, 41.010554041181294, 39.79005779538836, 40.6709052494594, 38.53207949229649, 37.78082636424473, 37.56030791146414, 38.82337924412319, 37.063188620976035, 37.39784165791103, 38.57362971987043, 39.45815971919468, 38.2182571547372, 38.84869500568935, 40.466972146715435, 42.45056472505842, 40.750614983694895, 41.4210501398359, 40.7713623046875, 40.55962984902518, 40.10349798202515, 38.60865906306675, 37.73531218937465, 39.19571236201695, 37.85708631787981, 37.435705866132466, 39.628533022744314, 39.24441576004028, 40.28218827928816, 40.062173570905415, 39.702110971723286, 37.62640959875924, 36.68844100407192, 39.47543641499111, 41.13278675079346, 39.62834194728306, 37.454587595803396, 39.101810932159424, 40.987340109688894, 38.613557543073384, 38.134309019361226, 37.15246255057198, 34.76170900889805, 34.96085827691214, 32.85319866452898, 32.53408179964338, 33.175483907972065, 37.66257149832589, 35.16189398084368, 35.7864362852914, 32.05879027502877, 32.2462283543178, 32.18871464048113, 32.70802995136806, 25.078484058380127, 8.905566930770874, 0.6854334941932133, 0.07476829617683377, 0.22516409706856522, 0.13451958101774963, 0.06436074285634927, 0.030527432981346334, 0.09969987800078732, 0.016325167480057905, 0.05965099057980946, 0.05295836559629866, 0.01780689966731838, 0.07659382000565529, 0.09656389270509992, 0.3420074065881116, 0.0358938578782337, 0.027642256280939494, 0.023636867458532964, 0.023977127325321947, 0.07100894754486424, 0.09592686367354222, 0.08555540163069963, 0.29201644765479223, 5.962390780448914, 6.119183395590101, 8.308555126190186, 15.58359524181911, 25.19664338656834, 26.286648988723755, 18.359711510794504, 4.672675711768014, 1.3007582532508033, 0.9209904542991093, 1.705589507307325, 0.13796948375446455, 0.1515083336936576, 0.038160850160888264, 0.08297858347318002, 0.22619408608547278, 0.3195600296769823, 3.0898100648607527, 56.22269684927804, 57.27235426221575, 61.3345490864345, 50.04612350463867, 31.52762828554426, 27.504904440471105, 32.316412108285085, 13.284138424055916, 10.52243619305747, 19.293356588908605, 2.4954822191170285, 15.408830676759992, 58.720998082842144, 40.34111247743879, 60.06268828255789, 5.99841719014304, 0.3136144887123789, 0.1513565182685852, 0.2369252938245024, 0.07397582834320408, 1.2365896850824356, 11.280399543898445, 16.795942987714493, 12.01499957697732, 12.720160961151123, 0.2581662897552763, 0.4634468544806753, 12.539491295814514, 46.7570686340332, 33.56081015723092, 10.732213599341256, 16.6416460786547, 15.418544258390154, 23.42219853401184, 37.77330493927002, 51.37443494796753, 58.55788912091936, 51.73604004723685, 10.13003407205854, 0.3334821569068091, 0.34993223420211245, 0.04187667416408658, 0.11071345130247728, 0.04113803790616138, 0.0958313870110682, 0.04979582243998136, 0.061734995538634915, 0.08879505350653615, 0.7265984224421638, 1.7224585392645426, 4.017089290278299, 15.03157649721418, 21.019103254590714, 19.04773255756923, 14.04917504106249, 25.252041373934063, 35.02576487404959, 19.628346613475255, 5.384194263390132, 4.899728511060987, 2.341860370976584, 0.2473122536071709, 0.07344667280891112, 0.05515243911317416, 0.057204254370714934, 0.42227516802293913, 1.4437626025506427, 0.3853189753634589, 0.6911671693835939, 0.6022980809211731, 0.6327747798391751, 3.382351807185582, 6.338559738227299, 6.142194960798536, 5.7493464180401395, 11.78383127280644, 14.148266775267464, 22.096801859991892, 36.098327023642405, 40.681035723005024, 38.91423041479928, 40.59379761559622, 40.611112526484895, 39.57885340281895, 38.62114497593471, 37.991874422345845, 37.60562058857509, 40.643317426954, 40.965929235730854, 39.614556721278596, 40.98886523927961, 41.809999874659944, 41.19109255926949, 41.24941921234131, 43.1307829448155, 45.08039535794939, 44.38357441765921, 44.95582110541207, 43.104546546936035, 41.882281984601704, 43.38001830237252, 39.98272092001778, 43.040053367614746, 43.445616245269775, 40.48750754765102, 40.6662985937936, 43.52229656491961, 41.699123995644705, 44.435432297842844, 42.54325022016253, 41.34668009621756, 39.87388433728899, 40.39107697350638, 41.04550348009382, 42.55386011941092, 41.7519337790353, 42.52481664930071, 41.39095401763916, 43.1127211025783, 41.133307865687776, 39.85530138015747, 39.055469921657014, 38.77009350912911, 37.081590924944194, 36.24773761204311, 35.685937540871755, 36.144914695194785, 39.228424480983186, 35.535946777888704, 35.952470438820974, 34.936209542410715, 32.64609718322754, 36.43468584333147, 30.483122961861746, 15.804914474487305, 3.6547033871923174, 0.7657105922698975, 0.02194378518366388, 0.12666690881763185, 0.07883303306464638, 0.057333583145269325, 0.04905790542917592, 0.034260037155555825, 0.05636327467592699, 0.04386102947007332, 0.051110070132251294, 0.0193614013426538, 0.09939907664167029, 0.039682787244341204, 0.4106702650231974, 0.039926754510296245, 0.03818001538248999, 0.0026684924793828812, 0.12656149161713465, 0.07791973171489579, 0.06422373306538377, 0.04812933364883065, 0.38381412039910046, 6.327423512935638, 8.03649319921221, 8.966222967420306, 17.215400525501796, 27.826135294778005, 30.8267183303833, 31.292674950190953, 21.411568777901785, 4.965141023908343, 1.3667785163436617, 2.065142716680254, 0.1999116971024445, 0.07345344458839723, 0.051786488121641536, 0.018335198551150303, 0.5670922643371991, 0.20009369376514638, 5.338523754051753, 68.4141867501395, 61.04697009495327, 68.7306980405535, 58.77038587842669, 40.253297669546946, 23.467679704938615, 26.456883328301565, 19.503711564200266, 14.466046980449132, 28.175860711506434, 2.9443243401391164, 37.93673351832798, 81.59776823861259, 57.50990969794137, 65.11149256569999, 7.215406332697187, 0.21939004904457501, 0.14621398278645106, 0.04476789491517203, 0.10651981990252223, 1.1719069502183368, 28.86598185130528, 39.35194260733468, 31.94910601207188, 29.440976551600865, 0.2904510130839688, 0.2856583573988506, 23.705141339983257, 66.22175216674805, 37.0587591443743, 17.321365765162877, 27.034987347466604, 12.93178745678493, 27.356412751334055, 45.520733969552175, 59.39832237788609, 66.11990547180176, 64.65451649257115, 11.237253836223058, 0.3674309737980366, 0.39692143563713345, 0.1770128637020077, 0.335213235446385, 0.1515436310853277, 0.1427129049386297, 0.13168817652123316, 0.19917902856000833, 0.21070196452949727, 1.5189200724874223, 3.506761908531189, 5.63382306269237, 18.500806842531475, 24.22899729864938, 19.412938560758317, 17.888220650809153, 28.88344267436436, 36.64866951533726, 26.455801146371023, 12.313060794557844, 13.639279961585999, 4.973048508167267, 0.46584908557789667, 0.7233092646513666, 0.29323181243879454, 0.2585544389273439, 0.4355396862540926, 3.1184878860201155, 3.8471541575023105, 1.990088926894324, 0.3874519094824791, 1.6791410808052336, 3.6627342019762312, 9.335256559508187, 6.886345727103097, 9.548552359853472, 18.218206235340663, 18.54161361285618, 30.561887741088867, 38.85491711752755, 40.49768318448748, 39.87193536758423, 39.598579338618684, 40.73691313607352, 39.71882138933454, 37.43784591129848, 37.18582432610648, 36.99811526707241, 37.87192072187151, 42.71156685692923, 40.889919417245046, 44.16675935472761, 44.411224773951936, 44.49098661967686, 42.82494408743722, 45.22351087842669, 46.7815123966762, 45.38710968835013, 47.409959588732036, 46.228845732552664, 43.954648222242085, 45.85561629704067, 42.728867871420725, 45.015433175223215, 43.76470184326172, 43.89503615243094, 42.35718093599592, 46.67311702455793, 45.24980981009347, 47.33726406097412, 45.97265522820609, 44.5413749558585, 41.28892319543021, 42.57257856641497, 44.94614921297346, 47.100035190582275, 44.15218550818307, 44.33861262457711, 44.60682698658535, 45.73943199430193, 43.342129775456016, 41.7430921963283, 42.20895848955427, 42.98912654604231, 41.00625658035278, 37.80649995803833, 37.19116749082293, 37.803974287850515, 41.87749120167324, 35.730100291115896, 39.685893876211985, 34.324180943625315, 33.6579008102417, 33.92780358450753, 35.72522612980434, 37.12689665385655, 18.381706033434185, 4.354011348315647, 0.6149512933833259, 0.287660822804485, 0.21346604478146347, 0.1275697403720447, 0.18985172334526265, 0.23513773402997426, 0.2881839190210615, 0.11110803298652172, 0.1654915969286646, 0.22688917735857622, 0.13853116147220135, 0.37824356502720285, 1.2560399728161948, 0.170222438073584, 0.08433485283915486, 0.12618763239255973, 0.16944447053330286, 0.13021738401481084, 0.3156140499881336, 0.1667300590447017, 1.1429861592394965, 7.454544220651899, 13.007832884788513, 18.928473676953995, 23.752957105636597, 29.136065278734478, 32.95481259482247, 33.27112933567592, 26.286723681858607, 7.795111043112619, 2.15532078061785, 4.170081675052643, 0.716596816267286, 0.2986890253211771, 0.15172007733157702, 0.10200075632227318, 0.6148830056190491, 0.32730504551104134, 4.087081100259509, 75.5583940233503, 67.26935291290283, 72.79172556740897, 62.15512439182827, 45.12493331091744, 38.46797888619559, 50.23184537887573, 35.96663086754935, 31.144879817962646, 45.77770962033953, 11.629290308271136, 38.86657272066389, 92.69934981209892, 65.52720328739711, 76.42334052494594, 11.745732562882559, 0.30635093418615206, 0.22802595421671867, 0.35457732209137505], [0.03837815439328551, 0.14627479309482233, 6.027859747409821, 5.222079762390681, 5.631516260760171, 5.290532112121582, 3.6284129236425673, 0.7829634036336626, 16.824189152036393, 36.75634574890137, 17.48279847417559, 23.617694786616735, 23.601654870169504, 29.175357341766357, 26.820816074098857, 27.440272297177994, 44.11487715584891, 56.546246664864675, 44.25547048023769, 12.593685507774353, 0.6323760183794158, 0.12462869818721499, 0.21860444119998387, 0.042583643192691464, 0.0518340466410986, 0.07207886834761926, 0.028616793719785552, 0.09112664910831622, 0.1569072739886386, 1.4018746273858207, 3.8154877424240112, 10.64324973310743, 21.65905840056283, 28.409023148672922, 23.038147279194423, 30.737743173326763, 37.867498193468364, 44.8970046043396, 32.28310244424002, 14.806248153959002, 12.995431218828474, 7.523660557610648, 1.4963629628930772, 1.3113899741853987, 0.7804995615567479, 0.9052942022681236, 0.10880746679114443, 0.07357116362878255, 0.5884639461125646, 0.4016245518411909, 0.5315207445195743, 2.2526696026325226, 4.285597213676997, 5.061207686151777, 5.341242236750467, 3.6600621853555952, 5.76589789560863, 9.693406667028155, 14.406409723418099, 26.088409934725078, 35.6623067174639, 36.46644605909075, 36.0682760647365, 38.34659385681152, 40.32466261727469, 37.6097651890346, 39.59651572363717, 39.55585139138358, 39.29415096555437, 39.61906957626343, 40.44108663286482, 37.97028636932373, 39.31124005998884, 39.357608863285606, 41.067518847329275, 42.21129308428083, 41.86896576200213, 42.52467768532889, 39.06048304694039, 37.38450806481497, 38.348421233040945, 39.43851021357945, 38.12817028590611, 38.52782719475882, 36.93844413757324, 36.96489245550973, 37.50355502537319, 37.16553558622088, 39.239562443324495, 39.610287053244456, 37.736059120723176, 38.13075154168265, 36.522438117435996, 37.93673699242728, 36.68228142602103, 36.569147382463726, 38.101027148110525, 36.48713779449463, 39.29076024464199, 38.07341848100935, 37.093441077641074, 37.206394468035015, 35.90824515478951, 35.7696077483041, 34.48032086236136, 34.28559064865112, 32.51055519921439, 35.35456057957241, 35.85427502223423, 34.43678344999041, 34.24884857450213, 34.346286637442454, 31.473863124847412, 34.37749447141375, 17.13541633742196, 1.9215466848441531, 0.4176085027200835, 0.1019069217145443, 0.030968884471803904, 0.1774656908320529, 0.06902664141463381, 0.039952063866491826, 0.04335337671052132, 0.09973329585045576, 0.05537327851301857, 0.13210394206855977, 0.062425506700362475, 0.01442541361653379, 0.04184441321662494, 0.04010160619925175, 0.051803227580551586, 0.04804201976263097, 0.048552240777228556, 0.07190521766564675, 0.13184480954493794, 0.11147324088960886, 0.07778777022446905, 0.15963840458009923, 5.079859691006797, 11.931010620934622, 17.02756987299238, 22.36720664160592, 30.12996687207903, 29.764755657741002, 34.76855993270874, 39.785107203892295, 30.4878477369036, 11.281750968524388, 4.000834848199572, 2.0280139318534305, 1.7457103601523807, 0.10222339044724192, 0.19037369319370814, 0.30165216060621397, 0.3947529191417353, 0.6039757994668824, 14.240097641944885, 63.13209669930594, 57.34988921029227, 62.46950953347342, 45.305572577885215, 41.63324812480381, 67.10216535840715, 45.702373777117046, 39.33096946988787, 39.69857781273978, 14.139215878077916, 5.482652842998505, 59.212812423706055, 47.11370577130999, 45.637623514447895, 46.555157457079204, 1.3251451275178363, 0.1246525419077703, 0.01586239133030176, 0.051751295902899334, 0.10127134474792651, 0.38271638644593103, 5.442895684923444, 18.275012969970703, 13.959929772785731, 12.146886808531624, 4.53770695413862, 2.1116543923105513, 22.33906991141183, 49.945127964019775, 25.557324375425065, 17.327518395015172, 12.30587375164032, 12.013756717954363, 27.541566610336304, 34.246326378413606, 56.60327400479998, 64.85988439832414, 58.17806237084525, 35.56406961168562, 2.456720607621329, 0.14568919023232801, 0.019610896972673278, 0.11442338222903864, 0.027872505265155008, 0.058363212538616996, 0.07786624958472592, 0.08423394789653164, 0.10197318065911531, 1.880574243409293, 6.69178227015904, 14.19854654584612, 24.740358659199305, 29.69624294553484, 26.343202114105225, 34.20818076814924, 40.59501007625035, 46.24002538408552, 34.60213320595877, 19.942868982042583, 15.155848503112793, 8.551224436078753, 1.7602897435426712, 1.0930210117782866, 0.4783326642853873, 0.3458145037293434, 0.34161961025425364, 0.13746781567377703, 0.39430961864335196, 0.738005736044475, 1.8400662456239973, 3.148341689790998, 5.883550439562116, 6.725431527410235, 6.033642819949558, 6.096446718488421, 8.318517974444799, 11.489866018295288, 17.527510132108414, 25.273400136402675, 35.46715613773891, 39.87768152781895, 38.25356789997646, 40.0611070224217, 40.81558411461966, 38.92342982973371, 40.17241368974958, 39.91908236912319, 40.93572194235665, 40.48880338668823, 43.04427787235805, 39.3336375781468, 41.84643275397164, 41.53947523662022, 41.3483441897801, 44.69801861899239, 44.10793243135725, 41.42460414341518, 41.832598890577046, 39.24702480861119, 40.312027318137034, 42.78244195665632, 41.25068725858416, 40.334021840776714, 39.133265427180696, 39.99384846006121, 41.68811457497733, 41.22803265707833, 42.7222010748727, 43.516310691833496, 39.74517590659005, 41.03484494345528, 38.58288124629429, 39.08090032849993, 37.60727425983974, 38.93946974618094, 39.697358403887065, 39.98557315553938, 43.20904050554548, 39.050488063267295, 39.70468875340053, 37.47185039520264, 37.446440832955496, 38.81604194641113, 35.768370968954905, 37.57833848680769, 34.24696213858468, 37.34049470084054, 36.71139437811715, 34.63061734608242, 34.538157667432515, 33.22023030689785, 31.878547055380686, 31.04567343848092, 11.74876458304269, 1.0793042906693049, 0.6535204723477364, 0.0784786342244063, 0.15187197418085166, 0.048038864574794254, 0.07590414344200067, 0.035710772166826894, 0.02659334970771202, 0.060054583208901544, 0.1253563862826143, 0.11798199984644141, 0.13493746359433445, 0.0819725263863802, 0.0420549863816372, 0.02343558513426355, 0.0893260750121304, 0.009655601660987096, 0.028280471052442278, 0.01865872404804187, 0.0725571812529649, 0.04589063627645373, 0.11588185253952231, 0.13894613991890634, 5.663234353065491, 14.654900755201067, 20.198232650756836, 29.597821712493896, 33.221206528799875, 34.09890644890921, 40.32840769631522, 44.43406350272042, 39.60150800432478, 19.945207050868444, 7.6196794509887695, 5.647002926894596, 2.558427687202181, 0.11707274935075215, 0.08318434921758515, 1.0770163791520255, 0.7087757502283368, 0.38432448729872704, 21.511145148958477, 69.71752984183175, 62.671264375959126, 68.83470562526158, 51.843511308942524, 51.19464683532715, 63.5190349306379, 47.43049498966762, 42.158608368464876, 50.89648573739188, 22.33019358771188, 7.35917672089168, 68.08652360098702, 56.76326322555542, 56.52127831322806, 50.71532188143049, 1.2757815420627594, 0.13404962766383374, 0.06798010971397161, 0.09663997005139079, 0.1929581787969385, 0.5456095742327827, 15.882364307131086, 50.25071668624878, 36.2987825529916, 33.15432664326259, 7.136489995888301, 5.14942809513637, 36.292563915252686, 62.84113393511091, 26.50311143057687, 36.92392587661743, 34.10825525011335, 35.90025820050921, 40.52520152500698, 40.11230829783848, 63.32545116969517, 73.79176589420864, 69.99320656912667, 47.910396644047324, 2.432747151170458, 0.3562300434069974, 0.29983460956386154, 0.2574420486177717, 0.15828015389186995, 0.16643504558929376, 0.17848251626959868, 0.24882248256887707, 0.1795582521174635, 1.857541399342673, 8.74913431916918, 18.265476567404612, 30.484161717551096, 33.55415030888149, 35.83699137823922, 42.16319070543562, 45.54214136941092, 50.03625358854021, 41.80914177213396, 29.629304000309535, 16.993184975215367, 11.444370082446508, 3.118250778743199, 1.7946942916938236, 0.8135968169995716, 1.731927522591182, 0.4561332240700722, 0.21756272709795407, 0.5285292193293571, 1.3055176607200076, 4.053968591349466, 4.9263240439551215, 8.64929825919015, 11.015807798930577, 10.249981692859105, 8.966597301619393, 11.630733796528407, 19.310551643371582, 23.787797110421316, 33.353375162397114, 38.142556531088694, 38.36050067629133, 38.94690431867327, 42.00981616973877, 40.6944249016898, 38.063305377960205, 41.67578499657767, 40.87453957966396, 42.96322018759591, 44.40960236958095, 46.271156787872314, 42.42040259497506, 44.692064012799946, 43.52710819244385, 45.37333835874285, 46.40596921103341, 46.38083062853132, 46.58135216576712, 42.03200871603829, 43.38260303224836, 42.438579082489014, 45.500274998801096, 42.51450204849243, 43.866579805101665, 41.91317367553711, 41.130709239414756, 44.07265642711094, 42.90521315165928, 45.850405148097444, 45.39686843327114, 43.31375333241054, 42.47372307096209, 41.27495731626238, 42.30628885541643, 40.80586358479091, 40.524180139814106, 41.78601121902466, 41.67344692775181, 44.9259785924639, 40.660472529275076, 42.7954455103193, 39.69332844870431, 39.17716761997768, 39.88313238961356, 38.11145292009626, 41.60363837650844, 37.32980489730835, 40.67542505264282, 39.424624238695415, 36.80863789149693, 36.587608746119905, 36.41827072416033, 33.49747385297503, 34.88083587374006, 28.02586473737444, 9.283802543367658, 1.2145606385810035, 0.30401899931686266, 0.4617239726441247, 0.24880351072975568, 0.16547364289207117, 0.06887171151382582, 0.07128424277263028, 0.1284560835255044, 0.17498058346765383, 0.24811878747173718, 0.17095934067453655, 0.18085026421717235, 0.1314721174005951, 0.15843438490160874, 0.20395233242639474, 0.12813908553549222, 0.1509931491953986, 0.17549468230988297, 0.2886654617530959, 0.1897395615066801, 0.2282521506505353, 0.3119496080492224, 6.87180141040257, 20.080347776412964, 24.987763166427612, 34.53143875939505, 37.08682639258248, 36.79716641562325, 43.86214338030134, 46.30905226298741, 46.93824986049107, 27.728923048291886, 11.86697254862104, 8.448051503726415, 2.983137194599424, 0.47470043918916155, 1.0312826846327101, 1.2729779439313071, 1.1998756208590098, 0.8331170209816524, 19.827000822339738, 79.07002748761857, 66.88099030085972, 76.48527676718575, 58.97137641906738, 56.03332717078072, 76.06026240757534, 52.904886858803884, 56.63995354516165, 58.70870671953474, 35.68627800260271, 16.008943114961895, 83.25726209368024, 69.53386810847691, 56.504262174878804, 70.6351158959525, 2.7389564343861172, 0.20336601031678064, 0.17941787679280552, 0.2373613475688866], [0.11800141951867513, 0.1465233133307525, 2.344319599015372, 6.074817844799586, 2.6335398852825165, 8.888450912066869, 4.002047743116107, 10.008933050291878, 20.9982100214277, 40.937948840005056, 12.109991005488805, 29.50136681965419, 47.051661831992014, 50.778300353458945, 23.29930921963283, 30.885083198547363, 33.45942204339163, 57.464089802333284, 48.27530908584595, 26.289054802485875, 1.9330893797533852, 0.17466244553881033, 0.10561372459466968, 0.021588463535798446, 0.02380999566854111, 0.06227268704346248, 0.026274137997201512, 0.043672966704304726, 0.37690671533346176, 4.001005947589874, 13.194647363254003, 23.481468405042374, 24.70606061390468, 23.789699179785593, 21.789985043661936, 27.20167636871338, 39.92011070251465, 45.89875766209194, 45.35341787338257, 40.42982707704817, 25.69742785181318, 16.114032881600515, 4.102268559592111, 6.697334315095629, 3.0904249804360524, 4.397026343005044, 3.3613256897245134, 4.5582288929394315, 1.2402893837009157, 2.885419032403401, 4.467974398817335, 7.903202431542533, 8.140586767877851, 8.817278776850019, 5.834485300949641, 4.4118481533867975, 4.32129966361182, 8.072732397488185, 12.093376125608172, 14.318849393299647, 20.149004663739884, 27.681609289986746, 35.499632017953054, 32.04372658048357, 34.61325032370431, 40.81779016767229, 39.95600162233625, 37.894606590270996, 41.07888262612479, 38.02174472808838, 41.29183101654053, 39.09096826825823, 38.224930899483816, 40.52776541028704, 38.18736546380179, 40.31761714390346, 40.25331851414272, 40.00552838189261, 40.7911160332816, 38.415943826947895, 38.320388725825715, 36.96455546787807, 38.825331687927246, 38.24135644095284, 37.67853151048933, 38.16562802450997, 40.78953879220145, 36.65084777559553, 39.52027661459786, 41.84808989933559, 36.379815919058665, 37.10774047034127, 37.01698310034615, 35.069833823612754, 36.26048755645752, 36.79447398866926, 39.322263377053396, 36.77571037837437, 40.06382724217006, 38.37262180873326, 39.22372055053711, 35.74502502168928, 36.578812326703755, 36.864494459969656, 35.80435916355678, 35.037903376988, 33.97466918400356, 33.87336792264666, 33.18863337380545, 33.24372216633388, 32.13410527365548, 27.973972116197857, 27.191856827054703, 18.14201750074114, 1.0821073459727424, 0.12026731935994965, 0.03592111462993281, 0.025219441823927418, 0.06189823749342135, 0.04064440368009465, 0.045031024010053704, 0.06156025241528239, 0.1270661045398031, 0.7655232080391475, 1.8551779261657169, 1.1976818357195174, 1.374704999583108, 0.6082680491464478, 0.054567477466272454, 0.0018854361385040516, 0.028059538354032805, 0.06593241994934422, 0.07091129278498036, 0.11108711375189678, 1.067066558769771, 4.497703569275992, 2.6079911419323514, 6.862540330205645, 15.88347601890564, 27.187225852693828, 30.15148891721453, 38.30750329153878, 40.07806062698364, 35.28957060405186, 35.274378367832725, 35.17111076627459, 28.028654439108713, 11.07409884248461, 11.171042714800153, 17.14379586492266, 7.2691832184791565, 0.70965057185718, 0.3113907394664628, 1.1970085118498122, 0.11246101824300629, 0.20004065946808883, 31.119640486580984, 62.43302454267229, 56.39769070489066, 56.11011866160801, 32.82721587589809, 25.412899119513376, 25.6081417628697, 33.710780075618196, 62.6620580128261, 56.870216846466064, 37.287928104400635, 26.44533368519374, 43.520622049059185, 34.08649001802717, 54.26957559585571, 20.358016899653844, 0.6143523369516645, 0.04720343868913395, 0.07727280285741601, 0.03146930065538202, 0.11389276784445558, 0.10492484191698687, 3.866817993777139, 14.251741085733686, 16.06454607418605, 20.730468136923655, 8.378504378455025, 3.9219154715538025, 43.75438724245344, 53.640311990465435, 18.17579616819109, 28.907103027616227, 44.68558829171317, 29.796786853245326, 26.07806580407279, 38.01384115219116, 42.94769443784441, 66.18334252493722, 56.78740126746041, 41.135107449122835, 8.117511800357274, 0.2431872763804027, 0.1948815948729004, 0.08779812950108733, 0.01320558152760246, 0.020863667695916126, 0.03730455932340451, 0.04454521329275199, 0.4844885511057717, 7.194418864590781, 14.67840129988534, 25.380364179611206, 26.586368220193044, 27.949955667768204, 30.91138560431344, 37.586335863385884, 48.05240045275007, 49.38642678941999, 48.58802318572998, 41.7057386807033, 26.645381007875713, 19.53561248098101, 6.406748924936567, 6.382368130343301, 2.704089722463063, 4.393005073070526, 3.583031850201743, 4.8532715524945935, 1.6410848200321198, 3.293460462774549, 6.077026069164276, 8.037345222064427, 10.667762977736336, 13.307433996881757, 10.99611052445003, 9.38301065989903, 9.235128675188337, 9.903199706758771, 13.29454595702035, 14.212257078715734, 18.657349756785802, 25.149150712149485, 35.27092858723232, 36.60579913003104, 34.462634222848074, 40.84370000021798, 38.5787227494376, 39.33249807357788, 43.01544632230486, 41.628036975860596, 45.61017465591431, 41.655906200408936, 39.37754324504307, 40.91035754340035, 40.7516850062779, 43.88026080812727, 41.7231821332659, 41.324841908046174, 42.69940750939505, 41.19618558883667, 41.5570923941476, 38.60468816757202, 40.701553753444124, 39.90028401783535, 40.04563685825893, 42.76617274965559, 41.87059511457171, 40.096473353249685, 42.74622794560024, 43.763395581926616, 39.57468448366438, 39.32944086619786, 37.957470417022705, 39.05208614894322, 37.86812005724226, 39.813466276441304, 41.03925357546125, 39.62893949236189, 40.02478878838675, 40.29942675999233, 41.410593100956504, 38.487381730760845, 38.86320979254586, 40.054978711264475, 37.729350634983604, 39.4545362336295, 37.46318599155971, 38.62327112470354, 34.67085089002337, 33.63833815710885, 31.445538793291362, 28.536720616476877, 26.010237489427837, 11.449219056538173, 1.330899755869593, 0.054315316889967234, 0.3736877180635929, 0.0853941613542182, 0.059410870607410154, 0.04052353284454771, 0.04200400126033595, 0.059360116188015254, 0.16597980287458214, 0.8491403268916267, 2.2267608557428633, 2.8717349895409177, 3.523472760404859, 2.156939276627132, 0.02222472073377243, 0.08634072449058294, 0.07865928738777127, 0.05003792034196002, 0.02626473519818059, 0.2182788122445345, 1.4991126039198466, 4.636337501662118, 3.2001474584851946, 8.346467103276934, 19.133049488067627, 33.79745190484183, 36.67755665097918, 46.39941358566284, 52.91265147072928, 43.66524880273001, 45.11847496032715, 43.194678579057964, 40.75611795697893, 21.01925958905901, 17.382249355316162, 24.433116265705653, 13.80912172794342, 3.5330443382263184, 3.06630192058427, 3.989190535885947, 0.06855647771486215, 0.4482127662215914, 41.1872467313494, 65.78940745762416, 60.96735068729946, 61.19033227648054, 46.5631548336574, 31.250676563807897, 29.74198293685913, 48.13493462971279, 72.98884596143449, 67.47868129185268, 48.65439932686942, 46.6952018737793, 57.95457703726632, 49.100678648267476, 60.929142543247764, 22.963763339178904, 0.5274732559919357, 0.2271837294101715, 0.06646758051855223, 0.11161676461675338, 0.39059545365827425, 0.2273854035884142, 8.421666588102068, 54.80824163981846, 33.25331762858799, 40.2896853855678, 43.70329366411482, 22.793612377984182, 71.66820880344936, 58.51164191109793, 21.39151280266898, 35.35407420567104, 59.18213612692696, 58.038764885493684, 33.820075239454, 46.58927658626011, 44.31719132832119, 75.8962015424456, 67.76689951760429, 58.74297523498535, 14.642758778163365, 0.3144885232406003, 0.5117672330566815, 0.1941656047212226, 0.21595702825912408, 0.19255075923034123, 0.1201432424464396, 0.11031346169433423, 0.7349087393709591, 8.63861800943102, 18.297261101858957, 30.877141407557897, 33.41296986171177, 33.89939587456839, 36.05272947038923, 42.27644634246826, 54.80250937598092, 51.75703750337873, 50.41244295665196, 48.47757114682879, 34.66570922306606, 28.86042329243251, 11.00083703654153, 7.728675842285156, 3.8104602864810397, 5.834111401012965, 4.871499717235565, 6.865250127656119, 3.761457247393472, 4.765384657042367, 7.463238154138837, 9.72229814529419, 13.641637137957982, 14.1396883555821, 15.038611548287527, 15.375540120261055, 14.28453745160784, 13.645601085254125, 20.83486829485212, 22.972677877971105, 26.414961372103008, 28.635176590510778, 38.834392138889854, 37.67830916813442, 39.01231813430786, 43.3834159714835, 39.37404830115182, 39.36691944939749, 44.86977113996233, 44.776998792375835, 48.34676088605608, 46.20473895754133, 43.13337114879063, 44.78199454716274, 43.12462336676461, 44.23816251754761, 44.78370380401611, 43.857251848493306, 44.46135255268642, 43.97209514890398, 42.068903650556294, 40.37646838596889, 42.639764172690256, 43.301475865500315, 42.14094952174595, 46.489774908338276, 45.50339126586914, 43.79688242503575, 46.316528524671284, 47.2920104435512, 40.69102028438023, 41.26042863300869, 40.3592403275626, 41.46974311556135, 37.85641929081508, 41.56746258054461, 43.36759492329189, 40.12883111408779, 43.270559855869834, 43.09323140553066, 42.81240953717913, 39.35996430260794, 41.656211921146934, 41.77773591450283, 41.52749654224941, 41.22052165440151, 39.66991301945278, 39.81371293749128, 36.387045519692556, 37.02654382160732, 34.69517305919102, 32.415781770433696, 30.131589276450022, 25.56442196028573, 4.806220088686262, 0.3202094691140311, 0.5166083361421312, 0.23138103846992764, 0.16622968018054962, 0.17746989774916852, 0.11551206452505929, 0.10447246262005397, 0.339257792702743, 0.9254468551703862, 2.062364305768694, 2.3480868254389082, 2.5836824348994663, 1.53705823634352, 0.16537210691188062, 0.1399789923535926, 0.1364468511726175, 0.21720523413802895, 0.10035917655165706, 0.3332511835864612, 1.9929470249584742, 5.874770522117615, 3.7074137244905745, 10.846875378063746, 24.688704013824463, 35.64581864220755, 41.14244474683489, 47.80318593978882, 53.83216912405831, 45.073957851954866, 49.91040434156145, 48.74422216415405, 51.23892423084804, 37.10734094892229, 24.98395902769906, 26.223024334226334, 12.824434314455305, 3.63523496900286, 2.3923650894846236, 4.487095841339656, 0.5867833505783762, 0.3582040917660509, 45.12956428527832, 73.78260122026715, 68.1043040411813, 66.53450448172433, 49.89942618778774, 39.401667390550884, 38.38740757533482, 43.55785744530814, 76.14635753631592, 71.79836245945522, 58.50297055925642, 60.02174254826137, 69.96551104954311, 53.42291327885219, 82.7096745627267, 38.950364521571565, 0.6487022766045162, 0.4404219357030732, 0.13461084397775785, 0.16971204403255666], [0.14077173838657991, 0.2605412708861487, 1.393782147339412, 5.467194403920855, 16.113035815102712, 7.32018951007298, 22.16384850229536, 41.69218621935163, 52.81378207887922, 47.46728917530605, 20.611091136932373, 38.63995027542114, 41.881948471069336, 55.62016643796648, 25.400018896375382, 28.505877562931605, 33.064288411821636, 57.23802668707711, 51.79133381162371, 31.255001817430767, 4.848822099821908, 0.13602576591074467, 0.14059787057340145, 0.05063126528901713, 0.10653819463082723, 0.10152755278561797, 0.05312462363924299, 0.3022773356309959, 4.8471128429685315, 11.831577556473867, 20.452441181455338, 37.318138871874126, 41.31953001022339, 29.164938517979213, 10.281521303313118, 13.206960439682007, 39.62343651907784, 53.36621250425066, 41.70632232938494, 50.237970215933665, 33.07603434153965, 13.997363192694527, 7.214854385171618, 11.610313040869576, 7.886961885860988, 10.16762295791081, 8.556759544781276, 10.973977037838527, 11.223077774047852, 13.499006254332405, 9.059691003390721, 6.991149314812251, 9.151967423302786, 12.205370664596558, 16.403225592204503, 8.569908142089844, 5.85393808569227, 6.845282741955348, 8.014806134360176, 7.124713667801448, 6.997718836580004, 14.464653866631643, 18.203338827405656, 27.552972078323364, 29.8272442817688, 35.00554214205061, 40.38741179874965, 39.87793861116682, 40.65784958430699, 40.21587814603533, 37.78846590859549, 39.3103472164699, 38.9456501688276, 40.18257890428816, 37.34089422225952, 40.253221239362446, 39.26940843037197, 39.6422244480678, 39.97964981624058, 39.082981313977925, 39.67828212465559, 37.40750660215105, 36.016407762254985, 36.68852438245501, 37.87891755785261, 37.76526239940098, 35.909329073769705, 40.96294151033674, 39.12072045462472, 38.99495111192976, 35.48796599251883, 35.71008253097534, 34.03291940689087, 34.570383412497385, 35.73518289838518, 35.66013193130493, 38.985352175576345, 38.70603806631905, 38.2956531388419, 38.18721955163138, 38.24833938053676, 36.05646760123116, 37.66850525992257, 33.48582172393799, 34.17580563681466, 38.19828803198678, 35.60878126961844, 36.299894264766145, 35.054315022059846, 32.08612101418631, 28.929580450057983, 25.519274302891322, 15.018423557281494, 1.6626363950116294, 0.11478760625634875, 0.05366717345480408, 0.12571567057498864, 0.13502435678882257, 0.07148952675717217, 0.08034698039825473, 0.14380093584103243, 0.4057849214545318, 1.2172726073435374, 0.8442325645259449, 1.4908801828111922, 2.376377067395619, 6.712291181087494, 6.821212444986616, 1.9075115408216203, 0.26014093522514614, 0.09367547769631658, 0.48670437506267, 2.2206605545112064, 6.613683215209416, 12.557693839073181, 14.911443880626134, 11.775734884398323, 22.080932174410137, 29.12047873224531, 40.448879037584575, 36.502132007053916, 41.236585889543804, 45.60592583247593, 36.591551848820274, 35.617216382707866, 33.6947922706604, 26.765049832207815, 14.269274864877973, 13.500585232462202, 23.997554540634155, 33.10173225402832, 18.571263313293457, 10.754423516137258, 4.0271090269088745, 0.11644385595406805, 2.0615042490618567, 45.309894357408794, 55.2184111731393, 52.111357416425435, 45.89542947496687, 23.94737117631095, 23.537780080522808, 13.487929088728768, 24.310619524547032, 25.33782035963876, 43.252459798540386, 42.22243799482073, 38.94724825450352, 29.755743844168528, 25.751057522637502, 51.36621870313372, 4.5334203498704095, 0.24118209683469363, 0.058406910193817954, 0.053823979504938634, 0.030662281638277427, 0.06111604267997401, 0.26872983149119783, 2.8068025537899564, 15.585578952516828, 27.32510069438389, 27.304718153817312, 44.42219597952706, 53.00793211800711, 69.07006195613316, 58.049142020089285, 26.707751512527466, 30.224601336887904, 44.369882992335725, 52.94641276768276, 25.198370013918193, 33.192083154405864, 42.83782604762486, 64.30111026763916, 64.04861967904228, 45.705580370766775, 14.337693776403155, 0.40089868221964153, 0.051435322500765324, 0.046064734791538546, 0.03912660226758037, 0.07175356508897883, 0.030533648362117152, 0.48524199639047894, 4.991850333554404, 14.282662306513105, 25.90648177691868, 39.58262627465384, 45.83264555249895, 39.203084400721956, 16.67288170542036, 18.170270613261632, 48.582179750714985, 57.864132336207796, 49.311420985630576, 49.4751935005188, 42.69623218263899, 26.252118178776332, 12.30931224141802, 12.732284699167524, 8.932817765644618, 10.03371901171548, 12.182057721274239, 14.194850972720555, 15.468578236443655, 17.64384729521615, 12.928051931517464, 9.91544416972569, 11.655738626207624, 16.47035387584141, 21.90429333278111, 16.648479631968907, 13.011129805019923, 14.033708350999014, 12.998417207172938, 12.103271228926522, 6.4339624132428845, 9.355111036981855, 16.577800818852015, 27.5767331804548, 33.25798681804112, 37.56462969098772, 40.97743892669678, 39.513418742588584, 42.08402987888881, 39.591693673815044, 39.1602383341108, 41.77317789622715, 40.12516246523176, 41.358860288347515, 39.974233695438926, 42.976911612919395, 43.578566551208496, 43.39615549360003, 43.304845741816926, 40.31739827564785, 41.53458023071289, 38.57822942733765, 37.428243500845774, 39.32799564089094, 37.798297609601704, 39.04019430705479, 38.98016881942749, 43.00459671020508, 41.69492033549717, 41.87636906760079, 37.20676619665963, 36.407521860940115, 37.043553011757986, 35.893268312726704, 36.26724815368652, 38.119901929582866, 39.324879373822895, 38.487152440207346, 40.33025939123971, 39.76039246150425, 39.41829095567976, 38.476268087114605, 40.20607076372419, 37.70548357282366, 37.93152584348406, 40.17243800844465, 38.116000516074045, 38.26247549057007, 41.97895574569702, 35.93653474535261, 29.615595204489573, 26.207175493240356, 11.11281246798379, 1.245363848549979, 0.08072214919541564, 0.11808994119720799, 0.06763223159526076, 0.06725817559553043, 0.040670079445200305, 0.04282828899366515, 0.0964509980486972, 0.29798609018325806, 1.454836185489382, 1.339549828852926, 3.076188338654382, 8.37752033982958, 6.902763017586299, 8.901449254580907, 4.590434227670942, 0.7089477724262646, 0.099191485638065, 1.6925082206726074, 4.492944487503596, 9.294726848602295, 16.44001282964434, 19.974149772099086, 15.459066152572632, 28.580383096422466, 36.16093029294695, 48.63486794063023, 45.40790217263358, 52.26244599478585, 51.618240288325715, 45.276435307094026, 45.224452359335764, 43.267912592206685, 39.43167666026524, 27.904601301465714, 17.65058704784938, 29.361541271209717, 37.44671876089913, 30.54911000388009, 24.465873547962733, 10.401944875717163, 0.09529034354324852, 3.9758795244353156, 56.1857567514692, 60.06539808000837, 62.20037106105259, 56.303448813302175, 36.30940634863717, 28.20910610471453, 18.191040515899658, 31.46634864807129, 35.09165464128767, 64.21275002615792, 65.88880838666643, 46.53727626800537, 50.73396042415074, 38.411021028246196, 58.45430537632534, 7.038373180798121, 0.4225451706775597, 0.1276362096624715, 0.053080803847738674, 0.02311870758421719, 0.21916400188846247, 0.4868416019848415, 2.9994776206357137, 45.20823178972517, 66.42213126591274, 44.85190732138497, 68.28640937805176, 71.4728810446603, 84.37936837332589, 62.30940219334194, 30.808121476854595, 43.908981187003, 47.543003695351736, 63.45746694292341, 36.60903351647513, 44.592392104012625, 45.36288826806204, 69.87518446786063, 72.76921340397426, 62.274459702628, 23.84374574252537, 0.3582541405090264, 0.2470853514969349, 0.1286646787609373, 0.13399681049798215, 0.15835688263177872, 0.15810773814363138, 0.4805420828717095, 5.539929449558258, 16.721312386648997, 30.955697740827286, 43.31481988089425, 47.83236837387085, 52.706199645996094, 24.583084447043284, 28.430103983197892, 55.8022335597447, 56.36449916022164, 49.53166151046753, 52.518070220947266, 42.605453968048096, 34.826730251312256, 23.472706726619176, 17.611102172306605, 10.192539198057991, 10.667519790785652, 12.911503059523445, 15.318168844495501, 16.791739327566965, 19.078782320022583, 15.435841798782349, 13.59026997429984, 16.629870619092667, 20.244078602109635, 24.314654690878733, 21.376789569854736, 18.779921191079275, 16.54713147027152, 16.035075289862498, 14.388995800699506, 16.050477709089005, 17.64125040599278, 22.221219778060913, 33.286067962646484, 37.854824679238455, 40.245432308741975, 41.387611934116904, 40.5904346874782, 42.93751185280936, 41.94444056919643, 40.81067173821585, 42.385029315948486, 43.707921164376394, 45.1159006527492, 42.12181765692574, 45.346500941685264, 46.52254261289324, 44.3087284224374, 44.31877899169922, 42.45839534487043, 44.51533658163888, 40.1082957131522, 38.82012053898403, 42.169395446777344, 41.47768490655081, 42.16569553102766, 40.29476451873779, 46.89284338269915, 45.138367652893066, 45.803140027182444, 39.901635442461284, 40.68820626395089, 39.17022289548601, 38.82243081501552, 40.740359442574636, 40.89908409118652, 41.89342342104231, 42.437241554260254, 42.69842086519514, 42.3310626574925, 43.51400736400059, 41.37535531180245, 44.26676825114659, 38.4943334034511, 38.96843678610665, 43.223114081791465, 39.944735118321006, 41.071590491703574, 42.026387623378206, 39.011866501399446, 30.792227472577775, 31.59253488268171, 23.867741346359253, 3.2663774703230177, 0.4179869352706841, 0.21362140215933323, 0.19682794543249266, 0.20232844884906495, 0.12889396931443894, 0.21359637778784546, 0.2880028044538838, 0.44618657923170496, 1.7052927975143706, 2.764889282839639, 3.659675257546561, 9.68088948726654, 9.513582076345172, 11.460046086992536, 4.522662367139544, 0.42191391597901073, 0.1935938439731087, 1.25620499253273, 4.238692096301487, 8.56396656376975, 21.293522357940674, 25.945561919893535, 20.268227066312516, 37.059047494615825, 40.40991006578718, 49.238746302468435, 46.239076954977854, 50.975597926548545, 53.89464732578823, 47.02353204999651, 48.98694705963135, 49.57673794882638, 48.27354424340384, 35.3979868207659, 23.950087921960012, 33.051013878413606, 36.5201347896031, 29.97361155918666, 23.144946302686417, 14.032030361039297, 0.1922038649874074, 3.2916617478643144, 59.50023855481829, 64.53619561876569, 67.23116561344692, 57.42073304312569, 39.794129439762656, 34.79612691061837, 23.8568309375218, 36.04610088893345, 41.7508533341544, 60.34108870370047, 61.623837334769114, 59.37157876150948, 51.41394240515572, 47.75555256434849, 81.56713363102504, 11.462741988045828, 0.7486717637096132, 0.13572607056370803, 0.20459095601524624, 0.10255290062299796], [0.08391658349760941, 0.3193567134439945, 0.026532625912555625, 10.184952633721487, 28.749748911176408, 15.865881443023682, 20.607356480189733, 45.898479734148296, 48.515463147844585, 59.64635222298758, 27.142621891839163, 38.38289819444929, 55.56595311846052, 61.065438406808035, 55.426078932625906, 34.23179422106062, 31.316729613712855, 56.63001067297799, 57.00736733845302, 33.651723861694336, 7.564599343708583, 0.9660390998635973, 0.43871837854385376, 0.015919775036828857, 0.11237147876194545, 0.15039667620190553, 0.2683831000966685, 2.710126838513783, 10.484893339020864, 20.409367561340332, 31.616579123905726, 57.47993516921997, 47.06159428187779, 20.800639731543406, 7.938691224370684, 25.27484015056065, 50.02517121178763, 45.80091660363333, 44.56905657904488, 46.44472278867449, 20.456823757716588, 11.010978800909859, 17.309159517288208, 28.260891028812953, 18.952936547143118, 9.623007518904549, 14.065024750573293, 19.153352124350413, 23.3536319732666, 22.514027288981847, 31.84692927769252, 26.352776731763566, 22.175516264779226, 25.71422859600612, 27.383151156561716, 22.25489248548235, 11.993523563657488, 15.136148623057775, 15.198102235794067, 12.018683859280177, 6.7540872011865885, 1.811711949961526, 7.831860933985029, 13.047051123210363, 20.04217263630458, 31.392690794808523, 37.88938501902989, 37.2034136908395, 39.14869042805263, 39.19462844303676, 37.37236608777727, 42.98046909059797, 39.099521500723704, 37.260427134377615, 38.421335629054475, 41.36374487195696, 39.581695216042654, 41.135416643960134, 40.66691698346819, 36.678859438214985, 37.17919921875, 36.33346448625837, 36.75380270821707, 34.96321719033377, 35.13053676060268, 35.24955940246582, 38.20866169248308, 37.85565846306937, 37.0008076940264, 38.61825105122158, 35.40681103297642, 35.64296293258667, 34.88183988843645, 35.6135790007455, 33.74373538153512, 33.976319381168906, 33.881657123565674, 37.21695920399257, 38.42672743116106, 38.612751552036826, 36.41558871950422, 34.72305270603725, 35.67143317631313, 36.00513778414045, 36.48629011426653, 37.076018469674246, 35.15954548971993, 32.59341246741158, 36.00493628638131, 37.26315082822527, 30.687507697514125, 19.068670954023087, 3.496679420982088, 0.08162671101412602, 0.059623706686709604, 0.025075170011924844, 0.1250982987029212, 0.05244787656036871, 0.14053796950195516, 0.04202839120158127, 0.08853227724986416, 0.9779083601066044, 4.113806043352399, 4.4491347926003595, 7.1947497725486755, 22.881022453308105, 20.473261458533152, 16.10795668193272, 8.739997438022069, 3.473012770925249, 4.270411925656455, 17.267239298139298, 27.711307627814158, 34.52574471064976, 29.807688576834543, 16.27712447302682, 20.25273605755397, 32.300632749285015, 40.85980592455183, 39.19450337546212, 41.08828353881836, 39.28585134233747, 36.80071347100394, 34.59256553649902, 35.860125405447825, 35.99855784007481, 31.555414131709508, 23.148713963372366, 16.152822937284196, 23.78198320525033, 32.39655957903181, 30.848865713391984, 33.76617111478533, 8.836640800748553, 0.2809416704944202, 10.03570967061179, 55.83844062260219, 57.78676414489746, 53.96005071912493, 29.90081180844988, 25.491297381264822, 24.41001350539071, 18.979591573987687, 31.810781274523052, 22.280383689062937, 35.87596035003662, 13.471593873841421, 21.54081048284258, 21.77619981765747, 41.909449441092356, 35.95547900881086, 0.46215188396828516, 0.06256170224930559, 0.09161359976444926, 0.03221811493858695, 0.04108221143750208, 0.17461945356002875, 0.32959387983594624, 0.656952936734472, 19.120676483426774, 35.49076959065029, 35.285502433776855, 56.18870278767177, 60.584643908909385, 63.29590742928641, 74.69173826490129, 35.56748117719378, 52.649245262145996, 60.35904284885952, 61.55760015760149, 55.73058373587472, 35.08342797415597, 37.00074863433838, 65.93159539358956, 63.520910944257466, 52.709767545972554, 23.024362053189957, 1.5153676973921912, 0.32007541773574694, 0.025070204831925885, 0.04882761403652174, 0.05872943824423211, 0.1949467613760914, 1.8653194734028407, 11.959850856236049, 26.0307867867606, 35.95116070338658, 55.0862911769322, 52.08422122682844, 31.49666711262294, 10.354115213666644, 29.585440022604807, 53.65892274039132, 52.38436950956072, 48.00257839475359, 51.40142175129482, 28.889890602656774, 17.715344258717128, 22.17025474139622, 28.6364654813494, 20.374192305973597, 12.388304574148995, 15.48552141870771, 23.804528372628347, 25.8431750025068, 27.97500044958932, 34.90881974356515, 35.62962933949062, 29.24484280177525, 30.698353835514613, 36.499627181461875, 29.75097390583583, 22.722990887505667, 25.196301187787736, 25.159209966659546, 20.457457780838013, 10.781061172485352, 5.382432460784912, 3.3363712344850813, 10.57778901713235, 19.73685141972133, 32.67171171733311, 40.373161043439595, 39.00975424902779, 41.33877304622105, 40.7699796131679, 42.210129261016846, 44.61816644668579, 42.308032853262766, 40.7137895311628, 41.17861359460013, 42.22677367074149, 41.926854678562705, 43.014181750161306, 41.962742124285015, 39.45343494415283, 40.32149771281651, 37.06619719096592, 36.7234981400626, 37.57731710161482, 37.86945758547102, 36.41103070122855, 39.460150378090994, 41.52099650246756, 40.57937315532139, 40.45961747850691, 38.44523395810808, 37.714599609375, 36.20545782361712, 36.601887294224326, 35.4924510547093, 36.26654291152954, 36.50855909075056, 39.16563361031668, 40.918928146362305, 40.358969347817556, 37.9829112461635, 37.57964127404349, 38.128983225141255, 40.03567314147949, 39.15397105898176, 40.79001126970564, 37.86611897604806, 34.95476123264858, 37.71809107916695, 43.10700968333653, 31.114113194601877, 18.844695772443497, 3.3132495837552205, 0.0987543190962502, 0.10269427339413337, 0.08947694727352687, 0.12426199072173663, 0.015420853326629316, 0.21061693052096025, 0.04575771126630051, 0.17804510545517716, 1.0069707206317355, 4.5568084205899915, 5.935475196157183, 7.469897133963449, 24.54722305706569, 28.009199483054026, 25.006420816693986, 13.693442906652178, 5.2296372311455865, 8.419089674949646, 26.951888629368373, 34.04070833751133, 39.600458826337544, 37.96010031018938, 24.30620047024318, 26.41277095249721, 39.01255784715925, 48.430382456098286, 47.097085680280415, 50.51562023162842, 45.65943390982491, 46.9100957598005, 42.3027035849435, 46.00311613082886, 46.61063534872872, 44.78452021735055, 38.801002570560996, 30.452311175210134, 27.96920738901411, 38.545982837677, 36.374069758823936, 44.30215890066964, 11.769809808049883, 0.317965743797166, 13.666087848799569, 63.72520882742745, 59.985007422310964, 60.33416134970528, 32.32650089263916, 31.967341559273855, 30.65959678377424, 22.725622517721995, 29.431328977857316, 28.15003773144313, 55.08032267434256, 19.874460492815288, 39.41921854019165, 28.186696427209036, 43.849129404340474, 46.21598809106009, 0.527434878051281, 0.1532224624284676, 0.09274636648063149, 0.05347687152347394, 0.1165047205452408, 0.18544649758509227, 0.47600458349500385, 0.286847964993545, 36.11064965384347, 80.76731259482247, 44.47511345999581, 63.20313508169991, 66.34503405434745, 76.42013045719692, 75.61266640254429, 40.622441564287456, 46.21396616527012, 60.314706393650596, 67.59893376486642, 69.11873408726284, 47.6485607283456, 47.059079033987864, 68.75924818856376, 74.26488263266427, 62.024984632219585, 40.34644174575806, 2.0280890592506955, 0.5546429923602513, 0.14609084225126676, 0.2696448766759464, 0.25756562341536793, 0.3631550632417202, 3.3316733837127686, 16.571392842701503, 34.496121065957205, 45.53951495034354, 61.2317087990897, 59.24018832615444, 39.37484386989048, 15.177822181156703, 42.9014333316258, 57.47293485913958, 53.04738398960659, 51.36188302721296, 55.32266889299665, 34.74097558430263, 27.346825974328176, 38.53212118148804, 36.84664453778948, 25.369743858064922, 13.205649835722786, 16.46810265949794, 25.86099192074367, 27.02932803971427, 28.995647396360123, 36.56259870529175, 39.502093178885325, 31.053163596561976, 34.32082148960659, 41.80887426648821, 34.44419370378767, 28.753964730671473, 29.24262285232544, 26.045735836029053, 21.196596724646433, 11.362235426902771, 9.527567063059125, 11.13694269316537, 15.572721311024257, 27.667976924351283, 38.03612402507237, 39.86602939878191, 37.51310879843575, 44.302405561719624, 40.68117468697684, 43.63205030986241, 47.19422149658203, 43.03809744971139, 42.02872221810477, 43.46789564405169, 46.218666621616904, 44.37552840369088, 46.19412211009434, 44.19913101196289, 40.15805523736136, 41.825907775333945, 38.44778047289167, 39.685813971928184, 40.28303248541695, 41.55869047982352, 38.699395588466096, 43.95012147086007, 42.992847306387766, 43.88618414742606, 43.037041323525564, 41.27193832397461, 38.841948304857524, 39.44180713381086, 38.48082957948957, 37.810258933476035, 37.466472489493235, 39.12078993661063, 41.53144659314837, 45.20287472861153, 42.212505544934956, 40.355297224862234, 40.7300900050572, 39.98883533477783, 40.769385542188374, 42.04987948281424, 41.60309641701834, 40.029475348336355, 36.167006492614746, 39.472705772944856, 45.499441214970176, 32.796004567827495, 26.661973306110927, 5.503751048019954, 0.2374920876962798, 0.2588398850389889, 0.11854709738067218, 0.2571829025234495, 0.1656384861895016, 0.30020354262420107, 0.1863986857767616, 0.3717846716088908, 1.320504816515105, 5.950855902263096, 7.213870346546173, 11.054475392614092, 29.900047506604874, 30.71917063849313, 28.259834902627126, 15.064538751329694, 6.462843034948621, 8.508152553013392, 29.12257535117013, 35.13306590488979, 39.44482612609863, 42.8732271194458, 34.34526177815029, 32.76071466718401, 40.4027429989406, 49.153356415884836, 49.862583364759175, 55.47319119317191, 51.13668148858206, 50.53490495681763, 49.417728424072266, 50.87399789265224, 51.81678853716169, 53.041446753910606, 48.58158220563616, 38.99902623040335, 35.99007756369454, 42.90815223966326, 41.389567852020264, 53.5485714503697, 14.659000192369733, 0.36847599915095736, 12.194138033049446, 68.33485221862793, 65.18225302015031, 68.6271003995623, 41.04824801853725, 40.16697672435215, 40.40342392240252, 27.637199878692627, 43.417368343898225, 32.01347759791783, 53.7366418157305, 22.68149971961975, 38.507406439099995, 38.702758516584126, 66.60805811200822, 68.29080758775983, 0.5028320125171116, 0.2513276609991278, 0.1572771162859031, 0.08158821093716792, 0.18287932819553784], [0.054709583055227995, 0.31562102532812525, 0.44322444817849566, 2.6954822071960995, 42.38377169200352, 33.73343120302473, 15.524669306618826, 40.95399917875017, 58.04084587097168, 55.47051613671439, 42.61657108579363, 16.606562886919292, 34.38832671301705, 68.922774042402, 69.38862991333008, 38.328267983027864, 32.28678151539394, 46.08391325814383, 61.05947685241699, 42.887543882642476, 12.440563712801252, 1.202213472553662, 0.10537564022732632, 0.09574223429496799, 0.16082537945892128, 0.09290022429611001, 3.9549133351870944, 15.259927306856428, 24.245853628431046, 27.499354566846574, 34.05668919427054, 54.25511639458792, 45.79789066314697, 23.240906136376516, 16.418032203401836, 28.999036380222865, 47.02920525414603, 46.786987577165874, 49.65120874132429, 49.801699774605886, 34.22132675988333, 20.329001222337993, 33.87704699380057, 41.22639635631016, 39.84330184119088, 24.44838145800999, 22.553571224212646, 31.350994655064174, 34.541346890585764, 39.973573616572786, 43.56807477133614, 44.846758706229075, 44.537365845271516, 40.36816528865269, 33.75432096208845, 27.129957062857493, 24.71558138302394, 30.057792459215435, 34.72330978938511, 29.468748501368932, 17.001300471169607, 6.193883044379098, 0.944285375731332, 4.494024063859667, 12.19730988570622, 14.178792817252022, 34.97670364379883, 37.66826554707119, 36.10271828515189, 37.99419512067522, 40.11664397375924, 40.886292457580566, 39.450940540858674, 39.2384819984436, 37.64836243220738, 37.680647236960276, 38.803479603358674, 38.24960395268032, 41.10336460386004, 36.83752850123814, 36.56148699351719, 35.50928653989519, 36.01058864593506, 35.21849053246634, 35.73421015058245, 35.53050981249128, 37.197063037327354, 38.70652444022042, 38.32088899612427, 36.24084152494158, 36.165179116385325, 35.25439534868513, 34.40994255883353, 34.611878054482595, 32.0237261908395, 35.72639342716762, 36.959128924778526, 38.61613185065133, 38.348883288247244, 36.856458868299214, 36.265733446393696, 34.29360539572579, 35.18370785032, 34.45064163208008, 36.30173206329346, 41.235557556152344, 35.685798576899934, 31.75964948109218, 29.954333782196045, 39.15917525972639, 27.14496169771467, 9.000307355608259, 0.16188462690583297, 0.09278920239635877, 0.04585376129086528, 0.07892638591251203, 0.12348255754581519, 0.06954621603446347, 0.152340597606131, 0.12894642007138046, 0.8802467605897358, 1.1944250847612108, 4.0407865558351785, 6.820724768298013, 7.589645862579346, 19.47094907079424, 32.63456317356655, 31.221348217555455, 22.48968948636736, 20.08995713506426, 28.648095028741018, 51.692440101078574, 47.96101427078247, 53.49974993297032, 42.46565621239798, 34.776557309286936, 44.04796947751726, 41.34421695981707, 37.627969469342915, 33.31661571775164, 38.03189952032906, 35.889846324920654, 34.5857424054827, 34.72156579153878, 36.988429478236604, 39.21026883806501, 38.500562463487896, 33.809197834559846, 26.46318187032427, 22.53086277416774, 28.08151980808803, 32.28671898160662, 35.18642112186977, 8.528180735451834, 0.05429112033120223, 20.76515007019043, 58.21072932652065, 52.47504697527204, 34.46073736463274, 33.13208198547363, 30.607349804469518, 25.46480737413679, 15.127960171018328, 33.976267269679475, 29.591022900172643, 22.71358823776245, 32.015353611537385, 33.133242334638325, 37.61573716572353, 54.85914066859654, 8.935227922030858, 0.5964289701410702, 0.09440045843699149, 0.1218939306480544, 0.03153503712798868, 0.1307975993092571, 0.10242297473762717, 0.08453517673271042, 0.558536100600447, 8.551053336688451, 51.30740567616054, 28.016125099999563, 34.46555246625628, 76.43015670776367, 78.49025590079171, 60.819819586617605, 20.94462377684457, 17.519978284835815, 41.453154291425435, 66.87543869018555, 68.3672308240618, 45.42019353594099, 31.736967086791992, 58.24372284752982, 69.31666047232491, 56.27159479686192, 38.04119273594448, 6.862167298793793, 0.1818583636943783, 0.11696269097072737, 0.20323161967098713, 0.22008314542472363, 5.045223355293274, 18.316606623785837, 27.6515930720738, 32.12109129769461, 38.585139410836355, 59.45283099583217, 52.42843498502459, 28.68159576824733, 17.992368936538696, 36.50263227735247, 51.35742923191616, 52.57809918267386, 53.57994604110718, 54.93586615153721, 37.92851032529558, 24.573968410491943, 38.286457198006765, 45.35636738368443, 42.65858336857387, 27.051798513957433, 24.264149972370692, 32.673448766980854, 39.014756952013286, 43.71654735292707, 46.11780309677124, 46.93536983217512, 51.06882190704346, 48.921609674181255, 40.08471352713448, 34.82245363507952, 37.02049888883318, 39.90713841574532, 37.42933784212385, 36.689431122371126, 22.481884922300065, 9.311071617262703, 4.010157593658992, 0.6464443834764617, 11.538068277495247, 17.314532211848668, 33.445397104535786, 39.70012378692627, 39.599388803754536, 38.6015545300075, 41.70224721091134, 42.05228008542742, 40.48407861164638, 39.02615894590105, 40.18758160727364, 40.304377351488384, 42.02024194172451, 40.10878903525216, 43.51790182931082, 38.296292373112266, 39.70660298211234, 37.03488860811506, 38.17887476512364, 36.28170388085501, 37.52730744225638, 36.19885008675711, 39.14370162146432, 41.401779311043875, 40.62127079282488, 39.29582895551409, 37.3902507509504, 36.944930280957905, 36.81052085331508, 37.0480762890407, 35.38459069388253, 38.074220997946604, 40.2595579964774, 40.4829877444676, 39.82109887259347, 38.19037055969238, 40.057483536856516, 37.434434345790315, 38.65972137451172, 35.82765647343227, 39.97677673612322, 43.20323528562273, 37.56586299623762, 34.717865875789094, 32.32883201326643, 37.75336708341326, 27.431041615349905, 6.820236223084586, 0.21736649477056094, 0.06541545768933636, 0.08095146689031806, 0.14452259854546615, 0.11739347928336688, 0.061194474542779584, 0.0598497267014214, 0.12469946938966002, 0.9860527345112392, 1.8543840944766998, 4.281939855643681, 13.639800207955496, 14.48938684804099, 28.66066084589277, 41.38437754767281, 37.505840982709614, 28.526442493711198, 27.20031452178955, 39.443002223968506, 57.37900563648769, 52.91388477597918, 57.235973494393484, 53.009693486349924, 43.432282652173726, 52.47841337748936, 49.21670661653791, 46.62920093536377, 43.66477632522583, 47.147300311497276, 45.290738173893516, 44.68453911372593, 44.25374732698713, 45.06667266573225, 48.12855618340628, 46.194955893925254, 45.519524982997346, 44.38009337016514, 39.924977915627615, 39.384835379464285, 46.28051948547363, 43.061061246054514, 8.932150738579885, 0.039841184459094486, 27.098391396658762, 64.00531155722481, 54.33390549251011, 38.88905014310564, 39.228382791791645, 36.53979124341692, 32.24509579794747, 17.982177666255406, 30.638665335518972, 34.09348337990897, 19.591569798333303, 33.12297289712088, 48.46139921460833, 39.53596912111555, 63.8676746913365, 11.66856847490583, 0.5493451537830489, 0.14434802505586827, 0.0874205179778593, 0.06261498081896986, 0.14045023492404393, 0.1274330291364874, 0.38582687239561764, 0.694837826703276, 6.701391194547925, 85.7546739578247, 64.54574939182827, 38.01649188995361, 67.90728787013462, 74.69841548374721, 69.89177676609584, 61.36018793923514, 22.42753611292158, 43.37845843178885, 74.41394233703613, 72.81352206638881, 56.79628453935896, 46.614387375967844, 61.49766499655587, 82.0953426361084, 63.04402828216553, 54.62377044132778, 9.348500694547381, 0.19564532674849033, 0.12155493455273764, 0.32203041283147676, 0.26061558404139107, 6.634532153606415, 21.861202342169626, 32.858559199741904, 40.46137189865112, 48.77619777406965, 63.56172466278076, 59.35927350180489, 40.92284345626831, 32.54083892277309, 45.62658282688686, 50.161821433476035, 54.12087024961199, 54.5555808203561, 58.87162808009556, 47.67431422642299, 37.17607600348336, 45.56865222113473, 46.96875245230538, 44.41909013475691, 31.674325602395193, 26.0719861303057, 35.968413080487935, 44.333481379917686, 47.71783079419817, 45.02898563657488, 48.42634555271694, 51.298480715070454, 48.20641769681658, 43.704954283578054, 40.97509043557303, 45.28202165876116, 42.90732887813023, 43.06426089150565, 39.880644934517996, 24.703349079404557, 8.56927933011736, 7.34126079082489, 8.375454987798419, 14.071926048823766, 20.84339373452323, 38.41280671528408, 40.037827083042686, 41.90881020682198, 40.88166495731899, 42.48050798688616, 44.461380345480784, 41.50876767294747, 43.02245705468314, 43.332155636378694, 41.03138126645769, 44.39402798243931, 43.03003753934588, 46.64172853742327, 40.40280900682722, 40.99031393868582, 37.560901982443674, 40.42169073649815, 39.26696613856724, 41.0020181792123, 40.00698750359671, 43.68868160247803, 45.632655552455354, 44.01228700365339, 41.69370787484305, 40.59106002535139, 38.91966738019671, 40.04008872168404, 41.62458372116089, 37.54326745441982, 43.26718997955322, 43.93731246675764, 42.73071609224592, 42.08640963690621, 40.38914884839739, 43.08555712018694, 39.10313803809029, 41.25062819889614, 38.63485377175467, 41.650417123522075, 45.47868694577898, 40.28594030652727, 36.85247755050659, 32.321539878845215, 41.2933144569397, 30.95225838252476, 9.847168564796448, 0.7114842448915754, 0.2530876722718988, 0.16043324050094399, 0.15209148025938443, 0.17899745649525098, 0.21561535873583385, 0.2564151537205492, 0.26584328923906597, 1.9023247105734689, 3.4768084415367673, 9.503724319594246, 15.26333018711635, 19.804005759102957, 31.494989122663224, 43.40388536453247, 37.13721820286342, 28.144427061080933, 27.9429657799857, 40.99972874777657, 58.62486975533621, 55.82218531199864, 58.79710170200893, 54.66214534214565, 48.064698764256065, 54.10158552442278, 50.18997206006731, 50.2291043145316, 49.83277211870466, 51.91394519805908, 50.268264361790244, 46.79325485229492, 49.02882385253906, 50.82202189309256, 53.994854245867046, 54.028657232012065, 51.77421345029558, 53.71395247323172, 45.149126938411165, 48.39507518495832, 53.194814341408865, 48.022210529872346, 10.478811928204127, 0.1467739370252405, 26.50248088155474, 68.16719913482666, 65.8092098236084, 46.57118695122855, 48.915547370910645, 48.74886008671352, 43.862060001918245, 20.74186839376177, 48.94022389820644, 42.90200655800955, 36.458903789520264, 56.53970840999058, 58.36673028128487, 62.15686838967459, 99.87325368608747, 16.03680191721235, 0.7948510657463754, 0.36453314072319437, 0.19476916162031038, 0.15391585736402444, 0.15794882524226392], [0.05737736222467252, 0.021384536621293852, 0.13668292707630567, 0.4235388445002692, 27.010701656341553, 63.703662463596885, 39.23550122124808, 21.439074959073746, 36.257663113730295, 49.88690553392683, 72.15604182652065, 52.42152500152588, 42.6633289882115, 50.16173110689436, 62.976846149989534, 46.807964188711985, 33.20313079016549, 32.962045669555664, 58.632630893162315, 47.86306551524571, 32.08777468545096, 5.541339499609811, 0.1376176904886961, 0.31013487971254755, 0.0947197430900165, 0.9650408391441617, 8.767378551619393, 25.399945940290177, 30.57561043330601, 43.06102997916085, 45.39193868637085, 24.718602112361364, 21.571665695735387, 36.96873828342983, 38.369971070970806, 41.94803278786795, 43.05128165653774, 44.92462369373867, 47.28047295979091, 51.54367222104754, 44.28464249202183, 38.35427509035383, 45.14506919043404, 47.42554439817156, 44.4876514843532, 44.59426464353289, 47.758832114083425, 47.439499855041504, 45.76898963110787, 49.12137038367135, 51.83122341973441, 49.050703729902, 49.4132398877825, 45.16558722087315, 38.11900561196463, 33.2696076801845, 38.38114724840437, 45.989872864314485, 42.853000913347515, 40.75599636350359, 35.060867173331125, 15.844970839364187, 4.68921285867691, 0.5850299075245857, 5.621550806931086, 12.285640597343445, 19.62136541094099, 35.93285914829799, 35.955472060612266, 35.71041604450771, 38.74194983073643, 43.68176467078072, 40.621840545109336, 38.24110630580357, 36.85516997746059, 38.51776967729841, 39.92989724023001, 41.056089060647146, 40.753435952322825, 39.2425571169172, 38.3754358291626, 39.582931995391846, 37.39236300332205, 36.71639013290405, 35.52041060583932, 37.98343236105782, 37.73651770183018, 38.26487956728254, 37.65942743846348, 37.97178718021938, 36.895646708352224, 36.02652433940342, 34.44715016228812, 31.86732918875558, 34.38771179744175, 32.524368218013215, 36.256461075374055, 38.49661241258894, 38.52066707611084, 36.235074520111084, 34.874158654894146, 36.622895172664094, 36.45706251689366, 36.854496002197266, 38.148886340005056, 37.11675228391375, 32.70228031703404, 33.526902948107036, 31.84945842197963, 28.98968584196908, 14.81387380191258, 2.1681914499827792, 0.1332585508269923, 0.1469278016260692, 0.22410408966243267, 0.28787106009466307, 0.44637499483568327, 0.820270941725799, 0.5682073416454452, 1.0258117382015501, 2.802902225937162, 3.9282752445765903, 4.276803834097726, 18.90827178955078, 15.462274483272008, 33.42438922609602, 44.83000659942627, 42.54177025386265, 44.344327517918174, 43.54066065379551, 50.59479495457241, 50.68061910356794, 51.32943146569388, 52.06527348927089, 48.40012999943325, 44.81377560751778, 47.36659240722656, 39.54436949321202, 34.92849704197475, 34.88836077281407, 37.01878615788051, 34.12869685036795, 36.46054356438773, 34.883437974112375, 33.405458859034944, 35.35174308504377, 38.926587785993306, 40.3776078905378, 36.7720000403268, 35.93011113575527, 35.1418901171003, 38.222040448869976, 37.23862716129848, 7.154936160360064, 0.4843555582421166, 33.565962246486116, 59.812073707580566, 43.64054100854056, 44.750852721078054, 36.04258510044643, 19.1044020652771, 34.99143729891096, 20.267907449177333, 36.21649851117815, 38.430614948272705, 74.77187878744942, 41.81527703148978, 36.58819934300014, 50.802834442683626, 30.934978212629044, 0.5892744969044412, 0.03476027013467891, 0.02718186009276126, 0.024854647827201655, 0.03289761686963694, 0.04628003056028059, 0.08349577643509422, 0.06982582674494811, 0.09469026074345623, 0.5999738542096955, 42.05198131288801, 58.978581701006206, 21.17745270047869, 31.755247797284806, 65.54242679050991, 70.88572352273124, 56.02254704066685, 33.63412754876273, 36.579847608293804, 60.44379002707345, 56.27023294993809, 55.43834250313895, 33.17590079988752, 41.76565647125244, 67.17289802006313, 55.6512769971575, 54.40145240511213, 21.42446289743696, 0.1131678753133331, 0.1418955009430647, 0.10790982602962426, 0.8470659096326146, 11.487986530576434, 30.83949954169137, 39.6223143850054, 49.07079097202846, 52.904699257441926, 31.097430569784983, 35.871093136923655, 45.63849203927176, 45.127938406808035, 49.86823572431292, 51.042922496795654, 52.21987785611834, 55.103849274771555, 57.95932960510254, 51.41702045713152, 43.12318161555699, 54.03553942271641, 55.033568246024, 52.40769113813128, 51.195293017796104, 52.42168481009347, 52.64215462548392, 51.5764433997018, 53.92069264820644, 56.10698502404349, 54.3938684463501, 52.555878843579976, 46.86589479446411, 45.388968331473215, 42.78128855569022, 44.772909777505056, 49.44515643801008, 47.836617197309224, 42.14687980924334, 38.093762806483674, 27.51002699988229, 6.300892685140882, 2.0996144669396535, 1.1700768598488398, 11.056513820375715, 23.695337431771414, 36.696052755628315, 38.201098578316824, 38.63565976279122, 41.14820827756609, 46.76128271647862, 41.865738323756624, 42.03067466190883, 39.38580117906843, 41.57012721470424, 41.6083527292524, 42.27516787392752, 41.7719897542681, 43.672798020499094, 41.51498631068638, 41.94163697106497, 39.35963078907558, 40.45590366636004, 37.334171840122764, 41.24071659360613, 38.57841008050101, 39.624145235334126, 39.25857966286795, 39.98160573414394, 36.50706870215279, 36.950725078582764, 35.095559528895784, 35.23136901855469, 36.11827877589634, 35.10513414655413, 38.20512853349958, 41.78404835292271, 39.668238503592356, 39.103937080928254, 37.354335512433735, 39.69786214828491, 36.1469018799918, 38.15453175136021, 41.12165226255144, 39.127064159938264, 34.64482293810163, 37.54763092313494, 33.26812423978533, 30.08960131236485, 13.30483102798462, 2.8491909078189304, 0.36392650327512194, 0.04396006504872015, 0.3110091585133757, 0.2917691894939968, 0.387432584805148, 0.9212249560015542, 0.6863331773451397, 1.018217031444822, 2.895919497523989, 3.930889504296439, 13.938485894884382, 25.119542700903757, 32.035454750061035, 42.76581144332886, 51.61750725337437, 46.526996408190044, 52.19676119940621, 50.477252279009136, 55.3886524609157, 55.87757635116577, 57.18111399241856, 57.68978466306414, 55.326160362788606, 53.9586888722011, 53.383735861097065, 48.40890557425362, 46.180670397622244, 43.97455481120518, 43.11569493157523, 40.655695642743794, 42.704257352011545, 38.91683598927089, 41.7443984576634, 43.36328704016549, 46.93017257962908, 48.01065567561558, 47.745272704533164, 47.108206272125244, 49.715087005070274, 49.774813720158164, 46.18228585379464, 9.055255447115217, 1.0928377530404498, 40.154407433101106, 66.23484257289341, 47.39480209350586, 55.90162059238979, 49.32179464612688, 27.80248188972473, 41.77365384783064, 22.95102902821132, 37.93452051707676, 38.08409438814436, 86.7570002419608, 57.65489428383963, 41.34874371119908, 64.35969747815813, 42.1509028162275, 0.695281480039869, 0.06611718503492219, 0.07578409702650138, 0.047797523239361386, 0.007018127137728567, 0.08177718972521168, 0.16357887456459658, 0.1672026315437896, 0.2331275333251272, 0.6245377989751952, 44.33214732578823, 95.39108194623674, 62.08341898236956, 35.05478402546474, 56.8389047895159, 65.9398637499128, 82.17615018572126, 65.60673931666783, 52.655616760253906, 58.72185965946743, 68.94796821049282, 64.48479979378837, 50.771070752825054, 47.16620288576399, 75.33954661233085, 61.925298827035085, 66.35141944885254, 27.716709852218628, 0.23789006205541746, 0.4509130098990032, 0.21716653050056525, 2.130490307297025, 19.431188004357473, 36.46536908830915, 42.64714315959385, 52.458659648895264, 60.2090242930821, 36.95708268029349, 44.873266083853586, 50.76783636638096, 53.0893372126988, 50.794826643807546, 50.91923066547939, 51.97159787586757, 52.15091003690447, 55.59489583969116, 52.76186861310686, 50.05891861234392, 55.93886293683733, 52.51884494509016, 49.98288447516305, 52.69382490430559, 55.77512863704136, 55.26464101246425, 54.65574605124337, 56.29720933096749, 58.334018162318635, 57.29600245612008, 53.678336007254465, 50.39466946465628, 52.36068657466343, 47.91790417262486, 49.95469910757882, 54.32056147711617, 50.72110973085676, 44.68289933885847, 43.231948716299875, 29.59171772003174, 6.174577474594116, 3.104079927716936, 7.620152797017779, 14.09729392187936, 26.20495901788984, 37.22286169869559, 41.81975514548165, 39.89105333600725, 45.80833380562918, 49.16549144472395, 43.82068695340838, 43.732344082423616, 39.35165078299386, 43.1624493598938, 45.309887409210205, 47.82832452229091, 44.87618432726179, 44.46607732772827, 43.9120557648795, 43.127270630427766, 41.621912138802664, 42.34657451084682, 39.31984192984444, 44.152227197374614, 41.25205952780587, 45.058206285749165, 43.73209047317505, 42.44186905452183, 40.23923104149954, 39.44122348512922, 38.27231413977486, 36.936550753457205, 38.51351737976074, 37.7551840373448, 43.298644474574495, 43.95917844772339, 43.29653569630214, 41.55257953916277, 40.759883880615234, 41.941459792000906, 41.650055817195344, 41.75184345245361, 42.94588443211147, 41.144154003688264, 36.13023315157209, 37.35554797308785, 34.75696686335972, 32.489689758845735, 16.450643573488506, 3.7493104934692383, 0.45054432111127035, 0.28952967109424727, 0.5058209864156586, 0.41621286475232666, 0.5180214260305677, 1.2616609569106783, 1.3198134707553046, 1.1512684119599206, 5.557233503886631, 6.451323355947222, 19.416515145983013, 34.157410281045095, 36.93752350125994, 46.939601285117014, 51.79265396935599, 49.00628737040928, 51.29929365430559, 48.339131764003206, 56.211531094142366, 57.62553467069353, 58.49425057002476, 57.40326527186802, 55.25967999867031, 52.24386303765433, 52.434882913317, 51.46506725038801, 51.68639169420515, 47.903667313711985, 47.05404506410871, 44.1279536655971, 47.92074598584856, 45.05784150532314, 47.28344331468855, 48.53727354322161, 54.137862069266184, 56.62134279523577, 53.826395171029226, 53.290727274758474, 55.77121332713536, 55.27754034314837, 52.337688037327354, 11.070844479969569, 1.15029034444264, 39.90794440678188, 73.6991741997855, 55.11863156727382, 64.19106469835553, 50.62466526031494, 36.5914580481393, 54.987689290727886, 27.904007230486187, 47.252791336604524, 58.28331020900181, 110.79799665723527, 66.37334796360561, 62.85235527583531, 80.34482737949916, 58.172753947121755, 0.9556719533034733, 0.2132168324398143, 0.24836316864405358, 0.11993521718042237, 0.1335866767913103, 0.16780275505568298], [0.06512518719370876, 0.09533666034362145, 0.13266412700925553, 0.10359448580337421, 0.8077528391565595, 53.656261580330984, 63.96462985447475, 49.834842681884766, 23.861328159059795, 22.234991107668193, 38.37407398223877, 65.32268306187221, 49.62679624557495, 26.310505628585815, 40.652412618909565, 45.858260086604524, 38.77454035622733, 22.608449833733694, 47.218776430402485, 55.797477517809185, 49.257662773132324, 28.622635092054093, 1.366208981190409, 0.03214891454471009, 0.11637301689812116, 5.027937974248614, 9.204079781259809, 31.075807775769913, 49.855173110961914, 58.70822034563337, 45.039202962602886, 21.276721613747732, 24.512824262891495, 41.14822564806257, 50.180070877075195, 41.81450925554548, 44.65984174183437, 43.612598827907014, 45.80187545503889, 43.73200362069266, 48.633242062159944, 48.70240443093436, 49.64584125791277, 49.52872937066214, 49.25078405652727, 51.481440680367605, 52.537132603781565, 49.84800604411534, 51.164748736790244, 53.45342976706368, 55.42978579657418, 52.43927417482649, 55.688838958740234, 55.32651819501604, 50.41668830599104, 46.799793107169016, 46.952556201389854, 49.03170388085501, 49.0536219733102, 46.849622113364084, 37.6890093939645, 31.59337214061192, 17.761037349700928, 5.10653339113508, 0.3213483765721321, 5.315680248396737, 19.406402042933873, 34.352633816855295, 35.03963000433785, 36.213062626974924, 35.377163069588796, 41.79895918709891, 39.7937889780317, 39.38660717010498, 38.820141383579795, 37.15342835017613, 39.66253055844988, 40.50769553865705, 37.63223218917847, 38.79908834184919, 38.97377300262451, 38.68164988926479, 37.02902085440499, 35.80505050931658, 35.54336745398385, 35.64026703153338, 38.22051879337856, 37.18799563816616, 34.38216018676758, 36.35145684650966, 33.906535148620605, 35.33579002107893, 32.81117248535156, 35.90811313901629, 31.69595534460885, 32.6926257950919, 34.41638701302664, 37.284061431884766, 37.100465706416536, 36.03958347865513, 34.63029772894723, 34.12365940638951, 34.21312441144671, 37.857534476688926, 38.571805817740305, 33.86099318095616, 34.3471690586635, 33.61486366816929, 26.951619386672974, 19.19072995867048, 7.672438859939575, 1.8980133533477783, 0.27867696487477844, 1.330478412764413, 1.819540615592684, 1.4557021047387804, 2.423402258328029, 2.937488398381642, 3.0273876658507755, 6.40859454018729, 13.599771635872976, 14.73646913255964, 14.631452322006226, 13.672204869134085, 35.11010905674526, 44.481137548174175, 45.8851044518607, 43.57901471001761, 45.560231004442485, 45.95657709666661, 50.329252174922395, 52.5709216935294, 49.38316461018154, 48.33416380201067, 46.583586011614116, 44.71529878888811, 39.62097685677664, 37.215211732046946, 35.468128885541645, 34.68931572777884, 33.70705584117344, 31.873929977416992, 32.81958327974592, 33.959442206791465, 37.06833028793335, 38.54470089503697, 38.071768283843994, 37.678357805524556, 42.168110030038015, 41.38634736197335, 47.21244314738682, 44.70031499862671, 43.87847859518868, 6.454361890043531, 2.2463298056806837, 43.440943581717356, 58.83524036407471, 41.842218671526226, 39.62617063522339, 20.29787850379944, 19.236826045172556, 46.65930053165981, 36.64590065819876, 16.467402628489904, 39.661564758845735, 46.06558738436018, 23.38158631324768, 29.539616652897426, 51.09601715632847, 9.18489406790052, 0.6723332085779735, 0.18742817267775536, 0.04771360881360514, 0.07736095812703882, 0.0295888019193496, 0.054205845442733595, 0.013855146493629684, 0.0544274889065751, 0.07578432094305754, 0.3446073356483664, 3.2375144362449646, 69.13915484292167, 60.100542068481445, 31.124281883239746, 26.736312082835607, 31.007486139025005, 55.3248610496521, 64.77429648808071, 40.79212352207729, 30.345708438328334, 42.06629112788609, 62.049880027770996, 44.98398910249983, 27.495904786246165, 59.56438432421003, 64.42548997061593, 61.47816835130964, 49.635314737047466, 2.5137481646878377, 0.06474771816283464, 0.6424316902245794, 9.404907039233617, 17.656911645616802, 42.536559104919434, 57.73106738499233, 65.05730356488908, 52.70887470245361, 26.737811156681605, 27.774188825062343, 49.453066962105886, 58.521181787763325, 51.29554162706648, 52.26323808942522, 51.153850487300325, 52.08630568640572, 51.27918209348406, 57.41395160130092, 58.52666391645159, 59.16697515760149, 56.48052365439278, 56.063909666878835, 57.52327108383179, 58.18557684762137, 55.59120634623936, 56.88300500597273, 59.44179725646973, 59.62672356196812, 54.02723632540022, 57.68750217982701, 56.24477127620152, 52.907871110098704, 52.77040794917515, 51.92455162320818, 51.00508608136858, 49.56601340430123, 47.95363528387887, 39.075616223471506, 33.8312931060791, 25.668278421674454, 13.418902209826879, 2.7982844965798512, 4.561019028936114, 18.891844511032104, 33.67763022014073, 39.28986392702375, 38.741300174168174, 40.21471779687064, 43.44815581185477, 41.647158418382915, 41.439768586839946, 38.48694052015032, 39.77555343082973, 42.07482698985508, 42.732484408787315, 40.988274642399375, 39.49400200162615, 40.83611256735665, 39.79343114580427, 38.22751215526036, 37.86449657167707, 36.53302369798933, 38.28708600997925, 40.5672207559858, 40.36502817698887, 37.733401434762136, 38.4711993762425, 36.39042581830706, 37.87078816550118, 36.02428354535784, 36.52978236334664, 33.741400786808555, 34.86944430215018, 35.687351499285015, 38.25005211148943, 38.7818637575422, 37.91912678309849, 37.04295546667916, 36.42840814590454, 35.473385197775706, 40.48539876937866, 40.41547209875924, 35.064949240003315, 35.34123740877424, 35.41960266658238, 28.177604709352764, 21.532059226717266, 7.677074176924569, 3.9305455684661865, 2.2901104050023213, 3.3635230575289046, 1.50175541639328, 1.4697450654847282, 3.5743761318070546, 3.6193457416125705, 3.765544959477016, 7.129000272069659, 17.893664564405167, 26.040677547454834, 24.66757106781006, 25.410825082233973, 43.98852416447231, 47.229278632572715, 51.33932222638811, 50.37239701407296, 49.37541389465332, 49.80272115979876, 54.675107206617085, 57.43327454158238, 53.7108223097665, 54.26309987476894, 52.5407178742545, 49.991382122039795, 46.834624426705496, 44.16589082990374, 43.071848324366975, 40.197659969329834, 39.712210178375244, 38.31888444083077, 40.154786109924316, 41.016453061785015, 43.69717924935477, 43.272689478737966, 45.997220584324424, 44.26811620167324, 51.323143345969065, 50.782458850315635, 56.72474588666643, 51.99515226909092, 54.348889282771516, 6.847106209823063, 3.685591604028429, 47.85477631432669, 64.21148545401437, 44.954737186431885, 52.29487323760986, 28.182791539600917, 22.109775883810862, 57.11518253598894, 32.99757875714983, 22.389677115849086, 49.908055850437705, 53.481424059186665, 32.89889349256243, 34.42539187840053, 68.35036754608154, 9.006766574723379, 0.4285337579037462, 0.17399621914540017, 0.06457204544650656, 0.09839205603514399, 0.01291810320357659, 0.07625713771475212, 0.12693047896027565, 0.18419701606035233, 0.2452800412263189, 0.2550513526158673, 1.3884009846619196, 76.9310245513916, 87.39810357775006, 70.01465565817696, 34.611356939588276, 33.68846246174404, 47.615438665662495, 76.97766780853271, 59.540016991751536, 38.02170303889683, 47.17567328044346, 63.37023230961391, 55.261931215013774, 35.356940337589805, 64.1912453515189, 71.26733943394252, 67.19689014979771, 58.18591730935233, 2.2428253080163683, 0.1319761603538479, 0.671584920159408, 12.713752116475787, 27.627729484013148, 46.74866131373814, 61.39731911250523, 69.91741561889648, 60.16863441467285, 36.66525486537388, 38.73676994868687, 49.92552014759609, 55.59255429676601, 48.356575216565815, 51.99357850211007, 51.79382126671927, 51.68853868756975, 48.51532070977347, 53.60135344096592, 55.989442348480225, 55.47319119317191, 54.55037661961147, 55.33644369670323, 57.44748360770089, 59.39072104862758, 56.131446157182964, 58.8465450831822, 60.39886992318289, 58.84566961015974, 52.37399237496512, 58.7330184664045, 58.146204880305696, 57.1708619253976, 55.60632562637329, 56.1540903363909, 55.51200383050101, 57.16004705429077, 56.419077260153635, 41.259243965148926, 39.48222827911377, 29.812628746032715, 13.452453323772975, 4.027124226093292, 9.355836255209786, 23.570612055914744, 34.096644810267854, 41.891825335366384, 41.2016156060355, 41.57646744591849, 46.56496136529105, 43.0590705871582, 41.423363889966694, 43.23599256787981, 40.904444626399446, 45.994847774505615, 45.93348823274885, 42.7093642779759, 42.03251246043614, 43.09326614652361, 41.14053399222237, 41.91480997630528, 40.67587668555123, 40.368992124285015, 40.94572734832764, 44.20589855739048, 43.706962312970845, 41.907371929713655, 40.129452977861675, 38.21658263887678, 41.387097767421174, 39.18595361709595, 41.1917839050293, 36.15238053458077, 37.9129706791469, 39.2952036176409, 42.34147105898176, 41.297094276973176, 40.231532437460764, 42.65456730978829, 39.3733743258885, 39.44778953279768, 42.37655251366751, 43.26791954040527, 35.308330740247456, 37.43737343379429, 37.55897733143398, 32.807566370282856, 21.32510539463588, 10.755864398820059, 4.946944994585855, 3.1600420219557623, 4.580266841820308, 2.525809586048126, 2.294762658221381, 6.454069631440299, 4.96196265731539, 4.397574382168906, 6.047355089868818, 18.90816409247262, 30.897916521344865, 31.21332652228219, 31.665984289986746, 47.819027832576204, 48.98045744214739, 51.944868155888145, 49.44090414047241, 49.81057609830584, 50.58440392357962, 57.369531767708914, 57.54920176097325, 56.67340912137713, 55.35350152424404, 52.4595490183149, 51.77031203678676, 50.790261677333284, 48.478950364249094, 47.44541277204241, 44.672629901341026, 44.45366784504482, 43.485370363507954, 44.917168276650564, 44.10031720570156, 49.10730722972325, 48.23110812050955, 49.82116167885916, 49.001110962459016, 58.761019706726074, 55.592418806893484, 64.21893392290387, 59.63559641156878, 57.96280370439802, 8.870620965957642, 3.2892496372972215, 52.868203844342915, 70.44975880214146, 51.63244240624564, 58.502032552446636, 29.743188449314662, 31.69654941558838, 65.45464324951172, 47.87012141091483, 23.655432190213883, 58.5103634425572, 55.56614766802107, 38.28652320589338, 52.11596059799194, 80.45294829777309, 16.378304140908376, 1.153128357870238, 0.525887763925961, 0.15823140793613025, 0.3788722955754825, 0.1677761022001505, 0.22589724058551447], [0.08790262389395918, 0.08367682314877, 0.09809115289577416, 0.26287760266235893, 0.5267546602657863, 9.935769387653895, 67.78301933833531, 53.54299552100045, 33.52314397266933, 27.969813619341167, 32.54922539847237, 50.11508090155465, 49.94761889321463, 34.007179805210654, 15.710101093564715, 21.40950516292027, 38.487760407584055, 24.883394275392803, 30.690095901489258, 49.39870078223092, 55.30543041229248, 59.77714511326381, 11.030064633914403, 0.15598199649580888, 3.5181921294757297, 11.454514452389308, 17.306249959128245, 43.0780600139073, 57.74053430557251, 46.94271060398647, 48.532673835754395, 39.53386034284319, 40.56406627382551, 46.640842642102925, 43.31911734172276, 37.41428804397583, 39.06167813709804, 40.66409601484026, 42.67674248559134, 41.866846561431885, 46.40628187997, 49.42378725324358, 48.0400013923645, 47.73078918457031, 49.0003570829119, 48.747491291591096, 49.60859891346523, 49.03628969192505, 48.296761648995535, 51.78690433502197, 51.971778529030935, 53.745695318494526, 50.28196620941162, 55.44834443501064, 52.53176164627075, 55.71506493432181, 54.41615826742989, 52.76588467189244, 48.62970890317644, 46.44564689908709, 42.70482015609741, 33.053852217538015, 29.02689344542367, 27.975443397249492, 6.845444721835, 1.9735830468790871, 10.336130670138768, 27.115345001220703, 35.52775832584926, 33.974269662584575, 36.837174143110005, 36.39957659585135, 40.26213230405535, 40.44958775384085, 36.88701009750366, 36.516177790505544, 38.62726286479405, 38.2360063280378, 37.34793274743216, 38.64283725193569, 36.98083857127598, 35.08528661727905, 33.51472623007638, 34.81518929345267, 33.06671333312988, 36.01204081944057, 37.34270770209176, 34.10718870162964, 35.86600358145577, 35.59524270466396, 35.20423282895769, 34.82836307798113, 32.42302526746477, 33.26270464488438, 32.910114833286826, 34.64833525248936, 33.37251744951521, 35.04785667146955, 36.00023235593523, 34.3616178376334, 33.13682413101196, 34.9402186529977, 36.48547370093209, 39.053705079214915, 36.84498044422695, 33.92051145008632, 34.24865402494158, 28.774917023522512, 22.9806353024074, 14.647297688892909, 5.08257383108139, 1.2691692454474313, 8.30585401398795, 5.641739232199533, 3.758041339261191, 5.222426738057818, 4.9628872019904, 6.570370316505432, 13.142333507537842, 20.867681162697927, 15.804237025124685, 21.952579838888987, 22.1798415184021, 30.857967853546143, 41.13960640771048, 44.025273186819895, 46.8694418498448, 48.34146983282906, 49.67724364144461, 49.18376520701817, 50.20448684692383, 49.11086818150112, 46.246820722307476, 42.751779556274414, 41.520127977643696, 38.785525458199636, 37.62592322485787, 35.065831661224365, 33.59430047443935, 32.20624841962542, 32.55833796092442, 34.113772119794575, 36.035831451416016, 35.91389404024397, 37.07066140856062, 36.95284080505371, 40.08613443374634, 42.56968464170183, 46.98632097244263, 49.60063280378069, 51.420675209590364, 48.3714165687561, 49.348430565425325, 6.249766102858952, 4.491846672126225, 46.39002309526716, 54.739617756434846, 39.863020828792024, 29.790648119790212, 13.53948472227369, 22.927978379385813, 51.77959483010428, 51.518127168927876, 20.523385763168335, 39.05450759615217, 26.107580014637538, 32.02761023385184, 49.18362276894705, 40.255062511989046, 0.05560383792700512, 0.04226696411413806, 0.05401345362354602, 0.04059754405170679, 0.04178786410817078, 0.06226905009576252, 0.09403160001550402, 0.09101469761558942, 0.07692712319216558, 0.026514235917212706, 0.29937806406191414, 0.8788707458547184, 21.85301215308053, 82.77820464542934, 58.48396028791155, 27.1733364037105, 17.45018710408892, 33.363495213644846, 68.37520735604423, 54.49123355320522, 26.683502299445017, 25.10873998914446, 32.812742778233115, 50.9571886743818, 30.197155952453613, 38.14889676230294, 53.12548521586827, 61.332992689950125, 71.14951188223702, 17.995575530188425, 0.19990491175225802, 4.559744034494672, 20.440761259623937, 32.50704288482666, 56.40293659482683, 65.36237117222377, 54.99685743876866, 58.76206193651472, 47.23385749544416, 50.42252826690674, 56.61781311035156, 48.91323014668056, 45.24622801371983, 46.81841427939278, 48.93119471413748, 48.914286272866384, 47.903007234845845, 52.33587803159441, 55.644710949489046, 53.25891842160906, 54.06709466661726, 55.84805345535278, 54.15336350032261, 54.00838238852364, 55.236601557050435, 52.97008180618286, 53.90657390866961, 53.80933734348842, 54.03855494090489, 52.38774285997663, 53.37795843396868, 55.313785621098106, 55.85710000991821, 56.06744629996163, 54.90131623404366, 51.90889385768345, 50.69119773592268, 45.22869423457554, 37.13927486964634, 33.41092709132603, 31.3505117552621, 15.412424632481166, 6.017050955976758, 10.637540919440132, 28.09928114073617, 35.61859212602888, 38.94981908798218, 39.32659905297415, 37.52849211011614, 42.44713231495449, 43.2176319531032, 38.535619599478586, 39.33358894075666, 41.28542825153896, 40.58534165791103, 42.44313710076468, 41.58382906232561, 39.33051436288016, 35.89720794132778, 35.21059390476772, 36.74605894088745, 36.484004156930105, 37.896107401166645, 38.871679646628245, 37.94631508418492, 38.70743465423584, 38.90705987385341, 38.941102572849815, 38.0807523046221, 33.93855939592634, 35.813982418605256, 35.021790504455566, 34.10633407320295, 35.81247813361031, 37.261174065726145, 37.22622462681362, 35.54946449824742, 35.51972273417881, 37.577702726636616, 39.31471415928432, 39.9219901902335, 38.18511424745832, 35.096435001918245, 34.911314146859304, 30.987405845097133, 23.523279190063477, 16.1505126612527, 5.73186822448458, 3.54292055112975, 14.449590172086443, 6.952217689582279, 6.071843147277832, 6.4700643845966885, 6.725946128368378, 9.732531973293849, 17.47924099649702, 25.29934123584202, 19.404793534960064, 26.24369522503444, 32.98374489375523, 43.172597203935894, 44.54406043461391, 47.40547800064087, 49.2665182522365, 50.18699128287179, 53.86062894548689, 52.654293128422324, 53.954499108450754, 54.42229005268642, 51.46149240221296, 48.87012004852295, 47.17596857888358, 46.6373998097011, 44.8812495640346, 43.154521465301514, 39.350004059927805, 39.18573822293963, 39.899491923195974, 40.761075496673584, 43.26016535077776, 43.25670167378017, 44.13842460087368, 42.69386979511806, 46.990347453526084, 48.696039881025044, 53.83238104411534, 54.189664363861084, 57.22808728899275, 55.681824752262656, 51.78756093978882, 6.344743200710841, 6.182094122682299, 50.390264306749614, 59.53252683367048, 42.654827867235454, 40.939362798418315, 14.472982151167733, 28.36275335720607, 61.09913716997419, 46.42505938666207, 21.01247467313494, 48.83467728751046, 36.39348649978638, 33.62630040305001, 52.08810874394008, 44.833063806806294, 0.1497831448380436, 0.019582367967814207, 0.09681548670466457, 0.03678388208416956, 0.0724788172436612, 0.10651455447077751, 0.0845928250678948, 0.17218656625066484, 0.11910363180296761, 0.20919021564934934, 0.47595757458891186, 1.1969526005642754, 14.99268742970058, 97.8500007901873, 69.94650077819824, 49.14096430369786, 39.147311210632324, 43.28259066173008, 66.30777086530412, 62.24190044403076, 50.90058864865984, 27.46780800819397, 37.85049595151629, 55.87065941946847, 35.804439067840576, 41.446240833827424, 62.075379916599815, 65.82446111951555, 77.41297245025635, 15.981562001364571, 0.15952759981155396, 4.244268459933145, 22.766293798174175, 43.13666459492275, 61.977785519191194, 69.94780009133476, 59.02397428240095, 59.365374020167756, 54.27187544958932, 54.16834381648472, 55.684079442705425, 49.13012163979666, 49.03313520976475, 47.4608655657087, 49.84613003049578, 50.22574486051287, 47.84277677536011, 50.01603780473982, 53.39398792811802, 52.1561142376491, 53.42577246257237, 52.26421431132725, 52.29725646972656, 53.95250497545515, 55.933085509708945, 52.523472445351736, 54.7992194039481, 55.7175350189209, 56.49760232652937, 53.884294509887695, 57.030897412981304, 56.41554410117013, 59.59603336879185, 58.95572907584054, 57.652917521340505, 55.94750302178519, 57.67684711728777, 53.995093958718435, 38.544620990753174, 36.52541542053223, 36.665730816977366, 15.814282383237567, 7.955848932266235, 15.288899557931082, 29.667956829071045, 37.05017811911446, 39.35314117159162, 39.64845698220389, 36.793449129377095, 44.11902870450701, 45.41243934631348, 40.64178534916469, 42.029448304857524, 45.22341707774571, 43.662928104400635, 44.32107189723423, 45.271939822605674, 40.7645183290754, 39.641043254307334, 39.22432851791382, 41.13888726915632, 40.551378863198416, 40.57425580705915, 42.173956939152305, 39.80752556664603, 43.25524950027466, 41.93327133996146, 40.59219952992031, 41.32906641278948, 36.40042775017874, 37.101365498134065, 37.267698424203054, 37.58479683739798, 38.420658179691856, 39.441414560590474, 42.05786991119385, 39.23941305705479, 39.05252735955374, 42.74601255144392, 40.727623394557405, 41.28574786867414, 38.893802710941856, 35.93028484072004, 37.68434715270996, 33.17496974127633, 27.295478786740983, 16.923331260681152, 9.106236985751561, 6.308507476534162, 14.250035302979605, 8.922000288963318, 7.948873809405735, 11.102366719927106, 12.399131604603358, 15.231648138591222, 17.926044906888688, 24.384855815342494, 22.550227403640747, 36.18780245099749, 39.6039502961295, 46.2924564906529, 48.84756619589669, 49.684320381709504, 50.10718079975673, 52.686616148267476, 55.33929245812552, 54.9434848512922, 53.82128129686628, 54.393882342747276, 51.859846523829866, 49.57351745877947, 49.024046966007774, 50.54379170281546, 49.708632128579275, 47.33216755730765, 44.93449708393642, 42.36950356619698, 42.53469698769705, 43.95991843087332, 46.12558855329241, 46.91984060832432, 46.88187912532261, 48.296678270612446, 51.398732798440115, 52.783831868852886, 58.06071424484253, 58.07794925144741, 62.94502340044294, 61.36325904301235, 62.81052017211914, 8.587506192071096, 6.04439298595701, 56.202071121760774, 67.92814636230469, 51.62782532828194, 41.01160669326782, 18.585190977369034, 37.44135127748762, 65.93497221810478, 68.96148245675224, 28.559972763061523, 60.45979172842843, 40.90557023457119, 55.69200038909912, 71.49560165405273, 60.788698605128694, 0.20197170227766037, 0.10643815821302788, 0.14763096746589455, 0.12870296170668943, 0.11051863032792296, 0.1795090176165104, 0.13646202321563447], [0.08443174085446767, 0.03256572164329035, 0.10026393737643957, 0.03758383076637983, 0.028027558998603905, 0.7872482708522252, 26.21626721109663, 70.10291862487793, 46.942894731249126, 26.154812131609233, 27.17993892942156, 38.202470847538535, 44.45308072226388, 45.32379422869001, 46.59840999330793, 40.35131243297032, 40.22254841668265, 18.42987094606672, 24.34058015687125, 39.36580078942435, 53.80620718002319, 59.50069713592529, 30.23509659085955, 0.670656141425882, 5.132842310837336, 18.538658891405376, 32.704121589660645, 57.03685549327305, 57.60325527191162, 41.18760108947754, 51.099682331085205, 50.06571395056588, 48.469004017966135, 41.302461760384695, 39.46460764748709, 36.591836724962505, 37.31159019470215, 36.267359324863975, 40.04640463420323, 41.69487517220633, 39.62465245383126, 44.10350642885481, 45.62044061933245, 44.91034514563424, 48.94379179818289, 51.956061703818186, 49.531366212027415, 48.46903875895909, 49.31920296805245, 51.098129408700125, 49.60995033809117, 53.15887825829642, 52.64815092086792, 51.74761922018868, 54.4246871812003, 54.38419655391148, 55.22315331867763, 51.928352287837434, 50.11304160526821, 48.20659834997994, 48.24542835780552, 44.05443130220686, 39.9817099571228, 29.617366995130265, 22.806291103363037, 10.341884647096906, 9.232281650815692, 25.048143012183054, 29.41136680330549, 32.371497426714214, 35.97042110988072, 36.86928871699742, 38.55531774248396, 40.28152820042202, 36.892346314021516, 37.58597455705915, 36.72000319617135, 36.92931073052542, 38.181351797921316, 38.41283450807844, 36.69044555936541, 34.47634996686663, 33.02684804371425, 31.615634168897355, 33.228991985321045, 35.30253594262259, 36.81939370291573, 37.01732703617641, 35.53065572466169, 37.32490989140102, 32.34743928909302, 35.40314585821969, 34.07027987071446, 35.001526083265034, 32.98867116655622, 35.226599080221995, 33.739069666181294, 34.36718681880406, 32.27695676258632, 34.14299276896885, 32.39630944388253, 34.54799631663731, 36.2875577381679, 38.15270784923008, 33.314222063337056, 33.52597188949585, 29.992323057992117, 25.77799916267395, 19.941713844026836, 12.567197237695966, 3.3698602489062717, 10.189328261784144, 16.436816658292496, 6.812258388314929, 8.440544843673706, 9.438683969633919, 9.187040192740303, 12.13689877305712, 26.75804431097848, 27.381407158715383, 17.83077641895839, 16.656435319355555, 29.711306640080043, 38.13328068596976, 44.99803488595145, 43.41153185708182, 46.7500752721514, 45.22075244358608, 47.44997426441738, 45.58844069072178, 47.92614821025303, 48.578973157065256, 43.03802101952689, 39.8289920261928, 39.08351632526943, 36.87389884676252, 34.97193717956543, 33.57261862073626, 32.16043547221592, 34.88869081224714, 37.91269275120327, 41.58074753625052, 43.392827306474956, 43.264164039066856, 46.06905800955636, 45.9847138268607, 45.436980383736746, 47.913724831172395, 50.2800624029977, 52.55637911387852, 57.564067431858604, 52.07643229620797, 38.26121439252581, 2.6625407976763587, 8.192924073764257, 45.778529507773264, 48.93214661734444, 35.13346890040806, 21.072342089244298, 19.409933464867727, 26.446299484797887, 55.88608094624111, 60.24382781982422, 35.16153962271554, 43.32018041610718, 26.870287248066493, 42.368673256465364, 62.61460181644985, 9.043164713042122, 0.4871108446802412, 0.10014498340232031, 0.09185855090618134, 0.08451600133308343, 0.011106462201236613, 0.0982192535219448, 0.1233641260436603, 0.07508312285478626, 0.012020638861161257, 0.12223484021212373, 0.05526734223323209, 0.12684089876711369, 0.13662762647228582, 45.979488781520296, 77.83963353293282, 45.131204060145784, 26.063102858407156, 24.993907111031668, 34.247973101479666, 56.749530111040386, 32.20291328430176, 43.244389465876985, 48.85268701825823, 53.34198066166469, 26.34507465362549, 30.973217623574392, 44.444256510053364, 55.49891342435564, 68.20284339359829, 36.624149322509766, 0.3543757971908365, 6.004980632237025, 29.057074683053152, 47.58195877075195, 67.85006945473808, 61.67965221405029, 49.724640778132844, 60.1180237361363, 61.14960193634033, 56.04036569595337, 47.411064352308, 46.61197287695748, 47.069060121263774, 44.47778851645333, 42.811488900865825, 43.96656090872628, 46.11052485874721, 44.78521851130894, 48.7494923727853, 51.71419143676758, 50.86051491328648, 53.821593965802876, 55.62424155644008, 51.532284123556956, 49.54489088058472, 49.74201822280884, 53.96517848968506, 52.17552055631365, 52.96480812345232, 54.47110462188721, 52.58102090018136, 53.28888252803257, 56.058180877140586, 55.891615186418804, 53.94230849402291, 54.68140227454049, 52.77960041591099, 52.10455165590559, 43.75376885277884, 43.40938833781651, 33.792852197374614, 29.410932540893555, 21.137097563062394, 12.692371640886579, 25.485014472688945, 30.582117421286448, 34.90121841430664, 38.81974186216082, 39.851455552237375, 39.57979140962873, 41.022449357169016, 40.189617429460796, 40.22971200942993, 40.17759357179914, 40.674226488385884, 40.940064566476, 40.62180233001709, 38.77281372887747, 36.33684478487287, 35.12738575254168, 34.201941285814556, 35.472148418426514, 36.70806966509138, 38.89701277869088, 39.03395482472011, 37.56054415021624, 39.88208668572562, 34.249532972063335, 37.419454029628206, 37.82697977338518, 35.720994676862446, 35.032181535448345, 36.759541920253206, 36.397370542798726, 34.75837387357439, 35.4055985723223, 37.74377509525844, 36.103444371904644, 36.14585270200457, 37.75381176812308, 41.332672527858186, 35.595736026763916, 33.474166120801655, 33.016668932778494, 26.749372959136963, 22.140917709895543, 14.101251789501735, 5.798723791326795, 19.448233672550746, 17.43382235935756, 8.414830429213387, 11.346434354782104, 11.7550014598029, 12.039675235748291, 21.261965376990183, 37.332028320857454, 33.63302973338536, 23.841174909046718, 30.700257641928538, 42.821949413844514, 44.53843239375523, 46.761751719883506, 46.591003213609966, 51.9861022404262, 49.761462756565635, 51.523227146693635, 48.03690596989223, 51.60309321539742, 52.24553060531616, 48.55977528435843, 45.89527661459786, 42.70681776319231, 42.19751133237566, 40.66399874005999, 40.088993617466514, 39.01041085379464, 42.31774296079363, 46.249426296779085, 49.43171167373657, 50.278950691223145, 52.28732054574149, 51.262558528355186, 53.72914470945086, 53.02625799179077, 54.69268962315151, 56.15818282536098, 60.498986516680034, 61.13843618120466, 61.09745570591518, 39.319383348737446, 1.411590814590454, 9.73849092211042, 52.68602555138724, 50.70744957242693, 44.663892541612896, 21.635783672332764, 14.391980920519147, 37.69300808225359, 61.27325207846505, 60.463536807468955, 30.335974012102398, 49.02358143670218, 30.70117133004325, 46.048810958862305, 69.79726736886161, 6.165566963808877, 0.5773779324122837, 0.12614188556160244, 0.17119556585592882, 0.10710415390453168, 0.024195659706102948, 0.10254787267850977, 0.10012663581541606, 0.18199432854141506, 0.2521747441164085, 0.18804240971803665, 0.1624142099171877, 0.18266491112964495, 0.9147823474236897, 42.107490471431184, 97.13933209010533, 60.093732833862305, 37.759578772953574, 36.749328068324495, 46.960129737854004, 56.695052759987966, 54.378644943237305, 64.31258869171143, 48.95314407348633, 59.78596237727574, 28.026523079190934, 37.13142687933785, 51.71642528261457, 61.96581377301897, 72.81666960035051, 35.68477371760777, 0.8669954059379441, 8.55854262624468, 34.30092879704067, 55.42855249132429, 68.58197184971401, 64.62107481275285, 55.83757209777832, 58.27396140779768, 58.27007736478533, 52.922208717891145, 48.68753181185041, 51.19413614273071, 49.434636865343364, 46.109969002859934, 43.39030858448574, 47.42157697677612, 45.79469101769583, 45.47949293681553, 51.304456165858674, 51.64634575162615, 52.742062773023335, 54.59882640838623, 57.55657032557896, 51.55969476699829, 49.49867146355765, 50.660914012363975, 54.58045537131173, 51.089683873312815, 53.2756427356175, 53.489629881722585, 52.74971968787057, 56.88246652058193, 57.32641124725342, 59.428547041756765, 54.61261510848999, 57.24847330365862, 56.434589113507954, 57.76263999938965, 48.676001276288716, 45.22643607003348, 34.26440559114729, 33.0845319884164, 20.683135271072388, 19.09314772060939, 31.562209469931467, 33.04160949162075, 38.23471743719918, 41.14219461168562, 40.835636615753174, 39.70483119147164, 42.36866978236607, 40.74586936405727, 42.83437279292515, 43.1820467540196, 44.86798545292446, 44.311879430498394, 45.059543813977925, 42.39374930518014, 39.35834189823696, 40.28224733897618, 38.58500739506313, 38.04902335575649, 40.63859265191214, 43.20520509992327, 42.716044970921104, 42.28183119637625, 42.77119977133614, 37.151076384953086, 41.501756940569194, 41.32243435723441, 39.6582921573094, 37.75322117124285, 40.38209295272827, 39.33728538240705, 40.1120651108878, 38.175904410226, 41.30849974496024, 39.60420390537807, 38.10716935566494, 39.618569305964876, 41.531026227133616, 34.83395290374756, 34.16081142425537, 34.78460332325527, 29.281800270080566, 22.713508333478654, 17.470388991492136, 8.425778184618268, 19.858321564538137, 22.24733805656433, 9.580204010009766, 13.657834257398333, 17.08060199873788, 18.747497422354563, 25.152239186423166, 36.48427166257586, 34.296294348580496, 30.373789582933696, 34.882201194763184, 45.997727802821565, 48.092637470790315, 50.72156136376517, 48.85200262069702, 53.65528188432966, 50.93003511428833, 51.999348981039866, 50.469852447509766, 53.33708218165806, 53.93718767166138, 50.705438068934846, 49.068383421216694, 47.02483483723232, 44.184032576424734, 44.3950319971357, 45.78500522886004, 41.96439579554966, 44.1912065914699, 50.93047979899815, 53.65060922077724, 55.72226674216134, 53.767182622637065, 54.448498657771516, 55.37432527542114, 55.03743144444057, 55.78612763541085, 59.372885022844585, 61.880733081272666, 69.54683344704765, 64.47899804796491, 48.48173311778477, 3.7785849911825995, 10.123310821396963, 58.00143568856375, 58.045799936567036, 50.25261007036482, 30.712052209036692, 28.54125952720642, 40.61390570231846, 73.33640875135148, 72.01406928471157, 50.34471539088658, 59.089697292872835, 40.10636411394392, 66.41248716626848, 86.59763635907854, 12.648421679224287, 0.9468418785503933, 0.40067517278449877, 0.2791789450815746, 0.2323990309877055, 0.16011595752622398, 0.19395707733929157, 0.1444439563368048], [0.08259712465639625, 0.06098933305059161, 0.04168374630223427, 0.08410703470664364, 0.0406634535507432, 0.12154941127768584, 0.16871036349662713, 52.461817605154856, 60.71046188899449, 39.251937185014995, 34.191522462027415, 40.784483977726524, 47.094820567539756, 50.27471923828125, 127.27869987487793, 58.51915986197335, 35.51315668651036, 29.20048897606986, 11.507443223680768, 35.18328401020595, 48.8730799811227, 64.20808778490338, 52.411644663129536, 1.7613565091575896, 1.4978303355830056, 21.526912348611013, 37.693536145346506, 59.60591370718819, 55.687664713178364, 43.973880835941856, 48.519604274204795, 51.274571963718955, 44.726318631853374, 41.28733205795288, 41.34857695443289, 43.016068186078755, 42.045912061418804, 43.33662680217198, 38.60803025109427, 39.12206493105207, 39.33629526410784, 39.0999870300293, 39.17580577305385, 41.29072972706386, 43.44931616101946, 43.58352061680385, 40.59618084771292, 41.52640220097133, 45.182401861463276, 45.91224064145769, 49.03374317714146, 49.338209765298025, 50.37939732415335, 48.74235657283238, 52.39865500586373, 53.91380698340279, 53.85321869168963, 51.32420989445278, 53.493729318891255, 49.88734674453735, 50.22147519247872, 41.660571915762766, 44.91085236413138, 44.75591795785086, 32.161561080387656, 26.58212287085397, 8.46506416797638, 16.18339327403477, 27.988452162061417, 27.719433546066284, 33.66948693139212, 35.89203153337751, 35.25155700956072, 36.59154142652239, 37.546161379132954, 36.86313261304583, 35.870870794568745, 37.2727358681815, 38.88412734440395, 40.63341276986258, 36.02659729548863, 33.264021328517366, 33.21774285180228, 32.19809470857893, 31.99270943232945, 35.28926140921456, 35.625773089272634, 33.986936228615896, 33.60270779473441, 34.94844879422869, 35.037764413016184, 35.909089360918315, 34.063279560634065, 33.80445221492222, 35.118731771196636, 35.33810724530901, 32.34340238571167, 32.372963496616904, 33.91713115147182, 33.215710503714426, 33.96955183574131, 35.10798985617501, 37.232797622680664, 37.121671608516145, 33.868872438158306, 31.835037435804093, 24.27246870313372, 20.871401923043386, 22.91376062801906, 11.707903964178902, 5.854791411331721, 16.920670100620814, 10.019612431526184, 9.553362250328064, 12.99235142980303, 11.681359239986964, 11.853814397539411, 22.867051362991333, 33.56272438594273, 24.8187986101423, 22.15777403967721, 30.504780496869767, 38.66556828362601, 45.09757130486624, 44.50229828698294, 41.80157518386841, 47.531167439052034, 49.053479535239084, 49.77351788112095, 45.622358322143555, 47.88218348366873, 48.7677001271929, 43.79136208125523, 39.364015102386475, 35.13923937933785, 34.66287783214024, 33.53021376473563, 32.8724034854344, 34.62488508224487, 42.024330956595286, 44.118347781045095, 47.07379184450422, 48.736318588256836, 48.64519643783569, 47.704146317073274, 51.15345791407994, 53.12986258098057, 54.39870439256941, 55.74206215994698, 60.68638638087681, 57.78805650983538, 61.99255044119698, 23.46287328856332, 0.2845679244824818, 10.838176233427864, 44.77528258732387, 47.06769132614136, 26.209444080080303, 27.553524460111344, 24.42953794343131, 28.354839359010967, 60.9188939503261, 54.793803283146445, 30.611925193241664, 45.0435004234314, 39.98621933800833, 51.90614931924002, 43.4366773877825, 0.030068241192826202, 0.028378731404830302, 0.1412621292152575, 0.052071062315787585, 0.02605511198219444, 0.08420903209064688, 0.05039791709610394, 0.17499331278460367, 0.09203218801745347, 0.03659299661272338, 0.043644301992441924, 0.079900938618396, 0.17667738241808756, 0.1703950980944293, 0.6184992715716362, 76.09658064161027, 66.24864864349365, 35.27798100880214, 28.999460220336914, 35.876693384987966, 44.36825016566685, 46.25227158410208, 115.72761848994664, 67.10886342184884, 37.232856682368684, 31.18068388530186, 15.938177449362618, 41.96340567725045, 51.73252425874983, 69.64622047969273, 59.8846754346575, 4.63318475655147, 1.8559585128511702, 30.963576998029435, 44.55389213562012, 65.88885702405656, 63.04280539921352, 53.03224733897618, 57.08614601407732, 55.74097129276821, 50.122710023607524, 48.53045736040388, 47.83533525466919, 47.33442224775042, 48.83647339684622, 48.06857933316912, 44.873505796704976, 43.43722629547119, 43.37975427082607, 44.188733032771516, 43.12258407047817, 45.97180754797799, 48.23048625673567, 46.54270281110491, 44.0428660256522, 43.19350780759539, 46.68760749271938, 48.19819450378418, 50.351281438555034, 53.05764995302473, 51.78653955459595, 52.037671770368306, 52.685688563755576, 55.404167788369314, 54.684907640729634, 54.12189163480486, 55.47241299492972, 55.799113818577354, 53.670428957257954, 46.63315446036202, 47.36912849971226, 47.770932401929585, 38.493548257010325, 32.861484391348704, 13.45989397593907, 18.95504879951477, 30.99567767551967, 30.976205348968506, 34.769883564540315, 35.59491613933018, 35.18748072215489, 36.390689849853516, 38.9117568561009, 39.0178211075919, 38.3539137840271, 40.64021853038243, 40.58988925388881, 42.8184301512582, 38.35125262396676, 34.90390041896275, 34.904633453914094, 34.160755838666645, 33.47003541673933, 38.02828645706177, 38.626411710466655, 36.758374622889924, 36.77543592453003, 36.08700145993914, 36.65367916652134, 36.20158420290266, 35.36517742701939, 37.3505140032087, 36.538412025996614, 36.99545758111136, 35.11145353317261, 33.532277379717144, 37.742302077157156, 34.87673643657139, 38.10914264406477, 38.54203973497663, 39.52863529750279, 36.57313564845494, 34.72291374206543, 30.281906604766846, 26.180273805345806, 25.819075175694056, 26.6476218019213, 13.845616272517614, 10.936135411262512, 20.08349531037467, 12.703502655029297, 21.478156839098247, 23.987102712903702, 23.238335302897863, 26.46571969985962, 33.32943861825125, 38.25498880658831, 33.82943098885672, 32.40873977116176, 39.97754798616682, 44.94075393676758, 48.48891060692923, 46.53213460104806, 46.75547749655587, 49.65264701843262, 52.103992325919016, 53.66315419333321, 49.310055664607454, 53.377593653542654, 51.017318384987966, 49.16395589283535, 42.667692456926616, 40.76789167949131, 38.75345604760306, 39.90165628705706, 39.266420704977854, 42.08077464784895, 48.08753054482596, 51.74611840929304, 53.34810549872262, 53.7566283089774, 54.33024031775338, 53.49693591254098, 55.78681550707136, 56.204002720969065, 59.50675596509661, 59.68062768663679, 61.10321576254708, 61.89614418574742, 63.98883737836565, 18.149370431900024, 0.20336154555635794, 13.870294536863055, 50.51414721352713, 51.24641786302839, 35.27372176306588, 30.24483449118478, 24.597580126353673, 28.508738483701432, 64.1602008002145, 62.82390240260533, 29.589060034070695, 47.66926288604736, 41.5778431892395, 56.67152615955898, 44.2904303414481, 0.143417305712189, 0.07600426128400223, 0.02597861224785447, 0.06518102384039334, 0.07881450905863728, 0.040167254462305985, 0.024085969431325793, 0.19348331061857088, 0.1164072286337614, 0.157572672569326, 0.1828237154654094, 0.12089611776173115, 0.1915785406849214, 0.1357284047241722, 0.30386255628296305, 79.52559307643345, 76.73494638715471, 55.39716053009033, 42.07140152794974, 48.80215276990618, 66.76866572243827, 58.642691884722026, 137.78377859933036, 63.999405588422505, 51.85135235105242, 43.52970681871687, 18.023064340863908, 50.85721104485648, 57.20756925855364, 75.12842559814453, 59.94269289289202, 3.3872520242418562, 7.296029755047389, 42.24678448268345, 53.495108536311555, 71.72311346871513, 61.7873284476144, 55.0919748033796, 54.6034608568464, 56.87047045571463, 51.33250951766968, 51.607588699885774, 49.031158447265625, 51.348858628954204, 50.35250779560634, 50.96921253204346, 44.72333090645926, 47.95864493506295, 43.539625372205464, 45.27759565625872, 44.29954637799944, 46.18853228432791, 48.40055383954729, 47.63376453944615, 44.873870577131, 43.203356879098074, 47.07055050986153, 47.78220932824271, 53.17414345060076, 54.71931512015206, 54.77780852999006, 52.245395115443635, 55.25494827542986, 57.1112950188773, 55.71257053102766, 57.61643600463867, 58.385830879211426, 58.424393381391255, 56.15380546024868, 49.08256469454084, 49.13020501817976, 49.095936502729145, 38.897377559116904, 36.31971052714756, 17.712016071592057, 25.46738862991333, 35.66160842350551, 34.82016767774309, 38.95774350847517, 37.653014251164024, 35.6397111756461, 38.10448735100882, 41.90645129340035, 42.470617226191926, 42.29072489057268, 42.856791155678884, 44.36765262058803, 46.83736549104963, 40.335995129176546, 38.52575315747942, 37.21415213176182, 37.123245375497, 37.56035654885428, 41.070770604269846, 40.891256945473806, 39.2782951763698, 39.69269616263253, 40.60352509362357, 39.92649957111904, 39.50186736243111, 39.6502183505467, 39.59832572937012, 40.024288518088206, 39.88050944464547, 38.57707602637154, 37.089737687792095, 40.315209593091694, 37.81441395623343, 40.90503522327968, 42.5959210395813, 39.91277687890189, 39.73980147497994, 33.605949129377095, 33.793873582567485, 29.030758380889893, 25.902769701821462, 27.292359045573644, 19.039881093161448, 13.880960021700178, 23.06063859803336, 15.960838999067034, 18.370194605418614, 24.34380064691816, 25.621284280504497, 28.268457617078507, 35.196773937770296, 41.64817632947649, 38.566368852342876, 34.860748631613596, 43.83082784925188, 48.146968909672324, 50.201269830976216, 50.28357471738543, 47.53706645965576, 52.26905720574515, 53.83891582489014, 54.88264989852905, 51.77017307281494, 55.29778739384243, 54.00045101983206, 50.944410937173025, 46.795519965035574, 43.53904867172241, 43.29294695172991, 43.00481557846069, 42.3992349079677, 43.35871512549264, 52.01074055262974, 55.477436542510986, 56.834631647382466, 58.74511528015137, 58.74198859078543, 56.41932392120361, 61.03081553322928, 60.691680908203125, 61.86170891353062, 63.23955059051514, 67.4898053577968, 64.26653603145054, 70.55107743399483, 30.930513995034353, 0.21487705835274287, 16.333802665982926, 57.036198888506206, 59.567121914454866, 39.50992032459804, 38.16628462927682, 32.20837804249355, 40.42656489780971, 75.06377955845424, 67.51551369258335, 46.209185804639546, 63.71698216029576, 63.28564493996756, 72.85370349884033, 61.307722091674805, 0.10152795990662915, 0.12077970829393182, 0.2764256399657045, 0.07240005289869648, 0.0975232869386673, 0.14486930279859475, 0.06765564105340413, 0.27421220445207184], [0.08885783156646149, 0.10741927913789238, 0.17504196374544076, 0.14568096638790198, 0.06570866624159472, 0.08659083928380694, 0.49231857380696703, 2.683313523020063, 59.3618860244751, 62.04725360870361, 55.31390374047415, 27.955177239009313, 50.358511039188926, 40.070233481270925, 26.72985199519566, 23.077644314084733, 32.57386023657662, 51.559031214032856, 13.556416613715035, 26.818215710776194, 46.69307919910976, 56.42326702390398, 65.59765802110944, 16.2345598084586, 0.5769136516111237, 15.643657207489014, 30.620947429112025, 51.825862884521484, 57.666344915117534, 54.22127171925136, 50.623407636369976, 46.624455315726145, 40.58195441109793, 43.321542263031006, 43.223364216940745, 45.4078118460519, 46.61095496586391, 47.2281356539045, 46.61165673392159, 40.950045653751914, 34.59363208498274, 37.03019857406616, 35.29674809319632, 37.50525385992867, 39.55139412198748, 36.22563886642456, 39.73550748825073, 41.42767177309309, 43.19537687301636, 46.77080174854824, 48.30828523635864, 52.80721950531006, 51.69725867680141, 49.639104979378835, 50.24960150037493, 52.4618627684457, 49.89908225195748, 53.12516559873308, 52.11343840190342, 53.663279260907856, 53.05526672090803, 44.45862538473946, 49.54316772733416, 49.53813028335571, 41.48240620749337, 37.496047496795654, 19.054923943110875, 14.700215169361659, 24.625954832349503, 25.335942608969553, 24.735498394284928, 28.724516527993337, 32.5880241394043, 33.8904778616769, 35.789302417210166, 37.329141344342915, 34.72574860709054, 36.61893817356655, 35.39543335778372, 35.66047934123448, 34.81375101634434, 32.806756905147004, 31.801359517233713, 30.53263929912022, 30.460947786058696, 34.74731234141758, 34.83805581501552, 32.96503686904907, 34.12387480054583, 36.03186750411987, 34.02457809448242, 35.16637209483555, 32.41967970984322, 33.043989249638145, 34.76852866581508, 34.980455671037944, 33.531815324510845, 33.97342893055507, 32.040273325783865, 32.7265225819179, 33.80757543018886, 36.20088243484497, 36.2601957321167, 33.86438042776925, 32.069410596575054, 26.17752058165414, 18.74977990559169, 26.673988478524343, 25.333111218043737, 11.02097031048366, 9.69439331122807, 15.185107367379324, 18.872514622552053, 38.42225626536778, 31.349403517586843, 23.155201843806676, 27.84394700186593, 31.180291312081472, 32.96126399721418, 30.551812853131974, 34.60178232192993, 39.05111340114048, 41.25683641433716, 42.67164945602417, 42.749549184526714, 44.07304205213274, 45.39524602890015, 46.44197130203247, 49.46110602787563, 43.76262433188302, 47.63707883017403, 45.11692203794207, 43.1603753226144, 37.46282121113369, 34.081452574048726, 35.12805625370571, 34.7662079674857, 35.69537666865757, 44.188475949423655, 45.88669558933803, 49.53151559829712, 47.10514906474522, 47.82915483202253, 49.83763585771833, 52.766089643750874, 53.28244849613735, 54.85534347806658, 54.16638789858137, 57.50507722582136, 56.03580072947911, 72.17807456425258, 44.71314484732491, 1.5957048322473253, 0.23177518589156015, 16.983341114861624, 51.20556245531355, 39.412114007132395, 22.326761177607946, 39.5656726700919, 51.548362255096436, 54.95784330368042, 59.86589445386614, 57.76056596211025, 41.594369479588096, 35.60674892153059, 35.466190338134766, 71.02591037750244, 10.69621671949114, 0.6584080415112632, 0.14214677603117057, 0.025114826991089752, 0.0528641645796597, 0.030794161704501936, 0.08957436454615422, 0.023110724619722793, 0.09427884460559913, 0.03242195364353912, 0.15007933894438402, 0.07852871689413275, 0.10557443063173975, 0.06796867639890738, 0.2318240946957043, 0.45134444960526054, 6.725659949438913, 73.36892632075718, 62.5140266418457, 51.36948783057076, 26.346860340663365, 54.7953006199428, 42.241444792066304, 37.323482036590576, 23.392494985035487, 33.937207971300396, 50.95937735693795, 17.210064308983938, 34.67610025405884, 51.57639823641096, 60.030816895621165, 70.60995646885463, 21.768410887037003, 1.0999121048620768, 25.219605445861816, 40.179386207035606, 57.61110673631941, 61.99532972063337, 63.660152844020296, 54.85519756589617, 54.891269138881135, 48.11542061397007, 50.07020248685564, 49.20590911592756, 53.2504346711295, 52.01285975319998, 52.967743737357004, 51.385347093854634, 48.43600354875837, 39.064363615853445, 41.478956426892964, 38.66771527699062, 41.92170606340681, 40.98773963110787, 42.33848333358765, 43.13095317568098, 45.853517941066194, 45.31874636241368, 50.49476868765694, 49.405586447034565, 55.31222922461373, 53.53288241795131, 55.16572993142264, 52.41117565972464, 54.552686895642964, 52.50648757389614, 56.18381125586373, 54.19689049039568, 57.69974143164498, 51.52981056485857, 47.21540307998657, 51.68252502168928, 50.65776300430298, 45.12505490439278, 44.54208019801548, 29.112618582589285, 20.891344990049088, 27.518799100603374, 30.801117692674907, 29.697246960231237, 30.45528153010777, 33.956801891326904, 34.23747784750802, 37.57700443267822, 39.84443439756121, 37.32334654671805, 38.86334875651768, 40.38297189985003, 37.67674582345145, 36.264719009399414, 35.766175338200156, 33.68970966339111, 34.38840661730085, 33.29418693270002, 37.70832886014666, 36.76265818732125, 36.18622868401663, 35.774047647203716, 37.0957305090768, 36.273355620247976, 36.7029835837228, 35.15725605828421, 34.82086249760219, 35.88836983272007, 36.61418213163103, 35.186518396650044, 36.60983255931309, 33.75770820890154, 35.43558699744088, 36.94182096208845, 36.49390186582293, 37.38978522164481, 35.06437601361956, 31.33507980619158, 22.949910368238175, 24.02295020648411, 29.584453378404888, 25.01931493622916, 17.193487644195557, 14.920511279787336, 23.413386481148855, 29.772416046687535, 48.21410240445818, 42.258888244628906, 38.04672350202288, 39.742205551692415, 42.653980187007356, 41.85456214632307, 40.466364179338726, 44.998017515454976, 44.75620630809239, 47.23518112727574, 45.75068807601929, 45.78981685638428, 48.040011814662385, 49.07188878740583, 50.40187822069441, 52.271593298230854, 46.382633686065674, 50.69667986461094, 50.63134595326015, 47.90710319791521, 42.16434758050101, 38.73476191929409, 40.61066089357649, 38.840885230473106, 42.9824423789978, 51.87074824741909, 50.074955054691856, 53.783677646092, 52.59039749417986, 54.29343223571777, 53.64385209764753, 57.60174751281738, 56.40110227039882, 61.72623988560268, 59.6255910055978, 63.65785299028669, 65.382632119315, 76.29187365940639, 32.71160479954311, 0.37115439400076866, 0.2387375251523086, 23.429195369992936, 57.46691077096121, 49.91735601425171, 27.810269083295548, 37.36841951097761, 53.41267163412911, 43.74963467461722, 64.58556951795305, 66.74827970777238, 41.946389538901194, 34.16795069830758, 42.88805457523891, 75.38482802254813, 7.944803033556257, 0.6613859417183059, 0.29509262687393595, 0.05051641305908561, 0.07868406070130211, 0.02119495563342103, 0.1810926097844328, 0.04609609668010047, 0.09391667653939553, 0.21112005066658768, 0.20932293709899696, 0.15728699575577462, 0.14520907242383274, 0.16017676783459528, 0.22097383120230266, 0.4599616272108895, 4.5551347732543945, 83.88781806400844, 70.05381570543561, 77.30903434753418, 32.17556170054844, 67.79126685006278, 48.11147403717041, 39.31536381585257, 34.570133277348106, 47.91047307423183, 72.4981711251395, 21.032252720424108, 40.35520689828055, 57.68954495021275, 64.60304423740932, 74.20815753936768, 18.20240776879447, 1.6841392240353992, 43.23344605309622, 50.18367351804461, 63.49092251913888, 58.675918170383994, 62.69050393785749, 54.02879619598389, 58.31994111197335, 51.45415163040161, 52.88867323739188, 52.969063895089285, 56.091125760759624, 54.57853419440133, 54.667690004621235, 54.0163380759103, 47.56884752001081, 41.30397994177682, 45.5074142728533, 42.377799715314595, 43.957212107522146, 44.43648842402867, 41.47471802575247, 43.693986552102224, 47.4170571735927, 48.110998085566926, 50.9157600402832, 49.76031282969883, 56.32148633684431, 55.765310832432334, 55.28449548993792, 53.69745397567749, 57.5945839200701, 52.71458959579468, 58.38558769226074, 57.34062031337193, 59.54663167681013, 54.59837824957711, 49.46471561704363, 53.351388522556846, 54.128089427948, 46.03637020928519, 46.165957587105886, 28.276904889515468, 25.33845090866089, 33.89991698946272, 34.23403154100691, 34.05907242638724, 35.51184000287737, 32.967190810612266, 35.865524155753, 38.468079635075156, 43.545308998652864, 38.66238253457205, 42.65862853186471, 42.321091992514475, 41.86442511422293, 39.385325227464946, 39.2041266305106, 36.74121604646955, 37.10717419215611, 36.57628665651594, 42.107740606580464, 41.07471718106951, 41.02547877175467, 39.972486223493306, 43.030815737588064, 39.46127946036202, 42.61323595046997, 39.32288176672799, 39.86347940989903, 40.74391344615391, 40.656039578574045, 40.19994592666626, 41.372947760990684, 37.491340092250276, 38.07292168481009, 41.802360330309185, 41.3448874609811, 40.91386638368879, 35.23931080954415, 32.26562772478376, 27.506530318941387, 26.54304620197841, 29.511997563498362, 27.939470836094447, 18.502632481711252, 16.039433547428676, 23.94108305658613, 26.019886800221034, 46.72973789487566, 44.260111876896445, 41.704387256077354, 44.25180183138166, 47.007971559252056, 44.892265932900564, 42.612801688058035, 47.091297830854145, 49.8042254447937, 49.27426201956612, 48.73892068862915, 46.98296846662249, 50.18118953704834, 50.7219226700919, 51.499009200504844, 54.6680200440543, 48.344533988407676, 54.28165851320539, 54.619538988385884, 50.26818445750645, 44.17865814481463, 40.14256075450352, 44.07713801520211, 43.51612656457083, 45.92373991012573, 54.02787555967058, 55.073610714503694, 59.150702476501465, 57.44074732916695, 59.68732575007847, 59.34884425571987, 62.83325467790876, 61.508337429591585, 62.148989132472444, 61.251066480364116, 64.89436135973249, 63.200807435171946, 79.86210128239223, 51.40615347453526, 2.543044592653002, 0.3103017179029328, 23.112282821110316, 63.07173769814627, 55.121025221688406, 35.42076996394566, 49.79395948137556, 67.01725142342704, 76.20775876726422, 75.83502265385219, 67.8723314830235, 57.82862704140799, 48.13770348685128, 54.91980191639492, 93.49287578037807, 15.570848771503993, 1.0831480558429445, 0.4457427087639059, 0.15385590200977667, 0.2252209447324276, 0.20548757218888827, 0.22653663770428725, 0.08580044098198414, 0.2014674964760031], [0.030634784006646702, 0.046412918251007795, 0.05234027786978653, 0.18966311775147915, 0.11585070778216634, 0.27925681376031464, 0.03777930652722716, 0.9394105630261558, 9.43066053731101, 62.799180712018696, 57.28424263000488, 47.3780951499939, 26.25034291403634, 38.78387873513358, 24.571630341666086, 106.51660006386894, 69.51480225154332, 55.36548369271414, 24.107301337378367, 18.600157397133962, 43.2935722896031, 56.539367948259624, 62.691997800554546, 30.317745413099015, 0.5391247336353574, 16.07254866191319, 33.056958062308176, 40.02357632773263, 52.53912673677717, 55.50033780506679, 48.46817370823452, 44.03886733736311, 43.79815741947719, 42.620510714394705, 45.81266253335135, 47.09817654745919, 48.33051947184971, 47.962862491607666, 46.138095310756135, 46.02307135718209, 41.257187298366, 35.182658672332764, 35.10314696175711, 35.96729442051479, 37.606186866760254, 37.09302418572562, 39.04214675085885, 40.756524426596506, 45.358483110155376, 45.707261834825786, 46.30706507819039, 46.874576568603516, 50.66659763881138, 50.39214379446847, 51.8107088633946, 52.95409747532436, 52.82099083491734, 52.733992440359934, 52.61491421290806, 54.10388190405709, 45.56952769415719, 46.523560523986816, 52.953843866075786, 51.33597319466727, 50.51203843525478, 47.44588524954659, 40.051504611968994, 21.210781472069876, 22.77382390839713, 29.157496997288295, 23.823835679462977, 19.21114202908107, 28.46992584637233, 33.16015270778111, 35.91774681636265, 35.193001065935405, 35.82802472795759, 35.24098879950387, 35.752959864480154, 33.27464859826224, 34.33045516695295, 31.98055703299386, 31.552718230656215, 31.605635711124965, 32.09856176376343, 33.43824740818569, 32.78307744434902, 30.519948414393834, 32.528537137167795, 35.064921447208945, 34.96916137422834, 34.74562740325928, 35.1035430090768, 34.23363549368722, 35.04691866465977, 37.92694698061262, 36.864657742636545, 36.76133108139038, 33.682688508714946, 33.98993437630789, 34.66507693699428, 34.950717381068635, 36.103958538600374, 34.35052503858294, 24.959855726787023, 13.275626012257167, 25.149650982448033, 29.99353551864624, 25.82209243093218, 27.55313014984131, 20.73609791483198, 36.97142376218523, 46.12301424571446, 49.85697269439697, 44.43161426271711, 38.92931842803955, 41.85460383551461, 39.63468565259661, 41.5115191595895, 39.33169208254133, 41.01000165939331, 42.21257850102016, 43.86145550864083, 44.040889263153076, 45.58482067925589, 43.8696265901838, 48.772435324532644, 46.6739890234811, 48.813982078007285, 42.40811817986624, 45.622719628470286, 47.914172989981516, 41.398367745535715, 37.849679538181846, 35.28413711275373, 35.02263123648507, 35.880414145333425, 45.359417642865864, 45.831669330596924, 46.16526971544538, 47.60124002184187, 49.108078479766846, 47.920791149139404, 47.32588985988072, 47.50009856905256, 50.1106618472508, 55.570149830409456, 57.63242033549717, 61.345075607299805, 62.74503340039934, 41.29305042539324, 3.74412670305797, 0.1577241894389902, 0.6799554909978593, 29.08958877835955, 56.664327825818745, 34.91932541983468, 24.100476469312394, 39.413656507219585, 23.013927595955984, 34.826737199510845, 65.48383957999093, 47.742333616529194, 33.61864696230207, 42.296342509133474, 48.66513081959316, 47.21262032645089, 0.11602389706032616, 0.03418536437675357, 0.039632467087358236, 0.10257279526974473, 0.3970130921474525, 0.053655282128602266, 0.03512340511328407, 0.02708368455725057, 0.03403351841760533, 0.04933194875983255, 0.03643796832433768, 0.08099906612187624, 0.08499274682253599, 0.12034144252538681, 0.10025458037853241, 0.15956341288983822, 0.4616497680544853, 13.095474856240408, 73.31714139665876, 59.27948733738491, 41.94029944283621, 35.0551210130964, 51.42050150462559, 26.403132064001902, 87.10357638767788, 75.84421512058803, 58.237983635493684, 26.70351311138698, 25.318146535328456, 50.31382022585188, 60.56512641906738, 65.63594259534563, 35.56729704993111, 0.8356197295444352, 19.360728059496196, 48.97615998131888, 48.89860418864659, 58.572890281677246, 60.61692523956299, 54.63616950171334, 49.209546497889924, 49.75270107814244, 48.795340061187744, 49.64759220395769, 51.016390800476074, 52.797696999141145, 52.535468510219026, 53.22510848726545, 50.80449506214687, 49.01573692049299, 41.15061582837786, 39.75232212884085, 40.49685287475586, 41.18119485037667, 41.60164771761213, 40.975910323006765, 43.71223599570138, 48.507969515664236, 47.967476095472065, 50.98666640690395, 51.15875938960484, 52.03992993491036, 52.642880712236675, 51.980185849326, 53.134788853781565, 53.68067060198103, 55.440680571964805, 53.98622458321707, 56.611392974853516, 49.326641014644075, 49.87034102848598, 57.57843630654471, 52.7045042855399, 54.87195662089756, 49.38697222300938, 43.99387427738735, 27.300950493131364, 27.28383013180324, 31.574705805097306, 31.128384794507706, 22.32562688418797, 28.73348491532462, 34.63141986301967, 36.33773415429251, 36.97135428019932, 37.56028706686837, 37.529523917606895, 39.126414503370015, 38.98535564967564, 37.65482078279768, 35.37118761880057, 34.26574659347534, 34.91841173171997, 36.972052574157715, 37.057195799691335, 34.30468429837908, 33.26985086713518, 35.69975750786917, 37.250873361315044, 37.259037494659424, 36.77443885803223, 37.66732406616211, 36.01740482875279, 36.48325375148228, 37.84061908721924, 38.74363824299404, 37.12608371462141, 36.889309951237266, 36.41359806060791, 37.06427948815482, 37.30009092603411, 36.04443679537092, 32.74570655822754, 21.39509286199297, 16.39782510484968, 30.074287482670375, 30.515741280147008, 33.071045534951345, 33.27395725250244, 32.447354384831016, 44.97472020557949, 49.35239103862217, 48.563183375767295, 45.80692332131522, 43.61334923335484, 45.822108609335764, 45.76725952965872, 46.354437896183555, 41.99574606759207, 45.96981341498238, 47.59487894603184, 46.88588128771101, 46.17083174841744, 46.70304291588919, 48.47491693496704, 50.3128787449428, 50.38693611962454, 51.103531633104595, 46.981387751443044, 48.27391597202846, 49.775612762996126, 49.287060601370676, 42.41364894594465, 39.89872414725167, 39.3874374798366, 40.00903374808175, 52.255796568734304, 50.92214890888759, 52.88543537684849, 52.47646788188389, 55.017368521009175, 53.22395508629935, 52.195159639631, 50.684788022722515, 52.47362606866019, 57.09609236036028, 60.977140699114116, 61.630646569388254, 55.62337303161621, 31.93949317932129, 3.8814148562295094, 0.31104346524391857, 1.8786543692861284, 35.533539227076936, 62.86445903778076, 41.419848101479666, 29.9224728175572, 43.34412043435233, 30.843741416931152, 43.86853919710432, 68.30448859078544, 54.42009789603097, 31.926666804722377, 41.891596044812886, 55.57754966190883, 42.01072638375418, 0.35178639899407116, 0.03141379988353167, 0.055615030362137725, 0.11330438298838479, 0.3223385491541454, 0.07182922174355813, 0.022860148422686116, 0.03784279026357191, 0.025574985692011457, 0.10051605384796858, 0.14938768105847494, 0.15299849158951215, 0.26592113077640533, 0.1348380853555032, 0.30137008002826143, 0.23501776903867722, 1.2108441122940607, 14.767348664147512, 84.86663164411272, 68.28559643881661, 63.179615429469514, 38.443983282361714, 51.7959543636867, 34.50846454075405, 119.59299169267926, 86.54057775224958, 71.38670948573521, 36.09596463612148, 28.55999881880624, 56.34190361840384, 63.52153628213065, 71.18641376495361, 36.70362629209246, 0.7807690213833536, 26.023254939488, 59.03927421569824, 54.46147789273943, 63.391389574323384, 61.04015391213553, 55.74946893964495, 51.020379066467285, 53.1472886630467, 51.140523842402864, 53.31253072193691, 52.456714153289795, 57.47035360336304, 55.82994992392403, 55.14398206983294, 54.394698756081716, 48.868726934705464, 42.57320043018886, 42.539425236838206, 44.68667915889195, 43.541254724775044, 42.70208951405117, 43.235599994659424, 44.629943643297466, 50.77141121455601, 49.57157891137259, 52.85119465419224, 52.67961931228638, 55.612537315913606, 53.99531977517264, 55.42983443396432, 56.283160073416575, 54.791010107312886, 57.4244190624782, 55.893081256321494, 59.5001551764352, 49.67667736325945, 50.81809268678938, 58.92823505401611, 54.1237850189209, 57.14248548235212, 51.7936475617545, 47.98120920998709, 31.98462520326887, 31.836628573281423, 35.57830647059849, 34.80176189967564, 27.456833328519547, 33.05373409816197, 34.641505173274446, 38.26558133534023, 39.43728385652815, 40.21632283074515, 42.397212982177734, 41.93164546149117, 42.00747115271432, 40.85704401561192, 37.96210833958217, 37.22641570227486, 37.96689564841134, 40.39217826298305, 41.02794190815517, 38.36268588474819, 37.074910231998985, 39.88929891586304, 40.255892821720664, 42.358949252537315, 39.71971423285348, 42.26852887017386, 38.790361404418945, 38.64083617074149, 42.804464272090364, 41.12711354664394, 40.877586364746094, 38.32091678891863, 40.00721332005092, 40.90330512183053, 39.39397573471069, 37.40032911300659, 34.02619702475411, 27.554248809814453, 21.03443271773202, 29.12847089767456, 31.898147923605784, 33.60484436580113, 33.67832851409912, 32.78263970783779, 46.39884383337838, 51.34277548108782, 52.62281084060669, 50.41781044006348, 46.00282778058733, 47.22340045656477, 46.65791436604091, 46.86241374697004, 44.997948033469065, 49.45266744068691, 50.716214724949424, 49.20248017992292, 48.53941706248692, 48.44701991762434, 49.74457515989031, 53.22309698377337, 52.011140074048726, 54.64771393367222, 48.85942677089146, 52.404731205531526, 52.355002948216026, 52.142106669289724, 45.90757145200457, 43.68196964263916, 42.28808110100882, 42.46142128535679, 54.8527170589992, 54.62264135905674, 56.510915075029644, 55.44933107921055, 58.25945356913975, 56.138119901929585, 52.81303514753069, 53.540858949933735, 55.32302325112479, 62.656728744506836, 64.18558951786586, 64.97198663439069, 66.40874208722795, 46.97207021713257, 6.36831670148032, 0.35491639961089405, 1.7182908143315996, 37.96399130140032, 68.13631439208984, 49.743901184626985, 33.742842538016184, 49.515691076006206, 33.02782079151699, 56.15904787608555, 79.72964082445417, 59.33665711539132, 48.451407705034526, 62.26826885768345, 64.26516028812954, 65.76965372903007, 0.3480832262762955, 0.11333351928208556, 0.11704653075763158, 0.1999846938997507, 0.6774876319936344, 0.14613858397517884, 0.06777346865939242, 0.12976735244904244, 0.1564957017877272], [0.14449479218040193, 0.09392155520617962, 0.12922517582774162, 0.08024935956512179, 0.1445911034409489, 0.08504300591136728, 0.12015998869069985, 0.08733437117189169, 0.3681575490960053, 12.121143732752119, 73.29263510022844, 54.04152182170323, 38.524874210357666, 36.652762004307334, 94.56826932089669, 101.67524814605713, 70.04178837367466, 59.91830471583775, 29.817461218152726, 16.802144254956925, 36.81053474971226, 52.692754881722585, 61.088763509477886, 40.156550952366416, 1.8423244101660592, 6.415639579296112, 43.445084708077566, 39.539808000837056, 46.460272857121055, 45.17464419773647, 47.841616426195415, 45.29924971716744, 43.86250468662807, 43.186823640550884, 45.93381479808262, 46.26647022792271, 50.16114398411342, 47.53665999003819, 49.427313464028494, 45.018587657383506, 46.074922289167134, 40.82021508898054, 36.36713893072945, 34.8798040662493, 38.74895708901541, 36.21287849971226, 37.241371699741904, 40.46131978716169, 46.83272409439087, 47.970057351248606, 51.435683318546836, 50.606686796460835, 51.27247013364519, 49.04600327355521, 48.349508898598806, 49.07902806145804, 53.28060722351074, 50.56948266710554, 52.32246453421456, 49.68628672191075, 47.738466944013325, 50.917358125959126, 52.00707885197231, 51.215609550476074, 51.28160354069301, 51.87520899091448, 48.62816640308925, 31.639063494546072, 28.330030815941946, 30.54192556653704, 31.678657804216655, 19.208211626325333, 20.60766393797738, 32.28157384055001, 32.7106876373291, 32.120375633239746, 35.299582958221436, 33.682104860033306, 34.003049101148335, 33.790253571101594, 33.52733373641968, 32.62646157400948, 30.455100876944407, 30.32199423653739, 29.485208783830913, 29.886592320033483, 28.344394479479107, 28.748077869415283, 30.445547103881836, 35.31197854450771, 36.32820817402431, 36.90521090371268, 38.5143963268825, 38.7287586757115, 40.955229009900776, 38.69434772218977, 37.52603244781494, 36.175469398498535, 34.455859729221885, 34.05914885657174, 35.28894526617867, 36.952319690159385, 34.36687762396676, 25.120096819741384, 10.448286754744393, 15.555083308901105, 31.774574211665563, 27.86306323323931, 34.521391664232524, 38.752313068934846, 41.94517707824707, 45.79475702558245, 48.40276684079851, 45.53605127334595, 42.77270405633109, 41.57871866226196, 42.435466289520264, 41.3970684323992, 41.14353213991438, 40.91510663713728, 44.072847502572195, 42.466483048030305, 42.68179382596697, 43.506749970572336, 45.53523138591221, 46.55520609446934, 45.50314807891846, 45.986753123147146, 45.3050479888916, 39.44663960593087, 42.12819610323225, 47.17191777910505, 43.929151807512554, 38.09219946180071, 36.58563198362078, 35.65587963376726, 41.53181137357439, 48.88734810692923, 47.022086824689595, 50.420714787074495, 48.83664015361241, 52.155732086726594, 50.88524355207171, 53.80724246161324, 51.1114456312997, 51.184926305498394, 48.248054776872905, 49.68591499328613, 44.45471354893276, 24.28555737222944, 14.179873262132917, 4.596603359494891, 0.5709240872945104, 3.116585382393428, 36.485272203172954, 50.225717067718506, 30.715731280190603, 40.42650931222098, 56.02858502524239, 20.484824998038157, 16.569614103862218, 58.63942623138428, 42.37605571746826, 41.66990682056972, 39.270700795309885, 59.50385161808559, 8.035031471933637, 0.3705655341701848, 0.08738103402512414, 0.05210396108616676, 0.17365706020167895, 0.050244232307055166, 0.031297692363815646, 0.04221200956297772, 0.10023879086864845, 0.006961058949985142, 0.15346953059945787, 0.046189083119056056, 0.030740906883563315, 0.02388328593224287, 0.11532150475042206, 0.03436436530734811, 0.060865853247897964, 0.10645319454904113, 0.48486511089972084, 14.082056522369385, 81.39304651532854, 57.22540875843593, 29.669593129839214, 46.43921634129116, 81.38848154885429, 94.38475349971226, 76.25913374764579, 66.92445128304618, 31.12961115155901, 20.62865792001997, 41.58838708060128, 57.6244021143232, 64.2947804587228, 47.7061265536717, 3.3552538326808383, 7.3812103271484375, 52.43387542452131, 48.3339136668614, 55.616876465933665, 51.0332783971514, 54.549153736659456, 49.8291277885437, 52.297499656677246, 48.69796800613403, 50.31839214052473, 50.75702844347273, 53.614801679338726, 50.49680798394339, 53.644685881478445, 51.822621549878804, 52.0193841116769, 46.251281465802876, 42.15503352028983, 39.299855436597554, 41.759528160095215, 38.7665707724435, 41.38280725479126, 44.79310124261038, 48.310765743255615, 53.69934388569423, 55.36853742599487, 51.92040702274868, 54.11292151042393, 51.33634144919259, 51.30578327178955, 51.552076067243306, 53.64708300999233, 53.34070914132254, 55.42059680393764, 51.68983105250767, 50.43503155027117, 52.46267918178013, 54.56070164271763, 53.12709719794137, 51.90653147016253, 54.23849630355835, 52.5015161378043, 39.69292892728533, 32.72573743547712, 32.37858806337629, 34.20510619027274, 26.042145354407175, 26.74862950188773, 34.05592489242554, 33.33012301581246, 34.28346797398159, 37.73253638403756, 36.65833098547799, 37.18198892048427, 36.55442762374878, 35.69764872959682, 38.20226240158081, 35.56920780454363, 36.179475034986226, 32.185879775456016, 31.503524984632218, 31.944593157087052, 31.87287037713187, 32.30305419649397, 37.76259429114205, 37.796960081372944, 38.90487813949585, 40.13072449820382, 37.32977363041469, 39.22076409203665, 38.29749093736921, 38.59221267700195, 37.907005650656565, 36.86543246677944, 36.4124516078404, 35.509324754987446, 36.19669614519392, 32.503933565957205, 22.560475996562413, 10.917282342910767, 20.888226985931396, 31.87752914428711, 32.24819469451904, 35.00352716445923, 39.763505254473, 46.22138336726597, 46.65874467577253, 49.00696134567261, 47.897862093789236, 45.86167165211269, 45.80899041039603, 48.530888148716514, 46.91443838391985, 46.12266336168562, 44.99935851778303, 48.18696621486119, 45.6049530846732, 46.27543340410505, 47.70864527566092, 48.394203186035156, 49.09187528065273, 51.58769253322056, 49.47610024043492, 49.244996207101, 41.51824848992484, 46.3642452784947, 50.76620006561279, 48.23846626281738, 42.39136607306344, 40.18874543053763, 39.9880154473441, 47.14187724249703, 53.35440404074532, 53.84654147284371, 54.76584373201643, 52.75009489059448, 54.53947837012154, 54.71114403860909, 56.9746413230896, 56.061276299612864, 55.92075245720999, 53.55496031897408, 52.658583641052246, 45.15815264838082, 30.847663675035747, 20.903144768306188, 7.934361628123692, 0.6761183483260018, 4.377819785049983, 40.84996032714844, 55.21223422459194, 38.76855795724051, 44.444683824266704, 65.02572400229317, 28.552008390426636, 26.977987800325664, 65.33842073168073, 51.20737246104649, 41.29994303839547, 44.452952180589946, 59.45139271872384, 2.5931860506534576, 0.11767532915941306, 0.0684126147202083, 0.011192875332199037, 0.050579041841306856, 0.05008464765601924, 0.04276611822258149, 0.06251230489994798, 0.07720010461551802, 0.03924627548881939, 0.2705848648079804, 0.14221928428326333, 0.1253754124045372, 0.21914266874747618, 0.13364302233925887, 0.2248963335795062, 0.16831635178199836, 0.22608737966844014, 0.5880764211927141, 19.01206398010254, 93.91647965567452, 63.46704156058175, 53.82752077920096, 48.50386313029698, 106.650741985866, 109.97554533822196, 76.65485450199672, 77.82023416246686, 42.92075974600655, 24.95958822114127, 48.17926761082241, 62.799847739083425, 67.47871603284563, 48.780846118927, 2.3024402005331854, 10.41161937373025, 61.2583065032959, 52.44850833075387, 60.7891571862357, 55.0397938319615, 57.92991093226841, 54.8297324180603, 55.544663837977815, 51.66972296578543, 54.45824350629534, 55.070286001477925, 58.386275563921245, 52.54538706370762, 57.399169308798655, 54.2654379435948, 56.525332587105886, 48.57136835370745, 43.96735300336565, 42.502259322575156, 47.053412778036936, 41.7931296484811, 41.76669522694179, 46.498553957257954, 52.694693429129465, 53.941961084093364, 56.621724946158274, 53.54050806590489, 54.577648299080984, 51.880694593702046, 52.14316626957485, 53.45625768389021, 56.839526653289795, 52.94020455224173, 55.54630708694458, 52.665580477033345, 51.38964455468314, 54.94590629850115, 57.7728990146092, 54.933528082711355, 54.9497833933149, 56.623166697365896, 52.97736699240548, 39.96776144845145, 37.86198827198574, 37.82855701446533, 37.25964546203613, 29.135255813598633, 29.53085150037493, 35.812919344220845, 34.009882654462544, 36.010842255183626, 39.207131726401194, 38.99661520549229, 40.87665530613491, 40.928843225751606, 39.39802653448922, 41.402741636548726, 37.954201289585654, 39.10373905726841, 35.32955748694283, 37.942858355385916, 34.91234942844936, 35.27783162253243, 35.218942165374756, 41.65823037283761, 42.227399008614675, 41.969749382564, 43.8375814982823, 41.16166346413748, 43.57705879211426, 41.09621490750994, 41.875594343457905, 42.67826761518206, 41.46663727079119, 41.739291531699045, 40.1267466545105, 39.30994074685233, 36.80793612343924, 29.72374391555786, 15.770482676369802, 22.05332350730896, 33.89684241158621, 33.829622064317974, 35.271300315856934, 45.72716147559029, 46.96925619670323, 49.66204445702689, 51.92559732709612, 50.21387733731951, 50.23000758034842, 48.46169798714774, 50.68274177823748, 50.48308181762695, 49.59259721211025, 46.960841928209575, 50.981389250074116, 49.0594619342259, 49.17166491917202, 51.10596350261143, 50.887025765010286, 50.850512981414795, 53.373563698359895, 50.7427533694676, 51.11155680247715, 43.95789997918265, 48.48459924970354, 53.709616797310964, 50.25672687802996, 45.74418108803885, 43.58820717675345, 43.109278270176475, 50.682411738804404, 57.22584302084786, 54.55408000946045, 57.18168027060372, 57.42427315030779, 59.5439635685512, 58.33849975040981, 60.427058764866416, 57.22164978299822, 56.30814579554966, 51.903526374271934, 52.10711554118565, 48.400359289986746, 34.84823145185198, 18.717667068753922, 7.509370718683515, 0.5738280543259212, 4.113885947636195, 44.9224454334804, 60.16472257886614, 44.53944335665022, 49.9651700428554, 69.00987665993827, 27.578850643975393, 26.203433888299124, 75.37744208744594, 52.288612910679404, 64.37949984414237, 52.053173201424734, 83.6328261239188, 12.810336419514247, 0.5650842349444116, 0.23528155631252698, 0.13502461463212967, 0.2966247589460441, 0.24155966086047037, 0.15423242109162466, 0.21742456379745687, 0.17665352512683186, 0.11350223701447248], [0.0742691115343145, 0.14477487786539964, 0.039997037167527845, 0.06897021444248301, 0.06984870016042675, 0.16101416147180966, 0.13730312165405067, 0.14569913755570138, 0.07800187516425337, 0.09734205702053648, 19.79259855406625, 62.32535525730678, 47.485205105372835, 37.41457292011806, 80.4758495603289, 82.77824633462089, 87.99083355494908, 61.452300207955496, 40.89969900676182, 18.318890844072612, 30.1796430179051, 55.39143521445138, 58.98345933641706, 47.51002059664045, 9.440761481012617, 7.016519793442317, 30.640725476401194, 37.318284784044536, 44.70301784787859, 44.86953837530953, 48.94449356624058, 45.942204747881206, 48.22718586240496, 43.560223306928364, 43.15178387505667, 45.869349411555696, 47.89993960516793, 47.34305885859898, 47.961128916059224, 45.754836150578086, 44.645969663347515, 43.37503644398281, 43.798688956669395, 38.361532483782085, 37.774913447243826, 35.855657713753835, 37.4364458492824, 41.62178359712873, 45.60052360807146, 44.90391458783831, 50.30417265210833, 50.244383403233115, 50.12483617237636, 50.26137522288731, 49.47697223935808, 49.25643989018032, 51.63161209651402, 49.76135853358677, 51.06868641717093, 51.13753959110805, 52.56336900166103, 50.671607289995464, 53.539809771946494, 50.554377283368794, 48.070490087781636, 50.274653230394634, 53.281329836164204, 46.57562337602888, 33.38982193810599, 29.547669615064347, 29.003630876541138, 27.099390200206212, 22.57742612702506, 25.991647584097727, 30.33325379235404, 31.538613387516566, 32.718222958701, 30.53980984006609, 33.399611949920654, 30.876130444662913, 33.67876277651106, 34.67737177440098, 32.94650949750628, 31.437836715153285, 31.09213604245867, 28.284240450177872, 30.725236415863037, 31.991208621433803, 32.04454646791731, 32.77438177381243, 37.88792937142508, 39.365352630615234, 40.08115952355521, 39.46651840209961, 41.87100853238787, 40.498676776885986, 39.21027231216431, 39.59951734542847, 38.55354247774397, 38.26224272591727, 33.39926106589181, 27.95441814831325, 22.7841055052621, 12.25970470905304, 9.420731561524526, 25.165916715349468, 34.13869530814034, 34.406134946005686, 35.99255459649222, 40.09777614048549, 43.23821946552822, 45.81307595116751, 44.72277157647269, 43.376884664808, 43.1610631942749, 42.59489965438843, 45.87087801524571, 45.01979316983904, 43.88436024529593, 42.766144956861226, 44.83785111563546, 46.48396968841553, 45.57892860685076, 46.62878751754761, 46.95427935464041, 46.487482002803254, 46.607637201036724, 44.70744385038103, 44.94123683656965, 41.36922352654593, 42.34792593547276, 46.76597275052752, 46.23803472518921, 39.329010077885215, 34.60253620147705, 36.67708764757429, 45.27204751968384, 51.36697605678013, 50.52256843021938, 47.169409479413716, 51.01321199962071, 50.8236060823713, 51.435495717184885, 51.270670550210134, 55.13699913024902, 55.23529876981463, 54.89718900408064, 51.422606808798655, 43.75507858821324, 36.40496839795794, 28.615542718342372, 14.223079766545977, 2.8396577622209276, 5.424431281430381, 37.73552063533238, 51.613369601113455, 36.448502336229595, 53.06797497613089, 18.63850450515747, 8.125685487474714, 29.9921840940203, 53.405497619083945, 51.02024705069405, 35.30465166909354, 54.83786875861031, 28.03183671406337, 0.4406677282282284, 0.07369864000273602, 0.0382131448547755, 0.09019608582769122, 0.057720212398895195, 0.14885185552494867, 0.030263133413557495, 0.00959544868341514, 0.06883124368531363, 0.060071268385010104, 0.05271346534469298, 0.09016243727611643, 0.1244820939110858, 0.07925832524363484, 0.037966290422316105, 0.06901091297290154, 0.07833533441381794, 0.08497086406818458, 0.019170258027900542, 0.14593372068234853, 19.160982983452932, 74.81335953303746, 45.581353528159006, 32.66742467880249, 87.19320120130266, 87.5096777507237, 96.45364911215646, 68.03578090667725, 48.268951484135215, 20.99921751022339, 37.560797759464805, 58.38765825544085, 61.8256825038365, 49.60622957774571, 11.410682610103063, 9.987839187894549, 32.724212305886404, 43.22304112570626, 51.18675715582711, 52.96016672679356, 55.92058917454311, 54.62035192762102, 54.6285924911499, 49.157959597451345, 46.96518802642822, 49.69320365360805, 51.71493836811611, 51.25478349413191, 50.611932686397004, 50.25883218220302, 50.272613934108186, 49.31183440344674, 50.413512979234966, 44.65142747334072, 43.16090338570731, 40.63927704947335, 41.276135035923545, 45.30724361964634, 50.52287067685808, 47.84945746830532, 54.122398853302, 51.23155566624233, 52.43215921946934, 52.16664770671299, 51.85761267798287, 49.56798321860177, 53.58099174499512, 51.810667174203054, 53.159166608537944, 53.4244453566415, 55.2440048626491, 54.65794168199812, 54.82812738418579, 51.35380574635097, 50.29187086650303, 52.07396568570818, 53.73987967627389, 48.863015515463694, 36.94390194756644, 31.184217044285365, 31.176900591169083, 30.693472726004465, 27.546762125832693, 27.568126099450247, 31.43053068433489, 32.131728989737375, 33.698766640254426, 34.18441792896816, 37.969622816358296, 35.484950474330354, 37.06005845751081, 35.16098724092756, 35.61362416403634, 35.48215382439749, 34.76056603022984, 34.11186136518206, 35.30911936078753, 35.32452004296439, 35.275253840855186, 34.886766161237446, 40.073269844055176, 38.12224347250802, 39.395014490400044, 37.91485711506435, 41.285039152417866, 40.08207321166992, 39.58607605525425, 36.71756437846592, 40.18359681538173, 37.00468478884016, 34.53304379326956, 28.552197728838237, 24.090125390461512, 13.640085952622549, 13.735490798950195, 28.954444578715734, 34.937321254185264, 34.02968154634748, 38.14356401988438, 43.57176773888724, 47.319414138793945, 47.39011205945696, 46.084833894457134, 44.67845943995884, 45.48778561183384, 46.29909202030727, 49.608498164585654, 47.183403151375906, 46.37030063356672, 44.422175134931294, 49.20974104745047, 48.29871756689889, 47.572467531476704, 50.715686661856516, 49.642860480717246, 48.88948815209525, 49.51403393064226, 48.23070165089199, 47.62730271475655, 46.005739075796946, 46.293304170881, 52.27605404172625, 49.96260615757534, 43.147079944610596, 39.86752673557827, 40.696564946855815, 51.26156146185738, 53.82999781199864, 54.846960476466585, 52.282227516174316, 55.14577470506941, 55.04602984019688, 55.30345017569405, 55.71019424710955, 57.897344725472585, 59.879610197884695, 59.65580872126988, 57.505139759608674, 52.38003035954067, 48.58759239741734, 38.44717250551496, 20.889526299067906, 4.895919595445905, 7.876772352627345, 41.755008356911794, 55.7279086794172, 42.16466719763619, 58.74305166516985, 28.13087633677891, 15.202472652707781, 39.240979875837056, 58.98886503492083, 60.40377535138811, 38.16066353661673, 64.09014211382184, 19.356154407773698, 0.6159445600850242, 0.08397311225001301, 0.052682432545615096, 0.06242144227560077, 0.04278887289443186, 0.005945254283558045, 0.06890533970935003, 0.03565523407555052, 0.06049646556909595, 0.03671766724437475, 0.14210782812110015, 0.14779131886150154, 0.1955646625054734, 0.16199820009725435, 0.16032312783811772, 0.24511312161173138, 0.20716596926961625, 0.22117094562522002, 0.17994364643735544, 0.2088655230722257, 28.01069334575108, 93.22317450387138, 63.170944077628, 56.774988310677664, 90.34996237073625, 89.237548828125, 92.08288478851318, 75.70575836726597, 56.31364529473441, 26.829494374138967, 41.164460114070344, 64.12965651920864, 65.16037314278739, 55.98062855856759, 11.513139878000532, 9.887396029063634, 43.162480626787456, 51.2318822315761, 56.03799983433315, 57.16421944754464, 60.711761202131, 56.46761737551008, 57.883469172886436, 51.547264439719065, 52.22066995075771, 52.493449279240195, 57.08954020908901, 52.62402677536011, 53.00510420118059, 53.741835594177246, 50.31380980355399, 52.03124468667166, 52.20704800742013, 46.63456494467599, 45.4390092577253, 42.367707456861226, 43.381661551339285, 48.09946755000523, 51.82418836866106, 52.08033718381609, 57.82321092060634, 55.84124769483294, 56.121190616062705, 54.67174775259835, 51.552486010960166, 50.058147362300325, 55.58999735968453, 53.88035140718733, 55.07469810758318, 53.669675077710835, 57.585620743887766, 54.31241818836757, 55.16394077028547, 53.68256746019636, 50.983633518218994, 55.57801866531372, 56.19512987136841, 51.4598456791469, 39.947660309927805, 35.27107449940273, 33.67215851375035, 34.94572162628174, 30.576569284711564, 30.773505551474436, 32.60751036235264, 32.69744437081473, 35.546924931662424, 35.29534108298165, 39.22398458208357, 37.80603442873274, 41.35557379041399, 40.80584274019514, 38.07958500725882, 39.45651299612862, 39.18182291303362, 37.010733195713584, 38.42264883858817, 39.50176313945225, 37.20650911331177, 37.74132932935442, 43.62062052318028, 42.86632061004639, 41.758722169058665, 39.498233454568044, 44.57758896691458, 43.696345465523855, 42.57271753038679, 42.32407624380929, 42.504857948848176, 42.77506644385201, 39.30977399008614, 33.79170574460711, 27.43202131135123, 16.55510105405535, 15.343335219791957, 30.277431964874268, 37.307918071746826, 36.50317423684256, 40.04902063097273, 45.62136820384434, 48.60002967289516, 49.53146348680769, 48.078327655792236, 48.57925108500889, 48.556513105119976, 48.348925249917166, 50.987552302224294, 50.31564065388271, 48.26917035239083, 48.107114042554585, 52.566023213522776, 51.9827184677124, 50.99424689156668, 52.15183067321777, 51.58462142944336, 50.6019411768232, 52.41098805836269, 49.690598079136436, 50.0673120362418, 47.90644659314837, 50.13503960200718, 54.38727460588728, 53.36229024614607, 47.20180892944336, 42.95911727632795, 44.26201568331037, 54.22932815551758, 57.87632989883423, 58.52543408530099, 54.70979956218174, 58.31195763179234, 57.15433216094971, 58.58473001207624, 58.94765526907784, 63.4573974609375, 63.98067324502127, 62.01587554386684, 59.69977692195347, 53.7108917917524, 48.27943284170968, 37.071387495313374, 19.302503892353602, 3.96704923255103, 8.671238933290754, 45.89781270708357, 62.306998116629465, 50.25941583088466, 64.64065483638218, 25.94834988457816, 12.863320776394435, 46.89568172182356, 64.83005578177315, 66.49551119123186, 53.39282063075474, 75.74382059914726, 35.14624663761684, 0.6559303573199681, 0.29831718813095776, 0.15995593182742596, 0.15636671228068216, 0.13891160248645715, 0.18440565200788633, 0.1241965392338378, 0.14208117526556763, 0.17713151233536856, 0.11391127827976431], [0.04932791826182178, 0.07448709769440548, 0.046999440528452396, 0.030404289053486924, 0.1564260298120124, 0.04149335616135171, 0.04843763281990375, 0.09536724870226213, 0.06937457381614617, 0.09261081553995609, 0.017986643593758345, 14.982914788382393, 57.45647457667759, 41.213743686676025, 50.19146939686367, 86.59940814971924, 97.19680758884975, 63.15670027051653, 38.45178263528006, 21.08423219408308, 26.28499010631016, 48.57161154065813, 56.948404925210134, 46.20555189677647, 14.21155617918287, 13.154527596064977, 17.06697310720171, 30.370676789964946, 42.33130237034389, 47.41157504490444, 48.85538639341082, 51.70796585083008, 51.271844795772004, 49.68594626017979, 45.74003301348005, 42.27285759789603, 44.15583678654262, 46.12610271998814, 47.50510474613735, 47.44425937107631, 48.36391946247646, 46.666113240378245, 45.72639717374529, 44.30189139502389, 39.85178559167044, 38.0539357321603, 37.61295788628714, 40.377149309430806, 44.11902175630842, 46.429283891405376, 45.39319978441511, 47.80623619897025, 46.04088306427002, 45.0620243208749, 46.65645177023751, 46.28616489682879, 50.359445571899414, 49.89474310193743, 50.62121547971453, 51.402814865112305, 53.1856427192688, 53.98616204942976, 51.39048876081194, 48.21422399793352, 49.03281559262957, 51.0112942968096, 50.19289377757481, 48.160305976867676, 39.331539222172324, 30.06675910949707, 28.545463187353953, 26.531062296458654, 24.13398241996765, 23.26776613507952, 27.45570945739746, 30.69862481525966, 30.387817995888845, 32.88203021458217, 32.91612155096871, 31.060490471976145, 31.34304244177682, 31.04514537538801, 30.227926049913677, 30.713629450116837, 27.033102648598806, 25.344992637634277, 31.23702335357666, 33.69816909517561, 35.4498724937439, 35.30252204622541, 39.99818066188267, 40.29762717655727, 43.3763427053179, 44.40406118120466, 42.49201767785208, 41.55758571624756, 40.85777357646397, 41.30535568509783, 35.59844929831368, 32.544604846409385, 24.805068969726562, 22.04904167992728, 17.959875685828074, 14.136745793478829, 20.145478452954972, 31.667384352002824, 34.87129947117397, 34.09642941611153, 37.307574135916575, 44.893287318093435, 46.28785330908639, 43.866572856903076, 42.26301200049264, 42.84312057495117, 41.80558429445539, 46.107790742601665, 46.7031158719744, 43.89410509381975, 43.09745591027396, 43.87644624710083, 46.027090890066965, 43.59996005467006, 47.18849965504238, 45.62460259028843, 46.33447224753243, 46.643430846078054, 47.48835263933454, 43.8421117237636, 42.80472482953753, 41.177897930145264, 45.14427014759609, 46.74403728757586, 44.88848958696638, 37.03073705945696, 35.8873484475272, 40.536791120256694, 48.8583984375, 51.10365670067923, 53.00866515295846, 51.51265198843819, 53.49198532104492, 51.493659087589805, 52.54007169178554, 53.79406520298549, 53.65715789794922, 54.79667983736311, 55.16264493124825, 51.52737522125244, 53.11423608234951, 52.26680598940168, 43.73665543964931, 27.260428598948888, 9.916441236223493, 7.21231655563627, 41.98292316709246, 46.91731146403721, 40.17706898280552, 38.388220514569966, 16.557050023760112, 19.096790313720703, 32.2489207812718, 56.614721161978586, 48.55889981133597, 29.321696826389857, 61.353607995169504, 6.770930068833487, 0.49481449701956337, 0.09233913690383945, 0.16242114454507828, 0.07126647872584206, 0.02310714534749942, 0.030171032462801253, 0.009567130024411848, 0.157701078536255, 0.04886106242026601, 0.03750365846125143, 0.018169739483190433, 0.07339755365891115, 0.04861002481941666, 0.04884391584034477, 0.038333516967083724, 0.06505952535995416, 0.07318691603307213, 0.04616956505924463, 0.11506637558341026, 0.016358687109979134, 0.03733591103394117, 15.858233213424683, 67.6694301877703, 37.927732127053396, 55.624654974256245, 94.64455359322685, 102.84365722111293, 69.69796371459961, 47.71575675691877, 26.841064861842565, 31.298938751220703, 55.75475304467337, 58.57939379555838, 49.67276552745274, 17.700318779264176, 17.771239042282104, 25.18396118709019, 41.0276882989066, 52.071610246385845, 53.29369068145752, 54.00135775974819, 57.84978430611746, 54.90314013617379, 57.20850031716483, 52.36061361857823, 46.659439495631624, 48.07193183898926, 51.023929595947266, 52.497687680380686, 51.89874253954206, 52.213753019060405, 51.32090950012207, 49.58201857975551, 48.05462040219988, 46.190918990543906, 41.413691997528076, 39.62159872055054, 43.61126477377755, 46.882445403507774, 49.62371819359915, 49.23165219170706, 49.120845794677734, 48.732173987797324, 49.04128197261265, 48.00858858653477, 48.731444426945274, 51.79988356998989, 53.53134339196341, 52.01911660603115, 54.2298492704119, 55.59205750056675, 53.60735321044922, 53.55082266671317, 52.94575268881661, 51.58285311290196, 51.967241355351035, 51.37119708742414, 50.929944787706646, 42.46823399407523, 34.42729915891375, 30.519899777003697, 29.35349873134068, 27.626068864549907, 25.50739983149937, 29.425888538360596, 32.60690934317452, 35.11832182747977, 36.70330320085798, 33.11604554312569, 33.57933752877371, 34.819260937826975, 34.383598463875906, 34.51313025610787, 33.582168919699534, 26.9222024508885, 25.202643156051636, 33.85743917737688, 34.97701631273542, 36.56899799619402, 37.77544845853533, 41.992438725062776, 40.81199189594814, 43.96928112847464, 45.01854944229126, 39.513582025255474, 38.00615644454956, 38.29871382032122, 39.74937261853899, 33.190224511282786, 33.03884410858154, 25.04119655064174, 21.655049289975846, 17.345196349280222, 19.468305281230382, 26.7900425025395, 35.648952279772075, 34.82367304393223, 35.08357388632638, 41.32902472359793, 45.20025525774275, 46.547886167253765, 45.002655438014436, 44.47141007014683, 45.37563821247646, 45.307733467647004, 50.21682684762137, 49.54295580727713, 48.71680109841483, 45.55936942781721, 47.823009150368826, 48.358760425022666, 46.64455298015049, 49.634661606379915, 48.44035659517561, 50.29905182974679, 49.68616165433611, 52.408462388174875, 46.62372922897339, 44.76436001913888, 44.32195084435599, 49.77983379364014, 51.18886940819876, 49.61556100845337, 40.95465578351702, 39.9968535559518, 43.98172535215105, 53.33156878607613, 53.727265221732004, 57.5207245690482, 54.78135905947004, 55.38805838993618, 53.481406688690186, 57.124927384512766, 58.48464815957205, 58.974808829171316, 57.303023610796245, 59.3887825012207, 56.180694988795686, 58.633471625191824, 57.28489228657314, 50.552428313664024, 32.672410011291504, 12.85855257511139, 10.049315980502538, 46.3753137588501, 52.30322844641549, 45.243420941489084, 46.1879312651498, 22.325192621776036, 23.640330280576432, 37.811134406498496, 64.66150638035366, 52.27219779150826, 31.568563597542898, 67.09124973842076, 6.045169012887137, 0.4113590323499271, 0.08498644323221274, 0.04248266021854111, 0.08073129584746701, 0.041882390821618695, 0.08343323586242539, 0.035270036530814, 0.09010525034474474, 0.02635480054388089, 0.10930171848407813, 0.2983359156974724, 0.14620129418160233, 0.1524664115692888, 0.11146872863173485, 0.1936147699930838, 0.14656025277716772, 0.14971052802034787, 0.12803710172218935, 0.22340089668120655, 0.10303281487098762, 0.15258605086377688, 32.45510162625994, 81.99531636919293, 57.74128123692104, 63.476567540849956, 90.09216335841587, 100.8990787778582, 74.57479313441685, 52.80799075535366, 30.326514039720806, 36.4999919618879, 59.40294292994908, 65.69588470458984, 55.19431482042585, 18.10102139200483, 19.370462485722133, 29.905404567718506, 48.95005559921265, 57.648998737335205, 58.25710507801601, 58.418140002659385, 61.88126809256417, 59.354201316833496, 57.24470738002232, 53.4825496673584, 50.39387042181832, 51.04852621895926, 53.0284640448434, 55.48114340645926, 53.85903433391026, 54.794036047799246, 52.93411098207746, 52.8200215612139, 49.572176456451416, 46.77983093261719, 43.05701044627598, 42.80076435634068, 46.208730697631836, 50.37887273515974, 51.26392732347761, 49.64933967590332, 52.127518926348, 52.3627849306379, 52.2399685723441, 50.315036160605295, 49.53130367824009, 53.849873134068076, 53.43656301498413, 53.4712484223502, 53.528088160923545, 57.251811913081575, 54.47308138438633, 54.44018861225673, 51.29849113736834, 52.762375831604004, 55.38483442578997, 52.17696578162057, 51.73800638743809, 44.530928339277, 39.07432038443429, 33.987457343510215, 32.75136586597988, 31.6179826600211, 29.879588535853795, 31.536799907684326, 34.20282023293631, 33.78651196616036, 37.22596059526716, 37.789223262241904, 35.45814085006714, 38.881309849875315, 38.05905655452183, 36.896959917885916, 36.036929266793386, 33.69141544614519, 34.53134148461478, 36.94734477996826, 36.51017107282366, 39.67699670791626, 37.03083780833653, 43.164606775556294, 44.13514157703945, 45.568103313446045, 47.18391384397234, 43.860868385859895, 40.342040061950684, 42.20942749295916, 40.814191000802175, 37.29136398860386, 35.917760712759836, 29.948393072400773, 25.75442566190447, 22.625016076224192, 18.74603135245187, 26.413641214370728, 37.639211654663086, 37.82983200890677, 37.94653047834124, 43.3575165612357, 50.11028664452689, 49.73695993423462, 49.56625311715262, 47.439020429338726, 48.533094201769146, 48.121013913835796, 52.77834626606533, 53.45438167027065, 51.29317576544625, 48.53503622327532, 50.10889005661011, 50.804866790771484, 48.37675278527396, 53.520021302359446, 51.87742894036429, 51.85448598861694, 51.832355976104736, 54.449999468667166, 48.55284098216465, 46.34676013674055, 45.85944822856358, 53.28711073739188, 54.53569507598877, 53.39400182451521, 44.38108696256365, 42.344201701028005, 46.727417196546284, 57.26113639559065, 57.3640843800136, 59.625827244349885, 57.77107858657837, 60.54396915435791, 57.80316884177071, 58.70462812696184, 60.665722438267295, 61.905086517333984, 61.921817779541016, 63.631366457257954, 60.63500445229666, 64.5715480531965, 63.63575771876744, 53.283886773245676, 33.19108261380877, 13.595693043300084, 10.748865825789315, 51.08164480754307, 55.900269167763845, 52.49521064758301, 47.387569018772666, 23.271002258573258, 26.51012216295515, 51.425031730106895, 68.77224826812744, 62.574517658778596, 43.47033098765782, 78.25756072998047, 9.333001000540596, 0.5043441142354692, 0.21763771878821508, 0.2414815207677228, 0.17162995040416718, 0.12708023163889134, 0.2859669551253319, 0.11261431287441935, 0.32021698728203773, 0.08769647816994361, 0.23320051655173302], [0.10996314763490643, 0.04423059017530509, 0.07520650766257729, 0.21823454461991787, 0.1879126059689692, 0.15841583375419888, 0.12574382977826254, 0.06723653711378574, 0.05618185137531587, 0.11283457212682281, 0.1567185733999525, 0.14117052698773996, 20.456424236297607, 48.971407413482666, 32.73325538635254, 73.57596179417202, 108.45288235800606, 60.62570776258196, 34.64664684023176, 31.81644753047398, 24.76561883517674, 46.855601038251606, 56.672557967049734, 48.523394516536165, 22.92462934766497, 20.52555533817836, 27.194085461752756, 40.088309219905305, 48.85832895551409, 52.52901015962873, 51.03031151635306, 52.23760271072388, 51.279984610421316, 53.33257974897112, 52.100757939474924, 46.31467335564749, 41.146009172712056, 46.23002345221383, 46.459314005715505, 48.489084311894004, 47.754972389766145, 46.404176575796946, 43.424212319510325, 42.39299195153372, 39.553294454302105, 39.72020755495344, 37.73612860270909, 39.57858937127249, 41.20220272881644, 43.2548326083592, 46.762967654636924, 44.39594915934971, 45.25156075613839, 40.32514899117606, 42.08898394448416, 48.659019878932405, 45.68938411985125, 52.59205116544451, 50.89865010125296, 51.893083231789724, 51.93184723172869, 54.15773739133562, 51.81538152694702, 53.900594983782085, 49.68034601211548, 49.07368837084089, 49.18860115323748, 50.72936071668352, 45.726195675986155, 34.373169217790874, 27.506464311054774, 27.877404315131052, 25.40047574043274, 22.844374179840088, 24.00979205540248, 28.244807686124528, 33.82877090999058, 34.312963077000205, 29.71722650527954, 31.507454190935405, 29.947441169193812, 32.57607671192714, 32.48660475867135, 29.524580751146587, 13.588838645390101, 16.3947331564767, 35.140177386147634, 35.73062488010952, 39.006756101335796, 45.26102767671858, 46.99059064047677, 42.262223379952566, 38.63480860846383, 37.87939698355538, 42.81723506110055, 39.454157556806294, 36.01921483448574, 36.34129858016968, 35.398170948028564, 26.978312628609793, 19.139111791338237, 12.605094449860708, 14.635947806494576, 25.987998042787822, 37.444168772016255, 35.942961829049246, 31.479404313223704, 35.31879472732544, 42.95059183665684, 45.088424001421245, 44.91895743778774, 40.716801575251985, 40.764883109501426, 41.109975814819336, 42.695252486637656, 45.73725373404366, 48.33235379627773, 47.27616855076381, 44.25530024937221, 45.45821755273001, 45.002158641815186, 46.17313855034964, 44.53036553519112, 46.07948725564139, 46.00127138410296, 47.15506492342268, 46.76053578513009, 45.228972162519185, 44.03725535529, 44.010737555367605, 45.027137415749685, 46.840283734457834, 41.60261699131557, 35.45395803451538, 38.79704557146345, 41.27936247416905, 50.67763485227312, 53.37516525813511, 55.04134675434658, 48.47370100021362, 49.116840158190044, 48.917836802346365, 53.491637911115376, 54.45418228421892, 56.163209847041536, 52.94043731689453, 56.135760988507954, 53.73730189459664, 53.900904178619385, 53.387421880449565, 49.84369816098894, 34.100303036826, 16.173585891723633, 10.870301229613167, 45.58175304957798, 43.33037689753941, 43.24549075535366, 26.802516256059917, 20.979929310934885, 32.39722660609654, 34.46267591203962, 57.529451506478445, 46.560201849256245, 35.64173310143607, 58.17532478060041, 4.1553749442100525, 0.4176883255796773, 0.017247082831870233, 0.03644441779968994, 0.12259331026247569, 0.10091596881725959, 0.08197429057742868, 0.07211923439587865, 0.10853464143084628, 0.0365214993778084, 0.09812390578112432, 0.07961100060492754, 0.015098355810291, 0.07863931131682225, 0.20611817549381936, 0.09100274861391101, 0.07297634626073496, 0.06821442821196147, 0.12341315698410783, 0.05234229311879192, 0.05364814054753099, 0.1418742085141795, 0.11292692752821104, 23.90561076572963, 58.27218961715698, 35.38741166251046, 85.23055744171143, 113.16658891950334, 69.82628999437604, 43.63258532115391, 37.62755605152675, 29.587969166891916, 51.33101565497262, 60.89615944453648, 55.877621514456614, 26.20567294529506, 25.070139271872385, 35.96752718516758, 53.04875973292759, 55.296557562691824, 59.29357133592878, 55.294382776532856, 56.79190370014736, 55.815056460244314, 56.9021646635873, 57.26556239809309, 49.4635135786874, 43.57558577401297, 47.867470673152376, 49.068501540592735, 52.923709528786794, 49.989134379795615, 50.97223152433123, 48.12428304127285, 47.18397985185896, 43.51568535396031, 44.49968923841204, 41.007312706538606, 43.46692289624895, 42.77039725439889, 44.33991541181292, 47.758703572409495, 46.88724660873413, 45.814757415226524, 40.762027399880544, 45.95580584662301, 51.82055446079799, 48.953765937260215, 54.54377235685076, 53.03498492922102, 54.58079235894339, 56.27075406483242, 56.034497942243306, 54.757273129054475, 53.835302761622835, 51.62610912322998, 49.60512828826904, 50.717305592128206, 51.806216853005544, 48.421203885759624, 38.692954608372276, 30.290689127785818, 28.762118441717966, 30.16056673867362, 27.11657656942095, 27.097321374075754, 29.559641361236572, 33.29868589128767, 35.87570674078805, 30.262729576655797, 33.392726285117014, 33.593188762664795, 36.52851431710379, 36.144424847194124, 32.06275074822562, 14.250645875930786, 23.110663890838623, 40.8985664503915, 37.28717075075422, 40.6323219026838, 45.07346452985491, 45.6175571169172, 42.4512699672154, 37.10443312781197, 35.65820728029524, 41.09955351693289, 41.671379838671, 39.49497127532959, 36.295166015625, 35.21285901750837, 28.984471218926565, 16.59857072149004, 13.837698800223214, 20.73891888345991, 29.6031231880188, 38.26785339627947, 36.25976146970476, 33.94782829284668, 40.20730059487479, 46.80464989798409, 49.217693260737825, 47.01090022495815, 42.862992422921316, 41.64037697655814, 43.18571192877633, 45.152757372174946, 48.04785633087158, 51.3943623815264, 50.81140851974487, 46.38651425497872, 47.25135653359549, 48.68482548849923, 49.115169116428916, 46.61616611480713, 47.965158871241975, 48.13334696633475, 47.99359437397548, 48.22793279375349, 47.9598365511213, 46.19781507764544, 48.785984311785015, 48.668754305158345, 50.71077081135341, 43.43224096298218, 39.956449781145366, 42.18172155107771, 44.433184555598665, 54.463847228458945, 56.381431920187815, 56.572545596531455, 52.36275713784354, 52.82277304785592, 52.438033921378, 55.964824880872456, 54.92927925927298, 57.6669910975865, 56.80909006936209, 62.37158857073103, 59.61237553187779, 59.822996275765554, 57.99717991692679, 59.1766539982387, 39.15141759599958, 18.864011764526367, 14.372053486960274, 50.10317516326904, 47.369757311684744, 51.061710425785606, 33.043405600956504, 24.882416316441127, 32.771154335566926, 39.44437101909092, 63.7891183580671, 45.18150554384504, 36.11758048193795, 62.76500252314976, 3.869473074163709, 0.29747892596891945, 0.06900741851755551, 0.03967512997665575, 0.018578346486070325, 0.07469198134328638, 0.03535306207569582, 0.02053680380673281, 0.11437971171523843, 0.03807788568415812, 0.14098386200410978, 0.11191430900778089, 0.08857285364397935, 0.16703428700566292, 0.3070363902619907, 0.16023874522319861, 0.27984971765960964, 0.2440823997770037, 0.19892688494707855, 0.13665073737502098, 0.2211239638605288, 0.1831928656569549, 0.2192917021789721, 45.9385986328125, 71.2173957824707, 48.69851343972342, 83.30182783944267, 112.70260211399624, 75.20386913844517, 45.670551027570454, 37.8012193271092, 34.07689108167376, 54.4032415662493, 65.37197358267647, 58.37556838989258, 27.70460261617388, 23.354128769465856, 39.6452225957598, 56.526611055646626, 59.93023477281843, 61.65110206604004, 58.97449616023472, 59.00003773825509, 58.70561477116176, 59.47746235983712, 58.35153457096645, 51.9325281551906, 48.05679866245815, 53.00814403806414, 52.55753598894392, 54.414299624306814, 54.16952153614589, 53.84378998620169, 50.752369676317485, 50.49563026428223, 44.97380999156407, 45.967722007206504, 42.94389724731445, 45.106440680367605, 45.30288362503052, 47.390577588762554, 49.52625233786446, 49.87969330378941, 48.725357804979595, 41.57531751905169, 44.9020003591265, 53.20856830051967, 48.1911837714059, 55.80439097540719, 54.940792424338206, 57.52992398398263, 58.367452893938335, 59.224686895098, 55.62054164069039, 56.50884451184954, 53.95187268938337, 53.718576499394004, 53.038531984601704, 52.13696500233242, 50.23027856009347, 39.361715248652864, 31.9813734463283, 33.100752558027, 31.161795207432338, 29.44970348903111, 28.901907512119838, 33.270813192640034, 35.84895270211356, 36.270121233803884, 31.609714303697857, 33.74207476207188, 35.17630107062203, 38.24947541100638, 37.21663958685738, 34.76452650342669, 17.467915432793752, 28.183215379714966, 44.50567511149815, 36.35344750540597, 38.1646066393171, 44.508947713034495, 48.09118529728481, 43.16442264829363, 38.754130022866384, 39.192787170410156, 43.75369937079293, 48.111984729766846, 44.730692522866384, 43.67205456324986, 38.131484576633994, 34.84819323675973, 22.76646055494036, 19.207713093076432, 23.247454813548497, 30.003471442631312, 41.43174689156668, 38.53943763460432, 35.5006742477417, 42.117874554225374, 51.58754662105015, 49.87581273487636, 48.255986145564485, 44.93911068780081, 44.025273186819895, 45.09077944074358, 47.513915061950684, 50.65184661320278, 54.63632583618164, 52.76317140034267, 48.98615843909127, 50.55779927117484, 51.10316685267857, 51.57412270137242, 50.502755641937256, 51.57730845042637, 51.27511044910976, 51.9635796546936, 51.38328695297241, 49.84969098227364, 48.49963515145438, 50.476161411830354, 50.91874776567732, 53.37652015686035, 48.883672509874614, 42.55322435923985, 45.80706228528704, 49.45981713703701, 58.226425307137625, 60.52556337629046, 60.28746945517403, 53.18030650275094, 55.22092294692993, 55.72685950142996, 60.43275628771101, 60.29916327340262, 63.03200095040457, 59.59669344765799, 66.9954479762486, 64.85788331712995, 64.24687262943813, 63.6745217187064, 61.86227171761649, 42.53108392442976, 20.870901652744838, 16.59072620528085, 52.77930164337158, 51.96655695778983, 56.70565223693848, 35.752873011997764, 31.289534364427837, 44.09923676082066, 54.27199009486607, 68.45672362191337, 65.21376310076032, 48.33896500723702, 72.92116355895996, 5.726707884243556, 0.6697746430124555, 0.24321992748550006, 0.1275673247873783, 0.31173285682286533, 0.27850247280938284, 0.22161393399749482, 0.10408666796450104, 0.12328946005020823, 0.16656145666326794, 0.3252142077045781], [0.048950992058962584, 0.1278893303658281, 0.2220403661153146, 0.42678566170590265, 0.03522427612915635, 0.09236270242503711, 0.2790963537991047, 0.015489989259679402, 0.2968894690275192, 0.33761074393987656, 0.5799072938305991, 0.21154222158449038, 1.028463453054428, 52.155655656542095, 35.097928864615305, 44.97679424285889, 24.77298218863351, 46.70336600712368, 34.789984703063965, 26.247737339564733, 27.91812423297337, 32.699730328151155, 52.971346378326416, 51.16656916482108, 28.264893191201345, 29.442397458212717, 43.13307932444981, 56.43607602800642, 59.34427234104702, 51.57642602920532, 52.94713885443551, 51.89108909879412, 52.60677787235805, 55.74509852273123, 56.226296016148154, 40.50521503176008, 37.972690446036204, 41.55298948287964, 44.11756610870361, 45.40996578761509, 45.82768453870501, 44.38785798209054, 43.07619094848633, 38.75340046201433, 37.12506927762713, 36.992966651916504, 37.54170758383614, 36.26200226375035, 35.186740739004954, 36.61029461451939, 42.85745470864432, 45.97845349993025, 46.83798735482352, 47.473125662122456, 51.94786630358015, 48.59751442500523, 48.8329576083592, 52.447667598724365, 50.73717049189976, 54.03495577403477, 54.660932881491526, 52.785923276628765, 50.30215072631836, 50.03708389827183, 46.98971864155361, 46.285004547664094, 45.646652698516846, 49.03843668528965, 45.282257897513254, 36.85647971289498, 30.763395922524587, 24.9540696144104, 28.461867673056467, 26.93188997677394, 21.191411631447927, 21.746148858751567, 22.607798440115793, 30.014883858816965, 28.477224928992136, 27.59428433009556, 28.34217974117824, 31.00130919047764, 28.850216388702393, 29.786072731018066, 22.280201298849924, 39.41242320196969, 54.82917308807373, 48.26016896111624, 50.1232693535941, 55.26827144622803, 52.735072885240825, 47.97171449661255, 36.51529884338379, 29.02696987560817, 27.320370708193096, 19.028492995670863, 18.057391916002544, 20.925337314605713, 27.924011094229563, 22.34346638407026, 11.319784539086477, 10.93356110368456, 22.158670357295446, 33.48026316506522, 34.71830013820103, 32.43977042606899, 34.820640155247276, 39.77684579576765, 43.786025864737375, 48.85381957462856, 46.05931316103254, 38.58398253577096, 37.613135065351216, 42.24297339575631, 44.00571748188564, 44.37124831335885, 48.51447302954537, 46.87650121961321, 44.2208753994533, 45.05085161754063, 47.088390009743826, 41.39415366309029, 44.18937226704189, 44.35397161756243, 45.256052766527446, 44.18690913064139, 42.838534763881135, 43.589034012385774, 45.57049349376133, 42.48789739608765, 45.19495030811855, 43.741560867854524, 36.13496140071324, 37.20227418627058, 38.118741580418174, 41.196387086595806, 51.01319462912423, 53.12777812140328, 54.2384546143668, 50.341206550598145, 49.517706053597585, 48.12957409449986, 50.565584727696006, 48.87934725625174, 48.102635928562705, 49.183633191244944, 55.06910480771746, 54.32858664648873, 55.51905972617013, 55.170829909188406, 56.24360050473894, 40.544930934906006, 15.540274960654122, 15.014211211885724, 44.93831511906215, 45.04139511925833, 38.77254274913243, 21.74583271571568, 24.736754281180247, 30.826138155800955, 38.82684639522007, 51.06767545427595, 71.7389692578997, 46.96413190024239, 51.806328024183, 2.230062118598393, 0.17007606449936116, 0.06817374325224332, 0.18221572094729968, 0.11265052628836461, 0.27043469143765314, 0.10198455969137804, 0.032513009650366645, 0.10374247429094144, 0.08013126054512602, 0.06444046393569026, 0.03390552296436258, 0.24925001391342708, 0.42297262059790747, 0.7005498430558613, 0.048310916405171156, 0.008102650438169283, 0.13341989288372652, 0.06877546132143054, 0.1007549592426845, 0.4720475843974522, 0.4842782052499907, 0.34716780111193657, 0.5711135342717171, 59.13028866904122, 39.400392396109446, 52.744418212345664, 39.10644885471889, 55.594135011945454, 40.90571962084089, 31.020656449454172, 32.932394232068745, 37.47196156638009, 58.55841023581368, 54.83900826317923, 32.36899954932076, 29.780541964939662, 46.17073794773647, 61.07162925175258, 64.25923347473145, 55.51596777779715, 56.61150414603097, 53.85913855688912, 56.2938220841544, 61.34044115883963, 58.318968364170615, 43.45870665141514, 42.759412152426584, 43.68335580825806, 43.23983492170061, 46.49712610244751, 47.85969911302839, 44.55475371224539, 45.41775124413626, 41.08414936065674, 40.519538743155344, 39.97627646582467, 40.40683896200997, 38.73203475134713, 35.94820424488613, 38.48348726545061, 43.807693822043284, 44.74987997327532, 47.247521127973286, 51.56633029665266, 52.804540974753245, 49.04614918572562, 50.469258376530235, 52.7919716835022, 53.80184718540737, 57.02625601632254, 57.75277355739048, 54.83694812229702, 52.11859743935721, 51.489208766392295, 51.54685797010149, 49.649291038513184, 48.50344623838152, 50.29648099626814, 47.5024470601763, 40.06486252376011, 35.77600703920637, 27.692768096923828, 29.40684700012207, 29.809078216552734, 25.22064593860081, 24.15501114300319, 24.110238688332693, 32.956702504839214, 32.485600743974956, 30.24990667615618, 29.29181957244873, 35.20370823996407, 32.50421149390084, 33.49506630216326, 41.34608949933733, 68.22855172838483, 66.63457938602993, 49.35147040230887, 53.584292139325825, 54.39669288907732, 53.81093890326363, 49.51905747822353, 37.57380826132638, 34.011192389896934, 34.70279523304531, 30.34782416479928, 24.719647816249303, 29.62394346509661, 30.205115113939556, 29.85462713241577, 18.33848476409912, 17.5087308883667, 24.7649952343532, 32.095341273716514, 33.002289635794504, 34.220548561641145, 36.403088910239084, 45.96890320096697, 49.015729972294395, 51.03884737832205, 45.718160084315706, 41.233167375837056, 41.80332612991333, 47.78712865284511, 49.138296195438926, 49.575494221278596, 51.076829705919536, 49.631086758204866, 48.55743374143328, 50.36656747545515, 48.316570963178364, 45.14672633579799, 47.48174837657383, 48.2622013092041, 47.71185186931065, 46.38725771222796, 45.77201557159424, 46.822555405753, 46.58101865223476, 44.0630852835519, 46.89396899087088, 44.96006645475115, 39.01645231246948, 41.63501991544451, 41.92494739804949, 44.28049789156233, 53.52959244591849, 56.61553062711443, 58.8086496080671, 52.13739579064505, 52.67939349583217, 50.063181332179475, 53.46031195776803, 54.20811530521938, 53.07300199781145, 52.06260190691267, 58.66266795567104, 58.3743177141462, 61.77897671290806, 59.292091369628906, 60.432700702122276, 44.02199363708496, 16.703432934624807, 19.596089601516724, 49.277840341840474, 49.31868880135672, 44.022108282361714, 24.37582663127354, 30.01000622340611, 30.541981152125768, 43.145457540239605, 58.880181312561035, 85.25173555101667, 50.075007166181294, 59.42097350529262, 2.5363673738070895, 0.07396455787654434, 0.01919993375694113, 0.07086633983999491, 0.05326645102884088, 0.03492104900734765, 0.08084447548857757, 0.017240699513682296, 0.060105527618101666, 0.15225191307919367, 0.05449839581602386, 0.13309585170022079, 0.23348631550158772, 0.4546858003096921, 1.1014225780963898, 0.11825306101569108, 0.19911196215876512, 0.5514309704303741, 0.2153305775885071, 0.25726440814988955, 0.49430244735309053, 0.6723822802305222, 0.6257302292755672, 3.5144396679741994, 79.95527662549699, 47.086993421827046, 59.35363851274763, 33.419994490487234, 61.10818372453962, 41.91385112489973, 31.91538987840925, 35.430473123277935, 42.077126843588694, 61.52416542598179, 57.290711402893066, 33.66239629473005, 33.06828015191214, 47.742410046713694, 64.37223202841622, 68.8918684550694, 60.76241356985909, 61.43185860770089, 58.14976235798427, 57.975011689322336, 62.82165118626186, 62.06022589547293, 45.02526487622942, 44.05926724842617, 47.24593693869454, 45.931528840746196, 50.57416922705514, 50.498826435634065, 48.20423248835972, 47.01928322655814, 44.70092644010271, 40.87039845330374, 40.87615850993565, 42.57204008102417, 41.78440618515015, 38.34053155354091, 40.11981235231672, 45.05673326764788, 45.291742188589915, 48.70198059082031, 51.37944459915161, 55.23344360079084, 50.42380673544747, 49.36394936697823, 55.88583428519112, 55.31975064958845, 59.26215853009905, 58.953790528433665, 59.39370877402169, 56.247581822531565, 56.47116790499006, 54.84350027356829, 52.277954374040874, 50.473871980394634, 53.107663086482454, 46.88856329236712, 42.02288225718907, 36.10904114586966, 29.611728531973704, 29.38151386805943, 28.60515342439924, 27.885234934943064, 30.26324721745082, 27.23813530376979, 32.84633037022182, 29.966837065560476, 31.076638085501536, 30.0844909123012, 36.558787618364605, 34.89319324493408, 37.59535115105765, 33.15887771333967, 62.2069023677281, 64.75136048453194, 50.75754608426775, 50.79172427313668, 52.354266439165386, 52.63559552601406, 52.6395559992109, 40.99856145041329, 37.031160899571006, 42.172911235264365, 37.60800382069179, 31.956054210662842, 37.20868737357003, 36.93945510046822, 37.9787596975054, 24.064328466142925, 20.001965148108347, 28.781168665204728, 36.21961825234549, 35.76908663340977, 37.92769391196114, 38.29599360057286, 49.42503445489066, 53.04733187811715, 56.753765038081575, 49.35587556021554, 44.306077684674946, 42.58074269975935, 50.31639800752912, 50.95643826893398, 48.77928624834333, 55.1473172051566, 53.13740832465035, 50.96069404057094, 51.70010396412441, 51.95168086460659, 47.46616356713431, 50.37414448601859, 51.013990197862896, 50.05019167491368, 49.36855602264404, 47.21037605830601, 49.31578098024641, 48.57512385504586, 44.55833550861904, 49.319036211286274, 49.71965544564383, 42.54723153795515, 44.02194847379412, 45.70395449229649, 46.33628920146397, 57.238189969744, 60.385529381888254, 62.202260971069336, 54.93020684378487, 55.46939747674124, 51.34711810520717, 56.48891360419137, 57.67781291689192, 57.78478390829903, 57.42381109510149, 64.09439441135952, 64.15871388571603, 68.34600407736642, 66.20278358459473, 65.06889316013881, 47.99033566883632, 20.676317351205007, 21.590458835874283, 52.73619154521397, 54.55300651277815, 50.25476401192801, 27.936005422047206, 34.40098980494908, 42.351413931165425, 61.14741325378418, 64.35314532688686, 90.49984196254185, 62.232298033578054, 70.86229419708252, 3.878287298338754, 0.21917898394167423, 0.3646746017038822, 0.2350583454327924, 0.43788999585168703, 0.2726201441671167, 0.18594370090535708, 0.19661955375756535, 0.26363677478262354, 0.18815763853490353, 0.19176372646221093], [0.009889077927385057, 0.1132146128054176, 0.34511053721819607, 0.9906824060848781, 0.06667046248912811, 0.033036940465016026, 0.09658101214362041, 0.05391429590859583, 0.5057188804660524, 0.37002015486359596, 0.3231328965297767, 0.42617272745285717, 0.22992395237088203, 22.186827932085308, 50.99073805127825, 30.184148924691335, 13.024337462016515, 45.92728001730782, 34.31628431592669, 23.116971118109568, 33.77002041680472, 30.584639617374965, 58.86276912689209, 51.07394272940499, 34.53904703685215, 24.571383680616105, 49.306911604745046, 58.00400652204241, 61.02743176051548, 51.09250136784145, 51.117910930088584, 46.25162540163313, 55.374155044555664, 53.44254193987165, 50.28673962184361, 37.52766874858311, 39.1694655418396, 41.65499946049282, 40.60118702479771, 40.86236980983189, 43.50660058430263, 39.187485694885254, 38.612202644348145, 38.881153515407014, 37.59280811037336, 39.08733088629586, 39.237693377903526, 37.535356930324006, 33.47813354219709, 36.30936813354492, 42.58366789136614, 45.37111840929304, 45.82995659964425, 48.968902587890625, 46.99792793818882, 51.12201731545584, 49.443315165383474, 46.35725539071219, 52.91162313733782, 55.84618091583252, 55.91582271030971, 50.74104411261422, 49.584978512355256, 50.23419386999947, 46.42155054637364, 44.180450780051096, 43.52430806841169, 48.16745914731707, 48.23764290128435, 41.966619219098774, 36.528920786721365, 27.542131151471818, 25.936607428959437, 30.121232986450195, 22.63350330080305, 13.832507627350942, 16.179712465831212, 30.844623838152202, 34.33153561183384, 32.77594511849539, 25.62567206791469, 30.001293182373047, 27.15011031287057, 27.666121755327495, 50.835987772260395, 91.43223462785993, 64.01200267246791, 37.389844281332834, 58.98063141959054, 55.14518758228847, 50.234009742736816, 41.88726731709072, 26.095524890082224, 11.947468297822134, 7.438215085438319, 4.4240613494600565, 4.674152638231005, 11.105806078229632, 17.58941684450422, 26.246229580470494, 23.62260890007019, 14.543516789163862, 19.388583387647355, 31.284156458718435, 33.03765944072178, 32.51212896619524, 35.86673314230782, 40.40517486844744, 45.4706791469029, 46.69352388381958, 39.137493406023296, 37.07731778281075, 37.11736372538975, 41.223679610661094, 44.06741401127407, 48.68520763942173, 48.141799449920654, 44.9181410244533, 44.52727011271885, 46.09981421061924, 43.843025411878315, 43.96481343678066, 40.223892893110005, 44.06535734449114, 44.937234674181255, 42.227305207933696, 43.424177578517366, 43.928040095738, 43.148587703704834, 41.37357309886387, 43.4917870249067, 36.453161103384836, 35.57443632398333, 37.43898541586739, 36.264250005994526, 40.87966387612479, 52.801136357443674, 53.41739640917097, 57.48847450528826, 49.57129750932966, 50.70938464573452, 46.8597525869097, 50.36192607879639, 48.925698689052034, 45.143887996673584, 45.71924747739519, 54.755935600825715, 50.901054177965435, 55.00981930324009, 56.45140722819737, 56.94098424911499, 39.86172846385411, 14.00043863909585, 16.907621383666992, 42.94131251743862, 41.6163501058306, 30.218434810638428, 21.918768167495728, 28.987808091299875, 36.03109972817557, 37.49356698989868, 52.93644210270473, 72.57775579180036, 38.59360579081944, 52.839434828077046, 2.000001834971564, 0.0641452537051269, 0.14567739729370388, 0.11752001249364444, 0.10123598628810473, 0.09956180290984255, 0.3161498483802591, 0.16286524571478367, 0.1099775190066014, 0.18884694868964808, 0.027521242953038642, 0.10989355029804365, 0.21303969408784593, 0.2645178660750389, 0.9233020331178392, 0.19448011927306652, 0.1968638263642788, 0.2871709476624216, 0.09004068773772035, 0.5121950900980404, 0.31490218532936914, 0.22741167646433624, 0.8644196870071548, 0.20655931825084345, 27.558336087635585, 58.00336033957345, 31.87207133429391, 22.215192215783254, 57.74195521218436, 44.1406306539263, 28.588868583951676, 40.00743913650513, 38.840989453451975, 66.60788440704346, 57.96801832744053, 40.26267078944615, 24.161386115210398, 53.08023854664394, 61.471435546875, 63.323311124529155, 53.05721569061279, 55.0076653616769, 50.50116450445992, 56.907278537750244, 54.57877043315342, 51.18594421659197, 42.17101437704903, 42.604449953351704, 42.58435576302664, 43.05589526040213, 42.24434913907732, 45.674907548086985, 39.6252430507115, 42.70738404137747, 41.519019739968435, 41.9984176499503, 43.872805391039165, 43.14603771482195, 38.99071618488857, 35.97912720271519, 39.443453856876914, 42.655505316598074, 44.75623410088675, 49.056422097342356, 50.29680756160191, 48.526295389447895, 50.549284253801616, 53.16558674403599, 48.47095993586949, 55.203663621629985, 58.273245743342805, 57.175416469573975, 57.89269985471453, 51.377450466156006, 51.481534481048584, 49.523195130484446, 48.89615147454398, 44.39535161427089, 48.49133552823748, 49.384696687970845, 46.487440313611714, 41.936512674604145, 28.506930215018137, 29.20865658351353, 29.64646257672991, 28.942163637706212, 20.672389881951467, 19.124227012906754, 34.65875407627651, 36.09419979367937, 32.64891120365688, 30.278832026890345, 33.495493616376606, 31.571103164127894, 30.095938069479807, 54.08403784888131, 95.83595425742013, 58.60897922515869, 39.49005195072719, 61.660197257995605, 53.30647536686489, 52.63676629747663, 44.73044238771711, 34.91569151197161, 24.738262040274485, 14.6519547189985, 11.485974158559527, 9.22623758656638, 19.7510917527335, 27.578313895634242, 32.228086607796804, 33.27566303525652, 17.08073401451111, 23.179881845201763, 31.855836868286133, 31.842538016183035, 32.97264167240688, 40.213439328329905, 45.65461533410208, 50.92453908920288, 48.89292056219918, 44.32362536021641, 42.03929042816162, 41.67712599890572, 45.10726056780134, 48.23042024884905, 52.67339025224958, 50.97829382760184, 49.28383316312517, 49.229321071079795, 48.50778538840157, 47.71422815322876, 46.145915508270264, 44.789165088108604, 46.121433530535015, 48.49498333249773, 44.73536171231951, 45.253197056906565, 47.558112553187776, 46.502740246909006, 45.55132688794817, 43.348379680088584, 40.59061534064156, 38.80060652324131, 42.645937647138325, 39.72789921079363, 43.90383604594639, 55.5107045173645, 55.83738449641636, 58.85463278634207, 53.46559606279646, 52.42076417378017, 48.51395191465105, 51.52206332342965, 51.75443887710571, 50.651808398110525, 49.00006525857108, 56.90652118410383, 58.18813031060355, 60.452134813581196, 61.41734382084438, 59.5829290662493, 40.621736322130474, 14.94451035772051, 19.160373279026576, 49.872074604034424, 47.785433292388916, 33.720966134752544, 20.819637843540736, 29.870788642338344, 32.06794800077166, 45.03557252883911, 54.080786091940745, 75.67189284733364, 44.72555085590908, 64.7904441016061, 2.356061403240476, 0.023251583400581564, 0.05523582428161587, 0.09537657177341835, 0.11679482140711375, 0.19378941133618355, 0.1637833307364157, 0.10544280162347214, 0.08106034461941038, 0.18785756320825645, 0.06244628344263349, 0.1366765217057296, 0.25404019973107744, 0.35489417080368313, 1.5431282477719444, 0.2029276088412319, 0.38540851484451977, 0.7928634466869491, 0.17344298240329536, 0.446104639342853, 0.4372027484433991, 0.3309301052774702, 0.821573511830398, 0.8347800288881574, 42.310878140585764, 71.26492146083287, 41.32452923910958, 19.84814419065203, 56.72391905103411, 44.553985936301096, 30.547550133296422, 43.28013447352818, 40.8649753843035, 70.7677778516497, 58.439957346235005, 41.77992112295968, 27.332783664975846, 54.372308186122346, 61.298974309648784, 67.43575532095772, 57.927819524492534, 60.44868155888149, 51.724613734654014, 58.778265135628835, 58.16666385105678, 57.283308097294395, 43.03847960063389, 42.405495234898154, 46.10795749936785, 44.51534352983747, 46.65043115615845, 50.44925798688616, 42.23019565854754, 43.91969878332955, 44.92917128971645, 42.243202686309814, 43.89832959856306, 45.43902662822178, 41.01427132742745, 37.75730671201433, 39.49005542482649, 42.939627579280305, 44.92111137935093, 48.853427001408164, 52.215038435799734, 48.14686121259417, 52.438638414655415, 54.370918546404155, 50.22122853142874, 59.43944876534598, 62.62680285317557, 64.63904285430908, 59.73610210418701, 55.19363042286464, 59.055227279663086, 53.515261786324636, 51.403975214277, 49.245409624917166, 51.59837538855416, 50.47709941864014, 43.963760784694124, 42.09292009898594, 30.968148912702286, 27.432618856430054, 31.348135471343994, 27.001602990286692, 26.670184339795792, 26.50145775931222, 39.21003259931292, 37.83642932346889, 38.07292863300869, 28.369996854237147, 37.37930038997105, 34.50490358897618, 39.86632817132132, 42.69968891143799, 77.54213251386369, 61.063826424734934, 42.52168301173619, 62.5227118900844, 52.91405848094395, 53.58545248849051, 46.87344053813389, 43.35101304735456, 37.04371282032558, 24.6454792703901, 20.795020375932964, 18.478775841849192, 27.315447909491404, 34.81989322389875, 38.519075938633506, 39.66677590778896, 25.861030135835918, 28.579888037272863, 35.53279229572841, 36.21782561710903, 35.364736216408865, 42.60008648463658, 50.04734986168997, 55.82537453515189, 56.23988321849278, 48.192632470812114, 44.16963938304356, 41.95887197766985, 48.82524858202253, 52.10829326084682, 56.43031249727522, 53.50622565405709, 51.30361890792847, 51.978921277182444, 53.10736083984375, 51.317807129451204, 49.40331438609532, 44.99570376532418, 49.916313784463064, 52.57058470589774, 48.495810168130056, 46.19333348955427, 47.8908965247018, 48.10867738723755, 45.717802252088276, 46.73081486565726, 42.990290369306294, 40.86617742265974, 44.98512513296944, 43.455614703042166, 48.18410355704171, 60.30406175340925, 60.31840283530099, 64.66050583975655, 56.281495979854036, 55.58071804046631, 50.48474938528878, 54.615293639046804, 57.75467388970511, 53.53305959701538, 50.04944126946585, 62.222521918160574, 61.53824247632708, 64.94911316462925, 67.43199634552002, 65.71599973951066, 46.01564373288836, 18.261078357696533, 21.96253660746983, 53.36471169335501, 54.670149666922434, 40.077629838671, 27.711008855274745, 38.5405250276838, 50.97949586595808, 55.72879457473755, 66.79973111833844, 76.57211535317558, 51.3017498425075, 72.29076044900077, 4.1572800534112115, 0.2297187905226435, 0.24224514407770975, 0.1625837893890483, 0.42513497599533623, 0.33179187189255444, 0.39801005007965223, 0.3832036017307213, 0.15833777508565358, 0.3022918834217957, 0.13230942961360725], [0.2436101394040244, 0.2603669416691576, 0.2566451228090695, 0.29939472888197216, 0.09629729629627296, 0.12150320304291588, 0.06196401467812913, 0.028472842515579293, 0.36559510231018066, 0.21186930260487966, 0.21855200401374272, 0.4099985153547355, 0.39770693491612163, 14.897858415331159, 47.75611189433506, 37.311166354588096, 56.504279545375276, 44.920941148485454, 43.20130716051374, 17.669185638427734, 38.248460974012104, 41.287926128932405, 49.00007915496826, 53.77940102985927, 40.854879651750835, 23.81227387700762, 47.29168387821743, 65.1696559361049, 62.36326462881905, 55.01792090279715, 51.02518721989223, 48.692600522722515, 52.817325660160606, 47.164399828229634, 42.114205905369346, 43.75128487178257, 46.68464756011963, 39.952753339494976, 43.28386913027082, 43.113009452819824, 39.535510540008545, 39.342069217136924, 39.98949193954468, 40.33173588344029, 40.39132363455636, 41.31828628267561, 41.44291959490095, 37.55595139094761, 37.14077568054199, 37.9506333896092, 41.2026161466326, 44.5764980997358, 45.71685034888131, 46.68216357912336, 47.69238996505737, 44.77682508741106, 45.67341715948922, 46.04743521554129, 48.69372960499355, 54.20835501807076, 50.09542097364153, 52.51746225357056, 50.61892604827881, 47.8557699067252, 46.20434985842024, 42.27236427579607, 37.21874141693115, 39.94908816473824, 46.37445913042341, 47.737212794167654, 44.55742876870291, 28.705763339996338, 31.761528968811035, 29.872869627816335, 27.58244981084551, 17.025714703968593, 15.257340839930944, 27.821624176842825, 25.930145604269846, 16.215902158192225, 20.249020508357457, 22.796341282980784, 23.23426365852356, 18.15579230444772, 35.82376548222133, 52.8992657661438, 27.358123745237076, 29.93055704661778, 43.51517813546317, 48.992842606135774, 41.92005934034075, 26.763727937425884, 9.506257806505475, 2.5799599375043596, 1.6655701633010591, 0.43925387838057106, 1.7168263729129518, 5.628316615309034, 16.831022705350602, 28.534481559480938, 33.3144965171814, 11.12904519694192, 22.489541837147303, 26.613163948059082, 27.644109862191335, 30.773463862282888, 35.49095024381365, 38.764257022312705, 42.41592795508248, 40.09172078541347, 36.54489816938128, 37.00544214248657, 42.3054654938834, 42.603001253945486, 45.16298859460013, 45.85169403893607, 44.07525157928467, 45.886782441820415, 46.0606506892613, 44.886161940438406, 45.33334800175258, 43.08701971599034, 41.888834135872976, 40.93214014598301, 46.98044627053397, 44.438312326158794, 44.35607344763619, 46.28157213756016, 43.10997656413487, 41.21109989711216, 37.693320751190186, 37.37129259109497, 38.92068876538958, 38.173076493399485, 37.3867175919669, 41.162000451769146, 50.64263677597046, 49.974112374441965, 53.313993317740305, 52.71189716884068, 51.450083460126606, 49.59545292173113, 51.39945888519287, 46.539749826703755, 46.86104147774832, 47.94362987790789, 49.855895723615376, 54.28552518572126, 56.86187553405762, 57.53179652350289, 56.92087616239275, 34.57092884608677, 10.404599087578909, 13.791142395564489, 44.79825333186558, 37.051699774605886, 25.328869342803955, 18.44773302759443, 27.383345706122263, 34.34315994807652, 39.133866446358816, 41.190925802503315, 28.52093083517892, 49.86330597741263, 56.646154812404085, 1.5846702243600572, 0.21218298934400082, 0.03186708502471447, 0.08096095280987875, 0.06549610836165291, 0.0815218977097954, 0.0295478862577251, 0.023594940779730678, 0.017624855507165194, 0.16927286902708666, 0.17242995676185402, 0.3486745288329465, 0.4413313354764666, 0.2694396876863071, 0.16735899315348693, 0.11224483698606491, 0.09231366469923939, 0.08359880519232579, 0.056551452792648754, 0.15703402433012212, 0.10951392352581024, 0.12512461229094438, 0.4370834891285215, 0.3826853909662792, 19.19325910295759, 54.51480879102434, 34.68327079500471, 52.818972383226665, 53.95421770640782, 49.718630586351665, 24.542777947017125, 43.75039897646223, 47.139806679316926, 51.95663145610264, 57.70475108282906, 46.18732329777309, 27.222147498811992, 47.46554865155901, 66.89025919778007, 64.20726789746965, 60.24416133335659, 56.65688977922712, 53.751910482134136, 55.73540578569685, 50.274080004010884, 46.613845416477744, 46.53027595792498, 48.93130241121565, 43.69979872022356, 48.22937454496111, 46.20648990358625, 41.879210880824495, 44.59965297154018, 43.05501978737967, 42.61130435126168, 42.774573121752056, 42.668668678828645, 43.969232491084504, 40.4113552910941, 39.43109995978219, 38.76093578338623, 41.03640481403896, 45.61153302873884, 46.71449702126639, 48.31603247778756, 48.08543218885149, 45.20347227369036, 46.71328108651297, 52.87572179521833, 53.743319034576416, 57.7703663962228, 52.781834261757986, 53.59343596867153, 52.5959803717477, 50.74169724328177, 49.528375012534006, 45.02896479197911, 40.72453492028372, 44.46319382531302, 48.33146442685808, 50.23469066619873, 47.50302723475865, 34.05295106342861, 33.41570050375802, 34.134394373212544, 29.089481081281388, 28.4477367741721, 28.793899502073014, 34.871122292109895, 30.406824793134415, 22.88439232962472, 22.450842108045304, 28.188070433480398, 26.31561255455017, 21.85175974028451, 22.7190842628479, 38.34239714486258, 25.949121134621755, 32.232436180114746, 42.91145263399397, 52.53952973229544, 45.9148462159293, 31.456412724086217, 14.652665172304426, 5.218200062002454, 1.3812618191753114, 1.678336392555918, 4.863289986337934, 11.221846205847603, 26.03413234438215, 33.46099233627319, 31.781588418143137, 16.547812393733434, 27.995200599942887, 29.110598393848964, 28.80372425488063, 31.275450365883962, 39.23715141841343, 42.935569831303184, 44.87770250865391, 42.06508214133126, 40.650171824863975, 39.791822637830464, 44.35640696116856, 47.20378916604178, 50.438012327466694, 50.88567434038435, 46.567146573747905, 47.53963034493582, 49.889465945107595, 49.30495221274239, 49.99232360294887, 47.44268907819475, 45.31369502203805, 44.20537396839687, 48.1403021131243, 46.895403793879915, 45.273107119968955, 48.61616686412266, 45.33220154898507, 40.13497679574149, 40.73903233664376, 41.277482986450195, 40.71462331499372, 42.75368683678763, 40.639523710523335, 45.34660169056484, 52.8541511126927, 52.94288655689785, 57.62246356691633, 55.259711265563965, 53.55458511625017, 52.297120979854036, 53.03869179316929, 53.67817619868687, 52.4447215625218, 52.32823501314436, 54.01856844765799, 57.19331502914429, 60.076820918491904, 60.17772960662842, 56.73096799850464, 32.386067799159456, 8.32528291429792, 17.152217081614904, 49.41643953323364, 41.37401778357369, 26.849296740123204, 18.517932415008545, 27.77303194999695, 32.00897169113159, 45.38641486849104, 49.521770749773296, 34.81633922031948, 56.22671290806362, 65.64885929652623, 1.8018577758755003, 0.23393311724066734, 0.08771311584860086, 0.09870175977370568, 0.02059325622394681, 0.059935398532875946, 0.045687170765761814, 0.039628439982022555, 0.041302748889263184, 0.13946876116096973, 0.23241838280643734, 0.3613602838345936, 0.4995825354542051, 0.29823945515922134, 0.3494552783668041, 0.25131468740957125, 0.3112735700394426, 0.19342289386051043, 0.12811004423669406, 0.36357879479016575, 0.2957283327622073, 0.3018084136503083, 0.6370867884584835, 0.5796603613666126, 25.459292241505214, 65.58299037388393, 46.48193039212908, 77.22867148263114, 57.58076047897339, 55.975935050419395, 25.96902424948556, 46.27657985687256, 53.70853287833077, 57.75866215569632, 61.007830892290386, 47.210379532405305, 29.315561567034038, 52.125118323734824, 68.91018390655518, 66.97133077893938, 59.80836336953299, 57.32120704650879, 54.304674421037944, 56.25975506646292, 53.00885622841971, 47.86787714276995, 47.58286551066807, 50.38015120370047, 43.617358343941824, 48.57968187332153, 48.493218490055625, 44.017091682979036, 47.39171014513288, 45.786255904606406, 46.21848596845354, 45.76518201828003, 45.91429730824062, 45.34903703417097, 42.29074226106916, 40.72141170501709, 40.084004810878206, 42.471336364746094, 46.013798986162456, 47.982206276484895, 49.21515022005354, 48.555210317884175, 45.479677064078196, 49.99607910428728, 53.876217229025706, 53.29088708332607, 62.28907871246338, 55.01256384168352, 57.35013934544155, 53.764900139399934, 51.90046221869332, 53.2495869909014, 47.910295895167756, 43.032584054129465, 46.52198675700596, 48.249093532562256, 50.9604161126273, 49.83882747377668, 35.08309098652431, 32.89439800807408, 35.01536342075893, 34.87973458426339, 29.665038585662842, 27.785993814468384, 41.067612648010254, 37.498104163578574, 29.04309664453779, 27.853021349225724, 35.62089545386178, 35.53627681732178, 31.782251971108572, 39.658556188855854, 50.0488715171814, 35.582854066576274, 38.64453608649117, 50.63825593675886, 50.14668825694493, 43.85126250130789, 36.18174014772688, 26.72482671056475, 12.224103007997785, 6.062724939414433, 7.119740494659968, 11.485359242984227, 22.621892860957555, 37.09562628609793, 34.107991218566895, 38.136202403477256, 21.11382109778268, 30.266380855015345, 30.605539798736572, 32.42941761016846, 36.20952599389212, 40.454451492854524, 45.50658048902239, 49.62475347518921, 46.907941818237305, 42.160272462027415, 43.556707518441335, 46.36146599905831, 50.55239357267107, 53.81820671898978, 54.26030322483608, 50.43504892076765, 50.26979991367885, 51.27315105710711, 51.383297375270296, 52.25037349973406, 52.451346669878276, 47.93804005214146, 46.71749864305769, 53.36867216655186, 50.03209856578282, 45.34889807019915, 51.99316855839321, 50.29488638469151, 45.65898922511509, 44.610759666987825, 43.41371706553868, 43.467711516789024, 47.07130091530936, 44.494474615369526, 46.90869917188372, 56.3281010219029, 55.23159537996565, 60.28350898197719, 59.038384846278596, 56.429082666124614, 54.097121306828086, 57.41224929264614, 53.910378047398154, 54.785003389631, 54.137844698769705, 57.469356536865234, 62.41731466565813, 66.48302527836391, 67.01637595040458, 62.84806823730469, 37.930052825382774, 14.572170291628156, 17.434602294649395, 55.21826526096889, 45.95305435998099, 33.434564862932476, 24.502264738082886, 38.085838385990684, 48.387692723955425, 56.00115353720528, 56.36525303976876, 34.90214947291783, 62.22103500366211, 75.70355578831264, 2.9597332733018056, 0.40752845789705006, 0.19082555680402688, 0.09273180511913129, 0.15216838541839803, 0.2381645973239626, 0.19489432418985025, 0.1547434665262699, 0.14007128668682917, 0.17621775636715548, 0.2709356945540224], [0.1308878037546362, 0.23298224540693419, 0.12022051401436329, 0.02703502681106329, 0.06263562185423714, 0.03436218381726316, 0.19024414728794778, 0.09325992928019591, 0.10245330525296074, 0.08533588876681668, 0.2695900781878403, 0.06414624436625413, 0.3542789838143757, 9.101080553872244, 54.33964123044695, 40.27534777777535, 40.781517096928184, 44.52214929035732, 46.079348291669575, 20.495294196265085, 23.16667331968035, 30.826843397957937, 39.90020063945225, 47.14633451189314, 48.04669598170689, 26.372014556612285, 35.442708900996614, 59.777186802455354, 67.18057577950614, 59.33958925519671, 60.30161598750523, 55.563625471932546, 59.02934523991176, 49.56324454716274, 52.65137141091483, 49.408928530556814, 51.32502283368792, 50.20776292255947, 51.101738997868125, 47.48918294906616, 46.631014415196006, 44.65587779453823, 43.9020607812064, 39.30616787501744, 41.76697315488543, 37.778359753744944, 38.562696729387554, 39.39532368523734, 38.46876055853707, 36.24729987553188, 37.74894455501011, 39.76475593021938, 43.06384399959019, 42.973670278276714, 43.445317472730366, 40.7111804825919, 43.41681943620954, 48.479002475738525, 52.63062408992222, 50.65724188940865, 52.18758610316685, 47.46203286307198, 51.69383321489607, 48.60110316957746, 47.13444267000471, 40.91488429478237, 40.42876747676304, 40.838193552834646, 45.830039978027344, 44.949369703020366, 43.40576485225132, 36.744311468941824, 27.971962349755422, 35.71688829149519, 28.37196319443839, 26.06705117225647, 36.68557834625244, 33.966571058545796, 24.653806686401367, 18.554485150745936, 16.485108375549316, 17.32660470690046, 16.346941709518433, 11.144907065800258, 6.686842969485691, 9.239830868584768, 11.40407747881753, 12.493131177765981, 17.963994230542863, 29.102781670434133, 25.753847224371775, 20.005965573447092, 10.289400560515267, 5.800500358854022, 4.48754790851048, 3.406498968601227, 3.8334935648100714, 14.643778426306588, 22.04213343347822, 26.827700001852854, 17.655765192849294, 19.950301817485265, 30.160730021340505, 26.866733244487218, 26.275226150240215, 27.224098205566406, 35.73145866394043, 37.79140499659947, 38.49205092021397, 36.867426599775044, 34.226405893053325, 33.65611512320382, 39.93068586077009, 42.73951945986067, 45.65421233858381, 46.540159770420615, 44.55627884183611, 44.94276544025966, 45.27301331928798, 46.57396970476423, 46.53135987690517, 44.330806323460166, 46.14401517595564, 45.76310798100063, 43.00655262810843, 44.59704392296927, 44.12931203842163, 42.26990113939558, 37.138531412397114, 36.254824774605886, 38.91895171574184, 37.05580963407244, 37.17211900438581, 37.989987986428396, 38.25773334503174, 41.100884096963064, 49.30472639628819, 52.68161344528198, 52.656586033957346, 51.01795761925833, 51.07419981275286, 53.887629645211355, 54.48572015762329, 52.498973097120015, 50.311673232487266, 48.9860576902117, 49.711512156895225, 55.66103226797921, 52.78660420009068, 60.61841215406145, 53.36382232393537, 20.776404414858135, 3.6425010476793562, 19.38117834499904, 48.46712800434658, 35.821330138615195, 22.145289863858903, 18.748478855405533, 32.075938429151265, 33.29224838529314, 33.435464654650005, 53.88915477480207, 46.638747760227744, 43.04414585658482, 53.2721825327192, 0.7589251878006118, 0.13454075131033147, 0.05194693790482623, 0.008800262468867004, 0.022749818628653884, 0.17728222853371076, 0.05232003038483007, 0.04420562008661883, 0.02818411059810647, 0.08730503810303551, 0.07652270953570094, 0.1259991353643792, 0.20545511107359613, 0.07472357393375464, 0.026990603123392378, 0.05331395187282136, 0.03535487037152052, 0.10083660057612828, 0.06714559985058648, 0.07620612545205013, 0.15350267024976866, 0.21787720093769686, 0.19853876291641168, 0.4172334357031754, 10.654175775391714, 67.29278223855155, 39.72176047733852, 39.10727916445051, 52.91296066556658, 47.26583310535976, 23.95845181601388, 30.658422538212367, 36.85573278154646, 45.99766526903425, 51.359242711748394, 53.70885249546596, 28.596332686288015, 36.179044246673584, 59.571214403424946, 68.42599868774414, 60.67086410522461, 63.42399747031075, 59.48874623434884, 64.78999941689628, 55.7587308883667, 55.43229757036482, 53.560400758470806, 54.72765990665981, 53.87066214425223, 57.402813638959614, 51.72056640897478, 51.86864989144461, 47.70677273614066, 46.39697824205671, 41.81549589974539, 42.3313753264291, 40.132110663822715, 40.3486373765128, 40.0683331489563, 41.26084899902344, 37.61732135500227, 39.01821368081229, 40.404056208474294, 42.46158109392439, 43.42177350180489, 43.78204454694475, 42.477930205208914, 45.90438222885132, 51.807630811418804, 54.160964829581125, 53.500844274248394, 53.28282369886126, 50.317016397203716, 52.26405797685896, 51.62303454535348, 48.00308908735003, 44.43270860399519, 43.396641867501394, 42.53991161073957, 48.23907423019409, 48.634426730019705, 47.135766301836284, 41.50328207015991, 31.764547961098806, 40.46718406677246, 37.17767756325858, 35.06013413837978, 42.35792439324515, 38.42280169895717, 31.357602391924175, 22.79291582107544, 22.227598224367412, 24.060795307159424, 22.320318460464478, 17.1358471257346, 13.525810667446681, 12.184189081192017, 10.709539890289307, 12.287643415587288, 15.773206370217459, 25.068438700267247, 29.839650290352957, 26.920387234006608, 13.656949230602809, 5.876807647092002, 4.216621143477304, 5.224631488323212, 5.69517001083919, 21.10493435178484, 26.989646877561295, 29.89078208378383, 20.21015923363822, 29.310155868530273, 31.896445614951, 28.684289932250977, 29.80307844706944, 31.32527937207903, 37.22451884405953, 42.65968118395124, 43.0757497378758, 39.25989634650094, 37.66790076664516, 37.5343668120248, 42.57749441691807, 47.58594356264387, 50.39889744349888, 49.74150405611311, 49.807873249053955, 49.58757366452898, 48.13832187652588, 50.19541597366333, 50.2012038230896, 48.99077204295567, 47.73449257441929, 48.55578007016863, 47.03641748428345, 49.94048309326172, 47.163979462214876, 45.52091809681484, 38.556026458740234, 38.53630747113909, 40.64241763523647, 41.1121506009783, 41.84158985955374, 42.9596175466265, 41.17316620690482, 44.23319108145577, 50.173098359789165, 55.25939859662737, 54.97094413212368, 55.07577855246407, 53.629781995500835, 55.952380657196045, 56.58279766355242, 59.19261401040213, 55.729152406964985, 53.67109945842198, 54.55996860776629, 58.742634773254395, 57.51015983309065, 64.2826280593872, 51.59145845685686, 16.3513468674251, 3.6546894907951355, 25.338402271270752, 51.87479557309832, 38.862553187779014, 23.538167442594254, 23.485204798834665, 31.31062909534999, 36.6364233153207, 34.86176306860787, 67.43029403686523, 59.75475801740374, 41.90614209856306, 59.97924041748047, 1.008938689317022, 0.020747648385752524, 0.013924172164739242, 0.047998084620173485, 0.03145050184269037, 0.08272725410227265, 0.18701095506548882, 0.1130020549254758, 0.043695935114685974, 0.17303366293864592, 0.03246275734688554, 0.37274930413280216, 0.3503320541765009, 0.19689305765288218, 0.11319068766066007, 0.10347423582736935, 0.11141488687800509, 0.214305080473423, 0.18756402895918914, 0.14074474626353808, 0.2506808542779514, 0.29206592642835205, 0.4036361096160752, 0.6315859322037015, 16.19204899242946, 77.04058374677385, 49.76028503690447, 58.94558470589774, 58.652808461870464, 60.62442929404122, 29.832490171704972, 28.851114443370275, 39.00012404578072, 52.05938836506435, 55.99095358167376, 55.04785026822771, 31.646807261875697, 40.21750055040632, 63.43437113080706, 68.97961030687604, 63.906723567417686, 65.24564838409424, 60.32368346623012, 66.36196681431362, 56.273912021092, 55.91288709640503, 52.765301023210796, 55.11583491734096, 55.09180804661342, 56.01089838572911, 52.21301303591047, 53.38147422245571, 48.627214499882285, 47.468227182115825, 44.702882358006065, 45.22527919496809, 40.47304139818464, 43.46162836892264, 42.59557710375105, 42.023052488054546, 39.58380052021572, 39.52533490317208, 43.43949835641043, 44.68414306640625, 46.303681305476594, 46.701691491263254, 43.896602971213206, 47.212401458195274, 53.90933929170881, 57.88092960630144, 55.33581835883004, 56.6316956111363, 52.11887189320156, 55.183503423418315, 54.40456172398159, 52.05014378683907, 46.81621170043945, 47.165018217904226, 44.62903342928205, 51.15803677695138, 49.47171592712402, 49.04354361125401, 41.29696226119995, 35.4992880821228, 38.372680868421284, 39.70617914199829, 41.787689208984375, 46.777711732046946, 42.341585704258506, 37.89003814969744, 28.659642934799194, 29.036362103053502, 32.05913421085903, 31.134238651820592, 25.526587281908306, 22.863222905567714, 24.048179115567887, 24.566910777773174, 25.551329817090714, 30.129174777439662, 37.38967752456665, 35.83547667094639, 33.12310143879482, 21.99997697557722, 14.226006695202418, 10.388022422790527, 10.103712558746338, 15.95445534161159, 28.52584842273167, 29.716583796909877, 31.180597032819474, 26.63210126331874, 32.25166531971523, 33.323351996285574, 30.762718473161968, 30.119565418788365, 32.38675914491926, 39.817350319453645, 47.53244590759277, 45.571824073791504, 42.460205350603374, 40.225640365055625, 40.46831314904349, 46.116416931152344, 52.36594983509609, 53.737110819135395, 53.3728723526001, 51.851880414145334, 52.56003039223807, 50.30868550709316, 55.316804613385884, 56.147656304495676, 52.77923216138567, 51.63325881958008, 51.88923740386963, 49.48950331551688, 52.114150592258994, 49.120109285627095, 49.784829548427034, 41.64965282167707, 42.857367856161936, 45.904413495744976, 44.54046821594238, 44.92289706638881, 44.940132072993684, 45.38922194072178, 49.72105203356062, 56.10762078421456, 57.58604110990252, 58.47214835030692, 57.90183326176235, 55.579196384974885, 58.60617215292794, 59.44349261692592, 59.26889828273228, 57.47539799554007, 57.91663987295968, 56.4273282459804, 64.42539269583565, 62.0723227092198, 68.72304112570626, 57.841244970049175, 23.876732315335953, 5.50729593208858, 24.563912630081177, 58.91505432128906, 46.203634193965364, 29.679848670959473, 24.41980004310608, 42.052551065172466, 47.48412118639265, 46.06830413000924, 66.06726591927665, 66.29229027884347, 53.50981092453003, 71.10945551736015, 1.7266861924103327, 0.21445851081183978, 0.2100821363606623, 0.08918316196650267, 0.20692500791379384, 0.19221158671591962, 0.2995893598667213, 0.23100572718041285, 0.22078107297420502, 0.27946238272956436, 0.20520794790770325], [0.08691874133156878, 0.035606722214392254, 0.07969197697405304, 0.03759929797212992, 0.04868348980588572, 0.10879636595823935, 0.03879057137029512, 0.047556721339268346, 0.06979713828435966, 0.12449934227125985, 0.08448863601578133, 0.13369289466312953, 0.24063199492437498, 4.835191905498505, 57.11630119596209, 46.34829568862915, 45.20448323658535, 53.82898684910366, 44.559429849897114, 25.720464604241506, 19.829483066286357, 34.379825592041016, 32.43305846623012, 38.547639983040945, 44.661620480673655, 29.957915578569683, 17.280208110809326, 28.26102304458618, 60.41903359549386, 60.5167669568743, 60.95036928994315, 59.584547996520996, 60.18890230996268, 57.09489727020264, 56.48200709479195, 55.9219023840768, 59.6629375730242, 54.15175151824951, 53.799870422908235, 51.38207449231829, 53.23375899451119, 52.85772596086775, 49.803242274693076, 46.31158488137381, 39.99772555487496, 39.98781047548567, 40.33392456599644, 38.246435574122835, 40.50468349456787, 38.83179351261684, 38.714025020599365, 38.208706855773926, 39.701516900743755, 39.0794620513916, 41.33251966748919, 41.07582194464547, 47.305496897016255, 51.367681298937114, 48.405108383723665, 50.07274552753994, 49.53794615609305, 49.413430963243755, 49.0636100087847, 46.78990234647478, 46.20942551749093, 39.643711362566265, 39.35977322714669, 41.51691096169608, 44.2236407824925, 48.29168251582554, 45.313712392534526, 40.990102018628804, 31.014284951346262, 31.158262048448833, 38.05697904314314, 39.40459605625698, 41.35079342978341, 35.362728187016074, 22.319020884377615, 13.260891488620214, 14.252721650259835, 13.453043920653206, 11.846826246806554, 10.405980910573687, 6.290210698332105, 2.4747266471385956, 1.5337086617946625, 1.6405852011271884, 2.540471370731081, 4.614221385547093, 9.2712037222726, 16.243469136101858, 14.73078898021153, 7.8306788716997415, 1.893479002373559, 2.7946102023124695, 9.688584617206029, 17.78915844644819, 21.75418966157096, 16.955131428582327, 25.735632521765574, 29.445274012429373, 31.22777877535139, 28.003951856068202, 29.106005634580338, 30.03128160749163, 35.49862452915737, 36.841530663626536, 41.040479932512554, 35.844860213143484, 31.765496390206472, 34.014881883348735, 35.25627483640398, 40.139632088797434, 44.04733371734619, 42.41641780308315, 44.9797055380685, 44.443252495356965, 43.18784849984305, 43.1041122845241, 43.69912127086094, 45.37669086456299, 43.53324692589896, 45.3314858845302, 43.172211578914094, 47.198466845921104, 43.20093890598842, 38.66697529384068, 36.68809012004307, 36.96801567077637, 36.928327560424805, 38.522282532283235, 41.91186741420201, 43.972407817840576, 41.94647639138358, 42.83012396948678, 47.01742805753435, 51.955981799534385, 49.11870922361101, 52.916507720947266, 52.11140605381557, 54.60322461809431, 53.181866373334614, 56.11721624646868, 51.54145227159773, 52.288383620125906, 51.15371152332851, 52.82218592507498, 53.24404927662441, 60.42298017229353, 35.40270117350987, 5.538707435131073, 3.0716001391410828, 31.499363013676234, 46.97392191205706, 33.22623355048043, 20.63865637779236, 16.115219286509923, 29.636881010872976, 30.57398108073643, 40.726938996996196, 38.57510968617031, 58.428423336574006, 38.298703398023335, 53.025156702314106, 0.9333953772272382, 0.06084566683109317, 0.01232131214679352, 0.006769975007046014, 0.05758180482579129, 0.07031367306730577, 0.03271556592413357, 0.04981557459437421, 0.021574473840051463, 0.08591925924909966, 0.039523229734706025, 0.10183627264840261, 0.051875922429774485, 0.04833474316235099, 0.0278932192429368, 0.09278600649642092, 0.06963885642055954, 0.08810983491795403, 0.1262273131204503, 0.02956665792901601, 0.006184226683607059, 0.03579227779326694, 0.0492533065511712, 0.17407255433499813, 5.624596289225987, 64.09716674259731, 50.373939514160156, 50.30209861482893, 60.14801216125488, 52.04130220413208, 28.73911816733224, 27.687306812831334, 41.91574798311506, 35.39323772702898, 43.976489884512766, 48.64736427579607, 33.126054423195974, 17.39674503462655, 27.824373926435197, 56.32269184929984, 65.16684886387416, 64.56684412275041, 60.61543137686593, 62.108877182006836, 60.29652990613665, 58.81468064444405, 58.782482692173545, 62.36258370535714, 56.72796637671334, 56.541153635297505, 55.1910526411874, 55.80035754612514, 55.993447984967915, 54.50512647628784, 49.390758991241455, 43.014720235552105, 42.576476505824495, 42.238443170275005, 39.86154086249215, 43.09531239100865, 42.80546481268746, 39.68540055411202, 41.14878150394985, 40.17891720363072, 40.51662744794573, 43.11315189089094, 43.450434820992605, 47.7854437146868, 51.84694024494716, 50.195419447762625, 51.650337491716655, 49.5532808303833, 49.10729333332607, 48.40036971228463, 49.14008188247681, 48.877714429582866, 42.30540643419538, 41.93953166689192, 43.14544711794172, 47.55521515437535, 51.85964502607073, 47.265107018607004, 46.36351919174194, 35.812926292419434, 36.288026741572786, 42.2672712462289, 44.77125610624041, 44.62909943716866, 37.79131467001778, 25.943437508174352, 19.49775000980922, 13.109544089862279, 12.84031355381012, 12.771510754312787, 9.93325935091291, 5.456941902637482, 3.271188880716051, 2.8802719371659413, 2.625468901225499, 1.6231888660362788, 3.9470440660204207, 9.349684493882314, 17.720963614327566, 17.659541538783483, 9.884703602109637, 3.6587038125310625, 3.5859741951738084, 12.53980222770146, 19.709842034748622, 24.65623508180891, 21.450508219855173, 31.49906771523612, 35.19891050883702, 35.85631084442139, 30.259932926722936, 30.101642540522985, 33.03001989637102, 39.31455087661743, 40.799148150852744, 43.39323377609253, 38.29822397232056, 36.54442221777779, 36.25976841790335, 39.65222985403878, 43.37810059956142, 48.879086698804585, 46.20624671663557, 48.580265522003174, 47.702662876674104, 47.9441614151001, 48.72711222512381, 46.29996749332973, 48.05641998563494, 47.12666763578142, 48.57528018951416, 46.68782983507429, 47.49939332689558, 44.96149778366089, 42.029201643807546, 39.56835120064871, 39.12078646251133, 39.12562588282994, 42.64118160520281, 46.68809386662075, 49.19885322025844, 47.00022431782314, 46.79962635040283, 49.365196568625315, 54.382768699101035, 53.88376644679478, 54.98480578831264, 54.61697162900652, 56.941880566733225, 55.401485783713206, 58.218500886644634, 57.351129463740754, 56.84092671530587, 56.67684847967965, 57.08261285509382, 56.984573772975374, 60.45970835004534, 30.499187197004044, 3.365799678223474, 4.359090915748051, 36.5386552129473, 52.54996245247977, 37.56489372253418, 25.109533820833477, 21.52720591000148, 30.707553250449045, 30.84474195752825, 40.38516058240618, 42.31659303392683, 59.63483905792236, 46.68642977305821, 62.46961375645229, 1.4738657815115792, 0.030164725479802916, 0.02943615528887936, 0.0030241580596858902, 0.021840028697624803, 0.05461757370669927, 0.06353909123156752, 0.051728300351117334, 0.040538301159228594, 0.12491795766566481, 0.03200213724215116, 0.18386883581323282, 0.1643544400909117, 0.15577884311122553, 0.08316146901675633, 0.20703522914222308, 0.2104599718004465, 0.1875483819416591, 0.22822481925998414, 0.16832422278821468, 0.3064818914447512, 0.2379268386534282, 0.29159336749996456, 0.31662881267922266, 8.114980050495692, 78.57018797738212, 55.38103028706142, 59.936773027692524, 70.14555277143205, 61.37716933659145, 37.7255082811628, 24.049280405044556, 41.87932900020054, 41.82174580437796, 48.2218531199864, 53.24175289699009, 36.7110504422869, 20.90043670790536, 35.488872732434956, 67.9039944240025, 65.60357788630894, 65.25838443211147, 64.75573090144566, 64.88995620182583, 61.79037175859724, 61.582669258117676, 61.180611746651785, 64.59820829119, 56.360139165605815, 58.58165890829903, 56.13289138248989, 57.49652746745518, 59.12545272282192, 55.098221233912874, 49.70276437486921, 44.646115575517925, 44.85464491162981, 45.863672733306885, 44.1555449622018, 45.23942572729928, 44.578655515398296, 42.35314055851528, 40.53758321489607, 41.71087687356131, 41.52621112551008, 45.16669545854841, 45.26172597067696, 49.035712991442, 55.23787655149187, 49.76351942334856, 52.828609534672324, 51.88946322032383, 51.801683153424946, 50.50413485935756, 50.48172344480242, 51.71939563751221, 42.86825915745327, 42.896878787449424, 47.238009044102256, 49.54869154521397, 52.05290569577898, 48.939240728105815, 46.85263415745327, 39.38991103853498, 37.330881868089946, 45.55985580171858, 49.50322948183332, 53.03031921386719, 48.19036040987287, 36.33889102935791, 34.22570065089634, 35.10485969270979, 30.897454466138566, 28.125538383211406, 23.150984287261963, 20.35227942466736, 18.86875738416399, 14.993653229304723, 14.920259407588414, 16.94613524845668, 20.352732794625418, 22.90394629750933, 29.23436839239938, 29.064599582127162, 14.09833094051906, 4.042398972170694, 4.995403468608856, 15.198605980191912, 21.62426355906895, 27.337973969323293, 26.342564616884502, 33.03525536400931, 38.14721529824393, 34.6919595173427, 30.210406167166575, 32.56939254488264, 34.87023639678955, 41.94787992749895, 44.59537982940674, 47.15061460222517, 43.234151295253206, 37.67179523195539, 40.572900908333914, 42.27716548102242, 46.814780371529714, 52.93085922513689, 48.48129538127354, 52.54649877548218, 52.28102200371878, 49.195219312395366, 52.61379555293492, 52.230810846601216, 53.27905430112566, 50.70526088987078, 53.290480613708496, 48.710172516959055, 52.27356311253139, 49.653133392333984, 44.806438309805735, 41.994231360299246, 43.50459950310843, 42.15811504636492, 42.49071489061628, 48.031882422310964, 51.12313944952828, 48.37035002027239, 49.95280919756208, 53.59848036084856, 57.39246082305908, 57.462891238076345, 58.64943858555385, 57.574788502284456, 61.91159003121512, 59.53930132729666, 62.82744598388672, 59.93198571886335, 59.669878823416575, 58.91859095437186, 61.71181542532784, 59.312491280691965, 67.09284087589809, 39.807772227696006, 6.321703842708042, 4.234185320990426, 37.54506008965628, 58.043190887996126, 44.3209468296596, 27.16558916228158, 20.20979619026184, 40.587481703077046, 41.55098145348685, 57.20904575075422, 48.4157703944615, 76.67906897408622, 51.30154834474836, 73.3715318952288, 2.2352969348430634, 0.33149765910846846, 0.10221232354108777, 0.11291377751954965, 0.14540603756904602, 0.11754446689571653, 0.1860796386109931, 0.11913518368133477, 0.07534729689359665, 0.1912502654428993, 0.2382338350372655], [0.11519214883446693, 0.04840019125757473, 0.04682376102677413, 0.11158355032759053, 0.03873359139210411, 0.09997388401201793, 0.06521062153790678, 0.10236124162163053, 0.05370269137035523, 0.03792828228324652, 0.22164202534726687, 0.04821807245856949, 0.03852674677701933, 1.7526519362415587, 47.71517310823713, 49.964944226401194, 30.746490955352783, 50.45182187216622, 47.34648779460362, 33.98152010781424, 19.049964666366577, 20.349239587783813, 36.52480050495693, 41.98424332482474, 48.26595681054251, 28.588484695979528, 13.325366428920201, 14.827396733420235, 24.92589119502476, 45.862182344709126, 63.25382913861956, 57.07640463965279, 57.823075430733816, 53.16844245365688, 58.03601687295096, 55.28894928523472, 56.81519406182425, 56.00648627962385, 56.556783608027864, 54.7730907031468, 54.85004547664097, 56.34004497528076, 55.42265347072056, 52.98741756166731, 50.536273751940044, 41.253265040261404, 40.21593720572335, 40.17391102654593, 41.48672103881836, 40.31746080943516, 38.98559536252703, 39.64559432438442, 40.95118168422154, 40.36199876240322, 41.37138441630772, 42.05124132973807, 44.34629038402012, 49.619837624686106, 49.55821405138288, 48.77296338762556, 51.65503447396414, 48.453353200639995, 47.48685877663748, 47.94230624607631, 44.688718455178396, 39.86439309801374, 42.24207707813808, 40.089143003736226, 41.82575838906424, 46.68424456460135, 48.71738822119576, 41.227918011801584, 33.90900523321969, 28.767730849129812, 32.7339745249067, 32.57150132315499, 41.70254250935146, 25.795906407492502, 15.447264637265887, 10.300946729523794, 3.1930961225714003, 4.800159088202885, 2.7574432023933957, 0.9133702346256801, 0.6797339086021695, 1.2322689912148883, 1.1296537603650774, 1.643500187567302, 1.317065241081374, 1.5777036781821931, 1.213461411850793, 0.8061075817261423, 2.5349922818796973, 2.2558023716722215, 0.5572102431740079, 0.7361170202493668, 6.577590363366263, 13.9451778786523, 20.798115798405238, 29.936278888157435, 25.951546055930002, 30.850463799067906, 31.63761826923915, 29.194930417197092, 28.593482187816075, 30.981656210763113, 36.34237207685198, 35.45266566957746, 36.26947505133492, 34.218405042375835, 33.7123156275068, 33.465237685612266, 36.21947928837368, 39.25536959511893, 42.87904623576573, 43.764302321842735, 44.665299551827566, 43.084660802568706, 45.41083083833967, 44.40194198063442, 41.71976709365845, 46.09944248199463, 43.48765632084438, 47.56252465929304, 44.87881074632917, 40.643098558698384, 40.66195249557495, 38.180236612047466, 37.63040133884975, 37.54282276970999, 41.727430956704275, 46.4379482950483, 47.42875099182129, 51.21219451086861, 49.979059491838726, 48.142014844076975, 47.85506813866751, 52.127060345241, 52.41541406086513, 53.03783369064331, 53.702998638153076, 55.40919828414917, 55.52781793049404, 55.865170342581614, 53.199118750435964, 52.23190171377999, 53.71467161178589, 50.781704970768516, 52.650607109069824, 49.69948829923357, 11.932025926453726, 0.3637826809925692, 7.35344706262861, 39.788616044180735, 44.95870113372803, 35.40595987864903, 14.864491428647723, 19.709364346095494, 31.718120098114014, 35.49442434310913, 32.67324032102312, 32.43624421528408, 52.30872447150094, 37.38935095923287, 52.24871982846941, 1.0237332497324263, 0.037227623630315065, 0.04252219845407775, 0.0754163988998958, 0.09552678585584674, 0.06046267452516726, 0.03745685650834015, 0.06259344411747796, 0.012133527580382568, 0.02823094478143113, 0.021312679762818983, 0.04862232326662966, 0.07099391799420118, 0.071142510377935, 0.09515766280570201, 0.011075697423491095, 0.046221422098044834, 0.051428964627640586, 0.05015519494190812, 0.028569245378353765, 0.022913354049835886, 0.049290144217333624, 0.1291823195559638, 0.1916616205126047, 2.771381505898067, 55.01584339141846, 54.65760122026716, 38.16385623386928, 57.07186051777431, 49.799424239567344, 32.92803423745291, 24.084684950964792, 28.706904581614904, 44.22659029279436, 43.27586133139474, 53.05457190104893, 31.523994377681188, 18.482201303754533, 17.977765560150146, 28.18352804865156, 46.49864428383963, 64.29403700147355, 62.65535994938442, 62.012463978358674, 56.28107908793858, 60.39422157832554, 57.42556551524571, 58.559202330453054, 57.86902734211513, 58.9240174974714, 56.92536122458321, 57.35712228502546, 57.699025767190115, 58.274687494550435, 54.64150224413191, 53.24062034061977, 43.80717618124825, 43.229555061885286, 42.30628885541643, 42.671996865953716, 40.17625951766968, 41.457062653132844, 41.057374477386475, 41.172985553741455, 41.54524918964931, 44.39664050510952, 44.01536852972848, 47.95882558822632, 50.62136139188494, 51.78226293836321, 52.894520146506174, 53.00162315368652, 49.626421042851035, 50.23889432634626, 49.85331446783883, 48.844373498644146, 41.88960191181728, 42.58495330810547, 43.50930690765381, 45.522783688136506, 50.19630534308297, 50.3048848424639, 45.57129601069859, 37.12070580891201, 35.36237382888794, 39.431603704180034, 34.87830672945295, 47.15924079077584, 34.31579099382673, 26.22225829533168, 18.222098963601248, 8.598386202539716, 2.42958202958107, 3.0515873730182648, 5.446291616984776, 3.1203389295509885, 2.5985235699585507, 2.061501209224973, 2.039793734039579, 2.571513967854636, 3.97430271761758, 2.197569953543799, 0.8423614363585199, 3.954243702547891, 2.7986890120165686, 1.6500021815299988, 2.4536323504788533, 7.247269034385681, 19.496659142630442, 25.641295092446462, 33.19278492246355, 29.85853202002389, 37.99395540782383, 33.268711362566265, 31.507985728127615, 32.72527885437012, 34.9764187676566, 41.15753970827375, 39.366537298474995, 42.42495713915144, 39.368455001286094, 37.161932945251465, 36.768477303641184, 38.710995606013704, 41.77249002456665, 47.56409495217459, 47.128693035670686, 49.841822147369385, 48.5923102242606, 46.95393194471087, 46.79207018443516, 43.041554178510395, 48.2555171421596, 46.13231093542916, 47.260218960898264, 44.6581255367824, 42.591800757816856, 41.11132376534598, 40.2359619140625, 42.637207235608784, 41.50569656917027, 47.37886292593819, 52.5510950088501, 50.27320453098842, 54.04752506528582, 52.13648905072893, 52.431683267865864, 52.59264523642403, 54.059288365500315, 55.035975796835764, 56.328410216740195, 56.69163772038051, 58.31349318368094, 57.207034247262136, 59.37168993268694, 57.42386320659092, 57.4589272907802, 57.77583115441458, 55.9152182170323, 55.274580410548616, 50.23251935413906, 7.625599316188267, 0.3497361647231238, 9.844153915132795, 46.793487616947715, 49.885324818747385, 39.16350398744856, 20.66809242112296, 23.99734956877572, 31.093977315085276, 37.22130530221121, 32.41243273871285, 45.92625168391636, 61.099095480782644, 42.656825474330354, 57.86883626665388, 1.415699479835374, 0.07979383186570235, 0.10839485643165452, 0.04410895259518709, 0.02849226218781301, 0.035029109101742506, 0.08193862677684852, 0.0415646498357611, 0.0663976642702307, 0.016201641876250505, 0.05609354343531387, 0.21819219046405383, 0.2662547800157751, 0.16705165750214032, 0.24620510158794268, 0.13593630785388605, 0.13149830885231495, 0.15585357695817947, 0.18824542739561625, 0.2344521422471319, 0.10074803818549428, 0.3376321042222636, 0.15242037975362369, 0.2682735031204564, 4.2613102197647095, 66.1881228855678, 60.645871434892925, 41.75032179696219, 60.2240879876273, 61.51696014404297, 46.22123745509556, 26.359874316624232, 25.743867874145508, 48.27998522349766, 49.52588060923985, 57.75728988647461, 33.991462979997905, 22.5889618737357, 19.658180441175187, 34.70626238414219, 55.3714348248073, 70.04194818224225, 61.8686432157244, 63.52262020111084, 58.45004613058907, 62.685501234872, 59.83685793195452, 60.438113348824636, 60.135672160557334, 61.07517978123256, 58.25952305112566, 59.713673319135395, 60.987549100603374, 61.525033950805664, 57.85906709943499, 54.754830837249756, 47.21472563062395, 47.28733083180019, 44.64648730414254, 45.8377559525626, 44.540579387119834, 42.23909282684326, 45.163269996643066, 44.244197028023855, 43.93616253989083, 46.78340230669294, 46.323309966496055, 48.07447835377285, 52.39548315320696, 52.52396924155099, 51.528962884630474, 54.46886730194092, 50.121504511152, 51.110219274248394, 51.935092040470664, 50.618776662009104, 41.76628875732422, 44.43234729766846, 45.46810136522566, 48.226265226091655, 53.7376388822283, 54.775737966809956, 46.36866085869925, 41.31351287024361, 37.26845230375017, 40.29908282416207, 42.59012624195644, 50.964869907924104, 40.92036989756993, 35.93989767347063, 26.91833404132298, 14.544995886938912, 12.535180807113647, 13.730262279510498, 15.968857220241002, 12.002055083002363, 9.702943069594246, 9.393541523388453, 7.691661051341465, 5.281151175498962, 5.649950700146811, 4.942318797111511, 6.256049011434827, 7.706716060638428, 4.534837348120553, 2.335930734872818, 3.3580344149044583, 7.338877558708191, 25.684349605015345, 32.90911429268973, 36.636093275887625, 33.268652302878245, 39.82037278584072, 35.56724146434239, 34.821189062935964, 32.954909869602744, 38.58539996828352, 44.71668495450701, 42.95230456760952, 44.75430597577776, 43.488017627171104, 42.5982208933149, 39.895163195473806, 42.811600072043284, 45.00751570292881, 48.927407945905415, 49.105994020189556, 51.49521895817348, 49.736880029950825, 49.03257587977818, 51.11699724197388, 47.099708625248496, 54.00505420139858, 48.914637156895225, 54.90568317685808, 49.19774498258318, 45.5301696232387, 46.42399631227766, 44.89743191855294, 45.0282769203186, 44.39447961534773, 47.96489136559622, 53.77467972891671, 52.53062908990042, 58.01442881992885, 56.53256566183907, 54.48331260681152, 55.00628614425659, 57.31191035679409, 57.552637645176475, 59.01777648925781, 60.494331223624094, 63.41480500357491, 60.03868920462472, 63.79310662405831, 60.32218265533447, 62.824013573782786, 63.50506905147007, 61.067015647888184, 60.477405411856516, 59.365860394069124, 14.526625718389239, 0.6014564260840416, 9.87725339617048, 49.94109106063843, 56.169897488185335, 46.50523117610386, 20.813667603901454, 26.805106197084697, 43.36418335778372, 49.37130750928606, 46.132408210209434, 42.075111865997314, 67.34972967420305, 47.12307889120919, 75.44026769910539, 2.8618952546800887, 0.1966582438243287, 0.22326106418456348, 0.2630968237561839, 0.11940906755626202, 0.14081938511558942, 0.17605497581618174, 0.12448840428675924, 0.14668867231479712, 0.13938303504671368, 0.10129284073731729], [0.03353153821080923, 0.015125948436824339, 0.08672802549387727, 0.09263729876173393, 0.07806947760816131, 0.045052146805184226, 0.08870294237775461, 0.07080877971436296, 0.05394691647961736, 0.0069820070223483655, 0.08757459292454378, 0.03507165324741176, 0.1779136053685631, 4.017820153917585, 54.37430231911795, 49.55101571764265, 40.29490695680891, 52.12912743432181, 50.62905304772513, 30.9974981035505, 30.609764303479874, 15.768987076623098, 31.739732469831193, 40.12756654194423, 52.451895577566965, 30.369287150246755, 18.144558804375784, 17.369294439043315, 20.26672625541687, 31.598579815455846, 45.3465495790754, 51.47158466066633, 57.2909129006522, 54.599350997379844, 54.23010982785906, 53.46455383300781, 51.97439799989973, 55.74681125368391, 57.732366698128835, 49.49972758974348, 53.12393576758248, 51.6557605607169, 52.45961850030081, 52.31983464104788, 51.62032127380371, 45.98717696326119, 40.504009519304546, 40.33900717326573, 40.62952177865164, 37.47484506879534, 39.232402324676514, 37.24833379473005, 39.973761217934744, 39.289752755846294, 41.09332793099539, 43.47417681557791, 50.0328802381243, 49.13459627968924, 49.34431723185948, 49.02812555858067, 50.17695461000715, 50.27947528021676, 48.45265143258231, 47.895572662353516, 45.308042662484304, 41.698085239955354, 39.82772050585066, 39.325907707214355, 41.37513296944754, 44.283746174403596, 44.11287260055542, 42.63315296173096, 36.626661096300396, 28.430472237723215, 36.61473103931972, 30.268684182848247, 34.33027451378958, 24.831013543265207, 16.815142597470963, 11.09964042050498, 8.78280702659062, 0.8970499475087438, 0.27084954774805475, 0.43174195289611816, 0.2380951696208545, 0.13714551153991902, 0.4682113102504185, 0.12121720053255558, 0.4080011253910405, 0.6311318022864205, 0.2045928966253996, 0.1694147371287857, 0.015975285986704484, 1.4950791746377945, 2.2187285210405077, 0.7558751457503864, 3.3700752088001797, 21.38328266143799, 27.56310428891863, 23.88442918232509, 19.373128856931412, 18.95986216408866, 32.377723012651714, 31.573854650769913, 30.660378456115723, 31.928782531193324, 33.988728863852366, 35.80954251970564, 37.25255829947335, 34.66534096854073, 33.714434828077046, 33.20714684895107, 34.98983573913574, 39.602063860212056, 42.2472882270813, 43.10386562347412, 45.57884522846767, 43.35023832321167, 43.7040753364563, 42.2206905228751, 41.49661179951259, 39.499630042484824, 38.89624500274658, 40.092384338378906, 39.520804677690776, 37.90996905735561, 38.04358639035906, 40.300159794943674, 39.31781652995518, 39.93448999949864, 47.127192224775044, 49.73961762019566, 51.66284424918038, 50.615768092019216, 49.966257435934885, 51.59456082752773, 49.33741072246006, 51.36186565671648, 53.71194791793823, 54.35680328096662, 55.186463356018066, 53.85847500392369, 52.81762095860073, 52.589501176561626, 55.3881904057094, 54.74631929397583, 52.84814786911011, 44.926791531699045, 43.65535109383719, 31.238055161067418, 1.1767650438206536, 0.8693447655865124, 15.072249514716011, 51.50882700511387, 39.84727968488421, 34.96217843464443, 12.786773341042654, 30.965428692953928, 29.420739923204692, 38.09601402282715, 25.13012307030814, 49.03573036193848, 65.11634935651506, 32.2043446132115, 50.30745220184326, 0.28637537892375675, 0.03475978158946548, 0.055069946218281984, 0.08259789140096732, 0.040408117430550713, 0.04404396929645112, 0.07703811795051609, 0.15838725385921343, 0.05278806348464318, 0.1114843145811132, 0.03565539013860481, 0.15081071827028478, 0.032459585195673366, 0.08109981500144516, 0.15316461053277763, 0.04267129973907556, 0.02093539902541254, 0.017061951337382197, 0.08561147576464073, 0.053500457400722165, 0.07208068682146923, 0.1291156467050314, 0.12256003490516118, 0.2694276640457766, 6.614233859947749, 65.8500165939331, 54.10743590763637, 50.46248040880476, 54.81462703432356, 54.325838633946006, 28.54395716530936, 30.94608838217599, 20.57839117731367, 39.186662333352224, 44.33681998934065, 58.012702192579, 34.79519237790789, 22.92735651561192, 24.08028847830636, 27.782512766974314, 39.095578398023335, 46.67192193440029, 54.36088534763881, 59.91576862335205, 59.26635524204799, 55.89447089603969, 56.08067914417812, 55.62520735604422, 55.87717682974679, 57.85800402505057, 51.87715796061924, 54.79772554125105, 54.05725949151175, 55.13009262084961, 54.848367486681255, 54.78110197612217, 50.477867194584434, 43.492547852652415, 42.454136099134175, 42.62972749982561, 40.97652523858206, 40.556353773389546, 39.85099349703108, 41.04552085059029, 42.718157223292756, 42.469887665339876, 48.47498294285366, 53.70259911673409, 51.428359917231965, 51.36438437870571, 51.65271030153547, 50.83808265413557, 52.968841552734375, 49.824628829956055, 49.33860581261771, 46.292765685490195, 43.98046425410679, 42.2921701158796, 41.79126753125872, 43.86980029514858, 48.348195689065115, 47.243202822549, 46.056262901851106, 39.83183036531721, 32.36458049501692, 42.724271638052805, 36.706238814762656, 32.861168248312815, 30.97649369921003, 23.14905616215297, 14.516321539878845, 12.092753393309456, 0.5585712758558137, 1.1007609793118067, 1.0909792184829712, 0.632495331977095, 0.23585698114974157, 0.6115044440541948, 0.8784697588000978, 0.8178911294255937, 1.817109831741878, 0.17713778199894087, 0.10415159698043551, 0.0761662343783038, 1.2542066254786082, 2.4102877506187985, 1.999213648693902, 5.35855975321361, 30.469904014042445, 29.9718154498509, 26.93630381992885, 22.701619965689524, 27.07314338002886, 37.768257072993684, 32.535130977630615, 34.91529893875122, 33.90654557091849, 40.017538343157085, 39.05943734305245, 40.19564846583775, 37.87602015904018, 38.409398623875205, 37.971926144191194, 40.64388370513916, 42.18377126966204, 46.458045959472656, 45.433721678597585, 47.79987164906093, 46.42415612084525, 46.20898083278111, 45.95130341393607, 45.415249892643516, 40.42881958825247, 42.02461930683681, 41.356716769082205, 41.987199783325195, 40.724298681531636, 41.50704451969692, 42.12059129987444, 41.05849313735962, 41.990910121372764, 52.4953739302499, 51.978990759168354, 53.7879090990339, 53.29082802363804, 55.30859184265137, 52.87175784792219, 53.53642947333199, 53.633631297520225, 56.5900376864842, 56.90368284497942, 58.58529281616211, 57.55637577601841, 53.81378766468593, 57.4915178162711, 59.67067091805594, 58.05606589998518, 56.04950605119978, 50.452905791146414, 49.46523673193795, 28.637521607535227, 0.5236351905124528, 1.498542851635388, 19.579281909125193, 58.47879777635847, 43.45956475394112, 40.70344366346087, 18.671798535755702, 30.628885746002197, 29.32260356630598, 38.15616110392979, 27.82790882246835, 47.30640363693237, 61.76097393035889, 38.17012003489903, 60.63285745893206, 0.9801693473543439, 0.05635608559740441, 0.061439934585775645, 0.048724334221333265, 0.05235619969399912, 0.045440065275345526, 0.10808258104537215, 0.045463094753878455, 0.021353369811549783, 0.06658346751438719, 0.04448283217581255, 0.1680000051856041, 0.12524972057768277, 0.2058027788464512, 0.3323346727660724, 0.1277039274573326, 0.1077330337305154, 0.1325511916407517, 0.17967992701700755, 0.2549154556223324, 0.14319860030497822, 0.26003280388457434, 0.2570663302072457, 0.4515113149370466, 7.424125875745501, 73.21926212310791, 60.36515726361956, 52.743664332798545, 66.13191195896694, 65.25996167319161, 42.492003781454905, 40.5198792048863, 20.830068826675415, 39.66436488287789, 49.02207020350865, 60.67385877881731, 37.2571371623448, 25.681382724217006, 26.941033806119645, 32.73853949138096, 45.425300461905344, 55.14250905173165, 58.97633048466274, 62.007919856480186, 58.46349089486258, 57.829815183367046, 58.161209515162874, 56.809875215802876, 58.02171400615147, 60.34258951459612, 53.771351541791645, 57.613917282649446, 56.65599346160889, 56.95818451472691, 57.24662855693272, 54.49771622249058, 52.222056116376606, 45.62905291148594, 45.57721240179879, 45.5675995690482, 42.159438678196494, 43.171982288360596, 40.52993672234671, 43.28321599960327, 43.8546393258231, 44.61503280912127, 49.43798589706421, 54.35891900743757, 52.07720354625157, 52.69235188620431, 53.45201928274972, 52.66122395651681, 54.34135743549892, 51.36762571334839, 51.603593485695974, 48.76817607879639, 45.06860079084124, 44.45634290150234, 43.63472536631993, 45.92671026502337, 49.758957930973594, 50.89243493761335, 48.09630611964634, 43.21882356916155, 35.36707081113543, 42.14394766943795, 40.887567452022004, 44.07263558251517, 38.31450360161917, 37.34422240938459, 25.49019956588745, 14.338815910475594, 0.6166889944246837, 1.313638584954398, 1.4663178665297372, 1.6918193719216754, 1.352200218609401, 2.0140135288238525, 1.563849838716643, 0.9818194359540939, 2.0718190670013428, 0.5809416526130268, 0.1371824238449335, 0.1672485547938517, 2.55106172817094, 8.641630922045026, 5.158772553716387, 9.011581676346914, 37.91086884907314, 31.497257709503174, 30.561356203896658, 27.19399687222072, 27.556409699576243, 39.356795924050466, 36.85583700452532, 38.667058672223774, 38.0659213747297, 45.318555286952424, 44.77217326845442, 45.29142257145473, 41.278733662196565, 40.70023706981114, 40.2728533744812, 42.945561340876985, 44.84893696648734, 49.667644705091206, 48.47982931137085, 52.24915061678205, 49.54351166316441, 48.805852685655864, 48.949916635240825, 50.28293548311506, 44.46285683768136, 44.31338718959263, 45.346650327954976, 46.511081559317454, 44.09009640557425, 45.30522864205496, 46.3469512122018, 45.055736201150076, 43.82879202706473, 55.0519323348999, 57.3684652192252, 58.791848863874165, 56.559976305280415, 58.06039115360805, 55.62060764857701, 55.220308031354634, 56.905180181775776, 59.88991437639509, 59.08522960117885, 61.62604686192104, 58.87292044503348, 56.7352237701416, 60.954218591962544, 61.09095914023263, 62.90986551557268, 60.47209003993443, 56.208161217825754, 56.050190448760986, 39.30874218259539, 1.2824345507792063, 1.4906021463019508, 19.624858617782593, 61.63911642347063, 49.52433116095406, 43.76591777801514, 16.909184728349956, 42.204289300101145, 40.78368493488857, 50.60654435838972, 37.78470345905849, 58.72752244131905, 79.10524790627616, 43.992866788591655, 76.23559325081962, 2.428651188101087, 0.09924380747335297, 0.12524687073060445, 0.10415211266704968, 0.11244402094078915, 0.09670359628008944, 0.1637675887239831, 0.20983147195407323, 0.12037834125970091, 0.16824047799621308, 0.1924047384943281], [0.04412779211997986, 0.07103412797940628, 0.08640032700662102, 0.09474963934293815, 0.11406132951378822, 0.06125384635691132, 0.09591716062277555, 0.07576899962233645, 0.1476308453295912, 0.08922599788222994, 0.06436965202114411, 0.3182296667780195, 0.38369182124733925, 8.951327766690936, 65.16844000135148, 49.35510083607265, 34.64073044913155, 44.482040813991, 53.180518422807964, 28.24826615197318, 31.565801688602992, 18.346167734691075, 22.967718601226807, 38.206073488507954, 53.82999781199864, 38.04084880011422, 21.519548995154246, 21.395641769681657, 30.016596589769634, 35.129185335976736, 36.06450319290161, 42.37697982788086, 48.99634449822562, 54.808741910117014, 54.86348329271589, 57.825458662850515, 58.07760531561715, 55.11432021004813, 53.04186364582607, 50.84470428739275, 48.3759572165353, 48.12644740513393, 52.69852188655308, 52.833438532693044, 51.65756014415196, 47.75267253603254, 42.38412257603237, 41.34341791697911, 40.31633520126343, 40.86016375677926, 39.37364877973284, 38.86431108202253, 37.98312316622053, 37.34725877216884, 39.58386305400303, 47.03021969114031, 48.047807693481445, 48.522366183144705, 50.69057239804949, 49.183966704777305, 49.743671894073486, 51.00005905968802, 49.11719799041748, 48.547723633902415, 45.221742561885286, 42.993403162275044, 40.3963680267334, 39.09603697913033, 41.19297552108765, 41.40350593839373, 43.73997320447649, 43.96311807632446, 39.58671876362392, 27.725864103862218, 34.932641642434255, 35.24461228506905, 25.479619196483068, 22.529012816292898, 10.033177920750209, 8.662809899875096, 10.391561661447797, 3.115618931395667, 1.133484497666359, 0.28667936261211124, 0.24547966622880527, 0.09075637254863977, 0.049537493980356624, 0.05090656051678317, 0.3926115983298847, 0.22139970692140715, 0.13362023713333265, 0.20119110202150686, 0.48490392310278757, 1.489899075457028, 2.4479009551661353, 2.8201593799250464, 7.495495166097369, 34.9394474029541, 26.114660229001725, 17.740177120481217, 27.904372010912212, 18.080112525394984, 25.569671324321202, 30.150130544389995, 30.55129521233695, 30.452526569366455, 32.24531119210379, 35.05202211652483, 34.37498269762312, 32.652465207236155, 34.36280945369175, 36.10710607256208, 37.298065526144846, 39.08766439982823, 41.633498259953086, 43.69662339346749, 43.16774736131941, 44.219207831791465, 44.36986909593855, 43.49806472233364, 43.31705025264195, 38.432817527226035, 35.960325377328054, 37.61302042007446, 37.49798257010323, 37.407235622406006, 37.81064803259713, 39.1557046345302, 38.08230870110648, 44.242293221609934, 50.07062632696969, 51.13328381947109, 46.85828651700701, 50.9489620072501, 51.90572895322527, 50.66825825827462, 50.19593708855765, 53.15358025687081, 52.61526162283761, 52.898268699645996, 53.442937987191335, 54.66023458753313, 53.76431996481759, 54.34565837042672, 56.12851054327828, 55.188478333609446, 53.94443464279175, 46.1305148260934, 44.049275738852366, 13.377373695373535, 0.386337049305439, 1.4730753153562546, 24.06447958946228, 52.90698521477835, 41.46198892593384, 32.31789207458496, 16.977829456329346, 40.83179078783308, 27.53101055962699, 38.26231568200247, 24.166607686451503, 32.580186571393696, 42.16072409493582, 36.77458477020264, 48.44342075075422, 0.7272529101797512, 0.010963467731406646, 0.059530469189797125, 0.006821097107604146, 0.029853155769939934, 0.10111076943576336, 0.06562967119472367, 0.06156575533428362, 0.05359655153006315, 0.09221213550439902, 0.04628541473565357, 0.05367885782782521, 0.08716365854654994, 0.08343250304460526, 0.04371441162324377, 0.07168105683688607, 0.09442650061100721, 0.07178573443421296, 0.02654974365473858, 0.03140536569324987, 0.12802787364593574, 0.1825640265430723, 0.2626288245831217, 0.3692571558058262, 11.200219069208417, 73.01083006177629, 52.0469754082816, 36.401442187173025, 47.64238725389753, 57.667873518807546, 29.839212553841726, 32.600652490343364, 20.681790794645035, 28.282670157296316, 44.76852546419416, 57.38912568773542, 42.93353400911604, 25.1242744241442, 22.33020227296012, 37.30481570107596, 44.89835255486624, 46.16408852168492, 49.35317618506295, 53.027974196842735, 57.029337542397634, 58.16806391307286, 60.56150640760149, 61.94945771353585, 58.722526686532156, 56.34326546532767, 55.57012551171439, 50.164875166756765, 50.5873430115836, 56.44372599465506, 53.36332900183541, 51.962947368621826, 48.98346253803798, 45.710048062460764, 43.05302218028477, 43.71192332676479, 42.71641322544643, 42.21397508893694, 41.336327280317036, 38.879072529929026, 38.233914920261924, 41.20244591576712, 47.21337420599801, 50.69662427902222, 50.19800417763846, 50.380988461630686, 49.735935074942454, 50.617362703595845, 53.4968455859593, 51.814648491995676, 49.39436163221087, 49.09098938533238, 46.15962430409023, 43.76389585222517, 40.7035722051348, 43.58258260999407, 45.62683991023472, 48.07122312273298, 46.985580989292686, 41.262082304273335, 34.32256201335362, 40.33063111986433, 38.67017841339111, 32.73821292604719, 29.52719327381679, 18.68211661066328, 15.020426375525338, 10.227435656956263, 3.188588695866721, 1.091608139021056, 0.3374883362225124, 0.20376203049506458, 0.08497899291770798, 0.04326962513316955, 0.04594740251611386, 0.5866532347032002, 0.5365295271788324, 0.19729542891894067, 0.10094680823385715, 0.08095138546611581, 0.7771266996860504, 1.4704304401363646, 2.0987737349101474, 12.35513995374952, 41.82857240949358, 30.781537669045584, 22.61884433882577, 32.49999393735613, 24.635183777127946, 30.821305683680944, 34.17828266961234, 34.971384797777446, 35.46691295078823, 37.28513840266636, 38.06325674057007, 39.92419624328613, 36.05661351340157, 37.306698662894114, 40.4732984815325, 40.58470589773995, 42.037904262542725, 44.068852288382395, 46.7718266078404, 47.41118247168404, 45.53602000645229, 47.792781012398855, 47.3522686958313, 47.162892069135395, 41.135837009974885, 39.10085208075387, 41.14343139103481, 40.931532178606304, 40.52285998208182, 39.54398039409092, 40.37037134170532, 41.42663649150303, 47.88752664838518, 52.528454303741455, 54.029018538338796, 48.242430210113525, 52.105190890175955, 53.36540651321411, 52.259277616228374, 54.51520831244332, 56.067630427224294, 56.46321221760341, 54.767212527138845, 56.48818056924002, 56.50107989992414, 57.34665134974888, 56.56785903658186, 60.48553480420794, 57.56420292173113, 58.65553910391671, 52.36890976769583, 49.37735939025879, 14.438366225787572, 0.3042915532631533, 2.1131482550076077, 29.51961973735264, 59.2660425731114, 43.607120173318044, 40.126479148864746, 22.164135115487234, 34.682777472904746, 26.43351479939052, 35.32619455882481, 26.234315156936646, 34.70432036263602, 47.971127373831614, 37.58381366729736, 58.89289651598249, 1.9666250773838587, 0.07514738012105227, 0.07481704213257347, 0.02446098725444504, 0.040077161975204945, 0.10604272157485996, 0.2161678626601185, 0.064350836245077, 0.023111469311905757, 0.027467368968895504, 0.01271393964998424, 0.17125116501535687, 0.17111380238618168, 0.15721148837889942, 0.13300908064203604, 0.23332751116582326, 0.1822415188487087, 0.24141909554600716, 0.14655467521931442, 0.2770085015467235, 0.2258801550737449, 0.27873941723789486, 0.6459812968969345, 0.5763021015695163, 14.057970591953822, 82.51579897744315, 59.87856796809605, 42.89460672651018, 56.36220278058733, 68.6108763558524, 42.31319189071655, 41.80526120322091, 25.982470750808716, 29.649971417018346, 48.29487173897879, 63.78241334642683, 43.756464753832134, 27.862196445465088, 28.399934904915945, 41.83351952689034, 50.12113625662667, 52.7241781098502, 56.43469681058611, 60.4629670551845, 60.66877964564732, 60.85081550053188, 62.71703216007778, 63.29739434378487, 58.59566647665841, 56.39037772587368, 56.0321181842259, 51.03218752997262, 50.15563406263079, 58.56583091190883, 54.732148442949565, 54.643385205950054, 51.547108105250764, 46.82341003417969, 45.076994214739116, 45.50946399143764, 47.476318359375, 43.39484575816563, 43.02134881700788, 40.27165481022426, 39.54408809116909, 42.63329887390137, 49.25620017732893, 51.72034059252058, 52.47963278634207, 55.48988424028669, 51.392951897212434, 52.66270739691598, 54.82845742361886, 53.81313453401838, 52.66262401853289, 52.201593671526226, 48.02366617747715, 45.34467009135655, 43.14965077808925, 46.66548442840576, 46.674121039254324, 51.89592504501343, 51.737811837877544, 44.89600058964321, 34.99128443854195, 41.078041894095286, 44.78986685616629, 37.61302042007446, 36.7796083177839, 25.91659140586853, 23.735086338860647, 22.84355776650565, 8.342744605881826, 2.5333624950477054, 0.4442415450300489, 0.9930370854479926, 0.16605516097375325, 0.20575263510857308, 0.35246208416564123, 1.1398346083504813, 1.2105593447174345, 0.45790680604321615, 0.3008646528635706, 1.0717435649463107, 2.6760913048471724, 7.524231178419931, 8.039350645882742, 14.919262341090612, 47.73836619513375, 32.09485142571585, 25.39985040255955, 40.25427736554827, 31.35394069126674, 38.243829999651226, 39.2902113369533, 39.965569291796, 39.8946316582816, 42.105065550122944, 43.34939064298357, 43.6979261807033, 39.427205494471956, 40.96651635851179, 44.785162925720215, 44.85581568309239, 45.89824002129691, 46.81147650309971, 50.24733986173357, 48.29856123243059, 48.52244956152779, 49.70779487064907, 51.14847605569022, 52.011001110076904, 43.20454502105713, 41.62594904218401, 43.66744443348476, 45.171388966696604, 43.3102479662214, 43.80963584354946, 44.64533737727574, 44.13128185272217, 49.15483290808541, 56.2434789112636, 57.16921172823225, 51.332043988364084, 55.03730985096523, 55.90012672969273, 56.69322885785784, 56.30912201745169, 58.521695954459055, 59.49782752990723, 58.79116794041225, 58.59090001242501, 59.013301849365234, 58.36062281472342, 59.89093576158796, 62.44343294416155, 60.990870339529856, 63.68283871241978, 56.3610007422311, 57.75448281424386, 18.990251847675868, 0.5010055590953145, 2.4438592748982564, 29.403206144060405, 64.12695366995675, 52.322846685137065, 42.15273019245693, 23.07037649835859, 51.54551001957485, 37.01505844933646, 48.55003390993391, 38.41657611301967, 41.5902943611145, 59.81957081386021, 47.73361710139683, 69.78437151227678, 2.970440447330475, 0.18109444182898315, 0.16882993493761334, 0.05025226616167596, 0.27369773920093265, 0.19253588574273245, 0.35989063126700266, 0.24753560019390924, 0.08397693918751818, 0.20911705600363867, 0.10447645240596362], [0.055138027029378076, 0.05311093758791685, 0.045277383111949475, 0.11914025912327425, 0.11012925979282175, 0.23572045990398952, 0.12818529377026217, 0.019574128856350268, 0.2056135218590498, 0.19008813851646014, 0.14844462594815663, 0.31370845224176136, 0.07884289896381752, 5.798665165901184, 58.74369089944022, 46.95665563855852, 51.27299124853951, 47.63626936503819, 49.40173714501517, 30.316119534628733, 28.6757002217429, 21.4058313029153, 20.082503455025808, 30.22840894971575, 54.6395845413208, 45.903666564396445, 24.673789705548966, 18.164048501423427, 32.62115315028599, 44.224585737500874, 45.58347620282854, 45.38416365214756, 45.707876750401084, 52.11081198283604, 51.85753277369908, 54.33036538532802, 57.473865917750764, 56.78299610955374, 54.2933349609375, 50.276386805943076, 48.33891289574759, 54.97517211096627, 55.35201113564627, 48.8716972896031, 49.14334058761597, 48.66555118560791, 44.73235314232962, 44.43378904887608, 41.32826042175293, 41.5151287487575, 41.79161146708897, 40.0262895992824, 36.84651599611555, 36.67825494493757, 38.90409299305507, 42.63707174573626, 46.522598198481965, 50.9116883959089, 43.94749157769339, 48.81682389123099, 53.041908809116904, 51.23705863952637, 49.13799047470093, 46.94413845879691, 47.18178422110421, 42.786902700151714, 40.42589439664568, 39.897101742880686, 39.03343718392508, 42.4332845551627, 42.04699945449829, 42.00120735168457, 40.06272595269339, 30.253130640302384, 34.70322949545724, 30.200828075408936, 21.22021538870675, 16.497444902147564, 9.041035958698817, 5.232234554631369, 3.132083990744182, 2.05997325692858, 0.5413459315896034, 0.32846924875463757, 0.16045168308275087, 0.05445101710834673, 0.05421068679009165, 0.07938135042786598, 0.055708919252668104, 0.013159045051517231, 0.04004983397732888, 0.102106777418937, 0.16562939382025174, 0.052173066485141, 0.27994148273553165, 0.8302902983767646, 11.96671393939427, 27.77030999319894, 28.075228214263916, 31.80222109385899, 28.698634488242014, 34.42179618562971, 26.832212856837682, 30.51972607203892, 29.877292156219482, 29.27501882825579, 28.05062985420227, 31.56117766244071, 35.459440163203645, 33.39372682571411, 35.61043841498238, 34.63080842154366, 35.712847914014546, 38.071990626198904, 42.35883460726057, 42.4867787361145, 42.60280670438494, 42.4674141066415, 45.36372900009155, 45.78945902415684, 45.3291061265128, 39.87705966404506, 37.3193096433367, 35.76010608673096, 37.81735304423741, 37.463126931871685, 38.21757970537458, 40.621284689222065, 41.924798011779785, 47.26785503114973, 49.02093069893973, 52.86668218885149, 50.80762869971139, 47.79886416026524, 51.255620752062114, 50.53587770462036, 50.932473931993755, 52.042479923793245, 51.40249177387783, 53.44490780149187, 54.96274873188564, 54.84130464281355, 57.16937501089913, 53.36652864728655, 57.80791793550764, 55.12947770527431, 56.16724327632359, 49.60953344617571, 42.56034278869629, 10.01465402330671, 0.15704693006617682, 2.4065059764044623, 32.77167892456055, 50.44139610018049, 35.5530115536281, 28.183493307658605, 30.383398941584996, 53.0085574558803, 29.06825433458601, 33.07680559158325, 23.860138280051096, 29.957474367959158, 54.27756255013602, 40.7993357522147, 50.492385455540244, 2.9378703321729387, 0.08093383176518337, 0.18130334919052465, 0.03986922831141523, 0.07811362309647457, 0.16334403359464236, 0.2188036319400583, 0.23303734245044844, 0.17322722183806555, 0.05811032932251692, 0.17778803567801202, 0.08916330124650683, 0.07501586646373783, 0.102627783747656, 0.09771615373236792, 0.15855018368789128, 0.12159256610487189, 0.05128840949120266, 0.023600248619914055, 0.06628868476088558, 0.2577796605016504, 0.13106551207602024, 0.19505282997020654, 0.27724278611796244, 8.873441934585571, 67.94516944885254, 53.82345955712454, 56.73659256526402, 52.93187713623047, 56.06091151918684, 28.332367147718156, 30.366521767207555, 25.726129123142787, 23.29318959372384, 35.428305285317556, 57.10540642057146, 52.23274939400809, 26.575079134532384, 18.268344436373027, 32.728277002062114, 50.10641302381243, 54.977749892643516, 52.827511719294954, 53.083038670676096, 57.049765246255056, 56.02952650615147, 57.49902187074934, 58.8456974029541, 57.181339808872764, 56.19837468011038, 54.04113619668143, 49.79012754985264, 58.77641691480364, 55.61989198412214, 51.11729948861258, 50.91940089634487, 51.222564697265625, 47.53733049120222, 47.070630414145334, 42.76290014811924, 44.0497864314488, 43.75709703990391, 43.00331824166434, 39.81624208177839, 39.01347500937325, 40.94792645318167, 46.19135672705514, 50.17440809522356, 52.96508605139596, 45.19903932298933, 50.432189737047466, 54.24005617414202, 52.857569626399446, 50.993402685437886, 49.156483105250764, 49.46538264410836, 46.323028564453125, 44.38943869726998, 43.44654382978167, 41.926889419555664, 46.89701577595302, 45.263702733176096, 43.617125579289024, 42.58120822906494, 34.53661864144461, 41.30878809520176, 38.62866292681013, 26.284833771841868, 20.226164409092494, 14.407557044710432, 13.428671377045767, 5.527452221938542, 0.8214020324604852, 0.4951607127274786, 0.4318652291383062, 0.23762850037642888, 0.04498280731162854, 0.023189336294308305, 0.01598230712780995, 0.1042352399921843, 0.018653511202761104, 0.03714875750509756, 0.09373045260352747, 0.14408437348902225, 0.0392694169256304, 0.24496104834335192, 0.13445003117833818, 12.542938470840454, 31.410453864506312, 35.02996506009783, 47.45857613427298, 41.66309411185128, 38.21546050480434, 30.20328426361084, 34.86575133459908, 33.65965870448521, 34.5069637298584, 34.906262806483674, 36.83719846180507, 35.989507811410085, 37.03724752153669, 37.783352034432546, 37.680362360818044, 39.04760456085205, 43.22427443095616, 43.69949647358486, 46.114342893872944, 45.39163643973214, 44.752690519605366, 49.68454967226301, 49.78166116986956, 48.81491661071777, 43.641659668513704, 39.68859672546387, 39.175607749394004, 41.894851275852744, 40.931893484933035, 40.75741727011544, 43.16231039592198, 45.15625926426479, 49.33931105477469, 52.60005896432059, 55.349468094961985, 53.393887179238455, 48.16334581375122, 52.235559940338135, 52.512855597904746, 54.392451013837544, 53.555377210889546, 54.96232141767229, 55.398817675454275, 56.28051628385271, 55.87756245476859, 58.840958731515066, 56.82178095408848, 61.170578547886436, 58.331377846854075, 57.97923271996634, 53.970903805324006, 50.28795208249773, 14.188727004187447, 0.0708685518641557, 3.525266481297357, 39.588428020477295, 54.51521526064192, 38.9607173374721, 34.208243301936555, 29.932537283216202, 42.82153947012765, 24.77259135246277, 32.94688817432949, 28.118440798350743, 32.341255392347065, 63.11550440107073, 50.32296405519758, 60.4061655317034, 7.7799005678721835, 0.1464906350842544, 0.11608701438776084, 0.08555122864033494, 0.12355731853416987, 0.19445935610149587, 0.23829303043229239, 0.18925630886639866, 0.09281098337045737, 0.10337027747716222, 0.08404307599578585, 0.25228640383907724, 0.14184927913759435, 0.1714981517621449, 0.4238760492631367, 0.3824941526566233, 0.3486183461334024, 0.37899174488016535, 0.1315899517919336, 0.30200033049498287, 0.6860826079334531, 0.2588786972420556, 0.4144675098359585, 0.5317402641688074, 11.32514681134905, 77.41894790104458, 56.66819797243391, 62.0053768157959, 66.32250799451555, 66.51001902988979, 40.637602533612935, 38.94422231401716, 30.123095103672572, 24.87281390598842, 39.314596039908274, 62.58637128557478, 55.30328689302717, 29.820928369249614, 22.89200929233006, 39.48282582419259, 52.725803988320486, 58.981256757463726, 58.76857934679304, 59.58310971941267, 63.24650573730469, 60.759099279131206, 61.936138016836985, 62.91816166469029, 58.8845864704677, 56.481503350394114, 51.38135535376412, 49.80800526482718, 59.66732883453369, 59.07090241568429, 53.74914857319423, 53.05304677145821, 54.242359501974924, 51.73701626913888, 50.11132192611694, 45.400901862553184, 46.28904492514474, 45.36025490079607, 43.326152392796104, 41.266008036477224, 40.38593183244978, 41.80855464935303, 44.45283753531319, 50.44300808225359, 55.039620126996724, 46.687517166137695, 52.85660382679531, 57.10604565484183, 56.91535929271153, 53.22641127450125, 50.89724309103829, 53.95570462090628, 48.32616295133318, 46.92182431902204, 45.583952154432026, 44.8834035055978, 48.816591126578196, 48.22808218002319, 46.94668844767979, 46.30179486955915, 35.65760973521641, 43.143605845315115, 41.955522945949006, 34.1541793687003, 27.30734978403364, 16.0846072605678, 20.69568545477731, 18.22253496306283, 12.258300304412842, 1.8838366397789545, 2.4760207491261617, 1.2602615462882178, 0.12847486537482056, 0.1080135740339756, 0.2919360005429813, 0.46457658814532415, 0.22465804565165723, 0.18724585031824453, 0.17782648147216865, 0.35790062376431053, 0.0944210859015584, 0.4218214180852686, 3.6738196185656955, 19.222285202571324, 36.327113832746235, 38.69502517155239, 46.61500576564244, 47.350535120282856, 53.87484843390328, 38.506951332092285, 39.65849018096924, 36.62291601725987, 37.9518632207598, 36.16651317051479, 39.59779071807861, 41.86121504647391, 40.502175194876536, 44.19738701411656, 39.90096494129726, 42.98826149531773, 46.67745964867728, 47.05432994025094, 47.23181472505842, 48.10049588339669, 49.53354794638497, 53.79297433580671, 54.22775091443743, 50.82685089111328, 47.409170968191965, 43.982156140463694, 43.265379973820274, 45.36004645483834, 43.6224478994097, 42.63151666096279, 46.01301383972168, 45.62003762381417, 51.865009035382954, 55.52296461377825, 60.93713297162737, 53.489345005580354, 51.72734785079956, 55.812440463474815, 54.050575324467246, 55.122001443590435, 55.50045245034354, 56.72094522203718, 58.484780175345286, 58.441569328308105, 58.93399511064802, 61.713552474975586, 57.56841353007725, 63.7366247177124, 60.92939267839704, 61.677963801792686, 57.995547090257915, 55.30813326154436, 15.032646519797188, 0.262905802577734, 3.7884774889264787, 42.04251439230782, 60.758842195783345, 45.357805660792756, 38.417493275233674, 38.13893304552351, 65.50501768929618, 38.80033206939697, 42.5388902255467, 38.81531585965838, 42.96665954589844, 73.56938185010637, 52.929455689021516, 76.30813939230782, 9.920535462243215, 0.2832170698259558, 0.34470936017377035, 0.17614233041448252, 0.14765973735068524, 0.3932867949562413, 0.6031363159418106, 0.43432803984199253, 0.19597863672035082, 0.19768455518143518, 0.2808489826108728], [0.06965998600104026, 0.10100542687411819, 0.14355256488280638, 0.10439804089920861, 0.08815365470945835, 0.14024866931140423, 0.17898718347506865, 0.10830181570989744, 0.11959787671055112, 0.1122484535777143, 0.08405772556683846, 0.14523472104753765, 0.03420994430780411, 4.889998861721583, 63.87453951154436, 43.98664467675345, 37.64451313018799, 36.42645570210048, 42.44632979801723, 40.00822080884661, 29.26331458772932, 24.94905996322632, 23.80537257875715, 27.7792557988848, 53.9254104750497, 52.34279843739101, 23.59147228513445, 10.582644070897784, 27.453647579465592, 49.44277320589338, 52.91307183674404, 49.83196265356881, 50.3258684022086, 51.927136353084016, 52.86256538118635, 50.63009180341448, 54.44128295353481, 55.203243255615234, 55.60666956220354, 54.17802613122122, 52.81791973114014, 55.638005937848774, 53.952946186065674, 49.796672752925325, 48.16538511003767, 48.4546559878758, 46.75180884769985, 44.726165771484375, 41.526429993765696, 40.01627377101353, 42.098228522709434, 41.61411278588431, 36.36424500601632, 36.15709488732474, 36.23328535897391, 42.916524818965364, 49.13642018181937, 49.918269702366416, 49.76951571873256, 49.711341926029746, 53.051618916647776, 51.29220649174282, 50.641003949301584, 48.85126263754708, 44.170810154506135, 43.17437594277518, 42.91927283150809, 38.1078850201198, 39.04190008980887, 40.945168018341064, 40.31486218316214, 40.893845149448936, 35.889693464551655, 30.966384070260183, 35.817421776907786, 26.435802493776592, 15.232219627925328, 7.713800617626735, 4.89876879113061, 5.663100165980203, 1.7021523203168596, 2.670953546251569, 0.6153647654822895, 0.1511407577033554, 0.039256219419517686, 0.04289515522707786, 0.007767602568492293, 0.049724739111427746, 0.04957345633634499, 0.03602820781192609, 0.026152030531583086, 0.15727961329477175, 0.1340012616877045, 0.11287061590701342, 0.2569589859672955, 0.3552145207566874, 3.7981228913579668, 22.184024333953857, 33.56285640171596, 47.651280948093955, 48.73228863307408, 36.30019998550415, 24.477423191070557, 26.38727801186698, 29.76802131107875, 31.41144745690482, 30.331933634621755, 32.77035181862967, 32.56939949308123, 33.85922833851406, 34.42836223329817, 34.32506683894566, 34.95132882254464, 38.01058939525059, 38.56199843542916, 42.626590388161794, 43.9950624193464, 40.849710191999165, 45.46416173662458, 46.44667175837925, 45.51438331604004, 40.284519399915425, 35.722116810934885, 37.86481271471296, 35.228339603969026, 36.64608131136213, 38.779404095241, 40.14779274804251, 45.66070543016706, 48.561116286686485, 50.44107648304531, 49.499981198992046, 51.41025985990252, 48.05146592003958, 48.14539861679077, 52.094591413225444, 49.845355306352886, 52.03757796968733, 50.219866684504915, 50.794534819466726, 52.89292900902884, 54.637100560324534, 53.103754724775044, 55.00071021488735, 57.11740943363735, 56.7368357522147, 56.536762373788015, 52.235250745500835, 50.21966518674578, 21.493305649076188, 0.23453861474990845, 5.339833923748561, 39.36098568780081, 48.72567742211478, 28.685590982437134, 31.328204563685826, 62.53146662030901, 37.84750475202288, 26.539610317775182, 27.007832050323486, 18.16158710207258, 32.90228073937552, 40.18982934951782, 30.04227713176182, 50.33619689941406, 5.495637723377772, 0.179042321230684, 0.370703005364963, 0.09662784463060753, 0.050140087359717915, 0.12254608422517776, 0.4937989743692534, 0.4930231102875301, 0.14442514734608786, 0.04861731907086713, 0.015997331589460373, 0.04227709464196648, 0.057369409794253964, 0.08389976261449711, 0.08024681505880185, 0.15703562567276613, 0.07912147830107383, 0.1749553826770612, 0.021210188744589686, 0.08991883641907147, 0.1231192834675312, 0.03962566816647138, 0.15628665871918201, 0.07395402701305491, 8.106909717832293, 73.25840132577079, 51.345787525177, 41.40477398463658, 42.3562707219805, 47.09989275251116, 34.0461869921003, 27.415425539016724, 26.27980501311166, 28.33884981700352, 34.95063052858625, 55.449609007154194, 55.400575569697786, 27.54688719340733, 9.640630756105695, 26.51965856552124, 52.32400008610317, 55.75376640047346, 55.16109200886318, 56.09717764173235, 57.63441446849278, 57.01388822283064, 54.68158292770386, 57.59775229862758, 57.26621205466134, 55.270540033067974, 55.62835489000593, 55.84040696280343, 56.621492181505474, 55.58292409351894, 54.0742860521589, 48.8952898979187, 51.31708104269845, 48.11774131229946, 46.25160108293806, 44.27164936065674, 42.19407892227173, 43.47725486755371, 40.946324893406455, 39.49585369655064, 38.19556433813912, 37.93102904728481, 44.20799343926566, 50.714946678706575, 52.723229680742534, 52.04968867983137, 52.699769088200156, 52.39155394690377, 50.9458144732884, 50.69545003346035, 49.251857553209575, 47.98880359104702, 43.789892537253245, 45.355523177555625, 44.70417472294399, 42.86164447239467, 45.92875303540911, 45.19204248700823, 45.62588105882917, 39.83479724611555, 34.679688998631065, 42.369850976126536, 31.587820529937744, 19.769462789808, 12.521554521151952, 8.67984254019601, 8.33728505883898, 3.593577261481966, 0.31927957758307457, 0.6039773736681256, 0.2846598524068083, 0.07001321776104824, 0.005080935952719301, 0.08917871077678033, 0.018198014037417512, 0.012984335854915636, 0.08465035126677581, 0.023531195807403753, 0.055795127126787386, 0.09814101164894444, 0.10188720348690238, 0.1874246442956584, 0.3883487970701286, 3.305938776050295, 27.809308494840348, 43.636962686266216, 50.53072214126587, 59.873315129961284, 43.24240575517927, 28.544169085366384, 30.56138399669102, 32.77289138521467, 36.33455187933785, 36.398346764700754, 36.33635493687221, 36.73922538757324, 37.187495367867605, 38.4792662348066, 37.489967823028564, 37.25776597431728, 40.21933487483433, 41.78155394962856, 44.812302589416504, 47.34938866751534, 43.735422134399414, 48.85591445650373, 49.824104240962434, 48.32693420137678, 43.41112191336495, 39.5515261377607, 41.76400279998779, 37.83659608023507, 38.58138738359724, 41.73615789413452, 43.56823110580444, 48.70525319235665, 53.697141306740896, 53.51979201180594, 52.649029867989675, 51.221748283931184, 50.50982543400356, 50.449254512786865, 54.81778151648385, 52.757008348192485, 53.52008383614676, 53.03712844848633, 53.674615246909006, 55.56058216094971, 55.21517678669521, 55.553272656032014, 56.62599808829171, 56.36709083829607, 57.313115869249614, 58.824296951293945, 56.95138222830636, 56.81817136492048, 30.145437036241802, 0.27221799003226416, 7.482874631881714, 45.89608955383301, 51.268381118774414, 33.89442096437727, 36.720951625279014, 51.76783152988979, 35.073137692042756, 23.586905581610544, 28.345754589353287, 24.212163550513132, 37.12535067967006, 50.04529319490705, 35.98722185407366, 62.74787521362305, 8.442248889378138, 0.11420074131871973, 0.23234051412769727, 0.03711386044908847, 0.18309675795691355, 0.06632584812385695, 0.27023978903889656, 0.14157075408313954, 0.10625766111271721, 0.05954851143594299, 0.06670053516115461, 0.1258018852344581, 0.24790135771036148, 0.1986029523291758, 0.3221116470439093, 0.35312143021396225, 0.23857511101024492, 0.32491817644664217, 0.2142766091440405, 0.3867335037461349, 0.4586552573101861, 0.20493046779717716, 0.2993668003806046, 0.29200778954795426, 11.637059262820653, 82.73894732339042, 53.992769786289756, 47.314970765795024, 49.02023935317993, 58.81447914668492, 50.5918002809797, 39.37699433735439, 33.073807443891255, 30.033463341849192, 37.672712394169395, 63.89262567247663, 59.47518335069929, 29.831152643476212, 13.236516339438301, 32.13963256563459, 56.33927719933646, 61.54357174464634, 60.90226691109793, 61.908164569309776, 63.06371947697231, 62.13339042663574, 58.954374177115305, 62.58967167990548, 59.81152479989188, 54.68939617701939, 54.84293746948242, 54.573833738054546, 57.98189735412598, 57.52132558822632, 54.0740567616054, 52.72023153305054, 55.75223779678345, 52.48209244864327, 50.4624456678118, 47.25470903941563, 47.00522354670933, 44.8646468435015, 44.143635749816895, 39.570710114070344, 38.84785079956055, 38.10917043685913, 44.49123328072684, 50.66022266660418, 54.70410898753575, 52.08239385059902, 54.62394067219326, 56.37496314729963, 54.154523849487305, 52.78393609183175, 54.01616089684622, 49.78298132760184, 47.042914049965994, 49.41875328336443, 44.8850919178554, 45.16997848238264, 48.387856006622314, 48.91062804630825, 49.711762292044504, 42.79592146192278, 38.91847229003906, 46.592632566179546, 41.1418194089617, 28.941637311662944, 13.388574191502162, 9.042437757764544, 15.680838755198888, 14.230239016669136, 8.443819182259695, 2.1646756614957536, 0.8116501271724701, 0.14724937294210705, 0.09470877796411514, 0.17850646855575697, 0.15313936903008393, 0.07682559399732522, 0.16598057640450342, 0.12279448232480458, 0.30006409010716845, 0.2120872073407684, 0.1201392255191292, 0.7344494525875364, 0.40212666775499073, 14.16427195072174, 34.18904195513044, 44.37267964226859, 51.20669501168387, 59.49059445517403, 53.93105936050415, 35.390573092869346, 36.53103303909302, 37.19611460821969, 40.72475726263863, 37.63732521874564, 39.434264864240376, 40.26592949458531, 42.13414028712681, 43.71092626026699, 39.70984779085432, 42.90630749293736, 43.6162987436567, 44.28093215397426, 44.228323868342805, 49.25242035729544, 47.04732963017055, 54.26095288140433, 53.79811947686331, 52.85218129839216, 47.63353872299194, 42.18262134279524, 46.218350478581016, 40.128855432782856, 41.50922277995518, 43.953136989048545, 45.579345498766216, 52.26141766139439, 56.65384646824428, 58.2176844733102, 55.13018642153059, 55.555339745112825, 51.13528142656599, 48.753220081329346, 55.25448969432286, 53.914460114070344, 56.43894910812378, 53.51462255205427, 55.45630707059588, 56.5511451448713, 56.08187770843506, 55.89075013569423, 57.741798877716064, 59.15391949244908, 60.57448564256941, 59.843423979622976, 62.17088290623256, 60.154640742710654, 29.86986800602504, 0.34091184394700186, 8.197247590337481, 48.598702566964285, 59.6256604875837, 40.57338033403669, 40.67755814961025, 69.4701600755964, 46.779872621808735, 34.75922850200108, 35.367720467703684, 29.534117153712682, 46.15508018221174, 60.554134368896484, 41.644490310123985, 76.08313587733677, 14.97895084108625, 0.23225778713822365, 0.484553473336356, 0.21225082927516528, 0.43644148643527714, 0.15051869036895887, 1.0702943227120807, 1.0681389697960444, 0.20325968387935842, 0.15161113174898283, 0.27241856498377665], [0.11095411410289151, 0.08603323277618204, 0.12929138727486134, 0.20209842547774315, 0.11510616487690381, 0.06320174397634608, 0.05627429498625653, 0.04286637516426189, 0.17594129405915737, 0.10521948896348476, 0.04967875818588904, 0.052608010824769735, 0.12819448113441467, 6.8310107077871045, 59.014538628714426, 39.25004380089896, 46.78509419304984, 33.92098045349121, 35.21127135413033, 53.358711923871724, 33.34056268419538, 40.82753154209682, 32.21623298100063, 20.5010438305991, 48.17847204208374, 52.167412008558, 30.257580961499894, 6.821426102093287, 15.947838919503347, 45.205028670174734, 52.27492148535592, 54.79908391407558, 55.192549977983745, 53.272693225315635, 50.2604650088719, 49.77327469417027, 53.2088531766619, 55.43043545314244, 53.183606897081646, 53.520243644714355, 52.9145587512425, 57.79199613843645, 53.22582067762102, 48.80939279283796, 45.64251504625593, 47.31789595740182, 44.92667688642229, 42.17149380275181, 39.92557198660714, 41.1337560244969, 40.7232460294451, 39.64205074310303, 36.77871200016567, 36.18261909484863, 36.40872737339565, 39.46771349225725, 49.37219687870571, 51.80514683042254, 54.50925023215157, 49.64475039073399, 51.22190114430019, 47.9423166683742, 47.35915783473423, 45.69020748138428, 43.544325828552246, 41.71748808452061, 40.56017180851528, 40.81385053907122, 37.8462575503758, 38.092939444950645, 39.595810481480186, 39.87678868430001, 34.73179006576538, 30.197614533560618, 30.06538336617606, 23.025412968226842, 13.611298697335378, 7.172030031681061, 4.061253343309675, 2.56742690716471, 1.0489483709846223, 1.5787944367953708, 0.5521792045661381, 0.12462664901145867, 0.08907599414565734, 0.023134673513205986, 0.022849561580057656, 0.03377144444467766, 0.0746774606938873, 0.03669835274506893, 0.04800659005663224, 0.2218680860740798, 0.1135723093258483, 0.19157619295375689, 0.178384359393801, 0.47655680243458065, 2.0771513751574924, 15.701422793524605, 35.79856089183262, 47.23538957323347, 70.43661975860596, 47.02071108136858, 25.05361819267273, 25.833081007003784, 29.117892265319824, 32.50999934332711, 33.9867764200483, 30.76620646885463, 32.684347016470774, 33.6482150214059, 34.52030774525234, 33.444809981754844, 34.243616580963135, 35.92746387209211, 39.902913911002024, 40.79275928224836, 45.352952344076975, 42.17828219277518, 43.72609765189034, 46.68868098940168, 43.36227260317121, 38.77629477637154, 36.42635842732021, 35.51172188350132, 34.47179889678955, 35.51767996379307, 38.211183888571604, 44.419767584119526, 47.93402746745518, 47.61954157693045, 49.622724601200645, 50.01326894760132, 46.18165356772286, 47.59813417707171, 49.65782342638288, 51.436961787087576, 50.97972168241228, 51.515320096697124, 53.00775146484375, 52.27078035899571, 52.463401794433594, 53.13840191704886, 53.48973063060215, 55.15009995869228, 56.1190436226981, 56.828419957842144, 57.783620085035054, 54.66820069721767, 55.19060795647757, 37.597407817840576, 0.7806003104363168, 11.456635390009199, 48.39721870422363, 40.61897093909127, 23.453965697969707, 32.8391181400844, 76.77987343924386, 33.07284164428711, 22.463116100856237, 26.412274156297954, 16.111826828547887, 45.80388695853097, 49.39345836639404, 27.80694089617048, 49.2054123197283, 5.074554307120187, 0.17001251290951455, 0.28090619668364525, 0.0539735998692257, 0.08192055060395173, 0.05583769841385739, 0.29754599237016266, 0.24595268656100544, 0.29255121467368944, 0.06771489751658269, 0.02119182249797242, 0.08028556619371686, 0.07470036125076668, 0.05978981205927474, 0.20036927397762025, 0.2528965153864452, 0.07204570834125791, 0.09726768279714243, 0.010583578026853502, 0.09132659980761153, 0.01523631894295769, 0.11103249846824578, 0.03972116518499596, 0.2698461301624775, 11.002692205565316, 70.11072840009416, 43.76738037381853, 43.859676769801546, 41.21419184548514, 38.036259514944895, 43.42055409295218, 34.00477572849819, 36.17703969138009, 33.353347369602744, 24.18705449785505, 52.210914679935996, 52.14183221544538, 35.67363575526646, 8.41595082623618, 14.90705783026559, 44.435612951006206, 54.79709325517927, 59.94008037022182, 59.75800977434431, 56.70698629106794, 53.70940487725394, 53.3362067086356, 55.72943033490862, 55.302473953792024, 54.89107458932059, 54.13564906801496, 53.602169854300364, 55.653389249529155, 54.87312739236014, 50.32870674133301, 49.61226061412266, 48.428106921059744, 47.89989791597639, 44.646039145333425, 44.54723228727068, 45.10601684025356, 42.18186051504952, 41.183334895542686, 40.322070939200266, 39.22751426696777, 38.239876474652974, 40.626332555498394, 49.09082610266549, 52.34647750854492, 53.40583113261631, 50.2662215914045, 51.98901006153652, 48.54908200672695, 50.355648381369456, 49.05505677631923, 45.62581157684326, 44.614164284297395, 43.3011770929609, 45.329276357378276, 41.96148450034005, 46.196467127118794, 44.291806084769114, 43.51980216162545, 38.42518145697457, 34.69263349260603, 36.02201495851789, 29.730306489127024, 21.730035986219132, 19.69610892023359, 11.937512397766113, 5.157359029565539, 2.4426976229463304, 1.157010338136128, 0.6706967992441994, 0.3498486658292157, 0.11677207691328866, 0.029838068543800285, 0.04379732181717243, 0.032982158940285444, 0.10277613864413329, 0.11390522574739796, 0.04431464709341526, 0.08221498730459384, 0.06459484422313315, 0.020969249441155365, 0.1353607065975666, 0.29921852690832956, 2.1084412847246443, 22.78664333479745, 45.87233713694981, 53.07506561279297, 68.59035832541329, 49.44796003614153, 32.12434652873448, 27.82623083250863, 33.048866885049, 35.53708280835833, 36.34010696411133, 36.73135655266898, 37.899647508348735, 36.5516483443124, 38.33703660964966, 37.59579930986677, 38.70559338160923, 39.220062323978965, 42.3669570514134, 44.382730211530415, 46.99799394607544, 45.31918062482561, 48.203763484954834, 49.50025217873709, 45.550524371010916, 41.06892933164324, 40.31657491411482, 38.46312556947981, 37.227131366729736, 39.99986212594168, 42.08187593732561, 47.001711232321604, 50.12748343603951, 52.47082247052874, 52.741041387830464, 53.381891114371165, 49.00041961669922, 47.10467658724104, 50.93931095940726, 52.2884635244097, 53.03686441693987, 53.41242497307913, 56.4805896622794, 53.567783219473704, 54.07498434611729, 53.05778544289725, 53.211107867104666, 57.00541489464896, 57.400437355041504, 56.66709668295724, 58.2229824747358, 56.71703686032976, 58.65625476837158, 42.64774070467268, 1.1093870592968804, 14.172358785356794, 55.50051498413086, 45.433832849775044, 29.836752891540527, 35.79800851004464, 65.72533117021833, 31.774522100176128, 21.1802875655038, 27.204016174588883, 25.01311888013567, 46.80949626650129, 53.56601142883301, 37.287122113364084, 64.01612295423234, 11.347325461251394, 0.04051597057176488, 0.21388565083699568, 0.28548592807991163, 0.09347521487091269, 0.15858514181205205, 0.16178125888109207, 0.19897462667099067, 0.17354662184204372, 0.14772043909345353, 0.06357728596776724, 0.2747544082147734, 0.25446536977376255, 0.2784601593656199, 0.3867494357483727, 0.45855570265225, 0.23530478935156549, 0.16422185434826783, 0.16903983296028205, 0.43413886427879333, 0.33035910448857714, 0.3181279408080237, 0.14732527386929306, 0.4968669297439711, 13.516446232795715, 75.89244256700788, 50.44913986751011, 55.797845772334504, 48.662330695560996, 51.075019700186594, 65.5142935344151, 45.7321537562779, 49.79737104688372, 38.63746976852417, 24.437295607158116, 60.40280955178397, 61.12770816258022, 37.37377309799194, 9.246033004352025, 18.57916862624032, 48.86927236829485, 58.29936054774693, 64.65712206704276, 66.71187114715576, 62.30639362335205, 59.278174127851216, 57.69744505201067, 60.730243410382954, 58.23759453637259, 55.244147300720215, 50.705257415771484, 54.26553521837507, 59.10326712472098, 57.688502720424104, 50.32169600895473, 51.44183942249843, 52.97412913186209, 52.03389889853341, 49.17208875928606, 46.84432063783918, 46.81812940325056, 46.41302858080183, 42.13343504496983, 41.3160628591265, 39.10815116337368, 38.154510906764436, 40.57328305925642, 51.99137939725603, 55.24518953050886, 58.6980551310948, 53.275576727730886, 54.346009254455566, 51.75579724993025, 53.396322522844585, 50.927509444100515, 49.31477001735142, 47.262935706547324, 47.290190015520366, 47.916038581303184, 44.58449895041329, 48.34183113915579, 49.620744364602224, 50.826131752559114, 42.94018343516758, 38.86673947743007, 43.826266356876914, 38.570819173540386, 28.942627429962158, 22.467642852238246, 16.582803521837505, 9.560922758919851, 10.453428421701703, 7.347532408578055, 2.2613867691584995, 0.36881301392401966, 0.2896847299167088, 0.07869402838072606, 0.15301659490380967, 0.228868911841086, 0.21867998928896018, 0.23659237740295275, 0.0775774447247386, 0.3818761429616383, 0.3648855446704796, 0.1799964364618063, 0.20327739364334516, 1.1654813864401408, 5.2859853846686224, 33.16867119925362, 43.515709672655376, 53.586355754307334, 69.76750128609794, 59.93389647347586, 35.85861417225429, 34.59260722569057, 35.2400438444955, 41.835298265729634, 41.82713760648455, 39.03258950369698, 40.570225851876394, 41.08730731691633, 44.1613050188337, 42.082014901297434, 42.21680300576346, 41.93165588378906, 44.915455545697895, 45.72530630656651, 50.121132782527376, 50.58468879972185, 53.1645827293396, 54.773736885615754, 51.261769907815115, 44.300828320639475, 44.89837339946202, 43.900313309260774, 39.83573177882603, 42.10177557809012, 44.757575103214805, 50.41015352521624, 53.47523668834141, 55.008002349308555, 58.03688192367554, 57.35998146874564, 51.32593652180263, 48.97881766727993, 51.554587841033936, 53.067026547023225, 54.68756880078997, 55.451057706560405, 56.920605182647705, 55.04205199650356, 55.24442522866385, 55.01775414603097, 54.879273074013845, 57.85267128263201, 57.766374656132285, 59.78604575565883, 60.03789016178676, 61.911673409598215, 64.40365873064313, 47.7792181287493, 1.28626463668687, 15.520818267549787, 59.55872849055699, 52.780152797698975, 32.61520201819283, 38.50029843194144, 81.90360709599086, 40.85587671824864, 30.45891543797084, 34.068768637520925, 25.112333944865636, 58.18735211236136, 68.91101769038609, 42.6235852922712, 78.39310618809291, 17.67214730807713, 0.351491670523371, 0.34797121371541706, 0.4858038233859198, 0.17666843932654175, 0.29748948397380964, 0.536208552973611, 0.6520641733493123, 0.5442283483488219, 0.37246852634208544, 0.2895158018384661], [0.04758918584723558, 0.06022200493940285, 0.00047505705047764683, 0.3412131134952818, 0.09853575618139335, 0.11020141520670482, 0.12316511172269072, 0.02686321665532887, 0.11638727970421314, 0.10778948105871677, 0.056154777828071795, 0.05256790940516761, 0.04729897641975965, 12.80751371383667, 65.16173498971122, 48.68035779680525, 47.67010709217617, 31.025693893432617, 42.9681464603969, 36.87507309232439, 33.89509841373989, 72.77223587036133, 61.219056129455566, 14.764228922980172, 39.04422773633684, 51.312853063855854, 38.51669618061611, 13.855916108403887, 7.474236283983503, 31.491167613438197, 52.642727851867676, 57.40063885280064, 55.53888988494873, 51.23831278937203, 47.37976271765572, 49.46667848314558, 51.652859687805176, 54.88298341206142, 50.926533222198486, 51.943395137786865, 56.33273894446236, 55.111335958753315, 53.345044817243306, 48.17444903509957, 45.436681611197336, 44.140592438834055, 42.53923763547625, 42.862495626722065, 40.68868916375296, 44.33784832273211, 40.423615387507844, 39.66345814296177, 39.3406274659293, 36.69396482195173, 36.90211200714111, 38.820502689906526, 44.436804567064556, 51.63972064426967, 51.246626308986116, 55.17495366505214, 48.946067333221436, 48.45947456359863, 45.94070741108486, 47.119073254721506, 41.14258023670742, 42.1253091267177, 38.75334487642561, 38.99450295312064, 35.81168951307024, 37.73923444747925, 38.4647410256522, 35.79359292984009, 32.482050214494976, 28.438158682414464, 17.767994233540126, 21.641406502042496, 7.305708595684596, 17.190585034234182, 6.2889938950538635, 0.8723328166774341, 1.7984133149896349, 1.5295713352305549, 0.23474336947713578, 0.05714868235268763, 0.13034881624792302, 0.07360706491661922, 0.08613921994609491, 0.1169809028506279, 0.08272866545511143, 0.11026274120169026, 0.1191458095397268, 0.051433022267052105, 0.12491107732057571, 0.18856526166200638, 0.029636658994214873, 0.09438023130808558, 0.9836511548076357, 7.267602937562125, 34.85117053985596, 40.17136798586164, 59.44503511701311, 52.259854316711426, 31.846203190939768, 24.719163179397583, 31.290204865591868, 30.67516769681658, 31.800873143332346, 31.553961958203995, 34.02387980052403, 32.4781870160784, 34.105736528124126, 32.116085120609824, 36.09494325092861, 34.501954078674316, 38.71295499801636, 40.06210061482021, 43.14349814823696, 41.068832056862966, 44.84354863848005, 43.0209492955889, 38.831925528390066, 34.585422788347515, 35.77480500085013, 33.97792441504342, 33.92947810036795, 35.76978840146746, 39.236974239349365, 44.38668721062796, 48.263920988355366, 48.798119340624126, 49.10931525911604, 49.944801398685996, 45.407540866306846, 41.87974936621529, 44.296367577144075, 48.493381772722515, 47.91942582811628, 53.058143275124685, 50.39933865410941, 47.905949796949116, 48.92422219685146, 47.03635842459542, 48.64014162336077, 50.85711029597691, 53.32111174719674, 53.46166338239397, 56.996555941445486, 55.049531732286724, 53.399296351841514, 38.55180542809622, 1.6251594402960368, 18.678315946034022, 51.04155717577253, 30.208905356270925, 19.998652594430105, 40.64402266911098, 64.26616777692522, 37.311208043779644, 22.33449799673898, 25.133209807532175, 16.735507556370326, 45.10000317437308, 55.14911331449236, 31.711717333112443, 45.82695845195225, 10.021405935287476, 0.44338205829262733, 0.20580052611018929, 0.24454453640750476, 0.011711897794157267, 0.10400740150362253, 0.025988756346383264, 0.08356835932603904, 0.04812798675681863, 0.04129532910883427, 0.08359997905790806, 0.06755681921328817, 0.057493344215410094, 0.052831320092082024, 0.19264810186411652, 0.20315339815403732, 0.1801178263766425, 0.2436786171581064, 0.07132361137441226, 0.09177147450723819, 0.09588095399418048, 0.06431030056306294, 0.10394771077803203, 0.45332061499357224, 18.823717423847743, 73.1754537309919, 51.271417481558665, 51.0248259135655, 36.6919915335519, 44.41558824266706, 34.398509298052105, 28.88743962560381, 59.95141288212368, 60.32127244131905, 16.675065176827566, 40.1060722896031, 53.757493359701975, 42.72913885116577, 15.688464403152466, 7.888491358075823, 29.50154399871826, 53.79194252831595, 58.835323742457796, 59.226764406476704, 53.53644336972918, 51.11902959006173, 49.96220663615635, 53.994809082576204, 55.796216419764924, 54.40236609322684, 52.474421637398855, 55.63987847736904, 54.90135097503662, 52.53635440553938, 48.83783524377005, 48.27900900159563, 47.06882388251168, 45.71477631160191, 43.97347436632429, 42.29379252025059, 45.99568155833653, 43.457622732434956, 41.822221755981445, 41.63198355266026, 39.468710558755056, 40.06321580069405, 39.29079845973423, 46.414098603384836, 53.5202054296221, 54.046889305114746, 53.54948513848441, 51.38217524119786, 50.89083685193743, 49.24641363961356, 47.987351417541504, 44.84465340205601, 44.9936158316476, 41.9621376310076, 43.04864134107317, 41.026458467756, 44.9497275352478, 44.19251980100359, 43.35298980985369, 39.11994573048183, 31.764495849609375, 26.839035987854004, 29.310023852757045, 24.88081475666591, 31.047122137887136, 16.692607641220093, 4.594878903457096, 2.219799195017133, 2.1401213790689195, 0.8664550206490925, 0.07346829771995544, 0.12304668022053582, 0.021220731482441937, 0.012153859034047594, 0.06892496972743954, 0.08686424139887094, 0.09950256001736436, 0.06227020360529423, 0.03916792505021606, 0.12597050118659223, 0.18820076622068882, 0.05691100171368037, 0.09344191915754761, 0.9141561410256794, 8.914464967591421, 45.9495906829834, 49.823162760053364, 56.423329557691304, 51.95037112917219, 37.39846352168492, 29.263595989772252, 34.91395098822457, 35.90967648369925, 36.846192904881065, 35.20054333550589, 39.15860898154122, 36.789933340890066, 40.728054182870046, 35.441534655434744, 38.31080715996878, 38.73206949234009, 40.56462560381208, 42.349774156297954, 45.73103509630476, 43.60395874295916, 46.413504532405305, 43.92413520812988, 41.93366043908255, 37.50565685544695, 39.67114632470267, 37.22919845581055, 38.1192626953125, 39.33604860305786, 41.73112392425537, 48.471147537231445, 51.8117858341762, 51.29948125566755, 52.28414174488613, 51.64455311638968, 46.70325483594622, 42.84261335645403, 45.45864486694336, 48.63548285620553, 49.60550001689366, 54.040156500680105, 52.104232038770405, 49.625187737601145, 49.167145115988596, 48.436166831425254, 51.880399295261924, 50.86154672077724, 54.86394534792219, 56.0259690284729, 59.173291070120676, 58.59181022644043, 57.29995250701904, 44.03414256232125, 2.5258069804736545, 23.9619710786002, 54.079559734889436, 35.9665961265564, 24.945328780582972, 41.31901931762695, 55.102845260075156, 29.941580363682338, 23.56771813120161, 26.19228376661028, 24.74346102987017, 49.4113256590707, 47.65675612858364, 32.42179891041347, 59.6878399167742, 25.525367873055593, 0.31116028183272904, 0.14429226304803575, 0.21664015017449856, 0.06531715832118477, 0.2209707370826176, 0.2624102277415139, 0.2191443515143224, 0.23100738280585834, 0.07311783438282353, 0.03998550546488591, 0.146901488038046, 0.25739465973206926, 0.15170026410903248, 0.7000977216022355, 0.5097209885716438, 0.47041014369044987, 0.2922862874610083, 0.10680789194468941, 0.3007023201457092, 0.14081033345844063, 0.3556200675666332, 0.33419421155537876, 1.3357592608247484, 22.25513914653233, 79.47787979670933, 56.26534489222935, 61.09215423039028, 41.04583004542759, 60.3346129826137, 49.18821900231497, 43.34486041750227, 82.23662035805839, 70.6865325655256, 20.278136934552872, 49.43949018205915, 59.80751568930489, 46.39271552222115, 17.079000438962662, 9.624223453657967, 34.09650584629604, 56.897238390786306, 66.39267785208565, 66.12638814108712, 59.30718980516706, 55.75064665930611, 53.5238219669887, 58.52694879259382, 58.657713890075684, 52.18833303451538, 50.60440083912441, 54.86366047177996, 55.757758140563965, 54.04224443435669, 48.32449538367135, 50.52133165087019, 50.32121658325195, 50.789466108594624, 48.10529708862305, 44.49528408050537, 49.25426857812064, 45.97654274531773, 43.28425128119332, 42.75225550787789, 38.45914077758789, 38.8752475466047, 39.727920055389404, 48.54253680365426, 55.238866669791086, 57.37429475784302, 60.14878341129848, 54.18950455529349, 53.01724965231759, 50.078411783490864, 51.821902411324636, 45.522568293980186, 48.82246930258614, 44.62117501667568, 46.11022956030709, 41.06847422463553, 47.79063401903425, 49.15786232267107, 47.467181478227886, 44.26669182096209, 39.36231974193028, 38.30317108971732, 42.79043238503592, 29.63913917541504, 35.83667523520333, 19.911893912724086, 5.233164744717734, 8.816676889147077, 7.417840361595154, 2.2735458995614732, 0.27554712710636003, 0.3157547781510012, 0.19408992092524255, 0.14719019111778053, 0.20768829195627145, 0.22045494190284184, 0.2616468758455345, 0.18261848576366901, 0.21091022049742086, 0.1551434357783624, 0.22400750698787825, 0.1005738718169076, 0.3785128891468048, 0.908782035112381, 26.77331124033247, 41.94864770344326, 43.03411613191877, 58.78517859322684, 56.63576030731201, 43.38271767752511, 35.36087996619088, 40.26892416817801, 43.23449523108346, 41.574733870370046, 38.53317035947527, 42.3784875869751, 42.182874952043804, 46.71174553462437, 40.63560492651803, 42.8557801927839, 41.265347957611084, 42.90147154671805, 44.600531918661936, 46.923936571393696, 46.77144793101719, 51.51741845267159, 51.01769011361258, 44.63134717941284, 40.17298344203404, 42.18613018308367, 40.2205160685948, 39.50117254257202, 40.55948393685477, 45.1765410559518, 51.50623880113874, 54.816058363233296, 53.72213397707258, 56.82465403420584, 58.123043060302734, 51.401974133082796, 43.82117680140904, 45.06621061052595, 50.770292554582866, 50.423389843532014, 56.73146479470389, 54.26770305633545, 51.87171057292393, 52.77687324796404, 50.91647917883736, 52.275254998888286, 52.81390714645386, 56.76302351270403, 57.98143182482038, 61.78820392063686, 62.92092704772949, 63.882078307015554, 48.969649519239155, 3.1713760537760596, 24.129431349890574, 63.117359570094514, 42.602066721235005, 30.5614013671875, 45.43949563162667, 67.42900167192731, 48.62127726418631, 34.27731534412929, 33.80814518247332, 25.11718726158142, 54.953618798937114, 72.91607052939278, 44.34759317125593, 71.74098423549107, 32.22469588688442, 0.7330910797630037, 0.3271923544151442, 0.8259693330952099, 0.24124810472130775, 0.46324752803359714, 0.762400535600526, 0.5633247122168541, 0.41730147919484545, 0.18050600269011088, 0.18567083483295782], [0.05743144825100899, 0.15347718447446823, 0.08861153692539249, 0.05427765480375715, 0.13927446944372995, 0.0592352386031832, 0.12365428118833474, 0.10448776358472449, 0.12157440850777285, 0.24974838431392396, 0.08791550927396331, 0.2021680295999561, 0.23742808827332088, 14.210029312542506, 66.88282462528774, 32.540825026375906, 22.14072663443429, 36.608533246176584, 42.45720372881208, 23.79093074798584, 35.13918031964983, 72.37165137699672, 57.33981432233538, 29.226878234318324, 20.121191024780273, 53.5590250151498, 43.904739311763215, 27.38331617627825, 4.384918238435473, 18.28788103376116, 49.33246013096401, 54.431760447365896, 57.78117779323033, 53.15719679423741, 50.37838288715908, 47.42000320979527, 46.29573604038784, 52.46504851749965, 52.28994696480887, 52.002100467681885, 55.52868298121861, 56.989798818315776, 49.92776094164167, 47.87472459248134, 45.18473993028913, 45.87556804929461, 43.181233814784456, 40.83417749404907, 40.60363973890032, 44.091663224356516, 42.779871123177664, 42.09141928809029, 38.23302902494158, 42.19446107319423, 38.362039702279226, 40.67661666870117, 43.31254781995501, 51.62187419618879, 53.83784580230713, 51.40209572655814, 48.50514507293701, 48.52593755722046, 47.013519695826936, 43.36847039631435, 40.4233409336635, 42.34631395339966, 38.77322367259434, 38.952653953007285, 38.57537371771676, 37.79792935507638, 39.95532069887434, 35.306399141039165, 36.27941792351859, 23.034176383699688, 12.472681760787964, 17.803379671914236, 18.178743941443308, 28.931647539138794, 11.0517213003976, 0.23085145545857294, 3.037886393921716, 0.8052121869155339, 0.9302387237548828, 0.3363544227821486, 0.21580784554992402, 0.022450555847691636, 0.10994649638554879, 0.16067729597645147, 0.2144149217222418, 0.1351872594760997, 0.11134596129081079, 0.06818384663867098, 0.13425117970577308, 0.034822949807026556, 0.05296032316982746, 0.040799201266574006, 0.22215389859463486, 0.9062816607100623, 34.989484855106895, 32.98421389716012, 44.959256989615305, 40.34653207233974, 32.42993177686419, 26.966222763061523, 29.041708741869243, 32.784213474818635, 32.98056609289986, 34.198262214660645, 34.10535437720162, 31.85830695288522, 32.844857352120535, 32.687564032418386, 32.38358381816319, 34.91597638811384, 37.78109734398978, 38.33465685163225, 41.149584020887104, 40.6549209186009, 41.67526388168335, 35.493680885859895, 33.045344148363384, 31.238148961748394, 31.42866161891392, 32.114705903189524, 33.83292245864868, 36.73780795506069, 40.99357264382498, 46.75471666881016, 47.53985268729073, 45.38748836517334, 47.741645744868684, 43.151478154318674, 39.094136646815706, 38.030641896384104, 40.71566901888166, 44.4165540422712, 45.20199925558907, 44.266038690294536, 45.12490551812308, 44.30681766782488, 46.07965401240757, 47.47026995250157, 50.81724500656128, 51.263982909066335, 52.116175992148264, 53.69786739349365, 57.28857135772705, 53.02290548597063, 55.605300767081125, 31.620709827968053, 1.1099982836416789, 31.15797369820731, 49.22795575005667, 29.280469690050396, 15.143897601536342, 28.44491580554417, 42.44373117174421, 27.90750391142709, 19.4864661352975, 26.991529839379446, 16.398358379091533, 40.97793224879673, 73.00717530931745, 27.168667214257376, 50.626503058842246, 35.338058607918875, 1.9520190954208374, 0.15362351733658994, 0.3124439072396074, 0.03833571542054415, 0.15905635724110262, 0.1793140745056527, 0.024425828962453773, 0.13737041875720024, 0.11804978549480438, 0.025475554866716266, 0.11675997184855597, 0.07933061636452164, 0.03655917503471885, 0.07578662796212093, 0.19733360329908983, 0.19966006917612894, 0.1014246733060905, 0.06944344512053899, 0.16031171487910406, 0.1388112742985998, 0.16370076659534658, 0.11393026368958609, 0.26710666716098785, 20.025760991232737, 72.73839119502476, 40.04307644707816, 28.525792837142944, 38.1946610723223, 42.03504507882254, 28.046841348920548, 26.679045030048915, 62.402292660304475, 56.145801135471885, 29.000113351004465, 25.39417198726109, 55.852368286677766, 49.98775168827602, 32.64324147360665, 6.2677580288478305, 15.490638766969953, 47.432906014578684, 54.71041100365775, 57.81203474317278, 56.84566191264561, 53.912677901131765, 48.64870180402483, 49.02032273156302, 53.77017729622977, 55.129932812282014, 54.47813619886126, 57.026586055755615, 57.6692145211356, 52.9055677822658, 49.28702586037772, 47.836721420288086, 48.546146392822266, 46.43788923536028, 43.29299906321934, 42.54289238793509, 44.91720649174282, 43.830348423549104, 42.90257978439331, 42.12821347372872, 44.64176252910069, 42.035364695957725, 41.6538599559239, 43.5905521937779, 50.13682181494576, 53.5111380304609, 52.798881667000906, 51.99585403714861, 50.704864842551096, 50.0765357698713, 44.87978002003261, 42.834626402173726, 43.64127056939261, 42.11598811830793, 44.19804014478411, 44.14227042879377, 43.5036997113909, 46.416190011160715, 43.617684909275596, 41.00558607918875, 28.206827095576696, 22.335251876286097, 30.311697006225586, 37.20159673690796, 37.93100125449044, 18.94523446900504, 5.487469681671687, 2.853155506508691, 4.736233489853995, 2.602073448044913, 0.4070215922381197, 0.18228532506951264, 0.06485751191420214, 0.062333164869674614, 0.045800058636814356, 0.14184256164090975, 0.09904784655996732, 0.04376357148534485, 0.03015683072486094, 0.17772733393524373, 0.035248225022639544, 0.05789186140256269, 0.15940345504454204, 0.3542594691472394, 1.5279630443879535, 34.41559839248657, 42.32017135620117, 52.52181529998779, 41.939813068934846, 35.279558249882285, 32.625999518803184, 31.641415459769114, 37.1431484903608, 35.487326758248464, 38.688504287174766, 38.19740908486502, 36.49662555967058, 37.46598958969116, 36.77790600912911, 35.34277296066284, 37.02234016145979, 42.677183696201865, 41.21902084350586, 42.982675143650596, 44.278799057006836, 42.805047920772004, 38.73220150811331, 36.69408988952637, 34.96603468486241, 35.375533717019216, 35.43744216646467, 37.30633735656738, 39.334509577069966, 43.18690354483468, 48.70347792761666, 50.39274828774588, 48.55017287390572, 48.4618056842259, 46.944478920527864, 41.688277857644216, 40.90623378753662, 42.680598735809326, 44.26612206867763, 44.61752026421683, 44.73234966823033, 46.043776988983154, 45.94820104326521, 48.84674283436367, 48.61541298457554, 51.73966005870274, 54.92051410675049, 56.58522605895996, 57.77007804598127, 60.79620960780552, 56.99289771488735, 61.14013154166085, 34.8253093447004, 1.7831470370292664, 40.86596897670201, 53.64960868018014, 35.897041184561594, 15.468361105237689, 27.869799511773245, 37.23540667125157, 31.471705709184917, 23.35619238444737, 28.940214668001445, 20.747689247131348, 44.96897404534476, 83.31548104967389, 36.37353474753243, 60.070220129830496, 58.131481647491455, 4.451471558638981, 0.2932797170111111, 0.019325121771544218, 0.09401585800307137, 0.1906938124448061, 0.0767344328175698, 0.12223280460706779, 0.14561858187828744, 0.0962588708581669, 0.027904406589056765, 0.1515049138771636, 0.2589308087314878, 0.26655157123293194, 0.3333124417279448, 0.4737972819379398, 0.29127755016088486, 0.39101147704890793, 0.21846821850964002, 0.21946808057171957, 0.32683840340801645, 0.46213668478386744, 0.31193601020744866, 0.699776747397014, 23.978063106536865, 80.690048626491, 41.57534531184605, 30.15421608516148, 46.25834778376988, 57.15836559023176, 33.42046349389212, 43.94882215772356, 83.09928785051618, 66.4066298348563, 36.74546486990792, 32.01755966459002, 65.25038010733468, 52.5345652444022, 33.749127183641704, 6.16400101355144, 19.523795332227433, 51.6381642477853, 58.645519801548545, 63.98662090301514, 61.16536045074463, 58.15671403067452, 52.46397154671805, 49.94148710795811, 55.38272564751761, 55.959558146340505, 53.5948360306876, 54.833866596221924, 59.958930832999094, 53.214991910117014, 49.98678241457258, 47.41159936359951, 50.81377438136509, 51.78378806795393, 48.62168025970459, 44.63692658288138, 48.96193354470389, 47.08151824133736, 45.54426751817976, 43.13605662754604, 45.11873204367501, 41.25346653802054, 42.43946150371006, 46.71991661616734, 55.74910068511963, 59.63843822479248, 55.648508140019004, 54.1034962790353, 54.972160066877095, 51.836059365953716, 48.93068749564034, 46.327478885650635, 45.34463882446289, 46.14325087411063, 46.864199434007915, 48.27544457571847, 44.99204206466675, 53.180289132254465, 49.360315459115164, 45.45965930393764, 36.441634041922434, 34.094442231314524, 41.89832190104893, 44.00195503234863, 47.070227418627056, 26.05505163328988, 6.475991197994777, 8.17333275931222, 7.69650307723454, 3.3008192564759935, 0.7280652523040771, 0.6262113920279911, 0.22220888707254613, 0.20837600076837198, 0.19211868170116628, 0.36680778009550913, 0.2135481746601207, 0.14968778352652276, 0.0924893170595169, 0.27443731522985865, 0.20714830021773065, 0.13447109290531703, 0.2526872009038925, 0.5704072064587048, 7.647280301366534, 41.62702601296561, 33.05829211643764, 54.699922697884695, 46.485560825892854, 43.51425402505057, 37.06332758494786, 37.45259346280779, 39.83854232515608, 39.01238761629377, 44.238760062626426, 42.51870223454067, 42.75466305868966, 42.06104176385062, 41.13918604169573, 38.09239053726196, 41.59339325768607, 42.02182265690395, 41.82506356920515, 44.92511701583862, 47.08662864140102, 49.56916093826294, 43.83644546781267, 39.159668581826345, 38.184867586408345, 36.590825762067524, 37.43958990914481, 38.331005573272705, 42.127188614436555, 45.01517956597464, 53.19671467372349, 53.31943723133632, 51.883661474500386, 54.06720583779471, 51.50541891370501, 42.285426889147075, 40.46701036180769, 43.08893741880144, 46.02251550129482, 46.144227096012656, 46.52109738758632, 49.67889731270926, 48.1393050466265, 51.489372049059185, 50.714501993996755, 54.65045847211565, 56.72178595406668, 57.141894885471885, 59.522736821855815, 61.69584151676723, 61.99606622968401, 66.46246555873326, 42.07423986707415, 2.2080076677458624, 41.214143208095, 62.39032786233084, 43.515598501477925, 22.89914161818368, 34.17399215698242, 48.45161615099226, 38.16144520895821, 29.39011573791504, 37.24501950400216, 24.58182508604867, 46.443371364048545, 81.97248458862305, 47.753568853650776, 67.13738577706474, 67.60123361860002, 3.612616411277226, 0.40161798362221035, 0.4897779758487429, 0.17745848479015486, 0.7485236802271434, 0.4663191746388163, 0.590903252363205, 0.4444177198622908, 0.24156628336225236, 0.14655531304223196], [0.047753672913781235, 0.15836449579468795, 0.183526162058115, 0.08307420262800795, 0.37483878486922806, 0.08770215750804969, 0.17350464766579016, 0.3833064133567469, 0.5962663388678006, 0.3793858380189964, 0.3165211156010628, 0.18935352936387062, 0.09173697100153991, 24.973639215741837, 59.65447466714041, 39.012714181627544, 29.76666293825422, 26.82457331248692, 30.22993755340576, 18.70330514226641, 26.28244011742728, 44.373398780822754, 33.435172830309185, 36.62987463814871, 18.97444816998073, 41.33182137353079, 44.29929624285017, 39.759246008736746, 9.672577704702105, 7.364188977650233, 38.88856724330357, 50.24239274433681, 54.369657448359895, 51.481141907828196, 49.205825737544465, 47.04754849842617, 46.42904417855399, 47.45175300325666, 53.79071617126465, 55.40885782241821, 52.75819649015154, 53.93702091489519, 53.48768091201782, 48.12448801313128, 49.77044677734375, 47.20018652507237, 45.11665105819702, 39.19907529013497, 43.064302580697195, 41.16607209614345, 41.55562285014561, 41.947317123413086, 40.977591787065776, 41.17106785093035, 41.850372382572715, 43.22083854675293, 43.45275204522269, 46.51257542201451, 51.27155991962978, 45.999579497746055, 44.94887638092041, 44.248699460710796, 44.92572498321533, 40.07523618425642, 39.570480823516846, 39.36137131282261, 37.88702263150896, 39.602129868098665, 38.95715985979353, 39.92709711619786, 39.026384762355256, 34.10503823416573, 33.28432396480015, 20.965862682887487, 14.708455732890538, 27.167432171957834, 31.32142312186105, 33.38539593560355, 9.934734974588666, 4.425072746617453, 5.058298127991812, 1.9248338341712952, 0.7628923377820424, 0.20948520196335657, 0.12807657888957433, 0.12964085995086602, 0.16733050825340406, 0.15473354634429726, 0.032331342077148814, 0.2537497053188937, 0.021501527932871665, 0.03246730353151049, 0.22353749935116085, 0.04638582095503807, 0.10540022355105196, 0.3237158123935972, 0.22057652180748327, 1.1407975852489471, 14.789023569652013, 36.44032778058733, 38.11127921513149, 25.67515366418021, 31.01074137006487, 32.775844369615825, 25.856199400765554, 32.02469546454293, 31.998879432678223, 36.59281989506313, 34.30909987858364, 30.960835933685303, 30.005521161215647, 30.577945028032573, 31.170160838535853, 32.231404372623985, 37.73109810692923, 39.61208316258022, 38.777618408203125, 39.08127900532314, 36.437364373888286, 32.67074939182827, 31.351894446781703, 31.271295343126567, 32.748068945748464, 31.361343996865408, 32.09643908909389, 37.37768840789795, 42.289661816188264, 46.96564313343593, 48.461979389190674, 45.69770458766392, 44.657368183135986, 40.55904967444283, 39.06671558107649, 39.47655507496425, 38.83314493724278, 40.66561419623238, 43.033327511378694, 41.6552391733442, 42.113125460488455, 45.50675766808646, 48.43178946631295, 46.97671856198992, 51.27626037597656, 53.20911373410906, 55.22703388759068, 56.938090324401855, 60.17663179125105, 51.93851055417742, 58.449337414332796, 19.30347490310669, 3.1516779107706885, 46.225031171526226, 45.085467542920796, 28.642201219286235, 9.94230329990387, 21.954488856451853, 21.340976817267283, 13.790090612002782, 17.136675698416575, 30.47315924508231, 15.299316644668579, 28.088886635644094, 55.236636298043386, 36.583700384412495, 36.747021266392295, 50.87870529719761, 13.848340834890093, 0.9786675593682698, 0.1829169461769717, 0.07711629197001457, 0.1277867630124092, 0.07772200661046164, 0.22631040055836948, 0.1524387951940298, 0.15917455804135117, 0.06669053355497973, 0.0314366800843605, 0.16227694228291512, 0.19925894641450473, 0.1528252208871501, 0.13554066765521253, 0.062169251165219715, 0.19361533996249947, 0.2906564734876156, 0.3776491954922676, 0.19218877436859266, 0.2769130452403, 0.08917172865143844, 0.0578625351190567, 35.89055504117693, 67.23721054622105, 44.51606961659023, 32.03275190080915, 29.833779062543595, 37.084627287728445, 25.399119104657853, 24.099098988941737, 42.54299661091396, 37.63569586617606, 40.50808463777815, 23.838954959596904, 44.34391410010201, 48.76357289722988, 49.54945237295968, 14.336189491408211, 5.839336012090955, 38.20348875863211, 51.24478851045881, 55.39345714024135, 54.59855890274048, 53.24858297620501, 49.84704371861049, 50.728975091661724, 51.49622644696917, 55.23088318961007, 55.932081495012554, 57.46224158150809, 55.73779944011143, 54.79673542295183, 50.92643247331892, 51.85443040302822, 49.924811431339805, 45.56251001358032, 41.128430230276926, 43.899413517543245, 42.43993050711495, 41.42372519629342, 42.64004210063389, 40.28817762647356, 43.52363409314837, 43.152266774858745, 42.426781041281565, 42.18481002535139, 46.315680844443186, 52.59610891342163, 52.30138717378889, 49.21380574362618, 49.17696986879621, 48.70481545584542, 44.18789577484131, 44.809189796447754, 43.648270879473, 41.3308937890189, 42.69255658558437, 44.29947689601353, 45.857815401894705, 42.484593527657644, 41.070871353149414, 37.52550091062273, 25.49864510127476, 24.557471649987356, 37.83809689113072, 46.70443255560738, 38.405118533543174, 22.591831479753765, 13.528509174074445, 10.018490297453743, 7.194639469896044, 2.1689140626362393, 0.10869540673281465, 0.13703853370887892, 0.11168239930910723, 0.184552310566817, 0.08744095545262098, 0.09687261935323477, 0.1667091330247266, 0.04545515250148518, 0.1454024277627468, 0.11504927650094032, 0.03257477669311421, 0.13200160541704722, 0.33837178881679264, 0.125826733186841, 0.9248139177049909, 10.21872956412179, 37.233013016836985, 45.95187316622053, 34.573211329323904, 33.562043462480815, 38.11491312299456, 28.596862486430577, 37.740241936274934, 36.26873506818499, 41.06393010275704, 37.98426267078945, 35.8929625919887, 34.63190623692104, 34.65756940841675, 34.35782412120274, 35.03456129346575, 39.0065268107823, 41.722431727818076, 40.726028782980784, 40.861980710710796, 38.197874614170615, 37.43447256088257, 34.815564496176584, 36.03262485776629, 37.23549699783325, 37.635532583509175, 36.30735315595354, 39.389817237854004, 42.232603209359304, 47.953246184757774, 49.50387566430228, 46.16534614562988, 46.10545267377581, 43.59320987973894, 41.9600635937282, 41.32486622674124, 42.114379610334126, 42.442841802324565, 44.13490881238665, 43.00361006600516, 42.58334132603237, 45.95971073423113, 47.7865172113691, 47.58697189603533, 51.68469633374895, 52.88682849066598, 57.484156199863975, 58.16892201559884, 63.585042817252024, 57.50546285084316, 63.34571211678641, 18.4217016015734, 4.436953731945582, 53.76831865310669, 51.057576247623985, 30.233137198856898, 11.807376112256732, 22.914707320077078, 22.64211733000619, 18.299477577209473, 19.510885579245432, 30.045619215284074, 21.334327391215734, 31.020190920148575, 64.07124301365444, 44.22385965074812, 48.823407309395925, 63.62671116420201, 25.49831853594099, 1.0045615413359232, 0.04370913601347378, 0.018863926608381525, 0.07177681848406792, 0.12210274301469326, 0.32126882512654575, 0.1635003409215382, 0.08123962035668747, 0.029626742204917327, 0.10140586431537356, 0.21003397394503864, 0.2830832355788776, 0.5489931840981755, 0.7144393463219915, 0.2345756356205259, 0.37965708917805124, 0.44161043050033705, 0.5050117384110178, 0.44333241667066303, 0.4076663633542401, 0.3246889130345413, 0.42454584475074497, 38.882612637111116, 74.1903076171875, 48.76556355612618, 38.796896185193745, 35.78088467461722, 44.75674131938389, 23.763836247580393, 36.673009055001394, 54.46606717790876, 38.376960958753315, 47.17124727794102, 31.61694390433175, 53.03513084139143, 52.99116611480713, 48.167629378182546, 12.524550063269478, 7.3808802877153665, 43.58788061141968, 55.30073690414429, 62.04066671643938, 58.59664617265974, 56.04215485709054, 52.05476433890206, 52.763028962271555, 53.3140732220241, 55.57118163790022, 55.582173688071116, 57.641710077013286, 57.565999031066895, 56.39124625069754, 49.78693832669939, 53.70910957881382, 52.376542363848, 50.92687715802874, 44.71053579875401, 44.977548122406006, 45.33639478683472, 45.23219265256609, 48.98397323063442, 43.30144807270595, 45.85718658992222, 45.541734899793354, 45.1260415485927, 47.58601304462978, 53.45374938419887, 61.02374226706368, 53.09587894167219, 51.767741203308105, 48.42197513580322, 51.45478391647339, 45.619526931217735, 49.19217600141253, 46.635277135031565, 44.48006752559117, 47.248719692230225, 47.47349739074707, 49.41895130702427, 48.154525075639995, 46.50984130586897, 45.73513453347342, 34.060760838644846, 36.717178753444124, 53.29503515788487, 55.71916437149048, 49.32205172947475, 26.53560641833714, 15.545600754874092, 16.49726251193455, 8.968220574515206, 2.3109057119914462, 0.22354323975741863, 0.28906756160514696, 0.16455216519534588, 0.3769111122403826, 0.4184656824384417, 0.23210229405335017, 0.38545845502189224, 0.10194646673543112, 0.1840729798589434, 0.1702755537948438, 0.12602464828108037, 0.2892080997782094, 0.40998293619070736, 0.6973597513777869, 1.1058273017406464, 21.963538885116577, 36.552082606724326, 46.14025967461722, 39.927576541900635, 42.6150598526001, 44.020315647125244, 34.234997340611045, 41.607206276484895, 38.855076926095144, 45.870336055755615, 42.564018385750906, 40.84429407119751, 37.82899127687727, 39.150698457445415, 37.301244327000205, 38.71282993044172, 42.96055555343628, 43.4299966948373, 42.39888402393886, 43.84596102578299, 43.67531674248831, 38.76696334566389, 36.807133606501985, 35.640788146427695, 38.15803016935076, 36.86021089553833, 35.7338627406529, 41.56187622887747, 46.176213128226145, 53.79443345751081, 55.039502007620676, 51.75700623648507, 49.89953735896519, 49.800456047058105, 44.48880141122, 42.80836568559919, 42.08808415276663, 42.9492438861302, 44.64695283344814, 43.99542372567313, 45.8296856198992, 49.20715979167393, 52.466987064906526, 49.69317586081368, 56.089541571480886, 58.02956894465855, 60.13263579777309, 62.452931131635395, 67.16364996773856, 63.1982296534947, 68.49344485146659, 25.83483021599906, 4.3550470641681125, 57.545692920684814, 57.44274146216256, 40.962500299726216, 17.603870834623063, 27.2608038016728, 31.687746047973633, 21.21150061062404, 25.65250253677368, 43.95610734394619, 24.626029525484356, 34.074841363089426, 58.924385751996724, 57.60638543537685, 51.858929361615864, 75.6201148714338, 29.083804403032573, 0.9500676883118493, 0.32113002400313106, 0.21218141514275754, 0.2706706316343376, 0.3589113423866885, 0.5190683784229415, 0.4150060495095593, 0.22698368371597358, 0.18913737524832996], [0.062021703725414615, 0.04849459244204419, 0.23685860740286963, 0.4779538246137755, 0.4620819677199636, 0.2692350415246827, 0.10952357229377542, 0.27833031490445137, 0.47153819458825247, 0.2282135012958731, 0.41927104922277586, 0.5087415639843259, 0.651445675109114, 38.685040610177175, 53.934415340423584, 28.876786300114222, 27.302366188594274, 43.987721647535054, 32.242386000497, 21.56937105315072, 15.189198119299752, 22.124061380113872, 12.672987035342626, 27.223835911069596, 18.128485883985245, 30.774429661887034, 57.29376861027309, 31.31350564956665, 13.737492748669215, 1.0527031123638153, 20.366384267807007, 46.41131932394845, 50.407381193978445, 48.96041883741106, 48.8623172215053, 45.13049186979021, 49.91331563677107, 49.56898723329817, 52.72877434321812, 52.44044842038836, 54.08552128928048, 51.922790254865376, 51.98814501081194, 51.45317540849958, 52.54774597712925, 48.938545908246724, 45.03406129564558, 41.48778063910348, 40.45824868338448, 38.48289666857038, 38.39039877482823, 40.46263994489397, 40.81708492551531, 44.94137232644217, 42.384428296770366, 42.21573298318045, 44.83216748918806, 42.43962478637695, 47.87020478929792, 46.71051917757307, 44.24669143131801, 47.09266662597656, 43.269979681287495, 39.21209274019514, 40.29853739057268, 37.00701938356672, 36.66912153788975, 40.211869035448345, 41.11844914300101, 41.563585485730854, 39.34167316981724, 34.77623421805245, 31.196880136217388, 18.661296333585465, 19.1930193901062, 36.2810229573931, 44.305056299482075, 32.535874434879844, 22.24991931234087, 9.480039647647313, 9.402061751910619, 2.533523823533739, 0.7737091087869236, 0.08956174379480736, 0.27874489980084555, 0.13573357516101428, 0.1899594882769244, 0.1230917756578752, 0.08998989939157452, 0.12926793710461684, 0.021820899099111557, 0.1311751769057342, 0.07776609103062324, 0.2048480665045125, 0.1109463380915778, 0.11024933334972177, 0.017782804888806174, 0.4588670145188059, 1.9650851828711373, 26.32093140057155, 30.91858741215297, 24.964947019304546, 32.62799365179879, 30.187907900129044, 25.681269815989904, 31.557967594691686, 33.413313797542024, 36.58600718634469, 33.9656434740339, 32.3499093736921, 30.55357074737549, 29.22931010382516, 28.616739545549663, 30.02965225492205, 33.870140484401155, 32.40881967544556, 33.41482155663626, 32.625349862234934, 30.948089463370188, 29.71346058164324, 30.790928159441265, 32.23001820700509, 34.03509419304984, 32.259721755981445, 33.6462139402117, 37.00598062787737, 41.5668511390686, 43.93836164474487, 44.97661706379482, 43.718128068106516, 41.254519190107075, 39.37562901633126, 38.77507536751883, 40.07236657823835, 41.88599927084786, 39.0395689691816, 42.604585443224224, 41.947101729256765, 43.02361740384783, 45.3587714603969, 48.44342769895281, 47.08500623703003, 52.73030294690813, 55.61971480505807, 59.122249603271484, 55.99636970247541, 57.20837524959019, 52.442873341696604, 55.543566022600444, 7.379093732152667, 7.722755977085658, 57.342162813459126, 41.25696495601109, 19.668673958097184, 7.47189039843423, 19.343675443104335, 16.821269171578543, 13.917486701692853, 23.060720239366802, 26.195792606898717, 19.096712146486553, 17.64024118014744, 27.773533957345144, 26.801203046526226, 41.00344603402274, 54.500620569501606, 36.68147543498448, 8.293776307787214, 0.3217843488923141, 0.05235501565039158, 0.18503017563905033, 0.38123889001352446, 0.38347829984767096, 0.4883263994540487, 0.02865073743409344, 0.08806608297995158, 0.10025279583143336, 0.19657950662076473, 0.17557422018476895, 0.4626471059662955, 0.15460307763091155, 0.3221131126795496, 0.04164563299023679, 0.22035712429455348, 0.3064540172261851, 0.23381117092711584, 0.3617393949202129, 0.10543551415737186, 0.6813056671193668, 48.59217126028878, 58.666538102286204, 33.11180714198521, 22.926168373652867, 43.46899693352835, 41.45300490515572, 24.321067878178187, 19.5277419090271, 28.24257905142648, 14.849881104060582, 32.794736521584646, 21.05854296684265, 33.576526982443674, 60.08547837393624, 37.57686199460711, 16.81630120958601, 1.3856708854436874, 15.763407673154559, 42.78322015489851, 54.40833112171718, 52.19413478033883, 52.44190059389387, 51.15879760469709, 55.186324392046245, 53.489991188049316, 57.66973563602993, 56.61360250200544, 57.86911766869681, 53.32802520479475, 53.31075198309762, 53.50811208997454, 54.949991839272634, 49.960691928863525, 47.27665492466518, 44.04489489964077, 41.46556724820818, 40.498006275721956, 41.037891728537424, 40.80899722235543, 44.59131165913173, 43.67006043025425, 44.08372490746634, 43.218903473445344, 42.178768566676546, 44.014579909188406, 47.6683908871242, 48.83487531117031, 48.31288841792515, 50.11240584509713, 49.13106312070574, 45.95487478801182, 44.41550139018467, 40.00878708703177, 41.42146355765206, 43.58456632069179, 45.82532215118408, 44.981380053928916, 43.7248990876334, 41.02944271905081, 34.73293999263218, 21.19147937638419, 26.13157214437212, 42.73822362082345, 52.81257309232439, 41.82354538781302, 42.65032890864781, 29.365515640803746, 19.339824404035294, 6.262017948286874, 0.7014610884445054, 0.09269124229571649, 0.252964260322707, 0.16528368022825035, 0.34115638796772274, 0.08606779735003199, 0.09343913716397115, 0.018215262397591556, 0.05453286200229611, 0.1466517871511834, 0.04609108230631266, 0.16521305830350944, 0.05666511080094746, 0.10029215764786516, 0.015863198786973953, 0.7061273466263498, 1.6835704488413674, 23.70610019138881, 34.47202818734305, 36.48007147652762, 40.9079395702907, 33.77459233147757, 28.423977409090313, 36.85297782080514, 37.69496052605765, 39.60559701919556, 36.88138553074428, 38.84808703831264, 34.28893273217337, 34.45089871542794, 32.66359274727957, 35.42345544270107, 36.61795500346592, 36.467161723545615, 36.646605900355745, 37.1279354095459, 35.45785249982561, 34.69121953419277, 37.67311538968767, 37.50429153442383, 38.07462746756417, 36.61803143365042, 37.81973627635411, 38.24858604158674, 43.73516852515084, 45.89605828693935, 45.09152637209211, 44.20301158087594, 42.60234464917864, 43.50937638963972, 42.226797989436555, 43.32455430712019, 43.15935046332223, 41.901052543095176, 44.723799909864155, 43.30060386657715, 45.59563902446202, 46.52028444835118, 47.80222361428397, 48.90877635138375, 54.14524800436837, 57.690639291490825, 59.716494287763325, 57.50267314910889, 61.946351868765696, 57.23199217660086, 53.400317737034385, 5.176840041364942, 11.62455597945622, 61.855101176670615, 47.415980202811106, 20.495992490223475, 12.458622080939156, 18.34865345273699, 18.392949955804006, 11.393268687384468, 25.72577997616359, 25.556933539254324, 26.90503866331918, 24.178926842553274, 41.923081806727815, 30.902106285095215, 49.54553358895438, 66.94235679081508, 56.20118522644043, 16.05913516453334, 0.3688091869865145, 0.12024680046098572, 0.09340246913156339, 0.11871835961937904, 0.1791895090469292, 0.20616012252867222, 0.02877128596550652, 0.1475260659520115, 0.17342901815261158, 0.23669312628252165, 0.27735452726483345, 0.8977185487747192, 0.3688703365623951, 0.5149811548846108, 0.20317459558801992, 0.8699239087956292, 0.5459735946995872, 0.35964274885399, 0.4834827450769288, 0.49694900533982683, 0.8413417339324951, 56.66280269622803, 66.20509038652692, 36.36427279881069, 35.04110302243914, 56.55444553920201, 45.400432859148296, 26.457524299621582, 21.447393689836773, 31.649423258645193, 16.545927694865636, 34.92349781308855, 30.673017229352677, 41.673235007694785, 65.10305050441197, 41.83508634567261, 15.725218636648995, 1.849447182246617, 23.892570734024048, 50.323043959481375, 56.39169093540737, 54.256189891270225, 56.018916606903076, 52.88394151415144, 57.37265150887625, 54.60895340783255, 58.86350563594273, 55.99813801901681, 58.49341678619385, 54.06763662610735, 54.483597482953755, 54.25556107929775, 55.16901295525687, 51.53898566109793, 51.10129083905901, 47.047836848667686, 44.58396393912179, 41.69798101697649, 45.70443044389997, 43.174518380846294, 47.486827509743826, 49.53672327314104, 47.18660627092634, 46.421265670231406, 48.512531008039204, 47.162193775177, 54.346009254455566, 51.90715333393642, 50.316502230507986, 51.684578214372905, 48.78514705385481, 47.770588466099326, 47.928336892809185, 41.02027109691075, 44.03202336175101, 46.685321535382954, 50.01944242204939, 49.08050455365862, 52.65738507679531, 47.18376445770264, 47.59269373757498, 29.834720543452672, 38.93613461085728, 55.72325686046055, 59.8458627973284, 48.33594601494925, 43.467027119227815, 33.596669810158865, 25.791035720280238, 8.720922895840236, 1.8740800661700112, 0.25304747585739407, 0.5058949738740921, 0.3873095799769674, 0.3736042311148984, 0.4578974151185581, 0.19961695506104402, 0.18660789169371128, 0.14805012568831444, 0.2568379896027701, 0.12834042044622557, 0.32135296346885817, 0.16728229155497892, 0.26436638991747585, 0.11970366031995841, 0.8804450556635857, 9.693780132702418, 33.94587237494332, 37.989327907562256, 43.762554849897114, 45.15511975969587, 38.85201277051653, 34.90258373532976, 42.563375677381245, 43.820659160614014, 45.934297697884695, 41.051961830684114, 44.59775611332485, 37.70494161333357, 37.07387842450823, 35.324252537318635, 35.92594569069998, 39.63967793328421, 36.95186110905239, 38.514952182769775, 39.72317443575178, 37.88666132518223, 34.986663886478965, 36.96459020887102, 37.22226415361677, 38.83404472896031, 36.564662320273264, 37.624898365565706, 39.870594365256174, 47.40141330446516, 50.724465710776194, 49.902955872671946, 47.60947363717215, 47.135328565325054, 46.91203778130667, 44.58790704182216, 44.27440084729876, 44.09101356778826, 42.74666220801217, 48.094593388693674, 47.22803837912423, 45.43592773165022, 48.04924597058977, 51.66178117479597, 52.155742509024485, 57.54027679988316, 64.67689664023263, 64.4544986997332, 62.85304314749581, 66.57039192744664, 61.15568161010742, 63.315216473170686, 11.571556857654027, 10.592207397733416, 68.38277394430978, 52.293785844530376, 29.672393253871373, 15.409515074321202, 26.526632819856914, 24.859654017857142, 22.452572209494456, 35.653180258614675, 38.37024205071585, 28.335403510502406, 26.91842610495431, 39.571450097220286, 39.68965285164969, 57.022083623068674, 69.74875504629952, 61.63257122039795, 16.12028452328273, 0.6064322590827942, 0.6348407832639558, 0.2541569620370865, 0.6050926681075777, 0.4907845961196082, 0.7674093182597841, 0.210867581356849, 0.2026291891400303], [0.08401246728109461, 0.16495151019522122, 0.37970719220382826, 0.5070488091026033, 0.35150817249502453, 0.4302503972181252, 0.2061325740069151, 0.26368115097284317, 0.33515678133283344, 0.1312497207628829, 0.21472867631486484, 0.5223295262881688, 2.763431246791567, 55.06187520708357, 47.94675309317452, 46.0257568359375, 46.609551429748535, 36.343490736825125, 30.78652994973319, 28.15719611304147, 14.629518985748291, 11.265268972941808, 21.426003660474503, 22.318767275129044, 22.5217866897583, 22.891467332839966, 53.5905350957598, 40.374696595328196, 18.3104852608272, 1.3171422140938895, 2.309091797896794, 24.990589346204484, 45.68480525697981, 47.97104399544852, 45.930215631212505, 44.01785251072475, 49.61956664494106, 51.32138545172555, 51.66311175482613, 55.2940388407026, 54.490629059927805, 50.66422482899257, 53.7321081161499, 52.531556674412315, 54.85216120311192, 51.45311982291085, 45.86941541944231, 39.796394552503315, 40.904944896698, 38.62055785315377, 39.92026356288365, 38.10170807157244, 42.63725239889962, 42.88317346572876, 42.09165552684239, 41.39041205814907, 40.93733739852905, 42.44934531620571, 43.547084263392854, 43.584069524492534, 45.09888104030064, 46.37113094329834, 44.38591596058437, 44.797742639269146, 38.19128772190639, 35.61231442860195, 38.48824678148542, 36.738791125161306, 40.27601480484009, 38.389488560812815, 36.89864138194493, 35.01456437792097, 23.568935803004674, 16.96124758039202, 22.4370881489345, 45.3455559866769, 46.78251641137259, 40.67801325661795, 40.672030857631135, 20.41295109476362, 10.938172101974487, 3.4324257373809814, 0.7188720798918179, 0.23034988237278803, 0.4259322817836489, 0.061736827583185265, 0.21382270992866584, 0.10281526297330856, 0.1933510098606348, 0.026795546357919062, 0.08985985815525055, 0.036069618804114204, 0.04442297520914248, 0.12999985925853252, 0.15552686234670027, 0.12898090322102818, 0.20533251336642674, 0.3942091683191912, 1.6412485369614191, 7.623361127717154, 29.53624677658081, 25.589468479156494, 38.227897780282156, 30.47195373262678, 21.84544903891427, 28.705641746520996, 32.887474128178184, 34.57324954441616, 34.151389666966026, 32.41944694519043, 28.693682159696305, 29.78355748312814, 28.490365709577286, 30.47819321496146, 31.55375698634556, 33.83408975601196, 32.000081471034456, 30.965546812329972, 30.185149465288433, 31.242790358407156, 35.37820529937744, 33.35033185141427, 35.87606804711478, 36.57395553588867, 35.94292361395699, 37.69128492900303, 39.60454784120832, 43.675869124276296, 42.79988540921892, 42.23246771948678, 40.218834604535786, 39.254664352961946, 38.12076350620815, 40.53183010646275, 41.45144503457205, 38.44961827141898, 43.04378802435738, 42.12549672807966, 45.00857182911464, 48.840472085135325, 46.8521408353533, 50.9514216695513, 52.13885838644845, 58.67379896981375, 58.211966105869834, 55.26210839407784, 56.1368761743818, 56.28694684164864, 34.173144476754324, 1.648898395044463, 21.307927710669382, 52.677593912397114, 41.837723187037874, 16.230396100452968, 8.906471933637347, 17.73302742413112, 12.663147517613002, 20.136414527893066, 23.97005878176008, 25.73720976284572, 25.133192437035696, 16.6795745577131, 33.96290935788836, 43.160302366529194, 21.573159558432444, 50.083143506731304, 57.827397210257395, 41.01651212147304, 1.2694460877350398, 0.04767019275043692, 0.16369531117379665, 0.3909008486994675, 0.5218937982405935, 0.040846155889864476, 0.2300256783408778, 0.047414917698396106, 0.08344040119222232, 0.2770459566797529, 0.21173023006745748, 0.2998774115528379, 0.0427493448369205, 0.1601915191859007, 0.1232562389756952, 0.24170983423079762, 0.13926370787833417, 0.34400113246270586, 0.14250151413891995, 0.40317600859063013, 6.3127150450434, 69.07084015437535, 59.12076268877302, 53.689953395298545, 47.233756746564595, 37.57997131347656, 37.418974603925435, 28.786120993750437, 19.69113401004246, 17.487749065671647, 24.488753965922765, 32.74947248186384, 31.15595177241734, 29.082522460392543, 55.337228843144004, 42.66280787331717, 23.52730914524623, 3.4125523694923947, 1.6756758838891983, 21.665516751153127, 47.276939800807405, 51.451393195560996, 52.35546152932303, 50.20826319285801, 54.1283916745867, 57.861266204289024, 57.93372201919556, 58.872753688267295, 55.545417717524934, 53.26616191864014, 56.17565059661865, 55.424321038382395, 54.78432246616909, 53.146347182137625, 48.16793509892055, 40.795601095472065, 41.561132771628245, 42.723886013031006, 41.71129376547677, 41.98818990162441, 43.41870239802769, 41.27745866775513, 42.09370524542672, 40.8487548146929, 42.15465484346662, 43.74965551921299, 42.939137731279644, 45.34306853158133, 48.79008027485439, 48.16852569580078, 47.90161064692906, 47.552133628300254, 41.73065492085048, 40.40147147859846, 41.087515762874055, 41.63972731998989, 44.973841258457725, 42.751463413238525, 39.91839449746268, 39.74655164991106, 27.52310872077942, 20.657989740371704, 29.444964817592076, 47.429091453552246, 51.54767438343593, 53.06501504353115, 61.66617270878383, 40.212598596300396, 17.709811755589076, 4.207683154514857, 0.5745724343827793, 0.28348183419023243, 0.16195653804710933, 0.08561703975179366, 0.08546156023762055, 0.045829537590699534, 0.07094599306583405, 0.0417381037425782, 0.0644269407327686, 0.025625090414126004, 0.0485169298148581, 0.3152692456330572, 0.014641684779365147, 0.03957187391019293, 0.09719888613160167, 0.26875368878245354, 2.248786428145, 9.148930191993713, 31.720208031790598, 35.577521324157715, 43.76131459644863, 35.637598923274446, 27.211402109691075, 35.19079153878348, 37.96417542866298, 37.51644393375942, 39.04667697634016, 36.030960764203755, 35.08097873415266, 33.22508362361363, 33.564006328582764, 35.80321618488857, 34.84946128300258, 37.23304428373064, 37.16638674054827, 34.98646933691842, 34.336329868861604, 38.27040685926165, 39.808098793029785, 38.64793028150286, 41.583196776253835, 40.94170781544277, 39.35514920098441, 39.52827051707676, 42.38343470437186, 44.14792626244681, 43.19711739676339, 43.02868611471993, 42.65347991670881, 40.567585536411826, 42.97057832990374, 43.43334920065743, 43.44415364946638, 42.725445883614675, 45.94186428615025, 46.519332545144216, 47.556114946092876, 49.43592228208269, 49.154006072453086, 50.30483967917306, 51.795996052878245, 59.077607427324565, 57.98129980904715, 57.44929013933454, 58.374262128557476, 59.30475793566023, 30.929822649274552, 1.0403245708772113, 26.206055096217565, 56.72737577983311, 45.000734261104036, 19.0037556716374, 13.834280286516462, 18.367217302322388, 16.117619889123098, 16.65260512488229, 24.51927219118391, 24.739434548786708, 28.960968937192643, 21.44971091406686, 39.3515430859157, 52.702506678445, 23.0785527910505, 66.07148347582135, 62.03471211024693, 63.66109779902867, 2.808254075901849, 0.06368561408349446, 0.2398323006927967, 0.18924029543995857, 0.12719791675252573, 0.1311769818088838, 0.027473508014476726, 0.11111025858138289, 0.1219179779291153, 0.40473805048636025, 0.3909234032034874, 0.9035873338580132, 0.3230418642716748, 0.4781771983419146, 0.2932382178093706, 0.3762947310294424, 0.42583723259823664, 0.3600930246923651, 0.31575412675738335, 0.7428873340998376, 8.952693956238882, 78.14995397840227, 61.71540764399937, 57.013704095567974, 61.02055304391043, 49.840210165296284, 39.907277379717144, 37.53873028073992, 21.943934542792185, 15.51429912022182, 27.810397624969482, 31.31867163521903, 31.39386851446969, 34.315700667245046, 62.24661827087402, 47.49454695837838, 23.497327668326243, 2.4126922615936826, 3.1760602252823964, 27.939354453768047, 51.85540315083095, 53.16729947498867, 53.61744894300188, 51.197207246507915, 54.48975011280605, 57.44551726749965, 59.00562408992222, 61.1305638722011, 58.20881857190813, 52.861224378858296, 58.609333583286826, 57.55285651343209, 56.66419928414481, 55.61009155000959, 50.59107766832624, 43.87369476045881, 44.46324941090175, 44.816454138074604, 45.3194967678615, 44.60743842806135, 48.23185852595738, 46.520214966365266, 47.01700421742031, 43.613731384277344, 45.914411953517366, 47.06205286298479, 48.68648610796247, 48.94983673095703, 51.89380931854248, 51.106199741363525, 50.342071601322715, 50.95235620226179, 45.5874262537275, 42.290186405181885, 44.73723077774048, 43.112554345812114, 48.593467099326, 46.4700802394322, 46.24805055345808, 47.82231085641043, 39.05485153198242, 28.926827226366314, 44.87506914138794, 62.952742849077495, 60.7704804284232, 56.37383753912789, 57.287261622292654, 49.78195646830967, 21.17443891933986, 6.583939714091165, 1.1382168723004205, 0.4264310864465577, 0.27510496654680794, 0.11514017305203847, 0.33248194200651987, 0.26887286667312893, 0.27641565193023, 0.071640521154872, 0.15968759836895124, 0.10153066726135355, 0.11184624516006027, 0.4213935610439096, 0.121353843914611, 0.3087415487638542, 0.5744227224162647, 0.8620494827628136, 3.065246880054474, 23.735734258379253, 40.902325425829204, 40.46565546308245, 53.34373508180891, 38.41825062888009, 32.94960839407784, 40.608600752694265, 42.91789361408779, 43.633575439453125, 42.742399488176616, 40.84149047306606, 35.84606572559902, 34.19312402180263, 34.34847184589931, 37.83415378843035, 37.304093088422505, 37.48346430914742, 37.98420361110142, 34.87753895350865, 34.26975570406233, 36.878196307591026, 40.733842032296316, 36.65964419501168, 40.71193783623831, 41.21012020111084, 39.766312326703755, 42.356513908931184, 45.02478892462594, 49.95216996329171, 49.393965584891184, 46.495844159807476, 46.26519175938198, 43.73090580531529, 43.7317395891462, 44.74169152123587, 45.79719236918858, 43.94566420146397, 48.614395073481965, 46.55319111687796, 49.31726789474487, 51.62384748458862, 52.989008699144634, 55.88607399804251, 55.86353404181344, 64.39958708626884, 64.45183059147426, 61.02883529663086, 64.17108862740653, 62.806288719177246, 42.52811009543282, 2.760050731045859, 24.865931715284074, 64.48879500797817, 49.43851743425642, 28.53774200166975, 16.46300789288112, 24.14579435757228, 21.05872709410531, 34.20526947293963, 34.29632908957345, 36.61769444601876, 34.31620788574219, 23.970711912427628, 43.175703048706055, 59.52073574066162, 31.93993091583252, 66.4682812009539, 71.51846122741699, 65.07429885864258, 2.4510749791349684, 0.1585703090365444, 0.26279753553015844, 0.48135409929922646, 0.6317743478076798, 0.2910563748862062, 0.31844210252165794, 0.21389139124325343], [0.2354708675827299, 0.20905201163675102, 0.4738780547465597, 0.3734937384724617, 0.757025941142014, 0.22492578199931554, 0.17382714178945335, 0.25915385676281794, 0.14271123574248382, 0.3860117324760982, 0.09993855947894709, 0.7265286147594452, 13.565219981329781, 55.474844864436555, 47.13378259113857, 31.09590196609497, 23.991884810583933, 32.437602588108604, 15.597210236958094, 25.952412843704224, 25.845890011106217, 15.114868027823311, 24.82444749559675, 24.04811484473092, 17.320436443601334, 27.635327339172363, 33.11797366823469, 54.96674394607544, 46.342004094805034, 16.613702160971506, 0.37411296953048023, 3.663174109799521, 32.08709723608834, 45.78353221075875, 46.079389980861116, 48.78289931161063, 54.39676931926182, 58.420141083853586, 58.377673694065635, 58.35007544926235, 53.591247286115376, 52.231623785836355, 52.69227545601981, 56.72767455237252, 54.39845425742013, 54.73462894984654, 48.940414973667686, 39.45081547328404, 38.19800662994385, 39.44163342884609, 38.98872900009155, 41.53957251140049, 43.66540166309902, 43.421603270939414, 42.77214820044381, 41.4184376171657, 39.85573216847011, 41.98049824578421, 39.5757406098502, 38.31846407481602, 44.14849254063198, 46.103142397744314, 47.8869742665972, 43.10400806154524, 35.54962083271572, 37.69943516595023, 34.1621732711792, 36.857077257973806, 38.426095145089285, 41.7591564314706, 35.61522919791085, 33.58321114948818, 17.91165518760681, 20.68432515008109, 25.995090416499547, 48.56025471006121, 46.68278544289725, 60.684656279427664, 49.09546749932425, 22.75935081073216, 9.257313404764448, 3.447285762854985, 0.7817616366914341, 0.3470410779118538, 0.4076458987380777, 0.32493831536599566, 0.030957352769161974, 0.0187572829558381, 0.07721841149032116, 0.08365070633590221, 0.15726221565689358, 0.05642898061445781, 0.07393411879560777, 0.1519292832485267, 0.05228520457499793, 0.09113971769277539, 0.07507234093333993, 0.3615428911788123, 0.8346468188932964, 3.2203743159770966, 18.836284978049143, 34.21539299828665, 36.27355364390782, 34.37160587310791, 19.173948322023662, 27.970562287739344, 31.827533381325857, 32.4088578905378, 36.86226756232125, 32.64001750946045, 31.87586157662528, 29.06252380779811, 31.99640587397984, 30.033967086247035, 32.496457304273335, 32.444165161677766, 33.308663504464285, 32.635657514844624, 30.411910874503, 35.98235811505999, 36.22812632152012, 36.03842312949044, 40.83682823181152, 36.931721755436485, 38.07118810926165, 36.29628120149885, 39.90909433364868, 37.48779651096889, 40.75288009643555, 37.906644344329834, 39.987688882010325, 39.816975116729736, 39.718651158469065, 40.79507998057774, 39.92343194144112, 44.17063644954136, 42.77620594842093, 46.96710572923933, 48.095708574567524, 50.596730027879985, 48.96703699656895, 51.13727903366089, 51.245160239083425, 58.682102067129954, 55.668053422655376, 58.37342834472656, 53.72951643807547, 53.1891758782523, 9.764811566897801, 3.0381228498050143, 37.47384105409895, 50.333858830588206, 39.78240435464041, 10.555329833711896, 10.829339861869812, 21.504047564097814, 9.10385549068451, 18.586304426193237, 20.287487472806657, 24.378324508666992, 22.24475680078779, 22.350355522973196, 19.405939987727574, 34.15944957733154, 42.60576663698469, 39.11726719992501, 51.659950324467246, 56.94429506574358, 24.310225214276993, 0.6211569032498768, 0.45935908811432974, 0.3359688791845526, 0.6706582041723388, 0.056829530013991256, 0.11093579365738801, 0.05229968451229589, 0.27565455277051243, 0.2240032729293619, 0.1437703881944929, 0.1737468032432454, 0.2551088923854487, 0.10660451464354992, 0.22490936145186424, 0.10174075527382748, 0.24687166724886211, 0.18759851210883685, 0.13079255100871834, 0.10092387375022684, 23.825379916599818, 68.76955236707414, 58.72420120239258, 37.1687456539699, 30.351802008492605, 39.06284890856062, 26.614801985876902, 27.671767166682653, 25.353276627404348, 19.47800496646336, 31.46899938583374, 27.69049256188529, 30.844752379826136, 32.1717506136213, 33.48724263054984, 57.82411766052246, 53.53726325716291, 24.087208884102957, 0.54448771157435, 3.321543561560767, 31.781789915902273, 50.275820527757915, 53.597469397953574, 55.09505980355399, 56.39583553586687, 60.93529864719936, 59.49470084054129, 60.28516265324184, 55.449796608516145, 55.536364214760916, 51.803774561200825, 57.60374511991228, 54.50290652683803, 54.95544964926583, 49.03592838559832, 42.70780093329293, 42.1935578073774, 43.20396137237549, 41.43487358093262, 44.58315794808524, 43.94432667323521, 44.910935742514475, 42.53509303501674, 42.56076315471104, 42.32224539348057, 44.833432061331614, 40.5194935798645, 42.72232266834804, 46.01110655920846, 48.30399819782802, 48.49863461085728, 45.88503149577549, 41.637667179107666, 41.55841602597918, 38.67864826747349, 42.092732497623985, 42.82853978020804, 43.69194378171648, 39.87131002971104, 37.4771032333374, 26.041959490094865, 22.669800690242223, 31.87643132890974, 46.37719324656895, 47.762108189719065, 63.83203043256487, 53.88981137956892, 25.957429443086895, 11.597320778029305, 2.3131022112710133, 0.6313394882849285, 0.16760977969637939, 0.35422901649560246, 0.2957307483468737, 0.03830892685800791, 0.07295276038348675, 0.07422097626009158, 0.10564607035900865, 0.007757104783585029, 0.06973750184157065, 0.010660456892635142, 0.16041711850890092, 0.05086767367486443, 0.07005287813288824, 0.14112438660647186, 0.5747314287083489, 2.054161088807242, 3.1646056856427873, 18.411807366779872, 40.23087930679321, 39.0787707056318, 38.98293767656599, 25.468307529176982, 33.4102600642613, 36.88834067753383, 37.47435869489397, 38.97981793539864, 35.79090050288609, 37.59324584688459, 35.18438529968262, 36.835371085575645, 35.750722544533865, 36.49708066667829, 36.81447785241263, 36.57365676334926, 36.82840551648821, 34.88481371743338, 38.924965381622314, 39.585659163338796, 41.78271777289254, 43.40023408617292, 40.07024737766811, 39.17290490014212, 39.703010763440815, 40.508032526288716, 39.43909733636038, 42.276303904397146, 40.62553003856114, 41.69198819569179, 42.55460010256086, 42.10183811187744, 43.02738332748413, 44.383706433432444, 47.75597987856184, 47.40630483627319, 49.84479945046561, 51.00910561425345, 52.17328323636736, 49.46269021715437, 50.58072485242571, 52.51559318814959, 58.09366260256086, 55.88623380661011, 60.40579727717808, 57.012498583112446, 52.49947336741856, 6.341319910117558, 3.86697085414614, 41.454613413129536, 55.50082417896816, 42.14484051295689, 13.003774268286568, 11.106978586741857, 24.499806812831334, 17.332779918398174, 18.51656883103507, 17.180543150220597, 26.590557983943395, 24.960571391241892, 28.892470121383667, 22.071227278028214, 49.45008271081107, 45.357100418635774, 53.34569794791085, 62.885359219142366, 63.79435729980469, 48.12696157182966, 0.6529189646244049, 0.02426171678650592, 0.08055090052740914, 0.06565551659358398, 0.11348494115684714, 0.04188238064359341, 0.09111906308680773, 0.328877184007849, 0.3673726740692343, 0.4561083082641874, 0.596744027520929, 0.5573995815856116, 0.20535689991499695, 0.48945825014795574, 0.19002248346805573, 0.3567133503300803, 0.4323571670268263, 0.16333741109286035, 0.5198437539594514, 27.142187629427227, 78.56217670440674, 64.77528313228062, 40.59094190597534, 32.16687297821045, 47.406554971422466, 25.625383717673166, 35.6603855405535, 31.802773475646973, 17.089044060025895, 30.34744201387678, 30.444536140986852, 25.879420280456543, 41.025999886649, 41.128075872148784, 62.967945507594514, 53.37357064655849, 21.1809024810791, 0.40869366537247387, 5.4688524178096225, 36.92665651866368, 54.29658324377877, 55.261107853480745, 57.79247209003994, 58.631150926862446, 61.29055309295654, 62.379099573407856, 63.422517504010884, 57.57338844026838, 55.89416170120239, 54.090013299669536, 58.228277002062114, 59.77713121686663, 57.173547404153005, 51.25674636023385, 44.13383184160505, 44.2164181300572, 44.72283411026001, 43.16735131399972, 48.66786840983799, 49.086125646318706, 48.034866673605784, 47.576771940503804, 46.23495667321341, 46.06170334134783, 48.123550006321494, 44.117677279881065, 45.11878762926374, 48.87671736308506, 53.88774081638881, 53.16140045438494, 48.933254855019705, 41.837486948285786, 42.439378125326975, 41.42453466142927, 43.572948932647705, 47.32600450515747, 49.116464955466135, 47.150611128125874, 48.57726737431118, 33.35139145169939, 31.858056817735942, 46.521055698394775, 61.386201994759695, 54.6671793120248, 65.22881984710693, 51.466707025255474, 34.07096426827567, 13.796855551855904, 4.4874158927372525, 1.2737563593047005, 0.31170142708080156, 0.5684610051768166, 0.2971675055367606, 0.2275656767721687, 0.19314544089138508, 0.19295218054737362, 0.16203595378569194, 0.3337075119572026, 0.17477677868945257, 0.20313346279518946, 0.2576060641024794, 0.16969700769654342, 0.16925761555986746, 0.24012037952031406, 0.5578015457306589, 3.3180811873504092, 9.538057974406652, 34.61290986197335, 43.80014113017491, 45.883026940482004, 42.688175746372764, 30.10422032220023, 38.76371853692191, 42.90036678314209, 45.03236246109009, 44.971836703164236, 41.255769865853445, 38.49555281230381, 36.917085375104634, 38.82325070244925, 37.64452007838658, 37.52289881025042, 38.354931695120676, 38.63927282605852, 39.62515272412981, 35.33032873698643, 39.826740809849326, 39.569827692849294, 42.33964368275234, 45.20104040418352, 41.45322724751064, 40.14930745533535, 43.319621086120605, 44.966656821114675, 41.80006742477417, 45.60562705993652, 42.30786609649658, 44.54343162264143, 44.879644530160085, 44.09924370901925, 43.802239486149375, 45.978734901973176, 49.290187290736604, 48.46384498051235, 51.56389495304653, 52.58303240367344, 55.4152466910226, 52.72878476551601, 54.48962157113211, 56.002383368355886, 64.51330825260708, 59.34847600119454, 64.15547602517265, 61.20506245749337, 60.49838202340262, 12.808976309640066, 3.315410473517009, 43.6505776814052, 58.65476785387312, 48.54925223759243, 20.34177201134818, 16.60960098675319, 31.63302203587123, 15.652794088636126, 31.35532338278634, 27.537653037479945, 36.13000733511788, 32.015937260219026, 32.76642608642578, 25.731159618922643, 46.167131832667756, 59.54317842211042, 49.89055681228638, 67.67043767656598, 69.25229930877686, 48.06801652908325, 0.7289358941572053, 0.7771197514874595, 0.2708858900836536, 0.5834828476820673, 0.2587527611425945, 0.1443866744105305, 0.1551764668630702], [0.29050231033137863, 0.2661975659430027, 0.17631485472832406, 0.3646111179675375, 0.4573360223855291, 0.09742761350103787, 0.1275197866239718, 0.07985358365944453, 0.13607508183590003, 0.25392533732312067, 0.14626955480447837, 0.2466344785477434, 33.795478616442, 59.71142905099051, 46.336963176727295, 33.45055266789028, 32.652663230895996, 25.71809353147234, 17.879245315279277, 28.07006570271083, 25.408474854060582, 19.54512456485203, 12.158883741923741, 18.838213103158132, 9.691960573196411, 10.734760982649666, 20.02254397528512, 42.99775620869228, 52.22106599807739, 44.58876861844744, 9.128208926745824, 0.7706044582383973, 15.625341756003243, 37.33631535938808, 47.24622876303536, 48.65358986173357, 56.497282709394185, 63.596278054373606, 58.94798878261021, 59.329854828970774, 52.055302824292866, 54.27252858025687, 54.09141683578491, 56.542025634220664, 52.96713924407959, 55.562079497746055, 45.11591107504708, 40.59768165860857, 40.5600780078343, 43.01161439078194, 40.043093817574636, 41.14771842956543, 40.031420843941824, 41.571798256465364, 39.643172877175466, 39.80613592692784, 36.87546566554478, 42.38370221001761, 37.660837922777446, 41.019360882895334, 41.52784047807966, 44.38895232336861, 43.53494923455374, 40.66541269847325, 38.94582387379238, 38.51198182787214, 34.896264348711284, 35.63154009410313, 39.148176261356895, 40.2261996950422, 31.8743850844247, 26.825224706104823, 17.59700948851449, 22.95083621570042, 29.62005247388567, 44.351199286324636, 49.92944587979998, 63.12237616947719, 36.53117200306484, 14.217946784836904, 3.6289713851043155, 1.4785513643707549, 0.1270599298711334, 0.14132953488401004, 0.5498771795204708, 0.19876833845462116, 0.11449643330914633, 0.04227044160610863, 0.06836661004594394, 0.06580038382006542, 0.009362388867884874, 0.00926451528045748, 0.05812018843633788, 0.1522598655096122, 0.090067673075412, 0.11630646618349211, 0.18064166898173944, 0.3100228671516691, 1.550264481987272, 2.1438690636839186, 9.433310406548635, 33.886826583317344, 39.31124005998884, 36.861468519483296, 19.008039236068726, 23.70770522526332, 31.94287347793579, 32.161988394601, 34.91791146142142, 32.5160790170942, 34.99742317199707, 35.00450338636126, 34.27944496699742, 33.33311421530587, 34.01628541946411, 33.37511607578823, 33.86682966777256, 35.13012681688581, 37.11167662484305, 38.19397667476109, 39.42425945826939, 42.610418455941335, 42.07104022162301, 38.2496908051627, 37.54323966162545, 35.65476444789341, 36.46514327185494, 37.99477529525757, 37.647903851100374, 37.727276597704204, 41.22404439108712, 39.431082589285715, 43.06025872911726, 43.53566837310791, 47.74858004706246, 48.79343972887312, 46.18911593300955, 52.23701558794294, 50.24651997429984, 48.79848064695086, 49.47873708180019, 51.34661783490862, 53.07238360813686, 56.35067571912493, 53.93125738416399, 52.8587577683585, 53.46109363010952, 33.14429691859654, 2.118816248008183, 12.30984812123435, 53.45453800473894, 47.781667368752615, 39.034667015075684, 6.468172303267887, 20.269013949802943, 18.17911740711757, 4.024811778749738, 9.850087676729474, 20.270660672869, 20.67777647290911, 27.142128569739207, 21.48584849493844, 32.8498774256025, 25.051577159336635, 35.767023018428254, 20.0103759425027, 53.324676173073904, 52.94687829698835, 59.56226512363979, 7.672561321939741, 0.11610378777342183, 0.31863779202103615, 0.06727282516658306, 0.1857754242207323, 0.04057503704513822, 0.09608378846730505, 0.14738707483879157, 0.24718281626701355, 0.018201355822384357, 0.10888538296733584, 0.07072233435298715, 0.08163230214267969, 0.08818946778774261, 0.12444124610296317, 0.19024174527398177, 0.08432147891393729, 0.130632077476808, 0.18578845209309033, 47.45745400020054, 74.71416010175432, 56.27815389633179, 42.29215621948242, 36.434498241969514, 35.588541167122976, 27.348139183861868, 25.99115252494812, 21.045442138399395, 21.267711537224905, 16.634459904262, 19.64189907482692, 16.13274438040597, 15.338429791586739, 24.31386607033866, 47.45352479389736, 55.8812380518232, 49.608036109379356, 15.070649691990443, 1.4819113612174988, 15.429765599114553, 41.10290949685233, 48.41020836148943, 50.52758502960205, 56.87122433526175, 61.48576968056815, 58.75904641832624, 58.4010682787214, 53.86885561261858, 54.913583278656006, 55.0696884563991, 58.73991802760533, 55.648945876530235, 54.40362024307251, 47.37143530164446, 43.49702596664429, 43.21085745947701, 44.53683778217861, 43.31856148583548, 43.47190128053938, 43.55762815475464, 43.908307211739675, 41.1675694329398, 40.53327533176967, 42.05781432560512, 42.01711177825928, 40.64881692613874, 44.1929749080113, 42.357920919145855, 45.93875496728079, 44.02253907067435, 43.19929565702166, 43.29401350021362, 42.88019963673183, 40.18376357214791, 40.416705404009136, 43.70415524074009, 42.317430291857036, 38.58623027801514, 35.31495932170323, 23.69374108314514, 25.442404644829885, 32.43203360693795, 43.438918181828086, 48.46453980037144, 58.57293891906738, 37.32447215488979, 17.327900545937673, 5.5375553369522095, 0.8876417066369737, 0.621091926736491, 0.6404929799692971, 0.8215327997292791, 0.3189219082040446, 0.07101056924355881, 0.035576876851597, 0.11752591574830668, 0.02986801229417324, 0.05232357233762741, 0.08977359599832978, 0.020536505251324604, 0.09882226080766746, 0.14612119990800107, 0.02571038226597011, 0.19844412085201057, 0.05291324980290873, 2.0708652096135274, 5.015516332217625, 9.55969032219478, 30.616153172084264, 40.120646136147634, 39.7422958782741, 25.22163084575108, 30.62760727746146, 38.3795039994376, 33.67574725832258, 38.053227015904014, 38.71698842729841, 39.37945747375488, 39.26517697743007, 39.89408622469221, 37.37943935394287, 36.68500164576939, 37.50766488483974, 37.758706774030415, 36.80807508741106, 40.30556896754673, 41.760282039642334, 42.8455593926566, 43.06469862801688, 43.57697193963187, 40.57666335787092, 39.51796981266567, 38.833648681640625, 39.630909306662424, 41.54107679639544, 39.657253401620046, 42.34487567629133, 42.400110380990164, 43.56024415152413, 45.991272926330566, 46.06554569516863, 51.378256457192556, 50.973780972617014, 51.187886238098145, 52.45098188945225, 52.45782239096505, 53.62071459633963, 51.52078138078962, 51.84217030661446, 54.392673356192454, 57.611961364746094, 55.05909940174648, 56.72917536326817, 55.21668107169015, 30.275389194488525, 1.6386551218373435, 15.249584913253784, 54.97404997689383, 52.77881874356951, 40.155376706804546, 7.820163641657148, 16.95282288960048, 19.475927455084665, 9.411722353526525, 11.72862001827785, 18.452709674835205, 23.932048661368235, 28.178671257836477, 28.725188766207012, 32.493771825517925, 39.353766509464805, 43.32042012895857, 21.035587855747767, 82.13366889953613, 58.00523287909371, 77.99569007328579, 15.899514198303223, 0.08310262645993914, 0.09827028614069734, 0.07240554224699736, 0.14395431189664773, 0.13441446237266064, 0.09637489356100559, 0.30055393810783115, 0.26246328917997225, 0.22046798334590026, 0.41658714466861313, 0.47779542739902225, 0.27284473925828934, 0.22293475669409546, 0.2046348029481513, 0.3503847356353487, 0.17975333093532495, 0.2570648645716054, 0.24065501083220753, 57.986073221479145, 81.95009054456438, 58.338770730154856, 43.915852955409456, 43.67003263745989, 40.59641361236572, 27.094738381249563, 34.57760953903198, 30.173104763031006, 25.229035888399395, 17.385214499064855, 27.859161819730485, 12.206409420285906, 18.000910009656632, 32.91842835290091, 52.95052262714931, 59.02251516069685, 50.28206695829119, 10.933164187840053, 1.4812106788158417, 20.480482373918804, 46.475562368120464, 52.11068344116211, 55.69138547352382, 60.70960031236921, 67.23935059138707, 62.64104666028704, 62.55267947060721, 54.9321106501988, 53.99775859287807, 55.46369647979736, 63.0535751070295, 58.56781809670584, 59.32136413029262, 51.38097320284162, 46.44097076143537, 46.17721019472395, 48.0144876071385, 45.56911080224173, 47.280069964272634, 46.871623584202354, 49.301971435546875, 45.26963996887207, 43.22077253886631, 44.519383907318115, 47.30500357491629, 44.727607522692, 48.20391287122454, 46.95677375793457, 49.86752005985805, 47.84706381389073, 47.280601501464844, 46.93476186479841, 44.88327496392386, 42.27543885367257, 44.131611892155235, 48.36774097170149, 51.20096274784633, 46.20866468974522, 44.90483175005232, 32.475397314344136, 37.31413670948574, 46.71607426234654, 61.42851652417864, 58.73443589891706, 62.23594583783831, 41.72474547794887, 21.551706995282853, 7.464456694466727, 1.5959956794977188, 0.5135689335209983, 0.5746381165725845, 1.065430149435997, 0.4751331816826548, 0.4456794150173664, 0.24458858690091542, 0.22399807535111904, 0.190338721498847, 0.10672257973679475, 0.12498036931668009, 0.12434226141444274, 0.21087265679878847, 0.5116391256451607, 0.09001019437398229, 0.3252871095069817, 0.46008550056389397, 2.058157822915486, 7.473375575883048, 27.12548589706421, 42.03621237618582, 42.594357694898335, 45.11654336111886, 29.09532972744533, 35.20949956348964, 45.06235088620867, 39.3253344808306, 44.010042735508506, 41.71515696389334, 42.81038761138916, 40.92324645178658, 40.01240362439837, 39.80124092102051, 38.482417242867605, 39.11358118057251, 39.47265713555472, 38.297775813511436, 41.073365756443565, 42.17413411821638, 44.01486825942993, 45.9019364629473, 45.814083439963206, 41.175935064043315, 41.70278917040144, 41.51949569157192, 43.544103486197336, 43.78790535245623, 42.79937471662249, 44.08731712613787, 46.46943753106253, 44.46792207445417, 48.31033842904227, 46.764572688511436, 52.33631229400635, 52.9167856488909, 51.59575591768537, 54.346436568668906, 54.35315547670637, 54.19027580533709, 55.843776839120046, 55.458130972726, 59.4785601752145, 61.98606777191162, 61.1506233215332, 61.336682183401926, 62.940069334847585, 38.649754183632986, 3.6751627922058105, 13.713310411998204, 63.108709062848774, 53.948016439165386, 50.90336445399693, 13.622309855052404, 30.444619519369944, 23.40645739010402, 8.823067494801112, 17.959933008466447, 31.951193945748464, 31.32509524481637, 39.361913272312705, 29.410706724439347, 46.70393575940813, 32.21255043574742, 56.275065422058105, 25.56440806388855, 73.99525778634208, 64.59864602770124, 87.68889263698033, 16.44472370828901, 0.5172879568168095, 0.37570057862571304, 0.2573407840515886, 0.415775046816894, 0.0949437478557229, 0.11399787291884422], [0.16474090649613313, 0.27972684853843277, 0.15093172820551054, 0.28109716357929365, 0.10191406668829066, 0.028487821176115955, 0.12255586870014668, 0.16320467607251235, 0.22525917339537824, 0.35664283697094235, 0.31232187950185364, 2.267334644283567, 53.27690383366176, 60.00037683759417, 42.204872948782786, 29.499435220445903, 32.758762223379954, 18.611661876950944, 22.776681355067662, 30.653294767652238, 27.39599663870675, 34.54320900780814, 30.001022202628, 20.623688220977783, 21.510377373014176, 6.066400970731463, 10.236959900174822, 36.716424873897004, 52.49682262965611, 42.25608812059675, 34.131100927080425, 4.284785577229091, 2.5176261280264174, 24.90366390773228, 37.3582820892334, 42.865066460200715, 51.49035174506051, 64.90803541455949, 59.07922635759626, 54.71812002999442, 55.24237551007952, 60.44908455439976, 49.8222143309457, 55.69093384061541, 55.92862129211426, 53.810462951660156, 41.60426718848092, 39.585957935878206, 42.98702124186924, 42.018925258091514, 40.994726044791086, 44.457058565957205, 38.79304688317435, 40.86395052501133, 38.19543579646519, 39.109770093645366, 38.21942792619978, 40.75681277683803, 36.79664530072893, 40.10034349986485, 42.069699219294954, 43.49038348879133, 39.656746183122905, 36.477271352495464, 40.365003858293804, 38.134482724326, 35.11140489578247, 36.639584745679585, 38.3595244543893, 37.22368853432791, 30.94871132714408, 26.109174626214163, 17.3389481816973, 25.62925386428833, 30.52368654523577, 37.13978556224278, 47.94875417436872, 52.6135037285941, 23.93992097037179, 7.717399784496852, 0.9715190572398049, 0.3691868324364935, 0.07074860044355903, 0.3330425204975264, 0.49021750369242256, 0.10108543972351722, 0.10280642166201558, 0.023005943545805554, 0.009535227004172546, 0.04574125339942319, 0.022805448322157775, 0.03918508520083768, 0.07584870713097708, 0.031396839900740554, 0.047936161514371634, 0.0778520003493343, 0.20185854977795056, 0.06672222114035062, 1.112617320248059, 2.4316389134952, 10.45978776046208, 23.879483801977976, 38.344519819532124, 35.31395878110613, 19.03159884044102, 20.693642684391566, 31.843653202056885, 31.38716002873012, 32.49874326160976, 31.625986984797887, 35.100235666547505, 36.435384137289866, 36.13613564627511, 33.66253178460257, 35.37443242754255, 33.81428044182913, 35.877002579825266, 35.83596999304635, 37.83580051149641, 39.517354897090364, 44.183511461530415, 44.189855166843955, 41.294735363551546, 39.62724413190569, 38.24053307941982, 36.95262541089739, 35.3196702003479, 37.15265710013253, 37.307549817221506, 37.918171405792236, 40.39652783530099, 41.57708930969238, 45.349804810115266, 47.59331907544817, 51.84227452959333, 49.16846874782017, 50.4381617137364, 51.76642451967512, 53.27765423910958, 50.1771456854684, 50.524312428065706, 48.73190648215157, 53.48722927910941, 54.167711530412944, 54.88014507293701, 50.8947799546378, 44.76705592019217, 13.363631895610265, 1.2666291360344206, 29.974730219159806, 52.71433251244681, 44.04931047984532, 30.672499588557653, 4.062148358140673, 24.532993146351405, 24.255176373890468, 9.58113854272025, 8.045780335153852, 15.296045780181885, 21.981182098388672, 29.012246642793926, 20.997475249426707, 24.795593363898142, 28.597626788275583, 55.35153865814209, 35.40777335848127, 25.314168691635132, 50.608444690704346, 60.877496583121165, 25.85541078022548, 0.5684942262513297, 0.35456961393356323, 0.19042554683983326, 0.32596374462757793, 0.1064900593566043, 0.16946801569844994, 0.1669921635517052, 0.2768536869968687, 0.0831927562664662, 0.04687401333025523, 0.0847206882068089, 0.10439711130623307, 0.15863996744155884, 0.12077030379857336, 0.12449318117329053, 0.2703815757163933, 0.16488785003977163, 5.536937381540026, 71.88613210405622, 65.48450660705566, 53.93587793622698, 36.945409706660676, 37.755507128579275, 31.585958412715367, 27.81897865022932, 32.26088905334473, 27.76391417639596, 32.985808508736746, 29.873331683022634, 26.093499490192958, 18.288909367152623, 7.092316823346274, 14.394859211785452, 38.61832053320748, 57.465326581682476, 45.18777281897408, 42.37906428745815, 6.950695599828448, 1.696398451924324, 21.367975779942103, 34.410977840423584, 41.87125519343785, 48.97321394511631, 61.095030784606934, 60.08756978171212, 55.74377836499895, 54.36415100097656, 58.08618981497628, 52.29396302359444, 57.510399545942036, 56.07952226911272, 54.69285985401699, 44.81534590039934, 42.373783656529014, 45.10722582680838, 43.26165573937552, 42.40397357940674, 45.69384833744594, 41.98103673117501, 42.91560765675136, 41.67243249075753, 43.780092103140696, 43.84883063180106, 42.54087393624442, 39.48610189982823, 42.01828949792044, 43.053550243377686, 46.05808680398123, 43.050145626068115, 42.17664589200701, 43.446609837668284, 43.214849199567524, 42.16954830714634, 41.502048764910015, 42.49768393380301, 41.406538827078684, 38.80103383745466, 35.542710849217, 23.71254117148263, 26.08042471749442, 29.98232807431902, 35.848626136779785, 42.88007456915719, 47.87203911372593, 28.4866657938276, 11.234578779765538, 1.805279655115945, 0.23525104937808855, 0.06427298113703728, 0.42286394642932074, 0.4702342131308147, 0.11931841527777058, 0.015618832881695457, 0.028376863737191473, 0.10769574823124067, 0.08522843596126352, 0.03968506372932877, 0.012999672442674637, 0.029710188441510712, 0.04022782728342073, 0.06375038703637463, 0.17221634036728314, 0.1155334926609482, 0.046787764744034836, 1.1616636770112174, 5.125315240451267, 8.526068483080183, 19.299043689455303, 40.614183630262104, 38.19141973767962, 27.112353801727295, 24.83347146851676, 38.26532425199236, 36.23893771852766, 38.085334641592844, 37.44447449275425, 39.68087727682931, 41.69631344931466, 40.98950447354998, 37.59666436059134, 40.03801121030535, 37.01659400122506, 37.40914290291922, 37.63281236376081, 40.6436961037772, 41.05192361559187, 44.95658540725708, 43.78881904057094, 43.97674349376133, 39.931349413735525, 40.021415437970845, 39.7339198248727, 40.59419018881661, 39.9654928616115, 41.75226034436907, 40.964126178196494, 43.05354676927839, 43.04012632369995, 46.97623913628714, 49.58628824778965, 53.09713656561715, 52.129193442208425, 55.029965605054585, 53.108455181121826, 54.88433483668736, 53.128907203674316, 52.9939558165414, 49.269075189317974, 55.47449050630842, 56.42329134259905, 57.89137274878365, 52.602897303445, 43.54614625658308, 8.590711048671178, 1.8316941005843026, 36.98628943307059, 54.87684120450701, 46.64017561503819, 31.646769046783447, 6.503766621862139, 22.467212063925608, 23.4211163520813, 6.96023200239454, 12.63060997213636, 16.346215622765676, 23.236615623746598, 29.82928705215454, 25.208900008882793, 27.428020886012487, 31.804788453238352, 73.04868384769985, 29.54680109024048, 32.29916320528303, 59.15777574266706, 69.61293166024345, 39.47292116710118, 0.759785461638655, 0.22507733958108084, 0.07204959634691477, 0.09055070858448744, 0.055043459603829045, 0.14034860394895077, 0.29711544833012987, 0.48744088411331177, 0.23849542385765485, 0.36215338270579067, 0.2549622745386192, 0.2295306734740734, 0.2772245742380619, 0.2502033827560288, 0.3425403008503573, 0.484697377043111, 0.49545687969241825, 6.626317645822253, 82.45816367013114, 75.84925951276506, 56.176331520080566, 39.84764099121094, 46.04238387516567, 31.54668719427926, 31.62214810507638, 38.97064631325858, 34.67692014149257, 45.57266133172171, 39.492153780800955, 29.471565995897564, 26.03210347039359, 10.64421900681087, 21.287411417279923, 43.87666858945574, 60.85824312482561, 49.56717375346592, 41.04540967941284, 5.676573591572898, 3.5325154066085815, 27.760957717895508, 42.96412345341274, 52.38411242621285, 57.97008194242205, 64.74292537144252, 61.111178398132324, 55.579307556152344, 54.82053647722517, 61.86724662780762, 56.91770083563668, 60.22855567932129, 58.174244335719514, 57.0268292427063, 47.52269063677107, 45.61120646340506, 48.624935490744456, 45.67789874758039, 45.0879202570234, 48.66995286941528, 44.173794405800955, 46.25226811000279, 42.83214589527675, 46.14633934838431, 45.62454353060041, 47.83305277143206, 42.667331150599885, 45.25763348170689, 46.66871881484985, 51.30165604182652, 45.23033400944301, 45.569534642355784, 46.29905727931431, 45.736638818468364, 44.018849577222554, 45.82225104740688, 44.63504014696394, 50.82965448924473, 46.597871507917134, 46.904290539877756, 30.578216007777623, 38.80082886559622, 48.13022027696882, 51.898641790662495, 57.377737590244834, 55.13172197341919, 36.02542304992676, 14.900681121008736, 2.719626763037273, 0.7084585215364183, 0.07970476735915456, 0.4282970034650394, 0.6344342593635831, 0.3419269866177014, 0.2343415410390922, 0.10356349710907255, 0.33602416621787207, 0.1988885205771242, 0.1796105128845998, 0.08824299741536379, 0.13274811607386383, 0.06629300024360418, 0.17790288451526845, 0.30853220713990076, 0.2811849117279053, 0.10040756966918707, 1.6174457456384386, 10.493830459458486, 17.761414289474487, 36.380528109414236, 45.08867761066982, 42.51630858012608, 32.11937509264265, 31.224030222211564, 45.89001682826451, 42.017511299678254, 43.936562061309814, 38.410326208387104, 40.99738720485142, 41.73260389055525, 43.04476772035871, 39.464343615940635, 42.28999185562134, 37.97816910062517, 39.485337597983225, 37.55078193119594, 41.676365171160015, 43.090577193668906, 46.84528991154262, 46.70260170527867, 47.37282146726336, 41.576533453805105, 44.08708783558437, 41.96282550266811, 42.09259353365217, 42.33068745476859, 44.45561334065029, 42.96679156167166, 45.661031995500835, 44.599406310490195, 50.7925580569676, 51.720326696123394, 55.82440526144845, 53.89380659375872, 55.17101403645107, 55.44539839880807, 57.05689409800938, 55.38187796728951, 56.454130922045024, 53.513441358293804, 59.463774408612935, 60.644982065473286, 63.371788706098286, 58.383544921875, 51.801707472120015, 17.12550299508231, 2.307499574763434, 35.89106920787266, 63.01901476723807, 51.67642102922712, 41.82941314152309, 11.362741776875087, 34.644402572086875, 29.945704119546072, 15.402113505772181, 15.160958903176443, 23.132813010896953, 30.421659197126115, 43.733546120779856, 27.419135877064296, 35.01146895544869, 38.15910019193377, 67.45386927468437, 47.82593086787632, 36.40926585878645, 66.5922440120152, 77.08851936885289, 51.877727712903706, 1.328929833003453, 0.5482479897992951, 0.3028315358928272, 0.504369030041354, 0.18023047676043852, 0.20313262141176633], [0.2602614701858589, 0.1713390624416726, 0.03346672793850303, 0.12032867249633585, 0.08581199643335172, 0.05283261609396764, 0.03334225747468216, 0.3482491688004562, 0.409619431410517, 0.08562828986240284, 0.24100945038454874, 12.52658154283251, 66.83271421704973, 54.396053654806956, 31.474252223968506, 36.45743424551827, 28.834588153021677, 22.845647437231882, 26.352762835366384, 24.77095331464495, 19.646210432052612, 33.54377664838518, 32.59237371172224, 20.855632986341202, 25.99387448174613, 8.629197989191328, 10.851017372948782, 26.17708110809326, 55.24183007649013, 47.51472800118582, 42.940940788814, 26.04789846284049, 0.7849149246300969, 4.9305585367338995, 15.393617595945086, 24.155678170067922, 31.396776335580007, 49.313015597207205, 59.98535483224051, 56.08196456091744, 57.35678877149309, 52.06178201947893, 52.185300145830425, 58.585786138262065, 55.189617838178364, 51.05070447921753, 44.069595745631624, 41.44936752319336, 41.79847281319754, 41.45673261369978, 43.23724324362618, 42.780600684029714, 39.70128066199166, 37.78498138700213, 37.91852923801967, 40.314823968069895, 39.487119810921804, 39.006523336683, 37.764056886945454, 39.19994381495884, 41.545346464429585, 42.41002893447876, 37.4908641406468, 38.0461676461356, 39.649853570120676, 37.49813543047224, 38.48919868469238, 37.12448910304478, 37.20354918071202, 36.005158628736226, 28.13512863431658, 26.519924334117345, 11.067888021469116, 22.438114745276316, 28.55620162827628, 33.675382477896555, 40.33337565830776, 40.548721177237375, 17.09015577180045, 3.585281329495566, 0.25828750325100763, 0.07374297548085451, 0.07620989810675383, 0.1205214714365346, 0.09863961953669786, 0.040797118164066754, 0.08959720403488193, 0.07380470859685115, 0.09015812857874803, 0.0430056817962655, 0.10193251605544772, 0.034503159645412645, 0.10836824428822313, 0.07164090113448245, 0.10900504261787448, 0.09497369839144604, 0.09062256544296231, 0.05789977990623031, 1.2202190778085162, 4.745805501937866, 14.119912913867406, 15.582923003605433, 33.311484473092214, 36.67275544575283, 21.237201997212, 14.767626592091151, 28.037836483546666, 30.1528160231454, 31.95795454297747, 31.966695376804896, 38.958615507398335, 38.89016532897949, 40.01496056147984, 34.38810089656285, 32.850412436894004, 35.2440425327846, 37.085836274283274, 39.33438103539603, 43.28714868000576, 41.351126943315776, 44.295082160404746, 44.10192223957607, 40.679698194776265, 37.40451887675694, 37.610286303928916, 35.52792508261544, 38.216638224465505, 37.02787440163748, 37.556528091430664, 38.029637881687705, 41.54407841818673, 41.73561940874372, 47.61402470724923, 49.72089917319161, 52.08641685758318, 50.13989986692156, 54.27162878853934, 53.00961358206612, 52.002083097185405, 50.155092103140696, 51.041935852595735, 51.81796973092215, 55.17168453761509, 52.023563453129356, 51.65292222159249, 43.52667393003191, 28.347634077072144, 1.3686615867274148, 7.804906266076224, 49.787480286189485, 52.096693243299214, 45.57229307719639, 26.74424171447754, 3.949672222137451, 17.26351158959525, 26.584377561296733, 49.52280950546265, 28.479469197137014, 15.635593823024205, 26.785362890788488, 25.343243428639003, 30.410604613167898, 23.77699613571167, 36.358738558632986, 38.809646129608154, 62.77588340214321, 29.911258425031388, 41.44577183042254, 60.17948750087193, 51.08627230780465, 4.244405686855316, 0.12963245968733514, 0.08972818164953164, 0.02001592979234244, 0.02898538751261575, 0.13068375470382826, 0.15949969845158712, 0.13835698153291429, 0.035304238088428974, 0.07477746318493571, 0.12108271489185946, 0.11034280833389078, 0.05733391562742846, 0.11289008986204863, 0.2182767087859767, 0.20190995559096336, 0.20857840776443481, 20.007921491350444, 81.7401020867484, 61.331860133579795, 44.88598476137434, 37.823311124529155, 35.39017357145037, 30.223104000091553, 30.746734142303467, 28.75797210420881, 23.525724955967494, 33.48174660546439, 30.992860180991038, 23.45483422279358, 25.571064438138688, 8.569596341678075, 13.37250474521092, 29.35173041479928, 58.0561979157584, 56.83480535234724, 48.12270927429199, 34.246489661080496, 1.7573936475174767, 2.6512768992355893, 9.35068850857871, 19.457733597074235, 24.39851597377232, 40.794329575129915, 55.28131321498326, 56.41242436000279, 56.440627098083496, 53.73575939450945, 56.29636859893799, 56.48944861548287, 55.314251150403706, 52.65134709221976, 44.55611555916922, 42.86411108289446, 43.73485933031355, 43.17245129176548, 46.34233066013881, 44.69352660860334, 43.94423287255423, 42.47703736168997, 40.14392260142735, 43.24672753470284, 42.98124728884016, 41.02434968948364, 41.54664577756609, 42.66146339688982, 42.269279275621685, 44.35265145983015, 41.73262126105172, 41.62245062419346, 43.96019983291626, 42.38769047600882, 41.22383941922869, 41.848392145974294, 40.794819423130576, 40.23769896371024, 34.42644453048706, 34.04939358575003, 19.467066764831543, 24.807594639914377, 26.387396131243023, 32.1070350919451, 34.30769286836897, 36.604364327022004, 20.692143610545568, 5.470096579619816, 0.2843639297144753, 0.014146534027531743, 0.10633977742067405, 0.15099856390484742, 0.042542917520872185, 0.0057030965856808636, 0.029844609621380056, 0.02470580268917339, 0.08891315931188208, 0.02403010394690292, 0.02098968013056687, 0.05355391578216638, 0.027019405238596455, 0.09066404428865228, 0.07832462713122368, 0.055543397420219014, 0.03008617487336908, 0.11537449833537851, 0.8605481290391513, 6.15216041462762, 13.875966003962926, 11.57885159764971, 35.38436835152762, 38.896342277526855, 26.79871906552996, 20.02445646694728, 32.294278621673584, 33.3553797176906, 40.00051525660923, 36.7556266103472, 40.89837190083095, 43.17010280064174, 40.89005490711757, 38.854837213243755, 36.29774727140154, 38.81936665943691, 40.70031349999564, 42.58037097113473, 44.001037870134624, 43.16045870099749, 44.19709518977574, 44.60506909234183, 41.748654229300364, 39.74624592917306, 39.91980845587594, 38.10721799305507, 40.918455668858115, 39.15431499481201, 41.67001799174717, 41.63751431873867, 43.04386098044259, 43.210610798427034, 49.45207684380667, 51.50836147580828, 54.27226802280971, 52.98132746560233, 55.166466440473286, 54.17018856321062, 54.62709515435355, 52.92917776107788, 54.078239577157156, 53.78480325426374, 57.61236783436367, 55.184052331107004, 55.99109949384417, 46.08894375392369, 25.991131680352346, 0.8535091696040971, 11.073392731802803, 56.34991141727993, 54.94438464300973, 50.68245690209525, 32.49650594166347, 5.220088669231959, 20.334509406770977, 22.402802262987407, 46.73299660001482, 37.11589765548706, 16.760618346078054, 27.016110828944615, 27.253773961748394, 27.935680593763077, 29.417158126831055, 35.70057739530291, 50.7967061315264, 60.86936719076974, 36.548764841897146, 56.83615330287388, 62.326564243861604, 72.34590830121721, 8.261461973190308, 0.08770747043724571, 0.05876051514808621, 0.027880941151774356, 0.03482064278796315, 0.12225599693400518, 0.3226239952657904, 0.2951592318713665, 0.25364618801644867, 0.3197602246488844, 0.33604566220726284, 0.29664088093808716, 0.19891544484666415, 0.5544423088431358, 0.46366279146500994, 0.4637633232133729, 0.5100307805197579, 25.715569598334177, 93.83289282662528, 71.25085830688477, 41.69893292018345, 44.861784185682026, 41.24446167264666, 32.95037269592285, 32.95989520209176, 32.09338188171387, 23.874988317489624, 42.83885438101632, 43.40358659199306, 26.12853057043893, 34.59049497331892, 13.705273083278112, 21.410476173673356, 35.695797034672324, 63.68877942221505, 55.95970058441162, 48.28490802219936, 30.77409962245396, 1.3952624393360955, 5.965319880417415, 17.51609250477382, 29.64499303272792, 34.66202667781285, 52.18627289363316, 61.64061723436628, 59.74261951446533, 60.60545376368931, 57.02566889354161, 56.36664962768555, 59.17347867148263, 57.74320241383144, 54.58265447616577, 47.51272691999163, 44.413104261670796, 45.40999010631016, 46.110472747257774, 47.231304032461985, 48.025503976004465, 47.592971665518625, 45.24818393162319, 42.341481481279644, 46.2429575238909, 46.36790697915213, 44.476197378976, 44.06920664651053, 45.612571784428184, 47.500119413648335, 47.817012854984824, 44.710285663604736, 42.78999464852469, 47.060392243521555, 45.25901617322649, 43.748800890786306, 45.28449869155884, 46.659957136426655, 49.38331052235195, 41.15528154373169, 43.630163873944966, 27.672910145350865, 36.96915170124599, 46.69254766191755, 51.692957741873606, 54.08199507849557, 47.884021282196045, 26.67007143156869, 7.279362763677325, 0.6537674048117229, 0.13864746237439768, 0.14568232345793927, 0.4637180513569287, 0.17114596494606563, 0.11678814462253026, 0.16407233237155847, 0.22836025484970637, 0.4245394393801689, 0.10258705129048654, 0.14584465617580072, 0.129754419571587, 0.10124600146497999, 0.5444922713296754, 0.2816125244966575, 0.274707127894674, 0.14661088506025927, 0.21576778484242304, 1.0363379333700453, 9.511578389576503, 16.926984276090348, 28.97115499632699, 47.28932843889509, 41.2788622038705, 32.73264741897583, 24.599143471036637, 39.61231592723301, 40.29410443987165, 43.32044792175293, 39.21523332595825, 45.80005850110735, 44.56945262636457, 43.57829557146345, 41.430798462459016, 37.92754452569144, 41.27029854910714, 42.66803986685616, 45.228499685014995, 45.748054708753315, 43.166003363473074, 47.39805037634713, 47.50075169972011, 43.62404945918492, 42.519265038626536, 43.59655891145979, 39.69036504200527, 43.926640033721924, 42.640903677259175, 44.84923573902675, 43.107742718287874, 45.83219044549124, 45.937417439052034, 54.08482299532209, 53.131161894117085, 57.15815019607544, 55.42618315560477, 56.35551166534424, 56.78190176827567, 57.59213120596749, 56.06712668282645, 55.3246282849993, 56.0129064151219, 61.32846246446882, 60.51004804883684, 61.064778327941895, 53.397969245910645, 39.48411124093192, 2.479225388595036, 8.830054777009146, 59.299206324986045, 59.727305684770855, 55.48488848549979, 36.381872585841585, 11.113703574453082, 25.346370118004934, 32.85474116461617, 57.07558127811977, 32.96648556845528, 22.800791604178293, 36.125654288700645, 36.808551039014546, 39.282054151807515, 31.644941670554026, 50.8656461579459, 46.32951470783779, 84.84821196964809, 36.77262537819998, 61.23428658076695, 71.93209443773542, 83.18274961199079, 9.689814448356628, 0.2328646145761013, 0.35568165140492575, 0.14241865144244262, 0.10534798313996621, 0.17355568706989288], [0.19863841256925038, 0.05636011270274009, 0.14613809542996542, 0.12644316868058272, 0.14521363217915806, 0.12696390359529428, 0.07950350030192307, 0.21133252712232725, 0.3171488419175148, 0.09265717305243015, 0.5358379100050245, 20.734102044786724, 64.57723862784249, 50.713386808122905, 30.5203583581107, 43.57361248561314, 31.037773336683, 23.813675676073345, 24.9237094606672, 32.69978591373989, 21.996850286211284, 24.48098761694772, 39.62701484135219, 32.9242057800293, 17.605792011533463, 9.683625340461731, 9.057015078408376, 27.347649335861206, 44.406201226370676, 46.78301668167114, 41.75925023215157, 43.521952629089355, 10.07576950958797, 0.01635080422939999, 1.3005477445466178, 2.7833328417369296, 5.424013086727687, 6.244469838482993, 42.2059360231672, 51.087158203125, 54.452313218797954, 54.852227210998535, 57.16572720663888, 56.17475775309971, 55.83326074055263, 47.1742593220302, 42.17093447276524, 41.68074253627232, 43.783375126974924, 41.770377772195, 43.96404218673706, 43.57375144958496, 41.26248529979161, 39.140467235020225, 37.849721227373394, 39.47491877419608, 39.51612854003906, 37.91554498672485, 39.55313464573452, 40.36222110475813, 40.60515444619315, 40.88225902829851, 37.89471081324986, 40.45173822130476, 40.92745706013271, 40.26424108232771, 37.863777433122905, 37.41443395614624, 36.20902572359358, 34.83359854561942, 27.519474812916346, 28.055667298180715, 8.295949356896536, 12.722974981580462, 22.897091899599346, 27.942562784467423, 30.65413202558245, 27.95300418989999, 10.839074288095746, 1.677495226264, 0.09599945334983723, 0.06300952179091317, 0.07853592972138099, 0.1312568589512791, 0.016589967467422997, 0.030811019907040254, 0.03198392196957554, 0.04267476026767066, 0.0400678965795253, 0.06317249911704234, 0.16946481301316194, 0.04555194552189537, 0.07468480922813926, 0.07298989660505738, 0.05902331176080874, 0.052754713488476615, 0.2085275583501373, 0.03364102662141834, 0.1952148505619594, 6.7297758885792325, 12.826126200812203, 13.878879036222186, 25.283315215791973, 36.405284540993826, 20.424172435488018, 13.22941267490387, 24.303871086665563, 27.025027104786464, 33.588901724134175, 34.298010553632466, 38.99552433831351, 39.8120835849217, 40.220272881644114, 35.12364067350115, 34.8190872328622, 35.08946248463222, 39.944099358149934, 41.14305966241019, 43.59002413068499, 44.44152586800711, 46.51361070360456, 42.84454148156302, 39.75484779902867, 36.41771139417376, 37.91331114087786, 36.506978375571116, 37.60940040860857, 37.41029282978603, 38.55071803501674, 40.439429487500874, 40.30644791466849, 41.36366496767317, 46.0138441494533, 49.93080425262451, 52.85249744142805, 53.11858218056815, 54.45365422112601, 52.813191481998985, 52.58224378313337, 53.37800012316023, 53.98395599637713, 51.0424291746957, 54.85604524612427, 53.111713886260986, 49.034715924944194, 38.83673715591431, 8.590973343167986, 0.7466615630047662, 26.77047290120806, 51.47358921595982, 47.09918056215559, 52.508353165217805, 31.62526089804513, 2.3869730702468326, 15.846157244273595, 47.519369397844585, 42.25913143157959, 13.081509845597402, 17.106063672474452, 29.174127510615758, 26.25015183857509, 35.49419157845633, 22.400500672204153, 32.901033537728445, 15.900136062077113, 29.452104091644287, 24.637961319514684, 33.485116481781006, 48.24520601545061, 66.8995280947004, 22.829315696443828, 0.6023035092013223, 0.11337221613419907, 0.09021504409611225, 0.15733423536377295, 0.06363935156592301, 0.15166112620915684, 0.05423015395977667, 0.04287680085482342, 0.08931317606142589, 0.11481100214379174, 0.1386830990335771, 0.09311597807598965, 0.166228675948722, 0.29111725304807934, 0.1707039808056184, 0.22719967498310975, 31.68520995548793, 78.5027904510498, 57.303642000470845, 36.26911721910749, 40.01141350609915, 37.533522605895996, 30.03988000324794, 30.14959553309849, 31.157007898603165, 26.18990053449358, 30.132478645869664, 39.049758502415244, 33.46414334433419, 22.083895581109182, 13.970315592629568, 11.429274252482823, 32.55183792114258, 48.335751465388704, 55.070268630981445, 49.48086323056902, 49.69389499936785, 14.081921032496862, 0.019711113202252557, 0.9108157945530755, 1.5747029249157225, 3.0292536914348602, 5.039507159164973, 42.76683282852173, 49.93224947793143, 57.53314099993025, 57.02951124736241, 57.0857048034668, 58.522175380161826, 57.409734044756206, 50.59324550628662, 44.558279923030305, 43.52525649751936, 44.331191948481965, 44.42944642475673, 47.01944998332432, 44.55084882463728, 44.315714836120605, 43.5439749445234, 42.28812626429966, 42.807431152888704, 42.86789090292794, 41.11946357999529, 42.82358224051339, 41.03311136790684, 43.65077917916434, 43.1010377066476, 40.87641559328352, 43.95611081804548, 43.83462503978184, 44.451263768332346, 41.97355004719326, 42.74296576636178, 41.24106747763497, 41.20013216563633, 35.06596367699759, 34.76831674575806, 15.662024770464216, 17.318622963769094, 24.378397464752197, 24.724594933646067, 25.367928641183035, 28.669650077819824, 14.62134964125497, 3.2534655460289548, 0.15411218468632015, 0.05884198684777532, 0.10683461943907396, 0.06364344991743565, 0.07088381890207529, 0.015528407912435276, 0.026422596370269145, 0.06351368009511914, 0.04264067406100886, 0.09821354025708777, 0.14231381778206142, 0.08749424759298563, 0.05269413388201168, 0.04931634584707873, 0.029809471685439348, 0.06642169798059122, 0.08367106917181186, 0.04659521007644279, 0.36660915932485033, 7.705190931047712, 13.104217427117483, 9.331703424453735, 25.79668286868504, 37.73049013955252, 26.976163898195537, 18.626128026417323, 28.991426365716116, 34.0258218220302, 39.445590427943635, 36.91686303274972, 40.70677185058594, 42.3719528062003, 42.39441285814558, 37.05627516337803, 37.74205194200788, 38.70382159096854, 43.01982716151646, 43.599386828286306, 44.79696791512625, 45.38800948006766, 45.543784618377686, 44.66080059323992, 41.706242425101145, 40.08060714176723, 40.35567937578474, 38.3025665964399, 39.36796862738473, 41.46928800855364, 41.39242008754185, 42.41092872619629, 41.938183716365266, 43.43186576025826, 47.55987739562988, 52.100577286311555, 55.50562538419451, 56.21143729346139, 55.75040347235543, 55.84877954210554, 56.34551320757185, 55.891983440944124, 54.81880637577602, 53.28743035452706, 56.33892631530762, 56.803708689553396, 52.68538284301758, 39.80732754298619, 5.157024647508349, 0.8914266292537961, 34.81442151750837, 55.11103023801531, 53.91576290130615, 57.613694940294536, 34.003914151872905, 2.950666525534221, 17.736859355654033, 50.38804088320051, 49.808370045253206, 23.405607972826274, 17.01392708505903, 28.729237828935894, 28.44980386325291, 33.159447465624126, 26.841900382723125, 29.390873091561453, 26.68894621304103, 37.83308376584734, 29.075900827135357, 45.03843866075788, 53.238924980163574, 76.17469923836845, 32.58966391427176, 0.4603997437017304, 0.06026122426348073, 0.05940494021134717, 0.17342170354511055, 0.04341490626601236, 0.29103205619113787, 0.25382575552378384, 0.2341955474444798, 0.3767762194786753, 0.24308924164090837, 0.42588771560362404, 0.1961088204490287, 0.41984481843454496, 0.6341691421610969, 0.4705037272402218, 0.6429800008024488, 42.16237776620047, 85.92764241354806, 68.01591600690568, 37.14065408706665, 58.29398264203753, 40.12624985831124, 33.927723680223735, 33.62132201875959, 41.60230779647827, 29.310822895595006, 33.34172650745937, 50.06620379856655, 43.09368651253836, 22.87055672918047, 15.512181656701223, 20.20576102393014, 36.64480979101998, 54.18079498835972, 55.387061323438374, 49.33347804205758, 50.35544340951102, 11.80894032546452, 0.11244039077843938, 2.3904397870813097, 3.7493686846324374, 5.996079555579594, 10.20506419454302, 53.93661444527762, 52.052488803863525, 62.0418062210083, 58.26520667757307, 59.048056738717214, 63.03922707693917, 60.507553645542686, 51.73273270470755, 46.263809067862375, 45.725955963134766, 47.90144736426217, 46.006131649017334, 47.64588567188808, 48.349953583308626, 49.210585253579275, 46.4563228062221, 44.67746932165963, 45.006532532828196, 46.44590745653425, 44.35266188212803, 45.933637619018555, 44.15806368419102, 46.84351464680263, 46.80112368719918, 45.12183094024658, 45.98247650691441, 45.86547926494053, 46.48791626521519, 45.58934048243931, 44.72334827695574, 47.81852756227766, 47.22902849742344, 42.68314177649361, 42.719157763889854, 22.373906442097255, 26.454830135617936, 43.46590845925467, 43.26001249040876, 48.3940920148577, 41.42271075929914, 19.777013744626725, 5.402072412627084, 0.4367629220443112, 0.25453911295958925, 0.10601103398948908, 0.29333858670932905, 0.17441247323794024, 0.12880339846014977, 0.07292122886117015, 0.10991043903465782, 0.12444060828004565, 0.14907415716775826, 0.31925428179757936, 0.14828351459332875, 0.2756788171827793, 0.28846627101302147, 0.12266192372356143, 0.2357168500976903, 0.23255061571087154, 0.283604947584016, 0.6475382362093244, 8.727957078388759, 15.229009560176305, 21.974433660507202, 38.57919175284249, 42.92790944235665, 32.79345110484532, 23.80780792236328, 33.67745304107666, 40.03390482493809, 44.24260241644723, 39.843520709446494, 42.61742224012102, 44.23106145858765, 45.45526456832886, 40.9226211139134, 39.96712916237967, 38.99448210852486, 46.599810055324006, 46.57656833103725, 47.59494495391846, 47.06169155665806, 46.14293473107474, 49.287710257938926, 44.23833622251238, 42.46194240025112, 41.91428886141096, 40.37186867850167, 42.345848424094065, 42.77198839187622, 42.84257166726248, 46.05774286815098, 44.396647453308105, 46.81293562480381, 50.62795523234776, 52.2827798979623, 57.51078864506313, 56.992404392787385, 57.68001896994454, 57.18845476422991, 58.863734926496235, 57.878393513815745, 56.710873808179585, 56.2837541443961, 61.30169105529785, 60.747412409101216, 57.7084127834865, 49.33943959644863, 12.107282945087977, 0.9387959731476647, 32.51642642702375, 60.60820525033133, 56.712791510990684, 61.241769790649414, 40.51166296005249, 7.976523297173636, 21.497194903237478, 55.425116607121055, 47.53637511389596, 18.77509219305856, 23.08635561806815, 39.50486551012312, 36.71556329727173, 46.71608468464443, 28.910507644925797, 45.974968978336875, 20.922709158488683, 44.94638197762625, 30.99882868358067, 48.762659209115164, 63.45733492715018, 89.87731116158622, 39.22029856273106, 1.0100298821926117, 0.46721185530935017, 0.22567451825099333, 0.1799361418400492, 0.18515186410929474], [0.16529322043061256, 0.031349281381283484, 0.07278241416705505, 0.008292421415847327, 0.10283168352075986, 0.025910014053806663, 0.10858166390763861, 0.09230957991842713, 0.2686701475509575, 0.032401679017181904, 0.32439673585551126, 38.707267897469656, 73.93530178070068, 37.095098223005024, 32.37443651471819, 43.74982227597918, 22.059576886040823, 26.749216624668666, 27.609412295477732, 37.57054955618722, 26.597167457853043, 25.14959713390895, 26.149936233248027, 34.81638438361031, 25.84260525022234, 7.366172688347953, 5.6184857828276495, 19.932312931333268, 51.620085035051616, 48.02295746122088, 31.895264421190532, 49.98444781984602, 20.835672548839025, 0.4629397988319397, 0.06778896639921836, 0.16420080619198935, 0.08827885120574917, 2.2827181730951582, 16.38677225794111, 56.59876114981515, 55.58917052405221, 56.32566915239607, 56.84807293755667, 57.90939637592861, 51.66457782472883, 45.28647892815726, 42.60589517865862, 44.55706746237618, 45.223243372780935, 47.97676236288888, 47.65598835263933, 42.43411833899361, 37.93920360292707, 39.278795446668354, 40.48719140461513, 40.035502910614014, 38.541490827287944, 40.99526105608259, 40.29594223839896, 40.52838379996163, 39.45404291152954, 38.65496185847691, 40.073603357587544, 41.41192715508597, 42.89954342160906, 42.27908318383353, 41.256155490875244, 39.053173542022705, 33.587244578770225, 35.91113560540335, 29.92220183781215, 27.922062124524796, 4.146373552935464, 4.1313207149505615, 16.46846570287432, 24.469976459230693, 21.916511740003312, 19.663422857012065, 9.733302354812622, 1.5023687034845352, 0.17153828032314777, 0.04166146321222186, 0.1271890550851822, 0.045117920597216914, 0.03862346515857747, 0.07573115093899624, 0.07673120299088103, 0.02539035800977477, 0.1226137884493385, 0.12117644771933556, 0.010845721549620586, 0.06051836867949792, 0.032295400077211, 0.044031026240970404, 0.06686167365738324, 0.062085106037557125, 0.07131421366440398, 0.025006320759920136, 0.2440635093620845, 5.7027066349983215, 11.71040792124612, 10.399326273373195, 16.158866133008683, 32.24992479596819, 22.574245589120046, 13.957087091037206, 24.107739073889597, 27.243996109281266, 30.889054094042095, 35.63197088241577, 38.67184598105294, 38.93484224591936, 40.014887605394634, 35.08603702272688, 35.82245227268764, 38.04469462803432, 42.23501076017107, 42.90346915381295, 44.720600264413015, 44.24171304702759, 43.325269971575054, 42.39591366904122, 39.926384925842285, 37.77789075034005, 38.290692125047954, 36.27609668459211, 38.294440678187776, 37.44910546711513, 41.55397612707955, 42.724646840776714, 39.10394055502755, 40.75120210647583, 44.791072368621826, 47.29710347311837, 52.7756746837071, 54.853623798915315, 53.71048879623413, 57.40327222006661, 53.224253858838765, 52.45635979516165, 53.293318952832905, 56.28482069287981, 53.559886591775076, 53.52969319479806, 45.27821752003261, 20.672025101525442, 0.5567938940865653, 5.485753910882132, 47.76086098807198, 51.85024758747646, 50.423907484327046, 49.34870154517037, 18.233438423701696, 0.2662348582276276, 14.745991638728551, 39.14190551212856, 16.408488852637156, 12.425903013774327, 18.243898936680385, 25.59251352718898, 26.018471104758127, 26.604553392955236, 29.035490104130336, 37.41156087602888, 26.001041548592703, 32.149016107831685, 33.437556062425884, 25.53779993738447, 46.46091556549072, 58.15382705415998, 42.378244400024414, 0.5483073751841272, 0.11160823543156896, 0.16033213878316538, 0.1323647845004286, 0.03480213235265442, 0.11549784243106842, 0.05993874371051788, 0.12467140518128872, 0.13739640664841446, 0.13122675913785184, 0.10200758916991097, 0.054572698793240955, 0.14955088230116026, 0.317145829222032, 0.09143169809664999, 0.21952730310814722, 52.14041478293282, 79.75177083696637, 50.29992730276925, 30.892274584089005, 42.518278394426616, 28.71729908670698, 31.12664427076067, 30.070980140141078, 33.65670224598476, 29.15902212687901, 29.45997987474714, 30.54937056132725, 35.321296078818186, 26.564347641808645, 8.707320928573608, 8.719407320022583, 20.081508125577653, 56.26701940808977, 53.059310572487966, 37.26337317058018, 55.485878603799, 25.273959466389247, 0.6587234788707325, 0.08016399985977582, 1.188419669866562, 0.12659602904958384, 1.5929507400308336, 21.312219960348948, 57.0209128516061, 59.35270050593785, 60.45865222385952, 58.55768762316023, 58.99746690477644, 54.46200248173305, 46.374163831983296, 44.05910396575928, 45.23447166170393, 47.32924236570086, 51.132241589682444, 49.80159207752773, 45.623987674713135, 41.89962816238403, 41.999873297555105, 42.43203387941633, 42.75526755196707, 42.251238277980256, 43.85489640917097, 42.11169065747942, 42.751032624925884, 41.373531409672324, 43.44364643096924, 40.72710575376238, 45.30882780892508, 45.70782116481236, 46.285820960998535, 43.64772891998291, 43.25118827819824, 38.46347992760794, 41.68703760419573, 35.43421820231846, 33.69112362180437, 12.290351475988116, 13.10653725692204, 20.59997923033578, 21.557286398751394, 17.663609709058488, 22.56004520824977, 12.967322281428746, 2.104247612612588, 0.13526219688355923, 0.040382204178188524, 0.09236320454095091, 0.09881527868232556, 0.015017501577468855, 0.04715780720912984, 0.0540050805014159, 0.021300464436145763, 0.08227418269962072, 0.09202361812016793, 0.01164130216264831, 0.052088141042206965, 0.04340354758980019, 0.06051484029740095, 0.08089357428252697, 0.04880512399332864, 0.08183936388897044, 0.028104469246630157, 0.3639569559267589, 6.095483090196337, 11.00654671873365, 6.953397580555507, 19.390230110713414, 37.79482698440552, 27.471818855830602, 19.630523136683873, 30.14864362989153, 34.250707217625205, 36.35210997717721, 38.903766427721294, 40.865034443991526, 41.41633231299264, 39.90159027917044, 39.18708617346627, 38.12269163131714, 42.43450743811471, 44.29435954775129, 45.09485803331648, 46.55790546962193, 45.39424548830305, 46.37914221627371, 44.578165667397634, 42.8155049596514, 40.195644991738455, 40.89130210876465, 39.630617482321604, 39.371369770595, 42.08453014918736, 45.19926166534424, 45.063247203826904, 40.80446004867554, 45.15815959657942, 47.78346695218767, 52.44518709182739, 54.08763354165213, 55.84629208700997, 56.48843765258789, 59.44086619785854, 56.25384562356131, 57.025377069200786, 55.18101249422346, 57.90791293552944, 57.44044508252825, 55.86997849600655, 43.180042198726106, 15.02570526940482, 0.19541423129183905, 9.857417157718114, 52.46986709322248, 53.604528767721995, 57.410856178828645, 52.187676429748535, 18.183209896087646, 0.9567036522286279, 22.09680012294224, 41.86733293533325, 20.036033902849468, 19.95562240055629, 16.18379626955305, 25.11102420943124, 26.604855639593943, 27.093560661588395, 33.99448892048427, 33.66074957166399, 25.439993619918823, 41.1059250150408, 29.800431183406285, 33.91418511526925, 54.16854878834316, 66.77257755824498, 52.70668601989746, 0.39115462079644203, 0.06721454579383135, 0.08562202698418073, 0.08396564157945768, 0.03670771652832627, 0.3867694389607225, 0.13983001320489816, 0.44573801330157686, 0.1917011791041919, 0.17257291051958287, 0.11362461080508572, 0.1617263653980834, 0.23561979244862283, 0.4524617525083678, 0.33446776973349707, 0.49765245616436005, 65.86549718039376, 90.34079074859619, 56.41109377997262, 41.56535380227225, 62.12454536982945, 27.42391276359558, 37.18767949513027, 36.31805338178362, 49.636197158268516, 36.36806304114205, 32.74282305581229, 35.65919739859444, 46.49010494777134, 35.67621006284441, 10.153722218104772, 14.010842697960989, 31.482197489057267, 62.64770998273577, 56.37058230808803, 38.39775691713606, 59.025641850062776, 25.146328006471904, 0.7244934439659119, 0.3100541340453284, 0.9007560514978, 1.1782421874148505, 3.009375980922154, 30.826231956481934, 61.651303563799175, 62.65769454411098, 63.27920395987374, 61.52606923239571, 62.63295200892857, 55.76029423304966, 50.233957631247385, 45.18392351695469, 48.02951308659145, 49.021955558231895, 52.7501574243818, 51.29334947041103, 47.70132187434605, 44.8138416154044, 45.406495162418906, 45.22452531542097, 44.83755234309605, 43.911927223205566, 47.813754149845664, 45.46615239552089, 46.39957686832973, 43.50516925539289, 47.38303879329136, 43.408578872680664, 47.27615465436663, 49.08410024642944, 48.87932641165597, 47.27174254826137, 48.22244371686663, 42.83527258464268, 51.09386321476528, 41.29280376434326, 43.64538737705776, 19.554687023162842, 22.599874019622803, 38.392677783966064, 42.21059479032244, 40.048648902348106, 35.88318995067051, 16.317073140825542, 3.2614498947347914, 0.47415153150047573, 0.07349445524492434, 0.26507244631648064, 0.22895940127117292, 0.14382651661123547, 0.2712328928921904, 0.26781625194208963, 0.08289348161114113, 0.18697653976934298, 0.4180568243776049, 0.14275356275694712, 0.20682839809783868, 0.10391841163592679, 0.1997536120137998, 0.15131824889353343, 0.16669702795999392, 0.13040379115513392, 0.11597637246762003, 0.4965848763074194, 6.252108080046518, 12.680067249706813, 15.06209819657462, 35.44591549464634, 41.11393976211548, 33.74282169342041, 26.29238646371024, 36.34982054574149, 39.69533995219639, 40.60790940693447, 41.91911438533238, 45.11741188594273, 45.03928634098598, 43.10576248168945, 42.314550263541086, 40.23526362010411, 44.65030881336757, 48.48295600073678, 47.05121714728219, 49.45457124710083, 47.79821450369698, 48.592820916857036, 47.40603385652815, 44.85092415128435, 42.15176439285278, 44.277478899274556, 41.95842381886074, 41.95049245016915, 44.071503026144846, 47.82801185335432, 47.98125089917864, 41.49720587049212, 45.82975510188511, 51.476031507764546, 54.20590230396816, 57.62875516074044, 56.90235226494925, 57.94378995895386, 62.901694434029714, 58.15325730187552, 58.78495625087193, 56.60623741149902, 60.50544834136963, 60.22152410234724, 61.897978510175435, 51.97287287030901, 25.59027794429234, 0.7798424682446888, 8.315347858837672, 55.22334439413888, 59.96333599090576, 58.06878457750593, 59.40925884246826, 28.679678065436228, 3.8785283139773776, 20.925557919910975, 47.18908330372402, 21.036848953792028, 17.28060415812901, 22.819098370415823, 37.140365736825125, 38.611764907836914, 35.46884454999651, 36.877612658909385, 51.27153212683541, 34.91076176507132, 46.929870332990376, 43.06401770455496, 35.50577769960676, 66.35569953918457, 75.11028385162354, 65.723434312003, 0.7418023837464196, 0.3056700921484402, 0.24106354319623538, 0.18749932385981083, 0.05941812414675951], [0.05881648750177451, 0.05240230614851628, 0.052600584258990626, 0.046433175913989544, 0.09031046647578478, 0.11389350066227572, 0.1791386189205306, 0.06938275694847107, 0.09999588890267269, 0.16800143010914326, 0.6055994523423058, 47.98577765056065, 62.31523173195975, 46.34484590802874, 47.929083824157715, 31.8929854120527, 25.674606493541173, 20.308900083814347, 30.43298476082938, 38.326253005436485, 30.41310943875994, 30.908648014068604, 29.072603906903947, 30.774290697915212, 28.94733136040824, 18.58887004852295, 4.350436065878187, 6.522406467369624, 31.652605533599854, 66.19913578033447, 37.13951458249773, 48.031257084437776, 45.26176071166992, 6.172915552343641, 0.4104157601084028, 0.8614309845226151, 0.31999000374759945, 0.8917607941797802, 14.169120056288582, 52.25220087596348, 54.79102052961077, 57.837781293051584, 56.93894842692784, 55.950313568115234, 49.79443890707833, 42.0044139453343, 44.03821073259626, 46.01059586661202, 50.933081899370464, 52.18974699292864, 54.34551593235561, 47.700290066855295, 40.98846224376133, 40.388554777417866, 40.83985417229788, 39.333290168217246, 40.72588634490967, 39.49136168616158, 38.905670234135215, 39.77870791299002, 38.23590210505894, 39.6085604258946, 41.74649681363787, 42.101195403507774, 40.896916253226145, 44.22290774754116, 41.134801728384836, 38.80454962594168, 34.940343720572336, 33.41964708055769, 29.845799446105957, 23.349909475871495, 1.9078962973185947, 7.797475167683192, 6.063015460968018, 16.81226430620466, 15.891556773866926, 11.670085787773132, 7.7602710383278986, 0.8238467127084732, 0.15106351327683243, 0.023492656714682068, 0.019804388018591062, 0.060662109537848403, 0.030878720738525902, 0.032260964425014596, 0.08784230213080134, 0.09602448450667517, 0.05245148636666792, 0.04388101232637252, 0.03159442590549588, 0.0368872806429863, 0.08794919175228902, 0.03130011473383222, 0.03748300385528377, 0.04348350276372262, 0.09453203994780779, 0.06196353970361607, 0.4253363651888711, 3.296976685523987, 6.167403025286538, 5.849562891892024, 5.534186329160418, 27.220808233533585, 23.720675774982997, 15.835524763379778, 23.084517819540842, 28.02815764290946, 31.055744852338517, 36.30555704661778, 37.99374696186611, 36.364251954214915, 37.01224790300642, 32.81873907361712, 38.14123984745571, 41.00085088184902, 42.25426421846662, 42.97271490097046, 42.4470419883728, 42.82782758985247, 41.89414603369576, 41.73331955501011, 37.459704944065635, 34.92157316207886, 36.955595765795024, 36.26844324384417, 39.0538683618818, 43.04596628461565, 45.35712473733084, 42.5357392174857, 37.6754013470241, 41.72494697570801, 42.357330322265625, 48.37754487991333, 50.4021109853472, 53.16897399084908, 49.90346309116909, 54.05664805003575, 57.11013119561331, 55.91940450668335, 57.41219023295811, 55.36055047171456, 51.997410433632986, 48.004982471466064, 22.31091407367161, 1.8958702683448792, 0.1533934668238674, 22.374007190976823, 45.24352516446795, 45.7228535924639, 43.46692637034825, 45.750649860927034, 9.328766942024231, 0.09865996201655694, 23.513673305511475, 26.067652191434586, 15.76774856022426, 26.202264853886195, 18.83456529889788, 25.617794547762188, 25.7889495236533, 34.439361231667654, 24.65356523650033, 33.3475456237793, 44.28530257088797, 23.223148277827672, 60.95467022487095, 41.420011384146555, 42.26656947817121, 60.292506899152485, 42.40931674412319, 0.7728171880756105, 0.05431062142763819, 0.14964480511844158, 0.07273832296154328, 0.04439031731869493, 0.12807856021182878, 0.05597420269623399, 0.1318536712122815, 0.07809055290584054, 0.01711273629085294, 0.07253284898719617, 0.13917138640369686, 0.01926754298619926, 0.15340359056634562, 0.03148511391399162, 1.1750499244247163, 62.069182123456685, 69.08689744131905, 55.80307081767491, 48.48406771251133, 34.375229358673096, 30.338881833212717, 26.680042096546718, 35.34186274664742, 34.10131399972098, 29.894607067108154, 30.998255457196915, 31.499884128570557, 31.497601645333425, 25.95425237928118, 12.800687108721052, 7.0018590944153924, 7.560955013547625, 32.5376740183149, 65.0768071583339, 41.496757711683, 49.28308275767735, 50.871472222464426, 9.64232177393777, 0.5549260771700314, 2.0442145253930772, 0.47296311812741415, 0.9211502628667014, 20.841795648847306, 57.41495909009661, 55.0321056502206, 59.60200881958008, 57.115321499960764, 57.45828110831124, 51.28739139011928, 44.26150499071394, 46.795606817517964, 48.830008098057334, 54.23228808811733, 54.851473331451416, 55.07241562434605, 49.2091052872794, 43.65376690455845, 44.19611201967512, 44.322899273463655, 42.99401460375105, 44.422321047101704, 43.415381159101216, 42.09422288622175, 41.31284931727818, 41.618768078940256, 44.576605796813965, 43.90964126586914, 44.54475178037371, 43.679100036621094, 45.80732979093279, 43.61731318065098, 44.683385712759836, 41.23410190854754, 39.663392135075156, 36.92998470578875, 29.260841029030935, 11.361081157411848, 17.134384529931204, 17.025349923542567, 13.711289354733058, 11.13983314377921, 13.71055805683136, 12.407986215182714, 2.4704339631966183, 0.06484186489667211, 0.0607212506500738, 0.03331749773185168, 0.0739752244470375, 0.015662450809031725, 0.04312872394387211, 0.010044744886857058, 0.03211460102881704, 0.31457119594727245, 0.16426282429269382, 0.05174746896539416, 0.041500867544008155, 0.05254757031798363, 0.04497230698221496, 0.0258407152723521, 0.013008138863369823, 0.036087840862040005, 0.03425465976553304, 0.4836010815841811, 3.4864625292164937, 6.454543845994132, 5.70706011567797, 11.439349140439715, 32.885931628090994, 29.84352043696812, 21.107296739305767, 29.69801821027483, 35.09457288469587, 35.79647643225533, 39.14526149204799, 40.0463490486145, 39.34670713969639, 38.411347593579976, 36.34337609154837, 40.645492213112966, 42.299583843776155, 45.279350076402935, 47.85883406230381, 45.421895844595774, 46.01267337799072, 44.058509894779746, 44.13058703286307, 40.64240026473999, 38.280530384608674, 39.1577057157244, 38.37061030524117, 40.40864201954433, 46.025315625326975, 49.12160314832415, 44.97248983383179, 43.404705251966206, 43.7982234273638, 45.099391732897075, 48.862751483917236, 50.19165005002703, 52.8081818308149, 51.83112267085484, 54.78052180153983, 57.079819679260254, 56.70358862195696, 56.858220781598774, 58.59176853724888, 54.85720212118966, 43.70472846712385, 15.688596418925695, 0.419312059879303, 0.3728818084512438, 27.879337651388987, 51.280380657741, 48.52092443193708, 48.05553061621529, 47.14994410106114, 10.416505694389343, 1.688370025583676, 25.111232655388967, 23.382394041333878, 16.134453637259348, 28.3093512398856, 19.76951663834708, 24.971092700958252, 27.074731043406896, 32.465259892599924, 27.281875950949534, 32.66529505593436, 38.85419797897339, 30.521032333374023, 63.48834473746163, 47.24246283939907, 48.665846484048025, 66.03138542175293, 53.610976696014404, 0.780211537012032, 0.044680835479604344, 0.08639433554240636, 0.06921595268483673, 0.056906543738607845, 0.3232350024793829, 0.22569590567478112, 0.31794302644474165, 0.2651552547301565, 0.19697631389967032, 0.21684197363044533, 0.1961617868925844, 0.10598928015679121, 0.1948500294238329, 0.31521458285195486, 2.2084603863103047, 76.46988650730678, 77.96267918178013, 60.52408340999058, 61.09644821711949, 45.33495650972639, 32.46192128317696, 28.981023175375803, 41.9135627746582, 50.10007974079677, 40.666097096034456, 40.002780369349885, 36.30270481109619, 41.617232527051655, 37.970383644104004, 24.410336596625193, 11.8035181249891, 16.24905722481864, 40.25491312571934, 71.64766992841447, 45.30807045527867, 55.38992745535714, 51.04293291909354, 8.356845106397357, 2.0581196078232358, 2.999347124780927, 0.8406628189342362, 1.2956278771162033, 28.399634395326885, 63.62944875444685, 58.99339526040213, 63.813374519348145, 60.33670439038958, 60.80805628640311, 53.755256039755686, 46.79789277485439, 47.365042958940776, 50.73744147164481, 55.699275153023855, 57.94608286448887, 58.63982922690255, 51.37574120930263, 46.03727347510201, 44.79904890060425, 46.20996052878243, 45.69731201444353, 45.807718890053884, 45.80150372641427, 44.99537025179182, 45.32000398635864, 45.118283884865896, 48.22904450552804, 46.1553442137582, 48.78869758333479, 45.68152570724487, 53.45653213773455, 48.044986724853516, 48.00631652559553, 47.229372433253694, 49.198776790073936, 45.749826499394004, 40.50071259907314, 16.387513978140696, 23.083545071738108, 30.68025377818516, 34.43323292051043, 25.5157185622624, 21.315126044409617, 13.400964566639491, 3.298893519810268, 0.26732729960765156, 0.11739920611892428, 0.24361787470323698, 0.16328018344938755, 0.18216789779918535, 0.10308536740818194, 0.09101564756461553, 0.1903371744390045, 0.5011877321771213, 0.18512100433664663, 0.1964168074939932, 0.21047542882817133, 0.24310644928898129, 0.13962322287261486, 0.12147447387022631, 0.15068022241549833, 0.24245736269014223, 0.20057317375072412, 0.6014774335282189, 3.1876904240676334, 7.337162222181048, 8.66686851637704, 20.78865930012294, 38.391170024871826, 36.5208990914481, 28.477570601872035, 36.22643443516323, 41.15232161113194, 40.865187304360525, 44.15468685967581, 44.92819159371512, 42.57925231116158, 42.29154477800642, 38.767731121608186, 43.44601229258946, 44.34005437578474, 47.366918972560335, 50.22949341365269, 48.37646443503243, 48.51906926291329, 47.77371515546526, 50.325239590236116, 43.070382254464285, 42.363264083862305, 41.564603396824424, 40.7835807119097, 43.163905007498606, 48.4578869002206, 50.209885597229004, 46.965309619903564, 43.951156752450125, 46.9957149369376, 46.69245038713728, 53.12901142665318, 52.87724692480904, 56.40360362189156, 52.483700956617085, 61.0506317956107, 61.71378871372768, 59.08306871141706, 60.08652755192348, 60.411605971200125, 58.7539255959647, 54.1222494670323, 24.366206850324357, 2.826832039015634, 0.2876141938780035, 27.99237094606672, 57.115818296160015, 55.23961707523891, 52.02496351514544, 54.44493423189436, 16.6260803767613, 2.7659812356744493, 30.961916378566197, 33.758260590689524, 22.622778756277903, 35.759890692574636, 26.65960223334176, 35.91745499202183, 34.31383507592337, 45.048867906842915, 32.562329701014924, 47.13105889729091, 54.96394729614258, 32.95258569717407, 79.68717343466622, 52.511167185647146, 60.07697377886091, 76.31091172354562, 67.09994193485805, 1.6646549552679062, 0.11385129578411579, 0.19121111397232327, 0.14521275008363382, 0.11198772649679865], [0.11573862736778599, 0.056047810175056965, 0.0956992558868868, 0.05611585366672703, 0.08908696605690888, 0.08254931507898228, 0.06521290820091963, 0.013514041850742484, 0.13151683285832405, 0.07876250613480806, 4.4707614949771335, 61.87500776563372, 61.0261116027832, 30.194758823939733, 28.304140090942383, 32.82934202466692, 26.74987322943551, 20.213892153331212, 29.34806524004255, 36.68550886426653, 30.874643530164445, 32.70264162336077, 29.647074018205913, 30.2139983858381, 24.33797284534999, 12.110737068312508, 5.757880977221897, 4.309399136475154, 21.93122455051967, 49.42433268683297, 44.103555066244944, 46.18534653527396, 53.01883384159633, 25.006294012069702, 0.9911591176475797, 1.9369834108012063, 0.33491872410689083, 2.4398523356233324, 17.49814009666443, 51.713510513305664, 57.1280505997794, 55.34880454199654, 54.76214381626674, 54.14076294217791, 45.66879660742623, 41.8515431540353, 43.59902204786028, 49.15829311098371, 53.11251640319824, 53.01933758599417, 52.39356892449515, 50.76790237426758, 45.067311900002615, 40.77008383614676, 41.52293157577515, 41.238524436950684, 42.18765183857509, 41.030540534428184, 40.91261918204171, 38.415103094918386, 39.00062084197998, 38.83392660958426, 41.5463296345302, 40.494097914014546, 43.68636090414864, 39.735465799059185, 42.51434918812343, 38.51125921521868, 38.58762339183262, 30.410368374415807, 29.37132086072649, 13.77450840813773, 5.484654792717524, 12.43574253150395, 7.24708490712302, 5.530176784311022, 6.453912428447178, 4.969390281609126, 3.951682422842298, 0.7387802973389626, 0.18493382366640226, 0.031108130035655837, 0.011298925266601145, 0.044147106619285684, 0.06270084264022963, 0.07826640882662364, 0.07095136027783155, 0.016640606535864726, 0.0855654032368745, 0.21175602796886647, 0.09233935403504542, 0.061641758041722436, 0.019655902504122684, 0.02593124541454017, 0.02772459141643984, 0.010663009032474031, 0.014689116073506219, 0.032349509852273126, 0.05190878048805254, 0.5818762396063123, 1.2161034643650055, 1.7955190645796912, 1.818998547536986, 25.46346810885838, 26.12360950878688, 14.488414100238256, 22.3544636453901, 29.107838221958705, 30.57607248851231, 34.0092191014971, 34.70866298675537, 35.236006941114155, 35.02116169248308, 36.382772377559114, 40.24942752293178, 40.88183866228376, 42.1272303036281, 42.297579288482666, 44.80104303359985, 42.45131860460554, 38.27783795765468, 41.41575561250959, 38.30899715423584, 36.3745561327253, 36.680169173649375, 37.58968489510672, 40.989410672869, 45.33519969667707, 47.18698147365025, 44.809002195085796, 40.038059847695486, 39.02293150765555, 43.3333854675293, 46.25846937724522, 49.45279598236084, 52.43839175360543, 51.71403510229928, 49.56220926557268, 49.56629828044346, 52.96309886659895, 54.31293930326189, 54.35030671528408, 38.773793424878804, 18.747070108141216, 2.4832429672990526, 0.10142452402838639, 2.2641984011445726, 29.582678113664898, 52.133789675576345, 56.917690413338796, 45.417344774518696, 40.91112879344395, 4.804537321840014, 2.1345237365790775, 20.40033664022173, 29.72254535130092, 20.31469314438956, 27.48970525605338, 18.163411004202707, 26.280412980488368, 25.797110182898386, 30.14663907459804, 38.071007456098286, 26.759755304881505, 39.104228905269075, 29.930313859667095, 22.83531199182783, 19.64493022646223, 41.46283313206264, 59.90288666316441, 38.65891885757446, 0.32261642281498226, 0.04776334882314716, 0.06014053323971374, 0.04704056314325758, 0.104650062375835, 0.06571660510131291, 0.005751521509539868, 0.1284020178552185, 0.05021106890801873, 0.08593491983733006, 0.02851158007979393, 0.0985101821965405, 0.045919670789901695, 0.16416344605386257, 0.1583646179309913, 6.600488586085183, 75.72820799691337, 65.85272639138358, 40.28478690556118, 34.14678648539952, 35.26797907693045, 30.79638249533517, 24.97856375149318, 31.30495936529977, 35.59170954568045, 29.881256103515625, 30.536123820713588, 30.820398943764822, 29.471381868634904, 23.574911253792898, 9.341126050267901, 6.625315368175507, 7.092505293233054, 25.061099665505544, 52.419058391026084, 47.1281476020813, 48.95930017743792, 56.082287652151926, 29.709562642233713, 1.5575615018606186, 1.8867286103112357, 0.11454171873629093, 2.102993897029332, 22.46684033530099, 59.26218632289341, 58.02217953545706, 59.78389181409563, 57.33139310564314, 54.93963207517351, 47.321342263902935, 44.439486571720664, 47.17753539766584, 53.62439366749355, 56.236405645098, 53.50524595805577, 55.98612458365304, 53.191392353602815, 45.75728191648211, 41.83268921715872, 43.49950647354126, 42.703371456691194, 45.7728146144322, 44.45869139262608, 44.38979305539812, 41.18092039653233, 43.30238260541643, 42.1141676902771, 44.788650921412874, 44.48107501438686, 48.06778376443045, 43.24266978672573, 46.99855327606201, 43.948756149836946, 44.52448388508388, 35.297585351126536, 35.29963159561157, 20.419032505580358, 13.087106619562421, 21.138228382383073, 17.056889533996582, 13.39270750113896, 6.0235753144536694, 8.836395008223397, 7.360385707446507, 1.5889777817896433, 0.08743721672466823, 0.02299196402808385, 0.032451748116207976, 0.03997849280546818, 0.01650623624612178, 0.056180426451776705, 0.0552892758777099, 0.07914427707770041, 0.058837596726204665, 0.3619278648069927, 0.045528424105473926, 0.024925605626776814, 0.015982244363320724, 0.011248319276741572, 0.02396724446277533, 0.03370783857202955, 0.004245948146230408, 0.06326944141515664, 0.05964326885129724, 0.5280537019882883, 1.4760413276297706, 2.2693947851657867, 4.688600982938494, 30.52238723209926, 32.48752539498465, 20.90820131983076, 29.96204628263201, 37.11112771715437, 36.12706477301461, 37.585529872349326, 38.46107585089547, 39.28875568934849, 39.24175807407924, 40.35664517538888, 43.500548703329905, 44.04030214037214, 45.277269090924946, 45.46353987285069, 45.173497744968955, 46.98010580880301, 41.96615021569388, 42.21901600701468, 38.878572259630474, 39.176827158246724, 40.847017765045166, 39.121672357831685, 44.15412752968924, 47.62500286102295, 49.45669739586966, 48.77732685634068, 43.88827902930123, 42.8064410345895, 44.801334857940674, 48.03858743395124, 50.98605843952724, 55.132694721221924, 54.16157974515642, 52.39887040002005, 50.66592713764736, 55.11694662911551, 53.8281044278826, 47.46450989586966, 29.178612572806223, 11.030801142965045, 1.5375744657857078, 0.16173627200935567, 4.1886924249785285, 37.40584250858852, 57.365724154881065, 66.05863625662667, 52.60811192648751, 41.54139641353062, 6.868929633072444, 2.530346325465611, 15.6575414453234, 23.982053109577723, 19.099710294178553, 28.987154960632324, 21.034675904682704, 26.34120798110962, 24.34501310757228, 30.479294504438126, 31.096482140677317, 30.724944591522217, 36.96789755140032, 36.47157730375017, 24.95240204674857, 18.774432114192418, 49.581942149571006, 64.88669054848808, 49.40651403154646, 0.3172718738870961, 0.1333077039037432, 0.06071510312280484, 0.08376902927245412, 0.10901973290102822, 0.21704704048378126, 0.1481273022613355, 0.3122872199331011, 0.2604413091072014, 0.25306256647620884, 0.14994207131011145, 0.23828646221331187, 0.16887781236852917, 0.3947591073811054, 0.2803983267928873, 9.409187998090472, 90.32797132219586, 77.96663965497697, 44.52616534914289, 38.69233621869768, 43.71232284818377, 35.91614178248814, 28.333854062216624, 37.02695723942348, 45.72237764086042, 39.015080043247764, 45.239477838788716, 39.79657520566668, 41.02826499938965, 29.87494019099644, 15.75790296282087, 13.15216955116817, 11.928167070661273, 31.06289107458932, 58.428395543779644, 51.7107138633728, 53.7124342918396, 60.58758299691336, 31.412816252027238, 2.648359090089798, 5.373917877674103, 1.1282619493348258, 2.86883151105472, 29.569181237901958, 63.86088630131313, 59.921507835388184, 64.29994991847447, 58.637022154671804, 57.21580982208252, 49.45078795296805, 48.07026079722813, 47.31830242701939, 54.69119923455374, 58.52264090946743, 57.222914355141775, 57.89177574430193, 55.718466077532085, 48.47841535295759, 45.05177225385393, 46.84713118416922, 46.247585024152485, 47.77105746950422, 46.174111298152376, 47.26745203563145, 44.13438769749233, 44.69668109076363, 44.579270430973594, 48.51092597416469, 48.02069582257952, 50.134209292275564, 46.4389523097447, 52.000530174800325, 47.30434002195086, 50.30567693710327, 43.116156986781526, 44.60066046033587, 29.429737840379985, 17.983336278370448, 32.332497188023154, 26.029112270900182, 29.210268565586635, 10.771951215607778, 11.019689236368452, 7.9540562970297675, 1.8985312112740107, 0.23732565662690572, 0.08498210739344358, 0.17039760867399828, 0.15935650042125157, 0.17844050138124398, 0.11459897352116448, 0.17988621523337706, 0.18892978424472467, 0.9029446797711509, 0.8127420257244791, 0.24021192746503012, 0.14306103411529744, 0.10097249756966319, 0.09866762267691748, 0.2560255117714405, 0.10256128731582846, 0.07240440909351621, 0.13750380517116614, 0.19007953469242367, 0.9709258547851017, 2.0222723313740323, 2.991041204759053, 12.268688729831151, 37.18517466953823, 36.82429913112095, 26.511338097708567, 35.81878014973232, 43.5086225100926, 41.4243609564645, 39.94126449312483, 42.30545507158552, 41.321652684892925, 41.68677009854998, 41.75413635798863, 46.674249580928254, 46.45231022153582, 48.517624037606375, 48.955711432865684, 48.99108471189226, 48.731354100363596, 44.26335321153913, 47.0044800894601, 42.54389292853219, 42.86273533957345, 44.598412718091694, 42.72564738137381, 47.12026834487915, 49.253726618630544, 52.54895148958479, 51.37317732402256, 45.56178045272827, 44.50757196971348, 49.44225556509835, 51.47991902487618, 53.09517022541591, 58.003711223602295, 55.29709952218192, 52.7935072353908, 54.046580110277446, 59.20589896610805, 59.19416345868792, 58.259568214416504, 42.59643868037632, 21.575365611485072, 3.7221690927233015, 0.18167093875152723, 3.6202678978443146, 39.978899410792756, 60.48670210157122, 66.60060269492013, 53.562929902757915, 50.73278965268816, 9.812476209231786, 5.1559706926345825, 28.637615408216202, 35.918153285980225, 25.669871296201432, 38.77459246771676, 23.93913756098066, 35.13210705348423, 32.77089377811977, 40.50047983442034, 49.0985872404916, 36.90397065026419, 51.235675948006765, 38.882477147238596, 32.81458405085972, 27.491906097957067, 62.48387145996094, 72.32421602521623, 63.421051434108186, 0.6276204107063157, 0.33431219522442135, 0.11139392014592886, 0.1320596065904413, 0.1434049970869507], [0.11596011476857321, 0.03224760067782231, 0.10071402322500944, 0.1036353132554463, 0.20273421279021672, 0.08719509507396392, 0.0787502314363207, 0.05135347082146576, 0.11684162675270013, 0.09313499741256237, 3.6404528490134647, 55.48781715120588, 58.75873374938965, 28.04445116860526, 33.04365226200649, 35.62258734021868, 33.38687937600272, 21.7174562726702, 38.413206236703054, 35.1153757912772, 32.441378934042795, 32.75407566343035, 34.96280377251761, 30.216162749699183, 24.280073506491526, 6.576971105166844, 2.8501719066074918, 6.262795278004237, 25.209084136145457, 53.65267283575875, 39.39155428750174, 49.969359806605745, 50.842032705034526, 39.924540179116384, 4.2597850901739935, 1.9351575544902255, 0.6328913250139782, 2.0197195197854723, 17.442243576049805, 53.547588280269075, 57.03946106774466, 55.81195061547415, 58.062305382319856, 49.7807856968471, 43.95289380209786, 42.361540930611746, 49.04929324558803, 55.52425697871617, 54.0100291115897, 52.56948341642107, 54.006277084350586, 51.43481479372297, 48.4363613809858, 39.97970540182931, 43.17068992342268, 40.82305690220424, 44.25487640925816, 43.00118861879621, 42.51142747061593, 39.33580541610718, 39.95954520361764, 39.21730736323765, 44.259906905038015, 39.59744330814907, 44.377112592969624, 40.49345520564488, 40.416576862335205, 38.6311434337071, 36.91062702451433, 29.279451778956822, 26.124247006007604, 9.597096817834036, 10.17327618598938, 9.281751087733678, 11.998970082827977, 2.030843802860805, 1.4106607330696923, 1.4705621302127838, 0.747320719063282, 0.04487116115966013, 0.05715866360281195, 0.03609887723411832, 0.03572950651869178, 0.013880119126822268, 0.07618490087666682, 0.04135428362392953, 0.023866912882242883, 0.12744544632732868, 0.0921420156955719, 0.28972362354397774, 0.02407679733421121, 0.07528766723615782, 0.03866129009319203, 0.06681009142526559, 0.046586185560694764, 0.020856755120413642, 0.054572831107569594, 0.01658797257446817, 0.07115085635866437, 0.05209152014659984, 0.1617290252553565, 0.014838972228712268, 0.4777769169637135, 19.685068232672556, 31.713169506617955, 16.994260208947317, 22.0155166217259, 30.516196387154714, 30.269149712153844, 36.96108136858259, 34.5091941016061, 35.03315428325108, 36.5361955506461, 39.22327586582729, 40.6209511756897, 41.28899267741612, 42.017382758004324, 41.77876077379499, 42.044678756168906, 43.77413749694824, 42.067514010838096, 38.978431769779746, 35.43473236901419, 37.5159957749503, 36.4363568850926, 36.62975304467337, 42.242122241428916, 46.45661810466221, 50.005024909973145, 48.946452958243235, 44.330010754721506, 40.51637036459786, 39.90218782424927, 45.36966970988682, 49.073990617479595, 49.987070764814106, 53.25394698551723, 53.33855519975935, 48.96954182216099, 48.7811553137643, 38.0214216368539, 11.655299152646746, 5.827172756195068, 0.3651530503162316, 0.01640360612821366, 0.3778334584619318, 9.533967222486224, 41.49386031287057, 48.18383605139596, 30.99194301877703, 35.14111886705671, 47.7384078843253, 9.624807102339608, 2.590811069522585, 4.790226204054696, 32.906675474984304, 17.69545156615121, 34.39998231615339, 17.093016692570277, 23.400374242237636, 30.182543890816824, 28.894837720053538, 35.07460028784615, 22.674520254135132, 28.682452133723668, 21.94440528324672, 40.001835414341514, 46.0334415435791, 42.954969201769146, 63.47549057006836, 32.92756175994873, 0.22587892014001096, 0.07550931748534952, 0.056157810879605155, 0.12752883828112058, 0.0715138115254896, 0.06828435124563319, 0.061528951594872136, 0.15290270958627972, 0.07732876164040395, 0.09754533254142318, 0.027666235708498528, 0.11696202600640909, 0.04970426431724003, 0.2762343202318464, 0.24509075709751674, 6.064770749637058, 67.79242025102887, 68.86245673043388, 32.88002218518938, 35.63257190159389, 40.70506954193115, 34.78209154946463, 24.44387207712446, 35.72892257145473, 33.47263056891305, 33.622558798108784, 29.17648294993809, 33.873107365199495, 33.182369572775706, 24.993988752365112, 10.901587230818611, 3.7045758196285794, 7.581157769475665, 28.79299623625619, 57.19490964072091, 43.00802912030901, 54.24501371383667, 55.531698499407085, 46.531387669699534, 6.773243818964277, 0.8686808869242668, 0.24877851349966867, 1.933638070310865, 22.355441604341777, 57.17404072625296, 58.563920157296316, 58.980964933122905, 57.92548492976597, 52.112455231802805, 44.91223158155169, 45.37951878138951, 51.40492711748396, 56.428398268563406, 54.496458598545615, 55.26505095618111, 55.65890611921038, 53.192969594682964, 48.42349679129464, 42.69298389979771, 44.941083976200645, 44.22306408200945, 46.43600279944283, 45.98418576376778, 46.3371889931815, 42.134376525878906, 42.362211431775776, 43.182144028799875, 45.46065289633614, 44.990239007132395, 47.8489294052124, 45.24368149893624, 47.98902940750122, 44.07205540793282, 41.75628335135323, 34.163507325308665, 35.00048385347639, 15.33910550389971, 18.171114819390432, 19.22048040798732, 21.531192438943044, 5.8453874588012695, 1.9359472606863295, 3.082173777478082, 1.9719052740505763, 0.28314509083117756, 0.12001235304134232, 0.02886855396042977, 0.07352515895451818, 0.0524439648059862, 0.10152418046657528, 0.01589393981599382, 0.024335134275523678, 0.09870027378201485, 0.13188090760793003, 0.4196461433810847, 0.07084658768560205, 0.05411822621577552, 0.055756518484226296, 0.015302979919527258, 0.0443521768652967, 0.02453291875177196, 0.06683145849300282, 0.03689471738679068, 0.05924766257937465, 0.06753141486218997, 0.11334566505891935, 0.11661294688071523, 0.23320347496441432, 24.988119261605398, 36.922984395708355, 24.77077787263053, 29.813657079424175, 36.10972901753017, 34.940993377140586, 39.80817869731358, 37.55393293925694, 37.77230092457363, 40.01972355161394, 42.285367829459055, 44.14302430834089, 42.29196514402117, 43.65117175238473, 43.314423833574565, 44.64948892593384, 45.453211375645225, 44.20383494240897, 41.478928634098594, 39.16172524860927, 38.91886486325945, 38.572319984436035, 39.588275160108296, 46.669868741716655, 49.949543544224326, 51.44436856678554, 50.96800701958792, 48.30798646381923, 43.3275420325143, 42.17248739515032, 46.73876360484532, 50.16023029599871, 51.660207407815115, 54.29899426868984, 54.24200861794608, 50.67157602310181, 49.68917369842529, 32.41745628629412, 5.223131545952388, 2.369355695588248, 0.24483741926295416, 0.6982267562832151, 0.8914813463176999, 13.483360648155212, 46.03429617200579, 48.5350466455732, 33.22502108982631, 39.65868820462908, 52.26683725629534, 16.167137963431223, 3.5421197712421417, 4.528111926146916, 33.868587562016074, 20.095373255865915, 32.35707644053868, 22.503427812031337, 24.971467903682164, 26.331254686628068, 26.978550604411534, 32.19645145961216, 27.271596091134207, 27.51955645424979, 27.189720255987986, 41.89759928839547, 41.140075411115376, 52.37247766767229, 67.54411942618233, 39.463912827628, 0.3072153063757079, 0.18634422655616487, 0.16069297013538225, 0.062039888463914394, 0.08491322930370059, 0.24655351574931825, 0.14594940841197968, 0.214048743514078, 0.2269062628703458, 0.2531633696385792, 0.2277857799615179, 0.24644538440874644, 0.24338345442499432, 0.3702640203492982, 0.3869488707610539, 9.595992922782898, 82.75062724522182, 79.71014417920793, 37.900891235896516, 47.26955039160592, 46.595272881644114, 44.227149622780935, 28.640957491738455, 51.11354398727417, 44.565346240997314, 44.08324200766427, 43.454072202954976, 48.75329998561314, 38.86384207861764, 30.7169645854405, 9.463960647583008, 9.470711691038948, 13.32343396118709, 34.335499559129985, 63.869335310799734, 47.852545942579, 58.80254214150565, 58.82897308894566, 46.70879602432251, 6.187089877469199, 6.243132310254233, 1.3216693997383118, 2.936245322227478, 26.5112338747297, 63.13153389522007, 59.19690104893276, 61.708653994968955, 59.52789238521031, 56.25175768988473, 46.92626074382237, 47.835477692740305, 53.421732085091726, 60.68564987182617, 57.31561722074236, 57.180818693978445, 56.65729972294399, 54.58543028150286, 50.6381447655814, 45.39979362487793, 47.56669357844761, 47.05811323438372, 48.6073773929051, 49.48166922160557, 47.890358039310996, 44.58325522286551, 46.596860545022146, 46.12630769184658, 48.981867926461355, 48.32043416159493, 50.94543579646519, 48.44340338025774, 50.69834395817348, 47.76586716515677, 47.16529961994716, 40.87285116740635, 41.759948526109966, 22.590026685169764, 25.811727455684117, 27.18123303140913, 30.745452199663433, 18.388452734266007, 2.374625035694667, 4.392729750701359, 2.2784092043127333, 0.5812230546559606, 0.21592053664582117, 0.10348322641636644, 0.21460810064205102, 0.13730996128703865, 0.2860291360744408, 0.1066447381994554, 0.1144916292812143, 0.23636303256664956, 1.0385983777897698, 0.719606091933591, 0.16024790544595036, 0.17557123463068688, 0.1545485369861126, 0.07040860011641469, 0.1541677431336471, 0.11964356925870691, 0.1737438312598637, 0.12293500692716666, 0.1846219418304307, 0.22830146657569067, 0.23261608076947077, 0.19858129349138054, 1.548974396927016, 32.317773955208914, 40.13654014042446, 31.459035669054302, 36.73242310115269, 41.40242549351284, 39.31113931110927, 43.76790843691145, 40.450164454323904, 39.30505616324288, 43.87713411876133, 45.13660281045096, 45.621236188071116, 45.33645384652274, 48.97669151851109, 45.36965928758894, 48.98241336005074, 49.210960456303184, 48.975051743643625, 45.431022303445, 42.10998140062605, 44.018318040030344, 41.49310295922415, 41.692512784685405, 48.2371461050851, 50.72454214096069, 53.77331788199288, 53.86058725629534, 51.0380448613848, 44.545682838984895, 44.94603109359741, 49.67302261080061, 54.77945177895682, 53.27093185697283, 58.41448525020054, 57.08223417827061, 53.09208869934082, 49.779479435511995, 42.971082074301584, 15.129646846226283, 6.768826935972486, 0.5593608734863145, 0.4495076281683785, 1.1084961699587959, 11.740703804152352, 50.66828605106899, 57.242379733494346, 38.94966622761318, 43.920904295785085, 56.00715330668858, 14.313179663249425, 6.408867256981986, 8.068371534347534, 38.855945450919016, 21.923016990934098, 48.19877815246582, 24.000504050936016, 31.65030915396554, 37.57522569383894, 38.45396784373692, 49.836274010794504, 30.261027268001012, 37.53284168243408, 28.904506138392858, 60.181926318577354, 55.888804640088765, 63.05025386810303, 76.02568817138672, 55.45746047156197, 0.45056204444595743, 0.4048062025436333, 0.27169953499521526, 0.2770540719585759, 0.2057944057243211], [0.09094938183469431, 0.029382489954254458, 0.029409465113920823, 0.11616850644350052, 0.15508019631462439, 0.036416119496737204, 0.011217541776464453, 0.07168529089540243, 0.11731946468353271, 0.15910209050135954, 2.0733984793935503, 54.0124123437064, 52.60469341278076, 34.86937829426357, 34.012703623090474, 27.727248532431467, 35.41455480030605, 23.162711109433854, 38.687149388449534, 34.448032583509175, 31.503837653568812, 31.24993658065796, 32.89109066554478, 25.98438845361982, 26.68898442813328, 8.505343743732997, 1.5499182662793567, 3.07821894969259, 18.841822692326136, 55.39927625656128, 48.40617840630667, 49.432184151240754, 52.98643786566598, 41.443058558872764, 13.109442472457886, 1.3536484837532043, 0.3312841105673994, 1.1062212863138743, 18.935515676225933, 57.591929708208355, 56.41276134763445, 55.85716949190412, 55.26301165989467, 48.80426849637713, 43.41686807359968, 44.793181146894185, 50.33242750167847, 53.154143060956685, 54.07176733016968, 53.92480945587158, 53.04684550421578, 52.246527671813965, 45.950222969055176, 40.95711891991751, 43.1791215624128, 43.029891627175466, 46.99766043254307, 45.127809865134104, 44.00290693555559, 39.71434327534267, 39.66535152707781, 39.433747223445344, 42.51816027505057, 41.616398743220735, 44.06910242353167, 42.13239976337978, 43.31394788197109, 38.67926665714809, 35.754203592027935, 30.637185369219097, 22.393317971910747, 7.613016997064863, 12.465423498834882, 12.975134662219457, 14.328745365142822, 0.4647161492279598, 0.34707120486668175, 0.11124418103801352, 0.03993256616273096, 0.06782173964061908, 0.0865810683795384, 0.027130289735006433, 0.043456985615193844, 0.021042899328417013, 0.05627674449767385, 0.1018918582371303, 0.020850439655727575, 0.06179041827895811, 0.041438041986631494, 0.43296122604182785, 0.08658196404576302, 0.05878478634570326, 0.12450703685837132, 0.10191783934299435, 0.18819072390241282, 0.025095878900693994, 0.054746787130300484, 0.08624965830573014, 0.03917660351310458, 0.09741166792809963, 0.027245852730369995, 0.08213261315332991, 0.7049612977675029, 10.597234419413976, 33.440509046827046, 21.00172928401402, 21.258220297949656, 30.129310267312185, 31.80970082964216, 33.78627225330898, 33.7813320841108, 36.480370249067036, 38.518210887908936, 41.288579259599956, 39.84536893027169, 41.557943548474995, 40.85442801884243, 41.73487247739519, 43.630188192640034, 41.36498512540545, 38.90586825779506, 37.573429584503174, 37.56261818749564, 38.473815373011995, 36.310208865574424, 35.70182112285069, 46.96354130336216, 49.56717722756522, 50.2711443901062, 49.628720896584646, 46.024165698460166, 44.30623401914324, 40.499739851270405, 43.00486421585083, 45.89821917670113, 50.28200095040457, 50.69464404242379, 52.95445530755179, 51.05415078571865, 49.13607972008841, 10.461868745940071, 0.12672716272728785, 0.1534716747701168, 0.19364269849445137, 0.604762845805713, 1.618638555918421, 28.20666207586016, 59.35261712755476, 50.364882537296836, 30.462340899876185, 49.00685017449515, 47.83903864451817, 34.53022282464163, 3.4274373650550842, 3.738476949078696, 36.037665775844026, 21.518404279436382, 33.43833426066807, 19.475289957863943, 29.428758144378662, 28.872412409101212, 27.099025419780187, 29.09478603090559, 30.47065441949027, 38.19962903431484, 30.04951368059431, 26.83337320600237, 31.608939579554967, 43.20899881635393, 60.07415281023298, 16.414862087794713, 0.32602136582136154, 0.03380752893696938, 0.13450914514916285, 0.042045181550617726, 0.18044197612575122, 0.08508132956922054, 0.03109154324712498, 0.08927896432578564, 0.15772570935743196, 0.056332635427159924, 0.041025411271091015, 0.11356399048651968, 0.05283923859574965, 0.1430980007031134, 0.13888790804360593, 5.33436873129436, 67.66877705710274, 61.060546875, 35.46753828866141, 33.9320524079459, 32.861734526497976, 37.2502167565482, 25.44084824834551, 36.3169903073992, 34.11302171434675, 30.697784083230154, 30.903287478855678, 29.079607691083634, 30.269080230167933, 27.333306516919816, 14.817790848868233, 6.183390395981925, 3.1964883634022305, 22.767370768955775, 56.88905341284615, 53.092477798461914, 53.317026206425254, 55.451064654758994, 45.04954188210623, 16.076849596840994, 1.9002558844430106, 0.7999832332134247, 1.1486841163464954, 22.5174058505467, 61.18025738852364, 59.24871376582554, 57.873102460588726, 57.127668448856895, 51.05272987910679, 45.299520696912495, 47.76677737917219, 52.57230091094971, 58.02239145551409, 56.43443625313895, 54.37540013449532, 54.90407466888428, 56.331404890332905, 47.464086055755615, 43.94831146512713, 45.535029888153076, 45.99956560134888, 49.692484515053884, 47.72678007398333, 48.01195151465279, 43.13938134057181, 43.99765062332153, 41.671949590955464, 46.07619728360857, 45.0301251411438, 47.75135932649885, 46.92879683630807, 49.358446393694194, 43.768377440316335, 42.67995950153896, 33.68293864386422, 29.109139272144862, 14.554573978696551, 22.968481166022165, 21.62750141961234, 21.54402576174055, 1.7521401579890932, 0.27225685651813236, 0.22874758977975163, 0.09522566558527094, 0.07877069605248314, 0.0750193948458348, 0.06350575480610132, 0.07877980199243341, 0.0458659002823489, 0.038920751706297906, 0.04507335441719208, 0.026708069623314908, 0.021972587298867956, 0.20925356367869036, 1.998478876692908, 0.24165907981140272, 0.029885888299239532, 0.05421114819390433, 0.05952698151980128, 0.041110567415931394, 0.038931808434426785, 0.035077705779778104, 0.015318740591672915, 0.10449128518147127, 0.10199358420712606, 0.058002584746905735, 0.03917670190068228, 0.8303684656109128, 13.354242273739406, 38.52336297716413, 26.1909236567361, 27.362098114831106, 36.2739496912275, 36.30691194534302, 37.45969104766846, 37.674661363874165, 38.80558838163103, 42.02926070349557, 42.980093887874055, 43.511301040649414, 44.49171270642962, 43.3381484576634, 44.565589427948, 45.39010088784354, 41.692307812826975, 40.89398758752005, 40.45849881853376, 40.74957970210484, 39.645702021462576, 37.79043572289603, 39.29646471568516, 48.64166675295149, 50.04114859444754, 52.39223139626639, 51.40440252849034, 49.89786284310477, 46.61133711678641, 42.917626108442036, 45.24000242778233, 50.17010716029576, 52.91907855442592, 53.382679734911235, 56.085553305489675, 52.451447418757844, 49.85375220435006, 8.122930526733398, 0.189463682738798, 0.38469855008380754, 0.20193686628980295, 1.2156900465488434, 2.592372242893491, 33.66726350784302, 58.98547431400844, 54.77472005571638, 32.853792735508506, 48.8619315964835, 52.10255057471139, 39.77216965811593, 3.132982913936887, 6.559700054781778, 43.12953574316842, 24.070125000817434, 32.460097381046836, 24.035585505621775, 29.800851549421036, 24.711730343954905, 27.650491782597133, 32.41778632572719, 31.09207350867135, 36.81724670955113, 31.185200214385986, 36.10151972089495, 35.98790625163487, 49.881840297154014, 67.42099039895194, 19.7026332787105, 0.39835287311247414, 0.22252645503197396, 0.10928434798760073, 0.1354661373687642, 0.09960940892675094, 0.17482008279434272, 0.11164971427725894, 0.2035542766430548, 0.20255422459117003, 0.2631352831210409, 0.09408533320363079, 0.298054785068546, 0.1028139873274735, 0.4173019134572574, 0.35920932782547815, 8.660219958850316, 78.98655877794538, 70.4426577431815, 45.582559040614534, 48.93144137518746, 35.034411907196045, 49.65136507579258, 28.70133212634495, 50.472253050122944, 43.19447013310024, 41.822214807782856, 40.07813010896955, 46.179541315351216, 33.24752630506243, 35.70504856109619, 10.892656190054756, 7.081789868218558, 9.136569346700396, 29.245909350258962, 63.97144603729248, 57.306584562574116, 57.410196099962505, 60.958978107997346, 47.82135200500488, 17.821695123400005, 3.0905394085815976, 1.258644353066172, 2.1699254597936357, 24.26443658556257, 65.21027510506767, 59.722275188991, 59.681204387119834, 60.11723164149693, 54.25538042613438, 47.399325370788574, 50.393668924059185, 53.78750262941633, 59.299713543483186, 57.75685562406267, 57.40966803686959, 57.9030179296221, 59.73845059531075, 49.266889980861116, 47.332893644060405, 47.848502090999055, 46.93144409997122, 52.030699253082275, 49.68235056740897, 51.2683915410723, 45.976792880467, 47.01870305197579, 45.52220351355416, 48.99949203218733, 48.18138681139265, 51.33265542984009, 48.96182237352644, 53.52754620143345, 48.78564732415335, 47.78440843309675, 41.87133857182094, 35.94080441338675, 21.35163187980652, 31.651452132633754, 32.95137323651995, 33.50806290762765, 5.413184319223676, 0.32253950408526827, 0.5875847818596023, 0.3192300988095147, 0.11485628757093634, 0.2268003299832344, 0.1306883551712547, 0.2474806388573987, 0.12199187039264611, 0.16299266102058546, 0.17285134057913507, 0.09999073203653097, 0.1722864466054099, 0.4048614352941513, 2.1385589029107774, 0.3129904536264283, 0.15444326906331948, 0.18290923801915987, 0.20599740983120032, 0.17256475452865871, 0.15341507137886115, 0.23616832015769823, 0.1675174039389406, 0.21312510807599339, 0.22765404917299747, 0.14403256055499825, 0.17082697206309863, 1.1261924718107497, 18.9195556640625, 44.01659141268049, 29.470780849456787, 33.999387400490896, 40.40336833681379, 41.066018036433626, 38.993797710963655, 42.13307721274239, 41.96079315458025, 44.357390131269185, 46.776509693690706, 44.09858363015311, 47.14795691626412, 45.98066302708217, 45.92121076583862, 48.19412980760847, 44.41981274741036, 44.87022277287075, 42.96404702322823, 44.07633202416556, 42.92707913262503, 41.58905063356672, 41.27386992318289, 51.457146303994314, 53.55154875346592, 56.26782887322562, 52.497910022735596, 51.375880173274446, 49.2994144984654, 45.19405051640102, 48.85000501360212, 52.57221405846732, 56.82946218763079, 56.36150448662894, 57.550080708095, 53.076003619602744, 50.646312373025076, 12.836492044585091, 0.46113261580467224, 1.093071169086865, 0.6563654339739254, 2.2372452531542097, 2.775306369577135, 32.196368081229075, 62.42144884381975, 55.726484298706055, 36.93461915424892, 56.945208753858296, 55.51076705115182, 41.74552753993443, 6.987345176083701, 7.152116060256958, 43.68252202442714, 27.229755776269094, 46.11969300678798, 26.721576690673828, 39.43499442509243, 38.8296708379473, 37.53374147415161, 40.853694983891074, 40.45853703362601, 51.35873896735055, 39.28846039090838, 37.97655364445278, 41.771670137132915, 60.90219048091343, 76.61564581734794, 31.13986669267927, 0.48726180515119005, 0.2434728310576507, 0.30067542301756994, 0.28911709466150826, 0.26931983126061304], [0.06568071738417659, 0.08342393314731972, 0.06423720198550395, 0.02994605739201818, 0.1319773681461811, 0.017296364830274667, 0.07365397882780858, 0.12193202360400132, 0.017771960202870623, 0.027478785320584263, 3.7290881957326616, 65.19239044189453, 53.32387018203735, 29.562094075339182, 35.75441203798567, 31.48498371669224, 32.45950331006731, 23.959914411817277, 43.09854677745274, 35.9140955380031, 36.066434792109895, 26.14714653151376, 37.278374331338064, 32.67884404318673, 28.82996412685939, 16.974014895302908, 1.8219779133796692, 1.4248864097254617, 6.911541197981153, 46.90780632836478, 40.996324130467, 47.23608439309256, 47.229674679892405, 39.11670439583914, 15.911166327340261, 2.1466129507337297, 0.22396979401154177, 0.6999861161623682, 20.06486545290266, 57.48901993887765, 56.09381818771362, 56.65316554478237, 53.49164138521467, 46.94027526038033, 44.83627734865461, 48.00650412695748, 52.63828795296805, 54.97592946461269, 53.2874789919172, 52.99901063101632, 53.63411767142159, 53.03362308229719, 46.780761991228374, 40.353223187582834, 44.627730642046245, 46.79660735811506, 47.847852434430806, 46.416266441345215, 43.401050499507356, 41.09679855619158, 40.34413146972656, 40.09049095426287, 41.34087140219552, 42.864809376852854, 43.09568759373256, 44.42165402003697, 41.62623044422695, 39.15400232587542, 32.86501407623291, 24.612028905323573, 17.77807433264596, 7.4976308686392645, 15.819125277655465, 13.400555491447449, 13.259502717426844, 0.702949902841023, 0.19696309603750706, 0.028793986354555403, 0.0809315654582211, 0.028248637582042387, 0.07597633278263466, 0.034480846021324396, 0.04159493624631848, 0.03402403589071972, 0.030401768295892646, 0.008337937544898262, 0.05615414339782936, 0.02109350447010781, 0.11866204121283122, 0.7860574690358979, 0.16012035443314485, 0.10907071123697928, 0.11315511206963233, 0.05745838609124933, 0.03183660523167678, 0.038175798287349086, 0.055454892705061605, 0.031675999385437796, 0.021621531939932277, 0.04923820575433118, 0.02489362457501037, 0.05004134015845401, 0.0938341123983264, 4.779629332678659, 29.370810168130056, 24.34124197278704, 19.935335397720337, 31.205190181732178, 32.353970595768516, 35.133180550166536, 35.82571792602539, 34.64162676674979, 38.85413197108677, 39.52457060132708, 40.332444599696565, 39.66043567657471, 42.11239242553711, 40.99684524536133, 41.30514029094151, 40.666312490190776, 37.834664481026785, 37.51501260484968, 36.5823142187936, 36.29334558759417, 36.21328844342913, 36.87168237141201, 46.92832088470459, 47.790988377162385, 50.23201213564192, 49.624183722904746, 49.16452217102051, 46.20815052304949, 41.18790681021554, 41.16168778283255, 45.51692983082363, 50.62428310939244, 50.50827251161848, 53.00495481491089, 53.49704360961914, 52.208375113351, 4.677233295781272, 0.20922738579767092, 0.4877683179719107, 0.25685460014002665, 1.5535127648285456, 8.876183867454529, 42.34423296792166, 51.81126124518258, 43.91291386740548, 67.82572296687535, 62.237411907741, 51.67275585447039, 31.65754917689732, 0.4323042684367725, 7.122237937791007, 24.397161075047084, 22.4433901650565, 31.429328645978654, 23.717757531574794, 29.198248182024273, 28.016998835972377, 21.20790491785322, 34.87132031576974, 26.873657124383108, 26.533572333199636, 36.05737086704799, 24.186788729258947, 25.921413455690654, 45.90245757784162, 62.56424127306257, 8.139081614358084, 0.16029290588838713, 0.15382810921541282, 0.06782936637422868, 0.14370420388877392, 0.1763701553323439, 0.027738263897065605, 0.0399228122218379, 0.0478020354972354, 0.034430556398417266, 0.053085913216429095, 0.02869161238361682, 0.047001890039869716, 0.05176257315490927, 0.07605646098298685, 0.1272757447191647, 7.109071101461138, 75.534499168396, 61.92041424342564, 34.21776580810547, 43.13653257914952, 33.477758339473176, 33.63632665361677, 26.90347010748727, 39.27765941619873, 36.05746814182827, 34.748771463121685, 30.0462897164481, 36.258236340114046, 29.884799684797013, 27.442617314202444, 16.554557357515606, 6.221937698977334, 2.4179563905511583, 8.970384069851466, 51.024238790784565, 44.26508331298828, 49.61316040584019, 52.81900017602103, 42.09483780179705, 22.48085137775966, 2.175092313970838, 0.08252159013812031, 1.2888875816549574, 22.420080695833477, 60.303603172302246, 57.295905181339805, 60.30984960283552, 54.995422635759624, 50.03429767063686, 47.21204710006714, 50.08258070264544, 54.8594012260437, 56.05780914851597, 56.38487475258963, 54.23601927076067, 55.474629470280235, 54.729782581329346, 50.14651802607945, 44.57766192299979, 47.03010157176426, 49.21576860972813, 51.01408747264317, 48.415648800986155, 46.83432218006679, 43.46106556483677, 45.60728073120117, 42.97197839191982, 43.28597443444388, 46.3838426726205, 46.20094176701137, 47.831548486437114, 46.72528409957886, 43.48615550994873, 39.155492714473176, 32.270745073046, 24.71433244432722, 14.761680671146937, 26.599166801997594, 22.749887364251272, 18.15575408935547, 0.9776278265884945, 0.11176962498575449, 0.06125768007976668, 0.1940331139734813, 0.09146249001579625, 0.07598126573222024, 0.07983054739556142, 0.022024001593568494, 0.02317316341213882, 0.04464360087045601, 0.01963670165943248, 0.030153037714106695, 0.08437041485948221, 0.015846947873277322, 1.7368166659559523, 0.9409620740583965, 0.12443205873881068, 0.09115108315433774, 0.06172428147069045, 0.024377898945073997, 0.03491999388539365, 0.06882426155997173, 0.08002048291798149, 0.02891117613762617, 0.03735880141279527, 0.025228674989193678, 0.026556245716554776, 0.02885243875373687, 6.803584430898939, 36.893468448093955, 28.42041298321315, 27.128355503082275, 34.455286502838135, 38.69296850476946, 40.36220720836094, 37.90995863505772, 38.32694435119629, 42.33170883996146, 41.820411750248496, 45.237049443381174, 43.21526609148298, 45.19153526851109, 42.21627146857125, 43.92709166663033, 42.578835419246126, 40.697311878204346, 41.170987946646555, 39.92142391204834, 39.54532834461757, 38.54369340624128, 39.300293173108784, 48.73892068862915, 49.709010805402485, 52.316475187029155, 51.153885228293284, 51.00031961713518, 49.56022208077567, 45.71493264607021, 43.428784234183176, 48.77704198019845, 51.62241962977818, 53.123296533312114, 55.370809486934114, 54.95645366396223, 53.7010566166469, 5.926785605294364, 0.1672336541648422, 0.42545326320188387, 0.3298296300428254, 1.1798996584756034, 11.299824101584298, 48.60194042750767, 51.460901805332725, 45.79851252692086, 65.10882445744106, 60.31460217067173, 60.29837812696184, 31.086153643471853, 0.49118623456784655, 13.302806496620178, 31.130451883588517, 23.9072105884552, 30.302243982042583, 27.07854560443333, 27.37209483555385, 28.858663661139353, 25.17063454219273, 34.491594314575195, 25.797233513423375, 27.532448836735316, 33.61299112864903, 29.162301676613943, 29.671531677246094, 55.43738712583269, 69.51470497676304, 9.747695548193795, 0.323792541133506, 0.2628882149500506, 0.13244263960846833, 0.09046332684478589, 0.10064798141164438, 0.1359093293015446, 0.1294091809540987, 0.11999184771307878, 0.10854483302682638, 0.28003392634647234, 0.12136140279471874, 0.3333102161330836, 0.25288359607969013, 0.2915362077099936, 0.18605726052607807, 10.445164408002581, 91.15666907174247, 69.51854733058384, 41.916119711739675, 50.79418740953718, 38.532454695020405, 44.55595227650234, 30.54153299331665, 56.645949840545654, 43.88916492462158, 48.26016896111624, 34.181336402893066, 51.97832373210362, 41.744909150259836, 38.10662739617484, 23.582031420298986, 6.354498471532549, 5.747467798846109, 14.111747911998204, 58.924281529017854, 51.49621949877058, 55.298239026750835, 54.784020219530376, 47.05976690564837, 21.786055837358745, 3.0810538147177016, 0.8990460889680045, 2.1220575826508656, 24.67037292889186, 64.83473191942487, 59.43493938446045, 63.22642544337681, 57.57173476900373, 52.70007480893816, 48.28031873703003, 52.73946067265102, 56.931024006434846, 60.37327970777239, 60.683113779340474, 55.94314650126866, 57.82134532928467, 56.56820297241211, 51.30886479786464, 47.002784729003906, 48.516262190682546, 51.12030805860247, 53.84996346064976, 51.224100249154226, 50.621340547289165, 45.608913557870046, 47.83981684276036, 47.11558525902884, 46.4300342968532, 49.26043857846941, 47.74353912898472, 51.61426591873169, 50.46180990764073, 46.469388893672395, 43.52304697036743, 37.90998642785208, 30.19280638013567, 23.149052688053676, 34.50351047515869, 32.031897272382466, 30.706028120858328, 2.694696192230497, 0.29714372966970715, 0.14187047657157692, 0.28105428016611506, 0.15137162245810032, 0.215478226808565, 0.2026072588882276, 0.0876510434650949, 0.14166334697178432, 0.09329562700752701, 0.10564526290233646, 0.12428663511361394, 0.17980940506926604, 0.2610306574829987, 3.2504808604717255, 0.34122185302632196, 0.15265159734657832, 0.18982369984899247, 0.14565785548516683, 0.1261327253388507, 0.07861467371029512, 0.13090354576706886, 0.11296016217342444, 0.17504767701029778, 0.19015238221202577, 0.10984470934740134, 0.1545036993920803, 0.22839339450001717, 11.779732704162598, 45.32324879510062, 32.80310910088675, 32.24102067947388, 41.19236060551235, 43.28304924283709, 42.634830951690674, 40.32075425556728, 41.23369543892996, 43.705530984061106, 43.9474881035941, 47.43825612749372, 44.05476481573922, 48.67603254318237, 45.155415058135986, 47.111885343279155, 44.98556981767927, 42.33384888512747, 43.05468627384731, 43.540337562561035, 42.47619662966047, 41.16325807571411, 41.030311243874685, 51.70952224731445, 51.54874440601894, 53.723843233925955, 53.78686339514596, 53.747390678950715, 51.08851310185024, 47.869169507707866, 45.849651268550325, 52.741333212171284, 54.192759786333355, 56.06944043295724, 57.98107746669224, 57.03124829701015, 56.17517811911446, 6.791415963854108, 0.5839006624051503, 1.4287960742201125, 1.4325018525123596, 5.898903787136078, 10.411998050553457, 48.92771714074271, 54.26994385038103, 50.143290587833945, 67.85301549094063, 70.56780174800328, 60.35248374938965, 37.95773792266846, 2.639360087258475, 11.78814002445766, 31.598433903285436, 30.48949793406895, 43.366260869162424, 32.34917981284005, 39.29635007040841, 39.29594012669155, 28.371687003544398, 47.25344099317278, 36.87365913391113, 36.09584304264614, 46.925444330487935, 36.32160043716431, 37.01640639986311, 64.85420077187675, 80.98652826036725, 16.15379568508693, 0.5194456438933099, 0.477613200034414, 0.36157494517309324, 0.36611646147710936, 0.3185283307518278], [0.01848236601134496, 0.12434972529964787, 0.0909616904599326, 0.0955991448302354, 0.11288816960794584, 0.028228722579245056, 0.05859205525900636, 0.002802505902114457, 0.053658013232052326, 0.11518479351486478, 1.1799404791423251, 49.689680916922434, 56.1374945640564, 24.437502316066197, 25.72985683168684, 28.746113266263688, 31.24290500368391, 26.162983213152202, 38.75391810280936, 37.000880650111604, 33.45801503317696, 27.06914642878941, 27.76186272076198, 44.488923004695344, 26.595155954360962, 33.50185816628592, 5.14630401134491, 2.948616589818682, 7.182259517056601, 39.744943141937256, 38.212493624006, 44.02937262398856, 55.48510387965611, 51.96738031932286, 34.75697381155831, 4.263905806200845, 0.34107203249420437, 0.5389559141227177, 16.989406892231532, 55.27384042739868, 57.54994174412319, 54.875225748334614, 52.998725754874094, 47.61454929624285, 45.54259647641863, 50.97840152468, 54.05694334847586, 53.32849768229893, 55.745452880859375, 53.09642090116228, 52.71177904946463, 52.93789427621024, 46.30511263438633, 40.766529832567485, 42.91506222316197, 50.019466740744456, 50.427551814488, 48.03683648790632, 47.38044364111764, 43.17544943945748, 40.5378611428397, 39.52665158680507, 41.15989514759609, 42.806371552603586, 43.57381745747158, 45.44511325018746, 40.97486114501953, 37.850777353559224, 32.62402970450265, 25.482539176940918, 14.166193996156965, 11.298288549695696, 18.716484137943812, 13.309793778828212, 2.223184270518167, 0.12341435120574065, 0.16640812131975377, 0.02704262131425951, 0.15733240331922257, 0.05760290726487126, 0.006737678012411509, 0.029751684250576154, 0.056976890856666226, 0.00904173611862851, 0.04433537633823497, 0.09935972161058869, 0.11648490732269627, 0.03252770671887057, 0.037281780902828486, 2.048985766513007, 0.8263469242623874, 0.11011868143188101, 0.11595809273421764, 0.042844987740474086, 0.055498162883200815, 0.05502688638599856, 0.08375667993511472, 0.05506465703781162, 0.060927091033330986, 0.08991340135357209, 0.03354818606749177, 0.07070791548384087, 0.062032105667250495, 1.416185962302344, 23.144142048699514, 24.026830775397165, 18.955762726919993, 26.947942052568706, 33.67643165588379, 31.211301122392925, 35.007261821201865, 36.85394014630999, 38.61229297092983, 38.97072969164167, 41.5853785106114, 40.91589525767735, 41.24713325500488, 41.27516228812081, 40.444119521549766, 37.858614921569824, 39.52672106879098, 38.63380806786673, 39.81840297154018, 37.22672142301287, 35.881584916796, 39.128523281642366, 46.17734568459647, 49.88876417704991, 48.28744758878435, 48.74048750741141, 50.47698824746268, 46.10342379978725, 44.246347495487754, 39.41220085961478, 44.5522905758449, 51.13059834071568, 51.13594497953142, 52.3250527381897, 53.56965575899397, 52.32911048616682, 10.19185219492231, 0.03330380489517536, 0.14852917141148023, 0.23861856439283916, 2.592530531542642, 18.00743784223284, 47.75479521070208, 46.529494285583496, 45.63032095772879, 46.972778933388845, 46.71223190852574, 47.90370205470494, 9.185246688979012, 0.43573008318032536, 15.320486068725586, 31.823625019618444, 24.661654676709855, 25.641633817127772, 26.98375654220581, 31.349379198891775, 24.465501819338115, 27.08804726600647, 37.073548385075156, 33.241905212402344, 30.49057490485055, 31.3354480607169, 37.58003384726388, 45.51091269084385, 47.44392933164324, 50.516853536878315, 2.6138061327593665, 0.09649603241788489, 0.10414719328816448, 0.1502027508935758, 0.03889168326609901, 0.19611610791512898, 0.040454457979649305, 0.010238054424657353, 0.11144881362893752, 0.04932017956993409, 0.09522671731454985, 0.004346206784248352, 0.07231005879917315, 0.04272411011957696, 0.05923449221466269, 0.08676153833844832, 2.93521894301687, 63.968534742082866, 63.43277999332973, 29.740082604544504, 36.05569635118757, 26.223816428865703, 31.54130581447056, 27.030827113560267, 34.142662729535786, 36.09607580729893, 33.54457221712385, 29.818652834211075, 30.422538144247874, 31.691647461482457, 32.18568522589547, 34.18909059252058, 6.434702830655234, 4.444145117487226, 10.042280060904366, 44.89835602896554, 44.8619578906468, 47.96092741830008, 59.839150837489534, 54.94731330871582, 38.601148060389924, 4.940190477030618, 0.26239847551499096, 1.0085843311888831, 17.78832639966692, 56.70334890910557, 58.92121737343924, 57.88729068211147, 56.42369781221662, 49.20765658787319, 49.22525984900338, 53.537812164851594, 54.90329647064209, 56.24234982899257, 55.61626502445766, 53.84463766642979, 54.47514499936785, 54.98273869923183, 48.79121283122471, 43.810410567692344, 45.36105046953474, 51.40654257365635, 53.39919212886265, 50.207280022757395, 50.56978491374424, 45.29778364726475, 43.501653466905864, 43.16216795785086, 44.25380291257586, 45.83569581168038, 47.1697290965489, 49.726846831185476, 45.16901615687779, 44.48043230601719, 39.143736362457275, 29.602786200387136, 18.77356011526925, 19.86655170576913, 23.7550676209586, 19.07879795346941, 4.426397681236267, 0.02608028732772384, 0.1037529915837305, 0.01851324105103101, 0.10138520292405571, 0.05905427331370967, 0.06293138169816562, 0.015814865041258078, 0.01548262545838952, 0.04315426400197404, 0.017891876000378813, 0.058548696871314726, 0.12234820984303951, 0.056212307419627905, 0.049733325972088745, 0.549347705074719, 3.409911619765418, 0.2822733633220196, 0.08062115604324, 0.08489236435187714, 0.02845594020826476, 0.017950236797332764, 0.0658046653760331, 0.062336408267063756, 0.05858759728393384, 0.008222846131372665, 0.044315067785126824, 0.04404225938820413, 0.06248567918581622, 1.8377917962414878, 28.71753532545907, 29.93111637660435, 23.889843566077097, 30.31943382535662, 39.241355078560964, 36.702139377593994, 40.04467453275408, 39.426913670131135, 41.02572543280465, 43.09100103378296, 43.989177295139854, 42.314557211739675, 44.50105108533587, 42.92166648592268, 43.21738529205322, 40.13775954927717, 41.75855541229248, 39.88851029532296, 41.31933198656355, 41.10014063971383, 36.831146580832346, 41.39462266649519, 48.160365036555696, 51.19745738165719, 52.010900361197336, 51.694733006613596, 52.18356657028198, 52.019901752471924, 47.641807079315186, 43.401752267565044, 47.7217252595084, 52.17298446382795, 52.416213103703086, 54.51669522694179, 53.86696570260184, 54.63614865711757, 12.361303005899702, 0.15066361187824182, 0.2275597463761057, 0.3520891884607928, 3.729766947882516, 23.39699568067278, 51.00217131205967, 49.61764546803066, 49.51911653791155, 49.246823583330425, 51.78399303981236, 55.35579790387835, 9.49956408568791, 1.3285240147794997, 19.37930233137948, 36.19327415738787, 24.66118393625532, 27.26212395940508, 24.626990113939556, 28.70402455329895, 26.291743755340576, 26.882443121501378, 29.672584329332622, 31.903564044407435, 33.422242232731406, 29.186967781611852, 38.26617888041905, 43.597396169389995, 55.82053858893258, 58.66222327096121, 3.1837612177644457, 0.3554417485637324, 0.0978512093424797, 0.08428916707634926, 0.03838156403175422, 0.06361852732620069, 0.12079431036753313, 0.19240545774144785, 0.23401627849255288, 0.24368241695421083, 0.28887659470949856, 0.28691842406988144, 0.18712006349648747, 0.12485884369484015, 0.3654850439301559, 0.22541439506624425, 6.128348069531577, 81.38274233681815, 72.67539882659912, 37.14898150307791, 36.54717023032052, 36.86935819898333, 42.51904617037092, 32.5576605115618, 50.688998631068635, 45.823574679238455, 44.672654220036094, 34.48069259098598, 39.48675503049578, 56.959751333509175, 32.88300296238491, 44.70463677815029, 8.022433519363403, 8.010824816567556, 11.974373459815979, 49.66306584221976, 49.18007223946707, 54.10540355954851, 61.255381311689106, 58.68049703325544, 40.10638843263899, 6.105604878493717, 2.3205693534442355, 1.8712927528790064, 20.580067430223735, 60.69503688812256, 59.93361159733364, 59.52703775678362, 57.68667881829398, 51.475138664245605, 50.553321157182964, 57.18540103094918, 57.649651868002756, 56.81412056514195, 59.22009413582938, 56.39963272639683, 57.1537971496582, 58.60594981057303, 51.076555252075195, 47.1857134274074, 47.3877774647304, 54.367152622767854, 55.86062969480242, 51.73716912950788, 53.83602884837559, 49.662186895098, 46.270250047956196, 46.071757384708945, 47.94240699495588, 48.75892455237252, 48.73598160062517, 52.233253138405935, 46.98676913125174, 46.892197200230186, 42.36056123461042, 35.66349833352225, 26.31801836831229, 25.639695269720896, 33.19441080093384, 30.25202935082572, 13.172376649720327, 0.30527336629373686, 0.2062638976744243, 0.1347046582294362, 0.16360479460230895, 0.18376013450324535, 0.12698117909686907, 0.1230440339339631, 0.10918580434684243, 0.14962534473410674, 0.12412052974104881, 0.14486871925847872, 0.3092755286821297, 0.12964282770242008, 0.14817773098392145, 4.445703251021249, 2.1161418429442813, 0.38789691988910946, 0.16419170025203908, 0.19134478537099703, 0.08037243903215442, 0.16918461876256125, 0.19800023681351117, 0.13895226030477456, 0.14114301917808397, 0.1037476650838341, 0.14167146225060734, 0.13047251318182262, 0.12520112389964716, 3.4630792353834425, 34.806406770433696, 31.497209072113037, 28.26370504924229, 36.812115464891704, 43.673440728868755, 38.89703362328665, 43.156341893332346, 42.516589982169016, 45.48995344979422, 43.130779470716206, 47.588972977229524, 44.907743045261924, 47.357952322278706, 47.2127662386213, 45.40048844473702, 43.517953940800254, 46.188612188611714, 43.27142490659441, 46.73841272081648, 44.113511834825786, 40.76222194944109, 42.72652632849557, 51.02614607129778, 53.6239698273795, 55.765098912375315, 53.46435580934797, 55.329460757119314, 52.83494281768799, 50.150065081460134, 43.45492335728237, 50.2960467338562, 56.861118180411204, 56.21936171395438, 55.38090174538748, 56.18794543402535, 56.30465085165841, 12.04990906374795, 0.535811257149492, 0.6991623203669275, 1.2050624511071613, 4.864681363105774, 21.55895049231393, 58.6489383152553, 52.653351647513254, 54.588925225394114, 52.51552718026297, 53.875091620853965, 55.20451477595738, 14.460309505462646, 1.6249949634075165, 21.241984094892228, 36.479706696101594, 34.87079572677612, 35.467183930533274, 34.55424969536917, 41.44571277073452, 31.492859499795095, 35.747925894601, 49.52954925809588, 43.23924085072109, 45.26739917482649, 42.44674668993269, 50.74827718734741, 56.27958869934082, 63.739695821489605, 71.13086986541748, 7.184726561818804, 0.9181570006268365, 0.23690659339938844, 0.31296135804482866, 0.11440329759248666, 0.27229379596454756], [0.0651609120624406, 0.059406555124691555, 0.014600311106603061, 0.0407997576652893, 0.08791962119617633, 0.057077361536877494, 0.11038418539932796, 0.0862849692681006, 0.06320706369089228, 0.0399101100462888, 0.46668281512601034, 39.80835587637765, 54.64963163648333, 27.9795914718083, 36.76701470783779, 67.27002688816616, 43.74483346939087, 30.486392089298793, 41.147388390132356, 44.203869683401926, 32.436275482177734, 33.46677671160017, 23.653755937303814, 50.49150998251778, 28.768896409443446, 25.200378043310984, 9.102656057902745, 1.3722787754876273, 15.903856822422572, 44.29190335954939, 45.273569175175254, 45.71229927880423, 52.943425042288645, 47.51514836720058, 32.060304982321604, 3.5479386704308644, 0.20009218741740498, 0.824846221932343, 14.237466880253383, 46.84058598109654, 58.047067982809885, 56.397878306252615, 55.61206136431013, 48.98870842797415, 51.70645114353725, 54.50737074443272, 54.30620649882725, 56.469215461185996, 52.100810050964355, 52.60683345794678, 53.77862630571638, 51.152384417397634, 45.98857702527727, 40.10177135467529, 47.44981792994908, 52.15487051010132, 51.246428285326274, 51.13988808223179, 49.18052734647478, 42.17747272763933, 42.45627614430019, 39.390657969883506, 42.065464292253765, 42.817870821271626, 44.39087002617972, 43.77805280685425, 42.08966139384678, 39.05428177969796, 28.571131569998606, 21.684085811887467, 11.452946765082222, 16.100490842546733, 14.290438209261213, 6.570439798491342, 0.24501231844936097, 0.22237826298390115, 0.0027243840449955314, 0.05139570623370154, 0.0454323469395084, 0.08359673566051892, 0.06273075246385165, 0.02006334581944559, 0.031064069364219904, 0.06086632143706083, 0.08954062099967684, 0.03451886773109436, 0.035198315379342864, 0.06737179628440312, 0.04181173497012683, 0.6068551221064159, 4.74540684904371, 0.04058764422578471, 0.0391387853638402, 0.060589655568557124, 0.03291384403460792, 0.026295903704262207, 0.03799008325274501, 0.026272970916969434, 0.00594186203254919, 0.02933683811819979, 0.062266810930200985, 0.04422947737787451, 0.03663542540743947, 0.05502601446849959, 14.536794407027108, 27.86373199735369, 20.448326110839844, 19.72264061655317, 32.01094497953142, 31.75722803388323, 35.47303431374686, 33.88577045713152, 37.49266024998256, 37.99754415239607, 41.433206013270784, 39.51334578650338, 39.48101929255894, 40.0551871572222, 38.81653874261038, 38.79153217588152, 37.93446145738874, 39.33703177315848, 37.91662195750645, 38.457230022975374, 35.77670880726406, 39.92748621531895, 44.833577973502024, 49.012995856148855, 46.93156221934727, 49.23970167977469, 50.93442637579781, 48.388439655303955, 45.61259262902396, 41.27415132522583, 43.92145667757307, 47.03524671282087, 49.1035030909947, 52.29810414995466, 52.43515389306204, 50.46411323547363, 14.3660580601011, 0.2572670408657619, 0.13388285732695035, 0.29647119290062357, 4.718043974467686, 33.85282904761178, 51.570606912885395, 48.90020227432251, 54.848238945007324, 50.35465826307024, 48.281197684151785, 34.92846924918038, 6.638496100902557, 0.15531450802726404, 25.677939891815186, 38.3210939679827, 21.505940948213848, 24.973488092422485, 33.00411006382534, 25.842330796378, 27.546732595988683, 30.963424137660436, 35.767829009464805, 31.75391721725464, 28.581776210239955, 34.56120484215872, 26.322477374758037, 40.9112434387207, 50.715700558253694, 47.678483145577566, 0.8695550028766904, 0.2155539241752454, 0.0197764561245484, 0.05743416239108358, 0.06931819434144668, 0.06946400473160402, 0.016324721343283142, 0.09677482210099697, 0.08170816235776458, 0.07833252527884074, 0.0803641201928258, 0.017406592844054103, 0.040655077035937986, 0.05640963218840105, 0.03462112295840468, 0.052341261745563576, 0.5651871008532388, 53.68204981940133, 64.90345655168805, 30.629577091762, 37.28881399972098, 56.90128224236624, 36.05410868780953, 27.188634599958146, 38.86367532185146, 40.39010769980294, 32.79751580102103, 32.776025022779194, 28.337616511753627, 44.215160506112234, 31.58190413883754, 28.136940377099172, 13.150757329804556, 2.5307347731930867, 15.196632691792079, 50.536437034606934, 47.60707303455898, 50.23761238370623, 56.47366925648281, 52.03456939969744, 35.53973354612078, 6.302517260823931, 0.5748120929513658, 0.9055536197764533, 14.160178593226842, 49.19234275817871, 61.089673723493306, 58.9416937146868, 56.90738276072911, 52.8876622744969, 54.53854036331177, 54.56832034247262, 57.10498258045742, 57.69194555282593, 52.69515895843506, 55.03784138815743, 56.04004260471889, 54.258986541203086, 47.87715993608747, 43.454662799835205, 49.43980632509504, 56.83074760437012, 53.13949278422764, 53.39680194854736, 51.015129702431814, 45.78690903527396, 44.26309265409197, 41.65827553612845, 44.38104179927281, 44.80846718379429, 48.71001965659005, 45.49507427215576, 48.268326146262034, 41.687197412763325, 34.84769296646118, 26.00985881260463, 20.667074510029384, 22.41514573778425, 18.24347335951669, 11.657927308763776, 0.7235412150621414, 0.03350664276097502, 0.031653787541602335, 0.04913292426083769, 0.08426978133086648, 0.0394452287416373, 0.05721068009734154, 0.020080753635349016, 0.04614515136927366, 0.0473895676300994, 0.05096775419743998, 0.051734797323920896, 0.03796568652614951, 0.04257857792877725, 0.027333723015284965, 0.3109389437096459, 2.1297477185726166, 0.0714115495128291, 0.06413769482501916, 0.025659931490996053, 0.029289849568158388, 0.033951117124940665, 0.019832942468513335, 0.06819243689200707, 0.07090011052787304, 0.041442272652472766, 0.046354883150862794, 0.01289502453125481, 0.11225072667002678, 0.40741839951702524, 15.670355660574776, 31.34487329210554, 24.466493674686976, 24.65956153188433, 35.888199601854595, 38.08521999631609, 38.565218925476074, 38.17904847008841, 41.5919063431876, 41.96897118432181, 42.28073338099888, 42.94500201089041, 40.92765508379255, 40.88029963629586, 40.80652366365705, 41.176004546029226, 40.20879445757185, 43.47639329092843, 40.79655647277832, 40.87911149433681, 37.98491580145699, 40.61888061250959, 46.791104384831016, 50.51952511923653, 48.844852924346924, 50.65214191164289, 54.87040369851248, 52.22684342520577, 48.10895878928048, 46.18039246967861, 45.7167843409947, 50.09500060762678, 53.22838108880179, 54.898696763174875, 54.293133463178364, 52.65451547077724, 15.976095506123134, 0.7316806497318404, 0.05755673974220242, 0.8567876879658017, 9.043886457170759, 40.76113108226231, 57.407100677490234, 51.89016151428223, 58.57978984287807, 56.0693952696664, 51.909692900521414, 37.74036005565098, 5.228149882384709, 0.8005998858383724, 26.992337567465647, 39.00399071829659, 24.4952609539032, 25.880241904939922, 28.383910621915543, 26.680844613483973, 27.518991913114274, 29.093973091670446, 28.938432455062866, 33.958115100860596, 29.36374385016305, 36.1824870790754, 30.696522985185894, 41.62920774732317, 59.62418052128383, 55.450098855154856, 1.1604130012648446, 0.07638480407851082, 0.04379830908562456, 0.027892516959192495, 0.07030421428914581, 0.1395150643906423, 0.1415406542697123, 0.1497624223785741, 0.0791014072352222, 0.22626583437834466, 0.20203872796680244, 0.20794462891561644, 0.20036882614450796, 0.16142447159758636, 0.12403652710574013, 0.12230249015348298, 2.1408900235380446, 68.27255467006138, 73.12044484274728, 37.977262360709055, 48.382797718048096, 82.06438146318708, 54.025124073028564, 37.69350835255214, 54.0971143586295, 56.0061423437936, 42.79365634918213, 42.729253496442524, 32.93618447440011, 65.41970075879777, 37.07742895398821, 31.750022751944407, 12.76410744871412, 4.614009899752481, 21.10336753300258, 52.28674731935774, 55.24242762156895, 54.85678175517491, 60.28719847542899, 56.963524205344065, 40.35266385759626, 6.299868260111127, 1.3748359297003065, 2.355181804725102, 18.282015017100743, 53.39407478060041, 65.97784260341099, 62.68937832968575, 60.80035073416573, 52.83428273882185, 55.97116163798741, 58.92864499773298, 59.69439206804548, 61.63842160361153, 55.25514282499041, 55.765536648886545, 57.83104501451765, 55.616866043635774, 50.17234100614275, 44.67506177084786, 51.62162058694022, 59.23740209851946, 56.8110842023577, 56.89368091310774, 54.082655157361714, 48.382561479296, 47.78289719990322, 46.080960273742676, 48.949840205056326, 49.45932728903634, 49.59360817500523, 49.05660275050572, 50.84462090900966, 46.10769346782139, 38.617347785404746, 33.17469528743199, 26.212935549872263, 28.685957499912806, 30.536686624799454, 24.318139212472097, 2.791765783514295, 0.3111930957862309, 0.11315971253705875, 0.20613429748586246, 0.21460453154785292, 0.17123866640031338, 0.20951623815510953, 0.15041008405387402, 0.13486614956387452, 0.10850327275693417, 0.14958476833999157, 0.13498452678322792, 0.1484226414135524, 0.17988284969968454, 0.12103831156023911, 1.4710926903145654, 5.667599558830261, 0.12516573151307447, 0.1649254680212055, 0.11168528308293649, 0.10335171954440218, 0.09370363689959049, 0.1336293566439833, 0.10540248307266406, 0.10666136230741229, 0.1313215233385563, 0.1648942825517484, 0.11000641781304564, 0.17970337718725204, 0.8706485841955457, 22.579211814062937, 37.32156433377947, 29.355367796761648, 30.884899071284703, 40.31181539808001, 40.87362936564854, 42.93828657695225, 40.76969473702567, 44.33353001730782, 45.5383928162711, 48.00028896331787, 45.72648402622768, 46.08334697995867, 44.499223709106445, 43.7341228212629, 43.38695955276489, 42.74605771473476, 45.63345112119402, 43.65852294649397, 43.071136134011404, 39.9585794040135, 43.74773434230259, 49.08492360796247, 53.866138866969514, 51.553927762167795, 54.492300101688926, 56.66197238649641, 53.785293102264404, 49.59423003877912, 45.793784277779714, 48.71774952752249, 50.996727398463655, 55.95827620370047, 58.12073973246983, 56.78071710041591, 54.42760195050921, 16.581952367510112, 1.412092496241842, 0.5182960427233151, 0.4783987264548029, 7.177170830113547, 39.07734979901995, 61.24614020756313, 55.016691071646555, 63.98451559884207, 57.76983833312988, 57.38956689834595, 43.448016847882954, 11.054680364472524, 1.4715443232229777, 32.60449137006487, 46.4420234135219, 33.62619965417044, 31.845786299024308, 45.24751690455845, 34.776289803641184, 36.5989898954119, 41.287036759512766, 47.9436229297093, 41.62838438579014, 39.94260549545288, 46.69786303383963, 36.855326311928884, 54.539850098746165, 67.2301859174456, 67.66145365578788, 2.432505484138216, 0.5930854209831783, 0.18329794358994278, 0.15465524340314524, 0.17355281008141382, 0.22768136699284824], [0.05373763592381563, 0.02808953299453216, 0.06016681968633618, 0.06425408393676792, 0.042530812456139495, 0.037836985396487374, 0.0840236223968012, 0.02331733174755105, 0.06848677181239639, 0.0540360047348908, 0.23836699074932508, 41.76237692151751, 58.601273672921316, 32.848932470594136, 56.5926502091544, 89.7608871459961, 58.05652100699288, 32.252947262355256, 30.885472297668457, 38.33158227375576, 35.97676134109497, 34.21018532344273, 21.716683285576956, 27.555487326213292, 46.33228356497628, 36.96958943775722, 15.598547765186854, 1.0381796402590615, 8.80419271332877, 50.71884461811611, 43.79668092727661, 48.496220111846924, 55.9695531300136, 51.49303027561733, 45.414624554770334, 13.115292855671473, 0.4542396771056311, 0.6539727023669651, 6.3649337972913465, 40.82698263440813, 60.96095139639718, 56.784535135541645, 56.51365613937378, 52.44818523951939, 54.88442516326904, 54.96225888388497, 54.74807718821934, 53.62013789585659, 53.44823251451765, 54.6403557913644, 54.62885652269636, 52.03090075084141, 44.43865973608834, 41.68419231687273, 48.98054082053048, 52.77312816892351, 50.81916618347168, 49.264343466077534, 50.494393484933035, 45.00871079308646, 42.25360761369978, 40.68614959716797, 41.939701897757395, 43.99851219994681, 44.446768283843994, 43.86845929282052, 44.573072637830464, 34.52168696267264, 27.559258460998535, 18.043167216437205, 16.9370140007564, 12.460577998842512, 14.106141584260122, 6.160638519695826, 0.655406691133976, 0.03983453142323664, 0.11633819448096411, 0.027023152448236942, 0.02970619187025087, 0.02662641302283321, 0.009558344692257898, 0.05682847149936216, 0.1039185066308294, 0.05755827323134456, 0.07102914753236941, 0.0019936098875145292, 0.05110327460403953, 0.06804827534194503, 0.026173901411571672, 0.0772587028997285, 4.87961173909051, 0.5139539614319801, 0.06858330020414931, 0.05578888121194073, 0.0397854054878865, 0.16147960935320171, 0.0021492446165731443, 0.06613857245871, 0.023253050732559392, 0.02070872761708285, 0.06726673870746579, 0.0775525967723557, 0.11117237167698996, 0.20255913718470506, 5.216013550758362, 27.117594480514526, 26.984875202178955, 19.99520628792899, 23.96671322413853, 31.354020595550537, 32.28550999505179, 36.74669122695923, 35.570402894701274, 38.97660786764962, 36.70992136001587, 38.1238693509783, 37.69286911828177, 36.65006610325405, 37.22184031350272, 39.84567812510899, 39.22530473981585, 41.07178504126412, 39.784148352486746, 40.26011037826538, 37.03081348964146, 38.78319433757237, 47.0848742212568, 48.958535875592915, 48.043075970241, 45.78559929983956, 48.289285387311665, 51.43560341426304, 48.63149806431362, 44.5486010823931, 47.32228374481201, 48.141816820417134, 49.81850051879883, 51.646411759512766, 50.254479135785786, 44.27721834182739, 12.18650369984763, 0.48096293743167606, 0.34834557505590574, 5.481534617287772, 31.70141315460205, 40.533080782209126, 49.71044908251081, 43.976726123264854, 50.53220905576433, 44.055869579315186, 48.61554847444807, 44.572120734623496, 2.223788980926786, 0.9932369547230857, 33.04646975653512, 30.980374268123082, 16.53255762372698, 26.9219297340938, 25.986300945281982, 27.73539182118007, 30.220936162131174, 28.163784742355347, 27.895453998020717, 26.534637144633702, 31.867509841918945, 27.6652740750994, 18.662880522864207, 33.09292541231428, 53.02165133612496, 32.53768791471209, 0.1892998301024948, 0.13633511002574647, 0.16148491549704755, 0.06990441467080798, 0.05947110416101558, 0.14261823573282786, 0.062211286409624984, 0.0652735149487853, 0.03375877619587949, 0.05020888402525868, 0.017644399012039815, 0.12147527454154831, 0.09748284625155584, 0.06332217715680599, 0.03428724301712854, 0.06053462637854474, 0.6848592364362308, 52.31646476473127, 68.20246819087437, 33.8478159223284, 56.67246764046805, 90.97061715807233, 41.89367355619158, 21.440237045288086, 28.469936268670217, 34.71496500287737, 34.41269404547555, 33.37768690926688, 25.652811731610978, 29.44365508215768, 28.817057847976685, 37.11381319590977, 18.16580465861729, 2.987844382013593, 7.896698917661395, 54.49991185324532, 47.366099085126606, 51.8704321043832, 58.978873525347026, 55.55142443520682, 50.52947841371809, 17.73168294770377, 0.8967446610331535, 0.6515994582857404, 6.011931002140045, 41.35614006859915, 61.89173207964216, 59.188132422310964, 57.383963176182334, 55.65180506025042, 55.70850930895124, 57.848054204668315, 57.93057101113455, 57.32294062205723, 53.05593374797276, 55.67189577647618, 56.241422244480674, 53.50165373938424, 46.38512461526053, 43.886510712759836, 49.28346838269915, 54.79381717954363, 53.73153141566685, 53.525354044778005, 53.17831931795393, 47.76386955806187, 45.043104376111714, 44.67075736182076, 45.17325455801827, 46.28859329223633, 47.67613812855312, 46.798615387507844, 46.779896940503804, 39.65093054090227, 34.06911604745047, 23.300170796258108, 24.49607563018799, 19.149346487862722, 21.812260968344553, 11.339098794119698, 0.5315570054309708, 0.032651685244802914, 0.04745516161035214, 0.07522419028516326, 0.06096519755997828, 0.06245037500879594, 0.06274174473115376, 0.06177192819969995, 0.07401835213282279, 0.05486610072797962, 0.03704238696289914, 0.013990223307960799, 0.051381165228251896, 0.09949777634548289, 0.018704338564670513, 0.029786520238433565, 1.2109220623970032, 1.1529014557600021, 0.12913509351866587, 0.06573156001312391, 0.04230189848957317, 0.09307201579213142, 0.026681795051055293, 0.050127083236085515, 0.04810439070154514, 0.01432051888800093, 0.08071178796568088, 0.07326433009334973, 0.20069750850754126, 0.1174548188490527, 6.551018280642373, 30.987266881125315, 27.469657966068812, 26.1840466771807, 28.680216550827026, 36.1695008959089, 36.605333600725444, 41.84845815386091, 39.42092432294573, 43.49426405770438, 39.52831220626831, 40.20672042029244, 40.02992698124477, 40.19168451854161, 39.57147789001465, 41.40723712103707, 40.99912772859846, 44.22436686924526, 40.69647809437343, 42.32780742645264, 39.617471490587505, 39.48238461358206, 48.03190326690674, 52.224651268550325, 50.55693769454956, 48.62930243355887, 50.1379508972168, 53.4928468976702, 51.462395668029785, 47.38163525717599, 50.18292658669608, 50.075486591884065, 54.42575025558472, 55.736500126974924, 53.66671167101179, 46.36890057155064, 13.26280050618308, 0.7918739797813552, 0.8147992353354181, 8.802968961851937, 40.01028789792742, 45.73143809182303, 52.073392459324424, 47.73039313725063, 54.38516582761492, 47.60990789958409, 52.98318263462612, 40.65135996682303, 1.0062193380934852, 2.157812795468739, 35.87117998940604, 40.047113350459504, 21.79230921609061, 26.72857873780387, 25.465908663613455, 29.792854172842844, 31.0119468825204, 29.63592563356672, 26.564092295510427, 29.449439457484655, 27.550838981355938, 30.837835448128835, 18.110825300216675, 35.847820145743235, 62.46903705596924, 40.348602635519846, 0.275455579161644, 0.07872103407446827, 0.08867987897247076, 0.08358321245759726, 0.07220876709158931, 0.1088729997032455, 0.14231297639863832, 0.12970825204891817, 0.09223872729177986, 0.10845098484839712, 0.08762603944965772, 0.1905856811042343, 0.1685437967202493, 0.1343121257211481, 0.10622978689415113, 0.12683894458625997, 1.325408616236278, 66.29206793648856, 78.86789744240897, 44.65720837456839, 73.31190245492118, 106.45709569113595, 72.32781519208635, 40.129230635506765, 41.04923118863787, 48.5584134374346, 46.21656826564244, 43.941439696720664, 29.835634231567383, 39.42027119227818, 57.012943267822266, 46.06870712552752, 20.84141002382551, 4.392428806849888, 13.831140569278173, 59.86237171718052, 54.37980876650129, 56.68784400394985, 65.68850571768624, 59.74752494267055, 54.69974204472133, 17.82365451540266, 1.0530910172632761, 1.4893981537648608, 8.740324003355843, 46.51272133418492, 65.09435135977608, 61.44447653634207, 61.01444557734898, 56.95351185117449, 59.07531452178955, 60.90924290248326, 59.386246408735005, 59.428915296282085, 55.98337657111031, 59.02880328042166, 58.70669174194336, 56.68562405450003, 48.750020435878206, 45.19800751549857, 54.464378765651155, 55.219105992998394, 55.32715742928641, 55.51409871237618, 56.73800652367728, 51.17527525765555, 49.42211968558175, 47.52875641414097, 49.32860735484532, 49.19528184618269, 50.784911564418245, 51.65719883782523, 51.37249640056065, 43.400981017521445, 37.93517712184361, 29.453035150255474, 30.53578335898263, 25.466445411954606, 28.449043035507202, 18.59293474469866, 0.8639588803052902, 0.1307282123182501, 0.22765045293739863, 0.1602529673171895, 0.09960328854088273, 0.3453972318342754, 0.1253223373953785, 0.13272208747054848, 0.31084449163505007, 0.1962939655142171, 0.24541897805673735, 0.11446724273264408, 0.09531842132232018, 0.15771315645958695, 0.16295190820736544, 0.1824642140418291, 6.522757351398468, 1.440535164305142, 0.22044730159853185, 0.13535484405500547, 0.17253310765538896, 0.21621933632663318, 0.15486183017492294, 0.11590516700276307, 0.14968330519539969, 0.09946842970592634, 0.25619481982929365, 0.22152364812791348, 0.36264882183500696, 0.28765770154339926, 10.20920705795288, 40.5829792703901, 31.852546896253312, 29.079446145466395, 32.70217261995588, 40.592738015311106, 40.80672516141619, 43.27622263772147, 41.83168520246233, 46.69512891769409, 42.54590095792498, 44.40394653592791, 43.11404126031058, 41.62120689664568, 42.66950593675886, 44.51383924484253, 44.63362618855068, 46.25325475420271, 42.50923183986119, 45.60946593965803, 41.75073521477835, 43.37929221561977, 50.90505634035383, 55.711632524217876, 54.057804925101145, 51.68134035382952, 52.781566756112234, 56.306714466639924, 54.813897473471506, 50.38521991457258, 52.35438108444214, 52.53190061024257, 56.00933851514544, 56.229856967926025, 55.04682193483625, 49.68575171061924, 17.12695516858782, 1.1577692117009843, 1.457448382462774, 8.526791095733643, 38.449138845716206, 52.352345262254985, 58.47034181867327, 53.19690227508545, 58.80349404471261, 53.42500468662807, 56.61453356061663, 50.38069316319057, 4.603911995887756, 2.3109767138957977, 41.22969675064087, 38.22545548847744, 24.60931042262486, 36.6025265284947, 34.727110454014365, 35.877388204847065, 42.47600555419922, 38.40757472174508, 38.225855009896414, 34.74870892933437, 41.86441469192505, 38.40383659090315, 28.25624963215419, 48.867003781454905, 69.58002499171666, 53.102219172886436, 0.5744387901255062, 0.34142717772296494, 0.24919355979987554, 0.2345612235367298, 0.14331943382109913, 0.23501915325011524], [0.02452017756045929, 0.05078019354758518, 0.04406989611951368, 0.08138866735888378, 0.05367512249254754, 0.08576639209474836, 0.025348589090364318, 0.028090628828587275, 0.044868721826268096, 0.052245103155395815, 0.0862716156989336, 29.33651385988508, 65.9873685836792, 30.01475531714303, 31.635519913264684, 65.33250086648124, 65.36125946044922, 41.94527782712664, 42.44590943200247, 36.47832400458199, 36.49424580165318, 28.48364680153983, 28.36319977896554, 22.481985671179636, 102.81697613852364, 95.0139684677124, 12.339404889515468, 2.7856915380273546, 1.1199470183679034, 36.45315762928554, 48.0923421723502, 46.24533380780901, 49.12027256829398, 45.09118243626186, 46.611632415226524, 17.681767089026316, 2.1071460970810483, 0.1532280399863209, 1.1733922362327576, 20.070062705448695, 53.40191234861101, 59.71919018881661, 57.76089947564261, 54.76420395714896, 55.86524677276611, 54.56570087160383, 57.11664860589163, 57.52350732258388, 51.78211007799421, 55.12530183792114, 54.49042408806937, 51.5405490057809, 45.64712170192173, 43.2441532271249, 49.68764509473528, 53.27727903638567, 52.2042999948774, 50.918917996542795, 49.15916510990688, 45.56923586981637, 41.13735866546631, 40.281886032649446, 43.65664345877511, 43.01152753829956, 46.07965748650687, 45.076698916299, 39.70004735674177, 33.59988682610648, 25.00920704432896, 17.280185529163905, 15.876842226300921, 16.496689285550797, 21.399527549743652, 7.2777099609375, 0.0460427672203098, 0.034616230720920224, 0.08658522779920272, 0.06958274157451731, 0.04375409913648452, 0.05822046234139374, 0.0667996419859784, 0.010194979325336005, 0.03396499316607203, 0.015753437266019837, 0.029911384252565246, 0.11297897116414138, 0.04448756495756762, 0.06668239792010613, 0.042450928528394015, 0.06711778670017209, 0.5043069847992488, 0.97173901115145, 0.04498933142583285, 0.044374144436525445, 0.06544781702437572, 0.019177048467099667, 0.01176060049328953, 0.025472489584769522, 0.07234691003603594, 0.08417399254228387, 0.03878940089738794, 0.0629616647160479, 0.1676002394940172, 0.15245261016700948, 2.8950616121292114, 20.646961212158203, 23.558391911642893, 26.4287257535117, 25.411208970206125, 28.75087104524885, 32.70275626863752, 33.664029121398926, 38.18982860020229, 37.18650524956839, 35.60472352164132, 37.865938322884695, 37.380050795418875, 37.18056453977312, 36.654419149671284, 40.882620334625244, 40.236712319510325, 42.471100125994, 40.5945098059518, 41.509688309260774, 36.76501015254429, 40.67730106626238, 46.13135208402361, 48.18813003812517, 49.033361026218955, 51.92756714139666, 51.88245596204485, 49.65316118512835, 48.27628183364868, 46.000249998910085, 47.07771757670811, 48.801617758614675, 48.895216941833496, 52.28272778647286, 52.0309111731393, 35.04006774084908, 7.272829719952174, 0.3721188636762755, 1.8648276712213243, 13.999135851860046, 49.97134004320417, 39.95485169546944, 37.54429578781128, 39.841884408678325, 43.150269167763845, 43.06426089150565, 59.2631173815046, 21.809657130922588, 0.20555587352386542, 5.680004698889596, 38.05511692592076, 19.78496422086443, 21.030545200620377, 30.617480278015137, 28.46763120378767, 30.055193832942418, 27.31302125113351, 28.729109287261963, 23.961081709180558, 28.893116303852626, 34.31483561652047, 33.720281737191335, 32.05499308449881, 38.11173432213919, 59.55424690246582, 27.692356416157313, 0.08217349488820348, 0.057879973469035964, 0.09963647568864481, 0.026239408878609538, 0.07508690908019032, 0.06668344964938504, 0.07077435763286692, 0.025281982396596243, 0.03966764573540006, 0.011984638337578093, 0.018147042486816645, 0.045273067629230876, 0.03489229269325733, 0.03745349436732275, 0.11937235881175313, 0.07591222479407277, 0.019061561806925705, 37.46847357068743, 76.48183740888322, 33.03338977268764, 39.98643125806536, 76.62768009730748, 69.94406196049282, 35.272484983716694, 29.09993290901184, 33.50413370132446, 34.88936478751046, 31.344522408076696, 30.0202374458313, 24.036907400403702, 75.91334969656808, 94.73684651511056, 14.131747433117457, 4.463750762598855, 2.0869227136884416, 35.94463981900896, 53.08069017955235, 51.305811064583914, 54.88670417240688, 50.078925950186594, 51.565270696367534, 23.408300399780273, 3.9407381415367126, 0.2704522790653365, 1.0841164610215595, 18.416125672204153, 53.44684287479946, 60.21754278455462, 58.17978204999651, 59.57791941506522, 58.04645654133388, 56.20544794627598, 61.58393383026123, 57.038839203970774, 52.479935032980784, 57.553290775844026, 56.467363766261506, 54.01037652151925, 45.59791803359985, 44.62274183545794, 52.04882710320609, 54.66772474561419, 52.89736890792847, 53.03560331889561, 52.35982847213745, 51.0883915083749, 46.190825189862935, 43.44269452776228, 46.78054659707205, 47.254583971840994, 48.07548236846924, 46.894066265651155, 43.292651653289795, 37.86830765860421, 34.125097683497835, 23.75130864552089, 26.146314484732493, 21.326039927346365, 29.269679137638636, 12.299552627972194, 0.05942760328097003, 0.03265538326065455, 0.10720882471650839, 0.04354152429316725, 0.07334694173187017, 0.04236307181417942, 0.02742855846216636, 0.0559587320978088, 0.1153908238879272, 0.0580518531746098, 0.039417435947273455, 0.026200790058023164, 0.015252206840419343, 0.05081255966797471, 0.056885217382971726, 0.06600893155804702, 0.16527836051370415, 1.5920043736696243, 0.08417927154472896, 0.053855164974395714, 0.0627034210733005, 0.04582291169624243, 0.030755006841250827, 0.055816002256636105, 0.007453795389405319, 0.16028126222746714, 0.0786625307851604, 0.10492593435836689, 0.030597512078072344, 0.08028065360018186, 3.9806242755481174, 25.21467743601118, 22.59351815496172, 29.710306099482946, 31.843229361942836, 33.17647055217198, 36.45444999422346, 38.10009956359863, 42.08167096546718, 40.13295834405081, 40.02620622089931, 39.0941435950143, 39.91476058959961, 40.986718245915, 39.3072726385934, 43.76163421358381, 43.43303305762154, 44.46684510367257, 42.562621797834126, 42.88459437234061, 40.05900171824864, 41.19255862917219, 47.153981004442485, 50.7467485836574, 51.03376129695347, 54.20468289511544, 54.78465945380074, 51.10950708389282, 50.560585498809814, 48.72680997848511, 49.510691847120015, 50.18414946964809, 49.897484166281565, 55.16425691332136, 55.30612175805228, 34.1175171988351, 6.8494720714432855, 0.637448149068015, 5.499532622950418, 20.08533832005092, 50.846080030713765, 44.97152403422764, 40.77555554253714, 43.01253850119454, 45.958453110286165, 46.5856739452907, 62.97666549682617, 18.903204815728323, 0.04206019413790532, 8.837724719728742, 43.80494928359985, 30.182536942618235, 26.02978277206421, 28.979183639798844, 28.69018374170576, 29.835839203425817, 27.90515194620405, 27.90337668146406, 23.991537400654384, 31.878192697252544, 27.185785838535853, 35.521046366010395, 35.564691475459504, 42.39840807233538, 67.57231521606445, 32.814604895455496, 0.17406006929065498, 0.07039225420781545, 0.025259475390027677, 0.07308252342045307, 0.05811697218034949, 0.04156401540551867, 0.13750797137618065, 0.21295339800417423, 0.12459992830242429, 0.14274084701069764, 0.08644057091857706, 0.2244789802602359, 0.08290365285107068, 0.11067140248737165, 0.23644888081720897, 0.277878681996039, 0.2075723438922848, 47.30683789934431, 89.281357220241, 40.948357241494314, 44.647394044058665, 67.8618813923427, 79.20180007389614, 50.93926927021572, 53.52362046922956, 46.67793560028076, 48.007848603384836, 39.45897960662842, 34.98443004063198, 31.095436436789377, 120.26812035696847, 97.81398132869175, 17.453174829483032, 5.599223639283862, 4.0448456065995355, 44.98567056655884, 59.42073726654053, 53.0934088570731, 59.8443272454398, 55.77131060191563, 56.49631690979004, 24.6712292943682, 3.658866226673126, 0.5192906664950507, 2.586669943162373, 21.97868422099522, 59.25599547794887, 63.377798897879465, 61.188088008335654, 61.29337406158447, 59.61643327985491, 58.2786340713501, 62.67580849783761, 57.37517023086548, 55.33511659077236, 58.69995198931013, 57.22948040281023, 53.47364207676479, 49.34796156202044, 44.954136167253765, 54.3605831010001, 56.59252514157976, 54.71625096457345, 55.522506032671245, 52.99970545087542, 54.7056063243321, 51.163188866206575, 46.860040937151226, 51.3600035394941, 50.175002166203086, 50.83617189952305, 50.584431716373985, 47.77383327484131, 43.346138886043, 38.74247094563076, 27.958295243127004, 30.34354407446725, 24.18911984988621, 34.657694475991384, 14.339674881526403, 0.10618599424404757, 0.16434453347963945, 0.28881870210170746, 0.20002698020211288, 0.16936486480491503, 0.17779064125248364, 0.14995014587683336, 0.14275907246129854, 0.18971753625997476, 0.20935999868171556, 0.16213918610342912, 0.1716377264154809, 0.0974114847236446, 0.2220650647899934, 0.1545186543038913, 0.29165242718798773, 0.8764926163213593, 3.845955158982958, 0.11965123670441763, 0.11310857813805342, 0.1697265782526561, 0.15527839639357158, 0.11126535133059536, 0.12944097710507257, 0.13515179923602513, 0.31526294882808414, 0.11188802934650864, 0.16204374336770602, 0.19831601344048977, 0.1777006403676101, 4.261741008077349, 33.63817834854126, 32.336065087999614, 39.66334697178432, 34.1720084462847, 42.08753177097866, 41.21361861910139, 42.46197019304548, 45.21824414389474, 43.463778836386545, 40.87938594818115, 41.706148624420166, 41.08114773886544, 42.26433910642351, 42.26214347566877, 45.4334055355617, 44.470479011535645, 47.559561252593994, 46.03592899867466, 46.05439731052944, 41.22018814086914, 44.5347637448992, 51.14345250810896, 52.85317489079067, 53.81042126246861, 54.06184182848249, 58.465776852199006, 54.44273860113961, 54.66799572535923, 51.264385904584614, 52.30589655467442, 52.601274899074006, 54.49252591814314, 59.22579165867397, 57.60979700088501, 38.91708265032087, 9.798462561198644, 0.6948996548141751, 4.099301244531359, 18.505634103502544, 56.567223276410786, 49.58407177243914, 46.5314884185791, 48.464939321790425, 53.37149313517979, 50.524552140917095, 69.34101390838623, 27.141973972320557, 0.40043117159179276, 8.810294100216456, 47.356837136404856, 27.72254981313433, 30.16745240347726, 41.7802928515843, 37.825934069497244, 38.04829726900373, 36.38011121749878, 38.331940105983186, 30.55937249319894, 37.39203296388899, 44.598978996276855, 47.460629326956614, 42.87336955751692, 53.772841930389404, 75.26770223890031, 44.30362149647304, 0.31169317609497477, 0.17201651180429117, 0.14623868146112987, 0.26913632825016975, 0.19515984851334775, 0.2808746855173792], [0.018371194833889604, 0.03440381533333233, 0.025521549362955347, 0.06375342008790799, 0.046236407543931685, 0.06960655815367188, 0.039151531644165516, 0.01109820612639721, 0.07826834943677698, 0.06779442182076828, 0.05157275637611747, 18.171872173036846, 76.28115953717912, 43.446755749838694, 33.29430157797677, 35.379323959350586, 18.563055753707886, 16.65179913384574, 32.329471247536794, 34.751422200884136, 31.27260160446167, 28.087833983557566, 37.62726422718593, 18.746218953813823, 26.032968521118164, 16.467755249568395, 21.89763695853097, 8.079004883766174, 1.5396989860704966, 25.26428062575204, 57.08080979755947, 53.30673939841134, 57.89200503485543, 50.664937019348145, 51.84225715909685, 34.443127155303955, 12.053492597171239, 1.6759268875632967, 0.0991317949124745, 5.973739794322422, 36.97912931442261, 60.09478201184954, 59.90599945613316, 56.62515040806362, 59.28351034436907, 57.29995598111834, 57.52489348820278, 48.54652506964547, 53.6587038721357, 56.90166091918945, 54.39885377883911, 53.245588302612305, 43.73825005122593, 46.059306212833945, 53.24897902352469, 51.567202295575825, 53.39220918927874, 51.46853787558419, 52.7903527532305, 46.69402068001883, 41.98695659637451, 41.33441999980381, 44.152862957545686, 45.0866904258728, 45.329457010541645, 46.01488290514265, 34.84584821973528, 31.782429150172643, 25.428984199251445, 21.876321622303553, 25.638270889009746, 24.92338636943272, 22.895009177071707, 10.577078563826424, 0.02013817466130214, 0.049518769806517024, 0.008769639335306627, 0.041177504895521064, 0.04496088045250092, 0.05443556347329702, 0.029385981016925404, 0.006040776747145823, 0.05258486260260854, 0.11412484039153371, 0.040398896139647276, 0.0647769630221384, 0.03331535695386784, 0.020610156834923794, 0.0728295859215515, 0.024435979846332754, 0.08495938325566904, 0.8705437641058649, 0.15055986387389048, 0.1412992315100772, 0.00976901370034154, 0.08856074179389647, 0.025612327170425227, 0.009673958577747856, 0.049787388249699555, 0.022662219757746373, 0.11003353207239083, 0.04522852859060679, 0.07752564536141497, 0.025067797728947232, 2.649687281676701, 16.554037979670934, 15.594213826315743, 14.010790586471558, 27.18989222390311, 23.96348578589303, 28.394084521702357, 33.92579902921404, 33.76863425118582, 38.425556659698486, 36.581247670309885, 39.21611227308001, 37.66181067058018, 40.23512118203299, 39.10916212626866, 43.03208030973162, 42.98141751970564, 42.5573342187064, 42.117874554225374, 41.1300630569458, 37.16615397589547, 41.0641941343035, 45.740112917763845, 50.536412715911865, 51.20345715114048, 49.6232248714992, 45.39379732949393, 51.47715016773769, 47.43640095846993, 49.828332219805034, 47.77561548777989, 49.506703581128804, 48.72433989388602, 50.333059787750244, 46.55088431494576, 20.78540406908308, 1.8973172307014465, 5.945344243730817, 26.413285119192942, 45.950222969055176, 38.89964962005615, 39.579124382564, 51.78099489212036, 46.005016463143484, 49.05116925920759, 49.96266869136265, 45.090140206473215, 6.7837065032550266, 0.34450552825416836, 15.279938118798391, 31.101311138698033, 15.617342642375402, 24.66285150391715, 29.404508931296213, 28.60266944340297, 29.058262825012207, 32.011306285858154, 34.526477745601106, 26.975826910563878, 26.001675571714127, 27.058359350476945, 30.59117439814976, 29.17383221217564, 37.57198435919625, 64.14398370470319, 16.465201786586217, 0.25971364815320286, 0.12031174983297076, 0.07452345360070467, 0.06929293926805258, 0.1399156714656523, 0.04465633358008095, 0.11333833009536777, 0.05526453988360507, 0.014252573783908571, 0.029893990007362196, 0.07679310574063233, 0.02054317864323301, 0.08649617007800511, 0.03760185944182532, 0.18353501015475818, 0.06744368706962892, 0.05631145495655281, 24.42582413128444, 89.09249128614152, 43.01044709341866, 30.708974157060894, 42.20565114702497, 33.909140723092214, 27.82062189919608, 29.388955388750347, 33.853968552180696, 31.898755890982493, 30.51040506362915, 35.76029021399361, 22.638631071363175, 28.59782133783613, 18.643076419830322, 21.500081879752024, 11.550592405455452, 1.6972155166523797, 27.090265478406632, 65.43614019666398, 61.23541913713728, 62.505674907139365, 57.733266489846365, 55.719657693590435, 41.28679704666138, 17.13866809436253, 3.103065924985068, 0.23396508981074604, 5.528066268989018, 36.077437264578684, 60.469324656895225, 62.63236836024693, 60.218209811619346, 61.6941739491054, 59.450635365077424, 57.830516951424734, 47.732901436941965, 53.6879175731114, 58.21015610013689, 56.92044537408011, 56.51259306498936, 45.892622402736116, 47.91403750010899, 53.6995210647583, 53.97315502166748, 54.516816820417134, 53.300124713352744, 53.92094278335571, 48.970094203948975, 44.69113642828805, 43.51524414334978, 48.225744111197336, 48.09770270756313, 48.667937891823904, 49.07534204210554, 38.76985379627773, 39.44386380059378, 28.040221452713013, 29.193141256059917, 29.648498398917063, 24.725397450583323, 29.399051121303014, 13.63347213608878, 0.012698865146376193, 0.09962475060352258, 0.05490130991009729, 0.034539827677820406, 0.0007882917686531853, 0.021086028710539852, 0.012372992766488875, 0.01695568936078676, 0.018832976929843426, 0.022066208168065975, 0.02561299892009369, 0.04121318565947669, 0.041257012236331186, 0.05321546930021473, 0.0937888269711818, 0.06892469831343208, 0.06738106507275786, 1.2312205731868744, 0.6513375437685421, 0.09867515441562448, 0.034236207005700896, 0.026220845856836865, 0.052704515467797, 0.0336464175821415, 0.038422401661851575, 0.03944754933140107, 0.07499592431953975, 0.036005941685289145, 0.08560102632535355, 0.013033073328967606, 2.240962322269167, 25.34017927306039, 16.70588391167777, 10.12490803854806, 33.15171412059239, 29.867158208574565, 31.795543875013077, 39.14309712818691, 37.70911748068673, 43.95561749594552, 40.46226474217006, 41.89163425990513, 40.33468539374215, 42.69259827477591, 39.92903913770403, 45.593672684260774, 44.49245963777815, 45.83872175216675, 43.10645382744925, 42.962011201041086, 39.48096023287092, 41.833498682294575, 47.673532554081504, 52.919328689575195, 51.305203097207205, 53.10041958945138, 47.17930718830654, 53.43547214780535, 48.26044341496059, 52.16511910302298, 51.355831146240234, 53.22400024959019, 52.37460381644112, 53.32972403935024, 47.23060573850359, 20.43538682801383, 3.4587678781577518, 12.035115480422974, 34.932846614292686, 51.265244007110596, 40.49210030691964, 44.665237018040244, 54.85047626495361, 51.944517271859304, 53.44031156812395, 51.57389688491821, 46.968036787850515, 6.200462119919913, 0.197725810110569, 22.98036084856306, 37.69861875261579, 22.960938896451676, 26.22278114727565, 27.940587759017944, 28.060317380087717, 29.181853907448904, 29.334953989301408, 30.98886844090053, 27.033813101904734, 27.311478751046316, 25.47533563205174, 41.93530021395002, 31.34932361330305, 43.39661060060774, 71.65756416320801, 20.685848542622157, 0.32713204622268677, 0.155997792791043, 0.11485031646277223, 0.040044402304504595, 0.1550106464752129, 0.05706151095884187, 0.2565518378147057, 0.17172170190938882, 0.17248478239136084, 0.16402866185775825, 0.17360524726765497, 0.24679900971906527, 0.27421044026102337, 0.19698076508939266, 0.23849591240286827, 0.2804311678877899, 0.18206414979483398, 32.4670421055385, 103.6158035823277, 53.60625886917114, 47.40235825947353, 39.19814770562308, 24.745107752936228, 25.154075247900828, 38.5394480569022, 47.26458590371268, 39.795202936444966, 40.424602031707764, 46.93347644805908, 26.16426341874259, 35.03459256035941, 19.213035413197108, 27.98620789391654, 13.040373904364449, 3.40802909220968, 31.544915403638566, 68.64125388009208, 63.444195883614675, 65.87219524383545, 60.76482459477016, 62.71369007655552, 44.40229286466326, 18.23793043409075, 3.023489075047629, 0.28909817710518837, 8.984085048948016, 41.78217233930315, 64.94067110334123, 65.00761699676514, 61.25087193080357, 64.8860582624163, 63.199014799935476, 59.14080824170794, 51.26176643371582, 55.43228019986834, 61.245827538626536, 59.959118434361045, 59.02237619672503, 48.73388671875, 51.391968727111816, 54.95190954208374, 56.140999930245535, 57.2367273739406, 56.94577155794416, 57.762772015162874, 54.022268363407676, 48.180122239249094, 46.84210416248867, 51.7564503805978, 52.82998875209263, 49.78232819693429, 54.1888097354344, 45.96098572867257, 45.822452545166016, 36.8275647844587, 30.276358468191965, 35.832537582942415, 34.017341545649934, 32.40739529473441, 14.190029791423253, 0.09326698604438986, 0.1141097362020186, 0.23708447813987732, 0.12016165788684573, 0.16675017082265445, 0.09809571265109948, 0.14757812315864222, 0.07312248234770127, 0.12521352751978806, 0.15477111004292965, 0.1275751550814935, 0.15780302163745674, 0.13922713484082902, 0.10236890906734125, 0.20635753550699779, 0.14901367255619594, 0.1511753358479057, 4.730011812278202, 1.233059674501419, 0.21175362595490047, 0.09539355550493513, 0.1722694289471422, 0.14764276040451868, 0.20054087548383645, 0.07595590209322316, 0.1650662233254739, 0.20230058820119926, 0.10184567714376108, 0.13160851651004382, 0.09589748310723475, 3.2233466250555853, 29.75549370901925, 23.8479893548148, 25.533815145492554, 41.09407486234392, 32.30867876325335, 41.973254748753135, 42.03091784885952, 41.72891787120274, 44.348315783909385, 43.415388107299805, 44.22800077710833, 42.19944987978254, 44.995272977011545, 41.70652730124337, 48.129553249904085, 46.985768590654644, 47.367103099823, 46.12874303545271, 45.89789955956595, 42.27510186604091, 45.10425894601004, 51.10668611526489, 57.52516794204712, 53.61699036189488, 54.199423108782085, 49.31087555204119, 56.625970295497346, 52.211831842150005, 56.33362831388201, 55.08298036030361, 58.018965993608745, 52.30963815961565, 55.47239909853254, 51.71108559199742, 25.25851709502084, 4.118553400039673, 8.056304250444684, 32.04107584272112, 53.25125803266253, 45.47450760432652, 48.442124911717, 58.98482118334089, 56.26043946402413, 57.31256348746163, 58.942513602120535, 53.807339736393516, 10.841493129730225, 0.8248795515724591, 19.796331473759242, 39.1396403993879, 24.007335867200577, 34.590404646737234, 39.71943283081055, 35.98259087971279, 40.29251330239432, 40.86640671321324, 45.626808643341064, 36.84738104684012, 35.617417880467, 39.22981759480068, 42.700098855154856, 39.99602672031948, 52.44003847667149, 81.25320707048688, 28.82866655077253, 0.46178699497665676, 0.25955180398055483, 0.33236194987382206, 0.16213164079402173, 0.19759960259710038, 0.189346703301583], [0.10695813995386873, 0.026163792936131358, 0.13479236566594668, 0.037643718267125745, 0.07615742699376174, 0.05168915566589151, 0.03694032851074423, 0.05405927509335535, 0.05876956001988479, 0.07322919555008411, 0.18348019809595176, 8.368166327476501, 71.77633666992188, 50.01846967424665, 36.91026224408831, 35.06654732567923, 20.397381918770925, 24.816001960209437, 25.287923608507427, 36.884088379996165, 33.20876577922276, 33.42506667545864, 36.963596616472515, 22.160945892333984, 9.33995875290462, 19.546198061534337, 16.117623363222393, 17.070869309561594, 0.8927625832813126, 18.32647827693394, 48.76768970489502, 33.45316171646118, 40.87854869025094, 44.419705050332205, 42.332143102373394, 43.670029163360596, 36.67312022617885, 16.89743706158229, 3.2845643801348547, 0.21108370833098888, 11.492613162313189, 43.99661881583077, 62.10132449013846, 61.225149699619834, 57.71400260925293, 54.302454471588135, 48.26272937229702, 52.1256741796221, 54.333283628736226, 57.04383148465838, 55.74941335405622, 51.42308276040213, 46.29837982995169, 47.911650793892996, 52.47424445833479, 53.61297082901001, 50.852090222494944, 52.37570858001709, 48.60147837230137, 46.30972276415144, 44.128106525966096, 42.80404738017491, 45.160935401916504, 45.757417406354634, 48.452238014766145, 41.4112149647304, 37.39558349336897, 31.13683727809361, 19.167272840227398, 29.032898426055908, 20.98744899885995, 15.123065165110997, 23.67331859043666, 12.370810747146606, 0.20796033021594795, 0.053754748576985936, 0.11098722661180155, 0.04344288905018142, 0.05120934659082975, 0.05108337995729276, 0.06996947939374618, 0.03833070443943143, 0.041862221368189366, 0.028989119455218315, 0.07534679477768284, 0.03293904143252543, 0.018623414782008955, 0.02226390952377447, 0.057775438364062986, 0.055751314120633264, 0.1704758166202477, 0.3413210819874491, 0.3734568804502487, 0.01980669334131692, 0.09895348948027406, 0.020616261953754083, 0.013692121670049216, 0.020587171461167078, 0.015628211931990724, 0.024843838764354587, 0.03628274665347167, 0.038714595804257054, 0.057985709580991945, 0.06751342011349541, 1.213147548692567, 17.94959930011204, 14.790180444717407, 2.3642103374004364, 8.39493339402335, 22.402819633483887, 22.515925884246826, 30.464216913495743, 32.9720093863351, 36.421310561043875, 39.34105478014265, 39.49302577972412, 39.05708885192871, 40.461938176836284, 40.23712921142578, 43.39106593813215, 41.372409275599885, 43.82237883976528, 42.34007099696568, 40.995393071855815, 36.97770840781075, 42.66786616189139, 49.1942708832877, 49.21212427956717, 48.72115761893136, 45.540386949266704, 50.87990386145455, 49.80508702141898, 47.612100056239534, 47.00483097348894, 47.49612072535923, 48.713747365134104, 47.512629645211355, 44.14512961251395, 38.03768736975533, 11.017491868564061, 8.19723195689065, 36.219031129564556, 43.74589306967599, 50.042437485286165, 37.59199169703892, 29.798579488481792, 44.33253295081002, 45.18418060030256, 45.037674358912874, 49.47567640032087, 35.74443442480904, 2.596523357289178, 0.0726867610854762, 23.150357212339127, 22.245098999568395, 20.257424354553223, 28.248384271349224, 29.004452501024517, 27.53948736190796, 27.60237029620579, 31.84155832018171, 30.900751386369976, 26.904729468481882, 31.841690335954937, 25.663711718150548, 19.65688807623727, 30.752852031162806, 43.189835684640066, 63.584382738385884, 9.056861349514552, 0.302967975714377, 0.02317533302786095, 0.095436995316829, 0.0025887800937718047, 0.16210056389016764, 0.089994574497853, 0.10618009098938533, 0.018942791037261486, 0.1301118175366095, 0.07787657688770976, 0.08866997236119849, 0.07860174083283969, 0.04753901496795671, 0.0948014794183629, 0.04929196608385869, 0.06776355526276998, 0.21548125307474816, 11.211412617138453, 84.3526108605521, 54.57881907054356, 36.972497258867534, 39.37110921314785, 21.737619944981166, 36.847085748400005, 25.49387342589242, 31.0134094783238, 32.15097202573504, 32.58562353679112, 34.273980208805625, 20.23172296796526, 13.873540214129857, 15.289299079350062, 15.254820380892072, 18.142243317195348, 1.0458368808031082, 17.82565038544791, 60.874161447797505, 40.56436504636492, 46.16974435533796, 50.63118267059326, 49.65700006484985, 49.61007193156651, 41.52985198157174, 23.68046133858817, 5.843942667756762, 0.055354394883449586, 8.860500914709908, 39.45274359839303, 59.69437122344971, 63.35199328831264, 58.36208888462612, 54.55372217723301, 50.03907108306885, 51.35714782987322, 56.82860061100551, 57.12992313929966, 55.72328812735421, 52.27890975134713, 47.52748489379883, 49.18644026347569, 53.61714669636318, 56.284497601645334, 52.125566482543945, 53.5200525692531, 52.10239424024309, 49.89907530375889, 46.59186479023525, 46.541076932634624, 48.12414060320173, 49.89540318080357, 50.81758894239153, 46.0204553604126, 44.98136963163103, 29.9909542628697, 25.914922101157053, 31.140408652169363, 14.170366389410836, 11.453567760331289, 28.133164031164988, 17.592724187033518, 0.5477116757205555, 0.008467272256634064, 0.09774491004645824, 0.03219271058748875, 0.022471732925623655, 0.04438787798530289, 0.04377221941415753, 0.05554575872208391, 0.06197707647723811, 0.019746995830376233, 0.15127707538860186, 0.031775839028081725, 0.02744742852103497, 0.0370060581980007, 0.0643013846129179, 0.009039918492947305, 0.13972455529229982, 1.08859555210386, 0.5802954701440675, 0.058855218280638964, 0.026484846869217496, 0.038481291716120074, 0.07544905679034335, 0.07774992832647902, 0.05726857270513262, 0.06765667242663247, 0.07831928027527672, 0.061898461409977505, 0.02839818161113986, 0.07323843041168791, 1.5049596215997423, 25.82112663132804, 16.784403766904557, 2.2183871907847266, 5.859687285763877, 26.449169090815953, 28.024718284606934, 33.881393092019216, 37.44007975714547, 40.43630974633353, 43.546792439052034, 42.627167088644846, 41.255478041512625, 42.650662422180176, 42.93410723549979, 46.41334819793701, 44.41352810178484, 45.35778481619698, 47.013689926692415, 43.30736098970686, 39.50985779081072, 43.54283543995449, 49.177244322640554, 51.045135498046875, 51.28021042687552, 46.02003846849714, 53.09386396408081, 51.55224977220808, 50.02776983806065, 50.048656123025076, 51.641436849321636, 50.98621824809483, 50.91858448301043, 43.53173916680472, 36.248845849718364, 11.24538322857448, 14.027917895998273, 40.94393471309117, 47.68695647375924, 54.17501756123134, 41.45942504065377, 33.5632072857448, 49.96780341012137, 48.26107570103237, 46.603478704180034, 54.18656894138881, 35.76638725825718, 0.8497820581708635, 0.7470812776259014, 29.96990122113909, 24.41195900099618, 25.037465367998394, 27.179589782442363, 28.53969270842416, 27.84092800957816, 27.098288910729543, 34.394521032060894, 25.224686316081456, 27.30548940386091, 30.01407786778041, 26.337824208395823, 22.997427361352102, 25.655238389968872, 50.737757614680696, 71.0331642968314, 11.301794784409658, 0.47836925089359283, 0.1945279152797801, 0.20724724419414997, 0.04903354262933135, 0.07829969096928835, 0.05431525921449065, 0.21800788678228855, 0.11624809860118798, 0.3241862271513258, 0.1926680372229644, 0.24980969673820905, 0.32564697733947207, 0.20114447309502534, 0.3637131175824574, 0.27859586636934963, 0.6134574306862695, 0.37215680735451834, 16.341407469340734, 95.80811977386475, 65.55029909951347, 53.13575117928641, 45.75730970927647, 23.001757826123917, 31.335006850106375, 30.782190799713135, 45.545045716421946, 40.04233298982893, 43.638539927346365, 48.274510043007986, 28.606893948146276, 15.037675278527395, 28.93257164955139, 21.25290318897792, 21.93650344439915, 3.2514829209872653, 24.98581072262355, 61.250413349696565, 43.66927875791277, 56.93501227242606, 55.952801023210796, 53.82968514306204, 53.7753780228751, 46.46343428747994, 21.04053497314453, 4.746615835598536, 0.3851523000214781, 15.156260183879308, 48.90660851342337, 65.77899210793632, 66.20087282998222, 60.65848936353411, 55.617449692317415, 51.43277897153582, 53.41943917955671, 57.450096130371094, 58.50552749633789, 58.23734787532261, 54.43215996878487, 51.177946840013774, 52.09209353583199, 56.07245247704642, 58.54411779131208, 53.354845251355854, 57.55504519598824, 54.40584714072091, 52.34342724936349, 49.86668280192784, 49.66368770599365, 49.33887331826346, 53.44535248620169, 51.33690077917916, 51.799973896571565, 49.766076360430034, 38.14123289925711, 30.18618474687849, 38.556617055620464, 30.65304810660226, 21.969595977238246, 35.91215699059622, 18.806485891342163, 0.5150587250079427, 0.15141644648143224, 0.3022034295967647, 0.1316856388002634, 0.11639353579708508, 0.14419759384223393, 0.1831945212824004, 0.22951680421829224, 0.1225913017988205, 0.11013603157230786, 0.16702986295734132, 0.1067666777276567, 0.17776934882359846, 0.12781888486019202, 0.28890373611024445, 0.1788690640990223, 0.24125860844339642, 1.8370274943964822, 1.9454102729048048, 0.26361020335129326, 0.14297454804182053, 0.13712728608931812, 0.13987696782818862, 0.3085382596722671, 0.1799968300121171, 0.1713404195117099, 0.14622105312134537, 0.14012626159404004, 0.12528028179492268, 0.1595903778714793, 2.728529793875558, 30.583104065486364, 23.053980486733572, 7.799101914678301, 20.682728801454815, 34.804058279309956, 32.393641335623606, 43.02764735903059, 42.81599828175136, 45.68233169828142, 44.03027936390468, 44.66753339767456, 42.02763482502529, 44.7692619732448, 46.037895338875906, 48.87870454788208, 46.036505699157715, 48.662820543561665, 49.22158425194876, 45.80690247671944, 40.33494595118931, 46.97053466524397, 52.21402399880545, 53.056308950696675, 52.469995634896414, 48.08938571384975, 56.07060078212193, 55.431283133370535, 51.62572002410889, 52.926301206861226, 54.955546924046104, 55.619422980717246, 55.82132373537336, 50.703912939344136, 42.77016796384539, 13.663250378199987, 10.657436217580523, 42.34907933643886, 51.486842904772075, 57.85981750488281, 45.373626708984375, 38.63463142939976, 52.75374616895403, 52.92256655011858, 54.764023303985596, 58.31568881443569, 44.83723620006016, 4.722416996955872, 0.6357188075780869, 28.565328087125504, 28.07518826212202, 29.3295031275068, 37.71363033567156, 39.0858404976981, 36.547072955540244, 36.634241580963135, 43.343467303684776, 41.46289219175066, 37.427017143794465, 42.16554267065865, 36.204057761601035, 27.034690311976842, 41.37193332399641, 58.40759263719831, 80.83872617994035, 17.107950108391897, 0.8309104793838092, 0.31011425224798067, 0.43770939697112354, 0.12086063038025584, 0.2591279095837048, 0.21080730030579226], [0.10090708000851528, 0.07308921377573695, 0.16313132643699646, 0.014287989919206925, 0.05728824343532324, 0.032099537551403046, 0.022316153327535306, 0.1518255759562765, 0.0650290252108659, 0.15380959878010408, 0.05734202412090131, 1.4721589131014687, 61.49319730486189, 58.91701371329171, 46.48395231791905, 37.86907543454851, 53.213192326681956, 31.592322962624685, 36.44764075960432, 46.17257227216448, 38.91512325831822, 36.78116471426827, 34.802032879420686, 32.02099207469395, 14.733045407703944, 19.54684250695365, 20.77795386314392, 23.63088420459202, 3.3781998242650713, 1.5061780533620288, 27.11998987197876, 37.862457275390625, 58.516491753714426, 57.725112778799875, 53.64869499206543, 35.722252300807405, 31.670476300375803, 47.518650259290425, 32.05855056217739, 6.318340914590018, 0.2856115927653653, 10.186945898192269, 41.294916016714915, 49.90883404867989, 50.237403937748496, 49.249561173575266, 48.39121198654175, 52.99445261274065, 56.27693796157837, 56.01229149954659, 55.60114574432373, 52.915913649967735, 47.35497849328177, 47.12396131243025, 52.05621998650687, 51.84410885402134, 52.744866371154785, 53.64419950757708, 55.88905130113874, 50.231581347329275, 43.28794077464512, 47.28919642312186, 48.564882210322786, 44.97978891645159, 48.542818205697195, 38.568237917763845, 35.62831612995693, 11.093491264751979, 24.979758841650828, 13.460871934890747, 2.3410378779683794, 6.6508864760398865, 17.717722279684885, 17.068468706948416, 0.7837881222367287, 0.04151697935802596, 0.06232153477945498, 0.027765366282047968, 0.025261156460536376, 0.09947963910443441, 0.0930822209588119, 0.030402402726135085, 0.06763944442250899, 0.03650517721793481, 0.0657902057947857, 0.021348531856866818, 0.09049318917095661, 0.024568238195830157, 0.06335552715297256, 0.12301268561610154, 0.201515740315829, 1.1609298821006502, 0.24452184619648115, 0.09966755259249892, 0.08414816071412393, 0.031026997603476048, 0.16028873968337262, 0.006781635631341487, 0.05250799815569605, 0.05081645106630666, 0.019139632349833846, 0.1009242944419384, 0.034507614227810075, 0.035018269504819594, 0.7239862797515733, 20.12696671485901, 9.589860269001552, 3.7192369529179166, 1.2337536258356911, 4.413446673325129, 14.969741003853933, 22.89206314086914, 30.72061586380005, 34.68595627376011, 39.328506333487375, 41.253445693424766, 40.257549967084614, 40.97974920272827, 42.26696899959019, 41.94091435841152, 43.17887837546212, 42.70577900750296, 43.743853773389546, 44.212829385484966, 38.815614632197786, 43.149539606911794, 49.15640320096697, 51.19162436894008, 47.99557113647461, 46.825980867658345, 47.86114433833531, 49.90763201032366, 47.5202830859593, 44.37859255926949, 46.93093688147408, 47.684288365500315, 39.26894290106637, 29.436963966914586, 24.760312148502894, 12.947640640395027, 31.199027129581996, 45.83605711800711, 45.74830831800188, 46.37036664145333, 41.77435908998762, 37.86077928543091, 45.491586276463096, 49.231054646628245, 45.08885131563459, 46.62789467402867, 9.214096478053502, 0.20398254080542497, 6.647048464843205, 27.623075928006852, 21.545524835586548, 19.862850052969797, 29.67449508394514, 29.566718101501465, 30.76133578164237, 31.663559368678502, 28.689457654953003, 37.420346873147146, 30.590851306915283, 29.08623627253941, 30.461517538343156, 30.391858373369487, 37.102994850703645, 43.08710656847273, 49.26010506493704, 2.9547952754156928, 0.17669225590569632, 0.03569123714364, 0.11309818298156772, 0.08896331662046057, 0.09496073158723967, 0.07272644859871694, 0.16750350754175866, 0.03911085007712245, 0.10440051755202667, 0.07133369440478937, 0.06771617994776793, 0.04264396495584931, 0.05835458157317979, 0.038523812113063674, 0.044390283391944, 0.08487653412989207, 0.08164576427744967, 2.920941263437271, 73.07454504285539, 68.97023023877824, 43.12436975751604, 40.92885364804949, 36.84833642414638, 37.265770299094065, 37.219446659088135, 37.406033584049766, 36.02188294274466, 31.45663854054042, 33.66753796168736, 30.09068523134504, 17.804249933787755, 17.32896188327244, 16.327217510768346, 33.78239515849522, 5.401805341243744, 0.7945328056812286, 22.46831856455122, 38.15396547317505, 62.76229967389788, 62.30628245217459, 61.957746914454866, 46.368928364345, 35.75143126079014, 52.93067509787423, 38.461794989449636, 11.77825881753649, 0.6113613003066608, 8.112232037952968, 38.777333532060894, 48.80520650318691, 50.367001737867085, 49.875472273145405, 49.39240224020821, 52.99564075469971, 57.6813634463719, 55.38084963389805, 57.11638110024588, 54.333735261644634, 49.71935667310442, 48.29033803939819, 52.829286984034944, 52.72665861674717, 53.408499240875244, 54.31989445005144, 57.22520726067679, 51.34322016579764, 45.144985812050955, 51.51374980381557, 50.16133853367397, 48.89630086081368, 48.898774419512065, 45.17580107280186, 32.69068724768502, 13.13643969808306, 24.550789219992502, 9.702641691480364, 5.311595141887665, 13.819762894085475, 20.225895166397095, 19.087603058133805, 0.6102066508361271, 0.18489376295890125, 0.036954903442944796, 0.10765904627208199, 0.05902753903397492, 0.060044534105275355, 0.04482696817389556, 0.038059527919228585, 0.03718898445367813, 0.04386478516140154, 0.01643824703725321, 0.08158559857734612, 0.06551183680338518, 0.020150055809478675, 0.05955679634852069, 0.12379741136516843, 0.7313583727393831, 1.0205370783805847, 0.3288791924715042, 0.1087676707123007, 0.04732634512973683, 0.026136436100517, 0.13264252245426178, 0.03563829444880996, 0.042534890451601574, 0.04810447212574737, 0.03692906822210976, 0.027673421394346014, 0.12341152850006308, 0.08507382497191429, 1.4987051572118486, 22.409446477890015, 13.250410999570574, 6.993652837617057, 2.227562721286501, 4.603302725723811, 18.7068487235478, 25.65961922918047, 35.031583990369526, 38.691995756966726, 42.031918389456614, 42.49740253176008, 43.46476895468575, 43.5126941544669, 42.76639856610979, 44.12504584448678, 46.10042565209525, 45.838402135031565, 46.16204922539847, 46.86014863422939, 39.124382155282156, 44.94919947215489, 50.047044140951975, 51.503212860652376, 51.51216214043753, 49.490375314440044, 48.845189911978586, 52.50023072106497, 49.37428133828299, 47.09424039295742, 50.065272739955354, 49.43194791248867, 40.31456341062273, 28.75895353725978, 26.34017791066851, 19.10031305040632, 36.54344252177647, 49.47310904094151, 50.57298803329468, 52.4538653918675, 47.47630793707711, 39.08654226575579, 48.76690455845424, 57.11486291885376, 53.33950015476772, 46.07343537466866, 3.5020625378404344, 0.25145359709858894, 12.513624020985194, 30.102340834481375, 23.98071731839861, 23.110766376767838, 24.633933101381572, 28.991534062794276, 30.372410365513392, 31.38316134044102, 26.149086815970286, 25.192696809768677, 36.760803018297466, 21.75997403689793, 38.0284879548209, 31.14059625353132, 35.373140062604634, 48.364197390420095, 58.8980381829398, 3.614548010485513, 0.385451859661511, 0.030778898059257438, 0.12429207696446351, 0.06263068211930138, 0.1896293538489512, 0.03892736403005464, 0.2380995936691761, 0.20853905273335321, 0.39135161308305605, 0.11603003101689474, 0.24700099602341652, 0.0834618496841618, 0.12722281898771012, 0.3212384810405118, 0.194515430235437, 0.25156645104289055, 0.15513625687786511, 4.499760670321328, 87.05149963923863, 75.89762592315674, 62.542882510593955, 53.91551276615688, 64.9687557220459, 42.09690836497715, 45.53359161104475, 59.79471015930176, 49.63967820576259, 47.18114498683384, 44.58946691240583, 41.24370084490095, 18.241972548621042, 29.63360493523734, 26.121035201208933, 31.725898606436594, 6.646744915417262, 3.0742662932191576, 35.63991962160383, 43.35025221960885, 63.31435489654541, 63.4751501083374, 61.04492037636893, 44.45907701764788, 41.38503762653896, 57.175100326538086, 39.13126087188721, 8.050738743373326, 0.6177851813180106, 12.859250000544957, 46.815294538225444, 51.607960428510395, 52.42571129117693, 50.5875757762364, 50.41037934167044, 52.00050933020455, 60.3711952481951, 57.889705181121826, 61.15602902003697, 56.99557277134487, 52.49752787181309, 52.50208936418806, 55.898295879364014, 54.15368659155709, 56.45275170462472, 56.59402247837612, 61.0445590700422, 55.012744494846885, 48.54470464161464, 53.935582637786865, 55.769257409232004, 50.93796648297991, 55.74160705293928, 49.57127666473389, 45.90710939679827, 26.066847937447683, 36.92991522380284, 21.171275751931326, 8.223028012684413, 14.774305547986712, 31.00121191569737, 25.925631012235367, 1.0621053278446198, 0.18062792186226162, 0.16813012106078012, 0.14113474105085644, 0.2526810940887247, 0.13660110932375702, 0.1710164597524064, 0.13092337256031378, 0.078879811268832, 0.13168747084481375, 0.17320493874805315, 0.10637883389634745, 0.15878693812659808, 0.11009694795523371, 0.13122983968683652, 0.24895248987845012, 0.7266655159848077, 2.488260869468961, 1.4644408758197511, 0.18446632660925388, 0.17483946175447532, 0.2613913124161107, 0.39285174544368473, 0.1663884845163141, 0.13724977523088455, 0.11487740358071667, 0.11067523621022701, 0.15934757090040616, 0.15027463489345141, 0.6095890754035541, 3.522573402949742, 31.859481198447092, 21.358580078397477, 9.760303923061915, 4.165958787713732, 13.120451893125262, 28.552237680980138, 34.467702933720176, 42.98628125871931, 43.71785361426217, 44.777909006391255, 46.180628708430696, 45.16805730547224, 43.72887345722744, 44.45277500152588, 48.0479952948434, 49.05675561087472, 46.24541023799351, 48.44442129135132, 49.545085430145264, 42.212974548339844, 47.30873128346035, 53.71508502960205, 56.09997776576451, 53.510380676814485, 49.971451214381624, 50.507282393319265, 54.121217659541536, 51.87821756090437, 49.54765626362392, 54.47932086672102, 54.00002023151943, 47.03170313153948, 36.50152056557791, 30.000747748783656, 19.2197300025395, 36.77670397077288, 52.29383100782122, 52.737800053187776, 55.106347152165, 48.21103477478027, 41.668451172964915, 53.33725936072213, 57.686050006321494, 52.12716109412057, 56.1913674218314, 12.364471384457179, 0.31676571390458513, 9.259714007377625, 35.08078071049282, 27.497857230050222, 29.16123512813023, 36.92939758300781, 40.81986767905099, 38.94130407060896, 42.38544273376465, 37.03752892357962, 50.4171781539917, 41.7948180607387, 39.412767137799946, 42.457832540784565, 40.37796572276524, 49.4432178906032, 56.6129424231393, 71.3253152029855, 6.342406868934631, 0.6507336476019451, 0.10824859142303467, 0.33256789882268223, 0.14914186139191898, 0.2526208944618702, 0.1602047234773636], [0.05463328179238098, 0.05945288549576487, 0.023825953115842173, 0.02756633160502783, 0.04525394651240536, 0.02892588677683047, 0.04727303941867181, 0.08409680239856243, 0.06056633431996618, 0.03162275813519955, 0.06630262187016861, 0.0910117392029081, 25.451036044529506, 66.3105640411377, 46.59265341077532, 39.54510947636196, 45.19547142301287, 46.39831577028547, 38.884026595524375, 37.24910504477364, 30.272898265293666, 41.47858122416905, 29.736959389277867, 29.88971206120082, 19.538845130375453, 8.702267851148333, 16.033138479505265, 26.48692560195923, 17.81955507823399, 0.12105435212807995, 16.892137323107036, 48.483984334128245, 53.394564628601074, 63.2254318509783, 57.86480631147112, 32.26712506158011, 51.776589734213694, 52.35905722209385, 46.739618233272004, 29.883753980909074, 13.0754987852914, 3.630177331822259, 12.863134043557302, 40.18090786252703, 43.25999511991228, 45.6001866204398, 46.6825179372515, 51.27726091657366, 56.44171101706368, 56.232789107731406, 56.7600496837071, 51.80840900966099, 48.43317910603115, 51.56953689030239, 55.23244653429304, 54.49403715133667, 54.529983656747, 54.60332189287458, 51.2497147832598, 49.42052159990583, 47.185400758470806, 50.560853004455566, 44.73538255691528, 52.118628706250874, 37.47657169614519, 38.556978361947195, 7.018354117870331, 1.908582431929452, 6.9656568084444315, 3.3553919281278337, 4.595540719372885, 13.809096540723528, 7.533195223127093, 11.220812661307198, 0.42919777227299555, 0.08030368307871477, 0.05384409806824156, 0.07073071426046745, 0.06798647437244654, 0.03952828821327005, 0.020103384474558488, 0.11235321938459363, 0.03492678602093032, 0.019413343198331337, 0.07946990603314978, 0.12631503412766115, 0.007413073110261134, 0.013596509300571467, 0.030348693286733966, 0.3098456880875996, 0.5874832730208124, 0.6083855171288762, 0.13191927197788442, 0.08571193965950183, 0.07546984710331474, 0.05308722957436528, 0.05324289907834359, 0.042609027187739096, 0.016841761634818146, 0.014809318552059787, 0.024997545605791465, 0.05763032007962465, 0.06005579100123473, 0.07365245890936681, 1.2655059163059508, 13.36666999544416, 7.667098300797599, 6.572417863777705, 3.6022143065929413, 2.5922067889145444, 1.3180654559816634, 10.323699474334717, 33.47370753969465, 32.436549936022075, 40.58123527254377, 40.415221963609966, 42.5181359563555, 43.32119137900216, 44.318250928606304, 40.59715706961495, 42.92028032030378, 44.206774030412944, 45.338948249816895, 41.792413984026226, 40.75603805269514, 43.77429035731724, 46.84846176419939, 46.62457690920149, 49.20077439716884, 45.837286949157715, 48.425355434417725, 50.45982619694301, 45.639978953770225, 39.40260887145996, 41.73456675665719, 37.338795866285054, 27.726770843778336, 14.654872962406703, 20.667347226824077, 31.213771206992014, 40.873479979378835, 55.3332371030535, 41.57839904512678, 44.44487489972796, 44.45096846989223, 61.69247164045061, 48.51111010142735, 39.665295941489084, 44.46631704057966, 12.80880868434906, 0.25071410249386517, 11.219130328723363, 38.02093178885323, 36.36024284362793, 17.550743171146937, 22.09688002722604, 34.47189964566912, 27.848025594438823, 30.603802749088832, 28.85486994470869, 38.942148276737754, 43.00366565159389, 23.536829914365494, 34.26253999982561, 25.451181956699916, 19.945321696145193, 34.524212632860454, 53.59432186399187, 37.61028977802822, 0.5503146446176937, 0.03886340192652174, 0.04350238300061651, 0.06257536794458117, 0.013415180994862956, 0.029575261753052473, 0.080121035022395, 0.04132836019354207, 0.07239840405860118, 0.06367669813334942, 0.04078602411651185, 0.025043105839618614, 0.023229254509455392, 0.04212488905925836, 0.06260992573308093, 0.05851831207317965, 0.056327733011650186, 0.1186436257724251, 0.05387240315654448, 32.29815919058663, 78.95490278516496, 46.62780087334769, 49.26422882080078, 38.30946268354143, 37.55484315327236, 43.804685252053396, 25.670731135777064, 33.06367349624634, 40.24081175667899, 27.519745792661393, 32.61697728293282, 24.996754135404313, 15.055744068963186, 10.436957716941833, 29.946131433759415, 27.46680573054722, 0.10915114477808986, 11.008693712098257, 50.26216731752668, 56.64118685041155, 59.9314854485648, 56.2105062348502, 29.68290935243879, 57.27828107561384, 53.381477696555, 50.76853813443865, 34.749775477818076, 19.573659079415457, 6.4526760833604, 13.566664338111877, 41.99782010487148, 42.01885577610561, 46.4894448689052, 49.17421490805489, 53.2207658631461, 56.29440573283604, 57.11520338058472, 57.154794216156006, 54.03388575145176, 49.97273315702166, 52.95488609586443, 55.59880072729928, 56.461530753544395, 55.094073159354075, 54.404943874904085, 51.45262997491019, 49.54873670850481, 48.984841755458284, 53.461399350847515, 46.556863239833284, 55.88818277631487, 40.07556274959019, 43.86612817219326, 6.370339061532702, 4.0604243363652905, 9.80648078237261, 8.63335474899837, 9.485327226775032, 17.71227662903922, 13.69795228753771, 11.518894723483495, 1.0906573214701243, 0.03609505708196333, 0.04149825179151126, 0.09981586677687508, 0.033254237912063084, 0.050981735411499224, 0.0443542362190783, 0.15171103924512863, 0.028934999502130916, 0.022517925893355693, 0.02874332693006311, 0.11707436426409654, 0.11196732294878789, 0.05614211975729891, 0.04916305121566568, 0.19606979111475603, 1.1278846838644572, 1.2002766621964318, 0.22518316390258925, 0.09557099919766188, 0.03851798349725349, 0.024134711994390403, 0.012871151972961212, 0.02077545135814164, 0.022394220477768352, 0.06108452472835779, 0.07966278639755078, 0.02047540826190795, 0.10726884113890783, 0.03596818121150136, 0.7379126410399164, 8.795733281544276, 13.101991397993904, 12.317949720791407, 8.562218223299299, 5.038728960922786, 2.922717179570879, 9.481464896883283, 38.47422879082816, 36.9916603905814, 43.86020483289446, 42.490124293736045, 44.87005949020386, 43.72203295571463, 46.59289312362671, 44.22377627236502, 43.888893944876536, 45.543253081185476, 46.413452420915874, 42.77144643238613, 41.77164929253714, 44.60538870947701, 48.69239207676479, 47.20989663260323, 51.36369998114449, 47.50446898596627, 50.188457352774485, 52.150229113442556, 49.620487281254356, 42.5327410697937, 43.71678359167916, 36.616131101335796, 25.288225855146134, 16.167091063090734, 25.36907856804984, 36.97572122301374, 45.55735445022583, 60.46249457768032, 43.81452737535749, 47.10495104108538, 46.77552652359009, 59.2736508505685, 46.595085280282156, 48.76815176010132, 46.05279575075422, 7.140976360866001, 0.1321391308946269, 23.24250943320138, 41.72524227414812, 36.31231416974749, 23.38276055880955, 22.58797870363508, 30.995045389447892, 24.028906549726212, 29.546780245644705, 26.187944616590226, 23.067506892340525, 39.874426296779085, 26.297495126724243, 25.1168954372406, 32.92902088165283, 18.123399802616664, 37.480330671582905, 59.90507534572056, 43.929075377328054, 0.6384867961917604, 0.10887795979423182, 0.00831296491170568, 0.04831575435985412, 0.02967172907665372, 0.06438814888575248, 0.05426407053268381, 0.17700058221817017, 0.14561427996626922, 0.12207702653748648, 0.14658542642635958, 0.1884676476142236, 0.14369121672851698, 0.09722667892596551, 0.1655459204422576, 0.2958306829844202, 0.14906606903033598, 0.3104548496859414, 0.17554068698414735, 45.999503067561555, 89.08271517072404, 61.371444020952495, 56.885548046657014, 57.01654590879168, 60.51632227216448, 46.24007054737636, 48.97518375941685, 37.596000807625906, 55.62916782924107, 37.96507522038051, 38.66397367204939, 25.436180795942033, 14.083056194441658, 24.630855049405778, 33.59915031705584, 24.18749918256487, 0.09487487655133009, 20.76794672012329, 58.13002599988665, 60.04918793269566, 66.56509045192173, 63.19271278381348, 36.17761639186314, 60.47934395926339, 62.29494299207415, 56.90847362790789, 38.26378870010376, 17.17659831047058, 5.74971032994134, 17.249170507703507, 47.39794267926897, 45.09321131025042, 48.98722498757498, 48.48044075284685, 56.043311732155935, 59.011724608285085, 59.10473319462368, 62.16990321023123, 54.9770759173802, 52.07931579862322, 56.65152924401419, 58.328272002083914, 60.08508927481515, 56.46522372109549, 58.42777715410505, 52.59709555762154, 53.82349082401821, 51.40114034925188, 57.79175989968436, 47.76672179358346, 57.53978000368391, 44.67384583609444, 54.16418531962803, 16.0221585886819, 9.99100409235273, 17.730995076043264, 7.287433096340724, 9.712301424571447, 21.223034620285034, 20.49920950617109, 19.948377166475566, 1.5747714298112052, 0.11926249042153358, 0.18795972344066414, 0.2348908015659877, 0.13120633523379052, 0.17879305460623332, 0.12678048200905323, 0.36290718082870754, 0.13703833014837333, 0.10659337988389389, 0.16354117515896047, 0.1817749717405864, 0.1620166426790612, 0.1042415639385581, 0.11603619211486407, 0.5515309050679207, 2.2801849033151353, 1.7478107788733073, 0.42433514605675426, 0.15661717312676565, 0.17690625227987766, 0.20884503131466253, 0.16002977000815527, 0.14454199107629911, 0.14717082572834833, 0.15663861483335495, 0.1372961870261601, 0.11954918503761292, 0.13784958661666938, 0.17825522060905183, 2.63634717464447, 20.790863616125925, 19.41464955466134, 13.709225739751544, 9.439119100570679, 5.892137110233307, 7.325279934065683, 19.554553270339966, 47.712268761226106, 40.34715741021292, 47.21341936928885, 46.04360328401838, 48.45049401691982, 46.09295981270926, 48.80473402568272, 44.6510522706168, 46.138550417763845, 47.66611187798636, 48.94752992902483, 46.20792818069458, 44.848464488983154, 47.29921225139073, 51.23978580747332, 47.38712433406285, 52.83968843732561, 47.88800259998867, 51.745795318058555, 54.39312498910086, 53.00357559749058, 46.376984800611226, 49.56781298773629, 43.046063559395925, 32.379196030753, 20.939060006822857, 27.867397172110422, 39.266455445970806, 49.111774921417236, 62.90152072906494, 49.04697254725865, 51.61649281638009, 52.40655858176095, 64.45511014120919, 52.46565301077706, 47.92182295663016, 54.16870859691075, 17.379508290972026, 0.2588871925004891, 16.498389857155935, 43.16423852103097, 44.042824336460654, 23.032687732151576, 29.358199187687465, 45.457397665296284, 35.78757231576102, 39.58265059334891, 36.69365562711443, 51.52358497892107, 55.363454818725586, 29.386183057512554, 44.74715280532837, 33.14890357426235, 28.54128905705043, 47.97356619153704, 67.01561859675816, 57.669905866895405, 1.0356742718390055, 0.3957998443927084, 0.1382004570748125, 0.1869058364203998, 0.1771081978721278, 0.07545331799026046, 0.185883989823716], [0.04931722454992788, 0.04165545478463173, 0.027361895789259245, 0.04619900330102869, 0.10008243604430131, 0.0295943251944014, 0.02511887445247599, 0.017976021128041402, 0.09659000273261752, 0.03296041528561285, 0.15548499673604965, 0.1384660763932126, 12.154848575592041, 72.27137497493199, 44.443106583186555, 31.216522693634033, 36.55844368253435, 49.37589679445539, 38.32231685093471, 44.59787423270089, 34.519300256456646, 28.451768466404506, 36.87799480983189, 25.39696342604501, 28.010406732559204, 9.556982261793953, 20.765867471694946, 23.771428891590663, 36.9477790423802, 2.0407263125692094, 1.0291065956865038, 32.17903232574463, 58.855939047677175, 47.77853373118809, 61.505808285304475, 43.01352514539446, 34.64720617021833, 49.75069304874965, 46.580368995666504, 53.563110555921284, 47.25317696162632, 27.88488405091422, 8.011738504682269, 30.668306350708008, 29.66033465521676, 30.616733346666607, 37.18694298607962, 50.55751786913191, 55.68743889672415, 59.363185337611604, 54.04425246374947, 58.0087799344744, 52.600965704236714, 53.17599514552525, 50.88922834396362, 54.90650306429182, 52.132709230695454, 53.85027960368565, 54.579277651650564, 49.748292446136475, 46.0827112197876, 49.448255334581646, 53.20690073285784, 41.64322921207973, 40.6457701410566, 16.958431822913035, 0.6758359149098396, 3.3601499242441992, 9.957264508519854, 8.092039704322815, 11.986836791038513, 9.95092167173113, 6.674870789051056, 4.666849212987082, 0.7879557386040688, 0.015460598515346646, 0.026709516599242176, 0.013721929713418441, 0.048941136337816715, 0.013880918949975498, 0.0326715256087482, 0.024353341066411564, 0.10166026744991541, 0.03240834901641522, 0.05302696887935911, 0.04124725490276303, 0.12306238152086735, 0.04842339376253741, 0.04089815881369369, 0.08379402650254113, 0.7588690051010677, 0.29409284623605864, 0.20968414843082428, 0.026461439107411673, 0.07659132299678666, 0.05657229060307145, 0.0768217331330691, 0.05425548706469791, 0.07395691757223435, 0.06078718389783587, 0.028699456248432398, 0.032592500027801306, 0.048851674888283014, 0.11597998227391924, 0.6711761706641742, 4.375692767756326, 7.249223215239389, 9.007295506341116, 9.7805483681815, 3.8728498986789157, 3.5491728442055837, 1.6062894357102258, 17.769526311329432, 43.408175877162385, 38.15451785496303, 41.761018548692974, 43.52311645235334, 42.42393227985927, 45.0220548084804, 43.20196723937988, 46.30736037663051, 44.59816953114101, 43.223555292402, 40.82295615332467, 42.05272477013724, 42.53849070412772, 48.76141200746809, 48.72799117224557, 52.24209819521223, 45.06711735044207, 47.25897870744978, 45.7933326448713, 42.54065159388951, 32.2909573827471, 32.02223580224173, 19.405985151018413, 15.722164903368268, 15.08712387084961, 32.37417595727103, 40.770535469055176, 40.09808186122349, 42.401628562382285, 46.424284662519185, 45.59932156971523, 49.905304363795686, 35.343245438167024, 44.17535775048392, 28.852182728903635, 6.4149326000894815, 0.1351772714406252, 12.370505026408605, 47.65994882583618, 32.8255934715271, 24.962628058024816, 11.111408063343593, 28.751895904541016, 25.448583330426896, 31.31644126347133, 28.743439946855815, 33.79539523805891, 35.098314489637104, 21.486975840159825, 21.738658700670513, 33.055540629795615, 31.691921915326798, 34.09785727092198, 40.03403684071132, 57.87763268607003, 18.724677801132202, 0.06513372316424336, 0.05558708489739469, 0.1495771144649812, 0.07026333933962242, 0.10922459619385855, 0.023510626018313423, 0.023845279489510825, 0.03747386398858257, 0.04930422042629548, 0.02151436751176204, 0.044123612344264984, 0.08298496848770551, 0.006745753003217812, 0.03189327986910939, 0.05259097281045147, 0.1542372658316578, 0.13572168722748756, 0.11031276958861522, 0.1617634812636035, 17.176247426441737, 81.75119141169957, 52.54843037469046, 35.680073261260986, 43.714414255959646, 31.42767150061471, 48.037816183907644, 35.21379702431815, 28.505247013909475, 33.72194235665457, 34.056386947631836, 30.981461661202566, 34.28750835146223, 17.261208261762345, 23.077719007219585, 18.884317874908447, 44.465573583330425, 6.053694886820657, 0.9725302372659955, 29.336433955601283, 65.31344890594482, 54.69626447132656, 61.63147340502058, 42.6127530506679, 42.05558395385742, 59.403797558375764, 52.29342106410435, 55.69349077769688, 50.57522882734026, 37.56181567055838, 11.219526376043047, 28.82335638999939, 28.716333287102835, 28.606207813535416, 37.05116128921509, 50.54310383115496, 55.268955843789236, 60.167453220912385, 56.0939884185791, 61.07212257385254, 51.408345631190706, 53.41627427509853, 54.86262171609061, 54.58891132899693, 52.58902175085885, 55.47474064145769, 57.86388220105852, 49.9757729939052, 49.28443418230329, 52.13624586377825, 55.181297370365684, 43.87848206928798, 45.60363987513951, 15.196198429380145, 1.8119773928608214, 12.220164247921534, 14.02542175565447, 13.341654743467059, 18.180944783346995, 13.55038731438773, 13.375819035938807, 5.9049526282719205, 1.0022652702672141, 0.0321763205741133, 0.017654614356745566, 0.04094934749550053, 0.010161078867635556, 0.035378788730927875, 0.07197438752544777, 0.06589614546724729, 0.08054718215550695, 0.03387022896536759, 0.03359021791922195, 0.04790461302867957, 0.011480059341660567, 0.0336488772715841, 0.039433829353324006, 0.2956265796508108, 1.7100672956023897, 0.029248971225959913, 0.08331943875444786, 0.0019392793765291572, 0.10724784048008067, 0.0773995260574988, 0.013402059823939843, 0.06956868232893092, 0.05992463696748018, 0.08202806447765656, 0.03695067956245371, 0.024098096548446586, 0.028767462420676435, 0.23318336318646157, 0.695692563695567, 3.765858062676021, 9.646284852709089, 18.57994508743286, 19.18482746396746, 9.80952148778098, 12.163327114922659, 5.3081405844007215, 16.032054560525076, 46.39262866973877, 42.87974452972412, 40.88474300929478, 45.39309556143624, 45.19887951442173, 45.55546801430838, 47.15241071156093, 48.14212254115513, 45.020164898463655, 44.8790956224714, 41.712843213762554, 43.007296085357666, 44.99280636651175, 50.680931772504536, 50.000831672123496, 55.56528261729649, 46.56823744092669, 46.387275082724436, 46.909519059317454, 44.306289604731965, 32.3973343031747, 30.670137201036724, 17.039044822965348, 16.56104871204921, 22.152528149741038, 36.71956198556082, 42.786381585257395, 41.57487630844116, 48.26500490733555, 51.796416418892996, 50.825318813323975, 56.41590888159615, 38.858780315944124, 49.36506455285208, 29.545352390834264, 1.3565982111862727, 0.4545486548117229, 21.516213859830582, 54.64581707545689, 30.79392283303397, 27.658212968281337, 16.224309478487285, 26.262014150619507, 26.108257464000157, 29.26116759436471, 23.73312520980835, 26.503368513924734, 26.316302163260325, 27.80826105390276, 17.603700603757584, 29.460160527910503, 33.07781655447823, 27.144452742167882, 43.88634395599365, 67.1485515322004, 22.919465099062236, 0.12807094704891953, 0.10526516794094018, 0.13512164513979638, 0.046773389979664765, 0.09111554827541113, 0.07514494418033532, 0.05637522367760539, 0.2798341656369822, 0.1943416574171611, 0.12952667607792787, 0.11187255874808345, 0.20230748211698873, 0.21948876231908798, 0.12034734578004905, 0.16891598674867833, 0.3522602878510952, 0.26431758967893465, 0.3393693710012095, 0.46269286636795315, 24.41850072996957, 95.81456770215715, 61.94161319732666, 46.01056112561907, 48.28536312920706, 63.01779883248465, 45.99183920451573, 60.27815886906215, 43.86003112792969, 36.16222960608346, 48.77153900691441, 38.418257577078684, 36.97531475339617, 12.803540212767464, 32.03468002591814, 32.234211444854736, 47.949372564043315, 5.011661384786878, 3.01101684144565, 40.390646185193745, 69.49586146218437, 56.30087103162493, 70.65477929796491, 50.966269969940186, 46.416617325374055, 60.40229538508824, 57.60643754686628, 62.888944489615305, 55.71719108309065, 34.325560161045615, 11.504062056541443, 34.657180309295654, 33.481204645974294, 36.25797230856759, 39.4711354800633, 52.42879629135132, 58.703634534563335, 62.82543795449393, 59.01649802071707, 62.59348624093192, 56.059605257851736, 56.5679806300572, 56.02799442836216, 58.034231185913086, 54.31958178111485, 58.70048700060163, 60.93736226218087, 53.366823945726665, 50.861720425742014, 52.83321966443743, 58.126131534576416, 47.63716220855713, 53.53295884813581, 26.782957077026367, 2.2268205668245042, 13.390612619263784, 16.20210998398917, 14.38216051033565, 17.69732063157218, 19.66130886759077, 14.684783220291138, 9.283918925694056, 2.761666404349463, 0.14580675320965902, 0.14921185906444276, 0.12615684047341347, 0.10099621236856494, 0.14915407502225467, 0.1427710418190275, 0.2252630546156849, 0.2730704742882933, 0.1372347388948713, 0.10562208414609943, 0.0991872176527977, 0.2190033383667469, 0.18469280802777835, 0.09450551601392881, 0.45681409324918476, 1.8763273741517748, 0.533529479588781, 0.3854728942470891, 0.17805981609438146, 0.16736197870756897, 0.1750308493418353, 0.2637948734419686, 0.3507673479616642, 0.13442071846553258, 0.21248568381581986, 0.13152110762894154, 0.10405138414353132, 0.1017031983605453, 0.34616660912122044, 2.5021874478885104, 10.973956193242755, 13.607854996408735, 17.89428469112941, 18.517201117106847, 11.13531334059579, 10.122860057013375, 6.323794381959098, 25.974218027932302, 51.84005805424282, 44.96366909572056, 44.04595102582659, 48.785532678876606, 45.541123458317344, 48.42442090170724, 48.18079621451241, 50.880689007895334, 46.3311197417123, 47.41823141915457, 45.137784004211426, 46.423940726688926, 45.53686768668038, 53.56111642292568, 53.52769558770316, 59.26702226911272, 48.011208057403564, 49.56866414206368, 47.89697619846889, 50.39370019095284, 38.140232358660015, 40.220787048339844, 22.442189863749913, 21.82862745012556, 21.591004269463674, 36.34255273001534, 44.14999335152762, 49.32791600908552, 51.838143825531006, 54.37058155877249, 53.19952869415283, 58.269611835479736, 42.619749886649, 52.85383496965681, 37.37296710695539, 9.582977209772382, 0.3213665070278304, 17.410259280885967, 55.094510895865305, 40.4105840410505, 33.13785246440342, 14.34539064339229, 35.5554712159293, 35.306030886513845, 42.11856937408447, 37.88029677527291, 45.46561738422939, 46.43129539489746, 30.07758092880249, 29.80868911743164, 44.95015137536185, 43.0171868460519, 49.549605233328684, 52.68960387366158, 73.06786782400948, 34.65198653084891, 0.32287410327366417, 0.20690668746829033, 0.22856340823428972, 0.20707816683820315, 0.2224128818405526, 0.19430688928280557, 0.20370278081723622], [0.03269599697419575, 0.05801411305687257, 0.01924331589335842, 0.0573863595990198, 0.02671497710980475, 0.02140375442935952, 0.04091809417254158, 0.11469312704035214, 0.04916873394644686, 0.0803653211998088, 0.06107455026358366, 0.08421302187655653, 4.099237407956805, 64.41633919307164, 51.102454662323, 49.98871748788016, 25.602004766464233, 50.00292655399868, 28.36894072805132, 26.017371552331106, 51.61576325552804, 34.1018385887146, 36.576425620487754, 22.462931973593577, 31.607873031071254, 12.897306152752467, 13.499087027141027, 38.24735621043614, 42.46611131940569, 31.32427535738264, 0.5719642543366977, 3.4938966674464087, 23.333343233380997, 54.468735286167686, 49.524428435734336, 58.56997203826904, 45.15954228809902, 45.49778406960623, 47.19651787621634, 49.10423265184675, 49.10431950432913, 35.48237269265311, 24.302974769047328, 17.248802253178187, 8.34181181022099, 10.288835150854927, 24.06051390511649, 50.142279624938965, 55.81175259181431, 57.95340973990304, 55.65969473975045, 57.45959779194423, 53.63591725485665, 55.683144909994944, 56.89672769818987, 58.50162260872977, 53.87497002737862, 55.488633564540315, 47.07441023417881, 52.28766448157174, 51.3848294530596, 50.391886711120605, 47.845243385859895, 44.32361146381923, 22.042494739804948, 1.9150405653885432, 12.597002404076711, 16.640011514936173, 7.470513786588397, 17.68829492160252, 21.46794819831848, 9.188267418316432, 8.087280188288007, 4.128372941698347, 0.5486278065613338, 0.146912439593247, 0.08324383638267006, 0.06197247600981167, 0.030921230957444226, 0.07786692811974458, 0.057451213976102214, 0.07306417583354882, 0.017102366579430442, 0.023763022385537624, 0.08977399633399077, 0.013832132282134677, 0.09980802969740969, 0.06304245788071837, 0.05194864781307323, 0.07541076027389083, 0.8953034526535443, 0.0066042241690281245, 0.0688424530838217, 0.005876259570608714, 0.11237539390900306, 0.042208277620375156, 0.046719571974660666, 0.06769995617547206, 0.017962903349793384, 0.07485531829297543, 0.10646046844444104, 0.11034854195479836, 0.07781356134052787, 0.10291744356176682, 0.23840338736772537, 3.6054519500051225, 8.779768926756722, 10.517253705433436, 22.528382267270768, 12.926485112735204, 2.8862497763974324, 15.266541991915021, 5.883470969540732, 21.917454957962036, 48.11387463978359, 41.26566757474627, 42.230727195739746, 43.82834039415632, 48.159524304526194, 47.01765387398856, 46.09584331512451, 47.03260292325701, 44.7399822643825, 41.88802467073713, 42.532522201538086, 43.706583636147634, 49.11133371080671, 46.1390437398638, 48.956451416015625, 43.498954091753276, 45.898194858006065, 37.120076996939524, 25.0378475189209, 17.02065988949367, 11.54817008972168, 11.277428320475988, 15.85685052190508, 26.836491210120066, 45.20126274653843, 51.862299237932476, 47.10498578207833, 44.57455260413033, 45.12592690331595, 41.91106142316546, 48.71965333393642, 52.89216123308454, 41.24860627310616, 14.812505006790161, 0.887874037027359, 2.923197690929685, 52.0653464453561, 38.54483985900879, 41.316542284829275, 14.146983964102608, 18.753589255469187, 30.668671131134033, 27.572470460619243, 25.37891548020499, 29.35431167057582, 22.053924526487076, 23.46764496394566, 21.242211648396083, 32.81569576263428, 33.53820071901594, 26.531767538615636, 30.34691742488316, 47.13793761389596, 54.57007128851754, 3.333588480949402, 0.30374875238963533, 0.09389720258436032, 0.052467252127826214, 0.0058532890398055315, 0.06304343497114522, 0.07730757777712174, 0.07035988130207572, 0.04742798628285527, 0.04506996852744903, 0.12827954228435243, 0.02978546850915466, 0.019026462886748568, 0.09651884476521186, 0.038397913333028555, 0.11354972768042769, 0.06225300274257149, 0.013052352205184954, 0.03306711491729532, 0.15900192516190664, 5.9572078585624695, 73.71386269160679, 60.522930009024485, 43.529585225241526, 33.86871262959072, 37.05834225245884, 28.230207783835276, 36.66391038894653, 33.92404808316912, 35.276018142700195, 35.03518315723964, 27.455183131354197, 33.57470308031355, 20.74466504369463, 24.72299337387085, 37.24845538820539, 43.04535484313965, 40.72974606922695, 1.218979801450457, 1.5642760672739573, 16.720275368009293, 53.74178000858852, 57.376094341278076, 59.80388872964041, 49.794220038822715, 50.332323278699604, 53.684509481702534, 50.62975828988211, 54.9080490384783, 37.31011022840227, 28.957955156053814, 19.863504920686992, 7.527637532779148, 8.432350311960493, 23.44789297240121, 49.33898101534162, 54.744346005576, 58.56580311911446, 56.22038309914725, 57.49489116668701, 53.76256207057408, 55.732727255140034, 56.16922698702131, 58.835685048784526, 58.135160718645366, 55.11682850973946, 49.162211894989014, 54.02814653941563, 51.93976122992379, 51.17135647365025, 46.462332998003276, 47.98041711534773, 18.62789981705802, 5.626329430512019, 17.277986424309866, 19.023024763379777, 13.012130345617022, 21.963116782052175, 24.79213489804949, 11.578177622386388, 13.227241362844195, 6.190894016197749, 0.5397115307194846, 0.14351676537522248, 0.048130633043391366, 0.09612891104604517, 0.014202868549286254, 0.05086620125387396, 0.08199628189738307, 0.07322527361767632, 0.03265131883589285, 0.01782299791063581, 0.06715796954397645, 0.05906926215227161, 0.016791648431015865, 0.07498725264200143, 0.46431934194905417, 0.11641295546931879, 0.6856748898114476, 0.046886291421417675, 0.052628268487751484, 0.0377685449618314, 0.06418241028274808, 0.05290181988051959, 0.08836317953786679, 0.02909507948373045, 0.05190336577860372, 0.10110355660851512, 0.07981358402009521, 0.13131876848638058, 0.050898753971393616, 0.1125947574951819, 0.3664016904575484, 2.0655016345637183, 12.942327874047415, 16.510050671441213, 29.391421999250138, 21.126253162111553, 9.142589960779462, 27.74415349960327, 10.978733079774038, 17.66678156171526, 47.610130241939, 45.68558692932129, 44.25677326747349, 44.143111160823274, 51.928182056971956, 47.7943617275783, 45.79549700873238, 47.783751828329905, 47.866449287959504, 42.31506790433611, 43.95256723676409, 46.23732253483364, 52.018015316554475, 47.17345680509295, 50.85885776792254, 43.86404023851667, 46.23041949953352, 36.87854719161987, 23.49706016268049, 15.56626296043396, 9.966746194022042, 12.130506430353437, 20.434721537998744, 33.42888123648507, 49.07561649594988, 53.60869073867798, 49.24633720942906, 45.70566374914986, 48.036409173692974, 44.821700028010774, 49.97356694085257, 56.37431696483067, 40.28388711384365, 5.944439675126757, 0.9898560047149658, 7.891856023243495, 61.3295533316476, 49.41583851405552, 45.74202367237636, 16.623726674488612, 22.752437353134155, 26.719632932118007, 28.21232659476144, 22.904104369027273, 24.3114515713283, 22.081962244851248, 21.28680518695286, 29.13701023374285, 23.95713860648019, 42.100768089294434, 22.48500292641776, 27.67957694189889, 51.86943851198469, 64.45720849718366, 4.723070127623422, 0.46458934460367474, 0.0221239786395537, 0.06970148520278079, 0.025643673791949238, 0.09012703131884336, 0.08684303717953817, 0.06774518731981516, 0.19028445226805552, 0.15210486096995218, 0.18314673884638719, 0.10779185593128204, 0.15518663131764956, 0.11100478709808417, 0.1279863744441952, 0.21466646822435514, 0.2490942222731454, 0.13424379724477017, 0.10014000974063363, 0.39478348035897526, 8.075409190995352, 92.02844565255302, 65.59360027313232, 64.31320013318742, 36.84787436894008, 65.94929940359933, 35.728623798915315, 35.21249771118164, 72.05013738359723, 41.75010987690517, 49.986202239990234, 31.13198743547712, 46.127857140132356, 16.178576435361588, 20.736959491457256, 44.817009993961875, 55.852163314819336, 38.90781722749983, 0.9655383953026363, 5.325312188693455, 30.554397583007812, 63.729322160993306, 60.3633576801845, 67.24333190917969, 56.48460224696568, 54.604009764535085, 58.25786937986101, 57.54425116947719, 58.525767598833355, 41.12311833245413, 30.132968493870326, 19.856615781784058, 10.992952568190438, 12.951703599521093, 28.166584866387502, 52.0221460206168, 58.0270675931658, 62.471065929957796, 59.10449695587158, 61.50603757585798, 56.7834164755685, 57.95058529717581, 59.12376431056431, 61.39393533979143, 59.1782659803118, 58.39051396506173, 52.83921248572213, 56.68712139129639, 55.61405897140503, 54.85219941820417, 52.017817292894634, 53.87696763447353, 31.024259090423584, 6.8225352082933695, 20.519986357007706, 24.55404966218131, 14.286007864134652, 21.875008412769862, 30.177930286952428, 17.049600873674663, 15.260981695992605, 9.58549245766231, 0.7039236820169857, 0.19365761269416126, 0.16365259060902254, 0.11798066991780486, 0.06008000113070011, 0.14695096681160585, 0.1485905788306679, 0.15885186035718235, 0.11464182979294232, 0.17764178424009255, 0.21262079370873316, 0.1776122815374817, 0.20394698557044777, 0.13710002255226883, 0.2638742891805512, 0.26284780140433994, 2.33081316947937, 0.15369134369705403, 0.25492131816489355, 0.10171270463615656, 0.2523212262562343, 0.1297473899487938, 0.15306063182651997, 0.09867545297103268, 0.1559067741036415, 0.20991630240210465, 0.2274254642959152, 0.22204933634826116, 0.23677536472678185, 0.11997081312750067, 0.7821803199393409, 6.4567190664155145, 17.97064539364406, 18.03947946003505, 28.03079969542367, 22.6833462033953, 7.632252216339111, 25.506303753171647, 12.183783480099269, 26.970235347747803, 52.895993164607454, 46.98466730117798, 47.24454035077776, 47.147164821624756, 52.50241245542254, 50.19265406472342, 48.48176438467843, 51.44484451838902, 48.84882034574236, 44.14432709557669, 43.96404218673706, 48.5555750983102, 54.85835204805647, 48.247669151851106, 52.955824102674214, 44.98719917024885, 47.54276745659964, 43.90199824741909, 27.89044608388628, 21.331751346588135, 14.907505989074707, 15.086312668664114, 19.433830056871685, 32.44832018443516, 53.6934483391898, 57.654032707214355, 53.35929209845406, 51.037495953696116, 53.76417057854788, 52.32801961898804, 53.979307651519775, 59.36452633993966, 49.48509120941162, 18.721603223255702, 2.7837681898048947, 4.58568947655814, 64.13616698128837, 45.029666560036794, 49.194437640053884, 18.751124382019043, 26.05061173439026, 41.93275022506714, 36.948994977133616, 33.433929102761404, 45.41251230239868, 32.93762622560774, 32.689422675541465, 31.437927041734966, 42.04431050164359, 47.66118907928467, 32.7584947177342, 45.15811095918928, 56.30285126822335, 77.29156657627651, 9.3064432484763, 0.6833494688783373, 0.15791633698557103, 0.21777076593467168, 0.09002165483044726, 0.22654070891439915, 0.12363168597221375, 0.18337377666362695], [0.06299825132425342, 0.04706917357231889, 0.03166953633938517, 0.02483116542654378, 0.07086887756096465, 0.03273608821577259, 0.024637715092727115, 0.039154540946973224, 0.027837747308824743, 0.1260092862482582, 0.08122586645185947, 0.02918592853737729, 0.11714231276086398, 38.29377712522234, 67.77731486729213, 39.97097151620047, 31.507568836212158, 46.13930777141026, 46.120148113795686, 16.228942189897808, 39.77633162907192, 39.283006055014475, 32.803859506334575, 29.37643126079014, 34.72938251495361, 32.18931565965925, 5.891928664275578, 32.98174033846174, 50.396792139325825, 49.12293720245361, 15.893634285245623, 0.4790266156196594, 0.5842924213835171, 9.931518827165876, 50.1081222806658, 50.387373856135774, 57.46917240960257, 32.29963220868792, 45.4782839502607, 51.86315039225987, 52.578224250248496, 49.036671842847554, 47.81310796737671, 15.675082172666277, 3.7108787042754035, 2.048933220761163, 7.547366074153355, 33.47877625056675, 57.02203498567854, 58.349832262311665, 58.77171993255615, 57.96800790514265, 56.417513915470664, 54.58305747168404, 52.57848480769566, 52.14060238429478, 54.718283312661306, 50.884315967559814, 58.12041316713606, 51.22783143179757, 46.29718473979405, 46.0456668989999, 44.1590051651001, 18.97430052076067, 8.107594983918325, 20.077559811728342, 17.90360048839024, 7.8437579870224, 6.20568151984896, 29.88912841251918, 12.359677127429418, 9.169613242149353, 9.674128021512713, 3.4797629458563666, 0.4678781766976629, 0.1398483607918024, 0.048449446114578416, 0.0589616329276136, 0.07705911860934325, 0.03890078242069908, 0.010680273507854767, 0.0457475230629955, 0.07900054300470011, 0.0538700350693294, 0.03620033518278173, 0.06863353215157986, 0.04232430371588894, 0.06754939604018416, 0.1455450151115656, 0.23368146217295102, 0.17038015675331863, 0.07468374392815999, 0.062099212780594826, 0.04041400032916239, 0.021737719187512994, 0.05632349556045873, 0.11714007359530244, 0.01619659357571176, 0.03205825548086848, 0.026791831378691962, 0.05049039802647062, 0.02836104708590678, 0.0418388628001724, 0.0577075577207974, 0.1072676604879754, 0.8012599647045135, 11.326473917279925, 18.21400257519313, 18.19088418143136, 30.65779025214059, 12.334749596459524, 4.58593396629606, 28.524491786956787, 8.47386406149183, 18.829131807599747, 46.02254329408918, 44.21088736397879, 42.67341429846627, 42.25639731543404, 47.4294353893825, 49.634077957698274, 45.29561928340367, 44.63934108189174, 46.54241098676409, 46.40198789324079, 47.93899890354702, 47.6261180468968, 48.93859454563686, 48.88511426108224, 45.805842876434326, 36.95356689180647, 22.418663263320923, 10.92053931100028, 3.9788668155670166, 4.067137598991394, 16.275581972939626, 28.893633944647654, 38.336682251521516, 45.40497350692749, 43.942787647247314, 47.840859072549, 37.628612177712576, 38.45716054098946, 41.466265542166575, 43.38829708099365, 43.057906763894216, 11.997187001364571, 0.3176507678415094, 0.894440736089434, 37.39029244014195, 27.429387944085256, 28.760827813829692, 59.32021072932652, 16.202669313975743, 23.19856207711356, 28.75384487424578, 28.924230337142944, 31.429651737213135, 17.959767988749913, 23.353838682174683, 30.328410897936138, 20.20930286816188, 37.61685235159737, 18.748975651604788, 28.957654646464757, 34.2206632069179, 53.49065126691546, 32.2469197000776, 0.4027403619672571, 0.13562435816441262, 0.057932973839342594, 0.029113640809165578, 0.060507383197546005, 0.036738152216587744, 0.0707548361803804, 0.024873558598171388, 0.025146533236173645, 0.05594955491168158, 0.021739356153245484, 0.011791867386948849, 0.11346772672342402, 0.006322121962771884, 0.03456310821431024, 0.0758018067904881, 0.05231643414923123, 0.12941216650818074, 0.04574570458914552, 0.03460939787328243, 0.20673788152635098, 46.625758102961946, 77.52781227656773, 41.16824688230242, 33.777152742658345, 50.04182604381016, 28.36648801394871, 27.61592275755746, 32.68796007973807, 33.384357179914204, 37.15550933565412, 28.06896093913487, 36.014719349997385, 32.544313022068565, 16.61314456803458, 46.37095376423427, 52.78655556270054, 52.61670337404524, 23.40204528399876, 0.6920199521950313, 0.21437419605042252, 6.854657164641789, 49.70386566434588, 56.74014656884329, 60.65739849635533, 38.183220863342285, 49.256624017442974, 61.7735710144043, 57.94109058380127, 52.33859825134277, 49.88164922169277, 20.06597021647862, 5.898627161979675, 2.987685659102031, 5.4701413086482455, 32.63277053833008, 57.12226275035313, 55.84688268389021, 60.96350138528006, 59.83759444100516, 58.59927259172712, 54.57273939677647, 55.61650126320975, 52.27677665437971, 54.38289724077497, 52.00815234865461, 58.56114782605852, 50.67103753771101, 47.60608639035906, 47.95825236184256, 44.533533913748606, 20.298894677843364, 13.445385268756322, 25.456262826919556, 18.760860545294626, 14.362488423074995, 7.757222516196115, 32.72754744121006, 15.367560114179339, 11.593764168875557, 17.60790252685547, 4.257275053433009, 0.42814180893557413, 0.09866149550569908, 0.023837457677083354, 0.014131630854015904, 0.0645577215722629, 0.03473021103335278, 0.17094924407345907, 0.15621434045689447, 0.14607321391148226, 0.03654854917632682, 0.1826407281415803, 0.09436896084142582, 0.09727486169763974, 0.14687863497861794, 0.6968379308070455, 0.589309889291014, 0.33663590624928474, 0.07731561163174254, 0.04162492410146764, 0.13418321763830526, 0.024035013147762845, 0.020080996211618185, 0.17396626860967704, 0.01268618247870888, 0.017519523123545305, 0.08919188792684249, 0.06773274977292333, 0.04294988586168204, 0.021972911299339364, 0.08907233684190682, 0.249375760023083, 1.6678215967757362, 17.899867568697246, 22.57536424909319, 22.13251907484872, 40.7173296383449, 13.672564438411168, 10.277685029166085, 41.05309438705444, 14.342173627444676, 16.146383694240026, 43.04571614946638, 47.265242508479524, 46.52355357578823, 43.506885460444856, 46.447547231401714, 49.84886762074062, 47.57327004841396, 46.79915387289864, 47.431036949157715, 49.609682832445415, 50.63214152199881, 50.238612924303325, 48.95005559921265, 52.236887046269004, 47.17374168123518, 38.43761873245239, 22.17525397028242, 10.289305022784642, 3.104068636894226, 6.279030612536839, 20.454348461968557, 35.202888352530344, 40.462101459503174, 47.813771520342144, 48.39573178972517, 49.93499749047415, 41.07753814969744, 44.84652941567557, 45.274368218013215, 47.91734136853899, 40.736680371420725, 8.68597171987806, 0.3884406435702528, 3.940533603940691, 43.023252623421804, 35.24387577601841, 27.121650491441997, 51.79935550689697, 21.080469744546072, 25.564302103860037, 26.417014564786637, 29.101980890546525, 27.228866406849452, 26.046032871518815, 17.824335438864573, 33.88679184232439, 22.794208186013357, 34.87234517506191, 28.371506350381033, 18.954953261784144, 36.669812883649556, 62.36098561968122, 38.42337145124163, 0.4396168403327465, 0.13559995804514202, 0.03153564780950546, 0.031050054223409722, 0.0760711987635919, 0.07139820951436247, 0.04041139814736588, 0.02332503820902535, 0.25006070041230744, 0.27140822634100914, 0.08945117651351861, 0.11772897413798741, 0.1998553651251963, 0.15005673015756266, 0.10456344059535436, 0.15428700244852475, 0.14659223891794682, 0.26266348415187424, 0.20028308645955153, 0.2439703872161252, 0.40355742669531275, 59.95499815259661, 84.27126135144914, 53.96688774653843, 41.4633229800633, 61.733813422066824, 58.01968165806362, 20.799623557499476, 56.599257946014404, 50.024969714028494, 46.2953017779759, 41.2279041154044, 49.810461453029085, 41.68955980028425, 9.130042382649012, 43.10440410886492, 54.46601506641933, 59.28540025438581, 22.241640533719742, 0.5632510504552296, 1.0590466005461556, 13.219349946294512, 59.80668190547398, 59.90526989528111, 64.48914241790771, 41.67093515396118, 54.74280003138951, 62.00197914668492, 58.891138621738975, 57.32469504220145, 54.06055988584246, 21.698565857751028, 6.249679250376565, 3.3129657932690213, 9.206525547163826, 38.60388912473406, 56.95651347296578, 57.97221156529018, 63.23697975703648, 63.679600851876394, 60.96045807429722, 58.67712715693882, 55.79540695462908, 54.0835862159729, 56.65357548849923, 53.20692157745361, 62.43124580383301, 56.38294315338135, 51.18468311854771, 53.11398247310093, 54.73139803750174, 27.373189176831925, 13.391955358641487, 31.00308792931693, 24.96753522327968, 12.69229086807796, 8.813540646008082, 39.20099994114467, 22.286949736731394, 15.362750223704747, 20.877375636781963, 7.729035411562238, 0.44570243092519896, 0.17060395117316926, 0.13494184693055494, 0.09106368105858564, 0.156683371003185, 0.08656747732311487, 0.1297873556613922, 0.14584202345992836, 0.09112180436828307, 0.10992282908409834, 0.15097476089639322, 0.11301377322524786, 0.1272504489336695, 0.1686172413506678, 0.42654494462268694, 0.35880302105631146, 0.43746053746768404, 0.17289801021771772, 0.1504842479314123, 0.17841350925820215, 0.14334004771496567, 0.09494556632957288, 0.2242313285491296, 0.08822642080485821, 0.11339241612170424, 0.1463656760752201, 0.1339460425078869, 0.10943928467375891, 0.1262506411543914, 0.12309314629861287, 0.13709205655114992, 1.774692816393716, 22.942804098129272, 25.071671349661692, 22.850125551223755, 41.9847366469247, 17.62068894931248, 8.219772781644549, 38.58723776681082, 15.443569932665143, 22.92146791730608, 51.28673478535244, 48.022106306893484, 48.12136827196394, 43.99741438456944, 52.45335469927107, 51.69205100195748, 48.28465093885149, 48.03110769816807, 49.93766212463379, 51.49379457746233, 51.24912766047886, 52.83680146081107, 52.8313228062221, 53.51716559273856, 48.21889318738665, 41.820144244602744, 27.80805434499468, 13.734676122665405, 5.790862773145948, 6.089964483465467, 19.429742779050553, 33.2583898135594, 44.78403384344918, 52.104666301182334, 52.10203293391636, 53.48099674497332, 44.47628075735909, 46.896383489881245, 50.61914144243513, 50.82322045734951, 51.71694639750889, 16.741896424974712, 0.9925284555980137, 2.370511919260025, 45.1877623966762, 34.94351557322911, 33.603385244097026, 60.630675724574495, 21.286678382328578, 29.88704742704119, 38.89468860626221, 37.625061648232595, 44.31419665472848, 25.42512968608311, 32.32527106148856, 45.364013876233784, 26.81649603162493, 49.22496802466256, 27.35151079722813, 39.415706225803916, 48.18301616396223, 68.87305273328508, 54.27051707676479, 0.9256367364100048, 0.22106630195464405, 0.13814067813966954, 0.1462763130132641, 0.1996573686067547, 0.26963233734880176, 0.2064357977360487, 0.08924929877477032], [0.03381167139325823, 0.03008702304214239, 0.03855740638183696, 0.020232083907883083, 0.023129146845479096, 0.006383696895292295, 0.07431245635130576, 0.03196786104568413, 0.03245497115754655, 0.04773600725457072, 0.025531898718327284, 0.07735080724315983, 0.052300176450184414, 16.26283723967416, 70.51549570901054, 46.888646670750205, 33.6324599811009, 32.01912300927298, 54.869000162397114, 23.283062594277517, 30.300027506692068, 43.64488710675921, 28.631157057625906, 34.421688488551546, 31.972709042685374, 39.77499062674386, 16.714511837278092, 12.550763010978699, 62.11600603376116, 49.49324492045811, 56.27754940305437, 8.782879982675825, 0.10330612199114901, 0.1900036201945373, 8.915508934429713, 42.656175817762104, 59.00490147726876, 54.03385101045881, 43.56888771057129, 44.0668477330889, 45.16313450677054, 51.28679731913975, 46.999421800885884, 44.74372386932373, 28.762325150626047, 6.186368133340563, 0.39467610897762434, 10.231555938720703, 48.72526747839791, 57.07656444822039, 51.857883657727925, 54.72612088067191, 55.620642389569966, 56.02059459686279, 58.78862489972796, 58.310755593436106, 54.06922081538609, 54.93264218739101, 43.253779956272666, 45.82097952706473, 48.751298904418945, 30.097744601113455, 15.312184708459036, 21.93940258026123, 28.18790888786316, 14.725715058190481, 10.570253695760455, 2.71295280115945, 16.29824525969369, 18.67793379511152, 4.679601328713553, 8.142296024731227, 8.693329862185887, 2.268910582576479, 0.5896472026194844, 0.11281954257615975, 0.11140582843550614, 0.09257853762911898, 0.053147510625422, 0.059096057500158033, 0.14177645875939301, 0.08289062497871262, 0.08637348416128329, 0.059950380586087704, 0.1470688283443451, 0.1245536929262536, 0.06676022588674511, 0.009773293559971665, 1.013248200927462, 0.03656526827918632, 0.0400445040847574, 0.05228280256103192, 0.03992706324372973, 0.0669678711731519, 0.034937720612755845, 0.03876717209017702, 0.031592892416353734, 0.04258633019136531, 0.031009488007319824, 0.06025815728519644, 0.032276974458779605, 0.09528238432747976, 0.016193189026255692, 0.08312902825751475, 0.27012367812650545, 1.920919609921319, 9.937577656337194, 21.578443663460867, 13.924635529518127, 21.398071902138845, 32.920154980250764, 11.533655302865164, 6.185316784041269, 36.37853397641863, 13.456396426473345, 17.25434170450483, 35.388506003788535, 46.83780322756086, 47.8621483530317, 47.34031432015555, 43.160747051239014, 49.03291981560843, 51.1458809035165, 48.571767875126426, 46.88661084856306, 50.31582825524466, 48.58993394034249, 48.39423097882952, 43.97301925931658, 38.87842287336077, 21.21911931037903, 10.749986222812108, 2.357906367097582, 0.7968907420124326, 7.637730870928083, 35.153142724718364, 42.32779353005545, 47.63185378483364, 46.190654958997456, 44.98037951333182, 42.14069243839809, 49.13665989467076, 50.06467172077724, 53.52458279473441, 39.18290683201381, 9.391990338053022, 0.5024352052382061, 0.4167290941945144, 34.24778550011771, 59.47282791137695, 15.3182852268219, 31.709469590868267, 18.3380800315312, 13.959097726004464, 24.551563944135392, 31.030220644814626, 26.68084113938468, 22.221324001039775, 19.345341273716517, 36.78451027188982, 16.202344485691615, 32.867505005427766, 27.888985225132533, 19.645986352648052, 41.74768842969622, 38.25379719052996, 60.829310825892854, 15.992943150656563, 0.24077991555844033, 0.039224657363125255, 0.04902297783909099, 0.042159280606678555, 0.013389888602042837, 0.06517816042261464, 0.035224075961325846, 0.06461838938828025, 0.08879590167530946, 0.04894708030458007, 0.045892135838844945, 0.037303745081382136, 0.06884728425315448, 0.06042602006345987, 0.04323469754308462, 0.024206921691074967, 0.04745170108175703, 0.09461473301053047, 0.05961114021816424, 0.16875311120280198, 0.1818298109407936, 19.568496567862375, 78.92844404493059, 50.388791288648335, 29.546106270381383, 42.88400377546038, 32.22366407939366, 27.62301513126918, 34.85084744862148, 25.400027581623622, 33.34080934524536, 33.67442710059029, 34.59740148271833, 35.49816247395107, 25.434299571173533, 26.42933372088841, 70.59143257141113, 58.84072944096157, 57.74538762228829, 17.42182282039097, 1.10138729427542, 0.1521464687372957, 5.823812867913928, 40.971261978149414, 63.00588962009975, 57.218832288469585, 47.53963381903512, 49.85268565586635, 48.04234640938895, 52.25047772271292, 50.7227668762207, 48.601832730429514, 33.401380266462056, 8.747921858515058, 0.7871628840054784, 9.234340054648262, 45.34445122310093, 54.85863692419869, 51.27816765648978, 53.111567974090576, 54.35413864680699, 55.33186830793108, 57.794202191489084, 57.85151093346732, 52.56689173834664, 53.72544131960188, 43.94608804157802, 50.01862948281424, 50.422729764665874, 29.709336825779506, 17.988234758377075, 25.012424060276576, 33.93060370853969, 18.433647292000906, 23.832705054964336, 6.818629886422839, 14.990524802889142, 22.27301686150687, 8.079497337341309, 13.614718079566956, 20.04411118371146, 6.0382512126650125, 0.316294403480632, 0.08109134009906224, 0.11059629544615746, 0.11427056257213865, 0.1457689180970192, 0.21713887341320515, 0.613651383136, 0.19671159024749482, 0.3154632252241884, 0.20136354491114616, 0.674437589943409, 0.3235905005463532, 0.056285378855786154, 0.045130619380090914, 2.4690471461841037, 0.4098555344556059, 0.11864286581320421, 0.05709805006959608, 0.010563867432730538, 0.08507214899041823, 0.0920542607616101, 0.04280561235334192, 0.02781068393960595, 0.134529854037932, 0.17624014802277088, 0.5450879165104457, 0.2533167456941945, 0.20491164523575986, 0.07765253140990223, 0.3235171101987362, 0.17328397450702532, 4.210620939731598, 17.618144171578543, 24.887394700731548, 17.456353630338395, 27.60114393915449, 30.32627432686942, 14.957032748631068, 10.885016645703997, 44.80331856863839, 22.909937381744385, 18.637922593525477, 35.74966641834804, 44.28068896702358, 51.01492125647408, 48.80602986471993, 43.66471379143851, 48.97265114103045, 50.98090635027204, 50.35427611214774, 47.43436166218349, 50.477339131491526, 50.56385115214756, 49.55445507594517, 44.75156838553292, 37.56912864957537, 21.15871340887887, 10.239849482263837, 2.462411399398531, 2.195067299263818, 11.460573281560626, 39.22833068030221, 45.110977854047505, 47.21810940333775, 49.72491870607649, 51.639585154397146, 46.8857353755406, 50.48065342221941, 52.23290572847639, 53.2855543409075, 37.874359539576936, 5.8555991394179205, 0.22639221831091813, 1.8152369665248054, 41.11606591088431, 62.482454027448384, 19.119651624134608, 26.574349573680333, 23.421795538493566, 20.003448588507517, 25.57608798571995, 30.67033175059727, 23.92787974221366, 24.025930983679636, 18.06777078764779, 27.748263359069824, 25.805130141122, 22.768308775765554, 33.346763951437815, 17.814118112836564, 35.2389668737139, 42.29391758782523, 70.04338645935059, 19.14138558932713, 0.3065765063677515, 0.10285036358982325, 0.029759249916034083, 0.1645990926772356, 0.048324775482927046, 0.05386931582220963, 0.011294970255611199, 0.044754113868943284, 0.1960162411310843, 0.09110166544892959, 0.110744623201234, 0.19657920806535653, 0.1346773946923869, 0.156987191843135, 0.14590625358479364, 0.23739934552993092, 0.14651826503021376, 0.27433993188398226, 0.26341608805315836, 0.41101303377321785, 0.18114409702164785, 26.907856157847814, 91.26718017033168, 59.86168384552002, 45.29508079801287, 42.79193319593157, 69.60908930642265, 29.79724543435233, 42.63882963997977, 57.95987156459263, 37.78724997384207, 47.109133856637136, 45.572459833962576, 50.966183117457796, 22.182695490973337, 19.07563304901123, 69.11612851279122, 55.149801186152864, 62.94776793888637, 13.965969494410924, 0.6952208461506026, 0.518977943275656, 12.240925465311323, 50.549926962171284, 69.64047431945801, 61.7303740637643, 54.96424606868199, 52.29131228583199, 54.02963692801339, 56.84792355128697, 55.44852161407471, 52.38219819750105, 31.569091660635813, 7.608724747385297, 1.0172009659664971, 12.619075962475367, 54.27066993713379, 57.57019921711513, 51.86449139458792, 57.936018398829866, 57.19189064843314, 57.1479606628418, 61.70602757590157, 62.975553785051616, 55.29709257398333, 58.80509907858712, 48.80570329938616, 51.24724122456142, 54.47066688537598, 36.26492745535714, 21.71758828844343, 26.99198842048645, 41.299262114933555, 23.709508282797678, 18.78128477505275, 6.1684604542596, 22.993055207388743, 29.294859409332275, 11.27634527002062, 14.352714044707161, 23.43420328412737, 4.739975529057639, 1.0170117361204964, 0.16667813754507474, 0.29404279749308315, 0.10539288180215017, 0.1584205020751272, 0.21475127153098583, 0.3702666802065713, 0.35700772596257074, 0.2221360666943448, 0.1444555999977248, 0.3089100425796849, 0.27020610656057087, 0.1529137154242822, 0.08330450419868742, 3.3287481921059743, 0.09980319852807693, 0.22412787910018647, 0.13984059835118906, 0.10410588407622916, 0.1976168645279748, 0.14687558157103403, 0.23895519918629102, 0.11712351734084742, 0.11381832576755967, 0.0954809168885861, 0.30258248639958246, 0.24026222048061235, 0.2605621697647231, 0.12025391150798116, 0.2267152959746974, 0.7785497233271599, 3.9092714871679033, 17.169637952532085, 29.539112908499582, 18.97359354155404, 30.194470473698207, 43.27291529519217, 16.948217970984324, 11.822989583015442, 46.05986901691982, 22.00416326522827, 24.465546982628958, 42.72446618761335, 47.815984521593364, 52.67990418842861, 48.45913757596697, 45.03372778211321, 50.989911215645925, 53.978275844029014, 51.253890650612966, 49.20432840074812, 52.38637406485421, 52.23010213034493, 52.757977621895925, 47.54066562652588, 42.34747082846505, 25.34588721820286, 14.208680493491036, 3.8161052635737827, 1.8258591336863381, 10.20722074168069, 38.75622837884085, 47.68233592169625, 54.12061664036342, 53.52540615626744, 55.58924000603812, 50.58731869288853, 55.53736822945731, 58.89220864432198, 60.198393549237935, 45.877975600106375, 12.427793792315892, 1.5952091217041016, 1.4249929125819887, 40.45680693217686, 64.57524449484688, 20.24981607709612, 34.24540226800101, 27.745103665760585, 17.903412887028285, 32.80523524965559, 43.75607565471104, 36.329333782196045, 31.980282579149517, 25.224062715257915, 53.758462633405415, 23.82159835951669, 41.37727301461356, 40.19985907418387, 27.833074808120728, 56.99343967437744, 49.22485685348511, 80.06398119245256, 28.955856800079346, 0.43037212640047073, 0.17136891798249312, 0.131121464073658, 0.30331058161599295, 0.24982837002192224, 0.20236071997455188, 0.1509868795318263, 0.23286388175828115], [0.0077373551736984935, 0.046696579815553765, 0.03335123110030379, 0.027966005694387213, 0.040294788511736054, 0.04215756052040628, 0.0633085182468806, 0.0644519922456571, 0.018887541323368038, 0.06413523852825165, 0.007075021026789078, 0.04396394287635173, 0.037230504011469226, 0.6058096896324838, 48.510276317596436, 60.085971696036204, 34.43984065737043, 25.658578736441477, 53.70890808105469, 38.78874247414725, 20.599520649228776, 44.19133513314383, 37.05051163264683, 29.547085966382706, 32.05959974016462, 39.466369015829905, 33.104737349918906, 10.619828224182129, 30.1840238571167, 46.775463989802766, 35.35728427342006, 49.72645425796509, 8.84010100364685, 0.20658031212432043, 0.15652660227247647, 5.2198915140969415, 44.107696192605154, 46.54866089139666, 57.78900146484375, 48.088795116969514, 45.6495292527335, 54.766604559762136, 43.70594787597656, 40.96415744509016, 42.10293940135411, 28.281638349805558, 1.2968508686338152, 0.30556073944483486, 8.466200198446002, 46.59010342189244, 59.34327874864851, 56.69407306398664, 53.11825908933367, 50.81118965148926, 47.75455549785069, 47.22803143092564, 47.356861455099924, 43.29859236308506, 52.58069086074829, 37.71810497556414, 13.359982354300362, 14.566402418272835, 31.633272171020508, 28.63160000528608, 12.334436927522932, 14.13792438166482, 4.099003774779184, 10.082586560930524, 14.065606662205287, 8.873177903039114, 3.297889939376286, 7.891312326703753, 12.26607881273542, 5.056349158287048, 0.15615028675113404, 0.07084422638373715, 0.061864507517644336, 0.010102891097111362, 0.04043052265686648, 0.03242830473131367, 0.6912724780184882, 1.52446006664208, 2.140607101576669, 0.5860121005347797, 1.205117168171065, 0.03979455892528806, 0.19293139023440226, 0.6854546102029937, 2.449412622622081, 0.02521758772698896, 0.012138378257597131, 0.036675150240106244, 0.060462145267852714, 0.024975708652553812, 0.041906295610325675, 0.07013910636305809, 0.04451367159241012, 0.06443389571670975, 0.11343501455017499, 0.05560099147260189, 0.07804640063217708, 0.014345288808856691, 0.5144907097731317, 0.5670005806854793, 0.39955059598599163, 4.166419540132795, 9.708871620041982, 16.004907948630198, 16.920254945755005, 10.752583980560303, 22.085014241082327, 24.06431978089469, 10.086104086467198, 7.922834566661289, 36.299303667885916, 20.039975268500193, 20.451167924063547, 22.869187934058054, 34.516736371176584, 44.26866510936192, 53.85052279063633, 45.60820484161377, 45.102077211652485, 47.30892235892159, 52.386054447719026, 49.853046962193076, 47.72254862104143, 45.29704713821411, 40.4400200843811, 17.61870002746582, 7.412643109049116, 1.584064536861011, 1.2922179400920868, 11.73810257230486, 41.8847416469029, 43.64989675794329, 39.87544073377337, 42.695422717503135, 41.93001958302089, 45.40371240888323, 43.46008586883545, 45.39994648524693, 43.84315742765154, 23.39847912107195, 8.578993780272347, 0.3004868174237864, 0.19295755454472133, 22.72059723309108, 50.650787012917654, 24.136891978127615, 35.03356075286865, 55.33442177091326, 17.694200890404836, 17.01564850125994, 28.924807037625992, 27.855816262108938, 27.014920949935913, 15.682723454066686, 37.29442467008318, 24.646552767072404, 18.66638936315264, 39.31231703077044, 25.491187947137014, 33.01876381465367, 32.7830878666469, 49.13841431481497, 37.8072885785784, 0.921399420925549, 0.11825021116861276, 0.029595003729420047, 0.06259057391434908, 0.001956469637142228, 0.0076072409948600185, 0.020079287999708737, 0.05955796342875276, 0.052416029519268444, 0.04829473334497639, 0.038339321834168265, 0.005083593689570469, 0.004682495524840695, 0.015780504027913724, 0.02457120339386165, 0.019979319435411265, 0.0855014988088182, 0.054640443729502816, 0.052802903045501025, 0.05894272215664387, 0.04876157561583178, 0.07033927419355937, 1.375787615776062, 57.10389518737793, 70.09965297154018, 26.506357976368495, 30.166107927049907, 49.958881923130576, 25.223602397101267, 31.296597208295548, 31.87849841799055, 29.764321395329066, 29.418919495173864, 31.577981880732946, 37.550583907536094, 31.81095497948783, 21.94795060157776, 38.67122064317976, 53.20116152082171, 47.75427756990705, 52.71070555278233, 15.819856575557164, 1.7914972518171584, 0.12403355512235846, 3.2088181589330946, 42.709041186741416, 49.51480170658657, 61.54666369301932, 51.30369186401367, 48.818425451006206, 60.88370827266148, 47.878379344940186, 45.3652263368879, 45.76198237282889, 34.423352582114084, 2.7664135439055304, 0.5168554314545223, 6.157678587096078, 43.79331799915859, 58.69439343043736, 58.500017574855256, 54.57911784308297, 53.62652676446097, 47.49460254396711, 47.8367144720895, 47.84020594188145, 46.45469345365252, 53.643056528908865, 36.98093237195696, 14.744527305875506, 18.602577107293264, 32.541981901441304, 36.38579831804548, 17.709962878908428, 29.11099965231759, 8.735924925122942, 8.989908507892064, 13.862470865249634, 11.760286433356148, 11.290652479444232, 17.42565301486424, 19.788945538657053, 9.469256911958967, 0.20255089976957866, 0.4683904977781432, 0.030153434657092606, 0.06599360345197575, 0.3801225370594433, 0.007692793234517532, 0.18346508033573627, 0.0541482581757009, 0.461508252790996, 0.13184381888381072, 1.7737422159739902, 5.561432387147631, 2.0059777200222015, 0.5680652292711394, 1.6772807006325041, 1.0726883028234755, 0.12239958851465157, 0.1451555360108614, 0.18544307776859828, 0.09111287484743766, 0.023429435910657048, 0.024548570858314633, 0.05079839185678533, 0.26018854124205454, 0.28318922274879044, 0.2325281969138554, 0.23742542841604777, 0.03858297018866454, 0.45499035396746224, 0.7859786504081318, 1.0971770116261073, 8.771190507071358, 17.86012213570731, 20.58592823573521, 19.581006799425396, 18.51845179285322, 22.28313170160566, 25.13784773009164, 13.509652631623403, 11.004568219184875, 48.30707277570452, 24.89022261755807, 24.77828540120806, 25.238961390086583, 30.57816389628819, 41.71215534210205, 56.97154590061733, 47.62601729801723, 47.09828077043806, 48.06995507649013, 54.42605945042202, 50.4529961177281, 48.991334847041536, 46.28303125926426, 39.5584465435573, 17.632754496165685, 7.631209118025644, 1.4170859711510795, 2.61394270828792, 16.498396805354528, 44.47131974356515, 46.32188558578491, 44.343507630484446, 46.939500536237446, 44.91025134495327, 47.70080770765032, 47.54613733291626, 47.79262120383126, 47.63429955073765, 25.883281741823467, 7.961400542940412, 0.2505716915641512, 1.0852858211312975, 34.375253677368164, 51.687545095171245, 28.521349464144024, 34.34130825315203, 59.76976612636021, 27.151421785354614, 23.988032034465245, 26.4397542817252, 29.014306783676147, 24.722237757274083, 21.30897167750767, 20.330828598567418, 29.489294324602398, 21.057931525366648, 30.297731127057755, 30.538503578730992, 23.603577784129552, 33.72648647853306, 57.52006449018206, 45.94168015888759, 1.949502544743674, 0.1873998370553766, 0.049217408656009605, 0.03800326379548226, 0.06305239841874156, 0.007725633481251342, 0.04722584391544972, 0.025674223134826337, 0.016708517713206153, 0.09559747563408953, 0.1480630857071706, 0.1616462982658829, 0.096246867573687, 0.16087781664516243, 0.09386614603655678, 0.19338533016187803, 0.317025538533926, 0.13719199118869646, 0.2210099564066955, 0.15229877270758152, 0.07364154128091675, 0.17947666506682122, 2.595307205404554, 75.00375407082694, 76.74398599352155, 45.763642992292134, 38.126023292541504, 67.07232284545898, 52.61143316541399, 27.898438249315532, 61.39478996821812, 45.459662778036936, 40.19915383202689, 44.498195375714985, 52.2473475592477, 41.85678904397147, 15.44841456413269, 37.44965437480381, 51.88777133396694, 44.26839760371617, 58.14637163707188, 13.634983369282313, 1.0110713520220347, 0.4790735702429499, 7.378343326704843, 51.13445111683437, 56.235352993011475, 65.22566536494664, 58.042377948760986, 51.06162009920393, 64.00857721056256, 51.352245875767295, 49.947441714150564, 48.06983348301479, 33.820644991738455, 2.0676008590630124, 0.6602153331041336, 10.662793278694153, 53.95992912564959, 61.874695096697124, 58.384156363351, 53.942374501909526, 54.862920488630024, 48.767067841121126, 49.38241073063442, 49.771718297685894, 46.34271281106131, 55.36987495422363, 45.86071974890572, 20.035620485033306, 20.350516319274902, 36.61629785810198, 42.53409596851894, 18.176701171057566, 25.968252999441965, 5.685719592230661, 17.849328109196254, 23.772354739052908, 13.96361231803894, 12.343117833137512, 15.443064451217651, 24.336220162255422, 9.607051849365234, 0.21974486857652664, 0.47642185539007187, 0.14409189165702888, 0.1291351613721677, 0.36529537982174326, 0.16197139796401772, 0.9408168132816042, 3.7329765813691274, 4.523806648594992, 2.152450740337372, 4.840588918754032, 3.861780549798693, 1.2971438871962684, 1.3009120907102312, 7.4663222857884, 0.7510922338281358, 0.21070025462125028, 0.25169439560600687, 0.19190750803266252, 0.12544656358659267, 0.1081172406141247, 0.2194862381688186, 0.12106538510748319, 0.2119761040168149, 0.22735478808837278, 0.3227768556347915, 0.21380688649203095, 0.17789613987718308, 0.709572893168245, 2.779095309121268, 1.2173880125795091, 10.40956791809627, 16.772164515086583, 23.786961589540752, 22.167362553732737, 16.850434235164098, 29.989793913705007, 32.49004759107317, 16.585528952734812, 13.10949718952179, 43.340219020843506, 29.885567460741314, 27.70307227543422, 30.580429009028844, 37.99924646105085, 50.95230061667306, 56.98573064804077, 47.95275286265782, 49.47661788122994, 49.40823023659842, 57.28280782699585, 53.59600680215018, 49.69171673910958, 49.66346883773804, 45.74033178601946, 20.12297671181815, 10.760514480727059, 2.7203428617545535, 2.1039592623710632, 15.833719968795776, 44.476318972451345, 49.764071805136545, 44.70066588265555, 49.783332211630686, 49.28721693583897, 54.24612889971052, 50.11124202183315, 53.974120821271626, 52.6395594733102, 31.238009997776576, 12.089571986879621, 0.6592648955328124, 0.8267974172319684, 26.47905329295567, 61.13284288133894, 30.86953660420009, 39.410682678222656, 57.84387138911656, 22.081102405275615, 22.925925186702184, 38.7133823122297, 40.24223266329084, 39.69227579661778, 23.76844811439514, 49.95706149509975, 37.58201060976301, 23.919458525521414, 54.388403688158306, 35.462341036115376, 43.405396597726, 46.56089319501604, 63.348984718322754, 66.07395008632115, 5.509455519063132, 0.38121847968016354, 0.202370002333607, 0.18400117728327, 0.1684459112584591, 0.10649133500243936, 0.08970332012644835, 0.11440215765365533, 0.14641238642590387], [0.030090995864676576, 0.036347221050943644, 0.04459873952769807, 0.030213868378528526, 0.08714275966797556, 0.060139813992593966, 0.06913121044635773, 0.009106154536961444, 0.051441666803189685, 0.0012125373073753767, 0.1287773155740329, 0.007342871029062995, 0.11838694954557077, 0.03622781585103699, 30.934269496372767, 71.86127839769635, 48.988753591264995, 32.80633653913225, 29.56631163188389, 56.42949260984148, 22.017396109444753, 26.04345335279192, 44.32520954949515, 29.416122845241002, 37.8145876611982, 32.98636089052473, 42.95757825034005, 21.62589638573783, 17.862828459058488, 37.9945182119097, 28.05919177191598, 40.707695960998535, 76.47323553902763, 8.978172131947108, 0.35378552600741386, 0.9871619492769241, 8.139491558074951, 50.2835191317967, 46.95766660145351, 62.25059264046805, 45.937504291534424, 44.548795631953645, 44.823527404240195, 48.80670731408255, 42.683186939784456, 41.88340064457485, 30.83475044795445, 8.252128805433001, 0.561061445091452, 2.0033504324299947, 20.453196798052105, 31.372992651803152, 48.20290190832955, 49.450475284031455, 56.28220469611031, 54.32072475978306, 47.11106892994472, 38.038024357386995, 14.61751423563276, 3.92169052362442, 20.036650555474417, 31.518123149871826, 25.600128752844675, 9.83287525177002, 14.146217925207955, 3.973639598914555, 13.319290229252406, 10.391245518411909, 4.686294615268707, 7.114783389227731, 3.4228661017758504, 10.328417301177979, 16.086012533732823, 4.9831607426915845, 2.2792419024876187, 1.1629385628870554, 0.6109633530889238, 0.49963486407484325, 0.49440623606954304, 2.321703212601798, 1.8217729415212358, 0.553004900259631, 1.63071528502873, 0.5842807505811963, 1.623081168958119, 0.6194530746766499, 0.5459751689008304, 0.20414483281118528, 2.8184501230716705, 3.3018929702895026, 0.27320050873926705, 0.25244395967040745, 0.03173532370211823, 0.08019912083234106, 0.04912960961727159, 0.11531020035701138, 0.1018939684810383, 0.022888351730736237, 0.02663129168961729, 0.15936312292303356, 0.871599021766867, 0.3388774059712887, 0.6774422515715871, 0.298183191035475, 0.9592763313225338, 10.031781332833425, 9.85769248008728, 12.876695190157209, 14.675628968647548, 9.108879906790596, 14.460747241973877, 16.551361186163767, 9.571489231927053, 8.80142993586404, 9.914427995681763, 28.4793267590659, 25.696503741400583, 21.043583495276316, 17.757846389498027, 17.287119831357682, 29.68460123879569, 50.982132707323345, 53.82705177579607, 48.3534311567034, 46.826915400368826, 47.65241697856358, 50.00120687484741, 33.43950503213065, 16.000917945589336, 4.5778979403632025, 7.28489830664226, 2.842227510043553, 11.392253381865364, 30.8498523575919, 46.20954711096627, 49.362229687826975, 42.47006137030465, 48.77996369770595, 43.214161327907014, 46.25355005264282, 40.24631125586373, 47.80446440832955, 41.798733370644705, 33.68928582327706, 9.259507298469543, 0.022695084601374607, 7.733554346220834, 44.8731028011867, 38.5841041292463, 22.238644123077393, 45.58900349480765, 39.92894533702305, 13.51000612122672, 22.415454932621547, 30.974659374782018, 29.477280889238628, 25.462493624005997, 14.974691595349993, 32.12075778416225, 17.119352102279663, 36.95339666094099, 31.055025713784353, 28.415431124823435, 24.821154049464635, 41.18392201832363, 46.85011543546404, 10.392129676682607, 0.129734552066241, 0.08253060108316795, 0.039672293700277805, 0.044707885278122764, 0.07331551198980638, 0.04277258126863411, 0.0349809670421694, 0.06030414838876043, 0.04594138391049845, 0.006217198820585119, 0.019160914600693753, 0.030492546103362526, 0.05469337285363248, 0.12165165293429579, 0.033689284031944614, 0.06128889269062451, 0.03943951886945537, 0.10048273099320275, 0.03299462362857802, 0.16715300349252565, 0.04037623307002442, 0.07689612092716352, 0.05940429560307946, 39.294189180646626, 77.99191720145089, 47.546279770987375, 22.55602741241455, 41.80956561224801, 37.680105277470176, 24.636005401611328, 32.43501785823277, 29.640042441231863, 28.313846724373953, 34.578735147203716, 32.734419209616526, 39.92062486921038, 27.85893600327628, 25.884916305541992, 38.565528120313374, 38.92775508335659, 47.67632572991507, 80.88707869393485, 13.996565018381391, 1.4454082399606705, 1.026747248002461, 7.4217183249337335, 50.90862424033028, 52.673324244362966, 64.13547216142926, 52.6111204964774, 50.408882004874094, 48.095218726566856, 52.105062348502024, 43.70393637248448, 45.86952659061977, 36.17069946016584, 12.414436749049596, 0.4805919687662806, 0.9139976352453232, 18.44272858755929, 29.62344319479806, 43.070733138493125, 47.06660393306187, 50.41414526530674, 52.93673045294625, 46.88595424379621, 35.9889554296221, 10.869130458150591, 5.328414125101907, 23.435561656951904, 36.74256747109549, 29.01382040977478, 19.094396659306117, 27.588963747024536, 9.828913041523524, 12.328345962933131, 6.582844504288264, 7.421948484012058, 11.865337116377694, 11.515974743025643, 20.231245279312134, 22.903565883636475, 9.557032636233739, 2.901730362858091, 1.2103067125592912, 0.48527880012989044, 0.273279463074037, 0.4181871031011854, 0.43825135646121843, 0.22960506805351802, 0.21304783650806972, 0.21554180553981236, 0.29355699356113163, 1.2080824204853602, 0.7134816348552704, 4.658656852585929, 1.336885194693293, 1.382453435233661, 1.2549674532243182, 0.3222154900431633, 0.20973833623741353, 0.3899086947951998, 0.3194037494914872, 0.19018165421273026, 0.5101604078497205, 0.4979319583092417, 0.06764211785048246, 0.04968462072845016, 0.5635252328855651, 0.42675417768103735, 0.5976610268865312, 0.45736826636961525, 0.17696489127618925, 0.4869431108236313, 10.479784676006862, 17.575907809393748, 17.37311942236764, 18.877833468573435, 13.94956306048802, 18.554499047143118, 13.511472191129412, 18.148475851331437, 12.599590608051844, 16.181397403989518, 43.74745988845825, 28.166623081479752, 25.13913835797991, 26.463687351771764, 19.636269296918595, 25.879316057477677, 50.061708314078196, 56.27078185762678, 52.363236563546316, 49.49596861430577, 46.84992783410208, 47.975793089185444, 31.13365500313895, 12.219071643693106, 5.196402260235377, 8.619678088596888, 4.218870622771127, 15.665891442980085, 35.22638021196638, 47.90612350191389, 51.86074978964669, 46.51701184681484, 51.06583418164934, 47.118916920253206, 49.97528314590454, 44.52012389046805, 51.870557171957834, 46.56990500858852, 34.90833684376308, 8.279104317937579, 0.347674232508455, 11.526864307267324, 49.94871323449271, 54.52425486700875, 23.810734851019724, 51.672797543661936, 49.46329471043178, 19.856586251940044, 26.017571313040598, 31.064586435045513, 28.564650637762888, 27.850844826017106, 17.816480500357493, 20.46562886238098, 26.697829484939575, 23.851906401770457, 33.673298018319265, 26.58781691959926, 23.84506937435695, 41.51291922160557, 61.94046674455915, 17.179752792630875, 0.22811405520353997, 0.10343194273965699, 0.02129464260568576, 0.09723771869071893, 0.05960017509226288, 0.011063779804057308, 0.10086798282074076, 0.04755453984918339, 0.023230799872960364, 0.07399461697787046, 0.09864970256707498, 0.1440730555249112, 0.14291974955371448, 0.23166822163122042, 0.12568143169794763, 0.1461154052189418, 0.11776533004428659, 0.2776628535773073, 0.08810015900858811, 0.3588643606219973, 0.2556621698396546, 0.2475342159824712, 0.272090344024556, 51.96470178876604, 90.1198171888079, 63.17940698351179, 44.118476322719026, 40.06108270372663, 75.6742274420602, 30.132148606436594, 39.877823965890066, 59.33522578648159, 39.62094906398228, 52.28879703794207, 43.90073020117623, 56.45128910882132, 29.102402993610927, 21.916579484939575, 44.55546590260097, 35.36766140801566, 49.599545410701204, 88.8631659916469, 13.389790994780403, 1.1996868252754211, 2.5295957028865814, 11.018266592706953, 58.31055409567696, 56.694819995335166, 71.48287950243268, 55.148216996874126, 53.81571578979492, 52.94636065619332, 57.6316351890564, 48.23947375161307, 47.95460108348301, 34.805274214063374, 10.535781945501055, 0.5424867932285581, 2.9853571440492357, 28.298751762935094, 36.07164594105312, 50.5711988721575, 52.07384409223284, 57.27144752229963, 57.190705980573384, 50.15589114597866, 43.99489566258022, 18.702556473868235, 6.996466858046396, 26.52855920791626, 39.06660788399832, 37.19042403357369, 15.918640851974487, 24.468791791370936, 6.949549147060939, 18.591654539108276, 24.87942337989807, 9.123501522200447, 14.322524121829442, 11.06569152218955, 17.797501495906285, 24.08673640659877, 9.4815673828125, 3.29298603108951, 1.8316595767225539, 2.8401072238172804, 2.3160625781331743, 3.485325413090842, 5.696103240762438, 3.156664763178144, 1.6212723574468066, 2.3774703230176653, 2.6646013728209903, 6.971881091594696, 7.814005800655909, 5.7453876818929395, 3.034317408289228, 7.071419247559138, 4.582364763532366, 0.7673994387899126, 0.4090607799589634, 0.44694409572652405, 0.15088896692863532, 0.3633910577212061, 0.7559747004083225, 0.5292833702904838, 0.18257409600274904, 0.12320822583777563, 1.1429848564522607, 3.3164563945361545, 2.663540686879839, 1.808826601931027, 0.5972917952707836, 2.013106571776526, 12.94047965322222, 16.353735310690745, 18.810088532311575, 22.570457083838328, 12.52419136251722, 23.88484260014125, 23.026884249278478, 15.588870661599294, 14.267589926719666, 12.242454937526158, 37.83091245378767, 34.446900027138845, 29.308807918003627, 28.130650520324707, 23.42069251196725, 34.587062563214985, 55.464752605983186, 56.60369437081473, 52.4924487386431, 48.61437422888619, 51.42040770394461, 53.41332823889596, 36.372586318424766, 17.550631999969482, 8.653204015323094, 9.713889956474304, 3.86046256337847, 14.383846317018781, 35.92358677727835, 51.06465993608747, 54.0698287827628, 51.62162058694022, 57.14262792042324, 51.77597829273769, 56.04348543712071, 47.85913283484322, 57.29305989401681, 50.73366859980992, 39.049692494528635, 11.563266788210187, 0.27053554888282505, 10.230194960321699, 52.75549364089966, 44.625152860369, 28.406830992017472, 48.938802991594585, 43.508539131709504, 16.613830702645437, 31.016994748796733, 43.58539663042341, 41.40818555014474, 37.33895567485264, 24.145400047302246, 44.67204277856009, 27.729593549455913, 47.168523584093364, 44.935469831739155, 36.363720417022705, 42.09324666431972, 50.782305989946636, 69.88402257646833, 30.506295204162598, 0.32879177001970156, 0.176695227889078, 0.11544852650591306, 0.2137868832796812, 0.11679589349244322, 0.1410845566008772, 0.14617171005478927, 0.21171831499253, 0.1193196094994034], [0.06635455015514578, 0.10895430176917996, 0.021589508479727165, 0.026179321210033128, 0.021094327193817923, 0.06931621301919222, 0.01183010368341846, 0.02189872197673789, 0.10111204508159842, 0.040115044585296085, 0.053232093408171616, 0.09739600055451904, 0.03448726496260081, 0.07716193702071905, 7.3044561828885755, 65.79992703029087, 53.594874245779856, 39.420552594321116, 25.848188127790177, 45.16946431568691, 40.84402656555176, 21.43992611340114, 40.69938938958304, 28.78767044203622, 31.297493525913783, 37.347276142665315, 36.335920674460276, 37.34622001647949, 15.547452449798584, 23.209425585610525, 30.976281779153005, 19.43807714326041, 32.39234202248709, 64.71591772351945, 1.606528497167996, 0.417105925402471, 4.265344517571585, 40.19455759865897, 55.54873200825283, 50.43100159508841, 50.270341873168945, 43.560935497283936, 49.64849546977452, 45.99446562358311, 44.87005254200527, 45.924497263772146, 48.98656490870884, 45.99676547731672, 6.03390120608466, 0.15100395147289547, 0.6182338286723409, 14.25657616342817, 12.97417494228908, 13.431615676198687, 5.6864052925791055, 3.4343888206141333, 4.082000664302281, 0.24135960159557207, 3.2137961089611053, 30.32780293055943, 26.09720982824053, 18.602314812796457, 8.107971923691885, 12.555046575410024, 8.432570048740931, 10.796622531754629, 15.80143690109253, 4.413894832134247, 5.681309223175049, 8.158017192568098, 6.407527991703578, 19.67069067273821, 16.49431994983128, 12.003204141344343, 1.7956099339893885, 2.3756320902279446, 1.4497670403548648, 0.4364215375057289, 0.03891136756699, 0.04277311052594866, 0.16163599810429982, 0.0808274374742593, 0.13251358723001821, 0.12139512598514557, 1.749522315604346, 8.920166833060128, 2.314373731613159, 0.42591271283371107, 2.6868169350283484, 5.274069224085126, 0.4600093417934009, 0.06676006982369082, 0.24012857622333936, 0.09378723241388798, 0.056731519023222585, 0.13086440786719322, 0.7139073205845696, 1.0932608331952776, 1.7097256396498, 0.6924173565847533, 0.31902596833450453, 0.03387034770899585, 0.079784868418106, 0.04767243530867355, 0.14784248040190764, 8.7700058392116, 13.90840106351035, 13.459848812648229, 17.238150664738246, 11.050117135047913, 4.035270554678781, 19.6356873852866, 7.0904733794076105, 6.481132864952087, 11.330809593200684, 3.6003074603421346, 18.976225171770366, 21.59656282833644, 20.85479051726205, 21.887881687709264, 17.729402201516287, 17.740576641900198, 30.923656123025076, 33.13701868057251, 41.68963623046875, 33.05335889543806, 25.82338305882045, 12.469784361975533, 2.8640726464135304, 0.5632865514074052, 1.0363760398966926, 10.391006674085345, 32.64115353993007, 44.44942944390433, 41.33460760116577, 42.90801674979073, 47.89657667704991, 41.04487466812134, 42.5959974697658, 43.177822249276296, 46.979605538504465, 40.09311042513166, 46.79339729036604, 25.686362845557078, 2.4636125692299435, 0.9813235082796642, 41.61794471740723, 11.368109260286603, 20.869649239948817, 40.87720421382359, 23.668944699423655, 27.786648682185582, 15.717857020241873, 30.71983766555786, 27.339413983481272, 29.667171682630265, 19.080500262124197, 26.19997021130153, 23.200563158307755, 26.806179693767003, 39.07242005211966, 34.95978825432913, 24.942186457770212, 27.592694929667882, 44.979191371372764, 46.037534032549175, 3.9181664841515675, 0.1497953041855778, 0.027926048463476554, 0.02018256951123476, 0.04137674991839698, 0.04552498393292938, 0.053318107899810584, 0.06810610009623425, 0.035488080366381576, 0.01300000153215868, 0.02576303997609232, 0.019501327137861933, 0.025499602147777165, 0.020738520393414155, 0.014848989101925066, 0.019677785258474093, 0.028999524789729288, 0.014851051848381758, 0.04687526183468955, 0.10834294850272791, 0.1416062278939145, 0.049237276161355634, 0.080534703896514, 0.24823788393821034, 11.810442873409816, 76.7538593837193, 67.64113712310791, 24.923876217433385, 30.500371864863805, 46.50667987551008, 28.481003011975968, 27.24920552117484, 36.46391691480364, 27.181041955947876, 31.43887894494193, 33.6020998273577, 36.63093076433454, 32.78791339056832, 24.824690682547434, 26.871230466025217, 33.17297213418143, 28.025701454707555, 39.00924008233206, 64.61999784197126, 3.588828384876251, 0.358645818063191, 4.461518653801509, 42.97677959714617, 58.97650418962751, 55.474382809230256, 55.03215428761074, 47.50784581048148, 52.981292724609375, 51.26690810067313, 47.385887554713655, 50.16963120869228, 50.40236806869507, 47.01638582774571, 9.89521883215223, 0.0836566910147667, 4.612684096608843, 30.736627987452916, 19.39588073321751, 21.80675104686192, 11.61560148852212, 8.005353978702, 3.7747005139078413, 0.465105628328664, 6.320165250982557, 37.21823419843401, 30.092700208936417, 23.711193220955984, 18.26938145501273, 26.77318617275783, 12.458236455917358, 11.567112616130284, 9.043896879468646, 3.006315299442836, 10.535139237131391, 10.274342945643834, 15.93198834146772, 24.900035211018153, 23.034146853855678, 16.5709707396371, 1.6594004886490958, 0.40521036514214104, 0.9247254367385591, 0.15277346223592758, 0.16443992193256105, 0.057586771702127795, 0.16382267219679697, 0.11567502149513789, 0.14655862429312297, 0.02655384030991367, 0.5895950368472508, 0.7904548102191516, 2.6382952758244107, 1.5969751583678382, 1.8193876466580798, 2.927896627358028, 0.410493085959128, 0.43111371089305195, 0.897392526268959, 0.9014103763869831, 0.22858449710266932, 0.2163442817649671, 0.09517030391309943, 0.307396800922496, 0.47009421778576715, 0.23996958189776965, 0.43121011714850155, 0.09869178530893155, 0.17426505471978868, 0.010995118845520275, 0.21209893242589065, 13.747170720781599, 16.480602468763077, 20.579449040549143, 20.24997762271336, 13.417615056037903, 9.331263082368032, 14.099466102463857, 10.070083277566091, 11.513984952654157, 15.05418940952846, 10.538167783192225, 31.52351495197841, 25.349689619881765, 24.496575900486537, 34.79307317733765, 24.579886538641794, 17.28324968474252, 29.620966162000382, 31.444899559020996, 42.60045821326119, 32.13628700801304, 25.65858915873936, 12.18370704991477, 3.5912778420107703, 1.4195509531668253, 0.47171825064080103, 12.086125680378505, 37.63599811281477, 45.807934284210205, 42.121042932782856, 46.69695976802281, 48.92284992762974, 46.00298064095633, 47.457096167973106, 47.27675567354475, 49.820376532418386, 46.60644905907767, 50.606144836970735, 28.517415046691895, 1.5769073494843073, 1.9609848771776472, 44.510962690625874, 12.405939970697675, 26.886387961251394, 48.95948430470058, 33.19848591940743, 29.13594194820949, 23.192169734409877, 28.11181742804391, 28.758458478110178, 23.23991428102766, 23.526824508394512, 18.53935718536377, 27.88023223195757, 29.247281619480678, 24.826547588620866, 39.73503153664725, 22.902004276003154, 30.036777632577078, 50.55453014373779, 59.735504559108186, 4.0420337574822565, 0.18213602022400924, 0.0639164245554379, 0.018836773333272765, 0.08728460062827383, 0.08219163212925196, 0.014129747919339155, 0.05809886208070176, 0.06251003180763551, 0.012632607049973947, 0.14714048164231436, 0.18174297202910694, 0.10787473898380995, 0.12167253824216978, 0.08182956584330116, 0.11709444890064852, 0.1399811500949519, 0.10566154095743384, 0.17537568083831243, 0.17225266913218157, 0.2099120140607868, 0.27627953780548914, 0.17189552901046617, 0.2858882179217679, 16.24481361252921, 92.01072774614606, 70.3417421068464, 53.25171313967024, 36.08196401596069, 58.524190357753206, 56.086324555533274, 31.6149845123291, 55.95867919921875, 36.66251727512905, 45.051695823669434, 48.784073557172505, 48.16265794209072, 48.49030719484602, 22.81305343764169, 30.611216476985387, 36.70046138763428, 25.937392575400217, 39.53398888451712, 73.22644656045097, 3.577213819537844, 1.1575558802911212, 5.922018272536142, 47.45805849347796, 62.246215275355745, 60.781507219587056, 60.3821108681815, 53.95969288689749, 57.00350066593715, 53.329616342272075, 52.54597418648856, 53.647131647382466, 53.58705404826573, 50.105287415640696, 8.785733086722237, 0.4160298231456961, 2.518213685069765, 22.321628195898874, 19.71935064452035, 19.78170725277492, 8.926877924374171, 6.541534423828125, 7.103350562708719, 0.965867349079677, 4.934362241200038, 40.09157139914376, 36.7569363457816, 27.04000394684928, 15.283540759767805, 22.32114703314645, 11.02417950970786, 16.432545253208705, 25.40934337888445, 7.877245698656354, 13.575833354677473, 12.028423496655055, 13.623901861054556, 25.151553051812307, 25.64918998309544, 18.212427071162633, 3.0411225174154555, 3.17744226540838, 2.761145506586347, 1.7960868626832962, 0.6298543108361108, 0.11962077048208032, 0.33776276292545454, 0.194634703121015, 0.47863963352782385, 0.21548939549497195, 2.172982232911246, 22.022980724062236, 8.313708083970205, 1.3957394765956062, 3.9373109425817217, 7.131350500243051, 0.9153058507612774, 0.3853494551564966, 0.38033177011779373, 0.3625395234142031, 0.3045548791331904, 0.6986166696463312, 2.710426696709224, 4.500634840556553, 4.912669096674238, 2.9460021129676273, 1.6232838609388895, 0.2923676302390439, 0.34522222408226555, 0.2433806588607175, 0.21565567728664192, 14.019212671688624, 15.091443913323538, 23.602304526737758, 20.381463595799037, 17.44759021486555, 8.901150482041494, 27.115991183689662, 11.883693388530187, 11.46336385181972, 16.584379025868007, 6.776717918259757, 23.982105221067155, 30.46498121534075, 31.224092755998882, 35.139475618089946, 25.37060717173985, 21.789345809391566, 36.44978775296892, 37.31371634347098, 49.52886486053467, 35.319743156433105, 31.77307687486921, 15.576350007738386, 4.120660441262381, 1.6809673713786262, 1.7861372594322478, 13.40292569569179, 37.66970035008022, 49.0375577381679, 45.682984828948975, 50.33259425844465, 53.11371496745518, 50.56229475566319, 50.769340651375906, 53.182370117732454, 55.59639317648751, 48.85482011522566, 55.81195408957345, 32.412985120500835, 3.4115583428314755, 1.8735005429812839, 42.45528950010027, 14.620026009423391, 27.257263694490703, 50.86662237984793, 25.46388152667454, 32.64579841068813, 21.33713272639683, 41.09332793099539, 37.11853449685233, 40.35043001174927, 29.544306686946324, 37.80655206952776, 34.07655756814139, 37.84128264018467, 50.91907433101109, 47.3867004939488, 34.71498237337385, 42.99560921532767, 55.87340743201119, 71.6069256918771, 8.44951844215393, 0.23602156660386495, 0.08651641756296158, 0.13343731766300543, 0.18467538324849947, 0.23960602283477783, 0.15491181106439658, 0.21668835330222333, 0.16783862241676875, 0.07949710171669722], [0.025049024361318777, 0.050896375706153255, 0.04646972520276904, 0.04752168518358043, 0.09515790707830872, 0.059624948405793736, 0.0299958007942353, 0.07712304339345012, 0.05775903817266226, 0.0314359744079411, 0.03895754187500902, 0.026838068451200212, 0.0010369208882496292, 0.070692492382867, 0.3563828766345978, 29.035080160413468, 56.52558272225516, 54.487936632973806, 35.18779339109148, 32.609914439065115, 45.641438075474326, 29.99613414491926, 29.290124211992534, 33.31685543060303, 26.832256283078873, 40.60671431677682, 35.46340411049979, 41.96265527180263, 24.0263409273965, 22.189280646187918, 35.49980224881853, 45.54973227637154, 18.177531480789185, 35.18029975891113, 42.04000609261649, 0.9307949053389686, 2.4560242678437914, 20.51519557407924, 44.97518573488508, 53.1017119543893, 58.06925705501011, 56.65481226784842, 51.08427470070975, 42.55593763078962, 46.99580526351929, 46.66037055424282, 46.541566780635286, 42.32114062990461, 24.969208002090454, 0.12762603163719177, 1.8794434240886142, 3.3819774729864935, 12.904335124152047, 4.9757170506886075, 0.7683033017175538, 2.902851628405707, 0.11789657228759357, 13.002103226525442, 39.13353293282645, 22.14208674430847, 14.872502701623098, 7.970241257122584, 8.4334602866854, 9.690467579024178, 17.18723773956299, 18.738023553575786, 6.86559362922396, 0.25154424937708036, 2.6203324454171315, 5.5246612174170355, 16.031950337546213, 26.247520208358765, 19.39749618938991, 10.337003537586757, 1.0962593065840858, 0.05920435168913432, 0.05458425424460854, 0.016651877002524476, 0.03943399898707867, 0.03402994253805705, 0.038871737729225836, 0.02876037172973156, 0.029300302400120666, 0.15385837187724455, 0.1927637785140957, 0.27407511323690414, 5.215004759175437, 1.8850139251777103, 3.2428193858691623, 1.5331488975456782, 0.4724423289299011, 0.6779047953230994, 0.748389004596642, 1.1838957411902291, 0.07360769595418658, 0.0611481780984572, 0.10874414590320416, 0.17766192315944604, 0.021975622046738863, 0.1137215191764491, 0.060679866799286435, 0.14362465244318756, 0.15458042813198908, 0.0529194380422788, 0.5898678079247475, 9.010693175452095, 12.985518745013646, 15.488140889576503, 21.446910790034703, 18.14841331754412, 1.0668406337499619, 6.9132886699267795, 16.36408117839268, 10.832439626966204, 10.481978569711957, 12.94892953123365, 3.251620582171849, 9.161301459584918, 17.48071575164795, 13.677841595241002, 20.431744234902517, 27.84151339530945, 15.798155614307948, 10.501507350376674, 7.614493489265442, 3.7063832197870528, 8.009654913629804, 1.985914796590805, 0.7392533719539642, 4.169650018215179, 0.843048439494201, 14.841829878943306, 41.59366423743111, 45.462553228650776, 41.998045921325684, 47.1372150012425, 54.6740198135376, 47.11603341783796, 46.43750013623919, 43.531228474208284, 44.769838673727854, 42.95828696659633, 45.5938081741333, 24.046363898686, 0.5812569814068931, 4.305320543902261, 42.143207686288015, 58.61064679282052, 52.132966314043315, 9.251863411494664, 24.820344584328787, 23.627460479736328, 16.701214722224645, 29.46791819163731, 29.367506299700054, 28.894674437386648, 22.89131099837167, 28.83116442816598, 16.747256960187638, 32.42946972165789, 71.7121353149414, 34.53965500422886, 21.854690143040248, 40.6294835635594, 55.159639835357666, 28.612125941685267, 0.09698171421353306, 0.1406534697328295, 0.07116908180926527, 0.05877612145351512, 0.03573915528665696, 0.04961969171251569, 0.041879954880901744, 0.06733928088630949, 0.01552217047927635, 0.05989623349159956, 0.03135483519041112, 0.019755675989602293, 0.03815213098589863, 0.04654226738161274, 0.061161022766360214, 0.03733054042926856, 0.01569772445197616, 0.044642861267285686, 0.02762784080446831, 0.06276686409754412, 0.07833931741437741, 0.04371689506141203, 0.06851204045649086, 0.05887157775993858, 0.5924012948359761, 40.503432818821494, 68.3167313167027, 52.83695779527937, 21.313866683415004, 38.85305152620588, 37.724507740565706, 28.101277010781423, 31.96512508392334, 32.56833641869681, 27.542551517486572, 34.010268279484336, 35.715967655181885, 36.31631285803658, 29.16370521272932, 27.772059202194214, 34.73908914838518, 42.433656283787315, 20.28782446043832, 38.6315255846296, 46.4228880746024, 5.322291893618448, 2.465718741927828, 21.644764219011577, 46.071990149361746, 58.10650634765625, 60.721745763506206, 58.01442881992885, 54.85694851194109, 47.93033102580479, 50.74891642161778, 50.23827246257237, 48.6661730493818, 44.61170809609549, 28.766912698745728, 1.9242632133620126, 5.571104279586247, 8.18932751246861, 23.015659434454783, 11.534876448767525, 1.0988709607294627, 3.386055197034563, 0.42130559576409204, 17.978350945881434, 46.057555266789024, 28.780741350991384, 20.65410396030971, 17.928818975176128, 22.07250053542001, 12.820769139698573, 16.120498180389404, 16.72652527264186, 3.6366775887353078, 4.289030926568167, 7.928424392427717, 9.429697343281337, 23.56606445993696, 31.062786851610454, 22.92184485707964, 10.19664558342525, 0.3184190051896231, 0.11433176643082074, 0.036221719213894436, 0.04965544372264828, 0.0530645766827677, 0.019045421155169606, 0.05573075790224331, 0.04794266527252538, 0.02465938071587256, 0.0818326056801847, 0.0644500312794532, 0.08583654583032642, 0.6888096673148019, 2.3383117956774573, 2.535642155579158, 1.3685990529400962, 0.5640092183436666, 3.307430250304086, 4.918312336717333, 4.284243183476584, 0.14091927904103482, 0.1152427132640566, 0.17281235195696354, 0.21521623086716446, 0.015769840850095664, 0.14139367001397268, 0.05159689525940588, 0.10035482035683733, 0.1268562472292355, 0.02375109543624733, 0.6405955744641167, 6.507537756647382, 14.556194646017891, 20.035271338054113, 27.568744489124843, 16.33175642149789, 4.06498669726508, 7.887726187705994, 14.432080711637225, 12.085695760590689, 13.15843595777239, 14.443619063922338, 11.238045062337603, 23.339521918978008, 22.453699554715836, 16.202122143336705, 27.56673124858311, 36.88545370101929, 23.13240827832903, 13.323747498648506, 6.791999178273337, 2.8623114952019284, 9.753243684768677, 2.3386704964297156, 0.9903391216482434, 8.003227829933167, 1.6836628381695067, 18.062351192746842, 45.37166036878313, 47.7095103263855, 43.92390939167568, 49.86107907976423, 56.59989023208618, 50.03331102643694, 50.245533330099924, 49.36118050983974, 48.42325013024466, 47.64707381384713, 44.37595919200352, 29.906519753592356, 1.445151916572026, 5.7976133823394775, 50.82935571670532, 54.76264408656529, 42.644891943250386, 9.337205529212952, 25.069152627672466, 24.11450661931719, 21.891048329217092, 27.79827128137861, 26.21433561188834, 25.96585065977914, 19.376672438212804, 18.843174116952078, 26.871906178338186, 21.441340071814402, 70.27369144984654, 39.60046230043684, 19.1222710950034, 41.81523881639753, 64.2476647240775, 29.871163845062256, 0.18308485645268643, 0.15684947637575014, 0.06462254202259438, 0.04853736389694469, 0.02270014307993863, 0.04650455101260117, 0.03187265240454248, 0.07533615534859044, 0.042629647866955826, 0.06689134599374873, 0.13344617933034897, 0.1982051001063415, 0.14101413823664188, 0.15243426258010523, 0.22899585217237473, 0.2622323972838265, 0.11955218416239534, 0.2971901957477842, 0.2171778484646763, 0.11939776316285133, 0.28005173110536163, 0.35876513166087015, 0.1531905848532915, 0.1498410917286362, 1.0331227630376816, 54.163639886038645, 79.91441426958356, 66.40080724443708, 49.3811148915972, 40.05825478690011, 62.85339750562395, 39.28009475980486, 42.274598121643066, 42.88371889931815, 38.90257828576224, 57.79478236607143, 46.34693384170532, 55.127851826804026, 32.6975451196943, 29.0850533417293, 46.357276235307964, 54.80357592446463, 23.3132038797651, 42.57071297509329, 48.37342112404959, 3.0039281589644293, 4.1369530984333585, 25.34310793876648, 56.01872900554112, 58.66519709995815, 68.246554510934, 63.13177013397217, 61.98299666813442, 51.195372922079905, 57.41252722058977, 54.76733064651489, 52.64772013255528, 46.825122765132356, 31.44571249825614, 1.72458153963089, 4.489694901875087, 6.141125806740352, 20.193191732679093, 7.7026887110301425, 0.6043191381863185, 5.171170311314719, 1.368746810725757, 14.478520733969551, 53.78902081080845, 34.640945843287874, 20.446740184511455, 15.419327667781285, 18.169681753431046, 11.032388806343079, 22.011670793805802, 25.69559700148446, 9.152862003871373, 7.689549667494638, 9.406555499349322, 8.723058598382131, 21.67738774844578, 33.65206779752459, 21.761907373155864, 14.510630096708026, 1.1564403687204634, 0.23420075859342301, 0.2474723064473697, 0.1473828950630767, 0.25614566675254274, 0.10402183394346919, 0.24848658059324535, 0.15711266653878347, 0.21399815194308758, 0.22005637043288775, 0.37350991474730627, 0.20414127728768758, 11.077105675424848, 7.121849272932325, 6.370741188526154, 3.3292814663478305, 0.6813633697373527, 1.5918477135045188, 1.70269048001085, 4.073508662836892, 0.1666643361427954, 0.4015265442430973, 1.2524680559124266, 0.380634071039302, 0.10704978289348738, 0.37683576771191185, 0.22927046886512212, 0.38278334428157124, 0.24767858109303884, 0.11658280635518686, 1.4106270777327674, 17.561681372778757, 19.281195504324778, 22.686287028448923, 29.773069177355083, 20.983646597181046, 3.91267306464059, 12.785706792558942, 26.50261810847691, 16.51172171320234, 14.622808762959071, 16.734887429646083, 6.229686677455902, 15.390164341245379, 23.697296823774064, 23.050805159977504, 32.90285396575928, 40.760741983141216, 27.16395459856306, 16.17405663217817, 8.861657789775304, 6.212634061064039, 14.15464174747467, 4.24566331080028, 0.6998425381524223, 6.497109813349588, 2.3158196083136966, 17.33943976674761, 46.006552015032085, 50.34264482770647, 47.27846493039812, 54.652605465480256, 60.50705337524414, 53.616875716618125, 53.13599784033639, 52.89498220171247, 54.247313567570274, 50.614694595336914, 53.14112213679722, 30.692621571677073, 1.515294415610177, 6.195356931005206, 51.83061892645699, 65.17936951773507, 60.40399769374302, 12.792410935674395, 30.982246807643346, 32.27484451021467, 25.234676088605607, 38.95582927976336, 40.04130118233817, 41.71263476780483, 32.47559533800398, 40.48077474321638, 26.69077706336975, 44.49460315704346, 89.16188294546944, 45.16179003034319, 32.93733092716762, 52.86970812933785, 68.37978621891567, 48.326253277914866, 0.244748449751309, 0.2785722262092999, 0.16285878606140614, 0.21970893336193903, 0.0939517364438091, 0.15060589568955557, 0.252045958169869, 0.19149467375661644, 0.11180796221430812, 0.2152145616710186], [0.03499310264097793, 0.06447454674967698, 0.02175924401464207, 0.04181615901844842, 0.03590720805472561, 0.11700717572654996, 0.028426196625722305, 0.02327050095690148, 0.019675169505977204, 0.027997298033109734, 0.05007174191996455, 0.0499684485340757, 0.12323566579392978, 0.0688587718510202, 0.08621531764843635, 8.593082121440343, 60.16050502232143, 48.443921021052766, 47.36873245239258, 32.15408481870379, 38.88148355484009, 30.761398315429688, 37.16789102554321, 35.9794294493539, 26.660997084208898, 34.145997864859446, 37.01348468235561, 33.42582055500576, 34.185408047267366, 20.846562113080704, 37.24592971801758, 48.14390822819301, 62.173363413129536, 36.123750482286724, 61.353906767708914, 26.71159212929862, 2.405247918197087, 2.764000130551202, 33.851394244602744, 52.05144657407488, 49.54234436580113, 48.389186586652485, 50.56491770063128, 52.79632125582014, 50.74193000793457, 41.615815094539094, 40.495828015463694, 46.372558798108784, 38.58462177004133, 8.009583694594246, 6.8048255528722486, 9.318216970988683, 2.197602306093488, 10.226582765579224, 12.109058209827968, 9.123614430427551, 21.721972601754324, 35.539129052843364, 21.22190206391471, 13.500841447285243, 7.988476804324558, 7.146031175340925, 8.75502986567361, 17.944983959197998, 19.475342069353374, 7.214128298418863, 3.807985859257834, 1.3593131112200874, 4.059291779994965, 3.9849564773695807, 27.15911865234375, 28.806307247706822, 18.504942757742747, 3.3763559460639954, 0.15708068039800438, 0.0992894796654582, 0.04363544711044856, 0.046376453779105625, 0.05498326336964965, 0.009330821722479803, 0.009915760468824633, 0.04003107248406325, 0.04591451731643506, 0.046740949220423184, 0.10976195521652699, 0.21344084399087088, 0.2627944142690727, 1.7806671815259116, 0.2970696607870715, 1.7362380112920488, 1.1271406837872096, 3.53726840870721, 9.539268698011126, 3.5323206399168288, 0.49401605129241943, 0.1242123083876712, 0.027035612047516873, 0.04581224851842437, 0.07157810271850654, 0.01839635830505618, 0.02926058435280408, 0.03184178923921926, 0.024665046483278275, 0.14163939468562603, 0.02629722006219838, 0.3157922604254314, 5.427648297377995, 13.025450042315892, 25.94560534613473, 24.74900916644505, 3.3206904530525208, 1.905611208506993, 11.006161962236677, 13.304963912282672, 13.599982687405177, 13.878456933157784, 13.51214703491756, 6.118604523794992, 6.607240063803537, 18.871043341500418, 12.38907321861812, 14.751291377203804, 26.936501843588694, 26.894932508468628, 13.211711270468575, 1.1275956822293145, 0.5598232001066208, 1.764258467725345, 2.830790340900421, 3.5456147151333943, 0.6727193221449852, 21.495419638497488, 43.44445937020438, 41.337664808545796, 40.34207827704293, 45.07634803227016, 43.00124767848423, 46.18786873136248, 41.730929374694824, 45.31123883383614, 43.650039196014404, 43.03538070406233, 27.942086832863943, 9.559054562023707, 1.347465998360089, 17.78374579974583, 51.21106890269688, 49.27346992492676, 76.09927654266357, 47.82019860403878, 27.88156107493809, 22.328763995851787, 22.35225932938712, 30.110074179513113, 28.19584894180298, 21.84899435724531, 29.3863810811724, 27.69160427365984, 16.572706052235194, 55.46427665437971, 49.970631326947895, 27.64035436085292, 42.97941296441214, 42.18679026194981, 46.62909671238491, 4.12364946944373, 0.09512229077517986, 0.06236808906708445, 0.03603450122422405, 0.05000222600730402, 0.07060978574944393, 0.02974392520263791, 0.07183733702238117, 0.0765328672049301, 0.045122989253806214, 0.08785603567957878, 0.058979383403701444, 0.03460105528522815, 0.02828935477217393, 0.08680831654263393, 0.054717610124498606, 0.025697783567011356, 0.07970463843750102, 0.06734732831163065, 0.015369126905820199, 0.026676704342077886, 0.04861099851716842, 0.055889938824943135, 0.03157513176224061, 0.05128849430807999, 0.07754224232797112, 13.303519555500575, 71.95041683741978, 56.61628450666155, 37.56995548520769, 27.239769867488317, 40.58018956865583, 27.028820821217128, 36.761813981192454, 35.351899419512065, 30.5983692577907, 31.308652332850865, 33.125720909663606, 34.97328165599278, 32.610720430101665, 27.108871017183574, 34.60517304284232, 51.8268495287214, 57.69075741086687, 38.52480820247105, 66.41286236899239, 33.137657914842876, 4.531282041754041, 2.8032995760440826, 36.9056590625218, 57.46625069209507, 54.2950233731951, 53.6845303262983, 55.99786703927176, 56.57358087812151, 53.19421679633004, 46.9169397354126, 45.8262288911002, 49.67001404081072, 42.047607421875, 10.78012750829969, 6.943826002734048, 12.781259945460729, 5.1302975331033975, 6.9736268264906744, 2.4850757718086243, 6.481796417917524, 24.200770241873606, 39.24000365393502, 24.71151668684823, 23.012060267584665, 17.35794629369463, 21.04672408103943, 12.637008394513812, 13.087343726839338, 19.677835157939366, 6.1170989360128125, 4.605721133095877, 4.295259118080139, 8.62683299609593, 10.35560039111546, 32.770956311907085, 31.0669800894601, 21.595251355852398, 5.913390781198229, 0.5736266108495849, 0.07194538015340056, 0.014848286818180765, 0.024237645756719366, 0.04238983662799001, 0.030260039293872457, 0.027498298291383044, 0.05824381073138543, 0.15903435913579805, 0.1226245364440339, 0.16774304397404194, 0.02001764139692698, 0.27174686959811617, 2.0870519067559923, 0.16869591070072992, 1.9965865782329013, 3.888012605054038, 5.233711915356772, 12.589229106903076, 2.8986681614603316, 0.2754157898681504, 0.0762268275554691, 0.13019518234900065, 0.03440791029216988, 0.11842831304030758, 0.01439020104174103, 0.0077499335166066885, 0.031484951065587144, 0.04959794127249292, 0.21838877562965664, 0.2919963630182402, 1.0899682555879866, 2.049546182155609, 18.471600089754375, 29.340575081961497, 25.53203293255397, 4.196625964982169, 3.458727926015854, 9.085159625325884, 11.653248565537588, 13.304341179983956, 15.42378146307809, 14.036551032747541, 12.143874764442444, 20.59951717512948, 28.683805295399257, 15.234335354396276, 19.022303887775966, 33.35003655297415, 35.15614087241036, 18.77228512082781, 2.1460195311478207, 0.45164194649883677, 0.7379996020879064, 4.32728727374758, 8.74276716368539, 2.1790536556925093, 24.65088496889387, 46.403290680476594, 45.37350164140974, 45.98488405772618, 46.92866134643555, 46.460866928100586, 49.33723701749529, 46.4417142186846, 49.24010467529297, 48.64131586892264, 47.77953774588448, 33.42545230048043, 11.302531293460301, 2.9996387319905415, 23.693259920392716, 55.74582460948399, 48.815646171569824, 71.27727535792759, 45.6041054044451, 9.121985077857971, 24.08928986958095, 24.460599865232194, 30.477456705910818, 24.998873335974558, 23.93987580708095, 18.624986784798757, 30.332034383501323, 20.85863287108285, 43.843925203595845, 61.532788140433176, 23.532541138785227, 38.76291254588536, 47.65422351019723, 54.297128677368164, 3.8460337604795183, 0.08612053309168134, 0.07764060954962458, 0.04056618216314486, 0.039966991636902094, 0.06763565141175475, 0.044184599071741104, 0.04968861051435981, 0.05605865655733006, 0.03480467346629926, 0.00941681585806821, 0.16670664958655834, 0.07675908399479729, 0.1176126596650907, 0.15712046969149793, 0.1815062311611005, 0.2503583872956889, 0.1687424582030092, 0.11813062615692616, 0.12054783930735928, 0.13096774875053338, 0.16300560746874126, 0.16161334860537732, 0.13117861029292854, 0.245075557913099, 0.2843792103230953, 19.73281451633998, 92.0702599116734, 60.39303343636649, 64.43478666033063, 45.20679351261684, 52.79488297871181, 43.95312309265137, 51.72216796875, 49.4698885508946, 35.17205919538225, 52.14311763218471, 49.92472110475813, 48.50401599066598, 44.520634583064485, 28.099962064198085, 46.437986510140554, 56.494864736284526, 74.15904767172677, 43.03563778741019, 71.17728383200509, 33.81125797544207, 3.305637615067618, 3.3412536467824663, 41.24275936399187, 60.003454889569966, 58.433877672467915, 56.65185233524868, 60.857867922101704, 60.37118829999651, 58.04225982938494, 49.63827119554792, 49.37406594412667, 53.774752685001914, 50.396646227155415, 9.782313210623604, 15.992889302117483, 18.42963991846357, 5.985680273600987, 17.000857523509435, 25.182097332818167, 17.519684723445348, 24.23437520435878, 51.81582621165684, 27.804509026663645, 23.343583141054424, 16.997852427618845, 15.308689764567784, 12.813985092299324, 21.627933944974625, 25.112618821007864, 9.191452298845563, 10.974307077271597, 4.901639699935913, 9.654022540364947, 8.113309008734566, 34.75655344554356, 34.752724988119944, 22.538038526262554, 9.105742795126778, 0.5216665704335485, 0.23241284596068518, 0.1864950648908104, 0.1164209350411381, 0.08515601591872317, 0.2424147506909711, 0.14482266030141286, 0.2563172004052571, 0.20265225933066436, 0.24654363627944673, 0.1512964272073337, 0.3224654352026326, 0.35827951771872385, 13.355748295783997, 1.0022544137069156, 3.5656270469938005, 3.0104292844023024, 7.228826778275626, 17.181654861995153, 7.360896400042942, 0.8427998785461698, 0.17984073981642723, 0.1871455628424883, 0.145137256277459, 0.2547271485839571, 0.11026661563664675, 0.06851944327354431, 0.08740824327937194, 0.2549522593617439, 0.4656415081449917, 0.4011796771415642, 1.0585075723273414, 12.026027236665998, 20.71005780356271, 33.44037703105381, 28.883385351725988, 6.518746503761836, 5.313515016010829, 15.254165513174874, 20.41752474648612, 22.023960420063563, 18.843537160328456, 15.984594890049525, 7.594298550060817, 12.632498145103455, 26.633268560682023, 17.001635721751622, 23.431439638137817, 43.469994000026155, 42.43837758472988, 21.39223541532244, 1.8683065474033356, 0.7649993247219494, 4.239215382507869, 9.355108431407384, 7.263094859463828, 1.6309066861867905, 26.094477449144634, 50.13119724818638, 47.50679315839495, 46.88773645673479, 49.43905591964722, 50.36797448566982, 54.69445446559361, 49.13103185381208, 54.55708857945034, 53.1517459324428, 52.235712800707134, 37.28343261991228, 13.631527509008135, 3.345424520117896, 23.095219782420568, 59.304876055036274, 58.2104618208749, 86.30432510375977, 53.91849701745169, 37.81270122528076, 32.199883869716096, 31.385659217834473, 40.58980587550572, 39.95485169546944, 34.185366358075825, 44.07345199584961, 39.230071204049246, 29.356114728110178, 71.90670572008405, 60.254541942051475, 37.04036031450544, 61.05713530949184, 53.75917829786028, 73.16586521693638, 9.160012568746295, 0.24010971294982092, 0.16297207426811966, 0.15763872116804123, 0.1637936308979988, 0.19714885178421224, 0.3200424409338406, 0.14762144083423273, 0.16016815043985844, 0.1080386255468641, 0.17222179578883307], [0.09321779904088803, 0.04465203845341291, 0.037048704123922756, 0.01815697454315211, 0.032979729784918685, 0.0201193181731339, 0.011662171355315616, 0.04672350747776883, 0.052333363597946506, 0.08308711514941283, 0.021557327260130217, 0.04636127495073846, 0.16572717071643897, 0.006399908369140965, 0.028097500691988637, 0.5607425336326871, 35.380574635096956, 66.96506350381034, 41.938902854919434, 39.76912982123238, 39.58155972617013, 34.32268360682896, 33.42065804345267, 42.30581637791225, 26.380585159574235, 27.493292263575963, 38.58849539075579, 30.458880696977886, 39.84971155439104, 24.016255617141724, 30.700820446014404, 31.819466522761754, 41.084215368543354, 66.84429686410087, 53.89646427971976, 67.9920906339373, 12.017976011548724, 1.1547342602695738, 25.169625316347393, 60.01398835863386, 46.376752035958425, 51.22806419645037, 47.50373942511422, 49.1753648349217, 46.56554848807198, 53.98327159881592, 51.17203739711216, 45.59421811785017, 50.272391591753276, 21.268005098615372, 5.72231228010995, 9.521338871547155, 12.752364993095398, 8.824165310178484, 5.1741523912974765, 29.32455948420933, 33.72560405731201, 18.477905579975673, 16.20775886944362, 23.199171781539917, 7.8240624495915005, 7.070689252444676, 15.727428163800921, 18.49653717449733, 11.890839610780988, 5.522207200527191, 3.3001659086772372, 0.7524487610374178, 4.285578106130872, 9.113691534314837, 36.14904192515782, 24.76921452794756, 19.700587034225464, 2.9518372969967976, 0.8865027991788728, 0.12603460917515413, 0.04033017411295857, 0.056236310595912595, 0.13345159403979778, 0.06728303711861372, 0.027043342257716825, 0.04835875990933605, 0.09568036547196762, 0.2095203772187233, 0.06709944589861802, 0.08015695666628224, 0.20429831743240356, 1.6632309002535683, 0.7120112223284585, 1.450594201683998, 3.9120038662637984, 5.527168648583548, 12.908193979944501, 3.7037589720317294, 0.09164403884538583, 0.10483287328055926, 0.07503105886280537, 0.10633510231439557, 0.02686710805366082, 0.019044983500082577, 0.03217128923695002, 0.07065665216318198, 0.03153547478307571, 0.04068423029301422, 0.12153159294809614, 0.27100688644817894, 1.419025061385972, 6.06383969102587, 22.640901395252772, 30.898805890764507, 4.040577241352626, 1.775495007634163, 11.439187594822474, 6.141467136996133, 14.88575986453465, 15.503261906760079, 18.995695761271886, 19.83950584275382, 6.013761852468763, 6.53365386383874, 21.342451572418213, 26.607895476477488, 19.163138662065776, 27.302565949303762, 35.61483315059117, 37.58418539592198, 6.983982247965677, 1.2966356916087014, 1.8887872312750136, 7.453980548041208, 0.8418377158897263, 13.343090415000916, 38.96738760811942, 41.97462701797485, 41.93084989275251, 45.6069506917681, 44.42809847423008, 43.48954275676182, 46.32321963991438, 46.86871228899275, 47.838976110730854, 41.51739386149815, 36.61833020618984, 9.296890343938555, 11.170090811593191, 43.468614782605854, 50.814625535692485, 45.75103896004813, 33.31546926498413, 49.476270471300396, 47.751355852399556, 18.9989492552621, 24.215627227510723, 28.967918872833252, 24.820577348981583, 16.880792651857647, 29.131255388259888, 23.556396041597637, 27.574799844196864, 58.83107839311872, 23.09599276951381, 29.971485410417827, 37.55773707798549, 56.021452699388774, 19.777253457478114, 0.04868088423141411, 0.020355226139404943, 0.13289341756275722, 0.11898739875427314, 0.02296494645997882, 0.008228293071234865, 0.08323788563055651, 0.06813620669501168, 0.035318253229239156, 0.004315521310283137, 0.028158640089843954, 0.060968936287931035, 0.03839019499719143, 0.0399228563266141, 0.054598517050700526, 0.05314736474039299, 0.04217422194778919, 0.013934412954508193, 0.05966477162603821, 0.012698962685785123, 0.05196726002863475, 0.03949970153293439, 0.05726800952106714, 0.15363745444587298, 0.03461645124480128, 0.03947757450597627, 0.878432575081076, 48.60123865944998, 75.9230910709926, 41.276461601257324, 32.38498388017927, 42.78707293101719, 29.88412570953369, 27.22156385013035, 34.62523249217442, 29.181245940072195, 30.997727394104004, 30.64707612991333, 29.455571242741176, 36.056384222848074, 26.805132252829416, 32.96229927880423, 34.297545024326865, 39.47445671898978, 71.22816549028668, 60.00376755850655, 68.84072971343994, 18.833870479038783, 0.8930888772010803, 27.326043912342616, 63.97585814339774, 52.79171460015433, 55.08862577165876, 53.80060345785958, 53.87800291606358, 51.78261729649135, 57.00216661180769, 58.12746558870588, 46.32871913909912, 54.292379583631245, 19.383820397513254, 6.790523988859994, 11.063209278242928, 8.867921590805054, 1.9459081547600883, 5.262966436999185, 33.64058937345232, 34.17705978666033, 25.4107278074537, 27.89320625577654, 32.85766288212368, 20.480103697095597, 14.30130866595677, 13.436838115964617, 20.40003613063267, 11.470613428524562, 5.245975051607404, 6.942830673285893, 4.775968934808459, 10.869992903300695, 19.03996968269348, 38.828607763562886, 23.85011724063328, 23.401425157274517, 9.142596908978053, 1.5000909971339362, 0.13199809060565063, 0.15812964125403337, 0.024244213975699883, 0.05228887205677373, 0.07277489599904843, 0.030580657268209115, 0.07076227970953498, 0.22790710202285222, 0.08651643791901213, 0.07326220627874136, 0.08751185557671956, 0.22218569474560873, 3.7946127482822964, 0.4527010853801455, 1.7893465672220503, 8.092852643557958, 8.327995317322866, 12.529637013162885, 2.161186363015856, 0.18483698314854077, 0.09466621346239533, 0.17429828936500208, 0.1291314565709659, 0.039771780504712036, 0.053494666104338, 0.055707816633262804, 0.1589788549712726, 0.30094005167484283, 0.05260801421744483, 0.07090412066983325, 1.229866542986461, 2.546296783855983, 12.371832132339478, 26.092714343752178, 31.156987054007395, 8.156215003558568, 3.8227186458451405, 6.100625191416059, 7.487392698015485, 14.006831850324359, 14.505887951169695, 16.03936059134347, 18.81192111968994, 9.857839260782514, 17.371295520237513, 35.5337997845241, 34.96984577178955, 27.264244897024973, 32.80855648858206, 39.755129201071604, 40.95941877365112, 9.849965214729309, 1.1967667362519672, 0.8401649913617543, 4.5537038786070685, 1.4481459387711115, 13.922739539827619, 43.03722545078823, 45.60096481868199, 47.79971184049334, 46.96019574574062, 45.482300009046284, 47.59083162035261, 51.432740756443565, 52.18221514565604, 52.491597584315706, 46.26503195081438, 42.753398486546104, 8.439849155289785, 13.315981149673462, 49.19742883954729, 53.42477192197527, 52.219617298671174, 37.35316474097115, 55.18832547324044, 26.889971494674683, 21.562358583722794, 24.879685674394878, 28.71642361368452, 22.524267196655273, 14.226564288139343, 20.894198962620326, 37.07745327268328, 20.498605012893677, 61.382713999067036, 30.931990487234934, 23.93097516468593, 39.146550382886616, 65.70491041455949, 21.280824525015696, 0.1955187799675124, 0.12698086697076047, 0.08689189170088087, 0.07054950469838721, 0.08645559368388993, 0.007365544276711131, 0.10651153498994452, 0.07471016608178616, 0.02230557327025703, 0.02541488196168627, 0.0526935740906213, 0.17354119356189454, 0.16208636893757752, 0.08840568297143493, 0.10195083650095121, 0.12099119408854417, 0.1108876515978149, 0.0605531707406044, 0.15553515404462814, 0.2018783087176936, 0.12216967370893274, 0.1584812988127981, 0.15268374633576187, 0.2989606021770409, 0.13732522832495825, 0.06202163587191275, 1.324031027300017, 69.09972381591797, 83.60305309295654, 55.40166643687657, 54.89248159953526, 55.70163059234619, 49.134540694100515, 49.22787584577288, 57.52270827974592, 34.568719318934846, 40.9835707119533, 54.95202071326119, 44.039051464625764, 53.06531381607056, 31.5157607623509, 39.93716158185686, 41.447484561375205, 51.224141938345774, 76.47593144008091, 64.04579871041435, 76.2927074432373, 16.98208522796631, 1.7643205672502518, 29.8898822920663, 70.7765395300729, 57.77593190329415, 58.08992447171892, 56.99729592459542, 58.1333715575082, 55.07547630582537, 63.12099347795759, 60.26619407108852, 53.7477902003697, 55.130304540906636, 25.778049537113734, 13.739079543522426, 18.060621091297694, 21.51813677379063, 16.949828216007777, 9.589995758874075, 34.216268471309114, 45.194036620003835, 25.708300045558385, 27.647533587047032, 33.0064377103533, 14.855660268238612, 13.536860040255956, 18.432257652282715, 20.963041714259557, 15.985138586589269, 10.255709614072527, 8.800458056586129, 5.228480790342603, 9.814093402453832, 15.12131769316537, 43.85453510284424, 27.578242676598684, 23.29549813270569, 13.781616415296282, 1.7856100648641586, 0.1963308642485312, 0.1792680969727891, 0.10639722219535283, 0.18122112431696483, 0.3358617520758084, 0.19254147687128612, 0.14513541066220828, 0.46634805308920996, 0.3614348684038435, 0.1973256372979709, 0.20063637250236102, 0.7688842362591198, 5.756425763879504, 0.7573610288756234, 4.027896344661713, 10.387348447527204, 14.578013726643153, 21.175937993185862, 4.880883693695068, 0.17438777456326143, 0.30924977149282185, 0.279531647584268, 0.22906476418886865, 0.10887916080121483, 0.13927605721567357, 0.16950365235762938, 0.362703837454319, 0.47724711682115284, 0.21606734448245593, 0.31107592635921066, 4.3802711963653564, 2.74005794099399, 19.169996534075054, 27.684586593082972, 38.91112457002912, 10.967097452708654, 4.266695073672703, 11.402462891169957, 11.20542848110199, 21.921959127698624, 21.215058088302612, 22.589443036488124, 22.651874337877544, 7.084276454789298, 10.403790490967886, 29.90395586831229, 33.903585638318745, 25.155798401151383, 38.016884463174, 49.12400722503662, 46.628158705575125, 8.86125305720738, 1.6382252020495278, 5.349517107009888, 16.511904103415354, 1.4761483733143126, 17.29934344972883, 46.24843965257917, 47.11270523071289, 49.72508198874337, 48.8716972896031, 48.79445416586739, 51.262669699532644, 56.613769258771626, 55.3609812600272, 54.79848289489746, 50.7436740057809, 46.153179849897114, 11.611255390303475, 14.56034619467599, 52.63728393827166, 61.29076153891427, 55.42436620167324, 39.81429658617292, 57.56140627179827, 64.09276853288922, 28.1244284084865, 31.181701796395437, 41.36097601481846, 35.356210776737754, 27.432116849081858, 41.07007231031145, 38.46987574441092, 42.38534198488508, 72.16012041909354, 31.644674164908274, 46.314902646201, 49.28540693010603, 72.5648946762085, 36.472616059439524, 0.3085318814430918, 0.20565470893468174, 0.2683607627238546, 0.2333191516143935, 0.18709974815802916, 0.11856735843632903, 0.1476408333650657, 0.12990776848580154, 0.1365539782813617, 0.09394776022859982, 0.11092405500156538], [0.09473046394331114, 0.0157747687106686, 0.06173106003552675, 0.007571061507665685, 0.030359583773783276, 0.05215362984953182, 0.02604056758406971, 0.027722038428432176, 0.033651275892875025, 0.06786611583083868, 0.011006870223874492, 0.0676046491467527, 0.04352111056713121, 0.0838812996766397, 0.15605318838996546, 0.06146770023873874, 7.1974760719708035, 62.42265088217599, 53.555332047598704, 38.48156956263951, 33.640394823891775, 34.633539063589915, 30.97407920019967, 51.44266973223005, 35.4804619380406, 26.13399359158107, 32.80623231615339, 32.52681050981794, 36.04453754425049, 31.57179798398699, 23.066631419318064, 42.70999656404768, 57.41110283987862, 50.775729519980295, 46.889032295772004, 70.93207495553153, 26.044502530779155, 2.379262741122927, 19.30401165144784, 46.43367862701416, 54.363442284720286, 46.32596417835781, 53.678551401410786, 50.74020338058472, 52.391046728406636, 44.265746865953716, 34.34026949746268, 43.7527995790754, 48.26109307152884, 15.34854463168553, 3.373846126454217, 13.415517568588257, 5.929259163992746, 5.328669905662537, 34.20853860037667, 35.90716470990862, 21.404947144644602, 27.18136852128165, 38.327472414289204, 15.835573400769915, 7.063624237264905, 19.471352066312516, 17.159337248120988, 9.160223620278494, 14.982702868325369, 9.165651900427681, 4.198242289679391, 2.961213673864092, 7.2678066066333225, 17.873238597597393, 34.611680030822754, 21.011091981615337, 17.60195139476231, 5.891046243054526, 1.5156050218003136, 0.15116659631686552, 0.11562790402344295, 0.021193607045071464, 0.07148495343114648, 0.06835067804370608, 0.019769116071984172, 0.08790925996644156, 0.013108876716744686, 0.42754697799682617, 0.09756756813398429, 0.17034564646227018, 0.31188767137272017, 0.366913550134216, 0.7069242724350521, 0.9274907112121582, 7.85500625201634, 5.443706018584115, 6.453396090439387, 1.1254463004214423, 0.01099086697545967, 0.07981943977730614, 0.06087282180253949, 0.09818050238702979, 0.24701060407928058, 0.03676191112026572, 0.08062657753803901, 0.0555276893345373, 0.4177399213824953, 0.1458418063287224, 0.31932009969438824, 0.7136131078004837, 2.2205250646386827, 2.2440505794116428, 19.30082937649318, 34.48103652681623, 4.9705632243837625, 3.0112515602793013, 9.990603702408926, 6.292448452540806, 8.515955380031041, 16.853765896388463, 16.2463196345738, 22.69852454321725, 19.469738347189768, 11.182792118617467, 4.332441968577249, 22.433105094092234, 31.697720187050955, 29.133086238588604, 30.029676573617117, 36.93948636736189, 48.97404772894723, 27.75512296812875, 5.449064816747393, 9.887666140283857, 3.611313189779009, 9.710912653378077, 42.31555775233677, 45.134309904915945, 45.31986154828753, 46.45945296968733, 46.9643611907959, 44.2782883644104, 45.538295541490825, 46.350143909454346, 48.56864813395909, 39.848127365112305, 41.41535609109061, 22.060344661985123, 18.770087753023418, 57.87076786586216, 33.91713115147182, 46.78425693511963, 32.08890724182129, 34.883153097970144, 83.57016032082694, 22.291535547801427, 27.01425392287118, 29.712196009499685, 23.62203914778573, 21.337153570992605, 24.98973819187709, 19.03923143659319, 43.095569474356516, 51.73018618992397, 22.27542093821934, 33.86994593484061, 47.39693866457258, 47.07997226715088, 1.1563832632132938, 0.12994573930544512, 0.11651356864188399, 0.0637343939659851, 0.051718241069465876, 0.03526739702959146, 0.09671435784548521, 0.13803535593407495, 0.07678843741970402, 0.04946747934445739, 0.05401408126843827, 0.03745950958026307, 0.07324223699314253, 0.061039707490376065, 0.012515194198515798, 0.07191899192652532, 0.021856939486627067, 0.04016281345060893, 0.05283699603751302, 0.07781788360859666, 0.04731670314712184, 0.10853591029133115, 0.0591770542253341, 0.04877566200281892, 0.06641612042273794, 0.05091771223981466, 0.1092942071014217, 0.09266806353947946, 12.060509409223284, 76.29031031472343, 62.52750614711216, 33.80006095341274, 37.81615795407976, 38.32828882762364, 30.521716730935232, 34.196118695395334, 29.28227969578334, 30.884659358433314, 29.030216421399796, 28.79375011580331, 33.56996093477522, 32.02183280672346, 29.7450818334307, 41.23976469039917, 65.68710218157086, 66.203186580113, 51.269395555768696, 75.91884572165353, 24.030033894947596, 2.5117522946425845, 22.28549756322588, 49.76359237943377, 60.44454738071987, 56.846867425101145, 55.84280061721802, 55.55110829217093, 58.5729250226702, 59.87080683026995, 41.607977526528494, 47.209858417510986, 52.57800885609218, 17.072260686329432, 6.42311931507928, 9.931408524513245, 1.7238624010767256, 7.0396429640906195, 37.111982345581055, 36.13680962153843, 27.889683519090923, 38.4957160949707, 42.07346166883196, 31.46098463875907, 12.104032056672231, 16.610321862357004, 14.891453913279943, 10.371831383023943, 13.03106071267809, 11.517267107963562, 7.318087679999215, 8.166198696408953, 15.398434434618268, 25.75834618295942, 35.734943185533794, 22.60811632020133, 21.08040373665946, 4.068066920552935, 1.5499267343963896, 0.10186451327587877, 0.058413498768849034, 0.06583702471107244, 0.03202415909618139, 0.3507511174040181, 0.027052091966782297, 0.06754186430147716, 0.039042348574314795, 0.2630237319639751, 0.10091054053711039, 0.3144915359360831, 0.3184153682419232, 0.9101497445787702, 0.8772705431495393, 2.8497270047664642, 9.159175310816083, 6.0056233406066895, 4.399699228150504, 0.5732962457197053, 0.14370815296258244, 0.036639588219778876, 0.09895234275609255, 0.05096344889274665, 0.1805970620896135, 0.032456083954977136, 0.24052242508956365, 0.03099819379193442, 0.13071895710059575, 0.34387123371873585, 0.2569601801889283, 0.4619631969502994, 2.334060149533408, 6.7918854015214105, 25.075166293552943, 34.61435508728027, 11.061817032950264, 5.258245136056628, 6.880796722003391, 3.5750644377299716, 8.395282541002546, 14.79700357573373, 16.148455994469778, 15.561164719717842, 18.25480760846819, 14.196045194353376, 12.589735456875392, 39.21270070757185, 50.92576197215489, 44.291173798697336, 38.07639231000628, 40.925299644470215, 54.49403715133667, 33.55216312408447, 8.771048937525068, 2.3196804182870046, 0.31307087359683855, 10.581253562654767, 52.93356554848807, 58.61470454079764, 50.341790199279785, 50.6132424218314, 49.75585208620344, 46.602228028433665, 49.201889583042686, 48.16682686124529, 55.92283344268799, 43.242624623434885, 45.501859188079834, 19.114673239844187, 21.983905792236328, 58.98357745579311, 39.85723992756435, 49.35558026177542, 36.9175682749067, 39.4878181048802, 78.52272483280727, 26.538924183164323, 28.212307487215313, 26.622340781348093, 20.534707852772303, 14.525665998458862, 26.973869255610875, 28.497954879488262, 36.33040033067976, 67.54553685869489, 21.588674885886057, 33.76963826588222, 54.48668595722744, 48.00151532036917, 0.9510563952582223, 0.14736077482146875, 0.12691411269562586, 0.013046490510792604, 0.03314862393641046, 0.0027018505331527975, 0.0798432088590094, 0.10154890628265482, 0.0062358067953027785, 0.003886840272960918, 0.039322539432240386, 0.0167328177485615, 0.14717214208628449, 0.19695035314985684, 0.11733086407184601, 0.18439157919159957, 0.09807310386427812, 0.13142088800668716, 0.11485753607537065, 0.16422640053289278, 0.10484528368605034, 0.2084113388721432, 0.1619692537933588, 0.1773131833012615, 0.25749302016837256, 0.23121965570109232, 0.4018283566193921, 0.3932109075997557, 20.54049049104963, 89.98141602107457, 69.07439068385533, 50.202013288225444, 48.1546744619097, 48.16447837012154, 46.44216932569231, 69.99275493621826, 48.01733636856079, 34.156013693128315, 48.732177461896626, 43.48009320667812, 49.43696103777204, 41.279709884098594, 34.03699452536446, 52.5905225617545, 64.92954703739711, 60.72612312861851, 55.86128282546997, 82.24884223937988, 29.301706859043666, 3.001660657780511, 24.664046594074794, 56.43224062238421, 61.67999962397984, 57.38697869437081, 66.04089750562395, 57.96989434106009, 66.59555830274309, 54.732388155800955, 43.57335887636457, 49.37072386060442, 56.72181722096035, 20.62509002004351, 9.590767008917672, 24.80770754814148, 16.949729204177856, 11.4956408398492, 39.20831986836025, 47.68216916493007, 30.279561587742396, 39.103141512189595, 45.14603846413748, 24.915244817733765, 10.194813864571707, 23.082315240587505, 18.003864731107438, 13.229802642549787, 17.23570316178458, 15.9690500327519, 9.129526478903633, 7.8723567724227905, 11.793766328266688, 26.455830676215037, 42.22629771913801, 26.317386082240514, 24.255436931337627, 14.647422756467547, 2.5376232607024054, 0.18082931105579647, 0.15511272528341838, 0.31824383458920885, 0.16141147086662905, 0.5149057017905372, 0.1303515846707991, 0.3049787463886397, 0.14781607181898185, 0.7714861195002283, 0.23661566472479276, 0.3697925199355398, 0.6139020611132894, 1.0905942448547907, 1.7604252334151949, 4.819411243711199, 16.52424236706325, 15.511922836303711, 11.934112123080663, 0.8003771635038512, 0.16082069756729261, 0.13422563964767115, 0.16975507672343934, 0.20526778112564767, 0.2734313192112105, 0.13526690591658863, 0.31521374146853176, 0.09101037534752063, 0.7604584598115512, 0.9477998614311218, 1.609613823039191, 0.7177550484027181, 6.127646735736302, 17.63437168938773, 26.59990852219718, 39.96658720288958, 12.298516477857317, 5.577683789389474, 14.737238645553589, 5.785471839564187, 14.189680644444056, 24.36410675730024, 20.747230666024343, 26.314064843314036, 23.713828325271606, 13.699627671922956, 6.119569020611899, 29.070277997425624, 40.88328388759068, 36.849771227155415, 37.58359479904175, 46.202810832432334, 60.623567717415945, 32.82198388235909, 10.187081388064794, 20.5026592867715, 11.826962215559822, 12.846874390329633, 50.569590364183696, 49.792910303388325, 49.65026031221662, 51.69677577699934, 49.934691769736155, 50.42082595825195, 50.4711343901498, 55.65463645117623, 59.11555848802839, 46.19010605130877, 49.91834613255092, 30.695126397269114, 23.412596123559133, 67.0266592843192, 42.91546869277954, 56.542234080178396, 37.90016514914376, 42.10071250370571, 93.69654137747628, 30.515195846557617, 36.36213275364467, 40.76168346405029, 35.69353539603097, 33.53371565682547, 34.969039780753, 32.52378804343087, 59.288249015808105, 64.24072347368512, 30.716412203652517, 49.84231546946934, 57.24650001525879, 69.85709135872978, 4.147592527525766, 0.28706173066581997, 0.2471283163343157, 0.15618356210844858, 0.11651982473475592, 0.1537175215780735, 0.14284083593104566, 0.21375596922423157, 0.2438167668879032, 0.12175930930035454, 0.17437325391386235, 0.08537583412336451], [0.058476772159338, 0.02036472223699093, 0.10887998861393758, 0.07436139908220087, 0.08414508695048944, 0.01052031566255859, 0.03141427146536963, 0.04852588986977935, 0.1394359336367675, 0.0799666072375008, 0.054391736896442514, 0.034453697835228274, 0.051717060418533425, 0.11444715809609209, 0.08430347737989255, 0.05815391841211489, 0.12230078024523598, 41.384047508239746, 64.12986496516636, 45.51013796670096, 31.144150257110596, 43.46286514827183, 23.18892318861825, 37.04837506158011, 44.98494447980608, 24.61075391088213, 27.621580328260148, 29.192536762782506, 33.09833458491734, 33.16189670562744, 22.619759763990128, 22.975257396697998, 43.41777828761509, 38.80674525669643, 53.09458657673427, 63.170124190194265, 36.83992910385132, 3.3371985043798174, 20.86909338406154, 50.451380661555696, 46.50982046127319, 44.43222917829241, 55.06485945837838, 44.88433803830828, 54.53618144989014, 15.137779712677002, 38.16251870564052, 49.02964721407209, 43.15638358252389, 14.73196496282305, 3.4219986626080106, 10.90781021118164, 4.056612815175738, 38.87205137525286, 37.36882250649588, 29.160133838653564, 36.35309314727783, 24.45742280142648, 15.347304378237043, 7.680524826049805, 20.745246955326625, 19.750061682292394, 14.067985551697866, 17.126168285097393, 19.18042404311044, 10.023714474269322, 6.83164473090853, 3.7281606112207686, 10.885734047208514, 17.604808841432842, 36.424270493643625, 16.96462961605617, 9.65204838344029, 1.9197366791112083, 0.3808330717895712, 0.13726000753896578, 0.1150153497500079, 0.2107150602553572, 0.42024347132870127, 0.3542315406458718, 0.3721145753349577, 0.32981356233358383, 0.1346301008015871, 0.1288409893001829, 0.14851037599146366, 0.03165993506887129, 0.17555291418518337, 0.7330082984907287, 0.06198352934526546, 0.41401403131229536, 8.612067205565316, 3.3127623413290297, 1.2341143893344062, 0.20411623934549944, 0.10095098800957203, 0.03607015484677894, 0.03983542030411107, 0.004179639159701765, 0.06252443032073123, 0.05813661576913936, 0.07804845659328358, 0.14773852883705071, 0.3060690978808062, 0.10299852849649531, 0.12774226468588623, 0.2314219677022525, 1.821117205279214, 2.660041617495673, 17.887023823601858, 37.06198310852051, 9.708296656608582, 3.6451100962502614, 6.752360139574323, 7.901589580944606, 8.989157233919416, 12.044497285570417, 13.251580902508326, 23.48327146257673, 21.674295800072805, 22.36479561669486, 15.466398239135742, 4.771686673164368, 11.761010783059255, 20.346554109028407, 29.814508233751567, 38.24495908192226, 34.71922772271292, 48.40597690854754, 47.2127662386213, 17.39582439831325, 0.964357852935791, 6.24821274621146, 29.157649857657297, 18.379216841288976, 54.29380396434239, 41.707072734832764, 57.409775733947754, 42.729201384953086, 48.887987341199604, 39.27896915163313, 46.177456855773926, 42.71965456008911, 47.49434546061924, 13.513508881841387, 33.3536947795323, 56.81211600984846, 35.04388230187552, 46.11599309103829, 49.966042041778564, 60.70949608939034, 38.49692855562483, 18.2420802456992, 30.63009820665632, 28.99508285522461, 23.217356954302105, 20.261834723608835, 22.142220497131348, 36.81082657405308, 76.05034732818604, 25.00908371380397, 28.618497439793178, 39.31408534731184, 55.40329231534685, 9.582820006779261, 0.281738107757909, 0.11628615084503378, 0.044031776022166014, 0.06997596618852445, 0.03355873728703175, 0.08118742744305305, 0.04720062955415674, 0.19452145562640258, 0.039684096816927195, 0.08391525356897286, 0.06393260083028249, 0.04008012378056135, 0.07159907623593297, 0.011559274912412678, 0.06130958800869329, 0.10910806458975587, 0.05474328249692917, 0.0030696678274710265, 0.032285585068166256, 0.048081544427467246, 0.06482091852064643, 0.11794025637209415, 0.01990837520653648, 0.035724729632160494, 0.05748752238495009, 0.060837700829974244, 0.037618588722710095, 0.02231823473370501, 0.6940178849867412, 50.05906105041504, 72.90493951525006, 46.408032826014924, 27.180213383265905, 41.672067710331504, 25.457605566297257, 41.79488059452602, 23.946084022521973, 25.406166315078735, 30.506441116333008, 27.792570284434728, 31.717869962964738, 28.513883624758037, 31.438048635210308, 27.148336785180227, 64.90758378165108, 42.39186634336199, 56.69591086251395, 66.55100645337785, 43.32050003324236, 5.474017100674765, 20.10074942452567, 55.693633215767996, 53.43732384272984, 49.39467082704817, 60.756333896092, 49.32810361044747, 60.50797053745815, 23.1543003150395, 39.195476123264854, 53.408130986349924, 47.711386340005056, 14.716857842036656, 1.9666854398591178, 2.1696863983358656, 9.748018639428274, 44.006064891815186, 38.67745665141514, 34.36897250584194, 52.2209826196943, 35.46761471884591, 31.483201503753662, 13.00513698373522, 16.491794279643468, 16.147415501730784, 11.790368659155709, 12.387343117168971, 16.333175591060094, 15.431770154408046, 9.39015427657536, 11.265565139906746, 18.814278296061925, 23.316631078720093, 34.8744261605399, 19.864757333483013, 18.503289086478098, 1.712703377008438, 0.3785255913223539, 0.21007695235311985, 0.04700334889015981, 0.010181998102260488, 0.28616174895848545, 0.28701852155583246, 0.153967873858554, 0.10267300810664892, 0.10580255410500936, 0.05740276657577072, 0.09786453577024595, 0.033394491100417714, 0.13843596300908498, 0.48011731995003565, 0.14187821187078953, 1.4021519039358412, 6.2908764226096014, 8.85353968824659, 2.9343825536114827, 0.13804497756063938, 0.08226342113422495, 0.017541913082823157, 0.0829320495416011, 0.04902204146076526, 0.18460206075438432, 0.170877997896501, 0.24518488347530365, 0.1251121408173016, 0.053935947961040905, 0.1569108837949378, 0.2005474301321166, 0.2919034037206854, 1.5551492827279227, 7.041026958397456, 22.84922228540693, 34.70578990663801, 15.42905514580863, 4.744992562702723, 7.467400993619647, 4.614655213696616, 5.697885887963431, 9.599360193525042, 13.438927786690847, 18.963291100093297, 16.825637851442607, 19.164729799543107, 16.33300883429391, 10.268121702330452, 18.952385902404785, 34.44168540409633, 47.47995226723807, 49.10275615964617, 39.4554568699428, 53.871266637529644, 53.6169729913984, 23.327555383954728, 4.712739893368312, 4.706810908658164, 31.897553852626256, 31.12346199580601, 56.499349798474995, 44.993282318115234, 59.82325335911342, 45.05197375161307, 56.59145859309605, 45.865833623068674, 50.28645127160208, 48.324700355529785, 50.75000034059797, 15.4200085912432, 36.61015565054757, 58.345288140433176, 40.616952487400596, 52.700609820229666, 46.94549683162144, 57.14237431117466, 43.85562597002302, 22.00154205730983, 28.22997154508318, 22.65683708872114, 20.77743101119995, 14.319753527641296, 32.295223576681956, 32.16864129475185, 75.19728919437954, 33.21958065032959, 26.674619027546473, 47.57426711491176, 60.584636960710796, 7.0629889113562445, 0.316862093018634, 0.1386364565363952, 0.04593886315290417, 0.06565755898399012, 0.07715074119291135, 0.027783632444749986, 0.06508062101368393, 0.12687941241477216, 0.09255190512963704, 0.14531013342951024, 0.10253222566097975, 0.010175980344813849, 0.1828271352819034, 0.10054141070161547, 0.23471150547266006, 0.20733544017587388, 0.27593644335865974, 0.15346217527985573, 0.11524614665125098, 0.17332227102347783, 0.26835134465779575, 0.15522427644048417, 0.11944048372762543, 0.23346533519881113, 0.1887535144175802, 0.22060784298394406, 0.15490921906062535, 0.1691901148962123, 1.2996489299195153, 71.93899399893624, 78.66560758863176, 62.3649183000837, 48.142904213496614, 58.07801178523472, 33.0735364641462, 58.84935910361153, 65.22457449776786, 32.63040467670986, 40.494268144880024, 39.209240504673545, 48.881365707942415, 41.66773203441075, 32.00039413997105, 30.049715178353445, 58.240377289908274, 45.28468976702009, 64.29430103302002, 70.9589992250715, 43.07672595977783, 5.950016473020826, 22.78024056979588, 59.42196709769112, 55.69600602558681, 53.524693965911865, 66.32365444728306, 57.23761674336025, 64.78626128605434, 20.56942626408168, 41.982457637786865, 54.42540284565517, 49.93500096457345, 18.26934150287083, 7.673642635345459, 22.736927236829484, 10.859795553343636, 46.04268612180437, 42.82687221254621, 35.93998800005232, 47.31781605311802, 32.959276812417166, 25.412782737186976, 10.982449497495379, 21.70211638723101, 22.953785726002284, 15.675981964383807, 21.178724220820836, 27.468329123088292, 16.870458943503245, 10.873090931347438, 9.449154904910497, 16.43354753085545, 27.268300907952444, 44.177403994968955, 22.112384932381765, 24.98539556775774, 6.159290569169181, 2.801092220204217, 0.29407767419304165, 0.197685749403068, 0.36655251522149357, 0.7018093126160758, 0.6540988013148308, 0.7676041935171399, 0.6988835238984653, 0.5331879864845956, 0.230881039585386, 0.719212433057172, 0.2922676684600966, 0.2792625677372728, 3.249871156045369, 0.2194154126835721, 2.5938771792820523, 15.166923931666783, 25.496650968279155, 6.080451965332031, 0.41933219879865646, 0.19241594789283617, 0.22276738924639566, 0.17001783262406076, 0.16491172090172768, 0.18140264600515366, 0.1940558584673064, 0.5892047435045242, 0.22067531650619848, 0.46393789670297075, 0.37542854036603657, 0.564858147076198, 0.4898845872708729, 3.2921702691486905, 17.160646983555385, 25.496343510491506, 44.127943243299214, 17.66557604925973, 5.072127648762294, 11.65755992276328, 11.47023822580065, 10.524054254804339, 18.996413162776403, 18.086405856268748, 26.40297051838466, 23.400902305330547, 25.076837335314067, 17.90197113582066, 6.445591960634504, 13.990428021975926, 27.6617773941585, 36.83685105187552, 46.48698173250471, 41.17325305938721, 59.82469858442034, 54.94340147290911, 24.160166706357682, 5.248325714043208, 8.953069158962794, 35.367866379874094, 26.071833269936697, 60.47277791159493, 46.04962042399815, 60.960187094552175, 46.97598205293928, 58.80549512590681, 45.23631293433053, 55.74304533004761, 53.61536795752389, 58.87075955527169, 16.932629687445505, 38.804570470537456, 66.33090141841343, 43.60839516775948, 53.45426007679531, 58.36383983067104, 71.74577849251884, 46.27118110656738, 27.104005541120255, 38.320499897003174, 39.62018128803798, 37.71100044250488, 28.80050723893302, 35.171409538814, 51.15466342653547, 94.26586982182094, 35.10992840358189, 44.70105845587594, 49.63877493994576, 72.2800463267735, 21.372202021735056, 0.37205109159861294, 0.23672908863851003, 0.15925554798117705, 0.2127147979502167, 0.18698644638061523, 0.2840920543032033, 0.11655894906393119, 0.4125848465732166, 0.2651127241551876, 0.1631126667239836, 0.22743448881166323, 0.0955527126789093], [0.046195885432618, 0.09781648192022528, 0.026402079167642763, 0.06749810557812452, 0.028228858286248784, 0.03338952422408121, 0.11519140244594642, 0.03913434095946806, 0.0513953194687409, 0.07713577271039997, 0.04720918248806681, 0.02116351232065686, 0.015003014854820711, 0.04699247536648597, 0.06248268684638398, 0.018701526037018214, 0.1137355173538838, 7.323807784489222, 73.17785085950578, 53.982934611184255, 41.40264783586775, 53.390388761247905, 60.246370860508506, 17.71895558493478, 52.92961202348982, 25.526889528547013, 24.92524674960545, 27.882288898740494, 26.64026713371277, 38.8249043737139, 27.168298959732056, 17.13026945931571, 26.367112602506364, 43.892982959747314, 69.90530490875244, 59.13732719421387, 67.83719444274902, 26.602663482938492, 7.288161788667951, 45.56525107792446, 61.993488448006765, 55.42568635940552, 52.69260549545288, 59.84187453133719, 48.09714685167585, 27.47175805909293, 60.0241049357823, 41.56743826184954, 40.77391229357038, 8.19737786906106, 6.514319632734571, 7.601833002907889, 45.57842833655221, 48.56672695704869, 40.30079208101545, 41.95685005187988, 14.60354140826634, 8.16580959728786, 7.701200059482029, 20.14505113874163, 19.83369541168213, 15.945309775216238, 14.38022369997842, 17.520026922225952, 22.95383436339242, 12.933292610304695, 10.156938365527562, 6.88848750931876, 18.991731813975743, 24.49865514891488, 38.48734698976789, 16.78514896120344, 7.913578697613307, 0.8418124201042312, 0.2326759004167148, 0.3438207778547491, 0.035188910883984396, 0.17457297391125134, 0.27981638801949366, 0.19751281796821527, 0.16148135997354984, 0.25174837985209053, 0.7725854005132402, 0.1278285879109587, 0.05579619581944176, 0.1353097486176661, 0.15746592544019222, 1.0174275423799242, 0.084995148836502, 0.4917522413390023, 3.5410328124250685, 3.65359080689294, 0.33226798634443966, 0.16233037013028348, 0.18356280294912203, 0.03269344228985054, 0.04982299776747823, 0.1213625291628497, 0.13656900104667458, 0.16717975134296076, 0.34048968659979956, 0.0682167284456747, 0.16238096170127392, 0.08291596826165915, 0.018329025578818152, 0.06494320410170726, 0.5395074273858751, 2.370110443660191, 15.62667407308306, 35.49562290736607, 19.704330376216344, 3.572909410510744, 5.561280395303454, 5.3830082927431375, 8.67539916719709, 12.021562150546483, 14.538821543966021, 12.148132273129054, 24.27534352030073, 20.969430582863943, 21.66948069844927, 21.826899085726055, 15.868101392473493, 12.86291778087616, 14.862321853637695, 33.2852133342198, 48.830963475363596, 43.87521641595023, 45.86545147214617, 53.22940247399466, 14.572625398635864, 2.9988381692341397, 10.425001604216439, 41.445657185145784, 48.892326491219656, 54.08575405393328, 51.84396641595023, 54.66646017347063, 26.691209588732036, 37.03410346167428, 44.43778773716518, 50.74180146626064, 39.08472531182425, 37.21441616330828, 49.08164405822754, 53.81072003500802, 41.61363683428083, 44.20724303381783, 54.814505440848215, 41.536737646375386, 27.021768399647303, 22.974738018853323, 28.88237612588065, 26.66827184813363, 18.167885644095286, 21.72195175715855, 27.644634451184952, 65.87514822823661, 52.92104836872646, 19.647270032337733, 42.114893777029856, 53.72087287902832, 40.13837446485247, 0.10371618105896882, 0.12241258924560887, 0.1487030799367598, 0.05921526253223419, 0.04838089711431946, 0.01490785540746791, 0.049512839410454035, 0.017959342737283026, 0.09768093776490007, 0.004364441140621368, 0.05277827222432409, 0.04488979373127222, 0.08166342654398509, 0.04033835045993328, 0.10387164021709136, 0.01252116700301745, 0.09297509385006768, 0.012135894819428878, 0.021175262850842307, 0.10736463671284062, 0.044524121031697304, 0.01706573586644871, 0.010947848703446133, 0.13429396812404903, 0.10334659660501139, 0.06272305787674018, 0.06669313912945134, 0.011819395552655416, 0.062056051168058596, 0.14442379027605057, 9.187614287648882, 82.16040556771415, 63.0138453074864, 37.880849157060894, 54.061209542410715, 51.35288511003767, 23.440011978149414, 49.286546434674946, 21.68503771509443, 34.86206878934588, 23.359822818211146, 27.110199860164098, 30.132607187543595, 33.78214502334595, 17.96598141533988, 32.7928535597665, 40.453259876796174, 69.87730366843087, 63.07387774331229, 67.77591133117676, 29.239992959158762, 8.513877868652344, 49.097941058022634, 63.6161082131522, 54.979910782405305, 66.64179161616734, 63.261048316955566, 54.56597185134888, 24.32401738848005, 57.80766780035836, 47.027436937604634, 43.59527696881975, 7.987306901386805, 3.6192193712506975, 10.776809743472509, 49.662325859069824, 50.01371710641043, 45.876047474997385, 59.27586037772042, 29.505761555262975, 17.100195918764385, 14.224290490150452, 17.038056441715785, 22.187807628086635, 13.70140814781189, 10.850105421883718, 14.800171954291207, 25.854207004819596, 17.201620510646276, 16.00279917035784, 13.160206011363439, 25.45278525352478, 26.793051072529384, 38.242356981549946, 21.989603315080913, 15.5295695236751, 0.5329957168017114, 0.12181572270180498, 0.09053850173950195, 0.12275032326579094, 0.10834121823843036, 0.24211584244455608, 0.3933810298996312, 0.24897637431110653, 0.41020441002079416, 0.4559963771275112, 0.44307831887687954, 0.6418511899454253, 0.040750465488859584, 0.3813778268439429, 0.09166942962578364, 0.11503476942224161, 1.033314272761345, 5.862734070846012, 7.9638332809720715, 1.520251521042415, 0.1677897950368268, 0.12655640260449477, 0.0450530662201345, 0.1429479494690895, 0.048986628718141995, 0.3226640016904899, 0.2364096072103296, 0.32179482547300203, 0.13049305922218732, 0.18039561861327716, 0.11413736614797797, 0.11141234915703535, 0.18975990398653916, 0.7892584715570722, 7.839427522250584, 19.343962056296213, 33.3249500819615, 21.31406991822379, 6.372655417237963, 7.813572406768799, 5.047990041119712, 4.9913665652275085, 8.306225742612567, 12.316032886505127, 14.943183251789637, 21.340749263763428, 20.819092409951345, 18.18047056879316, 20.032655341284617, 17.10015422957284, 17.149017436163767, 21.60145436014448, 49.149281297411235, 59.40925189426967, 46.817010743277415, 47.15928595406668, 58.180754797799246, 20.96648975781032, 9.347231779779706, 6.264709940978459, 35.36951657703945, 57.09567199434553, 57.9097854750497, 51.999348981039866, 58.37793772561209, 29.28167520250593, 45.18558761051723, 50.95150852203369, 55.071408135550364, 42.83777741023472, 43.606949942452566, 51.91043288367135, 60.6107621874128, 43.40395137241909, 49.974386828286306, 55.86727564675467, 42.88284690039498, 32.84399230139596, 27.02788802555629, 24.601596185139247, 20.849023512431554, 15.978351933615548, 20.221821784973145, 36.718714305332725, 55.38067592893328, 60.69571781158447, 21.19083145686558, 40.7848140171596, 60.77300262451172, 35.57288687569754, 0.14618264803928988, 0.15423383244446345, 0.14512709182287964, 0.08606473715709788, 0.11923399195075035, 0.09910127440733568, 0.09653150622865983, 0.028658985027245114, 0.17102334009749548, 0.08171496806400162, 0.05677960679999419, 0.037734804808029106, 0.1570812232260193, 0.14263270209942544, 0.2359917110630444, 0.08700139368219034, 0.13815693583871635, 0.16092927674097673, 0.09737772082111665, 0.2678017041512898, 0.12895534959222588, 0.15627924911677837, 0.20187361325536454, 0.2722131588629314, 0.22385593583541258, 0.12663959099778108, 0.26938874327710693, 0.1116583248866456, 0.22089178274784768, 0.21262190650616372, 18.9697060244424, 99.17867006574357, 66.81379427228654, 60.5638062613351, 69.39127717699323, 76.97404779706682, 26.859048536845616, 79.06876986367362, 37.847185134887695, 36.646581581660676, 38.99188000815255, 39.68330914633614, 49.948164326804026, 35.77814013617379, 25.022709131240845, 37.38037388665335, 52.4044463293893, 80.4809912272862, 67.5589816229684, 75.5653908593314, 31.411582946777344, 10.479288748332433, 52.182076181684224, 74.60312094007219, 64.94635472978864, 66.01144409179688, 68.543395451137, 56.064225809914724, 29.920874731881277, 65.96513434818813, 51.82935782841274, 47.559630734579905, 9.896012663841248, 16.08185751097543, 14.488582594054085, 51.63013213021414, 57.72523089817592, 47.10960633414132, 52.55976288659232, 21.93510685648237, 15.950347219194684, 10.486970850399562, 22.596043825149536, 26.245830059051514, 18.990435974938528, 15.428191832133702, 21.412677015577042, 31.911683014460973, 19.167774847575597, 18.7709858076913, 9.753766536712646, 26.916685581207275, 31.081175259181432, 46.90371036529541, 22.765256779534475, 22.448573521205358, 0.8648696371487209, 1.7906992946352278, 0.7688890674284526, 0.2629183961876801, 0.5320312199848038, 0.8531774474041802, 0.6070113480091095, 0.45313358360103195, 0.6074004471302032, 1.639332462634359, 0.5034251064062119, 0.7028183756130082, 0.27198104560375214, 0.3090117685496807, 1.7974254765680857, 0.2536802776157856, 2.4379541746207645, 14.864609548023768, 15.93524704660688, 3.3230024661336626, 0.315098661929369, 0.21618520601519517, 0.17188031625534805, 0.25816143144454273, 0.5482046178409031, 0.23936769419482776, 0.3569136810089861, 1.0402772362743105, 0.154899054606046, 0.64172910792487, 0.33487366938165253, 0.22171567353819097, 0.42790505449686733, 1.3255560483251299, 18.75662735530308, 23.909956863948278, 41.2807104246957, 26.171024015971593, 8.233491999762398, 8.702651739120483, 8.496734057153974, 13.288112793649946, 17.993459803717478, 20.5729490007673, 16.916183301380702, 29.588333947317942, 26.972609894616262, 27.706080845424108, 27.85440230369568, 19.42174366542271, 19.115295103618077, 17.178460427692958, 41.52195187977382, 55.1308673449925, 51.05020768301827, 53.391194752284456, 62.165095056806294, 20.356557777949742, 4.597374175276075, 11.759217279297964, 48.09628527505057, 64.04465225764683, 58.55872985294887, 52.26020867483956, 58.14559691292899, 31.489854403904506, 45.377100808279856, 52.72282668522426, 56.2709173474993, 47.71232434681484, 45.25264467511858, 58.61540630885533, 64.26325648171562, 48.50036818640572, 53.7062851360866, 65.95267622811454, 48.400727544512065, 32.67810753413609, 32.649609497615266, 38.75013133457729, 37.72975015640259, 28.013993740081787, 31.23560244696481, 44.85358878544399, 79.5573741367885, 64.50954232897077, 29.11739025797163, 56.646592548915315, 63.8459198815482, 60.19425242287772, 0.14128142675118788, 0.18337525586996758, 0.15756454371980258, 0.2788658690239702, 0.23718712691749844, 0.11386658996343613, 0.19455460884741374, 0.16229488274880818, 0.17911012044974736, 0.13495171282972607, 0.22636681395981992, 0.18313415880714143, 0.13363288502608026], [0.06610847943063293, 0.039565359974013906, 0.038640754230852635, 0.06410916921283517, 0.049345034307667186, 0.10186778381466866, 0.07341350601719958, 0.054483311982559304, 0.07900398996259485, 0.03238514651145254, 0.02427066835973944, 0.12919412606528827, 0.016415375318112116, 0.1314091222094638, 0.047932232796613655, 0.06768695544451475, 0.11528783584279673, 0.2050318137875625, 37.19740697315761, 69.88771206992013, 57.66408327647618, 45.019935607910156, 73.30103547232491, 40.52349921635219, 18.614109379904612, 58.76056112561907, 17.76387916292463, 40.68940135410854, 23.421279634748185, 37.48150839124407, 28.47303863934108, 45.28256709235055, 107.44413593837193, 57.508176122392925, 51.65143878119332, 64.74403708321708, 65.54933329990932, 57.480727263859336, 10.64124517781394, 21.65349463054112, 67.39446217673165, 50.79856824874878, 47.47373710359846, 48.422096729278564, 64.37976387568882, 55.830672536577495, 44.844907011304585, 44.36443560464041, 41.51868622643607, 1.3857752169881548, 5.797310267175947, 59.30117266518729, 54.907236099243164, 48.46299730028425, 42.81579678399222, 17.57580532346453, 13.054406659943716, 18.24457117489406, 17.86904535974775, 20.05964388166155, 18.299352509634836, 13.812727843012128, 14.639736311776296, 18.281474794660294, 22.910166672297887, 20.91678581918989, 12.66580433504922, 12.802993042128426, 23.32934628214155, 25.04401057107108, 35.636098112378804, 17.48285927091326, 9.7641966513225, 0.16140138783625194, 0.13372828704970224, 0.10446710897875683, 0.22900366889578955, 0.10867850442550012, 0.03804030502215028, 0.1835945448172944, 0.022702769010460803, 0.31715644150972366, 0.364555722368615, 0.23320043512753078, 0.6577918774315289, 0.021721412294677327, 0.562216040279184, 0.16566180065274239, 0.46777476796082085, 0.29922468800629887, 3.40264076420239, 4.533170648983546, 0.5464893355965614, 0.08976727205195598, 0.07434576563537121, 0.025302178991426314, 0.2040016890636512, 0.10297544473516089, 0.12091054341622762, 0.34269883377211435, 0.0868457852463637, 0.09055020646857363, 0.13905436625438078, 0.1378223637917212, 0.054440866224467754, 0.16858583875000477, 0.40722005016037394, 3.015653895480292, 18.11335791860308, 36.307457378932405, 24.136214528764995, 4.885559831346784, 6.890531148229327, 4.900831537587302, 7.102405607700348, 11.995960644313268, 19.14238265582493, 14.0134083202907, 14.18762310913631, 22.938138382775442, 20.708152260099137, 16.267185074942454, 15.993507691792079, 18.069945573806763, 17.605564458029612, 13.523707100323268, 26.735480036054337, 36.19743960244315, 38.80247906276158, 39.52805164882115, 51.94565677642822, 9.557096907070704, 8.999150480542864, 51.258476461683, 36.76053898675101, 30.754745415278844, 45.763292108263286, 46.914226463862825, 42.73232807431902, 41.98209980555943, 49.591169357299805, 53.3129997253418, 49.90817049571446, 48.00629915509905, 53.441916601998464, 49.71303033828735, 48.25020177023751, 50.383215359279085, 53.23637499128069, 50.98975488117763, 31.72150387082781, 25.13413565499442, 29.367283957345144, 23.986654554094585, 16.95703523499625, 27.43273871285575, 46.4650045803615, 76.55227824619838, 28.989729268210276, 41.761841910226, 45.874921866825645, 54.75962162017822, 2.264061825616019, 0.14083443502230303, 0.03853227344474622, 0.05718200520745345, 0.14831919196460927, 0.058104690696511946, 0.0991742101364902, 0.06972878266658102, 0.1188729570380279, 0.03716898463400347, 0.036748018115758896, 0.02132826571219734, 0.049978321218597035, 0.018638656374865344, 0.16800273289637907, 0.055697526649705, 0.062375335821083615, 0.053810062751706154, 0.011207971888195192, 0.07798650634608098, 0.07457323092967272, 0.01489408453926444, 0.05943825628076281, 0.012120915310723441, 0.1273247485182115, 0.15981893560716084, 0.0903519724628755, 0.12206549144216947, 0.21909966319799423, 0.02315849348503564, 0.15626204146870545, 0.2791681428040777, 42.61794682911464, 78.02116216932023, 59.18269198281424, 45.102514948163716, 72.97686031886509, 33.33572326387678, 27.991625751767838, 37.66029248918806, 22.111332280295237, 37.49395956311907, 21.754827158791677, 35.193584714617046, 29.91134180341448, 51.24109206880842, 86.98746504102434, 58.87132930755615, 55.876686981746126, 72.79180894579206, 61.4981027330671, 64.15918636322021, 13.050658106803894, 24.639825173786708, 75.18252427237374, 55.50504520961216, 56.431080273219514, 52.099625383104595, 62.376883098057334, 47.81230545043945, 48.53476524353027, 46.81728172302246, 43.750659533909385, 0.901453856910978, 7.583777240344456, 63.727314131600515, 56.92870678220476, 54.84921169281006, 56.83683770043509, 31.727260453360422, 17.897694519587926, 20.97731157711574, 18.057768855776104, 22.05920515741621, 17.127768107822963, 11.889667970793587, 13.580599818910871, 16.73186843735831, 28.774425438472203, 25.33287845339094, 18.88833567074367, 19.20356501851763, 27.227329117911204, 28.252285684858048, 40.29410443987165, 20.54180543763297, 18.112402541296824, 0.2442453024642808, 0.22291298929069722, 0.09690253596220698, 0.10217615083924361, 0.19635028392076492, 0.04072794830426574, 0.18228980340063572, 0.08578279228614909, 0.2490396409162453, 0.5729614294001034, 0.11659727272178445, 0.48616512971264975, 0.07566719901348863, 0.6377549011792455, 0.12586725529815468, 0.810104424399989, 0.3702281394175121, 3.266726617302213, 9.1122020142419, 1.0609537724937712, 0.275557386555842, 0.04690150078386068, 0.03032250522768923, 0.33203277896557537, 0.2486305928656033, 0.0916866237031562, 0.32145097106695175, 0.35404372215270996, 0.13519907955612454, 0.39787217176386286, 0.25360976425664766, 0.24633519032171794, 0.19749806661690983, 0.8982653394341469, 6.162893210138593, 22.914128882544382, 38.025444643838064, 24.652585540499004, 7.953906910760062, 9.068761008126394, 6.221289779458727, 6.855636426380702, 8.0583861044475, 10.373529349054609, 15.469580514090401, 16.936793395451136, 20.20135760307312, 20.65290539605277, 15.446302311761038, 14.23490994317191, 18.78306872504098, 21.542491946901592, 23.011962992804392, 42.87000662939889, 54.30097450528826, 39.185470717293875, 39.829502718789236, 47.24593693869454, 15.654789958681379, 17.490566560200282, 31.923317773001536, 44.07577616827828, 37.33587414877755, 53.894821030753, 47.85732977730887, 43.525965213775635, 42.24914687020438, 56.224892480032786, 58.40694645472935, 55.74491092136928, 49.557494912828716, 58.35590498788016, 53.90024062565395, 48.968704564230784, 50.74335438864571, 60.15557874952044, 51.1520265851702, 35.93516247613089, 28.30091438974653, 19.54439847809928, 21.986261231558665, 13.129875387464251, 32.59845685958862, 48.226567472730366, 73.83451816013881, 39.78353343691145, 37.36125591823033, 54.49512801851545, 50.4361641066415, 1.6268041006156375, 0.13372777136308805, 0.0407030664251319, 0.08055953827819654, 0.12637910140412195, 0.06133024940001113, 0.10970580644373383, 0.01568443703997348, 0.040695785744381804, 0.09356047958135605, 0.03166203174207892, 0.008423625491559505, 0.03176203762580242, 0.04853782190808228, 0.3172629986490522, 0.17362041931067193, 0.17948087198393686, 0.3489028422960213, 0.14910429769328662, 0.17816265486180782, 0.23668419676167624, 0.1811988955097539, 0.20327294245362282, 0.10490878777844564, 0.1899091816906418, 0.15908381076795713, 0.2139881503369127, 0.240780485527856, 0.3581620497362954, 0.16739089787006378, 0.29209765472582405, 0.3251764811575413, 61.97058718545096, 86.58001572745187, 74.69845022474016, 60.07935701097761, 90.97331305912563, 53.975003242492676, 31.996763706207275, 79.24508735111782, 27.38803400312151, 57.08320345197405, 33.14409194673811, 54.08217920575823, 38.04579244341169, 61.2457719530378, 120.65142468043736, 68.94172177995954, 64.71745327540806, 77.94756684984479, 70.36963217599052, 65.55151503426688, 14.246063538960048, 24.84127082143511, 83.24483176640102, 59.57959393092564, 62.79530361720494, 56.23422738483974, 69.08881514413017, 58.40223557608468, 56.47201558521816, 49.530455998011995, 46.96670273372105, 1.9307237352643694, 7.167403834206717, 62.84652573721749, 59.624646050589426, 54.094324656895225, 49.6850951058524, 22.82037510190691, 20.050701550074987, 22.62660895075117, 21.519057410103933, 28.59934994152614, 22.133900029318674, 15.573188577379499, 17.682229144232615, 22.422495194843837, 32.86010864802769, 30.04879454204014, 21.479709761483328, 17.106421504701885, 29.763470241001674, 30.750083174024308, 46.96044588088989, 22.03112574986049, 25.971358844212123, 0.41859498407159534, 1.675650696669306, 0.2656533537166459, 0.3314033970236778, 0.48486342813287464, 0.0896302554756403, 0.4090513347515038, 0.18868376101766313, 0.8743764013051987, 1.3134027804647173, 1.4718512381826128, 1.8449586459568568, 0.228143965027162, 0.7924675622156688, 0.2323067502251693, 1.2645192721060343, 1.7401398590632846, 8.990673678261892, 11.541554536138262, 0.8434664170656885, 0.2428383193910122, 0.20996248349547386, 0.1673432918531554, 0.42034802000437466, 0.26987831986376215, 0.2771474655185427, 0.7871045842766762, 1.1375616788864136, 0.22572201570229872, 0.4815896323748997, 0.4012775218912533, 0.19041108047323568, 0.28728209169847624, 1.058048556957926, 19.091999530792236, 29.359488078526088, 45.39871665409633, 31.328381742749894, 10.516055141176496, 9.769889831542969, 8.02588677406311, 12.706525121416364, 18.277875627790177, 28.166251352855138, 22.251731055123464, 18.5485965524401, 26.945333003997803, 27.775463819503784, 22.36540010997227, 18.56239914894104, 24.460085698536464, 26.090487446103776, 17.138193879808696, 34.91583742414202, 49.179773466927664, 49.38307080950056, 49.63073934827532, 58.0962473324367, 16.82529044151306, 12.474361487797328, 59.46238476889474, 46.233184882572715, 42.65389680862427, 51.92325578417097, 47.22999429702759, 48.07191794259207, 46.93147536686489, 59.870424679347444, 61.4988739831107, 57.71238715308053, 53.31241955075945, 65.27429580688477, 59.80891922542027, 57.68467773709978, 58.99478490012032, 66.55300753457206, 58.23780298233032, 40.16342619487217, 32.50644186564854, 39.20426212038313, 37.41352374213082, 25.208620343889507, 42.41374969482422, 62.417856625148225, 91.52791827065604, 39.991392271859304, 57.95877027511597, 55.580318519047324, 74.9060207094465, 8.072517003331866, 0.4416000082024506, 0.1820163537881204, 0.3084555598241942, 0.1843811704644135, 0.2372572331556252, 0.211219795314329, 0.2977504756833826, 0.20913879626563617, 0.10749642178416252, 0.10089222687695708, 0.13555791601538658, 0.22391971812716552, 0.14266506821981498], [0.023163197429052422, 0.048120203960154734, 0.08689481618681125, 0.055299660856170316, 0.02542281403605427, 0.08521227325711932, 0.04897503934002348, 0.04837780638730951, 0.009060428910223501, 0.0325243785046041, 0.10482112105403628, 0.0743682590712394, 0.00777317164465785, 0.040658798800515275, 0.07303639660988535, 0.05566037007208381, 0.1100272216967174, 0.0761184858690415, 3.8515554070472717, 72.75648430415562, 49.9489529473441, 45.31116240365164, 45.17106587546212, 91.03578431265694, 27.40311506816319, 52.21253708430699, 36.24821356364659, 25.208361523491995, 29.031877040863037, 26.238167933055333, 39.077690260750906, 18.379192522593907, 36.356362274714876, 49.048490728650776, 57.046127864292686, 64.96401705060686, 59.44189453125, 54.38936601366316, 25.697462592806133, 10.77099323272705, 38.70919254847935, 53.521570750645225, 52.24633659635271, 40.48180307660784, 53.25607660838536, 49.90132304600307, 52.26448876517159, 53.275225843702046, 25.157714366912842, 1.5296389716012138, 48.6140650340489, 60.26795196533203, 53.29815142495291, 51.30893080575125, 24.34484461375645, 17.01335906982422, 25.013818911143712, 18.252045699528285, 21.071975571768625, 18.522521700177872, 19.82787455831255, 13.395244462149483, 12.911330223083496, 25.581809827259608, 29.03444787434169, 26.924448456083024, 15.908215079988752, 19.888497591018677, 24.534186499459402, 20.381611245019094, 34.04359878812517, 23.08496424130031, 13.875891310828072, 0.24443982488342694, 0.7730405618037496, 0.36842394194432665, 0.09728731960058212, 0.04008749945621405, 0.05807927956006356, 0.25982891768217087, 0.09760694352111646, 0.04988810998786773, 0.1623863356986216, 0.1815500102405037, 0.44749539185847553, 0.06689643500638859, 0.9944672201360975, 0.02412460182261254, 0.6854284458926746, 0.14454755506345204, 2.9534811973571777, 6.886825152805873, 0.6799228127513612, 0.2049248902393239, 0.08004509338310786, 0.1784903329930135, 0.0717768252694181, 0.16274678707122803, 0.17905480627502712, 0.11013313422777823, 0.08319359086453915, 0.21263459511101246, 0.11685393537793841, 0.09550039084362132, 0.6880106244768415, 0.20208528903978212, 0.6624007586921964, 2.4680735298565457, 19.923209054129465, 34.00588049207415, 32.225248268672395, 6.9318903003420145, 6.581379737172808, 3.3979902480329787, 2.660175370318549, 6.581942541258676, 15.56584780556815, 20.03141508783613, 19.23603916168213, 20.38524341583252, 22.24845150538853, 22.69276969773429, 18.083487612860544, 16.826857260295323, 20.386775493621826, 16.780769859041484, 17.531821489334106, 19.062146595546178, 27.262665918895177, 26.438640832901, 33.24066495895386, 53.43388448442732, 8.04808713708605, 9.053100637027196, 34.18365362712315, 22.739815950393677, 39.129801750183105, 48.35479300362723, 56.17460836683001, 62.19082423618862, 54.50632504054478, 49.148482254573274, 53.79227951594761, 50.484523568834575, 47.43694986615862, 46.36300502504621, 49.19033472878592, 53.481886114392964, 50.95770978927612, 49.84031786237444, 38.072702816554475, 26.410915783473424, 33.81757041386196, 19.83680646760123, 22.30678163255964, 29.565533433641704, 63.19483893258231, 42.863909585135325, 30.34437438419887, 44.10288803918021, 61.53981276920864, 16.95062552179609, 0.4963828900030681, 0.14492127858102322, 0.11004607818488564, 0.0425739367492497, 0.10853633098304272, 0.03469448955729604, 0.0586507213967187, 0.025802793646497384, 0.024277504600052322, 0.020180238743445704, 0.02416950896648424, 0.027581167773210576, 0.04888346764658179, 0.048468618121530326, 0.06128914374858141, 0.07416997078273978, 0.06795046451900687, 0.06873624878270285, 0.015799368997769694, 0.011394917615689337, 0.03472159363861595, 0.021564367060948695, 0.021141044329851866, 0.02604328002780676, 0.08126703995679106, 0.06492607787783657, 0.06679122136639697, 0.019448593092550124, 0.2657214786325182, 0.10831271298229694, 0.13173731602728367, 0.11500662378966808, 4.449662855693272, 78.7862491607666, 59.582359313964844, 46.58533695765904, 54.34990719386509, 75.50497627258301, 26.93910915510995, 48.15241282326834, 21.49883815220424, 27.48022617612566, 28.770244359970093, 26.115836211613246, 33.641965116773335, 29.897841453552246, 40.92666843959263, 57.53469739641462, 62.10984298161098, 68.30034051622663, 61.9818571635655, 59.28651891435896, 29.045356546129497, 12.74406623840332, 41.4902993610927, 58.366243907383506, 54.74500608444214, 44.10121004922049, 54.33832107271467, 50.56940276282174, 53.154896940503804, 57.08288383483887, 22.009935481207712, 2.1981735782963887, 51.96359355109078, 59.760552815028596, 57.10488183157784, 62.2298036302839, 39.91388511657715, 23.488710165023804, 23.749052218028478, 18.859971387045725, 20.09272425515311, 17.740171909332275, 16.400171858923777, 12.11570850440434, 11.576827066285269, 23.080341952187673, 36.748153822762625, 29.687665394374303, 21.22909344945635, 24.50001699583871, 25.152821098055156, 27.41426866395133, 42.535805225372314, 25.51834671837943, 24.15382821219308, 3.6555762546403066, 2.1957230355058397, 1.1241929105349948, 0.1131298705669386, 0.034484306549919505, 0.05360427665125046, 0.15226751938462257, 0.04741410345637372, 0.07826611027121544, 0.3110149124903338, 0.8240137951714652, 0.5163260655743735, 0.16343355950500282, 0.49138648382255007, 0.09394683063562427, 0.16195195115038327, 0.31701492624623434, 0.8669632162366594, 3.394722423383168, 2.0055354237556458, 0.821530248437609, 0.1717023365199566, 0.39683919719287325, 0.050418174759085686, 0.1896099206060171, 0.11938852151589734, 0.25652314935411724, 0.08776750043034554, 1.0332187350307191, 0.2672764094812529, 0.037327144361500225, 0.8673399931618145, 0.47191909700632095, 1.95829462153571, 5.919160825865609, 24.976262160709926, 36.44659505571638, 30.94982303891863, 7.694350004196167, 8.313588227544512, 4.821135699748993, 4.530098242419107, 5.064656163964953, 11.40511884008135, 11.598250099590846, 18.985403742109025, 18.366727454321726, 20.210192237581524, 19.9207215990339, 16.984308651515416, 16.903197118214198, 22.98856840814863, 16.849006380353654, 26.042933974947246, 33.3682165145874, 46.954189028058735, 28.936903851372854, 36.71945081438337, 40.01446723937988, 13.277655754770551, 21.265887635094778, 28.879235540117534, 29.823926516941615, 41.39065524509975, 51.69814804622105, 55.534290177481516, 62.985593932015554, 57.6526152747018, 54.91082831791469, 57.76657962799072, 59.49937697819301, 54.33857468196324, 50.81989574432373, 56.259449345724924, 56.266831806727815, 58.712229456220356, 52.426923751831055, 46.588953495025635, 27.002162320273264, 22.090782982962473, 21.181197779519216, 16.997913224356516, 36.74085821424212, 62.19316577911377, 52.2787047794887, 33.46877779279436, 47.33831671306065, 64.95614474160331, 13.1005539894104, 0.43822057811277254, 0.13387799901621683, 0.05529875840459551, 0.05838737517063107, 0.11922173760831356, 0.09548105259558984, 0.020614718286586658, 0.07549735491297074, 0.04649357231599944, 0.08914974411683423, 0.04979372576677373, 0.06543765256979636, 0.022155145449297767, 0.07393161500138895, 0.20275127116058553, 0.2166032242987837, 0.19500578035201344, 0.09165672066488437, 0.1020643621949213, 0.16321466410798685, 0.12405857949384622, 0.15628865361213684, 0.12308869510889053, 0.1474863173706191, 0.15156657913965838, 0.2888331956097058, 0.16079489966588362, 0.22366769665053912, 0.32991572256599155, 0.2439622719373022, 0.31800417602062225, 0.29020530198301586, 9.900981494358607, 99.6358128956386, 63.71097891671317, 67.4803488595145, 63.70696980612618, 111.93293625967843, 42.15677056993757, 79.36312334878104, 50.31411899839129, 33.78420863832746, 41.81755951472691, 38.99267210279192, 54.53595910753523, 28.191032103129796, 45.20363903045654, 60.61677932739258, 71.08697809491838, 74.33506638663155, 70.22495678492955, 60.778686250959126, 30.19169466836112, 14.043168323380606, 49.74891778400966, 63.491401944841655, 59.65480818067278, 49.49580533163888, 59.48602254050118, 53.676164695194785, 61.176804133823936, 56.623114585876465, 29.960166794913157, 1.2913395357983453, 51.18973445892334, 63.45898859841483, 59.208414213997976, 57.116839681352886, 30.810657569340297, 23.567956107003347, 32.51550579071045, 21.689107622419083, 28.375333070755005, 24.53259709903172, 24.72482943534851, 15.425124202455793, 14.692561728613716, 26.72372715813773, 41.95700291224888, 33.63122320175171, 23.60147421700614, 23.75532817840576, 34.241584232875276, 28.39444409097944, 46.730297224862234, 27.025633335113525, 30.348428658076696, 4.002785989216395, 2.0684326887130737, 1.1947855225631168, 0.1873683123184102, 0.1380481802459274, 0.10075466747262649, 0.25589862572295324, 0.2996838390827179, 0.16743122999157223, 0.5737499956573758, 0.8866469200168337, 1.1179516911506653, 0.1865710336714983, 0.721930915755885, 0.10516920273325273, 0.6359935871192387, 0.6509636981146676, 5.240380883216858, 12.416838220187596, 2.2982936458928243, 0.6176502885563033, 0.3221465237438679, 0.3642821099076952, 0.2979633999722344, 0.3094751536846161, 0.4551151772694928, 0.14603938215545245, 0.24647757411003113, 1.4178337710244315, 0.3690633119216987, 0.19030674892876828, 2.649400451353618, 0.4541943781077862, 2.4335970027106146, 19.94498818261283, 35.16327319826399, 42.48755693435669, 41.27414090292794, 14.343543291091919, 9.833834971700396, 6.703675849097116, 9.108212879725865, 11.562178526605878, 22.359688690730504, 28.36710466657366, 29.378880500793457, 23.07686264174325, 23.075153384889873, 29.45994860785348, 25.439010449818202, 19.68996844972883, 27.905115468161448, 21.280350310461863, 20.96401446206229, 26.07896385874067, 41.08831480571202, 37.92482778004238, 45.02148853029524, 57.73371464865548, 13.47215928350176, 15.838013955524989, 42.19290467670986, 28.005718435559952, 47.95411123548235, 53.22981589181082, 59.039447920663015, 68.37110097067696, 60.52962807246617, 55.67734316417149, 62.828967639378135, 61.81180695125035, 61.170099122183665, 57.236282689230784, 59.706544467381065, 60.855818203517366, 65.54464326586042, 58.595124517168315, 51.54163292476109, 36.233865533556255, 47.2282190322876, 28.721758093152726, 32.33334139415196, 44.33784832273211, 79.09447125026158, 56.6152457509722, 43.64016580581665, 57.87167113167899, 76.86860888344901, 33.41199711390904, 0.5231060960463115, 0.24119743172611507, 0.3479090870491096, 0.246429832386119, 0.36305605141179903, 0.26628403844577925, 0.13990428564803942, 0.10774642801178352, 0.28779376138533863, 0.21857664840562002, 0.1065423676211919, 0.2190405899392707, 0.23536957587514604, 0.17288524018866674], [0.055139221251010895, 0.05950510555080005, 0.08608970046043396, 0.10150252841413021, 0.026301116549542973, 0.027001373170475875, 0.04655475921130606, 0.04292526861120548, 0.11888916045427322, 0.037043540472430844, 0.12300397322646209, 0.03494414294670735, 0.13590744297419274, 0.050937589923185964, 0.007909035559610596, 0.27183448203972405, 0.07440498817179884, 0.04898378226373877, 0.09179130808583327, 28.554659128189087, 70.11660657610211, 43.66444281169346, 41.23900038855416, 73.62007590702602, 75.41899231501988, 26.41871166229248, 49.27979278564453, 25.614855459758214, 37.24841717311314, 19.161014250346593, 37.77620233808245, 22.295299734388077, 35.41109112330845, 46.36822312218802, 48.03126055853707, 56.89113439832415, 60.77318327767508, 57.23645986829485, 57.83898680550711, 15.244582210268293, 37.361752714429585, 57.644572734832764, 47.62865761348179, 52.889812741960796, 31.752423354557582, 46.85522583552769, 49.37936394555228, 52.712564195905415, 7.145457514694758, 20.89699387550354, 74.80865560259137, 46.455530711582725, 52.23428494589669, 27.851147072655813, 16.959206547055924, 18.88396351678031, 19.27298273359026, 21.442472628184728, 19.222846269607544, 19.592804840632848, 17.43603536060878, 11.402083345821925, 17.847033466611588, 33.49575069972447, 33.92679262161255, 32.930480003356934, 24.76079331125532, 22.84298975127084, 26.97095969745091, 18.44881694657462, 38.42813096727644, 31.251809120178223, 10.740044219153267, 2.0808059104851315, 1.8169199505022593, 0.028190850147179196, 0.06217356664793832, 0.10394060651638679, 0.07061841671488114, 0.07800175302795001, 0.2096586355141231, 0.14244146378976957, 0.17082744703761168, 0.04497859700183783, 0.1294202275042023, 0.008963744455416287, 0.5414185619779995, 0.2665884292551449, 0.33947272545525004, 0.10117463315171854, 0.501944977257933, 7.807246940476554, 3.071104862860271, 0.8586825920002801, 0.1944945856396641, 0.11415461450815201, 0.06402314454317093, 0.115213400551251, 0.3865196295082569, 1.1829189764601844, 3.062780703817095, 0.36161866996969494, 0.4899381643959454, 0.30574758084756987, 0.11309631701026644, 0.07907742102231298, 1.0919329673051834, 4.804542532988957, 24.91568602834429, 31.46246807915824, 36.696473121643066, 13.21969301359994, 10.986203261784144, 9.18881458895547, 8.423905645098005, 10.744242668151855, 10.758272818156652, 18.595873832702637, 20.641850812094553, 24.883764266967773, 22.971632174083165, 18.371292420795985, 20.214866638183594, 19.79184467451913, 21.16332527569362, 23.939540556498937, 13.407728637967791, 15.136087826320104, 7.978443605559213, 18.05391434260777, 20.357216119766235, 38.56921761376517, 48.77312667029244, 2.651225222008569, 10.81977653503418, 46.633630411965505, 52.69387354169573, 47.202430793217246, 47.91726841245379, 50.02977786745344, 52.79747118268694, 48.74938814980643, 50.74871839795794, 52.69702802385603, 50.399019036974224, 48.388154779161724, 48.8597081729344, 50.101434639522004, 50.951348713466096, 48.44355624062674, 42.4933899470738, 32.55538845062256, 32.39734819957188, 16.99303732599531, 26.564401490347727, 43.408029964991975, 57.21520185470581, 25.175649404525757, 36.17283255713326, 52.18450457709176, 37.7291248185294, 0.14564572327903338, 0.08367975442005054, 0.0831323191523552, 0.010061242617666721, 0.023813366291246245, 0.06188779483948435, 0.046167078228401284, 0.031238242518156767, 0.007604213880508074, 0.00714012815816594, 0.08431676309555769, 0.016841213717790585, 0.02997821316655193, 0.0346399862319231, 0.01568310202232429, 0.02122798841446638, 0.048591561881559234, 0.028792273053633313, 0.10333171633205243, 0.03965920815244317, 0.03184827264132244, 0.0782457949327571, 0.08293491974473, 0.1205109812851463, 0.018552548584661314, 0.13743642664381436, 0.04577422680865441, 0.2013106191796916, 0.0018174738589940326, 0.024150905232610445, 0.25438646972179413, 0.05113051439236317, 0.03251748798148973, 0.1304686726736171, 33.16632270812988, 82.00206307002476, 49.282634598868235, 44.06828253609793, 80.91089017050606, 63.56406620570591, 31.107786859784806, 39.61135012762887, 21.058747938701085, 40.874584742954795, 19.777658190046036, 34.73643146242414, 29.919929776872905, 39.171612535204204, 50.73627070018223, 55.34847797666277, 58.944889886038645, 67.1603912625994, 55.868988377707346, 60.68064716884068, 16.113739320210048, 41.400716236659456, 63.84393964494978, 51.80622380120413, 53.515501499176025, 36.72335222789219, 48.071810245513916, 54.11426946095058, 50.872173990522114, 10.253563489232745, 28.36016689028059, 74.32836137499127, 49.91232899257115, 63.91857719421387, 44.7543511390686, 24.21758314541408, 21.704285962241038, 20.21379314150129, 20.072907992771693, 19.536927427564347, 17.989226613725933, 18.02185709135873, 12.15449856008802, 16.173021350588115, 35.66956411089216, 36.573872157505576, 35.859576497759136, 28.821464742933, 24.44028159550258, 26.92659718649728, 22.444048506872996, 43.99228661400931, 31.083009583609446, 23.24695106915065, 8.260467512266976, 3.2397741207054684, 0.6850791903478759, 0.043401925891105614, 0.07396926012422357, 0.029586630607289926, 0.14244660708521092, 0.3705960953874247, 0.22977193338530405, 0.06967109361929552, 0.14564227632113866, 0.3158673063984939, 0.05670210453016417, 0.5540954960244042, 0.224631148523518, 1.121299528649875, 0.2699133594121252, 0.35208579578569954, 3.470036119222641, 0.342235231505973, 1.1887282133102417, 0.25630525818892885, 0.02374492246391518, 0.08330864326230117, 0.04723068865548287, 1.090111779315131, 1.9868108970778329, 4.835686096123286, 0.411424524549927, 0.6718175219638007, 0.13449625298380852, 0.23598435574344226, 0.10594878518687827, 3.1813519299030304, 4.605989073004041, 28.455758469445364, 35.736409255436485, 37.78142738342285, 15.26135516166687, 13.199359978948321, 11.586125493049622, 11.958251902035304, 12.932193926402501, 11.26546699660165, 11.810224873679024, 13.789159553391592, 21.357360669544764, 20.365767615182058, 17.84193001474653, 19.46055977685111, 18.0722211088453, 20.43321204185486, 24.092300176620483, 12.974963562829153, 19.41771718433925, 18.791175535746984, 38.75130558013916, 23.977041721343994, 39.29246602739607, 34.43361854553223, 9.435112595558167, 17.7943365914481, 22.978889567511423, 56.82443169185093, 46.07483891078404, 54.93460505349295, 53.90202283859253, 58.24239921569824, 53.60254853112357, 59.87297466823033, 58.83207893371582, 57.90508501870291, 54.277955123356406, 55.18533079964774, 53.94278791972569, 58.40045683724539, 52.026026589529856, 49.73198502404349, 24.2299040385655, 34.7349271774292, 17.035263265882218, 29.111977611269268, 47.898025376456125, 58.654274531773154, 33.81054925918579, 37.61382293701172, 60.203847885131836, 31.856774875095912, 0.8514034854514259, 0.13482923725886004, 0.059387488290667534, 0.06641632398324353, 0.03931588300370744, 0.03677115276721971, 0.10485723947307893, 0.09806203695812396, 0.08503991857703243, 0.045999870236430845, 0.09903751925698348, 0.04882636892476252, 0.015058463040207113, 0.04111250463340964, 0.029680492356419563, 0.08006563263812236, 0.17192531669778482, 0.26295628558312145, 0.17176504672638007, 0.10987206109400306, 0.10837150125631265, 0.23090315982699394, 0.1689385005405971, 0.27698483424527304, 0.16827342765671865, 0.2039473248379571, 0.1747799270919391, 0.21910682852779115, 0.11367439491940395, 0.21803405109260762, 0.5292497692363602, 0.1796997402395521, 0.13830489718488284, 0.1292173591043268, 52.19732747759138, 88.37770925249372, 61.03538049970354, 59.36583954947335, 92.54139641353062, 89.48259789603097, 41.36105939320156, 64.8181048801967, 36.41649545942034, 50.29598420006888, 30.809337411608013, 54.784576075417654, 32.365428175245015, 42.9811361176627, 55.3620617049081, 60.789205823625835, 64.23822907039097, 72.71186992100307, 61.19582135336739, 65.55710833413261, 17.44595217704773, 48.77894231251308, 67.53167520250592, 59.40794563293457, 64.85329055786133, 37.891608442579, 53.612425395420615, 55.85624190739223, 57.83033977236067, 9.412960869925362, 26.57363043512617, 82.38481153760637, 52.46704612459455, 62.5889699118478, 31.386468682970317, 20.94339394569397, 23.398882116590226, 26.819098131997244, 23.78543472290039, 29.510712146759033, 23.383345944540842, 22.869792427335465, 11.843628338405065, 17.36072904723031, 40.56255504063198, 42.023858479091096, 39.748973097120015, 31.591030597686768, 28.28602613721575, 39.67157016481672, 23.400275230407715, 48.054040227617534, 31.366343225751603, 31.85519415991647, 9.090305634907313, 3.9222029532705034, 0.8109198063611984, 0.11668584868311882, 0.2338686835552965, 0.10471901510443006, 0.27175045226301464, 0.4759832503540175, 0.29350946896842545, 0.27613788683499607, 0.10053603670426778, 0.357511931764228, 0.16289938959692205, 0.9074642115405628, 0.6073373705148697, 1.612071965421949, 0.28441704543573515, 1.4543092080524989, 11.359885198729378, 6.029629801000867, 3.7361962028912137, 0.4525595158338547, 0.17377433819430216, 0.25194838483418736, 0.11784813845796244, 1.0349929141146796, 6.771159793649401, 7.153223429407392, 1.1933931687048502, 2.1383378633431027, 0.46181115082332064, 0.4087592932794775, 0.32524360184158596, 5.434673794678279, 12.343192526272365, 39.98805366243635, 40.933359554835725, 47.68644230706351, 18.585029431751796, 14.234545162745885, 13.71357878616878, 13.419286966323853, 17.934316737311228, 17.28695481164115, 25.288017409188406, 28.497068984167917, 31.88150351388114, 24.56067303248814, 20.294658013752528, 23.947331224169048, 25.544404200145177, 25.67755774089268, 32.33356721060616, 16.040296861103602, 17.000794989722117, 13.139335359845843, 27.243791137422832, 30.22897870200021, 49.620136397225515, 51.38110521861485, 6.443509238106864, 17.491054671151296, 52.94435262680054, 58.483835220336914, 51.080029351370676, 54.8140538079398, 56.095114026750835, 62.49005535670689, 55.18393421173096, 61.612518719264436, 60.70064408438546, 62.3110419682094, 59.14791624886649, 56.78614016941616, 59.684782709394185, 64.15242576599121, 59.99809782845633, 51.7720490864345, 45.82232747759138, 44.22231715066092, 25.344956159591675, 39.56938648223877, 59.634644508361816, 71.6627892085484, 36.62565360750471, 50.71017674037388, 61.02463858468192, 58.70434325081961, 1.199098942535264, 0.20147905871272087, 0.15039681190890924, 0.1094101280240076, 0.12230335867830686, 0.21636399999260902, 0.1708892887192113, 0.24350010816540035, 0.1860680085207735, 0.0834456801946674, 0.33434780474220005, 0.09081246025328125, 0.08052620863808052, 0.11061717396868126, 0.14920780142503126], [0.012057473134648587, 0.058097233596657, 0.058754985087684224, 0.07789923995733261, 0.05039840564131737, 0.027577447704970837, 0.029188313587967838, 0.04198078179199781, 0.01893295397582863, 0.05329251695158226, 0.010163732787727245, 0.038274308001356463, 0.023698570040453757, 0.11041399344269719, 0.02426675321268184, 0.009757198709329324, 0.06271803671760218, 0.08066188850040946, 0.12250527712915625, 2.2036385536193848, 59.59002317701067, 54.17580270767212, 43.58199201311384, 37.82441241400582, 83.23497922079903, 43.52771963391985, 35.08483498437064, 31.163205691746303, 32.48662560326712, 25.393645661217825, 28.881551027297974, 37.32801226207188, 60.70946829659598, 49.85058729989188, 55.22267041887556, 53.88789715085711, 63.04976749420166, 54.82498679842268, 62.68231201171875, 26.21183773449489, 47.28522900172642, 56.736787114824565, 38.40507337025234, 42.083685943058555, 39.83694076538086, 35.223090239933555, 64.58251925877163, 25.16756170136588, 7.005902511732919, 61.91073540278843, 39.600802762167795, 41.083426748003276, 34.01030649457659, 13.449912020138331, 24.60795726094927, 20.139951160975865, 23.193217175347463, 21.291450057710918, 23.6751320702689, 21.231395040239605, 15.222182955060687, 12.938621010099139, 22.653303929737636, 36.95585632324219, 36.91062702451433, 38.19691228866577, 25.3231839793069, 29.747802053179058, 25.602348702294485, 24.49578206879752, 45.65639059884207, 32.31033590861729, 23.969073874609812, 2.667423209973744, 2.9830357943262373, 1.2637926425252641, 0.3504618172134672, 0.28806183700050625, 1.2273790878908974, 0.9084769114851952, 0.3725015031439917, 0.20422637914972647, 0.17678084543773107, 0.016294117717604552, 0.09853465695466314, 0.14254518465272017, 0.5340680192623819, 0.27224836125969887, 0.687088631093502, 0.5151954633849007, 0.3184279075690678, 1.6238580644130707, 1.7513019229684557, 1.0725959134953362, 0.2857302821108273, 0.421441275626421, 0.40064016037753647, 0.11679510639182158, 0.813133676137243, 1.0643915023122514, 0.8805302253791264, 0.07443453837186098, 0.3711614507649626, 0.1517995609236615, 0.16149456426501274, 0.5742734989949635, 0.9176780091864722, 4.4392553227288385, 19.58299572127206, 37.10231045314244, 39.40791382108416, 16.487210205623082, 8.306350810187203, 6.769615990774972, 7.4945745297840665, 8.5146986246109, 9.994613681520734, 17.25627851486206, 21.791748149054392, 23.042408261980327, 27.70065256527492, 24.897632871355327, 18.316071612494333, 20.988352264676774, 21.56147963660104, 20.91554730279105, 27.276848929268972, 17.375488758087158, 17.339618682861328, 4.538614562579563, 19.28868739945548, 19.136886630739482, 52.22905642645699, 30.38095317568098, 1.5168608001300266, 3.07326249565397, 36.7907532283238, 56.63008362906319, 48.62344857624599, 51.352846894945415, 50.14926603862217, 50.22880901609148, 47.89465550013951, 53.771177836826865, 51.4712997845241, 51.3909021786281, 49.029272011348176, 55.45454222815377, 46.27635751451765, 51.87782151358468, 34.62018115179879, 34.01597275052752, 17.574578966413224, 21.980209350585938, 29.426642417907715, 45.091279711042134, 44.528027466365266, 26.239687851497106, 37.494185379573274, 50.007863249097554, 5.692496257168906, 0.4896405317953655, 0.06995732683156218, 0.15325862834496157, 0.09779702153589044, 0.06894614680537156, 0.09078958683780261, 0.07088380533137492, 0.036733965655522685, 0.007574645020732922, 0.01754912591007139, 0.024705931610826935, 0.08634077198803425, 0.04807640113202589, 0.015248122059607079, 0.029017529716449122, 0.0195467533610229, 0.06054973056805985, 0.06818577367812395, 0.016328203924266354, 0.0885187608322927, 0.02817928621412388, 0.0386235533681299, 0.06893839793545858, 0.02029995946213603, 0.01705274192084159, 0.003263272103920047, 0.05652006376268608, 0.06896479294768401, 0.0796952610835433, 0.037800341112805266, 0.1249525493809155, 0.09802863267915589, 0.12961618841758796, 0.09964256893311228, 3.422922990151814, 68.63487543378557, 66.21570028577531, 44.072830132075715, 51.38103573662894, 81.30957085745675, 41.69107450757708, 36.45677416665213, 24.637106691087993, 30.397826875959122, 25.645596027374268, 26.49642378943307, 40.63590717315674, 57.4835239137922, 51.08215202604021, 64.52782998766217, 56.863980838230674, 65.02477209908622, 58.54782118116106, 64.41244125366211, 27.59277135985238, 50.920074871608186, 62.685883385794504, 44.063637665339876, 48.125551087515696, 43.43726798466274, 38.281715052468435, 67.47399820600236, 25.599866458347865, 14.30318033695221, 58.08830206734793, 45.99948917116438, 48.84465490068708, 54.47451966149466, 20.16056646619524, 24.287238836288452, 19.33673766681126, 22.80099310193743, 20.949070623942784, 22.311075619288854, 21.191083329064504, 15.82941382271903, 12.828150732176644, 20.333682571138652, 40.10044077464512, 41.099873134068076, 40.37098625728062, 27.814184393201554, 26.88074254989624, 23.07514991079058, 30.417948859078543, 51.20580216816494, 36.54683324268886, 32.30261645998274, 10.244815707206726, 3.3198972727571214, 0.7682069497449058, 0.5300735650318009, 0.22334639674850873, 0.43563454544969965, 0.08661886278007712, 0.3939925256584372, 0.38146812628422466, 0.03206166511933718, 0.3336359400834356, 0.018807340180501342, 0.20948706114930765, 3.2321578093937466, 0.11364635106708322, 0.8284224271774292, 0.4033888785966805, 0.10401996118681771, 1.0490166587488992, 1.673974443759237, 0.5122171289154461, 0.43104056481804165, 0.23033889010548592, 0.3064036156449999, 0.24358677065798215, 1.2692830221993583, 1.238985185112272, 2.1939746950353896, 0.21333051419683866, 1.5143419695752007, 0.4143331599022661, 0.7075284942984581, 1.2203510935817445, 1.9292852410248347, 3.7817650948251997, 28.215095451899938, 39.319741180964876, 43.015088490077424, 18.618134123938425, 10.072795680591039, 10.351617336273193, 10.03608226776123, 12.086302859442574, 12.751276731491089, 14.464380281312124, 15.266376972198486, 17.796245609010967, 24.064529963902064, 21.888385432107107, 20.17614953858512, 19.77705717086792, 19.128402880259923, 19.871436289378575, 25.958852086748394, 16.19214279311044, 19.27492128099714, 11.74643085684095, 42.72092260633196, 23.918027196611675, 45.42022827693394, 22.3931234223502, 10.34308842250279, 3.217459546668189, 24.407566002437047, 60.73686504364014, 45.89127792630877, 56.632282733917236, 55.59858880724226, 54.917561122349326, 53.22304139818464, 61.09745570591518, 55.39759479250227, 56.66814586094448, 50.63931901114327, 59.71923882620675, 52.55457258224487, 58.09635155541556, 37.14981181280953, 32.511034624917166, 23.462345225470408, 19.154911994934082, 34.22484254837036, 54.28244365964617, 52.179015500204905, 31.312202862330846, 44.97183322906494, 48.69527905327933, 1.3021779656410217, 0.1708618894751583, 0.047628177862082205, 0.06263881775417499, 0.017346025111951997, 0.017747612670063972, 0.1162940761340516, 0.09358223341405392, 0.04522901713582022, 0.03414592452879463, 0.01967851129094405, 0.062266885569053035, 0.009365082651908909, 0.03434679464304021, 0.020371580529691916, 0.05599102357934628, 0.09312414085226399, 0.1610357253147023, 0.1550929799143757, 0.1232219458158527, 0.15302127679543837, 0.1349626508142267, 0.20033534722668783, 0.1321824485702174, 0.17623201917324746, 0.14720739876585348, 0.1129853833200676, 0.1960497879024063, 0.11207614639507872, 0.2250573227980307, 0.09168475773185492, 0.16032592340239457, 0.25621436163783073, 0.2284548697727067, 0.312339792826346, 6.9770088621548245, 94.22772421155656, 71.90881102425712, 63.83913149152483, 55.42813907350813, 99.03334849221366, 57.24654517854963, 50.39741400309971, 45.5284812109811, 45.46319941111973, 35.71333081381661, 44.715041705540244, 50.41273478099278, 72.36251449584961, 58.393154280526296, 69.33075836726597, 62.000117029462544, 72.01190144675118, 60.95554569789341, 71.8404129573277, 29.512532574789866, 56.88001380647932, 69.85916192190987, 50.27633816855294, 48.70305756160191, 48.75713539123535, 39.421136243002756, 72.94145924704415, 30.028881004878453, 10.34155808176313, 67.4050373349871, 48.33671031679426, 49.18814952032906, 40.14881413323538, 14.599983930587769, 30.846850735800608, 28.8907139641898, 30.516317980630056, 28.567327431270055, 29.24055576324463, 26.05316867147173, 20.42586084774562, 12.851812822478157, 25.745155027934484, 41.38597910744803, 44.79073190689087, 45.38411154065813, 32.063323974609375, 37.1658239364624, 34.44860928399222, 28.55507775715419, 53.98099953787667, 35.58717932019915, 35.53143392290388, 8.480384077344622, 4.50342150245394, 2.273235184805734, 1.1324913395302636, 0.5172654837369919, 1.2977835557290485, 2.132363063948495, 0.7475687371832984, 0.34360375521438463, 0.1925662433994668, 0.6334272048303059, 0.17159226456923143, 0.2938628228647368, 5.6021197353090555, 0.3880740718117782, 0.8875155534063066, 0.7344532523836408, 0.5057246344430106, 5.581185681479318, 4.550599770886557, 1.0116456640618188, 0.5527451027716909, 1.839813722031457, 0.4411979354918003, 0.8253188080021313, 5.9281335558210095, 1.8501956335135867, 5.559264983449664, 0.6210317271096366, 1.1694177580731255, 0.3619063416762011, 0.42081018377627644, 0.9401402324438095, 2.3760967510087148, 8.911472899573189, 40.88975613457816, 48.06008863449097, 49.63222278867449, 21.231666019984655, 10.93514095033918, 8.403507471084595, 11.78790031160627, 13.749973450388227, 15.92321971484593, 21.227297340120586, 32.6070031438555, 32.04483481815883, 31.10948916843959, 28.66716957092285, 23.403893504823955, 24.008524009159633, 26.010272230420792, 25.151120526450022, 34.82907179423741, 19.968379293169292, 17.93470409938267, 7.319932426725115, 30.916624546051025, 31.50585957935878, 60.04054437364851, 33.650042397635325, 6.196738753999982, 6.8885743618011475, 43.87983349391392, 66.48029463631767, 53.0532899584089, 57.58580139705113, 57.922333921704976, 56.24472958700997, 56.12843063899449, 64.54262270246232, 58.415200914655415, 60.440857887268066, 57.292219161987305, 67.49625328608921, 56.14485618046352, 62.770185879298616, 42.54006447110857, 49.30392735345023, 27.4411130292075, 30.878795078822545, 46.07606874193464, 61.17977796282087, 60.84250545501709, 42.61001893452236, 52.88742256164551, 68.88421848842076, 10.704409514154706, 1.2507513080324446, 0.17374327486114843, 0.3214642432119165, 0.2624240427144936, 0.1728660919304405, 0.20292908804757254, 0.237752726567643, 0.24615391290613584, 0.1587195053164448, 0.14045882517738, 0.16022950357624463, 0.24799238996846334, 0.11867067217826843, 0.10472927455391202, 0.1668373490018504], [0.027335695855851685, 0.05714357976934739, 0.041403918460543664, 0.11107044893183879, 0.10939230969441788, 0.05650328019899981, 0.03786387234660132, 0.10563372780701943, 0.06053875187145812, 0.09221569781324693, 0.06453710767839636, 0.07339959604931728, 0.00844120972656778, 0.10533885005861521, 0.13004370619143757, 0.08802328099097524, 0.1225196620715516, 0.053038381838372776, 0.1766212811427457, 0.3506896421313286, 13.3804943050657, 62.635536738804404, 50.504485743386404, 39.40087877001081, 71.55780192783901, 80.41287803649902, 44.10155051095145, 30.18682745524815, 37.17190708432879, 24.710597787584575, 26.78356330735343, 36.312209946768625, 62.55946091243199, 66.53246171133858, 55.71421725409371, 63.44304248264858, 58.64066995893206, 62.38219152178083, 56.165464537484304, 63.352201734270366, 56.9290646144322, 57.393364088875906, 63.17142350333077, 48.06886420931135, 52.59097072056362, 52.98619467871529, 32.93762622560774, 4.416581613676889, 35.15986858095442, 53.310536588941304, 28.495196444647654, 34.80149786812918, 10.801129307065692, 22.003286055156163, 21.899971553257533, 23.744021722248622, 22.59746125766209, 22.303017445972987, 22.05507619040353, 19.15588821683611, 17.91529083251953, 18.33773783275059, 25.902113097054617, 37.698156697409495, 40.98268829073225, 38.07559674126761, 27.958449840545654, 28.886527674538748, 25.14517113140651, 24.699786390577042, 44.60057013375418, 41.205812317984446, 25.553365639277867, 11.755999394825526, 1.222792299730437, 1.20534548163414, 0.2081503200211695, 0.07767379669738667, 0.8021699615887233, 0.07369040937295981, 0.48810139724186485, 0.1402332665664809, 0.42133157008460587, 0.09072851868612425, 0.22259303288800375, 0.3634917251765728, 1.1040011197328568, 1.3034482917615344, 1.4195058984415871, 1.8900822017874037, 0.6128425151109695, 0.6884542235306331, 1.1748334446123667, 0.35528584835784777, 0.07886708873723235, 0.04702678209702883, 0.1300217487982341, 0.3082791678607464, 0.8684949683291572, 0.16458615979978017, 0.1568437631108931, 0.37973351936255184, 0.40634319292647497, 1.0508274244410651, 0.5642367718475205, 3.1095818153449466, 2.396389399256025, 6.498064756393433, 16.89677177156721, 31.831521647317068, 40.875484534672324, 28.371733903884888, 14.311309729303632, 5.803512402943202, 7.356320142745972, 12.18327626160213, 15.821008239473615, 16.600304297038488, 17.84563340459551, 23.148039988109044, 26.760408435549053, 26.25476196834019, 26.29287110056196, 18.808539084025792, 19.41136826787676, 18.647999218532018, 21.858968496322632, 19.460544143404277, 18.252389635358536, 18.67362764903477, 6.218351125717163, 20.669624498912267, 26.76450960976737, 59.21719673701695, 11.744487966809954, 0.3748306424490043, 1.9128996516977037, 29.24881717136928, 31.114634309496196, 33.973481042044504, 46.289809226989746, 62.85332107543945, 53.01402568817139, 46.24584797450474, 49.4604355267116, 52.17845617021833, 50.062000138419016, 51.308298519679475, 42.86417361668178, 57.181343282972065, 31.045253072466167, 26.74283470426287, 15.862558467047554, 28.788591078349523, 37.7969913482666, 50.14699745178223, 30.11504908970424, 23.725549936294556, 43.31335033689226, 16.25279709271022, 0.05217420303129724, 0.09812955119247947, 0.01664136988776071, 0.03848338160397751, 0.08766428846865892, 0.041387949138879776, 0.016604756138154438, 0.10625121503004006, 0.08225027112556355, 0.12242915907076427, 0.05647064605727792, 0.05903842952102423, 0.072048877099795, 0.059772027656435966, 0.08331494006727423, 0.074575897572296, 0.10727690213492938, 0.034125381881105046, 0.13829969960664, 0.07785031079713788, 0.08662275078573398, 0.05151538624029074, 0.11739955895713397, 0.051476326371942244, 0.07414996757039002, 0.07123953410025154, 0.12444663367101125, 0.01920622038388891, 0.07048108122710671, 0.03406629165900605, 0.06648377714944737, 0.036314413882791996, 0.14763769853327954, 0.08803503321749823, 0.0725590947217175, 0.6106072579111371, 16.4339314188276, 78.66960975102016, 56.059775488717214, 48.87104068483625, 84.1099658693586, 79.53961454119, 43.54727186475481, 28.380481685910905, 28.519098247800553, 28.160555567060197, 23.999169996806554, 39.51782737459455, 64.96093899863106, 67.80755342755998, 58.1670321055821, 67.51943247658866, 62.42872360774449, 61.69404193333217, 59.4754821232387, 62.47232355390276, 62.88999366760254, 62.75603934696743, 62.61818708692278, 55.23512853894915, 52.511396476200645, 55.24881649017334, 27.79652033533369, 11.747739723750524, 36.815221309661865, 50.93790742329189, 39.813799789973665, 56.200650215148926, 18.6795231955392, 20.53652306965419, 21.299152135849, 19.84882164001465, 22.98256516456604, 19.58843789781843, 21.05477183205741, 22.873028550829204, 14.139577184404645, 13.4162905556815, 23.969026974269322, 41.20710815702166, 41.134791306086946, 38.16131319318499, 26.394219262259348, 24.091198887143815, 25.560944386890956, 30.692635468074254, 50.79568474633353, 42.58521039145333, 33.26289919444493, 16.128141198839458, 0.09292108246258327, 1.0845718937260764, 0.08262697341186659, 0.2353261224925518, 0.6814473995140621, 0.6491418587309974, 0.37293750260557446, 0.11511673645249434, 0.4869464763573238, 0.27631330170801705, 0.7056827704821313, 0.04307146915899856, 1.551152765750885, 0.8560695265020642, 1.2275341195719582, 1.7710364354508263, 0.25205743898238453, 0.79879579693079, 0.2264457954359906, 1.1208495242255074, 0.23330191682491982, 0.06897759011813573, 0.1450347024947405, 1.6467300142560686, 1.812861008303506, 1.999942558152335, 0.16614791671080248, 0.7470420311604227, 1.1093941160610743, 0.42587487772107124, 0.4503411405852863, 1.1655827867133277, 6.301348226411002, 6.456861070224217, 31.622193268367223, 38.16012505122593, 47.54973649978638, 19.816988468170166, 13.841290150369916, 6.959757353578295, 11.66220131942204, 16.021868501390728, 19.170319625309535, 18.074816261019024, 16.9434323992048, 16.50397273472377, 19.009378501347133, 21.33818711553301, 22.458672727857316, 17.7779666355678, 20.50743443625314, 13.229534268379211, 20.293957982744487, 16.913530826568604, 15.236855813435145, 16.191996880940028, 11.685443912233625, 38.73755509512765, 31.282464572361537, 42.33857018607003, 13.413383603096008, 14.540646314620972, 4.9510696189744134, 22.663872139794485, 25.160330363682338, 28.54425941194807, 45.79058115822928, 65.5980749130249, 57.790481431143625, 50.713987827301025, 55.35138579777309, 57.309342997414724, 53.54394742420742, 55.047079018184114, 45.749089990343364, 56.892096723829, 37.09244053704398, 32.96740620476859, 17.66351764542716, 27.022649083818706, 45.024709020342144, 54.27530785969326, 36.00978265489851, 28.973420109067643, 49.150924546378, 10.03185863154275, 0.2226309629955462, 0.10277923276381833, 0.15753573312291078, 0.014433757900925619, 0.08304058121783392, 0.05825170209365232, 0.02086211385072342, 0.019158061360940337, 0.015703195140564015, 0.06309624535164662, 0.054723499808460474, 0.06887914147228003, 0.018138011185718433, 0.019869320427200625, 0.07206597618226494, 0.06488078566534178, 0.2583022953144142, 0.18433329303349766, 0.2098842484078237, 0.19080449507704803, 0.29959921219519203, 0.1373347006738186, 0.22638503941042082, 0.2595282723861081, 0.2467830234340259, 0.1836056863623006, 0.20252367694463047, 0.1745996403374842, 0.15208534630281584, 0.15138144764517034, 0.18825620253171238, 0.33337169140577316, 0.32662797612803324, 0.24874016270041466, 0.3102944982903344, 0.7029806811894689, 37.096202986580984, 99.60494899749756, 67.59784289768764, 61.73443875994001, 90.59740856715611, 100.74867807115827, 63.704211371285574, 45.327601841517854, 51.3949043410165, 36.88018349238804, 41.123146125248496, 55.8239049911499, 75.7732879093715, 79.79054873330253, 64.49142142704555, 73.72518825531006, 67.54044382912772, 67.88553306034633, 65.04911858694894, 69.52828175680978, 69.36441544124058, 70.39779322487968, 70.11374391828264, 53.993818964277, 60.48301260811942, 58.63869667053223, 37.62935563496181, 6.8732839822769165, 40.19238976069859, 62.182048661368235, 39.45303889683315, 40.65420178004673, 12.484723857470922, 25.628032718385967, 27.976355348314556, 29.34783247538975, 28.94321976389204, 29.427847930363246, 26.43073378290449, 27.785538707460674, 21.858657564435685, 19.756577355521067, 28.560863869530813, 43.43840748923165, 48.585789339882986, 45.40620681217739, 31.941202436174663, 39.29203871318272, 31.805115018572124, 31.185026509421213, 49.653578077043804, 44.435199533190044, 37.636588709695, 18.267941440854752, 1.2134137515510832, 1.570972502231598, 0.2371313241975648, 0.32902841589280535, 0.7945364969117301, 0.7659479709608215, 0.4810786140816552, 0.703848228922912, 0.7284614081893648, 0.3359627995107855, 0.8769206904939243, 0.32188849044697626, 1.9342883782727378, 1.2350205864225114, 1.1327580852167947, 2.8804122039249966, 2.6303580445902686, 0.6786079204508236, 5.944648989609309, 0.9201663328068597, 0.9713056172643388, 0.2149892880448273, 0.2824422914002623, 2.773858538695744, 1.7953831404447556, 8.6067179611751, 0.45105704931276186, 0.5904743096658162, 0.8015512462173189, 2.503205358982086, 3.218761031116758, 8.185610226222447, 10.040499585015432, 7.922332559313093, 42.8457852091108, 45.486329964229036, 60.67718696594238, 31.887353897094727, 22.37054177692958, 6.939175920827048, 10.11917838028499, 15.257797683988299, 22.75971211705889, 20.309134585516794, 26.838395016533987, 31.773372173309326, 36.400980131966726, 29.165820939200266, 31.19033145904541, 20.63538725035531, 23.293856620788574, 21.461508955274308, 29.18197202682495, 24.444261176245554, 20.33525112697056, 20.91909956932068, 9.339714697429113, 25.53189049448286, 41.50247260502407, 64.3079959324428, 18.157030820846558, 7.920453071594238, 8.630116888454982, 37.950876576559885, 34.30701194490705, 36.245587144579204, 54.31190749577114, 73.48662185668945, 58.93018749782017, 51.14746509279524, 56.74593441826956, 62.24692399161202, 61.781894956316265, 59.884334972926546, 55.0407839502607, 65.25211020878383, 47.043706144605366, 39.77026585170201, 25.905535084860666, 44.6513614654541, 60.7086067199707, 66.73186806270054, 49.35757092067173, 40.61947120938982, 67.38053103855678, 29.03767010143825, 0.4430930023746831, 0.14560210704803467, 0.211163979023695, 0.11135714354791812, 0.1527819303529603, 0.15844412866447652, 0.1560630135770355, 0.22991103306412697, 0.1305108368396759, 0.2506523015243666, 0.17326101288199425, 0.28603790274688173, 0.11608834431639739, 0.3089797688382012, 0.18290173342185362, 0.10984080098569393], [0.04128437416095819, 0.03967230387830308, 0.05579939511205469, 0.11759602198643343, 0.06666903078023877, 0.08757919339197022, 0.004810316679400525, 0.04272268858871289, 0.1291520840355328, 0.05087109349135842, 0.058740674784140925, 0.0263872752298734, 0.022239463603390113, 0.08355227126074688, 0.01679023029282689, 0.17843959214431898, 0.04478525862629924, 0.056740835309028625, 0.08590236372713532, 0.047300347060497315, 0.8627019620367459, 30.88701479775565, 64.50589452471051, 44.476350239345, 46.69786998203823, 79.55820097242082, 67.89506598881313, 32.06410217285156, 35.1710239137922, 32.179946013859336, 26.049454859324864, 30.57280683517456, 58.78831917898995, 66.95911584581647, 64.01549761635917, 62.94931043897356, 57.266201632363455, 58.63424287523542, 59.49235234941755, 62.26457936423165, 57.185835293361116, 62.887520108904155, 55.81671360560826, 47.59319748197283, 55.030170576913015, 35.769124848502024, 4.876114623887198, 13.231196624892098, 67.33242865971157, 30.70257486615862, 28.871926035199845, 14.321432386125837, 27.236125537327357, 24.05803860936846, 21.125099761145457, 23.32215142250061, 21.284613030297415, 22.26247297014509, 26.707306827817643, 23.749960694994243, 22.83031449999128, 24.09248082978385, 30.151930127825054, 44.215143135615754, 42.82736553464617, 37.76407078334263, 25.40614025933402, 26.733814205442155, 20.932014533451625, 27.882283687591553, 44.67245272227696, 40.14416231427874, 26.106087888990128, 11.41633323260716, 0.888183937541076, 0.3811601528099605, 0.14268656420920575, 0.34444017176117214, 0.9983535430261067, 0.0034142751953498062, 0.5111052000096866, 0.031098437162914445, 0.07167205946253878, 0.18723118039114134, 0.3553820646234921, 0.22180308241929325, 1.0954732916184833, 0.162483936175704, 1.4282596515757697, 2.0167591529233113, 0.9517550149134227, 1.87110949414117, 1.2970342359372546, 0.8667693723525319, 0.2408263273537159, 0.02400294558278152, 0.08008531015366316, 0.11337447565581117, 2.512557634285518, 0.7201948974813733, 1.3887341724974769, 1.5558452968086516, 2.7268444214548384, 0.8561061673930713, 0.013540209553736662, 0.46714633596794947, 5.379647970199585, 13.712730237415858, 25.233555691582815, 32.35587092808315, 40.63234274727957, 31.951162678854807, 18.70950640950884, 16.566204275403702, 9.77116482598441, 12.963175075394766, 19.842500516346522, 22.39232611656189, 24.27475813456944, 22.087706668036326, 33.935689789908274, 37.564959730420796, 31.90410600389753, 29.400204522269114, 25.131048917770386, 26.524013348988124, 30.65188080923898, 33.94661235809326, 25.333484683717998, 24.45622076307024, 19.622888803482056, 8.989110333578926, 19.65674911226545, 44.53769588470459, 44.039464882441926, 5.569641249520438, 3.9066194466182163, 0.11198003869503736, 5.4146438751901895, 3.69532516172954, 6.675135254859924, 22.547651359013148, 56.31913089752197, 54.678921767643516, 47.091433320726665, 48.40296139035906, 50.068430696214946, 41.33270379475185, 35.446047510419575, 33.1608510017395, 26.30491406576974, 24.153010061808995, 25.147762809480938, 35.7815968649728, 53.687966210501536, 41.895427976335796, 28.38561119352068, 26.197253465652466, 24.83490800857544, 0.21477823651262692, 0.17144206405750342, 0.20189485140144825, 0.2290134398000581, 0.047959699894168546, 0.043387992174497673, 0.11429999742124762, 0.049252746759780815, 0.029011656995862722, 0.04821246775931545, 0.13413783721625805, 0.08007427038890974, 0.10972410653318677, 0.04265559843874403, 0.04695173951664141, 0.12525414462600434, 0.03656193667224475, 0.048638411331921816, 0.03400269257170813, 0.010885130015334912, 0.0933317318558693, 0.05458705659423556, 0.037031832350684066, 0.05312551591279251, 0.049365254651222906, 0.033215256075241735, 0.09036166872829199, 0.02953073289245367, 0.045662706185664446, 0.04266039228865078, 0.056690342125615904, 0.026638009186301912, 0.13771461243075983, 0.03458909271284938, 0.12245087219136101, 0.03866669123194047, 0.03253673462729369, 1.1812153650181634, 42.54724543435233, 78.16734531947544, 47.11229876109532, 60.87809412819998, 85.47892080034528, 70.71504797254289, 33.2369441986084, 26.444678817476543, 31.772020748683385, 25.683967454092844, 32.92109646115984, 63.57546125139509, 67.87223420824323, 67.2587638582502, 62.951276779174805, 61.327343804495676, 60.44645118713379, 62.67464814867292, 61.333583286830354, 62.88276754106794, 63.5234192439488, 62.33541624886649, 48.74174860545567, 67.29961231776646, 31.23089156832014, 9.415876507759094, 23.195781060627528, 54.17783505575997, 41.5351881980896, 44.525154386247905, 23.01578450202942, 22.65733735901969, 25.173339128494263, 21.04124195235116, 23.489099264144897, 21.27553173473903, 17.995344502585276, 25.01827618053981, 22.02328818184989, 17.30453027997698, 16.730619498661586, 31.159168788364955, 47.090036732809885, 42.01141078131539, 39.306355476379395, 28.167152881622314, 28.19957491329738, 26.17621432031904, 34.81831250871931, 49.47422422681536, 48.25404759815761, 34.29350464684622, 16.763527904238018, 0.5222763291427067, 0.8285201362201146, 0.11378393761281456, 0.6216782895582063, 1.2914657975946153, 0.04283872486225196, 0.6600823402404785, 0.11351624197725739, 0.06200708808111293, 1.1417384147644043, 0.4729754403233528, 0.05512925357158695, 0.6369093922632081, 0.06157127182398524, 1.1056246097598756, 2.395375830786569, 0.9224569584642137, 2.133064832006182, 1.587250937308584, 2.0651794118540625, 0.5994946456381253, 0.0691176668873855, 0.3447493394570691, 0.2928807927029473, 2.9990802705287933, 0.9353851675987244, 0.634488433599472, 0.29229852823274477, 1.9871496217591422, 0.5872112619025367, 0.08582619138594184, 0.25686488673090935, 13.020089507102966, 11.85213988167899, 30.483345304216655, 37.99210718699864, 49.04207059315273, 31.72049638203212, 12.990601352282933, 19.03876417023795, 11.863672154290335, 17.762138639177593, 21.528013638087682, 26.642422812325613, 24.644117423466273, 19.66786101886204, 23.725657633372716, 21.555940185274395, 17.122494425092423, 18.94452575274876, 18.53346685000828, 23.06498990740095, 22.84139861379351, 30.722380706242152, 21.70678731373378, 21.145430190222605, 16.17634780066354, 17.35358108792986, 37.68792200088501, 42.971992288317, 32.209187507629395, 11.93304123197283, 18.386267525809153, 5.192504320825849, 2.9942473641463687, 1.59503878227302, 2.6170800370829443, 16.67665457725525, 54.21762391499111, 61.139666012355256, 54.87050444739205, 52.80198056357247, 55.76712083816528, 43.33369813646589, 34.57013675144741, 36.93649864196777, 35.54820340020316, 27.30191629273551, 22.36388192858015, 40.07399245670864, 69.90631239754813, 50.66736194065639, 40.96936164583479, 32.87251813071114, 32.5057053565979, 1.331059998699597, 0.3861298518521445, 0.39792509749531746, 0.1641620211303234, 0.03613700072414108, 0.0975238365520324, 0.06966071203351021, 0.09802298048245055, 0.07394438503043992, 0.11658651115638868, 0.04638194652008159, 0.027721802637513195, 0.08891501171248299, 0.027472222190616385, 0.017072996191148247, 0.17134702844279154, 0.04945460074980344, 0.20780243511710847, 0.1582803710230759, 0.27571049119744984, 0.2067445447402341, 0.13777926324733666, 0.18695013118641718, 0.17409833866570676, 0.2097773655716862, 0.19642121797161444, 0.12136776745319366, 0.12674187336649212, 0.19699566571840219, 0.16798225470951625, 0.16750563814171723, 0.10004610049405269, 0.29676735986556324, 0.16772989396538052, 0.19088073527174337, 0.13678706863096782, 0.18951533282441752, 1.1550179421901703, 71.19685690743583, 87.8301773071289, 63.39774717603411, 70.76340743473598, 99.77589552743095, 90.70703724452427, 48.49625137874058, 48.53332001822335, 48.904940945761545, 44.30341305051531, 49.74595090321132, 72.25208677564348, 83.68695259094238, 72.05193696703229, 70.65400109972272, 63.44245883396694, 67.03667163848877, 64.67011519840786, 68.0984536579677, 67.56053801945278, 70.99610260554722, 61.2442433493478, 56.6011061668396, 64.08697373526437, 41.53977748325893, 7.116768836975098, 17.926786627088273, 74.11446802956718, 40.11512579236712, 32.048121316092356, 16.668209041867936, 31.204477991376603, 29.86854784829276, 27.319512605667114, 31.96966920580183, 31.235043116978236, 25.80958914756775, 32.97378465107509, 31.098236560821533, 28.98868703842163, 28.216094255447388, 31.952430725097656, 48.714518615177695, 51.05386938367571, 45.53919185910906, 32.38252074377877, 33.21213565553938, 30.766265528542654, 39.10842214311872, 50.87614836011614, 48.499548298971995, 39.81010682242257, 26.47181327002389, 4.166965842247009, 0.8748383479458945, 0.29878081753849983, 0.9744390376976558, 1.6633684528725488, 0.13185330480337143, 0.5135645366140774, 0.24712324089237622, 0.21330371206360205, 0.9217300031866346, 1.7403341914926256, 0.33369489120585577, 2.0374276552881514, 0.5172647780605725, 1.2074885666370392, 2.775902394737516, 4.201756341116769, 2.459692048174994, 7.245800793170929, 2.661864868232182, 1.114145272544452, 0.0707342562132648, 0.250913890344756, 0.23094427904912404, 11.053705879620143, 0.9242165897573743, 2.3661071956157684, 4.894933819770813, 7.568053466933114, 3.029723346233368, 0.2088949986334358, 1.2927474145378386, 18.81777845110212, 16.652877841676982, 39.069105761391775, 41.9214767728533, 63.63574382237026, 44.69691385541643, 20.68015275682722, 22.063120467322214, 11.298427513667516, 16.745869057519094, 23.005888530186244, 28.74159172603062, 29.29789924621582, 30.65457671029227, 39.16658203942435, 47.304458141326904, 36.19581719807216, 36.18507180895124, 27.9458840233939, 32.64086866378784, 35.82212223325457, 43.545809268951416, 29.263533455984934, 25.813949142183574, 22.499170303344727, 10.760352066584996, 30.19262225287301, 60.27047416142055, 51.97474193572998, 12.564820953777858, 13.830551709447588, 4.144964805671147, 8.899653145245143, 3.7375250458717346, 6.054787925311497, 26.589357682636805, 68.63534791128976, 58.785373142787385, 58.830675397600444, 54.367771012442454, 63.04652268545968, 50.25517048154558, 52.937557288578574, 45.29388223375593, 39.420180865696494, 36.38682665143694, 36.242363180433, 58.35348006657192, 72.34005791800362, 62.50915595463344, 47.912696497780935, 47.60253586087908, 54.92002773284912, 2.5315238279955725, 0.851171643606254, 0.486827868436064, 0.27518636360764503, 0.16419658570417336, 0.15703159517475537, 0.16688988118299417, 0.18567897725318158, 0.22977198766810553, 0.1604623632239444, 0.17174222080835275, 0.16818722656794957, 0.41086443460413385, 0.12663120430495056, 0.08583478163927794, 0.2403873966208526, 0.2582529793892588], [0.03579113106908543, 0.15106565744749137, 0.0730702080098646, 0.24842654381479534, 0.11240277279700552, 0.11411813646554947, 0.1650237606040069, 0.03328207141852804, 0.05167328812448042, 0.10543786867388658, 0.1480245449181114, 0.15408631893140928, 0.09695022340331759, 0.11730912380984851, 0.11263963580131531, 0.1799697700355734, 0.09929091137434755, 0.03494953051475542, 0.015508823695459535, 0.08584128879010677, 0.1440604483442647, 7.849544099399021, 68.38112027304513, 52.935038566589355, 47.73586136954171, 60.467559814453125, 74.61632946559361, 46.790736130305696, 37.40038469859532, 34.553360325949534, 28.972357034683228, 24.767437526157924, 57.011185373578755, 72.89504528045654, 59.24706704275948, 60.76273318699428, 59.69018145969936, 61.39278193882534, 60.461619104657856, 59.195671217782156, 64.21283340454102, 59.426170757838655, 57.69538491112845, 56.4553815977914, 33.672175884246826, 7.9218209981918335, 5.775726122515542, 52.300695828029085, 50.55294248035976, 23.419645071029663, 18.650841031755718, 22.512135641915457, 27.745343378611974, 17.1559065750667, 21.11278929029192, 23.629492827824183, 20.936709778649465, 22.39276385307312, 26.422498430524552, 28.704175676618302, 31.355434553963796, 29.20373031071254, 36.19481665747506, 43.310008253370015, 39.577623571668354, 30.861664295196533, 25.519486222948345, 22.575768981661113, 23.84546889577593, 30.538600853511266, 53.56216560091291, 39.90876429421561, 27.779427766799927, 17.34446505137852, 0.7495056561061314, 0.21779804304242134, 0.15731184370815754, 1.436994297163827, 0.44756495526858736, 0.6795811025159699, 0.148553069414837, 0.2600110907639776, 0.21304707654884883, 0.5742147107209478, 0.14805050566792488, 0.35159942188433235, 0.9359388521739415, 0.18449728137680463, 3.0815736268247877, 1.0548146047762461, 0.9716866825308118, 1.3250024723155158, 3.8368721263749257, 0.5048518212778228, 0.3463177595819746, 0.10710540919431619, 0.13309757517916815, 0.733339857842241, 0.8327567460281509, 2.151193984917232, 1.2072397342750003, 0.40894070640206337, 0.27005384330238613, 0.3566126285919121, 0.36937280531440464, 0.2477088166134698, 4.990628319127219, 15.230406148093087, 35.762583119528635, 39.25243050711495, 37.67291736602783, 32.30301250730242, 20.463549613952637, 14.321349876267568, 12.77014456476484, 18.59428095817566, 25.693654979978287, 28.92812306540353, 28.963364328656876, 31.395039285932267, 34.723629406520296, 43.614676339285715, 47.358403955187114, 42.68967655726841, 42.136328969682964, 20.575874192374094, 19.632637126105173, 18.172294276101248, 19.17366518293108, 20.798779351370676, 28.060946192060197, 16.305424485887798, 12.777084946632385, 29.179526260920934, 55.31775304249355, 27.96551615851266, 17.779623780931743, 6.755114231790815, 1.4410104645150048, 0.4827892280050686, 0.6382743875895227, 0.18039849560175622, 3.9678656458854675, 35.028245380946565, 54.696792534419465, 50.7568929536002, 49.29862935202462, 36.35843978609358, 22.03391718864441, 17.98592448234558, 28.97386131967817, 25.83923884800502, 24.876937661852153, 48.10913944244385, 51.335816860198975, 42.98634726660592, 29.803940023694718, 30.747019018445695, 11.723591259547643, 0.5175304923738752, 0.07140878108995301, 0.06624958078776087, 0.3142190362725939, 0.019683493434318473, 0.17547869602484362, 0.06540686743600027, 0.1642045924173934, 0.0953430657141975, 0.04224603470148785, 0.061121593096426556, 0.06213729216584137, 0.11868216656148434, 0.07572598050215415, 0.08004037756472826, 0.14367166134927953, 0.07004392825599227, 0.22812407038041524, 0.1872866302728653, 0.04598313756287098, 0.22377253031092031, 0.05824387179953711, 0.17949510764862808, 0.1402377856097051, 0.034569706967366595, 0.03380919474044016, 0.03917337368641581, 0.04908641068530934, 0.14213639444538526, 0.14124857208558492, 0.12236514607710497, 0.19254257609801634, 0.0943324217306716, 0.04722282782729183, 0.10419042275420257, 0.020012074017098973, 0.03697906268228378, 0.1267218023006405, 9.040696365492684, 80.51693425859723, 62.75793620518276, 59.703355244227815, 74.06055000850132, 77.3675034386771, 54.04903629847935, 28.073221921920776, 32.71393244607108, 28.44733551570347, 29.00626424380711, 61.51273563929966, 78.77429131099156, 64.19034903390067, 65.11807250976562, 59.83099365234375, 63.9586752482823, 59.395959990365164, 63.381655148097444, 68.05627809252057, 66.25447123391288, 60.45832565852574, 60.367443220955984, 29.621330942426408, 12.119153942380633, 17.232517412730626, 41.4354259627206, 49.216289724622456, 41.31053556714739, 26.530214616230555, 20.273577179227555, 28.861590589795792, 14.448319520269122, 19.628035681588308, 18.82312682696751, 22.653090272630962, 20.890710966927664, 24.356138910566056, 24.870990003858292, 21.301418985639298, 23.24058304514204, 38.40960012163435, 46.65127188818795, 44.35062953404018, 35.47743252345494, 29.24078505379813, 26.886172567095073, 27.582375117710658, 33.793446268354145, 64.35300636291504, 49.41753734861101, 40.532486711229595, 21.637869868959697, 1.8484868109226227, 0.12227248533495835, 0.048070596264941354, 1.6521033602101463, 1.7385627265487398, 1.739429622888565, 0.42943667088236126, 0.27203285853777615, 0.517882842038359, 0.7404557360070092, 0.10432368703186512, 0.5162783509918621, 0.5635156791125024, 0.2480218383882727, 3.3584408845220293, 1.799780698759215, 1.1518025547266006, 3.455819453511919, 4.009794984545026, 0.5786052122712135, 0.5679654574819973, 0.24014670667903765, 0.26341760797160013, 1.045056619814464, 3.657552582877023, 0.5803093665412494, 0.8946863657661847, 0.3434436209499836, 0.2113672952566828, 0.18183395000440733, 0.2735075594059059, 0.3552446205701147, 8.033669625009809, 20.074856962476456, 39.244676317487446, 38.273867062159944, 43.216812065669465, 35.303612913404194, 15.014577729361397, 18.62038881438119, 17.003034046718053, 21.767757756369456, 27.66249826976231, 31.232406275612966, 31.438326563153947, 35.11908612932478, 33.44746766771589, 32.79326350348336, 30.23986652919224, 32.356089796338765, 31.479793412344797, 18.37297214780535, 15.821932349886213, 11.190065145492554, 14.849834203720093, 17.525498628616333, 31.810409545898438, 13.635362914630345, 19.730507714407786, 44.051221234457834, 43.75383138656616, 24.330482687268937, 24.367662497929164, 24.08910574231829, 4.315324212823596, 1.1073212730033057, 1.2344307495015008, 0.335940950683185, 0.5088370474321502, 27.189890486853464, 57.46617078781128, 56.09027113233294, 54.520794664110454, 40.506298950740266, 25.208820104599, 22.473067658288137, 33.445480482918875, 27.763598033360072, 22.693587848118373, 53.25439861842564, 60.835237639290945, 55.962087290627615, 38.266442911965505, 42.710243225097656, 19.635063784463064, 0.43303705911551205, 0.30940317468983786, 0.242171509457486, 0.5793041033404214, 0.1273066723453147, 0.12147304894668715, 0.1048115197835224, 0.07569413006837879, 0.023780918746654476, 0.060459193640521595, 0.0380653429643384, 0.12766867077776364, 0.1696269285998174, 0.04983396628605468, 0.1460928778563227, 0.1157913902508361, 0.1283594329974481, 0.2998066267796925, 0.281288347606148, 0.22194560191461019, 0.28638941102794235, 0.41685231615390095, 0.1568245334284646, 0.2737317202346665, 0.1143545787781477, 0.12816237285733223, 0.16416017551507267, 0.21637343162936823, 0.2293456234037876, 0.2250996905245951, 0.35290807166269844, 0.20136876963078976, 0.283235743109669, 0.2772596680692264, 0.16003555112651416, 0.13129587471485138, 0.2236745769956282, 0.3720266914793423, 16.55082791192191, 103.32049819401333, 69.96347522735596, 73.54181834629604, 78.74267700740269, 99.63556970868791, 70.60628087180001, 55.67971249989101, 48.063757283346995, 48.00775480270386, 40.57418285097395, 76.54721300942558, 88.75655978066581, 69.7361649104527, 67.16296904427665, 67.65745149339948, 71.53567886352539, 64.86825002942766, 66.94191905430385, 77.84263515472412, 69.90128884996686, 66.59819167000907, 64.12455654144287, 38.321281569344656, 11.91503758089883, 7.962862270218985, 58.76564720698765, 60.87213952200753, 33.16386999402727, 22.790992907115392, 26.90090274810791, 34.67825766972133, 20.384777886526926, 28.13102572304862, 28.16355892590114, 31.09273706163679, 25.17040525163923, 35.31060627528599, 33.87393767493111, 41.07065595899309, 30.699059077671595, 38.5374539239066, 49.79098217827933, 50.84719869068691, 35.85258660997663, 33.834965229034424, 28.22211139542716, 35.654500416346956, 37.422274998256135, 64.97967829023088, 49.042716775621685, 46.94977344785418, 37.18723133632115, 3.3213392410959517, 0.350032277405262, 0.2301675464425768, 2.5379176906176975, 1.7506361986909593, 1.449558594397136, 0.48518261100564686, 0.30948025626795633, 0.7791811951569149, 0.9490795241934913, 0.8821517069424901, 0.9363191574811935, 1.2804894894361496, 0.596290223300457, 2.91944066967283, 2.4584155338151112, 2.5753823774201527, 3.2878074518271854, 9.404563103403364, 1.1013449536902564, 0.8724081612059048, 0.3421184963413647, 0.4725104538457734, 2.200297338621957, 7.804923636572702, 3.5775851139000485, 1.6110275643212455, 2.4105087901864732, 0.3450097611972264, 0.7199145268116678, 0.5447749218770436, 0.664056329854897, 20.452290058135986, 31.119786398751394, 42.40786109651838, 36.83163295473371, 51.83727182660784, 41.91299649647304, 22.875681025641306, 20.243743351527623, 18.55682495662144, 25.39417372431074, 30.628538336072648, 37.581697940826416, 34.102915559496196, 41.88828175408499, 41.82757534299578, 50.85597079140799, 51.97552013397217, 52.054580211639404, 49.699644633701865, 22.700450931276592, 24.56580948829651, 21.16570850781032, 25.344207491193497, 22.51032042503357, 28.19799072401864, 15.489160537719727, 13.21596096243177, 41.138657978602815, 68.03576006208147, 34.54648508344378, 26.439910616193497, 16.818540266581945, 2.5468637134347643, 3.9875281793730597, 1.6680448076554706, 0.2019129954278469, 5.003305741718837, 43.21757984161377, 63.1736330304827, 63.974037715366904, 60.19284888676235, 46.13680989401681, 39.73451042175293, 30.418601989746094, 42.77360732214791, 32.6235294342041, 38.83230767931257, 69.97842080252511, 68.8917155947004, 65.3788036618914, 47.21385710580008, 55.92058917454311, 35.68901906694685, 0.45194479024835993, 0.7611741785492215, 0.4027663362877709, 0.7340408116579056, 0.17258380779198237, 0.25128895736166407, 0.18272639997303486, 0.20157952260758194, 0.2457760503249509, 0.12161014016185488, 0.15454218589833804, 0.20938263460993767, 0.35652933163302286, 0.2139360795595816, 0.2650954079415117, 0.2717619873583317, 0.29695653542876244], [0.0768668149997081, 0.06880659250808613, 0.05084297500018563, 0.11793040404362337, 0.16433172273848737, 0.09017214032688312, 0.05770171553428684, 0.08810178070728268, 0.06767069774546794, 0.0846374591014215, 0.0502508921282632, 0.05464292377499597, 0.0531635749419885, 0.060340490724359236, 0.0037735847207451506, 0.20150170821164334, 0.10981807684791939, 0.04074125098330634, 0.12260635170553412, 0.047868837269821336, 0.1358799623059375, 0.29502789463315693, 34.23785652433123, 77.78719547816685, 49.05232266017369, 56.67784554617745, 73.6598265511649, 61.36378015790667, 41.490129130227224, 38.66491515295846, 33.75173275811331, 16.728446449552262, 54.03989941733224, 66.62658895765031, 55.27506331035069, 60.38074207305908, 56.21474116189139, 61.84624917166573, 60.58060005732945, 59.51740060533796, 60.36213479723249, 68.54482678004673, 40.72989892959595, 18.43186160496303, 5.887125287737165, 6.207743397780827, 21.885058982031687, 67.91827992030552, 37.631801400865825, 18.945699998310634, 29.0698367868151, 37.03082391193935, 23.762705428259714, 32.98788602011544, 30.931820256369456, 30.74666813441685, 23.422087362834386, 22.67273804119655, 32.06298351287842, 34.36163173403059, 38.01457071304321, 35.67521299634661, 42.42630508967808, 45.942246437072754, 36.90145540237427, 28.296979972294398, 23.609671354293823, 22.264387198856898, 27.16473800795419, 37.148495129176546, 47.83223983219692, 43.09139013290405, 27.235515832901, 15.610201631273542, 0.4290096823658262, 0.7421379600252423, 1.243794098496437, 0.1999947905008282, 0.4639903338892119, 0.7539991321308273, 0.16322974115610123, 0.023723548610827754, 0.18988038466445037, 0.698567977973393, 0.33781199742640766, 0.11428364472729818, 0.8760205187967846, 0.4954654020922524, 1.7768745507512773, 0.21774704435041972, 0.23267953736441477, 3.7918938313211714, 2.9974928242819647, 1.2124606541224887, 0.5814491425241742, 0.3644837976566383, 0.23314465954899788, 1.0969947299786975, 1.412359241928373, 0.22257015268717492, 0.062382480794829984, 0.30274395059262005, 0.1642654298671654, 0.5224856979080609, 0.20709282319460595, 0.3574702968554837, 3.715231316430228, 12.927972027233668, 27.940179552350724, 42.48535782950265, 42.53872694287981, 33.03598492486136, 19.192786625453405, 16.250436442238943, 16.135124138423375, 18.231538091387065, 26.78688975742885, 36.58606972013201, 45.55138942173549, 40.46367870058332, 37.913470949445454, 40.208137852805, 39.92669759477888, 45.625780309949604, 47.50524371010916, 47.73472533907209, 45.1016776902335, 49.82900619506836, 36.20001738412039, 28.88247513771057, 19.084460735321045, 30.393421718052455, 19.140268666403635, 14.488514849117824, 47.8319410596575, 45.02510854176113, 23.549411364964076, 16.028809751783097, 3.1058495470455716, 0.13240027188190392, 0.21676531274403843, 1.1328110652310508, 1.7693278299910682, 0.40294389533145086, 13.73742847783225, 31.28708165032523, 33.45617723464966, 26.632238490240915, 14.090048687798635, 9.559669477599007, 26.73487901687622, 21.08780356815883, 35.919758319854736, 39.47814621244158, 42.03491653714861, 30.809288774217876, 21.56171761240278, 32.626968792506624, 2.5314093998500278, 0.07007547334900924, 0.08798490305032049, 0.14784694516233035, 0.09009303671440907, 0.1735999954066106, 0.030458337760397365, 0.11309846118092537, 0.25163400598934715, 0.07007237244397402, 0.01876487406635923, 0.024863796175590584, 0.0212329230603895, 0.0740111664469753, 0.019213772478646467, 0.021956324510808502, 0.17512239728655132, 0.0768185236624309, 0.0932696255456124, 0.048779522867075036, 0.03285643997203026, 0.009403431754825371, 0.11406492574938706, 0.07021460016923291, 0.14204946053879602, 0.02726125038628067, 0.06557089649140835, 0.17582823655435018, 0.08893259934016637, 0.02964602956282241, 0.050981274007686546, 0.04393327648618391, 0.1793806523616825, 0.30444696492382456, 0.09668385091104678, 0.03832249416570578, 0.01330883165688387, 0.08191453199833632, 0.20558296064180986, 0.2746488553072725, 36.36785806928362, 89.23148999895368, 52.28452736990792, 70.85230268750871, 81.44191319601876, 71.33504962921143, 43.63223443712507, 38.8627963747297, 35.324269907815115, 22.69101701463972, 59.23341383252825, 70.94038500104631, 63.27942630222866, 60.02146462031773, 62.54665538242885, 65.12115056174142, 61.13699095589774, 63.55488068716866, 66.17633874075753, 73.22191633496965, 40.74296154294695, 15.181258065359932, 9.118640388761248, 15.405841214316231, 22.689352921077184, 54.95172888892037, 56.56177936281477, 32.59296778270176, 23.417148930685862, 27.73782890183585, 23.520942858287267, 28.959909336907522, 24.72521506037031, 27.730031285967144, 21.40187430381775, 19.971295799527848, 30.469403743743896, 23.430885519300187, 25.664203303200857, 33.98448004041399, 43.98305593218122, 49.34077712467739, 44.06037201200213, 31.162027972085134, 33.816948550088064, 28.333185298102244, 25.447462933404104, 38.902960436684744, 56.73659256526402, 54.23984772818429, 42.69341121401106, 32.98901162828718, 1.1111581985439574, 0.7622584775090218, 0.4407750181853771, 0.16784559775676045, 0.45634905248880386, 0.7120773930634771, 0.20370667560824327, 0.06210633061294045, 0.37464705801435877, 0.3292329806302275, 0.556221101965223, 0.092498707984175, 1.3406752198934555, 0.3654187646295343, 1.7612641198294503, 0.38683959948165075, 1.5719024751867567, 5.988103457859584, 3.555965793984277, 2.8318497240543365, 2.640491775103978, 0.2623439212994916, 0.22495117277971335, 1.1376994486365999, 0.9259589591196605, 0.31554562651685303, 0.14026280998119287, 0.16247006691992283, 0.2334998319191592, 0.11769541379596506, 0.3071639819868973, 0.6468417878661836, 3.266362705401012, 15.753834792545863, 36.21779782431466, 42.39225196838379, 41.51761620385306, 38.875323976789204, 14.563446828297206, 17.084960256304058, 20.989199944904872, 25.753876754215785, 28.565399306161062, 35.2816982950483, 47.64260264805385, 42.991721698216026, 44.61812128339495, 40.080687046051025, 36.43965033122471, 33.79308843612671, 33.598667417253765, 31.247456073760986, 26.108809845788137, 22.619641644614084, 13.676666481154305, 13.58843217577253, 12.171655399458748, 21.822195155279978, 15.730139698301043, 24.604761089597428, 53.684071745191304, 37.480764933994834, 23.623512165887014, 13.420636653900146, 11.495646919522967, 2.277347649846758, 0.666641602558749, 0.6922376262290137, 1.5664916740996497, 2.6612002296107153, 10.07089534827641, 27.748140028544835, 27.667712892804825, 25.750232424054825, 17.041768516813004, 17.520716530936106, 22.427737610680715, 18.6594237940652, 31.53669915880476, 46.56918934413365, 53.08130509512765, 41.07123613357544, 35.263368947165354, 44.58876167024885, 3.7231774500438144, 0.19758973669792923, 0.05482967018282839, 0.2405213394335338, 0.22159197660429136, 0.2565375342965126, 0.13236695581248828, 0.15605751744338445, 0.32181976842028753, 0.014829350602147835, 0.04716132202052644, 0.04479211522266269, 0.0470424121511834, 0.13531740249267646, 0.08622941760612385, 0.1149971785822085, 0.09514990715043885, 0.19072672139321054, 0.2287161328962871, 0.18355079287929194, 0.13180801937622683, 0.12207751508269991, 0.3484593518078327, 0.17566082839454922, 0.20986750216356345, 0.1838841571339539, 0.14215512201189995, 0.19549952314368316, 0.22231952899268695, 0.25050861494881765, 0.15723588849817002, 0.21564169946525777, 0.1692358617271696, 0.5717536913497108, 0.3358165616435664, 0.08196798698710543, 0.3745146894029209, 0.12231086327561311, 0.2810822900916849, 0.42058330880744116, 53.93623924255371, 101.34522955758231, 66.53607477460588, 80.08844579969133, 92.71910354069301, 87.51438862936837, 66.21693706512451, 51.883598940713064, 48.466481821877615, 36.24346099581037, 78.16940198625836, 80.09319836752755, 69.42045961107526, 64.06221035548619, 71.64170142582485, 67.96063613891602, 67.66878400530133, 71.56297833578927, 67.75385080065045, 78.81732845306396, 48.682001045772004, 21.673437697546824, 9.582793951034546, 5.78709511246, 25.131227833884104, 72.174211365836, 53.54561846596854, 21.510928017752512, 33.743057932172505, 40.47995832988194, 31.220757620675222, 43.39674261638096, 36.000131607055664, 39.15825809751238, 29.60730947766985, 28.257352658680507, 38.727369035993306, 39.2990529196603, 39.828988552093506, 38.63368647439139, 45.53691632407052, 58.03853212084089, 47.434868880680625, 33.60345472608294, 31.499602726527623, 33.49376698902675, 35.95425959995815, 42.628528935568674, 55.80431801932198, 49.622512681143625, 49.46430914742606, 49.79706185204642, 2.2993829931531633, 1.457307898572513, 2.1855254684175764, 0.993789553642273, 1.0327216131346566, 1.767258461032595, 0.3076004428522927, 0.18664138418223175, 0.7787912275109972, 0.7379300115363938, 1.086952086005892, 0.3149373877261366, 2.046499614204679, 2.5630983965737477, 2.7962684333324432, 1.1358949797494071, 2.578012053455625, 7.87773380960737, 5.913884971823011, 2.350392758846283, 1.6723816777978624, 0.9351062625646591, 0.301224520696061, 3.298135514770235, 5.92345437833241, 0.8173201829195023, 0.24801288172602654, 0.32503504731825417, 0.18265336246362754, 0.5025463764156614, 0.2695167692644255, 0.9673107287713459, 9.35775830064501, 40.99072388240269, 36.794255120413645, 40.358736583164756, 49.604555061885286, 45.71151065826416, 20.798631702150615, 20.749167476381572, 20.01323860032218, 24.327741622924805, 30.121031488691056, 39.92851454871041, 51.42320435387747, 46.748664787837434, 47.737487248011995, 50.240165846688406, 44.7671149798802, 50.13262162889753, 54.551905223301475, 53.80776357650757, 55.614767687661306, 59.7495607648577, 41.93198592322213, 35.12251159123012, 20.628873314176285, 34.483068874904085, 21.094001361301967, 16.55826074736459, 62.236147335597444, 58.98812852587019, 29.178970405033656, 19.257241589682444, 6.802291197436197, 1.3398610864366804, 1.6037476978131702, 1.5298813985926765, 2.6402255722454617, 3.973278726850237, 19.438721588679723, 36.82071386064802, 39.33177893502371, 35.98856633050101, 29.228931427001953, 21.793584210532053, 37.517520904541016, 26.19602710860116, 54.176664284297395, 60.270835467747276, 62.07934733799526, 51.03907666887556, 47.559304169246126, 70.14842932564872, 8.955518398966108, 0.5753767969352859, 0.4332676524562495, 0.5897595137357712, 0.2468074235532965, 0.3319308901471751, 0.22605403645762376, 0.20250851847231388, 0.5606141548071588, 0.14165747085852282, 0.12765326803284033, 0.14604451188019343, 0.2295403086713382, 0.21919509236301693, 0.23122093134692737, 0.15345734411052295, 0.29766443744301796, 0.3585762817944799], [0.06285609823784657, 0.02044887075732861, 0.033806100620755127, 0.06787006490464721, 0.18041473973010266, 0.07586102932691574, 0.05258218578195997, 0.11860021310193197, 0.0115896486843537, 0.01411396689114294, 0.031971481030008624, 0.07362628781369754, 0.031262520501124005, 0.10331458332283155, 0.08829780268882002, 0.172043721058539, 0.18017532543412276, 0.04804986362744655, 0.007975476012299103, 0.08419335114636592, 0.09047786785023552, 0.11865088609712464, 1.9294598145144326, 54.91141891479492, 78.2659194128854, 44.42721952710833, 55.61791174752371, 75.41700513022286, 50.04810374123709, 37.83996595655169, 32.30765390396118, 15.331052541732788, 35.56493466241019, 62.14281218392508, 42.36956262588501, 59.05114868709019, 58.067749295915874, 63.59014279501778, 57.05091169902256, 60.628876141139436, 60.487125941685264, 18.061395815440587, 4.130515158176422, 0.11515202027346406, 6.801582915442331, 14.23086782864162, 58.353209086826865, 52.99757235390799, 14.803545304707118, 20.82444425991603, 37.00191593170166, 38.5228453363691, 21.88768540109907, 27.063085862568446, 36.91770029067993, 42.121220111846924, 50.78238936832973, 42.69725009373256, 38.11270012174334, 46.018412590026855, 38.88638898304531, 32.84863369805472, 38.98687035696847, 48.90213387353079, 40.14631625584194, 27.997509138924734, 17.166771820613317, 21.68643430301121, 27.322875533785137, 41.54724332264492, 50.88335711615426, 44.54612752369472, 24.545597178595408, 7.531615376472473, 3.25980230314391, 0.14983383140393666, 0.43987601356846945, 0.09541583859494754, 0.7859976493886539, 0.7163777308804649, 0.6556692570447922, 0.6038364012326513, 0.6843773137245859, 0.4961255352411951, 0.8903081321290561, 0.05723645764269999, 1.5355441804443086, 0.30722849709647043, 0.2331216979239668, 0.49496122343199594, 0.2866181587534291, 6.276726416179112, 0.8554589535508836, 5.991744748183659, 4.881225023950849, 0.17087767219969205, 0.058607396935778, 0.6237991186124938, 0.6238184975726264, 0.15749753160136087, 0.042816326421286376, 0.14835286087223462, 0.06514170273606266, 0.44316989396299633, 0.6280181950756482, 0.44822156003543306, 3.591861490692411, 0.3010406105646065, 21.290376561028616, 38.133054869515554, 46.384923117501394, 43.27154997416905, 26.435408183506556, 17.985552753720963, 17.76277266229902, 15.134847572871617, 28.307058334350586, 50.40264252253941, 47.18842322485787, 42.93751185280936, 36.76471485410418, 45.83582435335432, 53.18636185782296, 60.63494191850935, 71.1274721963065, 80.3205156326294, 76.2147694996425, 75.3272899900164, 83.05067130497524, 64.97161143166679, 70.98039272853306, 42.62211227416992, 40.618720803942, 14.5721755027771, 25.944380726133073, 61.446262223379954, 36.020104203905376, 54.4927065713065, 26.702243328094482, 1.274535208940506, 0.04707934141957334, 0.05633930542639323, 0.2040710760546582, 0.33057984550084385, 0.5156279344643865, 3.4437148230416432, 9.136440805026464, 8.671694040298462, 5.949073255062103, 11.571270244462148, 46.91429247174944, 35.15873602458409, 38.15124872752598, 39.222146783556255, 30.89825698307582, 20.294631958007812, 26.655417680740356, 12.208851712090627, 0.1638112456670829, 0.15686935745179653, 0.12647058149533613, 0.02848398745326059, 0.04690587054938078, 0.10067960792886359, 0.06217599580330508, 0.20383850139166626, 0.09193750524095126, 0.030841252034796134, 0.07039906669940267, 0.033570906812591214, 0.011377637873270681, 0.12031362258962222, 0.07197005168667861, 0.06959667868380036, 0.19060922626938137, 0.10358941036143474, 0.14314944722822734, 0.03245405174259629, 0.041504283967827044, 0.014624957194817918, 0.1577656479286296, 0.11550275502460343, 0.009858160479260343, 0.07294127278562103, 0.035831643002373834, 0.09146755867238555, 0.03076950374192425, 0.11661715379783086, 0.03087251214310527, 0.06629026574747902, 0.10656408074178866, 0.19731355937463896, 0.29050833572234425, 0.059811084132109366, 0.07898888577307973, 0.03252695015232478, 0.0576423437201551, 0.052992170210927725, 1.3234171973807471, 62.399284090314595, 84.97744846343994, 53.38164792742048, 71.79695892333984, 83.34742886679513, 58.27995075498308, 34.48171745027815, 32.05304411479405, 20.324670757566178, 45.829459803445, 70.293472971235, 45.684753145490376, 67.10418728419712, 65.39568083626884, 63.18260315486363, 60.428337233407156, 66.81530203138078, 60.31658240727016, 16.577177218028478, 3.0711402552468434, 0.022922531235963106, 15.256427151816231, 19.28236280168806, 41.52823305130005, 53.09527097429548, 32.93784509386335, 26.937297412327357, 38.12484209878104, 40.82164294379098, 17.570891210011073, 21.2929265499115, 22.896555151258195, 34.20568289075579, 41.94903680256435, 33.73287534713745, 31.07451888493129, 36.45010389600481, 31.325102193014963, 32.6256034714835, 42.72485876083374, 59.11235536847796, 42.70277043751308, 35.55215345110212, 23.787835325513566, 23.800536632537842, 26.85303487096514, 43.49251658575875, 60.34211703709194, 49.15449939455305, 44.88203123637608, 27.318631921495708, 5.7010208283151895, 0.5333360699670655, 0.6391344985791615, 0.4219866006502083, 1.0611333400011063, 0.9197731081928525, 0.4589993559888431, 0.7273265176585743, 0.574954585305282, 0.856839365192822, 1.3550832867622375, 0.151520683030997, 0.8931104274732726, 1.146749151604516, 0.18338551531944955, 0.6172845853226525, 1.1822717083351952, 6.534936675003596, 2.1603299975395203, 3.9296218923160007, 4.147335009915488, 0.05502571930576648, 0.46050114397491726, 0.030243795165526013, 0.3939422597842557, 0.19080568929868086, 0.052886210182415586, 0.1097362455246704, 0.16405507044068404, 0.19732130824455194, 0.6586870551109314, 0.3721048858548914, 1.1391249150037766, 6.17823874098914, 35.80390058244978, 34.7486116545541, 48.709408215114046, 45.71768760681152, 19.45086009161813, 13.9202173437391, 17.265252113342285, 16.80334803036281, 30.68960952758789, 45.95485394341605, 51.79707302365984, 44.03184270858765, 42.160967281886506, 50.23007011413574, 54.98578201021467, 51.11450283867972, 58.95429079873221, 65.90487262180874, 64.2146190915789, 63.73787539345877, 66.70943927764893, 51.78939873831612, 48.00419385092599, 28.367360012871877, 25.099160160337174, 13.874339256967817, 39.63524150848389, 59.90036446707589, 32.10821975980486, 45.31270490373884, 19.52058526447841, 5.160558675016675, 0.08370994244303022, 0.282112007694585, 0.20502107936356748, 0.8948047022734369, 0.6361012841973985, 1.8374910695212228, 7.030058792659214, 9.290167961801801, 6.619206164564405, 15.514698641640798, 56.26553249359131, 29.262800421033585, 36.27874394825527, 55.48852934156145, 43.15197147641863, 33.044892515454976, 39.24557958330427, 13.856846298490252, 0.19213103103850568, 0.10102579649537802, 0.04656453350824969, 0.1291599686124495, 0.16539774196488516, 0.07852410285600595, 0.31051168377910343, 0.16436883860400744, 0.12917208724788257, 0.017103099397250583, 0.019938298600858877, 0.03850178008100816, 0.029540083105010644, 0.0930196193179914, 0.0033517975992123994, 0.12097469211689063, 0.28966366818972994, 0.07484074336077486, 0.36157323526484625, 0.1262399610131979, 0.21932208697710717, 0.14408894681504794, 0.49482540786266327, 0.2529063677149159, 0.14498196675309113, 0.2549587461565222, 0.11449479125440121, 0.20975789161665098, 0.12302038020321301, 0.19704301389200346, 0.27749799670917646, 0.22635238830532345, 0.3787168839148113, 0.45147901667015894, 0.4860157977257456, 0.17365958435194834, 0.25828432770712034, 0.22425264811941556, 0.20151857659220695, 0.30890968974147526, 4.156614763396127, 85.31574930463518, 95.84063734327043, 66.78199236733573, 82.08719934735979, 98.85787868499756, 74.39922605242047, 56.09543711798531, 47.506713254111155, 31.446765150342667, 56.70994969776699, 84.23265021187919, 51.55997964314052, 68.90315232958112, 72.88457434517997, 69.45452662876674, 68.27530615670341, 73.34205763680595, 68.88990211486816, 23.79083173615592, 4.572432313646589, 0.2810185620827334, 9.144191520554678, 19.441575561250957, 64.0572076525007, 71.2532137462071, 20.55323348726545, 26.354452984673635, 41.036957195826936, 44.59430980682373, 27.12859000478472, 32.773853710719514, 37.309707232883994, 47.61123153141567, 57.51312671388899, 48.74653591428484, 45.330568722316194, 58.36481952667236, 43.38551780155727, 34.72587020056588, 43.89185735157558, 61.14477988651821, 45.339299133845735, 35.8668338911874, 23.384619201932633, 32.25734199796404, 32.98541940961565, 52.42657634190151, 65.98635414668492, 46.82410485403878, 49.02554777690342, 53.03581523895264, 13.60676326070513, 0.5528899292860712, 0.6289896400911468, 0.6671018664325986, 1.870387532881328, 0.7967631231461252, 2.915676483086177, 2.367906127657209, 1.6277859679290225, 0.41808746701904703, 2.6541934055941443, 0.29284670310361044, 1.9064304445471083, 4.813090988567897, 1.056592692221914, 1.001811574612345, 2.9010494393961768, 11.664918065071106, 1.774438664317131, 16.9914322921208, 11.522367085729327, 0.7847905084490776, 0.3412607195121901, 1.8366416522434779, 0.4323420492666108, 0.22837056858198984, 0.11769245538328375, 0.5580564577664647, 0.1646653584071568, 0.5207147215093885, 0.8790883113230977, 0.992352687886783, 6.7134076697485785, 30.565931592668804, 52.899046897888184, 37.47436564309256, 50.73196281705584, 54.81654473713466, 32.53863634381975, 21.762214830943517, 21.68918057850429, 19.21708447592599, 32.49333756310599, 51.07208061218262, 52.05917991910662, 46.40509373801095, 43.30595050539289, 58.156731401171, 63.33824975149972, 66.0550023487636, 82.94388444083077, 91.07067816598075, 80.8401575088501, 81.2581958770752, 84.97646876743862, 74.18267849513462, 85.6248607635498, 60.074944904872346, 47.681682791028706, 15.789340087345668, 31.344199316842214, 79.70008318764823, 44.6509758404323, 71.06516075134277, 37.63215228489467, 4.778609684535435, 0.14394350961915084, 0.3222133458725044, 0.6093337291053363, 1.5605285997901643, 2.1135764377457753, 5.088175816195352, 13.564680627414159, 15.685745920453753, 12.113373041152954, 23.362305062157766, 56.75179174968174, 42.251856667654856, 55.28401606423514, 66.69085284641811, 54.46368047169277, 44.828672545296804, 61.902710233415874, 32.69942113331386, 0.2549733482301235, 0.3085978893297059, 0.3362211585044861, 0.18734619207680225, 0.30049799968089375, 0.2193917046700205, 0.32075123861432076, 0.18277932570448943, 0.3151377726878439, 0.1392641964235476, 0.12094972202820437, 0.13848553677754744, 0.13434147914605482, 0.18199701554008893, 0.266150638461113, 0.17013881541788578, 0.4038184184048857, 0.27308819762298037], [0.05478363497448819, 0.13764416692512377, 0.10626952190484319, 0.06046913417854479, 0.2129150064928191, 0.08261745356555496, 0.04946016473695636, 0.010376065054775348, 0.033430616304810555, 0.13906957900949887, 0.060490114481321404, 0.06374124038432326, 0.025327500221984725, 0.05523921695670911, 0.17540582136384078, 0.37416247544544085, 0.03378194138141615, 0.15904423860566957, 0.08068900954510484, 0.24038275544132504, 0.030374640465847084, 0.06325840843575341, 0.31734274008444374, 9.926335471017019, 73.94264602661133, 53.01014859335763, 50.354224000658306, 71.92408316476005, 62.87871674128941, 48.38356549399239, 24.442062071391515, 12.152848362922668, 17.96285125187465, 34.458802291325156, 32.365931919642854, 58.01266745158604, 51.805084296635215, 49.25007881437029, 50.48830338886806, 39.496784755161826, 7.557647671018328, 0.1829138791986874, 0.3507146936442171, 7.03385511466435, 35.20379856654576, 39.04891429628645, 67.3240213394165, 41.95466831752232, 14.546375972884041, 35.336498737335205, 26.743814400264196, 25.15454772540501, 46.52763911655971, 65.22403253827775, 76.5687176840646, 71.2974112374442, 66.26191970280239, 65.05770656040737, 63.5285678591047, 47.02409485408238, 39.42252240862165, 44.202813557216096, 51.18042039871216, 40.37626688820975, 29.852097988128662, 24.543524878365652, 25.812887804848806, 33.25931739807129, 25.15872880390712, 36.69607012612479, 52.89853967939104, 43.87436178752354, 26.96251937321254, 1.9047185821192605, 5.795690902641841, 1.366668973650251, 0.05993570387363434, 0.21218119801155158, 0.574269482067653, 0.22866421139666013, 0.43077327630349566, 0.3596416089151587, 0.37641192759786335, 0.8507742934993335, 0.086347821966878, 2.3974001450198035, 0.28231092702065197, 0.2174299242241042, 0.7379576957651547, 1.0782266684940882, 0.403277083167008, 5.405667671135493, 0.8840795606374741, 4.067982239382608, 1.9790432453155518, 0.5743420581732477, 0.8776681646704674, 0.6285138513360704, 0.5555348045059613, 0.5485556104353496, 0.138894096282976, 0.053212188583399565, 0.6235375297921044, 0.49650019513709204, 0.36986012916479793, 0.4114023500255176, 0.9279843590089253, 4.139810110841479, 13.471684200423104, 34.347856930324006, 41.1056227684021, 53.6279650415693, 38.97700391496931, 31.094953536987305, 24.967206920896256, 28.092468432017736, 25.813594784055436, 32.30237674713135, 32.59114040647234, 32.49724245071411, 42.38206590924944, 49.95268760408674, 56.51748807089669, 66.78627245766776, 69.95550564357212, 60.58022485460554, 50.821990626198904, 43.26947941098894, 49.33082383019583, 56.11808129719326, 60.244870049612864, 72.23208291190011, 55.75073003768921, 50.14952312197004, 14.16010216304234, 42.33934491021292, 43.14204944883074, 31.60160228184291, 53.1980174609593, 19.85566735267639, 0.3314082824758121, 0.17620973608323506, 0.20321637977446827, 0.05697818685855184, 0.07010042308164494, 0.5349934324622154, 0.7169839069247246, 1.759958184191159, 2.249973484448024, 8.347667404583522, 23.22615337371826, 56.19154807499477, 42.56058944974627, 35.66144514083862, 23.464950799942017, 23.322413716997417, 10.65140518120357, 1.141600645014218, 0.0906129777431488, 0.059885261580348015, 0.09852163586765528, 0.21870079317263194, 0.050746921582945755, 0.07472911077950682, 0.0925995654293469, 0.11077825139675822, 0.044425930229148695, 0.0577492265562926, 0.047711013417158804, 0.013331617710978856, 0.019251214040975486, 0.08909125439822674, 0.10322133904056889, 0.03488200270969953, 0.12463072022157055, 0.06541053831045117, 0.13432705349155835, 0.07112516702285834, 0.10811505573136465, 0.030833235143550804, 0.13433641727481568, 0.09710976734225239, 0.1300565576446908, 0.04513650906405278, 0.04401895171031356, 0.1143640646977084, 0.061792799936873574, 0.0989198816408004, 0.06935792256678854, 0.058991244195827415, 0.2303260522229331, 0.1337401071297271, 0.022928125757191862, 0.10353527005229678, 0.08570461148130042, 0.15101425163447857, 0.12189863968108382, 0.0829940540716052, 0.3431460697736059, 11.95876954283033, 85.23815877096993, 60.4857154573713, 67.6442985534668, 85.84322180066789, 73.22438294546944, 42.47179841995239, 19.18527214867728, 13.361101014273506, 28.64133964266096, 37.87664202281407, 36.951062066214426, 57.71514558792114, 55.81597014835903, 55.23104647227696, 56.77545731408255, 42.859302929469514, 6.109174949782235, 0.21439486422709056, 0.38820663041302134, 13.887965542929512, 36.87915863309588, 25.90045247759138, 57.497493267059326, 54.912329128810335, 24.031067439488, 23.348697015217372, 22.090640544891357, 13.27026981966836, 24.12788016455514, 32.90620299748012, 52.1837020601545, 59.64099516187395, 60.15442534855434, 56.581585202898296, 51.21358415058681, 41.94397503989083, 38.67077248437064, 43.54082046236311, 50.98682968957083, 45.31083583831787, 32.092746121542795, 32.38575860432216, 28.177286829267228, 31.13567692892892, 26.55677236829485, 37.55313042231968, 59.898655210222515, 48.536002022879465, 47.082025459834504, 19.66575571468898, 4.250104078224727, 0.59987723082304, 0.39060582167335917, 0.11848630064300128, 0.904737803552832, 0.36917369599853245, 0.4185236021876335, 0.1891480961016246, 0.9171060855899538, 1.654823905655316, 0.22161332331597805, 5.375814301627023, 1.8887290401118142, 0.18957691666271004, 1.342047923377582, 0.7029228157230786, 1.498375877737999, 9.491934963635035, 2.4853628192629134, 4.471161884920938, 0.18824759870767593, 0.4307411680264132, 0.5313970340149743, 0.6250523999333382, 0.7091175690293312, 1.2783652948481696, 0.05513279552438429, 0.019139371113851666, 0.5270320453814098, 0.0996324180492333, 0.3282470421067306, 0.4113189716424261, 2.5446494093963077, 7.3999730689185, 30.541084834507533, 34.01577125276838, 44.83016640799386, 54.21480294636318, 34.91437135423933, 24.61611270904541, 16.01611018180847, 18.52363862310137, 35.54226269040789, 37.88381603785923, 35.73957763399397, 33.9924704687936, 46.795735359191895, 57.578801086970735, 63.350749560764854, 62.426903179713655, 65.94511658804757, 61.09949847630092, 50.487215995788574, 44.846157687050955, 47.96697235107422, 53.24730798176357, 55.22461244038173, 63.639058113098145, 44.67563499723162, 33.52205310549055, 15.639710630689349, 57.17508295604161, 44.61064154761178, 33.429676805223735, 46.48085689544678, 17.402723959514073, 0.18804535456001759, 1.1197137108870914, 0.1427431676004614, 0.19816788924591883, 0.16579335502215795, 0.18542426877788135, 0.5378375798463821, 2.199390164443425, 2.3939601353236606, 8.965449980327062, 34.031276157924104, 46.74179301943098, 45.895835944584434, 48.89354937417166, 37.96737160001482, 37.36184651511056, 20.66670799255371, 2.118948046650205, 0.22893985946263584, 0.20091652604086058, 0.19450951341007436, 0.29039206196154865, 0.053870900201478174, 0.06185031256505421, 0.12816812683429035, 0.28049413593752043, 0.017102224087076526, 0.062085927064929686, 0.06460458798600094, 0.025565182557329535, 0.030594309392784323, 0.05903309623577765, 0.115750271028706, 0.05440040857398084, 0.2872219192130225, 0.18218479332114967, 0.3595138814832483, 0.259740979543754, 0.18652050995400973, 0.16557767588113034, 0.3186868093907833, 0.253938229488475, 0.35679675585457254, 0.10508303557123456, 0.2167864287538188, 0.23186917656234332, 0.0917814557573625, 0.2880386311028685, 0.14713024933423313, 0.33122838927166803, 0.35235096727098736, 0.850132725068501, 0.1911717996533428, 0.28963348695210045, 0.17719199694693089, 0.34278166932719095, 0.17977038930569375, 0.3596068407808031, 0.6318782450897353, 23.765477759497507, 104.31862776620048, 69.20102160317558, 76.86701774597168, 95.90946619851249, 87.32240295410156, 71.04897144862584, 43.581481320517405, 24.97461543764387, 35.312402384621755, 55.63869728360857, 48.50025354112898, 67.95162432534354, 57.218259062085835, 64.07307038988385, 70.31094074249268, 58.097838469914024, 10.216392363820757, 0.3599827491811344, 0.33446310141256874, 8.386413165501185, 40.86154644829886, 51.684612955365864, 82.64040102277482, 57.181169578007285, 19.541999612535747, 39.21774509974888, 31.959608214242117, 28.752557720456803, 59.49365861075265, 70.7972868510655, 86.99320425306047, 79.40486812591553, 75.2538753237043, 72.66370500837053, 74.21333394731793, 54.566458225250244, 41.321982724326, 45.09922497613089, 60.29691900525774, 45.45460101536342, 32.52855450766427, 29.71649694442749, 35.11262083053589, 44.129982539585654, 33.28072827202933, 52.43755449567522, 67.4206360408238, 44.389855589185444, 51.896331514631, 39.92997367041451, 10.055111646652222, 2.801994183233806, 0.5393332881586892, 0.41764511646968977, 1.7499383389949799, 0.7396438281450952, 0.6181323198335511, 1.211817620056016, 1.6864430946963174, 3.107816538640431, 0.24565879947372846, 4.1206100668225965, 1.9381706842354365, 0.3123423441180161, 0.8976532465645245, 2.4783201685973575, 2.819233749594007, 12.724622573171343, 2.0305660920483724, 10.861970339502607, 4.246823225702558, 1.0020541101694107, 2.7179062153611864, 3.170232857976641, 1.436232709458896, 1.0688611481870924, 0.16358355645622524, 0.16678780237478869, 0.7346508960638727, 0.5328695092882428, 0.9994360506534576, 0.6380927030529294, 4.730103007384709, 25.661899975367955, 44.67164673124041, 39.31633308955601, 46.14807292393276, 66.2366282599313, 43.4901750428336, 36.296861376081196, 26.572994674955094, 31.050446850912913, 33.92458656855992, 37.8410325050354, 38.61746590478079, 38.97028153283255, 54.04819209235055, 63.15371254512242, 62.193290846688406, 63.93716362544468, 69.00250462123326, 66.60659204210553, 48.82228864942278, 36.90606205804007, 43.620679582868306, 52.56605795451573, 60.56801686968122, 82.19863455636161, 60.04751341683524, 60.69156278882708, 20.07107366834368, 60.09725557054792, 61.74948855808803, 38.48927858897618, 64.19141905648368, 25.272133827209473, 0.5112429154770715, 2.4258556238242557, 0.35231763763087137, 0.07357359278414931, 0.1734004518283265, 0.9578231807265962, 1.378593928047589, 5.033736680235181, 4.152390692915235, 14.404508522578649, 29.539769513266428, 65.83752373286656, 62.14428520202637, 59.424405915396555, 50.93525668552944, 57.302210671561106, 39.516972746167866, 2.681713266032083, 0.6032806539109775, 0.5693451634475163, 0.283080304307597, 0.4446679364357676, 0.2599912504000323, 0.16870397169675144, 0.2251801240657057, 0.352570432637419, 0.24663903830306871, 0.17847704727734837, 0.22131315299442836, 0.11275715806654521, 0.09374588248985154, 0.20901060742991312, 0.4580870249441692, 0.1210612596145698, 0.36230097764304703, 0.27672091126441956], [0.0698897922411561, 0.008315293983157192, 0.04115711831088577, 0.040222107233213525, 0.03801939596555062, 0.0944400577406798, 0.06286925503185817, 0.15998497312622412, 0.02452139213814267, 0.07629326970449515, 0.03034538882119315, 0.07869995199143887, 0.027253852658239857, 0.1047470046739493, 0.12774701443101677, 0.05892267823219299, 0.09833774609225136, 0.055131760758480856, 0.04965801537036896, 0.18111825840813772, 0.11290996415274483, 0.03450796028066959, 0.11969763492899281, 0.1577734917934452, 36.578572613852366, 76.72846371786935, 41.6980504989624, 60.104836055210654, 66.25832053593227, 49.746697834559846, 33.63760164805821, 43.529130118233816, 13.979228394372122, 15.552736554827009, 15.795980828148977, 31.98788390840803, 34.83818435668945, 33.92312397275652, 14.174722041402545, 0.44962599181703156, 0.13852618102516445, 0.2652115731367043, 1.0368050911596842, 19.48081030164446, 34.704421111515586, 41.19396563938686, 63.137828963143484, 22.44046323640006, 27.974659987858363, 49.53871740613665, 59.97765622820173, 89.4210785457066, 89.6936980656215, 101.42775331224713, 77.43866688864571, 74.77939673832485, 78.28379017966134, 85.0278993334089, 63.170860699244905, 51.28342396872384, 38.289278166634695, 39.42098338263375, 38.760650907244, 35.41255719321114, 29.48503507886614, 24.73069371495928, 23.17330711228507, 28.55208829471043, 29.152240685054235, 41.71284668786185, 49.474384035382954, 43.01778091703142, 24.713019234793528, 3.431798662458147, 1.3708225850548064, 0.8558432757854462, 0.08525852220399038, 0.5897729758705411, 0.5868999500359807, 0.5196838911090578, 0.32075644976326395, 0.05207777641979711, 0.44014118505375727, 0.9676547731672014, 1.1395242192915507, 0.6453468395130975, 0.2124542947858572, 0.4567544364503452, 1.758847449507032, 0.41195340188486235, 1.8796242943831851, 8.40053277356284, 0.6587515973619053, 2.1956974140235355, 0.340077490146671, 0.7816440058606011, 0.67098645227296, 0.3815177407647882, 0.3363685634519373, 0.4325277235891138, 0.320088228476899, 0.13492101590548242, 0.5492756175143378, 0.43416605996234076, 0.1899343960519348, 0.6427913680672646, 2.02413010597229, 4.959434815815516, 12.996711424418859, 32.68728263037545, 38.5680433682033, 46.78205435616629, 25.388851404190063, 22.32411217689514, 26.933939695358276, 19.332339457103185, 9.932887622288295, 13.251156193869454, 24.764991760253906, 40.356009415217805, 54.747146129608154, 63.294712339128765, 63.23422827039446, 69.65037550245012, 61.99408599308559, 55.91474573952811, 50.28643390110561, 49.249620233263286, 48.501750877925325, 60.23375988006592, 49.22776467459542, 56.01611648287092, 61.053286007472444, 72.48621327536446, 41.76327671323504, 23.17427464893886, 50.93003511428833, 33.57076692581177, 36.28616809844971, 54.959229469299316, 5.263397659574236, 0.32105505945427076, 0.16302349365183286, 0.11780149596078054, 0.30243377866489546, 0.09055582473852805, 0.04381505872255989, 0.3116867978657995, 0.552159771323204, 4.300149347100939, 16.25086201940264, 30.457751614706858, 42.59088706970215, 32.288980620247976, 21.945485728127615, 17.075839008603776, 1.300579445702689, 0.05476180311026318, 0.04353116645610758, 0.17751423322728702, 0.07178761397621461, 0.09616532123514585, 0.01928180918496634, 0.1470981410571507, 0.036582282544778924, 0.14368420067642415, 0.05588493802185569, 0.05491708245660577, 0.01587539884660925, 0.10463574528694153, 0.044451633135655096, 0.0936236579769424, 0.1245437456028802, 0.08105737942137889, 0.11848666705191135, 0.049676023689763885, 0.10726411853517805, 0.07706728817096778, 0.07236110498862607, 0.045788642285125594, 0.08673035965434142, 0.16807116993835994, 0.08461786301008292, 0.023078945432124392, 0.0531923923242305, 0.03878128561856491, 0.039453900419175625, 0.020309363957494497, 0.02848220969151173, 0.10062385270638124, 0.17484829628041812, 0.1864792007420744, 0.057424371130764484, 0.04664377622040255, 0.056003885210624764, 0.05665257825915303, 0.13247594210718358, 0.08584405721298285, 0.07035469729453325, 0.20906726510397025, 47.07973255429949, 83.92390700748989, 55.01597888129098, 72.99662794385637, 76.77755274091447, 50.57368285315377, 38.00448887688773, 59.48519570486886, 28.6826171534402, 21.02282748903547, 21.28910677773612, 39.511646951947895, 41.74406494413103, 40.80109017235892, 17.679752111434937, 0.6618070676922798, 0.07681033374475581, 0.15599715496812547, 1.4150604626962116, 35.74314553397042, 38.45247745513916, 34.767517702920095, 63.331072262355256, 45.368377344948904, 23.38879680633545, 24.31768410546439, 32.10440519877842, 57.8191670690264, 69.62343733651298, 84.26799569811139, 73.06656156267438, 72.75044631958008, 74.69036252158028, 82.79497064862932, 71.13773468562535, 50.874876839774, 41.14225714547293, 44.66595268249512, 43.180420875549316, 41.38870974949428, 31.380312579018728, 28.935790402548655, 22.98923717226301, 31.106581347329275, 29.99750988824027, 41.25112499509539, 50.26016971043178, 44.37222106116158, 40.86633723122733, 14.693084580557686, 2.5153267085552216, 0.3061667526406901, 0.25499033874699045, 0.31118595759783474, 1.0272895331893648, 0.37219298684171265, 0.13149324698107584, 0.0409729096240231, 0.09822355543396302, 1.6164027558905738, 0.5472882155861173, 1.50029998591968, 0.6077776583177703, 1.666600450873375, 1.535742204104151, 0.8838164518986429, 2.3816570469311307, 11.077189922332764, 3.8349813478333608, 5.378490226609366, 0.16981585989040987, 0.33664654567837715, 0.4344857313803264, 0.24102318393332617, 0.4903073417288916, 1.4792901532990592, 0.5226994635803359, 0.14118997380137444, 0.5351113889898572, 0.3350388248051916, 0.20997950115374156, 0.6920146867632866, 4.245023208005088, 11.497110383851187, 37.66933209555489, 39.86804437637329, 41.50014843259539, 56.028571128845215, 28.90926218032837, 19.22558559690203, 18.196362836020334, 18.663658721106394, 16.60824087687901, 19.982956613813126, 24.8677955695561, 38.83554901395525, 58.58126286097935, 65.81419168199811, 67.44399588448661, 70.44743115561349, 64.66657161712646, 58.80754484449114, 52.415792737688335, 50.536086150578086, 48.16519750867571, 54.67367240360805, 46.42029987062727, 55.57687568664551, 57.685820715767996, 68.61369732448033, 34.82801914215088, 27.09872838429042, 58.85743291037423, 36.11501659665789, 38.58709185464041, 54.392277308872764, 7.437301397323608, 0.2664625202970845, 0.21944965156061308, 0.7638508634907859, 0.6205519757100514, 0.4280927101416247, 0.12350553274154663, 0.13002022887979234, 0.8520911399807248, 6.05497031552451, 22.285902295793804, 30.23568718773978, 49.379054750714985, 42.57588243484497, 35.803400312151226, 30.413258825029644, 3.494850524834224, 0.0610303029950176, 0.03695225715637207, 0.19853120403630392, 0.07767829538456031, 0.11002568142222506, 0.04374211960073028, 0.12829708919993468, 0.04181272902392915, 0.0778708839789033, 0.1831899615270751, 0.02178407330731196, 0.05012806371918746, 0.028548963966646364, 0.029448423202016523, 0.076020444344197, 0.06699932805661644, 0.1386268213391304, 0.24587074667215347, 0.09471468121877738, 0.21745767630636692, 0.2073506936430931, 0.15243970443095478, 0.23464164350714, 0.17680031939276628, 0.3238854461482593, 0.24326742493680545, 0.2268175104899066, 0.16429835238627025, 0.18628724318529877, 0.20541312332664216, 0.1930529022855418, 0.07767153039042439, 0.21494267268904618, 0.5511509254574776, 0.5483961818473679, 0.2216047059212412, 0.12198665924370289, 0.24027402698993683, 0.22137746454349586, 0.31062733328768183, 0.224946830155594, 0.3319637312420777, 0.281415695058448, 64.88708659580776, 96.30395712171281, 65.23069586072648, 83.96677044459751, 86.90809576851981, 75.76566573551723, 50.69912910461426, 60.782396589006694, 34.07621363231114, 29.349788393293107, 33.01088803155081, 48.29529905319214, 51.039493560791016, 53.877183028629844, 26.07517535345895, 0.9943261934178216, 0.17108315974473953, 0.3718611832175936, 1.1951573597533363, 22.80711793899536, 41.174312659672324, 51.71937131881714, 81.44954231807164, 37.65924678530012, 30.328320571354457, 53.35047483444214, 70.88167967115129, 103.59097072056362, 100.86465740203857, 104.99470138549805, 82.4342132295881, 77.44446168627057, 83.20868723733085, 91.9485205241612, 75.19949177333287, 56.1263427053179, 44.402341502053396, 43.55461611066546, 41.39564752578735, 43.218535218920024, 32.87292112622942, 32.26242460523333, 29.293827601841517, 38.23665598460606, 37.91473552158901, 55.75983565194266, 55.905233655657085, 40.004948207310264, 43.45877960750035, 25.996165650231497, 3.1075991903032576, 0.7461601527673858, 0.249138598463365, 0.5925441128867013, 1.157050833106041, 0.626836892749582, 0.5036392520580972, 0.16735471838286944, 1.311267837882042, 2.549183543239321, 2.168620284114565, 1.0756065462316786, 0.38169266709259575, 3.3535241654941013, 2.5030140663896288, 1.9696996552603585, 3.03550837295396, 16.62621934073312, 3.979466966220311, 8.930595210620336, 2.2075210767132893, 0.9544617725270135, 1.8396919114249093, 0.36034896810139927, 0.7344717085361481, 3.004376534904752, 0.8637624851294926, 0.2045806829950639, 1.1275876483746936, 0.5519557765551976, 0.3870704642363957, 1.290432470185416, 5.467619112559727, 22.899223259517125, 45.413321767534526, 45.628139223371235, 46.861816201891216, 65.07876655033657, 28.947710037231445, 24.86066324370248, 30.96928494317191, 22.681517090116227, 14.629281009946551, 18.063282251358032, 31.23467833655221, 52.21068886348179, 62.4667580468314, 66.20228331429618, 69.26796054840088, 72.34040532793317, 62.13610022408621, 58.830077852521626, 51.0799320765904, 46.728421211242676, 47.244338853018625, 52.76053803307669, 43.89196157455444, 55.98372745513916, 61.094808442252024, 80.11276449475969, 52.30752938134329, 35.61851222174508, 67.3220966884068, 46.98692546572004, 42.77639702388218, 67.27677358899797, 8.097685115677969, 0.3952184484473297, 0.8151589131781033, 0.3744528070092201, 0.40703483724168366, 0.33824536417211803, 0.3021874161703246, 0.7190821543335915, 1.4330415321247918, 9.26265743800572, 24.615400518689835, 44.801619734082905, 60.216667311532156, 54.748448916843955, 51.70864677429199, 53.18090752192906, 7.45452424458095, 0.1615863564823355, 0.21867321750947408, 0.3567880706063339, 0.253580451543842, 0.22709043084510735, 0.16317484767309257, 0.20137977546879224, 0.09169216054890837, 0.2863552128630025, 0.18099435791373253, 0.26928870007395744, 0.22178898246160575, 0.23400504195264407, 0.1865516547113657, 0.19023961467402323, 0.11937435370470796, 0.26164060618196217, 0.46713352522679735, 0.22322453185915947], [0.08058553295476095, 0.09785858501813241, 0.04895969766325184, 0.031498688007039685, 0.004806401532342923, 0.03951804572716355, 0.02780588500068656, 0.05704473078783069, 0.026487839208649736, 0.04306204091491444, 0.05800036593739476, 0.1028892911438431, 0.018202702714396373, 0.06060315163007804, 0.07145907410553523, 0.04865356641156333, 0.1926846206188202, 0.06733043278966631, 0.14475021990282194, 0.11187824487153973, 0.14179315072085175, 0.0954724419862032, 0.08087737086628165, 0.08627460125301566, 7.564648849623544, 61.21776376451765, 54.9314158303397, 49.32023477554321, 73.81565380096436, 54.691296509334016, 39.43156548908779, 38.662830693381174, 20.701360395976476, 9.176802022116524, 11.67493997301374, 18.21716226850237, 11.516555786132812, 3.180452138185501, 0.08462511654943228, 0.1463570451097829, 0.09365850753550019, 0.6102874236447471, 2.6107206983225684, 26.016365800585064, 31.06932510648455, 64.41242735726493, 51.10143327713013, 15.840999943869454, 54.87867900303432, 84.15734563555036, 92.53681060246059, 74.98878765106201, 63.12407152993338, 62.77712712969099, 66.96953119550432, 68.43007728031704, 66.10560607910156, 58.014831815447124, 55.07142203194754, 59.72575623648507, 56.65649025780814, 47.34114462988717, 34.72233356748308, 29.288300309862407, 26.07310826437814, 23.131261825561523, 22.67151689529419, 19.73936493056161, 19.583099944250925, 33.59674971444266, 51.67669548307146, 37.34242977414812, 27.55634195463998, 2.814880268914359, 1.2254828810691833, 0.5872642419167927, 0.09904517991734402, 0.2946695467191083, 0.12457654598568167, 0.18548065503793104, 0.43887175459946903, 0.2736001115824495, 0.07629091518798045, 0.6833410007613046, 0.39687418245843475, 0.4606291971036366, 0.8982396093862397, 0.39339978460754665, 0.7210110936846051, 0.25066237098404337, 2.5119283880506242, 10.499898842402867, 0.967837814773832, 6.309422901698521, 0.30077989026904106, 0.2374988187636648, 0.3385862058826855, 0.9162381035940987, 0.2448155161525522, 0.6935392192431858, 0.04041349142789841, 0.3502052224108151, 0.14997369104198047, 0.5176140336053712, 0.2016940186066287, 1.0361491377864565, 3.780608219759805, 4.030210963317326, 11.078341586249215, 27.51899538721357, 33.197829314640586, 35.62919160297939, 20.9892155783517, 22.20440513747079, 24.718643801552908, 11.221565672329493, 12.510912486485072, 21.175717387880596, 34.38008962358747, 54.656437397003174, 59.72870922088623, 64.35901655469621, 66.44334411621094, 63.51793711526053, 51.94527115140642, 51.375991344451904, 53.03127806527274, 53.287159374782014, 56.066181727818076, 57.5631502696446, 58.2707895551409, 53.29256854738508, 55.71738910675049, 55.246419361659456, 63.02791540963309, 33.985775879451204, 38.0638473374503, 48.901251452309744, 30.532337052481516, 57.92875058310372, 19.145663942609513, 0.5106953648584229, 0.17389589095754282, 1.856886965887887, 0.30702474660107065, 0.14522231742739677, 0.16950266169650213, 0.0832990419917873, 0.4636882500989096, 4.066566978182111, 38.18005248478481, 42.39046975544521, 38.65005643027169, 22.259323699133738, 17.520879813602992, 3.550168825047357, 0.02339553290845028, 0.07190232032111712, 0.03099204965734056, 0.13318308416221822, 0.016502117538558583, 0.06359357759356499, 0.020703289158908383, 0.11073534084217888, 0.0883164352604321, 0.049184109549969435, 0.12220366831336703, 0.023332106847582117, 0.021194897957944443, 0.02276350128730493, 0.063754621094891, 0.06697547076536076, 0.06268296324248825, 0.07368507608771324, 0.14253434166312218, 0.12208397473607745, 0.1919921620615891, 0.12536976699318203, 0.07066437389169421, 0.08229485087628875, 0.011106418944629175, 0.015752589097246528, 0.04194750304200819, 0.034871797543019056, 0.07852593490055629, 0.06461904078189816, 0.08710396103560925, 0.03281043869044099, 0.03176923348967518, 0.02980076608115009, 0.06616118124553136, 0.025123535988054106, 0.11992517486214638, 0.04408398589917591, 0.19092697064791406, 0.09336679176028286, 0.4034287493143763, 0.12146901844867639, 0.058386357368103096, 0.22674927700843128, 10.170756595475332, 72.54339000156948, 64.69740772247314, 61.2729046685355, 82.85712228502545, 59.964864594595774, 44.97759675979614, 60.71800763266427, 33.11064679282052, 14.202962126050677, 17.671968391963414, 21.347127710069927, 11.320392506463186, 2.618372836283275, 0.06382341776043177, 0.30923226528934067, 0.2575448059609958, 0.8821757542235511, 6.660333854811532, 38.196738583701, 26.814576591764176, 54.16264976773943, 63.77457577841622, 22.669243097305298, 29.641723905290874, 61.15714768001011, 77.4159323828561, 75.53358895438058, 63.200189045497346, 63.64760439736502, 65.4833323614938, 70.26140703473772, 65.64428043365479, 68.03744152614048, 61.25995322636196, 61.979202951703755, 57.49837916237967, 51.915216718401226, 39.45817014149257, 33.71206896645682, 30.280822685786656, 28.28694329942976, 24.649726356778825, 24.004188333238872, 22.802754470280238, 37.96027748925345, 49.25978544780186, 42.21843235833304, 43.950163160051616, 17.354225533349172, 2.4232645971434454, 0.11805342244250433, 0.1293689166860921, 0.528593435883522, 0.41849200959716526, 0.18305703651692184, 0.4220333924250943, 1.0530331517968858, 0.19649725460580417, 0.24121181666851044, 1.3472889278616225, 1.4328420971121107, 1.7680614122322627, 0.44960541863526615, 2.4722865266459326, 1.3602228909730911, 3.8473426273890903, 9.497523052351815, 5.131164755140032, 12.421945146151952, 0.25335067244512693, 0.3515428863465786, 0.40992246514984537, 0.9512134896857398, 0.4065543258828776, 0.5956240647605487, 0.20430952683091164, 0.6368506039891924, 0.061794299499264786, 0.7682404965162277, 0.16158081963658333, 1.293873131275177, 9.252272486686707, 15.521886553083148, 36.72800404684884, 42.253586769104004, 36.664563519614084, 49.43467855453491, 24.71855173792158, 13.263484903744288, 25.3541225705828, 13.279611672673907, 14.303000552313668, 18.912136725017003, 31.9192704473223, 56.1062867300851, 60.55170249938965, 64.32220499856132, 67.81401525224958, 68.33115577697754, 55.55972753252302, 51.853707790374756, 50.849192823682515, 51.882184982299805, 54.989207472120015, 56.4183338029044, 58.21837581907, 52.025595801217214, 56.219486781529014, 57.76681934084211, 64.31845297132219, 35.01372364589146, 43.81921740940639, 54.6249794278826, 34.90653378622872, 63.88394737243652, 26.786344323839458, 0.5290413232786315, 0.08026679112975087, 2.1465947117124284, 0.977270211492266, 0.1888237427920103, 0.10492695216089487, 0.03659075066181166, 0.20331126611147607, 6.107291987964085, 37.08117055892944, 40.19896623066494, 51.51478508540562, 34.45404624938965, 33.580661160605295, 8.548802120344979, 0.5061964605535779, 0.14338854939809867, 0.048111247297908576, 0.16362166298287256, 0.055615742823907306, 0.03763007292790072, 0.07196040291871343, 0.06724310533276626, 0.048138921348644156, 0.009087357420607336, 0.08449897010411535, 0.004956679227429309, 0.06950078811496496, 0.004493495108493204, 0.029479045487408127, 0.027804324370143668, 0.06578234835926976, 0.05859678464808634, 0.27102113568357056, 0.23421660917145865, 0.30747990789158003, 0.4426411794764655, 0.171910768906985, 0.14218519468392643, 0.13220243821186678, 0.14677906674998148, 0.1513313174779926, 0.14463902158396585, 0.06632949185690709, 0.224251426756382, 0.16460931141461643, 0.15214484025325092, 0.0988717395812273, 0.1406214428799493, 0.18879898983453, 0.23554566928318568, 0.2561569575752531, 0.19404961594513484, 0.2738039163606507, 0.1663082952478102, 0.5065908793892179, 0.5907993550811494, 0.20518770042274678, 0.6761518950973238, 15.65408297947475, 90.02728802817208, 77.38099684034074, 72.25280938829694, 94.85411821092877, 79.18858460017613, 53.91449138096401, 52.21262393678938, 37.63057156971523, 19.367693628583634, 26.45535819871085, 33.159388405936106, 20.05932252747672, 4.756686815193721, 0.1776287563677345, 0.46712983399629593, 0.6160100794264248, 1.5173697556768144, 2.7459619556154524, 36.13489539282662, 39.58007975987026, 81.12001705169678, 62.44906793321882, 20.160172155925206, 62.80257143293108, 98.01360307421002, 98.89327280861991, 76.4299065726144, 60.36739458356585, 60.334918703351704, 68.3588512965611, 72.9682445526123, 72.44567748478481, 69.40408965519497, 58.45172759464809, 62.25175298963274, 60.73649678911482, 54.7288167817252, 40.08257000786917, 33.47463859830584, 27.71573189326695, 29.437954085213796, 34.82934972218105, 29.14612627029419, 30.250792571476527, 44.30439969471523, 51.90311295645577, 45.74152340207781, 46.50688484736851, 23.62684382711138, 4.27197961296354, 0.527658686041832, 0.2189147895468133, 0.3739402959389346, 0.4839290039879935, 0.32220341211983133, 0.491938159934112, 0.5772244749324662, 0.13463453842060907, 0.6891414980803217, 1.381284617951938, 1.1900368630886078, 1.9620655391897475, 1.0955056441681725, 2.701378187962941, 1.2232741138764789, 3.6787758554731096, 15.694253989628383, 3.9417352080345154, 23.765123401369365, 1.7186299732753207, 0.4067986527723925, 0.809542597404548, 1.2603703290224075, 0.6766567251511982, 1.3505773799760001, 1.0777325864349092, 1.446814381650516, 0.49229246377944946, 1.6707566678524017, 0.3629740300987448, 3.072306901216507, 7.434489982468741, 20.12829555783953, 43.51599454879761, 50.043587412152974, 43.88840062277657, 53.30341815948486, 29.469881057739258, 27.69710898399353, 32.57458284923008, 13.876045039721898, 15.156678812844412, 26.86986861910139, 39.60881750924246, 56.03836114065987, 63.86950206756592, 63.87751334054129, 69.19794355119977, 65.90627615792411, 51.98476471219744, 48.17947605678013, 51.049405166081016, 55.78649588993618, 56.30177082334246, 53.65831477301461, 57.17462090083531, 50.29399701527187, 53.39220571517944, 60.35533251081194, 72.34347643171037, 46.40192188535418, 51.35214860098702, 64.12757900782994, 44.082922390529085, 68.18730722154889, 30.894880158560618, 0.5063570833631924, 0.40645216565046993, 4.295485368796757, 1.1417210442679269, 0.26390759167926653, 0.4308926984667778, 0.15176338143646717, 0.6398996146661895, 8.211300321987697, 53.415443965366904, 56.15735598972866, 65.70912102290562, 47.53459637505667, 53.60439327784947, 19.995593650000437, 0.6322351002267429, 0.2767561679439885, 0.1823119100715433, 0.31836458668112755, 0.16696890337126596, 0.29406817470278057, 0.26172547734209467, 0.30007684656551903, 0.2077398741883891, 0.20890118687280587, 0.18142286634870938, 0.10684003414852278, 0.1072094761101263, 0.19508153200149536, 0.12295581081083842, 0.18215681053698063, 0.13932632308985504, 0.1632629350892135, 0.22359704758439744, 0.3915538979428155], [0.10462336880820138, 0.03792267758399248, 0.122421763039061, 0.09732398763298988, 0.06347847091300146, 0.02953013578163726, 0.022910970695582882, 0.017749517657128826, 0.023127742277990495, 0.0399019235212888, 0.031311588760997565, 0.06728708118732486, 0.026578659424558282, 0.053470483116273365, 0.03409639147243329, 0.060511515475809574, 0.04173791714544807, 0.06966088845261506, 0.061105688235589435, 0.07168606442532369, 0.06815215226794992, 0.06992574781179428, 0.057203134787934165, 0.2971187052982194, 1.1489572674036026, 38.45334597996303, 68.70615700313023, 49.751078673771445, 62.52811064038958, 65.41640036446708, 42.169826235089985, 22.885686431612285, 14.300958650452749, 6.597053136144366, 6.826660701206752, 3.0586506511483873, 0.07074131297745875, 0.23761281264679773, 0.20387465373745986, 0.3904364321913038, 0.5153687340872628, 0.2736023100359099, 7.6990765162876675, 51.03132595334734, 61.05448109763009, 72.63424464634487, 25.178786516189575, 42.786009856632774, 94.75481455666679, 75.53869588034493, 72.84221117837089, 58.18600763593401, 63.1548798424857, 65.28416919708252, 68.43675449916294, 68.93981102534703, 66.57622146606445, 60.82705960954939, 57.707301071711946, 55.890777928488596, 58.16559730257307, 62.854196548461914, 58.90133857727051, 41.65070199966431, 32.800170012882774, 23.495548929486954, 25.888911519731792, 25.34062569481986, 23.763186591012136, 23.213481596538, 43.149025440216064, 36.63161516189575, 27.76728057861328, 6.652201422623225, 2.3280577744756425, 0.6275565741317612, 0.1535264461168221, 0.10744330606290273, 0.25327665784529274, 1.2479474927697862, 1.5311969965696335, 0.46641074972493307, 0.2775203069405896, 0.16548289810972555, 0.49647560502801624, 0.5427374169230461, 1.8561565365110124, 0.3467789191220488, 0.7703196363789695, 0.23838978952595166, 2.8092926144599915, 7.624479787690299, 5.81086186000279, 5.9169986333165845, 0.39552224214587894, 1.0110953450202942, 0.7286517779741968, 0.13110181369951793, 0.14852880500257015, 1.197002432176045, 0.36307331334267345, 1.988606137888772, 0.5072432500975472, 0.0775860214073743, 0.19289037957787514, 0.08673376590013504, 4.7344799382346014, 8.057628750801086, 15.645085062299456, 27.58448737008231, 27.72647554533822, 32.686688559395925, 27.115082706723893, 26.986395120620728, 17.122094903673442, 13.125920125416346, 25.563812255859375, 46.798684869493755, 49.59878805705479, 50.49722487585885, 62.398964473179404, 60.89172649383545, 64.21980939592633, 54.507881437029155, 54.15548964909145, 54.55705731255667, 57.84144994190761, 63.27675819396973, 62.961268288748606, 52.93642473220825, 60.81646360669817, 57.82492365155901, 60.41469097137451, 62.13835144042969, 58.74391324179513, 55.1218763760158, 28.844965287617274, 47.81014803477696, 35.38439267022269, 46.69490657533918, 30.988663469042095, 0.5885040068200657, 0.056060855010790486, 3.323128185101918, 2.900195462363107, 0.4193246534892491, 0.24976439774036407, 0.08722751547715493, 0.018542365470368947, 5.78047912461417, 37.241055556706016, 40.03519024167742, 30.36238064084734, 17.62339006151472, 9.144732611519949, 2.0548737134252275, 0.17992932934846195, 0.09276936881776367, 0.09201869195593254, 0.016889494877042513, 0.03600850994033473, 0.0349919084193451, 0.05424733446644885, 0.1001804368570447, 0.0744580224688564, 0.0637165688510452, 0.04748492215627006, 0.03039987518319062, 0.10890932168279376, 0.096622185648552, 0.042733959055372646, 0.033478378384773216, 0.05819678146924291, 0.05217420642397233, 0.07838110160082579, 0.021461031266621182, 0.19365806052727358, 0.044511405285447836, 0.039925349942807636, 0.03034652876002448, 0.08341175344373498, 0.06601824105850287, 0.09048936901880161, 0.08379469825220959, 0.03716235873954637, 0.15975066141358443, 0.10722610700343337, 0.013027252346676375, 0.028518423105457, 0.035650368979466815, 0.05583094699042184, 0.037554857321083546, 0.02913830555709345, 0.03809606024463262, 0.08105346427432128, 0.04246256201128874, 0.050997887937618155, 0.09999383972691638, 0.15079777182212897, 0.15971053285258158, 1.5015307941607066, 53.342324597494944, 81.51709965297154, 63.52427387237549, 76.01632894788469, 70.86972876957485, 44.12434755052839, 29.57840497153146, 19.010780300412858, 9.223305446760994, 5.65955571617399, 2.5811241950307573, 0.07262016965874604, 0.18183651486677782, 0.9717929682561329, 0.5204657262989453, 0.2840003435100828, 0.8397551019276891, 20.690257174628123, 46.10541098458426, 52.02005808694022, 73.39917182922363, 37.371594837733674, 29.667571204049246, 74.38543387821743, 74.3411808013916, 74.72249099186489, 61.90066746303013, 64.49360316140312, 66.81284931727818, 69.39838518415178, 67.36669022696358, 69.21650218963623, 65.44170570373535, 61.901751382010325, 56.311828340802876, 58.235027176993235, 65.61315945216587, 59.91866602216448, 39.899432863507954, 24.12369213785444, 23.138953481401714, 27.814867053713115, 25.942033972058976, 24.884693588529313, 26.380975995744976, 46.90752492632185, 39.68298952920096, 43.91249002729143, 25.40850612095424, 10.913832562310354, 0.4932691199438912, 1.4018089451960154, 0.21244248827653273, 0.3364160337618419, 0.4843684775488717, 0.42172468613301006, 0.5576790837304932, 0.2570908117507185, 0.27496934096728054, 0.17463695976350987, 1.6091681612389428, 3.9832876069205145, 0.4355932633791651, 0.49113032328230993, 0.8110310318214553, 4.311472739492144, 7.838628479412623, 8.360571946416583, 11.748867068971906, 0.2616495085614068, 0.8978468733174461, 0.5085900064025606, 0.20108482986688614, 0.5835745313337871, 0.8928157261439732, 0.33692547785384314, 0.58067251848323, 0.45118249686700956, 0.034170260187238455, 0.3163874170609883, 0.27131640698228565, 6.650432237557002, 22.685845817838395, 35.27545881271362, 41.5856842313494, 32.08909484318325, 43.44343103681292, 23.86950445175171, 22.490493740354264, 23.045908417020524, 14.283550807407924, 17.693318469183787, 35.617584637233186, 51.32712813786098, 50.88597658702305, 63.96642943790981, 62.475901876177105, 64.80425017220634, 57.69260215759277, 57.03163392203194, 57.13460622514997, 59.542177881513325, 60.74329907553536, 62.80291189466204, 56.8275340625218, 61.05530793326241, 55.098308086395264, 60.89011451176235, 64.47307818276542, 60.55965123857771, 59.37455259050642, 34.15282794407436, 53.27061223983765, 43.32027421678816, 53.121806144714355, 38.16409247262137, 0.5005174481442997, 0.20407655861760887, 0.20688751206866332, 3.7865993039948598, 0.7076343457613672, 0.30773134582809036, 0.019073371708925282, 0.019407528153221523, 8.028242213385445, 37.679702281951904, 44.811246463230674, 44.46400329044887, 31.123566218784877, 20.006698608398438, 3.4504602210862294, 0.15060980405126298, 0.06962711097938673, 0.1849521305412054, 0.02924914764506476, 0.03336855749200497, 0.03625284022252474, 0.08875306575958218, 0.008335015603474208, 0.0903154740642224, 0.019984627275594642, 0.15835910822663987, 0.018543386665572013, 0.039611978722470145, 0.06411915046295949, 0.07340027458433594, 0.0113296221908448, 0.057394644511597495, 0.05352347670122981, 0.13090818694659642, 0.14920763857662678, 0.35299733972975184, 0.17928765235202654, 0.17324980348348618, 0.25678661093115807, 0.19488896376320294, 0.12854030329201901, 0.14877907585884842, 0.14642025743212017, 0.16315602511167526, 0.3227802483098847, 0.19490511289664678, 0.21480928627508028, 0.10267492836075169, 0.23610955902508327, 0.2176208911197526, 0.12317341699131898, 0.15225659497082233, 0.21719501540064812, 0.09973752312362194, 0.1377611599330391, 0.1447258333542517, 0.222477736217635, 0.19600599525230272, 0.600729090826852, 1.113410609109061, 68.7280855178833, 95.93802329472133, 70.13408129555839, 86.44182995387486, 83.28991167885917, 58.468639510018484, 30.257549694606237, 25.20081925392151, 12.74989925112043, 10.491321291242327, 4.456008298056466, 0.23620137838380678, 0.4975094752652304, 0.6739114267485482, 1.2398892108883177, 1.3951649474246162, 1.471135139465332, 12.650181310517446, 60.68608066013881, 70.58296966552734, 86.37819140298026, 33.81008720397949, 57.91100835800171, 106.57584040505546, 75.82416956765312, 71.57601315634591, 58.05267865317208, 63.0279084614345, 67.56202493395124, 65.18877737862724, 64.30877413068498, 70.41774845123291, 70.87521784646171, 63.868015153067454, 56.446105752672466, 62.284228869846885, 68.95765399932861, 61.95565550667899, 45.77667433874947, 32.6717186655317, 26.874407529830933, 36.37303795133318, 38.77592304774693, 33.09827899932861, 25.562460831233434, 46.384693826947895, 41.226802825927734, 46.12695040021624, 31.907937935420446, 9.586275867053441, 0.5796826173152242, 0.8211185676710946, 0.38419203726308687, 0.8376558774283954, 2.4082004683358327, 2.6431646602494374, 3.929980158805847, 0.3066736454410212, 0.35059668283377377, 0.9607270934752056, 2.2403573947293416, 6.284460629735674, 0.3785251299185412, 2.460676303931645, 0.44781940590058056, 6.096574825899942, 11.798601405961172, 7.373024480683463, 22.643437487738474, 0.857367211154529, 2.143545972449439, 1.5716283470392227, 0.18643581521298203, 0.54728685851608, 3.957757753985269, 1.8124026443277086, 6.157690746443612, 1.0501804820128848, 0.19604674806552275, 0.5080016351171902, 1.2784038356372287, 7.302121588162013, 26.359848260879517, 37.62725033078875, 50.4700539452689, 36.9521564074925, 44.7680356161935, 33.78525086811611, 35.86473206111363, 20.357455832617624, 17.07517719268799, 32.15994562421526, 53.69036681311471, 50.00531326021467, 52.139636584690635, 65.91133444649833, 60.42747565678188, 64.57106862749372, 56.13960681642805, 56.2627705846514, 56.753997802734375, 60.837509700230186, 63.576871735709055, 59.025933674403596, 55.56206212724958, 63.40847519465855, 55.31085695539202, 59.92858804975237, 65.82425267355782, 61.11232485089983, 60.574200766427175, 40.63488926206316, 62.54056181226458, 50.481831141880576, 60.84474972316197, 40.62312943594796, 1.7308159193822314, 0.3838180830436093, 6.1357505066054205, 5.149535357952118, 2.530059495142528, 0.48911919976983753, 0.26754725351929665, 0.21056442548121723, 10.655700036457606, 53.20964527130127, 58.55217770167759, 57.48231145313808, 48.82884774889265, 37.49883025033133, 3.7389159883771623, 0.29503595562917845, 0.14587430815611566, 0.33918103682143347, 0.1313015472676073, 0.0793462498113513, 0.1540088030908789, 0.23622187014136994, 0.22831061322774204, 0.1880136669746467, 0.2033471470432622, 0.2949771944965635, 0.12431486217038971, 0.17806489153632096, 0.2194621501756566, 0.22226344128804548, 0.12027870517756258, 0.19929322600364685, 0.13772841383303913, 0.11096965255481855, 0.3434823245874473], [0.16833419725298882, 0.05869513151368924, 0.11150059942156076, 0.08624529532556023, 0.05063803706850324, 0.06578344758599997, 0.036808682539101155, 0.016125844425654838, 0.02509092559505786, 0.06089027372321912, 0.025988162628241947, 0.07219815480389766, 0.05178649829966681, 0.026531638644103493, 0.10873606455113206, 0.025849015451967716, 0.04628352840830173, 0.05214062233322433, 0.03788986023781555, 0.04152758146769234, 0.04510503521721278, 0.040212007239460945, 0.13222208858600684, 0.1333303398319653, 0.05075797152572444, 16.26372834614345, 63.82328265053885, 54.893482140132356, 58.91742365700858, 75.74173613956997, 55.29240601403372, 40.74432338987078, 10.280532922063555, 2.531984580414636, 0.6409349505390439, 0.12932456763727324, 0.10774963069707155, 0.2644568250647613, 0.15199012069829873, 0.17443113295095308, 0.2981670961848327, 2.7282772702830176, 21.384338787623815, 68.12116731916154, 62.811458178928916, 53.70868226460048, 35.70677866254534, 79.00852898189, 76.31348950522286, 65.325761113848, 64.73972225189209, 66.03895895821708, 66.20707062312535, 67.20789609636579, 59.600556646074565, 64.38304342542375, 65.7628653390067, 66.7650248663766, 65.4344378880092, 58.791598728724885, 60.55964429037911, 58.766362871442524, 61.24015780857631, 65.87485640389579, 66.45277282169887, 40.12141043799264, 22.864914791924612, 25.17418680872236, 23.856070109776088, 22.088151352746145, 37.101358549935476, 32.03618778501238, 34.1433436529977, 9.227535162653242, 1.4697422427790505, 0.6126274466514587, 3.126464852264949, 0.6392031120402473, 0.548746251634189, 1.2908313402107783, 0.3300224696951253, 0.35727544873952866, 1.8144516029528208, 0.18817618968231337, 0.07549987227788993, 0.6887999506933349, 1.0755334815808704, 2.2349388854844228, 1.3896660996334893, 0.29685646508421215, 5.127407516751971, 6.994947373867035, 7.91067521912711, 6.2458473188536505, 0.7752685993909836, 0.1050115315509694, 0.24791658403617994, 0.13371995463967323, 1.3913552718503135, 0.5310281280960355, 0.17609392372625216, 0.958306189094271, 1.140658295580319, 0.06660599487700633, 0.2199854499527386, 0.6506064087152481, 6.051604781832014, 14.28996660028185, 15.37144068309239, 36.79140983309065, 27.973680291857036, 31.714176995413645, 38.10778079714094, 22.817013910838536, 11.73044044630868, 21.39131999015808, 48.80900021961757, 56.45363065174648, 49.82584129061018, 58.17546374457223, 55.673473017556326, 57.824565819331575, 58.32640988486153, 57.758752482278005, 54.17465278080532, 53.00105687550136, 59.24268967764718, 61.07026045663016, 57.19863040106637, 56.57943820953369, 58.46561704363142, 60.541495595659526, 58.49585560389927, 64.20949826921735, 54.30471958432879, 63.28089237213135, 40.37511348724365, 33.18234177998134, 55.28440516335623, 42.641991070338655, 52.07750926698957, 5.64239844254085, 0.3432101777621678, 2.344245340142931, 1.1974083589656013, 0.991250855582101, 0.11878016058887754, 0.14316361503941671, 0.11307880402143512, 9.000322989055089, 31.21223565510341, 30.232508386884415, 24.16933832849775, 18.867008175168717, 8.25057762009757, 0.3452297965330737, 0.07175935977803809, 0.07972057043973889, 0.071219720877707, 0.052326296655727286, 0.01458062680571207, 0.040057928900101354, 0.06401635240763426, 0.0049388977931812406, 0.06786114216915198, 0.03380813283313598, 0.09357039976332869, 0.0557904045230576, 0.08945596018540007, 0.10137891290443284, 0.05213946203834244, 0.009610371364812766, 0.00043125703190785965, 0.04259440475808723, 0.015506767734353031, 0.06448724892522607, 0.20129928764488014, 0.11525556471730981, 0.19572715807173932, 0.009697262862963336, 0.03949392041457551, 0.043295467139354775, 0.124370651319623, 0.03151538675384862, 0.06750368992132799, 0.04985523157353912, 0.10995870323053428, 0.03140074486977287, 0.00728045598537262, 0.02353588448438261, 0.16420592234602996, 0.009576529430757676, 0.04936109523155859, 0.04962595798341291, 0.05818468318986041, 0.1343604102730751, 0.0669129505487425, 0.03075910180008837, 0.09099671643759523, 0.11511449728693281, 0.11761043407022953, 24.535173143659318, 84.9268308367048, 63.57402992248535, 67.6001844406128, 83.55103887830461, 54.31255367824009, 33.11562517711094, 11.574149404253278, 2.44678772347314, 0.2940465972891876, 0.1298757687743221, 0.20121523072677, 0.6391157710126468, 1.496199137398175, 0.07606834891651358, 0.7435911106211799, 9.112009201731, 25.38891393797738, 48.420648029872346, 61.106425830296104, 61.49259281158447, 31.868909903935023, 67.13409233093262, 78.54265226636613, 65.36208629608154, 71.09812995365688, 68.47628280094692, 67.25428921835763, 66.1911175591605, 63.18775871821812, 62.49261229378836, 66.19713469914028, 67.54351493290493, 65.16790499005998, 58.3190586907523, 61.84855597359793, 59.80190849304199, 61.13100855691092, 63.493931089128765, 51.674204553876606, 23.51833380971636, 22.99290755816868, 23.39866672243391, 22.75680603299822, 24.662026405334473, 38.69160665784563, 37.21561820166451, 40.854827540261404, 20.263250419071742, 15.308344091687884, 9.449537055832998, 6.050106576510838, 1.8552691212722232, 0.8906747581703323, 0.7790871230619294, 0.19962984722639832, 0.34125276708177155, 0.8297596839921815, 0.16719287421022141, 0.14571285753377847, 1.90716586794172, 3.248788756983621, 1.5615838574511665, 1.4229891172477176, 0.7814187865172113, 5.9687835574150085, 7.868819270815168, 10.170546412467957, 8.698625258037023, 0.9325983971357346, 0.35041399406535284, 0.2724024701331343, 0.18650924627270016, 2.0059781542846133, 0.5993705008711133, 0.3168362815465246, 0.32682958245277405, 2.0474115652697424, 0.3282922868217741, 0.2609143294394016, 0.4915742480329105, 8.541708009583608, 17.980657747813634, 29.904449190412247, 52.35585757664272, 31.596999100276403, 41.24198463984898, 31.89473635809762, 27.922670091901505, 13.472574438367571, 13.895109159605843, 34.60309553146362, 55.10128191539219, 49.9787711415972, 62.40263312203543, 59.08122743879046, 59.205009596688406, 58.573953356061665, 59.250978878566194, 54.469301564352854, 54.67774057388306, 59.461683000837056, 60.665312494550435, 58.65897151402065, 57.79881926945278, 58.8818210874285, 60.41817201886858, 60.32075827462332, 64.05137811388288, 56.9259101322719, 63.279064995901926, 47.743730204445974, 37.08701746804373, 61.007031849452424, 46.816409724099294, 61.32521765572684, 9.118790643555776, 0.2556393982044288, 1.0455486391271864, 1.7222523731844765, 1.3202007242611475, 0.06354782397725753, 0.05676325749871986, 0.14287219781960758, 13.901216626167297, 37.18970489501953, 44.73537213461739, 36.386531352996826, 28.674058709825786, 12.816591535295759, 0.47293413111141747, 0.07745209216539349, 0.09694653217281614, 0.023531219556129405, 0.014135520556010306, 0.09687795263848134, 0.02330961850072656, 0.10018813822950635, 0.032986932434141636, 0.05008565528052194, 0.0395791715543185, 0.07034506209726844, 0.033300561497786214, 0.034669098776898215, 0.06249525331492935, 0.01659972480099116, 0.03508007725966828, 0.05874343642166682, 0.0706707996183208, 0.02956147731414863, 0.028202824593920792, 0.5179344106997762, 0.18289398455194064, 0.3109626110110964, 0.14256562212748186, 0.14077989437750407, 0.1178407288555588, 0.15756182957972797, 0.1496398789542062, 0.10704812726804189, 0.15474832483700343, 0.19678267357604845, 0.24371061686958584, 0.12116545545203344, 0.10226731201899902, 0.14822381708238805, 0.3636811450123787, 0.24474850403411047, 0.20104281497853144, 0.18237586878240108, 0.28726982378533905, 0.10789738848273243, 0.09742261948330061, 0.22627865869019712, 0.17597408087125846, 0.19706288139734948, 30.823344979967388, 100.6894724709647, 75.82123742784772, 82.66281591142926, 93.20133631569999, 73.82903603145054, 55.603445598057334, 18.23874511037554, 3.0876196452549527, 0.6289562018854278, 0.21947226034743444, 0.2336010422025408, 0.4438759775034019, 0.9235136274780545, 0.5925996984754289, 1.7029612426246916, 12.803092922483172, 26.75132887704032, 76.25793865748814, 75.66035883767265, 67.58732332502092, 49.15071957451956, 91.85454613821847, 79.10891655513218, 65.57070595877511, 65.07689748491559, 67.83724308013916, 66.27230725969586, 66.09571879250663, 59.81159428187779, 59.33356516701834, 66.03087125505719, 68.29361465999058, 71.67441354479108, 59.064419746398926, 63.62990733555385, 59.29705933162144, 59.27598544529506, 67.70928505488804, 72.58475957598004, 46.88717017854963, 28.014818838664464, 33.06710590635027, 34.63577290943691, 26.560222148895264, 42.7370320047651, 39.68286793572562, 38.6069324357169, 25.432703222547257, 17.038002593176707, 6.3289942400796075, 7.777618953159877, 4.211476002420698, 4.222679972648621, 2.1516849185739244, 0.2855207233556679, 0.9476378815514701, 6.219051156725202, 0.2902496781732355, 0.27273997345141, 2.2578805344445363, 5.70912503344672, 3.7147210580962042, 2.0599925816059113, 0.3860838743192809, 8.290576662336077, 11.024225541523524, 11.267223153795515, 16.43048858642578, 2.1294804300580705, 0.6067115983792714, 0.6991781166621617, 0.13336417158799513, 2.8478162501539503, 1.4485936633178165, 0.7819038033485413, 3.52241359438215, 7.204818146569388, 0.6044958829879761, 0.5539408986057553, 0.6002985196454185, 9.963318126542227, 27.502903359276907, 33.17694650377546, 54.846970898764475, 34.316103662763325, 45.43682752336775, 47.230404240744456, 28.391847201756068, 14.196938037872314, 27.387137685503276, 60.15832328796387, 59.379694257463726, 46.544926234654014, 57.82438169206892, 55.783695765904014, 59.86711733681815, 58.29610184260777, 57.657162870679585, 52.02187851497105, 52.360738686152864, 60.570650236947195, 58.78785364968436, 56.72683729444231, 59.74847684587751, 57.79315996170044, 60.311336517333984, 58.44921929495675, 65.77159922463554, 56.41042675290789, 65.3402133669172, 47.97794355664934, 47.21149124417986, 67.96889754704067, 53.02556317193167, 66.50730923243931, 10.68242541381291, 0.38072225345032557, 8.168333530426025, 3.2164798506668637, 1.4839088597467966, 1.9917881957122257, 0.2151200688843216, 0.23852734214493207, 23.546560866492136, 56.1435672896249, 57.97447667803083, 52.79206895828247, 44.26381179264614, 14.66997834614345, 0.49868909482445034, 0.1295389168496643, 0.15273265513990605, 0.19254130045218126, 0.1953918124948229, 0.21989392914942332, 0.1718906978411334, 0.25766392956886974, 0.10307128780654498, 0.17852747599993432, 0.1298459946577038, 0.2313898051423686, 0.12935587524303369, 0.1740963573434523, 0.24540369744811738, 0.1724120570080621, 0.07409269242946591, 0.1709307064967496, 0.1539909847612892, 0.20484399529440062, 0.12449776807001658], [0.02635260039408292, 0.029232262301125696, 0.0779105918481946, 0.05835152816559587, 0.0613672634852784, 0.07460865045764617, 0.058708444370755127, 0.03852127439209393, 0.05980943529201405, 0.04553127734522734, 0.007127538789063692, 0.025623979313032966, 0.019995585616145815, 0.04892738243298871, 0.0914095507136413, 0.1140323696391923, 0.08965471666306257, 0.07680574684802975, 0.06478697819901363, 0.025561080813141804, 0.06410795463515179, 0.056432627740183046, 0.05671826384163328, 0.054329182753073316, 0.18712083702640875, 2.2948681839874814, 43.89273282459804, 60.36862441471645, 69.42586530957902, 78.49973324366978, 61.23527322496687, 62.136169706072124, 7.452435442379542, 1.8579274586268832, 0.027814543107524514, 0.1321716598634209, 0.06976119628442184, 1.0298310539552142, 4.039115514074053, 0.5193433750952993, 1.541900913630213, 3.554014435836247, 56.677505084446494, 66.07250486101422, 72.33206054142543, 50.201783997671946, 56.16580499921526, 77.38985579354423, 63.08502960205078, 66.93198313031877, 65.14988831111363, 73.67175660814557, 66.37990011487688, 67.07589421953473, 68.72039386204311, 67.19841180528913, 63.17934444972447, 61.87099865504673, 66.26680428641183, 66.65568106515067, 56.53698819024222, 59.05707550048828, 62.23930876595633, 65.55871336800712, 65.61973939623151, 67.27291733877999, 29.95115498134068, 27.139053991862706, 37.131472042628694, 25.75976882662092, 38.76312099184309, 34.9661215373448, 32.60645423616682, 15.325429712023054, 8.397620609828405, 6.223048107964652, 6.3113957558359415, 0.17718840071133204, 0.3510780898588044, 0.02583053894340992, 0.16511813125440053, 0.12140849312501294, 0.45933172958237783, 0.3075016752949783, 0.4781518482736179, 0.16538375057280064, 0.35903035742895945, 0.8785620938454355, 1.246339419058391, 0.8463145270943642, 2.864237231867654, 6.149413704872131, 4.96173597233636, 6.659880919115884, 0.6247453764081001, 0.03953723130481584, 0.46883322830711094, 0.29304263687559534, 0.4022159901048456, 0.18630579433270864, 0.2021777733628239, 0.046049501680369885, 0.9168818976197923, 0.1964290211243289, 0.08834280991660697, 0.23464175207274302, 3.8651773503848483, 26.137756041118077, 22.81959864071437, 38.27879680906023, 25.452119963509695, 40.434892313820974, 44.96823058809553, 19.265779188701085, 29.530545779636928, 45.95732055391584, 62.66986778804234, 51.300443581172395, 55.340428488595144, 52.281883580344065, 52.93106419699532, 58.93949113573347, 59.73236397334507, 57.05655711037772, 60.67404638017927, 61.65563229152134, 65.39236654554094, 62.173516273498535, 64.17447934831891, 61.15793282645089, 61.24653625488281, 58.23403705869402, 61.594543729509624, 59.72208758762905, 63.13768999917166, 58.24022095543997, 63.58630738939558, 28.569585595812114, 45.39517307281494, 43.286624091012136, 45.880713190351216, 21.227993897029332, 0.1805452491555895, 0.24863433837890625, 3.822543638093131, 0.8265826744692666, 0.3764653690159321, 0.1733038013002702, 1.7583259003502982, 11.785097581999642, 33.33167593819754, 37.53868164334978, 31.615787029266357, 24.401604448046, 2.988527693918773, 0.04691644551764641, 0.06121570590351309, 0.021084966803235666, 0.04975697970283883, 0.060201771025146754, 0.02782531824362065, 0.02508077980019152, 0.0025048111731718692, 0.027780294052458236, 0.031261431452419074, 0.06197160069963761, 0.02280044412639524, 0.02935065987652966, 0.09073385875672102, 0.08315206452139787, 0.031517653060810905, 0.027263537049293518, 0.05787607867802892, 0.066375625452825, 0.009775090829602309, 0.030271241907030344, 0.05017495048897607, 0.14317863780472959, 0.04589539959228464, 0.03807245401133384, 0.055750157218426466, 0.02687302657536098, 0.021118096275521175, 0.0571518103991236, 0.12021281942725182, 0.03134017883400832, 0.03798989326293979, 0.04953943798318505, 0.0646184708124825, 0.03555824767266001, 0.03018237417563796, 0.10487375501543283, 0.12846668224249566, 0.04635010287165642, 0.008028247377036937, 0.02774012817202934, 0.04106695797028286, 0.06184274689959628, 0.02319337018499417, 0.05691205005028418, 0.13399581983685493, 3.8591224295752387, 60.61648055485317, 75.1867904663086, 80.80416584014893, 85.03778662000383, 64.29101453508649, 51.531630992889404, 12.092637879507881, 1.6259790020329612, 0.05066133796104363, 0.418814123741218, 0.39424461498856544, 1.9459526666573115, 2.1340073985712866, 0.30081308420215336, 4.4915127243314465, 8.528307540076119, 26.19169316973005, 46.859613622937886, 77.45594011034284, 53.592171396527974, 55.94356686728341, 77.37231159210205, 64.45958478110177, 71.13018199375698, 66.02107429504395, 75.53735487801688, 67.27154854365757, 67.18721825735909, 66.59096554347447, 64.86747183118547, 61.10774598802839, 64.71429184504917, 68.30903271266392, 66.83659131186349, 57.703031403677805, 61.13489954812186, 63.67224965776716, 66.70755631583077, 63.908627373831614, 48.84606885910034, 20.964648485183716, 25.823897225516184, 31.593396459306987, 30.65880468913487, 39.43745061329433, 38.391187395368306, 40.34167875562395, 14.966819286346436, 16.433391196387156, 18.28156512124198, 9.213975753102984, 0.6076479767050061, 0.27799286586897715, 0.09572959997292076, 0.140739575826696, 0.15121622436812945, 0.6134545536977905, 0.20919242767351015, 0.37255358749202316, 0.5417709659252847, 0.5286193287798336, 1.2412175110408237, 1.6984787860086985, 1.286370922412191, 4.2872152754238675, 7.482403022902353, 6.13851762669427, 11.208788803645543, 0.35151324793696404, 0.24821177391069277, 0.47581687356744495, 2.5603571150984084, 0.8715694919228554, 0.0740008730707424, 0.24340633462582315, 0.7089286648801395, 0.6135556282741683, 0.23810477767671856, 0.20207165048590728, 1.1149460524320602, 12.806931802204677, 25.601167508534022, 31.62065771647862, 52.698250906808035, 31.180287837982178, 41.644962787628174, 46.28094679968697, 21.17489055224827, 10.221935289246694, 25.79514557974679, 56.28703022003174, 55.18941634041922, 56.1857567514692, 56.858168670109336, 52.75325632095337, 56.56523609161377, 57.55564621516636, 59.216446331569124, 60.29170090811593, 63.59720911298479, 65.41321808951241, 61.90489196777344, 64.34933076586042, 61.62043966565813, 59.695663588387625, 57.97397640773228, 63.172583852495464, 61.502626010349815, 65.98926544189453, 62.309089524405344, 66.80343450818742, 37.93877281461443, 47.6274208341326, 53.116223267146516, 49.85841791970389, 32.20055089678083, 0.07739841326006822, 0.6293786306466375, 1.7581554523536136, 0.29983431100845337, 0.027452788947682296, 0.2348731867969036, 3.5273733053888594, 24.28036880493164, 42.24158028193882, 49.592274120875764, 42.2404442514692, 30.059831755501882, 4.155829182692936, 0.1501429990998336, 0.022284175668443953, 0.07531169416116816, 0.029058536980301142, 0.07254148673798357, 0.029806604874985557, 0.034486569464206696, 0.12043522963566439, 0.04331552463450602, 0.010319048605327095, 0.05767361739916461, 0.011308719919595336, 0.034309627887393744, 0.04925446345337799, 0.02516961021215788, 0.045705433535788736, 0.022546015546790192, 0.027363944965015565, 0.025461724626698663, 0.018245888075658252, 0.04210479763735618, 0.14240923337638378, 0.1846166221158845, 0.14469111950269767, 0.1601707288729293, 0.17421561665832996, 0.1689009504126651, 0.12228738596396786, 0.1228142005524465, 0.232203585760934, 0.16867274551519326, 0.14258542177932604, 0.0982564033142158, 0.13978090084024838, 0.09277542135013, 0.12072001078299113, 0.2041077169456652, 0.21651667037180491, 0.12141305288033825, 0.14017419330775738, 0.12847421398120268, 0.11029303100492273, 0.20356540461736067, 0.1837907364325864, 0.257964086319719, 0.25549071761114256, 4.15859717130661, 78.46140003204346, 85.17010116577148, 89.37188529968262, 95.52042266300747, 75.81554685320172, 75.1910149710519, 17.485421419143677, 1.9750165471008845, 0.13816848450473376, 0.3015696236065456, 0.452038156666926, 2.020716586283275, 12.337668708392552, 0.9005106932350567, 8.251772710255214, 10.930108717509679, 67.61801351819719, 79.70957442692348, 86.58118302481515, 62.14698110307966, 70.39958586011613, 77.16194793156215, 64.36792414528983, 71.76834624154228, 65.46414838518415, 74.50229563031877, 64.86743014199394, 64.30487619127545, 66.36152907780239, 63.08790615626744, 60.46361323765346, 64.16666262490409, 70.06126417432512, 70.48040035792759, 56.401043210710796, 59.02352959769112, 59.878331729343955, 67.84248202187675, 65.12882832118443, 79.21839237213135, 38.01607847213745, 33.49552140917097, 46.94926970345633, 35.718118122645784, 43.264789376940044, 40.74611602510725, 42.794535296303884, 20.17346579687936, 20.627634797777446, 24.896201542445592, 15.476403645106725, 0.6217947804502079, 0.31502342596650124, 0.25752344567860874, 0.2598927271153246, 0.32793920433947016, 1.9614343387739999, 0.9509426185062954, 0.7293070256710052, 0.27344809259687153, 0.5513998121023178, 4.280467706067221, 3.1849979971136366, 1.1414620067392076, 5.387702235153743, 11.42632474218096, 6.714328306061881, 13.884392431804113, 0.6397877378123147, 0.42497647021498, 0.9646632479769843, 3.7215216074671065, 3.449125732694353, 0.7006072199770382, 1.2205227358000619, 1.1674257963895798, 3.64635078396116, 0.3721593857875892, 0.1865820259388004, 0.8499988636800221, 17.5772123336792, 37.22320563452584, 35.08726685387747, 50.6655866759164, 35.075152669634136, 50.577771868024556, 49.27492209843227, 24.025237900870188, 38.54200846808297, 55.6598927634103, 67.1186534336635, 52.523934500558035, 53.32853242329189, 54.85316869190761, 56.993373666490825, 60.06343868800572, 56.68264675140381, 54.25432082584926, 60.60593318939209, 63.02881867544991, 69.13987745557512, 63.6121129989624, 66.5030152457101, 61.67464256286621, 58.65374646868025, 59.001587186540874, 63.97624724251883, 63.210965701511924, 65.13091972896031, 62.44490596226284, 67.18400124141148, 42.86837032863072, 57.67488772528512, 58.86820261819022, 58.391403334481375, 33.94211687360491, 0.590989887714386, 1.7258265699659074, 9.09126969746181, 2.2373386195727756, 0.38797864264675547, 0.4483594926340239, 5.4604038425854275, 40.72642135620117, 58.840305600847515, 64.3106848852975, 52.84593834195818, 34.37249871662685, 3.4999174986566817, 0.18943336579416478, 0.10883817728608847, 0.13585493793444975, 0.12654760879065308, 0.18483126988368376, 0.12711939668016775, 0.1473899246858699, 0.217920505042587, 0.10342135080801589, 0.21600763340081486, 0.12271698005497456, 0.07763405490134444, 0.2367709135370595, 0.20269978392337049, 0.15127782177712235, 0.1153595434235675, 0.06621001541082348, 0.16741485015622207, 0.1248734321977411, 0.06591378737773214, 0.14263502268918923], [0.021807150283296193, 0.058679633773863316, 0.034693963692656586, 0.02823557747927095, 0.033580725214311054, 0.018842244021860615, 0.04058787153501596, 0.06148777130459036, 0.049932900084448714, 0.07897735067776271, 0.03940158876191292, 0.03693850325154407, 0.0328813727412905, 0.009324326446013791, 0.082150336488017, 0.029503082590443746, 0.015059104255799736, 0.07057156387184348, 0.04379624973184296, 0.06943507199840886, 0.0957665801314371, 0.07087180883224521, 0.1991131835217987, 0.013759603673991348, 0.06904669212443487, 0.09633154195866414, 23.633481093815394, 69.67374229431152, 64.74880354745048, 67.93519878387451, 65.68086964743478, 52.44858128683907, 11.649295909064156, 0.22780415468982287, 0.23469812476209231, 0.34422800743154114, 1.6394374455724443, 2.391706964799336, 2.1947735207421437, 0.17846882343292236, 2.8661833788667406, 20.49860848699297, 66.77651718684605, 64.67982183183942, 66.93723596845354, 38.68524905613491, 70.24053464617047, 72.08642087663922, 65.51764256613595, 66.68086828504289, 70.24648230416435, 67.20940385546002, 68.38900647844586, 64.44719614301408, 69.6792244229998, 69.14301804133824, 63.86319310324532, 66.42372935158866, 67.84746388026646, 66.800231388637, 62.13961601257324, 59.23900018419538, 61.523012025015696, 62.326050077165874, 62.582063402448384, 67.5104831968035, 57.310301848820274, 21.328946011407034, 29.492386272975377, 31.084468705313547, 44.819181306021555, 35.7809784752982, 33.8329815183367, 18.71285023008074, 12.045459611075264, 2.3971287310123444, 6.276652157306671, 0.6227129197546414, 0.44304447355014936, 0.09221392005149807, 0.29090631008148193, 0.06113149292234864, 0.3310340568423271, 0.44284799695014954, 0.3582459438060011, 1.4830950519868304, 1.7673278344529015, 1.6823831754071372, 1.4418362144912993, 1.0228755814688546, 4.999954538685935, 5.262037115437644, 2.3824934363365173, 7.305135369300842, 0.10946396299238716, 0.09858942830136844, 0.5374416953751019, 0.9875862236533846, 0.2928666520331587, 0.2043967864343098, 0.09029509765761239, 0.8168130187051637, 0.5428216638309615, 0.5331149761165891, 0.40511005052498406, 0.15304244708802017, 5.8775389449937006, 22.508929048265728, 20.3283463546208, 42.461612360818044, 28.26608828135899, 44.62242569242205, 34.058325495038716, 32.639096873147146, 94.82115595681327, 54.682204791477744, 58.23526341574532, 52.16415330341884, 52.114890575408936, 61.11112976074219, 58.842278889247346, 59.962849617004395, 60.29437596457345, 57.217004912240164, 58.46122578212193, 58.32264396122524, 59.31527056012835, 59.654613631112234, 63.9191677910941, 60.34186690194266, 60.00815882001604, 59.98267977578299, 62.28034482683454, 59.87231458936419, 60.77497591291155, 61.402419090270996, 64.20088250296456, 46.820321559906006, 32.19292524882725, 47.17672593252999, 44.338765484946116, 41.01471601213728, 0.8579470600400652, 0.05775147929255452, 0.9221056401729584, 2.019085713795253, 0.07812960259616375, 0.6429707184433937, 5.834602986063276, 17.524204526628765, 33.10715184892927, 47.2515024457659, 38.25045510700771, 10.731199162346975, 0.11868973901229245, 0.07330577501228877, 0.018890294479206204, 0.05567044970978584, 0.07331957641456809, 0.05841556830065591, 0.14121385823403085, 0.05383151463632073, 0.022377665919650878, 0.0038406350067816675, 0.07009253171937806, 0.03108808271852987, 0.020883898217497126, 0.0515426192432642, 0.02469255598927183, 0.02769817944083895, 0.06444498297891446, 0.02153395681775042, 0.04506050974928907, 0.031209967963929688, 0.037264888773539236, 0.04680505381631, 0.005803164385724813, 0.042786582838743925, 0.06434166923697505, 0.037846054017011604, 0.08684788870492152, 0.12802420955683502, 0.042257288204772134, 0.014645074061783296, 0.03966604778543115, 0.08564891054161958, 0.1541285373802696, 0.04621326610712068, 0.02866123097815684, 0.029472528158554008, 0.10163736010768584, 0.02240076834069831, 0.10028989812625305, 0.09255656666521515, 0.03332177928781935, 0.04680234985426068, 0.1155409294047526, 0.026086297451651523, 0.1691849444593702, 0.06236285077674048, 0.10251374236707177, 0.07475560078663485, 36.87064708982195, 86.22210706983293, 75.17807047707694, 80.50310039520264, 72.29435266767229, 55.52003594807216, 16.990872962134226, 0.12215090543031693, 0.16156404625092233, 0.4801708970751081, 2.7350854192461287, 1.760564305952617, 0.34443213790655136, 0.18199793834771427, 4.002538459641593, 26.707676819392614, 55.31606810433524, 63.084251403808594, 72.6754961013794, 45.31778056280953, 73.6416083744594, 73.32169246673584, 65.8381768635341, 67.35216849190849, 70.02949701036725, 70.07935033525739, 69.01872866494315, 67.09302152906145, 71.85768617902482, 69.1638001033238, 62.826834542410715, 67.44223799024309, 66.78081117357526, 66.87845420837402, 62.25733239310128, 59.82629667009626, 61.30066967010498, 63.73331042698452, 62.65474850790841, 62.60397802080427, 39.32710974557059, 21.528739724840435, 33.39613437652588, 36.4893091065543, 43.546545778002056, 43.83577496664864, 37.90811388833182, 20.50587456566947, 15.250736577170235, 8.854557599340167, 4.487415458474841, 0.6020297610333988, 0.23477056516068323, 0.12303954203213964, 0.23834240064024925, 0.3177712213780199, 0.24365500413945743, 0.20083682531757013, 0.020364774823454872, 1.4598847031593323, 2.7094563373497556, 2.9160623252391815, 1.111968097942216, 1.1284001533474242, 5.100336900779179, 7.3503290585109164, 3.533114471605846, 7.26903817483357, 0.48777901168380466, 0.4265903521861349, 1.9642822316714694, 0.9252543683562959, 1.037460935967309, 0.2336995383458478, 0.33142733573913574, 0.8243523027215685, 1.9906478226184845, 0.588882792208876, 1.3181945404836108, 1.9670623796326774, 14.882944107055664, 23.49145644051688, 30.013032163892472, 53.003818784441265, 33.04697002683367, 48.72954756872994, 38.81153951372419, 33.68937267575945, 80.0650303704398, 43.73877116612026, 58.197347096034456, 55.466201305389404, 53.515887124197825, 60.50219658442906, 58.06666885103498, 61.03539439610073, 61.095982687813894, 59.95444924490792, 60.03194945199149, 62.103534017290386, 61.94956193651472, 64.28861740657261, 64.73390660967145, 62.32688386099679, 61.43056624276297, 60.88835661751883, 63.31106145041329, 62.81307710920061, 63.03485666002546, 65.113785471235, 65.33534962790353, 53.00419051306588, 37.767006397247314, 53.46684673854283, 49.72291415078299, 54.9806090763637, 2.795152161802564, 0.05051379052123853, 0.5454351635915893, 0.5768044346145221, 0.08588556998542377, 1.9226230042321342, 15.021920238222394, 31.00432470866612, 44.0573182787214, 56.67961733681815, 47.44379384177071, 14.455708060945783, 0.3005047578896795, 0.04085091920569539, 0.10137921145984105, 0.07427469587751798, 0.05044785727347646, 0.013859493358592902, 0.1363582480698824, 0.0296734966603773, 0.04014281702360936, 0.057023153374237676, 0.11333867614822728, 0.016378463013097644, 0.011881789392126458, 0.03944930673709937, 0.0714564346043127, 0.02380434007916067, 0.032020776599113426, 0.07396169445876564, 0.15761555598250457, 0.26226656830736567, 0.0647624491580895, 0.0382666100215699, 0.2062974851578474, 0.212844669552786, 0.1479843213622059, 0.10498852242848702, 0.15753428105797085, 0.24746923946908542, 0.08400596691561596, 0.10517722301717315, 0.1958140241248267, 0.23871735909155437, 0.2149774543941021, 0.11427759219493185, 0.09471623506397009, 0.11650169427905764, 0.16618358051138266, 0.1361734558429037, 0.1780238944504942, 0.174629577302507, 0.1623100276504244, 0.07370901480317116, 0.2196664163576705, 0.15643793131623948, 0.27711400017142296, 0.19302405097654887, 0.22255814261734486, 0.19670355639287404, 46.21853460584368, 103.84667137690953, 83.67941379547119, 91.15305600847516, 86.69797529493059, 72.57968739100865, 23.144475562231882, 0.20810561813414097, 0.35614875491176334, 0.7243030198982784, 4.149508059024811, 6.443771966866084, 5.770452439785004, 0.4394543176250798, 7.840129290308271, 32.61671325138637, 81.51705796377999, 78.8582672391619, 80.2780065536499, 53.09086581638881, 75.48166506631034, 73.51995931352887, 68.4156528200422, 67.22197314671108, 69.79449503762382, 66.92281150817871, 67.01275593893868, 65.52956567491803, 70.15477303096226, 69.79809420449394, 59.19929122924805, 64.97069426945278, 66.956406048366, 69.25995622362409, 64.18572153363908, 56.89344814845494, 57.1006121635437, 62.11361585344587, 62.64814077104841, 71.33114474160331, 70.04565157209123, 27.58223615373884, 35.5062050138201, 42.21877976826259, 51.09481511797224, 48.202881063733784, 40.333424295697895, 27.889567136764526, 21.572341408048356, 27.78157823426383, 9.077974319458008, 0.6747335940599442, 0.7163314819335938, 0.18364462070167065, 0.2628124090177672, 0.6260713424001421, 0.458472269986357, 2.087279894522258, 1.92484273655074, 3.0031195623534064, 2.5625457976545607, 3.100969306060246, 5.206683857100351, 1.1088147014379501, 7.199567045484271, 10.306063209261213, 4.068823839936938, 11.569963114602224, 0.7662119482244764, 0.5250251559274537, 0.5840223101632935, 12.402790699686323, 3.3203178559030806, 0.7923028681959424, 2.643121234008244, 3.797407226903098, 1.5592786840030124, 1.9708541418824876, 1.2816494043384279, 1.7018941513129642, 17.823784794126237, 33.30185079574585, 33.67122745513916, 55.364354610443115, 38.44447660446167, 55.21711880820138, 40.51933029719761, 37.33443239756993, 104.08516134534563, 64.22805690765381, 56.89493158885411, 54.13904326302664, 51.738534450531006, 64.25889301300049, 57.452076366969514, 56.72030251366751, 59.10219710213797, 58.7251044682094, 56.79688903263637, 61.48762484959194, 59.9254127229963, 64.04922417231968, 64.794675554548, 60.90846470424107, 59.08037281036377, 64.20815031869071, 64.4794705254691, 64.62773813520158, 61.221078055245535, 67.40487057822091, 64.01079368591309, 55.57488850184849, 46.523880141122, 60.72286442347935, 56.97422443117414, 62.23038033076695, 3.0197639720780507, 0.19481675406651838, 2.8989235077585493, 6.354618327958243, 0.18755227673266614, 1.837328003985541, 24.17770917075021, 48.2372225352696, 58.304245131356375, 69.1285935810634, 55.50405509131295, 15.317401068551199, 0.32578227722219055, 0.14477372435586794, 0.15450317013476575, 0.2891859252538, 0.13648092720125402, 0.09113540899540697, 0.3105840970362936, 0.11491962202957698, 0.137156680226326, 0.123824539195214, 0.16381894025419438, 0.0946023633171405, 0.10470204494361367, 0.2047091025326933, 0.1141042672097683, 0.1165319840822901, 0.15289164946547576, 0.15934390681130545, 0.2683134281209537, 0.4459302287016596, 0.12193412706255913, 0.089663537618305], [0.09497328448508467, 0.047288448948945315, 0.022972856481958712, 0.03556154535285064, 0.02661011291534773, 0.018957886745088866, 0.10475602918969733, 0.043765512095498185, 0.02977901224845222, 0.042372059010501416, 0.05289591323318226, 0.04574446626273649, 0.0364304298002805, 0.0637947360851935, 0.009966909286699124, 0.01488255792563515, 0.03822075462500964, 0.0346724168131394, 0.01287101541778871, 0.05570466144542609, 0.024358455524114624, 0.004891366839209306, 0.10984960837023598, 0.02936875301280192, 0.17140740448875086, 0.07958424596914224, 2.9834611543587277, 51.12437275477818, 63.13882255554199, 55.18624448776245, 67.15390859331403, 55.79648739950997, 22.31605052947998, 0.2612185302589621, 0.10277928704661982, 0.9494270426886422, 1.1003674290009906, 1.3225184913192476, 1.146977030805179, 0.24670827601637157, 2.8122171546731676, 54.80750513076782, 63.23827907017299, 70.54376792907715, 55.056177684238975, 54.88280275889805, 79.07229954855782, 66.76016112736293, 71.86504432133266, 66.25151824951172, 70.53437396458217, 66.2661303111485, 70.85579068320138, 66.30987616947719, 65.82148729051862, 64.53572314126151, 67.70540796007428, 62.57776246752058, 68.03954683031354, 64.73083550589425, 68.90511172158378, 63.85273606436593, 61.66308076041085, 62.94825431278774, 71.0666059766497, 65.37594795227051, 68.13619627271379, 31.901726245880127, 17.17311726297651, 26.97022145135062, 43.40471567426409, 40.99613305500576, 33.67082445962088, 17.20768976211548, 11.490985546793256, 4.946426485266004, 4.178090342453547, 0.20600658362465246, 0.08283427943076406, 0.16395223167325768, 0.04113234839003001, 0.15083492839975016, 0.17625648714601994, 0.04334717829312597, 0.748646576489721, 0.6010370371597153, 0.4035412775618689, 2.6605868339538574, 1.6342325934341975, 1.2244848374809538, 3.4920008948871066, 3.42913424542972, 2.9483842594282965, 3.228934713772365, 0.5731113042150224, 0.5110829983438764, 0.5875039547681808, 1.0442373837743486, 0.26099005394748276, 0.10871844978204795, 0.6977823972702026, 0.32275981083512306, 0.012750257388688624, 0.08488593862525054, 0.5404004880360195, 0.9280700172696794, 9.061395049095154, 19.04198292323521, 17.947575637272426, 40.52429478509085, 34.91443041392735, 41.06418023790632, 36.632021631513325, 23.331654821123394, 26.84463276181902, 50.60247271401541, 57.13428313391549, 55.82107360022408, 56.137894085475374, 61.347896575927734, 59.817639214651926, 54.96041413715908, 59.78574003492083, 56.76313120978219, 56.317984444754465, 61.054015568324495, 58.52772004263741, 55.56555707114083, 60.12318624768938, 60.60151413508824, 59.87735898154122, 61.16426263536726, 61.60619585854666, 63.320934840611045, 60.527140617370605, 61.719347272600444, 60.761475563049316, 60.23605278560093, 30.70423548562186, 43.05986615589687, 51.38444035393851, 41.49801186152867, 8.276224289621625, 0.15936449356377125, 0.2523412023271833, 0.13311094231903553, 1.1524901006902968, 6.4656857166971475, 14.568863817623683, 23.34677583830697, 39.072767462049214, 46.67188024520874, 25.979932921273367, 1.4011069600071226, 0.04473489436454006, 0.08883178939244576, 0.0048439249429585675, 0.018406777210267525, 0.12627673761120864, 0.06874316983989306, 0.0904928431180971, 0.06047342251986265, 0.11350818776658603, 0.04347497357853821, 0.0670558228822691, 0.14298231048243387, 0.0977476988253849, 0.024782933461080705, 0.09979992798928704, 0.02858532326562064, 0.050744173516120226, 0.039676178313259564, 0.06494680712265627, 0.1589609823588814, 0.05175021363954459, 0.04274934822959559, 0.08896934201142617, 0.04387193013514791, 0.02581600133063538, 0.014505865817357386, 0.043929575077657185, 0.05229185761085578, 0.0645429634356073, 0.08129320426711015, 0.0166158196516335, 0.1483966942344393, 0.02933426647047911, 0.04433439924780812, 0.021839954058772752, 0.056254006789198945, 0.026965495631364838, 0.015596424262704594, 0.028798020245241265, 0.07393677865288087, 0.03552035827721868, 0.0032064011154164162, 0.02767855960077473, 0.009031558941517557, 0.23900948198778288, 0.006578097602219454, 0.1714876073279551, 0.014747536242274302, 5.920849238123212, 72.5323076248169, 76.03839642660958, 68.50524289267403, 74.86446353367397, 65.46320343017578, 31.74573223931449, 0.3692325385553496, 0.12155604735016823, 0.6831405343753951, 1.867641908781869, 1.3440365195274353, 0.7628122163670403, 0.6069855093955994, 4.767522965158735, 62.85985238211495, 66.2073346546718, 73.57357856205532, 62.329927171979634, 58.42749922616141, 81.10876096997941, 72.13899094717843, 74.80545943123954, 68.85989284515381, 71.53324699401855, 69.27766023363385, 72.6283039365496, 67.81871223449707, 69.48335470472063, 66.52349158695766, 68.606568472726, 64.68327508653913, 68.7916476385934, 67.1634623663766, 69.13561126164028, 64.02611446380615, 61.13473973955427, 64.33850547245571, 69.61075687408447, 64.82355921609062, 60.51650987352644, 25.148580959865026, 19.966610976627894, 27.676415511540004, 42.8968232018607, 48.71396623338972, 37.58780540738787, 19.29527255467006, 17.74896659169878, 7.829809478351048, 2.4624142221042087, 0.6319875163691384, 0.18321619369089603, 0.04468275234103203, 0.05672220952276673, 0.11215605067887477, 0.2913822888263634, 0.15437633836908, 0.39137224054762293, 0.7803104945591518, 0.4850192740559578, 2.331831080572946, 1.9053009280136652, 1.1559002548456192, 4.328914889267512, 4.644933291843959, 3.2533632772309438, 7.019435431276049, 2.2812716450010027, 2.670468692268644, 0.6112642426575933, 3.8084904721805026, 0.1772071418485471, 0.13617488076644285, 0.8770420668380601, 0.1709183164473091, 0.3836013318172523, 1.1543749081236976, 3.5229759642056058, 4.575276732444763, 19.02107058252607, 15.080019337790352, 23.832206521715435, 52.12472922461373, 44.53750828334263, 43.18611492429461, 37.935448101588655, 26.67343783378601, 38.48299394335066, 50.09485469545637, 59.02074337005615, 56.90590279442923, 57.81073890413557, 62.37439564296177, 59.95313603537423, 55.67976113728115, 62.715725898742676, 57.675349780491416, 55.898723193577354, 61.650240489414756, 59.67449937547956, 58.92531681060791, 61.02775137765067, 61.32398087637765, 59.876872607639854, 61.0218870980399, 63.37039906638009, 65.88711302621024, 61.3048802784511, 64.05442142486572, 63.537808963230674, 63.38489300864083, 37.09800951821463, 48.57457842145647, 58.21586404527937, 53.04201998029436, 16.304729666028702, 0.3867810011974403, 0.07175551926983254, 0.21535486914217472, 2.0940910833222524, 11.959984609058925, 28.954833677836827, 36.16083649226597, 50.58840956006731, 58.79721287318638, 31.866610050201416, 3.762643652302878, 0.04284510648410235, 0.16391569934785366, 0.08997699365551982, 0.17814144385712488, 0.2172980848699808, 0.0967758127621242, 0.15310911993895257, 0.08823808482182877, 0.10583205002227, 0.12195593517805849, 0.04545964440330863, 0.02419594638714833, 0.09492077265999146, 0.02846283751672932, 0.07312556968203612, 0.021260001696646214, 0.03709131273041878, 0.015922114286305647, 0.012374601742651845, 0.0885852776201708, 0.11023337420608316, 0.03611058196319001, 0.1725879604262965, 0.12436830358845846, 0.07902965894235031, 0.1283844845103366, 0.17501482234469481, 0.16702773235738277, 0.23014814034104347, 0.2914876788854599, 0.1471488411937441, 0.15768518724611827, 0.15455338172614574, 0.21562711096235684, 0.09807613691581146, 0.16228208557835647, 0.07252448943576642, 0.08207726505185876, 0.15725785946207388, 0.17991935488368782, 0.11865214817225933, 0.11061473124261413, 0.11101095498140369, 0.09211329330823251, 0.3451746180653572, 0.0746238496420639, 0.3675614967942238, 0.28393297855343136, 5.441555116857801, 83.8288973399571, 93.62020151955741, 82.40909549168178, 87.23247241973877, 79.79005541120256, 41.724547454289024, 0.9581538715532848, 0.24616208246776036, 1.7963065994637353, 4.75795008455004, 5.264844621930804, 2.498137733766011, 0.7417282334395817, 5.996942869254521, 69.5460899897984, 76.24948964800153, 84.89410482134137, 72.27646800449916, 65.75265843527657, 84.40908581869942, 70.68037646157401, 73.6662049974714, 67.90729481833321, 72.12731797354562, 69.4567153113229, 74.38493360791887, 68.88391276768276, 67.66605336325509, 66.15487575531006, 68.26794801439557, 62.98055648803711, 67.64179720197404, 66.6240598133632, 71.87124211447579, 65.89866093226841, 58.900581223624094, 60.534470966884065, 71.00145966666085, 67.44062600816999, 75.3268175125122, 42.15255648749215, 20.296985660280498, 35.825335775102886, 49.426114899771555, 55.33947311128889, 41.498439175742014, 25.641154391424998, 25.529385668890818, 22.313585656029836, 10.314979485103063, 0.9386211825268609, 0.5506568433982986, 0.27248587565762655, 0.1541043408215046, 0.7816885177578244, 0.4089153834751674, 0.3881725136722837, 1.9544481422219957, 1.0911102571657725, 1.0800426453351974, 4.0202294417790005, 5.741289981773921, 0.6675781437328884, 7.486566730907985, 7.828427655356271, 3.701238078730447, 6.863988161087036, 2.116384595632553, 1.248623856476375, 1.9483167912278856, 12.993710671152387, 0.8033408958997045, 1.0563903259379523, 4.11435147694179, 1.1307111893381392, 0.5792655082685607, 1.5079435471977507, 10.521983691624232, 4.358543745109013, 23.176400797707693, 21.577246836253575, 30.068655967712402, 52.4814566884722, 49.96953351157052, 46.73493167332241, 44.681103229522705, 28.757183483668737, 34.85717725753784, 53.36141129902431, 54.94662891115461, 57.69504444939749, 53.748762948172434, 62.71757411956787, 59.25182655879429, 50.55343232836042, 58.42405986785889, 60.673733711242676, 55.12092794690813, 63.52295371464321, 60.65170097351074, 60.2755046572004, 60.52532018933977, 63.84129238128662, 59.281814983912874, 61.39135755811419, 63.34491307394845, 67.37611893245152, 63.81960705348423, 64.57589067731584, 63.38481657845633, 64.5523293358939, 41.96233218056815, 59.26709869929722, 62.28532668522426, 62.82673726763044, 21.464263916015625, 0.4105423204600811, 0.5659936347178051, 0.40540298766323496, 1.9596820899418421, 15.898174933024816, 45.22276394707816, 50.864961760384695, 61.74386746542794, 66.19561999184745, 34.95348276410784, 3.7256553513663153, 0.10806975673351969, 0.32036270946264267, 0.2904902324080467, 0.3279837433780943, 0.2852458895317146, 0.1865134531898158, 0.25276661664247513, 0.2509146231625761, 0.16174417015697273, 0.3051965832710266, 0.2045797873288393, 0.2814533401812826, 0.256224376814706, 0.13999434081571444, 0.26002354866691996, 0.09358446579426527, 0.10029184552175657, 0.12298827192613057, 0.15706278064421245, 0.34394907525607515, 0.23785694954650743, 0.13047886426959718], [0.08861594061766352, 0.06547430703150374, 0.006247248167970351, 0.02548016551216798, 0.021266361266108494, 0.041213633492589, 0.06889934145978518, 0.060074898547359874, 0.04368742967822722, 0.05953233516109841, 0.007450798809129212, 0.023591263119929602, 0.055178433789738586, 0.03555961831339768, 0.03552650919716273, 0.06072657036462, 0.01639492087997496, 0.04112906767321484, 0.04028445781607713, 0.027303043054416776, 0.11401096864470414, 0.017058965783300142, 0.07201593422463962, 0.07583440361278397, 0.01300326528559838, 0.07684023678302765, 0.17037913895079068, 16.08161779812404, 81.94002260480607, 65.51584298270089, 70.14045974186489, 55.0842136655535, 31.538422312055314, 3.4879472724028995, 0.4324130783123629, 0.04864730014066611, 1.8544231780937739, 0.5887298775570733, 0.7277077457734517, 0.21283833203571184, 23.86160261290414, 78.29909706115723, 61.32087503160749, 66.22362123216901, 44.19264486857823, 67.37306867327008, 72.48044627053397, 69.96965217590332, 71.3466739654541, 67.079847744533, 69.93373693738664, 67.91925266810826, 69.64657483782086, 67.27193069458008, 66.30797931126186, 67.03699125562395, 66.56506960732597, 65.67781244005475, 63.191323144095286, 65.84468037741524, 67.70806217193604, 66.93049621582031, 61.19772515978132, 61.84025982448033, 69.14212172372001, 65.71850109100342, 67.80513545445034, 51.397909436907085, 26.803742613111222, 31.741545949663433, 41.74068464551653, 37.3961740902492, 32.56025218963623, 15.242136444364276, 11.392500042915344, 5.153384225709098, 0.6665934537138257, 0.35331999670181957, 0.07807707041501999, 0.11929280736616679, 0.03385190512718899, 0.10110822492944342, 0.31284147447773386, 0.13076925011617796, 0.36584119339074406, 0.5411461165973118, 0.2644110103803021, 1.8933954068592616, 1.788326267685209, 0.4354577735066414, 1.2264295731272017, 2.216192428554807, 2.6123035848140717, 0.8870897048286029, 0.8907746385250772, 7.07585436957223, 4.417229533195496, 0.23962236195802689, 0.5832885695355279, 0.2533925787678787, 0.09921309019305877, 0.10443930261369262, 0.26691336610487526, 0.3297960561301027, 0.5712532582027572, 3.3228020540305545, 12.977294683456421, 26.25287205832345, 22.96289655140468, 28.30493218558175, 37.9894495010376, 41.91192994798933, 34.65986926215035, 21.387488058635167, 28.357516152518137, 55.931713240487234, 52.95169687271118, 61.37954562050955, 53.2281413759504, 54.70093018668038, 58.6496261869158, 60.76003033774239, 59.996610913957866, 61.48838220323835, 59.58735506875174, 62.97063446044922, 59.4178329195295, 61.45663588387625, 59.06363459995815, 63.20874227796282, 59.57370185852051, 62.713314873831614, 59.625611850193565, 67.19865499223981, 59.371120180402485, 62.971711431230815, 59.03467450823103, 66.33535521371024, 41.74169908251081, 33.87680728094918, 45.43391622815813, 42.770275660923545, 26.180959939956665, 0.3671714477241039, 0.20326214017612593, 2.283847689628601, 8.401371768542699, 20.80385501044137, 26.594174521309988, 31.400681223188126, 35.59905726569039, 25.89322461400713, 11.77568885258266, 0.24801347883684294, 0.09185750596225262, 0.023473089461081793, 0.04513127416638391, 0.06995808679078307, 0.06675426156393119, 0.08388723007270268, 0.030956267113132135, 0.04898430473570313, 0.07458697126380034, 0.014339066642735685, 0.01951190210612757, 0.12650207909090178, 0.027515597541683486, 0.022027434980762855, 0.054352453111537864, 0.1358450177524771, 0.04176101108480777, 0.06844056357762643, 0.05461601646883147, 0.0899692244295563, 0.03470663194145475, 0.06347046419978142, 0.08335332479327917, 0.005886879067734948, 0.0549970919133297, 0.016561945667490363, 0.08845433393227202, 0.03091561947284, 0.04118669904502375, 0.03980837729094284, 0.014429333852604032, 0.014293788000941277, 0.03409301915339061, 0.04319527805117624, 0.051012774995927296, 0.008810700881960136, 0.0071186652473573175, 0.003798706631641835, 0.05971910871033158, 0.04568994597398809, 0.03347972866946033, 0.05901166131453855, 0.09151223341801337, 0.07109224450375352, 0.013244196107344968, 0.07209834908800465, 0.031301020578082116, 0.10060123034885951, 0.37884477419512613, 31.132244518824987, 96.35576289040702, 74.63051073891776, 82.00381401606968, 61.6558198928833, 46.12722832815987, 7.744016596249171, 0.34629577504737036, 0.18854935680116924, 1.256619278873716, 0.9787540861538478, 1.0603540561028888, 0.8030970032726015, 30.04079716546195, 86.38381249564034, 66.73469597952706, 73.68836280277797, 51.58538225718907, 72.54512705121721, 74.24376705714634, 73.12883826664516, 71.53108610425676, 70.25736318315778, 70.62957123347691, 70.07093606676374, 71.34054565429688, 69.4909977231707, 66.54493372780937, 67.46772398267473, 66.49777630397251, 65.12955788203648, 62.77601541791643, 67.51084450313023, 69.17836352757045, 67.1361003603254, 60.06887217930385, 64.52352210453579, 69.09574249812535, 67.20783356257847, 65.03428418295724, 39.247778688158306, 24.319032055991038, 32.66139016832624, 39.8607348714556, 50.854372705732075, 36.27443259102957, 19.25653461047581, 16.69896697998047, 9.024787596293859, 2.013527589184897, 0.8706772455147335, 0.23399616671460016, 0.04406990969021406, 0.13672935244228157, 0.13705252510096344, 0.23840930419308798, 0.0947177346263613, 0.41304025213633266, 0.7215586985860551, 1.680753605706351, 2.488572887011937, 1.446914153439658, 0.553689243538039, 1.7842559260981423, 3.0524485153811316, 2.7452577991144995, 1.8518230319023132, 2.8724111361163, 12.133986609322683, 6.892313361167908, 1.0198165284735816, 1.286458969116211, 0.19872331087078365, 0.22820297043238366, 0.4486182044659342, 0.8378986301166671, 0.27988114740167347, 4.712907952921731, 8.983328563826424, 20.329018592834473, 21.001607690538677, 24.8385523387364, 34.11007220404488, 47.14458009174892, 43.07272727148873, 37.64602436338152, 19.177808046340942, 28.603602239063807, 59.81005872998919, 54.18732282093593, 64.39190932682583, 53.48772954940796, 56.978709493364605, 59.09205273219517, 61.44027982439314, 58.905458859034944, 62.98497554234096, 59.664452280317036, 64.39549459729875, 62.2316449029105, 61.58737318856375, 58.20621299743652, 64.09772954668317, 59.44017832619803, 63.07913752964565, 59.5648637499128, 68.05607659476144, 61.73741258893694, 65.23066806793213, 63.394835880824495, 70.292250088283, 46.37421941757202, 41.33504186357771, 54.89496905463082, 51.96884638922555, 34.36003017425537, 2.4660902534212386, 0.6633735607777322, 3.6562784569604054, 14.480186564581734, 31.308735711233957, 42.32941246032715, 42.997071811131065, 50.22781889779227, 37.552977561950684, 17.17980490412031, 0.42594620532223154, 0.029750211829585687, 0.09713386890611478, 0.04285053137157645, 0.22359640976147993, 0.09738846203046185, 0.10834999848157167, 0.10438746253826789, 0.06339355904076781, 0.07626538870057889, 0.012585040048829146, 0.024290517205372453, 0.060928936648581705, 0.01944590948655137, 0.060208156039672237, 0.018122026597016623, 0.07300374550478798, 0.047576792405119965, 0.017789632647431323, 0.05704027281275817, 0.08254108444920608, 0.01719733264430293, 0.042895928756999116, 0.1659414792167289, 0.1576355184827532, 0.14308388717472553, 0.17690671368369035, 0.3566644415259361, 0.15273850411176682, 0.1460999617619174, 0.10979187861084938, 0.08820847355361496, 0.1551442907324859, 0.10158921126276255, 0.11713034340313502, 0.12347840491150107, 0.12202708636011396, 0.14445398508438043, 0.10872011897819382, 0.3893924110702106, 0.11438984902841703, 0.1037438517170293, 0.1431690976023674, 0.17963646006371292, 0.15866803164993012, 0.15915006292717798, 0.23499887862375804, 0.08846769428678922, 0.206199993246368, 0.35156525086079327, 34.63517189025879, 116.68549019949776, 87.69174834660122, 97.10478564671108, 78.455139705113, 54.894621644701274, 14.168644973209926, 0.33324637955852915, 0.575168785239969, 5.429013618401118, 2.5197902747562955, 1.4411869921854563, 1.17670196720532, 37.87893492834908, 96.93426295689174, 74.69494138445172, 80.63714504241943, 58.653864588056294, 75.26169204711914, 72.73295770372663, 71.98114177158901, 73.99947534288678, 70.84042126791817, 71.39177472250802, 69.01532404763358, 71.35729776109967, 69.69549710409981, 67.41907269614083, 67.64434719085693, 65.80110822405133, 63.76086698259626, 62.46404824938093, 66.90057032448905, 67.73438889639718, 67.58163275037492, 54.90584298542568, 62.176858357020784, 68.13524436950684, 71.01144422803605, 66.86533600943429, 65.74106189182827, 32.26280328205654, 46.470514501844136, 46.74259206226894, 53.935058048793245, 41.5597813470023, 25.327339002064296, 22.33155369758606, 18.937282255717687, 5.017828779561179, 1.0819075852632523, 0.4874840389404978, 0.148929004956569, 0.17691740739558423, 0.29946125245520044, 0.4594515860080719, 0.2067459018102714, 0.9016059030379567, 0.5546434809054647, 2.569320942674364, 1.745554894208908, 3.453751278775079, 0.33496801289064543, 4.244382236685071, 4.59711492061615, 5.079328153814588, 1.3913216165133884, 1.0258240061146873, 18.684833356312343, 6.363353950636728, 1.1915811002254486, 2.3578188632215773, 0.8330643123814038, 1.8544090645653861, 0.7972790811743055, 1.2392104587384631, 0.4307239060955388, 6.046001493930817, 12.044984527996608, 26.49848219326564, 32.18023089000157, 31.76421444756644, 34.58965424128941, 52.864187785557334, 48.94093608856201, 45.85992070606777, 24.177749122892106, 35.871881757463726, 59.55604648590088, 55.62531852722168, 64.03948279789516, 52.80868904931204, 55.54423999786377, 62.976540429251536, 63.934926305498394, 58.20481293542044, 60.405665261404856, 59.045520646231516, 64.23550537654332, 63.2350412096296, 62.13629477364676, 60.844173022678916, 62.23183250427246, 61.51915577479771, 64.08996840885708, 61.4358468736921, 68.07926273345947, 62.350354875837056, 65.92165946960449, 65.21599347250802, 71.9782999583653, 50.43898507526943, 50.57254682268415, 60.372536250523154, 60.993336950029644, 39.96976252964565, 2.45936005456107, 0.6691599988511631, 4.102673726422446, 19.863857541765483, 39.442383834293906, 57.38104493277413, 56.03554017203194, 60.25227682931082, 44.63607195445469, 19.06618697302682, 0.506216328058924, 0.3930598114218031, 0.18094605979110512, 0.177219654034291, 0.3781417304916041, 0.3027060069143772, 0.18944925708430155, 0.19180427571492537, 0.10798348100589854, 0.25709485581942965, 0.11443837785295077, 0.10693352270339217, 0.22775036043354444, 0.07834754125880343, 0.13774973340332508, 0.14447837163295063, 0.21728470415941306, 0.09453260991722345, 0.14776587379830225, 0.14583697515938962, 0.19264880754053593, 0.12202423651303564, 0.23237047823412077], [0.06675106566399336, 0.06865486529256616, 0.030020747134195905, 0.08206377577568803, 0.060526348251317225, 0.028991423081606627, 0.04257463224764381, 0.036857024766504765, 0.041660384341542206, 0.06570637279323169, 0.07311889968280282, 0.016499357597370232, 0.015931856352835894, 0.009865304604837937, 0.019752783734085302, 0.0801866968561496, 0.04570788983255625, 0.13354938450668538, 0.025351761241576502, 0.02875023102387786, 0.12081904975431305, 0.029091598599084785, 0.1104364258104137, 0.008158836530388465, 0.02864632017112204, 0.03189427053023662, 0.22460385784506798, 2.493767316852297, 57.65974760055542, 75.3053753716605, 62.511087553841726, 64.9354669025966, 41.19888148988996, 15.462943247386388, 3.2922225977693285, 0.5632132696253913, 0.8414292920913015, 1.0541918724775314, 0.43261332756706644, 1.1225200231586183, 50.22051634107317, 68.69952147347587, 67.02003070286342, 55.32390914644514, 48.46489763259888, 76.83047022138322, 68.58985805511475, 71.7980706351144, 69.94263063158307, 72.5676600592477, 67.02387305668422, 71.7648651940482, 67.86421598706926, 69.28533799307687, 68.8853371483939, 69.6791410446167, 71.68048627035958, 69.48526545933315, 65.39536121913365, 70.42188262939453, 68.09755734034947, 67.7269265311105, 60.680584635053364, 66.47716099875313, 65.8334242956979, 64.13527761186872, 64.56163992200578, 62.20349080221993, 29.54257311139788, 26.686352797916957, 46.13364151545933, 41.51382943562099, 27.26775026321411, 17.70382067135402, 10.670260855129786, 5.86094925233296, 1.3818151780537196, 0.6139286054032189, 0.15643415866153582, 0.14456115290522575, 0.15378643359456742, 0.22299240502927983, 0.02999129532171147, 0.053026443014719656, 0.1461685752230031, 0.5880076991660255, 2.5985910977636064, 0.20721460665975297, 1.5255451798439026, 0.10289450229278632, 0.18317658081650734, 0.971130826643535, 2.3673826243196214, 2.1733153121812, 7.252276514257703, 3.8035698447908675, 10.411015748977661, 1.5056604125670023, 0.40704645376120296, 0.06848029858831849, 0.0699339716562203, 0.2422993725964001, 0.13800056065831864, 0.27684644024286953, 1.9632973245212009, 6.199283097471509, 15.612902743475777, 24.916681357792445, 23.34522639002119, 22.558113609041484, 36.472598688943044, 42.28009762082781, 32.23032392774309, 30.02849885395595, 48.86270979472569, 55.02924299240112, 58.25123037610735, 59.1826502936227, 58.99413176945278, 55.50283915655953, 57.50797462463379, 58.0372953414917, 60.761225427900044, 60.540543692452566, 60.835904666355674, 60.49626977103097, 59.593525069100515, 62.37572274889265, 62.293233735220774, 62.83810452052525, 62.34836769104004, 62.70706844329834, 63.312367711748394, 65.5580254963466, 63.807815960475374, 60.71298408508301, 60.11759294782366, 63.24774946485247, 51.15122406823294, 27.354295287813457, 44.93012319292341, 39.686981269291465, 28.004617146083287, 12.00489342212677, 4.433838333402361, 8.029992290905543, 22.84124401637486, 29.236716883523123, 39.47765983854021, 52.044581753867014, 37.74935449872698, 27.67176021848406, 4.0473591174398145, 0.03417502689574446, 0.09511249272951058, 0.03812700144148298, 0.05870435280459268, 0.032720760109701326, 0.034641933627426624, 0.06639852600970439, 0.06220372074416705, 0.06656132013137851, 0.08034236636012793, 0.04851943360907691, 0.08013632241636515, 0.010314792494422622, 0.001636922899966261, 0.03171136123793466, 0.04867688426747918, 0.010012885123225195, 0.021554964261927774, 0.06282920110970736, 0.03616112603672913, 0.05178192836631622, 0.021388473820739558, 0.056116691657475064, 0.055773200267659764, 0.06061824903424297, 0.023949049546250274, 0.04059105725692851, 0.05074376978778413, 0.08872078784874507, 0.05263555934652686, 0.006936682155355811, 0.04061053121196372, 0.07832354147519384, 0.0766301080584526, 0.05344655118616564, 0.024741200164758732, 0.05461891720603619, 0.04443404211529663, 0.05148964601435831, 0.06406761572829314, 0.052574894923184595, 0.06298820900597743, 0.05141492234542966, 0.03478101634287408, 0.036684351174959114, 0.10684458711849791, 0.06289392656513623, 0.05956183786370924, 0.11444516320313726, 0.06900057888456754, 6.231841487543924, 76.0758124760219, 82.8925233568464, 76.76903424944196, 75.0276906149728, 51.83055291857038, 28.002048049654277, 4.646571329661778, 0.4191510028072766, 0.7792108335665294, 0.823520364505904, 0.46313825675419396, 2.2584435556616103, 62.366224561418804, 76.00801195417131, 76.87493869236538, 65.1225471496582, 55.340942655290874, 78.55914034162248, 72.1250250680106, 72.53213391985211, 74.09701415470668, 74.96592807769775, 67.35269655500139, 71.7823121207101, 69.37720012664795, 72.60760525294712, 69.48614093235561, 68.03078515189034, 69.45424175262451, 69.72744492122105, 66.26071071624756, 70.83569649287632, 69.17883600507463, 68.16476726531982, 60.55953311920166, 67.08247416360038, 67.81436266217912, 65.64121627807617, 63.94002628326416, 52.76343195778983, 23.049229655947002, 28.80076084818159, 46.63626030513218, 51.30124262401036, 31.803169522966655, 19.68889147894723, 17.993445907320293, 12.693647503852844, 1.101875513792038, 1.3976341634988785, 0.3391690674637045, 0.11862800589629582, 0.1683508620730468, 0.17807426889027866, 0.028308235009067824, 0.07299569807946682, 0.3829958071666104, 1.002113169857434, 1.8618822864123752, 2.58233665568488, 1.967097120625632, 0.35678019960011753, 0.538011719073568, 1.4812466140304292, 2.416576087474823, 1.2848469870431083, 23.72158251489912, 13.117115889276777, 26.28455584389823, 3.764045451368604, 0.4355047552713326, 0.1439481507986784, 0.05878870827811105, 0.3024196651365076, 0.26156214039240566, 1.3887946435383387, 5.630476636545999, 14.642084802900042, 17.415373155048915, 21.768089532852173, 25.214373452322825, 24.64256797518049, 48.32297025408064, 43.305418968200684, 33.21856273923601, 25.423224142619542, 48.591285364968435, 58.471967697143555, 58.74011952536446, 60.73659406389509, 59.27099663870675, 56.649132115500315, 55.52569872992379, 58.841945375714985, 62.44430146898542, 61.85412842886788, 60.67957019805908, 62.5250951222011, 61.907247407095774, 64.9652121407645, 62.970530237470356, 62.32060963766915, 63.12257766723633, 64.3867746080671, 64.32764543805803, 67.59501498086112, 66.27838693346295, 62.37986387525286, 62.81760038648333, 66.76301683698381, 54.457878725869314, 36.05188873835972, 55.47660275868007, 48.63636180332729, 40.22195781980242, 18.62777474948338, 8.66528866972242, 12.543135625975472, 29.0158041204725, 45.291526794433594, 52.96591983522688, 57.59214162826538, 51.733055795942036, 31.724415166037424, 6.465599732739585, 0.07417864924562828, 0.10926365945488214, 0.04596603508772595, 0.036075888467686515, 0.07850346182073865, 0.01816003643242376, 0.10109381284564734, 0.09616756040070738, 0.13162751549056598, 0.07487835455685854, 0.059921312145888805, 0.011092146808680679, 0.076095544600061, 0.07012180372008256, 0.06030950881540775, 0.0472155607172421, 0.008863634246933674, 0.01633659061709685, 0.09844395039337021, 0.08019887655973434, 0.051730305422097445, 0.029217117399509464, 0.0779222897919161, 0.21577626653015614, 0.12239638582936355, 0.08455258794128895, 0.1780641044356993, 0.15540391180132115, 0.19529840536415577, 0.14602634071239404, 0.1545951794832945, 0.21283130241291864, 0.19576898297028883, 0.17798483797482081, 0.1007619888654777, 0.09888896758535079, 0.1460504558469568, 0.10636129376611539, 0.17512446003300802, 0.1423898408455508, 0.16108007436352118, 0.1722444724291563, 0.15795738835419926, 0.20447685356651032, 0.312147604567664, 0.2514876595565251, 0.18019557291907923, 0.1316028439572879, 0.1494714937039784, 0.3197148713682379, 6.097529768943787, 87.65834140777588, 99.85799544198173, 86.95895658220563, 94.79076453617641, 68.22955921718052, 40.26505402156285, 6.453501616205488, 0.7838782859700066, 2.0921073726245334, 2.6272452516215186, 0.6426576152443886, 2.775884372847421, 68.91336618150983, 85.07077666691372, 85.23815182277134, 71.78459807804653, 60.09583813803536, 79.11539227621896, 73.67549473898751, 74.01830496106828, 72.00091634477887, 73.14526380811418, 67.69332504272461, 73.90159606933594, 71.47638988494873, 72.50728716169084, 68.19730567932129, 66.71172523498535, 69.86888939993722, 69.67793205806187, 66.28630787985665, 71.27655274527413, 70.16228403363908, 68.90138053894043, 57.03170687811715, 62.52124582018171, 66.48466505323137, 67.56561020442417, 62.675412450517925, 74.01264217921666, 34.465792179107666, 37.28377308164324, 53.888032640729634, 54.641199997493196, 37.612103257860454, 27.266977276120866, 21.674611943108694, 19.698969841003418, 3.5485075541904996, 1.403915877853121, 0.37503490863101824, 0.18859412654169969, 0.36855679910097805, 0.4585716075130871, 0.17031965857105597, 0.12811115703412465, 1.2309726093496596, 1.2210801116057803, 5.141258750643049, 1.2659337733473097, 3.8736528498785834, 0.3245551330702645, 0.6072554034846169, 2.6882072261401584, 4.791889863354819, 2.7033043588910783, 31.651851654052734, 18.48659082821437, 29.13559627532959, 10.196054986545018, 0.6196902905191694, 0.25409125270588057, 0.14959255792200565, 0.7862499558499881, 1.8068319261074066, 1.8278547866003854, 6.366055062838963, 23.936674424580165, 23.75528301511492, 31.465931756155832, 33.572479656764436, 31.74998106275286, 51.44779402869088, 48.052035672324045, 41.37834998539516, 36.067636830466135, 60.83936486925398, 55.49616888591221, 59.45306723458426, 58.840736389160156, 60.81273242405483, 55.65405627659389, 57.51620476586478, 55.812749658312114, 61.970816476004465, 62.11834062848772, 63.44744069235665, 62.67999826158796, 64.64483765193394, 65.2097053527832, 62.0222053527832, 61.60748822348458, 65.1255487714495, 64.49815423148019, 65.52824551718575, 67.88107926504952, 69.13694531576974, 63.26150689806257, 64.80790492466518, 68.74558803013393, 58.637459891183035, 41.1236116545541, 60.99587999071394, 57.56205245426723, 48.4117682320731, 19.91073877470834, 10.630449414253235, 14.492719377790179, 36.36404350825718, 56.075401987348286, 66.57775701795305, 71.91286877223423, 61.69278430938721, 39.332776001521516, 5.881472059658595, 0.15381339857620852, 0.27173699012824465, 0.10836256495011704, 0.23061157975878033, 0.16435715423098632, 0.2226361741444894, 0.2208228978727545, 0.19441538703228745, 0.13658809502209934, 0.14746237865516118, 0.14131319576076098, 0.13277694024145603, 0.08097877113946847, 0.16968183565352643, 0.1737006221498762, 0.18188920989632607, 0.09769705975694315, 0.12090164103678294, 0.3368470663470881, 0.13110459569309438, 0.12977477562214645, 0.1186558258320604, 0.13139468298426696], [0.0416378976910242, 0.027449976420029998, 0.005729871153432343, 0.03332512785813638, 0.05250183027237654, 0.07150405419192143, 0.09271715554807868, 0.015706625135083283, 0.04504154808819294, 0.03727076488680073, 0.04515635621334825, 0.022071388782933354, 0.06680267503751175, 0.10719553900084325, 0.03145920744697962, 0.08355290229831423, 0.014791542630908745, 0.023866751730175953, 0.06486047032688345, 0.03545939529846821, 0.047722931884761365, 0.037811876208122285, 0.061986345265592845, 0.10665136748658759, 0.12313859457416193, 0.04480524148259844, 0.1071336633924927, 0.20702479327363627, 29.455665043422155, 72.36649581364223, 68.90002564021519, 73.3476926258632, 58.99789074489048, 35.80441127504621, 10.568149260112218, 2.3101355476038794, 0.6784754161323819, 0.6600282745701926, 0.8544163980654308, 15.232436759131295, 59.61448083605085, 73.11433737618583, 69.24100153786796, 47.69136510576521, 58.97633048466274, 72.44274534497941, 70.75158160073417, 72.99012442997524, 71.17786053248814, 72.67539187840053, 70.75452068873814, 68.83144692012242, 70.19685132162911, 67.66335051400321, 67.43181569235665, 69.10527542659214, 68.09278392791748, 68.9690351486206, 64.6208802631923, 69.05394908360073, 64.76918956211635, 68.0382753099714, 65.12067113603864, 66.00425965445382, 66.02567400251115, 66.36815765925816, 62.833247729710166, 63.27040754045759, 45.60066952024187, 24.601358209337505, 46.82154444285801, 36.33833169937134, 22.656465360096522, 19.741623095103673, 15.259267227990286, 4.890150419303349, 1.1774395619119917, 0.6023398243955204, 0.16291013759161743, 0.11846320331096649, 0.021167776913249066, 0.1334113162010908, 0.09704413264989853, 0.21130871054317268, 0.36778801892484936, 0.8819033088428634, 1.4009932918207986, 3.7305520943232944, 1.3886034595114845, 0.43101364054850166, 0.2655927198273795, 0.4497705469174044, 1.073152637907437, 4.7763146076883585, 15.72066409247262, 7.789772221020289, 16.864162138530187, 1.511252952473504, 0.08772372135094234, 0.19585457337754114, 0.1034692893070834, 0.17884790737714085, 0.40915626340678757, 1.1122603565454483, 6.262498242514474, 11.229109678949628, 17.830359527042933, 25.591436556407384, 24.295621837888444, 19.703783205577306, 23.184495449066162, 40.80707604544503, 28.587456362588064, 29.83329963684082, 49.2615259715489, 55.78690235955374, 58.88378047943115, 58.16098369870867, 58.849046434674946, 57.08923101425171, 58.324902125767295, 59.85878644670759, 60.577938897269114, 65.02757222311837, 61.234807695661274, 61.21922288622175, 60.092079162597656, 61.973713874816895, 61.43140697479248, 61.70375551496233, 63.04167979104178, 61.732521057128906, 63.98943492344448, 62.266747202192036, 61.79343591417585, 60.54994460514614, 64.57574476514543, 64.13446467263358, 56.14450529643467, 25.688568898609706, 40.638314723968506, 44.03788764136178, 30.77171986443656, 18.250925302505493, 12.026216575077601, 25.862824508122035, 28.84293293952942, 40.95444386345999, 59.25740596226284, 62.222730364118306, 38.25882421221052, 11.818479333605085, 0.4982276367289679, 0.04811346950009465, 0.061032691438283236, 0.01266348802684141, 0.03570401395804115, 0.04128328850492835, 0.08576629031449556, 0.049102899086262496, 0.07160399561481816, 0.023689033230766654, 0.04194812050887516, 0.05496651712538941, 0.044482594688556025, 0.009413982974365354, 0.07292281663311379, 0.08559099079242774, 0.03980895743838378, 0.03295305318066052, 0.07687182258814573, 0.0442939924874476, 0.07765198858188731, 0.07041978915887219, 0.03550637706315943, 0.05869982697601829, 0.043310432229191065, 0.0333530292181032, 0.04833056338663612, 0.053041296146277866, 0.10951278358697891, 0.03879225074446627, 0.027278866851702332, 0.05733468237199953, 0.029803286838744367, 0.02265300864486822, 0.02170067117549479, 0.007962478674016893, 0.041190003510564566, 0.04704826112304415, 0.04174873638632042, 0.11088963970541954, 0.04081098063449774, 0.009397200258847858, 0.032493956387043, 0.05011691199615598, 0.07074280575449977, 0.045079946384898255, 0.07747065688350371, 0.0887731368254338, 0.0930996389527406, 0.038578705596072335, 0.1515303317989622, 1.1037439278193881, 44.43650579452515, 86.33925369807652, 75.28696264539445, 84.25874069758824, 62.16792297363281, 51.97735445840018, 17.42297795840672, 3.5655671187809537, 0.7461932109934943, 0.7561434656381607, 1.5768146344593592, 21.84787917137146, 77.73629992348808, 82.56336634499687, 78.99549416133335, 58.67677974700928, 63.43483666011265, 74.91711003439767, 73.28144850049699, 75.69885185786656, 74.86244855608258, 74.91449056352887, 71.19371632167271, 71.05578068324498, 71.41809449877057, 70.93445123944963, 68.7210191999163, 69.26400702340263, 68.51800673348563, 71.26606791360038, 65.94045434679303, 71.79024001530239, 68.73405402047294, 69.36673613956997, 65.89916120256696, 67.00145816802979, 66.5359080178397, 67.69304711478097, 64.22579874311174, 62.39629636492048, 33.705610615866526, 28.69024280139378, 46.950784410749165, 49.71849857057844, 25.357497658048356, 19.77554246357509, 20.04275975908552, 11.155415347644261, 0.6292279958724976, 1.9565267392567225, 0.3213739980544363, 0.07360941264778376, 0.060875827712672095, 0.2817284182778427, 0.08428717896874462, 0.20877789705991745, 0.17497584729322366, 0.6234025827475956, 5.097133346966334, 4.780285503183093, 2.1467371497835432, 1.4487475007772446, 0.6854574329086712, 0.9686235040426254, 1.535795184118407, 2.44135097520692, 32.46525641850063, 8.216811111995153, 18.650867087500437, 5.6814238684518, 0.34999674931168556, 0.1336944145815713, 0.09929181382592235, 0.10657995846122503, 0.7416912125689643, 2.8075483994824544, 14.980733054024832, 17.295523677553447, 14.463681987353734, 21.888838802065166, 24.10597770554679, 18.857843501227244, 30.8492374420166, 45.84315470286778, 31.022365706307546, 26.728547470910208, 47.820143018450054, 59.65598937443325, 58.95582635062081, 62.373402050563264, 58.92008481706892, 56.5026467187064, 57.634223393031526, 60.866886683872764, 60.252478327069966, 63.416549001421245, 61.711912700108115, 63.18859250204903, 61.7611198425293, 62.84018898010254, 63.66526671818325, 63.85771097455706, 65.28960963657924, 64.50431033543178, 63.42107227870396, 64.87635162898472, 65.76307378496442, 63.83174555642264, 64.73879814147949, 67.9240608215332, 60.469317708696636, 34.75672715050833, 51.90655926295689, 49.74768795285906, 41.68087107794625, 23.377342700958252, 16.50066712924412, 30.34774078641619, 35.22177355630057, 56.79589891433716, 65.32102939060756, 68.40184674944196, 44.56239325659615, 18.831657477787562, 0.9350911719458443, 0.0278673891111144, 0.04775915886940701, 0.030002179023410593, 0.021501005460907305, 0.029806730403964008, 0.07204709933804614, 0.12981191862906727, 0.0512569152883121, 0.01600443245843053, 0.052755476840372593, 0.02369717904366553, 0.012010804344234722, 0.021901770295309167, 0.0012258508005678387, 0.08842742323343243, 0.023917877647493566, 0.06403748877346516, 0.05673436887030091, 0.10769514433507409, 0.03542116663551756, 0.09187626067016806, 0.04413434337558491, 0.07892420102975198, 0.12139535668705191, 0.15544860011764935, 0.11713385821453162, 0.09163981835756983, 0.343557994812727, 0.1752306914755276, 0.16795115066426142, 0.23491555452346802, 0.12579351211232798, 0.10361165273934603, 0.08069423426474844, 0.08738747332245111, 0.1060031426272222, 0.17914555354842118, 0.09333052406353609, 0.21428348948912962, 0.171286353841424, 0.13310350557523115, 0.10035163802759987, 0.21180188336542674, 0.09446459356695414, 0.12965242218758377, 0.2179368305951357, 0.2310076542198658, 0.19154483106519493, 0.1451970487833023, 0.24805210105010442, 1.089076497725078, 49.0581556728908, 101.78024932316372, 87.41732229505266, 101.3567705154419, 85.84036609104702, 69.60427420479911, 25.75533935001918, 3.0890640020370483, 1.4874512468065535, 0.717391733612333, 1.7202835359743662, 27.74538333075387, 86.49540751320976, 91.41409288133893, 85.84426403045654, 66.95597526005336, 67.81564113071987, 75.21484729221889, 74.04439544677734, 75.64807442256382, 76.5399660382952, 74.79284845079694, 72.96848773956299, 70.71369307381767, 72.07605416434151, 71.97693811144147, 69.73864541734967, 68.984877041408, 66.82985155923026, 71.71161420004708, 64.3583425794329, 70.99972956521171, 68.54949596949986, 69.00194876534599, 63.34961005619594, 64.18600640978131, 66.02867562430245, 69.764221736363, 61.071448598589214, 70.63271181924003, 56.04289831433977, 33.56655979156494, 53.68327617645264, 46.96680000850132, 32.25872468948364, 27.448297466550553, 24.335249151502335, 17.213640894208634, 1.9193562652383531, 1.8854609983307975, 0.22489750065973826, 0.2076702836368765, 0.08897453958966903, 0.5422483288816043, 0.17031347033168587, 0.5383694427353996, 0.47534901010138647, 1.165494522878102, 4.83937862941197, 10.343336820602417, 3.066881660904203, 1.4687531015702655, 0.9186844123261315, 1.1109375932386942, 3.1127849348953793, 6.566408106258937, 38.59587785175869, 17.607461316244944, 29.796481132507324, 15.487293209348406, 0.5106150805950165, 0.5033880312527929, 0.1693748121282884, 0.16356524958142213, 1.022366191659655, 2.3284331943307603, 20.18334092412676, 25.27998181751796, 22.0220878805433, 32.09709569386074, 30.888432230268204, 27.895009313310894, 33.58262402670724, 54.18553018569946, 39.56885494504656, 38.95614889689854, 58.167299611227854, 54.4351372718811, 62.18606472015381, 59.54523508889334, 59.77442141941616, 56.38471494402204, 58.247752802712576, 61.130327633449006, 61.74480547223772, 63.00197083609444, 62.99527972085135, 62.821644238063264, 62.59885025024414, 62.51360974993025, 64.00703471047538, 64.93598801749093, 65.73833124978202, 63.671353340148926, 66.84859085083008, 64.62800911494664, 68.15503283909389, 66.57506806509835, 69.58650071280343, 69.83828953334263, 64.79195186070034, 40.28233419145857, 57.35761560712542, 60.603869574410574, 50.01193141937256, 26.91283975328718, 20.438761915479386, 32.41795308249337, 42.82620518548148, 68.00229058946881, 81.08171163286481, 78.20783942086356, 50.86561141695295, 18.437791892460414, 1.1047019107001168, 0.18335036720548356, 0.2482166322214263, 0.0804477564192244, 0.20361165356423172, 0.11213116201439075, 0.32775312289595604, 0.18414342536457948, 0.24809767146195683, 0.14690156946224825, 0.16745272598096303, 0.07599365578166076, 0.2560275745178972, 0.16856289069567407, 0.12930524295994214, 0.21257516901407922, 0.10719286557286978, 0.17508091165551118, 0.24102207113589558, 0.09736543933727912, 0.15931679255196027, 0.32099779109869686, 0.1576060564922435, 0.1654978258801358], [0.04880214522459677, 0.06468339304306678, 0.03389471729419061, 0.060327435710600445, 0.051424964663705656, 0.010757020059307771, 0.04789606009476951, 0.07040952292404004, 0.029914804069059234, 0.12029091880789824, 0.015002256591937371, 0.021881234432969774, 0.03820227811645184, 0.041072199653301916, 0.01203155648961131, 0.04650683428293892, 0.01914191392383405, 0.07245651379759822, 0.041520209184714725, 0.035954854783735106, 0.0326628878579608, 0.011588921803714973, 0.0441875133796462, 0.01833260485104152, 0.021893008711880872, 0.056392105628869364, 0.12568671070039272, 0.06173196927245174, 6.280248284339905, 51.931510244097026, 74.35981587001255, 70.7647762298584, 71.53972271510533, 54.37113741465977, 27.441561188016617, 12.786967022078377, 5.760652005672455, 1.355788094656808, 10.385086808885847, 24.60642170906067, 58.72884259905134, 68.29132175445557, 61.0839136668614, 44.75561571121216, 67.4835797718593, 70.87003449031285, 71.76669257027763, 74.65529496329171, 72.0898254939488, 73.38518510546002, 68.2248900277274, 70.6140559060233, 70.93930108206612, 71.38687624250139, 72.6053192956107, 69.44628606523786, 71.79035813467843, 71.36393329075405, 70.10419014522007, 70.22817380087716, 69.59984820229667, 65.96147264753068, 66.11855752127511, 69.84029756273542, 66.85667160579136, 65.62568705422538, 61.92063658578055, 61.183133942740305, 44.41006442478725, 25.96539728982108, 44.31403684616089, 33.50015933173043, 19.01637707437788, 23.26180979183742, 16.675518546785625, 6.421032684189933, 1.3988433671849114, 0.6741885947329658, 0.14097088841455324, 0.16540470373417648, 0.12639951173748287, 0.02537951841285186, 0.12036204284855298, 0.3337332420051098, 0.26563601036156925, 0.566972299345902, 3.0657697319984436, 3.8417632239205495, 0.7694048083254269, 0.5629668799894196, 0.7533790054065841, 1.5889028715235847, 0.7445196722234998, 5.062681572777884, 27.942076410566056, 1.499257213303021, 11.437407987458364, 3.0506526231765747, 0.28836481645703316, 0.16547196012522492, 0.1844130480395896, 0.29613168111869265, 0.39317692656602177, 1.819279515317508, 11.091821960040502, 12.951760053634644, 19.18478056362697, 21.712663752692087, 25.426792042596, 22.673471076147898, 14.264056767736163, 32.659701756068635, 37.155036858149934, 30.187623023986816, 51.18465185165405, 58.52387768881661, 61.53341347830636, 60.36939566476004, 59.349295888628276, 59.238673618861604, 56.91583871841431, 59.50601250784737, 62.740419796534944, 60.608441489083425, 60.66739695412772, 62.34421961648123, 61.908192362104145, 60.32639326368059, 62.82210976736886, 64.13623646327427, 63.92068944658552, 61.62741565704346, 64.59384482247489, 64.58144228799003, 63.74465683528355, 59.903998374938965, 63.360233851841514, 62.28395789010184, 57.48996836798531, 26.774801628930227, 38.150696345738, 36.70727409635271, 43.73922627312796, 27.077925477709087, 23.584669998713903, 35.709655216761995, 40.42253841672625, 51.723776476723806, 70.03850882393974, 49.31272029876709, 20.169041531426565, 3.312263373817716, 0.04127196375546711, 0.04087207253490176, 0.0933824319924627, 0.1837952554758106, 0.027239952868382846, 0.1335665107305561, 0.06238756302211966, 0.16216833596783026, 0.1590335720351764, 0.016095542748059546, 0.06797431502491236, 0.09124996606260538, 0.054087390191853046, 0.04546895729643958, 0.05836479352521045, 0.04628933666806136, 0.08092396586601223, 0.05220102212790932, 0.06239506083407572, 0.05194621187235628, 0.021240410694320287, 0.07628564297088555, 0.06726838076221091, 0.04137211213154452, 0.06211895136428731, 0.02517477555998734, 0.021000716502645185, 0.05699578805693558, 0.021780551710565175, 0.09526476277304546, 0.04451489295544369, 0.08279411015766007, 0.04403092106804252, 0.09332552326044866, 0.03202297844524894, 0.06403134803154639, 0.05176806928856032, 0.03227950878707426, 0.029625639585512023, 0.030490045701818805, 0.06282871934984412, 0.03141717220257435, 0.063062420380967, 0.07493197917938232, 0.06843112515551703, 0.030185108671763113, 0.060042030311056545, 0.045872736522661786, 0.07513458295060055, 0.018057409707190733, 0.07701164829943861, 0.015154830279893108, 15.091739211763654, 72.6063198362078, 82.47945989881242, 84.05854225158691, 78.40211800166539, 61.49570560455322, 41.26215178625924, 18.390700476510183, 7.937772325107029, 7.214405357837677, 15.808626549584524, 33.23390088762556, 73.57864379882812, 80.21074799128941, 73.03520434243339, 54.98029293332781, 72.96128940582275, 74.64878450121198, 73.73812580108643, 78.21922057015556, 74.0942348752703, 74.89655726296562, 70.28718485151018, 72.61052349635533, 70.98580537523542, 71.70085144042969, 73.78544303349086, 70.9951923915318, 72.55176258087158, 71.80909742627824, 69.19048813411167, 71.48306015559605, 71.37247957502092, 69.56502383095878, 65.70904459272111, 71.69255529131208, 65.36008521488735, 67.4692942755563, 64.10312829698834, 62.29101031167166, 37.49067653928484, 26.49258143561227, 46.56305408477783, 39.97750629697527, 21.49370517049517, 20.50353475979396, 20.112971305847168, 11.555909514427185, 3.0993162861892154, 1.2540124016148704, 0.7233835235238075, 0.1368836648762226, 0.08498402086219617, 0.10442848676549536, 0.1281135454773903, 0.5138704744832856, 0.21833017734544619, 0.16247046047023364, 5.809163893972125, 1.2194568387099674, 0.548543071108205, 1.435951633112771, 0.6263074725866318, 2.3907941452094486, 2.980713576078415, 11.783656699316841, 37.14152956008911, 6.728084002222333, 9.537249377795629, 3.008269263165338, 0.3914581702223846, 0.338187362998724, 0.07774574855076415, 0.10185681190341711, 0.4249456918665341, 2.2768790807042802, 21.068444149834768, 9.651392647198268, 14.981966359274727, 21.19763548033578, 25.407971109662736, 21.677792481013707, 18.442494085856847, 41.71871791567121, 35.495244230542866, 26.882067918777466, 54.893068722316194, 55.80376216343471, 63.78328187125069, 61.328017779758994, 61.424069677080425, 56.80769348144531, 58.692093576703755, 61.89717946733747, 62.54263237544468, 61.74905776977539, 64.17992673601422, 63.52986022404262, 62.986914089747835, 63.337228366306846, 66.82708617619106, 64.74593394143241, 66.48014177594865, 64.78629602704729, 66.894455909729, 67.64126219068254, 64.97056920187813, 61.00386347089495, 62.99106216430664, 65.53664588928223, 61.93304606846401, 35.17108644757952, 45.68680286407471, 46.7152613231114, 52.219429697309224, 37.74561289378575, 30.969719205583843, 42.08345317840576, 47.778460775102886, 62.55890505654471, 70.07062339782715, 58.46273354121617, 27.964765753064835, 5.597844421863556, 0.17892699741891452, 0.03684699601892914, 0.0937759280204773, 0.11238899175077677, 0.013719822014016765, 0.08338221681437322, 0.10509282683155366, 0.07685603307826178, 0.06627795033689056, 0.03961413985650454, 0.04724791665960636, 0.04699772044218012, 0.1325302520500762, 0.023699418209227066, 0.01702836894297174, 0.044597589410841465, 0.08101784118584224, 0.12320354394614697, 0.0360810181924275, 0.09555463293301207, 0.011217982824226575, 0.044354409245508056, 0.0745524609727519, 0.0421455538432513, 0.15066639387181827, 0.17454230412840843, 0.13400218449532986, 0.2594552891595023, 0.1049409978357809, 0.15079222140567644, 0.21099214681557246, 0.23807568209511892, 0.1252134053834847, 0.25737365228789194, 0.14962994520153317, 0.08357048314064741, 0.10923415675227131, 0.13470433253262723, 0.11566295714250632, 0.11556497668581349, 0.1577172412403992, 0.17335805696036133, 0.09691439675433294, 0.11567728780210018, 0.14001376048794814, 0.14881364043269837, 0.20189525852245943, 0.11310680716165475, 0.1951603777706623, 0.11333370927189078, 0.25237781607678955, 0.21590012631246022, 13.143561601638794, 77.77240971156529, 97.4488604409354, 94.32363019670758, 97.47044154575893, 75.03734166281563, 56.24184955869402, 19.18387382371085, 8.099182452474322, 11.863320401736669, 22.67056151798793, 40.852444308144705, 84.13377039773124, 87.40828963688442, 79.01909024374825, 62.10012245178223, 74.79751069205147, 74.84996959141323, 74.2909244809832, 78.39189720153809, 74.38642747061593, 75.43996892656598, 72.46983637128557, 74.86403274536133, 72.04303632463727, 72.06901563916887, 73.93825476510185, 70.41030693054199, 70.39823096139091, 72.12436498914445, 69.28468486240932, 70.36835370744977, 72.01107461111886, 70.03959969111851, 64.66107559204102, 69.04856422969273, 64.12613378252301, 67.18871212005615, 60.8635584967477, 64.321531023298, 52.974681513650076, 35.946390765053884, 50.08050666536604, 40.74858610970633, 28.32655324254717, 28.67834053720747, 25.132348230906896, 15.117662940706525, 4.209945227418627, 2.1275570818356107, 0.6203463524580002, 0.25945550629070824, 0.23548669101936476, 0.16040415849004472, 0.24564031617982046, 0.9154438376426697, 0.5389881038240024, 0.6861149062003408, 12.656488537788391, 11.44031754561833, 5.003001758030482, 1.2488616151469094, 1.1266602809940065, 2.87014102935791, 3.3265347565923418, 14.064507109778267, 45.93114668982369, 12.550845520836965, 27.279654264450073, 11.891915713037763, 0.40532870164939333, 0.3872328783784594, 0.3088607537959303, 0.33894485235214233, 0.4123894827706473, 3.4266467903341566, 28.44243356159755, 21.263110092708043, 23.508877311434063, 28.739934580666677, 33.713875498090474, 31.774348395211355, 24.62458082607814, 43.38704293114798, 44.55062648228237, 40.20672042029244, 59.861892291477744, 55.28647572653634, 63.48647567204067, 62.275356020246235, 61.73643984113421, 57.68088749476841, 57.59354863848005, 60.28076444353376, 64.51127937861851, 61.33252716064453, 63.685013498578755, 64.48619638170514, 64.45701394762311, 65.90644291469029, 67.43466445377895, 65.7553960255214, 68.85933004106793, 66.428683417184, 67.45197936466762, 69.83856746128627, 68.6933445249285, 63.73392881665911, 68.44423770904541, 67.87958540235246, 66.97960608346122, 40.06421981539045, 51.504637241363525, 56.943714891161235, 61.49323899405343, 42.85198300225394, 36.301283904484336, 50.45794670922415, 54.57132543836321, 78.67976801736015, 83.89341136387416, 62.34986155373709, 30.131432941981725, 5.839477147374835, 0.2609155779438359, 0.13416733991886887, 0.29862817430070465, 0.3277041869504111, 0.12948239488261087, 0.28698600615773884, 0.322755223938397, 0.2750093202505793, 0.2865090231810297, 0.08419989900929586, 0.16721766787980283, 0.13311729340681008, 0.20363416735615048, 0.12958901987544127, 0.08463315718940326, 0.09961060993373394, 0.1856489452932562, 0.22668412407594069, 0.10786565339991025, 0.17963827853756292, 0.12050931208900043, 0.13190848327108792, 0.16566619755966322, 0.20729178323277406], [0.030101133177855184, 0.05594173479559166, 0.12137470208108425, 0.06769720132329635, 0.05636006520528879, 0.07505759636738471, 0.06621044967323542, 0.02699890499934554, 0.05860346143266984, 0.09296784709606852, 0.04232007305004767, 0.05046742283073919, 0.08033307721572262, 0.051838301055665524, 0.1631950137338468, 0.05015827209821769, 0.07090426994753735, 0.07414123482470002, 0.10111204508159842, 0.03954467483397041, 0.15252013797206537, 0.07952625158109836, 0.013669783449066537, 0.030297134803341966, 0.040897619378353865, 0.04939826198720506, 0.04663145402446389, 0.02060337148473731, 0.6418993387903486, 15.765026603426252, 67.1982033593314, 74.82494218008858, 76.22872148241315, 66.45922769818986, 39.978169849940706, 19.81371760368347, 21.564965895244054, 16.61303687095642, 11.688262275287084, 37.4560467175075, 63.99220725468227, 63.22807911464146, 48.85483748572213, 45.67885065078735, 71.76467064448765, 69.27237960270473, 74.7116448538644, 73.46891784667969, 72.3389253616333, 71.20531981331962, 71.54813003540039, 73.32313074384416, 71.29911354609898, 72.65820898328508, 70.15657261439732, 68.588273865836, 69.5159000669207, 71.03944546835763, 71.46350792476109, 68.91734749930245, 69.74120930262974, 69.04799447740827, 69.72731290544782, 63.942388670785085, 70.73357881818498, 66.42743274143764, 65.26945291246686, 61.465883936200825, 39.05696725845337, 33.90308884211949, 43.31288480758667, 20.553910936628068, 21.338228804724558, 24.401731252670288, 19.269468682152883, 7.756340963499887, 2.512899398803711, 0.43970336711832453, 0.060290394483932426, 0.17505425879997866, 0.09781594587756054, 0.12751448048012598, 0.11068863049149513, 0.8744842069489616, 0.08403542890612568, 0.29182070387261255, 0.646836631000042, 0.5034901914852006, 2.3403489206518446, 0.754886058824403, 0.5067412427493504, 2.4015041419437955, 1.8291564881801605, 12.785791907991682, 18.80406618118286, 7.330263529505048, 1.8623643176896232, 1.872399470635823, 0.52523023635149, 0.1413112822920084, 0.08731354014681918, 0.0478355212004057, 0.07413094144846712, 1.1204408832958765, 11.310097013201032, 8.523029514721461, 15.62017924445016, 20.867531776428223, 22.2483229637146, 22.796586206981114, 15.03823981966291, 19.81016881125314, 43.204524176461355, 27.68115418297904, 47.791144711630686, 66.20012242453438, 57.548882143838064, 63.0745586667742, 59.54417896270752, 59.121408871241975, 58.69149603162493, 59.61223656790597, 64.06423922947475, 61.80578286307198, 60.567384583609446, 66.26016180855888, 63.84906741550991, 59.85148388998849, 64.86663109915597, 65.58014161246163, 61.00653157915388, 62.809186117989675, 63.60267734527588, 65.13203838893345, 63.84897708892822, 61.60972554343087, 60.68913091932024, 62.82030323573521, 57.88110678536551, 29.318948813847133, 36.823159626552034, 39.197338240487234, 47.96134431021554, 35.617018359048025, 36.21202734538487, 39.82551792689732, 40.96071808678763, 51.778330257960725, 52.64313084738595, 22.761051382337296, 7.775454589298793, 0.6812153948204858, 0.006750612586204494, 0.14600029853837831, 0.05765008580471788, 0.11928093300334044, 0.046886332133518796, 0.06097329926810094, 0.13870907335409097, 0.1481279536549534, 0.22980423165219171, 0.12969812830643995, 0.0789141519261258, 0.038642155405666144, 0.05870085834924664, 0.08938362156706196, 0.049323853837060075, 0.11908980325928756, 0.08300315322620527, 0.1496735071497304, 0.03431963627891881, 0.20452304823057993, 0.05987975187599659, 0.0017385310805236387, 0.06027753624532904, 0.010375311032735875, 0.032641720958054066, 0.07241633773914405, 0.035614393052778075, 0.07102886254766158, 0.07227005915982382, 0.02728565050555127, 0.028484224940517118, 0.00187112032186373, 0.06725919339805841, 0.02570822961362345, 0.05109929160348006, 0.038053621271891255, 0.02146720084627824, 0.07053141495479004, 0.03211776639467903, 0.021532335119055848, 0.04407851690692561, 0.10158294159919024, 0.026868078358737484, 0.02851765975356102, 0.05592161962496383, 0.03129013009103281, 0.02250359862643693, 0.029704997648618052, 0.057481374857681136, 0.04353942422728453, 0.04491839058963316, 0.049735870478408675, 2.8102968462875912, 35.98025975908552, 80.62630585261753, 82.49050753457206, 81.17569296700614, 66.6940837587629, 60.9573244367327, 34.68444504056658, 31.650764260973247, 22.118244000843593, 16.69753043992179, 48.11122390202114, 74.2148208618164, 75.3784704208374, 64.77032906668526, 56.71483775547573, 75.45666544778007, 72.64153330666679, 76.46798964909145, 73.95980112893241, 72.80669893537248, 73.35390431540353, 74.94507653372628, 74.36275495801652, 70.37730993543352, 73.13370895385742, 72.3652103969029, 69.51294708251953, 71.00805350712368, 71.2887190410069, 69.87824862343925, 70.69343212672642, 72.69346414293561, 68.51086398533413, 70.87874753134591, 65.98761177062988, 70.24387672969273, 66.22913115365165, 67.61089856284005, 63.24433789934431, 40.70514597211565, 29.939985752105713, 46.36580514907837, 25.794978822980607, 22.39725760051182, 23.595495292118617, 20.25843358039856, 13.08986679145268, 6.956575512886047, 0.88555958122015, 0.3065259147967611, 0.2075813819787332, 0.08625526979033436, 0.19924161663012846, 0.19886262768081256, 0.5470823752028602, 0.09933529434991734, 0.5142299894775663, 1.875597813299724, 1.711354123694556, 0.8814279000673975, 0.930738234094211, 2.450039263282503, 3.5477860271930695, 2.580002495220729, 26.517589739390782, 10.35354459285736, 8.836318578038897, 4.351768817220416, 4.2267351150512695, 0.6853770400796617, 0.20512736508888857, 0.034585530404001474, 0.07938064475144659, 0.028626924247613976, 0.7896564187748092, 16.554150887898036, 7.472474915640695, 14.085983991622925, 18.4491000856672, 22.957548175539287, 22.190098796572002, 15.653584446225848, 27.458467892238072, 44.68415696280343, 25.578285353524343, 49.70110375540597, 64.97940036228725, 61.244437898908345, 63.30421052660261, 60.60775361742292, 57.77752998897007, 59.897328104291645, 59.20473861694336, 63.112780707223074, 65.84465953281948, 61.652727944510325, 66.8204436983381, 64.84331294468471, 63.38218321119036, 65.88516058240617, 68.79496887751988, 65.89117077418736, 66.14326531546456, 65.36874961853027, 69.74284212929862, 62.882024083818706, 63.762326104300364, 62.87548582894461, 67.75846440451485, 59.42776884351458, 37.18533100400652, 43.12904242106846, 50.40805516924177, 50.8904755456107, 46.55009569440569, 44.54564462389265, 48.67442056110927, 55.68922805786133, 69.65197358812604, 69.80192266191754, 32.97858585630144, 12.29662309374128, 1.1392807066440582, 0.05552243747349296, 0.1356183463441474, 0.07628148355122123, 0.06907172328127281, 0.10205565659063202, 0.02499324539011078, 0.021311850253758684, 0.05287072940596512, 0.1296875567308494, 0.09304140707744019, 0.09242600974227701, 0.06345810129174165, 0.028302397911569903, 0.1546090758804764, 0.03208446050328868, 0.11797194395746503, 0.02710695661205266, 0.040077742122645886, 0.03658980071278555, 0.11412691670869078, 0.020006935810670257, 0.05274570932877915, 0.07078614378614084, 0.02556645141781441, 0.13218037225306034, 0.17369463747101171, 0.17495511126305374, 0.1546315082481929, 0.11670806391962937, 0.16028115366186413, 0.1415266085948263, 0.1247318083686488, 0.12141056944217, 0.17814968127225125, 0.12387023174336978, 0.11807045367147241, 0.14794743619859219, 0.22617320077759878, 0.26881844816463335, 0.08826935850083828, 0.18087467790714332, 0.1736371519842318, 0.14608732743987016, 0.20763447055859224, 0.21272999713463442, 0.1833553340818201, 0.1394717331443514, 0.1497844069131783, 0.13273094913789205, 0.1929686689483268, 0.15236415634197847, 0.1733407543173858, 2.048004984855652, 35.67508445467268, 88.96290738242013, 96.07471520560128, 94.48997701917375, 85.49105930328369, 68.99496582576207, 46.03421974182129, 44.75118970870972, 31.012634754180908, 18.08600459780012, 55.34132480621338, 83.832517351423, 83.99907261984688, 68.46452644893101, 63.984647614615305, 78.74586623055595, 74.45209489549909, 78.53319576808384, 74.34680884225028, 74.08061640603202, 76.54067475455147, 75.87156323024205, 72.55187375204903, 71.55423750196184, 74.43866402762276, 74.70601681300572, 69.5887449809483, 69.81852885654995, 72.0292580468314, 70.48741109030587, 68.71879577636719, 73.79123088291713, 68.96018314361572, 69.50951467241559, 64.82040473393032, 68.437484060015, 66.18431527273995, 66.0171207700457, 65.29201371329171, 51.69655690874372, 44.9851633480617, 49.8698616027832, 27.847151858466013, 30.211750643593923, 30.075784819466726, 24.69905161857605, 16.436417136873516, 6.246714540890284, 0.534461243876389, 0.3622327713029725, 0.3423961528709957, 0.12950694427958556, 0.32686850322144373, 0.6319643918957029, 2.179097516196115, 0.1688059012272528, 1.1075224450656345, 5.1287055271012445, 6.186331655297961, 5.064411239964621, 1.4090079303298677, 2.83962910090174, 5.386772479329791, 2.2229182847908566, 35.55261550630842, 35.423785482134136, 12.323107021195547, 17.871616193226405, 4.803934999874659, 0.9067389390298298, 0.2704327372567994, 0.1675883922725916, 0.11288424089018788, 0.14255268925002643, 0.7367285702909742, 33.871717725481304, 14.941421883446829, 21.63896073613848, 24.881189959389822, 31.35496207645961, 29.057739973068237, 24.27785529409136, 29.06440155846732, 54.350758348192485, 39.798597131456646, 52.601455552237375, 63.09983621324812, 59.29772635868618, 67.02554062434605, 63.319239480154856, 57.726596219199045, 60.402712277003694, 57.780628885541645, 63.68002469199044, 68.05060836247036, 61.98899296351841, 66.2647545678275, 67.28546578543526, 65.11067267826625, 67.44798415047782, 68.38823522840227, 68.53832326616559, 69.08074828556606, 67.77525125231061, 70.4614178793771, 67.43291350773403, 68.59292221069336, 65.3123858315604, 70.31287234170097, 64.63521439688546, 43.813662324632915, 50.16259963171822, 59.785566329956055, 58.505617822919575, 53.250465938023154, 50.584157262529644, 60.93885612487793, 67.0859065737043, 84.17879472460065, 75.60951886858258, 32.52426052093506, 12.899785791124616, 0.9530344605445862, 0.19877443169908865, 0.2053625996091536, 0.31160588935017586, 0.3135774407003607, 0.20491370798221656, 0.1939136239566973, 0.27415433898568153, 0.38906847845230785, 0.3663955565009798, 0.17160100410027163, 0.17985817816640648, 0.3030274696648121, 0.1742753413106714, 0.21455562274370873, 0.1632435561290809, 0.1470582839101553, 0.16386746907872812, 0.2383323311805725, 0.13429315388202667, 0.3070777808981282, 0.16741907064403805, 0.19522040097841195, 0.15920319221913815, 0.1964669240904706], [0.06348871679178306, 0.056883236060717275, 0.021002937008493712, 0.033256938481437306, 0.043430851838950596, 0.02195692671063755, 0.04401952846507941, 0.1371137968131474, 0.05054487421044281, 0.05153843268219914, 0.03579113106908543, 0.004497925518080592, 0.06518297123589686, 0.007133609981143049, 0.01608822644422097, 0.04284300981089473, 0.045942123513668776, 0.027731851741139377, 0.0728555398860148, 0.05658731336838432, 0.04306047010634627, 0.028639073417122875, 0.04026254792032497, 0.053115734830498695, 0.07415703111993414, 0.13284244601215633, 0.16028313498411859, 0.04587932849036796, 0.0588125791400671, 8.325361081532069, 51.233987535749165, 72.65733351026262, 92.1866283416748, 85.21651513235909, 57.937748500279014, 36.83407524653843, 25.24114486149379, 16.040211745670863, 15.089081525802612, 46.77073226656233, 56.881938457489014, 63.0915470123291, 48.099686418260845, 46.326130935123985, 72.5647418158395, 77.37156813485282, 72.21209294455392, 73.60519981384277, 76.2372955594744, 76.99858883449009, 71.22509438650948, 76.86685098920549, 71.94934681483677, 73.13200664520264, 69.90705585479736, 72.31157725197929, 69.63021877833775, 73.70478834424699, 72.85706642695835, 74.72570105961391, 66.50924777984619, 69.20671912602016, 64.3555632999965, 72.03225272042411, 65.75745964050293, 69.34562751225063, 62.004362378801616, 66.10754462650844, 34.68095704487392, 34.64434698649815, 33.83253683362688, 19.96477144105094, 20.585103137152537, 26.572247743606567, 20.399148498262676, 8.895471198218209, 4.681646704673767, 1.6182819179126193, 0.2076013037668807, 0.0821419090830854, 0.4038987840924944, 0.43030231871775215, 0.12789230234920979, 0.1104451585561037, 0.08160723027374063, 0.8504773665751729, 0.6809018573590687, 2.416088193655014, 0.9490894036633628, 0.749071230845792, 0.09966652800462075, 2.3345908182007924, 0.13097741108919891, 21.27625608444214, 3.045308372804097, 12.013140933854238, 5.0697630899293085, 1.1567263305187225, 0.2073686069675854, 0.07338659531835999, 0.05009613186120987, 0.07127721993518726, 0.02110607093865318, 2.180083726133619, 8.594483920506068, 4.63609778881073, 12.76924477304731, 23.90577057429722, 23.7013041973114, 21.146156276975358, 17.429886204855784, 15.746725048337664, 40.21454756600516, 37.116502148764475, 45.281281675611226, 67.62655285426548, 57.69993598120553, 60.25265898023333, 58.07969324929373, 58.671770095825195, 59.070131165640696, 65.36790193830217, 61.4981027330671, 62.99712099347796, 62.997523988996235, 65.44134439740861, 63.34758118220738, 63.191913740975515, 64.84948989323208, 66.7547276360648, 62.29068374633789, 66.29675102233887, 62.081014905657085, 68.90202672140938, 62.1408805847168, 61.70788969312395, 57.63940674918038, 69.38359941755022, 48.2588210105896, 35.30860866819109, 41.48724215371268, 44.163993971688406, 45.925928592681885, 42.66266196114676, 38.53558485848563, 29.389910766056605, 26.5007837840489, 34.38207680838448, 19.94837542942592, 10.918829185622078, 3.0075863855225697, 0.07581816626978771, 0.17150504567793437, 0.07000107198421444, 0.19347930726196083, 0.10335473223988499, 0.15652857002403053, 0.052978606295904944, 0.14074917031185968, 0.14965957004044736, 0.03143673436716199, 0.05531012047348278, 0.16286873338477953, 0.03357508658830609, 0.10846959027860846, 0.027524299753297652, 0.03511237891923104, 0.18735835142433643, 0.028775957679109912, 0.09236028684037072, 0.2273363455065659, 0.11288373877427407, 0.07169184554368258, 0.04861506633460522, 0.04361516230606607, 0.05021712822573526, 0.06099098189068692, 0.11988600982086998, 0.06923922643597637, 0.05099257840109723, 0.04076899288754378, 0.05926814076623746, 0.07852282721017088, 0.04977421109963741, 0.07633387324001108, 0.0017137405915751255, 0.036055125296115875, 0.03855308411376817, 0.05691169721207448, 0.08493398568992104, 0.03323906247637101, 0.0952613836686526, 0.019180020450481346, 0.035117369544293196, 0.043434142733791044, 0.02962696272879839, 0.0797680543203439, 0.028124716731586626, 0.037635599595627615, 0.015012655141098159, 0.04706708707713655, 0.06630862011973347, 0.0567411474351372, 0.03718240266399724, 0.3021435828081199, 13.67272858960288, 69.45702798025948, 81.42363943372453, 85.49666649954659, 80.9041782106672, 59.754445348467144, 57.386829308101106, 41.82238851274763, 22.281703846795217, 20.072501523154124, 59.00415802001953, 67.99925422668457, 69.26172801426479, 61.46388980320522, 57.738592284066335, 75.54063442775181, 78.23434679848808, 75.8792062486921, 77.21726254054478, 77.22225829533168, 77.98735918317522, 74.37458079201835, 76.44141973767961, 72.35385009220668, 74.93131215231759, 71.62303856440953, 71.1701271874564, 71.9669257572719, 75.2132978439331, 74.07227856772286, 72.9903815133231, 67.37950965336391, 69.43125711168561, 64.76780687059674, 71.07271344321114, 67.24443667275565, 69.71183926718575, 63.128115381513325, 67.94378675733293, 38.599358899252756, 33.77330691473824, 43.582339423043386, 20.881235361099243, 21.682312284197124, 24.445313828332083, 20.428768668855938, 13.59399594579424, 10.132307001522609, 2.1615333386829922, 0.570195449250085, 0.5142092534473964, 0.31268660564507755, 0.4332892027284418, 0.17730054897921427, 0.10308202901589018, 0.32489586621522903, 1.2819462226969855, 1.9770019948482513, 4.697172888687678, 1.2958219924143382, 0.9457038938999176, 0.058349607911493094, 1.6747866230351585, 0.07440057090882744, 37.659378801073345, 3.1057965670313155, 8.908152529171534, 1.5784358446087157, 2.0795211451394215, 0.10515954039458718, 0.11373838077166251, 0.12346293431307588, 0.13867041042872838, 0.06439832012568202, 2.642565812383379, 3.741875920976911, 8.03119432926178, 9.613293937274388, 23.62103339603969, 22.00155942780631, 22.148043087550572, 22.134249176297867, 20.964731863566808, 45.34965194974627, 33.52799034118652, 49.793191705431255, 66.12989698137555, 58.65559468950544, 61.24313858577183, 59.743925775800435, 59.33932522365025, 59.193023954119, 65.31217738560268, 67.54686396462577, 64.52967820848737, 64.22550691877092, 66.18290478842599, 65.69059712546212, 63.17783669063023, 67.24407536642892, 71.23097951071603, 67.57700525011334, 66.36685834612165, 66.74830750056675, 70.73812988826207, 64.72642339978898, 64.26559802464077, 63.30358518872942, 68.81384018489292, 51.8021000453404, 43.380966731480186, 50.442445278167725, 47.67279257093157, 57.46978037697928, 50.68431554521833, 47.45722818374634, 51.095739228384836, 56.38983576638358, 63.06114864349365, 40.19046858378819, 13.304850135530744, 4.710503876209259, 0.0636530104758484, 0.09214184606181723, 0.2947711098406996, 0.292921423379864, 0.06469532168869462, 0.13047095255127975, 0.034129018828805, 0.04254081066963928, 0.04327126379523959, 0.06611035897263459, 0.13364030819918427, 0.07524808150316988, 0.04903294551851494, 0.13420470005699567, 0.039533221162855625, 0.09951244627258607, 0.11172917751329285, 0.024152425151052218, 0.15693859516509942, 0.1709028458488839, 0.10906651789056403, 0.01833294072587575, 0.08844452910125256, 0.028895155925835882, 0.07527784883443799, 0.1653951635318143, 0.19278378172644547, 0.15974493457802705, 0.11731782262878758, 0.21473961429936544, 0.12963353177266462, 0.13173902593553066, 0.17878624211464608, 0.12515503780118056, 0.18559956151459897, 0.12879803803350243, 0.08663702716252633, 0.24073241810713494, 0.1270845199802092, 0.1721450806196247, 0.13647575676441193, 0.1438832285680941, 0.12727243346827372, 0.15512981079518795, 0.11247714702039957, 0.11934048123657703, 0.2486896796950272, 0.23078870454004832, 0.16517815446215017, 0.115486402330654, 0.18059939625007765, 0.3244089494858469, 0.12638355259384426, 0.39756297692656517, 12.993923459734235, 75.18823569161552, 94.85870402199882, 102.67471177237374, 104.49132524217877, 72.40585041046143, 61.3888909476144, 52.27619300569807, 26.17836478778294, 25.387619835989817, 67.9690990447998, 77.67387730734688, 81.04057134900773, 66.2847375869751, 65.45674160548619, 80.03891904013497, 77.36719076974052, 80.72915308816093, 77.94937338147844, 77.46787016732353, 79.75542558942522, 77.21833256312779, 78.08863612583706, 72.55618858337402, 72.80230072566441, 69.52637795039585, 69.30910778045654, 70.76911885397774, 72.93776280539376, 74.20363426208496, 71.97515937260219, 68.84658009665353, 68.41961329323905, 63.497620582580566, 70.91190433502197, 65.94938973018101, 69.26752281188965, 62.07952104296003, 67.62834548950195, 45.776438099997385, 45.99632774080549, 43.828840664454866, 27.16112494468689, 27.080056837626866, 32.75835575376238, 24.137513841901505, 20.303668090275355, 13.844479373523168, 2.3130151416574205, 0.5986130386590958, 0.9875222785132272, 1.2389943046229226, 0.9929763972759247, 0.37374425360134667, 0.19318852786506924, 0.22094787045248918, 3.3843554939542497, 1.8118034707648414, 11.225213476589747, 5.6927542090415955, 0.8077844860298293, 0.17021630411701544, 5.185810600008283, 0.2254178827362401, 47.79370512281145, 5.319531721728189, 14.627123594284058, 8.162873983383179, 6.547466882637568, 0.343302241393498, 0.17546629240470274, 0.1760704464146069, 0.2999211906322411, 0.22339561767876148, 3.42186621257237, 21.513045481273107, 15.626533372061592, 17.58139862333025, 30.31977776118687, 31.543011597224645, 25.388764551707677, 29.167120252336773, 23.472423587526592, 50.97151585987636, 44.912700584956575, 51.926511015210835, 64.38528074537004, 60.66529164995466, 61.051375252859934, 61.95432145254952, 61.28558513096401, 60.07756437574114, 65.33295249938965, 68.93910230909074, 66.26171820504325, 65.94590173448834, 68.66418293544224, 67.95314598083496, 65.81010614122663, 66.85736642565045, 71.27288409641811, 71.06613349914551, 68.19817420414516, 67.47041988372803, 73.11050197056362, 69.15467711857387, 67.36588423592704, 64.38883127485002, 71.27328709193638, 56.7958641733442, 49.97948680605207, 59.55299622671944, 58.20933621270316, 63.75250135149275, 58.92815167563302, 54.25526925495693, 58.03457164764404, 65.56122861589704, 67.23112392425537, 35.713205746241975, 18.871927499771118, 4.6438663090978345, 0.14739219099283218, 0.14899107734007494, 0.37851020214813097, 0.4024958722293377, 0.14468092790671758, 0.21614203761730874, 0.1829461231827736, 0.28383730511580196, 0.2459543693278517, 0.12530253774353436, 0.23108506149479321, 0.22492124938539096, 0.07617911297295775, 0.19391044841281005, 0.14709006649042877, 0.10141864112977471, 0.31564794959766523, 0.23078221774527005, 0.22453428086425575, 0.25085040660841124, 0.34928181767463684, 0.19737587603075163, 0.15629106919680322, 0.21990060593400682, 0.16077303726758274], [0.09682201421154396, 0.047588408924639225, 0.0741999281038131, 0.02818347277518894, 0.08887662698647805, 0.06264665483364038, 0.10083505351628576, 0.03346811893529125, 0.064671430470688, 0.11505889812750475, 0.15441436347152504, 0.10082098748534918, 0.0293882914286639, 0.011817141120055956, 0.09070861725402729, 0.05324991173776133, 0.06437505315989256, 0.08128113312912838, 0.022685973572411706, 0.07893931878996746, 0.04618843851078834, 0.01221862859425268, 0.04879756511322089, 0.05372542907883014, 0.03506798915831106, 0.007277428022851902, 0.11680297739803791, 0.03282754455826112, 0.11941387158419405, 1.824002661875316, 34.77903086798531, 57.79925700596401, 84.66325092315674, 86.60012381417411, 71.34590966360909, 49.281217166355674, 41.6514002936227, 36.968140738351, 29.09604365485055, 48.025931290217805, 68.34646960667202, 59.29307801382882, 51.99889039993286, 42.899668489183696, 68.46358844212124, 76.58451093946184, 78.33947304316929, 73.72817598070417, 71.66434560503278, 78.85063811710903, 71.20252663748605, 70.93542398725236, 79.13295037405831, 73.73704188210624, 68.98812185014997, 73.93569087982178, 71.35619299752372, 70.99525492531913, 69.35554953983852, 75.84660530090332, 69.29189014434814, 70.62087903703961, 69.79414067949567, 69.55688749040876, 68.39040306636265, 70.68846416473389, 65.2156252179827, 67.78766073499406, 29.75498996462141, 42.13146523066929, 25.216037545885357, 20.50038548878261, 22.500599895204815, 25.817398922783987, 19.84811292375837, 9.010064363479614, 4.943361895424979, 3.338415090526853, 0.9422367428030286, 0.18882151719714912, 0.17874779632048948, 0.09399578693721976, 0.09598614727812153, 0.09648778143205813, 1.2239426608596529, 1.3273111198629652, 0.3959834288273539, 1.066043762224061, 0.6900395527482033, 0.4144851246050426, 0.3420168517955712, 2.6160306419645036, 0.9608883133956364, 9.823322347232274, 4.053945575441633, 9.959457533700125, 4.911550436701093, 1.9552291631698608, 0.8858650305441448, 0.07076142475541149, 0.1619850229471922, 0.16360854011561188, 0.2599291508751256, 1.1437900875295912, 4.0377054640225, 1.3128687462636401, 11.84349719115666, 22.212339980261667, 24.644115686416626, 21.964256286621094, 20.29508706501552, 15.883243254252843, 31.49659068243844, 40.45780747277396, 42.376830441611155, 69.05904211316789, 55.82426977157593, 61.06944751739502, 58.688765389578684, 61.55277810777937, 57.79951408931187, 66.00254344940186, 62.87021214621407, 66.80878462110246, 61.43291473388672, 64.27353981563023, 60.34302030290876, 65.79450743538993, 65.17517280578613, 67.34089156559536, 62.642012459891184, 66.10525866917202, 64.20040307726178, 69.94401332310268, 60.947666440691265, 63.181630407060894, 58.41738959721157, 70.58703436170305, 41.17719268798828, 37.52995818001883, 52.8406959261213, 44.825681345803396, 44.96736553737095, 35.56358323778425, 18.922074386051722, 15.992455039705549, 15.399681636265345, 12.614104526383535, 9.751417177064077, 4.653134337493351, 0.6177481061645916, 0.09836171194911003, 0.2439979085964816, 0.1820662668240922, 0.1032235442793795, 0.025877636059054306, 0.030803851184568236, 0.08947668943021979, 0.023875659198633263, 0.16281755827367306, 0.13525640219449997, 0.06900868059269019, 0.09831683364297662, 0.09771272034517356, 0.04301933052816561, 0.05881590396165848, 0.11488459605191435, 0.07413493801972695, 0.0921339818409511, 0.18366560100444726, 0.0565037382101374, 0.045720602186130624, 0.09755861825708832, 0.029438106077057973, 0.05874456957514797, 0.027822867035865784, 0.06143758685461112, 0.06259223632514477, 0.011077818693593144, 0.012166410235555043, 0.05008434570793595, 0.06866354375545468, 0.06668425032070704, 0.03394316130184701, 0.033411725889891386, 0.2011515162885189, 0.13678184391132422, 0.03403401035549385, 0.07502126760248627, 0.08328311677489962, 0.06774311100265809, 0.06345746346882411, 0.05959783414644854, 0.03760173391284687, 0.017107862713081495, 0.0332621123109545, 0.02922958887315222, 0.037955667956599166, 0.04397563064204795, 0.1092899866136057, 0.10487570919628654, 0.00950832139434559, 0.04893826274201274, 0.07446200546941587, 0.06761921729360308, 4.495208731719425, 47.68453850064959, 75.18353176116943, 99.20820685795375, 91.3771562576294, 68.83396911621094, 58.26823609215872, 65.33434213910783, 53.005611419677734, 38.355445861816406, 61.28170108795166, 78.84453065054757, 74.13797378540039, 58.12060076849801, 54.63124670301165, 73.22425092969621, 79.81379740578788, 77.84251703534807, 79.44363907405308, 75.88698128291539, 80.19719205583844, 73.83127335139683, 74.81234509604317, 78.15313625335693, 75.53677122933524, 70.77710928235734, 74.18727125440324, 72.85847691127232, 73.58361870901925, 68.76812103816441, 73.93639264787946, 71.58310726710728, 73.96449811117989, 67.24568734850202, 67.60490921565464, 68.90996851239885, 71.76627567836216, 64.89468097686768, 68.27542427607945, 32.37621872765677, 42.81358725684029, 32.60349082946777, 21.87022978918893, 24.539078031267437, 23.43949954850333, 19.875429766518728, 12.068570188113622, 8.549903409821646, 1.994946151971817, 1.0955349568809782, 0.2936702274850437, 0.20339532302958624, 0.7116543671914509, 0.16764191511486257, 0.7453668639063835, 4.061106128352029, 0.4936319461890629, 1.5835709976298469, 1.7372894691569465, 1.2862206676176615, 1.0169637501239777, 0.45991890664611546, 5.135809625898089, 3.2330513043063025, 27.336089270455496, 4.252225450107029, 14.814615522112165, 3.5222214332648685, 0.7331751638225147, 0.38149165787867134, 0.22428596418883118, 0.09335590805858374, 0.10664013773202896, 0.23613846461687768, 2.61669745189803, 2.385652695383344, 5.754509798118046, 10.357419082096644, 21.95831731387547, 22.190708500998362, 24.378343616213115, 24.528110299791607, 21.183468103408813, 37.17848355429513, 40.231007848467144, 45.96830218178885, 68.46686799185616, 56.802986076899934, 60.370764459882466, 59.709726742335725, 61.544884954180034, 60.75958565303257, 67.88858331952775, 64.82607446398053, 64.89357621329171, 63.508869716099326, 67.51490225110734, 62.97658906664167, 68.95338085719517, 70.1372218813215, 72.130861554827, 62.885178565979004, 68.53124305180141, 69.69473975045341, 71.79763984680176, 64.36973762512207, 69.35285363878522, 60.88765484946114, 71.48203182220459, 48.40120349611555, 48.87542847224644, 56.048147678375244, 53.94027614593506, 56.363568101610454, 44.44010148729597, 37.268188272203716, 38.50923381532942, 42.511271136147634, 32.681046622140066, 12.442049758774893, 7.099301499979837, 1.2308118236916405, 0.06951971924198524, 0.41783005797437256, 0.37433756462165285, 0.055026435160211155, 0.034848354158124754, 0.043286876886018684, 0.042790101042815616, 0.053959333670458624, 0.14751641718404634, 0.15112720057368279, 0.0986218283485089, 0.08122104885322706, 0.0964547571327005, 0.06139484593378646, 0.0852732735552958, 0.03690215073791998, 0.06548886160765376, 0.05049713248653071, 0.06599190032907895, 0.11469866388610431, 0.10228017025760242, 0.054831590436931164, 0.006457016420816737, 0.010917600460483559, 0.02667852451226541, 0.22772430468882832, 0.07737521414778062, 0.19878181416009152, 0.0999411650534187, 0.1906430444547108, 0.18963575921952724, 0.22580707685223647, 0.17355754625584396, 0.15596728585660458, 0.2528965153864452, 0.28534644842147827, 0.18469976979706967, 0.12839340046048164, 0.12826306745409966, 0.12566574396831648, 0.14795461509908947, 0.08539715369365045, 0.15051053437803472, 0.12468629223959786, 0.22933894661920412, 0.15527954990310328, 0.06616776303521224, 0.09396542249513523, 0.1481657616261925, 0.20072251930832863, 0.17708176214780125, 0.13862199016979762, 0.2040145947997059, 0.24479898703949793, 2.6262983424322943, 45.88096332550049, 80.95278780800956, 108.93904781341553, 113.55195685795375, 86.48510333469936, 65.27253096444267, 71.96118654523576, 61.543703760419575, 49.12314564841134, 68.68676458086286, 88.61274596623012, 83.39216831752232, 66.55240304129464, 64.1007033756801, 77.78759152548653, 82.21413598741803, 79.3802992956979, 80.40116337367466, 78.87533896309989, 81.79725796835763, 76.15246500287736, 74.19025203159877, 79.23176765441895, 75.25847503117153, 71.39775712149483, 72.21818651471818, 73.28369971684047, 72.57225281851632, 69.51644897460938, 73.52634470803397, 72.81090259552002, 72.1507820401873, 68.84497506277901, 67.62213379996163, 68.0917694909232, 70.53632640838623, 63.99593843732561, 69.47555882590157, 39.59605714253017, 52.90962553024292, 34.68352787835257, 28.690987995692662, 28.838984625680105, 31.723737716674805, 24.07762384414673, 19.15476781981332, 11.989279082843236, 3.517409154347011, 2.162094839981624, 0.5494930744171143, 0.47453020832368303, 0.4394011747624193, 0.13282525193478378, 0.29697404163224356, 7.362102781023298, 4.483100627149854, 2.5947413614818027, 7.659263338361468, 3.5699225536414554, 0.556628548673221, 0.3827663537647043, 9.052380629948207, 6.32648594038827, 54.84664780752999, 3.8421023828642706, 21.496192625590734, 7.6251989262444635, 3.446961585964475, 1.1385629794427325, 0.43387529413614956, 0.3711844395313944, 0.3439963555761746, 0.4204050169459411, 5.939777868134635, 7.422307184764317, 13.480482356888906, 15.857731206076485, 29.952440398080007, 28.329638242721558, 28.593728848866053, 28.63627961703709, 26.998872348240443, 44.148249353681294, 47.11017608642578, 53.61530542373657, 68.1483347756522, 59.384314809526714, 61.4870412009103, 62.57315581185477, 62.2955961227417, 60.85558891296387, 69.44097764151437, 69.18628447396415, 68.38100910186768, 64.83143152509416, 68.88399614606584, 64.78672681535993, 69.42415605272565, 69.16990756988525, 74.03115912846157, 66.83641065870012, 69.4005252293178, 71.67837401798793, 72.4534525190081, 67.26034804752895, 69.75864233289445, 63.61405154636928, 71.11092853546143, 53.10776036126273, 56.34543677738735, 68.37089252471924, 58.300916944231304, 68.96661717551095, 54.882153102329795, 39.67874070576259, 46.8307021686009, 48.47881140027727, 30.287631920405797, 16.266799449920654, 8.483239786965505, 1.1146680159228188, 0.21444978485149996, 0.4149508981832436, 0.5692277497478894, 0.21232648592974457, 0.26719265111855095, 0.16371654931988033, 0.1762346654598202, 0.0843861840133156, 0.43786915125591414, 0.253737708819764, 0.39448747624244007, 0.18227858043142728, 0.25138465794069426, 0.18668101062732084, 0.16811975304569515, 0.2475289505507265, 0.14766319787928037, 0.11482183156268937, 0.35310061275959015, 0.18747622652777604, 0.3248479887843132, 0.20072426992867673, 0.07284754674349513, 0.17741898048136914, 0.15097656579954283], [0.030071582977793047, 0.027692603579323207, 0.13151794565575464, 0.05833149102649518, 0.08042634863938604, 0.016694672206150632, 0.06316210396055665, 0.005168438980555428, 0.15217185951769352, 0.043335649983159134, 0.16550864172833307, 0.18339179855372223, 0.016516000365040133, 0.03459056174116475, 0.011167389556898602, 0.037529564928263426, 0.058723534989569864, 0.07457264060420649, 0.19608819298446178, 0.03493398527747818, 0.10917056445032358, 0.045532335859856436, 0.020732101452137743, 0.14944075606763363, 0.12151224112936429, 0.055597334168851376, 0.14588335981326445, 0.2518651692995003, 0.18670242519250937, 0.12995009550026485, 11.054334691592626, 38.342213017599924, 57.174954414367676, 64.18793106079102, 70.12203311920166, 51.81514876229422, 34.21031386511666, 36.298403876168386, 44.98014327457973, 52.395538738795686, 75.43360437665666, 58.86531911577497, 58.28799329485212, 48.93255656106131, 69.36053834642682, 78.66111210414341, 75.60492610931396, 78.80318192073277, 70.44848033360073, 79.40868268694196, 76.58661624363491, 74.27465874808175, 72.42134489331926, 77.73354843684605, 71.04113388061523, 73.05228301456997, 75.68332958221436, 74.29843548366001, 70.51184790475028, 76.89340700422014, 71.43579156058175, 67.75745691571916, 69.82339259556362, 74.24146720341274, 67.7497444152832, 67.24035113198417, 66.36836610521588, 64.49086557115827, 30.26629400253296, 38.67874901635306, 16.303822926112584, 28.49883382661002, 21.378820180892944, 27.65070022855486, 23.265004226139613, 7.965524298804147, 2.6316219653402055, 1.8076890515429633, 1.0620401884828294, 0.3346628078392574, 0.22411319560238294, 0.2846467973930495, 0.9492707082203456, 2.767901761191232, 0.5391789621540478, 0.267998886427709, 0.16733664220997266, 0.09820503142795392, 0.03083090776843684, 0.010512608352915516, 0.7668759897351265, 2.1851035824843814, 0.5666633759226117, 2.63328931587083, 2.2029910683631897, 10.135907905442373, 1.8746107348373957, 0.40871901544077055, 0.13781028586838925, 0.20424708803849562, 0.052303117899490256, 0.03488778382805841, 0.027885468676686287, 1.5050515766654695, 0.7786423840693065, 3.4268860689231326, 9.824248194694519, 19.638788018907817, 25.579707997185842, 23.23871919087001, 22.11692210606166, 17.605206625802175, 27.746448142187937, 35.72837018966675, 40.011177267347065, 60.31757599966866, 61.78299971989223, 55.12992238998413, 58.933098793029785, 55.52886710848127, 61.87546634674072, 62.16210733141218, 66.57751383100236, 61.124873297555105, 64.2826280593872, 64.0445202418736, 62.61246177128383, 64.54332447052002, 69.10089111328125, 67.8305241721017, 68.12803908756801, 64.62398610796247, 72.87723009926933, 66.61938367571149, 65.32355158669608, 62.76478712899344, 69.39527933938163, 62.53239073072161, 33.648256710597444, 52.00790916170393, 59.90350505283901, 39.774962833949495, 36.54076746531895, 16.979992083140782, 12.134352258273534, 10.933916330337524, 12.072839856147766, 12.21091706412179, 5.070100077560969, 0.8095818981528282, 0.13901932670601777, 0.15081103039639338, 0.17952353826590947, 0.289272560604981, 0.2166886789990323, 0.04624790531982269, 0.05398607812821865, 0.06330425026161329, 0.04425152637330549, 0.08376445594642844, 0.021996695648080537, 0.32377432925360544, 0.04839602844523532, 0.0993951614946127, 0.11622622263218675, 0.09678714429693562, 0.05368941244004028, 0.057451254688203335, 0.05889904485749347, 0.07664283737540245, 0.12810791363673552, 0.035626871311771016, 0.04264289287051984, 0.040066271488155634, 0.05011624363916261, 0.06665944308042526, 0.048295500089547465, 0.14253636369747774, 0.04320318976949368, 0.10001416863607508, 0.10584712707038436, 0.014097579422273805, 0.046564547078950067, 0.03480778115668467, 0.06829464462186609, 0.13698727717357023, 0.11817431024142674, 0.10949189149375473, 0.07384847410555397, 0.030211920983025005, 0.016219371996287788, 0.03671349086133497, 0.032124246404107125, 0.03086439347160714, 0.10631830857268401, 0.022435366841299192, 0.015729373021583472, 0.12322111800312996, 0.05158764004175152, 0.0738959037033575, 0.0412491242667394, 0.0730314025921481, 0.06425908473985535, 0.02035857131704688, 0.12190516718796321, 0.5053831956216267, 20.07994999204363, 58.902054241725374, 82.64308302743095, 86.3873838697161, 79.75687081473214, 59.928018297467915, 58.44521713256836, 69.04096290043422, 60.03745242527553, 60.309168679373606, 80.17788301195417, 72.66922882625035, 72.49539879390171, 58.13451453617641, 72.60094887869698, 84.54387392316545, 77.83586066109794, 81.06812790461949, 75.14956896645683, 79.77733325958252, 75.02377183096749, 75.27833993094308, 75.32796396527971, 77.09344564165387, 74.31372152056012, 76.08534540448869, 78.66282136099679, 74.08253410884312, 72.85437052590507, 76.38699449811662, 68.85110337393624, 70.61017881120954, 71.9789947782244, 74.06314168657575, 67.17334965297154, 68.42496340615409, 64.45386641366142, 66.84676347460065, 32.74476160321917, 43.70341525759016, 24.152594906943186, 28.38724054609026, 23.70824544770377, 24.610008716583252, 20.089814696993145, 7.6540078946522305, 4.433612082685743, 1.457502339567457, 0.7917358300515583, 0.5320202548589025, 0.40531054405229433, 1.0482246726751328, 1.089718229004315, 6.232260116509028, 1.0520746260881424, 0.15193452153887066, 0.6226629795772689, 0.13942694983312062, 0.06987685936370067, 0.30499739253095215, 1.7380685359239578, 8.90502757685525, 2.0196040059838976, 17.355283396584646, 2.7694208111081804, 20.37361213139125, 6.169665532452719, 0.2158446628600359, 0.13029557839035988, 0.20059979946485587, 0.06324994031872068, 0.04566143053982939, 0.01760636712424457, 1.5441027326243264, 0.6583872511982918, 6.9265879562922885, 13.700161814689636, 18.667172772543772, 26.154574155807495, 25.521160738808767, 30.376235348837717, 20.859589985438756, 28.806687661579677, 40.82112182889666, 42.927106925419395, 61.44454601832798, 60.72549084254673, 57.742691721235005, 60.78113201686314, 59.82898562295096, 64.7972811290196, 67.85874080657959, 65.75976644243512, 64.26358304704938, 66.97627094813755, 63.25462818145752, 63.780634607587544, 67.74260861533028, 73.41713987077985, 68.26974064963204, 67.93539333343506, 71.24017197745187, 72.6819509778704, 70.07569558279855, 67.85541956765312, 68.07942949022565, 66.03555434090751, 70.01619121006557, 40.163770130702424, 61.70124026707241, 61.42679337092808, 57.20640543528965, 46.135816301618306, 30.37919875553676, 33.950937611716135, 34.297784737178254, 28.08863650049482, 13.269970178604126, 7.423508354595729, 2.3380560151168277, 0.035117722382502894, 0.09847231315714972, 0.28932575775044306, 0.2766227679593222, 0.056257820156003745, 0.041654114677969895, 0.13071544228919915, 0.0517494536803237, 0.07034474318580967, 0.07946496629821402, 0.14615405457360403, 0.13312082178890705, 0.08093202686203377, 0.015697018775556768, 0.05329151950510485, 0.08800429558115345, 0.032590291396315606, 0.033114235781665356, 0.08658750089151518, 0.11014627745108944, 0.011820589774288237, 0.061157412960061004, 0.06642027305705206, 0.11940547132066318, 0.13180214326296533, 0.03976239297272904, 0.19241505222661154, 0.15244273069713796, 0.23613024077245168, 0.16230120669518197, 0.23825598242027418, 0.1216739903071097, 0.14675177607153142, 0.15560923649796418, 0.3001432887145451, 0.1797581213925566, 0.21327226875083788, 0.22442359823201383, 0.17712866248829023, 0.22330271266400814, 0.13946508350116865, 0.2569278004978384, 0.22875746924962315, 0.1490248276719025, 0.2452099621295929, 0.15559855635677064, 0.17660358494945935, 0.207233673493777, 0.19603775069117546, 0.20896880967276438, 0.26265903296215193, 0.23508236557245255, 0.2656588362795966, 0.2851065184388842, 0.23336873895355634, 0.3748022796852248, 14.103735770498004, 58.90038667406355, 89.14920943123954, 101.15067304883684, 98.54238183157784, 65.44844545636857, 56.75901787621634, 76.1364494051252, 72.58422456468854, 71.48568657466343, 89.69008500235421, 81.68793501172746, 77.4394450868879, 66.10366753169468, 77.64987822941372, 86.13495581490653, 79.21026992797852, 83.48346069880894, 77.76352296556745, 81.34459672655377, 78.70278739929199, 77.8857695715768, 75.66709164210728, 77.89013998849052, 72.06102521078927, 75.1784109388079, 78.25829723903111, 72.65291445595878, 71.50997052873883, 76.0480683190482, 70.51038183484758, 70.47659969329834, 70.30973175593785, 73.8556684766497, 66.1606775011335, 69.19114126477922, 64.69311373574394, 67.73573684692383, 39.952016830444336, 50.269542830330984, 27.714674030031475, 36.70368535178048, 28.57804329054696, 33.881768294743125, 25.2314156464168, 16.428887026650564, 10.059257115636553, 2.3158914787428717, 2.6717601886817386, 2.5620668062141965, 0.36948213087660925, 0.5610073251383645, 1.6051934659481049, 14.814889975956508, 2.5885572476046423, 0.6668665504881314, 1.1500552999121803, 0.20446056872606277, 0.15150086980845245, 0.20706485398113728, 3.1303111144474576, 14.18316410269056, 7.01261316878455, 27.84219605582101, 3.870931761605399, 29.78736857005528, 7.499764834131513, 0.5683266552431243, 0.19782437410737785, 0.6681857854127884, 0.09208307135850191, 0.0827690993568727, 0.4030848406255245, 6.327831285340445, 1.8265500451837267, 9.584053312029157, 17.08713504246303, 27.2969639641898, 31.709271567208425, 32.01167801448277, 32.084203311375205, 26.839004720960343, 35.74122435706002, 47.830537523542134, 50.16670254298619, 62.91988481794085, 63.227141107831685, 57.81393160138811, 63.15045383998326, 60.04895864214216, 65.2993162700108, 69.3190506526402, 71.47619533538818, 66.38663986751011, 71.53438649858747, 68.68215097699846, 66.90868582044328, 68.22813483646938, 76.94590064457485, 73.5034156526838, 68.748610496521, 71.5741718837193, 75.5514110837664, 72.21582412719727, 68.81680706569126, 68.0227460861206, 67.66039058140346, 68.26205594199044, 46.431590693337576, 71.4000152860369, 70.9924339566912, 62.98860945020403, 61.02414526258196, 38.89634575162615, 39.565464224134175, 40.95633724757603, 33.54718126569475, 17.73276686668396, 10.175306797027588, 1.8376313362802779, 0.13903770143432276, 0.19002100426171506, 0.7405505137784141, 0.5062384211591312, 0.25979708081909586, 0.1466835154486554, 0.2902416171772139, 0.14138938167265483, 0.14051526572023118, 0.1424387360789946, 0.1905052882752248, 0.5025550073810986, 0.21984592958220414, 0.22874764406255313, 0.26488215795585085, 0.26828745380043983, 0.19654160365462303, 0.11879051503326211, 0.17796564900449344, 0.2689195227410112, 0.20983582814889296, 0.1668364940477269, 0.21763663313218526, 0.1965979492025716, 0.264198221798454, 0.18104941424514565], [0.039983137377670834, 0.024758730116965513, 0.019319344045860425, 0.04895178933760949, 0.04427633022091218, 0.03512209214802299, 0.052365444733628204, 0.032230993533240895, 0.10451033844479493, 0.046271894925407, 0.04423040697085006, 0.10446400807372161, 0.14078368060290813, 0.013942776746781809, 0.028851169893251996, 0.16077526286244392, 0.04319559017728482, 0.12735032928841455, 0.0211963008290955, 0.08729926377002682, 0.05742653565747397, 0.11998476380748407, 0.08497004304081202, 0.06770456342824868, 0.18917594317878994, 0.05086132937244006, 0.020068867398159843, 0.2755751098905291, 0.30275638135416166, 0.5254924765654972, 0.6636172905564308, 21.462066548211233, 38.17623792375837, 52.595382826668875, 62.83520712171282, 49.43800326756069, 33.45014272417341, 29.036728620529175, 32.68704291752407, 55.67813178471157, 79.35422965458461, 75.75586182730538, 58.12059382029942, 50.16610152380807, 60.89354692186628, 89.27060140882219, 69.97163936070034, 81.56996849605015, 72.09357057298932, 71.60108920506069, 74.57981668199811, 73.71245915549142, 72.0139720099313, 76.40230137961251, 74.11330768040249, 70.18656103951591, 71.85362843104771, 72.98662948608398, 71.37370245797294, 68.48019463675362, 71.9636184147426, 72.41142981392997, 70.11959430149624, 65.09708200182233, 70.9862083707537, 63.03976903642927, 68.87820134844098, 56.877324853624614, 31.22788299833025, 35.133309091840474, 17.81273889541626, 22.641189745494298, 24.5058274269104, 26.957542725971766, 18.75673505238124, 7.062039179461343, 0.9148830963032586, 2.0339757033756802, 1.2390356681176593, 0.7538610366838319, 4.533112457820347, 4.171925987516131, 0.10432819928973913, 1.3564043130193437, 0.14709691969411715, 0.32840571073549135, 0.3063033553106444, 0.06462400087288447, 0.0319541716016829, 0.2467398957482406, 0.046531356538512876, 1.8263956648962838, 0.1992797910102776, 2.686493192400251, 0.9929109322173255, 9.639888167381287, 3.9548186659812927, 0.15723295722688946, 0.12439788771527154, 0.09920522597219263, 0.06462507974356413, 0.18163152943764413, 1.266933988247599, 4.0669361012322565, 0.18057560681232385, 3.242293711219515, 8.407187410763331, 21.04952594212123, 23.99044132232666, 22.91970133781433, 26.769533157348633, 20.679523944854736, 19.268699169158936, 36.145234312329976, 33.34329332624163, 52.14264862877982, 61.34429046085903, 55.520737716129844, 58.6600067956107, 60.45145389011928, 63.51174627031599, 60.92088808332171, 63.63413878849575, 62.470120974949424, 64.10526139395577, 58.80914293016706, 66.4257721219744, 70.84274196624756, 70.09955569675991, 67.9449679510934, 63.719254221235005, 70.98392241341728, 72.49807385035923, 65.36074529375348, 64.5907598223005, 67.7684976032802, 69.48650918688092, 50.54817949022566, 34.429869992392405, 66.87974657331193, 43.38154690606253, 31.34268808364868, 19.82855200767517, 15.352873359407697, 7.776461209569659, 6.0342025841985425, 7.36202027116503, 5.392170361110142, 1.62747514460768, 0.13524881617299148, 0.14362944290041924, 0.18767467087932996, 0.25083404034376144, 0.1546337338430541, 0.044849095200853686, 0.04224575310945511, 0.05434481280722788, 0.031745776534080505, 0.10718866544110434, 0.04068602162546345, 0.14058215570236954, 0.06135656298803432, 0.04134041436814836, 0.04365807964599558, 0.03405721964580672, 0.12381372334701674, 0.05611565349889653, 0.0331388632101672, 0.0214944559016398, 0.07492317858019046, 0.0829717099134411, 0.06618579849600792, 0.07302100065031222, 0.0931067703557866, 0.06882415977971894, 0.09155551716685295, 0.11961710639297962, 0.024126086117965833, 0.06653982414198772, 0.016388914148722376, 0.06793183194739477, 0.036727159949285645, 0.054579585923680236, 0.048564773319022994, 0.09235378647489206, 0.05786610421325479, 0.18316618566002163, 0.09975317692650215, 0.1433997723673071, 0.013091495194073235, 0.09314866310783795, 0.02554994266081069, 0.03412416051807148, 0.06989442663533346, 0.03936055774933525, 0.038339488075247834, 0.02603658627984779, 0.05095181540985193, 0.07005483909909214, 0.03198518743738532, 0.014710595099521535, 0.05801747180521488, 0.0665898457435625, 0.16929038880126818, 0.06304613554051944, 0.4488335171980517, 2.7210969584328786, 33.47472545078823, 63.723909514290945, 74.24782480512346, 83.12965147835868, 65.71832738603864, 48.49378824234009, 63.18352031707764, 73.12646198272705, 71.82459885733468, 79.60946478162492, 72.8819270815168, 71.74174853733608, 67.53196007864815, 68.35379300798688, 85.87439141954694, 77.17502444131034, 81.75342873164585, 73.93691376277378, 75.98326941898891, 79.3654648917062, 75.73381519317627, 75.9310884475708, 79.37351785387311, 75.22957747323173, 72.35873467581612, 75.87863649640764, 72.70271914345878, 71.5578922544207, 70.31209414345878, 74.96884632110596, 71.2389143535069, 73.50583362579346, 69.15899889809745, 71.86612824031285, 62.46709850856236, 68.26515483856201, 59.279786109924316, 35.81122745786394, 38.64799281529018, 22.56821976389204, 27.14376834460667, 24.411382300513132, 26.350289276668004, 17.532377345221384, 6.700920454093388, 1.8366336183888572, 1.646667046206338, 1.7773164127554213, 0.8530011368649346, 0.5076102018356323, 1.2177312970161438, 0.4771978280373982, 1.8639063835144043, 0.26721067300864626, 0.42606980726122856, 0.33789285165922983, 0.23118828024183, 0.13523608685604163, 0.18854900396295957, 0.5478783239211354, 2.449786522558757, 1.6898909211158752, 10.614199314798627, 1.1989277345793588, 13.904347658157349, 11.616780076708112, 0.24091977519648416, 0.14399103421185697, 0.03720644994505814, 0.025118689551683407, 0.042841075986091576, 1.7700922404016768, 5.034583926200867, 0.8340404257178307, 7.042236379214695, 11.43472945690155, 17.18656029020037, 25.008727618626185, 22.698218822479248, 32.55380426134382, 24.853904383523123, 24.912038224084036, 39.76833077839443, 38.73606123243059, 55.99035256249564, 61.568286487034385, 58.903659275599885, 60.64731666019985, 62.76118796212332, 68.75940104893276, 66.20959281921387, 64.15023013523647, 64.00145530700684, 64.18788242340088, 61.38185937064034, 67.20568656921387, 72.52786772591728, 73.56740161350795, 69.56976250239781, 70.0669755935669, 74.19856902531215, 75.39618137904576, 68.43280792236328, 71.19197232382638, 66.91896915435791, 72.40072958809989, 55.77335684640067, 44.6392959186009, 73.33666583469936, 53.60545287813459, 45.65906912939889, 30.845770290919713, 26.452782154083252, 28.983050312314713, 26.0021584715162, 17.551575217928203, 7.9697392497743875, 3.576632342168263, 0.19992116945130484, 0.0799183159002236, 0.4554716795682907, 0.24762123131326266, 0.06643567580197539, 0.06109628374023097, 0.0751456498567547, 0.07832141087523528, 0.04222970236358898, 0.08637205245239393, 0.14221096544393472, 0.17929739611489431, 0.16082255675324372, 0.033571300362902026, 0.0221123570310218, 0.03998754446261695, 0.11925140315932886, 0.02553638383480055, 0.12303251240934644, 0.04717348476073571, 0.007283559434914163, 0.06569276138075761, 0.05985861551016569, 0.026457566368792738, 0.02060479810461402, 0.05610733126689281, 0.16099863659058297, 0.27962102421692436, 0.08927422815135547, 0.20879426332456724, 0.10858143320573227, 0.1866830733737775, 0.1827703011887414, 0.184261042624712, 0.1023774246818253, 0.17819194043321268, 0.1250802632421255, 0.28510459139943123, 0.22230625684772218, 0.1903037226625851, 0.16869190734411987, 0.11606638692319393, 0.2273186900253807, 0.08547125650303704, 0.18526405308927807, 0.08152490361992802, 0.2062329157654728, 0.1404837274125644, 0.1936441912714924, 0.16444283963314124, 0.1650267190166882, 0.2265521218734128, 0.17501027616006987, 0.10236998115267072, 0.5806927659681865, 0.32740172318049837, 0.6757533507687705, 1.335207856127194, 26.548071486609324, 61.23910168239048, 88.26693412235805, 101.78681537083217, 75.74498789651054, 54.57519905907767, 64.42909608568463, 72.8830874306815, 83.03326606750488, 94.67575100490025, 86.32806709834507, 83.75105667114258, 76.77555165972028, 73.56840910230363, 88.3136260168893, 78.23673003060478, 83.83531747545514, 78.07954093388149, 78.83431679861886, 77.7238209588187, 77.17093195234025, 77.28902353559221, 80.11854539598737, 75.024918283735, 72.30995832170758, 75.61889198848179, 71.91485595703125, 73.8827872957502, 71.61602783203125, 76.15487602778843, 71.55902481079102, 73.55228928157261, 68.67055443355015, 70.14228016989571, 62.783630643572124, 68.6798163822719, 60.162429673331125, 43.778831005096436, 47.01312017440796, 30.08750295639038, 33.54176861899239, 27.44556508745466, 34.71635464259556, 22.27912780216762, 16.799920831407817, 1.82755623119218, 2.6742478609085083, 7.790100523403712, 2.464390767472131, 12.48047763960702, 12.559695788792201, 2.214651448386056, 5.001007190772465, 0.3221716023981571, 3.570467335837228, 1.0841728065695082, 0.3366302879793303, 0.4859904476574489, 0.47003613518817083, 1.1881191602775028, 6.235563116414206, 2.9294842907360623, 21.095663717814855, 3.0454996653965543, 22.317507914134435, 16.45124806676592, 0.4088421016931534, 0.6126488340752465, 0.13231902409877094, 0.24580767005681992, 0.3611002963568483, 3.6410794896738867, 12.268311790057592, 1.304313776748521, 6.336935596806662, 12.086441823414393, 25.718480893543788, 28.316090992518834, 26.92635226249695, 38.46210765838623, 30.71229887008667, 29.438350132533483, 49.51514911651611, 46.18488448006766, 60.63465704236712, 63.43202263968331, 62.937171936035156, 62.222737312316895, 63.9517548424857, 69.9168597630092, 72.40949126652309, 66.27042429787772, 67.4299396787371, 66.89539391653878, 63.444710050310405, 67.7371403830392, 73.54229082380022, 78.2124947139195, 72.20640236990792, 65.2870179585048, 75.91989489964077, 79.05150359017509, 71.17205878666469, 69.9405322756086, 69.24691445486886, 66.35416398729596, 59.49779278891427, 50.84752525602068, 82.57697786603654, 62.38941070011684, 58.61590657915388, 41.40818555014474, 33.99714660644531, 34.92732974461147, 35.3935295513698, 19.200552974428447, 9.551092794963292, 2.7780941171305518, 0.2696040560092245, 0.14058001153171062, 0.6266776812928063, 0.43393169396689957, 0.34584110230207443, 0.18437335374099867, 0.14505576422171934, 0.18171485353793415, 0.050056423991918564, 0.1484662305031504, 0.2375202061874526, 0.25126583288822857, 0.22274209346090043, 0.17551602902156965, 0.13506695521729334, 0.19554868979113443, 0.23156342868294033, 0.11997880627002035, 0.22239758766123227, 0.10390940069087914, 0.15975994377263955, 0.22458177831556114, 0.28610198359404293, 0.11944232934287616, 0.30565144600612776, 0.19568689380373272, 0.4601061280284609], [0.029740871795053993, 0.11504505601312433, 0.09197702312043735, 0.046953714053545675, 0.10674734626497541, 0.04674861666613391, 0.052231797083680115, 0.036971320597721, 0.053208259865641594, 0.17504041668559822, 0.2529086475925786, 0.04763363328363214, 0.13385259466511862, 0.17314935315932545, 0.03936680705685701, 0.09031781501003674, 0.07073235631521259, 0.07558812932776553, 0.04267969660993133, 0.03794905902551753, 0.1203166488558054, 0.0673630703240633, 0.12625062758369104, 0.13596308284572192, 0.0945434800482222, 0.16210905914860113, 0.04315772113789405, 0.11347046800489936, 0.21646485743778093, 0.5602398748908723, 0.499523150069373, 3.316067946808679, 27.75137267793928, 45.50752544403076, 61.132676124572754, 54.33311687197004, 51.522309984479634, 28.01542854309082, 13.631263477461678, 41.549254826136995, 79.97453008379254, 88.56875692095075, 94.09944656917027, 65.46432209014893, 44.6676549911499, 91.10925456455776, 80.05433709280831, 73.13620335715157, 79.00579139164516, 74.62972559247697, 70.30424962724958, 74.6470057623727, 72.82208919525146, 75.96602399008614, 76.20233917236328, 78.2848949432373, 73.41473579406738, 74.56564235687256, 75.78292506081718, 70.49203164236886, 73.82076072692871, 73.22289603097099, 73.16417680467877, 73.00868306841168, 66.58246094839913, 63.84372425079346, 65.30192879268101, 46.247557231358115, 29.72655098778861, 25.989554439272197, 18.38689807483128, 28.6975679397583, 24.90432572364807, 26.30126452445984, 16.937241554260254, 3.5790998211928775, 0.4754062241741589, 0.9987678293670926, 0.09503557399979659, 0.3029206411114761, 0.26946775189467836, 0.1341928392648697, 1.2921319561345237, 5.6157199655260355, 9.459962827818734, 1.1133302705628532, 0.24823848104902677, 0.2922649271786213, 1.7168635023491723, 0.019258598198315928, 0.08963936141559056, 0.4487851783633232, 0.8178699048502105, 1.6601584936891283, 4.755831752504621, 4.34779748746327, 6.993304559162684, 0.4334448586617197, 1.3105640070778983, 0.5158954943929399, 2.650863915681839, 0.909800543316773, 1.2787888092654092, 2.9178543090820312, 0.46361735676016125, 4.650878344263349, 13.06324303150177, 17.478996072496685, 30.319819450378418, 21.363190208162578, 25.829756293978008, 28.309333869389125, 14.863492625100271, 26.888032947267803, 24.937400885990687, 35.35643311909267, 68.33433805193219, 52.47873299462454, 56.847610882350374, 57.16810349055699, 57.92333098820278, 62.23092229025704, 64.90967518942696, 59.40873077937535, 62.75020980834961, 60.981608390808105, 66.49010549272809, 67.72597462790353, 73.12746947152274, 70.78381429399762, 72.52442836761475, 72.51103224073137, 70.71848038264683, 66.3672821862357, 72.77524444035122, 67.70711026872907, 70.55198764801025, 35.87018639700753, 56.21997315543038, 61.51139463697161, 30.32837963104248, 21.066486494881765, 17.391718012945994, 13.55008680479867, 8.556095123291016, 8.792552743639265, 5.1143805129187445, 0.9471732207706997, 0.4460609959704535, 0.1605237570724317, 0.12823379545339517, 0.2622770991708551, 0.23967498913407326, 0.0909131887767996, 0.03183419303968549, 0.09510232148958103, 0.1547227847789015, 0.06789453287741967, 0.056833401056272645, 0.13410927089197294, 0.1584373026021889, 0.07461789888995034, 0.031347697002014945, 0.09915027142103229, 0.2336626531822341, 0.11629726524863924, 0.012150795448438396, 0.07692784922463552, 0.08492587719644819, 0.025670730375817845, 0.03114270818020616, 0.08454953453370503, 0.07459164637007884, 0.0676432577893138, 0.04286377298246537, 0.045856909693351815, 0.10548567146595035, 0.15158050267824105, 0.04067474437345352, 0.031094030077968324, 0.12212263766144003, 0.12126203812658787, 0.04555260370086346, 0.06382925316159214, 0.01878575428522059, 0.018929824233055115, 0.08207877818495035, 0.10389951443565743, 0.09800559641527277, 0.0693998085334897, 0.005176747217774391, 0.05363807787320443, 0.009211805832040097, 0.025221202622300813, 0.00758969916829041, 0.07182496054364101, 0.16062799362199648, 0.07087172740804297, 0.15375644234674318, 0.05155083290966494, 0.05638732874233808, 0.15482703489916666, 0.05167204640539629, 0.08523651052798543, 0.08277330627398831, 0.15839156934193202, 0.7756905938897813, 7.687539032527378, 44.60075078691755, 74.31694548470634, 81.56884288787842, 76.82829543522426, 62.764071464538574, 52.668762751988, 53.56612260001046, 77.58433587210519, 93.19837638310024, 83.50260298592704, 85.01161970411027, 80.4273441859654, 62.02726364135742, 92.26738725389752, 81.16770253862653, 78.3208588191441, 80.32799189431327, 76.22444139208112, 77.19601494925362, 76.28052030290876, 73.4280138015747, 80.2335033416748, 81.66014916556222, 77.2903436933245, 78.31901059831891, 77.9988237108503, 77.23926748548234, 67.81551606314522, 74.08921827588762, 72.49035440172467, 74.00449889046806, 75.28505189078194, 71.1100252696446, 66.27513517652238, 66.18120942796979, 49.55774504797799, 35.479360648563926, 30.698593548366002, 25.27263583455767, 32.103592259543284, 27.704918759209768, 24.93540849004473, 14.833995785032, 3.3834880547864095, 0.841385974415711, 1.4641378692218234, 0.5440593117049762, 0.5176066511443683, 0.5951235230479921, 0.1421954134213073, 0.5215539336204529, 3.7227431876318793, 13.240411673273359, 0.695495137146541, 0.4456971383520535, 0.09223407932690211, 0.7355417854019574, 0.15628270964537347, 0.31360534206032753, 1.0944880587714059, 3.0670935809612274, 1.9828521609306335, 3.8293919563293457, 7.791117565972464, 17.14434129851205, 0.4294480974120753, 0.15851548340703758, 0.6743985063263348, 0.5849825186388833, 0.19816033036581107, 2.2228629163333347, 5.195297930921827, 1.8076016562325614, 10.662159255572728, 18.47461039679391, 17.36034689630781, 27.702146427971975, 26.352670771735056, 35.28080545152937, 28.018770626613072, 23.448935202189855, 32.90641491753714, 33.53292008808681, 40.53391456604004, 68.62152794429234, 54.76884535380772, 62.89745603288923, 61.44664437430245, 60.70713370186942, 63.66464138031006, 70.03979424067906, 63.990692547389436, 64.27973066057477, 62.820546422685894, 68.93021556309291, 69.28512259892055, 72.11388710566929, 70.83178465706962, 78.94714164733887, 72.93672057560512, 73.81794670649937, 69.6669261114938, 78.7601100376674, 66.0765209197998, 77.87071282523019, 39.645375456128804, 68.90817587716239, 65.5441152027675, 43.915939807891846, 33.19395916802542, 23.46401105608259, 24.432753222329275, 21.774419341768535, 16.38333637373788, 7.588099019868033, 2.997091782944543, 0.6010374714221273, 0.10899948541607175, 0.11481273919343948, 0.6900152883359364, 0.2761458935482161, 0.03567525764395084, 0.044172219200325866, 0.08901030517050199, 0.11180633373026337, 0.18672062350170954, 0.06280313857964107, 0.083538958403681, 0.14652733025806292, 0.09470569741513048, 0.04260900343901344, 0.09414360579103231, 0.21612174942025117, 0.04689051190923367, 0.00929747342265078, 0.04123347046385918, 0.01487673948785024, 0.08930282161704131, 0.020560133537011485, 0.05736025635685239, 0.027983466096754585, 0.07425902850393738, 0.04729070507788232, 0.10849304723420314, 0.13757680196847233, 0.25210292797003475, 0.21525034760790213, 0.11105804531169788, 0.20857607360397065, 0.16415697282978467, 0.21026611434561865, 0.31669009796210695, 0.10826253531766789, 0.2569267419832093, 0.25719612038561274, 0.16049494647553988, 0.13053161358194693, 0.23057236043470247, 0.12507763052625315, 0.26783416526658194, 0.13819684726851328, 0.23212943545409612, 0.10408465271549565, 0.16363452800682612, 0.28317535349300926, 0.21410920098423958, 0.1877576828535114, 0.23014944312827929, 0.18544535764626094, 0.22699003480374813, 0.10434712363140923, 0.2563305268330233, 0.33358551136084963, 0.6953480850372995, 0.6203907015068191, 3.6927994915417264, 34.63630444662911, 73.82593713487897, 96.14159856523786, 88.37491607666016, 73.67022105625698, 52.112583773476736, 53.03652048110962, 78.66047981807164, 102.40986728668213, 95.30406965528215, 105.12106827327183, 98.5219680241176, 68.79152257101876, 91.60595348903111, 83.65078721727643, 79.49130371638707, 79.10224628448486, 78.40476526532854, 79.09053856985909, 79.07874052865165, 74.54787581307548, 81.56919724600655, 79.51347541809082, 76.06737041473389, 76.71640164511544, 75.06814997536796, 73.81110273088727, 69.28868007659912, 75.83452238355363, 72.99293845040458, 74.19794368743896, 76.09478105817522, 71.432067326137, 65.5910085950579, 65.9070474079677, 53.97093507221767, 41.53343377794538, 39.63745450973511, 30.830380031040736, 37.692539078848704, 32.38861778804234, 33.23683302743094, 19.313598428453716, 15.429650953837804, 0.25038542013083187, 2.634028647627149, 0.9160529992410115, 1.2297619943107878, 1.115982636809349, 0.2123578071062054, 3.1511761205536977, 12.544685074261256, 22.202876533780778, 8.584097232137408, 1.274200284055301, 0.7841776013374329, 7.924677576337542, 0.39805885031819344, 0.3723502169762339, 1.3744498704160963, 4.1106593779155185, 9.328603659357343, 10.152298705918447, 9.939948729106359, 30.055610724857875, 0.5371193098170417, 2.2017223707267215, 2.473768012864249, 5.0638592924390515, 5.811230983052935, 7.00052113192422, 11.35570672580174, 3.90703547000885, 8.807192598070417, 23.03699040412903, 22.079759665897914, 34.56349079949515, 29.439315932137625, 38.51140512738909, 32.61772768838065, 26.09051697594779, 40.79586165291922, 39.65724992752075, 46.07076726640974, 72.93455273764474, 55.06277847290039, 65.43261051177979, 60.59623350415911, 63.428923743111746, 67.93073109218052, 74.682434626988, 65.90670694623674, 67.5345378603254, 64.97716304234096, 71.56777259281704, 72.16873618534633, 78.97205788748605, 69.74705273764474, 78.26874732971191, 74.31484018053327, 77.46621649605888, 71.10568959372384, 80.409515108381, 64.53439603533063, 74.05690915243966, 47.20218413216727, 74.22087969098772, 74.99819551195417, 53.01428277151925, 50.7949343408857, 37.7717068535941, 32.243779114314485, 29.12450521332877, 26.790513242994034, 6.6989467314311435, 3.8572672605514526, 0.5886624583176204, 0.47160995645182474, 0.18673764115997724, 0.9134609954697746, 0.5092879746641431, 0.2031849500324045, 0.06303615429039512, 0.22940916142293385, 0.1791842436151845, 0.23876094818115234, 0.11589322478643485, 0.20998919063380786, 0.40695517723049435, 0.2224571630358696, 0.21050729283264705, 0.18034772761166096, 0.3467304174389158, 0.15369237507028238, 0.13022610997515066, 0.20687337139887468, 0.13928425391869886, 0.15173071676066943, 0.15210681515080587, 0.12270562137876238, 0.15196681980575832, 0.13049299136868545, 0.34187088534235954, 0.1850563535200698], [0.07275234149502856, 0.14455265764679226, 0.10895004735461303, 0.03679198379229222, 0.007819816686346062, 0.08695180634302752, 0.09438602599714484, 0.1362127023083823, 0.05933722920183625, 0.11522170581987926, 0.3405095269637448, 0.19459643374596322, 0.08668789014752422, 0.16634980802025112, 0.0991123141720891, 0.060609115952891965, 0.23148330726793834, 0.07059424729751688, 0.10206917979355369, 0.08012535729046379, 0.18405723784651074, 0.07049326093069144, 0.13825480772980622, 0.097518618617739, 0.0279104116239718, 0.1152153140200036, 0.2571202330291271, 0.08640635239758662, 0.3353230766952038, 0.46346368214913775, 0.7926257965820176, 0.3716455447886671, 6.272846281528473, 22.94878649711609, 25.36709485735212, 54.0270209312439, 55.44328614643642, 48.810389859335764, 19.93776031902858, 25.556106703622, 40.86261647088187, 77.22637162889752, 86.63515663146973, 99.2607421875, 40.488900661468506, 56.80523729324341, 95.71635491507394, 76.6767830167498, 72.65240028926304, 73.57908153533936, 77.11201817648751, 68.16742147718156, 77.67811570848737, 74.7213236945016, 72.90762846810478, 76.48380374908447, 76.40251677376884, 73.85634940011161, 73.47886071886334, 67.82294368743896, 73.16018159048897, 72.91979476383754, 73.87413678850446, 66.80227415902274, 68.3457886832101, 61.771604674203054, 64.43930298941476, 29.150041580200195, 26.574794258390153, 19.424276283809117, 13.506002221788679, 23.881365026746476, 24.742997237614222, 25.268850803375244, 13.910270128931318, 1.2548327233110155, 1.3803358631474631, 0.6705389991402626, 0.24297163795147622, 0.3261450763259615, 0.11762145347893238, 0.1789145123745714, 0.9958220102957317, 0.7914581192391259, 0.9083875077111381, 0.7342807416404996, 0.34947975991027697, 0.014159082684532871, 0.5798549652099609, 0.35222481404032024, 0.24553112632461957, 0.1672454471034663, 1.8623686603137424, 5.154366527284894, 8.059849568775721, 8.001037410327367, 6.106509447097778, 0.6300945665155138, 1.043005489877292, 0.6402694433927536, 0.5637122914195061, 1.961487535919462, 1.9097542890480586, 2.2251367143222263, 1.7991958558559418, 11.491405044283185, 10.930639386177063, 11.275749461991445, 25.969267436436244, 24.854557514190674, 21.7132682459695, 23.679650136402675, 14.858470814568655, 18.20025209018162, 27.192122595650808, 25.287650891712733, 43.04337460654122, 66.95174380711147, 53.1795699937003, 62.43775626591274, 65.22447027478898, 63.60117653438023, 61.40016092572893, 62.8092417035784, 62.54868425641741, 63.797629901341026, 63.297241483415874, 62.36705139705113, 65.97175598144531, 65.39945370810372, 68.11661624908447, 69.58700098310197, 65.61481312343052, 73.49978174482072, 66.0965803691319, 72.46987806047711, 46.58130005427769, 39.622675691332134, 68.87306662968227, 36.48159660611834, 24.024786267961773, 16.388257435389928, 16.86713423047747, 11.912556205477033, 10.856075661523, 5.886911630630493, 1.9824094304016657, 0.8699412792921066, 0.11181145666965417, 0.16904709328498158, 0.22623010272426264, 0.2023530253874404, 0.174526752105781, 0.15530431643128395, 0.08347248232790402, 0.039345616408224614, 0.2128036453255585, 0.04302167147397995, 0.03587224314521466, 0.13346912738467964, 0.10094534938356706, 0.036935164859252315, 0.08251489978283644, 0.0872460055564131, 0.023650482263682143, 0.06055434460618666, 0.013682849489019384, 0.055704468062945774, 0.012897097455736781, 0.10994404687413148, 0.06894580753786222, 0.11513800173997879, 0.004577796723294471, 0.07007867603429727, 0.15134659808661255, 0.06363255943038634, 0.048347862636936564, 0.13587456116718905, 0.05444768210873008, 0.04717034314359937, 0.04393255045371396, 0.14342434890568256, 0.042194988512034924, 0.12182965981108801, 0.06682379783264228, 0.07121471328926937, 0.10692490530865532, 0.11740508223218576, 0.2952583522668907, 0.14256739988923073, 0.07671095550592456, 0.027767232253349254, 0.056002222799829075, 0.08887386534895216, 0.1351257570620094, 0.0303174501418003, 0.07124655015234437, 0.05275988392531872, 0.07189543997602803, 0.011153596636307026, 0.06507649552077055, 0.11958742727126394, 0.1891206425747701, 0.20216971236680234, 0.19327498679714544, 0.11176155720438276, 0.447417251765728, 0.9545893371105194, 13.617288913045611, 49.091194357190815, 68.90623038155692, 75.4947624206543, 77.09131949288505, 59.294481549944194, 45.06799282346453, 64.53727953774589, 77.61447715759277, 89.59026718139648, 72.81111798967633, 95.97951793670654, 61.58155059814453, 73.26985890524728, 97.39862496512276, 78.1334033693586, 79.86392865862165, 73.80052062443325, 81.1280769620623, 74.52675328935895, 78.6706519808088, 73.85560594286237, 79.58869661603654, 78.55264377593994, 77.83173343113491, 79.31661210741315, 76.2977796282087, 71.93237931387765, 72.77480670383999, 74.51924228668213, 73.63900974818638, 66.8236676624843, 73.86985669817243, 65.8180479322161, 66.61101804460797, 39.14050892421177, 32.87213250568935, 29.587135383061, 19.439256599971227, 29.7327070917402, 31.1446852684021, 21.317377260753087, 16.36305284500122, 2.4445204394204274, 2.993122624499457, 1.502843786563192, 0.2856524134320872, 0.39717667336974827, 0.225139819085598, 0.1317909745765584, 0.8029877862759999, 4.3627161383628845, 4.1369383335113525, 0.353141650557518, 0.8340909630060196, 0.3330843453960759, 0.6735456149492944, 0.2810830771923065, 0.24290842562913895, 1.2630898973771503, 3.0412365112985884, 8.47230679648263, 15.751755544117518, 9.468196443149022, 10.02591097354889, 0.9718785179512841, 1.0114023685455322, 2.021370585475649, 3.1442524577890123, 3.6583247014454434, 3.1510881824152808, 3.1689459213188718, 2.1500279903411865, 15.399780648095266, 21.046882152557373, 16.398705789021083, 21.244395119803293, 23.698773315974645, 27.480846302849905, 32.1244090625218, 22.658593245915004, 28.02590295246669, 35.15662029811314, 37.449640478406636, 49.19660895211356, 68.15487303052629, 57.17640658787319, 63.75875473022461, 71.18129294259208, 61.78553581237793, 64.95901434762138, 64.78977707454136, 67.06495775495256, 67.36526584625244, 65.01259190695626, 67.65904263087681, 61.791302817208425, 70.22671467917306, 70.30215127127511, 72.55324949537004, 68.32716056278774, 79.99283858707973, 66.08683899470738, 75.6156541279384, 50.80390793936593, 49.105188029153005, 77.83131653921944, 44.177112170628135, 38.73978199277605, 22.51845850263323, 22.84673830441066, 23.380974871771677, 22.33283042907715, 9.058048622948782, 3.2296247567449297, 0.7825290326561246, 0.09210850285100085, 0.02581922776464905, 0.32828547433018684, 0.5460213635648999, 0.19517070507364614, 0.08259829852197852, 0.10040467911000762, 0.11744664928742818, 0.1348468791693449, 0.14152088175926889, 0.20461428404918738, 0.09011354204267263, 0.09268668932574135, 0.075433470840965, 0.052234643538083346, 0.11047892924398184, 0.04408185190654226, 0.0374871564895979, 0.04693292713324938, 0.03467136847653559, 0.05405564832368067, 0.09510071336158685, 0.1259241843862193, 0.11157861059265477, 0.06255108317626373, 0.03798720965694104, 0.06018876350883927, 0.04805347343374576, 0.22028118265526636, 0.2495838531426021, 0.19455147401562758, 0.159135691555483, 0.08471260006938662, 0.21560155733355454, 0.13312255883855478, 0.14856727793812752, 0.10498167601014886, 0.22426108909504755, 0.3508999337043081, 0.1967107488640717, 0.310993742197752, 0.2144498662757022, 0.1365045809320041, 0.15191438261951717, 0.27919335716537064, 0.32393837187971386, 0.22148757720632212, 0.14382059978587286, 0.3459940712366785, 0.17342082144958632, 0.19736090754824026, 0.2375043827508177, 0.12023541464337281, 0.23363420899425233, 0.29914540797472, 0.30678603798151016, 0.482586427458695, 0.3741261873926435, 1.021704375743866, 0.36516822235924856, 6.2225222161837985, 35.83519526890346, 63.89735739571707, 88.48275211879185, 89.63748019082206, 72.75523362840924, 43.79732363564627, 67.33427688053676, 76.53682545253209, 98.86394446236747, 90.9458120891026, 119.15319851466587, 74.08536897386823, 77.15020547594342, 93.75803293500627, 80.88032504490444, 81.49097442626953, 72.25006484985352, 80.75418744768415, 74.96231501443046, 78.96285152435303, 77.53953388759068, 80.6106515611921, 78.82686138153076, 78.78822939736503, 79.92721979958671, 73.59118529728481, 70.81356648036412, 72.78896713256836, 74.71707834516252, 74.46901375906808, 70.67902851104736, 73.20638016292027, 65.31679793766567, 64.1012383869716, 42.52756813594273, 39.55063329424177, 34.631669998168945, 21.409616334097727, 33.64894805635725, 32.11655412401472, 30.534487519945415, 21.676861422402517, 10.163245592798505, 2.1038163900375366, 3.694498760359628, 0.6966170540877751, 0.5838286834103721, 0.3282329557197434, 0.15338776712971075, 3.931972554751805, 7.029986705098834, 4.314674990517752, 1.0382604130676814, 1.422993459871837, 0.3627107585115092, 1.061541112405913, 0.4650813096335956, 0.22552817181817122, 0.7758263551763126, 1.9201713757855552, 20.923068727765763, 21.521702936717443, 20.845401763916016, 13.031362959316798, 1.4268643664462226, 3.4554783403873444, 1.8954203724861145, 3.886755849633898, 4.4604412487574985, 7.197150809424264, 6.786102328981672, 3.3609791483197893, 14.250585947717939, 22.012414251055034, 19.268624476024083, 34.70684950692313, 27.815214463642665, 31.685859612056188, 33.94891568592617, 26.11800057547433, 32.85132959910801, 43.27279370171683, 41.45649637494768, 54.74433210917881, 68.72875254494804, 60.42875412532261, 64.67790412902832, 74.03878130231584, 67.70426150730678, 71.46127755301339, 68.13532774788993, 67.70253140585763, 65.25924600873674, 66.36415549686977, 70.72706835610526, 69.16567611694336, 69.08516733986991, 74.21869795663017, 75.22552667345319, 75.72201715196881, 78.35726043156215, 71.53288568769182, 70.39989158085415, 57.75308970042637, 54.65423134395054, 88.58560630253383, 56.59539474759783, 55.28997067042759, 43.04415280478341, 37.52285017286028, 34.791930198669434, 32.628024918692454, 7.9447387627192905, 3.1515228790896277, 0.9849935684885297, 0.34254144078918863, 0.1737554884914841, 0.4071501339120524, 0.565609366766044, 0.3547378363353865, 0.2317942934376853, 0.23884242666619165, 0.2610332630574703, 0.1609520890883037, 0.27668446036321775, 0.23805331758090428, 0.2639451282364981, 0.15294545729245457, 0.1755329788263355, 0.15902283761118138, 0.2591613477894238, 0.15956715840314115, 0.06656937434204988, 0.09573971014469862, 0.15079707971640996, 0.14408768473991326, 0.21267526650003024, 0.32654109650424545, 0.2030836854662214, 0.18347177069102014, 0.2684029404606138, 0.2638201692274639, 0.16591758121337208], [0.0759454390832356, 0.04635034714426313, 0.03222525991233332, 0.08079489493476492, 0.0660130095535091, 0.08596594924373285, 0.032196591807795424, 0.08454726144139256, 0.09172855716730867, 0.10194156771259648, 0.06437720411590167, 0.23932285660079547, 0.04392008576542139, 0.08237159997224808, 0.06232884260160582, 0.031294662704957385, 0.1047522293935929, 0.023965381884149144, 0.08880336556051459, 0.02982579723798803, 0.07534951570310763, 0.10018820608300821, 0.09201009491724627, 0.20206272096506186, 0.12447908121560301, 0.06386981598500695, 0.12316770372646195, 0.2773486375808716, 0.22458967646317823, 0.2759082434432847, 0.6660814583301544, 0.7106232653771127, 0.11526935254888875, 4.739048378808158, 11.072668382099696, 25.460473435265676, 44.163521494184224, 50.88749129431588, 46.505130427224294, 25.47285338810512, 31.377550670078822, 35.70120620727539, 65.69018023354667, 90.87332848140171, 77.9025981085641, 39.39871440614973, 82.12909698486328, 88.25517777034214, 81.63967282431466, 77.46438217163086, 77.07962567465646, 76.58005714416504, 69.27105249677385, 77.13534327915737, 79.35240922655377, 74.12696089063371, 81.03076049259731, 80.58440821511405, 76.9015780857631, 73.73290770394462, 74.93031855991909, 72.04835864475795, 69.26500756399972, 77.41124234880719, 65.54029369354248, 65.71467958177838, 43.83770309175764, 20.614870956965856, 23.86358458655221, 10.52377198423658, 18.450048514774867, 28.719836916242325, 24.9981107711792, 20.02830229486738, 16.84306045940944, 3.8306296042033603, 0.2693271594388144, 1.2000802670206343, 0.27491926508290426, 0.1253752088440316, 0.24444992148450442, 0.33342372147100313, 0.036427495136324844, 0.18786612632019178, 0.18964433590216295, 0.05015804818166154, 0.24645176263792173, 0.7469856856124741, 0.1800557268517358, 0.5928672041211809, 0.32571933631386074, 1.0896606892347336, 1.3218395220381873, 1.917560807296208, 4.000457039901188, 2.704373295818056, 1.5495392637593406, 0.4842484582747732, 0.23976254729287966, 0.1504505518823862, 0.06566125021449157, 0.992192553622382, 0.5491325280496052, 0.12127704732120037, 0.9742561046566282, 10.300416929381234, 9.325931208474294, 6.502578479903085, 19.304723841803415, 23.372944491250173, 19.42629647254944, 22.932117768696376, 17.2967917237963, 8.585313166890826, 16.72652006149292, 25.352666922977992, 30.270070348467144, 45.10341821398054, 67.4951068333217, 53.807805265699116, 58.07815422330584, 56.78398970195225, 59.66948972429548, 57.01569128036499, 54.7802403994969, 52.328068256378174, 49.915028367723735, 48.213935647692, 52.00836774281093, 53.08307341166905, 64.32287202562604, 62.00203473227364, 68.05335984911237, 65.66839763096401, 75.29274354662213, 56.48473078863961, 28.669264452798025, 53.69858305794852, 40.50095231192452, 22.327230181012833, 17.254534517015728, 12.999554106167384, 11.732265216963631, 10.51126435824803, 3.286660130534853, 1.3899835454566138, 0.06393447358693395, 0.08535190897860698, 0.09979285765439272, 0.10375206199075494, 0.07292318304202386, 0.2243466523608991, 0.18103967048227787, 0.04036145796999335, 0.0703898114817483, 0.06102548539638519, 0.09083277559173958, 0.2176782273288284, 0.039599218871444464, 0.11254346703312226, 0.10305650252848864, 0.021681461849116852, 0.020605318880240833, 0.09727904147335462, 0.09000924442495618, 0.0303073094359466, 0.07262539437838963, 0.050633609627506564, 0.16315624224288122, 0.06426700324352298, 0.04283646194796477, 0.047834058957440515, 0.050173763052693436, 0.0680308166359152, 0.14999667980841228, 0.03580305292936308, 0.06831178441643715, 0.09715712908655405, 0.03406076838395425, 0.09967431080128465, 0.04472467562715922, 0.14887308010033198, 0.057624973223677704, 0.08234010237668242, 0.01516987509759409, 0.03949328937700816, 0.015520019523267235, 0.27792115828820635, 0.15227882377803326, 0.23842070358140127, 0.03103509931159871, 0.017501921925161566, 0.03010651735322816, 0.05211517387734992, 0.08074848313948937, 0.038548636316720924, 0.019216308503278663, 0.09980314424527542, 0.054583233049405475, 0.0670393073399152, 0.03205803156431232, 0.08231971239937202, 0.08011453465691634, 0.0796155332188521, 0.09850710164755583, 0.29172269627451897, 0.2133498660155705, 0.7903872824140957, 1.207228334886687, 15.235262938908168, 40.21818494796753, 59.26421519688198, 66.71679047175816, 75.40433856419155, 63.64684009552002, 58.89375114440918, 58.082997117723735, 77.21876335144043, 74.92710849217006, 76.18866511753627, 87.00443949018205, 59.71636922018868, 96.67116941724504, 85.80208846500942, 86.64084720611572, 79.7021815436227, 77.25579724993024, 76.25476333073208, 74.4846749986921, 78.26842771257672, 79.0336606161935, 81.14876869746617, 79.96950653621128, 81.04164831978935, 84.48452241080147, 76.9500904083252, 73.47065489632743, 76.23867130279541, 73.6507522038051, 74.37034933907645, 66.42281913757324, 74.42451054709298, 51.80593197686331, 30.039595127105713, 33.117660999298096, 17.477151325770787, 26.443770340510778, 35.27834926332746, 26.609066247940063, 18.484277078083583, 13.418542640549795, 2.8008199376719336, 3.0117383684430803, 1.590136936732701, 0.2729074901768139, 0.10190205661846058, 0.5291247559445245, 1.957104742527008, 0.20219876723630087, 0.24055225348898343, 0.3161819295159408, 0.16198503651789256, 0.009656302248393851, 0.35342571245772497, 0.424418605864048, 1.0693757491452354, 0.3248593067484242, 0.9221593801464353, 0.36933146896106855, 3.227284950869424, 8.127661381449018, 5.394144083772387, 2.60543355345726, 0.428266279399395, 1.0163502459015166, 0.2114769872277975, 1.0435666654791151, 0.8416963634746415, 1.2846274673938751, 0.9067550067390714, 2.9079127396856035, 17.213055508477346, 17.329236337116786, 11.0880959885461, 18.16182334082467, 23.808443682534353, 21.7586121899741, 23.231520857129777, 25.257778848920548, 21.9917277268001, 32.01213312149048, 37.6880852835519, 41.609933444431846, 50.21640995570591, 72.47875785827637, 58.592741285051616, 57.929681641714915, 59.19620622907366, 64.82553250449044, 60.00674833570208, 60.69429343087332, 55.515106201171875, 56.349352087293354, 56.02748373576573, 55.1556203024728, 59.67836257389614, 67.18134008135114, 67.6991684777396, 70.84405517578125, 72.08186285836356, 73.93885925837925, 59.916887283325195, 41.00276858466012, 66.90517003195626, 47.9111887386867, 37.32100847789219, 26.044783932822092, 17.741502489362443, 23.59777430125645, 19.89306950569153, 12.186700854982648, 2.0120298181261336, 0.5132258662155696, 0.14153484600995267, 0.1594520110104765, 0.06303617464644568, 0.2690878265670368, 0.5996278556329864, 0.3749672451189586, 0.05463860829227737, 0.06490779135908399, 0.06779012669410024, 0.1425409641649042, 0.1837435375366892, 0.27934548471655163, 0.08595475341592516, 0.059468980346407206, 0.024739878717809916, 0.06595721361892563, 0.07961055955716542, 0.060075495658176284, 0.02059497800655663, 0.04706160790686097, 0.03852380532771349, 0.04419440729543567, 0.061980883058692725, 0.04904530503387962, 0.13626929212893757, 0.044794540985354354, 0.019939231586509516, 0.10126316840095179, 0.048979334466691525, 0.17846167167382582, 0.25721501080053194, 0.08515091333538294, 0.23950226125972612, 0.08358608944607632, 0.10818916532610144, 0.1591441732432161, 0.25481891365987913, 0.2435315107660634, 0.13029289139168604, 0.10902942238109452, 0.3838798025889056, 0.18610671215823718, 0.32817848292844637, 0.12009071026529584, 0.08922123456639902, 0.17545961562011922, 0.1392239864383425, 0.2904847769864968, 0.13620428847415106, 0.08518800205950226, 0.2608657734734671, 0.18876950070261955, 0.3023293385548251, 0.21143061614462308, 0.1405560185334512, 0.24540486452834948, 0.3734941727348736, 0.4571990668773651, 0.5406770589096206, 0.8579647019505501, 0.967543710555349, 0.30473585799336433, 6.632818988391331, 34.087806701660156, 55.29392419542585, 70.51538453783307, 83.45435469491142, 78.63994789123535, 68.53006880623954, 67.02400507245744, 74.72941834586007, 83.47915281568254, 99.89334092821393, 107.5270904813494, 74.45138617924282, 93.57312052590507, 86.77787263052804, 86.06331293923515, 79.6826501573835, 78.29028674534389, 81.45788015638078, 75.22705527714321, 79.31239455086845, 82.45953941345215, 81.51242351531982, 77.95288916996547, 84.02606637137276, 77.45910154070172, 71.81988103049142, 72.35940170288086, 75.74145126342773, 71.5106861931937, 78.59297112056187, 70.90169743129185, 74.69291251046317, 52.52976403917585, 31.066448552267893, 36.1380672454834, 20.325325625283376, 29.42002773284912, 38.427057470594136, 28.658145598002843, 28.692214352743967, 22.454022645950317, 6.568995875971658, 3.765830704144069, 4.613681163106646, 1.0961004751069205, 0.3166232486920697, 1.5070774108171463, 3.3958115535123006, 0.34524092450737953, 0.7120435205953461, 1.06795505966459, 0.5055683542575155, 0.4635738219533648, 1.7044886520930698, 0.2822852241141455, 3.5426812725407735, 0.48607355462653296, 1.3391604040350233, 3.5006309917994907, 5.8853109393801, 9.032239539282662, 5.038474048886981, 4.571967652865818, 1.3272567284958703, 1.5083808494465691, 0.6494831889867783, 2.329460007803781, 2.813623947756631, 4.052030478204999, 0.7908943380628313, 2.900796264410019, 18.7893933228084, 18.17516561916896, 13.429056133542742, 26.368924345288956, 34.39463220323835, 27.17387315205165, 30.68857077189854, 32.87728112084525, 20.51561767714364, 31.363369396754674, 37.85433830533709, 47.571317604609895, 57.12632744652884, 77.70731203896659, 61.90969317299979, 66.94285011291504, 63.91767392839704, 71.91357054029191, 64.30163833073208, 64.63990443093437, 62.28340898241316, 63.198875835963655, 64.35133879525321, 59.93322944641113, 61.59027753557478, 72.99558571406773, 71.91099275861467, 73.28495734078544, 76.26628344399589, 76.42721761975969, 61.160323006766184, 47.16689075742449, 69.97126415797642, 60.843700545174734, 48.677234581538606, 45.94487285614014, 36.02571487426758, 35.15349013464791, 26.93980050086975, 11.789256947381155, 1.07083389375891, 0.6467661719237054, 0.1698145978152752, 0.3363291812794549, 0.14910454196589334, 0.2989507227071694, 0.6325203020657811, 0.41203412041068077, 0.15180942682283266, 0.17930239013263158, 0.1865627555442708, 0.19311703741550446, 0.46703809606177465, 0.41871956310101915, 0.1943589329187359, 0.12453548104635306, 0.17832014283963613, 0.12223669939807483, 0.12177776545286179, 0.16344987148685114, 0.09077089998338904, 0.18349682220390864, 0.12841603638870375, 0.2507199378950255, 0.2139078660735062, 0.2544026459966387, 0.17984588311186858, 0.10374267785144703, 0.1435745358467102, 0.20920062437653542, 0.16663049081606524], [0.023652519565075636, 0.08479454674358879, 0.07642128212111336, 0.03446654250313129, 0.06357642422829356, 0.10606334903942687, 0.09812308475375175, 0.03704023600689002, 0.12519344288323606, 0.07847151639206068, 0.05302821399111833, 0.3103865890630654, 0.1617973130196333, 0.09899511081831795, 0.02778379529315446, 0.019484124578801647, 0.029682178515940905, 0.056064108586204905, 0.016752876940050294, 0.049875526555946896, 0.04196081929174917, 0.05391700665599533, 0.0428295680321753, 0.0769164701923728, 0.3778549815927233, 0.06284524846289839, 0.09578152825789792, 0.3117247686854431, 0.48973601524318966, 0.2032315382467849, 0.40091173723340034, 0.891808671610696, 1.0190635174512863, 0.23253381518380983, 4.509424311774118, 5.512624331883021, 26.861162526266916, 32.33118050439017, 35.645874227796284, 34.89974192210606, 29.490711757114955, 24.697734934943064, 28.90429421833583, 54.57324661527361, 93.54222883496965, 55.36356946400234, 53.054113319941926, 91.70754310062954, 80.8481479372297, 79.23845876966203, 74.40364510672433, 80.88903113773891, 72.08300236293248, 71.22249576023647, 71.3317561830793, 67.2068955557687, 67.62808145795549, 76.26598467145647, 73.13849626268659, 74.88805266789028, 76.76343400137765, 85.16491780962262, 72.63402230398995, 62.29709693363735, 71.86340454646519, 60.70148481641497, 24.977207115718297, 29.818260260990687, 11.930542486054556, 18.27387867655073, 29.84336062840053, 18.414449419294083, 21.617713144847325, 20.55681528363909, 22.667639800480433, 3.3237778416701724, 1.5220369909490858, 0.5622344964316913, 0.2888976021536759, 0.03527721882398639, 0.8911613492029054, 0.19161972776055336, 0.41563754848071505, 0.3697321303188801, 0.05120644585362502, 0.16056484915316105, 0.39335801399179865, 0.11463427091283457, 0.18308318725654057, 1.8955686730997903, 0.028696976202939237, 1.4604838767221995, 1.0589525827339716, 0.29667613761765615, 2.1116070577076504, 0.3931105115583965, 0.18127054880772317, 0.15313098233725342, 0.21789424573736532, 0.30476666348321096, 0.4055573136678764, 0.22024671307631902, 0.3086446268217904, 0.25587683117815424, 1.5116254410573413, 7.845133730343409, 15.740869453975133, 16.40640091896057, 15.194569076810565, 18.475902761731827, 19.873326199395315, 25.278119700295584, 22.802096128463745, 10.788955194609505, 13.552919932774135, 24.412693772997173, 24.33446400506156, 27.086904287338257, 43.545885699135916, 69.09628445761544, 62.5636020387922, 52.78002773012434, 48.69132205418178, 48.483126231602256, 47.53862633023943, 52.361023562295095, 46.37333352225167, 47.425332478114534, 46.45667021615164, 52.87281050000872, 53.487854616982595, 62.24211583818708, 71.3349940436227, 74.64096777779716, 59.07055500575474, 35.75348097937447, 52.87054886136736, 41.64627252306257, 20.43697622844151, 11.162641474178859, 13.119129129818507, 8.634062596729823, 4.480653992721012, 3.6952895522117615, 1.392220214009285, 0.1937477764274393, 0.1096031576661127, 0.2958046815225056, 0.0921523090718048, 0.028088323505861417, 0.19928549070443424, 0.19919698259660176, 0.11777121972824846, 0.12149922682770661, 0.14521459569888456, 0.10121356749108859, 0.13112328254750796, 0.13893866246300085, 0.21492028103343078, 0.042576175914811235, 0.01336835783773235, 0.07965329369263989, 0.03124468520815883, 0.05264445833329644, 0.0460694743586438, 0.07572001617934022, 0.016410394871075238, 0.09745653266353266, 0.08444481622427702, 0.06662975038800921, 0.012099823049668754, 0.06257996841200761, 0.046404663872505934, 0.1148942583905799, 0.04613465103986008, 0.059289426409772465, 0.07092233933508396, 0.07142340351960488, 0.0511449095127838, 0.04537669688995395, 0.07335689584059374, 0.08438526799104043, 0.13455398274319513, 0.10354485096676008, 0.055906790242131264, 0.056643743733210225, 0.01981102069839835, 0.1943396082414048, 0.15288790395217283, 0.10538910236209631, 0.13154754335326807, 0.036406263775591335, 0.037150362240416665, 0.0534679555733289, 0.07456955326987164, 0.09431938707296338, 0.06493518381778683, 0.048573007341474295, 0.010538499552889593, 0.059290885260062556, 0.05422794193561588, 0.06876847241073847, 0.16315552299576147, 0.08023411966860294, 0.08042935454951865, 0.5017736064536231, 0.1338156552187034, 0.3932243154517242, 1.1042484321764536, 0.8791171897734914, 18.45965439932687, 33.21417842592512, 41.7553106035505, 54.96754993711199, 68.35018689291817, 60.276394026620046, 52.794361863817485, 53.78023133959089, 71.10758645193917, 59.396356037684846, 82.04832417624337, 68.32184519086564, 66.08926391601562, 95.4895796094622, 75.01761572701591, 86.47306905473981, 78.45724500928605, 80.85666642870221, 74.3620045525687, 75.20775318145752, 69.52407809666225, 70.69787897382463, 72.86910070691789, 71.61773708888462, 78.56980582645961, 76.71928514753068, 79.37905556815011, 80.76344244820731, 77.04826150621686, 65.37803936004639, 73.71229239872524, 61.026000431605745, 39.124305725097656, 39.72498096738543, 30.317217350006104, 21.352255480630056, 28.986600841794694, 25.71690191541399, 18.123276472091675, 22.482901096343994, 22.270652736936295, 3.3406715180192674, 3.7403429746627808, 1.1252651044300623, 0.3676558131618159, 0.30532517922776087, 0.05980432592332363, 0.4842750025647027, 0.4908047893217632, 2.2161196896008084, 0.27751116028853823, 0.23250995789255413, 0.22328417508729867, 0.19544169838939393, 0.6033322768551963, 1.562922362770353, 0.07745036190109593, 1.5192112454346247, 1.045717567205429, 0.6827805851187024, 2.7196812629699707, 0.405017226934433, 0.4051863450024809, 0.24114646017551422, 0.004917913249560765, 0.4430674080337797, 0.36233742854424883, 0.5299753674439022, 0.9371818197625024, 0.1154777713652168, 3.108270342860903, 18.639852455684117, 25.952041115079606, 25.875711679458618, 21.000297955104283, 18.099584851946148, 18.182803426470073, 31.193715231759207, 30.084768840244838, 18.774341787610734, 27.98854422569275, 41.71725531986782, 39.24427679606846, 37.906988280160085, 42.45368446622576, 74.32032925742013, 67.29779883793422, 60.37375218527657, 49.479640347617014, 51.33016102654593, 54.648172514779226, 59.1275371823992, 53.43937703541347, 50.52053260803223, 52.68354157039097, 59.0341533933367, 57.172432218279155, 68.79642105102539, 77.03291293552944, 80.65937232971191, 58.79491301945278, 44.29923718316214, 67.37856469835553, 54.14393132073538, 33.6236183983939, 26.776908670152935, 16.11770326750619, 16.970551218305314, 11.563429202352252, 6.929201781749725, 2.100340553692409, 0.6515897959470749, 0.13446244836917945, 0.25290123799017494, 0.0767391011384981, 0.06568405577646834, 0.25816316849419046, 0.29603560056005207, 0.33479300513863564, 0.10858825926801988, 0.02261454419099859, 0.013277686051359134, 0.18870816113693373, 0.15762827172875404, 0.15710586761789663, 0.07632491657776491, 0.1101169783089842, 0.048241135863853354, 0.050136457197368145, 0.028787625088755573, 0.048017392334129126, 0.0537979916137244, 0.07085292520267622, 0.03423226810991764, 0.06217754964849778, 0.051533710078469346, 0.018152117928756133, 0.06062732783279248, 0.04167840623163751, 0.04930317548236676, 0.07028512031372104, 0.06377610351358141, 0.2129017479185547, 0.13293282687664032, 0.12641836144030094, 0.1084625402997647, 0.25175551804048674, 0.24485147850854055, 0.2270236222871712, 0.2097583394497633, 0.2176395236913647, 0.17417189186172827, 0.10517286682235343, 0.29782454456601826, 0.24424513961587632, 0.18177873082458973, 0.1789682659187487, 0.26387046224304606, 0.14068595798952238, 0.14306012487837247, 0.07899027676986796, 0.16346971185079642, 0.13808617820697172, 0.15544820656733854, 0.1392636943076338, 0.16339569725096226, 0.27421266585588455, 0.21192773804068565, 0.19122970583183424, 0.3762106741113322, 0.726887261228902, 1.1427208249058043, 0.5594056025147438, 1.2035803134952272, 1.549368490065847, 0.1751941998622247, 9.500247614724294, 31.481975146702357, 45.23852940968105, 54.94015319006783, 67.70673506600517, 72.72910145350865, 78.1771492276873, 72.3662804194859, 74.21817684173584, 72.23905195508684, 106.957247870309, 92.01080417633057, 79.90235914502824, 97.53561564854213, 76.36398901258195, 87.82490362439836, 75.18357345036098, 81.30777127402169, 74.62224238259452, 77.28875950404576, 74.49449280330113, 74.36553423745292, 72.64418751852853, 77.02422768729073, 79.54262311117989, 72.59006105150495, 74.60713005065918, 82.13955402374268, 76.74956539699009, 67.21108531951904, 74.08581365857805, 69.0702565056937, 40.213216985974995, 38.58659158434187, 25.784367186682566, 26.795118161610194, 42.21218245370047, 24.257363319396973, 22.885940040860856, 25.230243137904576, 28.111742734909058, 6.745719833033426, 7.030740584645953, 4.1799116390092035, 0.6472681249891008, 0.33703059649893213, 2.7414299930844988, 1.1519041721309935, 2.226267750774111, 3.0879444735390797, 0.2607540323265961, 0.37676837561385973, 0.6819279108728681, 0.4363125376403332, 2.724687222923551, 5.110215502125876, 0.09495473333767482, 3.1079472516264235, 2.20316390480314, 2.4332330908094133, 3.6508215154920305, 1.1456999736172813, 0.3909390095089163, 0.632384215082441, 0.48831869129623684, 1.80137237906456, 1.2864739511694228, 1.269939626966204, 1.4104582582201277, 0.7218377664685249, 6.61885050364903, 20.692605665751866, 36.550540106637136, 26.706705808639526, 30.872590337480815, 29.806524753570557, 28.98434615135193, 48.0610613822937, 35.618244716099326, 16.847321442195348, 25.7719281741551, 41.42302690233503, 41.063589641026084, 45.40993104662214, 57.10249512536185, 77.28312451498849, 72.85112571716309, 65.63100242614746, 58.09185954502651, 58.335588455200195, 61.6027842930385, 63.14285945892334, 57.61435154506138, 57.35090364728655, 55.697586740766255, 62.90852451324463, 62.92510291508266, 74.76632717677525, 79.05782645089286, 85.35637542179653, 63.68327644893101, 49.89478131702968, 70.23061261858258, 65.6598791394915, 49.628498554229736, 46.53117227554321, 37.623748438698904, 32.613826274871826, 20.648519345692225, 11.266687273979187, 1.1710789203643799, 0.5269550180860928, 0.25945176077740534, 0.43050566209214075, 0.21651494689285755, 0.33461267767207964, 0.3922869600355625, 0.2514305811907564, 0.2751930132508278, 0.20659385568329267, 0.12502526119351387, 0.09359214681067637, 0.21823434105941228, 0.3235515797776835, 0.263553396399532, 0.20311683868723257, 0.15810674748250417, 0.17002719640731812, 0.0927815960187997, 0.07520643980907542, 0.15745319612324238, 0.12945078872144222, 0.16067859876368726, 0.2624514012464455, 0.12685779428907804, 0.14171210649822438, 0.11595647782087326, 0.2222442523177181, 0.17711038275488786, 0.3119392128927367, 0.18757461410548004, 0.13333222615931714], [0.141267896762916, 0.03230452298053673, 0.032873790112457106, 0.03306210054350751, 0.11179211163627249, 0.05975725594907999, 0.0808388843600239, 0.12956733389624528, 0.09346790026341166, 0.1559626039649759, 0.158344085461327, 0.06452914846262761, 0.1625259103519576, 0.12542665536914552, 0.02964316275236862, 0.06944370974919625, 0.03297077651534762, 0.09799997814531837, 0.041602688508906534, 0.06757870196763958, 0.14906627259084157, 0.012736901275015302, 0.17458692459123476, 0.07213177372302328, 0.15648434311151505, 0.38563408702611923, 0.08282116334885359, 0.021723590392087187, 0.06166679598391056, 0.524702173258577, 0.09101929808301584, 0.4404200900878225, 1.1314587720802851, 1.1263709536620548, 0.9505863061973027, 3.4828171133995056, 4.226097183568137, 21.026572568076, 31.44911711556571, 27.906154223850795, 31.710105351039342, 30.640447548457555, 19.522725309644425, 18.59879902430943, 51.20260599681309, 83.82257447923932, 46.15015390941075, 60.548422949654714, 93.5740863255092, 93.25156484331403, 75.82674040113176, 74.1764668055943, 76.3746336528233, 68.09717518942696, 62.19053936004639, 61.01794746943882, 58.09779678072248, 59.0129405430385, 75.08000360216413, 73.64180987221854, 76.49688025883266, 72.28884274618966, 70.46287005288261, 70.36280904497418, 52.838771275111604, 28.092259986060007, 37.26268529891968, 27.63534470966884, 20.881516763142177, 22.098139388220652, 33.52971002033779, 24.50255482537406, 28.184245450156077, 13.62699554647718, 11.826273475374494, 7.477504542895725, 8.049461143357412, 2.0057775250502994, 2.6336927456515173, 0.07909708496715341, 0.2302188165485859, 0.03987717056380851, 0.2672493223633085, 0.13749507921082632, 0.4952025104846273, 0.22354826091655663, 0.05043620682720627, 0.2490570114127227, 0.23642961042267935, 0.6831962828125272, 0.13924013557178633, 1.1930291482380457, 2.1181446611881256, 0.5880185014435223, 0.14254781736859254, 0.33452582518969265, 0.22302452687706265, 0.08929044513830117, 0.2299627645739487, 0.11406939050980977, 0.46132027144942966, 0.19885463453829288, 0.5799620651773044, 0.913912194115775, 1.443140087383134, 2.627182283571788, 24.919010741370066, 28.329440219061716, 13.698620183127266, 26.585339886801584, 28.76196210724967, 7.7866715873990735, 6.883823531014579, 12.84453284740448, 18.409182684762136, 26.12636273247855, 30.718305587768555, 38.036679880959646, 31.79538059234619, 32.114629473005024, 46.68141664777483, 58.38190514700753, 56.384878226688926, 54.24766097749983, 53.20205783843994, 52.26718119212559, 51.14893116269793, 46.73929166793823, 48.3406777381897, 57.93673406328474, 74.00787571498326, 87.6626284463065, 74.69848496573312, 65.39590317862374, 41.69610847745623, 58.11863442829677, 46.02247381210327, 23.62511372566223, 13.551167249679565, 5.780767040593283, 10.479661345481873, 4.7595473017011365, 4.99612260716302, 1.3653099494321006, 0.11269934009760618, 0.12238301868949618, 0.04743344170440521, 0.04602379538118839, 0.07930773616369281, 0.030098934724394764, 0.09773226215371064, 0.1504768111876079, 0.13896763590829714, 0.12436002546123096, 0.06146866375846522, 0.11222792789340019, 0.0628495571602668, 0.09229687095752784, 0.06620981185031788, 0.011690092223164226, 0.04378825319664819, 0.15230572090617248, 0.0403917070611247, 0.14807068529937947, 0.031632820809526105, 0.00823301397862711, 0.025315753084474375, 0.051409382107002397, 0.08277697036308901, 0.04845474208039897, 0.04309025100831475, 0.07801951028938804, 0.21834247239998408, 0.10232434288731643, 0.019476492756179402, 0.020303396242005483, 0.04790895226012383, 0.1159039456397295, 0.04590945883787104, 0.07133205913539443, 0.028400235875908817, 0.03858589128191982, 0.07395615082766328, 0.0322452495539827, 0.1357653984533889, 0.07591635028698615, 0.07381232854511056, 0.09497881454548665, 0.09997961763292551, 0.1586479605840785, 0.03261390780763967, 0.12053566638912473, 0.016230961374406303, 0.07055766068931137, 0.07230051859681096, 0.14432947390845843, 0.07690227523978267, 0.05304435294653688, 0.04637580917083791, 0.13210730760225228, 0.10248634312301874, 0.2206806226500443, 0.2578337804547378, 0.057765545323491096, 0.16414522060326167, 0.17891216464340687, 0.5215872089777673, 0.10108987734253917, 0.5523511181984628, 1.789616352745465, 2.632794690983636, 16.1907114642007, 23.253626550946915, 27.38197864804949, 45.031949043273926, 56.30474812643868, 49.55488586425781, 39.70546695164272, 43.90791116441999, 58.24720389502389, 54.48979180199759, 79.63066373552594, 57.53303677695138, 74.5925110408238, 97.70768083844865, 86.19157668522426, 80.67845903124127, 76.92912769317627, 77.73548698425293, 70.84120641435895, 69.12117290496826, 62.67831679752895, 61.36239051818848, 67.30601855686733, 72.46923882620675, 78.28371374947685, 79.64051628112793, 77.98610850742885, 68.10729871477399, 75.29550892966134, 55.542450836726594, 36.45928594044277, 47.11142676217215, 41.553354263305664, 27.474021434783936, 27.226689883640834, 31.35846049445016, 24.32593856539045, 22.097079787935527, 20.138620580945695, 25.67141900743757, 12.877986686570303, 12.380303723471505, 2.589354553392955, 0.5042276776262692, 0.026018793395321285, 0.3291446082293987, 0.09991258515843324, 0.3214833236166409, 0.26075563366924015, 0.8490881068365914, 0.23405948760254042, 0.03928835823067597, 0.05395500800971474, 0.11386175879410335, 0.9029305119599614, 0.5761647117989404, 1.8067456164530344, 2.0527749231883456, 1.8824567709650313, 0.5168570056557655, 0.5489361328738076, 0.19313991761633328, 0.020175935135089924, 0.09019070504499332, 0.2621436177619866, 0.3190325636948858, 0.1680337826588324, 1.621331091438021, 0.7057479098439217, 5.605241213526044, 15.524926389966692, 30.52875873020717, 39.49022218159267, 23.424472332000732, 21.183405569621495, 19.765340770993912, 16.531333003725322, 15.614064829690115, 16.42984935215541, 20.434073618480138, 34.11085040228707, 43.11051504952567, 49.539342744009836, 44.24960272652762, 37.717337199619834, 51.66919837679182, 69.4697014944894, 63.94585582188198, 58.15634230204991, 56.234932626996724, 57.39670269829886, 58.327973229544504, 50.6484489440918, 59.63960552215576, 66.43659741537911, 83.4160075868879, 90.5588321685791, 79.71830136435372, 61.37214578901018, 55.80925471442086, 72.67020852225167, 54.281015804835725, 35.77550329480852, 29.27103751046317, 13.092345561300005, 10.852205514907837, 9.18418448311942, 9.152352179799761, 2.051083471093859, 0.26512235935245243, 0.09440186978983027, 0.10104304485555206, 0.06026566866785288, 0.0163791381554412, 0.0909528084365385, 0.12097866833209991, 0.05777184891381434, 0.14503895012395723, 0.27879701129027773, 0.03950902121141553, 0.03971696166055543, 0.10253438340233904, 0.21142004456903252, 0.10697710500763995, 0.2074610370078257, 0.07708393263497523, 0.0740662906318903, 0.02409167930350772, 0.030751217223171676, 0.037191681630377255, 0.07630254527820007, 0.06007648631930351, 0.07829555869102478, 0.029497623776218722, 0.027528930754799927, 0.01924361614510417, 0.08066701143980026, 0.15258048687662396, 0.11155646999499627, 0.060144434816070964, 0.04994993470609188, 0.14270331045346601, 0.23665018858654158, 0.09654762822070292, 0.26940190685646875, 0.14542264810630254, 0.2045788780919143, 0.20877945769046033, 0.13106756125177654, 0.20672367300306047, 0.27246161124535967, 0.12861159018107823, 0.23403858872396605, 0.32599967984216555, 0.31874337206993786, 0.2165059359478099, 0.2968083976634911, 0.07031279097178153, 0.18365772999823093, 0.20792590134910174, 0.195670893947993, 0.19152182872806275, 0.14254032634198666, 0.23957323602267674, 0.18149998863892897, 0.13524420213486466, 0.30728405554379734, 0.2950245833822659, 0.30305889940687586, 0.24352038279175758, 0.41015341132879257, 0.6540547779628209, 0.4429489086781229, 1.3293010188000542, 1.3429266533681323, 0.645987865115915, 9.96826090131487, 21.945975576128276, 30.932000909532817, 44.916723591940745, 64.31759834289551, 68.59256090436662, 74.72195598057338, 66.51174218314034, 64.08354132516044, 65.70577199118478, 108.89558683122907, 80.22685391562325, 88.91677134377616, 90.83551638466972, 93.41477802821568, 80.97493866511753, 75.26322759900773, 76.76023088182721, 71.39137867518834, 67.37547969818115, 68.18261023930141, 68.40675217764718, 67.79629039764404, 75.56598145621163, 80.36745071411133, 79.14845875331334, 80.13021142142159, 69.27319949013847, 75.88743986402238, 61.30304595402309, 46.404312065669465, 50.22271892002651, 40.80242075238909, 21.643847056797572, 31.873398440224783, 43.22959327697754, 37.628712926592144, 31.65146950313023, 19.912871871675762, 20.1889203275953, 11.628751822880336, 25.752292564937047, 17.18912591253008, 6.997497362749917, 0.24292718033705438, 0.5543688642127174, 0.1486286310745137, 0.4208443547998156, 0.4753701803939683, 1.622900624360357, 0.6009315113936151, 0.6546445063182286, 0.28426478217755047, 0.654764742723533, 2.1890592787946974, 1.399099582007953, 7.763441153935023, 5.7645217180252075, 2.872045704296657, 0.8382203099983079, 1.8751281585012163, 0.4062022476324013, 0.1561209333262273, 0.5848930062992233, 0.5324964235935892, 0.5986950056893485, 0.25897179224661415, 1.82386999470847, 1.0722277675356184, 11.321413023131234, 21.772699662617274, 30.891058649335587, 43.996889795575825, 20.060580151421682, 40.752682072775706, 36.13984598432268, 12.462176953043256, 15.016962698527745, 20.75840163230896, 28.493120670318604, 41.86820493425642, 49.94547189985003, 57.096328599112375, 51.0621794291905, 51.73548419134957, 60.54398305075509, 74.5668304988316, 67.45950426374162, 64.46492794581822, 63.83488614218575, 65.49030140468052, 66.78726605006626, 57.21959311621529, 62.311368533543174, 71.9156619480678, 84.28957680293492, 89.47476727621896, 81.57798671722412, 71.84581865583147, 55.447559288569856, 74.68032237461635, 65.80557591574532, 53.48997729165213, 50.080753326416016, 38.07903609957014, 25.152737719672068, 16.197048221315654, 14.125397648130145, 1.9738099489893233, 0.2791655643710068, 0.24609935869063648, 0.23482463083096913, 0.21838617005518504, 0.4369172751903534, 0.21081608054893358, 0.1936298877532993, 0.21387118447039807, 0.2736159621604851, 0.2783720855201994, 0.10635245924017259, 0.13117584187005246, 0.22457753068634442, 0.37241614343864576, 0.1386007113116128, 0.2776086522000176, 0.0994990316352674, 0.2626958909843649, 0.1130450808310083, 0.16403452440031938, 0.10079449069287096, 0.1878821397466319, 0.23855771337236675, 0.18667489024145262, 0.16268011422029563, 0.1409791936831815, 0.10512454834367548, 0.24037572581853184, 0.30964128619858194, 0.14550335306142057, 0.12877389575753892, 0.13841138647070952], [0.10641126787023884, 0.0825250099546143, 0.07656169137252228, 0.10228300653398037, 0.10523749728287969, 0.08957076831055538, 0.06781363114714622, 0.05403456624065127, 0.10392658119755131, 0.0832837817392179, 0.013522212260535784, 0.037847180385142565, 0.3810398621218545, 0.15130653737911157, 0.2096616482096059, 0.023647495013262545, 0.10630374721118382, 0.06682758405804634, 0.046503855514207056, 0.030507691004978757, 0.03213869920000434, 0.22248952915625914, 0.05153693311980792, 0.3733802059931414, 0.04329998278990388, 0.2601636525775705, 0.43941390407936914, 0.19692956283688545, 0.0783387745863625, 0.16643222288361617, 0.2553118829216276, 0.12428643155310835, 0.40234260473932537, 0.8720521745937211, 1.400750539132527, 0.9047948547771999, 1.9930008734975542, 4.436124290738787, 9.603736690112523, 17.475509813853673, 19.214638710021973, 30.31731809888567, 25.32130970273699, 18.912518875939504, 18.755814416067942, 46.678776332310264, 67.96622249058315, 50.80075693130493, 54.89531993865967, 81.13019616263253, 89.05643708365304, 74.66439710344586, 61.43155288696289, 65.82009070260185, 58.34867886134556, 46.305974211011616, 51.11735160010201, 50.8015525000436, 56.112599168504985, 70.33510657719204, 67.51653507777623, 78.10892486572266, 73.98898356301444, 53.2821809904916, 34.45823948723929, 49.399204526628765, 51.373469148363384, 40.072078227996826, 28.09692222731454, 18.274266038622173, 31.552502836499894, 47.65392473765782, 23.22616032191685, 18.482176985059464, 3.842488876410893, 6.313690832683018, 13.52818695136479, 14.877201420920235, 3.3354540722710744, 0.42600059668932644, 0.09610254996057067, 0.3247187685753618, 0.511620289513043, 0.31873476824590136, 0.5960950766290937, 0.18216949914182934, 0.07435185887983867, 0.9191243201494217, 2.1430606842041016, 3.6098462513514926, 0.7099936391626085, 1.7433201798370905, 2.225205544914518, 0.69536811539105, 0.4335479959845543, 0.041615539962159734, 0.11235244585467236, 0.05362360132858157, 0.31636011281183785, 0.41000470359410557, 0.5305965798241752, 0.35457922198942726, 0.21041381784847804, 2.22336231810706, 2.318069956132344, 12.709521532058716, 18.852371794836863, 27.00154914174761, 27.688128437314713, 46.522608620779856, 39.01591730117798, 10.483010377202715, 14.11507957322257, 16.430929797036306, 26.49536940029689, 28.16327578680856, 27.709487199783325, 28.89048641068595, 28.818702833993093, 33.05633619853428, 30.286607061113628, 36.68170472553798, 56.131901264190674, 66.95842797415597, 68.2246537889753, 73.98534965515137, 75.97558471134731, 80.6873596736363, 83.39788668496269, 85.10004942757743, 80.99266351972307, 73.47883987426758, 63.435406412397114, 48.69417428970337, 57.41921486173357, 46.416464465005056, 26.079766375677927, 17.958157743726456, 8.70096332686288, 4.86473434312003, 5.194833270141056, 5.408009214060647, 0.1434759854206017, 0.07975713669189385, 0.08330147114715405, 0.2438225480062621, 0.1356250774115324, 0.22849712893366814, 0.20060112939349242, 0.044627237998481305, 0.25463052519730156, 0.03293516021221876, 0.1386502715093749, 0.11679380360458579, 0.010769013165762382, 0.1197117484573807, 0.17342603259852954, 0.11950706158365522, 0.02784807630814612, 0.06578178517520428, 0.06816309025245053, 0.044143333964582, 0.01662075429755662, 0.004510988589442734, 0.039421761608017344, 0.060387207860393186, 0.12619534055037157, 0.05847239560846772, 0.054898809508553574, 0.0509612674026617, 0.04224959022498556, 0.08930480293929577, 0.16358822477715357, 0.1348985835377659, 0.09623798555029289, 0.06467362892414842, 0.07183966439749513, 0.09272534546575376, 0.05070493383599179, 0.0760366070483412, 0.04643829885338034, 0.033488234105919085, 0.08414197247475386, 0.09191890659609012, 0.045155840526734076, 0.09931158633636576, 0.1097162151709199, 0.06843043304979801, 0.08141817006149463, 0.29405528253742624, 0.06572517499859844, 0.039396652419652255, 0.06534432686333146, 0.12632370580519947, 0.041900120941655974, 0.03390133979597262, 0.15803449707371847, 0.2258696106395551, 0.25143557520849363, 0.14588630465524538, 0.11004499931420599, 0.10198027135006019, 0.6245457785470145, 0.16986803923334393, 0.09449999273887702, 0.14944085106253624, 0.09520619163023573, 0.32542941187109264, 0.31413451795067104, 0.49163178780249184, 3.004285556929452, 4.50552420105253, 12.15994507925851, 11.906790069171361, 16.581936734063284, 41.60154002053397, 45.0826917375837, 36.61760064533779, 27.76497551373073, 40.288333960941856, 54.08620221274239, 47.672445161002024, 74.80210345132011, 55.818520137241904, 70.39449283054897, 83.10167803083147, 83.64153221675328, 80.29220867156982, 68.29175254276821, 66.8198253086635, 61.98702662331717, 54.94758081436157, 53.72623688834054, 57.35895660945347, 59.78888756888253, 69.50679097856793, 78.61345441000802, 84.96720681871686, 78.53546782902309, 47.75229038511004, 42.56427894319807, 61.91816997528076, 61.7171516418457, 50.389295033046174, 35.089688301086426, 29.59842620577131, 44.07387236186436, 38.50806999206543, 26.894666739872523, 15.711697442190987, 7.968728286879403, 16.20134047099522, 21.142784663609095, 18.428866931370326, 4.280992729323251, 0.42260127195290154, 0.07003726504210915, 0.43526615521737505, 0.6291366922003883, 0.19458401655512197, 1.5193071088620593, 0.3064181905772005, 0.13437156538878167, 0.7635582249079431, 0.6556059632982526, 1.747185549565724, 1.3061184627669198, 3.5325034643922533, 2.3095410423619405, 1.6494006195238657, 0.7962548189929554, 0.0909944229892322, 0.29295939419950756, 0.24541322407977922, 0.4570922926068306, 0.3604287638195923, 0.8479902371764183, 0.7604112880570548, 0.14605015729154858, 2.264649599790573, 14.918968779700142, 23.404431990214757, 25.49788079942976, 32.16673748833792, 36.953219481876914, 58.16507618767874, 48.038021155766074, 12.274155225072588, 17.449930020741053, 20.36279899733407, 33.62376083646502, 32.73785161972046, 41.653102602277485, 46.291737352098735, 47.8243327822004, 50.89595420019967, 45.3764511517116, 40.30839341027396, 60.35881355830601, 71.12511675698417, 73.77802235739571, 79.4762191772461, 75.41626167297363, 83.28877912248883, 89.44703006744385, 88.3836360658918, 83.24556827545166, 75.67836856842041, 62.846539633614675, 55.26732996531895, 72.57470553261894, 56.3925837789263, 38.82055827549526, 31.88254574366978, 20.38006179673331, 10.502755420548574, 8.98046156338283, 10.07936259678432, 1.9703996862683977, 0.15770664252340794, 0.132630960217544, 0.2888547187404973, 0.4131856214787279, 0.09750084778560059, 0.24025684648326465, 0.10540450510701962, 0.04530174930446914, 0.013303894466454429, 0.047767141833901405, 0.40355237839477404, 0.36727865625705036, 0.15482493144060883, 0.18203680483358248, 0.15356719893004211, 0.012145188204678041, 0.01803869571137641, 0.01691777621661978, 0.049504948048187156, 0.04852574059207525, 0.06336455166872058, 0.016615091922826, 0.050778107052402835, 0.17832027854663984, 0.022917574537651877, 0.10248426680586167, 0.1186695865222386, 0.022307122026437094, 0.057242252331759245, 0.05014671325417502, 0.15809004195034504, 0.08985035866498947, 0.06012175139039755, 0.21878182382455894, 0.09568297104643923, 0.14257266532097543, 0.14384042657911777, 0.1673999223858118, 0.10181687333221946, 0.15607819919075283, 0.1858907751739025, 0.16351784712501935, 0.22265313751995564, 0.1644128348146166, 0.08342993818223476, 0.2774496307330472, 0.41128870898059433, 0.35337406237210545, 0.17608943182442868, 0.2606654427945614, 0.1450627124203103, 0.20412854797073773, 0.11866632955414907, 0.223491331828492, 0.29934508726000786, 0.6333349240677697, 0.27911926114133423, 0.1701713308159794, 0.2551366580384118, 0.6257670872977802, 0.2821776898843901, 0.18872473096208914, 0.47903785215956823, 0.46553641664130346, 0.30529668075697763, 0.5906994747264045, 1.3562605721609933, 1.9847342542239597, 1.404284349509648, 9.821760739598956, 12.457433070455279, 13.263489246368408, 39.09219809940883, 50.07353414808001, 57.33425228936331, 67.63211836133684, 69.079254422869, 60.708495548793245, 67.55256843566895, 102.37488310677665, 76.31929819924491, 83.30536447252545, 87.05279200417655, 92.70032255990165, 80.93829386574882, 67.07626247406006, 73.24849319458008, 68.27805764334542, 59.59936850411551, 60.70400701250349, 63.21163967677525, 65.40261513846261, 77.78663267408098, 78.78320584978376, 87.49419021606445, 83.0274087360927, 56.769287313733784, 44.82616424560547, 59.030033111572266, 61.72002124786377, 51.86940029689244, 40.138739245278494, 27.98390977723258, 49.734924112047466, 46.27228239604405, 30.28445659364973, 22.839371476854595, 8.346782377788, 12.992045709065028, 30.706799370901926, 39.743536131722585, 11.283871037619454, 0.5908277992691312, 0.6406016541378838, 0.5340963548847607, 1.3284368366003036, 0.4003365838101932, 2.172134118420737, 0.4175231158733368, 0.2215308677405119, 1.449560005749975, 6.782505767686026, 7.2965977702822, 2.61494802577155, 4.621500492095947, 6.81740048953465, 1.9074021066938127, 0.7830981335469654, 0.15896593566451753, 0.30108156693833216, 0.20389272991035665, 1.5280064706291472, 0.6929906915341104, 1.0572428916181837, 0.9038275895374162, 0.29401647033435957, 4.282820539815085, 25.75948395047869, 27.64137748309544, 32.593989167894634, 31.752781186785015, 41.64584173474993, 69.27120535714286, 51.256794997623985, 15.036624363490514, 20.5860150882176, 29.88820777620588, 48.277494294302805, 43.50969253267561, 44.03980881827218, 45.075465611049104, 54.99775723048619, 51.72596515927996, 53.28716632298061, 52.692772252219065, 69.63934871128627, 77.4124652317592, 80.0797119140625, 84.43609346662248, 84.13147054399762, 82.034469468253, 86.17328207833427, 83.69394247872489, 85.00097506386894, 80.92799663543701, 74.65171664101737, 60.2589818409511, 77.06322792598179, 70.93949563162667, 56.94768926075527, 52.41036966868809, 44.21799884523664, 24.828602518354142, 15.281742913382393, 13.19981074333191, 2.2800565787724087, 0.2613747833030564, 0.28606775828770226, 0.31289817286389215, 0.6640932421599115, 0.5584694956030164, 0.450639967407499, 0.2306632569858006, 0.36551370524934357, 0.11427292387400355, 0.25852132641843384, 0.7055295301335198, 0.34184070410473005, 0.17571158281394414, 0.3777027997587408, 0.18213444602276596, 0.10218741452055317, 0.15384484188897268, 0.1555364839732647, 0.16435243162725652, 0.13175740066383565, 0.12084377557039261, 0.15870548678295954, 0.14217063332242624, 0.28040190945778576, 0.15635361655482224, 0.18903642280825547, 0.17060277052223682, 0.1591367364994117, 0.2763617219669478, 0.17461041547358036, 0.1981456061559064, 0.1765826182173831, 0.1709481177053281], [0.002774624474113807, 0.12579577841929027, 0.04512696886169059, 0.03362619384591069, 0.04692697298846074, 0.04462518882272499, 0.058565741670983176, 0.04177711611347539, 0.017485440309558595, 0.1224193067422935, 0.10645056183316878, 0.031939155621720214, 0.23897457814642362, 0.38362760469317436, 0.08707624966544764, 0.037050346178667884, 0.03481134007285748, 0.32993583434394425, 0.026344028800459843, 0.07299878541380167, 0.055050211027264595, 0.049626487240727456, 0.07809378951787949, 0.06331146987421171, 0.3057704067655972, 0.08547803506787334, 0.27049144410661285, 0.2011393705116851, 0.058260523048894744, 0.1701668660555567, 0.25033154445035116, 0.4435635528394154, 0.18850925538156713, 0.2439655289053917, 0.6153516833271299, 0.699450399194445, 0.7424953037074634, 0.99422316466059, 4.061061833586011, 7.208566699709211, 13.411088960511343, 18.286286422184535, 19.530635833740234, 19.566634450639995, 13.490973268236433, 12.472010391099111, 41.264517647879465, 59.30640465872628, 52.98089320319039, 47.383469581604004, 69.52542604718889, 90.65780925750732, 84.50369943891252, 73.4252484185355, 73.18889154706682, 74.04447187696184, 73.9047019141061, 75.76497786385673, 74.29282133919853, 77.62747723715646, 83.6711732319423, 57.21481622968401, 42.76142365591866, 42.919047015053884, 58.3097620010376, 44.6506701196943, 37.14675807952881, 34.86158241544451, 25.761601413999283, 19.572886092322214, 12.538122500692095, 28.889859335763113, 38.439480849674766, 40.42681850705828, 24.418459040778025, 2.2058116027287076, 21.244466338838848, 24.897136075156077, 8.804314306804113, 2.524206506354468, 1.0750202919755663, 0.5972930437752179, 0.13653024312640938, 0.7394302796040262, 0.3787314588470118, 0.1467086755271469, 0.3903462141752243, 0.5202407240867615, 0.8482583942157882, 3.9946240271840776, 0.20801283525569098, 1.6144599744251795, 2.5137826885495866, 2.8527021365506307, 1.3539933966738837, 0.8841198927589825, 0.13702019969267504, 0.2656190741275038, 0.24583386150853975, 0.15409125866634504, 0.2099216492580516, 0.8616077293242727, 1.7560069390705653, 2.8453513767038072, 8.924805624144417, 4.709346566881452, 28.794629062925065, 27.519684995923722, 15.817280530929565, 15.27446814945766, 8.914233071463448, 19.24289529664176, 18.059505905423844, 18.686898708343506, 20.21697541645595, 18.02404056276594, 16.62512673650469, 19.3484662260328, 25.072645834514073, 25.8404096194676, 33.83529526846749, 44.38215698514666, 39.57069621767317, 44.649812017168315, 60.453684261866975, 73.80336243765694, 73.25380856650216, 72.94207068852016, 71.30670097896031, 69.52605833326066, 67.96488148825509, 62.75647013528006, 57.1394282749721, 66.95380047389439, 49.44460753032139, 35.25206075395857, 23.52111656325204, 12.838992527553014, 6.773343699319022, 4.008233376911708, 0.5696952875171388, 0.7570790297218731, 0.08202899407063212, 0.04567128965365035, 0.04890397297484534, 0.2717916800507477, 0.14016453096909182, 0.02950306562706828, 0.1391496461416994, 0.0872828025104744, 0.16322429930525167, 0.030488210264593363, 0.06871240506214754, 0.0367052941583097, 0.11832326224872045, 0.07906439314995493, 0.05259533239794629, 0.09136465883680753, 0.033617016659783464, 0.03342329491195934, 0.0959694010338613, 0.0645513976258891, 0.023091505115319575, 0.03862005212743368, 0.09422594601554529, 0.1383178707744394, 0.10517213400453329, 0.14614479935594968, 0.05778875122112887, 0.032921436841466596, 0.03694348709125604, 0.046279925387352705, 0.06790521980396338, 0.11903110998017447, 0.027895804461357847, 0.1564076008009059, 0.05018112176497068, 0.04548918442534549, 0.1045444416148322, 0.02195388008840382, 0.07579156091170651, 0.044386001835976324, 0.052464724584881745, 0.15841290248291834, 0.0741899875657899, 0.08738022656845194, 0.039395570156297514, 0.0956911202520132, 0.09748872236481734, 0.2765333099024636, 0.14185800509793417, 0.09746307374111243, 0.056040566813732894, 0.009883224714680441, 0.03653688855203135, 0.04796468373388052, 0.05772254655935934, 0.04281427385285497, 0.15489178071064608, 0.06192691238330943, 0.15396886451968125, 0.10198921444160597, 0.18675852646785124, 0.3418697182621275, 0.07261744873332125, 0.07142693190170185, 0.2579726630023548, 0.24121206094111713, 0.28317828476428986, 0.15667358652821609, 0.763592423072883, 2.4182968522821153, 2.584960686308997, 3.4033540402139937, 5.640178493091038, 13.22572578702654, 30.752240589686803, 30.572893687656947, 21.251539605004446, 13.901281765529088, 28.510338306427002, 45.14432920728411, 45.514963490622385, 71.46834387098039, 60.9756190436227, 67.63124288831438, 72.27891377040318, 88.06208038330078, 94.01590837751115, 84.17944090706962, 77.61642265319824, 83.98466205596924, 85.56466157095772, 84.7055515561785, 86.90431594848633, 88.15093394688198, 88.19112232753209, 64.92531558445522, 53.878600461142405, 59.26160267421177, 70.34654331207275, 61.84016949789864, 45.90208237511771, 41.40442310060774, 38.033129351479666, 33.3756719316755, 26.47521788733346, 35.59304707390921, 39.42885569163731, 29.62394346509661, 31.398350102560862, 7.572000912257603, 29.205189432416642, 37.3046315738133, 15.500545161111013, 0.7445433938077518, 1.8400132656097412, 0.4020104482769966, 0.20745383096592768, 0.17005146081958497, 0.8347544074058533, 0.1035371156675475, 0.5317018862281526, 1.119163066148758, 1.7860977415527617, 5.029373645782471, 1.6077076281820024, 1.0057358954633986, 1.789842169199671, 1.5565214433840342, 0.772153092282159, 0.1729036827704736, 0.05958228212382112, 0.4541968208338533, 1.033734421644892, 1.678584030696324, 1.0897867338997977, 0.8322691779051508, 2.0472812865461623, 6.6338851026126315, 14.908188649586268, 18.15928030014038, 43.55754477637154, 31.763224329267228, 25.848030056272233, 29.819646426609584, 25.46689530781337, 27.560917343412125, 29.80122675214495, 30.614468233925955, 30.884805270603724, 26.990862812314713, 26.147893462862285, 40.29381608963013, 38.10351112910679, 29.992632252829416, 48.07553447995867, 63.70743533543178, 52.27663769040789, 51.60360043389456, 65.25614711216518, 74.83948475973946, 72.92752810886928, 75.3624131338937, 72.39422607421875, 71.70083754403251, 74.49657031467983, 74.15757465362549, 72.76120907919747, 82.77221529824394, 59.85555553436279, 50.29446601867676, 40.05858482633318, 22.874781233923777, 13.180785707065038, 12.64962979725429, 5.439307374613626, 1.3447754170213426, 0.04067908699757286, 0.1840350090392998, 0.027505024269755398, 0.299651350826025, 0.2811765250350748, 0.18158327202711785, 0.4151776374450752, 0.10664743198347942, 0.04263862149257745, 0.03175862459465861, 0.05731094043169703, 0.0886251822646175, 0.23675468297941343, 0.13802044173436506, 0.1460088887917144, 0.09330285340547562, 0.06631738000682422, 0.03924394132835524, 0.03325360008914556, 0.14784078406436102, 0.08626858943275043, 0.04042595272351589, 0.06314343067684344, 0.025661127408966422, 0.12716533350093023, 0.23246873010482105, 0.07322615571320057, 0.04023561008008463, 0.07285735157451459, 0.09564859646239451, 0.022313863271847367, 0.055072042891489606, 0.09097010429416384, 0.10912016965448856, 0.10053305115018572, 0.3161604606679508, 0.109100173227489, 0.12264402396976948, 0.16409637965261936, 0.1114168885563101, 0.12188098419989858, 0.27583165041037966, 0.2148121361221586, 0.1917536977146353, 0.24979979012693676, 0.15119600402457373, 0.19137457305831568, 0.43243215871708734, 0.2006718191717352, 0.15638352637844427, 0.1329064318644149, 0.3608120275395257, 0.17045083296086105, 0.21742170037967817, 0.10391014707939965, 0.1945114540202277, 0.2122571532215391, 0.17140027987105505, 0.2750863475458962, 0.12173226289451122, 0.26431672115411076, 0.590659251170499, 0.1344916932284832, 0.2193569636770657, 0.32468416328941074, 0.36030985734292437, 0.27193930212940487, 0.5504607739193099, 1.2280873698847634, 1.5880014513220106, 0.9247374875204903, 4.8265096970966885, 5.584557294845581, 9.447165983063833, 32.34046677180699, 40.242680822099956, 38.9862311226981, 52.01003878457205, 62.725731304713655, 51.67072698048183, 65.03580583844865, 99.23490183694022, 77.73315238952637, 73.10140677860805, 78.01952239445278, 101.75071253095354, 93.31690570286342, 82.59008911677769, 80.28152234213692, 85.04555470602853, 83.2300807407924, 84.71625873020717, 83.47055094582694, 87.33090060097831, 95.50491428375244, 69.68514428819928, 57.81768362862723, 58.40787056514195, 66.86728845323834, 52.54069702965872, 39.360207489558626, 41.50470297677176, 32.54649475642613, 27.363143818719045, 18.583917719977244, 37.9728467805045, 51.70266090120588, 39.743518761226106, 43.16455118996756, 4.357994403157916, 35.46018362045288, 56.47130339486258, 26.05260239328657, 5.918944563184466, 1.861530750989914, 2.8248350833143507, 0.5003637735332761, 0.46763005001204355, 1.0599356442689896, 0.10724376248461859, 0.5943988476480756, 1.9476534553936549, 2.9926525354385376, 7.35126793384552, 2.8705939650535583, 7.666829926627023, 4.038498427186694, 5.775773022856031, 1.7160088739224841, 1.968881504876273, 0.2706693559885025, 0.38621917420199936, 0.7732749549405915, 1.4983192064932414, 0.9286267416817802, 1.4695295627628053, 3.9712203230176653, 15.085060255868093, 27.95131230354309, 23.914408922195435, 57.66992323739188, 44.55505248478481, 28.80532581465585, 20.14979328427996, 16.152086428233556, 27.289901120322092, 28.389844383512223, 31.72379677636283, 31.94104610170637, 33.64041914258684, 29.491549015045166, 39.5210165977478, 38.86749683107649, 43.14926862716675, 48.74960701806204, 57.04446724482945, 50.71188947132656, 52.43752670288086, 66.58603927067348, 79.97374493735177, 76.08538014548165, 77.96750123160226, 79.46774237496513, 79.62957981654576, 74.16873346056256, 74.8946395601545, 72.65737519945417, 88.53418963296073, 76.45066779000419, 66.56450680324009, 60.22075285230364, 47.17594426018851, 30.11989893232073, 21.92308647292001, 9.571717653955732, 2.103822035448892, 0.1217978908015149, 0.1934053740863289, 0.1505115521805627, 0.459724628499576, 0.44596510540161816, 0.3185003751090595, 0.45702118213687626, 0.20905289373227529, 0.14983673553381646, 0.10811309476516076, 0.11418314012033598, 0.2393257607306753, 0.3440155174051012, 0.2829867478992258, 0.10986882448196411, 0.2179038266518286, 0.23638569563627243, 0.1296866610646248, 0.1593041718006134, 0.1914575036082949, 0.14793796384973185, 0.17721497214266232, 0.13837793469429016, 0.13957436835127218, 0.1481744468744312, 0.2523037743355547, 0.1224147876990693, 0.07160155967410121, 0.11400625961167471, 0.23314246109553746, 0.11869611724146775, 0.18914630476917538, 0.1636972924960511, 0.168586720845529], [0.14502608510000364, 0.14108872280589171, 0.06628662201442889, 0.02665102688063468, 0.13739471031086786, 0.036326814110257795, 0.05361757593761597, 0.04247647876452122, 0.04507417205188956, 0.035890553412692885, 0.20652799707438263, 0.03519501430647714, 0.03397757320531777, 0.07512416065271411, 0.19764807713883265, 0.037435614969581366, 0.04817783872463873, 0.07731664979032107, 0.20205023592071875, 0.07131482434592076, 0.06727249268442392, 0.00435134583884584, 0.024860505280750136, 0.04641346447169781, 0.04229020733120186, 0.1353829082633768, 0.04484639802415456, 0.20030085050633975, 0.46599320641585756, 0.09978862359587636, 0.22036768229944365, 0.47268844715186525, 0.29676293581724167, 0.16431736493749277, 0.2899875193834305, 0.4839605965784618, 0.4396773385150092, 0.4959307142666408, 1.0565508944647652, 1.6130989960261752, 7.64493875844138, 6.390887056078229, 10.989444596426827, 10.657685484204974, 15.218648059027535, 9.12834962776729, 20.207223619733536, 37.92614098957607, 51.506113733564106, 55.222802434648784, 48.88600015640259, 57.261372634342735, 72.52167688097272, 80.61794716971261, 82.07353224073137, 84.68778501238141, 78.46741717202323, 77.37398610796247, 75.55498245784214, 62.45917061397007, 56.94715772356306, 51.36095196860177, 52.220801966530935, 43.156074387686594, 36.50662054334368, 35.401551246643066, 33.839238371167866, 21.866177252360753, 18.92588894707816, 13.131388357707433, 11.319774985313416, 15.4959055015019, 26.346368755613053, 52.856909547533306, 55.34694937297276, 28.76251448903765, 29.312170846121653, 41.68581472124372, 14.270274536950247, 0.03790546654324446, 1.0936372301408221, 1.866219482251576, 0.66376971666302, 0.46059147055659977, 0.6459403676646096, 0.5167253698621477, 0.04150650617001312, 0.2670892152403082, 0.3799850658646652, 0.5234888440796307, 0.9071866092937333, 0.926530448453767, 0.8944792225956917, 0.1534602753818035, 0.24010699880974634, 0.301870947437627, 0.7871942051819393, 0.5856587737798691, 0.4100599092032228, 0.2863007400717054, 1.1618949217455727, 1.3553839049168994, 0.5520871409348079, 3.1961863338947296, 6.684267793382917, 8.39020688193185, 13.536298973219735, 46.31655284336635, 27.3446946144104, 11.666265147072927, 15.792534521647863, 14.064680814743042, 13.480046357427325, 10.996011512620107, 11.912194030625479, 14.414777960096087, 16.0995545727866, 24.054237944739207, 28.887015785489762, 28.682401759283884, 23.074046884264263, 31.77771827152797, 44.403112752096995, 54.01327739443098, 54.90014893668038, 55.91995688847133, 66.77680901118687, 72.12089088984898, 67.13730239868164, 63.47233608790806, 64.7027369907924, 64.14825684683663, 61.865502629961284, 47.31079837254116, 37.461105006081716, 30.815177372523717, 13.043051566396441, 5.643582241875785, 3.1507622684751238, 2.8377166092395782, 0.6053886179413114, 0.19282426312565804, 0.05611577224252479, 0.04268857863332544, 0.19494053242462023, 0.17080407829156943, 0.22489585860499314, 0.07973226838346038, 0.16921106805758818, 0.05700834774013076, 0.08314618840813637, 0.1537535653582641, 0.05678607663139701, 0.10618715453892946, 0.08195704900260482, 0.11054915083306176, 0.09468157549521752, 0.05550285156017967, 0.04211782890238932, 0.06734247000089713, 0.021652971860021353, 0.012973648928371924, 0.06689377514911549, 0.011682433259141232, 0.09826456609049014, 0.08836570368813616, 0.055147899713899405, 0.09886261328522648, 0.15032367940459931, 0.07166796789637633, 0.09673347217696053, 0.08952413938407387, 0.047589060318257125, 0.05864988001329558, 0.06322414920266185, 0.023534086366583194, 0.03495700118531074, 0.11871869888688837, 0.03043398853125317, 0.02074041180977864, 0.06783999223262072, 0.02948069093482835, 0.07327149542314665, 0.11684579295771462, 0.08536742028913327, 0.06795965188315936, 0.011089839789617275, 0.1421578090105738, 0.006743046496662178, 0.11104095301457814, 0.09559544002903358, 0.025996796986354247, 0.06646420819950954, 0.05278096940102322, 0.17463252214448793, 0.014598702978608864, 0.06050144601613283, 0.048301949564899714, 0.04853502295113035, 0.07586404880774872, 0.1035320470109582, 0.03533302154392004, 0.09140552700098072, 0.1041760513825076, 0.18863527290523052, 0.012236589416196304, 0.25761135667562485, 0.1914890826280628, 0.28341769906026976, 0.17854950124663965, 0.07835469301789999, 0.6372527852654457, 1.9199425194944655, 2.1771726480552127, 0.6484942649091993, 3.357678536857877, 12.916808009147644, 23.166760172162736, 18.526895591190883, 13.32319164276123, 10.709801316261292, 19.759968076433452, 40.28006213051932, 40.53675985336304, 68.6362372807094, 72.87466621398926, 65.11725262233189, 63.83621324811663, 77.34757600511823, 93.09998294285366, 87.21468503134591, 84.49723066602434, 79.67208889552525, 80.56352193014962, 80.4672407422747, 76.320451600211, 63.66207749502999, 68.68077523367745, 65.4356746673584, 58.62208352770124, 44.97353901181902, 49.53481599262783, 37.894561426980154, 26.189497538975306, 25.420463970729283, 22.15027345929827, 21.02785972186497, 24.18024526323591, 29.735983167375835, 58.84827518463135, 68.45965576171875, 26.543258122035436, 24.41725352832249, 44.774184771946494, 19.593457971300396, 3.9268981984683444, 1.1407035674367632, 1.4329016996281487, 0.9566964868988309, 0.4285502870168005, 1.0375639647245407, 0.4201437809637615, 0.5203962443130357, 0.5551794692873955, 0.32936638061489376, 1.7568879489387785, 0.9828915212835584, 2.351815402507782, 1.5194693058729172, 2.8289577535220554, 0.5942702516913414, 0.18268293301974023, 0.42404139467648094, 0.5954131217939513, 0.514528707734176, 0.4586986835513796, 1.5664643155676978, 4.192386695316859, 7.070343579564776, 7.679938571793692, 10.597759876932416, 18.975210734776088, 27.080247913088115, 57.233083043779644, 23.79418076787676, 13.372527326856341, 13.78109095777784, 14.126414690698896, 17.772998673575266, 22.367272649492534, 21.297142369406565, 19.280122007642472, 22.540614570890153, 29.529746736798966, 47.77220739637102, 45.71581506729126, 28.650764874049596, 41.736116204942974, 53.0222349848066, 63.93042387281145, 64.3751780646188, 63.17200715201241, 74.10732528141567, 75.52470220838273, 74.23245538984025, 71.49749156406948, 76.26851381574357, 72.30316993168422, 71.1936537878854, 58.29854760851179, 53.9370174407959, 44.5189322744097, 23.349403994424, 17.164237465177262, 7.744965893881662, 0.7536811434796878, 0.6970523478729385, 0.17737820052674838, 0.08412851033998386, 0.08774759221289839, 0.07473135673041854, 0.03737896068819931, 0.10766551949615989, 0.12050153607768671, 0.0852828680404595, 0.06596868764609098, 0.08535497595689126, 0.2494061312505177, 0.09257648166801248, 0.1409942571605955, 0.13890633705471242, 0.27149502454059465, 0.10929750478161232, 0.059984110561864715, 0.0758242459435548, 0.04381304347355451, 0.007642553653568029, 0.0600349260494113, 0.009120514034293592, 0.015008237878126758, 0.03821988949286086, 0.04384287526564939, 0.042028360667505434, 0.1347353280122791, 0.14439776167273521, 0.01926040819047817, 0.1275197323411703, 0.035911167306559424, 0.043673957365431955, 0.07418475606079612, 0.09817980349596057, 0.023642112534227114, 0.27103856046284946, 0.17153578331427916, 0.1481854934245348, 0.11289082267986876, 0.24363375242267335, 0.23216344362923078, 0.1451094906244959, 0.17019361390599183, 0.22741360350378922, 0.13548733480274677, 0.3390352874994278, 0.13022689707577229, 0.07445171209318296, 0.19482048600912094, 0.2884950137564114, 0.2614513491945607, 0.07296915378953729, 0.20774849158312592, 0.3079388146953923, 0.14700402825006417, 0.11457046147968088, 0.20919970156891005, 0.09169741919530289, 0.1823374094175441, 0.13333679948534283, 0.13848632387816906, 0.11419755220413208, 0.28378975338169504, 0.3640921472438744, 0.22021351914320672, 0.28721391249980244, 0.5419459193944931, 0.3909195762659822, 0.3598646569464888, 0.7134544391717229, 0.5057494416832924, 1.5663201404469353, 1.8861149975231715, 3.2884894609451294, 2.9442361848694936, 11.218291333743505, 21.349158321108135, 20.734346968787058, 21.62300419807434, 44.8020852633885, 57.16869408743722, 45.34684487751552, 59.07051331656319, 91.31626224517822, 81.87679399762834, 65.72572026933942, 66.19919831412179, 89.00407545907157, 94.79239041464669, 86.96095766339982, 90.11080537523542, 79.11822019304547, 83.23444420950753, 87.84731156485421, 81.89964662279401, 74.32897281646729, 70.16072068895612, 67.88997295924595, 62.222848483494346, 45.15725980486189, 47.65013102122715, 46.590120792388916, 31.21740858895438, 30.198191234043666, 23.457436323165894, 17.89829727581569, 15.575451953070504, 27.923185995646886, 67.99398749215263, 80.596588407244, 45.10086127689907, 37.10096597671509, 60.93466636112758, 36.12065505981445, 13.51220783165523, 1.3268010786601474, 3.008785601173128, 1.1459708447967256, 0.8089176395109722, 1.8009200947625297, 1.059859756912504, 0.5398920210344451, 0.6460406279989651, 0.30397473169224604, 2.1250244634492055, 1.8729010437216078, 3.418019298996244, 2.26539392556463, 3.5350415110588074, 0.7094419087682451, 0.9791350428547178, 1.2644164604800088, 0.506216110927718, 0.5200288040297372, 0.40234732734305517, 2.3656318954059055, 5.35759916475841, 8.019469244139534, 20.98038615499224, 25.159357615879603, 20.501227957861765, 20.937540088381084, 70.6627836227417, 47.058394636426655, 19.91043826511928, 21.40302423068455, 19.31748594556536, 18.907167025974818, 25.711367675236293, 27.302904673985072, 30.85509477342878, 33.53770392281668, 38.59550959723336, 45.102831091199604, 44.71958235331944, 37.64303663798741, 49.80589648655483, 52.80635445458548, 66.34741033826555, 66.32806655338833, 66.62087753840855, 77.64618873596191, 80.87045165470668, 76.98875713348389, 70.56907326834542, 76.87680775778634, 79.33808898925781, 81.75126089368547, 69.89020647321428, 68.18197795322963, 67.29918847765241, 50.70496211733137, 32.861321108681814, 17.552157129560197, 4.530702301434108, 0.7276771845562118, 0.23255455121397972, 0.14449675993195601, 0.28105126747063225, 0.3669696514095579, 0.2116638964840344, 0.41223640527044025, 0.20858992928905146, 0.171898324574743, 0.13986354640551976, 0.1786298126514469, 0.2966158837080002, 0.10674711556306907, 0.12828967959753104, 0.5190774436507906, 0.3159829287656716, 0.21807358254279408, 0.14030904535736355, 0.19227629181529793, 0.13066831124680384, 0.09344947125230517, 0.15704591226364883, 0.13359674625098705, 0.05155309921662722, 0.18838785189603055, 0.15115250992987836, 0.12789387655045303, 0.3063941161547388, 0.1693550260471446, 0.15574053302407265, 0.29074579583747046, 0.14228184521198273, 0.10938736317413193, 0.16534797820661748, 0.1474963461181947, 0.183815136551857], [0.0527159623535616, 0.057465829620403905, 0.07045479478048426, 0.08145289069839887, 0.05103453222130026, 0.04615870510627117, 0.12152153705911976, 0.04350939905270934, 0.07615289437983717, 0.06053221079387835, 0.08011617671166148, 0.05267164044614349, 0.09419016686401196, 0.08188300047601972, 0.06001257510589702, 0.08389689919671842, 0.2131372538528272, 0.04029086318665317, 0.07480647055698292, 0.2653199758912836, 0.19330819430095808, 0.10554600679980856, 0.14343960237290176, 0.07714217808097601, 0.1329812199941703, 0.04270917556381651, 0.2750216967293194, 0.05768162411238466, 0.286877657685961, 0.19631196026291164, 0.15031095008764947, 0.21718752437404223, 0.6831164870943341, 0.3170702675623553, 0.18548951670527458, 0.17425456456840038, 0.5642839978848184, 0.226425507238933, 0.6851557833807809, 1.3494561144283839, 0.9533236793109349, 3.992596455982753, 4.409975613866534, 8.14406520979745, 6.79017744745527, 9.194819569587708, 1.9915886521339417, 14.772974967956543, 31.346995966775076, 43.96473353249686, 53.051643235342844, 50.413467815944124, 58.18792186464582, 68.00582722255162, 70.19659423828125, 64.59303883143834, 65.05228696550641, 62.418662616184776, 69.38839367457798, 72.0379363468715, 59.66412571498326, 46.21700252805437, 45.044646876198904, 43.35081154959542, 31.143319947378977, 21.31624296733311, 16.855442149298533, 17.793650456837245, 20.015885863985332, 23.33632574762617, 28.3387508051736, 20.409470047269547, 42.14442362104143, 55.123092310769216, 68.99204063415527, 55.32425308227539, 53.28500543321882, 56.949210916246685, 33.887205260140554, 12.070414066314697, 4.3200563703264505, 1.375186053769929, 2.4847885072231293, 0.6189594811626843, 0.1568062129829611, 0.3282256546829428, 0.3844218435032027, 0.7962857601898057, 1.1566678136587143, 2.0140269909586226, 1.157150062067168, 1.404684630887849, 0.03127991135365196, 0.7833460431013788, 0.08077797227139984, 0.24600333241479738, 1.3582957429545266, 1.05096150296075, 2.390346420662744, 5.555185956614358, 6.208790838718414, 2.917554885149002, 2.000411778688431, 3.1889035361153737, 9.214843409402029, 19.88497485433306, 36.21019996915545, 53.891541481018066, 44.11920240947178, 46.85128273282732, 39.030776023864746, 32.67063822065081, 33.760181767599924, 24.709904704775127, 16.866684334618704, 10.935776710510254, 7.065933644771576, 10.8224515914917, 13.774049827030726, 15.557179927825928, 25.2183495589665, 26.95446641104562, 24.779944283621653, 33.36179985318865, 43.68132693426949, 56.96137721197945, 58.17215640204293, 53.072609424591064, 57.49488421848842, 56.896088463919504, 58.653531074523926, 58.07936320986067, 56.18201167242867, 56.6090965952192, 40.48125416891915, 14.508131350789752, 4.673965905393873, 1.2898133205515998, 0.35453351587057114, 0.3033370444817202, 0.08384794289512293, 0.11833379311220986, 0.0933200339121478, 0.1609381248376199, 0.1672979521432093, 0.0848181394061872, 0.08424755930900574, 0.0273366678572659, 0.14432222715445928, 0.052371585475546975, 0.11664994060993195, 0.013882310794932502, 0.0849065932312182, 0.12005199305713177, 0.07243131979235581, 0.10375014173665217, 0.09024153410324029, 0.08178951870650053, 0.039549899553614, 0.025469336093270352, 0.1357847774135215, 0.0568748900799879, 0.08980674921934094, 0.041739253859434805, 0.05023157084360719, 0.03489725956959384, 0.08111140437956367, 0.018767632311210036, 0.11594249999948911, 0.08466168280158724, 0.15352274131562027, 0.07511447117264781, 0.05508058564737439, 0.058238660650593896, 0.10320209578744002, 0.023583861999213696, 0.24767369564090455, 0.1170635891280004, 0.04560448448838932, 0.014413040530468737, 0.050207784798528464, 0.08237378485500813, 0.1341536199407918, 0.051802515118782005, 0.11406907838370119, 0.02349817829339632, 0.029163431708834002, 0.03701679940734591, 0.13348356660987648, 0.08499111155314104, 0.07887535329375948, 0.037143814377486706, 0.07370957798723664, 0.04154858212651951, 0.12856251852852957, 0.13181175131882938, 0.001775711088807189, 0.03653418119730694, 0.03870751189866236, 0.06604553173695292, 0.03205825208819338, 0.10723116887467248, 0.16533056699803897, 0.06879598022039447, 0.2297768188374383, 0.363510072763477, 0.20787760322647436, 0.41726538113185335, 0.26531118207744186, 0.24809009901114873, 0.18499539393399442, 0.16647431919617312, 0.7576318457722664, 0.881575060742242, 1.1549225130251475, 1.0158233770302363, 2.3368947974273135, 7.901977811540876, 11.205514465059553, 10.964225241116115, 8.394606828689575, 10.234719106129237, 17.380100624901907, 41.56873410088675, 42.63915967941284, 64.11029188973563, 74.66640513283866, 73.15707574571881, 68.57852554321289, 72.22976221357072, 76.1289175578526, 71.6850095476423, 73.21933160509381, 75.28129986354283, 76.1826479775565, 73.0291941506522, 68.39707333700997, 56.1619313785008, 48.29352726255144, 48.73909786769322, 46.50363656452724, 27.476694754191808, 26.942201103482926, 25.345508541379655, 26.22901020731245, 25.11034676006862, 25.620089190346853, 20.996966293879918, 47.56847926548549, 73.72138064248222, 80.49284485408238, 67.09937218257359, 44.9604103905814, 47.970210211617605, 27.20993603978838, 5.337072014808655, 6.1505979384694776, 2.205454856157303, 7.191484987735748, 0.3833247609436512, 0.18002558632620744, 0.40023830479809214, 0.2593691423535347, 0.1500874813646078, 0.42855848371982574, 1.7127257415226527, 1.372033960052899, 0.5929681701319558, 0.8202421718410083, 1.5605871166501726, 0.189329237810203, 1.0459551087447574, 1.254328327519553, 1.7466625890561511, 1.2253940744059426, 3.4937051577227454, 5.1020405122212, 5.578854560852051, 3.5669094238962447, 5.377283845629011, 11.608982460839407, 23.79571979386466, 16.783837488719396, 57.13800042016165, 47.22762843540737, 31.51728936604091, 27.34054480280195, 23.17130776814052, 22.384834221431188, 24.767774513789586, 26.03774540764945, 23.002904278891428, 15.749278511319842, 17.048501321247645, 18.234336478369578, 26.82736475127084, 39.12033830370222, 34.114362716674805, 33.65598310743059, 46.527795451028005, 52.30599382945469, 61.727511405944824, 64.88223675319126, 61.4727418082101, 61.27063955579485, 56.76183189664568, 61.808291162763325, 66.5911670412336, 69.54837594713483, 70.64368997301374, 51.00112908227103, 28.981912544795446, 12.7920800277165, 4.5470501099314005, 0.5063508408410209, 0.40387986653617447, 0.06526346584515912, 0.2235260863921472, 0.3482869767716953, 0.1698198632470199, 0.12361335195600986, 0.04241200775972434, 0.03392757874514375, 0.13122734267796787, 0.19646171294152737, 0.22631352181945527, 0.12384072904075895, 0.04086502594873309, 0.10809368187827723, 0.013565762334370186, 0.021791133464180996, 0.1880995152252061, 0.24968875465648516, 0.047291515927229605, 0.08567783648946456, 0.058921897916921546, 0.07042263222060033, 0.03656680855367865, 0.0967725965061358, 0.09857455481375967, 0.15398820276771272, 0.02224721247330308, 0.08039081376045942, 0.05831547760005508, 0.09399027044751815, 0.08017784875950643, 0.1015445568731853, 0.11960876041225024, 0.08849567707095828, 0.026683937525376678, 0.041884467138775756, 0.11415184608527593, 0.2684550790914467, 0.16824625911457197, 0.1394241949809449, 0.17946400360337325, 0.14383354623402866, 0.1673090122640133, 0.32973121532372063, 0.1835242078772613, 0.15379258112183639, 0.09936357568949461, 0.14122205493705614, 0.2033846971711942, 0.2562135745372091, 0.14730273293597357, 0.1629182935825416, 0.1684719534324748, 0.2656814722078187, 0.1966232992708683, 0.1825704454843487, 0.16885650636894362, 0.23221319381679806, 0.18698569999209472, 0.17899631655641965, 0.14103121017771109, 0.183938738490854, 0.19487033119159086, 0.3540193491748401, 0.15674453414976597, 0.2794760348541396, 0.43438533533896717, 0.16605839080044202, 0.24541444544281277, 0.38761958905628746, 0.20278613428984368, 0.24394889122673444, 0.3399917504617146, 0.7192227467894554, 0.8726666016238076, 1.6111265761511666, 2.7224390464169637, 1.5363290011882782, 6.416875924382891, 9.737536413328987, 16.800224815096172, 11.027784756251744, 31.789450304848806, 56.1918294770377, 49.751773493630544, 58.91627720424107, 82.11958490099225, 91.94865948813302, 82.3969361441476, 79.07917826516288, 80.69044467381069, 77.01864828382219, 70.51065281459263, 79.54981449672154, 77.89678941454206, 79.88821956089565, 79.00161552429199, 77.36821910313198, 63.05074719020298, 62.48026534489223, 48.71592909949166, 45.69021790368216, 34.16019998277937, 35.432481152670725, 34.63305268968855, 28.266015325273784, 29.67696864264352, 28.195630073547363, 23.02875852584839, 59.60914461953299, 82.09730897630963, 95.33371067047119, 84.05238614763532, 68.34737287248883, 61.917093004499165, 52.85303245271955, 34.517757756369456, 14.792700903756277, 15.519685711179461, 12.843207478523254, 0.6977796831301281, 0.40094465975250515, 1.1863541007041931, 0.3350730229701315, 0.5652615225740841, 0.8544959223696164, 3.217082606894629, 2.076640248298645, 1.4633488144193376, 2.345945260354451, 1.8957977465220859, 0.4255286891545568, 1.4426095272813524, 2.6085982407842363, 2.021404892206192, 4.3557679397719244, 14.201779195240565, 14.521584800311498, 10.862117988722664, 9.55144020489284, 17.75261960710798, 25.08076654161726, 51.61929294041225, 46.09352956499372, 69.3501091003418, 65.85415772029332, 72.42504133496965, 67.14654350280762, 55.70900610515049, 44.67903961454119, 38.33764457702637, 35.107628549848286, 32.46024676731655, 31.522997311183385, 34.144719396318706, 29.01373703139169, 30.681202207292827, 42.15399476460048, 38.479099478040425, 37.226193359919954, 46.660975047520225, 55.05025087084089, 65.31975092206682, 73.86424255371094, 71.65106759752545, 68.59829316820417, 67.83730561392647, 74.92256437029157, 77.09822600228446, 75.229827608381, 87.14700262887138, 75.68256528036935, 51.87582043239048, 36.46342011860439, 17.23442816734314, 1.5506845223052161, 0.4071070876504694, 0.12843270120876177, 0.49341579207352226, 0.6622721627354622, 0.20879480615258217, 0.22748597604887827, 0.167785981670022, 0.20097968408039638, 0.1595041360706091, 0.22773868963122368, 0.3469190230326993, 0.2295940757862159, 0.057219317848128934, 0.20941007456609181, 0.26797318352120264, 0.23414297455123492, 0.21086816489696503, 0.5290300867387226, 0.18871166237762996, 0.13877784966358117, 0.15203304482357843, 0.2314982350383486, 0.1789738027645009, 0.1947682930954865, 0.2840606245611395, 0.2641157933643886, 0.08955044618674687, 0.11806921873773847, 0.1230327838233539, 0.2478537516934531, 0.0992141215662871, 0.219790873250791, 0.15615806276244776, 0.16772336645850114, 0.14495961580957684, 0.18183690841708863, 0.22590386308729649], [0.5936001305069242, 0.3837113087730748, 0.09269724733063153, 0.08579798468521663, 0.18745501552309307, 0.061171071869986396, 0.03761947760358453, 0.1112244628103716, 0.06946232875010797, 0.08189551266176359, 0.19530432218951838, 0.23934057993548258, 0.1940186611775841, 0.2039284479937383, 0.38125140219926834, 0.137774472790105, 0.2585262661533696, 0.11454161017068795, 0.10210133556808744, 0.2717723825148174, 0.171641879049795, 0.04145922924258879, 0.21174304080860956, 0.04569421395925539, 0.25728454706924303, 0.06884674142513957, 0.06951266247779131, 0.11988670192658901, 0.261336052524192, 0.12308961791651589, 0.1068200987896749, 0.042597376741468906, 0.030082656669297388, 0.2848907985857555, 0.7325793557933399, 0.9252817268882478, 0.422478049993515, 0.08560156915336847, 0.3131045289337635, 0.20880402065813541, 0.660873674920627, 0.17894724490387098, 1.9906793066433497, 2.2076268196105957, 3.673556021281651, 1.6565631266151155, 6.045076514993395, 3.4263260875429427, 11.352242180279323, 32.36725207737514, 48.41166400909424, 51.63696220942906, 50.83362191064017, 52.42418268748692, 58.021634101867676, 60.32948521205357, 65.0842764718192, 69.81442247118268, 58.92262090955462, 44.08753252029419, 37.66161959511893, 33.773789814540315, 37.63390670503889, 25.756169659750803, 14.931567600795201, 15.22769808769226, 15.193017891475133, 20.892364638192312, 18.802094629832677, 28.58140274456569, 41.350234099796836, 38.573570660182405, 46.85951287405831, 42.55087586811611, 42.62293216160366, 49.12326029368809, 67.88806220463344, 45.850269658224924, 24.562635898590088, 18.165717806134904, 16.71879366465977, 15.987348113741193, 6.793453088828495, 3.7528558118002753, 1.3471555007355553, 0.49266864359378815, 0.8815743007830211, 0.25169892821993145, 0.31092192605137825, 1.2366730634655272, 1.489818302648408, 1.3839104941913059, 0.845577312367303, 1.9139173456600733, 0.3920334864939962, 0.13062493928841182, 1.4269996391875404, 2.354313062770026, 8.519108125141688, 9.142273817743574, 8.077261754444667, 4.183859952858516, 5.888534903526306, 12.834073202950613, 24.104320560182842, 47.05607393809727, 36.404339585985454, 48.905625343322754, 44.719175883701865, 39.84923907688686, 37.29595327377319, 39.95086342947823, 55.160230432237896, 36.83474574770246, 26.013522250311716, 22.819675070898874, 19.222651720046997, 14.970018931797572, 21.414084025791713, 19.374462911060878, 18.747530426297867, 29.097490617207118, 33.25505467823574, 34.60998119626726, 29.24327598299299, 27.780652386801584, 42.78047909055437, 51.39078753335135, 48.3519720349993, 55.76366063526699, 64.35928753444126, 70.61537606375558, 52.55596569606236, 29.856843607766287, 11.829264674867902, 6.058840896402087, 1.7256595960685184, 0.02685491308303816, 0.2573917827435902, 0.3766988936279501, 0.9106811189225742, 1.0736231612307685, 0.4902696151818548, 0.34012813600046293, 0.45466699131897514, 0.09551569180829184, 0.40770921962601797, 0.6952202490397862, 0.7105672998087746, 0.4947991892695427, 0.4446322183523859, 0.21676145866513252, 0.10844531229564122, 0.08592934906482697, 0.17408892059964792, 0.06403729878365993, 0.05086413511474218, 0.18088231821145329, 0.09075676609895059, 0.07639767588781458, 0.050898024546248574, 0.06203177318509136, 0.2257652926657881, 0.19433347428483622, 0.2608576581946441, 0.11450779198535851, 0.1029402491237436, 0.10357919840940408, 0.012689389404840767, 0.007703181605653039, 0.051358268064047606, 0.05118038332355874, 0.15768646289195332, 0.07691900112799235, 0.0934492541210992, 0.07326732243278197, 0.28206391313246315, 0.15789123118988105, 0.21149399131536484, 0.20347469805606774, 0.13989215344190598, 0.08155560732952186, 0.10212583746761084, 0.12131580524146557, 0.051697416829743555, 0.05831977951207331, 0.0844275542934026, 0.09331862934465919, 0.15367771871387959, 0.18646818133337156, 0.3484895330454622, 0.2364373185804912, 0.24631822694625172, 0.07176435379577534, 0.2240933823798384, 0.5165614358016423, 0.5390308243887765, 0.08831574994006328, 0.10054233350924083, 0.07330113383276121, 0.015725286544433663, 0.05927135023687567, 0.010532187480878617, 0.07625540066510439, 0.44543820938893725, 0.08490054748420205, 0.23190063344580786, 0.07353174074419908, 0.11694613471627235, 0.2564467734524182, 0.31314627240811077, 0.08865196404180356, 0.21110827129866394, 0.021774757021505917, 0.600802589740072, 0.6036588421889714, 0.8701952142374856, 0.6779021354658263, 2.3095694865499223, 5.774806788989475, 7.214958608150482, 2.4823479524680545, 17.889078753335134, 5.934640109539032, 28.66802419934954, 41.35697037833077, 51.18617698124477, 54.01417023794991, 64.33802604675293, 69.03743321555001, 73.03967203412736, 77.10467393057687, 73.60907690865653, 71.9143626349313, 67.53881100245884, 59.05801350729806, 45.65504264831543, 40.76281254632132, 45.37380041394915, 37.13956669398716, 20.88941512789045, 18.167513915470668, 12.705358692577907, 14.231913532529559, 14.585693223135811, 20.038172210965836, 24.481296811785015, 41.56035109928676, 59.889233452933176, 63.99529920305525, 60.18540736607143, 68.8394581930978, 65.22659642355782, 52.42984546933855, 34.48768595286778, 14.99921178817749, 3.529980399778911, 8.503126399857656, 11.541985324450902, 9.132878116198949, 1.767165637442044, 0.2632959873548576, 0.3892137663705008, 0.7208113329751151, 0.4902642954673086, 1.6996796301433017, 2.0212159880570004, 0.4491941178483622, 0.7980521225503513, 0.7330471649765968, 0.16981301004333155, 0.19583382377667086, 0.9299175867012569, 1.7128454893827438, 9.774919458798, 13.824300067765371, 13.021498254367284, 6.341960447175162, 3.0497523971966336, 13.864917499678475, 22.2818706035614, 47.056035723005024, 43.89231593268258, 52.65186125891549, 64.81624276297433, 66.4820316859654, 53.5119822365897, 37.65856238773891, 40.339048862457275, 30.74006039755685, 19.20687757219587, 10.70955639226096, 10.413722940853663, 17.42202605519976, 26.5365218435015, 31.58236619404384, 31.19382987703596, 41.8506155695234, 46.75000926426479, 49.560899530138286, 46.68006174904959, 41.12956626074654, 44.10165473393032, 50.108330726623535, 56.65971074785505, 71.00252274104527, 78.46417236328125, 79.93094403403146, 60.87320954459054, 40.14372457776751, 19.35428707940238, 5.036478613104139, 0.6586987801960537, 0.07064197545072862, 0.2997810052973883, 0.24993297298039707, 0.6161086027111325, 0.40546997264027596, 0.41341184505394524, 0.27729766603027073, 0.24140929750033788, 0.05690304928326181, 0.4117256583912032, 0.7968045409236635, 0.5595917382410595, 0.1826815895204033, 0.1759656670370272, 0.1644847866679941, 0.12393504540835108, 0.10790145290749413, 0.08749028494847672, 0.12673432805708476, 0.12485327970768724, 0.1665339081415108, 0.16682835162750312, 0.1594033329082387, 0.07401453198066779, 0.043812117273254056, 0.07041839137673378, 0.2231679963214057, 0.20123428399009363, 0.0953524023560541, 0.04615734125088368, 0.033370528636234145, 0.06377115699329547, 0.11128621628241879, 0.1438376988683428, 0.02810830805849816, 0.07307163971875395, 0.22962197714618274, 0.0792031671319689, 0.08703732211142778, 1.056451556938035, 0.5063836819359234, 0.2535631353301661, 0.25899364107421463, 0.2101199036198003, 0.19006462049271378, 0.1544407449130501, 0.26363807756985935, 0.14610955624708108, 0.24413860961794853, 0.34628299144761904, 0.3617922935102667, 0.28310041608554976, 0.4218944284532751, 0.5621146400059972, 0.2945329983319555, 0.3705530491258417, 0.21081005515796797, 0.37432206688182695, 0.5661429667047092, 0.5539357417396137, 0.1241050184305225, 0.15802928592477525, 0.2245631321732487, 0.2734521638069834, 0.09619468144540276, 0.10734206863812037, 0.2033249589481524, 0.2668618517262595, 0.2098369002342224, 0.21645390588257993, 0.10620489822966711, 0.19224573059805802, 0.35639587736555506, 0.5194534606167248, 0.7301107911126954, 0.47821204790047234, 0.11488828728241579, 0.6231583101408822, 0.6694568714925221, 1.1777819778238023, 0.45227949800235884, 1.904260869537081, 3.8854721699442183, 9.264376248632159, 1.6737756601401736, 25.564628669193812, 53.372243540627615, 57.4064371245248, 67.00669016156877, 76.32452324458531, 78.00894028799874, 77.72480760301862, 79.3912843976702, 83.86088684626988, 82.56992544446672, 80.2288202558245, 83.58156926291329, 76.84596470424107, 67.44293975830078, 63.40126991271973, 55.05839763368879, 50.33176047461373, 44.80643136160714, 37.186265536717, 31.637823241097585, 28.700769322259085, 32.49178464072091, 36.54118435723441, 45.80062825339181, 51.96163068498884, 67.9919238771711, 72.28411797114781, 69.41304588317871, 70.44193513052804, 77.49250847952706, 76.68962328774589, 56.83454132080078, 52.828029360089985, 50.56713417598179, 42.433367933545796, 32.53126777921404, 17.29640088762556, 9.768152781895228, 2.636481578860964, 0.2682875895074436, 0.46425262838602066, 0.6632437705993652, 0.47889405701841625, 2.808146161692483, 3.7331893699509755, 2.019001684018544, 2.1685597045081, 2.5454380299363817, 0.6793309130838939, 0.11848266369530133, 0.8371963192309652, 5.20866539648601, 23.220379420689174, 20.690076521464757, 27.911603348595754, 26.131492240088328, 24.070826768875122, 49.94361325672695, 66.67012637002128, 72.3343812397548, 49.4944851739066, 55.1623808997018, 76.64889294760567, 82.28263827732631, 71.3349106652396, 73.73665278298515, 100.7458918435233, 93.56760365622384, 75.40064907073975, 59.88994216918945, 57.885932309286936, 65.35729898725236, 71.51015813010079, 67.73167215074811, 52.31983116694859, 54.143924372536794, 57.59660931995937, 56.07919222967965, 48.347664151872905, 45.36292995725359, 51.56513173239571, 53.925076961517334, 55.75999198641096, 69.2915427344186, 85.565676007952, 97.01227038247245, 84.61120891571045, 63.447669982910156, 44.71009806224278, 30.076670714787074, 6.12068464074816, 0.13182784616947174, 0.14830800970750196, 0.2985864579677582, 0.9342285096645355, 1.063579105905124, 0.5513124167919159, 0.2258655394294432, 0.3739794338388102, 0.1635806116142443, 0.2590433098375797, 0.6477615013718605, 0.8349370147500719, 0.6865948204483304, 0.5465493723750114, 0.43505160244447844, 0.27959770975368364, 0.1478984866823469, 0.18777592187481268, 0.2686596709702696, 0.21272566808121546, 0.3126267859978335, 0.17923041113785335, 0.18022648697452887, 0.189769322052598, 0.11591510075543608, 0.1708824219448226, 0.391440066908087, 0.2828156756503241, 0.19154868514410087, 0.1751852703413793, 0.15538134372660092, 0.20114532804914884, 0.1378783429307597, 0.11588365744267191, 0.16656527003007277, 0.321506068110466, 0.2748213931918144, 0.18270301765629224, 0.2662197676088129], [0.05169697578198143, 0.16517272618200096, 0.13012157487017767, 0.13049403631261416, 0.18766996184630053, 0.10514330305159092, 0.04527900820331914, 0.07211717164942197, 0.0631131205175604, 0.044072284562779326, 0.016061816164957624, 0.08095341428582158, 0.21946293727627822, 0.1369935604078429, 0.4525096027978829, 0.1670364040349211, 0.031178226095757315, 0.11565381049045495, 0.11040105377989155, 0.4444553107023239, 0.6339324148637908, 0.257902773895434, 0.20245612199817384, 0.03758743039465376, 0.1270370768117053, 0.04545833143804755, 0.24620502016374043, 0.07213390432298183, 0.23215793392487935, 0.4183199873992375, 0.581874665405069, 0.5067411341837474, 0.304582916200161, 0.5227869674563408, 0.4285453472818647, 0.2165615486779383, 0.03936830322657313, 0.19481952248939446, 1.3973688291651862, 0.3869282975792885, 0.30436944908329416, 0.5512705647519657, 0.38332391956022804, 1.4094782365219933, 4.773496678897312, 1.223214294229235, 1.2281563090426582, 7.5751771075384955, 9.300796100071498, 3.207400075026921, 9.87361775125776, 25.550298009599956, 41.094849586486816, 51.14337607792446, 52.374794891902376, 59.5082220349993, 66.59357111794608, 57.196288858141216, 54.530355385371614, 54.12127671922956, 42.15518985475813, 31.67228283200945, 22.766107933861868, 22.323087317602976, 24.104562010083878, 16.581874200275966, 11.415304030690875, 13.547859907150269, 18.884889364242554, 27.915774004799978, 37.822446073804585, 22.42609088761466, 44.95651592527117, 34.918321405138286, 24.32570927483695, 32.44954306738717, 48.037920406886506, 52.00632149832589, 61.525770459856304, 46.123535360608784, 23.855436086654663, 17.51126524380275, 7.290843793324061, 6.569866572107587, 2.8812140694686343, 1.8854924823556627, 0.18621633627585002, 1.3220068216323853, 1.2588027502809251, 0.47288147679397036, 2.6197917887142728, 6.329850605555943, 4.594351274626596, 0.2047794937555279, 0.14841559822005884, 0.284251157194376, 2.096520781517029, 3.114236674138478, 4.893898972443171, 2.896514219897134, 2.372267859322684, 3.011852579457419, 10.649405837059021, 12.69341995034899, 28.542084625789098, 72.521315574646, 55.3758156640189, 45.82196964536394, 47.88842296600342, 45.382079192570274, 33.787040029253276, 28.18481867653983, 27.998624324798584, 22.806770529065812, 11.697849920817784, 13.934742552893502, 13.165537885257176, 15.37948669706072, 16.43138837814331, 21.049115998404368, 25.827659675053187, 20.529687779290335, 25.3708746773856, 32.34300633839199, 50.411532742636545, 63.67474406106131, 51.876404081072124, 52.75051178250994, 65.34005355834961, 72.17020920344761, 64.31861972808838, 45.291346141270225, 26.855089800698416, 12.495896560805184, 3.0346159636974335, 0.21577089253280843, 0.14671525731682777, 0.49300161429813927, 1.0642041180815016, 1.2352331578731537, 0.576581278017589, 0.28412923802222523, 0.4361714023564543, 0.5398006087967328, 0.7764315541301454, 0.21504579644118035, 0.25203491161976543, 0.3103718784238611, 0.35613683983683586, 0.2440805270203522, 0.02577718403855605, 0.03398788354492613, 0.40537136793136597, 0.21844408980437688, 0.08035922795534134, 0.08281536187444415, 0.08994510250964335, 0.32912441502724377, 0.2848515249788761, 0.11851112145398345, 0.06716340460947581, 0.1926494725048542, 0.07089162884013993, 0.12340848866317954, 0.2451805951339858, 0.1220370065420866, 0.2519540031041418, 0.19983450695872307, 0.07190247638417141, 0.3251923860183784, 0.3818341823560851, 0.09067763534507581, 0.08623827248811722, 0.20109024457633495, 0.33967400608318193, 0.22912697227937834, 0.04402621882036328, 0.053713965229690075, 0.05024849011429718, 0.11793793578233037, 0.12284895511610167, 0.035325527124639065, 0.037914355351988754, 0.064535275633846, 0.05418743000232747, 0.10803148735846792, 0.06788833785269942, 0.0511013814913375, 0.17601529508829117, 0.3029424627976758, 0.6301629628453935, 0.20424745444740566, 0.13308829282011303, 0.07347254534917218, 0.12103760588381972, 0.4174141160079411, 0.2995001732238701, 0.24139073278222764, 0.2652341276407242, 0.29188937161649975, 0.17175385089857237, 0.04155760324959244, 0.04931472075570907, 0.10940413655979292, 0.19323016277381352, 0.4306711974952902, 0.6590650262577193, 0.6647459385650498, 0.44688861870339935, 0.2975709353174482, 0.5154743141361645, 0.30483970099261826, 0.3390381373465061, 0.4546138213149139, 0.6502752293433461, 0.28273262296404156, 0.4163434420313154, 0.43116242970739094, 0.6657751947641373, 1.0239914187363215, 6.3884760311671664, 1.989656618663243, 0.23917811151061738, 13.519176874841962, 12.175417848995753, 11.453430533409119, 29.72617925916399, 43.461485930851524, 53.350436619349885, 56.00742081233433, 59.49447849818638, 65.03179672786167, 78.48934568677629, 75.37929725646973, 74.9772675377982, 67.89745616912842, 52.62206390925816, 50.14654581887381, 41.093543325151714, 26.785448006221227, 20.682454347610474, 16.635385751724243, 17.408404111862183, 20.253623689923966, 30.29188769204276, 36.8324111529759, 43.31075865881783, 64.46949291229248, 76.60104765210832, 66.38583387647355, 60.9909120287214, 47.936629567827495, 55.769170556749614, 48.66539485113961, 46.74040337971279, 43.904131344386506, 22.46054526737758, 18.82054557119097, 15.487788268498011, 5.326584577560425, 7.694652250834873, 3.6348697543144226, 0.4808080685990197, 1.7213435705218996, 0.8449716248682567, 0.6129497779267175, 3.093124572719846, 4.411007855619703, 3.5746314781052724, 1.904174017054694, 0.37093718137059895, 0.16319935635796615, 0.8166748146925653, 2.3698809359754835, 7.491832596915109, 5.366155002798353, 13.789324573108129, 9.297772765159607, 15.130414622170584, 25.29312607220241, 51.08839498247419, 75.10257829938615, 58.03361627033779, 50.542190143040244, 52.83057587487357, 48.37556116921561, 45.079961095537456, 40.51756198065621, 40.848806926182334, 35.72888435636248, 26.08294517653329, 22.29973442213876, 18.268653631210327, 13.591392108372279, 13.70661929675511, 24.012611286980764, 31.44442708151681, 33.371117387499126, 39.3643798828125, 42.35028484889439, 52.634931973048616, 65.26307446616036, 66.46104117802211, 69.63355391366142, 77.22015299115861, 75.47956671033586, 73.64089271000454, 55.77770641871861, 34.553697313581196, 15.877002034868513, 3.5977967722075324, 0.378862416105611, 0.06962827805961881, 0.4391600505581924, 0.8023084912981305, 1.006921866110393, 0.6497908639056342, 0.6719957866839, 0.822702594101429, 0.8588295355439186, 0.9063096163528306, 0.1719010251441172, 0.3893783518246242, 0.2823068829519408, 0.44165852506245884, 0.2183652033231088, 0.3262534790805408, 0.2711412363818714, 0.14326660308454717, 0.19463568021144184, 0.18160476801650866, 0.06972129163997513, 0.06956254158701215, 0.12524365447461605, 0.2233114657657487, 0.09010309260338545, 0.06861473673156329, 0.11183293908834457, 0.07917348801025323, 0.09266363949115787, 0.029735358698027473, 0.4881946008120264, 0.3423206183527197, 0.15109332810555184, 0.07712499078895364, 0.13044860160776547, 0.23961438238620758, 0.15678842179477215, 0.2834684263382639, 0.1660621091723442, 0.11451516087566103, 0.020652281985219036, 0.06838765141687222, 0.16507182802472795, 0.3246688283979893, 0.2137114166149071, 0.19897248250033173, 0.1783124211111239, 0.08696413532431636, 0.2461391208427293, 0.12873850337096623, 0.12769516078489168, 0.11663537924843174, 0.26868149265646935, 0.32787259934203966, 0.6561791896820068, 1.1346219394888197, 0.5153203138283321, 0.2813189359647887, 0.20860147795506886, 0.6439181704606328, 1.0081135907343455, 0.7863114582640784, 0.29967015981674194, 0.25055027699896265, 0.36188508995941704, 0.20701746509543487, 0.14855857911918843, 0.3774691665811198, 0.31790703694735256, 0.35869996515767916, 0.4832823872566223, 0.5093531140259334, 0.4834883362054825, 0.4851708316377231, 0.47407808687005726, 0.4808138225759779, 0.39976463307227406, 0.2106117465134178, 0.524315354015146, 0.7104308328458241, 0.35075204021164347, 0.38993523908512934, 0.7376671742115701, 0.633279664175851, 1.66651294699737, 5.789399743080139, 1.2114273267132896, 0.3201127643031733, 15.691941976547241, 48.313447747911724, 58.88023689814976, 59.01082829066685, 63.1762455531529, 72.49343940189907, 77.36514105115617, 82.08961732046944, 82.95589092799595, 80.50000844682965, 64.58086558750698, 63.0106908253261, 66.78463963099888, 56.610093661717, 56.416322299412315, 52.331292220524375, 53.43646226610456, 57.50408015932356, 51.43981054850987, 51.52765314919608, 62.04385593959263, 75.65154157366071, 73.92971542903355, 65.97883619580949, 87.1392206464495, 87.5068359375, 82.17613628932408, 82.59289618900844, 59.5860835484096, 62.605541365487234, 60.86466326032366, 69.40676471165249, 67.36744063241142, 50.622094426836284, 36.425819941929404, 22.249488524028234, 7.279651548181262, 8.587610415049962, 4.682896077632904, 0.19943615261997494, 1.859318835394723, 1.0261337437799998, 0.8671271502971649, 6.005693256855011, 7.32628915991102, 7.631666830607823, 2.1363875908511023, 0.6391729850854192, 0.21527727187744208, 1.240067258477211, 6.792842950139727, 7.241662706647601, 5.852287020002093, 27.665171589170182, 32.85706533704485, 54.30449724197388, 60.15202822004046, 79.83747686658586, 99.82913262503487, 75.68746376037598, 51.82789175851004, 59.39398670196533, 56.78488254547119, 55.46546827043806, 49.78134502683367, 54.67462083271572, 60.422806467328755, 66.71278830936977, 72.94455119541713, 60.46816430773054, 59.23242024012974, 66.65851593017578, 76.54387787410191, 88.8986712864467, 89.2026619229998, 89.92084857395717, 92.19803728376115, 93.95932919638497, 85.81424086434501, 64.16531467437744, 62.00190271650042, 77.35037612915039, 82.82678644997733, 79.92166818891252, 71.29437487465995, 59.12215232849121, 42.933033738817485, 15.074300970349993, 2.4122380231107985, 0.17292595228978566, 0.5331251270004681, 0.6778696743505341, 1.4987980893680026, 1.4162629353148597, 1.1496240773371287, 1.08204904624394, 0.9346175002200263, 0.878031316612448, 0.2941397465765476, 0.6595103080783571, 0.4219030594187123, 0.3653491197952202, 0.41952056011983324, 0.3717858929719244, 0.5678480980651719, 0.534665835755212, 0.21159693864839418, 0.1973580712718623, 0.20869223879916327, 0.12176016425447804, 0.3541320945535387, 0.4249872453510761, 0.38144372616495403, 0.22560144002948487, 0.21096032352319785, 0.11145196881677423, 0.2401800634605544, 0.38454126566648483, 0.5342441126704216, 0.3792951857405049, 0.23145239321248873, 0.1291589100978204, 0.2322802059352398, 0.2283293679356575, 0.1502012445458344, 0.3628920630684921, 0.3014878194246973, 0.30583277770451134, 0.2658287143068654], [0.4769725544112069, 0.31722185228552136, 0.05911072064191103, 0.09792434863213982, 0.06569163501262665, 0.0669115391959037, 0.1174297673361642, 0.020613003289327025, 0.08258064304079328, 0.09986613265105657, 0.17677142737167223, 0.20152194212589944, 0.25757591000625063, 0.4419973040265696, 0.6278061664530209, 0.4177648371883801, 0.2848899843437331, 0.09216896032116242, 0.11204791255295277, 0.28214137469019207, 0.277299023100308, 0.07305547701460974, 0.11509555258921214, 0.3391392933470862, 0.10999533055084092, 0.11460315329687935, 0.04032560757228306, 0.07516667765698262, 0.4281663990446499, 0.44637203642300194, 0.6003439000674656, 0.6983593691672597, 0.18908373026975564, 0.048819892308009524, 0.42600616067647934, 0.6342810732977731, 0.17158553350184644, 0.5534746093409402, 0.38103033549019266, 0.3040392468018191, 0.11811495199799538, 0.267977526145322, 0.7302084458725793, 0.469500689634255, 0.7508552351168224, 3.058751400027956, 0.954651762332235, 2.894591523068292, 2.9249946687902724, 4.26587518623897, 5.551634124347141, 8.926501853125435, 18.58770101411002, 28.402665546962194, 36.23912879398891, 41.072785581861226, 52.29589114870344, 58.95085144042969, 55.276157651628765, 40.61053235190255, 36.176299708230154, 29.631127902439662, 13.991148029054914, 4.773616535323007, 3.526351485933576, 7.2869197981698175, 8.361900789397103, 6.041854287896838, 5.725623096738543, 9.753123828342982, 13.088392036301748, 17.50142659459795, 26.806263072150095, 16.351906197411672, 21.413132122584752, 25.88746976852417, 26.35461105619158, 44.221969740731375, 66.82307011740548, 41.61384180613926, 23.964797258377075, 19.049120460237774, 7.6240646328244885, 6.915388762950897, 3.0984612235001157, 7.050575954573495, 1.131780886224338, 0.9956283292600087, 0.3000159684036459, 0.21921291069260665, 0.5980559342673847, 1.0477005179439272, 1.334719528044973, 1.7188211573021752, 0.33210228809288567, 0.04822636415649738, 0.541679173707962, 4.236318852220263, 9.404355525970459, 4.535545195852007, 1.6954019282545363, 5.366167596408299, 8.19808484826769, 11.198871987206594, 29.12015390396118, 84.31123433794293, 72.63660703386579, 35.0249137197222, 33.654784543173655, 30.15620674405779, 25.82137155532837, 25.163939952850342, 12.222580483981542, 11.146180323192052, 3.8749504259654453, 7.13478638444628, 5.327383620398385, 4.346635401248932, 7.732464347566877, 6.81232613325119, 9.873686364718846, 11.66750453199659, 15.691566773823329, 24.577560629163468, 28.776400463921682, 26.220656735556467, 39.71787296022688, 50.9343638420105, 53.21847643171038, 46.04787990025112, 33.1528570992606, 15.593619755336217, 3.648553362914494, 1.0897332110575266, 0.43169144274932997, 0.7856214152915137, 0.7683596472655023, 0.24409643188118935, 0.7384802220123154, 1.145440610391753, 0.44751976483634537, 0.4272946443940912, 0.11089451837220363, 0.2985529383378369, 0.3139856202261788, 0.26851555013230866, 0.6990244420511382, 0.5398730763367244, 0.2417871057987213, 0.08962412151907172, 0.16718337471996034, 0.0686634284045015, 0.03811414998822978, 0.14473901050431387, 0.10702239722013474, 0.020911991263606718, 0.12376879075808184, 0.24331310391426086, 0.4471861698797771, 0.31831247519169537, 0.10967135043548686, 0.010086772497743368, 0.034824483296168704, 0.16557361824171885, 0.10300717303263289, 0.038496803026646376, 0.051973522906856875, 0.16635831684938499, 0.005435137593719576, 0.2851408523108278, 0.11543072174702372, 0.12450715899467468, 0.3078053332865238, 0.23656048625707626, 0.08080195848430906, 0.18580283703548567, 0.35394970434052603, 0.30162762477993965, 0.15680026901619776, 0.04686944678957973, 0.15739998540707997, 0.0855870960014207, 0.1432221726115261, 0.05479875273470368, 0.04991884423153741, 0.06478761602193117, 0.16239654086530209, 0.14214262339685643, 0.46795547540698734, 0.7687325701117516, 1.1269623105015074, 0.8650165264095578, 0.25379592712436405, 0.2081878837198019, 0.25032663185681614, 0.3102702610194683, 0.38668823188969065, 0.3430456465908459, 0.049565578544778485, 0.4930823871067592, 0.3927978426218033, 0.04674949197630797, 0.059617613442242146, 0.10364581019218479, 0.38972538177456173, 0.3780429900756904, 0.6588310131004879, 0.4879683500954083, 0.33262288730059353, 0.2759388860847269, 0.5092842834336417, 0.5598572897059577, 0.1817533943269934, 0.6208284380180495, 0.9044977650046349, 0.6114133575132915, 0.7020273123468671, 0.5461965884481157, 0.327439368303333, 1.390363525067057, 2.5885691898209706, 1.4056776804583413, 1.5962250786168235, 1.416501562510218, 0.5960420966148376, 3.2091933616570065, 5.889990985393524, 14.03084395612989, 21.697792870657786, 35.667903491428916, 45.06697143827166, 58.250066552843364, 65.85753454480852, 64.75745405469621, 61.97661822182791, 55.837196895054404, 47.48697689601353, 38.47153288977486, 24.84669041633606, 18.874381950923375, 19.573999541146414, 19.487522261483328, 19.405102729797363, 34.56827463422503, 39.312924998147146, 37.342322077069966, 34.750487668173655, 40.29855476106916, 53.18137305123465, 49.30212082181658, 55.62058680398123, 49.324070181165425, 52.62463126863752, 60.492830412728445, 68.40677302224296, 50.75111552647182, 40.73302909306118, 24.93038841656276, 9.100730538368225, 5.095751089709146, 4.811723496232714, 6.651648606572833, 0.23811829409429006, 0.8070035736475671, 0.2292324709040778, 2.4700170712811604, 2.44219257576125, 5.935274132660457, 1.9590771624020167, 0.4884940247450556, 0.16676678135991096, 0.09594412560441665, 2.9978354573249817, 0.5256110302039555, 6.29665732383728, 4.547241619655064, 2.480427644082478, 6.722404718399048, 14.947690895625524, 24.29595535142081, 54.33356155667986, 86.30510330200195, 70.01473903656006, 49.412538119724815, 46.872474738529746, 40.028050967625205, 33.39090238298689, 34.686293261391775, 29.222747530255997, 21.290362664631434, 11.036037479128156, 7.630390967641558, 6.13306850194931, 4.313814282417297, 1.494540797812598, 7.703931570053101, 11.431784289223806, 13.229701893670217, 16.883314847946167, 23.673846653529576, 32.55799749919346, 37.61029672622681, 39.38971301487514, 42.96341821125576, 51.263100487845286, 45.960975306374685, 29.89560760770525, 6.788902453013828, 3.9580191799572537, 1.2087174206972122, 0.6119770301239831, 0.8953502987112317, 0.9530332663229534, 0.14808953500219754, 0.38395221584609573, 0.1399356068245002, 0.24510104368839944, 0.17019550023334368, 0.12748895399272442, 0.09807467806552138, 0.08241689218474285, 0.058258127820278914, 0.33009941556624, 0.5568221754261425, 0.20464226683335646, 0.060293407179415226, 0.11681946579899107, 0.08978196233510971, 0.12061681917735509, 0.17151504728410924, 0.15016814560762473, 0.07606476625161511, 0.20740219445100852, 0.44349420656050953, 0.5484979621001652, 0.5364836582115718, 0.44790017870920046, 0.06909655766295535, 0.050380159834665914, 0.11740789136716298, 0.10783867484756879, 0.06842632791293518, 0.07468140976769583, 0.017862344460029687, 0.0563504707201251, 0.10777841415256262, 0.13065970742276736, 0.131934647581407, 0.09383266711873667, 0.19408510332661016, 0.18771203101745673, 0.09914470064852919, 0.544127382338047, 0.38887227326631546, 0.2770070901938847, 0.1326211757425751, 0.2874202957110745, 0.2539741104202611, 0.31474319100379944, 0.09328841418027878, 0.23709484615496226, 0.21626988718552248, 0.34855849934475763, 0.3005567065307072, 0.9077358969620296, 1.014724041734423, 1.2678022959402628, 0.9782217890024185, 0.2661233613533633, 0.29228273193751064, 0.29065522498318125, 0.24643102660775185, 0.3888728432357311, 0.6788125123296465, 0.32820665570242064, 0.7110053620168141, 0.479363386120115, 0.18260435866458075, 0.11116083658167294, 0.19427764442350182, 0.3312338175518172, 0.4827959047896521, 1.2402303240128925, 1.0226271833692278, 0.2823949025145599, 0.22270895381058964, 0.33802888435976847, 0.6247601413301059, 0.2756284698843956, 0.8549971154757908, 0.9155278674193791, 0.8980442998664719, 0.8458765191691262, 0.4339695562209402, 1.1339489413159234, 2.3603076211043765, 2.8522478980677466, 6.0783310277121405, 0.9100640320352146, 1.6226955439363207, 4.380480510847909, 16.380312170301163, 35.53092670440674, 45.931563581739155, 59.1569766998291, 63.54584802900042, 63.24800654820034, 62.42918913705008, 66.78766209738595, 74.35574422563825, 77.13141059875488, 67.85249437604631, 66.86061818259103, 69.13680635179792, 69.80274949754987, 64.55995845794678, 51.82657160077776, 49.18149662017822, 57.33181347165789, 77.5532774244036, 71.05543327331543, 51.376581941332134, 43.37794426509312, 40.039730889456614, 53.879184109824045, 58.952873366219656, 74.3610040119716, 51.43277202333723, 58.165190832955496, 68.11995138440813, 75.15981061117989, 59.18558243342808, 61.147948265075684, 49.63614852087838, 31.870980467115128, 22.61910663332258, 13.632802503449575, 13.995818087032863, 2.5308785140514374, 2.6250567861965726, 0.2592313183205468, 2.5060495606490543, 2.0485393447535376, 4.773752459457942, 5.73366607086999, 2.525810237441744, 0.4418550559452602, 0.1219571293996913, 3.47354365672384, 6.559406927653721, 19.02444566999163, 15.949860845293317, 12.079306023461477, 17.160469804491314, 27.57210741724287, 45.45846421377999, 73.73804937090192, 105.36598532540458, 110.76563194819859, 69.89979498726981, 48.77500268391201, 34.45378916604178, 30.723256179264613, 39.17092118944441, 32.17872313090733, 24.69518494606018, 16.40407500948225, 15.259887354714529, 11.522716232708522, 10.05964708328247, 13.317710382597786, 17.568164042064122, 19.54018439565386, 33.96941981996809, 40.256511211395264, 40.46375165666853, 43.07832751955305, 55.794048581804546, 81.75930690765381, 92.75005776541573, 87.86182635171073, 78.28618730817522, 72.54831627437046, 51.47318969454084, 26.62999074799674, 6.278126912457602, 0.36248350356306347, 0.6133206923093114, 0.8397828947220529, 0.16361824316637857, 1.31684387581689, 2.446743211575917, 0.868031556052821, 0.33120027078049524, 0.18772360682487488, 0.2641158476471901, 0.33618451761347906, 0.73055086178439, 1.0341839918068476, 0.9036472077880586, 0.45180753618478775, 0.33769485514078823, 0.3568456918001175, 0.18264682138604776, 0.2008580227515527, 0.28701645880937576, 0.1647151085947241, 0.15044916767094815, 0.24705734157136508, 0.48980479155267986, 0.6149694238390241, 0.7795834307159696, 0.6285178682633809, 0.1774759774229356, 0.12950337518538746, 0.18635592449988636, 0.12317196492637907, 0.11359415815344878, 0.08327943911509854, 0.2512896901794842, 0.45856829626219614, 0.45623755561453955, 0.4575163498520851, 0.7592999019793102, 0.8845126288277763, 0.43459508408393177, 0.4427679841007505, 0.3139976438667093], [0.06509221717715263, 0.14250022492238454, 0.035021638431187184, 0.20701263392610209, 0.04762560282168644, 0.14850675261446408, 0.10050316168261425, 0.1609992337013994, 0.11187069956213236, 0.12955723729516777, 0.1518415758120162, 0.10859868835125651, 0.1496238112449646, 0.03588264508705054, 0.03668758439432297, 0.024653765838593245, 0.0472884048441691, 0.0513198663746672, 0.06049192616982119, 0.16245382279157639, 0.041512501026902876, 0.0592089318005102, 0.1191065495035478, 0.15947700824056352, 0.07070750836282969, 0.006334651535975614, 0.07580595263945204, 0.138025096484593, 0.15146793371864728, 0.27388192074639456, 0.6619298553892544, 0.30703915868486675, 0.22944740365658486, 0.2554305451256888, 0.04666733495625002, 0.2930800920086247, 0.16265656905514853, 0.1036831024768097, 0.037154046685567925, 0.06854490869279418, 0.28091604901211603, 0.32048196877752033, 0.2897914227630411, 0.3255675887422902, 0.8728194619928087, 0.4671068180884634, 1.7440952296767915, 0.7194368924413408, 1.4632334091833659, 0.9424258640834263, 1.8550094323498862, 2.7939911612442563, 4.615085133484431, 11.233195219721113, 18.090317692075455, 28.908171313149587, 33.324804169791086, 42.45068979263306, 44.42684432438442, 35.14990486417498, 18.091703857694352, 15.06069118635995, 10.337211983544485, 4.185554010527475, 1.6228531811918532, 1.9623180627822876, 2.0762585316385542, 5.408630209309714, 5.910387422357287, 5.784828262669699, 3.4345616570540836, 12.49120305265699, 15.40147600855146, 16.14910912513733, 25.22451434816633, 21.216294867651804, 16.20519151006426, 33.80593565532139, 51.33705363954817, 38.90920686721802, 12.234785863331386, 3.921143352985382, 6.311718847070422, 10.1915716614042, 14.699763536453247, 9.579530034746442, 1.5976219922304153, 0.12465474036123071, 0.0761385705055935, 0.5619249758975846, 1.3861046050276076, 1.9686037940638406, 3.5494909414223264, 0.694246415581022, 0.06678314679967505, 0.5523452013731003, 5.324226098401206, 5.084125450679234, 4.363931638853891, 1.3409517364842551, 1.8427011328084129, 4.6796278187206815, 10.54773371560233, 12.888898832457405, 30.753873416355678, 52.916431290762766, 56.383422579084126, 25.411624125071935, 16.972350801740372, 10.258777243750435, 3.8615364943231856, 8.20259075505393, 6.285142421722412, 3.633669453007834, 4.398662643773215, 3.46599400469235, 1.5588860022170203, 0.4636981838515827, 0.6403919596757207, 2.14802799480302, 1.3018002659082413, 1.7418487902198518, 3.6145497475351607, 3.1963745866503035, 5.930046047483172, 9.539577024323599, 10.578326633998326, 12.770670890808105, 16.079542023794993, 10.155915243285042, 7.363177146230425, 1.7084668214832033, 1.073098680802754, 0.786284154014928, 1.6422801273209708, 1.2199753480298179, 0.15869768363024506, 0.3987932966223785, 0.11910813727549144, 0.06889531096177441, 0.04580097465908953, 0.25257849959390505, 0.12060856819152832, 0.07945590785571507, 0.21586476106728825, 0.18132427521049976, 0.2115484912480627, 0.14794203505984374, 0.25531698550496784, 0.09934625269046851, 0.20775052718818188, 0.11993949195103985, 0.21958230515675886, 0.1339003906718322, 0.06946806237101555, 0.056607333544109545, 0.048126585582005124, 0.09842403539057289, 0.08596018848142453, 0.09629006989832435, 0.2831625427518572, 0.1687788548214095, 0.28457327133842875, 0.10808122397533484, 0.07106196148587124, 0.0648545195747699, 0.053255794636373005, 0.006415082956664264, 0.05741010153932231, 0.14735941775143147, 0.26914875901171137, 0.10061412929956402, 0.22144001190151485, 0.06671762067292418, 0.10261132248810359, 0.14161502170775617, 0.2858772256544658, 0.27605108863541056, 0.1150297075510025, 0.17009232219840797, 0.0339470866269299, 0.11493463122418948, 0.15538198154951843, 0.15847961604595184, 0.07867671895240035, 0.11857696649219308, 0.10723925701209477, 0.12267240030424935, 0.1887426171451807, 0.18765250992562088, 0.09402072988450527, 0.058101440513772626, 0.07856951720480408, 0.07852694591773407, 0.07865551473306757, 0.10962410404213838, 0.06934459613902227, 0.11213392365191664, 0.052365929886166535, 0.3720153463738305, 0.1706394792667457, 0.04050109369148101, 0.11781687156430312, 0.032507713684546094, 0.11663962687764849, 0.22247947326728276, 0.6828990844743592, 0.3893398924597672, 0.12577745797378675, 0.12758265967879975, 0.2582799308001995, 0.34776024360741886, 0.14890597547803605, 0.09338717495224305, 0.03173194459772535, 0.052207478388611755, 0.336777747209583, 0.44873906512345585, 0.37854358607104843, 0.8273555529969079, 1.1655111334153583, 1.534386328288487, 1.9370361736842563, 0.5354042989867074, 2.5607425229890004, 1.1455031441790717, 2.3821801160063063, 4.262101445879255, 7.862289701189313, 14.551233632223946, 21.6018990448543, 29.30025121143886, 34.90300757544381, 44.52253838947841, 44.85084424700056, 33.59876816613333, 20.26775632585798, 11.143245577812195, 3.7128380962780545, 3.0834027401038577, 9.174979857036046, 9.149846485682897, 12.107882227216448, 13.498052614075796, 9.75655015877315, 9.661683797836304, 14.645642280578613, 18.75669683728899, 25.6758519581386, 30.773519447871617, 36.96223129544939, 36.30863162449428, 33.81395040239607, 50.58339990888323, 71.5408205304827, 53.54611873626709, 31.459268433707102, 23.65486764907837, 15.063070944377355, 14.545120085988726, 4.561123251914978, 6.915117348943438, 1.2557662789310728, 0.39840278614844593, 0.08654978112982852, 1.4671911682401384, 2.2292969482285634, 1.616574940936906, 0.8704947467361177, 0.5151900351047516, 0.049539926528398476, 0.31191980679120335, 8.079551185880389, 17.820672001157487, 19.398491518838064, 13.352331519126892, 7.988644429615565, 2.19845997435706, 9.284697123936244, 18.726842164993286, 44.52143710000174, 75.8484674181257, 83.7640289579119, 51.302611419132774, 28.09519907406398, 19.148620401109966, 18.66448555673872, 15.348537683486938, 10.942940303257533, 8.367837156568255, 7.517936979021345, 6.094894230365753, 3.0743540142263686, 0.8902871246848787, 1.0150794855185916, 2.208660581282207, 1.6850653971944536, 1.0411143856389182, 2.091188473360879, 1.3049767868859428, 1.4757673080478395, 4.759642405169351, 7.033977142402104, 10.078047650200979, 9.321925571986608, 7.701205270630973, 3.0983252993651798, 1.4489079607384545, 1.2626098202807563, 1.1561840453318186, 1.2221808582544327, 0.21493602304586343, 0.19898078776896, 0.5518705525568554, 0.09311264646904809, 0.0724949799478054, 0.055226864226694615, 0.10592526716313191, 0.12795669532247952, 0.21897333354822227, 0.28823505342006683, 0.253445423075131, 0.21636443425502094, 0.17299704918903963, 0.19799069661114896, 0.13398944160767964, 0.06955013796687126, 0.07735109222786767, 0.1631535959563085, 0.08146134524473123, 0.11184681512947593, 0.06350729508059365, 0.014342014877391713, 0.08950357298765864, 0.11595147023243563, 0.11271179121519838, 0.23453571062002862, 0.2412275586809431, 0.09464937900858265, 0.04931801165054951, 0.13647433184087276, 0.03718565284673657, 0.07491122279316187, 0.0393219287507236, 0.06632603811366217, 0.11471405306032725, 0.29673907852598597, 0.15823927894234657, 0.2875627880649907, 0.11598767686103072, 0.22681094227092607, 0.29961226720895084, 0.5511699244379997, 0.6147041980709348, 0.6576985652957643, 0.4322361435209002, 0.12928876812968934, 0.3360464221664837, 0.19997170673949377, 0.2651078387030533, 0.10144937876611948, 0.2860901228019169, 0.37197246296065195, 0.25330925466758863, 0.31267034794603077, 0.20244312126721653, 0.14773008786141872, 0.08677772139864308, 0.2852775906877858, 0.19713237695395947, 0.15009248895304544, 0.20073033603174345, 0.11776792204805783, 0.1932977991444724, 0.19316795468330383, 0.33461582607456614, 0.3036992464746748, 0.2009370042277234, 0.2253322380461863, 0.20924281568399497, 0.27941667661070824, 0.45014284551143646, 0.8780633434653282, 0.3748141404773508, 0.19584284829241888, 0.4571665514792715, 0.6399614427770887, 0.3417814815683024, 0.26006667635270525, 0.2903406832899366, 0.14169473600174698, 0.26224273815751076, 0.8847645010266985, 2.658297836780548, 1.1182142027786799, 1.2596166666064943, 1.256565864597048, 1.6171542469944273, 4.264224554811205, 0.36021336966327255, 1.2863609343767166, 0.7120562227708953, 7.008173269884927, 17.472749641963414, 23.555414608546666, 31.884605884552002, 41.72782005582537, 62.16783959524972, 78.40108272007534, 84.12222249167306, 83.33173288617814, 77.55505616324288, 62.65699277605329, 45.70611538205828, 31.757565021514893, 20.935391357966832, 20.687872205461773, 15.505943911416189, 21.003495863505773, 21.693502358027867, 13.550380366189138, 12.581310766083853, 16.966203383037023, 23.60287949017116, 33.93702036993844, 44.588292666843955, 42.85046134676252, 44.64871767589024, 39.367239066532676, 50.79284988130842, 72.2306307383946, 65.32951314108712, 46.844056606292725, 42.19285603931972, 42.82729605266026, 56.105730874197825, 43.1551468031747, 21.576849051884242, 2.6730306233678545, 0.618250059229987, 0.3612762540578842, 1.6550204093967165, 7.314791628292628, 11.52829476765224, 5.349837592669895, 0.9041554576584271, 0.24197188445499965, 1.0740052035876682, 16.50323796272278, 35.96199989318848, 34.997093132564, 22.067652429853165, 21.740388802119664, 20.08885931968689, 24.88540404183524, 36.69247790745327, 61.68698951176235, 85.92094435010637, 88.204254422869, 55.30904000146048, 24.969251428331646, 12.985265135765076, 12.582855871745519, 9.28709077835083, 6.202251281057086, 5.257684069020407, 5.544427105358668, 5.99648255109787, 3.074672979967935, 1.18575981259346, 1.435999727674893, 3.1642969250679016, 4.58913882289614, 3.5027708198343004, 6.763372165816171, 16.50066712924412, 24.39301994868687, 31.517355373927526, 27.312896183558873, 33.60396541867937, 41.73267337254116, 33.805595193590435, 17.515675612858363, 5.408724009990692, 2.2833852001598904, 2.3034277132579257, 2.1142929707254683, 1.6996126451662608, 1.496257437126977, 1.2866302856377192, 0.3273080310651234, 0.2277860785169261, 0.1627875670258488, 0.21523106364267214, 0.18146224852119172, 0.1990295880075012, 0.37484130901949747, 0.49035597911902834, 0.32501944101282526, 0.5032891279884747, 0.48482483306101387, 0.34279562000717434, 0.3222954214683601, 0.3560097637985434, 0.3319544217416218, 0.38568280584045816, 0.18562829068728856, 0.13988914074642317, 0.08247655576893262, 0.15386541507073812, 0.21374945528805256, 0.4266406994845186, 0.7374935235295976, 1.253540684069906, 0.6460356882640294, 0.277193687324013, 0.2860176552619253, 0.26014576639447895, 0.13153504473822458, 0.21113803184458188, 0.15307671310646193, 0.4726275418485914, 0.43030207444514545, 0.17586505386446202, 0.3855497044112001, 0.3454194606414863, 0.5019262496914182, 0.3421144794140543], [0.16194371373525687, 0.03007238364911505, 0.01228540831445051, 0.11986353674105235, 0.08755418259118285, 0.05285694835973637, 0.06555738007383687, 0.1498037994440113, 0.13005477988294192, 0.14145266184849398, 0.1277764764215265, 0.18619186830307755, 0.03252510453707405, 0.043364480936101506, 0.033819104744387526, 0.04127953959895032, 0.050897593676511727, 0.02690165736047285, 0.10677008397345032, 0.11212970316410065, 0.06469298074288027, 0.058075805460768085, 0.09641142588640962, 0.07183689597461905, 0.03611700090446642, 0.062386470580739636, 0.01541855139657855, 0.04439834778064063, 0.00821714982989111, 0.02327496062831155, 0.09175030421465635, 0.11534798118684973, 0.16744155729455606, 0.4157837320651327, 0.10624268584485565, 0.05084507506606834, 0.1855036709457636, 0.2670201403754098, 0.14814368209668569, 0.07864134013652802, 0.02657023710863931, 0.19349005525665625, 0.07721152435988188, 0.1739782786795071, 0.17042152024805546, 0.287412343280656, 0.058604540303349495, 0.09780855663120747, 0.6659115531614849, 0.797051690518856, 1.7528620106833321, 1.4743244711841856, 1.2329476347991397, 2.5462268676076616, 6.439273876803262, 10.35380949292864, 7.9003467219216486, 10.645508766174316, 12.853091291018895, 12.429941654205322, 4.774672227246421, 2.401881298848561, 0.38868782030684607, 0.4708556426422936, 0.3475035945219653, 0.4941683145506041, 0.6102580023663384, 1.1485342958143778, 2.055177697113582, 0.789891354739666, 3.3610770744936804, 6.143139915806906, 7.493392467498779, 5.318345316818782, 13.878414375441414, 23.078349556241715, 11.84590995311737, 21.84448323931013, 41.81491572516305, 37.88894728251866, 9.684430462973458, 4.066088855266571, 3.641266005379813, 1.5739163671221053, 5.257317985807147, 7.8390227896826605, 2.360299587249756, 0.5295295427952493, 0.11899351914014135, 0.5709767416119576, 0.1444364245980978, 1.073191070130893, 0.5250286300267492, 0.10012097004801035, 0.11782620820615973, 9.321834376880101, 6.930408596992493, 4.412739259856088, 6.08751220362527, 6.80990468604224, 5.146267099039895, 6.958151885441371, 7.350807615688868, 16.959776299340383, 35.859680720738, 47.15656573431832, 28.587524107524327, 13.952334523200989, 4.921348699501582, 4.451075511319297, 0.9495116152933666, 2.562530598470143, 2.4869967315878188, 0.6973708793520927, 0.33967017914567676, 0.16436221610222543, 0.04975864211363452, 0.09182655798005206, 0.1979315419282232, 0.301605043134519, 0.12949739050652298, 0.37117865841303554, 0.043851679257516346, 0.17889244641576493, 0.48680012992450167, 1.2207244506904056, 1.8117942426885878, 1.7090180090495517, 0.40005482892904964, 0.1702545192092657, 0.047549179422536066, 0.07034942507743835, 0.14446963210191044, 0.32979467191866463, 0.2557659314147064, 0.16500335027064594, 0.1273923306060689, 0.15939932955162867, 0.22215106231825693, 0.1384617473397936, 0.11343597806990147, 0.15178457887044974, 0.07287746335246734, 0.0625381502988083, 0.00799309671856463, 0.026100773996274387, 0.05532122469906296, 0.0484231494899307, 0.09240674613309757, 0.0731363312474319, 0.06705425546637603, 0.013668302546388336, 0.059019864802914004, 0.057929513310747485, 0.07418169586786202, 0.14564588612743787, 0.02386482638706054, 0.07068133726716042, 0.060199742205441, 0.08774719866258757, 0.15783423424831458, 0.1495122058050973, 0.038843354609395774, 0.13316017681998865, 0.14288072021944181, 0.047547418624162674, 0.1363032731626715, 0.05602705039616142, 0.047512847264962535, 0.05100131793213742, 0.016161845797406774, 0.0542964095116726, 0.1012447868872966, 0.11869721646819796, 0.20301979460886546, 0.2592441833445004, 0.1812708880752325, 0.032394666357764175, 0.07829087001404592, 0.07304763993514435, 0.006880590633954853, 0.014326562938679541, 0.19237858775470937, 0.09309957788458892, 0.22442116907664708, 0.2013953003500189, 0.13788606465927192, 0.08194788199450288, 0.030031702082071985, 0.010315675438115639, 0.03566172765567899, 0.016444409831560085, 0.09523925664169447, 0.04569660240252103, 0.022888148170230643, 0.07013069252882685, 0.03266900824382901, 0.08836329488881997, 0.014702747842030866, 0.14979360784803117, 0.15375261540923799, 0.0614815762798701, 0.04724795397903238, 0.00815557871413018, 0.07978264282324485, 0.02393317861216409, 0.07886152475007943, 0.27597514699612347, 0.23674108513763972, 0.1572028709841626, 0.09356567715959889, 0.10577696654945612, 0.19212107014443192, 0.20227890222200326, 0.25909802690148354, 0.14874358847737312, 0.09958320390433073, 0.11812314870102064, 0.05524062491687281, 0.23133970211659158, 0.025616149018917764, 0.08368041259901864, 0.05669585522264242, 0.5438324638775417, 1.1934925062315804, 0.22930067724415235, 1.1448894228254045, 1.0813300162553787, 1.1271020344325473, 2.295401458229337, 1.0451871156692505, 3.682921758719853, 9.678910987717764, 4.434687750680106, 6.272741624287196, 6.922840705939701, 1.086298412510327, 1.100592594061579, 0.49613986590078896, 0.43403217143246103, 1.4898382787193571, 1.6462772956916263, 1.3145378338439124, 2.753052375146321, 2.805173418351582, 4.0009929197175165, 5.723811788218362, 8.922958271844045, 11.31556350844247, 14.726104157311575, 23.650380849838257, 25.718185595103673, 22.395704678126744, 39.869333267211914, 57.06179257801601, 48.82397706168038, 22.378179584230693, 19.11580753326416, 15.477586575916835, 19.344999074935913, 13.362991792815071, 16.34109480040414, 11.21404424735478, 0.5670447668858937, 0.17178829333611897, 0.5475600638559887, 0.8701808835778917, 0.21003524959087372, 0.17709396220743656, 0.051325864624232054, 0.12676053307950497, 11.96619369302477, 11.130361012050084, 9.10649059500013, 12.45959917136601, 10.649938242776052, 15.002915178026472, 16.35525175503322, 18.39510563441685, 30.443302835736954, 47.46535062789917, 65.81808267320905, 53.464126518794465, 29.521665981837682, 12.595487696783882, 9.389519384929113, 6.9036654148783, 6.411689528397151, 3.979732734816415, 1.6652551059212004, 0.8166254173432077, 0.3686705215701035, 0.03890583411391292, 0.02618615745034601, 0.12229566409119538, 0.14283741611455167, 0.11232394059853894, 0.219597083649465, 0.014559429371729493, 0.529839171894959, 0.8470724778515952, 1.1177019902638026, 1.6487399978297097, 1.8113072173936027, 0.5005975695593017, 0.2697188098515783, 0.02122560336387583, 0.05951064918190241, 0.03622529170076762, 0.29126802352922304, 0.365611305726426, 0.06487108261457511, 0.15228750902627194, 0.07031358485775334, 0.14256617852619716, 0.1917334638003792, 0.1277005619236401, 0.045699506532400846, 0.11116340144404344, 0.22428835263209684, 0.04781068342604807, 0.03335119038820267, 0.13581392727792263, 0.0428168658566262, 0.022066759477768625, 0.06027156513716493, 0.04128587033067431, 0.07015900779515505, 0.05715641765190022, 0.06862187491995947, 0.046672132198831866, 0.16898635083011218, 0.06543142361832516, 0.022371677848111306, 0.012709633497122143, 0.09270413446107081, 0.20052376283066614, 0.11722980306616851, 0.12353605324668543, 0.11303600203245878, 0.1525837438447135, 0.0936589485832623, 0.06576171410935265, 0.09336548218769686, 0.09493616183421441, 0.05645350626270686, 0.027519434657213942, 0.13986195863357612, 0.11178323639822857, 0.012064330579180802, 0.11173819524369069, 0.20620253096733773, 0.38128055206366945, 0.18780167906412057, 0.15521525192473615, 0.17091548017093114, 0.1310293868716274, 0.173828037455678, 0.258582204580307, 0.2901633685188634, 0.42719099138464245, 0.33661943141903194, 0.36223008430429865, 0.27563134687287466, 0.12744501206491674, 0.10633020329156093, 0.13500393288476126, 0.17207958841962473, 0.25866748286145075, 0.12667589262127876, 0.11312859492110354, 0.11237823697073118, 0.21724259427615575, 0.18537460001451628, 0.21625244883554323, 0.1638428382575512, 0.2329732073204858, 0.16221538558602333, 0.1383362862148455, 0.16518183212195123, 0.11468431965581008, 0.2048452166574342, 0.31430078617164064, 0.48804472599710735, 0.32550421357154846, 0.40471280898366657, 0.20802711163248333, 0.4423205038266522, 0.44516063428350855, 0.3183842370552676, 0.29010376600282534, 0.30834696707980974, 0.19867761832262787, 0.2583925133304936, 0.2116886494415147, 0.2581002004444599, 0.19658269573535236, 0.5341617656605584, 0.17913644760847092, 0.8535439648798534, 1.2466411228690828, 0.897132185953004, 1.6929482370615005, 2.252940148115158, 4.319774968283517, 14.71804598399571, 25.743133102144512, 36.97482490539551, 41.042908327920095, 43.93327556337629, 36.43727057320731, 31.467682702200754, 20.313551902770996, 7.149906098842621, 1.4923863134213855, 1.6518112101725169, 3.875147581100464, 3.8222982798303877, 3.8157934631620134, 3.5322014348847524, 2.775043857949121, 3.842412446226392, 6.171557179519108, 11.829540865761892, 13.40822890826634, 15.707999263490949, 23.63081645965576, 34.06308848517281, 31.09450885227748, 50.36035231181553, 64.39956624167306, 61.74154676709856, 40.87544631958008, 44.31100048337664, 34.023667880467, 25.074040685381206, 24.249461480549403, 26.90289514405387, 15.650324004037039, 0.8710396374974931, 0.24217739914144787, 1.1306472441979816, 3.8533458709716797, 4.944459276539939, 0.8339476564100811, 0.16372965861644062, 0.18448139008666786, 19.254054103578838, 21.213763986315044, 24.397253138678415, 25.45696633202689, 28.420425142560685, 40.65454224177769, 37.72670684541975, 38.38765771048409, 48.09390204293387, 61.13395459311349, 71.53957680293492, 45.51532827104841, 28.301921878542217, 11.42059074129377, 7.677492805889674, 4.129591916288648, 4.014947942325047, 2.2639526086194173, 0.6963113876325744, 0.41225182158606394, 0.3331577900264944, 0.3043288455477783, 0.13751274826271193, 0.3209290419306074, 0.7477632867438453, 0.6363622759069715, 0.404921933476414, 0.1323988333876644, 0.6466840963278497, 1.2277408284800393, 1.603448165314538, 3.1981172817093984, 3.1836737138884406, 1.2945228964090347, 0.5346994910921369, 0.100043528846332, 0.16435034173939908, 0.738443092576095, 0.8033537066408566, 0.5047382616571018, 0.26921083139521734, 0.3903355747461319, 0.19521371062312806, 0.4746101126074791, 0.4887680986097881, 0.3986083279762949, 0.2630768748266356, 0.21471035586936132, 0.41951654319252285, 0.22330269909330777, 0.13947436586022377, 0.2788753685142313, 0.18895214875893934, 0.11213654958243881, 0.2663068915052073, 0.15987745246716908, 0.13839630942259515, 0.14503646668578896, 0.2616178888295378, 0.2401371800473758, 0.3361701326710837, 0.24295491884861672, 0.12541773941900047, 0.10898517511252846, 0.19610875259552682, 0.47378284271274296, 0.3867659105786255, 0.5435810802238328, 0.22369269388062613, 0.16148798247533186, 0.17248008692903177, 0.2830924093723297, 0.24744000818048204, 0.22206435911357403, 0.18859082886150905, 0.21149092433708055, 0.31087803840637207, 0.4838884004524776, 0.21856336268995488, 0.3131601688052927, 0.45038258550422533], [0.0060292607356261995, 0.07418061699718237, 0.023529830255678723, 0.021457820099645426, 0.05348059328805123, 0.03532601906252759, 0.06442185850547892, 0.02368048538586923, 0.12464974634349346, 0.10447780269065074, 0.16781647503376007, 0.07791072076984815, 0.06606736699385302, 0.02777657737689359, 0.02140252458463822, 0.048674214232180796, 0.11553991160222463, 0.030761208651321273, 0.07581816626978771, 0.02422262977675668, 0.04883813811466098, 0.07853356841951609, 0.05333608229245458, 0.029043795807021003, 0.06891834722565753, 0.021065974608063698, 0.00503622685625617, 0.07943137881479093, 0.07807714505387203, 0.01917566595199917, 0.06465313716658525, 0.030472529320312396, 0.15588550881615706, 0.10012270709765808, 0.021093141453872834, 0.06741305121353694, 0.024342073992426907, 0.05676213113058891, 0.1666579714843205, 0.1288549942629678, 0.15507604368031025, 0.03296496486291289, 0.08096006392900433, 0.12428762577474117, 0.12552640001688684, 0.04375212799225535, 0.20315657369792461, 0.09046376110719782, 0.18757641900862965, 0.08902524651161262, 0.04537710061829005, 0.050174655326242955, 0.041587336654109616, 0.07111707888543606, 0.1771067322364875, 0.20751730113157205, 1.6458170861005783, 1.3337739216429847, 0.9739789366722107, 0.43765557557344437, 0.22339956675257, 0.34519337277327267, 0.10291559116116591, 0.7861881820218903, 0.5747326229299817, 0.03240462725183793, 0.1744656568127019, 0.21148352830537728, 0.06021457498094865, 0.21760421272899422, 0.9021740268383707, 0.4377511947282723, 0.8688816247241837, 1.973691395350865, 4.300150649888175, 11.790643981524877, 22.657670872552053, 37.179477146693635, 49.86922236851284, 29.253208432878765, 10.798066888536725, 2.2289849306855882, 3.977418984685625, 7.591747692653111, 7.425158551761082, 3.7598769664764404, 1.698737497840609, 1.8947175187723977, 0.0787891454196402, 0.12710528315177985, 1.073700568505696, 0.1455389761498996, 0.10595215072057076, 0.3028387283640248, 7.42489538873945, 11.85758205822536, 2.538595791373934, 2.2656279930046628, 10.865794454302106, 2.43480338369097, 8.79344471863338, 10.264384440013341, 4.930044370038169, 26.590703896113805, 43.55786439350673, 38.82582153592791, 23.97567466327122, 9.904084733554296, 3.874246052333287, 1.3811768123081751, 0.688975446990558, 0.9529862574168614, 0.6587708134736333, 0.32921675007258144, 0.12513317540287971, 0.06866259380642857, 0.06630809086241893, 0.1684380266815424, 0.010275895474478602, 0.06991626189223357, 0.1103689522881593, 0.03598987736872264, 0.04155428860602634, 0.020474281893776994, 0.04708026761987379, 0.04122370295226574, 0.017756135069898198, 0.24117875844240189, 0.10514106388602938, 0.03039199739162411, 0.026792170646201287, 0.03182799801496523, 0.07645493067268815, 0.13240476378372737, 0.08432792499661446, 0.01298235368449241, 0.07547249338988747, 0.05827176637415375, 0.04094892001843878, 0.07334170344152621, 0.017889499431475997, 0.057695296593010426, 0.026049812623698796, 0.07439010789883987, 0.09243554315928902, 0.11430305082883153, 0.033067077597869296, 0.009551500818426055, 0.045435746399951835, 0.016274316369422843, 0.09624528658709355, 0.04643739300913044, 0.05238526813419802, 0.010699220750081753, 0.04470492686544146, 0.10617706472320215, 0.07076607272028923, 0.06107436027377844, 0.02367746251236115, 0.10230552711124931, 0.08998859660433871, 0.04008388625723975, 0.03279084259910243, 0.06816254742443562, 0.03138766271461334, 0.17805961253387587, 0.04934019974565931, 0.07042454568935291, 0.0328236904793552, 0.027200818361182297, 0.16699039936065674, 0.08029323363942759, 0.02461118098082287, 0.03206826726506863, 0.07861630897969007, 0.030383821044649397, 0.08712500919188772, 0.011914906990049141, 0.07144395634531975, 0.14242973870464734, 0.08761377832187073, 0.06573415880224534, 0.04924499110451766, 0.08456387197864906, 0.06627852030630622, 0.033215161080339124, 0.1495344481830086, 0.09289934898593596, 0.01928339186789734, 0.11553480901888438, 0.07693405103470598, 0.09661277436784335, 0.02141505543009511, 0.05247828510722943, 0.05894754654062646, 0.018282651102968624, 0.08907771083925452, 0.026229410665109754, 0.029661296600741998, 0.13408582072172845, 0.08070903311350516, 0.022398586850613356, 0.028825361813817705, 0.0888063714706472, 0.07626629793750388, 0.05450541865346687, 0.05247214436531067, 0.024630375040162886, 0.013237990904599428, 0.059654145767646174, 0.05954872178179877, 0.02777520164714328, 0.05476481241307088, 0.05211474300761308, 0.01690597309997039, 0.0754886968061328, 0.07568726329399006, 0.08991897212607519, 0.0826620129602296, 0.0401222167004432, 0.006383690534026495, 0.029507886618375778, 0.08627101858811718, 0.09434969044689621, 0.07445093856326171, 0.04999292668487344, 0.03681510826572776, 0.0708992216469986, 0.10719580362950053, 0.2456882478935378, 0.16036682549331868, 0.43770519005400793, 0.8606710253017289, 1.101962257708822, 0.6470634788274765, 0.22357348884854997, 0.20228608112250054, 0.17790189385414124, 0.8731810397335461, 0.7046813613602093, 0.171803139682327, 0.08313757779874972, 0.11770731530019216, 0.2553964283849512, 0.08445714520556585, 0.46714552172592705, 1.4703123207603181, 1.842003924506051, 2.8244216654981886, 5.266977284635816, 9.777883734021868, 21.773481334958756, 17.48352803502764, 36.086459500449045, 54.53245721544538, 44.8145364352635, 20.42347240447998, 14.637945413589478, 10.831056066921779, 11.163827879088265, 9.945786084447588, 6.570702527250562, 4.7621563502720425, 4.285298441137586, 0.1493341310748032, 0.0373671711422503, 0.7846786858780044, 0.6250867609466825, 0.17848057565944536, 0.21316442239497388, 10.284759163856506, 18.1534229687282, 9.784248283931188, 9.441851479666573, 9.52744025843484, 15.379142761230469, 16.37917787688119, 12.400627204350062, 20.811669996806554, 37.072975158691406, 51.33704669134957, 52.458489418029785, 31.337237221854075, 15.32331919670105, 6.4515674114227295, 3.1622480750083923, 1.6049836086375373, 1.394044658967427, 1.308067106774875, 0.26002080738544464, 0.03870391905573862, 0.08900417121393339, 0.11188258749565907, 0.08230660310281174, 0.08282710053026676, 0.10755394798304353, 0.25991259462067057, 0.0632162374843444, 0.04529372902054872, 0.14679262387965406, 0.08754011656024627, 0.056248989022736035, 0.049667555572731156, 0.17435205647987978, 0.09076943434774876, 0.0839315994775721, 0.05314354798091309, 0.026024124984230314, 0.08726861434323446, 0.07296770850994758, 0.03513058401378138, 0.05557745309280498, 0.08348672477794544, 0.033107742201536894, 0.030058561890785183, 0.023451089659439664, 0.06082239307995353, 0.018539401968675, 0.04991064413583704, 0.0631820596754551, 0.04538217945290463, 0.08378905284085444, 0.0187430269350963, 0.022098080654229437, 0.026009836733075123, 0.02306028063009892, 0.061100578866899014, 0.09400925585733992, 0.06710425671190023, 0.08377303262906415, 0.07331989532602684, 0.029059168017868484, 0.1248179551746164, 0.08535310998558998, 0.16024637195680821, 0.14219463989138603, 0.016690239676141312, 0.016739282490951673, 0.1028911028323429, 0.019785847049206495, 0.024106395031724657, 0.09096231471214976, 0.15685464681259223, 0.11826367330338274, 0.05563868070021272, 0.0198439042017396, 0.16272052776600632, 0.038263047712721994, 0.015932282133560096, 0.0315228268903281, 0.14400434706892284, 0.06278388854116201, 0.172641537551369, 0.16528971918991633, 0.13483499123581819, 0.21345673528100761, 0.1689813703830753, 0.11307750801954951, 0.239683348685503, 0.16034471882241114, 0.2224508933722973, 0.1345457046159676, 0.32429302856326103, 0.3306880311242172, 0.19530145877173968, 0.17747152623321327, 0.11541683892054216, 0.13880584601845058, 0.2720227890780994, 0.11527522866215024, 0.16486416916762078, 0.07199669097151075, 0.1375525646976062, 0.14024765150887625, 0.20007037930190563, 0.31625884824565476, 0.17933749753449643, 0.1732863493795906, 0.14137342252901622, 0.2846517099865845, 0.150375845176833, 0.1387208934341158, 0.1554703132382461, 0.13656294851430825, 0.20042268825428827, 0.13916537458343164, 0.1119915670050042, 0.18601323717406817, 0.16601246755037988, 0.14080673722284182, 0.25142146168010576, 0.2459730968943664, 0.2315002435020038, 0.17660000228456088, 0.09886029948081289, 0.23013478677187646, 0.22399845533072948, 0.18068474238472326, 0.22441164244498524, 0.1554606780409813, 0.28557025641202927, 0.16201130939381464, 0.1496388611516782, 0.11005473629172359, 0.5501655840447971, 0.3009656188743455, 0.6092695125511715, 0.9178623535803386, 3.3979101266179765, 2.324355036020279, 0.7649557899151529, 0.4533046558499336, 0.4512672594615391, 0.980435984475272, 1.7206313801663262, 1.6894477563244956, 1.3123245068958826, 0.1848029206906046, 0.21828642540744372, 0.2876929039401667, 0.16084832751325198, 0.21373234263488225, 1.0461069920233317, 0.6433415785431862, 1.4130451594080244, 3.240936424051012, 7.599415898323059, 21.253068208694458, 35.949642521994456, 46.945184162684846, 62.34639440264021, 53.27629239218575, 44.39773484638759, 40.86406864438738, 38.41055202484131, 34.21016100474766, 17.00698583466666, 6.601965078285762, 7.812072464397975, 10.155477506773812, 0.15227963802005562, 0.36120707062738283, 2.0199108123779297, 1.2926524196352278, 0.5150539481214115, 0.3188972366707665, 16.312713146209717, 29.209594590323313, 21.301875829696655, 19.864819867270334, 22.31886281285967, 38.00517674854824, 35.9310804094587, 34.566231863839285, 41.59626633780343, 55.42891379765102, 69.25670446668352, 56.927654130118235, 37.61611584254673, 18.654386350086757, 7.842043519020081, 3.8935850603239874, 1.4509320578404834, 1.6426258002008711, 0.7595322323696954, 0.38453562025512966, 0.21625550224312715, 0.14424222787576063, 0.2147889302245208, 0.2869550921022892, 0.2167981674096414, 0.18205845010067734, 0.2759490912514073, 0.1728172374090978, 0.13903033254402025, 0.18575238117149898, 0.12908695824444294, 0.1733254465673651, 0.16608352373753274, 0.2919906633240836, 0.24722423404455185, 0.168056690001062, 0.1462325339338609, 0.1272199691406318, 0.20560901638652596, 0.18393660789089544, 0.1616753667060818, 0.17035220111055033, 0.18975885904261044, 0.159856309315988, 0.21650213615170547, 0.20068936608731747, 0.15126235117869719, 0.16533854656985827, 0.11232411701764379, 0.14983696623572282, 0.18893392330833844, 0.1217523068189621, 0.10958966160459177, 0.07104798366448709, 0.13534598238766193, 0.11680251599422523, 0.30583725603563444, 0.22925562251891407, 0.12564085530383245, 0.1696727161428758, 0.24040767124720983, 0.15858628175088338, 0.24992602478180612, 0.18918176500924996, 0.22026359502758297, 0.24513714175139154, 0.19729339331388474, 0.11642339133790561, 0.2415517084300518, 0.13873936315732344, 0.10558686139328138, 0.22792164981365204, 0.348245124731745, 0.3624062862779413, 0.194841629160302, 0.09917957056313753, 0.27469019166060854, 0.21672161508883747, 0.17593697857643875, 0.15946962577956064, 0.1450027163539614, 0.39295564272574013], [0.04258750066427248, 0.08906162277396236, 0.026514390283929448, 0.08392519410699606, 0.03197035466187766, 0.04762340097555092, 0.0558222820982337, 0.028041662348966514, 0.03500578785315156, 0.05313168379611202, 0.08875255685831819, 0.09906497956918818, 0.01666475729351597, 0.062481424771249294, 0.015266788557970097, 0.0623982838754143, 0.014682317152619362, 0.05717574232923133, 0.00795603174317096, 0.012844723033984857, 0.028476876406265155, 0.03435425174289516, 0.10615300387144089, 0.02508579587031688, 0.012504293533441211, 0.07018063270619937, 0.0269740994554013, 0.04184645899970617, 0.06214403001857655, 0.016569731856829355, 0.024022502658356513, 0.07559264158563954, 0.025051763946456567, 0.05506198360983815, 0.01212591611381088, 0.08048532011785678, 0.06516739885721888, 0.08277857849108321, 0.032962705341300795, 0.043466844729014804, 0.048334112124783654, 0.07982229640973465, 0.03600577883688467, 0.02358576698627855, 0.06085710693150759, 0.013735391848188425, 0.11555447296372481, 0.07338148594966956, 0.07116114294954709, 0.14263044936316355, 0.03467665087165577, 0.02160032093524933, 0.025916841812431812, 0.14339863242847578, 0.041698908167225976, 0.07953168664659772, 0.1717903832239764, 0.05584071450201528, 0.08821479749998876, 0.12365945162517683, 0.031169700303247998, 0.05461020142372165, 0.07336423758949552, 0.07031414804181882, 0.09742524541382279, 0.061931947113147805, 0.040544458864522834, 0.013975743370662843, 0.07697943824210338, 0.03988231385924986, 0.21625001968017646, 0.25515052729419296, 0.20029668430132525, 0.3427276579397065, 0.1409082053495305, 1.5256768699203218, 11.831583636147634, 30.955871445792063, 48.611212798527305, 38.43939052309309, 12.804155128342764, 2.8294330537319183, 5.8815419759069165, 4.996083523545947, 9.661998203822545, 7.040200991289956, 7.725904379572187, 5.831874081066676, 0.9772725999355316, 0.6846599642719541, 0.028185372673241154, 0.3780627761568342, 0.12749375802065643, 6.361643825258527, 13.376358389854431, 14.020912374768939, 18.279006447110856, 18.833549124853953, 10.63889581816537, 9.543244804654803, 7.6492657491139004, 3.5204555051667348, 6.286752232483455, 32.91234867913382, 39.25657858167376, 39.57650491169521, 18.959210770470754, 6.414469242095947, 1.6165358573198318, 0.6003491654992104, 0.7223830914923123, 0.4336537660232612, 0.2905500791966915, 0.2035641289715256, 0.12821296442832264, 0.08505996928683349, 0.10604577498244387, 0.04039677232503891, 0.010385009842658681, 0.13216636729027542, 0.18997288255819253, 0.0738709946828229, 0.03880134650639125, 0.05525678422834192, 0.032981317556862316, 0.02048385771922767, 0.07386489465300526, 0.08021840479757104, 0.11719492636620998, 0.014899972526888763, 0.05143110540562442, 0.036595137390707216, 0.040995331813714335, 0.012113334378227592, 0.022406354380239333, 0.025831797625869513, 0.0009132929740839504, 0.014557225829256433, 0.041537382906036716, 0.014805060744817768, 0.015659343118646314, 0.02745985928257661, 0.05285350479451673, 0.006083624961320311, 0.029422292818448374, 0.04705600660028202, 0.03565895584012781, 0.047092979973448176, 0.04653879328231726, 0.03667606286970632, 0.00952522030898503, 0.02825110236049763, 0.046339731463896375, 0.06129375778670822, 0.03392258133473141, 0.012301694003066846, 0.0445318563309099, 0.03634645091369748, 0.044362205612872324, 0.02535540158195155, 0.052078644944620986, 0.028900010843894312, 0.0473244520170348, 0.045702383520879915, 0.04822134639003447, 0.013357965225752975, 0.08047262472765786, 0.06603709754667111, 0.029113427070634704, 0.00868959425549422, 0.04209488084805863, 0.08791497323129858, 0.05155474805672254, 0.07840023628835167, 0.07023353808160339, 0.034355931117066314, 0.014035273792355188, 0.08975496342671768, 0.05280079958694322, 0.07618860567786864, 0.03047909414661782, 0.018530728594799126, 0.03266582591459155, 0.05416306380980781, 0.056542910036763976, 0.07400203336562429, 0.027256583761689917, 0.09600163144724709, 0.0013832802547507786, 0.03883871003719313, 0.06053284861679588, 0.08496897774083273, 0.054830396215298345, 0.030800458509474993, 0.024186519839401757, 0.04397176977779184, 0.012266121804714203, 0.061075133803699694, 0.14936075678893498, 0.030148912221193314, 0.02042865889546062, 0.035623498992728334, 0.028315547920231308, 0.08573404633040939, 0.06970468110271863, 0.08472950237670115, 0.02287114577900086, 0.07924928037183625, 0.030387888862086192, 0.043398597676839144, 0.04713407883952771, 0.06316925571965319, 0.05065945163369179, 0.018516157055273652, 0.034825979465884824, 0.011237651009910872, 0.11146932574255125, 0.04718775774485298, 0.0677883896444525, 0.08167802183223621, 0.025355191236095767, 0.0784192963370255, 0.02184283613626446, 0.03336142948163407, 0.07415992167911359, 0.016075626048924666, 0.041823402379772494, 0.02819970333283501, 0.06790650223514863, 0.04541630976434265, 0.06993224139192275, 0.04325783219454544, 0.13621481933764049, 0.20281704834529332, 0.154984889285905, 0.11147610430738755, 0.05524602944829634, 0.026476582312690358, 0.09677102909024272, 0.2627682771001543, 0.05902737618557044, 0.046332213295889754, 0.05167778681165405, 0.015193973268781389, 0.10882045395140137, 0.1976123047726495, 0.3304355618144785, 0.40491281396576334, 0.28337207436561584, 1.2713909319468906, 4.198555392878396, 11.02479268823351, 22.278021301542008, 38.00791433879307, 55.00138766424996, 43.506833348955425, 23.425097669873917, 8.809455973761422, 6.814131362097604, 12.678245084626333, 12.677691834313528, 7.83489555971963, 8.82006413596017, 8.578005399022784, 7.0483859692301065, 0.3438126897173268, 0.061988536933703084, 0.28142313180225237, 0.178982175886631, 13.560408353805542, 26.44200028691973, 18.328175374439784, 19.40467194148472, 9.809026428631373, 11.901726569448199, 15.512317146573748, 12.91402872971126, 9.670869316373553, 19.675107989992412, 47.32529926300049, 52.22669403893607, 40.94411884035383, 25.053336790629796, 10.709425245012556, 3.1974626311234067, 1.2871860329593932, 0.5175492742231914, 0.5144241590585027, 0.49937761787857327, 0.16005807848913328, 0.0404200698249042, 0.038015735269125016, 0.0755625960550138, 0.0451535199369703, 0.03629571685035314, 0.07410135053630386, 0.0533846687924649, 0.0811579790232437, 0.03368107036554387, 0.030988958930330615, 0.07503759315503494, 0.032171669216560464, 0.05365409469231963, 0.08194161911628076, 0.1757508157087224, 0.059727217203804424, 0.010304708615876734, 0.06703513434955052, 0.062493604474834034, 0.028140801404203688, 0.04861248790153435, 0.050301232641296725, 0.019813527885292257, 0.0509482123889029, 0.062468179767685275, 0.06123410777321883, 0.012050394318066537, 0.03245919503803764, 0.04200403518708689, 0.023694244379709874, 0.06093327248735087, 0.028906097303011587, 0.037500622017042975, 0.06267657822796277, 0.01765554055704602, 0.02545524631360812, 0.033055213413068225, 0.04421437997370958, 0.08260929078928061, 0.0628471008634993, 0.03640762763097882, 0.011744290207778769, 0.05185723557536091, 0.02178833111455398, 0.02999488477196012, 0.101711775043181, 0.029170644536082233, 0.0813711882968034, 0.0796436992074762, 0.0555678993197424, 0.02003360054056559, 0.04223986342549324, 0.09196823609194585, 0.09554800364587988, 0.05310699190678341, 0.0526016020615186, 0.06726447918585368, 0.08761948480137757, 0.1286127979734114, 0.11295080517551728, 0.09151855057903699, 0.02089416784500437, 0.08941796900970594, 0.18884086901588099, 0.16507136662091526, 0.19016570863979204, 0.13743251828210695, 0.09206162965191261, 0.14981837437621184, 0.17505889997950622, 0.3359538157071386, 0.25717785422291073, 0.24920259788632393, 0.22194003792745726, 0.09530158686850752, 0.2228890505752393, 0.1921066173485347, 0.09227725451013871, 0.08784165752253362, 0.1726241670548916, 0.12155076834772315, 0.13643860018679074, 0.19496608605342253, 0.09865407233259507, 0.2804394731564181, 0.09559793025255203, 0.13306519548807824, 0.31124954989978243, 0.17857611339007104, 0.17217575040246758, 0.1716994731021779, 0.12901301149811062, 0.10376369208097458, 0.2009995108736413, 0.1645995540810483, 0.11716218026621, 0.13671956796731266, 0.1418539203171219, 0.1272405558930976, 0.1700865953628506, 0.1279262291001422, 0.11185028922877141, 0.22235817834734917, 0.19173699218247617, 0.18791937774845532, 0.250531223735639, 0.1998173807348524, 0.17538676810051712, 0.14768203401139804, 0.20417124139411108, 0.14650881982275418, 0.24428007059863635, 0.13803158327937126, 0.10247309133410454, 0.16901820126388753, 0.21714218466409616, 0.12789143382438592, 0.17884854520005838, 0.41846117696591784, 0.41780269944242066, 0.18685403705707618, 0.16902943780379637, 0.1855145682181631, 0.17824376693793706, 0.23757454327174596, 0.24040373574410165, 0.35968324382390293, 0.26714165242654936, 0.17963764071464539, 0.12247249031705515, 0.11955811455845833, 0.128510393468397, 0.15283450324620518, 0.18851534862603458, 0.17071316816977092, 0.5722036957740784, 2.0030755443232398, 8.706197925976344, 22.927990538733347, 44.9199093409947, 60.950709751674104, 55.91721929822649, 40.75371388026646, 26.89169464792524, 23.83029576710292, 38.23312629972185, 31.91480622972761, 28.438116993222916, 21.677822010857717, 22.263912984303065, 20.748769692012242, 0.5820773573858398, 0.20100139720099314, 0.8372386598161289, 0.6047945469617844, 19.418528386524745, 40.26533194950649, 40.599192891802105, 50.906286171504426, 37.93282515662057, 25.403689282281057, 28.849366971424647, 27.68105169704982, 28.997413975851877, 40.166695322309224, 66.4693512235369, 58.63381208692278, 52.00976780482701, 27.074592079435075, 9.433643051556178, 2.0084299998623982, 1.0243999511003494, 1.3127141488449914, 0.600287445953914, 0.42183382170540945, 0.21191784500011376, 0.23955724973763737, 0.12690112553536892, 0.1419203896075487, 0.13824054492371424, 0.17760914670569555, 0.1990070335034813, 0.3774433008262089, 0.13829178788832255, 0.12016346278999533, 0.13713939115405083, 0.10927277896553278, 0.07921856987689223, 0.1758110017648765, 0.14684816875628062, 0.22802128589579038, 0.1339214795402118, 0.15761315396853856, 0.141043396666646, 0.1601032010678734, 0.08870876420821462, 0.12393184272306305, 0.10420853963920049, 0.10802233392106635, 0.13819881502006734, 0.17518525677067892, 0.16567899473011494, 0.2098039234323161, 0.17397575452923775, 0.145049711689353, 0.12141909184200422, 0.11933560935514313, 0.22774433504257882, 0.13273332401045732, 0.28515124746731346, 0.12407231304262366, 0.07454857296709504, 0.2251974402793816, 0.1644266497875963, 0.25405314617923325, 0.12405122417424407, 0.12403766704457146, 0.1101001099284206, 0.20038280396589211, 0.15486303796725615, 0.22167458145746163, 0.26552828614200863, 0.18243708621178353, 0.25270514136978556, 0.22024997004440852, 0.2726195470563003, 0.1340774611702987, 0.11738042426960808, 0.2189904733427933, 0.1470432747155428, 0.1440856491348573, 0.26768059922116144, 0.26529242736952646, 0.19030862168541976, 0.22455408051609993, 0.17762136033603124, 0.11882659952555384, 0.11510429212025233], [0.02849642839282751, 0.087389434288655, 0.07458638772368431, 0.028539121816200868, 0.07829513799931322, 0.037801742287618775, 0.027860714022868445, 0.038207672469850094, 0.07886222364114863, 0.07337308568613869, 0.019259195309132338, 0.078638028885637, 0.06351923051157168, 0.041759518307766745, 0.00664901511377788, 0.07977010349610023, 0.04436760335894568, 0.08101704051452023, 0.03873739458088364, 0.04358434324551906, 0.05383294973788517, 0.057561726974589486, 0.12856523266860417, 0.08423525746911764, 0.024662064321871315, 0.030630013905465603, 0.10712552097226892, 0.031054474879056215, 0.010082937926719231, 0.021006906438352804, 0.0275343912653625, 0.01823639706708491, 0.04314005208600845, 0.04330259854240077, 0.10637761253331389, 0.0041073518555744416, 0.027508764694045697, 0.032903961172061305, 0.01701904078280287, 0.02989092981442809, 0.04716714724366154, 0.10559315819825445, 0.04205693716981581, 0.017747329381693686, 0.07605658311929021, 0.0668739890679717, 0.08711831205125366, 0.04826577007770538, 0.10034653544425964, 0.03925012617505022, 0.07620163355022669, 0.026247247654412473, 0.061446516375456534, 0.026169982871838977, 0.022301395190879703, 0.05003464301781995, 0.022603163462398306, 0.029981419244515042, 0.20088358995105537, 0.011399561339723212, 0.028076530567237308, 0.054141751024872065, 0.09837299598647015, 0.037515342834272554, 0.03939635386424405, 0.0692367497831583, 0.05308892930458699, 0.02320182473132653, 0.061579624590064795, 0.0963613296459828, 0.11728361089314733, 0.09005830250680447, 0.08795180411211082, 0.560098685324192, 0.16042155612792286, 1.3456987674747194, 8.333887389728002, 23.256384985787527, 33.82546704156058, 39.55059507914952, 17.074713400432042, 6.2123439737728665, 2.785061206136431, 3.7484285065105984, 4.27690805707659, 1.6417993988309587, 3.2088631050927297, 5.0725332498550415, 7.8857251065117975, 10.388825808252607, 10.075997931616646, 7.645727378981454, 14.463016697338649, 21.14396412031991, 21.687952484403336, 20.223409448351177, 19.457275015967234, 15.81955085481916, 13.177957790238516, 7.9545470135552545, 4.955236366816929, 3.8257793273244585, 15.958794491631643, 31.240007604871476, 43.734727314540315, 22.56252745219639, 10.636283295495168, 3.0400774649211337, 0.6858080455235073, 0.851752903844629, 0.24356017208525113, 0.13785133723701748, 0.20274745779378073, 0.08726002408989839, 0.0957342954352498, 0.09112464064466101, 0.024912267324647734, 0.021525464951992035, 0.05351581943354436, 0.06901055334934167, 0.031064574872808795, 0.02837000205181539, 0.024529858558837856, 0.056866191261048825, 0.003567666730045208, 0.044155489919441085, 0.058154997282794545, 0.11438321295593466, 0.04532870750076004, 0.05338670100484576, 0.019590647791379263, 0.044258532247373035, 0.034038855095527, 0.0477153322925525, 0.04352038114198616, 0.04895137203857303, 0.007254983780772558, 0.020076080225408077, 0.0630805983341166, 0.027806946907990744, 0.13392869915281022, 0.05581745771425111, 0.050683369993099144, 0.04821797067831669, 0.02123589674010873, 0.05611734305109296, 0.09648630222571747, 0.0385078326133745, 0.022677120386755893, 0.007172528205306402, 0.04201938704188381, 0.03733289833845837, 0.05079687533101865, 0.059289426409772465, 0.03824852706332292, 0.056081241595425775, 0.03950693810890828, 0.038108396011271646, 0.0431937920594854, 0.07491995553885188, 0.04502832004800439, 0.046227393206208944, 0.037770780734717846, 0.03427760781986373, 0.02198194938578776, 0.047567384517086406, 0.058831910602748394, 0.04072338515626533, 0.10499236972204276, 0.043322781566530466, 0.08379317154841763, 0.04747712918158088, 0.0626961878900017, 0.038153912140322585, 0.02679844370244869, 0.011565424136019178, 0.01536372915974685, 0.04618066928482481, 0.038875703766409836, 0.09793860465288162, 0.14897600029196056, 0.06481380068830081, 0.027126710462783064, 0.15583460511905806, 0.1800830446715866, 0.06973386489387069, 0.014155284584765988, 0.0465236144539501, 0.04440336554710354, 0.05052455887198448, 0.10020475555211306, 0.022249743408922638, 0.01509214042952018, 0.0263970156000661, 0.08327416689800364, 0.019400673253195624, 0.09351237823388406, 0.10380698261516434, 0.10517673447195973, 0.12139448816222803, 0.039362569605665546, 0.01007144184716578, 0.05845586649541344, 0.025862112874165177, 0.08463532850146294, 0.06241101997771433, 0.030631533823907375, 0.05366052720429642, 0.04380521996478949, 0.04846198204904795, 0.045156383354748995, 0.03172744930322681, 0.009159517923503049, 0.026752812222444584, 0.03205343448956098, 0.03217186938439097, 0.025740049513322965, 0.05166629242843815, 0.026770618677671467, 0.04076459598062294, 0.051039214112928936, 0.03270835309688534, 0.03259366371535829, 0.038850916882178614, 0.016392454405182173, 0.0906142805303846, 0.035042706943516216, 0.01605694767619882, 0.07089768815785646, 0.03912882446976645, 0.010684801880935473, 0.044991475596491776, 0.036996545137039254, 0.02283777203410864, 0.13209365547767707, 0.028945954450006996, 0.022267047748235718, 0.09552342032215425, 0.11899286774652344, 0.015505397093615361, 0.07010387003953968, 0.01676973683892616, 0.034310679616672654, 0.06562930478581361, 0.03548321866297296, 0.05753934210432427, 0.12689436732658319, 0.01963036074968321, 0.13823485880025796, 0.4795343226620129, 1.237395350422178, 5.249999795641218, 16.586506911686488, 34.788945947374614, 52.22037465231759, 46.49456916536604, 21.813659293310984, 6.734928412096841, 4.8202758601733615, 6.5405577676636835, 10.337700094495501, 10.152633956500463, 15.350200039999825, 12.888016411236354, 20.02957555225917, 24.099335227693828, 18.185271774019512, 17.384835822241648, 27.246426241738455, 33.90375934328352, 31.587080546787806, 32.91015304837908, 31.366735798971995, 22.87305634362357, 13.166703445570809, 12.350335274423871, 9.274932299341474, 12.257322345461164, 27.572371448789323, 44.7431297983442, 49.10997186388288, 37.36164501735142, 17.00173125948225, 6.563517221382686, 1.8881747041429793, 1.1517187420810973, 0.48280529571431025, 0.28186903787510736, 0.14520961525184767, 0.16173582417624338, 0.026126561719658117, 0.06600036844611168, 0.02865937179220574, 0.05766685240502868, 0.030802921591592685, 0.03704685850867203, 0.08030687897865262, 0.03765539246212159, 0.013826374064332672, 0.02198222079979522, 0.0427999499786113, 0.02023538158807371, 0.019104767524238144, 0.06823558493384294, 0.08776151575148106, 0.04918628086202911, 0.09671022556722164, 0.0014867489995335095, 0.06252708339265414, 0.015281312600044268, 0.03716292531628694, 0.08676748909056187, 0.03098764257239444, 0.0175651613888996, 0.0490593201746898, 0.018437246825279932, 0.01667876904165106, 0.004576603349830423, 0.08026618723358427, 0.10649129429033824, 0.03901980085564511, 0.04425167565100959, 0.009750424385336893, 0.010958108152928097, 0.038576758200568814, 0.04669687497828688, 0.015668167466563836, 0.05115507736003824, 0.037424707519156594, 0.06112254983080285, 0.017083812039345503, 0.017610818313966905, 0.016314740093158822, 0.037653892899730375, 0.0816704493814281, 0.0700343744829297, 0.029799768634672676, 0.05280022622485246, 0.10097279612507139, 0.05980879746909652, 0.035598450872514925, 0.017490634495126348, 0.07112801686993667, 0.0712183638076697, 0.007978827127122452, 0.03216410694377763, 0.027765352711347595, 0.1670248553689037, 0.04932691742266927, 0.038463422496403964, 0.0017548139065703644, 0.005078008922282606, 0.1600923987903765, 0.1314290982804128, 0.14674006455710956, 0.09067665146929876, 0.1793004630931786, 0.15837399528494903, 0.1000215443117278, 0.3007660210132599, 0.48713500052690506, 0.19682163505681924, 0.15465734686170304, 0.19872051530650683, 0.12212655959384781, 0.1052526557551963, 0.14170742460659572, 0.13182981392102583, 0.2013678468231644, 0.11720567436090537, 0.11428777022021157, 0.11815893463790417, 0.24067373839872225, 0.20709150683666977, 0.28313515707850456, 0.20224177278578281, 0.31765918167574064, 0.1404423639178276, 0.16741209530404635, 0.13454617959048065, 0.11151483508625201, 0.1444827685398715, 0.09152789400624377, 0.09916792011686734, 0.182590177282691, 0.12561660446226597, 0.18205507099628448, 0.0700621876333441, 0.08275946415960789, 0.1535724779324872, 0.11553672248763697, 0.18071724421211652, 0.09512554774326937, 0.19310543446668557, 0.09138929644333464, 0.12361104493694645, 0.19612830797476427, 0.21415040163057192, 0.138019858194249, 0.1380355187824794, 0.13082916475832462, 0.1589106893432992, 0.16001301019319467, 0.13714038181517804, 0.14955696197492735, 0.09602560408945594, 0.10993158897118908, 0.18368044735065528, 0.07848947721400432, 0.18398774228990078, 0.28176310498799595, 0.10963467561772891, 0.1799436192959547, 0.1626311239919492, 0.21859853794532164, 0.24624179676175117, 0.2218852937221527, 0.13272595512015478, 0.21120200412614004, 0.15246079329933437, 0.13514451176992484, 0.16375343448349408, 0.14559203758835793, 0.19217368374977792, 0.17796100782496588, 0.42183346886719975, 0.7616712461624826, 3.920015139239175, 16.56207878249032, 33.24000835418701, 54.95365701402937, 61.3357789175851, 41.49230391638619, 34.221962520054404, 22.4550336088453, 21.437699215752737, 29.648283004760742, 32.67441804068429, 41.187416962214876, 35.93988725117275, 42.52797113146101, 38.69138084139143, 23.321310690471105, 20.646443571363175, 33.26258652550833, 47.16229452405657, 50.93831736700875, 55.54348611831665, 49.23885399954659, 36.55306577682495, 23.36613699368068, 26.730763946260723, 28.041010073253087, 33.26046732493809, 49.242383684430806, 58.25207110813686, 62.96122659955706, 37.00706802095686, 16.812589134488785, 4.594258342470441, 1.3141235475029265, 1.3310769349336624, 0.8435244453804833, 0.38900952732988764, 0.176325439874615, 0.1934484610600131, 0.21790090895124845, 0.22264267450996808, 0.1253998125238078, 0.14374824081148418, 0.1385451392935855, 0.13686776001538548, 0.12537675590387412, 0.14648264194173471, 0.2054982523300818, 0.0897251350272979, 0.10762516023325068, 0.0968253593891859, 0.10408774683518068, 0.1661266649940184, 0.16088956887168543, 0.1173849840249334, 0.24481082069022314, 0.14704263689262526, 0.10223236746553864, 0.0751360689422914, 0.07637202726410967, 0.13999354014439241, 0.06930015209530081, 0.2309240044227668, 0.15028994264347212, 0.13299757268811974, 0.2745490020939282, 0.07575631101748773, 0.17840476972716196, 0.2146907869194235, 0.10053131410053798, 0.11286988308919327, 0.14325703574078424, 0.18767152247684343, 0.1459288080888135, 0.13367582272206033, 0.09017940065158264, 0.12510189493852003, 0.2079048396221229, 0.16028108580836228, 0.13166897398020538, 0.10746207434151854, 0.16677390597760677, 0.1065802230898823, 0.17794331163167953, 0.18386251186685904, 0.15870351903140545, 0.16488519018249853, 0.13259444146284036, 0.13903145891215118, 0.08668290291513715, 0.16183138904826982, 0.1414941746209349, 0.21638864438448632, 0.17484269158116408, 0.18720923656863825, 0.3336184067385537, 0.31043167092970436, 0.1471483933606318, 0.09874865332884447, 0.061117732232170444, 0.10990174700106893], [0.04900278463693602, 0.07028419750609569, 0.13672567478248052, 0.079254729008036, 0.015765145387766615, 0.013221391393536968, 0.11525223989571844, 0.09762750991753169, 0.046973791904747486, 0.05150652796562229, 0.059157105295785835, 0.04157811536320618, 0.08915866006697927, 0.05151751344757421, 0.03988283293853913, 0.09325282501855067, 0.027866378093936613, 0.03198604578418391, 0.04315169574692845, 0.0777508986315557, 0.10954818954425198, 0.054953061775969606, 0.14531541243195534, 0.1743836762117488, 0.1568799154566867, 0.08065285041396107, 0.010720228194259107, 0.025811796109857302, 0.04852821724489331, 0.010635781118513217, 0.0678377394963588, 0.02288658245067511, 0.011210932845382817, 0.05328733633671488, 0.05174980312585831, 0.01211739965115807, 0.1148937019918646, 0.03101410883079682, 0.04886668747557061, 0.026001024259520427, 0.03818390678082194, 0.09667663808379855, 0.03199116872357471, 0.05454337590241006, 0.019219063355454376, 0.0513825189056141, 0.04849985448111381, 0.032277181411960294, 0.03333702936236348, 0.004650882154237479, 0.0640097027644515, 0.04188333398529461, 0.0342141647956201, 0.09147457472447838, 0.037287487382335324, 0.013711127435921558, 0.020400095963850617, 0.05406307488945978, 0.05048795869307859, 0.07570255068796021, 0.05498582823202014, 0.059004753828048706, 0.07196078289832387, 0.05133455326514585, 0.04469419244144644, 0.028179367638326118, 0.03960334436435785, 0.04254223559317844, 0.039168369490653276, 0.023116400565153787, 0.07162472485963788, 0.08899041052375521, 0.22769531767283166, 0.21767214765506132, 0.14800935930439404, 0.5243555775710514, 7.4957340104239325, 13.996505090168544, 31.18994583402361, 24.48139582361494, 25.328742538179668, 10.594996230942861, 1.1380959302186966, 5.568315012114389, 5.559312318052564, 1.0200778458799635, 0.643696588064943, 3.289349300520761, 10.696168082101003, 16.382116964885167, 17.071920224598475, 16.272556032453263, 25.938375745500835, 28.44781494140625, 28.997486931937082, 22.670351334980555, 22.958329847880773, 12.774072902543203, 3.9390623228890553, 4.275287824017661, 1.085288209574563, 6.908970364502498, 21.667750597000122, 38.640433175223215, 31.151821068355016, 21.644736426217214, 6.750006003039224, 2.158947523151125, 0.2873241337282317, 0.15247948015374796, 0.13865998813084193, 0.19633185490965843, 0.039379071577319076, 0.09001855392541204, 0.01229271528843258, 0.04461295483633876, 0.031054600408034663, 0.019124616369871155, 0.037187661310391765, 0.01850577038047569, 0.0759315833981548, 0.011620290477627089, 0.004443023977468589, 0.03906037385708519, 0.04146003669926098, 0.08806136716157198, 0.013739994860121181, 0.11829146609774657, 0.05135817985449519, 0.06653648574969598, 0.03243723425215908, 0.012974436028993555, 0.01980033716452973, 0.054222737572022846, 0.04936653029705797, 0.07375435451311724, 0.02347553218714893, 0.0366761748279844, 0.03705590677314571, 0.1096387468278408, 0.03166296812040465, 0.02507557374026094, 0.04778799321502447, 0.055603977026683946, 0.06582880086664643, 0.053202478747282705, 0.04777596957449402, 0.035466882932398996, 0.025165092865271226, 0.04700137435325554, 0.01182157704274037, 0.031575817082609446, 0.01927536310228918, 0.02472364985650139, 0.010019772253664476, 0.03270057030022144, 0.058028213014560084, 0.0947781785258225, 0.06550085810678345, 0.0950093146945749, 0.08608047916953053, 0.07910406030714512, 0.06398526871842997, 0.016760483317609345, 0.06476725997137171, 0.08134086456682, 0.021015260900769914, 0.023514285018401485, 0.0946189806397472, 0.04972291724490268, 0.0572811323883278, 0.0871121170265334, 0.05702719744294882, 0.04252575397757547, 0.05419418481843812, 0.02185786229425243, 0.019135433914405958, 0.029856914853943244, 0.04589862941897341, 0.0239590782938259, 0.08771036099642515, 0.03639858954453042, 0.12591990961560182, 0.05026768247729965, 0.07316060244504895, 0.02746783715805837, 0.10187758864568812, 0.056698121529604704, 0.045332663359918764, 0.08022151927330665, 0.024785121736515845, 0.03187377877267344, 0.057850077216114314, 0.04978048076320972, 0.13217186342392648, 0.10470699146389961, 0.10044251422264747, 0.11096332860844475, 0.19155803535665783, 0.04371929368270295, 0.06444106783185687, 0.05909174880278962, 0.010002599380511259, 0.04591354022600821, 0.021279312803276947, 0.0031536458658852746, 0.03681225502597434, 0.023967980673270564, 0.07596006829823766, 0.04110261159283774, 0.007223313158777143, 0.023755164950021675, 0.019094172199921947, 0.039107660962534804, 0.060845320778233666, 0.058021536229976585, 0.012902169505001178, 0.07751976924815349, 0.048788180973912985, 0.07208414735006434, 0.054429042751767805, 0.0931076660220112, 0.04996962579233306, 0.03883742082065769, 0.05528784756149564, 0.0678642023620861, 0.03502105489107115, 0.025939525238105228, 0.06669247416513306, 0.04458205435158951, 0.025256966506796222, 0.029659264388361146, 0.06601691791521651, 0.14275763396705898, 0.015771503260891353, 0.02405919274315238, 0.08470486477017403, 0.004265654499509505, 0.06769167804824454, 0.06208659881459815, 0.016608427012605325, 0.04619006699483309, 0.09246050646262509, 0.043794882483780384, 0.02075363815362964, 0.0742713642705764, 0.14550271523850306, 0.05851896346679755, 0.09279277149055686, 0.35001971093671663, 0.5764207094907761, 2.096832799060004, 10.337056517601013, 22.476911749158585, 43.08648817879813, 41.67150143214634, 31.91524396623884, 16.288689749581472, 5.806623458862305, 2.7200621111052374, 8.325955152511597, 6.7684126496315, 10.20506419454302, 14.949302877698626, 26.725521530423844, 38.55307000023978, 31.43200717653547, 34.14235700879778, 40.39001737322126, 44.942133154187886, 40.947457449776785, 35.603900160108296, 30.81855767113822, 23.349848679133824, 9.362827011517115, 7.536543386323111, 10.442006451742989, 20.842667647770472, 31.891710417611257, 45.47600841522217, 43.74917261941092, 23.04715735571725, 11.326501710074288, 3.5969108768871854, 0.5444796777197293, 0.38739605247974396, 0.12754631734320096, 0.09809106468622174, 0.09389256819018296, 0.030855124683252404, 0.02829593656185482, 0.04533479056720223, 0.05410194816067815, 0.041739158864532194, 0.029775042818593125, 0.014045539179018565, 0.03635377569922379, 0.021333627835182205, 0.019564064485686164, 0.0377075955537813, 0.046728555778307576, 0.012239239095444126, 0.052524181215890815, 0.03189184476754495, 0.06632041984370776, 0.0313798459911985, 0.016279412167412893, 0.06734173039772681, 0.03894532145932317, 0.05844306932496173, 0.04548314885635461, 0.04919046403041907, 0.06650182618094341, 0.014284434395709207, 0.037326604926160405, 0.12353726103901863, 0.021398195531219244, 0.03964023631332176, 0.06660353858023882, 0.007987997527899486, 0.026945126010105014, 0.0577865799090692, 0.02578388966087784, 0.06390984276575701, 0.03338413326335805, 0.03583844531593578, 0.0060238710471561974, 0.030318101535418203, 0.033175202153090916, 0.030554513313940594, 0.03576695825904608, 0.039308989087917974, 0.052039449369268756, 0.18117729095476015, 0.06876678964389221, 0.10806908498385123, 0.1010860436196838, 0.0846390604440655, 0.1272682672632592, 0.13063530730349676, 0.06055118941834994, 0.02887358869026814, 0.04727576034409659, 0.021535644673609307, 0.1275941947741168, 0.05731799719589097, 0.027683212654665112, 0.11406089525137629, 0.006355650922549623, 0.01413498620968312, 0.031131179870239327, 0.013110778311134448, 0.15183871239423752, 0.16413550398179463, 0.23543346673250198, 0.1375771683773824, 0.13229195055152687, 0.1983134350074189, 0.24675441639763968, 0.33610390765326364, 0.29662161054355757, 0.17219203524291515, 0.16825677640736103, 0.20611486424292835, 0.1264182800160987, 0.18289804219135217, 0.13534929363855294, 0.16962935775518417, 0.11721480744225637, 0.17154712841979095, 0.2388353699019977, 0.13837087793009623, 0.22278485473777565, 0.32873208607946125, 0.39400354506714, 0.28703496924468447, 0.23782676830887794, 0.18532978956188473, 0.1654092227774007, 0.07769005439643349, 0.15207288839987346, 0.09990152503762927, 0.10363471614462988, 0.12529962004295417, 0.08550182450562716, 0.2874581308237144, 0.0976097323000431, 0.08857595454901457, 0.24943476542830467, 0.08762462131146874, 0.12923035983528408, 0.0922412717980998, 0.13160876078265055, 0.25430252136928694, 0.13263334866080964, 0.14674324010099682, 0.16310436145535537, 0.13042751273938588, 0.13551656609135015, 0.2521598706287997, 0.12515914972339356, 0.13849270210734435, 0.23491607021008218, 0.10069730412214994, 0.17973746678658895, 0.16800103655883245, 0.09935977589339018, 0.15073441022208758, 0.17749432500983986, 0.25907229685357636, 0.11136822402477264, 0.10136709282440798, 0.20432950290186064, 0.12511881760188512, 0.1263684755457299, 0.18635825866035052, 0.33637754725558416, 0.19069527808044637, 0.14656382187136582, 0.2335319130548409, 0.12826659583619662, 0.1871988142707518, 0.15858679743749754, 0.1409988711987223, 0.2242122481444052, 0.27144066031490055, 0.3351370766758919, 1.8971893404211317, 10.547866599900381, 22.216623544692993, 47.01585776465279, 48.75587429319109, 53.939192226954866, 40.401586123875205, 30.424191815512522, 21.183228390557424, 25.552974803107126, 28.34020471572876, 35.865357398986816, 45.18683481216431, 49.39967005593436, 56.786293029785156, 43.15886756352016, 44.64064734322684, 53.34158114024571, 62.45436940874372, 58.72620228358677, 54.876990590776714, 47.984898703438894, 35.6078919001988, 22.90383165223258, 22.352400030408585, 31.82532732827323, 39.93031760624477, 55.22296919141497, 65.8696938923427, 47.24622876303536, 25.56271617753165, 9.950372764042445, 3.1300753099577765, 0.38718817649143084, 0.6536581878151212, 0.4331618552761418, 0.2049608661660126, 0.12444698650922094, 0.167567303404212, 0.14258124200361116, 0.14826995746365615, 0.14976570648806437, 0.0891700933820435, 0.09608996992132493, 0.1417349866990532, 0.21057159081101418, 0.2111680502338069, 0.12075443964983736, 0.20508435953940662, 0.20744967833161354, 0.26835511731249945, 0.17089390275733812, 0.19367126481873648, 0.16095974296331406, 0.18391129853469984, 0.03286700815494571, 0.12606548251850264, 0.0901985556951591, 0.2574209597493921, 0.16796473493533476, 0.1687110691730465, 0.1411308462598494, 0.12426253354975156, 0.09980143433702843, 0.3144844520304884, 0.12868792537067616, 0.14659455950771058, 0.21826824066894396, 0.17810729997498648, 0.13633534072765283, 0.2348950356245041, 0.19283938088587352, 0.13485247029789857, 0.14845859019884042, 0.17597550579479762, 0.10436071468783276, 0.1147614690874304, 0.08315288554877043, 0.1143137581114258, 0.11079433946205036, 0.09971346905721085, 0.10584877591047968, 0.2288255670240947, 0.21831075767321245, 0.40259374412042753, 0.3886785650891917, 0.27018216784511295, 0.28803759972964016, 0.2364489079586097, 0.1724580752530268, 0.16802132475589002, 0.12541668090437139, 0.0920278521786843, 0.27933123548116, 0.09719407531831946, 0.15919264778494835, 0.21984261833131313, 0.2043022122234106, 0.11949931271374226, 0.1412016446036952, 0.11028099379369191], [0.022110026263232743, 0.00887910314902131, 0.025736502471512983, 0.06295921520463058, 0.08377907159073011, 0.015887592120894363, 0.04813570848533085, 0.033941780483084064, 0.061558413585381846, 0.08055159941847835, 0.08257852601153509, 0.06437575205096177, 0.023736423812806606, 0.05657260951453021, 0.04375981918669172, 0.01708038034848869, 0.04296676102759583, 0.12063496320375375, 0.07165622924055372, 0.022083069763279388, 0.06544700278235333, 0.02411283432905163, 0.10336608413074698, 0.09125377264406, 0.10376644693315029, 0.0561251563818327, 0.024259650647374134, 0.06350076078836407, 0.04522173306239503, 0.0049836950991967955, 0.03844158384682877, 0.04354613833129406, 0.021200631578852023, 0.05895311052777937, 0.002855491853551939, 0.03657071691538606, 0.03575707200382437, 0.05441276469667043, 0.016238179290667176, 0.022501439188740084, 0.04007442747907979, 0.09313494991511106, 0.03955630153151495, 0.03648236147793276, 0.03874848862843854, 0.041916175080197196, 0.025072053839851702, 0.044931706839374135, 0.01575219045792307, 0.030869126253362213, 0.026036179158836603, 0.02277482264409108, 0.04602891832057919, 0.04249306894572718, 0.04438747764964189, 0.038970549391316514, 0.039681104477494955, 0.049500961654952595, 0.06238792264567954, 0.029431103595665524, 0.04755933030641504, 0.05244921327435544, 0.03941206194992576, 0.038015453677092276, 0.08502919772373778, 0.0389312486430364, 0.08687127102166414, 0.1201678461262158, 0.005446245211974851, 0.10924975627235003, 0.023255595238879323, 0.028852625350867, 0.05419971148616501, 0.12316660449973174, 0.07403450126626662, 0.4226096586457321, 2.6123578676155637, 10.110802326883588, 11.736054590770177, 31.281335490090505, 21.07140234538487, 17.993425062724523, 5.266527823039463, 2.0031298271247318, 5.9922758511134555, 5.4241264292172024, 9.209687846047537, 6.0341565523828775, 7.414421847888401, 16.739963088716777, 25.0214740889413, 28.505233117512294, 32.448212487357004, 25.43503781727382, 23.1246315070561, 18.560583932059153, 15.706395966666085, 12.636958888598851, 1.643072439091546, 3.1159743751798357, 7.307797397886004, 16.73079146657671, 31.883112021854945, 32.63704368046352, 16.420292104993546, 8.73343312740326, 3.9872107335499356, 0.5711702055164746, 0.26354110134499414, 0.08858387983803238, 0.12519690341183118, 0.17648017300026758, 0.057572128916425366, 0.06868409658116953, 0.06383470179779188, 0.09848487962569509, 0.022200308740139008, 0.029951346572488546, 0.026620898229469146, 0.12034829572907516, 0.02300160770703639, 0.10917475779673882, 0.019999717894409384, 0.06292013158755642, 0.028483417483844926, 0.036618780943432024, 0.08751959087593214, 0.06264229863882065, 0.02002871169575623, 0.040993306386683664, 0.02886523931686367, 0.09548268786498479, 0.04855556220614484, 0.020595636185524718, 0.05449304556740182, 0.08707255164959601, 0.06541378849319049, 0.06232255258198295, 0.017132225512926067, 0.01815437914670578, 0.04571726718651397, 0.09451429625707013, 0.02448322284700615, 0.03000788889559252, 0.02341546317828553, 0.0038435997807287742, 0.024602546622710567, 0.03049494811732854, 0.062089631866131506, 0.12134694999882153, 0.052107153593429496, 0.1537874513970954, 0.08373764024249145, 0.036692954998995574, 0.04431771746437464, 0.01976565893606416, 0.08104279091847794, 0.016726242744230797, 0.06304006265210253, 0.06449207330920867, 0.05864099120455129, 0.04699105044294681, 0.07079654572797672, 0.038526546609188826, 0.0469705213659576, 0.024922077244679843, 0.02877440383391721, 0.05352300172671676, 0.052313492699925385, 0.033783108461648226, 0.08705429227224418, 0.06992153410932847, 0.05754246336541005, 0.056279373820871115, 0.03128760254808834, 0.03405046482969608, 0.02930524552773152, 0.021338598104193807, 0.07848117194537606, 0.08301800635776349, 0.16286306083202362, 0.004864341213500926, 0.1090038280401911, 0.032480850483157804, 0.04421896008508546, 0.011609739258087106, 0.10066679040236132, 0.08548251339899642, 0.018356117785775235, 0.02465779464026647, 0.045251564854489904, 0.007936338960592235, 0.010761081939563155, 0.10735032640929733, 0.09025604118193899, 0.10773837380111217, 0.11231883801519871, 0.2430689941559519, 0.08749012888542243, 0.015396446422008532, 0.1580327735947711, 0.05639041946934802, 0.06126255874655076, 0.02858763707003423, 0.09024588351270982, 0.02591075704965208, 0.06321264124874558, 0.026470263455329195, 0.03581704432144761, 0.0792388648593, 0.06595406521643911, 0.0471105370670557, 0.036866751565997086, 0.04061434457876852, 0.03696013494793858, 0.04686478525400162, 0.03932695669521179, 0.03651168436876365, 0.04058796652991857, 0.0044315999922608686, 0.06631201279482671, 0.00837896770930716, 0.041254969845925055, 0.02724270093520837, 0.025011026400274465, 0.07472313288599253, 0.016315678167822104, 0.0914727630359786, 0.0530261716007122, 0.03707834253353732, 0.04397029057145119, 0.02550129678898624, 0.015792709176561663, 0.03657187721026795, 0.0822663116934044, 0.039397249530468664, 0.013125427882187068, 0.052664000141833506, 0.02766294650999563, 0.0189647976242538, 0.0368069013846772, 0.026131447171792388, 0.0559147562432502, 0.01595566953931536, 0.07224415947816201, 0.010640346811019948, 0.040901269896754196, 0.027249796715165888, 0.03697109328848975, 0.1412149846021618, 0.11021675009812627, 1.2327675244637897, 5.933002940246037, 14.663356712886266, 27.371968030929565, 35.34373876026699, 36.487631116594585, 24.544707809175762, 14.134105478014265, 2.06181583234242, 4.571483450276511, 7.5942047493798395, 17.716421229498728, 17.44311731202262, 28.23797239576067, 34.66587945393154, 47.31173290525164, 41.62725877761841, 47.32570573261806, 43.60679360798427, 43.73503998347691, 37.07122768674578, 18.804422276360647, 15.0173431124006, 6.583772088800158, 10.53360629081726, 20.528867891856603, 28.467080559049332, 39.23369121551514, 46.10173886162894, 25.816975082669938, 14.684044974190847, 6.286130368709564, 1.9634599557944705, 0.2821094292615141, 0.1815195983009679, 0.16605646376098904, 0.07704727138791766, 0.0226046477577516, 0.06775957904756069, 0.07598982884415559, 0.0935359505404319, 0.0512912491602557, 0.03377660470349448, 0.025835414217518907, 0.057955799757369926, 0.14516337987567696, 0.004751883364016456, 0.04260788046355758, 0.06685325982315199, 0.012898320515107895, 0.04289664800411888, 0.07048644843910422, 0.01978414731898478, 0.038632130050765615, 0.02349434287420341, 0.06272803832377706, 0.09815211248184953, 0.04100203573969858, 0.018545352720788548, 0.06985482733164515, 0.026483784961913313, 0.040176105951624255, 0.0204240261976208, 0.11997746277068343, 0.047628031977053197, 0.04008456818493349, 0.04221556508647544, 0.06436376912253243, 0.03995583312852042, 0.03182785552261131, 0.03735076755817447, 0.062002867593296936, 0.04654721390189869, 0.021342648958255137, 0.017857109562360814, 0.02571489961285676, 0.09184303281030484, 0.020621793710493615, 0.011625186955955411, 0.039564874821475575, 0.10912620861615453, 0.024573702099067823, 0.038586746236043315, 0.1189397248838629, 0.06503285893372127, 0.035454313071178536, 0.14832402313394205, 0.06681900737541062, 0.09682462657136576, 0.11344524007290602, 0.05556754308885761, 0.059914689644106796, 0.04931228820766721, 0.07073936558195523, 0.07545065134763718, 0.0662798366642424, 0.15311612242034503, 0.02117973778929029, 0.02888057760096022, 0.14982666607413972, 0.04780753841623664, 0.13521345092781953, 0.1829369222479207, 0.17828598538679735, 0.15459574945271015, 0.1772768816777638, 0.08134410117885896, 0.2162857377635581, 0.3626202147986208, 0.21979807929268905, 0.18635668445910725, 0.19626151796962532, 0.20165386290422507, 0.15369164225246223, 0.11875757894345693, 0.16067849019808428, 0.09192818895514522, 0.0779339809502874, 0.17875919570880278, 0.1382137020783765, 0.1875941694847175, 0.19087050296366215, 0.35242213202374323, 0.1978131511381694, 0.2745981551706791, 0.2445021415395396, 0.17162920401564666, 0.2141987540360008, 0.1277477608195373, 0.11934297824544565, 0.25419699560318676, 0.14075626778815473, 0.17166056590420858, 0.10491166476692472, 0.19532892586929457, 0.1884197159005063, 0.08701645037425415, 0.10492917775575604, 0.17391912399658135, 0.07721296285412141, 0.17392258452517645, 0.138716387961592, 0.19658721477857657, 0.11533107209418501, 0.09279759587453944, 0.08337684281702552, 0.12829494502927574, 0.18071894054966314, 0.11095797496714763, 0.13580311142972537, 0.11686992166297776, 0.07709035157625165, 0.204101596559797, 0.17811536097100802, 0.1661734567689044, 0.05676117100353752, 0.09664790891110897, 0.09366836664932114, 0.14105627526129993, 0.2225998860916921, 0.08197777824742453, 0.132652754762343, 0.2460578323474952, 0.1471387988754681, 0.10199327886636768, 0.12827385616089615, 0.1344310457685164, 0.18795671074518136, 0.1352683444108282, 0.13230492414108344, 0.18490124041480677, 0.09758599714509078, 0.11563899128564767, 0.23638878975595745, 0.1508731706334012, 0.14536632969975471, 1.2998465193169457, 4.9961821011134555, 14.387983100754873, 25.680646215166362, 51.44340624128069, 51.72730616160801, 49.03616462435041, 42.7158191544669, 28.536545174462454, 21.464493206569127, 30.180737359183176, 40.285245486668174, 43.23582233701433, 54.90145519801548, 60.31014837537493, 76.1697382245745, 69.34878199441093, 73.14733437129429, 63.5969728742327, 59.73498344421387, 58.55412319728306, 33.887427602495464, 26.943686280931743, 21.03136682510376, 27.128484044756206, 41.31267213821411, 45.6803479875837, 63.512906619480674, 54.8195915222168, 27.27892644064767, 11.16602177279336, 6.210379804883685, 1.4102187624999454, 0.4171874853117125, 0.32211778100047794, 0.35144767431276186, 0.3303910770586559, 0.19802579044231347, 0.2559246000434671, 0.22586205175944737, 0.27543009338634356, 0.15652958782655851, 0.11946791011307921, 0.07884093799761363, 0.21089348782386097, 0.2203846185335091, 0.21585223531084402, 0.075797945926232, 0.1434017808309623, 0.13549819136304514, 0.08743729136352028, 0.18601391570908682, 0.12174580645348344, 0.10905640771878616, 0.13385674729943275, 0.1553177378539528, 0.15255574748984405, 0.09747768938541412, 0.1198335454932281, 0.15658658476812498, 0.1432109089302165, 0.16898333813462937, 0.185191897675395, 0.2778043688407966, 0.15714983668710503, 0.17914450860449246, 0.2777990219848496, 0.14563885650464467, 0.12359497722770486, 0.07603549425091062, 0.09582340065389872, 0.09804176911711693, 0.1150791591831616, 0.1492875428604228, 0.1794112135789224, 0.09069968094783169, 0.23755277586834772, 0.19280856182532652, 0.08816867068942104, 0.1254967480365719, 0.4276948986308915, 0.17564790908779415, 0.1306730338505336, 0.31671189250690596, 0.29089233226009775, 0.2285992620246751, 0.2940899149647781, 0.17741459714514868, 0.18917196696358068, 0.220258356737239, 0.07744801416993141, 0.13549854420125484, 0.16205958037504128, 0.18108551230813774, 0.16963110837553227, 0.17589058035186358, 0.19123824180236884, 0.1705845586423363, 0.1351623029581138, 0.2041694636323622, 0.24121287518313952], [0.057980545929500034, 0.018100769791219915, 0.012075746082700789, 0.02375463060369449, 0.07342272052275282, 0.04728360760158726, 0.05840344287987266, 0.004134248559629279, 0.06542952372027294, 0.10356840970260756, 0.048881849340562306, 0.021993024773629646, 0.10044714183147464, 0.08122847881168127, 0.06062574006084885, 0.09938974678516388, 0.06255548686853477, 0.054828581134123464, 0.035398374644241164, 0.09590626335037605, 0.0680511048329728, 0.0566169958827751, 0.03517032241714852, 0.07356952157403741, 0.13418674602040223, 0.014860429202339478, 0.02502213741120483, 0.06270582987261669, 0.06891445922000067, 0.029728183190205267, 0.039779787217932086, 0.016649936392371143, 0.053358898032456636, 0.0547717334702611, 0.02540598976026688, 0.03163445947159614, 0.05117144023201295, 0.04922445863485336, 0.06703154489930187, 0.0881081996485591, 0.03131876426881977, 0.02471947516979916, 0.022752956853115132, 0.05885723352964435, 0.032887425273656845, 0.08125531487166882, 0.009215621743351221, 0.047172409282731156, 0.017694405346576656, 0.046746903365211825, 0.05601463999067034, 0.02152628089035196, 0.038153033437473435, 0.04078330658376217, 0.07184796966612339, 0.02677025566143649, 0.042513170545654635, 0.010210059766125466, 0.011727018947047847, 0.028107761837808148, 0.026655764751402394, 0.008267467442367758, 0.041822503320872784, 0.022768232372722456, 0.008322360925376415, 0.014597345908571566, 0.02356484605531607, 0.019493535859510303, 0.03632184723392129, 0.0245790353843144, 0.11256482053015913, 0.12162254378199577, 0.1529370570289237, 0.05425516136788896, 0.18913356188152516, 0.3643290916723864, 1.7753844878503253, 5.555035701819828, 10.038069452558245, 16.480319329670497, 32.42540155138288, 21.106688771929058, 8.883667077336993, 2.526899367570877, 3.717301445347922, 3.7226150802203586, 10.886010238102504, 11.870690703392029, 14.648296492440359, 14.547785588673182, 13.56426112992423, 19.593598672321864, 24.753655774252756, 27.77846196719578, 36.52747556141445, 10.03970922742571, 7.305078046662467, 5.383277101176126, 1.993288355214255, 8.421033433505468, 13.879361936024257, 27.192772252219065, 32.13502590996878, 23.13476719175066, 11.566959755761282, 2.6106049673897878, 0.9604689244713102, 0.377658125013113, 0.13815460167825222, 0.15010629035532475, 0.015030397135498268, 0.10579093758549009, 0.12162010105592863, 0.07648446051669971, 0.06867399319474186, 0.0470302629816745, 0.022353006260735647, 0.030903012292193513, 0.05132886714168957, 0.09472505601921252, 0.014973018517983811, 0.058868409001401494, 0.0353010625445417, 0.031164282201124088, 0.04596102749928832, 0.04508492683193513, 0.026126558326983025, 0.02192336297594011, 0.06809546745249204, 0.0049595447656299385, 0.021585472892703753, 0.03219752140077097, 0.06595498123871428, 0.025786722544580698, 0.012702245098937835, 0.044656537140586545, 0.02804622719330447, 0.024740916876388446, 0.017390245239117315, 0.07966214857463326, 0.010128504945896566, 0.029728685306119065, 0.031197459170860902, 0.0688753416761756, 0.06194940581917763, 0.03576514317787119, 0.043245554103382995, 0.03887760027178696, 0.02777964774785297, 0.058723501062818935, 0.05510501630072083, 0.0014824729566628645, 0.008055968925223818, 0.015947661129757762, 0.10262614847826106, 0.036098409044955454, 0.033921353186347654, 0.06452167100672211, 0.07989519821213824, 0.06102978730840342, 0.09255414429519858, 0.08528731244483165, 0.07178225354956728, 0.04473996641380446, 0.11436022418950285, 0.023861004538568, 0.12436769290694169, 0.03456279948087675, 0.03955176891759038, 0.0436870870180428, 0.038867137261799405, 0.05272810134504523, 0.0935346002557448, 0.030444210661309104, 0.05381554870733193, 0.0588425500318408, 0.03698836539738944, 0.013614140184862273, 0.04829120835555451, 0.0552146743450846, 0.0914528276771307, 0.004859906987154058, 0.028501089928405623, 0.09679522564900772, 0.0989300732367805, 0.04786660488960998, 0.09431772466216769, 0.05891420332981007, 0.0355718590851341, 0.07417712254183632, 0.10137113010776894, 0.07344024029693433, 0.09007964921849114, 0.022314557073903934, 0.05186497765992369, 0.0857692826539278, 0.2637570654707295, 0.10433628742716142, 0.0843328715169004, 0.10359553753265313, 0.15110548745308602, 0.053969535444464, 0.08258989147309746, 0.07647354288824967, 0.08433075448764221, 0.07294243308050291, 0.028879671756710325, 0.047030062813844, 0.03743653777720673, 0.020643986894616058, 0.03781619508351598, 0.06737001852265426, 0.08653803568865572, 0.013436664261722138, 0.01523979813126581, 0.018918183964810202, 0.0261808411284749, 0.02661040977441839, 0.03386202547699213, 0.02671280749408262, 0.05087442170562489, 0.048214961375508986, 0.02761068065384669, 0.02318452887370118, 0.02153711370192468, 0.018082817450964024, 0.14562855634306157, 0.008401379720973117, 0.060776171274483204, 0.010551116063392587, 0.10773365798273257, 0.050522319706422944, 0.013647383311763406, 0.031370312574186494, 0.026570966533784355, 0.03144417789631656, 0.01615702989511192, 0.026593775488436222, 0.019339452431138073, 0.0015979985265793012, 0.01807439004603241, 0.04451657911496503, 0.06738036618168865, 0.06867780656154666, 0.09555825631001166, 0.04487713226782424, 0.06837733089923859, 0.0665935098326632, 0.008623479499614664, 0.12200169557971613, 0.2038362757968051, 0.5933992298586028, 3.7742818849427358, 9.114232625280108, 12.711843967437744, 32.78795507975987, 38.11642435618809, 29.57479190826416, 19.200129134314402, 7.877432431493487, 4.074968653065818, 5.3609825032097955, 12.875497494425092, 16.075312307902745, 23.388732535498484, 29.56529024669102, 31.57321194240025, 36.706443786621094, 36.37762376240322, 42.042722838265554, 52.39942625590733, 24.384449345724924, 13.29444694519043, 16.04382654598781, 9.564930132457189, 18.486997297831945, 24.846938814435685, 41.56891475405012, 44.724209853581016, 30.713917800358363, 15.126888411385671, 5.7939065183912, 2.597452027457101, 0.7712042289120811, 0.165763811607446, 0.03446248825639486, 0.1228352351380246, 0.11208108613001448, 0.08611334740583386, 0.048089021883372746, 0.0527833374882383, 0.07897481974214315, 0.03570714878982731, 0.02051542147195765, 0.014474897479106272, 0.11579101027122565, 0.05849070926862104, 0.07611775983657156, 0.030793863149093728, 0.059603547411305566, 0.03539898193308285, 0.09477169851639441, 0.023710751440376043, 0.0358795034699142, 0.023217458178156188, 0.035309031938335726, 0.01933365604574127, 0.035410388106746335, 0.02597789469707225, 0.012988223012403717, 0.051475213574511666, 0.010794556616539401, 0.05430181743577123, 0.03213172046733754, 0.044605480773108344, 0.03489052510953375, 0.05774059559085539, 0.05096162024087139, 0.09644434162016426, 0.024768092203885317, 0.061919821692364554, 0.040226938402546306, 0.013294784285660301, 0.010685286185305034, 0.03395980576585446, 0.047019060368516614, 0.04028748068958521, 0.02487173842798386, 0.005886318852260176, 0.022903735815946544, 0.031621272143508704, 0.02312478725798428, 0.027092174726671407, 0.12903065340859549, 0.13050167661692413, 0.030779532489499876, 0.11755418351718358, 0.046874752933425565, 0.10665298239993197, 0.08960687315889768, 0.09935480223170348, 0.04169910494238138, 0.07327756152621337, 0.022780351008155515, 0.052622473798692226, 0.04501207931233304, 0.010179997272124248, 0.06723245911832366, 0.07058497172381197, 0.05007100570946932, 0.13476622849702835, 0.0785635325259396, 0.1813196883137737, 0.17836221201079233, 0.1597382306520428, 0.19067520701459476, 0.14706966972776822, 0.1524034570902586, 0.2835793803845133, 0.2285494032715048, 0.13756965020937578, 0.1803183470453535, 0.24419134535959788, 0.1569258387067488, 0.1031199251966817, 0.11066845764539071, 0.17396611933197292, 0.19794416267957005, 0.17013150081038475, 0.21483380853065423, 0.20218633647475923, 0.21949751542082854, 0.41337696835398674, 0.2464395218661853, 0.19931522410895142, 0.29044061792748316, 0.2641717589327267, 0.1492319708423955, 0.16990170814096928, 0.16887931871627057, 0.11489934740321976, 0.11420868017843791, 0.14769622896398815, 0.07664942595043353, 0.11277439285601888, 0.11725915649107524, 0.12036200213645186, 0.1606024807052953, 0.19976701986576828, 0.10123294645122119, 0.17955373307423933, 0.20964684257549898, 0.11058259582413094, 0.17066454435033457, 0.11868490784295968, 0.3365862103445189, 0.11967000498303346, 0.15237683137612684, 0.08934190523411546, 0.12797706494373934, 0.07451936203454222, 0.12749309305633816, 0.23919732762234552, 0.10347454795347792, 0.19649293912308557, 0.1646649512861456, 0.17925672472587653, 0.08419864371951137, 0.0777648493115391, 0.1750913339533976, 0.11207835841923952, 0.15489069505461625, 0.06421456605728183, 0.10962016853903021, 0.21397335827350616, 0.11464325471648149, 0.11210765756134476, 0.0701962322262781, 0.20199048412697657, 0.10297397231417042, 0.15790595539978572, 0.23040337807365827, 0.24290345875280245, 0.17229750672621386, 0.21036733819970063, 0.27216232301933424, 0.22581425575273378, 0.31591559095042093, 2.818447300365993, 9.012699467795235, 15.963413306644984, 29.96130977358137, 51.29573270252773, 50.42859404427664, 49.87823070798601, 29.949602058955602, 27.56152183668954, 24.416935648236954, 29.285844121660503, 34.10259594236101, 49.04066705703735, 56.774543625967844, 63.6097297668457, 68.01954991476876, 64.46425397055489, 56.30715567725045, 70.4698599406651, 38.41970975058419, 19.93889113834926, 27.550126791000366, 28.752866915294103, 35.87052338463919, 47.212154797145296, 70.52110290527344, 59.69341237204415, 33.11125476019723, 15.102995293481008, 4.04442263501031, 1.4293511701481683, 0.7033965417316982, 0.5736353503806251, 0.27629403131348745, 0.12838305958679744, 0.22298852380897316, 0.21940418971436365, 0.22579115842069897, 0.15692601512585366, 0.1619015767105988, 0.16330182871648244, 0.20145894693476812, 0.11711287791175501, 0.23298034550888197, 0.10670288186520338, 0.24143665603228978, 0.13137347197958402, 0.09760530146637134, 0.06278773583471775, 0.197167145088315, 0.10947306893233742, 0.09886797371187381, 0.15605263199125016, 0.1381951237895659, 0.1655142328568867, 0.136868506403906, 0.09810751237507377, 0.11288175066666943, 0.11732448584267072, 0.09578447988522903, 0.14438828932387487, 0.17214147081332548, 0.07821473159960338, 0.16829583288303443, 0.1486453501773732, 0.14429850557020732, 0.1909203210047313, 0.1471347819481577, 0.14945271185466222, 0.16322670131921768, 0.16880712259028638, 0.10472211600946528, 0.16118374094367027, 0.1469446157238313, 0.11272070716534342, 0.1012210992297956, 0.09067665146929876, 0.11955058281975132, 0.14019020673419746, 0.1262539659759828, 0.18399337413055555, 0.392492230449404, 0.34921328563775333, 0.18918484555823462, 0.36509865894913673, 0.2374763185424464, 0.24517332123858587, 0.1730814996574606, 0.16283844358154706, 0.10241342774991478, 0.1471288651227951, 0.07962096828435149, 0.1951601877808571, 0.1739426963031292, 0.1819697112909385, 0.1599057066653456, 0.1984015359942402, 0.1239991398262126, 0.2409853216792856, 0.18267027155629226], [0.011464095109009316, 0.03503639996051788, 0.17218005231448583, 0.01534479803272656, 0.025060968273984532, 0.077255445931639, 0.05581212442900453, 0.024264349502378275, 0.07021594366856984, 0.04293394707409399, 0.03376931045204401, 0.021387415306110467, 0.0029663894965779036, 0.05950203857251576, 0.08788782504520246, 0.04400409857875534, 0.07447356770613364, 0.06302999997777597, 0.1116265898038234, 0.06459964825106518, 0.03600136157391327, 0.11754393763840199, 0.053080637606659105, 0.05808109803391354, 0.07158329351139919, 0.12067249976098537, 0.0645161545170205, 0.025806478091648648, 0.05133159485246454, 0.027397179610228965, 0.04665629179882152, 0.07831947026508194, 0.05569287868482726, 0.02308635673086558, 0.047078476287424564, 0.04807991933609758, 0.04997484033395137, 0.022817329470334307, 0.026749467044802647, 0.02325035525219781, 0.06342114827462605, 0.020367818053013513, 0.09261386894754, 0.02586317138879427, 0.13318993736590656, 0.06156298012605735, 0.044429896266332695, 0.05094697745516896, 0.0689858343186123, 0.017253612035087178, 0.02112878829107753, 0.021203503478318453, 0.023450407731745924, 0.014692595261814339, 0.03906104899942875, 0.0032627394539304078, 0.021599141980654428, 0.01901164198560374, 0.020312152736421143, 0.014744969683566263, 0.031398543023637364, 0.01648874022066593, 0.036402525047638586, 0.026677652594766448, 0.034996461389320235, 0.03955897495948842, 0.1102411841441478, 0.1023190842409219, 0.061591655015945435, 0.06283388978668622, 0.04870490437107427, 0.11270738073757716, 0.025480869492249827, 0.07872353108333689, 0.1231267609234367, 0.0512176009693316, 0.35148632366742405, 2.4081633388996124, 3.7748268842697144, 6.438811387334551, 16.037819828305924, 30.26988274710519, 25.577114582061768, 12.218414170401436, 5.147779200758253, 2.13689871770995, 2.656468940632684, 4.714024441582816, 7.708372337477548, 14.699621098382131, 17.646760327475413, 13.34565430028098, 12.301690936088562, 17.47838463102068, 36.9440096446446, 7.164214176791055, 6.687004949365344, 7.437766926629203, 11.962475538253784, 14.337075386728559, 22.353963375091553, 22.88809745652335, 20.84278229304722, 9.141186424664088, 2.758716242653983, 0.7392788305878639, 0.40178536464061054, 0.23519150114485196, 0.11816090238945824, 0.08004918494927031, 0.035026449244469404, 0.21214723054851803, 0.049692586729569097, 0.09875222242304257, 0.08291961878005948, 0.09626712184399366, 0.04232559971777456, 0.01517292850517801, 0.00617799603579832, 0.034605679501380236, 0.05801887637270348, 0.014804056512990167, 0.06217694575233119, 0.010833925218321383, 0.027349863667041063, 0.051844496080385785, 0.059969983462776454, 0.022217331487419348, 0.03721651601205979, 0.029821983871183226, 0.06717939767986536, 0.0463659263082913, 0.031040422418820005, 0.017044302641547153, 0.08549626730382442, 0.04362130644065993, 0.06411395288471665, 0.024248639720359018, 0.016661245874794464, 0.07093280234507152, 0.027198350190051963, 0.05380635116515415, 0.0056644807336851954, 0.017546019916023527, 0.04501673745523606, 0.020414867671206594, 0.09360045886465482, 0.05259533918329647, 0.011653137509711087, 0.026116358249315193, 0.053577342203685215, 0.06641633755394391, 0.03079574947644557, 0.08130544503884655, 0.03342634153419307, 0.04635120888373681, 0.0494176205912871, 0.07273845188319683, 0.08422818034887314, 0.11752212952290263, 0.11271290401262896, 0.06657550151326827, 0.05654359196445771, 0.0893339053062456, 0.04063989142222064, 0.025506312859111598, 0.03658603823610714, 0.11438902121569429, 0.0792381591828806, 0.037208068251077614, 0.02632659045048058, 0.06038614256041391, 0.05863212275185755, 0.030721090268343687, 0.05720008138035025, 0.026143954268523624, 0.04558756182502423, 0.024709539720788598, 0.09243562458349125, 0.052203193439968994, 0.03331970636333738, 0.047774208776120625, 0.039638543368450234, 0.00460547798346462, 0.10660116268055779, 0.07391157107693808, 0.06946899196399109, 0.007876877240570528, 0.028282155515626073, 0.11396827522133078, 0.11291423892336232, 0.04440199490636587, 0.12920720822044782, 0.0285719391623778, 0.15962855225162847, 0.2175508663058281, 0.16023736101176056, 0.04790809730600033, 0.07715395066354956, 0.019755307884354676, 0.11559309517698628, 0.050911249193762026, 0.05535234910036836, 0.015545925990279232, 0.03852675695504461, 0.021110847825184464, 0.0011404099890829197, 0.04349379613995552, 0.06279492152056523, 0.03125497858439173, 0.006695095699147454, 0.030546299647539854, 0.09464305506220885, 0.04722818146858897, 0.048172044035579474, 0.06571602834654705, 0.0408020680770278, 0.053142764272966554, 0.1256242583372763, 0.040727307088673115, 0.020187538083908812, 0.018518565854589854, 0.08663099498621055, 0.055540690065494606, 0.09603601960199219, 0.07258196135184594, 0.09879026109618799, 0.033774497852261574, 0.013276592761810337, 0.05223856886316623, 0.06348677618162972, 0.03332878855456199, 0.04620463514168348, 0.03794409214918103, 0.03292802202382258, 0.01698672555253974, 0.047042147522526126, 0.08183011545666627, 0.0320741060589041, 0.03461914163615022, 0.008174291013606956, 0.06021644773760012, 0.11233288369008473, 0.01591826868908746, 0.06257852991776806, 0.0038702831703371233, 0.13479522908372538, 0.08642203334186759, 0.12913989754659788, 0.04502125310578516, 0.059671326274318356, 0.17519372488771165, 0.8449734162007059, 4.349459843976157, 8.320323637553624, 9.239105650356837, 31.59107576097761, 37.23463542120797, 31.36386271885463, 18.99113426889692, 12.727466991969518, 9.572288274765015, 8.312649352209908, 8.936665330614362, 14.333768912724086, 20.30801592554365, 28.537377221243723, 22.133615153176443, 18.513973678861344, 30.604223115103586, 46.23779501233782, 16.480244636535645, 11.95709763254438, 21.90247811589922, 23.04601263999939, 24.691629205431255, 35.12900815691267, 40.219776085444856, 27.576357977730886, 15.042707511356898, 6.360791802406311, 2.143599169594901, 0.7163146542651313, 0.18375520833900996, 0.10355053709021636, 0.06943004405392067, 0.015502118073137743, 0.09204404880957943, 0.06171990491982017, 0.022509495095748986, 0.0697995810104268, 0.05472923342936805, 0.020605420660493628, 0.04616350234885301, 0.028802257696432725, 0.030060638207942247, 0.06980572175234556, 0.026122651661613157, 0.01282240347271519, 0.036390063752021105, 0.027821245337171212, 0.007983676107999469, 0.06147915390985353, 0.054156695758657794, 0.03519549945901547, 0.0765983322635293, 0.019372605652149235, 0.10648011203323092, 0.058191047848335335, 0.027828544677634324, 0.039424475748091936, 0.025935586342321973, 0.05594741413369775, 0.021379695273935795, 0.015417927144361394, 0.045844763916518004, 0.030315668987376348, 0.026106963931982006, 0.032980119942554405, 0.007430789659598044, 0.020444356803117052, 0.04073310177773237, 0.042190988548099995, 0.07272080318736178, 0.09012262084122215, 0.013607777222724897, 0.011042870747457658, 0.08468716857688767, 0.0581172164529562, 0.03260172810405493, 0.006107508121723575, 0.030886920834226266, 0.047592283359595706, 0.07879709106470857, 0.028178624642480696, 0.17394883025969776, 0.04914472398481198, 0.09602742256330592, 0.061083221941121986, 0.06285283448440687, 0.048791078318442614, 0.05035798870293157, 0.03627009876072407, 0.030910805266882693, 0.09130086975970439, 0.014172478662138539, 0.0521143799913781, 0.1555447078176907, 0.02425547087165926, 0.08266425891114132, 0.1065313278564385, 0.02449115492137415, 0.12498621828854084, 0.17218287502016338, 0.30245872161218096, 0.14177875220775604, 0.09331313999635832, 0.11639966975365366, 0.2806667552462646, 0.19553558049457415, 0.31760707018630846, 0.1607249698468617, 0.31985725515655106, 0.12117840190018926, 0.12473516033164092, 0.13173575539674076, 0.15756238597844327, 0.1400347679321255, 0.2519114725291729, 0.15994655447346823, 0.28781042620539665, 0.29804517701268196, 0.26487027002232416, 0.1980422788432666, 0.22120552376977035, 0.2631262450345925, 0.2056624170924936, 0.31532673111983706, 0.15551942560289586, 0.09665083339703934, 0.09766999299504928, 0.06921553877847535, 0.1556571682116815, 0.1628594510257244, 0.08065982575395278, 0.11741382176322596, 0.11734849241163049, 0.11501568901751723, 0.2076322449637311, 0.1095123357538666, 0.16709412022360734, 0.15272679259734495, 0.0962924040587885, 0.10913108728293862, 0.28700942918658257, 0.18525890979383672, 0.30648854108793394, 0.13071624296052115, 0.1462921771620001, 0.15084528284413473, 0.12635585479438305, 0.18719297886959144, 0.32385800619210514, 0.15469121932983398, 0.15576263969498022, 0.10278557028089251, 0.1355313988668578, 0.0886099220120481, 0.07684108495180096, 0.11591256303446633, 0.15915885674101965, 0.09674504798437868, 0.20622071570583753, 0.21593806999070303, 0.21823576598295144, 0.2035629347498928, 0.09154367673077754, 0.1375887713262013, 0.25089850117053303, 0.18546688077705248, 0.14821868735764707, 0.12385989086968557, 0.2310770276401724, 0.17450795668576444, 0.13511267490684986, 0.168564125629408, 0.20545283119593347, 0.18767828068562917, 0.4213091784289905, 3.012575409242085, 6.686421300683703, 9.164402961730957, 30.4576404435294, 55.27850266865322, 51.69720656531197, 47.457335880824495, 39.85693073272705, 31.901059218815394, 26.87813002722604, 18.97347715922764, 25.360497542790004, 37.47767298562186, 49.67709078107561, 44.53894656045096, 37.83901405334473, 48.98849303381783, 74.00449194226945, 24.459639276776993, 23.06173815046038, 36.52114575249808, 44.93593536104475, 46.491908005305696, 63.26154163905552, 56.350380420684814, 31.760959216526576, 12.542809929166522, 4.161851968084063, 1.4512763193675449, 0.559027088539941, 0.5095609085900443, 0.24688103103211947, 0.13359500920133932, 0.29610041422503336, 0.2600955276616982, 0.14929325612527983, 0.13913976667182787, 0.16423591359385423, 0.19144417718052864, 0.15336431695946626, 0.1434261809502329, 0.14903980972511427, 0.22919026602591785, 0.2081255806343896, 0.12054530158638954, 0.2185556681028434, 0.19508173556200095, 0.10089636594057083, 0.1465412402259452, 0.1775362313325916, 0.12370025872119836, 0.1369128418820245, 0.1307984542633806, 0.15812539362481662, 0.17510307260922023, 0.11427897640636989, 0.0858522199892572, 0.22996200461472782, 0.14787032747907297, 0.1701380011758634, 0.1603663233774049, 0.1117397015914321, 0.17956241832247802, 0.22322062349745206, 0.1385456414094993, 0.12603566768978322, 0.10017820447683334, 0.23156861269048282, 0.12385888663785798, 0.1475981670830931, 0.10927647019603423, 0.10091854725033045, 0.06584760985736336, 0.15680888641093457, 0.15883721757147992, 0.0956809761534844, 0.10443436966410705, 0.11334507473345314, 0.11985832559210913, 0.15314618152167114, 0.1741328082446541, 0.21525749936699867, 0.2980787237840039, 0.3017628432384559, 0.2699740475841931, 0.15168925827103003, 0.18677200217332157, 0.15745683307094233, 0.08112895129514591, 0.12064617260226182, 0.14110666327178478, 0.23116170881049974, 0.1964952732835497, 0.17494436326835835, 0.18892769435686724, 0.18320980189102037, 0.17763049341738224, 0.1472263163221734, 0.1753337609448603], [0.03717410418071917, 0.10106375374432121, 0.11612100899219513, 0.014745242793911269, 0.014702562941238284, 0.05290904967114329, 0.032478716490524154, 0.03750065594379391, 0.06072294698762042, 0.08816740182893616, 0.0036458072468771464, 0.01018211939039507, 0.02132278654192175, 0.02807795040176383, 0.041908992787024806, 0.023611639526539614, 0.020175109018704722, 0.10442200675606728, 0.11666815248983246, 0.03959053023053067, 0.07480181580675499, 0.050262081170720715, 0.0025870192953984118, 0.060026220445122035, 0.04000746625076447, 0.039656860421278646, 0.020516524091362953, 0.02980655398485916, 0.09392241016030312, 0.0258020845774029, 0.0690493926938091, 0.05554911407775112, 0.05198138712772301, 0.046953340859285424, 0.04954925638490489, 0.02557123339335833, 0.07554251820381198, 0.010527033159243209, 0.026788888233048574, 0.05396092822775245, 0.026674797658675482, 0.018745607064504708, 0.11232962672199522, 0.041427738432373316, 0.011471810900340123, 0.020814758891771947, 0.02356003354569631, 0.040150046814233065, 0.09797685367188283, 0.051377270437244854, 0.022794735950550864, 0.022898073441215923, 0.022553323368941034, 0.017030793009325862, 0.020881748957825557, 0.01040532942196088, 0.015384395640077335, 0.03442869721246617, 0.02447697184314685, 0.08265505119093827, 0.04354018418650542, 0.061323497976575575, 0.05123894768101828, 0.08072400838136673, 0.04850972716563514, 0.019671971909701824, 0.02118895568751863, 0.04548922174477151, 0.01833835882799966, 0.09129881379859787, 0.0745919652815376, 0.05570906513769712, 0.0328042606290962, 0.013890709362125822, 0.16759098427636282, 0.12132682465016842, 0.03527888462745717, 0.38936231125678333, 0.9788747025387627, 3.3377877984728133, 4.1304435048784525, 15.370890038354055, 22.587066752570017, 15.190540858677455, 6.284964374133518, 6.923163362911769, 11.08650745664324, 3.326934278011322, 4.009838845048632, 5.437645886625562, 8.48514359337943, 4.439101593835013, 2.3928058658327376, 4.738915494510105, 9.578100442886353, 5.061231570584433, 12.300595726285662, 16.54688654627119, 16.464850902557373, 20.224851199558803, 23.18621165411813, 10.234060764312744, 4.381281724997929, 1.0469759511096137, 0.26547951304486817, 0.2525965486254011, 0.06974195303129298, 0.11546605985079493, 0.08732390137655394, 0.08672071767172643, 0.0850058968311974, 0.048820061941764185, 0.09326996481312172, 0.03472961392253637, 0.08171708509325981, 0.02333166919249509, 0.057921465885426314, 0.0851998832076788, 0.060901958096240244, 0.05740009993314743, 0.05520741741306015, 0.04245454172736832, 0.0641289349379284, 0.028764229201312577, 0.05113222090793507, 0.030061622083719288, 0.020828585739114454, 0.024298323750762, 0.021794831480032632, 0.03251695872417518, 0.022391187426234995, 0.01451877664242472, 0.03081679084737386, 0.056186618083821874, 0.04386570457635181, 0.03331788110413721, 0.051954181266150305, 0.06560567141111408, 0.08623173819588763, 0.027530788244413476, 0.04940791754052043, 0.03125901247507759, 0.02461773223642792, 0.02042049272651119, 0.05607966060883232, 0.014054967423102685, 0.025774851574429443, 0.005046353991409498, 0.019875749546502317, 0.016840994890247072, 0.04173107072710991, 0.0815757733902761, 0.07084692695311137, 0.02748755708203784, 0.027611401597304002, 0.0347813590030585, 0.10372636586959873, 0.045956583094916174, 0.03457860256146107, 0.1018590239275779, 0.07159272514815841, 0.06769940656210695, 0.08192954119294882, 0.04180386396391051, 0.046539003628173044, 0.05380515694352133, 0.0626362461064543, 0.05382500409281679, 0.033420947180794816, 0.07808751306895699, 0.016535961168951223, 0.04888504184782505, 0.007782227542650486, 0.022963099148390547, 0.037390977543379576, 0.05034171404050929, 0.03378083536933575, 0.04330997421805348, 0.12038504518568516, 0.043307046339448006, 0.00791901596156614, 0.05671419941687158, 0.02163700932370765, 0.05683631875685283, 0.06075201542781932, 0.024741257840235318, 0.0015933537423344596, 0.06776768754103354, 0.035136097110807896, 0.03805260346936328, 0.05276374139689973, 0.06165184785744973, 0.03537180321291089, 0.0890190786282931, 0.11671061521129948, 0.15755094587802887, 0.11554166222257273, 0.04993745305442384, 0.09547327658427612, 0.06136790130819593, 0.07784987653472594, 0.08500933700374194, 0.048400954609470706, 0.0689911540331585, 0.042859165729688745, 0.02472805354877242, 0.05768720845558813, 0.038927001013819656, 0.0034038251199360403, 0.030066426111651317, 0.022371141805446575, 0.08344886252390486, 0.04386341112798878, 0.04840666787432773, 0.07002727700663464, 0.03933526196384004, 0.04394760036042758, 0.009154871654962855, 0.07587960761572633, 0.02601098854626928, 0.01615908755255597, 0.02038844382124288, 0.024809750861355236, 0.017893947228523235, 0.03585709824359842, 0.039157350081950426, 0.023521565699151585, 0.05798946187964507, 0.02761474677494594, 0.061616672602083, 0.06350160217178719, 0.003931745296410684, 0.029266989723380123, 0.010871170005494995, 0.048439285052674155, 0.04354153447119253, 0.020837211615539024, 0.02647682828163462, 0.01293984176923654, 0.015324019594117999, 0.025887892115861177, 0.016362878760056834, 0.02129671722650528, 0.05726758882935558, 0.07388267227049385, 0.035793292203119824, 0.0828510799578258, 0.06870161635535103, 0.043774136275585206, 0.039357161681566916, 0.041832623670675924, 0.06519267428666353, 0.19437524490058422, 0.8915454543062619, 2.0400799129690443, 4.87659318106515, 7.273039468697139, 29.04104518890381, 31.282805034092494, 31.18031563077654, 16.893935169492448, 13.518277951649257, 16.04200611795698, 18.613878352301462, 10.594131180218287, 9.849448442459106, 16.270614010947092, 10.207638502120972, 8.726172259875707, 14.109070249966212, 16.732160261699132, 14.0429425069264, 25.49508936064584, 27.977750199181692, 24.489544323512487, 34.61508812223162, 37.83485555648804, 18.481846945626394, 10.161929777690343, 2.6016441796507155, 1.140597173145839, 0.574226652937276, 0.3176330716482231, 0.12383431009948254, 0.045263276368911774, 0.06060651037842035, 0.07600975741765328, 0.046822149506104846, 0.05378758627921343, 0.07966745471847908, 0.07476286111133439, 0.029915577598980496, 0.06930374154554945, 0.12271072396210261, 0.05172853105302368, 0.07738990443093435, 0.03326673652710659, 0.009505105138357197, 0.03483431187591382, 0.05500294767054064, 0.03046665999240109, 0.031642059063805, 0.039706973625080924, 0.025990942925480858, 0.0277799615702991, 0.029502000327089002, 0.033891518001577685, 0.07782293869448559, 0.05410213475780828, 0.08329614464725767, 0.04025648860260844, 0.018323285172560384, 0.02639577557731952, 0.03045382210984826, 0.018181103248415247, 0.036284724583051035, 0.030783926003745625, 0.03805039144520249, 0.029018785006233623, 0.06896726960050208, 0.029642874374985695, 0.042548674890505414, 0.0042474578866469005, 0.03415124424334083, 0.021773893585694686, 0.01894315574983401, 0.06287670534636293, 0.07949944944786173, 0.03301707295967, 0.12199436740151473, 0.07539111668510096, 0.10823776878948722, 0.046378397781934054, 0.03122594067826867, 0.14187177935881273, 0.10771165987742798, 0.11067693254777364, 0.06439204367675952, 0.07570354134908744, 0.08423305223030703, 0.09255991184285708, 0.09160991531929799, 0.060468455643526146, 0.026266107535255805, 0.11874843229140554, 0.06779850660158054, 0.029296207441283122, 0.030756323199187006, 0.04872428672388196, 0.06317607499659061, 0.11576295963355474, 0.06130070598529918, 0.07573442826313631, 0.19979562690215452, 0.24246873493705476, 0.11457004078796931, 0.08198501821607351, 0.14324182298566612, 0.1677024947213275, 0.18762029308293546, 0.2220038337899106, 0.1805925973291908, 0.13611717814845697, 0.1629794838705233, 0.15753581454711302, 0.15624939357595785, 0.1400501706770488, 0.14232027743543896, 0.07296371193868773, 0.1805272272654942, 0.20592152247471468, 0.30284084539328304, 0.29173998534679413, 0.2588401021701949, 0.25388671510985916, 0.2316478927220617, 0.13704766679022992, 0.2188405713864735, 0.12177990962352071, 0.24082594737410545, 0.2456236242183617, 0.08412885639284338, 0.3361018720482077, 0.12370570057204791, 0.12414396634059292, 0.1450069775538785, 0.19427092692681722, 0.1542045875851597, 0.3461621307900974, 0.08227121750158922, 0.09421652794948646, 0.16559305148465292, 0.23562313084091457, 0.10800323994564158, 0.24127470329403877, 0.18222568184137344, 0.1632915964084012, 0.1139628876532827, 0.11363808651055608, 0.19252638625247137, 0.07867572829127312, 0.09083360340446234, 0.11757182542766843, 0.19150452608508722, 0.06146316762481417, 0.3280686688210283, 0.13222036510705948, 0.12264866514929704, 0.08371501109961953, 0.08604863552110535, 0.12103753803031785, 0.13951715427849973, 0.10932938914213862, 0.16776915400155953, 0.12946794208671364, 0.19535384167517933, 0.10311116530959095, 0.07966577195163284, 0.07377683437828507, 0.13237845019570418, 0.08666155620345048, 0.23112675068633898, 0.1882445995828935, 0.1490238370107753, 0.1502748927367585, 0.08845561636345727, 0.23911731477294648, 0.25543996319174767, 0.39274524258715765, 0.5233780528817857, 1.1811018053974425, 4.846319879804339, 6.708656404699598, 27.50462477547782, 40.665829590388704, 59.13051101139614, 44.01429850714547, 45.290293489183696, 50.38111352920532, 49.876868861062185, 24.542256832122803, 23.532956293651036, 26.311313356672013, 25.776666845594132, 21.092344215938024, 34.2760021345956, 35.63482311793736, 28.38820287159511, 46.83793176923479, 62.13659354618618, 45.57729230608259, 57.71018804822649, 54.257596901484895, 24.202522924968175, 7.160661041736603, 1.4726129344531467, 0.6279763973184994, 0.5125781638281686, 0.27473538209285053, 0.24717136259589875, 0.12302218510636262, 0.21852642324353966, 0.2932827297065939, 0.10375663531678063, 0.17217600824577467, 0.22802606278232165, 0.2914417013525963, 0.0909185695594975, 0.21616920615945542, 0.17365711448448046, 0.11066361969070775, 0.27175588054316385, 0.13150503991969995, 0.1600636424762862, 0.12237104933176722, 0.1376728689564126, 0.13023980281182698, 0.11741116190595285, 0.11752024319555078, 0.0520292849146894, 0.09585443684565169, 0.17653358727693558, 0.12711076571473054, 0.18566992559603282, 0.1822618477578674, 0.17007111119372503, 0.15280684615884507, 0.14834904750542982, 0.08743919804692268, 0.2619520808969225, 0.18690544287008898, 0.11098960826971702, 0.1490808203816414, 0.17790124246052333, 0.12317079784614698, 0.15862160628395422, 0.14383255557290145, 0.17930606779243263, 0.09507102066917078, 0.10576931267444577, 0.1438491932515587, 0.08728105189012629, 0.13530172833374568, 0.14490540086158685, 0.16735797535095895, 0.2095232813486031, 0.16605467242853983, 0.2297668308019638, 0.1775993350893259, 0.21124502324632236, 0.32429731690457886, 0.34242071583867073, 0.23704031908086368, 0.303375313856772, 0.23135161719151906, 0.1853494942188263, 0.16720119304955006, 0.20051551184483937, 0.1682419843439545, 0.19935808038072927, 0.17183931916952133, 0.17019198542194708, 0.30101764893957544, 0.1423708147236279, 0.07783312350511551, 0.15989152528345585, 0.12052960028605801, 0.16802091763487884], [0.07435277490211384, 0.007442646210880152, 0.04686633570651923, 0.03753327312214034, 0.03857665642031601, 0.035837665000664334, 0.024274661538324187, 0.09082849403577191, 0.03515864482947758, 0.08951451775750943, 0.028592885538403476, 0.02278672075564308, 0.035784556064754725, 0.04372607564021434, 0.11953383657549109, 0.04532560659572482, 0.05440956201138241, 0.08271573257765599, 0.005426029109262994, 0.09880003200045653, 0.08128367085009813, 0.01835003980834569, 0.0737839929227318, 0.05660897220617958, 0.07433756893234593, 0.055417512210884264, 0.06625133819345917, 0.026162605499848723, 0.04411645379981824, 0.07691210721220289, 0.09227440466306039, 0.021418884063937833, 0.028396598928208863, 0.04678038567570703, 0.04818492941558361, 0.04538397078535386, 0.06353606496538435, 0.017325518087350895, 0.029533260435398136, 0.043701061446751864, 0.02544347882004721, 0.020676631214363233, 0.09064041769930295, 0.040380653725670915, 0.01548164158261248, 0.046161113905587366, 0.02609785459935665, 0.08677612684134926, 0.005300433973648718, 0.04442905488290957, 0.03862923949158617, 0.041206298529037406, 0.03604847565293312, 0.01967485568353108, 0.09269663664911475, 0.036336900533310006, 0.03730129556996482, 0.040177988886301, 0.045844146449651034, 0.02307899801858834, 0.04967184391404901, 0.07467629361365523, 0.05030984664335847, 0.03175085197602, 0.017490636191463897, 0.04685707709618977, 0.026212857803329825, 0.0358566605885114, 0.042284524600420675, 0.11541210274611201, 0.031922765608344755, 0.11871765394295965, 0.07138465917004005, 0.05470893505428519, 0.04024925881198474, 0.020873940716098462, 0.14680772806916917, 0.0820502864995173, 0.026248904976195524, 0.32008681712406023, 1.044155742440905, 1.3640598165137428, 10.774715730122157, 3.0560585388115475, 25.33148012842451, 15.677694695336477, 10.56050363608769, 10.528459412711006, 5.338187634944916, 8.071053539003644, 5.613758836473737, 5.370594033173152, 7.463800958224705, 2.658011874982289, 5.245661079883575, 12.64890284197671, 9.89318561553955, 12.402197497231619, 21.652323859078543, 21.3610988003867, 7.455860904284886, 1.8800507400717055, 0.45381580985018183, 0.11662727754030909, 0.3485900376524244, 0.04380620723324163, 0.01472945837303996, 0.12777881058199064, 0.034941591655037234, 0.06303391512483358, 0.05662800511345267, 0.04445683749924813, 0.09226698148995638, 0.08228111732751131, 0.06566224766096898, 0.03547312206189547, 0.025839476945943067, 0.04776652097435934, 0.03837076514693243, 0.1043773116543889, 0.05469112351004567, 0.07681223364280802, 0.03612349448459489, 0.06356853965137686, 0.047988018553171835, 0.03410361108503171, 0.036176742520183325, 0.04185574475143637, 0.05680166258077536, 0.019779037950294356, 0.02476315925429974, 0.06829333504928009, 0.057548984086939266, 0.05141479003110102, 0.017597468137474995, 0.01921226952358016, 0.02002637244627944, 0.08350725046225957, 0.029837301799229214, 0.020858507437099303, 0.016122024273499846, 0.035020427246178897, 0.015893078076520135, 0.022284806706011295, 0.005423339990167213, 0.03331530267106635, 0.016941716628415242, 0.01631279948300549, 0.014422265214047261, 0.02174123569524714, 0.044613728366260014, 0.01727821910753846, 0.07713885325938463, 0.03892878216824361, 0.030590363711650883, 0.03961840784177184, 0.04327834091548409, 0.057656212975936275, 0.04950270888262561, 0.051927894819527864, 0.052316305227577686, 0.029681649258626357, 0.059075463962342055, 0.06156915479472705, 0.0639975027048162, 0.05622848030179739, 0.024567225482314825, 0.06274960216666971, 0.013461570737750402, 0.07225961650588683, 0.058169158308633735, 0.032447008549102714, 0.02169767544338746, 0.09682827708976609, 0.0890573344326445, 0.025504677589716654, 0.049906467752797265, 0.10536231379956007, 0.08523809829992907, 0.04950974868344409, 0.07238495549453156, 0.026085454371890852, 0.026000454290104762, 0.13772279556308473, 0.07669745944440365, 0.01909913568358336, 0.02656475793836372, 0.017470112203487327, 0.028014559963984147, 0.04253489384427667, 0.04973532086504357, 0.03272348103512611, 0.02938844749171819, 0.09958757366985083, 0.06307351442852191, 0.1487183469746794, 0.16139092482626438, 0.11411858429866177, 0.06012281669037683, 0.10239009971597365, 0.01689185617890741, 0.06796337025506155, 0.03501136880367994, 0.0541134696852948, 0.045167965947517326, 0.05209180852398276, 0.045572929217347076, 0.046365359731550725, 0.04434113031519311, 0.04453146617327418, 0.09790912230632134, 0.050947428680956364, 0.010393657771471356, 0.022191489481234124, 0.05173622903281024, 0.019743401291114942, 0.031690737166042836, 0.02990898223859923, 0.061782472633889744, 0.03888639069295355, 0.039019526048962555, 0.0263615468783038, 0.09561345513377871, 0.07883706356265716, 0.020987953258944408, 0.032690938495631726, 0.020442981073366742, 0.04625204099076135, 0.06679865132485117, 0.004750050895381719, 0.026045980597180978, 0.034801623451390436, 0.07730751670897007, 0.028421387508777634, 0.02755184148970459, 0.13629894410925253, 0.031939701842410226, 0.0629858612748129, 0.03590579330921173, 0.04703857842832804, 0.06535736830638987, 0.08788426952170474, 0.08438490836748055, 0.015359033697417803, 0.04409515119290777, 0.03434092192245381, 0.0247601669148675, 0.0690342817189438, 0.04876976553350687, 0.04473232950216957, 0.054870633341904194, 0.03839632895376001, 0.11108677448438746, 0.11804738348083836, 0.4733615538903645, 0.8997010109680039, 2.4099946234907423, 2.6767181626388004, 13.741566998617989, 10.39258565221514, 37.211119243076865, 29.09041040284293, 19.39863916805812, 18.56578813280378, 23.95769098826817, 25.643400396619523, 15.350017649786812, 13.952661957059588, 17.158218588147843, 15.500423567635671, 16.7759564944676, 27.261337075914653, 20.454886947359356, 26.188688073839458, 36.832953112465994, 35.42900357927595, 12.564082707677569, 3.2298314656530107, 0.9242377600499562, 0.711119030203138, 0.39656756605420795, 0.11324497046215193, 0.04135248889880521, 0.08340093759553772, 0.08859992040587322, 0.015602722764015198, 0.083222985001547, 0.08761461970529386, 0.08246565849653312, 0.061628153414598534, 0.007468159975750106, 0.021548010974324176, 0.013481483196041413, 0.03276166898597564, 0.048979334466691525, 0.06827198833759342, 0.057556936517357826, 0.06228483960564647, 0.09064367466739245, 0.04730797379410692, 0.01652780857070216, 0.03369148927075522, 0.05483622822378363, 0.0169120425957122, 0.02166438821171011, 0.046838885572339804, 0.11773390030222279, 0.04198313970118761, 0.047149267845920155, 0.030803674765463387, 0.03865030121856502, 0.04813069411154304, 0.03206248953938484, 0.10424079719398703, 0.025513104994648268, 0.03861046103494508, 0.062297514639794827, 0.01702315440135343, 0.018728769218016948, 0.01362861503314759, 0.06312220610146012, 0.037263392603823116, 0.02068420366517135, 0.025030568208811537, 0.03210908114644034, 0.026942116707297306, 0.06162940191903284, 0.019735630368813872, 0.1254551945520299, 0.029627542876239334, 0.08100585825741291, 0.09466626095984663, 0.06108860272381987, 0.10700744230832372, 0.07121425867080688, 0.0784035814659936, 0.053087446705571244, 0.02018577728553542, 0.06802137142845563, 0.07432429000203099, 0.05831283809883254, 0.11524419247039727, 0.053184076877576966, 0.083393779051091, 0.051482246589979956, 0.07815560405807835, 0.011725006242548781, 0.057852526727531633, 0.054498202433543544, 0.055639725644141436, 0.055663447228393385, 0.09120883326977491, 0.28724151530436104, 0.21055814224694455, 0.2188017184713057, 0.15612343033509596, 0.16393966520471231, 0.14541481781218732, 0.18234951448227676, 0.28907301702669685, 0.1513350765619959, 0.17322374773877008, 0.20434265291052206, 0.09186425060033798, 0.09729654767683574, 0.19257298803755216, 0.27682440142546383, 0.14474855070667608, 0.12519288648452076, 0.14782183936664037, 0.19506234303116798, 0.39928735154015677, 0.5443232346858297, 0.3052464420241969, 0.18095456862023898, 0.21732024582368986, 0.2570475483579295, 0.17458095348307065, 0.19906612033290522, 0.21065741192017282, 0.1777775590973241, 0.2095502463302442, 0.1604814843407699, 0.08289118137742792, 0.18181481531688146, 0.1758638732135296, 0.2514537056641919, 0.16884824181241648, 0.1456989339951958, 0.0864420026274664, 0.08745735564402171, 0.12732306575136526, 0.12150267378560134, 0.05928260034748486, 0.1389664959694658, 0.1968221507434334, 0.09849811784390892, 0.10765521933457681, 0.19067319855093956, 0.28320811316370964, 0.13635535751070293, 0.10036494409931557, 0.1839632336050272, 0.1052187222189137, 0.2323583188865866, 0.09551294374146632, 0.1466453546392066, 0.16499230372054235, 0.11435820215514728, 0.11481282061764173, 0.1562574002891779, 0.14728503674268723, 0.10566769527005297, 0.1878501128937517, 0.09449577903641121, 0.12120791817350046, 0.15105135392929825, 0.2130095399916172, 0.10703716214214053, 0.0913159264517682, 0.12502029431717737, 0.17877269855567388, 0.15411726012825966, 0.24492910291467393, 0.17779691091605596, 0.1218654593186719, 0.0917960103335125, 0.11493967952472822, 0.35441466367670466, 0.1328795211655753, 0.2876567787357739, 0.3619569603885923, 2.010330766439438, 2.5913621485233307, 12.6590176820755, 20.537865809031896, 56.17897530964443, 46.50582177298409, 44.32215234211513, 62.11892427716936, 66.98920849391392, 52.52212449482509, 32.68057067053658, 32.15703780310494, 38.5129337310791, 25.250557933534893, 30.96719353539603, 61.47502776554653, 55.15052032470703, 53.7500170980181, 55.820476055145264, 49.25253847667149, 16.472982031958445, 2.903140412909644, 0.571972125342914, 0.547794945538044, 0.4921745072518076, 0.1559532673231193, 0.14584384193377836, 0.19969508158309118, 0.1334596143237182, 0.11095038216028895, 0.13897773250937462, 0.22291676194540092, 0.2514765315822193, 0.1692954913846084, 0.14478405165885175, 0.1259358823299408, 0.10192526930144855, 0.1804753736193691, 0.1585990653506347, 0.17091687795306953, 0.19581763393112592, 0.11629252907420908, 0.19649003499320575, 0.11804412651274886, 0.15388422406145505, 0.09639638276504618, 0.10787338869912283, 0.12648723274469376, 0.19750612761293138, 0.104069419604327, 0.22169275262526103, 0.20835629611143044, 0.19836030820650713, 0.20510604551860265, 0.22688144205936364, 0.11140676481383187, 0.1327724347689322, 0.27451398968696594, 0.1924797301845891, 0.13936748302408627, 0.09626957135541098, 0.07604184533868517, 0.11357283179781266, 0.14450928568840027, 0.20879370692585195, 0.12591540414307797, 0.09581578070563929, 0.09767743652420384, 0.10381641425192356, 0.12649997563234397, 0.12186228377478463, 0.12925144870366367, 0.19661123491823673, 0.14859296727393353, 0.1663592125156096, 0.18977907938616617, 0.18913911229797772, 0.2136753864054169, 0.2397888744516032, 0.18461895627634867, 0.2760758144514901, 0.28880032737340244, 0.2574127901877676, 0.30338106783373014, 0.3514145618038518, 0.3255015808556761, 0.1443967167288065, 0.14775788065578255, 0.19426116959324904, 0.15034892090729304, 0.10566540182168994, 0.18543779876615318, 0.10251887209181275, 0.20276143561516488, 0.16431136668792792, 0.18927931120353086], [0.06641067178653819, 0.10366753009813172, 0.07791286494050707, 0.04759352168600474, 0.054836007699902566, 0.021355771825515797, 0.04381267027929425, 0.04884807186733399, 0.040351005138031075, 0.028149807260238698, 0.05221742571198514, 0.014029925240070691, 0.043852300117058415, 0.02309517259709537, 0.019245480420067906, 0.0739364665267723, 0.05048028785469277, 0.07188332134059497, 0.11779498202460152, 0.05474644447011607, 0.02026213113484638, 0.06101009622216225, 0.048637356209967814, 0.15086881443858147, 0.04750367347151041, 0.022436620434746146, 0.019853826080049788, 0.02911244998020785, 0.02678442177628832, 0.053715220519474575, 0.056263543598886044, 0.0244023465617959, 0.027255581226199865, 0.06685264914163522, 0.02277110766486398, 0.02617447646999998, 0.056704618502408266, 0.015226254572293587, 0.022149498341605067, 0.06545427667775325, 0.014354545722848602, 0.04056345445236989, 0.016744052592132772, 0.07423289812036923, 0.019930904265493155, 0.013127767131663859, 0.00798255143620606, 0.024636008577155213, 0.03590502995731575, 0.10622616351715156, 0.028447182017511556, 0.046146294700780084, 0.025075336253004413, 0.060067000399742804, 0.041392905837191005, 0.011715763747426016, 0.030779837830258266, 0.026080507851604904, 0.03381717770493456, 0.0894841601007751, 0.0251360888858991, 0.038927523485784016, 0.028913327093635286, 0.05651103585426297, 0.02099293370598129, 0.0937473074133907, 0.041200310457497835, 0.05743983494383948, 0.0629249152594379, 0.0288473531337721, 0.133717362635902, 0.0570224341271179, 0.07496465742588043, 0.01815779217784958, 0.08440237385886055, 0.02982449105807713, 0.03290846664458513, 0.01579814593839858, 0.028894165264708654, 0.027333063139979328, 0.08010303348835025, 0.2296088949910232, 0.2780112677386829, 1.515922141926629, 6.041517734527588, 17.27650124686105, 12.763752222061157, 8.723973155021667, 6.520528282438006, 9.414740477289472, 5.978846286024366, 8.996188810893468, 8.62032687664032, 15.262803861073085, 7.836023773465838, 7.566996472222464, 5.961479697908674, 7.021753089768546, 11.638446296964373, 2.9025860769408087, 0.1485176363161632, 0.15885532088577747, 0.062355319038033485, 0.22434240473168238, 0.12043358758091927, 0.03577318721051727, 0.07822153052049023, 0.02324799564667046, 0.022014834585466554, 0.07012575957924128, 0.08265093926872526, 0.010274652059056928, 0.0848763237840363, 0.026849774876609445, 0.0544813069115792, 0.06045864402715649, 0.020825281273573637, 0.05742454754986933, 0.03794332540460995, 0.06986565675054278, 0.07291686588100024, 0.002955012584737103, 0.029491058949913298, 0.0010028616109463784, 0.05271811670224581, 0.045794087528650246, 0.1825205867311784, 0.030076658419732536, 0.08876794603254114, 0.06228868689920221, 0.047087758646479676, 0.014052848697506955, 0.06716309926871743, 0.01869399769098631, 0.021742077078670263, 0.026427395309188535, 0.029116158174084764, 0.02362460463440844, 0.02094428613781929, 0.018980095196249228, 0.03620079319391932, 0.04358882157664214, 0.06614747483815465, 0.018434815973575627, 0.006447049589561564, 0.04090934446347611, 0.028757420102400438, 0.040472659681524546, 0.0385413692066712, 0.03154542889179928, 0.042246119518365176, 0.026697650718103563, 0.05278557326112475, 0.04523281353924956, 0.02605646735589419, 0.040174497823630057, 0.08326010765241725, 0.028302433534658382, 0.010638753950063671, 0.026342793866725903, 0.06462744104542903, 0.028166768939367363, 0.04313848467011537, 0.12106089320565973, 0.042477608525327275, 0.07874585488545043, 0.02698002476245165, 0.04000446034063186, 0.05790770519524813, 0.12868206282811506, 0.024862992111593485, 0.04715365457481571, 0.04568595279540334, 0.02096514430429254, 0.048866775685123036, 0.029688444786838124, 0.015486823893817407, 0.05136783540781055, 0.07125815988651343, 0.03817332502720611, 0.04965349293446966, 0.0334819033741951, 0.01828193524852395, 0.06797489856502839, 0.05174713648323502, 0.07346471505505697, 0.01927482705962445, 0.00905063680173563, 0.011491421410547835, 0.014039372143867825, 0.03477959820468511, 0.036912569643131325, 0.04652474760743124, 0.11238452699035406, 0.06577728648803063, 0.09080883687628166, 0.07830952972705875, 0.10347950125911407, 0.12864804108228, 0.08661079499870539, 0.054279368104679246, 0.04089997728754367, 0.06479791618351426, 0.057108234880226, 0.0774469149432012, 0.11174981854856014, 0.08327411940055233, 0.05895088493291821, 0.029105511959642172, 0.043467200959899595, 0.013225368456915021, 0.03160049540123769, 0.0856633565521666, 0.04917104435818536, 0.026055922831541727, 0.020157390773030262, 0.04053825705445238, 0.010104936880192586, 0.09463479050568172, 0.029617663406367813, 0.04420515868280615, 0.029893959473286356, 0.013631829592798437, 0.014734510066253799, 0.03481391850592835, 0.09302626896117415, 0.0313386317741658, 0.007401072370287563, 0.039110259751656225, 0.06960028170474938, 0.03222821832501462, 0.06471411032336098, 0.019511366063462834, 0.055503404566219876, 0.031980349482702355, 0.09575692457812172, 0.024024483980610967, 0.029057315617267574, 0.03895473613270691, 0.00696844607591629, 0.032324644936514754, 0.046557656555835686, 0.024313261699197546, 0.06641994736024312, 0.037476510275155306, 0.06396177783608437, 0.02122884676126497, 0.011224048079124518, 0.045971066424889226, 0.028585730386631827, 0.03642844508535095, 0.026952886754380803, 0.08890577006552901, 0.05269962323031255, 0.05549898391057338, 0.10423551819154195, 0.10625315564019339, 0.6194563316447395, 1.5087867762361253, 2.552938393184117, 8.757792643138341, 23.55402844292777, 22.04810541016715, 27.534401280539377, 27.555647134780884, 23.352030413491384, 18.95699950626918, 18.10330387524196, 19.482066188539775, 22.953648499080114, 21.95034773009164, 26.906344924654277, 26.76911105428423, 24.509989397866384, 19.484015158244542, 3.6647734982626776, 0.1299826516104596, 0.11742242558726243, 0.24435853638819285, 0.17851553378360613, 0.024417661097166792, 0.079668906783419, 0.04440364035378609, 0.03169920189040048, 0.07211120054125786, 0.09358356334269047, 0.03970809320786169, 0.09207763629300253, 0.02691920766873019, 0.10332463242645774, 0.041611723202679834, 0.03579428964959724, 0.020119175680779984, 0.05026161976690803, 0.02793866073313568, 0.024849205976352096, 0.07391613761761359, 0.059327512580369196, 0.041262644076985974, 0.02379859288755272, 0.06941106542944908, 0.017965631060568348, 0.04841087818411844, 0.02890299300530127, 0.11331132440162556, 0.008921191828059298, 0.023637462873011827, 0.045968348892139535, 0.03876197451193418, 0.07098771618413073, 0.044834370990949016, 0.0070216377082813, 0.11988833041063376, 0.03387150461120265, 0.039014681308929405, 0.01490311075135001, 0.02521305680940194, 0.0124115242256916, 0.027693679057327763, 0.011719390517100692, 0.010446092413206185, 0.10635717505855219, 0.032462631817907095, 0.029008936070437943, 0.022073806063937287, 0.09400532035423176, 0.041399250139615366, 0.007414663426711091, 0.034402678787176094, 0.06157613692006894, 0.04501224555341261, 0.08623762109449931, 0.015790447958612015, 0.09828457608819008, 0.10652506497821637, 0.07346007387552943, 0.07606431841850281, 0.022817845156948482, 0.11197803701673235, 0.09196833787219864, 0.05163741397804447, 0.0989266127081854, 0.04229858045333198, 0.05478164686688355, 0.04136712150648236, 0.041173823843044896, 0.07041087320872716, 0.0684318986854383, 0.08730115009737865, 0.044105152799082656, 0.05024845618754625, 0.06417046806641988, 0.15465373705540383, 0.29952612040298326, 0.16479721133198055, 0.16019333765975066, 0.2235838568636349, 0.14825846308044024, 0.11746821313032083, 0.11847081647387572, 0.18808769514518126, 0.17143176389592035, 0.17129008578402655, 0.1113916877657175, 0.1591992024332285, 0.10217729077807494, 0.21662443530346664, 0.2781946079007217, 0.1375266718012946, 0.11280307453125715, 0.23978515607970102, 0.39940101972648073, 0.33805784423436436, 0.2622792162001133, 0.2110341074211257, 0.19970550388097763, 0.2953637423259871, 0.1730255340891225, 0.19918905730758393, 0.2798305015478815, 0.21224473603069782, 0.26568540771092686, 0.2242068877177579, 0.11447109681155, 0.11980569841606276, 0.2588896352265562, 0.11871708397354398, 0.1040958214019026, 0.19788609365267412, 0.10098259417074067, 0.16773821280470916, 0.14076510231409753, 0.14072569300021442, 0.11482386716774531, 0.15789485456688063, 0.13818265231592314, 0.16441541324768746, 0.18321740148322924, 0.16301742754876614, 0.12221269282911505, 0.19936828554740973, 0.2632036523095199, 0.09070195404014417, 0.18040350319019385, 0.12646967225841113, 0.1353666234229292, 0.13129891455173492, 0.19411031768790313, 0.11884510996086256, 0.1416393539735249, 0.12406358708228384, 0.16694963297673635, 0.09178967960178852, 0.19368408913058893, 0.10178471077233553, 0.12475662917963096, 0.2005884950714452, 0.18456172863287584, 0.1437975295952388, 0.1672618133681161, 0.1284725990678583, 0.19825039910418646, 0.2709860961352076, 0.08174778880285365, 0.11772579859410014, 0.11509062642497675, 0.19128990545868874, 0.11630422701793057, 0.14956993556448392, 0.1638168775077377, 0.12860275565513543, 0.18630738210465225, 0.23440231063536235, 0.4691654390522412, 0.6510254719427654, 2.115896050419126, 14.77527482169015, 42.67015559332711, 47.000735010419575, 54.144636562892366, 53.4220586504255, 64.8885109765189, 71.97158105032784, 56.73093673161098, 55.550357886723106, 57.35989114216396, 41.69332224982125, 71.34004538399833, 58.354202679225374, 50.13668979917254, 34.71027149472918, 7.72214366708483, 0.4238990108881678, 0.31582073175481384, 0.30094420430915697, 0.2943776952368872, 0.24955760740808078, 0.21333945728838444, 0.2018214339124305, 0.19553952956838266, 0.1252346978123699, 0.3007764161697456, 0.15644065902701446, 0.31836732796260286, 0.1465012745133468, 0.2790538232241358, 0.13807043619453907, 0.09938140758978468, 0.10628798484270062, 0.18262213628206933, 0.1801013515463897, 0.18771987488227232, 0.15246703582150595, 0.1263595867369856, 0.1555325077580554, 0.137464612988489, 0.2413505363677229, 0.1468946755464588, 0.22176241103027547, 0.10359063850981848, 0.1769188323191234, 0.15057769577418054, 0.20125445005084786, 0.15545915812253952, 0.14093609313879693, 0.21181366273335048, 0.1410330557929618, 0.19205447871770176, 0.34687551536730354, 0.13533181457647256, 0.22316425080810273, 0.1440116073936224, 0.14455672885690415, 0.14642896982175962, 0.18881238411579812, 0.14727590366133622, 0.08941206575504371, 0.1966729001807315, 0.10222616565546819, 0.1811253016016313, 0.2161324838442462, 0.20838966646364757, 0.11795385421386786, 0.09184784362358706, 0.20197406357952527, 0.20456776368830884, 0.26189785237823215, 0.1446850262582302, 0.23734978533216886, 0.2041967271694115, 0.2967074859355177, 0.23033218617950166, 0.2748086095920631, 0.16209253003554686, 0.3944219026182379, 0.3313738671796662, 0.2635772536907877, 0.2829831652343273, 0.158718093963606, 0.16180720606020518, 0.20005964487791061, 0.2930092529526779, 0.19246151830468858, 0.10630176588892937, 0.10788471344858408, 0.18560024004961762, 0.08840879066182034, 0.20266345515847206], [0.07020171478922878, 0.061988536933703084, 0.0618402295346771, 0.07193686453891651, 0.02725952860367085, 0.18853560968169145, 0.0520438937736409, 0.009255820702362274, 0.03267959678279502, 0.026687718661768094, 0.055956665958677015, 0.027561834614191736, 0.008420925770354058, 0.02934213069134525, 0.06705669819244317, 0.06693735745336328, 0.023324101830699613, 0.08145006799272128, 0.0510327069621001, 0.04521184002182313, 0.04011454925473247, 0.09798356438321726, 0.043211678242576976, 0.1403360781925065, 0.10957284072147948, 0.044518828458551846, 0.03948178481576698, 0.01324313080736569, 0.047068973404488394, 0.06371954761977706, 0.03869383263268641, 0.12117841547088963, 0.043512174260935614, 0.02461280267951744, 0.047136090695858, 0.051900373439171484, 0.03276392511491265, 0.07671356786574636, 0.015412729566118546, 0.005359293069756989, 0.03749471536970564, 0.04249375765877111, 0.027699217599417483, 0.04700273142329284, 0.07081969055746283, 0.010253843934541302, 0.10040781394179378, 0.016755798033305576, 0.018824271325554167, 0.034114939227168045, 0.07342769418443952, 0.08765485004654952, 0.03777772214795862, 0.04776117751108749, 0.023848268436267972, 0.1336587236395904, 0.014354208151676824, 0.030589047353714705, 0.07064563275447913, 0.08056300559214183, 0.02101730668385114, 0.06774427129753999, 0.04045790833021913, 0.06111192397241082, 0.01962818774128599, 0.058679986612073014, 0.051199718178915124, 0.032210732477584055, 0.02524703275412321, 0.03891043458133936, 0.051910907695336, 0.060931406516049585, 0.053309392117496045, 0.011815131808231984, 0.06590851516063724, 0.03782669880560466, 0.030555022215204578, 0.03677467775664159, 0.029227509163320065, 0.054463206989956756, 0.06381030846387148, 0.0452593476511538, 0.06130831914820841, 0.13152743157531532, 0.20482544414699078, 0.7363739407488278, 2.580683852945055, 9.157864706856863, 15.041772978646414, 5.515182571751731, 13.24786274773734, 11.951043145997183, 13.73737462929317, 16.882218769618444, 12.568478311811175, 3.9911581788744246, 0.8575757656778608, 3.351189353636333, 1.743337658899171, 0.14851857269448893, 0.14571121547903332, 0.0402869344688952, 0.07397996740681784, 0.056785903604967256, 0.13002605071025236, 0.12754462100565434, 0.02792723589975919, 0.020327572444719926, 0.03056863023500357, 0.05164088807733996, 0.04648661733205829, 0.041147201521588225, 0.0495475464766579, 0.037696657569280694, 0.07440211118331977, 0.01764800712200148, 0.05128188198432326, 0.06161586514541081, 0.0672259112553937, 0.016727177426218987, 0.024926123009728532, 0.11175279053194181, 0.02325439253555877, 0.03355476785717266, 0.03741345401587231, 0.05526810558512807, 0.012352056568488479, 0.0669029082304665, 0.08718216898185865, 0.006395552174321243, 0.05733462130384786, 0.03144434753007122, 0.075291894509324, 0.0492199226282537, 0.0327901029959321, 0.07945681030728988, 0.07247770444623061, 0.014609678282535501, 0.020621183028976833, 0.03577523299359849, 0.03162721611027207, 0.041769241714583974, 0.01887472210052822, 0.03807366519634213, 0.051936559711716006, 0.03717938657583935, 0.041722775636506934, 0.029814034833439758, 0.023715709835024815, 0.05972801787512643, 0.0353068843750017, 0.03996284239526306, 0.0479779999836215, 0.02852137473278812, 0.014017853253920163, 0.09041682005460773, 0.060160767153969834, 0.06819377360599381, 0.0457700164988637, 0.04400885510923607, 0.04412095927234207, 0.0626575860327908, 0.06297008533562932, 0.044952449654894214, 0.1107464823871851, 0.08339498684342418, 0.041468202868210416, 0.041639057985906086, 0.033219914218144755, 0.0693376072283302, 0.04072090171809707, 0.01702882186509669, 0.04025814083537885, 0.07940205931663513, 0.03648245647283537, 0.021303575519206266, 0.03425804904795118, 0.012260541702354593, 0.036778226494789124, 0.017879623354279568, 0.040830980454172404, 0.027714303129219582, 0.07368890981056861, 0.008434411653849696, 0.02370209842255073, 0.016708271744261895, 0.04775106055395944, 0.019228245630594235, 0.07230085786432028, 0.036126042383589914, 0.020756733969652226, 0.08125604768948895, 0.04872434100668345, 0.05533279372113092, 0.03188403143680521, 0.09310417156666517, 0.06352040437715394, 0.027538340339171033, 0.06904621714992182, 0.12467771555696215, 0.08308117118264947, 0.03195441248161452, 0.06930851164673056, 0.01933649741113186, 0.06750837859830686, 0.07953276551727738, 0.029921728518924544, 0.04642814118415117, 0.07050820227180209, 0.03367371504594173, 0.04720677029607551, 0.09525788242795638, 0.06853590453309671, 0.08243276990417923, 0.07583812198468617, 0.05432182404079607, 0.03122837661898562, 0.10068968417389051, 0.07626164318727595, 0.04358341365254351, 0.031068490019866397, 0.07709626161626407, 0.032585314341953824, 0.07666752926473107, 0.04044289235025644, 0.030930286007268087, 0.027836564961554747, 0.02402888936921954, 0.018518689687230756, 0.034876547288149595, 0.04915714796100344, 0.09822183195501566, 0.021049520133861473, 0.019241667053263103, 0.049798244809997935, 0.013024752793301429, 0.05203427553975156, 0.030504121910780668, 0.005170306224109871, 0.023259415391034315, 0.04062638857534953, 0.08834905922412872, 0.059575442490833144, 0.04926022421568632, 0.035630813600229364, 0.022030632577038238, 0.01860170335774975, 0.017940610081755688, 0.024355010262557437, 0.04165885763775025, 0.052290412331266065, 0.029286558673317944, 0.039420601313135455, 0.049825328535267284, 0.027540537096293907, 0.06788410379418305, 0.046605191326567104, 0.02326490813201027, 0.07804791376526866, 0.20535087452403136, 0.1631675466362919, 0.9948572963476181, 4.176623838288443, 8.908914225442068, 21.86604871068682, 23.462286165782384, 34.2092091015407, 29.225617136274064, 28.334015607833862, 36.80611569540841, 37.169047900608604, 25.24265956878662, 12.717532805034093, 8.348298822130475, 2.0025123059749603, 0.13705795338111265, 0.0799837266760213, 0.035301004869065115, 0.13264682436628, 0.04458728585658329, 0.13483797678990023, 0.04927789666024702, 0.05622790693970663, 0.045340469905308316, 0.024629367415660193, 0.025395004278314964, 0.02051738922351173, 0.030093394485967498, 0.017684456326865723, 0.040288352607084174, 0.05396478569933346, 0.01798541714171214, 0.04771553924573319, 0.0645316658275468, 0.06749718277049915, 0.01944259993199791, 0.02195338984685285, 0.03716365474143198, 0.0619581046381167, 0.029925847226487737, 0.05427791264706424, 0.04069335658901504, 0.017862242679776888, 0.015218110455732261, 0.07072124191160713, 0.06912297303123133, 0.03335239818053586, 0.008647226528929812, 0.006751671524917973, 0.04259653535804578, 0.08001008776149579, 0.0787497836032084, 0.06842524225690536, 0.04029432371524828, 0.04044750978105834, 0.07562254462391138, 0.07486158117119755, 0.06668383641434567, 0.009390159609860607, 0.01778982433357409, 0.03972928385649409, 0.06818628257938794, 0.016809914593717883, 0.0556624837086669, 0.027361057798511217, 0.03774240440023797, 0.03964361541771463, 0.08993623405694962, 0.03393169406003185, 0.02123403755415763, 0.11992303069148745, 0.05990840640983411, 0.06985553300806455, 0.04511783578033958, 0.03963766127292599, 0.05551550963095256, 0.061413580285651345, 0.03727529410805021, 0.1366502759712083, 0.05432396481877991, 0.21568921048726353, 0.11076419893652201, 0.08860851065920931, 0.09457214815276009, 0.01778317299405379, 0.027229145501873324, 0.05368775681459478, 0.11400799666132246, 0.040889351429151635, 0.05500049815912332, 0.05022698055420603, 0.029348122155559913, 0.17508365293698652, 0.1472978474838393, 0.18399935880942003, 0.15080113735582146, 0.13073095359972545, 0.2980227310742651, 0.20951960368880204, 0.10466800284172807, 0.1313770410737821, 0.11777170827346188, 0.15910196836505616, 0.07598215461309467, 0.12905271936740192, 0.14434869002018655, 0.1752094669001443, 0.24908504847969326, 0.15538143872150353, 0.21527752972074918, 0.1852321076606001, 0.23649135710937635, 0.2725178210863045, 0.23395048773714475, 0.19090128131210804, 0.3416651263833046, 0.2295453841132777, 0.1942567184035267, 0.14040071543838295, 0.14032961853912898, 0.1022675766476563, 0.1350893061608076, 0.1863019402538027, 0.14041121916047164, 0.1563428957015276, 0.1563420814595052, 0.15459033474326134, 0.23441270579184803, 0.16793591076774256, 0.1490248412426029, 0.1907917521893978, 0.09026621920721871, 0.1302431004920176, 0.17857550270855427, 0.1821751445531845, 0.19719773344695568, 0.15462327083306654, 0.18832394746797426, 0.13321922293731145, 0.23814128286072186, 0.1040475300646254, 0.10337500686624221, 0.10873304507029907, 0.1510388417435544, 0.1361667654876198, 0.08399595173874072, 0.1633069720119238, 0.25915966502257753, 0.0881343503881778, 0.09945692853736025, 0.21569750218519143, 0.15324839603688034, 0.13367457421762602, 0.16075977869331837, 0.16264758525150164, 0.12112121496881757, 0.07526201861245291, 0.2152017102177654, 0.14751063606568746, 0.12267994561365672, 0.09293227150504078, 0.12175335176289082, 0.10615109718803849, 0.12726910864668234, 0.10812142038983957, 0.23725441044994763, 0.23226364968078478, 0.08630896226636, 0.11817545018025807, 0.1351514599685158, 0.13408683852425643, 0.1282536629587412, 0.14447143700506004, 0.15468736525092805, 0.35516919461744173, 0.4072614407965115, 0.21686314392302716, 1.6495834439992905, 9.23541702542986, 37.16043560845511, 64.870758329119, 50.62775373458862, 53.414769990103586, 46.85794952937535, 47.34490360532488, 57.77103342328753, 61.09168175288609, 52.314647810799734, 37.312555994306294, 16.683505501065934, 3.725670550550733, 0.4602496517556054, 0.3405599014035293, 0.13028895588857786, 0.2673386718545641, 0.1312194038182497, 0.21991188318601676, 0.15274940138416632, 0.09661409751112972, 0.17256628801780088, 0.09350992193711655, 0.2653037453336375, 0.14761504903435707, 0.13041253068617412, 0.11588559805282525, 0.22715776866035803, 0.1492256468960217, 0.1492494499044759, 0.167939601998244, 0.18472726403602532, 0.2044372678335224, 0.08332458883523941, 0.11261621277247157, 0.20927481539547443, 0.23629889743668692, 0.13814168237149715, 0.1885859298386744, 0.13089688255318574, 0.12189188147229807, 0.126921468015228, 0.1514825765043497, 0.09229162588183369, 0.13007681870034762, 0.13906496497137205, 0.2913123725780419, 0.14502718432673387, 0.20421801959829672, 0.16135957650840282, 0.12070824498576777, 0.15616259537637234, 0.08835247225527253, 0.149818197957107, 0.23804267815181188, 0.12818491379065172, 0.13983990624547005, 0.12816839824829782, 0.11720823922327586, 0.1684476618788072, 0.18526798859238625, 0.12392033476914678, 0.11032148876360484, 0.1586169379630259, 0.1424776432769639, 0.12171466169612748, 0.12861731701663562, 0.15764045821768896, 0.22335310067449296, 0.24651635917169706, 0.20957276012216294, 0.3056425707680838, 0.14431264623999596, 0.18582146960709775, 0.19644143831517014, 0.22512787686926977, 0.216419232743127, 0.19836040320140974, 0.5251858330198697, 0.18157112625028404, 0.13110838191849844, 0.15165330948574202, 0.10591409169137478, 0.11308421194553375, 0.09352267839546714, 0.1888976488262415, 0.11781961284577847, 0.17130455215062412, 0.16799138779086725, 0.2475692555308342], [0.012991565645539334, 0.0014721260397761527, 0.0697466620643224, 0.04636255738192371, 0.05874265610639538, 0.03124944513131465, 0.04356434342584439, 0.04009676824456879, 0.0412347189682935, 0.0252853682863393, 0.061991325712629726, 0.05851209669240883, 0.014079342945478857, 0.10483812514160361, 0.052665910217911005, 0.051497337208794694, 0.028896550315299203, 0.030987659535769905, 0.03943363597084369, 0.06830611186368124, 0.02895602390968374, 0.023138917749747634, 0.04618521546944976, 0.05944052258772509, 0.023801837981279408, 0.0155626841089023, 0.020414341806567142, 0.047589402978441546, 0.04625742516613432, 0.04452042640852077, 0.03799869046945657, 0.02657729896184589, 0.009242551950072604, 0.03680844844451972, 0.01382063705075, 0.04482024728453585, 0.04498384886288217, 0.03437534739662494, 0.01628299822498645, 0.020927180269999162, 0.032993575291974206, 0.05663126547421728, 0.009707511286251247, 0.03174908099962132, 0.06342570124460117, 0.00042465425004983056, 0.0626036153574075, 0.047636713832616806, 0.02807680537391986, 0.04831122513860464, 0.05363205926758902, 0.028167271055281162, 0.038883561201925786, 0.012308674432071192, 0.019796194708240882, 0.08474085426756314, 0.037345590335982184, 0.018305970655222024, 0.02091306504527373, 0.006975269169613186, 0.0359525443719966, 0.02303520536848477, 0.017304936423897743, 0.03915358081992183, 0.018386948720685074, 0.036651822206165106, 0.05436055821233562, 0.017008888202586343, 0.027526978270283768, 0.02570654345410211, 0.0740838579035231, 0.035678426402487924, 0.002336715148495776, 0.018744289010230984, 0.04939733239422951, 0.013539665029384196, 0.023800061915868094, 0.02529326982663146, 0.04537557730717318, 0.030442795915795223, 0.03267013121928487, 0.028372439688869884, 0.029344064516148398, 0.01033609510133309, 0.11874122624950749, 0.03225302217262132, 0.051959324561591656, 0.08019266796431371, 0.3300520809633391, 3.1013073793479373, 23.445862361363, 28.187142848968506, 24.691104616437638, 23.297143118722097, 14.301330379077367, 7.154797196388245, 1.6311469418661935, 0.3552265986800194, 0.06471307216478245, 0.1270545558737857, 0.023236716698322977, 0.029039945120790174, 0.04778986597167594, 0.041745805115039857, 0.05662856151216796, 0.022021360396008407, 0.06433044626776661, 0.011658533559446889, 0.04752037900366953, 0.04841387052355068, 0.01702514081262052, 0.038192225620150566, 0.06331538502126932, 0.019928432701687728, 0.07760474218853883, 0.07904978429100343, 0.04480502774406757, 0.03982579189219645, 0.031079801198627268, 0.019433275164504136, 0.015016149596444197, 0.042123247004513226, 0.027676493461642946, 0.07099653035402298, 0.033489716704934835, 0.049208730193121095, 0.04296775847407324, 0.044322345073201826, 0.03481104151744928, 0.022679276431777647, 0.048012042085507085, 0.05256811296567321, 0.02751722263305315, 0.05878419602023704, 0.022694865773831095, 0.08305603824555874, 0.023796843963542154, 0.05108553430597697, 0.04973939886050565, 0.02301711223221251, 0.01918703650257417, 0.03343747629384909, 0.04367526354534285, 0.010204335475074393, 0.1087318304926157, 0.03983649578211563, 0.04732832305931619, 0.010360547807067633, 0.024541656586474607, 0.034602894115128686, 0.027593780042869703, 0.08429728914052248, 0.01224163856490382, 0.04547553230077028, 0.025138623214193752, 0.06764419416763953, 0.019250235254211084, 0.024829947456185306, 0.04417787139703121, 0.020045624181096042, 0.005229649624587702, 0.04822492226958275, 0.04946196285475578, 0.03548524069732853, 0.02095628433328654, 0.01641926502010652, 0.045369782618113925, 0.0455044887826911, 0.07543334870466165, 0.06844523189855473, 0.031332714948803186, 0.03142137911968997, 0.04626954040889229, 0.051716463307717016, 0.07191043559994016, 0.049934711772948503, 0.029454129681523358, 0.05602282990834542, 0.03330586085628186, 0.0481244414113462, 0.03713822324893304, 0.047783077228814363, 0.05320957283090268, 0.03752311545291117, 0.02632310108414718, 0.045241929657225094, 0.04512240232101508, 0.012626400150890862, 0.05419586419260927, 0.05374200568933572, 0.019407872509743487, 0.025748220771285038, 0.039407563262752125, 0.03328121307172945, 0.021491606054561477, 0.06769053810941321, 0.028695971971111636, 0.023185329545023184, 0.04133089791451182, 0.0609513825869986, 0.06142486432301147, 0.013437654074680592, 0.07694216631352901, 0.022643130871334245, 0.021490747707762888, 0.021751364526738013, 0.02573654827262674, 0.021902224913771664, 0.03176903671451977, 0.054286245057093244, 0.03150954117466297, 0.02864602840106402, 0.07176107647163527, 0.05604295525699854, 0.010048366567519094, 0.04479271911882928, 0.05198481033689209, 0.026818265406680957, 0.03252265163298164, 0.014624260000086256, 0.015423365602535861, 0.022768848143251877, 0.023663289612159133, 0.06372921674379281, 0.03582194334428225, 0.04127198411151767, 0.02890025172382593, 0.02273438365331718, 0.05180495445217405, 0.023966209696871892, 0.014316613918968608, 0.12960514186748437, 0.03197548099394355, 0.031317746466291804, 0.05683299732793655, 0.05448324412905744, 0.01885053402345095, 0.09714824027780976, 0.033120183141103814, 0.03463582681225879, 0.036635527187692266, 0.07499648750360523, 0.041734636428632906, 0.031075523035334687, 0.053505600696163516, 0.04088540914069329, 0.09176552375512463, 0.014593267913109489, 0.019108055026403496, 0.06266272932823215, 0.09609427861869335, 0.0273006461294634, 0.0260799582382398, 0.036022945772856474, 0.02566635043227247, 0.049058305764836926, 0.057940322373594554, 0.008035645105077751, 0.034938076843640635, 0.10744169114955834, 0.06927930071417775, 0.05361162857817752, 0.08641185531658785, 0.11317624165011303, 2.3344761729240417, 5.957327714988163, 19.993613413402013, 26.240502527781896, 25.737020424434117, 24.9649452822549, 13.762587036405291, 7.644851905958993, 1.6751203536987305, 0.15130492246576718, 0.04697276053151914, 0.0434833161665925, 0.01674841726864023, 0.0736074788229806, 0.05613975506275892, 0.0245633968484721, 0.07454304969204323, 0.06242155084120376, 0.03680360370448657, 0.05053793618987713, 0.022501798812299967, 0.014290607368041362, 0.03757288599652903, 0.016984272648447325, 0.08385799199874912, 0.027667287437777435, 0.07448647344218833, 0.09125555040580885, 0.013048715257484998, 0.01903653234642531, 0.02115426049567759, 0.06542173413825886, 0.06314298284373113, 0.03610483477158206, 0.03196495013045413, 0.07104957822178092, 0.04525730526074767, 0.036132817555751116, 0.030471440271607468, 0.05122045760176011, 0.03871142704571996, 0.005347773665562272, 0.08322343962000948, 0.04720397473179868, 0.04950815073347517, 0.039164681652826924, 0.03759302491588252, 0.060767676016049724, 0.017005181705046977, 0.034809165368122716, 0.03275973516117249, 0.03686637158638664, 0.017758063805688704, 0.06559965959084885, 0.07561161342476096, 0.037242588720151355, 0.05967498357806887, 0.040924502935792716, 0.01961102250165173, 0.0693846500611731, 0.05821267954472985, 0.018142246940572346, 0.05362843928326454, 0.010515645645292742, 0.015545905634228672, 0.028266065753996372, 0.04290060047060251, 0.04571937743042197, 0.02532864864250379, 0.05322534537741116, 0.024834113661199808, 0.020909624872729182, 0.06124908982643059, 0.02780108436542962, 0.07623789446162325, 0.0523798568174243, 0.016437085046033775, 0.02162763536242502, 0.05079355050942727, 0.05030978557520679, 0.012477869683477496, 0.03704119613394141, 0.044931635593197176, 0.03120090952143073, 0.022964437558714832, 0.04495139792561531, 0.03223658466179456, 0.011731642315031161, 0.09416996009115662, 0.20524093828030995, 0.12800979747303895, 0.2085520670350109, 0.09000815876892634, 0.16588501153247698, 0.16882751935294696, 0.20893885913704122, 0.09363249928823539, 0.12739275129778044, 0.16512977491532052, 0.12421737025891032, 0.13250567551170075, 0.18148301169276237, 0.20803509120430264, 0.1552156319043466, 0.12942853277283056, 0.23350846288459642, 0.13439056436930383, 0.21712451561221055, 0.17760131641158036, 0.1119130537179964, 0.12495280722422258, 0.18535554675119265, 0.134866203846676, 0.09034395217895508, 0.1346913589430707, 0.12696721484618528, 0.10085800835596663, 0.10168418580932276, 0.1982944631682975, 0.08000483590045146, 0.15797284538192408, 0.17011453743491853, 0.10560987730111394, 0.16503617779484817, 0.1338582400764738, 0.11850185266562871, 0.12744160581912312, 0.18316185660660267, 0.10034441162965127, 0.13176734798720904, 0.07781856214361531, 0.10200074275157281, 0.14201163899685654, 0.07126622766788517, 0.09905326805476632, 0.2524418154997485, 0.06668116977172238, 0.123883775302342, 0.1599670598017318, 0.0716803375897663, 0.1670415201889617, 0.07610678113996983, 0.08759526110121182, 0.27791646282587734, 0.10900979236300502, 0.23886872668351444, 0.11923815815576486, 0.12723695965749876, 0.0845148071114506, 0.16491698633347238, 0.09980626550636121, 0.09944375817264829, 0.16206948698631354, 0.194599555007049, 0.16345919455800736, 0.09995266622198479, 0.15420029924384185, 0.13299913331866264, 0.16555464640259743, 0.1258557473442384, 0.12136828313980784, 0.1978261654398271, 0.15273469074496202, 0.08000741433352232, 0.06281003249543053, 0.2101329450628587, 0.1371862372117383, 0.1179676963282483, 0.14004593661853246, 0.15770362982792513, 0.26920089764254435, 0.2901725694537163, 0.2847007544977324, 0.2200670912861824, 0.13226008654705115, 1.1749354962791716, 5.832226702145167, 24.400480576923915, 41.94385692051479, 49.54852131434849, 46.95338303702218, 46.922011920383994, 35.39542293548584, 18.541721309934342, 3.044623540980475, 0.9014570595962661, 0.2287792366530214, 0.26223595280732426, 0.11356063852352755, 0.2513191657406943, 0.13695263117551804, 0.2064739449747971, 0.17681158307407582, 0.16484127539609159, 0.17693206375198706, 0.15075107504214558, 0.15547978558710643, 0.1816141860825675, 0.12522241632853234, 0.09841909565563713, 0.2575544411582606, 0.10837712631161724, 0.17507521196135453, 0.2315921171435288, 0.11282908277852194, 0.0873556500300765, 0.19331173625375542, 0.17203530722430774, 0.16869361725236687, 0.07048533564167363, 0.09650222744260516, 0.16138244313853128, 0.1994462085089513, 0.11545326268034321, 0.14835043171686785, 0.17583195492625237, 0.11568434456629412, 0.11776828845696789, 0.21385658239679678, 0.1279023446674858, 0.19311610103717872, 0.25444623508623665, 0.1229216397872993, 0.17928333686930792, 0.13334427694124834, 0.10447751092059271, 0.1435858402401209, 0.14516599902084895, 0.1468728402895587, 0.12695342701460632, 0.12284374396715846, 0.1318489078964506, 0.21857025660574436, 0.11833578800516469, 0.15127026289701462, 0.19191142996507032, 0.14196374799524034, 0.20419009109692915, 0.11635849624872208, 0.1685785377132041, 0.09172491343425852, 0.11343774904630013, 0.13494646096868174, 0.14992817491292953, 0.09503318555653095, 0.1533897348812648, 0.13332856207021646, 0.13097233564725944, 0.19731289441032068, 0.14788161830178329, 0.18646036460995674, 0.16221586056053638, 0.10227700828441552, 0.12007635246430125, 0.23467008769512177, 0.2745991594025067, 0.12704919544713839, 0.19266338247273648, 0.09730573504098824, 0.07499327803296701, 0.09496080622609172, 0.11635507643222809, 0.252238254994154, 0.11436755236770425], [0.025844683005873646, 0.056690532115421126, 0.0477869245223701, 0.037344731989183595, 0.03038884898913758, 0.013868030177296271, 0.016201801331979886, 0.06070774101785251, 0.03418769175186753, 0.05562029918655753, 0.027532496456322924, 0.03384322666430047, 0.002662881206820852, 0.02087134531965213, 0.060756866953202655, 0.03547070308455399, 0.01318523650323706, 0.03163858835718461, 0.007030641443894378, 0.04121060383373073, 0.022695702068241577, 0.015296800161844917, 0.02533428217949612, 0.023624280633937036, 0.016775585810786912, 0.0407679784776909, 0.034208553311015875, 0.02122739130364997, 0.06579615654689924, 0.04886651784181595, 0.024562455381133726, 0.028868957688765864, 0.03456155436911753, 0.030523921562624828, 0.07041552795895509, 0.056869882491550276, 0.04762942297384143, 0.06168952690703528, 0.06772688723036221, 0.04615379590541124, 0.045029324279831986, 0.010013076809367963, 0.04680351014914257, 0.01865264098159969, 0.01613415478329573, 0.054713437134133916, 0.043097253489707193, 0.017777753195592334, 0.06362171644078833, 0.009478560000258898, 0.006269013450946659, 0.03837849026811974, 0.004482324725748705, 0.0052962711613093105, 0.03361259261146188, 0.033072343029614, 0.05516562983393669, 0.041710036141531806, 0.04726170788386038, 0.04375650454312563, 0.03342771217493074, 0.03971713807966028, 0.14753760104732855, 0.028202246142817394, 0.03906895053972091, 0.07457406552774565, 0.00939947589566665, 0.015317095144252692, 0.06946726848504373, 0.024119397459019507, 0.010381560340257627, 0.05996306240558624, 0.03388737215261374, 0.012617009226232767, 0.03743839017780764, 0.10800017975270748, 0.01969441954445626, 0.05156968939783318, 0.02966249082237482, 0.02952068718150258, 0.03747120073863438, 0.03769604010241372, 0.06530398117112261, 0.01955503996993814, 0.1157763267734221, 0.016811232647991607, 0.043984502487416775, 0.06151120111878429, 0.08883199295295136, 0.250499712569373, 0.9273303598165512, 1.033359544617789, 2.3929374473435536, 0.8785009171281541, 0.28068057021924425, 0.01952877557570381, 0.06902836489358119, 0.015771735659135238, 0.02467878512106836, 0.05345994546743376, 0.03096559696963855, 0.03304479450785688, 0.02770162809507123, 0.03711913266618337, 0.006846634197115366, 0.0062902320891485685, 0.03648173383304051, 0.0342921284692628, 0.03481572001640286, 0.0374798249187214, 0.0382808660423117, 0.05359864481059568, 0.044905104873968024, 0.145997231560094, 0.02968511657257165, 0.06439300041113581, 0.043768918341291804, 0.06841420249215194, 0.02091258328541049, 0.00893253947807742, 0.06811613562916007, 0.0562325922240104, 0.03261815543685641, 0.036034565685050826, 0.038517325318285396, 0.04512504521491272, 0.04331865607361708, 0.05299946785505329, 0.038660771013902764, 0.003236659748446462, 0.031126084072249274, 0.002235847313256402, 0.013664348383567162, 0.04990561279867377, 0.08031348112438406, 0.020079705298745205, 0.01774269498751632, 0.04171208531728812, 0.057144319372517724, 0.031750380394182036, 0.02259800998893167, 0.020647747674956918, 0.03659642660724265, 0.039147921837866306, 0.017613705480471253, 0.031228977122477124, 0.02149182657844254, 0.02681971068627068, 0.025354979193902442, 0.06846426480582782, 0.08096751424350909, 0.07011199888906308, 0.011130746969554042, 0.0568431583898408, 0.06743861162768942, 0.07023135319884334, 0.044563876398439915, 0.05048680518354688, 0.024482549401000142, 0.06503223468150411, 0.08635114000311919, 0.02888156147673726, 0.0291228179952928, 0.013862487394362688, 0.04581980400585702, 0.03280313426096525, 0.013728051795624197, 0.0364322889862316, 0.02944086432190878, 0.0798786555283836, 0.02488290541805327, 0.036075511880751164, 0.056479897882257185, 0.005258501781749406, 0.020725002279505134, 0.03549449930765799, 0.013927133970095642, 0.01679191305967314, 0.03319109344322767, 0.02735860998343144, 0.026607899194849387, 0.03978908993303776, 0.0196923652796873, 0.023757687403953502, 0.046234741740460904, 0.014233571410711323, 0.005418529600969383, 0.03733755648136139, 0.05581437037991626, 0.05008283596751945, 0.03289361012035182, 0.03611458871247513, 0.005923717157981757, 0.02279778426912214, 0.036630906364215274, 0.051818060356059244, 0.035621015554560084, 0.04396373592317104, 0.048445683637900014, 0.0388731660454401, 0.03757027702938233, 0.04061257699504495, 0.048592260772628446, 0.008054222545719572, 0.07514016729380403, 0.026232742272051315, 0.012298708448984792, 0.06479847936757974, 0.022452272541288818, 0.07462307611214263, 0.051042949448206594, 0.0667897489454065, 0.04676674372915711, 0.026751616304474216, 0.09994180966168642, 0.04167272010818124, 0.02846979589334556, 0.03766886816759195, 0.009506098343990743, 0.018504959531128407, 0.07634479765381132, 0.05417997629514762, 0.0741806509239333, 0.03718480467796326, 0.04426569418449487, 0.012811345896417541, 0.01807421023425247, 0.01440386164800397, 0.016637447955352918, 0.02763366263492831, 0.030728119891136885, 0.05217125479664121, 0.017584757480238165, 0.07267329216535602, 0.029082465517733778, 0.004274835078311818, 0.00637262235561918, 0.015288611940507377, 0.018634931217612963, 0.0414022458717227, 0.028844530428094522, 0.03661301000309842, 0.07084130189780678, 0.049019686944250546, 0.019176685450864688, 0.025639863817819526, 0.028463672114802257, 0.04855230184538024, 0.08944604678877763, 0.08251190065805401, 0.022640716983005404, 0.03692917000236256, 0.032695243800325055, 0.08217686720724617, 0.02279105829074979, 0.03448247450536915, 0.02793103569586362, 0.01708153385802039, 0.034451546879219155, 0.016947238207129494, 0.05385418449129377, 0.04118739115074277, 0.0338995925682996, 0.05596035718917847, 0.0801270061305591, 0.19856983982026577, 0.4776422956160137, 0.7564180823309081, 1.5630724004336765, 0.4110899796443326, 0.25846861781818525, 0.16459253802895546, 0.05393270795632686, 0.08735595537083489, 0.01961836594689105, 0.03579242367829595, 0.01605513089868639, 0.03076561912894249, 0.019520015688613057, 0.020320222214130417, 0.016792045374001776, 0.011586303506711764, 0.011760910074891788, 0.03814513868253146, 0.03107916676838483, 0.017878927855885456, 0.033478731222982915, 0.035366724378296306, 0.017390285951218436, 0.07675833082092659, 0.027578813256695867, 0.05413906741887331, 0.09039501872445856, 0.08244845763381038, 0.028012509091890285, 0.014576343553406852, 0.06430927597518478, 0.044337737640099864, 0.01910391596278974, 0.019341951136344245, 0.025831227656453848, 0.031199603341519833, 0.014470834750682116, 0.040726207861942906, 0.052870573342910836, 0.04951108539743083, 0.029137565953923122, 0.04682380513155034, 0.04181336345417159, 0.017510703864640424, 0.05366267816030553, 0.03678203646891883, 0.06487218184130532, 0.03268174773880413, 0.043328912130423954, 0.031138898206076453, 0.10545042835708175, 0.026878880636234368, 0.06047501029180629, 0.02174259446162198, 0.0330715389656169, 0.05094493506476283, 0.014660544660208481, 0.03729114129341074, 0.014248734972040569, 0.055176150519400835, 0.08776120362537247, 0.08029005809554032, 0.041929420083761215, 0.027656132322070853, 0.05491427671430366, 0.11615424363740853, 0.05842379214508193, 0.015629548645977463, 0.03187988558784127, 0.04098999174311757, 0.058815150787787776, 0.08507808617183141, 0.01059470939383443, 0.00646892937532227, 0.04240803832986525, 0.013631158691298748, 0.008292215310835412, 0.023927782562428286, 0.07691587308155638, 0.018166996505377547, 0.040983620299292464, 0.015720268777970756, 0.01856973418034613, 0.020287231841523732, 0.0079213340068236, 0.05396864656358957, 0.09923512222511427, 0.10329325018184525, 0.12736056159649575, 0.09444586600043944, 0.14995044443224156, 0.15002112063978398, 0.06945031868027789, 0.15105310454964638, 0.1225813544754471, 0.1079912773732628, 0.11553057496036802, 0.13686927993382725, 0.1436244895947831, 0.14569361428064959, 0.13754580648882048, 0.15957101248204708, 0.08498903523598399, 0.12335683857756001, 0.13554092549851962, 0.1805660937513624, 0.09130190113293273, 0.13887108037514345, 0.15365597845188209, 0.10165207074689013, 0.12095892296305724, 0.13357617306922162, 0.10068903278027262, 0.1400680975722415, 0.2307811863720417, 0.18055879271456174, 0.0895640372431704, 0.13838847912847996, 0.12783088135932172, 0.11107009609362908, 0.20949947834014893, 0.18732348829507828, 0.14908042683133058, 0.09197105879762343, 0.27711606291787966, 0.16440438026828424, 0.14799409226647445, 0.08281078854841845, 0.09256162853645426, 0.1276796901864665, 0.1666534524410963, 0.12103799943413053, 0.11284012932862554, 0.11538817760135446, 0.19959264993667603, 0.1328376962670258, 0.07737066796315567, 0.08943579412464585, 0.12178862201316015, 0.08244702592492104, 0.18973460820104393, 0.134912303515843, 0.09801491948642901, 0.17271595927221434, 0.21123770863882133, 0.1298225987702608, 0.09958183326359306, 0.1789014030780111, 0.23624043485948018, 0.13006495790822165, 0.16069773345121316, 0.10010159108787775, 0.1654006868068661, 0.09877602543149676, 0.11304415802338294, 0.08658524815525327, 0.0737628565569009, 0.11892278864979744, 0.15138224831649236, 0.1510636354131358, 0.09939100207494837, 0.18672804667481355, 0.15683671991739953, 0.16541057984743798, 0.09433511551469564, 0.14982138707169465, 0.10476423267807279, 0.11738992375986916, 0.1323055348226002, 0.11953181454113551, 0.22110518201121263, 0.14243223571351596, 0.2277596156511988, 0.20308819093874522, 0.22219001022832735, 0.5040776942457471, 2.1738288274833133, 3.0533113947936465, 4.6646822435515265, 1.8469940338815962, 0.59293011788811, 0.25518754816481043, 0.09717662339763981, 0.16522318204598768, 0.08865642201687608, 0.07823740823992661, 0.10142829668309007, 0.12047215551137924, 0.1604853519903762, 0.12423080525227956, 0.05689631821587682, 0.05356281476893595, 0.05936493378664766, 0.1273744987057788, 0.2139028584850686, 0.09931571861462933, 0.15332057859216416, 0.10454516086195197, 0.09627211586173091, 0.20240569327558788, 0.10765124990471772, 0.1595644171216658, 0.10993563303990023, 0.20239951860691818, 0.09101282485893794, 0.06794975205723729, 0.16889590211212635, 0.15010242270571844, 0.07830055949411222, 0.1782744638621807, 0.11358718959880726, 0.10899398249707051, 0.13320795925600187, 0.160084120663149, 0.10942462153200593, 0.058732274520610056, 0.17640109652919428, 0.08613837177732162, 0.12054588512650558, 0.13658329099416733, 0.13299035307552132, 0.10837277011679751, 0.16170165315270424, 0.22992484803710664, 0.16068105506045477, 0.08761889447591134, 0.24538239144853183, 0.11494646487491471, 0.15082799377185957, 0.15151338199419634, 0.0637463361823133, 0.11394388867276055, 0.0507696423280452, 0.0933561251897897, 0.09757722368729965, 0.1979281356824296, 0.2026171926409006, 0.19624071408595356, 0.11832795771104948, 0.11621409042605332, 0.1936785794262375, 0.24562907963991165, 0.15890448753322872, 0.12289016933313437, 0.08261328736054045, 0.13242037008915628, 0.24419652936714037, 0.2238584735563823, 0.10706887008356196, 0.059798137683953555, 0.17442240699061326, 0.14190263913146087, 0.1107603312869157, 0.12461244048816816, 0.17175994414303983, 0.13382728530892304, 0.11407567374408245, 0.09081471298954316, 0.19460757529096945, 0.14897445323211805, 0.15668259747326374, 0.11164733940469367], [0.04755614797717758, 0.037837657146155834, 0.024066800817048976, 0.03650581504085234, 0.004592452231528503, 0.05500227931354727, 0.03638888310108866, 0.011210649557012533, 0.034894993262631555, 0.01761007192544639, 0.01372592374017196, 0.03990278186808739, 0.034629211095826964, 0.0575327535292932, 0.04573769109057529, 0.04397350004208939, 0.048085001563387256, 0.04365355721009629, 0.026609553123957345, 0.007046631969777601, 0.008384440942401332, 0.042201054615101645, 0.012334846375909234, 0.029428274104637758, 0.010136981544617032, 0.05226666699828846, 0.04136361687311104, 0.03191259776109031, 0.040043957864067385, 0.025831460054697733, 0.022042301683021442, 0.021308974961617162, 0.017458889234278883, 0.025178236088582447, 0.003149590134853497, 0.04785497479939035, 0.039610295955623896, 0.02100603621719139, 0.022643492191231678, 0.04038496920838952, 0.035815083355243714, 0.05720958087061133, 0.049797213436769586, 0.06245292630046606, 0.026929614699578712, 0.07952709974987165, 0.04121244266363127, 0.023457344055974057, 0.06886198132165841, 0.05583507248333522, 0.03854586789384484, 0.033575639594346285, 0.01669122864093099, 0.04798657666625721, 0.02876732332099761, 0.03995049645059875, 0.06912669818848372, 0.01662191968145115, 0.02253503006483827, 0.038440318379018984, 0.06390981562435627, 0.041045489122292826, 0.03413951576554349, 0.031386909540742636, 0.010556417966394551, 0.0018568000523373485, 0.01797679465796266, 0.014946184154333813, 0.01679646602964827, 0.006954357144422829, 0.03285175808040159, 0.049854495363043885, 0.027365173113399317, 0.02076901714982731, 0.009443237163525606, 0.032050523574330976, 0.024200567210625325, 0.08106377800660473, 0.019751635313566242, 0.06705420118357454, 0.02901991137436458, 0.04777450054617865, 0.05422432195129139, 0.0325498337458287, 0.06333053670823574, 0.023927758813702633, 0.026560951356909106, 0.015544770784409983, 0.03661983606538602, 0.08703192775802952, 0.0911142590588757, 0.06601530300187212, 0.11086821835488081, 0.09063020574727229, 0.05463174491056374, 0.046934935596904585, 0.09128530416637659, 0.0430867565529687, 0.0376169330972646, 0.048153167191360674, 0.032460891375584264, 0.021504036816103116, 0.049205792136490345, 0.007346910008761499, 0.0136176032579637, 0.015984727801488977, 0.02024642813817731, 0.01828803018932896, 0.034469205753079483, 0.07830569600420338, 0.12258671490209443, 0.017916525481268764, 0.03903335798531771, 0.04728773309450064, 0.03729172144085169, 0.03831110495541777, 0.027403328833835464, 0.0637873061267393, 0.03385394751759512, 0.03987023593591792, 0.07603173516690731, 0.06233016574489219, 0.03784052734928472, 0.05243948308218803, 0.022508497649271573, 0.09531105921736785, 0.05663785404924836, 0.012971320705089186, 0.05295176684324231, 0.028545204882643054, 0.020043541078588793, 0.03830111013459308, 0.06453485494213444, 0.00448991498810106, 0.019473654783463905, 0.01844579297383981, 0.04416461282276681, 0.056364848877170255, 0.05008249330733504, 0.030720798498285667, 0.02184933819808066, 0.013978661919411803, 0.050386388786137104, 0.04464990446077926, 0.07212963633771453, 0.019800913919295584, 0.024701755227787153, 0.010961175979381161, 0.021474323767636503, 0.024421435448208025, 0.075910704875631, 0.043220489019794125, 0.05768447395946298, 0.024262335949710438, 0.01927140724313046, 0.0029215658973303755, 0.038062279378729205, 0.03597536350467375, 0.03877514148397105, 0.021685220933120166, 0.025262829049357345, 0.08404757468295948, 0.008792212499039513, 0.05431737285107374, 0.05522150719272239, 0.061045956797897816, 0.03527583121987326, 0.043718167314571996, 0.03752800429772053, 0.05093722351427589, 0.07735295141381876, 0.02521145885943302, 0.026298731498952423, 0.03592182030635221, 0.007376976743606585, 0.047353608666786125, 0.04697220752547894, 0.0613777061392154, 0.04803291043000562, 0.08554710314742156, 0.0209528407680669, 0.09139120312673704, 0.026132061245984266, 0.039224806640829356, 0.025663144354309355, 0.0023193747620098293, 0.030089757538267543, 0.01112570460619671, 0.03256632214678185, 0.011779796248967094, 0.02974224922114185, 0.030431243857102733, 0.06341149272131068, 0.07269564989422049, 0.033322132126029046, 0.00833790107364101, 0.0383218800915139, 0.032136185227760246, 0.03144080896994897, 0.07156663547669138, 0.03622006019577384, 0.04156373042081084, 0.02729157411626407, 0.033956748965595446, 0.05553851196808474, 0.02346735244749912, 0.030977800421948944, 0.009999090506296073, 0.019651186685743074, 0.0064461161798265365, 0.014418865753603833, 0.030983323697000742, 0.05411330344421523, 0.02056700031140021, 0.06476904451847076, 0.04437681786449892, 0.019758040684142282, 0.04028942808508873, 0.04753232461267284, 0.058220455556043556, 0.03714335975902421, 0.03416673519781657, 0.04188912528167878, 0.03736783271389348, 0.04615189940003412, 0.14051996118256024, 0.08533105081213371, 0.052708315263901434, 0.04483697656542063, 0.08336791329618011, 0.015910277242905328, 0.028304134961217642, 0.04688803186374051, 0.07794890872069768, 0.009030590332778437, 0.05472016141616872, 0.023504588752985, 0.038417349968637736, 0.03572423430159688, 0.030882910692266057, 0.03880056619111981, 0.05213894635172827, 0.042520841384040456, 0.023714561414505755, 0.028462121662284647, 0.02184203716128, 0.020613831102049777, 0.009001721212241267, 0.031470321850585084, 0.006872896895012153, 0.04330848144101245, 0.034757868120712895, 0.06000232244176524, 0.04929914837703109, 0.03223719873598643, 0.020542685009006943, 0.07057298201003245, 0.0385878081433475, 0.0655880430713296, 0.052685608089502366, 0.027993233608348028, 0.054090399494660754, 0.04763707345617669, 0.021482113349650587, 0.05743700545281172, 0.004270802459879113, 0.21257002571863787, 0.07922190826918397, 0.05165409576147795, 0.07880950825554983, 0.02433333106871162, 0.024137298909149, 0.1236486222062792, 0.021969981724396348, 0.019560419056298475, 0.037147705775818655, 0.017119392719385878, 0.03538130270317197, 0.028506083946142877, 0.017228300982554044, 0.04344702472112008, 0.02704108103976718, 0.04788592956694109, 0.08513857078339372, 0.042320218935076676, 0.04481763831738915, 0.04418868724522846, 0.05286390334367752, 0.02999182797170111, 0.049452039280108044, 0.02943431306630373, 0.0270881103019097, 0.043654558049248796, 0.058549517898687294, 0.03267669943826539, 0.023693185865080783, 0.029492226030145372, 0.041445326060056686, 0.08199402237577097, 0.07638583545173917, 0.03314675117975899, 0.04061282126765166, 0.00715314076348607, 0.04904676388416972, 0.031189360855413333, 0.02055986042666648, 0.03278188932953136, 0.02870193968660065, 0.07822867549423661, 0.02511297459048884, 0.05897496614073004, 0.004164837766438723, 0.008395532445449914, 0.03236079388963325, 0.022806919046810696, 0.02809465254124786, 0.008771401830017567, 0.04921187859560762, 0.03190418053418398, 0.02591062812799854, 0.056785286138100285, 0.012369249797692257, 0.06383004704756395, 0.010161234082521071, 0.03385630203410983, 0.03261204183633838, 0.05887637500252042, 0.04701923678762146, 0.0056779174233919805, 0.027763412101194263, 0.021253367320501378, 0.026557034513513957, 0.004980776974532221, 0.03801544010639191, 0.016150292042376738, 0.026214835732909184, 0.02971730288118124, 0.02898044777767999, 0.007954318442248871, 0.027598823254395808, 0.020957777110327567, 0.04045854615313666, 0.028240622387134602, 0.027143807848915458, 0.08299565541424922, 0.07034542850617852, 0.024215133661138158, 0.05170374756146755, 0.04928710098777499, 0.04423065124345677, 0.028521110104130845, 0.04187579546123743, 0.19575442160878861, 0.16672241874039173, 0.23709669177021298, 0.18147244011717184, 0.06354427523910999, 0.16295635939708777, 0.08252564777753182, 0.09280758391001395, 0.09363964426198176, 0.12089761053877217, 0.09371732295091663, 0.14925096982291766, 0.1405871497201068, 0.1272170107279505, 0.1140263442482267, 0.21236559668821947, 0.10218060202896595, 0.13744382267551764, 0.12452789502484457, 0.09620793323431696, 0.07693460064807109, 0.07141486754907028, 0.10722264647483826, 0.2060219727988754, 0.11993001960217953, 0.1496158723852464, 0.14569326144243988, 0.15087760825242313, 0.10227295743035418, 0.08653129105057035, 0.12540956985737595, 0.1003732154411929, 0.15168186223932675, 0.07569727168551513, 0.08698664233088493, 0.17070476790624006, 0.08125209861568042, 0.16688667849770614, 0.15626167505979538, 0.1276564842888287, 0.10043937939086131, 0.11880184656807355, 0.18984681075172766, 0.15533288275556906, 0.08171263390353747, 0.15886197052896023, 0.09716069818075214, 0.10475668736866542, 0.15401177507426056, 0.23580883230481828, 0.11673782446554729, 0.17332959920167923, 0.1700900558914457, 0.1977825899209295, 0.140057200299842, 0.0958309391779559, 0.19007338716515473, 0.09916586415576083, 0.07092917896807194, 0.10808999064777579, 0.18403739748256548, 0.16993463066007408, 0.11689076625875064, 0.1387562993913889, 0.12841457075306348, 0.12033631280064583, 0.16333008291465895, 0.08458621613681316, 0.1597433468060834, 0.07299910432526044, 0.19432934879192285, 0.13512342290154525, 0.11124038802725927, 0.08576293156615325, 0.1301699137049062, 0.1609877800302846, 0.11063266492315701, 0.2780841423996857, 0.11570508059646402, 0.28226372812475475, 0.20034047695142881, 0.1307476455611842, 0.14322922937572002, 0.09046260759766613, 0.17587059071021421, 0.09497461441372122, 0.17366688538874897, 0.11099163030407258, 0.16240518540143967, 0.1871045928980623, 0.2285698407462665, 0.15654357921864304, 0.312803965061903, 0.1962490329252822, 0.1289505727056946, 0.18090628406831197, 0.18303794254149708, 0.09653863763170582, 0.1577818649155753, 0.11002077561404024, 0.05518945998379162, 0.13652926603598253, 0.13290269992181233, 0.11455634795129299, 0.12769597502691404, 0.132286169433168, 0.15808998766754354, 0.166705509647727, 0.14278229192963668, 0.13748205133846828, 0.14060735649296216, 0.17589667359633104, 0.14196553932768957, 0.11035259280885969, 0.20803555260811532, 0.16526396200060844, 0.11428019776940346, 0.13525018681372913, 0.1412968702082123, 0.08751929910587412, 0.21445285182978424, 0.10567488774125065, 0.15388157777488232, 0.1383470884923424, 0.12187356102679457, 0.13861869248960698, 0.09726869381432023, 0.1236675533332995, 0.21769954689911433, 0.15491904424769537, 0.08471194189041853, 0.09998279996216297, 0.1596662380865642, 0.15904054737516812, 0.1515350408319916, 0.05768340187413352, 0.13525134032326086, 0.1551160365343094, 0.11397668905556202, 0.15591503866016865, 0.22943432150142534, 0.12110624648630619, 0.10311461905283587, 0.078895675417568, 0.29644350867186275, 0.11085582830544029, 0.13701067306101322, 0.1508791824536664, 0.08216557638453585, 0.08012372202106885, 0.15876814270658152, 0.1644055473485163, 0.16902050828295095, 0.12180036066898278, 0.11404144843774182, 0.08416340061064277, 0.07528222538530827, 0.09099065033452851, 0.06687039961772305, 0.14447047348533357, 0.1728452473346676, 0.18597513064742088, 0.1412801511053528, 0.09613902800317321, 0.1246356192444052, 0.11339000053703785, 0.10130898987076112, 0.10276123122977358, 0.1678575264023883, 0.2361594992024558, 0.17087168752082757, 0.09650169139994041, 0.16613870220524923, 0.1232107092759439, 0.12472209174718175, 0.15570737980306149], [0.03272277196603162, 0.019076647336727807, 0.025075941845508556, 0.06224097910204104, 0.03150471679068037, 0.0091063530084544, 0.033783440943807364, 0.04121176412861262, 0.02710720936634711, 0.05823855208499091, 0.08944354299455881, 0.02779909286514989, 0.06122290516006095, 0.010588256525807083, 0.00632757059897163, 0.01692666332902653, 0.05138630173834307, 0.02816818538121879, 0.04270033085984843, 0.01379473736908819, 0.055583078148109574, 0.03481231377060924, 0.022266328501115953, 0.035789716323571544, 0.019209078712654964, 0.030452268264655556, 0.04480509899024453, 0.02097113407216966, 0.04984855139628053, 0.03190016360687358, 0.023278088674747517, 0.0801651126572064, 0.011722712794185748, 0.023827030290184275, 0.015640959908653582, 0.04229692482788648, 0.03940640975322042, 0.02430829143018595, 0.008318159945442207, 0.03995308506169489, 0.03953015757724643, 0.028062376326748302, 0.041042191442102194, 0.06589843213026013, 0.029951794405600855, 0.0600300541679774, 0.014848371635058095, 0.05740098202867167, 0.008212859792235707, 0.03132291351045881, 0.08726655838212796, 0.10857625598353998, 0.06510371156036854, 0.061882407271436284, 0.015668555927862014, 0.024954266945964525, 0.0454037297250969, 0.019264206290245056, 0.03821707017985838, 0.06619743537157774, 0.05076130313266601, 0.04569616135475891, 0.06182167160191706, 0.03910602908581495, 0.0182143616423543, 0.019573903243456568, 0.020066177006810904, 0.016896838322281837, 0.008542829675466886, 0.02273349986145539, 0.044028817609484704, 0.029476667222167765, 0.0465189936304731, 0.04637859455708947, 0.04493648711858051, 0.042981329174446206, 0.02656365022994578, 0.05230714839750102, 0.059734219685196877, 0.05542915926447936, 0.01606024196371436, 0.04269523506185838, 0.034757661167532206, 0.042202981654554605, 0.08154352262083973, 0.06390403450599738, 0.062313731626740525, 0.02272839388544006, 0.03222940576129726, 0.02040237414517573, 0.08651663469416754, 0.02383990040315049, 0.04085793525778821, 0.03169770232800927, 0.05041376088878938, 0.06979496697229998, 0.08125994926584618, 0.018105729882206236, 0.039396693131753376, 0.010687438837651695, 0.03951231210625597, 0.05018103016274316, 0.03825658466666937, 0.044045991330806694, 0.002137349049527464, 0.01568855405119913, 0.06649607220398528, 0.059369568180825026, 0.021725883840450218, 0.012897520691954663, 0.07782880123704672, 0.011669413868470915, 0.04107634210959077, 0.019561855854200463, 0.01991355242872877, 0.03727421863004565, 0.07270324270107917, 0.020468186952971985, 0.06411048557077136, 0.025801068471212472, 0.09079709822045905, 0.05730037564145667, 0.014818682335317135, 0.019971626544637338, 0.0014173769575011516, 0.03843216917344502, 0.022643878956192305, 0.008811820464740907, 0.051062559110245535, 0.023884634520592432, 0.035631661769002676, 0.03803039501820292, 0.022558408988905803, 0.027404241463435546, 0.011679167809363986, 0.0394988974689373, 0.019638235148574625, 0.03853076370432973, 0.08268265399549689, 0.038817258152578554, 0.08150376046874694, 0.03396301862916776, 0.03086636122316122, 0.08501521311700344, 0.05024979290153299, 0.0338680644386581, 0.014152811324623014, 0.012919608703149217, 0.037303541520876546, 0.016959874225514274, 0.04486829774188144, 0.07321347389370203, 0.039906887004950216, 0.08165813397083964, 0.06825165942843471, 0.023512035674814667, 0.006568486153680299, 0.024031964829191566, 0.025369336994897042, 0.04454839901466455, 0.04259764476280127, 0.04769905084478004, 0.05007459855239306, 0.060633170019303045, 0.03290889751432197, 0.013011365297383495, 0.010817379990060414, 0.01938986758302365, 0.0159367977841092, 0.06606511425759111, 0.11829663653458868, 0.0419836960999029, 0.00643109341451366, 0.031139980469431196, 0.01845086332676666, 0.03490008566794651, 0.035645989035921435, 0.06436976737209729, 0.005849638945489589, 0.011441184374104654, 0.03088195395788976, 0.05041095514648727, 0.0765945663941758, 0.043948041408189704, 0.01720510865561664, 0.07170068685497556, 0.048599365034273694, 0.02440190890670887, 0.037725865109158416, 0.04143543641215988, 0.02480369832898889, 0.05951675599707024, 0.012984390137717128, 0.014274816161819866, 0.04367760449115719, 0.002921020524809137, 0.06825847192002193, 0.03985449053081019, 0.04262907789754016, 0.020481038406225185, 0.019900032618482198, 0.050972127355635166, 0.059246244441185675, 0.045865438878536224, 0.027365642998899733, 0.018509507412090898, 0.07461841457656451, 0.04003212760601725, 0.0709310517247234, 0.00806623516005597, 0.055883974502129216, 0.044388383493891785, 0.037517738062888384, 0.037231026483433585, 0.009234228021731334, 0.01109604159968772, 0.18059668211000307, 0.05226149995412145, 0.048649013441588194, 0.028222671743216257, 0.07664157530026776, 0.08517823115523372, 0.026971005335716263, 0.020314364760581936, 0.07565631531178951, 0.03516637334333999, 0.08679353804992777, 0.020069620572030544, 0.04213549116892474, 0.024973905445741754, 0.09205685276538134, 0.028300845762714744, 0.04180242886234607, 0.02322531391733459, 0.022537074151581953, 0.04647676161091242, 0.03816565418882029, 0.01659258152358234, 0.03835726569273642, 0.0722386429884604, 0.0058910440004962894, 0.054259422567806075, 0.062209454365074635, 0.037337885570845435, 0.03510806682918753, 0.036151484054114134, 0.016460784577897618, 0.01967532726536904, 0.02353302954829165, 0.10797556250223092, 0.07075349268104349, 0.03556177266208189, 0.008123049745336175, 0.09146836612905775, 0.026328649804262177, 0.00525115367158183, 0.0491951221733221, 0.03978905600628682, 0.04345276852005294, 0.034617889739040814, 0.021677667142025063, 0.04223258613741823, 0.057790949674589295, 0.029495140338050466, 0.02335013382669006, 0.047116246939237626, 0.04833307396620512, 0.03723107737355998, 0.09316703783614294, 0.02597328574795808, 0.0804578462349517, 0.10069525494639363, 0.008613778145185538, 0.03667015961504408, 0.012629637611098588, 0.022717623838356564, 0.031030749902129173, 0.026867279383753027, 0.03194832941517234, 0.08571174966969661, 0.023836916545405984, 0.022836910294634954, 0.012952169054187834, 0.03601751410003219, 0.005065809710816081, 0.036198238509574106, 0.033899992903960605, 0.010264135614436651, 0.06761193661285297, 0.026565601018124392, 0.06042214562850339, 0.04954491715346064, 0.04416120996964829, 0.013469861587509513, 0.0416189224592277, 0.00934980798047036, 0.0865144430260573, 0.02397722571289965, 0.014520187995263507, 0.04820761623393212, 0.04559860498245273, 0.04101070063188672, 0.07041999950472798, 0.0727787772193551, 0.07468993895288024, 0.025819209104936038, 0.046674595280949555, 0.023917275447664515, 0.08593076720301594, 0.019668390941140906, 0.03317418774323804, 0.03653300054637449, 0.018181632505729795, 0.06486536256436791, 0.01429512641126556, 0.04018861135201795, 0.11893494799733162, 0.05930516842220511, 0.06804035005292722, 0.05766822983111654, 0.08441893011331558, 0.004334354049725724, 0.03641202114522457, 0.03018520027399063, 0.0005402122094112981, 0.008756706457851189, 0.01399098411535046, 0.06296069441097123, 0.015028982389984387, 0.0074996635084971786, 0.04582858085632324, 0.04254366730206779, 0.028419691171231012, 0.027118588398609842, 0.03382244313667927, 0.0016787894648067386, 0.054154917996908934, 0.026230635420818414, 0.04214312129520944, 0.018895069669399942, 0.012420642040004688, 0.039781710864709954, 0.026520724408328533, 0.026193794361980896, 0.028780880450670208, 0.011711992789059877, 0.04368284956685134, 0.05324937569509659, 0.05890888361526387, 0.010372564662247896, 0.05592167051509023, 0.051746488482292206, 0.10870750501219716, 0.12366451349641595, 0.08638581314257213, 0.14583609306386539, 0.12386256429765906, 0.1280137329761471, 0.18049898663801806, 0.11310546366231782, 0.06710448062845639, 0.21643732248672418, 0.17212380176143988, 0.07462667234774147, 0.11796234947230134, 0.0948133741372398, 0.1510885783604213, 0.12867675668426923, 0.18747356667050294, 0.11611134665352957, 0.17106538212725095, 0.13034732347088201, 0.14652097917028836, 0.1450244566159589, 0.10388867144605943, 0.11629341116973332, 0.08481765764632396, 0.10965323355048895, 0.11499806067773274, 0.1555076190935714, 0.1594099011272192, 0.10427589781050171, 0.11080579313316516, 0.20928111220044748, 0.12523712696773664, 0.1181414012930223, 0.17059415312749998, 0.20243082621267863, 0.1128844783774444, 0.12982569288994583, 0.12244768307677337, 0.1359039553041969, 0.334907379001379, 0.1549771675573928, 0.12411014815526349, 0.15134354467902864, 0.18266911804676056, 0.20521473325788975, 0.26327004017574446, 0.0844426109854664, 0.11939428906355586, 0.099066173790821, 0.2573777777808053, 0.1695045344531536, 0.09161560144275427, 0.1611525554742132, 0.15207736673099653, 0.07076318216110979, 0.2235510971929346, 0.17049914465418883, 0.09527815705431358, 0.1480659626956497, 0.0786127331001418, 0.15741893010480063, 0.16296200480844292, 0.1430512224989278, 0.10216613566236836, 0.13076006275202545, 0.16406712122261524, 0.13507182709872723, 0.08997051364609174, 0.11646788966442857, 0.17086452219103063, 0.1218718375478472, 0.09904683554278952, 0.23466968057411058, 0.23678003304771014, 0.08217172391180481, 0.07101151919258492, 0.14611479453742504, 0.18660850237522805, 0.10275541618466377, 0.11953653714486531, 0.06684807581560952, 0.14420801614012035, 0.13154402854187147, 0.16988881597561495, 0.09418288618326187, 0.1509317010641098, 0.10670435428619385, 0.19097558089665004, 0.17005549131759576, 0.18169468747717993, 0.10301337484270334, 0.11602836182074887, 0.08382122218608856, 0.11679476712431226, 0.18370636738836765, 0.1552645814205919, 0.13837584480643272, 0.12370769546500274, 0.12921891973486968, 0.1324258797935077, 0.16072092577815056, 0.09876290256423609, 0.14141466388744967, 0.1158622700188841, 0.07854376680084638, 0.15494276583194733, 0.11629544677478926, 0.12715307915849344, 0.103969613888434, 0.27010123218808857, 0.11903296916612557, 0.13872116484812327, 0.07274163421243429, 0.13642249176544802, 0.09777251963636704, 0.12919285041945322, 0.078987949394754, 0.163512703829578, 0.1189450445984091, 0.18815267165856703, 0.11390625712062631, 0.07849648648074695, 0.11724976556641714, 0.13396744350237505, 0.11455641580479485, 0.16202817777437822, 0.2154726628214121, 0.20312215840177877, 0.07999922441584723, 0.13442278121198925, 0.15445362350770406, 0.12752574416143553, 0.14894382416137628, 0.13800336979329586, 0.0685900855543358, 0.07034279579030615, 0.0977561737277678, 0.17116222264511244, 0.22813451981970242, 0.18006700410374574, 0.30161674107824055, 0.12744756335658686, 0.21682634018361568, 0.24288388980286463, 0.08823155052959919, 0.11382920946925879, 0.09277384036353656, 0.09139299445918628, 0.1822789739817381, 0.09925376158207655, 0.22480631912393229, 0.07410698916230883, 0.12424029117184025, 0.10711165171648775, 0.1891760110322918, 0.08030514871435505, 0.10778790007212333, 0.07477202133408614, 0.1184388981865985, 0.13119138032197952, 0.14206358763788426, 0.17743282259574958, 0.14525059876697405, 0.12167970357196671, 0.10153287928551435, 0.08569503056683711, 0.17947253957390785, 0.13963815064302512, 0.1001892238855362, 0.21743702170039925, 0.08594798163643905, 0.11724825921867575, 0.12994367655898842, 0.13733415784580366, 0.12773925199040345], [0.025073785800486803, 0.028801273820655685, 0.045030800093497546, 0.02223656965153558, 0.037567033631993194, 0.010216066497378051, 0.01671098418799894, 0.02419035186591957, 0.032794805243611336, 0.04448927486581462, 0.01896803253995521, 0.05325990316591092, 0.00989925510449601, 0.031198225915431976, 0.031904170356158695, 0.029350978787988424, 0.058295956147568564, 0.06208425108343363, 0.017185354804886237, 0.03854722496388214, 0.05099901091307402, 0.022816557636750594, 0.005886651334419314, 0.06666863722992794, 0.023669376071276407, 0.037970127537846565, 0.06730014298643384, 0.015965045196935534, 0.02275755562420402, 0.09044595634830849, 0.07376257835754327, 0.0360942190912153, 0.015618519059249332, 0.03474224145923342, 0.038798778251345666, 0.049146430500383885, 0.03239081906420844, 0.027051515212016444, 0.04604092160505908, 0.03141960135794111, 0.05772671954972403, 0.032630118009235175, 0.07871382803257022, 0.036170757841318846, 0.07030993433935301, 0.0037743120254682644, 0.0271682096645236, 0.0297616519300001, 0.03311598640201347, 0.020968470822221467, 0.020624212687835097, 0.03681364602276257, 0.024771566303180795, 0.044343087888721905, 0.01555245349715863, 0.020879738797832812, 0.026062350254505873, 0.03578134998679161, 0.054458206186869314, 0.03683727261211191, 0.05302085527884109, 0.06515814363956451, 0.008113062558030444, 0.012236415541597774, 0.019195094105920622, 0.018327902603362287, 0.036368849354663065, 0.02583261186789189, 0.011770341711651002, 0.026150357942762117, 0.06084490687187229, 0.03222266112321189, 0.009609020231956882, 0.033162689967347045, 0.09823256637901068, 0.054172095110906024, 0.02818439219013921, 0.066049609732415, 0.06408404984644481, 0.026901394428153123, 0.030085886495986154, 0.06920694173978907, 0.08557872287929058, 0.028053780984399573, 0.08137196861207485, 0.03239679017237254, 0.07787927745708398, 0.029436905070074966, 0.043286931168820174, 0.04939712883372392, 0.018791252115209187, 0.03800180494519217, 0.021473182132467628, 0.06634169191654239, 0.04131900658831, 0.014198077243885823, 0.01944725468222584, 0.037457667357687435, 0.04124185376401458, 0.017532155749254992, 0.05836842368756022, 0.04314428614452481, 0.04719705706728356, 0.017995023501238654, 0.04562497285327741, 0.028699958364346197, 0.06591517837452036, 0.05991576172943626, 0.06012030611080783, 0.025053300828273808, 0.006148782134654799, 0.05601989185171468, 0.060693783552518914, 0.018737814089815532, 0.03589621578742351, 0.07052703161856957, 0.01715212524868548, 0.02327243478170463, 0.036358074218566926, 0.04680071797754083, 0.024356272337692123, 0.028437502715470533, 0.014700936153531075, 0.021459784458524415, 0.016043387153851132, 0.012175273599236138, 0.09674360949013915, 0.05508217002664294, 0.025907433924398253, 0.02592256016630147, 0.08042615864958082, 0.007079065519584609, 0.04383435286581516, 0.02165698878733175, 0.017975612310692668, 0.015890749005068625, 0.06598426002476897, 0.03486431669443846, 0.014426870770486338, 0.01754256447644106, 0.07443008039678846, 0.004348333991531814, 0.03951246816931026, 0.01866360780383859, 0.02302055579743215, 0.0820716739233051, 0.014485340133043272, 0.02676976881256061, 0.07503658892320735, 0.03432178044957774, 0.03986755232991917, 0.05316657067409583, 0.026591685600578785, 0.02072882921701031, 0.02445781510323286, 0.011453090967344386, 0.04044023588565843, 0.0346180491947702, 0.025693189884935106, 0.029021529680384055, 0.08657101249056202, 0.03222207079774567, 0.01453793847135135, 0.01878444810530969, 0.021637311271790947, 0.03221223543265036, 0.030697358506066457, 0.06814788428268262, 0.030058731524539844, 0.0282846270794315, 0.03130537338022675, 0.03827583809782352, 0.05064755691481488, 0.04758635974888291, 0.06223107249076877, 0.047509200139237304, 0.03229677750329886, 0.08917387960744755, 0.011932250345125794, 0.019678290767062987, 0.037868957966566086, 0.00539740129274183, 0.02463626302778721, 0.008303013347488428, 0.03336139216220804, 0.029512690646307807, 0.02698304085060954, 0.04488142739449229, 0.10356896610132285, 0.03864193827446018, 0.042448350095323155, 0.046882437342511754, 0.020574179211897508, 0.009588430086815996, 0.040980946871318986, 0.03444526703762157, 0.03319562266447714, 0.0612214734511716, 0.025586357938924005, 0.03576544512595449, 0.03752163963924561, 0.03697935784501689, 0.056064912650202, 0.01590459790479924, 0.06333578856928007, 0.0210815113636532, 0.02883650335882391, 0.02011922657090638, 0.02983425517699548, 0.10111097978161913, 0.028055543479110514, 0.05239896775622453, 0.016298819965283786, 0.020828368607908487, 0.019073649908282926, 0.04830044321715832, 0.0032632740122997867, 0.03937552623184664, 0.017005181705046977, 0.04233548936567136, 0.07153323798307351, 0.027826858518112983, 0.019969344970637133, 0.04074587859213352, 0.09001875748591763, 0.008040238787154002, 0.05147139681503177, 0.024437594759677137, 0.024899278468053256, 0.026865625454645072, 0.0198030648753047, 0.04642247202407036, 0.04951413880501475, 0.045588925680411715, 0.06615276062594992, 0.035885820630937815, 0.015704886389097998, 0.02869230109666075, 0.03353885621098535, 0.06132034957408905, 0.031166005680071454, 0.041819209033357244, 0.0881682364270091, 0.026483654343922223, 0.018325785574104105, 0.03346671436780265, 0.013060957725558962, 0.020557387166523507, 0.04361110805932965, 0.02602633022304092, 0.03303989887769733, 0.004527103796135634, 0.0663690504484943, 0.031082562836153165, 0.025717710444171513, 0.04304139309429696, 0.030156583059579134, 0.009697262862963336, 0.032236211467534304, 0.023167217749037912, 0.012515739571037037, 0.0288082457679723, 0.025098784726911356, 0.056046110444835255, 0.038391775983784876, 0.036289247018950324, 0.022806301579943726, 0.05414230742358735, 0.024316369389582957, 0.03553725379918303, 0.054822257187749655, 0.020841065694444945, 0.0771161766190614, 0.028864699881523848, 0.02886066599083798, 0.03524211820747171, 0.008767496012816471, 0.04561190426881824, 0.018481455078082423, 0.04409782122820616, 0.052604882778333764, 0.05233600309916905, 0.0767103380390576, 0.0572442336540137, 0.008637168095447123, 0.061227641334491115, 0.03423840545916131, 0.033483209554106, 0.06214630311088903, 0.02709166582540742, 0.04338400578126311, 0.010588259918482175, 0.005030247266404331, 0.018576409268592085, 0.027755534309627752, 0.04435518616810441, 0.024915785528719425, 0.016737318132072687, 0.01587199599349073, 0.012797347718982824, 0.014492306991347244, 0.01432112617684262, 0.04900455561333469, 0.048920983847762854, 0.03833430067503026, 0.022277682088315487, 0.03598254919052124, 0.00967440810719771, 0.004697011933395905, 0.01759632650230612, 0.0515325260348618, 0.026448575779795647, 0.016051078348287513, 0.0342150197497436, 0.04608348949945398, 0.016450838950861777, 0.031242551215525185, 0.035651583557150195, 0.023618167033419013, 0.028177559342501417, 0.050642590038478374, 0.08420750538685493, 0.045882761877562316, 0.026900313861135925, 0.04203507137883987, 0.014877703007576721, 0.014588238272283758, 0.10873153872255768, 0.06009427750749247, 0.058286775568766255, 0.016679033670308333, 0.023692436083885174, 0.04749108664691448, 0.008799665358050593, 0.012403299533096808, 0.027365938161632845, 0.0445638322936637, 0.051483776686447005, 0.029782092797436883, 0.05340087560138532, 0.03309833092082824, 0.03295279194467834, 0.01798248417409403, 0.026888476817735603, 0.06381618457713298, 0.016348185084228004, 0.025533936019720774, 0.05088061333767005, 0.04390839799972517, 0.04557303778295006, 0.054751631870333634, 0.08920697176030704, 0.10307907060320888, 0.12515950256160327, 0.12164098636380263, 0.08487183188221284, 0.10931205257241215, 0.0889766566189272, 0.13597522862255573, 0.1267190474484648, 0.16897090737308773, 0.13625931766416344, 0.10855157766491175, 0.16138492657669953, 0.1989650186151266, 0.11928832903504372, 0.2384081371128559, 0.12016350350209645, 0.12049514427781105, 0.18131834481443676, 0.09213748308164732, 0.13359243076826843, 0.14474724791944027, 0.11715292504855565, 0.10712413676083088, 0.08335544860788754, 0.14557103014418057, 0.13122329860925674, 0.17506487108767033, 0.12057519783931119, 0.09457013290375471, 0.13688244351318904, 0.16325598689062254, 0.19061094974832876, 0.10683146425123725, 0.20522496556597097, 0.06814766715147666, 0.1431879201637847, 0.121188471359866, 0.09774154451276575, 0.1439116591853755, 0.14017682602362974, 0.15361986681818962, 0.13671437038906983, 0.23925207182765007, 0.09877259204430239, 0.25251346879771774, 0.09167757883135762, 0.10723694999303136, 0.13917500978069647, 0.1730910941426243, 0.08983157003032309, 0.07922359782138041, 0.15544013200061663, 0.15920925832220487, 0.14411926375968115, 0.13132064124303205, 0.0900570811437709, 0.143578349213515, 0.10655162962419645, 0.1764037021036659, 0.1188499139887946, 0.16105969117156096, 0.13281337757195744, 0.1007065661251545, 0.13828319763498648, 0.12796265285994324, 0.13895190746656486, 0.12848771682807378, 0.09471388733280556, 0.07486325036734343, 0.07769781005169664, 0.15470674421106065, 0.11539481367383685, 0.15642069652676582, 0.1265173732702221, 0.17219488508999348, 0.15358219455395425, 0.3403821252286434, 0.09951896020876509, 0.1371555674288954, 0.11888837335365159, 0.05377289599605969, 0.08977924140968493, 0.19668754296643393, 0.11922249756753445, 0.12335035178278174, 0.09428094806415693, 0.11636366668556418, 0.10603683189089809, 0.08520725209798131, 0.13832671887108258, 0.07272088461156402, 0.1513526099068778, 0.14969089121690818, 0.18356136445488247, 0.06210313471300261, 0.058859425197754583, 0.14415661032710755, 0.12241588692579951, 0.08435138195220913, 0.21998051021780285, 0.12906118748443468, 0.11185580571847302, 0.11848699274872031, 0.11192792042025498, 0.13817892037332058, 0.12663499053035462, 0.10695083891706807, 0.12742496814046586, 0.1574688567114728, 0.1387593120868717, 0.08991612906434707, 0.13798249805612223, 0.21651623610939297, 0.11910564026662282, 0.15287851302751473, 0.14877762379390852, 0.08964402295116868, 0.19776089037103312, 0.09632261243781873, 0.11416975940976824, 0.09424543354128088, 0.12547527918858187, 0.0745823232989226, 0.08910497437630381, 0.052027320555810413, 0.1997568825525897, 0.1550156676343509, 0.17080591033611978, 0.1219203799430813, 0.08794173465243407, 0.11954268467213426, 0.07172412345451967, 0.10472372413745948, 0.07117326837033033, 0.11868546424167496, 0.15491671008723124, 0.12002000691635267, 0.11216719222388097, 0.14677133145076887, 0.10158611035772733, 0.13993096564497265, 0.1343067381531, 0.09890640593533005, 0.15039332423891338, 0.11152828365032162, 0.2072162622851985, 0.1583488487771579, 0.20310590070273193, 0.15727083305163042, 0.1572885156742164, 0.09363133220800332, 0.18613161439342157, 0.17525119680379117, 0.10920917309288468, 0.06968443361776215, 0.2240804766437837, 0.15803200006484985, 0.09546374995261431, 0.10951337391244513, 0.0896239790267178, 0.21077557200832026, 0.09121301304548979, 0.07114151293145758, 0.12610878662339278, 0.12025843055120536, 0.09898831868278128, 0.14186192703034195, 0.14108716217534883, 0.12826097756624222, 0.09654580296150275, 0.10840802679636649, 0.11664836640868868, 0.12802575661667756, 0.19177562796643802, 0.25878283381462097, 0.16149659987006867], [0.010233282627138709, 0.009801810690467911, 0.006481577268069876, 0.04090565662564976, 0.01680748543835112, 0.02450103948025831, 0.05583344739196556, 0.0347448606044054, 0.025327410316094756, 0.030438924873513833, 0.027007642834048187, 0.005902382320657904, 0.013348876249178179, 0.006924926536157727, 0.05707616052989449, 0.019495050688939433, 0.029378188042236224, 0.013464552899157363, 0.05051959538832307, 0.041286440300089974, 0.07076664947505508, 0.04679201576592667, 0.003559752891305834, 0.053047304573868, 0.037490182755781074, 0.027147529613492743, 0.050208816171756813, 0.030026049885366644, 0.15189055246966227, 0.04575658489816955, 0.016911815286480954, 0.05492289750171559, 0.022099161221246635, 0.09117827205253498, 0.04170000400128109, 0.04386594545628343, 0.0036784893101347344, 0.0700539027207664, 0.02741899960009115, 0.0891399664272155, 0.04606434463390282, 0.020275537290477326, 0.015601413191429206, 0.00477490181635533, 0.0450688285886177, 0.04133578336664608, 0.04696513379790953, 0.06922823416867427, 0.02654469196152474, 0.0680141043184059, 0.07963314798793622, 0.06916125597698347, 0.04311854252591729, 0.020621488369735222, 0.020861679588311484, 0.06527879395123039, 0.018107909675953642, 0.016567582597157786, 0.06041379286242383, 0.013040750952703612, 0.03324281477502414, 0.05101916001045278, 0.0049012586075280395, 0.022167776378669908, 0.04069790955899017, 0.03205962272893105, 0.0459040068089962, 0.0350526542668896, 0.09751167041914803, 0.05997169337102345, 0.0596228585179363, 0.03649877184735877, 0.009863025575344051, 0.019591363645823937, 0.03675699174138052, 0.02519878721795976, 0.11788726278713771, 0.07252465906952109, 0.06800951742167984, 0.07936262964670147, 0.09953694138675928, 0.09056631488991634, 0.048642750563366075, 0.057583026188824854, 0.059690162406436036, 0.02132535140429224, 0.00717434667915638, 0.03060996998101473, 0.024270724338878478, 0.07270919345319271, 0.005962844031663346, 0.06536426900752954, 0.04696651800934758, 0.02734772288905723, 0.07808350292699677, 0.08891847902642828, 0.01731576245012028, 0.06923658014940363, 0.028437955637595484, 0.08616743343217032, 0.03706631550033178, 0.032240218216819425, 0.007762048759364656, 0.0985978285648993, 0.028399399581498334, 0.0026714873633214404, 0.01358040766457894, 0.045796092599630356, 0.018529629368068914, 0.02068333514034748, 0.03981981739135725, 0.08213245030492544, 0.04033475761700954, 0.03030328911596111, 0.049832982410277636, 0.024703110601486902, 0.029714432678052356, 0.0594751075176256, 0.026008406720523323, 0.10309336055070162, 0.0535868383012712, 0.03996258115928088, 0.028005029939647232, 0.06525538449308702, 0.04724579284499798, 0.051392632470067055, 0.03418672483946596, 0.09464295328195606, 0.07060742444757905, 0.024512367622394646, 0.07018641382455826, 0.041869834531098604, 0.035091924481093884, 0.04595473747966545, 0.039385151251086166, 0.04590202209406665, 0.1007376362436584, 0.04490954249298998, 0.02499813593125769, 0.05010571277567318, 0.046081833874008486, 0.06894716460789953, 0.015204668677012836, 0.07189925334283284, 0.033112084825656245, 0.019662240021196858, 0.0654166926230703, 0.010209359178718711, 0.019997975755749003, 0.03021134083558406, 0.008322251511604657, 0.07490752477731023, 0.03294029672230993, 0.003431483691591503, 0.03417129834581699, 0.020178343934406127, 0.006693894692164446, 0.0618913367922817, 0.11595266445406846, 0.024870181190116063, 0.018463797900559645, 0.01663130721343415, 0.04414588525625212, 0.07055318235818829, 0.07481774780899286, 0.035200768283435276, 0.019278796489483545, 0.03137536087472524, 0.03799765231087804, 0.030610227824321816, 0.05384509890739407, 0.04525617549994162, 0.03930379829502531, 0.034949601760932376, 0.029549321359289542, 0.03844113601371646, 0.0581742948187249, 0.061442777647503784, 0.020267796902252094, 0.05000074001561318, 0.026499998556183915, 0.03188038431107998, 0.056091830134391785, 0.01968077929424388, 0.0277307609960969, 0.05203878101227539, 0.05207911652645894, 0.046153307360197814, 0.020508956729567478, 0.009713752960254039, 0.03290121989058597, 0.03705449542030692, 0.027146023265751343, 0.045621230732649565, 0.05437356233596802, 0.037986982347709794, 0.029170071173991476, 0.04692224020670567, 0.05689233182264226, 0.047678877998675616, 0.011816680564412048, 0.009854386976387883, 0.005931954149023763, 0.01177163771353662, 0.010901601452912604, 0.02728542998167021, 0.05376403432871614, 0.013634650602138467, 0.016058482861678516, 0.016998289485595057, 0.04831263988411852, 0.02133026230148971, 0.05123190788019981, 0.06144967156329325, 0.02344877246235098, 0.08669177815318108, 0.03323245354528938, 0.030384584396545376, 0.07801401415573699, 0.03125856124929019, 0.06502403119312865, 0.0023383775592914647, 0.02575451079090791, 0.04189857388181346, 0.04029997591195362, 0.017749588903305785, 0.06284888541059834, 0.027200845502583042, 0.018385165869923573, 0.009532651115608002, 0.04624643289883222, 0.07868213366184916, 0.03208326967433095, 0.04257394014192479, 0.026969940035736988, 0.0491796583602471, 0.06536473719669239, 0.05176423895838005, 0.0427897549899561, 0.008554329995864203, 0.06312480489058153, 0.034229431833539686, 0.007861184421926737, 0.07506419172776596, 0.05814318398811987, 0.08809440503162996, 0.04359203104728034, 0.010568075198014932, 0.03283925946535809, 0.018833222898787687, 0.07025046074496848, 0.04563916441319244, 0.044865461465503485, 0.06479913076119763, 0.06694509275257587, 0.07921719923615456, 0.0471740445521261, 0.03498811201591577, 0.016985154743971567, 0.04034588559131537, 0.058610524982213974, 0.03133213480136224, 0.027485687718061463, 0.028109364876789705, 0.04666570647220526, 0.025809860588716607, 0.02801875670307449, 0.06253859134657042, 0.03571329970977136, 0.019587714823761156, 0.02726410192969654, 0.062474015168845654, 0.023106088529207876, 0.048756866582802365, 0.04084992854456816, 0.05938237892197711, 0.05603344558871218, 0.03686440383483257, 0.02197488922891872, 0.01833152089134923, 0.08118756315005676, 0.014399329034079398, 0.0379791961583708, 0.044188283516892364, 0.02822086344739156, 0.07586982992610761, 0.052281282642590146, 0.02935006276571325, 0.05586465661014829, 0.0023301159713550335, 0.046498542585011036, 0.023274762156818594, 0.04293119561459337, 0.05310427776670881, 0.03368788964248129, 0.04339636868930288, 0.028909914062491486, 0.025555257286344255, 0.02641601118791316, 0.1025880758783647, 0.030508752912282944, 0.02935111110231706, 0.021475321214113916, 0.01662683566766126, 0.03254495507904461, 0.00557196418023003, 0.03672621339293463, 0.03288329638806837, 0.05050505777554853, 0.03599306648331029, 0.018108864713992392, 0.021577420378369943, 0.090534464456141, 0.0351959371141025, 0.019675868397046412, 0.028083645006907836, 0.050563734091286144, 0.07271416711487941, 0.01651721663906106, 0.022253385445635234, 0.040472941273557286, 0.03877764867086496, 0.04127344974715795, 0.04780033237433859, 0.03377371075163994, 0.01027684033449207, 0.008448151987977326, 0.00994661684879767, 0.037741722472544224, 0.06961768612797771, 0.042272161692380905, 0.02856244645746691, 0.016986978306834186, 0.07554056402295828, 0.04881075583398342, 0.033005266450345516, 0.06995045327182327, 0.02266361245087215, 0.035028698588056226, 0.05875987732516868, 0.06781949368970734, 0.039012303043689044, 0.03048212719815118, 0.03336124288450394, 0.01293621669589941, 0.024898511723482182, 0.08059256257755415, 0.011249684828466602, 0.05831217991986445, 0.005104944642101015, 0.03813766122662595, 0.009166836771847946, 0.12796106508799962, 0.1453162402446781, 0.07775083756340401, 0.17353105624871595, 0.1193942619221551, 0.11220250997160162, 0.23252173726047787, 0.10092913918197155, 0.24349362137062208, 0.09819327241608075, 0.11913403017180306, 0.09782913659832307, 0.07793879854891982, 0.07173093594610691, 0.13090127946010657, 0.12472145392426423, 0.20245587772556714, 0.13408814131149224, 0.16196675678449018, 0.08340188075921365, 0.1505732581551586, 0.13845102648649896, 0.12679101287254266, 0.17235862916069372, 0.09245338184492928, 0.13053968814866884, 0.10418634475874049, 0.12273429626865046, 0.21220631737794193, 0.1619179429752486, 0.12474383200917925, 0.09448091233415262, 0.1406903684671436, 0.1872622301535947, 0.08984691849244492, 0.13518470818442957, 0.125459455751947, 0.1303736234882048, 0.14754026090460165, 0.22981525106089457, 0.11956210434436798, 0.08679327342127051, 0.12289854245526449, 0.17359383430864128, 0.09088057838380337, 0.09381203965416976, 0.11043620867920773, 0.16274234945220606, 0.14794116653501987, 0.1579031598355089, 0.13728139496275357, 0.14899087377956935, 0.15896430718047277, 0.08370880928954907, 0.21316839861018316, 0.20099040493369102, 0.051569122821092606, 0.10663522513849394, 0.17719604101564201, 0.17293880374303885, 0.14558612076299532, 0.17831018194556236, 0.09803305672747747, 0.12167595805866377, 0.15005036549908773, 0.13676648187850202, 0.10037527818764959, 0.16362270792680128, 0.19036666357091495, 0.2303151956626347, 0.147304130718112, 0.08124660926737956, 0.1085913669584053, 0.08248913580817835, 0.12225679760532719, 0.12038712150284223, 0.18383663254124777, 0.13655467038708075, 0.17772100998886994, 0.13483872317842074, 0.2382487085248743, 0.17226838400321348, 0.12456887853997094, 0.14608297124505043, 0.16401840240827628, 0.0954468883574009, 0.1698511301406792, 0.07857488441680159, 0.11905526582683836, 0.18209129119557993, 0.10891760659537145, 0.2394760698080063, 0.09436119840081249, 0.17296561944697583, 0.11830484680831432, 0.1372108816036156, 0.10736753405737025, 0.23250034983669007, 0.15589393622108869, 0.12192810167159353, 0.1445613293243306, 0.12488565939877715, 0.09362726099789143, 0.13033835323793547, 0.12360153187598501, 0.13117008789309434, 0.11628700579915728, 0.16773566151303904, 0.10375187200094972, 0.1340207899255412, 0.1286865547299385, 0.1223623233714274, 0.12496221171958105, 0.09103301806109292, 0.08436939705695425, 0.11976228574556963, 0.09022715594619513, 0.15771873401744024, 0.09788039313363177, 0.18986799461500986, 0.07696191168257169, 0.09240178604211126, 0.14675743505358696, 0.14687657223216125, 0.17672426918787615, 0.1572730043636901, 0.2342189433319228, 0.1443702131509781, 0.17908139127705777, 0.158541986984866, 0.11702101784093039, 0.09048518924308674, 0.13906335005802767, 0.12578137990619453, 0.11645678883152348, 0.1081539900707347, 0.29774887434073855, 0.1568937711417675, 0.11357954250914709, 0.08615481946617365, 0.15470563141363008, 0.26830314153007095, 0.06506671104580164, 0.08038208101476942, 0.18557974829205445, 0.09035077824124269, 0.1919024868735245, 0.15176538990012237, 0.0889857897002782, 0.07871632504143886, 0.1369397390101637, 0.17049664764532022, 0.06762514090431587, 0.13179009248103413, 0.11746791457491261, 0.0946788749258433, 0.11225707097245113, 0.17727428967399256, 0.17201416407312664, 0.1163375973701477, 0.17811784440917627, 0.12708361074328423, 0.08243072072842292, 0.09420077236635344, 0.1255137656948396, 0.17623919807374477, 0.06919120651270662, 0.11389329710177012, 0.10151622803615672, 0.15030962015901292, 0.16519898548722267, 0.10640177516532795, 0.1425688248127699, 0.1695070993155241, 0.08450614900461265, 0.14892448591334478], [0.015975413212020482, 0.05494900413655809, 0.013462256058119237, 0.06432587972709111, 0.0029107841879262453, 0.05473144206085375, 0.04826936631330422, 0.059800682190273485, 0.06021509745291301, 0.03258959589792149, 0.03147776877241475, 0.018644452760262147, 0.03179990327251809, 0.028212320691506778, 0.03358284902891942, 0.06020421375121389, 0.039324218806411536, 0.030646946746855974, 0.021433145173692277, 0.01740549361732389, 0.03124318564576762, 0.022118458757176995, 0.01726010731155319, 0.029435069632849524, 0.018317807698622346, 0.01344677952251264, 0.039531348406204155, 0.0067939022722254905, 0.03293998120352626, 0.0011333821686483653, 0.03308413257556302, 0.03875047673604318, 0.10740667195724589, 0.05541735275515488, 0.038614810444414616, 0.03113275746415768, 0.034860849380493164, 0.01161654750883047, 0.01107115632787879, 0.03423017143671002, 0.025351842665778737, 0.02155248082375952, 0.02470452195432569, 0.028406006816242422, 0.010579048805604023, 0.017111421629254307, 0.05575701381478991, 0.07255298790654965, 0.014372157099257623, 0.01086265523917973, 0.042431922762521675, 0.048831451152052195, 0.02686834129105721, 0.047920857157026014, 0.048957373680812974, 0.032510183552013974, 0.060337627306580544, 0.051060740636395555, 0.10877273258353982, 0.04801822014685188, 0.05688095957572971, 0.028979501221328974, 0.028018012010891522, 0.025937038407261883, 0.04427566186391881, 0.011503385679264153, 0.039384754308100255, 0.05517131595739296, 0.04567702666723302, 0.03795768320560455, 0.010817431728355587, 0.007504878050115491, 0.07062568382493087, 0.049810719676315784, 0.034055394386606555, 0.04207382590642997, 0.07311667408794165, 0.0395534143650106, 0.04878187399091465, 0.022932164736890366, 0.09264953274812017, 0.02535235326338027, 0.019402079517021775, 0.04614367216293301, 0.026041951795507754, 0.04705777757668069, 0.02471934285547052, 0.08641030147139515, 0.04779449697317822, 0.05224591739741819, 0.018926365400797555, 0.006970547414052167, 0.038586128769176345, 0.03653238647218261, 0.05496549253751125, 0.02530066416199718, 0.007559835993950921, 0.025582737954599515, 0.06298377138695546, 0.0034982791029116406, 0.016423483811584965, 0.0067372424777464145, 0.07151482254266739, 0.025420661383707608, 0.05230894651530044, 0.00508727177345593, 0.06622774553086076, 0.05754196124949625, 0.02223587584947901, 0.014025120363969888, 0.026591073222724453, 0.039036723519010205, 0.016389068515439118, 0.06416998630655663, 0.053216171583959034, 0.011374659952707589, 0.016884053026192954, 0.011258033353702297, 0.04550834286159702, 0.07414322293230466, 0.09392913444233791, 0.07096475455909967, 0.046081039988036664, 0.019452650731961642, 0.04566475196874567, 0.08006827213934489, 0.02137632804390575, 0.02558479561204357, 0.05991475071225848, 0.01962097321770021, 0.01034016631144498, 0.047989667393267155, 0.024898947682231665, 0.02450060352150883, 0.032734697218984365, 0.05935160057353122, 0.011053947831637092, 0.008053611864202788, 0.029617174861154387, 0.01981734125209706, 0.01928501356659191, 0.02396174832912428, 0.025705878489783833, 0.035909786487796476, 0.045895840640046766, 0.024648737894105058, 0.03880613696362291, 0.030806120884205614, 0.08662862689899546, 0.017001748317852616, 0.05327804379963449, 0.03184332951371159, 0.027708148816600442, 0.03921615531934159, 0.03392446766208325, 0.029192150703498294, 0.036742481270006726, 0.021158155286684632, 0.05391072342172265, 0.02785012378756489, 0.0390309525786766, 0.03713214696784105, 0.009821580656405007, 0.031006058012800555, 0.07873859456075089, 0.02304040633940271, 0.02597616782544979, 0.0805178897987519, 0.04427624201135976, 0.03992610311667834, 0.011822973976710012, 0.021149001849283065, 0.01681767194531858, 0.03360245190560818, 0.039954645692237785, 0.025106794832806503, 0.043775517094348154, 0.032892901051257334, 0.029293384735605547, 0.024385532464033792, 0.04931160627997347, 0.012702642890092517, 0.012057331490463443, 0.05459932450737272, 0.012045899023567992, 0.03140201033758266, 0.011238401639275253, 0.03462907878149833, 0.0248207125945815, 0.008434960419046027, 0.07304803348545517, 0.008684271996441697, 0.035500256677291224, 0.026428720148812448, 0.015536446856068713, 0.060784177987703254, 0.017219059335600053, 0.02907299656154854, 0.03138701471367052, 0.028214084882555262, 0.011897980085840183, 0.03479631391486951, 0.07498489812548671, 0.05985900227512632, 0.005903014206394021, 0.025280499797580496, 0.03035242183666144, 0.04561033685292516, 0.047960297004984956, 0.0732851746891226, 0.036482649855315685, 0.004380100880683, 0.05232750105538538, 0.05605102643104536, 0.034777284400271516, 0.0438093318870025, 0.0423026380927435, 0.011563260457478464, 0.03520941621224795, 0.03226222650014928, 0.07332450936415366, 0.04287110116066677, 0.030487582619701113, 0.06045103764959744, 0.03318056257973824, 0.01111821866860347, 0.02590815656419311, 0.043853697899196825, 0.03802344681961196, 0.06960466504096985, 0.04361663811973163, 0.03183068162096398, 0.024737442777092968, 0.019828479404428175, 0.021771103110430495, 0.020130434273076907, 0.04269041746322598, 0.03508681511240346, 0.03466177738404699, 0.03466852880748255, 0.039337840396910906, 0.006127517695339131, 0.017211542863930975, 0.030532749303217446, 0.10174632604633059, 0.06047693733125925, 0.010615310565169369, 0.034597167279571295, 0.03690198449684041, 0.047024576858218224, 0.01678681217267045, 0.022393616581601754, 0.0163185161405376, 0.06975067220628262, 0.02542531952661063, 0.07432019165051834, 0.012301367458089121, 0.03258664766326547, 0.044318453674869876, 0.030399637695934092, 0.040727944911590645, 0.08626409753092698, 0.03702349994065506, 0.0475260685198009, 0.024620180051507692, 0.0308605970681778, 0.014011112856678665, 0.033703187214476724, 0.018802056089043617, 0.08244682914976563, 0.05821098999253341, 0.02952834784186312, 0.0665600716269442, 0.027413591675992523, 0.046059944334306886, 0.06781738344579935, 0.03191161049263818, 0.01570154121145606, 0.039188386273703406, 0.09421363739030701, 0.02969754733411329, 0.04029713285022548, 0.021430933149531484, 0.04278640981231417, 0.038802856246807745, 0.03961277939379215, 0.022135366153504168, 0.007664414355531335, 0.03138685865061624, 0.039173960619206936, 0.029240269014345746, 0.03627623950264283, 0.05937262837375913, 0.026077354360105734, 0.03895774882818971, 0.026946812169626355, 0.05143912568954485, 0.009927370202993708, 0.030004777812532017, 0.035232944414019585, 0.05968976207077503, 0.058615091522889476, 0.03770607902801462, 0.015801974572241306, 0.012434066007179874, 0.03996443695255688, 0.06241925060749054, 0.059312734087663035, 0.03338658956012555, 0.007548124479529048, 0.05475568272439497, 0.04483013693243265, 0.029625402098255496, 0.03900991120774831, 0.044882937134908776, 0.008764919276083154, 0.007972697411397738, 0.057061612739094665, 0.014425830915570259, 0.04451327804209931, 0.03625279951042362, 0.018901636192042912, 0.061070275492966175, 0.022446253935673406, 0.01191902400127479, 0.011601119318843951, 0.011706991985972439, 0.035579071912382326, 0.017390019626223614, 0.01812624538849507, 0.05035457227911268, 0.09064507923488106, 0.03637115637372647, 0.0028043311613146216, 0.013549223891459405, 0.037039381052766523, 0.02307777156654213, 0.007126008692596639, 0.021505136042833328, 0.00401630305818149, 0.01653437509334513, 0.03012912274737443, 0.04943730489217809, 0.012312092552227634, 0.025892621504941156, 0.06934636711542096, 0.011894311755895615, 0.04348206766215818, 0.04454734728538564, 0.026967887467305576, 0.03480392707777875, 0.02832270985735314, 0.15451784006186894, 0.15647647210529872, 0.10791880983327116, 0.12430992243545395, 0.12414467201701232, 0.10109841331307377, 0.21229150066418306, 0.1871253696403333, 0.07939962337591819, 0.10243218924318041, 0.09414083058280603, 0.12854938209056854, 0.11637431968535696, 0.10639562085270882, 0.12474763180528368, 0.1450245108987604, 0.17928955225007875, 0.09512059443763324, 0.12156868167221546, 0.09194493519940547, 0.14847505145839282, 0.09388414078525134, 0.08250026378248419, 0.10617808252573013, 0.10355752600090844, 0.183790831427489, 0.18348506997738565, 0.14612356120986597, 0.10655436412032161, 0.14143170868711813, 0.2705863304436207, 0.11208827860121216, 0.1391160450875759, 0.1946819427290133, 0.15169817422117504, 0.09006932191550732, 0.1305704800678151, 0.11933114459472043, 0.09899962986154215, 0.12414791541440146, 0.09708170313388109, 0.12597415170499257, 0.09066436320011105, 0.08863274793007545, 0.24707612342068128, 0.14719656934695585, 0.08766663619982344, 0.12226128950715065, 0.10189186502248049, 0.11251758092216083, 0.09155012959880487, 0.1445757278374263, 0.08455584490937845, 0.14753434407923902, 0.11074837549988713, 0.10581135470420122, 0.17539238637047155, 0.12560764780001982, 0.1392607358949525, 0.0990042235436184, 0.14445239731243678, 0.17459616623818874, 0.05620676039585045, 0.18961378825562342, 0.13534524956984179, 0.06341675815305539, 0.10239782144448586, 0.14606648284409726, 0.23476994090846606, 0.128427761473826, 0.1136875788548163, 0.12461404183081218, 0.1772512194833585, 0.17424036961581024, 0.09016780448811394, 0.12663196426417145, 0.1052831762603351, 0.17820768244564533, 0.15474053525498935, 0.12362785903470856, 0.16988842242530414, 0.06291943948183741, 0.12941281790179865, 0.0927539389314396, 0.09552093009863581, 0.21671795099973679, 0.12716499423342092, 0.23840249170150074, 0.18219710194638797, 0.14981570094823837, 0.10713739533509527, 0.21203520441693918, 0.09862781981272356, 0.2475962612245764, 0.16462920606136322, 0.12020963031266417, 0.09772803488054446, 0.06687523757240602, 0.14842916892043181, 0.15072202017264708, 0.11084164692355053, 0.1183158526463168, 0.19762799250228064, 0.12726283898311003, 0.2080057377793959, 0.13317661093814032, 0.1168878214167697, 0.0910885561523693, 0.12418917034353529, 0.12072047218680382, 0.12826472307954515, 0.1432825486574854, 0.1724370542381491, 0.20212563473199094, 0.12931141762861184, 0.08308991071368967, 0.1663569597793477, 0.10806413167821509, 0.1291909912335021, 0.1419319382735661, 0.15320640828992638, 0.27275557975683895, 0.13825974746474198, 0.08158793952316046, 0.17939752074224607, 0.11634671688079834, 0.06072140671312809, 0.12404918856918812, 0.125800826719829, 0.0904390285057681, 0.146365418231913, 0.10941798545952354, 0.11026137056095259, 0.106733795920653, 0.15545636255826267, 0.1107129966840148, 0.07314477222306387, 0.12748835688190802, 0.11539956341896739, 0.06289511400141887, 0.07788022740611009, 0.11448071843811444, 0.07146131327109677, 0.14012867717870645, 0.10064267526779856, 0.14204515862677777, 0.09680011110114199, 0.1130940303472536, 0.10505904257297516, 0.13506937080195972, 0.10893853940069675, 0.10395958514085837, 0.14866067149809428, 0.06313560716807842, 0.12382091581821442, 0.17565408375646385, 0.08397875766136817, 0.0713652598538569, 0.11538687481411866, 0.08470360948038952, 0.13662846785570892, 0.05157339759171009, 0.13488109090498515, 0.10291325021535158, 0.11328166563596044, 0.047753164012517245, 0.10064212565443345, 0.14705600403249264, 0.14401308659996304, 0.07386270977024521, 0.10067356218184743, 0.2261836366461856, 0.19851578772068024, 0.08630018880856888, 0.12742841509836061, 0.13300975917705468], [0.007648445033867444, 0.028092085982539823, 0.0067572876744504485, 0.06660889900688614, 0.0548684722078698, 0.014996285483773266, 0.05845400730946234, 0.014953542866611054, 0.04332589604226606, 0.04147685079702309, 0.03787446427824242, 0.006110861781053245, 0.037377413628356795, 0.01184189916654889, 0.03719878249934741, 0.06903660230870758, 0.06778120395860501, 0.014621890216533626, 0.027365943250645484, 0.01969827531969973, 0.04088518861681223, 0.013214409268195075, 0.04904388350301555, 0.06178408754723413, 0.09167445757027183, 0.08204936369189195, 0.05247447174042463, 0.1178769219134535, 0.0455099102774901, 0.0506332398259214, 0.023241712412397777, 0.011550985758991113, 0.06969734613916703, 0.014399615715124776, 0.029032932461372445, 0.01677089204479541, 0.01835560379549861, 0.1141814709241901, 0.03458442099924598, 0.05547553374032889, 0.050729432342840095, 0.05697975427444492, 0.04745667813611882, 0.02424072121669139, 0.06234685770635094, 0.06731096561998129, 0.032684071721243005, 0.06275567505508661, 0.052522013296506236, 0.030107938884092227, 0.04746123110609395, 0.022693174525297115, 0.03286148827256901, 0.04210502833926252, 0.04151903192645737, 0.06382994526731116, 0.04054877434724143, 0.04164642009085842, 0.08648420750562634, 0.023539864092266986, 0.018127929851678864, 0.047601803205907345, 0.056057482691747804, 0.029770455921867063, 0.04764547711238265, 0.011989706145998622, 0.02862235770693847, 0.03698149862300072, 0.03609914864812579, 0.04002140336004751, 0.008133277812573527, 0.014122395992412098, 0.03094754454546741, 0.014136568892614117, 0.05549493984186223, 0.0227562630149935, 0.018206573756677762, 0.019669697121051804, 0.026292760390788317, 0.017054407724312375, 0.023734712208222066, 0.02559335872397891, 0.029860975886029855, 0.030047043758843626, 0.017316505445965698, 0.05871951806225947, 0.03469785848366363, 0.04487271839752793, 0.04536883606176291, 0.010659658765819455, 0.037689607590436935, 0.02206681376057012, 0.013813829648175409, 0.07052909436502627, 0.03341162071696349, 0.024596156519172446, 0.013675090441081141, 0.07640163174697331, 0.02076232000919325, 0.05822670486356531, 0.11043792537280492, 0.014148433925583959, 0.028316265471013527, 0.030675075416054045, 0.022062104727540697, 0.04739303833671978, 0.04702936392277479, 0.05271893094426819, 0.07419046254030295, 0.06404668970831803, 0.07579930299626929, 0.05084617090012346, 0.05853091246847596, 0.017325489249612604, 0.02703029572564576, 0.01621775877928095, 0.009733063218716, 0.026534454564430883, 0.03542352454470737, 0.005400005170875894, 0.029104551832590784, 0.07456417248717376, 0.03487872199288436, 0.06835222510354859, 0.02836226505626525, 0.020157132929723178, 0.021158155286684632, 0.03281611463587199, 0.047425669085766585, 0.026928503598485674, 0.0013069551371570143, 0.047799094047929556, 0.015862679707684686, 0.10862573475709983, 0.03000122568170939, 0.0350610409597201, 0.07082498313060828, 0.02762429885167096, 0.003340281587692776, 0.04470729834533163, 0.03267195987116013, 0.0215989044933979, 0.017930125019380024, 0.013202992068337542, 0.057708670518227985, 0.027990857039445212, 0.022021772606032233, 0.023707211183916246, 0.03953091075111713, 0.038596568030438254, 0.058452690951526165, 0.03518058525930558, 0.04702954712722983, 0.02821858017705381, 0.08601725327649287, 0.04025076176705105, 0.041706687571214776, 0.012109973933547735, 0.040829952473619154, 0.053277799527027776, 0.015109120768361857, 0.06123278462993247, 0.055148238981408734, 0.042468963989189694, 0.09761335567704268, 0.0404441171059651, 0.01730682614392468, 0.053924368760947666, 0.0334159836971334, 0.05572006419034941, 0.026630563960809792, 0.03355404861005289, 0.009256268535474581, 0.06416895493332829, 0.0253864767894681, 0.010565758849095021, 0.005210715104892317, 0.01345198049343058, 0.030052153127534047, 0.07132661049919468, 0.060972247538822036, 0.05658249916242702, 0.04924620228952595, 0.02010613084504647, 0.00565811141028202, 0.02529810947765197, 0.044117997466985664, 0.005512136475382639, 0.05558411291401301, 0.009158397492553507, 0.048166938059564145, 0.05853514652699232, 0.0637627567297646, 0.016019509506544898, 0.09557032744799342, 0.03775653149932623, 0.05293491542605417, 0.024740750635308877, 0.02603536152413913, 0.013397436455956526, 0.07152788434177637, 0.07305041514337063, 0.052622168457933834, 0.07953191056315388, 0.055513857398182154, 0.025391124754345844, 0.05384517354624612, 0.025743287821699466, 0.032774632397506914, 0.016362181565325176, 0.016678275407424996, 0.03160333167761564, 0.044224113558552096, 0.0818431976118258, 0.01757800605680261, 0.050199184367167096, 0.020392642256670764, 0.04104762650760157, 0.026124721193420034, 0.03709061723202467, 0.04078631927924497, 0.08252363931387663, 0.013824694690161517, 0.08799090129988534, 0.04393251652696303, 0.025475132478667156, 0.026723662358043448, 0.014091074815951288, 0.012809604605925935, 0.015098267600738575, 0.10847256904734032, 0.02287256222085229, 0.0696598638647369, 0.01667300658300519, 0.03674205718562007, 0.045954394819481034, 0.05418577098420688, 0.009440826667871858, 0.04627600684762001, 0.014117690352057772, 0.027336966412674104, 0.0298558325905885, 0.023638730037159154, 0.01990725053474307, 0.006586166231759957, 0.04527011600189975, 0.0240265009259539, 0.014168645787451948, 0.02253413270227611, 0.021154604852199554, 0.04665957251563668, 0.02219527231396309, 0.028640413523784707, 0.05478467313306672, 0.010745282251653927, 0.026811071239145737, 0.041078913757311444, 0.0199683322571218, 0.04558996044631515, 0.04120510770007968, 0.07004073914140463, 0.09920873399823904, 0.023983609031087587, 0.05338073328935674, 0.03747672740636127, 0.02516670777861561, 0.08035525174013206, 0.02362589893995651, 0.050613949075341225, 0.09197210374155215, 0.06398407449679715, 0.06945369778467075, 0.01863433071412146, 0.03877151132162128, 0.026700895811830248, 0.055887842151735506, 0.011548385273532143, 0.009718698632371212, 0.009889989708816367, 0.05577735968732408, 0.043961133741374524, 0.05744997225701809, 0.015231061992900712, 0.08685850777796336, 0.13185968303254672, 0.020259362711970295, 0.08596942334302834, 0.06932949873485736, 0.055233975273690054, 0.033824787475168705, 0.0330238481318312, 0.020712966764611856, 0.05909083956586463, 0.010574373699325536, 0.04777961330754416, 0.00788681099324354, 0.05543308458956225, 0.023276088692780052, 0.06827211725924696, 0.04871029193912234, 0.023657328682020307, 0.025608272923688804, 0.046118702074246745, 0.04630252399614879, 0.03607825316222651, 0.022379648938242878, 0.012229326546990445, 0.010787542260784124, 0.026180581588830267, 0.08011618349701166, 0.0692725967881935, 0.020804784426997815, 0.05230844779206174, 0.057100770995020866, 0.05425439801599298, 0.04686436456229005, 0.03119364919673119, 0.021231459121086767, 0.03450475759538157, 0.02486730250529945, 0.030165566863226037, 0.04919469130358525, 0.02316786066096808, 0.02183456818706223, 0.025789304370326654, 0.02784076509332018, 0.03489926464057394, 0.15225552288549288, 0.009763675326082324, 0.016707749272297536, 0.032581948808261325, 0.02666450767511768, 0.0398486076321985, 0.03242480009794235, 0.10935818616833005, 0.0639714469601001, 0.04008472764066287, 0.08075743301638535, 0.02512723739658083, 0.06466005143842526, 0.03350574030940022, 0.012807458738929458, 0.028500418178737164, 0.045424204519284625, 0.023075669804321866, 0.03340807197881596, 0.020271104760468006, 0.034529686971966705, 0.019074806810489724, 0.054451770282217433, 0.04395138319315655, 0.05525298443223749, 0.06257611433310167, 0.09047741323177304, 0.14595423958131246, 0.0853439090507371, 0.2954862043261528, 0.08319470366196972, 0.07775115647486278, 0.060939996769385676, 0.11354622643973146, 0.08947490488312074, 0.12799282052687236, 0.13212154326694353, 0.1869665245924677, 0.12954160384833813, 0.16739597331200326, 0.3204609341919422, 0.2520863174327782, 0.08563228643366269, 0.12670676596462727, 0.11264853818075997, 0.13734456657298974, 0.12147896577204977, 0.13987881344343933, 0.21417062197412762, 0.2106470303343875, 0.19379919581115246, 0.1514694807784898, 0.2386269239442689, 0.1788474324026278, 0.12301819532045297, 0.1648905234677451, 0.08381333760917187, 0.1572305823543242, 0.10023331509104796, 0.1204546493078981, 0.14512867959482328, 0.07980867821191039, 0.1858469418116978, 0.07896878078047719, 0.1777212814028774, 0.17504473216831684, 0.146832318178245, 0.18003903489027703, 0.10558580966400248, 0.13771018838243826, 0.1954240564789091, 0.10429052702550377, 0.1978182808629104, 0.1630844668086086, 0.18593763480229036, 0.0950110178174717, 0.07526294142007828, 0.10469609419150011, 0.12983454098658903, 0.2690925491707665, 0.18978313702557767, 0.1394961875464235, 0.11645142840487616, 0.1659809292427131, 0.1024769250569599, 0.13307744983051503, 0.19074789168579237, 0.1672118596200432, 0.1457948109933308, 0.1610896959900856, 0.10189916605928115, 0.06953670297350202, 0.12980244628020696, 0.09445840532758407, 0.09820458359484162, 0.18427962091352257, 0.11524854866521698, 0.157776287357722, 0.14782411924430303, 0.12019885517656803, 0.10903561740581479, 0.08775613496878318, 0.182327909927283, 0.08421292009630374, 0.0989667751959392, 0.14394937216171197, 0.13287097162434033, 0.09176430239209107, 0.10967933000730616, 0.15557541831263474, 0.1959587149322033, 0.07558359671384096, 0.11843877605029515, 0.1363561446113246, 0.08674198295921087, 0.31037038564682007, 0.10283956131232636, 0.1166778283991984, 0.15581015071698598, 0.16967845654913358, 0.11175757420382329, 0.10555882432631084, 0.12213267997971602, 0.14628669459904942, 0.13478031488401548, 0.15882068845842565, 0.07943263410457543, 0.1123048330524138, 0.11722307199878351, 0.0710896932120834, 0.15085312670895032, 0.11424742452800274, 0.13535549544862338, 0.21914270945957728, 0.1288602596947125, 0.23822221851774625, 0.10586706921458244, 0.1401274829570736, 0.09867099499596016, 0.07624214209084, 0.10367626962917191, 0.1559125552220004, 0.07640390483928577, 0.08973199501633644, 0.1635761061417205, 0.10187264891075236, 0.13688370558832372, 0.14975854115826742, 0.14801101492983954, 0.09953231377793209, 0.09880208117621285, 0.09725234112037079, 0.10339430440217257, 0.1463749720049756, 0.1633230804332665, 0.08226255260940109, 0.24839668827397482, 0.08842966918434415, 0.1803589912929705, 0.1297993521605219, 0.08238676522991487, 0.14437868126801082, 0.15241235946970327, 0.10221895961357014, 0.28599325514265467, 0.1536048711942775, 0.05715283498700176, 0.1312930112970727, 0.14520943883274282, 0.1614309855337654, 0.10822569086615529, 0.11516955361834594, 0.1178462521306106, 0.12398304497557026, 0.11014544285301651, 0.15509766180600437, 0.17151419232998574, 0.12972976160900934, 0.14454789433096135, 0.09138185291418008, 0.15348230062850884, 0.210842584126762, 0.10430706292390823, 0.17242340211357388, 0.1285193365599428, 0.09583344975752489, 0.17221016569861344, 0.0810099837503263, 0.1243014136063201, 0.13810519075819425, 0.11096704698034696, 0.14169165545276233, 0.17070236589227403, 0.11862359541867461, 0.09715234541467258, 0.11111715928252254, 0.15445226643766674, 0.08338834398559161, 0.1288521308451891, 0.09269694877522332, 0.12505545600184373], [0.05097677532051291, 0.03507064223023398, 0.035584605365459404, 0.018211879900523593, 0.029645093184496676, 0.0738416819700173, 0.05641271273738571, 0.007098040327296725, 0.07408119804625, 0.010684625461830624, 0.05441325663455895, 0.03431224024721554, 0.013174703095241316, 0.052409427373536994, 0.005567761503958276, 0.0344380202836224, 0.030926411572311605, 0.029746303467878273, 0.025927908718585968, 0.018738358614167998, 0.05830260579075132, 0.055142138951591084, 0.03557512623124889, 0.03654747709099736, 0.07092611877513783, 0.05219697466652308, 0.051277393475174904, 0.04090366173269493, 0.04338289298383253, 0.028111067999686514, 0.039600657365683994, 0.014289806696719356, 0.046073538783405504, 0.03748126341296094, 0.029419405651944022, 0.01743513541961355, 0.03544654384521501, 0.010384032752231827, 0.03547987687800612, 0.026006815555904592, 0.03689688191350017, 0.008928795661112028, 0.054629424320799966, 0.04312040510454348, 0.038747426721134355, 0.030748306307941675, 0.026191360117601495, 0.0744747890691672, 0.04090582625940442, 0.05604058377710836, 0.030892841052263975, 0.012917998878817474, 0.03554649883881211, 0.041355467667537074, 0.04306911803515894, 0.04099608838026013, 0.052168530478541336, 0.08304073728088822, 0.0661508132304464, 0.06009163122091975, 0.017365460051223636, 0.013880347284222288, 0.007670711160504392, 0.006362252220112298, 0.020421237418694154, 0.03836990001478365, 0.0387567905043917, 0.028037665777706673, 0.06935260285224233, 0.04013896294470344, 0.019063091903392757, 0.03583971756909575, 0.011923854322438794, 0.02287064366308706, 0.04288265661203435, 0.03695169736498168, 0.0340760557779244, 0.05353576836309262, 0.008294995608074325, 0.03935727703252009, 0.055875102656760385, 0.007329468266107142, 0.019314360206148455, 0.01196685478290809, 0.06791433931461402, 0.06322915679109947, 0.010662293178029358, 0.05570941458323172, 0.03365629705201302, 0.05095752867470894, 0.07956394420138427, 0.01329938814576183, 0.031984614075294564, 0.06337145236986023, 0.06151833252183028, 0.016293072773675834, 0.026532622519880533, 0.07005051004567317, 0.019850462242694836, 0.06758191822362797, 0.04821261025166937, 0.04761620171900306, 0.015621077136269637, 0.039124179897563796, 0.01960357727615961, 0.02590493013017944, 0.03074977533625705, 0.023084088727565746, 0.028988943036113466, 0.02073477318377367, 0.047195472688015015, 0.026054185781893984, 0.04096319639523115, 0.05224303362358894, 0.07739798578300647, 0.031247158468301808, 0.022448638986263956, 0.030100807481046234, 0.0505979458269264, 0.046687097288668156, 0.06556668278894254, 0.06331035707678113, 0.02059086099533098, 0.0325364767839866, 0.023830791070525135, 0.042040017899125814, 0.036695937160402536, 0.01952379003965429, 0.014673123003116675, 0.02750893772047545, 0.008550537833278733, 0.02969755411946348, 0.06712212253894125, 0.043574022727885416, 0.03796736929299576, 0.020106956961431673, 0.045467976813337634, 0.09085405444992439, 0.04456280092043536, 0.039567789129380665, 0.039911541755178144, 0.05543954424293978, 0.002781814188762967, 0.029683505051902363, 0.02302784156719489, 0.008642534459275859, 0.0330368013653372, 0.020941773861912743, 0.04954848964033382, 0.06429901652570282, 0.037984064647129605, 0.0421523290154125, 0.030388998266841685, 0.03042797671098794, 0.04650214221328497, 0.037772612779268196, 0.04561492035697613, 0.04232903989031911, 0.05330614872010691, 0.01612190044085894, 0.03409000985058291, 0.02988771695111479, 0.02099300834483334, 0.01726873658065285, 0.00872332338310246, 0.005699618245541517, 0.0063595249334217185, 0.047316584403493574, 0.024451543743323003, 0.03742489411628672, 0.016711940922375237, 0.020080858808276907, 0.016252041761098162, 0.02814607022862349, 0.019723123272082636, 0.1256253711347069, 0.027219115057960153, 0.04293058493307658, 0.02833821777520435, 0.05032118835619517, 0.07357764363821064, 0.031257078650274446, 0.02410194044932723, 0.0453843066601881, 0.004071770751449678, 0.04781279027728098, 0.039142249285110405, 0.036414704751223326, 0.021071579307317734, 0.032568493458841524, 0.06689740531146526, 0.034747500105627944, 0.02280017440872533, 0.04728082221533571, 0.039751594087907245, 0.034079672369573794, 0.06277569183813674, 0.0305264457128942, 0.016959843691438437, 0.07262434264911072, 0.04288376262411475, 0.02139804625351514, 0.02788862556086055, 0.03549282332616193, 0.06559964602014848, 0.023093055567837188, 0.02299203018524817, 0.02128880550818784, 0.04734109648104225, 0.033951269795319865, 0.014947327485840236, 0.017403829510190656, 0.03768031505335655, 0.05809392913111618, 0.028042941387476664, 0.05760174018463918, 0.01541311972375427, 0.00576151124135192, 0.03296896482684782, 0.06657065677323512, 0.05147445022261568, 0.05345211178064346, 0.03435891667114837, 0.039272209097232134, 0.026412029883691242, 0.02858309427808438, 0.027317646824355637, 0.05274227594158479, 0.022750612514625703, 0.054660402837076356, 0.0317469334362873, 0.03836318251809903, 0.06091227861387389, 0.06746986495064837, 0.01968228055297264, 0.017206260468810797, 0.0017923373171860085, 0.06186305545270443, 0.028040768379079442, 0.04863029266042369, 0.07494968894336905, 0.032205850418124876, 0.006903052687578435, 0.04279992962256074, 0.032693486394626756, 0.011445747522105063, 0.025795811521155492, 0.04716389366824712, 0.045794871236596785, 0.06887585057743958, 0.04540278995409608, 0.03617369929062469, 0.051428459119051695, 0.04112877929583192, 0.02359099849127233, 0.02567989908025733, 0.04704566911927291, 0.025499546168638126, 0.043870552709060054, 0.06322836969047785, 0.016537979810631702, 0.06545930462224142, 0.07632124570331403, 0.08043093553611211, 0.09829152428678103, 0.02854428207501769, 0.04686530772596598, 0.05045213543676904, 0.04567544228796448, 0.010606891641925489, 0.061782750833247385, 0.047445556947163174, 0.03667840381552066, 0.05502055226159947, 0.029823619140578166, 0.04480785044974514, 0.03777353558689356, 0.023901964304968715, 0.049732803500124385, 0.06404711718537978, 0.02836689436142998, 0.03536991349288395, 0.026778009620362093, 0.009902676617327546, 0.045543911667274575, 0.002983685990329832, 0.029424878036869422, 0.04651823027857712, 0.0583230500508632, 0.009542829140887728, 0.058892395214310715, 0.010868226859851607, 0.0635837252650942, 0.04112616015065994, 0.09480432248009102, 0.05320704189528312, 0.04004823602735996, 0.029388830864003727, 0.073881586614464, 0.019525851089773432, 0.04403270222246647, 0.04400339290233595, 0.029919404536485672, 0.03465657302045396, 0.026299779835556234, 0.026354710637990917, 0.05259367337982569, 0.0638568898929017, 0.054493361086185486, 0.0022979190606357796, 0.02332833588921598, 0.015013579645061066, 0.06751353546444859, 0.08317029675734894, 0.08553585303681237, 0.01978489540384284, 0.021128101274371147, 0.03188245723556195, 0.06270184008670704, 0.10926523365612541, 0.014975907380825706, 0.045335994966860325, 0.03340289814929877, 0.043335161437945705, 0.026834282225796154, 0.05852083622344902, 0.09161963872611523, 0.03353449323081544, 0.02120855008251965, 0.0654978725527014, 0.023676151243437613, 0.017830728120835762, 0.024121200665831566, 0.017869014459263, 0.007534140720963478, 0.023231899099690572, 0.012328876964082676, 0.035334789127643616, 0.03659299661272338, 0.03559141107169645, 0.026249179782878076, 0.02988475514575839, 0.015601609966584613, 0.05830555741808244, 0.042379485576280525, 0.02703228044057531, 0.03167910707582321, 0.04948576586320996, 0.018292846091623818, 0.028764907736331224, 0.026313861133530736, 0.044055090485406775, 0.12459642706172806, 0.2091801054775715, 0.10279883564050708, 0.1495870617883546, 0.18010865258319037, 0.20655933182154382, 0.20593297614582948, 0.10886932882879462, 0.17136236333421298, 0.10341113207063504, 0.10277474086199488, 0.14512604687895092, 0.09267241973429918, 0.11097120640001126, 0.14693118073046207, 0.14619476667472295, 0.1850731676178319, 0.13295249082148075, 0.15670756756195, 0.1461605413683823, 0.09535647356616599, 0.11853797787002154, 0.10845241655728646, 0.12488380021282605, 0.1519102978387049, 0.1344331085149731, 0.24357409562383378, 0.17457955570093223, 0.15679294083799633, 0.09505588255290474, 0.1976908655571086, 0.1462547898824726, 0.14694477857223578, 0.10224715274359499, 0.10733908308403832, 0.1479094246668475, 0.150503667603646, 0.1149298543376582, 0.15687873480575426, 0.13307217082806996, 0.12407101025538785, 0.07994609512388706, 0.1408573016524315, 0.17367315505232128, 0.0898569675960711, 0.12079657667449542, 0.09539046817060028, 0.11883091500827245, 0.10926751353378807, 0.16759990022650786, 0.15509150070803507, 0.1469686630048922, 0.08510457617895943, 0.11535140100334372, 0.1386334574116128, 0.13536492708538259, 0.1285836481090103, 0.2141868525317737, 0.12665132965360368, 0.22823415590184076, 0.09204786896173443, 0.07295567808406693, 0.07877552043646574, 0.12251890211233071, 0.16303608726177896, 0.09942747333220073, 0.1462724589343582, 0.10773103883756058, 0.17606556096247264, 0.10046381343688283, 0.17750933420445236, 0.09008601387696606, 0.1444924580199378, 0.20745621940919332, 0.13029029938791478, 0.17918374149927072, 0.14519601741007396, 0.1489719697939498, 0.1106566172093153, 0.12842392096562044, 0.15346539153584413, 0.1448711891259466, 0.11848039738833904, 0.14616252269063676, 0.1384894044271537, 0.14718591634716305, 0.17167854708220276, 0.20088577483381542, 0.18172630720904895, 0.10343872130449329, 0.16710632028324263, 0.14852648441280636, 0.10393192805349827, 0.08779415328587804, 0.16626486900661672, 0.11101527724947248, 0.121965013976608, 0.23030862744365418, 0.08618939761072397, 0.15413526844765457, 0.1042844405663865, 0.11207270622253418, 0.09579062062714781, 0.14282233906643732, 0.08696167902754885, 0.05595252689506326, 0.10261143783905677, 0.10596052384270088, 0.09277523814567498, 0.10364862611251217, 0.13080073414104326, 0.0862291936895677, 0.1938767930758851, 0.1257889387863023, 0.15742581044988974, 0.11962581878261906, 0.2119862006178924, 0.11337268432336194, 0.1773430931248835, 0.1440423857420683, 0.17692478985658713, 0.16652545359517845, 0.15543892420828342, 0.14130027645400592, 0.09902248970632042, 0.09346338122018746, 0.11178976390510798, 0.10630884300917387, 0.12742266112140246, 0.09246398734727077, 0.0966098363112126, 0.13936115907771246, 0.2086373453161546, 0.14504545048943587, 0.0832465776641454, 0.08745958802423306, 0.18139862907784327, 0.15187953306095942, 0.10876562832189457, 0.12823641459856713, 0.09961224520312888, 0.12623134361846106, 0.12110601578439985, 0.1422656417957374, 0.1148984245955944, 0.10271422232368163, 0.11789095401763916, 0.11110359536749975, 0.09934546558984689, 0.1578510890581778, 0.1862363802003009, 0.19312897963183268, 0.08577583051685776, 0.13505721145442554, 0.15260350278445653, 0.08187697508505412, 0.11132705051984106, 0.1519552847104413, 0.2415384091436863, 0.10403988976031542, 0.1550574789622, 0.12012579052575997, 0.11184791435620614, 0.06888693105429411, 0.08931785116770438, 0.09481995592692069, 0.05902506916650704, 0.2083957732788154, 0.1004904934338161, 0.14529056447957242, 0.06665412336587906, 0.13908302757356847, 0.07653493673673697, 0.10112557506987027, 0.15535326594752924, 0.2548965652074133], [0.06560027705771582, 0.014972199186948794, 0.044421696170632324, 0.016393618092739155, 0.011186366485032653, 0.03022014143477593, 0.040582453432892046, 0.02733244058409972, 0.03348123501720173, 0.059640249370464256, 0.05364636957113232, 0.03143611690029502, 0.011613218446395226, 0.019744800769590905, 0.04584112357614296, 0.05618205154314637, 0.02349217834749392, 0.041763504701001306, 0.07374357937702111, 0.038710120865809064, 0.016280143288895488, 0.06552770095212118, 0.009017570093939347, 0.04119852591039879, 0.03697043510952166, 0.007658185404060143, 0.04777701451842274, 0.014265408273786306, 0.02419289806857705, 0.04652233880811504, 0.06641753856092691, 0.02812557338204767, 0.024489887757226825, 0.057143084438783784, 0.011709640817051488, 0.003447369468631223, 0.020373661935861622, 0.039405992454183955, 0.08779810914503676, 0.04522660494382892, 0.05950498341449669, 0.040496961413217444, 0.06286658838923488, 0.046788830044014115, 0.032092853981469355, 0.024061991700104306, 0.040627413163227696, 0.01989037367249174, 0.051270343496331146, 0.006263562694324979, 0.03701181896030903, 0.044077818015856404, 0.0250057372198041, 0.039194333633141856, 0.03631229346085872, 0.03086829844063946, 0.01960966712795198, 0.02075913598361824, 0.027991231930043017, 0.10704539277191673, 0.017105769432548965, 0.042178567964583635, 0.05300700977178557, 0.016565314593857954, 0.021797102876007557, 0.04600241474275078, 0.04015172279572912, 0.030380974590246166, 0.008520934198583876, 0.05630816066903727, 0.04290880056630288, 0.05089726458702769, 0.03506539376186473, 0.07564821360366684, 0.03678500505962542, 0.034295432934803624, 0.008764977799728513, 0.014448407471978238, 0.015003555986498083, 0.010462093965283461, 0.019769619884235517, 0.03912275158134954, 0.01924835062319679, 0.017394211276301315, 0.037615392822772264, 0.05256419103326542, 0.02198763211656894, 0.01763208020877625, 0.041690633432673554, 0.058418547069387775, 0.02844434743747115, 0.016321890155917833, 0.008080296101979911, 0.076906326093844, 0.026500266577516283, 0.05521123077986496, 0.05549146234989166, 0.05059190007991024, 0.033085445540824106, 0.02607402444950172, 0.03287107936505761, 0.02897330280393362, 0.05198491890249508, 0.034013752692512104, 0.0061850561926673564, 0.035812467602746825, 0.08098654715078217, 0.009256410179659724, 0.030769476600523506, 0.011512029367232961, 0.02531499821426613, 0.014635930802407009, 0.017987003217318227, 0.011747287636223649, 0.02833409228229097, 0.041250257420220544, 0.06530356726476125, 0.02821644109540752, 0.05010632345718997, 0.008434813685848244, 0.0050881665915117735, 0.053360767396433015, 0.04527000065094658, 0.0261018952753927, 0.06298738119325467, 0.03799594918798123, 0.04080267875854458, 0.0569483856005328, 0.13684311562350818, 0.03931593389383384, 0.019979821551325064, 0.02275794747817729, 0.04226693358006222, 0.010340028059934931, 0.051491050581846914, 0.060544071586004326, 0.03160302633685725, 0.03687218663149646, 0.017687104309776, 0.026053190031754117, 0.049501599477870126, 0.05576045738000955, 0.06473228827651058, 0.009004023990460804, 0.04675933412675347, 0.05217139728899513, 0.016944563082818474, 0.019553862711680785, 0.07286352624318429, 0.04068479686975479, 0.044334297467555316, 0.04212239205038973, 0.034268552770039866, 0.05494444098855768, 0.021084585127287676, 0.047997151634522846, 0.080320646454181, 0.05922334388430629, 0.018533602190603102, 0.02659566351212561, 0.04165962777499642, 0.026487554223941903, 0.020090186968445778, 0.029287834319153, 0.023332434240728617, 0.018853288875626664, 0.056992755005402226, 0.017928235299353088, 0.0727772708716137, 0.006200467843362796, 0.041014632742319784, 0.025697266184059635, 0.03539783860157643, 0.04467380924948624, 0.07352562035833086, 0.04701280766831977, 0.02183552661777607, 0.0024611215755742577, 0.021025722214419926, 0.01580113827783082, 0.034246659837663174, 0.026081515476107597, 0.025124696282935993, 0.003775425671067621, 0.055259623897394965, 0.051401779122118435, 0.07511233378733907, 0.05568693132538881, 0.05027136352977582, 0.03045632251139198, 0.030639258945094686, 0.030306997309838022, 0.05747204500117472, 0.02100303369973387, 0.07564182180379118, 0.01697112772879856, 0.018897086614742875, 0.028914226152534996, 0.023883133261863674, 0.040996997617185116, 0.04749011294916272, 0.040163220571620126, 0.012921862287579902, 0.031188275199383497, 0.0488766822963953, 0.04346405255741306, 0.09135791419872216, 0.019851758244580457, 0.05525954247319272, 0.030859324815017835, 0.056949912304324765, 0.027304488334006498, 0.027654167963191867, 0.03836042427324823, 0.03545584995299578, 0.004992273054085672, 0.041226851354752264, 0.05431924560772521, 0.0261822711410267, 0.015888031472318938, 0.05003622739708849, 0.0640630695436682, 0.013942831877752073, 0.02271327273254948, 0.02339316651757274, 0.028072751127183437, 0.02353476490160184, 0.04627109764676009, 0.008081502197975559, 0.04994278294699533, 0.0401186035014689, 0.03960018239117094, 0.06157656439713069, 0.06374330313077994, 0.007510613367360617, 0.0807345663862569, 0.038611407591296096, 0.016601041158927337, 0.023963780541505133, 0.010875391341479761, 0.0372158069429653, 0.015011165756732225, 0.0058877005191919, 0.02913847179817302, 0.03399397000404341, 0.03216783210103001, 0.001941009216742324, 0.06472123494105679, 0.019241585629060864, 0.05782501891787563, 0.04113736615649291, 0.009119885541232569, 0.04031044231461627, 0.03448991464184863, 0.040871336324406524, 0.012843558498259102, 0.01799380892355527, 0.05011454390894089, 0.019995180191472173, 0.07308164132492882, 0.018658651105527366, 0.03478339121543935, 0.027226563676127365, 0.007325291883067361, 0.013345612495738481, 0.044919045375926156, 0.029938535831336464, 0.014644366689026356, 0.01375573008720364, 0.04219162297834243, 0.048471071025622744, 0.02489452702658517, 0.12220422471208231, 0.012333981243760457, 0.009652278535733265, 0.02280739402132375, 0.036151545122265816, 0.038633290345647504, 0.06386003829538822, 0.05503476417756506, 0.020619936220880066, 0.006665067980065942, 0.029454367168779885, 0.016642499648566757, 0.03601759552423443, 0.040931162757000754, 0.005331038023411695, 0.03474361549264618, 0.055026730322944264, 0.018458006604175483, 0.0733742324103202, 0.02949433627405337, 0.03882354138685124, 0.009912811385999833, 0.02837970679891961, 0.03825058302442942, 0.09806796735418694, 0.0115856953697013, 0.02092624898068607, 0.06642056482711009, 0.03294617283557143, 0.031229129792856317, 0.03228688107005187, 0.049319365327911716, 0.09866006379680974, 0.03117817859830601, 0.06639165244996548, 0.01867875949080501, 0.043526396354926486, 0.0035773596027866006, 0.043948417995125055, 0.014477345294186046, 0.023418633633160164, 0.03892527074952211, 0.05846513528376818, 0.020824775764984742, 0.01983981772458979, 0.03280316818771618, 0.03159303490870765, 0.03897420669506703, 0.03130366007930466, 0.04857090049024139, 0.012523628388797598, 0.04341515053861907, 0.0323466091150684, 0.06752345564642123, 0.03756345775244491, 0.036490636212485175, 0.014271438753764545, 0.041855147640619955, 0.03646874328010848, 0.04916241339274815, 0.01216434155191694, 0.037944031081029346, 0.011765234887466898, 0.0327015948880996, 0.04455616484795298, 0.04576360095026238, 0.00962808367330581, 0.044567900111100504, 0.046704304936741076, 0.01316663616203836, 0.018804129013525586, 0.023994579246001582, 0.05762046096580369, 0.05288051048825894, 0.001666827846617837, 0.0214729446452111, 0.09552578162401915, 0.05031291362164276, 0.03009467013180256, 0.03404168119387967, 0.11971515470317431, 0.09914183723075048, 0.1100327449717692, 0.10282132229102509, 0.1634379971240248, 0.10922969877719879, 0.13542629379246915, 0.07601939940026828, 0.15819199862224714, 0.12848394417337008, 0.19500789738127164, 0.08613641081111771, 0.1518080833234957, 0.11000214982777834, 0.11164421814360789, 0.12869814410805702, 0.11315708660653659, 0.14432494129453385, 0.15365714553211415, 0.17997073355529988, 0.11128164974174329, 0.1202516316303185, 0.10060537619782345, 0.10235526372811624, 0.14084819571248122, 0.07639584384326424, 0.14215787686407566, 0.0986431682748454, 0.20142544087554726, 0.11424564676625387, 0.17107325313346727, 0.10083092802337237, 0.09128693943577153, 0.13379504132483686, 0.10853637169514384, 0.11477968096733093, 0.086785795965365, 0.19525359491152422, 0.19936209730803967, 0.13564516204808438, 0.09782693814486265, 0.11663407646119595, 0.17819355534655706, 0.15585865240011895, 0.10355981944927148, 0.16661663513098443, 0.10470240456717354, 0.10599412489682436, 0.09206733613141946, 0.1222404313406774, 0.07397635081516844, 0.14697874603526934, 0.1257457568177155, 0.1389725213604314, 0.11237892907645021, 0.07612761895039252, 0.16844413349671022, 0.13031326101294585, 0.12361669034830161, 0.18431457903768333, 0.20934063329228333, 0.156192491629294, 0.08096718176134995, 0.05730354439999376, 0.10903413819947413, 0.106037374718913, 0.1215019409677812, 0.11799786399517741, 0.16901602995182785, 0.19321569640721592, 0.15109904137040886, 0.21164839874420846, 0.11870982364884444, 0.17346499407930033, 0.1253376587160996, 0.11967712960072927, 0.10578659496137074, 0.06607523800006934, 0.10828705078789166, 0.10579001477786473, 0.1716463438102177, 0.11548747441598348, 0.09692906668143612, 0.14421856057431015, 0.053568042881254635, 0.170242631275739, 0.14173623520348752, 0.10798567945935897, 0.12981854113084929, 0.1875385974666902, 0.16777313021676882, 0.0688289977344019, 0.13410491469715322, 0.11714505404233932, 0.13600614267800534, 0.14428743187870297, 0.256447967674051, 0.13677476000572952, 0.13790396441306385, 0.10459149801837546, 0.14522296882101468, 0.22505154167967184, 0.1250911062317235, 0.11308069713413715, 0.1496926282665559, 0.12726938006068977, 0.10373817237892322, 0.10007849375584296, 0.18749272849942955, 0.13904732306088718, 0.05895856594932931, 0.07135981800300734, 0.109572277537414, 0.10180281408663307, 0.14233150040464743, 0.16365750320255756, 0.1109595423830407, 0.14017610677650996, 0.070502522933696, 0.18465282874447958, 0.1554715753133808, 0.11733314394950867, 0.17364209171916756, 0.19982709735631943, 0.1037742772272655, 0.08589108647512537, 0.1397140651409115, 0.11661908083728381, 0.19327413184302195, 0.10821455610649926, 0.09911525222871985, 0.10681421589106321, 0.19777496318731988, 0.06787974081401314, 0.19985109035457882, 0.1055438354877489, 0.13021891750395298, 0.15207529041383946, 0.17074968692447456, 0.209357759516154, 0.12369454545634133, 0.18518984849963868, 0.10432807036808558, 0.17418977804481983, 0.09795587336910622, 0.14170279699776853, 0.14920035111052649, 0.14856079114334925, 0.21592359005340508, 0.13861912675201893, 0.11567572717155729, 0.11219496466219425, 0.10773536110562937, 0.1604184755789382, 0.10551690443285874, 0.07613333221524954, 0.15982847580952303, 0.1738327464887074, 0.06371036704097476, 0.09203575711165156, 0.11603782059890883, 0.10792159182684762, 0.1384145620145968, 0.13433328244302953, 0.19488243625632354, 0.21464539292667592, 0.07189581995563847, 0.13271508498915605, 0.11095509119331837, 0.2877085373869964, 0.14724767660456045, 0.1094425552125488, 0.23638713413051196, 0.18738288725061075, 0.15345140014375958, 0.1172696195010628], [0.029258776056979383, 0.040804965421557426, 0.03459605448214071, 0.022812842657523494, 0.00487408455228433, 0.020459812134504318, 0.049965337451015196, 0.053325015386300426, 0.032987811136990786, 0.03986184245773724, 0.018990073053698455, 0.042882795711713176, 0.03875727226425495, 0.03088012191333941, 0.033102785503225665, 0.0033256996580998278, 0.022407697879576256, 0.059164460615387986, 0.019339160661080053, 0.035485220341277976, 0.03737653153283255, 0.04110468451731971, 0.02816503867506981, 0.03187020967847534, 0.009881340083666146, 0.11894393180097852, 0.02322327491960355, 0.055700281501880715, 0.023988865981144563, 0.03203622005613787, 0.03172054181673697, 0.020497296105272005, 0.032346585366342745, 0.03520938228549702, 0.020247674946274077, 0.013698465972473579, 0.06106754099684102, 0.060478233333144865, 0.021334202893610512, 0.047951336950063705, 0.029881437109517198, 0.03589774927656565, 0.07766350332115378, 0.021915463131985495, 0.04292862396687269, 0.03214788995683193, 0.06690908968448639, 0.0521181458607316, 0.07472050017012016, 0.0036778960160778035, 0.04913840003843818, 0.053260846329586845, 0.06083259146128382, 0.05406178228024926, 0.026768742528344904, 0.029087547745023454, 0.03472649944680078, 0.04089738867644753, 0.018136477696576288, 0.08811670847769294, 0.02726078898246799, 0.049400684357221634, 0.0619512242930276, 0.020357483964679495, 0.007717424903863243, 0.023712427421872104, 0.007243594570484544, 0.014402278965072972, 0.001048363745212555, 0.03936486644670367, 0.07651629737977471, 0.07820004131644964, 0.02407265148524727, 0.021462873489196812, 0.04121922462114266, 0.010138017158689243, 0.07092143009815897, 0.047871978886957677, 0.015068637672811747, 0.0586183417056288, 0.04404350449996335, 0.03338189409779651, 0.02697361260652542, 0.028266255743801594, 0.005753792905514794, 0.012375856184267571, 0.022557126557720557, 0.03593564885003226, 0.020957843267491887, 0.04986201013837542, 0.003297055302287585, 0.03698262159845658, 0.03410007931025965, 0.05602840068084853, 0.03130671687956367, 0.042294125870934556, 0.04257066621045981, 0.060320697857865264, 0.03370599974212902, 0.037468462849834135, 0.021835158512528454, 0.02982154960877129, 0.0014430729726362707, 0.02297827967309526, 0.021029145423589007, 0.01598101112592433, 0.026028545639876808, 0.056303692515939474, 0.021118859627417157, 0.051197848814938746, 0.04733582426394735, 0.024564608033480387, 0.01480846359793629, 0.019001206117016927, 0.021548177215403745, 0.005918162924769733, 0.030604945429201637, 0.04504345137892025, 0.03931154377226319, 0.014795513757105385, 0.020573583797418644, 0.04049454243587596, 0.048070599657616446, 0.005878944448860628, 0.05129839752667716, 0.034363378038895984, 0.048281447629311254, 0.04838060534426144, 0.003283644905812772, 0.015653409329908233, 0.06582597137561866, 0.05280345605154123, 0.012642254969770355, 0.12387637927063874, 0.030842436078403677, 0.04297712904268077, 0.04295142274349928, 0.010721178991453988, 0.03991065626697881, 0.010225236898155084, 0.03649362515924232, 0.031993876078299115, 0.0335546966109957, 0.030123009146856408, 0.0259514114752944, 0.014211258634791842, 0.04555981992078679, 0.017707691062241793, 0.049955631007573435, 0.019949920209390775, 0.03213961182960442, 0.022969182214832733, 0.0726380083443863, 0.126560704516513, 0.029037122415112596, 0.055362886749207973, 0.01973146077112428, 0.044749211453433545, 0.027505015788067664, 0.04453300305509141, 0.04690581287390419, 0.03884923072265727, 0.01808654091187886, 0.026205502483727675, 0.03491548841286983, 0.008759187351513122, 0.05383622706202524, 0.018139573512598872, 0.011738185088948479, 0.03797809693164059, 0.021416765338342105, 0.020296941677640592, 0.030166167366717542, 0.026183906410421644, 0.03766073592539344, 0.05218841494726283, 0.045049374989633045, 0.031163118513567106, 0.04150340865765299, 0.03941625529634101, 0.028859916209642376, 0.03620024697322931, 0.023054406213174974, 0.033211591986141036, 0.036476437867219956, 0.04270766243072493, 0.06459204187350613, 0.018576412661267177, 0.027217291495097534, 0.053251268807798624, 0.06789288403732435, 0.010153279955764967, 0.030998512703393186, 0.016024986980482936, 0.06300961678581578, 0.005505340099002102, 0.054662326483854225, 0.02038053040658789, 0.006206815114377865, 0.035690439864993095, 0.03575767929266606, 0.05911319050937891, 0.09015506160046373, 0.03613440872036985, 0.043095648754388094, 0.04858236773205655, 0.03312535697062101, 0.05255608593246766, 0.03732213338038751, 0.02177644657370235, 0.016423147936750735, 0.04266947787255049, 0.06514062386538301, 0.049119251780211926, 0.05515436954530222, 0.014190399620149816, 0.049734917136707475, 0.05416426481679082, 0.07601802197418042, 0.011353705094994178, 0.04281864361837506, 0.0782254660235984, 0.036622339859604836, 0.018252642891768898, 0.037170657222824435, 0.05993360720042672, 0.03601767016308648, 0.02504528054435338, 0.019180106963696222, 0.0329583864659071, 0.00903752920151289, 0.061689940813396654, 0.033032234824661694, 0.011929975556475776, 0.03002539509907365, 0.003848680735765291, 0.03906788523974163, 0.025452761179102317, 0.036407128907740116, 0.009595946558485073, 0.04481446955885206, 0.060412754703845294, 0.022780999009098326, 0.01813678812634732, 0.02706661431251892, 0.015627468936145306, 0.03560642705165914, 0.029464772503290857, 0.03401354913200651, 0.04182880351852093, 0.039073479760970385, 0.013378250878304243, 0.030915066466799805, 0.054741606515433104, 0.04846336626048599, 0.017755984095856547, 0.05732268587286983, 0.0471599378090884, 0.03127044918281691, 0.061048854142427444, 0.03918530233204365, 0.017074343083160262, 0.08618834588144507, 0.0035511603055056185, 0.04994740377047232, 0.0653007309883833, 0.037157598816390545, 0.029602264054119587, 0.02008818868281586, 0.053816725965589285, 0.022536661941558123, 0.07540717082364218, 0.08092302270233631, 0.022216825978830457, 0.011750092530356986, 0.03569307936621564, 0.024104198274601783, 0.039294515935970206, 0.02998308844066092, 0.016121781697230678, 0.04956784485174077, 0.0404044601268002, 0.02820931138869907, 0.0230008002503642, 0.014500072824635675, 0.06457291397133044, 0.07443820924631186, 0.012651279485518379, 0.04434481815301946, 0.02120834312933896, 0.037819431695554934, 0.029114641648318087, 0.018619582755491138, 0.04835353858236756, 0.04336452504087772, 0.03272461418860725, 0.04626562526183469, 0.049994952111904106, 0.06564964726567268, 0.016584199919764484, 0.0886152960093958, 0.03574428840407303, 0.026434850712705935, 0.019122392471347536, 0.007221380182142768, 0.06145876393254314, 0.01311654840329928, 0.06762982958129474, 0.01891445371854518, 0.06096507542367492, 0.029657900532973663, 0.01947383120256875, 0.05659623271120446, 0.03321687098858612, 0.06472066497164113, 0.007694907719269395, 0.021728170503463064, 0.05309890716203621, 0.06264531133430344, 0.045717406286192794, 0.06177614190216575, 0.00833062463373478, 0.02674305488887642, 0.01707438040258629, 0.021825577598065138, 0.02582039145220603, 0.07426280115864106, 0.02625793288461864, 0.040360392670014074, 0.0523385374274637, 0.02567040467900889, 0.02267970221250185, 0.012556881693724011, 0.024710543952616196, 0.012119711759234113, 0.04589792713522911, 0.06067528668791056, 0.022048986949292675, 0.02264662193400519, 0.02095941237972251, 0.045076577458530664, 0.028556024123515402, 0.045740680037332435, 0.025905720623476163, 0.06050679287207978, 0.06586532640670027, 0.028584861861807958, 0.027622619477499808, 0.02314319591304021, 0.015982288468096937, 0.03534054649727685, 0.034681783989071846, 0.1300205002937998, 0.12823976656155928, 0.20334868053240435, 0.11036479286849499, 0.06188230549118348, 0.14237860430564198, 0.14289225531475885, 0.1338071735309703, 0.09641947331173079, 0.12970173811273916, 0.1347894479653665, 0.13560104370117188, 0.10064259384359632, 0.1370617938893182, 0.11034263191478592, 0.13414108061364718, 0.10429172124713659, 0.14129695163241454, 0.2370464258960315, 0.10217936709523201, 0.13866264798811503, 0.171445687434503, 0.10632603030119624, 0.16571829547839506, 0.1049225688246744, 0.18081709742546082, 0.19890536181628704, 0.1667183203888791, 0.14042431488633156, 0.10838925851775066, 0.08589310850948095, 0.12634792950536522, 0.10606607675020184, 0.08758249785751104, 0.05097596447116562, 0.1892780355576958, 0.16626229057354586, 0.14960775710642338, 0.19627834563808783, 0.11883106428597655, 0.09906470136983053, 0.127495196514896, 0.12679778465202876, 0.06060828135481902, 0.1054313275963068, 0.17482343475733483, 0.1293687131255865, 0.13703408251915658, 0.12299049752099173, 0.07944822683930397, 0.18352304079702922, 0.09551062315170254, 0.1081357171226825, 0.10949176935745136, 0.19481361923473223, 0.1305781610842262, 0.10605222785047122, 0.08386745756225926, 0.08948599214532546, 0.14361670001276902, 0.15902382827230863, 0.10904687430177416, 0.152930990925857, 0.09824651705899409, 0.22006276223276341, 0.08913759834000043, 0.10749726995293583, 0.0697664956429175, 0.13516914259110177, 0.171155111598117, 0.12805082170026644, 0.14824524521827698, 0.14057336188852787, 0.09900632700217621, 0.2295475554253374, 0.09990596265665122, 0.1881214590477092, 0.14920206101877348, 0.09215781877615623, 0.13143791923565523, 0.16995932933475288, 0.1010040155212794, 0.10799609497189522, 0.13280577797974857, 0.1452283835304635, 0.15123972882117542, 0.1448054662240403, 0.10514409693756274, 0.22962447415505136, 0.13772745031331265, 0.1304344337965761, 0.0817209527428661, 0.14823708922735282, 0.11960705050400325, 0.07798120698758534, 0.1505859467600073, 0.2448215958263193, 0.11623800200011049, 0.11463432519563607, 0.13391417850341114, 0.08746342174708843, 0.07632755607898746, 0.17712604334311827, 0.13828353690249579, 0.12698914509798798, 0.15284415201417037, 0.152758887303727, 0.17518522962927818, 0.08006346132606268, 0.1749572418630123, 0.15184389640177998, 0.0949349133297801, 0.16026898074362958, 0.08406560335840497, 0.09984555268394095, 0.12552314304879733, 0.08562281408480235, 0.2820089789373534, 0.09934775903820992, 0.18510809860059194, 0.16201886827392237, 0.1280089153775147, 0.12628782487341336, 0.09757085902882473, 0.24055228063038417, 0.07447631577295916, 0.0948391720386488, 0.11841063041772161, 0.0658538591648851, 0.23833105553473743, 0.12940684679363454, 0.17530879085617407, 0.05204010076288666, 0.21922673923628672, 0.11370013175266129, 0.12000319281859056, 0.14580604753323964, 0.13779664731451444, 0.18577498995832034, 0.21703812453363622, 0.08470246954155819, 0.14850751257368497, 0.12354145438543387, 0.11040729630206313, 0.13520566134580544, 0.09163578785955906, 0.1323294463966574, 0.04774363059550524, 0.19143277779221535, 0.15213156810828618, 0.10594207447554384, 0.07090777118823358, 0.14722582777695997, 0.25964386761188507, 0.09669270579304014, 0.1987092923372984, 0.09196242104683604, 0.20084561913141183, 0.1421482688082116, 0.17152023129165173, 0.19680881074496678, 0.09434819766985518, 0.09960767866245337, 0.05118808808869549, 0.11778810167951242, 0.09213818875806672, 0.13709315577788012, 0.10325692141694681, 0.09963657068354742, 0.12074005470744201, 0.10790219251066446, 0.1259614766708442, 0.11024767772427627, 0.09187945657010589, 0.11987190986318247, 0.11382642747568232], [0.035980764643422196, 0.021423321682959795, 0.02020522579550743, 0.01665921705508871, 0.019327060685360005, 0.0432162854953536, 0.04313705635390111, 0.035996533797255585, 0.017533794411325028, 0.05874943467123168, 0.0073826433591810715, 0.03886355798957603, 0.034896452112921646, 0.019256747494052564, 0.032667912409773896, 0.012661723835792924, 0.0407031139225832, 0.018388254900595973, 0.05778104306331702, 0.05071665892111404, 0.019051621268902506, 0.02322719685201134, 0.04336882695289595, 0.04914668155834079, 0.09513776137360505, 0.01276671271105962, 0.08241703467709677, 0.026459720717476945, 0.04909329442307353, 0.0747392073805843, 0.024291675803916793, 0.027283282418336188, 0.019495150772854686, 0.026277140514659028, 0.02587120863609016, 0.004395313635801098, 0.0236919458423342, 0.024581495073757002, 0.03855699247547558, 0.02411694625126464, 0.04916311567649245, 0.027978897859741534, 0.05693246038364513, 0.027451112966186235, 0.025284979825041125, 0.014074715336651673, 0.056811474197145016, 0.04098974407783576, 0.04760240370939885, 0.006987536234581577, 0.04312386563313859, 0.0367086054092007, 0.05172099592164159, 0.04774300634328808, 0.06099377066961356, 0.013476028622660254, 0.02953667685921703, 0.033473275801432986, 0.0651257164510233, 0.046074512481157265, 0.027918805102152482, 0.023108914627560546, 0.0233417556155473, 0.03449162794277072, 0.02429590986243316, 0.0459977362437972, 0.05342195429173963, 0.02354362656894539, 0.0609130792851959, 0.04200234902756555, 0.0324722195177206, 0.02282046769479556, 0.028717264399996827, 0.009037183996822153, 0.037538898177444935, 0.015124221565201879, 0.12624901267034666, 0.03187542422009366, 0.04929654619523457, 0.02249517122150532, 0.028707863297313452, 0.03152294563395636, 0.05405328023646559, 0.041582298531596146, 0.004854669120894479, 0.05211375234648585, 0.012634406864110912, 0.010183918356363262, 0.019521863000201325, 0.02364345433722649, 0.04457441404727953, 0.023188903728233914, 0.009228276421449013, 0.024913570111883537, 0.020240947271564176, 0.032157531939446926, 0.01541842077858746, 0.0166773441181119, 0.01858195798870708, 0.040706618555954525, 0.029348688732300485, 0.006161238341259637, 0.022754230802612643, 0.002176785928895697, 0.0439939273388258, 0.00857146639776017, 0.03085216966324619, 0.028494704913880144, 0.016859232215210795, 0.06460864562541246, 0.013093934527465274, 0.030096956794815402, 0.0706073430233768, 0.01966073197711791, 0.07203139125236444, 0.01880782363670213, 0.02810549553084586, 0.028541164206607, 0.017265942712713565, 0.014149035277244235, 0.01458597875067166, 0.05148481823770063, 0.005743346858902701, 0.05108664710340755, 0.037072893897337575, 0.013362186561737741, 0.025063466979190707, 0.036354515302394114, 0.01804892293044499, 0.025820935976558497, 0.023626511317810843, 0.02997483406215906, 0.07587221836937325, 0.029915516530828815, 0.032006428976144106, 0.055908306767897945, 0.03556024595828993, 0.07691098762942211, 0.021944078650059443, 0.03368580314729895, 0.004915489183206643, 0.04997871816158295, 0.05904265000884022, 0.05914320211325373, 0.04027881919007216, 0.019077461578750184, 0.01414046622812748, 0.02629095039862607, 0.037029209812836986, 0.029923696270478622, 0.006911868129723838, 0.07638711788292442, 0.027400702903313295, 0.03790718662951674, 0.06566370651125908, 0.05989037773438862, 0.012359668035060167, 0.05782825552991458, 0.02433223184198141, 0.08634290937334299, 0.05933477969041892, 0.03986502817964979, 0.023973658315039108, 0.009968979666674775, 0.05897508149168321, 0.0024765779671724886, 0.044550241237240176, 0.0070574715667005095, 0.022048630718407885, 0.03424301610461303, 0.02110200990656657, 0.04568986115711076, 0.026740055764093995, 0.053888073922800164, 0.03901557018980384, 0.007463819896137076, 0.038411850442311594, 0.037976970563509634, 0.032826061959245374, 0.036989179639411826, 0.030559005215764046, 0.047172555167760165, 0.02458794285277171, 0.04077182916392173, 0.06154324832771506, 0.05130653316155076, 0.03555577780519213, 0.004258536243079496, 0.010676796864052969, 0.008325694228655525, 0.05033394142187067, 0.03369187603571585, 0.015153990592807531, 0.012897293382723416, 0.057268932328692505, 0.07818990400327103, 0.0325516386489783, 0.04599821461098535, 0.018931807251647115, 0.03394554295976247, 0.03902377707085439, 0.0716830517298409, 0.09548105259558984, 0.05832002378468003, 0.0646355359682015, 0.018159396913168684, 0.011793454310723712, 0.05858036410063505, 0.04215907026082277, 0.030674088147601912, 0.04436521152300494, 0.003676341746800712, 0.02761205468725945, 0.03797935900677528, 0.06317851093730756, 0.013843315387410777, 0.046384033015263934, 0.023467578060392822, 0.05051487617726837, 0.055437471318457804, 0.01696633896790445, 0.015712277331788625, 0.016489054043112055, 0.07879221918327467, 0.03346389166212507, 0.0315741852058896, 0.031091641634702682, 0.026437614046569382, 0.043608984244721274, 0.037866790047181506, 0.06041768765343087, 0.014909209084830113, 0.04450491849066956, 0.04779856139793992, 0.007041394951686795, 0.056179646136505265, 0.03383856173604727, 0.09280382482601063, 0.027159197023138404, 0.03620679483615926, 0.031685220676341226, 0.013832624220023198, 0.07255593953388077, 0.01965056752253856, 0.04191571706905961, 0.05624617310240865, 0.09162650550050394, 0.026209985903863395, 0.05221415517319526, 0.0486739122840975, 0.013274683533901615, 0.019840577683810676, 0.0805179372962032, 0.003620236654699381, 0.025415412915338362, 0.010813113701130663, 0.037738526572606394, 0.027493692734943967, 0.020227931273568953, 0.02681718483966376, 0.05333120023299541, 0.036142150804932625, 0.05069666249411447, 0.009205617592670023, 0.009959297820127435, 0.037822356181485314, 0.01592737462903772, 0.022818454142127718, 0.046017230554882965, 0.010362912501607622, 0.02656663578402783, 0.07348981406539679, 0.03061635499554021, 0.006212653060044561, 0.02344137303797262, 0.033272612640368085, 0.028744901131306375, 0.05297359870746732, 0.019291732759614075, 0.04145613173022866, 0.07358782844884054, 0.04533634441239493, 0.0359561134661947, 0.04168534764487829, 0.05346239837152617, 0.05193542316555977, 0.02354381825508816, 0.022690217808953354, 0.054539189341345, 0.06897035014948674, 0.03701250088800277, 0.04708601141880665, 0.053394622901188474, 0.03532241604157856, 0.01866537199488708, 0.024084542811449085, 0.022877966752275825, 0.03581389252628599, 0.014785783564937966, 0.026976635480033498, 0.025899591755920222, 0.026862042789746608, 0.008228664569157575, 0.009153522218444517, 0.03931505519098469, 0.07784294190683536, 0.03198228330750551, 0.07821507765246288, 0.07337159290909767, 0.04445209114679268, 0.024265438551083207, 0.02002563453944666, 0.027089443623221347, 0.025080315003703748, 0.02090916007624141, 0.029406320104109387, 0.00600605780657913, 0.051543698113943846, 0.06102792812245233, 0.03592189833787935, 0.07043768891266414, 0.02752264921686479, 0.03640258272311517, 0.029121657700410912, 0.07198603118636779, 0.01783527260912316, 0.03326340831284012, 0.05389424519879477, 0.06365422505353178, 0.016684127771960836, 0.13318712823092937, 0.04151245013677648, 0.018983847494902353, 0.06617675362420933, 0.06606251546846968, 0.045468801233385286, 0.0797986766057355, 0.16494391060301236, 0.04094900144264102, 0.029041088452296596, 0.033194285950490406, 0.013788322668655642, 0.10571473810289587, 0.005174452921242586, 0.02138119313998946, 0.07799920173627989, 0.0331199897586235, 0.019061602519026825, 0.04111542572666492, 0.04521606729498931, 0.018413016339764, 0.025063492424253906, 0.151034716250641, 0.11135389336517879, 0.1372988604541336, 0.14919638846601757, 0.09135795491082327, 0.13984365175877297, 0.17372143960424832, 0.157713739999703, 0.17013657625232423, 0.1622718668409756, 0.0782454963773489, 0.08893766121140548, 0.08331118098327092, 0.18919176661542483, 0.14036539090531214, 0.07868189617459263, 0.1270498875528574, 0.08219689077564649, 0.1309607598398413, 0.1195139962115458, 0.09995044062712363, 0.13633726776710578, 0.08354681583919696, 0.12238398220922266, 0.1560639635260616, 0.2255669433091368, 0.18448003301663057, 0.1028972300035613, 0.1750214991292783, 0.1527995586927448, 0.0670896071408476, 0.1468497429575239, 0.07132596589092698, 0.12772204434233053, 0.10914566221513919, 0.09839759966624634, 0.13753788119980268, 0.12250681061829839, 0.1337813620588609, 0.06237756820129497, 0.14038687332400254, 0.10090298844235283, 0.11750178704304354, 0.08933476704571928, 0.06760294602385589, 0.11971400119364262, 0.1726070272603205, 0.14813952946237155, 0.11031998920121364, 0.05336432970528092, 0.13426031278712408, 0.11151339659201247, 0.12946293449827603, 0.10559440670268876, 0.2059060518762895, 0.053939873286123784, 0.10838520087833915, 0.10160470900258847, 0.12663268351129123, 0.09901465941220522, 0.08259692109589066, 0.09410743308918816, 0.08579258354646818, 0.1177873145788908, 0.13745234507535184, 0.13509501942566463, 0.18710528500378132, 0.15661787880318506, 0.15303247262324604, 0.10741681605577469, 0.20152347561504158, 0.07952283854995455, 0.15061794647148677, 0.14937905009303773, 0.078942867528115, 0.14938955381512642, 0.22015606079782757, 0.07866567240229674, 0.15016818631972584, 0.1328393518924713, 0.08543296677193471, 0.11877306311258248, 0.1759424339979887, 0.0811077267197626, 0.09832205157727003, 0.1704435862068619, 0.13531415909528732, 0.10900445907775845, 0.2030870509999139, 0.18657899967261724, 0.17830224308584416, 0.09499335555093628, 0.10302505243037428, 0.07169256479080234, 0.09282865242234298, 0.3073200450411865, 0.10160208985741649, 0.16464471737188952, 0.16220318552638802, 0.1221160287303584, 0.106949563271233, 0.18864660444004194, 0.07810761127620935, 0.09727342998875038, 0.10812268246497427, 0.12363298875944954, 0.12574226914771966, 0.1217529039297785, 0.2134184930473566, 0.208467765844294, 0.07350589534533875, 0.22028247187180178, 0.0982327563688159, 0.1801212461931365, 0.13282522479338305, 0.06372653653046914, 0.06326165861849274, 0.09336552289979798, 0.11549208845411028, 0.11907019359724862, 0.08183937067432062, 0.15744296381516115, 0.11122923969690289, 0.09228978705193315, 0.14083541211272987, 0.11669427608805043, 0.11538927682808467, 0.1236999873071909, 0.1196347347327641, 0.10783019994518586, 0.10556913805859429, 0.13697496854833194, 0.15622196719050407, 0.13035875000059605, 0.15963262346174034, 0.16221712263567106, 0.09220990990953785, 0.16680414149803774, 0.1374547199479171, 0.09819451413516488, 0.10973000978784901, 0.18683692440390587, 0.095798559486866, 0.17775185619081768, 0.12765972768621786, 0.09292650395738226, 0.06988739022719008, 0.08213194818901164, 0.14073603387389863, 0.13318729107933386, 0.11694724751370293, 0.11866290973765509, 0.13820009066590241, 0.15937647649220057, 0.19528304333133356, 0.16346497567636625, 0.08393558926348176, 0.15105169319680758, 0.19619138459009783, 0.15287830946700914, 0.13208468524473055, 0.2511204906872341, 0.09184375884277479, 0.08959868324122258, 0.10760069226047822, 0.1123784269605364, 0.1767638549208641, 0.12021068882729326, 0.1065186799636909, 0.19578749340559753, 0.09708047498549734, 0.1628368150975023, 0.07679571810045413, 0.1714277605393103, 0.09392285799341542, 0.14250854376171315], [0.07340891233512334, 0.020877165453774587, 0.024070078141189048, 0.057284104371709485, 0.009296752479193466, 0.022953056830114553, 0.016395979394604052, 0.036246132903865406, 0.05113368993625045, 0.06440416909754276, 0.005659095710143447, 0.007116225065796503, 0.03748476126098207, 0.03660371746601803, 0.0691939749355827, 0.01319702944186117, 0.05842681162591491, 0.06444268953055143, 0.05179297152374472, 0.0262274038977921, 0.03282321550484214, 0.04657237398039017, 0.018845528131350875, 0.02610045508481562, 0.024692145475585545, 0.07206644437142781, 0.021343376687062637, 0.01908759380291615, 0.0024704794216501924, 0.029115700162947178, 0.06051143405160733, 0.025052705413794944, 0.03564803142632757, 0.025394748131345426, 0.06964730418154172, 0.05163466930389404, 0.04079241591638752, 0.03831104388726609, 0.07451095498566117, 0.06961518911910908, 0.03500921445499573, 0.015501984062471559, 0.003846100182272494, 0.06668032160294907, 0.0341122522284942, 0.015384746781949486, 0.04248285020834633, 0.07213458964335066, 0.031520798070622344, 0.05552617620144572, 0.019333315081894398, 0.01761772919313184, 0.02448884111696056, 0.037562321206288676, 0.022993673936330845, 0.0431494633667171, 0.048571806334491284, 0.009916664616736983, 0.029311745893210173, 0.008042498308766102, 0.03514570855934705, 0.12013400079948561, 0.0527937292520489, 0.08243538904935122, 0.061308889117624076, 0.0670849931027208, 0.0035300682564931257, 0.04945524875074625, 0.032334351379956515, 0.015533050788300378, 0.04346285494310515, 0.10307715034910611, 0.02472871003140296, 0.026057744698066796, 0.08265992307237216, 0.02481627667189709, 0.06212024736617293, 0.045411332709980864, 0.015342530029426728, 0.06593894745622363, 0.0076722972361104825, 0.008247454051992722, 0.03221249666863254, 0.03312969959474035, 0.041299254433917146, 0.03692299533369286, 0.039554493235690255, 0.04378232619326029, 0.0662364172083991, 0.047489071397909095, 0.049526176016245566, 0.05163838767579623, 0.01070376269386283, 0.019962919244010533, 0.047346972594303746, 0.048107749449887445, 0.01261501433327794, 0.02247883888360645, 0.043948136403092315, 0.0009585117139587444, 0.05286329944751092, 0.036826585685568194, 0.006763616285752505, 0.03298731241375208, 0.07253812798964125, 0.006374179169402591, 0.0408671294072909, 0.039971710847956796, 0.06382623368075915, 0.04467586860326784, 0.00788262952119112, 0.03222687143300261, 0.020463705229173814, 0.03987512817340238, 0.023126777061926465, 0.03604661307430693, 0.02746489570875253, 0.030577895630683218, 0.0504627002270094, 0.03169596188568643, 0.030483087325202565, 0.03969924171854343, 0.06606305151113442, 0.025810138788074255, 0.007342664075882307, 0.07309493382594415, 0.03709884786180087, 0.027560370674889003, 0.03858977250222649, 0.04610482603311539, 0.01871881171661828, 0.021310398188818778, 0.021568346668833067, 0.036651445619229756, 0.05080766403781516, 0.0041596855652252475, 0.06266663768993956, 0.014570788047941667, 0.07956534876887288, 0.06138341940407242, 0.016098638564082127, 0.06125050796461957, 0.005515356548130512, 0.017302999206419502, 0.09440181550702878, 0.0321654741918402, 0.03546902371038284, 0.023040084035268853, 0.04309879715687462, 0.015321760072505899, 0.03658914592649255, 0.01539369665884546, 0.05175770466615047, 0.05937337476227965, 0.007782208034768701, 0.031394183436142545, 0.03945051792210766, 0.03911873126136405, 0.08577431059841599, 0.03555406450427004, 0.04883520005803023, 0.028031742166993872, 0.0627223929124219, 0.020982022862881422, 0.047626607053514035, 0.07379031008375542, 0.04984000864039574, 0.05021189672074147, 0.06544686707534961, 0.04190599026956728, 0.0154811547337366, 0.03590501977929047, 0.042994424900306125, 0.051005236471870115, 0.03671231021040252, 0.03250364925978439, 0.08880482441080467, 0.031100581333573376, 0.05305364548361727, 0.018057760849062885, 0.030167215703321353, 0.009797319636813231, 0.01307246313496892, 0.056652724144182036, 0.03531083005613514, 0.03258499203781996, 0.05590262742979186, 0.0404277508413153, 0.05616113230852144, 0.10642874693231923, 0.03082449221983552, 0.03993151104077697, 0.03523937353332128, 0.02448619483038783, 0.026531114475801587, 0.0367407849324601, 0.01603491564414331, 0.027089553885161877, 0.0161928582404341, 0.012842455878853798, 0.054500095546245575, 0.02892248731638704, 0.01903801324910351, 0.04390654220644917, 0.03971624919878585, 0.00998973605289523, 0.11861624009907246, 0.01582749936330531, 0.019425383802237253, 0.036984385789505074, 0.044306796443249495, 0.045927083784980435, 0.025186675367876887, 0.009437752056068607, 0.08281650859862566, 0.01990487226950271, 0.023173170197489004, 0.029373665606336932, 0.05247333858694349, 0.047732706181705, 0.004943210731393525, 0.020024618433256234, 0.030859793004180704, 0.04150106092648847, 0.06958236838025705, 0.033014131510364156, 0.028471777215600014, 0.00798806538140135, 0.036903752080563984, 0.016192559685025896, 0.08956466828073774, 0.06822464016399213, 0.016475188180005977, 0.02194292174785265, 0.018677668745762536, 0.06077303644269705, 0.0512457160678293, 0.08252986147999763, 0.03172999041687165, 0.02649702487646469, 0.06672141368367843, 0.09925652321960245, 0.056307115725108554, 0.039454684127122164, 0.02302671011005129, 0.020153463751609837, 0.0042965308114487144, 0.024191820894234946, 0.05693461812500443, 0.052349919852401526, 0.061873620242944787, 0.035274626820215156, 0.01998220829825316, 0.008868531573430767, 0.0815870099301849, 0.027806052938103676, 0.039750956264989715, 0.019409161726278917, 0.03410241686339889, 0.024904284360153333, 0.026881713519937227, 0.09268777498177119, 0.011400599498301744, 0.02937030346531953, 0.004978204902727157, 0.05027812173856156, 0.00981546111870557, 0.03752557174967868, 0.03912983209426914, 0.016335182656933154, 0.04007235455459782, 0.026234240138104985, 0.022351447326530303, 0.04140689383660044, 0.0672922312681164, 0.01951213280803391, 0.04131023991586907, 0.02384589865271534, 0.029944459442049265, 0.00515930208244494, 0.10783553323043243, 0.002300159498450479, 0.04965124359088285, 0.012115118077157863, 0.09835979169500725, 0.03242082727540817, 0.059874337166547775, 0.0013848414153991534, 0.016304780895422612, 0.013218627211504748, 0.00560345541452989, 0.024134684852989655, 0.04640703195972102, 0.010663151524827948, 0.023564318494339074, 0.027177856736151234, 0.0195204211132867, 0.0323869717706527, 0.00646294724096411, 0.01734204380773008, 0.009433355149147766, 0.02661132240401847, 0.029899235083056346, 0.041516897933823724, 0.019844565773382783, 0.02340529702736863, 0.014706344077629703, 0.035303138861698766, 0.018934355150642138, 0.009896026125976017, 0.034420212132057974, 0.022041858938921775, 0.06468143886221306, 0.017354303239179508, 0.06373020740492003, 0.05177270368273769, 0.056491704391581674, 0.07040140085986682, 0.03372422180005482, 0.012701540270687213, 0.03892013763210603, 0.03192221599497965, 0.04211708929921899, 0.045491365915430446, 0.018723966886422465, 0.0032255657008915606, 0.043140734013702185, 0.0017281647617762375, 0.03492897429636546, 0.03590017843193241, 0.0412773886429412, 0.04525569713275347, 0.0354611085993903, 0.04443795386967914, 0.03811920168144362, 0.01426368479483894, 0.04413699984018292, 0.03531914211011358, 0.024088459654844234, 0.02384063322097063, 0.030344055499881506, 0.053449048195034266, 0.015815433314336196, 0.012370534773383821, 0.07122752403042146, 0.07833850317235504, 0.0746173153498343, 0.03519954013505152, 0.0945409694686532, 0.023385997795100723, 0.011779111776767033, 0.04163867122094546, 0.1296774058469704, 0.1357983345431941, 0.11111043500048773, 0.16309419700077601, 0.0761593065357634, 0.08255907919790063, 0.09098093371306147, 0.08392918389290571, 0.17647823239011423, 0.1421140299311706, 0.14099477284720965, 0.08889324430908475, 0.10174773061381918, 0.12561238397444996, 0.1410720172737326, 0.07422003988176584, 0.18375967309943267, 0.1286492081625121, 0.12386381280209337, 0.1592148087386574, 0.07370902158852134, 0.09941018425992557, 0.1671280741159405, 0.08844097357775484, 0.125632251479796, 0.13743245042860508, 0.17294341778116568, 0.158003515164767, 0.06497074583811419, 0.09646503693823304, 0.24686642895851815, 0.10146520898810454, 0.103433544082301, 0.09998900855758361, 0.1273560154118708, 0.21552542570446218, 0.1930941300732749, 0.15058420971035957, 0.18679542520216533, 0.13742481012429508, 0.1219071756516184, 0.05110641282850078, 0.10686621881489243, 0.1979632159428937, 0.1505813327218805, 0.14129419678023883, 0.12499559564249856, 0.0952856345102191, 0.13789434278649942, 0.14174918165164335, 0.13538459103022302, 0.16113396361470222, 0.11137724175517048, 0.12337886382426534, 0.14996096172503062, 0.13546777942350932, 0.11175530111151082, 0.08586277120879718, 0.08907963109335729, 0.11595517503363745, 0.08702474885753222, 0.19750798679888248, 0.128123832068273, 0.1131527643384678, 0.16915177766765865, 0.18874915822276048, 0.14706004810120377, 0.15464023420853273, 0.15179991376187119, 0.11412747310740606, 0.092195979585605, 0.20241945396576608, 0.15896292296903475, 0.09933169811431851, 0.20995979649680002, 0.1103644332449351, 0.12372457741626672, 0.07210590796811239, 0.15098017560584204, 0.1801307185419968, 0.10354694085461752, 0.09534497918295008, 0.13532091730407306, 0.09849503729492426, 0.1417216874126877, 0.18983918401811803, 0.10241945314088038, 0.09273356931017977, 0.2004279808274337, 0.14979090727865696, 0.11956076084503106, 0.10848044683890683, 0.10421452431806497, 0.12172616965004376, 0.16386037160243305, 0.11525248416832515, 0.10290729267788784, 0.16636164167097636, 0.19324245782835142, 0.10655782464891672, 0.1293234276984419, 0.13425948497440132, 0.10962932876178197, 0.07443812782210962, 0.2794090770184994, 0.07262556401214429, 0.1021379561030439, 0.15806733816862106, 0.13368895916002138, 0.1030034071632794, 0.10282422642090491, 0.18908553517290524, 0.11236988420465163, 0.16149258294275828, 0.11179121597004787, 0.1237854827195406, 0.13691548816859722, 0.11978496238589287, 0.12997658550739288, 0.12098822210516248, 0.10444198961236648, 0.09772898482957057, 0.10089139906423432, 0.09157189021685294, 0.07015773893467017, 0.14702557852225645, 0.11841683222779206, 0.1749818862548896, 0.0880981030474816, 0.07397993348006691, 0.20383179746568203, 0.11255933796720845, 0.17050431509103092, 0.16688412720603601, 0.15306692863149302, 0.1262968493891614, 0.21089800686708518, 0.1253272228475128, 0.1520189041537898, 0.1927254412855421, 0.12354222791535513, 0.0995006397632616, 0.1632570182638509, 0.1127324118944151, 0.1301073663468872, 0.17920206194477423, 0.13318714180162974, 0.1187418776431254, 0.12912967880921705, 0.10902036393859557, 0.12124834528991155, 0.10643692327929394, 0.19027192651161126, 0.16430950750197681, 0.09537685675812618, 0.058597110344895294, 0.1363429810319628, 0.07752924159701381, 0.13560240077120916, 0.09041403806103127, 0.12566239200532436, 0.14808812364935875, 0.15438340870397432, 0.09589575284293719, 0.18015499652496406, 0.15745592383401735, 0.14014657693249838, 0.08683190920523234, 0.18377333879470825, 0.18221454029636724, 0.17054206877946854, 0.0859952958832894, 0.20769359810011728, 0.178394401712077, 0.19744039114032472, 0.09793350206954138], [0.045295808730380874, 0.0308261580233063, 0.04286752528111849, 0.04930313816294074, 0.008152881537431052, 0.05929830164781638, 0.026781068116958653, 0.013061387747127031, 0.031207118116851364, 0.0738896204690848, 0.049969788640737534, 0.011371526817258979, 0.05361663955929024, 0.03601865403886352, 0.016139727252136384, 0.02170182977403913, 0.02498416319888617, 0.02288169869487839, 0.01144909015524068, 0.010185095614620616, 0.06333185985152211, 0.03184686468115874, 0.032085651332246404, 0.034994754873748334, 0.061396576198084016, 0.042442697898617814, 0.0946688868903688, 0.06297787491764341, 0.02432268315793148, 0.024267728606771146, 0.05389364469530327, 0.042623673366116624, 0.09598975029907056, 0.03390679182484746, 0.06776175714497056, 0.050270966586789916, 0.03522589782785092, 0.03621508992676224, 0.020759461680427194, 0.021465141492496644, 0.03709924480478678, 0.024670422176963518, 0.010153520835696586, 0.022238388125385557, 0.031198361622435705, 0.021125716223780597, 0.03758041434256094, 0.022477234148287346, 0.05321329120280487, 0.008355620167484241, 0.04175976936572364, 0.019596983612115895, 0.03814275023926582, 0.03123527392745018, 0.02781779837927648, 0.010618831313747381, 0.0953603344304221, 0.02791994164830872, 0.02365409885533154, 0.028906494245997498, 0.01838957974021988, 0.020783341024070978, 0.05220120193968926, 0.057166059634515216, 0.004432544428189951, 0.013827225625781077, 0.0379509826722954, 0.06313226877578668, 0.03874105866998434, 0.0652217562975628, 0.033719241353017945, 0.015344063518568873, 0.06550861376204661, 0.041099025535264185, 0.013962685812397726, 0.027697573848334805, 0.03515666011454804, 0.020532607067642466, 0.02393251025517072, 0.049578036447720866, 0.013581672284219946, 0.029699718646172966, 0.07006200442888907, 0.06182253334139075, 0.050899259479982514, 0.028839353205902234, 0.02418891167534249, 0.02583883233767535, 0.11895135497408253, 0.02635123484235789, 0.01284569503539907, 0.046083380933851004, 0.03517595086512821, 0.022218410358099, 0.027556845685467124, 0.035053312445857694, 0.03772591260660972, 0.07042739553643124, 0.02930773575124996, 0.00658454665348732, 0.08229767358196632, 0.011467598894211863, 0.031370556846793206, 0.04554302617907524, 0.02523748407007328, 0.05034856724419764, 0.07070919112967593, 0.04319054526942117, 0.008163855993188918, 0.08047949828739677, 0.04873829847201705, 0.0506410701200366, 0.036239507009408305, 0.03101982209565384, 0.03939561426107373, 0.07022937866193907, 0.05571564014202782, 0.02639899352964546, 0.016707454109564424, 0.04208222616996084, 0.04608298399086509, 0.03988573706841894, 0.0052136260201223195, 0.05704760777630976, 0.039238017717642446, 0.04645811886127506, 0.040204655312533887, 0.021332484503675784, 0.006626300729944238, 0.002330215843228091, 0.0352345932541149, 0.032750412090016265, 0.05435791192576289, 0.04072701192594, 0.0031939648407777505, 0.060389060260994096, 0.021159454681245343, 0.020762852659182887, 0.005606664885168097, 0.013143178358274912, 0.019258221611380577, 0.015168387409565704, 0.04944542017100113, 0.05865365945334945, 0.11528457887470722, 0.023783514143100808, 0.009704222935917122, 0.04617986182815262, 0.010113297279791107, 0.05447290325537324, 0.04264228218900306, 0.024251930615199462, 0.06710781223539795, 0.03305792755314282, 0.021198628204209462, 0.031612597073295286, 0.029422767792961428, 0.03138011401253087, 0.027912604988419583, 0.06341844091990165, 0.00683695192648364, 0.022256245470738838, 0.02382497432907777, 0.040028711182198355, 0.021009471300723295, 0.00791934335471264, 0.06373809198183672, 0.0028263279943660435, 0.03441807135407414, 0.06440205206828457, 0.06485880791608777, 0.012320564910104232, 0.023422976257279515, 0.05450131690927914, 0.010711026411237461, 0.04888891628278153, 0.04485634874020304, 0.024195055809936354, 0.03025726069297109, 0.054793504266334433, 0.045705959400428195, 0.04634260845237544, 0.01212192717607, 0.027741312215636884, 0.03744412719139031, 0.03901002655870148, 0.03130619101492422, 0.01712372007646731, 0.02151553119931902, 0.038319902161934545, 0.02363143578570868, 0.049384694679507186, 0.03563103751678552, 0.017870220555258647, 0.016090402845293283, 0.028750790815268244, 0.07116693085325615, 0.08769846627754824, 0.026178003155759404, 0.03050102779109563, 0.017551163211464882, 0.026738715657432164, 0.027020139752754142, 0.02806202009586351, 0.005178298518460776, 0.04458090762740799, 0.032494641707411835, 0.051168237546724935, 0.015448347565584948, 0.07233489318085567, 0.11139123993260519, 0.07243744017822401, 0.005969984764565847, 0.06235869135707617, 0.03298522252589464, 0.04342063988691994, 0.02364484024500208, 0.03555643937683531, 0.016139350665201033, 0.028315103479794095, 0.023768825556284616, 0.04748775503997292, 0.029239485306399207, 0.011335060649019266, 0.01827546372078359, 0.010516132494168622, 0.03542911906593612, 0.06544257873403174, 0.04106040671467781, 0.021459192436720644, 0.01909458780262087, 0.020925310906022787, 0.015117644864533628, 0.026535095780023506, 0.051989176709737094, 0.0468694128628288, 0.03690999460273555, 0.036600073732967885, 0.004978789291011968, 0.013537808387939419, 0.024921700657744492, 0.0322641738956528, 0.04236419478963528, 0.03532822769401329, 0.023452199064195156, 0.06959691617105689, 0.0308960403448769, 0.014337451729391302, 0.032490614602076154, 0.025139781812738096, 0.02293624951770263, 0.0387723560977195, 0.030013357887842824, 0.03624379535072616, 0.04712373118049332, 0.05360344544585262, 0.025417585923735584, 0.027432497357949615, 0.0928043405126248, 0.025970737848963057, 0.012798270526608186, 0.030298376522426094, 0.05052936289991651, 0.07451257668435574, 0.0953082772237914, 0.021328925587502972, 0.055000525300524065, 0.030122137229357446, 0.006154379200389875, 0.03823561793459313, 0.06248627629663263, 0.030364906881004572, 0.039660263274397166, 0.041904276968645196, 0.0034845436457544565, 0.024618758520643626, 0.02392513118684292, 0.037594819641006846, 0.047152114300323386, 0.0367959125100502, 0.033047858093466075, 0.05642959808132478, 0.06754406954028777, 0.0073510219309745085, 0.04523479486150401, 0.05151813091444118, 0.011089145987560707, 0.017810567149094174, 0.02447288197332195, 0.02640137349122337, 0.032213483937084675, 0.00913150969427079, 0.035640774494303126, 0.03275944339111447, 0.018506937460707765, 0.015605497972241469, 0.04503612320071884, 0.05331747346956815, 0.008688344902891134, 0.023418033129668663, 0.09099533901150737, 0.029082004113921096, 0.02245047272715185, 0.030568172223865986, 0.07914335427007504, 0.03981762233057192, 0.01884410829682435, 0.020039529240291034, 0.02684968666705702, 0.030317382288298438, 0.04558437271043658, 0.027423990225153308, 0.07052348966577224, 0.07601401183222022, 0.01116186797818435, 0.03641362588054367, 0.036855362355709076, 0.010438181543057519, 0.047582163009792566, 0.04305847521339144, 0.0662302357543792, 0.04700327764398285, 0.0233236319451992, 0.048897601531020234, 0.024817426788753698, 0.018064200146389858, 0.041211889657591066, 0.04423933649169547, 0.033019464795610735, 0.06851185725203582, 0.03510845698682325, 0.035725459057305536, 0.042407695669680834, 0.05381577601656318, 0.06173975885446582, 0.045528013591787646, 0.03637347017814006, 0.017225371407611028, 0.020431983717052, 0.04642788673351918, 0.08101699980241911, 0.0014721067439365599, 0.060467851747359545, 0.03354373487776943, 0.007120392967148551, 0.04181439822007503, 0.035015093960932324, 0.03291709761002234, 0.0133203760820574, 0.02579869529498475, 0.01510496813404773, 0.031692365650087595, 0.10223163464771849, 0.12529693304428033, 0.133211202653391, 0.09809020973209824, 0.13017900607415608, 0.1289453072739499, 0.17712360061705112, 0.20041685285312788, 0.0695298904819148, 0.14093365041272982, 0.11242620939654963, 0.09437686577439308, 0.06970974975930792, 0.08603518695703574, 0.17342300633234636, 0.17734142392873764, 0.1149209655289139, 0.10739884166313068, 0.1012389175593853, 0.052451632251696925, 0.1777403075248003, 0.18642128099288258, 0.10085070731916598, 0.06597725754337651, 0.1464405727705785, 0.17021641268261842, 0.11970204540661403, 0.23625997666801724, 0.0892501130167927, 0.1271921492048672, 0.09651388467422553, 0.16634239841784748, 0.16481435112655163, 0.16072989601109708, 0.15760632790625095, 0.2730136944779328, 0.14923369432134287, 0.11968361639550754, 0.04914261374090399, 0.18371248777423585, 0.09873929633093731, 0.15160722338727542, 0.08326325605490378, 0.18731837214103766, 0.10720429210258381, 0.0688242819160223, 0.13618098758161068, 0.13068663169230732, 0.09692793352795498, 0.0862138791541968, 0.1178818480776889, 0.157447469287685, 0.1330994072237185, 0.07797588048768894, 0.10333227951611791, 0.1379582065024546, 0.1354187891951629, 0.13821030940328324, 0.1620357230837856, 0.1293574630149773, 0.106530472902315, 0.10763050708919764, 0.11173510112400566, 0.07116809114813805, 0.11804433007325445, 0.11592207609542779, 0.07919792884162494, 0.12322771336351122, 0.12672524925853523, 0.2039111317800624, 0.1658776562128748, 0.12317162565886974, 0.2685444557241031, 0.16179347251142773, 0.1072809122768896, 0.11174310105187552, 0.0965912648077522, 0.10168664210609027, 0.11913842707872391, 0.13324069178530148, 0.10234937404415437, 0.16989205937300408, 0.33157647773623466, 0.18001943879893847, 0.16542263062936918, 0.0564024770366294, 0.1655476303505046, 0.09676287309931857, 0.19639882631599903, 0.11582283356360026, 0.07939367940915482, 0.14691039041749068, 0.10739008177603994, 0.14500464339341435, 0.10906033643654414, 0.12825097596006735, 0.15188592486083508, 0.16463065812630312, 0.12856779753097466, 0.11437755397387914, 0.20908848967935356, 0.06285571825823613, 0.14355894311198167, 0.1448834434683834, 0.09036818266447101, 0.15085643795984133, 0.18135957260216984, 0.15704684864197457, 0.09088532134358372, 0.18364080733486585, 0.12926591507026128, 0.11168348496513707, 0.1357151868620089, 0.14835242660982267, 0.0610546013340354, 0.13293566315301827, 0.11428648100367614, 0.1360958314367703, 0.10153693692492587, 0.16046382885958466, 0.12884732681725705, 0.1482036238802331, 0.05327621854043432, 0.08764062116720847, 0.14089181194347994, 0.16203028123293603, 0.11768686425473009, 0.10047854443213769, 0.1398934426584414, 0.10411827412566968, 0.12673439591058663, 0.21969184785016946, 0.12488878065986292, 0.1827741688383477, 0.12085805194718496, 0.10404843930155039, 0.10908311485712018, 0.1725723948329687, 0.07641714305749961, 0.07956029368298394, 0.23193266029868806, 0.08279234596661159, 0.18945209336067947, 0.23412118000643595, 0.3643983022442886, 0.15443545233990463, 0.08313905021974019, 0.14666455718023436, 0.11205083025353295, 0.10294309897082192, 0.11401654620255743, 0.0909769032150507, 0.18447195844990866, 0.10779509932867118, 0.1824756134301424, 0.07241215796342917, 0.1120224471337029, 0.1613644483898367, 0.14839898768280232, 0.27080232171075685, 0.11632336170545646, 0.052811432230685434, 0.09236559298421655, 0.09783603729946272, 0.15238310103969915, 0.07912404316344432, 0.09637668489345483, 0.15019258643899644, 0.05798207263329199, 0.0901126531617982, 0.148314306512475, 0.14835634854223045, 0.1313319592071431, 0.1257490680686065, 0.1296779622456857, 0.1435400934091636], [0.020931641637746776, 0.0153819783590734, 0.012621904008223541, 0.030222947177078043, 0.016144582170194814, 0.04059021248083029, 0.01986341886887593, 0.051360609009861946, 0.03863137687689491, 0.02006553579121828, 0.048785697535744736, 0.016698387185377733, 0.050595896651170084, 0.06020736215370042, 0.04185293222378407, 0.061597693977611404, 0.1485101452895573, 0.0712264994425433, 0.039730752884809456, 0.012157876809526767, 0.038012970238924026, 0.02946592940549765, 0.05853363339390073, 0.02607678947970271, 0.037607721984386444, 0.004808300158141979, 0.015236598838652884, 0.02872648908357535, 0.05875005892344883, 0.012180868968633669, 0.03546947493617024, 0.04955725970544985, 0.0749669848009944, 0.04819355698834572, 0.05749819574079343, 0.057512261771730015, 0.05208593580339636, 0.06569402345589229, 0.032512639848781485, 0.05357140162959695, 0.055889901505517106, 0.032098302617669106, 0.05187809034915907, 0.014519290632701345, 0.029521372501871417, 0.016937039825799208, 0.053035158797034194, 0.019794729072600603, 0.06150301798645939, 0.008358523449195283, 0.011494037163044726, 0.02881786400186164, 0.04553627475563969, 0.04982906047786985, 0.033577848225831985, 0.034223168955317566, 0.04627894490425076, 0.03168394163783107, 0.06971591764262744, 0.044410113577864, 0.016467614032860314, 0.01988612943595009, 0.020553982617067437, 0.054997231013008525, 0.09062817692756653, 0.018605079069467526, 0.055124273124550066, 0.055780796467193534, 0.009940749217223908, 0.015180911469672407, 0.001091507334162348, 0.04660547970395003, 0.060998995389257155, 0.04503230983391404, 0.026274668950853602, 0.05602087912016681, 0.059435230014579635, 0.02422285538965038, 0.012851226792138602, 0.015001652695770775, 0.02918743488511869, 0.041091073104845624, 0.029248055203684738, 0.014598188988332237, 0.04733284210254039, 0.017091191107673303, 0.015381618735513516, 0.01917706203780004, 0.03849986321958048, 0.038789777484323294, 0.009949321659015757, 0.05936110684914248, 0.01579188645285155, 0.04965961332033787, 0.03216128084542496, 0.04035635877932821, 0.060216481664351056, 0.10938169740672622, 0.04936240141146949, 0.016392593504860997, 0.05137113308800118, 0.016263858448447924, 0.0575857674703002, 0.01136714093653219, 0.09316411335021257, 0.04730917140841484, 0.04689808775271688, 0.02273262964029397, 0.017822906308408295, 0.007573498296551406, 0.06114543003163167, 0.06769051096801247, 0.08993487698691231, 0.01971602240311248, 0.023589244478249123, 0.03176805283874273, 0.026266387430951, 0.03779152694291302, 0.0663907364276903, 0.00821720835353647, 0.010223562612996569, 0.02967561368963548, 0.038462754139410596, 0.015099780733830162, 0.021244147725935494, 0.03434164795492377, 0.06525492308927433, 0.01999923783088369, 0.035622586363128254, 0.08907163795083761, 0.019637078246367828, 0.012122185019377087, 0.031176855455019643, 0.07379108361367669, 0.02491980924138001, 0.06555498484522104, 0.019529236979516487, 0.028893883672675917, 0.0354331970613982, 0.009368102980910667, 0.049357770409967215, 0.06187493660088096, 0.050047090742737055, 0.013000779302923806, 0.030436278586941104, 0.04050961269864014, 0.0014379856563339541, 0.04496946392048683, 0.030483633545892577, 0.04356069630011916, 0.12530545544411453, 0.07913112028368882, 0.05847380017595632, 0.026416883105412126, 0.01988352555781603, 0.04218298522755504, 0.020289700012654066, 0.035973080234336, 0.020166632419984256, 0.060973876022866795, 0.04102473612874746, 0.013889523622180735, 0.07185155911637203, 0.059889509209564755, 0.05948565873716559, 0.042649593403829, 0.01577430561051837, 0.039437269525868554, 0.0406154098787478, 0.04192600705261741, 0.041278355555342774, 0.049586901507739506, 0.03924146806821227, 0.05540413489299161, 0.004568651767580637, 0.027158621964710097, 0.046223708761057684, 0.011220819100604525, 0.013559405309414225, 0.0506588918423014, 0.015296109752463443, 0.04342762879761202, 0.05237956165469118, 0.06976820555116449, 0.02812562257583652, 0.028581811846899133, 0.056649915009204826, 0.031469069953475676, 0.0659343944862485, 0.014240908070600458, 0.07737826077001435, 0.025765472524134175, 0.01956538253995989, 0.08701476760740791, 0.0380235757412655, 0.014149660377630165, 0.04976682185328432, 0.0057402192365511185, 0.02249364451771336, 0.03163370629772544, 0.04920490325561591, 0.05518346173422677, 0.020513214536809495, 0.016408057317935994, 0.020611356145569255, 0.02212248246983758, 0.029020637406834533, 0.03674611482503159, 0.028314041572489908, 0.008091170473822525, 0.03490704404456275, 0.03924657743690269, 0.02749538398347795, 0.03908919802467738, 0.0076644338634131205, 0.04751064202615193, 0.03565236387242164, 0.04348690561684115, 0.05694194630320583, 0.016826167203752056, 0.01738616045830505, 0.07468366928930793, 0.054506643409175534, 0.02191415016672441, 0.011422438147876943, 0.032008352622921975, 0.01330125326889434, 0.027667855710855553, 0.03102040902844497, 0.026191833395777003, 0.0302430996671319, 0.019394980344389166, 0.01049731926260782, 0.030241522073213543, 0.030002684531999484, 0.018819723444591676, 0.030119382377181734, 0.01562499737233988, 0.049530871478574615, 0.0676953149959445, 0.06474372159157481, 0.02978522762922304, 0.05210153193079999, 0.0516733491926321, 0.028333858187709535, 0.011395839575145925, 0.02725282298134906, 0.10062985774129629, 0.009367999504320323, 0.00814307076923017, 0.041237948794982264, 0.08926041996372597, 0.015576037678069301, 0.02892764757520386, 0.02805235266818532, 0.04525134772328394, 0.03274169291502663, 0.05582730665004679, 0.026159808239234344, 0.035164266492107084, 0.021590383789901222, 0.10081031412950583, 0.062492539174854755, 0.025209246835272228, 0.022255312485088195, 0.03041799206818853, 0.028149052390030453, 0.032973293880266805, 0.05472915539784091, 0.03123454110963004, 0.06232762123857226, 0.0293105788129781, 0.02064704199853752, 0.048617325856217315, 0.03404393393014159, 0.022428569616749883, 0.023257009984393204, 0.05513287694858653, 0.03181135355095778, 0.008750789632488574, 0.05147667242480176, 0.043331795904253206, 0.011321489948646297, 0.023752849449270537, 0.026272127837208763, 0.024234212369525006, 0.05048075604385563, 0.007364830118604004, 0.03534795609968049, 0.026740417083991424, 0.0361526036368949, 0.03073634034288781, 0.09284961915441922, 0.02227484411559999, 0.055735392296420674, 0.025669602311349342, 0.025704818278817192, 0.04469179042748042, 0.06534759061677115, 0.024348319907273566, 0.024636927992105484, 0.05273735656269959, 0.07318411368344512, 0.01912631101108023, 0.030558370785521607, 0.07144562554146562, 0.010164168746476727, 0.010719458905181714, 0.02334099735266396, 0.04707459506711789, 0.02895420543583376, 0.06734492629766464, 0.013821318978443742, 0.0967423745564052, 0.010830249254857855, 0.0828093093420778, 0.049299667456320355, 0.020785500461767827, 0.020481662658442343, 0.039573553284364085, 0.032354894027646096, 0.016320341399737766, 0.015691834768014293, 0.0742810130385416, 0.0791065776720643, 0.06071907255266394, 0.04134487234322088, 0.0017820829567166843, 0.015290705221039909, 0.013960121798196008, 0.03493649924972227, 0.051567416305520704, 0.04830049071460962, 0.01673709082284144, 0.04813818513814892, 0.03155926422082952, 0.031276142091623375, 0.02652018327665116, 0.06188368291727134, 0.04661558309037771, 0.030724812032920972, 0.04625404266906636, 0.05459625752908843, 0.00818316709981965, 0.057935443706810474, 0.015780573577753136, 0.014921190316921898, 0.10033580780561481, 0.013547846465371549, 0.0429729967644172, 0.041425153213952265, 0.05701863433101347, 0.18181884581489222, 0.0894121200378452, 0.05388754127281053, 0.13768181204795837, 0.13490042915301664, 0.14813771098852158, 0.1268116674785103, 0.16253451417599404, 0.10707022036824908, 0.11943916736968926, 0.24068025233490126, 0.10632166053567614, 0.22516419206346783, 0.17788407552455152, 0.18748089484870434, 0.09944742904709918, 0.2168236667556422, 0.17547683683889254, 0.12940992734261922, 0.07862404427890267, 0.0925148706883192, 0.09791216892855507, 0.11603967978485993, 0.05884653303240027, 0.12418135362012045, 0.10852048719035727, 0.09275952327464308, 0.14113353325852326, 0.13963171813104833, 0.08695992162185055, 0.11985510933612074, 0.17205474046724184, 0.11332615039178304, 0.131835242201175, 0.13071317598223686, 0.09582982638052531, 0.09838980329888207, 0.22291825472244195, 0.08064640433128391, 0.1657554656267166, 0.11514455638825893, 0.1143679323473147, 0.16472112041498932, 0.10261057609958307, 0.12821004672774247, 0.22376011312007904, 0.11305800692311355, 0.10218757736895766, 0.10937241504767112, 0.07360283764345305, 0.10831601744783775, 0.17242739189948353, 0.14658096166593687, 0.21099205182066985, 0.1137828655274851, 0.06882993411272764, 0.16404396960777895, 0.08704159688204527, 0.2245587216956275, 0.11373844862516437, 0.0933163630376969, 0.115325250263725, 0.11467480659484863, 0.10493711661547422, 0.18833947234920093, 0.09129046781786851, 0.37413451980267254, 0.15819370853049414, 0.10725842562637158, 0.08086477725633553, 0.07909870666584798, 0.19516377044575556, 0.12207319959998131, 0.1815142243036202, 0.116642883845738, 0.1857044223163809, 0.1434900989489896, 0.13104868440755776, 0.16037055743592127, 0.08890380231397492, 0.12211935355194978, 0.19894239625760488, 0.13904041557439736, 0.1299663939114128, 0.15524326185030596, 0.20757919709597314, 0.16386343858071736, 0.12609334316636833, 0.08944945981992142, 0.11579235377056257, 0.12143092549272946, 0.17871146755559103, 0.1435369314359767, 0.13500404145036424, 0.12210652924009732, 0.2146473063954285, 0.18678444650556358, 0.20499484719974653, 0.1560239435306617, 0.08665177851383175, 0.07706911343016795, 0.13831670369420732, 0.10142856809709754, 0.11635871337992804, 0.17779556741671904, 0.13508376931505545, 0.1162131947598287, 0.10934032034128904, 0.1530451476573944, 0.1566965345825468, 0.09916355035134725, 0.18303069578749792, 0.14929108481322015, 0.07188427128962108, 0.14759564293282373, 0.09788431506603956, 0.23523175184215817, 0.12785874200718744, 0.1178995171295745, 0.13183950340109213, 0.13446556963026524, 0.15129098535648414, 0.21132282407156058, 0.1042579777006592, 0.09049918063517128, 0.07614963062639747, 0.1565684543124267, 0.1178171836904117, 0.07335106043943337, 0.14177788368293218, 0.1353402826935053, 0.09182029510182993, 0.1682306392384427, 0.22550658083387784, 0.10639531551195042, 0.15781438031366893, 0.08420245708631617, 0.2025020181068352, 0.1321981227291482, 0.10492123211068766, 0.15725252617682728, 0.1076867983543447, 0.1111213458435876, 0.09198948102337973, 0.09645563244287457, 0.11029575871569769, 0.08668596989342145, 0.20919292978942394, 0.12572017604751246, 0.15510693059435912, 0.16660831629165582, 0.11920391927872385, 0.0954438688765679, 0.15483371168375015, 0.10175634122320584, 0.15995456118668827, 0.14403300838811056, 0.09575942158699036, 0.13644603693059512, 0.14693831891885825, 0.09067042251782757, 0.12236160412430763, 0.21026695572904178, 0.11965319088527135, 0.15286097968263285, 0.1466305490050997, 0.12717296023453983, 0.12035816162824631, 0.14718787052801677, 0.13267339579761028, 0.11052168373550687, 0.1884053988116128, 0.11673980578780174, 0.13437337029193128, 0.09403868392109871, 0.13723586526300224], [0.03283241983237011, 0.04624437015237553, 0.05268258521599429, 0.011341786627391619, 0.06094552682978766, 0.018299963923969438, 0.05130936943792871, 0.0039433991353559706, 0.03652932627924851, 0.021473453546475087, 0.033675428346863816, 0.023919911556211964, 0.0429808813413339, 0.024683906364121606, 0.046303365379571915, 0.049373953470161984, 0.013063604860300464, 0.026511255452143292, 0.02417490671255759, 0.014876371382602623, 0.015234637872448989, 0.07057926524430513, 0.03140184409650309, 0.03510816182409014, 0.03207640629261732, 0.06433569812881094, 0.038015901510204585, 0.0037165199256768183, 0.03924209910577961, 0.04498459185872759, 0.0556954672959234, 0.05157659688432302, 0.021901285142770836, 0.017441237145768743, 0.018589043590639318, 0.03531820233911276, 0.048612219880201986, 0.021767433932317153, 0.03476927429437637, 0.04462576557749084, 0.010686445632018149, 0.00791412711675678, 0.037675802795482535, 0.04138270406318562, 0.06586932297796011, 0.02200688554772309, 0.04656694909291608, 0.021414139407819936, 0.036485245251762013, 0.031789175633873255, 0.02302513421247048, 0.015870834002271295, 0.07074282611055033, 0.05245015983070646, 0.04219596560246178, 0.03797195279704673, 0.05180753627792001, 0.039936705226344724, 0.03166280866467527, 0.04368008792932544, 0.04046427298869405, 0.010159765902374471, 0.04847225506923028, 0.07328811274575335, 0.031292647455952, 0.03609477548993059, 0.02034874104096421, 0.04011575026171548, 0.02186600471447621, 0.014218573242292872, 0.03725389311356204, 0.02501788130030036, 0.015503139268340809, 0.026061921081106578, 0.026642633402454, 0.010365875155132796, 0.015502399665170481, 0.05654508813417383, 0.028292080786611353, 0.06161348348749535, 0.06214963471783059, 0.04902895912528038, 0.019907649174066525, 0.04076619053791676, 0.02333655464462936, 0.058813257675085745, 0.036194550671747754, 0.06755206268280745, 0.11173478899789707, 0.06767029062445674, 0.03518586426175066, 0.03035230648570827, 0.03083717743200915, 0.07509588609848704, 0.040486878382840326, 0.030859932103859525, 0.06673591397702694, 0.037422071410609145, 0.03166747698560357, 0.02941428610522832, 0.03982437036133238, 0.05141390115022659, 0.041654531977006366, 0.027317178635192767, 0.02260552646060075, 0.13461974635720253, 0.049746930599212646, 0.07812996900507382, 0.017977751392338957, 0.007227984872380537, 0.07627642846533231, 0.026488100444631915, 0.02766081760637462, 0.01872913901960211, 0.04348597941654069, 0.017508030436666946, 0.05253861704841256, 0.02093597747651594, 0.0297797756003482, 0.0415964290233595, 0.0483447820879519, 0.022010722663253546, 0.0735010981027569, 0.024123524648270438, 0.008445191030789698, 0.046921015450997014, 0.0826689883002213, 0.0194435600590493, 0.024925480097798363, 0.03141528248254742, 0.06863980181515217, 0.030829360708594322, 0.02632919093593955, 0.0012522398756118491, 0.04699018870347312, 0.022486616591257707, 0.034340216246034415, 0.042038823677492995, 0.02032633581464844, 0.058099622039922645, 0.02714915300852486, 0.032232635587986024, 0.03285750187933445, 0.04828931524285248, 0.025834367577252642, 0.0257638287730515, 0.02982147836259433, 0.0167658776710076, 0.01691616469595049, 0.046453772844480615, 0.0459798127412796, 0.04820768748010908, 0.040257336771381755, 0.050328336722616634, 0.05676888933937464, 0.08534050280494349, 0.02181699243374169, 0.06376409344375134, 0.08997406238423926, 0.046896272671542, 0.03748205390625766, 0.012296541377768984, 0.010650390825633491, 0.050719142359282286, 0.014627136988565326, 0.04911082437528031, 0.0154092639485108, 0.008270311352264668, 0.05302052618935704, 0.02907010939504419, 0.07275231435362782, 0.041590569873473475, 0.04917392134666443, 0.03649698051490954, 0.052073250591222725, 0.04015489494694131, 0.011813825628321086, 0.051548434288374016, 0.05315535788291267, 0.019723415042140653, 0.010890688065306416, 0.012271117518789001, 0.11014857089945249, 0.011971133794369442, 0.002758239973835381, 0.023148315459755913, 0.05404024218608226, 0.0432965052979333, 0.024832485177155052, 0.013054569318358387, 0.016493427201307247, 0.021683168364688754, 0.03085348941385746, 0.018165866744571497, 0.017483129897820096, 0.024109886094395603, 0.05135923158377409, 0.013592376174139125, 0.02565166523813137, 0.02239603895161833, 0.030794538291437284, 0.035062537129436216, 0.06635973416268826, 0.020406808371522596, 0.00696595076338521, 0.05029409784557564, 0.03518044615962675, 0.032271478325128555, 0.022895771511165158, 0.01137133767562253, 0.033699801324733665, 0.01697575194495065, 0.04286989676100867, 0.022407512978783677, 0.034107811216797145, 0.07801934065563337, 0.009114635376525777, 0.007765431256432618, 0.026210988439353447, 0.0881510152082358, 0.006330274985105331, 0.03900777042976447, 0.010819158599978047, 0.04815933846735528, 0.04062338945056711, 0.0468404462028827, 0.03586123730721218, 0.07500365961875234, 0.044194624426641634, 0.02896907553076744, 0.035971624776721, 0.04561085932488952, 0.02268126793205738, 0.08385334403387137, 0.0173972816472607, 0.03557592011722071, 0.04766573816803949, 0.08963207394949027, 0.01925689846809421, 0.023125950945541263, 0.035052359104156494, 0.041429641723100624, 0.027738894934632947, 0.018350446929356883, 0.01788998967302697, 0.02271056198514998, 0.04557581638385143, 0.022134904749691486, 0.03170015183942659, 0.02747331463199641, 0.03197378126372184, 0.022268113048214997, 0.0341777681772198, 0.03992997755163482, 0.013326231839268335, 0.027474040664466362, 0.011260597367904015, 0.0020747917255253662, 0.054832811799964735, 0.03359091681029115, 0.04176770144009164, 0.02937446627765894, 0.04554882426080959, 0.037473161704838276, 0.03200155370203512, 0.031168651966644183, 0.03595937043428421, 0.020622482423537543, 0.02757594474990453, 0.06678565737924405, 0.034774885778980594, 0.013434141807790314, 0.07413318061402865, 0.027101036394014955, 0.07505503150501422, 0.010023436342765178, 0.03061695210635662, 0.03713071865162679, 0.07124322533075299, 0.014072574558667839, 0.07329253000872475, 0.09251547458448581, 0.05239085587007659, 0.03836802386545709, 0.049448951945773194, 0.007556590052055461, 0.04728433024138212, 0.020227206937436546, 0.025417416289980923, 0.028146129600437622, 0.031565472816250155, 0.04099476523697376, 0.003315387198069532, 0.029680872336030006, 0.030117974417018037, 0.022833088446142416, 0.0690137492492795, 0.0603943799755403, 0.0755454223336918, 0.004194604249538055, 0.030956999930952276, 0.03276305998276387, 0.05858792976609298, 0.05704922268965414, 0.06327542609402112, 0.024080756586045027, 0.06136883768652167, 0.02011155573252056, 0.031414692157081196, 0.0195806902899806, 0.03521525500608342, 0.049991810494767766, 0.022663337644189596, 0.09916448672967297, 0.06698973357145276, 0.003536784480924585, 0.04045373873252954, 0.01722415004457746, 0.016805365016417842, 0.027786258375272155, 0.020102431132857288, 0.03949567103492362, 0.033802467065730264, 0.013014763909658151, 0.012111347118791724, 0.026114144528816854, 0.04917986531342779, 0.05287113991965141, 0.02225017427865948, 0.1082896902891142, 0.03135521856269666, 0.013527906865679791, 0.04594665952026844, 0.009567898465320468, 0.03520078185413565, 0.06927823541419846, 0.02943895085315619, 0.04053649964875408, 0.031911417110157866, 0.020368136964472275, 0.03285420759181891, 0.027385140702660595, 0.019231419478143965, 0.03591279239792909, 0.017278020636045506, 0.05200361254225884, 0.020096985889332633, 0.06704320891627244, 0.009997812315954693, 0.028292896724971275, 0.021223516868693486, 0.04513190181127616, 0.12895971935774597, 0.13650015688368253, 0.2390493798468794, 0.06354793254286051, 0.10788584660206522, 0.14561927398400648, 0.25187849572726656, 0.09801621548831463, 0.09342042995350701, 0.10523578058928251, 0.10598673565047127, 0.13980318393026078, 0.0950662437826395, 0.1022072888112494, 0.15498383077127592, 0.15544132622224943, 0.14337720429258688, 0.10453041629599673, 0.11811198001461369, 0.10046611367059605, 0.1250802632421255, 0.11031700364713158, 0.097547727770039, 0.10732309679899897, 0.07707851114017622, 0.10824017758880343, 0.1513534648610013, 0.13122092373669147, 0.10260616562196187, 0.11578836398465292, 0.15038439471806797, 0.1269852231655802, 0.048832519844706566, 0.10321128315159253, 0.1250090849186693, 0.13914822121816023, 0.11430225015750953, 0.14044940711132117, 0.17349601670035295, 0.1248203164764813, 0.0869985099083611, 0.12894089679632867, 0.1450032727526767, 0.16411987053496496, 0.10584667923727206, 0.13997900592429297, 0.11187242304107972, 0.11504618238125529, 0.10347913485020399, 0.10996452506099429, 0.11598162432866436, 0.07960065294589315, 0.1771781276911497, 0.20714540965855122, 0.1621852722018957, 0.1227532545370715, 0.12030689152223722, 0.1729031263717583, 0.12279018041278635, 0.12228668028754847, 0.12234027098332133, 0.14133972647999013, 0.08958487505359308, 0.1530899852514267, 0.18535338900983334, 0.10886744250144277, 0.18625141653631413, 0.1767596887158496, 0.1260090284049511, 0.10812342885349478, 0.1049413981714419, 0.09427491588784115, 0.08738914251859699, 0.1294192232723747, 0.12502151568021092, 0.05142283745642219, 0.09815150180033275, 0.07782082166522741, 0.10009898551340614, 0.09816868909235511, 0.1495544242539576, 0.13932550884783268, 0.09826253727078438, 0.14318189477281912, 0.14258278906345367, 0.1455401432301317, 0.14485478214919567, 0.11968546201075826, 0.14454820645706995, 0.20428321324288845, 0.1682492582393544, 0.12478953812803541, 0.20161400575722965, 0.25163666584662026, 0.12282125731664044, 0.15087635974798883, 0.14984909844185623, 0.15507204032370023, 0.1272442742649998, 0.1402723230421543, 0.17162634059786797, 0.11087393840508801, 0.15288624832672731, 0.20242056676319667, 0.25861208726252827, 0.19719610496291093, 0.11262361558952502, 0.15872017028076307, 0.14474492732967648, 0.07685550382094723, 0.10188782773911953, 0.11989782990089484, 0.10983261106801884, 0.12251556372003895, 0.09157425151871783, 0.15607613644429616, 0.10173048225364514, 0.09268793783017568, 0.08457356824406556, 0.09341882182551281, 0.18243601412645408, 0.13549767567643098, 0.20574933742838247, 0.13080378754862718, 0.12473194407565252, 0.11030588245817594, 0.1466559533561979, 0.12349135135965687, 0.13508653773793153, 0.08267829780067716, 0.11074961043362107, 0.1110414687011923, 0.07099120385412659, 0.133093422544854, 0.11195731455726282, 0.1841856709548405, 0.09326419048011303, 0.22285027908427374, 0.1391850249575717, 0.18725634046963283, 0.12659053291593278, 0.08107630376304899, 0.08621098180966717, 0.12036896390574318, 0.0895111725798675, 0.07787061935024601, 0.1561166721263102, 0.08709946913378579, 0.09297349250742368, 0.1114424421851124, 0.12072864174842834, 0.16762271257383482, 0.0822195199185184, 0.16161310433277062, 0.09075964987277985, 0.14194278126316412, 0.07724664533244711, 0.10764102438198668, 0.11278917134872504, 0.11458575565900121, 0.08241218315171343, 0.11079625971615314, 0.14817047065922193, 0.11261664024953331, 0.19322481591786655, 0.1260376354413373, 0.0956485014674919, 0.12913560920528003, 0.11012614531708614, 0.133750583710415, 0.16362036019563675, 0.15544364681201323, 0.18493708063449177, 0.09295180652822767, 0.15957013038652285, 0.11283842620572873], [0.012556588227328445, 0.05378767788144095, 0.03330948084060635, 0.010792836530267127, 0.03886074885459883, 0.012288444758658963, 0.014986687605934483, 0.10198369116655417, 0.04032939379768712, 0.026157721744052002, 0.04318813307742987, 0.046616997835891585, 0.03237640358773725, 0.03263697121292353, 0.05415194262085216, 0.03845212149566837, 0.06718289892056159, 0.021056556542004858, 0.01479192091418164, 0.06707227735647134, 0.04655392461323312, 0.028214054348479425, 0.06081982143223286, 0.015850069134363105, 0.020426889615399495, 0.0016835243669837447, 0.026801081507333686, 0.018032873880916407, 0.03777754572885377, 0.06536167021840811, 0.07276558649859258, 0.06941393563257796, 0.032484816520341804, 0.029685167462698052, 0.06826313345560006, 0.03150441823527217, 0.041432919047240696, 0.04738453629293612, 0.03951453430844205, 0.04486886092594691, 0.062200328069073815, 0.02283840816068862, 0.03587455016427806, 0.06907658837735653, 0.04050686463181462, 0.07401247601956129, 0.03333470198724951, 0.047356733320547004, 0.07639025271471057, 0.03355955152905413, 0.02862250359196748, 0.014070119110069104, 0.013750030393046992, 0.012766570218705704, 0.06864553543605975, 0.03912813236404743, 0.09462917223572731, 0.035167560779622624, 0.041011250245251825, 0.008586473896035125, 0.013058112967493278, 0.004987072083167732, 0.062347332680863995, 0.04911281248288495, 0.02632087209661092, 0.03211704036220908, 0.022744385259492055, 0.03099261623408113, 0.01808741282937782, 0.013521002771865045, 0.017880293407610486, 0.058138664944895675, 0.05801193495946271, 0.017813457708273615, 0.0076927414962223595, 0.021576280439538614, 0.09118245861360005, 0.0552104538572686, 0.03416772925161889, 0.05167883175558277, 0.01571104070171714, 0.027669165283441544, 0.03421119281223842, 0.05385139571236713, 0.00907322862518153, 0.09160420205444098, 0.05258903220029814, 0.020464236182825904, 0.039151436649262905, 0.040127692478043694, 0.0246999486283, 0.11688465944358281, 0.013856763951480389, 0.05262455011584929, 0.02871794972036566, 0.02751872898079455, 0.020591483551210592, 0.02414572292140552, 0.07781336456537247, 0.07060208437698227, 0.04842880507931113, 0.015052318905613251, 0.014212784490415027, 0.016593214257487228, 0.05108249107641833, 0.02124961162917316, 0.022037180439968194, 0.055188007918851714, 0.02025258923614664, 0.05495414403932435, 0.03583580920738833, 0.05460434905918581, 0.03597074268119676, 0.02727532489890499, 0.02854661623548184, 0.03366594242730311, 0.03760531657774534, 0.04684207129425236, 0.08095066621899605, 0.028062842819573622, 0.037347293458878994, 0.014449783201728548, 0.013378246637460376, 0.018614020464675765, 0.04224321199581027, 0.04238033713772893, 0.007071791200100311, 0.026458921742492487, 0.020779466589114497, 0.06367122235574893, 0.04461391157071505, 0.0020830327453690445, 0.01951876888051629, 0.03693240661440151, 0.021160893175484877, 0.04705977925498571, 0.05620773070092712, 0.06589966027864388, 0.030788577361298457, 0.03529782932517784, 0.04113664351669805, 0.057429948688617775, 0.013030010591527181, 0.05412990380344646, 0.028512380751115934, 0.052498417241232734, 0.03492783775020923, 0.008196796323837978, 0.06071704373295818, 0.0314761368956949, 0.023803720915956155, 0.05623556420739208, 0.060070840907948356, 0.007272529848186033, 0.02112900372594595, 0.020921723152111684, 0.11860580423048564, 0.012814841199932354, 0.02630240237340331, 0.02090068517385849, 0.031120126534785544, 0.026351825167824115, 0.029920086464179412, 0.015678353973531296, 0.04750846732141716, 0.03416990056367857, 0.01719397389596062, 0.05424739892727562, 0.03577651542478374, 0.021138384472578764, 0.04357496928423643, 0.10006906890443393, 0.06290529881204877, 0.05824259615370205, 0.06274988715137754, 0.09657932937677417, 0.02630888407916895, 0.030636565161070654, 0.05295544111036828, 0.02190716125603233, 0.020940954530877725, 0.07787274316485439, 0.009413524963227766, 0.04034898988902569, 0.039020306364234, 0.01863377431540617, 0.040674910614533086, 0.0050747133625139084, 0.022462118084409406, 0.032298114217285595, 0.049497426487505436, 0.038919496416513405, 0.03509120184129902, 0.05342357938310929, 0.025691954951201166, 0.024089718337303827, 0.05564395630998271, 0.013556731033271976, 0.038051782441990714, 0.037916679334427626, 0.02259715673114572, 0.05645037482359579, 0.06232333968260458, 0.036463382853461165, 0.007432368949853948, 0.059131646661886146, 0.059497451675789695, 0.042023441288620234, 0.02907737989776901, 0.024309141295296804, 0.03940805520064064, 0.059836447771106444, 0.03771030290850571, 0.04260977357625961, 0.012427671662797886, 0.01577669066110892, 0.034549483231135776, 0.03837834777576583, 0.042911080443965535, 0.03297593677416444, 0.0720005789771676, 0.037315867109490294, 0.030185780421431576, 0.03686672442459634, 0.06181158857153995, 0.07273634163928883, 0.047907038791371245, 0.05216915812343359, 0.008813040131436927, 0.001530061904174675, 0.023133430097784315, 0.026764308301998035, 0.08415808768144675, 0.054185282438993454, 0.007333341852894851, 0.03982201923749276, 0.047801601234823465, 0.009287973932389702, 0.051491854645844014, 0.03330029347645385, 0.016954929401565875, 0.04774805125115173, 0.01694729588260608, 0.016972282934667807, 0.015656389794977646, 0.022978021829788173, 0.01739345131708043, 0.05831572187266179, 0.031026899215898344, 0.0910727937838861, 0.02747111957121108, 0.05591033219492861, 0.08972171521080391, 0.016929301133911525, 0.055311087385884354, 0.04707580285945109, 0.05216496477701834, 0.06257116781281573, 0.0511464158605252, 0.014835048599966934, 0.08198057381170136, 0.055196465857859166, 0.03265488453741584, 0.03334724809974432, 0.046849104309720654, 0.04958252156419413, 0.036912603569882255, 0.026367078635043333, 0.07626319024711847, 0.02357495453075639, 0.05645998627213495, 0.07991813269576856, 0.009765793203509279, 0.02329588495194912, 0.047895924387765784, 0.024346179129289727, 0.05157074112711208, 0.04478477347376091, 0.02944645545046244, 0.09346584430230515, 0.01809105825876551, 0.018132377648726106, 0.011659715906716883, 0.036099871287920644, 0.011146981768043978, 0.03088175379005926, 0.024268853278564553, 0.03176505371396031, 0.014569254558799523, 0.02709258015134505, 0.05598770554310509, 0.008401264370019947, 0.02387213081653629, 0.010177434106091303, 0.058549205772578716, 0.029145175724157264, 0.012918516261769193, 0.07917890950505223, 0.026437033899128437, 0.030526289649839913, 0.02510421639973564, 0.05183342917423163, 0.0043924570033725885, 0.05796882762972798, 0.03314307012728282, 0.01494094925666494, 0.04606925383476274, 0.018981643952429295, 0.019942707382142544, 0.003797630305468504, 0.05787497266594853, 0.005880894812954856, 0.04610474121623805, 0.028097624524629543, 0.026434599654749036, 0.056764014065265656, 0.06227707716503313, 0.03930487377302987, 0.06173687508063657, 0.03349331633320876, 0.025683585221746137, 0.011029808100179901, 0.07016186442758356, 0.02372521271796099, 0.02962564637086221, 0.01674591008174632, 0.026639800518751144, 0.0906368757465056, 0.11047147892947708, 0.0410689460778875, 0.0533650421670505, 0.01914496733141797, 0.04113293193014605, 0.04795265330799988, 0.048394053908331056, 0.06535667620067086, 0.023065695339547734, 0.05918474202709539, 0.0014823879277433402, 0.019608705304563046, 0.0355792347607868, 0.05540722222732646, 0.024864595150575042, 0.04630687001294323, 0.03189043680738125, 0.044925118264343054, 0.030176226648369005, 0.10498832565333162, 0.0377228083088994, 0.022286111189584647, 0.01146595344679164, 0.03158184925892523, 0.1332934818097523, 0.10918406729719468, 0.18323200355683053, 0.12284605098622185, 0.16661449096032552, 0.11524550882833344, 0.12333994305559567, 0.13162427209317684, 0.13963939914745943, 0.06757835591478006, 0.09757540521344968, 0.09340651320027453, 0.11636343598365784, 0.12897571921348572, 0.11928219507847514, 0.10681373413119997, 0.1451379076710769, 0.11659811410520758, 0.06438088177570275, 0.18115806127233164, 0.13772074638732842, 0.12927563169172832, 0.15438834843891008, 0.05681663445596184, 0.12192120775580406, 0.1454499252140522, 0.13230075793606894, 0.14132893777319364, 0.24398754058139666, 0.12795774026640824, 0.10188455041497946, 0.17034445224063738, 0.11613634388361659, 0.11818193697503634, 0.09535057709685393, 0.12183822292302336, 0.09544401136892182, 0.1192737812442439, 0.13073456340602466, 0.19354365952312946, 0.16202136528279099, 0.11761248324598585, 0.11605990012841565, 0.22035584864871843, 0.1442060483885663, 0.18459064779537065, 0.14150860027543136, 0.14271635189652443, 0.13066456573350088, 0.17087524304432528, 0.1652958124343838, 0.0781330359833581, 0.1571857447602919, 0.10594516859522887, 0.15699617564678192, 0.09529204666614532, 0.21460130172116415, 0.14778595843485423, 0.1857094027634178, 0.1498522875564439, 0.08953180004443441, 0.09343425849718706, 0.1923547847462552, 0.13647099344858102, 0.15808210309062684, 0.13869436271488667, 0.09738444510315146, 0.1091054929420352, 0.1034793316253594, 0.09864421321877412, 0.05737700938646283, 0.23564473539590836, 0.14520002076668398, 0.17734538657324656, 0.1289593122367348, 0.14933809371931211, 0.2384519704750606, 0.15714557548718794, 0.05777109573994364, 0.12862427878592694, 0.20591713913849422, 0.14317525870033673, 0.12073128803500108, 0.1046168820134231, 0.3069356685238225, 0.24847979524305888, 0.18482501379081182, 0.14697557049138205, 0.10434455876903874, 0.18249249538140638, 0.13615666888654232, 0.258483599871397, 0.17966270579823426, 0.10673220136335917, 0.11872878191726548, 0.12064474767872266, 0.10490497441164084, 0.07929180416145495, 0.15267397543149336, 0.11276713931666953, 0.16780194081366062, 0.11329316680452653, 0.1493420156517199, 0.2741386783974511, 0.09411195213241236, 0.1188924852758646, 0.17931501088397844, 0.1508631825979267, 0.09715710873050348, 0.13004080206155777, 0.14107182728392736, 0.11405484271900994, 0.12086239457130432, 0.12696158300553048, 0.13436564856341907, 0.14831877127289772, 0.0974189689649003, 0.10111097299626895, 0.23859261721372604, 0.11541895594980035, 0.1566388862473624, 0.08672565740666219, 0.1142503015164818, 0.1087242987539087, 0.09512681660375424, 0.18075653138969625, 0.099764196335205, 0.16926837712526321, 0.1366956563932555, 0.17045369637863977, 0.10431256584290947, 0.040479356822158606, 0.08448738751134702, 0.10371561108955316, 0.21361889157976421, 0.0771129128656217, 0.1551956965454987, 0.1499206024621214, 0.09683121514639684, 0.10702817155314343, 0.19391325754778727, 0.11341170008693423, 0.17907333028103622, 0.20074355389390672, 0.10360257394079651, 0.18312004527875356, 0.13242368134004728, 0.06628377895270075, 0.14701833176825727, 0.1185210823480572, 0.08294295359935079, 0.2518428590680872, 0.13897729824696267, 0.14178236201405525, 0.1854548164244209, 0.0758857483576451, 0.16752089160893643, 0.06784455198794603, 0.13041905819305352, 0.21582634241453238, 0.120838659416352, 0.16499716203127587, 0.127766596951655, 0.0884170416476471, 0.1420647818595171, 0.18596818244882993, 0.12354256718286447, 0.12128010072878428, 0.17087715651307786, 0.14375411692474568, 0.18315971243594373, 0.17977440623300417, 0.20111475326120853, 0.1037166899602328, 0.1273782713604825, 0.12267966062894889], [0.055995841177978685, 0.06823471640901906, 0.017552723842007772, 0.018585158977657557, 0.07430003916046449, 0.05208708252757788, 0.02989911294675299, 0.07461487940911736, 0.024717768654227257, 0.0791270626442773, 0.06339955050498247, 0.05253169938389744, 0.02225197578913399, 0.02738786332442292, 0.0380034944973886, 0.10606527607887983, 0.03820473441321935, 0.021408088571791137, 0.02499251426862819, 0.02633830875025264, 0.023024559154042175, 0.009892402748976434, 0.04534529089661581, 0.044970396906137466, 0.029867611958512237, 0.016490443343562738, 0.026945721424583877, 0.028810315299779177, 0.03749131251658712, 0.04992958204820752, 0.024997859428237592, 0.028181545735735978, 0.02448471392770963, 0.03884512219311936, 0.020197895920968482, 0.032749401072838476, 0.020210202849869217, 0.01416255084664694, 0.004061887464818678, 0.016506862194676484, 0.09926672838628292, 0.036746742469923835, 0.037829161887722354, 0.07914942037314177, 0.05094074511102267, 0.039724880164223056, 0.06771081273577043, 0.002507440072284745, 0.027201596980116198, 0.02312924014404416, 0.08070462942123413, 0.05196641864521163, 0.03025471279397607, 0.019684864075056145, 0.029616757562117915, 0.02300586042526577, 0.02551975633416857, 0.05731084543679442, 0.015233224823272653, 0.10222092736512423, 0.061941297325704775, 0.07022994863135473, 0.047630145613636286, 0.06294897611119918, 0.03396360556195889, 0.02338210300409368, 0.028772212165806974, 0.0359843778423965, 0.019979875834126557, 0.08020963133977992, 0.014445321833980935, 0.029642345117671148, 0.04275411154542651, 0.03674270857923797, 0.02999581436493567, 0.06241530831903219, 0.09619063059134142, 0.0707299407305462, 0.05425899848341942, 0.018848210041012083, 0.03222641681454011, 0.057110419762986045, 0.007009266318553793, 0.04035527990864856, 0.0749223507674677, 0.021780470286362937, 0.06500089314899274, 0.03734149198446955, 0.03668971160160644, 0.02034329410110201, 0.021430164708622863, 0.014971020232353891, 0.043774624820798635, 0.019503376313618252, 0.03923338332346507, 0.022009843960404396, 0.02145524336291211, 0.015513985650613904, 0.08034768607467413, 0.037600858602672815, 0.019675595286701406, 0.05075557290443352, 0.03780236314716084, 0.04969216603785753, 0.012548298225738108, 0.012857173303408282, 0.013766565443282681, 0.014959963504225016, 0.03683086045618568, 0.09707555560661213, 0.01938895834609866, 0.029458865855953524, 0.04079532004626734, 0.04028579453006387, 0.05056303859289203, 0.05399327399209142, 0.019522046204656363, 0.0013285944670704858, 0.01782529814434903, 0.05239278290952955, 0.024767802130164843, 0.024915519203724604, 0.005962891529114651, 0.029916585223483186, 0.040429721985544474, 0.020353663812524507, 0.04848085889326675, 0.04917239464287247, 0.02222070550279958, 0.04031428960817201, 0.01933605466703219, 0.060381067118474414, 0.01425661615628217, 0.039165278763643334, 0.024419920618778894, 0.04553685151040554, 0.005777439002745918, 0.0810679102848683, 0.04244188026392034, 0.039890798939658065, 0.04200124301548515, 0.04164341078805072, 0.008793245568605406, 0.08256664486335856, 0.03896309568413666, 0.03328066685103944, 0.07884730265608855, 0.09196657368115016, 0.07116704620420933, 0.026816686116425053, 0.014816217556861895, 0.00938011983609093, 0.029516809353871003, 0.021355094986834695, 0.035769177068557055, 0.026166279766974703, 0.08308455028704234, 0.010282797871955802, 0.05423198600432702, 0.055883519883666716, 0.03153830088142838, 0.06552893588585512, 0.027630166483244727, 0.012826171038406236, 0.023818964205150093, 0.01612043141254357, 0.06652937470270054, 0.009266421115691108, 0.029491917296711887, 0.04166722397453018, 0.06819922902754375, 0.04521819789494787, 0.027448047684239488, 0.011160488007590175, 0.012595133257231541, 0.02361058610092316, 0.04177733324468136, 0.06102154989327703, 0.008385645342059433, 0.058621585103017945, 0.048708972188511064, 0.009466300568809467, 0.009199585416354239, 0.038380532658525875, 0.0311706027548228, 0.10296247114560433, 0.011519032696794187, 0.018866260768845677, 0.06234774658722537, 0.02555389343095677, 0.04963553550520113, 0.039764818735420704, 0.016062477736600807, 0.023521390976384282, 0.040282496849873235, 0.014737985861886824, 0.03068534843623638, 0.027021695294284394, 0.020747884176671505, 0.03573237332914557, 0.01395955606962421, 0.038850428336965184, 0.029686755234641687, 0.04719962192965405, 0.05208764571164336, 0.031387954484671354, 0.04378008024234857, 0.034857504202851226, 0.02829817572741636, 0.04116767631577594, 0.0066113012892726275, 0.02542956037047718, 0.025353294730718647, 0.02868800257731761, 0.08908563612827233, 0.043869494194430966, 0.02732797752001456, 0.06755732132920197, 0.06336797827056476, 0.04542097129992076, 0.004600654447650803, 0.07567756702857358, 0.019002035626077225, 0.03663105903459447, 0.008966456050984561, 0.03423989823620234, 0.056189223658293486, 0.04855695998828326, 0.04197659183825765, 0.020579451428992406, 0.06397754698991776, 0.021133317512327006, 0.04708518021340881, 0.05940580873617104, 0.044503323933375735, 0.04419867528070297, 0.06755425435091768, 0.03265931876376271, 0.03460319945588708, 0.01837602091420974, 0.039764873018222194, 0.016785117531461374, 0.02992724161595106, 0.10688375894512449, 0.050089685778532705, 0.08066857885569334, 0.010554586770012975, 0.04119853608842407, 0.04572963009455374, 0.037691775509821515, 0.027685378877712146, 0.020885740440072756, 0.003951069549657404, 0.00797346924498145, 0.010449860827066004, 0.01816449949650892, 0.01933347962663642, 0.09784740954637527, 0.018150670952828865, 0.014406750510845865, 0.0562837469790663, 0.009496010224600988, 0.01732766904336001, 0.004841607745869884, 0.0412672954345388, 0.05029731749423912, 0.04277942090162209, 0.01768793721151139, 0.008014062602472092, 0.016062313191858784, 0.06717210342841488, 0.012540205847471952, 0.017320529158626283, 0.09020120876708201, 0.005245037102473101, 0.06132188984858138, 0.042040153606129546, 0.023809449447851096, 0.01654109767904239, 0.0662131163158587, 0.02369090768375567, 0.01235051714216492, 0.03338709846138954, 0.029765485652855465, 0.0173179100134543, 0.04462665106569018, 0.03186720376834273, 0.005660587214931313, 0.05056745585586343, 0.07770477860633816, 0.06787239227976118, 0.013239600728931171, 0.043130654376000166, 0.019760032184422016, 0.030548216508967534, 0.03662278090736695, 0.006397449951951525, 0.04129567176901868, 0.04448786351297583, 0.032513688185385296, 0.05344578783426966, 0.010568031941407492, 0.031509965259049616, 0.02832951895626528, 0.03764726361259818, 0.026548697014472315, 0.08899309752242905, 0.02014930433194552, 0.031065178768975393, 0.012416143352831048, 0.04288545556898628, 0.006706935287054096, 0.024245769517230134, 0.03804193689887013, 0.008070338600581246, 0.015173608736534203, 0.045662275315927606, 0.026920546079054475, 0.03707424757469978, 0.0813035654968449, 0.03733409595276628, 0.017807201615401676, 0.0309253089529063, 0.03508269301216517, 0.06684098512466465, 0.021612015486295735, 0.03419797155740006, 0.022511579894593785, 0.05972389916756323, 0.1385222455220563, 0.03709302603134087, 0.06445345788129739, 0.015087640046008995, 0.026574778204251612, 0.026958527076723318, 0.018108316796964834, 0.02500137932864683, 0.0386064339296094, 0.01675212206984205, 0.026935029409027526, 0.017011162991236364, 0.00590005749005026, 0.039495915307530334, 0.032443381779428036, 0.016126236279628108, 0.05024283452491675, 0.043985272624662945, 0.023125715154622282, 0.025233601153429066, 0.03863021318933793, 0.01045053088039692, 0.046580740317170105, 0.11721045124743666, 0.17433653159865312, 0.11491016325141702, 0.22882027445094927, 0.1443501149437257, 0.1309577335736581, 0.09379362421376364, 0.1543017402291298, 0.10653344488569669, 0.21000023718391145, 0.17425391317478248, 0.1357116856213127, 0.2002011194292988, 0.10871890440051045, 0.15746490763766424, 0.19636306752051624, 0.16705087040151867, 0.10363593072231327, 0.09631149803421327, 0.10388225250478302, 0.12580919984195912, 0.1148222658251013, 0.14185013409171784, 0.15562979610902922, 0.11459288027669702, 0.10035960402871881, 0.16349514334329537, 0.1271475830248424, 0.14188980124890804, 0.11777060904673167, 0.12860941886901855, 0.11436040060860769, 0.132411264149206, 0.13562847008662565, 0.08454460158411946, 0.07167765737644263, 0.07310568860598973, 0.17487513912575586, 0.18554360951696122, 0.12911852369351046, 0.13346565328538418, 0.13658916710742883, 0.14135478995740414, 0.15694061719945498, 0.15437135792204312, 0.1700328825307744, 0.13205089420080185, 0.11355060299060174, 0.11835933317031179, 0.1296080324266638, 0.12247548944183759, 0.1261573833014284, 0.061816053331962655, 0.1115612740229283, 0.11656904566500868, 0.11053524765052966, 0.12529058195650578, 0.1611757478011506, 0.13088808873934404, 0.10181181146098034, 0.1279506699315139, 0.10322622449270316, 0.0654192032026393, 0.11800521931477956, 0.14563775727791445, 0.10923771227576903, 0.15301815553435258, 0.1403710770287684, 0.10872256848961115, 0.17393804155290127, 0.0986276501789689, 0.17689584355269158, 0.1755923642111676, 0.09090825582721404, 0.06661904989076511, 0.19947649831218378, 0.18355836533010006, 0.10964536932962281, 0.19120499358645507, 0.07937940303236246, 0.18507083345736774, 0.16735181425298962, 0.08875432783471686, 0.0840601207954543, 0.13353201401020798, 0.07381813001952, 0.16173578346414225, 0.09027469410960164, 0.11817414739302226, 0.0922748049987214, 0.11111563257873058, 0.14002369424062117, 0.15750773676804133, 0.07554909320814268, 0.17862408581588948, 0.09739354425775153, 0.08223980811557599, 0.10035943439496414, 0.15256194929991448, 0.11612681725195476, 0.07674328091421298, 0.15934193905975136, 0.09514405139322792, 0.1438898646405765, 0.10222965332546405, 0.09391241533947842, 0.09646598688725914, 0.14559883650924477, 0.15915885674101965, 0.18052870647183486, 0.08908491688115255, 0.10771018067108733, 0.10413329010563237, 0.11998974425452096, 0.140008807182312, 0.14901209835495266, 0.15639925482017653, 0.09519425619925771, 0.09908135940453835, 0.22746962335492882, 0.08654041056122098, 0.06952833663672209, 0.12337532187146799, 0.15448365546762943, 0.10392605872558695, 0.15588002625320638, 0.20208568259009294, 0.12444588728249073, 0.08096513258559362, 0.10445329400577716, 0.197513645780938, 0.1281836110034159, 0.10962831095925399, 0.14288553781807423, 0.1978405232408217, 0.10699302343917744, 0.12258298295949187, 0.17622680802430424, 0.13395186433834688, 0.13486198335886002, 0.1038101649444018, 0.08429019844957761, 0.08854432803179536, 0.13241944728153093, 0.16639999247023038, 0.12621675511556013, 0.19468513184360095, 0.19292305782437325, 0.11042737415326492, 0.09107802528887987, 0.1218978932925633, 0.10051331256649323, 0.11228805966675282, 0.24555544501968793, 0.07083334268203803, 0.08321653213351965, 0.13683468821857656, 0.12333454191684723, 0.2070441993751696, 0.09000503750784056, 0.12526314200035163, 0.12147254683077335, 0.11026818305253983, 0.06455442389207226, 0.11822936657283988, 0.08364114577748946, 0.16745781499360288, 0.15471340742494377, 0.10118144564330578, 0.16730290544884546, 0.13129917239504202, 0.06788033113947936, 0.13768498759184564, 0.20694896019995213, 0.10382835646825177, 0.12767825169222696], [0.05773463126804147, 0.05795359451855932, 0.05822496102856738, 0.03251939466489213, 0.01462884689681232, 0.04671742441132665, 0.026235741396833743, 0.05540933586390955, 0.02214175625704229, 0.010464839487602668, 0.034155162783073525, 0.023635120230859945, 0.05405015219002962, 0.009696299343236854, 0.03857586592701929, 0.01606763799541763, 0.013826515708517815, 0.013912394493153053, 0.043311680733625374, 0.04794543369540146, 0.0564422391887222, 0.016914936547566737, 0.03498665995097586, 0.07996674972985472, 0.017859102758978094, 0.00780999065110726, 0.047199761029332876, 0.044786273036152124, 0.03856801866952862, 0.032996452280453274, 0.023432662344670722, 0.05035474869821753, 0.013125656039587088, 0.05626998968156321, 0.017231267876923084, 0.05231299736936178, 0.009622163455268102, 0.027344248789761747, 0.023207227566412518, 0.019545233442581127, 0.03771750216505357, 0.01784430560655892, 0.018870718743918196, 0.04148760557706867, 0.018616926290893128, 0.009065782551520636, 0.04336248943582177, 0.04867131688765117, 0.0384207833558321, 0.01718611646044467, 0.009846768724466009, 0.048495552569095574, 0.02665532031096518, 0.02894810201334102, 0.06920534718249526, 0.043324688249932866, 0.09990636977766242, 0.03325581211330635, 0.007817748002707958, 0.060911749356559346, 0.027825418327535902, 0.0755090257152915, 0.07589606208992855, 0.05250004572527749, 0.006394645481902573, 0.027831340241911154, 0.03830825850101454, 0.01147808226024998, 0.009403028026489275, 0.03247740691793816, 0.024243589723482728, 0.0215971725327628, 0.07166941996131625, 0.03140778806326645, 0.030003617517650127, 0.01387949741911143, 0.025725903754521693, 0.06987352775675909, 0.02787685128194945, 0.03713524108752608, 0.01854048592836729, 0.004775308937366519, 0.055723830059702904, 0.03403084159695676, 0.044992897127355845, 0.052303145040891, 0.017582280827420096, 0.021981654223054647, 0.05701465133045401, 0.03664594270022852, 0.04878122598997184, 0.015960924793034792, 0.10257634400789227, 0.04509673673393471, 0.01225141286184745, 0.08398483733513526, 0.01726751691395683, 0.009623619761051876, 0.04989484105525272, 0.023978187536288584, 0.032719732129148076, 0.039946157219154496, 0.05621707073545881, 0.03254031389951706, 0.009695078828372061, 0.04367692595613854, 0.03752594494393893, 0.07638957417969193, 0.022022617382130454, 0.018249414761417677, 0.0489125767988818, 0.0557187139056623, 0.042601715972913165, 0.016820243593039255, 0.05993751556213413, 0.024855521441038166, 0.050877257982002835, 0.024805800091209154, 0.02486542465963534, 0.0226306780574045, 0.03104562678241304, 0.04753528981070433, 0.022869636038584367, 0.030167354803000177, 0.10050217102148704, 0.009903517152581896, 0.03735688794404268, 0.012609256963644708, 0.03876642230898142, 0.030291072092950344, 0.04719931319622057, 0.006541141616513154, 0.015540657165859426, 0.0672292767890862, 0.03226271504536271, 0.03990334165947778, 0.032134743340845616, 0.06182244513183832, 0.027288529190367887, 0.02585692038493497, 0.024102233915722797, 0.04650395390178476, 0.02962511032819748, 0.02190608747436532, 0.015633217824090804, 0.08056320915264742, 0.0455068466918809, 0.03209635861484068, 0.09232281135129076, 0.010765847799900388, 0.014632063152800714, 0.054951094024415524, 0.0240300157373505, 0.01093282169728939, 0.05041466334036418, 0.014193181613726276, 0.03404481263299074, 0.060442209909004826, 0.07412458357534238, 0.06331439436014209, 0.04191265348345041, 0.0539175257352846, 0.02828083067600216, 0.05163934441017253, 0.034765216654964855, 0.0444004749879241, 0.02773979738620775, 0.021785457518750002, 0.02359934107932661, 0.018331541247399788, 0.021893052816657082, 0.02044685211564813, 0.03356896959511297, 0.01410117226519755, 0.061026347135858874, 0.004987805749156645, 0.025693161047196815, 0.03603900669674788, 0.026257167836385112, 0.03013954504526087, 0.04961107771045395, 0.0814320325319256, 0.0054482447698579305, 0.024994834858391966, 0.023786321581740464, 0.049230239753212245, 0.03580153979627149, 0.0055575851750160965, 0.03955648812864508, 0.04737575604979481, 0.026233203675863997, 0.028868065415216342, 0.0448318705894053, 0.03362658400354641, 0.0664003241275038, 0.05428850118603025, 0.06766972065504108, 0.02011917737711753, 0.07606293420706477, 0.062149254738220146, 0.028953716890620332, 0.019806778158194253, 0.027657290920615196, 0.03433115780353546, 0.04355439610247101, 0.018616927987230674, 0.045850718061306646, 0.038552534500403066, 0.027216528143201555, 9.436001515236317e-05, 0.01868788748314338, 0.058293133441890986, 0.015387935896537133, 0.0318684251313763, 0.0423651888434376, 0.030128624024135724, 0.01896410551853478, 0.005135234869417867, 0.028152458635824065, 0.013025888491288891, 0.04867192078381777, 0.012124405525225614, 0.044399681101952276, 0.04033621985997472, 0.014285940743450607, 0.0429004070881222, 0.025065263400652578, 0.021495388887290443, 0.026414016294958334, 0.03586987166532448, 0.04102387099659868, 0.02402798691764474, 0.01741335105283984, 0.02749485642250095, 0.044954994161214144, 0.043553463116820366, 0.028403553912150006, 0.04647777262809021, 0.04168669792956539, 0.014900829177349806, 0.027020942120413696, 0.03263662516006401, 0.05271984696654337, 0.022135647745536904, 0.04740048525854945, 0.03389518548335348, 0.04926661601556199, 0.08474485083882298, 0.021955579818625535, 0.027514477958902717, 0.056397025007754564, 0.03484596571485911, 0.04207395822075861, 0.010574128578550048, 0.03717376830588494, 0.031401016283780336, 0.08628838908459459, 0.04497443758217352, 0.1174357927271298, 0.06516317836940289, 0.04276923269831708, 0.03859691747597285, 0.048205831686833074, 0.007449769980407187, 0.05632062875000494, 0.016447917857606496, 0.019520042830013802, 0.01991080096922815, 0.028730604398463453, 0.07650439587554761, 0.034433979607586346, 0.04250734871519463, 0.06164171054427113, 0.06731675352369036, 0.04545412112825683, 0.036803858155118566, 0.02934857677402241, 0.05856603344104119, 0.06317707244306803, 0.05591379272352372, 0.02443901459420366, 0.006836725889505553, 0.057031139731407166, 0.04242189062227096, 0.07137047778815031, 0.0717618635722569, 0.04331551106380565, 0.02142060245387256, 0.0393305122187095, 0.011643917915145201, 0.012529722481433834, 0.03633994376286864, 0.025977803094844733, 0.023747187074539915, 0.02799102328052478, 0.022637555009818504, 0.017589167957859378, 0.05580183105277164, 0.01752766384743154, 0.04219997574442199, 0.02985572741766061, 0.00917799782473594, 0.023669415087039982, 0.045113340485841036, 0.014746749141652669, 0.02341786858492664, 0.025340192219508544, 0.014174434539329792, 0.02431117690035275, 0.033071823950324736, 0.012907741125673056, 0.03150958867211427, 0.0427597874908575, 0.04120635959718909, 0.005670299171470106, 0.017256902929927622, 0.0894647811406425, 0.03090336513040321, 0.040326163970998356, 0.021042626218072007, 0.05255073907652071, 0.018912121254418577, 0.07969422971031495, 0.02050983203974153, 0.055805532461298366, 0.019405584150393094, 0.032003158437354226, 0.037187532388738224, 0.02309075533412397, 0.029679732397198677, 0.012295999397922839, 0.01960629311257175, 0.06634406678910766, 0.04052482206108315, 0.06596910155245236, 0.07033433445862361, 0.07760092203638383, 0.05848112156880753, 0.08016733825206757, 0.0191790145223162, 0.019916987512260675, 0.02702353921319757, 0.011034321206222688, 0.02596261748112738, 0.025755516719073057, 0.02154257081981216, 0.037788320864949904, 0.01979522779583931, 0.030008625106087754, 0.014262500751231397, 0.09415371596281018, 0.03862463563148465, 0.1655464768409729, 0.1295831709035805, 0.16468348886285508, 0.11866087413259915, 0.2061504466193063, 0.1664802631629365, 0.09547065065375396, 0.15266051329672337, 0.11754692319248404, 0.12751055854771817, 0.09309533025537219, 0.1182281994926078, 0.09307967645249196, 0.12310597061046533, 0.12137107870408467, 0.09850928653031588, 0.1798748836985656, 0.15956481067197664, 0.16381644324532577, 0.12489353040499346, 0.1404744993363108, 0.12915099837950297, 0.16142251741673264, 0.15567761925714357, 0.2073244886206729, 0.10708858831120388, 0.11164395351495061, 0.12298534065485, 0.13514273400817597, 0.21608314077769006, 0.16390731265502317, 0.1577881888619491, 0.10656393146408455, 0.14808872076017515, 0.08862946382058517, 0.20352495035954885, 0.09831298634942089, 0.10886994629566159, 0.09900481386908463, 0.08928787349058048, 0.11045570977564369, 0.06665864919445344, 0.1213605206991945, 0.1143620562340532, 0.12368379746164594, 0.08914753209267344, 0.2074451864297901, 0.17102895836744988, 0.11412707955709525, 0.12247060398970332, 0.08622921404561826, 0.09255071090800421, 0.19982922795627797, 0.09831304741757256, 0.14108047182006495, 0.16773910847093376, 0.21025242150894233, 0.13531960094613688, 0.1528261708361762, 0.11015606192605835, 0.11505680823964731, 0.21172033702688559, 0.18154414769794258, 0.18425603503627436, 0.13350530687187398, 0.11246244995189564, 0.1572356985083648, 0.11531106888183526, 0.08749709744006395, 0.1374358973864998, 0.1403514537960291, 0.18315618405384676, 0.1536954827606678, 0.10504986199417285, 0.10075571920190539, 0.11831896033670221, 0.10904551044638668, 0.12474427984229156, 0.22263499349355698, 0.0883124251184719, 0.20447191383157456, 0.0889707330082144, 0.19371805659362248, 0.10560596893940653, 0.10282873867877892, 0.0941273413066353, 0.09860623561378036, 0.09000558033585548, 0.10639392451516219, 0.1127566152385303, 0.18420328572392464, 0.12486557476222515, 0.2219660258186715, 0.166251271164843, 0.08254274686000176, 0.15816994623414107, 0.10539634233074528, 0.12724882044962474, 0.11952076799103192, 0.1674015780112573, 0.134979872033, 0.18633619270154408, 0.1394834853708744, 0.0867771107171263, 0.11085776213024344, 0.11549972875842027, 0.11396733884300504, 0.13506699592939445, 0.0897108247237546, 0.12340592380080904, 0.12889145873486996, 0.11254658150885787, 0.112630455222513, 0.20480819578681672, 0.12932159565389156, 0.17785420641303062, 0.14994299411773682, 0.2065735539155347, 0.04777513497642108, 0.13204500451683998, 0.1650216028626476, 0.1250859900776829, 0.08111894968897104, 0.15465449701462472, 0.23896125171865734, 0.08651890100112983, 0.12090424661125455, 0.10390482057950326, 0.11869625294847147, 0.11830758808978967, 0.1362971527768033, 0.06403104947613818, 0.12778699371431554, 0.1755000427365303, 0.08169698688600745, 0.11771499631660325, 0.13943577078836306, 0.1097998513973185, 0.14657873607107572, 0.11906826655779566, 0.13997089064546994, 0.11881730359579835, 0.15586684910314424, 0.08750422205775976, 0.14969733729958534, 0.1336359791457653, 0.1243862576250519, 0.10145185541893754, 0.15288421272167138, 0.1103022319397756, 0.11622407846152782, 0.16669922641345433, 0.09102187651608672, 0.1687432588743312, 0.12021853269210883, 0.12354228219815663, 0.09048902975129229, 0.15310593082436494, 0.11723888186471802, 0.154476435855031, 0.161644846200943, 0.13558025338820048, 0.17642420743192944, 0.15346336950148853, 0.08570289478770324, 0.10043169158910002, 0.12287769785949162, 0.12300690449774265, 0.22950073650905065, 0.10077435177351747, 0.0956096892644252, 0.15422672139746801, 0.1939725343670164, 0.1398853545210191, 0.16609245325837815, 0.13920441748840467], [0.09970593731850386, 0.02069387787819973, 0.0259153676951038, 0.037467624859086106, 0.026471961489213363, 0.023558861376451593, 0.06447933042155844, 0.02684499629374061, 0.011744059505872428, 0.05174573530842151, 0.07765816325055701, 0.04592946544289589, 0.026354691978277903, 0.005323780243218477, 0.005402702771659408, 0.05712561894740377, 0.07737061368035418, 0.024129494060096995, 0.07647099838192974, 0.08519537094980478, 0.049501036293804646, 0.05942708759435585, 0.05408919170232756, 0.015533440945936101, 0.051279602106660604, 0.030745653236018758, 0.010823078836048288, 0.130262981568064, 0.01897378821325089, 0.04149715256478105, 0.03934396078277912, 0.05312646246914353, 0.028137637734679238, 0.037035923916846514, 0.04979430591421468, 0.06379671740744795, 0.05241822458005377, 0.04732452326321176, 0.020212659146636724, 0.03568633133545518, 0.013825585267373493, 0.038345852733722756, 0.018533451216561452, 0.04464152455329895, 0.00873631563237203, 0.02857340479801808, 0.07831106321620089, 0.05125555143292461, 0.09285889472812414, 0.016760127086724554, 0.054104560520499945, 0.047734663755233796, 0.018304661082636033, 0.030136566276529005, 0.09940335141228777, 0.03357691863285644, 0.04871322660307799, 0.027900404928784286, 0.03907095900337611, 0.023126397082316022, 0.034652576449194124, 0.07636345736682415, 0.022953063615464737, 0.059155388602188656, 0.08640557886766535, 0.03762465143310172, 0.007597850918370698, 0.043597744312137365, 0.01548811311035284, 0.014576964412948914, 0.0839443016531212, 0.08608868944325618, 0.03647036158612796, 0.01066905986850283, 0.027046115769605552, 0.036431613843888044, 0.03486591464440737, 0.011811671279636877, 0.07478448602237872, 0.039997878550950966, 0.04491729136290295, 0.040956733349178515, 0.03539651206561497, 0.02945404825732112, 0.04622334235214761, 0.010903441979150687, 0.042057473212480545, 0.01847807936636465, 0.009844405726263565, 0.034424286734844954, 0.06520749349147081, 0.03128581460831421, 0.04058180203927415, 0.01852219262426453, 0.01902619656175375, 0.020245926022263508, 0.00704257220994415, 0.010172495219324316, 0.04408664914912411, 0.05679719103500247, 0.05844602095229285, 0.07383463199117354, 0.039177550069455586, 0.014110620865332229, 0.04302587499842048, 0.04434987663158348, 0.01903886820322701, 0.046474386738347154, 0.03370943991467357, 0.07471628646765437, 0.057274808441954, 0.04832635307684541, 0.03477816988847085, 0.02349139972856002, 0.07486661590103592, 0.005356874940584281, 0.05571700060474021, 0.05763675259160144, 0.06464272843939917, 0.03196405785690461, 0.03289920124890549, 0.08166309406182595, 0.044123218793954165, 0.018728721720565642, 0.04895840844671641, 0.06584687703954321, 0.02385397152309971, 0.026456171979329417, 0.03780244457136307, 0.008072832216774779, 0.05581090985132115, 0.03002813977322408, 0.04121206946937101, 0.04429914256823914, 0.021546474092506936, 0.060441287101379464, 0.02946551549913628, 0.029037454897271733, 0.040411954546081166, 0.03125541963215385, 0.027966692711093595, 0.011329091237192708, 0.00702548457775265, 0.030940409749746323, 0.03142841213515826, 0.022733949390905242, 0.060360188595950603, 0.06327601641948734, 0.030121926883501664, 0.0603412642542805, 0.017384759283491542, 0.061548439120607715, 0.03672692246202912, 0.05344660546896713, 0.06983680544154984, 0.022970591871333972, 0.010341810062527657, 0.020829154012192572, 0.04268132509397609, 0.028319866795625006, 0.045953458441155295, 0.028716901383761848, 0.021305716297190105, 0.015819774242118, 0.006325669004581869, 0.01783446006343833, 0.023190818893324052, 0.07824788482061454, 0.044363386263804774, 0.04287473132301654, 0.040663551938320906, 0.05626039519639952, 0.05157466305951987, 0.05605384235137275, 0.030695506105465547, 0.03542308349694524, 0.04584146284365228, 0.054851814173161983, 0.01566548046788999, 0.0069285583948450425, 0.0211906537214028, 0.010738345927425792, 0.0420658293712352, 0.0548246965211417, 0.013857649439679725, 0.07423496086682592, 0.04129115611846958, 0.07816450643752303, 0.05744510716093438, 0.038082357229931016, 0.09664941525885037, 0.05412230081856251, 0.06324251036026649, 0.02364282329965915, 0.01779087945552809, 0.031817467151475806, 0.03445051211331572, 0.03100532858765551, 0.021529620978981256, 0.03909220393480999, 0.012490452267229557, 0.04901326461029904, 0.026383436418005397, 0.06670597701200418, 0.013811788954106825, 0.03842607592897756, 0.04038510491539325, 0.06173782502966268, 0.017515382363594005, 0.04219126674745764, 0.0771686409467033, 0.05572292082277792, 0.03346403415447899, 0.021430649861161197, 0.017759939955015267, 0.019321912300906012, 0.125429328797119, 0.01970548814694796, 0.02845333463379315, 0.02338484428556902, 0.015097887621128132, 0.05773932673037052, 0.01451503112912178, 0.03883677621238998, 0.06957512841160808, 0.032146003629480085, 0.01608644868247211, 0.03221719213096159, 0.019788152371932353, 0.010638021980412304, 0.08692893292754889, 0.042951711120882204, 0.03334480198100209, 0.03439471957140735, 0.030112518995468105, 0.06657354054706437, 0.04841063730418682, 0.0543604157199817, 0.05941638031176158, 0.05706250840531928, 0.060333508599017344, 0.03418406158951776, 0.03128714792962585, 0.03474087421117084, 0.03464200148092849, 0.058233178087643216, 0.040852931062025685, 0.034940037809844525, 0.07683093406792198, 0.004029681224242917, 0.05489010390426431, 0.06158467289060354, 0.042328734549560716, 0.020156145661271045, 0.052982233065579615, 0.030854877017970597, 0.015568429604172707, 0.016793943575716445, 0.017918398237920234, 0.0056590308252322885, 0.06458272558770009, 0.03009909757279924, 0.013340777085561837, 0.023389895978782858, 0.035086611551897864, 0.009944527809109007, 0.044817081918673854, 0.037655087121363194, 0.01889839788366641, 0.041720770565526824, 0.013991087591940803, 0.06585967420999493, 0.03752306117010968, 0.046311914920806885, 0.038397034630179405, 0.0318478417715856, 0.040967946140361686, 0.041700363624840975, 0.046084388558353694, 0.010115097093928074, 0.03594515512564352, 0.04732375651864069, 0.07127546252948896, 0.01063881756272167, 0.0437842294839876, 0.02841394397962306, 0.07876277076346533, 0.045371217719678364, 0.04880191791536553, 0.020319781166368296, 0.027979484792532663, 0.0518810385838151, 0.0431598551305277, 0.04387738894937294, 0.023250906561900462, 0.05847377303455557, 0.006478259655913072, 0.07659091587577548, 0.04614372983840959, 0.010123333660885692, 0.032707854373646636, 0.02465750795922109, 0.04911740277228611, 0.03238111940611686, 0.02358474918375058, 0.04216084802257163, 0.03761890763416886, 0.04430619593975799, 0.03956314455717802, 0.021299780812114477, 0.03349206782877445, 0.010142459866723843, 0.0015129198831605858, 0.0498682933726481, 0.02834114056479718, 0.02865339389869145, 0.01883723134441035, 0.04509484701390777, 0.043150766153952906, 0.04685145543356027, 0.02871217199468187, 0.07608455911810909, 0.01241002042245652, 0.08165613229253463, 0.01950219227001071, 0.0342682338585811, 0.044571153686514924, 0.050176158281309266, 0.04348434414714575, 0.0925998164873038, 0.036421252614153285, 0.04565388523042202, 0.03583711538729923, 0.05141115647607616, 0.049332026791359694, 0.028461775609425137, 0.05854893435857125, 0.022601399271349822, 0.04285172898588436, 0.01939395406017346, 0.062198102474212646, 0.020189650024154356, 0.051556251011788845, 0.01903534321380513, 0.008404074353165925, 0.02125540462189487, 0.02279917017689773, 0.05558114432330642, 0.05679788314072149, 0.0530780795296388, 0.04029470369485872, 0.06615244849984135, 0.16765875635402544, 0.14630938481007302, 0.076554403906422, 0.12247947922774724, 0.11441211854772908, 0.13098107517829963, 0.18076194609914506, 0.13075064468596662, 0.10087161298309054, 0.17024169489741325, 0.15508941082017763, 0.15884100379688398, 0.09191147663763591, 0.1287255704935108, 0.1577322504350117, 0.12398597624685083, 0.1698507908731699, 0.22009567118116788, 0.252149258341108, 0.1418655232659408, 0.12803364119359426, 0.16135995648801327, 0.09436885227582284, 0.12433402399931635, 0.1214751795466457, 0.12407912553421088, 0.19923674474869454, 0.21162098592945508, 0.1469423087047679, 0.08878462442329951, 0.10760082118213177, 0.21569735290748732, 0.11842960225684301, 0.12768602770354065, 0.10041704880339758, 0.192415323640619, 0.11836804555995123, 0.17541205031531198, 0.09999383972691638, 0.0776350252064211, 0.2324429186327117, 0.07649778015911579, 0.09725860399859292, 0.09776480469320502, 0.0971021338232926, 0.1155278743909938, 0.23402078396507672, 0.11460978936936174, 0.13015704868095263, 0.07626078823315245, 0.21247052534350327, 0.07536442990281753, 0.1430289801210165, 0.1027727731104408, 0.2795379715306418, 0.0656655046290585, 0.11348577575492007, 0.15119044003742083, 0.16066479736140796, 0.11133588504578386, 0.06111794936337641, 0.21780989026384695, 0.09668261597731284, 0.17470372760934488, 0.1753544562629291, 0.10714225364582879, 0.09253095196826117, 0.12139790797872202, 0.11994839433048453, 0.07994635975254433, 0.1646865965532405, 0.16068697188581738, 0.09545031495924507, 0.07807233424058982, 0.1937453065599714, 0.1309258695691824, 0.15264984672623022, 0.17255088527287754, 0.3131184796137469, 0.1038077086476343, 0.14778821117111615, 0.07350865698286466, 0.06740357207932643, 0.11567838702883039, 0.13895867924605096, 0.0929068128711411, 0.1709018009049552, 0.09837065504065581, 0.08370008332920925, 0.1110656720453075, 0.13724360056221485, 0.2492760153753417, 0.11742849169032914, 0.09160484666270868, 0.07773599121719599, 0.1034719016669052, 0.08393898872392518, 0.13065267779997417, 0.1821554670376437, 0.0769557234432016, 0.3148939072021416, 0.10719623110656228, 0.13697266152926854, 0.08266440818884543, 0.12475358934274741, 0.16062951354043825, 0.18519803163196358, 0.1249513958713838, 0.095758390213762, 0.2515200935304165, 0.22080559522977897, 0.17077032795974187, 0.144742471032909, 0.08675463763730866, 0.17901258782616683, 0.05817397590726614, 0.1297100976641689, 0.12029081024229527, 0.13841163074331625, 0.11307944184435265, 0.21179750002920628, 0.1695846151560545, 0.14408799686602183, 0.08632177300751209, 0.10844604511346136, 0.12019630388489791, 0.14914438554218837, 0.17697388865053654, 0.11685701592692307, 0.11556608948324408, 0.09158784936049155, 0.12204402259417943, 0.13205944374203682, 0.12148389193628516, 0.0988318281514304, 0.12829315369682653, 0.18408888471978052, 0.10816628512527261, 0.12767185989235127, 0.12197633194071905, 0.08699168384607349, 0.11789132042654923, 0.09914998643632446, 0.1766226924955845, 0.13245994225144386, 0.17410421477896826, 0.09576791684542384, 0.18644224772495882, 0.11532763870699064, 0.09768395724573306, 0.10003581390316997, 0.10223823000809976, 0.10891443783683435, 0.2576195533786501, 0.14497576494302067, 0.1114411393978766, 0.156234045113836, 0.11315923077719552, 0.12137164867350034, 0.1480291182441371, 0.18919431790709496, 0.11454570852220058, 0.17333662882447243, 0.18802753623042787, 0.10865090840629169, 0.08921980285750968, 0.11825126968324184, 0.0919654948104705, 0.10187470487185887, 0.1531240748507636, 0.13163179026118346, 0.19191536546817847, 0.13858551212719508, 0.08607818572116749, 0.109028275656913, 0.15009812079370022], [0.011315633343266589, 0.011338008035506521, 0.04586434304448111, 0.06442567187228374, 0.022067775583959053, 0.006499689912223923, 0.02259943830514593, 0.04875520756468177, 0.04943053650536707, 0.09537415618875197, 0.03866891682680164, 0.020339894640658582, 0.011499069348376776, 0.003925000658325318, 0.00881438871978649, 0.011872248341595488, 0.1380368351404156, 0.06032200064510107, 0.029889219906181097, 0.03176121659842985, 0.06209012719669512, 0.04744496322902186, 0.04923183431050607, 0.06393262797168323, 0.02612648199179343, 0.013378082940887128, 0.07161609389420066, 0.023472940183377693, 0.0677610853953021, 0.027632098611710326, 0.05212785569684846, 0.04922802433637636, 0.007612006855197251, 0.06493357568979263, 0.04783947366688933, 0.0180063957481512, 0.037740287370979786, 0.023417793946074586, 0.06314333568194083, 0.03441135725006461, 0.04643393248053534, 0.03139009526265519, 0.06019877190036433, 0.06752420203494174, 0.04273512613560472, 0.06248818298003503, 0.02205697669913726, 0.0905918413773179, 0.019148889263825755, 0.016246167344174216, 0.09267902866538082, 0.013516119864237095, 0.0564367159136704, 0.03615152815889035, 0.07825440554214375, 0.02330582548997232, 0.019998331986633793, 0.032068983119513304, 0.004142256969186876, 0.025701013393700123, 0.06750453130475112, 0.02977752625676138, 0.08071542491338082, 0.04878949733184917, 0.017876117024570704, 0.023368746042251587, 0.05181419949180313, 0.028752884095800773, 0.03140597637476666, 0.0961236252582499, 0.04398819371791823, 0.04103096168754356, 0.02258042405758585, 0.02779801738714533, 0.017797720784853612, 0.04217881562986544, 0.031730906439146826, 0.012110826343164911, 0.021058380104867474, 0.05047038463609559, 0.04288602214572685, 0.09349852933415345, 0.032059985745166025, 0.020640312627490078, 0.04267714871093631, 0.014098158721545977, 0.02963434179712619, 0.02554568654990622, 0.042078969201871326, 0.03576825426093169, 0.008916337758169642, 0.013211496656627526, 0.07067173599664654, 0.057428727325584204, 0.009424382371694913, 0.08892304556710379, 0.03628267201461962, 0.08799066381262881, 0.023626874334045818, 0.022877569809289913, 0.04080418849896107, 0.02162576769478619, 0.09187191126069852, 0.05160186892109258, 0.029216917231678963, 0.013979994392554675, 0.02274972024107618, 0.004158947658392468, 0.020291187700682452, 0.10109244220490966, 0.04760690239657249, 0.054563155198203664, 0.04886270108233605, 0.039096492276127846, 0.0344925405723708, 0.018058754902865206, 0.02519444459384041, 0.02918208802917174, 0.03808995682213988, 0.025573168914499025, 0.037812887225300074, 0.004023229628468731, 0.060224318743816445, 0.007358255114273301, 0.056814089949641905, 0.036947995956454954, 0.016421622929296324, 0.03248219398249473, 0.041760583607746024, 0.020904032047837973, 0.034157558011689355, 0.10440971170152936, 0.05321025475859642, 0.03896705832864557, 0.02909474360889622, 0.04777312990544098, 0.03930810359971864, 0.03557335525485022, 0.04589369986206293, 0.027696718894211308, 0.02942080343408244, 0.08523865469864436, 0.020348859784592475, 0.05450854669990284, 0.026958739118916646, 0.07591826375573874, 0.018235671034614955, 0.018365690218550817, 0.009897982851336045, 0.046159692374723296, 0.027748801545905213, 0.016893309940184866, 0.012139571631061179, 0.0789226811113102, 0.02387277372846646, 0.03971858335925, 0.056001137143799236, 0.055628981042121134, 0.04099092472876821, 0.026083949720487, 0.019183179030993154, 0.03297837610755648, 0.010801336877713246, 0.071204257064632, 0.020658838329836726, 0.023407190140070658, 0.03724900766142777, 0.029883092734962702, 0.014411196611555559, 0.061594783062381406, 0.05098890752664634, 0.016008586789082204, 0.005803353103276874, 0.026551920055810894, 0.05680344034252422, 0.03877894467275057, 0.0434767886597131, 0.03818190170984183, 0.018233065460143343, 0.03327889248196568, 0.016561055090278387, 0.02586693556181022, 0.03844186543886151, 0.027109085515673672, 0.016620321731482233, 0.07427674505327429, 0.06478480010160378, 0.05332387884014419, 0.03352274778964264, 0.014142712179039205, 0.02381925088619547, 0.035229782440832684, 0.028573974767433744, 0.05170227853315217, 0.035591322862144024, 0.008629185130952724, 0.08195484376379422, 0.09817164750503642, 0.060044873372784684, 0.03409794192495091, 0.004018993449530431, 0.024183759898213402, 0.010939656241264726, 0.00846674554382584, 0.07895964769912617, 0.01825108056488846, 0.010261686951188105, 0.05755744541862181, 0.012397700771024185, 0.02572370190838618, 0.056583354116550515, 0.04998966632410884, 0.013362243389045554, 0.028500845655798912, 0.0214536165752049, 0.040611196176282, 0.026765207360897745, 0.06012319666998727, 0.06438999450100319, 0.04296302229964307, 0.05389366165867873, 0.02833740014050688, 0.04040474850418312, 0.03329355901639376, 0.03225414514807718, 0.010064585250802338, 0.04799195744895509, 0.014450331118756106, 0.08312492312065192, 0.018685124149279933, 0.033287557374153814, 0.012545250755335604, 0.04681540826069457, 0.0810790111177734, 0.02750503784045577, 0.021486640874562517, 0.07650109819535698, 0.045121459157339165, 0.011632819626746433, 0.0181015297504408, 0.025424763127895336, 0.020728827520672764, 0.06486346945166588, 0.019818725463535105, 0.0675787426797407, 0.10211608013404266, 0.03837140296984996, 0.02142813758525465, 0.005223073348003838, 0.10856617973851306, 0.04313000298238226, 0.026013941869937947, 0.031558341413204155, 0.054941594534154446, 0.016285491841179982, 0.039076007303914854, 0.047026897447982004, 0.011724454084677356, 0.021714942463274513, 0.018656276232962097, 0.018236302072182298, 0.06760298673595701, 0.0601480310516698, 0.019800827406080704, 0.0321529755767967, 0.011232839348459882, 0.014611488274697746, 0.030607724030103003, 0.027858328972277895, 0.005906748693502907, 0.019321162519710403, 0.0765801543103797, 0.012949511741421052, 0.0436604782672865, 0.02115769388287195, 0.03583011629858187, 0.0294776036004935, 0.02287904392661793, 0.07107076208506312, 0.04222167868699346, 0.03325599192508629, 0.0380134350354118, 0.02860389816175614, 0.060951253665345054, 0.037303555091576915, 0.05355980546612825, 0.06541690296892609, 0.04137025973094361, 0.038677568148289404, 0.0298220958294613, 0.08066469763538667, 0.029785590645458018, 0.03458061441779137, 0.040208658669143915, 0.035564720896737914, 0.023408611670934727, 0.05666693266747253, 0.016179621718557816, 0.031635585839727094, 0.026408084202557802, 0.003600573558027723, 0.04752224497497082, 0.02243521756359509, 0.05806110839226416, 0.06674448387431246, 0.048373935345028124, 0.04891139275527426, 0.049737797517861636, 0.06756346885647092, 0.05586574226617813, 0.021293226163834333, 0.03475355603066938, 0.04850661608257464, 0.04115111666864582, 0.03472016532240169, 0.0229574503443603, 0.03746116520570857, 0.04426815726661256, 0.011138174383501922, 0.008596614601888826, 0.03168504086456128, 0.011813868884928524, 0.027155490525599037, 0.017096997671095387, 0.03218014072626829, 0.036287900126938305, 0.016919837266738926, 0.01644058459039245, 0.04380658721285207, 0.06127370707690716, 0.028404135755928497, 0.014593084708654454, 0.049327202407377105, 0.010370327193023903, 0.04338935263721006, 0.06502554432622024, 0.02057468980949904, 0.04056791242744241, 0.03128378578860845, 0.027710959647915194, 0.050949637312442064, 0.021016344860462204, 0.04864401603117585, 0.021776321044723903, 0.022234579847593392, 0.044256286296461306, 0.05161484929599932, 0.014996153169444628, 0.04662723692932299, 0.04885924394641604, 0.06731515218104635, 0.02041548004906092, 0.14235047224376882, 0.10614595389259712, 0.10194166270749909, 0.20844886185867445, 0.11012132093310356, 0.13876797019370965, 0.13821737973817758, 0.25268036127090454, 0.10272760981959955, 0.1974347728703703, 0.14504916886133806, 0.12362401852650301, 0.06885033087538821, 0.05906747081982238, 0.17748364486864635, 0.1683382684631007, 0.21904257126152515, 0.122785037117345, 0.1414003875106573, 0.11247148125299386, 0.21273370193583624, 0.16957122087478638, 0.16924992097275599, 0.12944960807050976, 0.09761100116052798, 0.07197170731212411, 0.11169312694775206, 0.07187618993754898, 0.11783155506210667, 0.13481055040444645, 0.11598389063562665, 0.11948555202356406, 0.08909014160079615, 0.16690736024507455, 0.16766761802136898, 0.11090479139238596, 0.13920813586030686, 0.07068565274987902, 0.09857298739786659, 0.10778923678611006, 0.13194862540279115, 0.17991370947233268, 0.14969925076833793, 0.09601710883102246, 0.18925501964986324, 0.17897416917341097, 0.10521210650248186, 0.14174911379814148, 0.1366710662841797, 0.12154470224465642, 0.1377333535679749, 0.14944653718599252, 0.22543241695633956, 0.13837637406374725, 0.10253801356468882, 0.07222338952124119, 0.11572116187640599, 0.21750408810164246, 0.09510609414428473, 0.17498978440250668, 0.22406013416392462, 0.10872721645448889, 0.1750837615025895, 0.13554870150983334, 0.08691258701894965, 0.1428549766008343, 0.25166942551732063, 0.10449091198721103, 0.19941787288657256, 0.2768714374729565, 0.14743625505694322, 0.11652138536529881, 0.11349413530634982, 0.21558026490466936, 0.08397543283977679, 0.10596379438149077, 0.14758243864136084, 0.14435221840228352, 0.07709291643862214, 0.09827814357621328, 0.1190806430365358, 0.20566742468093122, 0.08956173022410699, 0.17018948841307843, 0.08246968899454389, 0.15201437153986522, 0.09783921284335, 0.0877788116091064, 0.14551262184977531, 0.07810436787882022, 0.11033999241356339, 0.1395635117909738, 0.10809125272291047, 0.09859322809747287, 0.11525036713906697, 0.16464896500110626, 0.1788894065788814, 0.1734969937907798, 0.1172890527439969, 0.10625253817332642, 0.09200423237468515, 0.0852390889610563, 0.17150610419256346, 0.20315653298582348, 0.10291230026632547, 0.0669852416696293, 0.14266348044787133, 0.1233255716839007, 0.08405151018606764, 0.20836316288581916, 0.11456978294466223, 0.24467956487621578, 0.08943200789924179, 0.10539817437529564, 0.1354441392634596, 0.07290528328823191, 0.0840104656027896, 0.17570197475808008, 0.11975398047694139, 0.14490229317120143, 0.14764504028218134, 0.10854017827659845, 0.16358240294669354, 0.06969978886523417, 0.18807895561414106, 0.10834879068923847, 0.090348606929183, 0.14532668968396528, 0.093693139962852, 0.12101730411606175, 0.12331377874527659, 0.266454242169857, 0.1296262985893658, 0.08073520420917443, 0.12100237634565149, 0.1595465445092746, 0.10719458905181714, 0.17382948952061789, 0.15320803677397116, 0.13980515168181487, 0.0768240469374827, 0.13106570206582546, 0.0661671794950962, 0.13510132980133804, 0.05994774108486516, 0.11484273044126374, 0.0629957475300346, 0.11399087043745176, 0.11924362714801516, 0.13022780631269726, 0.08073716517537832, 0.1519709995814732, 0.11664056325597422, 0.12402873752372605, 0.09947632106819324, 0.064405960429992, 0.12901256366499833, 0.1546908529209239, 0.12480732931622437, 0.15412249841860362, 0.08682941898171391, 0.10848579369485378, 0.06446689287466661, 0.13357340464634554, 0.1378457053963627, 0.10496870242059231, 0.16545940722737992, 0.11478345362203461, 0.0714791723127876, 0.1592711407159056, 0.10680843477270432, 0.13839462665574892, 0.10361805132457189, 0.08768910249429089, 0.1462771272552865, 0.13113001361489296], [0.020328944781795144, 0.020135681045108607, 0.004711736567384962, 0.033550292918724675, 0.03762819677857416, 0.052712528966367245, 0.04941137806911554, 0.04323785273092134, 0.05122970603406429, 0.05906629016888993, 0.021386300812342336, 0.026372018369979093, 0.053084830953074355, 0.056901400443166494, 0.020985446072050502, 0.022796852979809046, 0.05287351139954158, 0.03449587217931237, 0.10071550921670028, 0.02986017521470785, 0.04398578491860202, 0.024575698688360195, 0.024498812189059596, 0.03186394680025322, 0.04179984025124993, 0.04159694131729858, 0.043089026252606084, 0.02235473313235811, 0.031097117412303175, 0.012480526996244277, 0.022389886335336735, 0.05009318023387875, 0.10679467408252613, 0.019802484727863754, 0.014177364962441581, 0.020968340204230378, 0.05273143295198679, 0.008137840112405164, 0.032236571091094186, 0.06104641141636031, 0.0242267603586827, 0.010425026445383472, 0.04141117199989302, 0.03452634857967496, 0.04224602113078747, 0.06094640213996172, 0.06951685582420655, 0.005432784349458026, 0.034270869967128546, 0.02042758511379361, 0.01258022414653429, 0.05540661833115986, 0.007408685533196798, 0.03381154586427978, 0.07484279253653117, 0.046499794482120445, 0.03336615887071405, 0.034506063775292466, 0.03042913361319474, 0.020717153325676918, 0.048987432782139094, 0.03857998463458248, 0.018096517072990537, 0.04575366380491427, 0.018505120683195334, 0.026381122613591806, 0.015188020820330297, 0.027718567721811787, 0.037420945042478185, 0.01615103503822216, 0.05479459670771446, 0.02400073016594563, 0.018964365058179413, 0.048628436867147684, 0.10375459971172468, 0.07891961413302592, 0.05594225726755602, 0.02585874903681023, 0.02306913211941719, 0.029221602515982728, 0.002893355591887874, 0.04013767033549292, 0.030355387034692934, 0.014333270257338881, 0.0696533363578575, 0.015053397776292903, 0.03580426411437137, 0.03491982764431408, 0.01811999099196068, 0.029894037504813502, 0.03304735937022737, 0.03813290808882032, 0.025714224470513206, 0.024505209077947905, 0.04580221977084875, 0.022691563004627824, 0.03191881314186113, 0.030167687285159315, 0.017052026066396917, 0.039839420268046, 0.03428993001580238, 0.058215631172060966, 0.016718230941998105, 0.024514671248782958, 0.059201800397464206, 0.0237412956942405, 0.023580567711698155, 0.08345505754862513, 0.03418379696086049, 0.024563610587002974, 0.017400128101663928, 0.06663167064211198, 0.030339007199342762, 0.006313429505098611, 0.03836198829646621, 0.04233006787087236, 0.03471051316176142, 0.036654013874275346, 0.018624512312401618, 0.014658017117264015, 0.03526704079870667, 0.06938606819936208, 0.031399085851652284, 0.07053034965481077, 0.011414775791178857, 0.062400889449885914, 0.036444444941090684, 0.0777231329785926, 0.06831790480230536, 0.05886241075183664, 0.05908640194684267, 0.123260853013822, 0.03814407677522727, 0.0697678459276046, 0.039609770090984445, 0.004288955392049891, 0.016819118921245848, 0.021706033298479657, 0.03540048149547406, 0.017351451695763638, 0.018254437616893222, 0.03047883969598583, 0.0623501893132925, 0.014854356313922575, 0.009899989618653697, 0.04048579611948558, 0.02245632848436279, 0.04749411291309765, 0.0629754661183272, 0.025195265621212975, 0.04364428163639136, 0.009050100759070898, 0.04741910086678607, 0.014824972354940005, 0.010850954750951911, 0.03716748167893716, 0.03909384259688003, 0.06656246685556003, 0.045000157452055385, 0.029275983705052307, 0.06823766803635017, 0.0825409758836031, 0.06123098651213305, 0.042546547683221955, 0.025927981661100472, 0.06652776657470635, 0.058115486188658645, 0.041697218615029535, 0.06141543947160244, 0.06650556490889617, 0.06052466548447098, 0.06496928020247392, 0.07567856447505099, 0.07754876983485051, 0.06693387656871762, 0.012713877733663788, 0.05158996402419039, 0.05260444173057165, 0.01275985102568354, 0.030316846245633702, 0.058383717866880555, 0.03981922706589103, 0.08344970390732799, 0.08960372475641114, 0.028099578705483248, 0.03904517127999237, 0.007123660961432117, 0.058770286052354744, 0.03865769725026829, 0.11159680890185492, 0.0617795820747103, 0.00592336050301258, 0.07100267788129193, 0.03484919214887278, 0.04032055248639413, 0.029416331888309548, 0.028694757393428257, 0.019928132449941974, 0.009634404227004519, 0.033482961888824186, 0.020099871359499435, 0.02131749566511384, 0.01966014165165169, 0.05020645147721682, 0.02796786488033831, 0.008680161770566233, 0.013624850860131639, 0.017106268155787672, 0.05784726129578693, 0.0740320517548493, 0.02222031873783895, 0.06441245401012045, 0.05592746859682458, 0.025424065933163677, 0.06324438311691795, 0.0553493194415101, 0.00628249127683895, 0.05805003470075982, 0.02525088344035404, 0.054072516704244275, 0.030251211553279842, 0.08736650659037487, 0.0479372335997011, 0.013236371750411178, 0.03774277759449823, 0.04491710476577282, 0.013743120362050831, 0.014490659847589476, 0.03599802657429661, 0.06452511117926665, 0.031766244542918036, 0.03306818700262478, 0.047927690004663806, 0.035009553722505055, 0.022499905699597936, 0.008014685158351702, 0.03432819599817906, 0.007092141737562737, 0.0328755509108305, 0.05670144295852099, 0.06819828586386782, 0.005611031258013099, 0.0022851543326396495, 0.08300347213766404, 0.11203696778310196, 0.0849758784419724, 0.012134261246371483, 0.033896417024412324, 0.02597654950139778, 0.10723249880330903, 0.03617675948355879, 0.04482893253277455, 0.04375237226486206, 0.03270819703383105, 0.03937766022448029, 0.0353199393887605, 0.04769948510719197, 0.034829758905938694, 0.035926729507212124, 0.029141501457031285, 0.03229163420785751, 0.0265294266199427, 0.04095057225120919, 0.03294116863980889, 0.04123366723901459, 0.04245144421500819, 0.06051550526171923, 0.07306406726794583, 0.06278447886662823, 0.01098485685153199, 0.032764875063938756, 0.040673204098961184, 0.06715483471219029, 0.021882162329607775, 0.006526504767992134, 0.019151328597217798, 0.06917062654559102, 0.05098271928727627, 0.09882764837571553, 0.11529002072555677, 0.021171686971294026, 0.015160490958286183, 0.021338956031416143, 0.13282446483416216, 0.017535236298239658, 0.02650349640420505, 0.07176792967532362, 0.02247942751273513, 0.04728241677262953, 0.03186613507568836, 0.03583538173032658, 0.02863802168784397, 0.029957195544349294, 0.014284371631219983, 0.050658023317477534, 0.04789181925090296, 0.012200505772073354, 0.03051353319148932, 0.0507175783360643, 0.03252253628202847, 0.04944217338093689, 0.017601094907149673, 0.0839255740866065, 0.04044323501044086, 0.03835612914658018, 0.03670623053663543, 0.010339280823245645, 0.11024051917982952, 0.02813632307308061, 0.12436273960130555, 0.06644480209797621, 0.07159184983798436, 0.05621714876698596, 0.014362715284473129, 0.02219863954399313, 0.016655697154679468, 0.022366478573530912, 0.010490557661146989, 0.047442130345318995, 0.02131203345821372, 0.05193538923880883, 0.06550617103597947, 0.030601155811122487, 0.02520690080044525, 0.08626369719526597, 0.03236118743994406, 0.0032741483841424008, 0.05237128013478858, 0.03058215683060033, 0.07155503252787249, 0.025732724727796655, 0.013127985959207373, 0.035033014070774825, 0.02753360246840332, 0.012229971155258161, 0.02142754047443824, 0.026407064703692282, 0.05421651201322675, 0.017426987910377126, 0.05777830856719187, 0.017787403659895062, 0.033306139055639505, 0.06191410164215735, 0.05393592081964016, 0.02935983027730669, 0.06702586556119577, 0.010492423632448273, 0.07582413737795182, 0.07290500508887426, 0.02607712196186185, 0.0451727971168501, 0.04014422498377306, 0.20279776438006333, 0.13284119750772203, 0.0760356503139649, 0.11418144378278937, 0.19489558626498493, 0.13952323395226682, 0.2151138535035508, 0.12958070103611263, 0.12095637167138712, 0.14039950764604978, 0.0665078651426094, 0.2030078659632376, 0.0987921202821391, 0.14034534698086126, 0.15644985996186733, 0.12658258048551424, 0.19891665263899735, 0.2098019013979605, 0.24116678908467293, 0.08809158911130258, 0.11011972637580973, 0.1128510469570756, 0.12254189087876252, 0.14324893403266156, 0.10532547613339764, 0.11610114148684911, 0.07414147909730673, 0.12150890273707253, 0.09712903095143181, 0.14617540128529072, 0.05915484577417374, 0.12261187498058591, 0.12598880806139537, 0.14465293155184814, 0.09855259063520602, 0.17378998521183217, 0.10844661508287702, 0.10328668874821492, 0.13728322700730392, 0.22690538077482156, 0.07943532110324927, 0.14275002080414975, 0.09050559957644769, 0.12941638699599675, 0.10445493606052228, 0.1533348142568554, 0.13111641577311925, 0.12653094397059508, 0.12944073283246585, 0.13145034999719687, 0.10145916324108839, 0.13639005779155663, 0.12308258829372269, 0.11743432709148952, 0.14210154488682747, 0.17724613047071866, 0.09604102719042983, 0.13139697643262999, 0.1452159799103226, 0.15575352018432959, 0.10719825314091784, 0.2107368955122573, 0.22978995527539933, 0.15226164327136107, 0.1201277854187148, 0.10525254718959332, 0.06519597196685416, 0.13234934104340418, 0.20206414588860103, 0.20171153838081018, 0.12892280705273151, 0.09265851655176707, 0.13232458808592387, 0.20014647021889687, 0.11585556609289986, 0.14788520096668176, 0.18546895709420952, 0.1072199119787131, 0.1132558813052518, 0.16768086302493299, 0.12950488153312886, 0.11618348849671227, 0.1576116747621979, 0.13679090913917336, 0.21066206667040074, 0.15384816671056406, 0.12739815243652888, 0.11350904272070952, 0.14873569032975606, 0.11631785200110503, 0.13051659081663403, 0.09242462553083897, 0.11052912047931127, 0.05504069796630314, 0.08307471831462213, 0.11281277758202382, 0.09892381035855838, 0.0680406146815845, 0.06317927089652844, 0.0832382927515677, 0.14826779972229684, 0.11850668383496148, 0.12615188716777734, 0.17196232399770192, 0.12139148903744561, 0.10958364299897637, 0.1622292548418045, 0.2577665240636894, 0.11136463457452399, 0.10612982511520386, 0.10519052230353866, 0.09005984956664698, 0.1186136616660016, 0.10932136207286801, 0.12455187445240361, 0.15754703751632146, 0.1566843616643122, 0.17437356603997095, 0.10175336245447397, 0.1682955071862255, 0.18160816069160188, 0.1263721396348306, 0.11074376146176032, 0.19303129773054803, 0.16951625953827584, 0.16066760649638517, 0.3415574835879462, 0.15071228998047964, 0.11676784285477229, 0.10969641551907573, 0.17849553057125636, 0.21414299202816828, 0.08673641218670777, 0.2327492364815303, 0.11663206799754075, 0.16735912886049065, 0.10244759198810373, 0.12176807597279549, 0.1085696266964078, 0.07781438915325062, 0.07515541397567306, 0.11860200443438121, 0.14905230834015779, 0.09216975420713425, 0.14607827578272137, 0.1382925614182438, 0.08617515516068254, 0.10268023450459753, 0.1399251709559134, 0.06562414791967187, 0.14094560619975838, 0.15565150922962598, 0.07966538518667221, 0.0750075001269579, 0.16097065380641393, 0.08253477407353264, 0.1370909573244197, 0.14312829050634587, 0.101963199408991, 0.09299614879169635, 0.11386160951639925, 0.24402198301894323, 0.1922473862235035, 0.10116654501429626, 0.11057820570256029, 0.11428459467632429, 0.15385993250778743, 0.13778505793639592, 0.14342429462288106, 0.24328292267663137, 0.1544338102851595, 0.17336165319596017, 0.16486103433583463, 0.14100180247000285, 0.19054100635860646, 0.11955183132418565], [0.010832535069701927, 0.07288500187652451, 0.02834918799011835, 0.03554389665701559, 0.05011352949908801, 0.018577153960775052, 0.012660672954682792, 0.08249537154499974, 0.0259941608778068, 0.031795743852853775, 0.03364297740959695, 0.05486279286976371, 0.04984176265341895, 0.05993510676281793, 0.022725077545536414, 0.025315196685759083, 0.027788621373474598, 0.031721121964177916, 0.04412784640278135, 0.042397164806191406, 0.020011144424123422, 0.004708122944326273, 0.03318318172491022, 0.06629968381353787, 0.031402152829936573, 0.029924011789262295, 0.03169847246525543, 0.010693956166505814, 0.03453565129478063, 0.01445168988513095, 0.0665565568155476, 0.03645802242681384, 0.09182826110294887, 0.029266626707145145, 0.03176538280344435, 0.08120956804071154, 0.01215629667110209, 0.05437199152739985, 0.029562970091189657, 0.03369358255128775, 0.028519583400338888, 0.019912432845947996, 0.035590630756425004, 0.1025536877236196, 0.06058331805148295, 0.035457264698509655, 0.006654120241624436, 0.024344871253041283, 0.04019738141713398, 0.04784903422530208, 0.04484156346214669, 0.034292233642190695, 0.011614669663166361, 0.030124149085687738, 0.022948201912056123, 0.00816805612495435, 0.024033510192696537, 0.05088952589514, 0.03546819929033518, 0.030636979067432027, 0.033963130587445836, 0.014965999073215892, 0.04323722169335399, 0.034656603554529805, 0.044249198998191526, 0.04513341833704284, 0.027168981498107314, 0.029724875331989357, 0.06732837004320961, 0.025805894551532607, 0.017787417230595435, 0.02964520514277475, 0.0804556409961411, 0.059709561722619195, 0.026993459755820886, 0.012029532758918191, 0.02562098018825054, 0.02367698075249791, 0.017857370798342993, 0.011164995176451547, 0.04081129954595651, 0.08004388559077467, 0.06001565565488168, 0.011913128380131508, 0.025130299285852482, 0.047397849150002, 0.03055199594902141, 0.014902377933529871, 0.06446111854165792, 0.027421578033162013, 0.03058589555855308, 0.04656857757696083, 0.02316665286863489, 0.030511148140898774, 0.02748328570409545, 0.08377706312707492, 0.057112909986504486, 0.01858628025677587, 0.020361078503940786, 0.012735982708233808, 0.01187211602726685, 0.027238860427002822, 0.012361497535104198, 0.007018340876259441, 0.03889198521418231, 0.044101390322404246, 0.12036899104714394, 0.04385430858071361, 0.013480183801480701, 0.0227474505414388, 0.022496569003643732, 0.026525889756157994, 0.0530481561353164, 0.00273101545254966, 0.02757130696305207, 0.04286804775308285, 0.04732588372592415, 0.02743479928800038, 0.06209364200809172, 0.013093677532326962, 0.052210664110524316, 0.004314973817339965, 0.013075372353861374, 0.01437793652127896, 0.011743633725148226, 0.054413595902068276, 0.07315730476485831, 0.014275508267538888, 0.015465970816356795, 0.011987483943812549, 0.011556731254261519, 0.03542749058189137, 0.033966835388647657, 0.025936790741980076, 0.05443913935284529, 0.06678018838699375, 0.019176619293700372, 0.056752933588411124, 0.03396345967692988, 0.08953998996210949, 0.005610223801340908, 0.0252238947099873, 0.05502418242394924, 0.055959604015307765, 0.052364942617714405, 0.01699005376680621, 0.048511684739163945, 0.06307576716478382, 0.018955956312960813, 0.053587971454752345, 0.03123481591631259, 0.011869126232340932, 0.04043661250865885, 0.04516753847045558, 0.02579295149605189, 0.09924331214278936, 0.023985422415924922, 0.042999361242566786, 0.06799944117665291, 0.020290804328396916, 0.056279770763857026, 0.04069699353671499, 0.04533112647810152, 0.010647503659129143, 0.04757354900773082, 0.0712308624227132, 0.03949832749952163, 0.04049187918592777, 0.014668434326137816, 0.006283984053879976, 0.018539865068825226, 0.04077980195039085, 0.010279441668119813, 0.036436387337744236, 0.04003517083557589, 0.03337571264377662, 0.024351410634283508, 0.06500246056488582, 0.048161106051078865, 0.01850094260381801, 0.04028307699731418, 0.02891881644193615, 0.029921280685812235, 0.04259042515020285, 0.030030060027326857, 0.03592208832768457, 0.015625394315325787, 0.03853241254442504, 0.023930338943111043, 0.04246159509888717, 0.003844741839982037, 0.016121890262833664, 0.06107714905270508, 0.01814478975055473, 0.0707430432417563, 0.061160018534532616, 0.054192525800317526, 0.012881182416874384, 0.08707141171076468, 0.05603468052244612, 0.019460094261116216, 0.012043231532775929, 0.04037982252027307, 0.023659662842484455, 0.06561190036258527, 0.028984461312315295, 0.015608995820262601, 0.03114201607448714, 0.010906469093502631, 0.03252289929826345, 0.05952990600573165, 0.02067338951331164, 0.0594448380704437, 0.008654701440328998, 0.019597270293161273, 0.015667477057182362, 0.07845607972038643, 0.08010514373225824, 0.039441666432789395, 0.06246066838502884, 0.016438092670536468, 0.034680603338139396, 0.04276525309043271, 0.005288731789083353, 0.025129130509282862, 0.07885695142405373, 0.04839795209201319, 0.030594597770167247, 0.10089334645973784, 0.043203644387956174, 0.025678565758945684, 0.039051702179546864, 0.024263933899679353, 0.009544457624932485, 0.08121180720627308, 0.054981010633387735, 0.019888451722051417, 0.003338984737638384, 0.017459131810548048, 0.025436403396140252, 0.01560872610259269, 0.017276096989267638, 0.018128949350544384, 0.053666667946215184, 0.011503267783804663, 0.03263485757634044, 0.041204256138631275, 0.03215405444747635, 0.010525066255857902, 0.04580522907365646, 0.07363053544291429, 0.017915100557729602, 0.019834643895072595, 0.01976510084101132, 0.019064337015151978, 0.04397149836378438, 0.012020358965466065, 0.039276887596185715, 0.0470946729183197, 0.042052977917982, 0.03211289790592023, 0.0739671838070665, 0.06010292882898024, 0.01171301059158785, 0.1016144866922072, 0.021990502319697822, 0.03519202535971999, 0.023814373915748935, 0.01690657190712435, 0.036282342925135574, 0.04854628323976483, 0.06740165861057383, 0.042627004973058186, 0.0386752102390996, 0.044485620954739194, 0.06507168470748834, 0.039347058295139244, 0.042636470536568334, 0.03396422642150095, 0.007376065810344049, 0.06118590464549405, 0.009187802655755408, 0.033062117506882975, 0.07103078280176435, 0.0022660219775778906, 0.05543609389236995, 0.05196200477491532, 0.03654393513820001, 0.022574176446401646, 0.03056634357199073, 0.03578121088711279, 0.05127852323598095, 0.032467174609856944, 0.030701120982744863, 0.038161392988903184, 0.021682369389704297, 0.025966836272605827, 0.026833267815943276, 0.023416073859802315, 0.02836317429319024, 0.03435781065906797, 0.014069973225040095, 0.006667323260834175, 0.05337408703884908, 0.017945819534361362, 0.07863250561058521, 0.00808267097454518, 0.03852747959483947, 0.023863337002694607, 0.03335023704650147, 0.07681147368358714, 0.0482450781523117, 0.014293492838208164, 0.01379560080489942, 0.017687808289857845, 0.06045578060937779, 0.04332034901848861, 0.04248790529423526, 0.046278731165719886, 0.013079126348852046, 0.009653969784267247, 0.014045685064047575, 0.0019870931947869913, 0.02029326741051461, 0.02630852784828416, 0.021978295474712337, 0.06803477249507393, 0.011017181411651629, 0.02235796974439706, 0.02643635875678488, 0.04818341628249202, 0.07733164541423321, 0.08661631827375718, 0.025834457483142614, 0.060031180536108356, 0.018157003380890404, 0.021508594875090888, 0.03335077987451639, 0.021176996507814953, 0.017905299119385223, 0.06290506811014243, 0.04291847308299371, 0.03760918762002673, 0.030651608282434087, 0.04843159046556268, 0.04426797066948243, 0.0471679682710341, 0.05874648304390056, 0.045824021100997925, 0.020539093862420747, 0.06642852404287883, 0.013655493501573801, 0.09761524200439453, 0.14280646134700092, 0.18677823112479278, 0.12444691865571908, 0.1227973321718829, 0.09029019184942756, 0.11863964955721583, 0.14685477768736227, 0.16413648107222148, 0.10399765095540456, 0.12214981977428709, 0.19499173467712744, 0.1390963675720351, 0.20222559651093824, 0.06085112225264311, 0.12074016327304499, 0.17049035084034714, 0.09595028670238596, 0.1404617428779602, 0.11961640071656023, 0.1731387815837349, 0.0646307658670204, 0.11560575664043427, 0.18983952328562737, 0.08754061867616006, 0.08480414122875247, 0.146151761125241, 0.15200632411454404, 0.12186346442571708, 0.15333720270012105, 0.12270893262965338, 0.08236402752143995, 0.14635897214923585, 0.09871261633400406, 0.12777750779475483, 0.17383143013077124, 0.11174513665693146, 0.13844700955918857, 0.10083062946796417, 0.11001955425100667, 0.18414966788675102, 0.11566354068262236, 0.09271537100097962, 0.25398819680724827, 0.16428535165531294, 0.14724554600460188, 0.12203317960458142, 0.14197654516569205, 0.1359147440109934, 0.10309041570872068, 0.15748447658760206, 0.10892255990100758, 0.1866278541939599, 0.09503854598317828, 0.11768967338970729, 0.14900110608765058, 0.13808259554207325, 0.11538707837462425, 0.18222211274717534, 0.1334527339786291, 0.2077577875128814, 0.138975235500506, 0.16333343487765106, 0.11336880988840546, 0.13440899338041032, 0.20153214729257993, 0.08582984190434217, 0.09187724454594509, 0.1863911540380546, 0.1252994029117482, 0.0842852315732411, 0.1494770034083298, 0.16809094244880335, 0.12665198104722158, 0.1234322509595326, 0.0956231988966465, 0.12703329058630125, 0.12309519547436919, 0.1780557313135692, 0.1289584572826113, 0.12728778193039553, 0.17925369845969336, 0.12829430720635823, 0.2053739447146654, 0.1970651884164129, 0.23657047429255076, 0.12239947994904858, 0.06698711442628077, 0.22523984871804714, 0.11153744387307338, 0.10191427703414645, 0.11977044173649379, 0.16434986676488603, 0.15949663147330284, 0.07480692517544542, 0.16775734749223503, 0.12409353761800698, 0.1239191676889147, 0.19323507536734852, 0.19008409444774899, 0.1575604046561888, 0.20392994077077933, 0.1403889496411596, 0.1551836593342679, 0.12830855644174985, 0.11348222701677255, 0.24181318868483814, 0.13440796200718197, 0.07054541991757494, 0.1776911137359483, 0.15444519610277244, 0.11330336518585682, 0.10381988156586885, 0.07679674947368247, 0.13399504630693368, 0.19316613620945386, 0.22520524343209608, 0.16907035346542085, 0.19079857825168542, 0.10032910387963057, 0.16272795093911036, 0.10509861473526273, 0.10957813329462494, 0.054425989344183884, 0.15249054027455194, 0.1323117094912699, 0.2524545448166983, 0.13698596081563405, 0.08965617551335267, 0.17394987520362648, 0.0827334491269929, 0.1139051578938961, 0.12412237535629954, 0.08631892994578395, 0.12728856903101715, 0.20233642842088426, 0.15164781335209096, 0.11990730224975518, 0.14351797316755566, 0.18422737371708664, 0.14190998088036264, 0.08809192159346171, 0.10580897304628577, 0.12209841396127429, 0.12532814565513814, 0.09121113350348813, 0.13504754911575997, 0.13942472423825944, 0.11215423899037497, 0.1129421606393797, 0.14129317897771085, 0.0951980831367629, 0.10172786989382335, 0.06547622728560652, 0.15571944415569305, 0.2222944096262966, 0.17258649479065621, 0.15742069429584912, 0.17086467146873474, 0.1354168757264103, 0.2541060990520886, 0.07537240268928663, 0.1616226038230317, 0.07351971031831843, 0.12920948809811048, 0.1866543713424887, 0.16585606522858143, 0.12628812342882156, 0.0831303106887, 0.14613900466689042, 0.2227026027228151, 0.11108140727238995, 0.09470728518707411, 0.14897696381168707, 0.08984382437275988, 0.13565836633954728], [0.019323630690840737, 0.004838427537054355, 0.02835947458100106, 0.03935810145256775, 0.059408292174339294, 0.019634048587509563, 0.01922573844370033, 0.03262629107173, 0.03142967760296805, 0.01574937962660832, 0.04553664116454976, 0.04746584175154567, 0.019512782505314265, 0.07748313514249665, 0.02805121272935399, 0.03713571945471423, 0.01753615740952747, 0.04095324907185776, 0.013617196985121285, 0.02076538698747754, 0.07670575114233152, 0.09504264433469091, 0.04148618743887969, 0.03928597657276051, 0.03349625099716442, 0.03715648941163506, 0.07578749648694481, 0.008398054051212966, 0.06176340579986572, 0.04062490936900888, 0.05089108652568289, 0.09184219821223191, 0.03705327744994845, 0.007007398650914962, 0.017867090812485133, 0.05107564805075526, 0.03689583018422127, 0.014041901383149837, 0.009276840020902455, 0.055506261198648384, 0.04275500042630093, 0.026371465363938893, 0.02791177887203438, 0.012906054117982941, 0.052174518550080914, 0.07351226000381367, 0.016319783304684927, 0.01714505152111607, 0.02243182828117694, 0.03166938706168106, 0.04533901105501822, 0.055456894383366616, 0.034948773948209624, 0.052514230499842336, 0.041296262094484906, 0.02420755272864231, 0.015744419535622, 0.034402756818703244, 0.041027731860854795, 0.0200361331725227, 0.018190607827688967, 0.023785346187651157, 0.04309204573343907, 0.004667369707021862, 0.04201805032789707, 0.06175221675740821, 0.03871580020391515, 0.03253044800034591, 0.01913301324072693, 0.03289878734254411, 0.023123041726648808, 0.012485564270588969, 0.06836086963968617, 0.048070708223219426, 0.021090208486254727, 0.048374814047877274, 0.018179335664691668, 0.05950910212205989, 0.027930065390786955, 0.046297058396573575, 0.0297151146057461, 0.016066850894795995, 0.06699368264526129, 0.03916446112894586, 0.009223143304032939, 0.02618471047441874, 0.01185419931009944, 0.021995145195562924, 0.04049697159124272, 0.0071157551802960885, 0.03899738545130406, 0.013607537190962051, 0.042516739639852724, 0.014733303970258151, 0.07847982166068894, 0.03509934765419789, 0.04333455754177911, 0.01627778707604323, 0.04569509944745472, 0.05348418613097497, 0.008712398121133447, 0.039653121693325896, 0.03428208275831171, 0.08490788244775363, 0.060222371348312924, 0.05598547655556883, 0.038916487113705704, 0.037003561189132075, 0.05165575138692345, 0.044564473509256325, 0.061060436735195775, 0.039922018335866075, 0.044267454982868264, 0.023474985966458917, 0.024821691381345903, 0.014918569475412369, 0.06630131908293281, 0.03544550229396139, 0.024212399165013006, 0.009229667418237244, 0.02371088714737977, 0.019893109864954437, 0.03887219913303852, 0.056093367016209025, 0.05905113169657333, 0.011541063880680926, 0.07183891122362443, 0.023440806461232047, 0.014950952559177364, 0.02585589579705681, 0.02374664255018745, 0.08871157334319182, 0.04066365371857371, 0.0599111748327102, 0.08563396241515875, 0.01770823558659426, 0.06497860327363014, 0.02306694384398205, 0.04964025132358074, 0.03153036880706038, 0.0342319356277585, 0.04774318276239293, 0.03237383872536676, 0.02094239302511726, 0.05331962103290217, 0.04175516550562211, 0.044781614893249104, 0.054918266500213316, 0.006217982952616045, 0.012944820519935871, 0.08695780459259238, 0.02443425467104784, 0.04874162329360843, 0.013704400609380432, 0.006554858625999519, 0.03975205888439502, 0.032860239768134694, 0.02039030979254416, 0.02886510021718485, 0.04896974676687803, 0.03461320445473705, 0.012486385297961533, 0.03886741206848195, 0.08559293140258108, 0.022734042689470307, 0.04866962394277964, 0.05931327013032777, 0.030213970158781325, 0.04715725759576474, 0.024891366749735813, 0.09043363415236984, 0.011620032634320003, 0.03408046964822071, 0.03897739241697958, 0.024634732931320156, 0.08744641087417092, 0.02311721141450107, 0.035725682973861694, 0.015322475926950574, 0.01828295474738947, 0.03915566731510418, 0.05273560254967638, 0.013049126619340053, 0.011528274343748177, 0.016901949387309805, 0.021817978005856276, 0.027975347425256456, 0.022361009581280605, 0.0418615021210696, 0.04158997615533216, 0.01664874217073832, 0.026250390967886363, 0.01824931467750243, 0.03139827839498009, 0.0402217204682529, 0.015811453706451824, 0.04081974391426359, 0.05910075974783727, 0.10085409999425922, 0.04604784944759948, 0.015797033140968, 0.03981679112517408, 0.0740356140636972, 0.02620553471414106, 0.043877928384712765, 0.08589005510189704, 0.02632862775187407, 0.0556298529596201, 0.01743945599134479, 0.006325883591281516, 0.033533804517771514, 0.01603159591156457, 0.08119540701487235, 0.04014821137700762, 0.0391088144720665, 0.02245433019873287, 0.06939798327428953, 0.04315904088850532, 0.02507928871948804, 0.03557118733546563, 0.010928109271584876, 0.12147564095045839, 0.013891401467844844, 0.013814958560812687, 0.0293860319070518, 0.020897058404183814, 0.06637697573751211, 0.04154765253354396, 0.03177488907905562, 0.00862103168453489, 0.038346521090716124, 0.011475550476461649, 0.027134723961353302, 0.03802977076598576, 0.037890749118689976, 0.011584228037723472, 0.020576978168849434, 0.04309565553973828, 0.03730885784274765, 0.023252618166485002, 0.013835014359626387, 0.06521992425301246, 0.07320398118879114, 0.02554677559861115, 0.024617408235956515, 0.02217471948824823, 0.04955053881609014, 0.08631340667073216, 0.04107983656493681, 0.06774615762489182, 0.023745227804673568, 0.049150864726730754, 0.009864293587660151, 0.007859751864868616, 0.008502612056742822, 0.11093824316880532, 0.04124789951103074, 0.06704400958759443, 0.052403178066015244, 0.019932449628998126, 0.036562398076057434, 0.047121953418744464, 0.057165700010955334, 0.03795706234606249, 0.044870648865721056, 0.02385729125567845, 0.009890815825201571, 0.03264633160350578, 0.037168584298342466, 0.035447873773851564, 0.05827762891671487, 0.05831745892230954, 0.019632309841524278, 0.028126891436321393, 0.023953979103160754, 0.03394934954121709, 0.019164302186774354, 0.04888154060712882, 0.08254330325871706, 0.017487409757450223, 0.04244936450517603, 0.0050850902833709756, 0.015753654397225807, 0.028605485933699777, 0.042497157119214535, 0.022103047530565943, 0.033701619798583646, 0.03112689492159656, 0.04154800197907856, 0.020622019323387315, 0.009629345748440495, 0.05197035414831979, 0.045862616172858646, 0.061580825597047806, 0.013227363349869847, 0.03631483118182846, 0.04079597483256033, 0.008282465610786207, 0.03461715692122068, 0.019715771345155578, 0.06595664364950997, 0.061922196564929824, 0.009321665740571916, 0.031385542292680056, 0.0814879641735128, 0.02388501789287797, 0.03080634819343686, 0.07738386546926838, 0.05695144579346691, 0.04809670289978385, 0.05563189535002623, 0.07001746539026499, 0.0384936783728855, 0.02852551040372678, 0.08822043612599373, 0.027435761111389314, 0.053118109703063965, 0.0779428765443819, 0.062080912691141875, 0.06281907058187894, 0.03264176506283028, 0.07580480591527053, 0.04015671681346638, 0.042496780532279184, 0.013330961228348315, 0.03194325736590794, 0.009433333944928433, 0.007718917680904269, 0.011530435477782573, 0.03952176070639065, 0.03631219168060592, 0.03101775934919715, 0.021701656747609377, 0.04319999386955585, 0.016537901779104556, 0.05282459581004722, 0.03012544508757336, 0.013185876022492136, 0.05137026117050222, 0.048336880547659736, 0.0081694623887805, 0.0392924090847373, 0.04075654176995158, 0.03281797721449818, 0.028733861366552964, 0.03648775243865592, 0.04503675423828619, 0.011751444511381643, 0.07715517881193332, 0.0625035585835576, 0.02328218024090997, 0.05148459771381957, 0.1595461102468627, 0.1280513373868806, 0.06762206035533122, 0.14677099218325956, 0.14663519018462726, 0.18264147453010082, 0.09767965533371482, 0.10504067463002034, 0.12840565480291843, 0.12692429072090558, 0.10447243547865323, 0.19304733829838888, 0.1418532282114029, 0.13498938509396144, 0.1778983383306435, 0.22668423264154366, 0.11341630055436067, 0.1048474617834602, 0.12153873113649231, 0.12984075636735984, 0.13712316059640475, 0.13885786251298018, 0.22204781642981938, 0.19793312970016683, 0.10403837662722383, 0.08193720863865954, 0.21184757591358253, 0.07722400940422501, 0.2162044764097248, 0.17375247579600128, 0.14623709368918622, 0.10395550036004611, 0.12008224214826312, 0.13599453972918646, 0.08497855186994586, 0.1702851482800075, 0.1613154038786888, 0.08380269139472928, 0.04608479567936488, 0.06741867626884154, 0.1612406564610345, 0.10962438902684621, 0.09687706375760691, 0.11605216482920305, 0.15278212034276553, 0.19062035424368723, 0.09839931635984353, 0.09562187575336013, 0.11675245368054935, 0.0689760430582932, 0.1516537166067532, 0.1343741166804518, 0.11682825961283275, 0.14995759619133814, 0.10298377035983972, 0.15143030216651304, 0.11413519483591829, 0.1113834571359413, 0.10730554309806653, 0.11157770135572978, 0.0861248214329992, 0.09689173368471009, 0.0726597011089325, 0.15728078037500381, 0.1331550878073488, 0.11797548591026238, 0.13040820163275513, 0.10820024580295597, 0.14767725712486676, 0.11461356202406542, 0.19310487806797028, 0.1953326849532979, 0.17926540997411522, 0.13846199161240033, 0.09772523253091744, 0.133048557809421, 0.12137094299708094, 0.07368412613868713, 0.10346357604222638, 0.21531759042825016, 0.11605135058718068, 0.18177406250366143, 0.1481355396764619, 0.09153275910232749, 0.15016015246510506, 0.16647400707006454, 0.18168950346963747, 0.1084281996424709, 0.0799580712669662, 0.09891905382807765, 0.12934655217187746, 0.14746164583734103, 0.11936541061316218, 0.14597592556050845, 0.1742876770773104, 0.11168320676577942, 0.15992294145481928, 0.18055039245103086, 0.13731676020792552, 0.09664802426206213, 0.12543798690395697, 0.1020608473835247, 0.18587244115769863, 0.13374915878687585, 0.15272177143820695, 0.08485699910670519, 0.14638155379465648, 0.1373158102588994, 0.09743494846458946, 0.10253337917051145, 0.17221507829214844, 0.09412052881504808, 0.07176415023526975, 0.10389211161860398, 0.17075535947723047, 0.11622736257101808, 0.12116259203425475, 0.10336162615567446, 0.062373089870171886, 0.19561899958976678, 0.11939601254250322, 0.10787534287997655, 0.19154075985508306, 0.19778862888259546, 0.1757418590464762, 0.11897886278373854, 0.19200293719768524, 0.05986299206103597, 0.08503678374524627, 0.08783494681119919, 0.0935517129089151, 0.17536441715700285, 0.12549412889139994, 0.14136964987431253, 0.1861287374049425, 0.14640220840062412, 0.15217375941574574, 0.1291355820638793, 0.16716871836355754, 0.10521855937050921, 0.07400322758725711, 0.10385268873402051, 0.17989374697208405, 0.16785508367632115, 0.13032611246619905, 0.14922285133174487, 0.1029771478580577, 0.10927948967686721, 0.06911274072315012, 0.06197653364922319, 0.16518442412572248, 0.11001170360084091, 0.10867043664412838, 0.10751698818057775, 0.06822618722383465, 0.1388990224472114, 0.11284046859613486, 0.17887852287718228, 0.11671486284051623, 0.12357776957963194, 0.09873363734888178, 0.10660847050270864, 0.07320446973400456, 0.16041776990251883, 0.10676935794098036, 0.09210693543510777, 0.13202399707266263, 0.12326761122260775, 0.09627339829291616, 0.12072835676372051, 0.21219388661640032, 0.09583444041865212, 0.22973987939102308, 0.20335173393998826, 0.1294324275638376, 0.140254301152059], [0.009381253837740846, 0.019821923059810485, 0.01010805050775941, 0.033425903879106045, 0.043887034324663024, 0.05623476692874517, 0.02389520948885807, 0.07153809629380703, 0.02022110521128135, 0.03585034003481269, 0.031214436117027487, 0.02611178153061441, 0.005183410007573132, 0.018681073295218602, 0.014763103531939643, 0.012448639243042894, 0.0632365799642035, 0.09667201047497136, 0.06085522060415574, 0.09715642341013465, 0.013056107896513172, 0.01835626706347934, 0.03064320462622813, 0.04777424609554665, 0.048135474390749416, 0.02169400287259902, 0.012039810868113168, 0.026108892667772512, 0.060872889656041346, 0.06488638357924563, 0.04559190444914358, 0.10185137683791773, 0.025693931184442978, 0.04672886451174106, 0.04403891421056219, 0.014070662786252797, 0.015614569985440798, 0.004702435548616839, 0.10490081499197654, 0.025137634249404073, 0.0045524140004999936, 0.03299508842506579, 0.04347245960629412, 0.0619426408250417, 0.021840966772288084, 0.007599975581147841, 0.07955516395824296, 0.05807606330407517, 0.02113190107047558, 0.034882138416703255, 0.029977585521659682, 0.022227119355063354, 0.009904886945150793, 0.040314520310078344, 0.0739735077534403, 0.04333233194691794, 0.03657669820157545, 0.05231085319870284, 0.026116534668420042, 0.04286776616105011, 0.061273496731051376, 0.029250603102679764, 0.030212158470281532, 0.03875426635412233, 0.0179189682073359, 0.026750712156561867, 0.020785276545211673, 0.050413553935608695, 0.07464260434997932, 0.012508964398875833, 0.02963277438123311, 0.043327120797974725, 0.0510885809282107, 0.013112219349880303, 0.13599107920059136, 0.01451219994175647, 0.027230794341968637, 0.025494760800419108, 0.028515162744692395, 0.06996930975999151, 0.041908840116645606, 0.013889845926314592, 0.05003651916714651, 0.06306569091975689, 0.05082247645727225, 0.046386350212352614, 0.04391664559287684, 0.042603402132434506, 0.021820673486217856, 0.08837546780705452, 0.041041160068873844, 0.018265972712210247, 0.011341051265065159, 0.047435002334948094, 0.05478444243116038, 0.05683812705267753, 0.023148659816277877, 0.01947412806163941, 0.03857739602348634, 0.06353045348078012, 0.04732759024149605, 0.027739269825230752, 0.0554114664638681, 0.011997460953093, 0.08476312378687517, 0.053897766795541556, 0.03315268836117216, 0.023505937341334562, 0.020432825100475123, 0.05795994560633387, 0.05837446264922619, 0.009285276755690575, 0.04320622621370213, 0.008856804791970976, 0.07110477704554796, 0.03820599648835404, 0.01824442413635552, 0.03806396893092564, 0.049907570372202566, 0.017885440095726932, 0.03627344054569091, 0.023884719337469766, 0.05447357839771679, 0.009059317809130465, 0.019973841961473227, 0.02955654775723815, 0.08089820867670433, 0.046439822164497206, 0.010239774510929627, 0.02111385712799217, 0.033209122118673155, 0.04670723620802164, 0.05924524020935808, 0.031605316392545185, 0.03363495373300143, 0.030452003635998284, 0.04081251751631498, 0.017500429148120538, 0.04470015337158527, 0.03207709839833634, 0.014667845697009137, 0.06874589755066804, 0.027318802030224885, 0.01452652720867523, 0.03166663899485554, 0.030507317810718502, 0.012883760001776474, 0.02289903356826731, 0.02507869669768427, 0.046894002971904616, 0.01783714027676199, 0.04982945742085576, 0.029691104644111226, 0.04287090438551136, 0.06157464414302792, 0.06888541792120252, 0.05689961928874254, 0.053917223787201304, 0.04644746246880718, 0.030462663421141248, 0.06170056667178869, 0.03445314822186317, 0.029083079591925656, 0.04822683234566024, 0.033561064662145715, 0.034263250018869124, 0.01854494390343981, 0.05167010240256786, 0.04848787833803466, 0.04722674636702452, 0.023432258616334627, 0.02180246839166752, 0.015542947221547365, 0.08022476945604597, 0.028114034894055555, 0.03428036267203944, 0.019071558324087943, 0.012995405305576111, 0.07289967180362769, 0.018089999744136418, 0.05019021074154547, 0.05684055620804429, 0.01688005306225802, 0.017594711588961736, 0.05152773557763014, 0.01095450682831662, 0.03052149240725807, 0.016117847890460064, 0.017139306025845662, 0.04178648328940783, 0.0598312026954123, 0.026847963188109652, 0.03398361895233393, 0.01790451880411378, 0.0045002770660045955, 0.037674174311437776, 0.009811339018467282, 0.005996953562966415, 0.021911397010886242, 0.009998942076760744, 0.017859187575855424, 0.01500353223777243, 0.038878774137369225, 0.019567889726853797, 0.015835104044526815, 0.013646192482805677, 0.04072966839053801, 0.027315382213730897, 0.02473410777747631, 0.029254060238599777, 0.02024420254331614, 0.042720133904367685, 0.015067765755312783, 0.02946303884631821, 0.021260970305385332, 0.051264463990394554, 0.03625480458140373, 0.017707989617649997, 0.015369174403271504, 0.06413378646331173, 0.04200686128543956, 0.1020585810765624, 0.020432531634079557, 0.06146542036107608, 0.07562803397221224, 0.03402891116482871, 0.04294983157888055, 0.03395476085799081, 0.025379803397559693, 0.03365142856325422, 0.17971111248646462, 0.030668093290712153, 0.034889117149370055, 0.017722835963858024, 0.043256950099021196, 0.043494104873389006, 0.025082041875326207, 0.014440712884866765, 0.016824660856010656, 0.011789594294636377, 0.05011031324309962, 0.05764543105448995, 0.07866523813988481, 0.028181737421878746, 0.03547851302261863, 0.011446401460229285, 0.0625049156535949, 0.061892374950860224, 0.04860749049112201, 0.016716368363371918, 0.017938543942623904, 0.08862687181681395, 0.043207223660179546, 0.04066464777237602, 0.02566063716741545, 0.04312272908698235, 0.06534147701625313, 0.04983854300475546, 0.03820227811645184, 0.03409430497725095, 0.022719142060460787, 0.058720732639942846, 0.013285380638470607, 0.04319784291354673, 0.016277522447385957, 0.04169184461768184, 0.02354468677991203, 0.041102984787098, 0.009239164363992, 0.04288875324917691, 0.024237778071048002, 0.011478249349498322, 0.033788309432566166, 0.044878706469067504, 0.07526932643460375, 0.045747974288782904, 0.029548479975866418, 0.014600238164088555, 0.09096804154770714, 0.039452645129391124, 0.06839253008365631, 0.09207330045423337, 0.05607323148953063, 0.023546881840697358, 0.017658775472747426, 0.04021043982356787, 0.06493096332997084, 0.014676400327256747, 0.020614709804898927, 0.06505987819816385, 0.023314517523561205, 0.012503212966424013, 0.0340127484606845, 0.01857772223385317, 0.031694384291768074, 0.0385257086184408, 0.008190745487809181, 0.006183338650901402, 0.022502892950017537, 0.03508542411561523, 0.025772931320326667, 0.04980319133028388, 0.060141591754342826, 0.028480452285813432, 0.01720604164126728, 0.05747899998511587, 0.019418666305552636, 0.06743151415139437, 0.05018893848838551, 0.04041164241997259, 0.021645423157938888, 0.06853639307831015, 0.01872343593277037, 0.010128227594707693, 0.0626796723476478, 0.03971829158919198, 0.019156142803175107, 0.03239397764472025, 0.015171167706804616, 0.026822272155966078, 0.022109317194138254, 0.07597600030047552, 0.03334176214411855, 0.0110363228845277, 0.05331494592662368, 0.0287587941358132, 0.030993908843291656, 0.022022113569879105, 0.0486509167323155, 0.021592390557218875, 0.021987431948738437, 0.030382250236081224, 0.018913437612354755, 0.024084340947281038, 0.04161777234237109, 0.05262536435787167, 0.006309635646175593, 0.06908625071602208, 0.017499046633020043, 0.058677258901298046, 0.006863486038387886, 0.01534786501101085, 0.017835528756092702, 0.00922765301740063, 0.021034709410741925, 0.03777264331334403, 0.02449133642949164, 0.03150949028453656, 0.036884284910878966, 0.02664246376869934, 0.015487074951774307, 0.005099529084483427, 0.1491101873772485, 0.15623382798263005, 0.17840772813984326, 0.09674092249146529, 0.1396783199161291, 0.10165584340159382, 0.08006251137703657, 0.11318636539259128, 0.24321946608168737, 0.11647231371275016, 0.08200054309730019, 0.08667180886758225, 0.07889691035130195, 0.12715362198650837, 0.14513850478189333, 0.04941708454862237, 0.1702236458659172, 0.17472307942807674, 0.11199318870369877, 0.22331709760640348, 0.1408004539885691, 0.11609802022576332, 0.07924445598785367, 0.1078572870631303, 0.14393147240792, 0.08590005670807191, 0.14627674727567605, 0.0765459697161402, 0.13241239051733697, 0.189956380586539, 0.14392734691500664, 0.1696051476257188, 0.11652667793844428, 0.06955987494438887, 0.08297422727836029, 0.22321359387465886, 0.11497661897114345, 0.14611525594123773, 0.18017528472202166, 0.16043064849717276, 0.1477044935205153, 0.09630010543125016, 0.1343480066529342, 0.2230190850262131, 0.10965493667338576, 0.2532134455229555, 0.14067265870315687, 0.218561109953693, 0.19751212586249622, 0.10521444744829621, 0.15885240318519728, 0.14403094564165386, 0.10241709862436567, 0.04900638087253485, 0.21014947417591298, 0.11887311988643237, 0.08943661515201841, 0.08685297771756138, 0.12008746686790671, 0.09858893297080483, 0.14691986276635102, 0.1424821758908885, 0.14293705219669, 0.08360390777566604, 0.10627031579081501, 0.14273598869996412, 0.1370424556412867, 0.15842008138341562, 0.13483248065624917, 0.1188804344939334, 0.11959016855273928, 0.11584553734532424, 0.1179334574512073, 0.0855294137394854, 0.20421673038176127, 0.11640052470777716, 0.09696002144898687, 0.1391491847378867, 0.1271603259124926, 0.13457714792873177, 0.16358187368937901, 0.1962273876581873, 0.19957671793443815, 0.16825324802526406, 0.16722814446049078, 0.1408932368670191, 0.16348031056778772, 0.19813803370509828, 0.11372361584965672, 0.15554234651582582, 0.12013811272169862, 0.10093942577285425, 0.13437227106520108, 0.17557502085609095, 0.1766391537551369, 0.0902515153533646, 0.1387404352426529, 0.11256959741669041, 0.15712471732071467, 0.18803426729781286, 0.11586536413856915, 0.09998109683926616, 0.1978618020990065, 0.1502927110663482, 0.16348792373069695, 0.16403326232518467, 0.13775350605802877, 0.07544032404465334, 0.10888629220426083, 0.0832898546276348, 0.1497034305440528, 0.0866170171648264, 0.09974760615399905, 0.13015398170266831, 0.1344716628747327, 0.10808284567402941, 0.09941793991518871, 0.10471630774970565, 0.06987732076751334, 0.14729887885706766, 0.09797776290880782, 0.11423686652311257, 0.15429100580513477, 0.12369659463209765, 0.10884736465024096, 0.15340277632432325, 0.1835719496011734, 0.1682866590895823, 0.12580265876437935, 0.08535494881549052, 0.16135538316198758, 0.14701981097459793, 0.11526142725987093, 0.08547356352210045, 0.09300026071390935, 0.21178441787404673, 0.09817609869475875, 0.1496925332716533, 0.10341244164322104, 0.14991342356162413, 0.2070240740265165, 0.10190511681139469, 0.08086187312645571, 0.11515271237918309, 0.07878900971263647, 0.14572394479598316, 0.13695720450154372, 0.08823251404932567, 0.10019123913454157, 0.1563726155353444, 0.14315368128674372, 0.11029458485011544, 0.12651851320905344, 0.17702647511448177, 0.14222503826022148, 0.1980821495609624, 0.09283969897244658, 0.12863286903926305, 0.12498045074088232, 0.19157844569001878, 0.10439541496868644, 0.1265810877084732, 0.18444896968347685, 0.12156648321875504, 0.10765544325113297, 0.1712534720344203, 0.1306423776383911, 0.11045345025403158, 0.1359831674822739, 0.14830908179283142, 0.12060760467180184, 0.1322075000831059, 0.09290914703160524, 0.19057132330323967, 0.09412569246654, 0.08077535312622786]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.021323950229478732, 0.048625519166567495, 0.034174056590667794, 0.045478151445942264, 0.035415175171302896, 0.0495484489282327, 0.055388026471648893, 0.08564103275005307, 0.029201463596629243, 0.05030550401923912, 0.03606153066669192, 0.03522221338269966, 0.031543617203299484, 0.0499281367686178, 0.09138391566063676, 0.04709830986601966, 0.07372185268572398, 0.013425101176835597, 0.027210523108286516, 0.045977118957255564, 0.0365583981121225, 0.07333607160087142, 0.027626631315797567, 0.035177324898540974, 0.05011431659970965, 0.008077615040487476, 0.02595807468917753, 0.026474797765591314, 0.025992013314472776, 0.08317594895405428, 0.06987592298537493, 0.0591557142989976, 0.013884355729844953, 0.043087699716644626, 0.013738816753695053, 0.011110532563179731, 0.013418527020673667, 0.051470066886395216, 0.013329511707914727, 0.04408762623955097, 0.054546639655849764, 0.038483127153345516, 0.0746708381921053, 0.035839592040117295, 0.018829502830547944, 0.0540543794631958, 0.04283597679542644, 0.07240435481071472, 0.02668225984754307, 0.06938676709043128, 0.06077002374721425, 0.03994126837434513, 0.03163499212158578, 0.06695777457207441, 0.008561610676614302, 0.04049797582307032, 0.03114924586511084, 0.03267571895516344, 0.039530544342207055, 0.049299124628305435, 0.046376552166683335, 0.014096576886783754, 0.00945318618323654, 0.025186880624720027, 0.042194486396121125, 0.011102630174718797, 0.01357831438404641, 0.0464194423652121, 0.01982840646191367, 0.01812761602923274, 0.020093581339876567, 0.02370707886958761, 0.053311319156949005, 0.03830902185291052, 0.02316681232436427, 0.03769047272258571, 0.01688105390141053, 0.028275156426908712, 0.021006288971485834, 0.049896751131330214, 0.01581563687484179, 0.055588469108832736, 0.06407296936959028, 0.06585842570556061, 0.05043487689856972, 0.040883719588496854, 0.05097059725916811, 0.008352288560542678, 0.00940456660464406, 0.024982114023129855, 0.05091339336442096, 0.055242708019380055, 0.0067461261974780685, 0.026232223192762052, 0.01459137480040746, 0.024721408994602304, 0.008290185642960881, 0.020028709999418685, 0.08707901808832373, 0.0197565021059875, 0.05184469285554119, 0.06041128228285483, 0.04989515996671148, 0.012595098482311835, 0.008675036286669118, 0.0258581112138927, 0.016027543361165693, 0.05187781893515161, 0.05991349542247398, 0.021383355970361402, 0.020708122024578706, 0.01773836593409734, 0.013428124898512448, 0.04687412189585822, 0.07056684805346386, 0.007543049885758332, 0.02899551804044417, 0.03287873324006796, 0.027516542401696955, 0.020353187141673904, 0.08440010755189828, 0.07385326456278563, 0.022688730120924965, 0.03062426671385765, 0.011088413169740565, 0.03598806228754776, 0.038295318838208914, 0.04439546739948647, 0.05478430672415665, 0.08495284896343946, 0.022868619932393943, 0.009127939751903926, 0.037112815505159755, 0.056796990867171965, 0.02335344168490597, 0.03665906556748918, 0.009885923587717116, 0.006807793156310383, 0.07635705878159829, 0.01606638270563313, 0.052455428655126264, 0.07694925700447389, 0.02203053079678544, 0.017453050440443412, 0.09773376171610185, 0.01712342321739665, 0.06962589640170336, 0.0422939019543784, 0.06593670829066209, 0.024146253875057613, 0.03943986492231488, 0.11046286153474025, 0.030224979389458895, 0.07016131481421845, 0.0023218147315284504, 0.0029533575954181807, 0.02064313194049256, 0.06887079549155065, 0.04776640223073108, 0.08156210090965033, 0.04595378753063934, 0.03548226532127176, 0.020222525045807873, 0.018179469675357853, 0.031130935597632612, 0.030374840633677583, 0.0804917865565845, 0.033403637752469094, 0.03162070556676813, 0.006563104522813643, 0.059474815747567585, 0.06580106235508408, 0.033568755856582096, 0.09413050327982221, 0.023262874223291874, 0.020393997630370513, 0.0893640254757234, 0.032687159055577855, 0.03449287983988013, 0.02067573894081371, 0.042237010185739825, 0.06565347420317785, 0.050007277700517855, 0.024588024276973944, 0.03357319347560406, 0.030311614740639925, 0.02231832972860762, 0.0162856343335339, 0.026483442301728895, 0.006479165500162968, 0.0190223051634218, 0.03031050194320934, 0.03508973281298365, 0.043068707521472654, 0.039167392400226424, 0.022930317425302098, 0.052436087014419694, 0.05720106525612729, 0.025613816554791162, 0.05872358248702117, 0.021605014701240828, 0.0189734574274293, 0.014363276772201061, 0.01918753013680024, 0.04990345166463937, 0.09112124796956778, 0.03895521789257016, 0.11652021828506674, 0.01255815479505275, 0.011177699048338192, 0.009375658468343318, 0.053045696445873806, 0.07021464088133403, 0.059925037303141186, 0.037494878218110116, 0.06441983647112336, 0.05637490476614662, 0.06510569966797318, 0.045555063390306065, 0.07470594559397016, 0.02656298696196505, 0.06839698127337865, 0.06320289748587779, 0.042052774357476404, 0.028967145098639385, 0.018448980392089913, 0.03437414978231702, 0.040073667519858906, 0.021132973155805042, 0.05993189729217972, 0.041928015516272614, 0.016469700528042655, 0.013158536150253244, 0.06212932616472244, 0.03334623368989144, 0.010866404145157762, 0.020391907742513076, 0.0330687807207661, 0.05542984797752329, 0.036280941750322065, 0.05540025367268494, 0.055139221251010895, 0.07421645721686737, 0.004967088378699762, 0.022967002421085323, 0.017771899134718945, 0.039203035844756026, 0.03331511268126113, 0.04102942141305123, 0.027768892967807393, 0.03099319977419717, 0.028238257692594613, 0.04293877145807658, 0.07128546413566385, 0.044387464078941515, 0.011845369025000503, 0.051571741966264587, 0.0545161496847868, 0.010688576231976705, 0.06343229660498244, 0.0456459633340793, 0.023516485168199455, 0.05147020598607404, 0.04022580524906516, 0.023209441286910857, 0.044933542276599577, 0.03863028782818999, 0.06285672249006373, 0.028784714173525572, 0.06629892385431699, 0.05826713876532657, 0.019753392719264542, 0.009547643346845039, 0.03933535356606756, 0.04179301418896232, 0.004228051785113556, 0.058668668647961955, 0.023063140655202524, 0.04710751758622272, 0.03586234671196767, 0.10882634363536324, 0.012475918895298881, 0.006491975817230663, 0.05408039788848587, 0.028586775330560546, 0.03784193191677332, 0.04725084453821182, 0.003665459741439138, 0.02997651682900531, 0.028431160109383718, 0.01246342367293047, 0.039485496402318986, 0.01096484430932573, 0.03814784264458077, 0.06293748851333346, 0.018114197999238968, 0.04312584017004285, 0.030146985181740353, 0.010875021539894598, 0.07626521228147404, 0.04933864250779152, 0.04320067918992468, 0.045519518333354166, 0.06432980844484908, 0.03112616888912661, 0.02200329440113689, 0.02801062785355108, 0.02687285015625613, 0.0060527961468324065, 0.05192143177347524, 0.019847320625558496, 0.03443120439936008, 0.013722991620722626, 0.04773057218907135, 0.06955095220889364, 0.03030820170949612, 0.020224038178899457, 0.10611747577786446, 0.03790171763726643, 0.0179520756272333, 0.04846833313682249, 0.018853375388841544, 0.035132948708321364, 0.01670725054905883, 0.0029770168392652912, 0.020783910993486643, 0.019413037857572948, 0.05206035164051822, 0.034305641494159184, 0.05591452554134386, 0.011167868772255523, 0.013941273791715503, 0.05048633360170892, 0.03754106948950461, 0.046203278071646176, 0.016397473867982626, 0.01763469765761069, 0.0031440314487554133, 0.04684217646718025, 0.02315634592170162, 0.04934566534523453, 0.04820365019674812, 0.04106213358630027, 0.06429177655705384, 0.015921198264030472, 0.014498483356354492, 0.14174367194729193, 0.050914953994963846, 0.0276598489976355, 0.04130266407238586, 0.03040839758302484, 0.008402561220074338, 0.2613482118717262, 0.2232683923627649, 0.07697427459061146, 0.13157104780631407, 0.15404582396149635, 0.20844450566385472, 0.12678728092994007, 0.12731936095016344, 0.08995256639484848, 0.1129732375432338, 0.07669165118464402, 0.09835970348545484, 0.13142745622566768, 0.08750053082725831, 0.20435948057898454, 0.11448215693235397, 0.17624192578451975, 0.10047431037362133, 0.13503249920904636, 0.10149526130408049, 0.10216882266104221, 0.17054813488253526, 0.11678722181490489, 0.19411474173622473, 0.13820560037025384, 0.08446135212268148, 0.15119061645652565, 0.06534388581556932, 0.14911743413124764, 0.16504056113106863, 0.17058879270085267, 0.1647860969283751, 0.1763941619013037, 0.09821406272905213, 0.14077025918023928, 0.12802956998348236, 0.18993295755769524, 0.17219697497785091, 0.14456305280327797, 0.13296949490904808, 0.17574925507817948, 0.08768566910709653, 0.17365540457623346, 0.15176549846572535, 0.1513667098645653, 0.1269892400928906, 0.14520923527223722, 0.13419070866491112, 0.12286557922405855, 0.09860527887940407, 0.19633911523435796, 0.1815270757568734, 0.08190537856093474, 0.11231824090438229, 0.09163584214236055, 0.1694965548813343, 0.12227951495775155, 0.18316636207912648, 0.18120900568153175, 0.17004903166421823, 0.1502895083810602, 0.12239558515804154, 0.1014600114098617, 0.09537205273019415, 0.13564224434750421, 0.24571718062673295, 0.13971454011542456, 0.12515297505472386, 0.10032237959759575, 0.13482767662831716, 0.15093573156212056, 0.09181108738162688, 0.21074935341519968, 0.14271785824426583, 0.1197755578905344, 0.0966303755662271, 0.15195265199456895, 0.15213087600256714, 0.11482991970011167, 0.08711055639599051, 0.23158196625964983, 0.15983584469982556, 0.11125246595059123, 0.23067481922251837, 0.14462497590907983, 0.0827783817159278, 0.20917671280247824, 0.09550664693649326, 0.15460808521934918, 0.08522551826068334, 0.11067973489740066, 0.25284733516829355, 0.07164940317826611, 0.12897966828729424, 0.17846752064568655, 0.14585081727377006, 0.08716175864849772, 0.09342484721647841, 0.14042371777551516, 0.07984134288770811, 0.1493018599493163, 0.14983113083456243, 0.16875723669571535, 0.12193023227155209, 0.11729445388274533, 0.07447436837745564, 0.07614212602909122, 0.11721832225365297, 0.126141614147595, 0.11326656144644533, 0.13627382474286215, 0.15572120834674152, 0.08959607088140079, 0.17599426050271305, 0.12805915411029542, 0.08192235550710134, 0.09825799108615943, 0.15902837445693357, 0.1373269110918045, 0.11339317608092513, 0.24396946440849984, 0.14045252837240696, 0.05374825160418238, 0.2303513480084283, 0.15274022759071418, 0.21878292305128916, 0.07692213595977851, 0.1300182339868375, 0.1619553438254765, 0.1623742442045893, 0.08634468034974166, 0.13895699647920473, 0.1242019132311855, 0.16627651266753674, 0.10870711146188633, 0.07036966577704463, 0.08891303039022855, 0.09815166464873723, 0.1897748046155487, 0.08147729760301964, 0.1426817194691726, 0.20053997981761182, 0.1243342547012227, 0.11593924303139959, 0.1703472478049142, 0.05091604982901897, 0.20155105127819947, 0.10695652504052434, 0.10120670071669988, 0.17696955959711755, 0.1273859930889947, 0.17664222073342117, 0.0684228538136397, 0.20449734532407352, 0.11517015072916235, 0.10143856291792222, 0.15291364757078035, 0.1794603123728718, 0.14682394505611487, 0.1506760697811842, 0.12649894425911562, 0.0928818563531552, 0.06740375528378145, 0.08505356391625744, 0.1768481425408806, 0.18335146643221378, 0.15099215853427136, 0.22760083845683507, 0.11303338967263699, 0.0673333504902465, 0.15580042052481854, 0.19876623499606336, 0.1281424103570836, 0.21739930872406277, 0.10422453270959002, 0.09958656265267304], [0.017572219849431088, 0.03516570498634662, 0.07584475127181836, 0.025469697413167784, 0.019579477408634763, 0.02463374735920557, 0.025130282322477018, 0.1386873602334942, 0.04012704108442579, 0.02487313960279737, 0.0277411273148443, 0.029646060096898248, 0.06741481540458542, 0.01915162375995091, 0.026940601877868176, 0.02471860494863774, 0.031951131764799356, 0.05297482007050088, 0.01978657308167645, 0.03815411230815308, 0.06733310621763978, 0.014704702022884573, 0.0051879214172783706, 0.005766362342650869, 0.04499148916719215, 0.03498480755037495, 0.02728698043418782, 0.022258404908435683, 0.06369208052222218, 0.03736544427062784, 0.022934410687802092, 0.014606304267155272, 0.017803193169779012, 0.02301207071702395, 0.07481080639575209, 0.02577609838252621, 0.06831601847495351, 0.037027055464152775, 0.02389335199924452, 0.022492005855643322, 0.010317877284251153, 0.020379056289259876, 0.03418087247493012, 0.08812082039990596, 0.05235462549275585, 0.019513937711183513, 0.04292522111375417, 0.02035443564610822, 0.037022458389401436, 0.02015359267326338, 0.0545412486951266, 0.07805017328688077, 0.017210889773975526, 0.0530912329309753, 0.07499753923288413, 0.011207323039083608, 0.01711637493489044, 0.022355060525504605, 0.02191163449814277, 0.026157730225739733, 0.02747725522411721, 0.04289138935772436, 0.02230384639863457, 0.046699273599577804, 0.029807127346949916, 0.034667134418019226, 0.014152068328777594, 0.014637728920206428, 0.008775311888062527, 0.024389695276373198, 0.02081220760010183, 0.04240459476464561, 0.023004723879109536, 0.016135147140760506, 0.05246303164001022, 0.05261611592556749, 0.008499380533716508, 0.014002717682160437, 0.039474005411778174, 0.08766256498971156, 0.06603630366069929, 0.0354237111418375, 0.022046759658093964, 0.0940815130514758, 0.05646183867273586, 0.058861338666507175, 0.033798650306250365, 0.08057444569255624, 0.057228878406541686, 0.061245771790189404, 0.03232271789706179, 0.0409753184233393, 0.02648663820166673, 0.04739698062517813, 0.09196909783141953, 0.0879242013075522, 0.01306598906272224, 0.003606837708503008, 0.018522650635402118, 0.03133008223293083, 0.038627024074750285, 0.06497055584830896, 0.012579984962940216, 0.02610683670666601, 0.023710117010133605, 0.0173070161337299, 0.05853980127722025, 0.07064292539975472, 0.011800695127541465, 0.027978692602898394, 0.01908305609997894, 0.013067188373367702, 0.0390540940154876, 0.01638881745748222, 0.09310195275715419, 0.03666082975853767, 0.006275800497470689, 0.07440050984067575, 0.05904374923557043, 0.020583522639104297, 0.06100785705660071, 0.06061512777315719, 0.05571470037102699, 0.044926319271326065, 0.026230128215891973, 0.018212261576471583, 0.02877667692622968, 0.03692047457609858, 0.01695108550068523, 0.013123477094008454, 0.008262698189355433, 0.027623272567455257, 0.019732683830495392, 0.006225018512590655, 0.02848786867356726, 0.03689136203112347, 0.022468158742412925, 0.019027772459334562, 0.01788223401776382, 0.023556954693049192, 0.06101440491953066, 0.019521062328879322, 0.06746822289590325, 0.0294645994768611, 0.025851787267518894, 0.028798895555415323, 0.02437023149936327, 0.05858765835208552, 0.04015626558767898, 0.028838952870241234, 0.060198147648147175, 0.0405323266583894, 0.03132370061108044, 0.04709664745522397, 0.016825470009020398, 0.062115633328046115, 0.051189465514783344, 0.048127901939941306, 0.01697938041096287, 0.004275107764572437, 0.02803239525694932, 0.021890128330726708, 0.09112221827464444, 0.01727687900087663, 0.13043872213789395, 0.06112564395048788, 0.030520026771617786, 0.01859581028111279, 0.060242333848561556, 0.027436388756281564, 0.0319575337427003, 0.02126958261110953, 0.027670200049344982, 0.03467913770249911, 0.10835493821650743, 0.018307063096602048, 0.06576973439327308, 0.035774344112724066, 0.02306279120966792, 0.04391810444316693, 0.03287311836278864, 0.04767851158976555, 0.08040883565055472, 0.010789392965047486, 0.014791491740782346, 0.015383099638191717, 0.020039252737270932, 0.011568754046623195, 0.0301074503388788, 0.044335026892700365, 0.023330339263858538, 0.00691749360911282, 0.04086105991154909, 0.028387889931244508, 0.041734507506979365, 0.07417848639722381, 0.05532112631148525, 0.024530978141618625, 0.02210973110049963, 0.040229985024780035, 0.03719416167587042, 0.014406336604484489, 0.09097956985767398, 0.02554689264590187, 0.038639651611447334, 0.07640193030238152, 0.01594248560390302, 0.002316713208399181, 0.038513993711343834, 0.04735922693674054, 0.03933763683640531, 0.05216489013816629, 0.0400141294646476, 0.033996616290616136, 0.07017753858651433, 0.006340180324124438, 0.04172948295516627, 0.04295303765684366, 0.04467856917264206, 0.05072804813140205, 0.05359750487176435, 0.04597211476149304, 0.055740332031356435, 0.039759848466409106, 0.06282713157790047, 0.04633311574746456, 0.0712148014988218, 0.038874801314835034, 0.009293249542159694, 0.05856039481503623, 0.029964466047074114, 0.016060082507984977, 0.01235489284486643, 0.012309151102921792, 0.06750364242387669, 0.024177317208211337, 0.0395950832005058, 0.046732138443206034, 0.025138049852102995, 0.06658067873546056, 0.036791844692613394, 0.07609868621719734, 0.06604239011981658, 0.05751069435583694, 0.010377308470197022, 0.02703364599230034, 0.027785115043765733, 0.03489676084635513, 0.05315813309113894, 0.025096918755610074, 0.045788367478443046, 0.08312488919390099, 0.03479517058336309, 0.03134910835485373, 0.05373454519680568, 0.03708366224808352, 0.017109277458595376, 0.10446763145072119, 0.006915427045896649, 0.053823982897613726, 0.03558933475453939, 0.04420141316950321, 0.020896705565974116, 0.01790843904018402, 0.029101885189967494, 0.0836446402328355, 0.04566597333177924, 0.01896791040365185, 0.020694814256525466, 0.05627620166965893, 0.06141547339835337, 0.03293691422524197, 0.06200837729764836, 0.01709587299930198, 0.04571792875815715, 0.0073280145048296875, 0.028479980703975474, 0.07173822341220719, 0.03840241880555238, 0.05551885820126959, 0.015379717141123754, 0.05426536653456943, 0.056878035089799335, 0.05130491146285619, 0.03399001414488469, 0.024369902409879223, 0.010670707012260599, 0.05300656533134835, 0.056047881421233924, 0.0369130819370704, 0.04202309523576072, 0.04306566768458911, 0.010120087718990232, 0.06538337655365467, 0.038489339141441245, 0.034182117586689334, 0.0068171471856268385, 0.04702019691467285, 0.039537278802267144, 0.027081016218289733, 0.02974461391568184, 0.02059225708113185, 0.029288326257041523, 0.047158618058477125, 0.07450277185333626, 0.030065052078238556, 0.025122421494285976, 0.023925071815028787, 0.04751771914639643, 0.008753069510151232, 0.10816616298896925, 0.04210808174684644, 0.010442580146315907, 0.022902441510398473, 0.05496868843744908, 0.009124856658412941, 0.016309961510289992, 0.027032025989943316, 0.039568111433514526, 0.026845221906634312, 0.10937031837446348, 0.02201641387572246, 0.03806945149387632, 0.06531834575746741, 0.05428407035235848, 0.039015210566243956, 0.040452717537326474, 0.028750451547758918, 0.014407595286944082, 0.019493613891037445, 0.013190258510543831, 0.03918538375624588, 0.0015074005308893643, 0.09090433389480625, 0.017221617412620356, 0.01256228452881, 0.05621935739847166, 0.05485796170043094, 0.03903353440442255, 0.020875087440279976, 0.049871950676398616, 0.049510539176740816, 0.013969890157958227, 0.0361484883220068, 0.030684405272560458, 0.06164082844874688, 0.0525762486005468, 0.022182643080928495, 0.02964684719751988, 0.027384302711912563, 0.06548734847456217, 0.09380076918751001, 0.1178212006177221, 0.12818887643516064, 0.1388085058757237, 0.11627903979803834, 0.1357261384172099, 0.1104903422029955, 0.13409936428070068, 0.31881133413740564, 0.1069163829088211, 0.17314183499131883, 0.10226169374904462, 0.09721090977213212, 0.1321762739015477, 0.10000310851527111, 0.13188799151352473, 0.12358980679086276, 0.12440451021705355, 0.14495399753962243, 0.1393203248402902, 0.17760538762169226, 0.14062085933983326, 0.0903445425044213, 0.18904000547315392, 0.09931761172733136, 0.15429738403431006, 0.08920361301196472, 0.11684401519596577, 0.11425300208585602, 0.167745920962521, 0.09348852094262838, 0.11808664351701736, 0.1506465399371726, 0.08575724544269697, 0.12740675626056536, 0.1688069733125823, 0.1095838804862329, 0.2139701284468174, 0.11326690071395465, 0.24531888057078632, 0.09318500544343676, 0.12951499170490674, 0.12438233569264412, 0.09334756886320454, 0.18314904586545058, 0.18584827174033436, 0.12526151351630688, 0.15214976641748632, 0.10232918084199939, 0.16320604671325, 0.09354308872882809, 0.12062440519886357, 0.17654687299260072, 0.06027784837143762, 0.20864255646509783, 0.12076457696301596, 0.0865016458556056, 0.06868500581809453, 0.06365636922419071, 0.10735023141439472, 0.11507658075009074, 0.1171323654374906, 0.09803581157965319, 0.08556372047002826, 0.12134544365108013, 0.13368144099201473, 0.27572712887610706, 0.14156718498894147, 0.16623881326190063, 0.18816587595002993, 0.10605180715875966, 0.10686351824551821, 0.18647526523896626, 0.1741254800664527, 0.11135706890906606, 0.16736318649990217, 0.1884817611426115, 0.11638061649033002, 0.14039779773780278, 0.11239290689783436, 0.20138201463435376, 0.11108993645757437, 0.19351300331098692, 0.13379973678716592, 0.09984930498259408, 0.13700740252222332, 0.12266675489289419, 0.1246270832738706, 0.12071542388626508, 0.14506534513618263, 0.1704802813806704, 0.11463748716882297, 0.08400960386331592, 0.14951228722929955, 0.08761683851480484, 0.13684967027178832, 0.11106034554541111, 0.1267487129994801, 0.06698688372437443, 0.1189771800168923, 0.11800907339368548, 0.11708560080400535, 0.16431842345212186, 0.11898578384092875, 0.23150613318596566, 0.16151361752833637, 0.14948908133166178, 0.06979156751185656, 0.19188666343688965, 0.07431269383856229, 0.08390545552330357, 0.07400206050702504, 0.10581349887486015, 0.11881899993334498, 0.10546460973897151, 0.10285478763814483, 0.17131535442812101, 0.10628317402941839, 0.18614544293710164, 0.18218696463320935, 0.1441735058490719, 0.09786929908607687, 0.12898904564125196, 0.1529269197157451, 0.11165958696178027, 0.18176195743892873, 0.13087679791663373, 0.07409628187971455, 0.13952227043254034, 0.14788045122155122, 0.06671676571880068, 0.13915294382189, 0.12351256236433983, 0.0739487683666604, 0.0757895592334015, 0.188906727624791, 0.06366090862346546, 0.11357087761695896, 0.11014350902821336, 0.1914990163807358, 0.09467721251504761, 0.1442789366202695, 0.08697893417307309, 0.14294089270489557, 0.11126581273440804, 0.14699029470128672, 0.0920660604855844, 0.08456358020859105, 0.10651183354535274, 0.13377061406416552, 0.09876960649022035, 0.08282173331826925, 0.12718351823943003, 0.09175670279988221, 0.12401110918394156, 0.14994783885776997, 0.13194239645131997, 0.10504435228982142, 0.10376677262995924, 0.11618199571967125, 0.16944456552820547, 0.14708546602300235, 0.12121840832488877, 0.1220169761883361, 0.12163234182766505, 0.21056317697678292, 0.14510281383991241, 0.08897525205143861, 0.08114324124263865, 0.1534771437623671, 0.09447249849992138, 0.2045755804117237, 0.14029508110667976, 0.10104566400072404, 0.11318573435502392, 0.16586035356989928, 0.16337968382452214], [0.04666044782581074, 0.04635160243404763, 0.018949030166757957, 0.02959644900900977, 0.06885773369244166, 0.02314831715609346, 0.013441311378431107, 0.04435842278014336, 0.009361041975872857, 0.05634979218510645, 0.02570620927560542, 0.061625792112733634, 0.05285931644695146, 0.03781843085640243, 0.06336884679538862, 0.006272852262814662, 0.00872520886228553, 0.02917748416907021, 0.02549248092275645, 0.047438897125955136, 0.018442634393328, 0.010388972487167587, 0.05643676341112171, 0.06876066925802402, 0.03528402453022344, 0.03485105812017407, 0.05273666784965566, 0.018345334167991365, 0.019948513945564628, 0.0196942244656384, 0.08260044947798763, 0.011203630960413387, 0.002633103061400886, 0.06619950490338461, 0.003708359269824411, 0.025921610217275362, 0.0061886630303758594, 0.04574788947190557, 0.05050228935267244, 0.053805068733968904, 0.02533230255357921, 0.030091579404792616, 0.0488602142514927, 0.020088266714343002, 0.01462894189171493, 0.020643332108323063, 0.09431180783680507, 0.049847947500113926, 0.011273614214068013, 0.041666294381554635, 0.036653148742126565, 0.008309138822369277, 0.02669812908529171, 0.023811512194307785, 0.039400920404919555, 0.04097025315942509, 0.048344419071716924, 0.04361792055091687, 0.02949062129482627, 0.062311526387929916, 0.05634741731254118, 0.017714620601119738, 0.02376797399483621, 0.013609851843544414, 0.05027100390621594, 0.07267719374171325, 0.030322040431201458, 0.02441394781427724, 0.09686854814312287, 0.046421318514538665, 0.02809918176249734, 0.010874579643963702, 0.03266185987740755, 0.02551532380415925, 0.05421504977026156, 0.0726531668167029, 0.0330944870199476, 0.02814835519529879, 0.025625648509178842, 0.040102193132042885, 0.0295656095924122, 0.021972721309534142, 0.027215756309617842, 0.05901401583105326, 0.03253807134128042, 0.05294094081701977, 0.01473720045760274, 0.019556096788229685, 0.014367295395849007, 0.08445254473813943, 0.027615265854235207, 0.09475436873201813, 0.026909708178469112, 0.028481615973370414, 0.012120598095602222, 0.03547997526558382, 0.009850639766747398, 0.028621248302182982, 0.023178783378430774, 0.023104597448504398, 0.020399790623092225, 0.041773133112915924, 0.056310315017721484, 0.032965324486472776, 0.040204115877194066, 0.01019033560130213, 0.04875103796699217, 0.016386474815330336, 0.00876168520855052, 0.020747292154867734, 0.03142155893146992, 0.06655201741627284, 0.061132816065635, 0.028553472831845284, 0.07683389926595346, 0.02241973509080708, 0.035920805896499326, 0.04108712403103709, 0.054780374613723586, 0.04511798505804368, 0.02429492089764348, 0.034695191841040335, 0.02179937427198248, 0.015997972805052996, 0.05549121129193476, 0.021256651429991637, 0.052586178960544724, 0.0073129739279725724, 0.01855109821605895, 0.031312864406832626, 0.02876504683601005, 0.11167376155831985, 0.01624318179009216, 0.018594583829066584, 0.04291800828650594, 0.010622119664081504, 0.05989308508911303, 0.02724850580229291, 0.018741668168721453, 0.02006188527281795, 0.031729444196181636, 0.04248064836221082, 0.019964001507365277, 0.01577100793032774, 0.03329818323254585, 0.02987489603193743, 0.008830999257043004, 0.020150420522051196, 0.08702221792191267, 0.06364161787288529, 0.02707757774208273, 0.03791898296081594, 0.04005253793937819, 0.04001895384863019, 0.042890914383211305, 0.023383170000410507, 0.022652433586439917, 0.03377558011561632, 0.02117227729676025, 0.019197299344731227, 0.06694200541824102, 0.03306670440360904, 0.011653180766318525, 0.06553441166345562, 0.016070426774344275, 0.005521719510267887, 0.050230084851916344, 0.03736971564857023, 0.0316724845740412, 0.02550260296889714, 0.0757143096998334, 0.04417688073590398, 0.05935099667736462, 0.017951215584097163, 0.020663940913176963, 0.08129813721669571, 0.07451083963470799, 0.04379480105957814, 0.06850743320371423, 0.026561110812638487, 0.02232731013957943, 0.03024503688461014, 0.07620259028460298, 0.046482152571635585, 0.014794163472418274, 0.018152253635759865, 0.029002086259424686, 0.04945277549060328, 0.05709122400730848, 0.03428038642076509, 0.0521312008744904, 0.020273869790669, 0.024398390702637177, 0.015856274337108647, 0.02053369102733476, 0.058434397647423406, 0.053536616531865935, 0.02573704021051526, 0.11742132636053221, 0.051376337451594215, 0.04540817752214415, 0.030970757228455374, 0.08034155890345573, 0.054955175412552695, 0.03070181648113898, 0.02037546344633613, 0.04429758193769625, 0.056436142551579645, 0.010396055544593504, 0.025287880562245846, 0.03182028307180319, 0.008219129455808018, 0.02850903896614909, 0.054002973650182994, 0.01903530759071665, 0.02734219452499279, 0.02661083555514259, 0.04986174890239324, 0.0369883382559887, 0.014271786502961601, 0.03420190366783312, 0.025067816388660243, 0.052361868854079924, 0.05779561799551759, 0.051896261516958475, 0.017263016530445645, 0.08477490315479891, 0.04016214170094047, 0.05415947435955916, 0.009543453393104886, 0.0214881065102028, 0.031365321949124336, 0.03549884532445243, 0.08013426645525865, 0.01256542360144002, 0.047345154120453765, 0.012708562259961451, 0.007415452223670269, 0.0278932192429368, 0.033510717363762, 0.03393556170963815, 0.04205381251605494, 0.05219066768352475, 0.012804010932865952, 0.022274369141086936, 0.019053560182718293, 0.028459410914885144, 0.006574640890383827, 0.017945517586278062, 0.020002789961706315, 0.047610050799059014, 0.038953175502164025, 0.011098765069618821, 0.010365532494948378, 0.015153583471796342, 0.030767332429864576, 0.04003824459921036, 0.020279986783862114, 0.030909471945571046, 0.0030561698575703694, 0.0707324038126639, 0.028447438164481094, 0.015799274002867084, 0.04865935092259731, 0.02579161987107779, 0.014062767183142049, 0.03661113724644695, 0.11478726698883943, 0.037254130600818565, 0.028896662273577282, 0.08085770692144122, 0.02455219253897667, 0.028612176288983653, 0.0291188519581088, 0.03162796589146767, 0.047234702190118175, 0.0706324488190668, 0.041581752310906134, 0.016402089602446983, 0.029887452322457517, 0.03588250259469662, 0.016407483955845237, 0.009190356491931846, 0.02009448379145137, 0.04640243149229458, 0.015786040873665894, 0.041003467448587926, 0.02960245404392481, 0.025287493797285215, 0.02686118783562311, 0.05969384006623711, 0.045208277712975226, 0.03978302382997104, 0.07583894301205873, 0.023713742083470737, 0.055979603834982426, 0.028617665637284517, 0.014609574805945158, 0.016718152910470963, 0.004920404321247978, 0.07435436945940767, 0.14509577064641885, 0.02773128686073635, 0.027745765101696764, 0.014337975897693207, 0.00544479229886617, 0.048723696398415735, 0.0254566865041852, 0.01694543330397989, 0.016897657653316855, 0.006118902845108616, 0.026361708030370728, 0.02575701967413936, 0.0505342890641519, 0.013578836007841995, 0.04213931132107973, 0.04610463943598526, 0.10818218998610973, 0.012171082797327211, 0.00869901232155306, 0.06335915052997214, 0.026730015142155544, 0.0312967627708401, 0.03313386579975486, 0.006147822007603411, 0.029239244426467588, 0.01865355870021241, 0.023538262749622976, 0.01562744009840701, 0.05648978753015399, 0.011873331453119005, 0.008405042113736272, 0.04800569439040763, 0.030211103348327533, 0.03169847246525543, 0.08639008791318961, 0.03907259427277105, 0.014952172225873386, 0.011614743453849639, 0.056836223761950216, 0.024364911784817065, 0.046831835593496046, 0.003961391763628593, 0.020712817486907755, 0.02253508604397731, 0.08138425688126258, 0.050067901411759, 0.014841728777225529, 0.028855414129793644, 0.021370311134627888, 0.017053685084517513, 0.09041597188583442, 0.2526262956006186, 0.0951582667018686, 0.11113293522170611, 0.18162839460585797, 0.09276862242924315, 0.054752066132745573, 0.128395123939429, 0.13506413251161575, 0.07665495601083551, 0.10490627719887666, 0.08044386841356754, 0.16781732998788357, 0.13983924128115177, 0.06476921415222542, 0.17807122905339512, 0.09121537434735469, 0.1006424038537911, 0.09433056254472051, 0.14229042189461844, 0.24881349876523018, 0.09824325330555439, 0.06918098777532578, 0.19157134821372374, 0.151120768061706, 0.18876996210643224, 0.10335100029728242, 0.18407464905508927, 0.1011011613798993, 0.1470416055193969, 0.0912175728008151, 0.19922326904322418, 0.12054465019277164, 0.11925597648535456, 0.20948902890086174, 0.09547145132507596, 0.15240257499473436, 0.06887103976415736, 0.1129807217844895, 0.19642866828611918, 0.16644041958664144, 0.08804680580007178, 0.09308475867978164, 0.13165920307593687, 0.13887274957128934, 0.05894829292914697, 0.13720716323171342, 0.3250481294734137, 0.1539548324154956, 0.20608792640268803, 0.1761480165379388, 0.19183414482644626, 0.1709392424672842, 0.1426911646766322, 0.05628952470475009, 0.11012743453362159, 0.098008296984647, 0.0826826404247965, 0.11151847881930214, 0.07665886437254292, 0.13862393077995094, 0.10409800628466265, 0.12980882450938225, 0.12673789715128286, 0.13114656986934797, 0.08655879886022635, 0.17430472187697887, 0.09893131495586463, 0.07771909569523164, 0.12955191758062157, 0.10989269534392015, 0.14071844624621527, 0.12178073743624346, 0.1419373665537153, 0.07618567440658808, 0.17271051742136478, 0.12123866938054562, 0.07878536597958632, 0.15951913169452123, 0.14188758922474726, 0.1336304558707135, 0.1121516130598528, 0.1025984642495002, 0.10734084048973662, 0.15019736332552774, 0.18754060593034538, 0.1523389419806855, 0.12417086346873216, 0.15133948703961714, 0.05874539738787072, 0.14944864064455032, 0.12001562358013221, 0.15758298630160944, 0.12738227471709251, 0.13171548077038356, 0.17378117782729013, 0.08631513693502971, 0.08467630523123912, 0.139972858397024, 0.08282046445778438, 0.15058065418686184, 0.1743978304522378, 0.10000063864780323, 0.21021219795303686, 0.13460601280842507, 0.11341372212128979, 0.16444720939866134, 0.11162213861410107, 0.11307032911905221, 0.16489933085228714, 0.14071607137365, 0.11388478827263628, 0.18366767732160433, 0.10138343873300723, 0.11920375643031937, 0.14312902332416602, 0.08641462373946394, 0.10851383754717452, 0.10846396522330386, 0.1472002062946558, 0.18166641970830305, 0.11863565977130618, 0.07743341209633009, 0.09495151029633624, 0.09065767284482718, 0.20779704754906042, 0.2203871426837785, 0.10984304015125547, 0.11691190940993172, 0.11201840306499175, 0.10292988789400884, 0.09098686410912446, 0.12924391696495668, 0.07648551903132882, 0.06967631155358893, 0.14280237656618866, 0.10726775548287801, 0.12241675545062337, 0.12807565608194896, 0.10665985595967088, 0.1167397243635995, 0.08469991824988808, 0.13996687371815952, 0.08083997001605374, 0.08691644788320575, 0.2475250150476183, 0.13164203613996506, 0.10131649446806737, 0.16366678556161268, 0.12754572023238453, 0.09339073726109096, 0.10910767103944506, 0.12367987552923815, 0.14192954983030046, 0.15532297614429677, 0.09758894198707171, 0.08601519731538636, 0.09918337714459215, 0.09943453009639468, 0.08733047638088465, 0.1471314299851656, 0.14062000438570976, 0.07995108914162431, 0.07768357438700539, 0.14069384256643908, 0.058314534436379156, 0.10970310587435961, 0.15737227403691836, 0.08055028984589235, 0.10556961981845753, 0.15471238962241582, 0.16853173236761773, 0.23952150451285498, 0.11864787340164185, 0.08109705336391926, 0.08042159210890532, 0.25851972507578985], [0.013297733368485101, 0.024514598306268454, 0.0060728108094606015, 0.044838374347559044, 0.024517758583117808, 0.020659606770745347, 0.008991490600497594, 0.015489741594397595, 0.025784384991441454, 0.042333053424954414, 0.04488539003900119, 0.04045044105233891, 0.02444512989105923, 0.019312304245041947, 0.09315399639308453, 0.023170193125094687, 0.017058824987283776, 0.0837008161470294, 0.03188663361860173, 0.03408399803031768, 0.014080717827060392, 0.0527936308644712, 0.031269312636660676, 0.01630459938730512, 0.02945016703701445, 0.05628756034587111, 0.021666138832058226, 0.05426951577620847, 0.038644475995429924, 0.018500662708122815, 0.038683820848486254, 0.035984896921685765, 0.07079828277762447, 0.05956542052860771, 0.043491058251155276, 0.046301010863057206, 0.030823270856801952, 0.0266979068650731, 0.015704667561554482, 0.03395997539960912, 0.03949083986559084, 0.010924278941404606, 0.07845161495996372, 0.023834908081750785, 0.014449923997744918, 0.0463257129304111, 0.06522049422242812, 0.04046479206798332, 0.0674398804881743, 0.017141333149213876, 0.022795779198142033, 0.029343134923172847, 0.04591985399435673, 0.026551646945465888, 0.026987792292077626, 0.014923675451427698, 0.03265112545341253, 0.0034167548167585793, 0.0442378674633801, 0.024543731207294122, 0.04091352763186608, 0.026732607145926783, 0.01675187610089779, 0.03541383506464107, 0.03660004998424223, 0.07210140249558858, 0.06466584612748452, 0.038952083060784, 0.09258393876786743, 0.03949671937152743, 0.028840340474354367, 0.030413215181657245, 0.03200385393574834, 0.014149585738778114, 0.015731513799567307, 0.047590743085103374, 0.062374060175248554, 0.05241224668653948, 0.014957819333566087, 0.021504701780421392, 0.016615419315972497, 0.042492403981408904, 0.05098746903240681, 0.02257690585351416, 0.08492996197726045, 0.009086411712425095, 0.01880285336769053, 0.04334280513493078, 0.028263519551338892, 0.03585096428702984, 0.055152578212852986, 0.03497942676767707, 0.04287978640890547, 0.010682798506292914, 0.07727056369185448, 0.03897123131901026, 0.005788786228679652, 0.02417981082440487, 0.03300654888153076, 0.0455588122962841, 0.036395339361791096, 0.04664504508088742, 0.037065056817872186, 0.025199993313955407, 0.03886795150382178, 0.009806449325489146, 0.013936878581132208, 0.018114004616758654, 0.03852639054613454, 0.05235946684011391, 0.0243849506202553, 0.047150160119469674, 0.03284694387444428, 0.010682470264977642, 0.051861293214772425, 0.010044908583430307, 0.03967669399987374, 0.03918771791671004, 0.04257931413927248, 0.005719369127681213, 0.058944832400551865, 0.0009716154974220054, 0.04616256257785218, 0.02721159688995353, 0.08198735916188785, 0.0647734482107418, 0.06951894571206399, 0.05343080238838281, 0.0681205800335322, 0.06118870699512107, 0.023034956006865417, 0.03362990543246269, 0.044523713910686116, 0.01731272430957428, 0.04293771633612258, 0.025448320167405263, 0.04097437865233847, 0.03669027817834701, 0.04403060894193394, 0.08080797030457429, 0.029901158729834214, 0.06634787337056228, 0.02919359937576311, 0.09079696251345531, 0.02460980016205992, 0.0225643614373569, 0.06071932361062084, 0.046763707284948657, 0.042551372067204545, 0.03176200369905148, 0.037201170942613056, 0.047104755948696814, 0.0201220798106598, 0.07252556830644608, 0.03455741869817887, 0.026958844291844537, 0.07123961552445378, 0.034707466539527686, 0.03330917549984796, 0.0671879132943494, 0.03696190931701234, 0.05319561536556908, 0.02254617160984448, 0.011224121021639024, 0.011023054980406803, 0.027503850404173136, 0.044634291370000155, 0.01580379983144147, 0.04513063634346638, 0.02219455985219351, 0.00863550229197634, 0.010081086374287094, 0.03682530325438295, 0.06170057345713888, 0.02234144402401788, 0.03649725532159209, 0.028088123338030915, 0.05423044912250979, 0.020844599165554558, 0.05054534239960568, 0.05202052163492356, 0.025417721630739312, 0.02137874871758478, 0.07639345539999859, 0.020622901418911557, 0.04084235948643514, 0.04641249416662114, 0.04196011022265468, 0.045420944158520014, 0.02410644931452615, 0.03879336014922176, 0.08468177422348942, 0.0184033268596977, 0.05767596513032913, 0.01994238168533359, 0.02085037180222571, 0.04103021529902305, 0.020401415714461888, 0.02257202549039253, 0.04101541305759123, 0.06974097594086613, 0.031493297046316523, 0.015027576126158237, 0.03198406785460455, 0.06291110028645822, 0.026976452275578464, 0.015127397109089153, 0.01061711716465652, 0.041528589092195034, 0.05087790937562074, 0.03503629478758999, 0.07024085268910442, 0.01172046599510525, 0.024360323191753457, 0.050939947832375765, 0.05542899980874998, 0.031085813018892492, 0.024675730017146895, 0.02057003845194621, 0.05073379871568509, 0.08805820518838507, 0.005882865533099643, 0.03462813561782241, 0.04817602025078876, 0.01382087793068162, 0.05324927730751889, 0.04142975028870361, 0.01757983470867787, 0.01908161082038922, 0.025807034490363936, 0.04604754410684109, 0.06473908041204725, 0.03142215604228633, 0.034573276061564684, 0.029553226328321865, 0.006387884728610516, 0.021339105309120247, 0.026510420854070356, 0.019293927820399404, 0.05557369061612657, 0.04084128740110567, 0.04077590376670871, 0.030771105084568262, 0.0874230692695294, 0.0884548496188862, 0.03410342788057668, 0.03377579724682229, 0.020460465224459767, 0.04075326444581151, 0.0591711306146213, 0.08331611393285648, 0.019065276786152805, 0.017343802909765924, 0.030956735302295004, 0.01566927008596914, 0.032671179555888684, 0.06332516271088805, 0.03371747037661927, 0.03740514535456896, 0.05076347105205059, 0.02236433101019689, 0.011221812306238073, 0.058047666613544734, 0.05109006691990154, 0.11595809273421764, 0.08696511920009341, 0.025094569328108003, 0.024921693872394304, 0.043792826522673876, 0.05771470269454377, 0.05719913821667433, 0.021771067487342016, 0.11588998138904572, 0.027569385012611747, 0.07073234274451222, 0.035430737371955595, 0.015678491376872574, 0.10430662187614612, 0.05921727099588939, 0.060687405323343616, 0.006332325433114809, 0.010195645137823053, 0.039992680972708125, 0.009177929971234074, 0.03465492757303374, 0.007737188084450151, 0.007710851595870086, 0.06075004767626524, 0.016530863674623624, 0.012996953213587403, 0.03352947546435254, 0.03477254822584135, 0.02014831536715584, 0.04282202272276793, 0.02109704981558025, 0.04033428603517158, 0.0359979281867189, 0.019905552500858903, 0.04418563044496945, 0.012272183666937053, 0.03135849249416164, 0.052124907462192435, 0.04056813295132347, 0.04553619333143745, 0.038415219368679185, 0.016125026790957366, 0.06564239372632333, 0.05431815316634519, 0.06426898456577744, 0.02924007223919034, 0.017060304193624427, 0.013885472768119403, 0.058377821397568495, 0.01463338459974953, 0.01978621006544147, 0.0724010978426252, 0.02190010788451348, 0.012827424631853188, 0.04703376761504582, 0.027833844036129967, 0.024681095532806854, 0.021074184881789342, 0.052502926106431654, 0.05987186051372971, 0.0673668361934168, 0.0527489968309445, 0.045752951343144686, 0.012410664182555462, 0.009812423826328345, 0.06278828544808285, 0.03612888544531805, 0.023334452882409096, 0.05455416121653148, 0.008098759888006108, 0.008091101772151887, 0.07238604793591158, 0.058488144406250546, 0.06003577421818461, 0.06561601228479828, 0.019592469657904336, 0.05760347723428692, 0.04555327884320702, 0.01639525675480919, 0.017681467380108576, 0.008914117252321115, 0.026276526440467154, 0.012637730837533516, 0.016039672174624035, 0.04786410109539117, 0.09080005663314036, 0.011322761353637491, 0.0797216696664691, 0.07781012116798333, 0.1410528283034052, 0.07786204945296049, 0.11303476709872484, 0.1341011691838503, 0.1193296518176794, 0.111926101946405, 0.1275684375848089, 0.1833609523517745, 0.11669100554926054, 0.16800860900964054, 0.10039120340453726, 0.15903165856642382, 0.11633652528481823, 0.15876001385705812, 0.143878967368177, 0.0957581934386066, 0.10588428364800555, 0.11566876540226595, 0.1014897787411298, 0.1513162540005786, 0.11195067169943027, 0.1229543180337974, 0.1004878810739943, 0.20489910590861524, 0.2333678975701332, 0.1309964507818222, 0.151385328865477, 0.11464153123753411, 0.17869891465774604, 0.16680285228150232, 0.12515131942927837, 0.20477840809949807, 0.14845386759511062, 0.16233229716973646, 0.1923572274723223, 0.12059901441846575, 0.16046270249145372, 0.11459510587155819, 0.1672496675912823, 0.10344490275851317, 0.10844371095299721, 0.2092749918145793, 0.09170832325305257, 0.15009281464985438, 0.12046569585800171, 0.12551692766802652, 0.15260610835892813, 0.21851121048842156, 0.11204908641853503, 0.11523640288838319, 0.14283265279872076, 0.1206902095249721, 0.11227050596582037, 0.14941653236746788, 0.12608339584299497, 0.09967108775994607, 0.16475691992257321, 0.12846106397254126, 0.09841342310288123, 0.16347691789269447, 0.12839398400059768, 0.10296710553978171, 0.1289144746427025, 0.14181183757526533, 0.13115917704999447, 0.16422557272017002, 0.16169053874909878, 0.25717845133372713, 0.19175239492739948, 0.1779124518590314, 0.08191985171288252, 0.11341631412506104, 0.1196076747562204, 0.14951690126742634, 0.1773801954197032, 0.13523662968405656, 0.12690896940018448, 0.11404082418552466, 0.10490232812506811, 0.21804979310504027, 0.19052682497671672, 0.10686777266008513, 0.14284384862652846, 0.1571393601064171, 0.10556611179241113, 0.14071171517883027, 0.1901832419846739, 0.1414165095027004, 0.11606896535626479, 0.12711487763694354, 0.16441621391900949, 0.11137405264058284, 0.08973257855645247, 0.16979435033031873, 0.08605552265154463, 0.11648372667176382, 0.07903931449566569, 0.15170615379299435, 0.11903505905398301, 0.07209936689053263, 0.13400118026350225, 0.2126363864434617, 0.12962310947477818, 0.1676896432680743, 0.07119690174502985, 0.22124563876007283, 0.07156258462263004, 0.12137582844921521, 0.15928312364433492, 0.13859806502504007, 0.14871370579515183, 0.1295186829354082, 0.09425451912518058, 0.16086742148867675, 0.15593987304185117, 0.09630837677312748, 0.1878341401794127, 0.15463122326348508, 0.0772532814049295, 0.1506259531847068, 0.1191616194056613, 0.12263968134565012, 0.08975269033440522, 0.09877507548247065, 0.1474093036460025, 0.15151847100683621, 0.17391244721199783, 0.16823952804718698, 0.14051815627941064, 0.12231429666280746, 0.1628909893333912, 0.12168202416173049, 0.13194124294178827, 0.08444310631603003, 0.06757666636258364, 0.1432373175131423, 0.07290948341999735, 0.08452994522771665, 0.18789362055914743, 0.10744732299021312, 0.09381877072155476, 0.09303137832986456, 0.1965918695288045, 0.08858504691826445, 0.08540195093623229, 0.18495291764182703, 0.11036317116980042, 0.1279245734746967, 0.12306346717689719, 0.15581082925200462, 0.14600869880190917, 0.10093501529523305, 0.18315731042197772, 0.11538557202688285, 0.16960316630346434, 0.1562320909329823, 0.06290784331836871, 0.1330816296062299, 0.1707609641764845, 0.10641919994460684, 0.1105535002425313, 0.21045210079423018, 0.18573507852852345, 0.12782501881676062, 0.17171731857316835, 0.1915480608918837, 0.1392763014882803, 0.10717031785420009, 0.12709023324506624, 0.07013012934476137, 0.06792326205010925, 0.15202802366444043, 0.26226708399397985, 0.12953036730842932, 0.21307800417499884], [0.014938548939036471, 0.021716347030763115, 0.013632482682753886, 0.022415278812072108, 0.01603617093392781, 0.03780245814206345, 0.009256092116369732, 0.06901603591229234, 0.047710046504757235, 0.021254620913948332, 0.021763897068532448, 0.03298737008922866, 0.059295132889279296, 0.0637999540194869, 0.038627475300537686, 0.019019419693254998, 0.029021455041532005, 0.02850071673414537, 0.031589845794120004, 0.01650360692292452, 0.022168906139475957, 0.016837442759424448, 0.10723338089883327, 0.01577348119047071, 0.04201641505850213, 0.058604221391890726, 0.053237521688320806, 0.024842176353558898, 0.036010545545390675, 0.06998336222022772, 0.020917634978624325, 0.014760642146159495, 0.018062393546902707, 0.01712737398754273, 0.0060116171288037935, 0.02196824297841106, 0.046155071551246304, 0.024949191504025033, 0.027312447549775243, 0.02321757352910936, 0.018801645575357333, 0.01267257530707866, 0.04265984606796077, 0.07965053205511399, 0.06313504398401294, 0.05702576573405947, 0.037275161793721576, 0.03579964329089437, 0.04150426700445158, 0.009855672800248223, 0.011451141875503319, 0.041358877306005785, 0.06192372326872178, 0.07363582801605974, 0.021372007472174506, 0.06083279502178941, 0.031216597251061882, 0.045474636634545665, 0.03276162827387452, 0.04244227720690625, 0.09138519130647182, 0.03838529258168169, 0.009960478471059884, 0.058296146137373786, 0.02787186574589993, 0.05481238111055323, 0.055896954877035956, 0.023346026993489692, 0.0322170835653586, 0.04857700052005904, 0.018052860129890696, 0.034717848125313006, 0.01495110522955656, 0.013316030913431729, 0.005259066662152431, 0.04688794365418809, 0.036930564391825876, 0.04474362711023007, 0.010882004513405263, 0.021850352607933537, 0.051167694718710015, 0.0748923323782427, 0.04101417812385729, 0.045966085977852345, 0.04563532390498689, 0.008213043844859515, 0.024813199515587518, 0.02586144451717181, 0.016475483342739086, 0.040390041257653914, 0.017458821380777017, 0.048360883723944426, 0.01886848806004439, 0.026593178377619812, 0.029974043568862335, 0.038700061584157605, 0.042257512121328285, 0.018975528655573726, 0.02890064866681184, 0.05447537651551621, 0.01474406723199146, 0.047345676592418125, 0.0386185830991183, 0.0741219644301704, 0.019455839846549288, 0.04489501845091581, 0.01441504220877375, 0.044366249681583474, 0.010484292238418545, 0.03138928102063281, 0.03525268978306225, 0.03861405387786882, 0.02786877841156508, 0.041118950716086795, 0.029594036817018474, 0.02166605571151844, 0.020591536137674536, 0.021973240388823406, 0.04204468282737902, 0.03210861974262765, 0.01688047205763204, 0.03178291614832623, 0.02241743146441877, 0.060884804730968814, 0.03590661772925939, 0.08313882630318403, 0.02898316870310477, 0.03833484350304518, 0.01706171385012567, 0.018318018044478128, 0.05029469834906714, 0.0395731461633529, 0.03673375191699181, 0.03240156027355364, 0.02163597964681685, 0.02050509925798646, 0.003105893963947892, 0.04552592370393021, 0.08861195761710405, 0.02208475592280073, 0.0312684983946383, 0.034353108411388736, 0.010421547257075352, 0.008712907022397434, 0.0452908791734704, 0.04946264138977442, 0.10753415511654955, 0.03313654940575361, 0.06189656151192529, 0.028240878534104143, 0.06804094037839345, 0.005963799069702093, 0.009912770673898714, 0.05552849679120949, 0.050606111995875835, 0.009625981062916773, 0.018518827090572034, 0.04156874818727374, 0.052576401270926, 0.02270827871481223, 0.060192176539983065, 0.015007125080696173, 0.019291271355801394, 0.02015359776227602, 0.06135431703712259, 0.024580489145591855, 0.056986634619534016, 0.0315755422759269, 0.027801771382136003, 0.04979843479980316, 0.04918971085654838, 0.026955599198117852, 0.02246805526582258, 0.003264995794909607, 0.032464759025190554, 0.016923090842153345, 0.07031107427818434, 0.012576905262124325, 0.07033569152866091, 0.0059898743222999784, 0.033775284952883206, 0.017663396296224425, 0.034265760598438125, 0.0627102946330394, 0.03312847823170679, 0.050432071156267605, 0.013672880113257893, 0.12877895762877806, 0.030939408910593817, 0.0583294757774898, 0.006740341686444091, 0.044589786258127005, 0.022030535885798078, 0.03708167753315397, 0.023173506072323238, 0.08095376033868108, 0.04316988727077842, 0.03157936582075698, 0.08063080481120519, 0.050048434242073975, 0.047761974789734395, 0.04707949748262763, 0.06458541258637394, 0.008315126045740076, 0.07816599921456405, 0.005848909520344543, 0.011317818226026637, 0.04663268895819783, 0.051182150907282314, 0.05301870093015688, 0.0050119183392130905, 0.011628918898557978, 0.027950100833550096, 0.0345493203827313, 0.029706256331077645, 0.024266120478776947, 0.04319855198264122, 0.024952770776248405, 0.029140439549727098, 0.030508410252098526, 0.031606944876589944, 0.0444364169878619, 0.015737464551680853, 0.027088585276422755, 0.062431593159479756, 0.04302833808053817, 0.012716719947223152, 0.03186669486707874, 0.04845143422218306, 0.04327051401404398, 0.049414716461407285, 0.060361464241785664, 0.052451126743108034, 0.030639235196369033, 0.029923665736402785, 0.030112878619027988, 0.07535860128700733, 0.053062001642371924, 0.04204723411904914, 0.05497768920447145, 0.04513291622112904, 0.05086407743926559, 0.06098982159580503, 0.05601179353626711, 0.04614044912159443, 0.052240797850702486, 0.008277206964391683, 0.01029553312608706, 0.020632446710286394, 0.056424729592565975, 0.03152401771928583, 0.0787746315555913, 0.057420985241021426, 0.06010946312120982, 0.01237488248651581, 0.06984672562352248, 0.03713330726272293, 0.03228299306439502, 0.0461810797985111, 0.026135016265990477, 0.0443532353799258, 0.01061470412449645, 0.05613202315622142, 0.043856507034174035, 0.10492600899721895, 0.03714555821248463, 0.053480325266718864, 0.04523873036461217, 0.019210798798927238, 0.02092415400381599, 0.04944749648815819, 0.019876387369419848, 0.058635576495102475, 0.045459542623055835, 0.014159456726961901, 0.04464395370866571, 0.006902278309488403, 0.008606834187438446, 0.030250519447560822, 0.03069574020004698, 0.02416978377316679, 0.02779206493869424, 0.0590050048860056, 0.033486103505960534, 0.03278564841353467, 0.03530965958322797, 0.030921135962541615, 0.022290560682969432, 0.04273133651752557, 0.10925297252833843, 0.03933534678071737, 0.0010408413363620639, 0.06042399124375411, 0.06921663121985537, 0.021108457685581276, 0.011219498501824481, 0.044580975480909855, 0.022190008578555923, 0.03020246559754014, 0.052166158998651166, 0.03012323984876275, 0.07088799867779016, 0.030457971351487294, 0.03650049871898123, 0.04492078921092408, 0.03517673457307475, 0.028902945507849966, 0.009906016705956842, 0.0664603201938527, 0.08194520856652941, 0.013080300214434308, 0.039451712143740485, 0.018747866586116806, 0.025034936277994087, 0.019043224398046732, 0.035983393966619454, 0.01627415182468082, 0.02310082140112562, 0.009234792053965586, 0.01504757085682026, 0.062268079790685854, 0.0209910711273551, 0.012669102904120726, 0.055073535668530633, 0.02497258908780558, 0.025448825675994158, 0.03296160950724568, 0.02856312838516065, 0.024563376492421542, 0.04540081541719181, 0.04688767563285572, 0.05204860619934542, 0.008315889397636056, 0.043618602478610616, 0.0252806490752846, 0.03163420162828905, 0.09064847869532448, 0.018136796608035053, 0.008688567971278514, 0.038392861639814715, 0.05886667873710394, 0.029344824475369284, 0.013076853256539574, 0.0718093067407608, 0.06595816356795174, 0.06054494011082819, 0.015489902746464525, 0.035419795994779894, 0.01940548576281539, 0.007523527585103044, 0.045588192862591574, 0.06499849792037692, 0.11706246275986944, 0.10199578944593668, 0.12879735949848378, 0.07901764208717005, 0.07272127816187483, 0.12469712165849549, 0.142133911007217, 0.13405394314655236, 0.10643138643354177, 0.10097160190343857, 0.12577083547200474, 0.24704596932445252, 0.2084210283522095, 0.09881063071744782, 0.10831628207649503, 0.11334015535456793, 0.10957605019211769, 0.17401987287615026, 0.10394749364682607, 0.11734896738614355, 0.14370485528239182, 0.12451626493462495, 0.3246265692370278, 0.17186898472053663, 0.128033668334995, 0.11995216698518821, 0.16845948195883206, 0.14604254412863935, 0.16522791822041782, 0.13950338001762116, 0.06199614331126213, 0.13109700967158588, 0.14046802611223289, 0.11977462151220866, 0.1260022973375661, 0.11934437602758408, 0.10345637000032834, 0.17090671349849018, 0.10251304347600255, 0.1008762473772679, 0.14920865637915476, 0.09172475737120424, 0.1581106422735112, 0.15155820601752826, 0.14455417756523403, 0.1348080669662782, 0.10294900901083436, 0.08486696000077895, 0.08796388882079295, 0.10325980519077607, 0.12354454850511891, 0.13145309127867222, 0.14953934720584325, 0.11155397977147784, 0.14223372350846017, 0.3062526823154518, 0.16607724050326006, 0.19397367430584772, 0.08167179288076502, 0.15174932219088078, 0.1164089385420084, 0.21319370796637876, 0.10744729584881238, 0.11968833899923734, 0.09921306305165802, 0.08975004404783249, 0.1235766839236021, 0.08809425575392586, 0.13905608973332814, 0.14730946400335856, 0.09814989367233855, 0.10893571669501917, 0.057578208590192456, 0.18206683679350785, 0.11616064900798456, 0.21196097268589906, 0.10519966895559005, 0.2036879751831293, 0.10477931651153735, 0.13022361296628202, 0.13858066738716193, 0.17690394526081427, 0.09381772577762604, 0.10573746902602059, 0.16356880510491983, 0.08656942471861839, 0.1968744657933712, 0.1424728256783315, 0.18959413788148335, 0.10740751334066902, 0.12341817814324584, 0.12599486059376172, 0.0791132544566478, 0.13398974016308784, 0.11914054410798208, 0.16600314447922365, 0.09559461900166102, 0.14307924599519797, 0.12717870064079762, 0.2003749736717769, 0.15587607717939786, 0.22935474291443825, 0.08852340879717044, 0.17044722315456184, 0.12452009187213012, 0.12941281790179865, 0.24009000829287938, 0.12643655974950108, 0.10124235094657966, 0.1157575042120048, 0.19670559199792997, 0.13421675083892687, 0.10650059700544391, 0.20892475917935371, 0.1578449279602085, 0.11670142784714699, 0.1480266483766692, 0.17955564654299191, 0.09501808815236602, 0.0628716434751238, 0.07745703868567944, 0.10548395477235317, 0.08632384932466916, 0.14868022687733173, 0.0637978912730302, 0.19785093196800776, 0.10660488783781018, 0.19269848987460136, 0.10931712801435164, 0.048278309404850006, 0.13126661628484726, 0.13957849384418555, 0.1257616209664515, 0.17106599280876772, 0.0509715573862195, 0.17669042386114597, 0.05080345033534935, 0.09143151489219495, 0.13044045918754169, 0.10398375455822263, 0.10702837511364903, 0.15510260154094013, 0.19788336594189915, 0.09529130027762481, 0.1472991502710751, 0.1769784755472626, 0.1780599518013852, 0.1335467110787119, 0.11637935441519533, 0.09812765807977744, 0.15495917280869825, 0.16114635366414273, 0.06577159357922417, 0.15242909214326314, 0.1029680147767067, 0.12139309038008962, 0.0822222815560443, 0.12048299850097724, 0.15233085384326323, 0.10619326135409729, 0.10189593623259238, 0.11566633624689919, 0.07471343662057604, 0.10484134818294219, 0.16222560432340416, 0.1511839668133429, 0.10662258403109652, 0.14929573956344808, 0.12341595254838467, 0.11193375582141535, 0.11499696145100252, 0.145770329449858, 0.12584303159798893, 0.11549561683620725, 0.16429121419787407, 0.15415115973779134], [0.026192410150542855, 0.01720406540802547, 0.018365981988608837, 0.062170357177300115, 0.023321596340143254, 0.003189230362685131, 0.007349133907285119, 0.06365710204201085, 0.08726374246180058, 0.009870736277662218, 0.017363473639956543, 0.017675330030864904, 0.008594677384410585, 0.04972357203119567, 0.015504124840455396, 0.04239256094608988, 0.05569389648735523, 0.042674709377544265, 0.036088872235268354, 0.0055615172854491645, 0.018401425265307938, 0.02232729996155415, 0.05693545950842755, 0.0844926665137921, 0.07776971440762281, 0.04393193298684699, 0.038158590639276166, 0.02897469719339694, 0.018009405050958906, 0.040243545547127724, 0.04531383740582636, 0.05122033207278166, 0.03765889370281782, 0.04429543098168714, 0.03079329657235316, 0.03351812696616564, 0.016135964775457978, 0.026343406244580234, 0.01675737732356148, 0.030835016297974756, 0.030232002226901904, 0.04182725306600332, 0.011787844522457038, 0.024841670844970003, 0.04091686263148274, 0.02452722075395286, 0.026549029496631453, 0.13665573139275822, 0.02886963283110942, 0.004066450188734702, 0.024937050816203867, 0.027136808760198097, 0.0670255059376359, 0.04701373726129532, 0.04288674478552171, 0.026463442482054234, 0.06749699278069393, 0.0414445152107094, 0.022375766021598662, 0.006920201387921614, 0.018168016004243066, 0.02746512641065887, 0.007793267307403896, 0.026490195421501994, 0.053888148561652215, 0.038345940943275175, 0.020607507155675973, 0.02927926102919238, 0.09111998589443308, 0.09624397022915737, 0.04864289305571999, 0.017690746346488595, 0.0392750860857112, 0.028747432066925933, 0.043796833271959, 0.0827590027557952, 0.01276418092727129, 0.036723451755408726, 0.011360543031644608, 0.06722983997315168, 0.02659984498417803, 0.033661772829613516, 0.020928961424423114, 0.03892454471705215, 0.046474692079105547, 0.040865952149033546, 0.020997588456209217, 0.04009127889626792, 0.047211058637393374, 0.0525128428957292, 0.0420624638375427, 0.07864123835627522, 0.03212498600727745, 0.050749055575579405, 0.01873290488895561, 0.02963968865307314, 0.029420956104461635, 0.05330446256058557, 0.020383655060348765, 0.02990227491993989, 0.02392111934854516, 0.029727199314428226, 0.08949868075017418, 0.03521647976179208, 0.006543963474021959, 0.08681652681635958, 0.035314514501286406, 0.012259473857868994, 0.011048913101798721, 0.046275603119283915, 0.02546057790251715, 0.03244524435805423, 0.028291141015610526, 0.026307832349890044, 0.024478851385148506, 0.06823126266577415, 0.04390430982623782, 0.054336663601653915, 0.02529850642063788, 0.04194274651152747, 0.01118075245592211, 0.00629325199406594, 0.011609879205934703, 0.05354324242632304, 0.01964268973097205, 0.04021021590701171, 0.01798787683115474, 0.013708614311846239, 0.031455075168716054, 0.01957045289288674, 0.04454875524554934, 0.02977908688730427, 0.02795497271498399, 0.04982864657150848, 0.058230762502976825, 0.030838822879429375, 0.007905863408398415, 0.017118025471323302, 0.026147743886602775, 0.035906753436263115, 0.04836021536695106, 0.04257845579247389, 0.0630952004077179, 0.032250694797507355, 0.009150605366033102, 0.030231401723410403, 0.01668128979924534, 0.04050044229786311, 0.07625688665679523, 0.03501323477498122, 0.025915225202749883, 0.010463906501952027, 0.04334494930558971, 0.039999262762389014, 0.014580776083416172, 0.03621653520635196, 0.059782069974711964, 0.0077301067233617815, 0.01847839997416096, 0.03138661098533443, 0.013057207123243382, 0.034141398700220246, 0.029395463543811014, 0.04079135740175843, 0.019155713629775813, 0.019753579316394668, 0.0313008780857282, 0.04905613784545234, 0.02344259779368128, 0.03860834739836199, 0.03858761476086719, 0.012327914292524968, 0.033600684321884594, 0.05056806653738022, 0.014821350674277969, 0.04294609624360289, 0.03282791096717119, 0.039961044277463637, 0.030737436176942926, 0.07291604485362768, 0.014746386125417692, 0.021803949294345717, 0.04279892539073314, 0.03035653375887445, 0.03971387093354549, 0.04241419264248439, 0.025974853163851157, 0.022601521407653178, 0.07550575517650161, 0.03825704607048205, 0.03722891963220068, 0.023499179132548825, 0.007016469815945519, 0.015163079569382327, 0.03631477350635188, 0.007247778587043285, 0.05108619587762015, 0.01693619504970099, 0.02911878071193184, 0.05131754239222833, 0.014343254900138293, 0.0169522814186556, 0.05696991551667452, 0.06336184431399618, 0.012494128230693085, 0.018288815593613044, 0.004441307707955795, 0.05717513843306473, 0.038883167651614974, 0.015562356715755803, 0.013066612466770624, 0.10090403338628155, 0.041566682048141956, 0.0020600251071820302, 0.041964608909828324, 0.03580106821443353, 0.02636434244258063, 0.05424005039302366, 0.0407366505158799, 0.03178295007507716, 0.012703876975657684, 0.02779120998457074, 0.036348289743598015, 0.052643440530768464, 0.03407285648531147, 0.04399193923122116, 0.02783672102460904, 0.026524999178946018, 0.0488956100307405, 0.02188556857540139, 0.05197837103956512, 0.06469091799642358, 0.017579193493085246, 0.08947903037603412, 0.027643263905442188, 0.024739352853170464, 0.03447877988219261, 0.0047703467259582666, 0.014150464441627264, 0.011813301460019179, 0.031849772203713655, 0.03846226559419717, 0.047211469151079655, 0.06618330148713929, 0.04867981553875974, 0.046955403605742116, 0.02932967957375305, 0.04722207126074603, 0.03463816097272294, 0.05103725314672504, 0.044567842435623915, 0.02581586901630674, 0.023683397997436777, 0.05541208732341017, 0.04092587357653039, 0.04091113240325025, 0.006956651865039021, 0.105221680631595, 0.02875108937067645, 0.017300407202648263, 0.004675219509018851, 0.023405419163671986, 0.03211695554533175, 0.06611966847309045, 0.026772002889109508, 0.03497003923569407, 0.05043618647115571, 0.01970132363827101, 0.04935244730274592, 0.05492232074694974, 0.008611494026679014, 0.0008263153337923411, 0.005279752650364701, 0.023880422514464174, 0.014750386089352625, 0.03956007079354354, 0.0289293846248516, 0.06500510685145855, 0.06449769157916307, 0.042651418663029156, 0.027331879096371785, 0.04214890241356833, 0.024205978527399044, 0.04335900515850101, 0.016176571703648994, 0.05214537886370506, 0.07463447550045592, 0.038374252816928286, 0.07808181337480034, 0.03961163266961064, 0.024057971380118812, 0.050374721376491446, 0.054599619670105834, 0.03625412604638508, 0.039137431686478, 0.09634910923029695, 0.04745582996734551, 0.02391245954536966, 0.012225688751121717, 0.08573498270873513, 0.025707783476848687, 0.029972632216023545, 0.02162104000204376, 0.032197714783251286, 0.034946453358445845, 0.011027872579039207, 0.016371838814978088, 0.009291969655480768, 0.04137914514701281, 0.008687274513899215, 0.06413025129586458, 0.041320706318531714, 0.029076016042381525, 0.020666541398635933, 0.06526364904961415, 0.025019635313323567, 0.0236967668336417, 0.03362009720876813, 0.024054329343406216, 0.011048137027371143, 0.07171061382229839, 0.029646127950400114, 0.022036661360678927, 0.04529361366959555, 0.03114609406994922, 0.0499857715331018, 0.01813615539244243, 0.07613635848143271, 0.026228009490296245, 0.06651576329022646, 0.01197075127025268, 0.028149183008021543, 0.0588864308914968, 0.020896949838580828, 0.05545230409396546, 0.04401115873562438, 0.05065309376056705, 0.017053177879591073, 0.034793993325105736, 0.015704472482736622, 0.015423796472272702, 0.02083620399103633, 0.018945547585774745, 0.04930500074156693, 0.06117192682410989, 0.01972855664124446, 0.0232839970184224, 0.11903794961316244, 0.017242804668577652, 0.03868495400196739, 0.049033610482833216, 0.06424896099737712, 0.1177986596844026, 0.08648922187941414, 0.09356014709919691, 0.1096932196191379, 0.09301165331687246, 0.09345576805727822, 0.12480283741440092, 0.1583026269716876, 0.1683654370052474, 0.12486395984888077, 0.08852339522647006, 0.07720984837838582, 0.1809656558824437, 0.1659146635127919, 0.1410039466406618, 0.12150909272687775, 0.09071699037615742, 0.15132188584123338, 0.11668348738125392, 0.1505147684365511, 0.10858329239168338, 0.11213272943028382, 0.2068232140902962, 0.19875640980899334, 0.1660984650786434, 0.13771476170846395, 0.11192702475403037, 0.16209459278200353, 0.09220589976757765, 0.13301877012210234, 0.11299692520073482, 0.14391012569623335, 0.16479510787342275, 0.1594576971339328, 0.09858904153640781, 0.1267614151750292, 0.15733982649232658, 0.09847130892532212, 0.06951235035168273, 0.0998745464852878, 0.11059871781617403, 0.1259702704846859, 0.12570462402488503, 0.14062301708119257, 0.14125766445483479, 0.1341526699917657, 0.10620924763913665, 0.20215414677347454, 0.09941992802279336, 0.1283165088721684, 0.22704190202057362, 0.1277876179665327, 0.15932247867541655, 0.13591283054224082, 0.1792925920869623, 0.10139154722648007, 0.1408135768558298, 0.12785583787730762, 0.17598250827619008, 0.051180223867829354, 0.1695842623178448, 0.09922651161572763, 0.09793274889567069, 0.11875037290155888, 0.19398157245346478, 0.13102604847933563, 0.18949543817767076, 0.17387971468269825, 0.2077679926795619, 0.30975742425237385, 0.14203474989959172, 0.13518073196922029, 0.13269299188894884, 0.09503363338964325, 0.16339565653886112, 0.2456582295043128, 0.09612382881875549, 0.15699681346969946, 0.09770016744732857, 0.1616963062967573, 0.16961653344333172, 0.1568265961749213, 0.07260324699538094, 0.08170883410743304, 0.13120689163250582, 0.10190361046365329, 0.1050696141485657, 0.16572069749236107, 0.1795032364981515, 0.2740116837833609, 0.14124878921679088, 0.21124752025519097, 0.14501464499958924, 0.09604155644774437, 0.1307303157768079, 0.11855902602630002, 0.07985336652823857, 0.14261525017874582, 0.11037951707839966, 0.12087113410234451, 0.1023104532754847, 0.16670846806040832, 0.18465415867311613, 0.0899020494627101, 0.10642635848905359, 0.13336597649114473, 0.10925893006580216, 0.1207544125084366, 0.06786769003208194, 0.23543704939740046, 0.11934352107346058, 0.10578715136008603, 0.13854034883635385, 0.14510917849838734, 0.12826491306935037, 0.14304229297808238, 0.08957906000848327, 0.18111147305795125, 0.11351152615887777, 0.2009593416005373, 0.08613930137029716, 0.12966359087399074, 0.06113046833447047, 0.2049463183752128, 0.0650486077315041, 0.08482018858194351, 0.10829406683998448, 0.11700218170881271, 0.18267514343772615, 0.1577200639460768, 0.06844482477754354, 0.08727655320295266, 0.11845324241689273, 0.11286153032311372, 0.1722309152994837, 0.0808125300598996, 0.12071307615510055, 0.07702787885708468, 0.13355496206453868, 0.07539313193410635, 0.09750620821224791, 0.17884960371468747, 0.12106982272650514, 0.09930638875812292, 0.18897634531770433, 0.08376050008726971, 0.10866850960467543, 0.1282295613948788, 0.1572589994009052, 0.10707710749868836, 0.07773090898990631, 0.18143194514725888, 0.17143978417984077, 0.1668661053159407, 0.1537619520510946, 0.13691119982727937, 0.156823529196637, 0.07184940816036292, 0.08968273337398257, 0.22293411887117795, 0.17365494317242078, 0.1332383711955377, 0.11784887127578259, 0.16433629606451305, 0.05946710080440555, 0.1159917480711426, 0.14386722871235438, 0.13609846415264265, 0.2212354607347931, 0.10043623777372496, 0.08327384798654489, 0.15585418763969625, 0.09541226950074945, 0.15187818956162247, 0.15319990792444774, 0.1454024277627468], [0.018356835336557457, 0.03609931828188045, 0.03956575013164963, 0.061755385515945296, 0.03541215229779482, 0.022914198825934103, 0.04509123042225838, 0.022379109502903054, 0.0747042696124741, 0.04079520469531417, 0.033255103044211864, 0.027377490220325332, 0.024124701906527792, 0.05613421821700675, 0.017236243234947324, 0.033205861757908545, 0.05114622587071998, 0.0405593357448067, 0.03693028958514333, 0.022281571790309887, 0.013683756181438054, 0.06337650745574917, 0.02183033412854586, 0.026721706480852196, 0.042096814672861776, 0.1402919055627925, 0.04722561999889357, 0.03558374362598572, 0.07013216494981732, 0.067072046654565, 0.003602983205512698, 0.03858191506671054, 0.025304782869560376, 0.02743812071691666, 0.045874680525490215, 0.04430752247571945, 0.022224412000338947, 0.03457267555807318, 0.0603701291339738, 0.01001503862374063, 0.03175706057144063, 0.052856520882674625, 0.027417293084519248, 0.0646830809169582, 0.020744118307318007, 0.02319070863138352, 0.04830379857282553, 0.046194955839642456, 0.04535833912502442, 0.04975246744496482, 0.023908425654683794, 0.04714431454028402, 0.09655951615422964, 0.014980397586311613, 0.0419712958724371, 0.024880135298839638, 0.021452834563595907, 0.05093909627092736, 0.027782363584265113, 0.04059754405170679, 0.0531083523694958, 0.018926648689167838, 0.024798154697886536, 0.05782005204153912, 0.0947843531944922, 0.042685372555362325, 0.021286722405680587, 0.0029168837936595082, 0.008670152530872395, 0.013490678193712873, 0.025857665077117935, 0.016149772963087474, 0.07018757411944014, 0.03747326687776616, 0.10255074288163867, 0.015649014119324938, 0.05039280094206333, 0.03436245183859553, 0.014485974563285708, 0.01684588034238134, 0.08450388948300055, 0.011827889114751347, 0.0017193287515380818, 0.01979846610421581, 0.046996970660984516, 0.045386562789125104, 0.029988944197871854, 0.015924989578447173, 0.04675919163439955, 0.04472080458487783, 0.027867375540414026, 0.02674055957634534, 0.043775632445301325, 0.034926816555006165, 0.0061923890357970125, 0.03903811790847352, 0.019809300612126077, 0.02143386102813695, 0.013909575180150568, 0.013175993159945523, 0.0434562052999224, 0.032562905722962956, 0.005857278825715184, 0.04967366578057408, 0.021686340515900935, 0.014497443501438414, 0.017287079078544463, 0.04237549239769578, 0.001695800549766448, 0.03035129207585539, 0.026626826929194585, 0.024486242327839136, 0.010611512465402484, 0.039138547876583676, 0.014426314371771045, 0.07142379028456551, 0.0706681397610477, 0.019761608082002828, 0.04511252285114356, 0.013453785396580185, 0.0077064809821812165, 0.01192616727868361, 0.015835316086720144, 0.08287037070840597, 0.035863093100488186, 0.06981686329735176, 0.01749324006959796, 0.010486240482090839, 0.007955249731561967, 0.02586784310239766, 0.034333709095205577, 0.03354136000520416, 0.02974899046655212, 0.03859168257830398, 0.04039940843358636, 0.06856058963707515, 0.0490815625526011, 0.06890245593552079, 0.026156681889135922, 0.026863443964560117, 0.03962675042982612, 0.057180051026599746, 0.015632028691470623, 0.022242835922432796, 0.021515415848365853, 0.050872562519673786, 0.015758665378338525, 0.025134355228926455, 0.04380479927307793, 0.0647028534274016, 0.04084352995934231, 0.026338469902319566, 0.03474105063027569, 0.05092085724962609, 0.039925502613186836, 0.011347065629836704, 0.04408856601055179, 0.10486878813909632, 0.03809155477210879, 0.04007816620703254, 0.03823799619983349, 0.03481324675625988, 0.021239157100873332, 0.07771470557366099, 0.004813639804654355, 0.024199583334848285, 0.06498291197099856, 0.024304576450958848, 0.03807516475873334, 0.03735321706959179, 0.06475624056266886, 0.05129818718082138, 0.03041779190035803, 0.04874671230624829, 0.05752184268619333, 0.005025370720042182, 0.0324535428413323, 0.03287792578339577, 0.03540054934897593, 0.014163366785006863, 0.02570164273492992, 0.014764564078567284, 0.020228241703339984, 0.05947228481194802, 0.06386866926082543, 0.018663190504802123, 0.044384773687592576, 0.009654360790071743, 0.04366957063653639, 0.044021767630640946, 0.02713561793124037, 0.033135076984763145, 0.026302882436929003, 0.022847587043153386, 0.04423384035804442, 0.023872329288029244, 0.007549959916754493, 0.016657486790791154, 0.016341945954731533, 0.014159511009763395, 0.04026091943628021, 0.04595512763730117, 0.0528851991652378, 0.028320721749748503, 0.05300441098266414, 0.030485574156045914, 0.015711765037849545, 0.018972013844177127, 0.04229197830760053, 0.02748080396226474, 0.01325081182377679, 0.016463335869567733, 0.03470741564940129, 0.056703417495425255, 0.016408886826996292, 0.003692361958591001, 0.04174882459587284, 0.03813440086586135, 0.06706511202667441, 0.062493794464639256, 0.055716420457299264, 0.031182884238660336, 0.05099235787721617, 0.046203786972910166, 0.052295630265559466, 0.036393486961190186, 0.0417165670410863, 0.03219719909663711, 0.01609816698224417, 0.030129343271255493, 0.015423326586772288, 0.011258038442714937, 0.01309199646181826, 0.07396877157901015, 0.03959975830678429, 0.026522361374061023, 0.07677509063588721, 0.05234277487865516, 0.02761977811210922, 0.07961151629154171, 0.024166815182460204, 0.10967892967164516, 0.007919883638221239, 0.042974757562790594, 0.043791215002004585, 0.014557699107431939, 0.040738326497375965, 0.06998312473297119, 0.03724881088627236, 0.02313921969783093, 0.030042650244597877, 0.05249448513079967, 0.05098334353949342, 0.031482857785054615, 0.03948797984048724, 0.0449388009229941, 0.03457501311121242, 0.049647718601460965, 0.03437472992975797, 0.04827960201406053, 0.017385005252435803, 0.011114217008330991, 0.027710988485653485, 0.05816637631505728, 0.04494095527167831, 0.024125483918136785, 0.028011435310223272, 0.039479582969631465, 0.012891011844788278, 0.06884281949273177, 0.07062708839241948, 0.02249416529334017, 0.02330484670320792, 0.055152035384838066, 0.04391887118773801, 0.01805352170153388, 0.029448497840868573, 0.04153840410123978, 0.025737515185028315, 0.01623295117834849, 0.04038966127804347, 0.028649963904172182, 0.04334518000749605, 0.05221289988341076, 0.045306417625397444, 0.009183809477170663, 0.010330554014737052, 0.026504246185400655, 0.014504440893818225, 0.03905824664980173, 0.032013519667088985, 0.06225782712655408, 0.06048332913113492, 0.08310468920639583, 0.010794330155476928, 0.03541239996307662, 0.015521229011937976, 0.052798170263745954, 0.004031895792910031, 0.04932538054085203, 0.015911378165973083, 0.018690611801243255, 0.08251342736184597, 0.07692944378192935, 0.04133359509121094, 0.008325037746024984, 0.014208251028321683, 0.005295593898543822, 0.06447710482669727, 0.06382270529866219, 0.034359130409679244, 0.03970858175307512, 0.03962284206811871, 0.03901762275823525, 0.027065728824319582, 0.061123777979186604, 0.04160019828538809, 0.034230924610580714, 0.011900191261832203, 0.026032684703490565, 0.030036879304264272, 0.08358176717800753, 0.02630019374191761, 0.07201256190559693, 0.0375248592879091, 0.04705632211906569, 0.02665389538742602, 0.014959390142134257, 0.08274104871920177, 0.028143128779317652, 0.009331402718089521, 0.06788259744644165, 0.09088753336774451, 0.0664931545034051, 0.009590234141796827, 0.029681018221059015, 0.0426937219287668, 0.06449868902564049, 0.029052477662584612, 0.020215347841648117, 0.019758561459769095, 0.04439383552276662, 0.06804772572857992, 0.04389220476150513, 0.05072133742006762, 0.030738009539033686, 0.09514295216649771, 0.040974992726530345, 0.07541126238980464, 0.01974697208165058, 0.09908056551856653, 0.019528929942420552, 0.05182559209476624, 0.1410159431397915, 0.12620786630681582, 0.16336943794574055, 0.16800517562244618, 0.08595452271401882, 0.11891174209969384, 0.15526008951876843, 0.16173931184623921, 0.13127148816628115, 0.13781982607075147, 0.09609565604478121, 0.0572503065424306, 0.1847017239779234, 0.09391540767891066, 0.10501821512090308, 0.18023716711572238, 0.07574708294123411, 0.09813426022550889, 0.09904866758733988, 0.06486094530139651, 0.08580122808260576, 0.08523784724197217, 0.12454327062836715, 0.08979786041059665, 0.17639574967324734, 0.1864491416407483, 0.19913296960294247, 0.19277524575591087, 0.221856523837362, 0.1267839561083487, 0.1261069138667413, 0.12324433747146811, 0.10345856166843857, 0.13252300529607705, 0.08085772049214159, 0.18024912290275097, 0.12687766179442406, 0.15829999425581523, 0.08404261459197317, 0.10281517476375614, 0.12054288600172315, 0.14979842544666358, 0.14974226988852024, 0.1340319857533489, 0.1144631172397307, 0.21368112681167467, 0.1387258738811527, 0.11450720844524247, 0.1598864769829171, 0.11873832211962768, 0.17590504671846116, 0.1377606713878257, 0.15365949326327868, 0.07374886516481638, 0.07504937252295868, 0.13732305701289857, 0.20100164147359983, 0.10852651936667305, 0.12880445697477885, 0.1553929466754198, 0.1456679520862443, 0.08075883758387395, 0.2582461397562708, 0.1673170325479337, 0.23347752168774605, 0.10013600638402359, 0.14091451572520391, 0.12278943402426583, 0.09024697595408984, 0.12469234477196421, 0.11119019679192986, 0.09134696264352117, 0.11525157493140016, 0.2014798458133425, 0.18213968431310995, 0.17770866065153054, 0.1967815879200186, 0.10251960490963288, 0.07566763327590056, 0.12588003889790603, 0.1533471228820937, 0.1275434267840215, 0.07623167229550225, 0.1507043239793607, 0.11530009018523352, 0.12965599128178187, 0.21099921715046677, 0.16115839087537356, 0.16645684013409273, 0.09049426125628607, 0.12568407798452036, 0.11182693405342953, 0.14087107591331005, 0.10809359366872481, 0.14016316032835416, 0.10093053017875978, 0.11074593277381999, 0.14566719212702342, 0.11847586477441446, 0.09591438541454927, 0.1856373559151377, 0.06997697720570223, 0.11945543863943645, 0.09468483924865723, 0.06172075308859348, 0.13309123766209396, 0.09044955258390733, 0.13100635739309446, 0.17252979640449795, 0.07286288163491658, 0.1078633124540959, 0.15904711559414864, 0.1252502498349973, 0.10316599772444793, 0.14871631136962346, 0.1530675935958113, 0.11608164039041315, 0.11307150976998465, 0.18072822290871823, 0.0802716426551342, 0.14619125186332635, 0.10838066826441459, 0.1202959128256355, 0.07372293834175382, 0.09300319198518991, 0.15458213804023607, 0.11689818943185465, 0.09532857899154935, 0.12191674299538136, 0.06703804526478052, 0.06736296175846032, 0.25802442165357725, 0.11330660858324595, 0.15973544865846634, 0.19369107804128102, 0.11706672395978655, 0.13013191574386188, 0.17540865764021873, 0.15005370389137948, 0.11494532493608338, 0.186375995565738, 0.09995462718818869, 0.12290118874183723, 0.19363520746784552, 0.11018785129168204, 0.1499531857137169, 0.2024850683020694, 0.1437995923416955, 0.18162217922508717, 0.0697387774874057, 0.07888089692486183, 0.1606009607868535, 0.11639010240989071, 0.14238068062279904, 0.21231033679630074, 0.16980828743960175, 0.21300696155854634, 0.08392811180757624, 0.1598264809165682, 0.1514359882899693, 0.11089188565633126, 0.08706622091787201, 0.18380015449864523, 0.07225908724857227, 0.15098645884011472, 0.21090898556368692, 0.06830526369490794, 0.13022066812430108, 0.1573544828487294, 0.18373793283743517, 0.16971600667706557, 0.20029677929622786, 0.0986442200041243, 0.15693144340600285, 0.09538385245416846], [0.02570273687264749, 0.024935983819887042, 0.0025341720195553663, 0.012608454595985157, 0.034423916933259795, 0.02280993343863104, 0.03528799396008253, 0.021258990679468428, 0.03840183187276125, 0.003535928890674508, 0.012122150244457381, 0.020984474070636288, 0.0364188336368118, 0.06812895315566234, 0.05789744574576616, 0.0019892373654459205, 0.016227051316361343, 0.023275399979736124, 0.056842154158013206, 0.008042519512985433, 0.0212247653731278, 0.017006216470950415, 0.026595451469932283, 0.03831798190783177, 0.020119336832846915, 0.0256420605749424, 0.0633824174957616, 0.03763031041515725, 0.027405461130131568, 0.04466597217002085, 0.02544524979644588, 0.0719588083614196, 0.014063209927241718, 0.016568817530891726, 0.02610265014560095, 0.023053876955860426, 0.009635181997769644, 0.013221129309386015, 0.01829692578342344, 0.034835316107741425, 0.013668307635400976, 0.03237769280427268, 0.03407628647983074, 0.03186200958277498, 0.02052075306086668, 0.02473233001572745, 0.033588263738368235, 0.04742906854621001, 0.030717466891344105, 0.01846062744568501, 0.017304625994126712, 0.03536485840699502, 0.0336553538883371, 0.008310221085724021, 0.05528770506914173, 0.030513210887355462, 0.04879885093708124, 0.038695478080106635, 0.03765727878947343, 0.018946448341012, 0.0452598497670676, 0.05404750929613199, 0.012500018762823726, 0.03698745955313955, 0.04765632688733084, 0.03786357379119311, 0.023721947268183743, 0.09666544225599084, 0.018561562922384058, 0.018199126834848096, 0.016589619718225937, 0.025890423051480736, 0.014265545677127582, 0.024229818855279257, 0.07396405576063053, 0.06277943056608949, 0.022386664990335703, 0.029109572991728783, 0.034250646230897734, 0.056251665843384605, 0.045980677873428376, 0.02447400494877781, 0.036389799123363833, 0.0378262781138931, 0.05170640063339046, 0.0163756487891078, 0.04499471899388092, 0.03785678165565644, 0.05236207241458552, 0.0372347346773105, 0.038599672328148565, 0.04940456557752831, 0.031449819914996624, 0.04896646605006286, 0.006528394912103457, 0.0477807498537004, 0.04320824485538261, 0.018755659560805986, 0.03137544908427766, 0.020475367549806833, 0.03778010380587407, 0.08419795839914254, 0.04890013925198998, 0.020989452821335623, 0.09349251072853804, 0.06589676293411426, 0.05247334197961858, 0.00786798249464482, 0.024047298024275472, 0.008103842963464558, 0.027995038511497632, 0.09216600190848112, 0.002716490562306717, 0.05691824846767953, 0.041133318695106676, 0.011233767245097883, 0.030384102636682134, 0.013924131452638124, 0.010421407309227755, 0.013976443109900823, 0.0307463351637125, 0.04345915014190333, 0.029399022459983826, 0.052180896779256206, 0.04652933111148221, 0.0277512934657612, 0.030159385409206152, 0.024503341410309076, 0.03375373807336603, 0.05692984123847314, 0.020514559732483964, 0.06573949208749191, 0.02368284499139658, 0.044420037152511735, 0.02044959339712347, 0.009810328001289495, 0.012471958795296294, 0.060237285548022816, 0.0445567585660943, 0.0206476306276662, 0.04575469517814262, 0.026565053101096834, 0.06794672579105411, 0.11086979934147426, 0.03907348654632058, 0.032424413332981725, 0.0064050894080927324, 0.03863488829561642, 0.07149481933031764, 0.08718054728316409, 0.010647869219870439, 0.017590275666277324, 0.003814001235046557, 0.020985987203727876, 0.028463689078177725, 0.03323169358606849, 0.037288474650787454, 0.03131535463035107, 0.00965629207036857, 0.07341673584388834, 0.025042150801579868, 0.01995150967767196, 0.0282987338224692, 0.08160119809742485, 0.03743883801091995, 0.037935311906039715, 0.01927515784544604, 0.02059952249484403, 0.011567955919807511, 0.00766013449590121, 0.0591983873663204, 0.03846615020717893, 0.0370736335005079, 0.016943645364205753, 0.05546525054212127, 0.027313012430178266, 0.06468390872968094, 0.024377176305279136, 0.0869163189615522, 0.012381582171656191, 0.01878367118271334, 0.04402889564101185, 0.02598793022999806, 0.04675915092229843, 0.03405317896977067, 0.011970640160143375, 0.035710477004093785, 0.03205921560791986, 0.02350113500974008, 0.09030917047389916, 0.020986429947827543, 0.06244199510131564, 0.020562985080427358, 0.048087040561118295, 0.058721872578774176, 0.011982363548928072, 0.013673429726622999, 0.03294314317671316, 0.036584101018628905, 0.06187313169773136, 0.04093618052346366, 0.03600138532263892, 0.0188980518308069, 0.03697808898453202, 0.03929109611947622, 0.0781112550092595, 0.03195339807176164, 0.07578599013920341, 0.01780748151109687, 0.006199984811246395, 0.02635502615677459, 0.054477754780756574, 0.07093377943549838, 0.01701422148783292, 0.037087075279227326, 0.06992467572646481, 0.05333045384447489, 0.023553458541365604, 0.021221435462523783, 0.012234725141232567, 0.013753320439718664, 0.06697625108063221, 0.0431284762785903, 0.031106569405112947, 0.025589411346507922, 0.05336254855085697, 0.02109504644093769, 0.08571851466383253, 0.03322216356173158, 0.04683596447908452, 0.04661371033372624, 0.055798421414302926, 0.06047122406640223, 0.02684244839474559, 0.02096909168176353, 0.016618328534864953, 0.03851484866546733, 0.014788787778733032, 0.02729578612239233, 0.07558069936931133, 0.03988176763855985, 0.0401003271607416, 0.05344723989920957, 0.07114785723388195, 0.025340322837499634, 0.053787728771567345, 0.03391843887844256, 0.026418738898688128, 0.06116708208407674, 0.03444398460643632, 0.05292353639379144, 0.03815976789753352, 0.03408838475921324, 0.03053157204496009, 0.05405765678733587, 0.03870020407651152, 0.04969422199896403, 0.010170471488631197, 0.015300348899992449, 0.11340673321059772, 0.021044639770739844, 0.02017460690279092, 0.024998911157516495, 0.05419028324208089, 0.07698046961533171, 0.026982204556199055, 0.008693134511954017, 0.01639342979927148, 0.025302016143021838, 0.04235772495823247, 0.028332338269267763, 0.03066642748724137, 0.004203690257522145, 0.007898005124713694, 0.012685876289781715, 0.03316445415839553, 0.036368459197027345, 0.021442424140072296, 0.04098453292889254, 0.028408705689279095, 0.022539988459487046, 0.06182589887508324, 0.01872739688094173, 0.0516678734150316, 0.021652266183601956, 0.03014410819326128, 0.07605625063713108, 0.01801337787349309, 0.05996668578258582, 0.006278449328549738, 0.014515068448547806, 0.0397626609940614, 0.01794255238824657, 0.041974634264728854, 0.0570319743294801, 0.01218937270875488, 0.03568365112213152, 0.03712928355006235, 0.040219806999500306, 0.07403336811278548, 0.03558402521801846, 0.055566800093012195, 0.021106016655851687, 0.025940953554319482, 0.06175825571907418, 0.032824531862778325, 0.05743534304201603, 0.00735298204900963, 0.0383888514978545, 0.01339829819543021, 0.013809606615853096, 0.06874229452971901, 0.05827631934412888, 0.012566240387968719, 0.024674774979108145, 0.01023651669467134, 0.05750462146742003, 0.03840965538152626, 0.05580471821927598, 0.04572534853858607, 0.021916167112067342, 0.0652017802266138, 0.03672566717224462, 0.04715558500694377, 0.016461793898737857, 0.04937157181224652, 0.013121855395313884, 0.06032473514122622, 0.04425917685564075, 0.024776331315349256, 0.010834080433206899, 0.07824849550213132, 0.05497357728225844, 0.015093502588570118, 0.02502289228141308, 0.04091546484934432, 0.025073132710531354, 0.04048821170415197, 0.04243322215708239, 0.026514412336317555, 0.05837229133716651, 0.08760935427354914, 0.009527884407101997, 0.04389508853533438, 0.046003205236047506, 0.026810509751417806, 0.036802171995597224, 0.039782464038580656, 0.008872975977802915, 0.04228914203122258, 0.0398911280291421, 0.06816678148295198, 0.07474078158182756, 0.21989067218133382, 0.17517141465629849, 0.1670393624476024, 0.12680838336902006, 0.1387123574635812, 0.07201001061392681, 0.08031188656709023, 0.11689919366368226, 0.11803991959563323, 0.07443349342793226, 0.1581066253462008, 0.0885244265996984, 0.2542039709431784, 0.14012349317116396, 0.10815127593066011, 0.11784471864146845, 0.13348246738314629, 0.2748837912721293, 0.08259262596922261, 0.0917152375248926, 0.15264679331864628, 0.1294820691858019, 0.12850324170930044, 0.07502490455018622, 0.12738904649657862, 0.11627960976745401, 0.13058791841779435, 0.1186436800552266, 0.15405828186443873, 0.13351536276085035, 0.20638777102742875, 0.13726192100771836, 0.1809784666235958, 0.11351958715489932, 0.1776807592915637, 0.12737969628402165, 0.1182900954570089, 0.10492716250675065, 0.15255608675735338, 0.11728597219501223, 0.1063155537205083, 0.12399813559438501, 0.11166358353304011, 0.0951381888506668, 0.10495071445724793, 0.08885731587984733, 0.17556241367544445, 0.07613126946879284, 0.09632707041289125, 0.09941749208207641, 0.11092900830720152, 0.12590266125542776, 0.15316163854939596, 0.1546256321349314, 0.09358929696359805, 0.15280269352453096, 0.14087312508906635, 0.15472461682345184, 0.11000058241188526, 0.1436032514486994, 0.12340250398431506, 0.1481459755450487, 0.14491986722818442, 0.11847982741892338, 0.10060276383800165, 0.09911491296121053, 0.2015082628599235, 0.060500570705958774, 0.1381471242223467, 0.08280331787786313, 0.06345579427267824, 0.11901327807988439, 0.13690532371401787, 0.1597795398639781, 0.15677460682179245, 0.1634113849805934, 0.11541364980595452, 0.26275345789534704, 0.13833009797547544, 0.12803222984075546, 0.0957603986774172, 0.14898562191852502, 0.12394596982215132, 0.1383847878979785, 0.07660515832581691, 0.1544967783348901, 0.17660697762455257, 0.14838837539511068, 0.11276605366063969, 0.10704307218215295, 0.1896905577076333, 0.14444753900170326, 0.14906194353742258, 0.09642884388033833, 0.08944802811103207, 0.10809575141008411, 0.10146727851991143, 0.09393228963017464, 0.11500101909041405, 0.10956868808716536, 0.12612010458750383, 0.16271579159157618, 0.15828323444085463, 0.27471980292882237, 0.19829145047281468, 0.13347148868654454, 0.14672755237136567, 0.157346353999206, 0.08910441797758852, 0.12646033561655454, 0.15367315895855427, 0.11270451731979847, 0.12576115956263884, 0.07047987343477351, 0.10268719627388886, 0.09688348269888333, 0.09689120442739554, 0.06898626858102423, 0.1302452582333769, 0.0899463374433773, 0.12073252296873502, 0.13794635928102902, 0.2288534412426608, 0.10507806190954787, 0.13685636062707218, 0.1436493918299675, 0.060065677256456444, 0.17751868441700935, 0.11995040279413972, 0.21601893779422554, 0.14188446796366147, 0.08550493219601256, 0.1299392117985657, 0.07375330956918852, 0.1362994597958667, 0.12836757541767188, 0.12119094122733388, 0.12179756510470595, 0.15011821900095257, 0.08309311339897768, 0.06289341087852206, 0.17066339084080287, 0.16023931519261428, 0.11301302683672734, 0.16249890465821537, 0.07464667556009122, 0.11373494738446814, 0.18018778333706514, 0.14050101648483956, 0.08301950592015471, 0.16826193327350275, 0.1349799670279026, 0.11603824129062039, 0.08623360416718892, 0.11539908844445433, 0.13730544224381447, 0.09462916545037713, 0.12046937351780278, 0.2299084003482546, 0.278437713427203, 0.09171219090265886, 0.15436472184956074, 0.12590120919048786, 0.11114252292151962, 0.14229732938110828, 0.1353774257004261, 0.11714540688054902, 0.10292272934956209, 0.12881326435932092, 0.15438534931412765, 0.11491249741188117, 0.13429448381066322, 0.1287244576960802, 0.12870748074991362, 0.20125206160758222], [0.0008555302421362804, 0.020211814370538508, 0.08329721673258714, 0.031480428629687855, 0.017281460808590055, 0.027047844337565557, 0.021344827055664997, 0.054475851490029266, 0.028607423151178018, 0.021673344873956273, 0.06540437042713165, 0.028124927077442408, 0.07753081579825707, 0.04128375669409122, 0.014637925695361835, 0.07071410372321095, 0.020121146825009158, 0.03959805179121239, 0.011606539965474179, 0.054219219367951155, 0.040113677337233505, 0.007209063075216753, 0.01079808669497392, 0.07840095553547144, 0.02542533479364855, 0.0764022356431399, 0.027811143647081087, 0.04885076904403312, 0.05597291687237365, 0.037965391363416395, 0.04825337663558977, 0.06289798420454774, 0.022122233108218228, 0.01769002540303128, 0.04178347737927522, 0.03909088757687381, 0.040538623463362455, 0.024457321469006792, 0.026914602112291113, 0.05544453826067703, 0.028823804575949907, 0.06648138870618173, 0.029519978112408092, 0.06529931285019432, 0.03369423394490566, 0.048107790161988566, 0.04228675698063203, 0.05918124078639916, 0.04757343365677765, 0.06696306035986968, 0.030605264340660403, 0.016861888679808805, 0.06835733447223902, 0.01359692744777671, 0.06496606394648552, 0.05347848643681832, 0.027672235654400926, 0.007234601436981133, 0.03113663868446435, 0.03862946680081742, 0.016668355225452354, 0.025086696625554135, 0.015545043894754989, 0.031339612257267745, 0.02615493975047554, 0.02285678288899362, 0.019557263868461763, 0.05004861066117883, 0.011840922076122036, 0.03288919285738042, 0.05875809956341982, 0.036036750567810874, 0.007878983243634658, 0.030290610689137663, 0.027648687096578733, 0.027196501182126145, 0.02459285205363163, 0.05118976067751646, 0.026411799181784903, 0.037595973150538545, 0.033875297621956894, 0.02071473604467298, 0.03963691149173038, 0.016492426362154738, 0.025873388429837565, 0.06682879185037953, 0.03631216793188027, 0.03516400186344981, 0.030971469690224955, 0.033900342349495204, 0.04759681936619537, 0.08718063549271651, 0.032353007700294256, 0.04897968730490122, 0.030212392564862967, 0.019605165048103248, 0.037447943950870206, 0.03860875451937318, 0.01805670403077134, 0.019617943558841944, 0.031034966997270073, 0.04825640629444804, 0.02566689156394984, 0.03610105872420328, 0.049814309126564434, 0.06072226166725159, 0.019988206547818015, 0.027501180368874754, 0.054160139323877435, 0.016678295763475553, 0.02914177965638893, 0.020834176867668117, 0.03749479340123279, 0.02110387078885521, 0.09932619519531727, 0.06056868883648089, 0.05814740447593587, 0.012881369862173284, 0.03681531521890845, 0.011705876644035535, 0.02821074818660106, 0.016282311208280068, 0.00944437540601939, 0.04510059081284063, 0.017759900939251696, 0.044504368877304454, 0.024980064847373536, 0.026166953212980713, 0.0059441219782456756, 0.050164178745555024, 0.021363463019952178, 0.033141190585281165, 0.0704944890790752, 0.010262332407624593, 0.03660692693665624, 0.04077945250485625, 0.008756544457615485, 0.02446408137413008, 0.03162503462018711, 0.026053507246875336, 0.05143321904220751, 0.02326925584514226, 0.038989446591585875, 0.015861046134627292, 0.022108764188098054, 0.002130105688203392, 0.03138768307066389, 0.03108861536851951, 0.06281077888395105, 0.008010576628813786, 0.01928541050957782, 0.014907706129763807, 0.05406206726495709, 0.014838914553235685, 0.09435113572648593, 0.0370667056579675, 0.040401009776230366, 0.012423938872026545, 0.04062902468389698, 0.07488248683512211, 0.039509370656950135, 0.07936401385813951, 0.04415880795568228, 0.07211717843477215, 0.030961719142006974, 0.03800286685249635, 0.011691401795750218, 0.015037660852872899, 0.053735515501882346, 0.034874901840729375, 0.02678563805030925, 0.03123243765107223, 0.017475253802591136, 0.05596095769266997, 0.029070869354265075, 0.006560342461203358, 0.005446953856984952, 0.008456004334480634, 0.03989773017487355, 0.03041606502873557, 0.01870079830821071, 0.025761297837431942, 0.04964193409042699, 0.08790640333401305, 0.05948668332504375, 0.0218251687807164, 0.03849020766626511, 0.04786560744313257, 0.04877915645816496, 0.09124280073280845, 0.029909039914075817, 0.05329153986115541, 0.01655033932599638, 0.003945855008039091, 0.06269525829702616, 0.07429231064660208, 0.03820392356387206, 0.019749981384458284, 0.01705997171146529, 0.04246130332882915, 0.03363719629123807, 0.07535405510238238, 0.021912609892232076, 0.005478777997528336, 0.04283329997477787, 0.03663322016862886, 0.05358027347496577, 0.03984285704791546, 0.054402535781264305, 0.05568083129557116, 0.01754180112454508, 0.03459994248779757, 0.05222967326907175, 0.049877429846674204, 0.04306353708463056, 0.03881360424150314, 0.00239643407569799, 0.048862226107822995, 0.05800695451242583, 0.029297357558139732, 0.04319943068549037, 0.02172774133006377, 0.028447494143620133, 0.03082402403067265, 0.04900242162070104, 0.0356764315095331, 0.07359240856021643, 0.010401968977281024, 0.07052493494536195, 0.06532232875802688, 0.059268717521003315, 0.048189071871872456, 0.0747032178831952, 0.03886209913928594, 0.06522816845348903, 0.032560829405805895, 0.011264848389795848, 0.014142179529049566, 0.10460596438497305, 0.05279983267454164, 0.03256381835256304, 0.07094257324934006, 0.09737673015998942, 0.017484402150980065, 0.010525646403298845, 0.019596433998750787, 0.034541361166962554, 0.040922725174043856, 0.04171836855156081, 0.06360001689089195, 0.033429534041455815, 0.00972937114004578, 0.04139867338484951, 0.05439905828929373, 0.011878169407801968, 0.0048944728332571685, 0.047540982719510794, 0.009754906109135066, 0.04983910279614585, 0.006348751069578741, 0.06783752236515284, 0.024353380082175136, 0.08114391977765731, 0.030435532198420594, 0.04328064793454749, 0.02503088372759521, 0.05270544506077256, 0.08929142222872802, 0.03543791966512799, 0.012113647352504944, 0.03872409190184303, 0.04385048503588353, 0.010556813213042915, 0.05891492257692984, 0.03571587135749204, 0.0289368145833058, 0.012469194613264074, 0.03836462440501366, 0.02519715534123991, 0.04616316308134368, 0.01084176653863064, 0.011785946320742369, 0.03844934628744211, 0.017074919837926115, 0.07774652208068542, 0.09604408059801374, 0.03932003563802157, 0.04637426211099539, 0.01715619136978473, 0.04023786960169673, 0.03642069960811308, 0.005036167060357651, 0.010234492963978221, 0.042389921444867334, 0.05284964393026062, 0.01198993091072355, 0.030382969483200992, 0.032378052427832565, 0.03684978819053088, 0.036396350378968885, 0.12128896239612784, 0.005063614225946367, 0.03140121305893574, 0.03174814462129559, 0.0574159776525838, 0.043985547431345494, 0.036894666496664286, 0.023234321469707147, 0.051003404427319765, 0.0077105191137109485, 0.028398892376571894, 0.0349703242204019, 0.005404537360716079, 0.03557260208097952, 0.015377432174448456, 0.04051346338487097, 0.0861468602504049, 0.009324680132392262, 0.09161670745483466, 0.010137951849693698, 0.04419744713231921, 0.028221923658358197, 0.052247043765549145, 0.047664119862020016, 0.020089019888213704, 0.035236588147069724, 0.018261948999549662, 0.05192613402115447, 0.008210269484802015, 0.0299507664250476, 0.04116809022213731, 0.01812991456660841, 0.004940008046105504, 0.027408658726406947, 0.04692029281120215, 0.08813368542385952, 0.023558902088552713, 0.06333047564008407, 0.012771777126805058, 0.0012425809296213888, 0.07158848430429186, 0.06767403613775969, 0.0645213181685124, 0.03909761864425881, 0.019236544113872305, 0.025510952342301607, 0.01308839428903801, 0.009305996670653778, 0.01568716814342354, 0.027012463825355684, 0.008962875930592418, 0.023535029530259113, 0.07904230683509793, 0.10561649301754576, 0.21432393017624105, 0.13225868876491273, 0.10156504863074847, 0.21588238940707274, 0.15325161229286874, 0.2573001805160727, 0.09048870405448334, 0.1589004841766187, 0.13965208775230817, 0.07950468773820571, 0.1883358082601002, 0.18586541153490543, 0.09926931360470397, 0.10588524716773204, 0.0970447501167655, 0.10925021089081254, 0.20369579190654413, 0.1841950211673975, 0.12596523575484753, 0.12520719000271388, 0.1060798510110804, 0.14954244132552827, 0.0977404113592846, 0.20624780282378197, 0.09133576003036328, 0.18324850552848407, 0.1832419644509043, 0.10831103700080089, 0.09388488038842167, 0.12083053056682859, 0.15274305029639176, 0.11525807529687881, 0.11902474532169954, 0.15063925247107232, 0.263101084956101, 0.11271850871188299, 0.12170746922492981, 0.15084606994475636, 0.1106419540675623, 0.17178403213620186, 0.14592297268765314, 0.13142912542181356, 0.11063341131167752, 0.12449713024709906, 0.10024799858885151, 0.10770957677492074, 0.17564892689032213, 0.11282153746911458, 0.14938297202544554, 0.16824279858597688, 0.13040662743151188, 0.07990225497633219, 0.16251223108598165, 0.11746910879654543, 0.13609636069408484, 0.0774892894551158, 0.20617205117430004, 0.09255464641111237, 0.14157182616846903, 0.2284415704863412, 0.17038865201175213, 0.11103880205856902, 0.16755280989621366, 0.10372846932815653, 0.1521659426923309, 0.14065505750477314, 0.12559867756707327, 0.13645161448844842, 0.17081627835120472, 0.11396702671689646, 0.06122299336961337, 0.12367775849997997, 0.15505431698901312, 0.15771029304180825, 0.1485889232052224, 0.18854124152234622, 0.10263880315635886, 0.17545160890689918, 0.2007453859384571, 0.17214939610234328, 0.10611921282751219, 0.08963006548583508, 0.1378673099513565, 0.12670677953532763, 0.14316917902656964, 0.12877287795501097, 0.10042803428534951, 0.14279265994472162, 0.13653573926006043, 0.20466186292469501, 0.1332651868994747, 0.12853282583611353, 0.2036068495362997, 0.12638803092496737, 0.11737684160470963, 0.07024870333927018, 0.13323458497013363, 0.09624918816345078, 0.1313775431896959, 0.1464012177394969, 0.0760734040024025, 0.1809928244245904, 0.09948041263435568, 0.1367338036320039, 0.15278980135917664, 0.09363192931881972, 0.1551790724375418, 0.2131532129964658, 0.12370340712368488, 0.12110307094241891, 0.11468209406094891, 0.14504857175052166, 0.181704186967441, 0.10771738671298538, 0.12050034185605389, 0.09944974285151277, 0.1648560403180974, 0.08657838138086454, 0.11431743577122688, 0.06551165359893016, 0.07873104246599333, 0.1004989208387477, 0.16046809005950177, 0.10624523035117558, 0.1762371760393892, 0.12731227704456874, 0.1265857560294015, 0.0886767984234861, 0.131129579352481, 0.08164853270032577, 0.16957983826952322, 0.07108162543071167, 0.059469428179519515, 0.11752283519932202, 0.05400699057749339, 0.12618168842579636, 0.1047969109245709, 0.10875391002212252, 0.24042900438819612, 0.0979160705049123, 0.16270466361727032, 0.1705930946128709, 0.11040389684161969, 0.10539645089634828, 0.14520550332963467, 0.08715053567928926, 0.11721108907035419, 0.10477186619703259, 0.13763354106673173, 0.0936234069189855, 0.10532369837164879, 0.1328531125826495, 0.23037631809711456, 0.09469896634774548, 0.09506243720118489, 0.05703818292490073, 0.2039356811770371, 0.18840818080518926, 0.1385224083704608, 0.15229980408080987, 0.2839124325130667, 0.1704059410840273, 0.11391711368092469, 0.1434437550072159, 0.16314295652721608, 0.09433130893324103, 0.10840884782373905, 0.19098620675504208, 0.08038782820637737, 0.11550515703856945, 0.12347046605178288, 0.1708851225141968, 0.1708116778837783, 0.07491992161210094], [0.016204878488289456, 0.014199856701972229, 0.01356777164619416, 0.05565835143040333, 0.013933509654764618, 0.00690424266836739, 0.04593314649537206, 0.026625793859628693, 0.02402673502053533, 0.029156059425856386, 0.03676316301737513, 0.017976031306066682, 0.03169482873220529, 0.011150534747035375, 0.024058955255895853, 0.08135847255055394, 0.04307811880218131, 0.06740554661623069, 0.04560638438644154, 0.047729374574763436, 0.016259168075131517, 0.05780220657054867, 0.017034871004787937, 0.0256180387389447, 0.024403788448710526, 0.07250373304954597, 0.01667743402400187, 0.02893181038754327, 0.01068094525752323, 0.0497719515780253, 0.06223447873656239, 0.020510853234944598, 0.031136068715048686, 0.0575516778709633, 0.023222837264516523, 0.050788508994238715, 0.0650936895981431, 0.00519486579910985, 0.04045256147427218, 0.01651184942706355, 0.013031840939739985, 0.029613772008035864, 0.013656589335628917, 0.015103770519739814, 0.02767058851064316, 0.030127741928611482, 0.011298367171548307, 0.03265087100278054, 0.06130313514066594, 0.01730090083687433, 0.03807375679856964, 0.01815946985568319, 0.03553343364702804, 0.033602723319615634, 0.0313149848287659, 0.02024000241155071, 0.09406402041869504, 0.04891421885362693, 0.0353101990185678, 0.09895975914384637, 0.029950169314231192, 0.035974705325705666, 0.015594743192195892, 0.05984097359968083, 0.04970987580184426, 0.019960914173030427, 0.058817491733602116, 0.02658291214278766, 0.04638049106246658, 0.06100883414702756, 0.04497530271432229, 0.04472578163923962, 0.03862727513270719, 0.04765434217240129, 0.0195972821675241, 0.02472159219905734, 0.017868895715634738, 0.01755468311187412, 0.02444216638936528, 0.0172181076902364, 0.05560533409672124, 0.028854579531720707, 0.00842239988768207, 0.06469323858618736, 0.021248444548941085, 0.023451330539371287, 0.0212857622786292, 0.008108869211615195, 0.03769416056041207, 0.023600363970867226, 0.045468295724796395, 0.04552011883684567, 0.09375185359801565, 0.07338247661079679, 0.020820222795009613, 0.029875717059309994, 0.02638535158309553, 0.05186069949663111, 0.0619387256779841, 0.015796151045443754, 0.04388236600373473, 0.027899639880550758, 0.039316324051469564, 0.011979569680988789, 0.08438023326120206, 0.05551387096888252, 0.04440986930525728, 0.025208946583526473, 0.03304444506232228, 0.03682384779676795, 0.042884424195757935, 0.0031656985561962104, 0.03905094561300107, 0.023962297942489386, 0.033421133777924945, 0.0655220216140151, 0.06264632913683142, 0.036944352223404815, 0.04656403139233589, 0.015451736848003097, 0.021872691677084992, 0.05506134917959571, 0.09440740663558245, 0.0471987432268049, 0.05306020013189741, 0.004989744662972433, 0.04507397188405905, 0.03437963913061789, 0.03924455540254712, 0.04189068591222167, 0.028036590299702117, 0.03976396378129721, 0.03435089299455285, 0.045992857577013116, 0.0411609181069902, 0.0653976190036961, 0.07139939016529492, 0.03833878239882844, 0.04511565089757953, 0.03987572528421879, 0.012300770347272711, 0.022369050221251588, 0.0793907277818237, 0.004457336825518203, 0.044689178067658625, 0.0202692235221288, 0.052221958325909715, 0.03171257920829313, 0.01820443637136902, 0.05896075761743954, 0.06262230221182108, 0.02580242045223713, 0.011152496561408043, 0.02364996657706797, 0.01690455835445651, 0.04421333163710577, 0.0449400562127786, 0.018381389822544794, 0.017941022291779518, 0.05808741519493716, 0.003679925259867949, 0.0291495251336268, 0.0296353426362787, 0.0409215513084616, 0.05490198165976575, 0.021813246920438747, 0.0144880118646792, 0.023925394119162644, 0.054856977824653895, 0.047678708364920955, 0.02988991540457521, 0.026382874930277467, 0.0551144649008555, 0.04642514884471893, 0.07404735271951982, 0.04147078130128128, 0.05660016482163753, 0.035735932245318375, 0.04652719372617347, 0.040567210143698115, 0.07480878436139651, 0.027437403166134442, 0.07242243098361151, 0.06007567886263132, 0.0297409192925053, 0.026648177033556358, 0.03485841343977621, 0.020155577388192927, 0.0167076424030321, 0.01916982206915106, 0.01942221843637526, 0.026833871712109873, 0.043421661082123, 0.04305300622114113, 0.0065542937455964935, 0.05460735496931842, 0.023041753231414726, 0.02682976996792214, 0.06593043862708978, 0.012790745573251374, 0.02957692077117307, 0.04339860106951424, 0.06462605004864079, 0.02344295911357871, 0.03574243939614721, 0.04082633927464485, 0.05856420139649084, 0.06502937126372542, 0.04273349765155997, 0.04110134273235287, 0.011184542922170033, 0.008156734768168201, 0.02318838973795729, 0.04132719650598509, 0.0130707286298275, 0.015970239382503287, 0.06002835783043078, 0.09338490185993058, 0.033334986971957345, 0.04302467738411256, 0.031097378648285354, 0.03798940811040146, 0.021393284634021775, 0.05941833449261529, 0.05341709598100611, 0.018648836096482616, 0.033215914254209826, 0.009462231903203895, 0.018781077482604554, 0.02916539946038808, 0.07073673965143305, 0.057755869414125166, 0.047136942257306406, 0.04302062653005123, 0.009057522235837365, 0.04614279006740876, 0.024701804421576004, 0.027204328083566258, 0.033843664319387505, 0.010690170789270528, 0.02488680020906031, 0.04031531758872526, 0.06254249970827784, 0.09050823907767024, 0.01623886630737356, 0.0646304130288107, 0.04701599678290742, 0.031281265031014166, 0.021685083529778888, 0.026253581778811555, 0.03272646998188325, 0.04865140188485384, 0.03349759788917644, 0.040239057037979364, 0.03265782937939678, 0.0034611263420499328, 0.016336911224893162, 0.018331980598824363, 0.09477255347051791, 0.02120291824186487, 0.034787401357399564, 0.03632205079442688, 0.0194588966468083, 0.04639613807999662, 0.005700154712290636, 0.04177341131227357, 0.04624306397246463, 0.07505274484200136, 0.08110415084021431, 0.028358137867014323, 0.04156804590352944, 0.057889968289860656, 0.02386968130511897, 0.013619923847727478, 0.029869199730455875, 0.053691624464201074, 0.01648720503518624, 0.0331756126667772, 0.10484593507966825, 0.04657643501247678, 0.041893315235418935, 0.038466777852071185, 0.07021352808390345, 0.024638795659744313, 0.05739501092050757, 0.08788571480129447, 0.04760309920779296, 0.023946318442800214, 0.02323438084152128, 0.034928587531404834, 0.07364907980497394, 0.08347713707813195, 0.04561091700036611, 0.025641385432598845, 0.02679519521604691, 0.044819894446326156, 0.006562861946544477, 0.036779933010361025, 0.05970763468316623, 0.015923747859363045, 0.18373333237000875, 0.04501864753131356, 0.035134787538221905, 0.014485694667590516, 0.018790448051212088, 0.06186866693730865, 0.009157692664302886, 0.055213788856885264, 0.01695192009875817, 0.08149356208741665, 0.07473606576344796, 0.05778889371348279, 0.036771040808941634, 0.047711040558559556, 0.024989605049735734, 0.04675069637596607, 0.04297879823882665, 0.04376347988311734, 0.025587384223139713, 0.014672883819522602, 0.019927676135141934, 0.019357453965182816, 0.0673840574121901, 0.05782244048480477, 0.010255251894704998, 0.03154210067753281, 0.02895647513547114, 0.044036939673657925, 0.031963436997362545, 0.01386849073294018, 0.056932195754987855, 0.017744920582377484, 0.06704203505069017, 0.045649797056934664, 0.02411843224295548, 0.06716976926795074, 0.0178861593428467, 0.03611088051859822, 0.026371299122859324, 0.008637503970281353, 0.08656726697725908, 0.010258112767977374, 0.022695016747872745, 0.0819597224305783, 0.01835172766420458, 0.02005876231539462, 0.04499915661290288, 0.04979107269485082, 0.029599393850990703, 0.025368917999523025, 0.04461737209931016, 0.08798436700765576, 0.16942730359733105, 0.09902557025530509, 0.15306858425693853, 0.17689029313623905, 0.13673066880021775, 0.1812372598797083, 0.2461920737155846, 0.15798102851424897, 0.11792763562074729, 0.11859246423201901, 0.09693494279469762, 0.060359890040542395, 0.17777453283114092, 0.14262340616966995, 0.19898449257016182, 0.11166232824325562, 0.08576401722218309, 0.14273331527199062, 0.1352702443088804, 0.23500873095222882, 0.07994092468704496, 0.11318721356136457, 0.1330081442637103, 0.15225753134914807, 0.165503946266004, 0.21322924963065557, 0.14336706697940826, 0.07192847784608603, 0.07997545533414398, 0.11593561965440001, 0.11532934861523764, 0.15887867606111936, 0.21011524886957236, 0.10863883726830993, 0.14285581798425742, 0.06622289400547743, 0.11044861229934863, 0.09152259464774813, 0.2093500784997429, 0.09516997821629047, 0.14647680654057435, 0.11732477082737855, 0.09641568708632674, 0.19873623017753872, 0.16093946833695683, 0.10707656467067343, 0.10642361720757824, 0.09516262289668832, 0.19369649275072984, 0.20884808472224645, 0.16076258782829556, 0.1151169128715992, 0.12725279666483402, 0.10236443073621818, 0.1991738174110651, 0.05630835744419268, 0.21292346103915147, 0.17951448660876068, 0.13868312617497786, 0.14620484970510006, 0.0732367272887911, 0.11016514750995807, 0.13014056027999946, 0.15697063558868, 0.10886421946010419, 0.18298555963805743, 0.23483228470597947, 0.17314695114535944, 0.193182624610407, 0.17084823735058308, 0.13888211335454667, 0.10549545594091926, 0.1362648137978145, 0.09234867032085146, 0.10609243105032615, 0.19766775465437345, 0.1774270414773907, 0.12425388901361398, 0.12557490170001984, 0.13405561234269822, 0.14240509431277001, 0.08471606059798173, 0.1570203314934458, 0.19325460360518523, 0.137338609035526, 0.1434003830488239, 0.08929400744714908, 0.09678708322878395, 0.1150614358484745, 0.08293532686574118, 0.11044087700013604, 0.1199747622013092, 0.1396300353642021, 0.2077930849045515, 0.1646940197263445, 0.1644286989633526, 0.12109415499227387, 0.10871720806296382, 0.14715961632984026, 0.06457733123430184, 0.146252984979323, 0.09956532450658934, 0.20813696645200253, 0.14224945195019245, 0.136393491178751, 0.13227801344224385, 0.19379988791687147, 0.133916865502085, 0.12557226898414747, 0.14553744266075747, 0.20292071492544242, 0.1364557942641633, 0.13644980958529881, 0.10162533646715538, 0.2380037573831422, 0.17752437054046563, 0.13323123300714151, 0.1565593212310757, 0.1384012491575309, 0.11677598527499608, 0.11500218617064611, 0.1522206190441336, 0.15315843586410793, 0.17267003602215222, 0.24975050134318216, 0.1328291195843901, 0.09283961754824434, 0.13442470825144223, 0.08297352838729109, 0.1257995782153947, 0.17352988916848386, 0.2005938690687929, 0.09410742630383798, 0.15169543293969973, 0.15293175088507788, 0.15473294923348085, 0.1540179904550314, 0.1388900386435645, 0.1246092649442809, 0.1467600813401597, 0.11444387398660183, 0.14303207424070152, 0.16414794831403665, 0.06935639586299658, 0.08426112322402851, 0.15139799032892498, 0.16756225510367326, 0.16667431060756954, 0.07729042441185031, 0.20060115653489316, 0.15047838538885117, 0.11689497317586627, 0.10017190767186028, 0.1591416626636471, 0.12835290549056871, 0.17688761970826558, 0.17050166880445822, 0.1721005822931017, 0.13341647306723253, 0.16986404944743427, 0.128284875569599, 0.10085780479546104, 0.08420144606913839, 0.10984000709972211, 0.18079143523105554, 0.13918687057282242, 0.0861094119027257, 0.1264121460595301, 0.11468554101884365, 0.23353329726627894, 0.1573620688702379, 0.1505847389676741, 0.1449487456785781, 0.15627736278942653, 0.1907211166939565, 0.15539492799767426], [0.017539926671556065, 0.017269467702135444, 0.05810819872255836, 0.022230647737160325, 0.03138268566025155, 0.0760906795039773, 0.04332873571131911, 0.04509965782718999, 0.027553005177261572, 0.05662876167999847, 0.006398034340236336, 0.03294444935662406, 0.03624754425670419, 0.03427785209247044, 0.05391861478398953, 0.09291587131364004, 0.021888621982985308, 0.010481588276369231, 0.02653020354253905, 0.014038158414353217, 0.04032832510503275, 0.01349932951520064, 0.02304473878549678, 0.01977991495680596, 0.034874318300613334, 0.11535944842866488, 0.03628091121624623, 0.024328979962904538, 0.04039927272658263, 0.03872458723240665, 0.04027168100167598, 0.056084026981677325, 0.017659384457926666, 0.01810769084841013, 0.07128053118607827, 0.03170219762250781, 0.066372714537595, 0.024850405286997557, 0.0391793006898037, 0.03332145698368549, 0.00935549580026418, 0.017284181734014834, 0.022337082740185515, 0.008315637491510382, 0.004146308671416981, 0.030119918419846466, 0.004232233257165977, 0.03823291736521891, 0.03197645129902022, 0.021514925606814877, 0.013530989111002003, 0.032198895434183736, 0.031254011671990156, 0.04290549270808697, 0.03767295294840421, 0.05109960712226374, 0.016796715391267623, 0.0605752095580101, 0.0264623788784125, 0.03551425824740103, 0.00561756088531443, 0.025748880646590675, 0.030620663692908626, 0.005879220527796341, 0.0025848522241826034, 0.0322705012347017, 0.04337711525814874, 0.06497322249093226, 0.017754840764350126, 0.05251794547906943, 0.06422683397041899, 0.06061434745788574, 0.044202559893684726, 0.051615626218595674, 0.021362151751028638, 0.016547048431155936, 0.05954896605440548, 0.035404993753348074, 0.043854688560324054, 0.09719235862472228, 0.05975764271404062, 0.027595742705411146, 0.031927186263991256, 0.044166919841830216, 0.03557772162769522, 0.006524338969029486, 0.03781729770292129, 0.03343545425949352, 0.012256825874958719, 0.03360308972852571, 0.02034637125741158, 0.02288462996615895, 0.05583585958395686, 0.023921036228005375, 0.04131245194002986, 0.021305797721392343, 0.059701290380741866, 0.0022279659169726074, 0.053855653519609144, 0.009104881435632706, 0.02288185475793268, 0.026397412543052008, 0.030886476393789053, 0.010346324016739215, 0.08114046603441238, 0.03307132861976113, 0.020686722726428082, 0.04417880438268185, 0.0855151577187436, 0.09793916105159692, 0.009103347098321786, 0.08041976006435496, 0.029307752714625428, 0.007566027625996087, 0.03748298349923321, 0.02572786811340068, 0.12260487249919347, 0.06102418939449957, 0.029766734157289778, 0.02893145415665848, 0.043567003283117495, 0.013952658761159649, 0.03568240940304739, 0.02368960659285741, 0.12165127295468535, 0.05578017221497638, 0.017118848195033412, 0.021891744940408638, 0.02034646625231419, 0.07107840917472329, 0.015776665216045718, 0.0441737560821431, 0.029923082196286747, 0.02557341827611838, 0.03446653911045619, 0.018829070264473557, 0.05628243401380522, 0.034646028586264165, 0.09543017603989158, 0.02632512990385294, 0.045680365059524775, 0.029779120814055204, 0.019428247220015953, 0.023518583537744622, 0.005370292970578053, 0.027336172526702285, 0.02286908303254417, 0.003450335090747103, 0.04794947437143751, 0.011784687638282776, 0.015393157223505633, 0.015332828674997603, 0.06531589624605008, 0.07814226405961172, 0.04028205580211111, 0.018354109322120036, 0.02776049100793898, 0.025343098045725907, 0.018732189034510936, 0.03729353312935148, 0.049898271049771986, 0.01843918743543327, 0.02906425703050835, 0.007922731788962014, 0.03591127247948732, 0.013253795681521297, 0.04755470609026296, 0.030884657919939076, 0.03796020057052374, 0.016918397076161842, 0.03709042724221945, 0.09913879739386694, 0.05466368355389152, 0.06048638253871884, 0.0429561317765287, 0.046541884009327204, 0.023003337971333946, 0.032229717887405834, 0.08429591171443462, 0.03223567881754466, 0.019733433611690998, 0.03624961718118616, 0.03214824279504163, 0.04897207074931689, 0.046977717229830365, 0.01525088369713298, 0.04949279209332807, 0.049002499652228186, 0.04028601844662002, 0.05568812893969672, 0.0013905143922394408, 0.07297958965812411, 0.011854943154113633, 0.015105974062212875, 0.015346794622018933, 0.023355056598250355, 0.06243129460407155, 0.031241085579884902, 0.02399646896602852, 0.02612845483236015, 0.008257820370740123, 0.061553528133247576, 0.014874792092346718, 0.03838139779067465, 0.05769198534211942, 0.034884815237351825, 0.03994376877588885, 0.04507007709305201, 0.021846030339864746, 0.06514603857483182, 0.03176687897316047, 0.03527804324403405, 0.012739919059510742, 0.031664355724517784, 0.04720941997532334, 0.015770081730027283, 0.01822094343203519, 0.009990372179475213, 0.014444460094507252, 0.026665238796600273, 0.02905938514907445, 0.043820514144109826, 0.02337571120421801, 0.0428795692776995, 0.031441568929169855, 0.029319107998162508, 0.08551760044481073, 0.038924717743481906, 0.01807128744465964, 0.07805337597216878, 0.027060943456100564, 0.04133769344272358, 0.04236702767333814, 0.040138878127826114, 0.028833514412066767, 0.038388858283204694, 0.012836447451263666, 0.08860899241907255, 0.027999630497236336, 0.004288314176457269, 0.0253398122398981, 0.024220602653388466, 0.05490761010774544, 0.05003503317545567, 0.032936157658696175, 0.11131955270788499, 0.050670932446207316, 0.049798109102994204, 0.041622467804700136, 0.03522664082369634, 0.007764547464570829, 0.09010489072118487, 0.06008326488413981, 0.02371991335946534, 0.01755228279424565, 0.08622155338525772, 0.03355649472879512, 0.029035069846681187, 0.024450022128543684, 0.05040008840816362, 0.028215319816289202, 0.017240921733900905, 0.009970402045707618, 0.021499841773350323, 0.04229275183752179, 0.02496374777651259, 0.017099862785211632, 0.0162209224488054, 0.03190726786851883, 0.030521980952471495, 0.044568816133375676, 0.011558894932802235, 0.012181479650150453, 0.08505158937935318, 0.01843225280754268, 0.025050425536132286, 0.053242251077400785, 0.005430032041788633, 0.03983353736943432, 0.029164011856274943, 0.04094774615285652, 0.023316676961258054, 0.027385205163487365, 0.03217854956164956, 0.052223179688943286, 0.013887202184248184, 0.07311239253197398, 0.023807742932279195, 0.07827472766595227, 0.04517665458843112, 0.029252645493085896, 0.02214460780045816, 0.045962048694491386, 0.025740748404392173, 0.03868029585906437, 0.02560318730372403, 0.019568220512675386, 0.031541320362261364, 0.057003041596284935, 0.04066260877464499, 0.14606509863265923, 0.005975509311870805, 0.003020836630769606, 0.05071523060489978, 0.03697670138041888, 0.018313651671633124, 0.05302510969340801, 0.028315183207658783, 0.016458866020132388, 0.05734008351074798, 0.026052621758676002, 0.02150350925512612, 0.04146277119538613, 0.014670366454603416, 0.0809452650802476, 0.03881436759339912, 0.008599522972612508, 0.07203574066183396, 0.06301200522908143, 0.03189445373469165, 0.018170882814696858, 0.02262938205551888, 0.09026804446641888, 0.0764133839734963, 0.03966598332460437, 0.02929153912035482, 0.05714382404195411, 0.042443498569939814, 0.02461911814420351, 0.025063083606905172, 0.04652163991704583, 0.045377025979438, 0.014989439065435102, 0.03489756491035223, 0.019583809854728833, 0.007416330926519419, 0.06368557337139334, 0.021292668068781495, 0.04768040130979248, 0.0722511958863054, 0.01476160396954843, 0.02160118267472301, 0.09810542927256652, 0.022568157840786234, 0.04696397689570274, 0.03935494965740612, 0.02951951331592032, 0.01028169016353786, 0.07178202963301114, 0.04769797197410038, 0.013224208162033131, 0.025023628491908312, 0.10100618004798889, 0.11878982292754309, 0.28704669432980673, 0.10585359350911208, 0.07839667397950377, 0.2854134062571185, 0.14014147434915813, 0.1700882509882961, 0.0837163817403572, 0.11654788894312722, 0.1048594650679401, 0.1101592985380973, 0.09042007023734705, 0.15501762181520462, 0.13114899902471475, 0.2559466931436743, 0.08574964585048811, 0.08462090963231665, 0.15759271649377687, 0.1312722209841013, 0.15311677381396294, 0.11128468279327665, 0.1227462791970798, 0.0841772970078247, 0.1419218416724886, 0.1762089082705123, 0.1318507127996002, 0.1360130501644952, 0.09975157558385815, 0.1523824089339801, 0.12484768857913357, 0.09387917390891484, 0.14888787216373853, 0.12193689548543521, 0.08564492754106011, 0.11197196412831545, 0.09427217460636582, 0.10948402727288858, 0.11331287824681827, 0.0934749027448041, 0.09943412297538348, 0.11318932380527258, 0.09509283557002034, 0.0872472133487463, 0.14052199678761618, 0.1229446285537311, 0.10338135116866656, 0.15251377331359045, 0.10390963817813567, 0.09782288729080132, 0.13371573415185722, 0.1512725292039769, 0.1402140368840524, 0.11483941919037274, 0.12494885815041405, 0.12699846816914423, 0.08267861671213593, 0.1511541519846235, 0.10031040345451661, 0.07773440344525234, 0.12802537663706712, 0.1851989272981882, 0.09326905557619673, 0.1224913943026747, 0.10124952306172677, 0.09542139579675027, 0.13991712353059224, 0.20165758127612726, 0.11395811076675143, 0.18349098680274828, 0.13682525658181735, 0.19073820220572607, 0.13475267136735575, 0.09683000735406365, 0.10417470788317067, 0.19329891194190296, 0.13831408454903535, 0.09727847828928914, 0.08964309335819312, 0.24714039425764764, 0.20516431810600416, 0.11657919654888765, 0.13082535139151982, 0.11723398284188338, 0.15665304048785142, 0.13467022936258996, 0.10748454742133617, 0.1143627076276711, 0.12201475059347493, 0.1255863146590335, 0.09333926359457628, 0.14587666945798056, 0.1699307630104678, 0.0475278259254992, 0.11432157483484064, 0.14158615682806286, 0.16825982981494494, 0.1400667540729046, 0.1101819955344711, 0.10407038990940366, 0.10954191988067967, 0.08033855977867331, 0.09629005632762398, 0.09178053973508732, 0.11535855276244027, 0.11665958937789712, 0.1208541707268783, 0.13992211754832948, 0.13876118484352315, 0.13056699239781924, 0.19920038884239538, 0.1603141576051712, 0.17708192499620573, 0.13910186370568617, 0.08938711602240801, 0.12305601686239243, 0.17338776322347776, 0.13383430136101587, 0.12589191326073237, 0.10175887894417558, 0.13602231895284994, 0.10504015894340617, 0.14072653438363755, 0.07861111140144722, 0.30325936579278534, 0.13894584136349813, 0.11106022340910775, 0.09427761645721537, 0.11042433431638138, 0.19397254793771676, 0.0735945798722761, 0.30636122077703476, 0.14030341351670877, 0.11093416517334324, 0.08760223644120352, 0.12270487499024187, 0.14529340075595037, 0.130506874195167, 0.2185244554919856, 0.11633109700466905, 0.08664084731468133, 0.22006633132696152, 0.14409326229776653, 0.15595629358930246, 0.10508622468582221, 0.12458281564925398, 0.142682533711195, 0.09353720583021641, 0.14919129945337772, 0.0938699594033616, 0.11075750179588795, 0.11531760995941502, 0.20063591109854834, 0.10189645191920654, 0.10036270493375403, 0.08438666577317885, 0.08684440103492566, 0.11601143915738378, 0.09701378856386457, 0.10970328229346446, 0.08496504223772458, 0.08740081332091774, 0.10620698811752455, 0.11010271550289222, 0.07695940110300269, 0.06505428706961018, 0.22024528815277986, 0.16603200935891696, 0.11779116865779672, 0.05667096995083349, 0.2311437412032059, 0.19670591769473894, 0.16132518835365772, 0.15011576270418509, 0.16487806556480272, 0.13972619734704494], [0.0591671611847622, 0.0399305916258267, 0.02709450040544782, 0.009960804167868835, 0.02694146192100431, 0.03338530034359012, 0.016839473275467753, 0.010890883144124277, 0.05161431325333459, 0.051948864944279194, 0.03703900785850627, 0.02385225652584008, 0.029125922293003117, 0.04655394157660859, 0.028564156365713904, 0.046183488597827296, 0.02160910626740328, 0.029386842756399086, 0.014935648201831749, 0.0832267983683518, 0.02503612032160163, 0.03259961786014693, 0.012202403973788023, 0.021715534485078285, 0.05331140736650143, 0.04477412047396813, 0.015400933234819343, 0.05671686605949487, 0.02228248950892261, 0.022680056747049093, 0.01243112625421158, 0.03779256510149155, 0.02793478120916656, 0.028111103622774993, 0.03778015130332538, 0.024088856597830142, 0.05502233002334833, 0.03767451697162219, 0.04448031820356846, 0.011212456156499684, 0.023992533462920358, 0.06075272110423871, 0.007539901483271803, 0.05572442038516913, 0.028493877101157392, 0.051769141373889785, 0.008420180230002319, 0.04884502863777535, 0.0130406941253958, 0.0405576767266861, 0.03142537569094982, 0.02412274942201163, 0.01947947491758636, 0.09086724517068692, 0.05844028054603508, 0.04050696301939232, 0.013100969239271112, 0.02117095754614898, 0.018688323441892862, 0.015547841155369366, 0.01364122815097549, 0.020894963427313736, 0.07516049620296274, 0.06359578283237559, 0.0272349554579705, 0.03588463319465518, 0.05921412937875305, 0.044529328787965436, 0.06973463842379195, 0.023551911481523087, 0.04202253205169525, 0.053533061008368216, 0.028795306105166674, 0.03564820445275732, 0.026939049729013016, 0.056761228679014106, 0.07251394500157662, 0.019386698824486563, 0.06430522512112345, 0.04491334568176951, 0.01879149808415345, 0.05486545611971191, 0.023400297920618738, 0.037261930360857926, 0.045020041920776875, 0.06432376269783292, 0.06065769906022719, 0.0411191474912422, 0.08077381963708571, 0.04488736457590546, 0.055576248693146875, 0.015477488948298352, 0.03295135345043881, 0.016966856350856166, 0.00976685680715101, 0.061129966218556674, 0.05981579316513879, 0.014698323793709278, 0.011020271290492798, 0.03486508343900953, 0.04296986871798124, 0.018873431187655245, 0.05762563140264579, 0.031306628670011244, 0.033250821488244195, 0.005648746778855899, 0.016845676781875745, 0.0046639766078442335, 0.01786998985335231, 0.07926889003387519, 0.029005865699478557, 0.08259360305964947, 0.012837407578315054, 0.0370031472827707, 0.020395904313772917, 0.013338624433215176, 0.03346924530342221, 0.059658861586025784, 0.0049095125619455105, 0.03489007727642145, 0.07476066265787397, 0.038894862202661376, 0.028253214300743172, 0.030632229322301488, 0.010371501906774938, 0.04576259332575968, 0.06681988268558468, 0.031149198367659534, 0.023273768103016273, 0.03143301599525979, 0.05155894818848797, 0.05394772732896464, 0.07670333555766515, 0.022864748890112554, 0.028403686226478646, 0.02724945405498147, 0.03885143256879278, 0.011259150391976749, 0.08900280057319573, 0.050462751117135794, 0.02327326768344002, 0.011626728078616517, 0.022132436578561152, 0.032570498529821634, 0.022803830016138296, 0.023780950977067863, 0.04767901709835444, 0.014258890944932188, 0.0583084411919117, 0.011778149105209326, 0.07391635474881955, 0.05923304014972278, 0.09649134374090604, 0.014775820974526661, 0.047145766605223925, 0.03574759626228895, 0.08047658737216677, 0.028946731372603347, 0.02630685525946319, 0.030870188160666397, 0.045078915011669905, 0.17364486014204367, 0.0028556027516190496, 0.022022099999178733, 0.03561753127723932, 0.08884585542338234, 0.01518105056935123, 0.03896440186404756, 0.02895424954060997, 0.001809915402970676, 0.03575841550316129, 0.012659577120627676, 0.021165729433830296, 0.04359543390039887, 0.0684556406257408, 0.05696563396070685, 0.04164333275652357, 0.025602245836385658, 0.008972603578253515, 0.023130056082404087, 0.02686964238195547, 0.05435869224103434, 0.019782303400071602, 0.028468303116304532, 0.04950261049504791, 0.050337507123393674, 0.016253836486222487, 0.01838489106324102, 0.03464921770085182, 0.05189913850543754, 0.043655328186494965, 0.08219060754137379, 0.03779219529990639, 0.02587753936781415, 0.020379091912348355, 0.06438993343285151, 0.038688177043305974, 0.01855540691342737, 0.03902706118034465, 0.06589645759335586, 0.03561778572787132, 0.027188021190730587, 0.01626644197053143, 0.03456313196303589, 0.007702645562988306, 0.01687546955820705, 0.03230475028976798, 0.06452720785247427, 0.049277798272669315, 0.04754709292735372, 0.0318124968824642, 0.008333122490772178, 0.024781924140240465, 0.01811255424815629, 0.07604452555200883, 0.03430844045111111, 0.03563588564949376, 0.04595340076567871, 0.033236548504126925, 0.029635193358574594, 0.046789084494646103, 0.047725218547774215, 0.05224512011877128, 0.025879313736887913, 0.024724494632599608, 0.0555196554799165, 0.017389027268758843, 0.011338259093463421, 0.03645068746326225, 0.07696392014622688, 0.03508761578372546, 0.06019000522792339, 0.05063049175909587, 0.044820807075926235, 0.006067194235843739, 0.014271148680044072, 0.06428374270243303, 0.013182203451703702, 0.044107259650315554, 0.05247302646083491, 0.034789796586015394, 0.0676218160827245, 0.07848624738731555, 0.024652820978579775, 0.03993310899074588, 0.03967622241803578, 0.03390608614842806, 0.06464303378015757, 0.05649310556639518, 0.03869202094418662, 0.012108024841706668, 0.018451202594275986, 0.035405224455254417, 0.009783459710888565, 0.035262799954840114, 0.030576949074332203, 0.01319534667501492, 0.013204701128415763, 0.034997472406498024, 0.05827594614986863, 0.03412733606195875, 0.0556494829777096, 0.030186811794659922, 0.03395366841661079, 0.02494299647930477, 0.05811963203762259, 0.037587817159614394, 0.048720402110900195, 0.02584553965633469, 0.07756444399378129, 0.07893788708107811, 0.061686873835112364, 0.056359159361038885, 0.039562795111643415, 0.03523957709382687, 0.026783537984426533, 0.03540163839768086, 0.04322116755481277, 0.005660440905817917, 0.08871310004698378, 0.08022512907960586, 0.04000134925757136, 0.015336189119677459, 0.040416853568915806, 0.011792526414085711, 0.013603946892544627, 0.04158908388178263, 0.06018733858530011, 0.017896620656496713, 0.0362587841892881, 0.018756331310474446, 0.026352004979604056, 0.04921733740983265, 0.04833404766395688, 0.00898086728661188, 0.034796463192573616, 0.03613303468695708, 0.0215083879219102, 0.019870658837524906, 0.04104286997712084, 0.07700750923582486, 0.07990303529160363, 0.0879719905289156, 0.03785649327827351, 0.05754978475826127, 0.06164795985179288, 0.04892283964103886, 0.030183110386133194, 0.04995792445593646, 0.03093991441918271, 0.02402675537658589, 0.02445643937348255, 0.01417010378957327, 0.0354148698305445, 0.051340853462793996, 0.09388458183301346, 0.06314417028001376, 0.02899929748049804, 0.0032176575872914065, 0.05119170468034489, 0.07296113350561687, 0.029075646240796362, 0.038128358511520286, 0.007713462259354336, 0.10788849288863794, 0.008783999680807548, 0.06250560775931392, 0.02938079022403274, 0.02942740897248898, 0.012693087420692402, 0.12673964777163096, 0.09444570993738514, 0.03532870266852634, 0.03910706385171839, 0.08419540032212224, 0.03533065006402986, 0.002861680941090786, 0.06962318904697895, 0.010737096574822707, 0.06470596790313721, 0.046652973762580326, 0.08170379259224449, 0.007266955683007836, 0.02784560983335333, 0.02211215516685375, 0.03373058306585465, 0.059297243133187294, 0.05184364791161247, 0.04543051828763314, 0.020607988915539215, 0.01836325936684651, 0.04032788405727063, 0.07310712031487908, 0.1839940526655742, 0.06939782042588506, 0.1032282126003078, 0.15017455097820076, 0.14900787786713668, 0.07556695224983351, 0.14855216017791203, 0.08468053928975548, 0.14522917063108512, 0.12356255682451384, 0.07466775764312063, 0.1801327405763524, 0.18200951415513242, 0.12287131963031632, 0.23689684963652066, 0.09722203774643795, 0.1349419690668583, 0.10732819259698902, 0.21757755987346172, 0.08208740915038756, 0.11885857209563255, 0.1474857066891023, 0.1406135040202311, 0.10642634491835322, 0.11353862006217241, 0.15072788271520818, 0.1343333502965314, 0.10216415434011392, 0.16666772881788866, 0.06535133613007409, 0.15789948217570782, 0.11520939719464098, 0.09734392299183778, 0.1486881657370499, 0.06966341260288443, 0.09934397281280585, 0.08497012446501426, 0.13678614582334245, 0.15708381522979054, 0.11468332899468285, 0.1840566543063947, 0.1489835727427687, 0.11460737378469535, 0.0901487987222416, 0.13438262550958566, 0.13216781935521535, 0.15871045365929604, 0.12632568712745393, 0.1542641765304974, 0.07206317383263793, 0.13748415479702608, 0.0855475849072848, 0.13514926151505538, 0.15811969393065997, 0.12340407818555832, 0.13322885813457624, 0.12028303423098155, 0.10746559593826532, 0.0818471602563347, 0.12398936892194407, 0.13386664034000464, 0.12687543619956287, 0.18389835208654404, 0.07988174964806863, 0.10349180309900216, 0.22750652208924294, 0.2694682947226933, 0.1760184977735792, 0.09188798575529031, 0.10713774817330496, 0.13873933601592267, 0.14419150059776648, 0.14980523793825082, 0.13754852062889508, 0.22147286656711782, 0.13904967079205172, 0.10767402153994356, 0.11917358876339026, 0.10103649020727191, 0.09883208599473749, 0.13656917746577943, 0.13784341194799968, 0.11484870154942785, 0.28016254944460733, 0.25872811675071716, 0.09765980139906917, 0.14855525429759706, 0.13226649191762718, 0.23816321311252459, 0.1441128719598055, 0.09430017096123525, 0.12710001772003515, 0.20926524805171148, 0.17963374592363834, 0.16121236155075686, 0.12985491060784884, 0.09737012801425797, 0.09255329612642527, 0.08899195079824754, 0.13171985053590365, 0.10375135631433555, 0.10035302223903791, 0.22190798393317632, 0.15627680639071123, 0.07836329005658627, 0.08069593738764524, 0.12654915585049561, 0.07201404111193759, 0.1842900024993079, 0.1421033362192767, 0.19302903142358574, 0.14801075708653244, 0.11912155869816031, 0.1131564284275685, 0.13479925958173616, 0.13617306229259285, 0.18585178655173096, 0.10966447009039776, 0.0853995828490172, 0.1347932070493698, 0.10840452555567026, 0.10724610343043293, 0.07196245887981993, 0.1423259364174945, 0.09609689097851515, 0.17195321805775166, 0.13587472401559353, 0.13532958898161138, 0.09798163055841412, 0.15504944510757923, 0.14044330029615334, 0.23501272073813848, 0.06263336233262505, 0.08909291002367224, 0.11560095261250224, 0.12236695098025457, 0.12784205004572868, 0.13011065045637743, 0.1837408776794161, 0.12613344458597048, 0.1370239859180791, 0.1276630117957081, 0.16618994516985758, 0.14650667565209524, 0.14325215028864996, 0.11941408871540002, 0.2033229504844972, 0.1940560077450105, 0.08839494176208973, 0.10667516370969159, 0.15831214003264904, 0.11685029843023845, 0.09395899676850863, 0.2223915486995663, 0.2889885258461748, 0.2367277315684727, 0.0923059768974781, 0.12494216779513018, 0.09467028467250721, 0.18115229372467312, 0.2878827308969838, 0.049762906706226726, 0.15972786263695785, 0.17856917876218045, 0.22271393425762653, 0.1049930550424116, 0.05899344264928784, 0.08850536655102458, 0.12130853134606566, 0.16524222173861094, 0.07731145221207823, 0.11951630323060922, 0.19643117886568817, 0.22369338598634514, 0.18937845874045575], [0.06782435878579106, 0.04880016729501741, 0.026956935912104588, 0.04935112755213465, 0.07994066684373788, 0.04255441529676318, 0.04254295484029821, 0.04629083962312766, 0.017767359735444188, 0.04495919429297958, 0.020393071430070058, 0.008067113014736345, 0.03953910406146731, 0.03106825931796006, 0.025814184553122947, 0.05155950119452817, 0.024912094298217977, 0.012104721224334623, 0.020736091238047396, 0.015832739349986826, 0.013297709619759448, 0.07156985173267977, 0.03915464272722602, 0.07242832745292357, 0.06030053858246122, 0.01634857863453882, 0.0244870633552117, 0.03306091989257506, 0.013623480219393969, 0.05353138841954725, 0.05690835542710764, 0.024294829295415963, 0.005136160645633936, 0.01794250149812017, 0.036176684844706736, 0.04729705277298178, 0.02511985323924039, 0.02100378178459193, 0.02191686600313655, 0.057488519831427505, 0.0397663250831621, 0.050219408103397915, 0.0024898541409389247, 0.05708685424178839, 0.03720493681196656, 0.030924111338598386, 0.019804340521139756, 0.032964143835540326, 0.02198650574843798, 0.0213704061295305, 0.0969721604404705, 0.0353970006108284, 0.042737755458801985, 0.030761693803859607, 0.016059030778706074, 0.040509473598961315, 0.05876842686640365, 0.009706850562776839, 0.03930139967373439, 0.04124740418046713, 0.053433258685150316, 0.019132992884676372, 0.08534255198069982, 0.041904857116086144, 0.0354649253588702, 0.01437629446653383, 0.02525408103662942, 0.01885549072176218, 0.03266151382454804, 0.04991464749244707, 0.015517972043848463, 0.010102097211139542, 0.03309153539261647, 0.06028063715036426, 0.015691358097163693, 0.05873885631029095, 0.02193516439625195, 0.03504315816930362, 0.04929415775196893, 0.04417065517710788, 0.06263959806944643, 0.022080684712688838, 0.013350212963164916, 0.03033730746912105, 0.01660316327719816, 0.04751166322135499, 0.058119638822972775, 0.002051875477523676, 0.049784395910267315, 0.008579815771164638, 0.04189470623220716, 0.05368003847875765, 0.016324095394728438, 0.06320819005902324, 0.033949600599173985, 0.03774226190788405, 0.02020099512966616, 0.03116609388962388, 0.09177659744662897, 0.033476363135767837, 0.02823853080293962, 0.031320121338857074, 0.03804513279880796, 0.0471532101343785, 0.06784899639231817, 0.050492124898093085, 0.016224676443796073, 0.026081121925796782, 0.01129147834477148, 0.0218325003515929, 0.032977690787187645, 0.028137267933094075, 0.05956950530941997, 0.014243920766083258, 0.040177958352225165, 0.022012127230742147, 0.017333757198814834, 0.044968876987695694, 0.034284769756985564, 0.08667089963065726, 0.0391745848714241, 0.016909530319805657, 0.030248293852699653, 0.053451538418552706, 0.032519238601837835, 0.020595130676935827, 0.06323570465402943, 0.008336616097949445, 0.11451297599290099, 0.024708562630361745, 0.029552157635667493, 0.024057116425995315, 0.027598714688792825, 0.02041278456869934, 0.01179071981459856, 0.021704569359176924, 0.04068422690033913, 0.004845977511389979, 0.03766488177435739, 0.02747639348464353, 0.02534286055846938, 0.006832733983173966, 0.034405973074691634, 0.028107215617118136, 0.07881269058478729, 0.010467321229433375, 0.017876471559117948, 0.057275005217109404, 0.02179928945510515, 0.1099503572498049, 0.13256122038832732, 0.01879067875311843, 0.020592509835426296, 0.0370980811172298, 0.046249896820102415, 0.07528864432658468, 0.018196879187598825, 0.03157627848642213, 0.06733466684818268, 0.06582242942282132, 0.05755682795175484, 0.0060423836028868595, 0.05246497903551374, 0.10114293199564729, 0.03249778671722327, 0.0038701525523460335, 0.008845513121091893, 0.035382174620670934, 0.02865417760663799, 0.009322411280923655, 0.08170452541006462, 0.04187830604080643, 0.06799700523593596, 0.01651120142612074, 0.027182587821568762, 0.09865471015551261, 0.009753428599131959, 0.05349093755441053, 0.012222752390828515, 0.058932130225002766, 0.08683661823826176, 0.0467097162535148, 0.0765853790300233, 0.039376957940735986, 0.021749267853530388, 0.020484432777655975, 0.016824243556974188, 0.04223563615232706, 0.10611672938934394, 0.013614998531660863, 0.018789157138339112, 0.04683027157027807, 0.026395633084965602, 0.06317220056163413, 0.022388758270868232, 0.05975796162549939, 0.02079996343569032, 0.04401581009317722, 0.02841658008817051, 0.040490206597106795, 0.06556407042912074, 0.005004481595408703, 0.021022865581991415, 0.03157997989494886, 0.0318823317065835, 0.026803478432287062, 0.0298201382559325, 0.055696559737303426, 0.022116409581420676, 0.019854533452806727, 0.043959176167845726, 0.0397934359498322, 0.011576122936925717, 0.057608525534825664, 0.02855227861021246, 0.03820200330976929, 0.0602806167943137, 0.010771045378143234, 0.0273100082163832, 0.10283164280865874, 0.05600295222497412, 0.03631670393847993, 0.052459357372884236, 0.0034506177429908086, 0.04160245102165001, 0.07756938372871705, 0.08488390980554478, 0.01765251937987549, 0.04286655158336673, 0.025677904187302505, 0.020164900459349155, 0.023055111889594367, 0.09839432912745646, 0.028699378216905252, 0.05783250994448151, 0.06487875006028584, 0.05707419956369059, 0.06625772320798465, 0.02786717706892107, 0.051773273652153354, 0.015541210171899624, 0.050905637709157806, 0.038153623762939654, 0.016317225227664624, 0.052187814443771324, 0.09119872988334723, 0.018020665339593376, 0.015235940659684795, 0.04196751982505832, 0.02824767236597836, 0.021869254897215536, 0.11567489935883454, 0.03938842178987605, 0.029397054708429744, 0.04526161735079118, 0.05404900546584811, 0.0528296746446618, 0.04789089983595269, 0.03209449603621449, 0.04919672351596611, 0.0303743317324136, 0.03841387586934226, 0.019407139691923345, 0.008686654502525926, 0.019346565174471055, 0.015236100115414177, 0.05039510456845164, 0.0336861288441079, 0.039139385867331705, 0.03220208454877138, 0.06042270202721868, 0.019223977645326937, 0.022665966967386857, 0.021081182274169157, 0.06346373313239642, 0.029334632879389182, 0.04675305428515587, 0.08287746818470103, 0.03174880619293877, 0.018454264483547637, 0.0537719358690083, 0.029377394156264405, 0.0022668538191023147, 0.008998826412217957, 0.04932591658351677, 0.0309982548600861, 0.03967443787093673, 0.01584624558953302, 0.030223632497446876, 0.022513064189947078, 0.06694376282393932, 0.029098265205643008, 0.014399681872289096, 0.06894064388637032, 0.014490756538829632, 0.038979757111519575, 0.033765330844159634, 0.04117448880736317, 0.03645797153668744, 0.06231538046683584, 0.041492297646722624, 0.020606165352676595, 0.05120346029954297, 0.025889547741306678, 0.03120294851916177, 0.01979145174846053, 0.027844081433223825, 0.045381212540503056, 0.027779656229540706, 0.013390695210546255, 0.002636628262864958, 0.004444866624128605, 0.02243168918149812, 0.04575344328103321, 0.06426817710910525, 0.022483795581917678, 0.08364208894116537, 0.014442777327661003, 0.014434304121615631, 0.02302510367839464, 0.1320280818534749, 0.05666300055703946, 0.04427612666040659, 0.03937240497076085, 0.06393611564167909, 0.032455765043518374, 0.03401569669534053, 0.021070564897464852, 0.03287912339770368, 0.07780537142285279, 0.06734420705054488, 0.07697810831346683, 0.006435048425503607, 0.029522431016500508, 0.025050379735018526, 0.038654955968792946, 0.05742105309452329, 0.007282348249905876, 0.0507382634761078, 0.04301254857065422, 0.018874108026336347, 0.008506720586280738, 0.02754689666575619, 0.02966125588864088, 0.01767050564688231, 0.030880138876714876, 0.009808138877685581, 0.02659809945284256, 0.04791872316439237, 0.070825627738876, 0.061754109870110235, 0.03983447374776006, 0.09029205782072884, 0.1062601309801851, 0.06540029243166957, 0.11550745048693248, 0.1394690325749772, 0.149622006341815, 0.14393797277339868, 0.1001405729246991, 0.07662466620760304, 0.0982446985851441, 0.1446198054722377, 0.14648610247032984, 0.22174436199877942, 0.14764717088213988, 0.23500362836888858, 0.0907822654449514, 0.1540509129741362, 0.1367288910384689, 0.09497134387493134, 0.2586380887244429, 0.26787585445812767, 0.16253015798117432, 0.14768527740878717, 0.1734277560774769, 0.185762097792966, 0.133564542979002, 0.11108574989650931, 0.15517814962991647, 0.06241106747516564, 0.12884070431547506, 0.1547172207917486, 0.12399447150528431, 0.0749104560485908, 0.11098034626671247, 0.10831349329756838, 0.18795654789677688, 0.09460694342851639, 0.13078645776425088, 0.10884339522038187, 0.13179732566433294, 0.16761923847453936, 0.12950142100453377, 0.18582060108227388, 0.16043400046016487, 0.1912259060357298, 0.1123182884018336, 0.11677724735013076, 0.11467676077570234, 0.12512417802853243, 0.11339310144207307, 0.1860868310821908, 0.09018370256360088, 0.09991650709084102, 0.08395959583244153, 0.07120868789830379, 0.0880340968391725, 0.20659776404500008, 0.15207098850182124, 0.13698305668575422, 0.18973546315516743, 0.23186157697013446, 0.14106220565736294, 0.12536072890673364, 0.09002160054764577, 0.11003652441182307, 0.12910362306450093, 0.0937899329832622, 0.0767332793080381, 0.10932887345552444, 0.15383399889937469, 0.10634780448994466, 0.0815538838505745, 0.10613975208252668, 0.14679218961724214, 0.07640689717871801, 0.16244764812290668, 0.14468630190406526, 0.09427681578589336, 0.196793937257358, 0.13542541169694491, 0.09839272099946227, 0.16587878258100577, 0.07049921846815518, 0.18025702105036803, 0.08797186839261226, 0.10622946798269238, 0.19924834769751343, 0.1472863531006234, 0.07655112658228193, 0.1672895790210792, 0.10414029258702483, 0.13919480943254062, 0.09007960172103983, 0.12950454226561955, 0.1169511830168111, 0.13836071347551687, 0.13228406597461018, 0.10102875490805932, 0.13177007569798402, 0.09540258680603333, 0.2014689621116434, 0.19370395663593495, 0.12734008340963296, 0.08366456202098302, 0.18961769661733083, 0.13879899281476224, 0.14972352875130518, 0.13025079507912907, 0.16403506722833427, 0.12494655113135066, 0.1134613620649491, 0.11248844462846007, 0.14082562763776096, 0.20770701952278614, 0.1778710747935942, 0.1415204746382577, 0.09860620168702942, 0.13928979076445103, 0.12739421693342073, 0.17449034191668034, 0.14339361126933778, 0.19123727828264236, 0.1214423520224435, 0.16548481157847814, 0.0950514313631824, 0.09556035976856947, 0.150807597009199, 0.13114845619669982, 0.14026137148695333, 0.06866589827196938, 0.09774005173572473, 0.10529220077608313, 0.0837484560906887, 0.15878107558403695, 0.13966259147439683, 0.14208513791007654, 0.09303175830947501, 0.10871703164385897, 0.11451415664383344, 0.1746763147945915, 0.17951094465596334, 0.08106906379440001, 0.11105495119201285, 0.12046462377267224, 0.17792883169438156, 0.09153265732207469, 0.16804766548531397, 0.1266185971243041, 0.09947989016239132, 0.21833697626633303, 0.24453891813755035, 0.0937719585906182, 0.10666681772896222, 0.14122831102992806, 0.09696576864059482, 0.1405562763767583, 0.14421074385089533, 0.11714076570102147, 0.14809781312942505, 0.12157337713454451, 0.17448255233466625, 0.1227348798087665, 0.15301107162875788, 0.23164184018969536, 0.13924013557178633, 0.07556602944220815, 0.14429729777787412, 0.10593704653105565, 0.17153699110661233, 0.08624859979110104, 0.12708072018410477, 0.15023712547762053, 0.16725531300263746, 0.18728231479014668, 0.26563943017806324, 0.10252902297569172], [0.014407588501593896, 0.040430319096360884, 0.027636597298883965, 0.03140869051484125, 0.05826590383159263, 0.013834749730969114, 0.024507319321855903, 0.038461644734655104, 0.02617972663470677, 0.017388107853808572, 0.035964798714433394, 0.07282688535217728, 0.01648863504773804, 0.05954817895378385, 0.026548773349661912, 0.0024130620004143566, 0.07369213285190718, 0.04511709278449416, 0.03449871863371559, 0.010766284606818641, 0.030673966011298553, 0.08320856613240071, 0.051787851977029016, 0.036109950925622664, 0.008081966994463332, 0.028855943387108188, 0.03648151330915945, 0.03989058180845209, 0.04113879447270717, 0.029552663144256388, 0.09158146434596606, 0.022343459273023263, 0.018797913632754768, 0.03984045164127435, 0.04195544868707657, 0.018000005644613078, 0.06592458286987883, 0.06208849871265037, 0.004001198868666376, 0.025240333917151605, 0.03266715245055301, 0.040158145129680634, 0.05385744145938328, 0.059970600929643424, 0.005190427756003503, 0.025260238741923655, 0.09591258729674987, 0.058275267614849975, 0.020785145927220583, 0.04477528416152511, 0.029606094384299855, 0.029427290228860717, 0.03180880565196276, 0.06176841338830335, 0.04825966326253755, 0.03326990528564368, 0.06594564459685769, 0.014084115591166275, 0.015741842798888683, 0.02505136700347066, 0.03244416888004967, 0.016423768796292797, 0.03541308867612055, 0.029441223945468664, 0.019336702667975, 0.00680122960225812, 0.04269596787967852, 0.05768330687923091, 0.03346786109198417, 0.006397791763967169, 0.03089331602677703, 0.04602033145991819, 0.039462053017424684, 0.04302698440317597, 0.03360974954973374, 0.042306319145219665, 0.014325835209872042, 0.02837166446261108, 0.028240591853058765, 0.022678448619054895, 0.04368064772071583, 0.01358645934877651, 0.03023153743041413, 0.022402914207694784, 0.04015291701736195, 0.08502514008432627, 0.01222029100504837, 0.0520932436255472, 0.08552814487900053, 0.058871272419180186, 0.051481099865798435, 0.057520288841000626, 0.024104936181434562, 0.030978495920343057, 0.060065304062196186, 0.039170744363218546, 0.006508240301627666, 0.06180667597800493, 0.07250962273350783, 0.03741519445819514, 0.007769685670999544, 0.0617855056854231, 0.042377466934600046, 0.02614706365524658, 0.0358279449865222, 0.08185541802751166, 0.029186627428446497, 0.021007800408239876, 0.018161145837179253, 0.061075133803699694, 0.02747934850464974, 0.004771346716942, 0.025752610892855694, 0.05870190329317536, 0.110642707241433, 0.035972958098032644, 0.04716000226991517, 0.023218833907906498, 0.07629065055932317, 0.021243182509871464, 0.028969207845096077, 0.012466216692700982, 0.003568550945991384, 0.0741485222908003, 0.02091560615891857, 0.014906959741243293, 0.047215659104819806, 0.02639464072750083, 0.03004709125629493, 0.014841521824044841, 0.006588818455514098, 0.02817264335629131, 0.06864527759275266, 0.094314752678786, 0.024819679525015608, 0.028878684488258193, 0.03997242670240147, 0.043556567414530685, 0.05888458527624607, 0.01582493450093482, 0.015140843976821219, 0.042664829907672744, 0.08186702097633056, 0.03832743390064154, 0.09257590491324663, 0.05097455311832683, 0.007431317220575043, 0.041951659068997414, 0.06713466865143605, 0.04148173964183245, 0.04021535241710288, 0.04922695903639708, 0.03331413898350937, 0.00915414307798658, 0.03993408947384783, 0.055792640295944045, 0.029416087615702833, 0.027093650540336967, 0.026225464983976314, 0.052619834297469685, 0.04154741165361234, 0.00653162897963609, 0.036472678783216646, 0.016796462636973177, 0.013640017814135976, 0.04159741289913654, 0.107461945419865, 0.04775692309652056, 0.02342247074869062, 0.0217366097827575, 0.0961068586579391, 0.011931079872218626, 0.009503908372218055, 0.02007324734170522, 0.02295583882369101, 0.09059997022684131, 0.054808527031647306, 0.05006265972873994, 0.0451711414914046, 0.038032722393316884, 0.030689419646348273, 0.05253804029364671, 0.0493720874988607, 0.041246963132705004, 0.022391195907922726, 0.02981805515342525, 0.04284445848315954, 0.01151451195723244, 0.06331858770655734, 0.05895670676337821, 0.013148997644228595, 0.053494225056575875, 0.04416750677462135, 0.05244381892095719, 0.031853100417980125, 0.044773927091487815, 0.034595521832151074, 0.019852329910333668, 0.07101829775742122, 0.05747927139912333, 0.0467548999004066, 0.05735825467854738, 0.03432701534724661, 0.03454384121245571, 0.03287333549399461, 0.06350494056407895, 0.06609807070344687, 0.01604103942268661, 0.03912250391606774, 0.0305438162093716, 0.0811474888718554, 0.027274171389373283, 0.02541573013045958, 0.008459223134975349, 0.07277501135000161, 0.05128482004095401, 0.026414408148931603, 0.019183689628594687, 0.06852434908172914, 0.04768992454877921, 0.026108068247724856, 0.020118509020124162, 0.03266121866181493, 0.017293939067583, 0.03612912293257458, 0.007320822881800788, 0.06056922487914562, 0.04057333392224141, 0.057251025789550374, 0.11333835045141832, 0.024755858217499087, 0.033772781158664396, 0.0406766578422061, 0.014831579589684094, 0.08178795807595764, 0.027680976881778667, 0.008733125669615609, 0.0654837725950139, 0.04744489537551999, 0.009285491342390222, 0.0370832686977727, 0.04024253792262503, 0.03570039397371667, 0.022103719280234406, 0.027142023301816413, 0.043074006879968305, 0.02981880832729595, 0.019704723098714436, 0.019584959971585443, 0.008717286117774035, 0.00870247369831694, 0.032050930695342164, 0.03721004618065698, 0.017981099962655987, 0.0018231158776740941, 0.04820608274478998, 0.048775797709822655, 0.021248943272179792, 0.013239014644308813, 0.02189617238140532, 0.10263828746974468, 0.01702524089653577, 0.04725541786423751, 0.05387537513992616, 0.018240366496944, 0.07205432573599474, 0.01989153227103608, 0.04210586293733545, 0.082911123521626, 0.01715524142075862, 0.036634142976254225, 0.08121432457119226, 0.03808980754443577, 0.037967019847461154, 0.09728793028209891, 0.03042003445859466, 0.02698648102315409, 0.012518783648764449, 0.019478223020476953, 0.04127293745321887, 0.007629574126830059, 0.05161284761769431, 0.0222039032794003, 0.03095729509368539, 0.009734355827926524, 0.03922331725646343, 0.04266330659655588, 0.011777997282998902, 0.04426368572083967, 0.011171905207447708, 0.08878946237798248, 0.024573771648907235, 0.04351362971855061, 0.01607944450474211, 0.04017513903922268, 0.025414021918550134, 0.014013198503692235, 0.022143203232969557, 0.05459194204636982, 0.02340770243400974, 0.03003811084532312, 0.07620975561439991, 0.055951095186173916, 0.031384962145239115, 0.011243721353821456, 0.014502457875226225, 0.06433162013334887, 0.01967295408914132, 0.038252309896051884, 0.02759425332104521, 0.0475745159201324, 0.024009827624208162, 0.03401205974764057, 0.007872487118999873, 0.06059642056269305, 0.02895415454570736, 0.01861082456473793, 0.07322689531637089, 0.0442575449789209, 0.03901805702064719, 0.010472872494054692, 0.038455999323299954, 0.04185463873935597, 0.05746494073952947, 0.08416246423231703, 0.009499812565211738, 0.025403964333236217, 0.03814670270574944, 0.06410179353718247, 0.026204213267192245, 0.014972533365445477, 0.01492469325395567, 0.02597896338972662, 0.05104242019089205, 0.033458415884524584, 0.021655053266191056, 0.07614824641495943, 0.07014356433813061, 0.019425663697932447, 0.054270235023328235, 0.014118510531261563, 0.09208110360694782, 0.03475268750584551, 0.02681560385307031, 0.034560838514672856, 0.047840583071644814, 0.10180169450385229, 0.06308148721499102, 0.09906680482838835, 0.024951028637588024, 0.019672221271321177, 0.054473266271608214, 0.11166600590305668, 0.13084137838866028, 0.12166678426521164, 0.10085899223174367, 0.13470454966383322, 0.08070751998041358, 0.09202802859778915, 0.17040781384067877, 0.13612506272537367, 0.24014909512230329, 0.08107193399752889, 0.15902521248374665, 0.11388907661395413, 0.1463109997234174, 0.08455471175589732, 0.1703357534216983, 0.1290270300315959, 0.1555376781948975, 0.10243220959923097, 0.22076253539749555, 0.04896151952977691, 0.11857311241328716, 0.14108785428106785, 0.14869607745536736, 0.10584399902394839, 0.10246785982911076, 0.08880634432924644, 0.0943211784054126, 0.10696779550718409, 0.08482795102255684, 0.12375431082078389, 0.0658274573673095, 0.11581060636256423, 0.10392055580658571, 0.17565831781498023, 0.1194152015128306, 0.1205249862479312, 0.11343374568969011, 0.09442990685680083, 0.08461474853434733, 0.08830910029688052, 0.13640263783080236, 0.1249776551766055, 0.11303372894014631, 0.11710272702787604, 0.09452843692685876, 0.15605730031217846, 0.10986703993486506, 0.085397282615304, 0.10272454962666545, 0.24528489953705243, 0.12865550496748515, 0.10668807623109647, 0.16317022006426538, 0.07583987260503428, 0.11660681292414665, 0.15252380206116609, 0.11652042184557233, 0.09665558314216988, 0.12549934004034313, 0.09442380682698318, 0.20385428411620005, 0.22371051221021584, 0.10401130307997976, 0.07882881257683039, 0.12300925222890717, 0.09865660326821463, 0.12345604039728642, 0.11045604225780283, 0.1860721611550876, 0.14383486259196485, 0.11081052930759532, 0.14418343960174493, 0.11311915649899415, 0.12584559646035942, 0.11791601910122804, 0.18035334588161536, 0.14395243913999625, 0.15601805384669984, 0.0976863456889987, 0.10618087809000697, 0.17539400128381594, 0.080158985485988, 0.0859070863308651, 0.22049614254917416, 0.151637553902609, 0.17476319441837923, 0.1681747686650072, 0.1449387983552047, 0.12621463808630193, 0.12810054474643298, 0.2469473374741418, 0.16502043578241551, 0.1352846971047776, 0.14697164855897427, 0.10109736836914505, 0.16579495636480196, 0.12543064515505517, 0.20851079853517668, 0.14718445071152278, 0.05267302805025663, 0.1320525769676481, 0.1206186240805047, 0.1595198916537421, 0.07660164351442031, 0.1356512824339526, 0.10603413810687405, 0.10198653422828231, 0.1332437859049865, 0.11718003930790083, 0.13276822785181658, 0.07639185405735459, 0.20501812095088617, 0.09657445070999009, 0.21506615249173983, 0.1062439139932394, 0.14393330445247038, 0.1018386407356177, 0.13345852866768837, 0.08865507173218898, 0.08475612130548273, 0.08705957806003944, 0.09857354379658188, 0.18695260105388506, 0.06512641534209251, 0.10116144243095603, 0.15579856133886746, 0.13323094802243368, 0.14071353365268024, 0.09948515559413604, 0.14190908521413803, 0.09491746140910046, 0.1738575537289892, 0.18695636013788836, 0.12703212350606918, 0.08447522816381284, 0.1511394413454192, 0.09971000174326555, 0.14877642957227571, 0.07371672974633318, 0.08891025518200227, 0.2247117856251342, 0.09361553591276918, 0.1390830140028681, 0.14736628452582018, 0.17150629418236868, 0.1612875975136246, 0.08426682291818516, 0.20286839987550462, 0.12135699231709753, 0.09307099798960344, 0.12829824270946638, 0.12034810573926993, 0.09115335624665022, 0.11813724865870816, 0.13641927550945962, 0.10479834941881043, 0.09699563775211573, 0.09597233909049205, 0.11219496466219425, 0.13688869960606098, 0.24421058861272676, 0.05814650880971125, 0.1689018053667886, 0.11729228257068566, 0.11441492768270628, 0.19076789489814214, 0.11985592357814312, 0.05959448218345642, 0.12372639589011669, 0.2012716034161193, 0.1281385427074773, 0.14142804459801742, 0.08266155834176711, 0.1100243039961372, 0.22874430567026138], [0.009305381748293127, 0.030493550335190127, 0.030214665657175437, 0.036261074244976044, 0.0385594962696944, 0.08562363511217491, 0.013772639179868358, 0.05168397844369922, 0.02277888197984014, 0.022999097127467394, 0.008765468041279485, 0.014684985491580196, 0.12694745590644224, 0.07494241504796914, 0.020634295718212212, 0.06048752247755017, 0.05209412232839635, 0.00773447479254433, 0.0294775527103671, 0.03927919461524912, 0.008705288770475557, 0.0446704640718443, 0.01397641681666885, 0.041474530207259316, 0.0514235872376178, 0.034958334506622384, 0.0188773191933121, 0.023842655255326202, 0.051852859024490626, 0.05388427073402064, 0.0660682355186769, 0.019643446297517846, 0.008439263179233032, 0.0844275610787528, 0.030030521431139538, 0.02477689110673964, 0.02242491061666182, 0.07245250365563802, 0.010643490124493837, 0.04071349550836852, 0.018574526333915334, 0.006635885461167033, 0.017048044762175, 0.048139647381114106, 0.03920881696311491, 0.05325880393918071, 0.06330471166542598, 0.004680537103143121, 0.051292324638260264, 0.031606361336473904, 0.026143769367731044, 0.042715645395219326, 0.015410492096894553, 0.03537185749571238, 0.06021664451275553, 0.0708029850253037, 0.04458895166005407, 0.036974770948290825, 0.024507685730765973, 0.04829887240859015, 0.0325735247960048, 0.04371197568252683, 0.06581953886364188, 0.02194925756858928, 0.03926221766908254, 0.04398909956216812, 0.032993442977645566, 0.060355065656559806, 0.019876791097755944, 0.008989945236992623, 0.016892019027311887, 0.05185034165957144, 0.02441409369930625, 0.07804173909659896, 0.04377777661596026, 0.10985667191978012, 0.0603853418890919, 0.045059702292616875, 0.08653321130467312, 0.01137279991858772, 0.05004043092152902, 0.01894284871273807, 0.020059776725247502, 0.04795553368915405, 0.036770504766276906, 0.012621324708951371, 0.010111103067174554, 0.011709891875008387, 0.013343620147289974, 0.05062938913969057, 0.05425360073734607, 0.03868970035442284, 0.011985102285897093, 0.01412123824203653, 0.026449642776112472, 0.015802883809166293, 0.056832254332091124, 0.00538726058688813, 0.0362024081072637, 0.04229042785508292, 0.0440415706751602, 0.026553821650200655, 0.041940792330673764, 0.03271556592413357, 0.04649513294654233, 0.02120570702079151, 0.06174506499831166, 0.004165765238992337, 0.09980593302420207, 0.01458783115127257, 0.038757638673165014, 0.07443081999995879, 0.057129934430122375, 0.035087659888501675, 0.18196893776101725, 0.01761945436841675, 0.029819741312946593, 0.03270776616409421, 0.025001114699989557, 0.02190280336487506, 0.0054092357916358325, 0.011523841813738857, 0.03221597076792802, 0.014911906261529242, 0.026484955434820483, 0.010035687292526876, 0.024355142576886073, 0.010786064750781017, 0.02865272554169808, 0.019739174017948762, 0.042185600980051925, 0.034079336494739564, 0.007825964213615018, 0.025370902714452574, 0.04670169596959438, 0.05424858297088316, 0.0393292603216001, 0.04850351857021451, 0.0453103565211807, 0.03050823722566877, 0.04596295114606619, 0.026824523195890442, 0.045724910883499045, 0.030194173899612257, 0.03429716659177627, 0.06955008368406977, 0.023634969256818295, 0.03788600955158472, 0.03603215688573463, 0.01802515554507928, 0.012526852278304952, 0.020991810730525425, 0.024818836445254937, 0.04110910178029111, 0.03117683849164418, 0.04932414560711809, 0.04869571700692177, 0.061958308198622296, 0.04234673947628055, 0.06918852629938296, 0.11026069881128413, 0.007532501210724669, 0.010559580787750227, 0.04824325628578663, 0.06867530276732785, 0.022842258846919452, 0.06412684505007096, 0.024433443821700554, 0.04322719633845346, 0.02193826699762472, 0.031772751693746874, 0.011728331064140158, 0.025935415012229766, 0.038985684114907465, 0.04913067491725087, 0.05003813747316599, 0.04198758749823485, 0.02486010324875159, 0.008566642013777579, 0.03608279934685145, 0.017528026863666515, 0.054179392755031586, 0.007529116169150386, 0.023606514890811274, 0.020234270486980677, 0.02641062022719, 0.034318048506975174, 0.02110461887371327, 0.011664297714430307, 0.03516356081568769, 0.03505628103656428, 0.012985537710067416, 0.058774927231882296, 0.06947834896189825, 0.027602685814989463, 0.02619014384358057, 0.019003903293716054, 0.06392019721014158, 0.01465241750702262, 0.061815137309687476, 0.01388707326259464, 0.04330365705702986, 0.04317005690453308, 0.01880699921665447, 0.008703012285487992, 0.031433284016592164, 0.0223688432680709, 0.041216887068003416, 0.011550221558926361, 0.05242328305861779, 0.05645541294610926, 0.02756800758652389, 0.015835573930027227, 0.06407233833202294, 0.024928122991696, 0.09164720081857272, 0.0376596027719123, 0.057214507034846714, 0.07990553230047226, 0.004016937488423926, 0.01694464111434562, 0.06643397267907858, 0.04051954984398825, 0.029235621049468006, 0.021235080801748803, 0.014539141174671906, 0.02689301791334791, 0.04823617577286703, 0.018405377731791565, 0.015961494762450457, 0.006142964545038662, 0.04665804920451982, 0.03639824688434601, 0.0106807968279879, 0.035143170838377306, 0.09042249260736362, 0.03307475861428039, 0.023071749568251625, 0.022654196081150855, 0.05737097042479685, 0.024658259436754242, 0.022744470076369386, 0.04187323059886694, 0.06261900453163044, 0.028066903851660233, 0.027956436654286723, 0.05007292935624719, 0.03929118432902864, 0.03574456321075559, 0.010481320255036865, 0.037581123411655426, 0.12261389701494149, 0.03375718842393585, 0.007637305185198784, 0.027670237368771007, 0.0032584036151612444, 0.060678720075104914, 0.05946047151727336, 0.05201592456017222, 0.05257113244650619, 0.03265449098710503, 0.1171889416873455, 0.02423190195778651, 0.027427703508042862, 0.0249809622099357, 0.011089574312791228, 0.054945988048400195, 0.052527397471879206, 0.08214696416897432, 0.05229527742734977, 0.03392418267737542, 0.02369821720224406, 0.07748834629143987, 0.0064390051328311005, 0.016301586691822325, 0.01115350503407951, 0.027951625841004506, 0.060225492609398704, 0.029086787785802568, 0.04740869892495019, 0.016993013875825063, 0.038254392998559136, 0.06527523164238248, 0.007759030126700444, 0.03653120582125016, 0.05747415524508272, 0.06900809026722397, 0.04330766719899007, 0.05047727855188506, 0.0605406721255609, 0.14349532366863318, 0.009903802985458501, 0.0038536624550553305, 0.06647149566560984, 0.02303081185423902, 0.038178682061178346, 0.01892745614584003, 0.030299974472395012, 0.01037855867096888, 0.08862424588629178, 0.057842145141746314, 0.04204653522797993, 0.012887525871129972, 0.06619682469006095, 0.061770367569157054, 0.05825867743364402, 0.08128025103360415, 0.012491682111950857, 0.02197429720711495, 0.014720304935638393, 0.049033698692385635, 0.009343270295565682, 0.031210239377937148, 0.037784381969166655, 0.03266972070559859, 0.017511004116386175, 0.017835737405610935, 0.07079868989863566, 0.02677769579791597, 0.05944558445896421, 0.02610812253052635, 0.008313674828968942, 0.06291688819016729, 0.07073869383228676, 0.03130232336531792, 0.03158970330176609, 0.03246042997177158, 0.02281560599138694, 0.03457706228696874, 0.04260047425382903, 0.025248379646135227, 0.08133958892098495, 0.01796438085979649, 0.055226358718105724, 0.1001282778701612, 0.015776843331488113, 0.07401962099330765, 0.04740246318812881, 0.03954450520021575, 0.009112588745275778, 0.014798039603712303, 0.04137680759387357, 0.02686881965824536, 0.06116695994777339, 0.047000862059316466, 0.0273733155336231, 0.06261875347367354, 0.0593251512785043, 0.01966722046823374, 0.039227710770709176, 0.02359679657300668, 0.07192695114229407, 0.1785403410238879, 0.2273012516754014, 0.05385920565043177, 0.12988156346338137, 0.1357707181679351, 0.12610931588070734, 0.18637648411095142, 0.15871177001723222, 0.08172266943646328, 0.09839589654334954, 0.14230876948152268, 0.07881753532482044, 0.18867260590195656, 0.14251211285591125, 0.08566057455859014, 0.16611735549356255, 0.12339746925447669, 0.19173412876469748, 0.13616961533469812, 0.11050439466323171, 0.12033169876251902, 0.14131852904600756, 0.08534310159406491, 0.17490305405642304, 0.0953886496967503, 0.1118733933461564, 0.0925780830106565, 0.08243396412581205, 0.15278612369937555, 0.12537644377776555, 0.1473401202155011, 0.10750346497765609, 0.07373066007026605, 0.17521676793694496, 0.14526148246867315, 0.0982328038662672, 0.08359183663768427, 0.11713364108332566, 0.10554686175393206, 0.11323704517313413, 0.16285647904234274, 0.11418198661080428, 0.11752632286931787, 0.2184299627052886, 0.19304603551115307, 0.15944418071636132, 0.2110038854713951, 0.09266224170901946, 0.14194879308342934, 0.12881295223321232, 0.13684914101447376, 0.10586466720061642, 0.10296828619071416, 0.1244612086032118, 0.07938097723360572, 0.1187157676156078, 0.1422443493668522, 0.11400545894035272, 0.1521832589060068, 0.14179701837045805, 0.11008001172116824, 0.09182399990303175, 0.10016084755105631, 0.17187057249248028, 0.12869973188000067, 0.16536100607897553, 0.14070183570895875, 0.10864859460187809, 0.12805863842368126, 0.15318052896431514, 0.16426234931818076, 0.1925156789698771, 0.12834339242960724, 0.12519991610731396, 0.11650917173496314, 0.17967025110764162, 0.18693669619304792, 0.11006329261830874, 0.1699504812381097, 0.1085884492578251, 0.10343355086765119, 0.09818025811442307, 0.14374925861401217, 0.12297038574303899, 0.08732399637145655, 0.12809438364846365, 0.14744418034596102, 0.06909781973809004, 0.10379392760140554, 0.12436816788145474, 0.12456769788903849, 0.1003508237855775, 0.1965481854443039, 0.1404849759169987, 0.18302175269595214, 0.11968003373060908, 0.14307754965765135, 0.10668235618088927, 0.0977811234604035, 0.11261575815400907, 0.11163494256990296, 0.10481947899929114, 0.13199779205024242, 0.17568370859537805, 0.16114811785519123, 0.06862861955804483, 0.11816590997789587, 0.09833550692668983, 0.20280765742063522, 0.11438496357628278, 0.1806707509926387, 0.17812468404216425, 0.15047834467675003, 0.12669041327067784, 0.33779869814004215, 0.07822558815990176, 0.11647141804652554, 0.17369470532451356, 0.08434697147458792, 0.1598905889051301, 0.11335122904607228, 0.13347089157572814, 0.16237235787723744, 0.14891000597604684, 0.15690213069319725, 0.14759215526282787, 0.03552596636914781, 0.16968790175659315, 0.19901992566883564, 0.14887238799461297, 0.1750178893229791, 0.06411651096173696, 0.13163952556039604, 0.05750387507889952, 0.14215965462582453, 0.15473376347550324, 0.23736761723245892, 0.13474442038152898, 0.11131702855761562, 0.13263343008501188, 0.16041714565030166, 0.09877252419080053, 0.11296403660838093, 0.17628122653279985, 0.1118361349882824, 0.15226129043315137, 0.12948095638837132, 0.13799848434116158, 0.09894565918615886, 0.09582734294235706, 0.14605367210294518, 0.12069115947399821, 0.100386718288064, 0.1648445866469826, 0.15878954370106968, 0.1379634855048997, 0.13220356457999774, 0.14212131739727088, 0.1726276140127863, 0.1579742431640625, 0.24891924166253634, 0.09145775384136609, 0.13788739458790847, 0.09523931770984616, 0.0994355207575219, 0.13768356266830648, 0.15308092002357754, 0.2301961806203638, 0.16950316381241592, 0.08993484306016139, 0.12019707741481916, 0.11635168375713484, 0.0852487784411226, 0.11385665621076312, 0.08995821180620364, 0.20494383493704454], [0.0039423851495874775, 0.07073489403618233, 0.006811921193730086, 0.025472489584769522, 0.0841635363176465, 0.04667544684239796, 0.0216583441610315, 0.030698746110179594, 0.015314280920262848, 0.032304421200283935, 0.04245103030864682, 0.007522698924211519, 0.059149308928421566, 0.025810377971668328, 0.013491618812882473, 0.030056736631585017, 0.06782762932458095, 0.04342324206871646, 0.014718919027862805, 0.027337327732571533, 0.02539414762785392, 0.06513033048915011, 0.024859022681734393, 0.1024882701624717, 0.03225943432854755, 0.02881853235885501, 0.0105787095380947, 0.11239228264561721, 0.020549039489456584, 0.04262072852413569, 0.027617722151002715, 0.017259296462205902, 0.017959816015458534, 0.02391555196871715, 0.043816493824124336, 0.03527318832597562, 0.009065580687352588, 0.05490056012890168, 0.0014668752389427806, 0.025973038082676272, 0.014937770320102572, 0.036628175260765214, 0.042442233102130036, 0.03487258803631578, 0.04223900507869465, 0.06384110716836792, 0.0034502928943506306, 0.03167568047397903, 0.06489710443254028, 0.042864780606968064, 0.009841798455454409, 0.05089209754286068, 0.07951738312840462, 0.03567160712555051, 0.019068404832588773, 0.014869596210441418, 0.033761371592325826, 0.01914219551586679, 0.026653612099055733, 0.05667053908109665, 0.016417926609782234, 0.003456618112977594, 0.052557761913963726, 0.049954053413655074, 0.03049576235935092, 0.05148939834907651, 0.027017174554722648, 0.018208360000114356, 0.004695942392572761, 0.030981006499912058, 0.0007052780451236426, 0.016204372979700565, 0.016286348491641026, 0.08821576101971523, 0.04185715949695025, 0.06154692598751613, 0.03496049903333187, 0.029833871804709946, 0.03072824881279043, 0.08260819834790059, 0.04193952347018889, 0.04162507677184684, 0.02586659459796335, 0.060650493018329144, 0.05724177735724619, 0.029576150633926903, 0.04576516497348036, 0.021047289449987665, 0.05442448638911758, 0.02330163214355707, 0.013393702817016413, 0.00550873192592657, 0.017223659803026488, 0.041425828356295824, 0.01580066160698022, 0.029445817627544914, 0.025359072456402437, 0.03239471385521548, 0.02749693613233311, 0.048346475032823424, 0.02924622655180948, 0.03205578900607569, 0.030345287040940354, 0.02400231284887663, 0.021126571177904094, 0.04398494692785399, 0.033280585426837206, 0.02235068058195923, 0.03714367188513279, 0.02183211867564491, 0.02710415595876319, 0.027404914909441556, 0.02947565959766507, 0.049282361420669725, 0.028148960787802935, 0.01130331793267812, 0.044321130495518446, 0.031243955783013786, 0.08014219852962665, 0.03387235277997596, 0.044530896203858514, 0.04258540738373995, 0.010025124198624065, 0.021712002710306218, 0.03522939228319696, 0.08687282486685685, 0.03303441631474665, 0.04732136129002486, 0.038124555322740755, 0.026355117759002105, 0.03334218283583011, 0.03077170219538467, 0.04606272293520825, 0.024925754904480915, 0.02702446880617312, 0.0373220858829362, 0.0643348703160882, 0.05287675479693072, 0.0696356673059719, 0.03071011496441705, 0.047492084093391895, 0.04178175050765276, 0.059084020288927216, 0.01881261239759624, 0.024102033747892295, 0.03966242101575647, 0.030372509865888526, 0.04673548022817288, 0.02058614687328892, 0.07963626924902201, 0.02211785825368549, 0.034399425211761675, 0.0036640933415453348, 0.031601408030837774, 0.05384817606370364, 0.020460667088627815, 0.014381827919610908, 0.02875262625249369, 0.09613738594842808, 0.048795963770576885, 0.026508565060794353, 0.040211203175463846, 0.009228142410782831, 0.04422412034390228, 0.023591678722628524, 0.00246089999148223, 0.021590488962829113, 0.0345802955063326, 0.06946939908500228, 0.028132560596402203, 0.03618475601875356, 0.014273666044963258, 0.017135930314127888, 0.008061550723920976, 0.022296080565346137, 0.025941325052242194, 0.038976238907447884, 0.0444930984106447, 0.060938069729932716, 0.017593558079430034, 0.01843500935605594, 0.041472844047737975, 0.0519227583094367, 0.04521067633426615, 0.05432091819654618, 0.030679828553859676, 0.05560672848618456, 0.038921335246413946, 0.03765531103791935, 0.03893944873873677, 0.03386186941393784, 0.009494188358075917, 0.01072023413144052, 0.03364765251587544, 0.0070647034777461416, 0.04804841834785683, 0.026393818003790717, 0.03131378721445799, 0.0029603361160427865, 0.013158402139587062, 0.019640548952988217, 0.03796554742647069, 0.03454806848562189, 0.05030116139511977, 0.06032935596470322, 0.027716445603540966, 0.03144715327237334, 0.049267053670649014, 0.02767482426549707, 0.010500861215405166, 0.047393832222691605, 0.03839154867455363, 0.03840005411101239, 0.04513532162777015, 0.01993400347419083, 0.05276183810617242, 0.007936682468945426, 0.011709924105421772, 0.07077724819204637, 0.01564542806175138, 0.06380824571741478, 0.04303087919418301, 0.044774934715990505, 0.045746461155691316, 0.028811285604855845, 0.026672845174159323, 0.032847619016787837, 0.012321975414774247, 0.031322513174797804, 0.025334214325994253, 0.011161594019670571, 0.0073751226466681275, 0.0930267439356872, 0.039327848968761306, 0.06227365056318896, 0.037609984898673635, 0.021103034494444728, 0.04341976457674589, 0.035177270615739484, 0.0212656555896891, 0.034836754601980956, 0.06192672239350421, 0.02830195686380778, 0.006101847867414887, 0.007398226764053106, 0.029605120686548095, 0.06050308807087796, 0.004804490608096654, 0.02445379987226001, 0.07442463854593889, 0.008644886431284249, 0.04838279701237168, 0.01538964410844658, 0.026524717586913278, 0.021460347642589892, 0.03289268731272646, 0.01315612904727459, 0.02233897415655, 0.021615538779380064, 0.05901472150747265, 0.009601530053519776, 0.027203744543450217, 0.03455901664814778, 0.027204319601878524, 0.06361248836453472, 0.00798003576762442, 0.08011823945811816, 0.03449925467638033, 0.020617093159151927, 0.03577816426487906, 0.05478818115911313, 0.04033258969762495, 0.03791912206049476, 0.02886953783620681, 0.012149820902517863, 0.008758189905035709, 0.054667829402855465, 0.04394507621015821, 0.06057647841849497, 0.018925498572311232, 0.019312592622424875, 0.027759254377867495, 0.037018336289163144, 0.024423489712976983, 0.022896022569122057, 0.02069794399929898, 0.005581566298912678, 0.03943524070616279, 0.013749248381438, 0.06821664023612227, 0.08247542261545147, 0.026001607799636464, 0.010248231601768305, 0.012200652505271137, 0.04166662686371377, 0.01892919828450041, 0.014291026363415378, 0.06656607666185924, 0.0355013219772705, 0.025151038708697473, 0.018343990668654442, 0.021333922997915318, 0.008091583532015128, 0.09967648889869452, 0.013063003508640187, 0.015387247183493205, 0.03708510074232306, 0.041176103720707555, 0.03220554847004158, 0.05291505470605833, 0.017346788463847976, 0.012395076536839562, 0.023199085146188736, 0.021767398309228674, 0.014264434576034546, 0.013700117357075214, 0.06486401906503098, 0.04999829389687095, 0.020035782030650547, 0.054108770830290656, 0.021705995979053632, 0.032358503833945305, 0.002272390240770099, 0.1262719335832766, 0.024750094062515667, 0.06839694056127753, 0.02365316417334335, 0.012284407475298005, 0.04545133574200528, 0.049808639966483624, 0.020894980390689204, 0.00597335326684905, 0.018044310588655726, 0.08240817979510341, 0.033311153429427316, 0.012178332095832696, 0.030081028185252632, 0.04569726736683931, 0.01878660075765635, 0.08052042073437146, 0.024376367152269398, 0.028945564292371273, 0.09191071667841502, 0.005684785045949476, 0.04672640821497355, 0.025769748991089206, 0.00949457597120532, 0.055006547298814566, 0.01925966010562011, 0.020369278599641154, 0.009691435943490692, 0.01309435861185193, 0.13876830946121896, 0.14903594207550797, 0.1649136207997799, 0.11440012204859938, 0.15260722115635872, 0.12368558879409518, 0.11185425865863051, 0.17247688424374374, 0.23816847854426929, 0.13922784051724843, 0.13320042751729488, 0.15105488231139524, 0.20862433101449693, 0.09068883117288351, 0.07157516466187579, 0.19064404868653842, 0.08064107104603734, 0.09158245500709329, 0.05548147092174206, 0.10024482304496424, 0.11012465254004512, 0.1762823121888297, 0.08286249970218965, 0.14662307154919418, 0.13950947326208862, 0.11271090911967413, 0.08522475151611225, 0.15361815690994263, 0.1523809161569391, 0.1788933149405888, 0.1545013380902154, 0.11955567183239119, 0.18238386192492076, 0.09025519301316567, 0.09725543524005584, 0.1852011936051505, 0.13465707935392857, 0.11653621814080647, 0.1132402682144727, 0.2079900364790644, 0.12004990316927433, 0.07701322250068188, 0.1592271173638957, 0.05651299003511667, 0.14744426177016326, 0.15785583880330833, 0.16453260981610843, 0.13688876745956285, 0.1145104111305305, 0.10357954446226358, 0.2025423502283437, 0.07220160176179238, 0.21743049419351987, 0.1093349666999919, 0.0708659870017852, 0.059505234472453594, 0.15867666261536734, 0.14890412986278534, 0.1418704358594758, 0.1107272052073053, 0.1451644112489053, 0.1595929834459509, 0.14714821694152697, 0.12477539745824677, 0.10584496932902507, 0.12470416485198907, 0.09813251639051096, 0.05636450621698584, 0.08552733742232833, 0.08548631319510085, 0.2348501437476703, 0.1624716275504657, 0.07460529849465404, 0.2285911196044513, 0.12595456918435438, 0.14125904866627284, 0.10270280257931777, 0.11666180140205792, 0.11527991055377892, 0.14888671865420683, 0.12272153981029987, 0.1367878828729902, 0.10259032861462661, 0.1311511296246733, 0.13743945290999754, 0.09804590818073068, 0.10444005578756332, 0.12224281978394304, 0.23418186817850384, 0.0937589578596609, 0.11259228762771402, 0.1126844191125461, 0.11460292259497301, 0.18393693358770438, 0.08538339300347225, 0.18724674598446914, 0.12937658413180284, 0.10803646102015461, 0.11201492218034607, 0.1281198558530637, 0.12116815602140767, 0.13357094834957803, 0.14562003394322737, 0.1452176355357681, 0.11566294357180595, 0.09060099481471948, 0.1324456523039511, 0.13107598865670816, 0.1622510358159031, 0.11628463092659201, 0.16106311098805495, 0.1429948498095785, 0.06557962245174817, 0.14124075536217007, 0.24065004395587103, 0.12816225072102888, 0.13316724715488298, 0.13609960409147398, 0.11050789590392794, 0.09019381273537874, 0.11026506857680422, 0.15942569742245333, 0.10517870900886399, 0.16379806851702078, 0.10860835068992206, 0.22288149169513158, 0.13256788360221045, 0.20436606236866542, 0.10954921413213015, 0.10505934112838336, 0.1318080329469272, 0.11023161680038486, 0.07276616325335843, 0.1348228726003851, 0.07268942772809948, 0.12593018263578415, 0.1476323516773326, 0.1254090948828629, 0.1650214535849435, 0.13149161849703106, 0.11539302234138761, 0.14776241326970713, 0.09903426907424416, 0.15184963680803776, 0.12286712628390108, 0.20478906109929085, 0.10151255716170583, 0.19307195554886544, 0.13015772721597127, 0.15394920057484082, 0.11392145630504404, 0.10408505305115666, 0.13205786954079354, 0.1707813609391451, 0.1605556346476078, 0.12092673326177256, 0.09944203469370093, 0.15427892788180284, 0.2266155784683568, 0.08427742163517646, 0.07877384445496968, 0.1271503921598196, 0.16925749342356408, 0.13941111282578536, 0.0883735679090023, 0.051068659140063186, 0.08784676010587386, 0.08194302368376936, 0.13552504777908325, 0.1145898811519146, 0.13087632294212068, 0.16991674447698252, 0.09617676133556025, 0.07493306483541216, 0.11165678461215325, 0.08208339900842734], [0.03165515139698982, 0.04012403517429318, 0.033392248542181084, 0.0021180385790233102, 0.07380532606371812, 0.03262872022709676, 0.012841916443513972, 0.04863732906856707, 0.01834517640859953, 0.024260841476331865, 0.054991840052285364, 0.03611136567113655, 0.016126290562429597, 0.062402029388717244, 0.06328092901302235, 0.045897207888109345, 0.03774895226316793, 0.01746745064987668, 0.041120762404586585, 0.026731407835281322, 0.03438186472547906, 0.030974967538246086, 0.050181070874844275, 0.07152271390493427, 0.002981416290692453, 0.049660213823829374, 0.04381294169330171, 0.10014697150992495, 0.07251370072896991, 0.03366841908012118, 0.0366668347934527, 0.038857298504029, 0.0937354126945138, 0.0616752098181418, 0.005852652913225549, 0.029345516581088305, 0.019814840850553343, 0.01926143786736897, 0.03594711269917233, 0.04915712760495288, 0.03633505491805928, 0.03675352782011032, 0.06758611157004323, 0.06712345925292798, 0.026137928877558027, 0.019716359974284257, 0.05624322486775262, 0.0324468151666224, 0.04860085441863962, 0.06724204003278698, 0.07416038308292627, 0.0055562361625821465, 0.0603931246857558, 0.037024758623114655, 0.044933413354946036, 0.03997083893045783, 0.018419840705714056, 0.04267738280551774, 0.014567541257877435, 0.0497945976842727, 0.06343893267746482, 0.012068103233884488, 0.058244251779147556, 0.036359098806445084, 0.023566091167075292, 0.08459527457931212, 0.041912375284092765, 0.02471367878440235, 0.025422213532562767, 0.050505352938281636, 0.0031853215768933296, 0.03231391390519483, 0.041049736751509566, 0.011094010235475642, 0.00919412320945412, 0.04401822228516851, 0.025830666168725917, 0.0393716314408396, 0.03915084971647177, 0.03206908150709101, 0.009953418314190847, 0.009042373093377267, 0.020804574081142033, 0.040201042113559585, 0.0028433935741694377, 0.032166865188628435, 0.02890695904248527, 0.008142211574262806, 0.032388396694191864, 0.02869442491126912, 0.03491046046838164, 0.028311704019350663, 0.0263216100034437, 0.028925618755498102, 0.044659980705806186, 0.04649412871471473, 0.023489450636718954, 0.02237604252461876, 0.027655523336891617, 0.03046207648835012, 0.016989497368090918, 0.01635983383416065, 0.038320685869881084, 0.028496045020541975, 0.01849022344686091, 0.07242295345557587, 0.02217330813540944, 0.018257871004087583, 0.020278309106028507, 0.02873673156968185, 0.016890594103772725, 0.014674437664715307, 0.06509202040199723, 0.036458758637309074, 0.10460379307291337, 0.020493686298972795, 0.05240767336051379, 0.07542464988572256, 0.042889974612210474, 0.04027883954612272, 0.024492247362754176, 0.04166697970192347, 0.019898030940177183, 0.006676223095772522, 0.07790831875588212, 0.04316951068384307, 0.04186016879975796, 0.03072216913902334, 0.020732020027935505, 0.011446698319299944, 0.0907006308968578, 0.01285961433313787, 0.025464830620746528, 0.04562066415590899, 0.011197078008470791, 0.10239797750754015, 0.033375543010021956, 0.029852684188101972, 0.008284921907553715, 0.0033448803587816656, 0.011877217762438315, 0.03315786558336445, 0.08084393266056265, 0.04105333637978349, 0.022376975510269403, 0.04794433446867125, 0.04501268999384982, 0.03182321095040866, 0.017013658303767443, 0.016819436136367064, 0.02570504728438599, 0.056953630676226955, 0.01777760561422578, 0.0785368796704071, 0.03581977881757276, 0.00816730804009629, 0.06830778784517731, 0.04249441583773919, 0.0596964049286076, 0.018148311347301518, 0.02216881623358599, 0.03038612467103771, 0.051582496746310165, 0.05740153842738696, 0.05769558836306844, 0.026129735567207848, 0.028191101205136095, 0.020779536138953905, 0.022813687433621714, 0.06289677641221456, 0.028624247426965406, 0.011617839269872223, 0.027992616141481057, 0.026322161313146353, 0.023010067342381393, 0.039113106206059456, 0.056559540930071046, 0.03173755608232958, 0.029933168619338955, 0.03250924038833805, 0.08021955152175256, 0.043262517478849204, 0.02469307846123619, 0.03525354812986084, 0.05185203460444297, 0.04559379756184561, 0.03491112543269992, 0.04287087045876043, 0.044575194362550974, 0.060967402798788886, 0.03128766700891512, 0.016661880305036902, 0.03922539357362049, 0.02683194467265691, 0.04883297785584416, 0.019550168088504245, 0.029012552662087337, 0.039445856386529546, 0.027692552689196806, 0.03484592839543309, 0.03710122612704124, 0.03577684451426778, 0.021412722965968505, 0.024698430406195775, 0.08207296313984053, 0.024473138120291487, 0.038271861882614236, 0.06306765867131096, 0.010432288466420556, 0.01744010908130024, 0.011635952762195041, 0.03285930338980896, 0.02794613649270364, 0.02035544835962355, 0.03455346283902015, 0.00790209838721369, 0.04109170074973788, 0.021506979961746504, 0.06312219931610993, 0.03480348603001662, 0.03399157477542758, 0.03766686988196202, 0.09439501658614192, 0.015958458318242004, 0.05755632583584104, 0.047524633418236456, 0.020454965698133622, 0.04992576189605253, 0.025892360268958976, 0.03195272292941809, 0.019646150259567157, 0.06985486125839607, 0.06546501788709845, 0.039314505577619584, 0.026469020039907525, 0.009921444047774588, 0.053030429407954216, 0.06290428779487099, 0.09110499027052096, 0.030611768098814145, 0.045807855004178624, 0.02973304150093879, 0.024687312609915222, 0.10641233317021813, 0.04424232543845262, 0.029631403740495443, 0.038860399409064224, 0.03454635179202471, 0.02116897961656962, 0.09215242442275796, 0.05909979622811079, 0.028022585336917212, 0.03142452073682632, 0.01596984583219247, 0.009097694901616445, 0.03872109277706061, 0.11425931246152946, 0.013723911035672894, 0.015222615928256085, 0.014777446065896323, 0.05259997697014894, 0.033619435637124946, 0.020604531779619198, 0.06634730340114661, 0.03826195187866688, 0.037777847676937065, 0.020108366617932916, 0.020061262716938342, 0.018218639805646877, 0.07298720960638352, 0.02582923785251166, 0.059871718021375794, 0.013892952768531228, 0.020017288558717285, 0.08896461940769639, 0.01930367497594229, 0.02365606151787298, 0.013852893757367772, 0.05040894668283207, 0.04817869367876223, 0.01846728896323059, 0.014562062087601848, 0.021230037590222697, 0.047374996090573926, 0.0810354355988758, 0.008540665148757398, 0.020660356551940953, 0.03220165367903454, 0.04076352050261838, 0.04411460479189243, 0.07636294168020998, 0.038373346972678385, 0.09993824735283852, 0.052227220364979336, 0.017051540913858583, 0.034235925413668156, 0.006102081961996321, 0.03675075261188405, 0.07771365384438209, 0.010585719653006111, 0.060187725350260735, 0.03375696111470461, 0.008927067941320794, 0.06440494262746402, 0.0029810978033180746, 0.022313067689538002, 0.08221877352999789, 0.03018067783809134, 0.020532401810799326, 0.051810168993792365, 0.05228859046474099, 0.08134773134120873, 0.017350533977150917, 0.02341133768537215, 0.007353563892788121, 0.040820581905011616, 0.07061279165957655, 0.03784568082275135, 0.01839043978335602, 0.08313749637454748, 0.029988180845975876, 0.08241768607071467, 0.03428983162822468, 0.003903517815550523, 0.02292796121244984, 0.053216755124075074, 0.01754693763463625, 0.017625668052850024, 0.03131798056087323, 0.10962029067533356, 0.06990074379635708, 0.039900932860161574, 0.07110802722828728, 0.03004764426233513, 0.03754105591880424, 0.03243624698370695, 0.0073620294653145325, 0.017238882736169865, 0.0423255284715976, 0.03691255607243095, 0.08028613616313253, 0.028248583299240897, 0.016709762824965373, 0.01088599514748369, 0.029376352605010782, 0.12960007999624523, 0.04210862457486136, 0.06917638730789934, 0.06563410881374564, 0.03197854457955275, 0.031788449601403306, 0.02214050435993288, 0.1666062671158995, 0.1141699765409742, 0.08366049759622131, 0.10220345508839403, 0.19359110269163335, 0.16545824014714786, 0.0666384899190494, 0.13663906657270022, 0.10540086815931968, 0.10881727162216391, 0.14675930781023844, 0.13010006531008653, 0.12009300371365887, 0.16704164232526506, 0.12708869975592407, 0.14349996484816074, 0.09231924904244286, 0.07937543360250336, 0.15724229386874608, 0.10306729123528514, 0.1626647657581738, 0.20540806145540305, 0.09873187994318348, 0.15061397025627749, 0.10261509514280728, 0.17513649724423885, 0.07150304317474365, 0.22854386642575264, 0.16479947763894284, 0.14840855502656528, 0.07393078040331602, 0.11662856675684452, 0.1841977760195732, 0.21209069501076425, 0.053828885313123465, 0.13266281065131935, 0.09195765094565493, 0.10582881341023104, 0.10729972805295672, 0.14189160615205765, 0.18198541259127005, 0.08993440201239926, 0.11191000709576265, 0.149559350418193, 0.21758673366691383, 0.15844829486949102, 0.15349861261035713, 0.11184734438679048, 0.1446640866675547, 0.1427107471972704, 0.07980547552662236, 0.11660510301589966, 0.16036012156733445, 0.17155217672032969, 0.14133283256420068, 0.1390348244458437, 0.18831144885293075, 0.1524169056543282, 0.10470100678503513, 0.20282170309552125, 0.12493880226143769, 0.20528515162212507, 0.23856132317866596, 0.09579391830733844, 0.14334679235305103, 0.09354664425232581, 0.16458179003426007, 0.15490292225565228, 0.1570385026612452, 0.1105813066075955, 0.10879531422896044, 0.11016243336988346, 0.12753936914461, 0.20047159705843243, 0.1452463918498584, 0.08723922699157681, 0.10462718217500619, 0.11393790399389607, 0.1190745769334691, 0.14533203653991222, 0.15214790723153523, 0.11826930514403752, 0.11604803933628968, 0.13876140197472914, 0.14134136853473528, 0.15590654340173515, 0.13815036761973584, 0.11066699200975043, 0.1505805320505585, 0.10605309637529509, 0.0983843207359314, 0.10330196935683489, 0.1079643734597734, 0.10744198970496655, 0.10053223012281315, 0.17997883526342257, 0.13500147658799375, 0.07320081243025404, 0.19974768161773682, 0.1647888110684497, 0.10606484860181808, 0.10245145285235983, 0.16899826590503964, 0.16045004102800572, 0.07966668797390801, 0.24312775528856687, 0.12839927657374314, 0.11929016107959406, 0.1625106026019369, 0.10191329994371959, 0.0661684347848807, 0.15501840891582624, 0.21030598506331444, 0.1120552271604538, 0.27110815101436203, 0.10758063476532698, 0.2521193213760853, 0.1281192044594458, 0.2551339981811387, 0.12066276956881795, 0.14602653070219926, 0.14450400668595517, 0.19223601397659096, 0.09288529652569975, 0.20698545181325503, 0.13064114270465715, 0.11857993847557477, 0.13165304197796754, 0.08064703536885125, 0.13873583477522644, 0.24625949295503752, 0.09306938307625906, 0.145716698041984, 0.15323859799121106, 0.1256014188485486, 0.24484026911003248, 0.1286141686141491, 0.12292970078332083, 0.10617838786648852, 0.20619486352162703, 0.18305414595774241, 0.12523602774100645, 0.2244339119642973, 0.13840766809880733, 0.13343729052160466, 0.16523355006107263, 0.09472673878605876, 0.11518384356583868, 0.1172632412718875, 0.13439087649541243, 0.12194612356168882, 0.10072446587894644, 0.10717903024383954, 0.18951089520539555, 0.14068812930158206, 0.09248285740613937, 0.14558958129159041, 0.13039017974265985, 0.13014030243669236, 0.07492637448012829, 0.26554932072758675, 0.13393985426851682, 0.10096413801823344, 0.1211532282509974, 0.16811839597565786, 0.11780853915427413, 0.15312209352850914, 0.11567739636770316, 0.07344424365354435, 0.14752766729465552, 0.08565760936055865, 0.12064292920487267, 0.22912113687821797, 0.0928663450426289, 0.10464009469641106, 0.11715117442820754], [0.057837565030370436, 0.034058804025075266, 0.03648428851738572, 0.012926832556591501, 0.025275370072839514, 0.027730236827794994, 0.05647055784772549, 0.032651220448315144, 0.022364188517842973, 0.06830200672681842, 0.0761872689638819, 0.015580902774153011, 0.02526186722596841, 0.0588299971339958, 0.04734715919143387, 0.03772288973310164, 0.05429173440539411, 0.060477005184761116, 0.040765152379338226, 0.018191803745659332, 0.021435711732400314, 0.00871485102522586, 0.10489207546093635, 0.04389029807810273, 0.022633130961496915, 0.013642167921976318, 0.04199477318408234, 0.049900483073932786, 0.047172198936875374, 0.05664489045739174, 0.029593151328819137, 0.032082994867648394, 0.055427259366427145, 0.10755109135061502, 0.009952368281249489, 0.04984935885295272, 0.0179333005632673, 0.019498585856386592, 0.04365956224501133, 0.03423015447333455, 0.03906951711646148, 0.010015945316159298, 0.039382080880126784, 0.03013071391199316, 0.03146212175488472, 0.022183280903846025, 0.04900737492633717, 0.03889493005616324, 0.031246422257806574, 0.03685976944065519, 0.010591728080596243, 0.04212559473567775, 0.015863076650670598, 0.06181002115564687, 0.016335186049608246, 0.009384364072632576, 0.07331790721842221, 0.02952478892569031, 0.026770593232608268, 0.017724849516525865, 0.02965838907818709, 0.04367099216740046, 0.03014619808111872, 0.037506667764059136, 0.07109691282468182, 0.02758847559536142, 0.030667241729263748, 0.054345549017723115, 0.08053112801696573, 0.03963726772261517, 0.03787940740585327, 0.04327860554414136, 0.020963490375184586, 0.04418624791183642, 0.05084007087030581, 0.07434693271560328, 0.052619084516274076, 0.04091802292636462, 0.11035110003181867, 0.029918664933315346, 0.02779406152798661, 0.0641193947355662, 0.054600837640464306, 0.11188816505351237, 0.020442248255546604, 0.04198361128302557, 0.034574975791786394, 0.03055667444797499, 0.06719680888844387, 0.02464060565190656, 0.0429732003249228, 0.035701272676565816, 0.049264624515282254, 0.01644807561699833, 0.008327787509188056, 0.0410110602554466, 0.03126134663554175, 0.009303335965211903, 0.04270932823419571, 0.05310539395681449, 0.004717856953253171, 0.06010805855372122, 0.031232566572725773, 0.005786088627896139, 0.02836986634481166, 0.025161242179040397, 0.05246477208233305, 0.04629095158140574, 0.040887895971536636, 0.04500608106276818, 0.06334207180355277, 0.05325008476419108, 0.051168648060411215, 0.01900366411012198, 0.06573644546525818, 0.04852528597361275, 0.0922471886234624, 0.016269159503281116, 0.012162879308951753, 0.009535887727646955, 0.03475735582677381, 0.021728065330535173, 0.005845449415833822, 0.0491891476724829, 0.06306862897638764, 0.02287660798590098, 0.008317856301021363, 0.01888678136414715, 0.012938220918710743, 0.056458724197000265, 0.021222826459312012, 0.05078298232651182, 0.027606109024158547, 0.04725238142002906, 0.0012892983837186226, 0.011105648807383009, 0.018716677723984634, 0.027473845585648502, 0.029600014710532765, 0.015787808457389474, 0.027820673671418, 0.046820914572370906, 0.018201808744509305, 0.015431869342657072, 0.03385797801560589, 0.037097809703222344, 0.0571056225204042, 0.03967833605461887, 0.0727145674505404, 0.03038359373541815, 0.09790885089231388, 0.02434210622284029, 0.03771325792851193, 0.06848405088697161, 0.01643961767799088, 0.026018883301211253, 0.028177681478804777, 0.03939051167773349, 0.02946944421689425, 0.045792146918496916, 0.052484259608068635, 0.11878838443330356, 0.08243389627231018, 0.008051209850236773, 0.028894239903560708, 0.05839325128389256, 0.028714421338268688, 0.043965120134609084, 0.019765831962493912, 0.05194932295541678, 0.023479650894712125, 0.01884735847956368, 0.03017426568216511, 0.021178404467978647, 0.11377526593527623, 0.010750368719787469, 0.03339594655803271, 0.05752429898296084, 0.04057599038683942, 0.0536796652844974, 0.011285936410006667, 0.024372967691825967, 0.05913715636623757, 0.027974088742796863, 0.028163567950416888, 0.05680938770196267, 0.07528854254633188, 0.05105788739664214, 0.02678817746761654, 0.037943098095378706, 0.02855129473443542, 0.046443706777478964, 0.03535534195335848, 0.06244793228272881, 0.023912098225472227, 0.01787108399106988, 0.016582478137154664, 0.0019107794214505702, 0.03234134707599878, 0.031596600610230646, 0.068123300958957, 0.06615896922137056, 0.04619739856570959, 0.01994907882596765, 0.05230719589495233, 0.012625334850911583, 0.042655272741935084, 0.04923662476773773, 0.008397392479569783, 0.014776104262896946, 0.017242551914283206, 0.1145790788744177, 0.01109887533155935, 0.014548917167953082, 0.09350987443966524, 0.003403745392071349, 0.02096894579673452, 0.06497398923550333, 0.03983307596562164, 0.011918720356853945, 0.020861377640228187, 0.06225473979221923, 0.03968174908576267, 0.02985924222905721, 0.03155404967921121, 0.026494305647377456, 0.057823702559939454, 0.035540476840521605, 0.019027819956785867, 0.04027581327993955, 0.03701400723574417, 0.014944275774593865, 0.07770059883062329, 0.0485768682057304, 0.03457767636116062, 0.02844070370442101, 0.035916785576513836, 0.0411512286269239, 0.04514747079727905, 0.06723184843680688, 0.03712270176038146, 0.08899408818355628, 0.016882984333538582, 0.03339517981346164, 0.029992292768188884, 0.04045028159660952, 0.03256992516773088, 0.03971820677231465, 0.03439357623990093, 0.03838383712406669, 0.04758073130090322, 0.08281853741833142, 0.07683069658066545, 0.02607329672069422, 0.08154316299727984, 0.05332852680502193, 0.07399517337658576, 0.06455177082014935, 0.02684409553850336, 0.08331832595701728, 0.04531052615493536, 0.03318387722330434, 0.005010498928770955, 0.03826908667438796, 0.05624854118962373, 0.014189212183867182, 0.014232918320755874, 0.08747223591698067, 0.033620667178183794, 0.04028678858386619, 0.03461097885987588, 0.011592885296392654, 0.07419315632432699, 0.023260740230658224, 0.03948857695130365, 0.06346895106668983, 0.056015820641602786, 0.03430425049737096, 0.020094320943046893, 0.04322784433939627, 0.014274994277262261, 0.046348806869770796, 0.011553463259977954, 0.08826960955879518, 0.037138684652745724, 0.008734187576919794, 0.023076635020385896, 0.055435289828372855, 0.05481391120702028, 0.024772599372746687, 0.040258588668491156, 0.03303590909178768, 0.05579515426818814, 0.025697364571637342, 0.03109754149668983, 0.022308818363983716, 0.10946062460009541, 0.021565104967781475, 0.011080161335745027, 0.028951257201177732, 0.05046349072030612, 0.03979533924055951, 0.051909689724977524, 0.015883485287693993, 0.02221419835197074, 0.029244648957891122, 0.02907349189211215, 0.049005973751523664, 0.03964575619569846, 0.04517477843910456, 0.025949979766405055, 0.02013768781242626, 0.009808078657702675, 0.033607272896915674, 0.04372943438855665, 0.020111179145585214, 0.04978207532050354, 0.023212279259626354, 0.03402391714709146, 0.009018939886508244, 0.05653592791142208, 0.10784119899783816, 0.0235866965792541, 0.052796935330012014, 0.023258551955223083, 0.05040225972022329, 0.032534583671284575, 0.04958299993138228, 0.05792832587446485, 0.03192336271916117, 0.05414684343018702, 0.01275957706716976, 0.01572541207341211, 0.027639915335125158, 0.015411302946241838, 0.05958652975303786, 0.02377142264906849, 0.041983651995126686, 0.028149371301489215, 0.030001870289977108, 0.012119660869107714, 0.04758537926578096, 0.022810667952788726, 0.05433996467451964, 0.05270328053406306, 0.03837603397135224, 0.012338768308317023, 0.05196805730728166, 0.03216892793508513, 0.029999566663588797, 0.094326504905309, 0.05076762029368963, 0.19601074499743326, 0.1612030113381999, 0.1290665886231831, 0.12220494395920209, 0.08345406010214772, 0.09663465033684458, 0.10377650282212666, 0.17394675394254072, 0.060581648855337074, 0.2013426460325718, 0.17221810455833161, 0.14999985535229954, 0.11795355565845966, 0.11269508568303925, 0.12655309135360376, 0.12113619702202932, 0.11539482724453722, 0.1562245184821742, 0.12807219555335386, 0.0530022735973554, 0.14913795303021157, 0.1333396221910204, 0.1966656669974327, 0.13256827715252126, 0.08789085131138563, 0.1338577243898596, 0.10429039810385023, 0.11339551024138927, 0.09829609082745654, 0.1481249002473695, 0.16348932151283535, 0.11082237652902092, 0.09003281673150403, 0.1437288075685501, 0.17579390268240655, 0.21710288391581603, 0.08576753881892987, 0.25705569077815327, 0.12107914579766137, 0.10061620561672108, 0.14197357318231038, 0.12374433635600976, 0.12695804105273314, 0.11142340927783932, 0.10924193276358501, 0.1343298761972359, 0.20202993415296078, 0.11516632379165717, 0.15254950496767247, 0.15093404879527433, 0.14063186517783574, 0.18614644716892922, 0.06619962025433779, 0.10901668627879449, 0.09850807873798267, 0.10702051767813307, 0.1557211269225393, 0.12912054572786602, 0.18845210916229657, 0.092813480379326, 0.10210683848708868, 0.13554602808185987, 0.09129986552787678, 0.1321441520537649, 0.17129208067698137, 0.1345615280526025, 0.18822921040867055, 0.1567717298333134, 0.13541435157614096, 0.15662498985018047, 0.12751302841518605, 0.19780409948102065, 0.11617272693131651, 0.16254229018730776, 0.22087659713413033, 0.1513794527522155, 0.21775354471589836, 0.10254511104098388, 0.3550759639058794, 0.1321365117494549, 0.12062227459890501, 0.2464764341711998, 0.13203509790556772, 0.35081375975693974, 0.12926788282181534, 0.15485378274960176, 0.12900119141808578, 0.12238191946276597, 0.15756934774773462, 0.15954225616795675, 0.15771764836141042, 0.1389173971755164, 0.10994266944804362, 0.17955629793660982, 0.10159880574792624, 0.10971163505954401, 0.1770273164979049, 0.09320749887930495, 0.08553570375910827, 0.20965581280844553, 0.16808560916355678, 0.1044517130191837, 0.12129954754241876, 0.16161087873790944, 0.11247426324657031, 0.19302201537149294, 0.17146254224436625, 0.2669997029006481, 0.16446021012961864, 0.12147038908941404, 0.22207102232745715, 0.10257207602262497, 0.11033870319702796, 0.12077616634113447, 0.09391605228717838, 0.12561918289533683, 0.1672004195196288, 0.05110465542280248, 0.08952656853944063, 0.09803190321794578, 0.18579040627394403, 0.05833420516656978, 0.0575807938086135, 0.1665035504847765, 0.1405707291726555, 0.08802804430680615, 0.13683436252176762, 0.12767195488725389, 0.113651582572077, 0.09890443139842578, 0.05690455563100321, 0.10507168368037258, 0.14593988178031786, 0.1754982378333807, 0.09348155238798686, 0.13783551380038261, 0.13935269096067973, 0.12231922282704286, 0.16822906503719942, 0.1571339996797698, 0.13202740331845625, 0.11274669505655766, 0.08250381252063171, 0.04558381631172129, 0.10707581149680273, 0.19878143418048108, 0.11332358552941255, 0.12993564270436764, 0.2102070410868951, 0.11141342124236481, 0.14807679211454733, 0.17254404563988957, 0.1667551648403917, 0.09130601305514574, 0.11750262842646667, 0.12580754421651363, 0.1836048856909786, 0.13558755442500114, 0.09643972079668726, 0.14040855930319854, 0.1501175540366343, 0.16416557665382112, 0.09960637587521758, 0.15644090329962118, 0.07878404283629996, 0.13781690837017127, 0.115975680361901, 0.18304578640631267, 0.11656481160649232, 0.13139605362500462, 0.061000196396240165, 0.1803500753428255, 0.1481461383934532, 0.22553954406508378, 0.3240864553621837, 0.1499431026833398], [0.03965166962838598, 0.029438933889780725, 0.049874512146094015, 0.027844995759161453, 0.014032229714627777, 0.025575726991519332, 0.024458605596529584, 0.08097216220838682, 0.046544435300997326, 0.03794489282050303, 0.03188305434637836, 0.01712088719276445, 0.07777339206742388, 0.03759461947317634, 0.04091412474268249, 0.05936553768281426, 0.04372033862663167, 0.06308409278946263, 0.04271825436236603, 0.08302377390542201, 0.04644235649279185, 0.023310164721416574, 0.015030001888849905, 0.044377866201102734, 0.051447315607219934, 0.011424979261521782, 0.11092879796134573, 0.06736197109733309, 0.004759734862350992, 0.021954872445868592, 0.027768933679908514, 0.043920241828475676, 0.007240071277400213, 0.02241793188399502, 0.00837000341354204, 0.010570322845264204, 0.046587926003017595, 0.012862338651237743, 0.054799115750938654, 0.06689836204584156, 0.023749036082465733, 0.028330012590491345, 0.048671483128730736, 0.0453756689094007, 0.022713004711217115, 0.017054168540718298, 0.052754207979887724, 0.04446090192400983, 0.0317787126238857, 0.060742237738200595, 0.01793225053032594, 0.030507467088422606, 0.04881826721663986, 0.016246954444795847, 0.01103683008945414, 0.05047973145597747, 0.08253030931310994, 0.011313436586143715, 0.08118360050554786, 0.023102432921794907, 0.00917074513355536, 0.03766750091952937, 0.031405182488794835, 0.049563627756599865, 0.01633525899212275, 0.027674866673935736, 0.060811095471893034, 0.04614135157316923, 0.021114522092310444, 0.016147136854540025, 0.020606318023055792, 0.020170111608292376, 0.06511700406138386, 0.030869211070239544, 0.02579346887900361, 0.037297662014939954, 0.025053205833371197, 0.03619401802175811, 0.038663973699190786, 0.02019859990105033, 0.033713585763637505, 0.07103761564940214, 0.047694497874804904, 0.07028632810605423, 0.046713475337518115, 0.04336419255871858, 0.030271686347467557, 0.012135504661793155, 0.02946470464978899, 0.05671540042385459, 0.03187780248533402, 0.033605457815740786, 0.036568908619561365, 0.06142512895166874, 0.031600977161100934, 0.03594610168199454, 0.005101438736476536, 0.018015617039054632, 0.05644312806959663, 0.05745410453528166, 0.04494940642533558, 0.05312606552615762, 0.03411761265514152, 0.024533013746674572, 0.017565157996224504, 0.04664680248658572, 0.021783730647127544, 0.012720227973269565, 0.034306265746376345, 0.03729624726942607, 0.03392009450388806, 0.03962288617289492, 0.039675116405955384, 0.09446910582482815, 0.11112856545618602, 0.01678022529397692, 0.030332282917307954, 0.010510393784248402, 0.024234409144680415, 0.0255433608711298, 0.034430033926452906, 0.022590334061533213, 0.04379973400916372, 0.06418393698654004, 0.03207688805248056, 0.010651460366456636, 0.05835274274327925, 0.023915528219991496, 0.07461086248180696, 0.004379807838371822, 0.05573917512914964, 0.05803679648254599, 0.01505010518511491, 0.03691676977489676, 0.08843412037406649, 0.0244287517520466, 0.04788208905873554, 0.06326788756996393, 0.07971190554755074, 0.03683623106085828, 0.01420526547423963, 0.008439661818556488, 0.03868468598063503, 0.013966450833582451, 0.055674561631998847, 0.05398011380540473, 0.03149525122717023, 0.03263583805944238, 0.048332877191049714, 0.039889397764844556, 0.058340386620589664, 0.030900009774735997, 0.005727331736125052, 0.05907690245658159, 0.0441147676402969, 0.038820009612079175, 0.017269973210724335, 0.01030945496833218, 0.044886787821139605, 0.03367186264534082, 0.05825924740305968, 0.01603870017320982, 0.07319507880934648, 0.029916802354689156, 0.027259533692683493, 0.042046005970665386, 0.014777968537860682, 0.05650296128754105, 0.019233597575553825, 0.007832159238335277, 0.011561824507745249, 0.013746728472012495, 0.09690005930938891, 0.050880009441503456, 0.019544113859800354, 0.045586679729499986, 0.02201169466466776, 0.07147181020783526, 0.002520156454660797, 0.04077256198174187, 0.03115311690739223, 0.032565507904759476, 0.022854428372478912, 0.044957827044917006, 0.056048648165805, 0.02165966560798032, 0.07360435077654463, 0.020022760943642685, 0.022527825719277774, 0.020552572960566198, 0.055399724415370395, 0.020808200850816708, 0.02673497692947941, 0.02734361605585686, 0.05207208011831556, 0.05146693544728415, 0.05552019830793142, 0.03982517442532948, 0.03121896873095206, 0.012421527528204024, 0.050459483971021006, 0.007973629548879606, 0.09011567942798138, 0.04530877214191215, 0.04368433216586709, 0.012277583109347947, 0.043124645948410034, 0.031129178191934313, 0.11424150770264012, 0.029312268365174532, 0.0254752614003207, 0.01257265339206372, 0.01731929083221725, 0.048951480604176006, 0.021824488549360206, 0.07016226476324455, 0.03599013521202973, 0.05240848081718598, 0.0576690033610378, 0.01849649311043322, 0.013630380920533623, 0.08204859694732086, 0.025213117877553617, 0.08820084682000534, 0.09534856863319874, 0.012388974810684366, 0.037759964886520586, 0.027475750572713356, 0.008538252108597329, 0.04633260006085038, 0.01210730813909322, 0.07102818401264292, 0.017502062721177936, 0.02787894625881953, 0.027898340485990047, 0.038354341206806045, 0.03948636831981795, 0.025299995805003812, 0.03802890902651208, 0.050591221544891596, 0.04355549193652613, 0.07865998627884047, 0.013917221421641963, 0.0307284116611949, 0.057192882123802385, 0.022912590697939907, 0.07752970978617668, 0.040415523640279255, 0.006071126770361194, 0.027590511200417365, 0.04042926736708198, 0.06659440549888782, 0.1416859421879053, 0.022680346820769564, 0.022198824444785714, 0.02238025453074702, 0.025821845213483487, 0.048694794199296405, 0.04482302588543721, 0.03152199229225516, 0.02340411807277373, 0.00837046736186104, 0.02852132384266172, 0.004790825336905462, 0.0635736897321684, 0.06851045268454722, 0.032393282146326134, 0.02373730081931821, 0.049131953955761025, 0.04224508475246174, 0.016146848477157097, 0.008512561076453753, 0.012644374543534858, 0.03398201421701482, 0.026545190684763447, 0.013280356086657515, 0.013258658233098686, 0.04035755300096103, 0.020393520959519913, 0.04524897285071867, 0.019247303982930522, 0.028055652044713497, 0.07784232443996839, 0.045916434177862744, 0.014963683572464755, 0.013380171132407017, 0.025716640055179596, 0.02432141429744661, 0.038608747734022994, 0.06848532653280667, 0.03085938249049442, 0.053111487201281955, 0.006055316056257912, 0.03635010143209781, 0.008644842326508036, 0.03621792620314019, 0.02715905283444694, 0.05953658279031515, 0.013229366724512406, 0.04948680741446359, 0.06980172518108572, 0.01857437196719859, 0.04007767426914402, 0.027031164250469635, 0.053481824829110076, 0.02545092404553933, 0.012195054591367287, 0.022588917619681785, 0.07733936714274542, 0.024852037163717405, 0.012922299094498158, 0.042449211834796836, 0.026465715574366704, 0.03240116672324283, 0.06853181296693427, 0.040458725964916606, 0.04520716152286955, 0.028477514229182686, 0.023986306207786714, 0.04643890953489712, 0.021834619077188627, 0.04577309026249817, 0.005946759359046284, 0.009822797778594707, 0.03503375028127006, 0.04994682701570647, 0.03208050803680505, 0.017839577913816487, 0.005300093433886234, 0.024482773317556297, 0.025895498493420224, 0.05307457150359239, 0.025193282602620975, 0.0398293304523187, 0.02205603862447398, 0.060547002857284885, 0.023230104374566247, 0.03598952792318804, 0.020664855239114592, 0.03430821653455496, 0.04617359216458031, 0.07534623159361736, 0.05013418410505567, 0.03815268738461392, 0.05199514442522611, 0.05252606415056756, 0.06306949071586132, 0.013244671081858022, 0.05591819641579475, 0.030802860523441007, 0.02340501543533589, 0.05030273559636303, 0.11262400913983583, 0.17966248866702828, 0.11461662900234972, 0.12869682775012084, 0.08897126226552896, 0.12006428811166968, 0.07495496794581413, 0.19476266125483171, 0.18119635778878415, 0.1012916329449841, 0.12267203389533929, 0.06627809961459466, 0.18077576107212476, 0.14539889938064984, 0.11732760710375649, 0.15785332822373935, 0.18364464784307138, 0.1892825953130211, 0.09917936021728174, 0.1444832028022834, 0.10830999205687217, 0.2138762463416372, 0.15286464377173356, 0.15233550859349115, 0.15654955032680715, 0.17192150333098002, 0.11859354988804885, 0.12089144944080285, 0.1505265070923737, 0.07927072207842555, 0.11773152542965752, 0.13472888192960195, 0.17140444607606956, 0.15998178401163646, 0.08438733752284731, 0.10975639801472425, 0.14135888830891677, 0.1640991209340947, 0.12100798104490552, 0.21404408876385006, 0.11101702108447041, 0.13169333338737488, 0.16161865474922316, 0.12963619162993772, 0.05056890792080334, 0.18983708055956022, 0.14052397810987063, 0.17766843709562505, 0.22107168952269213, 0.16079708454864367, 0.1571704912930727, 0.20905260874756745, 0.17705265299550124, 0.10346795259309666, 0.17369515315762588, 0.12038382382265159, 0.1870537299130644, 0.10243291527565036, 0.17802378588489123, 0.13295414644692624, 0.12835556534784182, 0.12116082784320627, 0.18444069155624934, 0.1478023925530059, 0.13012036707784447, 0.20117162806647165, 0.1307022108563355, 0.2576064169406891, 0.134650836831757, 0.11888458712824754, 0.1305530552885362, 0.11228464663560901, 0.1647081332547324, 0.08736362960189581, 0.12440343813172408, 0.18458186755222933, 0.2805764829473836, 0.06889106333255768, 0.14501810552818434, 0.08374608121812344, 0.17376867921224662, 0.13717357574829034, 0.18315289994435652, 0.2218363984887089, 0.13190385566226073, 0.14028617872723512, 0.08209523265915257, 0.14324810621993883, 0.16157392572079385, 0.1179354659148625, 0.15651314013770648, 0.1523844309683357, 0.15187242201396398, 0.1888115970151765, 0.10769250483385154, 0.1457004946257387, 0.1856432727405003, 0.13720800461513655, 0.1487396801156657, 0.10799480575535979, 0.11558705621532031, 0.1198501153183835, 0.1048170905560255, 0.10664477891155652, 0.1203787483807121, 0.10318615021450178, 0.14671825644161018, 0.08054239848362547, 0.14030377992561885, 0.07663320217813764, 0.2549809749637331, 0.08194061488445316, 0.18019059247204236, 0.23047633415886334, 0.215701926233513, 0.17384467513433524, 0.09610787646046706, 0.21032517403364182, 0.1513050581727709, 0.11437616976244108, 0.06725377190325942, 0.20318587284002984, 0.12197479845157691, 0.11166723405144044, 0.09929144063166209, 0.08652519780610289, 0.12021318583616189, 0.08983738507543292, 0.1416875571012497, 0.09270617685147695, 0.1475571021437645, 0.09870972577482462, 0.11445112074060099, 0.1265879137707608, 0.13815602660179138, 0.14970492332109384, 0.20435593862618717, 0.0848500644788146, 0.2181379348039627, 0.08168226267610278, 0.09808360080101661, 0.08807603708867516, 0.09421336597629956, 0.15409184220646108, 0.08047758481864419, 0.20870209112763405, 0.09830743593296834, 0.12250466644763947, 0.13124117122164794, 0.1132162684308631, 0.219743280804583, 0.21754060685634613, 0.1356948579528502, 0.11018773594072886, 0.09709682089409657, 0.1640597116202116, 0.10538292769342661, 0.14842964389494487, 0.0806028355977365, 0.1163838327463184, 0.1509107207613332, 0.10295669681259564, 0.12565095190490994, 0.16458282140748842, 0.11939575469919614, 0.1272059641778469, 0.10880619793065957, 0.12439653064523425, 0.16235481096165522, 0.12027630316359655, 0.11264389021588223, 0.08883023554725306, 0.22925003139036043, 0.1511940091316189, 0.13502270116337708, 0.11529065854847431], [0.081735466606915, 0.038111347638602765, 0.029107055626809597, 0.11171711994601147, 0.0328735899446266, 0.021206522959151437, 0.02161003416404128, 0.02437103895603546, 0.013249919550227267, 0.003838215605355799, 0.026708834671548436, 0.004520590284040996, 0.041134794508772235, 0.015025771223008633, 0.0236821579746902, 0.0852044497483543, 0.001738175273723235, 0.03425106013725911, 0.07802388005490814, 0.0693784278950521, 0.05621051269450358, 0.016039115775908743, 0.0820941673591733, 0.014335919936586703, 0.04638397194711225, 0.02893107078437294, 0.03746966724949224, 0.01130294134574277, 0.004841748965970639, 0.052076639873640876, 0.058234338382525105, 0.014081623671310288, 0.016213049746251533, 0.013567436619528701, 0.05309408956340381, 0.0821240907534957, 0.03982242975117905, 0.059643825250012536, 0.03702688243772302, 0.06615901671882186, 0.02406482119113207, 0.015819119455825006, 0.09284714250160114, 0.008049975764671606, 0.012656369346327015, 0.044311814209712405, 0.00878419475962541, 0.04166056076064706, 0.042634937047426186, 0.06085679480539901, 0.05133984244561621, 0.019882458561499203, 0.014161334572626012, 0.034688501485756466, 0.06014481479568141, 0.07005082217178174, 0.02953943849674293, 0.05546240408771804, 0.021614619364429797, 0.006447342207788357, 0.057845157837229114, 0.012509285006672144, 0.08980704777474914, 0.06161271674292428, 0.0023898921499494463, 0.06751158128359488, 0.03448165347799659, 0.0341097925390516, 0.02831471841117101, 0.03799943685797708, 0.07706886237221104, 0.021432824565895965, 0.03582306631973811, 0.03144286832373057, 0.0229600847565702, 0.009783102631835001, 0.02800105881345059, 0.03862695282857333, 0.06680602700050388, 0.009881139067666871, 0.025002894158075963, 0.07316247520170041, 0.036741731488811116, 0.031965455639043024, 0.013726668432354927, 0.005140384102040636, 0.023835759643199186, 0.010913182349343385, 0.015647365279229622, 0.08637271741671221, 0.03335832179124866, 0.00790926965419203, 0.03621646056749991, 0.022445580489667397, 0.002509323431045881, 0.05869217988635812, 0.03081857200179781, 0.04378317096935851, 0.05472439547468509, 0.047128989826887846, 0.024384339938738515, 0.03800721286929079, 0.04484494935188975, 0.048015129419841936, 0.019372337630816867, 0.006039505766239017, 0.029323124925472906, 0.05193633918783494, 0.013981755190928067, 0.013713145229433264, 0.02206026929031525, 0.010880772972346416, 0.08644877440695252, 0.013773462751747241, 0.054145845983709605, 0.07260736570294414, 0.054358495465878925, 0.044543052158717594, 0.003845730804771717, 0.029646891302296093, 0.004143025834179882, 0.02328207337164453, 0.030563056069825376, 0.029843897159610475, 0.04637868615931698, 0.01788362840722714, 0.019829543008069907, 0.024037516941981654, 0.004195271334278264, 0.03493091829919389, 0.04751915085528578, 0.06163850107363292, 0.01922706837233688, 0.024986700919855918, 0.018194684126813496, 0.07530889859689133, 0.03045185435829418, 0.015966164779716303, 0.05449260791231479, 0.04850675178957837, 0.013791423573690866, 0.027658251047666584, 0.006673043735125768, 0.05988197068550757, 0.056945569680205414, 0.04144373828811305, 0.016812080816764916, 0.06608059164136648, 0.040902314840682914, 0.04934930907828467, 0.04376174283346959, 0.0525219284796289, 0.0636439723894, 0.03681512862177832, 0.018507449754646847, 0.028963107815278426, 0.016537878030378903, 0.04112786327355674, 0.022232172744614736, 0.04486773455781596, 0.020948686437415223, 0.048115888477436135, 0.024348550609179904, 0.05980748111116035, 0.03990113642066717, 0.024113594288272516, 0.04950765540291156, 0.014004532763335322, 0.043996458274445364, 0.02579167245754174, 0.03332040525440659, 0.07657309076083557, 0.06802908637161766, 0.0627735001700265, 0.028745352357093776, 0.07571277621069125, 0.05627022377614464, 0.03443387782733355, 0.042888295238039324, 0.0833186177270753, 0.01965886939849172, 0.015652756239952784, 0.025750066386535764, 0.034496038420391936, 0.05012947167935116, 0.012643241390053715, 0.03777866191895945, 0.005952021398115903, 0.058376980014145374, 0.028509826066770723, 0.02843419655359217, 0.015774281861792718, 0.02261270536109805, 0.02565999934449792, 0.052485884699438295, 0.0328881988035781, 0.050243499489235025, 0.06016502156853676, 0.07258076713021312, 0.03256632893213204, 0.014642875608322876, 0.06898702854024512, 0.044708041341177056, 0.023264847063858594, 0.010516981511110706, 0.005173731129616499, 0.03437295216800911, 0.000724326166424102, 0.01686245695288692, 0.04173103001500879, 0.030031881893851926, 0.0433168918825686, 0.044566760172269175, 0.006568922536514167, 0.03198329771735838, 0.015063480806670018, 0.006142603225141231, 0.023184696811118295, 0.053331712526934485, 0.029208578036299775, 0.007657848681057138, 0.03833888078640614, 0.031700928762022934, 0.04604362556710839, 0.060245699382254055, 0.049377149370099814, 0.025757665978744626, 0.023657033519287194, 0.039838884225381274, 0.06006087322852441, 0.07779357169887849, 0.0790213333176715, 0.02378498826042882, 0.0956287696691496, 0.03465546022302338, 0.03245721371578319, 0.043593235446938446, 0.03832580880927188, 0.0488300431918885, 0.0651867099638496, 0.02058444544672966, 0.05654749693349004, 0.047401764297059605, 0.044227177144161293, 0.051895905286073685, 0.053788997632052214, 0.022932217323354313, 0.07674961843128715, 0.03277650854683348, 0.02113126833657069, 0.016222255770117044, 0.05653182277455926, 0.00985872875233846, 0.019483990568135465, 0.0362098855631692, 0.008341119874135723, 0.0166287219950131, 0.04585398860009653, 0.046594382263720036, 0.020799396858949746, 0.02640520891041628, 0.057028086323823245, 0.015560534849230732, 0.04941040097868868, 0.0768019063398242, 0.03803896152281335, 0.10044453625700303, 0.01714350446127355, 0.02900024742952415, 0.09558064118027687, 0.06282520453844752, 0.030174116404461007, 0.08392925853175776, 0.022441164923033545, 0.03762438680444445, 0.04883535272840943, 0.013819138336527561, 0.0024746208177280743, 0.011263588859167482, 0.04348320420831442, 0.026475768070667982, 0.026014520321041346, 0.053100969908492904, 0.01716713105062289, 0.0021831520716659725, 0.052588591152536016, 0.044925287898097715, 0.029539560633046285, 0.020834801119885275, 0.046750754051442654, 0.02632765914313495, 0.05383892084604927, 0.08242257152284894, 0.029637038973825316, 0.019054829043203166, 0.034744728290076764, 0.07040714126612459, 0.037891573538737636, 0.029034275960709368, 0.03869165114260145, 0.017031748047364608, 0.06897501168506485, 0.03296392670433436, 0.02021397041556026, 0.015893529302307537, 0.039590357204100916, 0.03335623190339122, 0.035964001435786486, 0.026870571974931017, 0.015511149374235953, 0.03212164422231061, 0.03116318636706897, 0.003432649711612612, 0.03530333563685417, 0.050597603166741986, 0.04127050829785211, 0.036480590501534085, 0.02550157668468143, 0.03209697608170765, 0.06304106009857995, 0.030292134000254527, 0.008509529721257942, 0.05020720125841243, 0.01361303502095065, 0.02544520908434476, 0.05343754363379308, 0.05067881702312401, 0.020673708424770405, 0.03776847032297935, 0.02039026059875531, 0.02926587692594954, 0.004928697715513408, 0.02408536383882165, 0.005070312638833586, 0.08194977510720491, 0.013498264215221363, 0.031002648374331847, 0.06384992812361036, 0.028636383025773933, 0.05605541994529111, 0.05141381972602435, 0.033776485959866216, 0.03415571239643863, 0.04781443911737629, 0.05030777711155159, 0.037214470228978565, 0.022829125801633512, 0.03674523612218244, 0.019293083044301187, 0.03502756204189999, 0.021684052156550542, 0.04411191100786839, 0.1768671822335039, 0.12078042754105159, 0.10588560679129191, 0.17343230226210185, 0.12730876223317214, 0.12964008642094477, 0.09123668713229043, 0.09757683692233902, 0.21126149807657513, 0.06943097364689622, 0.13236451308642114, 0.11109402802373682, 0.28903819460953983, 0.11848246013479573, 0.12497456105692045, 0.14239486200468882, 0.10267387663147279, 0.08491600451192685, 0.13327266435538018, 0.11949689712907587, 0.1602919152272599, 0.12595984818679945, 0.2420860683279378, 0.11568138615361281, 0.15954452247491904, 0.1129220285053764, 0.13299580849707127, 0.10264568350144795, 0.13021727544920786, 0.13861429558268615, 0.11720574221440724, 0.12197631837001868, 0.11810606318925108, 0.1186815830213683, 0.15280812180468015, 0.1290037427097559, 0.11397135577031545, 0.12623650048460278, 0.14939517208508082, 0.15934951151055948, 0.07312930840998888, 0.09200613905808755, 0.2116469738206693, 0.08030078573418514, 0.09085249381938151, 0.0972645886774574, 0.10025310795754194, 0.12336173760039465, 0.09651001702461924, 0.1322226585554225, 0.17394034857196466, 0.11907338271183626, 0.12481412823711123, 0.15172218079013483, 0.16871857377035276, 0.18132437020540237, 0.16747973167470523, 0.2083793527313641, 0.15791842687342847, 0.10798755221601043, 0.1674442035811288, 0.061484738253057, 0.15832306444644928, 0.12962296019707406, 0.12123477458953857, 0.11442663919712816, 0.12617696582206658, 0.09102797654590436, 0.12606796595667089, 0.23294082762939589, 0.1390529956136431, 0.1718325066779341, 0.09935993195644446, 0.14852543946887764, 0.15226099187774317, 0.121731272233384, 0.12690048771245138, 0.1313491261431149, 0.11126157189054148, 0.09451952097671372, 0.06894578039646149, 0.11914541598941598, 0.1359816204224314, 0.11538004875183105, 0.14986580397401536, 0.16104493982025556, 0.11570748261043004, 0.24239132766212734, 0.10031900049320289, 0.22974731613482746, 0.13680096502814973, 0.0935248089954257, 0.1273842288979462, 0.12897808051535062, 0.1226866359689406, 0.11987477328096117, 0.12493906010474477, 0.19499900857252733, 0.15572874008544854, 0.1554431446960994, 0.10107097335691963, 0.09386883982058082, 0.12714645665671143, 0.16387205597545418, 0.14263400488666125, 0.09801410524440662, 0.10384286354695048, 0.13795868147696766, 0.1224783935717174, 0.1321361589112452, 0.1792635236467634, 0.11308458513979401, 0.13593212807817118, 0.10467984327780348, 0.10641433484852314, 0.167782670419131, 0.16704626993409225, 0.12608967907726765, 0.11333754978009633, 0.0847843958597098, 0.12073979686413493, 0.0792307835072279, 0.0945964464917779, 0.07766095202948366, 0.13196871003934316, 0.14623834219362053, 0.0922969930938312, 0.19010972950075353, 0.08817689453384706, 0.14341296308806964, 0.07889729033091239, 0.30967646145394867, 0.0804238516305174, 0.16423679568937846, 0.11826664528676442, 0.10909562704286405, 0.11392239268336977, 0.11148887433643852, 0.11173584751252617, 0.18658047887895787, 0.16948324202426843, 0.08094588254711457, 0.1402345286416156, 0.10174695708389793, 0.12377290268029485, 0.09396774308489901, 0.12243787146040372, 0.12734627164900303, 0.1537545695900917, 0.1151856891810894, 0.11110339859234435, 0.06122116811041321, 0.1473769782377141, 0.12476816427494798, 0.1346987821161747, 0.06501613983086177, 0.12181602125721318, 0.112364876616214, 0.1796262820384332, 0.08730733155139855, 0.08056921418756247, 0.163853382691741, 0.14562084818524973, 0.1863992286047765, 0.1516651159950665, 0.18601308789636406, 0.08977447809385401, 0.07335568126291037, 0.14282482250460557, 0.12653331884316035, 0.08081027732363769, 0.21138765130724224, 0.12159332606409277, 0.11832953191229276, 0.1202818535800491, 0.15860552500401223], [0.0033539572489514414, 0.0415535048980798, 0.011171997657843998, 0.022921367548406124, 0.024233128409832716, 0.040553473202245574, 0.046932947489299943, 0.014526779962969678, 0.05471806813563619, 0.006500308227259666, 0.0402522409733917, 0.061446692794561386, 0.03296329566676702, 0.03684645997626441, 0.019132528088188598, 0.03029184223019651, 0.07014498926166977, 0.033411464653909206, 0.028279337898961136, 0.004926854644769004, 0.03484809970749276, 0.06559615156480245, 0.030677528320146457, 0.05492169988740768, 0.08052080749933209, 0.0389413384587637, 0.02511751907877624, 0.02766194736718067, 0.019524495716073682, 0.027888822336015955, 0.014769471583089657, 0.03403789157580052, 0.05432744909610067, 0.030457106219338517, 0.02671453606204263, 0.003212412299555061, 0.06019488389470747, 0.021527826253856932, 0.010215909586154988, 0.017415958323649, 0.013530385214835405, 0.018304007992680584, 0.02471281704492867, 0.017349334666505456, 0.06468087567814759, 0.02511533589235374, 0.037534260390592475, 0.021608624507540038, 0.01291979699661689, 0.0028865161709420916, 0.05184499480362449, 0.004310764779802412, 0.06437303791088717, 0.052720067490424426, 0.05357396309929235, 0.017287759309900657, 0.029728363001985208, 0.042213865356253724, 0.017087092756160667, 0.025956580215798955, 0.08102103030042988, 0.0392895456669586, 0.00236992201618185, 0.008427286187985113, 0.042280239651777914, 0.07951002102345228, 0.009247146480317627, 0.033613037051899095, 0.022757065382653048, 0.030437639049653496, 0.021268977018605386, 0.018936115949015533, 0.03214851420904909, 0.027902197957571064, 0.016161079052835703, 0.0045656229568911445, 0.065192036463746, 0.020686079814497913, 0.0362242467568389, 0.02484304827105786, 0.027451284296278442, 0.03598393679463437, 0.03963114394407187, 0.03212763907920037, 0.055882583505340984, 0.005616831036084997, 0.016375614862356867, 0.04002023967249053, 0.018977350522098795, 0.038265297056308815, 0.06100108527711459, 0.04332638798015458, 0.060573255377156396, 0.010037134268454142, 0.004776350488620145, 0.07588355668953486, 0.031234418973326683, 0.03493602088253413, 0.06771320117903606, 0.01111826192521091, 0.014072938423071588, 0.038870390837213824, 0.006823739153333008, 0.059832430843796046, 0.06058246988270964, 0.03101451595180801, 0.030606265179812908, 0.015689683812005178, 0.05442001484334469, 0.015588536293112805, 0.022899130259507468, 0.026247173015560423, 0.08130300909812961, 0.040240217332861254, 0.0578840243230973, 0.05082505828301821, 0.07826807123741933, 0.03054888147328581, 0.050471039422388585, 0.03603898294802223, 0.06271204525338751, 0.03071539057418704, 0.05468562737639461, 0.03971139767340251, 0.0070471798868051595, 0.044262104734246216, 0.02804907873672034, 0.016057315781446438, 0.023457515386066267, 0.02793579561901944, 0.022764651404161538, 0.09113536149795566, 0.03979202459699341, 0.06788386630692653, 0.045672656901712926, 0.061760712015841684, 0.007466457701022071, 0.02008070783423526, 0.027715799298935702, 0.05794255475380591, 0.05849516724369355, 0.04160007614908474, 0.06703386548906565, 0.06075839365699461, 0.034693621032472165, 0.04387448142681803, 0.016229353246412108, 0.035247929859906435, 0.046090230744864256, 0.01768636640294322, 0.0203013809930001, 0.012715108426553863, 0.02189930890952902, 0.040402020793408155, 0.07254084891506604, 0.009897920935015594, 0.050683936569839716, 0.02653691086119839, 0.03962521015533379, 0.01313241764104792, 0.017916058988443444, 0.0418128070554563, 0.010516168117257101, 0.020546070898749998, 0.02460230065376631, 0.0037694303900934756, 0.054902775545737574, 0.013728133219826435, 0.04385232047310897, 0.010705533670261502, 0.07275919469871692, 0.022275091780881797, 0.07102191434907061, 0.0126402736475159, 0.034240078047982285, 0.05617935097377215, 0.05782694595732859, 0.03709282586351037, 0.04941965280366795, 0.018532560639349476, 0.03910338958459241, 0.01957573019899428, 0.01715566889782037, 0.015426444455182977, 0.07276942700679813, 0.05697043120328869, 0.03732887123312269, 0.022152175162253634, 0.0810767448108111, 0.06526149809360504, 0.04734194804249065, 0.06374967457460505, 0.0244704969227314, 0.04580219941479819, 0.03972221352159977, 0.035702578856476715, 0.07816599242921386, 0.025224707255672132, 0.008321295625397136, 0.023001346471054212, 0.05074711835810116, 0.06046369232769523, 0.05909880556698356, 0.057106097494917255, 0.05367396559034075, 0.018609764353771294, 0.035971234619085274, 0.04335687455854245, 0.05768180053148951, 0.04099036154470273, 0.041140477239553414, 0.026442392629438212, 0.025132774242333004, 0.009593933853986008, 0.05679365586755531, 0.011673282366245985, 0.03487827755244715, 0.015338421499888812, 0.03183968238798635, 0.01353527490781354, 0.058399073114352565, 0.09447942634246179, 0.015412751618506653, 0.04876257645498429, 0.017088244569354823, 0.030342111497053077, 0.010301395668648183, 0.010520526856583143, 0.025444298151082227, 0.017900498484128287, 0.03359710844233632, 0.03753828749592815, 0.02493477942022894, 0.05378432931112392, 0.002501267524036978, 0.05881369872284787, 0.08198613779885427, 0.04184107482433319, 0.018873677156599503, 0.08059839119336434, 0.0885482771056039, 0.07068163582256862, 0.08710465314132826, 0.013339882267505994, 0.031009182666561434, 0.016851138988775865, 0.018690640638981546, 0.020414920257670537, 0.04349092593682664, 0.018520253710448742, 0.008720372603940112, 0.04973002829189811, 0.04853520615558539, 0.02911253140441009, 0.030561064569545642, 0.021743233980877057, 0.03353261708148888, 0.01134589854960463, 0.05617840102474604, 0.035436277610382864, 0.07440435713423149, 0.06519573447959763, 0.0319275119608002, 0.06010577189070838, 0.06683728710881301, 0.016194668232596347, 0.10710697661020926, 0.06159580086490937, 0.030798263448689665, 0.03815265345786299, 0.04508977835731847, 0.034603114639009745, 0.025459258151905875, 0.07185390684753656, 0.023973067989572883, 0.008890036044509282, 0.03420293504106147, 0.04106465434389455, 0.00832726079637983, 0.04351032864568489, 0.04385633740041937, 0.03555416289184775, 0.03325913354222264, 0.02841543166765145, 0.04092248429411224, 0.014502413770450013, 0.04511420222531472, 0.012047406219478165, 0.05236324628016778, 0.0322791864829404, 0.04663849721795746, 0.027100831137171814, 0.03584137319454125, 0.07274357482258763, 0.045149055176547596, 0.036578655775104246, 0.014476235889430557, 0.033180912025272846, 0.03875565056556037, 0.020319721794554164, 0.03632980305701494, 0.058083608613482544, 0.029782194577689682, 0.02354966553061136, 0.03804518368893436, 0.01003836580951299, 0.023806664061599543, 0.040951535770935674, 0.04498656978830695, 0.021944275425214852, 0.038051500849957974, 0.012097960471042564, 0.010539529229780393, 0.06428464515400784, 0.015377973306125827, 0.045569651893207004, 0.040102047247013876, 0.020129350313384618, 0.023306108778342605, 0.055765509073223384, 0.008716732263565063, 0.037638887097792964, 0.10178444614367825, 0.024185323921431388, 0.02142557441922171, 0.04247884685173631, 0.05711999389209917, 0.028392025602183173, 0.02449296660987394, 0.023267802083864808, 0.05356412434152194, 0.04003108944743872, 0.03202230330290539, 0.027238054666668177, 0.06977805109428507, 0.031302856015307565, 0.042245427412646155, 0.05146406524415527, 0.02421602084567504, 0.03292308907423701, 0.022431439819878767, 0.02683803452444928, 0.027513158208291446, 0.03113885410130024, 0.016706804412284067, 0.013284236458795411, 0.03964824302654181, 0.05098696691649301, 0.042720900648938756, 0.03240352802510772, 0.01809008795368884, 0.04942882659712008, 0.13944095479590551, 0.10081036162695714, 0.1958744137414864, 0.08028115571609565, 0.1116635903183903, 0.10666415108633892, 0.12926656646387918, 0.10624018883598702, 0.20698347049100058, 0.18806385142462595, 0.07698146706180913, 0.12217926819409643, 0.13898465356656484, 0.22712576894887856, 0.2850697418408734, 0.1630370236401047, 0.17394139351589338, 0.16683106576757772, 0.13731168476598604, 0.15635299230260508, 0.1357134905244623, 0.17076316262994493, 0.09359536985201494, 0.15422957124454634, 0.18084438810391085, 0.10676610775824104, 0.0640696445479989, 0.1668265060122524, 0.11897604007806097, 0.12218351582331316, 0.1035231582022139, 0.13198530700589928, 0.14481031096407346, 0.15594870756779397, 0.13097895814904145, 0.05892001158956971, 0.10995992459356785, 0.09813390060194901, 0.12558222987822124, 0.096973707500313, 0.1685559424970831, 0.14398758725396224, 0.11042798483478171, 0.08869463032377617, 0.1791612955608538, 0.2363153179841382, 0.1539637076535395, 0.07361221499741077, 0.14372286360178674, 0.091052960205291, 0.13502632454037666, 0.10460617473082882, 0.12331114602940423, 0.15247156843543053, 0.1350085333521877, 0.1193150904561792, 0.1358119730970689, 0.2522378478731428, 0.07478226721286774, 0.11782751099339553, 0.1798998809286526, 0.11603946265365396, 0.06824663148394652, 0.1612697656133345, 0.2129338290542364, 0.20902634944234574, 0.12164403977138655, 0.13555027571107658, 0.1515805705317429, 0.11009683938963072, 0.08624461679054157, 0.14412967248686723, 0.1546366922557354, 0.09631175587752036, 0.0957730058580637, 0.15298406593501568, 0.09268103712903601, 0.1289583080049072, 0.12203203966575009, 0.12211635442716734, 0.13823325745761395, 0.1759844081742423, 0.11293359074209418, 0.10517595415668828, 0.19066040138048784, 0.0913819886211838, 0.108838414773345, 0.12546625467283384, 0.12282237011407103, 0.06457642878272704, 0.2927413673273155, 0.16103919941399777, 0.11952599271067552, 0.17350937026951993, 0.12004341637449605, 0.2050665004977158, 0.16420551522501878, 0.16699029079505376, 0.13486521318554878, 0.059906174029622755, 0.08728046156466007, 0.1263035126030445, 0.12712876046342508, 0.1557207740843296, 0.13997906020709447, 0.14020278677344322, 0.0947481601365975, 0.08726533701909439, 0.20518189216298716, 0.07927466436688389, 0.1235706585326365, 0.11586255500359194, 0.2243644164076873, 0.12529660734747136, 0.18417094674493584, 0.11138032230415515, 0.15903338204537118, 0.31448046224457876, 0.09557407296129636, 0.10897765694452183, 0.15176102013460227, 0.10967653444302933, 0.12580035174531595, 0.11850839374320847, 0.10313431013907705, 0.1170040951775653, 0.060202300282461305, 0.0908731280692986, 0.12140222346144063, 0.06929416063108615, 0.1271163025604827, 0.1341609074068921, 0.1534436241324459, 0.10869250260293484, 0.10170582429106746, 0.16455069955970558, 0.08389969476099525, 0.12557981429355486, 0.0830607812053391, 0.13634296746126243, 0.10822242711271558, 0.1981250194034406, 0.09836446680128574, 0.12134727569563047, 0.11911762319505215, 0.14793204702436924, 0.17682112327643804, 0.16984654324395315, 0.14093850872346333, 0.1398854088038206, 0.1398234042738165, 0.15320672041603497, 0.1586233704750027, 0.11596478308950152, 0.12152963876724243, 0.11171676710780178, 0.17641917270209106, 0.12664717701928957, 0.23916790634393692, 0.10227683186531067, 0.12601400885198796, 0.10257849496390138, 0.11284724716097116, 0.12875485606491566, 0.09864160085895232, 0.093438112576093, 0.10878205565469605, 0.11479635935808931, 0.07978238497993775, 0.10395569713520152, 0.13519525261861937, 0.11159774528018065, 0.15101828213248933, 0.09220930601337127, 0.1709786924932684, 0.11328336875885725], [0.008836832961865833, 0.020750488054805567, 0.06309302231030804, 0.03828659966321928, 0.00311663983822135, 0.046545388642698526, 0.036553339633558474, 0.023893294323767935, 0.014846563339233398, 0.02127569112261491, 0.07676198133932692, 0.03715868107974529, 0.0038035318637931986, 0.04147879819252661, 0.023889173919867192, 0.04279478293444429, 0.08009162731468678, 0.03725124682698931, 0.021099066760923182, 0.032829580163317065, 0.014698505301826766, 0.07124570876892124, 0.02875648033139961, 0.026420111235763346, 0.008393068515163447, 0.016244594839268496, 0.03353864586512957, 0.02133011811279825, 0.04083336889743805, 0.024094534239598682, 0.05249817975397621, 0.04958320349188788, 0.013878070799234723, 0.054726682137697935, 0.02864814203764711, 0.022494764100494127, 0.036615300058786354, 0.022705824114382267, 0.030800431368074248, 0.049371843226253986, 0.04760024257536445, 0.021293736761435866, 0.02103900962642261, 0.08460097427346877, 0.05035238739635263, 0.031464995350688696, 0.0972540442432676, 0.03460965910926461, 0.02814794298527496, 0.029932032073182718, 0.036926957978201766, 0.08801359829625913, 0.03494342030691249, 0.027513991110026836, 0.04381724699799504, 0.02328491134436003, 0.014408468900780593, 0.006272631314849215, 0.11120627807187182, 0.03569157301847424, 0.10403317226363079, 0.04615625559485384, 0.008224606929746057, 0.04030865098216704, 0.039761867108089585, 0.07036844441401106, 0.05621634470298886, 0.045411780543093166, 0.0087196007703564, 0.03454868595248886, 0.04344755397843463, 0.00958073974054839, 0.027091156924143434, 0.06263010536453553, 0.055283250486744304, 0.05785287956574133, 0.017662643122353723, 0.028235460431980233, 0.028185866307467222, 0.025105237594938705, 0.028553466046495096, 0.07026528673512594, 0.033849703281053474, 0.03175758643608008, 0.08042598901582615, 0.047006242842014344, 0.03853463813928621, 0.09829037077724934, 0.01713316358758935, 0.05004397287432637, 0.03489548859319516, 0.02730597093302224, 0.020329131378925273, 0.02605685920986746, 0.07232286954032523, 0.05993802446339812, 0.06785780377686024, 0.02208697982132435, 0.059800648263522556, 0.04455524204032762, 0.02493269631772169, 0.11050634205873523, 0.02172469810050513, 0.01856361549081547, 0.02265107142738998, 0.025654937473258803, 0.049863621659044705, 0.03750483232683369, 0.031615759046482186, 0.029922390090567724, 0.03633267665281892, 0.027354189327784946, 0.02112902408199651, 0.03498691440160785, 0.028305743089211837, 0.1101614630648068, 0.016373136513201252, 0.10329791850277356, 0.05355028561981661, 0.06949842002774988, 0.02943244030965226, 0.031120747394327606, 0.04244391247630119, 0.053981667650597434, 0.03001541384894933, 0.053388960526457856, 0.04766404861584306, 0.055418282348130427, 0.03912753864590611, 0.03035757191745298, 0.013718761803050126, 0.032147275882640054, 0.01860207655201001, 0.06754527733262096, 0.020013980700501373, 0.005111064603884837, 0.017024947430140207, 0.037070329034967084, 0.03674824542499014, 0.01862330621640597, 0.022422249063051174, 0.0047779492867578354, 0.02441035836402859, 0.06086877094847815, 0.04201041680893727, 0.027924935666045973, 0.033783610577562025, 0.008433848469784217, 0.09205470180937222, 0.061265551085983, 0.0523222729430667, 0.01423292510610606, 0.04196025950035878, 0.0374633602664939, 0.08513936466936554, 0.010387656977400184, 0.027404947139854943, 0.01228241088600563, 0.052442170080861876, 0.04221262024449451, 0.031150524903620993, 0.05080118063571198, 0.03492188360542059, 0.027677431536306227, 0.03388717198478324, 0.027023612155712078, 0.04203377537695425, 0.006986616395546922, 0.01885867305099964, 0.025105376694617525, 0.07490414567291737, 0.04340682152126517, 0.039459759569061656, 0.08153153969241039, 0.0232343452184328, 0.042153703048825264, 0.03473523558516588, 0.010204956334616457, 0.040810970456472466, 0.024988977404843484, 0.01814349544500666, 0.016705710274566497, 0.019084916982267584, 0.005196587157635284, 0.07245263257729155, 0.005067486116396529, 0.10847055379833494, 0.032940235654158254, 0.014289648937327521, 0.008268429265756692, 0.07577598853302853, 0.030336008074560335, 0.08235950847821576, 0.012870405584440699, 0.016320202300058942, 0.050117600709199905, 0.007427329131002937, 0.02742252458951303, 0.011113298441549497, 0.08724890968629292, 0.05484800759170737, 0.04173836497856038, 0.028526355179825, 0.0063344127764659265, 0.04203995004562395, 0.033104207034089735, 0.032326792499848774, 0.06496811990759202, 0.002971681221554588, 0.011389121230292534, 0.050256612178470404, 0.05998335060264383, 0.03111582462276731, 0.007030152050512177, 0.051301942872149606, 0.07415805570781231, 0.06565501447767019, 0.020420504600874016, 0.021544826948749166, 0.14503421394952706, 0.017597434210724065, 0.03802731107654316, 0.014988821598568132, 0.03830789887745466, 0.01434251360063042, 0.06838201279086725, 0.0509569994173944, 0.09205641171761922, 0.0556896454654634, 0.04506962586726461, 0.015978408944127814, 0.01944896798314793, 0.0051987037628090805, 0.03601438944627132, 0.03612422390973993, 0.04413655200707061, 0.07213782625538961, 0.01659136524956141, 0.020726707098739486, 0.02241679364150124, 0.050905522358204634, 0.004879236329413418, 0.04061081958934665, 0.01587920882073896, 0.037684630536075146, 0.00847661229116576, 0.0215431034698018, 0.08451181477201836, 0.0682260583021811, 0.02995174690814955, 0.055978966012064896, 0.03630151493208749, 0.026925541793129275, 0.06584540461855275, 0.0768368916053857, 0.0432314439676702, 0.038839039126677175, 0.0953320666615452, 0.015855151361652782, 0.0031748784988719437, 0.057526327802666595, 0.08349278409566198, 0.023810733575373888, 0.05349157877000315, 0.038446496440363784, 0.08432411162980966, 0.03968962009197899, 0.014079288662677365, 0.028842637315392494, 0.036518062597938945, 0.054639408963599374, 0.08847570778535944, 0.01873850280285946, 0.020489442062431147, 0.04696478435237493, 0.012406421642351364, 0.022534236178866456, 0.027750823580260788, 0.04885215664814625, 0.028961445404482738, 0.039602625117238076, 0.040272189902939966, 0.028891461302659342, 0.04078985105401703, 0.07448876689055137, 0.014432460202702453, 0.023247820923903158, 0.021858922505219067, 0.1317689764712538, 0.03388024753491793, 0.02179592052873756, 0.05317610748378294, 0.07928139543426888, 0.025813171839607612, 0.03325335581653884, 0.05836241186729499, 0.025037268742120693, 0.02280610310845077, 0.06879921683243342, 0.01688756444491446, 0.03484356709356819, 0.022544929890760353, 0.013244090086248304, 0.027161817864647934, 0.05336021099771772, 0.01559109945914575, 0.019922556588426232, 0.020994979489062513, 0.013938239892013371, 0.0446201608782368, 0.019619112335411564, 0.07903070388627903, 0.02299269854224154, 0.06199668613927705, 0.02445002382488123, 0.07306053888584886, 0.03160011202895215, 0.03728035937196442, 0.02020107994654349, 0.04312828289610999, 0.03418644664010831, 0.0032402407170073794, 0.043408718026642285, 0.053286104795656035, 0.10334683409226791, 0.014941408964140075, 0.018779506674036384, 0.042792065401694605, 0.05714371547635112, 0.03143754521650927, 0.03740415808611682, 0.01068975349023406, 0.02220574550197593, 0.016125052236020565, 0.07498732049550329, 0.03392549224996141, 0.018316598209951605, 0.04735760523804596, 0.03417994627462966, 0.04645803065172263, 0.0638718515900629, 0.06294381924505744, 0.03199334003563438, 0.06540751882961818, 0.010237115501825298, 0.051434650751096864, 0.015204402352018016, 0.03491980389558843, 0.09072394536009856, 0.04330502091241734, 0.0242993534276528, 0.006486244316745017, 0.09234873138900314, 0.08096774494541542, 0.14110702968069486, 0.20152449341756956, 0.13813928035753115, 0.1369773434208972, 0.16904245210545404, 0.15043139005345957, 0.1201550896678652, 0.11852747414793287, 0.42196233623794144, 0.20560457876750401, 0.14458578372640268, 0.10225247924349137, 0.14819003960915975, 0.09339575842022896, 0.24263991575155938, 0.1456385308078357, 0.08085820903735501, 0.19442437083593436, 0.08404097932257823, 0.09725405102861778, 0.134987295206104, 0.10919676268739359, 0.12412215822509357, 0.2467876374721527, 0.11206634834940944, 0.08301954663225583, 0.17102252585547312, 0.10087710911674158, 0.15775819761412485, 0.1088076364248991, 0.1615871571536575, 0.152432362682053, 0.12313501190926347, 0.20595714556319372, 0.09392131771892309, 0.12329661180930478, 0.12076905529413905, 0.145523017006261, 0.14394184042300495, 0.14440599908786161, 0.08348160862390484, 0.25710310680525644, 0.1439142104770456, 0.1586476077458688, 0.15549157852573053, 0.1057930410440479, 0.07509462402335235, 0.1983964198401996, 0.12286378789160933, 0.21451788262597152, 0.10033004704330649, 0.135469950735569, 0.15954350467239106, 0.09558831541133778, 0.08487305324524641, 0.11900286935269833, 0.289990450654711, 0.1539247054606676, 0.29696443357637947, 0.16116381915552275, 0.10378558840602636, 0.15907281850065502, 0.1986443701067141, 0.1521131390971797, 0.17840352122272762, 0.07763009225683552, 0.1361742972263268, 0.10004224641514675, 0.08277802887771811, 0.12663276493549347, 0.17832654821021215, 0.1581702312188489, 0.14225618301757745, 0.14571460815412657, 0.09979328513145447, 0.12902302667498589, 0.2106345860021455, 0.17735552388642514, 0.10806735471955367, 0.2513037494250706, 0.10422664295349802, 0.11831206642091274, 0.15364423979605946, 0.18433963055057184, 0.07889809778758458, 0.17463429990623677, 0.13946995538260254, 0.17850839559520992, 0.15075786039233208, 0.11606011725962162, 0.1489259922610862, 0.14637067009295734, 0.1700490452349186, 0.14175846401069844, 0.21842169814876147, 0.11496437819940702, 0.10755244163530213, 0.13898709629263195, 0.13956543883042677, 0.3139507978090218, 0.15911411414188997, 0.18709273210593633, 0.08674840868583747, 0.17297332760478767, 0.12499894760549068, 0.07665710696684462, 0.08759570893432413, 0.1075403094291687, 0.0897903490279402, 0.15270137467554637, 0.14645797040845665, 0.15652607301516192, 0.111454689742199, 0.22377153964979307, 0.17420139456433908, 0.18444709692682537, 0.17941890816603387, 0.1515955932970558, 0.12610262552542345, 0.15563233382999897, 0.23532905376383237, 0.08194459788501263, 0.09627694024571351, 0.18430497098181928, 0.06845411392194883, 0.16737142391502857, 0.15845077830765927, 0.15363160547401222, 0.07891956663557462, 0.07971179019659758, 0.122390034741589, 0.13760878810925142, 0.10868501836167914, 0.11245746950485877, 0.12835395043449743, 0.18859294589076722, 0.12554804528398172, 0.12051077772464071, 0.07952937962753431, 0.10948404762893915, 0.052680050887699635, 0.14639707867588314, 0.2259503970188754, 0.09940422672246184, 0.1838085547621761, 0.12475356220134667, 0.19761814017380985, 0.2523957836840834, 0.10952545183577708, 0.08711612038314342, 0.13992494025400706, 0.18402857652732305, 0.18999717411186012, 0.08171798075948443, 0.09235503497932639, 0.10806343278714589, 0.17506788378315313, 0.09512765120182719, 0.0804213478362986, 0.10032013364668403, 0.0853312611579895, 0.17524143947022303, 0.1154321330998625, 0.13972539667572292, 0.1264894583395549, 0.1732142889606101, 0.1193115756447826, 0.08579064293631486, 0.10123070050030947, 0.046700304972806146, 0.14762600058955805, 0.20014514029026031, 0.10040838391120945, 0.11240481518741165], [0.018374987844643847, 0.03523501055315137, 0.0347111747334046, 0.007885171483004732, 0.047392539613481076, 0.01904996225078191, 0.033621098047920635, 0.035332899407616684, 0.040511665267071555, 0.04545292690662401, 0.07965671350913388, 0.019588744500651956, 0.0776229812098401, 0.03562301384019, 0.027034227836078832, 0.0334419410542718, 0.06740794184484653, 0.017283995136884705, 0.04325987797762666, 0.042989559804222414, 0.020693674317694137, 0.07662096140640122, 0.024669056625238488, 0.030398545254554068, 0.015987730318946496, 0.0154461881278881, 0.040584865624883344, 0.03597125836781093, 0.05811331487659897, 0.0024713967161785278, 0.04163646598213485, 0.04095915571919509, 0.03472768688308341, 0.08505011017301253, 0.02069269722726728, 0.041165138594806194, 0.019615424497585212, 0.04586874334407704, 0.021128101274371147, 0.03226995501401169, 0.014764508099428244, 0.059488250740936825, 0.022649578650348952, 0.06287889022912298, 0.050829811420823844, 0.014143245677197618, 0.046541212259658744, 0.009795721686844314, 0.03389043573822294, 0.044665178284049034, 0.009673400482695018, 0.05272220826840826, 0.04637597541191748, 0.04755418701097369, 0.005077323601913771, 0.020120319012286406, 0.008937640365080109, 0.009276670387147792, 0.0380196572015328, 0.037750706276191134, 0.045895633686866076, 0.03553247691265174, 0.046053935906716754, 0.01077871282385396, 0.027742536971345544, 0.07362828270665236, 0.021627307969278524, 0.02636616600544325, 0.03764318222446101, 0.034980556528483114, 0.0023691338553492513, 0.05308457650244236, 0.029811341049415723, 0.02502022563878979, 0.029131581275058643, 0.05788421431290252, 0.03258628464703049, 0.060254343918391635, 0.0883181451686791, 0.01530956510188324, 0.02595928417784827, 0.010222458297253718, 0.11917759212000029, 0.024408102235091583, 0.062166632020047734, 0.010686393045554203, 0.03298243713964309, 0.016017275429995995, 0.019733681276972805, 0.021332357278359786, 0.05023559116359268, 0.05738728240664516, 0.06752430381519453, 0.0418589915415006, 0.021881278537745987, 0.06513313283877713, 0.037232688894229274, 0.007415980632816042, 0.06620815622487239, 0.04643988323264888, 0.024546501326507757, 0.05889621536646571, 0.10059271473437548, 0.001304239300744874, 0.04712095597226705, 0.009188333609407502, 0.03631967252918652, 0.005466659362095275, 0.04498104651325515, 0.03090088169223496, 0.048941244903419695, 0.009371204734114664, 0.022415117660005177, 0.021243187598884106, 0.04024497725601707, 0.013646297655733568, 0.023085179472608224, 0.026938206649252346, 0.07435251705880676, 0.07412376933332, 0.07583073952368327, 0.015626157667221766, 0.02714633708819747, 0.057980193091290336, 0.04658783779346517, 0.016442175755011182, 0.05724804023546832, 0.05945546392883573, 0.025113836329962527, 0.017498307029849718, 0.028332792887730256, 0.05612407072580286, 0.04815927061385342, 0.013839176323797022, 0.0476038829157395, 0.01859914867340454, 0.012871080726784254, 0.015374702767335942, 0.05997968651354313, 0.024712910343493735, 0.04216761301670756, 0.05363763343276722, 0.012102552456781268, 0.015620973659679294, 0.041442774768386564, 0.02522471234468477, 0.027583172844190682, 0.05772161018103361, 0.04638808047665017, 0.006867827814338463, 0.029382690122084956, 0.045488889262612374, 0.04977701005658933, 0.008157525261464928, 0.035871662997773716, 0.02461129633177604, 0.01702598898139383, 0.018043218147275702, 0.011378594607646977, 0.014034354377404919, 0.05872375212077584, 0.02430191998636084, 0.03292241393189345, 0.0046981247308264884, 0.06612884905189276, 0.05038961861282587, 0.016193043141226684, 0.022529883376721824, 0.011901607703683632, 0.028712640183844736, 0.004793304110145462, 0.054405399199043, 0.03710788255557418, 0.03477428527548909, 0.06250749408666577, 0.03185099017407213, 0.018641497740255933, 0.028989038031016077, 0.018232129081817608, 0.03906950354576111, 0.03636245076943721, 0.05176898870351059, 0.01558517075942031, 0.033590530045330524, 0.006742411218250969, 0.08674532135150262, 0.07917422761342355, 0.05537236588341849, 0.05807541191045727, 0.017316664901695082, 0.012692363084559994, 0.017557989273752485, 0.08063364108758313, 0.014603015068652374, 0.07634899778557674, 0.02337471884675324, 0.009662550707746829, 0.055692875292152166, 0.019040299912116358, 0.035806374358279366, 0.044634196375097544, 0.0395907168276608, 0.07034164228077446, 0.040515292036746225, 0.024532491274710213, 0.02700365474447608, 0.034195386338979006, 0.04199813871777483, 0.012861777163509811, 0.020606250169553926, 0.04081977105566433, 0.038969002331474, 0.027712262435150996, 0.02421879435756377, 0.023391230996432047, 0.019867975231526152, 0.02613412738511605, 0.023204072378575802, 0.019703359243326952, 0.042787481897643635, 0.061029475182294846, 0.028579657498214926, 0.04155114698889, 0.008196290815249085, 0.07180595477776867, 0.10383655995662723, 0.05816101588840995, 0.05859250309211867, 0.01395172662367778, 0.017213595432362387, 0.1119168670848012, 0.015525040682405233, 0.017668088365878378, 0.006404409600820924, 0.029883191122540405, 0.05121633889419692, 0.04484231663601739, 0.01592334752370204, 0.06426440445440156, 0.04120344868195908, 0.02647311839142016, 0.006582891452126205, 0.0630812429423843, 0.026926462904417088, 0.010189644343751882, 0.0217215751430818, 0.021065815152334313, 0.026020474465829984, 0.01727263137165989, 0.04012973147577473, 0.020717847127733485, 0.05108614498749375, 0.04208071982221944, 0.1293687131255865, 0.05413913866505027, 0.002860983958401318, 0.03607865349788751, 0.04404279203819377, 0.050100311636924744, 0.02191585159328367, 0.04188496586201446, 0.024489400908350945, 0.048241190146654844, 0.026586199644953012, 0.07292685391647474, 0.0715454923255103, 0.007546617283618876, 0.08790078506405864, 0.08223250029342515, 0.02086560152071927, 0.028804205091936246, 0.03715577355719038, 0.08465364894696645, 0.03876741636278374, 0.07817741895892791, 0.002028145199541801, 0.1152532576982464, 0.038933847432157824, 0.046367191776101074, 0.042824987920799425, 0.057265994272061756, 0.011936970404349267, 0.0349775031208992, 0.02233533381617495, 0.019917189376428723, 0.05751127789595297, 0.04401237331330776, 0.04104886144133551, 0.04184013505333236, 0.018421601504087448, 0.01676223733063255, 0.00606135671426143, 0.008345196173260254, 0.03592762178076165, 0.07766783237457275, 0.08241780142166785, 0.05320515217525618, 0.04689647623204759, 0.03483985211434109, 0.053920473969940624, 0.04637515777722001, 0.07753604051790067, 0.03231114887499383, 0.04919145129887121, 0.035756478285683055, 0.03540382328044091, 0.017353848620717014, 0.040816653187253644, 0.02283606891121183, 0.024560669137697135, 0.012539537490478583, 0.03751925119597997, 0.039098141116223166, 0.03147633367085031, 0.031468360884381194, 0.05857922416180372, 0.02065229555591941, 0.011121021866399263, 0.03960020953257169, 0.046799303232026954, 0.059303431372557364, 0.03637940396687814, 0.004418790523361946, 0.04112111524279628, 0.025570683779993227, 0.01526313803956977, 0.04255246450858457, 0.020123989886737297, 0.023314777063205838, 0.03291146916204265, 0.056802290225667615, 0.053180049772241285, 0.01487363688647747, 0.022040500172546933, 0.034523254459989924, 0.017074390580611568, 0.05996075538652284, 0.007804962706619075, 0.025196951780734316, 0.019430939307702438, 0.058702215419283936, 0.04605002754500934, 0.008634934867066997, 0.030525746821824993, 0.027981082742501582, 0.04044458868780306, 0.04156558621408684, 0.028650985099375248, 0.06486382907522575, 0.030311529923762594, 0.01347617111501417, 0.01562845959727253, 0.05788801410900695, 0.109323472316776, 0.11469596331673008, 0.06513827613421849, 0.12981179649276392, 0.0886891477608255, 0.15775126298623426, 0.10876861387597662, 0.11716536938079766, 0.13994898753506796, 0.19385730555014952, 0.13135207098509583, 0.17773778337453092, 0.1080448952104364, 0.13426013636801923, 0.1495883102927889, 0.17807904577680997, 0.07054432069084474, 0.1309963557869196, 0.09894812226827655, 0.0656461256689259, 0.15671516715415887, 0.06206855656845229, 0.1302037997437375, 0.12267934850284032, 0.10184524288134915, 0.12068322061428002, 0.14051207660564355, 0.1306051667779684, 0.10437577137989656, 0.09188360241906983, 0.141925967165402, 0.1587888380246503, 0.16260168914284023, 0.11199358903935977, 0.16184677822249277, 0.07180016008870942, 0.12012015868510519, 0.11865373594420296, 0.09120009373873472, 0.0634441641824586, 0.0854896040899413, 0.08122822096837418, 0.1553873284054654, 0.17037110509616987, 0.11502858118287154, 0.1456979161926678, 0.13516188226640224, 0.13484780197697027, 0.2083932626992464, 0.19536401970045908, 0.10581053367682866, 0.13860404970390455, 0.0838575034535357, 0.1549762718911682, 0.07602903459753309, 0.14268078309084686, 0.14643848288272107, 0.12692644846226486, 0.10172288944678647, 0.10556626107011523, 0.09095622146768229, 0.12819074919181211, 0.07762107452643768, 0.0983179532257574, 0.16562828102282115, 0.15979639467384132, 0.11954273895493575, 0.12429052990462099, 0.11547825991043023, 0.14472672902047634, 0.17481745007847035, 0.10310117048876626, 0.08337502434317555, 0.09685765087072339, 0.09381056044782911, 0.1050908047971981, 0.2407264741403716, 0.16959768374051365, 0.1183630922543151, 0.0897105804511479, 0.19165442804140703, 0.2840352202100413, 0.11923218704760075, 0.18248789491397993, 0.11457799321838788, 0.17852164059877396, 0.08756503236613103, 0.11281676058258329, 0.1694157820727144, 0.08674796085272517, 0.19769617170095444, 0.21393408466662678, 0.11662996453898293, 0.06453179474920034, 0.22442213259637356, 0.13251537856246742, 0.10253979811178786, 0.17139079395149434, 0.1294600846511977, 0.16824737191200256, 0.14617451918976648, 0.17059090973011085, 0.1472075344728572, 0.13814378583005496, 0.11140515668583767, 0.17171098105609417, 0.08927413994180304, 0.08559426811656781, 0.17318946814962796, 0.1177598067692348, 0.0933659707329103, 0.14324551421616757, 0.06797716487199068, 0.18814100085624627, 0.14754809119871684, 0.058960696549287865, 0.16238420509866305, 0.1334782333246299, 0.16405235630060944, 0.09844578922327075, 0.1594843499894653, 0.11349495633372239, 0.15422444151980536, 0.17043267536376203, 0.211763505424772, 0.1570737457701138, 0.14781558327376842, 0.09432355327797787, 0.11885085036712033, 0.10829620422529322, 0.10454464517533779, 0.14565689196544035, 0.08327412618590252, 0.09975363154496465, 0.13147621575210774, 0.07263088372669049, 0.15546052876327718, 0.1339899165821927, 0.10861995363874094, 0.1448553656893117, 0.11817412025162152, 0.11693302541971207, 0.13952754943498544, 0.1346240754106215, 0.1483664180019072, 0.09851611937795367, 0.10899487137794495, 0.19147739825504168, 0.10752538165875844, 0.10006458378796067, 0.06330209930560418, 0.10510573935295854, 0.09867864208562033, 0.1831133413527693, 0.0932325232507927, 0.12412347458302975, 0.12586146060909542, 0.0927374233890857, 0.04693096616704549, 0.1717676387301513, 0.10202972976756947, 0.10799648852220603, 0.11022307404450007, 0.16753113748771803, 0.15359269827604294, 0.1132330893139754, 0.09524678838040147, 0.08962102739938668, 0.07988348669771637, 0.10965502488293818, 0.12490634114614554, 0.15834370548171656, 0.13365443529827253, 0.12013664708605834, 0.09829203997339521], [0.06412618008575269, 0.03710240338529859, 0.06050819743956838, 0.054976372846535275, 0.058790173913751326, 0.07811168248632125, 0.062073170606579096, 0.017155841924250126, 0.06054744390504701, 0.012274508497544696, 0.016407214238175323, 0.04208133728908641, 0.047540236330990276, 0.055098105421555896, 0.01426850917882153, 0.053904409653374126, 0.024513317571420754, 0.036105167253741195, 0.0346227175156985, 0.09835064504295588, 0.035415039464299164, 0.06277183775923081, 0.0417185246146151, 0.014824298908933997, 0.040947644372603724, 0.06219950704170125, 0.05038733534248812, 0.03792381413014872, 0.008665276408594633, 0.017393176510397877, 0.014131200832447835, 0.04590248689055443, 0.08057751945619072, 0.03119303851521441, 0.05286790330761245, 0.04397989184196506, 0.0338715283599283, 0.03558194211551121, 0.016835415636056235, 0.06763490502323423, 0.020800641970708966, 0.040095926861145666, 0.03620792120429022, 0.022799539978482893, 0.03727011349318283, 0.033239198183374744, 0.037315117328294685, 0.027559456348951374, 0.0491582709364593, 0.04768429949347462, 0.02831201275278415, 0.030787159223109484, 0.040912570897489786, 0.025284367447186793, 0.018302235319944363, 0.024361030564510396, 0.029122716215040003, 0.046853501216641495, 0.04358725416074906, 0.0853153495118022, 0.001838211585501475, 0.008357472568085151, 0.013330900160196637, 0.0226525675971061, 0.010986665995525462, 0.0704659227547901, 0.05501547681965998, 0.042243459661092074, 0.041621158232114146, 0.06385303581399576, 0.07158316458974566, 0.04543171590194106, 0.10482606078897204, 0.015619662390755755, 0.0190049601120076, 0.03894068027979561, 0.061011683994105885, 0.0020164873317948407, 0.06458440835454635, 0.07528991318706955, 0.036087450704404285, 0.04596149568845119, 0.01815445378555783, 0.023484665268499936, 0.044734134405319176, 0.02996908687055111, 0.03734930192253419, 0.03006358304992318, 0.013400031852402856, 0.06745370903185435, 0.04509883001446724, 0.08004722398306642, 0.028504238330892155, 0.052436015768242736, 0.04851810368044036, 0.054751564016831775, 0.03577035093413932, 0.04282967659777828, 0.01355644520039537, 0.028596746402659586, 0.017431221968893493, 0.04779618652537465, 0.05742909373449428, 0.028431999796469296, 0.08718369568565063, 0.024738769313054423, 0.014275755932820695, 0.06021805586559432, 0.028916190511413982, 0.030901926636163677, 0.03777233797258564, 0.019399239847968732, 0.02366972212413592, 0.026823831090171422, 0.037332182484013696, 0.014873418058933956, 0.030307109268116098, 0.032892680527376275, 0.07812122947403363, 0.04304161022550293, 0.07225890404411725, 0.00938733690418303, 0.07914672658911773, 0.0357011810743383, 0.011276559056048947, 0.040330313212637386, 0.018317602441779206, 0.002533533560511257, 0.013516197047595466, 0.01012776788723256, 0.047508582672370334, 0.03563422663137317, 0.015938158246821592, 0.021128472772293856, 0.05349793325045279, 0.018358882815976228, 0.08132135668503386, 0.08552023994603328, 0.04085720583264317, 0.04090651497244835, 0.016247244518516318, 0.018622585272948657, 0.0704951404726931, 0.05219978380150028, 0.040406041113393645, 0.014163188669564468, 0.01889004511758685, 0.03355163981073669, 0.03490377011309777, 0.06439715304544993, 0.01917686526264463, 0.04216644593647548, 0.04276853719992297, 0.04824815530862127, 0.030108773482165167, 0.01199860598093697, 0.046764134762010405, 0.013627697314534868, 0.04029627789610198, 0.02860664962125676, 0.02629960172011384, 0.03790170067389097, 0.04506204663110631, 0.05185436197955694, 0.031199993499155556, 0.03568023130563753, 0.020394073965560113, 0.02050828667623656, 0.05377930136663573, 0.033182258917284865, 0.09837813249656133, 0.0394920680139746, 0.03158735217792647, 0.06683358230761119, 0.03580050842304315, 0.058830451752458296, 0.035792376180844646, 0.029623580231730427, 0.0335556499526969, 0.030541363305279186, 0.06760034723473446, 0.018869207307164158, 0.07265455781349114, 0.03843580951382007, 0.020555780734866858, 0.027609718830457756, 0.009787102595769932, 0.0204166216842298, 0.03570330149627157, 0.05088431474619678, 0.05323201198396938, 0.055059225364987335, 0.06979617476463318, 0.017457240394183567, 0.031103974008666616, 0.0873209090371217, 0.032783354965171645, 0.007687669446957963, 0.04468464545373406, 0.07620642400745835, 0.08696413532431636, 0.0368249741648989, 0.03851080459675618, 0.04824636058349695, 0.022891947966335074, 0.018285310960241725, 0.024526671140587757, 0.04380209191835352, 0.032781913078257015, 0.026918305217155387, 0.03188519851703729, 0.08118037746420928, 0.004183708249391722, 0.0404094778932631, 0.04417133031945143, 0.08284276111849717, 0.03191419571105923, 0.031114474338080202, 0.031642472970166376, 0.0344686934591404, 0.016562379929902296, 0.03255445456930569, 0.02917643922514149, 0.013242878053071243, 0.049356705109987936, 0.01982596203950899, 0.05351616209372878, 0.036859172329838784, 0.03213000716641545, 0.01685949514753052, 0.020692970337612287, 0.017225132224016955, 0.032870882589902194, 0.023581431147509387, 0.04043449887207576, 0.009834231941827705, 0.0431699992290565, 0.018274020137531415, 0.09622331562318973, 0.013996514175752444, 0.05443172296509147, 0.10804142789649111, 0.0725378022928323, 0.03254533845133015, 0.05290587751993111, 0.009252995452178376, 0.04426481548164572, 0.026731881113456826, 0.03723130468279123, 0.06769729631819896, 0.03230867900752595, 0.020505708243165697, 0.010610910265573432, 0.012785901681386998, 0.039064031160835705, 0.031616790419710536, 0.02706640227032559, 0.05779301920639617, 7.393903329752252e-05, 0.03885502201904144, 0.0557740857558591, 0.06250613701662847, 0.10910159136567797, 0.03100838538791452, 0.07456334467445101, 0.07912934930729014, 0.03869008711938347, 0.08982349546360117, 0.06180499321115868, 0.024972780773948346, 0.008700574648433497, 0.015641967533156276, 0.004559355837825153, 0.008828598939414536, 0.010677365137131085, 0.00640245754038915, 0.004356223233376763, 0.0030369442039435463, 0.04964306385123304, 0.04827708464914134, 0.06871341607932534, 0.02712097853821303, 0.046384725120982954, 0.019910816236266067, 0.04005200189671346, 0.06281317411256687, 0.058194691581385474, 0.03296771292973842, 0.08685113210231066, 0.013708057913130947, 0.002545830311386713, 0.04459444100835493, 0.007041641768799829, 0.012100833218677767, 0.041767633586589775, 0.01859355584851333, 0.08601985885096447, 0.10704455817384378, 0.034967861138284206, 0.0373981462658516, 0.06865812904600586, 0.03888510486909321, 0.09583593319569315, 0.08570152414696557, 0.06884078388767582, 0.022999577190993086, 0.06990403469119753, 0.017981983754517775, 0.026501051981800368, 0.06836824531533889, 0.02047876701025026, 0.01896786460253809, 0.04969580298555749, 0.02710894980866994, 0.03765618634809341, 0.05383448661970241, 0.009687132335134914, 0.04322655512286084, 0.07238587151680674, 0.04518078686669469, 0.0524479783406215, 0.04176390164398721, 0.03745235103581633, 0.010684135220279651, 0.020167670578562787, 0.06950404508305447, 0.0541413303331605, 0.06200517461236034, 0.02883680530690721, 0.03173462820372411, 0.02222538230541561, 0.021799944241398146, 0.05172245477193168, 0.029842272068240812, 0.060524502636066506, 0.05601672648585268, 0.03275277339188116, 0.03804045429985438, 0.029578613716044595, 0.03515745400051985, 0.014662707490580422, 0.04378030415890472, 0.0378314485507352, 0.02345318633264729, 0.055810841997819285, 0.027768728423065374, 0.06142217732433762, 0.04612565027283771, 0.038256896792777946, 0.010517739773994046, 0.0496858556621841, 0.056001696935189624, 0.14458989564861568, 0.11422265799982206, 0.09365837182849646, 0.13568225077220372, 0.11359691979097468, 0.1296695212700537, 0.12537092050271376, 0.1410713115973132, 0.10748779081872531, 0.1407219474869115, 0.12643605763358728, 0.1267335952392646, 0.13056915013917855, 0.20631016019199575, 0.08388507233134337, 0.1735329832881689, 0.11025349276938609, 0.1222031254853521, 0.09325664517070566, 0.20553116127848625, 0.14711700433066913, 0.11114430746861867, 0.23803790126528057, 0.2168092546718461, 0.125576326623559, 0.12214901910296508, 0.1334243305027485, 0.17849994104887756, 0.10239235245223556, 0.10679432124431644, 0.08577815110662154, 0.08076315985194274, 0.14657714829913207, 0.06601581190313612, 0.11721372178622655, 0.19007684769374983, 0.14918679398085388, 0.14021216412740095, 0.239609849772283, 0.18517049668090685, 0.08468828815966845, 0.13210816255637578, 0.0947843056970409, 0.1890751671578203, 0.1411242237580674, 0.09766592178493738, 0.11919025358344827, 0.0888410581808005, 0.17477824432509287, 0.18656750528940133, 0.1264059713908604, 0.12988122419587203, 0.13605760277381965, 0.15425174576895578, 0.08421501676951136, 0.1399518238114459, 0.1508225654917104, 0.18194665467100485, 0.1619186079395669, 0.1750042371984039, 0.1256885834570442, 0.15673892945051193, 0.15825978427061013, 0.09064763052655117, 0.1337754452334983, 0.25248722306319643, 0.15830524611685956, 0.10606009885668755, 0.10944402084818908, 0.09888543920325381, 0.1525402633207185, 0.1590796717043434, 0.26758384012750214, 0.16537027486733027, 0.12793468364647456, 0.16601257611598286, 0.12392291320221764, 0.07929806703967707, 0.17026142669575556, 0.0966859475842544, 0.07204730968390193, 0.15174275397190026, 0.186198070113148, 0.14210877807012626, 0.11132426852626459, 0.1274607947894505, 0.1594328356108495, 0.17790348162608488, 0.1273878522749458, 0.22896710942898477, 0.2151711761419262, 0.134153226390481, 0.17622528810586247, 0.1426873920219285, 0.08115433529019356, 0.19186573741691454, 0.07777344635022537, 0.10705232739980731, 0.13795737868973187, 0.08000750254307475, 0.16441698744893074, 0.1193698210907834, 0.17657583286719664, 0.18081225268542767, 0.17925984598696232, 0.17182971111365727, 0.09227360399173838, 0.18353593296238355, 0.14288627063589437, 0.12382455276591436, 0.12866889924875327, 0.0892547881230712, 0.24286947771906853, 0.08631038718989917, 0.14908843354455062, 0.11583483006272997, 0.14939160299088272, 0.07668247739119188, 0.17266114721340792, 0.11807312709944588, 0.189214768952557, 0.17213536399815763, 0.11098578133221183, 0.14574800564774446, 0.12054165106798921, 0.13336661431406224, 0.14191198934401783, 0.13191554003528186, 0.1746936717203685, 0.1482974924147129, 0.19610769408089773, 0.1035669304962669, 0.08189372132931437, 0.15849763793604715, 0.08726803758846861, 0.06990543247333594, 0.11935306127582278, 0.14026557840406895, 0.10375147845063891, 0.15353073445813997, 0.16963820585182735, 0.14191591127642564, 0.1537238455244473, 0.2252230889030865, 0.16324730164238385, 0.09253944044134446, 0.106276246186878, 0.10874856316617557, 0.13176121403064045, 0.2141538214470659, 0.13830003887414932, 0.1977188754826784, 0.08737753278442792, 0.2079659891980035, 0.10718603272523199, 0.06486077566764184, 0.16289888748100825, 0.1209068386150258, 0.10783699886607272, 0.15519121821437562, 0.10254323149898223, 0.15147968594517025, 0.09630939457565546, 0.11105358733662538, 0.15387890434690885, 0.12584111812923635, 0.11029694615198032, 0.13442504751895154, 0.1342922310744013, 0.10590662102081946, 0.20466802402266435, 0.1434085118983473, 0.0971214585006237, 0.1327266472258738, 0.09234415127762727, 0.1529035238283021], [0.05377008346840739, 0.04070126152198229, 0.006657035821782691, 0.022477486902581792, 0.03767512086778879, 0.020972638723573515, 0.05976933387241193, 0.037712877948901484, 0.030286793929657767, 0.00808314255638314, 0.017550939294908727, 0.02564178576825985, 0.05389914422162941, 0.030657504751746143, 0.0684185451162713, 0.03875660390726157, 0.05585536068039281, 0.02556034460264657, 0.01032369741837361, 0.022153220106182352, 0.04285236680880189, 0.04831825476139784, 0.04327174216242773, 0.012067203326816005, 0.025808471288265925, 0.009466701752639242, 0.02747585065662861, 0.028976152651011944, 0.01065626778706376, 0.030597674926476817, 0.05032244025330458, 0.039075600182903666, 0.021454647948433245, 0.05622391036844679, 0.011512752007027822, 0.03517069221873369, 0.020389275026640723, 0.03641871489318354, 0.045292911385851245, 0.009781994923417057, 0.08553738652595452, 0.033889417935694964, 0.06195602832095964, 0.04805397215698447, 0.09322799063686814, 0.009973552992700465, 0.027809006261772344, 0.06519083545676299, 0.0281644415642534, 0.021217172566269125, 0.06524287909269333, 0.07265983003058604, 0.03979262510048492, 0.02984011432688151, 0.02072572661563754, 0.03000168369284698, 0.030101414769887924, 0.04563586673300181, 0.02850700675376824, 0.023705565736496022, 0.03370342470173325, 0.025827005472300307, 0.10203521911587034, 0.008487485814839602, 0.02352478025880243, 0.07869858813605138, 0.034484734026981254, 0.05323260909478579, 0.039884359642331085, 0.028823865644101585, 0.011864636026855026, 0.05563646528337683, 0.040697054604866674, 0.09285413819764342, 0.07407215317445141, 0.02487235589485083, 0.03115891498912658, 0.013890623697079718, 0.026214879837685397, 0.04077275536422219, 0.036102582035320144, 0.04208562223772917, 0.01386000310802566, 0.031023133346544843, 0.02483806443134589, 0.037631687841245105, 0.027003756524728875, 0.04211893830714481, 0.023501703282818198, 0.05080456652545503, 0.03543903924790876, 0.17442997944142136, 0.06696311464267117, 0.040488690071340115, 0.055259196420333216, 0.018742733468700732, 0.018282951354714375, 0.030055532231926918, 0.03528903551133616, 0.03151059629661696, 0.05679505364969373, 0.06231656111776829, 0.013818890671245754, 0.019106246730578796, 0.01983882367078747, 0.051164176514638324, 0.005224850685668311, 0.027101124603567377, 0.06402098001646143, 0.0059169084831540075, 0.02615961485675403, 0.012083934304038329, 0.04500387243128248, 0.07526163184749228, 0.0891563326918653, 0.04230821565059679, 0.04114841270659651, 0.00828197197656014, 0.02781679923646152, 0.04543414844998291, 0.041360817916159115, 0.021990481963647262, 0.060440764629415104, 0.04258686284135495, 0.01337136120335864, 0.00501713584942211, 0.05079037157286491, 0.02107340795919299, 0.010385067518135267, 0.04371252868856702, 0.026565546735322902, 0.0114612418692559, 0.0247431238115366, 0.04689584858715534, 0.04774492999006595, 0.019632165652832816, 0.03844754816964269, 0.023042723536491394, 0.03132067434489727, 0.054219219367951155, 0.023424720092277442, 0.04108685940237982, 0.06508746064667191, 0.0200159755934562, 0.04415189029116716, 0.025705546007624695, 0.029495995292173963, 0.05468886059575847, 0.041743928965713294, 0.0165227670555136, 0.0361282578004258, 0.050313263067177365, 0.031190368479916027, 0.02675254420111222, 0.01316035632044077, 0.04615767373304282, 0.10885675557489906, 0.052228227989482026, 0.028309921168589165, 0.06492147062505994, 0.04504507647028991, 0.026561806311032603, 0.04326275496610573, 0.05059992375650576, 0.047719603670494895, 0.06814971632723298, 0.03405558437641178, 0.046429773060871024, 0.017135278920509985, 0.0397191838627415, 0.028698146675846407, 0.029457780199923685, 0.10828529338219336, 0.06685515293585402, 0.020894352745796953, 0.02619052891220365, 0.08069238864949771, 0.03894733331565346, 0.038163448950009685, 0.019367231654801538, 0.007640406938402781, 0.018143090020333017, 0.09090392677379505, 0.01539797312580049, 0.03481837308832577, 0.029488585689770322, 0.0484708912138428, 0.024155420883159553, 0.03902965318411589, 0.006744737745196159, 0.03447454921635134, 0.014873998206374901, 0.03022987162694335, 0.011659581047881926, 0.03936312939705593, 0.015903868479654193, 0.013622851726332945, 0.07090691623411008, 0.07266358911458935, 0.04929774380954249, 0.026023193694917218, 0.043103526545954604, 0.012863879773898848, 0.003978607045220477, 0.03623464530599969, 0.01685477763281337, 0.06386894746018307, 0.011661827846962427, 0.02690707885527185, 0.07722561074686901, 0.061519818513521125, 0.023295082584289566, 0.020972586137109568, 0.023906079619856815, 0.04769656401393669, 0.010567921679466963, 0.05208063983757581, 0.011217223713174462, 0.046212892912860425, 0.004012174596677401, 0.014515714753153068, 0.03882892895489931, 0.012849431218845504, 0.009987270426271217, 0.016816143545189073, 0.02836363060799028, 0.00035800814293907024, 0.06369927299341985, 0.00802341366319784, 0.042721775959112814, 0.059820101862507205, 0.040250822835202725, 0.028861853427120616, 0.013087083020114472, 0.02269417536444962, 0.07142737973481417, 0.07872828761381762, 0.011212432407774031, 0.017931755199762325, 0.009414206890921508, 0.005806523134067122, 0.032931709861648936, 0.08192746487579175, 0.07321041370076792, 0.07933108455368451, 0.008390149966414486, 0.022793787697862302, 0.03517416971070426, 0.040578002243169715, 0.08112855095948492, 0.0492987412560199, 0.03087567750896726, 0.020051135581785014, 0.08730189648589917, 0.01848098010356937, 0.060286723609481535, 0.012668326829693146, 0.02975870030266898, 0.0446998344601265, 0.036723791022918055, 0.0802577869700534, 0.10757662462336676, 0.041440834158233235, 0.029814784614635364, 0.0659855967387557, 0.0423185022414795, 0.034586806049836535, 0.051543138322553465, 0.027359020497117723, 0.046546803388212404, 0.027311953915549175, 0.05213967238419822, 0.012318032278147126, 0.06168354901352099, 0.07228056966726269, 0.06726240965404681, 0.027465128106996417, 0.035595122658248456, 0.04569158463605812, 0.08003286618207182, 0.02290062982189868, 0.03624588863125869, 0.037657577344881635, 0.02654020005970129, 0.023363450076431036, 0.013896163935506982, 0.021171203515093242, 0.024453194279755865, 0.028138451976701617, 0.013224308245948382, 0.0074216854159853286, 0.03828172438911029, 0.03501260034473879, 0.03406242061672466, 0.03426655448440995, 0.03895872252594147, 0.025134309427812696, 0.010359887931761997, 0.038925165576594215, 0.029917830335242406, 0.04849066372428622, 0.05403446785307356, 0.03226626039083515, 0.020635328787778105, 0.04129196357514177, 0.026197982619383504, 0.01998591309945498, 0.01883944676124624, 0.017951890726440718, 0.01608576505844082, 0.04536210499437792, 0.019065001979470253, 0.041572157825742445, 0.03325764076518161, 0.07283699552395514, 0.01751816096449537, 0.03217198134266904, 0.0716106520433511, 0.040682632343045304, 0.013444808378283466, 0.09977386545922075, 0.02550196514597961, 0.01929868265454258, 0.013484837703539856, 0.07041062215077025, 0.04659190561090197, 0.050253996425973516, 0.06289666784661156, 0.03398781569142427, 0.052528669725039175, 0.03650581504085234, 0.04795573724965964, 0.07159089310360806, 0.0028705303099871215, 0.09753115115953342, 0.017701236497876898, 0.04806557510580335, 0.02454793982074729, 0.006104926720062005, 0.013183390039817562, 0.035267050976731946, 0.03649824259004422, 0.06553360420678343, 0.05880236718803644, 0.03634872739868505, 0.00933935260400176, 0.062327818013727665, 0.015806990642366663, 0.058358869914497645, 0.016327084341485585, 0.04464544648570674, 0.011070094420574605, 0.2438765593937465, 0.07660167065582105, 0.08496704391602959, 0.11963582038879395, 0.0662279287353158, 0.1095074706577829, 0.20357801179800714, 0.08336157577910594, 0.08338883931615523, 0.11776340300483362, 0.12445336473839623, 0.09706535722528185, 0.16460709939045565, 0.1624992032136236, 0.14197938144207, 0.0973930082150868, 0.08102924057415553, 0.12431164591440133, 0.19657498757754052, 0.09851848746516875, 0.08371184912643262, 0.15723993256688118, 0.18627325179321425, 0.1228088808379003, 0.10258382824914795, 0.09869183280638286, 0.07294626680335828, 0.1346160415560007, 0.16329015791416168, 0.12326573846595627, 0.11725474601345402, 0.10562044887670449, 0.09018912405839988, 0.16519202371793135, 0.16456156969070435, 0.13744224847427436, 0.06800332918230977, 0.10985347601984229, 0.175993894093803, 0.08385675706501518, 0.17361557457063878, 0.11637729166873864, 0.13706696432616028, 0.10825321903186184, 0.19664886647037097, 0.12240926442401749, 0.1751735723976578, 0.11642476197864328, 0.0928492731015597, 0.11806866233902318, 0.11403640013720308, 0.18749648758343287, 0.19150371184306486, 0.17392706285629952, 0.18345973347978933, 0.12736518920532294, 0.06968471860246998, 0.14084122037248953, 0.08832668792456388, 0.11025617298270975, 0.10847433323838881, 0.11781681728150163, 0.18077563893582138, 0.11785504594445229, 0.11629152484238148, 0.1767611000686884, 0.20696064457297325, 0.15466592354433878, 0.20838445531470434, 0.14795609430543014, 0.09874295363468782, 0.18189885866429123, 0.11114436853677034, 0.14790527203253337, 0.13123520011348383, 0.2074486469583852, 0.11999752026583467, 0.1545251410986696, 0.12103533957685743, 0.2111040779522487, 0.09036440322441713, 0.12124880669372422, 0.1309772346700941, 0.11026959440537862, 0.10612327046692371, 0.21368856355547905, 0.22186698684734957, 0.13521776641053812, 0.1492959295532533, 0.16452038261507237, 0.15156858760331357, 0.21476284733840398, 0.18518641511244432, 0.15526174514421395, 0.17869640407817705, 0.15390915343804018, 0.08907990929271493, 0.19935311350439275, 0.16766432034117834, 0.1013998728511589, 0.1383842314992632, 0.10658579386238541, 0.1308187696018389, 0.14304031165582792, 0.1356073133647442, 0.20819726107375963, 0.13676612904029234, 0.1285662233297314, 0.2889612487384251, 0.09740772563964128, 0.0967518129785146, 0.13003655443234102, 0.10109800619206258, 0.1834229433110782, 0.14051730132528714, 0.12397214770317078, 0.08370203072471277, 0.09397872178150074, 0.13664571621588298, 0.15883629476385458, 0.18593337360237325, 0.1240681739790099, 0.13988297964845384, 0.0901799299088972, 0.1750957037189177, 0.18003968628389494, 0.10890748285289321, 0.11560141401631491, 0.15880848839879036, 0.08719571932618107, 0.21700669479157242, 0.14522765071264335, 0.06851062231830188, 0.14333206814314636, 0.08301468153617211, 0.0755907077608364, 0.14811056958777563, 0.09184204214917761, 0.13147736926163944, 0.155165433883667, 0.10882247598575694, 0.134235858385052, 0.13925333986324923, 0.12022928068680422, 0.290483365633658, 0.06157822680792638, 0.12857709346073015, 0.1633678637444973, 0.22075493580528668, 0.17613268164651735, 0.08930947804557425, 0.1499889445091997, 0.0906545990811927, 0.11530896542327744, 0.07360614889434405, 0.1424466342266117, 0.22440622773553642, 0.0994730708854539, 0.22546444380921976, 0.14474574157169887, 0.17184914435659135, 0.12123261684817926, 0.06943087186664343, 0.11817194893956184, 0.08242759946733713, 0.19603875492300304, 0.1346404959580728, 0.13852068489151342, 0.08376822860113212, 0.11324382373797041, 0.1492747999727726, 0.14992476866713592, 0.19570319221488067, 0.16285366990736552, 0.16994696642671311, 0.15120744412498816], [0.012255180427538497, 0.029888398878808533, 0.019876319515917982, 0.015713179783363427, 0.023630996434284107, 0.023987200177673782, 0.034316070577395816, 0.04515280408252563, 0.07069040928035975, 0.04877064084368093, 0.02487017779744097, 0.0408178813356374, 0.03512145432510546, 0.007223880583686488, 0.07199337293526956, 0.038537789934447834, 0.037760171839701276, 0.041083422622510364, 0.016871452630896653, 0.01341445411422423, 0.0198415683449379, 0.026759936840140393, 0.0052253328696159375, 0.031515332471047125, 0.062244344635733535, 0.054525089383657487, 0.019297939658697163, 0.03697856056636997, 0.03431663376146129, 0.022079858596303632, 0.030561118852347136, 0.028492842335253954, 0.008130025933496654, 0.03584605508616992, 0.039739451703748534, 0.013990136794745922, 0.019708785827138593, 0.03563880335007395, 0.009775855029667062, 0.10140853095799685, 0.01597946067340672, 0.04970689703311239, 0.04234570810305221, 0.03888145435069289, 0.009510724256480379, 0.03600083910194891, 0.02085858886130154, 0.034139973776681085, 0.03574788124699678, 0.024643932169835483, 0.025172073294275572, 0.036618465424648354, 0.036318434202777486, 0.05824945614274059, 0.016558395233005285, 0.02677360762442861, 0.11500533457313265, 0.027699617935078483, 0.04209157298984272, 0.03958498999210341, 0.04689103098852294, 0.029352274789874042, 0.0828982177855713, 0.01588032840351973, 0.025183111362691437, 0.03421679411881736, 0.03912783380863922, 0.04899336317820208, 0.0544131311055805, 0.04664790849866612, 0.03803117533347436, 0.05986360274255276, 0.03169247082301548, 0.05682954697736672, 0.03737798699044755, 0.01237542022551809, 0.02178579000090914, 0.01606424871299948, 0.05279663338192871, 0.05829812745962824, 0.016464562321613942, 0.1163231852863516, 0.032395901291498115, 0.03446013034720506, 0.07102516453180995, 0.03660736459174326, 0.058962019692574225, 0.042992012708314827, 0.08700156331594501, 0.0696361151390842, 0.053320021368563175, 0.06527375243604183, 0.04057002267135041, 0.05050429781632764, 0.014433635764622262, 0.03052887486826096, 0.025789864161717038, 0.065800695946174, 0.044691030468259535, 0.030340194635625397, 0.052615902187036614, 0.030500651204160283, 0.037600295418607335, 0.02852673515943544, 0.028002799255773425, 0.02488101739436388, 0.052592089000557146, 0.057230316900781224, 0.06863213436944143, 0.032022740957992415, 0.10985654978347675, 0.07648555974342994, 0.03385185084438749, 0.05819344986230135, 0.046953785299722633, 0.031989869329013994, 0.007401330213594649, 0.0334506771926369, 0.04400744714907237, 0.022272140153550675, 0.038548039205904515, 0.01899042589190815, 0.004070933184786034, 0.0396625567227602, 0.024947537574917078, 0.01832044211083225, 0.0642902362825615, 0.035955129590417655, 0.02835046872496605, 0.009615013392509093, 0.027131685820807303, 0.05860077443399599, 0.010672059841454029, 0.045806545431592634, 0.037435011073414765, 0.010259144989374493, 0.0443851604525532, 0.04989833211792367, 0.01019644835365138, 0.004032437772756177, 0.06117676477879286, 0.0064694098629323495, 0.015175260969304612, 0.06825676201177494, 0.08388832251408271, 0.0176716913868274, 0.031660376116633415, 0.010881404858082533, 0.0623096264898777, 0.058147255198231766, 0.03385170156668339, 0.05085870683459299, 0.050381713679858615, 0.04312277997710875, 0.043376728493188105, 0.0718858183494636, 0.03655631161694016, 0.027148128420646702, 0.04794440571484821, 0.016222140419163873, 0.031607898218291144, 0.019485266213970523, 0.03580629632675222, 0.019791975916762437, 0.011907978299339967, 0.10225982777774334, 0.05632412999070116, 0.0184386938012072, 0.036794708110392094, 0.04088373655187232, 0.08261779283306428, 0.016800640716350505, 0.01510703596951706, 0.036362881639174054, 0.05627337217863117, 0.029126604220696857, 0.0058733567129820585, 0.04537318886390754, 0.029982786492577622, 0.014735997754282184, 0.00457361906800153, 0.04181701736524701, 0.04717648388551814, 0.08126514684408903, 0.018996203617591943, 0.021693263269428695, 0.021262412192299962, 0.04667204398927944, 0.03893161505194647, 0.0675190994516015, 0.014773284949894463, 0.03482489041717989, 0.008482127932698598, 0.08059517493737595, 0.02846451349822538, 0.006985317849154983, 0.019373514889074222, 0.0023277796904689497, 0.08680585346051625, 0.04867644321971706, 0.05130911159462162, 0.041193369044257064, 0.030237478004502397, 0.024572592694312334, 0.0404109842410045, 0.020652122529489652, 0.020300926374537603, 0.054537757632455656, 0.08696159081799643, 0.06471551489084959, 0.04068277822807431, 0.017531020899436305, 0.032408508472144604, 0.02871115758482899, 0.019833037463415946, 0.04340571890185986, 0.022764101790796434, 0.059007610460477214, 0.03576512960717082, 0.041357655942972214, 0.04255205738757338, 0.025109218899160624, 0.0491682148671576, 0.02263396555956985, 0.06765782593616418, 0.04844665055030158, 0.013059528561175933, 0.01339658913535199, 0.06279013784868376, 0.03165632865524717, 0.03407533313812954, 0.03826831992981689, 0.023219307186082006, 0.020524858197729503, 0.05623268382623792, 0.0525320691854826, 0.03572044129084263, 0.004310117202943989, 0.06673832277634315, 0.036196199511843066, 0.0141238260049639, 0.05921136774122715, 0.03573340130969882, 0.0441206437535584, 0.029173409566283226, 0.059932867597256384, 0.025328589270689657, 0.07489265807505165, 0.06636018878115074, 0.06194507676575865, 0.012641088737707053, 0.017287786451301405, 0.1155389209410974, 0.10518098210117646, 0.028564410816345896, 0.0821283044559615, 0.017051966694582785, 0.035880371994738064, 0.023178985242598822, 0.031781542114913464, 0.08541147756789412, 0.013101774999605758, 0.037212227670741935, 0.04235337554876294, 0.024176757416820953, 0.012379829006801759, 0.0739960011893085, 0.03447367390617728, 0.01818541024944612, 0.015050164556929042, 0.03696065741990294, 0.04753227372254644, 0.035026021767407656, 0.021562711435503194, 0.07972536768232073, 0.04355924084250416, 0.015029608338539089, 0.07756093596773488, 0.04159801000995295, 0.044055721522974114, 0.0483921709736543, 0.02234063996002078, 0.025639102162261094, 0.04683890253571527, 0.06641442408519131, 0.02649978142497795, 0.06219595830355372, 0.03930724525292005, 0.04136078059673309, 0.032261357975325415, 0.030751129013619254, 0.02540903807883816, 0.02030507561617664, 0.056681826511131864, 0.005728486941994301, 0.010786454908416739, 0.05964291601308754, 0.01978099382748561, 0.0515156610469733, 0.052286273267652304, 0.017095045186579227, 0.046863937085228305, 0.05788372576768909, 0.04969095146017415, 0.028551264200359583, 0.02150415047071874, 0.004795900354760566, 0.05026840511709452, 0.04262503722150411, 0.055212723556905985, 0.019616306593109454, 0.025656547297590544, 0.0257895062344947, 0.04569023435137101, 0.004358312273065427, 0.016282584318625073, 0.03306114720180631, 0.024217381308387433, 0.062066269905439446, 0.048838562199047635, 0.01070984491213624, 0.014367504045367241, 0.03950217140040227, 0.03701688761689833, 0.05850736730332885, 0.04331559927335807, 0.019285332478050674, 0.035806106336946995, 0.02756896771357528, 0.033891534964953146, 0.053323274943977594, 0.05930077151528426, 0.02848741744777986, 0.06960281942571912, 0.015767847653478384, 0.027096804031836133, 0.009326830240232604, 0.02037732602496232, 0.015293663633721215, 0.08739360049366951, 0.048826423207564015, 0.05588926028992448, 0.07330526611102478, 0.03905618051066995, 0.06002623401582241, 0.04171455179208091, 0.03855519775035126, 0.033014640411628146, 0.020807529101148248, 0.0398336968251637, 0.050472555948155265, 0.03998020610639027, 0.10769853022481714, 0.12934911703424795, 0.1686262387250151, 0.08233603116657053, 0.11097599685724292, 0.1436726384397064, 0.13055179321340152, 0.17498898373118468, 0.1405276014868702, 0.16226803990347044, 0.08601042721420527, 0.12718621880880424, 0.16549937293997832, 0.18026087512927397, 0.2039669616413968, 0.11457320276115622, 0.14210871021662438, 0.11861218245966093, 0.14093593029039247, 0.06609606902514185, 0.05666290556213685, 0.08197534909205777, 0.14531518173004898, 0.10491796835724797, 0.17555656470358372, 0.1450384072959423, 0.13814445079437324, 0.07518820078777415, 0.11589804238506726, 0.10644151017602001, 0.06994188337453774, 0.151347086631826, 0.17057930678129196, 0.12313011288642883, 0.12176500899451119, 0.06715513326759849, 0.09483128746173211, 0.09272871778479644, 0.12521613309425966, 0.21072997445506708, 0.13175923270838602, 0.1844192227082593, 0.0752877283043095, 0.0990044813869255, 0.14103663845786027, 0.08834651471780879, 0.16119642954851898, 0.13405937142670155, 0.12905090089355195, 0.12795373690979822, 0.15948014307234967, 0.16793787851929665, 0.14762107442532266, 0.11466594492750508, 0.153564756203975, 0.10838132644338266, 0.1756868434271642, 0.09660109678017241, 0.15904516141329492, 0.11397572553583554, 0.18704748739089283, 0.11408829449542932, 0.22844596739326203, 0.19192918044115814, 0.10674731912357466, 0.11115192741687809, 0.09453752251075846, 0.1987835919218404, 0.10113723908684083, 0.15027688762971333, 0.07348058598914317, 0.18584711823080266, 0.16353021003305912, 0.1968899771038975, 0.14605976534741266, 0.08247971095676933, 0.2482221419257777, 0.1814758735043662, 0.14267076791397162, 0.20339666652892316, 0.059459643704550605, 0.19444753602147102, 0.13883167106126035, 0.16275391168892384, 0.18196171814841883, 0.15951857529580593, 0.1560747522328581, 0.19166612598512853, 0.1530472104038511, 0.1531945067856993, 0.16489546320268086, 0.16905926620321615, 0.11632170608001095, 0.13844885517443928, 0.1679358971970422, 0.14833726813750608, 0.12153480920408453, 0.3385433496109077, 0.20856839258755955, 0.09145605071846928, 0.13434548250266484, 0.20826267184955732, 0.15851085579821042, 0.18355383271617548, 0.10908137102212224, 0.09999585497592177, 0.17697368509003095, 0.13278778323105403, 0.1278446013373988, 0.12262152374855109, 0.17367489210196904, 0.13969384479735578, 0.1256529875099659, 0.13776147205914768, 0.2418258637189865, 0.09732685783611876, 0.16812972751046928, 0.15853431953915528, 0.1274654766810792, 0.1474489708031927, 0.23314265108534268, 0.11984482274523803, 0.08673103818936007, 0.12099403036492211, 0.11451775287943226, 0.22612958454660007, 0.1502102690615824, 0.10584229590105158, 0.08343055564910173, 0.08210277118320976, 0.07748971693217754, 0.3791801876255444, 0.11230887712112494, 0.20811115497989313, 0.14166369980999402, 0.13992951358003275, 0.10949226468801498, 0.1849308923951217, 0.1406700259872845, 0.09007429557719401, 0.12293943097548825, 0.12383538218481199, 0.12329054570623807, 0.1549363061785698, 0.1875820101371833, 0.06865543526198183, 0.15844824058668955, 0.11666595403637205, 0.1910110411367246, 0.12429001421800681, 0.12625425096069062, 0.0977417209318706, 0.12305558259998049, 0.1308245507201978, 0.09138055012694427, 0.29079880299312727, 0.1057494655251503, 0.09389807789453439, 0.12582632606582983, 0.08961400456194367, 0.08528385870158672, 0.1183660506669964, 0.13841620406934194, 0.19303580320307187, 0.11265359326664891, 0.16472082185958112, 0.17875070045036928, 0.09685434640518256, 0.1057015677381839, 0.11485328844615392, 0.14963059659515107, 0.10502069177372114, 0.07394592530493226, 0.07906689694417374, 0.14421239947634085, 0.09415913745760918], [0.008181971181849284, 0.017434599376948814, 0.04469870809199555, 0.05497433045612914, 0.01683671842329204, 0.006827515200711787, 0.017078526251550232, 0.014527987755302871, 0.027826149449018494, 0.04414918293644275, 0.0376679894647428, 0.010949548433667846, 0.08693038499248879, 0.010551284000809704, 0.03434928486655865, 0.0516447319782206, 0.05712156809334244, 0.028807092258440595, 0.026744172775319645, 0.035492402634450367, 0.08347531860428196, 0.002341182029340416, 0.04333600282136883, 0.04626464477873274, 0.03749323955604008, 0.05101690388151577, 0.027883444945993166, 0.018762254921187247, 0.044812138791063, 0.016943206012781178, 0.034108771343848536, 0.01704230096324214, 0.02291109283188624, 0.053675573718334944, 0.021361407058845674, 0.024939284892752767, 0.06214985863438674, 0.024567707242178063, 0.03161159962681787, 0.04140398970672062, 0.05826816335320473, 0.04079977123598967, 0.03588644488315497, 0.037504740724606175, 0.01656133328963603, 0.023087415245494673, 0.040006248280406, 0.015596073120832443, 0.014575478421258075, 0.048966669610568454, 0.06893232504704169, 0.04580359041158642, 0.01341034219201122, 0.032904541319502253, 0.03276537039450236, 0.0533095142537994, 0.07606766359614474, 0.04569335900513189, 0.017138451071722165, 0.03226453012653759, 0.01926896451706333, 0.07076918719602482, 0.032009757190410576, 0.0385709906529103, 0.02387866680510342, 0.10769126311476741, 0.04554177428196583, 0.07105024997144938, 0.09712945842849356, 0.036989284812339714, 0.036827074230781624, 0.021959384703742604, 0.08196068595030478, 0.08107616805604526, 0.03216334359188165, 0.01547212852165103, 0.028806064277887344, 0.10023410897701979, 0.023026302989040102, 0.04998363075511796, 0.07530461704092366, 0.0717819482088089, 0.04965472108285342, 0.02341878291086427, 0.033798032839383395, 0.02938056630747659, 0.013051918790941792, 0.09040725949619498, 0.12782454384224756, 0.045359214435198476, 0.05928977246263197, 0.03805396732475076, 0.04231462441384792, 0.10725187097809144, 0.07847669361425297, 0.058073389876101694, 0.02009691294681813, 0.0783386253086584, 0.07910714764147997, 0.02117757495891835, 0.08189188928476401, 0.0019479527504050306, 0.08459586490477834, 0.06274825866733279, 0.02818605290459735, 0.08317567075469665, 0.032646263750003915, 0.02821239872303392, 0.0278033031749406, 0.022746924676799347, 0.06991766645972218, 0.05275019783792751, 0.05026942291962249, 0.06643997771399361, 0.043428904443447075, 0.024993209767022302, 0.019897047064400146, 0.020403213832261305, 0.08787280906523977, 0.011150707773465132, 0.07407264850501503, 0.03995646755876286, 0.009130361273751726, 0.03214656342087047, 0.061784942501357625, 0.0449047147163323, 0.03617707500234246, 0.0343630693054625, 0.07230569581900324, 0.0404958791498627, 0.062158496385174136, 0.03135601244866848, 0.05990143106984241, 0.014325987880251237, 0.018720302797321762, 0.0520564466714859, 0.09129812169287886, 0.047775464065905125, 0.04828379875315087, 0.013480968357596015, 0.07095065460141216, 0.02411626771624599, 0.09006796484547001, 0.028234412095376422, 0.049873518092291694, 0.01924916825789426, 0.013918321496540946, 0.05479820312133857, 0.06296990891652447, 0.034440021961927414, 0.018105497483962348, 0.02741058576585991, 0.024358172235744338, 0.04924180538260511, 0.08578562856252704, 0.011136747763625212, 0.05006494639175279, 0.07306552611823593, 0.04478183202445507, 0.02202089729585818, 0.032224968142275295, 0.03271524701267481, 0.03398769355512091, 0.041654267348349094, 0.027861005792926465, 0.0536617417819798, 0.0157509470425014, 0.03136734398347991, 0.09130775689014367, 0.01471520574497325, 0.01614898755880339, 0.02433696462373648, 0.09210804144718818, 0.08447558100202254, 0.050482822182987414, 0.030441954532372098, 0.017863821970032792, 0.03158078735162105, 0.030037015011268, 0.025899169367871115, 0.021961243889693702, 0.041778035528425655, 0.050171418714204004, 0.006502925676094102, 0.044205779542348216, 0.023793120502627323, 0.025431121001020074, 0.033892223677997074, 0.11951409120644842, 0.04155696203399982, 0.031420541128941944, 0.01602603870976184, 0.07100535130926541, 0.03991918545216322, 0.057870324701070786, 0.007105098363743829, 0.024083609825798442, 0.055431076125907044, 0.07168784218707255, 0.07205409503408841, 0.08205027292881693, 0.05079008319548198, 0.008291352723192955, 0.02064632614409285, 0.026625366382566944, 0.01814949369457151, 0.056170831966613016, 0.016872356778809, 0.053680398102317534, 0.055232346789645295, 0.07468166761100292, 0.029828328173607588, 0.04195466837180512, 0.005829491120363984, 0.01671448882137026, 0.11614585694457803, 0.04847637716946857, 0.08036889707935707, 0.017216703122747794, 0.04500718368217349, 0.025940010390643562, 0.056117848559681854, 0.07448319611804825, 0.05476666481367179, 0.02372209824222539, 0.0443602616100439, 0.03974235922630344, 0.04049314804641264, 0.027980568752224957, 0.049485379098249335, 0.050085085311106274, 0.021885175025090575, 0.04342539641740067, 0.03179280918889812, 0.029718575134341205, 0.011894707002543976, 0.024943873485816375, 0.0296275089494884, 0.044624130308095894, 0.031624644462551386, 0.05456686678475567, 0.14579698230539048, 0.07207396932478462, 0.04349493947146194, 0.04226137977093458, 0.031500815214323144, 0.03017549043787377, 0.06481522561183997, 0.03883358709780233, 0.017514571514246718, 0.049312888711158714, 0.01996642048470676, 0.11549235986811773, 0.11914008270416941, 0.003661829579089369, 0.05201851317126836, 0.10199222713708878, 0.06932946480810642, 0.05064130421461804, 0.011147097118997147, 0.10926519294402429, 0.021149933138596158, 0.007284889363550714, 0.07444519137165376, 0.05615386859114681, 0.087079683052642, 0.06645596399903297, 0.020573588886431286, 0.02657451866460698, 0.1660579836794308, 0.08894413443548338, 0.0726127125588911, 0.024831404610137855, 0.050478038511105945, 0.20440857937293394, 0.009420075370664043, 0.0525174128290798, 0.0686709601432085, 0.1340484470129013, 0.07425872994852917, 0.011312195715228361, 0.034778590580182414, 0.039557987691036293, 0.04471639749993171, 0.07609045558742114, 0.0861653367589627, 0.016822540434077382, 0.08221978454717568, 0.026721455422895293, 0.02076767704316548, 0.10397270800811903, 0.049213476545576534, 0.05181983472513301, 0.06683374515601567, 0.0345440990557628, 0.026989990745538046, 0.010475779168440827, 0.059022260031529834, 0.010842171963304281, 0.0357776417929147, 0.07877324055880308, 0.035478611410196335, 0.07874253006385905, 0.04043871596721666, 0.02619600129712905, 0.03929420041718653, 0.02489424204187734, 0.06397922297141381, 0.009428275466364409, 0.040901229184653075, 0.02179007664588945, 0.026510366571268866, 0.07651709805109672, 0.0076972876808473045, 0.033362912080649815, 0.026099966539602195, 0.042729450190173726, 0.012753690775882984, 0.02008311154453882, 0.03483734832012227, 0.05198108178696462, 0.05079327231006963, 0.045529974557991536, 0.045339611558509726, 0.018282997155828134, 0.03065518076930727, 0.012996785276170288, 0.007159244185978813, 0.05605912135381784, 0.005655980810323464, 0.016752926133839146, 0.05155706864648631, 0.024492408514821103, 0.021914072135197263, 0.03680897770183427, 0.04285873146727681, 0.04083984551419105, 0.035525813698768616, 0.05520539198602949, 0.014736834048692669, 0.019284051743202975, 0.051042386264141114, 0.030296103430113623, 0.025601087237841318, 0.01019535506410258, 0.0200886449976159, 0.02327047720817583, 0.036307374081973515, 0.044399603070425134, 0.023020197870209813, 0.032356017003101964, 0.014461031616000193, 0.08020393843097345, 0.13663199623780592, 0.1268888440515314, 0.2953501987670149, 0.10131044193570103, 0.13292635365256242, 0.15949934561337742, 0.09289987145790032, 0.200215572225196, 0.0966718408412167, 0.12271411663719586, 0.23851930829031126, 0.24936050655586378, 0.13251330224531038, 0.08492404515189783, 0.10948219522833824, 0.11044988794518368, 0.09868210261421544, 0.11039623618125916, 0.13737142298902782, 0.16588497082037584, 0.19800023681351117, 0.11170968998755727, 0.14234022636498722, 0.1721891582544361, 0.11812042099024568, 0.10998718134526696, 0.172754988606487, 0.0981651335688574, 0.1209044230303594, 0.09454481676220894, 0.07777356848652874, 0.1676825593624796, 0.1427246435944523, 0.16085222230425902, 0.12353063853723661, 0.12144442833960056, 0.08054174030465738, 0.10907426676047699, 0.14077582316739218, 0.17328827641904354, 0.12170056173843996, 0.07547205912747554, 0.07471962485994611, 0.13259528284626348, 0.07396915155862059, 0.2294468336871692, 0.2114980760961771, 0.128302558192185, 0.1674598098865577, 0.18494810004319462, 0.17454275196152075, 0.0726660250553063, 0.1419011599251202, 0.0994169424687113, 0.17323514712708338, 0.21532087453774043, 0.2375717477074691, 0.20590864388006075, 0.08513812295028142, 0.10407690384558269, 0.08116396370210818, 0.1735006985919816, 0.16499823411660536, 0.1981017863644021, 0.21888056424047264, 0.13086389218057903, 0.13485403092844145, 0.17482207768729754, 0.1387985721230507, 0.10001821949013642, 0.13584307714232377, 0.11449719326836721, 0.20455055604023592, 0.2054066908146654, 0.15941519370036467, 0.1452563798853329, 0.28164881254945484, 0.10648585922483887, 0.15762396981673582, 0.16074974994574273, 0.23064116388559341, 0.17669423722795077, 0.11322500117655311, 0.15862889375005448, 0.23083375926528657, 0.11532801868660109, 0.20706090490732873, 0.20421272702515125, 0.17637903057038784, 0.23752397884215626, 0.15603166525917395, 0.13409430240946157, 0.19387549028864928, 0.24886894864695414, 0.33147244474717547, 0.23709091065185411, 0.1610766409763268, 0.40767781702535494, 0.14873513393104076, 0.19818623683282308, 0.2173996887036732, 0.23019981756806374, 0.17593072248356684, 0.08757168200931378, 0.1565047941569771, 0.15487644581922463, 0.11732041463255882, 0.13291165658405849, 0.190694463838424, 0.14637916535139084, 0.1484202393995864, 0.16763184565518582, 0.12003732313002859, 0.21204896510711738, 0.1926498117723635, 0.10543641660894666, 0.09815155608313424, 0.18502109684050083, 0.11226942030979054, 0.15894038203571523, 0.15120292508176394, 0.09995288335319076, 0.10400727936731917, 0.24216982669063977, 0.1584675381226199, 0.18101484967129572, 0.10575872074280467, 0.14891216371740612, 0.10557067154773644, 0.1584653803812606, 0.1839985717087984, 0.1928463562258652, 0.13606275963996137, 0.0895723153703979, 0.14119926973112992, 0.17112412968916552, 0.20712163379149778, 0.1252479021038328, 0.08306912040071827, 0.11986368601875645, 0.1275863509093012, 0.13821744759167942, 0.11351500025817327, 0.1796893450830664, 0.1304903043700116, 0.14153035410812922, 0.11692816710897855, 0.14112089893647603, 0.06622301614178078, 0.20542940816708974, 0.1474006048270634, 0.17654923429446562, 0.15310175104865006, 0.12476999631949834, 0.12308713447834764, 0.1376227523599352, 0.10967396958065884, 0.18610561293150696, 0.21368272815431866, 0.1339192268039499, 0.14887595708881105, 0.19086088133709772, 0.12273749895393848, 0.1082847234127777, 0.1373003532311746, 0.13214279498372758, 0.09394392650574446, 0.1494702859116452, 0.19892718350248678, 0.07170079542057854, 0.10959711870444672, 0.21665638073214463, 0.22503836452960968, 0.09430014381983451, 0.12302894331514835], [0.014063836723965193, 0.014569052694631475, 0.01730017819707947, 0.04281962410147701, 0.03232124547607132, 0.0031858147870350096, 0.004439635967303599, 0.05948419988687549, 0.033450914679893425, 0.0168687690248979, 0.102577680721879, 0.015762383750240718, 0.038197928706982305, 0.058110451458820274, 0.02228731898191784, 0.04747555158766253, 0.06940218340605497, 0.014754542116341847, 0.032604449029479704, 0.04280533754665937, 0.024395184624674063, 0.06326094615672316, 0.023357249962698137, 0.04025775067774313, 0.02041661998789225, 0.020839635681893145, 0.04759095682363425, 0.04937862518376537, 0.018607940790908675, 0.044942746604127545, 0.03619240650108882, 0.013037302298471332, 0.012492411537095904, 0.021763590031436512, 0.043515672108956745, 0.05396192567422986, 0.027684732573106885, 0.030170876399746964, 0.028178928286901543, 0.021311745080830793, 0.04327909069667969, 0.032015385638390265, 0.05097984569147229, 0.0584659766671913, 0.020319107720362287, 0.09286276916308062, 0.07320197272513594, 0.010673696807186519, 0.04119052258985383, 0.04968681239656039, 0.053196382110140154, 0.009218662428403539, 0.04690511059015989, 0.11477676326675074, 0.013614492174903197, 0.017900042169328247, 0.02827975689433515, 0.030939870314406495, 0.058463316809918196, 0.07111760135740042, 0.016281900694593787, 0.026582242089456747, 0.019393787819093893, 0.029592581359403472, 0.07893898630780832, 0.11524637735315732, 0.05424732768109866, 0.035424678054239066, 0.10013791985277619, 0.005662110101963792, 0.05206925741263798, 0.015810875255348425, 0.08056056965142488, 0.06552629638463259, 0.05895185523799487, 0.053461322893521616, 0.11425902747682162, 0.17796271773321287, 0.03159901958757213, 0.09845492230462176, 0.1375819452639137, 0.4513411654957703, 0.19797593168914318, 0.08261070892746959, 0.05412643648950117, 0.14902762323617935, 0.14266802663249628, 0.022309892145650725, 0.01760568350021328, 0.08635791178260531, 0.19210739087845596, 0.06151941817786012, 0.05154170322098902, 0.046471285833311934, 0.15842568608266966, 0.03990998112463525, 0.12250537212405886, 0.36642310502273695, 0.22689676338008472, 0.12722458317875862, 0.06231652040566717, 0.11556549237242766, 0.026606562480862652, 0.050983048376760313, 0.07533177201236997, 0.02153300347604922, 0.08930321516735212, 0.028460727272821323, 0.008977283773544644, 0.05302366780649338, 0.04765049148617046, 0.07329229252146822, 0.012267372853654836, 0.027038896157007133, 0.08800960851034947, 0.042755848595074246, 0.03614522456856711, 0.021179469767957926, 0.07292884880942957, 0.08791957369872502, 0.05451592916090574, 0.040619850890444856, 0.00588232312916911, 0.007413412377770458, 0.04049384354480675, 0.025401253585836718, 0.05101565198440637, 0.04710362958056586, 0.024216134500290667, 0.008619106341419476, 0.07199163588562182, 0.01361361940923546, 0.029643742899809564, 0.00787791285464274, 0.03161206103063055, 0.013955554409351732, 0.00733423073376928, 0.05273059156856366, 0.03919211482363088, 0.05856700374611786, 0.06404553619878632, 0.021388300794309804, 0.07442582598222153, 0.007179930174191083, 0.058486156298645904, 0.06181959528476, 0.03023162903264165, 0.038370317313820124, 0.03233628520475967, 0.061633798825953684, 0.040849110909870694, 0.052489043279950104, 0.009465063938737979, 0.035925779558186016, 0.052949276619723866, 0.02119162741915456, 0.03623045874493463, 0.04233932648120182, 0.013250974672181266, 0.035201477352529764, 0.08366507770759718, 0.022351934175406183, 0.02110516170172819, 0.01719038953472461, 0.007034877622832677, 0.053382222673722675, 0.04471456206270626, 0.009277680556156805, 0.05171244638040662, 0.015621952446443694, 0.022943923748763542, 0.08579617299671684, 0.039920542522200515, 0.024953247447099005, 0.04022296218733702, 0.04799351468682289, 0.010576107356298183, 0.048542985559574196, 0.08633281955761568, 0.013865427995499755, 0.044432627369782755, 0.03074002478803907, 0.028788822703063488, 0.08409703988581896, 0.04093945784760373, 0.03396374126896262, 0.03200501423063023, 0.06565835965531212, 0.03392244562772768, 0.027972400886937976, 0.06170731809522424, 0.05446085247344204, 0.00578303013129958, 0.021994827980441705, 0.03462727048567363, 0.06918974766241652, 0.017598465583952408, 0.07382534963211843, 0.00632783692396645, 0.0260167527012527, 0.01516050792166165, 0.05008319898375443, 0.022018563135394027, 0.0853147456156356, 0.018710601442892636, 0.06540112024439232, 0.04665466331477676, 0.007508737218034054, 0.043247990044099946, 0.017761571831735115, 0.007467891954417739, 0.021138051990419626, 0.023103374389133284, 0.035846886291567764, 0.048646340013614724, 0.025658248724149804, 0.028574008694184676, 0.012084014031903019, 0.04376533906906843, 0.06801046058535576, 0.05865667893418244, 0.049477480950632265, 0.018170121159138422, 0.019887366066021577, 0.021061552256079655, 0.016835291803415333, 0.019880616338923573, 0.0314195097557136, 0.007028051136460687, 0.07106337283871003, 0.021283931930416396, 0.030936019628175666, 0.03960382951689618, 0.01015371676268322, 0.039556359206991534, 0.022502648677410822, 0.030474785449249402, 0.04460584039666823, 0.05391679291746446, 0.062433676261987, 0.025319892148088132, 0.11066969257912465, 0.02896694832348398, 0.05122209626383015, 0.034751164194728644, 0.013655367972595351, 0.036451033516121764, 0.023441846316148127, 0.06841226866734879, 0.05353740702516266, 0.04013222509196826, 0.04360307759738394, 0.21586165337690286, 0.25710592951093403, 0.04875290393829346, 0.12036889605224133, 0.05490029210756932, 0.12084506478692804, 0.07055566579635654, 0.1164447787616934, 0.08682513064039604, 0.10719736426004342, 0.10820336706404175, 0.012652507633902133, 0.03284350030922464, 0.06848035965647016, 0.1032516627705523, 0.042351669033191035, 0.12281745752053601, 0.5817710938198226, 0.46356470244271414, 0.07672870598201241, 0.22276140456753118, 0.03414299325751407, 0.18112340170357907, 0.12933284576450074, 0.050894167074667554, 0.10502811494682517, 0.11520375178328582, 0.10177400348974125, 0.06280837008463484, 0.01582182850688696, 0.008616847667976149, 0.043841745504843335, 0.0241055197215506, 0.008707187820359, 0.01677033055706748, 0.031809714888887744, 0.01075404807592609, 0.023386477858626416, 0.04067228468401091, 0.03791712377486484, 0.05375750003648656, 0.04560112234737192, 0.02027308608272246, 0.017357680647234832, 0.033769507227199416, 0.010480418651630836, 0.07795534123267446, 0.019431560167244503, 0.01245375709342105, 0.0263518065081111, 0.028331617325810448, 0.022990959796256254, 0.02623569220304489, 0.048937394217188866, 0.029845674921359335, 0.040904879703053405, 0.040033128445169756, 0.022484930431736366, 0.047872749024203846, 0.06002318739358868, 0.07006657775491476, 0.013388377165288796, 0.011372686263972094, 0.013000538422992187, 0.04716103025046842, 0.02790477469430438, 0.032904968796564, 0.04987113643437624, 0.0475457494280168, 0.009231947295899903, 0.018631100887432694, 0.023680466726156216, 0.0411389776771622, 0.047982875257730484, 0.05457933825839843, 0.03231045676927481, 0.022042858081736734, 0.06649930881602423, 0.04396795301831194, 0.09127029497176409, 0.030426616248275553, 0.01694182349768068, 0.017839437117800117, 0.09956359424229179, 0.03843872382172516, 0.07689239576991115, 0.04646578969966088, 0.0414968268679721, 0.058316875382193496, 0.056817699755941115, 0.03562486284811582, 0.057158514325107844, 0.03448929717498166, 0.034547932778618166, 0.020086660282686353, 0.020760028257167766, 0.03809759373377476, 0.03729544999077916, 0.025674499637846435, 0.10232396290770598, 0.11968508203114782, 0.11208375277263777, 0.16696954119418347, 0.11101395410618611, 0.18925773378993782, 0.0977741956178631, 0.1106637961098126, 0.12000848539173603, 0.09683207010052033, 0.06817935473684754, 0.11963557611618723, 0.15145060393427098, 0.1952197224433933, 0.15429534842925413, 0.15214915573596954, 0.11077829210885934, 0.15433178575975554, 0.10335743280925921, 0.13803793436714581, 0.18083742633461952, 0.12661284314734594, 0.17891645298472472, 0.06476457297269787, 0.1099275177610772, 0.19180943258106709, 0.12792846826570375, 0.19373772053846292, 0.27492097499115126, 0.06957229213523013, 0.13811108044215611, 0.23151310852595738, 0.07244508726788418, 0.10127068656895842, 0.12916451479707444, 0.07529388940227882, 0.1400974238557475, 0.17382806459707872, 0.1131970998165863, 0.1676384817276682, 0.1290371266326734, 0.13358359624232563, 0.07057298879538264, 0.11173997979078974, 0.1459872028125184, 0.11127510187881333, 0.13332021608948708, 0.17090577712016447, 0.11283349325614316, 0.13023604372782366, 0.16590179848883832, 0.11480355182928698, 0.10910833600376334, 0.1273662612906524, 0.26136995213372366, 0.07564279210886785, 0.1571138064776148, 0.1477057013128485, 0.1914636782769646, 0.1318202330065625, 0.15416938518839224, 0.12396571519119398, 0.2386292309633323, 0.1643567606806755, 0.14035049027630261, 0.10460507550409862, 0.18698061097945484, 0.1882435410682644, 0.2376037745603493, 0.18568266848368303, 0.07454475960029022, 0.09608813109142439, 0.07419768215290137, 0.1506295901324068, 0.18598659788923605, 0.12286358433110373, 0.12627718544432096, 0.1951935581330742, 0.37562949529715944, 0.21793395360665663, 0.2477182075381279, 0.4085104880588395, 0.7826461206589426, 0.24929824418255261, 0.24707547202706337, 0.1181902965264661, 0.1525358392723969, 0.1977916280073779, 0.07369564766330378, 0.0749286747138415, 0.19808292309088366, 0.16879047134092875, 0.1308745994631733, 0.09512165295226233, 0.407314692224775, 0.3275737182370254, 0.06803701166063547, 0.14403554610908031, 0.5781516251819474, 0.39205742520945414, 0.291435214557818, 0.10641814142997776, 0.39238027217132704, 0.12608421008501733, 0.16400386818817683, 0.16308844302381786, 0.08531900681555271, 0.15964205509849957, 0.11703610845974513, 0.12368233182600566, 0.09704521152057818, 0.1783074542347874, 0.18100425095430442, 0.11907822745186941, 0.19366895779967308, 0.2288539840706757, 0.15018831166837895, 0.05819373484700918, 0.19019210365201744, 0.1223698551101344, 0.16597417103392736, 0.14037763167704853, 0.18385297166449682, 0.10639972598957163, 0.14717945669378552, 0.11697551528257982, 0.08959869681192295, 0.1841854266822338, 0.22740483683134827, 0.07273339679730789, 0.13716001861861774, 0.1626009020422186, 0.12592140239264282, 0.24029460017170223, 0.0701706243146743, 0.17676065223557608, 0.10075000593704836, 0.19971684898648942, 0.17953108357531683, 0.14835997191923006, 0.08905448458556618, 0.13522894866764545, 0.09985018029276814, 0.12015738311622824, 0.13744105425264153, 0.12527193581419332, 0.13141491689852305, 0.09083793245788131, 0.09851909814668552, 0.13062557711132936, 0.16405425619866165, 0.09350125025957823, 0.16608269592481, 0.17114684704158986, 0.10744756047746964, 0.14921498032552855, 0.15857770506824764, 0.1165169748876776, 0.12115705518850259, 0.05607530102133751, 0.12903749304158346, 0.12684433215430804, 0.1988956859069211, 0.14715489372611046, 0.11019305565527507, 0.14879177803439753, 0.15957504298005784, 0.16466309210019453, 0.17046543503446238, 0.11064142481024776, 0.10076196850942713, 0.09457406840686287, 0.15759609559816973, 0.12783282196947507, 0.09834007346736533, 0.16436281321304186, 0.13735695662243025], [0.0687167476862669, 0.029264994830425297, 0.056608124037406275, 0.04112015850841999, 0.04561035381630063, 0.07027925777115993, 0.02528766173470233, 0.10143637124981199, 0.06871212007743971, 0.0228427117690444, 0.034853215861533365, 0.03179930276902659, 0.03559491570506777, 0.0793185927239912, 0.01479617363241102, 0.022812242154031992, 0.049965958310557265, 0.04317284568345972, 0.02035420324786433, 0.056260873563587666, 0.08040776356522526, 0.027942219649308493, 0.0028319496569955455, 0.05431230758715953, 0.008334722137078643, 0.03032251201303942, 0.031101890906159366, 0.07446900795080832, 0.040394295672220845, 0.03499447667439069, 0.07840537958379303, 0.03319100523367524, 0.0739687444376094, 0.024925364746845195, 0.023310219004218067, 0.07288021820464305, 0.03557885817385145, 0.02830963279120624, 0.05571185052394867, 0.034849402494728565, 0.01831537515058049, 0.05297014835689749, 0.014049087068997324, 0.0552936931406813, 0.04119988637311118, 0.009810331393964589, 0.010009318573533424, 0.04636026393356068, 0.0363065801960017, 0.03858531791982906, 0.048380788548716476, 0.10416788860623326, 0.02727977778496487, 0.0383998980479581, 0.017377249597172652, 0.06685845061604466, 0.044910112462405644, 0.04742669706631984, 0.007903480902314186, 0.0200977560265788, 0.0325249790080956, 0.01899102469906211, 0.01709894337026136, 0.04218523117846676, 0.030702746074114527, 0.024773639227662767, 0.08848528191447258, 0.09042785303401095, 0.04283762224284666, 0.023844024199726324, 0.017168839262532334, 0.017101060399519544, 0.12063174694776535, 0.31000275537371635, 0.1435413419135979, 0.12509099766612053, 1.2181260415485926, 3.464965888432094, 2.9985107353755405, 6.087660721370152, 7.144197719437735, 14.94207501411438, 18.682627303259714, 31.76077161516462, 35.56829759052822, 29.66638653618949, 23.53954666001456, 31.253421102251323, 26.95734817641122, 30.825617040906632, 22.651321956089564, 32.91498899459839, 30.450581073760986, 41.1006999697004, 44.45107964106968, 37.60463394437517, 37.089348588671, 15.312294142586843, 8.323452932494027, 0.6288620755076408, 0.25880804817591396, 0.32493115003619877, 0.295254253915378, 0.20846212043293885, 0.038942512324345965, 0.017454034316220453, 0.05977215657808951, 0.005381508730351925, 0.021990519283073287, 0.03454920842445322, 0.040757688494133096, 0.08080628753772803, 0.026589678833261132, 0.037496676335909536, 0.06685701890715531, 0.08577330636658839, 0.020973174766238247, 0.025340763885261755, 0.040459604667765756, 0.05279291161735143, 0.04301562911963888, 0.04451752567131605, 0.02332160821450608, 0.030916637275367975, 0.04049224220216274, 0.04510142880358866, 0.04146516642400196, 0.051641274842300584, 0.048978435407791815, 0.031307883959795745, 0.04028882758159723, 0.03765397093125752, 0.019026038802361915, 0.013300665487934436, 0.06281294341066054, 0.07798345293849707, 0.02368078224493989, 0.02855799187506948, 0.026945505989715457, 0.014088870425309454, 0.038267631216772964, 0.06552585533687047, 0.04100597802815693, 0.029390411850597178, 0.04421569633164576, 0.018471623105662208, 0.029430489521473646, 0.030508294901145355, 0.04351350758224726, 0.009792826038652232, 0.028093080036342144, 0.027453632027442967, 0.0022446534255452988, 0.039718074457986016, 0.029151913576892445, 0.04304199020511337, 0.017503730220986263, 0.04238340411601322, 0.049174511672130654, 0.032720084967357774, 0.02432750414923898, 0.061039198589112074, 0.02362175309099257, 0.05638123889054571, 0.04116098256781697, 0.03299741240750466, 0.06193187925964594, 0.021942528197541833, 0.021556796306478124, 0.04296256768118058, 0.0405906603139426, 0.04023276701835649, 0.06407077770148005, 0.009901933621482124, 0.02606954611837864, 0.08243770285376481, 0.03606892330572009, 0.0560591383171933, 0.017639997016106333, 0.025147196504154375, 0.03514886713985886, 0.035065885699753246, 0.03760976776746767, 0.10211066542459385, 0.07439181102173668, 0.07896370533853769, 0.012669146160728164, 0.024122281232848763, 0.010838183873732175, 0.024272888865587965, 0.013323135175076979, 0.00406056983462934, 0.03570446179115346, 0.05649743801248925, 0.06771879909293992, 0.01932533720641264, 0.08582471217960119, 0.013793024916334875, 0.024566416329305087, 0.06323992514184543, 0.021963289672774926, 0.01929373274158154, 0.04086268161024366, 0.06741727170135293, 0.029514200386724303, 0.03490429937041231, 0.01588258962146938, 0.024208232959998504, 0.01949320168101362, 0.07727449240961246, 0.013213202324030655, 0.03371902422181197, 0.015614688729069062, 0.03806131246632763, 0.03816537259678755, 0.03861444403550454, 0.03535778128675052, 0.04948791003386889, 0.01602473931520113, 0.054518575447478464, 0.04308914499623435, 0.006895458184382213, 0.05108754616230726, 0.021544116183317134, 0.029878421021359305, 0.013464121181251747, 0.10571953534547772, 0.03741357954485076, 0.030448919694338526, 0.020452076835291724, 0.05273380782455206, 0.039653644165290255, 0.015511814338554229, 0.012969288492708333, 0.031631901394575834, 0.06120721064507961, 0.07368893695196935, 0.05270589289388486, 0.01792552794462868, 0.06757239837731634, 0.042901652199881415, 0.12643563694187573, 0.13786304875143937, 0.07799682686371462, 0.030107538548431227, 0.06755628317062344, 0.07342516324881997, 0.03880088170990348, 0.03840529240135636, 0.08445088911269392, 0.14388967465077127, 0.39288081388388363, 5.094051386628832, 10.408729791641235, 9.587585602487836, 14.58654090336391, 18.817326818193706, 30.717801843370708, 35.69672114508492, 54.538863454546245, 58.949107442583355, 50.59033073697771, 41.65230703353882, 53.46965728487287, 48.62317759650094, 51.325234753744944, 42.17377628598894, 53.75643375941685, 51.322997433798655, 66.6105316707066, 72.21886048998151, 65.50414221627372, 63.72059522356306, 33.79531880787441, 22.11318744931902, 4.400805728776114, 0.2959261121494429, 0.2157184010637658, 0.21337259693869523, 0.31541361074362484, 0.07908758547689233, 0.024201340740546584, 0.053687553254089186, 0.027691190530146872, 0.02953697202195014, 0.04701283820239561, 0.03465200987245355, 0.08207403522517, 0.07624372986278363, 0.0778726888820529, 0.11809447381113257, 0.06142989226749965, 0.05463309519525085, 0.04494975247819509, 0.04601589384089623, 0.03705625621868031, 0.03480812720954418, 0.011415076891093381, 0.03870758993018951, 0.02598227294428008, 0.0686909972823092, 0.04945555409150464, 0.03446416084521583, 0.08005817553826741, 0.06645112604435001, 0.019791168460090245, 0.04310660709493926, 0.028561320089335953, 0.03503991137923939, 0.0543441512355847, 0.038098737065281184, 0.0425346258229443, 0.013347559043073227, 0.045317386143973896, 0.02642119349911809, 0.06422971774424825, 0.06212359254381486, 0.02610208187252283, 0.11108180760805096, 0.015893717595775212, 0.02179343539423176, 0.04829266042049442, 0.021255993251023547, 0.020493289355986884, 0.030257063917815685, 0.022141976780923348, 0.024697387158604603, 0.02682158344292215, 0.12201726117304393, 0.029103340647582496, 0.057146544967378886, 0.038656730337866714, 0.03897173343492406, 0.04345844785815903, 0.02170919527166656, 0.03739911996360336, 0.04540116486272641, 0.03901780935536538, 0.02833355963230133, 0.008068861938746912, 0.01575131175507392, 0.04470587342179247, 0.03938847268000245, 0.02793152933008969, 0.02679590767781649, 0.027314393248941218, 0.08147657835589987, 0.04335395346528717, 0.01855966472066939, 0.04433619736560753, 0.038996533889855654, 0.07164439558982849, 0.09949102492204734, 0.08769809986863818, 0.16422661766409874, 0.1132219952664205, 0.15082320331462792, 0.12084594688245229, 0.12415034456976823, 0.13881230567182812, 0.17230212076434068, 0.19176027950431618, 0.12764678123806203, 0.15205375371234758, 0.11063090751745872, 0.1189503236008542, 0.08276508921491248, 0.10563965820308242, 0.12601843290030956, 0.09791023510375194, 0.17950566565351828, 0.13005134649574757, 0.16367085677172455, 0.10763141632612262, 0.1226303582744939, 0.15035117364355496, 0.09003009580607925, 0.1478606651404074, 0.11664783715137414, 0.15841366244213922, 0.19859182435486997, 0.1619336171341794, 0.17749448785824434, 0.11103996235345091, 0.14474780431815557, 0.13521241955459118, 0.09917260879384619, 0.1312431932560035, 0.1154926312821252, 0.13200533735964978, 0.24112249431865557, 0.18986207778964723, 0.09275337574737412, 0.10008989314415626, 0.057019523211887906, 0.10409074595996312, 0.11602685547300748, 0.07103516613798481, 0.11896531922476632, 0.08504458689796073, 0.10087940256510462, 0.10669695146914039, 0.11115084176084825, 0.1704266092606953, 0.15915298062775815, 0.18503409757145814, 0.14763152386460984, 0.14109250903129578, 0.1329724940338305, 0.14475921727716923, 0.1614459811576775, 0.16018351247268064, 0.14491598600787775, 0.09574615622737578, 0.12328305467963219, 0.19434296020439693, 0.14146334198968752, 0.25834154177989277, 0.26806223445705, 0.2967027361903872, 0.12356273324361869, 0.06582344722534929, 0.15698055577065262, 0.1117668022800769, 0.2781911338014262, 0.35448851542813437, 0.16611133010259696, 0.1886993401816913, 3.04131663271359, 7.554956112589155, 6.743148131029947, 11.133931517601013, 14.84887535231454, 25.120970555714198, 31.680203778403147, 51.7473795073373, 58.690745626177105, 50.16546923773629, 40.533900669642854, 54.820369720458984, 52.92620393208095, 53.2017034803118, 46.42489957809448, 55.65834331512451, 52.62661497933524, 70.55493368421281, 74.5489319392613, 64.6489509854998, 61.83364513942173, 31.56799384525844, 18.325555903570994, 2.5293025757585252, 0.21376279528651917, 0.47171412514788763, 0.3792676915015493, 0.38901183434895104, 0.23170464539102145, 0.16348712305937493, 0.23759728776557104, 0.06452167100672211, 0.11891650541552476, 0.15302350239029952, 0.1459532489201852, 0.22462414604212555, 0.1578459186213357, 0.13772272770958288, 0.31585463136434555, 0.1473036286021982, 0.10299709678760596, 0.1270308478602341, 0.253340521561248, 0.15003946822668823, 0.10092632326164416, 0.14683330883937223, 0.13413129613867827, 0.06698247324675322, 0.15493114931242807, 0.10630184052778141, 0.15374532794313772, 0.14663472878081457, 0.10541450671319451, 0.15925121892775806, 0.15202902789626802, 0.13290298490652017, 0.11675196513533592, 0.12800407063748154, 0.08292802582894053, 0.1617735642939806, 0.23126329907349177, 0.14163271790104254, 0.0873267851503832, 0.09839268028736115, 0.1436291579157114, 0.15373596415988036, 0.14135606560323918, 0.14409045316278934, 0.11026308725454978, 0.12005917195762907, 0.07869835064879485, 0.11229331831314734, 0.12052487768232822, 0.11473313346505165, 0.08403684704431466, 0.1004139275423118, 0.20557886229029723, 0.10417065024375916, 0.11369235574134759, 0.15844184878681386, 0.19349753271256173, 0.13789321641836846, 0.11216012867433683, 0.08064076570527894, 0.1311785424394267, 0.21154690347611904, 0.19378338594521793, 0.08584925479122571, 0.13300222743834766, 0.13813119222010883, 0.14640507181840284, 0.08840267027595214, 0.18170498763876303, 0.1607792390776532, 0.19741216408354895, 0.22487019641058786, 0.11029737362904207, 0.11887126070048128, 0.11877317167818546, 0.09784646638269935], [0.034411228328411064, 0.014919102125402008, 0.030838676994400363, 0.06552111237709012, 0.030238204036972353, 0.023577035936926092, 0.021205666308690394, 0.03550489107146859, 0.08472481369972229, 0.07865974200623375, 0.07119701709598303, 0.012799004192597099, 0.08364691332514797, 0.0016996143406556386, 0.0306096341061805, 0.016026286375043646, 0.030035949711288725, 0.020793347719258497, 0.1054090377209442, 0.07213486784270831, 0.025686748891270587, 0.03303144772404006, 0.05696248555822032, 0.05455006625769394, 0.10458923849676337, 0.026680773855852227, 0.003968359894185726, 0.058669890010995526, 0.03729061882144638, 0.07723760046064854, 0.06618503853678703, 0.041936975571193864, 0.021534742222034504, 0.020581454803634967, 0.04382390342652798, 0.024588677366929393, 0.04206212117735829, 0.03239996571625982, 0.016752566510279263, 0.04440812547025936, 0.0888572751677462, 0.07229039485433272, 0.08519923181406089, 0.030876807269773314, 0.02688318763726524, 0.14824871931757244, 0.03591154050081968, 0.032668343279510736, 0.047867185037050924, 0.023860733124560544, 0.025085336162841747, 0.04159009150628533, 0.025613548533458794, 0.018687834896679436, 0.03474964427628687, 0.024012736843100617, 0.008612731504919273, 0.02082370367965528, 0.053128810200308046, 0.06715285338993583, 0.033805313520133495, 0.03913449362984725, 0.043246320847954066, 0.003454233062387045, 0.045650974315192015, 0.3064780373658453, 0.2932365893253258, 0.2625609167984554, 0.17164326326123305, 0.051030101387628486, 0.429285004734993, 1.634550147822925, 5.149764214243207, 11.38688850402832, 23.66520483153207, 39.26392977578299, 58.23714985166277, 64.87143230438232, 85.21215166364397, 88.3946350642613, 97.506502696446, 105.70893451145717, 103.89923449925014, 107.80292701721191, 107.94303049360002, 111.46639946528843, 106.19318921225411, 105.38199397495815, 105.82892295292446, 101.98692349025181, 105.7139858518328, 97.90775421687535, 102.49161284310478, 109.51758262089321, 114.68549292428153, 116.0313173021589, 103.18719005584717, 92.09487737928117, 85.97124235970634, 69.50670760018485, 39.751783643450054, 19.28750967979431, 9.752402952739171, 5.749713369778224, 1.0667817911931445, 0.10129515454173088, 0.10172293015888759, 0.11749295251710073, 0.04087411831798298, 0.038892707853977165, 0.03106375384543623, 0.0940920574856656, 0.04015790085707392, 0.03180951132838215, 0.016714682203850577, 0.10062463980700288, 0.07318513148597308, 0.09224436591778483, 0.04264344248388495, 0.03249600217012422, 0.024682109942659736, 0.0027798676414282192, 0.029147479350545576, 0.025438315168555294, 0.05013429945600884, 0.02037955670883613, 0.05471217166632414, 0.05279832293412515, 0.04747022508776613, 0.02138349337370268, 0.028104060429281423, 0.04067037121525832, 0.030556023054357086, 0.03844762620116983, 0.033365046073283465, 0.049076388723083904, 0.04973494427810822, 0.04185153444164565, 0.006370011268050543, 0.045987320731260946, 0.061322622666401524, 0.028725793585181236, 0.07766155592565026, 0.03248714389545577, 0.05145947156207902, 0.01434700719879142, 0.023607782054958597, 0.034160831943154335, 0.02411616763233074, 0.031507050951144526, 0.028183961320402365, 0.022143440720226084, 0.04572871407227857, 0.03963977151683398, 0.03427940933033824, 0.023581975671861852, 0.020045412138902714, 0.05271231522783637, 0.030083898388381516, 0.004590645632041352, 0.00541999311618773, 0.03581309185496398, 0.010142676997929811, 0.0577138816671712, 0.05067612323909998, 0.004001376135939998, 0.01866685798657792, 0.005780319807984467, 0.0643732211153422, 0.03860167400645358, 0.040285360267651935, 0.02065164246596396, 0.0524304110689887, 0.0865739369764924, 0.07892786511885268, 0.022578315510015403, 0.03820613219535776, 0.05274232683171119, 0.023443410339366113, 0.032589748568300686, 0.007920794571483774, 0.019777424733287523, 0.03173944580235651, 0.03839350624808243, 0.04051367712340184, 0.03857367765158415, 0.02111944995288338, 0.036362057219126394, 0.05744307155587843, 0.05375131518979158, 0.043831140002501864, 0.07888198936624186, 0.04728307155892253, 0.031748317647725344, 0.05019660932677133, 0.034109439700841904, 0.03918953639056001, 0.049396311199026446, 0.041274576115288904, 0.07042703591287136, 0.056343990710697005, 0.05841830958213125, 0.05628821173948901, 0.01754780955213521, 0.026383634889498353, 0.028908478960927044, 0.025708090513944626, 0.03131992117102657, 0.031054675046886717, 0.05497071725715484, 0.02539824428302901, 0.09337025228887796, 0.0526046147570014, 0.045739814905183654, 0.10453792767865316, 0.01855856040492654, 0.04481897842405098, 0.07265006591166769, 0.03757188855005162, 0.044421869197062085, 0.04026264291522758, 0.09989851912749664, 0.050528772574450286, 0.05332574141877038, 0.028518765765641416, 0.005497009385310645, 0.04148510517552495, 0.038733469255800755, 0.014937617649723376, 0.043592187110334635, 0.03845123261479395, 0.030084505677223206, 0.005761552801621812, 0.007071012157082025, 0.03487455239519477, 0.03201962648225682, 0.016320456750690937, 0.034279565393392525, 0.0900440261300121, 0.03142266833622541, 0.04032734122925571, 0.4139841486300741, 0.3513168256197657, 0.06738743651658297, 0.16142436303198338, 0.7860830905182021, 2.7331965948854173, 4.707604740347181, 14.843282052448817, 24.17685454232352, 41.704387256077354, 64.1532734462193, 79.28434467315674, 89.26109627314976, 109.16093158721924, 108.90047141483852, 118.82046318054199, 123.73347881862095, 121.36914580208915, 120.72144862583706, 119.86797360011509, 125.86978585379464, 121.40076010567802, 118.71343312944684, 120.2662582397461, 113.16338579995292, 119.31239564078194, 110.8281170981271, 115.21903814588273, 120.81021881103516, 128.72885840279716, 127.8423238481794, 116.62037168230329, 113.72084672110421, 107.59059006827218, 99.13100542340959, 69.07680865696499, 39.57687316622053, 23.88194693837847, 13.750368629183088, 2.9671168199607303, 0.4784092573182923, 0.0635166045810495, 0.03355875085773213, 0.10172045350606952, 0.054212294918085845, 0.03653406923902886, 0.07126140328390257, 0.027122873347252607, 0.036990428143846135, 0.025837563477190476, 0.036812258418649435, 0.045505900135529895, 0.03864486615306564, 0.03845430977110352, 0.02355585546631898, 0.09722754745078938, 0.009000385346423303, 0.022378768539056182, 0.015546431498868125, 0.05750865875078099, 0.031282052131635804, 0.017404750621478473, 0.02275765740445682, 0.016008922663916434, 0.06930787382381302, 0.016868887768526162, 0.03568487587784018, 0.02355985712659146, 0.017445452544572096, 0.010082678387074598, 0.09813322885228054, 0.03131262352690101, 0.01685434506673898, 0.00966262025758624, 0.011905974924697407, 0.01903743140532502, 0.05197588081604668, 0.07732092456093856, 0.0312830563634634, 0.034536719987435, 0.007476163296295064, 0.04116351689611163, 0.024790589032428603, 0.0232209916492658, 0.05209548618378384, 0.011472351183848721, 0.05066440493932792, 0.060799051475312026, 0.054084207862615585, 0.07289703908775534, 0.011022870927782995, 0.03648610020588551, 0.10221397916653327, 0.036951965386314053, 0.04237604879641107, 0.06383235406662736, 0.0817986721439021, 0.019360772001424005, 0.02660561931718673, 0.0767265007432018, 0.033796743622847965, 0.025409448592524444, 0.02186775194214923, 0.02131189775120999, 0.009869928820990026, 0.04120497877842613, 0.026514307163389664, 0.04143798431115491, 0.03757645509072712, 0.03075133596679994, 0.029782286179917197, 0.1047438494861126, 0.11694612114557199, 0.13062899692782334, 0.13975584932735988, 0.1240496499730008, 0.11780345014163426, 0.1303407009691, 0.17177093641034194, 0.2388006831918444, 0.2079162254397358, 0.22323633836848394, 0.08533881325274706, 0.18524012794452055, 0.14357630003775868, 0.10872942847864968, 0.10731620966855969, 0.12393336264150483, 0.09266353092555489, 0.14814598911574908, 0.16908469769571507, 0.11185041815042496, 0.0848914347589016, 0.11102941113391093, 0.18339642616254942, 0.213371606277568, 0.15316340274044446, 0.11455671436020307, 0.11124191473105124, 0.15832948338772568, 0.12700391001999378, 0.1737486488584961, 0.130851773545146, 0.14118347343589577, 0.07957556750625372, 0.09385646334184067, 0.19878121704927512, 0.16615091583558492, 0.1314109678247145, 0.19362675292151316, 0.2811890100794179, 0.11631823198071548, 0.10552913841924497, 0.14351641253701278, 0.09213882658098425, 0.09833364095538855, 0.19927471556833812, 0.22732634390039103, 0.16305907602821076, 0.14178065210580826, 0.09403233283332416, 0.16402801046414034, 0.13180550879665784, 0.09274909419140645, 0.11195074633828231, 0.099371813104621, 0.15625233841793879, 0.15431517522249902, 0.11340863310864993, 0.22639422677457333, 0.13735756730394705, 0.17763231189123221, 0.09845817248736109, 0.11396333548639502, 0.15728687361947127, 0.12803155130573682, 0.4171012027987412, 0.37959211266466547, 0.36985453803624424, 0.17782460871551717, 0.3749080497239317, 1.9513618392603738, 4.074358514377049, 11.454090612275259, 19.902588537761144, 38.67700501850673, 64.6749233518328, 85.52055440630231, 100.30285385676792, 119.79089028494698, 122.68637139456612, 132.35109329223633, 139.88695662362235, 140.687778200422, 141.26111575535364, 138.72375869750977, 141.92735072544642, 139.05818939208984, 137.10990061078752, 140.68031583513533, 134.5884688241141, 141.51111194065638, 129.73634719848633, 135.12584250313895, 139.52473313467843, 145.00676454816545, 146.3079675946917, 133.7616470881871, 130.40955815996443, 122.05697577340263, 105.32451847621373, 68.58018616267613, 37.659809589385986, 21.116228648594447, 11.498720628874642, 2.4979594690459113, 0.29376280680298805, 0.17220572807959147, 0.2815555546964918, 0.1917849238961935, 0.16791707463562489, 0.10637280850538186, 0.20415575722498552, 0.1259653036083494, 0.18218642180519445, 0.1392588767090014, 0.14745547116867133, 0.12534341269305774, 0.18334359542599746, 0.11548267038805143, 0.10254246475441114, 0.22471322411937372, 0.19673562395785535, 0.10631252066897494, 0.10134770029357501, 0.1698119786701032, 0.09611164232982056, 0.1197637649519103, 0.19583965917783125, 0.187139184613313, 0.15712007614118711, 0.08479086229843752, 0.23136928624340466, 0.08949022620384182, 0.11720131816608564, 0.09445272598947797, 0.22988535729902132, 0.18729276422943386, 0.12151359819940158, 0.11152838543057442, 0.09730231522449426, 0.10219703614711761, 0.12445225194096565, 0.18594767712056637, 0.1271546669304371, 0.08790871713842664, 0.24952427776796476, 0.18914502912334033, 0.20131171840642179, 0.1151573264173099, 0.20398938043841294, 0.06033014306532485, 0.11689276115170547, 0.14873179553874902, 0.13507083643759998, 0.15903019293078355, 0.056260463049901385, 0.1664732335401433, 0.137129063851067, 0.15045684868735926, 0.10408629477024078, 0.14282863587141037, 0.212266829130905, 0.14547950934086526, 0.09891794781599726, 0.10813136771321297, 0.11388345834399972, 0.13574744441679545, 0.12369754458112375, 0.1377571972885302, 0.09282893062170063, 0.0809922129181879, 0.12135179473885468, 0.17607539972024305, 0.1318649077521903, 0.24051759392023087, 0.11984771330441747], [0.041987333047602854, 0.013486906387177961, 0.06242077052593231, 0.06717966230852263, 0.027296717411705425, 0.02397781434202833, 0.06074716390243598, 0.050191625487059355, 0.02051846300517874, 0.04265392924259816, 0.009043166979349085, 0.013763305930686849, 0.08553936106285878, 0.05726768382425819, 0.04655074567667075, 0.035174542904964516, 0.06510685317750488, 0.04676762243200626, 0.01716640841082803, 0.04450385319069028, 0.01749890244432858, 0.03650094655209354, 0.025836671203640953, 0.03216867009177804, 0.00943231359789414, 0.03472094903034823, 0.0472734974298094, 0.03562377719208598, 0.02917897355343614, 0.03386502799444965, 0.03309253962444408, 0.060390139131673744, 0.00841860518059028, 0.031979335072849474, 0.006924163608346134, 0.02117657920877848, 0.015665514394640923, 0.012645207445270248, 0.011326078541709908, 0.017356362592961107, 0.06344052044940846, 0.037455591040530374, 0.07866529920803648, 0.018177885296089307, 0.021271029587036798, 0.046334489780877314, 0.01273836606248681, 0.009433679997787943, 0.027568857451634746, 0.07536463346332312, 0.04166150053164788, 0.11974685585924558, 0.024862371252051423, 0.042009558462138684, 0.0524186622351408, 0.030909326060542038, 0.09077564972851958, 0.03207669806267534, 0.0531525792820113, 0.037108265927859714, 0.006905256230051496, 0.030344662788723196, 0.1132199325199638, 0.12911879510751792, 0.12382831184991769, 2.4502459721905843, 5.527591620172773, 12.157494970730372, 24.899981362479075, 41.93679060254778, 51.04678916931152, 55.21444027764456, 78.62351540156773, 89.33512932913644, 89.6526689529419, 90.90048898969377, 92.78191525595528, 103.2760088784354, 86.75698634556362, 83.29081494467599, 80.72200339181083, 89.7770972933088, 84.18171296800885, 78.90414619445801, 79.73672798701695, 87.43132986341203, 76.88397135053361, 85.51797662462506, 92.7113493510655, 89.9955278124128, 85.22929981776646, 83.87535994393485, 86.0838657106672, 78.68744577680314, 83.89610031672886, 85.20900412968227, 97.97108704703194, 92.28314576830182, 98.97444166455949, 98.59602887289864, 109.94865580967495, 105.38482189178467, 100.75169358934674, 77.25458826337541, 52.56333078656878, 34.71404436656407, 24.138186080115183, 5.72757727759225, 0.6974032319017819, 0.2540212007505553, 0.08960656103278909, 0.2553728696491037, 0.05985535175672599, 0.06332826361592327, 0.10464246956897633, 0.024093029588194828, 0.038259288628718684, 0.06962267336036478, 0.14399974660149642, 0.05911152131323304, 0.030312493443489075, 0.051141106324004273, 0.04874913467626486, 0.03583258955872484, 0.03394280167828713, 0.01936536398716271, 0.03019302717543074, 0.01923257638035076, 0.021134175859125595, 0.02384116587096027, 0.04777626134455204, 0.08170200804514544, 0.026008301547595432, 0.02028870765518929, 0.0057709543283895725, 0.02373762142711452, 0.02621921567645456, 0.018846125242167285, 0.05622430391875761, 0.03503502592710512, 0.03192797336461289, 0.01173181873413601, 0.003974439143868429, 0.05100154184869357, 0.008558814264168697, 0.012986725146350051, 0.009806982823647559, 0.03016817583037274, 0.04425584524869919, 0.05298159184998699, 0.09645508961485964, 0.04070585859673364, 0.07239561527967453, 0.008373918560599642, 0.025018341007775495, 0.05515358244468059, 0.0674885246636612, 0.038707559396113665, 0.030952521599829197, 0.024507748495255197, 0.051556006739182134, 0.06966265942901373, 0.05129085560994489, 0.06660091943506684, 0.014378861025241869, 0.02211245202592441, 0.041998023366821666, 0.07879592398447649, 0.025111381729532565, 0.04633246096117156, 0.005955649015959352, 0.032693615316280296, 0.028767554022903954, 0.026868164871952364, 0.06736062759799616, 0.01671558465542538, 0.026754966571128795, 0.04208354252789702, 0.042987178146306954, 0.08522832739566054, 0.048396611985351355, 0.025231280563665286, 0.06264681089669466, 0.06632177691374506, 0.02969060592087252, 0.014275350508147051, 0.030641610068934302, 0.10837939261857953, 0.022775636886113455, 0.02290287577281041, 0.013889929046854377, 0.012748774789672877, 0.06576303725263902, 0.04389349397804056, 0.02524041703769139, 0.037572027649730444, 0.05677422262462122, 0.02466490738359945, 0.04222906454067145, 0.008848643712034183, 0.027938689570873976, 0.10846488803092923, 0.01652103170220341, 0.0414789542555809, 0.005161190954303103, 0.06738899714712586, 0.018012322751539092, 0.01703140708351774, 0.016954082929130112, 0.0547776061908475, 0.04284666032929506, 0.01640357729047537, 0.047489030685807974, 0.05855385373745646, 0.04560751075457249, 0.023241887135165076, 0.04177066324544804, 0.037536051723041704, 0.023601839784532785, 0.030424997942256074, 0.06333747812147651, 0.06597421770649296, 0.0431990608839052, 0.06023012700357607, 0.029127303111766065, 0.03804412517430527, 0.0823001502347844, 0.035003681001918655, 0.0558009930620236, 0.05066176883078047, 0.048064479271748235, 0.0092934717623783, 0.06868430692702532, 0.02965937295396413, 0.02552627196668514, 0.052670605680240054, 0.04363661079800554, 0.025667907670140266, 0.15782686535801205, 0.033987897115626504, 0.3851853039647852, 6.842645466327667, 13.071546128817968, 24.993518011910574, 44.81535632269723, 65.5055318559919, 77.0360882622855, 83.9511022567749, 103.38020406450543, 110.96939482007707, 107.69929463522774, 107.44885376521519, 111.71899427686418, 116.16518824441093, 94.2605891908918, 92.69531290871757, 91.34223461151123, 102.26191929408482, 97.73450783320835, 90.52316706521171, 94.80546692439488, 99.33770043509347, 88.87718050820487, 96.52113696507045, 104.59931414467948, 104.64235128675188, 99.30452278682164, 98.05675138745988, 102.78000477382115, 90.41331604548863, 100.16477925436837, 97.83482592446464, 114.8461491721017, 108.52606078556606, 108.77557754516602, 110.17098426818848, 120.2611721583775, 120.52191025870187, 120.30154119219098, 97.60506289345878, 75.6793691090175, 54.60132081168038, 41.9602164540972, 15.22597667149135, 2.7707965544291904, 0.5650249581251825, 0.08585817074137074, 0.09429829820458378, 0.04751027222456677, 0.02693896321579814, 0.21432645432651043, 0.032282005795942884, 0.04481142293661833, 0.027965705442641462, 0.07049691144909177, 0.03741698918331947, 0.055904065924031396, 0.01413684369929667, 0.05186769179999828, 0.026884624435167228, 0.03695002477616072, 0.026665540744683573, 0.08952696208975144, 0.024373859965375493, 0.03274643587480698, 0.06146362902862685, 0.03332814733896937, 0.003560334735084325, 0.016139647524271692, 0.005336103287325906, 0.01705462994453098, 0.020134391828573177, 0.06930121739528008, 0.012319541170394846, 0.0736101386802537, 0.03147678150396262, 0.01964545645751059, 0.020940818823873997, 0.03420785781262176, 0.03155869085873876, 0.05613835049527032, 0.061596146917768886, 0.03712384509188788, 0.05299532200608935, 0.05606048181653023, 0.02636137045919895, 0.03948310795905335, 0.06680574880114623, 0.024476524010034542, 0.004680363652628979, 0.01595007671442415, 0.06306375709495374, 0.0057334169229891685, 0.03078105240794165, 0.03928005635472281, 0.016082599692578827, 0.0301761282607913, 0.06388880139482872, 0.07701873899038349, 0.04129622816773398, 0.017306641243132095, 0.018970163139913763, 0.04308339101927621, 0.028049368810440813, 0.034608933076794655, 0.020572087627702525, 0.028941415050732236, 0.04548153055033513, 0.0247719666388418, 0.03555001025753362, 0.052065847774169276, 0.03160962508991361, 0.08345420259450163, 0.06239250275705542, 0.11606599337288312, 0.14619980140456132, 0.1633713242730924, 0.11986238323152065, 0.16847901019666875, 0.21222269721329212, 0.09590059758297034, 0.12250269869608538, 0.1091630259262664, 0.14866135003311293, 0.10293566901236773, 0.14642863055425032, 0.09153869628374066, 0.1159732240651335, 0.18263491988182068, 0.14798965464745248, 0.08922832525734391, 0.1131767098392759, 0.15271675027906895, 0.1472411083855799, 0.07216998202992336, 0.14518197173518793, 0.1950883444930826, 0.23185631153838976, 0.10957942251116037, 0.1266855142478432, 0.15366695714848383, 0.1007339721545577, 0.06134869198181799, 0.1465142752443041, 0.11141174526086875, 0.14325874564903124, 0.10220749237175498, 0.16147152121577943, 0.12580934911966324, 0.132858880130308, 0.141232165108834, 0.08778221785490002, 0.14690397147621426, 0.10553620875413929, 0.12876958027482033, 0.125954664179257, 0.1540685955967222, 0.2108097430318594, 0.14260944191898617, 0.1180126696292843, 0.10361743385770492, 0.17485417239367962, 0.1423385843102421, 0.2110796778329781, 0.14858277567795344, 0.1871063978012119, 0.10456063824572734, 0.16251704868461403, 0.2602318860590458, 0.07587563140051705, 0.11417438701859542, 0.151429827192, 0.11439123323985509, 0.14118329701679094, 0.2670813985168934, 0.2601715235837868, 0.33353149997336523, 4.87643597807203, 9.82995527131217, 21.876325096402848, 41.551578998565674, 66.9467272077288, 81.73623194013322, 88.30384295327323, 114.56465680258614, 122.09086908612932, 119.53372355869838, 117.5067811693464, 119.47356605529785, 124.16098758152553, 108.63998344966343, 101.26887580326625, 101.74265956878662, 108.13700335366386, 104.56828348977226, 99.95401954650879, 104.4344264439174, 107.46408421652657, 99.6587141581944, 106.7745588847569, 114.88617774418422, 111.21976620810372, 107.12227453504289, 104.78795773642403, 110.77463681357247, 103.54260431017194, 111.00006416865757, 108.37511811937604, 121.25101252964565, 112.69949626922607, 120.15125165666852, 123.8053787776402, 137.13509477887834, 135.5346884046282, 132.63870702471053, 109.05817467825753, 79.84619685581752, 55.65892696380615, 40.062757219587056, 13.050477453640529, 2.387625549520765, 0.4096139759889671, 0.22512183790760382, 0.4980000289423125, 0.19538394148860658, 0.2235492244362831, 0.31188536435365677, 0.17508150876632758, 0.18421099388173648, 0.10238072914736611, 0.24248963381562913, 0.11142210649060351, 0.10654279509825365, 0.12701800997768128, 0.13882166945508548, 0.07772627459572894, 0.1318214950816972, 0.09888527635484934, 0.10567485381449972, 0.08399739023298025, 0.235947741993836, 0.17016815527209214, 0.09380078954356057, 0.16241142792361124, 0.0782303379050323, 0.09316248486616782, 0.12203597516885825, 0.1226975739534412, 0.17077845680926526, 0.12535257291580948, 0.1811517644673586, 0.05374765110069087, 0.12627958745828696, 0.1171727789832013, 0.11204601265490055, 0.07246403196560484, 0.1153287650751216, 0.1087051233542817, 0.1241024671388524, 0.14325027753199848, 0.1895607675292662, 0.1620396857282945, 0.15470640494355134, 0.18415707748915466, 0.12643109075725079, 0.13282200853739465, 0.15916693130774157, 0.11376109812408686, 0.1567011350499732, 0.11368296481668949, 0.09987066526498113, 0.11685766732054097, 0.11679408858929362, 0.15898369971130574, 0.19081011334700243, 0.17198721266218595, 0.10495028698018619, 0.09540333997990404, 0.16984363911407335, 0.2513409602854933, 0.07364511716046504, 0.11607499074723039, 0.061699657434863706, 0.26977721814598354, 0.15195096922772272, 0.1361460837402514, 0.10926467725741011, 0.12774822222334997], [0.10031339579394885, 0.07906023373029061, 0.023880712588184645, 0.03101526912567871, 0.04023772032399263, 0.013803990042236234, 0.024298544274643064, 0.04626835636528475, 0.043402716384402344, 0.039062928541430404, 0.021789644079815065, 0.06684917504233973, 0.09466807943369661, 0.0429792766060148, 0.007420907645220203, 0.09503840349082436, 0.011101149272040596, 0.012162715612378503, 0.03578612008797271, 0.05357025829809053, 0.029277568084320853, 0.021132742453898703, 0.043328260736806054, 0.011569996613876095, 0.009098625342760767, 0.04625805959637676, 0.02700549187803907, 0.03694185521453619, 0.011981738448542143, 0.03012841028560485, 0.05813932990921395, 0.04260110189872129, 0.07142347137310676, 0.012571579610396708, 0.04487774634201612, 0.033609783476484675, 0.0796767845749855, 0.0350125969520637, 0.03416806512645312, 0.0190136708053095, 0.014202027165863131, 0.038841417391917536, 0.04384529763566596, 0.03567238404814686, 0.04160841195178883, 0.02113539891849671, 0.0427998956958098, 0.008299507865948337, 0.02909278603536742, 0.08540682960301638, 0.007436572474294475, 0.009099182589644832, 0.005138346376562757, 0.05619118123182228, 0.05170942011422344, 0.03518363188153931, 0.02177357467423592, 0.014983685088476964, 0.041372719420386214, 0.044671542942523956, 0.004752966475539974, 0.1984015359942402, 2.1148006234850203, 7.346108027866908, 26.45034854752677, 53.06362540381295, 72.89963803972516, 76.68011815207345, 96.48203250340053, 93.74244812556675, 91.52613258361816, 87.03913184574672, 73.99267305646623, 72.43993132455009, 82.08794975280762, 74.8056400844029, 58.10249376296997, 58.32286630358015, 84.61804594312395, 85.95507390158517, 89.93655150277274, 79.59835461207798, 88.01252583095005, 86.68557970864433, 85.72139208657401, 88.68436104910714, 81.85449722834996, 89.14459582737514, 85.30052580152238, 89.32606192997524, 93.21191842215401, 77.4267576762608, 87.70048223223004, 95.74801090785435, 70.3958546774728, 93.91459669385637, 80.54984787532261, 74.74965844835553, 80.75314521789551, 68.96679088047573, 88.58542564937046, 86.292770249503, 93.53157029833112, 93.5201335634504, 97.27475942884172, 101.15264633723667, 101.39510372706822, 87.34767355237688, 56.79937301363264, 41.235696520124165, 24.988237380981445, 11.400061420031957, 0.24802713096141815, 0.1518566528601306, 0.18201197045189993, 0.06804217531212739, 0.04698843129777482, 0.04921709652990103, 0.07364983976419483, 0.11094855690108878, 0.08295862097293139, 0.052869351979877265, 0.07674972021153995, 0.04193758964538574, 0.043503064928310256, 0.041470523457974195, 0.03974884602108172, 0.059955266038221974, 0.030752011109143496, 0.062083755752870014, 0.07141614998025553, 0.06422178566988025, 0.05580563763422625, 0.01875698270409235, 0.07484056694167, 0.0060381486962017205, 0.024485825028802668, 0.07030017700578485, 0.0447067623026669, 0.08394754505051033, 0.030501709718789374, 0.015269361902028322, 0.03303738829812833, 0.04951076309329697, 0.04477617982774973, 0.022453134280762503, 0.040356877858617475, 0.01743250440007874, 0.035498797827001126, 0.02255832586836602, 0.06091933537806783, 0.09775377849915198, 0.06085681516144957, 0.020209154513265406, 0.05700638677392687, 0.029745468869805336, 0.0130644903484998, 0.01499519813140588, 0.04024252435192466, 0.020228667484064187, 0.0957980030881507, 0.018046130758843253, 0.027052952009918432, 0.057685939595103264, 0.018304167448409965, 0.023727217788941095, 0.036600616560982804, 0.0381182076276413, 0.08595088576631886, 0.042364897073379586, 0.03191892510013921, 0.047788281592407396, 0.08347291659031596, 0.03613396088725754, 0.08921613198305879, 0.09951321980250732, 0.0576228154823184, 0.008082614995406141, 0.01869074920458453, 0.027884997094848325, 0.04126027938244598, 0.039139236589627605, 0.03024904363389526, 0.019970293223325695, 0.009192529500329068, 0.018523324081408124, 0.06870465619223458, 0.04163899352507932, 0.02000386543971087, 0.024431788196255053, 0.018081979460215995, 0.04171083681285381, 0.023924310159470354, 0.014520481461659074, 0.04105366886194263, 0.024766974317442094, 0.04744782664680055, 0.05650643877951162, 0.020027413997533064, 0.03182759089395404, 0.04776688738326941, 0.03505347190158708, 0.01588932068885437, 0.0028271960951055265, 0.01671921821045024, 0.02930792574105518, 0.03724215106506433, 0.010027615270311279, 0.031756270078143904, 0.04924621246755123, 0.08493941397007022, 0.05089438420587352, 0.06396389486534254, 0.0174296358932874, 0.026639177962871533, 0.040858763070510964, 0.023703620037330047, 0.06615946455193417, 0.05259616360334413, 0.03802291416962232, 0.06920430902391672, 0.02413992483967117, 0.06338933176760163, 0.05244685536516564, 0.03606028894760779, 0.03782907707084503, 0.04461549934265869, 0.09952343175453798, 0.017242770741826723, 0.04423482084114637, 0.021717656603349105, 0.1051830244915826, 0.05638504207932523, 0.06999795750847884, 0.13216152255024227, 0.05636671145579644, 0.08220077878130333, 0.713788278400898, 6.555413016251155, 17.838679994855607, 42.96949093682425, 72.59268052237374, 94.06861741202218, 91.30629852839878, 105.98964173453194, 103.73820999690464, 103.57954788208008, 101.95711571829659, 84.62174933297294, 87.37495218004499, 98.49863597324916, 94.64838899884904, 70.26080254146031, 67.24926567077637, 106.97296469552177, 113.66370473589215, 110.1907935823713, 112.14713532584054, 117.67854063851493, 104.96462263379777, 108.71942915235246, 108.2428869519915, 108.16439315250942, 111.80996704101562, 109.60638754708427, 116.34038012368339, 115.4470293862479, 99.2496737071446, 115.15763691493443, 115.63076060158866, 88.809129851205, 116.0192482812064, 113.34148202623639, 102.4015919821603, 102.34353283473423, 92.83469377245221, 100.36884784698486, 97.13073022024972, 104.80748217446464, 104.79956817626953, 107.02078914642334, 113.1411863054548, 115.99299103873116, 109.37076718466622, 82.66941670009068, 63.43993663787842, 43.52337006160191, 23.323360409055436, 2.7052044740745, 0.0926855154601591, 0.25462610114898, 0.05348395203639354, 0.08435956508453403, 0.0668137419436659, 0.05667697498574853, 0.01515726961328515, 0.0779332345617669, 0.11197581820722137, 0.07589214015752077, 0.02322596700729004, 0.00820709902992738, 0.05233699036762118, 0.020351098950154016, 0.043761430707361014, 0.06227209671799626, 0.05632917829123991, 0.04146931905831609, 0.10981103365442582, 0.03800935025459953, 0.05300765438005328, 0.03560141607054642, 0.04008738071258579, 0.017147755483165383, 0.03680097438128931, 0.08250431463654552, 0.041415633367640634, 0.05179851854752217, 0.05524149004902158, 0.03348554710724524, 0.01658396582518305, 0.018507258068504076, 0.04233780317008495, 0.004466352435494108, 0.035194681824318, 0.036839888364608796, 0.02731970278546214, 0.07086555952472345, 0.0075333688873797655, 0.03482539592576878, 0.05834320932626724, 0.03486255928874016, 0.02612806297838688, 0.045946645949568064, 0.030597020140183822, 0.015784419174971323, 0.032818357194108624, 0.04171489445226533, 0.012280087751735533, 0.034542745378400595, 0.04039646698428052, 0.04183281026780605, 0.05261016856612904, 0.03856228165594595, 0.015243143308907747, 0.02477191235604031, 0.007245409651659429, 0.04163321919207062, 0.07878702839038201, 0.04758016811683774, 0.0769618981118713, 0.041752648140702925, 0.03938875766471028, 0.17257619462907314, 0.11184852503772293, 0.07266499368207795, 0.1033439299623881, 0.2223519358251776, 0.12088104071361677, 0.13483234494924545, 0.12215332101498332, 0.1442595576601369, 0.13196159899234772, 0.16146092249878816, 0.0836384112813643, 0.16595249862543174, 0.13148376106151513, 0.09378788380750588, 0.1331832062985216, 0.13132359965571336, 0.1082300538463252, 0.13923898206225463, 0.16621053192232335, 0.11117018000887972, 0.0933853496930429, 0.10766027442046575, 0.16251456524644578, 0.17928016132542066, 0.1058980104114328, 0.09028880763798952, 0.1651738796915327, 0.143584171043975, 0.18852973356842995, 0.15158164261707238, 0.14651449237551006, 0.15094052201935224, 0.19208080587642534, 0.15388862096837588, 0.09443378807710749, 0.1540091966411897, 0.07891275414398738, 0.1260862456900733, 0.18046865612268448, 0.07968017725007874, 0.08835519996604749, 0.10453636026276009, 0.10217458342335053, 0.0940759354936225, 0.10971456633082458, 0.15881673938461713, 0.13590257109275886, 0.08691509081316845, 0.17519140429794788, 0.09551664175731794, 0.16006772725709847, 0.08811809947448117, 0.12129452638328075, 0.12675416842103004, 0.17617681356413023, 0.15217152025018418, 0.10727313626557589, 0.20855989732912608, 0.11286195780017547, 0.22578632725136621, 0.3838029924247946, 4.46858149766922, 15.700983319963727, 43.781523432050435, 79.11338424682617, 100.9089104788644, 102.8590544291905, 122.1087259565081, 116.59095300946916, 114.82933453151158, 108.37873118264335, 93.19930049351284, 94.15151636941093, 101.46279307774135, 94.86738927023751, 76.81981863294328, 79.41962609972272, 111.78590542929513, 111.23875563485282, 110.57275690351213, 104.41438783918107, 112.6284578868321, 108.50929478236607, 106.26481124332973, 110.09828526633126, 103.97968769073486, 111.47310447692871, 107.33385413033622, 113.38570731026786, 115.96701867239815, 100.09945229121617, 110.52569675445557, 118.9783262525286, 93.02838870457241, 115.74751118251255, 104.14554813929966, 100.63089220864433, 104.99308245522636, 92.27157701764787, 110.7519370487758, 106.08479036603654, 114.33645016806466, 114.88353742871965, 122.88256072998047, 127.43874468122209, 130.4145747593471, 119.87111418587821, 88.2698871067592, 64.04131712232316, 42.09353848866054, 20.04395832334246, 1.960369961602347, 0.27604031349931446, 0.5065909336720194, 0.14763870276510715, 0.19929436594247818, 0.14324668129639967, 0.19139794180435793, 0.1722581381244319, 0.28252995812467163, 0.14024571089872293, 0.2347265960914748, 0.15959596900003298, 0.10115028731524944, 0.1285606593425785, 0.10715519330863442, 0.16387163528374263, 0.12184818381709711, 0.20205092802643776, 0.13601678210709775, 0.20657782868615218, 0.09329456849289791, 0.10987789649516344, 0.1541415923940284, 0.11545776815286704, 0.11290925169097525, 0.09609798341989517, 0.10629192034580878, 0.28730988449284006, 0.10051548387855291, 0.11779618981693472, 0.10050503443926573, 0.08881748587425266, 0.17512735059218748, 0.08357177235718284, 0.08637697183127914, 0.17856737385903085, 0.07897623109498195, 0.07458184832440955, 0.10149914930973734, 0.1424810223813568, 0.16107529747698987, 0.18246377977941716, 0.17253556395215647, 0.16012135866497243, 0.14434164682669298, 0.07541525217571429, 0.07710808848163911, 0.11336995661258698, 0.14862586265163763, 0.15515665364052567, 0.09174542554787227, 0.07270907810223953, 0.11730778031051159, 0.1341195846242564, 0.3101873168987887, 0.14216942553009304, 0.19092836843005248, 0.10523176366197211, 0.11898080339389187, 0.14751007966697216, 0.202798334349479, 0.15565368054168566, 0.1593369993248156, 0.22838660914983067], [0.03360372076609305, 0.009422199185272413, 0.008228862192481756, 0.011179559082458062, 0.08680105621793441, 0.08078060498727219, 0.03490815005664315, 0.00715166240531419, 0.02754243020899594, 0.03211007520024266, 0.01588467781298927, 0.02019168732554785, 0.04918211465701461, 0.0967201389638441, 0.041214508802763054, 0.05221005682168262, 0.01636265993251332, 0.037062244290219884, 0.06777705810964108, 0.03804771462455392, 0.03297373153535383, 0.059063209619905264, 0.01857792749069631, 0.028984410422188894, 0.02195977995039097, 0.048810576022203477, 0.022084113010870557, 0.00884119000485433, 0.0595897256529757, 0.036165234566267045, 0.03105228321094598, 0.02447445278189012, 0.014526971649112446, 0.044705737714788744, 0.049224557022431066, 0.010265138998095478, 0.021972678901095475, 0.05438619326534016, 0.10989473773432629, 0.04403332647468362, 0.021448215436456457, 0.07821861281991005, 0.027004511394937123, 0.05798862049622195, 0.023755758668162992, 0.023102780670991967, 0.0381429571924465, 0.0414082712626883, 0.018100776576570103, 0.051601112354546785, 0.009072283765168061, 0.03473557824535029, 0.0141788738546893, 0.10449087806046009, 0.030748743963028704, 0.10569757795227425, 0.09697847081614391, 0.09358568715729884, 0.09876520279794931, 0.1798124449061496, 10.500789080347333, 37.525101389203755, 58.55563790457589, 70.21249866485596, 81.82464776720319, 90.79976095472063, 81.46757289341518, 75.17377649034772, 69.09736837659563, 67.97250366210938, 72.40315450940813, 57.756334509168354, 80.58261557987758, 81.98778452192033, 72.63231304713658, 67.38092013767788, 90.03971140725272, 92.17239148276192, 41.678578172411235, 37.70382642745972, 31.853512695857457, 28.358268295015606, 30.69675922393799, 38.78642872401646, 40.81744623184204, 39.6826560156686, 34.21422222682408, 35.5226548739842, 37.53980030332293, 32.6378288269043, 43.844550541469026, 36.96724442073277, 36.75365332194737, 37.63334042685372, 32.872521604810444, 34.10141127450125, 35.1140730040414, 33.65189061846052, 53.82212550299508, 43.052348205021445, 72.54769788469586, 92.06247792925153, 89.51799201965332, 73.40656471252441, 79.30298668997628, 84.01528276715959, 69.34612083435059, 84.55722141265869, 92.24564634050641, 89.85956546238491, 92.6224957874843, 86.95599664960588, 62.28291566031319, 24.739983456475393, 4.221622543675559, 0.2603848821350506, 0.29643411774720463, 0.08113724977842399, 0.09805493948182889, 0.05925499075757606, 0.07594621261315686, 0.06402224887694631, 0.07184524874069861, 0.035663220432720015, 0.01773684431931802, 0.01744215147170637, 0.03188430963616286, 0.014363119012809225, 0.028707174584269524, 0.010733379051089287, 0.02051286000226225, 0.012908973514900675, 0.03564635544483151, 0.020376525353640318, 0.0011441588950609522, 0.07891864382794925, 0.030510242296648876, 0.02070014923810959, 0.02423655501167689, 0.08368282139833484, 0.03241929717894111, 0.06142904409872634, 0.041577002565775595, 0.016998699999281337, 0.02939757378771901, 0.047126180691910644, 0.03114855375939182, 0.058018543890544345, 0.0400705564367984, 0.03911840217188001, 0.008754609784643565, 0.02653444608274315, 0.061967190222016404, 0.015122357290238142, 0.03156163909339479, 0.006526472113494362, 0.06451527242149625, 0.08471398428082466, 0.03117688259642039, 0.04681530308776668, 0.002888087191552456, 0.06666872543948037, 0.024869573901274374, 0.01162461274569588, 0.05439874955586024, 0.007064843001509351, 0.041089220704244714, 0.052131244979266605, 0.04356746807960527, 0.1124442448573453, 0.011245384612785918, 0.02648171373376889, 0.05007254259128656, 0.024415455858356187, 0.06645331092711006, 0.030356106281812702, 0.027275570867849246, 0.028931596649012396, 0.01390110282227397, 0.04103492433205247, 0.08338901573526007, 0.07125879770943097, 0.0026246917716759655, 0.04937338010807123, 0.0379883326323969, 0.045136105335716686, 0.04070925127182688, 0.026888895813109617, 0.05789800892983164, 0.013436604889908006, 0.03356154302933386, 0.06132234446704388, 0.039989776842828305, 0.030772601254284382, 0.04157024774966495, 0.058628241531550884, 0.020019799138286283, 0.05690514934914453, 0.05972709506750107, 0.027749098404975872, 0.05869293984557901, 0.049282079828636985, 0.013670819063138748, 0.04983323686090963, 0.06198876763560942, 0.02952663114826594, 0.01464219028795404, 0.029785475294504846, 0.031257224535303454, 0.027849830321169326, 0.030719034307237183, 0.017346503479140143, 0.02990830031090549, 0.010556047316640615, 0.10593483450689486, 0.06173889711499214, 0.021732044938419546, 0.022398809070831964, 0.012432795450357454, 0.07119815703481436, 0.06772680580615997, 0.02198518599782671, 0.06717080064117908, 0.029545134798224484, 0.02785848164265709, 0.045734522332038195, 0.06355186126061849, 0.03602637576737574, 0.007906610645087702, 0.03720580533679042, 0.030671265441924334, 0.01612318796105683, 0.020226558936493735, 0.013690059771761298, 0.12386698834598064, 2.1648834560598647, 20.71873610360282, 58.44377885546003, 78.78834056854248, 88.1965697152274, 92.56962694440568, 99.25608689444405, 90.4916569846017, 85.70368807656425, 80.75135258265904, 83.30296039581299, 87.01122093200684, 80.19884572710309, 105.8464879989624, 112.55369526999337, 97.47997447422573, 88.48082051958356, 100.86975737980434, 100.05583844866071, 56.844553674970356, 66.16730608258928, 56.37584209442139, 42.68847451891218, 49.201976435525076, 51.45389454705374, 67.09907341003418, 54.95499801635742, 54.07100650242397, 54.30393443788801, 52.583275590624126, 49.78523601804461, 58.30557918548584, 51.506349972316194, 54.29565565926688, 63.197548730032786, 49.99178859165737, 56.814075401851106, 59.95712430136544, 55.747825690678184, 84.01594284602574, 70.62017726898193, 98.58157661982945, 113.78276211874825, 111.6412786756243, 94.22089413234166, 98.83954238891602, 98.08656610761369, 84.95569365365165, 95.18460232870919, 101.06637055533272, 97.14464051382882, 103.96595805031913, 102.83359622955322, 86.1229145867484, 43.0434684072222, 12.636565446853638, 1.3900319657155444, 0.060142005660704205, 0.1869401160095419, 0.07371907747749772, 0.053881023943956406, 0.014094195228868296, 0.07577265692608696, 0.0449980913129236, 0.03906589713213699, 0.015986985626763532, 0.055398394486733844, 0.013477115126858865, 0.017687016100223576, 0.03226926290829267, 0.008289918469797288, 0.02310660421582205, 0.041010147625846524, 0.03464418975636363, 0.03103943515036787, 0.03859170971970473, 0.0575398306495377, 0.02099236034389053, 0.015256842930934258, 0.06061750264572246, 0.07857349342001335, 0.03627191723457404, 0.01943299696514649, 0.005644683202262968, 0.024248444641541158, 0.04244708802018847, 0.06686776011650052, 0.04037814653877701, 0.03744846981550966, 0.026719238309721862, 0.04403494817337819, 0.05284183399219598, 0.02432408942175763, 0.03185519030583756, 0.039317148471517224, 0.008496568006064211, 0.03316871535831264, 0.03374780767730304, 0.018679522842700993, 0.05835985379027469, 0.08017531782388687, 0.029688271760408367, 0.037216546546135626, 0.06932999406542097, 0.036513088936252255, 0.1154092936111348, 0.042578968086412976, 0.018973934098279903, 0.07453310236866985, 0.004500526427623949, 0.055734031833708286, 0.04087756188320262, 0.02684265704426382, 0.0027231259986625184, 0.021694774706182734, 0.06239383268569197, 0.004065529501531273, 0.14213558020336287, 0.09453878458589315, 0.1406106948852539, 0.10910361340003354, 0.26991045528224533, 0.20307205537600176, 0.12548713998070785, 0.16227751225233078, 0.1417504165853773, 0.13328719857547963, 0.10555135365575552, 0.1535841758762087, 0.15995985375983374, 0.12386120722762176, 0.11851908745510237, 0.19714805111289024, 0.13802435009607247, 0.09171959371971232, 0.12177392494465623, 0.14519384609801428, 0.09091027107621942, 0.13545826636254787, 0.10814647190272808, 0.10080601221748761, 0.13457763647394522, 0.12200177700391837, 0.12330233864486217, 0.13196751581771032, 0.18171372716980322, 0.10135460778006486, 0.0935358487601791, 0.08689690607466868, 0.13586602519665444, 0.11563132383993693, 0.12832174716251238, 0.11542027230773654, 0.11123768067253487, 0.12404279676931244, 0.3858193813690117, 0.15265349724463054, 0.14494624866970948, 0.1837017262088401, 0.18826494206275257, 0.13366341910191945, 0.1559427228889295, 0.15863392847989286, 0.16042478595461163, 0.09211712024573769, 0.08769314656300203, 0.13459599763154984, 0.10750296964709248, 0.2340247466095856, 0.07323136686214379, 0.20586630329489708, 0.15102451108396053, 0.2302994265088013, 0.15752896134342464, 0.21128387616149016, 0.2643501050770283, 1.25686029451234, 18.70376546042306, 57.308804512023926, 83.69847965240479, 96.39652797154018, 106.90738064902169, 111.37924126216343, 101.84417969839913, 95.17636176518032, 88.58429309300014, 88.30677509307861, 90.0365777696882, 75.6889784676688, 103.43471963065011, 104.23071915762765, 93.88844367436, 84.76784910474504, 107.09531552450997, 106.34363855634416, 58.3043007169451, 52.063182081495015, 49.00994907106672, 40.9971718106951, 44.44051143101284, 53.656674998147146, 58.284574781145366, 56.62365307126726, 47.85523836953299, 49.89230081013271, 55.59364168984549, 47.1985502243042, 59.94444383893694, 53.166729722704204, 52.375611305236816, 55.43180077416556, 50.10708005087716, 49.69104971204485, 48.47603212084089, 47.19374554497855, 71.74886349269322, 60.31008584158761, 96.17087827410016, 115.47851167406354, 112.03885459899902, 94.82758304050991, 100.84185341426304, 102.5088026864188, 87.62697723933628, 103.85721179417202, 111.9344231741769, 113.11337961469377, 120.24213409423828, 116.6282787322998, 90.09116976601737, 40.99738720485142, 11.152132323810033, 0.8215814914022173, 0.36677795169608934, 0.1591563733028514, 0.18069709172206266, 0.20304946015988076, 0.12315726785787515, 0.15815686407898152, 0.15156599559954234, 0.12847407827419893, 0.0672972049298031, 0.16078989207744598, 0.09864890189575297, 0.13449355241443428, 0.1492170023598841, 0.0947519735034023, 0.15130417607724667, 0.1314104249966996, 0.0781052771157452, 0.1068884679781539, 0.17532033952219145, 0.17013688837843283, 0.10020024329423904, 0.0977610998920032, 0.2080280344401087, 0.11649912941668715, 0.1262114489717143, 0.09615651385060378, 0.1315378945853029, 0.08802107575216464, 0.10076823138764926, 0.14440728830439703, 0.15554463996418885, 0.19926186411508492, 0.1568410625415189, 0.16466256284287997, 0.10871498246810266, 0.1429927327803203, 0.1826729585549661, 0.11954423173197679, 0.09506331929670912, 0.11593293265572616, 0.15399677945034845, 0.1594631661261831, 0.08118161239794322, 0.16481874803347246, 0.10594297014176846, 0.18936317813183579, 0.151394461946828, 0.08058701216110162, 0.24930223396846227, 0.10556797097836222, 0.08484659037951912, 0.1791327428072691, 0.18165335112384387, 0.3616569664861475, 0.139612312029515, 0.10245128321860518, 0.10908122852976833, 0.07849529225911413, 0.1789208906037467, 0.16947420393782003], [0.06681167919720922, 0.047577423442687304, 0.049900893587619066, 0.010838702953021442, 0.037873073281454187, 0.008992930791074676, 0.041067707751478465, 0.018565218529797027, 0.05708570073225668, 0.052910756186715195, 0.01203345469132598, 0.035223180295101235, 0.026783807702096443, 0.035078604838677814, 0.0298964463041297, 0.13042797414319857, 0.02096761077908533, 0.020703343441709876, 0.05973111878016165, 0.03446062228509358, 0.025171521984572922, 0.043944485884691985, 0.02249736967496574, 0.01634871943055519, 0.022825288686103055, 0.059483500995806286, 0.05812660737761429, 0.051137649188084264, 0.059100888669490814, 0.05661965913272329, 0.006947867381053844, 0.016176720981353095, 0.060826362509812625, 0.00946129806938448, 0.05934529698320797, 0.04698469256982207, 0.06361230516007968, 0.04216935345903039, 0.051886531324791055, 0.017747767036780715, 0.050574122462421656, 0.018018237880564163, 0.03876030870846339, 0.06604160301919494, 0.014864651386493018, 0.04382033093965479, 0.08078202312546116, 0.03871430403419903, 0.020316237517233406, 0.06819596527410404, 0.07383486947843007, 0.10802349421594824, 0.018466182951150194, 0.02800021573368992, 0.0219256767803537, 0.18576215207576752, 0.21683670819870063, 3.220892825296947, 18.97114256450108, 52.151566641671316, 74.52827494485038, 77.22097287859235, 75.80022607530866, 74.92409297398159, 74.02907466888428, 53.691582747868125, 66.50294576372418, 76.67071723937988, 79.77101039886475, 58.6281076158796, 54.3439108984811, 46.673057964869905, 42.862401826041086, 38.41879258837019, 33.18634046827044, 34.08324868338448, 22.799012865339005, 87.55220767429897, 117.2184726170131, 31.961647510528564, 27.794138840266637, 55.81939908436367, 44.97616195678711, 37.773214612688335, 29.53134134837559, 34.065492561885286, 37.778575147901265, 32.147421496255056, 42.049618925367085, 36.5849232673645, 25.924397706985474, 40.92252036503383, 41.30405984606062, 32.41736943381173, 35.08782270976475, 37.00720003673008, 35.51478603907994, 34.6112631389073, 21.958398955208914, 25.087139776774816, 25.202634470803396, 38.85160630089896, 40.1043004989624, 45.655928543635774, 70.49958433423723, 64.51681014469692, 84.28675583430699, 78.95747361864362, 76.25955063956124, 76.43830694471086, 76.34423528398786, 73.3365546635219, 76.01518249511719, 88.11039120810372, 66.121107510158, 43.960255418504985, 13.021705831800189, 0.9069093870265144, 0.29335712428603855, 0.06516473899994578, 0.03530527624700751, 0.06890401656606368, 0.03680188022553921, 0.045814874448946545, 0.005390987440478057, 0.10316065086850099, 0.015025581233203411, 0.04334000278530376, 0.027245706845340983, 0.0313950112488653, 0.0689957748566355, 0.057278710018311224, 0.05826371894883258, 0.021020522939839532, 0.05118122809965696, 0.041352329443075826, 0.014154564489477446, 0.06705122920019285, 0.04031521241579737, 0.02454794830243502, 0.07315070261912686, 0.030190981392349516, 0.015013125026598573, 0.00823986463780914, 0.010915995725164456, 0.02747372684202024, 0.023495233451415385, 0.0204484992594059, 0.06704206219209091, 0.012704389269596763, 0.056434178192700656, 0.03821892936580947, 0.05340013939089008, 0.014363466762006283, 0.04566447716206312, 0.03456331177481583, 0.0397664234707398, 0.01563787766333137, 0.014163505884685686, 0.029690853586154323, 0.03805447283333965, 0.04294643211843712, 0.021486075994159495, 0.06545247177460364, 0.04821768230093377, 0.06819371253784214, 0.05145525785961321, 0.018476612034386823, 0.04104362654366663, 0.04736561534394111, 0.04624725392620478, 0.06971761398017406, 0.015582629645775472, 0.02091984700278512, 0.026528770137312155, 0.021085742029494474, 0.007673343876376748, 0.05086742940225771, 0.055565364991447756, 0.057689983663814406, 0.0255233814075057, 0.032586006447672844, 0.024160857644996474, 0.018121422700850025, 0.007990943218049194, 0.03565608224432383, 0.05372026203466313, 0.01144710713664868, 0.009523716505749949, 0.008466674297648882, 0.07947456078337771, 0.03340466573302235, 0.05309217270197613, 0.0507764683903328, 0.029958525472985845, 0.06662225257605314, 0.010605952719093432, 0.02436229433598263, 0.051276005871061764, 0.052274191951645274, 0.017979741196281145, 0.0765768498448389, 0.08382817038467952, 0.05049401122544493, 0.019280782900750637, 0.04780166908832533, 0.02041946813863303, 0.03675545146688819, 0.032566831048045836, 0.024953232180061083, 0.07430807301508528, 0.056336167201931985, 0.029885664382683377, 0.024872367769213657, 0.029623973782041242, 0.022622313416962112, 0.011956646223552525, 0.04758862605584519, 0.011171800034519817, 0.07415912779314177, 0.04448873882314988, 0.08079456923795597, 0.043627023098192046, 0.01885975701069193, 0.04665443939822061, 0.032883571194750924, 0.0492718814473067, 0.04751580907031894, 0.030697294045239687, 0.04731358867138624, 0.052533555177173445, 0.061220177449285984, 0.42784132648791584, 7.839264239583697, 34.811913217817036, 76.19054113115583, 91.01502309526715, 88.7153708594186, 85.25438976287842, 91.81032085418701, 82.918961252485, 69.86200373513358, 88.9983570916312, 109.71005467006138, 107.50115980420793, 78.02740165165493, 80.88775961739677, 69.39467484610421, 60.09715829576765, 55.64922033037458, 49.72226102011544, 46.63510343006679, 39.72402906417847, 104.42639432634626, 123.83003098624093, 37.98634713036673, 33.558638845171245, 57.212408678872244, 50.558150155203684, 52.12258570534842, 43.12369230815342, 47.47803109032767, 47.46568761553083, 41.750196729387554, 49.21746744428362, 42.788886410849436, 37.80180644989014, 46.11239045006888, 40.31094339915684, 39.674926144736155, 40.30966145651681, 39.00863558905465, 35.100131443568635, 37.197792598179404, 23.606051342827932, 33.24068232945034, 48.325951031276155, 58.55032253265381, 63.636904171534944, 71.74430547441754, 98.49509239196777, 94.19744396209717, 110.4636423928397, 105.86580399104527, 97.63572529384068, 91.2624067578997, 90.21054676600865, 82.33279732295445, 83.25709533691406, 97.82512623923165, 86.92028290884835, 64.93527930123466, 27.34787515231541, 4.029484008039747, 0.11750558683914797, 0.12802697797971113, 0.05402203030618174, 0.012952542248448091, 0.018672296444752386, 0.03644612770793693, 0.03797042609325477, 0.07108941501272575, 0.028480024808751683, 0.023676327662542462, 0.002598837679085721, 0.04064300589795623, 0.017407705641484687, 0.06632212296660457, 0.03753474215045571, 0.021183637669309974, 0.012862767824637038, 0.09839772858789989, 0.04782969258459551, 0.04440412211364933, 0.06132414937019348, 0.04699265178559082, 0.06591777716364179, 0.04371271189302206, 0.0554905904323927, 0.03907103364222816, 0.01366694802085736, 0.005547101808977979, 0.013444480136968195, 0.07345016047890697, 0.014701565494760871, 0.006941992115961122, 0.03507257266236203, 0.05204059609345027, 0.0696479623605098, 0.04348320760098951, 0.04519476808075394, 0.0745998430731041, 0.044309042394161224, 0.028872591243790727, 0.03996047430804797, 0.014927091875246592, 0.028219706545184766, 0.07099688319223267, 0.027112608808758, 0.08638835764889206, 0.006808357612629021, 0.038615648435162644, 0.03315854751105819, 0.024746448633127978, 0.04688007943332195, 0.022619068323235427, 0.03910817664914897, 0.02434715113070394, 0.10810360884560005, 0.07062868973506348, 0.013472336543990033, 0.057305111815886836, 0.14810067654720374, 0.12048926816454955, 0.11285118944942951, 0.07338633068970271, 0.17157136569065706, 0.12745601790291922, 0.27132178097963333, 0.13541032107813017, 0.10739054996520281, 0.19494974693017347, 0.13307882047125272, 0.11360895700220551, 0.11803280854863779, 0.0879439263205443, 0.20507317728229932, 0.19763665060911859, 0.09352230520120688, 0.1373649769063507, 0.18989806728703634, 0.16834611232791627, 0.06656011233904532, 0.1071142301495586, 0.1250805210854326, 0.14414887502789497, 0.10478906705975533, 0.16155238901930197, 0.17101336563272135, 0.19558520854583808, 0.09872548814330782, 0.10275648148464304, 0.14215681834944657, 0.13943365375910485, 0.08909112547657319, 0.0882676418072411, 0.1568094699510506, 0.11153445153364114, 0.09813848749867507, 0.1256086520318474, 0.10341396156166281, 0.09021861997566052, 0.09578367921390704, 0.13775266467460565, 0.18514422380498477, 0.22713914965944632, 0.11640934566301958, 0.14965119691831724, 0.13378670891480787, 0.12804759187357767, 0.07452841369169098, 0.15316858674798692, 0.12981840542384557, 0.24343640729784966, 0.07669127120503358, 0.16976115639720643, 0.08319808955171279, 0.3731378875672817, 0.366569885717971, 5.795418620109558, 31.52081557682582, 78.74051611764091, 102.36341163090297, 101.33690561567033, 94.86417920248849, 96.00087669917515, 91.89385904584611, 73.04539040156773, 87.52847262791225, 98.1897121156965, 98.39420454842704, 74.44409057072231, 72.34827068873814, 62.70258685520717, 57.142360414777485, 47.76994228363037, 46.12029750006539, 45.094656535557334, 31.347951344081334, 96.34942613329206, 129.49061720711845, 47.29838194165911, 39.42059775761196, 71.69172150748116, 62.79320526123047, 53.76655381066458, 44.03995125634329, 50.22155162266323, 54.84855508804321, 44.21840878895351, 61.916544096810476, 52.51410627365112, 40.97176224844796, 60.24473108564104, 57.051575251988, 46.87144293103899, 48.548477513449534, 51.985497747148784, 48.71281978062221, 51.07708331516811, 33.47814049039568, 34.27334444863455, 43.51112733568464, 56.249562059129985, 55.7994647026062, 64.70533561706543, 90.92129189627511, 85.62871701376778, 104.48705210004533, 100.79659979684013, 94.48312609536308, 95.30659879956926, 96.04546328953334, 92.5092887878418, 96.67985466548375, 112.18925530569894, 96.6262423651559, 68.37629127502441, 22.160035678318568, 2.5844821291310445, 0.331527623214892, 0.20437527687421866, 0.20453171990811825, 0.0980904268633042, 0.13500545280320303, 0.18463286624423095, 0.10997633835566895, 0.16529446893504687, 0.10069894617689507, 0.11001227357025657, 0.16063035492386135, 0.08468005074454205, 0.19656406316374028, 0.11017311351107699, 0.13383283572537558, 0.09142474989805903, 0.097129037736782, 0.2084425650537014, 0.12042320599513394, 0.09973634247268949, 0.1734694724104234, 0.15762306057981082, 0.18471119632678373, 0.10724976751953363, 0.11648588441312313, 0.0859388146283371, 0.15496599887098583, 0.12571393352534088, 0.11261847229408366, 0.09379647406084196, 0.0741682473037924, 0.13207538931497506, 0.15034555537360056, 0.15220940964562552, 0.14570361588682446, 0.13101340058658803, 0.15582699195614882, 0.10818241390266589, 0.15939616757844174, 0.10641185819570508, 0.15652205608785152, 0.08947081331695829, 0.08659556867288691, 0.1292488702705928, 0.11177877163780586, 0.193311247708542, 0.11904873831995896, 0.2283711385514055, 0.13903144534145082, 0.10850299455757652, 0.1347380421523537, 0.08282549918762275, 0.13297417680067675, 0.15596525025154861, 0.1459499376692942, 0.09167190627860171, 0.07430582706417356, 0.13109536761684076], [0.048379960735993724, 0.04195920777107988, 0.02202689045641039, 0.06362799967506103, 0.041372441221028566, 0.04093369369262031, 0.018204775638878345, 0.018570054788142443, 0.07182895032955067, 0.027899461765108362, 0.023805558049519147, 0.01867779257840344, 0.04675982267196689, 0.017353019111656716, 0.03223484082679663, 0.07938983211559908, 0.03318998064579708, 0.08055455783115965, 0.05139228641720755, 0.00930828757451049, 0.009307282494514115, 0.06392587654824768, 0.013615859422965773, 0.026093496708199382, 0.025323211880666868, 0.022841726196929812, 0.02859940965260778, 0.02354164524669094, 0.023559141272146786, 0.10129178900803838, 0.03257175042693104, 0.04818120765100632, 0.052445080996091874, 0.026336405459525328, 0.03540712435330663, 0.042207300529948304, 0.052718815593315024, 0.03045866684988141, 0.018101092095353773, 0.04589674987697175, 0.01882194564677775, 0.039960800004856925, 0.02107695160832788, 0.04337013991815703, 0.1051486838342888, 0.02141292143746146, 0.03269019549978631, 0.09539987266595874, 0.012404787221125193, 0.06617059252624001, 0.016610416816547513, 0.11707440497619764, 0.01149359017810119, 0.042436129679637294, 0.7630228336368288, 8.46512496471405, 37.70561211449759, 53.54554898398263, 73.43967982700893, 73.69731903076172, 74.90258135114397, 73.74033532823834, 68.34797736576625, 64.34266744341168, 73.81300653730119, 71.632814679827, 46.87056745801653, 33.19827747344971, 31.914455345698766, 33.96829768589565, 15.86639734676906, 29.102750403540476, 32.29528611046927, 35.56152309690203, 30.43448904582432, 48.1885712487357, 22.95176206316267, 18.302251645496913, 60.27394131251744, 62.274445806230815, 57.59893349238804, 42.408232825142996, 42.03371449879238, 34.00530726569039, 45.937778745378765, 41.404892104012625, 45.198031834193635, 40.06576926367623, 41.4221271106175, 45.211924757276265, 34.31590911320278, 42.932912145342144, 55.32548291342599, 53.41205671855381, 42.13439737047468, 55.846761090414866, 65.9885150364467, 72.05744688851493, 89.3519092287336, 62.817204339163645, 26.783221108572825, 25.199744020189556, 27.55948427745274, 19.532348564692906, 9.404286043984548, 19.498990263257706, 28.574042865208217, 33.17404563086373, 52.892856052943635, 62.346220697675435, 66.73291724068778, 73.79945755004883, 78.10861914498466, 71.11381203787667, 77.67166083199638, 82.87643827710832, 75.88500104631696, 54.53718546458653, 12.8592734507152, 0.8873231751578194, 0.32627193523304804, 0.19075330639524118, 0.048453262874058316, 0.03298050331483994, 0.06423434535307543, 0.13364815206399985, 0.011537164000661244, 0.012741442370627607, 0.04171874853117125, 0.0550517139823309, 0.027519746783322523, 0.0211623384550746, 0.04344590513833931, 0.06204205299062388, 0.057665983880204816, 0.03670146722080452, 0.0335007802184139, 0.019220905578030006, 0.04507973264636738, 0.03289824451452919, 0.017049939571214572, 0.014519534905308058, 0.08063478102641446, 0.08943774830549955, 0.03820858849212527, 0.04816900759137102, 0.033512033721698184, 0.044205945783427784, 0.09483048000505992, 0.01845876995607146, 0.01206689459338252, 0.014083198720722325, 0.05857921737645354, 0.04952854410346065, 0.039461045392921994, 0.014188343659043312, 0.017689988083605255, 0.018103560266484107, 0.013234318333810993, 0.01714678687442626, 0.029030598300908293, 0.02678610963214721, 0.03660240450075694, 0.059598682315221856, 0.07158550553555999, 0.01916012750007212, 0.008006298465521207, 0.015035715153706926, 0.020245530775615146, 0.028570459956037145, 0.02417257764110608, 0.02917125861027411, 0.01377352381989892, 0.0745497943301286, 0.046687975991517305, 0.022295904146241288, 0.018344148428046277, 0.027981160774028728, 0.03286977318514671, 0.08481008519551583, 0.07226167925234352, 0.0615334842087967, 0.06508026817547423, 0.01765868387051991, 0.010187529010831245, 0.05421136871778539, 0.04713746812194586, 0.023283411781968813, 0.012163943760762257, 0.0370784544918154, 0.03535905693258558, 0.03693731581526143, 0.0268768552092037, 0.03797256347856351, 0.10137122510267155, 0.041551374298121245, 0.025316602949585234, 0.07026454713195562, 0.028662143607756922, 0.0015959064122788341, 0.07175389757113797, 0.036748035079134364, 0.01207716082821467, 0.022788595208632093, 0.02534999535419047, 0.05618625167491181, 0.09145042566316468, 0.06532741777066674, 0.021629263846469775, 0.013831354511369551, 0.06712178327143192, 0.058095767961016724, 0.04213835458670344, 0.026879810229209915, 0.04525319333853466, 0.023236435106290237, 0.043032867301787646, 0.028073390646438514, 0.0246580796249743, 0.07615598849952221, 0.04525472004232662, 0.060367191077343056, 0.038739233410784175, 0.03911166771181992, 0.02221990143880248, 0.013019706189100231, 0.07822017345045294, 0.25698227328913553, 0.12087135123355047, 0.11678232279207025, 2.477376082113811, 18.391961574554443, 56.69946486609322, 76.80488000597272, 86.34209551130022, 80.74719755990165, 82.42149802616665, 94.70916489192417, 90.95134285518101, 88.58195155007499, 112.23887934003557, 93.15842424120221, 67.86304174150739, 58.164332730429514, 52.85550601141793, 44.73044238771711, 22.530244384493145, 23.467228072030203, 27.591185433523997, 18.830427646636963, 23.796381609780447, 29.26155321938651, 13.129783323832921, 15.547997883387975, 55.26174708775112, 30.12634686061314, 37.14641414369856, 31.724752153669083, 22.908177750451223, 23.87340760231018, 28.970267363956996, 30.33039460863386, 33.563888209206716, 31.54500573022025, 33.5514474596296, 33.139947346278596, 20.144887856074742, 28.75815623147147, 35.76761361530849, 32.751911299569265, 25.56115456989833, 33.761519295828684, 26.787640162876674, 36.85094894681658, 58.654052189418245, 27.034464495522634, 24.530243396759033, 24.047922032220022, 26.210395983287267, 20.32314215387617, 19.68487020901271, 31.813522338867188, 39.6082547051566, 48.92525053024292, 68.83579649244035, 87.87503487723214, 84.16427298954555, 100.1876527241298, 101.4230910709926, 86.83791896275112, 84.81149768829346, 92.09704521724156, 87.82705061776298, 76.96281255994523, 27.980583327157156, 5.44795788185937, 0.2584727975939001, 0.21809748054615088, 0.08342350567025797, 0.03942266745226724, 0.04638044356501528, 0.14087632777435438, 0.049469457274036746, 0.08245931419410876, 0.03684898751920887, 0.022628328629902432, 0.03270686371251941, 0.01545032040615167, 0.0664458606126053, 0.05558695597574115, 0.014086942537687719, 0.052250490723443885, 0.05741628299334219, 0.037176268707428656, 0.0467136822906988, 0.05021203921309539, 0.02903498163712876, 0.00846165737935475, 0.03608959487506321, 0.023401729629508088, 0.016281390096992254, 0.12813770132405417, 0.03544656080859048, 0.0149746300386531, 0.019525364240897552, 0.09625538318817105, 0.02765748430309551, 0.0048137089304093805, 0.01794244721531868, 0.09473155638469116, 0.04526583783860717, 0.04939743417448231, 0.017450393975845406, 0.03717115255338805, 0.03410994860210589, 0.04556455948789205, 0.011981807150212782, 0.008581677501622056, 0.06696816972856011, 0.09460961685648986, 0.034427916897194724, 0.05905938268240009, 0.008556178155621248, 0.02350053789892367, 0.018423107851828848, 0.0548338329951678, 0.03303889125319464, 0.0365434364149613, 0.009142625794213797, 0.017295492912775705, 0.053745001421443055, 0.004183606045054538, 0.07630776999784367, 0.153938764706254, 0.10907628879483257, 0.12582120991178922, 0.13188957928546838, 0.14935479925147124, 0.18267242929765157, 0.11105009966662951, 0.16436817363968917, 0.15868741061006272, 0.16270013100334577, 0.07337373029440641, 0.12592788918742112, 0.19734550480331692, 0.11915382982364722, 0.13738089533788816, 0.14742473353232655, 0.13968562095292977, 0.20397772320679255, 0.16295360454491206, 0.09347338961171252, 0.12889904475637845, 0.14230372118098394, 0.04194532833727343, 0.21060946663575514, 0.11890186262982232, 0.16137358147118772, 0.17259827415857995, 0.07524628338537045, 0.2217717476721321, 0.15579796422805103, 0.12239078113010951, 0.19162493890949658, 0.16008986106940679, 0.12143834866583347, 0.10173063153134924, 0.16799402050673962, 0.12784955464303493, 0.12115751659231526, 0.12692746626479284, 0.10139561165124178, 0.14656713312225683, 0.11389823683670589, 0.10572224270020213, 0.30049192000712666, 0.16054956854454108, 0.11423226605568614, 0.1297090391495398, 0.13568719050713948, 0.16027066351047584, 0.10488953095461641, 0.45523579365440775, 0.19559550870742115, 0.1660473442503384, 1.6089222601481845, 14.277004735810415, 54.67029905319214, 81.94180134364537, 99.90192195347377, 92.46692562103271, 90.10721315656389, 91.99759565080915, 84.61442593165806, 81.41516263144356, 96.21165030343192, 91.41060488564628, 63.252925872802734, 44.65385586874825, 41.633807454790386, 47.96089962550572, 24.340027775083268, 40.26546049118042, 46.835155963897705, 50.17475550515311, 44.69931098393032, 64.05481052398682, 32.867452893938335, 22.342017684664043, 69.82905537741524, 79.46089145115444, 73.73218509129116, 56.28955241612026, 58.22897529602051, 46.19874961035592, 61.179034505571636, 56.081109932490754, 62.853682381766184, 54.91757501874651, 57.521596567971365, 63.67529991694859, 48.07531908580235, 61.61293561117989, 72.28486837659563, 70.02402182987758, 57.25331967217581, 69.66129112243652, 82.23319489615304, 85.88701629638672, 109.09750843048096, 80.0053106035505, 39.6839588029044, 37.14987087249756, 39.60717078617641, 31.663587161472865, 20.340681144169398, 32.34936046600342, 42.41101210457938, 48.27487482343401, 68.51540115901402, 83.76629407065255, 86.6077390398298, 96.70220007215227, 96.57921695709229, 89.00791086469377, 95.20904609135219, 103.69620813642229, 101.71112169538225, 83.06794452667236, 26.678315469196864, 2.9781108243124823, 0.5126700103282928, 0.3329563465501581, 0.18677542198981556, 0.17739266689334596, 0.19973822283957685, 0.2522530470575605, 0.11181125310914856, 0.16370244936219283, 0.16121895691113813, 0.12704957542674883, 0.13346186705998012, 0.26915106603077477, 0.20438270004732267, 0.13910432000245365, 0.1622172583426748, 0.10427206408764635, 0.09082680448357548, 0.1689694281667471, 0.13568941610200064, 0.16696688133691037, 0.16194923701030867, 0.07897121672119413, 0.1797966214695147, 0.22524904965290002, 0.1444089032177414, 0.1855460793844291, 0.11339222613189902, 0.19797548385603086, 0.17118165588804654, 0.12948573327490262, 0.08373198126043592, 0.15687245157148155, 0.1158294424946819, 0.10876193709139313, 0.09881398268043995, 0.09932674480868237, 0.09599791986069509, 0.10912393552384206, 0.07549699528941087, 0.11759249360433646, 0.11057005649698631, 0.10167863539287023, 0.11442046452845846, 0.19735750130244664, 0.16293642403823988, 0.12440927353288446, 0.07407655008137226, 0.10960902020867382, 0.12724958040884563, 0.07733454954411302, 0.11047832534781524, 0.1137065506939377, 0.11409455058830124, 0.1586990135588816, 0.1594418872679983, 0.11849232603396688], [0.03991441874365721, 0.02180316049738654, 0.023961434506678154, 0.05223397857376507, 0.050508592942995686, 0.1241909209638834, 0.028292124891387563, 0.008148628819201673, 0.04775570173348699, 0.026972586322309713, 0.011748479313350149, 0.03895109918500696, 0.04518524144909211, 0.07665836225662913, 0.07887259844158377, 0.024796573711293082, 0.029593880753964186, 0.054105999014739475, 0.05185802606865764, 0.04157294492636408, 0.07651426856006895, 0.17338211781212262, 0.03887427205752049, 0.06401212513446808, 0.03584108481715832, 0.008799572907654303, 0.16107802518776485, 0.012297919652025615, 0.07181426004639693, 0.026042743985142027, 0.05002023771937404, 0.021785537246614695, 0.07090644125959703, 0.03496876358985901, 0.01875944578621004, 0.031228356262935058, 0.016897006259698952, 0.04287933518311807, 0.09853943384119443, 0.03521939406969717, 0.10896727535873652, 0.02466561984536903, 0.07407182069229228, 0.018734809876020466, 0.11895125997917992, 0.11601527966558933, 0.03650581843352743, 0.05990091538322823, 0.08010920137166977, 0.07458693733704941, 0.12887224262314184, 0.17722576084945882, 0.7290693212832723, 19.047767298562185, 45.02961792264666, 62.88849980490548, 72.45218099866594, 72.8691771371024, 72.30729021344865, 77.11305345807756, 76.70945344652448, 64.04138660430908, 44.727263586861746, 44.28111975533621, 21.447463171822683, 24.581512417112076, 31.301853520529612, 23.63563677242824, 32.47745050702776, 37.039933000292095, 65.51330689021519, 59.47825445447649, 51.446779591696604, 64.9747450692313, 95.34864234924316, 92.01896830967495, 84.38336358751569, 52.658823353903635, 36.11161545344761, 65.79579980032784, 43.73749617167881, 57.85699653625488, 68.12600326538086, 70.99895831516811, 75.50416333334786, 59.471688406808035, 60.536256653921946, 62.866494859967915, 58.890805108206614, 62.95278453826904, 65.64222376687187, 61.18004894256592, 51.007472787584575, 54.11474193845476, 70.44069835117885, 70.03925922938755, 98.10007340567452, 104.76056098937988, 99.76830809456962, 89.40757124764579, 66.1837385722569, 62.79192679268973, 57.69137232644217, 66.83442347390312, 47.7742988041469, 57.66874551773071, 44.19602516719273, 34.82090071269444, 21.942166226250784, 23.24617808205741, 25.713474716459, 35.06461225237165, 35.54806443623134, 52.18971572603498, 59.83323097229004, 65.4464304787772, 75.78864342825753, 69.64902060372489, 72.62002863202775, 54.42135204587664, 21.782013722828456, 1.306369575006621, 0.029890610902969326, 0.16491970047354698, 0.10825963118778807, 0.006204953383920448, 0.12675591904137815, 0.05395175104162522, 0.0338918606617621, 0.04155924869701266, 0.04688827274367213, 0.014384177347112979, 0.018933495107506002, 0.021859555239123956, 0.01174536398944578, 0.08428036647715739, 0.06631670147180557, 0.03243064567712801, 0.057705623895994256, 0.01599732650044773, 0.041811297315039804, 0.026418538730857626, 0.028247263548629623, 0.0547843847556838, 0.029796515059258257, 0.08442346272724015, 0.02473734608585281, 0.0781403234494584, 0.0340794213116169, 0.02026629733986088, 0.08257648362112896, 0.039385694079101086, 0.015076925978064537, 0.04544176161289215, 0.07493975519069604, 0.0031275515294899897, 0.04439763531887105, 0.03600778390786477, 0.05406093071880085, 0.048398522061428854, 0.041201826983264515, 0.005544616250387792, 0.04028867491121803, 0.03935779271913426, 0.02655921769993646, 0.058823584978069575, 0.09396384150854178, 0.007013881628933761, 0.04458165401592851, 0.03719390383256333, 0.04888878736112799, 0.05373472161591053, 0.02119005491424884, 0.03778555244207382, 0.024881836725398898, 0.030314345844089985, 0.05309306836820074, 0.027235025007809912, 0.04152164767895426, 0.10408734649951969, 0.032771606131323745, 0.029012885144246475, 0.014564248666699444, 0.028053080396992818, 0.02251062316021749, 0.05647502939349838, 0.0337615310480552, 0.10945054835506848, 0.030833028190370117, 0.04764852373461638, 0.012175246457835394, 0.08265831494437796, 0.03396433837977903, 0.05097858361633761, 0.07894098120076315, 0.009491252845951488, 0.0329789698256978, 0.07717695300068174, 0.023718150864754404, 0.059925709052809646, 0.04715246035318289, 0.07610929850488901, 0.019873110045279776, 0.025545683157231127, 0.07104021443852357, 0.02651137758844665, 0.03579215565696359, 0.08798803109675646, 0.041008912692112584, 0.04333007921065603, 0.04640153243339487, 0.01774371279004429, 0.02021918834985367, 0.044227292495114465, 0.014436877465673854, 0.05028343466775758, 0.046405376334275515, 0.024369429131703715, 0.021942818271262304, 0.02858085511252284, 0.041666670968489986, 0.03892519950334515, 0.06303280911275319, 0.04943376633205584, 0.026664142962545156, 0.12794958427548409, 0.2738490253686905, 0.03604881152776735, 3.9902210405894687, 35.79954753603254, 68.5928179877145, 79.65504496438163, 80.78510693141392, 84.72896698543003, 93.24660382952008, 102.88065637860979, 99.33554649353027, 91.58318424224854, 70.27870804922921, 58.45152609688895, 30.680291993277415, 24.499303068433488, 29.049801656178065, 13.781513929367065, 21.024545431137085, 21.78437611034938, 31.122544833592006, 28.586811917168752, 28.580221550805227, 41.97926146643502, 64.34272997719901, 67.54395266941616, 55.42042657307216, 33.248165539332796, 18.43293683869498, 39.00328547613961, 21.752124309539795, 20.628967114857264, 33.07277911049979, 32.30992596490042, 18.87812008176531, 24.327430691037858, 18.474507910864695, 20.06062010356358, 18.96026168550764, 20.747993230819702, 22.04351612499782, 30.733056613377162, 28.274969816207886, 30.07789707183838, 43.039254324776785, 47.288637093135286, 69.45968219212124, 74.50479003361293, 86.05037539345878, 63.72623021262032, 33.38370057514736, 39.226176738739014, 32.611449990953716, 39.387159551892964, 19.192890848432267, 29.873800686427526, 25.934524706431798, 20.376313243593486, 23.893847465515137, 31.67399208886283, 43.79440539223807, 49.12181854248047, 54.29322031566075, 76.32072257995605, 83.44699655260358, 83.84077875954765, 88.05356884002686, 79.32882704053605, 85.93281882149833, 74.73613725389752, 40.65808929715838, 5.803327407155718, 0.04282368513356362, 0.3326438404619694, 0.1185015541102205, 0.051743136519300084, 0.061734018448208056, 0.04652943967708519, 0.049986908079258034, 0.03122293476813606, 0.0038397872620927437, 0.02497690117784909, 0.07479678786226682, 0.054774440824985504, 0.06148028027798448, 0.022851276577317288, 0.046168279235384295, 0.053915279784372876, 0.028294472622552087, 0.03623316949233413, 0.021930177163864886, 0.09421803429722786, 0.03486576197402818, 0.016136159854275838, 0.0099440290858703, 0.00466139944702653, 0.020455321929018413, 0.10640268440225295, 0.01162328536156565, 0.04800451713215027, 0.062057733934904845, 0.0023527760723871844, 0.012435128762652832, 0.05009221671415227, 0.03099696903622576, 0.0297021104821137, 0.05524576821231416, 0.05745697473841054, 0.08038291561284236, 0.09782528930476733, 0.008551544609612651, 0.02880782846893583, 0.016000089834311178, 0.02774498817910041, 0.05782657276306834, 0.07779056578874588, 0.05739359278231859, 0.025664414911131774, 0.051689596713653634, 0.047791541953172, 0.006134079977138234, 0.018199064070358872, 0.03311445291287132, 0.008334108062886765, 0.020778886441673552, 0.030177848347063576, 0.2775886489876679, 0.08423334400036506, 0.17077857894556864, 0.3608279052589621, 0.14279027150145598, 0.25596026384404724, 0.10554731637239456, 0.10440121644309588, 0.18220877274870872, 0.16819384906973156, 0.10103896686008998, 0.17767302399235113, 0.12040726042219571, 0.12666671882782662, 0.2323194524007184, 0.16321175997810705, 0.1390958790268217, 0.15467455450977596, 0.15947763249278069, 0.08552536967077426, 0.12803240625986032, 0.3059048924062933, 0.1174885556101799, 0.18292776202516897, 0.1894371655902692, 0.1655011507017272, 0.2761371268757752, 0.11460395396820136, 0.13683153981609003, 0.12180996872484684, 0.1296931750008038, 0.11175167094916105, 0.21630694876824105, 0.1527548296643155, 0.12892917171120644, 0.08334294320749384, 0.10346120795501129, 0.12317257560789585, 0.32256968532289776, 0.24063199492437498, 0.1727638638445309, 0.09408284976546254, 0.1898768969944545, 0.13060830160975456, 0.21397109196654387, 0.1870809527380126, 0.162308738433889, 0.20953746273049287, 0.19322995921330793, 0.23575066828301974, 0.2205207190875496, 0.42692774693880764, 2.1708007156848907, 32.06989002227783, 68.75482913425991, 91.41191809517997, 92.01272187914167, 92.66471304212297, 90.5455402646746, 97.55097811562675, 98.66662951878139, 81.13956233433315, 56.83696276800973, 55.89227179118565, 29.352675369807653, 36.49934925351824, 43.48073591504778, 31.76107038770403, 44.301068033490864, 50.23896380833217, 83.34515680585588, 80.83523123604911, 68.3085880279541, 90.36898653847831, 116.00413594927106, 115.27784075055803, 105.60640689304897, 70.7083568572998, 52.336128166743684, 92.67479487827846, 63.73560333251953, 80.9326866694859, 91.73450211116246, 99.30503695351737, 102.4144947869437, 83.32591724395752, 85.88327121734619, 87.93226024082729, 83.26431451525006, 86.95917197636196, 94.67657784053257, 86.16695226941789, 76.06836400713239, 82.5740248816354, 100.69569110870361, 92.57595675332206, 125.33794294084821, 131.15311268397738, 125.3792291368757, 116.18829100472587, 87.29240758078438, 81.28537028176444, 76.11289501190186, 90.76888316018241, 63.9796518598284, 75.16224942888532, 61.11829335348946, 50.74663393838065, 35.95984247752598, 35.3066006387983, 40.41126149041312, 46.84372309276036, 51.3779924256461, 70.46537140437535, 79.09508269173759, 83.62444659641811, 91.75960595267159, 88.61624091012138, 99.00081702641079, 81.52685492379325, 36.466178553445, 3.1338510044983456, 0.11512287040906292, 0.3353711983987263, 0.29349543686423984, 0.15093227103352547, 0.21463113012058394, 0.10751386691949197, 0.18334079986172064, 0.07490350784999983, 0.10258464927652053, 0.12428526447287627, 0.11356922199151345, 0.10855108911969832, 0.17021638554121765, 0.17627414262720517, 0.12180706459496703, 0.14281993705247129, 0.18370264901646546, 0.15719869120844773, 0.07630245028329746, 0.12884548120200634, 0.2772850724203246, 0.11620676224785191, 0.10524804850241967, 0.1404718937618392, 0.13812987586217268, 0.18035881487386568, 0.13219185306557588, 0.11252599475639206, 0.12888391342546257, 0.1670149758990322, 0.07158904748835734, 0.12729270809463092, 0.26919891632028986, 0.11132952717265912, 0.11346807277628354, 0.1842307663921799, 0.13245022562997683, 0.14960695643510136, 0.11006181341196809, 0.094047172394182, 0.16024775616824627, 0.11560011122907911, 0.09367393063647406, 0.20748399863285677, 0.17036222985812596, 0.10656017238008124, 0.095154351554811, 0.09155432294522013, 0.1414878913866622, 0.13352054676839284, 0.12079064627843243, 0.09365147791270699, 0.11223374972386019, 0.08533816864447934], [0.024711358194638575, 0.06093338783830404, 0.021683022479659746, 0.015449565535943423, 0.03254696015002472, 0.05178989776011024, 0.01778065223645951, 0.017473386134952307, 0.024715833133086562, 0.023687153688765, 0.025559252161266546, 0.040271799745304246, 0.007235592946277133, 0.03576047485694289, 0.014742323396993535, 0.08002315634595496, 0.05292782473510929, 0.04184004684377994, 0.042373572143593004, 0.01711404586343893, 0.01101314158378435, 0.06434900420052664, 0.030399244145623276, 0.06042045607630696, 0.050020994285919836, 0.012535577390475996, 0.08609742897429637, 0.045188298249351125, 0.0587090618376221, 0.09770350583962031, 0.008024394146299787, 0.01718063898650663, 0.029503021522292068, 0.09269199546958719, 0.040107879255499156, 0.026230465787063752, 0.06520361905651433, 0.009395418256255133, 0.046436188609472344, 0.047301486999328644, 0.011821376874909868, 0.07248467300087214, 0.036495199360485585, 0.03166401645700846, 0.08173189751271691, 0.024241677951067686, 0.06382719720048563, 0.05444942933640309, 0.10439732843743903, 0.040164302834974866, 0.2683594599366188, 16.999434879847936, 56.07212591171265, 75.48951653071812, 73.26229926518032, 72.84735979352678, 69.57720402308873, 64.43056910378593, 54.491886683872764, 47.140748160226, 38.16059405463082, 39.583376680101665, 24.228087084633962, 30.19350814819336, 51.65291179929461, 49.68713787623814, 43.80739504950387, 77.3441435950143, 75.73793547494071, 53.21949086870466, 60.165000506809776, 55.65497691290719, 44.94066708428519, 37.121098382132395, 63.71730177743094, 52.429411206926616, 49.00301129477364, 47.27108941759382, 76.82083306993756, 59.779083660670686, 57.174172742026194, 61.33197825295584, 53.33130128043038, 59.20311968667166, 74.71746744428361, 60.375357219151084, 75.59324618748256, 72.84912463596889, 72.07344164167131, 69.6822121483939, 57.80833830152239, 54.0840482711792, 54.442752497536794, 60.69872638157436, 53.19193778719221, 50.50703573226929, 33.436416557856965, 52.692695822034565, 48.23934520993914, 44.80177954265049, 70.43554973602295, 54.448679310934885, 54.34028741291591, 49.64543826239449, 77.07720075334821, 66.5247631072998, 54.51715380804879, 66.5266808101109, 56.86556155341012, 40.57401956830706, 22.50410005024501, 26.82354324204581, 28.81874626023429, 25.82279941013881, 30.00181082316807, 47.326060090746196, 56.86236885615757, 59.22929355076381, 61.14167404174805, 70.15537057604108, 74.83227252960205, 50.019011633736746, 20.313812460218156, 1.583790083016668, 0.12774852077875817, 0.13903759286871978, 0.02344109144593988, 0.04044862597116402, 0.017061109953959073, 0.054019160103052855, 0.027339760280613388, 0.03653125331870147, 0.05008820317951696, 0.10911654627748898, 0.044397397831614525, 0.02760038897395134, 0.03137578835178699, 0.02277500245587102, 0.03490984978686486, 0.015751155692019632, 0.03994001308456063, 0.006978703404976321, 0.05262683677886214, 0.07007213495671749, 0.052012969540166, 0.01369917843424316, 0.039090483848537715, 0.05030496458389929, 0.008589493376868111, 0.04250015963667205, 0.030738898419908116, 0.0708026864698955, 0.09265651487346206, 0.02910605478765709, 0.028355606931394765, 0.04375230780403529, 0.033667340209441524, 0.03882383654958435, 0.007710905030502805, 0.025394256193456904, 0.0446955155847328, 0.048821687033133845, 0.04756501642987132, 0.04723762667604855, 0.04935471021703311, 0.028371277697650448, 0.023518627642520835, 0.028950456529855728, 0.005564821326905596, 0.023834051431289742, 0.04039302681173597, 0.008331906216751252, 0.04999663148607526, 0.08890099317899772, 0.04808303041915808, 0.05464746317427073, 0.04359449412939804, 0.04959707274766905, 0.08427663453455482, 0.015567043696397116, 0.013528129934067172, 0.014385203631328685, 0.019446906933028783, 0.04032250666724784, 0.05861770388271127, 0.009406536052535688, 0.03882694084729467, 0.0668727405635374, 0.01964680165318506, 0.009389383535433029, 0.013131808655868684, 0.02054660694141473, 0.014499616509835635, 0.006850670208223164, 0.015937703628359095, 0.04051275770845158, 0.039002654275723865, 0.04232078551181725, 0.045121625398418734, 0.020229010144248605, 0.07738597571317639, 0.017394165475187556, 0.08294211221592766, 0.05625802032383425, 0.04298375493713787, 0.05656305234879255, 0.04736980190500617, 0.04149975474657757, 0.008389822573267987, 0.02336061549639063, 0.0060052601038478315, 0.013192615571564861, 0.017267284515712942, 0.03188081857349191, 0.03312668350658246, 0.03518535536048668, 0.017691189090588262, 0.018045978088464056, 0.05865000214959894, 0.06912361763949905, 0.08302488670285259, 0.005380804326185691, 0.008037683254640018, 0.022262655930327516, 0.07544774043240718, 0.051503681511219056, 1.4120301795857293, 32.296508993421284, 76.98400456564767, 87.81797627040318, 82.73491736820766, 83.44823333195278, 89.85578564235142, 89.082749911717, 79.08711310795375, 69.10219737461635, 52.4411814553397, 46.492154666355674, 25.623634508677892, 18.0201130935124, 26.782729523522512, 39.38306706292288, 36.74956430707659, 46.88013860157558, 51.97030551092965, 55.98717376164028, 62.35411385127476, 55.973947865622385, 50.822643756866455, 40.295924867902485, 58.657199723379954, 54.37960032054356, 48.28175006593977, 48.59193502153669, 75.38575213296073, 65.01081316811698, 56.97437381744385, 62.217540059770855, 56.00787591934204, 57.57557364872524, 63.77816104888916, 53.78561619349888, 60.93789727347237, 59.41147531781878, 65.0365353993007, 67.92866052900041, 60.58466475350516, 61.213858876909526, 56.79366159439087, 61.58191190447126, 57.43299661363874, 55.98093427930559, 41.699287278311594, 60.4076246534075, 57.602289472307476, 46.55890948431832, 62.11051000867571, 51.972449030194966, 51.40874515260969, 49.910029138837544, 67.57500416891915, 58.801305362156455, 50.09940229143415, 57.79430988856724, 41.29202904020037, 28.979657854352677, 16.147934879575455, 23.196137155805314, 23.90329875264849, 28.334272691181727, 50.71489804131644, 69.62834971291679, 84.96223190852574, 82.86522388458252, 76.75135803222656, 79.22058800288609, 87.04168878282819, 69.64617184230259, 38.95284155436924, 5.036460808345249, 0.13591034710407257, 0.15717209263571671, 0.04238473065197468, 0.026220540516078472, 0.03621352590354426, 0.022404105036652515, 0.01837475035738732, 0.07135072563375745, 0.08107109261410576, 0.05095882806926966, 0.03808085088218961, 0.05255688999646476, 0.11127734104437487, 0.03466379263305238, 0.05249997787177563, 0.09903392980673484, 0.020434462066207613, 0.027258926403841803, 0.019099072919094136, 0.07661647628992796, 0.014661499698247229, 0.027072219011772956, 0.015871437898437892, 0.06996005454233714, 0.048560155888221095, 0.016646662460906163, 0.038263553221310885, 0.02368396457417735, 0.06329705779041563, 0.016018713924235532, 0.02423911987404738, 0.0378661386535636, 0.03741584585181304, 0.027555222290435007, 0.005905601121152618, 0.0214442290432219, 0.06590776877211672, 0.08934673640344824, 0.08200754557869264, 0.01942058147064277, 0.07646633684635162, 0.0406557250368808, 0.07149397116154432, 0.03600426231111799, 0.022604474731321846, 0.07663062374506678, 0.038020919276667495, 0.03976006559761507, 0.008480238212671663, 0.08162928944719688, 0.054893533898783584, 0.042046752359185896, 0.1592372411063739, 0.20947598745780333, 0.17078666708299092, 0.08544841701430933, 0.11866670953375952, 0.11278317988451038, 0.08347216341644526, 0.1645370474351304, 0.20304042207343237, 0.1310093022350754, 0.12710423820785113, 0.10809832984315497, 0.08643537334033422, 0.07050779515079089, 0.07453466299921274, 0.12542931522641862, 0.16000793475125516, 0.09693737873541457, 0.1052915629531656, 0.10440933172191892, 0.08073773514479399, 0.1302592767668622, 0.11815569124051503, 0.16499982188854898, 0.2070908554430519, 0.11591507361403533, 0.1924631196473326, 0.17441902788622038, 0.1349445203585284, 0.19746955457542623, 0.05326565375019397, 0.10551070940813848, 0.06377307046204805, 0.22096526809036732, 0.10307355411350727, 0.09146064440054552, 0.1296029705554247, 0.11718071784291949, 0.10627134037869317, 0.14695505159241812, 0.10339205166591064, 0.1126666482804077, 0.14076407094086918, 0.1542057410946914, 0.28145686856337954, 0.0940813569884215, 0.1321212447115353, 0.16813465367470468, 0.15563928202858993, 0.1550621065710272, 0.772370386336531, 27.30792648451669, 79.54809829166958, 102.53996535709926, 93.04731559753418, 89.55630438668388, 90.16668278830392, 83.89748995644706, 69.31179673331124, 61.25593716757638, 49.67591306141445, 51.67898144040789, 30.786853040967667, 43.58427102225167, 70.32462869371686, 63.078248160226, 61.03092670440674, 102.00147301810128, 105.57469531467983, 79.04219995226178, 84.40607030051095, 80.8452227456229, 69.08237416403634, 57.44790397371565, 85.72856262751988, 73.6861185346331, 67.89574691227504, 71.23131997244698, 104.32662514277867, 79.63517311641148, 83.65977123805455, 94.01032202584403, 82.0169461114066, 91.01255648476737, 114.91115651811872, 89.45900181361607, 116.01161915915353, 104.66563470023019, 109.10681206839425, 103.88398320334298, 89.60146767752511, 82.74847330365861, 85.16680077144078, 91.75372777666364, 80.00196852002824, 79.82397651672363, 55.22230911254883, 74.01979187556675, 69.71730055127824, 66.75041280473981, 98.22922652108329, 79.03910800388881, 79.15666457584926, 69.24774823869977, 110.91387176513672, 94.90661185128349, 77.66012682233537, 93.34224578312465, 77.2848059790475, 56.03225367409842, 31.580667359488352, 39.29752779006958, 41.600091321127756, 35.740064007895334, 42.44752141407558, 63.31104755401611, 75.92988640921456, 78.80772604261125, 79.09803567613874, 89.17488302503313, 99.57896968296596, 75.89315128326416, 37.6160672051566, 3.107815235853195, 0.28067079931497574, 0.2593602128326893, 0.12569326534867287, 0.10326730300273214, 0.174996963303004, 0.09957301909370081, 0.2077808984156166, 0.13557916773217066, 0.1100374607901488, 0.21299299730786256, 0.14815782276647432, 0.08727398834058217, 0.1571536229125091, 0.11402139094259058, 0.14196704567543098, 0.1648905641798462, 0.10165724796908242, 0.16087244264781475, 0.12443782628646918, 0.1697605321449893, 0.09239417287920203, 0.16633630517338002, 0.1248303045119558, 0.1638772671243974, 0.13824335405869143, 0.10991755686700344, 0.12890360451170377, 0.11691956328494207, 0.16984974592924118, 0.16866495593317918, 0.08717621144439493, 0.06816775857337884, 0.13760376695011342, 0.1475490140063422, 0.08595205963190113, 0.0870435374921986, 0.137386201481734, 0.1364441370325429, 0.22376149733151707, 0.11922641949994223, 0.19181058609059878, 0.09653411858848163, 0.16289598335112843, 0.16020685407732213, 0.18162379413843155, 0.09808556855257068, 0.08325403476400034, 0.09156781222139086, 0.1575344574770757, 0.13940473459661007, 0.14531956506626947, 0.12117822548108441], [0.02650267368049494, 0.036196250401969464, 0.05414942864860807, 0.03326135574440871, 0.028028970351442695, 0.03200727375224233, 0.08537628195647683, 0.017873048349948864, 0.034271097276359797, 0.029367650393396616, 0.024174180680087635, 0.014112716690371079, 0.010686170825335597, 0.05247768460373793, 0.04640454852155276, 0.04867504543757864, 0.062011959962546825, 0.060648660973778794, 0.00851345165366573, 0.06335192413202353, 0.04341204624090876, 0.029176266198711734, 0.01713684294372797, 0.0767947274393269, 0.05745246248053653, 0.04130538160513554, 0.020584608295134137, 0.003211385803297162, 0.07422784981983048, 0.020208803371393254, 0.017818122636526823, 0.024440848335091556, 0.036513458737837415, 0.033841231771345646, 0.012200823835363346, 0.03963727790064045, 0.07273733908576624, 0.05129059437396271, 0.030268198677471707, 0.02671695334304656, 0.03093606373295188, 0.05693524916257177, 0.019390337468524064, 0.04050293252138155, 0.0389108145609498, 0.027796117489093115, 0.049863214538033516, 0.0749292311125568, 0.20295897072979383, 3.7118896671703885, 36.73901694161551, 70.10703195844377, 68.90821756635393, 68.47556018829346, 60.029385566711426, 62.75245407649449, 55.086061886378694, 45.75148711885725, 41.76882832390921, 28.485123293740408, 33.65963438579014, 35.57229280471802, 51.89470911026001, 57.87205328260149, 102.41659314291817, 74.29618426731655, 43.67007432665144, 42.91427707672119, 45.973923274448936, 35.56572675704956, 33.07887615476336, 35.36422552381243, 30.15497691290719, 46.92658730915615, 50.84473555428641, 27.820088624954224, 19.133789471217565, 15.494460276194982, 17.442842858178274, 20.171372652053833, 15.73778966494969, 13.182213561875479, 17.665682009288243, 18.454114948000225, 19.599094697407313, 25.00229706083025, 28.465680497033254, 30.273888383592876, 27.67279723712376, 27.80729178019932, 20.882392236164637, 17.670900106430054, 20.760654585702078, 18.473378828593663, 14.073949711663381, 14.71430264200483, 19.74548281942095, 20.498766558510916, 30.18999583380563, 23.786541223526, 19.84874520983015, 26.735975095203944, 27.017184325626918, 28.938265698296682, 30.383850574493408, 35.43232134410313, 41.83003153119768, 40.01875080381121, 48.55950083051409, 51.44017880303519, 69.66743332999093, 82.21072442190987, 174.58453723362513, 42.59322166442871, 22.565615926470073, 24.635491234915598, 20.804541145052227, 29.70618234361921, 45.850467681884766, 54.360534463609966, 59.39026941571917, 68.39263343811035, 67.26440579550606, 40.33491815839495, 8.019981673785619, 1.2584268961633955, 0.03972242386745555, 0.07425626008106129, 0.01953230395780078, 0.024252196940194284, 0.06616498782698597, 0.10309196955391339, 0.013383477294285382, 0.031316962758345265, 0.009573760159712816, 0.02636305152970765, 0.033681860858840604, 0.02171689664412822, 0.013060498018083828, 0.04517729580402374, 0.08329303695687226, 0.01531218085438013, 0.08178728632628918, 0.05739377598677363, 0.09960523593638625, 0.03432350392852511, 0.04874188452959061, 0.017148260991754274, 0.056657341574983935, 0.04278023175096937, 0.055394302920571396, 0.02224427611300988, 0.014283703274226614, 0.01839262466611607, 0.015585942593004023, 0.05457844598484891, 0.010864675577197756, 0.046154508367180824, 0.05119834414550236, 0.08296499920210668, 0.085665263235569, 0.039678112138062716, 0.017174162369753634, 0.033714467859161754, 0.01483903668953904, 0.009930159830089127, 0.041182278389377255, 0.08841211548341171, 0.01546414555715663, 0.03858686837234667, 0.02783354717705931, 0.018306265817955136, 0.025941681283126985, 0.046966942093734226, 0.013160755807932998, 0.013225172529928386, 0.030808916448482444, 0.01347526696710182, 0.0321584954591734, 0.02273242099077574, 0.022404695362118737, 0.034859556771282635, 0.04794581028233681, 0.020878463151997755, 0.011895632354675658, 0.03739780021299209, 0.0214731702581048, 0.009631305866475617, 0.023018169050504054, 0.013535576855896838, 0.05773604940623045, 0.01822237514092454, 0.02364216003167842, 0.012334267076637064, 0.06500873701380831, 0.10683742857405118, 0.03810209920629859, 0.0694132638829095, 0.04934566195255943, 0.06223356271428721, 0.03439697230766926, 0.0314296470688922, 0.03191041966368045, 0.020564145375309244, 0.03472949517890811, 0.035755935457668135, 0.040217751038393805, 0.0466032371457134, 0.035725716900612624, 0.025695430746834193, 0.019657814276537726, 0.0717050294790949, 0.0623420061809676, 0.027467005952660526, 0.07016556244343519, 0.06918959159936224, 0.0568380422358002, 0.0033941354278275476, 0.12896715610155038, 0.01236043986864388, 0.023358398383217197, 0.1103853660502604, 0.07041638291307858, 0.03315667475440672, 0.14061925799718925, 11.465138248034886, 57.665351322719026, 81.71037769317627, 77.70688125065395, 82.84473364693778, 81.99387114388603, 87.15431213378906, 76.1974823815482, 62.01285307747977, 60.2203984941755, 31.37312466757638, 37.60276140485491, 16.831585509436472, 16.16120593888419, 42.09397969927107, 99.33688749585832, 79.99076107570103, 40.3324168069022, 43.89070742470877, 44.79512664249965, 35.64208051136562, 30.15979548863002, 34.835484981536865, 28.91933706828526, 45.50349201474871, 50.49837132862636, 23.867835147040232, 15.216294356754847, 11.64510006564004, 13.747806480952672, 15.375757251467023, 15.762316805975777, 12.06141528061458, 15.191131455557686, 16.487304006304058, 16.128768273762294, 23.512872525623866, 27.903916903904506, 30.546518325805664, 26.252620186124528, 26.069606372288295, 19.844322681427002, 12.30372849532536, 15.089852775846209, 11.073101775986807, 7.170236962182181, 9.484713179724556, 16.81241021837507, 16.38847804069519, 22.666241475514003, 20.925886222294398, 18.0562732560294, 21.737467084612163, 22.53140994480678, 23.58417320251465, 28.863233838762554, 37.10684067862374, 41.48910774503435, 43.32207032612392, 46.30593947001866, 45.8130134173802, 47.04180233819144, 60.678131920950754, 135.11007009233748, 30.321997710636683, 17.2162812096732, 29.871862139020646, 31.13885920388358, 45.39993953704834, 68.87717301504952, 78.46868869236538, 77.83741010938371, 78.20859677450997, 79.22892584119523, 61.202144214085166, 19.838856186185563, 4.639432055609567, 0.07931484042533807, 0.23252952684249195, 0.030829533735024076, 0.007265847974589893, 0.0956609525850841, 0.022104508077193583, 0.0459712258806186, 0.044956510686980825, 0.05269522632339171, 0.03168943437880703, 0.13308422161000116, 0.04596052538337452, 0.010802801665184754, 0.01649946446663567, 0.015886621815817695, 0.10094178028936897, 0.04102152665810926, 0.03855528935257878, 0.0511465651382293, 0.016247234340491037, 0.023025729626949345, 0.025668647273310592, 0.07282844598272017, 0.03295412526598998, 0.02886638604104519, 0.019191798122067536, 0.014644159735845668, 0.06089783260332687, 0.03475913019584758, 0.10806048794516496, 0.015064605478463429, 0.03248086744653327, 0.04176003060170582, 0.06951924426747219, 0.03576044771554215, 0.019103451166301966, 0.07155444220240627, 0.035827860169644864, 0.002786529583058187, 0.04972991972629513, 0.025323089744363512, 0.05321070259170873, 0.045151463975863795, 0.04668371818427529, 0.02556022416268076, 0.05092643480747938, 0.035922695616526265, 0.031703907530754805, 0.004194111463480762, 0.0069022189376742715, 0.13609694423420088, 0.15191394835710526, 0.1882099128727402, 0.10004775611949818, 0.11343292466231755, 0.14273954422346183, 0.13448690277125153, 0.056987713490213664, 0.11277261509427003, 0.15341602132788726, 0.08964003995060921, 0.0761741596673216, 0.07046407713953938, 0.11013623513281345, 0.11551234950976712, 0.15452972799539566, 0.2122415333454098, 0.10703514689313513, 0.1727184969931841, 0.29041263514331406, 0.08201262780598231, 0.12932876098368848, 0.14372065157762595, 0.25475589132734705, 0.11813506377594811, 0.07572611620915787, 0.12682420680565493, 0.09772974478879146, 0.08122172060289554, 0.08515573771936552, 0.18576044216752052, 0.11291659343987703, 0.11541207560471126, 0.12940139137208462, 0.10222865587898664, 0.17835869719939573, 0.16190640787993157, 0.09089290057974202, 0.12094726573143687, 0.15371723659336567, 0.1609724179974624, 0.1541236654988357, 0.1269337630697659, 0.09801010867314679, 0.11350554826536349, 0.134625731036067, 0.20033014964844498, 0.13484659418463707, 0.2981430489037718, 8.32598294530596, 60.48760536738804, 93.43408012390137, 86.50470420292446, 87.99687848772321, 78.53862231118339, 81.32192475455147, 71.13480254581997, 54.97687094552176, 50.75630235671997, 39.592072350638254, 47.07630361829485, 48.748005458286826, 68.23430483681815, 78.9032985142299, 120.379152570452, 88.43251664297921, 59.62785611833845, 64.17751571110317, 66.15637656620571, 52.418030057634624, 48.31125906535557, 53.01207324436733, 47.324757303510395, 69.34054143088204, 72.36187526157924, 41.48325736182076, 31.56236580439976, 26.553305217197963, 29.236393792288645, 33.240560735974995, 31.10258960723877, 26.131259475435527, 33.927466596875874, 35.930434226989746, 34.59707144328526, 44.7794897215707, 49.51224476950509, 50.44230284009661, 44.62806068147932, 45.536735670907156, 37.32791151319231, 30.754095758710587, 34.82033790860857, 32.27809279305594, 25.79610095705305, 26.26106572151184, 35.64267110824585, 34.12824869155884, 40.40537289210728, 38.564892360142295, 32.24969897951399, 41.17252002443586, 40.762472084590364, 43.52692753928048, 47.968434946877615, 55.36424343926566, 61.22567081451416, 58.88140419551304, 70.72746440342495, 73.32745252336774, 94.45636858258928, 100.93828746250698, 179.5782492501395, 52.36646747589111, 32.931140082223074, 37.552258423396516, 30.142282554081508, 40.92319434029715, 64.18392889840263, 74.82058565957206, 76.99594157082694, 86.49714456285749, 91.38950320652553, 66.46555055890764, 17.061190468924387, 3.1061368116310666, 0.15643688637231076, 0.2643859860088144, 0.2296093835362366, 0.10422234104147979, 0.33735083788633347, 0.24692983127066068, 0.10566827202481882, 0.0880747614428401, 0.1199360585638455, 0.09885590257389204, 0.2415924748139722, 0.14071198659283773, 0.08486046642065048, 0.16485192839588436, 0.24833613580891065, 0.1494269682360547, 0.09370953336890255, 0.14891999401152134, 0.22219045806143964, 0.09604784646736723, 0.12775301268058165, 0.11428101201142583, 0.13368069460349424, 0.15882043061511858, 0.11822860661361899, 0.07249495280640465, 0.12295148175741945, 0.13492766554866517, 0.13902672273772104, 0.12726050482264586, 0.055011337756046226, 0.11290146889431135, 0.14170229488185473, 0.14064599227692398, 0.14282206765242986, 0.1267879730356591, 0.10937630305332796, 0.12933398570333207, 0.16475415149969713, 0.1251974326691457, 0.17079022260648863, 0.15879805253020354, 0.08278562168457679, 0.14102058431931905, 0.14245652726718358, 0.12228562177291938, 0.08188211838049547, 0.12380324676632881, 0.13020783024174826, 0.04521419114566275], [0.046049335439290316, 0.035003290844282935, 0.019402586721948216, 0.054613709449768066, 0.07811862389956202, 0.021658853062295487, 0.03587475033210857, 0.016293183035616363, 0.06651211277182613, 0.07511519041976758, 0.08608809233243976, 0.059938200882502964, 0.07507147919386625, 0.042655893601477146, 0.04586576796802027, 0.042595690581947565, 0.05921756276594741, 0.009802883623966148, 0.02955432216237698, 0.0836070833195533, 0.0764315076438444, 0.03715293388813734, 0.06933547662837164, 0.06955440595213856, 0.03590191887425525, 0.07261499243655375, 0.03489124435665352, 0.03215422747390611, 0.013077022042125463, 0.042388255641396554, 0.036403142514505556, 0.018632558041385243, 0.023382628868733133, 0.03498742330287184, 0.043811906927398274, 0.042186089525265355, 0.03424852920163955, 0.05831946738596473, 0.03855456332010882, 0.05861759531710829, 0.029247047579182044, 0.025616949690239768, 0.04353754807795797, 0.06610458463962589, 0.028513323914791857, 0.07135888162468161, 0.06839673700077192, 1.6101669647863932, 17.294194834572927, 61.55138151986258, 78.53634330204555, 73.69442858014787, 74.35964911324638, 64.77940341404506, 39.45961536679949, 35.62090935025896, 36.3664093698774, 33.305397851126536, 33.39518247331892, 41.422960894448416, 35.82792050497872, 55.231661387852256, 51.21742650440761, 38.729964188167024, 37.9517867905753, 30.079575061798096, 46.52931015832083, 45.73281383514404, 32.452370984213694, 18.16964874948774, 12.527446593557086, 6.325422431741442, 5.6377036316054205, 3.4980258515902927, 1.8035902657679148, 0.46100418269634247, 0.5732330605387688, 0.6378776888762201, 0.46888837963342667, 0.8119575306773186, 0.9427946614367622, 1.0084953073944365, 0.811961439039026, 0.5571728966065815, 0.3594120740890503, 0.860430009663105, 3.188026543174471, 2.850429641348975, 1.7663250139781406, 2.671450776713235, 3.2785153218678067, 1.9626246520451136, 1.0384540941034044, 0.7924589312502316, 0.8703698962926865, 0.5569898549999509, 0.42328493669629097, 0.1875702714813607, 0.3517138228884765, 0.5743926497442382, 1.4176135999815804, 1.488548410790307, 1.661569195134299, 5.959862070424216, 10.65436337675367, 15.46469419343131, 27.718848160334996, 35.35564797265189, 30.67095708847046, 38.109535217285156, 42.636373451777864, 45.2236533164978, 27.805667638778687, 36.95089183534895, 66.14753150939941, 42.26040295192173, 36.27022545678275, 26.730635404586792, 22.77017436708723, 27.47734441076006, 33.56048011779785, 44.929397106170654, 51.79060425077166, 67.5965574809483, 61.53366361345564, 49.04914385931832, 21.2703674861363, 1.6201450122254235, 0.2401648914175374, 0.029276238155684302, 0.04027816101110407, 0.0389900878071785, 0.05117920267262629, 0.023166152449058633, 0.037973435396062474, 0.026283305005303452, 0.031553045447383604, 0.026236898299040537, 0.02875931660777756, 0.04073854023590684, 0.11718027000980717, 0.06138214375823736, 0.019557533586131673, 0.03941105432542307, 0.06052325413163219, 0.05343476503289171, 0.019874319533950517, 0.04823693912476301, 0.008440275892748364, 0.022781938780099154, 0.05273125653288194, 0.026661060717222945, 0.016946152551099658, 0.042666611062096696, 0.035504541625933986, 0.088034843227693, 0.048368568133030615, 0.013612709324141698, 0.010802531099346067, 0.02517663304960089, 0.052238572255841324, 0.009737785822445793, 0.04895326175859996, 0.012207410714056875, 0.06651280487754516, 0.11339747799294335, 0.06552573998591729, 0.0296850419337196, 0.04826626880094409, 0.033745297097734044, 0.06200125946530274, 0.024108931056356857, 0.04346465306090457, 0.023611934689272727, 0.029701204637863805, 0.01751067502690213, 0.0010761922686859699, 0.01139681666557278, 0.007739763124845922, 0.10794401740921394, 0.01690845993081374, 0.053393652596111806, 0.047868219802954366, 0.007815379067324102, 0.12316611595451832, 0.04402172013318964, 0.016892064828425646, 0.04358732540692602, 0.08160552715084382, 0.06583055827234473, 0.03868528987680163, 0.09875917062163353, 0.06401153480900185, 0.026964211503842046, 0.07560262283576386, 0.02204427621992571, 0.03911726901839886, 0.0753251766519887, 0.051805941720626185, 0.04661050086308803, 0.02442796465142497, 0.03224597219377756, 0.01139628910459578, 0.02474712038279644, 0.023522515648177693, 0.02442428020627371, 0.03186645059447203, 0.014661252032965422, 0.0107713515670704, 0.05636181921831199, 0.01111345280826624, 0.021434878830664923, 0.04536459182522126, 0.05799797070877893, 0.06184580709253039, 0.03370773000642657, 0.025917104744751538, 0.07404290152979748, 0.06718460882880858, 0.036142228836459775, 0.03935339581221342, 0.07244742142834834, 0.10363407153636217, 7.621080381529672, 34.7060261453901, 83.60513060433524, 90.27238573346818, 88.0861211504255, 91.61745970589774, 85.22264344351632, 60.19433580126081, 58.17531088420323, 53.867528506687705, 30.43526724406651, 14.245591061455862, 24.95463936669486, 29.16534846169608, 51.579055922372, 47.1226863179888, 42.31151042665754, 36.689681257520405, 26.40323802403041, 35.67372955594744, 33.10101311547415, 20.652959244591848, 7.909504447664533, 4.365596166678837, 2.496187678405217, 1.67977879515716, 0.8761137766497475, 0.12142734282783099, 0.32869596087506836, 0.7877563578741891, 0.8402979842254094, 0.717719493167741, 0.5359522295849664, 0.49192051802362713, 1.0411736624581474, 0.9641415902546474, 0.25874345164213863, 0.43012131271617754, 0.594489717057773, 2.3019818365573883, 1.410174467733928, 0.6344869136810303, 1.0598039541925703, 0.6538705964173589, 1.4684817961284091, 0.3122384739773614, 0.3767474224524838, 0.547056428023747, 0.5170986726880074, 0.5972762703895569, 1.2240718539272035, 1.5014140861374992, 0.7537788525223732, 0.9526378703968865, 0.7158074357679912, 0.1715989684952157, 1.7567137011459895, 4.196820514542716, 8.145139575004578, 18.71605508668082, 23.2666301046099, 24.367070163999283, 32.0257168497358, 39.94389091219221, 45.339403356824604, 37.435052735464915, 32.13138157980782, 35.326944964272634, 24.184551409312657, 23.653010743004934, 24.765382596424647, 33.73676981244768, 48.06185347693307, 56.16917140143258, 68.08696133749825, 69.03270844050816, 79.00197683061872, 82.40040329524449, 70.31618663242885, 38.35066550118582, 6.468909680843353, 0.05754631065896579, 0.030851874500513077, 0.07172925996461085, 0.06928626926881926, 0.023661997002948607, 0.023212515050545335, 0.011615368554235568, 0.04462675963129316, 0.012135558096425874, 0.019296479112069522, 0.06703106992478881, 0.042986139987728426, 0.06596394468631063, 0.0251951027728085, 0.05076721656535353, 0.030776580862168754, 0.03392585526619639, 0.032019263466021845, 0.020976158623982753, 0.029713119712791274, 0.04847504045548184, 0.03064619018031018, 0.07301451385553394, 0.03543533444670694, 0.015376051355685507, 0.11196374028388943, 0.0339869471666004, 0.04981061789606299, 0.021764516231736968, 0.006623352919372597, 0.023100371871675764, 0.027020063417564546, 0.04824815870129636, 0.04303491987021906, 0.044154221058956215, 0.06038833422852414, 0.07473537365772895, 0.05720633747322219, 0.02774991773601089, 0.03636306823630418, 0.0540977548142629, 0.0332354560627469, 0.034395398106426, 0.04614667807306562, 0.0254276180639863, 0.010248111161802496, 0.0482116433392678, 0.0413793012100671, 0.13756555185786315, 0.09492611273058824, 0.05987761449068785, 0.14910865388810635, 0.12936963593321188, 0.1352229504180806, 0.19632477100406373, 0.13114217296242714, 0.2085170139159475, 0.18453645998878138, 0.15746057858424528, 0.14253968851906912, 0.2699239174170153, 0.10768174326845578, 0.20350827196879046, 0.12972246057220868, 0.20928492556725228, 0.08297054283320904, 0.17611498545323098, 0.14783177311931336, 0.2444483744246619, 0.17332346524511064, 0.1847011675792081, 0.12755455475832733, 0.14725656541330473, 0.18386977219155856, 0.1287729458085128, 0.12352997357291834, 0.0887911587155291, 0.11502183654478618, 0.16449754312634468, 0.11437964386173657, 0.1153266616165638, 0.24284602754882403, 0.12509401036160334, 0.11959379192973886, 0.17787157690950803, 0.2639759880091463, 0.1674922438604491, 0.1900531125387975, 0.13318037002214364, 0.21800108786140168, 0.2404805730496134, 0.17028368264436722, 0.16680804985974515, 0.16808315286678926, 0.1466111700449671, 4.574659645557404, 29.977644988468715, 89.33941636766706, 100.1292531149728, 92.04283537183488, 92.83528436933244, 85.31601333618164, 52.164941923958914, 44.852442332676475, 47.44221312659127, 43.739719595227925, 41.16907024383545, 56.54722983496529, 50.03540938241141, 79.22816848754883, 71.80938230242047, 52.69997753415789, 52.196636131831575, 48.193660804203574, 67.09006159646171, 60.42143767220633, 43.12462684086391, 25.573866299220494, 18.517076049532207, 9.66249760559627, 8.988593561308724, 6.604859871523721, 2.6211234544004713, 1.1483008797679628, 1.1225101436887468, 1.3532657900026865, 1.9089910728590829, 3.140620721238, 2.8653207165854315, 3.305465430021286, 2.833144477435521, 2.1884695504392897, 2.6115564363343373, 3.742798294339861, 6.738109818526676, 6.3990364245006015, 4.382584512233734, 6.684306876999991, 7.658552885055542, 6.765576047556741, 2.689540846007211, 2.5260829542364394, 2.581285740647997, 2.1617984558854784, 1.43460313975811, 2.572768986225128, 2.3832646863801137, 1.7991516696555274, 3.8271211981773376, 3.732250928878784, 3.4854200822966437, 9.826770390783038, 16.58283305168152, 22.493292127336773, 37.569493430001394, 43.89123548780169, 42.63143675667899, 56.90303666251046, 66.37495299748012, 66.14092377253941, 45.0779252733503, 52.97590092250279, 86.19097914014543, 60.40246214185442, 55.24751370293753, 39.48514999662127, 32.092805181230815, 38.894351618630544, 48.48918506077358, 62.45511981419155, 67.07342066083635, 88.14588260650635, 89.56222425188336, 75.97017901284354, 36.499165126255576, 4.135365000792912, 0.36524419113993645, 0.08761132881045341, 0.1339479424059391, 0.20877324230968952, 0.15910982580057212, 0.11624694509165627, 0.11407802147524697, 0.20383064395615033, 0.07797229782279048, 0.07254445193601505, 0.11858638455825192, 0.15731936187616416, 0.1272864384310586, 0.1563733754945653, 0.11958944930561952, 0.16285923389451845, 0.18010420139346803, 0.09772694243916444, 0.11313605202095849, 0.13801789044269494, 0.2462646226797785, 0.14604137704840728, 0.22124766079442842, 0.17129746824502945, 0.10329392871686391, 0.24643615633249283, 0.07402160231556211, 0.1734768141593252, 0.10986883805266448, 0.08983209250228745, 0.0984161983111075, 0.06753095345837729, 0.17370875099939959, 0.12947153832231248, 0.11652845570019313, 0.13944886651422295, 0.20612093034599507, 0.2561324488903795, 0.10237587762198277, 0.08133878824966294, 0.12917560205927917, 0.0784275880349534, 0.15448353333132608, 0.10770887788385153, 0.13854215373950346, 0.158527032073055, 0.11075233135904584, 0.1332174316048622], [0.015964220776887875, 0.032707471001361094, 0.05331843359661954, 0.049765020342809815, 0.0655884909044419, 0.050222749888364754, 0.030159863776394298, 0.031080740969628096, 0.10769838094711304, 0.06685562112501689, 0.019970925957230583, 0.013926496995346887, 0.03666821561221566, 0.04506660977910672, 0.020864283466445546, 0.07800333401454346, 0.03731272549235395, 0.028824228660336564, 0.009298655769920774, 0.05862998536654881, 0.024200134644550935, 0.06358133003647838, 0.07204615617437021, 0.03506145825875657, 0.0681832359571542, 0.00530272233299911, 0.035438601592821736, 0.020935039401852658, 0.02446772680351777, 0.07268674751477582, 0.07639135872679097, 0.0384023577374007, 0.033301029686949084, 0.015903622510709932, 0.055825267652315755, 0.06110275696430888, 0.047683950047940016, 0.01702019089965948, 0.06923452418829713, 0.04018122889101505, 0.041717947859849246, 0.05489552200638822, 0.04291685477697423, 0.028066296562818543, 0.17749876262886183, 1.0990192613431384, 23.714990411485942, 60.19983182634626, 77.31405789511544, 71.90721988677979, 58.024086815970286, 51.50460597446987, 44.45641933168684, 46.56293249130249, 37.68029635293143, 36.95023175648281, 27.964784860610962, 35.82685743059431, 74.03377859933036, 45.152746949877056, 50.98952906472342, 35.041075229644775, 27.693466390882218, 26.594171047210693, 25.69758071218218, 22.116981165749685, 7.069618795599256, 1.5228421134608132, 0.1947033301528011, 0.2390097262603896, 0.21417553456766264, 0.21794805356434413, 0.22571246192923614, 0.22316298873296805, 0.29568392943058697, 0.09526110546929495, 0.16993965181921208, 0.2560047485998699, 0.10557436277823788, 0.06102224199899605, 0.07100684408630643, 0.0967132111213037, 0.019198407053149173, 0.10523692731346403, 0.026523389354614273, 0.02995904115960002, 0.031647076830267906, 0.060298346914350986, 0.04524119683940496, 0.10610735203538622, 0.051617163100412915, 0.041251553422106166, 0.08571790398231574, 0.030051030152078186, 0.07297324535569974, 0.045337396141673834, 0.04867455010701503, 0.044781295981790335, 0.18979506567120552, 0.06876332232994692, 0.13433936211679662, 0.08564082918954746, 0.12489967793226242, 0.4621935188770294, 0.5519808552094868, 0.6357652736561639, 0.6314274264233453, 0.18747488302843912, 0.4587186596223286, 1.703612419111388, 6.434688065733228, 14.64610607283456, 30.59749378476824, 43.653700896671836, 51.828023774283274, 56.97508600779942, 46.477400166647776, 43.31559113093785, 25.00081535748073, 17.4114283152989, 24.71575161388942, 29.206825733184814, 35.5632358278547, 47.67932735170637, 52.89675399235317, 63.74371188027518, 64.35416671207973, 52.2454263823373, 13.528206927435738, 0.0938465635159186, 0.3375601795102869, 0.04957124770485929, 0.08027449928756271, 0.08324792116348233, 0.07968768863273518, 0.005546596300389085, 0.0474503609750952, 0.07512182649224997, 0.03176385949232748, 0.01687892330145197, 0.016813354766262428, 0.053829282256109376, 0.02629824634641409, 0.020457318518310785, 0.0042095142084040815, 0.10823203516857964, 0.057542388726558, 0.02763207655932222, 0.04403684807143041, 0.026860546620030488, 0.01205463516193309, 0.008812832330087466, 0.016866185502814393, 0.05216812675020524, 0.03997549707336085, 0.03903510182031563, 0.01346647654593523, 0.03152181587315031, 0.05621821406696524, 0.010331347052540098, 0.025791913337473358, 0.039259808869766336, 0.056947381368705204, 0.017383161333522627, 0.05100019834935665, 0.04300574964976736, 0.03066860219197614, 0.08405211408223424, 0.02516829046154661, 0.045535005895154815, 0.06643053250653402, 0.02518234122544527, 0.0598171434498259, 0.005390272010117769, 0.04824130210493292, 0.03188575152307749, 0.0323262768132346, 0.034597282630524466, 0.06902239378541708, 0.007292355793262166, 0.027771756385586092, 0.05475539095433695, 0.01713083790881293, 0.046684868301131895, 0.10682338968451534, 0.05253582487681082, 0.01812120556964406, 0.07883751139576946, 0.03580946508528931, 0.01565862726420164, 0.005034189554862678, 0.056837702968290875, 0.02358324283600918, 0.007984509857903634, 0.029612075670489242, 0.07853283560169594, 0.03091790952852794, 0.05922994603003774, 0.022387894835057, 0.03402648540213704, 0.08585521232868944, 0.02235877380839416, 0.01945914431209011, 0.031053555464105945, 0.04653838276863098, 0.07615610385047537, 0.03973021005679454, 0.03693999942126019, 0.026738856453448534, 0.050520504625248056, 0.021233733909736787, 0.059371644497982094, 0.007524519942567817, 0.03317368223464914, 0.07047828566282988, 0.030303455357040678, 0.002459417392466483, 0.05053183616005948, 0.18789462479097502, 0.050956897637141604, 0.05831942667386361, 5.102862136704581, 41.51542752129691, 81.48503371647426, 92.68295206342424, 87.08760942731584, 79.12383433750698, 75.22351169586182, 70.80568722316197, 70.92706530434745, 43.2572922706604, 30.491707461220876, 15.069074187959943, 20.664705174309866, 55.663696902138845, 41.775220666612896, 45.34689351490566, 37.37086875098092, 25.5054578099932, 17.836998530796595, 13.100740722247533, 12.855726395334516, 2.645946979522705, 0.5063480181353432, 0.4259843932730811, 0.39422257617115974, 0.18392185653959, 0.33867088705301285, 0.18641549987452372, 0.09635505319706031, 0.09631359470742089, 0.012975256208197346, 0.346875895346914, 0.3562580533325672, 0.21873040444084577, 0.19818394338446005, 0.07633814122527838, 0.06721528539700167, 0.03092634371880974, 0.1512492418821369, 0.03840928218726601, 0.06002913136035204, 0.04610359788473163, 0.13080259332699434, 0.06544597140912499, 0.12735057356102125, 0.019362936528133493, 0.11483954132667609, 0.1661060375294515, 0.17355017736554146, 0.05596992114026632, 0.015170294092968106, 0.13018594070204667, 0.10599690689040081, 0.325438667088747, 0.0521774871407875, 0.0614711336259331, 0.04254395228677562, 0.07704697283250944, 0.28738579899072647, 0.5280472966177123, 0.47186421709401266, 0.6040895219360078, 0.41620686650276184, 0.13332415159259522, 0.5310012581092971, 2.9617823404925208, 10.703396814210073, 26.961876664842876, 39.57838787351336, 50.06143733433315, 52.214284556252615, 33.25725378308977, 29.731581483568462, 16.04430944578988, 14.926163639341082, 34.59361471448626, 46.40153278623308, 56.270743642534526, 70.25222846439907, 62.27613421848842, 72.7823246547154, 72.81584276471818, 72.30981240953717, 28.104349851608276, 1.2625764906406403, 0.23088663071393967, 0.05524348154930132, 0.026186221911172782, 0.04212268042777266, 0.06970953262810196, 0.038247468548693826, 0.05044130262519632, 0.023067973520872847, 0.03538179464106049, 0.02589869439335806, 0.018126700006957566, 0.06985666616154568, 0.023616942277710353, 0.05259986501187086, 0.02436917128839663, 0.02168987737968564, 0.04384591510253293, 0.0627011072688869, 0.03406082605943084, 0.010409008778099502, 0.02420632797293365, 0.02070903974319143, 0.02667961864998298, 0.019798506816316928, 0.04820456961169839, 0.024993328510650566, 0.007787889917381108, 0.04016201277928693, 0.03217690750690443, 0.0658195252929415, 0.05229472102863448, 0.03546802965658052, 0.07182920138750758, 0.07652525404202086, 0.01368995544700218, 0.05793092466358628, 0.042546656248824935, 0.02863315659176026, 0.040361013529556136, 0.006073655585558819, 0.05641965754330158, 0.0639822424522468, 0.023512469937226603, 0.03928773058578372, 0.07425072323530912, 0.04561398058597531, 0.1337006299623421, 0.050088206572192054, 0.2292302724506174, 0.125704040484769, 0.19337778485247067, 0.10707708714263779, 0.14938375912606716, 0.11405819468200207, 0.17490701670093195, 0.17071269319525786, 0.09485379446830068, 0.14314537601811544, 0.12727564972426209, 0.1473381660346474, 0.1410413882029908, 0.16467040670769556, 0.16409836097487382, 0.07456216402351856, 0.10790209073041167, 0.12127110335443701, 0.108269307097154, 0.2765895468848092, 0.18024628662637301, 0.06927966712308781, 0.18971993827394076, 0.09694687144032546, 0.11776432581245899, 0.11811572552791663, 0.10002176822828394, 0.206099787194814, 0.13176050835422107, 0.12137785048357078, 0.10137712157198361, 0.1019376457801887, 0.0808793454031859, 0.16681935425315583, 0.10457925046128885, 0.10689616256526538, 0.19664594876979077, 0.17928850730615004, 0.14767609004463467, 0.1531695502677134, 0.304433991334268, 0.15460300977740968, 0.1981381829828024, 2.8773869148322513, 38.229714734213694, 89.34373814719063, 105.50353186471122, 89.8809381212507, 76.87096432277134, 69.883195740836, 59.51553848811558, 57.075206075395855, 48.760988167354036, 47.1633471761431, 37.378105299813406, 50.542919703892295, 103.52865927559989, 63.80123601640974, 70.10652473994664, 50.7493611063276, 41.334051745278494, 39.73210634504046, 34.98400272641863, 27.89241416113717, 9.278599211147853, 3.25348248226302, 0.9378478697368077, 0.7147091861282076, 0.6523160998310361, 0.6326530777982303, 0.6094756786312375, 0.38456379302910393, 0.3865693525544235, 0.1984277410166604, 0.46821831273181097, 0.6520714472447122, 0.2379836727465902, 0.32172081087316784, 0.16988789316798958, 0.19717526036713803, 0.08037510567477771, 0.2703598625957966, 0.08522723495428051, 0.16901085951498576, 0.17250170505472592, 0.2676560633948871, 0.14435932944927896, 0.2393052689731121, 0.10598347868238177, 0.1563083039862769, 0.23493496062500135, 0.22545208090118, 0.09453986345657281, 0.10531764583928244, 0.22925559537751333, 0.14246544321732862, 0.24479676144463675, 0.16182336876434938, 0.3673007222158568, 0.1926220596901008, 0.27581734689218657, 0.9023877925106457, 0.9469842080559049, 0.9558218824011939, 0.9975505918264389, 0.7895877510309219, 1.1473528849227088, 3.0318156225340704, 10.123020734105792, 23.70171935217721, 46.63630199432373, 63.22269426073347, 73.53179209572929, 81.75866072518485, 68.03355748312813, 60.192834990365164, 38.199316365378245, 26.599264076777867, 33.88035086223057, 39.38211515971592, 49.18770136151995, 67.0051268168858, 66.11408982958112, 80.99844442095075, 84.96706785474504, 80.13562406812395, 24.963830096381052, 0.6348744928836823, 0.5287486304129873, 0.15724902493613108, 0.15809253895921366, 0.12452214104788643, 0.26222276208656176, 0.09828668633209807, 0.24249264651111194, 0.329484934253352, 0.10442221710192305, 0.07867022537227188, 0.07069787995091506, 0.14783771708607674, 0.08571485736008201, 0.14401508149291786, 0.06584362007145371, 0.14811915984111174, 0.16641075403562613, 0.14977179973253182, 0.10452190746686288, 0.05961640564990895, 0.12907773016818933, 0.09322864881583623, 0.08014407128627811, 0.12406118506831781, 0.15605139705751622, 0.08456872350403241, 0.08647514906312738, 0.17116332187184266, 0.13734246311443193, 0.1411820078002555, 0.07219404288168464, 0.10519986573074545, 0.24427914779101098, 0.13708520334746155, 0.1808440081243004, 0.10841280368289777, 0.14998048996286734, 0.09904702553259474, 0.1267927499221904, 0.15561592685324804, 0.13483098787920816, 0.104716029550348, 0.19081430669341767, 0.14059787057340145, 0.2211583113031728, 0.09525677641587597], [0.023312809311651757, 0.07331599374966961, 0.014222978630901446, 0.011355332730870162, 0.04895180630098496, 0.033754426786409955, 0.02165951972295131, 0.07163693848997355, 0.05750691491578307, 0.016448732099628875, 0.03060819221926587, 0.02251655185994293, 0.04943661617913416, 0.04412248258345893, 0.05004274133326752, 0.01816719158419541, 0.023893223077590977, 0.0462406687438488, 0.012295666915763701, 0.012573249654711356, 0.021813479318682636, 0.036747509214494906, 0.0370794553309679, 0.09077846564884696, 0.014877742023340293, 0.032537589581417184, 0.04874095154393997, 0.03950005437114409, 0.04084206771637712, 0.024053009592794945, 0.10580457613936492, 0.056937223699476035, 0.03746984027592199, 0.041028630919754505, 0.04268182720988989, 0.028133590273293, 0.08107290430260555, 0.041637317543583255, 0.0428642072448773, 0.04700592053788049, 0.009374908687147712, 0.03634296324370163, 0.1016671477950045, 0.6649648611034665, 15.383697305406843, 54.434967041015625, 77.33718844822475, 74.60766506195068, 68.19526290893555, 43.73742321559361, 50.150641781943186, 46.802329199654714, 24.704813412257604, 21.289792912346975, 40.343346323285786, 62.866606031145366, 83.87158012390137, 55.612624168395996, 30.92063365663801, 33.200146538870676, 27.03862646647862, 18.704015595572336, 9.166527373450142, 1.825559492622103, 0.1166204921901226, 1.0113591594355447, 0.39266400837472504, 0.08605837928397314, 0.03731947013043931, 0.11957115600151674, 0.21769987259592327, 0.2297203918652875, 0.08494252166045563, 0.14583578093775681, 0.5244814051049096, 0.12711863672094686, 0.10347404583756413, 0.15132435570870126, 0.2697061619588307, 0.1765838802925178, 0.6450530609914235, 0.6428903798971857, 0.4256987300302301, 0.33246869700295584, 0.06563510626022305, 0.26683088338800837, 0.46559053659439087, 0.23808062183005468, 0.25628042380724636, 0.15572481815304073, 0.5827218570879528, 0.7966378927230835, 0.11988427277122225, 0.14433881055031503, 0.3810157062751906, 0.37904277071356773, 0.1842171006969043, 0.11472064842070852, 0.08337833559406654, 0.0920479843126876, 0.118405514263681, 0.13185753886188778, 0.043971447473657985, 0.43173009210399216, 0.3461518170578139, 0.24037105749760354, 0.115687615105084, 0.1276022693408387, 0.017382464138790965, 0.020480907788234096, 0.09707238006272487, 0.6545061394572258, 2.631030717066356, 17.48475786617824, 23.816418477467128, 29.4019068309239, 43.55058962958199, 47.880231039864675, 64.18072577885219, 58.22710623059954, 30.58854103088379, 27.883180005209788, 33.00254324504307, 38.32081256593977, 54.9003712790353, 50.4579119682312, 56.104546206338064, 63.649133001055034, 73.02572005135673, 42.02612359183175, 7.572867700031825, 0.022587319669712867, 0.16910649224051408, 0.0735767072598849, 0.02959488159311669, 0.04125853215477296, 0.0928661889795746, 0.012817813183314033, 0.009774682860422348, 0.04363251244649291, 0.01578101801819035, 0.06091533202145781, 0.054547460683222325, 0.03186401465375509, 0.046453677849578004, 0.03144117198618395, 0.07472391320126397, 0.02128145358126078, 0.04917955318731921, 0.0033448156859127005, 0.015412005229986139, 0.0587295943072864, 0.057979874179831574, 0.014933339486430799, 0.01865472917311958, 0.08652781016592469, 0.03477109955357654, 0.04657242147784148, 0.031018278428486416, 0.05823735786335809, 0.03629426478541323, 0.014614249912223645, 0.0033079513024339186, 0.07575871981680393, 0.033535395682390244, 0.027501638380012343, 0.03463602698008929, 0.04029352982927646, 0.025918008892663887, 0.045252338384411166, 0.02641274913081101, 0.041392176412045956, 0.06773856481803314, 0.015438096597790718, 0.07379038472260747, 0.05462775851732918, 0.028724182064511945, 0.05557367365275111, 0.025535206576543193, 0.040079143297459395, 0.045144034017409594, 0.003977462441460895, 0.027132880042440126, 0.07954722509852477, 0.05830010199653251, 0.01720734273216554, 0.01919919585010835, 0.013491406770689147, 0.022463682107627392, 0.010026516891749842, 0.07880474493971892, 0.03757972223684192, 0.027508829154872468, 0.03544552604268704, 0.057201207748481205, 0.009438785973803272, 0.06727317121944257, 0.028879651400659765, 0.039607714129877944, 0.08183384739926883, 0.019432888399543505, 0.021500840916165283, 0.03656912914344242, 0.01639551459811628, 0.06797832516687256, 0.016202871720971804, 0.04311926855838724, 0.044993083724485974, 0.0038742419980865505, 0.03126883087679744, 0.01820787145490093, 0.002742782522026183, 0.08279498546783413, 0.0364111526204007, 0.05144476770822491, 0.06793934333005122, 0.020267556022320474, 0.09534310642629862, 0.022850063695971454, 3.34375239270074, 32.214794703892295, 75.04785428728376, 88.88897854941231, 90.12270763942173, 85.67094816480363, 67.25640147072929, 80.0184635434832, 69.44321496146065, 38.986404827662874, 19.336225237165177, 21.279733657836914, 36.43206984656197, 63.5242599759783, 61.14742020198277, 36.1047089440482, 33.53318064553397, 21.054789202553884, 10.420257721628461, 3.380271907363619, 0.7770273621593202, 0.17558993505580084, 0.9747301020792553, 0.32396022070731434, 0.050521719202931435, 0.12199326817478452, 0.23665170850498335, 0.22606517800262996, 0.24570789826767786, 0.17118476357843193, 0.216654684394598, 0.32317173587424414, 0.06947001655186925, 0.04359880621944155, 0.15542926186961786, 0.3981647832053048, 0.28567808919719284, 0.5997434237173626, 0.6556359274046761, 0.7787906846829823, 0.45554007589817047, 0.45017240249684876, 0.4004114126520497, 0.4230578988790512, 0.4153777238513742, 0.26484074017831255, 0.4170577765575477, 0.9609200145517076, 1.085876418011529, 0.09773881001664059, 0.17965606972575188, 0.28954218327999115, 0.303721122443676, 0.3175161736352103, 0.05713750688093049, 0.11608538590371609, 0.03679748331861837, 0.04339330171101859, 0.22021759035331862, 0.03984396645267095, 0.33333876888666836, 0.16032361638333115, 0.15050704670803888, 0.06659135887665407, 0.1006251283522163, 0.032224778152470074, 0.055491693051798005, 0.11123907845467329, 0.2697261380297797, 0.36639892203467234, 11.891974772725787, 22.949137381144933, 30.62299714769636, 43.70236955370222, 36.571711267743794, 40.7903482573373, 25.06406307220459, 17.118742397853307, 20.564770971025737, 39.41577223369053, 63.13407693590437, 81.28687109266008, 74.95253889901298, 71.23806667327881, 73.85579354422433, 86.03509630475725, 62.25412927355085, 17.473414931978496, 0.29238432220050264, 0.13706616365483829, 0.013182388352496284, 0.04536332296473639, 0.027045133590166057, 0.03986458034653749, 0.0004924752034379967, 0.013171328231692314, 0.00699808999862788, 0.05095182219520211, 0.05400523317179509, 0.03277803525062544, 0.012644812198621886, 0.06596292688378266, 0.034777192798044, 0.04074993623154504, 0.036493628551917415, 0.027734040016574518, 0.04235064783798797, 0.019297376474631683, 0.03784206423110195, 0.031248054134526422, 0.025345018299828683, 0.033151935187301466, 0.10178760811686516, 0.04464930395728775, 0.03044021748272436, 0.05389831301623157, 0.03481992354084339, 0.03693197235198958, 0.013629924605733581, 0.013553670840337873, 0.019665172988814966, 0.04095273677791868, 0.017524639277585914, 0.044607465488037894, 0.0416087783606989, 0.03497887376163687, 0.05724137702158519, 0.019239794296611632, 0.02296694813828383, 0.02822730613739363, 0.017102497197421532, 0.029569019230880907, 0.06620723341724702, 0.08608231121408087, 0.14453162306121417, 0.10545270144939423, 0.14238066705209868, 0.14354417818997586, 0.07271550382886614, 0.12975420244038105, 0.1440432406961918, 0.22169254906475544, 0.06679061068488018, 0.09748564860118286, 0.09935014748147555, 0.13721023020999773, 0.10336058121174574, 0.22256042249500751, 0.16551922687462398, 0.0870734133890697, 0.14246713955487522, 0.14562103817505495, 0.12630330904253892, 0.15572033982191766, 0.11924035660922527, 0.0962950164186103, 0.17144472391477653, 0.15957079535084112, 0.15950112337512629, 0.09894199509705816, 0.09956558913524662, 0.11561829596757889, 0.09574505700064556, 0.14660597246672424, 0.07669518635209117, 0.11534134511436735, 0.15632650229547704, 0.12621797647859367, 0.08247675932943821, 0.2947450540959835, 0.1976803211229188, 0.10741347766348294, 0.19943218997546605, 0.1438491525394576, 0.27915915900043076, 0.21333930801068032, 1.7712708285876682, 28.594062362398418, 79.50758334568569, 102.59703091212681, 94.5261423928397, 84.5914968763079, 61.18539210728237, 64.37444850376674, 57.49256699425833, 32.99336814880371, 29.837916714804514, 54.61841338021414, 80.95371886662075, 109.27191516331264, 78.72851657867432, 42.11510222298758, 48.634034156799316, 41.377811500004356, 27.36128864969526, 14.044610074588231, 2.95012434891292, 0.42019233692969593, 1.2401353291102817, 0.6255882797496659, 0.20084177862320626, 0.15329624632639544, 0.47365066409111023, 0.7617379054427147, 0.5827905791146415, 0.30282540193625856, 0.8191718235611916, 0.857537279171603, 0.4186328463256359, 0.3153048280094351, 0.4300428740680218, 0.8019654239927019, 0.7389192070279802, 1.2128433478730065, 1.6739033332892825, 1.4369640073605945, 1.2636994932379042, 0.9770592685256685, 0.7928625238793237, 1.1067681312561035, 1.1127319655248096, 1.0073972748858588, 0.8524783934865678, 1.942334609372275, 2.5776644263948714, 0.6144428263817514, 0.6114390875611986, 1.0835145733186176, 1.3495840047086989, 0.5743922697646278, 0.42868203137602123, 0.3188352457114628, 0.48816941359213417, 0.5766175389289856, 0.6890470460057259, 0.609255670436791, 0.8747885163341249, 0.7174519332391875, 0.7051884712917464, 0.3525959998369217, 0.2583406189722674, 0.16198362516505377, 0.15826572823737348, 0.3359980561903545, 1.693293258547783, 4.920200509684427, 26.669206380844116, 38.29392998559134, 45.04304184232439, 63.39939389910017, 66.8042960848127, 86.1973020008632, 75.9446930204119, 44.19785949162075, 39.87849794115339, 42.24742719105312, 50.554113251822336, 74.30357020241874, 69.37164156777519, 73.71974781581334, 78.91877215249198, 98.44198036193848, 64.61926133292062, 13.525095002991812, 0.17044701959405625, 0.3216066541416304, 0.17934471714709485, 0.20967322401702404, 0.14107445999979973, 0.16668465148125375, 0.17809628056628363, 0.1195669626551015, 0.13168125546404294, 0.13252991278256687, 0.16281770755137714, 0.12796086152749403, 0.09240495480064835, 0.17556865619761602, 0.14639904642743723, 0.14218553395143577, 0.13593022818011896, 0.13352180884352752, 0.12057761342397758, 0.10329354195190327, 0.12392515236777918, 0.2290929098214422, 0.11660057040197508, 0.15827449490981443, 0.22983880979674204, 0.06519550377769129, 0.16181807619120392, 0.12838339885430677, 0.14093698880502156, 0.08818702506167547, 0.11652821142758642, 0.11504451318510941, 0.1322733179799148, 0.10262163622038704, 0.11973190094743456, 0.1038506802703653, 0.1581282570425953, 0.11807041295937129, 0.16563185011701925, 0.09874534207795348, 0.09896860724048955, 0.16111146339348384, 0.0981199499219656, 0.09501906524279288, 0.15696678150977406], [0.07782735595745699, 0.044954383479697366, 0.03601008414157799, 0.020473845935027515, 0.006392044572359217, 0.02274607990070113, 0.026545392548931495, 0.08080203312316112, 0.035663464705326726, 0.034981180780700276, 0.04211167798244527, 0.028417017743257538, 0.04121491253109915, 0.039263734194849215, 0.019294974460665668, 0.019785465373258506, 0.018146686255931854, 0.012234437612018414, 0.02459671800690038, 0.04356987348624638, 0.04808081839499729, 0.043143502436578274, 0.06223745071994407, 0.05617238241913063, 0.022747905159901296, 0.005656396837106773, 0.03875919930370791, 0.005903446348384023, 0.006512469695215779, 0.019540517624201517, 0.02848494758031198, 0.03242269324670945, 0.06287287162350756, 0.01797734427132777, 0.0655541502471481, 0.08087853794651371, 0.030182832186775546, 0.09295086336455174, 0.03128273745200463, 0.07207581494003534, 0.0392619869671762, 0.2833124989909785, 10.47123839173998, 47.32687997817993, 69.27117756434849, 80.84266580854143, 69.6616107395717, 64.92335619245256, 53.17476184027535, 43.07419334139143, 25.562730073928833, 20.383296183177404, 35.66104909351894, 72.02739592960903, 71.87909357888358, 62.381892749241416, 36.22077512741089, 23.282666546957834, 26.825229917253765, 13.159532904624939, 4.328499300139291, 0.5307219730956214, 0.17275120238108294, 0.0031413567485287786, 0.03590618685952254, 0.5575235092214176, 0.21071719085531576, 0.23140177450009755, 0.20570359059742518, 0.026710278254800608, 0.10219313457076039, 0.05085558557350721, 0.18061505683830806, 0.03519812538953764, 0.1229688251124961, 0.03745769110641309, 0.27137780083077295, 0.20647207221814565, 0.046430709439196756, 0.2817234785429069, 0.31601077584283693, 0.055369773879647255, 0.05427447925986988, 0.11576700370226588, 0.1736102955681937, 0.17442186416259833, 0.18373448587954044, 0.05675640429503151, 0.289983936718532, 0.26018607137458666, 0.05636785817997796, 0.08293372552309718, 0.09142450562545232, 0.07664753962308168, 0.09930330142378807, 0.062099674184407504, 0.0659170714872224, 0.02133496624550649, 0.08581533482564346, 0.023880140922431434, 0.03862258306305323, 0.06772724685392209, 0.08120139847908701, 0.08655362842338425, 0.15129102606858524, 0.11392445542982646, 0.06441888652209725, 0.12228038348257542, 0.04464694944077304, 0.043319802797798596, 0.0703098936272519, 0.07279014946626765, 0.06469100620597601, 0.5863437684518951, 6.946121079581125, 16.73960873058864, 26.62881302833557, 37.5505804334368, 41.234213079724995, 54.98405885696411, 63.158958435058594, 91.33252102988106, 37.763806751796174, 20.032386098589214, 23.68910837173462, 21.42148733139038, 39.95208978652954, 44.77786384310041, 54.46514654159546, 64.77563054221017, 61.41987296513149, 30.792894499642507, 3.5774457156658173, 0.04037753585726023, 0.016446145184870278, 0.04544981582356351, 0.037927939623062096, 0.022154850286564658, 0.015886094254840697, 0.007872599925446724, 0.04805628256872296, 0.047542628166931014, 0.06404648614781243, 0.028294438695801154, 0.033199558167585304, 0.04743967404855149, 0.03018891525321773, 0.031344121122466664, 0.0565093123753156, 0.02917499394555177, 0.004579010876893465, 0.04490254001159753, 0.03701877733692527, 0.012800368896153356, 0.04403685824945569, 0.043097782747021744, 0.06001320614346436, 0.058553975873759816, 0.025823702703097036, 0.034931060791547806, 0.06477757370365517, 0.02203813547800694, 0.05681165740160005, 0.038092653998839, 0.014222714850412948, 0.09939595538058452, 0.010469160907502686, 0.019708110684795038, 0.024549578482817327, 0.05202663862811668, 0.03323086916602083, 0.04971689524661217, 0.030885546800813506, 0.0647936753396477, 0.06364585193140165, 0.07046628237834998, 0.08117430457579237, 0.09219333329903227, 0.03634097852877208, 0.0493810204123812, 0.05631456943228841, 0.018740110930853655, 0.009838070753695709, 0.07870295790157147, 0.0571167708507606, 0.022536717920697162, 0.08400286601058074, 0.024589389828698974, 0.0632066090724298, 0.03178630203806928, 0.015022125793620944, 0.014656721115378397, 0.012078614589492125, 0.04847382927047355, 0.012949113950266369, 0.025083529563354592, 0.034220417495816946, 0.052164045362068076, 0.06777610137526478, 0.02215349321652736, 0.023442528243841868, 0.03207739016839436, 0.01988173252902925, 0.005904020134559167, 0.027575006675241247, 0.029299209958740642, 0.02450957545079291, 0.032448111168508015, 0.01890021805385394, 0.03826484243784632, 0.09963648247399501, 0.02439957983525736, 0.02224905469587871, 0.039021829675350866, 0.03387867333367467, 0.03659801098651119, 0.032703416754624674, 0.7573819820369992, 22.651321956089564, 70.15999807630266, 81.88095596858433, 95.1471654347011, 89.8063770021711, 92.21378884996686, 76.32755265917096, 44.99184056690761, 20.959614515304565, 14.027889234679085, 14.829823391778127, 40.66955729893276, 58.88210596357073, 60.04776355198452, 40.338190759931294, 20.85999298095703, 15.643209048679896, 5.866675436496735, 1.0149549607719694, 0.2354950505707945, 0.13885638330663952, 0.038065424388540645, 0.04774938117978828, 0.4861527532339096, 0.19562502498073236, 0.21568968546177658, 0.2375504688492843, 0.03602080499487264, 0.12736232578754425, 0.07074637484869786, 0.2576916409390313, 0.07840261116091694, 0.0026922863700227545, 0.07596413272299937, 0.28126736730337143, 0.31724098697304726, 0.13609587214887142, 0.1463672909885645, 0.20180843318147318, 0.0067848544318362, 0.08471795371068375, 0.11946936217801911, 0.21122793773455278, 0.12486256206674234, 0.2286677397787571, 0.04136007831298879, 0.1390825118869543, 0.2927098290196487, 0.14600971660443715, 0.10469930366213832, 0.06637093677584614, 0.01504071256411927, 0.106572643853724, 0.10019134770014457, 0.14944203171346868, 0.024272865116862313, 0.09425195426281009, 0.1011284181315984, 0.06036352698824235, 0.033462592267564366, 0.05770656027431999, 0.09620532087449517, 0.0840195579720395, 0.15815450277711662, 0.13938574918678828, 0.08721015855137791, 0.060886453571064134, 0.07438697306705372, 0.020331278942259293, 0.030693199086402143, 0.06797851515667779, 0.21868088495518478, 3.376365065574646, 14.495524712971278, 28.583395140511648, 40.97210965837751, 43.24651561464582, 48.89532463891165, 36.92594085420881, 59.73075199127197, 22.55507377215794, 20.53764694077628, 29.95489658628191, 35.24207271848406, 68.4928889955793, 69.23085716792515, 70.06631551470075, 72.20105920519147, 76.21627031053815, 49.64536530630929, 11.130619832447596, 0.02123317920735904, 0.059874357522598336, 0.04284836345219186, 0.01873510843142867, 0.03875445295125246, 0.015253384098676699, 0.028125444460394125, 0.01922049336800618, 0.039267612022480795, 0.031963291112333536, 0.02013699909938233, 0.034618324001452754, 0.01815230622222381, 0.04028388784666147, 0.05446157172056181, 0.041491266273494275, 0.09480540135077067, 0.054812774660864046, 0.05661354213953018, 0.03423251238252435, 0.046575820938284905, 0.023249177993940454, 0.07383234532816069, 0.05130730329879692, 0.021237140155530403, 0.04866655696449535, 0.057060316737209044, 0.057859210297465324, 0.05147592942895634, 0.04080321480120931, 0.04105366886194263, 0.013941717383983945, 0.076002870287214, 0.016417092011709298, 0.03215452263663922, 0.01556758482807449, 0.027687653666362166, 0.03998882010845201, 0.051283622426646094, 0.025184437898652892, 0.04464417423254677, 0.018835965876600573, 0.016070978084046925, 0.11127455905079842, 0.16809786350599357, 0.1528544250343527, 0.09520176758191415, 0.27415689027735163, 0.15758514404296875, 0.15749848155038698, 0.2537231338875634, 0.23374747005956514, 0.09156744581248079, 0.1436473833663123, 0.08720506275338785, 0.1443899856614215, 0.12546431406268052, 0.10591110613729272, 0.04495466167905501, 0.09466170120452132, 0.1073326166453106, 0.07716257484363657, 0.09884497137474162, 0.11672390092696462, 0.1903278242264475, 0.15263160770492895, 0.12958116243992532, 0.08737234199153525, 0.07749855824347053, 0.07950592945728983, 0.0958418839478067, 0.09121529292315245, 0.1958925441971847, 0.0798147985977786, 0.13020191341638565, 0.14194633678666183, 0.13823221251368523, 0.16605632805398532, 0.1383685301989317, 0.1060685059055686, 0.23226351397378103, 0.06259726426963295, 0.14384694051529678, 0.08183162180440766, 0.4183603466621467, 19.473658868244716, 74.45725045885358, 96.0121397290911, 102.52520738329206, 86.7483080455235, 83.98241083962577, 72.04079900469098, 54.105740547180176, 34.14176293781826, 30.116584641592844, 49.81611033848354, 86.35995932987758, 90.13851479121617, 80.25670337677002, 48.537287439618794, 32.21323135920933, 38.211809226444785, 20.85628264290946, 7.196479439735413, 1.0974245412009103, 0.6037807070783207, 0.2598329074680805, 0.2033178207597562, 0.7397406686629567, 0.6471487028258187, 0.6607819912689072, 0.5598640750561441, 0.14487371327621595, 0.327146973993097, 0.17202857615692274, 0.3358270653656551, 0.16256218483405455, 0.24813279243452208, 0.22401176818779536, 0.652664378285408, 0.4481395115809781, 0.3743463855768953, 0.7000739457351821, 0.8320000980581556, 0.29279472732118195, 0.5322476997971535, 0.39425235028777805, 0.34912230766245295, 0.6733074762991497, 0.5716708557946342, 0.20840833974736078, 0.8786346156682286, 0.7712751222508294, 0.26003842215452877, 0.31959827191063334, 0.7796616522329194, 0.37007327058485573, 0.29596028317298206, 0.20930273032614163, 0.2425163138125624, 0.1530013278658901, 0.3216121367045811, 0.2528705139245306, 0.148251867720059, 0.15580726015780652, 0.18299678260726587, 0.19801619595714978, 0.2553443711783205, 0.350437797073807, 0.28162867363010136, 0.25322506204247475, 0.32276200928858345, 0.15842977086348192, 0.21100520182933125, 0.15464298906070845, 0.33982594364455765, 1.4388171136379242, 12.167695794786725, 28.97290767942156, 44.77208989007132, 57.77488967350551, 59.53715433393206, 75.81612355368478, 86.7796652657645, 105.8144359588623, 48.388446603502544, 29.181784425462993, 31.00324078968593, 30.945271968841553, 53.20787000656128, 63.88937391553606, 66.96511908939907, 82.03670678819928, 85.11349419185093, 49.893033845084055, 8.123290964535304, 0.0763580087306244, 0.14666778700692312, 0.1750356126576662, 0.1330628070448126, 0.3338742415819849, 0.135398853836315, 0.15176589201603616, 0.12145571916231088, 0.07253559026867151, 0.1617113562034709, 0.10052545834332705, 0.14314426322068485, 0.09973983692803554, 0.22272134386003017, 0.2499735222331115, 0.14830851182341576, 0.1865055686128991, 0.11457189997392041, 0.13513969417129243, 0.14315830889557088, 0.14197966642677784, 0.10812821931072644, 0.10678304399230651, 0.12786240609628813, 0.09978335137878146, 0.15862750953861646, 0.1607442945241928, 0.15419413814587252, 0.1020507507824472, 0.1420182886400393, 0.12391456722148828, 0.06703993159213237, 0.23977541231683322, 0.11945108244461672, 0.11795689405075141, 0.09741204112235989, 0.12847453967801162, 0.09027519622551543, 0.12050220104200499, 0.10034764824169022, 0.18841299840382167, 0.11953541077673435, 0.12507682985493115], [0.0152597589351769, 0.030917390449238673, 0.059498571258570464, 0.04319965799472161, 0.04226399891610656, 0.009803303467508937, 0.010917032187405442, 0.0359108789291765, 0.05693566985428333, 0.05726053885051182, 0.02587543930193143, 0.014567449655649918, 0.041722589039376805, 0.04602373092036162, 0.06135494128933974, 0.009990607122225421, 0.06561036008809294, 0.03610137763566204, 0.011459714317295169, 0.014238614622237427, 0.04731751060379403, 0.01913146278820932, 0.01752996408114476, 0.03120734542608261, 0.015896251924069862, 0.01948042486661247, 0.021298238841284598, 0.015584253040807588, 0.015082445860441242, 0.0017745409339633106, 0.045590510059680255, 0.01751750617820237, 0.03321289477337684, 0.03833550168201327, 0.04509646531992725, 0.057143905466156344, 0.04325691277959517, 0.07529453401054655, 0.07514242681541614, 0.12029531571481909, 4.004141756466456, 30.32843174253191, 66.81242547716413, 78.04743330819267, 66.53668621608189, 59.401928492954795, 45.93612854821341, 33.13922473362514, 30.533865656171525, 40.05113983154297, 77.87684113638741, 129.7728113446917, 106.47568907056535, 63.16699750082833, 33.791285378592356, 20.381110974720546, 18.539244277136667, 26.29129385948181, 6.595541902950831, 0.16076675403331006, 0.03077412795807634, 0.04940876231661864, 0.12392151542007923, 0.0757222417742014, 0.06019890760736806, 0.0939184000183429, 0.0655807148931282, 0.04428304432492171, 0.0938177393483264, 0.03430337179452181, 0.2015146818011999, 0.16992563328572682, 0.04075212111430509, 0.12005803201879774, 0.1795279894556318, 0.02041324766884957, 0.08933881789978061, 0.2506658450833389, 0.2240855520857232, 0.2820433670920985, 0.29344270112259047, 0.24985667850290025, 0.6037129621420587, 0.17985796103520052, 0.32367021484034403, 0.15376558899879456, 0.4944938485111509, 0.10305836171443973, 0.30541680859667913, 0.07463197170623712, 0.41938577592372894, 0.05184271153328674, 0.1704439390450716, 0.03554621046142919, 0.07722569895642144, 0.07979443576186895, 0.04420855135789939, 0.18573221511074475, 0.03872707745592509, 0.09974052903375455, 0.11819185715700899, 0.19213681215686457, 0.1479992355619158, 0.03509007886584316, 0.019081146023901444, 0.02481207314745656, 0.07275579523827348, 0.0978275148996285, 0.05205960185932262, 0.05811515370649951, 0.14267003509615148, 0.10758595447987318, 0.12070950706090246, 0.06456652217145477, 0.2621585726737976, 0.2962883141423975, 4.286416232585907, 10.698252541678292, 25.11249201638358, 33.11886651175362, 48.71056161608015, 48.82554735456194, 52.40883411679949, 50.524010181427, 26.23402680669512, 22.159893240247452, 19.60138760294233, 24.603626796177455, 43.80791616439819, 50.79126569202968, 54.70318487712315, 65.54978493281773, 55.45097780227661, 23.86425335066659, 0.576625084238393, 0.1353239028581551, 0.004939700160840792, 0.04047622199037245, 0.06933010263102395, 0.06665275272514139, 0.10725151135453156, 0.07487133171941553, 0.013770126055793037, 0.01330051027304892, 0.0259609007875302, 0.015415608250935162, 0.02977814372362835, 0.04606324540717261, 0.06626182834484748, 0.02771408430167607, 0.030817035119980574, 0.044054601940193346, 0.03939432843721338, 0.008395008277148008, 0.06246051232197455, 0.015388032587777292, 0.049083034973591566, 0.016449829630021538, 0.00754286498496575, 0.026373307586514523, 0.03114970387624843, 0.012371365130612893, 0.07766722169305597, 0.03216329948710544, 0.06575073541275092, 0.06237574972744499, 0.024304601896022047, 0.014903198960902435, 0.029014537377016883, 0.07221891119011811, 0.03150221638913665, 0.011029434057750871, 0.09743498917669058, 0.056010243083749495, 0.04363932493808014, 0.10199975209044558, 0.035342945118567774, 0.08111308036105973, 0.040452771820127964, 0.009657871360624475, 0.077348120244486, 0.07341210144971098, 0.14368329143949918, 0.05359885176377637, 0.052050540024148564, 0.0025494074631881502, 0.04732571069949439, 0.010236390317524118, 0.04184434197044798, 0.01174634786522282, 0.02200819512030908, 0.020064736816233823, 0.005768596843284155, 0.06400777572499854, 0.019206208509526083, 0.05753954566482987, 0.0017321462780403505, 0.06171678365873439, 0.01638587091916374, 0.023387663598571504, 0.0004061946253516778, 0.019832962824563895, 0.03296754329598375, 0.020987167854660323, 0.018309724650212696, 0.0425178558299584, 0.06330676762653248, 0.003844521316100976, 0.015092347382700868, 0.007529773499949702, 0.09309183580002614, 0.034416334304426394, 0.014279246995491641, 0.06002103643757956, 0.07629873869674546, 0.20692317586924347, 11.35359013080597, 51.996534960610525, 82.15205383300781, 88.6304360798427, 84.49748774937221, 80.61823204585484, 71.21008627755302, 50.47188132149832, 49.81486313683646, 47.11525174549648, 50.762590476444785, 92.24456242152623, 81.3774061203003, 60.839378765651155, 37.876992906842915, 18.955993754523142, 9.570837838309151, 10.712587543896266, 1.8402375621455056, 0.11170839398567166, 0.09712086817515747, 0.02865396047543202, 0.0568814684769937, 0.15934979649526732, 0.055634483961122375, 0.10498323664069176, 0.02835075031699879, 0.04353558032640389, 0.12473944867295877, 0.11109110353780643, 0.1462478416838816, 0.19918328975992544, 0.06716267857700586, 0.055603783644203625, 0.2461417807000024, 0.13893079145678452, 0.21370758967740194, 0.2338742475424494, 0.3422569717679705, 0.5042399455394063, 0.16105536211814198, 0.1697197114782674, 0.5789689070412091, 0.5152051800063678, 0.7603035909788949, 1.001343656863485, 0.8927480354905128, 0.7389126388089997, 0.8298553845712117, 0.5988870039582253, 0.27019872409956797, 1.0454015327351434, 0.7436691150069237, 0.18918261996337346, 0.495685518852302, 0.23201484446014675, 0.9897169321775436, 0.6313214663948331, 0.1927422011005027, 0.19325061381927558, 0.20481456044529164, 0.24121225093092236, 0.02841432056655841, 0.1409810528691326, 0.24923771885888918, 0.13953714392014913, 0.113582704482334, 0.028906409429120164, 0.08575087399887187, 0.04948619334027171, 0.0886462711329971, 0.08493593308542456, 0.11645015275904111, 0.04689121080030288, 0.3676113826887948, 0.3313859451029982, 2.036949315241405, 9.005281397274562, 24.73180890083313, 38.40130049841744, 50.48001071384975, 48.34102862221854, 36.48857954570225, 22.79522783415658, 16.728863341467722, 19.64195987156459, 24.98121796335493, 38.850609234401155, 65.76642976488385, 76.13303089141846, 70.00223922729492, 75.23890890393938, 72.42321395874023, 40.164166178022114, 3.1459766966956, 0.1419851082776274, 0.02218728934946869, 0.13046221302023955, 0.05405495961063674, 0.04194951489833849, 0.05342017313731568, 0.05359292136771338, 0.008163220714777708, 0.01983463710972241, 0.04705905322251575, 0.012449061631092002, 0.032945714824433835, 0.033310407040906806, 0.02970681612246803, 0.08563485808138337, 0.010025540649491762, 0.048774060660174916, 0.054273451279316626, 0.04124407257352557, 0.053671200560139756, 0.009946424314486129, 0.06755963513361556, 0.02960917493328452, 0.014849496306851506, 0.026539302697139125, 0.050065010852579556, 0.07176248782447406, 0.06835231331310102, 0.08578714848096881, 0.08754728189004318, 0.01363901951948979, 0.026742571432675635, 0.024916503079501644, 0.032085990599755726, 0.013043331082112022, 0.03573700772332294, 0.055927037727087736, 0.08444636328411953, 0.04301751544699073, 0.02299066972253578, 0.024640685379771248, 0.1039095703246338, 0.16850978854511464, 0.15669916729841912, 0.08692550632570471, 0.12131230400076934, 0.1687965645853962, 0.15463890427989618, 0.1058050918259791, 0.18285076187125274, 0.11709427248154368, 0.10653090716472693, 0.09217054809310607, 0.09396055739905153, 0.0794648238058601, 0.08346338995865413, 0.10015441503907953, 0.1276305913925171, 0.2040151104863201, 0.09816640921469245, 0.11037334919508014, 0.0896567590534687, 0.127188647964171, 0.14275585620531014, 0.1587674506008625, 0.0616232476064137, 0.16205952609223978, 0.20777875424495765, 0.10039054522556917, 0.08704446708517415, 0.09643032308667898, 0.11015874213938202, 0.09618455091757433, 0.17884941372488225, 0.10242005025169679, 0.10076363092022282, 0.19702543983502047, 0.13442785665392876, 0.23825147694775037, 0.23680538311600685, 0.24835806606071337, 8.521348919187274, 51.44306925364903, 94.43365492139543, 99.00243595668248, 85.2125963483538, 81.11868994576591, 62.92464433397566, 44.431572573525564, 39.821894441332134, 56.4230238369533, 92.78475012098039, 140.35441752842493, 123.95411191667829, 88.09925324576241, 49.4898750441415, 30.392598356519425, 27.145609617233276, 35.24900007247925, 9.844790543828692, 0.729509066258158, 0.3460757125701223, 0.07196171927664961, 0.5208207358207021, 0.3813426787299769, 0.31472424630607876, 0.14667316100427083, 0.17655163630843163, 0.1491240837744304, 0.26401659154466217, 0.26373627515775816, 0.5693858755486352, 0.4438750818371773, 0.3113037241356713, 0.2960079163312912, 0.6029243958847863, 0.4065977521240711, 0.558806048972266, 0.6714269572070667, 0.9244715017931802, 0.8427820737872804, 0.9248291168894086, 0.8102087559444564, 1.3021445274353027, 0.9377478808164597, 1.2953098884650638, 1.5524321028164454, 1.6081820598670413, 1.0613625219890048, 1.3063353768416812, 0.6828285711152213, 1.1937526294163294, 1.2819120245320457, 0.7841906834925924, 0.3056842328182289, 0.5774156046765191, 0.3173568807542324, 0.5913782268762589, 0.3977604577583926, 0.21442344412207603, 0.25514257486377445, 0.42035097841705593, 0.39955515574131695, 0.34192047268152237, 0.5907516947814396, 0.4321830006582396, 0.23340820255024092, 0.3324032590857574, 0.1824520275528942, 0.16145136872572557, 0.15742414125374385, 0.453754904546908, 0.5333167995725359, 0.2913520804473332, 0.12529605094875607, 0.8408593226756368, 1.0016499204295022, 7.336915561131068, 18.773332561765397, 39.661179133823936, 51.57257672718593, 70.11883694784981, 67.02766677311489, 70.92491831098283, 66.95426600319999, 41.0160049029759, 33.31198474339077, 23.664579493658884, 32.80755247388567, 58.63931506020682, 69.47819219316754, 69.18878582545689, 85.88811411176408, 80.62267889295305, 38.40127617972237, 1.7961331116301673, 0.27300699055194855, 0.11103236954659224, 0.22407878030623707, 0.17319334936993463, 0.21506145702941076, 0.151937479951552, 0.16665527091494628, 0.15410740779978888, 0.0915865126465048, 0.11400820022182805, 0.08852873529706683, 0.13333267399242946, 0.18384332289653166, 0.11755030229687691, 0.12355810563479151, 0.09089693786310298, 0.10534947591700725, 0.08877969825906412, 0.11474154729928289, 0.1566559581884316, 0.1937734250511442, 0.17581348520304474, 0.11471530156476156, 0.0711331737360784, 0.07618153534297432, 0.3027928593967642, 0.17464450507291726, 0.19415363536349364, 0.1149201105747904, 0.21434271202555724, 0.1726631556770631, 0.20402024021106108, 0.09326859417238406, 0.06133684476039239, 0.210111815482378, 0.17388286308518477, 0.15355744159647397, 0.15006704388984612, 0.18670038958745344, 0.14292397004153046, 0.19757749592619284], [0.03801600329045739, 0.02788202850414174, 0.011914722937425333, 0.06570744487856116, 0.022391643741035035, 0.046429063991776535, 0.012907158433725792, 0.07758140058389731, 0.02350355568341911, 0.02033513641384031, 0.0009690745958193604, 0.006753489150599177, 0.0942524563787239, 0.03789061680436134, 0.012978309615781265, 0.026072429892207896, 0.008706711997677172, 0.07428127766719886, 0.056840322113462856, 0.03670804901048541, 0.03750037095908608, 0.029076009257031337, 0.015358962451240845, 0.056120861255164654, 0.01875818710375045, 0.06153706008834498, 0.03237825598833816, 0.023322132382807986, 0.022643807710015347, 0.018163076269307306, 0.02405344894421952, 0.044356146295155795, 0.044699003254728656, 0.03471179898562176, 0.08561914999570165, 0.015148228134161659, 0.02252618027185755, 0.15703425503202847, 3.1072665452957153, 28.25001014981951, 67.60682691846574, 82.91907242366246, 69.65234879084996, 58.03030545370919, 63.703551292419434, 44.40208789280483, 26.162382193974086, 33.68307065963745, 24.877384083611624, 16.679058653967722, 48.31409045628139, 113.89057036808559, 45.37053823471069, 17.438599245888845, 19.361445461000713, 20.87111357280186, 7.624330401420593, 0.11276468980525221, 0.3513321333697864, 0.05345457486276116, 0.10000206357134239, 0.20373630044715746, 0.09731525488729988, 0.05552602692374161, 0.054487688533429585, 0.1927486336124795, 0.20033096389046737, 0.1304826640657016, 0.0998601344014917, 0.07687714908804212, 0.06847608488585268, 0.09452522745622055, 0.13489353523722716, 0.08251019074980702, 0.20509383188826696, 0.08433338720351458, 0.1549463349261454, 0.10715471154877118, 0.030590024444141557, 0.027109017662171806, 0.14688783591347082, 0.037504910358360836, 0.07377654939357724, 0.14079917834273406, 0.0347698646198426, 0.08800739648618869, 0.34742724576166695, 0.43996039618338856, 0.9464744925498962, 0.07874240114220551, 0.10612532642803021, 0.02785790997690388, 0.017039189880181636, 0.47567058141742435, 0.3840067429201943, 0.2505379005202225, 0.013268610645484711, 0.05999838015330689, 0.05430758498342974, 0.022333170985803008, 0.019884070082168494, 1.0091963154929025, 0.4640251291649682, 0.021277613073055233, 0.11326407800827708, 0.020740257443061898, 0.014450368438182133, 0.033540060610643456, 0.11370061351252453, 0.08010380701827151, 0.015069541820724095, 0.02595662771325026, 0.10066889386091914, 0.2373656359102045, 0.11406683921813965, 0.014429844450205564, 0.18450375460088253, 0.22948206322533743, 1.5499330312013626, 9.137358835765294, 23.722353764942714, 33.94697366441999, 42.66963447843279, 58.007331235068186, 50.4592946597508, 52.9486083984375, 45.905028411320274, 27.109397343226842, 31.750408376966202, 28.857845510755265, 44.47930669784546, 53.128337451389854, 63.57209137507847, 67.77930900028774, 45.62163918358939, 6.731937646865845, 0.06727281838123288, 0.03121191535943321, 0.03460429868261729, 0.1232508649783475, 0.021191406895273497, 0.08183224605662481, 0.014160960530196982, 0.014459172430049096, 0.045874792483768294, 0.05517140416694539, 0.029793943411537578, 0.08614550996571779, 0.055041003307061534, 0.020907250000163913, 0.018515056132205894, 0.04625117585861257, 0.13040725168372902, 0.01684962585568428, 0.03557305669944201, 0.03404069392542754, 0.007537038065493107, 0.042007163233522854, 0.007762421105456139, 0.040055849190269194, 0.051264056869383366, 0.017131172087309614, 0.02044851622278137, 0.06295826525560447, 0.03798299256180014, 0.042608019563236406, 0.05926816790763821, 0.018024344695731997, 0.10428210640592234, 0.05321588999192629, 0.045839562945600064, 0.02228411629662982, 0.03588709966944797, 0.051676131186208556, 0.007962451532616146, 0.009903598576784134, 0.02643277100287378, 0.010755573931549276, 0.013420738196665687, 0.03914132647748504, 0.037904777830200534, 0.0064108357515319115, 0.04883896592738373, 0.04335732917700495, 0.01846621178888849, 0.03645058907568455, 0.022723505040630698, 0.046721570260290585, 0.06086374978934016, 0.04752161054472838, 0.06182140697325979, 0.025673970380531888, 0.02149936001348708, 0.10314036267144339, 0.027542121475562453, 0.0691960376820394, 0.084347229317895, 0.06753058026411704, 0.01866320237916495, 0.016109902245391692, 0.03729589782389147, 0.022670523330037082, 0.04391224190060582, 0.05563636689579912, 0.046378927039248605, 0.04603181227243372, 0.022757177340931127, 0.0308264599713896, 0.024185885409159318, 0.01687068079731294, 0.0722184090742043, 0.05716558466000216, 0.01855202272002186, 0.1210029734564679, 8.673297337123326, 49.34313951219831, 87.79011399405343, 102.10796110970634, 84.71950353894914, 79.8691189629691, 88.56599848611015, 68.9963971546718, 39.032044070107595, 36.598645959581646, 20.26114685194833, 11.157178453036718, 42.97527878625052, 100.91101578303746, 48.96629006522042, 18.522535596575054, 16.066750390189036, 9.306194850376674, 2.348061638219016, 0.3073938153684139, 0.3135566775287901, 0.04037274540002857, 0.09220564192427055, 0.041655688879213164, 0.05918115936219692, 0.024789832465882813, 0.04102541805644121, 0.19469340997082846, 0.19055889254169806, 0.13405308819242887, 0.13046739702778204, 0.16616068673985346, 0.09664591401815414, 0.2900952436029911, 0.4742721478853907, 0.18245656016681874, 0.48211362425770077, 0.33117345507655827, 0.6479578422648566, 0.2263150553085974, 0.037001298274844885, 0.12346923111804894, 0.3337443156966141, 0.1833863974149738, 0.2610287847263472, 0.39947009459137917, 0.3332229565296854, 0.6242623680404255, 1.979729162795203, 2.559303377355848, 4.337889790534973, 0.7704724967479706, 0.3942349797913006, 0.38807287759014536, 0.619886685694967, 1.6691596678325107, 0.5391455239483288, 0.4450137178812708, 0.12175335176289082, 0.1182513375367437, 0.010097361036709376, 0.016142751821982007, 0.07429420375930411, 1.1511083862611224, 0.8623109630175999, 0.08930136276675121, 0.02135026890651456, 0.08732064440846443, 0.02175250616190689, 0.058680190172578604, 0.14529824549598352, 0.04761888532500182, 0.042712347715028694, 0.04294852539896965, 0.10707295486437422, 0.05942264997533389, 0.17015774654490606, 0.06639186958117144, 0.10612399649939366, 0.5100066246730941, 0.26492050875510487, 5.577694645949772, 25.04178019932338, 38.867812974112375, 46.91917358125959, 45.24804149355207, 34.40953261511666, 35.470272404806956, 24.315964426313126, 23.115020411355154, 40.27069248471941, 47.81760345186506, 68.4427855355399, 73.29353836604527, 76.69841970716203, 80.64806761060441, 65.83785724639893, 15.489031996045794, 0.071054857224226, 0.09211790056100913, 0.018080342494483505, 0.007552292380881096, 0.047456484753638506, 0.05900348496756383, 0.010378368681163659, 0.029176032104130303, 0.03186301042192748, 0.07423782428460461, 0.0516411696693727, 0.027268838104126707, 0.014130815763824751, 0.040491478850266764, 0.033702593496335406, 0.015872513376442448, 0.028165939430307065, 0.011808894375073058, 0.054571497786257944, 0.027794831665232778, 0.011372917814047208, 0.03928829716252429, 0.04609740625268646, 0.022987495874986053, 0.08614417325173106, 0.0458681089138346, 0.030208324747426168, 0.04409891366958618, 0.041211268798049004, 0.009020067102807974, 0.01107486112908061, 0.011496650371035295, 0.09853702504187822, 0.055436205850648027, 0.007772650869031037, 0.056027026647435765, 0.02669050744069474, 0.10672383502657924, 0.011505685912977372, 0.038312794507614205, 0.06558835519743816, 0.10411633351551634, 0.11659223799194608, 0.23587163750614437, 0.13428537787071296, 0.13083889495049203, 0.09621311045650925, 0.12484649435750075, 0.09240673934774739, 0.11925828350441796, 0.11042751664561884, 0.09684460942766496, 0.16156049072742462, 0.18660824453192099, 0.13181693532637187, 0.1216303605054106, 0.1352674351739032, 0.25611624547413414, 0.14743966130273684, 0.1337633944515671, 0.1197714866804225, 0.1211774790925639, 0.2008593391094889, 0.0717733104580215, 0.139898775943688, 0.0986339266278914, 0.13192854076623917, 0.09391456629548754, 0.0945717953145504, 0.09819241746195725, 0.0969880653013076, 0.14466446664716515, 0.14072037328566822, 0.135247852653265, 0.1853720894349473, 0.15464927229498113, 0.21799218548195703, 0.1782344031546797, 7.0278249468122205, 48.572824001312256, 98.79975005558559, 109.80436256953648, 87.68226405552456, 78.73794528416225, 84.01693643842424, 58.036183629717144, 34.66683483123779, 47.54450798034668, 38.72073698043823, 21.076332092285156, 57.595858914511545, 130.93600927080428, 60.92930930001395, 27.33423410143171, 29.800083773476736, 30.571924413953507, 11.806210551943098, 1.091139244181769, 0.7938143185206822, 0.18523607030510902, 0.3427347147039005, 0.5233107964907373, 0.17287887553019182, 0.14654392722461904, 0.27739157527685165, 0.4497933185526303, 0.5679791367479733, 0.24997772915022715, 0.30616998246737887, 0.23870647538985523, 0.14128016467605317, 0.35894882466111866, 0.48033374547958374, 0.14047890981393202, 0.5986965256077903, 0.5384888106158802, 0.5322626818503652, 0.2689149629856859, 0.13376448010759695, 0.09992015082389116, 0.34278028511575287, 0.09465456980147532, 0.16821762493678502, 0.1112899821517723, 0.10308420711330005, 0.22784958939467156, 0.7883897296019963, 1.154799182500158, 1.7779942963804518, 0.2746882917625563, 0.2670072210686547, 0.1811319648155144, 0.1844241488724947, 1.2121701325689043, 0.3719516455062798, 0.28559286519885063, 0.10429463216236659, 0.31975281504648073, 0.2619332719062056, 0.07491931771593434, 0.1746233076389347, 1.001819174204554, 1.0218452938965388, 0.17952948223267282, 0.15049674654645578, 0.20461649607334817, 0.1421417005892311, 0.14613497416887963, 0.1792750587420804, 0.20878758653998375, 0.13561234809458256, 0.18741301420543874, 0.2741837059812886, 0.7337989274944577, 0.46886107538427624, 0.12667548550026758, 0.4509653928024428, 0.9346084892749786, 2.6346622364861623, 16.194797004972184, 38.93986231940133, 53.99646275384085, 62.11346994127546, 85.39427784511021, 72.56029496874127, 73.00927366529191, 64.13232462746757, 39.04959174564907, 38.365836892809185, 38.7242944581168, 58.79344694955008, 69.35405567714146, 79.3953560420445, 90.08900887625558, 69.22875881195068, 11.639802064214434, 0.2203974835574627, 0.181052956197943, 0.14028248749673367, 0.23733797882284435, 0.16268357474889072, 0.21037621343774454, 0.10774374101310968, 0.1296455825545958, 0.16843167559376784, 0.2062835751899651, 0.10772830434143543, 0.1246624756604433, 0.12106535796608243, 0.11256119715315954, 0.14501625991293363, 0.13496061520917074, 0.16032896323927812, 0.2480125017464161, 0.18732115413461412, 0.1212775358664138, 0.11379374244383403, 0.16764618988548005, 0.09568143755729709, 0.14212910697928496, 0.1417636615889413, 0.12110065535775252, 0.100373765054558, 0.15715868478374823, 0.11231682276619331, 0.08865129907748528, 0.10051249153912067, 0.1337155577327524, 0.34160935080477167, 0.15201053103165968, 0.12829565070569515, 0.15371771156787872, 0.14037763167704853, 0.15938592169966015, 0.15037604873733862, 0.12431050597557], [0.034919966743992906, 0.020751376935679997, 0.008908457422096814, 0.03177917742037347, 0.02907735275636826, 0.04229608344446335, 0.012951990090576666, 0.07321616767772607, 0.038217107499284406, 0.03125409648886748, 0.03759265850697245, 0.03456485204930816, 0.0033680591150186956, 0.024338413296001296, 0.04894726011636002, 0.034055340103805065, 0.03788682718628219, 0.036897618123995404, 0.06427899974265269, 0.06580997830522911, 0.02682276239751705, 0.0331666254704552, 0.008137632311055703, 0.025773691279547553, 0.01951979686106954, 0.029053142626902888, 0.060124662305627546, 0.09809753112494946, 0.02097205857613257, 0.02444996784574219, 0.08191692044160195, 0.01546159596182406, 0.06608393681900841, 0.05218728857913187, 0.09064876368003232, 0.0506241542420217, 0.7348891432796205, 14.445409093584333, 59.90833405085972, 77.0519162586757, 67.4797374180385, 56.98022072655814, 46.961074692862375, 49.5658848626273, 35.172403131212505, 22.529497453144618, 34.69593388693673, 32.69233397075108, 61.2543043409075, 70.45492131369454, 35.49841260910034, 17.9177748135158, 16.160379103251866, 20.57364903177534, 5.356772329126086, 0.09003416023084096, 0.7151002937129566, 0.1275988630950451, 0.19374202245048114, 0.10028532480022737, 0.07194480339863471, 0.043292468014572344, 0.09765600160296474, 0.07945350584174905, 0.08228663381721292, 0.06987681865159955, 0.037397637364587615, 0.005026808366112943, 0.07066395998533283, 0.13796869665384293, 0.12313476763665676, 0.04894844415996756, 0.09046078233846597, 0.12193925678730011, 0.22056839295795985, 0.07583332474210433, 0.03410293933536325, 0.2891964561172894, 0.09396130378757205, 0.387990232024874, 0.6137093571679932, 5.278861744063241, 4.9743591121264865, 6.135380949292864, 5.242850533553532, 9.593245778764997, 20.36653365407671, 11.871003372328621, 12.675035885402135, 1.8184912204742432, 0.33519502356648445, 0.7588106510894639, 0.5395833690251622, 0.836462632886001, 0.47797412638153347, 0.5531746425798961, 2.5389864104134694, 1.1920248078448432, 0.1687447109392711, 0.13191412868244307, 0.38725695280092104, 2.2729312011173795, 0.27624276120747837, 0.16809856918241295, 0.04635575167568667, 0.09754164131092173, 0.07539228376533304, 0.04588196459891541, 0.02814165296565209, 0.060267663560807705, 0.03779611383963909, 0.030816536396741867, 0.056111789241965325, 0.10225520016891615, 0.07324765848794154, 0.017487346992961, 0.02036701059634132, 0.018859930037121688, 0.10753454866686038, 0.10205480163650853, 0.6810084687811988, 7.33841289792742, 24.416522230420792, 40.45297152655465, 43.551982743399485, 50.03230701174055, 61.02784865243094, 46.89147111347744, 26.19368382862636, 27.82981436593192, 32.63826656341553, 31.457903112683976, 44.8765595299857, 52.40750701086861, 67.08673340933663, 66.21244852883476, 21.275830507278442, 0.3413609527051449, 0.15510675417525427, 0.0721907044893929, 0.02584429963358811, 0.02886679655473147, 0.07099617073046309, 0.0456416444586856, 0.07741119007446937, 0.013352904202682632, 0.013923956729870821, 0.008482424791769257, 0.02409477172685521, 0.04096815309354237, 0.057600579889757295, 0.04655820956187589, 0.009722665517723985, 0.029035276799861873, 0.09075684752315283, 0.020064422993787696, 0.006266577510229711, 0.02962816712845649, 0.006845918342670692, 0.009187311566035663, 0.02205103782138654, 0.028460951189377477, 0.02209290343203715, 0.019661052584914223, 0.03247987000005586, 0.04513329280806439, 0.07329064368137292, 0.053029584631855996, 0.058892822691372464, 0.026704023858266215, 0.028863800822624137, 0.05307817113186632, 0.014340418623760343, 0.037991494605583806, 0.02339873050472566, 0.038367589603045156, 0.03279112419113517, 0.058837481375251494, 0.004639383954262095, 0.05290341104513832, 0.034430536042366705, 0.021772249834612012, 0.03368661060397114, 0.07520968999181475, 0.03757334061499153, 0.04994819426376905, 0.025097870400973728, 0.04915896304217832, 0.01358697164271559, 0.037996936456433365, 0.023538276320323348, 0.03044669409947736, 0.02519259897858969, 0.029281812320862497, 0.03508456576881664, 0.018778751803828136, 0.05199536155643208, 0.040669088784073076, 0.026617334224283695, 0.03340305421235306, 0.05958904033260686, 0.012939024134539068, 0.0536011452121394, 0.04907838022336364, 0.05727258284709283, 0.07627084412212883, 0.07842057198286057, 0.014057684955852372, 0.03271952856864248, 0.06600233619766575, 0.06588410147066627, 0.02659744636288711, 2.245613055569785, 31.82690109525408, 81.09669194902692, 90.90172576904297, 83.79594898223877, 76.54371111733573, 74.2297386441912, 71.95321001325334, 58.47450378962925, 30.417316573006765, 25.45651469911848, 18.17953082493373, 29.44458266666957, 46.65804638181414, 37.79386118480137, 23.22683082308088, 13.072022948946271, 11.308057716914586, 1.2628139236143656, 0.25248597455876215, 0.3842812781887395, 0.07950817540820156, 0.13857955458973134, 0.02055400127678045, 0.0377500209558223, 0.05965291761926242, 0.08198348472693137, 0.18258366334651197, 0.1663092044847352, 0.17422404406326158, 0.09446189299757991, 0.056229627025978904, 0.11988994532397815, 0.7601667983191354, 0.4584582650235721, 0.408191440893071, 0.5806830493467194, 1.3477807300431388, 0.5591240376234055, 0.5127816700509616, 0.5713695862463543, 1.9676890202930994, 0.9903537780046463, 1.9926727882453372, 1.0672921580927712, 13.81652763911656, 13.09191129888807, 12.323696749550955, 10.478243912969317, 17.94022618021284, 32.83115203039986, 22.33051494189671, 18.3420352935791, 4.201417616435459, 2.4429770708084106, 4.969780683517456, 2.5252654552459717, 0.44096001397286144, 1.2490706039326531, 0.9448097475937435, 0.15969902489866528, 0.34642722085118294, 0.1868004056492022, 0.13332579364734037, 0.028167610322790484, 2.8131475618907382, 0.2884158694318363, 0.11664909922650882, 0.06943800326968942, 0.10071757196315698, 0.06696211719619376, 0.04239347018301487, 0.030035654548555613, 0.08862711608942066, 0.14122912527195045, 0.13673254155686923, 0.05532972335017153, 0.07281245291233063, 0.08296386604862553, 0.04358252477166908, 0.11965700425207615, 0.06962433577116046, 0.04926012922078371, 0.32957398518919945, 0.4638615208012717, 4.82174106155123, 22.716959851128713, 45.61338472366333, 44.84140164511544, 44.63238940920149, 44.63311549595424, 31.336789063044957, 20.06478728566851, 32.517260210854666, 45.531392506190706, 52.17211593900408, 68.78239958626884, 69.42002882276262, 75.8825135912214, 81.5591709954398, 36.73860352379935, 1.949784598180226, 0.16574466334921972, 0.052843798351074965, 0.09546020799981696, 0.03973764680059893, 0.0156351024551051, 0.022260537204731787, 0.037486667944384475, 0.011703351645597389, 0.007435074608240808, 0.054671870078891516, 0.014149565382727554, 0.021064882166683674, 0.10614657814481429, 0.03838906523638538, 0.003316741935642702, 0.042135840614459345, 0.01305419612409813, 0.0062615304819441265, 0.06937556447727339, 0.04764683757509504, 0.0621933052316308, 0.015295867176194276, 0.062302746144788604, 0.015024397189595869, 0.03805772640875407, 0.08053402536149536, 0.046959573203431706, 0.009048306033946574, 0.03954931940617306, 0.0831401494464704, 0.028657739915485893, 0.051439719407686164, 0.01596147271006235, 0.08520468723561082, 0.04481478507763573, 0.01163638532826943, 0.06401761448276894, 0.017569275007450154, 0.14228990620800427, 0.1446922051587275, 0.09436431966189827, 0.12576920698795999, 0.09618490375578403, 0.13391257716076715, 0.10705011537564652, 0.23156022599765233, 0.09921361945037331, 0.18896187895110675, 0.08171475771814585, 0.14172536507248878, 0.07727751867579562, 0.11923260773931231, 0.10281133425555058, 0.13205354048737458, 0.07429403412554945, 0.10352955000208956, 0.14446957781910896, 0.12341912809227194, 0.1401507974203144, 0.11601542894329343, 0.0740436954157693, 0.17283156806869165, 0.09344994622681822, 0.12571235932409763, 0.08619002186294113, 0.19229335018566676, 0.1002039820221918, 0.21479633982692445, 0.15474132235561097, 0.18046805901186808, 0.1737960513148989, 0.17264212109148502, 0.239725119301251, 0.14111518567161901, 2.7846716727529253, 31.80746350969587, 90.52698162623814, 103.78147642953056, 90.88523769378662, 75.28751850128174, 66.54637895311627, 63.31483432224819, 46.384308201926096, 30.961586339133127, 50.99153362001692, 47.74866342544556, 81.30606201716832, 99.90347140175956, 54.97712108067104, 34.20525210244315, 25.651547159467423, 28.478717054639542, 9.175168326922826, 0.9743068047932216, 1.106658154300281, 0.38027699877108845, 0.8391708561352321, 0.5597561065639768, 0.10849620920739003, 0.0946333927235433, 0.3663895311100142, 0.35977636596986223, 0.23160099238157272, 0.25290142797998016, 0.1938996325646128, 0.16714662526335033, 0.17412237237606729, 0.5150845636214528, 0.470956880067076, 0.33656189164945055, 0.25506690463849474, 0.6876189740640777, 0.24463103605168207, 0.2028300083641495, 0.16847504755215986, 0.9064288213849068, 0.5411612614989281, 1.36006894494806, 1.485322383897645, 11.568673355238777, 10.730283737182617, 14.17531784943172, 11.853383609226771, 18.17675849369594, 38.88143491744995, 25.41842120034354, 25.00538727215358, 3.291910797357559, 1.3642710851771491, 3.951356726033347, 2.4927711188793182, 1.4635112285614014, 1.4144927731582095, 2.905871923480715, 5.54404365164893, 2.834939283984048, 0.5992284970624107, 0.5942237313304628, 0.9791162610054016, 3.678159637110574, 0.9175341597625187, 0.7051627955266407, 0.4425865709781647, 0.36275024924959454, 0.3409835515277726, 0.25782145825879915, 0.11499264596828393, 0.28660765503134045, 0.17731565316872938, 0.16566205849604948, 0.1472826482994216, 0.12993497774004936, 0.3432974102241652, 0.18973156836416039, 0.33252854379160063, 0.170972382117595, 0.34577713002051624, 0.6232257293803352, 1.396508121064731, 12.484207953725543, 39.39057459150042, 59.1174692426409, 61.235537256513325, 70.34452833448137, 84.37069702148438, 66.06642518724713, 37.28777871813093, 38.04576812471662, 40.66576705660139, 41.778778144291465, 60.62492956433977, 65.680390221732, 83.80636433192662, 93.75139045715332, 35.34621926716396, 0.9524687251874379, 0.32686378061771393, 0.15873545088938304, 0.16858358601374285, 0.10477106552571058, 0.11162808936621461, 0.09294683286654097, 0.1412843173103673, 0.05528537430135267, 0.08685903024992772, 0.10826384489025388, 0.1291080064007214, 0.11875117357288088, 0.22159889766148158, 0.09701682161539793, 0.10217431200934307, 0.15974349608378752, 0.15631590357848577, 0.16716702202601091, 0.1736872007272073, 0.15061866571860655, 0.16571362715746674, 0.11445245066923754, 0.17192606308630534, 0.08675545866468123, 0.1575377687279667, 0.16225358710757323, 0.13138500707490103, 0.139565411689026, 0.14302268331604345, 0.20051794100020612, 0.10008049543414797, 0.16085391864180565, 0.0954184170280184, 0.16972895312522138, 0.09190273710659572, 0.08398588906441416, 0.17013766190835408, 0.10237355024686881], [0.05934834360544171, 0.008328820578753948, 0.04858593682625464, 0.001866245683881321, 0.02890822451029505, 0.04352830982367907, 0.01018896241605814, 0.010532262967899442, 0.004210329722679619, 0.06073995107518775, 0.03672862897760101, 0.029912534369421855, 0.10353446259562459, 0.04749699329425182, 0.014130163522038077, 0.03812976986435907, 0.07248435408941337, 0.023729065100529363, 0.02045978668944112, 0.012029571774681764, 0.04614138549992016, 0.02236029881584857, 0.06850457657128572, 0.023200927368764366, 0.037958511018327305, 0.020101754294176186, 0.041271115586693795, 0.0474610037968627, 0.020572956152526394, 0.04176384736118572, 0.02876020548865199, 0.07489321447376694, 0.06647412838148219, 0.032819069655878205, 0.18262464686163835, 4.636289298534393, 41.703928674970356, 79.24189117976597, 77.69130338941301, 67.0720032283238, 63.524468421936035, 64.88808018820626, 43.853638785226, 27.015992709568568, 26.772305488586426, 45.59481566292899, 53.20858914511544, 55.60650627953665, 58.883516447884695, 34.41202701841082, 23.75744216782706, 19.6730409009116, 7.9912925618035455, 0.5924100343670163, 0.13218630264912332, 0.06786091825259583, 0.6388596104724067, 0.04488642480490463, 0.02627283351362816, 0.03537191856386406, 0.035441719461232424, 0.0824457367083856, 0.04453453993690865, 0.06568620673247746, 0.07273914398891584, 0.0798557617568544, 0.16272894160023757, 0.21933590195008687, 0.28793999925255775, 0.3826822968465941, 0.2151871488562652, 0.4024584170963083, 1.084233603307179, 0.39639844798616, 0.3144046834536961, 0.2993059493601322, 2.3044121861457825, 2.0751394374029974, 1.7852019667625427, 2.434229071651186, 2.4284284114837646, 4.618575300489153, 17.047770023345947, 15.439939498901367, 13.207180176462446, 18.418951851981028, 14.276748520987374, 11.861237679209028, 6.6450599772589545, 7.009805228028979, 1.63075675708907, 6.410977338041578, 5.576487830707005, 0.7421487080199378, 0.32953688289437977, 0.47335303149053026, 0.5786750742367336, 0.48994451548372, 0.22440723196736403, 0.14409712994737284, 0.2615095946405615, 0.18288269372923033, 0.34196897436465534, 0.26147051102348734, 0.14596919449312346, 0.03994082393390792, 0.086332758489464, 0.028276793392641202, 0.27114785888365334, 0.16691122789468082, 1.028217334832464, 0.8781741346631731, 0.23851634987762996, 0.46226582356861656, 0.025560322550258467, 0.06514513612325702, 0.10754636196153504, 0.0812641086855105, 0.07891787029802799, 0.13906723127833434, 0.09572106400238616, 0.18961331328111036, 0.13266146715198243, 12.33470790726798, 43.35053709575108, 46.59408821378435, 53.19872965131487, 51.18465185165405, 51.40760217394148, 41.28510863440377, 29.631972108568462, 21.24893229348319, 28.04876252583095, 41.10651561192104, 46.099498067583355, 59.034361839294434, 66.61620834895542, 43.38373211451939, 3.721743081297193, 0.2425361813179084, 0.0671232489070722, 0.04692533093371561, 0.05395257206899779, 0.04133267228358558, 0.03764395236170717, 0.04229815297627023, 0.03025186973224793, 0.060025155145142756, 0.0462078887170979, 0.013822770195214875, 0.012921983575714486, 0.06750335065381867, 0.020029096764379313, 0.03216872098190444, 0.052631284575909376, 0.05114724367324795, 0.017220241682870046, 0.05847479083708354, 0.08937744011304208, 0.026198047080210278, 0.04332697152027062, 0.01960929393369172, 0.02357535995543003, 0.018524514910365854, 0.006965711579791137, 0.027094932971522212, 0.052073233627847264, 0.05496376905856388, 0.039170852928821526, 0.05844455531665257, 0.0215156431575971, 0.03159499926758664, 0.02057225556511964, 0.032359738767679246, 0.03084353530513389, 0.03601932918120708, 0.018056139150368314, 0.04863434690716011, 0.07925242198897259, 0.06009957008063793, 0.0555953630246222, 0.041762324050068855, 0.03555998811498284, 0.003971059191306787, 0.04526109487882682, 0.0558454744251711, 0.029770744299249988, 0.03154599546853985, 0.07335444632917643, 0.09627205479357924, 0.029447880374001603, 0.019126256728278737, 0.026639374738026942, 0.013708939160486417, 0.02618446959448712, 0.017602954093100767, 0.029320987540164163, 0.02286152245609888, 0.017268802737817168, 0.01807736711842673, 0.03037855222022959, 0.024477280576580336, 0.005319548305124044, 0.035157759341278245, 0.029959166688578467, 0.049038017567779334, 0.08716253896376916, 0.013854005706629582, 0.06321863271296024, 0.02229457930661738, 0.06532876805535384, 10.310067977224078, 63.103873116629465, 95.31801468985421, 87.68837847028459, 93.73770250592912, 96.34590339660645, 93.31324400220598, 65.32144628252301, 35.51410164151873, 20.23843492780413, 19.693430389676774, 27.893315689904348, 36.3921663420541, 50.28843150820051, 37.3628956930978, 24.33699836049761, 12.085840804236275, 3.2179014086723328, 0.5105303451418877, 0.09476761373558215, 0.07148482450949294, 0.3930313672338213, 0.07423234172165394, 0.013146923023409076, 0.035610715392977, 0.04835539776831865, 0.33657470239060266, 0.276330617921693, 0.15881813716675552, 0.23257933131286077, 0.1686041456248079, 0.34188052053962437, 0.7253605031541416, 1.7507243539605821, 2.222508123942784, 1.7071828160967146, 2.3441300434725623, 3.935392371245793, 4.42905102457319, 3.0733426170689717, 3.4268995310579027, 6.315577702862876, 7.07884817464011, 9.429919685636248, 7.435394116810389, 5.892189221722739, 10.517912915774755, 24.223956380571636, 16.933298451559885, 15.70920651299613, 26.059269189834595, 13.767509835106985, 14.746002061026436, 8.370877861976624, 10.547314218112401, 3.679640471935272, 6.615559663091387, 1.1884174985545022, 1.2442571307931627, 0.4681539876120431, 0.14707040254558834, 0.4651013399873461, 1.1066350298268455, 1.4317932448216846, 1.2123034511293684, 1.4614542360816682, 1.3969391265085764, 0.5313764608332089, 0.28228250997407095, 0.17288214606898172, 0.11260707290577036, 0.05551175054694925, 0.06560493859329394, 0.10026403237134218, 0.07701789760696036, 1.9299103617668152, 1.281856547508921, 0.21824122140450136, 0.6680287995508739, 0.009807681714716767, 0.06724579233144011, 0.1222492658666202, 0.09178441417004381, 0.030195595430476323, 0.2508093145276819, 0.0833074218992676, 0.20103757668818745, 0.42221515838588985, 8.890107188905988, 45.48345341001238, 47.498170443943565, 51.59856993811471, 39.312744344983784, 30.932108606610978, 20.392193351473125, 18.229535273143224, 23.591328110013688, 42.10277959278652, 63.96347645350865, 71.53024537222726, 76.61486067090715, 77.88688128335136, 63.23199095044817, 11.928447604179382, 0.12329540401697159, 0.09111582647476878, 0.05699897038617304, 0.05006168603098818, 0.07247098016419581, 0.05865675357303449, 0.061465508570628505, 0.021388093841129115, 0.016000122064724565, 0.009677169744723609, 0.04232598987541028, 0.024856391662199582, 0.047702036398862085, 0.058816853910684586, 0.052409634326717684, 0.05225116925846253, 0.0483007519505918, 0.02706897391804627, 0.01571431293684457, 0.0425163528748921, 0.009639922413043678, 0.052975895548505444, 0.07108174756701503, 0.04160744503938726, 0.016017869148137312, 0.04389456606337002, 0.037362336580242426, 0.03529337474278041, 0.07361856608518533, 0.03821417283532875, 0.038849013591451306, 0.055185242888650725, 0.026060309560437287, 0.07013008184731007, 0.017609272950461934, 0.010373909857922366, 0.08095986715384892, 0.1191222643745797, 0.10802708366619689, 0.23502463581306593, 0.14257643797567912, 0.22158018366566726, 0.11770827881991863, 0.10886713037533419, 0.1496514683323247, 0.10873449713523899, 0.1295370440930128, 0.16844417420881136, 0.09079708464975868, 0.25805243157914703, 0.23466878490788595, 0.12214726848261696, 0.11288613400288991, 0.14182292483747005, 0.10160477007074015, 0.13835156682346547, 0.10117452458611556, 0.15472293405660562, 0.0828846674412489, 0.19270561449229717, 0.10510679108223744, 0.21038465441337653, 0.08924084422843796, 0.08453430142253637, 0.18233837293727057, 0.11613627603011471, 0.14127797979329312, 0.16245911536472185, 0.1473731648709093, 0.1477733783956085, 0.11897228099405766, 0.19841548667422362, 10.641433647700719, 69.67576422010148, 108.10932867867606, 100.02901145390102, 90.75222137996128, 89.80066558292934, 87.44738020215715, 55.58686719621931, 38.74086938585554, 40.78108630861555, 62.43175997052874, 72.60225514003209, 79.26346533639091, 86.9502921785627, 55.306684562138145, 38.71379920414516, 27.497224943978445, 12.695419294493538, 1.5635027544839042, 0.3092529470367091, 0.22642523582492555, 1.2605908257620675, 0.24786607388939175, 0.1524747439793178, 0.10523521740521703, 0.2641578082527433, 0.254552385104554, 0.19977262456502232, 0.11118157939719302, 0.24198654081140245, 0.1680959364665406, 0.3974663535399096, 0.5101514511874744, 1.2073605677911212, 1.193161923970495, 0.6492967275636536, 1.17109748508249, 3.0199559160641263, 1.641169718333653, 1.123710227864129, 1.2738655763013023, 6.0367512702941895, 6.823321223258972, 8.236881852149963, 6.106314029012408, 9.543570501463753, 16.50659567969186, 29.398436205727712, 31.386538164956228, 27.00431626183646, 41.19898918696812, 26.147728443145752, 23.412882736751012, 15.451039246150426, 15.380105086735316, 4.259548417159489, 12.759591119629995, 13.534530656678335, 2.339425244501659, 2.1666656689984456, 2.903372960431235, 3.6546104550361633, 1.233567870088986, 1.0773308937038695, 0.7481674222009522, 0.9971937366894313, 0.8545598132269723, 0.5167182588151523, 0.3978377293263163, 0.24040028878620692, 0.1611698174050876, 0.15582853901599134, 0.20359664436961922, 0.9139890585626874, 0.5617403058069093, 3.77672678232193, 1.605692324893815, 0.4159722833761147, 1.09759336071355, 0.14617363709424222, 0.22484233576272214, 0.2773128923560892, 0.45252387917467524, 0.26641290581652094, 0.5176005714706012, 0.24169501502599033, 0.5856726701770509, 0.7409875988960266, 19.065115213394165, 64.47459983825684, 63.32527051653181, 69.82429586138043, 71.28052016666958, 69.38175814492362, 54.52991764886038, 40.96883705684117, 29.807546138763428, 33.352551800864084, 55.766502448490684, 62.09439713614327, 74.0827008656093, 86.4075961794172, 67.39252362932477, 10.207268510546003, 0.38482280341642244, 0.22990831892405236, 0.21563587763479777, 0.14277619868516922, 0.09173469112387725, 0.09780747097517763, 0.1809701206428664, 0.09362875377493245, 0.1579397600144148, 0.11345219505684716, 0.09828164481690951, 0.10772849433124065, 0.27664836230022566, 0.16664338298141956, 0.12936939166060515, 0.10276395894054856, 0.19848534863974365, 0.0936453982389399, 0.17462049850395747, 0.11409194501382963, 0.11013196036219597, 0.1466505793588502, 0.10002153074102742, 0.1790422805185829, 0.14030700975230762, 0.11392571750496115, 0.06667386194957153, 0.15993941628507205, 0.17809482850134373, 0.11832464646015849, 0.13276100823921816, 0.12438814395240375, 0.14608400261827878, 0.1444187962583133, 0.19125516446573393, 0.16151364466973714, 0.2662352653486388], [0.03394396197316902, 0.02616402872705034, 0.013649147502811891, 0.0608155805883663, 0.021366558835974762, 0.01855738993201937, 0.014111657327573215, 0.044010975531169345, 0.02169216743537358, 0.04500644747167826, 0.05278260127774306, 0.04978722879397018, 0.02812476422903793, 0.11426136163728577, 0.03032150778121182, 0.03924836198400174, 0.04074679461440869, 0.020313416507893374, 0.07241388144237654, 0.03392241509365184, 0.011039706229764436, 0.03288091133747782, 0.010732158536224492, 0.03723045312134283, 0.10174692994249718, 0.1455312001385859, 0.023099769671846713, 0.02548161248809525, 0.025443470338359475, 0.06312433670141868, 0.032916904227542024, 0.052393617507602484, 0.03149654044370566, 0.0980309396982193, 16.21356408936637, 70.03610474722726, 84.70557934897286, 70.05356557028634, 59.18965407780239, 52.73400286265782, 36.25677374431065, 22.996425083705358, 28.088933535984584, 30.16054241997855, 57.68069641930716, 56.460578850337434, 51.853259631565635, 46.50837523596627, 31.040743691580637, 12.998574410166059, 3.0203282960823605, 0.24499942628400667, 0.2059091595666749, 0.08563137719673769, 0.22478790368352616, 0.14420108151222977, 0.07614739824618612, 0.052788144908845425, 0.23461485494460377, 0.04054115439898201, 0.062046510965696404, 0.13705665059387684, 0.09389631370348589, 0.13956102835280554, 0.2192332667431661, 0.24710399763924734, 0.27821360688124386, 0.3429867226098265, 0.8962858627949442, 1.0771134368010928, 0.34969925241810934, 0.7134105786681175, 4.210495437894549, 2.9866000030721938, 2.2052487986428395, 5.186553188732692, 4.688759054456439, 9.202687535967145, 9.22304836341313, 5.535041391849518, 3.699445877756391, 7.723353522164481, 6.95649300302778, 11.796624643462044, 11.450404592922755, 11.414193187441144, 11.262104068483625, 11.72689425945282, 3.1183345913887024, 7.348260232380458, 4.1359043547085355, 5.741921399320875, 2.6937961833817616, 0.8719478430492538, 1.3487927785941531, 5.976909909929548, 13.756418773106166, 25.34289949280875, 30.399126189095632, 32.747391496385845, 31.381424290793284, 29.589511666979107, 25.036615950720652, 19.560971668788365, 13.135646734918867, 7.4003447975431165, 3.498906101499285, 0.5698535218834877, 0.07764633638518197, 0.05694970874381917, 0.04147271512608443, 0.1093511361894863, 0.18056480453482696, 0.07036528244082417, 0.07468189152755908, 0.060228566373033185, 0.04977200925350189, 0.08470119389572314, 0.07286406907119922, 0.10539302429450409, 0.13617995620838233, 0.24398618351135934, 0.0438677198253572, 0.4374095930584839, 2.71517014503479, 12.64901488167899, 43.4591235433306, 43.37141990661621, 35.041151659829275, 61.47839069366455, 55.209906578063965, 41.37043946129935, 26.87293103763035, 25.13504934310913, 23.675920690808976, 34.96474231992449, 53.841340746198384, 67.14466054098946, 53.24550492422921, 10.935886144638062, 0.09015163499861956, 0.04519809629502041, 0.09348985765661512, 0.040179566480219364, 0.11628818645008973, 0.05093067225867084, 0.04419728089123964, 0.023992109378533702, 0.012387378557052995, 0.048711933993867466, 0.007021378592721054, 0.029996116313018968, 0.06928537360259465, 0.02443995775787958, 0.021832590257482867, 0.024843699664675763, 0.08932018532816853, 0.07919077029717819, 0.015153787032301937, 0.050005974913282056, 0.02932352526113391, 0.038222379716379304, 0.045025358242647986, 0.010041750851087272, 0.029136385302990675, 0.021894691478727118, 0.015501600690186024, 0.061597788972514014, 0.07955272123217583, 0.05407658791435616, 0.06147586301501308, 0.02945868604417358, 0.048793738175715716, 0.07122998032718897, 0.002984635091187166, 0.030931035788463693, 0.054116417919950824, 0.06939310460750546, 0.03632783191278577, 0.02246750395611993, 0.04708279516281826, 0.01694564873884831, 0.05327907517286284, 0.017072181949125867, 0.012564471107907593, 0.03762911619352443, 0.03680199896916747, 0.03338541569454329, 0.0539434288096215, 0.006867957160076392, 0.04314289175506149, 0.07883821028683867, 0.011281032298159386, 0.07951482505138431, 0.0430976538253682, 0.02982878279207008, 0.02910468414691942, 0.06812774536332913, 0.045508370002997775, 0.0472712887983237, 0.020161039595093046, 0.06064496974327734, 0.04817684127816132, 0.03623185991974814, 0.033054460239197524, 0.028478002774396112, 0.099949653526502, 0.02937667490914464, 0.1471089297639472, 0.4926874797259058, 28.7802289213453, 91.95195293426514, 92.73103359767369, 84.31211675916398, 82.87247085571289, 75.9852774483817, 57.33750057220459, 33.01437950134277, 20.607229675565446, 11.805467963218689, 37.108414445604595, 40.90459401266915, 42.35017715181623, 48.49302394049508, 36.17129005704607, 11.481128658567156, 0.4767726851361138, 0.3374161400965282, 0.07116713441376175, 0.09439931171280996, 0.06778319206620965, 0.10485398929033961, 0.07029160710849933, 0.055754774649228366, 0.16673368242170128, 0.08334098902664014, 0.19039071085197584, 0.19685922589685234, 0.8432653535689626, 0.7249210838760648, 0.914646966116769, 1.380924071584429, 1.8849042739186967, 2.010248039449964, 2.7541434594563077, 2.863462507724762, 4.190819442272186, 3.5206515746457234, 5.953270401273455, 5.598725540297372, 4.519520912851606, 10.036268132073538, 7.431166137967791, 8.941067014421735, 13.250363230705261, 12.22670771394457, 9.2664954492024, 7.839555195399693, 11.738846029554095, 14.992584943771362, 11.078195674078804, 12.800142543656484, 14.1721624987466, 14.291832191603524, 8.729156511170522, 9.35356158869607, 3.6597938111850192, 2.3981297058718543, 1.29626342015607, 0.38072988018393517, 2.7679619065352847, 9.941322735377721, 20.02028407369341, 33.19164889199393, 39.39034877504621, 42.81041193008423, 43.003898416246685, 41.97388703482491, 38.91520663670131, 31.409154551369802, 23.207474878856114, 15.508589438029698, 9.897944263049535, 3.2260184245450154, 0.9109900423458644, 0.4869222662278584, 0.10154959160302367, 0.08684798369982413, 0.3265680750565869, 0.029305309988558292, 0.12552924986396516, 0.06659730284341744, 0.07940304319241218, 0.03789598401635885, 0.015716889673577886, 0.059911751587476046, 0.05637243150600365, 0.12647256281759056, 0.0632744829303452, 0.8739457758409637, 0.9674788968903678, 10.813317315919058, 44.63508531025478, 45.5974177633013, 28.70217285837446, 53.43769209725516, 44.126442432403564, 21.25509708268302, 16.34451331411089, 24.058373859950475, 42.75602143151419, 62.7140930720738, 72.01035894666398, 79.07432842254639, 72.7718815122332, 21.48811708177839, 0.037485690853957615, 0.06498335980411087, 0.06551801825740508, 0.04672275769657322, 0.11465998739004135, 0.06887974536844663, 0.022839982361931885, 0.05246251934607114, 0.03166309704205819, 0.02163528075574764, 0.014211666603971804, 0.035706246338252506, 0.02745229361711868, 0.005160320733141686, 0.027994863788730333, 0.022219194066045538, 0.04445225399519716, 0.049455591410930665, 0.09056847263127565, 0.05455896524446351, 0.06344631513846771, 0.02227991955753948, 0.026394637334825735, 0.022865469833569865, 0.045433687046170235, 0.03588293346443346, 0.054756425720240386, 0.032459656441850324, 0.026136570111183182, 0.04530079935544303, 0.08590526107166495, 0.046911678809140406, 0.010526207891026778, 0.016729884780943394, 0.03374475087704403, 0.020264953840523958, 0.13649118665073598, 0.13001245286847862, 0.09226861675935132, 0.12750932361398423, 0.13134789120938095, 0.07806242762931756, 0.09658542940659182, 0.09762472113860504, 0.1599475722759962, 0.12468203103968076, 0.12588298373988696, 0.13345073908567429, 0.11356154776045255, 0.1593384649604559, 0.14382023337696279, 0.14294481463730335, 0.10791785988424506, 0.12313653182770525, 0.160719595849514, 0.13390393262462957, 0.06320293141262871, 0.1418589414762599, 0.14389067888259888, 0.17996994645467826, 0.19754590333572455, 0.22652172350457736, 0.1570400090089866, 0.16671104649347918, 0.15588507455374512, 0.18177654594182968, 0.24628101608582906, 0.15486450360289641, 0.3408233086977686, 0.5221862739750317, 32.03806727273123, 102.47003173828125, 108.1019983291626, 90.7957935333252, 84.2493119921003, 71.59614903586251, 50.098547663007466, 32.02693625858852, 42.30026476723807, 48.06550822939192, 82.52258041926792, 81.59520435333252, 76.30862576620919, 67.47257382529122, 47.742298875536235, 23.188343014035905, 5.147223344870976, 0.7151578334825379, 0.5032147062676293, 0.22466147903885159, 0.4552480344261442, 0.16812755619840963, 0.17992866438414368, 0.1452698013080018, 0.453287312494857, 0.16381599541221345, 0.3179610754762377, 0.1989836511867387, 0.465235527072634, 0.38189850747585297, 0.5399329502667699, 0.5922069081238338, 0.7409130143267768, 0.9885202135358537, 1.9404095241001673, 2.2243467909949164, 3.958471247128078, 3.3671524056366513, 9.092476946966988, 8.7770573922566, 6.961336765970502, 11.941405994551522, 14.136104822158813, 19.193469285964966, 16.863995381764003, 15.474767344338552, 14.533051933561053, 18.059174128941127, 15.792418139321462, 22.022892134530203, 18.65413968903678, 18.149591037205287, 19.41922320638384, 20.876668657575333, 11.272958891732351, 15.760949747903005, 13.80988689831325, 14.714458976473127, 7.615595647266932, 2.435512099947248, 1.9578108532088143, 6.434706739016941, 13.399089421544756, 26.223062549318584, 30.84805624825614, 34.43249641145979, 33.818852356501985, 33.87859991618565, 29.984072072165354, 23.427037954330444, 16.009658779416764, 9.72139835357666, 6.19426953792572, 1.5472442954778671, 0.4076685346662998, 0.4270743105028357, 0.21606549886720522, 0.32292743612612995, 0.6942997755748885, 0.3871028439274856, 0.3128349876829556, 0.2529504724911281, 0.17939697791423115, 0.23953491236482347, 0.1676795059548957, 0.3751694214131151, 0.2246396844940526, 0.4141044393181801, 0.14465605281293392, 1.1523251895393645, 7.06752130814961, 25.447984048298427, 62.061462674822124, 61.33019951411656, 50.725685119628906, 85.59540734972272, 76.00226579393659, 56.06618867601667, 37.772985322134836, 32.71355029514858, 31.72004474912371, 50.20114476340157, 67.86404923030308, 86.30892481122697, 82.18954631260463, 19.370914118630544, 0.1680303221302373, 0.15748077178640024, 0.15415922073381289, 0.1828403395733663, 0.14756544812449388, 0.23287378836955341, 0.18437122314104012, 0.10962468079690423, 0.12552760780922004, 0.18559787874775274, 0.044355026712375026, 0.12873637277100766, 0.15876411220857076, 0.1270261795393058, 0.08290542382746935, 0.12691527977585793, 0.22505401154713972, 0.2596145277576787, 0.15243426258010523, 0.14216483863336699, 0.14603370960269654, 0.15223501755722932, 0.08220868371427059, 0.07918016479483672, 0.14611906930804253, 0.09357280856264488, 0.1358550057879516, 0.08082561221505914, 0.19881354245756352, 0.1225242761096784, 0.17129545978137425, 0.08006610761263541, 0.1251280049660376, 0.2034257213984217, 0.09475718465234552, 0.17583048929061207], [0.002759788305931059, 0.0943107900342771, 0.036780187460993014, 0.032796993519046476, 0.11534658340471131, 0.013254322394329523, 0.06866079568862915, 0.010504091890262706, 0.07483652965830905, 0.04483537861545171, 0.07793527016682283, 0.041173274229679785, 0.06365105629499469, 0.02739083021879196, 0.013576372077555528, 0.05050051159092358, 0.053746680795614205, 0.0797302056370037, 0.06376549801123993, 0.009248706262691744, 0.02080930007754692, 0.03146562299558094, 0.029171882862491266, 0.04776425466739705, 0.031003323516675403, 0.01957656310072967, 0.037379391557936154, 0.10515554382332734, 0.10885310505649873, 0.18548536407096045, 0.0586577510195119, 0.13004783168435097, 0.8816860690712929, 35.364020551954, 78.61224542345319, 79.71026924678257, 67.93908282688686, 71.85692187717983, 33.11572592599051, 38.64447007860456, 30.82791689464024, 38.073018959590364, 48.978696073804585, 56.79943207332066, 38.858026436397004, 32.179998125348774, 39.503319535936626, 39.707169260297505, 16.199002402169363, 1.680928070630346, 0.1256602749760662, 0.16042916929083212, 0.2567983360162803, 0.13496132088559015, 0.08296693302690983, 0.023247176315635443, 0.08990254479327373, 0.12495617275791508, 0.14996159954794816, 0.09129529898720128, 0.14911972757961067, 1.2936153965336936, 1.6839797411646162, 0.6248310889516557, 0.9841819320406232, 0.7098044635994094, 0.8928554611546653, 2.686575485127313, 3.7012328675815036, 5.57119026354381, 6.428233189242227, 6.596831228051867, 8.386925595147268, 16.0595121043069, 10.611713596752711, 11.357888460159302, 8.318169695990425, 11.401365944317408, 10.798102498054504, 12.364843981606619, 5.359191605022975, 11.587947658130101, 14.309491906847272, 9.529071348054067, 16.597564969744, 16.736791236060007, 11.385213119643074, 5.023835497243064, 5.991156322615487, 4.55044560773032, 1.9683642983436584, 0.3371035525841372, 0.41939535683819223, 7.604552354131426, 36.58037914548601, 52.33536386489868, 60.149909019470215, 61.25463090624128, 66.77798325674874, 70.60277897971017, 72.82192243848527, 76.80022471291679, 73.81244373321533, 71.39858395712716, 64.43106242588588, 59.64455958775112, 53.1502103805542, 42.53621864318848, 27.93615828241621, 16.251508201871598, 7.108050150530679, 1.8439472487994601, 0.26978014941726414, 0.05318499289985214, 0.053668937645852566, 0.05312032172722476, 0.03926757809572986, 0.062317063233682086, 0.08846756536513567, 0.021064812616844262, 0.05383250529744795, 0.06962502787687949, 0.052575234190693924, 0.2935786252575261, 0.1832470398928438, 0.4242024246071066, 5.1223796265465875, 26.640692710876465, 30.920560700552805, 17.691466774259293, 30.685992990221294, 56.76920740944998, 56.35284355708531, 47.73354761941092, 30.966835703168595, 32.88997547967093, 45.94261121749878, 47.39631332669939, 66.63050774165562, 62.8686557497297, 15.23237075124468, 0.09424810018390417, 0.006618758389127574, 0.0879230003005692, 0.06623640363769871, 0.11450841623757567, 0.026791980656396066, 0.02552626178865986, 0.06616436357476882, 0.07717425243130752, 0.022108879539051225, 0.039232138211705854, 0.039061642717570066, 0.047514753948364935, 0.038608428822564225, 0.037866206507065465, 0.09933309589645692, 0.07193100878170558, 0.013720643041389329, 0.02357603849044868, 0.03006354912317225, 0.049597622361034155, 0.06160698990736689, 0.018396180189613785, 0.09113886952400208, 0.0114227986196056, 0.05907807632216385, 0.06315791739949159, 0.08923739048519305, 0.10719163742448602, 0.0595983566184129, 0.02068167781856443, 0.015895814268982837, 0.009275789139792323, 0.045751095549868684, 0.03461173542642167, 0.01265298345658396, 0.028054876818454692, 0.03252452099695802, 0.006508069395619843, 0.03921501538051026, 0.04766066951145019, 0.04891506362972515, 0.019325147216607417, 0.04916009958833456, 0.07424598027552877, 0.05165372595989278, 0.054206778428384235, 0.03435025517163532, 0.04928620532155037, 0.04557213193870016, 0.01443348648691816, 0.03884464043325611, 0.08270760372813259, 0.02402835332655481, 0.0198686537665448, 0.03810660128614732, 0.032508616136120896, 0.036945414130709, 0.05067075602710247, 0.06406914921743528, 0.01798705241110708, 0.05136713312406625, 0.10170961051647152, 0.0649421252310276, 0.26766754420740263, 0.05094634981027671, 0.142781830525824, 2.320807329245976, 52.75376353945051, 95.52776690891811, 88.18267331804547, 84.98415347508022, 95.81050300598145, 59.28569207872663, 48.92681040082659, 20.00936324255807, 17.322065796170914, 27.84919810295105, 44.83507531029837, 34.83212552751814, 35.55436992645264, 42.42203542164394, 41.65505852018084, 13.228519831384931, 0.5870114469102451, 0.06275619752705097, 0.1268142323408808, 0.0826040253575359, 0.28641978225537706, 0.08916937413492373, 0.04056680641536202, 0.1894732636532613, 0.4313214240329606, 0.35910795469369206, 0.42853248225791113, 0.6657193377614021, 1.9825064880507333, 2.8040417305060794, 1.2782561864171709, 1.1409547882420676, 1.2644162433488029, 1.2869152703455515, 1.2838162652083804, 1.1645501106977463, 1.6299237332173755, 0.4053158366254398, 1.8005790902035577, 2.0322627552918027, 1.6781789724315916, 2.8889302611351013, 6.454507802213941, 5.463370723383767, 9.48487298829215, 12.676807676042829, 14.761508703231812, 11.818189246313912, 18.41575046948024, 20.005347183772496, 16.11709703717913, 22.466220208576747, 23.707211903163365, 17.109452656337194, 14.443333319255284, 11.199658002172198, 4.648906792913165, 4.219570219516754, 0.5710602828434536, 0.40514006891420906, 10.75900845868247, 39.16136046818325, 53.66932071958269, 59.988009044102256, 60.69302885872977, 66.00893579210553, 68.00307573590959, 70.1592685154506, 72.34451171330043, 71.46973351069859, 69.92073685782296, 66.0781398500715, 63.871565682547434, 59.96056365966797, 53.59482560838972, 42.07305172511509, 27.33271418298994, 15.614471299307686, 5.888290413788386, 1.8209155989544732, 0.32831087868128506, 0.08408154214599303, 0.03706622050542917, 0.04567159838708384, 0.04814952006563544, 0.025367231840001683, 0.14383005856403283, 0.14155991109354155, 0.025238620616229515, 0.17764626257121563, 0.1710626408457756, 0.06269487831741571, 0.32781085265534265, 1.5314654793058122, 24.402346168245586, 30.048130989074707, 20.18729271207537, 31.94852236339024, 40.95011860983712, 31.086337770734513, 27.93600194794791, 17.208902222769602, 38.542814459119526, 71.3037063053676, 69.07857349940709, 78.58897590637207, 75.678069795881, 29.61654015949794, 0.49889216678483145, 0.04632638468007956, 0.16816806473902293, 0.039262746926397085, 0.0672951964661479, 0.030140033590474298, 0.025898982770740986, 0.01350612928425627, 0.008953542681410909, 0.012349460323873376, 0.015496935761932815, 0.043842685275844166, 0.0506006565743259, 0.04419774229505232, 0.03786299703642726, 0.1118885993159243, 0.041472650665257654, 0.06183610404176371, 0.045497910385685306, 0.014820600893082363, 0.04570944028507386, 0.058034971223345826, 0.018564019219151566, 0.042959344639841995, 0.05907317729932921, 0.03429549739563039, 0.026994609872677496, 0.03244301876319306, 0.028054045613056848, 0.053780061325856617, 0.027226711257493923, 0.025623619689473083, 0.041659563314169645, 0.06988451323871102, 0.019345528712230067, 0.0744063181004354, 0.2294622500027929, 0.108809197055442, 0.09349380673042365, 0.17038874700665474, 0.10920190598283495, 0.1339490009205682, 0.12008946176086154, 0.12154083459505013, 0.20528135182602064, 0.10598439470465694, 0.08785257515098367, 0.15431586732821806, 0.12753642430262907, 0.09764044279498713, 0.17080192055021012, 0.14603601662175997, 0.1957659838455064, 0.12219199751104627, 0.13934260793030262, 0.1621891534222024, 0.09755775651761464, 0.19053906574845314, 0.11630175715046269, 0.16984378839177744, 0.12052375131419726, 0.14325244884405816, 0.21185362844594888, 0.21734501235187054, 0.3095583420779024, 0.23750994673797063, 0.24609857159001486, 2.4330409296921323, 58.631755420139854, 109.61108452933175, 98.7272594996861, 89.90520817892892, 95.36980656215123, 46.973036016736714, 53.826805114746094, 45.29814495359148, 56.66408463886806, 67.90450859069824, 75.7091977255685, 60.514404569353374, 52.956442492348806, 56.49788720267159, 59.428950037275044, 27.245080028261455, 3.640737290893282, 0.22301212325692177, 0.24277247435280255, 0.5648426221949714, 0.2739397319299834, 0.2852234978760992, 0.1666781511157751, 0.5460916055100304, 0.35500121648822514, 0.30896847801549093, 0.3474316698099886, 0.479099734553269, 2.526815337794168, 3.253501372677939, 1.7100538334676196, 2.3260768864836012, 1.6098458277327674, 4.056967173303876, 7.669954878943307, 9.048514825957161, 13.95119936125619, 14.527480346815926, 14.856396777289254, 17.34699419566563, 30.612383774348668, 27.333042485373362, 25.494530030659266, 19.609770604542323, 22.87215828895569, 22.286522422518047, 22.250344889504568, 12.822326404707772, 24.72300900731768, 32.23217562266758, 23.050294467381068, 29.425082547324045, 31.06110191345215, 24.555666855403356, 13.432357396398272, 15.276290314538137, 12.0889926808221, 9.471827745437622, 1.8520955315658023, 0.6643032623188836, 6.574490598269871, 34.97987897055489, 51.88658666610718, 59.11974825177874, 62.629241670881, 71.42334733690534, 72.48940944671631, 73.98506477900914, 76.5329761505127, 76.04007094247001, 74.35050528390067, 69.2988383429391, 64.24394743783134, 57.453869002205984, 47.817975180489675, 35.824904986790244, 20.56833713395255, 10.781485881124224, 3.661473103931972, 1.0836509317159653, 0.251060562474387, 0.12853396577494486, 0.15665612103683607, 0.1693636298711811, 0.438930298600878, 0.3005679159292153, 0.2114318646490574, 0.28735873901418274, 0.32204387496624676, 0.22847593149968556, 0.33655714190432, 0.4547525410141264, 1.3220568703753608, 8.783116221427917, 41.470844405038015, 45.4208779335022, 27.308298213141306, 44.76533276694161, 79.42487893785749, 78.17862919398716, 71.31719275883266, 41.603218010493684, 38.23098625455584, 59.87911687578474, 64.11224433353969, 79.68648556300572, 86.21655545915876, 28.615433284214564, 0.29636135165180477, 0.08246563135513238, 0.17708797752857208, 0.14473154661910875, 0.3186037295631, 0.15250017547181674, 0.16565045554723057, 0.09106725693813392, 0.1036924934014678, 0.09325843650315489, 0.07478657591023616, 0.12392771723014967, 0.19420749747327395, 0.20497451829058783, 0.17353245403085435, 0.17172548813479288, 0.1660978136850255, 0.13054777628609113, 0.13925453408488206, 0.10174437865082707, 0.12350756834660258, 0.16452871502510139, 0.05954232319657292, 0.23667556579623902, 0.10779018673513617, 0.12143173973475184, 0.09222647294934307, 0.135895663606269, 0.13126380714987004, 0.25809998331325396, 0.1101010734481471, 0.06430902491722788, 0.14250136486121587, 0.14852999922420296, 0.14333453801061424], [0.015355959933783327, 0.06312806864402123, 0.06652977503836155, 0.018794707554791654, 0.03719828038343361, 0.08792281709611416, 0.04340669259961162, 0.016777777478897145, 0.03922146146318742, 0.1378014920545476, 0.1153209347810064, 0.12264173052140645, 0.027847516516755735, 0.053972816161279163, 0.08092807778822524, 0.09707700088620186, 0.06140013850693192, 0.022902992820101123, 0.007288778217376343, 0.04417639897604074, 0.03661612108615892, 0.04634242524792041, 0.05351284405748759, 0.013677797795805548, 0.06139414704271725, 0.03868192434310913, 0.046082505623676946, 0.08771190805626766, 0.056965661102107594, 0.13836774309831007, 0.15940787909286364, 2.020241503204618, 45.70280456542969, 86.47880826677594, 85.3286382130214, 79.41275433131626, 68.00088010515485, 42.56549835205078, 20.705379928861344, 28.4633024760655, 59.38320309775216, 61.44386509486607, 58.591435023716514, 48.92654289518084, 48.27975940704346, 42.298461709703716, 17.51587884766715, 4.669040935380118, 0.3327255903610161, 0.2751364234302725, 0.11161234735378198, 0.3988610144172396, 0.03536039703924741, 0.08303558720009667, 0.20755540765821934, 0.3072841369679996, 0.155465943472726, 0.17119739790047916, 0.15801981357591494, 0.0818281884172133, 0.03863909860540714, 0.9441554227045604, 0.6774201041885785, 1.8441817505019051, 1.0756416129214423, 3.1968624804701125, 4.845971167087555, 4.4338778512818475, 3.843194987092699, 4.785116672515869, 3.5163363090583255, 3.9374064803123474, 3.4532725044659207, 5.058773645332881, 2.804966709443501, 7.7281008788517545, 6.049923752035413, 5.747462587697165, 10.921853389058795, 16.83169320651463, 10.749578016144888, 6.916778402669089, 14.321885756083898, 17.26798622948783, 14.4423405953816, 19.34514151300703, 12.964674149240766, 9.085651210376195, 11.238831077303205, 7.908443110329764, 0.7084006017872265, 1.6808151624032428, 18.693280628749303, 46.30325051716396, 45.58856575829642, 51.05127770560128, 44.52060679027012, 46.262752941676546, 46.12218393598284, 50.271585600716726, 52.65912560054234, 53.61893933159964, 52.07721396854946, 51.86607905796596, 53.81904745101929, 56.45935596738543, 60.23429489135742, 62.084864207676475, 60.96341800689697, 61.568133626665386, 52.86400018419538, 39.381208419799805, 20.09881435121809, 8.522449340139117, 3.2574110371725897, 0.4907598431621279, 0.13392545575542109, 0.04591248510405421, 0.07231252188129084, 0.03375159051003201, 0.02865725476294756, 0.10457496890532118, 0.1745234951376915, 0.18408121727406979, 0.10518786244626556, 0.029087266152990714, 0.1503815177295889, 0.8108180803912026, 9.137701034545898, 22.56778723852975, 36.07379640851702, 79.66832992008754, 83.07976341247559, 60.47940649305071, 67.76179259163993, 37.27372946058001, 25.7218142918178, 39.64154699870518, 44.150615215301514, 56.7205422265189, 68.2690736225673, 28.312658582414898, 1.1308277887957436, 0.10487705948097364, 0.12660763199840272, 0.08780992243971143, 0.16163891580488, 0.0642486692273191, 0.12576696782239846, 0.053071250074676106, 0.054531654209962914, 0.014139973442070186, 0.017483723615961413, 0.008130176907538303, 0.051546578495098014, 0.028999131239418472, 0.013768651090296251, 0.01316996437630483, 0.032532541280878444, 0.09972011191504342, 0.07011098108653512, 0.05759990135473864, 0.03933797610391464, 0.18615990930369922, 0.07229333291096346, 0.03303024671705706, 0.05425393321950521, 0.05078045478356736, 0.08358278498053551, 0.057463542957391055, 0.15217962195830687, 0.03856005945375987, 0.036753592280937095, 0.048893001063593795, 0.04409752267279795, 0.046463611602251015, 0.00664220134993749, 0.05739913641342095, 0.029810798221400807, 0.03682365780696273, 0.03783009826604809, 0.06968430469610862, 0.026652952223750095, 0.01585877813132746, 0.03858170472085476, 0.08290894542421613, 0.08841664131198611, 0.0432170352765492, 0.07025235385767051, 0.03916753489258034, 0.07096391317567655, 0.05306195753759571, 0.05616713395076139, 0.0758463933265635, 0.01770752651749977, 0.06799137339528118, 0.015760772229571427, 0.07980854929025684, 0.004281890994336988, 0.09056542600904192, 0.11285640059837274, 0.079939798318914, 0.0342950427771679, 0.09520157080675874, 0.06311235377298934, 0.08679914274918181, 0.13341037982276507, 5.763278424739838, 67.07506043570382, 98.44455814361572, 96.06872585841587, 103.30093901497978, 93.67861502511161, 70.53132370540074, 28.47144055366516, 16.65950468608311, 42.975275312151226, 58.740098680768696, 62.11557524544852, 52.51640960148403, 51.96122421537127, 42.31675284249442, 13.961983833994184, 1.4914463524307524, 0.13632347993552685, 0.1350776624998876, 0.031763211491384676, 0.11374209235821452, 0.010132659276548241, 0.09975431686533348, 0.1663302933531148, 0.7495266635503087, 0.31018454847591265, 0.8753609284758568, 0.5606924848897117, 0.8899555653333664, 0.11685890225427491, 0.16039792953857354, 0.2142164230878864, 1.0613500369446618, 0.5528635478445462, 2.4352291779858724, 2.5866920905453816, 1.05152256999697, 1.628192003284182, 1.1967002941029412, 1.1312949465853828, 0.6540448984929493, 1.108769646712712, 1.2520791739225388, 2.5026599253926958, 1.398985805256026, 0.30775460600852966, 4.568901325975146, 7.6474253450121195, 19.421672446387156, 19.27778046471732, 14.17062781538282, 17.68719710622515, 20.15084593636649, 23.241621800831386, 27.272388185773575, 19.879728964396886, 13.460197959627424, 13.060021672930036, 7.123554187161582, 0.6946640131728989, 2.5864050430910925, 23.415799243109568, 47.65275396619524, 48.79933874947684, 52.123885018484934, 47.29795810154506, 49.64459753036499, 50.52473626817976, 54.44753980636597, 56.05068724496024, 57.090169021061485, 59.42903341565813, 57.856312138693674, 59.319960594177246, 60.72987515585763, 64.31110872541154, 63.916833196367534, 64.54286588941301, 66.06208256312779, 59.6324280330113, 50.312069279806956, 29.234795706612722, 15.669342960630145, 6.835715072495597, 1.674561240843364, 0.17757994255849294, 0.018375646023611938, 0.0707384292036295, 0.07005637258823429, 0.035278813381280215, 0.015802086530519382, 0.07412551316831793, 0.3844327814877033, 0.01586271702711071, 0.01677513288866196, 0.09408631029405765, 0.5250164163964135, 6.175994907106672, 9.331421153885977, 24.38452751295907, 83.1940473828997, 81.43126160757882, 58.632478032793315, 45.790810448782786, 13.09716066292354, 30.419727597917827, 61.625004632132395, 67.58113248007638, 74.38433606284005, 79.9317569732666, 45.99775559561593, 2.794000497886113, 0.10460395592131785, 0.10712273219334227, 0.030196718405932188, 0.14142119139432907, 0.02209775156474539, 0.21531068294176034, 0.07610173962478127, 0.04763979098892637, 0.09046234975435904, 0.0976659149995872, 0.010564752072761101, 0.028992773366293738, 0.06581066362559795, 0.028439365294096724, 0.10992160772106477, 0.03852014463128788, 0.06811927046094622, 0.13455377918268951, 0.0530048316743757, 0.014969661465979047, 0.04469502025416919, 0.07514099510652678, 0.024910206274528588, 0.08079112906541143, 0.028519997306700264, 0.04482088510745338, 0.03617145333971296, 0.06198247761598655, 0.10396496592355625, 0.0601195665076375, 0.060585692924048216, 0.07019198459706136, 0.04051428780491863, 0.14074902103415557, 0.1377630326896906, 0.14743614649134024, 0.07282644430441515, 0.154994239498462, 0.16391918701784952, 0.14030242285558156, 0.10705924167164735, 0.09647943545132875, 0.19774622044392995, 0.18889524681227549, 0.2482578328677586, 0.10095655199672494, 0.07960857144956078, 0.17479633406869002, 0.2419908834355218, 0.08930076565593481, 0.16236266839717114, 0.12779406404920987, 0.18610179956470216, 0.18953765662653105, 0.14039455434041365, 0.18485301014568123, 0.18347742967307568, 0.2155215037720544, 0.19546924691115106, 0.11458467000297137, 0.2267611242298569, 0.18748742235558374, 0.31633978390267914, 0.15672926711184637, 6.85371481520789, 78.41493047986711, 111.91689981733049, 104.1522045135498, 103.69638878958565, 86.52982194083077, 55.011417388916016, 27.73392227717808, 45.37473842075893, 83.50422886439732, 86.7731409072876, 86.14456517355782, 70.93117863791329, 66.77065985543388, 56.929627418518066, 25.80339309147426, 7.723610605512347, 0.9078647643327713, 0.21255433798900672, 0.1952025555074215, 0.6352366134524345, 0.40293846705130165, 0.2349871535386358, 0.6445936656423977, 0.6007643203650201, 0.34482511824795176, 0.25555865253720966, 0.5047813079186848, 0.7942270306604249, 0.45443039972867283, 4.534207667623248, 3.3030624389648438, 5.016667127609253, 6.43093169586999, 15.3814617225102, 15.911343506404332, 13.908315948077611, 11.696614009993416, 13.244154146739415, 13.640980533191136, 14.517335108348302, 13.071936964988708, 15.334288665226527, 13.423510602542333, 21.26828302655901, 16.61803436279297, 15.361150400979177, 23.473682948521205, 30.014477389199392, 24.406799963542394, 19.543170383998326, 25.46923337663923, 30.23553432737078, 28.277691773005895, 37.49369205747332, 26.15720578602382, 17.260058334895543, 21.953000204903738, 15.653952700751168, 1.4927928916045596, 3.2781818083354404, 19.07783215386527, 46.029748576028005, 51.338544028145925, 59.08561175210135, 51.645887170519146, 57.4543171610151, 56.94205774579729, 64.26966966901506, 66.39130905696324, 68.8894852229527, 67.29362991877964, 67.30055727277482, 66.82502256120954, 68.69597789219448, 72.3902586528233, 74.08208247593471, 71.02192211151123, 72.29644407544816, 61.65472207750593, 49.16299704142979, 25.50026055744716, 11.854854890278407, 4.415795164448874, 0.9830781455550874, 0.212597465674792, 0.15887957172734396, 0.23326988997203962, 0.1688002829572984, 0.1552383221153702, 0.19581995452088968, 0.30980902005519184, 0.534000817154135, 0.21602907510740416, 0.11721693804221493, 0.3332211651972362, 2.8166980913707187, 16.815154756818497, 33.94124140058245, 45.43456588472639, 89.2031899860927, 99.20395456041608, 72.30056435721261, 93.64019843510219, 52.71433251244681, 31.256370612553187, 51.058708803994314, 61.551318986075266, 71.44699205671037, 89.48882348196847, 48.996007510593955, 2.3265708599771773, 0.3702948529805456, 0.3262676740331309, 0.21748593050454343, 0.29320268971579416, 0.13595327122935227, 0.2751333564519882, 0.17193686536380223, 0.14027842985732214, 0.1429537712995495, 0.21846022536712034, 0.09587259444275073, 0.1556259420301233, 0.2608782042350088, 0.08977934318993773, 0.25582683671798023, 0.10229302171085562, 0.15187327696808747, 0.1689419610691922, 0.09761220216751099, 0.21592786482402257, 0.2233989696417536, 0.26360721779721125, 0.06309322587081365, 0.17744123642998083, 0.13378088708434785, 0.12814512449715817, 0.14480530337563582, 0.21275576789464268, 0.1245378694896187, 0.15562234579452447, 0.09777769685855933, 0.16749803854950837, 0.12485394467200552], [0.06121010120425906, 0.017708875105849335, 0.11009578087500163, 0.006192017113789916, 0.03200325003958174, 0.07248603685625962, 0.0688909954790558, 0.04878437778513346, 0.010606314038990863, 0.03650723657171641, 0.03339965475190963, 0.08906435727008752, 0.020178328667368208, 0.017266780703461597, 0.01611661465306367, 0.02945949350084577, 0.028477263171225786, 0.011791888591168182, 0.04981989007709282, 0.07459448943180697, 0.047634800363864215, 0.01900512465674962, 0.07614396485899176, 0.08985377169613327, 0.05521583803264158, 0.06763946477855955, 0.11390386867736067, 0.03560987061687878, 0.04594898011003222, 0.06630062697721378, 8.68415824004582, 61.26244068145752, 90.91148798806327, 77.50837816510881, 74.95916053227016, 53.861764975956504, 37.69906343732561, 32.89864683151245, 62.87417956760952, 73.91702801840646, 43.32434238706316, 27.80370650972639, 35.071105343954905, 55.93109485081264, 24.547933510371617, 3.6878675733293806, 0.2182641423174313, 0.09098206008119242, 0.04830325235213552, 0.43757282144257, 0.3172265206064497, 0.16314064950815269, 0.1145029743867261, 0.18624334196959222, 0.10729620645620994, 0.4497892473425184, 0.17382670752704144, 1.1229327895811625, 0.16543099018079893, 0.7594577563660485, 0.31698021239468027, 0.21023507815386566, 2.330300522702081, 0.8831202749695096, 2.1857460737228394, 2.1000834703445435, 1.8690680265426636, 0.8484057177390371, 0.9575665316411427, 0.6627616850393159, 0.3884404535804476, 0.5945412857191903, 0.728293891463961, 0.2926323131791183, 1.9725594903741563, 2.8506923701081957, 0.9987685893263135, 1.4756726388420378, 4.342192462512425, 9.870246137891497, 8.846551537513733, 10.530939051083156, 8.798682791846138, 6.094614131110055, 8.436837111200605, 6.101703464984894, 10.45217774595533, 18.73262480327061, 3.849436640739441, 0.6317009031772614, 0.47869185358285904, 12.949695570128304, 40.04491424560547, 36.24011891228812, 39.27828822817121, 37.6252110345023, 35.67027630124773, 34.05163785389492, 39.147509234292166, 42.249334471566335, 43.26333025523594, 45.440204347882954, 48.22481305258614, 51.50928906032017, 52.59640073776245, 53.98838547297886, 55.3403833253043, 52.55014310564314, 53.095548902239116, 53.13594920294625, 50.5300030027117, 51.7503012248448, 46.97376210348946, 40.428374903542654, 27.974218777247838, 15.613783427647181, 5.414890101977757, 1.5086794048547745, 0.02610132869865213, 0.010353770090400108, 0.09735511881964547, 0.31945493817329407, 0.09153948338436228, 0.06352809217891522, 0.06771158626569168, 0.019999287024672543, 0.03342894371598959, 0.1083026435226202, 0.3554948642849922, 4.832182901246207, 19.00807397706168, 44.43680109296526, 82.76246002742222, 81.45828315189907, 89.75520351954869, 84.72654206412179, 50.44749314444405, 24.250090292521886, 24.000467572893413, 31.074977466038295, 52.96714966637747, 56.9561174256461, 41.05962916782924, 6.288450632776533, 0.21414607257715293, 0.04590414251599993, 0.033725314241434844, 0.04596154997125268, 0.12562053996537412, 0.035767494301710806, 0.09073710893946034, 0.09257194905408792, 0.05816959257104567, 0.01720987875679774, 0.03857088547998241, 0.029817128953124796, 0.08396767039916345, 0.024055082517276918, 0.017581895758797015, 0.08400258781122309, 0.032849091437778304, 0.025885186457474316, 0.1420357541314193, 0.10607458557933569, 0.02009591889301581, 0.10589523520320654, 0.061631335743835995, 0.043789365994078774, 0.09567619926695313, 0.08844529584582363, 0.09147001496915307, 0.033006274074848206, 0.0222883690148592, 0.02856577467173338, 0.05002032932160156, 0.03471436724066734, 0.035998474407408915, 0.009287645691074431, 0.03513434988313487, 0.029902929706232886, 0.022893534041941166, 0.10216162340449435, 0.06224669236689806, 0.027422879124060273, 0.01730668534790831, 0.07204527407884598, 0.02303935630646135, 0.05045028642884322, 0.04159996758348175, 0.01680165173352829, 0.02342572432410504, 0.07675700767764024, 0.040249404697013755, 0.022869814154026762, 0.08140611927956343, 0.03623612790501543, 0.02471981443730848, 0.03253752851326551, 0.07116967892008168, 0.007120630454405078, 0.03775517442928893, 0.0849925364766802, 0.06162364794207471, 0.05162209944267358, 0.04062612394669226, 0.27894666897399084, 17.06538544382368, 82.60351303645542, 100.73952729361397, 94.68517971038818, 100.17632021222795, 78.617157799857, 61.05983815874372, 30.38591766357422, 32.826979637145996, 62.310194287981304, 53.592935698372976, 30.2876284463065, 38.27119547980172, 61.39005824497768, 20.699779680797032, 1.5101136650357927, 0.2961618894977229, 0.07953080455107348, 0.09613913656877619, 0.28054757735558916, 0.22317901573010854, 0.5573336822646004, 0.42347641927855356, 1.5246102128710066, 0.5668699219822884, 0.5604921813522066, 1.1028136291674204, 0.606483664895807, 0.6330707296729088, 0.2958632798067161, 1.1612160610301154, 0.7689012810587883, 1.0599009032760347, 0.3665450241948877, 0.5171063808458192, 1.0430318713188171, 1.4031406108822142, 1.1824246772697993, 0.6609570533037186, 0.9264390362160546, 0.6194403725011008, 1.0508478347744261, 0.45668853712933405, 0.17426110564598016, 1.8230661749839783, 2.4963637718132565, 0.5740867661578315, 1.2853621308292662, 2.583176519189562, 5.203264040606363, 12.025527834892273, 8.361658470971243, 8.800332989011492, 11.005687747682844, 8.829432044710432, 8.032768964767456, 14.201623729297093, 22.676561287471227, 5.905330436570304, 0.32818505114742685, 0.21752551623753139, 16.33772666113717, 40.54514632906233, 41.49958562850952, 44.583644321986604, 42.57020575659615, 40.924861907958984, 42.638492652348106, 47.685778754098074, 50.14527082443237, 49.52562352589199, 53.580929211207796, 56.46648134504046, 60.04151017325265, 60.83408423832485, 63.235062054225374, 65.47158295767647, 62.35063280378069, 59.365269797188894, 59.36379677908761, 57.791019916534424, 54.93569939477103, 52.448748043605256, 45.88113355636597, 36.285678250449045, 24.972748109272548, 10.25903606414795, 2.989010593720845, 0.38359723346573965, 0.03950439699526344, 0.03619784495926329, 0.09470666093485695, 0.0834738936807428, 0.1791848407260009, 0.16844673907118185, 0.18395031429827213, 0.0692882573764239, 0.12654944083520345, 0.3338568982269083, 1.4562580691916602, 8.998494744300842, 40.517815589904785, 82.8772303717477, 85.99761077335903, 91.69405664716447, 79.46089145115444, 19.001638208116802, 25.06964421272278, 40.01619734082903, 54.90120158876692, 70.10518373761857, 65.81261444091797, 59.63656915937151, 12.796764850616455, 0.1242726030094283, 0.0326967263993408, 0.022311736064563905, 0.13671650098902838, 0.1013733557026301, 0.07348712706672293, 0.07291067764163017, 0.08696646269943033, 0.03491990228316613, 0.03205056767910719, 0.03432315109031541, 0.01081496016455016, 0.062401004800839086, 0.04026506528524416, 0.039144963425184996, 0.019790400019181625, 0.022617918206378818, 0.06570164340415172, 0.09314463939517736, 0.08225065789052419, 0.011635545641183853, 0.07285559416881629, 0.052948448807001114, 0.01481437194161117, 0.06425195333680936, 0.01479558161060725, 0.028296677861362696, 0.0651227105408907, 0.005471684337992753, 0.08005098306706973, 0.05616504745557904, 0.008790155689764236, 0.10551119116800171, 0.12366387567349843, 0.10290495173207351, 0.11508371893848691, 0.09920108690857887, 0.19176391645201615, 0.10733650465096746, 0.1002551367772477, 0.12346406068120684, 0.18734904192388058, 0.1062569215095469, 0.1480192116328648, 0.18523311189242772, 0.16987090265112265, 0.10169589732374464, 0.12195787578821182, 0.09156232965844018, 0.08207402843981981, 0.25242626347712105, 0.16160941310226917, 0.10395914409309626, 0.09864205547741481, 0.15841214252369745, 0.23657134281737463, 0.12275408234979425, 0.1547390424779483, 0.2911118247679302, 0.07575150020420551, 0.1744395060730832, 0.44211520627141, 22.200878926685878, 97.10616139003209, 113.77462577819824, 96.55341134752545, 98.6490227835519, 67.52676282610211, 49.61600916726248, 43.312804903302876, 83.835268838065, 98.71601731436593, 61.31465639386858, 47.522784437452046, 50.201714515686035, 78.14386735643659, 38.159725529806956, 6.495600751468113, 0.4895976483821869, 0.22617941615836962, 0.23541313782334328, 0.885188124009541, 0.7017330995627812, 0.47872985154390335, 0.36046326053994043, 0.7185471430420876, 0.1885181984731129, 0.7219960008348737, 0.7784498972552163, 1.9127090104988642, 2.5090789752347127, 1.9511021503380366, 3.3178325721195767, 1.7378111268792833, 7.637718711580549, 5.30409152167184, 4.744773260184696, 6.3846341116087775, 4.792334982327052, 3.4687876147883276, 2.813876688480377, 2.601680657693318, 1.2135962503296989, 1.302310741373471, 1.9096016458102634, 4.173450248582022, 7.007859298161097, 9.938213416508265, 6.995872352804456, 7.567690423556736, 12.42377860205514, 20.385726315634592, 16.22863473211016, 20.30672182355608, 18.29360808644976, 16.192000355039323, 17.906162636620657, 14.50643685885838, 21.145197425569805, 30.47975308554513, 13.058993339538574, 1.7703669113772256, 0.8323685697146824, 15.74574361528669, 44.43249320983887, 44.96573271070208, 49.64386102131435, 53.07610089438302, 52.550483567374094, 51.79376915522984, 57.740530831473215, 61.70234503064837, 60.9163578578404, 63.39627415793282, 66.1091913495745, 69.13669518062046, 70.70755086626325, 71.16524955204555, 71.31778335571289, 70.35325527191162, 66.79889038630894, 63.73966802869524, 62.2326454435076, 61.837772369384766, 56.453814779009136, 49.508728981018066, 35.83245767865862, 21.998392786298478, 7.379646113940647, 1.8550556812967574, 0.1908933560230902, 0.05576089842777167, 0.2500250908945288, 0.8844421697514397, 0.3166165719074862, 0.26880805300814764, 0.4023707503718989, 0.6940397066729409, 0.1840709171124867, 0.27254211263997213, 0.6720843762159348, 8.219151786395482, 28.396599769592285, 56.98383378982544, 92.54552364349365, 97.53822817121232, 94.96205152784074, 108.46902302333287, 65.8853759765625, 32.78217417853219, 30.01940713609968, 47.552324703761506, 66.76404517037528, 76.38568823678153, 66.42519542149135, 10.572262593678065, 0.467446574143001, 0.11505884384470326, 0.2099331843533686, 0.2045629732310772, 0.1810524540820292, 0.20454695980463708, 0.29291395949465887, 0.17341808016811097, 0.18433528792645248, 0.0879272615004863, 0.1259197196257966, 0.10000420095665113, 0.18611727016312735, 0.16257366564657005, 0.07577356616301195, 0.20250265592975275, 0.13166322000324726, 0.18445471008973463, 0.2860716123666082, 0.2762645014694759, 0.11776860058307648, 0.2523746133915016, 0.13661871052214078, 0.12733943201601505, 0.14948182100696222, 0.14998097850808076, 0.1855502048773425, 0.2167563017989908, 0.08365865876632077, 0.11952125653624535, 0.13490182693515504, 0.21130405579294476], [0.033549638132431676, 0.1084388933543648, 0.03415878616007311, 0.04032405711976545, 0.07566773505615336, 0.011927995082390095, 0.03352249673168574, 0.04060648714325257, 0.07724430438663278, 0.06338876179818596, 0.046603488203670294, 0.053570417753819904, 0.0880725494186793, 0.04716716081436191, 0.03782264455886824, 0.07564965209790639, 0.009090142806858888, 0.06322044440146003, 0.021203576420832957, 0.08322867791035346, 0.01481119470138635, 0.05024289220039334, 0.07493939556713615, 0.061865457466670444, 0.07415321096777916, 0.05596185675156968, 0.01219762793542551, 0.044806313567927906, 0.2690781642283712, 19.453239849635533, 85.48746013641357, 87.21881226130894, 74.02446106501988, 67.35056345803397, 41.20494031906128, 38.53864901406424, 35.1219870022365, 66.86046532222203, 83.24488040379116, 32.822108949933735, 20.950684343065532, 34.48540694372994, 40.9851062638419, 7.523883768490382, 0.4097471045596259, 0.031026977247425487, 0.08863717197839703, 0.12704604704465183, 0.08572268086884703, 0.04766257619485259, 0.1409031841903925, 0.5418121665716171, 0.18999226151832513, 0.29476223460265566, 0.41990284674933975, 0.8596887780087334, 1.622024608509881, 5.359425672463008, 0.8860723365630422, 1.2125273134027208, 0.8420087067144257, 0.6081450443182672, 0.6938325635024479, 1.6082525189433778, 5.559373549052647, 9.573059524808611, 15.142613921846662, 19.652370010103496, 32.90546301433018, 44.895003523145405, 48.750482491084504, 49.392773968832834, 38.213362148829866, 27.527729272842407, 15.999144417898995, 4.695687276976449, 0.3931659071573189, 2.8032602752958025, 2.593905189207622, 3.974767812660762, 5.2665126238550455, 4.830464959144592, 3.7290734308106557, 9.617617453847613, 12.893781679017202, 2.6081754863262177, 8.519595367567879, 8.209580642836434, 4.100118960653033, 0.019650229951366782, 2.9139982759952545, 16.416203090122767, 27.404754843030656, 38.47782448359898, 33.91633905683245, 35.82827486310686, 38.94336421149117, 47.680487700871055, 55.28695167813982, 55.290092263902935, 55.27960048403059, 57.63457080296108, 56.75299726213728, 55.298541273389546, 54.19063016346523, 54.689917291913716, 53.801312174115864, 50.69005823135376, 51.65277978352138, 49.78203289849417, 53.417691707611084, 53.14973095485142, 51.26319081442696, 45.24307353155953, 42.62574618203299, 39.09957013811384, 27.278962918690272, 16.050145932606288, 6.569401477064405, 0.7860791278736932, 0.11892563849687576, 0.0035402403445914388, 0.04822141085086124, 0.07830356540424482, 0.12087772946272578, 0.04958142912281411, 0.1071151936692851, 0.109565254699971, 0.10505067623619523, 0.5480455149497304, 0.7477706692048481, 0.7072076829416412, 14.534431150981359, 45.21522862570626, 58.587071555001394, 54.08977358681815, 66.98940999167306, 56.567153794424875, 26.963968072618755, 30.957208974020823, 33.319391523088726, 48.25981460298811, 52.58341108049665, 62.79470607212612, 17.02736837523324, 0.11148357497794287, 0.11309751801724945, 0.06395062950572797, 0.03861550933548382, 0.021781917262290205, 0.019440435405288423, 0.022866445227659175, 0.034096103095050366, 0.04012626755450453, 0.08199263137898274, 0.03917334654501506, 0.10921768870736871, 0.06948930051709924, 0.03868187006030764, 0.032840243341135125, 0.05441640503704548, 0.024067262220861654, 0.02930262977523463, 0.10477645309375865, 0.06004334666899272, 0.02402181224897504, 0.038397570672844133, 0.07191675954631396, 0.051514103809105496, 0.023475538972499113, 0.017592307878658175, 0.13341707017804894, 0.027365123919610466, 0.03642913719106998, 0.12299838209790842, 0.09451612830162048, 0.04999982060066291, 0.07364625031394617, 0.0037339302860865636, 0.009218958439305425, 0.014900025113352706, 0.07373874820768833, 0.040567505306431224, 0.045455932816756625, 0.023754757829010487, 0.0467603213952056, 0.06307369084762675, 0.08402981063617126, 0.04264587163925171, 0.022990265994199684, 0.01424133385132466, 0.014790628304971116, 0.022049962343381982, 0.16188111209443637, 0.024094386658232127, 0.07342822344175406, 0.06564423255622387, 0.0727274256891438, 0.05606033932417631, 0.021492243877479007, 0.05555489519611001, 0.03488828255129712, 0.1049821102725608, 0.07290818741811173, 0.9317323693207332, 33.21820490700858, 104.49879455566406, 98.28382546561105, 87.47893892015729, 87.68271568843296, 66.96979522705078, 55.81073815482003, 31.38007981436593, 35.28335196631295, 74.29627459389823, 43.17318432671683, 20.055525336946758, 35.722683089120046, 40.91712161472866, 6.292860567569733, 0.36592172192675726, 0.017729567031243017, 0.22134443345878804, 0.17238149579082215, 0.08159528127206223, 0.10726802011153527, 0.5495449687753404, 2.7796005734375546, 0.7864445596933365, 0.5581434188144547, 0.8191064127853939, 0.7263615865792546, 0.02895186449001942, 0.7268265187740326, 1.1570539815085275, 0.7234310752579144, 0.4399449255849634, 0.6906373692410332, 1.6070639427219118, 2.9757922972951616, 9.261139256613594, 13.351007887295314, 21.790561744144984, 28.61381609099252, 44.48915229524885, 57.333199637276785, 58.342703410557334, 59.8746839250837, 47.8074243409293, 35.303835255759104, 20.069400889532908, 7.211987818990435, 1.1577483671052116, 1.252091116138867, 2.1414502220494405, 2.842708455664771, 2.6556171349116733, 2.3375514021941592, 3.8710676857403348, 12.297737411090306, 15.94210318156651, 6.232802510261536, 11.81347141947065, 9.354266830853053, 3.6821292298180714, 0.4148041717708111, 3.6381488697869435, 17.6858526297978, 33.217937401362825, 43.96772125789097, 39.62387425558907, 44.0635473387582, 49.13664599827358, 56.90571171896798, 62.23336805616106, 62.4310998916626, 66.07233115604946, 67.1252611705235, 67.37358283996582, 65.07682800292969, 65.34910706111363, 63.808538573128835, 63.42920167105538, 61.88895974840437, 59.19437885284424, 57.32269396100725, 61.274287360055105, 60.285009792872835, 56.89766917909895, 53.57468278067452, 50.98756272452218, 46.16975130353655, 36.582123143332346, 23.28769530568804, 11.850862281663076, 3.0108937280518666, 0.2350482488317149, 0.027389795452888523, 0.06007953294153724, 0.14771119744649955, 0.0974686173722148, 0.054833517476384125, 0.06680137225027595, 0.12863622100225516, 0.08431579957583121, 0.41111655107566286, 0.6543935026441301, 0.20881265162357263, 11.589444994926453, 46.855170249938965, 58.11359003611973, 52.07411854607718, 83.92793001447404, 21.8219085420881, 16.746921709605626, 40.81848498753139, 50.18494503838675, 66.78186729976109, 58.50142111097063, 78.55524935041154, 29.085756846836635, 0.18050560913980007, 0.09410343651792832, 0.006696992204524577, 0.06133140969489302, 0.04962378667135324, 0.02632420200721494, 0.04909693815612367, 0.09633650204965047, 0.05686283251270652, 0.06209095500941787, 0.026523638716233627, 0.022887966662113155, 0.11332407407462597, 0.0025126253520803793, 0.06877577344753913, 0.018078133862997805, 0.04730452683621219, 0.12432369669633252, 0.04455399014321821, 0.04573814910171287, 0.04152299117829118, 0.007788123163793768, 0.022510078635865023, 0.06210773518042905, 0.034954575422619066, 0.022788388255451406, 0.054358332617474456, 0.04547425665493522, 0.009816046355159154, 0.08718112403792994, 0.08966889125960213, 0.1485400279717786, 0.14584563326622757, 0.1098463378314461, 0.122213819197246, 0.17340518800275667, 0.14188396584774765, 0.11243450109447752, 0.1844694342996393, 0.18207176295774324, 0.24312770100576536, 0.1144530206386532, 0.23192685203892843, 0.17000735604337283, 0.18027986053909573, 0.14295862961028302, 0.14470095826046808, 0.09862359253955738, 0.1994693601237876, 0.1425385485802378, 0.1754189170897007, 0.14270176339362348, 0.10469532066157886, 0.16091662884822913, 0.1641272394252675, 0.1335428027170045, 0.10889038377042327, 0.23623174961124146, 0.15041935284222874, 1.9850156562668937, 44.12942320959908, 124.41752896990094, 110.99967506953648, 95.42507253374372, 88.81614058358329, 57.50206518173218, 53.50943572180611, 49.20469318117414, 100.07645375388009, 117.36225863865444, 50.282775674547466, 38.6725685937064, 48.22381946018764, 60.745327949523926, 14.83165076800755, 1.0938240715435572, 0.3532250017992088, 0.48264673565115246, 0.3352779948285648, 0.1720710795904909, 0.1334025359579495, 0.3615621072905404, 0.9737272816044944, 0.6606861278414726, 0.5272869031344141, 1.470192790031433, 4.0482259052140375, 3.653464436531067, 9.695054258619036, 4.429688087531498, 2.5891037668500627, 1.7944002960409438, 1.607210289154734, 1.2213821411132812, 2.4079034328460693, 7.279089178357806, 10.842544913291931, 18.425552640642437, 29.294699600764684, 46.21077694211687, 60.250317437308176, 59.62679304395403, 61.59693390982491, 48.213470118386404, 33.3704468863351, 16.481611694608414, 5.132908752986363, 1.667507950748716, 7.106285742350987, 10.313810450690132, 15.259519100189209, 13.553005916731697, 15.997282300676618, 16.4125657081604, 19.2034364768437, 26.136421986988612, 8.890399013246808, 17.751240389687673, 16.090337787355693, 9.662099821226937, 1.3966782433646066, 4.040834324700492, 19.690797022410802, 37.04819788251604, 51.89334726333618, 47.70108910969326, 53.39621829986572, 56.87198863710676, 66.52686146327427, 72.45770481654576, 72.86463301522392, 73.56802000318254, 76.42743301391602, 75.5539471762521, 73.79706042153495, 73.0160551071167, 72.03782517569405, 71.6305843080793, 68.30410643986293, 67.75837407793317, 65.59865161350795, 69.8009568623134, 68.26056207929338, 63.029902594430105, 57.41914190564837, 54.586740016937256, 49.125195366995676, 37.514356000082834, 22.400099413735525, 9.966481293950762, 1.9068488563810075, 0.24882248256887707, 0.15517760680190154, 0.23106736530150684, 0.20988066574292524, 0.33382416569760864, 0.19241148313241346, 0.3783692568540573, 0.21147446307752812, 0.31325410519327435, 1.158813612801688, 0.9823699721268245, 2.3516712273870195, 25.983549458639963, 62.11702741895403, 78.66271713801792, 63.15268421173096, 96.43515300750732, 76.10552297319684, 39.803040504455566, 38.17951052529471, 48.64904573985508, 65.1284739630563, 68.14757742200578, 88.34347547803605, 27.742439031600952, 0.2327376471034118, 0.2697955657328878, 0.12713934560971601, 0.09997501038014889, 0.23360723044191087, 0.17884550536317484, 0.152597043131079, 0.26345226754035267, 0.2226583758102996, 0.2674300569508757, 0.12385461186724049, 0.15463063972336905, 0.2091973674084459, 0.0940144941476839, 0.12795669532247952, 0.10418197499322039, 0.15011226146348886, 0.35623357178909437, 0.24256025574037007, 0.12233260353761059, 0.1791715957224369, 0.09302502045673983, 0.16400605307093688, 0.15246509521135262, 0.13811447311724934, 0.13986469991505146, 0.2148078749222415, 0.0876602783266987, 0.1463868599385023, 0.24320073851517268, 0.16489618244980062], [0.016935034754819105, 0.03492912696674466, 0.05160681204870343, 0.04681145579421094, 0.03821292433089443, 0.04574562655761838, 0.0685523793633495, 0.029245276602783372, 0.02813041303306818, 0.022590905727286423, 0.06074847347502198, 0.21172812660889967, 0.1360058576932975, 0.04030593344941735, 0.08223902101495437, 0.022702000569552183, 0.01661066957084196, 0.0963896924097623, 0.06317961016403777, 0.034792917847101174, 0.07519913198692457, 0.16300055916820252, 0.02861071065334337, 0.1350635625422001, 0.0694672820557441, 0.09253137265997273, 0.06305577073778425, 0.9852305671998433, 31.524633611951554, 83.9115183694022, 79.83096640450614, 81.1738725389753, 66.87584863390241, 54.13650369644165, 40.75125074386597, 28.35193501199995, 63.493041719709126, 65.0066442489624, 21.559292691094534, 23.59031367301941, 35.72664703641619, 35.32516622543335, 4.214330843516758, 0.340443383370127, 0.02999946827601109, 0.2780929362135274, 0.09883882384747267, 0.08710763869541031, 0.10007248872092792, 1.2667850362403053, 0.6897977771503585, 6.854696248258863, 2.9524189914975847, 6.37262328181948, 5.812229352337973, 1.3539481248174394, 1.7869591010468346, 0.6271673121622631, 1.440908738545009, 0.561204263142177, 5.741971339498248, 23.60367853300912, 42.95273188182286, 60.083887236458914, 73.91217122759137, 76.97634070260185, 78.45400020054409, 76.56495870862688, 82.81686442238944, 74.79430062430245, 82.56675706590924, 78.05065727233887, 81.42338235037667, 91.98209421975272, 81.16018458775112, 75.02196529933384, 52.15655197416033, 24.246569292885916, 9.767774105072021, 0.9187122051204953, 3.7098981397492543, 2.0947131642273495, 9.008585265704564, 11.42967985357557, 4.57767516374588, 1.803375523005213, 2.4166863901274542, 2.5381044234548296, 0.4202515051833221, 0.124423264924969, 2.938283315726689, 15.007054567337036, 26.990326063973562, 41.025843552180696, 51.663525172642295, 58.436080251421245, 62.18964304242815, 62.991812569754465, 64.83890083857945, 68.26798275538853, 70.46788665226528, 68.50383935655866, 69.98090130942208, 68.36169310978481, 67.84019606454032, 64.72001021248954, 64.57350049700055, 61.236558641706196, 61.681396211896626, 54.218151978084016, 53.71289982114519, 51.463990279606406, 50.5237843649728, 51.45830317905971, 47.812444414411274, 45.24960136413574, 42.62078864233834, 31.295548030308314, 24.045099326542445, 13.774705563272748, 4.728912694113595, 0.4545872227421829, 0.08705589361488819, 0.1519370592598404, 0.06331832986325026, 0.06225438016865935, 0.038902946947408576, 0.0315853810336973, 0.1572062365178551, 0.26672660612634247, 0.07775220820414168, 0.1309637725353241, 0.2510652036539146, 7.327872480664935, 52.440173966544016, 48.85349995749337, 15.866499832698278, 56.427085059029714, 63.337006023951936, 25.147410188402446, 33.10416759763445, 39.6701214654105, 48.83740792955671, 57.37297807421003, 63.009391512189595, 28.57118715558733, 0.5965897015162877, 0.10558074100741319, 0.04637538169377616, 0.03681382583454251, 0.06106631963380745, 0.011962471446687621, 0.06954252480396203, 0.039782128163746426, 0.038943258712866476, 0.08806463091501168, 0.06247522296117885, 0.07871373303766761, 0.0401801500203354, 0.026116739925263182, 0.10409871874643223, 0.049363802586283, 0.08408900603119816, 0.09022712880479437, 0.08593764754810504, 0.13825957104563713, 0.10098511153565985, 0.11052198907626526, 0.07027606187122208, 0.03537528749023165, 0.032050279301724265, 0.03597280203497835, 0.06544266015823398, 0.02170060501833047, 0.026155202682795267, 0.02343973098322749, 0.014848291907193405, 0.059423647421811304, 0.05867167455809457, 0.015551690145262649, 0.040078437621040006, 0.030233654459672313, 0.020571736485830376, 0.02631647858236517, 0.06558602103697402, 0.012089271830128772, 0.00841107259371451, 0.07472889364830085, 0.038799568744642396, 0.04568523694095867, 0.026226777949237397, 0.04216873599216342, 0.009750586385572595, 0.028686614973204475, 0.02686038037895092, 0.05726106810782637, 0.06108539325318166, 0.08428702969104052, 0.011684193209345852, 0.1874761451035738, 0.06323080563119479, 0.14860192393617971, 0.02986370020412973, 1.1208165202822005, 44.71755347933088, 102.16511699131557, 88.82260935647147, 99.9066606249128, 89.37575544629777, 69.94896738869804, 55.931456157139365, 26.992453949792043, 36.01523699079241, 71.0862068448748, 27.6098986693791, 23.637102842330933, 32.25776931217739, 34.699335030147004, 1.4488208911248615, 0.029298239653663974, 0.024722221540287137, 0.16190942057541438, 0.08298133154000555, 0.09384895195918423, 0.2221350081797157, 1.6790767014026642, 2.31352344581059, 4.554154208728245, 3.290741980075836, 1.9722667975085122, 1.3889767080545425, 0.5915688137922968, 0.16047009852315697, 0.5300878956913948, 1.1820791129555022, 1.1551839389971323, 9.6056934765407, 34.00388983317784, 53.875032561165945, 74.0314440046038, 89.86244201660156, 92.50619683946881, 93.11727700914655, 90.61149951389858, 94.84131268092564, 84.02529512132917, 89.68784073420933, 85.11623178209577, 86.70813356127057, 98.15062155042375, 89.29143905639648, 86.00584438868931, 68.02829769679478, 35.65035581588745, 13.961558256830488, 1.9218252641814095, 2.1611824546541487, 0.7104310499770301, 7.312213846615382, 12.751980236598424, 7.117038079670497, 5.850552575928824, 2.1130359981741225, 4.321526782853263, 0.5173183009028435, 0.04363133518823555, 4.931533455848694, 17.989839792251587, 32.35542276927403, 46.999456541878835, 58.782044955662315, 63.705448150634766, 66.21189267294747, 66.13456617082868, 66.98834691728864, 71.17777020590646, 72.39701925005231, 72.40268898010254, 74.24905463627407, 74.70797620500836, 72.1358642578125, 70.21647998264858, 72.05561256408691, 69.37265600476945, 69.92721952710832, 67.1903657913208, 61.74086584363665, 59.968012128557476, 59.665112359183176, 57.34535551071167, 55.174557617732454, 50.89306027548653, 49.16435194015503, 39.96962703977312, 32.050306524549214, 20.38992997578212, 9.164238810539246, 2.226474893944604, 0.024103290734014342, 0.08521415958447115, 0.10171262321195432, 0.1617498155683279, 0.060381949213998656, 0.03911521305729236, 0.11051888817123004, 0.05251382337883115, 0.12600768490561418, 0.02021260147116014, 0.2996763751975128, 4.986056404454367, 56.575220652988975, 47.553894996643066, 14.1342887367521, 60.23947824750628, 37.677961758204866, 21.277013438088552, 53.942562103271484, 60.88795362200056, 72.67920643942696, 66.92895371573312, 72.07962553841728, 47.41358307429722, 1.8116802488054549, 0.11785725796861307, 0.06566564712141242, 0.08703466903950487, 0.04912700065012489, 0.03828579559922218, 0.0485441865665572, 0.06796693934925965, 0.045273067629230876, 0.0710013411673052, 0.08483147940465383, 0.06449575775435992, 0.02803856653294393, 0.015777616861409376, 0.030799067512686764, 0.03221953646945102, 0.04528334064941321, 0.02974661559398685, 0.03683430062873023, 0.050155710628522296, 0.038343657672937424, 0.1310721074364015, 0.06569339241832495, 0.07248520904353686, 0.08877376786300115, 0.07295723192925964, 0.043459737074694464, 0.010609209687182946, 0.028004090168646405, 0.0236300973753844, 0.12673351381506237, 0.12973430779363426, 0.2631004607038838, 0.14651437023920671, 0.16227059119514056, 0.1963350847363472, 0.24683812047754014, 0.14199216504182133, 0.16632113313036306, 0.12637581729463168, 0.17105411844594137, 0.2202320702906166, 0.17287865839898586, 0.13761227577924728, 0.24493330983178957, 0.06554835555808884, 0.1498280367148774, 0.2633841426244804, 0.1192749347537756, 0.14451704812901361, 0.15677662885614804, 0.2096506016595023, 0.10524749888905457, 0.2986873968371323, 0.18245696728782995, 0.2917165623179504, 0.1588259267487696, 1.9069687128067017, 58.59504113878523, 115.67451340811593, 98.10107394627163, 103.91239438738141, 88.88034193856376, 71.99491310119629, 55.018851961408345, 46.03101314817156, 87.7324995313372, 88.99994128090995, 35.22799914223807, 36.36080912181309, 46.431323187691824, 54.119442394801546, 8.078358701297216, 0.572977822806154, 0.18643019694302762, 0.39304621358002934, 0.24517117706792696, 0.2835275131676878, 0.13869360275566578, 1.7771598611559187, 1.4521612375974655, 9.474213583128792, 6.654023587703705, 11.036351016589574, 16.916054759706768, 5.573600419930049, 6.430461389677865, 2.54784340943609, 3.811628886631557, 0.8049152057085718, 6.9059600574629645, 34.009041922433035, 57.03916924340384, 78.83819389343262, 99.79536437988281, 103.04826082502092, 103.89974171774728, 100.50945159367153, 104.20463562011719, 88.7794679914202, 96.65812764848981, 91.06099237714494, 91.92932265145438, 99.42112745557512, 94.12211854117257, 85.34607819148472, 68.20615768432617, 33.352826254708425, 11.90747012410845, 0.7895193547010422, 7.958512697901044, 12.187468630926949, 20.83719767842974, 24.520272731781006, 12.386201007025582, 8.131197146006993, 5.496497562953404, 9.960818512099129, 3.7033364347049167, 0.20408090124172823, 5.4468435645103455, 19.054378509521484, 38.584461961473735, 56.04148783002581, 66.21019731249127, 74.27860532488141, 77.10041468484062, 75.94103826795305, 79.10267012459892, 80.99939632415771, 80.31768076760429, 80.32302393232072, 82.72987992422921, 80.6265559877668, 82.8574002129691, 79.88860866001674, 78.5211684363229, 74.31455530439104, 76.44466454642159, 72.36247280665806, 71.01048537663051, 68.05551379067558, 68.19657611846924, 65.49743025643485, 62.7413786479405, 57.01123401096889, 56.124237401144846, 42.61410100119454, 32.081170422690256, 19.107056277138845, 7.888575604983738, 1.279411107301712, 0.19547753860907896, 0.16410282573529653, 0.1853435638227633, 0.3246384843119553, 0.2528978724564825, 0.2501919562263148, 0.352116194154535, 0.5568091475537845, 0.2377940086381776, 0.1723760132278715, 0.6954266865338598, 12.481715287481036, 66.06235354287284, 66.13225936889648, 22.089950936181204, 87.73577908107212, 86.83176980699811, 41.08629287992205, 44.07765565599714, 53.529752254486084, 69.15202985491071, 72.09433487483433, 86.73364734649658, 49.34433807645525, 1.387449624282973, 0.3889364083962781, 0.1664036022765296, 0.20249497491334165, 0.10602391258414302, 0.2889530248939991, 0.1877324820629188, 0.30213535896369387, 0.12137643913073198, 0.24189922692520277, 0.16762013414076396, 0.14841360332710402, 0.12794434598514012, 0.08773148379155568, 0.1400236670992204, 0.2183111376528229, 0.14400592127016612, 0.1928850327219282, 0.17320583441427775, 0.2381462768784591, 0.1683258241308587, 0.1554980788912092, 0.18521789913730963, 0.13642110755401, 0.15900994544582708, 0.17197638324328832, 0.1470309660903045, 0.13235464718724999, 0.11915301558162485, 0.12073512854320662], [0.09821356739848852, 0.043907692323305776, 0.11155240557023458, 0.045749022625386715, 0.038965538410203795, 0.08261459693312645, 0.06779511392648731, 0.035289476559098275, 0.05943127415542092, 0.03237645108518856, 0.06493810151836701, 0.051607287023216486, 0.03988691771935139, 0.029110600972282033, 0.04200158228299447, 0.02533600226576839, 0.04666949609028442, 0.06962333153933287, 0.09324327803083829, 0.0493702283129096, 0.07785595620849303, 0.0523835684039763, 0.09309910969542605, 0.04264503704117877, 0.17753746626632555, 0.031260813985552104, 0.6004048053707395, 40.597334248679026, 81.86740698133195, 84.41176782335553, 74.41332394736153, 60.79266602652413, 58.59225491115025, 44.19924218314034, 37.372949736458914, 57.6955759865897, 82.05801691327775, 29.204786436898367, 30.034231117793492, 64.00026021684918, 31.460592065538677, 2.3171577879360745, 0.17512169161013194, 0.2079322524368763, 0.12384765009794917, 0.08005354114409004, 0.09841551299073867, 0.26470755732485224, 0.6077899805137089, 1.524078892810004, 4.123701580933162, 6.7338601265634805, 1.231490901538304, 1.271682973418917, 0.5060985886624881, 0.7592809572815895, 0.43075636721083094, 2.8154293937342505, 19.817212547574723, 46.080161230904714, 69.59321962084088, 70.40559605189732, 70.21473598480225, 67.94193158830915, 61.18669836861746, 59.699221066066194, 60.53188623700823, 61.89332321711949, 67.87752178737095, 69.46268381391252, 69.46073831830705, 71.96345165797642, 67.39698437282017, 68.05220644814628, 66.71752003261021, 70.05171040126255, 81.05556556156704, 75.54959760393415, 65.52411133902413, 64.93521676744733, 23.1319705418178, 2.280634582042694, 1.1603911795786448, 7.336609840393066, 11.753707357815333, 10.542639817510333, 6.183670495237623, 3.85122059072767, 1.8445984252861567, 3.551082730293274, 19.170665298189434, 34.07677296229771, 46.918079239981516, 49.938103335244314, 51.39425121034895, 49.15994330814907, 47.52329513004848, 54.589112826756065, 57.805899483816965, 59.91336454663958, 60.06943498338972, 64.776380947658, 64.05863898141044, 69.56963743482316, 67.82546588352749, 65.44684737069267, 65.53761863708496, 71.2366909299578, 67.85963017599923, 68.65660939897809, 72.92442921229771, 68.8020907810756, 62.50033869062151, 49.02080910546439, 48.754394326891216, 49.85135160173689, 49.364671979631694, 48.46866703033447, 39.43514381136213, 31.739419800894602, 20.737009865897043, 9.875905445643834, 2.8123361425740376, 0.16268634317176683, 0.028830925800970623, 0.04918604676744767, 0.012843025848269463, 0.04355592619893806, 0.0529497617722622, 0.4256161930305617, 0.11206858751497098, 0.10683588829955884, 0.013320035118210529, 0.24889017322233745, 16.030011790139334, 80.05287102290562, 88.12218924931118, 25.734017065593175, 25.28317277772086, 46.20750434058053, 16.780095883778163, 28.90067768096924, 28.35771938732692, 51.82025568825858, 55.4463711466108, 64.58871705191476, 35.78265993935721, 0.7193714816655431, 0.2291716741664069, 0.048741524906030724, 0.12496131605335645, 0.051756289920636585, 0.05043597951797502, 0.07707810401916504, 0.057980600212301524, 0.04052714943619711, 0.039181587352816544, 0.053437526670417616, 0.014203934697434306, 0.06280133367649146, 0.03740172893075006, 0.05073761547516499, 0.04003172727035625, 0.016941865906119347, 0.06590272725692817, 0.02174924749747983, 0.08827568923256227, 0.1317606983440263, 0.09396129700222186, 0.04475791705772281, 0.03942816358591829, 0.03990595741197467, 0.054040072552327595, 0.0035681031128790763, 0.04358145268633962, 0.018193108229232684, 0.10269117927444832, 0.022560883945386325, 0.1133720532857946, 0.05192641561318721, 0.05167602940595575, 0.08729882272226469, 0.010392799424672765, 0.033176253882369826, 0.059003573177116256, 0.07427424125905548, 0.06975503518645253, 0.023740640907947506, 0.03213799013090985, 0.005382804308153156, 0.03759527765214443, 0.06602762519781079, 0.10793085382985217, 0.04798501264303923, 0.07142467916543994, 0.039104105439037085, 0.013721168057860007, 0.01620464100103293, 0.054002359575991116, 0.09553598679069962, 0.14748398321015493, 0.052389726109270535, 1.5342698373964854, 56.78352417264666, 97.98697757720947, 96.8515099116734, 101.1916674205235, 83.54393781934465, 81.8236472266061, 65.617522920881, 29.010450533458165, 26.166295766830444, 73.92101628439767, 34.9577385357448, 32.52421883174351, 61.82666219983782, 25.629234756742203, 1.0608124200786864, 0.07115876807698182, 0.06731724885425397, 0.05208899260365537, 0.034932346615408144, 0.2847372868231365, 0.03153338489521827, 0.6042018330522946, 0.5701771016631807, 2.5846369436808994, 1.782147039260183, 0.14333468728831836, 0.1897276464317526, 0.5093259726251874, 0.7144382063831601, 0.9012593616332326, 5.132225223949977, 29.06259502683367, 59.628418922424316, 85.30231148856026, 83.7975401197161, 81.97686890193394, 78.14064339229039, 71.51318754468645, 68.65001555851528, 69.1889317376273, 70.62528419494629, 75.05653953552246, 76.80483831678117, 76.28546047210693, 78.76167338235038, 72.98389884403774, 73.70891557421002, 72.34818731035504, 73.98329993656704, 85.06807381766183, 82.22457218170166, 75.73869282858712, 76.09929738725934, 34.759231976100374, 5.102804379803794, 0.40298086191926685, 1.9531390581812178, 11.51300699370248, 10.264131699289594, 4.6090341210365295, 0.8756752258964947, 1.129102464233126, 4.510544274534498, 23.07455583981105, 43.07289750235421, 56.31662259783064, 56.73583173751831, 56.95827831540789, 54.48875652040754, 53.309567315237864, 61.73256969451904, 65.35686819893974, 69.28371211460659, 67.17036192757743, 72.78816808973039, 68.29166916438511, 71.55385535103935, 68.57606588091168, 66.80918066842216, 66.11764730725969, 72.1844391141619, 69.72673620496477, 70.28396088736397, 77.86927454812187, 75.27037034715924, 72.7676500592913, 59.60954066685268, 58.17730501719883, 58.140521253858296, 57.4198853628976, 57.35820967810494, 48.06650529588972, 41.21890272412981, 31.76453059060233, 17.29069467953273, 6.3772468737193515, 0.6773267377700124, 0.11198802505220685, 0.039810172016067166, 0.06622808479837008, 0.015039194342015045, 0.06809489748307637, 0.24067322271210806, 0.13691274688712188, 0.1790377614753587, 0.05766690668783017, 0.2436181189758437, 10.474691646439688, 78.26327214922223, 81.07502051762172, 28.141142300197057, 27.716018506458827, 24.164507593427384, 15.694505861827306, 45.9232292175293, 47.053798403058735, 73.33804852621896, 65.9251822062901, 71.5805572782244, 52.543323448726106, 3.555397995880672, 0.24292609468102455, 0.03857714496552944, 0.20518248927380356, 0.03006937773898244, 0.10408641690654413, 0.0557836259582213, 0.06353953906467982, 0.08594925049692392, 0.023033539565013986, 0.034788093463118584, 0.028314760819609677, 0.04677345783316663, 0.007068036781025252, 0.08572639245539904, 0.05589647311717272, 0.02298352474878941, 0.04513155575841665, 0.03828659627054419, 0.028096993487062197, 0.10416693187185697, 0.01895906400334622, 0.04269332159310579, 0.029359049962035248, 0.07680012857807533, 0.04029864937599216, 0.04053471849433013, 0.06396335882267781, 0.006465861124784819, 0.1689178187932287, 0.11725231685808726, 0.2752851311649595, 0.10760652087628841, 0.09891728963702917, 0.25336003622838427, 0.20663930395884172, 0.07765096399400916, 0.20649120690567152, 0.16712096306894506, 0.10309526723410402, 0.13043750077486038, 0.17376540867345674, 0.1221811952335494, 0.1158715659486396, 0.19722224213182926, 0.1596696036202567, 0.1667288648230689, 0.19695236161351204, 0.1672763204468148, 0.10003663493054253, 0.09072811835046325, 0.19325209302561625, 0.15491684579423495, 0.20563032238611154, 0.1689351350069046, 2.5474091470241547, 68.71275084359306, 112.10734299251011, 104.83031395503453, 97.93100983755929, 79.51007774897984, 71.32672568729946, 59.17448616027832, 56.80227736064366, 76.95063931601388, 111.59004960741315, 45.36996153422764, 46.63829960141863, 84.65710176740373, 47.31329277583531, 4.957344710826874, 0.3875240513256618, 0.28572262823581696, 0.3113935893135411, 0.08991883641907147, 0.2272236951227699, 0.19049908646515437, 1.0458971347127641, 3.3893193304538727, 10.234211887632098, 17.112033912113734, 3.7679525102887834, 5.491401927811759, 3.2711667333330428, 2.430797964334488, 0.8919406331011227, 3.206024331705911, 27.66396086556571, 62.187732287815635, 95.72265693119594, 92.42926638466972, 93.83692278180803, 87.32489040919712, 77.76631614140102, 72.6352938243321, 70.26651396070207, 70.70306232997349, 77.90136132921491, 76.29087311880929, 73.83386502947126, 76.80670043400356, 71.83325631277901, 71.8919130052839, 70.52211734226772, 73.33643654414585, 86.11100537436349, 87.64559841156006, 81.09303024836949, 83.976699420384, 35.618081433432444, 3.160184460026877, 3.969690416540418, 16.21644411768232, 20.320107528141566, 24.362541675567627, 17.703487157821655, 13.652570128440857, 4.253715838704791, 4.148853625570025, 26.39534487043108, 48.53209366117205, 67.03740814753941, 63.42923641204834, 66.55819089072091, 61.90014634813581, 59.79168769291469, 65.5526475906372, 69.42961733681815, 72.01331193106515, 72.3208600452968, 74.44964218139648, 71.68429388318742, 75.06377955845424, 74.70784418923515, 72.56160817827497, 75.15548883165631, 79.73844419206891, 77.22622571672711, 73.89934485299247, 78.92059258052281, 80.56787845066616, 79.40074784415108, 66.25640978131975, 67.14315278189522, 66.05086122240338, 66.00176525115967, 61.29313087463379, 53.477991649082725, 42.230768884931294, 33.263138907296316, 16.786835636411393, 5.915190364633288, 0.37160059862903183, 0.16598185205033847, 0.26994332351854866, 0.14749372697302274, 0.23287875524588994, 0.1172275503299066, 0.6835831020559583, 0.38291210308671, 0.2159015919481005, 0.17058177664875984, 0.4376042511846338, 20.724249499184744, 91.97270720345634, 113.06458936418805, 36.077857630593435, 43.34139674050467, 67.77584879738944, 26.45845709528242, 39.06714636938912, 40.93586785452706, 70.53813988821847, 69.82374695369175, 85.43536949157715, 59.42885971069336, 3.544134531702314, 0.36731014028191566, 0.17274551625762666, 0.3365698440798691, 0.2051914595067501, 0.24449842316763742, 0.2400940523615905, 0.1782811406467642, 0.27495115622878075, 0.18257309177092143, 0.1236940569111279, 0.08887968039406197, 0.12795647819127354, 0.12350091870341982, 0.18530966421323164, 0.18402675805347307, 0.07917363050260715, 0.2453087568283081, 0.16745181674403803, 0.17345478891261987, 0.2500224310372557, 0.11409198572593075, 0.10588813772691147, 0.11984628838087831, 0.12425791951162474, 0.16237923822232656, 0.09016566031745502, 0.10590991870101009, 0.10192267729767732], [0.02970144891047052, 0.004788872852389301, 0.029931574062045132, 0.05937935944114413, 0.08285757353795425, 0.07500742548810584, 0.019467120491234318, 0.005430539246715073, 0.011230034454326545, 0.023600487803508128, 0.03400813442255769, 0.0382066173478961, 0.023401018864076053, 0.03287471292008247, 0.05468035176662462, 0.04889081618083375, 0.041137657926550934, 0.07417582653995071, 0.019087999227589796, 0.09887188207358122, 0.08353131131402083, 0.11654536479285785, 0.06294749690485851, 0.028582273250711814, 0.2405927756002971, 3.4337098513330733, 50.150339535304475, 84.20013264247349, 78.96305302211216, 70.98264394487653, 55.90813800266811, 44.86360113961356, 35.121413775852744, 27.949940034321376, 59.79824679238455, 69.9147891998291, 41.84437608718872, 55.75083426066807, 62.807726996285574, 21.972592387880596, 0.7275319237794194, 0.11406873911619186, 0.13274439770196164, 0.1094577204702156, 0.09381305745669774, 0.25853291579655235, 0.20897034316190652, 0.9662758814437049, 1.7511273494788577, 1.1857032499143054, 0.249489319643804, 0.7298101729580334, 0.9246784278324672, 0.274363354912826, 1.197845226952008, 11.46202632359096, 35.866444792066304, 62.38655499049595, 71.63984625680106, 72.95478589194161, 62.742094312395366, 65.1741166796003, 70.31720801762172, 73.89327212742397, 75.18169743674142, 79.40602847508022, 80.76747240339006, 79.77946635654995, 80.46033423287528, 79.13545867374965, 79.78030014038086, 83.71687153407505, 84.8520473752703, 81.73670441763741, 84.7695722579956, 79.19231578281948, 75.84667478288922, 73.82401248386928, 69.20396069117955, 62.22971330370222, 77.901903288705, 58.290946279253276, 28.228739976882935, 2.254863279206412, 2.1606142222881317, 7.949947306088038, 2.6109035227979933, 2.4582218527793884, 0.6380451513188226, 11.908847604479108, 54.02367884772164, 42.138559341430664, 55.63031080790928, 56.61045844214303, 64.4717858178275, 68.844210760934, 74.75163868495396, 78.43435764312744, 78.41795294625419, 73.40456363133022, 71.9030509676252, 73.76921898978097, 66.87183257511684, 67.44628879002163, 62.665413992745535, 55.25904423849923, 59.89493792397635, 59.568337849208284, 53.590045247759136, 63.426582200186594, 69.95064190455845, 69.56350217546735, 72.32227052961076, 68.24656145913261, 60.457165309361045, 57.81034285681588, 54.29714604786464, 52.500147342681885, 45.2032082421439, 45.515946660723, 41.00232737404959, 28.524276392800466, 17.31626926149641, 7.481466753142221, 1.6122514243636812, 0.11638285565589156, 0.05601087412131684, 0.06907982498939548, 0.09554276535553591, 0.09391404382352318, 0.056676103068249564, 0.05920688262475388, 0.07004694773682527, 0.07177495929811682, 1.0151031528200423, 9.976836715425764, 72.70878492082868, 72.5752613885062, 40.510825702122276, 35.052925382341655, 57.359224115099224, 19.658720663615636, 28.551237140383037, 29.878751277923584, 50.48318256650652, 56.32795510973249, 61.55712768009731, 44.44435725893293, 2.1827527029173712, 0.11323172545858792, 0.11351081369710819, 0.04140894640503185, 0.09749805222132377, 0.06524100633604185, 0.03572631061875394, 0.0641095559777958, 0.0990322877519897, 0.04466068638222558, 0.03644689105983291, 0.04615498673436897, 0.05723657299365316, 0.027331578844626035, 0.02812689482899649, 0.02672656479158572, 0.06675726068871361, 0.08817620921347823, 0.07577463824834142, 0.03549603958215032, 0.06822533905506134, 0.033029527469937286, 0.06566957583917038, 0.09494698446776186, 0.036984965936946015, 0.030622807863567556, 0.04719185609636562, 0.035280027958963595, 0.038372152751045566, 0.060447461770049164, 0.056461977772414684, 0.020744681491383483, 0.08672759801681552, 0.017322332365438342, 0.0270598968158343, 0.009560330255356218, 0.018453085528952733, 0.02910560356186969, 0.010710818609888, 0.02449843899479934, 0.1302142898951258, 0.014641835753406798, 0.017733314240883504, 0.016522499034181237, 0.04210294862943036, 0.05511447507888079, 0.030107077144618546, 0.07856008556804486, 0.11662437341042928, 0.060221346760434766, 0.014831106311508586, 0.025144236395135522, 0.09804598960493292, 7.2511352726391385, 67.8475125176566, 97.1451963697161, 88.53833075932094, 93.15491540091378, 74.0664142881121, 70.29898984091622, 49.240177631378174, 23.861929178237915, 28.59679995264326, 61.30415071759905, 50.24757262638637, 56.05869504383632, 59.34867055075509, 18.43573522567749, 0.1321750253971134, 0.08452177566609212, 0.16166821494698524, 0.12317205992128168, 0.21351906550782068, 0.4816339814237186, 0.3612003395599978, 0.9945156403950283, 0.350459483053003, 0.4485953785479069, 0.4068980174405234, 0.18102742971054145, 0.46711116071258274, 0.5451535444174493, 2.9506574060235704, 18.186937604631694, 49.54399456296648, 79.18177536555699, 82.48096765790666, 82.80884620121547, 74.42896434238979, 77.76589230128697, 78.86902305058071, 82.33821691785539, 83.39178616659981, 86.49158600398472, 87.38014248439244, 87.66980593545097, 86.34858512878418, 87.70061424800328, 86.80791664123535, 90.68344811030796, 90.64171028137207, 85.59904820578438, 89.12760053362165, 85.84315231868199, 82.09884452819824, 80.94334520612443, 73.38609531947544, 67.22562789916992, 87.35538605281285, 72.16413647787911, 39.49327938897269, 4.834048926830292, 1.8225487513201577, 3.463543244770595, 3.335048471178327, 1.50504723404135, 1.4324274850743157, 19.130485602787562, 63.985154833112446, 52.255591596875874, 66.26134300231934, 64.03880187443325, 73.947815486363, 77.78147711072648, 82.46831498827252, 82.66956261226109, 80.58311585017613, 76.06122820717948, 77.41808632441929, 77.45636395045689, 71.14526653289795, 69.9503014428275, 69.49036543709892, 60.779207365853445, 64.5770023890904, 64.83852563585553, 64.30870464869908, 68.11867986406598, 71.07772309439522, 68.17368875231061, 72.81576633453369, 76.08908353533063, 69.28044646126884, 69.21169403621128, 65.98869568961007, 63.24132932935442, 59.17925262451172, 56.684477601732524, 51.22310665675572, 40.30989074707031, 25.757618359157018, 12.989169154848371, 4.144106703145163, 0.5505804132137979, 0.0378043885741915, 0.13062929548323154, 0.07544408991400685, 0.05550474128020661, 0.23707202023693494, 0.02909562231174537, 0.1079141686537436, 0.14418938356850827, 0.7406497970223427, 5.02716064453125, 76.49175943647111, 80.80089323861259, 43.04305151530674, 28.961182594299316, 21.51090543610709, 18.164182254246303, 44.088272503444124, 45.63933277130127, 70.75914124080113, 72.89082772391183, 68.92903436933244, 62.67728846413748, 6.316910454205104, 0.2338709362915584, 0.058886329111243994, 0.0890367476801787, 0.061537440067955425, 0.024231045307325463, 0.02429634073217, 0.02060305596595364, 0.013761491697680737, 0.07119383476674557, 0.04934672725253871, 0.05167282672066774, 0.052953497107539854, 0.022950936408181275, 0.036987120285630226, 0.02349435644490378, 0.0673978588144694, 0.1376678477972746, 0.06825624632516078, 0.06326306997133152, 0.027916184260642955, 0.05972465234143393, 0.038751019564058097, 0.07214799070996897, 0.009232948983221181, 0.027270882190870385, 0.05008904456294008, 0.059164474186088355, 0.13181620250855172, 0.13701306150427886, 0.12527447353516305, 0.1601295689386981, 0.30229522181408747, 0.12224151699670724, 0.13334145423557076, 0.09690549437488828, 0.11292930918612651, 0.15293960832059383, 0.22876002054129327, 0.16315104466463837, 0.16504541944180215, 0.18977088268314088, 0.12772680765816144, 0.11660532014710562, 0.11643123520272118, 0.1485682957406555, 0.08684075730187552, 0.2152579336294106, 0.2855023486273629, 0.26564882110272137, 0.13252092897891998, 0.0997386427064027, 0.43300286095057217, 9.536209753581456, 84.06752627236503, 109.23526341574532, 98.7520089830671, 95.99351855686733, 71.56306171417236, 59.11612824031285, 48.84962633677891, 41.36780609403338, 80.18803433009556, 99.7225819996425, 58.61620535169329, 71.19646780831474, 78.81015791211809, 34.17382192611694, 1.0933155502591814, 0.23608442608799252, 0.3366645947098732, 0.4064139776996204, 0.2767814094466822, 0.29642497109515326, 0.44213583373597687, 1.8809902667999268, 4.231593642915998, 3.3732223084994724, 2.1110711778913225, 0.6691106015018055, 1.24680657684803, 0.7564629742077419, 1.4648842577423369, 15.005908114569527, 49.05478579657418, 84.34250123160226, 91.16611167362758, 89.92833873203823, 79.49876608167375, 83.04445961543492, 81.3961523600987, 84.71682153429303, 86.36164079393659, 88.2299974986485, 91.7045762198312, 92.6915191922869, 89.4853424344744, 90.4244818006243, 89.75340393611363, 92.82674503326416, 89.38856792449951, 85.37636538914272, 88.27256911141532, 83.0535409109933, 80.67069094521659, 80.13385922568185, 71.68931048257011, 65.98595115116665, 99.6148988178798, 79.7907224382673, 39.022354807172505, 2.8121576607227325, 6.248714753559657, 13.369374581745692, 11.663636990955897, 7.061519367354257, 1.0641632974147797, 18.713852507727488, 71.29681369236538, 59.535993984767366, 69.31719548361642, 66.08837454659599, 74.8167919431414, 78.29422637394497, 84.78144672938755, 84.59793785640171, 83.88312108176095, 76.0945656640189, 76.53330271584647, 76.96275697435651, 73.03545447758266, 74.45395701272147, 81.30104541778564, 66.88734095437187, 67.77962166922433, 71.30230971745083, 69.46369130270821, 74.22988455636161, 77.15994685036796, 73.39621884482247, 76.89363629477364, 80.00622081756592, 75.23424666268485, 74.96667153494698, 73.52826935904366, 73.83654703412736, 68.01410947527204, 65.11365345546177, 57.22721529006958, 42.63154445375715, 27.568002768925258, 13.220698765345983, 3.6302515906946997, 0.5384239969508988, 0.16989309074623243, 0.2241507185889142, 0.15775173796074732, 0.37057272664138247, 0.44047610993896213, 0.1100112082702773, 0.21312482309128555, 0.230181307132755, 1.0732198400156838, 14.024620975766863, 85.2188080378941, 92.29941844940186, 57.534492424556184, 56.63141073499407, 81.23366873604911, 32.342523438589915, 39.565738677978516, 41.00425897325788, 70.17128195081438, 74.31821700504848, 79.18826498304094, 73.92878437042236, 7.981152534484863, 0.4500185378960201, 0.18456590840859072, 0.2951827091830117, 0.19507068901189736, 0.17556944329823765, 0.11850577459803649, 0.21122849413326808, 0.25949540414980476, 0.2660812921822071, 0.09225665418697254, 0.09160528092512063, 0.10593036974647216, 0.138137638302786, 0.16102983563074044, 0.07659613381006888, 0.1811113373509475, 0.3586448681141649, 0.21845003377114022, 0.2682466602751187, 0.2255826581801687, 0.1584143138357571, 0.16137664844947203, 0.2016808550272669, 0.14763347804546356, 0.14200208522379398, 0.13433594230030263, 0.12823109488402093], [0.07664682037596192, 0.0587560028902122, 0.0532850157469511, 0.040480873347925286, 0.10471083875745535, 0.07535200592662607, 0.0530336999467441, 0.03925260282786829, 0.010992971282186252, 0.03698937302189214, 0.03754964956481542, 0.04189019736700824, 0.020669883183602775, 0.013837561410452639, 0.06077173365546124, 0.024790775629558733, 0.02213279789845858, 0.038329198091690025, 0.02965420251712203, 0.06562317082924501, 0.04117209018607225, 0.009837996114843657, 0.05428081338426896, 0.029949626486216272, 5.770783347742898, 64.99244213104248, 89.92769949776786, 82.28006744384766, 74.66616194588798, 57.104072366442, 69.78676864079067, 36.13857446398054, 40.343342849186485, 58.69384452274868, 54.7282053402492, 52.85024969918387, 54.5863995552063, 44.702600955963135, 23.013604504721506, 0.7524325304797718, 0.043059109643633874, 0.09716291020491294, 0.0056336820291887435, 0.004132531866032098, 0.13970118654625757, 0.09741383924015931, 1.508121051958629, 0.31384228648883955, 0.6825039599622998, 0.3646725389574255, 1.1437331991536277, 4.622495821544102, 12.30449366569519, 28.251498801367624, 52.44985280718122, 68.78062084742955, 70.1510557447161, 68.48751108986991, 68.46032278878349, 73.0768518447876, 80.12679290771484, 79.39102731432233, 80.0530447278704, 81.89353220803397, 78.45204775674003, 75.52905178070068, 78.50488880702427, 82.93021038600376, 85.65357766832624, 82.3568172454834, 82.14849635532924, 84.50437341417584, 83.59730693272182, 80.63988958086286, 77.15697996956962, 83.08238288334438, 78.99094309125627, 78.32091440473283, 82.76820618765694, 73.0269637789045, 67.111969266619, 66.43789672851562, 63.61308574676514, 65.85394927433559, 11.578065582684108, 0.3463941083422729, 0.5347669103315899, 8.171982203211103, 34.79753392083304, 46.67249863488333, 45.95442662920271, 63.6925106048584, 82.24602821895054, 82.10966287340436, 84.599258014134, 83.76122188568115, 83.62396022251674, 79.3191898890904, 77.39715140206474, 78.16588619777134, 83.25092533656529, 83.74248954227993, 80.20638452257428, 78.71081256866455, 79.76674420492989, 66.45659433092389, 74.97370311192104, 71.29945400782994, 76.31663703918457, 79.34434931618827, 73.77496515001569, 68.42034980228969, 62.16204479762486, 78.02355929783413, 83.00655024392265, 75.72293431418282, 68.79424626486642, 58.050514289310996, 49.08760213851929, 52.063070910317556, 45.4480801309858, 40.74099520274571, 30.669334684099468, 21.022521768297466, 11.014800310134888, 3.5669448162828172, 0.1791105004293578, 0.05616794140743358, 0.0574535820633173, 0.027754930413461158, 0.0513814671763352, 0.08847117517143488, 0.010866042825260332, 0.08238949294068984, 0.24068592488765717, 0.45440274264131275, 10.405708193778992, 68.27444458007812, 83.5344465800694, 40.53744077682495, 46.50249705995832, 59.719836371285574, 25.04379517691476, 29.54748896190098, 31.183424949645996, 38.81862320218767, 48.30294554574149, 66.63708768572126, 53.767276423318044, 6.5950568318367, 0.501794342483793, 0.01485978629040931, 0.10711268987506628, 0.08960210984306675, 0.22528072366757051, 0.036270784081092904, 0.03711850502129112, 0.02488601310843868, 0.10607349992330585, 0.054090589484465976, 0.05814298042761428, 0.015049185770164644, 0.03799117908680013, 0.14398564664380892, 0.08612486214510032, 0.046959271255348406, 0.009451745992659457, 0.07487635966390371, 0.08912457046764237, 0.04511575946318252, 0.04476512649229594, 0.055677737175886116, 0.038112304372979064, 0.07310161061052765, 0.009378446399101188, 0.02643487785410668, 0.029418740687625747, 0.012040330795571208, 0.08327881486288138, 0.01850224539105381, 0.07841473658170019, 0.014503831908638989, 0.053023389607135735, 0.05778953153640032, 0.0445032900066248, 0.01799508456939033, 0.10208075560097184, 0.08285344125969069, 0.013838848930650523, 0.03228590737230011, 0.05044185223856142, 0.04639898453439985, 0.01568372966721654, 0.009475494718312152, 0.02858975749196751, 0.009619735148070114, 0.004933114130316036, 0.04387781981910978, 0.009324801420526845, 0.03702319799257176, 14.372084753853933, 88.64704922267369, 99.89459160396031, 93.58211149488176, 93.63986492156982, 75.37060506003243, 91.7934923171997, 42.32423952647618, 20.701337814331055, 29.760409559522355, 53.44651630946568, 59.196407726832796, 55.56576899119786, 44.7319084576198, 19.2316027368818, 0.31186603967632565, 0.030542245400803428, 0.1070107196324638, 0.023327335050063472, 0.11263599206826516, 0.3100970445999077, 0.17770847066172532, 0.44034466413514955, 0.3872799144259521, 1.6612066945859363, 1.8814603558608463, 4.314672384943281, 10.804808378219604, 23.02204656600952, 42.833570275987896, 70.26493671962193, 83.64439487457275, 81.86848395211356, 80.56852463313511, 79.19970866612026, 81.48013523646763, 86.38040787833077, 86.47748116084507, 86.69102014814104, 88.50673035212925, 83.26549570901054, 82.22675391605922, 82.07362951551164, 87.24334635053361, 88.19234521048409, 87.33241530827114, 86.76501151493618, 87.50965690612793, 86.58848558153424, 83.19717407226562, 79.19238526480538, 86.67840916769845, 83.99432005201066, 83.74562317984444, 88.77449308122907, 85.17455496106828, 80.31112861633301, 72.32950360434396, 71.2771224975586, 77.62135587419782, 17.902085781097412, 1.0299831543649947, 0.9640918672084808, 12.403965813773018, 44.664681162152974, 55.119618211473735, 54.63440465927124, 70.75222778320312, 86.34436757223946, 88.95907197679792, 89.50835486820766, 85.87232780456543, 85.53551387786865, 80.72444915771484, 78.50454834529332, 79.395585332598, 84.91294833592006, 86.63030678885323, 81.59950528826032, 89.0948189326695, 91.15015860966274, 75.33830288478306, 82.29491574423653, 76.9173504965646, 81.52571541922433, 83.39234897068569, 80.42502348763603, 75.85618686676025, 67.83833394731793, 73.38372598375592, 81.72531632014683, 78.71771212986538, 78.28483240944999, 71.93407467433384, 63.98240334647042, 67.41336822509766, 65.62704890114921, 59.813803809029714, 46.02691718510219, 32.85184029170445, 18.419577189854213, 7.860015034675598, 1.172954065459115, 0.1020808234544737, 0.015305171587637492, 0.11635420790740422, 0.029342514063630785, 0.05164220104260104, 0.07610076253435441, 0.05660948450011866, 0.1930569599249533, 0.31161300039717127, 6.799871921539307, 67.2520866394043, 91.90176609584263, 47.41846765790667, 37.765161650521414, 24.096611533846172, 15.792256593704224, 41.09523868560791, 54.208837917872835, 55.73344986779349, 64.9739807673863, 74.16758005959647, 71.40851293291364, 14.418100067547389, 0.3387153446674347, 0.009752091885145222, 0.05615157853545887, 0.047984479993049584, 0.21719122917524405, 0.08199578656681947, 0.03685375762038997, 0.03662061977333256, 0.03810935613832303, 0.04260653696422066, 0.10623248746352536, 0.05632314272224903, 0.045217705957059345, 0.12227228177445275, 0.12898211101336138, 0.06058274808206728, 0.02780985103787056, 0.018358443464551653, 0.02000832511112094, 0.07480442816657679, 0.0748186774019684, 0.053423138335347176, 0.017010905147929276, 0.06472422728048903, 0.03609795103381787, 0.009261592490864652, 0.22804386754121098, 0.12886012398770877, 0.19358636651720318, 0.1385979564594371, 0.17365108909351484, 0.15618453919887543, 0.2297935379402978, 0.14297308240618023, 0.2129494489303657, 0.1316803190857172, 0.23215226137212344, 0.1333580512021269, 0.0691023523520146, 0.09788738204432385, 0.17633911914059094, 0.18806630772139343, 0.14195314927824906, 0.15735602990857192, 0.11067244064595018, 0.1587170490196773, 0.11033801109130893, 0.13032733382923262, 0.25130459080849377, 0.09222122108829872, 19.326836483819143, 106.19254302978516, 110.93091569628034, 102.22576781681606, 96.22466427939278, 72.87334605625698, 87.46242305210659, 46.66689491271973, 56.23902859006609, 79.74903324672154, 76.26276765550885, 76.64477961403983, 74.52780941554478, 65.1769654410226, 36.115159034729004, 1.65499033672469, 0.15123238707227366, 0.4758106310452734, 0.18562135605939797, 0.19262329462383473, 0.37914446954216274, 0.34219077389155117, 3.0150559161390578, 1.5066707240683692, 2.279780170747212, 0.7472473829984665, 2.3592154511383603, 7.347737380436488, 18.49673867225647, 40.49703005381993, 73.02578258514404, 90.55749116625104, 90.33171640123639, 84.9461259841919, 81.5038285936628, 84.38614981515067, 87.93956974574498, 89.2954273223877, 89.80593926565987, 91.2678610937936, 84.69238471984863, 81.16092804500035, 83.36468819209507, 87.05576583317348, 90.345550264631, 86.79094914027623, 87.53036948612758, 87.88868113926479, 88.44836548396519, 82.98628234863281, 80.68299620492118, 86.71213572365897, 87.19329847608293, 88.98054885864258, 93.7118968963623, 84.17641844068254, 80.69910907745361, 73.00010899135044, 74.49738325391496, 82.6263587134225, 12.11092814377376, 2.908444059746606, 1.5293662548065186, 11.08752363068717, 42.880571365356445, 62.284444264003206, 59.79293142046247, 67.9771728515625, 88.67146519252232, 90.731383732387, 93.16108540126255, 90.8648933683123, 87.4860121863229, 84.5342298235212, 82.3528220312936, 79.51754706246513, 87.2104744229998, 89.26611982073102, 83.47943769182477, 89.99097674233573, 90.57194341932023, 70.6193573815482, 81.48934159960065, 78.67071451459611, 87.21346909659249, 87.65881388528007, 86.73182691846574, 81.9071854182652, 73.04435511997768, 80.5813649041312, 83.41552121298653, 80.33803898947579, 81.11611216408866, 74.05142702375139, 70.91046605791364, 76.21340070452008, 71.17517852783203, 64.6818437576294, 49.49117088317871, 35.35913944244385, 19.940725462777273, 7.692769289016724, 0.8875819955553327, 0.1365124247968197, 0.12227419524320535, 0.18363418483308383, 0.14399277126150473, 0.2976559150431837, 0.12314989896757261, 0.2580173648893833, 0.3922546889100756, 0.7331188725573676, 16.05790707043239, 80.36786065782819, 105.1453035899571, 54.12526845932007, 69.48944132668632, 81.10627351488385, 37.38705805369786, 44.029542854854036, 43.63863720212664, 54.53622661318098, 65.45556735992432, 84.32764598301479, 82.64274256569999, 16.293576070240565, 0.48502942493983675, 0.12431836341108594, 0.14562607290489332, 0.24681502314550535, 0.38791491463780403, 0.22461448370346002, 0.19079914822110108, 0.11537447119397776, 0.27502891634191784, 0.12946051891360963, 0.2705909716231482, 0.15043707617691585, 0.15585549042693206, 0.2997810867215906, 0.22033087856003217, 0.15654758257525309, 0.0694567919043558, 0.1899153563593115, 0.15283134127301828, 0.09888877759554557, 0.19522293869938168, 0.15344181922929628, 0.16913877693670137, 0.1112330462783575, 0.18690753275794642, 0.09544348889695746], [0.07984186535967247, 0.025404844732422913, 0.033136423876775165, 0.026671342219093015, 0.0646509997812765, 0.013960382186009415, 0.02292303504821445, 0.022563189268112183, 0.027628929853173237, 0.04548428540251084, 0.01986657744938774, 0.05514640693685838, 0.06050338662628617, 0.08247255919767277, 0.07804713344999722, 0.029925477424902574, 0.017491438559123447, 0.08841043950191566, 0.04094200574659875, 0.051087644549884965, 0.02656004042364657, 0.07092000517461981, 0.012913470505736768, 12.775453857013158, 74.65246704646519, 82.05081857953752, 75.70179789406913, 74.96818624223981, 49.15855366843087, 41.68381711414882, 35.38334001813616, 52.03861672537667, 65.87905311584473, 49.43477235521589, 32.99133580071585, 43.34738956178938, 53.04095343181065, 19.24320796557835, 0.8098505437374115, 0.24513524185333932, 0.11158837471157312, 0.0855890026848231, 0.0683325950854591, 0.16677334957889148, 0.1399623139628342, 0.8627421313098499, 0.7009255343249866, 1.0070521448339735, 19.589615617479595, 44.323576722826274, 55.569858006068635, 60.862592697143555, 78.36908626556396, 81.35240650177002, 69.9024144581386, 66.37587015969413, 69.97414766039167, 78.51785414559501, 78.14126178196499, 78.64385277884347, 77.46787016732353, 81.35822214399064, 82.89089053017753, 85.66630676814488, 84.91354588099888, 89.1847425188337, 86.5996652330671, 85.00603335244315, 83.63946860177177, 80.55970736912319, 79.66552284785679, 79.29041045052665, 79.1351876940046, 76.14997059958321, 72.7611118044172, 71.48556150708879, 73.14827932630266, 74.56466266087124, 70.79125581468854, 76.98069722311837, 80.8781224659511, 76.4953169141497, 72.4267019544329, 65.29306983947754, 67.41756493704659, 27.90939555849348, 12.826507483209882, 33.59039558683123, 62.402695655822754, 56.355466502053396, 73.91424179077148, 79.73108604976109, 78.68827956063407, 74.97666999271938, 82.40873418535504, 81.51596709660122, 83.17860153743199, 81.23477349962506, 79.21684292384556, 77.52066258021763, 80.65441826411656, 81.90490640912736, 82.87720257895333, 88.62803200313023, 85.29070799691337, 82.11395686013358, 81.31057139805385, 78.37199756077358, 76.70197023664201, 74.83882468087333, 79.39364678519112, 77.29392896379743, 74.38460009438651, 67.90040915352958, 71.2675061907087, 68.47439289093018, 72.94145229884556, 78.24486637115479, 59.34832314082554, 56.69631038393293, 70.90731157575334, 63.399776050022666, 49.5173134803772, 36.975036825452534, 27.16417520386832, 13.927032658032008, 6.144835710525513, 0.747641747551305, 0.2540898956358433, 0.10370822184320007, 0.12323315521436078, 0.04977518479738917, 0.1447224406791585, 0.11408334118979317, 0.2116103736417634, 0.17508354437138351, 0.27759215022836414, 10.714639868055071, 60.04016917092459, 80.21154008592877, 52.45479645047869, 50.50770970753261, 67.4935712814331, 28.152573823928833, 24.025847605296544, 32.00447620664324, 42.23162351335798, 51.195862770080566, 63.86798736027309, 62.978305271693635, 16.176698684692383, 0.47615429546151844, 0.09717946645936795, 0.039090483848537715, 0.01704183447041682, 0.04766775680971997, 0.04660988339622106, 0.0404190147029502, 0.05328996226723705, 0.04240088996344379, 0.02821222230392907, 0.08583978922771555, 0.06920682638883591, 0.062196772545576096, 0.07293169865650789, 0.014854307120133723, 0.01903635762365801, 0.06393051772777524, 0.0939995256651725, 0.07992471448544945, 0.024123137883309807, 0.08204217800604445, 0.08880961486803633, 0.04878443885328514, 0.04757109610363841, 0.02113978225471718, 0.05192002042063645, 0.05197168407695634, 0.041290871133761745, 0.033826398995837996, 0.033460753437663825, 0.05117982692484345, 0.028722706250846386, 0.01678735500068537, 0.0711699164073382, 0.04298834861921413, 0.007569148038913096, 0.022499237342604568, 0.06614734591650111, 0.02400854180034782, 0.09761898751769747, 0.024073133245110512, 0.0647899094702942, 0.04957572603598237, 0.027812370099127293, 0.03013619308226875, 0.03587763410593782, 0.01114465863377388, 0.03606646361627749, 22.268616914749146, 92.725405556815, 93.83623491014752, 92.02824415479387, 97.0829405103411, 66.6734059197562, 55.22304214750017, 43.44269105366298, 18.17811860357012, 26.77135705947876, 41.676639625004356, 34.31134762082781, 45.52984305790493, 53.59417247772217, 16.021587099347794, 0.40637215280107086, 0.20525744025196346, 0.02922429969268186, 0.15656921427164758, 0.09561379440128803, 0.3458764675472464, 0.16454715760690825, 0.22717897966504097, 0.38980615458318163, 4.056694456509181, 34.53814377103533, 65.14089039393834, 79.14201777321952, 77.78926604134696, 91.41569096701485, 87.82970482962472, 78.72056783948625, 74.71077632904053, 79.45355415344238, 86.92314556666783, 84.28329563140869, 84.42840181078229, 83.72960758209229, 85.72980635506767, 86.86960969652448, 89.79794883728027, 90.59073829650879, 92.25840323311942, 90.48995467594692, 87.93774236951555, 87.11591638837541, 84.64688096727643, 83.12367602757045, 83.49558530535016, 83.54734938485282, 78.72354861668178, 75.76286561148507, 75.72086375100272, 77.89735221862793, 79.63827201298305, 74.79443958827427, 80.39756420680455, 87.97957052503313, 86.58387892586845, 80.42313357761928, 69.76077542986188, 77.31733049665178, 39.716660499572754, 19.842783655439103, 43.12281683513096, 62.71179321834019, 59.784135001046316, 79.80230508531842, 83.69679124014718, 82.11998789651054, 79.14723587036133, 84.20208508627755, 87.27835137503487, 85.44952992030552, 83.18955189841134, 81.08135032653809, 79.43992178780692, 82.17407962254116, 82.14224992479596, 83.9676320212228, 91.31683199746269, 86.60667596544538, 84.07708004542759, 80.76103142329625, 81.14658001491001, 81.16382544381278, 78.08018016815186, 81.99863760811942, 79.07473836626325, 80.48192228589738, 75.90385845729283, 72.87727178846086, 69.59965365273612, 74.3007561819894, 84.17712020874023, 73.88168253217424, 67.09577301570347, 76.1285423551287, 79.99115712302071, 74.4097386768886, 58.09899534497942, 42.04701682499477, 23.989522423063004, 10.50495365687779, 2.3115790358611514, 0.556020798427718, 0.1010147567306246, 0.09528234361537866, 0.022395991454167024, 0.03303630942744868, 0.09861170460603066, 0.14652997654463562, 0.14153517170676164, 0.23145242035388947, 7.8649656261716565, 62.3852139881679, 89.4320844922747, 58.95029558454241, 41.10837772914341, 26.063042061669485, 12.101153765405927, 37.850426469530376, 51.46923964364188, 56.81550325666155, 65.24845545632499, 71.265275818961, 76.74143600463867, 29.072374616350444, 0.35204407945275307, 0.17796146922877856, 0.046630276766206534, 0.037066848150321415, 0.025545667890193205, 0.04803124462653484, 0.07688477582165174, 0.016317072557285428, 0.02917662582227162, 0.04763915655868394, 0.03361075378156134, 0.07192627939262561, 0.08521249717367546, 0.019332458431433355, 0.020755295475412692, 0.07771850536976542, 0.05837227776646614, 0.018501641494887214, 0.016091719203229462, 0.013295581564307213, 0.03193056197570903, 0.06042244418391159, 0.06223337272448199, 0.043606049580765624, 0.02892614801281265, 0.17926067379968508, 0.14923529566398688, 0.12302127586943762, 0.11713005841842719, 0.1385178214737347, 0.11518914970968451, 0.09773195002760206, 0.1097294194623828, 0.1741020298962082, 0.13033952031816753, 0.18636813813022204, 0.17592182010412216, 0.1906913561480386, 0.12727664038538933, 0.2149723789521626, 0.0859858031783785, 0.15361720696091652, 0.18324169303689683, 0.24487207883170672, 0.1510563072349344, 0.09207508500133242, 0.18770101160875388, 0.10735364444553852, 27.244251455579484, 109.638106073652, 102.135740007673, 95.27512345995221, 97.67562185014997, 66.07024669647217, 56.31519821711949, 50.530812467847554, 73.03276552472795, 91.20792593274797, 71.07142802647182, 49.82042516980852, 57.312601702553884, 70.53959900992257, 33.56684119360787, 1.6748131130422865, 0.38753270943249973, 0.20465658392224992, 0.2721498379749911, 0.2644877391202109, 0.3929998560675553, 0.6569142873798097, 3.5427092824663435, 2.0005537824971333, 1.6037460693291254, 31.161027431488037, 63.83927045549665, 79.06194673265729, 83.82786205836705, 96.02209649767194, 96.18856838771275, 85.93957247052873, 77.16524137769426, 81.41748332977295, 88.98472472599575, 86.26021793910435, 88.37789685385567, 85.59086322784424, 86.48848710741315, 87.67913041796002, 89.59280327388218, 91.69968468802315, 94.40249919891357, 95.65978268214634, 93.63530690329415, 91.46842779432023, 87.87349237714494, 87.93512289864677, 86.96483475821358, 87.95650945390973, 82.07454667772565, 78.72663361685616, 77.26757444654191, 79.49108137403215, 80.60978998456682, 76.45819963727678, 81.92573710850307, 90.84646674564907, 87.68244470868791, 79.76641763959611, 69.060348374503, 86.54773439679826, 36.24033778054373, 16.78612518310547, 43.32356766292027, 72.82584122249058, 62.802522795540945, 75.2540351322719, 88.49391092572893, 86.86351612636021, 82.87717478615897, 86.09050124032157, 88.75159181867326, 88.12703214372907, 86.55366121019635, 85.88454273768834, 83.24156611306327, 87.82661288125175, 86.76617186410087, 86.27046653202602, 91.83055400848389, 86.51138142177037, 89.45615305219377, 86.95009762900216, 83.97228036608014, 82.99058328356061, 78.34681034088135, 85.32840892246791, 83.66291877201625, 86.17235101972307, 82.05126326424735, 76.88927977425712, 72.71127237592424, 77.61535957881382, 86.1961555480957, 79.28485883985246, 73.9619620186942, 79.52660056522915, 81.17512321472168, 76.7193546295166, 59.06749085017613, 45.43504531042916, 26.92273919922965, 12.230853182928902, 2.0532046258449554, 0.6719450865473066, 0.320774933057172, 0.24345763187323297, 0.20654775601412567, 0.2527618126145431, 0.16960095427930355, 0.3234370159251349, 0.34851089332784924, 0.5559311232396534, 15.008506740842547, 72.39462906973702, 96.80460262298584, 68.56834643227714, 73.44496045793805, 97.67627498081752, 41.238729408809114, 36.26109899793352, 43.50466898509434, 56.895556926727295, 68.4299452645438, 79.74916526249477, 91.29972553253174, 37.22638096128191, 1.0657960155180521, 0.32317379862070084, 0.19013286754488945, 0.20863108922328266, 0.07997814911816802, 0.12953200936317444, 0.23337378725409508, 0.19764910851206097, 0.159773568755814, 0.20344643028719084, 0.1438908145896026, 0.32975002431443756, 0.19531285816005298, 0.08385446361665215, 0.06597455697400229, 0.18619000911712646, 0.1720835103520325, 0.1511341623429741, 0.12078707718423434, 0.08510563469358853, 0.2248258880738701, 0.18262018210121564, 0.1552298811397382, 0.13687896941389355, 0.08096676106963839], [0.028296808479353786, 0.02365469087713531, 0.015005204826593399, 0.03308614443189331, 0.04225858759933284, 0.0442553872375616, 0.0411122230413769, 0.025753689763535346, 0.027005926140451005, 0.09103360838655915, 0.05461222345807722, 0.055729916518820186, 0.021866929218439118, 0.05963984903480325, 0.04312198269846184, 0.04348564354170646, 0.057193519946719916, 0.08691766924623932, 0.10816465664122786, 0.04478636463837964, 0.053097159934363196, 1.4171938853604453, 24.264440059661865, 75.0954008102417, 78.42683274405343, 73.31753744397844, 60.93370056152344, 66.13689381735665, 54.8908383505685, 33.042009013039724, 39.0443389075143, 60.27301720210484, 92.95661381312779, 109.05929333823067, 94.37241349901471, 70.47919137137276, 23.294473273413523, 0.8072692879608699, 0.09923212988568203, 0.0779182728646057, 0.09288389874356133, 0.0598449023174388, 0.11742470546492509, 0.12169716906334672, 0.36688942142895287, 0.5010990340794835, 5.095760209219796, 47.28477042061942, 73.29173878261021, 74.89128358023507, 79.47699737548828, 64.2942454474313, 66.61779253823417, 67.26211983816964, 76.27289118085588, 79.49930109296525, 78.15943826947893, 76.67528915405273, 82.20999486105782, 84.94310351780483, 83.48781721932548, 88.41274901798793, 86.3618631362915, 82.59953866686139, 79.15888105119977, 76.87680080958775, 77.05973298209054, 77.91477830069405, 79.08520930153983, 79.12170818873814, 78.17312622070312, 77.58551011766706, 80.7862047467913, 77.70267064230782, 73.56414985656738, 74.52094459533691, 75.01949868883405, 78.86158847808838, 76.17229516165597, 74.60496916089738, 77.23343099866594, 73.92838137490409, 74.9537409373692, 80.05108533586774, 54.49612855911255, 48.99619511195591, 62.48290566035679, 63.3509441103254, 55.252311434064595, 71.39038508278983, 80.05328791482108, 78.8393611907959, 78.84859534672329, 80.62185205732072, 76.95325183868408, 80.4935883113316, 77.76721245901925, 73.59919657026018, 75.8711324419294, 73.63160991668701, 76.643876348223, 77.57121767316545, 76.96308353969029, 74.98851667131696, 75.40299756186349, 75.70685618264335, 75.78792776380266, 75.18870816911969, 79.44935744149345, 77.83440848759243, 75.06813607897077, 72.80441992623466, 75.53798716408866, 75.27934047154018, 70.15145874023438, 72.4170925957816, 74.73176683698381, 71.26233673095703, 70.51653793879917, 64.93379933493478, 68.31485530308315, 73.61098071507045, 68.16620554242814, 59.46874237060547, 41.818355083465576, 25.45636878694807, 14.458099109785897, 7.196011304855347, 2.1665410356862203, 0.2509108233664717, 0.5061841383576393, 0.15362783281930856, 0.0843249869399837, 0.03736385989135929, 0.04395406340648021, 0.07446397322096995, 0.17878075955169542, 0.11596452524619442, 15.133242538997106, 59.67745930807931, 75.36731161390031, 58.55872985294887, 46.59779160363333, 54.889545985630576, 31.1929544040135, 23.136186361312866, 34.28684827259609, 36.94692093985421, 47.51034368787493, 62.06502015250069, 66.79302610669816, 30.618074348994664, 2.117749265262059, 0.05438130781320589, 0.1606372624103512, 0.04879067459010652, 0.016611795938972915, 0.04638175992295146, 0.012498496299875634, 0.030937699002346823, 0.07053733178015266, 0.03686536056920886, 0.04923271301335522, 0.03823938380394663, 0.01331312339087682, 0.02862383352060403, 0.03809922221781952, 0.04371259654206889, 0.07883061747997999, 0.04398915045229452, 0.021311081812850068, 0.05085919198713132, 0.060663663383041105, 0.03355458465271762, 0.019667254394984672, 0.03548886746700321, 0.04900116633091654, 0.028501829531575953, 0.02258675478930984, 0.04464217255424176, 0.03945065362911139, 0.03410655253433755, 0.02786852396093309, 0.051351852515446286, 0.07653634130422558, 0.030762477511806146, 0.053691366620893986, 0.011777452758646436, 0.018703844930444444, 0.08428435626306705, 0.013872911388586675, 0.09808457789144345, 0.004276332520281098, 0.08388085862887756, 0.1024922395923308, 0.018583113194576333, 0.007850011494675917, 3.690075363431658, 37.397073881966726, 91.35440785544259, 88.69796562194824, 89.28893770490373, 80.6661468233381, 84.53463281903947, 76.40780435289655, 41.63406106403896, 16.281223910195486, 38.72223431723458, 99.56585148402623, 107.78215885162354, 89.12168066842216, 69.68533883775983, 20.11656526156834, 0.2429677295897688, 0.10029734165540763, 0.06510018317827157, 0.15737992791192873, 0.1639808929924454, 0.36326658725738525, 0.41452328541449135, 0.3589220089571816, 0.3090456410178116, 11.657498257500784, 68.66191782270158, 85.47637775966099, 77.10393742152623, 82.36186858585903, 70.07909325190953, 73.60239968981061, 76.81180041176933, 83.05383273533413, 85.99861826215471, 86.23464162009103, 85.17429092952183, 88.01157392774309, 88.28217152186802, 90.96400942121232, 93.24425533839634, 90.90012768336705, 86.7556870324271, 82.50177751268659, 78.87714549473354, 81.03240721566337, 80.74208368573869, 83.79269027709961, 82.98580987112862, 82.5776309967041, 81.19444615500313, 82.8955944606236, 80.1884651184082, 75.26927947998047, 76.4523423058646, 77.4780284336635, 82.90646144321987, 85.00202424185616, 79.5509192602975, 79.42498316083635, 78.25852652958461, 79.42954812731061, 87.2791782106672, 59.31203964778355, 54.53054298673357, 74.53538295200893, 68.94622421264648, 59.460112707955496, 76.51912144252232, 82.587247303554, 81.63444083077567, 83.06529031481061, 83.68214443751744, 82.55209636688232, 84.0196670804705, 78.62355014256069, 75.78717735835484, 78.0547845023019, 75.83930969238281, 79.00928633553642, 78.51144790649414, 79.1589366367885, 75.31025995526994, 76.65867601122174, 78.44302899496896, 78.82358183179582, 76.81060532161167, 81.33668272835868, 79.8124008178711, 78.67004748753139, 78.20802702222551, 77.54879583631242, 79.71477167946952, 76.5350536618914, 76.91368879590715, 76.99941567012242, 75.07909338814872, 78.08295944758824, 77.05609907422746, 72.96083777291435, 72.03382301330566, 75.71015657697404, 78.21812970297677, 72.69854327610561, 50.45745686122349, 24.705720152173722, 12.098317163331167, 3.4605209955147336, 0.8863116151520184, 0.609259090253285, 0.17695495752351625, 0.05552700740684356, 0.07843308416860444, 0.13792984373867512, 0.03346478732834969, 0.07658363519502537, 0.2859146265046937, 11.322299786976405, 61.014237131391255, 84.71347945077079, 68.51945195879254, 51.008167607443674, 35.92512232916695, 12.865024822098867, 30.674354757581437, 51.542581353868755, 59.67312363215855, 67.498261315482, 69.59169796534947, 76.82890687670026, 45.697708061763215, 4.141532829829624, 0.09272985093827758, 0.13735372679574148, 0.09628540836274624, 0.016039505933544466, 0.007665579739425863, 0.04267266359446304, 0.04261065906445895, 0.024594480537676384, 0.051165167175765545, 0.03734436218759843, 0.04303310139636908, 0.05452384087922318, 0.03799307559217725, 0.0365970033620085, 0.08806790823915175, 0.03612558437245233, 0.05193211870001895, 0.03734908479132822, 0.044114146780754836, 0.011566105215544147, 0.026051815998341357, 0.0539597950742713, 0.09429724647530488, 0.10494257882237434, 0.17144344826894148, 0.14248315298131534, 0.14167055301368237, 0.1449021031813962, 0.14558780352984155, 0.12317207349198205, 0.14643697653497967, 0.14928085250513895, 0.1266336470310177, 0.1591862559850727, 0.13526317397398607, 0.10148687461124999, 0.13605478006814206, 0.1634971789483513, 0.12271878495812416, 0.13232571445405483, 0.21650049409696034, 0.18384440855256148, 0.1238243899175099, 0.2170582634529897, 3.7753914254052297, 44.2247177532741, 103.20151724134172, 99.40112359183175, 95.1178787776402, 81.75567994798932, 81.27369035993303, 69.84186785561698, 50.382642132895334, 59.799038887023926, 83.95727225712368, 118.80359295436314, 135.32700674874442, 115.84909384591239, 85.63233007703508, 36.50997999736241, 1.145767175725528, 0.18500224713768276, 0.3585703378277165, 0.18736984580755234, 0.27058130928448265, 0.25270609131881167, 0.4101266770490578, 2.1575902359826222, 1.3895116107804435, 7.547155022621155, 74.4397201538086, 93.38919476100376, 87.63223007747105, 89.0604600906372, 77.91178362710136, 78.40384810311454, 79.26466042654855, 88.06984152112688, 91.48722267150879, 88.35054179600307, 86.7012756892613, 90.50573403494698, 90.6739638192313, 89.37455340794155, 96.29999664851597, 94.85964897700718, 90.76941817147392, 85.18779127938407, 80.28965868268693, 82.68270860399518, 82.34455367497036, 84.0461814062936, 83.8327327455793, 84.5138646534511, 83.30803258078438, 84.69232218606132, 80.35929352896554, 77.06060150691441, 78.00351374489921, 78.08770506722587, 85.21129703521729, 86.27859592437744, 83.87471376146588, 78.30468341282436, 80.28768539428711, 85.71108790806362, 87.14025592803955, 61.12940352303641, 64.88671139308384, 75.6114226749965, 76.97975226811, 58.98421669006348, 73.30798367091587, 86.01206302642822, 82.58245304652623, 85.23394121442522, 86.04138442448208, 85.09956305367606, 86.55197279793876, 81.94455977848598, 77.94082709721157, 80.44253989628383, 76.44113486153739, 82.50702340262276, 82.91793291909354, 83.69449833461216, 79.01960441044399, 82.01599420819963, 84.26256915501186, 84.38103594098772, 80.17088617597307, 84.92889445168632, 83.52232892172677, 82.2494397844587, 80.92488384246826, 82.56170572553361, 81.85378156389508, 78.49165943690709, 77.80287061418805, 79.1109037399292, 78.31201376233781, 78.66664287022182, 80.71984250204903, 83.641740662711, 81.28800364903041, 78.05176203591483, 76.7285054070609, 68.48188304901123, 53.20700148173741, 30.701522214072092, 14.555630973407201, 3.300697445869446, 1.1609602804694856, 1.4029567007507597, 0.2540609086198466, 0.15488357043692044, 0.28662024864128655, 0.166166929262025, 0.3436405860951969, 0.260253762028047, 0.4416140131652355, 20.21046495437622, 69.65825475965227, 90.01441301618303, 74.00605528695243, 69.11752510070801, 81.51158278329032, 47.65079457419259, 34.22377252578735, 47.64753586905343, 53.768811975206646, 66.03080177307129, 76.91489083426339, 90.09232316698346, 56.96464286531721, 5.61232316493988, 0.27252042666077614, 0.27706674699272427, 0.17841701049889835, 0.06573362275958061, 0.10653075110167265, 0.1515358957861151, 0.24542725618396485, 0.17298157859061444, 0.1661704033613205, 0.1128584701301796, 0.091640734379845, 0.1273115985095501, 0.10602457076311111, 0.09734120206641299, 0.173504715519292, 0.11138874292373657, 0.11760151812008449, 0.15712905994483403, 0.14699705291007245, 0.14258595103664057, 0.10029569960066251, 0.21088428688900812, 0.17858972480254515], [0.052707287283348184, 0.039581705882613144, 0.042170018423348665, 0.07199140518371548, 0.08788987422095877, 0.055550640781543086, 0.042284259971763404, 0.02016095138554062, 0.023038375823359405, 0.04343207998733435, 0.01952170524080949, 0.05057848883526666, 0.06421658809163741, 0.044327600326921256, 0.0774575068748423, 0.050830995464431386, 0.07731128257832356, 0.10494294523128442, 0.02194603791992579, 0.0007919430292011903, 3.7847185134887695, 55.01532922472273, 84.84796878269741, 73.72689751216343, 70.01584380013603, 70.26036480494908, 55.53982441765921, 48.19614478519985, 34.14989233016968, 39.562042236328125, 46.344380378723145, 40.02239165987287, 64.10279478345598, 82.51142161233085, 66.62413624354771, 24.059801714760916, 0.5215932886515344, 0.2501748842852456, 0.09053207601287536, 0.08309761887150151, 0.13311224510627134, 0.02483851396079574, 0.20285002514719963, 0.9524593885455812, 0.7701547252280372, 3.4309092930385043, 47.979923793247764, 70.59501784188407, 73.91804245540074, 70.89779254368374, 82.6381150654384, 67.56369944981166, 76.0446081161499, 86.35288606371198, 79.48361900874546, 81.52836963108608, 83.83967399597168, 85.14480972290039, 83.03883157457624, 86.88102558680943, 84.12637056623186, 84.59065614427838, 78.79100867680141, 77.50257641928536, 79.97418962206159, 83.59553514208112, 82.80396161760602, 78.99373626708984, 79.2415576662336, 79.03256280081612, 78.6747305733817, 81.26623494284493, 78.49202769143241, 79.10902772630963, 73.89364038194928, 74.90014253343854, 77.45780222756522, 78.91170583452497, 80.76526287623814, 75.23039736066545, 73.00216565813336, 78.49639116014752, 75.18498393467495, 74.7478449685233, 70.42480087280273, 43.12406056267874, 61.75809737614223, 54.45032603400094, 57.73384666442871, 72.6479048047747, 70.85943153926304, 79.2091373716082, 73.35298020499093, 74.05063492911202, 78.84027140481132, 76.23797648293632, 73.78125326974052, 76.09660843440464, 83.55426284245083, 82.11768804277692, 78.28675706045968, 76.20075498308454, 74.68608243124825, 70.44986997331891, 75.73145975385393, 76.00463512965611, 74.27626378195626, 72.60928671700614, 71.21517235892159, 73.03737218039376, 70.80685452052525, 75.11919839041573, 73.81233256203788, 71.84378283364433, 74.05121857779366, 77.93386500222343, 76.85781138283866, 78.60966764177594, 79.10588019234794, 75.84515312739781, 54.72970962524414, 52.3362706048148, 59.93668964930943, 64.22108091626848, 69.28355230603898, 58.622917311532156, 19.103283405303955, 12.886248963219778, 8.169192501476832, 3.4818476225648607, 0.466995864042214, 0.2806536459497043, 0.14549818262457848, 0.046945150941610336, 0.1517731523407357, 0.09700784459710121, 0.09359859967870371, 0.09366633782961539, 0.09632713826639311, 18.38071765218462, 61.11859907422747, 70.34431294032505, 57.816043853759766, 45.76842335292271, 64.08322865622384, 40.82556520189558, 22.63364052772522, 27.314079114368983, 33.68950816563198, 60.681501797267366, 61.64117309025356, 65.65770435333252, 50.481129373822895, 1.974926654781614, 0.08634021558931895, 0.06737183021115405, 0.08227199781686068, 0.024180223034428697, 0.08583320743803467, 0.07833519870681421, 0.0539750078293894, 0.07716880379510777, 0.030315947186733996, 0.0305499399879149, 0.025424700363406112, 0.07683864222573382, 0.05448271826441799, 0.011702976754999586, 0.017436511149363856, 0.06607018291418042, 0.03970022898699556, 0.03755480982363224, 0.04799426786069359, 0.004727514626990471, 0.04981898423284292, 0.04183414698179279, 0.06119494951729264, 0.05815239170832293, 0.029327881455953633, 0.082026843114623, 0.05140755684780223, 0.034434335838471136, 0.025648136856034398, 0.01577242267584162, 0.04879155329295567, 0.038474089066897116, 0.05642096033053739, 0.024383252586371133, 0.06285438832959958, 0.04482702924204724, 0.020435800476531898, 0.048167372321976085, 0.0655845757573843, 0.03373334470338055, 0.045519816888762374, 0.10499284469655581, 9.038928048951284, 75.5725405556815, 101.2337874003819, 82.42502076285226, 93.76329272133964, 96.46032633100236, 72.7976176398141, 63.18625095912388, 37.9805314881461, 31.105104855128697, 33.38214765276228, 44.85222346442086, 73.41415214538574, 88.77156094142369, 70.46480860028947, 23.486373833247594, 0.1198889139507498, 0.10247955098748207, 0.03678976498278124, 0.16283677438540117, 0.08425544388592243, 0.21472917843077863, 1.0169617959431239, 0.5530092971665519, 0.3688661567866802, 8.51766116278512, 69.51956871577671, 75.49011407579694, 81.74279103960309, 80.37906115395683, 89.21022156306675, 76.88850157601493, 84.11313424791608, 91.02019950321743, 84.35521643502372, 87.88838931492397, 89.94547993796212, 92.11527034214565, 89.8341281073434, 89.63907827649797, 86.91811507088798, 86.59988062722343, 81.3176029750279, 81.66456127166748, 83.96640219007219, 86.36824853079659, 86.96645368848527, 85.29482133047921, 82.70116301945278, 82.47638184683663, 84.42412172045026, 82.10798835754395, 84.2234160559518, 83.50399957384381, 78.09533418927873, 77.99271624428886, 83.00116539001465, 80.58656215667725, 81.85865225110734, 80.03042139325822, 79.56031322479248, 80.96383544376918, 79.27043437957764, 77.33132416861397, 75.39966937473842, 51.04838030678885, 63.52957534790039, 58.306510244097026, 60.67737456730434, 76.79520116533551, 77.02280330657959, 82.4717126573835, 76.32009724208287, 79.18313721248082, 79.61364759717668, 77.66749886104039, 75.5397172655378, 78.59037944248745, 84.41769463675362, 85.19708796909877, 81.87571702684674, 77.6926930291312, 78.56599126543317, 75.99847207750592, 76.51272909981864, 77.40728882380894, 76.22143977028983, 76.18619155883789, 73.8445166179112, 74.59209414890834, 73.18602888924735, 76.56789779663086, 77.57641492571149, 75.67898695809501, 75.25281919751848, 80.40938309260777, 78.13882991245815, 81.11361081259591, 80.10780348096574, 79.86142035893032, 66.02525016239711, 62.53159168788365, 66.78297206333706, 72.36088166918073, 78.16931860787528, 92.50221552167619, 53.21380376815796, 25.567288092204503, 12.92019612448556, 4.940047604697091, 1.2290621804339545, 0.44279121713978903, 0.10339244521622147, 0.04223712892936809, 0.07132712618580886, 0.056443684468311925, 0.16196059568652085, 0.061929232973073206, 0.14152910560369492, 15.136049611227852, 63.5039712360927, 77.35337775094169, 65.6351991380964, 50.08019747052874, 33.4548397064209, 13.996260166168213, 32.44765315737043, 43.208158084324424, 49.15414156232561, 81.65065097808838, 70.70768983023507, 73.81179060254777, 65.30475670950753, 3.6973205975123813, 0.1584572379610368, 0.04160730593970843, 0.11196517199277878, 0.006725914335610079, 0.018422671893079366, 0.11783242358693055, 0.03615532795499478, 0.03733854374981352, 0.02523869864775666, 0.043083472443478446, 0.010681744232507688, 0.05349193160821285, 0.06876454369298049, 0.06208904154066529, 0.005743336256793035, 0.025438128571425165, 0.028369342176509754, 0.05890796759298869, 0.056179605424404144, 0.05974305421113968, 0.055578569282910655, 0.07502355426549911, 0.19092402580593312, 0.14135797907199177, 0.08151526842266321, 0.2532212351049696, 0.14727884850331716, 0.09873415982084614, 0.0917776966733592, 0.08894007679607187, 0.1486017339463745, 0.1293779547725405, 0.14730901617024625, 0.12330543276454721, 0.16682596318423748, 0.11832114521946226, 0.10796060759041991, 0.2026264342878546, 0.19200805335172585, 0.21599916528378213, 0.11719765407698494, 0.19822283701172896, 9.128983650888715, 83.59744589669364, 115.97507163456508, 90.02956703730992, 91.39640276772636, 90.96350915091378, 74.05565152849469, 64.23020390101841, 47.505136013031006, 57.75899914332798, 66.42817619868687, 57.436675684792654, 85.4636139188494, 100.16378566196987, 85.92024953024728, 41.46471609388079, 1.2045751001153673, 0.233053518725293, 0.254517562687397, 0.3100179545581341, 0.2698416518313544, 0.27352251431771685, 0.440401552511113, 3.8400405049324036, 2.215347788163594, 5.836994903428214, 76.4282876423427, 81.61902972630092, 85.8595917565482, 87.2723342350551, 94.21849005562919, 86.22849941253662, 90.90650612967355, 97.03012030465263, 89.35784299033028, 92.02805655343192, 92.54933820452008, 94.00921031406948, 92.51525729043144, 91.14594800131661, 90.61294473920549, 88.55279690878731, 84.68957764761788, 81.74381242479596, 87.41063812800816, 90.29110418047223, 91.24658570970807, 87.91573742457798, 86.05631610325405, 85.81364331926618, 87.03527559552873, 86.20104707990373, 86.47219358171735, 86.78211103166852, 81.07770947047642, 81.57068416050502, 82.1124768938337, 84.39801733834403, 83.62623923165458, 79.83407919747489, 82.588317326137, 83.74115548815045, 80.81180885859898, 79.42242622375488, 73.81126253945487, 51.577843461717876, 73.22832257407052, 66.01292405809674, 62.20326151166643, 75.94871602739606, 77.42273466927665, 83.47462953839982, 78.23819610050747, 79.20852593013218, 82.51811272757394, 77.88970225197929, 77.83125400543213, 78.87626307351249, 88.12088298797607, 88.34880474635533, 86.23951230730329, 82.58148724692208, 83.31986536298479, 77.69865458352226, 81.52217878614152, 81.80767331804547, 81.45709500994, 79.63478401729039, 78.02184309278215, 77.11098289489746, 74.49718175615583, 80.93971129826137, 80.84749480656215, 79.35604313441685, 79.75255598340715, 83.66209888458252, 81.0007929120745, 82.73843315669468, 82.32056849343437, 81.11418056488037, 69.72803551810128, 69.20482921600342, 75.31668703896659, 75.26706995282854, 78.35758004869733, 79.64464351109096, 51.05601290294102, 28.208548511777604, 16.619260719844274, 6.3739899056298395, 1.502049194914954, 1.0703088705028807, 0.17450187701199735, 0.09165207948535681, 0.24172112505350793, 0.23980999046138354, 0.3144681400486401, 0.1877542766077178, 0.2894042506814003, 24.21362440926688, 72.79606819152832, 85.22713892800468, 72.3719709941319, 64.23648507254464, 97.17544882638114, 61.748349053519114, 33.64532109669277, 37.332184655325754, 47.96351214817592, 81.77327973502022, 78.03070204598563, 84.79151466914585, 81.0835668018886, 7.293055057525635, 0.3216125438255923, 0.11218471199806247, 0.42088772675820757, 0.12598014995455742, 0.14105111839515821, 0.2416882568172046, 0.20845970484827245, 0.12686018273234367, 0.1429217444466693, 0.12830964209777967, 0.0876649059355259, 0.13399600982666016, 0.11548336249377046, 0.13673529640904494, 0.12122477298336369, 0.12651695257851056, 0.10566842130252294, 0.14959652056651457, 0.11799341280545507, 0.1771017246480499, 0.17848599036889418, 0.15364223133240426], [0.039893954127494774, 0.010231556603685021, 0.0461885097569653, 0.04507196002772876, 0.047159181242542605, 0.029181945536817824, 0.01409508750241782, 0.005119850784207561, 0.018381481424772313, 0.027526538918859193, 0.024897281878760884, 0.04304950498044491, 0.0804231052419969, 0.02350827998348645, 0.07258872634598187, 0.00950433245660471, 0.030977786851248572, 0.034749803732016256, 0.06416840531996318, 3.3905356994697025, 60.08464459010533, 85.3054451261248, 71.87221486227853, 69.48955249786377, 55.50025790078299, 47.8935854775565, 47.30833523614066, 42.309161935533794, 53.263785634722026, 57.5382513999939, 32.15326145717076, 37.8771561895098, 53.5345812525068, 43.60409075873238, 22.272169181278773, 0.9444128317492348, 0.09892140155924217, 0.028000780614092946, 0.08495720515825919, 0.06712488417646714, 0.025824345615027205, 0.2329524712903159, 1.560044071504048, 0.2208883222192526, 0.37522194002355846, 40.836640630449565, 76.69756507873535, 70.98142106192452, 78.58881609780448, 76.45209911891392, 77.57549776349748, 63.14713260105678, 73.75446796417236, 78.78972326006208, 84.3364701952253, 87.98751926422119, 85.46779673440116, 86.35537351880754, 86.97118541172573, 84.16888659340995, 82.32419545309884, 74.70069449288505, 76.98810400281633, 80.75483363015312, 74.38119547707694, 73.7122437613351, 77.2821934563773, 76.91807310921806, 78.88528183528355, 76.44214235033307, 80.25491074153355, 77.45106247493199, 77.39867305755615, 75.74263940538678, 76.66737515585763, 72.44328035627092, 77.3038718359811, 78.511246408735, 76.0552110671997, 79.71061665671212, 76.90885284968785, 70.3135324205671, 81.26358767918178, 74.90465886252267, 78.76900373186383, 60.72015462602888, 52.521412304469514, 54.44832842690604, 62.08931105477469, 75.10334954942975, 75.64143889290946, 74.47892189025879, 68.03380761827741, 75.25940608978271, 76.01237542288644, 76.66899408612932, 72.59238174983433, 72.35938085828508, 73.94193731035504, 76.92083849225725, 78.03437069484166, 77.30804075513566, 74.00807721274239, 73.9010124206543, 71.60795402526855, 71.7043741771153, 70.95421191624233, 73.93096610477993, 70.58898680550712, 70.8177353995187, 71.01698889051164, 69.00729887826103, 71.4053931917463, 71.2202375956944, 69.23428262983049, 74.78164100646973, 71.0330878666469, 75.81400435311454, 77.9666188103812, 77.32799598148891, 74.34457847050258, 68.63758523123605, 60.30138669695173, 59.56685788290841, 57.93412501471383, 81.47120680127824, 52.29334115982056, 16.660746676581248, 15.081629582813807, 8.35938206740788, 4.7599442175456455, 0.6700069191200393, 0.05469982911433492, 0.05237378392900739, 0.061047320653285296, 0.044327658002397845, 0.3304032635475908, 0.11107571436358349, 0.24468344609652246, 0.37878139902438435, 27.030806268964493, 66.6925412586757, 73.11255863734654, 57.1096066066197, 48.99888406481062, 56.18497507912772, 35.476136684417725, 34.47313642501831, 43.52300875527518, 38.20385701315743, 49.798406328473774, 59.58559717450823, 61.98209340231759, 49.66420187268938, 9.589620556150164, 0.11410628924412386, 0.0064389563631266356, 0.05421764177403279, 0.018702292781589285, 0.04729426399405513, 0.010103701946458645, 0.06932655389287642, 0.04275489864604814, 0.06470535722162042, 0.04487325783286776, 0.05515320585774524, 0.011693808898728873, 0.044152290626828156, 0.013151866999188704, 0.02126826116416071, 0.0023664771787090494, 0.05111821594515017, 0.024531627838898982, 0.04288392886519432, 0.03673975355923176, 0.04098421062475868, 0.02287066401913762, 0.050940470304340124, 0.017358019914744154, 0.04357098628367696, 0.011625161510892212, 0.01098711128413145, 0.02636777582977499, 0.006647979075621281, 0.05822134443691798, 0.045126751730484624, 0.014611800400806325, 0.07883740961551666, 0.07156227928187166, 0.04924024814473731, 0.02589471817814878, 0.0896738784919892, 0.03404919257653611, 0.03590315720066428, 0.12077661417424679, 6.642457008361816, 82.67430823189872, 94.77158055986676, 84.1057413646153, 89.68784073420933, 74.01472663879395, 62.463631357465474, 62.242081097194124, 30.855674948011124, 20.41013707433428, 34.720071928841726, 29.199745518820627, 43.95887620108468, 64.25942802429199, 51.74252619062151, 23.15267617361886, 0.28302015896354404, 0.03559618117287755, 0.13534085266292095, 0.0881505673751235, 0.06252939041171755, 0.2081406441118036, 0.5839411573750632, 0.727434648999146, 0.7091447647128786, 1.063901654311589, 60.58234405517578, 83.45798165457589, 81.26015526907784, 86.93089280809674, 84.30215304238456, 80.91567053113664, 71.15753705160958, 80.94327572413853, 82.6862313406808, 91.6076557976859, 90.82218279157365, 87.09866401127407, 89.44971207209996, 90.2529377256121, 86.35880592891148, 88.52043914794922, 77.99610001700265, 81.12479046412876, 83.67446667807442, 79.40747370038713, 75.95469147818429, 79.7144034249442, 78.7371392931257, 82.70904922485352, 81.34106704166958, 83.13958740234375, 82.64106110164097, 83.69839627402169, 78.69237204960415, 79.44315270015171, 75.08536761147636, 77.94647598266602, 81.89330291748047, 81.29355525970459, 80.82580947875977, 81.96074213300432, 72.64342321668352, 83.10194206237793, 79.80641147068569, 83.6812411717006, 68.04659925188336, 56.1482503754752, 56.437795707157676, 66.1051891871861, 81.66776439121791, 79.60237761906215, 76.63023008619035, 73.34271076747349, 76.33523736681256, 78.15054457528251, 78.42014162881034, 76.39918163844517, 74.4426383972168, 75.36379582541329, 79.24265548161098, 79.89377117156982, 81.49417754581997, 77.47921657562256, 76.87025560651506, 75.7081207547869, 74.42422567095075, 74.1989164352417, 74.8566676548549, 73.34867927006313, 74.50718021392822, 72.89479514530727, 72.94658701760429, 73.62217426300049, 73.15433120727539, 73.42423398154122, 77.04152870178223, 76.70080293927873, 76.33879484449113, 77.53584439413888, 80.39274215698242, 80.31151076725551, 78.50770282745361, 69.22568075997489, 66.8887722832816, 64.19871466500419, 75.41732474735805, 93.52833243778774, 47.10369689123971, 26.503384147371563, 13.270766615867615, 5.916371124131339, 1.6715076161282403, 0.2230442858168057, 0.231650851134743, 0.019547136733308434, 0.03688230358862451, 0.523392872086593, 0.4114195576735905, 0.1602567264011928, 0.11071473373366253, 23.28624313218253, 72.38399137769426, 83.02346215929303, 65.42328602927071, 51.52398797443935, 36.72258792604719, 25.68911954334804, 48.40095336096627, 55.63021353312901, 58.27660172326224, 71.96478571210588, 71.27639293670654, 70.9084163393293, 64.39555018288749, 14.454501679965428, 0.0594153692945838, 0.06804213460002627, 0.02727907380488302, 0.04903606677960072, 0.010489515261724591, 0.04732187019128885, 0.05880943752293076, 0.039767834823578596, 0.041202780324965715, 0.052882298428033075, 0.021597698397402252, 0.033333114215305874, 0.03934554176937256, 0.017452855361625552, 0.007375270228034684, 0.025460728876558796, 0.05758584210915225, 0.025382235945601548, 0.031216264768902744, 0.032849630873118124, 0.07161002100578376, 0.08865258829402071, 0.17569122676338467, 0.13070107091750416, 0.12613811290689877, 0.1538668264235769, 0.13066532569272177, 0.1373250519058534, 0.06507112830877304, 0.14171102084219456, 0.20095438829490117, 0.059535748192242215, 0.20893363441739762, 0.16325281134673528, 0.12018512162779059, 0.15340639970132283, 0.10245966991143567, 0.11099737071033035, 0.20953003955738886, 0.3213750294276646, 7.5771616867610385, 94.80823925563267, 107.07547146933419, 91.89520004817417, 91.31071063450405, 72.7564217703683, 59.49119894845145, 64.0824087687901, 57.045770032065256, 77.12956237792969, 83.58082580566406, 47.01719181878226, 57.748205116816926, 73.11024488721574, 63.11042526790074, 40.81515680040632, 1.828145525285176, 0.2211693035704749, 0.18449778349271842, 0.193731355879988, 0.30374579397695406, 0.19941236318222114, 0.7192432114056179, 5.305740416049957, 2.931453670774187, 0.9221701281411308, 66.89528274536133, 90.44324193681989, 89.11343315669468, 92.33329091753278, 90.26096289498466, 87.11832046508789, 78.07651151929582, 86.04864529200962, 89.27777194976807, 93.02788843427385, 97.27444675990513, 91.85418483189174, 92.33197770799909, 91.06975405556815, 89.94753660474504, 90.74254948752267, 80.67235851287842, 83.10445731026786, 87.56649317060197, 83.07730375017438, 78.74734619685582, 83.24775000980922, 81.09974220820835, 85.78285585130963, 83.78722899300712, 86.14610072544643, 85.91151564461845, 86.3857649394444, 80.21022687639508, 80.75337450844901, 73.94304207393101, 81.87049198150635, 84.79482895987374, 84.51642853873116, 84.42835317339215, 83.52175222124372, 77.17270374298096, 87.7018301827567, 81.57559653690883, 86.57020487104143, 65.55189023699079, 62.653178215026855, 63.295073645455496, 67.44503116607666, 84.37515776497978, 82.32247924804688, 80.27044691358293, 74.19383035387311, 77.37387493678501, 79.97117410387311, 81.99505233764648, 78.88569177900041, 78.89648233141217, 79.56398882184709, 80.25632122584751, 83.90561934879848, 85.35383238111223, 81.66418606894356, 80.76135798863002, 78.22314630235944, 77.4789455958775, 75.2382001876831, 79.61933122362409, 77.35200895581926, 78.93724741254533, 77.80009133475167, 74.51666450500488, 77.64442389351981, 73.48423862457275, 75.41145351954869, 81.59497506277901, 80.38147912706647, 79.91457407815116, 79.8677293232509, 83.64360277993339, 83.21026447841099, 81.48836885179792, 72.7770162309919, 73.47993768964494, 72.26762989589146, 81.96466786520821, 76.3521284375872, 50.148289816720144, 30.34766435623169, 16.29171916416713, 7.3647231204169135, 1.937365778854915, 0.6698750661952155, 0.34946917476398603, 0.13721884760473455, 0.1298550870269537, 0.9909413350479943, 0.4064093908028943, 0.4176860457020146, 0.5570503260408128, 34.70434815543038, 78.02392755235944, 91.90710926055908, 74.07669067382812, 67.60358905792236, 89.16817106519426, 52.84138379778181, 52.00327818734305, 56.770273957933696, 51.81706646510533, 68.54997539520264, 77.44232164110456, 80.64317607879639, 78.33037785121373, 18.71808222361973, 0.19272389422569955, 0.09240325167775154, 0.07731356245598622, 0.08448326880378382, 0.13670299814215728, 0.181662633482899, 0.17989072070590087, 0.11302823280649525, 0.1336326271827732, 0.12765668784933432, 0.15811030300600187, 0.2035588635397809, 0.10212191553520304, 0.1669653207063675, 0.09538423921912909, 0.17285881803504058, 0.15726283990911075, 0.11627217302364962, 0.10417729988694191, 0.07427119463682175, 0.17703753523528576], [0.05221257418660181, 0.04442873257877571, 0.058303250399019034, 0.0910256491707904, 0.028084744233638048, 0.0354517719575337, 0.020291040119315897, 0.036329246658299646, 0.06209394056349993, 0.020576817016782503, 0.008100432476827076, 0.006895019681126411, 0.005255707913810121, 0.028090655969988023, 0.05586833426994937, 0.047387433637465746, 0.05146636547786849, 0.09002785664051771, 0.14906277135014534, 42.061614990234375, 80.6981154850551, 68.47294071742466, 71.3294563293457, 45.93431159428188, 53.92666809899466, 66.51810673304966, 45.99211713245937, 49.03645644869123, 106.5189277103969, 118.77888516017369, 79.61018739427838, 90.5826644897461, 71.34461729867118, 32.16036251613072, 2.901710169655936, 0.1208947878330946, 0.051265458044196875, 0.15046286050762447, 0.004754649666470608, 0.039988714935524125, 0.2134280875325203, 0.7042570869837488, 4.968544772693089, 0.591988528413432, 9.84872669833047, 73.50636168888637, 70.5840813773019, 76.45589978354317, 73.09793267931256, 76.71301092420305, 70.64412076132638, 76.6983780179705, 80.60194546835763, 85.77191938672746, 85.09451171330043, 84.88744149889264, 88.89133398873466, 88.63848904200962, 84.5402261189052, 83.52796391078404, 77.68283353533063, 76.45763683319092, 75.03309631347656, 76.1017987387521, 77.20583970206124, 75.28926249912807, 74.62299278804234, 78.38474750518799, 77.40778909410749, 76.99256474631173, 77.52448408944267, 77.51151875087193, 74.78100177219936, 77.65025343213762, 76.7461051940918, 79.75385529654366, 72.95646040780204, 74.7276257106236, 79.0948395047869, 70.36558832441057, 76.77040999276298, 71.89624868120465, 71.95402990068708, 76.01118728092739, 78.80974102020264, 68.44174330575126, 31.93594264984131, 30.78426136289324, 57.34733574731009, 75.89685467311314, 73.16740771702358, 68.27139432089669, 68.06742300306047, 72.57294763837541, 72.8819340297154, 71.59450926099504, 68.85749571663993, 67.60722991398403, 71.9578583581107, 76.02768230438232, 74.4992801121303, 75.21301991598946, 73.15461608341762, 72.46092878069196, 73.19939027513776, 72.93067564283098, 69.26015077318463, 69.20455128805978, 69.72210870470319, 68.86231776646206, 66.50261225019182, 69.2939954485212, 73.54205458504813, 70.80987003871373, 72.01238087245396, 70.34159619467599, 72.64648737226213, 66.16962678091866, 73.8125479561942, 77.99600969042096, 78.70994404384068, 78.92803410121373, 75.91075107029506, 64.12879494258335, 55.597435406276155, 58.12190008163452, 84.95430401393345, 37.26430770329067, 14.59744610105242, 17.210489886147634, 7.296007173401969, 4.404642002923148, 0.510250517300197, 0.17993449978530407, 0.05975036881864071, 0.10078122533325638, 0.2998403092580182, 0.2592109079871859, 0.11628216105912413, 0.051595931739679406, 0.8246707799179214, 34.07888521466936, 66.72186960492814, 70.56173597063336, 58.20731776101248, 43.0981889452253, 45.193581512996126, 32.18685599735805, 27.28264546394348, 32.714787074497764, 35.82345628738403, 40.78420952388218, 59.621317863464355, 65.1200110571725, 68.17069407871791, 20.774220943450928, 0.32960234795297894, 0.04687848826870322, 0.06425857583859138, 0.049679976156247516, 0.07050217688083649, 0.02728879381902516, 0.07557235338858195, 0.05716800024466855, 0.04499747723873172, 0.03043494526562946, 0.03033341946346419, 0.022798469589490975, 0.005456041985390974, 0.03627623950264283, 0.08102547470480204, 0.03340492018365434, 0.006632349021466715, 0.028624661333326782, 0.036623011609273295, 0.02481731483047562, 0.04205637059307524, 0.07084035873413086, 0.024479735177010298, 0.031854094471782446, 0.05191766929679683, 0.050988788783018074, 0.026704240989472185, 0.004104574951010623, 0.026503708446398377, 0.021304187897060598, 0.03008217490943415, 0.04623784264549613, 0.04409361431109054, 0.04942849750763603, 0.10011250193097762, 0.033282356403235874, 0.03378460802403944, 0.039821652828582695, 0.2830788386719567, 59.507096426827566, 92.62781810760498, 81.46774659837995, 91.76997961316789, 66.9268970489502, 64.18740994589669, 80.60966491699219, 52.271523816244944, 33.71782207489014, 93.27440357208252, 103.90806565965924, 78.47445569719586, 97.74067088535854, 75.20598139081682, 30.60354913984026, 1.8084624728986194, 0.23491585307887622, 0.02218851919418999, 0.2248511838593653, 0.02426443262291806, 0.6404017305799893, 1.9044890744345528, 1.4275100060871668, 1.5432517954281397, 0.5948351728064674, 20.103210823876516, 85.18188531058175, 76.80972984858921, 86.16725104195731, 78.1527818952288, 84.8911657333374, 76.27792862483433, 84.1437132699149, 84.4000323159354, 89.70539883204869, 88.60195541381836, 89.94347885676792, 91.24869101388114, 89.9511913572039, 85.7901862008231, 84.54169913700649, 80.484833581107, 81.97293622153146, 77.6213628223964, 79.36490208762032, 80.86724158695766, 83.99318749564034, 80.78999846322196, 78.54262447357178, 78.85290322984967, 79.66992800576347, 82.40002114432198, 78.73900835854667, 79.2457196371896, 81.96889236995152, 80.35659762791225, 82.86984443664551, 73.3598380770002, 76.62287194388253, 79.94438879830497, 74.4288740158081, 79.86101041521344, 76.85832554953438, 75.7079609462193, 77.22674683162144, 80.35829298836845, 68.18548679351807, 34.88601228169033, 31.77412257875715, 55.113753931862966, 80.60464831760952, 76.13506671360561, 73.54042870657784, 70.82307161603654, 73.83574799128941, 73.73431818825858, 74.91890961783272, 68.90939181191581, 68.81782845088414, 72.21005017416817, 77.96496513911656, 75.05272497449602, 75.60429382324219, 74.65926933288574, 75.18542167118618, 74.17550795418876, 75.97844042096818, 72.9145975112915, 72.61786774226597, 71.2601341520037, 72.90061773572648, 71.08668627057756, 73.96506786346436, 74.68845871516636, 76.5177526473999, 75.78139645712716, 73.64633314950126, 73.36950302124023, 72.60855020795549, 74.30234731946672, 76.99439212254116, 79.5014202935355, 80.4645448412214, 79.48065907614571, 71.71735341208321, 64.20395360674176, 65.52414608001709, 78.34293324606759, 86.19224371228898, 35.669609274183, 29.359290054866246, 12.391664028167725, 5.264461602483477, 0.6897250381963593, 0.22442373393901757, 0.17898779415658542, 0.15928340862904275, 0.5757522167904037, 0.39702253735491205, 0.4552383992288794, 0.058897389232047966, 0.045310047787747214, 29.578606469290598, 72.60628509521484, 80.08926568712506, 69.110917363848, 45.62379312515259, 20.218969549451554, 21.259158304759435, 33.95583956582205, 47.60419300624302, 48.31787722451346, 59.40981469835554, 75.06175763266427, 72.15752179282052, 82.45229939052037, 27.46871301106044, 0.2342593568776335, 0.04870621394366026, 0.04464462206565908, 0.06070971555475678, 0.16643998532422952, 0.04739212231444461, 0.10149072190480572, 0.035603804513812065, 0.07731789829475538, 0.016294010848339115, 0.037728630139359405, 0.05463470332324505, 0.05833102283733232, 0.04163341935990112, 0.013202710476304804, 0.027955303500805582, 0.05438895829554115, 0.023879808440272297, 0.012876744797852422, 0.012923732499725052, 0.10841693596116134, 0.20639539776103838, 0.11929041892290115, 0.14407898592097418, 0.11388197913765907, 0.10706501600465604, 0.1418958537812744, 0.1318075308310134, 0.1617272203522069, 0.13371774261551245, 0.12075313686260156, 0.16900669330997126, 0.1574048844299146, 0.17337964794465474, 0.18982580330755028, 0.13376609502094133, 0.11141479866845266, 0.15163749961980752, 0.4649937514747892, 65.49028056008476, 106.84058066776821, 88.7258209500994, 93.57426697867257, 65.61687673841203, 71.90938077654157, 84.05649253300258, 60.42234788622175, 63.28770160675049, 120.41040556771415, 138.72163254874093, 98.5042918069022, 110.45243494851249, 89.86618709564209, 48.319871357509065, 4.6844168645995, 0.4130669321332659, 0.1983393957572324, 0.4303222405058997, 0.18745687470904418, 0.3916174631033625, 0.6849659564239639, 2.233014451605933, 12.515215158462524, 2.1682122945785522, 21.307776587350027, 96.94125284467424, 90.03439603533063, 92.67539242335728, 80.9372307913644, 91.00001498631069, 81.37445313589913, 90.50310066768101, 89.26639774867466, 96.19155611310686, 91.6519227709089, 94.37532479422433, 96.43423584529332, 94.24639402117047, 89.35045705522809, 90.43004035949707, 85.79189545767647, 84.2365620476859, 80.55658762795585, 80.5948235648019, 83.15759713309151, 87.04033388410295, 82.15809181758335, 86.50693457467216, 82.68568938119071, 83.39315496172223, 84.79465525490897, 82.97331701006208, 79.79903248378209, 86.16445091792515, 81.49879809788295, 84.70523193904332, 73.31928144182477, 78.10470730917794, 82.46993391854423, 77.81634317125592, 82.87912028176444, 80.28952666691372, 76.29035200391496, 80.94147614070347, 82.85391916547502, 69.41285133361816, 44.91078288214547, 44.5510642187936, 60.699740818568635, 81.01851081848145, 80.23851299285889, 76.30624253409249, 73.05573626926967, 74.31924533843994, 75.2765542439052, 73.49268763405937, 71.81388473510742, 69.78234958648682, 73.94978877476284, 79.75278527396065, 78.82395703451974, 81.60644653865269, 78.70519842420305, 79.43537766592843, 77.81216730390275, 80.71220643179757, 75.17529119764055, 74.61816379002163, 73.29931926727295, 74.95517226627895, 74.9614325932094, 74.76850196293422, 76.57409558977399, 80.34040832519531, 77.6239822932652, 75.67590195792062, 76.4479649407523, 73.3333306993757, 76.1766516821725, 79.35307625361851, 81.68478052956718, 83.56273964473179, 83.31053393227714, 74.62738404955182, 68.81693213326591, 73.69096837724958, 82.489013671875, 72.77534171513149, 39.660623277936665, 33.15012993131365, 15.608805043356758, 6.501769014767238, 1.586341917514801, 0.43383205788476126, 0.46778893577201025, 0.202060142531991, 1.0516079025609153, 1.1524048766919543, 0.5876910675849233, 0.18103589782757418, 1.4464779368468692, 43.042641571589876, 75.0966306413923, 86.6838218144008, 75.14122417994908, 58.172684465135845, 66.52187960488456, 49.013270309993196, 40.020282881600515, 45.76686348233904, 49.96837663650513, 58.802583830697195, 79.21102728162492, 83.21792834145683, 99.12125710078648, 34.94336271286011, 0.43339299144489424, 0.16181785905999796, 0.11624543874391488, 0.13899066538683005, 0.2771273808819907, 0.11868786625564098, 0.1784686063017164, 0.0894330528431705, 0.17820703105202743, 0.06853287826691355, 0.16026326747877256, 0.10470218743596758, 0.09657918009907007, 0.12150225309388978, 0.09472201618232898, 0.10935413531426873, 0.2155324960393565, 0.09012847659843308, 0.128615512113486, 0.10807794665119477], [0.06444658432155848, 0.023227300328601683, 0.02950340150190251, 0.01335328078961798, 0.05187867049660001, 0.02129198614108775, 0.06001972007964339, 0.05437646985852292, 0.09720395478819098, 0.00985538272652775, 0.06430567295423575, 0.02428216443929289, 0.0027840853726956993, 0.025939084190343107, 0.02970740305525916, 0.0493797651225967, 0.2450419297175748, 0.22784839517303876, 4.979376145771571, 69.44370828356061, 71.93110084533691, 72.8223740713937, 45.16664334705898, 55.65064123698643, 61.38867555345808, 44.87703548158918, 41.090944698878694, 49.997753620147705, 99.89288929530552, 118.24141420636857, 88.74740205492292, 52.51514155524117, 23.805193662643433, 1.599281200340816, 0.06527546912963901, 0.08050270418503455, 0.03676008586106556, 0.1991497158472027, 0.044299261311867406, 0.23429865762591362, 0.648733272084168, 0.9915610275098256, 0.464246820126261, 0.6831954685705048, 44.36705160140991, 65.15619727543422, 60.6349002293178, 75.27896526881626, 80.784426007952, 76.82148620060512, 70.90313570840019, 80.83573845454625, 78.6203053338187, 83.5102321079799, 83.0219544001988, 91.70478466578892, 84.25599615914481, 84.18600000653947, 83.57530893598283, 81.84179592132568, 76.624358858381, 76.54620552062988, 73.56678322383335, 72.88962568555559, 71.11980138506208, 73.75249467577252, 70.62924466814313, 72.53404467446464, 77.33904361724854, 76.7879889351981, 77.70028741019112, 76.11603559766496, 79.95539474487305, 75.41372558048793, 77.17479515075684, 77.85966518947056, 81.56461838313511, 71.93984862736293, 75.03192206791469, 76.90682397569928, 77.32933698381696, 68.40980243682861, 70.84668854304722, 71.43866116659981, 81.4936911719186, 55.547116552080425, 32.91115358897618, 26.25909764426095, 31.38220248903547, 81.7836811883109, 69.99271324702671, 73.37538119724819, 68.42957006181989, 76.206556728908, 69.62809262956891, 71.82954597473145, 62.32642527988979, 72.70519965035575, 73.36557034083775, 75.9294000353132, 69.9751204081944, 74.17959349496024, 70.11832278115409, 72.9481781550816, 65.91597584315709, 70.92066601344517, 69.85754299163818, 73.68877969469342, 70.02848952157157, 74.82314954485211, 70.32849189213344, 70.17572184971401, 67.34219087873186, 73.20679705483573, 71.00016035352434, 73.75784478868756, 69.02040318080357, 73.07950605664934, 67.72380678994315, 73.35414055415562, 74.6984919139317, 81.40878418513707, 77.92290074484688, 75.58793081556047, 68.58570998055595, 64.5959084374564, 61.39753450666155, 77.93346895490373, 23.93317253249032, 14.14822769165039, 15.599225214549474, 8.612167954444885, 1.6774031626326698, 0.07293603449527707, 0.024285640234925916, 0.12313079142144748, 0.5650054163166455, 0.7179469381059919, 0.2280781471303531, 0.09555146417447499, 0.0932260500267148, 1.4616859150784356, 41.68457099369594, 69.63503387996128, 67.66214152744838, 61.30781936645508, 60.07489626748221, 61.873374938964844, 36.840491907937185, 32.56697457177298, 40.12652778625488, 39.39119298117501, 47.611690112522666, 54.18770497185843, 53.536328724452424, 63.23394339425223, 23.032251732689993, 0.37534988458667484, 0.017532125215179155, 0.026485004628609334, 0.026942316875127808, 0.03013602684118918, 0.00866694814924683, 0.12662178623889173, 0.03656202148912208, 0.052591644560119936, 0.05318718117528728, 0.052831622040165324, 0.03720802414630141, 0.05417067697271705, 0.03733670152723789, 0.034726567300302644, 0.036691519897431135, 0.026571237947791815, 0.045325708375977616, 0.07993890943803958, 0.017733463518587605, 0.06358781004590647, 0.018123626243323088, 0.0339903601977442, 0.034323809269283495, 0.019328075095212886, 0.021470859846366302, 0.023162121951047863, 0.07946698154721941, 0.09369769293282713, 0.0499498227478138, 0.014885882747226527, 0.06884234451821872, 0.025801484073911394, 0.06152796093374491, 0.05587871585573469, 0.2739344393568379, 0.2259977316217763, 9.333063534327916, 88.26826122828892, 81.73651681627545, 89.7683356148856, 61.65229715619768, 67.45238930838448, 75.72888892037528, 53.58680043901716, 44.44034467424665, 52.4613972391401, 114.59199101584298, 118.79261480058942, 93.46520805358887, 59.48329189845494, 25.153508969715663, 0.8588305126343454, 0.12998769991099834, 0.032598898613027165, 0.02127588789777032, 0.11242809572390147, 0.3338232971727848, 1.6543866034064973, 2.592509469815663, 0.9601420334407261, 0.8206254627023424, 1.5112429644380296, 63.072606222970144, 73.44487707955497, 71.32872676849365, 82.19261046818325, 89.5329236984253, 79.68640218462262, 77.55484771728516, 84.52692031860352, 85.26443685804094, 86.74441705431256, 86.5480192729405, 92.73081820351737, 88.14946092878068, 84.01537309374127, 86.79069900512695, 84.40486131395612, 81.23656613486153, 81.87035301753453, 78.93132059914726, 75.91040366036552, 73.92597034999302, 73.48805318559918, 78.2456167766026, 75.39605631147111, 79.1369525364467, 80.93359688350132, 80.85021155221122, 80.0530447278704, 82.50747503553117, 79.98154776436942, 80.61183275495256, 80.19818564823696, 83.26423113686698, 73.68431200299943, 77.7466596875872, 78.44611399514335, 80.3058340890067, 71.42632811410087, 75.77078655787876, 75.71414484296525, 85.00156566074916, 53.12821933201381, 40.58923612322126, 36.19628620147705, 30.55775703702654, 82.49206393105644, 74.63200460161481, 76.70039299556187, 71.99039677211216, 81.25195639474052, 71.70868900844029, 73.71935176849365, 63.35773944854736, 75.26344299316406, 77.92582593645368, 79.58085904802594, 75.74787834712437, 76.2308406829834, 73.93433598109654, 75.1642644064767, 70.10812282562256, 73.99870409284318, 72.09367479596818, 77.04867144993374, 71.34760502406529, 75.96307795388358, 73.13790566580636, 74.45875126974923, 71.57507514953613, 74.16234111785889, 74.18395001547677, 77.07384477342877, 69.32037081037248, 75.67636053902763, 73.86735534667969, 75.57825892312187, 76.4692611694336, 81.77056298937116, 77.32213170187813, 80.6075804574149, 73.0201198032924, 71.18621921539307, 64.22702857426235, 80.61156872340611, 70.87430763244629, 34.84032440185547, 26.651597908564977, 13.47945315497262, 3.2282223062855855, 0.3534281551837921, 0.05711999389209917, 0.5879112386277744, 1.405406809278897, 0.2381987954889025, 0.33430464991501396, 0.3666059566395623, 0.11210024117359094, 0.22965880802699498, 37.76492888586861, 77.25383785792759, 77.2868765422276, 71.6300492967878, 50.77298845563616, 24.197719982692174, 19.55350582940238, 31.699071611676896, 53.88896369934082, 53.30350848606655, 61.858721188136506, 67.55838407788957, 60.983081408909385, 73.00322873251778, 34.0077669279916, 0.34463518272553173, 0.03709184877308352, 0.015468069185901965, 0.04401051073468157, 0.01445614786020347, 0.06278694873409611, 0.08197430414812905, 0.012756410004970218, 0.07583667670509645, 0.010842329722696116, 0.049305937119892666, 0.009449965686404278, 0.042279174351798635, 0.03987223422154784, 0.06652238579200846, 0.025479868653097322, 0.046511899546853135, 0.01998007600195706, 0.05794013916913952, 0.19953113395188535, 0.12080337559538228, 0.10184919195515768, 0.1043784651639206, 0.10647300777158566, 0.09150580769138676, 0.12051829589264733, 0.20905017959220068, 0.22510262179587567, 0.13503019218998297, 0.1608018342937742, 0.1222206995423351, 0.13186988819922718, 0.07660580293408462, 0.17165230134768145, 0.09385286710624184, 0.5163338822977883, 0.6818870359233448, 12.633052263941083, 106.29266657148088, 92.05272960662842, 100.18054471697126, 60.53547150748116, 74.61086818150112, 82.14377158028739, 64.14207295009068, 58.171124594552175, 58.03007616315569, 108.31783717019218, 127.80080141339982, 109.97025081089565, 71.00243241446358, 40.81068216051374, 4.176251241139003, 0.21639477834105492, 0.218757993674704, 0.1394247513796602, 0.23965311316507204, 0.25333797026957783, 0.557399852999619, 1.8163087261574609, 8.179200513022286, 3.1108783057757785, 1.1134201628821236, 71.33156858171735, 85.75431959969657, 80.97733579363141, 90.24569770268032, 96.2659296308245, 84.53218705313546, 86.29426411220005, 87.76460715702602, 87.95887878962925, 88.80962317330497, 89.76524366651262, 97.2715563092913, 91.77211271013532, 90.43600886208671, 91.69549492427281, 88.66421822139195, 83.56408064705985, 86.51552949632917, 80.97055435180664, 80.99936853136334, 77.3177056993757, 78.18894726889474, 80.3024433680943, 78.7465818950108, 85.72305270603725, 83.6212226322719, 81.5906046458653, 83.99315275464738, 84.21418190002441, 81.729186466762, 82.29700020381382, 83.82258142743791, 86.19729505266461, 73.95959963117326, 79.22394398280552, 81.52087252480644, 81.75210857391357, 75.01677499498639, 79.79446751730782, 80.87083380562919, 84.48767689296177, 60.27055753980364, 39.9272916657584, 34.20318848746163, 39.701673235212056, 82.82001195635114, 78.58520998273576, 79.29491983141217, 74.10255881718227, 84.50112165723527, 75.41496930803571, 75.50589343479702, 65.8997448512486, 74.29719870431083, 80.52066544124058, 82.4846363067627, 78.03298800332206, 77.88702719552177, 76.39338684082031, 77.78916181836809, 74.48949010031563, 77.11108711787632, 76.3171581540789, 79.57455008370536, 74.6569903237479, 79.43254974910191, 77.97429656982422, 77.75079386574882, 73.65865925380162, 75.33221626281738, 77.11442225319999, 79.68987628391811, 74.63187953404018, 77.06772341047014, 75.64490604400635, 76.44630432128906, 80.43687711443219, 83.37121949877057, 83.33634649004254, 85.6782090323312, 76.32527365003313, 72.00045081547329, 69.37039089202881, 81.72662952968052, 59.3469751902989, 37.344420433044434, 31.892596312931605, 16.295797756740026, 3.908116783414568, 0.46455780629600796, 0.21669327946645872, 0.4529979851629053, 1.4901629984378815, 1.7100081273487635, 1.4658291041851044, 0.21150140091776848, 0.36825246257441385, 2.531075886317662, 54.348107610430034, 82.90834440503801, 84.25526659829276, 79.94440964290074, 86.74240207672119, 88.19960607801164, 56.225107874189106, 50.8450516973223, 56.594960485185894, 53.081218242645264, 64.55988897596086, 72.18306337084088, 69.37513651166643, 85.68291296277727, 42.628897190093994, 0.9178990487541471, 0.18337984276669367, 0.1317220761307648, 0.12060031720570155, 0.14407946089548723, 0.19758908530431135, 0.23184325652463095, 0.2124320524079459, 0.11484172620943614, 0.09117207702781473, 0.10114830599299499, 0.1622238808444568, 0.1632721631654671, 0.12905000522732735, 0.11112817869122539, 0.1291221742119108, 0.1341385564633778, 0.09807731078139373, 0.21139181751225675], [0.05137270389656935, 0.08564260695129633, 0.11656563941921506, 0.030468675241406475, 0.043214745220861266, 0.04506366493712578, 0.012115386946659003, 0.049399992251502614, 0.0838058397972158, 0.09437159355729818, 0.0712334815678852, 0.012121014546469917, 0.003368899650273046, 0.041189460682549646, 0.04693807382136583, 0.03103667012016688, 0.14400935465736048, 0.16685458379132406, 13.567202823502676, 69.60917268480573, 57.575705664498464, 57.19389172962734, 42.20020375932966, 57.27053036008562, 37.255691937037874, 51.35959359577724, 43.065726961408345, 34.40837574005127, 51.071965966905864, 57.10229710170201, 42.59412840434483, 28.319407020296367, 2.7286101324217658, 0.031400510775191445, 0.16013087172593388, 0.041667644666241746, 0.11731825689119951, 0.10626657706286226, 0.08495092870933668, 0.31576115638017654, 7.546530553272792, 1.789021413241114, 0.16819884308746882, 17.295356920787267, 69.44277027675084, 66.69643919808524, 65.81926386696952, 67.86723150525773, 80.58576311383928, 78.81439631325858, 86.9708171572004, 84.46681145259312, 85.06000001089913, 83.50213050842285, 83.1360924584525, 82.28012302943638, 84.28148909977504, 83.12025751386369, 84.37433092934745, 77.30664416721889, 80.403977394104, 76.25926576341901, 75.92320224217006, 68.68225519997733, 73.22477899278913, 74.16365432739258, 76.88522202627999, 73.76076303209577, 72.5193909236363, 74.13644518171037, 78.63324287959507, 75.54513686043876, 77.39929144723075, 77.9940641948155, 73.02453190939767, 72.08632360185895, 75.87224415370396, 72.8677874973842, 68.11984716142926, 67.03486510685512, 76.78054741450718, 69.55990300859723, 69.8165625163487, 74.99414471217564, 85.12545898982457, 33.639064243861604, 52.21194996152605, 68.02515711103166, 20.815036399023874, 58.74435097830636, 74.44296496255058, 69.73736000061035, 70.20684977940151, 69.22075448717389, 66.64621761866978, 61.82306998116629, 68.24361542293003, 73.10840361458915, 71.8367234638759, 74.09071908678327, 74.98217296600342, 76.14689949580601, 75.15944930485317, 70.31773608071464, 70.76006535121373, 65.90754073006767, 65.66320732661656, 70.3127750669207, 69.72668061937604, 67.27518939971924, 70.96667003631592, 70.35476997920445, 67.89779663085938, 70.11484173366001, 71.25610419682094, 70.68765817369733, 67.03658826010567, 70.15445341382707, 70.85647855486188, 69.9346957887922, 72.07185745239258, 71.45466981615338, 77.6607313156128, 78.91917514801025, 72.41519573756626, 73.35595403398786, 65.29034614562988, 65.07306902749198, 66.85394096374512, 18.62408004488264, 10.175048845154897, 14.508688943726675, 7.6102116618837625, 1.3061139030115945, 0.2210156832422529, 1.1468867042234965, 0.6650314661008971, 0.027662442697744285, 0.42753433010407854, 0.3204750477203301, 0.08292328965451036, 0.021467767423018813, 2.404866852930614, 49.08263765062605, 72.40163285391671, 64.50102383749825, 56.1640088898795, 47.01415545599801, 42.378372941698345, 39.21230466025216, 23.74181740624564, 35.06298289980207, 45.94974701745169, 53.83918333053589, 66.49705369131905, 57.55854361397879, 68.55156653267997, 25.115078483309063, 0.24069214026842797, 0.033350657738213024, 0.0270021382187094, 0.05678341677412391, 0.01663599249773792, 0.02025529319819595, 0.062301199084946086, 0.08741576823272876, 0.05123409954831004, 0.04545816519696798, 0.030498778447508812, 0.0867341865918466, 0.021278781849624853, 0.04493096384352871, 0.028036441021998013, 0.02112866615477417, 0.07148687368524925, 0.04243228238608156, 0.1020889523039971, 0.06650048946695668, 0.027903607614072304, 0.04576786893552967, 0.024393260977896195, 0.07562491271112647, 0.057617360060768466, 0.03373848121347172, 0.06472367088177375, 0.025489748122968843, 0.04265505561072912, 0.06106444687715598, 0.054794474571411095, 0.08383984118700027, 0.08027695558433022, 0.0707289364987186, 0.11979394618953977, 0.12533388606139592, 24.277151788984025, 85.98956475939069, 69.11462770189557, 72.565735408238, 50.734498909541536, 77.40259184156145, 49.75708886555263, 45.27582733971732, 26.214495420455933, 35.935089520045686, 55.652798652648926, 62.185494967869346, 50.699855191367014, 32.31596047537667, 2.083593223776136, 0.03896627122802394, 0.031142345163971186, 0.030468285083770752, 0.07511751100953136, 0.21304740224565777, 0.323627060013158, 1.509364670940808, 6.115637642996652, 1.0681103084768568, 1.0124871560505457, 28.30484880719866, 82.18074989318848, 76.12126064300537, 79.95531136648995, 80.0704847063337, 83.22136769975934, 85.90871552058628, 93.35629504067558, 89.4258519581386, 88.64887659890312, 87.74729224613735, 85.76554094042096, 84.7952458517892, 89.34846292223249, 86.0037043435233, 85.65541894095284, 81.47567449297223, 81.96709973471505, 79.10597051892961, 79.4590015411377, 74.7915699822562, 76.2243788582938, 78.75725432804653, 79.22293649400983, 79.6642096383231, 75.87874071938651, 78.15426880972726, 79.05080182211739, 78.70966611589704, 78.60188565935407, 79.81222711290631, 77.81185463496617, 76.43146991729736, 78.64210183279855, 75.74519634246826, 70.93607711791992, 70.8125034059797, 78.84905392783028, 73.73495047433036, 73.42558888026646, 80.66495868137905, 83.95301301138741, 35.10353258677891, 55.07969733646938, 70.50700501033238, 24.83227116721017, 53.41615962982178, 79.55228110722133, 72.30763762337821, 73.30069501059396, 72.40724699837821, 70.91246713910783, 60.33427252088274, 72.13866438184465, 74.73570646558488, 75.67037119184221, 73.60322652544293, 75.14068916865757, 76.55087471008301, 75.14198848179409, 71.55785751342773, 72.44562884739467, 68.9141652243478, 67.84839493887765, 71.18602466583252, 72.97223281860352, 68.5310207094465, 73.19896643502372, 74.92496149880546, 72.80724784306118, 72.47185134887695, 72.66136346544538, 71.47058119092668, 72.91689736502511, 73.40496662684849, 74.44115148271833, 74.01730442047119, 70.95093931470598, 74.29446111406598, 78.60412992749895, 79.49832834516252, 78.2491534096854, 75.8097312109811, 72.38286576952252, 65.22698552267892, 78.10248388562883, 67.59527901240757, 33.60471929822649, 25.501420906611852, 11.204709342547826, 2.3279046969754353, 0.31470503019435064, 1.6034380687134606, 1.177303529211453, 0.01574531859452171, 0.1353273226746491, 0.1631083105291639, 0.37453176134399, 0.05585808160581759, 0.8238134373511586, 45.740679195949006, 79.89359051840646, 71.28350789206368, 66.78921849387032, 43.35999706813267, 26.91126251220703, 24.051602840423584, 33.60552528926304, 54.181545393807546, 63.090143476213726, 72.53920718601772, 84.14323384421212, 67.32089465005058, 80.92441136496407, 37.15626668930054, 0.1309197898954153, 0.014820775615849664, 0.05069089833913105, 0.04574181319081357, 0.047727515388812335, 0.020151585905945728, 0.0772793914324471, 0.06831220510814871, 0.024920825347570435, 0.03717428059982402, 0.06911035906523466, 0.02081448578142694, 0.010019887604617646, 0.07504023265625749, 0.06527431562010731, 0.021862554363906384, 0.054744547964738946, 0.05215828799243484, 0.18708585176084722, 0.14921641881976808, 0.23675099174891198, 0.10867815837264061, 0.10620563104748726, 0.11019927103604589, 0.1254604057009731, 0.099758374504745, 0.21071311964520387, 0.14930428910468305, 0.1661618266786848, 0.14460651975657257, 0.15261202518429073, 0.2452416361442634, 0.07075512795043842, 0.09620938529925686, 0.26538579378809246, 0.19952527140932425, 33.440651484898154, 100.68169048854283, 78.68298503330776, 79.77278913770402, 59.23986870901925, 79.43989399501255, 50.28055919919695, 73.58505698612758, 64.31394359043666, 49.36959825243269, 65.41305828094482, 76.06209673200334, 59.97931684766497, 46.143368993486675, 5.744098791054316, 0.1510263295578105, 0.25820518338254517, 0.12788899109831878, 0.34733105663742336, 0.258734332131488, 0.3315832902278219, 2.2693168350628445, 15.865857124328613, 7.899632794516427, 1.4314806844506944, 29.729587350572857, 94.0122605732509, 78.96282373155866, 87.3330545425415, 84.14008631025041, 93.92314297812325, 89.88359928131104, 97.7923446382795, 94.22836344582694, 92.9184126172747, 89.18436731610979, 88.3113192149571, 88.56028011866978, 93.32172080448696, 89.58577169690813, 90.38307748522077, 85.50444848196847, 86.1205244064331, 84.00852216993059, 84.45473548344204, 75.51581546238491, 79.35607092721122, 81.06985800606864, 82.96695246015275, 84.63141427721295, 79.77936908176967, 80.71510383061, 84.39638451167515, 83.1320972442627, 84.90962709699357, 85.74028423854283, 80.25957298278809, 79.09252575465611, 80.53965486798967, 78.13151345934186, 71.97966875348772, 71.47972502027238, 83.47313567570278, 75.80600002833775, 76.73430715288434, 80.63645022256034, 85.46644183567592, 40.47850268227713, 56.628919805799214, 65.39772360665458, 26.612102610724314, 59.39889213017055, 78.30995709555489, 76.04656055995396, 75.22884791237968, 73.54920428139823, 71.18405832563127, 60.67312921796526, 71.45041751861572, 78.0870588847569, 77.20934854234967, 78.09048434666225, 77.93657479967389, 82.6607106072562, 80.35931437356132, 76.30152470724923, 75.79263864244733, 70.75701509203229, 72.37629972185407, 78.20614406040737, 75.85565185546875, 72.76536410195487, 77.42128944396973, 78.10139301845005, 75.79023456573486, 77.64454896109444, 77.29506846836635, 74.00528403690883, 74.20373153686523, 76.41393961225236, 77.83544376918248, 77.23630755288261, 72.45410564967564, 75.00418485913957, 80.39963476998466, 85.61716910770961, 81.75121225629533, 77.74941117422921, 72.62747015271867, 70.9245639528547, 74.63461712428501, 58.61910275050572, 36.11036825180054, 28.806849207196915, 13.390870571136475, 2.4620044955185483, 0.5918761630143438, 4.146921592099326, 2.144426873752049, 0.07067967485636473, 1.7094750702381134, 1.2650797963142395, 0.3762710637279919, 0.12196654746575014, 3.7521592548915317, 57.64394392286028, 86.49591473170689, 77.83240045819963, 74.3039801461356, 68.46374825068882, 60.953662736075266, 61.049867493765696, 37.30975934437343, 47.687821524483816, 64.03520270756313, 73.26796899523053, 88.13212517329625, 73.11536570957729, 93.54748167310441, 44.09457104546683, 0.29206573643854683, 0.17192675519202436, 0.16853021244917596, 0.12949614200208867, 0.09311052265443973, 0.14816314248102053, 0.13614047904099735, 0.1730572623865945, 0.16121016309729644, 0.2759809823972838, 0.22114474060279982, 0.26495481548564775, 0.07779510518802063, 0.125159638268607, 0.1061833683135254, 0.117340906390122, 0.14553668270153658, 0.2840008863380977], [0.059692014807036946, 0.009816064166703393, 0.01502004438745124, 0.11458517211888518, 0.03635385712342603, 0.08908421799008336, 0.03286307265183755, 0.11578312569430896, 0.05611951097047754, 0.05829158638204847, 0.16971048340201378, 0.05318504718265363, 0.005774139202133353, 0.025883435837126205, 0.06089296072189297, 0.05127294907080276, 0.057267507405153344, 0.31310773161905153, 28.825760466711863, 66.6376643862043, 58.84218161446707, 53.75498158591134, 52.46280424935477, 37.545928614480154, 40.97307893208095, 46.634693486349924, 58.77662536076137, 36.97509241104126, 29.596828120095388, 46.34023577826363, 41.94237000601632, 6.158621370792389, 0.14414474953498158, 0.0461795700580946, 0.10188260301947594, 0.0074237456179357, 0.10328470742596046, 0.10756419386182513, 0.3229773763035025, 6.341444109167371, 6.534881957939692, 0.5115377796547753, 4.208905603204455, 58.2013110433306, 67.5061822618757, 78.40436226981026, 76.34209523882184, 83.13058948516846, 72.50742612566266, 82.57536588396344, 83.46751458304269, 81.5763052531651, 80.45014122554234, 86.97097696576799, 85.632246698652, 85.15489155905587, 84.58891909463065, 83.4661249433245, 80.25798184531075, 82.54985904693604, 74.79999119894845, 73.60868086133684, 76.0474499293736, 75.2656386239188, 71.79711178370884, 71.48099654061454, 73.23337391444615, 72.68226364680699, 70.02685669490269, 73.90010220663888, 70.69120175497872, 75.73189054216657, 73.01512404850551, 75.42617675236293, 74.36351231166294, 75.60422434125627, 74.7413136618478, 72.93628978729248, 69.10013375963483, 72.41400064740861, 74.05094064985002, 73.97508021763393, 63.05441583905901, 80.32838099343437, 68.79082080296108, 46.68618311200823, 51.60459402629307, 65.83145795549665, 38.64391769681658, 26.175370114190237, 78.31737082345145, 68.82612460000175, 73.16691439492362, 69.42094598497663, 65.5923843383789, 60.2728157043457, 68.17710031781877, 68.24922261919293, 73.4088020324707, 69.20255715506417, 73.27008124760219, 68.93054212842668, 70.92090920039585, 65.97965608324323, 67.22395338330949, 66.07873044695172, 65.44911248343331, 63.96173940386091, 63.85473019736153, 64.44111646924699, 65.60262598310197, 66.24111679622105, 69.54880673544747, 66.78929492405483, 69.75236810956682, 69.46273245130266, 68.04915618896484, 68.75166075570243, 70.41444110870361, 67.4004237311227, 68.79321793147496, 73.24767330714634, 73.73492962973458, 76.7298811503819, 74.2939122063773, 74.22371455601284, 72.38706248147147, 68.00325638907296, 67.44007015228271, 60.668091773986816, 17.520502873829432, 6.561483570507594, 12.782858031136648, 5.551894681794303, 0.7321594240409988, 0.26835240317242487, 0.671116785279342, 0.4299386239477566, 0.1371383462101221, 4.356198293822152, 0.4847052480493273, 0.0551216980841543, 0.06919340496616704, 5.080584909234728, 55.24240330287388, 71.15416717529297, 63.12701756613595, 51.43104192188808, 36.887586797986714, 40.74574082238333, 33.52702454158238, 27.474374055862427, 30.54043170383998, 44.30814824785505, 36.25097894668579, 55.417932169778005, 54.2694331577846, 70.41639355250767, 14.243003726005554, 0.20576815998979978, 0.039472831546195915, 0.042763329443654845, 0.09866496281964438, 0.06655146780290774, 0.13601239877087729, 0.0706130223614829, 0.027333680606846298, 0.025722441529589038, 0.024070088319214325, 0.01877765596977302, 0.035111588425934315, 0.04140434593760541, 0.021427733856918554, 0.026681662736726657, 0.07690501652125802, 0.04134941513517073, 0.020722154128764356, 0.011988051368721893, 0.030611347407102585, 0.07012897583522967, 0.014502444304525852, 0.04776746074536017, 0.016170756658539176, 0.06543103685336453, 0.06122000103018113, 0.05096561341945614, 0.044104453908013444, 0.006726805760990828, 0.04339888944689717, 0.08849899510719947, 0.04462650178798607, 0.04993744287639856, 0.09863768571189471, 0.3285560740956238, 42.343711853027344, 81.67040470668248, 67.00846890040806, 68.71553012302944, 59.283961977277485, 48.16176162447248, 27.410749401365006, 25.49604994910104, 29.816255705697195, 29.62664978844779, 31.482621329171316, 51.15653249195644, 46.55133594785418, 3.7289553114346097, 0.055176788342318366, 0.0336930566866483, 0.10850421592061009, 0.03896688869489091, 0.14472290208297117, 0.13523506905351365, 0.11955636393811021, 1.9392211650099074, 1.7459182632820947, 0.6749155500105449, 9.690064583505903, 75.99223259517125, 70.26343590872628, 84.80432714734758, 81.72270379747663, 87.58835220336914, 81.40154416220528, 88.84958226340157, 85.9520514351981, 85.46206447056362, 84.19377504076276, 91.89075320107597, 88.02189895084926, 89.24678993225098, 87.2830969946725, 85.1742353439331, 84.43673270089286, 86.00314153943742, 78.14830725533622, 78.18395151410783, 80.74848992483956, 80.53634752546037, 74.05626991816929, 74.906555720738, 74.05952862330845, 75.12616743360246, 74.34614876338414, 76.85517106737409, 74.63290786743164, 80.15247344970703, 77.24466623578752, 79.39205564771379, 77.18849699837821, 81.52418681553432, 79.04622990744454, 76.60839884621757, 70.23817225864956, 73.90625136239188, 74.64779785701207, 76.96600178309849, 66.71968092237199, 83.89325155530656, 68.93827547345842, 51.78408684049334, 53.800686836242676, 63.92606735229492, 43.90145976202828, 27.064355645860942, 77.63186849866594, 71.77737195151192, 74.74057020459855, 70.61766896929059, 67.9769366128104, 63.66726085117885, 70.58823640005929, 73.67775290352958, 74.40315178462437, 73.15253162384033, 77.7595694405692, 72.33368641989571, 73.33648518153599, 70.5088323865618, 70.00057860783168, 68.63939176286969, 69.41877119881767, 66.6355868748256, 65.00685964311872, 67.63482121058873, 68.77260957445417, 67.35457256862095, 69.72172655378068, 69.35485471997941, 71.36255754743303, 71.00988783155168, 69.34305667877197, 71.55675969805036, 71.82293128967285, 69.84105491638184, 74.1967694418771, 74.84632873535156, 73.66924830845424, 75.52414635249546, 75.20587021963937, 77.2870294025966, 75.66832842145647, 70.34446580069405, 70.33938666752407, 76.2153878893171, 63.58616842542376, 33.1042857170105, 21.87218918119158, 8.173946806362697, 1.109028684241431, 0.32728240958281923, 1.6396157102925437, 1.4841100318091256, 0.5063421555927822, 1.5122344940900803, 0.5291806672300611, 0.17331068164535932, 0.13273903727531433, 3.163992941379547, 53.08520998273577, 79.63653496333531, 71.21164267403739, 55.48940828868321, 34.08568402699062, 27.54293887955802, 18.07844148363386, 29.649578843797954, 41.88493619646345, 60.329860414777485, 47.02832283292498, 71.83229051317487, 59.74949823107038, 82.07289995465959, 22.95089180128915, 0.24437910956995829, 0.03431047944884215, 0.04447940896664347, 0.04324444130595241, 0.05942330815430198, 0.0356774323486856, 0.06386955814169985, 0.03328764897638133, 0.01751161310156541, 0.02740035854679133, 0.021107112489906803, 0.02839535890546228, 0.023827764804341962, 0.021755496805001582, 0.04800743144005537, 0.03412691876292229, 0.03929221909493208, 0.10300458781421185, 0.07990397166992937, 0.09209431468376092, 0.2337873407772609, 0.12952639109322003, 0.17929004079529218, 0.07226600830576249, 0.29523251365338055, 0.18246669747999736, 0.17400347947009973, 0.31340170013053076, 0.21552572425987038, 0.13566505669483117, 0.16294692776032857, 0.11599272516156946, 0.09429727361670562, 0.20693552520658287, 0.5468439651387078, 57.92614500863211, 95.28211334773472, 81.58248220171247, 77.54790646689278, 71.09220314025879, 56.90424912316458, 61.382943289620535, 68.22031116485596, 80.28824125017438, 57.46045936856951, 44.815613406045095, 61.748244830540244, 62.19188731057303, 9.962444390569415, 0.14945314611707414, 0.14333357449088777, 0.1955668202468327, 0.28364457402910503, 0.20973638205655984, 0.38196041701095446, 1.1518524949039732, 15.809741735458374, 16.71421480178833, 1.6082729292767388, 8.106249638966151, 84.26598072052002, 76.96017919267926, 91.97435392652238, 90.30026190621513, 97.30094718933105, 87.87816851479667, 92.71435097285679, 89.82947976248605, 88.39822033473423, 86.34495816911969, 94.2543636049543, 90.5096458707537, 93.1640453338623, 90.02998392922538, 89.10356671469552, 90.87761551993233, 90.82032762254987, 84.51803357260567, 81.91480759211949, 82.6569516318185, 84.6956434249878, 77.46436827523368, 77.6040062223162, 77.645354952131, 79.34798322405133, 79.0900799887521, 80.72802747998918, 78.09608459472656, 82.33368669237409, 78.92160701751709, 82.16487325940813, 78.66921370370048, 83.24020426613944, 82.00872639247349, 78.52303750174386, 73.6722777230399, 75.71902247837612, 79.04196371350969, 79.16883781978062, 68.98143073490688, 86.28787871769497, 72.59572383335659, 49.055845396859304, 51.93408802577427, 66.52872358049665, 43.169262068612234, 33.868236677987234, 79.69968019212995, 75.16846806662423, 78.04619652884347, 74.29550334385463, 69.11164692470005, 64.17720999036516, 71.88620853424072, 73.65223911830357, 77.43374756404332, 75.49734020233154, 82.01843997410366, 75.4393505368914, 77.51333917890275, 72.77507073538644, 73.17612770625523, 73.1906008039202, 73.32725797380719, 71.81851918356759, 68.9837931224278, 72.78387410300118, 72.64696679796491, 74.00217124394008, 74.81096935272217, 71.9018975666591, 72.47326183319092, 74.54399177006313, 73.34687273842948, 74.52268859318325, 74.05825015476772, 72.81147929600307, 75.81276757376534, 74.61815684182304, 75.69100039345878, 78.0101284299578, 78.15137141091483, 81.51249299730573, 77.7152121407645, 73.73562444959367, 70.61616121019635, 69.11459990910122, 53.57166378838675, 35.17298330579485, 25.435173307146343, 9.546692848205566, 1.2755048083407539, 2.2920126914978027, 3.5457278404917036, 0.884240129164287, 0.45386678140078274, 9.329130853925433, 2.4864641087395802, 0.20986599581582205, 0.2409681954554149, 7.558204395430429, 66.41524560110909, 86.28290380750383, 80.5665374483381, 68.30084773472377, 54.00371667316982, 56.89863845280239, 53.06767272949219, 41.89137717655727, 44.24755300794329, 58.415277344839915, 50.643748487745015, 77.15390191759381, 70.43598747253418, 94.37268447875977, 26.774532386234828, 0.3710819807435785, 0.17503627762198448, 0.15564750587301596, 0.1975860861795289, 0.16269160860351153, 0.21876681462994643, 0.20214073892150605, 0.1679850909858942, 0.10359477078808205, 0.11220360919833183, 0.0716139157967908, 0.07726484364164726, 0.1658028138003179, 0.05123851681128144, 0.14461935763912542, 0.19615554437041283, 0.09574958961457014], [0.02189711724141879, 0.011155382031574845, 0.028588980569371154, 0.025421414557578306, 0.031546711322984526, 0.04285006318241358, 0.024575685117659823, 0.046988417727074454, 0.013704790767016155, 0.04126154145758067, 0.04496903305074998, 0.14547648307468208, 0.0345497716085187, 0.005932145835166531, 0.01282862139799233, 0.04407945328525134, 0.09798175269471747, 0.6629743107727596, 37.84883533205305, 58.19981370653425, 53.36158847808838, 45.90558426720755, 57.27787808009556, 44.259531702314106, 50.49746111461094, 54.18334150314331, 41.05924701690674, 41.78662960869925, 47.11418867111206, 45.632280349731445, 9.831715771130153, 0.07974338278706584, 0.08847245081726994, 0.0607359070064766, 0.05112527610201921, 0.14253645869238035, 0.15521772179220403, 0.5016404507415635, 0.3001769711928708, 4.453390564237322, 1.015658465879304, 0.6378934851714543, 40.036284582955496, 74.24207169669015, 67.48551137106759, 76.42078358786446, 72.74121911185128, 76.57954992566789, 83.56868730272565, 84.56375966753278, 85.62567370278495, 88.07455934797014, 88.05110917772565, 88.07579612731934, 82.37732832772392, 79.56542709895542, 84.68916770390102, 80.9478337424142, 80.89473560878209, 78.70998573303223, 77.3237714767456, 78.33359486716134, 75.29216684613908, 72.67417594364711, 72.37477111816406, 65.27874265398297, 66.98028005872453, 70.27331624712262, 68.02656064714704, 64.85894639151437, 71.73252827780587, 75.82204341888428, 74.9330700465611, 73.03146621159145, 75.01565633501325, 74.68394238608224, 73.42927142551967, 71.90289115905762, 66.80580384390694, 68.95271383013043, 71.94631740025112, 71.71327481951032, 64.70797593252999, 78.83676256452287, 66.36501707349504, 64.38928985595703, 64.57181208474296, 57.73740414210728, 55.60240684236799, 27.04001784324646, 60.42920575823103, 70.81633186340332, 68.82986273084367, 65.6810850415911, 59.779854910714285, 62.96326242174421, 63.040776525224956, 68.24397672925676, 71.52897385188511, 72.49620478493827, 73.55571474347795, 72.85862977164132, 70.75144263676235, 71.23663534436906, 69.77393531799316, 67.51273441314697, 64.73311451503209, 64.27755587441581, 62.23490360804966, 57.69644798551287, 61.558684076581685, 61.228040150233674, 63.47367014203753, 67.1803673335484, 67.83747931889125, 66.29711927686418, 64.66313225882394, 69.02447482517788, 70.58351857321603, 69.16209779466901, 69.25953933170864, 67.13735798427037, 70.54900687081474, 74.3888245991298, 77.80092511858258, 74.47633021218437, 69.45222677503313, 70.23325988224575, 68.38989584786552, 68.50577095576695, 55.29125608716692, 11.46192557471139, 5.531044440610068, 9.632872223854065, 3.7085258705275397, 0.20597326755523682, 1.4116895007235664, 1.555687116725104, 0.03945680794173053, 0.23964201233216695, 0.6840785954679761, 0.21355528570711613, 0.18389286952359335, 0.06123951569731746, 6.866175975118365, 49.51514911651611, 67.77374349321637, 61.804893493652344, 49.92339052472796, 40.32531227384295, 53.80345916748047, 46.25240707397461, 34.704719884055, 35.57504776545933, 39.81625945227486, 38.4050282069615, 57.5681460244315, 52.954743657793315, 51.84070423671177, 5.124417620045798, 0.07501465867140464, 0.01064464363402554, 0.05587164552084037, 0.032355793086545806, 0.08291007179234709, 0.052336522178458314, 0.047493861855140755, 0.014754862724138158, 0.058453905529209545, 0.04496372690690415, 0.016740581885512387, 0.0061891083189818475, 0.022802045469039252, 0.03288253303617239, 0.043421589835946045, 0.01246690540574491, 0.02276698386828814, 0.06397977258477892, 0.06956117773162467, 0.028293266526556442, 0.02585684065707028, 0.039742427079805305, 0.05202630275328245, 0.03426721944872822, 0.038023463782987425, 0.005683107792200255, 0.020862032426521182, 0.008780612942895718, 0.033650095241942575, 0.020904081241626824, 0.06435702448444706, 0.01913884694554976, 0.015642936141895394, 1.0962797169174467, 52.88768311909267, 67.90890680040631, 62.7229311806815, 58.28943852015904, 67.28429848807198, 50.58629035949707, 31.56185163770403, 40.32801512309483, 38.42974989754813, 45.87443896702358, 55.85085357938494, 54.08332218442644, 8.798161676951818, 0.1644191723316908, 0.10319772602191993, 0.045628993173262904, 0.013504907073053931, 0.21502302480595453, 0.061535906578813276, 0.8473245671817234, 0.27060473231332643, 1.0888937818152564, 0.6626647359558514, 2.231389875922884, 57.55110556738717, 78.02176666259766, 75.08750070844377, 80.71460356031145, 78.87447043827602, 81.32366875239781, 90.13455431801933, 88.86287416730607, 91.0165239061628, 93.07392024993896, 90.09336539677211, 90.61822537013462, 85.06327956063407, 84.36948803492955, 88.0624486378261, 83.4397634778704, 83.67542552947998, 80.9621331351144, 81.26044709341866, 81.1326766695295, 78.41051837376186, 75.75149141039167, 78.04951776776994, 69.51697703770229, 71.35132231031145, 73.33344881875175, 72.26318304879325, 70.70679351261684, 73.68538202558244, 76.97630596160889, 76.68785844530377, 75.80044841766357, 76.3220774786813, 75.62463814871651, 76.95551000322614, 76.0546760559082, 69.10435131617955, 71.20400660378593, 74.16971315656389, 72.67062541416713, 67.18725994655064, 81.14938013894218, 67.86366707938058, 64.87289837428501, 65.75347137451172, 56.127742767333984, 58.343391282217844, 31.141944204057964, 60.479503767830984, 71.92748083387102, 70.32585852486747, 66.57806968688965, 61.715282576424734, 66.5590455191476, 64.11981092180524, 69.62265219007219, 74.14135060991559, 73.03234168461391, 74.5529271534511, 73.83205849783761, 73.82319954463414, 72.3157878603254, 71.22084208897182, 70.45846489497593, 66.70450605664934, 66.82042980194092, 66.53197533743722, 63.15756184714181, 67.0611570903233, 64.47198731558663, 65.84579903738839, 71.71935449327741, 71.66982773372105, 69.47684424264091, 67.90424455915178, 69.7924314226423, 72.34927817753383, 70.69858769008091, 71.0940305164882, 68.64852169581822, 71.10892050606864, 73.62538433074951, 79.33319050925118, 75.91135556357247, 74.23835441044399, 71.56389549800328, 72.92295619419643, 72.88674913133893, 77.77990681784493, 52.07167625427246, 31.405478954315186, 16.93291108948844, 6.026460119656154, 0.5326343019093785, 1.2341599868876594, 0.47120392109666553, 0.3285139506416661, 1.5859328423227583, 0.48693589121103287, 0.21462405978568963, 0.14459890659366334, 0.08900164027831384, 5.008369241441999, 49.85047265461513, 76.84231689998082, 71.7087515422276, 56.535226821899414, 42.024716581617085, 29.8333899634225, 27.212430443082535, 44.4888048853193, 53.096396582467214, 55.24099629265921, 51.40884937558855, 75.58679131099156, 57.88143335069929, 68.51021085466657, 9.72469961643219, 0.13494382825280937, 0.04687891235308988, 0.08614312830780234, 0.04363018846405404, 0.020890157703044157, 0.02491488477348217, 0.09768851700105838, 0.03990492943142142, 0.07110778295568057, 0.06770903497402157, 0.04346079558932355, 0.028740324412605593, 0.014068187829772276, 0.02201033420195537, 0.04780597439301865, 0.009173549179519926, 0.1558898650109768, 0.17182620987296104, 0.14433950265603407, 0.11632038972207479, 0.09566197717296225, 0.14174245058425836, 0.25869527565581457, 0.11114674340933561, 0.12714056697274956, 0.10194112666483436, 0.08188931763704334, 0.13819227394248756, 0.09583681529121739, 0.1016543981220041, 0.13869634403714112, 0.10710827939744506, 0.13368821277150086, 1.848839432001114, 71.03821563720703, 84.8097814832415, 78.2409336907523, 67.10259614671979, 77.37750884464809, 65.99550492422921, 80.54888207571847, 79.51993724278041, 58.909697260175435, 61.84529032026018, 66.42802333831787, 68.85737064906529, 16.04701750619071, 0.27476569903748377, 0.2540694038782801, 0.2757131781961237, 0.14934942525412354, 0.3345273451081344, 0.21226228294628008, 3.5997353196144104, 4.0112858074052, 12.875395877020699, 4.924028967108045, 1.5565521674496787, 62.640066964285715, 85.24152169908795, 81.21116352081299, 88.75345393589565, 85.29204899924142, 87.69855758122036, 90.64901978628976, 93.87513092585972, 94.51253087180001, 94.32736832754952, 93.14078276497978, 93.18788460322789, 88.15394251687187, 85.68974304199219, 92.40155002049038, 88.20130143846784, 89.12576620919364, 85.37005642482212, 84.73255225590297, 83.04473754337856, 80.40749318259103, 80.55735192980084, 82.36731597355434, 72.5923261642456, 74.9977091380528, 77.223390851702, 74.12233339037213, 73.35149329049247, 75.97914913722447, 82.64538288116455, 80.61731488364083, 79.56704602922711, 80.65482125963483, 77.93408734457833, 79.73775632040841, 76.6108237675258, 69.49012225014823, 72.42824445452008, 77.19776589529855, 76.66660390581403, 71.03240694318498, 83.4263048171997, 68.63420145852226, 65.81629698617118, 64.441422189985, 57.272058963775635, 54.96327332087925, 32.2700572013855, 63.669706617082866, 73.4886646270752, 74.02693462371826, 67.86238166264125, 61.956656047276084, 67.30048779078892, 66.7107594353812, 70.59815842764718, 76.47099821908134, 77.02505452292306, 78.32130350385393, 77.37053980146135, 76.50924110412598, 77.76546151297433, 73.1048947743007, 74.22874505179269, 70.96282073429653, 72.03237778799874, 67.44618456704276, 65.33987290518624, 68.1081394468035, 66.75306006840297, 69.8568342753819, 76.43001079559326, 74.61646842956543, 72.36910833631242, 70.55150822230748, 72.60977309090751, 74.62463256290981, 72.20408167157854, 75.29671096801758, 71.38004616328648, 72.18850381033761, 76.23591981615338, 83.94854531969342, 79.1355698449271, 75.08046913146973, 75.1493535723005, 74.96290561131069, 72.61221885681152, 66.91568960462297, 46.68373734610421, 33.56724418912615, 20.538850716182164, 6.643929157938276, 0.9315510647637504, 4.624541631766728, 2.9565438330173492, 0.1535213163920811, 0.9659893768174308, 2.7772084389414107, 0.7566141518098968, 0.32275402971676415, 0.17417467385530472, 10.553619708333697, 61.43634714399065, 85.94762543269566, 83.32967621939522, 69.44377081734794, 58.04414973940168, 79.65458638327462, 68.89585672106061, 51.71108559199742, 50.19271312441145, 61.209585734776084, 52.76781974520002, 79.59522792271206, 68.82227529798234, 81.42518888201032, 11.55210016454969, 0.2768071937773909, 0.11302127782255411, 0.1733698770403862, 0.21572465715663774, 0.22030989825725555, 0.16293058863707952, 0.24145435222557612, 0.31512992882302826, 0.1697028295270034, 0.1442733183503151, 0.1344453492867095, 0.09660495085907833, 0.12623289067830357, 0.10964328622711556, 0.11078730305390698, 0.05444546329921909], [0.004963445493818394, 0.004794988997413644, 0.006536159049054342, 0.036037015196468146, 0.023829535780740634, 0.0625349408281701, 0.016491861481751715, 0.008931894021640931, 0.04734323386635099, 0.03777533709736807, 0.07349883858114481, 0.0341172224975058, 0.024073984806558917, 0.0760330922369446, 0.01708038374116378, 0.07382686276521001, 0.04110270658774035, 0.8876646139792034, 30.18395437513079, 51.90704911095755, 49.85792459760393, 55.74044322967529, 54.03709234510149, 43.11173793247768, 33.7225399017334, 43.06165879113333, 50.41670567648751, 49.58860547201974, 69.06750501905168, 26.502298491341726, 0.4565967991948128, 0.035463551325457435, 0.09888944255986384, 0.030037364456802607, 0.14703351738197462, 0.030086341114448648, 0.3845651229577405, 0.46116599972758976, 0.054629889117287736, 0.6574387678078243, 0.28450305653469904, 19.168883085250854, 66.72486427852085, 62.982397760663716, 73.26483535766602, 74.22437463487897, 76.39011423928397, 86.09182139805385, 90.10246058872768, 81.65060234069824, 86.96746117728097, 84.81133093152727, 82.99936580657959, 81.30238642011369, 80.16646017347063, 82.2394552230835, 81.35832636696952, 80.22987638201032, 81.57809094020298, 77.58353682926723, 74.95487349373954, 76.7206678390503, 76.20782824925014, 73.5721263885498, 67.46515314919608, 63.20413562229702, 66.26711695534843, 63.902033533368794, 67.07559544699532, 68.43231460026333, 68.48928982870919, 66.78313187190464, 69.86071831839425, 69.16216032845634, 69.69800540379116, 69.36976555415562, 73.7135500226702, 73.22470951080322, 72.273820740836, 70.31262220655168, 71.67673424312046, 69.46499061584473, 67.49144513266427, 71.14687851497105, 68.76400770459855, 60.24406405857631, 59.714006832667756, 54.087501525878906, 63.72506291525704, 51.10885395322527, 64.34801755632672, 73.98445333753313, 69.10350363595145, 65.6825441632952, 59.17343003409249, 63.79233537401472, 60.407680238996235, 67.46155398232597, 69.92333548409599, 72.04733725956508, 68.18859263828823, 66.04858916146415, 65.74991389683315, 65.1709760938372, 62.41958672659737, 62.0803131375994, 63.83027253832136, 60.96899741036551, 64.20421763828823, 61.78536210741316, 61.472922461373464, 62.128908838544575, 64.61948367527553, 65.20026275089809, 65.27820069449288, 65.35870947156633, 63.796233313424246, 65.61025510515485, 67.53757422310966, 70.26272719247001, 65.0715890611921, 65.35629149845668, 68.63325650351388, 70.91498238699776, 72.6909488950457, 74.14755535125732, 71.41205651419503, 67.23329871041435, 69.03601578303746, 72.57883971078056, 64.29627432141984, 44.517445359911235, 12.295219557625906, 2.9799629534993852, 8.252366781234741, 2.78497457078525, 1.1329066029616763, 3.4159441760608127, 1.2640974947384425, 0.3499332384339401, 0.46353848384959356, 0.5366490579077176, 0.12042989635041781, 0.21892107278108597, 0.09822023739772183, 6.303288076605115, 44.88681159700666, 63.47329493931362, 63.262701988220215, 46.24451739447457, 38.93851784297398, 31.66315984725952, 28.130046027047293, 28.529668194907053, 28.086418288094656, 43.03231654848371, 39.96361337389265, 65.54740864889962, 52.934882232121055, 63.07570511954171, 4.4361989838736395, 0.14770728908479214, 0.06322824755417449, 0.017562722055507556, 0.02963627901460443, 0.024179103451647928, 0.07181979689214911, 0.07372493323470865, 0.0379464670217463, 0.042473041984651766, 0.019200931203418543, 0.034259735207472525, 0.02869285410270095, 0.02018634895128863, 0.038235156530780454, 0.01527894112015409, 0.023375952084149634, 0.01034797285683453, 0.036091793328523636, 0.0240844088007829, 0.02593275176228157, 0.01896402070165745, 0.03421819190095578, 0.022213535083990012, 0.0476572463022811, 0.03524020813139422, 0.04909587285614439, 0.07679540597434555, 0.035703779863459725, 0.05036501493304968, 0.04145378399906414, 0.08427744199122701, 0.07685219257005624, 1.1593985642705644, 40.597275188991, 66.43711853027344, 57.709764208112446, 60.30030972617013, 57.24266113553728, 42.30611515045166, 29.89989812033517, 46.839898109436035, 58.86679213387625, 58.379612241472515, 77.14262499128068, 26.77322265080043, 0.6868464212332452, 0.020266031014866064, 0.19463306106626987, 0.03471168363466859, 0.5826252337012972, 0.05767261316733701, 0.046586300911647935, 0.35369595938495224, 0.517778890473502, 0.45314902705805643, 0.6394620410033635, 33.066028935568674, 75.14264161246163, 69.10379546029228, 79.8499002456665, 79.15749141148159, 81.00496877942766, 91.49263531821114, 90.66047041756767, 86.55528014046806, 90.62437452588762, 87.15383965628487, 85.12149851662772, 84.95135102953229, 83.69198308672223, 85.08668109348842, 85.98246370043073, 83.27856527056012, 84.18795939854213, 81.15133953094482, 78.57714312417167, 81.41541971479143, 78.03805324009487, 76.01310498373849, 70.68307931082589, 69.19804777417863, 70.29492514474052, 68.95696612766811, 70.48236669812883, 73.10170555114746, 72.81285503932408, 69.6603809084211, 73.52680328914097, 74.3266521181379, 75.23223863329206, 74.2465741293771, 77.39367035457066, 76.51769011361259, 74.38668455396379, 69.06753281184605, 73.40860748291016, 72.45512703486851, 72.11955683571952, 73.73869555337089, 68.52084854670933, 61.97445733206612, 58.24951764515468, 55.564584323338096, 61.773209708077566, 59.392006465366904, 68.07394736153739, 74.66059643881661, 71.2682774407523, 65.91451672145298, 62.087678228105815, 65.79236044202531, 62.18288244519915, 71.3981740134103, 71.51964242117745, 72.82017844063895, 71.09380122593471, 69.66789885929653, 66.4810380935669, 67.78873075757707, 64.19540037427629, 65.12469414302281, 66.16980048588344, 64.39070728846959, 65.84741796766008, 64.2709481375558, 62.19550037384033, 67.23140185219901, 67.46176937648228, 68.89090265546525, 66.50719111306327, 66.45667770930699, 66.8121475492205, 68.95703560965401, 70.70871121542794, 72.20056588309151, 67.06810528891427, 71.26460879189628, 69.23766640254429, 72.90190315246582, 71.9387925011771, 76.25162969316754, 73.27146393912179, 71.712447983878, 71.11477783748082, 71.86598927634103, 70.81855528695243, 72.30047403063092, 52.28925214494978, 25.318837881088257, 12.423319152423314, 4.187369661671775, 1.0940836519002914, 0.6287325024604797, 1.5852368282420295, 0.9847940249102456, 0.3360662896718298, 0.3169795067182609, 0.085215537010559, 0.057426691720528264, 0.04793901475412505, 4.352397194930485, 48.55888591493879, 72.0757623400007, 70.92414011274064, 51.66182286398751, 40.47075891494751, 17.427532502583094, 18.04252450806754, 33.80525820595877, 40.749593598502024, 53.428120953696116, 50.00794315338135, 81.93245601654053, 59.60877636500767, 80.72576236724854, 6.999627419880458, 0.13505362878952706, 0.13753845116921834, 0.12241835679326739, 0.02620743800486837, 0.012706217073303248, 0.07884187437593937, 0.04384655971080065, 0.008614924869367054, 0.02712913622547473, 0.03632341464981437, 0.009661643167159386, 0.07534965819546155, 0.029675742611289024, 0.02795882340121482, 0.014871396024578383, 0.07819936956678118, 0.0716519680406366, 0.13495776536209242, 0.17545166318970068, 0.16052447631955147, 0.11791424133947917, 0.11560381603028093, 0.15636569447815418, 0.22517645997660501, 0.13600686192512512, 0.09277255793235131, 0.23198143339582852, 0.27350023122770445, 0.2377177413020815, 0.15442610212734767, 0.22693174864564622, 0.19624413390244755, 1.9714221571172987, 61.3731324332101, 81.96917724609375, 76.215304510934, 75.75970418112618, 76.31847831181118, 61.1157294682094, 47.909069538116455, 62.68747452327183, 72.69392272404262, 69.65906075068882, 89.6275998524257, 39.817360741751536, 1.4946293873446328, 0.13441324100962707, 0.27045632313404766, 0.08945738510893923, 0.4094770476222038, 0.16364447533019952, 1.2282154772962843, 2.058409477983202, 1.5328314517225539, 1.3914616661412376, 1.0181013005120414, 35.97534738268171, 87.7177346093314, 76.35961859566825, 86.28605134146554, 83.69546413421631, 85.36764539991105, 94.92016083853585, 98.74533871241978, 88.2519051688058, 94.7462682723999, 89.34010423932756, 88.22197232927594, 87.7904475075858, 85.51931762695312, 89.7470463344029, 90.9499740600586, 87.22924150739397, 86.58619267599923, 85.67811870574951, 81.45934622628349, 83.97310720171247, 81.8250299181257, 79.95379665919712, 74.45664596557617, 70.8772189276559, 73.08487006596157, 72.22475951058524, 73.42215647016252, 76.11118575504848, 75.80244255065918, 71.56727232251848, 75.36358737945557, 75.00056484767369, 76.49863815307617, 77.41837814876011, 80.2643324988229, 82.00086797986711, 79.79769842965263, 73.613009589059, 75.91259929112026, 75.5710119519915, 75.9905789239066, 76.46658611297607, 70.00344126565116, 63.8506863457816, 59.347989627293174, 55.84589951378958, 64.09250450134277, 65.69762870243618, 73.57871328081403, 76.15578624180385, 75.46665695735386, 67.78382532937187, 62.14135306222098, 68.20235007149833, 63.58022076742989, 72.97498430524553, 74.69215515681675, 76.91748251233781, 73.63219356536865, 73.16009821210588, 71.57659680502755, 70.63266318184989, 68.35409872872489, 69.65277263096401, 72.22710800170898, 67.54111780439104, 72.06885583060128, 66.8338954108102, 69.97909477778843, 69.73373304094586, 71.31455939156669, 70.72576209477016, 71.02703598567417, 70.01160539899553, 69.70671149662563, 70.68389919825962, 75.35788985661098, 74.84903853280204, 70.43837765284947, 70.8332576751709, 72.90903895241874, 74.84275041307721, 73.53371674673897, 77.56322724478585, 76.77836568014962, 69.90158762250627, 73.2351804460798, 72.10612596784318, 70.27429594312395, 60.79738385336739, 48.5629506111145, 27.84714491026742, 16.294769423348562, 4.3515060884611945, 2.6241734964506964, 8.543749042919703, 2.5148637848240987, 1.0921324023178645, 2.304115584918431, 1.1308205149003436, 0.3608819166464465, 0.3492039761372975, 0.24598075076937675, 8.89152114731925, 60.708426066807334, 81.08036368233817, 80.46549674442836, 64.07001318250383, 60.466969217572895, 44.01260314668928, 44.53010845184326, 41.043870653424946, 40.4995105607169, 56.20610455104283, 55.263800280434744, 86.65348597935268, 70.55662904466901, 92.02694484165737, 7.676674655505589, 0.33129605278372765, 0.23198642741356576, 0.16236458186592373, 0.13329720018165453, 0.11277311721018382, 0.19736892783216067, 0.181196534207889, 0.09279958398214408, 0.10350078690264906, 0.09192079292344195, 0.09685710804270846, 0.1620278927896704, 0.15103253136788095, 0.09916584379971027, 0.08794027580214397], [0.06132822736565556, 0.058329312929085324, 0.040079163653509955, 0.05665755192083972, 0.057085368250097544, 0.037751975136676004, 0.044053923405174694, 0.07249512244015932, 0.03360381915367075, 0.019154592350657498, 0.025486514903604984, 0.019268604893503443, 0.0685980176287038, 0.006307787910502936, 0.020920445809939077, 0.055330188146659305, 0.1075241874371256, 0.6023930215409824, 26.070492267608643, 47.049886567252024, 52.70641156605312, 43.03491517475673, 51.98711667742048, 48.74276304244995, 27.820086887904576, 38.65728950500488, 45.88013301576887, 76.76191929408482, 51.75225019454956, 2.0948768811566487, 0.16661359529410089, 0.05122247963611569, 0.15065586300832884, 0.041668333379285674, 0.11559393656040941, 0.16586183277623995, 0.10104938237262623, 0.20908371279282228, 0.09718931200248854, 0.3753960249679429, 7.857543213026864, 54.07789216722761, 60.23503140040806, 65.75324208395821, 67.74491541726249, 74.80641828264508, 80.1558016368321, 88.91638224465507, 82.63340418679374, 89.29275921412876, 83.32871736798967, 83.22919137137276, 81.80098220280239, 81.69532094682965, 78.4124847139631, 79.23032242911202, 81.3648020880563, 83.50666073390416, 78.79168960026333, 76.88577788216728, 74.91357340131486, 74.47595500946045, 70.6229704448155, 66.51864869253976, 65.75299194880894, 66.60327775137765, 65.37604522705078, 64.40282494681222, 65.55947072165353, 68.05695901598249, 68.90905135018485, 67.53218936920166, 71.77411324637276, 73.07263428824288, 73.77399935041154, 71.86398819514683, 71.45785209110805, 71.37185423714774, 67.47933442252022, 61.02486787523542, 68.19385242462158, 69.85474981580461, 68.26522432054792, 70.21293640136719, 64.37950679234096, 62.021649496895925, 55.89562429700579, 60.680258069719585, 56.455690792628694, 50.62714924131121, 59.869319915771484, 69.2835384096418, 66.52201162065778, 60.75454820905413, 63.1204445702689, 60.15697533743722, 64.87985352107457, 67.98998532976422, 67.43164198739188, 68.96947288513184, 66.05015250614711, 65.59697014944894, 65.84344359806606, 64.85917568206787, 64.78535107203892, 64.79471724373954, 62.50557763235909, 60.955385889325825, 58.964671407427105, 55.84249837057931, 53.76306234087263, 56.58698395320347, 62.010372570582796, 66.64515454428536, 68.19062846047538, 64.74711513519287, 65.56983048575265, 66.0925156729562, 65.08297021048409, 64.75984423501151, 66.89041205814907, 65.23524693080357, 65.03626441955566, 69.26698780059814, 72.21904114314488, 71.58380903516496, 71.47000449044364, 66.2506844656808, 69.317202431815, 65.96482862745012, 63.894091742379324, 59.839505195617676, 39.18170479365757, 6.455580430371421, 5.9795845321246555, 7.712127838815961, 2.232020207813808, 0.4103833261345114, 4.251610534531729, 4.342147299221583, 0.15295768449349062, 0.35503207626087324, 0.025216642866975496, 0.10584981406905822, 0.11969355014818055, 0.232472584183727, 3.7711043868746077, 42.941093649183, 64.66525840759277, 56.2921267236982, 39.147509234292166, 47.45928137642996, 51.171637875693186, 46.11693457194737, 31.83642360142299, 32.85119758333479, 32.84440571921212, 30.762537819998606, 50.38383722305298, 53.47554588317871, 39.56450537272862, 0.7274907231330872, 0.021771304974598542, 0.06889830330120665, 0.033185346251619716, 0.11842766164668969, 0.054023370412843566, 0.06682059514735426, 0.01569701199020658, 0.013551153475418687, 0.02600102256318288, 0.05814137908497027, 0.050372244723673375, 0.051072764276926, 0.06429781551871981, 0.008004033006727695, 0.04488221788778901, 0.06113318247454507, 0.009780655664924, 0.007583831536716649, 0.02957260189577937, 0.04579566512256861, 0.02518508759593325, 0.05101571983790823, 0.008158167325226324, 0.04033234542501824, 0.04493399689506207, 0.008173823672612863, 0.029739901489977325, 0.017109224872131432, 0.03703195448698742, 0.11669561958738736, 0.09675770944782666, 1.071180977991649, 41.391610622406006, 59.5639465876988, 71.16385296412876, 50.9859333719526, 53.49213470731463, 42.933933530535015, 30.683342252458843, 47.09943764550345, 55.22416080747332, 87.73934350694928, 53.159837109701975, 2.0834023654460907, 0.1128234780792679, 0.0314546510843294, 0.12436976922409874, 0.01973314014529543, 0.16509211622178555, 0.359108388956104, 0.11798970800425325, 0.019328692562079856, 0.13862408005765506, 0.7443993272525924, 15.85512910570417, 69.60579586029053, 69.34661415645054, 75.91697665623256, 73.96863228934151, 81.6441752570016, 82.43250397273472, 90.76862607683454, 85.41075202396938, 92.32579381125313, 85.77772113255092, 85.64496190207345, 84.61913681030273, 83.48797702789307, 81.83024106706891, 84.49794633047921, 85.41371890476772, 84.82502583095005, 80.81698526654924, 79.92072323390416, 78.87820162091936, 75.63961151668003, 70.92476545061383, 69.20056302206856, 71.19916370936802, 72.1537697655814, 70.6496445792062, 68.91491562979562, 67.9930772781372, 71.64908736092704, 72.68941334315709, 72.95152718680245, 74.39039489201137, 74.09301199231828, 76.45498956952775, 75.79639761788505, 74.52404349190849, 74.86500549316406, 73.40233325958252, 64.75761386326381, 68.24503285544259, 70.41198144640241, 69.33121694837297, 70.96902547563825, 65.04028047834123, 65.80702808925084, 58.81043529510498, 60.84387425013951, 61.651963642665315, 60.811676297869, 62.82948180607387, 72.2489322934832, 69.86800697871617, 62.769379888262065, 61.650414194379536, 62.20918137686593, 69.08979484013149, 71.43163653782436, 68.21100057874406, 71.03596442086356, 68.85623809269497, 68.5324034009661, 69.26390974862235, 68.5392404283796, 67.9246792112078, 66.20980821337018, 65.5883126940046, 64.67852251870292, 62.88724218096052, 60.116703578404014, 58.33556761060442, 58.003992625645225, 64.20357145581926, 68.45642484937395, 69.69913796016148, 69.4230512891497, 69.51478140694755, 66.42435468946184, 68.73149708339146, 67.61681842803955, 69.28026580810547, 67.38010719844273, 69.41357394627163, 71.0116457257952, 71.93250438145229, 70.84780025482178, 72.41632829393659, 69.49187319619315, 70.64424582890102, 69.4182778767177, 68.81551470075334, 71.34735488891602, 70.91520472935268, 38.301642486027305, 15.948980161121913, 11.061336738722664, 3.4519284623009816, 0.49413748191935675, 3.305392039673669, 3.5984459945133755, 0.3399288366947855, 0.17652942107192107, 0.030874887015670538, 0.15426026816879, 0.037853236310184, 0.04827040107920766, 3.0186040571757724, 52.03758839198521, 73.12091732025146, 65.1270078931536, 45.79845346723284, 43.151839460645405, 23.629584891455515, 29.968768664768763, 41.99832384926932, 44.14371912819998, 41.64525808606829, 46.99446078709194, 64.83111885615757, 60.197045598711284, 52.654192379542756, 0.821449584194592, 0.06563391882394042, 0.05631883063220552, 0.04220058303326368, 0.03314436273649335, 0.0514099317203675, 0.04315118684566446, 0.07745515235832759, 0.07709320142332997, 0.016120709611901214, 0.04455402746264424, 0.01088519617249923, 0.08318877326590673, 0.03507562267727085, 0.035483978622193844, 0.14943728196833814, 0.1343833447567054, 0.21664738335779735, 0.08138533575194222, 0.15384223631450109, 0.12925406784883567, 0.12892372986035688, 0.21689411226127828, 0.11294255418969051, 0.1971818014447178, 0.1890071372368506, 0.14749311629150594, 0.1604928294462817, 0.07800275047442742, 0.12112793246550219, 0.1943586750754288, 0.2894842635307993, 1.634502921785627, 59.548368726457866, 74.04705660683769, 84.09303310939244, 73.69242749895368, 70.61573737008231, 71.14600999014718, 41.72995662689209, 62.02754156930106, 68.3642361504691, 95.4546093259539, 69.14645739964077, 4.9219953162329535, 0.30287659061806543, 0.1666972315204995, 0.2558477898793561, 0.17745178086417063, 0.3151598386466503, 0.7617353541510445, 0.288848340511322, 0.3538377732038498, 0.5214569302541869, 1.5055275282689502, 15.46469419343131, 84.70582253592355, 71.4626532963344, 82.05892017909459, 80.54916000366211, 84.6567474092756, 86.70455523899624, 92.2534213747297, 90.45988982064384, 94.99497209276471, 88.45094326564244, 89.63848073141915, 88.1755792072841, 88.68084526062012, 85.91683796473912, 86.07751505715507, 88.08060428074428, 89.16409247262138, 83.61289174216134, 84.21168749673026, 82.38231713431222, 80.34202030726841, 77.20965426308769, 73.19188622065953, 74.1933022907802, 76.00104985918317, 73.83517129080636, 70.39476381029401, 70.37063271658761, 74.61265386853898, 75.4979863848005, 75.59916605268205, 77.36831637791225, 78.75558676038469, 80.06114632742745, 77.4881728036063, 76.8785378592355, 78.28018406459263, 73.53714220864433, 66.20408289773124, 70.49538762228829, 72.79697145734514, 72.41612679617745, 71.15894753592355, 65.70878750937325, 67.61605412619454, 62.98384993416922, 58.65028626578194, 61.44903455461775, 62.36664145333426, 68.78897953033447, 73.73853574480329, 72.63033281053815, 62.34326771327427, 65.43527167184013, 64.33835261208671, 68.25091103145054, 73.31553636278424, 72.62190464564732, 74.22664669581822, 70.4601741518293, 71.30951499938965, 73.79082093920026, 71.73239626203264, 69.8177923474993, 71.23733711242676, 70.0160800388881, 68.04145758492606, 67.11410931178501, 63.39480808803013, 61.81104959760393, 61.96721730913435, 69.5852222442627, 72.66131482805524, 73.08490480695451, 72.00979614257812, 72.0962039402553, 70.24340425218854, 72.58156340462821, 69.5990491594587, 71.39422048841203, 70.03246389116559, 71.0522996357509, 72.84601879119873, 74.29036167689732, 72.4734285899571, 74.82765892573765, 71.79961313520158, 73.61398233686174, 70.42794145856584, 68.49498735155377, 66.18166106087821, 60.70590387071882, 36.19847140993391, 21.067530461720057, 12.021141784531729, 4.860705256462097, 1.675344541668892, 10.167206934520177, 11.346815637179784, 0.48180003251348225, 0.7500787196414811, 0.1828575065093381, 0.6501121095248631, 0.19087040796875954, 0.34966676416141645, 6.696413678782327, 64.94899504525321, 83.33897985730852, 75.25067220415387, 55.5620482308524, 65.69290392739433, 73.90663351331438, 71.0857413155692, 48.0884233883449, 48.1526768548148, 48.82161120006016, 47.0455230985369, 69.90614564078194, 72.87589604513985, 61.134058816092356, 0.7824906547154699, 0.13918716912823065, 0.19992870119001183, 0.11399715367172446, 0.30727789444582804, 0.16629674658179283, 0.2152793753359999, 0.16854670085012913, 0.13725464711231844, 0.10277645755559206, 0.16588475368916988, 0.16226250305771828, 0.22725976604436124, 0.09964134757007871, 0.11602586481188025], [0.013628205367630082, 0.03281383475820933, 0.04426013359001704, 0.06232078160558428, 0.013862310975257839, 0.02974292097081031, 0.04069807919274483, 0.03678906948438712, 0.004217659173134182, 0.021757301708151187, 0.02347107251573886, 0.014390251931867428, 0.020233904078070606, 0.016940829443878362, 0.045607721100428274, 0.09223215228744916, 0.019679054118958966, 0.8213744025145258, 32.13441446849278, 51.7402332850865, 53.57090990883963, 50.279989446912495, 44.977555070604595, 38.77383163997105, 35.141285623822895, 48.822754178728374, 57.963887623378206, 53.32828228814261, 8.764210173061915, 0.25603653118014336, 0.07387964600431067, 0.04897210467606783, 0.06799545817609344, 0.059409432113170624, 0.14899232584450925, 0.2077994631337268, 0.05470140670825328, 0.16190182098320552, 0.045477520408374925, 1.5513556748628616, 33.8152288709368, 61.12335164206368, 63.16841493334089, 70.92698192596436, 73.26498821803501, 82.31674698420933, 86.31881904602051, 84.91778428213937, 86.3823881149292, 87.14209720066616, 79.45318589891706, 81.28003406524658, 76.80539417266846, 80.6675364630563, 80.709107535226, 81.4067692075457, 78.61022349766323, 78.72051920209611, 77.9937515258789, 74.8479129246303, 72.31948430197579, 66.10124955858502, 68.05077511923653, 69.26805782318115, 70.29877444675991, 65.28284903935024, 64.81581197466168, 68.98746871948242, 65.88569559369768, 68.85762773241315, 67.89267580849784, 65.48574338640485, 66.96507045200893, 67.44312735966274, 71.4913910457066, 68.39183439527238, 71.4185322352818, 74.18376241411481, 71.67164121355329, 70.24156992776054, 67.69420746394566, 65.25280502864292, 64.577315058027, 64.24539961133684, 66.53458786010742, 61.79352624075753, 58.68628488268171, 68.78416442871094, 70.95948559897286, 69.27067034585136, 59.87794263022286, 65.74060331072126, 67.5758865901402, 60.203931263514924, 60.625944001334055, 63.70093876974923, 67.82465989249093, 67.3721376146589, 65.18212795257568, 65.85861846378872, 63.3437944139753, 62.43483107430594, 62.28036567143032, 63.05477714538574, 61.11137989589146, 61.338266372680664, 59.52470316205706, 59.158762386866975, 61.00923442840576, 63.07170990535191, 60.25494493756975, 57.21527133669172, 56.69235338483538, 59.23055117470877, 62.56755556379046, 66.83607019696916, 66.61301912580217, 65.15849018096924, 63.86641011919294, 63.416847773960654, 65.06641265324184, 69.0432071685791, 64.38644804273332, 65.06789261954171, 69.29236957005092, 71.82270199911935, 70.68387835366386, 68.66519042423793, 65.2598991394043, 69.46527549198696, 67.08411393846784, 65.41110583714077, 54.29372753415789, 23.748847246170044, 3.63305801153183, 7.265401661396027, 6.830160856246948, 0.16790317823844297, 1.3947164629186903, 1.3985479601791926, 0.06656995109681572, 0.14289984133626732, 0.24649035770978245, 0.08472815209201404, 0.08185034937092237, 0.08172563463449478, 0.07355348779154675, 3.4581288610185896, 41.859231335776194, 66.8811570576259, 70.55628858293805, 46.25281701769148, 38.42683512823922, 31.17047003337315, 24.519991329738072, 31.922584738050187, 41.333572319575715, 45.029350417000906, 43.717089312417166, 51.836754185812815, 58.419119698660715, 16.09364860398429, 0.3245249518326351, 0.05438819833632026, 0.02751227272009211, 0.05922820219503982, 0.06948550072099481, 0.0388417363033763, 0.03374298329332045, 0.023326680263770477, 0.024644396966323256, 0.022919165702270608, 0.009441847863074924, 0.006978402305061796, 0.0428581343564604, 0.04452922361503754, 0.03666608840493219, 0.04065215255000761, 0.07134864931660038, 0.015415562449821403, 0.09119736602795975, 0.08998426755091973, 0.06878827884793282, 0.006595147914984929, 0.04193698235654405, 0.013473731781622129, 0.026723472368238226, 0.007628921885043383, 0.037081701281879625, 0.01677885465323925, 0.054383621617619476, 0.09508987715733902, 0.05460120065669928, 1.3696002449308122, 45.830905028751914, 61.78482014792306, 71.00398186274937, 67.0134368624006, 51.133964742933, 30.87969834463937, 34.259385517665315, 58.46605478014265, 69.28522682189941, 61.56142166682652, 8.039790987968445, 0.05915271517421518, 0.06963858500655208, 0.12957220577767917, 0.029970399835812192, 0.20849772995071753, 0.7301953637174198, 1.439391317112105, 0.21143375097640923, 0.5299190218959535, 0.23155506913151058, 4.744939148426056, 49.784839970724924, 73.35564831324986, 74.54770905630929, 76.42785685403007, 81.69470255715507, 87.61838926587785, 89.15581716809953, 86.41308525630406, 91.1052940913609, 87.8562400000436, 82.18689904894147, 84.62236772264752, 81.4479650769915, 82.00853184291294, 83.89926869528634, 83.47469207218715, 82.50696086883545, 82.63334165300641, 81.29774502345494, 76.28068011147636, 73.93178599221366, 69.17777293069022, 71.42992728097099, 73.31090886252267, 72.4947178704398, 69.8217111315046, 69.7504573549543, 71.86237621307373, 69.77832657950265, 71.74085916791643, 70.8875161579677, 69.32269150870187, 71.10437638419015, 71.18139021737235, 72.93046719687325, 71.81700447627476, 74.35691847120012, 73.8977745601109, 74.73488657815116, 75.21732779911586, 70.00284372057233, 67.10738345554897, 66.56392315455845, 66.12950788225446, 66.35310786111015, 67.08030632564, 65.00720010484967, 71.64921937670026, 74.54857758113316, 71.80236462184361, 60.490148408072336, 65.67146178654262, 70.9577693939209, 62.72322300502232, 62.13738564082554, 65.87398787907192, 70.2714124407087, 69.23682567051479, 68.34079987662179, 68.48499584197998, 65.12627833230155, 65.40724263872418, 65.22393526349748, 63.71122210366385, 63.78787463051932, 62.32529967171805, 62.84446212223598, 62.988449641636436, 62.69816085270473, 67.21813774108887, 64.4885309764317, 62.17408602578299, 60.6471985408238, 63.12635748726981, 63.35372338976179, 69.35434055328369, 69.32729121616909, 67.93649114881242, 65.40069048745292, 64.65552398136684, 67.63043689727783, 70.79984378814697, 67.0226571219308, 68.50968973977226, 70.90148203713554, 71.25269263131278, 71.58448995862688, 72.64623028891427, 70.87750380379813, 72.70658234187535, 70.07180459158761, 70.83378573826381, 70.57959978921073, 59.39988572256905, 29.27663775852748, 14.691522972924368, 8.335299611091614, 0.7581199567232813, 0.0778735438361764, 1.381933297429766, 0.17465058474668435, 0.055332824255206754, 0.18934347347489425, 0.02431510222543563, 0.12572706996330194, 0.09898542133825165, 0.02726502643365945, 3.363897825990404, 47.6673903465271, 74.08634866986955, 74.43220915113176, 57.60062190464565, 38.021414688655305, 21.355924129486084, 19.092529330934795, 23.129931245531353, 39.879932744162424, 52.25920813424246, 65.24464089529855, 61.77628081185477, 71.97243567875454, 22.880492653165543, 0.3338519313505718, 0.08114970768136637, 0.15286134609154292, 0.06960898730903864, 0.039039288381380696, 0.02773631310888699, 0.03340027900412679, 0.04829707768346582, 0.029738500315163816, 0.06229935346969536, 0.008364818557830793, 0.04768856408606682, 0.04901329853704997, 0.04134806485048362, 0.13730907919151442, 0.1169478174831186, 0.14597774403435843, 0.11725508528096334, 0.22513899127287523, 0.19608755516154425, 0.10158647676663739, 0.06776165536471776, 0.1654588236872639, 0.09964586661330291, 0.08655527047812939, 0.06462568363973073, 0.10525151581636497, 0.11514633415000779, 0.16596445441246033, 0.21640420997781412, 0.15911141357251576, 1.95893537572452, 64.33171708243233, 82.10281194959367, 72.09046472821916, 78.34294019426618, 72.85325881413051, 58.85005392347063, 49.98932892935616, 70.11963599068778, 82.2920947756086, 72.60288742610386, 14.89097969872611, 0.4958999902009964, 0.20257014302270754, 0.24945265161139624, 0.15579064962055, 0.2739948018320969, 1.172273250562804, 1.845739666904722, 0.37244502188903944, 1.0433355293103626, 0.2613941351217883, 3.353607326745987, 63.01788221086775, 74.13029602595738, 81.44390038081578, 83.0847452708653, 84.4583693913051, 90.33116054534912, 94.98644665309361, 91.59338419778007, 95.05825628553117, 91.8563735144479, 86.06441075461251, 87.74303300040108, 85.10589286259243, 88.0514635358538, 87.70594351632255, 86.41944285801479, 85.0378838947841, 83.06920909881592, 85.50099522726876, 80.6928209577288, 81.97271387917655, 73.09689739772251, 76.69593225206647, 77.35826928274972, 77.49592699323381, 70.80695874350411, 71.62298992701939, 73.61004270826066, 71.72065380641392, 73.8276811327253, 73.77294322422573, 73.15792342594692, 75.42200088500977, 74.27409594399589, 77.3965538569859, 75.18021052224296, 77.95760699680874, 79.83924865722656, 78.40413297925676, 76.97141442980084, 72.78483990260533, 69.1280516215733, 68.19428321293422, 68.98434897831508, 68.66220269884381, 68.26439748491559, 65.25907925197056, 74.17345128740583, 77.28033828735352, 71.22853374481201, 60.81189169202532, 67.74723611559186, 73.11938176836286, 64.40968976702008, 65.56368132999965, 68.1241272517613, 73.94049903324672, 75.5447963987078, 71.38635512760708, 72.97335147857666, 68.64067023141044, 69.27282428741455, 69.69557353428432, 67.61563028608049, 67.91308266775948, 68.34082766941616, 65.24032606397355, 67.60759122031075, 67.62309959956578, 70.66347844260079, 66.67354488372803, 65.11061014447893, 64.26059532165527, 65.54209327697754, 69.54415839059013, 74.36867482321603, 73.43114049094063, 70.29045745304653, 68.34477424621582, 69.43240356445312, 72.9464133126395, 73.7336859021868, 70.25859301430839, 71.86852536882672, 73.56259346008301, 73.68477753230503, 75.62566648210797, 74.65173053741455, 72.60617392403739, 73.1643921988351, 70.42387676239014, 71.39961229051862, 64.3814036505563, 49.016768727983745, 29.404422078813823, 20.829490389142716, 10.09555276802608, 0.7950354101402419, 2.583419054746628, 4.015295352254595, 0.1910442350698369, 0.38493660730975016, 0.4351709974663598, 0.21140507608652115, 0.4745030669229371, 0.24024902975984982, 0.35609884187579155, 5.472872819219317, 61.20784868512835, 84.4812845502581, 86.2115249633789, 64.49881431034633, 58.17375101361956, 48.970754282815115, 42.23540333339146, 47.77788060052054, 58.046963759831016, 60.029170172555105, 61.618049485342844, 69.38880361829484, 84.74038982391357, 26.325876780918666, 0.365216886890786, 0.18912632869822638, 0.2884466749216829, 0.178812799975276, 0.09781856502273253, 0.16121838694172247, 0.17794833279081754, 0.08635124856872217, 0.09157085884362459, 0.11693715091262545, 0.08183156752160617, 0.100052370157625, 0.18944922994290078, 0.1344309914857149], [0.0620859202795795, 0.01570277614519, 0.02651373210496136, 0.02183687181345054, 0.054500821578715525, 0.0299962011298963, 0.020621712286291376, 0.02554430573114327, 0.02342631634590881, 0.0555656431908054, 0.013298733359468835, 0.06792188462402139, 0.1037294464185834, 0.06235808067555938, 0.05129586659105761, 0.024858188083661453, 0.1635111431990351, 2.6407655775547028, 36.023328168051584, 47.73993648801531, 50.252804619925364, 58.38247489929199, 49.24605928148542, 31.59264257975987, 32.8903854233878, 40.472152028764995, 45.98870209285191, 18.783339704786027, 0.8530058051858629, 0.06293896771967411, 0.062042473682335446, 0.018754850407796245, 0.10602837734456573, 0.05467672160427485, 0.0867349940485188, 0.1516076305082866, 0.11302044322448117, 0.12060746896479811, 0.13383485775973114, 18.8628705229078, 66.0560862677438, 68.86208152770996, 67.58554458618164, 76.25153936658586, 81.85448333195278, 77.46213790348598, 81.5848445892334, 85.33686488015312, 83.12469046456474, 83.4204683303833, 82.11843150002616, 79.74462114061627, 79.32214982169015, 77.54946981157575, 78.2824352809361, 76.80002321515764, 78.52567781720842, 77.16560963221959, 66.69427830832345, 68.37331744602749, 70.54606778281075, 74.21103409358433, 72.30339227403913, 67.63182653699602, 68.1861538205828, 71.0642088481358, 68.35430717468262, 66.87920461382184, 67.63159029824394, 68.18570218767438, 65.15380014692033, 67.1671449116298, 67.35329410008022, 67.5775055204119, 68.77388804299491, 68.27983638218471, 66.62487275259835, 66.32794843401227, 69.91872882843018, 68.06258010864258, 68.8256173815046, 65.92932333265031, 66.52318586621965, 62.263870647975374, 60.82457215445382, 75.35978671482631, 68.73099681309291, 70.9505363191877, 65.35354001181466, 67.08464200156075, 62.745533670697895, 55.936636039188926, 64.296475819179, 59.680752754211426, 56.88523885181972, 59.34418896266392, 63.22070707593645, 64.0452081135341, 62.088956696646555, 62.05159623282296, 60.73739310673305, 61.14152812957764, 59.693356786455425, 60.44602734701974, 60.935798917497905, 59.80725165775844, 60.5407521384103, 60.250616209847585, 58.13374676023211, 57.79896865572248, 63.15665858132498, 63.42585263933454, 60.56490407671247, 59.58119896480015, 59.02466910226004, 58.2663357598441, 61.68032618931362, 62.64806434086391, 64.61197962079729, 63.65494169507708, 63.3608591897147, 62.500220571245464, 65.72030762263707, 61.94393389565604, 65.05847781045097, 68.80074977874756, 69.58750125340053, 71.94349643162319, 72.01574380057198, 70.02376474652971, 71.09951264517647, 66.02562536512102, 59.370140484401155, 46.202814306531636, 19.37853455543518, 2.310548314026424, 9.397631406784058, 3.565469192607062, 0.9739815422466823, 1.2988811539752143, 0.24567929123129162, 0.16496107753898415, 0.1511733273842505, 0.20930792790438446, 0.04383868531190923, 0.15154551741267952, 0.023295386228710413, 0.2835442865533488, 3.206082740000316, 52.982116086142405, 50.81505979810442, 51.65821327481951, 32.50100837435041, 37.81475789206368, 97.80980546133858, 74.65614264351981, 30.180751255580358, 31.99977227619716, 39.08141449519566, 46.81476994923183, 57.96463802882603, 40.66388756888253, 1.054975498999868, 0.06826960667967796, 0.013789315026120415, 0.0193473200446793, 0.02165293284425778, 0.06161555301930223, 0.009007034141437283, 0.03115444683602878, 0.04488895574052419, 0.057337342229272635, 0.078494450875691, 0.061511302899037085, 0.026020287868699858, 0.044055460286991935, 0.048796184294457944, 0.011698563732872052, 0.032777465281209776, 0.03263379906171134, 0.056062707411391396, 0.041188001832259555, 0.0679162052859153, 0.02798498940787145, 0.03573941991531423, 0.02898598801610725, 0.07169351473982845, 0.052778455428779125, 0.04332384347383465, 0.07537240947463683, 0.026278748642653227, 0.04465491883456707, 0.1254524261291538, 4.620730979101999, 53.406046526772634, 60.439072200230186, 68.13552924564907, 53.31735277175903, 50.991095883505686, 28.185789687292917, 35.20544876371111, 53.51492132459368, 54.4354499408177, 20.687948635646276, 0.5679360904863903, 0.007431083125993609, 0.137016304901668, 0.019627247970285158, 0.09239293794546809, 0.16286455360906466, 0.36388820675866945, 0.1718323438295296, 0.4116730312151568, 0.2002979735178607, 0.9790865140301841, 32.366883822849815, 82.19688361031669, 79.15467044285366, 76.73509924752372, 81.75551319122314, 87.97840322766984, 83.68340900966099, 85.50891617366246, 89.18304021017892, 84.06826972961426, 85.57847458975655, 85.31417901175362, 84.95651354108537, 82.62836674281529, 81.15345873151506, 82.54222297668457, 78.63184629167829, 80.85410949162075, 78.03166784558977, 70.5428716114589, 70.12831429072789, 73.13401467459542, 79.57482801164899, 74.79651015145438, 70.42841393607003, 72.47907052721295, 77.14763464246477, 73.26364026750836, 69.63634014129639, 70.55268941606793, 69.30179827553886, 68.7772718157087, 71.44102355412075, 71.08415017809186, 70.08866092136928, 70.4057628086635, 71.01923315865653, 70.53783416748047, 68.38911070142473, 71.21869509560722, 68.45350660596574, 69.81734766278947, 67.95457730974469, 66.94102273668561, 62.467376436506, 63.24898624420166, 75.62551362173897, 71.25982843126569, 72.93260029384068, 67.54748930249895, 70.24765654972622, 65.11707891736711, 56.24031400680542, 66.197190284729, 61.92099094390869, 59.92396054949079, 60.98064259120396, 64.59304577963692, 68.35584272657121, 64.92854649680001, 65.55027825491769, 63.70771326337542, 63.03701754978725, 63.0199875150408, 63.495793206351145, 63.404104777744834, 63.60581793103899, 62.58864334651402, 63.539337566920686, 63.45171383449009, 61.336841991969514, 64.90246990748814, 67.00170135498047, 64.86613082885742, 64.62771034240723, 62.137496812003, 60.961944988795686, 64.07133334023612, 66.64685685294015, 65.98645142146519, 65.93212345668248, 65.38007518223354, 65.7732320513044, 66.84592274257115, 67.08482960292271, 67.41589042118618, 69.87243298121861, 71.65816170828683, 73.12086173466274, 74.3991287776402, 71.71722139630998, 73.27459062848772, 69.11548233032227, 66.54478781563895, 68.40181200844901, 56.22452769960676, 26.290171725409373, 13.492509688649859, 5.15351711000715, 0.5104039204972131, 0.6169968321919441, 0.5394443507705415, 0.14607598233435834, 0.07278206132884536, 0.1640152811471905, 0.05352854196514402, 0.1813745139432805, 0.024733010247083645, 0.4054167483534132, 4.746697911194392, 60.94895185743059, 55.70434733799526, 56.590058531079976, 41.55539355959211, 27.145894493375504, 61.960498401096885, 62.32333333151681, 45.30599989209856, 40.23528446469988, 41.12782573699951, 63.39580168042864, 66.90992954799107, 53.70307159423828, 1.4221159241029193, 0.15148799121379852, 0.042002827394753695, 0.024504666249932985, 0.030859178929988827, 0.04541317832523158, 0.06393790018877812, 0.023980577675891773, 0.05047778745314904, 0.015318861031638724, 0.10270164228443589, 0.03644733889294522, 0.0995261933920639, 0.02162123508086162, 0.15918048843741417, 0.1296337353331702, 0.17646080761083535, 0.15166404390973703, 0.18655563092657498, 0.10905170547110693, 0.18176449515989848, 0.10409290370132242, 0.07490415245826755, 0.14220356941223145, 0.19429303359772476, 0.26653976472360746, 0.16114754788577557, 0.21411453426948615, 0.11172898752348763, 0.10969560806240354, 0.2253795319369861, 6.175653142588479, 70.996276310512, 72.09208365849086, 74.84487656184605, 79.30294500078473, 79.17493138994489, 50.58163159234183, 51.47363090515137, 68.74217646462577, 65.50465638296944, 31.317914281572612, 1.9414261324065072, 0.22169290190296514, 0.21732051723769732, 0.13312158174812794, 0.21441002269940718, 0.35610977986029213, 0.9852703022105354, 0.7497496030160359, 0.781809079859938, 0.41230189747044016, 0.5409132976617131, 39.65265716825213, 83.83903476170131, 78.09620966230119, 82.86004747663225, 85.57945428575788, 92.43032251085553, 85.17537484850202, 88.93658065795898, 92.32625239236015, 88.11897918156215, 90.26085172380719, 88.96284484863281, 89.62248597826276, 88.37251894814628, 84.81786223820278, 87.22282137189592, 83.13130514962333, 85.77751268659318, 83.69504724230084, 74.0125310080392, 74.42845712389264, 76.7652405330113, 81.6928265435355, 79.04090063912528, 73.02927058083671, 76.82607895987374, 80.7421601159232, 74.8618162700108, 73.36989212036133, 75.18306623186383, 74.38589940752301, 71.81571211133684, 74.1314285823277, 74.68176759992326, 72.70081533704484, 75.00745746067592, 74.47915812901088, 73.87608228410993, 72.95853097098214, 75.92835085732597, 74.09350531441825, 74.4615444455828, 71.03371320452008, 69.0002464566912, 65.31399086543492, 63.293572834559846, 79.67864799499512, 73.92321191515241, 76.55984483446393, 71.25109454563686, 74.41324056897844, 66.10723890577043, 56.873492922101704, 70.52976730891636, 62.39301681518555, 62.64990561349051, 65.26345661708287, 69.76325593675885, 72.08809539249965, 68.44523130144391, 69.16336931501115, 65.6776248386928, 66.39458860669816, 65.14270387377057, 67.04158401489258, 65.86366285596574, 64.66075597490583, 65.47398703438895, 65.46931089673723, 64.74519048418317, 64.67190088544572, 70.78480788639614, 70.84730693272182, 67.56238624027797, 68.28388718196324, 66.33212430136544, 65.39934253692627, 67.45039517538888, 69.52353613717216, 69.78432287488664, 68.39349501473563, 67.25927802494594, 68.78246906825474, 71.03445666176933, 68.5358636038644, 69.96788733346122, 72.5499074118478, 73.36765480041504, 76.30676364898682, 75.25721045902797, 75.0046295438494, 75.20310483660016, 69.51856122698102, 65.8618563243321, 61.15705735342843, 48.43446799686977, 27.11147311755589, 17.178998913083756, 5.888473238263812, 2.2022423999650136, 3.2874283407415663, 1.331873806459563, 0.44937922220144955, 0.1993312511060919, 0.5834876788514001, 0.2848616215799536, 0.4033731094428471, 0.11559652856418065, 0.41983605176210403, 8.21479526587895, 75.49091311863491, 65.57249859401158, 67.77489689418248, 50.15220512662615, 48.307618209293906, 119.84234864371163, 89.38128621237618, 46.85616731643677, 47.04156262534005, 55.54056440080915, 66.64552279881069, 77.78449957711356, 60.58481066567557, 1.7467008041484016, 0.21604727341660432, 0.10100154565381152, 0.1245080546608993, 0.09850835693734032, 0.1398132805313383, 0.12572705639260157, 0.15218708584351198, 0.14792576379009656, 0.08838227351329156, 0.1619907362120492, 0.18663846648165158, 0.162403706195099, 0.09402379007743937], [0.03312296174200518, 0.017312179785221815, 0.019744719345388666, 0.023088180293728198, 0.03639866757605757, 0.016048939266641225, 0.026977882288130264, 0.02425283645944936, 0.05360436486080289, 0.03940113753612552, 0.03167041843490941, 0.025001274155718938, 0.04927930462041071, 0.04210184940270015, 0.04742844429399286, 0.16037709851350102, 0.08544319908001594, 21.757243394851685, 47.57817200251988, 51.5105744770595, 39.92047200884138, 82.68275724138532, 89.51517799922398, 26.006563629422867, 32.01529802594866, 37.86790466308594, 21.437676634107316, 5.121975328241076, 0.05058121315336653, 0.04877619804548366, 0.08580679885510888, 0.2669777183660439, 0.06386061505015407, 0.16241634051714623, 0.2445745819381305, 1.7961267062595911, 0.5374023403440202, 0.11158204397984914, 7.935770375388009, 61.335375922066824, 81.78727340698242, 79.40502098628453, 76.73971979958671, 82.20713220323834, 81.23546137128557, 79.35217298780168, 83.46500628335136, 82.61932018824986, 79.68440110342843, 82.13498210906982, 78.78231648036412, 78.22224303654262, 77.48569924490792, 80.47529370444161, 78.54174205235073, 77.6423533303397, 67.75586577824184, 64.8516160420009, 68.77572236742292, 73.7958653313773, 75.25461183275495, 71.92227663312639, 69.8958067212786, 72.16807610648019, 72.59370190756661, 70.29346602303642, 68.2262796674456, 66.67851284572056, 63.05862644740513, 65.09469876970563, 65.41387816837856, 65.53801468440464, 64.39874635423932, 63.596062660217285, 64.79385566711426, 64.08746705736432, 63.99821744646345, 64.94518048422677, 65.82237665993827, 67.12228039332798, 68.04894774300712, 65.75093528202602, 65.38731520516532, 62.61602619716099, 68.89339011056083, 70.31416470663888, 65.2931740624564, 66.1814317703247, 67.3795860835484, 66.55707223074776, 65.54469190325055, 58.45092855181013, 59.30288887023926, 59.66518184116909, 60.732154164995464, 61.28462627955845, 61.84538064684187, 63.387873785836355, 62.04715633392334, 62.93650490897042, 59.3251439503261, 60.24792030879429, 57.1867733001709, 56.54227924346924, 58.638870375497, 61.013361658368794, 59.9376346043178, 61.45827565874372, 63.52327333177839, 62.05454226902553, 61.06737000601632, 63.270428385053364, 63.14192145211356, 63.98733656747, 61.38574341365269, 62.89431544712612, 57.55741105760847, 57.47121865408761, 60.736288343157085, 61.28240980420794, 64.28934001922607, 61.07481847490583, 62.99190984453474, 65.37127876281738, 63.21505124228341, 64.06059837341309, 68.54382623944963, 69.80153356279645, 70.162353515625, 67.93823514665876, 68.97644192831856, 70.55452374049595, 63.5377116884504, 54.43841682161604, 39.48280497959682, 20.934804235185894, 3.3856270142963956, 9.526364156178065, 0.745019291128431, 1.0127253489834922, 1.1515169186251504, 0.05619808532563703, 0.1587532963603735, 0.05224506583596979, 0.28389107223067966, 0.06965324814830508, 0.2072618462677513, 0.11883063002356462, 0.6939333123820168, 2.0698347049100057, 53.5295854977199, 47.02588401521955, 40.881918566567556, 55.610633509499685, 67.15734100341797, 19.213820559637888, 26.357268742152623, 39.46219662257603, 52.23349632535662, 44.45767000743321, 48.96433067321777, 60.36052976335798, 5.456542815480914, 0.3039154005902154, 0.05531971835132156, 0.03439039730333856, 0.03131220962053963, 0.06342612193631274, 0.03396919669051256, 0.06614205334335566, 0.01862248688537095, 0.03698920678081257, 0.029616621855114187, 0.028232905747635022, 0.0498830006191773, 0.07739767365689788, 0.05330308513449771, 0.054347140182341845, 0.038652207901967425, 0.05079343515847411, 0.003915438403575016, 0.066199409908482, 0.010922105084838611, 0.020078439830935428, 0.07292691498462643, 0.06487190364194767, 0.04152763235781874, 0.04235062748193741, 0.0380349208467773, 0.012481591448054781, 0.04323289263993502, 0.09141976266567196, 0.20630690322390624, 33.102548667362754, 60.2154027393886, 68.05768162863595, 50.73908124651228, 106.00275993347168, 95.38449505397251, 21.75604656764439, 42.450807912009104, 49.12274612699236, 25.862101895468577, 4.2471940858023505, 0.029858492447861602, 0.17832604609429836, 0.11768626714391367, 0.2252103460154363, 0.09588246034192187, 0.12984702603093215, 0.7031788676977158, 3.071358689240047, 0.3187051298362868, 0.42343052316989216, 17.409378596714564, 82.8000567299979, 86.21866076333183, 82.11927223205566, 81.33869770595005, 88.87081595829555, 85.48716136387416, 84.98688411712646, 86.11540358407157, 84.17920466831752, 83.26907403128487, 84.555908203125, 81.33265972137451, 80.96292522975376, 79.1401834487915, 82.98501082829067, 84.1294138772147, 78.82580525534493, 69.84398010798863, 68.77843911307198, 73.34380858285087, 77.35096672603062, 79.0990709577288, 75.49647862570626, 76.72929750170026, 77.86304896218437, 77.56425557817731, 72.36608586992536, 72.46525750841413, 71.39202485765729, 69.40718160356793, 69.99297727857316, 69.79797608511788, 68.15058599199567, 64.91460841042655, 66.09274496350969, 66.88788291386196, 68.53043706076485, 68.71620409829276, 70.14530958448137, 68.59662560054234, 70.30440943581718, 71.25587490626744, 69.49991921016148, 67.05540398189, 62.94968564169747, 70.55815070016044, 71.19179861886161, 69.08577183314732, 69.86353928702218, 70.54317733219692, 70.03566701071603, 66.98331642150879, 58.91414410727364, 61.86197294507708, 61.039327076503206, 63.398636545453755, 63.55565193721226, 64.53628594534737, 65.33336244310651, 66.05161162785122, 65.74357713971818, 63.572119167872835, 63.30067389351981, 61.055328777858186, 59.765381813049316, 60.88219356536865, 63.84455803462437, 64.20095198495048, 64.06328732626778, 65.01544761657715, 66.7049229485648, 66.09852586473737, 68.01316452026367, 67.8542731148856, 65.96475914546421, 64.43882356371198, 66.09561456952775, 61.52841772351946, 59.87003558022635, 64.8566117967878, 64.73883288247245, 67.30023765563965, 65.07268687656948, 64.1338323865618, 67.62715734754289, 66.44217681884766, 67.51611818586076, 69.78311388833183, 71.74390247889927, 71.7158317565918, 69.61566230228969, 70.45342050279889, 72.78818893432617, 68.35995606013707, 65.3966257912772, 62.27948325020926, 55.53654834202358, 23.325849601200648, 11.321492058890206, 1.5749020342315947, 0.5276299704398427, 1.2381149232387543, 0.1321246780987297, 0.18920364097825118, 0.07859044322477919, 0.39324963837862015, 0.08413585208888565, 0.36228480136820246, 0.1848674900829792, 1.1521695064646857, 3.035702705383301, 62.281810896737234, 52.53724724905831, 46.43617997850691, 57.74203164236886, 61.99582999093192, 19.94621627671378, 27.912454502923147, 40.471286978040425, 54.95289271218436, 54.44433668681553, 55.736319473811555, 72.28981549399239, 6.202684674944196, 0.29048569979412214, 0.07400054058858327, 0.07193223014473915, 0.02656737538719816, 0.02540094654874078, 0.01407247532292136, 0.06876916451645748, 0.03297964157536626, 0.06514104455709457, 0.015507587065388049, 0.04689704280878816, 0.02499355242720672, 0.06093598662742546, 0.1796929141772645, 0.12139522098004818, 0.14456156002623693, 0.1365717558988503, 0.15388107565896852, 0.13086982257664204, 0.13682650508625166, 0.10359928983130626, 0.2733744036938463, 0.13658855642591203, 0.12721561294581207, 0.10700743552297354, 0.19210312967853888, 0.10504173314464943, 0.19278139328317984, 0.2357162529868739, 0.41774130559393335, 38.26956960133144, 75.16413239070347, 74.88720498766217, 62.136232239859446, 107.12824303763253, 101.91031960078648, 36.91136353356497, 53.27550377164568, 63.23851530892508, 36.40933186667306, 7.7400213820593695, 0.3016768049980913, 0.4012185979102339, 0.24191491465483392, 0.5608026789767402, 0.2847629083054406, 0.789520874619484, 5.0341435841151645, 10.520580155508858, 1.3514011757714408, 0.4296802378126553, 20.67315592084612, 87.60895361219133, 85.12436812264579, 91.0682601928711, 84.9757878439767, 94.52321025303432, 88.01893901824951, 87.75433077130998, 87.93551199776786, 88.61824893951416, 86.39643737248012, 89.62961483001709, 84.21355656215123, 85.43999699183873, 82.54016630990165, 85.65135424477714, 87.76801872253418, 82.81689916338239, 73.26366806030273, 72.57930524008614, 73.42982728140694, 79.84270886012486, 80.82956150599888, 79.82276058197021, 79.00009386880058, 80.10683768136161, 79.22074781145368, 74.7258608681815, 73.04650906154087, 74.23044041224888, 71.55332728794643, 69.74932479858398, 70.25739792415074, 71.91929585593087, 69.74174431392125, 70.78285544259208, 70.08701419830322, 70.50751222882951, 71.18598297664097, 71.93144825526646, 71.65443052564348, 72.0696131842477, 73.86789035797119, 72.74592304229736, 72.40683010646275, 66.35181549617222, 71.52618067605155, 76.21891062600272, 71.28120109013149, 71.89195469447544, 70.56944847106934, 71.18979058946881, 68.45595237186977, 59.396460260663716, 64.59904902321952, 64.2126110621861, 67.55481270381382, 66.73145117078508, 67.56531143188477, 70.09107889447893, 69.43867083958217, 68.7680585043771, 66.56815460750035, 66.04811668395996, 62.88526889256069, 62.67516926356724, 66.07654871259416, 68.59062930515834, 67.92449855804443, 68.45203358786446, 68.8889502116612, 69.35743944985526, 69.1089232308524, 70.26397092001778, 71.35253129686627, 70.36858299800328, 66.20480551038469, 68.48428017752511, 65.93627847943986, 64.6290374483381, 67.15529823303223, 67.652907371521, 70.04535974775041, 66.97969641004289, 68.15821511404855, 69.4149010522025, 68.80223669324602, 70.28405121394566, 71.0422316959926, 73.9991557257516, 73.42176737104143, 70.9484727042062, 72.7226048878261, 73.80803857530866, 66.63972105298723, 63.768906048366, 54.071336541857036, 48.706312792641775, 24.76105907985142, 14.39417220864977, 1.4668441925730025, 2.690737238952092, 4.681682314191546, 0.6730636379548481, 0.3175185077956745, 0.11668545513280801, 0.5587308130093983, 0.25589040187852724, 0.4887478511248316, 0.49192062658923014, 1.9137636167662484, 8.452237793377467, 75.80538858686174, 64.73237105778286, 57.11816678728376, 79.12610639844621, 87.46134608132499, 30.51864562715803, 34.30430562155587, 51.9386773109436, 68.80182674952916, 62.754059110369, 67.52433790479387, 84.48226424625942, 7.877457618713379, 0.4308078815894467, 0.2604546626763684, 0.2425454365355628, 0.10802584873246295, 0.18186478263565473, 0.09512326108025652, 0.16734745805816992, 0.17679746954568795, 0.12177216075360775, 0.10256430001131125, 0.15614096367997782, 0.10570803417691163, 0.10724607628903218], [0.02247020791816924, 0.06338611551161323, 0.03954420664480754, 0.06323248839804105, 0.029498353201363767, 0.03679003978946379, 0.08882867491671018, 0.02721114905684122, 0.060225682599203925, 0.024147712725347707, 0.024978970709655966, 0.05757259710558823, 0.039840624667704105, 0.03746542301295059, 0.07049826851912908, 0.03255048853212169, 1.503812734569822, 44.21061291013445, 51.87503181185041, 48.92739404950823, 52.61223220825195, 34.582532337733674, 33.09391205651419, 29.930279118674143, 36.40170274462019, 25.759907790592738, 9.241050277437482, 0.06739308871328831, 0.0584260652373944, 0.08279018822525229, 0.05851947236806154, 0.2063382922538689, 0.09693362643676144, 0.25839487463235855, 0.0230130257550627, 0.1383463285331215, 0.12834157395575727, 2.5374161175319125, 53.4969984463283, 85.6928836277553, 68.14447157723563, 72.10741138458252, 84.54573604038784, 83.11107199532645, 80.75603566850934, 81.49088409968785, 80.41133553641183, 79.35194369724819, 80.64448928833008, 79.04943997519356, 79.46456010001046, 75.81562328338623, 78.84929711478097, 75.0576651436942, 76.94805458613804, 67.43856934138707, 69.03102002825055, 74.03546701158795, 75.78061131068638, 76.33550834655762, 74.20313399178642, 73.99606377737862, 76.11891215188163, 79.02172361101422, 75.14754704066685, 70.0393773487636, 70.84944002968925, 67.34657519204276, 69.38466944013322, 71.70258154187883, 65.39978722163609, 62.953514099121094, 63.257066999162944, 65.04743712288993, 64.43637084960938, 63.63411794389997, 65.53743798392159, 65.73892879486084, 67.07959760938371, 64.8545481818063, 70.0800312587193, 66.19047137669155, 60.13016223907471, 62.5061890738351, 66.01502241407121, 65.24696159362793, 68.58925356183732, 65.23961734771729, 65.81945146833147, 64.65430109841483, 64.39006805419922, 60.16832174573626, 59.743342127118794, 61.331637791224885, 60.886077608381, 64.71729346684047, 62.16887487683977, 61.03071131025042, 58.8211007799421, 59.67041383470808, 58.92084217071533, 60.004816736493794, 56.94991268430437, 57.398061071123394, 55.33148963110787, 59.17310346875872, 60.661581311907085, 61.85683822631836, 60.67230238233294, 63.92881883893694, 67.05375725882394, 63.874754905700684, 64.12516103472028, 61.77880995614188, 61.71428203582764, 63.2349647794451, 63.91020461491176, 58.29323918478829, 56.81555189405169, 58.61869280678885, 61.126158714294434, 62.963721002851216, 61.713406562805176, 63.075496673583984, 62.18171514783587, 63.307094029017854, 63.99954455239432, 70.63692937578473, 70.4205972126552, 69.7099563053676, 65.29527936662946, 68.89992836543492, 64.06897095271519, 64.75428567613874, 46.132470743996755, 36.112181731632774, 18.00510151045663, 7.722635252135141, 6.106850777353559, 0.07873485583279814, 0.17799099907279015, 0.14364598558417388, 0.08274758301143136, 0.1358763389289379, 0.06807357791279044, 0.17244240109409603, 0.16795364767313004, 1.5111449296985353, 0.5076810408915792, 0.4696505644491741, 5.544516997677939, 61.20491654532296, 39.43875340053013, 19.83487834249224, 20.744748422077723, 58.81744602748326, 50.26551634924752, 36.15569829940796, 27.375258002962383, 48.98337568555559, 46.949582372392925, 61.0192745753697, 5.386351244790213, 0.2785304013107504, 0.1137594628546919, 0.027765457884275486, 0.04767600101019655, 0.04643823778522866, 0.06402067467570305, 0.06273951235094241, 0.01499335590883025, 0.034754533121096234, 0.019862628375579203, 0.08141079438584191, 0.029170875237988572, 0.0374106448808951, 0.028957862739584277, 0.09958697655903441, 0.04962651098945311, 0.027022190624848008, 0.06619821568684918, 0.026223831410918916, 0.03643131868115493, 0.02464004586051617, 0.05330039135047367, 0.05692718138120004, 0.07239656522870064, 0.07977857839848314, 0.03671319569860186, 0.030560793155538182, 0.1017989328663264, 0.013422994325602693, 1.6618991260017668, 52.61074529375349, 62.942515100751606, 66.22924927302769, 66.59312643323625, 62.83909116472517, 39.07989631380354, 24.57788372039795, 44.91979469571795, 30.439484800611222, 8.650517668042864, 0.09402505893792425, 0.035349530300923755, 0.0623328730996166, 0.10068304810140814, 0.14513185513871057, 0.18323770325098718, 0.1953409087977239, 0.38874541435922894, 0.3166008841778551, 0.18730476072856359, 7.10432939018522, 80.70176328931535, 89.2536061150687, 74.94716794150216, 75.3265882219587, 89.04839106968471, 85.88969135284424, 85.1470261982509, 85.89391585758754, 83.89878926958356, 80.64298152923584, 83.9120533806937, 83.11519227709088, 82.93259361812046, 79.96143967764718, 79.88890048435756, 79.81235218048096, 78.74081489018032, 70.64960289001465, 74.28758239746094, 78.33633940560478, 80.16174929482597, 77.93214184897286, 75.76875073569161, 76.28533540453229, 77.44627516610282, 81.631258555821, 77.24172714778355, 72.93079376220703, 74.39826025281633, 72.47568675449916, 73.5110308783395, 75.60106985909599, 69.45697934286935, 68.4389431817191, 66.47230420793805, 69.04676464625767, 69.12333379473004, 68.43137659345354, 68.38316304343087, 66.93620763506208, 70.18516445159912, 67.89482280186245, 72.83090645926339, 68.75276551927838, 63.25071634565081, 64.10387870243618, 68.8308493750436, 67.78759125300816, 69.37947913578579, 68.55117743355888, 68.6915032523019, 69.32264981951032, 65.09077998570034, 61.880990164620535, 62.66082123347691, 63.6703736441476, 64.8234897341047, 65.92723887307304, 64.19997923714774, 62.705734389168875, 62.515492711748394, 61.325259344918386, 61.37277112688337, 63.41199793134417, 59.98453494480678, 60.46109798976353, 60.27217647007534, 62.4688355582101, 62.65699277605329, 65.44307449885777, 63.61512851715088, 66.5565024784633, 67.30290576389858, 67.31034033639091, 67.0895335333688, 65.4950122833252, 65.92693315233502, 65.49259431021554, 65.96468271527971, 62.34430994306292, 60.61374991280692, 62.35546875, 65.03413827078683, 65.19002110617501, 64.78671986716134, 65.60163239070347, 64.99750736781529, 66.6174590247018, 67.08785206930978, 72.16224656786237, 71.3150110244751, 69.4048261642456, 67.98055662427629, 69.80954483577183, 66.00857448577881, 71.0254101072039, 62.75298908778599, 59.27021844046456, 46.996788433619905, 19.079600470406668, 8.236014195850917, 0.36159337418419973, 0.3089302900646414, 0.10914861384247031, 0.14369649573096208, 0.012043413889062191, 0.03916100399302585, 0.06936236018581049, 0.087993581513209, 2.682499280997685, 0.5637327560356685, 0.5416374845164162, 6.555994927883148, 67.88808304922921, 43.74130378450666, 24.50272158214024, 25.902137415749685, 62.10348537990025, 50.0357984815325, 47.25990629196167, 36.078500338963096, 54.316003458840505, 55.387620653424946, 69.01524066925049, 7.014713696071079, 0.19833745514707907, 0.02990321469094072, 0.04387809123311724, 0.04608079232275486, 0.057826979884079525, 0.06063027267477342, 0.06448473834565707, 0.05538447094815118, 0.03943337134218641, 0.06643395232302801, 0.05650001305288502, 0.03104241731177483, 0.05717596624578748, 0.06414855138531753, 0.2007736401366336, 0.10017125627824239, 0.12336152046918869, 0.12596396010901245, 0.13969125279358455, 0.17885433988911764, 0.09552275535783597, 0.14479819232864038, 0.1524753953729357, 0.16172408552042075, 0.14427563894007886, 0.1368271836212703, 0.11687974685004779, 0.18040188827684947, 0.15412935162229197, 2.4667160255568366, 68.99674456460136, 72.45631517682756, 72.65872314998082, 75.65871906280518, 46.64224617821829, 44.059701510838096, 44.34514045715332, 58.760178974696565, 46.134082726069856, 13.276468481336321, 1.120439580508641, 0.1662138703146151, 0.25182293727993965, 0.1901275206889425, 0.6041639979396547, 0.4147976306932313, 2.261321629796709, 1.345261465225901, 1.423668303659984, 0.2708607300051621, 8.208885822977338, 83.65074552808488, 89.81084469386509, 84.73235075814384, 79.67183181217739, 95.25855895451137, 90.14583819253104, 87.50633566720145, 88.35999134608677, 86.76200294494629, 83.68664687020438, 86.74047742571149, 86.7928112574986, 87.52506106240409, 84.76738357543945, 85.8280816759382, 81.92485468728202, 83.23988464900425, 75.54466438293457, 75.79602936335972, 81.52017075674874, 82.56129578181675, 82.69980812072754, 80.48732798440116, 79.74978365216936, 81.89378234318325, 86.15605749402727, 80.21746689932687, 77.31359236580985, 77.03952762058803, 73.37334537506104, 75.13258062090192, 79.30306312016079, 71.29320757729667, 70.8887459891183, 68.15319156646729, 73.09792573111397, 69.40153271811349, 69.82442787715367, 69.64942359924316, 71.19309793199811, 74.60332938602993, 69.78380870819092, 76.923492704119, 71.87609890529087, 65.55751827784947, 64.3566472189767, 72.77113805498395, 69.30607836587089, 72.97129481179374, 70.51545401981899, 69.75357709612165, 71.18371091570172, 69.1500357219151, 63.37766688210623, 64.53477818625313, 65.90788813999721, 65.56065191541398, 70.31574889591762, 67.8183022907802, 66.402252469744, 65.01288373129708, 66.56873825618199, 66.1880464553833, 66.25630555834088, 61.56277656555176, 62.563789640154155, 60.77745641980852, 65.90841620309013, 65.9320956638881, 68.41958550044468, 67.6343000956944, 70.08082335335868, 71.60866968972343, 69.14597797393799, 70.0714224406651, 68.5176454271589, 67.69167831965855, 68.12124374934605, 68.59005955287388, 64.92635781424386, 62.9619631086077, 65.66877283368791, 67.10106754302979, 68.3185725893293, 68.27431951250348, 68.9211620603289, 67.79346248081752, 67.11743749891008, 67.74839646475655, 75.63884721483502, 72.49367564065116, 72.58345331464494, 69.17881516047886, 72.34954220908028, 68.44773265293666, 68.0486420222691, 58.53586333138602, 50.868296895708355, 42.9123524257115, 23.769637993403844, 8.440743735858373, 0.5225926350269998, 1.1575173395020621, 0.43336709854858263, 0.1935160838599716, 0.2751366677028792, 0.17738505373043673, 0.42735128849744797, 0.2953497916460037, 4.5652066213744025, 1.256199129990169, 0.9666149318218231, 10.694042801856995, 79.59874371119908, 54.1801244871957, 32.02388947350638, 32.73300872530256, 84.77874388013566, 73.72928074428013, 54.100216729300364, 40.941377776009695, 71.06618213653564, 65.706362588065, 81.54077911376953, 9.514968241964068, 0.3916919119656086, 0.2409662412745612, 0.2600579911044666, 0.3063258555318628, 0.13207783204104218, 0.16466894107205526, 0.11776022746094636, 0.12529316038957664, 0.09321178722062282, 0.1782314040298973, 0.24325922823378018, 0.05590934831915157, 0.17466202484709875], [0.04449794654335294, 0.034923722435321124, 0.0032911624376928167, 0.03154186997562647, 0.02802202384918928, 0.028775642160326242, 0.02257966579470251, 0.014405410404184034, 0.0332278225437871, 0.006942639268735158, 0.024860294934894358, 0.01634859390157674, 0.07321178434150559, 0.029061288439801762, 0.07918481954506465, 0.0735486905489649, 0.4656311944127083, 32.16772413253784, 55.0005920955113, 47.87270614079067, 47.624818733760286, 38.44181544440133, 25.799722705568584, 42.78292138235909, 26.613969939095632, 9.691330892699105, 0.6991000037108148, 0.014062880837757672, 0.10517534347517149, 0.014489044934245092, 0.17394336126744747, 0.25443646418196814, 0.2462520290698324, 0.08709934699748244, 0.2016329640256507, 0.10538408798830849, 0.7950862188424382, 38.912590639931814, 91.11737700871059, 72.958635193961, 69.60676860809326, 82.96808501652309, 85.70258331298828, 80.88808618273053, 81.7421726499285, 83.5312990461077, 78.26744106837681, 81.76294081551688, 77.4862620489938, 76.3077641895839, 73.26416833060128, 77.390946660723, 75.06616279057094, 78.80065277644566, 68.32616697038922, 65.02719702039445, 74.70785808563232, 77.25441455841064, 74.76135226658413, 70.98816081455776, 76.89321245465959, 75.51330021449498, 74.47101484026227, 75.46312727246965, 70.99114853995187, 71.221314566476, 73.70252323150635, 75.62786906106132, 71.10653032575334, 68.54049805232457, 65.67881298065186, 68.77156039646694, 65.73696245465959, 67.8426765714373, 66.38101182665143, 65.56944138663155, 66.84177466801235, 65.7248170035226, 64.83558654785156, 65.56116608210972, 67.01015731266567, 59.719690459115164, 61.58917277199881, 65.0790375300816, 61.93871579851423, 67.68862806047711, 66.11915506635393, 68.1318050112043, 68.9488228389195, 70.71147659846714, 60.94794436863491, 61.1165771484375, 59.94262341090611, 59.76387405395508, 62.50616128104073, 62.37306158883231, 61.84789589473179, 61.33477142878941, 61.07083020891462, 56.751614570617676, 56.304032461983816, 55.3507604598999, 57.35597930635725, 57.815536635262625, 59.98769637516567, 59.714402879987446, 60.04038456508091, 62.231082098824636, 65.17133045196533, 64.0319926398141, 64.70403630392892, 63.825895173209055, 63.16224493299212, 62.11164256504604, 62.46594510759626, 61.30315712520054, 63.0660262789045, 62.07287161690848, 59.79309817722866, 56.87979146412441, 59.15207821982247, 59.47702462332589, 62.79906259264265, 63.086335863385884, 62.541569301060264, 61.10170800345284, 66.55506420135498, 64.32656151907784, 71.50856699262346, 68.10094111306327, 69.02495425088065, 63.76651586805071, 65.04654775347028, 67.54387623923165, 59.108228138514924, 39.44921391350882, 30.27778284890311, 12.029881749834333, 10.5077702828816, 2.063300141266414, 0.07470485315259014, 0.188446558745844, 0.07107565432254757, 0.019114268710836768, 0.27496752249343054, 0.020313516591808627, 0.45951911381312777, 0.42580987406628473, 0.36519674797143253, 0.19581149997455732, 0.4247098330940519, 12.940898282187325, 63.45502812521798, 39.31320640019008, 17.998662267412456, 13.988920262881688, 14.804891518184117, 30.54344722202846, 48.70831387383597, 51.86447054999215, 49.2246310370309, 44.57639735085623, 2.9701672962733676, 0.21016683110169002, 0.040920611537460766, 0.07157728847648416, 0.061823015101253986, 0.04627945041283965, 0.02937877836770245, 0.03200176065521581, 0.07613235512482268, 0.02920056114505444, 0.03850147134757467, 0.028252829232120087, 0.06865160832447664, 0.033666912732379775, 0.025610712257080843, 0.002877126942621544, 0.07630482515586273, 0.015400275055851256, 0.030914333648979664, 0.05466912201206599, 0.08402933566165821, 0.05029875259580357, 0.056779728936297555, 0.0408116048867149, 0.01759685915229576, 0.025238607045529143, 0.0879339382850698, 0.048585370249514065, 0.14091383719018527, 0.03631067854751434, 0.8406840435096196, 39.425242628370015, 66.10594654083252, 61.52076080867222, 66.0976642881121, 29.609112535204204, 18.209774596350535, 51.683619362967356, 33.253018856048584, 9.403390594891139, 0.5957846875701631, 0.018580353253387978, 0.1337429162647043, 0.039046898151614835, 0.2741147396819932, 0.04472739315990891, 0.7020403945020267, 0.05662467011383601, 0.25977957461561474, 0.19161986346755708, 2.536639439208167, 62.53796318599156, 94.99953011104039, 75.64204338618687, 77.70389352525983, 87.19690459115165, 88.61824199131557, 82.64842619214738, 84.7519029889788, 84.46140575408936, 81.84074674333844, 84.43551676613944, 82.32568236759731, 78.97299589429582, 77.16854177202497, 79.9596539906093, 78.82093456813267, 80.23958996364048, 69.62973935263497, 71.32210513523647, 80.02207660675049, 79.7565998349871, 76.51555701664516, 76.7125106539045, 79.71935749053955, 76.5408901487078, 78.37519373212541, 78.22307682037354, 75.27137783595494, 73.77766799926758, 76.20133168356759, 78.34497601645333, 74.07665593283517, 71.10032558441162, 70.27854129246303, 72.0339550290789, 69.65443325042725, 70.47564779009137, 68.19113567897251, 67.99966417040143, 70.32751219613212, 67.87401989528111, 68.57783767155239, 68.89621802738735, 69.25412668500627, 63.898879051208496, 64.95364339011056, 67.26787294660295, 66.32448823111397, 69.46656785692487, 68.20979159218925, 68.57484299795968, 72.08751174381801, 71.40575449807304, 63.367988041469026, 62.853515625, 64.29994297027588, 62.25644997188023, 65.09232248578752, 63.4559383392334, 64.5985209601266, 62.98162651062012, 64.15361390795026, 58.866451672145296, 61.46638420649937, 58.546966552734375, 58.92461504255022, 61.56556279318673, 63.20994431631905, 63.620159012930735, 63.32479109082903, 64.86281653812954, 66.90389156341553, 66.23350157056535, 68.55581188201904, 67.13846969604492, 67.1832160949707, 64.85759844098772, 66.35385131835938, 64.83350208827427, 64.55918720790318, 64.69619178771973, 63.90806456974575, 60.131607464381624, 62.74236529214041, 63.06744371141706, 65.03522913796562, 64.721344266619, 67.25572054726737, 63.8324681690761, 68.2371049608503, 66.93299756731305, 70.87317507607597, 69.80350685119629, 68.64577020917619, 64.87016078404018, 69.32862527029855, 67.13914367130825, 72.4064826965332, 56.95640230178833, 55.87018346786499, 34.21287080219814, 15.129045827048165, 2.9911185034683774, 0.07313958143017121, 0.3682802010859762, 0.14673621047820362, 0.17920409754983016, 0.05835599971136876, 0.13952457745160374, 1.1391560733318329, 1.4065952769347598, 0.43759328605873243, 0.06965244747698307, 0.419804214899029, 14.578218698501587, 71.60306249346051, 42.68806457519531, 24.472458703177317, 18.18437545640128, 20.70297758919852, 34.93585865838187, 47.767948150634766, 54.06220660890852, 55.681164673396516, 48.24847166878836, 3.275688490697316, 0.215960773772427, 0.10278403679175036, 0.13777109368571214, 0.02383522699320955, 0.10793147129671914, 0.03929391882515379, 0.04254674445837736, 0.020018920435437133, 0.06902670926813569, 0.016339949365439158, 0.045395373566342254, 0.027904808621055315, 0.036448604360755, 0.09122320464146988, 0.16188531901155198, 0.10815173054912261, 0.12710886581667832, 0.11922571382352284, 0.164542163589171, 0.1578229298549039, 0.1298404170998505, 0.2032715989542859, 0.10267137283725397, 0.11196302782211985, 0.10156815632113389, 0.12588028317051275, 0.13442147842475347, 0.24259119693722042, 0.12642624601721764, 1.0050066603081567, 54.18862560817173, 78.58308383396694, 70.85160786764962, 68.13775266919816, 54.662774154118125, 41.23490789958409, 66.89695726122174, 45.82449531555176, 15.646045650754656, 1.9161600938865115, 0.15290587155946664, 0.2539485975035599, 0.18743611153747353, 0.7065060777323586, 0.4290657564997673, 1.6336721777915955, 0.27393715349691256, 0.5239708753568786, 0.33717577585152214, 2.0204149910381863, 64.16038840157645, 95.61801011221749, 86.42288916451591, 82.73816217694963, 91.87732233319963, 93.25793634142194, 85.13777814592633, 87.99493299211774, 89.31357601710728, 84.31145668029785, 89.22765459333147, 87.38244928632463, 81.98275402614048, 81.60780143737793, 83.32263074602399, 81.7394836970738, 84.51153005872453, 76.68950516836983, 73.73278263636998, 81.61199120112828, 82.11815357208252, 80.17324161529541, 79.90951578957694, 82.18350137983049, 81.17854867662702, 82.27377932412284, 82.16549859728131, 77.17619173867362, 74.54556901114327, 80.62858486175537, 80.94743769509452, 78.6191658292498, 74.7873454775129, 71.51386151994977, 74.10642201559884, 72.03689411708287, 74.41668687547956, 72.90566212790353, 71.40706075940813, 72.69098363603864, 71.8034415926252, 71.48547812870571, 73.31573091234479, 75.1860956464495, 66.35879843575614, 64.88113893781389, 68.0000810623169, 67.97711726597377, 71.9781470979963, 71.23904636928013, 71.95766380855015, 75.16077641078404, 74.86738177708217, 65.53109427860805, 67.20853533063615, 67.79941013881138, 65.76435920170375, 69.70238276890346, 66.7443539755685, 67.98688643319267, 66.92714718409947, 69.16212558746338, 61.90969317299979, 64.92861597878593, 61.6488230569022, 62.29902158464704, 63.05144201006208, 66.80649866376604, 66.89895139421735, 65.97532735552106, 68.46482522147042, 72.27996294839042, 69.83768504006522, 71.04378809247697, 69.92967224121094, 68.13239560808454, 67.58696896689278, 68.45722389221191, 67.53724070957729, 68.69444234030587, 67.74965408870152, 65.9546286719186, 61.80135686056954, 65.57477760314941, 65.18141228812081, 68.85689122336251, 68.1557207107544, 68.39591993604387, 67.65652043478829, 71.01358427320207, 68.85041550227574, 73.58539744785854, 71.24007470267159, 69.68310151781354, 68.75100067683628, 68.96243435995919, 69.51735224042619, 67.48783901759556, 52.757977621895925, 50.292610849652974, 33.34873029163906, 19.240128176552908, 3.0451153431619917, 0.46759205205099924, 0.5580842505608286, 0.2619416314576353, 0.330976489931345, 0.4312442067478384, 0.2905377298593521, 2.2623354153973714, 6.0695003015654425, 0.659040490431445, 0.290150910615921, 0.5827992643628801, 21.35149986403329, 81.99478830610002, 56.66419928414481, 32.88587951660156, 24.28759319441659, 24.289328507014684, 46.77724272864205, 71.45513534545898, 71.50260543823242, 65.59486484527588, 64.77064868382045, 5.454985984734126, 0.45828043456588474, 0.30855302459427286, 0.271547760282244, 0.1286383651729141, 0.22129627104316438, 0.10675385341580425, 0.12493185406284672, 0.15521084144711494, 0.15582468493708543, 0.12824314566595213, 0.12976827525666781, 0.20951235693480286, 0.12314094230532646], [0.019108299299010208, 0.1172512447727578, 0.028202415776572058, 0.011302792068038667, 0.08488793351820537, 0.0199548294102507, 0.007297804429461914, 0.030591968446969986, 0.0494100888525801, 0.04635949379631451, 0.029645859929067746, 0.037876981643161604, 0.009246142248490026, 0.04496853432751127, 0.05379182712307998, 0.01875769007684929, 0.29118193100605694, 38.22644908087594, 54.16831949778965, 35.358211857931956, 43.75052056993757, 50.556555543627056, 42.09720366341727, 35.972606318337576, 17.18136998585292, 2.3750384535108293, 0.14237545590315545, 0.07489875810486929, 0.044233613048813174, 0.08770314816917692, 0.0276427804492414, 0.02247629437728652, 0.12963011195617063, 0.13111428517316068, 0.17467247428638594, 0.09578502271324396, 23.871799094336374, 77.90588460649762, 73.20556722368512, 64.64007118770054, 81.23468317304338, 78.3863525390625, 82.59086731501988, 79.81763281141008, 81.03454726082938, 73.68586145128522, 79.07597514561245, 75.51097951616559, 76.2090094430106, 76.519364629473, 78.2213328225272, 75.93466676984514, 78.65255192347935, 70.21787657056535, 66.57445662362235, 76.11532688140869, 77.99753134591239, 78.43791512080601, 71.09280068533761, 75.92345932551792, 75.35017735617501, 75.73688629695347, 74.75309085845947, 68.88530240740094, 71.72907502310616, 73.34809562138149, 74.9715005329677, 74.55939592633928, 69.902560370309, 68.8503668648856, 70.51419639587402, 71.44660295758928, 68.08490467071533, 64.98967674800328, 65.14173807416643, 65.12623664311, 63.026935713631765, 62.450693811689106, 66.46584238324846, 64.97103473118374, 63.416264125279014, 63.35939311981201, 62.71198081970215, 63.603969710213796, 59.98168618338448, 65.65816293443952, 66.00826876504081, 63.214578764779226, 62.472129004342214, 63.40115874154227, 57.869638783591135, 55.947020121983115, 57.795942715236116, 58.39954662322998, 58.684888294764924, 60.1332402910505, 62.29918139321463, 59.78272451673235, 59.06333582741873, 60.593836375645225, 58.78066921234131, 55.98724671772548, 58.65640068054199, 59.87385708945138, 63.32355431147984, 63.374755586896626, 62.21321133204869, 61.55794061933245, 62.406392097473145, 62.842071941920686, 64.4053679874965, 64.8075088773455, 62.19430528368269, 63.23716041019985, 61.506100109645296, 61.231583731515066, 63.731087003435405, 60.906685965401785, 65.6705515725272, 56.945643016270225, 56.908452783312114, 58.84584331512451, 61.672648429870605, 60.289949962071006, 63.34680993216378, 59.19333662305559, 61.260919025966096, 65.50958960396903, 66.12888254438127, 70.26314408438546, 68.74571309770856, 64.29594080788749, 66.70109449114118, 66.93779877253941, 64.39316695077079, 50.54201643807547, 37.23951653071812, 18.90278271266392, 12.289525508880615, 8.195905719484601, 0.32504223978945185, 0.09890648735953228, 0.27344252860971857, 0.349374207002776, 0.1113146808264511, 0.5293173513242176, 0.9605881295033863, 0.4855618306568691, 0.08745214449507849, 0.1557079769138779, 0.028688650578260422, 0.2838495730289391, 38.732778208596365, 56.06292997087751, 27.74619800703866, 33.42982619149344, 33.56255415507725, 42.486299310411724, 49.84717573438372, 48.242197445460725, 47.682665961129324, 13.955068639346532, 0.02711393534471946, 0.021402626364891018, 0.0346356707492045, 0.06276313215494156, 0.045437727722206285, 0.05874418281018734, 0.02487388768765543, 0.02725871266531093, 0.06299785777394261, 0.08088884489344698, 0.06960155735058443, 0.06182410754263401, 0.040052076535565515, 0.05721504307751145, 0.03783787088468671, 0.09197290441287415, 0.02818136422761849, 0.0468577658092337, 0.0219546179952366, 0.03550679096952081, 0.023572567783828293, 0.01517143233546189, 0.04641187669975417, 0.004536043495006327, 0.04485660997618522, 0.04512019368952938, 0.014784066871340786, 0.07618203745888812, 0.040814502231244526, 0.05382392182946205, 0.6693017312458583, 48.19757958820888, 68.88562202453613, 55.34217248644148, 53.61358574458531, 30.941189902169363, 36.23085696356637, 46.734997681209016, 21.90246421950204, 2.559482510600771, 0.12480263385389533, 0.051582045520522764, 0.10138959304562636, 0.1583627044622387, 0.0667894503899983, 0.22645766979881696, 0.23351345690233366, 0.26239999543343273, 0.21234723553061485, 0.5831834237490381, 36.10502161298479, 89.00335284641811, 77.28670978546143, 72.99550233568463, 86.40107182094029, 83.45154067448208, 83.50092847006661, 83.77190821511405, 82.70520687103271, 76.1057939529419, 81.04255158560616, 79.19846493857247, 80.67663165501186, 79.63386685507638, 81.79157434191022, 78.99636268615723, 80.52658530644008, 73.90053994315011, 71.172274180821, 79.00875132424491, 79.68737493242536, 79.09417247772217, 74.9255381992885, 79.98751626695905, 76.40066160474504, 78.79020963396344, 77.4209976196289, 72.1506152834211, 73.35318170275006, 76.68435655321393, 76.74015058789934, 77.4119371686663, 71.96755804334367, 72.42770249502999, 72.81209073747907, 74.27374853406633, 71.42942006247384, 70.23331546783447, 68.14615304129464, 68.88514954703194, 66.11802945818219, 64.66698156084333, 68.13985102517265, 67.05418109893799, 65.95954104832241, 65.52376392909459, 64.07958780016217, 65.8301864351545, 62.19257518223354, 67.47107301439557, 66.53957666669572, 64.08164446694511, 63.37265028272356, 65.50040408543178, 61.19338948386056, 57.99689851488386, 59.73638003213065, 58.35177080971854, 60.60259805406843, 63.03948416028704, 63.182867186410085, 64.72862597874233, 60.95186315264021, 62.86452851976667, 61.289198194231304, 60.674067224775044, 61.766803468976704, 63.67244420732771, 64.50854178837368, 67.62150151388985, 64.05585275377545, 65.10951927730015, 64.75097138541085, 64.11860888344901, 67.14088072095598, 67.13135474068778, 67.2310266494751, 67.90067318507603, 64.43170166015625, 62.6857305254255, 65.79219368525914, 62.956696374075754, 68.57344641004289, 62.365779876708984, 59.441137177603586, 61.09149415152413, 65.77883229936872, 64.41772188459123, 66.23472445351737, 62.36917059762137, 65.69923373631069, 68.29318387167794, 68.36047717503139, 70.54157229832241, 71.4670376096453, 65.86147417340959, 68.84030587332589, 69.19034222194126, 68.09633445739746, 65.66407585144043, 59.02291120801653, 44.23289925711495, 26.019572394234793, 11.93037920338767, 0.6536665473665509, 0.07996978278138808, 0.4088367819786072, 0.4445070150707449, 0.21700855397752353, 0.6848862692713737, 1.9733722124780928, 0.33681292246494976, 0.07837481158120291, 0.1063525542350752, 0.02340734620312495, 0.3430573173931667, 45.221315247671946, 65.48221370152065, 29.974768434252056, 28.3338714327131, 20.859713315963745, 40.98299053737095, 63.43937383379255, 55.8176029750279, 54.338890824999126, 16.439814805984497, 0.08426486873733145, 0.012985885459264475, 0.021843721624463797, 0.0275902940692114, 0.06755783701581614, 0.044824382955474515, 0.021490422010953938, 0.05051343429035374, 0.024307212559506297, 0.09230499302170106, 0.043591495004615614, 0.04007173030238066, 0.02941269494060959, 0.03274188290483185, 0.20451896344976767, 0.1895105152257851, 0.11031834036111832, 0.13572007231414318, 0.1383323778531381, 0.10940664035401174, 0.11836439504155091, 0.14603616589946405, 0.1635432243347168, 0.08238880083497081, 0.17995683715811797, 0.17224551737308502, 0.11019015831074544, 0.1368331140173333, 0.128044511324593, 0.16066810861229897, 0.8701893516949245, 57.85379341670445, 73.61502456665039, 52.57480921064104, 67.32758576529366, 71.96466759272984, 56.333058561597554, 59.68117659432547, 35.855588231767925, 4.318700168813978, 0.4094386696815491, 0.29623717974339214, 0.2640598549374512, 0.27900754713586395, 0.2791631487863404, 0.36189464373247965, 1.1084771709782737, 0.43456712844116346, 0.4943777375987598, 0.6410111093095371, 40.216979435511995, 100.39961447034563, 82.42676476069859, 78.83068983895438, 90.06297397613525, 88.932418687003, 88.06440108163017, 87.26321125030518, 85.13729872022355, 80.46232836587089, 85.06566974094936, 83.2163997377668, 81.75861208779472, 85.02081217084611, 84.17258303506034, 83.6357513155256, 87.39379569462368, 79.78856154850551, 72.26935304914201, 81.96451500483921, 82.6049165725708, 86.51387582506452, 77.51447173527309, 80.02432782309396, 79.68653420039585, 81.37187535422188, 80.2126795904977, 75.68984699249268, 76.99160589490617, 80.99576241629464, 76.97328349522182, 81.51915631975446, 74.40634795597622, 76.929794720241, 74.60835988180978, 78.12577424730573, 77.00008964538574, 72.02606882367814, 72.70881966182164, 72.3525229862758, 69.61437688555036, 67.85072258540562, 70.30758476257324, 70.43997573852539, 68.70530932290214, 66.49307237352643, 65.4708811896188, 68.03684398106166, 66.5729627609253, 71.79288033076695, 70.45638043539864, 66.63940838405064, 66.521379334586, 68.59113652365548, 61.82485566820417, 61.199580328805105, 62.7829566683088, 61.35992390768868, 63.07997131347656, 67.25732558114188, 67.83292824881417, 67.56870910099575, 62.652664048331125, 66.45264080592564, 63.47856167384556, 60.13417134966169, 64.28236402784074, 65.2415281023298, 66.27322442190987, 69.25761468069894, 67.02052402496338, 68.59831401279995, 70.42346681867326, 68.5261013848441, 70.62223393576485, 70.90287167685372, 70.9453182220459, 71.67195388248989, 66.81255749293736, 65.87366826193673, 68.79008429391044, 66.89602620261056, 72.53300244467599, 63.01312269483294, 62.71974195752825, 64.2635691506522, 68.60585280827114, 66.61564554486955, 69.37127331324986, 65.2913327898298, 66.63927636827741, 69.24179363250732, 69.57288919176374, 74.93509197235107, 74.59272643498012, 68.55825069972447, 70.5806211744036, 70.30066435677665, 66.60095010484967, 61.651810782296316, 53.50595120021275, 41.07421691077096, 31.09420313153948, 12.627841983522687, 0.6070423977715629, 0.1795569629009281, 0.7797176178012575, 1.4005515383822578, 0.8153959661722183, 1.539570878658976, 5.638318112918308, 1.2124399180923189, 0.28207772810544285, 0.19896860128002508, 0.1686500824455704, 0.7121938839554787, 55.75002479553223, 70.96420342581612, 42.59467731203352, 50.79651505606515, 48.52748353140694, 65.64674009595598, 71.9902091707502, 67.55061599186489, 67.04585020882743, 27.79119454111372, 0.12936859098928316, 0.14251612978322165, 0.13963386230170727, 0.17080247694892542, 0.16768108015613897, 0.16829415011618817, 0.18683893286756106, 0.17427867970296315, 0.1826610027679375, 0.17749421644423688, 0.16093497643513338, 0.22315376065671444, 0.197846792904394, 0.11942745585526739], [0.13729614631405898, 0.05671232666022011, 0.06587131787091494, 0.03622563775362713, 0.04959873515846474, 0.02090574874143515, 0.03186712912949068, 0.027744414817009653, 0.07408119126089982, 0.04699076206556388, 0.054411482265485187, 0.031071051489561796, 0.054278482616479905, 0.06519135114337717, 0.049144279544374773, 0.035266989908580265, 5.458366283348628, 58.39552361624581, 47.874835763658794, 31.990767410823278, 33.817994253976, 28.219740322657994, 36.58006647654942, 26.78134856905256, 3.841326355934143, 0.6799065279109138, 0.14929256401956081, 0.08642763125577144, 0.0910506938983287, 0.13622212037444115, 0.07400063558348588, 0.6047458010060447, 0.20548109896481037, 0.5761735598955835, 0.5656755375010627, 9.56330338546208, 55.40089518683297, 64.76383250100272, 78.73810509272984, 74.99723666054862, 84.94383307865688, 76.4785509109497, 81.78443159375871, 73.98652390071324, 76.11445140838623, 73.85526548113141, 80.89438125065395, 74.20592716761998, 78.0022074835641, 73.11806161063058, 75.89431163242885, 75.91037586757115, 70.61075551169259, 67.60214383261544, 80.27694347926548, 75.95640073503766, 77.44416291373116, 72.04514162881034, 75.63401126861572, 74.86813913072858, 75.44125434330532, 73.64849403926304, 70.76317119598389, 70.70994104657854, 73.14122690473283, 74.2295093536377, 72.55119282858712, 71.42288180759975, 74.64369147164481, 70.29325757707868, 71.66929967062813, 69.80244377681187, 68.62570381164551, 66.73837157658168, 65.84455530984062, 64.98226302010673, 63.194227491106304, 63.793454033987864, 66.04273183005196, 63.97159889766148, 66.83709158216203, 64.85279028756278, 63.13245105743408, 62.113782610212056, 61.71114839826311, 63.40985788617815, 62.11173289162772, 63.72135257720947, 64.05886827196393, 65.44086497170585, 62.12275273459298, 61.926799637930735, 58.93246650695801, 56.99113982064383, 56.71812425340925, 59.94010121481759, 60.08226830618722, 59.561702319553916, 58.648041997637065, 60.03299168178013, 60.620739800589426, 62.71370397295271, 61.94850581032889, 60.990620204380576, 61.90457929883684, 65.99078014918736, 62.742865562438965, 63.24982697623116, 66.74813379560197, 61.75187873840332, 62.29375485011509, 64.88339710235596, 63.00348554338728, 62.75020980834961, 62.157403400966096, 61.43712534223284, 60.192828042166575, 61.83580602918352, 61.56127575465611, 64.13251917702812, 60.06987271990095, 58.92137023380825, 57.79576553617205, 61.18168176923479, 60.845312527247835, 61.61902223314558, 61.596558707101, 63.021773202078684, 63.45883573804583, 68.64364406040737, 69.06890160696847, 67.18478638785226, 63.79189763750349, 65.29523072923932, 65.95871421269008, 57.337684699467246, 46.985445499420166, 27.791580166135514, 15.926994323730469, 16.796257393700735, 3.474195484604154, 0.15624871504093918, 0.24433557476316178, 0.02091933979785868, 0.23895161652139255, 0.21959499376160757, 0.5662602175559316, 0.0691526589382972, 0.14174425548740796, 0.18407250488443033, 0.07623739234570946, 0.441563747291054, 8.470726081303187, 73.58587687356132, 48.92504208428519, 24.1739501953125, 32.42140286309378, 32.220787525177, 28.46277267592294, 33.489181177956716, 44.78835562297276, 6.103214698178427, 0.18671306462160178, 0.034192444889673164, 0.07201239227184228, 0.03973825748211571, 0.046806339640170336, 0.06453484815678426, 0.037093263518597396, 0.018094059079885483, 0.034341980437082906, 0.023542147362604737, 0.06182066058473928, 0.023428190798897828, 0.16254351155034133, 0.019199340038799813, 0.08006990062338964, 0.0047249964139025125, 0.04471709978367601, 0.11524185830993311, 0.10101313503193003, 0.03302275908312627, 0.06360203892524753, 0.048697579585547955, 0.042452767358294556, 0.04361528783504452, 0.06257122209561722, 0.024591286334076097, 0.08165997958609036, 0.0671168774632471, 0.07329374458640814, 0.16780648699828557, 8.149689776556832, 68.06550530024937, 58.55126748766218, 45.57087911878313, 36.21422297613961, 26.81261546271188, 44.600521496364046, 37.2695119040353, 2.8480012459414343, 1.2551877328327723, 0.08193634689918586, 0.018035971393276538, 0.05743805718209062, 0.14484019364629472, 0.06355557963252068, 0.9399863949843815, 0.35124457521098, 0.6258050852588245, 0.3624163828790188, 13.009280715669904, 70.07240908486503, 76.97971752711705, 84.59938308170864, 81.56098447527204, 89.09667410169328, 82.26130035945347, 84.52566964285714, 76.91099289485386, 77.71461459568569, 76.8324921471732, 84.26865577697754, 79.47919300624302, 80.51222337995256, 76.9082761492048, 78.98104190826416, 76.26267732892717, 72.25718675340924, 72.56520734514508, 82.01424326215471, 78.82700729370117, 79.33007076808384, 76.10575226375035, 79.46318435668945, 77.45878887176514, 78.72420869554792, 75.15762887682233, 72.39375359671456, 73.22909382411412, 75.54376806531633, 74.78404508318219, 75.50345461709159, 75.15185492379325, 76.61917550223214, 72.91788400922502, 75.04427596500942, 73.20792961120605, 72.01648030962262, 68.68641717093331, 69.1535723549979, 70.4974581854684, 67.95001234327043, 69.67397853306362, 69.20128563472203, 68.812242099217, 67.8646467753819, 67.48083523341587, 65.21925912584577, 65.12875189099992, 64.90492262159074, 65.53811195918492, 64.7483936037336, 66.67316968100411, 68.41356141226632, 66.82912199837821, 66.36022281646729, 63.48625332968575, 61.114430155072895, 58.5010598046439, 59.1630494253976, 62.760701588221956, 61.98427513667515, 62.15785503387451, 61.53743648529053, 61.375654629298616, 62.87083053588867, 64.05803448813302, 66.51344449179513, 64.82247529711042, 64.3386583328247, 66.79855687277657, 66.68316813877651, 65.717590876988, 67.92800739833287, 65.55388436998639, 64.23642253875732, 65.86821392604283, 67.11472075326103, 66.40767901284354, 62.57617827824184, 64.45911925179618, 62.24522863115583, 64.8260258265904, 63.498975481305806, 66.8523428780692, 63.465950693402974, 62.26502404894148, 60.76720782688686, 64.82754748208183, 65.26824392591203, 63.7726719720023, 63.24629034314837, 64.9842085157122, 66.42035252707345, 67.95935767037528, 70.16034548623222, 70.10917200360979, 65.16855117252895, 68.4300286429269, 68.91265746525356, 66.30182320731026, 61.724217959812705, 52.85283095496041, 36.09225082397461, 23.79071535382952, 5.50431124653135, 0.1090431898566229, 0.16147794015705585, 0.00741183732835842, 0.40021018630691935, 0.36825723946094513, 0.6334929413029126, 0.4020794417176928, 0.28291235331978115, 0.18869153702897684, 0.0780432250882898, 0.4056267413709845, 9.35819777420589, 82.6478772844587, 51.45300170353481, 29.008379970278057, 19.8383663381849, 35.67809302466256, 40.94405630656651, 39.608973843710764, 55.024921212877544, 7.662324888365609, 0.19829970145864145, 0.08498979519520487, 0.05617493371080075, 0.03164895297959447, 0.055124534360532246, 0.041944941572312794, 0.03933321278808372, 0.02066009022694613, 0.02822726033627987, 0.01810643555862563, 0.01865450695290097, 0.04503249643104417, 0.08738526129829031, 0.05236068820314748, 0.2219037634453603, 0.0923211896525962, 0.1450218374707869, 0.21479885040649346, 0.1603160710739238, 0.10773518468652453, 0.1555317613695349, 0.12630530393549375, 0.20004863903990813, 0.1165219960468156, 0.18441407941281796, 0.07764558321131126, 0.2443453185260296, 0.1785461085715464, 0.15636254607566766, 0.2830842398107052, 9.255015288080488, 82.67832429068429, 65.50677558353969, 50.95368330819266, 48.967075211661204, 42.71516602379935, 53.516390868595664, 48.44894456863403, 7.99542760848999, 3.8023083124841963, 0.3724084895636354, 0.19608917007488863, 0.1975302563181945, 0.5105973301189286, 0.19267996586859226, 1.4785014241933823, 0.7191329087529863, 1.043339871934482, 0.6252201880727495, 12.372397541999817, 80.89865439278739, 80.31005859375, 89.20643479483468, 83.47662367139543, 94.57887922014508, 86.19942120143345, 86.02511869158063, 79.55403205326625, 79.27972412109375, 79.34964384351457, 88.3817947932652, 81.8944285256522, 84.20265483856201, 81.24625192369733, 83.87315041678292, 82.11238656725202, 77.99357782091413, 73.51135049547467, 85.83373056139264, 82.37694617680141, 81.77889387948173, 79.82171835218156, 80.44439506530762, 83.1484602519444, 83.5280681337629, 81.96784319196428, 76.91858727591378, 77.34574862888881, 77.29199041639055, 78.03859519958496, 77.03008501870292, 76.95456504821777, 78.89275809696743, 76.01705850873674, 78.13797528403146, 75.58338669368199, 73.48557267870221, 73.60714530944824, 71.66951506478446, 72.23804446629116, 68.96299716404506, 71.00505883353097, 71.40327399117606, 68.63502134595598, 72.05535548073905, 71.57111467633928, 67.06255367824009, 67.1357112612043, 66.55660670144218, 69.17810644422258, 66.23903233664376, 69.52832344600132, 69.65645517621721, 68.28886209215436, 69.84799616677421, 66.09457233973912, 64.0966386795044, 62.7905718939645, 62.7403781073434, 66.76810986655099, 65.83976800101144, 64.211916242327, 63.03348091670445, 65.10038934435163, 65.52779388427734, 67.8781749180385, 69.3903044291905, 68.27598013196672, 67.25056498391288, 71.80135713304792, 70.3728700365339, 68.23176874433244, 71.51646709442139, 68.58478587014335, 68.44596086229596, 71.3906421661377, 70.44507571629116, 69.70122241973877, 66.42304842812675, 65.39043494633266, 65.62554809025356, 66.90515613555908, 66.3498283113752, 72.66199575151715, 64.42733124324253, 65.28136212485177, 63.862665040152415, 66.99892902374268, 66.8710960660662, 67.24329021998814, 66.60768985748291, 67.61373342786516, 70.04056549072266, 70.2535764149257, 73.41632693154472, 72.6286930356707, 67.05792617797852, 69.60764408111572, 68.87690898350307, 62.25612340654646, 57.41301359449114, 46.4207376071385, 36.71744278499058, 29.108062301363262, 4.203658410481044, 0.3162411520523684, 0.2938830160668918, 0.29795672318765093, 0.5644523288522447, 1.130363670842988, 2.1318046024867465, 0.5960930681654385, 0.27774047798344065, 0.309554216584989, 0.32775982682194027, 0.7593478336930275, 14.372228060449872, 94.77743789127895, 62.227392605372835, 39.057682922908235, 48.47029638290405, 47.86494847706386, 42.07851995740618, 47.592308112553184, 66.11609091077531, 11.304374303136553, 0.5891800448298454, 0.22563387400337628, 0.18201521384928906, 0.19533305136220797, 0.19468171202710696, 0.10329085495322943, 0.12366496132952826, 0.11180989603911128, 0.13160945288836956, 0.13533150245036396, 0.195128093074475, 0.09728911093303136, 0.21659103780984879, 0.2071199103125504], [0.11930375892136778, 0.05532232392579317, 0.0164953321883721, 0.05945303477346897, 0.03890034815828715, 0.04312704796237605, 0.025543589876698594, 0.06320532664124455, 0.07771370134183339, 0.04761203212131347, 0.027102437568828464, 0.049794709642550776, 0.07043772283941507, 0.016279742953234484, 0.05850244113909347, 0.04704039350950292, 29.405822140829905, 63.43359293256487, 49.70259761810303, 51.93532827922276, 36.057926722935264, 30.55797243118286, 37.08007274355207, 7.34258268560682, 0.6102383519921983, 0.19035283502723488, 0.5263479192342077, 0.0813189750271184, 0.1402372427816902, 0.025251438142731786, 0.3144881161195891, 0.29551358999950544, 0.06000562012195587, 0.3452234997281006, 0.34648272501570837, 29.95509113584246, 77.98796367645264, 71.33106136322021, 79.2818294252668, 79.37317044394356, 83.39193207877022, 75.74270193917411, 76.7829236984253, 76.17102364131382, 77.77758611951555, 76.02287415095738, 76.09666401999337, 72.82996845245361, 77.39436517442975, 74.19916657039097, 75.39994730268205, 74.09470040457589, 67.69625718252999, 76.92784227643693, 75.0941709790911, 78.7031695502145, 72.67448166438511, 76.11372879573277, 73.04839897155762, 72.20105225699288, 72.79574162619454, 66.8630153111049, 70.92976815359933, 74.46877057211739, 73.75939423697335, 71.81355816977364, 72.80600411551339, 73.07765088762555, 75.27326079777309, 70.95086288452148, 69.78473281860352, 72.65253925323486, 66.93313653128487, 69.8169446672712, 69.75708593641008, 70.54576901027134, 69.34739930289132, 68.45748792375836, 70.14150891985211, 69.36875806535993, 65.0676633289882, 62.34584549495152, 63.24459498269217, 61.82651628766741, 61.763002804347444, 65.9797672544207, 63.66072954450335, 65.13221209389823, 67.26147365570068, 62.222264834812705, 61.59990079062325, 58.79715033939907, 57.12551103319441, 56.33662298747471, 57.14069979531424, 59.25995595114571, 58.81707777295794, 59.730342047555105, 57.95292684010097, 62.009865352085654, 62.2949777330671, 59.936189379010884, 60.74759306226458, 61.538506507873535, 61.879086358206614, 62.37169974190848, 64.96366964067731, 64.74994305201939, 61.58251639774868, 66.31850583212716, 63.46069090706961, 61.001014709472656, 62.05004678453718, 61.274655614580425, 58.91906343187605, 63.76304176875523, 58.55013493129185, 61.78772449493408, 60.184149742126465, 61.34952245439802, 64.69126551491874, 59.93457044873919, 57.24094493048531, 58.565796170915874, 61.303983960832866, 63.087544849940706, 61.21939659118652, 65.34422942570278, 62.12487193516323, 65.88705049242292, 67.30325317382812, 68.20811707632882, 65.39703573499406, 65.6252771105085, 67.17586490086147, 63.779793875558035, 50.57507249287197, 41.746545451028005, 19.28600365774972, 22.410367114203318, 14.563835058893476, 0.4486185573041439, 0.23423273116350174, 0.19488002067165716, 0.08695696320916925, 0.07150060044867651, 0.030544033340577568, 0.1542340495756694, 0.4651346153446606, 0.13135608791240624, 0.09244721396160976, 0.20111041063708918, 0.5329985395073891, 44.00581475666591, 62.52410847800118, 31.008709021977015, 25.754377024514334, 21.86753215108599, 48.799894605364116, 42.58059331348964, 46.31639303479876, 7.5410701377051215, 0.3970821941537516, 0.1547903532960585, 0.06258748658001423, 0.009989069392239409, 0.024884203116276433, 0.05183225530864937, 0.019799592472346764, 0.011635965484726642, 0.08544252733034746, 0.04273460705631545, 0.07213038951158524, 0.02809647610411048, 0.0655296551329749, 0.05004638506631766, 0.08869625880782094, 0.03421959646844438, 0.029548517295292447, 0.05943217660699572, 0.06836263383073465, 0.02120616163925401, 0.059686959721148014, 0.039144495236022134, 0.007841055680598532, 0.04279693389045341, 0.08804350133453097, 0.008268868617181267, 0.04290862075452294, 0.05356581389371838, 0.012328034732490778, 0.02723222435452044, 38.41936928885323, 73.25765786852155, 64.60662950788225, 64.64597715650285, 23.19661831855774, 35.02478517804827, 49.132671628679546, 7.554653865950448, 0.5867350931678499, 0.22285896433251245, 0.7068038731813431, 0.20324269336249146, 0.27123913541436195, 0.08505668517734323, 1.0981775522232056, 0.5143534285681588, 0.2943672729390008, 0.3992840402892658, 0.5328506188733237, 40.69047485079084, 88.42318521227155, 78.3929602759225, 83.62554441179547, 84.30946949550084, 86.47708511352539, 80.51469693865094, 78.1216470173427, 80.98870304652623, 81.23114653996059, 80.65083299364362, 81.31348964146206, 76.20658452170235, 80.54679761614118, 79.78662300109863, 77.83711828504289, 75.55174459729875, 71.10523101261684, 80.49980694907052, 76.60422992706299, 79.65912355695451, 75.46995735168457, 79.61113929748535, 73.99051911490304, 76.82209069388253, 74.84946237291608, 70.45608861105782, 73.9677220753261, 79.98362527574811, 78.11086341312954, 75.65059661865234, 76.84968893868583, 74.07580130440849, 74.43522466932023, 75.36988939557756, 71.86986637115479, 77.49587835584367, 70.22773606436593, 72.68651594434465, 73.3739012309483, 73.03745555877686, 72.55664021628243, 72.48451096670968, 72.90005493164062, 69.61556502750942, 66.34593732016427, 65.60381412506104, 63.71663475036621, 65.21242209843227, 62.461289814540315, 65.52415302821568, 65.07616792406354, 65.53307451520647, 67.15997437068394, 65.81824248177665, 64.5195060457502, 60.91598265511649, 59.44036592755999, 58.5347238268171, 60.328547205243794, 61.52442250932966, 60.741186823163716, 60.64006274087088, 59.84673132215227, 63.11997904096331, 64.09665257590157, 62.64735562460763, 62.85817091805594, 65.38066577911377, 62.57445512499128, 64.6778346470424, 65.36974321092877, 66.2021929877145, 64.82926368713379, 68.46204594203404, 64.93937179020473, 64.6198866707938, 64.25874015263149, 63.87417820521763, 61.80894429343087, 65.85176753997803, 64.18859113965715, 62.90295900617327, 61.34508950369698, 62.18442494528634, 67.55254064287458, 63.81321471078055, 61.982204573495046, 61.48399788992745, 64.17333289555141, 64.66602965763637, 64.92944281441825, 67.18374415806362, 66.0319412776402, 68.23348494938442, 68.04064464569092, 69.84841305868966, 67.20032255990165, 67.52080821990967, 67.96668801988874, 68.64153180803571, 60.28237642560686, 59.68173939841134, 44.33657680238996, 34.510208538600374, 19.884309564317974, 0.8615576262984956, 0.2699256001838616, 0.626326145870345, 0.11343548273933785, 0.13850616424211434, 0.05292961946023362, 0.3028134325785296, 0.28485385913934025, 0.2678488759057862, 0.12850067684692995, 0.16612138599157333, 0.7056831504617418, 50.18750197546822, 69.94294330051967, 33.66052028111049, 23.332754373550415, 22.337650741849625, 57.59046711240496, 48.42172152655465, 57.61422995158604, 10.021039417811803, 0.5421451372759682, 0.08643842674791813, 0.11678743894611086, 0.0865885933328952, 0.014083821276601936, 0.04344674991443753, 0.02626060800892966, 0.04656453350824969, 0.0451613502310855, 0.07369376812130213, 0.012256739361743842, 0.029165626769619327, 0.04483100884993162, 0.05235700715067131, 0.24872496351599693, 0.14316200012607233, 0.15361453353294305, 0.14821378833481244, 0.11584557805742536, 0.17200306324022158, 0.19423697303448403, 0.16081617852406843, 0.16528895923069545, 0.12033472502870218, 0.1761259234377316, 0.15537212922104768, 0.13895019755831786, 0.11205645530883755, 0.13562334036188467, 0.21170076807694777, 45.10526296070644, 84.20711558205741, 71.80446992601667, 77.66858972821916, 50.216531549181255, 49.932256426130024, 58.30081272125244, 12.152103168623787, 1.5449307624782835, 0.5211648344993591, 1.5036172079188483, 0.5500182605215481, 0.5592998596174377, 0.08730831542717558, 1.489998195852552, 1.088595226407051, 0.5747670925089291, 2.1194068448884145, 0.5556806081107685, 48.98481048856463, 90.43183299473354, 82.12828404562813, 87.35357257298061, 87.08709526062012, 90.29488400050572, 81.29887063162667, 80.81934070587158, 81.95386341639927, 85.65680163247245, 84.27411706107003, 85.79385484967912, 80.53749397822789, 86.0850191116333, 83.0154925755092, 82.08701869419643, 79.88852528163365, 74.18743106297084, 82.49415533883231, 81.45131410871232, 83.27338191441127, 79.16825417109898, 81.56492410387311, 79.57715565817696, 79.59645775386265, 77.91847474234444, 72.07651969364711, 76.16160883222307, 82.52522073473249, 80.37551062447685, 77.66260038103376, 79.62575830732072, 78.14399242401123, 79.58406216757638, 77.4934812273298, 75.90278843470982, 80.54976449693952, 72.55135958535331, 74.19981275285993, 76.82399450029645, 75.41911738259452, 73.81434753962925, 74.78048760550362, 75.05886718205043, 73.82602051326207, 70.64445427485875, 68.49483449118478, 67.51898779187883, 68.2041357585362, 66.57353251320976, 70.20295878819057, 67.4326981135777, 69.10659558432442, 72.56386634281704, 67.56737504686627, 66.43313026428223, 65.28289072854179, 62.43178081512451, 61.4366181237357, 61.89949321746826, 65.50513580867222, 64.89069965907505, 65.74295180184501, 63.52811622619629, 65.44406809125627, 68.03751795632499, 65.76952171325684, 65.3804017475673, 69.16196577889579, 66.3798028400966, 68.43691430773053, 70.131454876491, 70.29340348924909, 67.60977295466832, 72.60126849583217, 68.3246522630964, 66.07451983860561, 69.57347284044538, 65.94312245505196, 64.54347733088902, 70.34502860477993, 65.18979876382011, 65.96113913399833, 64.5730071749006, 67.1943610055106, 70.40916047777448, 64.74164690290178, 63.46260166168213, 63.69056510925293, 68.0780051095145, 66.74518775939941, 67.72474479675293, 70.82182788848877, 66.89615821838379, 70.88167967115129, 71.2217800957816, 73.20929840632847, 69.4556244441441, 69.22721631186349, 69.0308324268886, 66.80321911403111, 56.469531604221885, 54.62549359457833, 43.18180704116821, 41.533399036952424, 21.128643342426844, 0.6576696868453706, 0.6495279722980091, 0.7542563240442957, 0.3103595290865217, 0.2649748186979975, 0.1819865253887006, 1.0241439534085137, 0.9979312228305, 0.8821052951472146, 0.20980908029845782, 0.3142018829073225, 1.2976444831916263, 58.39241777147566, 78.50891181400844, 47.460406984601704, 39.316329615456716, 34.46857493264334, 69.77300425938198, 57.164174284253804, 67.21061284201485, 12.370830723217555, 0.6021254073296274, 0.4060049567903791, 0.17850758135318756, 0.19200417213141918, 0.0648499530340944, 0.24528413957783154, 0.13275999043669018, 0.19773240547095025, 0.11231132663254227, 0.1565408922199692, 0.1347445696592331, 0.20631413640720503, 0.19576138337807997, 0.15699768199452332], [0.052551176731607745, 0.002251191110449976, 0.020509794720315506, 0.08153698154325996, 0.00729695541251983, 0.030705487355589867, 0.0682626041982855, 0.03435623645782471, 0.05300551699474454, 0.04637678626126476, 0.08155877608805895, 0.02187795880516725, 0.021770612868879522, 0.010331525167982494, 0.03155906066032393, 1.0180841471467699, 47.25321517671858, 47.91614280428205, 34.09437274932861, 31.58106688090733, 33.82003355026245, 39.2586213520595, 18.175500869750977, 2.753464924437659, 0.07983450325472013, 0.022077037586963603, 0.2797931549804551, 1.210382491350174, 0.0368028878500419, 0.5397439375519753, 0.7792069252048219, 0.08688249399087258, 0.32590840331145693, 0.38959179180009024, 4.148755916527339, 63.50811236245291, 78.59226240430559, 72.65968894958496, 80.48527826581682, 86.01596096583775, 78.80414772033691, 77.34722164699009, 74.96545560019356, 77.72855963025773, 75.84807137080601, 79.81506197793144, 75.29530048370361, 76.16487448556083, 73.91950852530343, 75.71589578901018, 70.72305229731968, 67.49340452466691, 78.5002613067627, 75.00987543378557, 79.29068143027169, 75.18273271833147, 73.21850476946149, 73.57946368626186, 69.35553564344133, 72.7294488634382, 69.42075143541608, 72.47586740766252, 71.76565728868756, 73.72566768101284, 73.0404154913766, 74.60917976924351, 71.81533690861293, 73.52726881844657, 69.12612002236503, 70.4420393535069, 70.29876749856132, 70.83837849753243, 70.30968311854771, 72.61845139094761, 69.76571559906006, 71.31756101335797, 69.40502766200474, 67.59152698516846, 67.42221328190395, 64.09894548143659, 65.8149003982544, 64.34882354736328, 60.988348143441335, 60.00920104980469, 59.70250756399972, 59.349261147635325, 62.794129371643066, 61.09585762023926, 58.765966824122835, 62.893523352486746, 60.558706283569336, 58.66795553479876, 56.625782694135395, 55.02193348748343, 58.97219630650112, 56.84778806141445, 59.91098826272147, 59.367354256766184, 59.66067940848214, 59.62291594914028, 61.88629164014544, 59.71547985076904, 56.96462549482073, 60.28589221409389, 59.54230294908796, 61.09500299181257, 60.56213869367327, 62.24059418269566, 62.27266011919294, 63.28183732713972, 63.02824892316546, 61.684404781886506, 61.03461619785854, 61.01864228929792, 61.34911251068115, 59.49449239458357, 62.922226360866, 60.029461996895925, 58.89154161725725, 60.8587920325143, 62.210730825151714, 63.72864818572998, 60.82467637743269, 56.534181118011475, 58.86161572592599, 62.210466793605256, 63.30937303815569, 62.715281214032856, 60.543809345790315, 63.15658909933907, 66.84582546779087, 70.08181694575718, 68.69244125911167, 64.03188146863664, 62.89269651685442, 67.82141508374895, 54.675218377794536, 50.590514864240376, 27.56717767034258, 15.753190347126552, 26.50341194016593, 5.038120993546077, 0.2533299635563578, 0.33636837346213205, 0.10147972285215344, 0.06558804985667978, 0.15679885766335896, 0.04102910250159247, 0.008661569911055267, 0.1468946619757584, 0.04476548272318073, 0.0867226447111794, 0.1799579770969493, 32.00100210734776, 61.22877665928432, 52.8375449180603, 23.743804591042654, 24.35817473275321, 44.08504853929792, 35.37065955570766, 49.41404240471976, 11.988892589296613, 0.41501614611063686, 0.15208776188748224, 0.01589940202289394, 0.0312352637494249, 0.025870211189612746, 0.04101162004683699, 0.08070504332759551, 0.03681303194857069, 0.02149062217878444, 0.0400501732448382, 0.08203938244176762, 0.027992538109953915, 0.050588846672326326, 0.040193096468491216, 0.010113641636313071, 0.027315458548920493, 0.0376283290929028, 0.060120075408901484, 0.011086452203536672, 0.014892177855862039, 0.04591110089261617, 0.03604443158422198, 0.015736073554892625, 0.011151238727117223, 0.03478427670363869, 0.03501361136191657, 0.050280415186924596, 0.050135748128273656, 0.04138015277151551, 1.501086326582091, 60.46355070386614, 57.27321931294033, 57.48967654364449, 36.185415744781494, 26.247150216783794, 49.83719464710781, 23.51396860395159, 2.114749380520412, 0.04956144965919001, 0.024383988796866367, 0.3750286932502474, 1.4450476935931613, 0.8205646659646715, 1.083626070192882, 0.9985296364341463, 0.037895912770181894, 0.3283506136919771, 0.2454931012221745, 5.788572473185403, 77.19913469042096, 79.24745668683732, 76.45678220476422, 82.72753143310547, 88.96102442060197, 82.54149341583252, 79.57622459956578, 78.04289613451276, 81.9118824005127, 79.74419035230363, 81.90493420192173, 76.89457430158342, 79.79432160513741, 77.10392352512905, 80.1917724609375, 72.32525825500488, 70.10849802834647, 79.58629948752267, 76.80648503984723, 82.01935018811906, 77.85362025669643, 74.12330613817487, 74.51214817592076, 73.27048424312046, 74.29167488643101, 72.37337453024728, 75.03866182054792, 74.78184945242745, 73.85199982779366, 77.22387722560337, 77.10354832240513, 74.8599055153983, 76.54807458605084, 70.87709386008126, 71.9725399017334, 72.07153783525739, 73.94746112823486, 72.70758983067104, 74.20518371037075, 71.93191378457206, 72.94346727643693, 70.59981904711042, 70.10865088871547, 68.54720306396484, 67.91632052830288, 67.14867659977504, 65.22045421600342, 61.96651554107666, 62.23825263977051, 62.068049567086355, 64.1728048324585, 65.93538911002022, 64.35520894186837, 61.26893029894148, 65.85143402644566, 62.89283548082624, 60.91717774527413, 59.54592296055385, 58.33198234013149, 61.910978589739116, 59.076141357421875, 61.48030144827706, 60.895193644932334, 61.264219420296804, 61.634162357875276, 62.351862634931294, 62.820907729012625, 61.80597741263253, 62.833581243242534, 60.6901662009103, 63.702773094177246, 63.77966185978481, 63.69172545841762, 63.81558404650007, 65.9461727142334, 65.23898506164551, 64.50351129259381, 63.372170857020784, 63.35548823220389, 64.60618482317243, 61.73108278002058, 66.29919678824288, 63.756614685058594, 60.60404327937535, 62.8077061516898, 63.66726085117885, 67.268296786717, 63.64453329358782, 60.329790932791575, 60.779492241995676, 63.848865917750764, 67.0789236341204, 66.11015714917863, 64.14203820909772, 64.53562586648124, 67.01522949763707, 69.53397233145577, 68.15856252397809, 66.4191643851144, 66.63517693110875, 68.9296875, 60.81980569022042, 61.13017477308001, 51.24773802076067, 33.6315393447876, 33.40169293539864, 8.35606517110552, 0.25039475677268846, 0.3565167651644775, 0.013275123733494962, 0.03270591037081821, 0.06502344086766243, 0.19001202045806817, 0.11400144201304231, 0.1116327101896916, 0.010719590371341577, 0.003720700549560466, 0.10553631053439208, 37.395385469709126, 67.45443207877022, 59.38997759137835, 26.316984823771886, 21.633707898003713, 50.53897312709263, 42.59975644520351, 58.619964327131, 15.60802858216422, 0.3074108330266816, 0.15626691335013934, 0.05068133778071829, 0.05697832935090576, 0.10488618577697448, 0.005414540239144117, 0.03873202736888613, 0.038670426567218134, 0.06092857702502182, 0.02609626852375056, 0.0064274479851259714, 0.03242438619158097, 0.043135628037686856, 0.08381845376321248, 0.08694166224449873, 0.10471501174782004, 0.09811297458197389, 0.18278906946735723, 0.060005084079291136, 0.0859681409118431, 0.17033115295427187, 0.14730007307870047, 0.17160245616521153, 0.1152666655502149, 0.13111990344311508, 0.12342908898634569, 0.1658511526350464, 0.19465180220348494, 0.31244607855166706, 2.035724478108542, 70.45624147142682, 64.41667965480259, 48.408297606876914, 44.05263866697039, 50.472388539995464, 59.683504240853445, 33.539215156010215, 4.418634372098105, 0.13949225204331533, 0.12664215586015157, 0.9852747534002576, 3.7481944390705655, 1.7969795976366316, 1.6956640056201389, 2.5847196706703732, 0.1930553178702082, 0.8345970415643283, 0.6473887413740158, 5.634180894919804, 84.42190524509975, 83.49580069950649, 82.89581680297852, 83.97534452165876, 94.86736147744315, 83.88236372811454, 83.47216987609863, 80.41362844194684, 86.18004962376186, 84.03960841042655, 88.90611975533622, 81.68915789467948, 82.85812977382115, 82.34877123151506, 84.54932131086076, 76.7514066696167, 73.97170339311872, 85.09114183698381, 80.53074032919747, 85.03961399623326, 83.50761958530971, 77.31567682538713, 77.98842920575822, 75.50729697091239, 78.30415534973145, 75.46511445726667, 78.23087269919259, 77.90771198272705, 77.24256787981305, 78.79179382324219, 83.37815380096436, 77.6818538393293, 80.73911680494035, 74.81222002846854, 77.55247143336705, 74.38047981262207, 76.41816411699567, 77.22453730446952, 78.53526633126395, 76.25645174298967, 78.18964903695243, 75.4647045135498, 73.82974474770683, 73.32378387451172, 70.15906701769147, 72.78822367531913, 71.62537315913609, 65.68141855512346, 65.38224302019391, 65.33825397491455, 66.46978201184953, 69.29563522338867, 66.93135084424699, 64.42211314610073, 67.91267272404262, 66.77774006979806, 64.08024787902832, 63.35896233149937, 60.20939949580601, 64.20775427137102, 63.0916998726981, 64.11340468270438, 63.63961396898542, 65.34683500017438, 65.53433908735002, 68.22563348497663, 65.7972936630249, 62.95869745526995, 66.32636424473354, 64.73070349012102, 67.84052262987409, 65.36239896501813, 68.83343410491943, 67.04767758505685, 69.93817683628627, 68.3241936819894, 66.98594978877476, 64.24191161564418, 67.3989507130214, 67.4981918334961, 65.74305602482387, 68.80507850646973, 64.09187916346959, 61.87782178606306, 65.60792745862688, 68.19681235722133, 70.01910945347377, 64.23857648032052, 62.02416474478585, 63.48295293535505, 66.29560456957135, 69.65075070517403, 68.3721501486642, 64.92874104636056, 68.20773492540631, 68.83924279894147, 75.19218226841518, 70.38159697396415, 68.38762378692627, 68.56427478790283, 70.35828576769147, 59.50203119005476, 54.59432397569929, 46.1347462790353, 37.19668436050415, 38.76651866095406, 7.178607370172228, 0.6945785177605492, 0.7715009387050356, 0.2233325953462294, 0.20637553025569233, 0.18616540543735027, 0.3046043579067503, 0.23013576386230333, 0.35976607937897953, 0.12341037499053137, 0.18224560362952097, 0.33815327339938706, 44.04737540653774, 77.48207228524345, 67.33857781546456, 37.486382552555625, 35.54162345613752, 62.349736486162456, 49.25598130907331, 70.48650782448905, 18.861126525061472, 0.6177719905972481, 0.34430468188864843, 0.13031982923192637, 0.16911642599318708, 0.21687108278274536, 0.1197746079415083, 0.17581101533557686, 0.13960697874426842, 0.2370203701513154, 0.13411037011870316, 0.2038160011704479, 0.0941714189414467, 0.20853055747491972, 0.1736038087734154], [0.013544704000066434, 0.02159668568388692, 0.03602859118421163, 0.07804376791630473, 0.09634178783744574, 0.04070091886179788, 0.010025200533813663, 0.038917308141078265, 0.0328611897171608, 0.021369844641802565, 0.05652674733261977, 0.06557656904416424, 0.06618393252470664, 0.02677962283736893, 0.12215758221490042, 5.4770647542817255, 57.00823933737618, 47.460156849452424, 32.73379387174334, 37.88470540727888, 29.983064583369664, 33.431170667920796, 5.807812469346183, 0.1505494144346033, 0.1758343840816191, 0.002600599325627887, 0.06481090334377118, 0.058197127522102425, 0.7415506743959018, 0.4558770092470305, 0.07917080101157938, 0.0780804291633623, 0.05229063964049731, 0.14071440217750414, 13.178207056862966, 81.50837966373989, 72.88647815159389, 75.82092475891113, 77.9251936503819, 79.17147118704659, 76.0127923148019, 77.73946135384696, 74.77571419307164, 77.24120603288922, 75.0658848626273, 74.89322212764195, 69.85140078408378, 75.20750304630825, 70.71538148607526, 74.57696792057583, 65.93600749969482, 72.98526763916016, 73.38009207589286, 76.99268981388637, 74.34973403385708, 74.364089012146, 72.8744091306414, 70.88671016693115, 72.2820474079677, 68.45789786747524, 73.68335315159389, 72.47046170915876, 74.57769053322929, 71.23896993909563, 74.22083800179618, 69.92852578844342, 69.00440147944859, 70.4455759865897, 70.02459853036063, 72.04109777723039, 71.03450529915946, 68.97386414664132, 69.41560282026018, 68.77449948447091, 68.55071190425328, 66.76930495670864, 67.59636987958635, 63.49723148345947, 64.92488479614258, 63.27338136945452, 58.17821175711495, 56.12308400017874, 60.16417367117745, 59.406319754464285, 63.09501416342599, 65.54228782653809, 66.36717101505825, 65.77820696149553, 65.90816606794084, 62.761319977896555, 61.71675559452602, 61.02891867501395, 57.27604028156826, 53.24154097693307, 55.77604232515608, 54.952642577035085, 57.699025767190115, 57.7768177986145, 57.948143005371094, 58.63271427154541, 57.52910757064819, 58.134080273764475, 59.72772257668631, 60.27162061418806, 58.245557171957834, 58.03086130959647, 61.048630714416504, 61.43753528594971, 60.943011147635325, 59.64611598423549, 62.5950356892177, 62.29479013170515, 62.74353953770229, 63.47234303610665, 61.769652230399, 60.056052752903526, 60.39575713021414, 63.219234057835166, 60.26479748317173, 56.48595714569092, 59.18290737697056, 60.26852866581508, 61.88206018720354, 59.56385626111712, 55.72649819510323, 60.196677344185964, 62.72175693511963, 61.749558040073936, 61.57761096954346, 62.80366924830845, 65.88573728288922, 67.06827204568046, 67.07533141544887, 66.25477695465088, 62.100601877485005, 65.1471507208688, 58.650425229753765, 48.91662434169224, 32.82183102199009, 15.902578353881836, 24.98857089451381, 19.748305525098527, 1.8308711733136858, 0.06172257156244346, 0.14539592739726814, 0.1221037201051201, 0.07929665568683829, 0.10694387714777674, 0.10828492697328329, 0.07582571157919508, 0.11894990290914263, 0.08062573615461588, 0.3275440255446093, 22.08882359095982, 49.79153803416661, 60.55902590070452, 46.66509532928467, 36.24916546685355, 35.2860061781747, 31.68021420070103, 52.672817025865825, 18.795507737568446, 0.1356176949505295, 0.04717411579830306, 0.01777461836380618, 0.03780838853812643, 0.04828398874295609, 0.024868087909583534, 0.02359003497154585, 0.03128911907385502, 0.04749643011018634, 0.034791872903172455, 0.04344191874510475, 0.036553906210299046, 0.06441645058138029, 0.03672891056963375, 0.01891601943810071, 0.03476410385753427, 0.03790903563744255, 0.020093542324112992, 0.04310980638755219, 0.029086363701415912, 0.02715688491506236, 0.01856575796513685, 0.036321385830108605, 0.03328538266941905, 0.06439076124557427, 0.08559535377259765, 0.08800246353660311, 0.13528301433793136, 0.17271224090031215, 8.725772738456726, 68.14309583391461, 56.84578698022025, 47.02426161084856, 28.507307154791697, 33.04847431182861, 44.119737420763286, 8.125860929489136, 0.20265031872051104, 0.10838820678847176, 0.014147737579021071, 0.10915140262139694, 0.10606324047382389, 0.8937523758837155, 0.3997131186936583, 0.29271601725901875, 0.21788091930959905, 0.1924250674034868, 0.22885800099798612, 18.830766371318273, 89.04764066423688, 75.60764285496303, 79.87278761182512, 80.79644639151437, 81.32706642150879, 75.9848883492606, 78.21982506343296, 80.17080279758999, 80.23267650604248, 78.94218063354492, 78.9561048235212, 74.01464326041085, 79.19230188642229, 76.34834861755371, 75.59749848502022, 70.21464565822056, 77.82203374590192, 75.71497862679618, 79.45229652949742, 76.8883695602417, 79.68976511274064, 74.8127828325544, 75.05719266619, 75.57290881020683, 73.86074760981968, 76.23054191044399, 76.89164216177804, 75.84042140415737, 73.12682328905377, 76.88664640699113, 72.42274842943463, 71.9493329184396, 72.26050799233573, 73.02644266401018, 75.46207809448242, 73.22382708958217, 74.15576812199184, 72.61150319235665, 70.04676328386579, 71.05623231615338, 69.34202834538051, 70.5191296168736, 66.38775157928467, 67.81506443023682, 64.11498887198312, 60.154849188668386, 58.743294852120535, 62.197473662240164, 62.36173602512905, 65.76723575592041, 68.47558103288922, 68.91749341147286, 67.99690573556083, 66.98174612862724, 65.336836542402, 62.697820390973774, 60.888592856270925, 58.64169134412493, 56.67283589499337, 58.146170139312744, 57.04997716631208, 60.16704327719552, 59.84145763942173, 59.616558347429546, 59.83470399039132, 60.00923579079764, 60.74343803950718, 62.89631652832031, 61.76275266919817, 62.48630332946777, 61.910103116716655, 62.45443194253104, 64.40691743578229, 63.22035966600691, 63.7587616784232, 65.53194195883614, 63.717058590480256, 63.82877172742571, 62.359262466430664, 64.45432499476841, 63.333559717450825, 61.54662895202637, 65.0786623273577, 63.805509158543174, 59.03068624223982, 60.61859975542341, 64.45465156010219, 66.32024982997349, 63.81904424939837, 59.45251832689558, 62.936817577907014, 65.53915418897355, 63.748221261160715, 63.874532563345774, 65.89056628090995, 64.90427643912179, 67.65099661690849, 67.66709559304374, 67.97859723227364, 64.52391815185547, 66.1065788269043, 62.739683287484304, 54.417791094098774, 50.204664025987896, 41.31307513373238, 32.83428566796439, 26.436721393040248, 4.6945147684642246, 0.07449154209877763, 0.15420318980302128, 0.42116646894386833, 0.22341817218278134, 0.08277291950902768, 0.03017427586019039, 0.07499025176678385, 0.06627638292099748, 0.15342975487666471, 0.27315078569310053, 22.211504459381104, 53.0153979573931, 63.84593377794538, 53.78693635123116, 30.75254283632551, 34.99375799724034, 40.89522784096854, 57.67019074303763, 24.071771723883494, 0.2332518680819443, 0.03687635622918606, 0.021710168969418322, 0.0637582376865404, 0.047232700511813164, 0.01725331517601652, 0.03949922316574624, 0.04415273506726537, 0.03817446157336235, 0.016937212852228965, 0.004586171965846526, 0.08701294234820775, 0.019988642506567494, 0.05603224118905408, 0.11174483810152326, 0.11920983610408646, 0.17067082758460725, 0.15608355961740017, 0.13199799561074801, 0.12117880902120046, 0.12728951898004326, 0.11093987843820027, 0.18323163714792046, 0.1405704306172473, 0.11345456992941243, 0.24180770612188748, 0.198128235659429, 0.2995638740914208, 0.2591011481625693, 11.443617071424212, 76.27312741960797, 62.659035546439036, 46.64166252953665, 49.7847809110369, 46.73822511945452, 55.23673357282366, 13.924899561064583, 0.623453825712204, 0.3282875099352428, 0.1324758878243821, 0.22346466540225915, 0.2540877786065851, 2.5892108125346045, 1.7797775949750627, 0.44814089579241617, 0.37627263792923515, 0.7297549673489162, 0.5145654571907861, 21.538934469223022, 91.3313467843192, 78.78057943071637, 83.84305082048688, 85.8343072618757, 83.40076323917934, 80.74887207576207, 81.57622882298061, 84.60080746241978, 85.83459213801792, 82.78590324946812, 83.07611560821533, 75.98290811266217, 84.12366771697998, 78.60566547938755, 79.97097260611397, 73.97974245888847, 79.94785594940186, 79.80488981519426, 84.63686166490827, 82.17952701023647, 80.76769474574498, 77.61616556985038, 79.8218503679548, 78.23770277840751, 75.93401363917759, 79.25780950273786, 78.38906928471157, 78.87068367004395, 75.9058803830828, 80.41323934282575, 75.31157316480363, 75.03900228227887, 75.46639292580741, 74.80800247192383, 78.53143787384033, 75.62693800245012, 75.8211748940604, 75.26431151798793, 74.80992017473493, 75.67526272365025, 70.55402347019741, 73.11733899797711, 67.81832313537598, 70.96014567783901, 68.07314831869942, 63.74522658756801, 62.903994287763325, 66.37730148860386, 65.52771745409284, 67.13168825422014, 69.16698932647705, 73.10235173361642, 69.9110302243914, 69.66801003047398, 67.15313039507184, 65.51372378213065, 65.25142928532192, 61.5757349559239, 58.18883555276053, 61.21721485682896, 60.80251857212612, 65.01266138894218, 64.13803604670933, 64.47099372318813, 64.82121767316545, 63.486204692295615, 64.23360851832798, 66.10615498679024, 65.16413906642369, 64.97273703983852, 65.39505549839565, 67.47384534563336, 67.93319770268032, 67.63623864310128, 67.21129376547677, 68.64859117780412, 66.92351327623639, 67.4034114565168, 64.69099453517369, 68.20999308994838, 66.0366313116891, 63.76457037244524, 68.66207763126918, 65.69728824070522, 61.526826586042134, 63.486934253147666, 65.46070207868303, 68.20345483507428, 65.5192198072161, 62.17867183685303, 65.12267221723283, 67.67908123561314, 64.89493806021554, 65.12286676679338, 67.41527203151158, 67.56784752437046, 70.57291562216622, 71.61616679600307, 70.35729912349156, 66.11600058419364, 68.96115589141846, 61.265720231192454, 53.075704847063335, 44.40177869796753, 42.11068664278303, 41.41140604019165, 28.197113513946533, 3.7123895032065253, 0.3218929687780993, 0.3366264339004244, 0.32701813376375605, 0.1932739554239171, 0.3199172376521996, 0.30759585595556665, 0.21962852696222918, 0.2089084471975054, 0.2677732871047088, 0.3692911368395601, 25.917833396366664, 66.01213891165597, 73.45065103258405, 60.78963661193848, 50.613947663988384, 51.29155683517456, 45.13804803575788, 71.38377039773124, 29.075311967304774, 0.2535625925021512, 0.2523823215493134, 0.08047871118677513, 0.1443626678415707, 0.13743391606424535, 0.07911395334771701, 0.13701147373233521, 0.11668360951755728, 0.09438099126730647, 0.09552827184753758, 0.13844715883689268, 0.1523139447505985, 0.19077545377824986, 0.14925945151065076], [0.048068184072950056, 0.055463852759982855, 0.044693632650056055, 0.027134311751329472, 0.03797053465885775, 0.04632828797080687, 0.018586429534479976, 0.01743092680616038, 0.009976796390089606, 0.04992515460721084, 0.04176230708669339, 0.042286024162811894, 0.06961755042097398, 0.04591731966606208, 0.01987970879833613, 27.154247965131486, 59.435870443071636, 37.924438680921284, 41.77348709106445, 33.076763902391704, 40.49178763798305, 28.921398946217128, 0.8992162655506815, 0.09985107595899276, 0.08151302247175149, 0.07526024763605424, 0.08469469353024449, 0.046461073881281276, 0.03864355658047965, 0.05302462114819458, 0.24802004705582345, 0.12812776757138117, 0.10134018891091857, 0.35688672959804535, 30.999926498958043, 85.5907381602696, 75.00645692007882, 78.60948004041398, 74.67855058397565, 76.2688820702689, 73.97934641156877, 76.28474480765206, 77.23065171922956, 73.42497049059186, 74.83620521000454, 75.14433697291783, 74.5538582120623, 77.36846923828125, 72.28424303872245, 66.20466654641288, 70.7434105191912, 74.46759632655552, 74.68062114715576, 76.48264339991978, 74.40201228005546, 76.92796039581299, 73.59224142347063, 74.58663286481584, 70.15414074489048, 72.75364249093192, 70.7703069959368, 73.81734916142055, 67.95363235473633, 71.7643301827567, 72.05626569475446, 70.31082957131522, 69.23632540021623, 75.73596913473946, 70.89095551627022, 72.79990359715053, 70.76464421408517, 70.17079557691301, 69.005005972726, 67.20877156938825, 65.08233097621373, 66.23349462236676, 64.54163605826241, 64.20635768345424, 58.35822568620954, 55.54379183905465, 53.843828201293945, 56.00754240580967, 55.53282758167812, 57.425846917288645, 61.96621676853725, 62.154401779174805, 62.699425424848286, 63.25258541107178, 65.03817517416817, 62.92050320761544, 61.74283913203648, 61.3352439062936, 58.05591998781477, 53.05431134360177, 55.20628309249878, 53.87987198148455, 53.093214307512554, 52.66197436196463, 54.751964705330984, 54.928622654506135, 56.86801426751273, 57.451117515563965, 56.76721327645438, 60.19862978799002, 57.84844330378941, 59.693537439618794, 57.81023168563843, 58.13881894520351, 60.53119141714913, 59.64125224522182, 58.79839406694685, 61.31799847739083, 59.182337624686106, 62.154846463884624, 60.07848153795515, 60.9353472845895, 60.60589844839913, 57.19025782176426, 61.204048020499094, 57.83426203046526, 58.70137637002127, 60.26334530966622, 61.00353690556118, 59.528079986572266, 57.09614447184971, 56.031152384621755, 60.20965657915388, 59.82656070164272, 61.662941796439036, 60.0666834967477, 65.12377003261021, 66.00176525115967, 69.21640491485596, 66.52055944715227, 66.2893511908395, 60.87517588479178, 66.4569000516619, 41.44851289476667, 41.97646829060146, 30.820325987679617, 21.649431671415055, 30.709179128919327, 16.879910230636597, 0.4956696682742664, 0.16464762150176934, 0.09278385554041181, 0.07895447047693388, 0.06702843720891646, 0.1657343903290374, 0.13162725764725888, 0.11113792245409318, 0.0926604096644691, 0.06632375145064932, 4.592573404312134, 8.78677705356053, 29.578700269971574, 57.723611967904226, 24.75620228903634, 28.888130971363612, 18.48051115444728, 47.63546337400164, 18.454121896198817, 0.11506649771971361, 0.03160745717052903, 0.02616579461443637, 0.06236391607671976, 0.006183590981111462, 0.029593819685812508, 0.016744922813294188, 0.08255837352148124, 0.03130659135058522, 0.04413589043542743, 0.0159475423861295, 0.08282777227993522, 0.08120636535542351, 0.01179741186621998, 0.05082596412726811, 0.0031927952160393553, 0.04348096165007778, 0.03031385051352637, 0.0463246069183307, 0.026074328093922565, 0.0649837940665228, 0.04819036787375808, 0.042115297966769764, 0.03564812981390527, 0.0478149887307414, 0.058002136913793426, 0.01572288792314274, 0.06317241090748991, 0.06713521147945098, 35.07708774294172, 66.62400422777448, 52.66157136644636, 44.53758471352713, 20.363179411206925, 51.96085248674665, 33.230322565351216, 0.6276800675051553, 0.26065656755651745, 0.3223017725561346, 0.015407365746796131, 0.0731365280225873, 0.039063305128365755, 0.01903535339183041, 0.09568260463752917, 0.24623715558222362, 0.13760926308376448, 0.2196214294859341, 0.6866059484226363, 38.52298082624163, 89.107957976205, 76.63324560437883, 81.78264590672084, 77.7372796194894, 76.14192458561489, 77.61106559208461, 79.7748874936785, 81.41652447836739, 77.43590150560651, 77.52412973131452, 79.4128029687064, 75.56949724469865, 79.92389856066022, 73.74522686004639, 70.79985768454415, 74.12148571014404, 77.7381203515189, 77.22887298039028, 77.9929038456508, 75.72813851492745, 78.79724815913609, 77.68141610281808, 76.4087701525007, 72.86111722673688, 73.97527476719448, 73.35432120731899, 74.01856204441616, 71.36813695090157, 73.853285244533, 72.69166455950055, 73.6449087687901, 72.38290051051548, 79.80798871176583, 73.46139989580426, 73.84261281149728, 73.54855809892926, 73.28126784733364, 74.1733262198312, 71.33031095777238, 68.94807938167027, 70.33336952754429, 66.24697412763322, 67.43803433009556, 58.68018436431885, 56.85023382731846, 54.36553021839687, 59.52791322980608, 58.786644663129536, 60.63200283050537, 65.08721555982316, 65.88648074013847, 64.15545518057687, 67.19941234588623, 65.55292551858085, 64.63684722355434, 64.69521903991699, 64.28813103267125, 60.756827218191965, 55.57420757838658, 57.881033829280305, 57.225881235940115, 55.632621083940776, 54.99403647014073, 57.32476452418736, 55.81736673627581, 56.7675051007952, 59.20681612832205, 56.66857317515782, 61.34582601274763, 60.639534677777974, 61.65746661594936, 59.501933915274485, 60.89037159511021, 61.506829670497346, 62.50330557141985, 61.655145917619976, 62.97339289528983, 62.354211126055034, 65.19077845982143, 64.12565435682023, 63.584493909563335, 62.436672346932546, 59.26552145821707, 62.86175618852888, 61.301857812064036, 60.453531401497976, 63.524690764290945, 64.01721382141113, 62.87030247279576, 59.748428208487375, 58.092335496629985, 62.590845925467356, 65.66600050245012, 64.78495502471924, 63.19378975459507, 66.20098400115967, 66.22198145730155, 69.9033316203526, 67.368211882455, 68.72499356951032, 61.88482557024275, 65.92291709354946, 49.99238266263689, 53.786522933415, 55.06816332680838, 37.93809189115252, 36.20899445669991, 23.36782714298793, 1.5004432925156184, 0.0851228152002607, 0.33174014038273264, 0.2263047280056136, 0.41346221949372974, 0.2224356263343777, 0.11402166235659804, 0.06283282448670693, 0.15929661292050565, 0.05054576648399234, 4.378512433597019, 6.552651107311249, 26.97870520183018, 69.72173350197929, 18.118925162724086, 24.391458341053553, 30.64307049342564, 52.08144889559065, 24.951976469584874, 0.12164946805153574, 0.07367098291537591, 0.06572058131652218, 0.01160491063326065, 0.030351441353559494, 0.04533514340541192, 0.04197814568345036, 0.0277032243487026, 0.053425964433699846, 0.03073768044954964, 0.02328416325950197, 0.04724072418840868, 0.04712370403909257, 0.04296884752277817, 0.15864627781723226, 0.19032585647489342, 0.12138720069612775, 0.14066340348550252, 0.12780127009110792, 0.10269874493990626, 0.15353458853704588, 0.08155069473598685, 0.10125331607248102, 0.10648832230695657, 0.1381511411496571, 0.15344510333878653, 0.08529021657471146, 0.17005010374954768, 0.09335957214768444, 42.37115376336234, 80.43649496350969, 54.582202843257356, 56.223937102726524, 49.573385443006245, 60.64380087171282, 42.65050956181118, 1.1867359259298869, 1.3262228582586562, 0.48341445731265204, 0.12515947542020253, 0.24316721888525145, 0.15961409945573124, 0.15834291838109493, 0.3475678653589317, 1.3148988144738334, 0.476651091660772, 0.45989067958933966, 0.8456527111785752, 41.520708152226035, 96.3373362677438, 82.19374997275216, 85.85857731955392, 80.81783294677734, 82.44686589922223, 81.31371198381696, 85.69975539616176, 85.3030479976109, 81.86919961656842, 80.48709869384766, 83.47593579973493, 78.92087050846645, 85.50438594818115, 79.92065375191825, 75.1301348549979, 76.51113796234131, 80.06332111358643, 80.04585334232875, 83.41233198983329, 76.71782602582658, 82.72145870753697, 81.41718455723354, 79.92628179277692, 75.14708151136125, 77.13775430406842, 77.0170293535505, 79.99577072688511, 72.72065244402204, 76.10619000026158, 76.89727715083531, 76.62176023210797, 75.0500568662371, 83.62012481689453, 75.60541943141392, 79.15467044285366, 76.10441820962089, 77.80695615495954, 76.39844512939453, 73.0684653690883, 73.11317007882255, 71.69672421046666, 70.64232117789132, 72.6057709285191, 64.19734586988176, 60.678785051618306, 59.21111011505127, 61.7229186466762, 63.48824051448277, 64.40695912497384, 69.53559820992606, 67.98290511540004, 67.32361139569963, 69.78310694013322, 70.55483640943254, 67.63395963396344, 68.6575265611921, 66.40580994742257, 64.60246753692627, 57.89938749585833, 59.69432258605957, 59.179634775434224, 59.30837794712612, 56.833294119153706, 59.83843517303467, 58.812651770455496, 62.16508116040911, 63.94251373835972, 60.71594401768276, 65.60509259360177, 63.40202726636614, 65.25078310285295, 63.06877776554653, 65.53857748849052, 65.77118928091866, 64.6950522831508, 64.2123053414481, 66.47994027818952, 65.92051996503557, 67.58199405670166, 67.40083367483956, 66.13029302869523, 65.60262598310197, 61.689560345241, 67.1713833127703, 62.594486781529014, 64.11423151833671, 66.20062964303153, 67.18687779562813, 63.237438338143484, 61.703262192862375, 59.972299167088096, 65.85874353136334, 67.25072479248047, 65.61739090510777, 65.34432670048305, 67.44204344068254, 69.91409437997001, 72.4243187223162, 71.2629759652274, 70.89524950299943, 65.03525693075997, 67.37107454027448, 50.077647481645855, 49.16832283564976, 52.22916064943586, 44.98804337637765, 44.42190762928554, 24.20621415546962, 1.0599478036165237, 0.7425673369850431, 0.41319759083645685, 0.27050306062613216, 0.3140092875276293, 0.3216852827795914, 0.5331475457974842, 0.25545195969087736, 0.26769723689981867, 0.2931734041443893, 6.725751578807831, 15.147651365825109, 40.7698198046003, 75.92227813175747, 40.34555237633841, 45.22818354197911, 29.455018860953196, 65.2507553100586, 28.689448969704763, 0.15850681172949926, 0.17705635779670306, 0.127900933314647, 0.2325596809387207, 0.12205829897097178, 0.12003511110586779, 0.12790961856288569, 0.13829182860042366, 0.106575154433293, 0.09411417772727353, 0.07756907160260848, 0.2446119285055569, 0.21176370898527758, 0.2123779731669596], [0.0975087730746184, 0.06965301744639874, 0.09523300054882254, 0.0347629842747535, 0.028457648420174207, 0.01126192560020302, 0.023443798800664287, 0.051181876100599766, 0.03373164836583393, 0.03618876276803868, 0.03943310671352914, 0.07726883342755692, 0.06059566738882235, 0.06552067132932798, 1.5514450243541171, 43.54856422969273, 50.47780466079712, 30.451821327209473, 36.99815000806536, 35.26265328271048, 44.13152503967285, 16.656223399298533, 0.09022269118577242, 0.07651998182492596, 0.32319301473242895, 0.07504909432360105, 0.075935702105718, 0.05409829764227782, 0.09488044732383319, 0.09996190786893878, 0.11041298921086959, 0.1663565526583365, 0.09656902921519109, 2.0315192980425696, 59.28178024291992, 77.31863675798688, 70.83973339625767, 78.22138840811593, 71.88971042633057, 72.37755039760044, 72.64734200068882, 77.06600025721959, 77.57672759464809, 72.07182271139962, 75.66256141662598, 73.4174108505249, 73.96877125331334, 71.05291107722691, 68.10143443516323, 70.60371003832135, 74.95319202968052, 70.83053398132324, 73.39652456556047, 69.17634854997907, 71.0181770324707, 73.66266141619, 74.44084576198033, 70.88784272330147, 69.32900047302246, 68.73537417820522, 71.38485431671143, 68.19885512760708, 71.44909041268485, 67.89269665309361, 66.77466201782227, 70.28368295942033, 69.652314049857, 69.90258816310337, 66.95446055276054, 71.26668630327497, 71.00133459908622, 69.93710681370327, 70.48468044825962, 67.58038902282715, 63.43562180655343, 62.99872602735247, 57.714596680232454, 56.339113916669575, 51.25668382644653, 51.62848193304879, 49.46390962600708, 55.21513509750366, 57.9969436781747, 61.26617881229946, 62.515854018075125, 65.43935026441301, 62.17914431435721, 61.240852628435405, 62.54897608075823, 63.19127450670515, 61.11239433288574, 60.172136306762695, 60.242556299482075, 54.49712562561035, 51.775887966156006, 53.12512738364083, 51.568505082811626, 51.053924969264436, 52.99252448763166, 53.069951738630024, 53.504756110055105, 53.96371241978237, 56.744197368621826, 58.1427446774074, 59.7921393258231, 57.883573395865305, 58.074634960719514, 59.44580636705671, 60.51856654030936, 58.97736576625279, 58.975941385541645, 60.15521049499512, 60.5321363721575, 60.264644622802734, 60.22827775137765, 59.57657841273716, 62.20659664699009, 58.89254910605294, 55.467674323490684, 60.52534103393555, 58.847038405282156, 57.83447395052229, 61.24259662628174, 58.780349595206125, 60.31494263240269, 59.67012895856585, 55.61608437129429, 60.97217273712158, 62.73167896270752, 59.01906190599714, 59.844229970659526, 65.25693225860596, 65.5866312299456, 66.47231115613664, 65.64393997192383, 60.36977086748396, 58.659325872148784, 50.33247266496931, 45.562082699366975, 41.73831530979702, 24.428480080195836, 25.73859419141497, 31.606163774217876, 10.222264460154943, 0.29524062893220354, 0.7010159151894706, 1.258950942328998, 0.24151286908558436, 0.07825300097465515, 0.34410918237907545, 0.03794765106535383, 0.09206634547029223, 0.06208988292408841, 0.42048185425145285, 0.4010820766644818, 0.4402518405445984, 50.386630398886545, 39.5928818157741, 25.810806819370814, 31.562570776258195, 43.89474432809012, 28.66750134740557, 0.06501187863094465, 0.04327681760436722, 0.03989799141085573, 0.07124538985746247, 0.04206641630402633, 0.03460086190274783, 0.04370471875050238, 0.031405352122549496, 0.0728771783677595, 0.028029302833601832, 0.03052441350051335, 0.04373143945953675, 0.009237169471037174, 0.05196156711982829, 0.04551964046965752, 0.1066045757117016, 0.02200583551478173, 0.03475231431158526, 0.06430506905806915, 0.019337328616529703, 0.04558840999379754, 0.04068890539929271, 0.052671952572252066, 0.013104078625994069, 0.02451905288866588, 0.10426012187131814, 0.08250949864408799, 0.06731389010591166, 1.9304870622498649, 53.857992104121614, 61.997268268040244, 51.12123564311436, 22.025527238845825, 30.227335453033447, 56.06277016230992, 17.711003371647426, 0.20110973210207053, 0.22743818004216465, 0.32578366143362864, 0.01230836400230016, 0.05516947712749243, 0.03775974436263953, 0.02392803701306028, 0.30273238835590227, 0.4010557495057583, 0.48084997492177145, 0.1451796240040234, 4.579488209315708, 67.27105522155762, 77.3090899331229, 72.95138822283063, 82.55758544376918, 74.26818302699498, 76.26774256569999, 78.70019572121757, 81.31825610569545, 78.5715081351144, 74.7722748347691, 81.0204632622855, 75.50116865975517, 76.84643718174526, 74.91899994441441, 70.60286930629185, 76.63332898276192, 79.51596287318638, 75.15212590353829, 76.10411943708147, 72.08617074148995, 73.68074757712228, 74.7847260066441, 76.20677212306431, 74.30519608088902, 73.02340630122593, 69.83107730320522, 72.684556552342, 70.01596886771065, 74.21703733716691, 71.08369854518345, 73.52034146445138, 73.92939581189836, 73.29256561824253, 71.28367464882987, 72.15580558776855, 73.02356610979352, 72.17373888833183, 73.98031221117292, 73.88593482971191, 68.8288482938494, 66.06390299115861, 61.428683280944824, 58.47286401476179, 55.83375058855329, 54.56108031954084, 53.322445801326204, 52.86300311769758, 54.962797369275776, 60.2376161302839, 64.47737216949463, 65.77347523825509, 66.8504112788609, 64.85775824955532, 62.464333125523154, 64.20103536333356, 65.2169314793178, 61.96578598022461, 62.93650490897042, 62.08639281136649, 58.14767789840698, 54.231433459690635, 53.298377241407124, 53.137849535260884, 52.50011607578823, 52.520547253744944, 55.8826242174421, 54.71504545211792, 56.67637252807617, 58.35443196977888, 60.650186266217915, 62.050394194466726, 60.147900990077424, 60.00251688276018, 62.51645156315395, 61.97736167907715, 62.67044448852539, 62.17550345829555, 63.53746850149972, 62.29480402810233, 63.22163813454764, 64.99524225507463, 63.00568812234061, 62.47135080610003, 61.05860832759312, 58.89161804744175, 62.811791692461284, 61.39029448372977, 59.59640857151577, 64.02142442975725, 63.510189873831614, 62.57596288408552, 61.79164327893938, 59.97993523733956, 63.03573908124651, 64.45486000605992, 62.98447527204241, 61.33710602351597, 66.89879158564976, 64.27114268711635, 67.46401364462716, 66.6765604019165, 64.81469331468854, 60.42744091578892, 58.59789684840611, 51.12182623999459, 56.99579858779907, 48.3037028993879, 37.52547311782837, 36.51919330869402, 17.026034321103776, 0.7676484340003559, 0.7677763242806707, 0.8687867926699775, 0.35536241424935205, 0.06876806528972727, 0.24022058557186807, 0.09487581292965583, 0.09518638519304139, 0.10509469958820514, 0.24850891796605928, 0.3609292512493474, 0.43931915344936506, 52.87658337184361, 47.418217522757395, 19.484444209507533, 32.58465426308768, 52.37050090517317, 36.289440699986045, 0.08347016852349043, 0.025092460780537555, 0.0632315588050655, 0.03576138409386788, 0.01194540798730616, 0.04353665580440845, 0.058640509444688044, 0.014579028855743153, 0.007830544324990894, 0.03539030007751925, 0.031778753335986815, 0.06582453966672931, 0.03168362272637231, 0.03791112552529999, 0.1706222987600735, 0.1406373477407864, 0.31896861855472836, 0.16261224714773043, 0.0977873524118747, 0.07743535270648343, 0.16039801096277578, 0.25473773373024805, 0.21497748153550283, 0.19705628603696823, 0.09497669751622848, 0.1413240251796586, 0.18817196919449738, 0.24766104774815695, 2.4640320667198727, 64.35580648694719, 67.14143657684326, 44.68800279072353, 51.77276127679007, 52.42797987801688, 64.35098443712506, 26.78448220661708, 0.3165153887655054, 0.7626541991318975, 0.6006775764482362, 0.23615759930440358, 0.14795385513986858, 0.22070420852729253, 0.17648575055812085, 0.2714983086500849, 0.5182430084262575, 0.5905631706118584, 0.4765896978122847, 4.496388622692653, 71.38073403494698, 81.13895089285714, 78.20485864366803, 85.89090033939907, 79.72603470938546, 79.81294277736119, 81.11550767081124, 83.40373011997768, 85.1713935307094, 78.80481474740165, 83.35528727940151, 78.51540143149239, 82.08663654327393, 78.66553810664585, 74.0361270904541, 78.63966301509312, 82.35594177246094, 77.64902360098702, 80.75222110748291, 74.23932715824672, 77.03469167436872, 78.45723806108747, 79.74053559984479, 80.0998477935791, 75.9545316696167, 71.38521562303815, 76.04078660692487, 72.25692967006138, 77.75247532980782, 74.40401336124965, 75.19644846235002, 76.3120790209089, 75.21398571559361, 76.80852086203438, 73.88884612492153, 75.70256914411272, 76.42584882463727, 76.10425840105329, 77.55020632062639, 73.61998558044434, 71.8727776663644, 67.30924252101353, 63.40832233428955, 63.16806752341134, 56.66321611404419, 58.054262842450825, 55.01590245110648, 60.16927364894322, 63.7365482875279, 68.16193240029472, 67.36046464102608, 69.21481377737862, 65.67236505235944, 65.8098976952689, 65.61602905818394, 69.24102238246373, 64.52782998766217, 63.18559088025774, 62.37458324432373, 59.63887596130371, 56.9907785143171, 55.93030970437186, 56.33342681612287, 55.937931878226145, 55.195072174072266, 58.00022322790963, 57.72900377001081, 59.269877978733604, 63.82383850642613, 64.865067754473, 66.45086901528495, 62.931606428963796, 61.306950841631206, 65.58319187164307, 66.45269639151437, 65.71948078700474, 64.89462539127895, 66.64222935267857, 65.84799466814313, 64.97398771558488, 66.59226485661098, 64.70055525643485, 66.6885599408831, 64.76335307529995, 61.255680084228516, 67.63177095140729, 63.718184198652, 62.3126608984811, 65.96862234388078, 66.39080878666469, 64.08392347608293, 63.37485980987549, 62.674272945949006, 66.59988703046525, 68.21785845075334, 64.70054830823625, 64.30083233969552, 69.56132738930839, 69.59570012773786, 70.59473991394043, 71.69877392905099, 66.7581878389631, 64.3904641015189, 58.03476619720459, 54.801522731781006, 53.23981087548392, 52.1933148929051, 46.38229669843401, 46.666474546704976, 15.551133258002144, 0.625440847660814, 3.722985940320151, 2.2626469986779347, 0.2651556618511677, 0.20399646434400762, 0.9513097873755864, 0.16116779537073203, 0.21393506175705365, 0.26970814328108517, 0.4392400091247899, 0.7111616422023092, 0.8357705814497811, 67.09086063929966, 55.43404156821114, 42.51530456542969, 47.664169856480186, 62.42480482373919, 41.605517864227295, 0.23994700025234902, 0.21591155284217425, 0.10419294011912175, 0.15737796016037464, 0.14671274673725876, 0.15625665390065738, 0.13779431315405027, 0.17925394273230008, 0.18667698012931006, 0.1380433083644935, 0.12753282806703023, 0.18443211487361363, 0.09060382430574723, 0.1336937224758523], [0.16520467161067895, 0.08697247451969556, 0.016291788646153042, 0.05553664599678346, 0.08564094454050064, 0.05322225804307631, 0.049422950483858585, 0.06637375269617353, 0.06584007811865636, 0.07963625567832164, 0.06716961320489645, 0.03542934298249228, 0.05405110892440591, 0.2309308983385563, 5.901248804160526, 54.47625323704311, 38.67757477079119, 28.818979024887085, 40.327428000313894, 35.060353006635395, 32.1074971471514, 0.9654569711003984, 0.0856547730841807, 0.051917231641709805, 0.2813585081270763, 0.05447117977642587, 0.007737657969950565, 0.0965870443199362, 0.054259086692971845, 0.21219019538589887, 1.1971872108323234, 3.084672523396356, 0.22967346438339778, 14.98269418307713, 74.91089834485734, 75.21014336177281, 72.13192462921143, 70.50111293792725, 73.29389967237199, 77.17449637821743, 76.89979934692383, 76.66689573015485, 72.96413816724504, 74.53989928109306, 73.27784933362688, 73.00316619873047, 71.87626566205705, 74.59848649161202, 67.59311812264579, 73.78720787593296, 74.82936818259103, 72.02021149226597, 71.86660766601562, 72.34663786206926, 68.7767368044172, 67.53204345703125, 70.33471747807094, 68.94124930245536, 68.36343015943254, 68.12801129477364, 68.31607818603516, 70.76751382010323, 69.11956092289516, 65.78878211975098, 70.67557525634766, 69.57820456368583, 69.44309684208461, 69.01713752746582, 69.22206769670758, 68.96375451769147, 68.81568145751953, 69.55328832353864, 66.73537690298897, 58.34476702553885, 55.08665943145752, 53.1711140360151, 51.381813934871126, 50.576073033469065, 50.10268531526838, 48.80978536605835, 50.963549750191824, 49.973313331604004, 57.132445335388184, 61.437618664332796, 63.16082055228097, 63.68433257511684, 61.09862995147705, 62.741663524082725, 63.42158644539969, 61.68983827318464, 62.129937171936035, 60.1064132962908, 59.656156131199424, 56.70962313243321, 53.17092990875244, 50.258474349975586, 48.023273604256765, 48.50446762357439, 49.09369223458426, 50.50683423451015, 52.87473862511771, 55.34748785836356, 55.52261025565011, 54.63112163543701, 56.898763520377024, 56.24715798241751, 56.229700633457725, 58.330537114824565, 59.51835945674351, 60.00553934914725, 61.51124177660261, 59.5929205758231, 59.645052909851074, 59.409724371773855, 60.75001103537423, 61.60199219839913, 58.35697501046317, 59.09864657265799, 56.41925096511841, 59.548375674656455, 57.313425064086914, 59.144032205854145, 57.12684856142317, 58.81065763745989, 56.99180684770857, 60.24763543265206, 56.068161964416504, 56.16199391228812, 59.91906901768276, 61.997733797345845, 57.114463397434776, 61.59473133087158, 58.08297627312796, 63.97815104893276, 63.2092217036656, 64.82605361938477, 58.3757073538644, 57.33825445175171, 46.45643745149885, 45.31101649148123, 29.277381215776714, 25.896657024111065, 32.120684828077046, 29.599228722708567, 6.713260889053345, 1.2189559170178004, 0.18455516041389533, 1.6763162038155963, 0.23934448829719, 0.18848729798836367, 0.11842726809637887, 0.2066497126860278, 0.06026325986853667, 0.148056259644883, 0.3823321456355708, 0.4448903873562813, 11.958657503128052, 46.822343485695974, 39.918589047023225, 36.3385123525347, 32.621156624385286, 41.124827589307515, 0.09083411230572633, 0.04748187892671142, 0.06267258844205312, 0.1276861634105444, 0.08826430341494934, 0.05253707677392023, 0.11993974979434695, 0.053302996924945285, 0.04611104141388621, 0.05801718682050705, 0.0792445849095072, 0.07383347169629165, 0.02664137980900705, 0.05134362527834518, 0.0441196904118572, 0.020346123592129776, 0.039210981489824395, 0.04868982393028481, 0.02648379683627614, 0.05828347788857562, 0.0664140305348805, 0.018287796094747524, 0.023052628451426114, 0.07005959562957287, 0.04277358889313681, 0.03954803018963762, 0.10972018460077898, 0.3026368234838758, 8.940583246094839, 63.14092091151646, 54.62623010362898, 41.13937364305769, 30.871176379067556, 42.13583564758301, 37.233356952667236, 0.7278388387390545, 0.28657953654016766, 0.024573004904336164, 0.20125469432345458, 0.03266453669805612, 0.008728630375117064, 0.16462658691619123, 0.25242458071027485, 0.11330407086227622, 5.403304415089743, 6.696602148669107, 0.3444657661020756, 22.147047758102417, 77.76759460994175, 73.0800758089338, 73.00636237008231, 72.63481439862932, 74.32016250065395, 79.34817082541329, 79.92958913530622, 79.47447517939976, 75.61698818206787, 76.90910993303571, 76.7540261404855, 74.10335091182164, 74.38396780831474, 76.32846982138497, 71.16852910178048, 77.44284275599888, 76.32094492231096, 77.3306154523577, 72.97251074654716, 74.73362200600761, 73.35680171421596, 71.17725603921073, 70.65626621246338, 72.83809784480503, 69.95765263693673, 70.00335788726807, 70.36262839181083, 73.2042053767613, 72.60151168278286, 71.56459726606096, 74.6093395778111, 71.80435180664062, 73.31295163290841, 72.64456966945103, 71.75624942779541, 74.14375468662807, 71.36287716456822, 69.84450817108154, 68.34872777121407, 59.308322361537385, 55.81732504708426, 54.40855346407209, 54.716052940913606, 53.92084550857544, 53.14833089283535, 51.84885447365897, 52.50126600265503, 53.101190839494976, 58.43762969970703, 64.10790865761894, 63.37629113878523, 66.30991785866874, 65.37318951742989, 63.60566507066999, 66.05798312595913, 64.0223137991769, 64.14655453818185, 61.45022964477539, 60.5702611378261, 59.72333131517683, 55.76950407028198, 51.64864560535976, 48.647308690207346, 49.37185294287545, 50.21554837908064, 51.49214090619768, 52.65246227809361, 56.31554215294974, 55.340942655290874, 55.7111530985151, 59.10096032278878, 59.11842114584786, 58.93444674355643, 59.586347579956055, 61.6605863571167, 60.11550848824637, 62.68802343096052, 60.76417146410261, 61.45522539956229, 62.16459478650774, 62.003340993608745, 64.49478435516357, 63.1411988394601, 62.60060119628906, 59.398558616638184, 61.422888483319966, 60.87523147038051, 60.16662638528006, 59.38535703931536, 62.794316973005024, 60.953440393720356, 61.43605531964983, 59.85399218967983, 58.2682569367545, 63.07626792362758, 64.82189164842877, 63.07768535614014, 65.50234263283866, 59.22206047603062, 64.40012209756034, 65.56058938162667, 67.27330643790108, 62.43010629926409, 59.87298856462751, 54.35624047688076, 54.83781664712088, 50.71441166741507, 46.35108539036342, 41.76444401059832, 36.64897176197597, 12.53363743850163, 1.4675666966608591, 0.6048493725912911, 1.3879868068865366, 0.4535231169845377, 0.09782653102385146, 0.10278774837830237, 0.11880309507250786, 0.18836064264178276, 0.10232583566435746, 0.4337462910584041, 0.341750540371452, 10.194940669195992, 52.40166704995291, 33.90881415775844, 47.38844796589443, 40.75879648753575, 47.23784228733608, 0.1949757891041892, 0.05509229037644608, 0.08675737213343382, 0.07877234489257846, 0.09852058413837637, 0.03088942462844508, 0.07975091452577285, 0.056582193821668625, 0.06228927043931825, 0.01584722607263497, 0.05273281716342483, 0.052168326918035746, 0.05751860607415438, 0.031055665708013942, 0.201844775517072, 0.16454589553177357, 0.1631170500602041, 0.16172593113567146, 0.14647656226796762, 0.132105841966612, 0.1508632775928293, 0.25979048545871464, 0.09861731609063489, 0.11057691648602486, 0.12123719017420496, 0.11804511717387609, 0.16638287981706007, 0.5779770516923496, 11.067330428532191, 75.04894515446254, 54.60893951143537, 40.48386321749006, 59.905033656529014, 51.231750215802876, 49.987247943878174, 2.0470724063260213, 0.36642926612070625, 0.10104385231222425, 0.7128198732222829, 0.17258870681481703, 0.14469977760953562, 0.3064355067908764, 0.2222831595156874, 0.7542451417871884, 5.308072405202048, 8.56414200578417, 0.40863026306033134, 24.122941732406616, 87.65749372754777, 77.99273708888462, 78.81736319405692, 79.70914363861084, 79.49222087860107, 85.79355607713971, 83.44188267844063, 85.89749417986188, 80.1664810180664, 83.41364519936698, 81.70640332358224, 79.0214456830706, 76.57821587153843, 83.68168585641044, 75.57304777417863, 80.66386086600167, 80.08077498844692, 78.67809350149972, 76.10443210601807, 78.50180380684989, 76.36183507101876, 74.0261425290789, 74.63431140354702, 74.62914194379533, 72.73495878492082, 73.50192178998674, 74.03810037885393, 76.89875016893659, 76.45920712607247, 72.13088239942277, 75.43614046914237, 73.94878128596714, 77.37517424992153, 75.35458946228027, 76.0931065423148, 76.32273755754743, 75.29613426753453, 73.66261277879987, 73.5264697756086, 62.85876151493618, 59.8022072655814, 58.92776952471052, 58.342043331691194, 56.95955678394863, 55.64467968259539, 55.15205240249634, 56.31312070574079, 55.71844175883702, 62.800354957580566, 67.90772560664585, 69.89935725075858, 70.8264136995588, 66.55974728720528, 68.28101757594517, 69.91008526938302, 67.40667016165597, 67.51115717206682, 63.2231319972447, 62.77005386352539, 62.68883637019566, 57.94885172162737, 54.957092898232595, 50.78420979636056, 53.19070795604161, 53.452731473105295, 56.85255799974714, 57.75008807863508, 60.217883246285574, 59.982547760009766, 59.12655748639788, 63.44937229156494, 62.644354002816335, 63.953484943934846, 62.939784458705354, 64.60330132075718, 65.24748965672084, 66.96454238891602, 64.57485539572579, 63.301591055733816, 65.09259346553257, 65.62893881116594, 68.71899032592773, 63.24597767421177, 64.89679322923932, 61.771965980529785, 63.906542914254324, 64.66470255170549, 64.31458977290562, 61.74627849033901, 63.62061759403774, 61.56018488747733, 65.02387578146798, 61.33968380519322, 62.583453042166575, 67.29270580836705, 67.32523727416992, 64.87123080662319, 67.44813701084682, 61.423180307660786, 66.47765432085309, 67.44792856488908, 68.74029350280762, 64.87822764260429, 60.5601931980678, 54.45990065165928, 54.319286482674734, 48.77981778553554, 51.98092583247593, 50.95754303250994, 46.08545575823103, 11.416023169245038, 3.7216536232403348, 2.06873602100781, 5.3404592616217474, 1.5422718822956085, 0.4646581751959664, 0.371492792985269, 0.382093355591808, 0.40403617386307034, 0.3045345502240317, 0.6601609417370388, 0.5034980624914169, 18.26977402823312, 65.1480609348842, 57.836513246808735, 55.79864134107317, 45.69901779719761, 59.42414883204869, 0.14414812863937446, 0.12536288664809295, 0.12593566519873484, 0.219344275072217, 0.22061150707304478, 0.12375467722969395, 0.21005586348474026, 0.17125910387507506, 0.15849362100873673, 0.11312784853258304, 0.16466211500976766, 0.14290270475404604, 0.15702366988573754, 0.1260081191680261], [0.08531125116028956, 0.030860851518809795, 0.05868612735399178, 0.0653131753206253, 0.05639912846631237, 0.022971711454114745, 0.029738395142235925, 0.07323891895690135, 0.032463646227759976, 0.032119944492088895, 0.04094030262370195, 0.08393179625272751, 0.03320410095953515, 0.13309707306325436, 18.25491530554635, 56.86436298915318, 27.39095398357936, 51.70852518081665, 18.081225974219187, 41.96219321659633, 12.096536687442235, 0.5075713353497642, 0.3175312371126243, 0.05684584878118975, 0.11937415014420237, 0.2602125070989132, 0.05436795763671398, 0.0853203706709402, 0.04655282538650291, 0.10862274920301777, 2.4509896465710233, 2.721060697521482, 0.38354069792798584, 39.0115955216544, 76.88473565237862, 69.27883447919572, 70.79848888942173, 73.28162220546177, 71.47666781289237, 73.90601512363979, 77.40874794551304, 69.82139846256801, 70.34531348092216, 70.03311702183315, 68.8724343436105, 67.9814043045044, 70.19959586007255, 68.41800131116594, 68.78245517185756, 75.11450140816825, 73.10423469543457, 70.76998043060303, 69.8551458631243, 73.37155273982457, 70.39203316824776, 67.64798109872001, 62.96644469669887, 69.32324736458915, 66.1462321962629, 69.70168100084577, 68.2719293321882, 68.74770723070417, 68.34473255702427, 70.9071100779942, 68.79879038674491, 69.74924142020089, 67.5222395488194, 69.77085726601737, 67.30500411987305, 69.1205336706979, 64.32807622637067, 63.241718428475515, 55.64523206438337, 51.398166520254954, 50.98792403084891, 51.478584970746724, 49.342507226126536, 49.90491873877389, 50.14275905064174, 48.746007851191926, 47.5741594178336, 50.340546471732004, 55.72087710244315, 61.156807218279155, 61.013695171901155, 61.7631139755249, 61.64336177280971, 60.62793813432966, 59.756710461207796, 59.44167913709368, 60.41271768297468, 58.994951656886506, 58.00034482138497, 57.98092113222395, 54.36670446395874, 47.164090633392334, 45.73399155480521, 48.1701203073774, 45.42228841781616, 47.18976075308663, 47.95247493471418, 48.40590047836304, 51.58536488669259, 53.3651841708592, 56.872659138270784, 56.991452489580425, 55.32080330167498, 56.30831602641514, 60.169544628688264, 60.33359159742083, 57.64729642868042, 59.64478887830462, 61.27734456743513, 61.03656169346401, 59.902643476213726, 62.14243003300258, 62.27617590767996, 60.15735748835972, 56.21302148274013, 56.81401286806379, 55.61020966938564, 57.9844126020159, 58.19505419049944, 54.31924826758248, 61.0879088810512, 55.901658807482036, 58.87360136849539, 55.09696013586861, 58.02255821228027, 58.481194904872346, 56.956020150865825, 59.812963077000205, 59.417812074933735, 60.99662344796317, 65.26317868913922, 66.93085752214704, 62.92455400739397, 57.98832791192191, 51.75748218808855, 43.891652379717144, 40.10309498650687, 25.39573359489441, 31.7181305204119, 36.29946000235421, 23.194884743009293, 1.555219633238656, 0.7019940369895526, 1.6535106961216246, 0.11057811070765768, 0.05255518348089286, 0.13733738767249243, 0.0442610089001911, 0.0647133503641401, 0.11540510026471955, 0.11258397557373558, 0.34544356220534866, 0.8174798286386898, 39.54954937526158, 30.195738519941056, 17.673128741128103, 24.237131902149745, 44.8567293712071, 1.4971553832292557, 0.1282867890383516, 0.0800793661868998, 0.07571888302585908, 0.04990958562120795, 0.05444092729261943, 0.040113921609840224, 0.04893479882074254, 0.051978255688611946, 0.03829797530280692, 0.032530444607670815, 0.0174207759222814, 0.033080712759069035, 0.014350287915606583, 0.03989471747939076, 0.017056570554684316, 0.03930474824405142, 0.08026540691831283, 0.06009511210556541, 0.005268725184058505, 0.0342088959712003, 0.027294524047257643, 0.029988068887697797, 0.017974896456247995, 0.06061035767197609, 0.0827316442238433, 0.01964316300914756, 0.19118360616266727, 23.379338571003505, 64.136597769601, 39.032978602818076, 40.385671275002615, 16.4162552016122, 53.36459009987967, 13.280061568532672, 0.29200257839901106, 0.05756597460380622, 0.08071743337703602, 0.06845190868313823, 0.37079517756189617, 0.09724317411226885, 0.07389055006206036, 0.2857639917305538, 0.49866852164268494, 4.14283127444131, 2.089564549071448, 0.34617719426751137, 47.40415436880929, 79.26543167659214, 72.08525357927594, 74.35762023925781, 77.19247831617082, 77.23782226017543, 79.30356339045933, 80.28570515768868, 77.74153191702706, 74.56418323516846, 75.9364733014788, 75.25515379224504, 72.88178811754499, 74.82381657191685, 70.6520278113229, 72.9722397668021, 77.4362211227417, 77.85898426600865, 72.92537416730607, 73.03175108773368, 74.96203013828823, 72.19469465528215, 69.4142757143293, 67.92786148616246, 71.71896539415631, 68.66006960187639, 71.28976127079555, 71.50621155330113, 71.54794243403843, 73.1222722189767, 73.85323660714286, 73.40777369907924, 72.52868066515241, 71.84976523263114, 72.01025472368512, 70.47853129250663, 70.0766544342041, 66.63365527561733, 62.56136471884591, 57.2920697757176, 54.56629146848406, 53.736019951956614, 53.91139595849173, 52.93365934916905, 52.11144774300711, 51.854760442461284, 52.63313238961356, 51.83468362263271, 53.6125921521868, 56.24430227279663, 63.54079668862479, 62.88631807054792, 62.81942081451416, 63.164669854300364, 63.639933586120605, 63.21338367462158, 62.38791683741978, 62.53362056187221, 62.619382177080425, 62.46759877886091, 58.972946711948936, 55.88802991594587, 50.01032985959734, 49.34678384235927, 49.647765908922466, 48.16891132082258, 48.90416622161865, 50.502019132886616, 49.04240410668509, 50.79222454343523, 54.25638096673148, 56.47077880586897, 58.168876852308, 58.96296909877232, 60.1791261945452, 62.03283609662737, 61.61176136561802, 60.371792793273926, 60.40146854945591, 63.20911748068673, 63.39280005863735, 62.12730380467006, 63.50870295933315, 64.46411500658307, 62.727600370134624, 60.96757302965437, 59.88210460117885, 60.26283809116909, 60.41135583605085, 62.556758063180105, 56.95395653588431, 63.17359134129116, 59.238520758492605, 61.95113917759487, 58.18922117778233, 60.29912158421108, 62.282429286411826, 60.97782857077462, 63.821649823869976, 61.389752524239675, 59.56029878343855, 64.24775505065918, 65.95536518096924, 65.32717854636056, 60.597678729466026, 56.0765380178179, 54.014437743595664, 55.818603515625, 50.92442791802542, 47.312733445848735, 42.523413113185335, 29.17572907039097, 4.591201135090419, 0.805872917175293, 1.6861033929245812, 1.3264536687305994, 0.034622086478131156, 0.09210734255611897, 0.049570436855512004, 0.12959921147142137, 0.05692952232701438, 0.06392424806420292, 0.43375725618430544, 0.6671382901923997, 44.32073490960257, 30.425185407911027, 20.721795048032487, 34.490565981183735, 51.73411539622715, 2.17692294716835, 0.2160908489355019, 0.02897220357720341, 0.04788651649973222, 0.04237429139071277, 0.020584479373480593, 0.05965888872742653, 0.02578866994008422, 0.0541902289592794, 0.045393449919564385, 0.04135680777419891, 0.036117553910506625, 0.014917478730369891, 0.06633317630205836, 0.13103497800018105, 0.13004737028053828, 0.15053023903497628, 0.17792066213275703, 0.14603556878864765, 0.14725850602345808, 0.07781998028180429, 0.20940844608204706, 0.09376822664801564, 0.1661349566919463, 0.14928109677774565, 0.26847595082862036, 0.15968151869518415, 0.32898840946810587, 28.89521987097604, 78.20654705592564, 40.88960327420916, 70.42401572636196, 28.169324193681987, 63.17592593601772, 20.934811183384486, 0.950196772813797, 0.31545415999633925, 0.18008902935045107, 0.18544554763606616, 0.5400747912270683, 0.25686950076903614, 0.22203558922878333, 0.32196554488369394, 0.8835296215755599, 6.413393574101584, 6.775572334017072, 0.4828181607382638, 54.50658212389265, 84.54440893445695, 74.07906695774624, 78.18623747144426, 85.19200188773019, 87.76896367754254, 84.81675052642822, 86.97663974761963, 81.26143373761857, 78.91708374023438, 81.78889233725411, 78.62628078460693, 76.29397201538086, 79.72316510336739, 74.81474917275565, 75.96584333692277, 80.43427153996059, 82.93492821284703, 75.94864654541016, 76.29743221827916, 78.26008292606899, 75.82461425236293, 72.44528838566372, 72.00703770773751, 77.05960791451591, 70.02380643572126, 73.82518672943115, 74.15511499132428, 75.0346805027553, 75.99781894683838, 77.00512014116559, 75.50683144160679, 77.45214639391217, 74.61777469090053, 76.26371261051723, 72.56078829084123, 72.30201653071812, 71.63086918422154, 68.9671104976109, 61.076499938964844, 57.85385595049177, 56.64387232916695, 56.42311416353498, 55.12597581318447, 54.75673811776297, 56.581970827920095, 55.50735201154436, 55.061718872615266, 55.68810592378889, 59.85044860839844, 66.51390307290214, 66.27402346474784, 65.25873184204102, 66.75377573285783, 66.58458709716797, 66.2401509966169, 64.87858200073242, 65.99288545336042, 64.71506309509277, 65.31174659729004, 61.75587395259312, 61.53386511121477, 51.64441762651716, 51.26457698004586, 53.17904193060738, 50.43518788473946, 51.06413882119315, 53.44725281851632, 53.65633453641619, 55.560922622680664, 60.04141984667097, 63.78676986694336, 63.06335817064558, 63.522564615522114, 62.625163078308105, 65.58286530630929, 64.84120069231305, 63.71626649584089, 65.59426035199846, 66.3139339174543, 67.45878165108817, 63.76388944898333, 67.150545665196, 68.12311976296562, 64.5793856212071, 62.26967934199742, 62.6331604548863, 61.82874665941511, 61.724398612976074, 66.06696019853864, 60.43595245906285, 65.43343039921352, 59.999362400599885, 63.64315060206822, 59.245121547154014, 65.48513889312744, 65.73566314152309, 63.581381116594585, 65.2555843080793, 62.016417503356934, 62.267052922930034, 66.97370706285749, 70.09588704790387, 67.1059799194336, 62.795234135219026, 58.47386455535889, 53.88655614852905, 55.787221976688926, 53.25892536980765, 54.00022520337786, 52.102686064583914, 35.69669335229056, 3.2441193503992896, 3.3836289729390825, 5.155845625059945, 1.1999287094388689, 0.13651960369731697, 0.4252858821834837, 0.2838590182363987, 0.26461006541337284, 0.2593654239816325, 0.16841754849467958, 0.7610710955091885, 1.5253276143755232, 55.565202713012695, 45.586623736790244, 28.032877206802368, 38.59779902866909, 63.49683543613979, 2.120184825999396, 0.30082225799560547, 0.2339267118700913, 0.19294344101633343, 0.15515250100621156, 0.12652647921017238, 0.1584250754011529, 0.16037202307156154, 0.1798265584345375, 0.129226098635367, 0.1810006004359041, 0.10457393074674265, 0.10531520311321531, 0.13629593141376972], [0.028927579721701995, 0.024485584148871045, 0.04247901648549097, 0.08261779961841446, 0.049134539174182076, 0.024639881315774152, 0.02326413120941392, 0.06535211644534554, 0.025732212433857576, 0.05839819101882832, 0.042102368481989415, 0.036666339462889094, 0.09867172102843012, 0.060877734396074495, 40.27883577346802, 43.63445438657488, 32.98949105398995, 32.085224696568076, 35.732490471431184, 36.4148383140564, 3.359376937150955, 3.5734769914831435, 0.16731494266007627, 0.08885203687740223, 0.03701496397012046, 0.06123120364333902, 0.17394583113491535, 0.11395439239484922, 0.41994076328618185, 0.39685225220663206, 2.610632760184152, 0.5165403740746635, 6.918876324381147, 63.104248319353374, 69.9034844807216, 67.68850299290249, 72.53603880746024, 58.199619156973704, 58.58918380737305, 71.30064909798759, 72.65386635916573, 71.72699056352887, 68.72361087799072, 69.98190879821777, 70.00442790985107, 69.23615169525146, 70.1711916242327, 64.21456350599016, 71.60158947535923, 72.0101227079119, 72.00295216696603, 70.66994026729039, 72.06005941118512, 72.02139268602643, 70.1091650554112, 70.47958047049386, 68.84080614362443, 65.33540521349225, 69.56481538500104, 70.22397014072963, 67.87834167480469, 65.14178671155656, 67.85294600895473, 67.60247734614781, 67.79400444030762, 68.15906279427665, 69.06900582994733, 65.50297491891044, 64.50732585362026, 63.491846629551475, 62.1833827154977, 54.491528851645334, 52.974698884146555, 54.37362486975533, 50.801170349121094, 50.04714836393084, 48.19101006644112, 51.24391998563494, 48.0313925743103, 50.85212843758719, 52.00749226978847, 51.07448468889509, 51.772490297045024, 60.63046727861677, 61.035707065037315, 61.84739562443325, 58.12411655698504, 59.306995255606516, 58.01887566702706, 59.64642865317208, 59.62306186131069, 58.09252309799194, 56.32554061072213, 53.92700161252703, 49.148704596928184, 46.67724772862026, 48.69749205453055, 49.699491773332866, 46.59456763948713, 47.534266335623606, 48.401314667293, 45.46603080204555, 47.53919608252389, 46.260995047433035, 49.70362595149449, 49.816885062626426, 53.79864753995623, 53.90727915082659, 57.69815376826695, 59.81472791944231, 60.23851244790213, 58.06132568631853, 59.10044615609305, 58.228878021240234, 60.95142541612898, 58.245386941092356, 60.307480267116, 58.893153599330354, 59.520214625767295, 55.36677953175136, 56.65768187386649, 54.29495389120919, 58.091546876089915, 55.55234507152012, 55.88405554635184, 60.03812640053885, 56.62533106122698, 58.41299833570208, 54.9064370564052, 60.07646656036377, 58.413491657802034, 58.6341803414481, 62.31587791442871, 59.76621559688023, 62.02459553309849, 62.39410768236433, 62.74761813027518, 59.32415730612618, 50.61805057525635, 48.28900745936802, 39.37354803085327, 31.430502891540527, 23.454978397914342, 30.343210560934885, 31.237454141889298, 14.691985028130667, 0.288140601345471, 0.29110072393502506, 0.19469642266631126, 0.061253086397690434, 0.055203183354543786, 0.04674178381849613, 0.6171557722347123, 0.1402188544826848, 0.11858126840421132, 0.08212603136364903, 0.4527143303837095, 24.654362542288645, 33.202373436519075, 26.831257479531423, 20.187237126486643, 42.427639143807546, 3.3815167205674306, 0.1815507701997246, 0.15625711530447006, 0.03804287327719586, 0.007046309665643743, 0.019640939110623937, 0.0324580584918814, 0.043841375703258176, 0.027561729441263845, 0.06573807394930295, 0.05751020581062351, 0.018242595484480262, 0.0389904881428395, 0.06274836723293577, 0.0728154723931636, 0.07054007984697819, 0.04218359590907182, 0.014231696957722306, 0.07492735835590533, 0.021717408938067298, 0.009397749872212964, 0.1536711369241987, 0.025491441067840372, 0.012724983655581517, 0.0393918110722942, 0.048341335130057166, 0.06680317715342556, 0.1313073012445654, 48.767015729631694, 50.19646862574986, 44.7883243560791, 28.368867771966116, 41.03447321483067, 41.23363290514265, 5.1568231497492105, 6.655949975763049, 0.6253850992236818, 0.053435372321733406, 0.10861103090324573, 0.18273995710270746, 0.28751140939337866, 0.08067747444978782, 0.23558703277792248, 0.4286751374602318, 4.876308304922921, 0.29427458505545345, 8.630595445632935, 71.30818094526018, 70.99390697479248, 72.50079754420689, 74.85153293609619, 65.44937651497978, 67.82365240369523, 78.98233427320207, 75.80749389103481, 76.72868606022426, 74.8500668661935, 75.69265406472343, 74.22606304713658, 74.26049137115479, 73.79159913744245, 69.16006197248186, 74.55843012673515, 76.4648768561227, 75.36945860726493, 72.19061606270927, 74.51495524815151, 72.90439755575997, 73.42433820452008, 72.67873396192277, 70.52716868264335, 70.32753998892647, 70.75281838008335, 70.70057487487793, 70.91128594534737, 69.229127066476, 70.62288706643241, 69.69533729553223, 70.0210063116891, 71.726122038705, 70.48629243033272, 68.51577636173793, 67.7946297781808, 64.55675533839634, 63.87187140328543, 55.288257939474924, 57.16676248822893, 56.7101720401219, 53.701171261923655, 51.00441905430385, 50.65388938358852, 52.34195423126221, 50.47229126521519, 52.199801036289756, 54.83100741250174, 53.75181668145316, 55.24764919281006, 60.59113352639334, 63.62752410343715, 62.03822789873396, 61.531113624572754, 62.0604829788208, 63.8194819859096, 61.83916200910296, 61.893886021205354, 60.83023493630545, 60.743431091308594, 57.09403221947806, 51.119627135140554, 50.4759703363691, 51.243968623025076, 51.4400189944676, 47.649978160858154, 49.61049577168056, 50.085485049656455, 48.29926994868687, 49.17001472200666, 46.9603659766061, 49.150625773838584, 51.243642057691304, 54.772871834891184, 55.96498816353934, 61.09977640424456, 60.42908069065639, 62.76186193738665, 58.25007002694266, 61.411917277744834, 62.006822041102815, 62.812410082135884, 60.425009046282085, 63.2629451751709, 60.4542818069458, 63.15986170087542, 59.974126543317524, 60.73926912035261, 59.09290041242327, 60.86190482548305, 59.01983315604073, 56.04009471620832, 62.056480816432405, 61.2347868510655, 58.46597140175955, 58.53592586517334, 62.335159165518625, 61.87870420728411, 60.33801065172468, 63.06163501739502, 60.453163146972656, 62.39470522744315, 64.94459683554513, 66.38174138750348, 63.87622792380196, 54.09589842387608, 55.24973017828805, 52.38985858644758, 49.03653287887573, 40.89421687807356, 41.562974044254844, 35.16504151480538, 20.449962411608013, 1.5375070465462548, 0.15702149857367786, 0.4950294569134712, 0.1897529422172478, 0.11050356006515877, 0.017191763568137373, 0.25825525926692144, 0.0863852770999074, 0.12613250820764474, 0.2466279917529651, 0.35078515272055355, 27.610282557351248, 35.66164663859776, 26.760300738470896, 29.439121382577078, 48.59161540440151, 4.871669948101044, 0.32012345801506725, 0.2113132295863969, 0.12469451608402388, 0.04860077977978757, 0.07620721110807997, 0.021313733188435435, 0.04937636226947818, 0.0539842969737947, 0.048755645219768794, 0.03896900572414909, 0.024072975485718677, 0.12079462249364172, 0.06455844760473285, 0.25480716143335613, 0.15162035982523644, 0.1764306128025055, 0.15488633885979652, 0.1325588726571628, 0.18847526077713284, 0.08375903445162944, 0.20652190382991517, 0.09971777096922908, 0.17703070917299815, 0.1573946928339345, 0.2788964573826109, 0.23877419318471635, 0.26880935579538345, 57.5788323538644, 59.374601227896555, 49.70717300687517, 50.23629222597395, 58.055798394339426, 48.62325055258614, 8.226239817483084, 9.146759748458862, 0.7309761675340789, 0.20847045284296783, 0.24477282272917883, 0.25337159846510204, 0.5391443840094975, 0.32575738855770653, 1.9917953610420227, 1.9422731612409865, 8.342637777328491, 0.7549210712313652, 8.695113812174116, 82.90853895459855, 78.6320686340332, 78.64894580841064, 78.65615803854806, 73.00639711107526, 72.24117810385567, 83.18848882402692, 78.97157151358468, 78.71793447222028, 76.04011263166154, 79.24980517796108, 76.65219334193638, 76.94081456320626, 78.17348752702985, 72.22149385724748, 77.62139756338937, 81.4627994809832, 78.2513837814331, 75.09982681274414, 79.12807273864746, 77.81464086260114, 76.66230991908482, 76.30797263554165, 71.63731711251395, 74.00673621041435, 75.71961307525635, 75.93903023856026, 75.05399649483817, 71.3293034689767, 73.75956099373954, 72.26620551518032, 73.77413136618478, 72.15593065534318, 75.90799958365304, 70.84500013078961, 70.6130484172276, 68.98461300986153, 69.78147411346436, 58.75499561854771, 59.408334732055664, 61.61556897844587, 57.305837631225586, 55.82500628062657, 52.36353186198643, 55.21301589693342, 52.98527751650129, 56.51126248495919, 58.06910766874041, 58.35355649675642, 58.435420172555105, 64.72891085488456, 64.31849466051374, 67.98913764953613, 64.86466475895473, 64.56510707310268, 66.22507340567452, 63.95909908839634, 64.93757915496826, 65.4624947139195, 62.30042512076241, 59.89346490587507, 53.95861939021519, 53.66356413705008, 53.74341630935669, 55.18377440316336, 51.94109875815255, 51.85846035821097, 53.65022359575544, 49.90482841219221, 51.78750882829939, 52.484051840645925, 54.53246763774327, 57.121692998068674, 60.19387722015381, 58.86147676195417, 65.00546305520194, 65.28815746307373, 65.9682262965611, 63.01112856183733, 66.01236820220947, 65.78705896650041, 66.75424821036202, 63.89212540217808, 66.12967463902065, 63.030562673296245, 65.05662958962577, 61.347424098423545, 63.08112471444266, 60.92520291464669, 64.10881192343575, 60.933304514203755, 58.662723541259766, 65.623060635158, 63.45442363194057, 62.3904390335083, 60.25978088378906, 66.64526571546281, 61.8155311856951, 63.824908529009136, 64.70118754250663, 63.48582948957171, 64.04334599631173, 68.65971524374825, 67.5934168951852, 65.92399406433105, 57.36190264565604, 58.43797016143799, 54.47519016265869, 51.10016175678798, 46.91083574295044, 50.651610374450684, 44.935681751796174, 22.709610394069127, 1.408050381711551, 0.6407337241939136, 0.28779747975724085, 0.10267984095428671, 0.19927132289324487, 0.3329823208706719, 1.8745451612131936, 0.3186176259602819, 0.25628957045929773, 0.5389257871678897, 0.4476055045213018, 34.42309897286551, 49.55142566135952, 43.68250812802996, 30.844259057726177, 61.593918391636436, 5.7269406488963535, 0.3844039301787104, 0.32955314059342655, 0.1436852320496525, 0.1513006476951497, 0.12611713260412216, 0.10477264651230403, 0.19360831033970627, 0.14000354175056728, 0.12637554588062422, 0.12190465150134903, 0.09414315795792, 0.152529257482716, 0.15235779168350355], [0.03983111839209284, 0.041483748105487654, 0.09578020511461155, 0.044718382214861255, 0.0752064058823245, 0.058711640270692964, 0.05267350981011987, 0.05901217021580253, 0.08931073333535876, 0.05476992856711149, 0.016804901916267614, 0.04677421100703733, 0.09141672282878842, 1.6317587090390069, 54.29217113767351, 30.919230120522634, 45.039887360164094, 17.445823635373795, 45.304252420152935, 20.652372121810913, 0.6618880033493042, 5.352556509631021, 0.12636950691895826, 0.06251491725976978, 0.011551716032304933, 0.06571954315794365, 0.19655240593211992, 0.07719321069972855, 0.1854749010609729, 1.7255570015736987, 2.8849202820232938, 0.08132272054042135, 38.37260096413748, 69.18081624167306, 58.4549446105957, 60.66924517495291, 60.75801536015102, 55.03437423706055, 66.15140165601457, 74.75648852757045, 74.87077249799455, 74.77604075840541, 72.72658620561872, 73.15986892155239, 70.92653029305595, 74.08446570805141, 68.36481285095215, 66.33295808519635, 71.65333271026611, 70.03513894762311, 69.43321650368827, 71.02105358668736, 72.55224895477295, 68.95902279445103, 67.54705156598772, 67.88843740735734, 69.62725189753941, 65.25626523154122, 66.95096560886928, 68.90131105695451, 64.0430611201695, 67.47082982744489, 67.55761977604458, 69.38135514940534, 65.54961817605155, 65.80329690660749, 63.9879549571446, 65.41180065699986, 63.19295597076416, 59.984486307416645, 54.302805355616975, 55.70002555847168, 51.97064944675991, 50.17400162560599, 51.99343258993966, 50.907727922712056, 50.00649445397513, 50.0063659123012, 48.933786392211914, 49.26272800990513, 52.18030091694423, 49.24692433220999, 49.743842124938965, 57.62327650615147, 63.919133050101145, 61.930357115609304, 58.61275209699358, 59.01628957475935, 61.55687754494803, 57.94695833751133, 58.31703676496233, 58.640635217939106, 59.082227979387554, 55.777987820761545, 52.18102352959769, 43.81380476270403, 46.35746383666992, 46.408171789986746, 44.92283453260149, 47.92472035544259, 47.8520039830889, 46.83299160003662, 47.8636109488351, 45.39202206475394, 48.23109769821167, 45.28613499232701, 47.85728461401803, 51.004412106105256, 54.37352064677647, 55.96829203196934, 59.93898255484444, 60.4542818069458, 58.481597900390625, 56.97543689182827, 58.627829687935964, 58.992325237819124, 58.87501185280936, 60.01179967607771, 59.112723623003276, 58.4820773260934, 55.608642850603374, 55.57117121560233, 55.732160976954866, 57.39218289511544, 51.59853172302246, 54.84238508769444, 58.54961381639753, 53.96988589423043, 55.13123559951782, 56.11077874047415, 58.81319372994559, 56.97718436377389, 61.1547783442906, 61.759591238839285, 65.22048200879777, 62.30784579685756, 64.0919416972569, 65.11564758845738, 49.85995347159249, 47.587843894958496, 37.477877957480295, 41.03343793324062, 31.139422007969447, 21.079314606530325, 25.69025731086731, 20.28997492790222, 6.122903287410736, 0.3144380673766136, 1.021944414292063, 0.20333391561039857, 0.09737186506390572, 0.006128552885326956, 0.26900043125663486, 0.03252530809757965, 0.4174169658550194, 0.19089469952242716, 0.39147293514439035, 18.088874203818186, 36.396314416612896, 19.16459083557129, 27.31199812889099, 44.90723582676479, 6.2749528884887695, 0.5888514710324151, 0.22406849371535437, 0.09308580362371036, 0.08810921745108706, 0.11580467596650124, 0.055104592216334174, 0.065406602807343, 0.023486227595380375, 0.040627128178519864, 0.030610088724642992, 0.02731338732077607, 0.04021630236612899, 0.0976550177271877, 0.04309601177062307, 0.06680361820118767, 0.041056050519858084, 0.09300461690872908, 0.05386255761342389, 0.05521209930468883, 0.06815817765891552, 0.014487462251314094, 0.0439586367325059, 0.01607924942592425, 0.019663988945207427, 0.04712555643969348, 0.20213651843369007, 3.102599310023444, 59.91207912990025, 44.06910242353167, 52.05426754270281, 14.194541777883257, 54.369004317692344, 22.255375385284424, 0.4977342060634068, 6.733521401882172, 0.14861195268375532, 0.11263788518096719, 0.029563020981316055, 0.05405525477336986, 0.12896341058824742, 0.12004207287515913, 0.07326172451887812, 2.1045932854924883, 1.8790999225207736, 0.312745312494891, 44.074674878801616, 74.42675481523786, 65.32792895180839, 66.70266478402274, 66.66176768711635, 61.588387625558035, 71.14694104875836, 76.12049634116036, 78.5193896974836, 76.43176868983677, 74.17230483463833, 74.6791272844587, 73.8189194543021, 76.6233583177839, 71.12513065338135, 70.5351174218314, 75.36182253701347, 73.14285973140171, 71.77613517216274, 73.08095823015485, 74.53380571092877, 70.61454227992466, 68.37649972098214, 70.56331321171352, 72.10288115910122, 69.00836195264543, 69.45645822797502, 71.69325705936977, 70.31262915475028, 69.35474354880196, 71.47700132642473, 71.96526513780866, 69.97738552093506, 70.46058409554618, 67.23937143598283, 67.92302553994315, 66.83486121041435, 61.38951628548758, 57.986587388174875, 57.66837726320539, 53.63813373020717, 53.26266697474888, 53.84943192345755, 51.964455127716064, 51.66337578637259, 51.34080914088658, 52.98900522504534, 50.97948891775948, 55.27984019688198, 51.01410484313965, 52.272242954799104, 60.13728414263044, 66.0340882710048, 64.94848782675606, 63.11081436702183, 62.15614577702114, 63.31871836526053, 60.73853955950056, 61.59190341404506, 61.0122777393886, 62.20524869646345, 59.72057288033621, 53.366292408534456, 47.6072085244315, 47.97546999795096, 49.96248109000069, 47.110342843191965, 49.39762381144932, 48.44238894326346, 48.50341149738857, 48.576603821345735, 48.29827635628836, 50.453816005161826, 47.54601921354021, 48.46988991328648, 52.78391177313668, 56.90319994517735, 57.40046862193516, 60.95413521357945, 62.625010217939106, 62.38827814374651, 59.60704626355852, 61.53494208199637, 60.55653844560896, 62.13648932320731, 62.778350012642996, 60.902621269226074, 60.6614215033395, 59.60102217538016, 59.03027629852295, 57.71726826259068, 60.90332998548235, 54.9859869820731, 56.843848432813374, 62.23927402496338, 58.586147444588796, 58.05953999928066, 59.72631904057094, 60.07012285505022, 60.381652287074495, 61.79959896632603, 63.008043561662944, 64.76850863865444, 62.147814886910574, 63.67240946633475, 67.63466140202114, 50.79682772500174, 52.150038037981304, 49.76699699674334, 42.534749099186485, 30.780040332249232, 31.421136719839915, 34.69843176433018, 23.64979546410697, 11.567400097846985, 0.5889276840857097, 1.0207854764802116, 0.6761923357844353, 0.43824793664472445, 0.09269840084016323, 0.5610638335347176, 0.040634181550038714, 0.3997283721608775, 0.18243818543851376, 0.32141837424465586, 20.368244647979736, 44.32588699885777, 18.11720895767212, 33.089704922267366, 55.533498082842144, 9.05157116481236, 0.7317944264837674, 0.23733873878206524, 0.1706404834985733, 0.099900751507708, 0.07825333345681429, 0.10736639411853892, 0.05356145430622356, 0.05472781868385417, 0.0013464666553772986, 0.039132410527340004, 0.015425268893263169, 0.037119607640696425, 0.026365543449563638, 0.17261879305754388, 0.1880092972091266, 0.14848984352179936, 0.14593841614467756, 0.09766516861106668, 0.1200973599084786, 0.1866619980760983, 0.13168136402964592, 0.1448661679668086, 0.12715573901576654, 0.10323522186705045, 0.09623017561222826, 0.42619020651493755, 3.212875472647803, 71.95334897722516, 43.38086250850132, 61.01945522853306, 26.535484824861797, 63.07733794621059, 25.164151872907365, 0.7371902455176625, 11.9513966356005, 0.25449875369668007, 0.4521932969135897, 0.1845751500555447, 0.20356274476008757, 0.5763114382113729, 0.3268474686358656, 0.45224942533033236, 6.667502224445343, 7.217076940195901, 0.5119021258183888, 49.159536838531494, 85.92611380985805, 71.00422504970005, 73.82093443189348, 71.2533666065761, 67.32916300637382, 75.58699975694928, 82.33135904584611, 83.06478309631348, 82.79431751796177, 77.8198937007359, 80.34992735726493, 77.22202900477818, 82.23939963749477, 74.46443489619664, 73.69765949249268, 77.62297480446952, 77.67125783647809, 75.89859172276088, 77.56052439553397, 76.89278166634696, 75.85793781280518, 72.14832237788609, 75.02339662824357, 75.22126742771694, 71.14041669028146, 74.10713768005371, 76.22114099775041, 71.99652508326939, 73.6963393347604, 75.07584163120815, 77.13035447256905, 74.14271245683942, 73.56878430502755, 69.98837757110596, 70.82175145830426, 69.17695999145508, 66.21005834851945, 60.38130487714495, 61.22611549922398, 56.06314536503383, 55.3216336114066, 56.20484692709786, 56.357241766793386, 57.15247004372733, 54.93561601638794, 55.250216552189414, 54.090218271527974, 58.35168048313686, 54.2830342565264, 54.87597267968314, 63.67682157244001, 68.18464606148856, 67.32823194776262, 65.34586225237165, 64.88416140420097, 66.78530665806362, 61.60162394387381, 63.56693581172398, 65.02385493687221, 64.83269609723772, 60.967107500348774, 57.73345756530762, 50.679114818573, 50.24480029514858, 52.155235290527344, 50.42607184818813, 52.39736958912441, 51.37784651347569, 52.98937347957066, 54.04406486238752, 50.60176052365984, 54.974501609802246, 49.885394300733296, 53.95234864098685, 58.006883076259065, 61.02324199676514, 62.13325841086251, 66.47325611114502, 65.81436538696289, 66.86612115587506, 63.18497943878174, 64.25893470219204, 63.836553709847585, 65.54692922319684, 64.96482304164341, 62.87965474809919, 65.2764219556536, 62.43879154750279, 62.241302898951936, 61.9112982068743, 63.760345867701936, 55.13245153427124, 58.962802342006135, 60.930309840611045, 60.70615400586809, 59.26699447631836, 63.435406412397114, 64.19683170318604, 63.592942919049946, 65.2506719316755, 65.59665053231376, 67.40421744755336, 63.23137950897217, 67.13299451555524, 69.7590661730085, 54.63219860621861, 55.52267278943743, 51.38931451525007, 48.12857007980347, 41.662892614092144, 42.16690451758248, 43.55482455662319, 33.91494594301496, 11.89892383984157, 0.8916001170873642, 3.5818786663668494, 0.2839704879692623, 0.2482502604169505, 0.2459700841988836, 1.133156846676554, 0.10211502840476376, 0.42762756081564085, 0.2926220808710371, 0.4567715898156166, 28.841390439442225, 53.83288826261248, 31.78166832242693, 41.8365524155753, 65.57231099264962, 11.357353448867798, 0.9675805142947606, 0.499853569482054, 0.19435921790344374, 0.24482352286577225, 0.2783333275999342, 0.17739999507154736, 0.11636024686907019, 0.10269682468580348, 0.18772420393569128, 0.13246778611625942, 0.1088194293635232, 0.14483544390116418, 0.2783750982156822], [0.04643543543560164, 0.07626283740890877, 0.04057065031624266, 0.03509977513125964, 0.05634395678394607, 0.027001542804230536, 0.022143566249204532, 0.03958325972780585, 0.0410751682440085, 0.039344276301562786, 0.021448011875950863, 0.021905259661642567, 0.16533940152398177, 7.605618034090314, 60.449800218854634, 28.88129220690046, 43.6010092326573, 25.27429645402091, 58.382648604256765, 7.634096094540187, 0.5759101797427449, 1.0672933523144041, 0.03259403690961855, 0.06273662179176297, 0.018193308397063186, 0.039650370233825276, 0.19301003244306358, 0.24382965905325754, 0.09800410363823175, 1.0434974006244113, 0.23607973062566348, 23.498739889689855, 67.44778265271867, 58.390124865940635, 59.631246839250835, 56.88811540603638, 59.66528606414795, 55.923840931483674, 65.12825856889997, 71.78777340480259, 70.74230575561523, 71.56743907928467, 72.2671365737915, 70.83823258536202, 75.62547888074602, 70.77253736768449, 70.12958581107003, 70.85028076171875, 70.40152440752301, 66.03368527548653, 68.07722691127232, 70.43496608734131, 71.2843416758946, 68.11779049464634, 68.87492179870605, 67.58374500274658, 66.48308781215123, 64.81398459843227, 65.66569478171212, 68.99258954184396, 65.91421794891357, 64.81597873142788, 67.45612743922642, 66.16490200587681, 64.60078607286725, 65.08215727124895, 63.607158933367046, 61.11482620239258, 59.218162536621094, 55.91134112221854, 55.98372745513916, 54.700447286878315, 51.30556787763323, 51.317292962755474, 52.50455597468785, 50.76623828070504, 47.89486394609724, 47.908683913094656, 49.93597371237618, 48.05094827924456, 52.048167024339946, 48.324700355529785, 49.07244464329311, 57.52340657370431, 62.81573132106236, 59.76844596862793, 59.40197018214634, 61.279859815325054, 60.47456359863281, 60.028662954057964, 59.625528471810476, 57.77219377245222, 58.191583565303254, 54.7946891784668, 47.05635186604091, 45.60484538759504, 46.266397271837505, 45.57933160236904, 45.979485307421, 46.229874065944124, 46.00105251584734, 45.81028624943325, 46.951965604509624, 44.705911772591726, 46.754282406398225, 46.24229049682617, 45.412102358681814, 45.607360635484966, 48.9948228427342, 52.94865703582764, 55.64419330869402, 58.36932890755789, 57.4298768724714, 58.83743599482945, 59.62861347198486, 58.974162646702354, 56.406761578151155, 58.831043652125764, 57.330250126974924, 57.58000659942627, 55.773606981549946, 52.83500187737601, 55.39466960089547, 55.383125168936594, 58.17422696522304, 52.49722909927368, 59.34334823063442, 58.92772783551897, 56.057041372571675, 54.37764092854091, 56.829441343035015, 59.73053659711565, 57.89229685919625, 59.793000902448384, 63.91520731789725, 65.56837136404855, 63.05874456678118, 66.29350621359688, 52.08825813020979, 46.81893539428711, 44.05434444972447, 38.2935791015625, 30.57336269106184, 22.522497143064225, 27.968333653041295, 22.432867118290492, 19.51256356920515, 3.3425538284437994, 2.8971779899937764, 1.014770399246897, 0.12291880351092134, 0.149035032838583, 0.07283268682658672, 0.1485962513834238, 0.11400946229696274, 0.1513085322720664, 0.523684099316597, 7.542537944657462, 35.41694150652204, 30.761815207345144, 26.8586003780365, 39.9535801751273, 12.034632580620901, 0.5914703447903905, 0.20755286993724958, 0.08079996359135423, 0.0584749129733869, 0.03515706384288413, 0.015590197007570947, 0.06142350046762398, 0.11440930941275188, 0.06880566291511059, 0.020721177038337504, 0.09463436302861997, 0.04682296035545213, 0.050048305320420435, 0.03924333403951355, 0.06565807467060429, 0.05832983540104968, 0.08669380018753664, 0.03818166082991021, 0.0065673390054143965, 0.025333763100206852, 0.05020889759595905, 0.051173472444393804, 0.04086831345089844, 0.061306364967354705, 0.06322959105351142, 0.44672397896647453, 11.271722112383161, 67.73368018014091, 40.09088005338396, 42.991318702697754, 24.28042960166931, 67.39517784118652, 8.272110956055776, 0.6917084231972694, 1.3054994216987064, 0.02028906388607408, 0.10520641359367541, 0.01843688720172005, 0.07961149593549115, 0.2952578365802765, 0.49276684118168695, 0.21449257326977594, 1.0452869960239954, 0.2366483701126916, 27.3648704460689, 74.21581445421491, 63.23949500492641, 65.88736316135952, 62.87954357692173, 66.59079183850969, 62.404814856392996, 71.49425370352608, 73.3602271761213, 75.56660679408482, 75.19730309077671, 75.34921155657086, 74.3950640814645, 77.12068258013043, 74.30177756718227, 72.79881967817033, 74.33455221993583, 74.24654633658272, 70.45191274370465, 72.25492858886719, 74.00628457750592, 73.22006811414445, 71.68472467150006, 72.22107696533203, 70.42900453295026, 67.99580097198486, 66.78459099360875, 68.94277095794678, 71.28398731776646, 67.93210683550153, 69.81653472355434, 70.93343680245536, 69.13392284938267, 67.46695968082973, 67.98698370797294, 65.28445407322475, 64.7886723109654, 61.17085647583008, 59.65835871015276, 57.85408524104527, 57.06828914369856, 54.45076377051217, 55.324343408857075, 53.793724741254536, 54.057110105242046, 50.459193910871235, 52.661703382219585, 52.96487065723964, 52.028597423008506, 52.53192492893764, 52.15978636060442, 50.693740776606965, 57.58996336800711, 62.97239235469273, 61.77719102587019, 63.40063762664795, 64.02250834873745, 62.08059106554304, 62.7891058240618, 60.48783465794155, 59.67953681945801, 59.47867134639195, 55.89546448843819, 50.30209861482893, 48.472415583474294, 49.567159857068745, 48.04156126294817, 49.031731673649375, 46.90919596808297, 47.55613579068865, 46.35223184313093, 47.20728063583374, 46.26388897214617, 48.203902448926655, 48.21935176849365, 47.24754892076765, 46.84278508595058, 50.331687518528526, 54.11294930321829, 58.87870829445975, 59.76430484226772, 61.52379717145647, 60.3555201121739, 61.84195518493652, 60.923493657793315, 59.166996002197266, 59.807348932538716, 58.1598025049482, 60.72649138314383, 59.71131787981306, 57.71590641566685, 58.948113850184846, 58.30961608886719, 60.011452266148154, 56.989197799137656, 60.25536182948521, 63.72576468331473, 60.14321790422712, 57.80946738379342, 59.18331037248884, 59.021438189915244, 60.56322956085205, 59.62539645603725, 64.0216259275164, 66.98777716500419, 63.998425892421174, 67.79798575810024, 55.90181514195034, 50.19466209411621, 52.61420202255249, 42.30764375414167, 29.254671028682164, 24.818892410823278, 36.13980082103184, 30.065487589154923, 26.090096609933035, 6.089228842939649, 0.908457369676658, 0.5286471758569989, 0.15974093122141703, 0.12651600262948445, 0.0627644145861268, 0.20547427290252276, 0.1422167872743947, 0.25863016343542505, 0.4511906664286341, 8.010949884142194, 41.72686815261841, 29.477593558175222, 33.7041688646589, 49.285122053963796, 14.30547411101205, 0.5809780763728278, 0.07250099855342082, 0.09202150109090976, 0.03878774866461754, 0.09145325515419245, 0.03553238531042423, 0.06316236180386373, 0.04946744202503136, 0.03460372871320162, 0.04009320593572088, 0.09202460199594498, 0.010338786340850805, 0.024542582786775062, 0.0994770878127643, 0.2858498128397124, 0.17919086611696652, 0.29111236759594505, 0.0750292878864067, 0.14249141753784247, 0.06562234980187245, 0.14593233647091047, 0.19007796049118042, 0.1835058738610574, 0.18808692161525997, 0.22637882402965, 0.532918200961181, 12.599489859172277, 79.94267954145158, 39.924206665584016, 59.633039474487305, 40.07691070011684, 76.87361158643449, 10.383459193365914, 1.3089367172547748, 3.4223369530269077, 0.17222928681543895, 0.27157313749194145, 0.09164529413517032, 0.166658717872841, 0.5146242997476033, 0.5446499628680093, 0.20124295566763195, 2.7262103983334134, 0.4429619094090802, 28.98223042488098, 86.68226541791643, 69.7930428641183, 70.56022126334054, 70.04344204493931, 72.8620274407523, 67.60345009395054, 77.67299488612584, 80.00517163957868, 79.2251946585519, 78.6595070702689, 78.55970314570835, 78.15118380955288, 80.90135029384068, 77.82092898232597, 77.34677696228027, 77.76274476732526, 76.1630471093314, 73.25887380327497, 74.29533658708844, 76.95111874171666, 79.61175073896135, 75.37009089333671, 76.56493786403111, 72.67781679970878, 71.39028085981096, 69.36856351579938, 72.46617467062813, 77.34864602770124, 72.34195477621896, 71.23631572723389, 74.76532663617814, 71.92475714002336, 70.91246713910783, 71.9690032686506, 69.59847245897565, 67.1388726915632, 67.11736801692417, 63.08909429822649, 59.47319616590227, 59.61083997998919, 57.24531534739903, 56.37689127240862, 57.26277617045811, 56.766174520765034, 53.75598560060774, 54.360569204602925, 57.53085504259382, 55.355839593069895, 57.2872234072004, 53.77359233583723, 54.11052090781075, 61.93754850115095, 67.4786604472569, 64.9578331538609, 67.0809108189174, 67.41718278612409, 65.82116072518485, 64.2293701171875, 65.98239367348808, 62.29035718100411, 65.1000280380249, 60.48153264181954, 52.66520527430943, 50.856832368033274, 51.082256249019075, 50.12090696607317, 52.14761311667306, 51.31921066556658, 51.40782451629639, 50.40991381236485, 51.994526931217735, 49.33628511428833, 51.88646854673113, 52.03131764275687, 52.58736113139561, 50.97207171576363, 55.63182551520211, 57.43191964285714, 61.623142514910015, 62.24537454332624, 64.67519433157784, 63.124856676374165, 65.0555248260498, 63.78117656707764, 60.9493340083531, 63.468292236328125, 61.663907596043174, 63.29578930991036, 61.4247019631522, 58.47439956665039, 61.14163930075509, 62.221347672598704, 60.70583438873291, 57.31783717019217, 62.53992257799421, 63.36543805258614, 61.284834725516184, 59.598069190979004, 63.4447934286935, 61.64270864214216, 63.07189055851528, 63.84471089499337, 67.61045387813023, 70.75461796351841, 66.8771618434361, 70.75918292999268, 57.48312439237322, 53.44948319026402, 53.684936795915874, 48.569805009024485, 46.46531030109951, 37.1280847958156, 44.106007780347554, 40.72614690235683, 32.31245510918753, 5.931003596101489, 6.430911719799042, 1.475477655019079, 0.2079840518001999, 0.3522290480988366, 0.11712138674088887, 0.4411181126322065, 0.3770506190402167, 0.5853641267333711, 0.7959305335368428, 12.605353270258222, 49.49519736426217, 49.12844017573765, 42.27889905657087, 54.51358243397304, 20.50115500177656, 0.8996401056647301, 0.4798557854124478, 0.21329957299998828, 0.2138618342578411, 0.14567358392689908, 0.22799666864531382, 0.1797083169221878, 0.3081530960542815, 0.17693983976330074, 0.15082507607127937, 0.18797207277800354, 0.12968470688377107, 0.1512521052999156], [0.07022857799061707, 0.09066114694412265, 0.023390754325581447, 0.07654343199517046, 0.03271977284124919, 0.061418492879186354, 0.013422968032370721, 0.08902167063206434, 0.192334401554295, 0.04297187378896134, 0.04403099570689457, 0.15400763601064682, 0.4374333417841366, 21.54896593093872, 49.43273305892944, 44.76112215859549, 33.38044534410749, 27.154845510210308, 57.08750786100115, 0.6271935307553836, 0.04726391312267099, 0.07811308026845966, 0.1749727124614375, 0.06573466091815915, 0.10633498696344239, 0.06709727458655834, 0.09245158372712986, 0.06767830412302699, 0.9856410537447248, 0.3373934770269053, 7.6945619242531915, 61.73214585440499, 57.039721625191824, 60.344368253435405, 61.2760591506958, 63.70041070665632, 56.01201009750366, 56.332954338618684, 65.3869400024414, 70.47960826328823, 69.58914797646659, 71.84553377968925, 72.42472866603306, 74.91731848035539, 75.235518183027, 67.56860487801688, 67.74714578901018, 74.76432609558105, 67.93099512372697, 68.50161593300956, 71.40404524121965, 69.21893405914307, 64.97829559871128, 62.351529121398926, 66.94321836744035, 66.39793763841901, 67.01647322518485, 66.2782062802996, 64.8408532823835, 64.98307595934186, 64.88134738377163, 64.48712049211774, 66.44941684177944, 63.35665552956717, 61.299780300685335, 61.74637576511928, 59.607004574366975, 59.31365857805525, 53.51708568845476, 55.12176867893764, 54.40692063740322, 51.03503976549421, 51.96997894559588, 52.80843544006348, 50.06810065678188, 51.31156417301723, 46.44282593045916, 49.06401647840227, 50.68905421665737, 48.609680720738, 50.15959106172834, 50.41459689821516, 46.8150999886649, 56.92849138804844, 58.11338159016201, 58.0296870640346, 60.71942506517683, 59.43369565691267, 61.23457145690918, 59.6846923828125, 58.377242905753, 57.29228169577462, 56.01672445024763, 52.82366589137486, 47.901051316942485, 46.410624504089355, 48.13298913410732, 43.030301570892334, 44.53442675726754, 43.9400292124067, 44.18072870799473, 46.493502616882324, 46.48167678288051, 45.012765066964285, 45.627176897866384, 46.96782486779349, 46.67742838178362, 45.111335686274934, 43.235936982291086, 46.469559124537874, 54.22998823438372, 58.38175228663853, 58.49861403873989, 55.901693548474995, 57.10651813234602, 59.11296680995396, 59.770961216517854, 60.14927673339844, 53.09517022541591, 54.97310502188546, 57.82626812798636, 54.5848605292184, 56.97327600206648, 54.22386687142508, 56.05800717217581, 55.78144107546125, 55.48273801803589, 59.42358602796282, 58.15939603533064, 55.13920865740095, 52.945568561553955, 58.32303306034633, 57.13967841012137, 58.95384611402239, 62.20148277282715, 64.97154194968087, 63.46572835104806, 66.18799781799316, 55.88576132910592, 45.900657994406565, 48.51193346296038, 41.1810211454119, 26.388193437031337, 25.811037846973964, 32.37406478609358, 24.880602836608887, 21.41956615447998, 19.994855403900146, 0.4579120714749609, 3.097977020910808, 2.0313332165990556, 0.10741785421435322, 0.33544437161513735, 0.0315853301435709, 0.27636880587254253, 0.0977278109639883, 0.17201351267950876, 1.8193306497165134, 34.56799670628139, 24.83256299155099, 22.45325834410531, 42.80871309552874, 18.26265386172703, 0.28922335324542864, 0.17301114914672716, 0.056600283565265794, 0.036503562304590426, 0.05026311593662415, 0.05972228425421885, 0.025244700289996605, 0.041376909374126365, 0.0217302095011941, 0.019246194578175033, 0.12035783593143735, 0.038921542199594636, 0.07030150014907122, 0.07651867225233998, 0.05819391805146422, 0.08382947317191533, 0.007994530123791524, 0.011108955817430146, 0.029488850318427597, 0.04507823308397617, 0.05982061754912138, 0.08113095297345094, 0.02510730203773294, 0.12197589767830712, 0.12316023984125682, 0.2671824459518705, 25.939532620566233, 56.20162991115025, 53.319840226854595, 36.67076131275722, 33.676032134464805, 61.72737939017159, 0.5552179015108517, 0.05371709666880114, 0.07689202257565089, 0.1827074417046138, 0.10641938993441206, 0.167828552957092, 0.21516015673322336, 0.2318939838026251, 0.2753676138818264, 1.9776064881256648, 0.34304412667240414, 10.643969740186419, 69.10270459311349, 60.297085762023926, 67.95404924665178, 66.47864096505302, 69.366089957101, 61.81409985678536, 63.315404074532644, 68.40716212136405, 70.10390526907784, 72.40865053449357, 74.62251336233956, 74.60164792197091, 76.42849608830043, 77.1011095046997, 71.57768767220634, 71.55677359444755, 77.11369269234794, 71.81921400342668, 71.95084067753383, 72.73615387507847, 72.12567125047956, 66.08406666346959, 65.97227014814104, 68.57854638780866, 69.41599191938127, 69.28882598876953, 67.9795560836792, 68.28700692313058, 69.49977329799107, 67.29812540326799, 69.35050514766148, 68.05231761932373, 67.46707780020577, 66.09659426552909, 63.77845287322998, 62.879321234566824, 61.7681861604963, 55.41831432070051, 58.56873525891985, 55.99519198281424, 55.51042658942086, 53.202669279915945, 54.05337544849941, 53.203989437648225, 52.8031895501273, 50.85122169767107, 51.58749450956072, 50.96440437861851, 50.7350617136274, 51.235460553850444, 52.0828663281032, 47.79048810686384, 55.71488428115845, 59.354715483529226, 60.97960730961391, 62.25369153703962, 60.8535669871739, 65.2093926838466, 60.8753148487636, 59.70391110011509, 58.386199133736746, 57.957088811056956, 56.42455244064331, 50.155974524361746, 48.40194695336478, 49.79596056256975, 47.08301905223301, 45.86259923662458, 48.06159291948591, 44.87972443444388, 48.40689754486084, 48.610879284994944, 46.88160119737898, 47.809449740818565, 48.54772015980312, 49.46783535821097, 48.55791664123535, 45.1773088318961, 49.17239448002407, 54.96809884480068, 59.40784140995571, 60.271829060145784, 59.475238936288015, 60.29835728236607, 62.16034943716866, 62.55165808541434, 62.12374632699149, 56.94273866925921, 54.585023811885286, 59.9177280153547, 58.23872709274292, 60.23836653573172, 58.367452893938335, 60.502613476344514, 60.61200591496059, 58.79617064339774, 62.06758403778076, 61.35282979692732, 59.38370336805071, 55.55784804480416, 61.09594794682094, 60.43454197474888, 59.78400993347168, 62.263092449733186, 66.79322760445731, 62.23516763959612, 70.0437616620745, 57.97699540002005, 51.566239970070974, 52.641782896859304, 47.43571656090872, 29.93468427658081, 27.416245426450455, 35.82427964891706, 31.40156364440918, 27.048545019967214, 26.889768259865896, 2.024691607270922, 1.05084251505988, 0.8752103479845184, 0.1545215720044715, 0.3178899378648826, 0.03831026017931955, 0.22781658545136452, 0.07387275887387139, 0.1312444553311382, 2.086296941552843, 39.8100130217416, 29.925467491149902, 23.320412635803223, 48.29010527474539, 24.369382177080425, 0.20741121896675654, 0.1966597366013697, 0.05702039173671177, 0.10042066539504699, 0.058456131124070713, 0.023939963962350572, 0.033194326662591526, 0.09389165895325796, 0.031048832860376154, 0.026053824461996555, 0.07397445770246641, 0.12486968668443815, 0.03725930782301085, 0.13870013026254518, 0.19724683224090508, 0.2025433951722724, 0.18370992291186536, 0.18331646759595188, 0.24049745500087738, 0.15670232927160604, 0.24887073997940334, 0.18129310331174306, 0.1423694576535906, 0.217195775359869, 0.28444953369242804, 0.705608565892492, 31.34326478413173, 65.4913158416748, 56.349720341818674, 44.98680659702846, 40.25483322143555, 72.82568836212158, 1.1128461765391486, 0.1633481862289565, 0.3176973967679909, 0.5070876755884716, 0.2125575678156955, 0.3434799632855824, 0.13946663056101116, 0.21969454841954367, 0.4211690473769392, 2.6619545434202467, 0.656368473810809, 13.125881910324097, 81.99075835091728, 68.63249220166887, 73.32140759059361, 71.9238886151995, 73.36516039712089, 69.4805406842913, 71.38078962053571, 75.62857777731759, 78.32265840257917, 80.12561171395438, 78.4964189529419, 78.92148889814104, 79.51471219744, 80.53693117414201, 74.61530113220215, 74.75700269426618, 78.21637180873326, 74.80966309138707, 74.46377481733049, 75.3757884161813, 75.79973970140729, 68.52155726296562, 69.44427108764648, 70.2319883619036, 74.12759317670549, 73.50055299486432, 72.34394196101597, 72.385422706604, 73.77671609606061, 72.5039311817714, 72.81423773084367, 73.54620960780552, 70.80506883348737, 69.95256655556815, 69.78355857304165, 65.72073146275112, 65.53946685791016, 58.80329949515206, 61.844803946358816, 60.410098212105886, 56.90175124577114, 55.99936090196882, 57.782848834991455, 56.65147713252476, 56.91528633662632, 52.987723282405305, 56.04940182822091, 56.43434245245797, 54.539370673043386, 54.280195917402, 55.58851739338466, 53.60053702763149, 64.21755817958287, 62.70064830780029, 64.84717614310128, 67.07155854361397, 66.36109134129116, 69.76504162379673, 65.59950624193463, 63.6716034752982, 62.53465584346226, 61.48506096431187, 60.14610835484096, 53.26900373186384, 51.705210890088765, 54.23087065560477, 48.3966246332441, 51.07574231284005, 51.794898237500874, 48.60830497741699, 53.51643255778721, 53.018875530787874, 49.25701659066336, 51.1295804296221, 52.20712791170393, 53.61225169045584, 51.393907274518696, 47.323496205466135, 52.81270858219692, 57.79560572760445, 64.05661705562046, 63.99916934967041, 61.941745213099885, 63.40964944022042, 64.9201739174979, 65.70901679992676, 64.63730580466134, 59.468499183654785, 58.060307775224956, 62.97440038408552, 61.38044193812779, 62.49342523302351, 61.15627915518624, 62.27725287846157, 61.84558909279959, 59.652160917009624, 62.077096121651785, 63.33025237492153, 61.31036935533796, 58.58077648707798, 63.144631249564036, 61.149636677333284, 61.98988928113665, 66.52704211643764, 69.59294864109584, 66.26772839682442, 73.77643816811698, 62.01770292009626, 56.89625522068569, 56.34895256587437, 53.77198382786342, 44.44320733206612, 41.864522389003206, 46.10474048342024, 43.05321672984532, 37.616699491228374, 32.35195214407784, 1.7917835393122263, 7.191115864685603, 4.251789450645447, 0.270566001534462, 0.8934724394764219, 0.1418441901249545, 0.4700130649975368, 0.26892804514084545, 0.24949702780161584, 3.5889473727771213, 52.381468636649, 37.161641120910645, 35.98464754649571, 58.5168947492327, 28.401618106024607, 0.3330511786043644, 0.473815629524844, 0.20265764689871243, 0.22158607334962913, 0.1608039920351335, 0.21420255383210524, 0.09116700158587523, 0.20392589670206818, 0.11239250656217337, 0.11922149333570685, 0.258545237992491, 0.2181745892656701, 0.14623633372996533], [0.01011686128497656, 0.04200248812724437, 0.050341751359935315, 0.029878264958305017, 0.012157962474572872, 0.11182502737002713, 0.059982353156166415, 0.0715071822383574, 0.04097874163250838, 0.03443401353433728, 0.016960696949224387, 0.021832824352064302, 0.026971641462296247, 38.0496278490339, 44.096113545554026, 38.7651081766401, 23.724181141172135, 38.43073306764875, 38.82188885552542, 0.1585973554423877, 0.19445624841111048, 0.16961776837706566, 0.24042938436780656, 0.1094968244433403, 0.11973867272692067, 0.4355740744088377, 0.21863300752426895, 1.0460474980728967, 2.1480907457215443, 0.35616170135991915, 33.43578427178519, 63.70333589826311, 53.43987730571202, 64.2519726072039, 62.46281841823033, 60.58349745614188, 54.16434512819563, 55.99575826099941, 65.1934813090733, 66.42607089451381, 67.85530144827706, 69.65059089660645, 70.17117772783551, 71.8351879119873, 72.71210615975517, 67.53232138497489, 71.68616989680699, 73.49322959354946, 65.67275415148053, 68.21963024139404, 69.21831566946847, 70.2588084084647, 64.23139204297746, 63.27027552468436, 68.57079914637974, 65.14542756761823, 61.70083727155413, 66.47361046927315, 66.3632035936628, 66.41840008326939, 66.58741501399449, 64.56450952802385, 62.11368533543178, 62.19549342564174, 63.58377129690987, 62.37884943825858, 58.85962854112898, 52.230661460331504, 53.133784839085166, 48.425063610076904, 50.9259078843253, 50.74450084141323, 52.05459410803658, 50.877541473933626, 50.15929576328823, 48.990271772657124, 50.34630652836391, 48.62091943195888, 48.13635206222534, 48.645703656332834, 52.76528365271432, 48.61797686985561, 46.626220158168245, 45.89872292109898, 50.09547308513096, 55.65009580339704, 55.490804876599995, 55.83005067280361, 57.78018767493111, 53.63024752480643, 54.07445975712368, 54.87525006702968, 54.566423484257285, 52.376080308641704, 45.06473411832537, 46.521733147757395, 46.38886969430106, 43.38755362374442, 42.43478536605835, 45.09099136080061, 42.55383927481515, 45.50683062417166, 44.58099705832345, 44.43121821539742, 46.3010687828064, 45.117682865687776, 45.83059583391462, 46.808863980429514, 47.76258414132254, 43.65044913973127, 45.90513263429914, 53.53756897790091, 56.12271227155413, 57.529871872493196, 58.90281159537179, 58.11142567225865, 58.34699739728655, 57.602237360818044, 54.115780694144114, 51.31700461251395, 56.65255410330636, 53.48513439723423, 55.87074279785156, 55.46948432922363, 53.963007177625386, 56.09181710651943, 55.26565892355782, 58.855647223336355, 57.663440568106516, 57.25783947535923, 53.09209564753941, 56.32220547539847, 57.24441902978079, 58.12700005940029, 59.62536171504429, 64.30662713732038, 62.2784549168178, 64.18344947269985, 58.98730863843645, 47.342200756073, 50.754297801426475, 45.907456806727815, 30.32239028385707, 24.735117980412074, 37.05559771401541, 27.072632687432424, 22.863629375185283, 25.151011092322214, 10.214613624981471, 0.5606542697974614, 0.7859138367431504, 0.06286427458482129, 0.04423102443771703, 0.06074326911142894, 0.03546174981498292, 0.1481567235397441, 0.03396780230104923, 0.24334149381944112, 21.93983336857387, 27.715304579053605, 28.011867591312953, 46.6565386227199, 20.349293436322892, 0.09272968130452292, 0.056179659707205634, 0.07772104309073516, 0.01594419381581247, 0.043388833557920795, 0.02677197744404631, 0.0744912096166185, 0.047643913089164665, 0.03890620391549809, 0.08793192982141461, 0.012977538630366325, 0.03730019634323461, 0.0307312241888472, 0.011949418977435147, 0.08991944031523806, 0.05058134546769517, 0.0502064107651157, 0.01952083332331053, 0.01819253825981702, 0.022200454625168016, 0.037089484078543525, 0.057159321781780036, 0.01793395365322275, 0.04396868922880717, 0.012720377250973667, 0.024325297214090824, 43.93563795089722, 50.46134785243443, 52.02387612206595, 23.51975471632821, 42.76690231050764, 44.12793629510062, 0.15316239850861685, 0.21235862134822778, 0.22008356611643518, 0.3720085881650448, 0.13891992132578576, 0.1798500900289842, 0.6338427939585277, 0.45859478626932415, 1.7023384017603738, 3.897770047187805, 0.40719795706016676, 36.31664637156895, 67.68577235085624, 60.580655642918174, 66.63520472390312, 65.55450970785958, 64.2279943738665, 58.20147085189819, 62.02438708714077, 68.59093502589634, 70.38142326899937, 72.43180888039726, 72.63334832872663, 73.74580356052944, 76.12684004647392, 75.09290640694755, 70.96020126342773, 75.69457176753453, 75.21785586220878, 69.40678555624825, 71.15445899963379, 71.46669714791435, 70.52151979718889, 66.36990860530308, 67.52176012311662, 71.769013268607, 69.78036934988839, 66.46015180860246, 68.82033675057548, 68.20842279706682, 69.31817517961774, 68.92316314152309, 67.51235921042306, 65.37173039572579, 66.22594887869698, 65.8624677658081, 65.72752680097307, 63.159104347229004, 54.67680951527187, 54.68450117111206, 52.432548318590435, 54.168038095746724, 52.30926990509033, 55.6523574420384, 52.902152742658345, 52.5968211037772, 51.29660470145089, 52.68425028664725, 52.20063829421997, 50.378257819584434, 50.37473160879952, 53.82109716960362, 51.85712282998221, 49.99459913798741, 47.48399611881801, 50.23820645468575, 55.862915652138845, 55.5993218421936, 57.6474666595459, 60.7874687739781, 56.16981758390154, 58.35237530299595, 55.54794686181204, 54.99414069311959, 50.18456636156355, 46.99411685126168, 48.94709914071219, 49.013225146702354, 46.08691487993513, 45.70654617037092, 46.749112946646555, 42.712393692561555, 45.74964584623064, 45.1441068649292, 44.62581293923514, 47.766534192221506, 46.110312938690186, 48.369401591164724, 49.1858948298863, 48.35254526138306, 46.906889166150776, 47.335499218532014, 55.58413655417306, 59.43680150168282, 58.41633347102574, 61.371145248413086, 60.234107289995464, 60.3113226209368, 60.670926639011924, 57.780302320207866, 52.6156507219587, 58.49198545728411, 58.62423052106585, 57.959607533046174, 60.499431201389854, 59.07422365461077, 59.08418042319161, 57.30239479882376, 62.22580146789551, 61.58514976501465, 62.08854675292969, 56.02688619068691, 57.61027990068708, 61.51090131487165, 59.34379291534424, 61.708063398088726, 65.88426426478794, 63.757934842790874, 65.10708045959473, 61.75322668892996, 50.036281381334575, 52.76958458764212, 52.886595726013184, 35.51759311131069, 26.281392676489695, 37.980340412684846, 35.30456134251186, 30.659284114837646, 33.0208864893232, 18.573978321892874, 1.3846530829157149, 0.24796218158943312, 0.479166176702295, 0.06075698230415583, 0.03237525686355574, 0.08984452326382909, 0.08118667426918234, 0.030965003251497234, 0.19525436844144547, 23.66916877882821, 29.84031731741769, 27.670975072043284, 54.55921820231846, 24.698462758745464, 0.04571489570662379, 0.11103958237384047, 0.07081159563469035, 0.018255596215437566, 0.04628663270601204, 0.07550844217517547, 0.06086622644215822, 0.018555846264851943, 0.010373109186600362, 0.0951088625671608, 0.013429289434238203, 0.056413730539913685, 0.020239817510758127, 0.08175194822251797, 0.26738209809575764, 0.1738542424780982, 0.19176517852715083, 0.20483646355569363, 0.2300632691809109, 0.3355848283639976, 0.17057157148207935, 0.2301542471562113, 0.12321745391402926, 0.1444026335541691, 0.10364684156541314, 0.19800160745424883, 52.180703912462505, 59.022640228271484, 51.5115750176566, 35.44649914332798, 55.96687807355608, 50.00022370474679, 0.2392870842346123, 0.3242340774408409, 0.3990533926657268, 0.6568269463522094, 0.2805397877735751, 0.46669068613222664, 0.7733976883547646, 1.0278722047805786, 3.168206806693758, 7.390786681856428, 1.0222603401967456, 44.76212269919259, 80.78655910491943, 70.24327918461391, 73.81534113202775, 70.91960293906075, 70.17154598236084, 66.26185716901506, 68.71921961648124, 78.13304206303188, 77.71691444941929, 77.58655234745571, 77.924971308027, 76.74162360600063, 76.87492479596818, 77.14811406816754, 75.26834842136928, 78.09286757877895, 79.3878172465733, 71.45050089699882, 74.60156454358781, 75.1104714529855, 74.07953248705182, 69.90752833230155, 69.17705031803676, 76.59927586146763, 74.92619132995605, 67.57175936017717, 72.94024331229073, 73.63664041246686, 73.43463543483189, 72.43589442116874, 71.9221168245588, 68.82442923954555, 71.60090855189732, 71.12506811959403, 69.01166234697614, 66.85726915087018, 58.14883129937308, 59.047028405325754, 54.78860950469971, 57.60487767628261, 56.393994263240266, 60.03703553336007, 57.29638460704258, 54.2007224219186, 53.80549498966762, 57.75278745378767, 55.55357837677002, 52.675631046295166, 53.93222665786743, 57.40907049179077, 56.76894685200283, 51.12385163988386, 52.34260041373116, 55.032915115356445, 62.17237676892962, 60.56555025918143, 62.11391462598528, 63.04725224631173, 59.374309403555735, 60.27452496119908, 59.91002246311733, 59.69387790134975, 56.73144742420742, 49.5110079901559, 52.54667248044695, 51.769797870091026, 47.55573974336897, 47.801657336098806, 51.481989588056294, 45.525417055402485, 50.10657978057861, 48.06777334213257, 48.379229818071636, 52.76599931716919, 49.838914326259065, 53.25602102279663, 53.02081755229405, 52.365525994982036, 49.15337726048061, 50.64438077381679, 60.249379430498394, 63.41518715449742, 61.563110079084126, 64.38719844818115, 63.96917397635323, 64.09164292471749, 62.7461381639753, 59.60625416891915, 56.81853267124721, 61.911458015441895, 60.30513177599226, 62.094306809561594, 61.93818078722273, 60.425161906651084, 59.453372955322266, 60.66035148075649, 63.325979232788086, 62.89036887032645, 62.87452697753906, 57.81341396059309, 60.6784029006958, 64.7850592476981, 62.317448207310264, 63.792321477617534, 70.04240676334926, 65.79170731135777, 68.52364172254289, 64.6115974698748, 55.57968970707485, 57.3504068510873, 59.49704933166504, 48.30436297825405, 41.82958337238857, 50.6545946257455, 42.32305833271572, 40.45590366636004, 43.789232458387104, 20.408158574785503, 2.0264238800321306, 1.8017534443310328, 0.520430822457586, 0.2380658026252474, 0.13787565593208584, 0.20693063975444861, 0.19825451102639946, 0.3012496807745525, 0.28444711810776163, 34.92400503158569, 41.473245007651194, 44.19700486319405, 65.34146404266357, 30.307740007128032, 0.18557805195450783, 0.18790662129010471, 0.14893888442644052, 0.13104924080627306, 0.1727871104542698, 0.22726765062127793, 0.175999715924263, 0.2191498747893742, 0.1118486336033259, 0.13501155961837086, 0.15541954524815083, 0.09869305416941643, 0.23190717452338763], [0.040927702228405645, 0.08616045809217862, 0.03195747606722372, 0.097825350372919, 0.05027869510065232, 0.1518816908023187, 0.09851030433284384, 0.09977307157324893, 0.15152657271495887, 0.028867834713310003, 0.07374049882803645, 0.11053203139454126, 0.940403938293457, 49.86622422082083, 36.056839329855784, 40.03299461092268, 20.25079229899815, 48.70827218464443, 25.038839374269756, 0.2652972313974585, 0.35083718278578346, 0.08604460502309458, 0.2170814693506275, 0.1635926216840744, 0.2875445761850902, 4.552609537328992, 0.5488420064960207, 0.7059147751757077, 0.9699668948139463, 0.867937863937446, 43.87663732256208, 62.28893974849156, 63.57550988878523, 60.79805782863072, 61.429628235953196, 49.36389378138951, 51.54897717067173, 58.79614979880196, 61.29077543531145, 66.5431410925729, 66.72583702632359, 69.29162611280168, 69.26133196694511, 71.45342608860561, 69.90186555044991, 69.05966745104108, 71.7545610155378, 66.7777887071882, 67.23530673980713, 67.61943095070976, 67.22376578194755, 63.475622585841585, 62.81530748094831, 65.48502077375139, 67.99095112936837, 65.04704802376884, 65.66453443254743, 64.96044567653111, 62.977534021650044, 66.81251580374581, 65.08777141571045, 66.2009562083653, 61.420449665614534, 60.206967626299175, 61.335591316223145, 61.626317841666086, 52.174923011234824, 50.719313621520996, 46.662889276232036, 50.067270347050254, 50.91697250093733, 50.09166547230312, 51.49519116537911, 50.05922433308193, 48.9757639339992, 50.78992468970162, 51.241772992270334, 49.96119567326137, 48.65882532937186, 49.41960096359253, 53.688171182359966, 47.79910734721592, 50.100020681108745, 47.758616719927105, 46.507892336164204, 48.962315695626394, 53.72890499659947, 56.09011479786464, 59.659664971487864, 52.91841152736119, 53.47814450945173, 51.70425203868321, 46.56720563343593, 42.02421283721924, 45.0745484488351, 45.331583159310476, 44.861739022391184, 42.05772399902344, 43.212233202798025, 44.277503217969624, 44.32376085008894, 44.659442220415386, 44.79988963263375, 43.82776716777256, 44.96338421957833, 46.82998303004673, 48.24405608858381, 47.460775239127024, 45.52403088978359, 44.902538844517295, 44.52134329932076, 50.6937129838126, 54.11187580653599, 54.147791045052664, 57.397685868399485, 56.159086091177805, 55.685031345912385, 57.081709589277, 57.24827527999878, 50.34504543031965, 52.451381410871235, 55.62000315529959, 54.08541359220232, 55.55441910879952, 53.59411689213344, 56.45557962145124, 53.2727175440107, 54.245222159794395, 58.89360523223877, 56.062495708465576, 58.170454093388145, 53.497199944087434, 55.21332509177071, 57.1490341595241, 59.06560788835798, 62.69374874659947, 66.56088679177421, 63.158034324645996, 61.53937503269741, 48.41027089527675, 55.261847836630686, 47.46481214250837, 42.619603974478586, 29.54712070737566, 38.676397051130024, 34.17918593542916, 28.19020700454712, 12.337019051824297, 20.279550892966135, 4.823371716908046, 0.33254303729959894, 0.08932066030268158, 0.1302931492349931, 0.09742605965584517, 0.06821721020553793, 0.12118349091282912, 0.09004640100257737, 0.28033869713544846, 7.162569190774645, 41.37070001874651, 16.775138344083512, 34.129419463021414, 28.34323934146336, 0.05951676956777062, 0.08701064889984471, 0.025282357287194048, 0.05707885431391852, 0.07708543219736644, 0.05635114925514374, 0.09983976478023188, 0.03927781718916126, 0.010864040298786546, 0.05681638679068003, 0.05216597918687122, 0.07890700016702924, 0.04259225380207811, 0.03241912754518645, 0.03484475452985082, 0.055569402274808714, 0.015187769762373396, 0.0246087806631944, 0.039124386850744486, 0.03263083725635495, 0.03203088677089129, 0.08661012324903693, 0.04929976584389806, 0.04381692808653627, 0.19988748697297914, 1.427603155374527, 57.34747471128191, 45.496526445661274, 46.147322518484934, 21.08535259110587, 55.92727681568691, 27.977988174983434, 0.20484805293381214, 0.22094151936471462, 0.046453175733664205, 0.3336972253663199, 0.2992434969970158, 0.14469645278794424, 2.3744630558150153, 1.5729012787342072, 1.345187640615872, 1.6594277386154448, 1.0671955347061157, 57.74970940181187, 66.20433303288051, 65.04119764055524, 65.4664204461234, 65.27806173052106, 55.65485184533255, 56.55927801132202, 62.86505658285958, 65.97175598144531, 68.52104309626988, 70.44620132446289, 72.00252832685197, 72.63238947732108, 74.10790198189872, 73.3680647441319, 70.59405204227993, 77.18299402509416, 69.1893138885498, 68.43516336168561, 72.95323644365583, 69.01847158159528, 65.43055384499687, 64.28661632537842, 65.10803236280168, 69.8247127532959, 66.46525873456682, 68.43091801234654, 65.26067733764648, 65.8160537992205, 71.8056789125715, 68.70564283643449, 68.7343805858067, 66.71669319697789, 64.52966431209019, 62.37256826673235, 64.3142215183803, 54.95976448059082, 53.921495165143696, 51.62851667404175, 54.86118343898228, 55.04212147848946, 51.917377608163015, 53.656761850629536, 52.579158782958984, 49.75434085300991, 50.292739391326904, 53.45683091027396, 51.77262231281826, 50.90347909927368, 52.118458475385395, 53.400404589516775, 52.533126967293875, 49.53545870099749, 50.79979460580008, 46.852203369140625, 51.38054936272757, 56.892812388283865, 58.36959988730294, 62.84030015127999, 54.173853737967356, 54.401765074048726, 52.45170797620501, 46.797475882938926, 44.237749099731445, 48.013351576668875, 47.61792264665876, 47.15324796949114, 45.11971173967634, 44.904248101370676, 46.18942860194615, 44.69283178874424, 46.77472748075213, 47.52284002304077, 45.472173009599956, 45.51313958849226, 48.30107300622122, 48.59977258954729, 48.311311176845, 46.87753997530256, 46.87449319022042, 47.919359820229666, 51.250322750636506, 54.535382407052175, 56.49461807523455, 58.028356484004426, 58.56404522487095, 58.480097089494976, 60.592988695417134, 59.57282638549805, 56.666933400290354, 55.09001541137695, 58.106586251940044, 58.15620681217739, 59.2214629309518, 58.83596992492676, 60.28922734941755, 56.77532182421003, 56.00431496756417, 61.819832120622905, 60.41619178227016, 60.30046953473772, 55.36573382786342, 59.8918251310076, 59.608581815447124, 60.14892932346889, 61.0910564150129, 65.35531875065395, 64.18425546373639, 62.272618430001394, 51.259539536067415, 55.77981172289167, 51.95410578591483, 49.066437925611226, 34.817725385938374, 39.51140376499721, 39.795355796813965, 38.69102300916399, 23.705952542168752, 28.636809417179652, 8.801826851708547, 0.1727660894393921, 0.6006268220288413, 0.21334704330989293, 0.0845870982323374, 0.10480571152376277, 0.2146010845899582, 0.012041866829219674, 0.21785200014710426, 9.213446821485247, 44.931894983564106, 20.155765260968888, 41.43937948771885, 33.89281245640346, 0.0453448939536299, 0.06896642143172876, 0.04465315803619368, 0.047354521296386204, 0.07545336548771177, 0.037514372529195886, 0.058570247143507004, 0.06012204994580575, 0.010363681790685015, 0.08015602028795651, 0.05414967292121478, 0.02171028940938413, 0.04720532501648579, 0.1140030026435852, 0.21208500888730797, 0.16194105387798377, 0.1920569757265704, 0.18547803589275905, 0.21217753392245087, 0.2615229753511292, 0.1850730319108282, 0.28216091649872915, 0.1497301376823868, 0.2243311817624739, 0.3895290680229664, 2.0071669476372853, 67.04065990447998, 49.30870076588222, 52.42635747364589, 31.12105097089495, 64.24386405944824, 33.86529758998326, 0.2364292847258704, 0.45193835773638313, 0.1939786954649857, 0.5837621869785445, 0.4026453127818448, 1.311547502875328, 10.901845182691302, 1.6622887679508753, 1.9221715884549277, 2.3504481273038045, 2.3107044313635146, 73.71082632882255, 80.33658681597028, 74.03907312665666, 71.64818409511021, 71.07759107862199, 61.93270560673305, 65.62076078142438, 72.7212221963065, 74.09612478528703, 77.37585517338344, 76.84204592023576, 79.25190353393555, 76.98004409245083, 77.74589538574219, 77.72994232177734, 75.08982835497174, 80.04622159685407, 68.71891389574323, 72.76397446223667, 75.85275445665631, 71.61943244934082, 68.88238416399274, 67.38588809967041, 69.72637489863804, 74.27880682264055, 69.40225533076695, 72.45100675310407, 69.24493421827043, 67.78813321249825, 74.97855295453752, 72.68101297106061, 74.9876411982945, 70.55877603803361, 67.62407234736851, 67.46340915134975, 70.11302130562919, 59.14517171042306, 56.82167673110962, 54.61304242270333, 54.636586393628804, 58.036888871874126, 54.55132852281843, 59.366576058524, 55.01005206789289, 54.11881358282906, 54.956933089665, 56.78138412748064, 56.85422556740897, 56.2682318687439, 55.58058255059378, 59.83056286403111, 54.30427142551967, 54.95510918753487, 53.5087582724435, 51.811490535736084, 54.03726257596697, 60.63614395686558, 61.93729141780308, 66.31761646270752, 57.491576875959126, 58.96353885105678, 57.46295724596296, 51.178916113717214, 46.129066126687185, 49.69066408702305, 51.034226826259065, 51.86597830908639, 46.812911306108745, 47.77695301600865, 48.11708123343331, 49.740163053785054, 50.683690207345144, 51.32696485519409, 49.504824093409944, 50.266534260341096, 52.33362681525094, 53.16164711543492, 52.054451669965474, 52.00665848595755, 49.65090649468558, 50.58781896318708, 56.35860013961792, 57.96885905947004, 59.2724974496024, 62.59325000217983, 62.397713797433035, 61.782402174813406, 65.33048588888985, 64.44269371032715, 58.22995151792254, 58.796059472220286, 60.99678325653076, 60.3727377482823, 61.623580251421245, 60.621768133980886, 63.59053884233747, 58.073974881853374, 58.322081157139365, 63.311151776994976, 60.26202515193394, 63.11635902949742, 57.8963337625776, 63.533257893153596, 62.40249415806362, 63.54504203796387, 65.67428275517055, 69.6969770703997, 65.85283756256104, 67.24592358725411, 56.981325490134104, 61.35844394138881, 59.77038451603481, 58.287284578595845, 48.13034534454346, 50.777897357940674, 48.66190685544695, 45.841935294015066, 29.65442521231515, 42.1369925226484, 7.845262272017343, 0.4560220528926168, 0.29619660334927694, 0.254215343190091, 0.29502455624086515, 0.15901633724570274, 0.4345513050045286, 0.23555340458239826, 0.49381591060331886, 14.582245179585048, 59.23872920445034, 30.489028930664062, 50.23602819442749, 40.03278963906424, 0.14645145647227764, 0.1776040034102542, 0.21399942758892262, 0.2044190830950226, 0.22865948879293033, 0.10763772670179605, 0.272454527339765, 0.16315306669899396, 0.11917832493782043, 0.1680402151708092, 0.22644563258758613, 0.19742851677749837, 0.15833839933787072], [0.039204959491533894, 0.1181787478604487, 0.1462020541408232, 0.10467930723513875, 0.11558955322418894, 0.19449299786772045, 0.09073463228664227, 0.15140253651354993, 0.07436365181846277, 0.010633858319904124, 0.0461786676065198, 0.17261123417743615, 2.822161763906479, 57.87415163857596, 32.94825349535261, 40.6576828275408, 25.33862461362566, 54.62301656178066, 15.971014635903494, 0.25485436032925335, 0.13745530348803314, 0.05764267620231424, 0.08490657966051783, 0.04345839357535754, 0.8881060960037368, 1.0982729813882282, 0.4675863523568426, 0.07311789545097522, 0.23368433916143008, 2.909437435013907, 25.608546495437622, 53.429260458265034, 74.19786725725446, 59.37993049621582, 60.33960178920201, 53.48194169998169, 38.00087581362043, 48.051597935812815, 62.01870346069336, 65.03540284293038, 64.79655851636613, 64.73052283695766, 70.0732706614903, 66.85881165095738, 66.5056208201817, 69.97967842647007, 71.4364377430507, 66.41726752689907, 66.34513132912772, 67.37841183798653, 64.02916472298759, 61.479578835623606, 63.87845829554966, 65.7485659463065, 69.19095366341728, 65.84274183000836, 63.7523832321167, 61.955836159842356, 62.97599152156285, 63.81247125353132, 63.42864581516811, 61.20322118486677, 61.485727991376606, 58.90430545806885, 59.87890148162842, 54.4857132094247, 50.94654403414045, 51.35076938356672, 50.50915493283953, 50.857673100062776, 49.89419419424874, 48.63133825574602, 49.197567803519114, 47.55021939958845, 45.21559688023159, 48.87182583127703, 49.85311644417899, 49.8115245274135, 46.18676744188581, 50.254941190992085, 49.51567717960903, 53.062732560294016, 51.421165057591026, 46.29624673298427, 46.155458859034944, 49.72328935350691, 53.183332443237305, 55.9515677179609, 56.00653144291469, 51.63623264857701, 49.18209763935634, 45.02664409364973, 42.88054357256208, 44.32723494938442, 48.35757923126221, 47.52415670667376, 44.48982627051217, 44.41278117043631, 43.63086911610195, 47.31732620511736, 45.13454614366804, 46.777419907706125, 43.783187525612966, 46.83230025427682, 47.89413091114589, 47.82139369419643, 48.71176018033709, 49.94562823431832, 48.67795719419207, 45.29107863562447, 46.12920161655971, 47.44291142054966, 52.71369327817644, 54.53041097096035, 54.754872526441304, 53.88941533224923, 54.53363493510655, 55.53158385413033, 54.394716126578196, 53.95207418714251, 50.929781505039756, 54.24921389988491, 53.754988534109934, 53.12471743992397, 54.853641169411794, 51.16655874252319, 55.28759091241019, 52.11973346982683, 54.63565533501761, 58.029958043779644, 60.41737992422921, 54.17183181217739, 54.19786671229771, 57.81865985052926, 57.798951285226, 59.35025474003383, 62.66814463479178, 63.82072571345738, 61.91462639399937, 46.17266954694475, 55.37344285420009, 52.38694381713867, 49.88517195837838, 44.76621866226196, 48.674927779606406, 45.31072119304112, 30.597535473959788, 16.9205676146916, 22.010487862995692, 15.934397629329137, 0.9884263042892728, 0.27558015819106785, 0.14233508306954587, 0.2030063189033951, 0.11962329463234969, 0.034666683192231824, 0.10066426625209195, 0.16378820261784963, 0.9050636632101876, 34.639094148363384, 25.68453025817871, 30.256497042519705, 39.40182719911848, 0.568692467042378, 0.02250371058471501, 0.0364074376411736, 0.07949778025171586, 0.11286346414791686, 0.01641424386096852, 0.01037924229500017, 0.12757881917059422, 0.024522900182221617, 0.045035868750086853, 0.05373589548149279, 0.03640855383127928, 0.029481684988630668, 0.05054109477038894, 0.1428453414035695, 0.04631183349660464, 0.0206122636861567, 0.035474943928420544, 0.06298582056271178, 0.10076231456228665, 0.10764634409653288, 0.02292678565053003, 0.058070478960871696, 0.08963988388755492, 0.21940068847366742, 4.7903638652392795, 65.01088265010289, 41.28916638238089, 34.92106246948242, 18.62938325745719, 62.76915059770857, 17.797438962118967, 0.21878615287797792, 0.10651146713644266, 0.06032583436795643, 0.12267725861498288, 0.12337536258356911, 0.6635249012282917, 1.506323748401233, 1.1595921367406845, 0.6575237746749605, 0.09303772263228893, 3.561387777328491, 39.94357476915632, 66.1393951688494, 74.68916743142265, 62.664392607552664, 62.96268572126116, 55.572859627859934, 46.20967217854091, 50.409823485783164, 69.14652688162667, 68.33535943712506, 71.438369342259, 68.51908370426723, 74.12953867231096, 69.28833266666958, 71.03888961247036, 73.7409884589059, 74.06533731733049, 66.99882480076381, 71.2579732622419, 67.73053959437779, 68.18750871930803, 62.67396722521101, 67.89973517826625, 67.5086419241769, 70.16802324567522, 68.11370495387486, 67.05787059238979, 65.28526701245988, 64.8164164679391, 67.23197160448346, 67.89776188986642, 65.15616253444126, 63.29867281232561, 61.32694775717599, 62.262911796569824, 58.5165125983102, 54.30754402705601, 53.57703821999686, 53.65464959825788, 55.81576517650059, 52.7196444102696, 51.788644858769004, 51.457507610321045, 50.9672600882394, 48.847965717315674, 50.212682247161865, 52.681933062417166, 53.53290326254708, 46.956930092402864, 51.91610261372158, 50.685260500226704, 54.78182111467634, 52.5220376423427, 47.23524713516235, 46.88179227284023, 53.16804640633719, 54.32268067768642, 59.24804673876081, 59.531262261526926, 54.90530450003487, 51.91353872844151, 46.804378918239046, 44.86791944503784, 47.54629714148385, 51.306283542088096, 48.61844934735979, 47.56313957486834, 46.69689376013619, 44.48873192923409, 47.735937799726216, 46.86704124723162, 47.09679038184029, 45.709954261779785, 45.950000626700266, 48.10562712805611, 47.15918173108782, 48.69617189679827, 50.59292936325073, 49.026732444763184, 48.111845765795024, 46.1627197265625, 50.088153157915386, 50.449494225638254, 55.96798631123134, 56.4322440964835, 58.1199962752206, 55.646375043051584, 59.06942939758301, 58.70932510920933, 58.54207502092634, 55.92248603275844, 56.18847697121756, 58.24751656396048, 58.76543876102993, 59.38812242235456, 56.746785572596956, 58.305600030081614, 55.367456981113975, 58.294211932591026, 59.8636918749128, 61.45161928449358, 55.600016662052695, 56.76500374930245, 58.847517830984934, 59.90837574005127, 60.73036847795759, 63.67006097521101, 62.89127213614327, 60.50126552581787, 48.15618569510323, 56.26547690800258, 57.89292567116873, 54.43608570098877, 49.63869503566197, 49.30589369365147, 48.80460895810808, 39.74059704371861, 29.830291066850933, 34.80587523324149, 20.920468364443096, 1.5174775613205773, 0.04663012409582734, 0.08410160642649446, 0.07540949141340596, 0.04930446130622711, 0.08690271433442831, 0.0364404721185565, 0.28856631421617096, 0.8582237394792693, 35.70244298662458, 25.963087013789586, 33.43334545407976, 47.585794176374165, 0.864468378680093, 0.0334725158422121, 0.024239481193944812, 0.11543582433036395, 0.10922142064997128, 0.015407418333260077, 0.039168644297335825, 0.03256682426269565, 0.010664956427977552, 0.06063675268420151, 0.07218391235385622, 0.009223742111186897, 0.023696868613894497, 0.11122330251548972, 0.332170087311949, 0.36814536260707037, 0.21159263673637593, 0.23065508742417606, 0.377780017043863, 0.2937297485768795, 0.2646755033305713, 0.17301783950201102, 0.15286332741379738, 0.16114752074437483, 0.34929658259664265, 5.754342172827039, 77.5693416595459, 46.49246733529227, 54.58403369358608, 38.60042197363717, 72.52543585641044, 22.833383866718837, 0.4273666505302702, 0.2349726871720382, 0.14677035436034203, 0.2988085560500622, 0.19858968018421105, 1.5781096049717493, 2.1302883752754758, 1.1204942975725447, 0.3057026889707361, 0.9793820296015058, 4.090907820633479, 57.21462515422276, 80.82909597669328, 83.55402660369873, 70.81912503923688, 68.244873046875, 64.85988439832414, 53.99728264127459, 58.60651956285749, 76.8267181941441, 74.28091212681362, 75.06140327453613, 73.5054097856794, 78.94525868552071, 72.45806612287248, 76.02809919629777, 77.67406490870884, 76.14685085841587, 70.95061274937221, 74.58953026362828, 69.7742896761213, 69.47152192252022, 65.12411744253976, 69.72406809670585, 71.50596836635044, 74.28031458173479, 72.21043232509068, 69.75303513663155, 66.93000984191895, 67.6459869657244, 69.90665285927909, 72.30822822025844, 70.10721955980573, 67.14452852521623, 65.0830327442714, 66.8428863797869, 62.05240222385952, 56.078896931239534, 58.021126883370535, 56.54873064586094, 58.70591354370117, 54.38683686937605, 54.23401818956648, 55.96398414884295, 53.8932055745806, 52.315144606998985, 53.53107588631766, 55.45758901323591, 55.241489614759175, 52.3037599836077, 57.4303354535784, 54.876976694379536, 60.87301499502999, 58.01249374662127, 51.631883076259065, 50.094611508505686, 54.05547380447388, 60.1529940196446, 61.53219754355294, 61.300655773707796, 57.39199529375349, 55.34599052156721, 49.655516624450684, 47.87611075810024, 49.05387210845947, 54.027910300663535, 51.17842279161726, 50.13678707395281, 50.4342359815325, 48.107301643916536, 51.1998336655753, 50.737500531332834, 52.126671246119905, 48.22618532180786, 48.922957624707905, 53.33225665773664, 50.9159893308367, 51.66419219970703, 55.980413164411274, 54.32552943910871, 50.97280822481428, 51.14821202414376, 53.65273536954607, 55.55576705932617, 60.061764172145296, 59.77760369437081, 61.53611632755825, 60.71833419799805, 61.62975719996861, 62.00250720977783, 60.00823525020054, 58.032066822052, 58.97600391932896, 62.058058057512554, 58.42925712040493, 59.88054820469448, 56.95348753247942, 60.228312492370605, 56.7475985118321, 57.95227370943342, 61.052771840776714, 64.42763696398053, 58.40061664581299, 60.30937712533133, 62.924588748386924, 61.59753145490374, 64.06145995003837, 68.16287040710449, 68.1175889968872, 64.71684183393205, 54.485706261226106, 63.038692065647666, 66.08158615657261, 61.968516622270855, 58.69641535622733, 58.93790694645473, 57.54338959285191, 45.40437943594796, 36.42815453665597, 44.178005014147075, 26.175701890672954, 1.8216869575636727, 0.6469151239309991, 0.26924823224544525, 0.4670237111193793, 0.19951822821583065, 0.18540468625724316, 0.19641815099333013, 0.38992538675665855, 2.364608556032181, 49.855301652635845, 39.556983947753906, 44.129398890904014, 57.064307825905935, 1.0938910565205981, 0.12223980708846025, 0.1833254513995988, 0.2854607408600194, 0.23325181379914284, 0.06948056098605905, 0.09141974909497158, 0.24874206259846687, 0.1674759725907019, 0.165798851155809, 0.26446798018046785, 0.1943805374737297, 0.12534364339496407], [0.009699785316895162, 0.043581727493022165, 0.07097715139389038, 0.11057348988418068, 0.16191875721727098, 0.10147279500961304, 0.2090455519833735, 0.058088453353515694, 0.048309881639267714, 0.11814525537192822, 0.023705935538081185, 0.09387785755097866, 25.483357327325002, 56.20093509129116, 26.546193735940115, 37.49869128635952, 28.24432131222316, 49.75836385999407, 7.422982897077288, 0.043748881202191114, 0.31815793205584797, 0.027491926847557937, 0.3562117229614939, 0.1789320864315544, 0.017251615445794802, 1.1328646966389246, 2.2049689165183475, 0.8918847760983876, 2.26077076792717, 9.73930994101933, 13.351300580160958, 40.111373765128, 63.43831075940813, 64.74067415509904, 53.45651824133736, 46.52929278782436, 39.00984457560948, 45.29676226207188, 59.2123191016061, 61.59912954057966, 68.19403307778495, 62.67343916211809, 69.65264061519078, 66.90765053885323, 66.54519081115723, 71.55735724312919, 70.60553046635219, 63.36027554103306, 64.46820749555314, 65.41533034188407, 64.13795266832624, 63.38494859422956, 65.65268080575126, 64.12733582087925, 63.75638539450509, 64.67224829537528, 65.03948143550328, 63.54727240971157, 63.61278697422573, 62.33707686832973, 62.185606139046804, 61.12677015577044, 58.492617743355886, 56.265879903520855, 55.494873046875, 53.26184013911656, 50.45988873073033, 51.21800667898995, 52.73151193346296, 48.8885258265904, 50.856738567352295, 48.369290419987266, 46.05990028381348, 46.93782254627773, 44.986823967524934, 47.6844481740679, 49.889611857278005, 52.492215973990305, 49.01734890256609, 48.28350796018328, 45.1703919001988, 49.5227678162711, 53.795500005994526, 45.87705496379307, 47.42640944889614, 52.588882786887034, 54.44867583683559, 54.291399887629915, 56.01838506971087, 54.85387740816389, 50.75942209788731, 47.21333599090576, 42.07424681527274, 45.42975425720215, 48.76280859538487, 44.68614762169974, 43.109726428985596, 42.089157649448936, 45.790588106427876, 48.476181507110596, 46.521535124097554, 46.38610431126186, 43.89161763872419, 46.15134899956839, 45.7399947983878, 46.466724259512766, 47.78057302747454, 50.03475625174386, 48.50917502811977, 51.62941299165998, 46.57119389942714, 46.52582911082676, 47.54235403878348, 52.50480610983712, 54.29269225256783, 52.73183849879673, 53.413953576769146, 54.88903876713344, 53.64325107846941, 52.07692214420864, 52.64706352778843, 50.57005589348929, 55.19250134059361, 55.75381851196289, 55.9244384765625, 53.25559718268258, 53.850362982068745, 53.665301186697825, 50.75277614593506, 55.304617473057334, 58.076135771615164, 56.007288796561106, 51.83971411841256, 56.24362482343401, 60.56521674564907, 58.93356432233538, 61.19739164624895, 63.25813007354736, 64.24637930733817, 44.10187707628523, 53.91737140927996, 59.905679838997976, 50.062830448150635, 53.43572923115322, 44.19407967158726, 38.38347142083304, 26.244261503219604, 17.631917238235474, 17.995236805507115, 23.09275143487113, 2.4801736005714963, 1.7623641065188815, 0.7518279286367553, 0.10431826553706612, 0.27675073966383934, 0.08015595921980483, 0.1905361209064722, 0.07521505720381226, 0.13969331554004125, 21.471121788024902, 37.185556820460725, 17.916004759924753, 45.17280639920916, 2.241143843957356, 0.0359692634748561, 0.059832919389009476, 0.002493903086620516, 0.2628034252141203, 0.08203358096735817, 0.06822244171053171, 0.033971004986337254, 0.031259490842265744, 0.1321493767734085, 0.17266669762986048, 0.17813872971705028, 0.03635456279984542, 0.11650416414652552, 0.06887877506336995, 0.017221183150208423, 0.05904992390424013, 0.17930039523967675, 0.09584678975599152, 0.03274380655160972, 0.15153292380273342, 0.10521703945206744, 0.14419402474803583, 0.03117332368024758, 0.04738811556515949, 32.41833175931658, 65.94964681352887, 39.05403164454869, 37.72137757710048, 29.113203968320573, 59.56336988721575, 8.482439007077899, 0.09192681152905736, 0.09576750972441264, 0.11246606654354505, 0.10098743891077382, 0.11299019413334982, 0.08865431855831828, 0.570342338510922, 2.1620844176837375, 0.8345095376883234, 1.8107869710241045, 13.388320582253591, 20.61742615699768, 56.43810142789568, 69.12135355813163, 66.57383128574916, 58.95483275822231, 52.668700218200684, 44.87289782932827, 52.93983282361712, 63.88590676443917, 65.08604826245988, 69.52220903124127, 68.1694781439645, 73.55914715358189, 69.96248163495744, 69.46121774400983, 76.24551527840751, 69.34091663360596, 66.58862400054932, 69.04530552455357, 67.9536531993321, 63.205796241760254, 65.35301194872174, 69.36034379686627, 68.59941182817731, 66.2526091166905, 67.34920161111015, 67.77499416896275, 65.55205004555839, 65.7510186604091, 64.47722625732422, 65.09094674246651, 63.78475488935198, 62.33398491995675, 59.93559183393206, 59.01606723240444, 56.56466286523001, 52.81947265352522, 54.32041556494576, 55.92253814424787, 53.87458092825753, 55.05209214346749, 52.07183606284005, 49.515409673963276, 48.65920400619507, 49.44955117361886, 52.80537823268345, 51.837233611515586, 55.78864288330078, 51.51460443224226, 48.66988338742937, 48.437414033072336, 51.50047527040754, 57.93893664223807, 49.373127937316895, 48.84934493473598, 54.71708127430507, 55.643185819898335, 57.76909487588065, 59.2698849269322, 57.82404817853655, 52.061851501464844, 49.64244358880179, 45.3268757547651, 49.91723789487566, 51.42701544080462, 47.81246525900704, 45.93201174054827, 44.67481510979788, 47.93659482683454, 48.471901416778564, 46.530640738351, 49.48308318001883, 45.39838661466326, 46.0404349054609, 48.254141398838584, 48.131036690303254, 47.594145911080496, 50.716652461460654, 49.197345461164204, 52.35115017209734, 50.303106103624614, 48.310790061950684, 48.847364698137554, 55.351483072553364, 56.46531057357788, 57.268935748508994, 57.09520646503994, 57.78288357598441, 57.64699418204171, 56.799960136413574, 57.08183813095093, 55.798655237470356, 57.01198441641671, 59.056582178388325, 58.163217544555664, 58.35050623757498, 57.48961053575788, 58.70979758671352, 54.314280305589946, 57.84654644557408, 60.79256180354527, 57.835693359375, 53.68754584448678, 57.56038836070469, 60.399217333112446, 61.91785730634417, 61.85578210013253, 63.42033576965332, 61.43540218898228, 48.26102706364223, 53.9311774798802, 64.85802228110177, 54.3881014415196, 58.937100955418174, 51.64895827429635, 48.488615308489116, 35.24620342254639, 28.356750113623484, 30.39198691504342, 32.704687867845806, 3.160674742289952, 0.7055943980813026, 0.7566435188055038, 0.8096888352717672, 0.3828998351735728, 0.05976253495152507, 0.18365625079189027, 0.046623806934803724, 0.1233354104416711, 23.554924760546, 35.86958885192871, 20.044882433755056, 59.06890828268868, 3.4806171400206427, 0.09386755060404539, 0.10189068437154804, 0.019259446367089237, 0.12129281647503376, 0.04051102405147893, 0.016040360887667963, 0.025570329245445982, 0.022866329876706004, 0.03404503994222198, 0.11885227529065949, 0.0636516601911613, 0.04290325693520052, 0.3101473647568907, 0.17611968091556005, 0.16621719513620647, 0.1732642969914845, 0.391951573746545, 0.27233562086309704, 0.4419792821364743, 0.3964053690433502, 0.49749069341591423, 0.34764730823891504, 0.16898278173591408, 0.20020128227770329, 36.30186060496739, 76.4016204561506, 36.75836072649275, 56.171193327222554, 44.490323066711426, 66.46756553649902, 11.862299016543798, 0.36632295325398445, 0.37773189534034046, 0.21921437632824692, 0.5887873630438532, 0.4585373007825443, 0.5133689013975007, 3.1456549082483565, 12.86476947580065, 3.769626157624381, 3.331136852502823, 19.136200496128627, 32.702193464551655, 69.76349912370954, 76.12111473083496, 73.45632076263428, 65.27191257476807, 58.54877308436802, 54.68287876674107, 59.13294982910156, 71.38597992488316, 71.4942467553275, 74.48154136112758, 71.29975278036935, 78.5597448348999, 74.60182162693569, 74.40668146950858, 79.28818007877895, 73.8198435647147, 69.36573559897286, 71.15269415719169, 69.14885452815464, 66.07538141523088, 68.7702888761248, 71.1778813770839, 69.96494824545724, 68.0052296774728, 70.49342128208706, 70.46869264330182, 68.31279168810163, 69.18883446284703, 67.36271585736955, 69.62074838365827, 67.77363232203892, 66.27302292415074, 63.130616733006065, 62.90907342093331, 60.43619564601353, 58.43647629874093, 56.8649640083313, 59.40764686039516, 53.203704561506, 57.33739982332502, 55.115758487156455, 52.289953913007466, 50.244032519204275, 49.71195684160505, 56.060487679072786, 55.23648691177368, 58.21757330213274, 54.76003156389509, 54.2553665297372, 52.87112556185041, 57.38070099694388, 61.19348675864083, 51.920507771628245, 52.11692639759609, 58.907911573137554, 58.36160945892334, 59.8387200491769, 61.81646919250488, 62.102547373090474, 55.32246044703892, 51.209161622183665, 47.835255350385395, 50.713532720293315, 56.61945983341762, 51.94626126970564, 49.69309248243059, 47.41099834442139, 50.817908559526714, 52.55191142218453, 50.68675783702305, 52.39091123853411, 49.70592927932739, 49.97768027441842, 52.31104169573103, 52.96588856833321, 53.911555767059326, 57.65641941343035, 55.75500317982265, 58.96949345724923, 53.0525221824646, 52.923018183027, 55.30880723680769, 59.02826826913016, 59.322705132620676, 57.77300671168736, 59.304806573050364, 60.348981857299805, 60.54606056213379, 57.4214243888855, 58.57449531555176, 55.682081835610525, 59.30991349901472, 58.66646862030029, 60.23212705339704, 58.42562321254185, 58.83967331477574, 56.95883764539446, 54.500009128025596, 58.00756399972098, 61.82190268380301, 58.1037722315107, 56.129080295562744, 60.939940043858115, 64.40217181614467, 65.19760853903634, 65.67609623500279, 69.15454510280064, 66.43567330496651, 54.60458646501814, 60.38147163391113, 68.7128689629691, 62.11321285792759, 65.7074465070452, 56.13699776785714, 51.91133962358747, 39.960695130484446, 35.97350263595581, 37.620388984680176, 46.34545387540545, 3.706206040722983, 3.754022240638733, 1.2788580741201128, 0.7541174686380795, 0.6239453021969114, 0.16659975317972048, 0.3077036887407303, 0.2729960254260472, 0.5883299218756812, 32.60668352672032, 54.197220529828755, 28.223464557102748, 63.68898091997419, 4.1324280841009955, 0.16182814565088066, 0.3280370219477585, 0.15587476082146168, 0.22841366912637437, 0.1481831864054714, 0.14598195095147404, 0.10031822017793145, 0.14470432379416057, 0.1470476444810629, 0.25138188951781815, 0.23773223481007985, 0.1593035204069955], [0.11521399766206741, 0.07501436011599642, 0.1350126995572022, 0.10882373127554144, 0.03771269813712154, 0.17646415957382747, 0.08029769839985029, 0.10262149372803313, 0.3414345330425671, 0.2723116007234369, 0.8744535371661186, 7.168309705598014, 66.80255903516496, 41.982964856284006, 21.348630258015223, 23.716461692537578, 32.99736336299351, 39.060847827366416, 1.5588113090821674, 0.0335430020599493, 0.07598260923155717, 0.10863646918109485, 0.06768739649227687, 0.174231155110257, 0.17460709065198898, 0.8177429373775209, 1.6096899275268828, 0.7884549775293895, 5.5680522833551676, 13.36958042212895, 14.305937903267996, 39.041014194488525, 60.986604145595, 58.06644303458077, 44.206113951546804, 41.57199280602591, 41.034976959228516, 48.89085347311837, 65.79993397848946, 59.11046545846121, 65.2606634412493, 62.260125568934846, 68.26380688803536, 63.58319459642683, 65.4493487221854, 73.31341021401542, 60.33889307294573, 65.50171729496547, 68.10663863590786, 59.35884966169085, 57.36479309626988, 62.82074097224644, 66.19218758174351, 64.33695602416992, 63.10522106715611, 64.62771729060582, 62.8682735988072, 61.86785806928362, 63.379931994846885, 63.1687137058803, 58.199132783072336, 59.293230874197825, 56.78877353668213, 53.85812759399414, 53.43579871313912, 50.03540243421282, 48.778310026441304, 54.10014377321516, 50.643001556396484, 53.59619787761143, 48.48005860192435, 47.896455083574565, 46.828603812626426, 49.84244748524257, 45.45036956242153, 47.32264157703945, 47.553293977464946, 47.978502886635916, 46.98668922696795, 45.493688106536865, 42.438554763793945, 44.20202841077532, 50.075743675231934, 47.134720597948345, 44.60006291525704, 48.2203939982823, 49.64759220395769, 53.84289366858346, 54.095432894570486, 52.29005813598633, 48.57392181668963, 48.32896307536534, 44.01226615905762, 48.37306676592146, 45.74915599822998, 43.772483825683594, 39.811201163700645, 43.49031400680542, 47.07764114652361, 44.270231928144185, 43.505693844386506, 45.5785151890346, 40.82095854622977, 44.54779509135655, 42.897490228925435, 43.01696450369698, 43.226407527923584, 45.33203479221889, 44.01362453188215, 47.64546530587332, 46.02513149806431, 45.64756638663155, 42.058099201747346, 49.97811801092965, 53.40121405465262, 54.93229477746146, 55.38487958908081, 56.19929184232439, 56.534987109048025, 53.948023387363975, 55.53604459762573, 52.012699944632395, 53.413654804229736, 59.156129019601, 55.48712927954537, 57.61394854954311, 54.9004407610212, 59.65301554543631, 52.27392789295742, 55.48136574881417, 58.35409845624651, 60.46661485944475, 52.81446647644043, 53.11741835730416, 58.462372234889436, 59.70728097643171, 59.06649030957903, 60.19151483263288, 63.7364718573434, 42.151465620313374, 47.836565085819785, 69.279543195452, 48.20876618794033, 43.42278446469988, 27.238642522266932, 22.989395243780955, 19.03202268055507, 18.435488564627512, 12.948827913829259, 19.16369104385376, 5.995511540344783, 0.2246008315788848, 0.23162221695695603, 0.2104596732450383, 0.11935094424656459, 0.2605433879154069, 0.0553640775781657, 0.015410956893382328, 0.18897071347704955, 5.329549287046705, 54.58966520854405, 18.19263686452593, 44.04753174100603, 19.950086423328944, 0.2641563154757023, 0.2511536031961441, 0.12433171698025294, 0.24044556064265116, 0.02997480352808322, 0.06709331194204943, 0.09564073224152837, 0.04455600878489869, 0.1133548320670213, 0.12983474454709462, 0.04859211488759943, 0.07856156477438551, 0.07247943471052817, 0.07919300946273974, 0.13299266009458474, 0.033370528636234145, 0.04208493691736034, 0.25154424937708036, 0.4644552118011883, 0.30142943827169283, 0.43004463825907024, 0.3243336049573762, 0.6016363192881856, 12.374623571123395, 74.18240056719098, 54.29997396469116, 34.21645259857178, 21.914364746638707, 38.022495133536204, 42.944380147116526, 2.811711673225675, 0.06623764535678284, 0.08994415934596743, 0.08730437992406742, 0.21608238081846917, 0.054756442683615854, 0.12469081128282206, 0.46772292788539616, 2.1697739022118703, 0.31645174218075617, 6.570782431534358, 18.49925218309675, 16.9672178200313, 51.81330401556832, 69.02192483629499, 60.256556919642854, 53.01511655535017, 50.092089312417166, 48.00744213376726, 55.54015793119158, 66.02117156982422, 63.970334325517925, 69.96316950661796, 67.59455639975411, 72.45901802607945, 68.23033741542271, 69.10260731833321, 73.57362025124687, 63.032577650887625, 68.74488626207624, 68.87054443359375, 63.286840030125205, 56.97326905386788, 63.921662194388254, 66.99100807734898, 68.46959168570382, 65.19769191741943, 66.2740512575422, 65.78987298692975, 66.1211769921439, 65.22001647949219, 66.08660275595528, 62.47759028843471, 62.234639576503206, 59.974967275347026, 58.22496618543352, 57.618086201804026, 52.9909541947501, 54.07607173919678, 56.49243286677769, 54.91774524961199, 55.757250922066824, 52.77226659229824, 53.52087593078613, 47.30549342291695, 51.377464362553184, 50.22862488882882, 50.30611119951521, 49.875538281032014, 51.68206991468157, 49.96795974458967, 47.956421511513845, 45.23415551866804, 47.45107207979475, 51.50080530984061, 50.75355781827654, 48.50011110305786, 51.78172097887312, 50.92215585708618, 57.76674291065761, 57.90473760877337, 54.765670027051655, 50.026866572243826, 49.22167805262974, 46.81540223530361, 51.95366110120501, 48.36737619127546, 45.6010308265686, 42.17743798664638, 45.38348967688424, 48.65536512647356, 45.511892386845176, 46.91242340632847, 47.04712813241141, 42.74611677442278, 45.06739180428641, 46.388386794498985, 46.93933725357056, 47.48704290390015, 48.5853932925633, 47.3508095741272, 51.05283062798636, 49.35786621911185, 48.04979487827846, 45.5581430707659, 49.89033099583217, 55.95029272351946, 57.35701806204659, 57.630989006587434, 57.14262097222464, 57.92641598837716, 56.74344001497541, 58.898997034345356, 56.18940108163016, 55.31658227103097, 61.32070132664272, 56.9165335382734, 58.82362297603062, 55.20645679746355, 59.36037826538086, 55.717444692339214, 56.50214992250715, 61.52125413077218, 60.52485466003418, 55.6478202683585, 56.66188900811331, 60.10560730525425, 59.89515331813267, 58.88580240522112, 61.38123403276716, 65.13135051727295, 46.02305398668562, 49.26010159083775, 73.20813805716378, 57.20336559840611, 55.598130226135254, 40.48301206316267, 33.786935806274414, 25.151334183556692, 25.28145830971854, 24.148596218654088, 33.13050821849278, 11.575531227248055, 0.5945849833743913, 0.1218484416604042, 0.5632071899516242, 0.3298581013722079, 0.058263128623366356, 0.0778080312801259, 0.05946419667452574, 0.1856489045811551, 6.238071416105543, 56.18734788894653, 19.671725954328263, 50.59138338906424, 31.706759793417795, 0.131770984934909, 0.17203841491469316, 0.07029328987534557, 0.06213567725249699, 0.008762792068799692, 0.013207845290058425, 0.043371622517172775, 0.043104272934475114, 0.07814953116966145, 0.23981702008417674, 0.1057968611962029, 0.11060437679822956, 0.20062265252428396, 0.16104229353368282, 0.19081119900303228, 0.19299317763320037, 0.1550920299653496, 0.6718113880072321, 0.8618764291916574, 0.4659220959459032, 0.838172432567392, 0.5562090511832918, 0.7259513714483806, 14.695869071143013, 87.6531788962228, 56.685516357421875, 32.139344215393066, 37.22376496451241, 47.28376988002232, 54.82357631410871, 4.075297823974064, 0.3570667313677924, 0.19937368668615818, 0.22049513831734657, 0.313224656773465, 0.45745061337947845, 0.4424737984580653, 1.221971652337483, 9.007788828441075, 2.660604855843953, 8.500436578478132, 22.034730127879552, 37.11306973866054, 68.3605466570173, 76.51709951673234, 64.9257880619594, 60.97082478659493, 56.56814391272408, 55.86021975108555, 62.58496080126081, 72.01381220136369, 71.75636059897286, 73.2354097366333, 72.03735269818986, 76.98670046670097, 73.3596087864467, 72.56122602735246, 80.31032957349504, 65.23550401415143, 70.22729137965611, 69.74956103733608, 65.8104327065604, 61.600769315447124, 67.62594836098808, 71.14599609375, 70.96805272783551, 67.85509995051792, 70.9642312186105, 69.39058235713414, 69.40800843920026, 68.54106780460903, 69.78256498064313, 66.47214439937046, 67.83361612047467, 63.22606413705008, 61.146739278520855, 59.530101912362234, 56.62528937203543, 55.79875946044922, 59.79810088021414, 58.513608251299175, 60.00872162410191, 55.41618122373308, 54.20576681409563, 48.857964175088064, 54.51289108821324, 52.02221897670201, 51.69390617098127, 53.34094190597534, 55.0191194670541, 54.361889362335205, 51.39506762368338, 49.64953422546387, 53.56434733527047, 57.51360961369106, 53.291251863752095, 52.74401521682739, 56.336876596723286, 54.426281792776926, 59.26205430712019, 62.52681827545166, 59.88776043483189, 51.76304422106062, 53.63235630307879, 46.47656985691616, 53.49020658220564, 50.96327182224819, 48.7322712625776, 45.471512930733816, 46.94241183144705, 51.50784036091396, 48.53486599240984, 48.698405742645264, 51.307714870997835, 46.492661884852815, 49.313908440726145, 50.727922439575195, 53.44185406821114, 53.329195976257324, 52.11692292349679, 52.43428536823818, 57.83473450796944, 54.589508874075754, 52.09317398071289, 47.8482415335519, 55.33230257034302, 57.69805996758597, 60.87261894771031, 61.205257007053916, 59.9182630266462, 59.569609369550435, 56.60047388076782, 58.793912478855674, 56.15702247619629, 57.12861687796456, 61.85357257298061, 59.1293854032244, 60.8953742980957, 57.75584813526699, 62.92852142878941, 54.19599764687674, 55.30711882455008, 62.980903897966655, 62.33374868120466, 57.21339532307216, 58.02532706941877, 63.827764238630024, 63.29119655064174, 62.5391652243478, 66.14207717350551, 69.50755528041294, 49.05167300360543, 57.10690723146711, 74.02202224731445, 64.96458680289132, 61.314239501953125, 45.65264899390084, 38.37950052533831, 30.299683570861816, 33.347476141793386, 28.629105601991924, 48.2136264528547, 16.156951904296875, 0.7150394969752857, 0.8514046796730587, 0.7823200438703809, 0.2915592779006277, 0.4516588013087, 0.3580971003643104, 0.12827948800155095, 0.26343022872294697, 9.887962307248797, 75.79750932965959, 30.457508427756174, 58.89385536738804, 34.17561803545271, 0.2878885662981442, 0.36449164152145386, 0.22951669565268926, 0.35105002565043314, 0.13436244587813104, 0.18343632402164595, 0.148463923484087, 0.18056419385331018, 0.24798082773174557, 0.3565712922385761, 0.26388764274971827, 0.22475679963827133], [0.806740573474339, 0.11162722762674093, 0.04030858312866517, 0.020972285885363817, 0.23023252295596258, 0.4213193293128695, 1.6965043033872331, 6.366639580045428, 11.38917793546404, 13.90955012185233, 4.85068074294499, 41.8264080456325, 57.43734271185738, 36.1184663772583, 30.723839827946254, 31.125918184007915, 42.98630210331508, 29.032987015587942, 0.22623106624398912, 0.14128218671040876, 0.06687819598508732, 0.17942372576466628, 0.09161069563456944, 0.12578790741307394, 0.1751876316432442, 0.30708635758076397, 1.4715399805988585, 2.3898198774882724, 3.6270621504102434, 17.332887615476334, 20.018229143960134, 43.00446122033255, 53.15133598872593, 50.649904591696604, 44.77599825177874, 46.20323814664568, 51.522111960819785, 53.614509854997905, 53.93590225492205, 55.001342500959126, 65.9846796308245, 64.96926294054303, 64.8443134852818, 62.709284918648855, 68.5041172845023, 64.64108562469482, 58.63158866337368, 67.9013124193464, 64.87985352107457, 64.19582421439034, 57.710413864680696, 59.75395202636719, 61.95955344608852, 63.99283954075405, 63.59247044154576, 62.92126750946045, 63.157895360674175, 61.34404032570975, 62.62345382145473, 57.05692536490304, 57.95763424464634, 56.97881024224417, 57.37495831080845, 57.29743378502982, 48.61739322117397, 48.393532684871126, 50.71055889129639, 50.76769740240914, 52.10337046214512, 51.49272108078003, 49.04988036836897, 48.45215116228376, 48.60273947034563, 46.426772117614746, 46.59270204816546, 44.59676252092634, 48.32343578338623, 46.59914650235857, 48.127625124795095, 45.48833451952253, 41.91653312955584, 40.84906053543091, 45.593262740543906, 49.41945505142212, 47.369003432137625, 49.59727682386126, 49.64521244594029, 54.032103538513184, 53.55729143960135, 50.33399779456002, 48.375182492392405, 47.67018004826137, 46.94931486674717, 49.437152113233296, 44.50676250457764, 40.26958424704415, 41.67761584690639, 42.54893732070923, 43.615565708705354, 42.998034136635916, 45.54958636420113, 45.43984304155622, 41.38114663532802, 42.2230007989066, 43.579490661621094, 42.64483288356236, 40.82067019598824, 42.65530034473964, 44.80272102355957, 46.71244730268206, 46.80192273003714, 44.80580254963466, 43.680489676339285, 43.81027855191912, 51.14734697341919, 53.67148508344378, 51.59179891858782, 53.467531136104036, 55.65925700323922, 56.72127526147025, 56.09640291758946, 53.70608711242676, 50.02482032775879, 55.83353172029768, 53.79968976974487, 55.601347242082866, 52.89729247774397, 56.56545148577009, 57.44188683373587, 54.655204091753276, 54.775692803519114, 57.57101215635027, 58.129845346723286, 54.05428218841553, 54.59970188140869, 56.677720478602815, 56.92053917476109, 58.79284940447126, 61.20791121891567, 45.25425318309239, 37.228861468178884, 76.850008555821, 57.03861338751656, 38.34017024721418, 21.617720093045914, 13.016482523509435, 14.20233244555337, 14.125575695719037, 12.989330700465612, 14.397513423647199, 6.932985510144915, 2.4928343040602545, 0.5726181992462703, 0.09774880483746529, 0.05355828215501138, 0.1961926602359329, 0.0852859757308449, 0.1261213666626385, 0.015878484484606555, 1.3383348711899348, 29.85125378199986, 34.58531856536865, 19.343553849628993, 48.47423253740583, 5.717882803508213, 0.14103560708463192, 0.09471636398562364, 0.055431734304875135, 0.03343432789136257, 0.07582261745951005, 0.0822498911459531, 0.12411949836782046, 1.9312567923750197, 5.099699837820871, 5.392509085791452, 3.5057633221149445, 0.847040016736303, 0.11789381743541785, 0.14184587289180073, 0.15039203502237797, 0.32780045749885695, 0.4857485634940011, 0.9458785759551185, 3.3939355398927415, 12.074082715170723, 18.497282368796213, 8.73649902003152, 53.0078626360212, 62.84930501665388, 52.48123434611729, 29.615831443241664, 30.11572653906686, 46.68821198599679, 33.52237272262573, 0.41216168499418665, 0.12463452001767499, 0.006681096673543964, 0.3749651280897004, 0.14304814194994314, 0.22236143531543867, 0.14589154294558934, 0.6119234529989106, 2.7664491534233093, 3.615961968898773, 10.031739643641881, 20.371619735445293, 25.18724421092442, 53.32901879719326, 65.02659947531563, 59.89589677538191, 52.51180641991751, 51.96025841576712, 55.389170101710725, 60.681939533778596, 58.51614434378487, 61.85636574881417, 70.26208795819963, 69.68986906324113, 69.48252092088971, 68.11211381639752, 68.83228765215192, 67.00661373138428, 63.66475255148751, 70.23242609841483, 64.79204913548061, 66.21219839368547, 58.53908729553223, 61.92832129342215, 66.16665295192173, 67.16549818856376, 65.85536670684814, 66.93122577667236, 66.89079420907157, 64.6477906363351, 64.14983408791679, 60.684253283909385, 61.21690913609096, 58.564760889325825, 59.048049790518625, 59.292278970990864, 52.549945081983296, 54.90460968017578, 55.26930325371878, 54.776860100882395, 56.69693572180611, 53.36058446339199, 53.823959827423096, 51.26595272336687, 51.03059639249529, 46.76055662972586, 48.588943822043284, 48.53817333493914, 52.028854506356375, 50.566564423697336, 51.358652114868164, 47.41268328257969, 44.95091915130615, 45.61983265195574, 48.72531958988735, 52.49097919464111, 50.028051240103586, 53.894230433872764, 55.496422495160786, 57.643690313611714, 56.597687653132844, 54.68571710586548, 52.4181273324149, 50.02276018687657, 49.655853612082346, 51.21714162826538, 45.456153937748496, 42.23246077128819, 42.93447896412441, 42.17229284558977, 44.449134145464214, 45.618884222848074, 47.58066987991333, 47.435626234327046, 43.113231795174734, 43.50060428891863, 46.30213533129011, 46.84815256936209, 45.23909568786621, 46.933521611349924, 46.73297575541905, 48.73622131347656, 49.412552016122, 48.42809649876186, 46.378895555223735, 45.608489717756, 52.2376617704119, 56.07980367115566, 55.33143751961844, 55.81196451187134, 56.9927031653268, 56.69171762466431, 57.48626497813633, 56.584791796548025, 51.61348077229091, 55.66928325380598, 57.101129804338726, 58.14219924381801, 55.4463746207101, 58.77359594617571, 59.23420592716762, 55.91942187717983, 55.30134834562029, 60.3780392238072, 59.68459510803223, 57.54481744766235, 58.65922164916992, 58.084796701158794, 59.71311051504952, 60.655946322849815, 61.49494130270821, 49.926458154405864, 43.47982917513166, 76.16955757141113, 65.85619354248047, 53.68148701531546, 39.69664968763079, 27.174072912761144, 21.612303972244263, 18.046870606286184, 20.15270631653922, 24.31135777064732, 15.43208282334464, 7.046844337667737, 0.7454858518072537, 0.7730732943330492, 0.34335755556821823, 0.08089356749717679, 0.03358639437439186, 0.2726889747594084, 0.025007204551781927, 1.4982651408229555, 35.273582799094065, 37.30828980037144, 17.91771227972848, 61.36000033787319, 11.31274948801313, 0.05796315507697208, 0.06362329742738179, 0.06818206209157195, 0.11406261873032365, 0.04243637055956891, 0.09119729817445789, 0.14574853490505899, 1.927846529654094, 4.9089257546833585, 5.622012862137385, 3.7094039491244724, 0.9887668745858329, 0.2579736943755831, 0.3159357027283737, 0.31024995925171034, 0.6857445346457618, 0.612351364323071, 1.9180230796337128, 7.630644576890128, 20.01581985609872, 29.251620769500732, 17.03991334778922, 65.08498518807548, 71.13783196040562, 54.06826891217913, 39.9103102684021, 47.14446892057146, 55.68045595714024, 41.74050399235317, 0.6709023139306477, 0.35588162924562183, 0.12373466044664383, 0.5644416351403508, 0.21541232748755387, 0.4830562451056072, 0.20710764239941323, 1.217155356492315, 5.5604018824441095, 5.625192531517573, 14.866918087005615, 32.5180001940046, 45.88757106236049, 66.02211652483258, 68.29412187848772, 63.29069628034319, 59.795488357543945, 58.65648405892508, 61.81342588152204, 64.92622579847063, 67.37315899985177, 67.40730244772774, 74.73021738869804, 74.40230410439628, 72.69706330980573, 70.47619669778007, 72.68744005475725, 71.15560545240129, 63.52293981824602, 73.4908949988229, 68.00695283072335, 67.32922554016113, 61.73755850110735, 65.44244916098458, 69.64486558096749, 71.7343556540353, 68.58945505959647, 69.56791428157261, 69.63035774230957, 67.71513543810163, 68.85038076128278, 63.2809271131243, 63.5707642691476, 61.68668379102434, 65.08039242880685, 63.05138642447335, 55.740203516823904, 56.4118024962289, 56.85641424996512, 58.782809257507324, 60.31410190037319, 57.172439166477744, 55.64060803822109, 54.364477566310335, 53.428572586604524, 51.25200421469552, 50.39897387368338, 50.28220592226301, 54.58272048405239, 53.17368139539446, 54.753270966666086, 51.2851436478751, 48.361032485961914, 49.55526801518032, 51.70700352532523, 55.411644050053184, 51.069214480263845, 56.39034645898001, 55.629807063511436, 59.33954061780657, 57.613427434648784, 55.54005370821272, 53.04943718229021, 50.93532964161464, 51.82718651635306, 53.5452675819397, 48.481215476989746, 46.38781009401594, 44.676350661686485, 45.62019395828247, 48.234575271606445, 47.42222315924508, 50.22209358215332, 50.43771355492728, 45.43268987110683, 46.620362826756065, 50.77561487470354, 50.015836306980674, 49.33082730429513, 50.14491299220494, 51.319335733141216, 56.24299601146153, 54.67088270187378, 51.81575672967093, 51.52404703412737, 50.40667595182146, 56.677491188049316, 58.19308090209961, 56.78974975858416, 57.22768776757376, 59.42800508226667, 60.38591153281075, 59.00280312129429, 56.679728507995605, 53.97508314677647, 60.71679169791085, 59.14378901890346, 59.79665565490723, 55.75802564620972, 60.53211552756173, 60.806673594883506, 56.117494174412315, 55.08252872739519, 61.01939269474575, 62.080577169145855, 58.38668550763811, 62.16898604801723, 61.51444489615304, 61.817963055201936, 66.82107598440987, 67.32514694758824, 53.0033324105399, 52.601111616407124, 76.1985524041312, 67.96513857160295, 61.99109826769148, 46.58434336526053, 33.15023415429251, 27.08341976574489, 28.161054100309098, 26.797767162322998, 37.99384423664638, 34.04623562949044, 8.031669412340436, 1.1597751783473151, 1.3139536423342568, 0.6253192541854722, 0.3707153818437031, 0.14454860000738076, 0.42462583045874325, 0.08536872986171927, 2.3908710096563612, 48.484463759831016, 60.018553325108115, 28.815244368144445, 68.91991138458252, 10.122536965778895, 0.25888911953994204, 0.2386059979242938, 0.15761471459908144, 0.2985682189464569, 0.13498672523668834, 0.13666557015052863, 0.17289461754262447, 2.2614933805806294, 6.582005509308406, 6.67821113552366, 4.060059555939265], [25.1518292427063, 14.787908383778163, 10.832644598824636, 3.8651300157819475, 4.782194520745959, 20.40726920536586, 22.574863978794642, 27.070812259401592, 14.98856714793614, 12.30701412473406, 24.01368304661342, 56.869386536734446, 45.839739663260325, 35.69378900527954, 38.22398247037615, 22.074360915592738, 43.570367676871165, 16.91843625477382, 0.10985735724014895, 0.13973383765135491, 0.08780030081314699, 0.10144393691526991, 0.2347154409757682, 0.07680619468114205, 0.0943318246198552, 0.1027218626279916, 2.024203062057495, 5.535460889339447, 4.414211843694959, 36.433744362422395, 35.342345646449495, 55.79026181357247, 51.545916489192415, 49.34923308236258, 45.869682925088064, 46.72981432506016, 41.402223995753694, 53.38398599624634, 52.735534940447124, 54.886975152151926, 63.52166134970528, 61.80758939470564, 59.76654216221401, 59.58947426932198, 67.07839557102749, 57.301547118595664, 66.2998777117048, 65.93951633998326, 59.1794958114624, 62.7180118560791, 61.738024030412944, 61.76553889683315, 61.74234580993652, 59.97213935852051, 61.61590944017683, 61.592167445591514, 65.80541610717773, 60.42090960911342, 60.97890554155622, 58.51936830793108, 58.30464117867606, 56.9721017565046, 57.543299266270225, 54.23355960845947, 47.011727060590474, 54.64838790893555, 51.08587278638567, 51.441498960767476, 53.29164096287319, 51.732263701302664, 49.126994950430735, 47.27468858446394, 47.77947173799787, 46.056870869227815, 45.66668782915388, 45.16882160731724, 46.289232526506694, 45.71813923971993, 46.67463868004935, 43.900108337402344, 41.25991794041225, 42.3182258605957, 40.98010703495571, 46.463017395564485, 48.294017110552105, 51.87362827573504, 55.74268054962158, 55.19634369441441, 59.04317910330636, 54.68578658785139, 51.22835602079119, 47.59879425593785, 48.869609355926514, 46.947567394801546, 42.79689073562622, 39.37412820543562, 40.45624760219029, 40.65867294584002, 43.21576288768223, 44.647890840257915, 44.614671502794536, 40.6706030028207, 42.109345640454976, 42.99605737413679, 40.24576582227434, 40.57585736683437, 42.558230536324636, 42.736938204084126, 44.46417352131435, 40.918344497680664, 47.17861584254673, 44.41833278111049, 46.45785140991211, 43.90238734654018, 46.08489295414516, 51.97361980165754, 50.94916350500924, 54.22684070042202, 56.196568148476736, 53.4311329977853, 54.996367590767996, 56.55034262793404, 48.84109047480992, 50.717031138283865, 51.79304306847708, 55.05727202551705, 53.63975266047886, 56.72947413580758, 57.01866858346121, 54.452431338174, 52.937060492379324, 56.650459221431184, 58.223750250680105, 54.20411661693028, 53.62631484440395, 58.818001883370535, 58.40291649954659, 57.076397691454204, 60.22999395642962, 43.060505390167236, 34.172776222229004, 77.9599276951381, 70.1147791998727, 45.98298372541155, 24.452847412654332, 14.567237070628575, 11.304705211094447, 11.033742836543492, 14.451850942202977, 15.92773083278111, 4.874516103948865, 1.3260462220226015, 5.893415578774043, 1.3799829163721629, 0.3042514654142516, 0.03643171562414084, 0.055618847121617625, 0.02734681704480733, 0.12096246491585459, 0.006676771436884467, 15.208554063524518, 41.570068155016216, 21.836348635809763, 27.289849008832658, 45.59569113595145, 3.3452922872134616, 0.04550252781648721, 0.026989249446030174, 0.0723332239847098, 0.043180265463888645, 1.384550922683307, 15.271047898701259, 24.363865307399205, 21.652113676071167, 25.816648517336162, 27.111361946378434, 32.07187025887625, 19.05875587463379, 14.613722256251744, 6.456483696188245, 2.542777304138456, 21.566100188664027, 35.54153660365513, 46.205847195216585, 36.906117643628804, 27.51617268153599, 34.44231769016811, 67.8940932410104, 55.94374404634748, 46.27448844909668, 32.313702310834614, 26.411515065601893, 50.30329370498657, 21.493284804480417, 0.1880115635160889, 0.03210184457046645, 0.03649126725005252, 0.19421547704509326, 0.4042345503611224, 0.06298404280096292, 0.07995169303779091, 0.27235939673015047, 3.09856544647898, 7.142232247761317, 7.030321955680847, 39.92264679500035, 37.93139035361153, 62.250717708042686, 59.36861882890974, 55.96003062384469, 54.63250085285732, 52.7817508833749, 48.703801018851145, 57.34020342145647, 57.78033011300223, 60.693911279950825, 65.98792443956647, 65.56683581215995, 66.13092531476701, 66.13706752232143, 70.25614030020577, 59.25448077065604, 68.86308901650565, 70.04418550218854, 62.03883934020996, 64.44982951028007, 62.212370600019185, 64.31317928859166, 66.75428989955357, 66.2357041495187, 65.92329229627336, 64.27235862186977, 67.09164578574044, 62.50543866838728, 62.74566568647112, 59.49602099827358, 61.26265607561384, 58.940387453351704, 61.62659576960972, 56.46642228535244, 52.63050249644688, 57.340154784066335, 52.91242912837437, 56.80187783922468, 56.76819297245571, 54.780247347695486, 52.82553495679583, 49.5955536706107, 50.04347971507481, 48.46024581364223, 47.84372867856707, 48.54218244552612, 49.99681561333792, 48.7075252532959, 50.22070394243513, 46.80037675585066, 44.28456258773804, 45.873532227107454, 46.33410399300711, 48.1992575781686, 51.094224521092, 54.24370745250157, 57.294369629451204, 59.30610588618687, 59.95126696995327, 56.82539054325649, 55.30343280519758, 49.703660692487446, 51.96053286961147, 49.09951829910278, 43.75485624585833, 40.671353408268516, 42.84948165076119, 40.831366947719026, 44.85040651048933, 47.02130167824881, 47.67466511045183, 42.01087924412319, 43.781471320560996, 43.81438493728638, 45.58805506569998, 45.422086920057026, 44.46975639888218, 46.43903916222708, 47.988893917628694, 45.191010679517476, 48.16825819015503, 47.502193450927734, 49.672633511679514, 46.66003704071045, 49.354527609688894, 52.93570211955479, 53.54125847135271, 53.99380159378052, 57.38302864347185, 54.76648644038609, 57.189642906188965, 57.23168992996216, 51.77910498210362, 55.4588223184858, 56.82579353877476, 56.6672043800354, 56.34796592167446, 57.488394601004465, 58.70724064963204, 55.64991167613438, 55.42234427588326, 57.38151046207973, 60.76513031550816, 56.36951575960432, 56.40192910603115, 61.68200765337263, 59.665932246616904, 59.50304562704903, 62.14208262307303, 45.81953082765852, 40.98097555977957, 79.57399422781808, 72.53217560904366, 61.31172425406319, 42.31934452056885, 29.087761402130127, 20.10438506943839, 16.505952971322195, 19.77501266343253, 24.16275143623352, 11.61575174331665, 9.312707918030874, 13.615432875497, 1.6957876618419374, 0.7489561513066292, 0.2759911332811628, 0.08227733110210725, 0.04334693402051926, 0.1953898583139692, 0.2792332278830664, 18.413351603916713, 50.472305161612375, 23.079864263534546, 31.572600500924246, 62.99431392124721, 8.067864315850393, 0.0754250366506832, 0.09229389897414617, 0.03688118739851883, 0.039912366175225804, 2.295028643948691, 20.041708844048635, 34.64638975688389, 33.38058778217861, 38.966091769082205, 39.1941351209368, 39.481623785836355, 25.984216485704692, 20.95015106882368, 8.903892414910452, 6.617306266512189, 34.52313566207886, 49.051516669137136, 55.154338359832764, 48.00006314686367, 38.8036150932312, 54.89219672339303, 76.67107159750802, 62.75816549573626, 50.60514777047293, 52.499317032950266, 35.15753051212856, 56.99904339654105, 30.23523208073207, 0.4876822254487446, 0.23492662821497234, 0.13776155348334992, 0.3893843229327883, 0.566213805760656, 0.19616779871284962, 0.09881210992378847, 0.45571595217500416, 4.605718093258994, 8.408061146736145, 7.882250138691493, 57.67265040533883, 56.07204948152815, 74.97406441824776, 64.0696518761771, 61.33208247593471, 62.570161138262065, 60.97735609327044, 57.019846303122385, 62.842322077069966, 65.00328826904297, 65.42166709899902, 73.14937714168003, 67.89869989667619, 68.97565678187779, 70.90977818625313, 73.44089576176235, 62.452166829790386, 70.92047841208321, 72.09368174416679, 63.79783834729876, 69.15544142041887, 65.2991703578404, 65.0901129586356, 69.01178741455078, 68.98591927119664, 68.87775666373116, 66.7425127029419, 70.92944853646415, 65.68560137067522, 65.07312461308071, 64.58365876334054, 64.8860443660191, 62.67479406084333, 65.58749280657086, 62.03999968937465, 53.88346072605678, 60.2768942969186, 57.80043819972447, 58.88550363268171, 60.00615773882185, 56.99447495596749, 53.649719851357595, 50.934033802577424, 52.658006940569194, 51.19014092854091, 50.0517133304051, 49.334711347307476, 51.98351056235177, 50.70703615461077, 51.92674725396292, 50.21610770906721, 46.312335286821636, 49.746652671269004, 50.34538241795131, 51.27700383322579, 54.495360783168245, 56.25382825306484, 62.54065213884626, 61.683716910226, 63.75648266928536, 59.69674055916922, 57.75907557351248, 50.71776417323521, 54.21081468037197, 50.97040414810181, 46.78559793744768, 44.91370112555367, 44.17909935542515, 43.13757480893816, 47.44652100971767, 50.60041952133179, 49.14813831874302, 45.050719601767405, 46.323344707489014, 47.45545639310564, 47.40744434084211, 48.21527317592076, 49.42364134107317, 49.51679931368147, 51.49867916107178, 48.207518986293245, 53.59196295057024, 51.20287350245884, 53.77711854662214, 49.614511830466135, 52.56904220581055, 55.92950023923601, 53.28743382862636, 55.65415007727486, 59.89028263092041, 57.23289196831839, 59.41508143288748, 58.774714606148855, 53.181119441986084, 57.40361615589687, 58.13841247558594, 58.3386595589774, 55.241017137254985, 59.363838468279155, 60.74575178963797, 55.836290155138286, 54.802405153002056, 58.829021726335796, 63.584820474897114, 57.94186183384487, 59.40686171395438, 66.08609553745815, 62.04101412636893, 63.387137276785715, 66.53289249965123, 51.31091104234968, 48.235902377537315, 77.96107414790562, 72.31176485334123, 66.12343515668596, 50.755346979413716, 39.74790307453701, 28.203785521643503, 29.021268878664287, 27.930304425103323, 39.15615279333932, 30.645905358450754, 30.309237343924387, 14.422213401113238, 3.371208416564124, 2.261124691792897, 0.19121730221169336, 0.11065912100353412, 0.23267679608293942, 0.21145546409700597, 0.5736118459275791, 24.20883710043771, 64.85871015276227, 42.25472627367292, 38.46555049078805, 74.00149726867676, 8.345979860850743, 0.12533354679388659, 0.13919877207704953, 0.2725496308079788, 0.11285667201238019, 2.665639477116721, 25.28292785372053, 40.89160782950265, 40.915207386016846, 44.83090986524309, 46.16569702965872], [11.683725101607186, 19.97972743851798, 17.449921335492814, 18.13948835645403, 26.256141185760498, 16.33161745752607, 16.199533939361572, 7.341895682471139, 3.6063206919601987, 13.384028332574026, 32.03754268373762, 45.26256670270647, 51.40221732003348, 40.59343630926949, 29.60493666785104, 42.48912722723824, 42.46030262538365, 3.0069621333054135, 0.07206964705671583, 0.053462255879172256, 0.03750491714371102, 0.08363433328590222, 0.5601676244820867, 0.09851275384426117, 0.1225892933351653, 0.28825823217630386, 1.0807322540453501, 1.2375452795198985, 0.051579188888094256, 28.511371850967407, 60.07561193193708, 54.58176858084542, 48.56863076346261, 44.85639238357544, 45.20439638410296, 46.286352498190745, 41.81892483575003, 46.42368016924177, 49.23712737219674, 53.03746543611799, 62.21261378696987, 60.3695068359375, 59.83592687334333, 60.37810870579311, 62.37056023733956, 53.55464417593819, 63.498871258326936, 64.6024397441319, 59.79954610552107, 61.657973834446494, 64.65082005092076, 61.09145246233259, 63.032494272504536, 61.67742184230259, 61.13330841064453, 60.360258783612935, 61.98599134172712, 58.39958831242153, 59.47126456669399, 58.292301177978516, 59.76049722943987, 58.25109141213553, 55.38750948224749, 47.26574625287737, 52.86377089364188, 51.99822684696743, 50.70453827721732, 53.852822644369944, 49.95933355603899, 50.76271901811872, 47.72758259092058, 48.31175586155483, 45.902200494493755, 46.866780689784456, 43.97194228853498, 47.446455001831055, 46.82106154305594, 46.57816989081246, 44.839657647269114, 42.87548875808716, 43.82037428447178, 39.031731401171, 41.06505223682949, 45.23692090170724, 49.3451440674918, 55.99482372828892, 54.79910128457205, 55.34016793114798, 57.51790360042027, 55.32403073992048, 53.229183605739046, 52.187214374542236, 50.46387004852295, 45.9354476247515, 39.05484805788313, 38.59986959184919, 38.11389521190098, 39.38501950672695, 41.68734679903303, 42.754781178065706, 44.732519899095806, 41.522629329136436, 42.012324469430105, 42.854063987731934, 41.4268171446664, 41.61549547740391, 41.31653186253139, 43.471435751233784, 44.773097378867014, 46.77079132625035, 43.66385221481323, 46.10240936279297, 45.796452386038645, 45.77224486214774, 45.930507455553325, 52.094070298331125, 52.31699630192348, 53.99646275384085, 52.074260984148296, 54.70691953386579, 55.32197059903826, 55.20654017584664, 51.10987881251744, 52.640959535326274, 54.99169145311628, 52.770421845572336, 54.159523078373496, 54.93131160736084, 55.53381075177874, 56.36112928390503, 51.406500884464805, 54.132716928209575, 55.08769818714687, 54.34392826897757, 52.783703327178955, 56.10991368974958, 57.79969474247524, 57.4673102923802, 56.14537034715925, 42.647556577410015, 51.720604624067036, 71.07134464808873, 52.51530136380877, 51.16955689021519, 31.28299263545445, 16.77235906464713, 12.569525752748762, 11.258473634719849, 14.204864195414952, 20.939746141433716, 10.938669766698565, 1.3521777455295836, 9.958179065159388, 1.742142677307129, 0.35271737618105753, 0.02891364261241896, 0.25428846212370054, 0.26727016695908135, 0.21743396829281533, 0.2060994750687054, 8.8404084614345, 45.830144201006206, 36.75621025902884, 17.935348544801982, 36.16153131212507, 34.866519110543386, 0.9882937456880296, 0.23336480345044816, 0.04332660511136055, 1.095061936548778, 20.18644503184727, 27.045840433665685, 7.422842196055821, 13.72876146861485, 13.45501720905304, 8.449371661458697, 27.078825269426616, 34.50757169723511, 28.84046459197998, 32.525639738355366, 47.33183056967599, 40.47579288482666, 38.01154824665615, 24.117355380739482, 18.039974519184657, 19.38924867766244, 44.15197358812605, 54.05170440673828, 59.02723298754011, 50.28407498768398, 30.400904927934917, 40.82587439673287, 49.12499039513724, 3.7255294152668545, 0.07017225958406925, 0.09601282048970461, 0.06250634736248425, 0.3073181180017335, 0.560913687305791, 0.7495967426470348, 0.2970536473606314, 0.5867162570357323, 1.2822709424155099, 2.074095036302294, 0.15403156115540437, 36.35339191981724, 58.70915835244315, 62.20312254769461, 62.39114080156599, 56.74491650717599, 55.105374404362266, 53.368668692452566, 49.95976087025234, 52.33121926443917, 51.78576830455235, 57.25031110218593, 65.23275252750942, 64.78310680389404, 64.85183838435582, 65.06538431985038, 64.8558474949428, 56.25565562929426, 67.42941161564418, 67.38153157915387, 62.6038737978254, 65.97739097050258, 65.02525152478898, 64.14201736450195, 65.96971321105957, 65.34730052947998, 63.46341460091727, 61.79629162379673, 63.94459124973842, 62.14955888475691, 61.03773593902588, 59.33993666512625, 60.79496588025774, 59.37655367170061, 56.88347053527832, 50.820712157658164, 57.24245963777815, 55.57759482519967, 53.83713708605085, 55.54430947984968, 52.19794586726597, 54.26995079857962, 51.55042587007795, 50.97342661448887, 48.48429700306484, 47.915166582380024, 45.38872514452253, 50.36439963749477, 49.918589319501606, 48.9483185495649, 48.70379407065255, 46.73898594720023, 45.33046102523804, 43.69474043164934, 43.76321145466396, 46.581174986703054, 50.755447728293284, 57.14391681126186, 58.67636980329241, 60.065418924604145, 60.24883052280971, 57.60020153863089, 54.24284587587629, 53.421825885772705, 51.946653842926025, 47.9769777570452, 41.26411465236119, 41.519189970833914, 39.22714948654175, 40.96979243414742, 42.61940942491804, 46.61802475793021, 45.997470719473704, 42.23196744918823, 43.98923635482788, 44.510465894426616, 44.182653359004426, 45.81968368802752, 45.727807658059255, 47.447559765407014, 46.18880673817226, 47.31187186922346, 46.39033229010445, 48.02882521493094, 48.64669030053275, 50.61481271471296, 49.42373514175415, 51.74815770557949, 53.083062989371165, 54.42117486681257, 53.8740667615618, 56.30472033364432, 56.517665249960764, 56.37496314729963, 55.91276550292969, 56.6738920211792, 56.832856382642476, 55.730489935193745, 56.15334687914167, 56.28009244373867, 56.15136316844395, 56.49409001214163, 54.66143315179007, 53.16646569115775, 58.168560709272114, 56.44627250943865, 55.126649788447786, 56.830935205732075, 61.373389516557964, 58.651224272591726, 59.023335048130576, 41.78091124125889, 59.16808686937605, 72.61608900342668, 58.349985122680664, 62.05206871032715, 48.63587542942592, 35.55511685780117, 28.27643241201128, 18.482498339244298, 19.701627526964458, 26.529547589165823, 14.008485521589007, 10.506355455943517, 15.273683003016881, 1.8497374866689955, 0.8406734040805272, 0.108622939192823, 0.12744913755783013, 0.2712997150208269, 0.2049477297280516, 0.2368158868380955, 8.961558120591299, 54.52194806507656, 39.99498449053083, 23.672040121895925, 46.406010900224956, 49.31179618835449, 1.5798773786851337, 0.1341631737138544, 0.04434018375884209, 1.796028454388891, 28.332176072256907, 42.38123907361712, 25.300162860325404, 27.857164212635585, 25.485823937824794, 22.116058792386735, 33.824254580906455, 46.6909704208374, 43.54326622826712, 55.66507959365845, 64.87369046892438, 43.03506803512573, 43.08398682730538, 28.32369405882699, 25.31921308381217, 37.93926266261509, 61.7228422164917, 63.527810505458284, 71.10015882764543, 56.49626479830061, 47.83893094744001, 58.51624161856515, 57.422595160348074, 7.2019363812037875, 0.19257526791521482, 0.1971464226288455, 0.18225373247904436, 0.7771417903048652, 1.0751249492168427, 0.32716990847672733, 0.5587724479181426, 2.2576258395399367, 1.7192886407886232, 1.9342371353081294, 0.1736932804009744, 35.91952208110264, 70.53256743294853, 65.4451242174421, 66.41828891209194, 63.77725083487374, 61.360716002328054, 61.465189116341726, 56.101117270333425, 59.79184055328369, 62.121953691755024, 62.63481412615095, 69.22784859793526, 68.54159586770194, 69.21150643484933, 70.3145399093628, 66.86585712432861, 59.2903265271868, 69.5684631892613, 71.63894993918282, 63.92226668766567, 68.87614468165806, 70.5068313053676, 66.4704281943185, 69.76058782849992, 69.50433826446533, 68.04835714612688, 67.41914217812675, 67.60741056714738, 65.50188405173165, 64.60380159105573, 62.09857995169503, 65.19107723236084, 63.695164816720144, 61.36893572126116, 53.91790989467076, 58.92620618002755, 60.69029821668352, 55.13115916933332, 59.7000617980957, 57.18980271475655, 57.280059814453125, 53.83392007010323, 52.56958416530064, 49.89649057388306, 52.1822429384504, 47.60540894099644, 52.37369360242571, 51.93897608348301, 50.863846574510845, 50.57570130484444, 47.89158092226301, 49.10316957746233, 45.9939410345895, 47.48478821345738, 49.373847075871055, 53.67149897984096, 61.41247313363211, 60.90633855547224, 63.17890671321324, 64.26134572710309, 59.03942707606724, 57.116659028189524, 55.5116286277771, 54.77933365958077, 53.287089892796104, 44.015538760593955, 43.08225672585623, 41.56250851494925, 42.9020482472011, 46.66104800360543, 47.90529319218227, 48.9098151070731, 42.959273610796245, 46.17297874178205, 47.991211141858784, 48.14171954563686, 48.940800598689485, 49.62925590787615, 52.338393279484336, 52.195041520254954, 51.82762425286429, 51.40002516337803, 53.79035139083862, 52.90336867741176, 53.10761097499302, 51.447071416037424, 56.26992722920009, 56.7966354233878, 55.53654139382498, 56.2998948097229, 57.203945772988455, 57.27434492111206, 57.46178994859968, 57.55772372654506, 58.58649485451834, 58.85673114231655, 57.27819422313145, 56.503053188323975, 58.25683757237026, 57.10452747344971, 59.25039522988455, 55.020523003169465, 53.68275506155831, 61.10584912981306, 59.591294697352815, 58.3899233681815, 59.40354742322649, 64.20125770568848, 61.353357860020225, 63.70558711460659, 46.368956157139365, 58.02279445103237, 71.84155246189663, 62.54823957170759, 66.84536688668388, 54.132133279527935, 47.12163714000157, 36.49712930406843, 33.80304520470755, 35.42071090425764, 47.935368469783235, 40.55008997235979, 17.489081382751465, 24.46312553542001, 4.148403295448848, 2.1555392146110535, 0.2815336515860898, 0.41111516686422483, 0.5518043275390352, 0.46473873087338036, 0.27989379529442104, 15.267174277986799, 63.33613749912807, 50.0756915637425, 30.609934534345353, 56.95577001571655, 60.82642732347761, 1.9521170215947288, 0.3001865792487349, 0.13663932441600732, 2.2202679812908173, 36.86165264674595, 51.345978600638254, 35.87281976427351, 44.12245416641235, 40.90040077481951, 32.04471322468349], [17.90342504637582, 2.56421879359654, 5.1779608726501465, 18.08894889695304, 7.3850856849125455, 16.509896074022564, 25.3740656375885, 31.281067984444753, 19.64390536717006, 15.979659932000295, 31.494082382747106, 41.26939875738961, 53.96999706540789, 40.412810938698904, 18.088080372129166, 42.16109929765974, 22.939887591770717, 0.2516826976622854, 0.016655899018847516, 0.0333024783592139, 0.05916854539620025, 0.1112750136692609, 0.8196177024926458, 0.2184517029672861, 1.3108571342059543, 0.036563151249928136, 0.33378798621041433, 0.49126022202628, 0.4023806027003697, 8.19172203540802, 51.978820528302876, 60.61041477748326, 45.61221742630005, 38.71418482916695, 42.58706556047712, 45.81828710011074, 43.03567600250244, 46.78231143951416, 47.74269492285592, 51.55094698497227, 55.83403199059622, 60.636859621320454, 57.771957533700125, 59.58906432560512, 54.35027892248971, 53.708512033735005, 62.8581292288644, 60.73513494219099, 62.26043823787144, 63.11246803828648, 66.65801565987724, 62.74178859165737, 60.004128864833284, 62.733388219560894, 63.84487765175955, 60.94135052817208, 58.71723910740444, 58.04084587097168, 59.292869567871094, 57.16219057355608, 58.649181502205984, 57.77338538851057, 49.069550718579976, 52.73325245720999, 53.83606358936855, 51.932288442339214, 54.696955817086355, 48.43051099777222, 50.91195937565395, 49.23111023221697, 49.38579797744751, 45.356277057102744, 46.173381737300325, 46.86522429330008, 45.42116975784302, 43.0676064491272, 47.50972877229963, 47.11310127803257, 46.27940429959978, 41.533176694597515, 40.64654833929879, 37.836960860661094, 39.967973368508474, 42.7797669001988, 45.61003916604178, 48.17983388900757, 55.195937224796836, 58.93534306117466, 58.370565686907085, 57.50342008045742, 52.73971775599888, 47.727850096566335, 46.32780197688511, 41.05075979232788, 38.46109669549124, 39.558773108891074, 38.32438741411482, 38.78031778335571, 42.38761404582432, 46.317112173352925, 44.39447614124843, 42.5773971421378, 42.29576580865042, 41.98145014899117, 41.26392705099923, 42.63654715674264, 43.16437748500279, 40.50863354546683, 43.56075831821987, 45.473142283303396, 45.90149872643607, 43.910047735486714, 45.769604546683176, 47.50380890710013, 47.74720777784075, 49.768984181540354, 53.37332051140921, 53.17673512867519, 52.77232217788696, 51.96439606802804, 51.35231188365391, 56.15753664289202, 51.20872041157314, 53.01450858797346, 52.806719235011506, 52.89051798411778, 53.548429012298584, 54.30821452822004, 58.30812222617013, 56.914459500994, 53.66428327560425, 48.94534124646868, 51.78558417728969, 54.77430316380092, 52.14767565046038, 56.07195220674787, 57.63091605050223, 58.72822420937674, 52.90821852002825, 48.149765559605186, 53.03526980536324, 58.05430800574166, 57.266896452222554, 59.85938399178641, 39.66219009671892, 26.025834458214895, 17.66105624607631, 13.957873106002808, 16.1340297971453, 20.264732122421265, 20.438980783735, 16.34277626446315, 4.936333358287811, 0.6653858785118375, 0.3876667065279824, 0.15349273649709566, 0.2430393286049366, 0.35196792068225996, 0.1219812852463552, 0.18835887845073426, 2.350172370672226, 36.859922545296804, 29.10001802444458, 18.591963733945573, 23.71341664450509, 42.18640463692801, 5.9039225578308105, 0.010795371706730552, 0.40484580184732166, 14.101141486849103, 18.629725456237793, 9.902676854814802, 27.773888315473283, 31.419896466391428, 36.3646480015346, 32.52133532932827, 22.087215082986013, 12.97762211731502, 15.264238664082118, 65.36187785012382, 32.160626547677175, 27.27630523272923, 34.03464950834002, 35.40243019376482, 30.080683299473353, 30.817939281463623, 44.74465840203421, 52.15759072984968, 63.44808687482561, 42.46762950079781, 19.942624058042252, 47.31241035461426, 26.65694628443037, 0.07065614326191799, 0.06711510648684842, 0.06893343784447227, 0.045329128192471604, 0.2415146061352321, 1.5197211780718394, 1.1123067140579224, 0.5114072837999889, 0.027581364548365985, 0.5833751506039074, 1.6540725231170654, 0.27308765479496544, 13.09450123991285, 63.95684092385428, 63.4852180480957, 54.95183311189924, 51.59777089527675, 53.22442061560494, 56.294040952410015, 50.18676894051688, 52.017365659986226, 54.401754651750835, 56.185093198503765, 60.95558043888637, 64.15411417824882, 63.52391256604876, 63.22538321358817, 57.72958394459316, 53.89079107557024, 66.55585629599435, 65.78466183798653, 65.92398711613247, 62.67175074986049, 68.08497415270124, 64.76756368364606, 65.45392063685826, 63.60425458635603, 65.4017744064331, 62.56369931357247, 59.57163824353899, 60.43776593889509, 63.829591614859446, 61.98655414581299, 59.344126428876606, 60.99722099304199, 51.7638258934021, 55.330937249319895, 56.259953090122764, 56.79314047949654, 58.05601726259504, 53.42212813241141, 53.58099521909441, 49.87148748125349, 51.99077837807791, 48.961871010916575, 48.94591447285244, 49.42406518118722, 46.68675981249128, 46.25670106070382, 50.29994119916643, 49.149805886404856, 50.047773701804026, 43.6384391784668, 43.20179353441511, 42.921635219029014, 42.46640314374651, 45.33414009639195, 46.22418349129813, 49.77826350075858, 58.18746328353882, 60.476863452366416, 61.50945608956473, 59.40020533970424, 53.72998891557966, 49.14622061593192, 48.23881714684622, 43.224222319466726, 41.40215451376778, 42.0213988167899, 39.43911818095616, 41.0354494367327, 44.88044704709734, 49.08964490890503, 45.43937403815133, 42.62847682407924, 43.257674421582905, 43.19386911392212, 44.288839203970774, 45.79677895137242, 47.28964805603027, 44.71893964494978, 45.31187111990792, 48.33057853153774, 46.98747784750802, 47.94716303689139, 49.262172154017854, 49.95720393317086, 50.54686975479126, 50.70618500028338, 54.114502225603374, 53.08369527544294, 55.80810826165335, 54.31753206253052, 52.4062876020159, 58.85827364240374, 55.01919937133789, 55.33482129233224, 55.42323364530291, 54.703997816358296, 54.766621930258616, 55.86547606331961, 58.11104004723685, 59.235546929495676, 57.552665437970845, 48.69249977384295, 53.59907790592739, 56.63713952473232, 54.11347041811262, 55.655782903943745, 59.133714130946565, 59.96635150909424, 56.769176142556326, 48.149706499917166, 57.77294765199934, 63.47959000723702, 60.37074361528669, 65.08854266575405, 52.81252792903355, 43.10975422177996, 35.19059004102434, 28.86705013683864, 23.39058075632368, 27.06344543184553, 19.244851214545115, 12.477627141135079, 3.3852125108242035, 0.6533539869955608, 0.19405136656548294, 0.35335237639290945, 0.1448196747473308, 0.2522025097693716, 0.13779826222785882, 0.2612535426659243, 3.094542439494814, 44.60199104036604, 33.026754243033274, 26.27936727660043, 32.59368692125593, 56.898909432547434, 8.276421444756643, 0.13013880965965136, 0.8068508761269706, 19.789449283054896, 32.79359354291643, 24.349729197365896, 37.26142072677612, 44.07316364560808, 48.32971348081316, 44.78231069019863, 47.080225876399446, 24.093382358551025, 24.20842715672084, 109.23056643349784, 38.528747831072124, 55.200411864689414, 72.45656531197685, 82.20722252982003, 58.146170139312744, 49.09360538210188, 61.561616216387065, 61.94089753287179, 74.22941207885742, 53.96170091629028, 34.571762629917686, 56.731829575129915, 35.59639263153076, 0.950864885534559, 0.16938794856624945, 0.27494111391050474, 0.19794741964765958, 0.6308400322284017, 2.1291388826710835, 0.8811030175004686, 3.8682254382542203, 0.16263672869120324, 1.2729271352291107, 2.6713022589683533, 0.33785819209047724, 10.77375601019178, 68.41181741441999, 69.35578577859062, 60.57996777125767, 58.69847897120884, 61.07179600851876, 63.19134398869106, 56.149567059108186, 58.7774452481951, 60.5034681047712, 62.232659339904785, 62.92426913125174, 69.13633387429374, 65.85104492732457, 69.81754221235002, 57.11102403913225, 57.865692206791465, 70.64217526572091, 69.42041097368512, 67.92274066380092, 67.62191840580532, 71.61515235900879, 67.46561173030308, 67.74877861567906, 68.90179743085588, 69.85242216927665, 65.91632325308663, 64.0857925415039, 63.035030364990234, 67.17455863952637, 63.84843512943813, 63.922461237226216, 63.607416016714915, 56.082603795187815, 59.97697530473982, 60.80690288543701, 58.58338900974819, 60.282848903111045, 56.00747639792306, 57.05316638946533, 54.78095258985247, 57.40460627419608, 53.15832935060774, 51.18102836608887, 51.8336136000497, 49.83868850980486, 48.02975974764143, 53.05204970496041, 49.564054012298584, 50.74523735046387, 46.805570534297395, 47.58236871446882, 45.09769637244088, 45.146305969783235, 49.16492864063808, 50.85729789733887, 53.10140970775059, 60.76706886291504, 63.29761668613979, 63.867903981889995, 61.74231801714216, 55.52886710848127, 51.922720772879465, 52.46675082615444, 47.31020777566092, 43.15102999550955, 45.14406170163836, 42.3180695261274, 43.3343825340271, 46.82129430770874, 50.81696707861764, 49.50009931836809, 44.44821350915091, 46.724637917109895, 48.20444788251604, 46.974554198128835, 48.33725922448294, 50.38324315207345, 48.75557552065168, 49.77874640056065, 53.46874359675816, 53.07559020178658, 51.46277434485299, 53.87832253319876, 55.26489462171282, 53.15507411956787, 56.411187580653596, 57.26430824824742, 57.3451818057469, 58.32884175436837, 54.49561439241682, 53.14475951875959, 62.38250419071743, 57.26607656478882, 55.15821198054722, 57.097905840192524, 56.01354564939226, 55.24544313975743, 54.925614084516255, 61.95685059683663, 61.351377623421804, 58.09410728727068, 51.13397863933018, 55.379095213753835, 57.16004705429077, 55.4938725062779, 59.60266195024763, 64.18446390969413, 62.43695722307478, 61.7329865864345, 53.871405601501465, 58.709054129464285, 64.8642270224435, 61.47071988242013, 68.2042955671038, 58.889880997794016, 52.06027773448399, 42.46266848700387, 47.75620222091675, 44.65205628531319, 52.210664544786724, 49.3606732913426, 41.74397461754935, 16.167242186410085, 2.979288326842444, 1.727365704519408, 1.072356852037566, 0.2564918010362557, 0.719462296792439, 0.363839542227132, 0.3367886851940836, 5.7886762619018555, 56.886673654828755, 40.03928967884609, 37.630172048296245, 41.53210667201451, 74.38534355163574, 11.295680369649615, 0.255891813231366, 1.0091180396931512, 26.84404042788914, 44.107842104775564, 37.30416257040841, 68.37387330191476, 72.90098599025181, 80.63203811645508, 81.22617162976945], [19.502113478524343, 8.948776040758405, 10.309742280415126, 8.768707394599915, 12.342240623065404, 29.244974817548478, 36.325328145708355, 29.5971268926348, 23.436796699251445, 24.97864191872733, 24.02713302203587, 32.89563826152256, 49.98304428373064, 36.828693866729736, 23.54454936300005, 44.037870270865305, 10.584705080304827, 0.22869952235903057, 0.05241980556664722, 0.02157401922158897, 0.23269574078066008, 0.0729442515543529, 0.3618331141769886, 3.3281389219420294, 0.257012563092368, 0.21307121882481234, 0.7449305387479919, 0.16512157821229526, 0.11808228732219764, 1.566234590751784, 28.475489616394043, 42.08775411333357, 37.57900203977312, 35.25761236463274, 42.9201899937221, 46.264983313424246, 47.62234170096261, 48.4739476612636, 45.25065401622227, 46.220365456172395, 58.195425919124055, 58.36036573137556, 58.28997353145054, 54.55131115232195, 53.4950772694179, 50.57799768447876, 60.34991986410958, 61.84526252746582, 62.88385146004813, 61.075284004211426, 64.34576633998326, 61.37538364955357, 61.35461548396519, 59.04408236912319, 63.55630506787981, 58.04064089911324, 59.483000074114116, 59.98846067701067, 59.10081441061837, 56.80267340796334, 56.98584876741682, 52.80907467433384, 52.16816241400582, 53.60912847518921, 53.893271582467214, 55.24055160794939, 49.757474490574424, 47.79104743685041, 47.874630791800364, 49.31282452174595, 47.129089082990376, 46.768765926361084, 46.84649542399815, 44.09365735735212, 43.34036840711321, 41.5027505329677, 45.543656076703755, 49.29959167752947, 45.48173720496041, 43.5114677974156, 38.70428017207554, 39.08456202915737, 40.49592876434326, 42.39537865774972, 40.454527923039024, 44.48294407980782, 50.648000785282676, 52.04744093758719, 53.21342509133475, 52.64491653442383, 49.992625849587576, 41.94330106462751, 40.66581221989223, 38.8628693308149, 38.94529233660017, 38.3287022454398, 37.001610210963655, 37.29723869051252, 40.43422876085554, 47.04108319963728, 42.96136154447283, 41.58370746885027, 43.96266644341605, 42.73745584487915, 42.69033316203526, 42.40130547114781, 39.995304107666016, 39.774980204445974, 42.715172971997944, 44.66311781747, 44.83356755120413, 44.168058667864116, 44.61489731924874, 43.8751608303615, 48.204941204616, 47.74742317199707, 50.51845162255423, 49.452962739127024, 54.20970644269671, 51.52899762562343, 53.28698219571795, 53.34468698501587, 53.14034741265433, 53.80101340157645, 53.11352736609322, 51.961745330265586, 54.37358318056379, 51.70542975834438, 56.19168356486729, 54.49020869391305, 53.747915267944336, 53.257747650146484, 48.08422667639596, 54.51058776038033, 54.40434980392456, 54.87322119304112, 51.79131644112723, 59.48284026554653, 47.71266828264509, 44.913972105298726, 48.64991079057966, 52.27657168252127, 53.30687836238316, 60.33947672162737, 49.58052819115775, 34.23394468852452, 28.520725863320486, 19.2704918043954, 16.226525953837804, 29.415205683026993, 22.70249891281128, 4.499876184122903, 1.06718587236745, 0.25705750925200327, 0.15871262497135571, 0.31816488025443895, 0.12749599718621799, 0.20068399208996976, 0.10939898647900138, 0.2405546690736498, 1.4869504336799895, 33.89455645424979, 33.89775609970093, 24.218917199543544, 24.906752382005962, 35.786300795418875, 6.707572485719409, 0.030362243631056378, 3.723220876285008, 18.917721339634486, 3.620449419532503, 20.386527095522197, 14.939380850110735, 8.886071154049464, 2.968236565589905, 13.565056698662893, 38.823358399527415, 19.63514368874686, 30.90080349785941, 40.03681264604841, 21.177906070436748, 47.99557113647461, 51.71286085673741, 55.552657740456716, 38.32308462687901, 33.53837789808001, 37.98100049155099, 41.795228004455566, 62.70421968187605, 41.36266095297677, 24.981426409312657, 52.455289772578645, 12.593005452837263, 0.21013484496091092, 0.08743104884134871, 0.10412229783833027, 0.3545960767992905, 1.0654994142907006, 3.408850282430649, 7.338931407247271, 0.9784013565097536, 0.27731259380068096, 1.3732627055474689, 0.38160478323698044, 0.16408335178026132, 3.070496895483562, 42.793704986572266, 57.59178032193865, 49.91578919546944, 53.138853549957275, 50.88152279172625, 52.44629880360195, 54.78349910463606, 54.10727957316807, 51.07869182314192, 51.22202968597412, 66.1700575692313, 63.144492285592214, 64.76290144239152, 59.246323585510254, 54.8577857698713, 54.09002372196743, 63.30929660797119, 64.64906910487584, 64.45114271981376, 63.87829153878348, 66.67036955697196, 63.03145204271589, 62.85680212293352, 62.33541624886649, 64.84858662741524, 61.15601512363979, 61.94580296107701, 61.62412221091134, 63.040998867579866, 60.24295234680176, 59.98106779370989, 56.25936944144112, 55.243872846875874, 58.19859082358224, 56.00258834021432, 58.21464811052595, 54.34045764378139, 51.67706721169608, 51.73205178124564, 51.35743270601545, 49.652362142290386, 50.43619189943586, 50.134021690913606, 48.102792263031006, 46.10866274152483, 45.98206308909825, 46.91536944253104, 53.64540502003261, 49.337188380105154, 44.90620401927403, 42.52696016856602, 43.73647478648594, 43.24235016959054, 45.43433659417288, 43.16542666299002, 44.19295406341553, 51.73143686567034, 52.83818415233067, 51.71129751205444, 53.40897519247872, 52.38062443052019, 42.867810998644146, 41.36414091927664, 43.61877577645438, 41.60121692929949, 39.85192108154297, 39.019394874572754, 39.14888497761318, 43.08157580239432, 49.86269801003592, 43.77590928758894, 43.19271918705532, 44.4417655808585, 44.62779664993286, 44.01175199236189, 45.66423511505127, 44.972969259534565, 45.01558256149292, 45.8303804397583, 48.49395499910627, 47.40825728007725, 46.661551748003276, 48.38652195249285, 48.22437531607491, 48.60152700969151, 50.0190463747297, 51.030898639133994, 52.7380154473441, 55.20414652143206, 50.19292504446847, 54.89636564254761, 55.72361816678728, 56.4899662562779, 58.10082966940743, 54.38927916118077, 56.00761536189488, 55.893435614449636, 53.82865333557129, 57.98115389687674, 56.197999477386475, 55.45207561765398, 54.48684923989432, 49.75245441709246, 55.85324723379952, 54.433330740247456, 55.37723657063076, 54.28075177328927, 61.51256193433489, 52.177361828940256, 46.66393845421927, 54.39985431943621, 57.790540490831646, 55.78583928516933, 62.91613279070173, 58.564218929835725, 50.551427773066926, 45.66240773882185, 36.56546483721052, 32.33003405162266, 35.79780353818621, 19.619635309491837, 3.794412987572806, 1.3117604000227792, 0.3736655706805842, 0.31715470446007593, 0.315335606357881, 0.09224098681339196, 0.18889817808355602, 0.09041582260813032, 0.4480154210967677, 2.114280811377934, 44.04636444364275, 40.965842383248464, 28.763125930513652, 32.435538973127095, 50.67369522367205, 9.018542902810232, 0.04249675678355353, 7.965061375073024, 32.64068453652518, 15.068360260554723, 37.939161913735525, 34.46975612640381, 26.7703652041299, 20.087184803826467, 29.338615689958843, 83.24426896231515, 63.42095415932791, 74.09998103550502, 88.75708784375871, 68.97922815595354, 94.58476434435163, 88.41085910797119, 82.75977802276611, 64.82995850699288, 53.102837562561035, 49.616603238242014, 52.4526355607169, 68.20516409192766, 53.77181012289864, 40.23494400296892, 58.795225688389365, 19.858800990240915, 0.2646911639188017, 0.17680738972766058, 0.13456361794045993, 0.5070690565875599, 1.0874781949179513, 1.5410303260598863, 7.547083803585597, 0.7578737842185157, 0.5618945775287492, 1.9268073397023338, 0.6939955204725266, 0.23092313589794294, 2.5463701742036, 47.47481754847935, 60.614305768694194, 56.70813274383545, 62.30972875867571, 57.21058477674212, 59.35752950395857, 61.57324750082833, 59.87032740456717, 60.35098988669259, 58.69698510851179, 69.58876582554409, 66.4618193762643, 67.14808600289481, 64.5690883908953, 57.80237327303205, 54.50591509682791, 66.2228638785226, 68.90497275761196, 67.50782898494175, 64.83967208862305, 67.45386232648576, 66.69917678833008, 65.34211022513253, 64.82722091674805, 69.19041170392717, 64.57050582340786, 64.00287968771798, 64.41697147914341, 65.25056770869664, 62.66371168409075, 62.127887453351704, 62.430015972682405, 59.26636219024658, 61.79018415723528, 59.6612491607666, 62.17301600319998, 57.00680800846645, 54.75296524592808, 55.22026286806379, 55.01241445541382, 51.17122793197632, 53.926886967250276, 53.11206477028983, 49.55762692860195, 48.136817591530935, 48.40805789402553, 48.45263753618513, 54.54011413029262, 50.37612124851772, 48.31616449356079, 45.26241036823818, 47.02989312580654, 46.41288266863142, 48.01778105327061, 42.96271644319807, 46.49742834908621, 53.79489551271711, 56.98302779878889, 55.00648069381714, 57.126716545649934, 53.90426710673741, 43.17415707451956, 43.56091465268816, 44.23076616014753, 42.967368262154714, 42.12383958271572, 41.55203757967268, 40.157520226069856, 43.90432589394705, 51.332610266549246, 44.95299318858555, 44.92632947649275, 48.67026206425258, 48.63222415106637, 47.71698311397007, 48.36199828556606, 46.42201607567923, 47.20788860321045, 49.43390383039202, 51.570134435381206, 51.28642211641584, 53.05278621401106, 50.17628410884312, 51.610291549137656, 53.64398758752005, 54.13520785740444, 53.69202743257795, 54.311945710863384, 58.34190436771938, 54.361882414136616, 57.35963405881609, 58.36174842289516, 59.42380837031773, 59.37549754551479, 54.83683000292097, 56.42750889914376, 56.6996420451573, 52.98847368785313, 60.66258880070278, 59.40795258113316, 57.19726160594395, 55.67751339503697, 50.14661182676043, 58.05404397419521, 57.06797647476196, 56.75676665987287, 57.23824208123343, 66.04678957802909, 57.106643199920654, 53.36264113017491, 56.935575076511924, 62.61207962036133, 57.9557443346296, 61.53483785901751, 63.71780204772949, 56.63552059446062, 51.17241259983608, 49.132251262664795, 53.030437333243235, 58.66709395817348, 52.56920896257673, 17.238597086497716, 2.5835221920694624, 0.8469105522547449, 2.201277468885694, 1.0515636077948978, 0.20180204138159752, 0.3866324563111578, 0.1904910933226347, 0.6101796180009842, 3.468911813838141, 54.44783163070679, 47.55506576810564, 41.42018508911133, 46.063096455165315, 71.26836776733398, 14.236171041216169, 0.28889768357787815, 11.940655589103699, 47.25844022205898, 27.70670792034694, 70.36111368451799, 64.22204671587262, 54.510608604976106, 39.97808994565691, 55.79336418424334], [6.506971912724631, 21.77919101715088, 24.51805625643049, 14.05890599318913, 2.6430904013769965, 17.724717378616333, 25.920237473079137, 27.197681154523575, 25.87126656941005, 26.04794536318098, 22.559261798858643, 28.77944377490452, 49.989478315625874, 18.66099234989711, 37.71768808364868, 34.93579612459455, 0.9996958481413978, 0.02575563546270132, 0.057918493902044635, 0.09102889256817953, 0.13010010602218763, 0.2048114256135055, 2.8307271557194844, 2.227224213736398, 0.1867417259407895, 0.3905629925429821, 0.3070697199021067, 0.3851277641952038, 0.33367285238845007, 2.7947176822594235, 14.01369753905705, 32.98681947163173, 37.4908641406468, 34.51162944521223, 41.20994302204677, 48.17205190658569, 49.38607937949044, 51.145241669246126, 45.79448257173811, 43.32725020817348, 54.37619570323399, 55.81862088612148, 55.95334645680019, 53.23604147774832, 50.74741908482143, 55.705441679273335, 62.49142415182931, 58.48206342969622, 63.92262799399239, 59.12072794778006, 61.76622676849365, 58.72015735081264, 61.16919585636684, 59.376880237034385, 60.69390433175223, 57.43355941772461, 59.33488532475063, 57.2976839201791, 58.94198553902762, 58.247082301548545, 54.81653778893607, 48.63209908349173, 55.72300672531128, 55.134393555777415, 57.771950585501536, 49.666835239955354, 46.30860410417829, 46.00994273594448, 49.14694322858538, 47.60345649719238, 48.968388421194895, 45.470630509512766, 47.907388074057444, 42.26941129139492, 44.44873809814453, 39.74447413853237, 42.91371774673462, 46.225646087101524, 46.793289593287874, 41.08145693370274, 40.09501770564488, 38.3613726752145, 43.29215485709054, 40.78831243515015, 41.33038657052176, 40.98604774475098, 44.806382724217, 41.19932617459978, 44.35938426426479, 44.65965414047241, 48.79497528076172, 42.509065083095, 41.1000086239406, 39.796307700020925, 37.63468142918178, 36.56551694869995, 35.699159962790354, 37.17210163388933, 46.02653850827898, 47.209434577396934, 41.702931608472554, 40.781666483197895, 41.74006278174264, 42.563528537750244, 42.82302638462612, 41.39158282961164, 40.8020281791687, 40.35605110440935, 42.76027372905186, 44.84638697760445, 45.18996844972883, 42.75169965199062, 45.759012017931255, 45.96302155085972, 44.516621998378206, 47.27883318492344, 48.120756830487935, 49.90797594615391, 51.85334300994873, 47.27042933872768, 52.41531331198556, 52.96383190155029, 51.89297553471157, 54.19246448789324, 52.43708896636963, 53.03592988422939, 52.88222878319876, 50.25101545878819, 52.96928971154349, 53.096921171460835, 55.02513313293457, 53.027529512132915, 49.237947259630474, 52.87861571993147, 53.56608438491821, 53.24833631515503, 50.2836719921657, 52.606718812670024, 47.81008897508894, 41.59618295942034, 46.6922037260873, 52.0697272845677, 56.17074516841343, 58.19467898777553, 55.074625151497976, 41.32101345062256, 32.5144670350211, 24.51173686981201, 26.18484398296901, 35.839048045022146, 7.43688884803227, 1.1295444348028727, 0.04657438922939556, 0.03062972892075777, 0.04581269635153668, 0.3016043374580996, 0.08007905406079122, 0.1918866227247885, 0.1751461053001029, 0.2321271284350327, 0.40708580879228456, 27.690400498253958, 37.30529165267944, 28.81943413189479, 24.117716687066213, 25.388279914855957, 4.169547966548374, 0.1881229111126491, 8.456097517694745, 7.417937636375427, 8.110862374305725, 8.904502987861633, 6.653892874717712, 3.326100928442819, 3.4241163432598114, 4.465207712990897, 20.546266181128367, 22.935086386544363, 37.046443462371826, 14.283367548670087, 33.822625228336875, 40.94006109237671, 53.47290556771414, 47.93036924089704, 45.25999934332711, 42.31282711029053, 32.29216636930193, 43.57893133163452, 59.74881035940987, 21.93422964641026, 41.92338752746582, 41.76087958472115, 1.513592324086598, 0.03579452035150357, 0.09580565696316105, 0.18749952742031642, 0.44142432191542214, 0.36002910669360844, 1.9225391915866306, 2.8259986894471303, 0.6869783827236721, 0.21312512164669378, 0.7663897243993623, 0.37409188066210064, 0.4353507821049009, 1.969676205090114, 21.056762490953716, 44.90944535391671, 46.64799928665161, 44.663454805101665, 50.813656261989046, 56.27586099079677, 55.14489575794765, 57.17781359808785, 52.009594099862234, 52.77502155303955, 58.98570360456194, 60.2254706791469, 60.88305514199393, 58.52812303815569, 52.78203228541783, 59.65805993761335, 64.52192401885986, 62.19044208526611, 64.87455204554966, 63.68688256399972, 62.839806829180034, 61.632633754185264, 64.35295077732631, 63.40693269457136, 60.98564529418945, 61.16590241023472, 61.917211123875205, 59.013593673706055, 58.59594440460205, 61.11148411887032, 57.71072653361729, 51.18349845068795, 60.29912853240967, 57.57955149241856, 59.75600869315011, 53.65392698560442, 48.095329897744314, 50.28948416028704, 53.311915806361604, 51.224878447396414, 50.0154367855617, 49.715750558035715, 50.25982230050223, 46.34070478166853, 46.64582102639334, 42.81397635596139, 46.16414063317435, 50.10953623907906, 48.713712624141145, 45.15074239458357, 41.78987094334194, 41.83161224637713, 45.82732670647757, 42.89473874228341, 43.33291299002511, 42.18380948475429, 44.830440861838206, 43.884999479566304, 42.718174593789236, 45.54045990535191, 46.8125638961792, 41.78819295338222, 41.459421566554475, 43.91353225708008, 41.09491212027413, 41.27611419132778, 37.799617767333984, 40.04621703284127, 47.32588638578142, 49.010466711861746, 42.354801177978516, 40.82264001028878, 41.47640643801008, 44.37760591506958, 44.70821162632534, 43.392313139779226, 45.00555978502546, 44.625218868255615, 45.00823136738369, 47.99201365879604, 48.76445184435163, 47.58227491378784, 47.69166040420532, 50.23730666296822, 48.595805168151855, 47.1950170653207, 49.85816431045532, 52.47727039882115, 53.07497876031058, 49.516806261880056, 52.9997228213719, 55.6062387738909, 54.915004185267854, 57.63782950810024, 56.079987798418315, 56.25279297147478, 54.646859305245535, 51.29157073157174, 54.972132274082725, 54.2592853137425, 56.0914488519941, 55.431581905909944, 50.24241358893258, 52.421410356249126, 54.520648751940044, 53.7298777444022, 51.76495497567313, 53.65081419263567, 49.93279491152082, 44.7917810848781, 51.486311367579866, 58.85158947535923, 60.11692592075893, 61.55276421138218, 59.219837052481516, 52.5116605077471, 47.11802755083357, 42.06426920209612, 40.577782017844065, 48.34878976004464, 12.356258613722664, 1.153156259230205, 0.12163083547992365, 0.06048013323119708, 0.04191435660634722, 0.07889065425843, 0.031402169793312035, 0.18344184729669774, 0.17214022230889114, 0.4350933459188257, 0.343948559569461, 37.7196752684457, 44.14517477580479, 34.15994984763009, 31.708475998469762, 41.598976135253906, 6.05933769260134, 0.15825624231781277, 16.862227065222605, 18.59792181423732, 23.216695138386317, 29.360443455832346, 19.953645638057164, 12.30620379107339, 6.534776432173593, 15.025208473205566, 40.44433144160679, 90.97468185424805, 109.09179006304059, 87.48456696101597, 58.86500644683838, 50.29019635064261, 66.86546802520752, 74.92610795157296, 72.6828681400844, 62.46148436410086, 45.51846538271223, 59.20291818891253, 67.88620703560966, 36.92760494777134, 54.30375378472464, 49.601716722760884, 2.828019312449864, 0.1262493926499571, 0.22076645732990333, 0.4086320815341813, 0.2601602327610765, 0.6644131307091031, 6.119210754122053, 2.832582541874477, 0.9441764844315392, 1.0838225739342826, 0.7403757774404117, 0.9118041758026395, 0.8591159858873912, 2.6846558281353543, 22.721860068184988, 58.068197454724995, 54.963610308510916, 53.43345022201538, 56.90558665139334, 62.3623057774135, 61.129889896937776, 61.748897961207796, 62.34601919991629, 60.452801840645925, 64.35845375061035, 62.63634967803955, 66.71795082092285, 63.21352958679199, 57.392565046037944, 61.776982579912456, 70.7525543485369, 65.1572186606271, 70.44713933127267, 66.13472597939628, 66.63336345127651, 63.43682384490967, 68.32688958304269, 66.54810905456543, 66.3696654183524, 63.69565119062151, 65.24984509604317, 61.531627791268484, 62.80515616280692, 65.68121010916573, 63.216162954057964, 55.0081239427839, 63.34107766832624, 61.153180258614675, 63.73971666608538, 55.250070640019004, 50.37854616982596, 54.14816624777657, 56.74789033617292, 54.159755843026296, 56.0411056791033, 52.27628680637905, 54.8088287625994, 46.68109703063965, 48.12914678028652, 44.75087703977312, 48.18742479596819, 50.178733348846436, 50.09059892381941, 47.193134103502544, 44.82676179068429, 43.562266077314106, 47.75322491782052, 44.37846054349627, 44.142041138240266, 42.35212959562029, 47.525897230420796, 43.73231281552996, 45.560821601322715, 46.4739990234375, 49.98071663720267, 43.632262229919434, 43.35461916242327, 46.203766209738596, 42.57157455171858, 42.00238159724644, 40.93873746054513, 41.15687962940761, 48.588242053985596, 52.56237193516323, 44.332470417022705, 43.50872673307146, 46.08289187295096, 47.991992814200266, 47.006488118852886, 47.42861202784947, 47.14455229895455, 45.69032212666103, 48.8531699180603, 52.5394880431039, 52.162096636635916, 49.62285661697388, 52.52817637579781, 54.23113121305193, 50.914766447884695, 52.013033458164756, 52.66500377655029, 55.199376583099365, 55.57686179024832, 51.15967307771955, 56.52806322915213, 57.61575508117676, 57.0439635004316, 60.37922041756766, 57.89764697211129, 57.26118155888149, 55.43970782416207, 51.7261631829398, 56.22102580751692, 55.568263394492014, 57.297124590192524, 57.058356693812776, 50.070761816842214, 55.98918873923165, 55.42125340870449, 54.68843732561384, 55.379334926605225, 58.669650895254954, 55.491885321480886, 50.102980613708496, 57.69560030528477, 62.80905410221645, 62.44073704310826, 60.64339092799595, 62.632819993155344, 59.490295682634624, 55.57191119875227, 53.136793409075054, 58.03824029650007, 70.92514760153634, 28.741190467561992, 2.351228496858052, 0.3649624634001936, 0.19007707839565618, 0.13584758261484758, 0.38032237919313566, 0.3578754094030176, 0.4379624905330794, 0.4601836981517928, 0.9516919382980892, 0.848646624812058, 51.91848931993757, 50.218751498631065, 49.54886872427804, 47.77030011585781, 65.35465172358921, 10.058975713593618, 0.16845052529658588, 29.075911249433243, 32.75646931784493, 53.56393044335501, 60.79966286250523, 36.56812947137015, 19.001836231776647, 19.642418452671595, 36.69577482768467], [12.275702936308724, 53.09240484237671, 38.67790481022426, 25.79008034297398, 3.4206481065068925, 1.062518637095179, 1.5931257477828433, 10.062488027981349, 15.586836576461792, 29.785242421286448, 31.291452067238943, 44.45300081798008, 28.00252573830741, 46.06901632036482, 54.013537951878135, 16.786550760269165, 0.14510797070605413, 0.028867766859808137, 0.03769534121134451, 0.061661958029227595, 0.7855795089687619, 1.3632001940693175, 11.401939170701162, 10.835101655551366, 3.0235691964626312, 1.0368363580533435, 0.09196850750595331, 0.22248179385704653, 0.3851162562412875, 2.3521428363663808, 7.243709819657462, 19.09321025439671, 31.315913200378418, 35.61593444006783, 45.00051539284842, 46.05399431501116, 46.36361994062151, 44.370852266039165, 41.822315556662424, 42.887832232883994, 51.565503461020334, 52.393874645233154, 52.22439765930176, 50.62284483228411, 50.94736739567348, 55.7633410181318, 59.90149007524763, 59.51091793605259, 61.06858594076974, 61.76084886278425, 64.74080617087228, 61.205076353890554, 59.30856554848807, 58.79406533922468, 56.52714259283883, 58.81529208592006, 56.68443591254098, 57.41637652260916, 56.764083112989155, 54.49243559156145, 49.478664125714985, 56.31550741195679, 57.39532348087856, 56.0598658152989, 55.096730845315115, 46.98940249851772, 47.26362010410854, 47.82826198850359, 48.26378549848284, 46.61683661597115, 47.47246905735561, 47.872608866010395, 44.482322216033936, 44.667821747916086, 46.04207468032837, 41.001851422446116, 40.94857610974993, 45.66656276157924, 50.11451462336949, 41.535542556217735, 41.406445026397705, 39.570772647857666, 41.90832035882132, 41.081752232142854, 41.48786401748657, 41.90545422690255, 39.24688931873867, 40.10400172642299, 40.82519347327096, 40.206174986703054, 38.92135231835501, 40.18360028948103, 39.628953388759065, 37.077147551945274, 38.34905699321202, 35.80817025048392, 36.40379762649536, 38.90790407998221, 41.66801691055298, 45.898712498801096, 40.6227194922311, 41.468176296779085, 42.19652468817574, 43.68095520564488, 41.042890957423616, 41.4210536139352, 40.72812019075666, 40.734175545828684, 41.1292153767177, 42.447549206869944, 42.30104643957955, 45.26045445033482, 45.02704014096941, 46.2338901247297, 49.35424620764596, 43.35119717461722, 42.624703952244346, 47.157771246773855, 50.37372759410313, 50.581113951546804, 51.97612462724958, 50.099430084228516, 51.52899762562343, 52.92679105486189, 53.57441527502877, 54.207020963941304, 50.094611508505686, 51.161861760275706, 48.87316335950579, 51.08503900255476, 51.70920957837786, 57.433007035936626, 47.146289348602295, 49.54878881999424, 54.07498434611729, 51.97112887246268, 48.49043573651995, 50.40222910472325, 45.00041464396885, 37.715058190482004, 44.981175082070486, 53.92305850982666, 54.366433484213694, 53.077188287462505, 55.06982742037092, 44.69016368048531, 34.59521974836077, 24.708754777908325, 41.587066922869, 22.469864538737706, 7.124328477042062, 0.1132659779063293, 0.00948902131390891, 0.06635603614683662, 0.10634767556829111, 0.05836454925260373, 0.03252881273095097, 0.13131884991058282, 0.0707310942400779, 0.1766716827239309, 0.20358628992523464, 21.403686046600342, 33.41490840911865, 19.701948881149292, 20.031578370503016, 10.630571007728577, 2.2635650294167653, 1.149742522409984, 9.997453757694789, 4.081435254641941, 5.207728692463466, 3.3831067723887305, 2.2114035998071944, 0.7743497001273292, 0.7780800685286522, 0.4521465322801045, 27.380293709891184, 34.0274372782026, 43.40136316844395, 25.470781087875366, 12.867260404995509, 6.716856147561755, 17.292584589549474, 41.479762417929514, 32.54583815165928, 40.94643259048462, 44.284003257751465, 57.467042786734446, 41.668270519801546, 46.9383019719805, 63.92258630480085, 19.836719615118845, 0.25069057089941843, 0.048104305884667804, 0.09035328203546149, 0.1451193836650678, 0.6799648819225175, 0.9314154663256237, 2.8816665709018707, 4.352609983512333, 0.5873599967786244, 0.6138340447630201, 0.2263939825019666, 0.03488694583731038, 0.2685828065233571, 3.176383967910494, 10.745822514806475, 24.547143152781896, 42.0263216154916, 46.61644751685006, 53.32905353818621, 52.43161031178066, 53.933532919202534, 52.43616138185774, 48.212622438158306, 50.96585655212402, 55.697124685559956, 57.125962666102815, 58.74773475102016, 55.70934656688145, 52.54757227216448, 60.071033069065635, 59.78905432564871, 63.504728589739116, 62.66579614366804, 64.17813410077775, 63.692114557538716, 64.55496965135846, 62.754288400922505, 59.6716228212629, 60.36675534929548, 63.620666231427876, 59.95641558510916, 62.61549118586949, 58.79146671295166, 56.492300851004465, 51.49803645270211, 59.86604731423514, 59.51565660749163, 61.01402868543352, 58.48290416172573, 51.61837230409895, 49.61391428538731, 51.54194906779698, 52.117186955043245, 49.951739174979075, 48.50626025881086, 50.62533228737967, 47.652319703783306, 47.58309480122158, 47.44887644904, 45.502897943769185, 43.672342913491384, 47.22396673474993, 49.71481255122593, 42.332949093409944, 42.10849448612758, 43.24103001185826, 44.150351183755056, 42.66923148291451, 41.1452830859593, 41.669993673052105, 40.534630230494905, 40.03323779787336, 41.99067735671997, 42.43801627840315, 38.32282059533255, 39.60768495287214, 40.373091561453684, 39.25557109287807, 40.70476382119315, 38.50127117974417, 39.182434354509624, 42.117714745657786, 42.32913105828421, 44.23044306891305, 39.64886345182146, 42.4598787852696, 42.35142435346331, 44.764693532671245, 43.505950927734375, 44.87291519982474, 45.44706221989223, 44.872817925044465, 44.5794997215271, 45.689123562404085, 44.61842353003365, 49.357418060302734, 49.751981939588276, 50.485930579049246, 52.38851063592093, 47.73144578933716, 44.502103737422395, 50.2769079208374, 51.50247982570103, 53.37212194715227, 55.47849266869681, 54.89232873916626, 54.50083943775722, 57.02423061643328, 55.02075229372297, 55.6311411176409, 52.36536618641445, 56.33980873652867, 48.787262780325754, 53.29067516326904, 53.2592693056379, 59.1542113167899, 47.59508391789028, 51.304852213178364, 54.18710742677961, 54.90557547977993, 49.49684756142752, 50.49400091171265, 46.53555311475481, 40.852642331804546, 52.40302194867815, 58.932070459638325, 58.31652954646519, 57.3793044090271, 61.12682574135916, 55.040109974997385, 49.919864313943044, 40.67216287340437, 54.644604614802766, 30.141629423413956, 7.898711289678301, 0.14592401763158186, 0.09527398406394891, 0.04933793004602194, 0.04820415231266192, 0.0909045578113624, 0.08043651309396539, 0.03994351093258176, 0.1195643027978284, 0.28088296364460674, 0.31767744783844265, 30.056795392717632, 41.1623443875994, 29.776348727090017, 31.19398273740496, 24.4766206741333, 2.3098641335964203, 1.16125807591847, 20.674837384905132, 16.75629309245518, 24.566335814339773, 11.586389524596077, 4.410436800548008, 1.6030650373016084, 1.8126759039504188, 4.736041980130332, 48.33264562061855, 104.82362283979143, 111.51128482818604, 107.97693075452531, 20.871172632489884, 4.738306658608573, 20.412878138678415, 60.27920109885079, 50.78051682880947, 61.93223312922886, 57.91126891544887, 71.48690250941685, 48.10496357509068, 67.82304791041783, 71.66285869053432, 27.76670387813023, 1.0078328400850296, 0.10373629283692155, 0.7137292729956763, 0.407891039869615, 2.9265302206788744, 2.7173047619206563, 25.346594197409495, 26.552747624261038, 7.848810195922852, 1.823749269757952, 1.2400954855339867, 0.351303010646786, 0.4945619734270232, 4.233962110110691, 13.552914721625191, 29.629943234579905, 51.02649695532662, 55.992263317108154, 59.58885587964739, 57.19043500082833, 60.28725406101772, 59.71326337541853, 58.47341987064907, 57.6406226839338, 61.2682215826852, 63.717683928353445, 65.4914687020438, 63.469793047223774, 57.12393379211426, 63.31640461512974, 64.97303581237793, 64.69024412972587, 64.62071350642613, 67.12797791617257, 68.810866355896, 65.27824238368443, 65.20766258239746, 63.063476290021626, 62.778350012642996, 67.06868893759591, 61.92623683384487, 65.47629383632115, 61.085907799857004, 59.57641165597098, 55.28682313646589, 62.78285244532994, 64.162570135934, 64.95778451647077, 62.61174610682896, 53.16914422171456, 52.52108573913574, 54.729799951825825, 55.074555669512065, 55.041120937892366, 53.41150433676583, 53.89229883466448, 49.10075855255127, 50.04388618469238, 49.822544370378765, 44.680338927677695, 44.90473447527204, 48.76279122488839, 52.73994009835379, 44.865341663360596, 46.99350888388497, 44.301422391619, 44.97480010986328, 44.71407243183681, 44.50861767360142, 42.32343353543963, 42.62684399741036, 41.9991854258946, 41.70411280223301, 42.022253445216585, 37.66711909430367, 39.31335926055908, 43.486457756587434, 41.45397417885916, 42.715249402182444, 39.272774832589285, 41.05449444907052, 43.87649141039167, 44.77484485081264, 49.60686533791678, 42.804439953395296, 44.163417271205354, 45.33162137440273, 47.40325110299246, 46.317032269069124, 46.752593994140625, 46.551909174237935, 46.81984213420323, 47.581479345049175, 48.060119901384624, 48.492259638650076, 51.81182404926845, 51.83633729389736, 53.78683907645089, 54.761157172066824, 50.76708943503243, 47.15723276138306, 54.05820097242083, 54.42464549200875, 55.51343168531145, 57.28784874507359, 56.41951847076416, 55.995212827410015, 58.76710632869175, 57.61691543034145, 57.45813519614083, 52.96459967749459, 56.59120150974819, 49.504104954855784, 54.86963939666748, 53.63315882001604, 60.5072409766061, 49.82271112714495, 52.059895583561485, 58.02032436643328, 55.546053477696006, 49.69829668317522, 54.97446339470999, 54.82541411263602, 46.58208520071847, 59.136785234723774, 63.32536779131208, 63.33908353533064, 58.29609489440918, 62.14984376089913, 59.499300548008506, 57.1601755959647, 52.34690134865897, 65.81603295462472, 39.13992180143084, 17.115721668515885, 0.6354052701166698, 0.23419663310050964, 0.206691890422787, 0.20684652855353697, 0.13468071951397828, 0.10760523165975298, 0.22664004644112928, 0.21453555167785712, 0.5197658581393105, 0.9118592185633523, 43.785664558410645, 47.42923389162336, 40.92557062421526, 42.39635835375105, 55.99251345225743, 4.23473813704082, 1.426419464605195, 35.954735551561626, 37.50643505368914, 54.66301734106881, 38.13830770765032, 5.911308492933001, 1.3260722777673175, 1.4593499089990343, 13.65492730481284], [8.986926862171718, 45.671940667288645, 53.68838657651629, 31.846460274287633, 0.6684265296374048, 0.09304724247860056, 6.120603433677128, 10.382218939917427, 12.291880079678126, 27.745150566101074, 44.52857289995466, 35.23777525765555, 34.865661008017405, 89.2573025567191, 50.98737164906093, 7.962012852941241, 0.0633126844518951, 0.030226265213319232, 0.14244862911956652, 0.08648983934628111, 0.6736506521701813, 0.5330480454223496, 0.3590878429157393, 0.9110088241951806, 0.5772757178970745, 0.21114066456045422, 0.17353415036840097, 0.13608882895537786, 0.1263432747551373, 0.6992334851196834, 3.812824845314026, 7.4584013393947055, 17.831879445484706, 22.277607883725846, 29.361819199153356, 42.50269705908639, 44.57042190006801, 40.80845873696463, 38.727351665496826, 44.97067982809884, 48.95558289119175, 51.82114853177752, 51.11965492793492, 49.499710219247, 52.29582861491612, 55.977084977286204, 55.65165567398071, 58.10716642652239, 56.90762594767979, 59.33430167606899, 59.64788082667759, 58.80728776114327, 57.12194660731724, 56.734737396240234, 57.80236979893276, 59.704154287065776, 57.8058716910226, 58.122160639081685, 56.06311409814017, 50.65436880929129, 53.49937473024641, 57.09448037828718, 58.68604169573103, 58.819169180733816, 48.82735736029488, 47.767295019967214, 48.38775525774275, 49.862565994262695, 46.91995872770037, 47.668064321790425, 46.4168153490339, 47.36039808818272, 44.32242679595947, 44.32433407647269, 45.00465651920864, 44.34213883536202, 41.54827165603638, 42.466413566044395, 45.592276096343994, 40.194067750658306, 38.52113607951573, 40.40423338753836, 41.15261690957205, 39.22545412608555, 40.4652281488691, 40.218247481754844, 39.35674033846174, 40.43301977430071, 40.6440052986145, 39.32151297160557, 39.81401865822928, 38.191374574388774, 36.84976427895682, 37.208263533455984, 38.30370610100882, 36.255363259996685, 36.447258608681814, 39.72182648522513, 39.99775334766933, 41.44001872198922, 39.148151942661826, 41.34536688668387, 41.69825199672154, 42.883913448878694, 42.24865007400513, 40.815229756491526, 38.99702514920916, 39.978548526763916, 41.79667322976248, 42.7268876348223, 43.618216446467805, 45.138589995247976, 46.837521825517925, 46.25968531199864, 49.971496377672466, 49.36098943437849, 43.14013869421822, 42.397334575653076, 46.67295374189104, 52.18821491513933, 51.846016134534565, 50.09149176733834, 50.10084751674107, 53.01852812085833, 53.21041652134487, 49.886995860508506, 51.09924112047468, 52.303954533168245, 46.692276682172505, 49.4386876651219, 54.230703898838584, 53.990264960697715, 46.19258655820574, 46.91226707186018, 49.92515536717006, 50.50667095184326, 49.279299463544575, 43.62374721254621, 43.922457218170166, 33.80661310468401, 44.26347133091518, 54.41351795196533, 56.87396192550659, 50.844596590314595, 53.013817242213655, 46.003387110573904, 31.960518428257533, 36.805410453251426, 48.25100776127407, 5.660677415984018, 2.47385464821543, 0.22295201862496988, 0.008927263868307429, 0.031063523143529892, 0.05132898249264274, 0.01699576703166323, 0.10273041216922657, 0.3183881182755743, 0.12202522717416286, 0.26723504598651615, 0.22745651405836853, 18.8426582132067, 23.674286127090454, 18.83100608416966, 23.424849271774292, 6.6629072938646585, 2.208961525133678, 1.2726595210177558, 15.518337760652814, 7.02503741639001, 10.911993895258222, 1.6510320348399026, 0.059761367871293, 0.22389937564730644, 0.018076183074819188, 0.18099856483084814, 9.586794376373291, 42.279656410217285, 55.89172288349697, 10.43407074042729, 1.0028214518513, 1.2205806012664522, 9.994369626045227, 20.543476479394094, 27.94745605332511, 36.77465425218855, 56.858648095812114, 46.45858097076416, 42.7042121887207, 89.59403310503278, 58.22332641056606, 11.619542854172842, 0.21645138173231057, 0.09234751002596957, 0.13420791631298407, 0.16645165612655027, 1.784157348530633, 0.8576239145227841, 0.4126087852886745, 1.1034411383526666, 0.4144931041768619, 0.39559365117124146, 0.10504709357129675, 0.11252095324120351, 0.09720123386276619, 3.468452798468726, 5.225311108997889, 11.928092377526418, 21.542966161455425, 25.986530235835485, 34.56063161577497, 52.97369834354946, 51.49083464486258, 50.09295088904244, 44.94471093586513, 49.99667317526681, 55.32011890411377, 56.479915687016074, 58.644484519958496, 55.22065544128418, 53.879482882363455, 60.42043713160923, 59.88888604300362, 60.84397847311837, 60.64837278638567, 63.17386926923479, 61.0302666255406, 62.889173780168804, 61.593105452401296, 57.88107899257115, 61.12610312870571, 62.06212970188686, 60.16768251146589, 61.01073523930141, 57.997263295309885, 55.18155445371355, 59.04401983533587, 59.42271055494036, 60.964508874075754, 61.5651250566755, 50.76228128160749, 51.95372016089303, 52.930869647434776, 52.41562598092215, 50.705524921417236, 50.8715694972447, 49.87865802219936, 47.7119665145874, 47.03487498419625, 47.842870576041086, 47.74806240626744, 46.81776114872524, 43.77950498035976, 44.426934650966096, 46.733538559504915, 42.763178076062886, 40.5504721232823, 42.64539916174752, 43.85609497342791, 40.0449663570949, 41.62896456037249, 40.10446378162929, 39.46491684232439, 40.49338572365897, 40.13641159875052, 40.34490966796875, 40.89737483433315, 39.18269838605608, 37.53214686257498, 36.908407075064524, 39.78143160683768, 37.02822528566633, 37.38707195009504, 42.008190291268484, 42.03602824892317, 41.69025462014334, 41.068324838365825, 42.34950317655291, 43.15633494513375, 43.97392947333199, 43.47240502493722, 43.69497667040144, 41.83100080490112, 42.81257976804461, 44.93423652648926, 44.90371309007917, 47.13261529377529, 48.21684346880232, 49.85046223231724, 49.041017941066194, 50.889134543282644, 53.554963793073384, 47.021544865199495, 44.34797532217843, 48.820381368909565, 53.626207147325786, 54.13490213666643, 54.4796404838562, 54.13325193950108, 54.995877742767334, 54.09672178540911, 51.04420443943569, 54.519731589726035, 54.77380289350237, 47.94893830163138, 51.398621627262656, 54.252496923719136, 55.94194793701172, 47.35406133106777, 48.94998959132603, 52.27982343946184, 53.239765712193076, 51.5510790007455, 44.32677984237671, 46.98816571916853, 38.39055858339582, 49.065475600106375, 59.6840739931379, 59.13201182229178, 56.594060693468364, 57.42150429316929, 54.99388360977173, 44.06829643249512, 49.33832788467407, 57.0046123777117, 5.153282608304705, 1.7417440244129725, 0.10090106818825006, 0.1231433307485921, 0.053019162333969555, 0.09280373661645822, 0.06354124218757663, 0.0552542329366718, 0.24050570598670415, 0.05579939850472978, 0.15726549976638385, 0.28239340973751886, 26.22816252708435, 29.122521502631052, 23.50868102482387, 39.224394525800435, 7.321269086429051, 3.001995256968907, 1.4087044894695282, 27.350472041538783, 19.539671966007777, 30.06668962751116, 8.687323144504003, 0.29436219749706133, 0.22447499047432626, 0.22751902070428642, 0.15142173905457768, 29.98685829980033, 97.68057591574532, 124.09873172215053, 97.98767239706856, 4.076979722295489, 1.0568400046655109, 22.76243928500584, 46.11035115378243, 48.37206275122506, 55.8779376574925, 68.67515414101737, 59.811559540884836, 54.66549089976719, 104.54144954681396, 66.78642531803676, 17.516012600490026, 0.5317404813000134, 0.32099125002111706, 0.8517088262098176, 0.28922183332698687, 3.09366284097944, 2.363016115767615, 6.023684748581477, 6.627813679831369, 1.433006139738219, 2.925329485109874, 0.4446425049432686, 0.21228690019675664, 0.15610555772270474, 4.006119387490409, 9.266286134719849, 18.674692460468837, 33.67199870518276, 39.528374740055625, 44.36407429831368, 60.87926837376186, 58.098158087049214, 58.161786215645925, 54.85853270121983, 61.26822853088379, 58.99235303061349, 60.780374663216726, 65.71527712685722, 60.885549545288086, 57.7827341897147, 62.38967473166329, 63.85712037767683, 65.26226152692522, 65.15555804116386, 66.58654648917062, 63.06417805807931, 63.920230865478516, 61.64802401406424, 61.10427188873291, 63.92360768999372, 65.42542607443673, 63.53196552821568, 64.40918949672154, 59.23742989131382, 57.9034035546439, 60.31958402906145, 62.26248795645577, 64.5385024206979, 65.00414984566825, 52.88008873803275, 53.9249484198434, 52.84535469327654, 55.118409224918906, 54.70884765897478, 54.32135009765625, 52.90521689823696, 51.217669691358296, 49.59320517948696, 49.591221468789236, 48.88769899095808, 49.063057626996724, 45.64886222566877, 47.92527968542916, 50.296585219247, 43.75345965794155, 43.167882851191926, 47.279555797576904, 44.94090679713658, 39.93435798372541, 42.33833394731794, 40.68852588108608, 40.664637974330354, 42.2748760495867, 41.534343991960796, 40.703082357134136, 39.2713747705732, 38.832995550973074, 37.68899202346802, 40.12317875453404, 40.663977895464214, 40.81502478463309, 40.139812741960796, 43.6541942187718, 42.5290515763419, 45.13605042866298, 41.91657134464809, 43.66957058225359, 46.511560985020225, 46.66539062772478, 46.769471168518066, 46.73375742776053, 44.69952637808663, 45.06571381432669, 47.58042669296265, 48.211309228624614, 49.157744203295024, 52.54065534046718, 53.51756164005825, 52.22204221997942, 55.167407921382356, 55.124617440359934, 46.85956845964704, 48.049958160945344, 51.75066600527082, 55.439412525721956, 56.884950501578196, 56.89002963474819, 54.8082138470241, 58.77594443729946, 57.78664949962071, 53.99009125573294, 54.45069776262556, 56.14926828656878, 47.61026225771223, 51.220574038369314, 54.94659069606236, 60.02966349465506, 48.6738577570234, 50.257814271109446, 51.41351509094238, 55.80687495640346, 53.49844714573452, 50.33489063807896, 51.83113309315273, 45.88431930541992, 57.85360581534249, 63.457821301051546, 64.67569460187639, 59.10307257516043, 59.77655451638358, 61.786355699811665, 55.289560726710725, 62.209223066057476, 61.72119549342564, 10.921460815838405, 7.594175219535828, 0.323539990399565, 0.23419435322284698, 0.11000055527048451, 0.21992299758962222, 0.17507846892944404, 0.2357299593942506, 0.6929078016962323, 0.4084513469466141, 0.3899669130997998, 0.705715937273843, 37.97699138096401, 40.60576936176845, 34.85114622116089, 52.21940885271345, 30.68688235964094, 3.8066296577453613, 1.5160203937973296, 44.40000690732683, 42.51092720031738, 54.18578379494803, 25.08247058732169, 1.4329995172364371, 0.4041568988135883, 0.44727999770215576, 0.37078855506011416], [5.127141748155866, 27.258490051542008, 40.2452620778765, 7.8801430974687845, 0.2683740348688194, 2.05606033546584, 19.423162834984915, 3.7399981703077043, 12.137026446206228, 27.41667100361415, 48.15580701828003, 33.13499328068325, 50.80140311377389, 65.85807650429862, 40.018806389399934, 4.648955430303301, 0.18807796495301382, 0.09439220066581454, 0.08368603765432324, 0.028106533689424396, 0.21912334407014505, 0.20646352267691068, 0.16853805631399155, 0.38400712289980476, 0.0451998570933938, 0.36036935129335945, 0.029323216527700424, 0.026867491425946355, 0.039437547725226195, 0.8435647775019918, 3.160505597080503, 5.377821462494986, 6.1305654134069165, 10.584382857595172, 11.992577740124293, 20.10324730191912, 37.25648750577654, 36.174663407461985, 33.86438042776925, 38.03844124930245, 48.46814244134085, 49.75260727746146, 47.63399730409895, 43.469934940338135, 50.110415186200825, 58.980374336242676, 55.983327933720176, 56.074807916368755, 58.42068999154227, 59.867749622889924, 57.52943761008126, 56.89204808643886, 56.566465922764365, 56.42894370215279, 57.985788345336914, 58.631380217415945, 57.34869759423392, 53.793054240090505, 55.12099395479475, 52.56332036427089, 57.68854440961565, 57.17867170061384, 62.0092191696167, 51.38568408148629, 48.39307757786342, 50.985717977796284, 50.73398126874651, 49.97818749291556, 47.263390813555034, 45.591369356427876, 45.4312550680978, 45.34056370598929, 43.48950801576887, 44.35066774913243, 45.23743854250227, 44.145230361393516, 41.854822703770225, 38.45691735403878, 40.821024554116384, 40.80919872011457, 38.6628098487854, 39.43046072551182, 42.51040955952236, 39.828019278390066, 40.27665056501116, 40.05613906042916, 39.35949182510376, 40.948034150259836, 39.73197432926723, 38.50182008743286, 38.42491395132882, 37.3331469808306, 36.54420682362148, 35.157346384865896, 38.30519996370588, 35.67426804133824, 35.29467405591692, 37.880894320351736, 39.84685237067086, 38.80036333629063, 39.592440605163574, 39.25773893083845, 41.8222564969744, 40.99450370243618, 41.436388288225444, 40.850335529872346, 39.693964208875386, 41.07734707423619, 39.57721710205078, 40.500038623809814, 44.56055545806885, 44.990145206451416, 45.21224437441145, 47.62100069863455, 46.38069861275809, 51.584145477839876, 50.471926484789165, 42.8563152040754, 42.775104658944265, 48.590906688145225, 50.00781808580671, 50.97352041516985, 48.672954491206575, 50.642393589019775, 51.80968747820173, 49.8843103817531, 53.54097012111119, 48.60167292186192, 48.3505858693804, 50.44826439448765, 45.65832567214966, 52.51079198292324, 45.171656472342356, 45.42657545634678, 51.33525058201381, 46.02326243264334, 51.618618965148926, 39.95386505126953, 38.755210467747276, 29.0427440234593, 36.15165444782802, 50.30491263525826, 58.539427757263184, 49.72146545137678, 52.44170951843262, 37.70131465366909, 32.43309668132237, 41.21632841655186, 33.769040720803396, 1.5103111458676202, 0.4307489033256258, 0.08967474023146288, 0.09430603350379638, 0.023775573587045074, 0.053646973467298915, 0.043280234028186114, 0.04015646575550948, 0.11590950962688241, 0.15555532010538237, 0.20308405187513145, 0.19732064328023366, 23.01607632637024, 17.1863831111363, 17.85484845297677, 13.043048960821968, 4.734864694731576, 0.5649774606738771, 0.3764974772930145, 14.202353290149144, 9.957079512732369, 14.936872550419398, 6.971697398594447, 0.5335128690515245, 0.23301033675670624, 0.1590911118047578, 0.1075639563745686, 6.644085926668985, 29.166279520307267, 42.37635449000767, 14.722638743264334, 0.17913289208497318, 3.1213060319423676, 26.080725227083477, 15.195114510399954, 26.54729676246643, 36.68933384759085, 60.99034227643694, 43.489768573216026, 59.159450258527485, 73.2338672365461, 47.2199194090707, 6.444972702435084, 0.30654119540538105, 0.15193026033895357, 0.2962788689349379, 0.39562635655914036, 0.24007421199764523, 0.1610313012663807, 0.1573000100574323, 0.12886335381439754, 0.09059132569070373, 0.32805078263793674, 0.06323307872350727, 0.16858319246343204, 0.028281251367713724, 2.1562985224383215, 6.174135395458766, 10.307490195546832, 9.661826235907418, 14.668065854481288, 13.643104076385498, 23.373342275619507, 47.310100078582764, 44.41700220108032, 44.22460658209664, 45.904104300907676, 55.43366983958653, 55.13380295889718, 55.41913420813424, 50.516929967062815, 51.909008502960205, 62.148613929748535, 60.21166460854666, 60.8597091947283, 61.965250968933105, 61.93258053915841, 61.378072602408274, 57.96302604675293, 60.027189935956685, 60.13121836526053, 59.52011735098702, 60.89369283403669, 58.604824202401296, 57.74145494188581, 56.88856356484549, 56.06076560701643, 61.495670863560264, 58.62765598297119, 62.91354806082589, 55.07773447036743, 51.224416392190115, 53.557253224509104, 54.420559951237266, 52.157757486615864, 49.21359034946987, 48.6889249256679, 47.44168158939907, 47.39366953713553, 46.946556431906565, 47.11775309698922, 47.416921683720176, 45.59060852868216, 43.17588370186942, 42.119927746909006, 41.50276790346418, 43.83643504551479, 40.622827189309255, 42.71518686839512, 44.86697449002947, 41.804660184042795, 41.67632000786917, 40.42363623210362, 40.2316575050354, 39.15847001756941, 39.642974853515625, 37.4931639943804, 38.968475001198904, 36.16349765232631, 35.99751213618687, 35.62652696881975, 40.27510459082467, 37.361228125435964, 37.210160391671316, 40.433391502925325, 42.23900250026158, 40.443605354854036, 40.86686182022095, 41.54982110432216, 43.19671787534441, 43.28979246956961, 43.18962376458304, 42.90144375392369, 42.13772208350045, 43.9316531590053, 44.0286500113351, 45.18470866339547, 47.87667008808681, 48.93836872918265, 48.850237778254915, 48.801874841962544, 50.36730745860508, 54.15920346123831, 54.8839943749564, 46.948081561497276, 46.14539439337594, 53.03705896650042, 51.67437825884138, 53.410823413303916, 54.38127136230469, 53.94849239076887, 52.285715511866975, 52.72346939359392, 55.51794106619698, 50.93482937131609, 50.5977201461792, 51.16989040374756, 45.92533104760306, 55.8006910596575, 45.37538807732718, 46.83764689309256, 54.15332875932966, 49.81100688661848, 53.81276627949306, 41.28819016047886, 40.34013625553676, 33.98979541233608, 44.48147453580584, 55.93964460917881, 63.09305477142334, 57.26575347355434, 58.89430700029646, 47.10606970105852, 44.10349600655692, 52.30531985419137, 41.23893438066755, 2.116879871913365, 0.23144338226744107, 0.049731643205242496, 0.005300637110069926, 0.03842770102034722, 0.04787684398304139, 0.014650222446237291, 0.03760094002687505, 0.04864464706874319, 0.07811939064413309, 0.1131741992597069, 0.5453541193689618, 29.40750013078962, 20.81844970158168, 16.529992001397268, 31.019360610416957, 4.602915363652365, 1.2839265678610121, 1.218517529112952, 19.784554277147564, 23.114822387695312, 32.48904357637678, 30.500378813062394, 4.260654483522687, 0.13311594990747316, 0.06003302615135908, 0.14908926135727338, 11.974449021475655, 60.31595706939697, 79.28462954929897, 28.570507969175065, 0.5071652999946049, 3.7426823462758745, 44.819018023354666, 33.694048813411165, 50.50677170072283, 55.161182335444856, 72.04551683153424, 52.80735846928188, 71.13080038343156, 81.25356142861503, 55.46315452030727, 10.224175214767456, 0.5898856669664383, 0.6130455870713506, 0.4161149114370346, 0.32474067168576376, 0.5937171642269407, 0.5251492464116642, 0.6508519298263958, 0.8427946673972266, 0.30697586493832724, 0.6365861924631255, 0.11293329218668596, 0.27244573352592333, 0.1544859353452921, 2.553217623914991, 8.580075962202889, 14.866233689444405, 13.249946338789803, 21.579843725476945, 22.845689126423427, 40.926199436187744, 57.583185400281636, 54.55327749252319, 54.93155132021223, 55.82042394365583, 61.01587690625872, 58.99009486607143, 63.926685741969514, 57.32302747453962, 56.696911403111045, 63.08254909515381, 63.93478039332798, 63.473823002406526, 64.83416216714042, 63.57223728724888, 62.31147275652204, 62.675419398716514, 62.65713174002511, 60.70972537994385, 63.7812807900565, 64.09882041386196, 62.45102037702288, 58.60511602674212, 59.81051731109619, 57.11746849332537, 64.30054746355329, 61.879746437072754, 69.5228135245187, 57.08415535518101, 55.35644061224801, 58.49846117837088, 56.47403056280953, 55.53237247467041, 52.70086342947823, 50.83750247955322, 51.050252846309114, 50.50092131750924, 47.85873678752354, 51.368650572640554, 49.459771973746165, 47.008562156132285, 45.60358428955078, 41.41200358527047, 44.731137207576204, 45.831582478114534, 44.61006137302944, 45.40795081002371, 45.974215098789756, 43.20039347239903, 42.5136786869594, 40.435399532318115, 40.76849617276873, 40.858308587755474, 40.041832719530376, 38.46420948845999, 39.44735527038574, 36.76409993852888, 35.58978142057146, 36.789512974875315, 42.69308117457798, 39.93388898032052, 41.081821714128765, 43.07279327937535, 44.66938509259905, 42.854845660073416, 42.20238549368722, 42.610501834324424, 45.76401472091675, 46.50085033689226, 45.78776018960135, 45.58215951919556, 44.27266379765102, 46.84303869519915, 44.72521734237671, 48.45704616819109, 51.92886298043387, 50.93209178107125, 51.33851970945086, 51.67303030831473, 53.68708726337978, 56.86443941933768, 54.420295919690815, 49.069908550807405, 49.445298876081196, 54.38778182438442, 55.099791526794434, 56.795037337711875, 55.17008645193917, 58.13384403501238, 58.395690373011995, 52.32948221479143, 57.309429849897114, 51.94994381495884, 50.83099201747349, 51.06464603969029, 48.99641745431082, 58.00841515404837, 46.93033586229597, 48.01618296759469, 55.900380338941304, 51.888987268720356, 54.03030048097883, 44.8554995400565, 47.03739718028477, 44.53194277627127, 56.70058005196707, 59.32642936706543, 62.62231431688581, 60.32072353363037, 62.887999534606934, 59.51733112335205, 58.52123737335205, 65.39267226627895, 49.75464309964861, 5.964096563202994, 0.4367532054228442, 0.3415324863578592, 0.19112226659698145, 0.20587501568453653, 0.21600555708365782, 0.13901505193540029, 0.11175578965672425, 0.1712921213890825, 0.20029576149369988, 0.42624799055712564, 0.866705481495176, 39.97895499638149, 32.38085317611694, 33.72480501447405, 48.257924692971365, 26.82765657561166, 3.083989211491176, 1.7938124133007867, 39.07825653893607, 46.254658290318076, 48.91978229795183, 50.41637911115374, 3.041978882891791, 0.4350483997591904, 0.38366128717150005, 0.24320176988840103], [5.336181776864188, 18.16713523864746, 15.528806958879743, 1.8869711458683014, 0.10304935755474226, 19.385623455047607, 18.506386246000016, 3.5623257841382707, 17.21080255508423, 29.407948289598735, 44.84307268687657, 35.338736057281494, 38.334941727774485, 31.901281561170304, 36.26847798483712, 1.4953946662800652, 0.03263143436717136, 0.16716314080570424, 0.025645207281091383, 0.2567244571234499, 1.4115942886897495, 0.11392661317118577, 0.027870634204841087, 0.08903838973492384, 0.08922530577651092, 0.14601671908582958, 0.09388109416301761, 0.05484120188547032, 0.07071445656142064, 1.1185575957809175, 3.4179092134748186, 2.9599425877843584, 1.513852013008935, 4.420303242547171, 9.517446143286568, 13.658921650477819, 14.058621985571724, 29.207162720816477, 35.921481473105295, 34.362399509974885, 45.93085833958217, 49.62831095286778, 43.876817975725444, 42.26025356565203, 49.24022626876831, 57.84802641187395, 55.183597224099294, 56.786164488111226, 56.768001896994456, 58.62406376429966, 59.41779817853655, 59.284260749816895, 53.930333273751394, 57.6270945412772, 57.504636015210835, 60.15293148585728, 56.64526196888515, 56.45314427784511, 54.045131410871235, 56.039264406476704, 59.281432832990376, 62.51169204711914, 55.48007685797555, 49.912447111947195, 53.39574582236153, 55.693716594151084, 52.10213368279593, 49.0865147454398, 45.72187737056187, 47.64146661758423, 45.06798587526594, 45.06180545261928, 43.35287863867623, 43.78753014973232, 42.71871655327933, 43.594651630946565, 39.34869432449341, 39.1995130266462, 39.706029755728586, 41.15082080023629, 38.43081644603184, 40.207599367414204, 40.73916435241699, 38.483216285705566, 41.61743402481079, 39.64447913851057, 40.752414567129954, 39.230258805411204, 37.24803849628994, 37.10240772792271, 36.4872385433742, 36.989443915230886, 37.72496632167271, 36.68425818852016, 36.41984101704189, 37.79496594837734, 35.79605259214129, 37.58818755831037, 38.46655103138515, 39.59284012658255, 39.68647405079433, 41.32650947570801, 41.45513800212315, 40.91736480167934, 41.727285044533865, 41.79840680531093, 40.11708518436977, 40.588447502681184, 41.15344374520438, 41.044169425964355, 42.42170190811157, 45.66342217581612, 48.402443749564036, 49.82070657185146, 47.66541010992867, 50.53583254132952, 52.555705138615195, 49.52231618336269, 40.610539300101145, 46.67994015557425, 52.230223723820274, 50.957463128226145, 51.11202233178275, 51.64107206889561, 47.8803700038365, 49.537282603127615, 52.10367270878383, 48.69132552828108, 50.45051908493042, 44.97225359507969, 43.795593534197124, 50.275031907217844, 41.045600754874094, 43.21319900240217, 48.77012504850115, 47.76222630909511, 44.81715938023159, 36.176608903067454, 35.40151650565011, 29.99809353692191, 27.28861744063241, 25.438025542667933, 53.178357533046174, 41.52508899143764, 46.72355399812971, 22.456385033471243, 33.58474670137678, 57.7481495312282, 24.243209838867188, 1.393964211855616, 0.20396191334085806, 0.07052826655230351, 0.0990228968273316, 0.13049288280308247, 0.018377985273088728, 0.033557848406157324, 0.08173896784761123, 0.06756120254950863, 0.033282712634120665, 0.06218373788786786, 1.140931989465441, 27.99618377004351, 18.190100772040232, 19.60121042387826, 18.372292961393082, 8.342947840690613, 0.9774154722690582, 0.23011589635695728, 7.556321433612278, 12.177305153438024, 15.535576241356985, 31.64482355117798, 11.855110236576625, 0.09110414210174765, 0.03593871922099164, 0.15240051224827766, 7.5562536886760165, 25.737505061285837, 23.591107504708425, 3.7719703061240057, 0.9810954119477953, 30.26236479622977, 32.4791910307748, 19.167950289590017, 29.133207832063945, 40.90594891139439, 53.55403273446219, 45.47077294758388, 43.57225063868931, 43.85380901609148, 45.510127544403076, 2.47154524070876, 0.1733086867524045, 0.16863273909049376, 0.46073928262506214, 0.05559729006407516, 0.2526734402137143, 0.12960462618087018, 0.015472666260653307, 0.048123050414557965, 0.10941141724054303, 0.15689054131507874, 0.04600375484941261, 0.1383527610450983, 0.11224914568343333, 1.0416546080793654, 6.463406273296901, 5.885650966848646, 4.420265027454921, 10.448635033198766, 16.21571281978062, 15.133888721466064, 21.251468385968888, 41.05652332305908, 39.7674275125776, 45.81105055127825, 49.9464932850429, 54.60676819937569, 49.205481801714214, 48.84331389835903, 52.61479261943272, 61.16804245540074, 58.49194376809256, 59.08707087380545, 59.10797800336565, 60.723468916756765, 62.07909720284598, 60.439621107918875, 56.151154722486226, 60.31893784659249, 60.862877573285786, 61.82803099496024, 57.93253040313721, 60.724052565438406, 56.609617710113525, 60.62592315673828, 62.61525494711739, 63.662994657244, 56.22646277291434, 52.6092757497515, 55.877253259931294, 57.02093022210257, 53.62500163487026, 52.33497476577759, 48.5744047164917, 48.48211874280657, 48.20251975740705, 45.97615017209734, 45.52850552967617, 47.42340087890625, 46.001861980983186, 47.17915085383824, 40.00120660236904, 41.49749769483294, 41.44240542820522, 42.55514901024954, 39.6466817174639, 41.64059237071446, 42.6845383644104, 40.435826846531455, 41.58546536309378, 40.5642260823931, 42.169232164110454, 39.67162922450474, 38.09084108897618, 37.927422932216096, 36.82202359608242, 37.01373134340559, 38.20460047040667, 36.169612067086355, 38.31995446341378, 38.86363363265991, 36.838862555367605, 38.589951038360596, 39.75683845792498, 40.64120170048305, 40.9754239491054, 42.44538484300886, 43.581488268715994, 42.52948236465454, 43.98588037490845, 43.51866960525513, 42.69507878167288, 43.79364456449236, 44.71812323161534, 44.240868840898784, 44.6452887398856, 48.172378471919465, 50.868623461042134, 52.28489562443325, 50.93312358856201, 52.80383225849697, 54.28797789982387, 52.39942625590733, 44.89909948621477, 49.91363525390625, 55.92387914657593, 54.540871483939036, 54.741709164210725, 53.18396125520979, 49.848322187151226, 54.16339322498867, 56.207372597285676, 51.657035555158345, 51.419855322156636, 47.712227072034565, 47.78397764478411, 51.735435553959434, 43.17749915804182, 43.817299706595286, 51.12793023245675, 49.50730460030692, 45.533810479300364, 38.9479534966605, 38.094252654484336, 34.95118638447353, 32.79648051943098, 32.641403675079346, 52.59422247750418, 44.115172454289024, 49.820595400674, 27.75486067363194, 41.28066178730556, 68.05549989427838, 24.144350869315012, 1.3926914972918374, 0.11517719392265592, 0.04183704771899751, 0.033825218344905546, 0.10690949577838182, 0.06732083830450263, 0.047249144807990105, 0.012079152328494405, 0.04912294301071337, 0.04501348387982164, 0.1833606945084674, 1.6300043974603926, 35.879375389644075, 24.47942427226475, 22.949721029826573, 39.36675269263131, 1.6697015187570026, 2.240008247750146, 0.2092606747256858, 9.427553824016027, 30.809281826019287, 28.605264595576696, 62.25695719037737, 27.399177176611765, 0.14772575880799974, 0.09561159594782762, 0.11351411137729883, 12.450316378048488, 32.01446424211775, 31.290569646017893, 2.330024983201708, 0.5814898546252931, 37.799899169376914, 56.83527435575213, 34.60614579064505, 59.76071957179478, 54.5737955229623, 68.32227597917829, 55.1469281060355, 60.64552402496338, 50.17164618628365, 57.07099199295044, 4.204562110560281, 0.3812173940241337, 0.6503607247556958, 0.4540792171444212, 0.8369479754141399, 4.007093003817967, 0.31731603294610977, 0.22522270892347607, 0.18066990960921558, 0.3019711806305817, 0.5035930573940277, 0.18120920924203737, 0.21268347677375588, 0.17040184273251466, 2.1539558938571384, 8.701103159359523, 6.748152571065085, 5.621343663760594, 13.572770936148506, 22.340101718902588, 25.001841953822545, 39.38894871303013, 56.31471879141671, 51.226490429469514, 51.656347683497835, 57.30706746237618, 61.670744623456685, 57.82675102778843, 56.19416407176426, 56.608724866594585, 64.88549545833042, 62.11915356772286, 63.71070098876953, 62.25882625579834, 65.36089815412248, 64.89446558271135, 62.107862745012554, 59.4285956791469, 61.78163092476981, 63.72311741965157, 64.99710437229702, 62.46073395865304, 62.59233978816441, 59.65031964438302, 60.584894044058665, 64.97791344778878, 67.42134475708008, 59.5720134462629, 55.18341309683663, 57.701308250427246, 59.47162587302071, 55.99789135796683, 55.679253918784006, 51.49615696498326, 51.8612048966544, 51.793519020080566, 49.77721432277134, 47.07696369716099, 49.700374194553916, 47.4677859715053, 48.61125101361956, 42.491625104631694, 43.10279907499041, 45.06980977739607, 44.15344313212803, 43.79901204790388, 45.059748785836355, 44.38824360711234, 40.26272290093558, 41.80808564594814, 40.75233118874686, 42.832180636269705, 39.17958211898804, 38.88842827933175, 38.205944946834016, 37.0871981212071, 36.48171819959368, 38.032743726457866, 38.86453342437744, 39.44940498897007, 42.16755764825003, 39.66375344140189, 41.13668121610369, 41.819178444998606, 42.775729996817454, 44.500988551548545, 43.68808058329991, 47.380332469940186, 45.92601891926357, 47.660619327000205, 46.96531656810215, 46.05452585220337, 47.13046135221209, 49.21600832257952, 46.955071449279785, 49.5464368547712, 49.877247537885395, 54.95556082044329, 55.306910378592356, 53.44875362941197, 53.88929373877389, 56.7754225730896, 52.66974244798933, 46.460411821092876, 53.166291986192974, 57.85011087145124, 56.07826117106846, 57.56934458868844, 57.131382261003765, 52.584800720214844, 54.80645595278059, 59.66694668361119, 51.890845911843435, 53.44535943440029, 49.22157382965088, 48.01551594052996, 54.05255903516497, 45.38951029096331, 44.818726199013845, 52.51479761941092, 49.562237058367046, 52.24027081898281, 43.26561621257237, 44.17048011507307, 41.96189444405692, 46.58558709280831, 51.14889989580427, 66.08255890437535, 57.144264221191406, 64.53470175606864, 46.319349493299214, 60.903093746730256, 76.51666178022111, 24.420380217688425, 2.1402088829449246, 0.19132879908595765, 0.11455554727997098, 0.2078809416187661, 0.2306479492357799, 0.13708290989909852, 0.2329808883368969, 0.09862608954842601, 0.1493341446455036, 0.16123254118221148, 0.4836604669690132, 2.653649926185608, 48.782041209084646, 35.6281806400844, 37.160011768341064, 57.76548181261335, 20.311707156045095, 4.247727794306619, 0.6893507582800729, 24.353939805712017, 51.08119664873396, 42.83684287752424, 77.21461527688163, 28.57282519340515, 0.32032956981233185, 0.07786539463060242, 0.2761289844555514], [5.532604311193738, 12.82432314327785, 7.2461317011288235, 0.870039205465998, 5.303008036954062, 23.3880672454834, 7.485715576580592, 5.705832890101841, 20.40756450380598, 42.06739936556135, 46.30289268493652, 49.63645771571568, 74.26627922058105, 36.92928988592965, 33.856153760637554, 1.6608005506651742, 0.1812561774360282, 0.2003689482808113, 0.2501222842506, 0.8117320399199213, 0.34956083127430504, 0.10642706416547298, 0.026024340419098735, 0.011839727006320442, 0.06049027054437569, 0.02214833635038563, 0.05437940112980349, 0.11106229972626482, 0.0702527134812304, 1.3092211591345924, 2.626936273915427, 0.5985653783593858, 0.46134822709219797, 2.922016280038016, 6.165041506290436, 9.54717401095799, 12.62870877129691, 12.615300485066005, 27.759731360844203, 35.04732166017805, 42.71646533693586, 43.93245220184326, 38.99555213110787, 38.015738010406494, 45.996605668749126, 58.6475556237357, 52.17041710444859, 54.73093945639474, 58.06397989818028, 57.4898294040135, 59.248081479753765, 53.797580991472515, 54.37780768530709, 54.957332611083984, 56.96854427882603, 56.485105991363525, 54.773139340536936, 57.04995632171631, 55.448236737932476, 60.06321634565081, 60.35368578774588, 60.51181289127895, 51.821551527295796, 53.58364595685686, 55.22416080747332, 54.87864078794207, 48.363384451184956, 46.47055966513497, 46.88194513320923, 45.59728922162737, 45.12818159375872, 43.35248606545584, 43.30172947474888, 42.538455963134766, 44.35854353223528, 44.00142696925572, 40.100152424403596, 37.47911473682949, 37.60452972139631, 40.266117095947266, 38.3679769379752, 37.454379149845664, 40.71328231266567, 39.19658088684082, 40.40730101721627, 42.283814907073975, 42.69466188975743, 39.61714145115444, 40.44951827185494, 36.04878289358956, 36.52796540941511, 37.54407344545637, 37.219686371939524, 33.254495348249165, 36.757106576647075, 36.583450249263215, 33.92886665889195, 35.341900961739675, 37.29335812159947, 37.88259315490723, 39.22876494271414, 40.08836133139474, 40.36304794039045, 40.951014927455354, 41.201000690460205, 40.975549016680034, 40.918559891836985, 41.108506270817344, 39.72755527496338, 41.22946398598807, 40.694258144923616, 41.48002644947597, 47.64457941055298, 48.96253456388201, 51.61256013597761, 49.829148633139475, 53.43600715909685, 52.695499420166016, 46.817431109292166, 44.032912731170654, 47.7569317817688, 49.509319577898296, 51.531314849853516, 47.48782457624163, 47.34805808748518, 48.926369190216064, 48.72674397059849, 50.538813318525044, 47.916108063289094, 46.042224066598074, 45.91312306267874, 45.87682567323957, 37.2529856136867, 39.855082511901855, 45.27412503106253, 39.52490064076015, 37.98893880844116, 37.54932975769043, 21.15211956841605, 20.011581454958232, 25.58042366164071, 8.311198915754046, 12.215046031134468, 28.275975567953928, 25.51214371408735, 20.298151220594132, 41.390022959027974, 28.857246228626796, 1.0208712433065688, 0.036706396777715, 0.13606402171509607, 0.04188797855749726, 0.08150019137454884, 0.016200242397774543, 0.01630102690043194, 0.16638236413044588, 0.11529395622866494, 0.12174875129546438, 0.23381917764033588, 0.2598437097455774, 2.1298949335302626, 30.18004948752267, 18.33753286089216, 15.192811182567052, 12.84839951992035, 5.818836654935565, 1.140611503805433, 0.6558823713234493, 4.200947310243334, 17.745490755353654, 18.152874061039515, 45.84941502979824, 36.15306840624128, 1.8560308175427573, 0.3837675457554204, 0.33037145382591654, 8.010988099234444, 22.153888259615215, 11.121850337300982, 0.5852359107562474, 9.468950322696141, 42.689961433410645, 15.95051223891122, 13.541305150304522, 25.330437898635864, 54.631371770586284, 56.948397977011545, 58.366278648376465, 75.47263935634068, 44.46642821175711, 44.39091518947056, 2.368032932281494, 0.15149595721491746, 0.18190795103354113, 0.4317594048167978, 0.18991374144596712, 0.19693914375134877, 0.019749005990368978, 0.018089368706569076, 0.033401116994874816, 0.06550433899142913, 0.10462046467832156, 0.02071863762103021, 0.046101026237010956, 0.035077600606850216, 1.7138842450720924, 4.588628130299704, 3.083636590412685, 1.1752754151821136, 6.1631850344794135, 13.54720503943307, 17.076417446136475, 14.081937534468514, 19.46115732192993, 40.23355088915144, 40.597400256565635, 51.49323524747576, 47.20739875520979, 48.020681926182334, 44.951728616442, 52.221100739070344, 60.087653160095215, 57.34703350067139, 56.6327691078186, 59.24906117575509, 59.58734812055315, 60.92778764452253, 57.60824407849993, 57.95177691323416, 55.476783411843435, 59.156379154750276, 59.52769088745117, 58.76274285997663, 57.563476834978374, 58.61822032928467, 61.19396618434361, 60.04346261705671, 61.794408661978586, 54.54338673182896, 59.38642706189837, 58.07464190891811, 57.2902250289917, 51.693781103406636, 49.441369669778005, 47.563222953251426, 49.294036592756, 46.294815404074534, 44.35227973120553, 45.462466376168386, 47.20384127753121, 47.12013632910592, 45.59640680040632, 41.53904792240688, 39.548531464168, 39.35705648149763, 41.94543763569423, 40.67941331863403, 40.14899131229946, 42.40341772351946, 39.334044047764365, 41.2252915927342, 40.604063579014365, 43.326635292598176, 40.529005663735525, 38.89421612875802, 37.561819144657676, 36.50063467025757, 35.89735037939889, 36.503042221069336, 34.756199087415425, 37.625377791268484, 38.11965526853289, 36.09114258629935, 36.75328854152134, 40.181627001081196, 40.98017999104091, 41.25178507396153, 41.6849809374128, 42.92998000553676, 43.732927731105256, 41.970322608947754, 43.67199897766113, 42.69323056084769, 43.786703314099995, 42.41969040461949, 44.141784054892405, 44.431367601667134, 44.1928950037275, 47.62902239390782, 51.976597104753765, 53.548328263419016, 53.59825454439436, 52.800080231257844, 54.990399088178364, 50.21014962877546, 46.368914467947825, 52.05228730610439, 50.331388745989116, 52.54551213128226, 51.04620552062988, 51.904850006103516, 53.22147110530308, 51.33083152770996, 53.88847732543945, 48.93035398210798, 50.40749931335449, 47.57438176018851, 49.436849866594585, 37.47740200587681, 41.689201968056814, 47.387516907283235, 43.121868406023296, 39.07395212990897, 40.32526363645281, 23.756575380052837, 20.60805651119777, 33.570721762520925, 15.165497813905988, 25.699922255107335, 37.06323378426688, 35.56336089542934, 30.735266140529088, 47.121550287519185, 26.289377893720353, 0.5341081885354859, 0.006781697547661939, 0.13766016678086349, 0.04027479547741158, 0.08705529650407177, 0.06047925113567284, 0.030191412262086357, 0.0630312484822103, 0.018037043478606, 0.0507726516308529, 0.05492235467370067, 0.5544438287615776, 3.3889243687902177, 37.89720869064331, 25.148393358503068, 21.16471838951111, 32.09519188744681, 4.763048325266157, 3.7889130541256497, 0.6676381262285369, 2.5109119968754903, 33.83215468270438, 31.06073365892683, 59.792743819100515, 56.044298376355854, 5.735778323241642, 0.25173434774790493, 0.31487618386745453, 11.302446178027562, 21.35685866219657, 9.986186385154724, 0.843372887798718, 11.836906824793134, 65.73487104688371, 33.1952862739563, 39.018349170684814, 46.80154057911464, 65.9884386062622, 69.65221677507672, 68.82142066955566, 89.33640779767717, 54.58052485329764, 57.843475341796875, 3.814341289656503, 0.35579895653894966, 0.8149695204836982, 1.3292115607431956, 2.6810872767652785, 0.7666684123022216, 0.1276713984885386, 0.1628578089709793, 0.09276369626500777, 0.18662633427551814, 0.17711370757647923, 0.10965194433395352, 0.2797256271753992, 0.21413801158113138, 2.124132271323885, 5.291746309825352, 6.0615949886185785, 1.1628047014985765, 5.976864746638706, 17.745181560516357, 22.502976179122925, 24.831527709960938, 39.49333150046212, 50.05423205239432, 50.64515202386038, 60.05970055716378, 54.87798070907593, 58.94411168779646, 54.33478791373116, 56.885746070316856, 64.00596468789237, 60.8661710194179, 59.18632589067732, 62.422769001552034, 62.464145524161204, 63.939282826014924, 58.71888583047049, 60.611123493739534, 59.09248352050781, 62.55693871634347, 62.97601931435721, 61.344234875270296, 60.912244524274556, 58.84632968902588, 63.956562995910645, 63.58279160090855, 65.51531491960797, 57.7039555140904, 61.545836857386995, 63.311596461704795, 60.80442932673863, 54.9371828351702, 51.54711505344936, 50.322383880615234, 53.67324297768729, 49.84372247968401, 46.03970881870815, 47.23942300251552, 49.924828801836284, 50.201943806239534, 48.029189995356965, 43.013288906642366, 41.63310916083199, 41.89754717690604, 44.28629616328648, 43.45784854888916, 40.56134605407715, 43.99681336539132, 39.22246987479073, 40.64873702185494, 41.46693951742989, 42.41786650248936, 41.14687769753592, 39.14038733073643, 37.43668556213379, 37.52932241984776, 37.35286596843174, 36.93132223401751, 35.19540514264788, 39.49879278455462, 39.98792512076241, 38.89078719275338, 39.24569770268032, 41.000871726444785, 42.86019924708775, 44.09855236325945, 45.57847349984305, 46.30844776970999, 46.005659171513145, 43.964921133858816, 46.09718779155186, 44.9473443031311, 46.284858635493684, 45.63148825509207, 47.348759855542866, 46.23724610464913, 46.173767362322124, 52.40812887464251, 56.9103878566197, 53.95987354006086, 54.49538857596261, 56.48890665599278, 56.235029901777, 50.28658676147461, 49.14578982761928, 54.928803307669504, 53.355599130902974, 55.575937679835725, 53.51511240005493, 52.95112712042672, 55.22961514336722, 52.76440123149327, 54.469576018197195, 53.76145383289882, 51.6530716078622, 48.54285989488874, 50.017597675323486, 39.84947184153965, 44.67453023365566, 52.034197671072825, 45.703127656664165, 38.217367785317556, 43.58883946282523, 34.89503799165998, 37.17248725891113, 49.206127984183176, 30.112940311431885, 45.09210654667446, 53.05758047103882, 59.82608127593994, 51.78169666017805, 59.54783371516636, 25.49186887059893, 0.6532485697950635, 0.15342233170356068, 0.29148119209068163, 0.11746167205274105, 0.3435449669403689, 0.12697333523205348, 0.09313359963042395, 0.21044729676629814, 0.38877396711281365, 0.223688649811915, 0.4955507889389992, 1.0667175203561783, 5.138012204851423, 46.498074531555176, 36.981064387730186, 29.458461693355016, 48.18769577571324, 23.99414471217564, 8.020440254892621, 1.0338093319109507, 9.479505504880633, 60.814879417419434, 41.70908771242414, 74.30533504486084, 63.09833540235247, 4.305641029562269, 0.5335249741162572, 0.6540984756180218], [9.06491778578077, 6.1921108194759915, 1.2246269498552596, 0.6030512547918728, 9.908072999545507, 5.810257800987788, 2.154264437300818, 15.039554766246251, 13.925615225519453, 38.75543281010219, 37.1306208883013, 48.751135621752056, 100.20273726327079, 33.58520875658308, 22.095768315451487, 2.766872993537358, 0.6416283047624997, 0.13468556425401143, 0.46089594279016766, 0.033453947731426785, 0.05265959984223757, 0.017265586481828774, 0.0682189811819366, 0.0215503078153623, 0.1157274315399783, 0.06661777424493007, 0.042368598481906314, 0.10266451284821544, 0.6542308713708604, 3.1062236641134535, 3.3883302978106906, 0.6581647459949765, 0.9677118786743709, 2.2976396467004503, 6.665482469967433, 8.803020204816546, 10.081975987979344, 5.945952645369938, 17.115468059267315, 26.493144239698136, 39.987886905670166, 41.91238852909633, 37.31287561144148, 34.449703625270296, 45.05546522140503, 53.431876455034526, 56.35633850097656, 53.3093831879752, 54.67755644662039, 54.76783091681344, 55.034766810280935, 56.24712324142456, 55.073388372148784, 52.257196630750386, 55.35733692986624, 50.531455176217214, 55.29755810328892, 53.69115195955549, 58.79061903272356, 59.39457729884556, 60.58834729875837, 54.336101123264854, 56.65640687942505, 57.758401598249165, 53.2667281968253, 51.54534673690796, 48.01353570393154, 43.38028580801827, 45.54133537837437, 44.58927583694458, 43.59989404678345, 43.31784234728132, 44.984020369393484, 44.446441718510215, 46.16089929853167, 41.69876963751656, 41.12966353552682, 40.490530014038086, 39.11599915368216, 39.110388483319966, 37.70635904584612, 38.774488244737896, 40.441041469573975, 37.3387576511928, 39.98668139321463, 41.75914600917271, 41.27344955716814, 38.0158109664917, 39.77093287876674, 37.864753655024934, 36.50657190595354, 34.828272751399446, 35.166184493473594, 34.81680474962507, 36.2587366104126, 36.08805758612496, 31.23332691192627, 34.70639787401472, 35.84094490323748, 38.25519377844674, 40.44564812523978, 39.5994165965489, 41.86932359422956, 40.921492031642366, 39.71586840493338, 42.5281274659293, 42.28952285221645, 40.53826066425869, 39.794601917266846, 40.84636810847691, 40.251505034310476, 39.267886774880544, 44.96893235615322, 47.15602377482823, 52.65571403503418, 54.98196744918823, 51.37527915409633, 51.478199345724924, 49.098396165030344, 45.18253040313721, 47.76363679340908, 47.706953389304026, 47.06555822917393, 49.65807703563145, 45.92890589577811, 49.43663794653756, 49.71813031605312, 51.45400224413191, 44.55002546310425, 47.97484118597848, 46.05766643796648, 41.97488757542202, 34.1040689604623, 32.4000232560294, 35.889905384608674, 35.661292280469624, 33.03855575834002, 21.95336151123047, 9.085883975028992, 2.2029022616999487, 24.5819571018219, 18.309177262442454, 21.384507281439646, 25.871032067707606, 21.243500539234706, 17.7780830178942, 6.130627512931824, 0.2615187684340136, 0.13503179353262695, 0.056063525046088865, 0.06681767744677407, 0.05964056149657283, 0.04462517864469971, 0.06022920419595071, 0.09649673809430429, 0.10517442745289632, 0.05222314915486744, 0.03755395486950874, 0.12825529144278594, 0.2602945826947689, 2.599708889211927, 35.307597705296104, 18.422212294169835, 22.5257853780474, 17.026112488337926, 10.38861996786935, 4.403605852808271, 0.2520429997571877, 0.7418459728360176, 6.830469182559422, 28.93492361477443, 42.599329130990164, 60.36271844591413, 14.00540746961321, 0.10349336372954504, 1.2663770467042923, 8.839603338922773, 13.708295549665179, 3.665879564625876, 0.5899529776402882, 20.79919798033578, 30.032858848571777, 12.364321998187474, 18.51506802013942, 19.83463168144226, 52.69088929040091, 50.07406915937151, 58.203232220241, 114.1349732535226, 46.60400676727295, 30.793502467019216, 4.2593881743294855, 0.807369168315615, 0.10343538969755173, 0.43849508623991695, 0.06379183874066387, 0.05111797167254346, 0.05492071261895554, 0.04332968905302031, 0.10813995118119887, 0.06604570137070757, 0.03892800863832235, 0.008071525188695108, 0.07941940267171178, 1.1610064208507538, 3.278677518878664, 3.5577438814299445, 2.0068262687751224, 1.2339170170681817, 3.4701275314603532, 8.604593549455915, 14.723717451095581, 12.124063713209969, 10.58992144039699, 26.837774889809744, 39.198658398219514, 44.64995445523943, 49.10537215641567, 43.54692098072597, 43.308868748801096, 50.43620579583304, 56.22740077972412, 56.352874823978965, 58.49029704502651, 55.27189145769392, 58.898496764046804, 58.326729501996724, 59.31987721579415, 57.111951623644146, 54.75547354561942, 57.89561462402344, 55.3866548538208, 57.07711683000837, 57.73597281319754, 60.41382244655064, 62.97477558680943, 62.78884179251534, 56.88637835638863, 56.977243423461914, 60.519275256565635, 56.42800569534302, 54.75283670425415, 51.076263427734375, 47.43004335675921, 46.24630308151245, 46.0808629989624, 46.335007258823936, 45.663613251277376, 45.64632613318307, 46.7064961705889, 46.78258241925921, 44.69710840497698, 43.96424715859549, 42.77486147199358, 40.99276665278843, 42.26864351545061, 39.500515937805176, 41.79995277949742, 43.076899664742605, 39.37548657826015, 39.83632584980556, 42.2913293838501, 41.26937096459525, 40.712601389203755, 38.78936433792114, 38.37939977645874, 35.97783831187657, 34.47581842967442, 35.04817976270403, 34.03406238555908, 39.44474969591413, 38.431111744471956, 32.997460637773784, 36.406938212258474, 38.72329044342041, 41.63383872168404, 40.385619163513184, 41.48700591496059, 42.50787694113595, 44.96974529538836, 42.607458523341585, 42.9918224470956, 43.68733712605068, 42.998273849487305, 41.17255823952811, 45.24130521501814, 42.64427702767508, 42.330711773463655, 46.195685454777305, 51.247088364192415, 55.235118116651265, 57.720599923815044, 54.131535734449116, 55.12068475995745, 51.19109283174787, 48.86022233963013, 50.296494892665315, 51.637455531529014, 48.08341026306152, 53.022512912750244, 50.42121158327375, 52.23248536246163, 51.94389540808541, 53.84015260423933, 47.81292036601475, 51.74438483374459, 48.01113510131836, 46.849406719207764, 36.94835574286324, 37.089456285749165, 39.210758686065674, 37.985923290252686, 32.83874988555908, 20.16246853555952, 4.692030353205545, 1.1143354794808795, 28.654753140040807, 27.41115239688328, 37.3392197063991, 33.50237928118025, 26.68795783179147, 17.172453710011073, 4.5350436227662225, 0.03383166103490761, 0.1122891181813819, 0.02021409255186362, 0.10475494353366749, 0.03600568723465715, 0.06061826939029353, 0.04311681904696992, 0.03834479421909366, 0.06622505174683672, 0.034672562698168416, 0.10894582008144685, 0.16680301512990678, 0.3115972855261394, 7.0785819717815945, 45.93657670702253, 25.89495471545628, 28.451855318886892, 30.89852796282087, 8.578821812357221, 5.165557903902871, 0.8308562508651188, 1.0439190694264002, 25.640740973608835, 44.83578750065395, 60.03131021772112, 77.23906598772321, 23.244329861232213, 0.041647831443697214, 0.9369555690458843, 12.86895055430276, 12.847273911748614, 2.569075584411621, 0.5867826449019569, 38.72914777483259, 58.560591970171245, 31.856212071010045, 42.13110045024327, 21.105955736977712, 66.14099325452531, 66.19045053209577, 65.81007834843227, 122.65848132542202, 44.07070050920759, 40.99654647282192, 5.604087378297534, 0.9612109703677041, 0.2612670590834958, 1.3540991395711899, 0.1763551054256303, 0.12216465254979474, 0.19919232784637383, 0.24647746554442815, 0.2044560903949397, 0.14259530124919756, 0.07095295483512537, 0.11623270942696504, 0.1744646661515747, 1.7427535759551185, 3.9632364085742404, 9.583576491900853, 6.722953626087733, 3.025840823139463, 7.291870389665876, 16.15820258004325, 22.492729323250906, 18.851939269474574, 21.44061745916094, 47.91124432427542, 48.18546540396554, 55.41257510866438, 56.90833118983677, 56.34710781914847, 53.26601600646973, 58.456223079136436, 59.89468778882708, 63.63329805646624, 60.9837623323713, 58.40556376320975, 60.70846080780029, 60.40576253618513, 59.84366716657366, 60.26636777605329, 56.15348584311349, 61.55760015760149, 59.66873237064907, 59.24499647957938, 58.548001834324424, 61.74222074236189, 64.95233712877545, 66.2633649281093, 60.43422930581229, 60.64138984680176, 63.1159907749721, 58.31153379167829, 56.688344274248394, 54.85751826422555, 50.191115038735525, 49.740437507629395, 49.28744970049177, 48.14847319466727, 47.50948905944824, 48.49388551712036, 49.7282121522086, 49.88303886141096, 45.97473273958479, 44.31860876083374, 45.00955152511597, 42.75015715190342, 44.14757537841797, 41.84292391368321, 41.58200863429478, 42.12089007241385, 38.35643598011562, 39.70339291436331, 43.06916631971087, 42.00451469421387, 40.460437365940635, 38.34599978583199, 38.64327846254621, 35.402965205056326, 34.65780564716884, 34.51227910178048, 35.24233675003052, 39.671135902404785, 38.994965008326936, 34.252329621996196, 38.711193629673545, 41.32688120433262, 42.685125487191335, 44.90790980202811, 44.06529828480312, 45.049611364092144, 45.88682413101196, 44.06844581876482, 46.87772062846592, 46.76255423682076, 47.43452841894967, 44.635450090680806, 47.67396681649344, 45.568301337105886, 46.03465747833252, 49.67484998703003, 54.12174572263445, 57.40061453410557, 60.94423403058733, 55.89956392560686, 56.67725147519793, 51.35074159077236, 52.36797523498535, 51.88358851841518, 52.864806175231934, 50.887685843876426, 54.9358765738351, 50.564195087977815, 54.05011326926095, 52.722628661564414, 56.3527740750994, 49.76924473898751, 53.46242421013968, 49.58964770180838, 48.9602381842477, 37.54601894106184, 38.89788825171334, 40.86737251281738, 38.95801796231951, 42.08283131463187, 35.94434799466814, 13.19776449884687, 8.332764387130737, 40.88116121292114, 33.30025271006993, 47.11013787133353, 43.295319761548726, 37.51093053817749, 21.44632887840271, 5.466702818870544, 0.21237759318734917, 0.41123825311660767, 0.13601531647145748, 0.35656165704131126, 0.18307315850896494, 0.20859330839344434, 0.3004214609307902, 0.2155320889183453, 0.1486704016902617, 0.19240187507654938, 0.3788730555347034, 0.49762640041964395, 0.6914334265249116, 9.819686702319554, 54.98867246082851, 33.54922751017979, 37.82495437349592, 53.39133024215698, 27.219069446836198, 10.962132096290588, 0.8126171752810478, 2.0877897185938696, 51.46568216596331, 55.055125032152446, 66.87244401659284, 91.43349225180489, 22.940382650920323, 0.3382776081562042, 2.67575648852757], [4.128250045435769, 2.369729161262512, 0.4214749852461474, 2.520446445260729, 3.2212843128613065, 3.860972387450082, 2.43833350283759, 7.210906505584717, 13.636469415255956, 26.25569302695138, 34.052252769470215, 29.57747391292027, 39.90535620280674, 22.870172841208323, 27.738070351736887, 4.316336044243403, 0.5215784151639257, 0.16304884372012957, 0.14046039937862329, 0.043215135378496985, 0.1103619294507163, 0.1272784045764378, 0.0822231840076191, 0.0626993498631886, 0.027682259312963912, 0.021827801496588757, 0.013268765860370227, 0.0685349138719695, 0.885816718850817, 5.301752584321158, 3.7705172640936713, 2.785303307431085, 0.33843489257352694, 4.402736025197165, 8.967396344457354, 4.632352275507791, 3.814982695238931, 2.4620442305292403, 1.8121908328362872, 18.727912187576294, 33.40118571690151, 35.8241719518389, 33.54226541519165, 32.43754700251988, 37.092551708221436, 51.47095237459455, 51.02162626811436, 50.79412487574986, 53.260533877781455, 57.973827021462576, 56.70073291233608, 55.55542312349592, 55.273201193128315, 54.82194696153913, 55.09172814232962, 53.453923089163645, 56.28866652079991, 56.16978284290859, 56.11942229952131, 57.20592948368618, 55.82729223796299, 54.06243242536272, 58.457647459847585, 56.448582785470144, 54.99287264687674, 48.56613636016846, 43.66204220908028, 44.35858869552612, 46.31926958901541, 42.32691805703299, 44.91535827091762, 44.71951634543282, 45.869905267442974, 42.202941349574495, 42.72460167748587, 40.900390352521626, 40.508331298828125, 40.63382618767874, 42.39313786370413, 40.81225592749459, 39.083471161978586, 41.00072234017508, 43.69897883278983, 39.74015235900879, 38.79660088675362, 40.21638536453247, 39.125229835510254, 38.05675670078823, 38.238796029772075, 36.389067445482524, 35.56544188090733, 36.58403737204415, 36.057627950395855, 34.60796969277518, 39.23922545569283, 37.32406568527222, 34.44161244801113, 35.50708743504116, 38.48749985013689, 38.258938857487266, 38.44629355839321, 39.376535756247385, 38.05478341238839, 39.953225816999165, 41.51676852362496, 40.84962681361607, 41.63268532071795, 39.55973196029663, 39.151685101645334, 40.91089950289045, 41.3021490914481, 39.227309295109336, 41.516865798405235, 49.20621483666556, 52.195951734270366, 53.21551997320992, 54.12803731645857, 50.6671257019043, 50.99541071483067, 46.890300342014854, 46.52033308574131, 48.95458582469395, 47.34502519880022, 45.10395669937134, 51.042776584625244, 44.946375029427664, 48.110285895211355, 45.86091429846627, 47.68117904663086, 44.279115200042725, 44.05571671894619, 42.212588923318044, 30.772699560437882, 25.58626535960606, 25.155843564442225, 18.975697108677455, 12.38860855783735, 3.2279958384377614, 0.09294389480991022, 0.12475668346243245, 4.274057558604649, 22.887699672154017, 12.843128442764282, 4.631115061896188, 0.9197473781449454, 0.07071122673473187, 0.091191625621702, 0.028561292947935205, 0.12890063252832207, 0.028366309124976397, 0.025967119560976113, 0.020237554596470933, 0.01874885385456894, 0.1168845644486802, 0.07926658301481179, 0.03166115303922977, 0.1842897039438997, 0.04449913737231067, 0.35836981715900557, 0.29044308779495104, 10.200244750295367, 40.579831736428396, 23.30879351070949, 24.396346398762294, 17.495975732803345, 11.449016690254211, 4.174925872257777, 0.15198381032262528, 0.14790552987584046, 8.868180411202566, 33.8062413760594, 42.735753536224365, 69.83330072675432, 35.16723019736153, 0.09408912621438503, 1.5131738036870956, 8.87094839981624, 5.397734565394265, 0.5278370050447327, 3.3820597657135556, 24.133211169924053, 20.107713256563457, 9.54177873475211, 9.056260330336434, 17.249052388327463, 39.367701121738975, 48.80684975215367, 38.813068117414204, 60.68066801343645, 33.72263370241438, 33.65754297801426, 6.3988692334720065, 0.7225901803800038, 0.1684108038565942, 0.13635823449918202, 0.0712741461715528, 0.1928382816591433, 0.08790435415825673, 0.06395820874188628, 0.057246255688369274, 0.0827062398727451, 0.04796963703951665, 0.016342286918578402, 0.056137495541146824, 0.6694042171750749, 6.133574417659214, 6.08900476353509, 3.335609321083341, 0.6431976205536297, 6.535631494862693, 14.834416151046753, 9.368665235383169, 8.371174897466387, 9.517738836152212, 10.2445855481284, 28.216111625943864, 43.01533167702811, 43.684269496372764, 40.06501191002982, 42.26560020446777, 43.87225648335048, 55.42371654510498, 53.325037479400635, 54.55506665366036, 53.98722859791347, 60.57666737692696, 57.408573695591514, 57.18041917255947, 55.85681513377598, 57.64721999849592, 56.099574770246235, 56.98121084485735, 57.40303945541382, 59.476670265197754, 57.655731541769846, 60.699810300554546, 57.27292748859951, 58.867869104657856, 61.27225848606655, 59.69985335213797, 58.27349240439278, 50.66014276232038, 44.91613299506051, 46.6071959904262, 47.39533710479736, 46.24419777733939, 46.33017478670393, 48.26210750852312, 45.46266092572893, 43.93878548485892, 45.06437976019723, 42.775472913469585, 42.91306809016636, 43.7269001688276, 43.29394054412842, 42.53377635138375, 41.00225094386509, 43.644904477255686, 44.42692422866821, 40.57485335213797, 39.76246302468436, 39.82245029721941, 39.165373052869526, 37.297763279506135, 39.28568805967058, 35.376784392765586, 35.225337982177734, 36.59136077335903, 37.523986203329905, 33.15304470062256, 40.437035833086284, 38.82055480139596, 34.70884016581944, 36.707413060324534, 40.862418447222026, 42.26798691068377, 39.62736225128174, 41.95324393681118, 40.411577633449006, 40.86310979298183, 43.0450039591108, 44.110895838056294, 43.38493067877633, 41.49028199059622, 43.52184493201119, 44.400402954646516, 43.788263184683665, 43.346691267830984, 44.177577699933735, 50.53756611687796, 54.2323853628976, 57.24263334274292, 56.10588720866612, 52.367186614445274, 53.31120709010533, 50.66134827477591, 49.05090522766113, 51.6867356300354, 50.75944641658238, 47.563403606414795, 53.18057748249599, 50.09816551208496, 49.426431042807444, 50.7431320462908, 50.98767736979893, 48.68186208180019, 47.91404444830758, 47.14253732136318, 31.66326059613909, 25.565490245819092, 23.634403467178345, 17.377203226089478, 8.071452191897801, 1.4029241310698646, 0.12165995820292405, 0.10297226240592343, 2.4785160209451402, 18.224369287490845, 9.19689621244158, 3.6116243387971605, 0.7759734615683556, 0.16274970477180822, 0.060893374628254344, 0.0704316363802978, 0.1702587396970817, 0.031250174556459696, 0.013804207173442202, 0.021022209099360874, 0.029209283712719167, 0.03622704232111573, 0.07949004495250327, 0.06884684320539236, 0.06125966818737132, 0.04263145616278052, 0.3459476865828037, 0.436505920120648, 17.730791841234478, 49.35548298699515, 30.494066374642507, 32.08945962360927, 27.83378005027771, 11.46743289061955, 6.4385855708803446, 0.7282438427209854, 0.33446928965193884, 17.926576444080897, 46.97126422609602, 52.746478353227886, 77.55386802128383, 47.66691786902291, 0.38225796818733215, 1.3941492076431001, 7.374045865876334, 5.1367780310767035, 0.4682673843843596, 7.4248667274202615, 53.87750611986433, 43.193351473127095, 30.14211927141462, 16.22807366507394, 24.919738565172466, 58.91882719312395, 64.73701245444161, 47.9385472706386, 64.31035831996373, 33.968797956194194, 49.36277512141636, 6.591993544782911, 0.742444386439664, 0.4772246980241367, 0.1745081331048693, 0.19797043555549212, 0.1663440947553941, 0.17339735770864145, 0.19780278312308447, 0.1232019697449037, 0.12730944076819078, 0.16974569936948164, 0.18770931687738213, 0.1083220699802041, 1.1380826852151325, 7.281664788722992, 7.929516996656146, 3.7234232425689697, 0.4832457463656153, 9.438566718782697, 21.32634391103472, 12.178702609879629, 12.656934091023036, 19.086310693195887, 20.0210987499782, 41.07576635905674, 53.33732189450945, 51.52419294629778, 52.484281131199424, 55.46513475690569, 52.31416143689837, 62.000367164611816, 58.529825346810476, 56.33978789193289, 56.95039905820574, 63.575996262686594, 61.873263767787385, 60.08133724757603, 58.16750110898699, 59.76020540509905, 58.362908772059846, 60.269299915858674, 59.674311774117605, 62.02155222211565, 59.89907210213797, 63.32915455954415, 60.36764471871512, 61.5345321382795, 63.848052978515625, 61.85225936344692, 59.10435104370117, 54.10282230377197, 47.45189544132778, 48.996695382254465, 49.56260183879307, 46.96094615118844, 48.73794099262783, 49.484288692474365, 48.024687562670024, 45.58493879863194, 48.00052867616926, 46.29005936213902, 44.78114686693464, 45.85502570016043, 44.83915737697056, 45.66210549218314, 42.53893886293684, 43.66919885362898, 46.14659295763288, 41.07046488353184, 39.59269421441214, 41.363404410226, 40.79799474988665, 38.07527365003313, 38.719819818224224, 35.88952670778547, 34.97905560902187, 36.546850613185335, 37.78513077327183, 34.67010048457554, 40.808052267347065, 41.565781116485596, 37.88264526639666, 39.7880289213998, 43.3825717653547, 43.74039704459054, 42.043650422777446, 44.52955954415457, 43.124321120125906, 46.03318446023123, 46.0051589012146, 47.562896387917654, 47.67694411958967, 45.40848582131522, 44.76975876944405, 46.76822396687099, 44.84033162253243, 45.13089486530849, 47.47352170944214, 53.84685066768101, 57.521297795431956, 60.28528772081648, 57.930616174425396, 53.82777786254883, 54.56385612487793, 51.2201258795602, 52.57607725688389, 53.07313748768398, 51.97358506066458, 49.291295528411865, 54.83687516621181, 50.37847668784005, 52.85087851115635, 51.34282411847796, 53.28743382862636, 52.51044109889439, 50.58305944715227, 50.875012329646516, 35.63173116956438, 32.4084027835301, 37.49717657906668, 34.84025839396885, 20.200304950986588, 5.022151861871992, 0.27265909207718714, 0.2802713050373963, 5.145693438393729, 24.94766684940883, 15.383073704583303, 6.153905715261187, 1.2290133259126117, 0.25233786393489155, 0.1776997854134866, 0.10061706057084457, 0.3009237125515938, 0.15305562423808233, 0.173360228272421, 0.20788073805826052, 0.17711323260196618, 0.278448081442288, 0.26688793461237637, 0.1978904227060931, 0.24780717704977306, 0.12525691304888042, 0.7933871128729412, 0.6437095616544996, 22.269570555005753, 59.30799579620361, 39.62463508333479, 45.105916091373985, 47.73375953946795, 28.39659629549299, 10.966977596282959, 0.7942084116595132, 0.4856572598218918, 36.4408141544887, 65.21552794320243, 60.66184534345354, 89.85164451599121, 51.389463901519775, 0.3572140006082398, 2.487493310655866], [2.960003818784441, 0.4631897711328098, 0.2926537006029061, 3.489153653383255, 6.682427389281137, 2.3525996804237366, 3.5541927005563463, 1.5805942373616355, 12.92042715208871, 24.323251349585398, 28.540613344737462, 22.176794733319962, 28.80028142247881, 31.159738540649414, 32.63541432789394, 7.642799581800189, 0.5692496257168906, 0.08677002002618142, 0.07948779221624136, 0.04960876390604036, 0.025064791818814616, 0.01485752676879721, 0.027585310229499425, 0.06524631247988769, 0.02174959015766425, 0.07560799004776136, 0.03765977579834206, 0.0045573028453093556, 0.8026734345725605, 6.819481475012643, 7.13435081924711, 6.114755656038012, 3.502043213163103, 5.06727910893304, 6.634404046194894, 0.8704483892236436, 0.4160642113004412, 0.533222564629146, 1.1599198962960924, 6.801234636987958, 24.343260424477712, 31.418753487723215, 26.71366616657802, 29.05466365814209, 30.277779374803814, 39.87711524963379, 48.69379908697945, 49.27491167613438, 49.81559269768851, 54.51892907278878, 54.891064167022705, 55.011862073625835, 57.68238483156477, 53.56874207087925, 53.411143030439106, 53.77609716142927, 55.038755076272146, 54.01338856560843, 59.07710715702602, 53.29291248321533, 51.081724711826865, 55.897653170994346, 58.5854526247297, 59.331911495753694, 54.94102866309029, 43.16538497379848, 44.012888022831504, 45.7280056817191, 47.29517534800938, 42.365914821624756, 43.18691396713257, 43.40656042098999, 43.95969608851841, 42.22308070319039, 42.62375552313668, 41.590620926448274, 43.175258363996235, 44.29654475620815, 42.58637421471732, 39.53591006142752, 40.98165648324149, 45.50516653060913, 46.26797103881836, 36.99698965890067, 38.619286332811626, 37.203521387917654, 37.283116476876394, 37.6445756639753, 35.84580864225115, 34.13812902995518, 36.076012883867534, 33.841621603284565, 35.946380342756, 34.8879508290972, 38.8297507422311, 38.74667113167899, 37.381596769605366, 35.25175155912127, 40.92357996531895, 41.13307510103498, 37.81801659720284, 36.07113872255598, 38.75263268607003, 39.54146862030029, 40.4991249356951, 41.53666469029018, 40.50345366341727, 38.109886101314, 41.11612149647304, 41.626612595149446, 42.82614612579346, 41.05348348617554, 39.736643518720356, 44.061209269932334, 51.931586674281526, 49.03118971415928, 51.156456061771934, 49.45016956329346, 53.3393611907959, 51.04474639892578, 46.160854135240825, 46.8134115764073, 49.48056445802961, 45.600954396384104, 49.531296730041504, 46.260248116084504, 44.57789121355329, 46.70185477393014, 42.16094643729073, 41.04621567044939, 37.05842563084194, 30.799922602517263, 17.188721179962158, 6.89042431967599, 3.854230897767203, 5.159730102334704, 0.5186159312725067, 0.21865162652518066, 0.020991469766678553, 0.04048254932942135, 0.04170875371034656, 0.739963173866272, 0.7702899436865533, 0.15998601807015284, 0.03352072575528707, 0.08261591329106263, 0.059492593365056176, 0.048959952113883834, 0.015139449587357896, 0.08465983718633652, 0.04442968592047691, 0.006009645560490233, 0.04132986654128347, 0.05844125085111175, 0.06654829225902047, 0.0622174542929445, 0.009482759283855557, 0.053134197768356116, 0.10860625401671443, 0.32297186659915106, 15.25512957572937, 39.94895962306431, 25.476692267826625, 21.70365193911961, 13.679563011441912, 7.787033762250628, 2.2086440793105533, 0.36804561795932905, 0.3161958801959242, 2.7074111785207475, 37.84890133993966, 35.40050554275513, 66.91053404126848, 48.05963352748326, 1.2427290699311664, 1.5662196086985725, 5.975606688431331, 1.1644031128713062, 0.6427429478083337, 7.74630776473454, 25.077676330293926, 21.542703866958618, 3.79358571767807, 2.8958476270948137, 16.630112068993704, 32.70862749644688, 45.46888998576573, 29.956081254141672, 34.1838447025844, 28.413346665246145, 40.971314089638845, 11.206312639372689, 0.526866645685264, 0.051445931395781894, 0.03926609888938921, 0.03164353148479547, 0.04839004037369575, 0.005591482240041452, 0.046471733666424236, 0.01591186162217387, 0.014198266385522271, 0.04314925641353641, 0.052299762543823035, 0.004486485841750566, 1.1604329773357935, 8.490113292421613, 10.178888593401227, 5.809192555291312, 1.8904782491070884, 5.5850788440023145, 9.429440259933472, 3.1243334923471724, 3.0498357755797247, 2.215073334319251, 3.952932664326259, 13.047210931777954, 27.015405586787633, 42.572106088910786, 33.87232916695731, 38.88205330712454, 38.46943800789969, 45.669849259512766, 50.9160657610212, 52.87185859680176, 52.928750446864534, 57.30757468087332, 57.09724923542568, 54.44796017238072, 58.97790772574288, 58.57104206085205, 54.3879520552499, 56.924461432865684, 57.958613940647666, 58.03473493031093, 57.847995144980295, 56.51493460791451, 56.08583470753261, 60.12222044808524, 60.37569768088204, 60.20380619594029, 55.00842618942261, 45.88659136635916, 45.521102224077495, 50.393095697675435, 47.28689309528896, 45.579269068581716, 46.09250817980085, 45.22901037761143, 44.95715863364083, 46.631014415196006, 44.988977909088135, 45.08779518944876, 45.18687302725655, 48.25824431010655, 45.34875563212803, 41.27635737827846, 42.48658071245466, 49.67703172138759, 48.5918481690543, 39.7657356262207, 39.23449720655169, 37.732928957257954, 37.24911199297224, 37.40638446807861, 35.95960276467459, 35.073137692042756, 35.26417146410261, 35.1900828225272, 36.61560651234218, 34.65200390134539, 39.84638336726597, 41.61046150752476, 39.402268409729004, 37.4100079536438, 41.84611313683646, 43.15799903869629, 40.999037402016775, 38.91608905792236, 41.34467554092407, 41.351168632507324, 43.06055055345808, 42.750563621520996, 41.133950574057444, 40.72187376022339, 43.251910890851704, 43.66688857759748, 44.614918163844514, 45.30102845600673, 42.568100452423096, 45.48460681097848, 53.26276772362845, 53.00979770932879, 52.59407309123448, 50.17803852898734, 53.81311021532331, 52.78929662704468, 49.153860160282676, 49.90033292770386, 50.94892726625715, 48.9872145652771, 50.04716920852661, 48.846131392887656, 47.312243597848074, 49.754139355250764, 44.33737237112862, 45.880650656563894, 37.406943798065186, 30.0455219405038, 16.034684453691753, 5.503970350537982, 1.9441252904278892, 1.485035879271371, 0.4254918582737446, 0.03737884533724614, 0.05988984847707408, 0.02295387107213693, 0.09514735585876874, 0.4039279339568955, 0.6761389757905687, 0.08894696392651115, 0.05511217823784266, 0.1266808459269149, 0.08019289866622005, 0.04606318773169603, 0.034632298430161815, 0.09580319388104336, 0.07994599334363427, 0.03380290811349239, 0.061681750895721574, 0.06977446842938662, 0.10871831407504422, 0.05986379951770816, 0.08416783144431454, 0.15439816005527973, 0.13344578578003816, 0.33221867041928427, 26.304689986365183, 47.82965162822178, 32.86595903124128, 30.63568455832345, 25.093427896499634, 6.503903848784311, 3.384788019316537, 0.5265536510518619, 0.39976824287857327, 6.578423278672354, 49.06301941190447, 46.886082785470144, 75.22663838522774, 59.87139742715018, 1.4492880489145006, 1.337384705032621, 4.63446409361703, 1.6604525979076112, 0.7726307809352875, 18.887050254004343, 57.100914410182405, 40.148696013859336, 27.874663250786917, 4.674339371068137, 23.07462532179696, 52.17843532562256, 59.95353208269392, 40.62209415435791, 45.947683402470176, 46.00393949236189, 52.907752990722656, 12.622143592153277, 0.8266021077122007, 0.13777740406138556, 0.13968697802296706, 0.13276383094489574, 0.10996525787881442, 0.10190933729921069, 0.1569685728422233, 0.24181289012942994, 0.1354500560888222, 0.14056361812566007, 0.09623125448290791, 0.12843375972339086, 1.1473565761532103, 8.962655067443848, 12.900788937296186, 11.59082681792123, 7.1335552505084445, 10.39403782572065, 10.354203803198677, 2.8005817447389876, 4.45686422927039, 4.280067316123417, 8.515965802328926, 19.444499015808105, 37.77364540100098, 51.95165654591152, 43.89039822987148, 51.665258748190745, 48.368098803928916, 51.57998350688389, 57.04415804999215, 56.646165234701975, 55.319917406354634, 60.95867238725935, 58.51285089765276, 57.29062107631138, 60.53813961574009, 59.50137111118862, 56.95821578162057, 58.1206111907959, 58.52225181034633, 59.04112243652344, 62.024685859680176, 58.513601303100586, 58.97439193725586, 61.56493745531355, 62.36213207244873, 65.00777680533272, 58.32030936649868, 47.30008772441319, 46.84801707948957, 52.433656556265696, 50.63139806474958, 48.62931980405535, 48.475323404584614, 46.63455104827881, 48.05371366228376, 48.86672237941197, 46.694951738630024, 47.69561045510428, 47.90677663258144, 50.42144087382725, 47.262939180646626, 44.19611201967512, 45.814733096531455, 50.50419391904558, 49.06733076913016, 39.00013794217791, 39.27006850923811, 39.60211597170149, 38.50804219927107, 39.64292969022478, 36.18541921888079, 34.19241183144705, 35.547345297677175, 35.077546324048726, 35.97552456174578, 35.028467723301475, 40.362999303000315, 42.21513196400234, 41.11426632744925, 40.15538712910244, 45.198365347726, 45.05580915723528, 42.02661343983242, 39.70409120832171, 43.890617098127095, 44.812733377729145, 44.937099184308735, 44.4366169657026, 44.25541489464896, 43.246036188943044, 45.67791264397757, 47.31604773657662, 48.73110396521432, 48.07294627598354, 43.41968904222761, 49.17276620864868, 56.91678367342268, 53.91682250159127, 55.554259300231934, 52.27574137278965, 56.96086999348232, 56.694271087646484, 51.29773030962263, 53.43565974916731, 52.40767724173409, 50.51260471343994, 54.76764331545149, 49.646212986537385, 50.86900213786534, 53.592689037323, 48.6807746887207, 51.244190965379985, 46.43631199428013, 40.997185707092285, 29.82645913532802, 27.145395960126603, 12.60613407407488, 7.2130065986088345, 0.988899433187076, 0.34770921777401653, 0.1717328570250954, 0.09921478653060538, 0.14264526856797083, 1.1942846008709498, 1.0618011270250594, 0.16245705261826515, 0.14387571040008748, 0.2756364494562149, 0.16812096083802835, 0.3886089473962784, 0.10907516242670161, 0.200588888621756, 0.132630960217544, 0.11700874992779323, 0.13785734905728272, 0.21908819595617907, 0.1587869788386992, 0.19412588328123093, 0.1536801207278456, 0.20583484641143254, 0.2428272185581071, 0.5185784761394773, 33.99971396582467, 55.5824933052063, 40.21490887233189, 44.46653243473598, 39.50496973310198, 21.987049852098735, 5.007524601050785, 0.7225965314677784, 0.6563027373382023, 13.584681017058235, 77.90113898686, 56.109211921691895, 87.40257126944405, 70.68801253182548, 1.6403127014636993, 2.388395062514714], [1.4848045259714127, 0.2769296286361558, 0.27801273337432314, 2.9763483703136444, 8.275055255208697, 1.097841541681971, 4.377722076007298, 0.27636020204850603, 4.865275434085301, 15.398005383355276, 23.739819799150737, 25.84060069492885, 52.74729129246303, 54.905144691467285, 32.61761999130249, 14.392848576818194, 0.33410510633672985, 0.06880727104310479, 0.06114958945129599, 0.08456393983215094, 0.04892832220398954, 0.023828769036169564, 0.10902845207601786, 0.012935889302752912, 0.04020934059683766, 0.015985738818666766, 0.046975474671593735, 0.08282389784497873, 0.5445030193243707, 6.801369258335658, 9.06951401914869, 9.367082783154078, 9.472255059650966, 12.369131888662066, 6.279334596225193, 2.515798100403377, 1.4770978880780083, 0.20551307153488907, 0.3638870668198381, 0.6936499561582292, 3.0084633784634724, 21.520785774503434, 21.692734582083567, 24.393785987581524, 25.82014867237636, 34.0973813193185, 40.95979397637503, 45.86239079066685, 50.37598575864519, 56.00365488869803, 51.3427859033857, 50.616591453552246, 53.21561029979161, 56.126790864127024, 52.1274459702628, 55.12312705176217, 54.208018030439106, 56.517863273620605, 54.52032913480486, 50.8198366846357, 53.92336770466396, 58.257021699632915, 55.94598831449236, 54.25571393966675, 48.789996896471294, 42.63879837308611, 45.131266593933105, 49.61880234309605, 44.65181657246181, 41.42954083851406, 42.3452856200082, 44.92437355858939, 43.68353646142142, 42.023076806749614, 43.90032025745937, 41.69145318440029, 43.4744929586138, 46.09784092221941, 45.594350133623394, 40.64518996647426, 39.3325640814645, 46.751683780125205, 49.82671676363264, 37.78899049758911, 35.86179992130825, 38.02463517870222, 38.372156279427664, 37.849405084337505, 35.431966985974995, 36.04372807911464, 34.990026814596995, 35.81961740766253, 34.993250778743196, 35.24363258906773, 44.960816860198975, 42.753099714006694, 38.1991218158177, 40.67645686013358, 38.62771797180176, 40.60419906888689, 40.59200498035976, 37.493139675685335, 36.17377751214163, 40.70543779645647, 40.04156868798392, 38.24671350206648, 38.603586878095356, 38.0303361756461, 41.89029325757708, 43.52114316395351, 39.925776958465576, 45.41803959437779, 41.763651915958945, 41.39491449083601, 48.134826932634624, 48.8923716545105, 51.111094747270855, 47.08391189575195, 48.71608543395996, 51.29435348510742, 46.95165293557303, 45.94307674680437, 46.96771369661604, 44.94621869495937, 45.59743513379778, 41.93126678466797, 41.92079584939139, 40.20069285801479, 32.71409225463867, 28.769104855401174, 22.856309447969707, 11.619039109774999, 1.003469045673098, 0.7139732741883823, 0.2958538074578558, 0.2929208262690476, 0.13739659663821968, 0.022878833580762148, 0.014221433267396475, 0.014005596366977053, 0.03075275749766401, 0.013311124257078128, 0.12619072651224478, 0.10204720882964985, 0.045569651893207004, 0.10014976707420178, 0.026706059463322163, 0.013905990818914558, 0.02390655629070742, 0.03645100637472101, 0.04791720663862569, 0.054416170942464044, 0.10351084957697562, 0.04511025654418128, 0.1215027959219047, 0.07730324193835258, 0.021223245454686027, 0.013568741103102053, 0.09244079502033335, 0.5480917096138, 24.00386871610369, 39.10225561686924, 28.759789058140345, 22.623351982661656, 13.767756496156965, 7.797425661768232, 0.9134606697729656, 0.10087021520095212, 0.04847942039902721, 0.4638849166887147, 22.96814070429121, 42.95364556993757, 51.86872979572841, 58.10894863946097, 1.2623470915215356, 0.6091196377362523, 3.3647876296724593, 0.3587299021227019, 0.49333371647766655, 19.997973408017838, 29.651687622070312, 9.567616479737417, 1.3248373440333774, 0.2355975636414119, 9.899248787334987, 24.024914809635707, 43.15082154955183, 32.482126644679475, 51.85883903503418, 46.074974400656565, 37.472757135118755, 24.098178352628434, 0.16622379049658775, 0.037536201000745804, 0.03743226300658924, 0.040137042690600665, 0.014325516298413277, 0.03693742098818932, 0.08343199414334126, 0.05039925041741558, 0.010349095832290394, 0.015449116006493568, 0.10327885166874953, 0.07810575209025826, 0.8979666211775371, 8.195075409752981, 10.377702610833303, 12.339410969189235, 8.319364786148071, 14.005821755954198, 7.603309495108468, 2.4331992183412825, 2.6493841665131703, 0.32476914301514626, 0.834051499409335, 4.760069285120283, 7.964343973568507, 21.469013009752544, 31.607376234872, 32.34040771211897, 34.041424001966206, 39.245110579899375, 45.599505696977886, 51.32063157217843, 51.04575041362217, 58.07123381750924, 53.518381527491975, 51.97842100688389, 55.74032163619995, 58.69483811514718, 55.29132556915283, 56.28784315926688, 55.12139000211443, 58.79418345860073, 56.17313534872872, 55.2959634917123, 57.660883631025044, 61.8748688016619, 58.403847558157786, 59.28406620025635, 50.400262764522004, 48.17278494153704, 47.673765318734304, 51.43698957988194, 47.66689702442714, 45.880813939230784, 45.53282730919974, 46.29653855732509, 45.1873003414699, 44.269252232142854, 44.78637538637434, 43.8832311630249, 44.9819324357169, 49.017376695360454, 48.22808912822178, 44.14311463492257, 42.23409707205636, 47.606784684317454, 51.5553035054888, 40.9970189503261, 37.528360094342915, 37.773454325539724, 37.46740007400513, 38.02747351782662, 35.5799948828561, 37.161022731236045, 36.10514668055943, 35.15075601850237, 34.447268281664165, 36.67972796303885, 46.66275378635952, 43.96179444449288, 41.324098450796946, 40.79471867425101, 39.98141118458339, 42.06521763120379, 42.93217216219221, 40.29701920918056, 39.53991917201451, 42.08197668620518, 41.951096943446565, 40.132326057979036, 40.34814405441284, 41.83162266867501, 42.87718064444405, 46.51760939189366, 44.52276420593262, 47.28984260559082, 45.10507535934448, 45.44761112758091, 49.39360427856445, 50.42083985464913, 54.38275827680315, 49.705588817596436, 48.76918704169137, 53.14772292545864, 50.639409337724956, 49.08961016791207, 49.32729761941092, 49.76690667016165, 48.035665716443745, 46.59324400765555, 43.62562322616577, 44.87767471585955, 35.950087206704275, 28.38393667766026, 21.804406029837473, 10.02863814149584, 1.6430692906890596, 0.3367047097001757, 0.21594718950135366, 0.11369382137698786, 0.015017562645620533, 0.03297074937394687, 0.03408457139240844, 0.0494463395859514, 0.11340800207108259, 0.0530556912666985, 0.07989243657461234, 0.06318462453782558, 0.05044927201899035, 0.09562673406409365, 0.029098468766148602, 0.0419656233196812, 0.054466005946908674, 0.013476249146541315, 0.07400562960122313, 0.030149237918002263, 0.05368600619424667, 0.032041712797113826, 0.004528630499927593, 0.055313424939023595, 0.0319945342572672, 0.004866658834673996, 0.10994716134986707, 1.0290278856243407, 34.705637046269004, 44.85885899407523, 37.18914556503296, 31.032444068363734, 31.975259031568253, 4.825052746704646, 1.326162930045809, 0.09536878897675446, 0.06834656612149306, 0.3626419279192175, 40.326177324567524, 57.63612025124686, 61.078438486371724, 70.38300051007951, 1.8488939319338118, 1.1410394694123949, 2.988900291068213, 0.5530332358820098, 0.9341215725455965, 36.959799425942556, 60.51514802660261, 23.574800082615443, 25.795675379889353, 0.2726303221923964, 13.312000700405665, 49.237724917275564, 52.80314091273716, 46.50849335534232, 71.02741118839809, 67.5346212387085, 46.51278734207153, 29.818347113473074, 0.583705081471375, 0.27387128131730215, 0.1856682835412877, 0.2521270295338971, 0.1359783634543419, 0.16528710004474434, 0.3302727948342051, 0.26221613958477974, 0.05730431792991502, 0.11290544510952064, 0.2091555425098964, 0.15154554455408029, 1.3655579132693154, 11.601235219410487, 13.051174879074097, 19.92941553252084, 16.420790638242448, 18.237555231366837, 10.53887128829956, 3.8430052144186835, 2.965021069560732, 0.32983028143644333, 2.431778528860637, 8.093280826296125, 14.503183364868164, 36.66140556335449, 41.708333832877024, 47.204720224652974, 44.27348368508475, 48.85307959147862, 53.28971283776419, 57.98389148712158, 55.38959741592407, 62.89558696746826, 56.465383529663086, 55.66383934020996, 58.211865356990266, 62.01612567901611, 57.26142127173287, 59.57828766959054, 57.59138080051967, 59.64663015093122, 59.28214849744524, 57.40061453410557, 59.10905497414725, 65.38070746830532, 61.87109592982701, 60.38869776044573, 53.36219644546509, 49.94006620134626, 49.21780443191528, 55.334126472473145, 49.03845752988543, 47.420284611838206, 47.288859435490195, 50.78168065207345, 46.77726009913853, 47.09424039295742, 47.908176694597515, 46.863984039851594, 48.34740012032645, 51.72333179201399, 49.41563701629639, 46.06683458600725, 42.8378712109157, 50.51869828360421, 52.58980342320034, 39.347971711839946, 36.58440910066877, 39.31914016178676, 38.44549451555525, 38.69033861160278, 35.96965333393642, 36.07248667308262, 36.38045515332903, 35.960617201668875, 36.47189692088536, 37.15491526467459, 47.5937568119594, 47.36334759848458, 44.1837511743818, 43.53887496675764, 40.65729372841971, 44.63474832262312, 45.242357867104666, 43.0052741595677, 40.035297938755576, 45.80408845629011, 44.91461133956909, 42.508217402866904, 42.74609245572771, 43.7894652230399, 47.01882464545113, 49.36960172653198, 47.42846958977835, 49.72808708463396, 45.67870126451765, 47.485361439841135, 51.948446478162495, 53.38412148611886, 56.62386499132429, 49.76105976104736, 51.38895320892334, 56.20384986060006, 52.79038054602486, 52.21790109361921, 52.60216426849365, 51.32517569405692, 50.35065957478115, 47.93011563164847, 46.20858131136213, 49.30287817546299, 42.845951965876985, 41.12617553983416, 38.928508962903706, 27.44613310268947, 12.755177276475088, 1.9294958582946231, 0.7056475409439632, 0.532327441232545, 0.2067797878491027, 0.08412792001451765, 0.12518174493951456, 0.11926531312721116, 0.25117857328483034, 0.10339297447353601, 0.18054919822939805, 0.11176387100879635, 0.24894453744803155, 0.24761374028665678, 0.15050739954624856, 0.1038585105644805, 0.13226798469466822, 0.06880789529532194, 0.13728039073092596, 0.24975804665258952, 0.20289349210049423, 0.09295895828732423, 0.21443155940089906, 0.1814799311437777, 0.09154964783894164, 0.09893984414104905, 0.2474683438028608, 1.1308538445404597, 45.038216318402974, 53.8795280456543, 47.91695574351719, 40.531183923993794, 45.33186803545271, 19.71487774167742, 2.412955207484109, 0.14354022911616734, 0.20140128502888338, 1.7056179514953067, 64.3886158806937, 68.03677449907575, 68.84569767543248, 82.68756539481026, 2.259542239563806, 1.011423213141305], [0.4166962802410126, 0.07000379290963922, 0.31180548721126145, 7.271282008716038, 7.344126922743661, 0.14676109914268765, 3.056254825421742, 0.25292124120252474, 3.427143152270998, 4.542853397982461, 19.91043652806963, 31.241814136505127, 65.0469160079956, 52.50963510785784, 30.290001256125315, 22.0160915851593, 0.806747413107327, 0.028318114478939345, 0.07158518662410122, 0.053121512556182485, 0.011274981462130589, 0.028449943655037453, 0.021646600416196243, 0.10491203796118498, 0.01505660724693111, 0.05204364950103419, 0.03172515246218868, 0.11766669819397585, 0.7956010912145887, 8.548058663095746, 4.269493894917624, 11.945716483252388, 13.771841168403625, 13.33042471749442, 5.197022821222033, 9.971653359276907, 0.5618995172636849, 0.26875222314681324, 0.25883774086833, 0.9574556861604963, 2.3106438517570496, 2.4861872664519717, 9.924458588872637, 13.472863657133919, 20.151142971856252, 22.324669769832067, 32.67895174026489, 37.82716737474714, 38.59821939468384, 46.53051567077637, 47.689603737422395, 48.05947371891567, 55.46420022419521, 53.08431019101824, 55.66463490894863, 52.37411049434117, 51.510244437626426, 56.24517774581909, 51.88850089481899, 53.42364978790283, 57.27898631777082, 57.13649960926601, 57.193328925541465, 56.80579662322998, 45.25081035069057, 45.80177470615932, 50.13772855486189, 47.737633160182405, 45.3292555127825, 41.81721557889666, 42.88048798697335, 41.57326085226876, 42.75372505187988, 41.490490436553955, 42.371376105717246, 41.288759912763325, 44.5470620564052, 44.663454805101665, 46.4760730607169, 44.98618473325457, 44.11816017968314, 46.964111055646626, 44.99075664792742, 44.58392572402954, 40.55753149305071, 40.64145530973162, 37.849481514522004, 35.16489907673427, 36.00459235055106, 36.7464028767177, 36.44213431222098, 36.81973416464669, 36.85179662704468, 41.58761235645839, 45.06246205738613, 40.87434850420271, 40.242951801845, 42.98686490740095, 40.462966510227744, 40.00263793127877, 39.457252979278564, 38.92880426134382, 38.940657888139995, 37.79685238429478, 39.19101537976946, 35.98935147694179, 37.723562785557334, 37.97194698878697, 39.229418073381694, 40.72588981900896, 43.44841636930193, 43.6807085445949, 48.00145278658186, 41.52638830457415, 48.040327957698274, 46.66916002546038, 49.989881311144146, 50.79233224051339, 45.511815956660676, 48.22920778819493, 47.8360960824149, 45.09357609067644, 47.0741913659232, 46.12092283793858, 41.86525542395455, 38.89114849908011, 37.001422609601704, 33.16073635646275, 21.069145917892456, 11.244494727679662, 5.905719101428986, 0.4413220259760107, 0.06423083054167883, 0.06594240119946854, 0.06953492521175317, 0.08509635233453341, 0.012055848043278923, 0.040920424940330644, 0.079988191436444, 0.06642101944557258, 0.05801755322941712, 0.04453483509964176, 0.09112594343189682, 0.061974864453077316, 0.05724979085581643, 0.059532789779560905, 0.04756129127261894, 0.11845409737101623, 0.07653051268841539, 0.0687244829854795, 0.021394706164885844, 0.03686492630679693, 0.06498653534799814, 0.02021315786987543, 0.047676031544272385, 0.06349916623107024, 0.07062630807714802, 0.02866200790075319, 0.08215518122805016, 1.0186493396759033, 25.467399052211217, 38.83636542728969, 26.23275007520403, 20.62093152318682, 30.940644468579972, 15.23835836138044, 0.305045378527471, 0.08436036575585604, 0.5604235136083194, 1.0298141177211488, 31.967932156154088, 39.01961374282837, 58.09414897646223, 53.8443215233939, 0.9461167688880647, 0.25314477777906824, 0.992593377828598, 0.047641351619469266, 0.7142081558704376, 27.05067811693464, 26.09402060508728, 9.786484735352651, 2.3221020826271603, 0.15288588191781724, 2.622440789427076, 25.172519241060527, 34.41878414154053, 36.6052884374346, 81.33500126429966, 61.839023045131135, 35.04198544366019, 32.58303533281599, 0.89177170502288, 0.032358826138079166, 0.1044169245287776, 0.007790015428327024, 0.031035598034837415, 0.014413895484592234, 0.05597170568736536, 0.11606952175498009, 0.042168596892484596, 0.05708186700940132, 0.032951445052666326, 0.01723798706994525, 0.9652041218110493, 9.50484297956739, 7.925845742225647, 14.251246895108904, 16.822448628289358, 16.428626469203405, 5.681035203593118, 7.869481955255781, 0.5764026333178792, 1.033306998865945, 0.8075332109417234, 1.7098893565790994, 3.3238592658724104, 5.62664600781032, 12.481882912772042, 22.76663773400443, 25.64127251080104, 27.040483372552053, 35.38073444366455, 41.43334150314331, 43.45625046321324, 50.74147490092686, 51.25177492414202, 50.45930508204869, 57.77659893035889, 55.52556324005127, 57.36335481916155, 53.197301796504426, 53.15919440133231, 57.88367414474487, 52.2901554107666, 56.37516464505877, 58.04731464385986, 59.27481814793178, 58.28778484889439, 57.21964522770473, 47.13743039539882, 48.872635296412874, 50.95758124760219, 49.43698188236782, 47.71003491537911, 46.26502847671509, 44.5236987386431, 43.457990986960276, 44.431992939540315, 44.31434951509748, 44.196407318115234, 44.74094806398664, 47.605627809252056, 47.44162252971104, 48.8074403490339, 47.44320324489048, 45.26419258117676, 48.73590169634138, 48.18447528566633, 45.52757447106497, 42.909100668770925, 40.563906465257915, 38.674423762730186, 36.62641790934971, 35.25066416604178, 36.32162128176008, 37.94829879488264, 37.86040408270699, 37.2712003162929, 43.62489366531372, 45.89204222815377, 44.362253870282856, 42.700258663722444, 43.76077263695853, 41.854096617017476, 40.646836689540315, 40.407203742435996, 40.428743158067974, 41.037044048309326, 38.67738022123064, 41.03471292768206, 39.601452418736045, 39.21728304454258, 40.98106241226196, 41.50854533059256, 42.47610282897949, 46.670890126909526, 45.09396866389683, 50.609052658081055, 44.779520988464355, 47.32694946016584, 49.00125340053013, 52.98720564161028, 53.11651161738804, 47.8861265863691, 50.91604839052473, 52.91630622318813, 47.83467517580305, 48.63822044645037, 49.01683126177107, 46.24822425842285, 42.83813871656145, 41.40064328057425, 37.073676926749094, 21.815425872802734, 9.462234888757978, 6.4519330603735785, 1.769201785326004, 0.04896950249427131, 0.02338287653401494, 0.06268142296799592, 0.05131560517475009, 0.06157177393989904, 0.023572264139407446, 0.04591592188392367, 0.011868704692460597, 0.09638012506599937, 0.16798194258340768, 0.06858355126210622, 0.11382709922535078, 0.03125184714528067, 0.10398918283837182, 0.04631417104974389, 0.14390317749764236, 0.06923430705709116, 0.05987874764416899, 0.036294427633817704, 0.07082476599940232, 0.07218183603669916, 0.035793051323188205, 0.02422484180091747, 0.06665473404739584, 0.05339467039863978, 0.17188590738390172, 0.0857540156160082, 1.8775669762066431, 38.951636041913716, 48.6494139943804, 35.18120302472796, 24.964217458452495, 47.578665324619834, 41.35432311466762, 0.23538151809147426, 0.0553388767875731, 0.8749066357101712, 9.700823000499181, 54.260428292410715, 45.37655190059117, 70.16348607199532, 58.590177399771555, 0.6222797429987362, 0.5531726883990424, 0.6181085982492992, 0.21100852665092262, 1.3429116713149207, 48.99485410962786, 47.42744820458548, 27.680681705474854, 22.818959406444005, 0.399324182420969, 6.663294221673693, 57.94221271787371, 43.24214172363281, 53.923669951302664, 80.76219177246094, 65.80201148986816, 45.00936392375401, 41.91104057856968, 1.0139159879514148, 0.12293835889015879, 0.2161393099065338, 0.14122250277016843, 0.14142325414078577, 0.08543494130883898, 0.1281641370483807, 0.15373954682477883, 0.15104076878300735, 0.2297791801393032, 0.15693290904164314, 0.15459117612668447, 0.9400306897503989, 10.91355984551566, 10.138958164623805, 17.320615359715053, 20.08855012484959, 18.996103967939103, 7.171252267701285, 14.67027017048427, 2.4207345843315125, 2.071395878280912, 0.9237707108259201, 3.0850896324430193, 5.279128815446581, 9.17497638293675, 21.908999000276836, 37.25454201017107, 41.69063329696655, 38.84620060239519, 46.5763008253915, 50.25881828580584, 50.43328755242484, 56.35489674976894, 55.70404161725725, 53.823324067252024, 59.52043696812221, 59.39985792977469, 59.701590401785715, 55.87470327104841, 55.08213268007551, 60.79627908979143, 55.715360232761924, 58.20303767068045, 61.29005282265799, 61.84636034284319, 58.993054798671174, 61.4536828994751, 49.38018730708531, 50.94222572871617, 53.17561994280134, 52.41245412826538, 51.15075853892735, 48.02122735977173, 47.14738021578108, 45.67336157390049, 47.91373872756958, 46.325696672712056, 45.5868877683367, 46.08151960372925, 48.831484590257915, 50.72662660053798, 49.262602942330496, 49.31101451601301, 47.62171288899013, 50.66838679994856, 51.03040879113333, 47.31942456109183, 43.95169523784092, 41.688910143715994, 37.75503812517439, 35.92176982334682, 35.02848161969866, 37.0018117087228, 37.40786443437849, 36.30167300360543, 37.5772510937282, 44.335121154785156, 49.76950529643467, 45.294684750693186, 44.7818729536874, 47.22882005146572, 43.23410613196236, 43.3625088419233, 44.76651396070208, 41.91524076461792, 43.84781619480678, 42.404161180768696, 42.946523666381836, 39.73456948144095, 41.638806683676584, 44.47813592638288, 44.85709415163313, 46.41766650336129, 49.61893088476998, 49.465028285980225, 53.0895665032523, 46.855239731924875, 51.247484411512104, 51.33177648271833, 55.59497921807425, 55.20013741084507, 49.4894129889352, 52.91880757468087, 54.04431847163609, 49.26939828055245, 51.09231724057879, 54.10928412846157, 47.61982645307268, 44.32091556276594, 45.37447091511318, 47.15215015411377, 39.773197991507395, 26.510116951806204, 18.783619369779313, 7.496564320155552, 0.41581635602882927, 0.1446518323251179, 0.16636871200587067, 0.1850798036903143, 0.18924983564232076, 0.21142484859696456, 0.12638944227780613, 0.11714227204876286, 0.2569567875138351, 0.264894751565797, 0.1362554228731564, 0.19656231254339218, 0.16874695010483265, 0.1816243098250457, 0.15987207846982138, 0.3838982858828136, 0.26646135321685244, 0.16904485411942005, 0.18752565101853438, 0.2560824272888047, 0.1807015836238861, 0.18959989185844148, 0.19873059833688395, 0.27669200567262514, 0.15466622209974698, 0.3677214410688196, 0.25944679390106884, 2.763345045702798, 52.51903602055141, 60.43711975642613, 46.16683653422764, 34.61738102776663, 56.09781687600272, 49.467540059770855, 0.8954852457557405, 0.15498220228723117, 0.9809154101780483, 9.621089816093445, 69.64707510811942, 57.349124908447266, 86.05507237570626, 74.94737638745988, 1.7768027888877052, 0.41796888623918804], [0.04453965609094926, 0.08589285066617386, 0.341244923216956, 4.173230946063995, 7.480514849935259, 5.015865044934409, 9.65073777948107, 0.5137985497713089, 4.6485103113310675, 3.6209442615509033, 19.103451899119786, 40.198955808367046, 78.90673787253243, 55.55086163112095, 29.454772199903214, 32.47503253391811, 3.26362316097532, 0.2261489906481334, 0.1945230976811477, 0.042080431444836516, 0.057068554152335436, 0.049457352209304056, 0.0687644419127277, 0.10484649147838354, 0.023225771928472177, 0.14341145674032824, 0.018453034638826336, 0.16103283475552285, 1.9322879484721591, 11.18785388129098, 4.702333228928702, 7.6090982130595615, 9.609830260276794, 7.665031211716788, 7.975687776293073, 4.706806566034045, 2.4351792378084998, 0.631572850048542, 0.24521053209900856, 0.42492085748485153, 1.9189678175108773, 2.0913194034780775, 1.909263355391366, 7.525219559669495, 13.464246153831482, 17.538688046591624, 18.38506027630397, 25.700674397604807, 36.81017344338553, 43.86344616753714, 43.20937054497855, 43.30782304491316, 51.206288542066304, 52.096898215157644, 52.66550752094814, 49.87841830934797, 53.082204886845176, 52.32822459084647, 50.99897166660854, 55.037726742880686, 58.016127654484336, 56.518446922302246, 56.49513571602957, 49.42019503457205, 44.08168561117989, 50.16505929401943, 46.200507504599436, 46.86774301528931, 42.31957033702305, 41.77494968686785, 41.50762816837856, 42.98431144441877, 41.00640249252319, 41.66542175837925, 40.35028062547956, 42.277735233306885, 43.678697041102815, 45.51335498264858, 48.743607248578755, 49.714934144701274, 45.20632103511265, 52.1206818989345, 46.34559631347656, 42.913147994450156, 45.13427168982369, 44.54255962371826, 44.20384189060756, 41.02485343388149, 37.125701563698904, 38.414192880902974, 43.33667196546282, 41.06929063796997, 41.59313270023891, 42.04549516950335, 43.86167090279715, 48.28606142316546, 43.22929450443813, 46.05318832397461, 41.47082008634295, 39.8265323638916, 39.977586201259065, 37.466010434286936, 38.57310513087681, 36.77204172951834, 36.75597402027675, 39.269370215279714, 38.95522826058524, 37.127219745091026, 39.11188582011631, 37.530468872615266, 41.008427892412456, 44.41154439108712, 49.27072538648333, 44.59050219399588, 45.33738143103463, 48.10051325389317, 43.64907339641026, 50.26373413630894, 45.66240773882185, 45.13156189237322, 47.239211082458496, 44.47902876990182, 45.33497388022286, 42.61693934031895, 41.90563835416521, 34.198338644845144, 30.978453091212682, 19.959577662604197, 6.891733620847974, 5.572186027254377, 0.05396646507350462, 0.035797051287123134, 0.02344393790034311, 0.050488145290208716, 0.029483676488910402, 0.05449098621362022, 0.059226417647940774, 0.10342715906777553, 0.05742114130407572, 0.06266091763973236, 0.13605332800320216, 0.08331378655774252, 0.16092017080102647, 0.05527336423152259, 0.037282249091991355, 0.09092897828668356, 0.014392394406188811, 0.05668943288869091, 0.056327604089996645, 0.07018487355006592, 0.014505270402878523, 0.10428440663963556, 0.022563628619536757, 0.15729707878615173, 0.027220614620351365, 0.058538145651774745, 0.05291143132905875, 0.1360139594014202, 0.1267087065747806, 1.7344111778906413, 31.65014934539795, 37.66973161697388, 32.58377531596592, 20.179689645767212, 29.501603058406285, 38.15098817007882, 3.34514268381255, 6.312343316418784, 16.54709846632821, 35.40361486162458, 37.49006857190813, 39.45097528185163, 62.68834999629429, 36.533902645111084, 0.08983085756855351, 0.030660816002637148, 0.09380340190338236, 0.04339142556169203, 0.7251441319073949, 28.56507100377764, 24.239735739571707, 11.120141080447606, 9.169851217951093, 1.2844557166099548, 3.336237915924617, 22.041952780314855, 35.462691920144216, 47.386360032217844, 88.10281767163957, 60.77160603659493, 36.55674484797886, 43.561724117824006, 5.0998987300055365, 0.21194101018565042, 0.04568917244406683, 0.051624593058867116, 0.09474115765520505, 0.09033569440777812, 0.010977645720621305, 0.04564375809526869, 0.05399714503437281, 0.032571770782981596, 0.03876229342339294, 0.1231639175010579, 1.240674574460302, 10.164727296148028, 7.56547394820622, 11.01369207245963, 13.572127359254019, 8.75637868472508, 8.930539625031606, 8.08373052733285, 2.5552734221730913, 0.7058506129043443, 0.2517509582851614, 0.7230738401412964, 2.854070063148226, 2.9476712005478993, 2.748021010841642, 9.933296697480337, 16.83722744669233, 21.580746991293772, 24.094572237559728, 30.830908094133648, 41.22875874383109, 49.30064780371529, 46.70831659861973, 45.101844446999685, 54.10653959001814, 53.72069569996425, 56.29860939298357, 51.75777053833008, 55.42084346498762, 55.2748235974993, 55.17023236410958, 57.77544552939278, 60.87857355390276, 59.24588584899902, 60.252596446446006, 49.90188585008894, 47.99722480773926, 53.370836530412944, 49.595373017447336, 47.98598262241909, 44.54662779399327, 44.186040605817524, 45.88757801055908, 44.93417746680123, 43.37161445617676, 43.77857044764927, 42.520084926060264, 44.35663972582136, 46.14022145952497, 46.5915139062064, 50.03213678087507, 50.35529054914202, 48.66095495223999, 52.75818606785366, 48.89871188572475, 46.23696122850691, 48.138954162597656, 48.216051374162944, 45.9515118598938, 43.125134059361045, 38.38639313834054, 41.07450178691319, 44.64593492235456, 43.7897709437779, 43.741185665130615, 44.88804142815726, 46.155299050467356, 50.070737498147146, 45.339841093335835, 47.09821823665074, 44.09231982912336, 42.39832469395229, 42.09474400111607, 39.98249510356358, 40.97528845923287, 39.341787815093994, 38.701566900525776, 40.88891887664795, 40.49569599969046, 40.36210993358067, 41.27774701799665, 41.581824507032124, 43.351624488830566, 47.761962277548655, 52.63185044697353, 48.754540239061626, 47.869117396218435, 51.31842204502651, 47.29810748781477, 52.083085196358816, 50.14358588627407, 46.33908237729754, 48.67100552150181, 49.900193963732036, 48.814857551029746, 46.426994459969656, 45.12754583358765, 38.12677369798933, 35.37225069318499, 22.74419505255563, 11.181858454431806, 5.17953724520547, 0.3614075912960938, 0.035347284350012026, 0.03418201919911163, 0.0742480701633862, 0.01932524051517248, 0.02105078051265861, 0.06330315782023327, 0.1355011226343257, 0.02465055976063013, 0.0889382040394204, 0.051844998196299584, 0.10311093460768461, 0.1318407654762268, 0.054315432240920405, 0.09204595549298183, 0.3042510582932404, 0.04956950047718627, 0.06027047269578491, 0.05208241081397448, 0.009235290777204292, 0.04899507987179926, 0.07728966445262943, 0.016294930263289382, 0.1032867973138179, 0.06345498681600605, 0.019296136451885104, 0.026885857672563622, 0.14350333038185323, 0.1252406146377325, 3.2762910297938754, 47.91242551803589, 46.56487798690796, 39.65136480331421, 25.64079134804862, 37.33364725112915, 59.701375007629395, 7.584909796714783, 8.442199383463178, 27.11441741670881, 51.71977778843471, 52.18311841147286, 47.883719035557334, 76.34695202963692, 37.092107023511616, 0.10339745280465909, 0.1000739543565682, 0.12004186931465353, 0.16313694470695086, 1.485542772071702, 54.344018595559255, 49.61875023160662, 30.65337119783674, 26.48666330746242, 1.4233634514468056, 6.851823602403913, 51.31921761376517, 46.09284864153181, 63.376596859523225, 87.65474224090576, 68.88381549290249, 42.287528719220845, 57.15706280299595, 4.432363143989018, 0.45358472796423094, 0.3353770337998867, 0.11683923830943448, 0.18680336406188353, 0.21292914716260775, 0.21532409079372883, 0.14941726518528803, 0.1990235626165356, 0.23095426708459854, 0.08024618402123451, 0.38337763239230427, 1.9408835215227944, 15.421964509146553, 9.159251741000585, 15.3919917174748, 19.501646212169103, 16.388222694396973, 11.775394422667366, 7.2173461828913, 4.841331507478442, 1.2094313481024332, 0.38740031367966105, 0.7290731210793767, 3.110088599579675, 3.96715475831713, 4.813851382051196, 13.365203057016645, 24.106385912214005, 36.451462268829346, 35.76804092952183, 41.57118681498936, 48.88423531396048, 56.861837318965364, 51.92933893203735, 49.138588019779746, 56.77830260140555, 56.505335671561106, 58.73224721636091, 53.851089068821494, 57.64127581460135, 57.69209493909563, 55.65361506598336, 58.2954626083374, 63.206046376909526, 61.31736619131905, 63.484154973711284, 55.28738594055176, 49.75510515485491, 55.435236658368794, 51.58117164884295, 50.3681377683367, 47.40540157045637, 45.24005453927176, 45.81782157080514, 48.16247034072876, 45.01465845108032, 46.14675276620047, 44.75459432601929, 47.70444508961269, 48.12279960087368, 50.97670269012451, 53.92355530602591, 52.908221994127544, 48.63624368395124, 56.186225754874094, 51.91009937013899, 48.6784713608878, 51.39792333330427, 49.49942534310477, 46.70185477393014, 42.77869687761579, 36.71618863514492, 40.74552195412772, 45.66366536276681, 44.88294839859009, 47.207954611097065, 47.6311103275844, 49.30189847946167, 54.60842187064034, 46.46506016595023, 51.73415361131941, 45.287111214229036, 44.2029664175851, 46.53298575537545, 42.2851767539978, 42.96170548030308, 40.724503653390066, 39.510952132088796, 44.603283405303955, 43.86303274972098, 43.221005303519114, 44.00530406406948, 43.27547223227364, 45.35805927004133, 49.476072447640554, 55.872750827244346, 51.08948932375227, 49.95763124738421, 51.39373704365322, 48.57173660823277, 57.14046703066145, 50.39022609165737, 46.94255426951817, 52.084422724587576, 51.13370418548584, 50.84266151700701, 48.74554927008492, 48.76859297071184, 44.002281597682405, 41.9619083404541, 37.375291279384065, 24.68524554797581, 11.026483706065587, 1.871223270893097, 0.1444155392902238, 0.1709400974214077, 0.1311936466289418, 0.10712556846972023, 0.14625373136784348, 0.22998048790863582, 0.37311972997018267, 0.14235971389072283, 0.26266033574938774, 0.23676412818687304, 0.3308933015380587, 0.5085030996373722, 0.23199546550001415, 0.24557677816067422, 0.6422422432473728, 0.10243237923298563, 0.1844047699123621, 0.12319069249289376, 0.2119364368596247, 0.2125954707818372, 0.22309618017503194, 0.1316488893436534, 0.26747554593852585, 0.1541322014693703, 0.1057858621435506, 0.13011238750602516, 0.1876568254083395, 0.34999191814235275, 5.80856808594295, 59.933945110866, 53.62014831815447, 47.92081894193377, 34.33390147345406, 44.15373495646885, 79.13533360617501, 9.490284766469683, 11.090004137584142, 27.963898965290614, 58.59130300794329, 66.44410146985734, 63.2995274407523, 92.83411012377057, 53.00835943222046, 0.12354169865804059, 0.17313523963093758], [0.060353566094168594, 0.028881809142019068, 0.4506405916597162, 5.514184636729104, 8.518626962389265, 5.047974407672882, 14.660490580967494, 2.4995338874203816, 0.31618415511080195, 18.59227466583252, 30.28334140777588, 50.304659026009695, 93.55306107657296, 96.9143146787371, 52.86902025767735, 36.11571489061628, 9.024684241839818, 0.5798217984182494, 0.1097731917564358, 0.036059125260050805, 0.01933854489055063, 0.062018148201916895, 0.06145917783890452, 0.04051784672109144, 0.0485028230718204, 0.060466990007885864, 0.08527470526418515, 0.13259107592914784, 3.0522233503205434, 7.977641088621957, 3.653196496622903, 1.185853504708835, 11.603368316377912, 17.46611758640834, 9.116354431424822, 7.798058816364833, 7.667562961578369, 0.9708827542407172, 0.7391084368739809, 0.06605808463479791, 0.6472028770617076, 2.610110125371388, 3.01878080197743, 2.2868230385439734, 5.0649979284831455, 14.359146339552742, 20.788485595158168, 23.16847116606576, 26.058814082826885, 35.4246609551566, 42.59369414193289, 41.24231467928205, 51.45048298154558, 46.97328267778669, 54.11133732114519, 52.250206742967876, 53.99577488218035, 51.57187148502895, 53.801937511989046, 54.42884915215628, 55.07448966162545, 55.02869755881173, 52.000488485608784, 46.6865166255406, 51.57481404713222, 50.45250974382673, 47.78086485181536, 42.74724585669381, 42.44478382383074, 41.003258432660786, 44.10936723436628, 41.974300452641074, 40.229493141174316, 41.44281884602138, 41.622547898973735, 40.40306609017508, 44.87762260437012, 43.46264975411551, 47.02788857051304, 46.003585134233745, 49.73394789014544, 53.804150513240266, 46.01411165509905, 44.21291276386806, 44.39441360746111, 42.642790113176616, 42.09592866897583, 43.49659865243094, 41.57204839161464, 42.45648111615862, 43.4340683392116, 42.618735449654714, 42.158351285117014, 42.677930627550396, 44.0806815964835, 48.81983593532017, 45.122834954942974, 42.8667687688555, 43.82513380050659, 39.141412190028596, 39.29761116845267, 37.044459751674104, 37.212404659816194, 36.66019657679966, 35.832256180899485, 37.23580271857125, 37.55943243844168, 38.016245228903635, 39.16439683096749, 38.264288970402305, 42.920005866459434, 45.187956946236746, 49.43482446670532, 47.656273228781565, 43.6515017918178, 47.92888927459717, 43.716512611934114, 48.79778930119106, 48.117463384355815, 42.42641626085554, 43.2150159563337, 47.10769557952881, 42.83093343462263, 43.9126741545541, 35.058035782405305, 28.8454064982278, 23.69177300589425, 9.498149258749825, 5.027967069830213, 0.2580445877143315, 0.06329234197203602, 0.046693607832172086, 0.014990292323221053, 0.10795608176184551, 0.03289854646261249, 0.0670025103858539, 0.03203114461419838, 0.03504589945077896, 0.07899993232318334, 0.13952486243631157, 2.240764298609325, 2.2495459531034743, 2.694116017648152, 3.1323323888438086, 0.4458935335278511, 0.09292864812804119, 0.08250209582703454, 0.0628110570833087, 0.07804150160934244, 0.005799081301250095, 0.06111834291368723, 0.03733974136412144, 0.04197500406631401, 0.04059950501791068, 0.03074992461396115, 0.03061711834743619, 0.06106962409934827, 0.16492800574217523, 0.11445064576608793, 1.50625014092241, 40.48773683820452, 44.89051846095494, 35.9205538885934, 24.119250501905167, 20.51884511538914, 37.85600587299892, 30.249086788722447, 17.889669350215367, 33.657063552311485, 26.00805401802063, 32.862050669533865, 54.32207271030971, 58.355953625270296, 6.380793929100037, 0.27741377694266184, 0.15633794239589147, 0.04875231022015214, 0.12205871966268335, 0.7699445422206606, 24.67197969981602, 27.042619943618774, 10.065540892737252, 20.313558850969585, 5.39775150162833, 2.2830410471984317, 39.26654577255249, 45.25888415745327, 62.833504813058035, 99.4737183707101, 99.75588471548897, 62.21305847167969, 44.47254262651716, 14.277280926704407, 0.8862865907805306, 0.23582169732877187, 0.09119937449161496, 0.06708415850464787, 0.09284651824938399, 0.09457372913935355, 0.007017417220465306, 0.04354434360616973, 0.04514537412407143, 0.08147062081843615, 0.24130138329097203, 4.881278003965106, 13.029055288859777, 5.3318977781704495, 8.442715287208557, 16.403771025793894, 16.299773863383702, 10.899837153298513, 8.010512147630964, 5.055125841072627, 1.399660649044173, 0.1176742027912821, 0.056958685762115886, 0.5999922560794013, 2.364646553993225, 2.4242662233965735, 2.693484817232404, 6.624528918947492, 16.58279136248997, 23.682976586478098, 26.11715636934553, 30.8431647164481, 40.520834582192556, 46.76692465373448, 44.88986185618809, 53.22456652777535, 51.67312410899571, 58.17720774241856, 53.48403310775757, 58.40411853790283, 53.02284990038191, 57.68623413358416, 56.18058034351894, 57.124951703207834, 58.00130367279053, 52.52907616751534, 48.61968960080828, 55.3385385785784, 52.07433046613421, 53.0679715020316, 46.42037282671247, 45.9186920438494, 43.92271430151803, 46.50631162098476, 43.258668013981406, 43.951834201812744, 43.33617516926357, 43.27679933820452, 44.50260748182024, 45.29815884998867, 44.82915891919817, 48.16559355599539, 48.007365703582764, 51.04470123563494, 53.79492677961077, 47.278517041887554, 46.91446270261492, 46.33412136350359, 44.01997865949358, 44.05902406147548, 45.79076875959124, 45.04820087977818, 42.09743642807007, 44.708920342581614, 44.99794108527047, 44.79502589362008, 44.11794131142752, 43.623875754220144, 50.361967767987935, 46.27825089863369, 44.59186404091971, 45.18962103979928, 40.19450201307024, 41.29524258204869, 39.38432468686785, 38.93249722889492, 39.14606053488595, 38.28385509763445, 40.58299664088658, 39.52620690209525, 39.327526637486045, 41.797680718558176, 41.26850243977138, 45.057389872414724, 47.27444192341396, 53.02891220365252, 51.36456503186907, 47.82939107077462, 49.73928758076259, 48.007546356746126, 50.32288762501308, 49.55019930430821, 42.84104653767177, 44.5224723815918, 49.29915394101824, 46.97389759336199, 46.46947922025408, 40.279158864702495, 32.22369187218802, 24.648229019982473, 12.002547536577497, 4.555431808744158, 0.6505669451185635, 0.13109740322189672, 0.12164697104266711, 0.023445060875798975, 0.0705152183238949, 0.07471608290714876, 0.08589135788913284, 0.04171990543337805, 0.09531910664268903, 0.014786565576546958, 0.06687514936285359, 2.3310303006853377, 2.657982562269483, 2.2112090502466475, 4.549594453402928, 0.8148062378168106, 0.1966217522110258, 0.0645440626623375, 0.03593003058007785, 0.023970772844872305, 0.05487013461866549, 0.057164186877863746, 0.05214911759165781, 0.07844458533717052, 0.056508711871824095, 0.05343081256640809, 0.04009988611297948, 0.056198723148554564, 0.2123056956167732, 0.1592391138630254, 6.836008633886065, 57.88712045124599, 54.28624779837472, 42.71356793812343, 29.911175046648296, 30.496498244149343, 46.8341623714992, 47.59255129950387, 29.512157372065953, 41.80778339930943, 34.71490246909005, 42.095838342394146, 60.62351213182722, 65.91161932264055, 4.020028378282275, 0.1994930681373392, 0.11083046466644321, 0.20315889428768838, 0.4376410006412438, 1.1242356853825706, 46.23167712347848, 54.615825176239014, 24.235886437552317, 44.31626026970999, 6.861238411494663, 9.779658998761859, 70.0247722353254, 52.73289462498256, 68.68644496372768, 100.25038800920758, 109.76693262372697, 61.33611937931606, 61.54951940264021, 14.38073091847556, 0.8647147683160645, 0.302560420440776, 0.21729786773877485, 0.09379485914749758, 0.3443712597446782, 0.200907881504723, 0.15213924912469728, 0.11023093148001603, 0.21249112566666944, 0.3339682322527681, 0.6077186529125486, 5.672290027141571, 17.52778458595276, 10.748052018029348, 10.695499317986624, 20.49757320540292, 26.26898319380624, 14.102488568850926, 12.168724128178187, 10.545376539230347, 3.6659373215266635, 2.119602697236197, 0.10469224011259419, 0.6692883233938898, 2.6266346786703383, 3.6644608293260847, 3.990166323525565, 8.35598005567278, 21.46960186958313, 34.049782684871126, 37.335356507982524, 39.539960861206055, 48.37998717171805, 55.106232506888254, 48.81829343523298, 56.79599618911743, 53.21197986602783, 59.703098160879954, 56.27140372140067, 60.185914584568565, 56.33208233969552, 57.72765929358346, 57.45737784249442, 59.50869451250349, 58.90414564950125, 55.623161111559185, 52.499014786311555, 55.9330472946167, 53.480753558022634, 53.132009574345176, 48.49686629431588, 47.304739543369834, 45.653625215802876, 50.455323764256065, 46.30592557362148, 46.01643582752773, 46.82083920070103, 46.28622743061611, 44.97397327423096, 50.285023416791645, 47.66619178227016, 49.38609674998692, 50.34612934929984, 53.08498069218227, 58.71917070661272, 51.225229331425254, 48.56400326320103, 48.6355870791844, 48.92747742789132, 45.4494628225054, 47.13935852050781, 47.69539853504726, 44.26098040172032, 49.61721815381731, 46.91276734215872, 46.14469262531826, 46.22632006236485, 46.217106751033235, 53.608749798366, 50.673743861062185, 47.00520270211356, 47.509902477264404, 45.028304713112966, 43.49740811756679, 41.79859788077218, 41.28939914703369, 41.04767826625279, 39.786000047411235, 42.69103493009295, 42.183330059051514, 42.50187022345406, 43.4293783051627, 44.223300320761545, 47.22611720221383, 49.48260375431606, 53.68689618791853, 53.96767289297921, 48.65344047546387, 53.311384269169395, 49.55240535736084, 53.51607819965908, 53.01655830655779, 45.838221481868196, 45.295369148254395, 51.13138001305716, 46.41048901421683, 50.43170683724539, 43.060838903699604, 36.795130593436106, 36.66110331671578, 26.903147016252788, 9.850402082715716, 1.5347211446080888, 0.3054765739611217, 0.22447333484888077, 0.13828444613942079, 0.1541487577238253, 0.17378634826413222, 0.20116884607289517, 0.0906854724245412, 0.19683120240058216, 0.15283362115068094, 0.3323460721543857, 3.3617130517959595, 3.672926340784345, 3.4760115700108662, 6.220930644444056, 1.0933002425091607, 0.29460239889366285, 0.18537176373813832, 0.14499716593750886, 0.12171747083110468, 0.14982655750853674, 0.17644530987100943, 0.1412850365574871, 0.22576356918684073, 0.14244128737066472, 0.11930375892136778, 0.21594714878925256, 0.19583070251558507, 0.653446050626891, 0.3897349355476243, 9.602448667798724, 70.32713004520961, 59.032270431518555, 54.36443935121809, 37.211873122623985, 33.6771890095302, 54.04173026766096, 56.31058461325509, 36.784479004996165, 56.35701942443848, 50.10044799532209, 63.11415645054409, 81.00123064858573, 94.84386266980852, 11.614281330789838, 0.5097791797348431, 0.27869808088455883], [0.31996902344482286, 0.12348637091261999, 0.26335358140724047, 6.04027704681669, 10.143980843680245, 4.345399056162153, 13.019650902066912, 18.976140056337627, 4.243478970868247, 38.73927477427891, 39.758655411856516, 54.501311915261404, 93.65633215223039, 101.09164810180664, 50.0949068069458, 35.65682806287493, 17.534659828458512, 0.6164284912603242, 0.11270517549876656, 0.08873883688024112, 0.048934920957045894, 0.0925753213731306, 0.03307172217007194, 0.08861787444246666, 0.04948628494249923, 0.054193438429917605, 0.04004815121048263, 0.28218803075807436, 2.0339474763189043, 5.6002958331789285, 5.404671907424927, 1.0852001628705432, 6.0638284002031595, 23.026104313986643, 25.068216357912334, 14.302310943603516, 19.846287284578594, 7.157146121774401, 1.41689532995224, 0.2616122162767819, 0.48554266882794245, 0.4448968198682581, 1.3335421340806144, 0.6947560225214277, 1.4166487774678638, 4.533531521047864, 21.625964130674088, 21.357138327189855, 29.174478394644602, 31.153141226087296, 39.14022057397025, 40.69745431627546, 46.046966212136404, 46.99821628843035, 49.92973075594221, 49.38610022408621, 52.55745955875942, 49.6584279196603, 54.474061080387656, 52.91662236622402, 51.67239454814366, 54.82099505833217, 44.72301476342337, 46.92456190926688, 54.58360637937273, 49.69418682370867, 46.33031027657645, 44.96786233357021, 40.90106085368565, 38.76053973606655, 41.04156385149275, 39.015656743730815, 39.30057110105242, 39.150038378579275, 41.16755901064192, 41.917731693812776, 40.65288509641375, 43.65718194416591, 44.80062961578369, 44.01239470073155, 45.99352066857474, 44.62376322065081, 45.686389446258545, 43.41258103506905, 44.64617463520595, 42.22457456588745, 40.7265533719744, 42.983807700020925, 44.94815376826695, 41.863699027470176, 40.39503049850464, 42.82952642440796, 44.1287179674421, 40.50315489087786, 42.262007985796245, 44.722069808415, 42.53998109272548, 41.9871963092259, 40.14226198196411, 37.54721750531878, 39.474522726876394, 37.907443387167795, 38.96442072732108, 35.57516935893467, 35.56922517504011, 37.05954081671578, 38.14437001092093, 38.104893820626394, 39.04696880068098, 37.50955132075718, 41.83006279809134, 45.25734165736607, 51.79099334989275, 50.33576263700213, 44.65339381354195, 46.56543731689453, 48.220279353005544, 44.260129247392925, 47.71878964560372, 40.574738706861226, 41.616631507873535, 43.75801420211792, 42.80731650761196, 37.40058619635445, 32.73309905188424, 22.320549488067627, 9.919812849589757, 3.616389717374529, 0.2631527621831213, 0.17329640526856693, 0.09099054855427571, 0.03786142622785909, 0.016603315947577357, 0.09770506647016321, 0.08018787072173186, 0.1038992837337511, 0.03204439640311258, 0.14160603790410928, 0.13765078942690576, 0.44651053899100845, 1.4112008469445365, 8.351115448134285, 10.381566677774702, 6.153464938913073, 2.415501070874078, 0.42235091967242105, 0.3336112956915583, 0.020602660719305277, 0.036905363601233275, 0.04774484856586371, 0.020584939080955725, 0.060167206451296806, 0.09347341675311327, 0.0038287653088835733, 0.03381100303626486, 0.009679902544511216, 0.05773881782910653, 0.05300357299191611, 0.18045241199433804, 12.339166045188904, 54.40802192687988, 54.53093555995396, 42.00783593314034, 26.537407738821848, 24.009258781160625, 28.43324978010995, 37.99620662416731, 30.374560832977295, 24.412097964967998, 22.28035589626857, 30.433401652744838, 36.43961559023176, 12.472432494163513, 0.06765836197882891, 0.012670084235391446, 0.06887922289648227, 0.0776221194703664, 0.10145503096282482, 0.16701056542141096, 15.928502082824707, 25.46166852542332, 7.560565914426531, 23.81084428514753, 27.997978142329625, 7.309206145150321, 54.38082320349557, 50.37835162026541, 60.58479676927839, 98.94427953447614, 99.87282984597343, 54.75946181161063, 47.16018574578421, 24.486011164528982, 0.6090191059878894, 0.29526361769863535, 0.0644529489800334, 0.06539276069296257, 0.13038680063826696, 0.02442176453769207, 0.10184256945337568, 0.031361949630081654, 0.04289242751630289, 0.019238847740260617, 0.19714528269001416, 2.507014274597168, 11.717596701213292, 7.40449287210192, 3.130406217915671, 12.510729227747236, 27.38083914348057, 20.866305419376918, 10.79200197969164, 15.805327892303467, 3.9477875232696533, 1.7413695816482817, 0.16073045240981237, 0.16909130662679672, 0.2873869932123593, 1.4312709357057298, 0.9081651110734258, 1.5082375428506305, 5.816555040223258, 21.060346024377004, 25.958311864307948, 33.98252412251064, 35.38202680860247, 43.67420850481306, 43.62697465079171, 49.328725474221365, 49.946541922433035, 53.207394054957796, 53.0741936138698, 57.20009299686977, 53.8726875441415, 56.78220401491438, 55.11876358304705, 55.33475181034633, 56.895463126046316, 48.358701365334646, 51.03929901123047, 56.16771922792707, 52.92928545815604, 49.50988933018276, 49.7195269039699, 43.61969641276768, 42.25048787253243, 44.65719447817121, 42.753690310886924, 41.179954596928184, 43.19638783591134, 43.65699781690325, 41.801022802080425, 43.813377448490684, 44.48363195146833, 45.22787087304251, 45.70946441377912, 48.6394259589059, 46.06969724382673, 49.68189198630196, 44.77526521682739, 47.36001941135952, 44.354621274130686, 44.90019382749285, 44.42154284885952, 46.2574097769601, 45.955923965999055, 41.370422090802876, 43.63873100280762, 45.88256141117641, 42.617088726588655, 44.130489758082796, 46.24675818852016, 44.22484629494803, 43.35693291255406, 40.93282454354422, 39.16593933105469, 40.76631791251046, 40.211653641292024, 40.2573276247297, 38.34948778152466, 38.56338112694876, 40.00037629263741, 40.46457849230085, 40.44456768035889, 40.7039578301566, 40.25822741644723, 44.67722960880825, 47.80864027568272, 52.65722526822771, 51.87641797746931, 48.577051980154856, 48.244410446711946, 51.70850086212158, 46.635773931230815, 50.14496162959507, 41.7952766418457, 43.91739892959595, 48.764194761003765, 45.757229804992676, 41.406448500497, 36.21966688973563, 22.517642089298793, 11.372390219143458, 3.8272688473973955, 0.17395727123532975, 0.13503776464079106, 0.05411583777250988, 0.013911937330184239, 0.017582640450979983, 0.012078249876919602, 0.05214468336531094, 0.05058318090492061, 0.03231258397655828, 0.10474912170320749, 0.24947287195495196, 0.6559721550771168, 1.884034663438797, 8.964407750538417, 11.399899005889893, 7.650663205555507, 1.948280964578901, 0.37176089574183735, 0.30756646181855885, 0.1347941705690963, 0.031281417701393366, 0.07905388264251606, 0.044551961323512454, 0.00798465489476387, 0.06128771203969206, 0.02657322266272136, 0.02486453577876091, 0.06613237743398973, 0.02923423344535487, 0.1451157738587686, 0.1684322048510824, 25.334750992911204, 65.444582257952, 59.50111402784075, 50.96252836499895, 30.9566878591265, 33.58326326097761, 36.820109367370605, 46.150212969098774, 39.98645557676043, 30.681205681392125, 26.136795452662877, 39.619847774505615, 44.1368682043893, 8.857330799102783, 0.12226028527532305, 0.0742493797359722, 0.07014659060431377, 0.47203993052244186, 0.30103697361690657, 0.35961034202149933, 29.446753978729248, 52.27375418799264, 27.941207885742188, 43.004475116729736, 37.82784135001046, 17.435823440551758, 75.20010321480888, 63.01458876473563, 68.42313602992466, 101.18335737500871, 105.65095179421562, 60.03435352870396, 61.747807094029014, 28.98567499433245, 0.9374171899897712, 0.4640993880374091, 0.2076261110071625, 0.1920072662511042, 0.3607963669512953, 0.11923875526658126, 0.18497395222740515, 0.1867220484252487, 0.24313733620303019, 0.15440476898636135, 0.551645604627473, 2.9944032643522536, 14.674353974206106, 15.578463997159686, 4.140165337494441, 15.316652400153023, 42.09730093819754, 31.48095723560878, 19.667127983910696, 22.173129558563232, 11.44430581160954, 3.3826581793172017, 0.46379176740135464, 0.541642315685749, 0.2871673921389239, 1.2672288524253028, 1.0927606714623315, 2.3898061982222965, 7.156017908028193, 25.480166367122106, 33.087071555001394, 43.42640447616577, 42.53186559677124, 51.286432538713726, 49.659616061619346, 53.24716206959316, 53.23684746878487, 56.46695729664394, 53.9872008051191, 58.70903328486851, 55.613805362156455, 59.434883798871724, 56.22705684389387, 55.61186334065029, 59.14167676653181, 50.156189918518066, 50.29588345118931, 59.07045078277588, 55.35959162030901, 51.27470050539289, 51.711401735033306, 45.67026962552752, 43.713993889944895, 47.25623416900635, 43.42781843457903, 45.191326822553364, 46.576377255576, 46.8498409816197, 45.72426060267857, 47.703409808022634, 49.422310761043, 48.759668009621755, 47.91665349687849, 50.62412677492414, 47.76473808288574, 52.75832503182547, 49.56066329138619, 51.01122828892299, 47.52199581691197, 46.3541773387364, 46.109736238207134, 49.630287715366904, 47.74098219190325, 44.52888904299055, 46.27058356148856, 47.66650445120675, 44.837316104343955, 46.683650493621826, 49.4491342817034, 48.16063601630074, 45.31905903135027, 43.55492877960205, 41.624879019601, 43.7164431299482, 42.34314210074288, 42.31206280844552, 41.37913165773664, 40.25465604237148, 41.64633158275059, 43.12798629488264, 42.82992941992623, 43.50522484098162, 41.27698619025094, 46.70232377733503, 50.21001761300223, 57.16213846206665, 56.0833020891462, 51.20691735403878, 49.38967854636056, 54.9741507257734, 49.69480868748256, 53.69547373907906, 43.25728532246181, 45.07156767163958, 50.959425994328086, 48.8597846031189, 43.8518739427839, 39.13711820329939, 31.58256769180298, 26.639426401683263, 8.284589920725141, 0.808378068464143, 0.3534777153815542, 0.18811855491782936, 0.17156555743089744, 0.12572590288306984, 0.1526102474225419, 0.17467391278062547, 0.1375460914735283, 0.17921213140445097, 0.15035992674529552, 0.4211810438760689, 1.4734574662787574, 2.914595821074077, 12.374484607151576, 14.843448809215001, 11.332462395940508, 6.424180218151637, 1.376047847526414, 0.7391338955078806, 0.3478007385773318, 0.13412980336163724, 0.22927836701273918, 0.10550895200244018, 0.13087005327854837, 0.19843771548143455, 0.1919396027390446, 0.1194400494652135, 0.15022210271230765, 0.11534434423914977, 0.32248489558696747, 0.42780208002243725, 27.661275386810303, 77.15296391078404, 66.1031881059919, 60.3331538609096, 39.49558619090489, 37.956261430467876, 40.33894811357771, 58.63345772879464, 56.31217575073242, 46.02876540592739, 52.54670374734061, 68.60720075879777, 76.85536561693463, 22.46651898111616, 0.25884943881205147, 0.14574857561716012, 0.20267119045768464], [0.534578549010413, 0.6814763865300587, 0.2485583967396191, 2.425786576100758, 7.085496732166835, 4.264383060591562, 4.269420504570007, 18.39548257419041, 20.044887644904, 48.95474215916225, 53.14311279569353, 48.596996784210205, 77.55614008222307, 89.91512325831822, 44.24582985469273, 44.19738006591797, 27.042927401406423, 1.0585908421448298, 0.18063484291945184, 0.053416271560958455, 0.08783929622066872, 0.09220619153763567, 0.06839678449822323, 0.07463195813553673, 0.0214536165752049, 0.0859046300340976, 0.19775069877505302, 0.8654919351850237, 1.765353786093848, 4.164455371243613, 1.9829533440726144, 0.41899070569447106, 1.0433829724788666, 9.465818422181265, 25.86766219139099, 22.503165517534526, 25.231097766331263, 15.48895730291094, 11.581594399043492, 1.1509097112076623, 0.26514412675585064, 0.3827030600181648, 0.49697174983365194, 0.4158187716134957, 0.44105012342333794, 2.3868662416934967, 9.331543615886144, 21.936746631349834, 27.056290524346487, 31.446098123277935, 32.22629049846104, 40.058536188943044, 42.62617697034563, 44.53657375063215, 44.9805497441973, 50.09391668864659, 49.690170764923096, 50.25635862350464, 54.68321228027344, 52.50658137457711, 54.924102851322715, 52.355732509068076, 47.057098797389436, 54.06067105701992, 53.23881033488682, 51.360941546303884, 48.01422010149275, 40.90965230124337, 40.57856021608625, 41.62053986958095, 40.69644682747977, 39.77562986101423, 37.48029245649065, 40.11589009421212, 40.27755730492728, 38.65141827719552, 41.62801265716553, 41.42015034811837, 41.22748374938965, 47.72030087879726, 44.02455752236502, 44.50637687955584, 44.273688656943186, 42.853327478681294, 43.81776523590088, 45.63109220777239, 42.72936119352068, 44.38564845493862, 44.389254570007324, 45.25100142615182, 44.8096935408456, 42.08986289160592, 41.824862071446006, 40.32976606913975, 42.867529596601216, 43.13513946533203, 39.69933516638619, 42.018918309892925, 38.81758097239903, 35.54576110839844, 37.87209790093558, 38.25142090661185, 37.471221583230154, 34.53949172156197, 37.133292470659526, 37.63702992030552, 37.46100425720215, 37.008506298065186, 37.07758181435721, 37.60751397269112, 41.53369433539254, 49.33518729891096, 50.144791398729595, 51.16049643925258, 45.549794810158865, 49.27630826405117, 47.60999822616577, 44.6641982623509, 45.4686016355242, 40.022436823163716, 38.278362546648296, 43.79537466594151, 37.75837326049805, 35.368415287562776, 23.69767897469657, 11.781169244221278, 4.297085191522326, 0.29483961473618236, 0.12106330879032612, 0.001366278711689769, 0.03713570588401385, 0.025789043134344474, 0.027303770783224275, 0.09614894818514585, 0.050200080033391714, 0.016859530770619, 0.05876631662249565, 0.007973895025705653, 0.07097059674561024, 2.0296306908130646, 3.4819101563521793, 17.095776864460536, 12.265154702322823, 9.334057995251246, 4.7277084844453, 2.8766037225723267, 4.330903376851763, 0.11730934094105448, 0.05886742512562445, 0.1317840399486678, 0.01751586073078215, 0.056963957979210784, 0.08156064884471041, 0.03281618927472404, 0.026766462650682245, 0.047167540793972354, 0.0392587741038629, 0.07341286819428205, 0.33886847645044327, 27.45116707256862, 52.87999146325247, 55.90771068845476, 40.87975767680577, 25.896165439060756, 25.27619331223624, 37.03760187966483, 43.845606667654856, 28.240560599735804, 13.061019607952662, 2.5241995581558774, 2.728281178644725, 3.822912326880864, 0.4145383488919054, 0.029663311849747385, 0.056373473057257276, 0.12678178479628904, 0.18586230384452002, 0.20603776909410954, 0.04970689703311239, 4.399024818624769, 18.703364201954432, 8.460321153913226, 13.095308099474225, 35.583986622946604, 28.225764410836355, 59.5773149217878, 61.44050216674805, 56.708049365452354, 84.13515308925084, 87.71854060036796, 44.06679214750017, 57.13057279586792, 40.51462984085083, 1.051368623971939, 0.164106191268989, 0.07235336968941347, 0.06868903631610529, 0.08187079363103424, 0.04548884855051126, 0.042017812840640545, 0.001115596599577527, 0.04655471510652985, 0.041603380614625554, 0.40358991495200564, 2.78182030575616, 9.807144335338048, 7.067463551248823, 0.6172852909990719, 2.7988264560699463, 21.86909896986825, 35.67995514188494, 24.243128197533743, 25.63412802559989, 15.37403062411717, 7.094136382852282, 0.5865187219211033, 0.3159041372793061, 0.41411570299948963, 0.5937830635479519, 0.6305302402802876, 0.6392653744135584, 2.9788864169801985, 9.847983241081238, 24.387398856026785, 31.717018808637345, 37.416382925851, 37.409611906324116, 43.07340472085135, 46.530463559286936, 46.84086390904018, 49.331143447331016, 51.019315992082866, 51.023088863917756, 52.88267694200788, 56.32146201814924, 54.85103906903948, 56.75787489754813, 53.80562700544085, 50.420502867017476, 56.53115865162441, 56.564708028520855, 54.36475202015468, 50.825746127537315, 44.536730085100444, 44.59643595559256, 43.232900619506836, 42.685973167419434, 42.04775333404541, 41.56056996754238, 41.69108145577567, 42.27146448407854, 41.997788837977815, 44.91255814688546, 43.95815706253052, 44.48116534096854, 48.754950182778494, 44.18148953574044, 46.61581523077828, 45.73096908841814, 45.393272740500315, 44.52982357570103, 46.76132093157087, 47.09139857973371, 47.65700626373291, 45.47448328563145, 46.19593211582729, 47.036817005702424, 45.07420103890555, 44.5683582850865, 41.969996043613975, 44.320078304835725, 45.728999274117605, 39.61263901846749, 44.1948161806379, 40.75290094103132, 37.11807591574532, 38.44232266289847, 38.29102563858032, 40.05581596919468, 36.670181138174875, 40.049267292022705, 39.90565497534615, 40.80176067352295, 39.73452779224941, 40.961590085710796, 40.6812094279698, 43.73414019175938, 51.28049182891846, 52.07528584344046, 52.26866463252476, 48.33866970879691, 49.08740064076015, 50.993986334119526, 47.312184538160054, 48.8100528717041, 42.44951902117048, 41.99596840994698, 44.1370974949428, 41.76477405003139, 38.24583108084542, 23.667452573776245, 12.698134303092957, 4.513562832559858, 0.28982754796743393, 0.07352104703230516, 0.03840866811307413, 0.05053904898730772, 0.031871790665068796, 0.04284751867609365, 0.030975008250347207, 0.040487957253519974, 0.013927245080204946, 0.03893528931907245, 0.030571972019970417, 0.08199385274201632, 2.5319535306521823, 4.050370727266584, 18.98225620814732, 15.894577503204346, 10.80501595565251, 4.315450148923056, 2.985642454453877, 4.420264593192509, 0.07142561554376568, 0.06084195524454117, 0.12813348083623818, 0.06879913540823118, 0.09173612961811678, 0.10723761495734964, 0.06939272462789502, 0.01348932960536331, 0.02495949505828321, 0.0932807738759688, 0.022433950399447764, 0.8286364642637116, 39.80382565089634, 62.25078024183001, 63.08628722599575, 48.854604721069336, 34.74073239735195, 31.582866464342388, 41.61362293788365, 61.46716240474156, 35.35308061327253, 10.419826064790998, 4.234808921813965, 12.500623072896685, 5.609975108078547, 0.316145695745945, 0.01284163654781878, 0.017408428281279545, 0.07232438267341681, 1.316411024757794, 1.9984484783240726, 0.5146366219435419, 8.880352786609105, 38.92239107404436, 26.749708209718975, 32.305847372327534, 49.00644717897688, 47.89588533129011, 76.99360002790178, 74.34422411237443, 63.30198015485491, 86.8805183683123, 97.39292744227818, 55.18329497746059, 68.4434734072004, 48.36239780698504, 0.7492558466536658, 0.3198995957417147, 0.14956490083464555, 0.2142037616244384, 0.14722612633236817, 0.11210938782564231, 0.15489757539970533, 0.18101558248911584, 0.25356411242059296, 0.2724717892706394, 1.747659764119557, 4.46307635307312, 14.55257637160165, 9.006689276014056, 2.594210692814418, 2.9363148042133878, 20.60857936314174, 42.902298382350374, 28.181801421301707, 30.723002570016043, 20.148504393441335, 15.057105915887014, 1.5794009928192412, 0.33599303503121647, 0.5058807517801012, 0.9454465934208461, 0.6923573198063033, 0.7002924340111869, 3.5009267245020186, 10.746565972055707, 28.702963215964182, 38.39138194492885, 46.566041810171946, 42.912154402051655, 47.108987944466726, 50.95904731750488, 50.57585416521345, 52.51309878485543, 54.054640020642964, 53.895269189562114, 54.611135142190115, 58.91703455788748, 57.53451326915196, 58.78616523742676, 57.8679712159293, 52.067604609898154, 57.90761068889073, 58.40541090284075, 55.14902993610927, 54.717536381312776, 45.663863386426655, 46.749901567186626, 48.04948568344116, 46.101558208465576, 45.53522791181292, 43.69347933360508, 44.49250480106899, 46.56911986214774, 43.96096066066197, 47.98199783052717, 47.124954904828755, 45.44399111611502, 52.60811540058681, 48.09531947544643, 48.67691843850272, 49.61436244419643, 48.52457571029663, 48.36017785753523, 50.39637872150966, 45.87600578580584, 49.06166103907994, 47.60397066388811, 49.45911884307861, 49.332953453063965, 48.76503201893398, 45.99988521848406, 43.119707516261506, 47.097398349217, 47.312090737479075, 43.083948612213135, 45.870113713400706, 43.01200001580374, 39.47200400488717, 42.807167121342246, 42.77567788532802, 42.59321471623012, 38.67875943865095, 42.99772146769932, 43.935363497052876, 42.65846872329712, 41.66837821687971, 42.50620242527553, 42.88301018306187, 47.04800360543387, 56.38872752870832, 54.32324000767299, 54.910262039729524, 51.25557558877127, 53.51803411756243, 52.351028578622, 50.61750514166695, 52.1770144190107, 45.217670917510986, 44.23372261864798, 48.104609216962544, 46.14308411734444, 43.43976933615548, 30.95886959348406, 26.176231690815516, 9.072243792670113, 1.0206911329712187, 0.2036880294659308, 0.22140410382832798, 0.07968945960913386, 0.14691999847335474, 0.11314344805266176, 0.21285893235887798, 0.17913078862641538, 0.12282416144652025, 0.20114270890397684, 0.20870796724089555, 0.14392248860427312, 3.235065847635269, 6.066985922200339, 23.19240771021162, 20.687208652496338, 15.276061023984637, 10.718184317861285, 5.0331074340002875, 6.740697588239398, 0.4459972679615021, 0.09429223210151706, 0.1901980069066797, 0.2715171719236033, 0.12982665640967234, 0.22686793921249254, 0.20878583591963562, 0.17143662220665387, 0.3184514120221138, 0.27116398087569643, 0.14772099549216883, 0.8583814310176032, 51.20088979176113, 70.2489767074585, 70.28177915300641, 57.163017409188406, 39.567527839115684, 38.64436585562569, 50.72737005778721, 68.55850083487374, 50.26835468837193, 46.780240876334055, 36.87339162826538, 36.03559521266392, 15.55714692388262, 0.43630368954369, 0.12215336172708444, 0.08382855714964015, 0.2030471802822181], [2.9176117735249654, 3.0041622264044623, 0.05400238671739187, 0.03653096494131854, 1.8683755951268333, 1.4198368063994815, 3.5597968569823673, 3.6475610733032227, 20.737298216138566, 47.32021318163191, 58.15256248201643, 41.116663455963135, 69.63702801295689, 73.23659787859235, 36.4251320702689, 46.98734583173479, 36.52860811778477, 1.8792599482195718, 0.35189168048756464, 0.061073267832398415, 0.07293793439332928, 0.2017386526401554, 0.09470460497375045, 0.05568163535956826, 0.0674203047528863, 0.09448104125580617, 0.07836630275206906, 2.808848364012582, 4.360684658799853, 3.4411342186587195, 5.835085885865348, 0.18804421462118626, 2.608000478574208, 6.318574982030051, 6.619046355996813, 19.105958461761475, 34.14737360818045, 24.139509711946758, 10.914780122893196, 4.222683012485504, 0.7153351211122104, 0.7724481193082673, 0.40403310688478605, 0.5129050005759511, 0.7478237577847072, 1.993442518370492, 6.611569660050528, 16.49187765802656, 27.301087720053538, 31.09020791734968, 28.50960874557495, 34.74586016791207, 37.08761848722185, 42.56721108300345, 42.03209209442139, 45.85778760910034, 48.165603978293284, 47.80744865962437, 49.85808093207223, 52.45747150693621, 52.55002498626709, 51.62033864430019, 49.18942451477051, 52.142082350594656, 53.412477084568565, 51.39409487588065, 46.28868709291731, 42.34383692060198, 40.77854674203055, 41.496785504477366, 37.64595488139561, 39.70892020634243, 38.54989814758301, 37.642890725817, 39.98245341437203, 40.124780314309255, 39.926735809871126, 40.39664248057774, 46.7344730922154, 47.46896021706717, 41.804479530879426, 40.31794023513794, 39.98308570044381, 42.478437423706055, 43.46006155014038, 43.088520526885986, 45.10212237494332, 45.27705717086792, 44.890344755990164, 43.28085708618164, 43.52782385689871, 42.777772767203196, 41.13987043925694, 40.21116031919207, 37.87290389197213, 40.69254193987165, 37.2128632409232, 40.03145905903408, 39.63991069793701, 35.561495304107666, 35.43782431738717, 36.15923145839146, 38.39928552082607, 36.298153741019114, 36.675138677869526, 36.59551232201712, 38.768356459481375, 38.04216200964791, 39.49849053791591, 41.42782810756138, 39.33115359715053, 47.37498583112444, 50.15799992425101, 48.46401868547712, 43.982816219329834, 46.895508016858784, 49.45576286315918, 43.97573600496565, 44.030758789607454, 39.06431497846331, 41.35366998400007, 36.8594639641898, 32.42681203569685, 24.00238527570452, 11.196018014635358, 4.007750042847224, 0.7622784535799707, 0.10711958379085575, 0.015344848922852958, 0.002798674087638834, 0.03217849527884807, 0.0754085686057806, 0.024082807458138893, 0.0375663754530251, 0.04714323227692928, 0.04873120778107217, 0.028274864656850696, 0.0685957038242902, 0.2427273653447628, 3.232495665550232, 4.034898826054164, 23.843281950269425, 24.799062252044678, 22.748548098972865, 18.432268074580602, 11.060776540211268, 4.7856026121548245, 5.625430507319314, 1.3461646224771227, 0.04014197224751115, 0.04578871013862746, 0.02458916760848037, 0.05305152506168399, 0.07527270553899662, 0.014711784232141716, 0.0626430721687419, 0.1258409417101315, 0.15460485539266042, 1.1871415270226342, 28.19444019453866, 55.08990771429879, 57.09620005743844, 43.383898871285574, 16.15604169028146, 24.481842245374406, 52.70064108712332, 45.28486347198486, 14.872535705566406, 5.907407947949, 2.0070850891726355, 0.5412329690796989, 0.2599788467798914, 0.27801590891821043, 0.14002471204314912, 0.011794201547413, 0.12149108440748282, 1.737660980650357, 1.1876678530658995, 0.06177373310284955, 0.0795159853462662, 6.359722648348127, 5.318541603428977, 5.2315614478928705, 11.896846328462873, 42.72030421665737, 61.00588539668492, 63.34258542742048, 48.67891604559762, 76.54607350485665, 75.5731450489589, 38.04606342315674, 57.32479231698172, 55.779127325330464, 2.700680111135755, 0.3303901542510305, 0.009561224225243288, 0.10027656491313662, 0.17121100931295327, 0.14266896301082202, 0.01956795758035566, 0.07741570233234338, 0.02586502718207027, 0.040840693682964356, 2.254291138478688, 5.605427512100764, 10.116401706423078, 4.483967414924076, 0.9924258611031941, 1.700906747153827, 13.07401534489223, 16.695888928004674, 26.66674324444362, 35.66997058050973, 23.637790713991436, 12.90542425428118, 3.929642302649362, 0.7762567092265401, 0.7954239664333207, 0.8590183854103088, 0.6794726454785892, 0.530911745769637, 2.143252193927765, 8.11758475644248, 16.577324867248535, 28.850245918546403, 34.38149315970284, 32.10510001863752, 39.08911657333374, 41.52048233577183, 44.97734662464687, 43.91634280341012, 48.907591683524, 50.698774746486116, 50.10887616021292, 52.81457069941929, 55.215600626809255, 54.85665321350098, 53.75054863521031, 52.504958970206125, 55.86312409809658, 57.83189269474575, 55.099715096609934, 48.01169443130493, 45.26903200149536, 43.93636056355068, 44.47983128683907, 40.70136267798287, 42.20211451394217, 40.772911752973286, 39.75157867159162, 42.54772138595581, 42.64715705599104, 41.50157281330654, 41.566826820373535, 48.800881249564036, 47.37465579169137, 44.26040022713797, 40.78326456887381, 41.9623703956604, 43.29379463195801, 43.428422927856445, 44.756578036717, 45.91523878914969, 48.18562868663243, 45.757598059517996, 45.40467473438808, 43.44262851987566, 43.43556220190865, 42.11191994803292, 42.659253869737896, 38.03293480191912, 40.323200021471294, 40.55232729230608, 42.92813525881086, 41.20110838753836, 39.76818486622402, 37.28309563228062, 38.55535248347691, 40.685614585876465, 40.44057246616909, 38.807106563023154, 40.584452288491384, 40.74686990465437, 41.07343176433018, 40.372723306928364, 45.04530348096575, 41.133950574057444, 50.07648365838187, 51.68877840042114, 50.71002388000488, 47.52476119995117, 48.61439854758126, 50.798262528010774, 46.41253178460257, 45.61514956610543, 40.37410947254726, 43.61442967823574, 39.14493840081351, 31.405819416046143, 21.562216145651682, 12.14132911818368, 3.5694620183535983, 0.6163429958479745, 0.08100340874599558, 0.1328492042209421, 0.040576037884290726, 0.051549998311592, 0.12471223941871099, 0.045436041562684944, 0.025005347062168375, 0.03373917331919074, 0.16266437220786298, 0.068911487236619, 0.16717303384627613, 0.12980720959603786, 2.6612948988165175, 5.160195197377886, 25.775129556655884, 26.99138219015939, 23.472055333001272, 21.226711954389298, 11.934374417577471, 6.723624127251761, 6.8320008260863165, 2.2310470257486616, 0.15131176209875516, 0.10055367182940245, 0.015464858018926211, 0.008804635627062192, 0.04801590973511338, 0.06813768590135233, 0.06008239635931594, 0.10614955012819596, 0.1657932735979557, 2.026112731013979, 37.807163511003765, 63.08676665169852, 63.90769631522042, 51.135621888296946, 23.158085346221924, 30.162668568747385, 58.56854765755789, 54.57544572012765, 14.492262533732823, 4.2771351763180325, 0.8419514926416534, 1.1638994770390647, 0.25491293147206306, 0.20263885147869587, 0.06452042928763799, 0.0025511886176121023, 0.02846934466755816, 5.548330690179553, 6.5035490563937595, 0.10031003704560654, 0.09103745568011488, 12.832971044949122, 19.923328910555156, 22.784593616213115, 27.115134818213328, 56.72606951849801, 80.02064527784074, 74.32006522587368, 57.230418409620015, 77.74343572344098, 85.40531158447266, 47.47539077486311, 63.278126989092144, 72.67557253156389, 1.9348444512912204, 0.3190164417028427, 0.12098577937909535, 0.3023403308221272, 0.25824757825051037, 0.23872938273208483, 0.09675662379179682, 0.3017101346382073, 0.1860939014170851, 0.12144944949873857, 3.269279428890773, 7.15889185667038, 11.887766769954137, 12.386452879224505, 1.4473997673818042, 6.293715630258832, 25.647062097276958, 14.360154696873256, 31.0775100844247, 42.67034319468907, 30.241301332201274, 15.517184359686715, 5.561406331402915, 1.5107514879533221, 1.2019763652767455, 1.2512715544019426, 0.9123061831508363, 0.6606000896011079, 2.8191846779414584, 9.315385580062866, 17.510377611432755, 33.33689750943865, 41.79454013279506, 40.837189538138254, 46.66841309411185, 45.97678245816912, 50.68750129427229, 48.101760455540244, 53.91874367850167, 53.529279776981895, 53.629139287131174, 55.308831555502756, 55.99651908874512, 58.217017446245464, 57.09289271490914, 53.847694873809814, 57.752228123801096, 59.85429791041783, 57.2174391746521, 50.488605635506765, 47.936407225472585, 45.24514756883894, 47.04299395424979, 42.37584727151053, 45.53186845779419, 44.38622862952096, 42.76095812661307, 44.48612288066319, 46.63629157202584, 44.65775033405849, 43.98805863516671, 53.03853893280029, 52.6652261189052, 46.09428344454084, 44.524938992091585, 45.425369943891255, 48.07453046526228, 48.21106604167393, 48.422089781079976, 48.05488790784563, 52.030546392713276, 48.47399629865374, 48.57543999808175, 48.64513390404837, 47.991760049547466, 46.54048980985369, 46.00257069723946, 41.781515734536306, 43.81624010631016, 41.543279375348774, 44.76178918566023, 43.16857072285244, 42.294859068734304, 40.13486909866333, 40.85564047949654, 42.832642691476, 41.83116061346871, 40.82133722305298, 43.38685532978603, 44.04908118929182, 43.28845146724156, 44.04249777112688, 47.97402129854475, 42.67110749653408, 52.36900009427752, 53.69616508483887, 54.32390008653913, 48.45026125226702, 52.763980865478516, 55.39463833400181, 50.567908900124685, 50.64674316133772, 41.92389127186367, 46.918384960719514, 46.12865965706961, 38.41590908595494, 31.013315677642822, 24.991831336702617, 11.752535717827932, 1.24104890865939, 0.19861015837107385, 0.2873323032898562, 0.08256981362189565, 0.2216684610715934, 0.2809015283627169, 0.11556632018515042, 0.05258112387465579, 0.17138353362679482, 0.31814514845609665, 0.11499390804341861, 0.3357711269387177, 0.41177649423480034, 5.60639374596732, 8.767011165618896, 30.672464847564697, 36.783791133335654, 31.650316102164133, 22.7375682081495, 15.691796064376831, 8.515507221221924, 9.101150035858154, 4.553573599883488, 0.27722821118576185, 0.2411658934184483, 0.06349967513233423, 0.16910181034888538, 0.13215390938733304, 0.18588225277406828, 0.15046906231769494, 0.32971129353557316, 0.2860070972570351, 2.282130398920604, 58.76836395263672, 71.51504966190883, 68.4459400177002, 61.005232266017366, 27.610306876046316, 35.97140080588204, 75.15846960885185, 64.72725023542131, 49.87214756011963, 14.434048788888113, 4.426521880286081, 1.4971659140927451, 0.4761076665350369, 0.4605703002640179, 0.2942986051951136, 0.11670330060379845, 0.16821710925017083], [9.408394166401454, 17.407377515520366, 3.5767615352358137, 0.10899316146969795, 0.1281442152602332, 0.9734881115811211, 1.0380982160568237, 4.389471045562199, 6.146210151059287, 28.043339456830704, 56.18244246074131, 42.444505895887104, 75.20236832754952, 75.59554604121617, 31.66105454308646, 50.059589113507954, 43.72795976911272, 7.06413015297481, 0.549347705074719, 0.12075605456318174, 0.034056174701878, 0.12997357281191008, 0.02786818808609886, 0.023487844205062305, 0.07413200674844639, 0.02392490387761167, 0.06457484779613358, 3.6877550993646895, 3.041913092136383, 2.4102734199592044, 7.505130580493382, 3.0740934567792073, 2.814284243753978, 4.271406386579786, 8.907145040375845, 30.258633613586426, 48.716259138924734, 41.21186767305647, 28.37572043282645, 8.05887942654746, 3.362142971583775, 1.4307119314159666, 0.5196066466825349, 0.8017709287149566, 2.230518094130925, 3.672127732208797, 10.325167281287056, 13.938610093934194, 17.52689000538417, 17.2867203099387, 18.958795615604945, 26.889099495751516, 35.6519330569676, 34.30856834139143, 40.56183590207781, 38.69375365121024, 44.99303913116455, 44.52881956100464, 53.13789817265102, 50.66125099999564, 50.27110270091465, 49.72866031101772, 53.18201575960432, 51.35212428229195, 53.493413175855366, 51.235255581992014, 49.74072585787092, 41.66903134754726, 42.0221665927342, 41.80009869166783, 39.25864219665527, 39.084145137241904, 38.84622492109026, 39.482891832079204, 38.13019915989467, 39.005640915461946, 37.92865971156529, 40.64145530973162, 43.46763856070382, 45.95214067186628, 47.01515252249581, 41.167823042188374, 38.55130863189697, 38.79019464765276, 36.23021425519671, 38.33757509504046, 42.33692346300398, 42.384977204459055, 43.99099424907139, 42.633090427943635, 39.89691761561802, 39.349625383104595, 35.914363043648855, 36.269127641405376, 36.06655291148594, 35.243174007960725, 42.0704322542463, 39.28664691107613, 37.68121351514544, 36.166405473436626, 35.359865529196604, 34.105187620435444, 36.34808349609375, 38.20087971006121, 36.530233996255056, 38.63438129425049, 36.34418903078352, 39.90402562277657, 38.8781692641122, 44.50094338825771, 43.391600949423655, 47.35708727155413, 50.941614287240164, 48.345666544778005, 45.85600887026106, 44.80547945840018, 42.73604883466448, 40.79232849393572, 40.518114362444194, 37.962837900434224, 34.78499242237636, 27.71900623185294, 16.620627777917043, 9.080897774015154, 3.2292942830494473, 0.7692968398332596, 0.2632355977381979, 0.134776949350323, 0.2882574993584837, 0.04114322191370385, 0.09088495493467365, 0.036737202267561636, 0.03882408421486616, 0.033698115165212324, 0.04024021394018616, 0.023758788327021257, 0.05826865868376834, 0.0720288467460445, 0.6339491339666503, 6.671419705663409, 12.774545380047389, 23.96398605619158, 32.24381038120815, 30.513913903917583, 29.478222370147705, 13.515068752425057, 11.129343969481331, 8.247453536306109, 5.7712527854102, 0.5031789881842477, 0.19553826749324799, 0.07154396562171833, 0.03544161089562944, 0.022717586518930535, 0.028498304542154074, 0.03595077000292284, 0.08761641103774309, 0.2481273641543729, 3.7002397094454085, 21.627249547413417, 46.01035615376064, 58.34908880506243, 37.146070207868306, 15.351021664483206, 29.81753764833723, 51.763384682791575, 30.06592185156686, 7.08184197970799, 0.6232442398156438, 0.30095052825553076, 0.014974852258871709, 0.1469678080507687, 0.17528939832534107, 0.10294437461665698, 0.04753964939819915, 0.18133120983839035, 3.1449407637119293, 7.819282957485743, 0.5248471083385604, 0.057584132200905254, 0.3247209127460207, 1.7147243257079805, 2.715569232191358, 3.8631406596728732, 17.05285436766488, 43.8979891368321, 67.09565489632743, 47.46277632032122, 78.40678024291992, 86.87468882969448, 32.895228317805696, 54.25452579770769, 65.97387518201555, 10.611028330666677, 0.6496771957193102, 0.08044145961425134, 0.050722714846155474, 0.12958896559263977, 0.02015203543539558, 0.06739061206047024, 0.017810887756890485, 0.08710261075092213, 0.07196488124983651, 4.851784203733716, 5.87642593043191, 4.416737948145185, 9.209222316741943, 1.1666935213974543, 1.066838571003505, 7.759082896368844, 10.418093357767377, 29.654713562556676, 49.44702550343105, 39.04926865441458, 25.154643263135636, 7.006769733769553, 2.789457244532449, 1.0634637006691523, 0.9040353298187256, 1.4986304640769958, 1.556195529443877, 4.52927531514849, 14.261923670768738, 16.61414337158203, 16.13658673422677, 18.879718167441233, 21.95113113948277, 29.041769538606914, 38.06804404939924, 39.33714294433594, 40.78698532921927, 42.60883774076189, 48.00306476865496, 49.59596014022827, 54.959458759852815, 53.73694058826992, 55.09579978670393, 53.72653913497925, 53.86819205965315, 55.0114278112139, 55.27212422234671, 54.04071235656738, 52.02086060387747, 45.31444195338658, 44.77521310533796, 43.23880311420986, 41.132512296949116, 40.318176473890034, 40.61440944671631, 40.87539073399135, 40.89696489061628, 42.75918286187308, 38.80454962594168, 42.93313796179635, 45.46740307126726, 48.73613446099417, 50.00838783809117, 43.82562017440796, 39.32436868122646, 40.821292059762136, 37.923375606536865, 40.81468432290213, 44.61278159277779, 43.42283657618931, 45.11703668321882, 44.40254299981253, 41.47890084130423, 41.630163124629426, 38.080936431884766, 38.022880758558, 38.59871619088309, 38.321948596409385, 43.98031139373779, 41.78541367394583, 41.43782656533377, 40.420401845659526, 37.61253752027239, 37.58072519302368, 38.38314485549927, 40.2877642086574, 39.39959682737078, 39.99550560542515, 38.32038525172642, 41.64637327194214, 41.228869915008545, 47.39699077606201, 47.55632339205061, 48.505207606724326, 55.04191998073033, 48.806050709315706, 48.4607287134443, 46.625476700919016, 46.926104409354075, 42.55508647646223, 43.40134579794747, 38.787547383989605, 35.53785058430263, 24.69362681252616, 15.21759193284171, 10.675080299377441, 4.822391586644309, 0.9846262910536357, 0.44563845864364077, 0.16638149560562202, 0.21820401054407867, 0.031248016815100397, 0.05577359381797058, 0.03077769705227443, 0.06134829164615699, 0.03158050236691322, 0.013303116695689303, 0.051383638488394875, 0.033566265633063655, 0.030652805896742002, 0.4333170498056071, 7.165332402501788, 15.806354488645281, 27.621377093451365, 38.26458774294172, 33.456079959869385, 30.46442535945347, 17.495788131441387, 14.93597970690046, 8.771934832845416, 6.278734879834311, 0.4704338109919003, 0.14768506027758121, 0.09129311410444123, 0.036434775817074945, 0.0218166107577937, 0.05366215229566608, 0.05266509936856372, 0.1136182461466108, 0.08633126571242299, 4.7890706317765375, 37.79434061050415, 56.2616970879691, 62.7741185597011, 44.52026285443987, 18.175398383821758, 33.471060276031494, 62.18496690477644, 38.09394693374634, 3.7409791690962653, 0.7144801127059119, 0.4119992165693215, 0.12364201327519757, 0.12191317390118327, 0.19399681234998362, 0.0835179713155542, 0.019846974572698985, 0.15871168859302998, 11.535553029605321, 30.24483449118478, 6.95206960609981, 0.15840756919767174, 0.2674698462443692, 4.963605037757328, 11.360528775623866, 21.947521550314768, 31.541232858385357, 61.84398405892508, 76.92307581220354, 60.12264428819929, 79.3801325389317, 97.14530059269497, 43.21283769607544, 62.48772076198033, 87.76660823822021, 10.100611925125122, 0.7005712847624506, 0.17470023993934902, 0.09673168084451131, 0.1828851228845971, 0.12483430786856584, 0.1328733464969056, 0.15506034237997873, 0.15740769356489182, 0.18034067084746702, 6.359816449029105, 9.820310303143092, 4.190525880881718, 11.814135840960912, 11.684320041111537, 14.855241639273506, 25.938122136252268, 23.392840657915386, 49.78361708777291, 52.06468984058925, 48.461746624537874, 34.93267290932791, 10.704092502593994, 3.738779195717403, 2.7438236474990845, 1.3575151562690735, 2.4201884993485043, 2.6969632591520036, 5.12595751455852, 16.501982075827463, 19.47687762124198, 22.494523695537023, 32.40539768763951, 33.48001650401524, 42.45009224755423, 43.42263160433088, 44.41411175046648, 46.96124839782715, 46.43415110451834, 51.16615922110421, 51.855062689099995, 58.457286153520855, 57.04185472215925, 56.648214953286306, 56.25982454844883, 56.696035930088584, 55.978842871529714, 57.77256897517613, 55.77190467289516, 53.07298115321568, 47.58915363039289, 46.7084173474993, 48.05764634268624, 41.86982039042881, 44.494189739227295, 44.27670417513166, 44.60552419934954, 44.2034284727914, 44.98057058879307, 42.06527669089181, 46.297233377184185, 47.41314533778599, 53.66989394596645, 51.02670887538365, 46.508913721357075, 40.77466269901821, 45.12544400351388, 40.04034233093262, 43.26959753036499, 48.42413255146572, 46.61961242130825, 48.16103206362043, 47.515457562037874, 43.1068047114781, 44.14492116655622, 38.933265004839214, 40.626711232321604, 40.117036546979634, 38.89282648903983, 45.079016140529085, 43.49397570746285, 42.49003049305507, 42.55015325546265, 39.53645896911621, 39.174124308994834, 40.159253801618306, 43.10463339941842, 42.530180658612935, 45.141796588897705, 41.45376225880214, 45.29380580357143, 42.78926508767264, 51.08691849027361, 49.02756970269339, 52.89815058026995, 56.62140532902309, 52.49435601915632, 50.355731759752544, 50.40082904270717, 47.936261313302175, 47.29433461597988, 48.40264524732317, 45.23735516411917, 43.53849628993443, 33.64285101209368, 27.66802556174142, 24.072807005473546, 11.693666236741201, 1.6726084713424956, 0.4757803955248424, 0.47931008040905, 0.5448028232370103, 0.11480393180889742, 0.22493872844747134, 0.13132488887224877, 0.143580859793084, 0.11374442651867867, 0.20876121866915906, 0.10484227099056755, 0.11408593319356441, 0.16637993497507914, 0.6446612477302551, 9.150530014719282, 18.943749291556223, 30.68082700456892, 41.41779143469674, 36.655576024736675, 35.8744352204459, 21.294069528579712, 20.36878660746983, 10.920632243156433, 9.641367265156337, 1.532168984413147, 1.0380658635071345, 0.19009294254439218, 0.16670445113309793, 0.12825489789247513, 0.14282991151724542, 0.18704264265085968, 0.20879175274499825, 0.4275939054787159, 7.359277469771249, 56.86062833241054, 66.03449126652309, 69.37902750287736, 55.22849995749337, 24.796069315501622, 40.709453855242046, 72.70135034833635, 62.04184096200125, 22.858840329306467, 1.6466772513730186, 0.6339832235659871, 0.14674599495317253, 0.4163437948695251, 0.3228645223592009, 0.15919730253517628, 0.13837809754269464, 0.38975746291024344], [8.131443807056971, 29.058902059282573, 18.856742211750575, 4.050153161798205, 0.0992775781612311, 0.1069237110870225, 0.7715413251093456, 1.774064330118043, 7.146164059638977, 9.896945459502083, 42.937699454171316, 40.38643905094692, 70.87434237343925, 66.38312407902309, 30.39084393637521, 52.923556668417795, 56.56038277489798, 19.200916017804825, 0.47131606936454773, 0.12520600935178144, 0.07937252268727336, 0.1309910360723734, 0.07796427753887006, 0.0506856023733105, 0.06315791061414139, 0.12325469191585268, 0.03703700278752616, 0.7123300795044217, 1.876907331602914, 1.136482753923961, 4.9760410104479105, 13.96167550768171, 11.917826414108276, 20.91601630619594, 21.419722488948278, 46.431159905024934, 54.966542448316304, 50.01404367174421, 37.75085530962263, 14.613004854747228, 6.651566530976977, 5.519188208239419, 2.898305118083954, 5.148229965141841, 6.909241778509958, 10.660959822790963, 12.80608412197658, 11.832439133099147, 6.635032423904963, 5.031481555530003, 10.205797229494367, 13.401476996285574, 28.825251511165074, 32.12139007023403, 31.7656284059797, 35.2258243560791, 42.43430246625628, 45.8235364641462, 45.215527398245676, 48.73693002973284, 51.5200275012425, 52.81515434810093, 49.26919330869402, 49.33371428080967, 51.55915975570679, 50.44928577968052, 48.29389899117606, 48.98301437922886, 42.9069675718035, 38.628496170043945, 37.89743798119681, 38.44574465070452, 37.48248808724539, 37.434371812003, 38.286398138318745, 38.877818380083355, 38.24286420004708, 40.30296686717442, 42.76879916872297, 42.07899938310896, 42.74275732040405, 41.57255908421108, 40.44600943156651, 39.53753593989781, 39.17103583472115, 40.1497278213501, 42.891240324292866, 44.74716670172555, 40.932629993983674, 42.883527823856895, 41.520350319998606, 40.91163601194109, 37.28729929242815, 37.027044091905864, 39.26457248415266, 39.967820508139475, 38.83665030343192, 38.644643783569336, 39.987595081329346, 37.917313303266255, 35.284112794058665, 36.140318461826865, 34.83801065172468, 36.50651284626552, 36.54409217834473, 36.48184674126761, 33.84631858553205, 38.10960469927107, 40.60110364641462, 43.5076254435948, 45.06345564978463, 45.65493147713797, 47.979642391204834, 43.39882707595825, 43.670508589063374, 41.7510096686227, 43.565899985177175, 35.684075423649375, 36.36004481996809, 28.680041108812603, 23.3826858656747, 13.519446117537361, 6.356824815273285, 5.6588791353361945, 1.0958259126969745, 0.3241540917328426, 0.1784128171524831, 0.47185612895659035, 0.07415937206574849, 0.04766665758298976, 0.09659886439996106, 0.02857733690845115, 0.012811741143065904, 0.07103192952594586, 0.029231882321515253, 0.014890318669910942, 0.06021561313952718, 0.11656975134142808, 0.703988929944379, 13.226277300289699, 16.960851533072336, 33.0601681300572, 51.01127345221383, 49.343261105673655, 47.89295319148472, 31.566430500575475, 30.66132688522339, 18.007708821977886, 12.795508963721138, 2.2721477917262485, 1.2734565011092593, 0.65912435735975, 0.15179923522685254, 0.07022440500025239, 0.06297970696219377, 0.027320065801697116, 0.21249808743596077, 0.07063628932727234, 5.691787106650216, 21.297524520329066, 49.26791484015328, 50.024782112666536, 35.02490677152361, 16.41269424983433, 25.03084373474121, 41.178551060812815, 12.826150519507271, 1.3106558535780226, 0.16576687858573028, 0.3358831394995962, 0.061705173924565315, 0.3813018852046558, 0.6660251127822059, 0.1555774403469903, 0.06702507846057415, 0.0286188293248415, 10.805874058178492, 27.0129702431815, 9.867800371987478, 0.3655185635600771, 0.026175875948475938, 0.060546181829912324, 0.17194755907569612, 3.581747736249651, 8.713144387517657, 27.761511836733135, 57.22451591491699, 48.223145484924316, 70.15099321092877, 77.02751418522426, 37.932620184762136, 56.54110847200666, 78.20917347499302, 33.72856051581246, 0.3106667154601642, 0.1337125450372696, 0.05130041277568255, 0.06773586424865893, 0.06703999266028404, 0.0733449671949659, 0.12632354295679502, 0.024671009109754647, 0.2793396221739905, 3.0620567883763994, 3.073642041002001, 3.405517101287842, 7.353751046316964, 12.541109357561384, 9.742197786058698, 17.14592375074114, 24.7527368749891, 49.6445871080671, 62.05411842891148, 52.58573872702462, 44.1135048866272, 16.041669130325317, 7.217743967260633, 4.157726040908268, 3.559937992266246, 5.427283951214381, 6.93285653420857, 12.236949358667646, 17.28581530707223, 14.098780836377825, 6.735353989260537, 4.530615883214133, 14.179658736501422, 20.335789612361364, 32.932967458452495, 36.19475064958845, 35.49609538487026, 39.992319856371196, 44.45046125139509, 48.85926348822457, 46.534424032483784, 53.86394671031407, 54.09579072679792, 55.26181656973702, 50.93247045789446, 54.2323818887983, 52.252332891736714, 55.47630746023995, 50.85697133200509, 51.51906170163836, 46.97310549872262, 42.469397817339214, 41.001893111637656, 39.47522449493408, 40.294483116694856, 41.13495111465454, 40.99425704138619, 42.488658223833355, 42.927211148398264, 43.145148345402305, 44.79194784164429, 45.16022321156093, 43.287308488573345, 42.682141235896516, 42.385421889168875, 43.28328895568848, 42.42369256700788, 42.70446579796927, 45.47681788035801, 46.54788964135306, 41.83283860342843, 44.809387820107595, 47.69733360835484, 43.4615797315325, 39.82296446391514, 39.152696064540315, 40.01038864680699, 41.48539045878819, 39.055101667131694, 39.43790919440133, 41.56269611631121, 40.08845860617501, 38.24813788277762, 38.219973359789165, 37.89249781199864, 38.973425592694966, 38.99851901190621, 38.90471485682896, 38.04904072625296, 41.728914397103445, 42.279809270586284, 46.89958660943167, 49.71931845801217, 49.28523669924055, 47.801744188581196, 45.95188011441912, 46.59609276907784, 45.5345504624503, 47.43007114955357, 42.11359446389334, 39.31438064575195, 31.121867384229386, 21.943436009543284, 11.170124684061323, 12.78671167578016, 5.735866478511265, 0.8304252997040749, 0.5530800276568958, 0.40209230674164637, 0.36648460743682726, 0.2412808643920081, 0.03069016942754388, 0.05849155065204416, 0.040390533195542436, 0.09432477464101144, 0.041886353466127596, 0.028059346667890037, 0.07428275008818933, 0.11945750138589314, 0.2018076732222523, 0.6134279551250594, 13.993328026362828, 19.064446449279785, 37.20811414718628, 51.149417536599294, 52.34904139382498, 51.84848621913365, 33.50759390422276, 31.977475506918772, 17.98749303817749, 13.642562985420227, 2.496825175625937, 1.3320859436477934, 0.2463474582348551, 0.10826712221439395, 0.05060316036854472, 0.05564841089238014, 0.052324909051614146, 0.10956110206565686, 0.15080424504620688, 6.712785371712275, 39.62203645706177, 57.41634178161621, 58.2062268938337, 42.54203428540911, 17.76401812689645, 28.28023133959089, 52.766885212489534, 19.18031460898263, 1.2979185027735574, 0.029850187179233347, 0.008622698336174446, 0.06458435407174484, 0.46082667793546406, 0.614532610135419, 0.13400426081248693, 0.057972953122641356, 0.03876360978132912, 14.316240344728742, 48.65075152260916, 46.43061794553484, 5.36649763584137, 0.1600383331200906, 0.11751838400959969, 0.8894884075437273, 10.13684070110321, 25.57803521837507, 45.570194721221924, 63.578921454293386, 57.16131510053362, 75.66263089861188, 83.89573206220354, 48.77726779665266, 68.42225360870361, 98.03659466334751, 39.54345580509731, 0.7860643086688859, 0.3871431489075933, 0.10860269170786653, 0.186818481822099, 0.1870590089155095, 0.12627065793744155, 0.19077677013618605, 0.1961315513721534, 0.2912935907287257, 5.3828141774450025, 6.137540102005005, 7.0308873653411865, 9.654954467500959, 23.265094552721294, 23.122890983309063, 38.96090146473476, 44.72433492115566, 56.81735495158604, 60.76678398677281, 60.028586523873464, 48.370370864868164, 28.86519844191415, 7.9592457328523905, 7.395038979394095, 6.618494842733655, 8.11777583190373, 7.848243917737689, 13.248639208929879, 19.74902466365269, 19.078388009752544, 17.154298067092896, 19.30121500151498, 27.951461689812795, 31.505081381116593, 39.89898123059954, 41.59309448514666, 40.29900639397757, 44.59458078656878, 49.89478479112898, 54.00039890834263, 49.265653201511924, 56.48104476928711, 53.188713823046, 57.67308814185006, 55.98793806348528, 57.15159109660557, 53.31956229891096, 56.31920385360718, 54.29286248343331, 55.48087590081351, 47.921513761792866, 43.14691318784441, 42.86134222575596, 43.04597323281424, 42.808824266706196, 42.95312098094395, 44.412218366350444, 45.628059319087434, 43.80385146822248, 43.37646082469395, 47.876663139888215, 48.4904774257115, 49.436241899217876, 47.02167688097273, 45.424348558698384, 45.837894916534424, 44.40461703709194, 43.9419538634164, 46.12745067051479, 50.53056928089687, 45.52731738771711, 49.29565552302769, 47.724160603114534, 45.288483483450754, 41.80991997037615, 41.50270536967686, 44.581424372536794, 44.18689176014492, 42.129794188908164, 42.63998998914446, 44.383536202566965, 41.96887043544224, 40.14268582207816, 40.665315423692974, 39.824562549591064, 41.67965514319283, 40.12758043834141, 41.44436829430716, 39.71927997044155, 44.94031272615705, 44.12631041663033, 49.92709738867623, 50.78710372107369, 52.20467519760132, 50.47390324728829, 50.01061473573957, 48.13730049133301, 47.85528353282383, 51.252080644880024, 44.32436881746565, 43.926751204899375, 36.724950313568115, 32.490943908691406, 25.65689206123352, 21.110393898827688, 12.537536246435982, 1.8023768280233656, 1.1304437922579902, 0.6382070226328713, 0.576748034783772, 0.3680054215448243, 0.21591206852878841, 0.1349475330540112, 0.11236014722713403, 0.16991252398916654, 0.2139981383723872, 0.13503966453884328, 0.09144186933657952, 0.20745108968445233, 0.44396090294633594, 1.5452197641134262, 15.48250937461853, 23.02569089617048, 45.399119649614605, 56.19276748384748, 55.68567058018276, 54.87581981931414, 40.51971244812012, 35.62892409733364, 21.976019586835587, 15.872690677642822, 6.454440057277679, 2.0815851943833485, 0.6206235204424176, 0.6566992189202989, 0.2447528195168291, 0.1442112731082099, 0.2923746055790356, 0.4232548368828637, 0.2205194705831153, 12.712430221693856, 56.10563359941755, 62.71289798191616, 69.00133732386998, 49.01793255124773, 29.59716510772705, 34.63389342171805, 67.99978923797607, 47.402198450905935, 4.478754963193621, 0.5543361316834177, 0.25145625695586205, 0.221619470843247, 0.5704902591449874, 0.6115449390241078, 0.2636589764484337, 0.16838903645319597, 0.19428559685392038], [7.805437803268433, 22.915975366319927, 16.819344520568848, 12.09224704333714, 0.7798107670886176, 0.07463642289595944, 0.23208638919251307, 0.7736404953258378, 3.088344646351678, 8.126847573689052, 22.832775899342128, 40.257275513240266, 71.18890816824776, 73.76823929377964, 32.27599096298218, 53.540171078273225, 67.61641543252128, 41.31832102366856, 0.5435695179871151, 0.10255931956427437, 0.03149845051978316, 0.035956160963646004, 0.07061724963464908, 0.02498012252285012, 0.014579530971656953, 0.10183451524270432, 0.1114813561684319, 2.8095640284674506, 1.2488744258880615, 6.28659633227757, 17.404719829559326, 35.34469761167254, 26.85093825204032, 37.8181277683803, 42.9293338230678, 52.69629151480538, 54.75475093296596, 49.02102449962071, 48.136147090366904, 24.718221698488506, 3.869120453085218, 10.62691799231938, 1.6563306876591273, 6.371064714023045, 10.348090256963458, 15.697142703192574, 13.195090310914175, 9.37911011491503, 5.001821867057255, 4.694912118571145, 10.352313024657112, 12.96492862701416, 21.356638056891306, 29.06749176979065, 36.379996572222026, 37.86530256271362, 38.34919943128313, 41.16707958493914, 42.55876554761614, 43.363071646009175, 48.72398553575788, 49.98417336600167, 49.128676414489746, 49.98812689099993, 50.16632039206368, 49.52879190444946, 49.867096219744, 51.061804226466585, 43.256267411368235, 38.98548419134957, 38.429704734257285, 38.00614949635097, 36.88378265925816, 38.77012825012207, 38.06869370596749, 37.71956409726824, 40.61429827553885, 41.96340915134975, 41.60890858513968, 41.06503486633301, 39.681777068546836, 37.39563907895769, 36.902431624276296, 39.128773416791645, 37.4827173777989, 39.83010026386806, 41.78428111757551, 40.312826360974995, 36.46805804116385, 40.100023882729666, 41.34286206109183, 39.777571882520405, 38.405556270054404, 37.42987632751465, 37.44877542768206, 36.18040609359741, 37.595278194972444, 37.84785563605172, 38.3037234715053, 39.08671249662127, 35.35839251109532, 36.82689428329468, 36.122767312186106, 34.264429909842356, 35.851436683109824, 36.19115148271833, 34.88553980418614, 36.088988644736155, 40.92447280883789, 43.14335571016584, 47.237227371760774, 44.9555709702628, 44.864417552948, 44.56039217540196, 44.73184592383248, 43.64814581189837, 38.90688269478934, 38.16598238263811, 26.850295543670654, 19.633170400347026, 10.606043866702489, 5.824468169893537, 7.095977221216474, 1.5659003172601973, 0.6394348996026176, 0.17363576777279377, 0.15106887370347977, 0.13727136621517794, 0.17501541945551122, 0.022468810136030828, 0.021290123562461565, 0.036130944799099646, 0.05214896831395371, 0.03645263146609068, 0.04537441022694111, 0.04219922596322639, 0.0250372144593192, 0.15708583726414613, 1.6621456784861428, 15.108698027474539, 25.852487325668335, 44.29054846082415, 46.83747666222708, 38.90699734006609, 39.31382131576538, 41.291264738355366, 36.62628589357649, 28.74043311391558, 22.614421810422623, 12.745003376688276, 4.707274700914111, 3.4434861838817596, 0.2812405244580337, 0.02363911340944469, 0.009498817663240646, 0.048258194234222174, 0.06431964399026972, 0.24262447229453496, 6.064886263438633, 28.746749026434763, 52.96802861349923, 45.874487604413716, 31.969401700156077, 19.888582706451416, 22.694445950644358, 34.524410656520296, 8.668541295187813, 0.6703594859157289, 0.20266786563609326, 0.16891286548759255, 0.07773871892797095, 5.726575868470328, 14.938887528010778, 1.7396287322044373, 0.07692962020103421, 0.28755727836063927, 11.030722107206072, 43.725493158612935, 33.17819023132324, 13.587139810834612, 0.43978864539946827, 0.11119266665939774, 0.6712464126093047, 2.4566452630928586, 9.042000889778137, 23.109639031546457, 38.977580615452354, 50.707459994724815, 73.0172015598842, 78.82036481584821, 40.54960012435913, 62.17940139770508, 77.36669744764055, 59.76112256731306, 0.9371534841401237, 0.06684262039405958, 0.028372865469594086, 0.07586338384343044, 0.10899791800017868, 0.02263778231904975, 0.021690087725541422, 0.13847602371658596, 0.45821980067661827, 4.124078954969134, 2.469166568347386, 3.969394249575479, 17.069007192339214, 35.55474165507725, 27.684838465281896, 40.45810277121407, 46.02132388523647, 58.77975899832589, 63.46549211229597, 55.53427628108433, 54.799462590898784, 30.677505765642437, 9.174524750028338, 10.48067491395133, 6.438625088759831, 8.273729886327471, 14.238410098212105, 19.612341438020977, 16.883608409336635, 9.724479011126927, 4.204560807773045, 5.050405408654894, 7.517108406339373, 17.477404935019358, 29.326133251190186, 37.283477783203125, 41.24803652082171, 43.55658939906529, 40.59814371381487, 43.880660329546245, 45.59039660862514, 43.90781388963972, 48.80552959442139, 50.358365127018516, 55.66892889567784, 50.91794524874006, 53.588054588862825, 51.4052015713283, 53.34958893912179, 52.76797260556902, 47.774343967437744, 43.16788632529122, 40.71505410330636, 40.89384167534964, 39.92932748794556, 41.384853499276296, 41.777527468545095, 41.00212240219116, 42.50397552762713, 43.74992649895804, 44.70237166540963, 44.60597235815865, 43.016495500292095, 40.99452454703194, 39.85341147014073, 40.49893038613455, 39.9118458202907, 42.440781661442344, 41.36011096409389, 43.986384119306294, 38.42297887802124, 41.163261549813406, 41.91046387808663, 39.684726578848704, 39.76282433101109, 39.61654043197632, 41.250718525477815, 38.2324731690543, 40.56126962389265, 39.66723101479666, 38.696237632206504, 40.453423159463064, 37.42768069675991, 38.97848735536848, 38.805393832070486, 35.92697402409145, 36.97650636945452, 38.683359146118164, 37.451585974012104, 38.81641020093645, 42.67218099321638, 46.4460255759103, 50.131155558994834, 48.604653699057444, 48.546222823006765, 51.0219841003418, 48.230329922267366, 45.60398728506905, 40.94561965124947, 37.72956255504063, 30.37856994356428, 19.412330593381608, 11.57628858089447, 10.953584943498884, 8.703609722001211, 2.6603130315031325, 0.7219507289784295, 0.3253664438213621, 0.4604507695351328, 0.316476115158626, 0.20375315525702067, 0.027396321263430373, 0.036611435801855156, 0.029092782642692327, 0.0221981035013284, 0.06094155739992857, 0.04005952345739518, 0.02318199454540653, 0.0219873759695994, 0.184119866628732, 2.4882923534938266, 20.3042083127158, 31.82602562223162, 50.105843271527974, 53.208585671016145, 47.95541402271816, 44.83195209503174, 45.42239611489432, 39.53983926773071, 30.52943617956979, 25.369045564106532, 13.190029416765485, 4.516770728996821, 2.6955740536962236, 0.6287213744861739, 0.027903712787000195, 0.09090484958142042, 0.05616981416408505, 0.11472277902066708, 0.2765021515744073, 13.604674458503723, 46.88575274603707, 59.85666029793875, 55.92681128638131, 38.58934654508318, 19.94758333478655, 25.92474685396467, 45.74862446103777, 17.72382800919669, 1.1790257053715842, 0.150483691532697, 0.07373558623450142, 0.5637388357094356, 17.381809881755284, 27.845211574009486, 1.9454111414296287, 0.01693849019440157, 0.049408694463116784, 14.452819347381592, 56.66152075358799, 51.175202301570344, 32.517902919224326, 1.2887476405927112, 0.2663869314960071, 0.6238039497818265, 3.1654666108744483, 15.111890724727086, 46.903508867536274, 44.54564462389265, 55.18939202172415, 76.1468369620187, 88.4964678628104, 49.774824142456055, 69.94625064304897, 92.36305005209786, 73.69715922219413, 0.8792653275387627, 0.21727312835199492, 0.1364167242177895, 0.20926769077777863, 0.22551815664129599, 0.08769138237195355, 0.14282050702188695, 0.2529315820762089, 1.4261970136846815, 7.900155646460397, 3.6464506643159047, 8.585270609174456, 25.878350257873535, 42.40247971670968, 41.20029544830322, 46.70513432366507, 56.13386760439192, 58.10222625732422, 62.661363192967, 57.80424233845302, 62.48334339686802, 46.01837090083531, 19.085468224116735, 13.677936264446803, 9.170773591314044, 10.924477202551705, 15.412139756338936, 22.845911468778336, 22.09884636742728, 15.163802453449794, 14.37069250856127, 11.063429015023367, 20.997190373284475, 31.969700472695486, 39.32791573660714, 40.71535634994507, 45.7186256136213, 47.12985685893467, 45.12268556867327, 48.783111231667654, 50.48960617610386, 47.93790456226894, 53.81770992279053, 51.832585266658235, 54.63453320094517, 52.30911357062203, 56.31550393785749, 53.54723392214094, 54.72319916316441, 54.72308799198696, 47.18598093305315, 43.536675861903596, 44.28745303835188, 41.579371792929514, 42.102366174970356, 43.09383242470877, 43.697676045554026, 44.32058899743216, 45.84044143131801, 46.39157254355294, 46.97540882655552, 47.82098375047956, 46.19033186776297, 42.175947598048616, 42.92189577647618, 42.99699190684727, 43.348466532570974, 45.5669846534729, 46.29956102371216, 47.09435851233346, 42.60927200317383, 44.94174058096749, 46.164293493543354, 43.857182366507395, 43.57538080215454, 42.87179926463536, 44.18081556047712, 40.861699308667866, 43.764587197984966, 40.38013356072562, 41.95592246736799, 43.41595785958426, 39.15407875605992, 41.89438227244786, 41.01656423296247, 36.64270796094622, 40.50647265570504, 41.29199429920742, 40.64688532693045, 41.06937401635306, 46.32932710647583, 49.012627601623535, 52.454191957201274, 50.84760863440377, 50.44001688276018, 49.1931209564209, 51.00583301271711, 51.62224245071411, 47.22830935886928, 48.17193726130894, 38.70302602222988, 30.47232893535069, 24.166875192097255, 20.535513843808854, 15.572038650512695, 3.548435249498912, 1.0883328233446394, 1.0119565959487642, 0.787640138396195, 0.5300724250929696, 0.5336024356739861, 0.11466222655560289, 0.08623140571372849, 0.10921862508569445, 0.13844155413763864, 0.2080324042056288, 0.1573077453566449, 0.10343236343136855, 0.08629666042647191, 0.35264629285250393, 4.909264045102256, 21.29414769581386, 36.150490624564036, 55.60646111624581, 54.362490381513325, 54.01532711301531, 49.68494571958269, 54.71573679787772, 48.19383798326765, 36.021424361637656, 27.919656310762676, 18.72180645806449, 7.340380975178309, 5.298992412430899, 0.8286306017211506, 0.13352417014539242, 0.17457272963864462, 0.141475840604731, 0.12793372012674809, 0.35834150867802755, 23.37483787536621, 61.7588894707816, 66.36202239990234, 67.34246185847691, 45.48961993626186, 33.77860491616385, 30.639339310782297, 60.589875902448384, 33.090305941445486, 1.4166399836540222, 0.23700728799615586, 0.21686340176633426, 0.26559991229857716, 11.305684907095772, 23.74299338885716, 2.0760539940425327, 0.16826616733201913, 0.4064353108406067], [2.0343420037201474, 11.83884276662554, 3.933874189853668, 6.932206443377903, 2.485386920826776, 1.113464131951332, 1.4459175212042672, 1.827463516167232, 2.6325677888734, 8.49572309425899, 30.33362204687936, 39.727662972041536, 61.756846700395855, 56.601213863917756, 28.919602836881364, 50.56348984582083, 69.95602675846645, 53.90985345840454, 6.132292475019183, 0.2775263866143567, 0.25039681951914516, 0.22025087928133352, 0.15531870137367929, 0.06325908018542187, 0.07165228016674519, 0.05373893192570124, 0.8194998545306069, 1.469846031495503, 7.163275735718863, 8.272728477205549, 17.40927263668605, 30.012337344033376, 30.902380738939556, 49.48554631641933, 56.38870668411255, 50.688133580344065, 52.521412304469514, 52.381989751543315, 56.51359360558646, 39.97293438230242, 5.192683236939566, 12.842986873217992, 3.2464522080762044, 6.373695909976959, 9.308565054621015, 15.270811659949166, 11.960624711854116, 6.354487180709839, 3.7212267432894026, 6.089536734989711, 4.216831760747092, 8.834406954901558, 24.09818008967808, 39.44047655378069, 44.556942394801546, 43.300489221300396, 38.148017815181184, 40.50396088191441, 38.21237203053066, 35.96349375588553, 35.27529205594744, 43.36531591415405, 51.64038072313581, 48.487454959324424, 51.00793136869158, 49.65599257605416, 48.566622734069824, 52.15943200247628, 45.381703989846365, 41.72735800061907, 36.98615741729736, 39.69417265483311, 35.90115451812744, 38.46754462378365, 36.803131444113596, 38.98013060433524, 40.96150323322841, 41.44000482559204, 41.53195381164551, 41.495531354631694, 38.44159657614571, 38.90378727231707, 37.86750514166695, 37.974733216421946, 38.8364383833749, 39.12700162615095, 36.19523702348982, 40.05843196596418, 37.1898056438991, 36.03150272369385, 36.89280489512852, 37.7119836126055, 38.73950753893171, 35.92784949711391, 34.892536640167236, 37.787166595458984, 37.90518522262573, 38.25978306361607, 37.42903559548514, 37.97823510851179, 37.06055525371006, 36.42304066249302, 35.75088930130005, 35.76905536651611, 35.28626673562186, 35.839457988739014, 35.55995627811977, 40.763417039598735, 40.780943870544434, 45.01874399185181, 46.30440739222935, 46.21284750529698, 44.765054838997976, 51.05231646129063, 38.786063943590435, 32.480507714407786, 27.09215886252267, 23.183976071221487, 18.559336730412074, 7.581420063972473, 5.226598262786865, 5.017469644546509, 2.874102153948375, 1.8238309110913957, 0.9992092571088246, 0.22264329876218522, 0.19979641400277615, 0.28781789009060177, 0.2691684908100537, 0.10993777042520897, 0.012348072719760239, 0.028599911768521582, 0.06386438091950757, 0.06483500490763358, 0.0314987796092672, 0.09279851868216481, 0.14113251545599528, 0.34977052573646816, 1.6033447022948946, 25.458906616483414, 42.86742189952305, 48.903749329703196, 39.035097803388325, 43.79769536427089, 49.407361711774556, 51.28772142955235, 44.44440589632307, 53.03331388745989, 26.10946123940604, 24.7207647391728, 16.523490224565776, 11.803267989839826, 4.223755640642984, 1.5001434343201774, 0.45900049592767445, 0.7523791162031037, 0.13476089521178178, 1.765106582215854, 9.405591436794825, 35.187581471034456, 51.7808871950422, 41.48378542491368, 25.2836400440761, 21.577300684792654, 19.205845764705114, 22.368453843253, 11.829871773719788, 1.7909661488873618, 0.05049649127093809, 0.22034835762211255, 27.179035663604736, 69.63173348563058, 67.67033345358712, 20.635593959263392, 0.4317409758056913, 0.11210872964667422, 5.503483542374202, 38.25546475819179, 22.75177206311907, 16.448574747358048, 4.746850771563394, 0.5860674689923013, 1.7851940414735248, 1.5503205018384116, 5.579997539520264, 19.44391015597752, 48.27278341565813, 38.62363243103027, 66.02305453164237, 61.172517095293315, 35.28323037283761, 66.4278426851545, 74.97939368656704, 72.91267980848039, 10.816780124391828, 0.27335282628025326, 0.18018496063138756, 0.03358880995905825, 0.15440547466278076, 0.026425659955878342, 0.16045019030570984, 0.053549186393086395, 0.9619699524981635, 2.0762841531208585, 5.320473636899676, 12.151285886764526, 23.993993588856288, 36.842774391174316, 35.026324204036165, 59.70250061580113, 61.17189870561872, 59.12944098881313, 60.007151331220356, 58.59731319972447, 63.781114033290315, 44.2025008882795, 14.839309419904437, 15.035054070608956, 5.101787771497454, 9.837028537477766, 19.37411376408168, 23.466687849589757, 16.526444946016582, 7.116286371435438, 2.737366382564817, 8.89377670628684, 8.869120155061994, 18.526892117091588, 32.67029775891985, 45.200029441288535, 49.24335295813424, 47.90240274156843, 42.466347558157786, 43.675747530800955, 41.74611813681466, 37.59805747440883, 35.688022000449045, 44.7312205859593, 49.437468256269185, 47.621876171657014, 50.06398037501744, 54.46467406409127, 50.642178194863455, 53.84259837014334, 47.63185725893293, 45.494553157261436, 40.310880865369526, 40.477432659694124, 39.73623704910278, 40.928857122148784, 39.204859665461946, 42.978113651275635, 44.59672083173479, 44.32615450450352, 44.02654470716204, 43.91289302280971, 40.13130814688546, 42.25324283327375, 41.86822577885219, 40.38739095415388, 40.74263845171247, 42.74491821016584, 41.735998085566926, 43.659891741616384, 39.4389305795942, 39.48328440529959, 40.31552573612758, 39.88818025588989, 40.50636495862688, 38.32628427233015, 37.45460149220058, 41.670810086386545, 39.98695584705898, 39.78123705727713, 39.32944086619786, 41.01413236345564, 38.9457231249128, 38.50215360096523, 38.29643481118338, 38.85304110390799, 38.76661246163504, 37.21352679388863, 38.681712423052105, 41.30635622569493, 44.85425928660801, 47.53909533364432, 48.822594370160786, 48.39683655330113, 46.76381880896432, 53.24893386023385, 40.68410682678223, 34.49506493977138, 30.579685551779612, 23.440543515341624, 17.133976323263987, 10.914332832608904, 10.313723598207746, 8.196319137300764, 3.484203061887196, 2.7755506421838487, 1.4057504194123405, 0.1766970327922276, 0.1991698004837547, 0.145973143566932, 0.31655430953417507, 0.008938698879709201, 0.010139917056741459, 0.05897883379033633, 0.037520211323031356, 0.038947316352277994, 0.055080236201839786, 0.06338041581745658, 0.16258361296994345, 0.9100158289074898, 4.453934260777064, 31.436221258980886, 51.668507031032014, 55.13073532921927, 47.3505733353751, 51.279394013541086, 55.72324991226196, 58.505214827401296, 49.397206919533865, 59.998695373535156, 29.239305087498256, 29.67837217875889, 18.160965238298687, 14.204396060534886, 5.732270351478031, 1.587549926979201, 0.3943751108433519, 0.8344662742955344, 0.08193720185330935, 2.0087352863379886, 30.544475555419922, 50.46605525697981, 57.131312779017854, 56.01530701773507, 31.918290751320974, 25.18782091140747, 27.741770267486572, 36.45975146974836, 18.41407595361982, 2.8219578777040755, 0.05596799410081335, 0.44133320823311806, 45.06212159565517, 90.77579661778041, 80.64773409707206, 26.164741107395717, 0.5682763350861413, 0.11789425169782979, 3.6535326157297408, 54.41222906112671, 33.473384448460166, 29.127121210098267, 6.44364081961768, 1.8969993506159102, 3.942151665687561, 2.9108718037605286, 9.149946366037641, 36.80813067299979, 60.29391738346645, 52.571116243089946, 70.76317814418248, 68.25613607679094, 46.241032872881206, 71.13743591308594, 86.34471498216901, 86.928544316973, 14.821238892418997, 0.5052778869867325, 0.48342498817614143, 0.3891529424914292, 0.6884275706751006, 0.10489763266273908, 0.19974614812859467, 0.4144152083567211, 2.460423780339105, 4.909680068492889, 11.149065562656947, 15.831463541303362, 26.288867201123917, 37.4510474886213, 40.072317940848215, 56.73228815623692, 59.33209214891706, 60.328797340393066, 57.663079261779785, 61.07450580596924, 61.34504781450544, 57.97332327706473, 35.009002344948904, 19.352621248790197, 14.64990326336452, 12.46496752330235, 24.74110906464713, 30.014154297964915, 21.36584963117327, 11.094874824796404, 13.585209948675972, 17.496482951300486, 12.800271953855242, 23.171293871743337, 38.50185135432652, 47.983432633536204, 55.129418645586284, 50.60091979163033, 48.34371062687465, 45.70607369286673, 47.31719766344343, 39.50583825792585, 38.73988968985421, 47.599256311144146, 54.30329520361764, 50.82591635840279, 53.31149891444615, 54.04275165285383, 51.474263191223145, 55.81107514245169, 49.01663671221052, 46.101134368351524, 42.77476419721331, 43.35259028843471, 40.65475763593401, 43.599643911634175, 42.965353284563335, 44.87283876964024, 48.78008876528059, 46.4211996623448, 43.89656475612095, 48.40751940863473, 45.340320519038606, 45.12690312521798, 45.18673753738403, 42.61355904170445, 45.635417461395264, 44.12268693106515, 42.107559953417095, 44.78675058909825, 44.28456606183733, 41.13833836146763, 41.2682557787214, 41.1478921345302, 43.7417345728193, 41.502788748059956, 38.611810071127756, 43.49737685067313, 43.945806639535085, 41.18318550927298, 41.38646895544869, 42.3971643447876, 41.55312497275216, 38.782874720437185, 40.24330268587385, 40.9871038709368, 41.24705682482038, 39.908361298697336, 40.905723094940186, 47.786485944475444, 45.26372357777187, 48.65062992913382, 52.252530915396555, 52.39535461153303, 49.72778483799526, 55.72786351612636, 48.62588391985212, 42.87454380307879, 36.35620594024658, 30.0049409866333, 27.860605307987758, 20.653063467570714, 20.91617958886283, 16.4759749685015, 6.104737656457083, 3.377351926905768, 1.4722744269030434, 0.5386113811816488, 0.5079913756677082, 0.43236775217311724, 0.3900884251509394, 0.16823699032621725, 0.07765481807291508, 0.15358888490923814, 0.3093049228191376, 0.1956680305302143, 0.12315114747200694, 0.28207601819719585, 0.23980404649462017, 1.324525760752814, 8.515738248825073, 38.55916704450335, 54.78695930753435, 55.97966970716204, 52.746794496263774, 56.85623359680176, 62.43162795475551, 59.84790556771414, 52.63134322847639, 58.20076213564192, 32.75451339994158, 28.938550574438914, 25.039864233561925, 15.241269656590053, 10.09742443902152, 1.489411290202822, 0.8004457769649369, 1.4846388548612595, 0.23185750576002256, 3.2731695515768866, 40.85183981486729, 63.71831621442522, 64.47691358838762, 63.11656747545515, 39.80465248652867, 35.388825620923726, 30.470619678497314, 47.66216877528599, 32.64460679462978, 3.4690835646220615, 0.08856424303459269, 0.15856925052191528, 46.0764856338501, 107.60061631883893, 92.16959830692836, 31.647352695465088, 0.5889334380626678, 0.25153572697724613], [0.14286529033311776, 7.252647374357496, 3.870359403746469, 2.743223931108202, 2.983794233628682, 1.2324938305786677, 2.8050878686564307, 1.6785398444959094, 1.8793064142976488, 6.81036022731236, 23.208765506744385, 53.920247963496614, 60.830109868730815, 44.15605912889753, 30.645714282989502, 46.28702647345406, 73.94433443886894, 62.03448281969343, 33.34490530831473, 0.04370069843051689, 0.08414181641169957, 0.04876994534528681, 0.08915359141038996, 0.072786159680358, 0.06959566088127238, 0.2405009019587721, 1.9407779957566942, 0.9646662878138679, 5.4989567909921915, 17.72848503930228, 20.520682913916453, 19.80440875462123, 26.264558928353445, 53.06867674418858, 57.52407707486834, 52.11440767560686, 54.12047072819301, 54.14226027897426, 54.25104475021362, 45.907095500401084, 19.8696106501988, 10.736213156155177, 13.60413076196398, 4.380257734230586, 9.017477222851344, 17.709618943078176, 19.504686049052648, 13.26912944657462, 7.565039685794285, 6.21481362410954, 20.12569693156651, 23.58425658089774, 43.99668482371739, 49.17074080875942, 47.66985348292759, 39.85462393079485, 39.62694188526699, 36.14346946988787, 35.78553649357387, 36.539339610508506, 35.85812085015433, 35.97058091844831, 35.947189807891846, 35.39695501327515, 38.6576577595302, 50.7213077545166, 49.309895856039866, 48.64906658445086, 47.07625150680542, 42.43192965643746, 39.45078420639038, 35.45141499383109, 38.56141826084682, 38.15967689241682, 37.28982843671526, 39.169368267059326, 41.73540054048811, 42.428170680999756, 38.964229651859824, 38.194199017116, 35.15614782060896, 39.88151693344116, 37.95997176851545, 38.37655101503645, 38.96626894814627, 40.308827672685894, 39.96095221383231, 38.97921691622053, 37.29559891564505, 38.39021464756557, 39.719363348824636, 37.79160302025931, 34.99834728240967, 37.512271540505544, 38.71859346117292, 37.63402482441494, 37.60374110085623, 38.254832472120015, 37.38351794651577, 36.86268792833601, 37.378397124154226, 37.21544797079903, 36.78242581231253, 36.83454772404262, 36.13545472281319, 34.6715943472726, 36.46000507899693, 36.7584684235709, 42.313681738717214, 44.393909863063264, 47.67870201383318, 40.629414081573486, 42.40147222791399, 40.12761170523507, 27.04113824026925, 21.45134547778538, 22.720852579389298, 13.448300038065229, 5.536204780851092, 1.648851169007165, 5.807302211012159, 5.57075035572052, 4.796037937913622, 3.5177604726382663, 2.8202338559286932, 2.1909824098859514, 2.103104199681963, 0.6020649362887655, 0.09929583075323276, 0.04502738027700356, 0.08112036104180984, 0.027201719116419554, 0.08617928743894611, 0.05551691080576607, 0.043552285858563015, 0.08520216987069164, 0.21200785945568765, 1.0060488900968005, 2.6793749800750186, 29.5750663621085, 50.085700443812776, 47.09338229043143, 41.29795585359846, 48.14356081826346, 52.18452194758824, 54.36129181725638, 46.03012030465262, 48.78625181743077, 35.635865347726, 37.78280312674386, 45.58224984577724, 38.877321583884104, 17.895611797060283, 6.927668835435595, 0.35324837054525104, 0.5481970725314957, 0.20377501765532152, 4.127702874796731, 28.789885180337087, 44.283916405269075, 51.16024283000401, 33.60428850991385, 26.042838437216624, 23.995808805738175, 24.75785074915205, 25.267428159713745, 12.527840035302297, 0.43983554573995726, 0.2920147920293467, 21.042662858963013, 41.5626995904105, 32.583323683057515, 27.001498767307826, 12.068875908851624, 0.3634959320936884, 0.05077794420399836, 0.29246235372764723, 21.372698817934307, 13.08090535231999, 0.9345573548759732, 7.489966137068612, 1.6419085072619575, 1.4472313821315765, 3.2388827971049716, 5.400585063866206, 13.875658546175275, 47.79184995378767, 47.345438616616384, 64.11905356815883, 53.34122330801827, 37.6143023627145, 59.288026673453196, 76.94499737875802, 72.74961948394775, 47.21155377796718, 0.16427746707839624, 0.009659826389646955, 0.023921124437557797, 0.059769571359668455, 0.070307932661048, 0.021030889258586934, 0.15216777473688126, 2.35312340089253, 2.913286519902093, 8.671131236212593, 17.861649002347672, 25.101727519716533, 25.04654666355678, 35.94834668295724, 61.636038371494834, 62.46178313664028, 60.19855335780552, 60.76021099090576, 61.33809266771589, 60.54312147412981, 56.37232978003365, 27.331795283726283, 17.373272282736643, 17.964301688330515, 8.510918804577418, 14.746550968715123, 27.761850561414445, 29.57477453776768, 16.984258277075632, 10.374686224120003, 17.854223115103586, 28.884040219443186, 38.200695582798545, 47.519824504852295, 51.91969830649239, 50.527501651218955, 44.76608664648873, 43.65246411732265, 40.8499881199428, 39.08243588038853, 39.90084682192121, 37.48992960793631, 36.90922001429966, 35.40829447337559, 37.03133807863508, 41.212774412972585, 51.194910866873606, 52.68880830492292, 52.38946253912789, 49.158619676317485, 43.66624239512852, 41.821784019470215, 38.96200622831072, 40.64881692613874, 41.66684266499111, 41.82521990367344, 43.427967820848735, 43.68288333075387, 43.171099867139546, 42.58874355043684, 41.99739279065813, 40.09994397844587, 43.3569016456604, 40.14398513521467, 40.780627727508545, 39.39545917510986, 40.708217075892854, 40.79946081978934, 42.05057430267334, 40.00639690671648, 39.64880786623274, 43.77316127504621, 39.61005081449236, 38.02816138948713, 41.37651913506644, 42.66328729901995, 40.0186813218253, 39.08655268805367, 40.16821002960205, 40.048058305467876, 39.51550667626517, 39.0395689691816, 40.660409995487754, 39.058978761945454, 39.579596860068186, 38.960286549159456, 38.23582220077515, 39.581028188977925, 40.0591094153268, 43.47863755907331, 46.160965306418284, 49.26665374210903, 43.56518432072231, 45.374192987169536, 42.36368097577776, 31.282367297581263, 26.560550451278687, 24.605627877371653, 13.652064646993365, 8.225895881652832, 8.649934019361224, 10.86781290599278, 7.265191912651062, 6.428363902228219, 5.488468485219138, 3.4861439977373396, 2.145616101367133, 2.5743903049400876, 0.3698333134608609, 0.017017481848597527, 0.10184430650302342, 0.029382788509662663, 0.06030205171555281, 0.041873257740267684, 0.030352136851953607, 0.10452495408909661, 0.024452878760972192, 0.13354344053992204, 1.6293422558477946, 5.393855733530862, 36.93804809025356, 53.99487509046282, 51.00358527047293, 49.71139056341988, 54.08829014641898, 59.159200123378206, 63.14891133989607, 56.86247655323574, 54.93467106137957, 41.54284858703613, 40.00304787499564, 51.94075829642159, 42.114994525909424, 23.005902426583425, 11.53343209198543, 0.22148441523313522, 0.8753681480884552, 0.3497950615627425, 13.102991938591003, 47.18745742525373, 56.188438756125315, 60.56170790536063, 45.68548618044172, 29.52706125804356, 32.9680940764291, 28.29581788608006, 36.478671414511545, 23.654784270695277, 0.204792195931077, 0.9131988095385688, 36.43561690194266, 59.03980227879116, 47.350618498665945, 33.55986172812325, 21.100805384772165, 0.5030734624181474, 0.06156747202788081, 0.27743709140590256, 39.85407154900687, 44.21554265703474, 18.683309963771276, 15.667499950953893, 3.7509176986558095, 4.717782982758113, 8.680400133132935, 11.910226821899414, 33.9278244291033, 59.08228356497628, 64.19237790788922, 74.02346747262138, 59.6006052834647, 48.826777185712544, 65.08920274462018, 86.46502998897007, 78.43706049237932, 56.47922434125628, 0.2004716649119343, 0.13750486368579523, 0.13518833156142915, 0.1298053368393864, 0.22867322234170778, 0.09941628428974322, 0.330195034721068, 3.5570833683013916, 3.769820272922516, 9.789372580392019, 29.564765657697404, 32.2746638570513, 29.609411307743617, 42.58214970997402, 62.449672426496235, 57.79953840800694, 60.69663497379848, 57.87807042258126, 62.704525402614046, 56.64111736842564, 58.64673573630196, 47.37066057750157, 27.149363381522043, 27.957635164260864, 16.841849735804967, 15.085635219301496, 36.63794844491141, 35.18453468595232, 19.491745029176982, 17.184305599757604, 23.469364643096924, 36.758298192705425, 40.964522225516184, 54.33134855542864, 56.34776789801461, 56.24892977305821, 49.58473532540457, 48.95313712528774, 45.20572349003383, 44.183261326381135, 43.86334541865757, 40.06122861589704, 38.3099490574428, 38.113037109375, 37.6906943321228, 43.21164608001709, 53.82475887026106, 51.531606674194336, 52.5977452141898, 51.06776925495693, 45.18600102833339, 44.15804283959525, 41.337164538247244, 43.75224372318813, 44.97328887666975, 44.476412773132324, 45.3917441368103, 47.252912930079866, 48.848222800663535, 43.03995956693377, 44.54462323869978, 42.424918924059185, 47.398922375270296, 43.01262535367693, 42.64227942058018, 44.19290542602539, 45.98718043736049, 44.50105108533587, 45.95307520457676, 43.254912512642996, 41.96886696134295, 46.804629053388325, 41.18997737339565, 41.07858385358538, 42.95518807002476, 45.530860968998496, 42.0562162399292, 41.72751086098807, 41.215543270111084, 42.1355368750436, 40.61422879355294, 43.38388497488839, 42.49395275115967, 40.43197407041277, 43.01355988638741, 41.22311680657523, 39.65881674630301, 42.01736191340855, 42.445388317108154, 47.12337071555001, 48.4472005707877, 52.3254383632115, 48.15355927603585, 48.32313701084682, 46.068345819200786, 35.05980409894671, 31.54628767286028, 34.470447472163606, 28.538334335599625, 19.43618028504508, 19.531834397997173, 17.200743300574167, 9.543761576925005, 6.5419973475592474, 5.653998894350869, 3.876436471939087, 2.9412378200462888, 2.5625575227396826, 0.4952553276504789, 0.23938948873962673, 0.14524336558367523, 0.24130955285259656, 0.16706369471337112, 0.17392991270337785, 0.17463883252016135, 0.16372395892228397, 0.3167915253766945, 0.19742390273937158, 2.3272094428539276, 10.563453146389552, 42.35664939880371, 55.20584535598755, 55.039870262145996, 52.48462159293038, 53.569447313036235, 55.019862924303325, 57.751265798296245, 54.81581865038191, 54.32216303689139, 46.830799443381174, 42.10573952538626, 54.961748191288535, 41.544151374271934, 26.61942948613848, 10.134880440575735, 0.6897087533559118, 1.9009040210928236, 0.4269522013408797, 14.232204488345555, 58.63554913657052, 65.49428272247314, 69.18573556627545, 50.55627761568342, 38.5200834274292, 39.05142954417637, 33.336303438459126, 44.95767627443586, 34.507175649915425, 0.6309637970158032, 0.4016444736293384, 41.20626742499215, 91.44359493255615, 58.198684624263215, 51.301405906677246, 31.596120153154644, 0.6346832002912248, 0.19694848039320537], [0.029061702346163135, 5.232307510716574, 13.221716676439558, 2.7081789544650485, 4.135847466332572, 2.0450758848871504, 7.546623485428946, 13.292130589485168, 5.558369534356253, 9.702263883181981, 33.65570517948696, 47.844284534454346, 51.92673683166504, 32.67221893583025, 29.087667601449148, 44.41398320879255, 78.50579902103969, 66.11926623753139, 56.038722446986604, 5.172629867281232, 0.22844029484050615, 0.04059316750083651, 0.0940295033422964, 0.021604249653007303, 0.08270019412572895, 0.051948172838560173, 2.9230778345039914, 2.8987589223044257, 6.9195602876799445, 15.676188673291888, 18.07646472113473, 17.729110377175466, 34.81096478870937, 54.928289140973774, 57.41803019387381, 55.5264630317688, 52.136002676827566, 52.82767847606114, 54.54766682216099, 49.62862709590367, 39.23845420564924, 12.656615342412676, 21.39978289604187, 8.46069027696337, 5.5665397473743985, 16.819386209760392, 35.40249620165144, 31.291205406188965, 20.937312534877233, 24.021041188921245, 38.06676210675921, 42.14881140845162, 52.24502338681902, 50.22411550794329, 45.652131353105815, 35.59063604899815, 35.50609731674194, 37.13444239752633, 38.60956927708217, 35.53391790390015, 34.60645151138306, 34.4945855140686, 35.35895184108189, 37.206738403865266, 36.614279406411306, 38.446237972804475, 47.29473761149815, 47.64097329548427, 44.27800696236746, 39.17873443875994, 42.42078127179827, 37.28754595347813, 38.75613457815987, 38.59016990661621, 41.68289647783552, 40.60767316818237, 41.644361768450054, 41.144876616341726, 41.856135913303916, 39.886585644313264, 40.50331817354475, 39.04099334989275, 37.94143744877407, 39.52890975134713, 36.43048218318394, 37.31855576378958, 35.91900096620832, 38.472564697265625, 35.70930085863386, 38.81062235151018, 39.247632775987896, 39.063918931143625, 39.61144045421055, 40.81003597804478, 37.72238506589617, 37.56424754006522, 39.14150946480887, 39.793709073747905, 38.27037559236799, 37.45159987040928, 36.45501627240862, 38.533792223249165, 36.13836601802281, 36.1137033871242, 35.278436115809846, 35.444529329027446, 34.05576508385794, 38.20327683857509, 38.8503452028547, 41.98076922552926, 44.43470968518938, 38.71339273452759, 36.648141452244346, 30.56542090007237, 23.437911885125295, 20.241681473595754, 13.022297297205244, 3.1489526970045905, 2.741235443523952, 5.940211262021746, 9.785290513719831, 10.72568142414093, 9.251022679465157, 12.373236536979675, 9.04324288027627, 7.540234616824558, 5.463102783475604, 2.7590484533991133, 0.4434581899217197, 0.062336795032024384, 0.0456540955762778, 0.03852888076965298, 0.05739235106323447, 0.02038066611359162, 0.9996586101395744, 4.911223437104907, 1.7165939339569636, 3.2849022362913405, 9.372835891587393, 41.9974171093532, 53.1947865486145, 49.28317308425903, 47.45396253040859, 50.90822124481201, 52.98835209437779, 52.34763438361031, 41.178620542798726, 38.98163488933018, 41.11301565170288, 55.309627124241416, 27.174540179116384, 18.09807014465332, 23.024127551487513, 18.820441348212107, 0.6736655799405915, 0.15437665049518856, 0.3346757542874132, 18.020875658307755, 39.6444548198155, 47.974309648786274, 47.282369818006245, 30.345621585845947, 32.896513734545024, 52.229032107761924, 30.452088832855225, 38.38584770475115, 26.327742372240337, 1.4238838063819068, 13.707011001450674, 34.24935926709856, 24.97569588252476, 18.52543820653643, 15.891994510378156, 3.760078464235578, 0.2869801436151777, 0.021509081723966768, 0.2292457159076418, 11.019043053899493, 15.746768474578857, 7.219936992440905, 3.492842061179025, 5.999425981725965, 6.4355457339968, 8.114535365785871, 5.4334187763077875, 11.180650336401802, 43.90166820798601, 46.836236408778596, 58.75949110303606, 41.420900753566194, 36.33984988076346, 55.114292417253765, 81.07975224086216, 68.17147922515869, 71.02250576019287, 11.442726833479744, 0.3295883158487933, 0.03663730834211622, 0.12007177913827555, 0.031164288986474276, 0.03221858312774982, 0.24706016427704267, 2.969365647860936, 3.391608110495976, 7.070319695132119, 23.327835048948014, 25.211958953312465, 24.6094354901995, 43.33026920046125, 57.42513820103237, 60.99084949493408, 58.46649946485247, 57.55883543831961, 60.247836930411204, 58.728974614824565, 59.35440976279122, 45.9312960760934, 21.720688922064646, 29.239673342023575, 15.332867758614675, 8.239388414791652, 22.586344139916555, 43.6608054297311, 39.32555334908621, 27.44101401737758, 38.51626886640276, 44.97692278453282, 48.57344239098685, 53.10872268676758, 53.185159819466726, 47.748465401785715, 38.570124353681294, 39.10530587605068, 42.27377128601074, 44.21644939695086, 39.79014812197004, 37.75374576023647, 37.82802200317383, 37.54235029220581, 38.77964033399309, 36.800480706351145, 38.6468220438276, 44.65838956832886, 45.97493423734392, 44.565492153167725, 42.169669900621685, 45.24554361615862, 38.827645438058035, 41.756408418927876, 40.16779661178589, 43.20477431161063, 42.49395969935826, 44.09926107951573, 43.90170989717756, 44.093462807791575, 44.362611702510286, 42.74007878984724, 40.57471786226545, 41.67633737836565, 43.563534123556956, 40.117293630327495, 42.025897775377544, 40.636754853384836, 40.182551111493794, 39.0706204686846, 40.82484258924212, 40.97145305361067, 42.17035429818289, 42.7245843069894, 42.474133014678955, 40.42152050563267, 41.45253937585013, 42.65620708465576, 42.65418863296509, 40.95275892530169, 39.973597935267854, 38.809931005750386, 40.63559103012085, 37.86198827198574, 39.102092334202354, 38.12896238054548, 37.75785561970302, 38.033153670174734, 39.502881799425396, 39.41943046024868, 45.873577390398296, 48.13548353740147, 41.2644898550851, 37.52112354551043, 32.508435998644146, 24.819637605122157, 26.985431058066233, 15.94710762160165, 7.775589210646493, 8.670026472636632, 8.761505586760384, 11.262303829193115, 11.289215070860726, 11.295458027294703, 15.556330510548182, 10.598512887954712, 9.916138989584786, 7.106690040656498, 3.230805299111775, 0.8969890422054699, 0.07600015614713941, 0.02810986020735332, 0.030076322544898306, 0.02111140083122466, 0.024181398596348505, 0.897839599422046, 4.102433579308646, 2.500829292195184, 2.6081359684467316, 16.022856882640294, 48.83839804785592, 55.490947314671104, 54.20913321631295, 54.4251457623073, 58.355953625270296, 57.807296071733745, 57.12035199574062, 49.52263927459717, 45.87362950188773, 46.73554311479841, 63.867535727364675, 33.97466223580496, 22.573114769799368, 31.820922170366558, 24.10894284929548, 1.1583295187779834, 0.21033721124487265, 0.3069007103996617, 29.26185199192592, 53.304894651685444, 57.69736862182617, 56.464723450796946, 39.3494690486363, 40.11139113562447, 49.71312413896833, 23.937456096921647, 45.181088651929585, 52.097825799669536, 8.938522236687795, 26.50974174908229, 56.30346270969936, 47.087076800210134, 26.813301597322734, 31.870615686689103, 6.99564219372613, 0.28166159614920616, 0.08260992182684795, 0.39546280247824533, 17.64737003190177, 62.027034350803916, 30.417254039219447, 19.20312554495675, 15.217948028019496, 20.55022144317627, 35.28496742248535, 28.782395022256033, 49.614202635628835, 53.806901999882285, 59.39706475394112, 63.07935987200056, 44.32595648084368, 45.644241673605784, 59.088300704956055, 90.59307983943394, 74.66600908551897, 80.51570442744664, 11.256450840405055, 0.37815888385687557, 0.09801831216152225, 0.13955797494522162, 0.11059486373726811, 0.14699957706034184, 0.6557750542248998, 4.581708158765521, 4.099719873496464, 10.722981180463519, 33.237274238041465, 32.572613034929546, 37.675707067762104, 53.903815473829, 58.87481730324881, 60.622914586748394, 58.48554447719029, 56.71759966441563, 56.626946517399375, 59.98875944955008, 57.9329195022583, 60.96431432451521, 40.658697264535085, 35.27899544579642, 31.508802141462052, 17.158329759325298, 26.356803212847026, 53.83422926494053, 44.73158189228603, 33.64509875433785, 44.68090173176357, 54.87251942498343, 58.75543335505894, 60.242528506687705, 56.94852999278477, 51.961324964250835, 46.3218925339835, 47.847334793635774, 47.297204221997944, 47.05715785707746, 42.37243570600237, 41.980734484536306, 40.854372433253694, 39.70550864083426, 39.20813921519688, 37.04033252171108, 41.4737035887582, 49.67924124853951, 48.755287170410156, 46.46187441689627, 43.14086478097098, 47.272892475128174, 41.18567991256714, 44.99096509388515, 45.306979588099885, 48.047359534672324, 46.59177098955427, 46.266379901341026, 46.59281669344221, 47.54527228219168, 44.12906190327236, 46.28680065699986, 41.65565606525966, 43.72062594549996, 44.319032600947786, 43.05385249001639, 43.51021364756993, 41.78885998044695, 41.5545563016619, 43.472995621817454, 43.7574131829398, 42.89703859601702, 43.31774854660034, 44.930074555533274, 45.40782226834978, 43.95491572788784, 41.93269463947841, 44.328593322208945, 44.14018249511719, 41.5419522694179, 40.55689920697893, 39.95993777683803, 41.67966556549072, 39.80627489089966, 40.84495415006365, 42.59140818459647, 41.296468939099995, 38.56134877886091, 40.63889489855085, 40.26145485469273, 47.01938744953701, 52.14694261550903, 43.63332877840315, 44.896528652736116, 35.00159903935024, 32.927367210388184, 32.24041271209717, 28.708686794553483, 16.663232394627162, 15.95966649055481, 15.94440129825047, 13.559269717761449, 12.20554436956133, 13.199987922395978, 16.63573316165379, 11.564019799232483, 11.374177643230983, 8.369701010840279, 4.719597765377589, 1.1081489771604538, 0.22465235952820095, 0.07351750507950783, 0.1100306347278612, 0.16337516478129796, 0.11366768420806952, 1.0968208078827177, 5.162928879261017, 2.519201849188123, 3.1126909170831953, 22.572725670678274, 53.86094161442348, 58.17159707205636, 58.02420493534633, 51.8905645098005, 55.93376990727016, 55.414399010794504, 58.039504868643625, 49.61118711744036, 48.8395688193185, 48.163109574999126, 63.49855858939034, 39.4819781439645, 26.141494171960012, 36.07904577255249, 27.675482715879166, 1.7608694838626044, 0.5350341988461358, 0.38062234595417976, 31.267810821533203, 63.18329102652413, 65.91080638340541, 64.26957934243339, 44.24510724203927, 47.40710735321045, 66.91119412013462, 45.20530659811837, 53.61633723122733, 68.90119988577706, 11.777949622699193, 37.46589231491089, 81.49562971932548, 60.35105242047991, 39.10227646146502, 60.959888322012766, 9.989961862564087, 0.5185170280081886, 0.28911177494696205], [0.23007645990167344, 2.8870779148169925, 14.859610319137573, 4.264611482620239, 2.6702708857400075, 2.248017783675875, 11.310436606407166, 34.704976967402864, 20.172691072736466, 21.314710889543804, 43.890669209616526, 55.515672479357036, 55.1883602142334, 20.159294945853098, 26.122925111225673, 45.12416206087385, 68.97915867396763, 64.24990899222237, 62.46395097460066, 29.272364616394043, 0.4270292557775974, 0.08104051782616548, 0.0622217697756631, 0.1367942611021655, 0.155108599790505, 0.3919217182057244, 3.5733063263552527, 6.132387578487396, 10.555379339626857, 9.592929635729108, 18.79402777126857, 36.848440647125244, 51.968064716884065, 60.29674530029297, 56.225868701934814, 54.331918307713096, 53.90082427433559, 52.829870632716585, 53.62641906738281, 56.390110220227925, 44.891727447509766, 31.147853646959575, 29.02730165209089, 23.57792329788208, 16.671670981815883, 17.373623166765483, 35.273718288966585, 38.24317339488438, 34.163840838841026, 37.02234016145979, 37.29121112823486, 37.58605793544224, 48.48720482417515, 51.30093690327236, 36.628349508558, 29.25444868632725, 28.49215313366481, 34.810283865247456, 38.14496060780117, 37.77290889195034, 34.63198266710554, 33.77466181346348, 33.16750390189034, 33.76823125566755, 36.96651485988072, 37.463255473545615, 35.52604906899588, 37.278058188302175, 39.380986077444895, 37.90769699641636, 41.367747034345356, 39.137073040008545, 39.43676274163382, 37.852458817618235, 39.54064525876726, 40.00085571834019, 41.24208538872855, 40.585550103868755, 40.08017635345459, 39.61062404087612, 39.03246096202305, 40.08758313315255, 39.47551284517561, 38.77726405007498, 38.48083652768816, 38.319214480263845, 37.9085933140346, 38.15314211164202, 37.729361057281494, 39.71696274621146, 40.555777072906494, 38.60075896126883, 37.636741570064, 36.56645495550973, 36.988655294690815, 38.93547453199114, 39.853727613176616, 41.5795385496957, 43.16860893794468, 41.45476974759783, 39.11064904076712, 37.552581514631, 37.0163369178772, 36.796346528189524, 36.58971405029297, 35.77989108221871, 33.29707738331386, 36.00156988416399, 34.65209770202637, 42.38130160740444, 44.57137727737427, 35.93873732430594, 28.33736116545541, 21.581221205847605, 17.48128202983311, 17.773222752979823, 6.019622223717826, 6.430025390216282, 10.101287637438093, 11.259740812437874, 12.983595831053597, 11.692868930952889, 18.781481061662944, 19.85563087463379, 17.954249382019043, 16.702267374311173, 12.043284824916295, 3.0856207353728156, 3.106165907212666, 1.4256363809108734, 0.02723058738878795, 0.1706825526697295, 0.7144168189593724, 1.5254715723650796, 14.518494588988167, 18.718356677464076, 4.772907819066729, 15.617625781467982, 43.253943238939556, 54.3236916405814, 51.00746236528669, 53.19667993273054, 47.7410204069955, 50.578491006578716, 48.52172000067574, 45.450855936322895, 40.922402245657786, 35.516088826315745, 37.921471800122944, 49.926510265895296, 32.23083462033953, 30.16069528034755, 29.539206709180558, 19.881804738725933, 6.734753838607243, 0.796811434839453, 0.7918701799852508, 30.38302721296038, 47.664777823856895, 50.82771941593715, 41.353305203574045, 24.312024797712052, 39.537053040095735, 84.05233751024518, 47.97762393951416, 45.59916870934622, 48.9923666545323, 35.86292552947998, 55.714967659541536, 22.952660117830547, 13.93752270085471, 16.328916345323833, 17.133389200483048, 1.4364428924662727, 0.19458958054227488, 0.13431378134659358, 0.16722901298531465, 5.41319864988327, 16.34553643635341, 11.256522059440613, 6.948454805782863, 6.204317501613072, 11.70805595602308, 27.459612607955933, 17.35574892589024, 30.967210905892507, 49.83848353794643, 51.10863161087036, 57.1848521232605, 31.585135051182338, 35.29992341995239, 53.166740145002095, 73.79335703168596, 71.68511377062116, 67.05712713514055, 38.508382661002024, 0.4165147585528237, 0.16139300114342145, 0.01540924868147288, 0.11131936950342995, 0.06932446400501899, 0.2916368751653603, 4.239100302968707, 6.948387929371425, 11.416835239955358, 12.460199322019305, 32.789351667676655, 46.44594914572579, 59.147957938058035, 61.96707834516253, 60.933130809238975, 59.70678765433175, 59.04162965502058, 57.77221114294869, 59.67051805768694, 61.18102169036865, 54.67810535430908, 37.33636747087751, 35.37596103123256, 30.810657569340297, 18.23969180243356, 21.905455418995448, 39.10272809437343, 42.54260056359427, 36.83231387819563, 41.489368302481516, 36.14071798324585, 40.110244682856965, 52.6337924684797, 54.476326193128315, 40.63855791091919, 36.00522116252354, 34.1165965625218, 39.02954271861485, 41.22230386734009, 42.562336921691895, 38.977264472416465, 37.53952237537929, 36.23377868107387, 35.30132348196847, 35.50973469870431, 36.51637928826468, 37.61117567334856, 38.27996063232422, 40.51057209287371, 40.207891191755024, 43.465870244162424, 42.01297412599836, 41.844139848436626, 41.022379875183105, 42.716708523886545, 42.249671459198, 43.512339796338765, 44.72151395252773, 43.97957141058785, 42.14643512453352, 42.01330416543143, 44.34573800223214, 42.282470430646626, 41.60736608505249, 40.68883507592337, 40.87492173058646, 40.33491815839495, 41.20367922101702, 41.422144481113975, 42.54685633523123, 42.44637148720877, 41.22276244844709, 40.07088313783918, 39.0119047164917, 39.03965582166399, 39.6012578691755, 40.406620093754356, 43.267089230673655, 44.399416310446604, 44.49407509395054, 41.32010671070644, 39.897341455732075, 39.25525494984218, 39.14230503354754, 38.85222121647426, 38.1609206199646, 36.940848214285715, 38.45995371682303, 37.240635190691265, 43.01939637320382, 45.637251785823274, 37.185060024261475, 32.10308851514544, 26.31990306718009, 22.069083758762904, 19.11705126081194, 12.20778168950762, 14.511284964425222, 14.159921509878975, 13.83895902974265, 15.683277572904315, 14.143263203757149, 23.508870363235474, 24.716361318315776, 24.893298932484218, 23.92199288095747, 21.03067547934396, 12.114427430289131, 4.475715560572488, 2.217531693833215, 0.054172539551343234, 0.1104626851156354, 0.5989836816276822, 1.6474596836737223, 15.26372970853533, 23.494942699159893, 9.426618422780718, 23.437527997153147, 47.63550158909389, 56.41468947274344, 54.62247460229056, 58.26272964477539, 51.530286516462056, 56.742884159088135, 53.00304058619908, 52.05647012165615, 48.28384147371565, 43.231802804129465, 45.50350591114589, 57.24674667630877, 37.94928196498326, 38.16611439841134, 35.05804967880249, 28.898138114384242, 14.121748975345067, 0.9964981568711144, 0.8977488928607532, 41.312922273363384, 59.04506206512451, 59.26874542236328, 52.15485313960484, 33.86944566454206, 44.70090559550694, 90.7172372000558, 54.413177490234375, 58.19301836831229, 62.322423117501394, 55.79892274311611, 71.96814864022392, 39.578641482761924, 25.263302666800364, 31.551165308271134, 30.59318242754255, 2.7441024439675465, 0.4155220075377396, 0.083210031768041, 0.5458214942898069, 4.648822980267661, 59.99371351514544, 41.583429540906636, 27.468530620847428, 23.174078362328665, 47.23709535598755, 67.6045618057251, 49.80050468444824, 57.848200116838726, 54.527801922389436, 68.37563814435686, 63.80186135428292, 34.13393579210554, 43.63717113222395, 56.94405882699149, 82.98780400412423, 75.46256446838379, 75.64551748548234, 38.11445106778826, 0.49730900887932095, 0.20361345846738133, 0.11172818685216562, 0.15935515692191465, 0.33831604037966045, 0.9705104827880859, 6.009202097143445, 12.253183824675423, 13.163137282644, 26.605974299567087, 45.247631549835205, 53.22458389827183, 59.68205901554653, 62.71753937857491, 60.10921342032296, 58.15478937966483, 59.62024784088135, 57.12254762649536, 58.604025159563335, 59.17892605917794, 56.37382711683001, 50.018042360033306, 45.63673414502825, 41.6818334034511, 37.9457175391061, 33.575832162584575, 49.219041211264475, 50.84730291366577, 44.98899180548531, 53.72126545224871, 48.32266453334263, 49.47218493052891, 57.13574225561959, 59.90622179848807, 46.593473298209055, 44.557758808135986, 43.14163255691528, 47.78801107406616, 48.3018616267613, 47.940204416002544, 44.10454518454415, 41.89592824663435, 39.349788665771484, 38.36066395895821, 37.97206858226231, 37.114924907684326, 39.17203984941755, 41.40348856789725, 41.87600081307547, 40.40927083151681, 45.80277524675642, 46.546402726854595, 43.88012184415545, 44.946479252406526, 46.15381213596889, 44.662374360220774, 46.29957839420864, 48.362422125680105, 46.87567785808018, 45.01717022487095, 45.124766554151265, 46.16645785740444, 45.569149017333984, 45.327601841517854, 43.1068776675633, 42.130697454724995, 43.32084049497332, 44.44902297428676, 43.203707763126914, 46.73926387514387, 44.46585498537336, 45.002387932368684, 42.78860848290579, 43.34151485988072, 42.813100882938926, 42.9159585407802, 43.59469332013811, 45.42970561981201, 46.52431787763323, 48.248662744249614, 44.46438544137137, 41.34078802381243, 41.47414132526943, 41.680506297520225, 42.28416231700352, 41.15029968534197, 38.98899303163801, 38.92118903568813, 36.13483285903931, 48.244007451193674, 48.69064113071987, 43.306218011038645, 34.00396278926304, 30.283251081194194, 28.071722848074778, 34.19072341918945, 20.3921377658844, 19.005716800689697, 19.883270808628627, 14.385359287261963, 19.091280392238072, 18.6721841607775, 25.658809764044626, 25.646580934524536, 24.65675445965358, 26.348251717431204, 22.578388452529907, 15.341427939278738, 6.766768097877502, 3.1336086860724857, 0.1658006967710597, 0.28031158287610325, 0.751154496201447, 1.9759495598929269, 16.614522048405238, 26.386494602475846, 12.731298054967608, 28.520043202808925, 49.583863326481406, 59.052996907915386, 55.630408082689556, 57.5728325843811, 49.83126088551113, 54.27653769084385, 52.26959569113595, 53.13202347074236, 49.27143062864031, 49.91595247813633, 46.527871881212505, 57.167578901563374, 41.505651405879426, 40.08732257570539, 42.277287074497764, 36.566798891339985, 13.536765371050153, 0.8783438227006367, 0.8405057245067188, 44.89066784722464, 65.28585066114152, 68.28755583081926, 54.58686855861119, 40.411098207746235, 52.7800555229187, 99.06792272840227, 59.54154559544155, 61.59286226545061, 75.74411937168666, 69.9329309463501, 88.40333420889718, 54.449791022709434, 36.232125009809224, 58.49889891488211, 51.36113262176514, 2.889673718384334, 0.6596263647079468, 0.4122656637004444], [0.06706023335989032, 0.12026962637901306, 7.235019360269819, 2.9220788138253346, 1.4204721323081424, 5.703875235148838, 11.466481855937413, 39.126122679029194, 36.247730663844514, 40.92990977423531, 46.60825211661202, 65.37874807630266, 58.838686670575825, 26.49773699896676, 30.372410365513392, 38.949259757995605, 64.07984488351005, 68.59737600599016, 60.63575485774449, 43.32117748260498, 1.6979639679193497, 0.057594065953578265, 0.07839568331837654, 0.04616110712023718, 0.03359589725732803, 1.9731922107083457, 4.509545036724635, 7.779395954949515, 14.034310238701956, 26.888736452375138, 43.843230383736746, 54.609394618443076, 62.817947796412874, 58.45176233564104, 55.81354175295149, 52.76226118632725, 52.80308532714844, 51.76644883837019, 54.703997816358296, 53.93857383728027, 49.976471287863596, 40.55119126183646, 39.42086526325771, 36.177397523607524, 38.453894887651714, 36.46621676853725, 41.7727610043117, 44.904880387442454, 36.480366774967735, 40.7737455368042, 38.00022963115147, 37.44261237553188, 48.838908740452354, 46.495785100119456, 37.468021937779014, 26.705938032695226, 25.82445308140346, 26.995559794562205, 31.658876282828196, 36.94188002177647, 35.750559261866975, 30.968475478036062, 33.433105741228374, 32.485315867832725, 29.773781367710658, 35.646072251456125, 38.65196718488421, 32.76301452091762, 38.24083532605852, 38.48158345903669, 40.796320234026226, 40.40147147859846, 38.20746660232544, 38.293436663491384, 38.8019996370588, 39.44655622754778, 39.94084760120937, 39.65842764718192, 41.05747522626604, 39.8344463620867, 39.61633198601859, 40.36000810350691, 41.134138175419395, 37.639982904706685, 38.71181549344744, 41.56020518711635, 38.23061105183193, 38.22571952002389, 37.00194719859532, 38.458824634552, 39.594198499407085, 38.845276491982595, 37.270741735185894, 38.02200181143624, 36.34465108598982, 38.4205504826137, 40.03750399180821, 39.478966099875315, 39.04534292221069, 37.61945792606899, 38.36090019771031, 38.45379761287144, 35.96665518624442, 36.56341859272548, 34.77747447150094, 34.52053703580584, 34.978510175432476, 38.71493176051548, 32.89088569368635, 33.08986125673567, 31.289107050214493, 30.724743093763077, 28.060918399265834, 20.145276955195836, 15.557511704308645, 5.116302124091557, 12.836133343832833, 14.241955416543142, 9.89436854634966, 13.343733991895403, 9.482897962842669, 21.02942827769688, 30.311710902622767, 37.570890017918174, 31.59637028830392, 19.804674523217336, 18.78623710359846, 17.77142664364406, 15.585134267807007, 13.037031820842198, 5.037615946360996, 5.458955577441624, 7.293475423540388, 18.79016283580235, 29.723518099103654, 38.023551259722026, 44.35346439906529, 51.04455532346453, 54.353006090436665, 54.51355464117867, 54.31528084618704, 53.666527543749126, 46.93695054735456, 47.859994411468506, 48.21091318130493, 47.15186527797154, 43.425369194575715, 38.56544821602957, 39.170618942805696, 49.63480404445103, 47.622185366494314, 47.530330181121826, 36.44889143535069, 28.378096716744558, 22.312265498297556, 0.8049090174692017, 2.4818819889000485, 42.28510727201189, 47.612701075417654, 47.02931295122419, 30.46329975128174, 22.807131835392543, 43.69935750961304, 40.82871273585728, 27.867669888905116, 46.677893911089214, 55.883315563201904, 57.40480777195522, 30.018562929970876, 25.630825894219534, 17.296710082462855, 20.519164732524327, 15.2399651323046, 0.575616075524262, 0.12230295155729566, 0.07577341009995767, 0.11192111471401793, 0.45264986955693787, 27.47782036236354, 11.179247668811254, 6.935434750148228, 14.5500967332295, 21.650208132607595, 44.38135099411011, 45.13160705566406, 47.43237795148577, 52.348509856632774, 63.107507024492534, 58.0299198286874, 30.647447858537944, 39.607233319963726, 45.38223900113787, 73.88569164276123, 71.55821881975446, 64.36073970794678, 54.04322065625872, 2.2576314849512915, 0.037496130115219524, 0.20381742609398706, 0.036716646049171686, 0.08888045392398324, 1.8694714563233512, 4.879213954721179, 10.804906521524702, 20.29413516180856, 42.07602555411202, 51.94412817273821, 58.95590278080532, 62.04686450958252, 61.726337160382954, 58.706309591020855, 56.34009708677019, 55.49454648154122, 55.66543395178658, 58.805293628147666, 59.6442677634103, 56.208453042166575, 50.88841540472848, 46.167962142399375, 44.47445338112967, 44.33803939819336, 44.72523471287319, 50.731344427381245, 51.896095275878906, 40.49875668116978, 42.97019965308053, 46.190866879054475, 46.95043352672032, 50.22874648230416, 48.69679376057216, 43.990080560956685, 36.03336484091622, 34.19234929765974, 34.92329978942871, 38.49619204657418, 43.744159494127544, 41.30063438415527, 35.120232582092285, 35.558775084359304, 34.00811086382185, 29.859619413103374, 33.184057985033306, 36.58080298560006, 35.495567321777344, 38.778844765254426, 39.53542716162545, 40.798755577632356, 42.39942945752825, 41.429443563733784, 41.875583921160015, 39.854721205575125, 41.4959135055542, 40.48437738418579, 42.538480281829834, 43.18068838119507, 42.01842498779297, 41.79325124195644, 43.14279638017927, 40.74613686970302, 40.06369175229754, 40.54483713422503, 42.774555751255576, 40.73691661017281, 41.854892185756135, 39.98739358357021, 41.54478018624442, 42.9048935345241, 41.367538588387625, 39.88012381962368, 39.36263241086687, 38.26111364364624, 41.6139668737139, 41.489316190992085, 40.9383761542184, 38.74127932957241, 41.81262281962803, 41.42196035385132, 41.13624695369175, 37.797241483415874, 39.335339886801584, 37.92571020126343, 38.04136644090925, 37.40387964248657, 39.886662074497764, 34.115985121045796, 34.64541006088257, 32.18400723593575, 33.45110157557896, 30.672899109976633, 23.35636956351144, 14.91956979887826, 10.842894060271126, 19.580807038715907, 20.303353684289114, 11.378958872386388, 18.22592568397522, 14.53453711100987, 25.341296195983887, 35.16800144740513, 40.5154948915754, 36.682555879865376, 25.987819126674108, 29.153091839381627, 27.23015182358878, 19.464035613196238, 16.394637618746074, 5.063113663877759, 7.5717299325125555, 8.763639552252632, 23.67593285015651, 35.317478043692454, 42.50789431163243, 50.08847277505057, 55.986006464277, 57.13750014986311, 57.39733498437064, 58.747505460466655, 58.81190831320626, 52.3030686378479, 53.12149347577776, 53.5673246383667, 54.24756370271955, 51.634756156376426, 48.557197502681184, 49.07630784170968, 57.84654991967337, 56.99133089610508, 58.375769887651714, 45.50579186848232, 39.4371657371521, 27.505118097577775, 0.4621180115001542, 2.959840101855142, 50.420673097882954, 54.925152029309956, 54.84476137161255, 41.1997708593096, 28.105128049850464, 49.74377959115164, 51.06798117501395, 39.050936222076416, 64.89386108943394, 71.5665705544608, 61.203137806483674, 45.082455498831614, 41.42556299482073, 31.20112201145717, 39.15994998386928, 20.014122758592876, 0.7412406110337803, 0.0401596175506711, 0.053538092345531495, 0.15228315283145222, 0.34136372112802094, 39.41167279652187, 48.759522097451345, 29.567572729928152, 26.78067111968994, 43.08046061652047, 62.1929086957659, 62.937359537397114, 61.46283367701939, 61.537769998822895, 72.77757208687919, 63.39376585824149, 40.58360113416399, 48.16029208047049, 54.92763253620693, 77.83606215885708, 80.58654131208147, 72.13700376238141, 58.67987864358084, 2.0146353925977434, 0.26043303097997395, 0.19445172936788627, 0.14413516862051828, 0.21604322934789316, 3.072665819099971, 9.640338931764875, 19.229236875261577, 31.44864116396223, 52.687873772212434, 59.13870293753487, 64.32467855725969, 67.19615364074707, 63.94756507873535, 60.847105162484304, 57.5127306665693, 55.65938207081386, 55.48653173446655, 57.45523432322911, 58.394814899989534, 54.69557312556675, 57.01604911259243, 53.08943101337978, 49.92814309256417, 51.59974765777588, 53.395947320120676, 54.165484632764546, 55.94691937310355, 49.037623746054514, 49.150764737810405, 54.52525193350655, 54.170654092516216, 55.70315572193691, 54.014938013894216, 48.818793705531526, 42.42665249960763, 41.05086401530674, 42.47022812707083, 44.93536213466099, 48.80534199305943, 45.29956933430263, 37.647202083042686, 41.64705419540405, 38.74941219602312, 32.10186563219343, 37.40013803754534, 37.87358481543404, 36.53407287597656, 41.04460368837629, 40.1787782396589, 43.07211235591343, 45.83101272583008, 44.032363823481965, 43.40479905264718, 42.08581209182739, 44.13941124507359, 45.171611309051514, 44.975995200020925, 46.9604424067906, 47.04741300855364, 45.81667511803763, 48.68934876578194, 45.333907331739155, 42.27846132005964, 43.67699473244803, 45.1245059967041, 43.32361282621111, 44.27863924843924, 42.581982953207834, 43.02908911023821, 45.37788248062134, 44.40919937406267, 41.89710249219622, 42.36294099262783, 40.598887171064106, 44.60625376020159, 44.470350469861714, 43.28814574650356, 42.835592201777864, 42.924431868961875, 44.11979300635201, 41.53914172308785, 39.81893450873238, 41.585375036512104, 39.52821145738874, 40.04580014092581, 38.94328778130667, 40.93984917231968, 34.07590791157314, 37.90317024503435, 34.39527491160801, 34.56948709487915, 32.18163095201765, 29.68931906563895, 26.037799256188528, 19.15832356044224, 26.960049288613455, 25.909585884639196, 16.282656976154872, 25.020925181252615, 19.59785791805812, 29.98737941469465, 36.98020281110491, 42.611773354666575, 40.23228631700788, 34.03257199696132, 37.905890464782715, 35.872910090855186, 25.783997195107595, 17.333156858171733, 5.140732424599784, 8.301092760903494, 10.421144485473633, 25.339392389569962, 38.62206213814871, 49.0493175642831, 54.572864464351106, 57.64305107934134, 61.4100273677281, 57.218616894313264, 60.63242667061942, 57.918929304395405, 51.62062699454171, 52.10388115474156, 54.590835980006624, 54.508406026022776, 55.31819772720337, 50.91382496697562, 52.84286028998238, 57.86876678466797, 57.067059312547954, 59.09032957894461, 51.23984486716134, 45.932435580662315, 36.86222587312971, 1.718108098421778, 2.7181177011557986, 55.28069829940796, 63.02399662562779, 62.53256443568638, 46.75985138756888, 35.6963528905596, 61.12862532479422, 51.65087945120675, 42.606996468135286, 64.94522217341832, 71.21923705509731, 71.06302070617676, 50.394287313733784, 47.11987229755947, 47.64246368408203, 72.65486689976284, 25.435442549841746, 0.8753053971699306, 0.22392731771937438, 0.20072783902287483], [0.09803046472370625, 0.11053668614476919, 0.6970329689128059, 6.35684609413147, 2.5202833797250475, 4.177302590438297, 4.204066182885851, 33.4383863721575, 46.72698640823364, 36.38212966918945, 24.99585608073643, 60.65954548971993, 65.36023112705776, 44.22539867673601, 30.85335077558245, 41.464782101767405, 54.1769700050354, 66.46277127947126, 50.584424768175396, 48.914519037519185, 5.516742008072989, 0.05849447513797453, 0.3076602896409375, 0.10783545859158039, 1.3852957912853785, 5.662658521107264, 15.634242398398262, 30.8742961202349, 44.08424949645996, 53.42231920787266, 54.203512123652864, 61.60976028442383, 60.05381543295724, 56.88984203338623, 52.01476008551461, 49.56794152941023, 48.20481613704136, 49.80847774233137, 51.63272033418928, 52.48460422243391, 49.530740874154226, 46.5643881389073, 44.98437820162092, 43.030919960566926, 45.93335969107491, 49.18045439038958, 51.470875944410054, 51.73228801999773, 47.45606436048235, 51.454547677721294, 46.19746766771589, 44.63062456675938, 47.17820937292916, 45.45662988935198, 39.28148092542376, 29.698737348828995, 27.783516781670706, 26.91981748172215, 30.570711953299387, 33.209870542798726, 34.945554869515554, 33.324074608939036, 29.022863490240915, 27.749515771865845, 29.251724992479595, 29.499598503112793, 35.64025313513619, 35.242402757917134, 35.864961351667134, 35.924886090414866, 37.580641814640586, 40.17130545207432, 38.717266355242046, 38.522591727120535, 38.7699475969587, 38.304619789123535, 39.31048270634243, 39.86555692127773, 40.06220483779907, 38.63363783700125, 38.01351111275809, 36.416339124952046, 36.71822793143136, 38.14640583310808, 36.980421679360525, 39.01349932806832, 40.509616715567454, 39.53824813025338, 37.27651916231428, 41.00026028496878, 39.862155778067454, 38.83824144090925, 38.50308118547712, 36.58925894328526, 35.73902177810669, 38.84969554628645, 40.641118322099956, 37.671958514622276, 38.34873737607683, 38.87602921894619, 39.726718017033164, 37.783897468021934, 37.63300691332136, 38.12311894553048, 33.35220439093453, 37.264193058013916, 36.286171572549, 38.82461602347237, 29.666299683707102, 32.513546398707796, 31.02958835874285, 28.54350553240095, 24.84440793309893, 18.291296073368617, 5.049252007688795, 11.03599318436214, 13.940837860107422, 11.529132894107274, 6.675852222102029, 4.512544921466282, 6.95277658530644, 22.74680757522583, 43.29225213187081, 46.94331162316458, 41.926479475838796, 34.70454617909023, 31.637454986572266, 25.273342813764298, 17.65628978184291, 20.429086548941477, 13.77452838420868, 19.86147952079773, 29.212134156908306, 45.276511737278526, 40.833982944488525, 41.09460987363543, 54.521902901785715, 49.162924085344585, 55.72081804275513, 54.27407455444336, 53.77218532562256, 49.013954707554404, 42.77612257003784, 42.017153467450825, 44.56709023884365, 43.80892365319388, 43.54936327253069, 42.041378361838206, 45.19718067986624, 48.0815029825483, 56.374897139413015, 49.27686064583914, 41.02173021861485, 41.664059911455425, 12.375409586088997, 0.11243879622114555, 5.766684344836643, 48.17138140542166, 48.48751054491316, 42.69748285838536, 19.726055656160625, 24.402914183480398, 40.20615414210728, 28.06448803629194, 28.539812564849854, 31.356855460575648, 37.68054996218, 33.77504743848528, 26.31304693222046, 19.03769588470459, 22.520291090011597, 16.374677181243896, 2.7527594651494707, 0.3409215062856674, 0.1348367418561663, 0.06715265661478043, 0.044453692489436696, 0.014559363214565175, 6.774996067796435, 20.465024369103567, 8.981683577810015, 5.822464048862457, 29.89711536679949, 55.299111025674, 53.98235443660191, 43.031976086752756, 37.75323159354073, 67.65539482661656, 72.4944885798863, 46.53952748434884, 36.670076915196006, 47.403535979134695, 61.68936579568045, 72.70096124921525, 58.9054936000279, 61.168007714407786, 8.736970629010882, 0.32892074595604626, 0.383124158850738, 0.11048540246805974, 0.9402359873056412, 6.3001144868986945, 16.589517218726023, 36.21868371963501, 51.54817465373448, 58.663640703473774, 58.39565563201904, 63.49548748561314, 61.91058949061802, 61.022449902125764, 55.652360916137695, 55.99210350854056, 51.279710156576975, 53.68703862598964, 56.5776629447937, 57.969845703669954, 56.564117431640625, 54.80736269269671, 53.22486530031477, 52.26480490820748, 54.22306782858712, 55.0328699520656, 55.08246966770717, 54.437478814806255, 52.76822274071829, 56.96513966151646, 50.52371140888759, 46.479321343558176, 48.95948430470058, 48.06089115142822, 44.268585205078125, 38.33673088891165, 36.8768379347665, 36.10175595964704, 38.81528459276472, 40.452155113220215, 41.05732583999634, 38.92672674996512, 33.96987840107509, 30.26901422228132, 33.664122922079905, 31.52114909035819, 35.84562104088919, 36.95007194791521, 38.089493138449534, 37.7660927091326, 40.043931075504844, 43.23923737662179, 42.093764305114746, 40.54275267464774, 41.332655157361714, 40.93532589503697, 42.9374041557312, 44.02567965643746, 43.299384457724436, 39.47894525527954, 39.756056785583496, 39.147679465157644, 40.21959890638079, 40.08264643805367, 38.13204738071987, 39.26071275983538, 40.81794302804129, 41.10716526848929, 39.264183385031565, 40.86538880211966, 41.74021216801235, 40.76415702274868, 38.47139392580305, 37.499573707580566, 37.960138525281636, 38.872023582458496, 42.15083680834089, 39.38765287399292, 40.03924798965454, 41.23329939161028, 43.31193290437971, 39.6035646711077, 40.0714876311166, 39.36801726477486, 36.976263182503835, 40.13582100187029, 40.1410356249128, 39.833094937460764, 31.349955899374827, 34.757244791303364, 32.77752583367484, 30.534755025591167, 28.12217024394444, 17.841626031058176, 10.49743744305202, 17.177056891577585, 18.526600292750768, 12.038504464285714, 10.35404052053179, 9.205491134098597, 12.49024420125144, 32.4806501524789, 46.31922789982387, 49.72451571055821, 47.19403736931937, 44.87060144969395, 42.06433868408203, 36.742213112967356, 26.373077630996704, 26.33735520499093, 17.242884125028336, 26.25378748348781, 38.18753916876656, 50.54762710843767, 46.41468225206648, 45.7439900125776, 56.3970445224217, 54.02896990094866, 59.40324865068708, 58.384260586329866, 56.57146862574986, 52.918734618595664, 47.37014293670654, 46.30878128324236, 47.946867738451274, 50.09594556263515, 49.46167230606079, 49.829464776175364, 51.84418181010655, 55.410685198647634, 62.31931727273123, 59.2574337550572, 50.87504012244088, 53.87551198686872, 14.616454635347639, 0.07600589655339718, 7.150898388453892, 59.31800815037319, 52.937251567840576, 51.9948604447501, 24.270681279046194, 29.06693070275443, 47.28768171582903, 30.097758497510636, 32.620934282030376, 46.112661429813926, 54.61723566055298, 44.474474225725444, 44.30866936274937, 34.091690744672505, 34.42154952457973, 32.992565631866455, 5.73818804536547, 0.437195393123797, 0.10557776223868132, 0.03713187894650868, 0.35955171659588814, 0.239835367671081, 4.061425745487213, 52.23601157324654, 29.242789609091624, 31.824274676186697, 36.68593617847988, 55.663346018110005, 72.5943967274257, 50.01548542295183, 36.61413696834019, 68.89724636077881, 72.21558788844517, 57.725154467991416, 45.627989837101524, 59.45925113133022, 66.44130829402378, 81.87746797289167, 64.05116271972656, 69.04365185328892, 8.88564383983612, 0.40112580146108356, 1.1416147585426057, 0.2823914826980659, 1.341613335268838, 6.591481115136828, 20.601172583443777, 40.77318620681763, 61.812876973833355, 64.5051371710641, 63.42886815752302, 64.76909923553467, 59.43423066820417, 60.84235954284668, 58.18400655473982, 56.0936062676566, 53.047842570713584, 55.33474138804844, 56.2477833202907, 57.277186734335764, 56.22166504178728, 58.56954819815499, 56.22801569529942, 54.69629921231951, 55.73302602767944, 56.68275097438267, 55.9690910748073, 58.13846458707537, 54.262933118002756, 60.63716534205845, 54.553246225629536, 51.94019896643502, 55.575277600969585, 51.80710622242519, 47.794479846954346, 44.16711023875645, 44.81068365914481, 42.688682964869905, 44.625243186950684, 48.03496394838606, 46.38074377604893, 43.227248259953086, 39.25584207262312, 36.046420506068635, 35.90537207467215, 33.70481852122715, 37.5492706980024, 36.77539076123919, 40.06369522639683, 37.02536262784685, 42.29505014419556, 44.93794339043753, 45.31478588921683, 43.027685574122835, 44.47747932161604, 45.148769106183735, 46.66382033484322, 47.54643957955496, 44.79546363013131, 42.899699756077354, 42.57656683240618, 40.93012516839163, 42.65834365572248, 44.386655943734304, 39.81486981255667, 42.83311169488089, 44.13195235388619, 44.01933247702462, 43.78035613468715, 44.451649393354145, 44.92109053475516, 45.452398436410085, 40.303025926862446, 40.53237206595284, 40.91726752689907, 43.77469335283552, 46.4807630947658, 43.12979282651629, 42.614201750074116, 43.4672703061785, 44.23474747794015, 41.84544958387102, 42.12664665494646, 43.45967592511858, 37.557539054325645, 41.37535183770316, 40.792787075042725, 41.41810757773263, 31.4793313571385, 35.85953828266689, 32.24502631596157, 32.09038025992257, 31.72431789125715, 29.50336790084839, 16.521501302719116, 22.44781790460859, 24.576612200055802, 16.614633219582693, 17.737845999853953, 15.998159510748726, 21.34702696119036, 41.41226414271763, 52.55410705293928, 57.48849534988403, 50.12177549089704, 49.01596621104649, 47.587329728262766, 43.454756600516184, 29.403063705989293, 28.716409717287334, 18.10644793510437, 29.966774531773158, 38.953400884355815, 53.390131677900044, 50.38268729618618, 46.72282443727766, 60.30009433201381, 53.78591844013759, 60.414128167288645, 60.08614540100098, 56.286641120910645, 52.9344653402056, 46.97486686706543, 46.69305488041469, 50.14240121841431, 52.338247367313926, 53.729530334472656, 52.999128750392366, 52.887488569532124, 56.09818513052804, 61.48604760851179, 59.770433153424946, 55.8100711277553, 60.35884829929897, 20.54369534764971, 0.2349654132766383, 7.485342110906329, 63.85866982596261, 64.45098291124616, 55.87535640171596, 31.28075531550816, 40.904760769435335, 56.340065819876536, 37.490631375994, 46.68216357912336, 45.49869080952236, 56.13769258771624, 48.48846244812012, 57.98791102000645, 48.221161774226594, 52.98685128348214, 54.41001605987549, 4.658789302621569, 0.49599563649722506, 0.39972245533551487, 0.17109867105526583], [0.13003643229603767, 0.09709329929734979, 0.06672882328608207, 11.018035565103803, 10.75566463811057, 16.233439411435807, 20.95124888420105, 29.995797157287598, 42.57052189963204, 51.41453300203596, 25.353603192738124, 29.396143300192698, 25.534152133124216, 25.61649697167533, 27.62394792693002, 38.91788516725813, 45.17908409663609, 67.41361141204834, 51.919239725385395, 48.61733763558524, 16.03477304322379, 0.22841836458870343, 0.4003138935991696, 0.5451465419360569, 4.194275736808777, 11.200892175946917, 34.98464890888759, 55.25490311213902, 59.12321540287563, 56.9440484046936, 60.23111956460135, 60.76058619362967, 58.84388392312186, 54.69795983178275, 50.31438997813633, 49.966264384133474, 48.460273606436594, 48.144672530038015, 50.8365193094526, 52.791641644069124, 50.90514666693551, 46.53183235440935, 43.1914233480181, 46.91067246028355, 46.866419383457725, 51.13600056512015, 52.73258195604597, 52.15827512741089, 53.697836126599995, 51.61115312576294, 50.22952468054635, 48.18945366995675, 50.447326387677876, 46.48582138334002, 41.4192088672093, 34.67001015799386, 32.13340697969709, 31.174572944641113, 34.08560412270682, 33.15982961654663, 32.794298785073416, 34.36445965085711, 32.7701016834804, 24.425188371113368, 22.20341154507228, 28.74228307179042, 30.515178476061138, 36.443958214351106, 34.64588253838675, 35.129706450871055, 35.03376572472708, 42.10187632696969, 39.84600816454206, 36.232218810490195, 38.13974598475865, 37.22480372020176, 39.2931295803615, 40.949371678488596, 37.40596757616316, 40.81658465521676, 38.71685988562447, 37.89161886487688, 36.8799854687282, 38.24274608067104, 36.17360380717686, 36.83735827037266, 37.21740736280169, 38.55249677385603, 35.0892470904759, 37.268949099949424, 38.59674637658255, 36.02693428312029, 36.31956114087786, 36.295228549412315, 35.42959417615618, 37.18365996224539, 35.886132512773784, 36.26256159373692, 38.64549841199602, 40.576142242976594, 40.1194406236921, 37.49726343154907, 36.17463908876692, 36.270044803619385, 35.034241676330566, 40.11307259968349, 37.18349320547921, 39.042942319597515, 34.714068685259136, 35.10185807091849, 31.42924874169486, 26.236503839492798, 22.75078194481986, 8.291974987302508, 13.534145900181361, 15.539766005107335, 8.769866875239781, 4.4649328248841424, 2.259332707950047, 4.248721820967538, 6.298584146159036, 23.45909867967878, 42.909340381622314, 45.0411171913147, 48.939977237156455, 47.01217869349888, 42.470495632716585, 42.95168965203421, 38.684901646205354, 32.60296276637486, 32.51429680415562, 37.42150722231184, 41.3567202431815, 48.2536689213344, 48.74681384222848, 50.56757886069161, 53.008543559483115, 52.37135205950056, 53.75527688435146, 50.80813939230782, 48.2615134375436, 43.26870468684605, 41.142020906720845, 38.96797820499965, 41.802745955330984, 42.23636218479702, 43.88514886583601, 43.02891193117414, 43.339652742658345, 45.4913569859096, 51.053855487278526, 50.99488959993635, 44.81713506153652, 44.113657746996196, 12.990469336509705, 0.14446414953895978, 9.521805269377571, 56.193910462515696, 45.498232228415354, 30.79121650968279, 19.883845772062028, 30.111908503941127, 35.78583526611328, 37.93235615321568, 44.01559434618269, 29.680470534733363, 25.476047822407313, 29.582014560699463, 37.88749163491385, 32.15775694165911, 31.81411988394601, 7.229253658226558, 0.4242339900561741, 0.17741134017705917, 0.10395401436835527, 0.1335258800536394, 0.03779314864160759, 0.0548688725435308, 0.574998065829277, 17.345760890415736, 17.53809744971139, 14.639474017279488, 12.779921548707144, 41.5849928855896, 52.53066383089338, 50.152562958853586, 19.854729345866613, 41.970374720437185, 43.62658207757132, 26.349434648241314, 33.619591917310444, 43.83094596862793, 53.398570265088765, 72.41644641331264, 57.317851066589355, 57.373718057359966, 23.317364113671438, 0.12370118152882371, 0.3527725003659725, 0.3520312144287995, 5.19309014081955, 11.828378779547554, 36.31507955278669, 57.370177950177876, 62.291580063956125, 63.53946263449532, 64.04572228022984, 62.56909806387765, 60.853031975882395, 59.27983474731445, 56.35414287022182, 54.41749232155936, 51.75650596618652, 52.79972587312971, 54.8825352532523, 57.95908989225115, 56.64389317376273, 54.17563942500523, 50.41535425186157, 54.03949294771467, 54.599927697862896, 57.20696129117693, 57.67268514633179, 53.70681667327881, 57.33668763296944, 53.88921383449009, 53.47735936301095, 53.83088370731899, 53.13257237843105, 50.36403138296944, 43.146221842084614, 40.582086426871165, 38.56037950515747, 41.88401903424944, 42.079777581351145, 42.222827093941824, 41.23031514031546, 40.38120705740792, 36.67014987128121, 30.509102276393346, 22.171380349567958, 28.928256818226405, 32.04928513935634, 35.62168060030256, 36.716511726379395, 36.38900491169521, 37.779054573604036, 43.91575915472848, 42.84585121699742, 37.896499974387034, 40.34205395834786, 41.06729997907366, 43.50048616954258, 43.47029972076416, 38.99250882012503, 41.26494148799351, 42.63069329942976, 38.49299240112305, 38.15881878989083, 40.09670959200178, 38.8369699205671, 39.16201359885079, 40.847445079258506, 41.31518043790545, 37.870114190237864, 41.846926076071604, 42.28087929316929, 39.0520236151559, 39.275974478040425, 38.74614306858608, 38.08317722593035, 37.64293588910784, 38.505082266671316, 38.304612840924946, 40.94604696546282, 41.69893986838204, 42.22620044435774, 39.960941791534424, 38.15274953842163, 39.51029552732195, 39.04808746065412, 42.21490962164742, 37.05988475254604, 38.94053282056536, 38.97682326180594, 35.92108195168631, 32.58225366047451, 30.78124237060547, 21.687160389763967, 10.22532514163426, 19.07431983947754, 22.43781249863761, 9.975943003382001, 5.922987546239581, 6.373739770480564, 9.42390775680542, 15.328184672764369, 32.76075983047485, 50.254229000636506, 47.83218077250889, 50.70906850269863, 47.4654027393886, 47.090311186654226, 48.45409318378994, 49.260911055973594, 41.168114866529194, 42.179247992379324, 46.376015526907786, 47.154137338910786, 51.07864318575178, 55.0327935218811, 55.127111843654085, 56.55939613069807, 57.250696727207725, 57.64809199741909, 56.394859313964844, 53.049412863595144, 48.82654789515904, 47.690882205963135, 44.900061811719624, 48.09920004435948, 50.45210327420916, 49.72157662255423, 49.54483529499599, 49.85583666392735, 51.3935181753976, 56.219789028167725, 58.66229970114571, 56.35611268452236, 51.74690008163452, 17.303276130131312, 0.18572017789951392, 13.334999237741743, 63.14922400883266, 52.74926805496216, 37.23419073649815, 24.03817892074585, 34.41875287464687, 41.73576879501343, 34.3097425869533, 42.227492809295654, 25.652853420802526, 19.76213938849313, 51.932410035814556, 39.76655551365444, 28.1000645501273, 51.86620759963989, 12.810788052422659, 0.5016853426183973, 0.07251925114542246, 0.05837917168225561, 0.0842671621856945, 0.22481385086263928, 0.2583956888743809, 0.47005920537880486, 25.654781545911515, 50.43441316059658, 43.45774780000959, 45.9896296773638, 51.691387448992046, 59.282544544764924, 64.97964354923793, 37.32964856284005, 38.89709268297468, 38.51361118044172, 33.27013226917812, 46.34777109963553, 53.10909441539219, 58.71072169712612, 78.94844096047538, 63.62890679495675, 66.76193291800362, 26.991222381591797, 0.24268068213547977, 2.400679260492325, 0.8956365862062999, 5.8083222934177945, 14.771726029259817, 43.17900691713606, 62.89415563855852, 63.62247276306152, 65.2027918951852, 64.96381555284772, 65.16088036128453, 62.64042132241385, 61.85255813598633, 59.58427701677595, 57.74878529139927, 52.97148534229824, 54.72878898893084, 56.92769234521048, 58.01301138741629, 56.51388542992728, 53.95089646748134, 50.44954981122698, 55.3642886025565, 59.243829182216096, 57.4921327318464, 58.794586454119, 55.499035017830984, 58.54580620356968, 54.280192443302695, 55.29319116047451, 58.52869973863874, 56.503414494650706, 52.03435747964041, 48.961141450064524, 43.55007198878697, 43.85170718601772, 44.782949924468994, 47.93949917384556, 47.70216955457415, 47.45545291900635, 46.2164431980678, 40.11563648496355, 34.1162109375, 32.92257990155901, 34.54790946415493, 34.19427742276873, 36.33560800552368, 39.552842821393696, 38.154389313289094, 39.6557491166251, 45.89384528568813, 45.524951526096885, 41.62175580433437, 42.62152862548828, 42.85452256883894, 45.713160855429514, 46.12687397003174, 42.132316384996685, 46.49627842221941, 45.25751188823155, 42.26401948928833, 42.380679743630544, 42.80152865818569, 42.246075766427175, 40.088465554373606, 44.200815950121196, 43.40049811771938, 40.95585782187325, 44.57039063317435, 46.33345781053816, 40.782402992248535, 42.40639155251639, 40.742749622889924, 39.831430843898225, 39.77654702322823, 40.52121325901577, 39.11149672099522, 43.538569246019634, 44.44783135822841, 44.5684312411717, 41.12981986999512, 41.148222173963276, 42.68040418624878, 41.771809101104736, 43.366038526807515, 41.76927648271833, 38.57191004071917, 37.92848253250122, 37.654327460697715, 36.18315410614014, 31.574347972869873, 32.87097215652466, 15.640170948845999, 22.914500611168997, 27.30201530456543, 14.45787329333169, 10.661566921642848, 11.634957432746887, 18.90492970602853, 26.457885605948313, 42.33234807423183, 54.79940700531006, 49.23682165145874, 53.70311328342983, 50.39097997120449, 50.80146564756121, 49.67750072479248, 52.756664412362234, 43.338012967790874, 42.50043542044503, 49.145456314086914, 48.47413526262556, 54.88533190318516, 54.31910930361067, 56.454731941223145, 56.849010944366455, 57.47741992133004, 57.872751576559885, 56.29385682514736, 54.345578466142925, 51.00390141350882, 49.520019803728374, 47.406117234911235, 49.84013373511178, 52.19626440320696, 53.29726552963257, 54.2735048021589, 53.12732648849487, 53.8693002973284, 59.46232918330601, 64.0260032926287, 61.09471811567034, 58.53745446886335, 21.316798823220388, 0.32469333708286285, 14.636184045246669, 71.17087064470563, 59.236144474574495, 44.55219677516392, 31.97398751122611, 48.29406574794224, 46.45155981608799, 51.12729099818638, 52.613389083317344, 45.55562782287598, 31.70522424152919, 53.443271500723704, 52.66442012786865, 53.07989113671439, 79.56571892329625, 12.86754788671221, 0.9918590400900159, 0.3207882052021367, 0.3362862435834748, 0.21291888771312578], [0.05660379837666239, 0.015406118938699365, 0.16654871377561772, 1.1979330565248216, 15.060826676232473, 26.451548848833355, 47.21536833899361, 32.251814705984934, 20.30493787356785, 30.558920860290527, 51.859735352652415, 41.27015263693673, 27.144801889147075, 30.636428015572683, 26.52375626564026, 36.472428458077566, 39.4535356930324, 60.69548852103097, 53.53518227168492, 48.32933132989066, 33.59643357140677, 0.2958610270704542, 0.09542571127946887, 0.12017290799745492, 6.1760561381067545, 20.13077085358756, 44.00917421068464, 61.59953948429653, 58.91315051487514, 62.99860095977783, 58.80475861685616, 60.938328061785015, 56.183102539607454, 54.205735547201975, 49.38579797744751, 48.94795376913888, 46.19578620365688, 47.276366574423655, 50.97269357953753, 53.803351470402305, 52.18313578196934, 51.77111107962472, 47.53774390901838, 41.788144315992085, 48.675587858472554, 51.54560729435512, 53.67197840554373, 55.075688225882395, 54.399896008627756, 53.9433958871024, 53.85015453611101, 52.1518862588065, 54.70095797947475, 51.32126733234951, 41.12249646868025, 38.982187271118164, 37.57545498439244, 39.37624740600586, 37.85499143600464, 39.72787141799927, 35.08121149880545, 34.924717221941265, 31.101995536259242, 29.959895815168107, 11.733102474893842, 15.367471524647303, 28.095831360135758, 31.301575592585973, 36.384599753788535, 36.6799989427839, 33.75678062438965, 38.85079336166382, 42.417758805411204, 37.87136834008353, 37.32944706508091, 36.44072035380772, 40.59262684413365, 40.35319192068917, 35.68248776027134, 35.71474477222988, 36.83065325873238, 37.1485333442688, 37.22614124843052, 33.906448296138215, 35.00447906766619, 35.97961357661656, 36.35485451562064, 37.87627376828875, 35.936374936785015, 38.74130712236677, 36.649718693324495, 37.6202152797154, 36.49218566077096, 36.4914630481175, 35.713952677590505, 36.059490067618235, 36.31001431601388, 37.020943573543, 40.39374508176531, 40.4223438671657, 38.537735325949534, 35.71525199072701, 35.64917809622628, 36.17143249511719, 36.53118242536272, 39.56412322180611, 32.84288058962141, 34.60094506399972, 36.37138775416783, 32.145542008536204, 27.70624586514064, 26.998352970395768, 9.877005866595677, 15.70052821295602, 21.66897347995213, 12.294214674404689, 4.131188699177333, 6.030142230646951, 6.348242052963801, 13.147199852125985, 11.41552984714508, 29.45172541482108, 46.45633670261928, 47.64620876312256, 44.58870955875942, 42.58767352785383, 44.34809691565377, 45.45212745666504, 45.93231051308768, 44.64823825018746, 40.5301764351981, 43.99351991925921, 45.70941230228969, 47.46160554885864, 47.32715443202427, 47.81705801827567, 48.84403998511178, 50.30143853596279, 49.22396748406546, 47.022204944065635, 42.23543112618582, 40.420856952667236, 39.94193499428885, 40.67779786246163, 40.77730301448277, 42.29321929386684, 42.28298807144165, 44.58292865753174, 45.45831135341099, 45.5817426272801, 49.5105494090489, 50.2001233782087, 46.16781970432827, 42.492740290505544, 11.904270478657313, 0.2051649559289217, 19.267248732703074, 53.37245198658535, 46.52998413358416, 29.282971041543142, 23.508540323802404, 25.2255756855011, 33.571534701756065, 28.864738123757498, 33.00484309877668, 44.2439295223781, 45.728596278599326, 15.18625729424613, 38.75693709509713, 52.692841734204976, 21.78743158067976, 0.13297110982239246, 0.060089120641350746, 0.05812568456998893, 0.047378694106425555, 0.022544107167050242, 0.0035790097151350763, 0.04004616988822818, 0.16488029115966388, 5.199602774211338, 23.314607415880474, 29.354711191994802, 38.81009776251656, 34.431506293160574, 33.6823410987854, 50.05473927089146, 47.745873723711284, 31.788838863372803, 22.81057119369507, 18.029844045639038, 32.719984327043804, 45.82045146397182, 45.33089528764997, 68.89076369149345, 61.505620683942524, 52.27138485227312, 40.90271799904959, 0.8035319713609559, 0.03319941567523139, 0.8246873904551778, 8.954494408198766, 23.402823482240947, 53.237295627593994, 66.21198299952916, 65.31346975054059, 66.11286694662911, 60.10528073992048, 61.39514432634626, 59.74643407549177, 58.40344456263951, 53.59071574892317, 52.51629843030657, 51.60614000047956, 50.34242248535156, 55.48313059125628, 59.357029233660015, 58.70499638148716, 56.41282735552107, 52.77055386134556, 47.50825228009905, 53.815073081425254, 57.39916583469936, 58.42638751438686, 58.770872252328054, 57.25099202564785, 57.99108287266323, 55.565887110573904, 54.535983426230295, 56.04960332598005, 53.36731726782662, 43.112116609300884, 42.297930172511506, 42.33631896972656, 44.45564113344465, 45.142258644104004, 45.234297956739155, 43.665877614702495, 42.502002239227295, 34.69593388693673, 34.69197341373989, 16.956672191619873, 13.793171269553048, 28.33476253918239, 32.63271842684065, 36.884088379996165, 36.31992244720459, 36.43149662017822, 39.33029202052525, 43.00284229006086, 40.49092953545706, 41.31108100073678, 39.32202019010271, 42.38499110085623, 41.83011143548148, 38.78957278387887, 38.29799815586635, 39.3647585596357, 39.71980108533587, 39.5011864389692, 37.71488448551723, 37.3318441935948, 36.029296670641216, 40.68453414099557, 39.75702953338623, 39.977690424237935, 41.25411966868809, 38.35762759617397, 40.238383361271445, 39.403255053928916, 36.690146786826, 36.72709730693272, 36.978552613939556, 38.03807299477713, 38.28730140413557, 41.76006317138672, 42.16188097000122, 41.416082177843364, 38.11198098318917, 37.23097372055054, 37.66973161697388, 39.16941690444946, 41.38488824026925, 36.65249102456229, 33.11190789086478, 36.784152439662385, 34.44421802248274, 31.945659705570765, 27.681741305759974, 11.421085800443377, 21.982974733625138, 26.331404072897776, 12.442521367754255, 6.660691687038966, 8.8939208814076, 10.88795747075762, 23.210716213498795, 18.019585030419485, 41.96113361631121, 51.95701360702515, 50.843095779418945, 47.78853218896048, 46.06352724347796, 48.14470379693167, 48.22424677440098, 50.29355233056204, 49.15920679909842, 44.882680892944336, 47.57668856212071, 49.79120799473354, 52.38404989242554, 52.03607021059309, 53.179927825927734, 52.564925398145405, 54.846884046282085, 52.75998912538801, 50.16450343813215, 46.597228799547466, 44.98050110680716, 46.04633740016392, 45.833076340811594, 46.910026277814595, 47.079145431518555, 48.28101008278983, 51.107964583805625, 53.988371576581685, 54.25829866954258, 57.62512125287737, 58.511086055210654, 53.10261174610683, 53.93077448436192, 13.196314930915833, 0.20637478386717184, 22.880468334470475, 63.139371463230674, 53.72149821690151, 39.6529073034014, 27.264649629592896, 34.33815029689244, 41.3321270942688, 29.91120978764125, 35.869095529828755, 33.896390778677805, 52.63106877463204, 27.665762186050415, 38.21317107336861, 64.27885518755231, 35.59838329042707, 0.4744243568607739, 0.031976064534059594, 0.10686655129705157, 0.024579734275383607, 0.040843367110937834, 0.12677624795053685, 0.17333276117486612, 0.30153374267475946, 2.4611650662762776, 36.43140976769583, 54.32057884761265, 72.57235009329659, 49.01017836162022, 30.342078004564556, 48.38427768434797, 65.46104948861259, 49.836635317121235, 36.84652294431414, 42.28695896693638, 42.999500206538606, 54.89739397593907, 51.76133496420724, 74.90710462842668, 67.88864585331508, 59.47506523132324, 48.67315598896572, 0.7565998754331044, 0.3454490719097001, 1.6092619619199207, 12.32292376245771, 26.53442175047738, 57.115210328783306, 62.929487228393555, 67.6948605946132, 69.26952389308384, 61.891829354422434, 61.94421877179827, 61.39952169145857, 59.43512698582241, 55.04044696262905, 53.095583643232075, 53.032487051827566, 52.24824387686593, 56.681191103799, 60.11630753108433, 59.39223575592041, 58.516901697431294, 53.12434918539864, 46.267092091696604, 52.375618253435405, 55.61352743421282, 57.929379395076204, 58.188429083142964, 58.936982836042134, 60.544643129621235, 57.462158203125, 57.26037904194423, 57.836280482155935, 54.78939812523978, 45.61736604145595, 46.29397814614432, 46.98031078066145, 48.42566810335432, 48.22158214024135, 51.48712083271572, 44.44666406086513, 48.09584059034075, 40.26695435387747, 36.95284080505371, 22.78582865851266, 25.615699665887014, 36.62524366378784, 33.601919174194336, 40.29019260406494, 40.191281523023335, 36.42204359599522, 42.55552421297346, 44.8073103087289, 42.56006138665335, 42.90971211024693, 41.36896644319807, 44.97926432745797, 45.14330087389265, 40.92998273032052, 40.791456495012554, 42.955879415784565, 41.86494970321655, 44.8023110798427, 40.17750324521746, 39.36119760785784, 41.26369081224714, 41.08305154527937, 43.056068965366904, 43.24839162826538, 44.300296783447266, 41.09782688958304, 43.1153301511492, 39.94678831100464, 39.11476237433297, 41.60665042059762, 39.30427796500069, 40.94388607570103, 39.108508995601106, 45.7823405947004, 44.77704742976597, 45.68782424926758, 40.60542542593819, 39.783359731946675, 40.49280902317592, 41.78748771122524, 45.12390497752598, 37.633955342429026, 37.61674118041992, 38.68401575088501, 38.466141087668284, 35.74595955439976, 37.28708389827183, 20.03041454723903, 22.988101141793386, 31.94154289790562, 19.446159635271343, 11.083056807518005, 13.366560561316353, 16.790116923195974, 32.25287083217076, 28.571569306509836, 49.2989559173584, 50.08814968381609, 51.12514053072248, 48.421940394810264, 47.72165925162179, 49.72636045728411, 50.97822781971523, 52.91892221995762, 51.32422726494925, 46.63343933650425, 50.55612128121512, 51.80543865476336, 53.44461597715105, 52.42115674700056, 54.36069427217756, 52.83292784009661, 54.54970611844744, 54.01315927505493, 54.45797947474888, 47.59589685712542, 48.18467330932617, 47.32726560320173, 48.58236040387835, 48.721789905003135, 50.4382381439209, 50.70100859233311, 54.99335902077811, 55.037365436553955, 54.27910157612392, 60.52613312857491, 61.92839772360665, 59.27621473584856, 63.48557240622384, 17.876528569630214, 0.33649270821894917, 24.391717161451066, 69.65764331817627, 60.44038540976388, 46.32614483152117, 35.58732523236956, 43.45092466899327, 44.54068013599941, 40.43884236471993, 45.03176839011056, 60.49998010907854, 61.1267979485648, 33.33681413105556, 58.048912729535786, 87.71186338152204, 44.116812229156494, 0.3909974449447223, 0.12428890142057623, 0.2651978667293276, 0.12748275218265398, 0.13550003697829588], [0.013496951249960278, 0.11733900649206978, 0.11307185582284417, 0.20750719095979417, 2.9024812025683264, 38.21651315689087, 55.36001893452236, 56.27244595118931, 29.64128269468035, 16.449846267700195, 30.68429068156651, 58.30873366764614, 56.65514578138079, 29.609487737928117, 22.323848145348684, 38.018225465502056, 38.34171969549996, 52.47008943557739, 60.63540049961635, 46.13659102576119, 49.95630414145333, 6.286000089985984, 0.27653561692152706, 2.416106866938727, 7.950484922954014, 43.221939836229595, 56.11823068346296, 58.526650020054404, 56.06097752707345, 58.04250649043492, 56.57464395250593, 54.8342730658395, 50.195864132472444, 48.73482125146048, 45.346632957458496, 47.75414555413382, 44.76956769398281, 43.274325779506135, 47.34218685967581, 52.761920724596294, 52.57512535367693, 51.58519812992641, 49.90253898075649, 48.344533988407676, 50.77554191861834, 52.67531490325928, 52.44886268888201, 54.905915941510884, 52.548930644989014, 51.5945017678397, 51.431635992867605, 54.88339335577828, 54.11046879632132, 51.91473034449986, 49.13042041233608, 40.7224817276001, 42.553665569850374, 42.77245739528111, 43.52450261797224, 43.44900696618216, 40.82995646340506, 40.367585114070344, 33.24751935686384, 34.42829622541155, 26.177741186959402, 8.741495643343244, 12.645961148398262, 28.957937785557338, 33.471633502415244, 33.18678167888096, 34.772937297821045, 37.85764217376709, 39.468804359436035, 37.78912946156093, 36.748744419642854, 38.14987645830427, 38.52677801677159, 41.24247101375035, 38.96011631829398, 36.44974258967808, 36.45474181856428, 34.265979358128135, 35.77347789491926, 31.96089015688215, 35.37613126209804, 33.90605224881853, 38.18506908416748, 36.933962549482075, 36.589314528873985, 38.98703016553606, 36.774164404187886, 35.51337555476597, 39.57086297443935, 35.811727728162495, 36.2019350869315, 35.81243297031948, 38.059129510607036, 36.8189629146031, 41.05875022070748, 38.32214662006923, 37.53048971721104, 37.275674956185476, 37.08813960211617, 32.278919628688264, 39.48818635940552, 35.56946836199079, 34.82647664206368, 26.437732355935232, 31.407090936388286, 31.818042142050608, 28.141081503459386, 9.634116819926671, 15.867613281522479, 25.065327644348145, 15.880295481000628, 6.670783076967512, 6.479808798858097, 6.629606749330248, 11.85630098411015, 21.42040514945984, 26.26050639152527, 43.01144068581717, 47.07014056614467, 42.44471434184483, 42.01172692435128, 41.18126433236258, 45.516377449035645, 47.31941066469465, 48.57405035836356, 46.445678165980745, 47.66172409057617, 46.63954332896641, 48.124897956848145, 46.89965261731829, 45.40937519073486, 45.48702825818743, 46.97227866309029, 44.693134035382954, 40.93812949316842, 40.25015708378383, 39.62478794370379, 39.50745023999895, 41.11785159792219, 41.317647048405235, 43.38316583633423, 44.74862582342965, 45.768864563533235, 47.21417324883597, 47.645809241703574, 50.49135364804949, 48.99799469539097, 50.27339560644967, 46.05782624653408, 42.24646486554827, 9.672397920063563, 0.2915027423628739, 24.959652491978236, 54.89693539483206, 45.87681177684239, 32.46500628335135, 46.063020024980815, 24.808801889419556, 37.05957555770874, 26.03022571972438, 30.158662932259695, 54.26339169910976, 27.995857204709733, 29.185797010149273, 53.35272952488491, 58.61780343736921, 3.1509965530463626, 0.1937790433210986, 0.09748140775731631, 0.11350963304617576, 0.01468334174049752, 0.08203100253428731, 0.04255303447800023, 0.02207577890450401, 0.08698276789592845, 0.49844275947128025, 8.665504932403564, 42.26556198937552, 62.091228757585796, 47.272044794900076, 19.122350999287196, 20.214970861162456, 40.811515944344656, 59.52979619162423, 51.18101446969168, 24.30328917503357, 28.527297122137888, 44.241598401750835, 45.274906703404014, 55.45639392307827, 68.18620940617153, 51.29363087245396, 58.34052862439837, 8.937050087111336, 0.3403728971523898, 2.7853174209594727, 13.330838135310582, 52.58185468401228, 63.777229990277974, 64.56899111611503, 61.364329065595356, 63.45460428510393, 59.92140361240932, 61.55204854692732, 57.27683585030692, 53.33972249712263, 51.98800604684012, 51.98134272439139, 49.6372115952628, 49.3185533114842, 52.13175732748849, 58.483432224818635, 57.31557205745152, 58.333948680332725, 54.64216232299805, 53.035308020455496, 55.56777702059065, 57.009889534541536, 57.87146268572126, 57.415118898664204, 53.577180658067974, 56.727688448769705, 54.10605321611677, 59.53309658595494, 55.26847294398716, 51.75162833077567, 50.888450145721436, 43.78850637163435, 46.48434836523873, 47.583553382328574, 50.31138488224575, 47.8721468108041, 45.11101259504046, 45.067655835832866, 41.52586718967983, 39.09781224387032, 35.86647605895996, 14.523129037448339, 16.495801653180802, 28.68271095412118, 35.62292085375105, 36.510157176426475, 35.35343497140067, 39.75659874507359, 40.4520126751491, 40.460899421146934, 40.019897256578716, 38.87296158926827, 41.13110876083374, 44.905651637486045, 40.961169719696045, 39.576497963496614, 38.33252722876412, 37.05554212842669, 36.869313035692485, 34.82002871377127, 39.24568728038243, 38.08822856630598, 39.71032721655709, 41.95157289505005, 39.83245570319039, 42.119934695107595, 40.31877054486956, 39.41287136077881, 39.456651960100444, 37.91467646190098, 37.83446645736694, 37.596747738974436, 40.69057559967041, 40.0876248223441, 41.366854190826416, 39.877410548073904, 39.36987590789795, 39.15089300700596, 39.51854998724801, 35.56841570990426, 41.40980100631714, 37.608451979500906, 34.72375099999564, 32.70779718671526, 35.06914247785296, 35.54379824229649, 28.440880639212473, 12.671613897596087, 21.346337352480205, 31.31539555958339, 21.486419984272548, 11.000262941632952, 10.323430231639318, 9.19766138281141, 21.1427447114672, 30.695960181100027, 37.32834577560425, 50.360397475106375, 51.70443269184658, 45.31451143537249, 44.25106184823172, 43.784764766693115, 48.237302439553396, 51.33050843647548, 52.154721123831614, 49.00488036019461, 51.20307500021798, 51.66307701383318, 50.17259808949062, 50.05779995237078, 49.60246018001011, 49.52026299067906, 50.747644901275635, 47.740739004952566, 44.7722601209368, 45.44023561477661, 43.69207927158901, 44.595480578286306, 43.78718968800136, 46.81045511790684, 48.28383799961635, 52.04800374167306, 51.348938533238, 53.56026874269758, 53.55653061185564, 54.091812883104595, 51.80393436976841, 60.09751960209438, 54.06038965497698, 54.283624853406636, 10.216383678572518, 0.36765176909310476, 28.87943008967808, 62.31950487409319, 52.44323117392403, 42.976029191698345, 42.96228218078613, 33.08643926892962, 41.753583976200645, 31.552857194628032, 39.14696032660348, 59.10455254146031, 45.12616661616734, 21.955237524850027, 56.72860213688442, 69.4144424710955, 4.31885780606951, 0.2380688153207302, 0.026238947474796857, 0.05247993055464966, 0.01400865231906729, 0.059327268307762485, 0.1340838936822755, 0.2427608035504818, 0.19666299356945924, 0.4005821592041424, 6.565406697137015, 66.07198374611991, 79.46626240866524, 69.96223844800676, 44.191425459725515, 28.045828648975917, 45.2087459564209, 73.02490711212158, 74.88862936837333, 42.475022384098594, 37.05494458334786, 50.89027057375227, 49.867985589163645, 63.45764759608677, 72.82538264138358, 63.1398161479405, 66.66505418504987, 10.452456542423793, 0.5243111199566296, 3.7006470475878035, 20.121620076043264, 53.35699571881975, 64.3457315989903, 64.5568665095738, 61.735967363630024, 64.06897790091378, 63.40979535239083, 62.78780651092529, 56.88066693714687, 54.85203613553728, 52.31869861057827, 52.917192118508474, 50.26348052706037, 48.97730643408639, 51.6377716745649, 57.1195981161935, 57.88406324386597, 58.4629419871739, 55.10105609893799, 51.90776824951172, 53.930833544049946, 56.488097190856934, 57.805555547986714, 59.408987862723215, 54.70875038419451, 56.77513074874878, 54.85619115829468, 61.110963003976, 56.70482540130615, 56.22903708049229, 54.19535493850708, 47.538508210863384, 48.454784529549734, 49.73846769332886, 53.25001777921404, 50.39643430709839, 48.49985749380929, 50.146952288491384, 44.588035583496094, 42.78681237357003, 37.469783306121826, 19.285908120019094, 23.445930106299265, 35.1600318636213, 38.84428637368338, 38.15647724696568, 38.39023896626064, 41.92039632797241, 43.49757487433297, 43.70002106257847, 42.39182465417044, 44.01770312445504, 43.95190020969936, 46.270840644836426, 44.16178444453648, 42.03668832778931, 39.97461584636143, 38.96681090763637, 38.89001941680908, 36.36398444856916, 40.95672287259783, 39.18556799207415, 43.2675130707877, 45.701362814222065, 42.664749894823345, 43.521969999585835, 42.09908662523542, 41.652053424290244, 42.899477413722444, 39.45542212894985, 39.706175667899, 39.39509786878313, 42.72953837258475, 41.48889929907662, 45.17060382025582, 42.63945845195225, 42.426822730473106, 43.5076219694955, 42.68327726636614, 37.67780542373657, 44.7968567439488, 39.99638107844761, 36.544769627707346, 32.74336848940168, 37.93254028047834, 42.23172773633684, 37.58825356619698, 23.798010962350027, 22.839493070329937, 34.5801282610212, 26.820312329701014, 21.47273898124695, 22.662718738828385, 25.712449857166835, 33.45991883959089, 39.65111466816494, 45.63324267523629, 53.05316489083426, 51.24622678756714, 47.27277782985142, 46.1916172845023, 46.7650660106114, 50.426134381975444, 53.41332129069737, 53.51934732709612, 50.212529386792866, 52.35757030759539, 52.216573987688335, 51.7358524458749, 51.483969824654714, 49.945871421269004, 48.21369593484061, 52.25569234575544, 49.579291411808555, 46.89604650224958, 47.9921213558742, 46.60126917702811, 46.27880328042166, 46.612191745213096, 49.25219801494053, 50.21721594674246, 54.52119418552944, 53.2682637487139, 58.35878154209682, 57.61107199532645, 53.561832087380544, 54.360253061567036, 65.80217824663434, 58.44225719996861, 63.85253456660679, 13.612029126712255, 0.2590852975845337, 30.89609956741333, 68.70478125980922, 59.28127302442278, 49.419604437691824, 62.249390602111816, 39.217029435294016, 51.43845912388393, 34.67017691476004, 45.92434092930385, 70.5400367464338, 45.34395442690168, 43.79503420421055, 72.80177961077008, 81.95582975660051, 4.058424557958331, 0.32308135500976015, 0.25015813804098536, 0.262079048369612, 0.09819027329129831, 0.13676098574485096], [0.11538508348166943, 0.1740087584725448, 0.06753443434302296, 0.1489918508699962, 0.33669705582516535, 18.22277467591422, 57.29424108777727, 57.377595152173726, 56.2052777154105, 42.335016182490754, 22.357856103352137, 29.04764597756522, 58.638773100716726, 24.093227761132376, 18.897755690983363, 37.139816829136436, 35.27448606491089, 46.17104019437517, 53.46624224526541, 43.879701478140696, 46.69866555077689, 13.686902046203613, 0.2746947785573346, 1.9647987868104662, 7.480179599353245, 51.01357678004673, 47.68686614717756, 57.21510110582624, 52.65946953637259, 53.76934698649815, 51.674812521253315, 50.395968777792795, 47.65991408484322, 47.28069182804653, 43.96173538480486, 46.04817867279053, 43.78422975540161, 45.16795655659267, 43.51420191356114, 49.2679808480399, 52.720915930611746, 53.352812903267996, 52.569691862378804, 54.190591948372976, 54.07348700932094, 53.1203852381025, 50.73134790148054, 55.06078781400408, 54.46316630499703, 53.73168427603585, 52.899460315704346, 52.47955983025687, 49.238798413957866, 51.0232834134783, 47.52290603092739, 42.89870963777815, 45.951258250645225, 44.72182662146432, 49.709729943956646, 46.0867064339774, 46.02933515821184, 46.33429854256766, 45.25856106621878, 39.08323492322649, 41.316611766815186, 24.36190070424761, 11.389519265719823, 19.516687325068883, 27.947383097239904, 31.736216681344168, 37.53928961072649, 38.51874589920044, 39.99566888809204, 38.09453405652727, 36.242456981113975, 36.38725743974958, 35.98660346439907, 41.35941961833409, 37.98020839691162, 35.53684656960623, 37.823293754032676, 37.75647987638201, 37.299854687282014, 36.625306197575156, 35.382495812007356, 35.45543105261666, 37.28686850411551, 37.343357358660015, 38.15413570404053, 40.201203550611226, 38.370759691510884, 38.843570709228516, 36.59210770470755, 34.8047913142613, 35.68241480418614, 35.69751671382359, 37.54610231944493, 36.62506995882307, 36.93353870936802, 35.14592007228306, 37.385178565979004, 36.50684983389718, 35.5511668069022, 34.93722745350429, 38.085008076259065, 35.778421538216726, 28.937204360961914, 31.766097409384592, 33.13563598905291, 24.537394830158778, 13.11774730682373, 7.70202602658953, 29.02217561858041, 37.26839671816145, 28.49244495800563, 18.782208885465348, 15.330116271972656, 19.86367862565177, 26.980600322995866, 37.06548152651106, 43.83333962304251, 48.39135789871216, 47.76576294217791, 44.86813831329346, 41.13071618761335, 38.79720885413033, 44.41429935182844, 47.809383732931956, 47.31115967886788, 47.69612462180001, 45.38269758224487, 50.14894642148699, 47.54267365591866, 47.98324155807495, 41.645091329302105, 40.25455181939261, 40.21019451958792, 41.62223175593785, 39.70765216009957, 41.010321276528494, 37.65858670643398, 40.21923412595476, 39.002562863486155, 44.06767109462193, 43.39935861315046, 45.97101892743792, 47.316318716321675, 49.625316279275076, 47.67795508248465, 51.543609687260215, 50.853094237191335, 55.26765653065273, 49.931561606270925, 46.935800620487754, 5.1017226321356635, 0.741773396730423, 27.52513412066868, 56.954331738608225, 41.32303537641253, 36.45919213976179, 30.47653259549822, 27.7165014062609, 36.150567054748535, 30.813155446733745, 36.09747239521572, 50.17068386077881, 28.46448540687561, 43.54449953351702, 65.15977559770856, 22.665503229413712, 0.6026330058063779, 0.2617035742316927, 0.08253496406333787, 0.04919045724506889, 0.03596387251413294, 0.04498256303902183, 0.021654050730701004, 0.024934769242203662, 0.04303708100425346, 0.314594211855105, 0.7268327612962041, 32.37841088431222, 74.97183404650006, 68.53302179064069, 48.37815979548863, 30.05756664276123, 23.535469804491314, 35.88016748428345, 71.34247725350517, 21.83069280215672, 26.754714386803762, 40.608156067984446, 43.182279518672395, 49.95219428198678, 61.40098081316267, 52.54272242954799, 55.61225243977138, 17.54680006844657, 0.21858312162969792, 2.3480555585452487, 14.420525857380458, 61.75586005619594, 54.90479033333914, 63.67470237186977, 57.40608276639666, 56.54719509397234, 54.042101996285574, 54.549264907836914, 50.68897778647286, 53.40748480388096, 48.8086701801845, 52.23109572274344, 48.893500736781526, 49.445691449301584, 46.52717358725411, 55.550941535404746, 58.951768602643696, 59.8681526184082, 58.866812978472026, 57.83711774008614, 57.10992274965559, 57.43191269465855, 54.44709512165615, 56.108680384499685, 57.82603883743286, 56.42121730531965, 53.67156498772757, 55.20018604823521, 53.58476114273071, 53.74549729483468, 49.34654065540859, 45.655004433223176, 50.71784060341971, 46.38744878768921, 53.386633259909495, 49.342514174325125, 50.442316736493794, 48.19154507773263, 48.92898518698556, 44.80259943008423, 45.72982610974993, 31.582129955291748, 19.52521971293858, 23.85797565323966, 33.09917531694685, 34.50799553734915, 42.42822279248919, 41.21728031975882, 41.22649015699114, 39.446716036115376, 38.08966684341431, 40.64399140221732, 37.94062103543963, 42.612819058554514, 41.026545320238384, 38.26967035021101, 38.4164718900408, 39.59710284641811, 38.609294823237825, 37.62621852329799, 36.673936639513286, 38.29299545288086, 38.94721351351057, 39.5537599836077, 41.026889256068635, 40.12044811248779, 39.91528517859322, 37.928041321890696, 37.78071171896798, 35.39752129146031, 36.279014928000315, 37.099840368543354, 37.50452777317592, 38.563606943402974, 39.458281312670024, 37.59152964183262, 39.31285204206194, 38.36418669564383, 38.2895804132734, 37.98909861700875, 41.13361011232649, 37.16944742202759, 31.644472667149135, 34.83150366374424, 36.08277348109654, 28.200961078916276, 16.752817256110056, 17.57738082749503, 35.004972389766145, 46.2088349206107, 38.54758439745222, 29.662922859191895, 23.65379762649536, 29.1829343523298, 34.65203169413975, 47.24355023247855, 50.49788842882429, 54.54562405177525, 49.733603954315186, 48.83443062646048, 45.766755785260884, 44.41710294995989, 45.61919341768537, 52.41039398738316, 49.014340332576204, 49.61625235421317, 49.285823822021484, 54.59242016928536, 51.63541276114327, 50.528189522879465, 44.227166993277415, 45.14730303628104, 44.04489489964077, 46.373184135981965, 43.25725058146885, 45.62542595182146, 43.34424550192696, 44.377539907182964, 43.99201910836356, 49.29505797794887, 48.35772166933332, 52.456113134111675, 52.280775342668804, 54.799900327410015, 54.40623276574271, 59.60778972080776, 56.47392633983067, 64.26707799094063, 57.09084299632481, 55.01590592520577, 4.031030850751059, 0.622181599693639, 31.864588124411448, 65.14459378378731, 47.84855767658779, 44.446254117148264, 32.27447625568935, 37.98640619005476, 35.54492037636893, 36.323709215436665, 38.19670384270804, 64.78501755850655, 31.20508943285261, 36.548556395939414, 78.00618185315813, 27.26694600922721, 0.9282272202627999, 0.24546115579349653, 0.15183692106178828, 0.05327742972544261, 0.0820834736472794, 0.015683707614828433, 0.1965926702001265, 0.24849643292171614, 0.14679813358400548, 0.31152818351984024, 0.7107246113674981, 29.44756691796439, 85.30587591443742, 74.1374318259103, 69.05084323883057, 58.3179817199707, 34.971607140132356, 42.65005445480347, 73.0488645008632, 35.67146096910749, 32.79443774904524, 49.51530545098441, 45.25759874071394, 59.03429235730852, 65.11869089944022, 61.477209499904085, 63.18973200661795, 20.19680827004569, 0.49977377376386095, 4.906853888716016, 23.35433200427464, 62.29488740648542, 58.305968284606934, 63.488768577575684, 58.28737490517752, 59.306557519095286, 56.25330366407122, 55.07193619864327, 51.333930424281526, 53.74635192326137, 48.98107583182198, 52.0009366444179, 48.757448060171946, 50.9151485988072, 48.20407615389143, 56.389516149248394, 58.78294127328055, 59.90860503060477, 57.29016596930367, 57.97221851348877, 57.63315684454781, 58.97345393044608, 56.74132776260376, 57.50978115626744, 58.0453656741551, 56.476222719464985, 55.51809740066528, 56.07233435767037, 53.0306179864066, 56.88480111530849, 51.92855725969587, 48.8808411189488, 52.73888397216797, 48.61587503978184, 57.438819204057964, 49.41807583400181, 53.34717444011143, 50.50900207247053, 54.53084870747158, 47.79480641228812, 50.24963971546718, 35.31655740737915, 23.021695681980678, 28.628099850245885, 36.42556285858154, 39.123249598911826, 44.48805447987148, 43.220609256199424, 43.16438095910208, 43.10473067419869, 41.132216998508994, 42.56320892061506, 41.38933161326817, 44.548000063214985, 42.791509355817524, 38.145728383745464, 40.55962290082659, 43.5406745501927, 41.4456467628479, 41.26246098109654, 38.64690889630999, 40.12406464985439, 43.015630449567524, 43.59949452536446, 43.47840132032122, 45.92049510138375, 42.35513816561018, 42.18276030676705, 41.85516663960048, 38.29036555971418, 40.85346221923828, 41.1170768737793, 40.882175649915425, 42.126469475882395, 41.41225719451904, 38.91261495862688, 43.37732934951782, 40.418557098933626, 40.89990745271955, 39.47817747933524, 44.22554458890642, 38.846537590026855, 32.91055256979806, 38.8050776890346, 42.00607109069824, 36.11152860096523, 28.720783608300344, 23.339110238211497, 35.56329141344343, 48.50087887900216, 41.528281688690186, 40.15722145353045, 37.90622050421578, 41.54439803532192, 42.270540373665945, 49.25968817302159, 51.31881809234619, 52.66778653008597, 50.558424609048025, 49.73020281110491, 47.3935409954616, 44.95459822246006, 48.8377240725926, 54.895076751708984, 51.397780895233154, 53.55732618059431, 51.06535823004586, 58.467430523463655, 53.632929529462544, 52.63359791891915, 45.83396571023123, 47.45109987258911, 46.297980308532715, 48.17151689529419, 45.432391098567415, 48.818366391318186, 44.65317147118704, 46.79107311793736, 45.8180821282523, 51.55072464261736, 51.64528962544033, 54.403752258845735, 56.01902082988194, 59.3323700768607, 56.05419608524868, 62.70040512084961, 57.36755500520979, 66.40757478986467, 59.39152703966413, 63.30439117976597, 6.650190353393555, 0.6941703110933304, 34.71241501399449, 70.28629548209054, 56.23483535221645, 51.656761101314, 41.38559695652553, 43.59950494766235, 50.988580635615754, 41.05057566506522, 55.10438776016235, 63.5182706287929, 46.359266894204275, 60.92302812848772, 91.7244758605957, 29.31303242274693, 1.3520779737404414, 0.33846746225442204, 0.4453393332660198, 0.12896992452442646, 0.24317365139722824, 0.21056040855390684], [0.011998328629748096, 0.033997810512248955, 0.025118536881304214, 0.05559732399082609, 0.1514061734612499, 0.3200037372963769, 31.292351858956472, 49.14541115079607, 44.86235046386719, 42.05662965774536, 24.61967018672398, 15.436218738555908, 26.197375059127808, 47.24808393205915, 22.44459741456168, 29.569236823490687, 29.77541766847883, 39.38317476000105, 52.75966950825283, 49.246986865997314, 50.35502651759556, 21.031516211373464, 0.06906119920313358, 0.6896954540695462, 2.339592218399048, 33.19598109381539, 43.369641167776926, 52.59140498297555, 51.98787750516619, 50.93127189363752, 50.87583916527884, 50.78132629394531, 47.860300132206504, 48.38497597830636, 43.931295326777864, 45.22925009046282, 42.793781416756765, 44.339338711329866, 41.26692867279053, 41.867524010794504, 51.32621097564697, 53.73604079655239, 51.28770753315517, 51.46797507149832, 50.642855644226074, 51.39423731395176, 52.220200947352815, 51.07703815187727, 51.643837451934814, 53.42529303686959, 52.41087341308594, 50.83840921946934, 51.263260296412874, 51.62472643171038, 43.58627210344587, 46.80504594530378, 50.53543996810913, 47.27203784670149, 49.89262390136719, 51.71880851473127, 50.616539342062815, 46.50247621536255, 47.17806693485805, 46.17772783551897, 42.41309309005737, 36.11656951904297, 24.835748740604945, 21.22167103631156, 23.742573022842407, 27.837148189544678, 37.76492541176932, 34.213947772979736, 40.33343819209507, 38.41103145054409, 36.09992510931832, 38.534236907958984, 36.291542530059814, 36.65744856425694, 38.911312171391074, 39.93735613141741, 38.601252283368794, 35.86058746065412, 36.90574244090489, 34.993035384586875, 34.99699585778372, 34.92127438953945, 37.30111925942557, 37.467629364558626, 38.21127768925258, 38.72194596699306, 34.32005371366228, 35.339097363608225, 37.308748381478445, 34.486181667872835, 34.966788564409526, 32.39596550805228, 38.15159266335623, 37.60051366261074, 37.217824254717144, 38.01978186198643, 37.33926139559065, 37.545688901628765, 34.99587024961199, 35.92403146198818, 38.06514665058681, 32.23628895623343, 27.56419689314706, 30.534713336399623, 18.723882232393535, 12.636937175478254, 9.517347999981471, 20.948214258466447, 42.27554307665144, 45.17431763240269, 41.53210667201451, 39.44808830533709, 36.301534039633616, 40.68102877480643, 43.67776945659092, 47.56952496937343, 49.29732656478882, 45.935218334198, 45.8027092388698, 45.95732750211443, 45.777313573019846, 40.584195205143516, 42.01954364776611, 46.01717233657837, 49.06289781842913, 48.16742788042341, 47.325406960078645, 48.341963154929026, 49.086528641836985, 44.770276410239084, 39.66286407198225, 40.05307143075125, 38.59130246298653, 40.30551338195801, 38.769634928022114, 38.51799201965332, 39.05445201056344, 39.51103203637259, 39.825274739946636, 42.70025518962315, 46.16551290239607, 46.86369568961007, 49.9348863192967, 50.994514397212434, 53.33155836377825, 55.80967160633632, 54.96318646839687, 58.124915599823, 61.13077231815883, 44.764273166656494, 1.2306458268846785, 1.25533646770886, 30.832603454589844, 58.069062505449565, 32.30554512568882, 29.640539237431117, 24.55202078819275, 20.089086873190745, 46.11197008405413, 21.273216247558594, 40.30043077468872, 31.994467326572963, 34.68005377905709, 56.73355967657906, 51.69807161603655, 0.1436115838587284, 0.06377588638237544, 0.059408136111285, 0.08356101079178707, 0.06314127293548413, 0.02717675920575857, 0.04636772781876581, 0.019512818128402745, 0.009134178033231624, 0.06691791063972882, 0.0872968617560608, 0.14390600020331995, 2.2114739503179277, 53.121514320373535, 59.72401223863874, 51.41624920708792, 47.84464931488037, 23.858213629041398, 14.09333258015769, 40.73513439723423, 48.28989682878767, 26.805809702192033, 34.85827159881592, 33.0687769481114, 49.1721373966762, 55.122157778058735, 59.99065630776541, 57.58566243307931, 27.726428644997732, 0.10997384134680033, 0.6659284351127488, 7.638249380247934, 46.3546359198434, 53.01400136947632, 61.36028521401541, 57.12371144975935, 57.83520351137434, 53.791080951690674, 54.59658214024135, 52.92738512584141, 51.806286334991455, 47.6460975919451, 49.716685090746196, 49.248223645346506, 48.94410099302019, 44.87389489582607, 47.84051513671875, 53.816438402448384, 58.61769921439034, 56.56720243181501, 57.19271400996617, 54.440900802612305, 57.14602558953421, 54.47793470110212, 55.51348727090018, 53.76797471727644, 56.604284967694966, 56.510605880192344, 53.79658045087542, 54.1658216203962, 53.899292196546284, 47.0063213620867, 49.82501792907715, 51.01055083956037, 49.63001673562186, 51.10471977506365, 53.74254083633423, 52.17900160380772, 49.294064385550364, 49.926322664533345, 48.56494474411011, 46.00289031437465, 40.45437853676932, 32.570556368146626, 26.01078987121582, 29.100744111197336, 34.336340291159495, 39.80215113503592, 37.55715342930385, 44.425913265773225, 40.72559799466814, 38.70746939522879, 40.93274463926043, 39.69830335889544, 39.08746985026768, 42.03032030378069, 42.51600980758667, 41.136524881635395, 37.72338560649327, 39.370789596012656, 38.308107784816194, 38.044249943324495, 39.51105635506766, 40.03959192548479, 41.41243437358311, 40.81942299434117, 41.68174307686942, 38.39023201806204, 37.05024412700108, 39.287737778254915, 37.51218121392386, 37.441483293260845, 35.12322378158569, 39.80765758241926, 39.80202259336199, 38.20281130926949, 39.5077976499285, 38.645241328648154, 37.820945262908936, 35.6900508744376, 39.153227601732524, 41.08181129183088, 33.45619460514614, 30.435340200151714, 32.5748017174857, 20.161563532693044, 15.022243329456874, 18.181005580084665, 27.774440697261266, 47.29752731323242, 48.91952174050467, 49.410842759268625, 49.224023069654194, 46.1269781930106, 50.87211145673479, 52.458770820072715, 54.40463468006679, 53.77293920516968, 51.8425281388419, 48.87378869737898, 49.14656455176217, 50.40140921728951, 42.50671311787197, 44.370501382010325, 50.35630151203701, 53.410121645246235, 50.56787763323103, 52.762059688568115, 53.02547631944929, 53.13698101043701, 49.632879393441335, 43.08323294775826, 45.33286510195051, 42.42132323128836, 44.65309156690325, 42.95697028296334, 43.49649095535278, 42.172115666525706, 45.53155926295689, 43.199139322553364, 48.886948585510254, 48.7883744921003, 53.426866803850444, 53.84629481179373, 57.57063347952706, 58.29663685389927, 60.658760343279155, 59.02181339263916, 64.94025421142578, 63.5398656300136, 49.41281604766846, 1.1446403733321597, 1.3250274424042021, 35.656755106789724, 66.26645687648228, 38.024270398276194, 33.695080620901926, 27.248922382082256, 28.629056964601787, 47.92690208980015, 30.66712863104684, 39.385196685791016, 45.22447667803083, 27.917106321879796, 61.855212347848074, 55.42344209126064, 0.19048095600945608, 0.013892429448398096, 0.027138552595196024, 0.04142576050279396, 0.04410747338884643, 0.05734081632856812, 0.051209149815674336, 0.08865554670670203, 0.09007082147789852, 0.15500983223319054, 0.2850752244038241, 0.21663848097835267, 0.9194870378289903, 52.2617963382176, 72.83811174120221, 63.238598687308176, 53.58289902550833, 45.87977865764073, 25.222659179142543, 42.582795892442974, 58.47660909380232, 35.530812059129985, 43.18277284077236, 38.861219133649556, 53.91761807032994, 63.50367246355329, 64.10281562805176, 63.52452400752476, 29.82076508658273, 0.24739869896854672, 1.806588304894311, 27.01367895943778, 56.404524258204866, 58.74825586591448, 63.55139963967459, 59.815811838422505, 59.02299458639962, 54.85881062916347, 55.27274261202131, 54.46428843906948, 53.85771765027727, 48.55545697893415, 51.28484487533569, 49.552308082580566, 48.605021953582764, 45.54040779386248, 45.97638293675014, 55.177826745169504, 59.12121432168143, 56.429145199911936, 56.729995250701904, 55.11525821685791, 56.898961544036865, 58.026761872427805, 55.3311630657741, 53.84346342086792, 58.20806121826172, 57.39742531095232, 53.343411990574424, 56.19522714614868, 55.34622328622, 47.84221397127424, 52.92183004106794, 54.12230852672032, 51.841555391039165, 56.036415645054404, 57.39456960133144, 57.08627108165196, 51.34335218157087, 52.711834635053364, 54.3152356828962, 52.16209316253662, 44.377154282161165, 37.2807297706604, 30.865114075796946, 34.75153684616089, 37.733314582279746, 44.64574384689331, 38.74660859789167, 43.51683875492641, 43.79519748687744, 40.66407864434378, 44.46241215297154, 41.61741318021502, 42.62539529800415, 44.68582453046526, 45.044038908822195, 43.738156250544954, 40.04486560821533, 41.86113861628941, 41.06940180914742, 40.39491932732718, 41.082561697278706, 43.624330861227854, 45.17038842609951, 44.38408511025565, 43.5678767476763, 41.57291691643851, 41.054511819567, 44.39929819107056, 39.67449535642351, 40.396948201315745, 36.96958943775722, 44.385697092328755, 42.50724465506417, 40.73288665499006, 41.518377031598774, 41.20762232371739, 41.20778560638428, 39.36507817677089, 40.29858602796282, 41.6445563180106, 36.925350257328574, 34.073587213243755, 41.202998297555105, 31.012721606663295, 25.774007422583445, 24.36336156300136, 31.74746928896223, 48.7232003893171, 49.73053979873657, 49.58306428364345, 49.69785894666399, 48.32313353674752, 50.071338517325266, 49.55747059413365, 50.65687710898263, 52.97081136703491, 51.53535870143345, 49.908048902239116, 51.47695214407784, 51.903845991407124, 46.35625832421439, 45.82448141915457, 49.988199847085134, 55.05655288696289, 52.479327065604075, 53.901692799159456, 54.758318832942415, 53.69447667258126, 50.37527356828962, 43.98124940054757, 47.517354420253206, 43.997153827122276, 47.826361656188965, 44.55295065471104, 46.169747829437256, 45.63090808050973, 47.69632264545986, 44.98683091572353, 51.12813173021589, 52.6116555077689, 55.15485600062779, 56.280405112675254, 59.81005872998919, 60.781145913260325, 64.71407645089286, 60.35178198133196, 68.92046724046979, 66.7422000340053, 57.72100639343262, 1.8825592568942477, 1.3395181276968546, 37.33731589998518, 72.40522507258824, 43.914824622017996, 43.08783265522548, 32.4987085206168, 33.164644718170166, 62.47729846409389, 29.079605954033987, 61.73144408634731, 46.01089811325073, 50.752730982644216, 72.82755742754254, 66.64381354195731, 0.33784673841936247, 0.17860150417046888, 0.1408776712736913, 0.18316372936325415, 0.1428767711456333, 0.17619015356259687, 0.18869098063026155], [0.08631533371018511, 0.08209776359477214, 0.03996159389082875, 0.05632562616041728, 0.11715090301420007, 0.2537636288574764, 2.8261908505644118, 44.134144510541645, 55.72813449587141, 42.96551309313093, 37.069261346544536, 26.4930191721235, 22.65228428159441, 48.187515122549875, 29.428372519356863, 30.723495892116002, 27.6509781564985, 27.359723567962646, 51.5972706249782, 50.282730511256624, 57.949327673230854, 33.103312969207764, 0.6853880594883646, 0.20919286193592207, 2.729524471930095, 24.1808271748679, 47.09551191329956, 51.6895809173584, 57.41057825088501, 52.537653718675884, 55.09153706686837, 51.52193130765642, 52.91047668457031, 47.569097655160085, 47.758686201913015, 42.899196011679514, 43.22344412122454, 41.150431701115195, 44.24437768118722, 39.48888117926461, 44.0378737449646, 47.811621052878245, 50.61549016407558, 46.60633441380092, 46.80169343948364, 46.43962281090872, 48.5280567577907, 49.36799669265747, 54.00312955038888, 49.442620345524375, 51.52495377404349, 53.39044087273734, 52.4740047454834, 51.407042843954905, 49.84510517120361, 44.71466997691563, 45.767467975616455, 50.00886378969465, 52.57715770176479, 50.39296020780291, 49.85151835850307, 52.05549042565482, 49.31677457264492, 45.97350638253348, 45.21853596823556, 42.03845664433071, 28.423230477741786, 25.387821333748953, 22.7010588986533, 23.246647085462296, 34.43773882729666, 34.98030628476824, 41.270347186497276, 39.238329138074604, 34.78884867259434, 36.96091113771711, 37.111725262233186, 38.03422369275774, 37.84651810782296, 37.60467215946743, 33.345002583095, 34.77802685328892, 33.17197854178292, 33.48251438140869, 34.92311218806675, 37.60616602216448, 36.40150819505964, 37.43812036514282, 36.744492122105186, 38.79114655085972, 36.094304016658235, 37.74650573730469, 37.29952117374965, 34.854985100882395, 35.57302931376866, 34.918140751974924, 36.61563083103725, 38.658053806849885, 37.30818557739258, 37.75842884608677, 34.670659814562114, 35.37915372848511, 33.90121977669852, 35.693740367889404, 35.13377462114607, 31.67611128943307, 26.30584512438093, 17.173857246126445, 8.298723425183978, 7.3633690902165005, 19.50029652459281, 36.25784029279436, 41.56801496233259, 41.25735405513218, 44.699859891619, 46.16349445070539, 46.316872460501536, 50.042215142931255, 49.634154387882774, 49.30500085013253, 49.33051463535854, 49.198509284428184, 47.38095433371407, 45.813260078430176, 46.030339172908235, 41.593587807246614, 42.3526611328125, 48.48925454275948, 48.170492036002024, 47.4225948878697, 48.22156824384417, 50.65956258773804, 47.51350164413452, 45.58718306677682, 39.94306060246059, 37.750764983040945, 38.5043249130249, 40.33140584400722, 37.86063684735979, 39.69156360626221, 40.598911489759175, 42.2725692476545, 45.30585397992815, 46.742123058864046, 47.50050156457083, 50.806402342660085, 53.45381191798619, 57.07687364305769, 55.904650006975444, 58.74352414267403, 58.58913516998291, 62.34452533721924, 63.7303227015904, 38.55861813681466, 0.02328382568833019, 2.5927118360996246, 42.389556067330496, 57.574805872780935, 31.877699375152588, 32.40259061540876, 15.426779610770089, 29.557386670793804, 41.056252343314036, 19.41788567815508, 49.61720773151943, 33.80570636476789, 45.81184959411621, 67.49487754276821, 10.554269364901952, 0.5406881868839264, 0.14105210905628546, 0.06711995801223175, 0.02336617948354355, 0.0942612909046667, 0.09779198680605207, 0.033440757010664256, 0.019950907477842908, 0.06511058512010745, 0.04811893170699477, 0.012677079083264937, 0.05947273264506033, 0.22360452504030295, 7.620560135160174, 60.19366182599749, 64.72517967224121, 48.484637464795796, 42.63155835015433, 25.418515001024517, 18.022312198366436, 55.70504215785435, 32.38440717969622, 34.85618713923863, 28.235450199672155, 37.351007325308665, 57.24453714915684, 57.221010548727854, 66.63657351902553, 41.336573941367014, 1.328226002199309, 0.12745600433221885, 11.441804460116796, 40.08403260367257, 54.79662772587368, 59.95732579912458, 58.50952965872628, 57.362382071358816, 59.40358911241804, 56.7015562738691, 55.24395969935826, 53.38632753917149, 53.51086010251726, 49.19821398598807, 46.60689026968819, 44.10884959357125, 46.39326442990984, 44.42731332778931, 49.06685481752668, 52.90596035548619, 54.313637597220286, 52.348700932094026, 51.56619133268084, 49.10223157065255, 51.1708527292524, 53.26486260550362, 56.74188361849104, 53.945494243076865, 52.66724109649658, 54.62324237823486, 53.42060647691999, 53.87960794993809, 52.83437653950283, 47.45289250782558, 48.93864665712629, 51.16585350036621, 54.51420429774693, 52.08438450949532, 55.0663845879691, 52.94193812779018, 52.88469539369856, 47.83468559810093, 47.34423310416085, 47.76613814490182, 37.77650458472115, 31.315802029200963, 28.53375026157924, 27.180091789790563, 38.34141397476196, 36.511644090924946, 45.16914817265102, 44.62109163829258, 38.370304584503174, 39.48229776109968, 39.43206228528704, 39.74384880065918, 38.626505511147634, 40.52405507223946, 37.89772980553763, 36.2218451499939, 36.67942919049944, 36.34070798328945, 36.50285114560808, 38.56691081183297, 37.055000168936594, 39.97176013674055, 39.31037848336356, 39.40961265563965, 37.868759291512625, 38.634422983442036, 39.41024146761213, 37.36205496106829, 38.94130059650966, 37.57531949451992, 38.34960242680141, 37.610817841121126, 39.39265210287911, 39.91890171595982, 37.43304818017142, 37.00749880926949, 37.15476240430559, 38.292373589106965, 35.89558553695679, 33.961259160723, 28.812720435006277, 21.866482973098755, 11.447529775755745, 15.969352279390607, 27.457526411328995, 43.10794421604702, 45.67539739608765, 43.031538350241526, 48.95380762645176, 51.206236430576865, 52.11018317086356, 53.27167878832136, 53.53660665239607, 55.18063381740025, 52.70370176860264, 51.732701437813894, 51.18199069159371, 50.59344700404576, 50.15822226660592, 44.95619978223528, 45.59752198628017, 51.658449513571604, 51.846367018563406, 50.459030628204346, 51.03789894921439, 53.91613462993077, 52.15079886572701, 49.86021402903965, 43.710589272635325, 41.57125282287598, 42.2482852935791, 45.422983237675254, 42.33150734220232, 44.8083039011274, 45.88831104551043, 47.94821916307722, 50.90982627868652, 52.83139228820801, 53.43009076799665, 56.60779728208269, 56.76083830424717, 62.71836621420724, 60.50199508666992, 63.97938782828194, 63.43974903651646, 65.04201752798897, 64.65729577200753, 38.87536219188145, 0.05321183574518987, 3.6755019511495317, 49.36679812840053, 63.4397976739066, 36.69073738370623, 38.29905775615147, 20.163495131901332, 32.186195918491904, 49.04020847593035, 23.98000339099339, 44.83270597457886, 39.74353265762329, 43.092616489955354, 78.44019412994385, 7.530282190867832, 0.4254029430449009, 0.12285605259239674, 0.02033447314585958, 0.05815980809607676, 0.04766781109252146, 0.024325512648959245, 0.005582839400241417, 0.15654313138553075, 0.2662476146859782, 0.1769011632672378, 0.20273204147815704, 0.264740805540766, 0.561545267701149, 4.8605563044548035, 64.15860271453857, 77.23681477137974, 59.52640547071184, 54.74780968257359, 43.044649600982666, 29.170955657958984, 63.52140426635742, 39.19611883163452, 44.62795645850045, 38.38223811558315, 38.77414778300694, 66.4195534842355, 60.603459630693706, 72.13073648725236, 42.12148066929409, 1.338286885193416, 0.6274766698479652, 25.245360680988856, 52.74218784059797, 60.49916022164481, 62.05396556854248, 61.84383814675467, 58.48106288909912, 60.25420148032052, 58.5615508215768, 56.7386804989406, 53.692312308720176, 53.76036296572004, 50.027561392102925, 48.828955445970806, 45.12731654303414, 47.859831128801616, 45.12761531557356, 49.09012433460781, 53.96473380497524, 55.1722925049918, 51.36673981802804, 51.15864821842739, 50.3971152305603, 53.07410676138741, 52.545098713466096, 57.832559721810476, 53.78901733670916, 53.664397920881, 56.2767607825143, 58.09698384148734, 55.00834281103951, 55.57821321487427, 49.77611650739397, 51.110931464603965, 53.91886179787772, 56.78361449922834, 53.59304339545113, 57.18813167299543, 53.559817109789165, 56.73927456992013, 50.712441853114534, 52.94702073505947, 50.00145353589739, 42.07023770468575, 36.304646832602366, 36.30517142159598, 33.861385754176546, 42.774041584559846, 39.56000294004168, 44.016250950949534, 46.37070710318429, 40.67030423028128, 41.71755756650652, 41.82410471779959, 42.50404848371233, 41.86953204018729, 42.75780711855207, 41.20242854527065, 39.21241930552891, 40.27259281703404, 39.62879358019148, 40.29359722137451, 42.80541270119803, 40.79152945109776, 43.23715986524309, 42.21517365319388, 42.622209548950195, 40.0839388029916, 42.258905615125386, 43.05133376802717, 38.80037375858852, 42.53004516874041, 39.7694216455732, 40.79566362925938, 42.873077733176096, 42.33370297295706, 42.108313832964214, 39.745971475328716, 39.95209673472813, 38.6681912285941, 40.9193936756679, 41.00557565689087, 35.436038630349294, 34.410171849387034, 31.459838185991558, 17.439182894570486, 20.07073494366237, 33.96988534927368, 44.35766805921282, 50.717538356781006, 44.616318225860596, 50.84799425942557, 50.080888816288535, 48.851491928100586, 50.676582200186594, 48.5850111416408, 53.2984675679888, 51.51290559768677, 49.34342786243984, 51.879277161189485, 50.93670538493565, 51.917224747794016, 46.51021998269217, 46.6811317716326, 55.42312247412545, 53.219150406973704, 52.89896004540579, 51.83775125231062, 55.14389174325125, 55.252756118774414, 50.68463168825422, 45.06990705217634, 43.80703026907784, 44.554583481379915, 48.01062093462263, 45.23425626754761, 47.428601605551584, 47.20575898034232, 49.37867954799107, 52.72059283937727, 56.096750327519004, 54.082964352199006, 58.52095944540841, 60.14105006626674, 65.92494596753801, 63.026268686567036, 65.39203998020717, 65.32890864780971, 67.043258530753, 66.85619218008858, 45.860990728650776, 0.14195765475077288, 3.883188383919852, 48.95488459723336, 72.66679000854492, 41.80707468305315, 47.701523372105186, 22.094286612101964, 50.03828593662807, 54.63753482273647, 27.676881040845597, 66.14368220738002, 53.64671128136771, 60.261893136160715, 92.28422968728202, 12.782786812101092, 0.5127175620623997, 0.23530557645218714, 0.12914734786110266, 0.11905076035431453, 0.1625694723001548, 0.19006755176399434, 0.12847627672765935], [0.0746568264439702, 0.017473433632403612, 0.058950274251401424, 0.0646093784432326, 0.013277171212913734, 0.021708898412595903, 0.28010476540241924, 7.6102472714015414, 49.649138178144185, 55.04305601119995, 33.80708558218819, 18.662237814494542, 25.70367775644575, 69.52653775896344, 28.69715278489249, 25.145183290754044, 34.23867988586426, 18.23073731149946, 47.671965735299246, 51.031131403786794, 57.22953946249825, 45.914658614567344, 5.585559138229915, 0.14789455117923872, 6.29457460130964, 26.308822427477153, 39.76105254037039, 50.69006517955235, 53.97327661514282, 57.494766099112375, 55.44719450814383, 55.562166350228445, 52.15285553250994, 50.77791125433785, 50.763413837977815, 46.953285762241904, 41.69331530162266, 42.691899980817524, 41.46913167408535, 41.55185692650931, 41.48985120228359, 41.946156774248394, 44.750783239092144, 43.9419503893171, 42.18387201854161, 41.72566958836147, 47.08428015027727, 49.848836353846956, 51.863001005990164, 53.213841983250205, 53.928318296160015, 51.90643419538225, 53.23100750786917, 50.99430595125471, 47.492545877184185, 44.8317471231733, 46.53904458454677, 48.320309094020296, 50.57810885565621, 51.00636454990932, 53.36645221710205, 51.19732536588396, 51.22236319950649, 43.845443384987966, 43.917715072631836, 44.87284571783883, 41.91217313494001, 27.167183773858206, 26.955442632947648, 23.14628209386553, 36.21512276785714, 35.29064757483346, 38.82721812384469, 39.24806356430054, 36.87388147626604, 37.48083789008004, 36.168969358716694, 37.391379833221436, 34.494637625558035, 37.234263692583355, 34.152358940669465, 33.89359065464565, 33.75139577048165, 32.55806350708008, 34.60368612834385, 33.93539449146816, 36.70045791353498, 38.01792321886335, 37.31174652917044, 36.01299967084612, 35.728675910404746, 35.928811822618755, 37.15253550665719, 34.88523060934884, 35.511690616607666, 35.87178448268345, 36.00647183826992, 36.61364017214094, 39.01530238560268, 35.42822885513306, 35.866694927215576, 33.88364430836269, 35.98223304748535, 34.77938175201416, 32.497082642146516, 28.671263796942576, 23.46474061693464, 10.639327475002833, 6.056136310100555, 20.90657023021153, 29.228458949497767, 40.55639893668038, 36.688315936497276, 38.73412963322231, 36.77595703942435, 41.61422743116106, 40.550854274204795, 46.16520023345947, 46.870133195604595, 47.91877269744873, 48.191416536058696, 41.34058652605329, 45.72379854747227, 46.90183782577515, 47.09262146268572, 41.48723520551409, 39.8023977960859, 47.92953545706612, 46.90832049506051, 47.224255084991455, 48.21897656576974, 47.285534722464426, 49.959851196834016, 44.569935526166645, 37.86262403215681, 36.61656188964844, 37.77408313751221, 40.323158332279746, 39.805576596941265, 43.662174224853516, 45.37988703591483, 48.39063876015799, 50.07221051624843, 50.808476379939485, 52.319389956338064, 57.131389209202354, 54.20814657211304, 56.826113155909944, 57.55366597856794, 61.49678257533482, 60.6736364364624, 63.01816708700997, 59.34748935699463, 13.67138671875, 0.5038073116115162, 7.919770411082676, 50.91101789474487, 47.72808633531843, 35.182703835623606, 32.911348138536724, 12.00128904410771, 36.6752324785505, 44.229876790727886, 30.611991201128276, 52.316054821014404, 47.4238976751055, 57.632173674447195, 38.43151821408953, 0.12599754759243556, 0.010021427879109979, 0.08619025256484747, 0.035536680437092266, 0.03786806230034147, 0.033803087925272327, 0.019616818887048533, 0.02255751332268119, 0.08118814669017281, 0.025389516626351645, 0.01797462673857808, 0.04057873506098986, 0.03631886507251433, 0.03176974917628935, 0.2501774898597172, 14.110472917556763, 62.53411388397217, 59.65754577091762, 38.10970197405134, 25.260664088385447, 19.930018288748606, 74.19786030905587, 32.116668769291465, 36.16234425136021, 34.21022006443569, 23.963888781411306, 55.39654908861433, 55.26202154159546, 61.53489344460623, 49.57766900743757, 8.118571400642395, 0.4040379380541188, 12.147948145866394, 42.04957376207624, 51.57850006648472, 60.02585588182722, 61.20506245749337, 61.137095178876606, 61.39355318886893, 60.368388175964355, 58.96449075426374, 56.885172843933105, 54.587417466299875, 51.4710670198713, 47.32911034992763, 46.56674705232893, 44.84249251229422, 44.012220995766775, 44.4160190309797, 45.73459604808262, 47.238978317805696, 49.02663516998291, 45.587388038635254, 45.57042053767613, 50.88798809051514, 54.370463439396445, 55.512594427381245, 56.285543305533274, 55.79499701091221, 56.441544260297505, 55.323749337877544, 52.545192514147075, 50.18548699787685, 48.38887391771589, 50.05646937234061, 50.59871026447841, 53.80663449423653, 53.8455548286438, 53.88485383987427, 53.20520189830235, 53.54524673734392, 46.703810691833496, 47.4533371925354, 44.81879220690046, 48.28575917652675, 33.651525838034495, 33.9202230998448, 31.029167992728098, 40.786398206438335, 36.50477927071707, 42.25183582305908, 43.074752671378, 37.806100436619346, 41.779851640973774, 39.53817170006888, 41.49615669250488, 37.72997597285679, 40.30619430541992, 37.89628458023071, 35.88526051385062, 35.270400524139404, 36.00985561098371, 36.62720652988979, 36.431892667497905, 39.90906654085432, 38.394668442862375, 39.2758389881679, 39.17166812079293, 36.878727844783235, 37.61156824656895, 39.89626101085118, 37.78785794121878, 36.57947587966919, 37.07504572187151, 38.16340112686157, 37.403077125549316, 40.321546350206646, 37.545313698904856, 36.07627691541399, 34.972524302346365, 38.68639203480312, 37.07011250087193, 35.451748507363455, 31.00096525464739, 26.500238350459508, 15.169704948152814, 14.736516032900129, 28.40832311766488, 37.4937059538705, 41.391773905072895, 43.9138240814209, 43.17330592019217, 41.6514002936227, 44.09119422095162, 43.33360433578491, 50.40622084481375, 49.64247138159615, 50.10807016917637, 50.79433332170759, 45.44606515339443, 47.38790600640433, 52.60622896466936, 51.24209608350481, 42.19676440102713, 42.83131905964443, 51.38480860846383, 51.80741889136178, 49.651934828077046, 51.39992094039917, 53.38086972917829, 52.061389446258545, 47.77065794808524, 41.202355589185444, 41.344342027391704, 41.31401661464146, 43.162702969142366, 44.33997794560024, 48.55107961382185, 50.65429237910679, 52.762598173958914, 55.46496800013951, 57.112243447984966, 57.23161697387695, 62.298180852617534, 59.37875625065395, 61.04259272984096, 62.73177623748779, 64.51179354531425, 62.61572742462158, 67.50215230669293, 58.8994973046439, 13.413730144500732, 0.5209893382021359, 9.681473135948181, 56.38122000013079, 51.12047134126936, 41.87205423627581, 37.43769999912807, 14.232534527778625, 37.403556551252095, 54.75450774601528, 29.131880726133073, 48.52392257962908, 47.163635526384624, 63.86456189836775, 38.165273666381836, 0.2011014132627419, 0.03645287573869739, 0.11770921519824437, 0.043463143320488076, 0.014088699943386018, 0.053990162909030914, 0.032404786707567315, 0.02439395308361522, 0.16155423463455268, 0.14031276372926577, 0.11563696925129209, 0.2743717687470572, 0.14219016156026296, 0.25433357113174027, 0.4229644781776837, 11.390294858387538, 73.1287201472691, 73.19299793243408, 49.807143688201904, 40.771591595241, 33.263531480516704, 84.43157713753837, 35.5835280418396, 37.53968218394688, 44.49603796005249, 26.44298345702035, 61.430663517543245, 62.59318052019392, 66.38246400015694, 55.411852496010916, 8.273405058043343, 0.4768543807523591, 19.225681134632655, 54.79071133477347, 56.33113043648856, 62.265288080487935, 63.94123526981899, 61.7562699999128, 62.36645385197231, 60.71725722721645, 58.38947173527309, 56.42075872421265, 57.134265763419016, 53.09746313095093, 47.79781150817871, 48.10391092300415, 44.78385666438511, 44.94482558114188, 46.09805631637573, 46.04723719188145, 49.183386530194966, 49.44400303704398, 46.67991236277989, 47.152205739702495, 51.951847621372764, 54.14792306082589, 55.01651736668178, 57.03460775102888, 57.38800007956368, 58.75487749917166, 56.65050091062273, 54.06086908067976, 51.676209109170095, 48.994009903499055, 51.69640752247402, 51.86435243061611, 55.68387794494629, 55.60279941558838, 55.491464955466135, 56.05542591639927, 56.70740665708269, 49.96660137176514, 50.51039171218872, 50.65373304912022, 51.72268908364432, 38.07656601497105, 39.1095095361982, 36.814919063023154, 46.57615838732038, 38.256135259355815, 44.41384424482073, 43.93253558022635, 42.174634388514924, 43.44934047971453, 41.272330897195, 45.3493184362139, 39.648540360586985, 41.269079140254426, 38.193448611668174, 38.730377605983186, 38.98788826806204, 36.86029774802071, 40.46410254069737, 39.15584012440273, 43.73883369990757, 43.29200547082083, 42.60488074166434, 42.84984295708792, 41.14100994382586, 42.18590089253017, 42.59536170959473, 40.63304451533726, 39.0078295980181, 40.89113882609776, 42.08158411298479, 40.69206598826817, 44.66773836953299, 41.36076062066214, 40.4341835975647, 38.831901209695, 40.211705752781455, 40.58352817807879, 37.39683416911534, 34.005449703761506, 34.91572972706386, 23.439758368900844, 19.05932215281895, 30.764215809958323, 40.31072800500052, 46.380535330091206, 46.25255298614502, 48.89255230767386, 44.53782442637852, 46.61976180757795, 44.83761140278408, 51.27974489756993, 50.86877632141113, 50.57629190172468, 50.84616340909685, 44.57441711425781, 47.92188549041748, 54.05231237411499, 51.843365396772114, 46.62577199935913, 43.013101305280415, 53.72307893208095, 52.78742061342512, 51.28869070325579, 52.76619734082903, 54.43661028998238, 52.8543769291469, 50.563983167920796, 43.40341983522688, 42.58628041403634, 43.79185887745449, 47.91399581091744, 46.018864222935264, 51.808283942086355, 52.20017623901367, 55.79958629608154, 56.42519167491368, 59.39427157810756, 58.78097493307931, 65.42343194144112, 61.86155605316162, 63.42636680603027, 64.35499354771206, 68.21740681784493, 64.37707492283413, 66.69447980608258, 64.41699927193778, 18.728711230414255, 0.665643396122115, 10.075126801218305, 58.5276575088501, 59.477768080575125, 47.65349047524588, 49.18130554471697, 14.958457129342214, 56.65174116407122, 57.692928722926546, 45.02310398646763, 77.19310365404401, 66.53221157618931, 73.74861758095878, 49.353252615247456, 0.17891358956694603, 0.13793078011700086, 0.17719855159521103, 0.08116820454597473, 0.11037950350769929, 0.14557481636958464, 0.11577439973396914, 0.1220093494547265], [0.05560042489586132, 0.0608517804316112, 0.016309625635455762, 0.03260835399851203, 0.08878013930682625, 0.07546833397022315, 0.044094001076051166, 0.45468536604728016, 15.43657830783299, 52.25679363523211, 54.47163963317871, 24.196587426321848, 43.062454359872, 62.87852219172886, 33.80724886485508, 11.896700416292463, 48.91465105329241, 21.39259672164917, 31.441272599356516, 52.71036856515067, 53.07983207702637, 46.46930204119001, 12.146553294999258, 0.14418276106672628, 1.6789290521826064, 31.92283139910017, 44.69005945750645, 52.261407239096506, 52.039582524980815, 55.828768730163574, 52.54835047040667, 55.62347378049578, 51.535025187901084, 50.775607926504954, 50.44091667447771, 46.966108662741526, 42.47005442210606, 42.83235086713518, 42.65995911189488, 40.326615061078755, 40.93563508987427, 42.16788073948452, 41.25562047958374, 40.58319813864571, 38.84134381158011, 43.65339170183454, 47.29326111929757, 52.053732531411306, 53.52319662911551, 51.24890879222325, 52.66990920475551, 50.8233003616333, 51.280592577798025, 48.802715573992046, 48.41335589545113, 46.48711722237723, 48.76999650682722, 50.605467387608115, 51.69933271408081, 52.01176541192191, 50.95891877583095, 52.050661427634104, 46.21744721276419, 44.10246072496687, 43.05806309836251, 43.93745837892805, 45.01388372693743, 36.1444456917899, 27.976909467152186, 28.273147651127406, 28.35827350616455, 31.133748803819927, 33.96847833905901, 38.638220173971995, 37.324732712336946, 35.56354849679129, 37.18303115027291, 37.85090936933245, 37.75445100239345, 36.78781066622053, 34.01436076845442, 33.85225582122803, 32.27854095186506, 32.71208422524588, 35.562891892024446, 37.47568232672555, 35.35097530909947, 35.79055309295654, 35.08131572178432, 38.1035041809082, 36.0522118295942, 37.63517822538103, 36.181392737797324, 35.76553610392979, 36.18691308157784, 36.31703199659075, 36.10443101610456, 37.14515651975359, 36.40162978853498, 35.21117407935006, 36.67768171855381, 34.45840276990618, 35.70162309919085, 32.86762312480381, 28.794490098953247, 26.449394907270158, 13.825633253370013, 8.29860270023346, 17.973768608910696, 30.506729466574534, 37.656248637608115, 35.85561602456229, 40.42838185174124, 35.282413959503174, 39.62894991465977, 39.42703526360648, 44.36897625241961, 44.88843400137765, 43.960717473711284, 48.41357476370675, 48.38614674976894, 47.5312716620309, 45.4735244342259, 48.45532996313912, 47.37908179419381, 39.39295434951782, 42.25261402130127, 48.3796397617885, 48.12776408876692, 49.53128283364432, 47.09274653026036, 50.25834928240095, 47.287549700055806, 44.7100841658456, 37.13148593902588, 41.49069888251168, 37.93708440235683, 39.29319211414882, 40.89675644465855, 48.40426070349557, 46.958559444972444, 52.125635964529856, 52.100518226623535, 52.613819871629985, 54.499307359967915, 55.62470361164638, 53.95952613013131, 58.94033881596157, 57.263724599565776, 59.30591133662632, 56.18785163334438, 65.95627539498466, 27.344597339630127, 10.426819426672798, 0.6570775700466973, 12.300521033150808, 52.049469811575754, 44.15073333467756, 38.18584033421108, 27.185130970818655, 16.34578309740339, 50.39948456627982, 41.549984386989046, 33.82999726704189, 57.00689486094883, 39.78990493501936, 71.82092326028007, 5.511044485228402, 0.3384012643780027, 0.06861309467681817, 0.10620246907430035, 0.05788878085357802, 0.058134512310581546, 0.01905338037093835, 0.0812132524858628, 0.08130684282098498, 0.02457111348797168, 0.03197096873606954, 0.07042050840599196, 0.007150867671173598, 0.035376820979373794, 0.05336030259994524, 0.06434330450636999, 0.14057765022984572, 22.99805269922529, 66.15060261317662, 61.429933956691194, 25.24289754458836, 38.35710995537894, 76.11729322160993, 31.647401332855225, 22.152166843414307, 49.21262802396502, 24.28220660345895, 40.61093534742083, 56.890411785670686, 58.766946520124165, 51.87474693570818, 13.56828761100769, 0.20229362643190793, 2.294159467731203, 43.31765474591936, 53.75769485746111, 58.03096900667463, 57.69645493371146, 60.40638787405831, 58.06378534861973, 59.05339295523507, 57.68823521477835, 57.3186605317252, 53.98977163859776, 49.40007305145264, 47.24569722584316, 46.875347818647114, 46.84978192193167, 44.841794218335835, 45.284540380750386, 45.56573050362723, 44.88909060614449, 44.4758951323373, 42.608591079711914, 47.57352018356323, 51.550874028887065, 55.289553778512136, 56.70451968056815, 53.38968004499163, 53.83385406221662, 53.71754469190325, 52.883125100817, 49.981595584324424, 51.367802892412456, 48.705058642796104, 51.085303034101216, 52.55894994735718, 54.40786559241158, 53.82963303157261, 54.201274803706575, 52.16064098903111, 50.242264202662874, 45.878062452588765, 45.50126164300101, 45.62819133486067, 47.0336069379534, 41.35809251240322, 33.88638537270682, 29.556288855416433, 31.201563222067698, 30.57450566973005, 36.28274958474295, 45.38953113555908, 38.6483610698155, 38.138877459934776, 39.92728819165911, 40.95077868870327, 41.328444549015586, 41.54763242176601, 36.377766200474326, 35.52763673237392, 34.8823366846357, 36.90577718189785, 36.191617012023926, 39.10768910816738, 37.43397923878261, 39.37285321099417, 37.60811499186924, 38.49291249683925, 36.63047913142613, 37.77727583476475, 37.61278418132237, 37.345872606549946, 35.95382186344692, 37.62292160306658, 38.134135314396445, 39.435206345149446, 39.16517502920968, 37.3796512739999, 37.79822812761579, 38.41130243028913, 37.99015474319458, 36.28154059818813, 31.48905188696725, 29.918765953608922, 18.869686705725535, 15.211946521486555, 28.115470443453106, 38.751600878579275, 44.67875126429966, 41.74177898679461, 44.70196172169277, 40.76034593582153, 44.25195469175066, 42.46397474833897, 50.25543451309204, 51.86005844388689, 47.28632681710379, 51.227511814662385, 51.928748335157124, 50.004177229745046, 48.60077313014439, 52.03726530075073, 49.22650705065046, 42.68434034075056, 45.7198554447719, 50.686862060001914, 52.05980178288051, 52.75889825820923, 50.73920978818621, 53.451050009046284, 51.50322675704956, 47.258117130824495, 40.90999623707363, 42.70674133300781, 41.01213475636074, 44.09116642815726, 44.909820556640625, 52.74237544195992, 52.24064254760742, 56.360729762486045, 56.41004112788609, 59.746642521449495, 57.514728273664204, 60.50915173121861, 58.29943697793143, 63.27327714647566, 61.34219905308315, 63.437164306640625, 59.424155780247276, 68.67939949035645, 30.252939564841135, 12.902446951184954, 1.5266534175191606, 14.669231414794922, 56.191190242767334, 49.26477772848946, 46.695062909807476, 32.70074129104614, 12.166467700685773, 48.79420403071812, 51.55114500863211, 31.579513958522252, 56.34677083151681, 43.221717493874685, 76.28079128265381, 2.968132559742246, 0.21892318981034414, 0.013375806455899562, 0.061972224951854775, 0.08511968036847455, 0.040515726299158165, 0.04282062494062951, 0.07801949671868767, 0.01730786939151585, 0.13681741271700176, 0.23070204204746655, 0.22162656831954206, 0.11192399848784719, 0.16472672511424336, 0.20254727639257908, 0.17217615752347878, 0.6741509224687303, 23.74253307070051, 76.6994410923549, 79.37792995997837, 40.86199460710798, 58.433849879673545, 73.79938111986432, 44.61326796667916, 17.32026273863656, 63.61024393354143, 28.524754081453594, 44.891727447509766, 62.27615506308419, 65.51951163155692, 55.08165325437273, 15.065574032919747, 0.2997808153075831, 4.480902390820639, 54.07473768506731, 58.14571155820574, 62.41241618565151, 58.32180322919573, 61.98611640930176, 57.77927051271711, 60.68621962411063, 57.69072961807251, 58.63008090427944, 57.207874979291645, 51.64004373550415, 49.81831986563546, 48.97851889474051, 49.030025890895296, 45.30990825380598, 47.10259907586234, 46.2640974181039, 46.5995112827846, 45.75354378564017, 43.54260614940098, 47.55680281775338, 52.75824860164097, 54.570793901171, 55.08762175696236, 54.16862521852766, 54.44924211502075, 55.51743384769985, 56.67149836676461, 51.942735058920725, 53.728672231946675, 51.62005724225725, 52.3996833392552, 54.08705684116909, 56.889984471457346, 54.82220751898629, 55.25537558964321, 55.306333678109304, 52.17212636130196, 49.60380465643746, 48.75408165795462, 48.52479805265154, 51.53264890398298, 44.393173354012625, 40.47819001334054, 39.61849634987967, 36.02705935069493, 33.695549624306814, 39.53348166601998, 44.76385280064174, 41.36051048551287, 40.853250299181255, 43.10584238597325, 43.05367531095232, 43.69962501525879, 44.80288083212716, 39.8924777167184, 37.74022456577846, 36.74690662111555, 39.04617323194231, 38.69552196775164, 42.00175625937325, 40.2208183152335, 43.19990709849766, 40.89776045935494, 43.07761880329677, 40.10191379274641, 42.80821629932949, 41.522973264966694, 39.964527062007356, 40.91269908632551, 41.883216517312185, 38.989194529397146, 43.001747948782786, 42.95124844142369, 40.3851432119097, 41.80785982949393, 42.115105697086875, 42.07690102713448, 37.78147602081299, 32.64260918753487, 36.52168771198818, 25.590213673455374, 21.67492287499564, 33.280262742723735, 40.87167344774519, 49.185484886169434, 45.86124433789934, 50.06167009898594, 43.57804891041347, 45.169082164764404, 43.333270822252544, 48.747963769095286, 54.54726382664272, 48.324905327388215, 53.02495520455496, 51.94177620751517, 51.293610027858186, 51.59641947065081, 53.57814645767212, 51.28551190240042, 45.14557293483189, 47.58802107402256, 54.01519162314278, 53.70900535583496, 56.49979100908552, 51.527677467891145, 55.10440513065883, 53.63344717025757, 50.82157720838274, 43.573230334690635, 46.14472736631121, 41.95180913380214, 45.2642377444676, 48.19674580437796, 56.550071648189, 53.65463917595999, 58.86558314732143, 58.963240078517366, 61.35078007834298, 59.17600781576974, 61.07643740517752, 58.601273672921316, 64.89913477216447, 64.43871934073312, 65.21022646767753, 59.74446078709194, 70.64488506317139, 36.03246504919869, 13.068944896970477, 1.5684625740562166, 14.695483446121216, 62.05957276480538, 56.084695202963694, 53.6020621572222, 38.72924157551357, 24.255429983139038, 70.05895042419434, 56.05938638959612, 45.45915903363909, 76.37655830383301, 51.68356377737862, 93.54309041159493, 8.185367039271764, 0.5239933484366962, 0.18268696351775102, 0.17389799441610063, 0.24072785835180963, 0.11804594498659883, 0.07832884761903967, 0.22309119972799504, 0.20722977870276996], [0.11473159997590951, 0.07317586948296853, 0.0776313136198691, 0.0845184779859015, 0.08712730942560093, 0.0787122809727277, 0.008957934499319111, 0.12214881554245949, 0.14208885628197873, 19.48440773146493, 46.77704470498221, 49.21572344643729, 24.553429535457067, 28.460286957877024, 43.45906795774187, 17.382914645331248, 39.17007350921631, 36.126950127737864, 24.47865128517151, 51.36776120322091, 49.885540212903706, 47.855328696114675, 14.785507781164986, 0.1643151936254331, 0.13071424806756632, 21.01998393876212, 47.54484844207764, 50.31493541172573, 56.33707809448242, 55.3509133202689, 55.797460147312705, 53.12380722590855, 55.67665181841169, 51.58253002166748, 51.81571504047939, 45.93792118344988, 43.89396265574864, 42.22134712764195, 45.12809821537563, 41.825136525290354, 40.903586523873464, 39.639535495213096, 41.61303234100342, 40.452676228114534, 41.37211397715977, 43.056155817849294, 52.90097502299717, 49.510313170296804, 56.00445393153599, 49.85447481700352, 52.021145480019705, 52.614959376198904, 50.90767233712332, 49.65454387664795, 47.5802321434021, 50.30843537194388, 50.971654823848176, 51.4969733783177, 51.055193015507285, 52.5997428212847, 50.890927178519114, 50.46005548749651, 49.26133837018694, 41.7619183404105, 41.15141487121582, 41.64762394768851, 44.613142899104524, 42.834814003535676, 32.849523067474365, 19.669926370893204, 18.27180985042027, 29.846077374049596, 29.645489828927175, 33.90083415167672, 38.61709417615618, 33.05735758372715, 35.75298418317522, 35.070101329258506, 38.404736382620676, 36.008768217904226, 33.00618757520403, 32.48289442062378, 33.83933217184884, 33.153263568878174, 34.57389920098441, 35.55413368770054, 35.86367246082851, 37.44753170013428, 35.6873653956822, 35.851516587393625, 32.574318817683626, 33.25043065207345, 34.02479001453945, 35.99814442225865, 35.34625053405762, 36.534323011125835, 35.77884537833077, 33.503560474940706, 31.56253603526524, 34.9677300453186, 34.00332008089338, 35.90450702394758, 32.71257059914725, 30.955273900713237, 31.136851174490793, 16.442100763320923, 14.139333997453962, 13.189716747828893, 27.190111092158727, 37.31807286398751, 37.32421159744263, 38.40316261563982, 36.93756519045149, 36.39793682098389, 37.86890867778233, 38.059216363089426, 46.824136120932444, 46.92648656027657, 43.07137584686279, 47.318941661289756, 47.953214917864116, 45.70375299453735, 47.673841748918804, 48.50043766839163, 42.32321466718401, 40.9452930859157, 42.77712311063494, 48.47506284713745, 48.67118617466518, 49.20711810248238, 46.73787423542568, 50.391296114240376, 48.90617077691214, 42.395799023764475, 38.49127272197178, 39.56504733221871, 38.94064746584211, 42.49928201947893, 42.276533194950645, 46.21597419466291, 52.0527389390128, 52.11526230403355, 53.358677182878765, 55.401638644082205, 56.02037225450788, 58.47798483712332, 56.60912438801357, 56.15090111323765, 55.01721566064017, 58.27050815309797, 56.299519606998985, 49.3799649647304, 23.437463726316178, 12.443861501557485, 3.983570311750684, 16.860795736312866, 45.90214490890503, 45.430720056806294, 28.804320062909806, 32.03351272855486, 37.084019320351736, 52.58479029791695, 41.494110448019846, 39.646619183676584, 49.78852946417672, 63.44122205461775, 32.611905097961426, 0.31379394765411106, 0.20898276035274777, 0.05869151492203985, 0.13890441001525947, 0.03959968027525714, 0.06343183520116977, 0.0836162706837058, 0.0675565477992807, 0.0674179434510214, 0.045863515231758356, 0.033636270090937614, 0.07119854379977499, 0.00817007985564747, 0.10734354784446103, 0.07672118102865559, 0.12308490888348647, 0.2855829857289791, 0.5279081697974886, 26.310892990657262, 57.958280427115305, 58.747762543814524, 24.9165232862745, 41.66424751281738, 44.30661964416504, 16.171586547579082, 50.68015357426235, 33.55162811279297, 30.348824705396378, 55.74511241912842, 57.234472683497835, 53.38100869315011, 16.349453483309063, 0.31349362805485725, 0.046958053284989934, 25.919302940368652, 56.020792620522634, 53.547105380467, 61.788711139133994, 58.88347475869315, 61.788551330566406, 56.85945061274937, 59.944138118198936, 55.74215596062796, 56.24175923211234, 47.79301725115095, 46.579305921282085, 46.398635387420654, 47.958453859601704, 46.23982736042568, 44.7029309953962, 42.75306149891445, 44.57244035175869, 42.1771913255964, 44.03711291721889, 46.87427084786551, 55.17745501654488, 54.43995237350464, 59.19367013658796, 50.631047180720735, 55.24076352800642, 56.061859948294504, 52.05453852244786, 51.407487528664724, 51.28131866455078, 52.47232328142439, 53.78820092337472, 51.2766946383885, 51.378186975206646, 53.981458118983674, 53.62380307061331, 52.00952809197562, 52.03484385354178, 43.59377268382481, 44.444391999925884, 44.11339718954903, 45.65611614499773, 47.268727030072895, 39.93097768511091, 23.918782813208445, 21.548724481037684, 32.060801778520855, 33.41880982262747, 40.37386628559658, 43.71733249936785, 35.51092284066336, 38.1304840360369, 36.655714988708496, 39.92924410956246, 39.128325257982524, 35.81448268890381, 34.73279060636248, 34.46447549547468, 35.9545271056039, 38.51739794867379, 38.89175646645682, 38.89531741823469, 37.55253635134016, 37.89597538539341, 38.219834395817344, 36.67639282771519, 35.21541942868914, 38.049363817487446, 37.03810562406267, 35.70056002480643, 36.8356351171221, 37.65724917820522, 35.729732036590576, 34.25897557394845, 37.19305740083967, 35.924139159066335, 37.82282475062779, 36.93176691872733, 33.96883269718715, 34.09344169071743, 19.87669086456299, 16.51931609426226, 23.336390018463135, 36.19560180391584, 43.15589720862252, 42.63743652616228, 42.49987609045846, 40.81472601209368, 40.565306527274, 41.18828548703875, 41.52799333844866, 50.062820025852744, 51.12290668487549, 46.68303557804653, 51.0135281426566, 50.98452288763863, 48.126235485076904, 51.784701756068635, 50.102824279240195, 43.455024106161936, 42.152990749904085, 46.118157454899375, 51.4164194379534, 52.517545631953645, 52.51148680278233, 50.649011748177664, 52.53699711390904, 54.051423004695344, 47.49325111934117, 43.884794507707866, 42.83295883451189, 42.71372079849243, 46.657778876168386, 47.03161975315639, 50.03085136413574, 55.182499408721924, 56.626011984688894, 56.74297101157052, 58.22392395564488, 60.22597789764404, 61.916842869349885, 60.46247373308454, 59.0761205128261, 58.84545421600342, 61.07804938725063, 60.0148777280535, 51.16085774557931, 30.973637989589147, 17.270211390086583, 6.067700283867972, 18.054739441190446, 50.062743595668245, 52.61496632439749, 36.151828152792795, 36.43371309552874, 32.85174649102347, 53.56045634405953, 49.81871938705444, 36.69237715857369, 50.355888094220845, 66.75036416734967, 25.8082047189985, 0.4610894066946847, 0.22447626612016133, 0.062300527335277626, 0.12634896087859357, 0.03133200927238379, 0.06346708509538855, 0.02263463900557586, 0.08285980591816561, 0.08933461776801518, 0.18561318649777345, 0.10537371997322355, 0.3081857743007796, 0.14997507525341852, 0.22525195378277982, 0.1785640354667391, 0.14315270419631684, 0.37290004747254507, 0.3942198348896844, 33.946779114859446, 69.0801785332816, 73.98707975660051, 39.85408544540405, 38.35119703837803, 53.881001063755576, 24.641794988087245, 56.85052565165928, 46.624222551073345, 35.0031623840332, 63.213703291756765, 64.8547010421753, 58.387116295950754, 18.32948510987418, 0.4224795156291553, 0.21544121950864792, 34.030661242348806, 57.49642324447632, 57.98475306374686, 62.334325381687705, 61.831248010907856, 62.92986937931606, 58.51734638214111, 63.04593208857945, 57.784863812582834, 56.776103496551514, 50.54188094820295, 48.54015704563686, 50.46989761080061, 51.58490283148629, 48.111710275922505, 46.3384952545166, 44.78072302682059, 45.19260876519339, 43.83859246117728, 44.411645139966694, 48.10715225764683, 55.866712842668804, 54.78296061924526, 60.06849697657994, 49.660182339804514, 56.841291495731895, 56.811803340911865, 55.36341660363333, 55.421951702662874, 54.86034618105207, 54.9750713620867, 55.63807194573538, 54.56485319137573, 55.226592676980154, 56.45283160890852, 54.216196060180664, 55.10432175227574, 54.32771117346627, 46.08745336532593, 47.33387334006173, 46.877036230904714, 51.47549302237374, 48.74649769919259, 40.47795377458845, 29.464009829929896, 29.32163429260254, 36.15625415529524, 35.5593135697501, 40.21458578109741, 44.37004974910191, 39.45420619419643, 40.625099250248496, 42.37512813295637, 42.54393114362444, 41.81120538711548, 37.13882671083723, 38.428683349064414, 37.36631768090384, 38.35741220201765, 42.05271782193865, 43.07670511518206, 41.449551650456016, 40.38370840890067, 41.91115174974714, 43.41380391802107, 40.74959707260132, 39.161964961460654, 41.31907490321568, 40.15721103123256, 41.71723100117275, 39.55351332255772, 42.91731343950544, 36.92831366402762, 37.44875110898699, 42.545501436506, 40.52091448647635, 41.93427882875715, 39.37587915148054, 37.30724062238421, 38.15944412776402, 27.02203243119376, 22.058237620762416, 27.9117978981563, 36.29533624649048, 46.162810053144185, 44.892394474574495, 47.62582969665527, 44.3365455354963, 43.32678467886788, 44.40144518443516, 42.2257661819458, 52.53934213093349, 54.01014723096575, 47.31402233668736, 53.510210445949006, 51.05305644444057, 50.26630844388689, 52.712265423366, 54.21221474238804, 46.58464561189924, 43.314955370766775, 47.370462553841726, 53.977240562438965, 53.71402890341622, 54.304750851222444, 51.40594155447823, 55.18419476917812, 55.919897828783306, 49.00250407627651, 45.88887732369559, 46.34877858843122, 46.06884608949934, 48.99896396909441, 48.92231839043753, 53.97485038212368, 57.62741763251168, 57.15859835488455, 61.45872729165213, 61.463396481105256, 63.365021160670686, 65.02051285334996, 63.22001920427595, 63.38744299752371, 60.46555873325893, 63.82456111907959, 61.78443104880196, 57.787872382572715, 34.88219772066389, 19.41790999685015, 5.789930846009936, 20.787379094532557, 54.83790349960327, 59.641356468200684, 40.740015506744385, 46.39992775235857, 50.22652653285435, 72.81921264103481, 51.56004217692784, 57.24274103982108, 66.98643616267613, 77.34689508165631, 44.32843698774065, 0.5093568595392364, 0.3363610995667321, 0.23644714376756124, 0.25276756659150124, 0.20854258111545018, 0.27477389574050903, 0.24182971779789242, 0.14239795612437384, 0.22669009518410477], [0.024035815515422394, 0.013849421354409839, 0.04412044358572789, 0.05384726682677865, 0.08563712438834564, 0.048041412473789284, 0.09465883100139243, 0.017360053823462555, 0.15703209729066916, 0.983355204973902, 19.742896352495464, 46.76139041355678, 33.06915215083531, 34.46213395254952, 38.81908178329468, 75.88285405295235, 46.848044872283936, 37.835154329027446, 23.003397600991384, 45.235232489449636, 49.54332753590175, 48.27381869724819, 14.688710689544678, 0.32288430844034466, 0.10096061642148665, 20.61978680746896, 54.01795353208269, 47.59754358019148, 56.57621077128819, 54.23711708613804, 54.8121326310294, 52.731369495391846, 55.42791673115322, 53.38125188010079, 48.92573690414429, 43.32774700437273, 41.54466206686837, 41.68992110661098, 42.13220173971993, 42.358598368508474, 43.38667120252337, 39.57830449513027, 40.3474075453622, 39.88838522774832, 38.948769909994944, 41.59281655720302, 50.013762269701274, 50.54911402293614, 49.764464378356934, 52.48275252750942, 50.728068351745605, 50.52197783333914, 48.14856699534825, 49.94161912373134, 49.89788716179984, 49.44504179273333, 52.04779876981463, 52.12673725400652, 52.448532649448936, 50.453190667288645, 52.61837094170706, 51.61745514188494, 46.89967693601336, 44.07629033497402, 38.5633533341544, 40.62246935708182, 41.566979680742534, 46.732947962624685, 45.500650201525005, 25.56875589915684, 14.804241861615862, 17.85822180339268, 27.650231225149973, 27.777428422655376, 37.65045383998326, 33.215769563402446, 33.497661454336985, 33.60817950112479, 34.72518580300467, 36.5831549508231, 34.67414781025478, 35.18464238303048, 30.52042784009661, 32.480959347316194, 34.31947353907994, 32.55869231905256, 33.79965100969587, 35.942371232169016, 35.63307564599173, 35.18774127960205, 36.65574625560215, 34.181249550410676, 35.514389991760254, 34.059367724827354, 33.58428464617048, 36.62862743650164, 34.18301091875349, 38.398972851889475, 37.62680912017822, 35.594558307102744, 31.585795130048478, 34.18341391427176, 34.24266120365688, 27.8252945627485, 20.144312892641338, 18.477245501109532, 12.244622775486537, 26.467413323266165, 36.27618701117379, 40.93982137952532, 38.35736009052822, 35.27064023699079, 35.99974945613316, 36.37846449443272, 39.48650142124721, 41.57505348750523, 43.71336855207171, 45.942496572222026, 44.93781137466431, 45.865892682756694, 49.14564391544887, 45.74624122892107, 45.603966440473286, 42.313587938036235, 40.71031195776803, 41.52402244295393, 45.80862562997, 45.99780075890677, 49.70725985935756, 47.79302767344883, 47.551087924412315, 50.656772886003765, 47.74992799758911, 45.44369234357561, 38.81527417046683, 39.81519637789045, 39.32956940787179, 42.85666608810425, 41.708333832877024, 49.36760064533779, 53.003151757376536, 55.50207485471453, 55.09824902670724, 55.065807887486045, 55.14035511016846, 52.791096210479736, 51.49810593468802, 51.6185633795602, 52.90443522589547, 55.99421576091221, 52.85785102844238, 44.867321899959016, 28.3409811769213, 23.047159092766897, 6.927646253790174, 12.741158417293004, 43.18684101104736, 44.61900717871529, 27.676837614604406, 26.10262942314148, 30.32291487285069, 53.36075816835676, 43.85721363340105, 42.33446380070278, 50.26713180541992, 48.94266619001116, 1.288542777299881, 0.2640836036631039, 0.05745444380279098, 0.06461412818836314, 0.042393626246069155, 0.07517376156257731, 0.037350234908184836, 0.08436434197106532, 0.04407576544742499, 0.0322942499603544, 0.045488648382680755, 0.043661139838929684, 0.03667775920725294, 0.024590107379481196, 0.11420581676065922, 0.07032124551811389, 0.05023658861007009, 0.04432995145076087, 0.1806118270116193, 0.9545370084898812, 26.749862807137625, 62.518563815525596, 28.479538679122925, 22.489263909203665, 45.37426246915545, 51.30065202713013, 55.043076855795725, 39.527947425842285, 26.92581377710615, 53.858947481427876, 54.828902108328684, 54.30443123408726, 16.371404579707555, 0.8882654160261154, 0.20030300824769906, 27.00215537207467, 60.26747948782784, 51.98782191957746, 62.347214290073936, 59.1791136605399, 57.852136271340505, 58.47635895865304, 60.72602585383824, 56.15921810695103, 53.890888350350515, 47.52146775381905, 45.950368881225586, 44.8068482535226, 46.766229833875386, 46.89147111347744, 46.756214005606516, 42.095108781542095, 43.20133147920881, 42.60408517292568, 43.02226250512259, 45.219505241939, 52.29275056294033, 54.437162671770366, 54.414900643484934, 53.26679767881121, 53.01596423557827, 52.21333612714495, 50.64817796434675, 50.86099086488996, 52.497437545231406, 51.28659234728132, 52.98998492104666, 53.994142055511475, 54.45787525177002, 52.52782896586827, 54.63299070085798, 53.203072275434224, 49.68138476780483, 47.38489396231515, 41.01309013366699, 44.6204628263201, 43.497279575892854, 46.60959659303938, 50.4491468157087, 33.93705858503069, 19.459526232310704, 21.527141639164515, 28.77562573977879, 33.950284481048584, 43.00620174407959, 36.148663248334614, 37.07844339098249, 36.60491670880999, 36.3581132207598, 38.65293993268694, 38.99966893877302, 38.03668335505894, 33.3456244468689, 34.575278418404714, 36.27756970269339, 34.45641905920846, 35.35943126678467, 37.24231318065098, 36.12988574164254, 36.72681243079049, 37.841251373291016, 35.38389239992414, 37.00980908530099, 35.400453431265696, 37.0822753225054, 38.77208764212472, 36.209762232644216, 40.971981116703574, 41.65549625669207, 36.182945660182405, 33.46565110342843, 37.143711294446675, 37.80704191752842, 30.146666867392405, 22.17738880429949, 19.76341438293457, 20.395474638257706, 33.912184034075054, 43.554786341530935, 44.408376012529644, 44.09720441273281, 37.857492787497385, 41.580983775002615, 39.6491448538644, 43.002998624529155, 46.10104751586914, 48.71414341245379, 49.351244585854666, 47.87604822431292, 49.52969169616699, 50.577556473868235, 49.13589906692505, 48.961176191057476, 43.97668443407331, 43.49879080908639, 44.54657915660313, 50.08639873777117, 48.548811026981895, 51.45306076322283, 50.38688400813511, 50.51583562578474, 53.974624565669465, 52.75490999221802, 46.74855361665998, 41.839998722076416, 43.24800252914429, 42.60809080941336, 46.48627301624843, 45.49937173298427, 52.43725919723511, 56.2038185937064, 58.53947639465332, 59.45544351850237, 57.20296607698713, 56.574348654065815, 53.791647229875835, 54.09441498347691, 55.51467888695853, 58.90565340859549, 60.13829163142613, 58.477019037519185, 53.30421025412423, 41.68239273343767, 30.212733813694545, 9.772466744695391, 13.742162806647164, 49.276475020817344, 50.46007285799299, 36.40800823484148, 28.38029408454895, 34.92838587079729, 55.2543819972447, 54.120713915143696, 40.67245122364589, 55.3628260067531, 43.515942437308176, 0.7135326606886727, 0.22369501447038992, 0.07143277408821241, 0.03780792034896357, 0.05820585348244224, 0.06513672228902578, 0.0444185986582722, 0.059246020524629524, 0.04968286671542695, 0.05776852409222296, 0.09588690474629402, 0.164764153105872, 0.1350434236228466, 0.13471788966229983, 0.14274451109979833, 0.1984678152948618, 0.339925579726696, 0.14321660862437316, 0.2652132016207491, 1.12717781322343, 41.11487429482596, 75.73682376316616, 45.91997398648943, 44.71945381164551, 48.55138880865914, 86.76938193184989, 59.78708798544747, 50.6873345375061, 34.356629031045095, 59.07769775390625, 60.59589304242815, 58.558681215558735, 16.587893077305385, 1.7698185465165546, 0.21820820389049395, 27.612516403198242, 61.21588775089809, 53.82548148291451, 65.62292861938477, 61.3821998323713, 58.93171610151018, 60.046492031642366, 62.343629019601, 60.08851473672049, 54.36759730747768, 49.952972480228965, 45.60584592819214, 47.77616092136928, 49.59931264604841, 49.342145919799805, 48.50617340632847, 43.677891050066265, 46.459192412240164, 44.58243880953108, 42.73686177389962, 47.00892693655831, 54.467724323272705, 57.03499337605068, 56.95674276351929, 56.8607360294887, 54.561108112335205, 54.255359581538606, 53.3860878263201, 54.10705028261457, 52.8189480645316, 54.77937534877232, 56.60919039590018, 56.755474294934956, 56.77085413251604, 53.589531081063406, 56.49078266961234, 55.94675956453596, 53.8686124256679, 50.792228017534526, 41.88513422012329, 46.2606372152056, 46.60967302322388, 51.52264697211129, 52.07707847867693, 36.67398527690342, 24.903952257973806, 27.252135923930577, 35.294625418526785, 36.23696443012783, 45.89033644539969, 38.19329922539847, 40.643220152173726, 39.16780144827706, 41.84785713468279, 41.126432623182026, 40.53164597920009, 39.905786991119385, 38.03425843375069, 38.91165263312203, 40.30058363505772, 39.82172073636736, 41.857362270355225, 40.93293571472168, 39.84929813657488, 40.71081222806658, 42.21270704269409, 39.59623432159424, 41.61386265073504, 37.397296224321636, 41.57619994027274, 42.56187834058489, 40.719716344560894, 44.27040910720825, 44.33924491064889, 38.84827463967459, 36.5996082850865, 40.150325366428916, 39.360071999686106, 32.29671049118042, 29.502026898520334, 23.417484181267874, 28.855057546070643, 36.3341315133231, 46.080307143075125, 48.083736828395296, 46.580917903355186, 41.93829836164202, 43.79979372024536, 40.34632362638201, 47.34762382507324, 47.679219654628206, 50.38132892336164, 50.98386280877249, 48.140385491507395, 52.16322571890694, 54.36771890095302, 49.646754946027485, 52.41782855987549, 45.362797941480366, 46.69209950310843, 46.402647972106934, 51.610968998500276, 50.113750321524485, 53.3526530947004, 53.01475524902344, 52.353238105773926, 57.59164483206612, 56.123282023838584, 50.177934306008474, 44.30584144592285, 44.50604336602347, 45.25363826751709, 49.877254486083984, 47.15626696177891, 55.598105907440186, 61.429850578308105, 61.009477615356445, 62.05592496054513, 58.598306792122976, 60.11811406271798, 54.755643776484895, 54.881896018981934, 55.31423030580793, 59.56784452710833, 64.43398066929409, 62.24232428414481, 59.18005861554827, 44.12365967886788, 32.043816907065256, 10.552180562700544, 15.387213093893868, 53.46967812946865, 56.497692653111045, 40.88923154558454, 35.091873509543284, 44.05798530578613, 72.03826986040387, 55.91120563234602, 60.16962800707136, 61.42045661381313, 62.75981221880232, 2.443862531866346, 0.5803995302745274, 0.20514761257384503, 0.12031367687242371, 0.1734062736587865, 0.18180451515529836, 0.12420150611017432, 0.24622974597981998, 0.19226729444095067, 0.15703101163463934], [0.0227903237765921, 0.027744843990408947, 0.04483971106154578, 0.03342735255137086, 0.14650527786995682, 0.05614257098308631, 0.05741227963673217, 0.09325214648353201, 0.10580289337251868, 0.07292160205543041, 0.5066024416259357, 32.258373805454795, 47.987771783556255, 42.984474727085654, 44.056074551173616, 96.53167738233293, 65.79530647822789, 34.29848303113665, 24.540589264460973, 34.39886018208095, 49.89474310193743, 49.079427582877024, 15.058933292116437, 0.8490822985768318, 3.245979730572019, 41.08874559402466, 53.78257635661534, 52.22438723700387, 53.79807431357247, 54.255161557878765, 55.12234885351998, 54.351418427058626, 56.98076616014753, 52.802157742636545, 47.77103662490845, 41.371318408421104, 40.95030621119908, 40.41578129359654, 41.26788752419608, 42.410959993089946, 41.090371472494944, 38.85609483718872, 39.92362649100167, 39.21067878178188, 40.655883244105745, 37.10565948486328, 47.218258789607454, 49.84283658436367, 48.248443875994, 48.381321225847515, 50.922544956207275, 49.17130708694458, 48.3424460547311, 47.69681249346052, 50.69469962801252, 50.04505695615496, 49.76673991339547, 50.63516051428658, 52.89890098571777, 51.46792990820748, 54.149052143096924, 50.377959047045024, 47.9823556627546, 46.23756572178432, 43.69603279658726, 39.60039976664952, 40.14255033220564, 42.106531620025635, 47.534103052956716, 40.258022444588796, 24.815406152180262, 15.132207257407051, 12.639343857765198, 23.583104916981288, 28.937595197132655, 35.906087739127024, 30.784177984510148, 31.96995755604335, 32.68696996143886, 37.20561279569353, 35.04436520167759, 34.18790245056152, 31.287918908255442, 29.272684233529226, 34.14783566338675, 31.241359029497417, 29.600764274597168, 32.12679924283709, 30.653489317212784, 34.63420261655535, 33.30977521623884, 31.151942661830358, 35.379317011152, 38.03312587738037, 39.965941020420615, 39.65962273733956, 41.15570885794503, 32.77772038323538, 31.787515231541224, 33.301621505192344, 32.40288938794817, 35.486948081425254, 29.892460073743546, 23.598224197115215, 20.58727444921221, 13.002633895192828, 21.677901915141515, 28.12632179260254, 40.30322047642299, 38.43035091672625, 38.95374482018607, 36.052260466984336, 37.25169324874878, 38.62956271852766, 36.80756786891392, 43.81038972309658, 45.60771499361311, 46.47062914712088, 46.33598348072597, 45.59811953135899, 45.49504995346069, 44.05451815468924, 42.125121525355745, 41.3564110483442, 40.982365199497764, 43.84204224177769, 47.81592198780605, 46.400132724217, 48.68455798285348, 43.68325505937849, 48.082802295684814, 48.60037360872541, 48.09817171096802, 41.89741168703352, 38.49754694529942, 39.08909920283726, 40.45198835645403, 42.463474478040425, 42.42377594539097, 48.84284836905343, 52.83158336366926, 55.571966784340994, 52.64335666384016, 58.20370122364589, 54.15520477294922, 55.00716856547764, 54.45871250970023, 54.15326969964163, 57.57646996634347, 54.92166403361729, 51.46057176589966, 53.49174908229283, 45.50692095075335, 35.2740135874067, 11.574237125260488, 12.406177946499415, 46.71899250575474, 40.62123605183193, 23.48574675832476, 30.584309577941895, 17.149856431143625, 48.853420053209575, 47.17842129298619, 30.977466447012766, 56.24922507149832, 17.97378076825823, 0.32491087540984154, 0.06816828783069338, 0.03231692320800253, 0.061303392983973026, 0.043519600826714716, 0.008052130113355815, 0.03560774340959532, 0.026788289425894618, 0.03242664232051798, 0.04032735479995608, 0.028359143795179467, 0.035379236564040184, 0.029117538992847716, 0.05008292078439679, 0.04896322265267372, 0.01178031278375004, 0.03657937841489911, 0.06906268519482442, 0.05486892004098211, 0.13077072932251863, 0.5388519082750592, 37.25907570975167, 63.94866289411272, 27.160676785877772, 40.25974907193865, 83.96841716766357, 68.83036994934082, 43.04380886895316, 26.65825080871582, 40.55667686462402, 55.807271003723145, 56.045173849378315, 17.2027930191585, 0.7445661925843784, 4.414581401007516, 49.8545686176845, 58.19243819372994, 59.491643633161274, 57.76027761186872, 59.10167598724365, 60.245418957301546, 60.79283973148891, 61.79253264835903, 56.43377617427281, 52.32554953438895, 47.014162404196604, 44.677837576184956, 44.34879173551287, 43.83016429628645, 47.000655106135774, 43.97581243515015, 42.83947624479021, 42.22117689677647, 42.29038790294102, 41.7792957850865, 39.46534068243844, 50.56729745864868, 54.598454679761616, 53.24772834777832, 52.03880780083792, 53.45559760502407, 51.11904001235962, 51.23160777773176, 49.133074624197825, 52.61920819963728, 52.67309842790876, 53.076305866241455, 55.375853879111155, 51.691224166325156, 51.633592333112446, 55.893991470336914, 52.24846969332014, 50.474816935403005, 47.75896412985665, 44.72079481397356, 40.506795746939524, 42.43814134597778, 43.276417187282014, 51.1299660546439, 44.460233892713276, 32.44907406398228, 16.77251192501613, 17.091779913221085, 26.92987847328186, 32.95398923328945, 40.28973402295794, 33.428999355861116, 35.22349670955113, 37.673466273716514, 39.645486627306255, 37.47319139753069, 35.78562682015555, 33.733778612954275, 31.447637149265834, 37.106614862169536, 36.15318652561733, 32.822296551295686, 33.617997305733816, 34.56344216210501, 38.718784536634175, 35.39209822246006, 34.699130058288574, 37.667216369083945, 40.88899530683245, 42.76830237252371, 39.10795661381313, 43.39457130432129, 33.97358873912266, 32.59882858821324, 34.9186931337629, 33.328590938023154, 36.91781146185738, 31.606872490474156, 27.884234394345963, 23.124617610658916, 16.095812967845372, 30.069055489131383, 39.454793316977366, 44.07679060527256, 42.43874931335449, 41.345533643450054, 39.13952228001186, 41.15503488268171, 42.592290605817524, 39.170858655657085, 47.46518734523228, 48.2854881967817, 49.91895409992763, 48.78632477351597, 47.672712666647776, 48.08692257744925, 45.94588034493582, 45.353337969098774, 43.811296463012695, 44.020888873508994, 47.8294084412711, 51.76741116387503, 48.135327202933176, 52.320411341530935, 46.81523200443813, 51.54298782348633, 50.749281202043804, 52.33776446751186, 45.173285824911936, 40.83033166612898, 43.00914430618286, 45.472642013004844, 46.99225125994001, 46.80023084368025, 52.09317398071289, 56.49152612686157, 57.61982325145176, 56.202526228768484, 59.806841714041575, 57.163180691855295, 59.59219796316964, 59.351825032915386, 58.082139015197754, 60.87817055838448, 58.51055104391915, 56.972337995256694, 57.94366141727993, 55.96937247685024, 41.77113512584141, 13.742344328335353, 15.342211348669869, 51.04172740663801, 47.47082928248814, 27.50962574141366, 31.35702916554042, 23.153834785733903, 55.24513394492013, 56.98225654874529, 33.55819068636213, 62.2395658493042, 14.226028408323016, 0.28823418489524294, 0.05643115531919258, 0.15029781364968844, 0.03713735472410917, 0.10884513905537979, 0.016875147254073193, 0.0305453734472394, 0.055668868723192384, 0.005301218953848417, 0.02205617942049035, 0.13521383090742997, 0.17567567474075726, 0.08521702978760004, 0.12404727510043553, 0.26358531468680924, 0.15131799105022634, 0.14481818197028978, 0.22502744011580944, 0.21111128399414675, 0.1403475318636213, 1.501340152961867, 58.728939873831614, 74.26888479505266, 61.50981739589146, 58.14030933380127, 103.78508254459926, 75.17259529658726, 46.219611576625276, 33.7683459009443, 47.67837544849941, 61.791810035705566, 61.537151609148296, 20.069741351263865, 1.0001041633742196, 3.7594414012772694, 49.96665695735386, 64.94552094595772, 61.44443484715053, 60.39990520477295, 64.51271070752824, 63.97218254634312, 63.17391095842634, 64.53329127175468, 57.806920869009836, 52.754958629608154, 47.962654045649934, 47.36575862339565, 45.85899659565517, 46.78783873149327, 49.638959067208425, 45.785828590393066, 42.98100757598877, 44.57200608934675, 44.35888746806553, 43.18367958068848, 40.11802666527884, 53.01246234348842, 56.2714558328901, 53.560657841818674, 52.557490825653076, 54.98817566462925, 54.29426254544939, 52.537372316632954, 51.368171146937776, 54.25392130443028, 54.88726002829415, 53.40915584564209, 55.40838187081473, 55.30644484928676, 55.7729469026838, 58.96247577667236, 54.88575226919991, 51.181035314287456, 50.57498564038958, 47.33965424128941, 43.72679941994803, 44.98519808905465, 45.99717889513288, 52.61681454522269, 49.39153718948364, 36.89857884815761, 21.03405577795846, 23.045977899006434, 29.17291852406093, 35.68694850376674, 42.64087241036551, 37.411675521305625, 38.07299811499459, 39.24387380055019, 44.419430596487864, 43.491432666778564, 40.17600243432181, 35.68862301962716, 33.587932450430735, 43.24897527694702, 37.70890556062971, 35.900445801871165, 37.15361942563738, 39.362403120313374, 41.7994316646031, 38.62832246507917, 37.03319672175816, 39.96194928033011, 44.31566967282976, 47.04350464684622, 43.05480439322335, 46.18137911387852, 38.78209999629429, 38.43142441340855, 38.89137084143502, 36.926218782152446, 38.94078990391323, 34.31729180472237, 29.770116192953928, 23.82944287572588, 26.388711077826365, 31.511577946799143, 39.65380014692034, 48.8143572807312, 43.78688744136265, 45.85985817228045, 41.9094876561846, 44.185251985277446, 45.63892977578299, 41.08141871861049, 48.99197060721261, 50.297102860042024, 51.506051199776785, 50.25345427649361, 49.41983025414603, 51.587560517447336, 48.64754145486014, 47.39933231898716, 46.40457957131522, 45.72125203268868, 49.718477725982666, 54.589998722076416, 49.70686728613717, 54.40526696613857, 46.827446937561035, 54.28432314736502, 53.27601446424212, 54.788289887564524, 47.693925516945974, 44.20675318581717, 44.85856716973441, 47.45922579084124, 49.773625578199116, 49.37137699127197, 56.346538066864014, 60.020345960344585, 60.66046265193394, 57.46973173958914, 63.67796107700893, 58.5774621963501, 58.464679036821636, 60.052238191877095, 58.3024594443185, 66.85355881282261, 61.14220210484096, 61.81189032963344, 63.65244034358433, 59.88511317116873, 42.75469085148403, 14.903279747281756, 16.016509703227452, 55.95788710457938, 52.994754859379356, 35.72004277365548, 38.862306526729036, 25.975178616387502, 68.4221076965332, 58.80930968693325, 49.768383162362234, 75.4973749433245, 26.321028675351823, 0.6774443143180439, 0.19830529258719512, 0.34223105173025814, 0.2418741211295128, 0.21581673435866833, 0.07784168661705085, 0.24571015100393975, 0.1664061535681997, 0.13372291305235454, 0.11281736447874989], [0.03422341322792428, 0.057815587281116416, 0.027454293599086146, 0.04284525915448155, 0.03048234772203224, 0.06666909863374063, 0.1599142019237791, 0.08511022159031459, 0.029693248814770153, 0.06017030057098184, 0.22770082737718308, 5.638046698910849, 50.39823041643415, 49.78563206536429, 49.34890651702881, 76.56803676060268, 94.40629291534424, 32.35358844484602, 23.494517121996196, 27.53518990107945, 49.845157282693044, 51.10048137392317, 19.754635334014893, 0.40715548076799934, 19.86322351864406, 50.11346544538225, 47.33996343612671, 51.269395555768696, 55.53882040296282, 52.105423654828755, 52.94719444002424, 53.89609949929373, 50.9950007711138, 51.458407402038574, 47.35122994014195, 42.209535190037315, 42.739818232400076, 43.74110228674752, 40.66620479311262, 41.970888887132915, 40.971810885838096, 39.43475471224104, 39.73779344558716, 38.3662120955331, 38.8152984891619, 38.98224980490548, 42.513244424547466, 50.806384972163606, 52.32349286760603, 50.8312977382115, 51.592233180999756, 48.81442328861782, 48.67602906908308, 51.25047213690621, 51.014077050345286, 51.76742506027222, 54.617121015276226, 52.97547360828945, 46.825730732509065, 52.02896220343453, 52.019884381975444, 49.305737359183176, 48.99324907575335, 43.41444315229143, 41.52901472364153, 39.21486854553223, 37.87241404397147, 42.68233925955636, 47.680171557835166, 43.43931770324707, 32.53822987420218, 14.145619511604309, 15.108011892863683, 16.5723933832986, 24.574988058635167, 29.58514472416469, 30.27912732533046, 31.608658177512034, 31.345776557922363, 34.09198604311262, 31.59374734333583, 33.911662919180735, 30.26909065246582, 32.51320593697684, 29.939006056104386, 33.95491198131016, 29.974400179726736, 31.520096438271658, 29.4278826713562, 32.25981903076172, 34.61277437210083, 36.103506905691965, 39.71520137786865, 35.36103630065918, 43.078306674957275, 40.445818356105256, 41.21420921598162, 38.270875862666536, 31.231648921966553, 37.48083094188145, 34.03509766714913, 29.408097675868444, 26.920177050999232, 23.837396826062882, 18.875446762357438, 12.87981493132455, 27.302635431289673, 38.498797621045796, 40.68204321180071, 38.92742504392351, 38.744207995278494, 36.16960164478847, 37.69441161836897, 38.24235003335135, 38.359920501708984, 45.64956051962716, 45.550764083862305, 45.65627595356533, 46.223436559949604, 45.694355555943076, 44.87512125287737, 42.06306021554129, 40.540772438049316, 42.27984748567854, 42.071988650730674, 47.42202513558524, 48.36507633754185, 47.36481714248657, 48.50848020826067, 44.531987939562114, 49.804461683545796, 48.142973695482524, 49.09826414925711, 40.52050106866019, 38.463063035692485, 38.182189055851524, 42.0879556110927, 43.21308435712542, 44.04196623393467, 46.926757540021626, 51.16011428833008, 54.27899735314505, 53.02096346446446, 57.43121787479946, 57.2013714654105, 59.785086904253276, 56.8877888407026, 55.79980863843645, 55.76753773008074, 57.08354043960571, 56.22052901131766, 56.15244013922555, 55.08846248899187, 44.024293490818565, 12.512007696287972, 14.480509655816213, 49.98132460457938, 33.95726047243391, 20.343672343662806, 18.930229834147863, 20.597816603524343, 48.04058156694685, 44.094327858516145, 34.52720035825457, 57.9216946874346, 5.225191252572196, 0.42834336097751347, 0.04746194356786353, 0.16597683089120047, 0.07534364637519632, 0.04621000235368099, 0.04248659572164927, 0.05121451363499675, 0.04534480913675257, 0.05632065589140568, 0.0249399956581848, 0.024278527491592934, 0.03284724582252758, 0.014895117608830333, 0.010815933014133146, 0.05824545957148075, 0.05032784478472812, 0.0790908628010324, 0.04184790088662079, 0.12377221057457582, 0.16274690920753138, 0.2655650627400194, 3.77790059362139, 56.779577595846995, 48.16462428229195, 42.48736585889544, 84.60866587502616, 90.75148487091064, 42.02115910393851, 27.044555016926356, 33.015470368521555, 55.73601722717285, 57.08211605889456, 23.108188595090592, 0.2644570421959673, 26.161537987845286, 59.77613067626953, 54.56633315767561, 59.65328652518136, 60.035687582833425, 56.99409975324358, 56.586653913770405, 57.75027567999703, 54.62677901131766, 55.80542278289795, 50.9583420753479, 46.233872754233225, 45.66816432135445, 45.443848678043906, 42.594055448259624, 44.967754636492046, 44.72229215076992, 43.15079723085676, 42.16060944965908, 41.02349853515625, 41.192433561597554, 42.09870794841221, 42.559877259390696, 52.888405731746126, 55.08236197062901, 54.86775296075003, 52.898953097207205, 49.67822681154524, 51.32575586863926, 52.75604602268764, 52.02351481573922, 52.719800744737896, 55.52708142144339, 54.747969491141184, 50.81620972497122, 56.25317512239729, 53.191385405404226, 52.247486523219514, 49.693891525268555, 47.46605934415545, 43.27702515465872, 43.070621967315674, 41.74535036087036, 44.59292711530413, 49.348447935921804, 48.70719173976353, 36.749338490622385, 22.28562436785017, 15.91777059010097, 21.23229135785784, 29.09843557221549, 32.21393312726702, 34.89578839710781, 36.08824518748692, 34.01771674837385, 36.16280630656651, 34.836377825055806, 35.869797297886436, 34.03780051640102, 35.381946904318674, 32.751980781555176, 34.89879696709769, 32.53746209825788, 34.51001746313912, 31.79409170150757, 34.61646386555263, 35.647093636649, 37.19582278387887, 40.51713466644287, 35.2984538759504, 41.7212679045541, 41.0006354876927, 43.592063426971436, 40.43484367643084, 32.914943831307546, 41.038586548396516, 35.03713212694441, 31.221254416874476, 29.73019184385027, 26.491410664149694, 17.87714695930481, 23.99909704072135, 37.62594754355294, 42.76003054210118, 43.94907924107143, 42.608063016619, 42.40760401317051, 38.91189234597342, 40.022572313036235, 41.81529092788696, 42.32858909879412, 50.0583210672651, 48.73372343608311, 51.507913316999165, 51.88428681237357, 50.158444608960835, 48.21143429619925, 46.68804522923061, 44.60473905290876, 46.28644282477242, 45.411417961120605, 50.79356901986258, 49.86885758808681, 51.693093231746126, 48.958296162741526, 47.097957679203574, 52.22452967507498, 50.2432473727635, 50.49517863137381, 43.07786546434675, 42.302404812404085, 41.96580280576433, 44.61375434058053, 46.95868798664638, 46.885328905923025, 48.43902601514544, 53.254447255815776, 57.38118042264666, 57.71627467019217, 58.21939720426287, 59.8911372593471, 60.77933938162667, 60.411126545497346, 59.83168152400425, 61.20087269374302, 62.3754517691476, 60.152431215558735, 61.15198516845703, 60.21134499141148, 49.502948079790386, 13.61693629196712, 16.617681741714478, 55.714307580675396, 40.23758431843349, 24.08004355430603, 23.643071344920568, 24.72631982394627, 54.630249636513845, 41.69751896177019, 32.89943197795323, 67.74004473005022, 6.4237611549241205, 0.4191091236259256, 0.038759419827588966, 0.11713943577238492, 0.15337351789431913, 0.05911093098776681, 0.020198739000729153, 0.024983197982822145, 0.06687150562980346, 0.09312361838029963, 0.042765666996794086, 0.14003520219453744, 0.14687419735959598, 0.0715668797492981, 0.20866186757172855, 0.07781898962067706, 0.1334810153182064, 0.17488067597150803, 0.13963707855769567, 0.1793101661439453, 0.5174071618488857, 0.32321779483130997, 8.235241208757673, 71.26439339773995, 60.551056316920686, 64.65999862125942, 83.45170743124825, 101.6276112965175, 45.119412967136924, 30.634367874690465, 39.37026500701904, 62.41709232330322, 60.69372367858887, 25.29679819515773, 0.5619695420776094, 26.10230459485735, 65.38798918042863, 57.31327567781721, 62.549948828560964, 63.554651396615164, 58.02292646680559, 58.83952740260533, 59.93285424368722, 57.97593927383423, 58.91358825138637, 53.04570599964687, 47.766770430973594, 48.85262448447091, 48.9755346434457, 45.941843441554475, 49.160506112234934, 47.59507696969168, 45.80179555075509, 47.536124978746685, 42.6719343321664, 42.652625288282124, 43.42186035428728, 46.262857164655415, 54.24315159661429, 57.8976400239127, 56.97919586726597, 56.81145245688302, 51.215001583099365, 54.26495156969343, 54.91319417953491, 54.51478794642857, 54.17706380571638, 54.53099809374128, 56.1155868938991, 50.311409200940815, 58.01520354407174, 57.6417760848999, 53.882244791303364, 54.9128919328962, 48.327410152980256, 46.72808422361101, 43.72074406487601, 44.6222311428615, 46.92552770887102, 53.87888881138393, 46.93832629067557, 40.3723098891122, 28.27071578162057, 18.29990836552211, 27.187736545290264, 30.879545484270366, 35.53168058395386, 35.88952670778547, 39.30443777356829, 39.10567760467529, 41.90229279654366, 38.00203963688442, 39.00801372528076, 36.718940121786936, 39.26249497277396, 37.19184841428484, 40.53852122170584, 35.0612701688494, 37.296436173575266, 34.67745515278408, 37.90929160799299, 37.0807397706168, 40.49761717660086, 42.84512513024466, 39.451816013881135, 47.554030486515586, 45.9744165965489, 51.414717129298616, 42.964991978236604, 35.48734760284424, 46.010067803519114, 36.0847224508013, 33.97113602502005, 31.145449570247106, 29.259381907326834, 26.202987466539653, 26.013378075190953, 38.427338872637065, 46.8445360319955, 47.08213315691267, 45.89017316273281, 45.15620020457676, 41.12318434034075, 43.16935586929321, 44.704838275909424, 42.678187710898264, 52.7593047278268, 50.01285900388445, 52.01147011348179, 52.23690789086478, 50.59368324279785, 49.4661990574428, 48.048269748687744, 47.791992391858784, 46.827429567064556, 46.45730945042202, 52.1707957812718, 53.407821791512625, 52.91085883549282, 52.329218183244976, 47.796939509255544, 54.59753056934902, 53.2352910723005, 57.15967879976545, 47.69019433430263, 45.51074940817696, 44.286094665527344, 47.50278057370867, 48.41018751689366, 50.05370398930141, 53.37976843970162, 58.33787441253662, 62.28811291285923, 59.11623246329171, 63.03787912641253, 64.4476547241211, 64.86572783333915, 63.552629470825195, 60.85598496028355, 63.388464382716585, 65.5023078918457, 64.54588835580009, 65.56760706220354, 65.274886403765, 52.2785519191197, 16.772708211626323, 17.312915018626622, 62.573239190237864, 45.84450612749372, 31.418360914502824, 25.15577929360526, 31.87848104749407, 61.572087151663645, 58.43416254861014, 49.975217138017925, 76.72122369493756, 9.559623445783343, 0.7957278415560722, 0.19507024117878505, 0.3168967254459858, 0.2184578776359558, 0.14524712466767856, 0.14843014601085866, 0.1432918988700424, 0.17042025817292078, 0.20631759693580015, 0.1882431882300547], [0.0464617117041988, 0.008228927501477301, 0.02434778556094638, 0.06551656619246517, 0.06714578305504151, 0.04042930129383292, 0.10570168308913708, 0.05984409486076661, 0.07717267144471407, 0.03815248043143323, 0.05687828954043133, 0.07085441797971725, 21.086203745433263, 57.40212229319981, 31.142204761505127, 50.10815354755947, 101.60287570953369, 42.8949020249503, 16.92260864802769, 28.90235219682966, 39.4534592628479, 53.640603814806255, 28.99834156036377, 2.865907622235162, 30.710186617715017, 48.566323961530415, 51.005165985652376, 54.14922932216099, 52.21297482081822, 53.76848540987287, 52.81561292920794, 53.195345878601074, 52.253764220646445, 50.1985878263201, 47.08565936769758, 42.431589194706504, 42.058870451790945, 41.7310266494751, 39.8751836504255, 42.082494327000205, 40.12138959339687, 41.288509777614046, 41.38647590364729, 39.67466558728899, 40.01015935625349, 38.878096308027, 38.875251020704, 46.37916653496878, 48.987714835575645, 50.150735582624165, 49.36726713180542, 47.55915130887713, 49.82754012516567, 49.96130337033953, 48.10232673372541, 48.90312399183001, 46.54150424684797, 49.74095862252371, 53.15464333125523, 52.03636203493391, 51.597805636269705, 50.649536337171284, 47.30623688016619, 44.681488854544504, 42.944671971457346, 39.537362234933035, 39.16995538984026, 42.08519370215279, 45.020533152988975, 49.06681660243443, 39.15839358738491, 23.887729576655797, 12.064524599484034, 12.231002569198608, 24.957764319011144, 26.239809444972447, 29.606204714093888, 30.122501032693044, 32.41684137071882, 28.68551802635193, 31.291525023324148, 32.34247480119978, 32.69245209012713, 30.553171225956508, 31.826908043452672, 25.854748964309692, 31.81291437149048, 33.12376151766096, 32.78929608208792, 35.38152306420462, 38.05183390208653, 39.41668592180525, 40.03316484178816, 40.06416422980172, 40.86133452824184, 41.3047650882176, 35.564229420253206, 42.87017338616507, 38.495580605098176, 38.03250401360648, 30.47151599611555, 31.10108184814453, 29.783199650900706, 22.58252263069153, 15.212139333997454, 24.540363448006765, 37.894297395433696, 42.66354438236782, 41.50476898465838, 39.25196845190865, 36.74263347898211, 35.597525187901084, 39.42698662621634, 38.7157620702471, 40.746960231236045, 45.3254895891462, 47.74188198362078, 46.982947622026714, 45.92909697123936, 47.96318210874285, 42.37613909585135, 43.81479835510254, 40.94712046214512, 43.46508509772164, 46.10933324268886, 48.171579429081504, 47.07598052706037, 49.106886863708496, 43.139429977961946, 47.40142720086234, 47.797238281794954, 50.7394495010376, 42.91785192489624, 39.6754264150347, 39.2015905380249, 39.688704422542024, 43.2012619972229, 42.67767701830183, 44.1569276537214, 42.001280307769775, 46.72047594615391, 49.284083298274446, 53.438220160348074, 55.912883622305735, 56.7738036428179, 54.686203479766846, 55.3261638368879, 56.65484006064278, 57.84782144001552, 56.15843990870884, 56.565145765032085, 54.45994234085083, 58.16062586648123, 47.108352184295654, 13.566204019955226, 12.652996199471609, 52.0246821131025, 25.46711938721793, 25.58088571684701, 12.137869783810206, 16.827795267105103, 49.25711733954293, 39.809634344918386, 34.44171667098999, 59.48475796835763, 3.655626194817679, 0.3504735694399902, 0.05325577088764735, 0.0734771526019488, 0.01711281432238008, 0.01671469916722604, 0.05170304188504815, 0.037607012915291956, 0.03840891917103103, 0.014188164695432144, 0.02697365840763918, 0.04425646271556616, 0.024323750154248307, 0.041784006636589766, 0.06163359526544809, 0.13825222929673536, 0.1063575278967619, 0.08691296699856009, 0.05444085604644247, 0.07204534871769802, 0.015370015786694629, 0.022369369132710353, 0.06908595894596406, 21.690643174307688, 62.37561157771519, 30.489612579345703, 59.144622802734375, 103.89184856414795, 49.44974224908011, 26.602488040924072, 34.36351816994803, 44.84188107081822, 60.81265599387032, 30.94996895108904, 6.817222876208169, 40.470960412706646, 57.512028898511616, 57.794751099177766, 59.1968663079398, 57.562552724565776, 57.60600675855364, 56.472884110042024, 56.500506673540386, 54.92660420281546, 53.12094109398978, 50.2561571257455, 46.757763453892295, 44.38170535223824, 44.57444838115147, 42.14155054092407, 45.08583927154541, 44.14360448292324, 44.76168843678066, 44.885338578905376, 43.52254670006888, 41.72262627737862, 41.10525451387678, 40.680865492139546, 47.06127119064331, 51.02863700049264, 51.60715096337454, 51.70671170098441, 51.09593725204468, 50.01283815928868, 52.09269802910941, 49.29747595105852, 50.21612160546439, 47.880161557878765, 52.192092009953086, 55.565477166857036, 53.50681972503662, 53.7113607951573, 52.109384128025596, 47.52422271456037, 46.08103322982788, 44.78055279595511, 42.32615375518799, 40.81335721697126, 43.867771421160015, 46.54702459062849, 51.8223922593253, 44.84894044058663, 31.031645025525773, 15.00672800200326, 15.135095970971243, 28.38193212236677, 28.492702041353496, 32.40170472008841, 33.90654904501778, 36.02663551058088, 32.44909143447876, 34.89542014258248, 36.237964970724924, 35.76210369382586, 35.51056153433663, 33.23211867468697, 26.196848733084543, 33.95394270760672, 33.409645148685996, 35.018795830862864, 36.12471628189087, 40.705542019435335, 41.002733843667166, 39.47923360552107, 40.93612493787493, 42.16649457386562, 42.47882652282715, 35.340733664376394, 42.14120660509382, 37.83022458212716, 38.32871266773769, 33.46054070336478, 33.1564701625279, 32.44378301075527, 22.573371853147233, 26.353344746998378, 33.09706653867449, 42.56046438217163, 46.97040959766933, 45.85007858276367, 40.46745504651751, 39.07484497342791, 37.50113010406494, 41.74265793391636, 40.382454259055, 45.5317816053118, 48.67289890561785, 49.13606234959194, 49.36171204703194, 49.22790016446795, 49.98466321400234, 45.74627249581473, 46.25369596481323, 43.863560812813894, 45.127045563289094, 47.107136249542236, 52.49651690891811, 50.862279755728586, 51.666825566973, 46.876883370535715, 51.542445863996235, 51.73589413506644, 52.81537321635655, 44.87773377554757, 42.751324449266704, 41.53867619378226, 42.688863618033274, 46.36294249125889, 47.05470514297485, 47.91173069817679, 45.109973839351106, 48.83944027764456, 52.42240742274693, 54.218384742736816, 58.01204906191145, 60.00292682647705, 59.14604023524693, 60.26185144696917, 60.36198888506208, 60.380512782505576, 59.861009870256694, 57.278711863926475, 57.793816566467285, 62.08378723689488, 52.85898011071341, 16.009662253516062, 15.639517818178449, 56.83927304404122, 30.65313148498535, 27.854735817228043, 17.219644137791224, 23.89370502744402, 57.79661321640015, 40.874209540230886, 33.470761503492085, 64.3181403023856, 3.275624219860349, 0.08780282496341638, 0.12687695611800465, 0.04448873882314988, 0.01712955378129014, 0.025600893855361, 0.10976152095411505, 0.08873279113322496, 0.08226853728826557, 0.024864050626222576, 0.017847433652994887, 0.11008667493505137, 0.16949493996798992, 0.1712129499231066, 0.1659507072929825, 0.1750957037189177, 0.2636042322431292, 0.14225432383162634, 0.21595734038523265, 0.17762632721236774, 0.18789896741509438, 0.11478201512779508, 0.13514813514692442, 36.98603234972273, 72.39854785374233, 40.64047908782959, 62.3688440322876, 106.80966118403843, 61.465897832598, 22.945788349424088, 41.71159601211548, 49.949560914720806, 65.65739863259452, 31.280797004699707, 6.600027399403708, 44.413719177246094, 60.17927210671561, 61.811112131391255, 63.24315670558384, 60.95184925624302, 61.601575306483674, 59.944610595703125, 61.6522832598005, 59.50344167436872, 57.55186639513288, 53.35239601135254, 49.10468775885445, 46.633140563964844, 46.37663391658238, 42.96671165738787, 47.82871362141201, 46.33653933661324, 46.79177141189575, 48.94619240079607, 44.64674091339111, 43.30311911446707, 43.448093278067454, 43.402936935424805, 50.08361251013619, 53.50219917297363, 54.98970079421997, 54.40914058685303, 52.78309188570295, 51.43872662952968, 55.225435801914756, 51.686336108616416, 52.916671003614155, 50.89597157069615, 53.37209415435791, 56.34788254329136, 56.494006633758545, 56.8135438646589, 54.50660644258772, 50.63317332948957, 50.016857692173545, 46.71430941990444, 44.75782176426479, 44.32019989831107, 46.98458044869559, 50.99693237032209, 53.703092438834055, 46.33644206183297, 35.78864581244332, 21.108411925179617, 19.166109016963414, 32.86727571487427, 31.598986285073416, 35.30631228855678, 36.0165502003261, 37.03546878269741, 34.54879188537598, 35.73828526905605, 39.19795315606253, 37.65575531550816, 37.05918298448835, 38.67360040119716, 34.24151822498867, 40.986895424979075, 36.31065355028425, 37.97577544621059, 37.80396386555263, 43.823619093213765, 44.29035043716431, 43.311328411102295, 42.59911373683384, 46.634815079825266, 47.2008570262364, 39.880266257694785, 46.19825628825596, 40.98412309374128, 40.14245653152466, 33.58432980946132, 33.13502107347761, 33.649212087903706, 30.887150287628174, 29.106828996113368, 32.67465427943638, 46.526329381125315, 48.36961351122175, 48.33238158907209, 43.96081822259085, 44.17427035740444, 39.27744402204241, 45.22822175707136, 43.63973501750401, 49.73621300288609, 52.08654539925711, 53.47628239222935, 51.99389464514596, 52.42221287318638, 54.12918724332537, 47.15341125215803, 49.11713545663016, 45.45203365598406, 47.778401715414866, 50.925518785204204, 53.99590342385428, 51.96524722235543, 53.62406710215977, 48.87259360722133, 53.17832279205322, 54.137785639081685, 56.21313612801688, 49.48423310688564, 44.25757578441075, 44.133251667022705, 46.00677783148629, 50.78468574796404, 49.5021698815482, 50.340390137263704, 48.39134052821568, 52.146188735961914, 56.32370628629412, 58.383155822753906, 62.6006498336792, 65.60125023978097, 59.931103297642295, 61.027202469961985, 63.89233384813581, 64.96042483193534, 64.5542539869036, 64.78171021597726, 61.3525310243879, 68.61841515132359, 56.896824972970144, 18.79525760241917, 15.451956408364431, 64.12395899636405, 37.487935474940706, 36.652894020080566, 15.573577676500593, 30.822671004704066, 63.084362574986045, 55.08549213409424, 52.31296287264143, 79.58292266300747, 7.199023348944528, 0.3743828907608986, 0.31857243552803993, 0.23260926827788353, 0.184542485379747, 0.18887081955160412, 0.14241059044642107, 0.20842011911528452, 0.17209755602691854, 0.2013193451400314, 0.19332141216312135], [0.0796807472194944, 0.008377147539119636, 0.11921770711030279, 0.042864271705704074, 0.04491459418620382, 0.05648706660472921, 0.16785805565970285, 0.09394005207078797, 0.053501726261207035, 0.02517425817703562, 0.01806358098318534, 0.09574630550507988, 4.569199664252145, 56.10167660032, 40.66256741115025, 35.06594630650112, 65.82769898005894, 49.26538569586617, 19.157338653291973, 24.552984850747244, 37.70496245792934, 50.48156016213553, 32.06787157058716, 10.21820410660335, 40.376822744097026, 56.99365506853376, 50.979252679007395, 49.78159516198294, 47.671621799468994, 47.34906905038016, 45.93053872244698, 47.282130105154856, 46.40947110312325, 46.34578044073922, 46.09001725060599, 40.95533670697893, 41.80207198006766, 41.4301974432809, 40.71558564049857, 40.058056763240266, 41.72562442507063, 41.088502407073975, 40.02127299989973, 39.934625489371165, 37.250779560634065, 36.689851488385884, 36.113352503095356, 38.58220727103097, 46.753820351191926, 44.75661972590855, 45.27396869659424, 47.925748688834055, 52.030244146074565, 49.74737180982317, 49.11670814241682, 51.06085927145821, 48.72405849184309, 48.92863777705601, 51.473960944584434, 51.25560685566494, 53.992332049778526, 50.626648971012656, 47.623814719063894, 42.47957692827497, 43.12964344024658, 39.66591433116368, 37.87788922446114, 39.50462579727173, 45.134876183101106, 47.22857339041573, 45.74777678080967, 29.95303099496024, 13.670178600719996, 16.32017203739711, 17.530530861445836, 23.363904884883336, 24.568534919193812, 29.689260005950928, 29.772568907056534, 30.49363558632987, 31.904140744890483, 34.02964333125523, 31.44308955328805, 31.47754567010062, 19.349273954119, 17.359224762235367, 29.50140850884574, 33.93538406917027, 28.50376878465925, 35.088871887751985, 39.56003073283604, 41.89654663630894, 36.786389759608674, 38.52412033081055, 38.69227368491036, 36.56512784957886, 39.19566025052752, 35.086308002471924, 37.15372364861624, 34.05830117634365, 33.99068825585501, 28.064262219837733, 23.733437878744944, 21.425746577126638, 27.606954370226177, 33.470323766980854, 43.843487467084614, 45.08016259329659, 45.24424082892281, 39.82912056786673, 34.39135265350342, 37.0635256086077, 39.849294662475586, 38.78884322302682, 42.1061737877982, 46.81967885153634, 45.731750760759624, 44.575688634599956, 46.01163114820208, 47.13119091306414, 45.615302426474436, 43.88656629834856, 44.850899832589285, 43.6889317376273, 45.488497802189414, 45.47690125874111, 48.706552505493164, 47.910500867026194, 47.33107321602957, 48.931823526109966, 46.78611557824271, 45.77326277324131, 37.848661627088276, 39.85275139127459, 40.569527557918, 39.6855742590768, 42.711295877184185, 45.02215903145926, 42.03928000586373, 44.26750823429653, 44.027614729745046, 45.01548876081194, 46.69167218889509, 49.780090876988, 53.1337639944894, 57.65823636736189, 54.96050793784005, 56.93511996950422, 52.038835593632285, 51.170084953308105, 52.49040249415806, 56.44609533037458, 55.222100666591096, 52.75848831449236, 11.21530100277492, 21.092663833073207, 49.59649167742048, 27.771880286080496, 26.811971017292567, 14.12734488078526, 24.650124141148158, 51.534205300467356, 91.05508640834263, 48.63727896554129, 48.386278765542166, 0.965219538126673, 0.20931666743542465, 0.08576277550309896, 0.04548002080991864, 0.027851728522883992, 0.03496406812752996, 0.0990271173151476, 0.07875221275857516, 0.06077019338096891, 0.06716360138463122, 0.2322874255478382, 0.08032233600637742, 0.05909614570971046, 0.09265568706073932, 0.06643022716577564, 0.06483740692159959, 0.052177117339202335, 0.2256695513746568, 0.13457150251737662, 0.08563346029924494, 0.047544972505420446, 0.09683734910296542, 0.10988833236375026, 4.566611894539424, 63.377659933907644, 45.159643036978586, 42.38956996372768, 74.50246238708496, 52.29391438620431, 27.70921274593898, 30.350836208888463, 41.24137667247227, 57.557473591395784, 36.961908204214915, 14.044749038560049, 45.211966446467805, 65.91647611345563, 55.10767078399658, 56.117966651916504, 54.265622070857454, 50.815028531210764, 49.06529147284371, 50.81903069359915, 48.47194310597011, 49.57614387784685, 49.70758295059204, 45.753894669669016, 46.05301114491054, 45.625471115112305, 44.05392755780901, 43.731923716408865, 44.23282977512905, 43.791633061000276, 43.06827695029122, 42.98926898411342, 40.37895584106445, 38.30710029602051, 38.325884750911165, 41.04643453870501, 47.30994027001517, 46.08271469388689, 45.47775936126709, 48.76118966511318, 52.81107922962734, 51.41608592442104, 50.132948194231304, 52.703121594020296, 52.25040476662772, 52.324055671691895, 52.84600782394409, 53.79407215118408, 55.154320989336284, 54.33103936059134, 51.18072959354946, 46.09491573061262, 44.405273641858784, 44.225683552878245, 41.22287361962454, 41.35058150972639, 48.93824366160801, 50.515891211373464, 48.92866904394967, 37.56002650942121, 24.11563570158822, 16.627758366721018, 23.03281627382551, 28.40388321876526, 24.634528909410747, 31.193753446851456, 31.957940646580287, 33.17639759608677, 31.34752402986799, 37.0679863521031, 31.915063313075475, 33.16593360900879, 18.5393328666687, 23.823488269533428, 39.7307688168117, 35.815285205841064, 29.698299612317765, 36.87927327837263, 40.779057434626985, 40.52739020756313, 34.69096939904349, 38.67909990038191, 37.87648916244507, 34.96137939180647, 38.82537685121809, 34.311858313424246, 36.223481450762065, 32.91187620162964, 33.658255168369834, 28.355659246444702, 24.289180857794626, 31.961525917053223, 37.362478801182334, 36.7895963532584, 46.126450129917686, 47.994376046316965, 47.813319887433735, 42.727203777858186, 38.87769331250872, 41.76526042393276, 43.24608135223389, 41.898360116141184, 46.57587351117815, 49.11211538314819, 50.26206309454781, 49.26235628128052, 50.29803739275251, 51.346603938511436, 48.731652872903005, 46.59329611914498, 47.14492402757917, 46.70968539374215, 48.75022193363735, 47.30187341145107, 49.51671593529837, 50.5130980355399, 52.79120390755789, 51.97713559014456, 49.83243860517229, 46.62707131249564, 41.381997789655415, 42.7535582951137, 42.7494067464556, 43.467756680079866, 45.73318556376866, 47.54391738346645, 46.18511029652187, 46.32678753989083, 46.93664830071585, 47.955608572278706, 47.69707652500698, 50.10671527045113, 53.865781034742085, 59.16978222983224, 58.9594533102853, 57.413600717272075, 52.546710695539204, 53.11461475917271, 56.37679052352905, 62.09805188860212, 58.42175306592669, 55.604241166796, 11.082151804651533, 26.677043948854717, 54.893200738089426, 32.45691163199288, 29.667988095964702, 18.384236914770945, 31.293102264404297, 56.269955021994456, 87.12621361868722, 57.270419188908164, 58.55403287070138, 1.7721722487892424, 0.10774690977164678, 0.11080465319433383, 0.07748967622007642, 0.037743147396083386, 0.041788325511983464, 0.13763833152396338, 0.08288202115467616, 0.006012893198723239, 0.06912049637841326, 0.2539501445634024, 0.25540096099887577, 0.23274595237204007, 0.27752646803855896, 0.14338674449494906, 0.10072951417948518, 0.09534109117729322, 0.261975748198373, 0.15777517456029141, 0.1290278849857194, 0.09763657514538084, 0.21308483023728642, 0.25468138818229946, 8.569062198911395, 80.28788689204625, 51.32976845332554, 49.937856674194336, 72.90502984183175, 68.00342314583915, 27.156268153871807, 31.94419363566807, 50.51498099735805, 62.96590273720877, 37.57555225917271, 16.389695712498256, 49.39191934040615, 68.8328504562378, 58.6378698348999, 58.65795012882778, 56.77402598517281, 54.4119302885873, 52.33535691670009, 55.32089362825666, 52.210237230573384, 53.579515252794536, 53.2696464402335, 46.43560675212315, 48.378885882241384, 47.33094467435564, 46.81748669488089, 44.97545671463013, 47.28661169324602, 46.42745998927525, 44.32446609224592, 46.21886464527675, 43.22903047289167, 40.45830774307251, 40.57553080150059, 43.819168772016255, 50.743031297411235, 49.059687750680105, 48.57991811207363, 53.143689496176584, 56.87200253350394, 53.03823321206229, 52.8705940246582, 54.52858359473092, 52.75381565093994, 54.19362136295864, 54.458094120025635, 55.454351152692524, 56.768085275377544, 55.12004205158779, 53.04831157411848, 45.71326855250767, 47.40172944750105, 44.293942655835835, 41.84307329995291, 43.87953124727522, 51.994228158678325, 53.64249719892229, 52.03228691646031, 38.82143027441842, 28.122752155576432, 20.58888122013637, 27.087230852672032, 29.38201413835798, 27.92447141238621, 34.18967424120222, 32.54286432266235, 36.23370919908796, 35.957229954855784, 39.1959034374782, 34.60405090876988, 36.49210923058646, 20.500180516924175, 28.434583834239415, 45.290164947509766, 39.07634578432356, 30.847712312425884, 37.15823997770037, 41.88310882023403, 41.17397914613996, 36.5973014831543, 41.57312536239624, 39.13107327052525, 36.540909903390066, 41.92631271907261, 35.96590825489589, 37.43456983566284, 34.6178743498666, 35.4867604800633, 32.08783027103969, 30.832787581852504, 35.50468683242798, 37.628431524549214, 41.31318630490984, 48.664818150656565, 50.84640659604754, 50.5690484046936, 46.32648181915283, 40.92733199255807, 47.75805044174194, 47.97834655216762, 44.60535396848406, 48.35413292476109, 52.11523103713989, 51.48467854091099, 53.16663939612252, 51.30266005652291, 55.81830126898629, 50.472662993839805, 47.27421610695975, 49.992994104112896, 48.7914525440761, 50.372883387974326, 48.425886971609934, 51.17767933436802, 53.77584702627999, 52.946812289101736, 55.55572189603533, 50.25832496370588, 51.37274653570992, 44.82199880055019, 44.68784645625523, 46.60977724620274, 46.531352928706575, 48.14825780051095, 51.32911532265799, 48.084577560424805, 48.20880092893328, 51.24876635415213, 51.87961762292044, 52.73067467553275, 57.31745501926967, 59.15918622698103, 64.84397302355084, 63.0309865134103, 66.78957285199846, 60.94614478519985, 58.95638220650809, 59.582720620291575, 65.10488482883999, 63.391500745500835, 61.338085719517295, 15.519498109817505, 26.343702384403773, 61.681000164576936, 40.32608699798584, 36.03608158656529, 19.447207076208933, 42.58967113494873, 61.171488761901855, 98.81529317583356, 64.42480904715401, 63.519729750497, 2.2593164231095995, 0.31839715636202265, 0.21872351052505629, 0.14283935672470502, 0.14024605016623223, 0.24168662833315985, 0.3273695334792137, 0.26518312894872254, 0.14338588954082557, 0.1109426197196756, 0.3028842716344765], [0.377521386636155, 0.10381226161760942, 0.21984370398734296, 0.5079036003776959, 0.25224732022200314, 0.23003479785152844, 0.4901999160647392, 0.20795651684914315, 0.0442056370499943, 0.0714614489781005, 0.17317498821233, 0.20645859651267529, 0.8169335265244756, 35.754505838666645, 49.952020577022004, 35.896422794886995, 15.292545625141688, 37.71176127025059, 27.24959809439523, 14.484272105353218, 33.836288860866, 40.663387298583984, 32.764765466962544, 10.792477931295123, 40.85450792312622, 57.60812248502459, 54.29504769189017, 51.149983814784456, 48.34954016549246, 46.85238749640328, 44.72201074872698, 40.944507939474924, 40.07262366158621, 42.5836991582598, 45.89907727922712, 39.55726187569754, 39.45591197695051, 39.848401818956646, 37.70778342655727, 37.698191438402446, 42.77291945048741, 39.35300915581839, 40.87147889818464, 36.728671073913574, 37.022354057856965, 33.05213253838675, 36.669434206826345, 36.88936901092529, 34.447862352643696, 34.84131452015468, 38.69553239004952, 45.4547712462289, 47.415757860456196, 46.80389254433768, 48.86780629839216, 48.21025310243879, 51.06222806658064, 49.5193875176566, 49.963419096810476, 55.873212882450645, 55.710809162684846, 51.872957774571006, 52.77699484143938, 43.173535210745676, 41.29147318431309, 39.730348450796946, 39.35634429114205, 37.50194304330008, 43.005374908447266, 47.78916447503226, 46.99399525778634, 36.8696882384164, 24.16575653212411, 15.6532370362963, 21.09498974255153, 26.62147399357387, 21.48960747037615, 23.748861142567225, 28.76499499593462, 29.523309230804443, 29.99883004597255, 33.34840372630528, 29.862624508993967, 25.576032400131226, 20.019368648529053, 62.757811137608115, 71.82323006221226, 44.889167036329, 26.501285791397095, 38.880410058157786, 43.27275201252529, 42.23166520254952, 39.184563977377756, 33.00962345940726, 30.765126023973735, 32.231835160936626, 37.24895913260323, 37.97068589074271, 35.174623080662315, 32.46462413242885, 19.122074808393204, 23.93932168824332, 25.188944782529557, 39.54088149751936, 32.19863319396973, 35.089747360774446, 44.770790576934814, 43.55630799702236, 43.81926257269723, 39.63485240936279, 37.422514711107524, 41.385958262852256, 39.97243063790457, 39.19561161313738, 41.3189046723502, 44.43763835089547, 47.45637355531965, 47.22483178547451, 47.726151262010845, 48.80014821461269, 44.35950238364083, 45.46958480562483, 44.36391796384539, 42.94420991625105, 45.90453856331961, 45.246457304273335, 42.38349028996059, 47.39074087142944, 50.002916131700786, 48.00405141285488, 44.94465882437569, 38.795635087149485, 37.909020628247944, 39.84571634020124, 39.06092078345162, 42.80913693564278, 42.62721572603498, 47.179484367370605, 42.131486075265066, 41.96135943276541, 43.88265446254185, 43.35197537285941, 39.37397187096732, 42.515575545174734, 45.65237801415579, 50.1093555859157, 48.31460114887783, 47.77581351143973, 44.077461106436594, 51.77225405829293, 54.246931416647776, 56.34802498136248, 53.56802640642439, 46.519520146506174, 5.666295903069632, 33.19446638652256, 45.19728142874581, 34.09699222019741, 22.9385552746909, 17.896985803331646, 24.211340188980103, 49.600087370191304, 73.01278250558036, 40.104703494480674, 60.87217426300049, 2.2106694791998183, 0.09095644538423844, 0.14341738713639124, 0.08001365685569388, 0.298327311873436, 0.16214253806642123, 0.3313296538378511, 0.11422306512083326, 0.08156338334083557, 0.07638869886951787, 0.21441219401146683, 0.31051021814346313, 0.11140588271830763, 0.2909622485084193, 0.3807816659765584, 0.12844441272318363, 0.26234622831855503, 0.35630199526037487, 0.47931306596313206, 0.03144421521574259, 0.07951245696416923, 0.10365577787160873, 0.21653257523264202, 0.8657481500080654, 41.94952665056501, 54.84808955873762, 39.52062749862671, 29.39338833945138, 44.883605003356934, 34.085618019104004, 20.523927722658428, 38.17964254106794, 43.324095726013184, 37.51932743617466, 14.462084770202637, 41.962057726723806, 64.32294845581055, 58.28942462376186, 53.51726286751883, 52.43870789664132, 49.834182603018625, 47.6543242590768, 46.51121704918997, 44.301564829690115, 46.28360448564802, 50.32614633015224, 44.150076729910715, 43.57161487851824, 43.47298867361886, 39.61352143968855, 40.99780757086617, 46.96045977728707, 42.31445298876081, 42.1239264351981, 40.02645288194929, 40.920852797372, 37.32391282490322, 40.67266314370291, 40.128191879817415, 35.96583182471139, 36.98829746246338, 40.62808697564261, 47.15230648858206, 47.561103752681184, 48.22972542898995, 48.45961700166975, 49.52044711794172, 50.58917038781302, 50.78465795516968, 53.27566705431257, 59.10585185459682, 57.79432725906372, 56.159152099064414, 57.72936160223824, 46.33171728679112, 43.42995153154646, 42.507480893816265, 41.21812799998692, 40.042312145233154, 44.21717200960432, 50.489936215536936, 48.713945388793945, 42.206029823848176, 30.76942695890154, 21.385184730802262, 23.0284423828125, 30.60969134739467, 25.95775600842067, 25.22940240587507, 28.94701521737235, 31.845807143620082, 34.148078850337434, 35.580693176814485, 33.91688101632254, 27.835807187216624, 25.668780429022654, 84.26923247746059, 83.71394634246826, 48.37714883259365, 29.890778609684535, 43.682685307094026, 45.153278487069265, 41.616037436894004, 35.33985471725464, 30.03206675393241, 28.57549330166408, 32.302123137882774, 35.61427729470389, 38.06217976978847, 35.144217763628276, 31.860815252576554, 19.96631220408848, 28.081408636910574, 35.50161920275007, 46.60431943620954, 34.260056018829346, 39.91817215510777, 48.41235882895333, 47.16070338657924, 48.01351833343506, 44.18361568450928, 40.30542652947562, 45.11734240395682, 44.43505709511893, 43.818199498312815, 43.49076563971383, 46.87042154584612, 49.211443356105256, 49.13350541251046, 54.24230739048549, 52.361374446323936, 49.14229140962873, 50.4449987411499, 44.21623747689383, 45.01397057941982, 48.08178438459124, 46.234317438943044, 44.445541926792686, 50.37760121481759, 53.04520920344761, 50.88231141226632, 44.71788004466465, 40.37608276094709, 40.52480895178658, 43.04395130702427, 41.77131577900478, 45.429622241428916, 46.847746099744526, 47.96597875867571, 46.34884112221854, 44.83254964011056, 47.0710368837629, 45.16368341445923, 42.441118649074006, 43.517425877707346, 49.25116968154907, 52.66603210994175, 51.768033027648926, 48.66705199650356, 48.35127374104091, 55.474365438733784, 57.465660095214844, 58.54933588845389, 57.686067376817974, 44.150660378592356, 6.301611389432635, 37.370799268995015, 51.792282240731375, 37.79456295285906, 27.492957012993948, 17.81330864770072, 31.3664231300354, 54.210838999067036, 78.95530578068325, 40.32335288184029, 66.77086135319301, 4.081984162330627, 0.05877779743501118, 0.08272733552647488, 0.08116571432245628, 0.24634401127696037, 0.36505376707230297, 0.49633376406771795, 0.09462092124990054, 0.10172854842884199, 0.04956408916041255, 0.2456201229776655, 0.5209992176720074, 0.22740451113453933, 0.5314109846949577, 0.5946508826954024, 0.29860442557505196, 0.35162987453596933, 0.5572460698229926, 0.8626766119684491, 0.16009100100823812, 0.10444924315171582, 0.3331359683402947, 0.2987836945269789, 1.7443777173757553, 63.083848408290315, 64.46674837384904, 50.08241047177996, 24.579172611236572, 48.606533186776296, 38.653568744659424, 17.35854731287275, 42.98169892174857, 50.19255331584385, 41.349813733782085, 15.449347359793526, 46.46582794189453, 66.57585321153913, 62.797839709690635, 54.736762046813965, 52.2492687361581, 49.157170976911274, 50.005778789520264, 48.1947968346732, 46.28182922090803, 47.394659655434744, 52.810544218335835, 47.411449977329795, 45.282070296151296, 45.10401923315865, 41.25631182534354, 42.04183346884591, 49.949157919202534, 43.13532011849539, 45.33750302450997, 40.96436589104788, 44.70629392351423, 38.04557010105678, 41.95087112699236, 40.07701144899641, 36.30751296452114, 36.61615889413016, 39.0500225339617, 49.40934542247227, 50.65658181054251, 50.522401673453196, 49.20268515178135, 49.609168665749685, 52.01949528285435, 52.08259882245745, 55.06175708770752, 61.85885320390974, 61.266963958740234, 58.48045144762312, 61.39415768214634, 49.88663455418178, 46.34629808153425, 47.16462564468384, 42.71841083254133, 41.91774211611067, 47.79665463311331, 56.25895254952567, 53.213637011391775, 44.023480551583425, 33.81885930470058, 27.39948116030012, 28.547651869910105, 32.04435191835676, 25.934630666460308, 25.88055804797581, 27.94850696836199, 30.39639207295009, 33.86494670595442, 39.0902213369097, 34.97660984311785, 30.57287631716047, 22.39665310723441, 83.91750076838902, 81.49129404340471, 53.74907214300973, 30.839780943734304, 44.41854122706822, 47.570956298283164, 44.72981704984392, 34.78853947775704, 30.632776737213135, 30.185972826821462, 34.13835137231009, 39.283280508858816, 39.98030642100743, 37.10243899481637, 36.321909632001606, 28.33603058542524, 34.892081533159526, 42.03288071496146, 48.349310874938965, 39.19798789705549, 41.221880027226035, 50.114486830575125, 47.51270954949515, 50.7068589755467, 50.30600350243704, 44.73996836798531, 49.22941834586007, 48.29859944752285, 46.266595295497346, 46.513183389391216, 50.65072100503104, 53.33145414079939, 53.51118319375174, 56.26286785943167, 57.21769625799996, 52.41122082301548, 51.14759363446917, 46.65634407315935, 44.3518454687936, 49.92693758010864, 45.999006271362305, 43.90727193014962, 51.02730642046247, 55.659708636147634, 53.58979511260986, 46.86988653455462, 41.940660749162944, 44.2975800377982, 44.76328999655587, 43.61401973451887, 48.61740016937256, 48.63408279418945, 54.06006308964321, 49.166088989802766, 45.724625383104595, 49.98383985246931, 49.2638258252825, 45.705632482256206, 46.30784327643258, 51.258743967328755, 56.814759799412315, 57.96907445362636, 57.92722545351301, 51.454505988529746, 56.472807679857524, 57.845274925231934, 61.69514669690813, 60.94544996534075, 53.75664220537458, 7.863047054835728, 37.89519371305193, 61.04746341705322, 45.73624971934727, 29.173908642360143, 26.89904931613377, 45.27541044780186, 61.04659489222935, 85.59330204554966, 47.84017814908709, 76.21363694327218, 4.616654992103577, 0.20002133479075773, 0.21251220096434864, 0.24870371179921286, 0.35575786445822033, 0.5490700485450881, 0.63516658863851, 0.2225210131811244, 0.22387365917009966, 0.12143530882894993, 0.48447660888944355], [0.26091940488134113, 0.06599580869078636, 0.8051329340253557, 0.41984438417213304, 0.08474763283239943, 0.15922547530915054, 0.23936058314783232, 0.14114381984940597, 0.12622485682368279, 0.1766289078763553, 0.025515535846352577, 0.3233375698328018, 0.23380604120237486, 21.112857035228185, 52.67962278638567, 35.25844962256295, 18.396307672773087, 33.40276295798165, 33.78048092978341, 14.979095016207014, 35.50069161823818, 42.87900802067348, 41.686363628932405, 15.512424843651907, 35.7111872945513, 57.324298994881765, 49.69028888429914, 56.21763856070382, 53.522633825029644, 50.73945297513689, 48.65905809402466, 46.92672279902867, 43.66294894899641, 46.36676747458321, 47.464291027614046, 42.18715851647513, 43.50397069113595, 46.19254834311349, 42.485270977020264, 44.93836028235299, 42.781861782073975, 39.35627828325544, 38.44921180180141, 39.14386143003191, 36.24984291621617, 35.173302922930034, 39.406402587890625, 35.497412068503245, 35.26789569854736, 35.66934871673584, 43.188807351248606, 46.81950167247227, 46.19879477364676, 47.64650753566197, 46.85465955734253, 47.12655299050467, 47.908624853406636, 49.02701384680611, 52.7717558997018, 56.79169178009033, 55.06104489735195, 54.85106338773455, 50.205692359379356, 41.1787108693804, 41.05647815976824, 41.13878304617745, 37.8882281439645, 40.77980089187622, 40.42660658700125, 42.75826917375837, 41.789916106632774, 41.73392057418823, 28.16776258604867, 19.932863576071604, 15.45291178567069, 16.143088511058263, 20.525421585355485, 25.908477646963938, 27.561056307383947, 28.074698414121354, 29.50047745023455, 31.535260881696427, 26.972894770758494, 26.087751592908585, 24.094893591744558, 60.133691923958914, 65.41555268423897, 31.04642036982945, 31.47439466203962, 36.74603462219238, 37.20079769407, 43.99904373713902, 38.07867479324341, 35.565035411289756, 30.763913563319615, 32.978947162628174, 31.040580408913748, 36.63302564620972, 29.001767022269114, 17.074748141424998, 16.578900371279033, 33.090100969587056, 44.58159112930298, 34.87566988808768, 29.04862741061619, 45.5878917830331, 48.59231717245919, 48.777135780879426, 41.33399615968977, 35.94723497118269, 37.140091282980784, 40.176798003060476, 39.55213063103812, 39.441987786974224, 43.3326142174857, 44.84808928625924, 46.24283593041556, 42.893939699445454, 47.30282531465803, 47.37365525109427, 48.72671965190342, 44.244137968335835, 45.494195325034006, 42.72190577643258, 47.533811228615896, 46.297594683510916, 47.14745317186628, 49.34261839730399, 49.23190927505493, 43.14037145887102, 39.043418271201, 38.40861347743443, 37.6093031338283, 40.9648175239563, 40.4283366884504, 39.93670647484915, 42.695853505815776, 41.301638398851665, 42.54627268654959, 44.28470502580915, 43.84866040093558, 41.669899872371126, 42.30327681132725, 41.800234181540354, 44.79898984091622, 45.33818742207119, 46.92757395335606, 47.03917244502476, 52.433149337768555, 55.385713372911724, 60.228903089250835, 57.63074581963675, 62.81515462057931, 31.413650035858154, 5.415766443525042, 41.46711322239467, 41.92357512882778, 34.601080553872244, 18.39168017251151, 24.496921573366436, 29.514130660465785, 47.91376652036394, 26.43744053159441, 37.732550280434744, 53.67539691925049, 4.181344270706177, 0.20764397004885332, 0.06908944661595992, 0.22828727162310056, 0.33542732681546894, 0.036768570941473754, 0.6467096635273525, 0.1162641527397292, 0.10976309515535831, 0.03474999372182148, 0.053645009108419926, 0.2236737763243062, 0.11166046227195434, 0.2936103535549981, 0.19221660787505762, 0.14251878964049475, 0.21065289287694863, 0.1589568161538669, 0.16352932793753489, 0.12698689236172608, 0.17985474477921212, 0.043089080535407574, 0.2040620922510113, 0.13771686516702175, 30.647503444126674, 61.77185480935233, 31.206475598471506, 25.17543227331979, 42.459006786346436, 36.342743805476594, 18.4586694921766, 43.988586698259624, 47.250460215977256, 47.49859080995832, 19.904619148799352, 37.626545088631765, 63.801729338509695, 56.18734788894653, 58.50839015415737, 57.09656483786446, 52.571071079799104, 54.17301300593785, 51.46280561174665, 48.04864147731236, 49.938308307102744, 52.147491523197715, 48.38468415396554, 48.25709090914045, 51.280814920152935, 46.68206630434309, 49.38363013948713, 46.74552420207432, 42.44321353094918, 40.71031543186733, 44.34741251809256, 40.130731446402415, 37.44318560191563, 41.83345351900373, 38.96813801356724, 36.597923346928184, 34.9948662349156, 42.09480653490339, 46.348590987069265, 47.100823811122346, 49.244037355695454, 47.55446474892752, 49.985163484300884, 47.979343618665425, 51.65513522284371, 55.005688599177766, 57.8727376801627, 57.83831977844238, 56.74461078643799, 53.19394581658499, 46.00395686285836, 45.42731891359602, 44.9997615133013, 40.53876788275582, 42.21068164280483, 41.59861830302647, 45.598321029118125, 43.71057537623814, 45.06045055389404, 31.322503566741943, 28.43876838684082, 25.387496505464824, 19.032575062343053, 20.085268838065012, 27.816850764410837, 30.823133059910365, 29.456669058118546, 30.438894203730992, 33.32349443435669, 29.453205381120952, 29.694488525390625, 28.167752163750784, 58.278571537562776, 61.51504244123186, 33.84526245934622, 34.046489238739014, 38.798987592969624, 36.5918401990618, 40.26946265356881, 34.64367995943342, 34.424690110342844, 32.803748335157124, 32.79802649361746, 34.12440633773804, 35.68848752975464, 29.52354199545724, 21.640770741871425, 26.19844855581011, 45.12226520265852, 51.84763853890555, 33.07118449892317, 33.25743791035244, 49.52264969689505, 51.76332562310355, 49.43423386982509, 46.39756536483765, 40.88663291931152, 44.091103894369944, 44.35910981042044, 43.383204051426475, 43.64307015282767, 48.827478953770225, 47.15987655094692, 48.63915497916085, 46.51947150911604, 49.24789708001273, 49.31341859272548, 51.15496914727347, 46.85417665754046, 45.48571157455444, 45.52439219611031, 48.11930465698242, 48.34798724310738, 50.051185267312185, 52.27969142368862, 50.68894304547991, 42.71521118709019, 39.32128368105207, 40.111370291028706, 37.97455951145717, 41.19039079121181, 43.703172070639475, 44.45277847562517, 43.831001554216655, 43.77474546432495, 47.65184375217983, 45.93693801334926, 46.69100168773106, 44.566847051892964, 46.54195587975638, 43.05574934823172, 47.55688272203718, 47.527234758649556, 49.29308121544974, 51.89296511241368, 57.04561717169625, 58.026692390441895, 63.35144438062395, 58.77081666673933, 64.41151714324951, 27.346365656171525, 6.614812297480447, 47.620590754917686, 43.99669872011457, 40.3922894341605, 26.893343108040945, 22.394061429159983, 37.008377756391255, 55.8874636377607, 41.2434298651559, 45.615618569510325, 62.854703766959055, 6.7304277164595465, 0.26280106391225544, 0.051201234704681804, 0.3331034258008003, 0.30138023091214045, 0.11103812352355037, 0.450164151511022, 0.04632402677088976, 0.25307722283261164, 0.03965769162667649, 0.030145234561392238, 0.31273746863007545, 0.24165207733001026, 0.7755696518080575, 0.441376905888319, 0.3371953990842615, 0.3643360941537789, 0.5382804732237543, 0.42118134243147715, 0.2859167435339519, 0.1715534795075655, 0.15987680107355118, 0.5758081280759403, 0.4714250149471419, 39.704202379499165, 69.79224382128034, 44.80742842810494, 27.01461696624756, 41.16776050840105, 47.361217975616455, 17.573180641446793, 46.77254922049386, 53.103435107639854, 50.07339865820748, 19.656028236661637, 40.84815379551479, 67.15363761356899, 58.150766372680664, 58.09881121771676, 56.79160840170724, 53.638203212193076, 54.3324533190046, 51.13727903366089, 48.9501632962908, 49.88859394618443, 54.32928841454642, 49.05667918069022, 48.24414641516549, 50.97624063491821, 45.40982334954398, 47.9058837890625, 46.70523507254464, 44.28017132622855, 42.36690146582467, 47.31034326553345, 42.91758789334978, 38.36053889138358, 43.54778255735125, 40.30147647857666, 38.485898290361675, 36.78723396573748, 43.21457127162388, 49.70677695955549, 49.357348578316824, 50.607266971043174, 49.50234011241368, 52.462338720049175, 51.02479812077114, 53.547091484069824, 56.33098799841744, 62.75032097952706, 61.294068881443565, 60.966669763837544, 58.55873680114746, 49.62118904931204, 48.31211369378226, 47.40632220676967, 42.79286772864205, 44.63035358701433, 45.417813777923584, 48.083524908338276, 45.88074098314558, 48.100134577069966, 36.44506992612566, 31.907270908355713, 31.995120457240514, 22.940340961728776, 24.634297881807598, 28.079173054013932, 30.676022325243267, 33.05260501589094, 35.619290419987266, 36.491251128060476, 34.131392751421245, 33.00993960244315, 32.72572006498064, 49.44743892124721, 59.539141518729075, 39.517511231558665, 38.06018911089216, 44.33704580579485, 42.46766076769148, 40.8851911681039, 34.82921075820923, 34.512807164873394, 36.09460278919765, 34.792333194187705, 35.88666752406529, 39.69890437807356, 34.031408173697336, 29.385540349142893, 30.606460435049875, 51.037110328674316, 55.49736050197056, 42.0068736076355, 38.38478115626744, 51.03485563823155, 55.49306304114205, 52.56744064603533, 49.27808700289045, 43.70206730706351, 47.4189818246024, 47.72515419551304, 49.15004212515694, 46.63807031086513, 52.01642417907715, 51.71403510229928, 54.23934050968715, 51.021622794015066, 55.3347761290414, 54.41117293494088, 53.792856216430664, 46.7899683543614, 44.612493242536274, 45.25048725945609, 46.961887632097515, 46.98353474480765, 49.69933543886457, 52.92641585213797, 53.33615459714617, 46.827172483716694, 41.717724323272705, 40.7887328011649, 41.041723660060335, 43.54501717431204, 46.25374460220337, 46.95978927612305, 46.333259786878315, 48.82985871178763, 51.79521785463606, 48.10542910439627, 50.81295796803066, 48.14513805934361, 47.44759103230068, 44.717470100947786, 49.96420771735055, 51.22363124574934, 54.48281928471157, 53.44286503110613, 59.40121977669852, 61.82516138894217, 65.45194734845842, 59.930151394435335, 67.38242094857353, 36.57311827795846, 8.862118107931954, 46.805640016283306, 56.1524019241333, 43.42294774736677, 26.50474599429539, 39.18718344824654, 48.83850227083479, 58.921599524361746, 38.18355437687465, 50.54197127478463, 75.70754405430385, 8.909526535442897, 0.6028808067951883, 0.3056244131709848, 0.4478084407746792, 0.44550307733672007, 0.32937085894601686, 0.6117972997682435, 0.24538041012627737, 0.37415672146848267, 0.1274105560566698, 0.16231180541217327], [0.03804056965080755, 0.07505565575723137, 0.06975390203297138, 0.08431753662547894, 0.05845498439988919, 0.09700783781175103, 0.04318153771704861, 0.10004977136850357, 0.25392085899199757, 0.18496134504675865, 0.13732978808028357, 0.2756108822567122, 0.13970105083925383, 24.552116325923375, 52.92201764242989, 41.98097767148699, 46.099626609257285, 30.08182975224086, 38.04058129446847, 24.65883023398263, 31.542160442897252, 39.35939802442278, 49.65670824050903, 20.84841901915414, 30.46901117052351, 55.11581059864589, 56.22541012082781, 56.80782897131783, 53.691214493342805, 50.48091050556728, 52.847519057137625, 53.95389461517334, 51.843862192971365, 51.61738565989903, 49.37880114146641, 51.64302798679897, 49.78084475653512, 49.89506619317191, 53.202294077192036, 52.81656830651419, 49.515037945338655, 44.81580100740705, 43.405233315059114, 35.659346784864155, 36.771631785801475, 36.053101199013845, 36.992348262241904, 34.25422648021153, 35.04205839974539, 34.58933809825352, 37.820566586085725, 40.12183427810669, 41.343167781829834, 43.519902910505024, 42.541044167109895, 43.124863079616, 48.95830658503941, 52.539060728890554, 53.60862820489066, 52.72226735523769, 51.279845646449495, 51.51562581743513, 47.449731077466694, 42.67022507531302, 39.318737166268484, 41.75786059243338, 43.27623306001936, 39.38960531779698, 37.77866547448294, 42.3778691973005, 43.61219583238874, 40.333215849740164, 29.057363033294678, 31.958409649985178, 30.39072581699916, 11.294579080172948, 11.23856704575675, 19.579747438430786, 23.88970286505563, 17.56096397127424, 16.679637091500418, 24.66197255679539, 22.42177258219038, 24.638690880366735, 17.769439458847046, 26.32037033353533, 26.01135614940098, 18.93042438370841, 29.205481256757462, 34.452020849500386, 31.767052786690847, 30.196231842041016, 30.55810444695609, 31.19809259687151, 27.65207076072693, 27.07261184283665, 29.01907672200884, 29.96746587753296, 28.328663757869176, 35.51081166948591, 45.49807936804635, 40.959971155439106, 40.1103697504316, 22.843366691044398, 33.77940395900181, 45.948822907039094, 45.55540548052107, 43.755804674965994, 40.04314245496477, 36.93766941343035, 40.08952515465872, 39.56059353692191, 38.24674824305943, 41.01621682303292, 45.53641605377197, 43.89738116945539, 44.36615180969238, 41.47061858858381, 42.872261319841655, 45.09918328693935, 44.372120312282014, 46.35091863359724, 47.5321922983442, 46.76070254189627, 47.76477977207729, 46.66481045314244, 48.951323645455496, 48.22283281598772, 44.02750355856759, 37.46333537782942, 37.810800892966135, 39.1666966847011, 39.836774008614675, 39.49966130937849, 41.33009474618094, 40.25341926302229, 43.362359455653596, 41.65501683098929, 45.198848247528076, 42.02103403636387, 46.543359415871755, 46.44957957948957, 50.520480496542795, 47.06055205208914, 45.4679137638637, 43.51727649143764, 51.19593572616577, 54.67366198131016, 60.003392355782644, 55.01554461887905, 64.61617633274624, 59.75361851283482, 60.07495185307094, 13.747695309775215, 8.721685460635594, 48.53469923564366, 44.391373770577566, 33.43040289197649, 13.59103340762002, 25.312369108200073, 23.3017532484872, 53.97617401395525, 25.41082681928362, 37.16595247813633, 55.47126306806292, 4.758646641458784, 0.1448623003172023, 0.05830330468182053, 0.11701271257230214, 0.04007760302296706, 0.14567510384534085, 0.04660315911418625, 0.04071771599618452, 0.33572976344398087, 0.12288484961858817, 0.10817002385322537, 0.08802847856921808, 0.0753386387867587, 0.06051016519112246, 0.20725744936083043, 0.04540488323462861, 0.14975586773029395, 0.08202204587204115, 0.06018083143447127, 0.23196471429296903, 0.12691350201410906, 0.15136399572449072, 0.22985305903213366, 0.06360370133604322, 30.812523160661968, 59.01850605010986, 42.076876708439414, 43.93301848002842, 34.188239438193186, 39.6545991897583, 24.69521795000349, 41.16632570539202, 42.888287339891704, 54.88839953286307, 26.913954939161027, 31.112337929861887, 57.53522893360683, 59.5766270501273, 61.2054237638201, 56.79873725346157, 53.02550758634295, 56.369870117732454, 56.76105717250279, 57.718369552067344, 53.46983446393694, 52.164205414908274, 54.48795052937099, 51.59839970724923, 52.55481229509626, 57.36026634488787, 55.65691198621477, 53.27338457107544, 50.176718371255056, 47.49945586068289, 38.22162355695452, 40.54286731992449, 39.6097902570452, 39.08814035143171, 36.19894388743809, 36.750530106680735, 35.46339021410261, 39.021455015454976, 39.559676374707905, 42.80856370925903, 41.90016317367554, 41.81889009475708, 42.882405689784456, 50.254475661686485, 53.40955884116036, 54.40502725328718, 54.093727111816406, 54.213760716574534, 54.13816779000418, 52.14980527332851, 46.71358333315168, 42.84111254555838, 42.79932607923235, 44.47417892728533, 40.79387446812221, 39.019096102033345, 46.55838142122541, 46.76685169764927, 44.89097704206194, 34.261546407427105, 32.976265157972065, 40.874904360089985, 25.89184192248753, 21.02400173459734, 24.78345833505903, 25.9637679372515, 22.991571766989573, 22.317209141595022, 28.944298471723283, 27.1073545728411, 29.06064084597996, 24.303961413247244, 26.738710948399135, 26.908455439976283, 25.694276843752178, 32.86975622177124, 38.73043319157192, 32.6842497416905, 27.632337876728602, 26.868996620178223, 29.54049907411848, 31.88516868863787, 31.39494548525129, 34.131253787449424, 33.039566721235005, 32.619930267333984, 40.733320917402, 49.26443379265921, 42.390987396240234, 42.462470463344026, 25.11299054963248, 38.712197644369944, 50.396465573992046, 49.01362466812134, 46.75009959084647, 42.65989657810756, 42.23240171160017, 44.70108624867031, 45.18698419843401, 42.565303802490234, 46.392840589795796, 51.942811489105225, 49.70651292800903, 48.91510616030012, 44.163125446864534, 46.74084111622402, 47.5936803817749, 47.22419255120413, 47.583914688655305, 47.35370697293963, 48.08867352349417, 49.42193555831909, 49.75811719894409, 51.127475125449045, 49.79690899167742, 44.830798694065635, 40.46291787283761, 39.4417723928179, 42.20925031389509, 43.021161215645925, 40.76719338553292, 43.61217846189226, 45.26742001942226, 45.93705265862601, 46.10441391808646, 47.34769330705915, 46.25730207988194, 50.92742953981672, 51.941199507032124, 54.218614033290315, 49.53514950616019, 47.32909992762974, 46.74529838562012, 57.09383072171892, 57.41540724890572, 62.65358815874372, 58.579671723502024, 65.43711989266532, 62.16008540562221, 57.872296469552175, 11.182234525680542, 11.213891386985779, 53.07736199242728, 45.817265714917866, 43.94124862125942, 18.98939027105059, 28.1902209009443, 26.076556307928904, 65.18654005868095, 31.16312231336321, 37.23072705950056, 64.5923718043736, 6.2941624862807135, 0.18427687963204725, 0.1447413039526769, 0.13452621709023202, 0.07865293629999671, 0.0979845482589943, 0.07071627503527061, 0.026809822734711424, 0.2921257460755961, 0.10717758496424981, 0.11765357532671519, 0.3575958529753344, 0.1593525649181434, 0.09583742597273417, 0.36177997131432804, 0.12492889565016542, 0.29597493952938486, 0.14029202769909585, 0.2216763999313116, 0.3664470708795956, 0.21851396534059728, 0.2547083395932402, 0.3121866610433374, 0.15816685211445602, 40.36574036734444, 69.17695304325649, 51.70595782143729, 61.86953953334263, 39.269036701747346, 50.10581200463431, 29.506779466356548, 42.64515944889614, 51.48988274165562, 61.93549183436802, 29.865490640912736, 35.50034073420933, 61.62433760506766, 61.616923877171104, 62.22090993608747, 58.30992875780378, 53.15492820739746, 57.52104071208409, 59.11073643820626, 57.83801058360508, 56.6574386869158, 53.97159167698452, 56.82381330217634, 53.37121868133545, 55.00599431991577, 58.598126138959614, 56.13704987934658, 54.75235727855137, 52.42256375721523, 49.95967749186924, 41.21423353467669, 42.76353938238961, 42.268018177577424, 41.2913168498448, 38.03784370422363, 38.09521497998919, 35.7073518889291, 41.860614027295796, 43.068756375994, 44.06128570011684, 45.46336269378662, 42.53572184698922, 44.91006374359131, 49.551210267203196, 56.813912119184224, 56.04538229533604, 57.247663838522776, 56.6172468321664, 58.370704650878906, 57.203862394605366, 50.68798419407436, 46.28571326392037, 47.262963499341694, 46.19524424416678, 43.56334999629429, 38.87265586853027, 47.43625504629952, 48.757899693080354, 45.30700738089425, 38.18191460200718, 35.551701818193706, 41.425121784210205, 29.338855402810232, 21.890645333698817, 30.26832982472011, 29.2322769846235, 27.865312712533132, 25.071726935250418, 33.50260509763445, 31.01467752456665, 35.15768684659685, 31.589832033429825, 39.163010665348594, 37.026908602033345, 31.4163806779044, 43.62984773090908, 45.992857115609304, 38.12558555603027, 32.67709657124111, 27.735280650002615, 32.63363558905465, 37.35184458323887, 37.48290845326015, 38.073508807591026, 36.51026487350464, 38.80994837624686, 42.675582136426655, 53.23843860626221, 46.28333003180367, 45.38148512159075, 29.87133060182844, 39.27751350402832, 51.164064339229036, 51.46027299336025, 49.5622752734593, 46.25039904458182, 45.45942306518555, 48.66504396711077, 48.336234365190776, 44.9377384185791, 51.10339961733137, 55.96650634493147, 54.33641379220145, 52.81375776018415, 49.183925015585764, 50.87462323052542, 52.99957343510219, 51.236419405256, 49.83456127984183, 48.98214932850429, 49.4831839288984, 52.40977559770857, 51.5830511365618, 53.188185759953086, 52.59973587308611, 47.246833256312776, 41.8516126360212, 40.88329083578927, 44.21785988126482, 43.05614539555141, 43.02047681808472, 45.51343141283308, 46.502524852752686, 50.36871794291905, 49.1557674407959, 53.17707559040615, 50.03308868408203, 53.318554810115266, 53.28466844558716, 57.372311047145296, 50.357559135981965, 49.33850506373814, 48.48157330921718, 59.77373354775565, 60.92940657479422, 68.17612757001604, 61.034894125802175, 71.15709931509835, 66.56582001277378, 68.97482994624546, 18.160447597503662, 12.237005812781197, 57.01720598765782, 54.981394222804475, 40.98714208602905, 20.77451797894069, 39.23312841142927, 38.20621592657906, 71.38352721078056, 34.394420283181326, 49.59830515725272, 76.34055273873466, 9.458550606455121, 0.23498593217560224, 0.32350978202053476, 0.3257467491286141, 0.13069130001323565, 0.20697428312684807, 0.13725721197468893, 0.12260184623301029, 0.5141365687761987, 0.2221111644591604, 0.29231109470129013], [0.0668252973950335, 0.1784744281321764, 0.09038576350680419, 0.05691727476992777, 0.09587745275348425, 0.02675549922111843, 0.10692466103604861, 0.08012300277394907, 0.03407181154138275, 0.11743778762008462, 0.07949339013014521, 0.35224370445523945, 0.20562266851110117, 16.130091905593872, 58.64443588256836, 56.83783824103219, 55.61908599308559, 34.74483183452061, 31.87406894138881, 21.12230658531189, 23.094425950731548, 35.24394873210362, 46.83880376815796, 29.920662811824254, 24.234119858060563, 50.356409209115164, 53.47023745945522, 54.82363189969744, 51.543703487941194, 52.15866422653198, 52.65517554964338, 54.69618804114205, 52.65797219957624, 52.769014835357666, 52.90443522589547, 51.9140841620309, 52.15086487361363, 52.8636006627764, 50.187981401171, 48.37053067343575, 50.11221129553658, 47.1671130997794, 47.07731458118984, 42.6524098941258, 39.34846155984061, 38.165315355573384, 35.668091092790874, 36.686842918395996, 37.604550565992085, 37.261636120932444, 38.03922986984253, 38.644206047058105, 37.93724768502371, 40.0319037437439, 41.099727221897666, 44.752044337136404, 51.099390506744385, 50.48010104043143, 50.6890993799482, 51.69989551816668, 50.090081283024375, 46.1699458530971, 47.04962600980486, 43.11672673906599, 43.82886150905064, 43.06352090835571, 41.623086384364534, 39.49567651748657, 40.47003282819475, 42.593377998897004, 43.1174840927124, 42.84469781603132, 33.84284448623657, 26.40975890840803, 37.637384278433665, 28.796274048941477, 28.20102882385254, 19.69084392275129, 20.792062180382864, 21.576077801840647, 21.182484933308192, 18.73634556361607, 15.165011440004621, 12.740931732313973, 12.912380269595555, 11.009034173829214, 10.742146917751857, 13.64489758014679, 10.759849190711975, 6.240404273782458, 6.717829329626901, 8.61262045587812, 22.53441330364772, 31.237144947052002, 29.417290142604283, 33.656344413757324, 35.658162117004395, 42.00914914267403, 49.50244780949184, 45.66214370727539, 40.42728056226458, 44.92543315887451, 36.2794839314052, 23.573988880429948, 41.37014416285923, 45.62830250603812, 43.032094206128804, 39.82225227355957, 36.682031290871755, 34.127414907727925, 38.78388915743147, 36.851775782448904, 40.20435455867222, 41.039580140795024, 40.98221581322806, 43.761311122349326, 42.80016333716256, 43.019222668239046, 46.17626871381487, 44.04198013033186, 45.705931254795615, 43.338315214429585, 45.286854130881174, 46.22006320953369, 46.98295109612601, 45.096442222595215, 48.87093298775809, 43.789420059749055, 38.98282650538853, 39.84474359239851, 41.494110448019846, 39.516507216862266, 40.79993677139282, 37.602379253932405, 40.00809921537127, 41.89867625917707, 43.17523751940046, 42.44667720794678, 45.131506306784495, 46.94858183179583, 53.21314368929182, 51.073577948978965, 52.15029164722988, 47.55645540782383, 47.99021060126168, 45.97215148380825, 57.228181089673726, 56.20492335728237, 62.06169891357422, 56.856737341199604, 66.86876841953823, 58.83826283046177, 42.3712614604405, 4.425746287618365, 18.642127990722656, 46.577728680201936, 47.32908603123256, 20.63023863519941, 21.983403784888132, 22.467366661344254, 32.734110014779226, 34.650277273995535, 37.57207815987723, 41.03846148082188, 47.15336261476789, 5.898906826972961, 0.41114181971975733, 0.07239953721208231, 0.0990159689847912, 0.06261996126600675, 0.16114780572908266, 0.24534993033323968, 0.23482134672147886, 0.09554011906896319, 0.10732153616845608, 0.06475723800914628, 0.07975729275494814, 0.08964165486395359, 0.07173682563006878, 0.15620002336800098, 0.0619267766763057, 0.055999715612935166, 0.023539882751979997, 0.055738184468022416, 0.022781736915931106, 0.17183796209948404, 0.06878089638692991, 0.607438499374049, 0.23553264141082764, 20.789710215159825, 64.2235266821725, 61.76770673479353, 62.085149083818706, 38.54223428453718, 38.80790907996041, 22.406545604978287, 27.40524469103132, 39.23546648025513, 52.84033809389387, 35.037163393838064, 26.56330714906965, 52.82855742318289, 59.01612976619175, 58.88775484902518, 56.6923360143389, 55.46357488632202, 58.114288330078125, 56.60172455651419, 57.86917325428554, 54.88158335004534, 57.389288970402305, 54.499453272138325, 55.97706413269043, 53.58943728038243, 53.82661056518555, 52.16758223942348, 54.94712223325457, 50.75775453022548, 50.916534764426096, 46.19708204269409, 41.83855349676949, 40.75976228713989, 38.87060267584664, 38.92810249328613, 40.34945726394653, 39.68634550912039, 41.96502808162144, 40.57876518794468, 39.92234107426235, 42.2698073387146, 43.91916724613735, 46.09027085985456, 53.29501778738839, 52.956751687186106, 53.88691050665719, 53.404347692217144, 53.59834139687674, 48.88946730749947, 48.998540128980366, 45.572185380118235, 44.377894265311106, 43.98438998631069, 44.96493019376482, 42.379258837018696, 42.074580328805105, 44.802040100097656, 46.23494972501482, 46.12281622205462, 40.5032000541687, 27.797651154654368, 35.408162457602366, 40.552483626774375, 38.39536673682076, 32.70226642063686, 28.849031720842632, 26.788922105516704, 28.225720984595164, 24.301008428846085, 19.65136773245675, 15.281551837921143, 15.372788633619036, 16.04770711490086, 15.919380835124425, 17.158564261027745, 15.253871951784406, 10.806819881711688, 9.730529155050005, 12.683325954845973, 27.691434042794363, 36.04320001602173, 33.95714235305786, 36.949206897190635, 39.58312654495239, 44.50623444148472, 49.172630718776155, 46.63811894825527, 43.906917572021484, 47.22576979228428, 35.859249932425364, 27.049806118011475, 45.995952538081575, 49.156990323747905, 48.92524358204433, 44.37038673673357, 40.147375856127056, 38.47384663990566, 42.896006788526265, 42.88340275628226, 44.57762023380825, 45.4476250239781, 46.439539432525635, 49.01635531016758, 46.33479186466762, 46.454554489680696, 48.258730684007915, 45.678207942417686, 48.258824484688894, 47.27732195172991, 49.659188747406006, 49.21447971888951, 51.46169737407139, 50.190712043217246, 50.98062494822911, 44.742605209350586, 40.70059142793928, 41.80447258268084, 43.100989069257466, 41.878467423575266, 43.48872981752668, 41.098149980817524, 44.41189874921526, 45.49087061200823, 45.643744877406526, 47.019700118473594, 48.874549525124685, 50.352191652570454, 55.557108061654226, 53.70156730924334, 56.0428010395595, 50.57128919873919, 50.950706005096436, 49.43222236633301, 58.7688433783395, 58.768746103559224, 62.59915597098214, 59.950141361781526, 68.50871699196952, 55.54523706436157, 34.90513025011335, 3.6388241478375027, 22.7931763785226, 51.20840426853725, 51.09016677311489, 28.342143263135636, 25.444271973201207, 25.54946596281869, 36.60670586994716, 44.58369990757534, 42.10189717156546, 43.8976799419948, 56.13575056621006, 9.150283353669302, 0.4228805298251765, 0.10330559273383447, 0.06770143538181271, 0.05266204256830471, 0.06656489601092679, 0.17853439705712454, 0.08528631499835423, 0.13948051338749273, 0.05923443793186119, 0.028164960643542663, 0.1841085758060217, 0.4148552790284157, 0.28413279354572296, 0.230226280433791, 0.1403614961143051, 0.13081454911402293, 0.201309506382261, 0.14576632609324797, 0.3200504747884614, 0.16837258876434394, 0.3240586897092206, 0.7307064362934658, 0.34419364641819683, 26.066900048937114, 75.84463201250348, 66.98132228851318, 73.28116362435478, 49.168267250061035, 45.03156689235142, 29.75925268445696, 30.883613654545375, 46.058138915470664, 52.8768960407802, 37.13080154146467, 29.192099026271276, 56.664445945194785, 61.734320640563965, 59.566711970738, 57.71773379189627, 59.151438985552105, 57.55187334333147, 61.7911708014352, 59.571957860674175, 60.352247510637554, 58.64274052211216, 56.44774552753994, 58.62919153485979, 56.4898133959089, 57.66712311335972, 56.29901933670044, 56.773428440093994, 53.5687073298863, 54.39018937519619, 46.05486978803362, 45.59203290939331, 43.939219747270855, 40.70708451952253, 42.04194811412266, 40.92460829871041, 40.89165646689278, 42.224456446511404, 41.455287388392854, 41.00293186732701, 43.92537546157837, 43.442718846457346, 47.406648772103445, 54.34938260487148, 54.14188855034964, 56.21703406742641, 58.275312832423616, 58.83456638881138, 53.85445547103882, 53.76593542098999, 47.36114501953125, 48.22083520889282, 46.79626342228481, 46.11003501074654, 43.834055287497385, 44.11892795562744, 47.17967196873256, 49.73089763096401, 49.132087979997905, 42.94388335091727, 34.81299713679722, 42.3318304334368, 44.94159814289638, 41.07460948399135, 35.18706035614014, 32.49134343011038, 32.03496837615967, 33.683383328574045, 30.936016968318395, 27.02222350665501, 24.96240050452096, 24.66307384627206, 23.36875820159912, 25.001016855239868, 28.026055812835693, 25.957611833299907, 22.784595353262766, 18.890385389328003, 20.105569737298147, 30.88723714011056, 40.3885999407087, 38.15067550114223, 40.16987064906529, 43.29004955291748, 47.698129177093506, 51.15572302682059, 52.49779537745884, 49.63908066068377, 51.555692604609895, 41.515993799482075, 32.2766649382455, 48.88277619225638, 55.08796221869332, 52.15955012185233, 48.234651701790945, 44.30228049414498, 41.4680164882115, 47.37881081444876, 47.128512382507324, 50.13480683735439, 50.531594140189036, 49.41810015269688, 52.20794432503836, 50.227071966443745, 48.92793600899832, 51.71595975330898, 48.734053475516184, 51.416534083230154, 49.14259713036673, 51.45811905179705, 50.85469232286726, 52.59834623336792, 49.32730804170881, 53.51524094172886, 47.37517690658569, 40.986527170453755, 42.79526833125523, 45.4139575277056, 42.39826563426426, 45.46777827399117, 41.83114324297224, 44.30800928388323, 45.6991081237793, 48.44751671382359, 48.43680606569563, 52.046416078295024, 52.45877429417202, 58.735714367457796, 55.43272488457816, 57.71951253073556, 52.61541795730591, 55.60411957332066, 52.46357897349766, 62.29373400551932, 63.18948881966727, 66.59429373059953, 62.31540543692452, 72.28721686771938, 60.66559042249407, 46.72468655450003, 5.716738522052765, 21.93044808932713, 54.30433048520769, 59.46682466779436, 28.09471443721226, 32.24616929462978, 30.867059571402415, 52.06409229551043, 48.06262820107596, 51.65325920922415, 54.37263822555542, 64.83876187460763, 11.622297814914159, 0.5884630775877407, 0.23689144849777222, 0.2812787666916847, 0.1087355963619692, 0.24130629588450703, 0.36073475597160204, 0.23959934605019434, 0.20325610121445997, 0.33548245100038393, 0.15924280509352684], [0.04572029006002205, 0.023065461244966303, 0.05178262386471033, 0.031678146948771815, 0.07318530111972775, 0.08415303938090801, 0.0607856096965926, 0.1233827993273735, 0.036744869713272364, 0.04008358770183154, 0.04293127703879561, 0.17675945801394327, 0.08220594243279525, 14.423405017171588, 65.73635796138218, 33.77989380700247, 34.0803165435791, 39.6330771446228, 25.061090980257305, 19.130089555467876, 18.54906381879534, 30.974096570696148, 56.269517285483225, 42.004539012908936, 21.464057207107544, 41.219361305236816, 51.934828008924214, 50.188842977796284, 54.35323885508946, 48.649973324366975, 54.56401245934622, 52.16021367481777, 53.331256117139546, 51.45968934467861, 52.80104603086199, 51.10765538896833, 51.46347958700997, 50.8358279636928, 49.71955122266497, 51.01018953323364, 51.46872547694615, 49.52443538393293, 49.36379650660923, 51.37949323654175, 43.848643030439106, 39.94199405397688, 40.36783177512032, 38.426970618111746, 38.707191467285156, 40.358017444610596, 39.65179559162685, 40.41455841064453, 40.71154178891863, 41.51681021281651, 43.37858697346279, 47.20952837807791, 48.288375173296245, 49.46883242470877, 49.68542514528547, 50.23422166279384, 49.12397248404366, 48.523780141557964, 44.67408207484654, 43.04024791717529, 42.593687193734304, 43.42247526986258, 46.48069361277989, 41.310615471431184, 40.19714232853481, 41.90021875926426, 45.255948543548584, 41.46523720877511, 39.18988977159773, 20.794245651790074, 27.630838802882604, 32.96592623846871, 29.61180148805891, 33.56110545567104, 29.4776873588562, 18.885624136243546, 16.865847076688492, 13.40723705291748, 8.906762020928518, 10.263604504721505, 9.735286934035164, 9.950199059077672, 8.371086307934352, 5.274558203560965, 2.3800589612552097, 1.3872658227171217, 3.570461473294667, 10.958199415888105, 17.99334168434143, 26.997218676975795, 30.595200879233225, 31.607855660574778, 42.48454489026751, 46.956402029309956, 45.0388069152832, 39.228236879621235, 36.83962338311331, 43.3288482938494, 22.906075920377457, 21.975604431969778, 42.469852924346924, 40.31292710985456, 44.31109428405762, 37.46137251172747, 36.02935920442854, 36.11374855041504, 36.49669851575579, 37.262973649161204, 39.90417848314558, 41.87486130850655, 45.233182770865305, 43.35789523805891, 44.02589157649449, 47.230428559439524, 47.19935621534075, 45.291047368730815, 44.90459898539952, 45.74231549671718, 46.66436576843262, 45.95718853814261, 46.41814940316336, 45.322418485369, 44.40334899084908, 38.18075772694179, 38.200549670628135, 39.91576113019671, 39.19717843191964, 42.24863617760794, 41.766698701041086, 41.5864520072937, 44.60927970068795, 46.00339405877249, 46.511845861162456, 48.18535075868879, 50.21786560331072, 51.680256434849326, 53.01838220868792, 52.58481461661202, 51.44224936621529, 50.5174754006522, 48.480478967939106, 50.072759423937114, 56.93648876462664, 57.52934728349958, 60.431991985866, 63.71882343292236, 60.777664865766255, 42.00507402420044, 16.286688668387278, 1.892071123634066, 29.26256765638079, 51.37578289849417, 35.398761544908794, 11.939496108463832, 25.43207093647548, 19.036379201071604, 33.23967136655535, 27.73404734475272, 37.49287564413888, 50.78103794370379, 54.99458190373012, 8.64638088430677, 0.36816414445638657, 0.023911457009879605, 0.09620651509612799, 0.03145587584003806, 0.09281367036913123, 0.1376044319144317, 0.11445839463600091, 0.05298819399571844, 0.02382933222023504, 0.07805062111999307, 0.032001472277832885, 0.049312142322638204, 0.025615436557148184, 0.05173393219177212, 0.08926397548722369, 0.05331479325624449, 0.05147884034418634, 0.08134630641766957, 0.016871018368484716, 0.0972784918599895, 0.02900663244404963, 0.13433640370411531, 0.04293197253718972, 18.958271026611328, 73.49350752149309, 42.579068183898926, 39.8265323638916, 43.59636436189924, 31.27767378943307, 21.71601278441293, 22.51719045639038, 35.552969864436555, 61.34318569728306, 48.89737435749599, 22.783011163984025, 41.27816390991211, 58.92829063960484, 55.818992614746094, 57.37096309661865, 51.91617556980678, 56.15825578144619, 54.92421402250017, 56.59331028802054, 55.01205662318638, 56.301871572222026, 56.19086020333426, 54.50463662828718, 55.18524742126465, 53.85668931688581, 52.85193463734218, 54.79091630663191, 53.59091029848371, 52.80151156016758, 53.93013177599226, 47.99339287621634, 42.94304609298706, 42.49768393380301, 40.649143491472515, 41.89794669832502, 43.935610158102854, 41.4912234715053, 41.84464706693377, 43.323772634778706, 42.76132985523769, 46.06708819525582, 47.92911161695208, 51.200476373944966, 51.529049737112864, 52.52854463032314, 50.963730403355186, 51.030016217912944, 50.91187947137015, 48.660503319331575, 45.11800595692226, 46.79506833212716, 46.38658373696463, 47.88944782529558, 44.153634207589285, 42.94144800731114, 44.410571643284385, 49.74324457986014, 46.74963058744158, 45.46235867909023, 26.80815645626613, 32.37199074881417, 41.044315338134766, 34.08043466295515, 35.995365142822266, 37.74377509525844, 22.283810888017925, 18.782667466572352, 21.105099371501378, 17.25519633293152, 15.843582936695643, 16.91681558745248, 16.33495954104832, 12.56405144078391, 8.951483232634407, 7.137786703450339, 4.94881362574441, 6.426931704793658, 13.720849207469396, 18.585798944745743, 25.849709783281597, 32.95243631090437, 33.41319567816598, 44.77473020553589, 47.84981530053275, 45.21456159864153, 43.83022335597447, 37.948243209293906, 46.94505909511021, 28.304148776190623, 27.609608582087926, 45.43479864937918, 46.06447567258562, 46.858272620609824, 41.4382677759443, 39.889896460941856, 41.60945054462978, 43.22816889626639, 41.69843264988491, 43.04007421221052, 46.29557623182024, 49.01370457240513, 46.735202653067454, 47.81232629503523, 48.15819372449602, 48.45258889879499, 48.77465179988316, 48.3934006690979, 47.77801261629377, 49.47177151271275, 48.99750484739031, 49.151529039655415, 48.02164077758789, 44.805142470768516, 40.138801779065815, 40.16608040673392, 41.45419652121407, 42.89204284123012, 43.9707749911717, 45.89332069669451, 45.02476460593087, 48.474103995731895, 49.85234866823469, 51.54069839205061, 50.67514739717756, 51.26310396194458, 55.30391917909895, 54.31687198366438, 54.971524306706016, 53.18997492109026, 53.21728828975132, 52.648206506456646, 54.124441623687744, 60.19461372920445, 59.79678072248186, 60.02145072392055, 63.82576315743582, 58.18656349182129, 37.42000641141619, 13.46652168887002, 2.2936587631702423, 36.01660578591483, 55.0520087650844, 42.022194385528564, 15.627905641283308, 26.593187877110072, 23.95503851345607, 37.187436308179585, 37.03306818008423, 39.84993389674595, 54.56191062927246, 63.84663554600307, 11.014949696404592, 0.4375568080161299, 0.07113651212837015, 0.11174171005508729, 0.04316951746919325, 0.06467959324696235, 0.09606450450207506, 0.10493118621941123, 0.03777361701109579, 0.03846816884885941, 0.018593723785930445, 0.1378148320530142, 0.13464850267129286, 0.14008694727505955, 0.26047960562365396, 0.20381777893219674, 0.1578613349369594, 0.14402171756540025, 0.182762063773615, 0.0824064291747553, 0.19062369263597898, 0.20069151025797638, 0.29475330508181025, 0.1547963244042226, 23.702655621937343, 85.33757359640938, 46.96583420889718, 45.9244555745806, 55.380807944706504, 35.160090923309326, 24.86093943459647, 24.761750425611222, 41.173861026763916, 66.19898986816406, 51.11261987686157, 26.064369167600358, 48.02493422372, 62.797798020499094, 60.184038570949006, 61.45983900342669, 54.30548736027309, 60.076237269810264, 59.77647113800049, 58.70694187709263, 57.56513398034232, 59.073174476623535, 56.26956592287336, 57.009854793548584, 57.568809577396934, 56.15510477338518, 56.82848596572876, 56.7099358013698, 55.54765156337193, 54.572145325796946, 56.85364539282662, 49.43712779453823, 45.50005265644619, 45.00036948067801, 42.873077733176096, 44.85598938805716, 47.57602848325457, 44.70280245372227, 46.19712025778634, 45.20414972305298, 46.84930944442749, 47.614021233149934, 53.11506986618042, 53.330491815294536, 53.889318057468955, 54.8797733443124, 52.23138754708426, 50.41143546785627, 55.068277972085134, 49.70341403143746, 47.19069528579712, 48.00605596814837, 47.62095206124442, 49.15256779534476, 45.0222806249346, 44.07014465332031, 48.642847946711946, 49.637604168483186, 50.69170148032052, 47.03324910572597, 35.57610041754586, 37.58567925861904, 45.587936946323936, 40.576819692339214, 42.90617547716413, 40.846569606236045, 31.783693722316197, 26.886523451123917, 27.153388125555857, 24.55995215688433, 24.648468732833862, 24.82392290660313, 25.632590736661637, 21.272113221032278, 17.503398145948136, 15.30207507950919, 9.578562498092651, 11.511646015303475, 19.743877785546438, 23.466451610837662, 30.800304753439768, 35.610414096287315, 35.938949244362966, 45.188186236790244, 49.313102449689595, 50.83334398269653, 48.040407861982075, 43.067655086517334, 53.130672046116416, 31.979820523943218, 32.26586743763515, 51.69375678471157, 51.30670738220215, 50.69510609763009, 44.57287808826992, 42.98819201333182, 43.587772914341514, 46.36190373556954, 45.044459274836946, 47.2405173437936, 48.9689998626709, 52.52412210191999, 49.67324842725481, 50.364205087934224, 52.54793010439192, 52.941760948726106, 52.028062411717, 50.265377385275706, 50.24004772731236, 51.54274811063494, 50.32719898223877, 52.527478081839426, 50.51436955588204, 48.25359943934849, 42.7221976007734, 41.30581079210554, 44.61828456606184, 42.72506373269217, 48.064014366694856, 46.968731607709614, 45.70084864752633, 50.57299845559256, 53.99033791678292, 52.6732234954834, 53.50226518086025, 53.59632989338466, 56.24981566837856, 56.63947411945888, 57.699925558907644, 56.55039473942348, 57.44296727861677, 54.7606395312718, 55.821077074323384, 63.40422984531948, 63.484599658421104, 64.48129790169853, 66.26373318263462, 65.45093985966274, 45.55242470332554, 19.237685884748185, 2.9574390649795532, 34.35701813016619, 60.984436307634624, 48.66633980614798, 15.891436917441231, 34.38881308691842, 28.38616531235831, 50.64152159009661, 42.85976151057652, 50.86537865230015, 63.558570180620464, 73.87738159724644, 15.175161021096365, 0.9041440582701138, 0.19979159640414373, 0.23529588697212084, 0.27366134258253233, 0.18363356058086666, 0.2512702840779509, 0.2940272454704557, 0.2113502233156136, 0.16225494417761052, 0.12038678223533289], [0.06947362635816846, 0.09774958515273673, 0.07431788463145494, 0.05761075791503702, 0.05072441118370209, 0.09644560369529895, 0.0388704519053655, 0.02852004480415157, 0.09077263703303677, 0.07681366535169737, 0.07584268852536168, 0.1344694508505719, 0.20767066361648695, 18.552431958062307, 61.9740960257394, 31.894236087799072, 31.80084535053798, 35.728290285382954, 32.10053505216326, 18.878033229282924, 16.136369603020803, 20.36494251659938, 47.86982611247471, 49.48039770126343, 16.051061357770646, 27.88160102707999, 55.20062378474644, 48.80917045048305, 53.8224972316197, 46.73026248386928, 49.16540111814226, 49.210269110543386, 50.96732609612601, 50.382315567561555, 51.507687500544954, 50.605484758104595, 51.045281410217285, 50.70935337884085, 50.987844126565115, 48.78924649102347, 50.467955589294434, 51.819474015917095, 50.91631589617048, 49.13109786169869, 47.616689341408865, 40.02256536483765, 41.231388636997764, 39.22522483553205, 40.23001078196934, 39.20424822398594, 38.719660009656636, 38.34958158220564, 39.62906108583723, 39.44419731412615, 43.86150414603097, 47.035267557416645, 50.85700607299805, 47.42571462903704, 49.27515486308506, 48.20731748853411, 49.977308545793804, 47.93823112760271, 45.36274582999093, 43.8666284424918, 43.795972211020334, 44.4248571395874, 45.87131922585623, 42.195044721875874, 42.16762365613665, 40.17826407296317, 44.56698254176548, 41.10105432782854, 40.300587109157014, 25.384654692241124, 26.679090193339757, 36.541219098227366, 31.591784477233887, 26.307563066482544, 33.57329607009888, 14.162755506379263, 8.609285320554461, 18.922755309513636, 11.8309383222035, 5.936666812215533, 4.699946088450296, 6.089303970336914, 4.472589305468968, 3.9871898889541626, 1.8214878482478005, 2.045966122831617, 5.364752769470215, 8.076297691890172, 8.227628588676453, 9.749923314367022, 17.4417085647583, 15.363028151648384, 32.10292175837925, 42.5508828163147, 39.82930816922869, 37.661900997161865, 31.88074963433402, 36.44939170564924, 21.102379151753016, 25.96583502633231, 41.05895519256592, 38.81766782488142, 41.54544026511056, 37.78287608282906, 36.50717639923096, 36.71023055485317, 38.961728300367085, 37.16109568732125, 37.50372525623867, 43.67870398930141, 44.59293058940342, 43.131967612675254, 46.213017736162456, 45.97914831978934, 46.09818138395037, 45.22979552405221, 44.65744808741978, 45.944167613983154, 43.985011850084575, 43.07035446166992, 42.08932440621512, 38.465387208121165, 38.43863664354597, 38.97902931485857, 37.15426213400704, 37.40656859534127, 40.88447897774832, 42.90345178331648, 47.31648547308785, 47.662050655909944, 47.14499350956508, 50.37169872011457, 50.45117221559797, 51.3899815423148, 51.235616888318745, 53.86227914265224, 52.40703453336443, 54.92520414079939, 49.63992486681257, 49.78823069163731, 50.18477133342198, 53.05810506003243, 58.01836844852993, 60.15090956006731, 56.476281779153005, 63.85700920649937, 42.75945731571743, 23.362470081874303, 4.994430720806122, 4.353541042123522, 40.4731490952628, 45.98850754329136, 25.55500715119498, 17.347331183297293, 29.07100408417838, 24.351389816829137, 34.29822942188808, 34.06318923405239, 50.703301497868125, 34.0657114301409, 56.76188748223441, 5.28736286503928, 0.3114991422210421, 0.0931828273460269, 0.18074841611087322, 0.07384039275348186, 0.04913578428594129, 0.04420627487291183, 0.019939754058473876, 0.05061840365773865, 0.08025514746883086, 0.02807167056016624, 0.020100500700729232, 0.05575062880026443, 0.11054981579738003, 0.011011784513747054, 0.17891230035041059, 0.19761256261595658, 0.043210287245788744, 0.03162139767248716, 0.0912147161683866, 0.06962831198636975, 0.012389411617602621, 0.10935226255761725, 0.29240475967526436, 25.90546386582511, 69.3544100352696, 37.75048010689871, 32.074719020298545, 36.14022118704659, 36.00343547548567, 20.863117933273315, 19.13756581715175, 25.23069303376334, 50.476616518838064, 55.28602409362793, 18.266233921051025, 26.719935178756714, 59.00199018205915, 55.398442472730366, 59.706322125026155, 51.6363959312439, 51.988832882472444, 51.93320907865252, 51.15922839300973, 51.92540972573416, 52.84181458609444, 53.047373567308696, 54.407844747815815, 52.61379555293492, 51.97408880506243, 50.04734638759068, 54.32471302577427, 54.401077202388215, 52.85903569630214, 52.14991297040667, 52.190341063908164, 42.73454107557024, 41.978316511426655, 40.47593184879848, 42.55485718590872, 40.54575777053833, 40.607631478990825, 39.845153536115376, 43.11995070321219, 42.65842703410557, 45.095104694366455, 50.75026784624372, 52.880422251565115, 50.68560096195766, 50.24396651131766, 50.57837636130196, 52.23766524451119, 50.91473170689174, 48.224910327366416, 46.011387961251394, 47.2095388003758, 47.44223744528634, 49.38485649653843, 44.28733491897583, 46.72359568732125, 42.87764617374965, 48.46209403446743, 46.11691720145089, 45.64040626798357, 30.264803613935197, 29.627250807625906, 42.80074003764561, 39.13442925044468, 34.04947349003383, 37.96135098593575, 22.212670019694738, 11.865400518689837, 23.921614204134258, 17.42505373273577, 14.696391923086983, 15.134547063282557, 14.615235226494924, 11.095883182116918, 9.678912724767413, 8.495543309620448, 13.275883095605032, 16.58784965106419, 13.755536351885114, 12.848957112857274, 13.399941444396973, 19.305540255137853, 16.39850950241089, 34.591940198625835, 40.641451835632324, 41.24870007378714, 38.931576592581614, 33.78530297960554, 40.59972790309361, 23.547660418919154, 33.03710011073521, 45.09767205374581, 44.22574608666556, 45.046644483293804, 41.159641538347515, 41.18519353866577, 41.24061237062727, 43.01461601257324, 39.76413059234619, 43.02948863165719, 46.51074457168579, 48.05827168055943, 46.19175624847412, 49.6148418698992, 50.04070390973772, 50.156068325042725, 49.790165764944895, 46.529355321611675, 48.12768071038382, 46.037544454847065, 44.49340111868722, 43.405816963740754, 40.46939359392439, 40.339795793805806, 41.599507672446116, 39.338751452309744, 40.99262768881661, 45.309414931706016, 46.053681646074565, 48.59213651929583, 50.23953703471592, 49.336656842912944, 53.08338260650635, 53.13336099897112, 55.28782715116228, 53.46544320242745, 54.24124084200178, 55.40650238309588, 56.12982375281197, 52.570334570748464, 51.579121930258616, 50.32137986591884, 54.63122933251517, 58.063076632363455, 61.961227961948936, 60.04438672746931, 64.96335002354213, 42.013498714991975, 21.349696806498937, 4.018514539514269, 5.9884964653423856, 44.9245993750436, 48.28749622617449, 30.053196225847515, 18.963885171072825, 32.111926623753135, 28.008259739194596, 37.837245736803325, 41.55299990517752, 56.05004801068987, 36.974487917763845, 63.80749634334019, 7.3716504744121005, 0.3040681523936135, 0.07349871644484145, 0.1230995109570878, 0.02341428761636572, 0.06079478349004473, 0.130283975441541, 0.09317186900547572, 0.014870551248480166, 0.08840497050966535, 0.05236553294318063, 0.11538497491606645, 0.27345924771257807, 0.29042566301567213, 0.14550636575690337, 0.2131973991968802, 0.2540177809340613, 0.16015973660562718, 0.09294590327356543, 0.28680611295359476, 0.1918497918439763, 0.21517019905149937, 0.2545982269304139, 0.429705370749746, 30.966547352927073, 80.67637457166398, 42.510208061763215, 43.12023557935442, 50.68549673897879, 46.42650808606829, 26.80028067316328, 19.825451374053955, 29.273931435176305, 58.19046490533011, 56.61039243425642, 20.766560554504395, 32.22375093187605, 62.32654339926583, 58.52804660797119, 63.1213686806815, 52.900043964385986, 55.36066511699131, 54.51958220345633, 55.36829423904419, 55.622956139700754, 56.17220081601824, 56.34920270102364, 56.9529698916844, 58.45677893502371, 56.08153029850551, 51.71035255704607, 57.86087710516793, 57.25860725130354, 55.369089807782856, 55.83860043116978, 55.29400757380894, 45.08794804981777, 45.92038740430559, 43.316789695194785, 44.91098090580532, 43.19235093252999, 42.84207139696394, 41.67166471481323, 45.689210414886475, 45.706247397831504, 49.18213932854788, 52.91851922443935, 54.9201979637146, 52.405700479234966, 53.36184903553554, 53.199417522975374, 55.6873277255467, 51.937596866062705, 49.15815762111119, 49.00978231430054, 49.139390536717, 48.13262087958199, 51.30170120511736, 46.36765684400286, 48.24525465284075, 47.05093574523926, 52.06334883826119, 51.36289051600865, 49.89738689150129, 37.53176818575178, 36.956335748944966, 49.608925478799, 44.45616919653756, 41.160464899880544, 46.77225044795445, 27.69165117400033, 21.14535549708775, 32.3715877532959, 23.631313255855016, 20.15063054221017, 20.013617277145386, 19.665828670774186, 19.23659154347011, 21.67743464878627, 17.72800213950021, 20.27129990713937, 21.56456289972578, 18.11424902507237, 15.403195687702723, 17.827915498188563, 23.68198994227818, 20.084895372390747, 38.29997491836548, 45.13300016948155, 44.06251205716814, 44.59776653562273, 38.296181201934814, 46.694718973977224, 29.69469349724906, 38.1944317817688, 49.97894484656197, 50.17905991418021, 49.13005910600935, 45.16756050927298, 45.45459406716483, 44.805608000074116, 45.514268670763286, 44.83827495574951, 45.29993758882795, 50.97143595559256, 50.566800662449424, 49.82769993373326, 51.69573702130999, 53.879927567073274, 54.00852830069405, 53.56149509974888, 50.510482038770405, 52.54992076328823, 51.08355903625488, 50.64857401166643, 45.91203914369856, 43.89033917018345, 43.394689423697336, 45.12570456096104, 40.810581411634175, 41.71261739730835, 46.57256269454956, 45.91480105263846, 51.30325065340315, 51.8855687550136, 49.38923038755144, 54.204464026859824, 55.43650470461164, 57.385672433035715, 56.50412668500628, 57.42583302089146, 59.02681609562465, 60.19163990020752, 55.14546551023211, 54.7131381716047, 55.13026632581438, 59.210908617292134, 62.46072006225586, 64.90788950238908, 62.62511444091797, 67.136413029262, 48.938452107565745, 26.973606961114065, 6.496552220412663, 5.22479737656457, 46.81525979723249, 55.22489731652396, 35.361845765795024, 22.53470512798854, 38.3602158001491, 36.1488994870867, 48.51284715107509, 52.215774944850374, 67.73646640777588, 40.869696685246055, 77.15778596060616, 13.205833094460623, 0.6591577412826675, 0.187232659597482, 0.3496968096920422, 0.1219070263739143, 0.12626959942281246, 0.08948363762881074, 0.211857889645866, 0.13912867940962315, 0.2033649246607508, 0.08113013873142855], [0.05654695749815021, 0.08292223113988127, 0.018575189601896063, 0.1740532432283674, 0.056894214757319005, 0.07999733808849539, 0.05555167554744652, 0.1190744683678661, 0.022548185162512318, 0.0913012158125639, 0.08152506646833249, 0.07051111318703208, 0.07443815496351038, 30.103376116071427, 60.52185303824288, 34.606336866106304, 33.79133749008179, 38.585816860198975, 34.898769174303325, 23.453307356153214, 15.2592568056924, 19.82314804622105, 39.75477136884417, 56.672926221575054, 19.379224164145334, 15.496895619801112, 54.651396478925435, 53.253495352608816, 54.56818832669939, 49.56062160219465, 48.62845127923148, 44.54827799115862, 47.911563941410606, 45.14748368944441, 50.8412892477853, 45.85632153919765, 50.07256834847586, 45.70888423919678, 50.80090284347534, 48.359986782073975, 50.4514536176409, 50.675140448978965, 50.34997170312064, 50.90740483147757, 51.92118869509016, 41.17619562149048, 42.547217641557964, 40.924323422568186, 40.327264717647004, 37.487456049237935, 39.520769936697825, 38.59653793062483, 39.16155849184309, 38.4659743309021, 43.777406624385286, 48.448096888405935, 48.87087392807007, 47.75635160718645, 48.289573737553184, 49.55638667515346, 45.41783809661865, 49.126411301749094, 47.38080494744437, 42.576556410108296, 45.37217453547886, 45.05164371218, 45.38396215438843, 44.006648540496826, 41.43157318660191, 39.99675628117153, 43.527441705976216, 41.08773463112967, 40.66882078988211, 26.68576567513602, 21.869739941188268, 28.59705008779253, 35.74835320881435, 29.5465544291905, 30.187953063419886, 20.598488841738018, 5.259507536888123, 6.625621957438333, 3.9428360632487705, 0.6717923890267099, 0.4488420938806874, 0.7928244173526764, 1.588239644254957, 1.8249074476105827, 1.9521246211869376, 3.092539404119764, 5.417665473052433, 1.6920518108776637, 2.605748610837119, 3.0346956508500234, 2.204531614269529, 6.421161225863865, 23.00323952947344, 34.79550852094378, 31.216053690229142, 28.680541379111155, 28.776219810758317, 18.629563910620554, 16.15145414216178, 30.788124561309814, 39.02154534203665, 38.942707606724326, 39.30934320177351, 36.88477625165667, 35.69352149963379, 37.949031829833984, 40.78600563321795, 39.14159631729126, 37.452579566410606, 43.37330634253365, 45.35787514277867, 44.486300059727256, 46.09398119790213, 46.3225074495588, 44.42742797306606, 41.20639944076538, 40.885872091565815, 41.41229888371059, 38.6695739201137, 41.0751827103751, 37.61840874808175, 37.174231256757466, 38.30009651184082, 38.94302722385952, 39.60965824127197, 38.860472202301025, 42.872570514678955, 43.48405715397426, 42.88043934958321, 49.2958014351981, 49.278927734919954, 49.76116745812552, 51.95995269502912, 51.389085224696565, 51.704019274030415, 49.001513957977295, 49.741542271205354, 48.062478814806255, 50.073857239314485, 48.22076225280762, 48.15376077379499, 51.325001989092144, 53.55350467136928, 60.39486081259591, 59.92986651829311, 60.79388196127755, 28.546899727412633, 11.391844306673322, 1.4029548551355089, 9.939056754112244, 54.69381523132324, 39.86414296286446, 22.33697155543736, 15.69810676574707, 29.021866423743113, 29.551803793225968, 33.932035037449424, 32.72148513793945, 47.40212549482073, 32.346827847617014, 50.994590827396934, 4.078151362282889, 0.3242585318429129, 0.1521864208791937, 0.07000871907387461, 0.10205536482057401, 0.051404496654868126, 0.04755833285993763, 0.00877409306953528, 0.18912600300141744, 0.04362955064113651, 0.057561163790524006, 0.08478737462844167, 0.04296103079936334, 0.09318150420274053, 0.14720909510340008, 0.07332607678004674, 0.17024812740939005, 0.007346615694197161, 0.020581395431820835, 0.030559168064168522, 0.09449269848742656, 0.10093698304678712, 0.013811711770748454, 0.04995311703532934, 36.93139866420201, 66.99830368586949, 37.23817900248936, 33.76000458853585, 39.41406297683716, 37.54861409323556, 26.009018080575125, 20.255963495799474, 25.40357116290501, 44.92245932987758, 60.69888619014195, 25.45944857597351, 15.099206788199288, 55.429285526275635, 58.94769695826939, 60.34573704855782, 55.500570569719585, 52.4390309878758, 47.24903236116682, 51.07726744243077, 48.75526979991368, 53.44861466544015, 49.32038763591221, 50.89007602419172, 48.81967265265328, 50.88982936314174, 49.84017195020403, 52.80316523143223, 53.66249064036778, 54.28762354169573, 55.461803095681326, 56.447606563568115, 44.50646373203823, 45.136109488351, 42.571932383946006, 43.14881352015904, 39.76329680851528, 41.599608421325684, 42.060329573495046, 40.821969509124756, 40.263688700539724, 45.86435713086809, 49.45635346003941, 52.18214913776943, 49.076217515128, 48.626460620335166, 50.33820840290615, 49.42927633013044, 51.45694480623518, 49.1832788331168, 45.07387447357178, 47.79792267935616, 48.398198400224956, 48.36213377543858, 46.77514089856829, 43.56936018807547, 42.749903542654856, 47.71244246619088, 43.55182988303048, 42.759342670440674, 33.25775752748762, 26.10793958391462, 33.17869744982038, 40.00198827471052, 35.23411008289882, 37.244793687547954, 29.98729256221226, 15.252223491668701, 8.66040929726192, 9.16801689352308, 3.30696102976799, 3.2955629442419325, 4.086134842463902, 3.024510894502912, 4.226013805185046, 3.7314935752323697, 13.430527414594378, 11.442933542387825, 3.8006255456379483, 4.579404396670205, 4.510028370789119, 6.8517493435314725, 8.130920955113002, 25.84401399748666, 35.68374538421631, 34.39041812079293, 33.830205712999614, 32.04163517270769, 21.581118719918386, 22.55297715323312, 34.71084124701363, 44.67022582462856, 41.65659754616873, 43.393796580178396, 41.80054337637765, 38.48023203441075, 41.936220850263325, 43.23000322069441, 40.49211767741612, 40.8721216065543, 45.13038764681135, 47.31244509560721, 47.45382356643677, 49.12115846361433, 49.93574789592198, 48.329147202628, 45.1232761655535, 42.129325185503276, 42.102869919368196, 41.016762256622314, 42.158632687159944, 40.5914352280753, 40.66261952263968, 41.73037699290684, 42.37697287968227, 42.46613563810076, 42.2962452343532, 47.06633990151541, 45.92808253424508, 47.05819661276681, 50.24796519960676, 52.24772276197161, 50.782708985464915, 53.53771489007132, 52.704271520887104, 55.645791394369944, 51.85622303826468, 50.54886736188616, 50.65657138824463, 50.56291661943708, 49.31394665581839, 50.75536434991019, 52.90747158867972, 57.69132716315133, 61.29943289075579, 60.77225916726248, 63.09094251905169, 27.416330541883195, 10.229576570647103, 0.9574959639992032, 12.64668549810137, 58.861323901585166, 43.26215948377337, 25.261301585606166, 14.895077398845128, 28.325511012758525, 25.286909171513148, 34.15221650259835, 32.390313148498535, 44.44211993898664, 34.651889256068635, 61.8562684740339, 10.326843534197126, 0.4429860109729426, 0.1723044549248048, 0.10109314788132906, 0.0976471806477223, 0.052033966806318076, 0.05360634618305734, 0.027436035918071866, 0.08363320691777126, 0.017572111283828105, 0.04744779272004962, 0.1789774532829012, 0.16736788196223124, 0.14737620470779283, 0.21764837178800786, 0.18994689466697828, 0.24054348681654247, 0.17217029498091765, 0.20596028039497988, 0.15456510681126798, 0.14907810624156678, 0.09162607123809201, 0.13560362213424274, 0.24758681601711682, 43.480454513004844, 79.54399190630231, 46.19773169926235, 47.03078249522618, 57.883358001708984, 49.71490287780762, 31.43348366873605, 21.057300976344518, 28.4484680720738, 51.86010708127703, 66.4829488481794, 25.867842844554357, 19.090747117996216, 62.734326226370676, 60.93878664289202, 64.57562664576939, 56.694107804979595, 54.6193722316197, 50.37515892301287, 53.54906129837036, 50.55488102776663, 57.37179340635027, 52.42323425837925, 55.14053923743111, 51.512276785714285, 54.86000919342041, 54.38914714540754, 55.414725576128276, 58.08007192611694, 54.81053801945278, 58.03538111277989, 59.6637852532523, 47.355110509055, 47.96432161331177, 44.71989154815674, 45.06325762612479, 42.449977602277485, 45.7770425932748, 43.76781811032976, 42.43073804037911, 42.081184591565815, 49.919787883758545, 53.361182008470806, 54.689479555402485, 52.28430502755301, 52.50184270313808, 52.567822796957834, 51.575029441288535, 51.8478296143668, 51.78001172201974, 47.47701665333339, 50.599036829812185, 50.05065025602068, 52.634664467402864, 50.591473715645925, 46.22255066462925, 44.88468197413853, 52.40137522561209, 47.16738755362374, 49.805694988795686, 39.35929380144392, 35.254999841962544, 39.210289682660786, 47.05871772766113, 41.97960887636457, 44.320585523332866, 33.58048745564052, 20.202398095812114, 16.97116960797991, 7.811209150723048, 2.494202447789056, 2.2559042062078203, 2.858473049742835, 5.951674052647181, 7.059036689145224, 7.248038113117218, 20.011954920632498, 17.37998424257551, 5.239565338407244, 4.400826139109475, 3.7777720519474576, 6.319134312016623, 9.842506323541913, 33.74071291514805, 38.16785144805908, 38.922811440059114, 35.09605285099575, 36.42296075820923, 25.705611092703684, 24.866048097610474, 40.90587248120989, 48.44456025532314, 46.545065198625835, 49.577696800231934, 44.62865475245884, 41.191259316035676, 45.28950139454433, 45.41480868203299, 46.54259858812605, 43.54642765862601, 48.71173933574131, 49.03221109935215, 50.42678056444441, 51.721803188323975, 53.097039290836875, 52.642442975725444, 47.86496237346104, 46.39188868658883, 46.792528765542166, 44.435123103005544, 47.660688808986116, 44.37342657361712, 42.10648993083409, 43.201317582811626, 43.71871519088745, 44.02295248849051, 43.25050040653774, 47.4449576650347, 49.418336391448975, 47.68563631602696, 53.17912530899048, 54.359419277736116, 53.60678693226406, 56.12893090929304, 56.24456630434309, 59.019812311444966, 53.5332020350865, 53.27809544972011, 53.61721617834908, 54.38983849116734, 52.94138922010149, 49.61490092958723, 51.7960273197719, 59.45207364218575, 62.752857072012766, 63.278189522879465, 62.81425135476248, 34.78974846431187, 13.685745171138219, 2.068756648472377, 11.175125649997167, 65.53249781472343, 51.31265851429531, 32.048267228262766, 20.5596536227635, 39.839612347739084, 40.03525972366333, 48.736325536455425, 48.29427419389997, 63.71666949135916, 44.63213927405221, 68.70641408647809, 11.78281249318804, 0.7156856251614434, 0.2878834908562047, 0.15403146616050176, 0.2898293664412839, 0.15827696477728231, 0.11256366023527724, 0.08885615558496543, 0.2588293541754995, 0.0944647089179073, 0.2130273583212069], [0.06116847986621516, 0.02028309617058507, 0.07836855548833098, 0.1612127958131688, 0.060963562290583334, 0.09422471108181135, 0.06420333630272321, 0.025162550055288842, 0.02325588700893734, 0.12218009600681917, 0.14871142591748918, 0.09645614812948874, 0.08995577586548668, 29.913499219076975, 58.51117638179234, 36.20336641584124, 29.917365891592844, 40.71781601224627, 38.138543946402415, 22.622222900390625, 17.448120015008108, 16.48270950998579, 34.16453218460083, 50.494994504111155, 33.19896534511021, 5.866960312638964, 37.598477840423584, 58.509613037109375, 56.099480969565256, 53.44142327989851, 51.23335872377668, 46.238528047289165, 44.680717604500906, 43.76362487248012, 45.0319698878697, 43.46511289051601, 44.501203945704866, 44.8246808052063, 46.448568616594585, 46.98290245873587, 50.98020805631365, 48.957924434116904, 54.14840248652867, 48.889449937003, 50.980513777051655, 42.555413041796, 40.927391052246094, 39.63950770241873, 41.14210428510393, 39.122863973890034, 39.0790799004691, 38.71334409713745, 39.429727690560476, 38.08809307643345, 41.571284089769634, 47.178070408957346, 47.82975237710135, 49.04691001347133, 48.17584909711565, 47.24752460207258, 49.003587995256694, 47.54579339708601, 45.806270190647666, 43.22854062489101, 46.06823812212263, 49.20648929050991, 44.98952681677682, 43.78633853367397, 43.07738603864397, 40.89865330287388, 44.3310112953186, 38.73562697001866, 37.6016913822719, 28.72698140144348, 21.060300861086162, 25.48248185430254, 28.004255839756556, 24.781267915453228, 23.192491088594707, 16.170976843152726, 18.879839760916575, 1.134238485779081, 0.9509692170790264, 1.2308376623051507, 0.8429847657680511, 0.07888959574380092, 0.07932177505322865, 0.46695395771946224, 0.3865701396550451, 0.4618568569421768, 0.6856459570782525, 0.5549943106515067, 0.6075708408440862, 0.09876502637884446, 0.16014950429754599, 2.4558229872158597, 11.90198712689536, 26.095686435699463, 22.068991695131572, 19.6942937033517, 22.906107187271118, 17.915368999753678, 16.65275798525129, 35.063326835632324, 39.15333529881069, 38.40099130358015, 37.136429582323345, 38.86481830051967, 35.82877165930611, 37.113250391823904, 38.55877794538225, 38.93562739236014, 35.576131684439524, 42.29636335372925, 45.1012920652117, 44.7082394191197, 44.191408089229036, 44.9165220941816, 43.46085711887905, 41.893343516758506, 39.32270111356463, 38.07722609383719, 38.46066243307931, 37.400579248155864, 37.02506732940674, 39.613990443093435, 38.069378103528706, 40.9317684173584, 38.27220644269671, 40.50940826960972, 41.85129649298531, 45.01255662100655, 47.00211770193917, 47.61918027060372, 48.28415414265224, 49.896375928606304, 49.810009820120676, 50.63738741193499, 51.008803367614746, 51.93386568341936, 50.173543044498985, 46.46749898365566, 47.06703124727522, 45.82290070397513, 50.95421831948416, 56.15794311250959, 56.7352237701416, 59.30270821707589, 58.56155776977539, 62.37238066537039, 19.50966443334307, 6.425299312387194, 0.5745182601468903, 17.236660276140483, 56.05760070255825, 32.01844555991036, 17.78330111503601, 22.268630811146327, 34.87496812002999, 32.20270136424473, 35.74912445885794, 28.691318035125732, 48.97050414766584, 38.26812090192522, 61.83091449737549, 12.629102213042122, 0.3185594619384834, 0.054329162397022755, 0.07550726152424302, 0.011759608135824757, 0.04145067970135382, 0.04097934552867498, 0.05558876087889075, 0.05962326563894749, 0.02936960457425032, 0.030756553901093345, 0.05385652543710811, 0.04105951783380338, 0.021764280440817987, 0.14297962348376, 0.038768868427723646, 0.05834806085165058, 0.04397929812382374, 0.037323968817612956, 0.10140307553644691, 0.13475135500941957, 0.14727005468947546, 0.22914825113756315, 0.06146142378981624, 34.23112719399588, 65.30165086473737, 40.6537640435355, 38.87657117843628, 41.68131228855678, 42.15590551921299, 24.999887772968837, 21.60431006976536, 21.018986872264318, 40.48012508664812, 53.291964054107666, 39.3321784564427, 7.312912140573774, 35.01516539709908, 61.83709144592285, 61.14005511147635, 58.728974614824565, 53.37343863078526, 49.69483300617763, 45.782868657793315, 45.84745216369629, 47.46804652895246, 47.6993659564427, 47.68102271216256, 46.79770169939314, 48.88596541540963, 51.30959783281599, 53.373032161167686, 53.62453610556466, 56.09812259674072, 51.19341005597796, 54.606743880680625, 45.05898795809065, 42.875964709690635, 43.04805074419294, 43.819467544555664, 41.3798542703901, 41.776266370500835, 40.97174487795149, 42.012546811785015, 39.98043843678066, 43.37554713657924, 47.99368470055716, 52.15913322993687, 51.247321128845215, 50.052953583853586, 51.203877517155235, 52.312709263392854, 48.86444337027413, 48.268447739737375, 45.2797600201198, 47.05137695584978, 49.38137544904436, 47.40761457170759, 47.542788301195415, 47.762177671704976, 45.23795618329729, 46.61633634567261, 43.44856922967093, 44.64302362714495, 36.60676840373448, 26.135126147951397, 30.57587446485247, 34.86072431291853, 34.026666028159006, 29.209594590323313, 21.490748711994716, 30.237052508762904, 5.2206102183886935, 4.446938727583204, 5.002034221376691, 3.0027228636401038, 1.1437553465366364, 0.520551221711295, 0.8474065342119762, 0.2934472065951143, 0.40725112706422806, 1.8643658331462314, 1.088889004928725, 0.5992802828550339, 0.0824383542473827, 0.7045091763138771, 6.943792130265917, 19.80795407295227, 27.505182368414744, 25.912412064416067, 22.323554583958217, 28.886268854141235, 22.181397914886475, 22.465268305369786, 39.49978985105242, 41.84263903754098, 43.017061778477256, 42.66235624040876, 43.66042675290789, 40.69572421482631, 40.842077595846995, 42.63758938653128, 42.74272952760969, 40.006407329014365, 43.91383450371878, 47.09776660374233, 48.83926657267979, 46.202598912375315, 50.01698970794678, 45.47727646146502, 44.66525786263602, 40.65415661675589, 41.0655003956386, 40.78608553750174, 40.92888838904244, 40.20754378182547, 41.54436329432896, 41.10178388868059, 42.5457307270595, 41.6054379599435, 41.615644863673616, 44.28293670926775, 47.674553939274375, 49.6586537361145, 49.87972804478237, 49.557435853140696, 51.091605050223215, 50.559383460453574, 52.46988098961966, 53.96481370925903, 51.75656502587454, 50.9614166532244, 49.09557867050171, 47.850638662065776, 48.20047698702131, 53.540702615465435, 55.71377256938389, 58.069687843322754, 61.42572334834507, 59.93885748726981, 61.49577508653913, 21.02431092943464, 5.197672043527875, 1.0836895810706275, 20.925943544932775, 59.877310344151084, 33.91671773365566, 21.84203921045576, 22.804910148893082, 27.189449276242936, 26.35473438671657, 40.42995909282139, 24.03545696394784, 49.41926050186157, 46.26470191138131, 67.23416028703961, 17.414780821119034, 0.3322332724928856, 0.10732442672763552, 0.11181990443063633, 0.02263528700651867, 0.016135218386937464, 0.060712490762983046, 0.020667111368051598, 0.07346673030406237, 0.04699631926736661, 0.05789719468780926, 0.2562455471072878, 0.13048421112554415, 0.103591384898339, 0.26260906564337866, 0.10830492340028286, 0.14144659574542726, 0.08413750092898097, 0.09009318599211318, 0.14736339396664075, 0.23186499678662845, 0.1951118760875293, 0.41011557621615274, 0.108987814613751, 45.776882784707205, 75.90246186937604, 46.82507412774222, 39.339602606637136, 57.88722120012556, 53.13359028952462, 31.568574019840785, 22.318531036376953, 23.868093967437744, 48.12563793999808, 60.85107258387974, 42.24884114946638, 9.23446077959878, 44.524938992091585, 64.77993842533657, 64.89513955797467, 60.84445789882115, 58.54457637241909, 51.88650328772408, 50.83683197838919, 49.1270956993103, 52.95180456978934, 50.21429770333426, 52.14330523354666, 50.36318022864205, 53.18379102434431, 53.2774110521589, 57.7556084224156, 54.923606055123464, 60.35501289367676, 52.49411630630493, 56.96933289936611, 46.93928166798183, 45.08095121383667, 44.837118080684114, 47.56697498049055, 43.18530198505947, 42.98909180504935, 42.29754454748971, 45.149307591574534, 42.42807688031878, 45.991210392543245, 50.7201543535505, 53.08524819782802, 54.138977255140034, 53.86744165420532, 52.45228467668806, 54.22565950666155, 51.94668163572039, 51.80359043393816, 47.30236325945173, 49.940590790339876, 50.48209169932774, 47.69395330974034, 49.425968987601145, 49.61580419540405, 45.80041980743408, 50.634451798030305, 47.37598637172154, 49.82494149889265, 41.27708693913051, 35.27005658830915, 39.155913080487935, 40.53827108655657, 41.870695863451274, 42.05021299634661, 31.136733055114746, 38.34118815830776, 5.450685049806323, 2.427214865173612, 4.375264150755746, 2.1973814836570194, 0.5551167183688709, 0.4163420849612781, 0.7382190131715366, 0.7226643849696431, 1.110852586371558, 1.613889787878309, 1.7334224709442683, 0.7522184933934892, 0.10065311113638536, 0.3192588686943054, 7.763358644076756, 27.215254885809763, 32.16082109723772, 29.383577483040945, 27.022072383335658, 34.85567644664219, 24.281240803854807, 23.964213609695435, 45.73541940961565, 46.112678800310405, 49.05591835294451, 46.045458453042166, 47.33833755765642, 42.055827140808105, 44.28540331976754, 45.12560728618077, 46.18949113573347, 41.11083044324602, 47.16337149483817, 49.481109891619, 50.6422233581543, 49.79241003308977, 51.23225743430001, 48.55243798664638, 47.92485931941441, 44.227062770298545, 44.619594301496235, 44.46949584143502, 43.56067493983677, 40.249729769570486, 45.56436170850481, 43.18971061706543, 45.591949531010215, 42.529861041477744, 44.54894501822335, 44.80511815207345, 50.14189747401646, 53.43722309385027, 51.94215835843767, 52.5242680140904, 54.80756766455514, 53.779265539986746, 57.0682544027056, 56.449225493839805, 56.24434048788888, 54.98020955494472, 52.732258864811485, 52.649509293692454, 52.08539547239031, 56.16749688557216, 59.49317223685128, 60.90629686628069, 66.22360038757324, 61.94674096788679, 67.00423744746617, 26.268208469663346, 7.357403193201337, 0.9883576908281871, 20.685702630451747, 65.08800070626395, 42.96207026072911, 24.962192058563232, 31.10493462426322, 47.05139780044556, 44.00369208199637, 55.37767778124128, 41.223457268306184, 62.806073325020925, 51.78133882795061, 79.96616445268903, 22.110119819641113, 0.4370252979653222, 0.31273285459194866, 0.21836035858307565, 0.16627580699111733, 0.1435002362621682, 0.22854389356715338, 0.1475283729710749, 0.20653240755200386, 0.14207124151289463, 0.23825655238968985], [0.008653098401347441, 0.08204148590032544, 0.029998864379844496, 0.02975018129550985, 0.012298369181475468, 0.04496406278173838, 0.0321100005613906, 0.1324183480548007, 0.09686094855091401, 0.1121934379584023, 0.11480756875659738, 0.0864520992285439, 0.0762490224359291, 23.24094087736947, 57.79309395381382, 40.353264876774375, 28.80925328390939, 43.84976863861084, 42.287931714739116, 26.009787593569072, 22.59731708254133, 14.984691790172032, 28.909481048583984, 46.387598173958914, 46.0314439364842, 6.616466403007507, 15.521580832345144, 58.30072239467076, 59.09959152766636, 57.897574016026084, 52.39992652620588, 45.963883127485005, 42.885973589760916, 42.076279163360596, 43.067794050489155, 42.26967879704067, 41.72494697570801, 41.91000877107893, 46.89408711024693, 47.171834400721956, 50.924601622990195, 52.13291767665318, 50.64924103873116, 51.367476327078684, 51.20227943147932, 43.47374950136457, 38.204666478293284, 41.45244904926845, 39.46915176936558, 40.35587045124599, 38.07910210745675, 37.3206193787711, 36.57329545702253, 40.04607459477016, 38.64834369931902, 42.229549476078574, 48.71342427389962, 48.54207474844796, 50.205049651009695, 48.14150415148054, 48.65897124154227, 49.33954381942749, 46.24827984401158, 44.218547752925325, 45.58161061150687, 45.82908112662179, 45.563145773751394, 43.842330592019216, 42.66036558151245, 42.25450740541731, 43.31008120945522, 39.994710036686485, 36.95585284914289, 28.518672670636857, 18.657222952161515, 23.391588245119365, 24.663285766329082, 23.578380141939434, 14.665585347584315, 4.0217233044760565, 13.188079578535897, 8.093745487076895, 5.436167223112924, 1.933471096413476, 0.8480222640292985, 0.03992788766377738, 0.42584238946437836, 0.04288951660107289, 0.02968232100829482, 0.053791396253343136, 0.16832825328622544, 0.16200923307665757, 0.24767228428806576, 0.4086519218981266, 0.347028131463698, 3.843925850731986, 10.490167021751404, 16.70964115006583, 15.214110885347639, 13.78354627745492, 17.500540699277604, 23.43567977632795, 26.262399775641306, 35.30167784009661, 40.24278504507882, 37.210382734026226, 37.785012653895784, 35.95175130026681, 37.97419473103115, 37.52540710994175, 39.10161985669817, 37.98721218109131, 38.77759061540876, 39.275151116507395, 44.49321004322597, 43.71469913210188, 45.89109032494681, 43.829080377306255, 42.64339460645403, 40.04578277042934, 38.662729944501606, 38.363238266536165, 38.70191778455462, 37.37799065453665, 36.18527678080967, 37.356426920209614, 38.98345531736101, 39.849009786333355, 39.10042824063982, 39.61544261659895, 40.63510118212019, 41.781599112919395, 42.95956196103777, 46.42786645889282, 45.48077140535627, 47.37871701376778, 47.4478793825422, 47.17360619136265, 46.74037558691842, 45.8318430355617, 44.02261897495815, 44.53725119999477, 44.425013474055696, 46.30704075949532, 49.02390105383736, 55.84261996405465, 54.25401510511126, 57.89895323344639, 57.06804248264858, 60.21387413569859, 17.95133634975978, 4.227802532059806, 1.5631594700472695, 29.616362980433873, 50.02395527703421, 26.201794113431657, 16.89037595476423, 22.9921258858272, 36.76371431350708, 27.319642884390696, 37.469679083142964, 30.39866065979004, 43.12680857522147, 26.408932072775706, 55.89333833966936, 12.42075092451913, 0.2823292746075562, 0.04408585526315229, 0.012582849228887685, 0.0633957710649286, 0.09147904627025127, 0.042145078868738244, 0.18521656920867308, 0.045970482884773185, 0.0196264998854271, 0.025266063965058753, 0.04083736886137298, 0.09110771798129592, 0.02367162541486323, 0.03926769344668303, 0.037558222854776044, 0.004638759277960551, 0.011626520277267056, 0.04242349535759006, 0.04347203212923237, 0.18504369205662183, 0.11371792294085026, 0.07955517074359314, 0.002061108006663354, 31.668291091918945, 64.76417296273368, 49.09683976854597, 35.48284864425659, 47.598613602774485, 42.8159635407584, 27.9878511428833, 24.904362201690674, 19.358938898359025, 36.012290954589844, 49.68068299974714, 52.46725109645298, 8.765647581645421, 15.26733408655439, 58.496578216552734, 63.827222279139924, 59.8603914805821, 57.29840653283255, 49.07654408046177, 47.40773963928223, 45.208426339285715, 46.75835405077253, 45.41161945887974, 44.61204508372715, 43.393581186022075, 49.285361766815186, 50.52198130743844, 54.63780232838222, 56.06348582676479, 54.45170177732195, 53.218834263937815, 53.73086438860212, 46.680843421391074, 41.04863364355904, 41.46303115572248, 42.10879673276629, 41.175942012241904, 39.964544432503835, 38.30816337040493, 40.46619047437395, 40.954687050410676, 40.827020849500386, 43.97912672587803, 50.426874365125386, 50.764313629695344, 52.64765065056937, 51.203147956303184, 51.69513600213187, 50.973395347595215, 47.49648550578526, 45.5120278767177, 48.051014287131174, 46.81349842888968, 48.294232504708425, 48.312558378492085, 46.402477741241455, 45.97857856750488, 47.422674792153494, 47.20727368763515, 43.23841054098946, 38.6607323374067, 26.26242583138602, 29.164705753326416, 28.387084211621964, 32.04260792051043, 22.997086899621145, 12.404714482171194, 21.696761063167028, 18.60413350377764, 6.435648654188428, 6.451355925628117, 3.1721722739083424, 2.436199971607753, 0.3614712921636445, 0.19779997398810728, 0.06887646125895636, 0.08409490250051022, 0.2731185959918158, 0.4469673830483641, 0.4816192165017128, 1.3581716524703162, 1.6619006459202086, 10.266869289534432, 18.30194592475891, 20.583529370171682, 18.724775075912476, 19.532006365912302, 26.445849588939122, 25.114123106002808, 26.51874140330723, 39.342826570783345, 44.140060901641846, 43.16120563234602, 40.64495720182146, 41.54039934703282, 41.344032832554404, 42.04588426862444, 42.74929904937744, 40.7141751561846, 41.72590582711356, 42.2121616091047, 47.18537296567644, 45.59482608522688, 48.38461814607893, 46.99703509466988, 45.74662337984358, 44.22289385114397, 43.05777127402169, 41.296930994306294, 41.33821371623448, 40.97861317225865, 40.6031950541905, 41.26761654445103, 42.54618583406721, 40.165503706250874, 41.10850279671805, 41.42955126081194, 43.05675336292812, 44.265899726322715, 45.1746198790414, 47.950494698115754, 48.551753589085166, 47.15487732206072, 48.211156368255615, 47.958763054439, 47.912602697099956, 47.30996458871024, 46.0734874861581, 46.808322020939414, 46.0349770954677, 48.05766371318272, 52.13854224341256, 57.72753422600882, 57.06426613671439, 60.408409799848286, 58.24251733507429, 60.383229528154644, 22.210295472826274, 3.7379310812268938, 2.3349336683750153, 34.95800256729126, 53.66257749285017, 29.962143557412283, 21.783115012305124, 26.788836990083965, 36.27851118360247, 23.31076158796038, 39.40575640542166, 31.481516565595353, 38.958212511880056, 32.42417172023228, 63.949892725263325, 20.68574779374259, 0.1328841352037021, 0.07910842328731503, 0.09087902453861066, 0.06628337183168956, 0.10636650491505861, 0.038047500886023045, 0.027894986826660376, 0.023264811440770115, 0.02573713011640523, 0.054110507879938395, 0.10099955754620688, 0.15397111725594315, 0.09140732511878014, 0.10964809704039778, 0.07610239780374936, 0.09823587084455149, 0.08770025082464729, 0.20972251280077867, 0.1464169868933303, 0.25600575283169746, 0.21823199332824775, 0.15634069724806718, 0.13449762362454618, 40.84029885700771, 74.04648685455322, 51.28720726285662, 37.896545137677876, 58.86144202096121, 57.321717739105225, 34.67738567079817, 28.78423282078334, 20.229324102401733, 43.35764857700893, 57.34230177743094, 55.96469633919852, 9.728403006281171, 18.460349219185964, 63.56298228672573, 65.79573031834194, 65.02006816864014, 60.35715988704136, 53.95775086539132, 47.73126861027309, 46.79243496486119, 48.67523350034441, 49.249714033944265, 46.55460507529122, 46.20390517371041, 50.2187306540353, 52.39792544501168, 57.094063486371724, 59.804833684648784, 56.34537771769932, 56.05869851793562, 57.067712443215505, 47.085628100803916, 44.50712728500366, 46.228991644723074, 45.0033780506679, 44.34651967457363, 42.520678997039795, 43.297914913722444, 41.409943444388254, 44.540273666381836, 43.5724139213562, 46.94066088540213, 52.62091050829206, 53.21181658336094, 53.88899496623448, 53.68808780397688, 54.71738699504307, 52.926676409585134, 50.51456410544259, 47.8360196522304, 48.704238755362375, 48.744944776807515, 48.861386162894114, 50.681435516902376, 50.01436676297869, 49.640588419778005, 53.414835997990195, 49.55454192842756, 47.155780587877544, 40.69976111820766, 34.29177801949637, 34.557459763118196, 34.80881084714617, 37.00348275048392, 30.76400736400059, 16.95518180302211, 33.40387119565691, 24.998776061194285, 12.097158551216125, 8.746834465435573, 3.0250819495746066, 3.5878704019955228, 1.228724975671087, 0.15552319825759955, 0.11642082647553512, 0.16712445073894092, 0.27554712710636003, 0.30750650646431105, 1.2857557897056853, 1.4197370346103395, 1.5561707764863968, 11.359237279210772, 22.713131393705094, 26.753712109157018, 21.367451190948486, 22.655464819499425, 28.679082257407053, 33.859989166259766, 33.085442202431814, 43.23980018070766, 48.56347867420742, 46.64166600363595, 43.972209794180735, 45.13465731484549, 44.58582258224487, 43.07522167478289, 44.344466481889995, 42.74982016427176, 44.76866095406668, 46.34697205679757, 50.471061434064595, 50.13137442725045, 50.432436398097444, 50.68002503258841, 48.30835471834455, 48.087947436741416, 45.03762572152274, 44.433125495910645, 44.06936298097883, 43.215808050973074, 42.18044655663626, 43.51543869291033, 45.281778471810476, 44.051117011478965, 43.638171672821045, 45.72518123899187, 46.44306564331055, 47.635136808667866, 47.37029232297625, 52.56221907479422, 50.26644393375942, 50.18435096740723, 49.0875951903207, 50.265436444963726, 50.51130887440273, 51.39393854141235, 48.07167475564139, 50.303498676845, 50.55817447389875, 50.995827606746126, 54.16593279157366, 63.184152603149414, 59.07022149222237, 63.10624245234898, 61.699454580034526, 64.49786935533795, 26.499619960784912, 4.6033079368727545, 2.2495049153055464, 35.12797634942191, 60.035173416137695, 39.23451110294887, 23.28977629116603, 30.860333715166362, 51.9636595589774, 37.418957233428955, 56.31430537360055, 40.63890879494803, 55.59755005155291, 37.23318324770246, 71.99391950879777, 27.647731610706874, 0.3338094821998051, 0.2617510716829981, 0.11330134315150124, 0.14006429777613708, 0.25870127390537945, 0.15182405603783472, 0.20811059858117784, 0.10534033605030604, 0.10908925559903894, 0.12462050148418971], [0.04909623247970428, 0.05868186615407467, 0.06858121031629187, 0.030705015773751905, 0.1359951232693025, 0.10760846148644175, 0.07243420356618506, 0.00848984033135431, 0.021002853887953928, 0.23470116459897586, 0.3426074758172035, 0.025734548290659274, 0.042688598989376, 30.00936004093715, 53.64206293651036, 32.73159129279, 23.895106826509746, 43.294555459703716, 44.47279276166643, 30.344586304255895, 28.083958625793457, 19.590577942984446, 23.16250092642648, 39.95917347499302, 59.10020991734096, 18.35103494780404, 7.8191908938544135, 44.931978361947195, 59.26955141339983, 56.10784312656948, 53.70776857648577, 49.836694376809255, 50.55348096575056, 49.325904505593435, 48.02356195449829, 44.26865816116333, 41.82606758390154, 43.732583795275005, 49.11336953299386, 49.20454379490444, 49.59907988139561, 56.3438595363072, 52.5852176121303, 51.918037687029155, 51.319446904318674, 45.810598918369834, 41.07200043542044, 39.543504442487446, 39.34318092891148, 40.40648807798113, 38.820836203438894, 40.69802059446062, 38.76926667349679, 37.85637412752424, 38.53151668821062, 40.79405859538487, 44.97357375281197, 48.082364559173584, 49.99809755597796, 48.33287838527134, 49.304646492004395, 48.65548324584961, 45.918080602373394, 42.611095905303955, 47.85199703489031, 47.60612113135201, 42.99008539744786, 43.484932626996724, 43.21820517948696, 41.90430777413504, 42.584185532161165, 39.995929445539204, 38.8921594619751, 32.26769828796387, 22.67914949144636, 21.39398636136736, 25.921866825648717, 21.449808188847133, 18.20947756086077, 11.874705893652779, 8.748702662331716, 10.845172200884138, 5.830171772411891, 2.506819942167827, 1.3064496964216232, 1.199340501001903, 0.0809244340551751, 0.0687664978738342, 0.20446180365979671, 0.2573532962373325, 0.15103259922138282, 0.3740226429487978, 0.35559013060161043, 0.4118717334100178, 1.4594025633164813, 6.691834815910884, 11.432141252926417, 13.322139859199524, 10.891847593443734, 15.141118322099958, 18.304970128195627, 24.92587035042899, 32.33852822440011, 31.662920134408132, 40.78944499152047, 33.63031298773629, 37.90967723301479, 34.311625548771445, 37.75599002838135, 38.062739099775044, 42.46541997364589, 39.45004769733974, 37.77987098693848, 36.9078095299857, 38.8459643636431, 41.22664301736014, 43.3268472126552, 43.35625893729073, 41.51132461002895, 38.061804567064556, 38.38761602129255, 37.373095648629324, 39.52980259486607, 38.5980943271092, 40.277828284672324, 38.442558901650564, 37.46497515269688, 38.061735085078645, 38.543568338666645, 38.79916477203369, 40.00037281853812, 39.94153894696917, 42.60155602863857, 42.0172437940325, 43.57132305417742, 44.81900760105678, 43.06581728799002, 44.11533226285662, 43.38309288024902, 42.36761018208095, 43.339027404785156, 42.749121870313374, 41.974533217293875, 44.15585763113839, 51.395199639456614, 55.791887692042756, 57.37394734791347, 58.12224401746477, 56.27726452691214, 59.92848382677351, 17.41596027782985, 2.920332210404532, 6.384985864162445, 45.374380588531494, 45.32921034949166, 22.41775826045445, 18.456882068089076, 22.927205392292567, 22.43065411703927, 25.101230723517283, 34.070714133126394, 24.028229100363596, 37.007158347538535, 26.229903050831386, 50.44460269383022, 26.775932448250906, 0.178632363943117, 0.1625073863459485, 0.13142315431364945, 0.07873853349259921, 0.18025012713457855, 0.15866005207811082, 0.14880909424807343, 0.15769399463066033, 0.031716948973813226, 0.0875500367422189, 0.011241642492158073, 0.033401398586907556, 0.05519669655976551, 0.04225107282400131, 0.04973810625129512, 0.07942669692316226, 0.03612521117819207, 0.02648659240055297, 0.03809489994975073, 0.16536560654640198, 0.21935062615999154, 0.029105810515050377, 0.14950335770845413, 39.876118183135986, 61.50641277858189, 33.85879060200283, 28.16787723132542, 48.473454339163645, 40.183992862701416, 31.501899106161936, 28.55351267542158, 20.154868943350657, 28.553576946258545, 44.65978268214634, 63.5391777583531, 22.535978385380336, 7.617019159453256, 45.52872092383248, 63.963295800345286, 59.99223354884556, 56.23800025667463, 52.784596170697895, 52.02974387577602, 51.43659005846296, 52.621681758335654, 49.824663570949006, 45.29545252663748, 48.10417148045131, 50.11789492198399, 51.48791640145438, 51.86995267868042, 55.829341956547324, 55.82271337509155, 54.51780693871634, 52.68062332698277, 49.19782141276768, 43.7989946774074, 41.61840329851423, 41.782276562282014, 42.597623348236084, 40.84804957253592, 40.83389956610543, 40.52987766265869, 38.27934224264962, 39.9508182661874, 41.624125140053884, 46.11429425648281, 50.61520528793335, 50.47291660308838, 50.689985275268555, 52.69146599088396, 50.44910512651716, 47.32850585665022, 45.62469291687012, 48.15501839773995, 49.15959242412022, 47.472531591142925, 47.5178199495588, 45.79267604010445, 47.04294184276036, 45.90179402487618, 44.67315101623535, 44.2730598449707, 40.375707558223176, 26.3339592729296, 28.500565665108816, 32.0218050139291, 30.882831982203893, 28.46875854900905, 27.199878522327968, 20.44691388947623, 16.186156920024327, 13.559702243123736, 3.9556698203086853, 1.5692185163497925, 0.45968901898179737, 0.17682990351957933, 0.07352657030735697, 0.18100273103586265, 0.08455775837813105, 0.3186810554138252, 0.15379445387848786, 0.6759324297308922, 0.3590615428984165, 4.376309854643686, 14.058338846479144, 17.277977739061626, 17.276819126946585, 17.938204254422867, 27.06524501528059, 31.10493462426322, 34.67758022035871, 31.89497607094901, 36.46697759628296, 42.85822248458862, 39.003806591033936, 41.939941610608784, 40.41600711005074, 41.38998474393572, 40.687844957624165, 45.01145880562918, 42.668616567339214, 40.72800554547991, 40.77949864523751, 42.64251913343157, 46.32600586754935, 44.82420137950352, 44.950707231249126, 45.951338154929026, 42.17655209132603, 41.58172723225185, 40.93993255070278, 42.32653938020979, 42.161877495901926, 43.55261502947126, 41.46215568270002, 42.27632474899292, 41.03685644694737, 39.961601870400564, 41.93724570955549, 41.900625228881836, 42.08156326838902, 43.619588715689524, 44.06309917994908, 45.446026938302175, 45.102952684674946, 43.48741660799299, 44.02166012355259, 44.506863253457205, 45.0673952783857, 45.17585318429129, 45.20729030881609, 43.06586939947945, 46.61527674538748, 54.68006822041103, 56.25069114140102, 57.66051190240042, 60.440795353480745, 56.96551833833967, 62.44860240391323, 23.387078864233835, 2.059585894857134, 8.374718478747777, 53.287239279065815, 48.02483000074114, 25.95722620827811, 20.438002824783325, 23.457917485918315, 25.127718993595668, 24.489485263824463, 36.067824431828086, 32.917643206460134, 47.215517725263325, 35.148230348314556, 55.82263347080776, 42.303450516292024, 0.11688733287155628, 0.14155087300709315, 0.13918270436780794, 0.059578699458922656, 0.10119800189776079, 0.14546896490667546, 0.04992525978013873, 0.07009819070143358, 0.0469775984862021, 0.0877744418435863, 0.16199336892792157, 0.1312936084078891, 0.22330947087279387, 0.21470409977648938, 0.23150629603437015, 0.27092766069940155, 0.2074864413589239, 0.10889246008758034, 0.1933727501226323, 0.3345185512942927, 0.43583555466362406, 0.26460528852684156, 0.2651379927992821, 49.74194874082293, 70.88900307246617, 41.955179010118755, 31.26529209954398, 59.40508297511509, 57.98323835645403, 43.22025837217058, 35.642358439309255, 24.190907273973735, 34.35713972364153, 51.279348850250244, 68.57266126360211, 24.503612688609532, 11.191952449934822, 52.63255916322981, 67.55533381870815, 63.275368554251536, 60.63123852866036, 54.72327559334891, 54.21926368985857, 53.36055667059762, 52.791214329855784, 51.65633378710066, 47.085061822618755, 49.78886297770909, 53.871603625161306, 54.81262942722866, 55.90037339074271, 60.321487835475374, 56.37221513475691, 56.16817780903408, 55.49301092965262, 50.84300545283726, 46.142597743443076, 45.056431021009175, 46.158331939152305, 47.39612225123814, 44.09569665363857, 44.87091064453125, 42.42643015725272, 41.26105744498116, 41.89260005950928, 43.67170715332031, 48.78534855161394, 52.575913974217, 52.48596954345703, 53.61225516455514, 55.04080479485648, 53.97185570853097, 50.07176235743931, 48.214696475437705, 50.870416096278596, 53.79200158800398, 48.88329035895211, 50.03632307052612, 49.78940493719918, 51.530884061540874, 50.00250618798392, 48.154594557625906, 49.03506333487374, 44.01938458851406, 33.06861366544451, 33.60865545272827, 36.77609600339617, 37.06741312571934, 30.593418666294642, 33.86569711140224, 27.818789311817714, 27.78540321758815, 24.102786745343888, 9.719317368098668, 4.919079678399222, 2.908309872661318, 0.32097700078572544, 0.24920770046966417, 0.3337249367364815, 0.5895851573773793, 0.4297728714134012, 0.8402900589363915, 1.0271032346146447, 1.5626948092664992, 6.1332747765949795, 19.70299632208688, 20.671391078404017, 22.062234572001866, 18.616152150290354, 29.198446205684117, 33.76157488141741, 41.27329322269985, 41.81259502683367, 38.91625928878784, 48.88511078698294, 41.780727113996235, 45.568051201956614, 40.76597050258091, 44.527478558676584, 43.168945925576345, 49.27367489678519, 44.915976660592214, 43.82055493763515, 43.76810993467058, 45.833479336329866, 49.50166266305106, 50.69250052315848, 48.5090777533395, 49.85901199068342, 44.29456104551043, 43.33102308000837, 42.855248655591694, 44.646931988852366, 46.29534346716744, 47.38925743103027, 43.742884499686106, 44.62882498332432, 43.36863367898123, 41.56173726490566, 44.00678055627005, 44.94315453938076, 46.35775913511004, 46.07873337609427, 46.095391682216096, 47.59458017349243, 47.440469128744944, 45.748037338256836, 48.04758187702724, 47.971436568668906, 47.03038992200579, 48.5990742955889, 47.94007587432861, 45.740043435777935, 50.050688471112935, 57.3122056552342, 59.29342542375837, 61.21504007066999, 62.693581989833284, 60.15751729692732, 68.91368579864502, 28.769342831202916, 2.6582567989826202, 8.065883210727147, 54.158821310315815, 54.366846902029856, 32.179431847163606, 23.825649159295217, 29.58496059690203, 28.94306342942374, 35.24572399684361, 49.765544823237825, 34.91204023361206, 46.894212177821565, 36.58380460739136, 62.44149439675467, 45.74305200576782, 0.29069143161177635, 0.2266929450311831, 0.11128447244742087, 0.45937786996364594, 0.23719326087406703, 0.25074151530861855, 0.19860236878905976, 0.16074888142091887, 0.12320110122007982, 0.18313350741352352], [0.0839591615700296, 0.03594116873240896, 0.010597409115039876, 0.09005533730877296, 0.12603254642869743, 0.19722833537629672, 0.06554095274103539, 0.08860053787274019, 0.049552686379424164, 0.19075452775827476, 0.24876225580062183, 0.13658116039420876, 0.18120429664850235, 38.282316071646555, 51.38868917737688, 44.17077193941389, 27.94115924835205, 39.35003185272217, 39.36967788423811, 31.900149004799978, 26.084944520677837, 24.008352041244507, 26.328365973063878, 37.035680702754426, 58.21543673106602, 34.27458470208304, 8.208560994693212, 29.75517409188407, 58.58170754568917, 54.97051681791033, 55.50992979322161, 50.60926110403878, 54.761587960379465, 52.92968497957502, 54.01536532810756, 49.25227444512503, 48.13199554170881, 45.36182519367763, 50.3755966595241, 49.432159832545686, 51.13707058770316, 51.517679010118755, 58.54728616986956, 54.1532940183367, 51.778698512486045, 46.98411839348929, 40.63444805145264, 39.57111310958862, 40.415315764290945, 37.64815746034895, 38.61429405212402, 41.27537073407854, 40.370551994868684, 36.609544209071565, 41.007260595049175, 40.84387370518276, 41.278820514678955, 47.471211433410645, 46.680287565503804, 48.75273718152727, 50.2082006590707, 47.931741510118755, 48.49341998781477, 45.10908446993147, 47.72074556350708, 44.68115186691284, 45.03060456684658, 40.45575775418963, 41.70592975616455, 41.173961775643484, 42.33481815883091, 38.814509868621826, 37.982303278786794, 31.51287031173706, 22.513514859335764, 20.66918155125209, 29.35567351749965, 20.805048363549368, 23.14656697000776, 20.408252375466482, 14.812133278165545, 13.95833168710981, 4.933117210865021, 4.7434192299842834, 5.911962492125375, 0.8124871136886733, 1.1904053347451347, 0.834385121507304, 0.6964915522507259, 0.1851722744426557, 0.07483187490808112, 0.21723415330052376, 0.0545733264381332, 0.9285931949104581, 2.3597888946533203, 6.2702441811561584, 15.096804448536464, 11.870397142001561, 7.781562055860247, 18.192112275532313, 29.596894127982004, 26.775449548448833, 29.033202409744263, 31.65160846710205, 43.14921304157802, 35.80786452974592, 37.510635239737375, 37.19868196759905, 36.57759986604963, 38.16763605390276, 38.86796930858067, 39.66871792929513, 39.39032793045044, 38.42345135552542, 36.84038768495832, 38.58724471500942, 38.593449456351145, 39.744442871638704, 40.44867753982544, 36.898245334625244, 37.838274070194785, 38.831651074545725, 39.36150680269514, 38.57443223680769, 38.484560762132915, 38.6881742477417, 38.0128892489842, 40.70758826392037, 39.5711270059858, 37.844819273267476, 39.74171570369175, 38.867691380637034, 41.7265659059797, 40.867591381073, 43.67121730531965, 43.21167039871216, 41.298577717372346, 39.41569927760533, 40.82113225119454, 37.890833718436106, 42.32014356340681, 44.5013359614781, 42.067899635859895, 44.651003633226665, 55.91276202883039, 54.19637632369995, 60.28806700025286, 55.72945465360369, 57.95815188544137, 59.50983401707241, 17.664617197854177, 1.6616356372833252, 14.34974021571023, 51.48534556797573, 34.21865170342581, 20.00366571971348, 33.41608265468052, 27.55834650993347, 27.841584614345006, 30.040602615901403, 24.795113938195364, 23.580570561545237, 63.72103990827288, 40.303168364933555, 38.013799462999614, 49.55276666368757, 0.7871076783963612, 0.18592804031712667, 0.0479123822546431, 0.19379787945321628, 0.3059142290481499, 0.38337448398981777, 0.17333367041179112, 0.1134374640615923, 0.10380757972598076, 0.02206440326491637, 0.08312486883785043, 0.03050828811579517, 0.075999959371984, 0.0741700047094907, 0.11254267314715044, 0.06615617365709373, 0.04897686799189874, 0.06444745284638234, 0.08799638386283602, 0.1493227452571903, 0.18022791189806803, 0.10848935600370169, 0.3931195225034441, 46.9246244430542, 58.581645011901855, 47.6448712348938, 29.78613873890468, 45.40648821422032, 35.46319913864136, 28.00900145939418, 21.054203816822596, 26.37699815205165, 31.529948983873638, 41.035970551627024, 63.91988345554897, 40.75449902670724, 10.284469945090157, 29.716125215802872, 63.99759905678885, 59.06482969011579, 60.66820294516427, 55.314685412815635, 58.35354954855782, 55.20451130185808, 55.66883509499686, 52.82117148808071, 50.257126399448936, 46.85366596494402, 51.47726828711373, 50.50615678514753, 53.550846985408235, 54.03046376364571, 57.744095257350374, 54.93926729474749, 53.40692547389439, 48.69559172221592, 42.88881540298462, 42.07856164659773, 43.530630929129465, 40.844512939453125, 41.27989053726196, 43.55161796297346, 42.02531065259661, 39.512522424970356, 43.00844253812517, 41.854822703770225, 41.323796204158235, 47.2814040184021, 48.2310004234314, 50.86986371449062, 50.92577934265137, 49.56407138279506, 50.355571951184956, 44.994578157152446, 47.77697386060442, 47.471562317439485, 46.44606031690325, 45.75407879693167, 45.352438177381245, 45.754572119031636, 45.873594760894775, 45.175575256347656, 41.98891598837716, 38.68856682096209, 29.802605969565256, 30.381540298461914, 37.2824946131025, 27.610226971762522, 30.241030352456228, 28.178495815822057, 27.306998900004796, 20.827317340033396, 10.202616691589355, 5.625975506646292, 2.663058872733797, 1.6855567651135581, 0.3393866872148854, 0.5746323083128247, 0.28034621530345505, 0.23518371156283788, 0.057284287576164515, 0.2223006792898689, 0.08699093745755297, 1.248309993318149, 5.080711713859013, 13.31431792463575, 22.447675466537476, 16.493263823645457, 16.885969059807913, 30.50028153828212, 37.89278963633946, 39.32485852922712, 32.67036376680647, 35.2762439591544, 43.626602922167095, 41.46240234375, 40.137967995234895, 42.01357167107718, 40.39681271144322, 40.98447050367083, 42.32364198139736, 41.90445368630545, 42.075917857033865, 42.00831535884312, 40.23722996030535, 41.72270965576172, 42.24530799048287, 43.12410920006888, 42.83531774793352, 39.525727476392476, 40.00205428259713, 39.38880974905831, 41.60875572477068, 42.83667264665876, 41.62076916013445, 42.9194986479623, 42.37054927008492, 42.92076669420515, 40.72245046070644, 41.228939396994456, 40.60719721657889, 42.02460888453892, 44.342597416469026, 44.16759661265782, 43.641343525477815, 44.43797186442784, 42.08917849404471, 41.502271107264924, 41.86415066037859, 40.529863766261506, 42.87421376364571, 45.8522881099156, 44.145008019038606, 48.085581575121196, 56.33669941765921, 57.415702547345845, 60.123686517987935, 59.664389746529714, 60.720279693603516, 61.82889257158552, 21.36130029814584, 1.4449015642915453, 18.70696857997349, 55.70955153873989, 35.13304158619472, 22.81995473589216, 36.86421653202602, 20.944519553865703, 19.724841458456858, 33.422784192221506, 29.441521985190256, 33.18304007393973, 77.52133655548096, 42.56879527228219, 45.80197620391846, 58.77154622759138, 3.4995438158512115, 0.24713887433920587, 0.11443004544292178, 0.01975466327608696, 0.144624473793166, 0.27906690537929535, 0.1000003604484456, 0.050394449782158644, 0.10329334517674786, 0.0415481851835336, 0.22713838970022543, 0.07697073263781411, 0.12295217386313848, 0.23942002281546593, 0.30331188440322876, 0.2379869839974812, 0.2569313288799354, 0.17561854209218705, 0.14202607822205338, 0.22114512058241026, 0.2754209738756929, 0.2559909607682909, 0.6190194093755313, 60.91278648376465, 64.8430906023298, 57.278847353799, 39.05964578901018, 53.59972756249564, 50.13857970918928, 41.907604694366455, 34.958495889391216, 30.25144570214408, 38.66355678013393, 48.10334464481899, 67.80417660304478, 41.262526988983154, 12.724970851625715, 36.72996343885149, 71.23294585091728, 61.28099237169538, 65.29557813916887, 57.47993516921997, 60.56524453844343, 57.31731258119856, 57.08041027614048, 54.178800855364116, 54.687051159994944, 50.51581825528826, 55.94101340430123, 53.445963927677695, 56.43143810544695, 57.93064744131905, 62.2146635055542, 58.41500636509487, 55.447739941733225, 49.464257035936626, 45.588930538722444, 44.44342620032174, 46.39384113039289, 43.810174328940256, 44.42928661618914, 47.43817274911063, 44.94620827266148, 40.68370035716465, 46.71671002251761, 45.12048298971993, 44.73128659384591, 52.204345158168245, 50.22061014175415, 52.74620737348284, 56.09789678028652, 54.46807173320225, 55.773433276585166, 48.690818309783936, 50.59073025839669, 50.272065026419504, 47.82490600858416, 46.51623364857265, 47.82668474742344, 49.46853017807007, 49.89437484741211, 47.47132955278669, 46.98233618055071, 42.90764849526541, 33.91781554903303, 33.532037666865754, 39.44547578266689, 33.33210672651018, 34.65742002214704, 38.870019027165, 37.00297900608608, 36.98220041819981, 21.887897321156093, 18.497240679604666, 10.610855494226728, 5.404409178665706, 2.9571035972663333, 1.3858242886407035, 1.0883690842560358, 0.7264778060572488, 0.38073017873934334, 0.30435289282883915, 0.7052346116730145, 2.9516853051526204, 8.597909382411412, 14.90068633215768, 24.983569928577968, 20.540064913885935, 18.009400708334788, 31.762842178344727, 41.09580496379307, 42.94573504584176, 42.25368751798357, 39.10942963191441, 50.247093200683594, 40.36026866095406, 41.99742405755179, 44.08561481748308, 43.93040248325893, 42.64938047954014, 47.208830084119526, 45.44533906664167, 46.706638608660015, 44.582942553928916, 43.29600068501064, 45.377201557159424, 47.72115898132324, 47.324326515197754, 46.1227571623666, 43.332826137542725, 45.438248429979595, 44.0719998223441, 44.66163785117013, 45.1447947365897, 46.41730867113386, 46.25658988952637, 45.79404136112758, 46.493999413081575, 44.88212503705706, 43.823608670915874, 42.56136417388916, 45.53428643090384, 47.09635959352766, 45.99793972287859, 45.824825354984824, 47.085388387952534, 43.11858885628836, 43.38586173738752, 43.524224690028596, 42.76559257507324, 45.462852001190186, 48.18303006035941, 45.82178551810128, 50.29674155371529, 59.805785587855745, 59.77312905447823, 63.98083305358887, 62.90210437774658, 62.83361598423549, 65.82409981318882, 28.21553145136152, 1.592267862388066, 18.34351873397827, 59.398704528808594, 42.36007138660976, 30.238949366978236, 38.99242544174194, 37.3877146584647, 36.42176219395229, 40.76754774366106, 38.93437671661377, 35.080374240875244, 69.32572092328752, 52.205547196524485, 46.61891065325056, 68.10656220572335, 2.842505220855985, 0.31075598352721756, 0.20311347315354006, 0.28867737682802336, 0.4579221137932369, 0.6088058831436294, 0.1960585138627461, 0.23466588077800615, 0.29272073986274855, 0.1212540449840682], [0.06777668491538082, 0.07908453206930842, 0.03617708518036774, 0.24266659574849264, 0.1325383944703, 0.12957361713051796, 0.06125877930649689, 0.03257271733933261, 0.029104287203933512, 0.06992836017161608, 0.21430938238544123, 0.08421180729887315, 0.5501468021954808, 40.92667886189052, 56.351314953395296, 38.221328258514404, 29.88457386834281, 37.518917492457796, 50.2504700251988, 36.71857534136091, 40.83849927357265, 29.394809246063232, 31.388987404959543, 27.615332160677227, 55.55214704786028, 43.82112121582031, 13.896968671253749, 15.42671707698277, 49.854495661599294, 55.88176958901541, 54.96268619809832, 55.57044860294887, 57.85854251044137, 56.23597833088466, 57.37416969026838, 55.515481403895784, 49.32548066547939, 46.62962130137852, 49.089401721954346, 49.96313074656895, 51.9472131729126, 51.22817884172712, 52.937095233372276, 53.92098447254726, 55.57544783183506, 49.36308431625366, 41.36115666798183, 39.15269953863961, 40.97816153935024, 36.03732878821236, 38.946737561907085, 39.75024461746216, 39.374392236982075, 40.92788437434605, 40.584351539611816, 43.40592466081892, 41.917964458465576, 41.115523951394216, 46.77463020597185, 47.74526923043387, 49.16664831978934, 46.286189215523855, 44.68736355645316, 45.90950652531215, 47.500470297677175, 45.34980133601597, 44.7882513999939, 42.19785526820591, 41.65253979819161, 40.6510785647801, 41.67428765978132, 38.348824228559224, 40.01536355699812, 33.999470778873985, 24.09805154800415, 18.057461397988455, 15.313275575637817, 16.437508004052297, 22.306416852133616, 21.362047229494365, 21.6283404145922, 18.95396661758423, 10.07226848602295, 18.182428223746165, 9.74973223890577, 6.8049823216029575, 4.238578753811972, 3.700181952544621, 2.240629025868007, 1.4767909731183733, 0.6299650477511543, 0.2967635600694588, 0.5111876555851528, 1.6370298947606767, 4.276135069983346, 8.920484713145665, 16.85952421597072, 17.090649093900407, 10.000901801245552, 22.82955367224557, 36.57979897090367, 34.44084119796753, 29.691198553357804, 26.436976739338466, 41.19304500307356, 39.17710856028965, 36.91568183898926, 37.49934441702706, 37.15039546149117, 37.87990767615182, 38.30753108433315, 39.72664506094796, 37.43100193568638, 38.183349405016216, 38.37492166246687, 35.40934712546212, 37.084036690848215, 37.01363059452602, 36.81598908560616, 36.446452617645264, 37.309460571834016, 38.39717674255371, 36.360847336905344, 38.88549266542707, 38.142615590776714, 38.76470865522112, 37.60301501410348, 37.76047509057181, 37.548134667532786, 37.512306281498496, 41.322750500270296, 39.886596066611155, 41.124441964285715, 43.017919881003245, 43.00999893460955, 41.71421548298427, 43.515108653477256, 39.475776876722065, 42.072495869227815, 41.439553192683626, 44.144674505506245, 45.535346031188965, 42.7331097466605, 45.881731101444785, 55.760134424482075, 57.75907904761178, 60.06186144692557, 56.94254411969866, 59.15812315259661, 57.70497342518398, 10.006071260997228, 1.406834555523736, 30.464845725468226, 45.60771499361311, 33.88243184770857, 16.621313912527903, 64.52963651929582, 88.39515617915562, 34.74235480172293, 20.775146790913173, 18.435839448656353, 29.585947241101945, 60.2683549608503, 35.046630314418245, 39.32731124332973, 64.85235255105155, 11.738264986446925, 0.13825986960104533, 0.13183885200747422, 0.30192311320986065, 0.37974139036876814, 0.28287212976387566, 0.1574976673083646, 0.2652131201965468, 0.09516834294689552, 0.06643877670701061, 0.036971625938479385, 0.06266149439449821, 0.031606907557163916, 0.04301011941528746, 0.051176427464400015, 0.11128306109458208, 0.026218615172963058, 0.10247384450797524, 0.1599782963416406, 0.06662557739764452, 0.13020704314112663, 0.05885523185133934, 0.5602143076913697, 52.648137024470735, 64.16889994485038, 44.46284294128418, 30.91766677583967, 41.36236565453665, 47.08474915368216, 27.64354705810547, 34.26925195966448, 37.09258297511509, 37.221006529671804, 31.013357366834367, 58.13707147325788, 49.940761021205354, 18.471756424222672, 17.025989157812937, 51.321058886391775, 60.015982491629465, 59.01739433833531, 58.44991411481585, 61.66489424024309, 55.40054777690342, 59.024912289210725, 55.185139724186485, 48.631734303065706, 47.10003866468157, 50.314237117767334, 49.648658752441406, 53.181866373334614, 52.30577148709978, 53.24114145551409, 55.24486991337368, 55.63445888246809, 51.50816692624773, 44.16756534576416, 41.63204608644758, 43.05586051940918, 39.13009704862322, 42.49128464290074, 40.68555205208914, 40.63138736997332, 40.9188551902771, 44.13556889125279, 44.26736232212612, 41.96848828451974, 44.64147765295846, 48.11611890792847, 49.83588491167341, 51.39826379503523, 49.77598796572004, 47.17792797088623, 45.95716074534825, 48.82239982060024, 48.25364807673863, 47.550420897347585, 44.03723451069423, 44.30566774095808, 43.76721361705235, 45.85813849312918, 44.36645753043038, 45.43836307525635, 39.45536306926182, 29.015013762882777, 24.04530256135123, 20.142975364412578, 22.6066016129085, 28.081733465194702, 29.63674204690116, 33.091831071036204, 25.441930430276052, 9.781542829104833, 12.734461222376142, 7.656049796513148, 5.943819548402514, 4.243558440889631, 2.103413828781673, 1.383415326476097, 0.5874238876359803, 0.17006064818373748, 0.4910784832068852, 0.11710484405713421, 1.3427078936781203, 4.3532900384494235, 11.423396944999695, 24.27534873144967, 20.10811104093279, 19.11200860568455, 33.275298254830496, 43.29600068501064, 46.32571751730782, 38.04256500516619, 31.590870789119176, 42.88705403464181, 41.392295019967214, 41.41305276325771, 42.76106582369123, 39.822262695857454, 41.035696097782676, 41.20562819072178, 41.32341405323574, 39.99865313938686, 39.08997120176043, 40.55837222508022, 40.823143754686626, 40.823675291878835, 39.228879587990896, 39.7080933707101, 39.16880546297346, 40.25741795131138, 41.50971610205514, 39.54355655397688, 40.86219263076782, 40.37408515385219, 42.36410828999111, 39.52798911503383, 42.572859968457905, 41.06230075018746, 38.71602610179356, 41.814450195857454, 42.883531297956196, 44.07280581338065, 44.81000620978219, 42.98222351074219, 42.82704939161028, 44.2875850541251, 42.82496493203299, 42.357757636478965, 42.90745047160557, 44.777436528887065, 47.26903969900948, 44.374058859688894, 48.01004770823887, 57.05221448625837, 59.01257923671177, 60.77198123931885, 61.08779770987374, 59.98124844687325, 59.929185594831196, 11.349739091736929, 1.4373007778610503, 37.85396310261318, 48.15505313873291, 36.99691670281546, 19.02356324877058, 67.9151393345424, 71.60159642355782, 24.586940697261266, 20.884976966040476, 24.01497367450169, 32.200794083731516, 79.37516457693917, 41.619820731026785, 46.330810546875, 74.55197525024414, 24.518356766019547, 0.08628261475158588, 0.05329021671786904, 0.14475228264927864, 0.09879858672086682, 0.17213587968477181, 0.05549543856510094, 0.1458965776754277, 0.017511942191049457, 0.06995840570224182, 0.07964717330677168, 0.1727208040122475, 0.07863204420677253, 0.4585224272949355, 0.29547206365636414, 0.20449623252664292, 0.13853933103382587, 0.15336627114031995, 0.29590179345437456, 0.15976725838014058, 0.3938276959317071, 0.2503648469490664, 1.3598394372633524, 67.17851911272321, 70.36476148877824, 49.62774120058332, 39.90069743565151, 51.21845831189837, 67.82873848506382, 48.95009381430489, 51.35918712615967, 36.91255514962332, 41.85472542898995, 38.61041348321097, 65.82514204297746, 54.54426220485142, 19.553577048437937, 22.755841970443726, 59.80982249123709, 64.80946826934814, 63.414937019348145, 62.20765972137451, 64.53223514556885, 59.45884813581194, 62.31558609008789, 60.61641107286726, 54.60344001225063, 50.913943086351665, 55.978095940181184, 53.761721338544575, 57.44068826947893, 55.04496329171317, 56.414995193481445, 59.99598557608468, 58.04446588243757, 53.39624261856079, 46.35775566101074, 44.72688838413784, 46.64867326191494, 42.72951405388968, 45.43678930827549, 44.71447542735508, 41.82314239229475, 43.49210316794259, 46.15867934908186, 48.144689900534495, 43.42719309670584, 46.889563832964214, 50.84027828489031, 53.35449436732701, 56.69006395339966, 56.71988214765276, 52.85244880403791, 52.0226845060076, 50.592752184186665, 50.0647794178554, 48.97500658035278, 47.49902854646955, 48.03286559241158, 48.87864201409476, 51.696230343409944, 45.665576117379324, 50.114486830575125, 43.24259683064052, 35.98523119517735, 26.38998086111886, 23.0589154447828, 24.14556680406843, 31.16988638469151, 34.678222928728374, 43.312356744493755, 38.1693731035505, 31.260952949523926, 30.568745613098145, 17.987534727369034, 11.69648025717054, 9.384857143674578, 6.8646873235702515, 4.4574244277817865, 2.3183902246611456, 1.5841811363186156, 2.017664155789784, 0.5649402769548553, 2.8299055312361037, 7.571974856512887, 16.64676342691694, 26.26480906350272, 28.554405518940516, 20.26618603297642, 35.82357440676008, 47.69938332693917, 48.41554805210659, 45.61697694233486, 36.23969507217407, 48.052456038338796, 42.660848481314524, 43.135271481105256, 45.453805446624756, 44.04230669566563, 42.921260016305105, 43.86099345343453, 46.65381145477295, 43.11383976255144, 41.660665716443745, 46.23695775440761, 44.86476148877825, 45.58254167011806, 44.86789512634277, 43.449389117104666, 42.87787546430315, 42.563855103084016, 44.0381794657026, 42.72356639589582, 44.44369718006679, 43.6337491444179, 46.26184272766113, 43.3639679636274, 44.25360836301531, 41.738843372889924, 41.952674184526714, 44.8605751991272, 44.162156173161094, 46.68548829214913, 49.243762901851106, 45.65815544128418, 44.46593141555786, 47.20836108071463, 42.53102139064244, 43.1754390171596, 43.51079729625157, 47.20871543884277, 48.377027239118306, 46.85355479376656, 50.648316928318565, 60.34632764543806, 61.909290177481516, 63.755628040858674, 63.98453644343785, 60.69471032278878, 63.864270074026926, 17.755454472133092, 1.679893006171499, 36.48313215800694, 54.5186824117388, 43.19929913112095, 25.146750109536306, 70.26098319462368, 98.63924666813442, 46.12854848589216, 27.049945081983292, 28.20562332017081, 42.40057591029576, 72.77650206429618, 46.06335006441389, 48.185593945639475, 81.86041014535087, 22.625637939998082, 0.333785244928939, 0.1103547437648688, 0.4463423980133874, 0.5541284456849098, 0.4744533438767706, 0.29013926695500103, 0.3992148297173636, 0.1650914376867669, 0.17295084095426969], [0.1311160357935088, 0.04859490027385099, 0.036383122338780334, 0.21850428943123135, 0.3579134887882641, 0.1784398771290268, 0.11963485686906747, 0.006150849546039743, 0.0700278062639492, 0.05528236160586987, 0.15556536242365837, 0.19051746119345936, 0.536482572555542, 45.30218880517142, 48.28894839968, 35.99139077322823, 25.708645718438284, 36.23649542672293, 45.318951334272114, 39.56383139746529, 39.170361859457834, 29.43109621320452, 37.44020829881941, 21.683125223432267, 45.43213401521955, 55.08401564189366, 21.959206683295115, 9.53423820223127, 35.047078473227366, 55.176197392599924, 55.88239145278931, 53.87475115912301, 57.04364388329642, 57.08172695977347, 59.63395663670131, 57.123895577022004, 48.07142114639282, 44.505011558532715, 47.67265708105904, 49.15392616816929, 48.80468538829258, 50.2453179359436, 54.019009658268516, 53.20225933619908, 54.31027814320156, 49.785576479775564, 45.160848549434114, 40.060603278023855, 39.25353179659162, 38.07372072764805, 39.600587368011475, 39.54738501140049, 43.20098059517996, 40.22125605174473, 39.940910134996685, 40.63308620452881, 41.3802398954119, 43.92777953829084, 43.8293583052499, 47.2650271143232, 46.36059400013515, 46.6210298538208, 45.90327399117606, 46.16851799828665, 46.925128187452046, 43.9110552242824, 45.286843708583284, 41.323976857321604, 39.11390427180699, 41.60364185060774, 43.19766283035278, 40.15032884052822, 41.4492633002145, 35.095920835222515, 21.383107219423565, 14.260964819363185, 12.398465446063451, 13.81824905531747, 18.05912028040205, 25.652808257511683, 28.463781901768275, 26.960957765579224, 22.043234722954885, 19.67872279030936, 19.765316452298844, 14.956002678189959, 7.659873911312648, 6.4458664144788465, 6.886118607861655, 2.3208042894090926, 1.311755731701851, 0.9223746657371521, 0.5859386016215596, 2.2035063207149506, 6.849546330315726, 10.07227109159742, 21.14720024381365, 27.64668764386858, 10.000797578266688, 26.945751632962907, 42.01759467806135, 43.6197624206543, 36.154398986271445, 30.946678979056223, 38.34563847950527, 41.542737415858674, 37.78570399965559, 38.08192307608468, 37.735843726566856, 38.311873708452495, 36.96730695452009, 37.84500340053013, 35.9784254346575, 34.20178842544556, 35.977074010031565, 35.95365858078003, 33.5298524584089, 35.04852022443499, 33.9114579473223, 37.080708503723145, 36.86238915579659, 40.13774912697928, 37.456293378557476, 39.26213714054653, 38.959411076136995, 37.91500997543335, 37.017782143184114, 39.14311102458409, 38.8425805909293, 40.00506285258702, 37.653014251164024, 40.58156531197684, 40.5484745161874, 42.23055349077497, 41.59302152906145, 44.10998214994158, 43.77019439424787, 45.74437911169869, 42.89842823573521, 41.28011287961687, 40.39645140511649, 44.92444998877389, 42.91981479099819, 48.32708706174578, 54.57324661527361, 56.96269736971174, 57.550487177712576, 57.35604531424386, 58.58866964067732, 50.780829497746055, 6.13797219310488, 2.6917267058576857, 43.40935707092285, 48.095382009233745, 28.690586737224034, 12.317967091287885, 43.608311789376394, 70.55196680341447, 37.867661476135254, 26.64778161048889, 19.30785574231829, 25.48540530885969, 30.08038800103324, 31.947778906141007, 27.28093273299081, 52.33624628611973, 48.89123909814017, 1.722148584468024, 0.24276862027389662, 0.27701148710080553, 0.15816839917429856, 0.7520546678985868, 0.4490141975028174, 0.2934946226222174, 0.17355324434382574, 0.05467563934092011, 0.06176403683743306, 0.06444784639669315, 0.14673534195337976, 0.030406433224145855, 0.16289330992315496, 0.29472097967352184, 0.08245026253695999, 0.06914114419903074, 0.08998905122280121, 0.13813586054103716, 0.12175400315650872, 0.08876652110900198, 1.8702585569449832, 61.15381254468645, 53.67315265110561, 45.82575641359602, 27.74633523396083, 41.35513257980347, 42.21455873761858, 38.611987250191824, 39.95073141370501, 31.038499423435756, 41.331136975969585, 25.274629967553274, 48.51900325502668, 57.635064125061035, 27.216312749045237, 10.453518748283386, 34.464034284864155, 59.49782752990723, 60.17369965144566, 58.78151689256941, 60.756910596575054, 58.5071325302124, 61.12253870282854, 56.281419549669536, 48.79313748223441, 46.802999700818745, 49.96534027372088, 50.465315273829866, 50.455987317221506, 53.040675503867014, 54.89343350274222, 54.778308800288606, 54.78520488739014, 51.81085130146572, 45.588048117501394, 42.6411885534014, 41.738905906677246, 40.00883572442191, 42.10191106796265, 40.52340541567121, 44.62012931278774, 41.57041903904506, 42.089011737278526, 42.21391602924892, 44.189136028289795, 44.36777768816267, 45.10094812938145, 48.11523996080671, 46.48231949125017, 48.97885935647147, 47.38798243658883, 46.314916542598176, 48.396610736846924, 45.73920965194702, 46.78001158578055, 43.39696148463658, 42.70874241420201, 45.61683797836304, 46.928411211286274, 43.64547422954014, 48.08387231826782, 37.87021146501814, 27.053134305136545, 17.517355339867727, 16.927378586360387, 25.901998451777867, 24.441283873149327, 33.339131355285645, 38.28971937724522, 31.474953992026194, 27.768109151295253, 25.60485005378723, 18.608670677457535, 10.85781010559627, 8.543742094721113, 6.535661893231528, 3.367862424680165, 2.1290978448731557, 1.088821911386081, 0.8718976857406753, 0.3038396489407335, 1.824710292475564, 6.225825216088976, 12.748234289033071, 22.946594340460642, 29.040636982236588, 27.246394974844797, 39.750637190682546, 45.880567278180806, 48.50936262948172, 44.89107084274292, 34.1795402935573, 39.88804129191807, 42.852545806339805, 41.974171910967144, 42.355117321014404, 42.3254519871303, 42.4008538382394, 40.971029213496614, 40.35990388052804, 39.99517904009138, 38.825109345572336, 39.655940192086355, 38.79812601634434, 38.73547410964966, 39.42977285385132, 38.26288196018764, 38.700569834027974, 39.383730615888325, 41.053052697862896, 41.003376552036826, 40.311572211129324, 40.936798913138254, 41.54752125058855, 39.69790036337716, 40.754009178706575, 40.09393031256539, 40.728054182870046, 39.621338163103374, 42.76673207964216, 44.156208515167236, 45.963025024959016, 44.93000854764666, 46.18364075251988, 46.366204670497346, 45.2745349747794, 44.922330788203645, 43.32804230281285, 42.50859955378941, 45.3046658379691, 44.06826516560146, 50.44195890426636, 58.21439102717808, 58.921974727085654, 59.50312900543213, 59.50117656162807, 60.08951527731759, 51.28619977406093, 6.396503371851785, 5.154089902128492, 51.22605964115688, 49.66616473879133, 31.312157699040004, 16.4603328364236, 47.617735045296804, 55.043135915483745, 34.058262961251394, 22.541767971856252, 23.534125328063965, 26.645394904272898, 42.134932381766184, 38.49637617383684, 33.594561031886506, 54.29018742697579, 64.46957629067558, 6.56057596206665, 0.33113369292446543, 0.14552816030170235, 0.1537814395768302, 0.2176873061273779, 0.2617635024445397, 0.20905406081250735, 0.054581211015049896, 0.0558701730998499, 0.16202118886368616, 0.09602046079401459, 0.20900553198797361, 0.20105459434645517, 0.6435436734131404, 0.5309741709913526, 0.21015811871205056, 0.10511046874203853, 0.23546128666826657, 0.23413743770548276, 0.21284243038722447, 0.2548110969364643, 2.383143527167184, 71.74974591391427, 62.52444199153355, 48.60595996039254, 34.30055359431675, 50.907366616385325, 60.02254853929792, 52.10805702209473, 47.73308556420462, 35.91827835355486, 48.15984739576067, 34.65621450969151, 53.40754038946969, 63.81200572422573, 28.89862969943455, 15.213257993970599, 44.23708207266671, 63.27137334006173, 62.0507207598005, 62.36368152073452, 64.04518032073975, 60.397174562726704, 64.30670356750488, 61.592890058244976, 54.47970649174282, 50.22637019838606, 53.51475804192679, 54.77126680101667, 51.657702582223074, 55.39891495023455, 57.27417816434588, 59.308245931352886, 57.85533939089094, 52.80299500056675, 48.53840262549264, 46.495208399636404, 44.94018071038382, 45.048405851636616, 46.86277505329677, 44.942157472882954, 48.05305010931832, 44.74016639164516, 44.10107108524868, 44.59292016710554, 46.559507029397146, 49.21796771458217, 47.82826893670218, 53.32920639855521, 53.38845368794033, 54.93548747471401, 54.72600276129586, 52.640737192971365, 53.904145513262065, 48.11156783785139, 50.9784049987793, 47.58974770137242, 44.64331892558506, 49.54516186032976, 51.36069141115461, 47.180589130946565, 51.40048721858433, 42.255636487688335, 32.353849002293174, 21.66865907396589, 20.098553793770925, 24.93744257518223, 25.09205562727792, 37.064484460013254, 48.012667179107666, 45.025647027151926, 40.578640120370046, 35.60302816118513, 29.337351117815288, 20.141881023134502, 11.818148425647191, 12.59240790775844, 13.690088663782392, 7.191547955785479, 3.5109794650759016, 2.6734388300350735, 2.0621558598109653, 3.399234626974378, 9.626537203788757, 14.568323595183235, 26.822897059576853, 38.71773188454764, 26.04641502244132, 42.227270466940745, 49.56221273967198, 53.06369488579886, 47.52557066508702, 40.879670824323384, 42.963407788957866, 46.24465635844639, 41.91978488649641, 43.8152117729187, 45.69473075866699, 46.19737039293562, 42.00888858522688, 45.95147017070225, 43.08917018345424, 41.43481452124459, 41.906781332833425, 44.257978779929026, 41.39541128703526, 44.903132915496826, 42.08321346555437, 42.261063030787874, 43.20984302248274, 46.89959703172956, 43.92182840619768, 44.202160426548545, 47.24421378544399, 45.57652800423758, 43.77722944532122, 44.34879868371146, 42.50443410873413, 42.11840956551688, 40.82530811854771, 45.082146303994314, 46.05294861112322, 49.4245411327907, 46.74709102085659, 48.859576157161165, 46.565697874341694, 46.56411715916225, 44.908406598227366, 44.57887438365391, 41.48298290797642, 46.973181928907124, 43.77162224905831, 52.62202916826521, 61.15373611450195, 62.0684039252145, 60.50460066114153, 63.31110313960484, 59.365012713841026, 57.87494025911604, 8.626315355300903, 5.0301097205707, 52.9881922858102, 53.54667111805507, 38.14390100751604, 21.572544642857142, 51.11891494478498, 74.99546486990792, 44.43382031576974, 33.56333582741873, 28.937074082238333, 36.85432924543108, 41.68143735613142, 43.696060589381624, 37.08837931496756, 61.235974993024556, 71.60812773023332, 6.616973187242236, 0.4335048140159675, 0.31118107214570045, 0.27647617725389345, 0.5996660164424351, 0.7887717176760946, 0.574570425919124, 0.3185721369726317, 0.13262565407369817], [0.05504474203501429, 0.03031893613349114, 0.05269360123202205, 0.21430689894727298, 0.34584609631981167, 0.7067339569330215, 0.2811724266835621, 0.11906920293612139, 0.09255361503788403, 0.1090774762311152, 0.08083273683275495, 0.06975458056799003, 5.742558462279184, 52.88498721803938, 43.9757707459586, 31.349695341927664, 24.605039017541067, 33.083434173039024, 36.291601589747835, 15.352036101477486, 33.016293730054585, 71.72234221867153, 26.985637766974314, 17.288809980664933, 36.27543313162667, 58.012062958308626, 42.98160859516689, 8.372548035212926, 11.270718966211591, 50.47885383878435, 55.773245675223215, 57.37867907115391, 53.3156852040972, 61.76846408843994, 57.17681653159005, 57.36713463919503, 45.8547442981175, 43.8050674029759, 48.305363518851145, 48.60674163273403, 47.51188618796212, 48.16705962589809, 52.55926261629377, 54.37539318629673, 54.49701445443289, 53.04541070120675, 45.137481757572715, 40.111752441951204, 40.75512783867972, 38.48102412905012, 39.9812513760158, 41.07880967003958, 42.19143165860857, 43.38665035792759, 42.70867988041469, 44.04473509107317, 41.39922932216099, 42.437422207423616, 41.2372042792184, 44.30637298311506, 41.466908250536235, 44.31754221235003, 43.60964584350586, 45.701946462903706, 45.51946244921003, 45.68126514979771, 40.58850656236921, 40.91472796031407, 38.509042739868164, 41.58796671458653, 41.78976672036307, 42.91516644614083, 41.27982105527605, 33.268874645233154, 20.75585859162467, 15.034435680934362, 14.478360056877136, 10.473234261785235, 14.091110893658229, 25.546565089906963, 40.15929201671055, 41.07258755820138, 29.127974101475306, 18.45038202830723, 11.22286672251565, 17.860804796218872, 12.128871866634913, 8.740658385413033, 9.463616711752755, 7.784772123609271, 3.7633297869137357, 2.0569644698074887, 0.2721577632640089, 0.29147280539785114, 4.350306221417018, 10.035915510995046, 19.341938393456594, 25.96183807509286, 14.551189337457929, 38.44539029257638, 45.1434120450701, 49.07810047694615, 39.46492379052298, 31.14302464893886, 33.89682156699044, 42.18391718183245, 37.716576371874126, 39.39708505358015, 37.83977835518973, 37.38643271582467, 36.968793869018555, 36.41556787490845, 35.91960545948574, 34.192696707589285, 36.03874969482422, 33.71096420288086, 34.31160123007638, 32.085387979234966, 35.77287687574114, 37.15943854195731, 36.83675377709525, 37.703652722494944, 38.18266500745501, 38.94084896360125, 38.25012159347534, 36.94533327647618, 36.97161831174578, 38.29659114565168, 39.38837548664638, 38.92196028573172, 38.34932797295706, 40.431942803519114, 37.12352677753994, 41.56722634179251, 44.4994113104684, 47.28844601767403, 50.96699605669294, 50.37391866956438, 47.22197607585362, 45.94076647077288, 46.44263138089861, 43.29194293703352, 44.791524001530235, 48.851363386426655, 55.82856375830514, 59.057541029793875, 57.50491394315447, 59.714229175022666, 59.211304664611816, 39.139122758592876, 4.334361408438001, 7.6629849672317505, 51.66993488584246, 46.89147458757673, 19.34302752358573, 12.754496353013174, 33.1431747845241, 20.27129817008972, 16.059249809810094, 29.093340805598668, 16.337639808654785, 23.902466705867223, 24.169925451278687, 29.977037021092006, 36.72579799379621, 45.892038754054475, 56.80714109965733, 14.19236525467464, 0.3640790922301156, 0.041193949191698005, 0.06718838826886245, 0.38796637473361834, 0.7655795535870961, 0.2257846716259207, 0.27831826412252014, 0.10908609362585203, 0.07500796153077058, 0.05668912076258233, 0.1535326750682933, 0.08107427494334322, 0.23122103991253035, 0.19520292191633157, 0.2585272161023957, 0.01578597302016403, 0.21048458905092307, 0.13593691853540285, 0.14697280206850596, 0.28082471819860594, 8.656779732022967, 66.52426978519985, 54.07998704910278, 39.33760152544294, 25.863628762108938, 40.261503492082866, 39.77532066617693, 19.720186165400914, 32.035763944898335, 63.96565123966762, 32.84353024618966, 20.79128919328962, 38.79512439455305, 58.64816011701311, 51.51571961811611, 12.371025272778102, 9.274260929652623, 49.60150827680315, 63.01828520638602, 63.48354353223528, 57.57239832196917, 62.468175479343955, 57.252062048230854, 56.51069620677403, 48.09645898001534, 47.803352696555, 49.53285660062517, 48.44271898269653, 48.2907931464059, 52.114727292742046, 54.2347685950143, 55.45418439592634, 53.11976337432861, 53.00175516945975, 47.2021598134722, 44.1910537311009, 43.32877533776419, 42.63395547866821, 42.316315105983186, 43.08596706390381, 45.59008741378784, 42.87739951269967, 43.76826279503958, 45.28653103964669, 45.0985232080732, 43.86743095942906, 44.980890205928254, 46.28422634942191, 45.63831833430699, 46.294568743024556, 46.386382239205496, 46.81366865975516, 48.07672957011631, 46.659321376255576, 44.30132164273943, 42.09537976128714, 43.44327122824532, 45.2268077986581, 47.30938441412789, 46.78008801596505, 47.83374759129116, 35.8043417930603, 28.239881413323538, 22.140097822461808, 26.47114450590951, 24.520427329199656, 23.654270103999547, 35.8563733782087, 42.883152621132986, 43.0110376902989, 38.10337911333357, 26.386612721851893, 14.708174330847603, 21.62827788080488, 11.628587671688624, 9.508829508508954, 12.067511456353323, 9.235385758536202, 2.51879928793226, 0.3603563505624022, 1.411992833018303, 2.7021303304604123, 7.439349378858294, 15.089173589433942, 25.807238919394358, 32.03368990761893, 28.25988527706691, 47.03149815968105, 53.08419554574149, 50.337645598820274, 49.24494062151228, 36.493995666503906, 36.9021953855242, 43.32940762383597, 40.27002893175398, 42.016903332301546, 42.18238510404314, 40.74433381216866, 39.371331555502756, 39.298590864454, 39.07286473682949, 37.82834162030901, 39.46422202246529, 38.28465066637312, 38.403885228293284, 37.677232197352815, 40.11766883305141, 39.7054773739406, 40.385876246861045, 41.43079498835972, 40.45776578358242, 42.410925252096995, 40.027401311056956, 39.42390857424055, 39.993400301252095, 41.89371871948242, 41.02433231898716, 41.4234368460519, 41.281933307647705, 42.699445724487305, 41.70892790385655, 43.15944078990391, 46.88362659726824, 46.57139539718628, 51.237228870391846, 51.174764565059114, 48.339937755039756, 45.18011243002755, 46.889650685446604, 46.29958534240723, 46.175764969417024, 52.60645478112357, 59.821599687848774, 60.434938022068565, 59.90875094277518, 60.463828631809776, 59.45683315822056, 39.94318567003523, 2.699912986585072, 11.326137798173086, 58.57715647561209, 48.18143892288208, 23.802157299859182, 14.47178966658456, 38.43288353511265, 22.506432907921926, 15.503687483923775, 22.195087603160314, 21.66289380618504, 26.490411860602244, 28.49101710319519, 41.36846269880022, 41.87983274459839, 60.01508617401123, 61.11020565032959, 32.788021087646484, 0.31690845053110805, 0.10868379699864558, 0.0775566544117672, 0.0314216674970729, 0.0873939533318792, 0.038050472869404724, 0.07161701670182602, 0.11408621817827225, 0.1780041762228523, 0.14343654896531785, 0.24604605297957147, 0.41695849331361906, 0.5464572544608797, 0.8687027086104665, 0.3028860629669258, 0.2389849733029093, 0.29017854056188036, 0.21657281235924788, 0.27611223821129116, 0.6060981484396117, 9.101617302213397, 77.4472826548985, 58.69533143724714, 42.600572858537944, 33.068471227373394, 48.568175656454905, 49.7804000718253, 21.26403420312064, 38.92744588851929, 80.43630041394914, 33.81579862322126, 28.741087981632777, 48.8477920123509, 65.04774284362793, 54.40835196631295, 12.656111598014832, 14.863690648760114, 59.71405547005789, 63.76685632978167, 65.04982730320522, 62.03836686270577, 69.29216807229179, 61.37149960654122, 62.36342443738665, 53.885649408612935, 52.24295629773821, 54.40883834021432, 51.6254803112575, 50.37541948046003, 55.00630004065377, 58.04285390036446, 58.307420458112446, 60.35529776981899, 55.89166382380894, 48.33915955679757, 46.28908314023699, 46.89736665998186, 45.39915091650826, 44.42372110911778, 45.86800493512835, 50.431005069187705, 46.59522077015468, 45.696679728371755, 49.07607160295759, 46.96798815046038, 48.84323746817452, 47.87741354533604, 51.05256312234061, 51.294579301561626, 56.73048162460327, 51.619140080043245, 53.14271674837385, 54.46081781387329, 50.602406706128804, 47.038738182612825, 43.57351173673357, 43.85765831811087, 48.9467899458749, 50.6712772505624, 50.6218512398856, 49.9634816305978, 41.32326119286673, 30.858151980808803, 24.67517066001892, 27.818641662597656, 22.16146179607936, 20.51159119606018, 38.477167878832134, 48.23288338524954, 51.9354498726981, 50.57782397951399, 33.52817794254848, 14.988598414829799, 25.654972621372767, 17.258255277361187, 12.911073139735631, 19.447134120123728, 16.93717380932399, 6.99535254069737, 5.619117200374603, 3.0003272550446645, 3.3507709418024336, 9.46695966379983, 18.480980157852173, 27.756823539733887, 31.558895179203578, 26.553588356290543, 48.023332663944785, 55.443435532706125, 55.01567663465227, 50.47071402413504, 46.388386794498985, 39.147071497780935, 45.80995621000017, 39.2349523135594, 44.21068239212036, 43.37943812779018, 45.58739151273455, 41.59620380401611, 42.94458164487566, 42.669509410858154, 38.46677337374006, 41.282645498003276, 41.10672753197806, 41.59925058909825, 39.77240242276873, 43.968700953892295, 41.93073524747576, 42.414027622767854, 45.266402108328684, 46.689083984919954, 47.83469949449812, 43.485808100019185, 42.721474988119944, 42.154338700430735, 44.825396469661165, 43.804125922066824, 43.64930616106306, 43.32013872691563, 44.92535672869001, 42.44399520329067, 45.87555415289742, 48.92387478692191, 51.23225743430001, 55.264067786080496, 52.67072214399065, 47.288748264312744, 46.075908933367046, 48.478950364249094, 47.270474502018516, 46.345325333731516, 52.122377259390696, 60.546192577907014, 62.71687235151018, 60.957803862435476, 62.62180015019008, 62.222626141139436, 46.61467225211007, 4.75744720867702, 10.135015061923436, 63.66778891427176, 52.10857118879046, 32.51328236716134, 19.368506567818777, 43.350877557482036, 25.77627600942339, 22.08249204499381, 41.26824535642351, 24.444275072642736, 34.11308772223336, 31.341750076838903, 40.24378211157662, 45.860549518040244, 53.48982095718384, 72.55297156742641, 35.13931580952236, 0.48014451563358307, 0.2389760980648654, 0.19784429589552538, 0.6266479343175888, 0.9112902262381145, 0.4320355957107884, 0.35092547376241, 0.16082012759787695], [0.1386830447507756, 0.03765811678022146, 0.2657922905470644, 0.4072427675127983, 0.5687092947108405, 0.638252891600132, 0.3918298174227987, 0.09480939792203051, 0.07775252711560045, 0.32324121786015375, 0.045315845869481564, 0.19411639736167022, 10.920548864773341, 62.177073751177105, 38.06237779344831, 39.4978790964399, 32.12826878683907, 36.71891232899257, 25.705154248646327, 23.17306739943368, 49.45872279575893, 81.45669201442173, 29.026737110955374, 14.549765825271606, 30.893983840942383, 47.90269456590925, 51.819929122924805, 31.951899187905447, 1.1156368553638458, 13.89684099810464, 47.53168855394636, 53.087033884865896, 49.88825001035418, 57.93143606185913, 58.61754635402134, 54.282568727220806, 45.31253467287336, 43.51688044411795, 50.47729744229998, 50.19422435760498, 50.1708471434457, 50.54373264312744, 53.33823210852486, 53.908165046146934, 51.21724237714495, 54.98196050098964, 48.49537590571812, 40.97522939954485, 40.01738895688738, 38.90043476649693, 39.68642888750349, 39.622220584324424, 39.17863021578108, 41.74342223576137, 42.86250952311924, 40.70523977279663, 41.77740240097046, 42.76544318880354, 44.245371273585725, 45.22180509567261, 42.97409411839077, 42.920092718941824, 43.62250695909773, 44.695388725825715, 44.12784596851894, 45.32009431294033, 43.065702642713276, 39.869291578020366, 41.5954464503697, 42.91486419950213, 43.65235294614519, 46.57017251423427, 44.87250525610787, 29.731970582689556, 22.3971620627812, 13.815565313611712, 18.49630962099348, 10.887306077139717, 14.869386434555054, 29.5928224836077, 49.80455201012747, 38.37112099783761, 27.498916830335343, 11.962560653686523, 5.297532422201974, 14.02898531300681, 16.64530256816319, 9.778592450278145, 12.718370062964302, 12.810742889131818, 6.1370250667844495, 2.088189022881644, 1.197564150605883, 0.6938982999750546, 1.5829241637672697, 4.380345455237797, 11.251713906015668, 19.23049102510725, 24.717179468699864, 35.63723414284842, 54.01535837990897, 45.09967313494001, 47.79039430618286, 33.06659173965454, 34.622348989759175, 40.83929136821202, 43.00893586022513, 39.28101887021746, 39.32250656400408, 34.71761574063982, 37.71201140539986, 36.921869209834504, 35.298252378191265, 34.38603728158133, 34.40675333568028, 34.68701934814453, 32.07323905399868, 33.67599391937256, 33.5888808795384, 36.61088868549892, 36.46508073806763, 37.63134976795742, 38.236190455300466, 37.84647641863142, 36.044568811144146, 37.87819147109985, 37.54591819218227, 37.55107722963606, 38.21213231767927, 39.63473081588745, 39.579311983925955, 39.959784916469026, 40.38164826801845, 40.09476062229702, 43.193976811000276, 45.84204299109322, 50.81458732060024, 50.69937229156494, 51.56407560620989, 47.205175331660676, 47.386318343026296, 46.07643699645996, 46.036137444632395, 53.10405697141375, 57.80360657828194, 59.32449081965855, 60.215930802481516, 58.718691280909944, 60.91264057159424, 22.967897517340525, 0.7981815327491079, 20.81166304860796, 48.8837628364563, 45.808285168239046, 12.66376417023795, 19.613621643611364, 42.04309804098946, 32.41327347074236, 11.147002816200256, 28.82066743714469, 14.733384132385254, 21.426239899226598, 34.05760635648455, 32.66167157036917, 26.691456249782018, 39.5829632622855, 54.42610808781215, 48.138307980128694, 2.7196938565799167, 0.2641064024397305, 0.15026835165917873, 0.5327332051736968, 0.24435370521886007, 0.4456607960164547, 0.4430693079318319, 0.07631655024098498, 0.05865011750055211, 0.030806209093758037, 0.05058801546692848, 0.07861545402556658, 0.325492081365415, 0.03602120533053364, 0.24543363441314014, 0.05619883510683264, 0.04911768775699394, 0.1448356881737709, 0.06275665214551346, 0.29673014900514055, 17.76908162661961, 70.89403356824602, 46.86309814453125, 46.873701095581055, 31.244690690721782, 41.55559853145054, 32.62993567330496, 24.831107343946183, 36.336441789354595, 74.40776538848877, 38.55964299610683, 24.735380274908884, 33.21667282921927, 53.933800424848286, 55.679062843322754, 41.09189312798636, 1.9699860513210297, 8.720510346548897, 42.32041106905256, 54.34917068481445, 55.08281707763672, 59.692585536411826, 58.45543793269566, 54.1034893308367, 48.84057978221348, 49.5062380518232, 53.67360775811331, 53.51934732709612, 51.59187534877232, 52.889013699122835, 55.25221068518502, 55.18211725779942, 52.220124517168315, 52.55746303285871, 48.83994402204241, 43.901560510907856, 41.99248736245291, 41.5629358291626, 42.48684821810041, 41.81698281424386, 41.105077334812705, 42.525865827287944, 42.19154977798462, 43.13322523662022, 45.07406554903303, 45.65348277773176, 45.18889842714582, 46.67010498046875, 44.94522162846157, 46.89121750422886, 45.32894284384591, 48.765396799360005, 46.32440430777413, 46.195251192365376, 45.02060958317348, 43.19608906337193, 44.30070325306484, 46.36853926522391, 49.63752773829869, 51.74736908503941, 46.579691546303884, 32.17091335569109, 30.75051048823765, 28.442699330193655, 31.30572714124407, 24.297325883592876, 28.307171242577688, 37.03724752153669, 47.06349808829171, 43.789069175720215, 34.24008689607893, 11.934781755719866, 7.024737775325775, 18.400646822793142, 15.973304067339216, 10.881487829344612, 15.839846542903356, 13.031256999288287, 5.760459627423968, 1.2950504166739327, 0.653633109160832, 0.6894651864256177, 2.739309706858226, 9.181829043797084, 17.18225588117327, 27.062653337206157, 29.242643696921213, 46.587751456669395, 55.60942799704415, 48.59852886199951, 52.8296274457659, 40.069298948560444, 34.636273179735454, 42.364386217934744, 44.57681771687099, 40.30842815126692, 43.401366642543245, 39.59306246893746, 41.098226411002024, 39.32876341683524, 40.216395786830354, 39.30901663643973, 38.10588046482631, 37.535151958465576, 37.305875301361084, 38.245115416390554, 36.371669156210764, 39.61737074170794, 39.487918853759766, 41.3126790864127, 41.873961516789024, 41.366249697549, 38.601210594177246, 39.11387300491333, 40.00121702466692, 39.51552057266235, 41.68796866280692, 41.94861643654959, 41.902032239096506, 42.38766268321446, 41.809548241751536, 43.370600019182476, 47.96774707521711, 47.83332027707781, 51.69377415520804, 52.92336559295654, 50.7005534853254, 49.22633334568569, 49.11329657690865, 47.87308481761387, 46.711561407361714, 54.281540393829346, 58.687556403023855, 60.92637021200997, 61.577694347926546, 57.34101288659232, 60.44408185141427, 20.169963904789515, 0.5548272281885147, 26.534051758902415, 57.248931884765625, 49.56113576889038, 16.329869985580444, 20.42254481996809, 42.762705598558696, 34.614775453295024, 12.49801402432578, 23.551917927605764, 16.575042384011404, 27.640997069222585, 31.37029675074986, 44.75275305339268, 29.71841812133789, 51.74393320083618, 59.23497717721121, 66.9350333895002, 14.158379009791783, 0.2637278341821262, 0.33619301287191256, 0.24106262038861, 0.10974110383540392, 0.04246972734108567, 0.1812681332230568, 0.019329946155526807, 0.2464414489056383, 0.08070036822131701, 0.49848276589597973, 0.5009872657912118, 0.763699577323028, 0.790963602917535, 0.4320420282227652, 0.20413149281271867, 0.28700332237141474, 0.561979312981878, 0.19333551212080888, 0.44810561197144644, 22.127365248543875, 83.94282695225307, 50.963987486703054, 49.9643223626273, 43.90158830370222, 51.53786352702549, 37.93462821415493, 30.962215151105607, 58.00026491710118, 85.96257100786481, 35.789344106401714, 25.993030275617325, 41.7347126688276, 56.354865482875276, 63.72653593335833, 39.38713870729719, 2.8705518415996005, 17.53453823498317, 54.76656287057059, 59.3476630619594, 58.41852910178048, 65.91440555027553, 62.64924553462437, 58.9680551801409, 52.07936791011265, 52.3578690801348, 58.411170959472656, 55.53272335869925, 54.04670865195138, 55.68641751153128, 58.989573751177105, 59.19447612762451, 56.090389251708984, 56.17784970147269, 51.26189497538975, 45.96832650048392, 45.33635309764317, 44.777231557028635, 47.44114310400826, 44.71281828199114, 44.284225600106375, 46.45542301450457, 45.54556335721697, 45.43248837334769, 49.31200463431222, 48.864808150700156, 51.753316743033274, 52.35605212620327, 54.19331911631993, 54.84694310597011, 54.108182838984895, 53.73011745725359, 53.80738489968436, 50.578789779118125, 48.40238468987601, 45.73230314254761, 45.852840491703574, 47.75027193341936, 54.86969150815691, 54.70601279394967, 49.45074278967721, 37.34495891843523, 33.31708819525582, 26.083778960364207, 33.25449187414986, 20.82192553792681, 28.06499525478908, 41.81327942439488, 52.17615284238543, 53.57944924490792, 43.7225957598005, 16.40853575297764, 11.926735741751534, 19.12539952141898, 26.38895426477705, 13.359218052455358, 18.96343527521406, 22.734974793025426, 15.820125818252563, 7.882162417684283, 2.598782173224858, 1.9946727837835039, 5.066089229924338, 10.85594277722495, 18.826666934149607, 29.246138640812465, 35.49295479910714, 41.5899087360927, 56.98826674052647, 52.8394660949707, 55.05974211011614, 48.41671534946987, 39.47575603212629, 44.33621897016253, 46.28211062295096, 42.00929158074515, 45.587954316820415, 42.46616343089512, 42.85115269252232, 41.85754987171718, 44.209973675864084, 41.56419345310756, 37.177034854888916, 39.66043220247541, 38.269468852451865, 41.4411165373666, 39.574337073734824, 42.6288937159947, 41.787456444331575, 44.94958162307739, 44.623975140707834, 44.91584464481899, 41.490601607731406, 42.40766307285854, 40.094639028821675, 44.614070483616416, 42.71694128853934, 42.422827516283306, 42.19542687279837, 42.28343970435006, 42.885296140398296, 45.16511126926967, 50.769118309020996, 51.66637045996529, 55.59279400961739, 53.226303577423096, 51.72650017057146, 49.523264612470356, 48.55306679861886, 47.22132641928536, 47.4162893976484, 56.745920521872385, 60.69833728245327, 64.2170023236956, 62.852612359183176, 60.190889494759695, 62.562622342790874, 32.886053221566335, 0.5999292880296707, 25.604570388793945, 60.288727079119, 56.5516037259783, 22.577264581407817, 27.7334497996739, 47.87226840427944, 37.85153470720564, 17.183477027075632, 40.68258169719151, 22.332694939204625, 33.60906539644514, 48.506920337677, 44.29383148465838, 35.05798019681658, 50.11926024300711, 64.79067339215959, 71.0805093220302, 14.489919253758021, 0.4733371266296932, 0.6394333254013742, 0.5329725380454744, 1.064995127064841, 0.6482396785702024, 0.42072281560727526, 0.1175493523478508], [0.042076780926436186, 0.027613174270040224, 0.12583825471145765, 0.5776172652840614, 0.5745454558304378, 0.6625450966613633, 0.5761118946330888, 0.07059001323900052, 0.09124720442507948, 0.1048197504132986, 0.1665701690529074, 0.0502874380243676, 27.374834162848337, 54.25765248707363, 37.411119665418354, 33.00020865031651, 35.146402972085134, 38.3685918535505, 24.02917058127267, 31.7694707598005, 45.05445425851004, 63.3188225882394, 26.97672496523176, 9.75133466720581, 23.932814700262888, 45.69799641200474, 48.33785676956177, 48.924996920994346, 10.680187225341797, 0.572723779295172, 3.4959689676761627, 35.58784982136318, 57.713047231946675, 48.11813735961914, 57.950922284807476, 47.00700923374721, 49.39126968383789, 49.21158926827567, 54.8588662147522, 49.46181127003261, 54.74386657987322, 50.10983848571777, 51.070055212293354, 52.99868059158325, 51.558694226401194, 53.57571806226458, 49.223415102277485, 39.335871423993794, 42.620931080409456, 40.7517614364624, 40.68603842599051, 38.77428674697876, 41.22334609712873, 41.579997130802695, 43.014035837990896, 40.742707933698384, 43.88340139389038, 40.429681164877756, 41.32786437443325, 43.514886311122346, 42.55085849761963, 39.717150347573416, 41.89137370245797, 47.164750712258474, 44.65807689939226, 45.01548876081194, 43.73548466818673, 39.544341700417654, 43.345867906297954, 47.73787634713309, 47.53652102606637, 46.13480186462402, 42.18473359516689, 26.061358860560826, 20.99412795475551, 17.09552846636091, 20.309231860297068, 10.690532224518911, 17.760062864848546, 38.65276275362287, 49.1746734891619, 37.05819286618914, 23.601665292467388, 10.3290547983987, 11.631049071039472, 13.151486022131783, 21.744370119912283, 9.967612981796265, 12.201332892690386, 12.53670767375401, 7.163766452244349, 1.5423994468791145, 2.646884334938867, 0.6612667909690312, 1.7058690637350082, 2.762671938964299, 8.814624564988272, 24.16736330304827, 33.17578962871006, 29.016672645296367, 52.14782851082938, 47.05039725984846, 46.209929261888774, 36.89422927583967, 30.06989622116089, 42.45476838520595, 42.90911109106881, 40.10197285243443, 40.69595350537981, 39.55550398145403, 40.330773557935444, 36.64559146336147, 35.045987606048584, 35.05015999930245, 36.295881680079866, 34.28131055831909, 34.24091025761196, 33.56479147502354, 35.333368573869976, 37.60035732814244, 38.55186448778425, 37.59960344859532, 36.3271416255406, 37.748756953648154, 37.92153780800955, 35.61200523376465, 39.36780187061855, 35.74207203728812, 36.87909262520926, 40.632311480385916, 39.6144038609096, 39.124072960444856, 40.3674669946943, 42.408010482788086, 44.229918479919434, 46.079268387385774, 50.025640215192524, 50.310276644570486, 52.826545919690815, 50.235361167362754, 48.76618194580078, 46.230089460100444, 45.7006402015686, 53.27814061301095, 56.91543919699532, 62.62976278577532, 58.50080966949463, 63.18695272718157, 48.11403097425188, 6.175949309553419, 0.6730466474379811, 35.16444396972656, 43.470671449388774, 45.05244622911726, 8.164485965456281, 21.084013325827463, 45.186410972050254, 29.283954211643763, 6.590194829872676, 20.760479143687657, 18.343164375850133, 14.702094657080513, 27.66361345563616, 27.19531876700265, 31.034566743033274, 24.164978333881923, 52.04532868521554, 57.81022126334054, 38.543995652879985, 0.3572693147829601, 0.1972110734454223, 0.6236392014792987, 0.1289907962616001, 0.7246003268020493, 0.30766324805361883, 0.24070915792669567, 0.04456250575770225, 0.03441326054079192, 0.06335050599383456, 0.18710204160639218, 0.3634743003972939, 0.15447236464491912, 0.009988798826400722, 0.07510548736900091, 0.052356633956411054, 0.035887354120079956, 0.10797925373273236, 0.251017407647201, 43.568978037152974, 66.43154607500348, 48.297192437308176, 40.140764645167756, 39.771919522966655, 41.842545236860005, 31.427490847451345, 27.736242975507462, 35.73060403551374, 65.37318951742989, 30.325631618499756, 15.479238510131836, 28.41867072241647, 46.81563152585711, 55.62789978299822, 54.60402366093227, 17.83614911351885, 0.05048727676538484, 1.1653626156704766, 34.35161937986101, 65.12407575334821, 51.98419148581368, 60.48137978145054, 49.53508349827358, 51.5366267476763, 53.94806160245623, 58.45616054534912, 52.93744264330183, 55.54394817352295, 53.07320696966988, 55.9853081703186, 53.44551229476929, 53.51404932567051, 54.58497517449515, 50.18299954278128, 42.35945299693516, 43.16858809334891, 41.656795569828574, 43.22020626068115, 39.98957879202706, 42.05354118347168, 44.16204152788435, 44.371536663600374, 42.55916506903512, 45.883746079036165, 43.375950132097515, 45.78176042011806, 46.363793645586284, 44.86249985013689, 44.10505240304129, 44.19777263913836, 47.34938866751534, 47.419982365199495, 47.45750263759068, 43.61419691358294, 43.18298476082938, 46.42905807495117, 50.19665275301252, 47.12669195447649, 51.310758181980674, 40.88097708565848, 28.462958540235245, 30.979272978646414, 33.34734065192086, 33.20893948418753, 26.400931222098215, 36.02241447993687, 43.71459490912301, 44.13234492710659, 46.09286948612758, 29.997367450169154, 13.4963025365557, 12.100581407546997, 12.903529133115496, 24.380080665860856, 10.618273564747401, 16.157957656042917, 19.78355721064976, 13.783271823610578, 2.655980612550463, 1.0826132616826465, 0.5628597800220762, 2.844596411500658, 7.041026958397456, 11.593386360577174, 25.889177288327897, 33.0007540839059, 41.07156964710781, 53.72691433770316, 49.76313032422747, 48.819686549050466, 43.870738301958355, 31.36707626070295, 40.65428863252912, 42.87801095417568, 40.7449244090489, 42.95835297448294, 41.77713142122541, 43.26660980497088, 40.42354243142264, 40.44069753374372, 39.59964936120169, 39.92417539869036, 37.665375096457346, 37.579637799944194, 38.67506994519915, 39.29393557139805, 39.25257641928536, 40.75328309195382, 40.239095551627024, 40.65281561442784, 39.9090769631522, 40.8466807774135, 38.230923720768516, 40.80177804401943, 40.34701844624111, 40.31903110231672, 42.30240133830479, 41.48927797589983, 41.7816755431039, 42.43309000560215, 45.515571457999094, 46.88090637751988, 49.82216569355556, 52.22574213572911, 50.79434721810477, 50.78636721202305, 51.092393670763286, 51.04825871331351, 48.19185427256993, 46.42038324901036, 54.130993774959016, 57.86075203759329, 61.18850490025112, 60.38310446058001, 63.56290585654122, 43.73168747765677, 4.979693157332284, 1.1908664128610065, 42.43214505059378, 52.41764095851353, 49.375424316951204, 9.52743331023625, 20.8131708077022, 45.03847687585013, 38.37025247301374, 8.962911282266889, 22.782384089061193, 18.79577350616455, 19.514130387987407, 25.532934461321148, 37.659361430576865, 34.64696298326765, 31.504452569144114, 63.0674159186227, 57.65312944139753, 61.93040575299944, 1.5472363701888492, 0.08528727851808071, 0.14934607329113142, 0.1837381771100419, 0.14878981028284344, 0.13133598970515387, 0.07207405074898686, 0.11183220627052443, 0.15267573962254183, 0.30640616693667, 0.6562303783638137, 0.9512928511415208, 0.9157048293522426, 0.7808703130909375, 0.24824306794575282, 0.14755022179867539, 0.23119292142135756, 0.2998881595475333, 0.2285822443664074, 51.19065856933594, 73.86568777901786, 52.47535964420864, 42.52997916085379, 48.77473865236555, 52.113132681165425, 38.25951208387102, 41.31213712692261, 52.411342416490825, 67.11417879377092, 31.98495176860264, 16.915443318230764, 36.817896366119385, 55.427148955208914, 58.237309660230366, 58.46415792192732, 14.445865937641688, 0.5307353266647884, 5.4450240050043375, 40.28903225490025, 65.44839681897844, 56.36608682359968, 65.61504936218262, 51.74412080219814, 56.59129531042916, 57.84354134968349, 62.40412698473249, 55.67008229664394, 57.549156597682405, 54.671282223292756, 60.391053199768066, 56.00416905539376, 58.08514411108834, 59.62693895612444, 52.725727558135986, 43.7069935798645, 47.323444093976704, 45.084651129586355, 47.282084941864014, 41.9182562828064, 46.03304202216012, 47.84896762030465, 47.490315505436485, 45.61011559622628, 50.16536154065813, 45.579286439078196, 49.76373481750488, 52.483631474631174, 50.44996322904314, 50.288956097194124, 51.702073778424946, 55.31928859438215, 54.63957411902291, 50.14301265989031, 46.58053575243269, 45.480250290461946, 50.01100383486067, 54.2041791507176, 53.11299235480172, 57.154262678963796, 47.1472864151001, 34.67914703914097, 30.311161994934082, 30.174820968082972, 32.33452953611101, 22.47003824370248, 30.331794670649938, 49.82099839619228, 47.13830239432198, 55.417015007564, 46.81191423961094, 32.605988706861226, 40.569541454315186, 28.91192160333906, 28.110344409942627, 15.108600752694265, 16.536679642541067, 22.336523396628245, 21.811517511095317, 7.567154543740409, 5.6602453248841424, 3.978382612977709, 6.971695227282388, 9.446844628879003, 14.530837195260183, 27.525432893208094, 37.093444551740376, 37.29945516586304, 59.7344970703125, 51.418986797332764, 52.86073800495693, 48.19122198649815, 36.126307419368196, 44.01075839996338, 45.79856811250959, 40.71187877655029, 45.71030861990792, 46.325255462101524, 47.29522745949881, 39.84464284351894, 42.393130915505544, 40.68621907915388, 39.88313238961356, 38.14295605250767, 39.43586989811489, 39.738356249673025, 41.15603542327881, 42.94878877912249, 42.43748126711164, 42.99716561181204, 43.39679820196969, 45.04777356556484, 42.5579491342817, 40.825551305498394, 43.76820720945086, 41.65183455603463, 43.070674078805105, 42.2891754422869, 42.107407093048096, 41.8448485646929, 41.81224066870553, 47.74531439372471, 48.677894660404746, 52.84032072339739, 56.66917072023664, 52.37594134466988, 52.81826366697039, 52.766885212489534, 51.38069180079869, 47.08484295436314, 47.13481092453003, 56.01909031186785, 60.50775514330183, 66.01157610757011, 63.05744525364467, 66.11568791525704, 55.816626753125874, 10.23022014754159, 1.0443167452301299, 44.03213105882917, 53.284477370125906, 58.040602684020996, 16.665289061410085, 30.0798008782523, 49.62847423553467, 36.59442492893764, 10.714257717132568, 31.507033824920654, 28.33858057430812, 23.54503399985177, 39.269370215279714, 38.134906564440044, 42.2774156161717, 30.1354490007673, 66.46583543504987, 69.4213559286935, 66.7627944946289, 1.7135431319475174, 0.41981702564018114, 0.5908727454287666, 0.8330912909337452, 1.1010833105870654, 0.33374493994883125, 0.29905049449631144], [0.07143227197229862, 0.2851780360298497, 0.23325015817369732, 0.562186456152371, 0.8857789923037801, 0.5166526851909501, 0.44320192081587656, 0.09217065665870905, 0.14210959231214865, 0.07714089564979076, 0.24454746767878532, 0.43987080241952625, 43.91326822553362, 54.16581467219761, 40.47628273282732, 26.59111383983067, 26.707876580102102, 33.59622859954834, 22.203086716788157, 26.01144995008196, 28.409429618290492, 19.88438946860177, 17.46624960218157, 12.646417992455618, 7.994607721056257, 29.269005162375315, 52.42747265951974, 52.282526288713726, 38.657282556806294, 2.9928062643323625, 0.8959968611598015, 20.102873836244854, 56.41987977709089, 48.248739174434114, 54.230276584625244, 51.92557300840105, 55.67773573739188, 52.465819767543245, 56.67021642412458, 55.44824021203177, 54.687523637499126, 53.252904755728586, 51.993859904153005, 53.44613068444388, 54.50928149904524, 53.43156378609793, 48.91075658798218, 39.97250359398978, 41.678133487701416, 41.39729077475411, 39.73432976858956, 39.85317523138863, 40.89140633174351, 40.133757386888774, 41.463142326899934, 40.281396184648784, 42.55866132463728, 40.454229150499614, 41.81726769038609, 44.884779248918804, 43.958987372262136, 43.369099208286826, 41.23888226917812, 44.75287812096732, 43.127055236271445, 43.11876603535244, 43.563096387045725, 42.95519849232265, 44.91714743205479, 51.801690101623535, 50.00080040522984, 51.568220206669395, 36.195389883858816, 25.8011314528329, 17.264911651611328, 15.209735257284981, 24.59470009803772, 12.217740195138113, 18.554307971681865, 50.33427572250366, 38.074554511478965, 34.27329928534371, 19.970814636775426, 23.96257904597691, 27.789181300571986, 20.375899825777324, 20.76945447921753, 13.729401571410042, 8.946242553847176, 14.687136922563825, 3.3195685361112868, 0.48428613053900854, 2.876012474298477, 1.68002621616636, 4.375657158238547, 6.408361775534494, 5.876588344573975, 15.818819556917463, 31.39557777132307, 27.153848443712505, 49.35706370217459, 45.967141832624165, 43.40083857945034, 40.434412888118196, 29.385224206107004, 39.69333192280361, 43.37873983383179, 42.02370909282139, 41.967414787837434, 41.74644470214844, 41.16416481563023, 39.10276978356497, 38.29503127506801, 37.11741583687918, 36.95658588409424, 33.55416420527867, 34.31139278411865, 34.38656187057495, 36.6303471156529, 36.712575571877615, 36.921716349465505, 35.62267419270107, 36.7905968938555, 36.1464432988848, 35.943955421447754, 36.48263883590698, 37.11054406847273, 37.61030714852469, 36.410266399383545, 39.05244050707136, 38.774470874241416, 38.756273542131694, 40.084835120609824, 41.97465828486851, 43.6515017918178, 44.78846332005092, 47.04007918494088, 52.08864722933088, 49.7885468346732, 49.34357030051095, 48.766414710453574, 48.648052147456575, 45.44524874005999, 53.79650749479021, 56.679728507995605, 58.2803989137922, 61.05477292197091, 58.26471682957241, 27.214905738830566, 2.1905314283711568, 8.864351953778948, 43.72372136797224, 32.793048109327046, 31.372367313929967, 8.101115788732256, 11.56057436125619, 55.236445222582134, 58.17596748897007, 16.807501316070557, 11.320887565612793, 18.7429324558803, 15.04039202417646, 33.63256767817906, 26.504297835486277, 36.95242043903896, 30.642622334616526, 33.48436607633318, 43.32034717287336, 65.05808871132987, 10.951020189693995, 0.32964848833424704, 0.4274948393659932, 0.22792034702641623, 0.7094406059810093, 0.40430571511387825, 0.2685297450848988, 0.0052744100352616185, 0.19209946558943816, 0.10569806649748768, 0.36297983835850445, 0.24847626686096191, 0.20443553078387464, 0.0274159886009459, 0.03544252352522952, 0.013468132171380733, 0.13078879192471504, 0.18956804142466613, 1.1218450708048684, 60.43468788691929, 64.80497278485979, 47.286132267543245, 27.8288676738739, 30.928422587258474, 43.122483321598594, 27.397356748580933, 23.85365734781538, 28.879091364996775, 28.660704272133962, 22.844766753060476, 13.385048849242073, 11.89202948978969, 30.51734631402152, 54.36333111354283, 57.476464544023784, 48.27838018962315, 7.607198749269758, 0.2245591152459383, 21.62868435042245, 63.314702306474956, 53.68050731931414, 58.548870359148296, 55.06322315761021, 59.340443883623394, 57.06950160435268, 59.87662942068917, 58.615600858415874, 55.974281379154746, 53.34409291403634, 55.15381724493844, 55.0919782774789, 54.4808668409075, 52.916076932634624, 49.392523833683555, 42.41123444693429, 43.712270736694336, 43.104966912950786, 43.003815037863596, 44.15909201758248, 42.782007694244385, 43.41783734730312, 42.81395203726632, 42.49298695155552, 45.75285938807896, 43.646078722817556, 45.68381861277989, 45.271349225725444, 46.14643662316458, 47.78527348382132, 46.065969535282676, 46.38835552760533, 47.16468817847115, 45.061593532562256, 46.29772669928414, 44.65170887538365, 46.821606976645334, 51.12665523801531, 50.69851071493966, 50.519942011152, 36.74119520187378, 28.515886443001882, 31.46186705998012, 32.846538816179546, 32.47512286049979, 29.12112144061497, 34.47192396436419, 48.386792932237896, 43.83647673470633, 44.242491245269775, 26.215867689677648, 19.82634769167219, 26.226745094571793, 19.286759274346487, 24.303890194211686, 16.267944165638514, 12.914959788322449, 17.42189403942653, 8.020854541233607, 1.2780989834240504, 2.906795382499695, 1.3766182512044907, 4.18630050761359, 5.308994344302586, 8.02664499623435, 19.33964201382228, 31.273998192378453, 37.05979790006365, 52.79588351930891, 47.90333032608032, 48.352441038404194, 45.478433336530415, 29.539178916386195, 38.52783761705671, 44.18715579169137, 41.59331335340227, 45.634885924203054, 44.07487290246146, 44.159696510859895, 41.577596528189524, 42.41817569732666, 39.14390311922346, 39.94563143593924, 35.63801234109061, 39.95693268094744, 38.42402458190918, 39.780358110155376, 38.59961945669991, 40.28187561035156, 38.85881853103638, 40.05114677974156, 40.82621485846383, 39.941674436841694, 39.29573515483311, 38.416739395686555, 40.59485374178205, 41.10361473900931, 42.00890942982265, 40.205403736659456, 41.46657126290457, 43.784934997558594, 46.797107628413606, 49.74452652250017, 49.73707110541207, 51.46762071337019, 51.85598332541329, 50.14743171419416, 49.91251311983381, 51.29671239852905, 51.710098947797505, 48.66692345482962, 53.6560948235648, 57.086781774248394, 59.21422985621861, 61.06308991568429, 57.62236976623535, 27.26934313774109, 1.6384834796190262, 12.439148885863167, 50.50294671739851, 34.398439816066194, 38.01701300484793, 11.011943731989179, 13.93400604384286, 48.656928471156526, 60.70059544699532, 19.024249383381434, 15.162515299660818, 22.305788040161133, 19.72798899241856, 33.02915831974575, 30.608249596187047, 40.42651973451887, 28.26002597808838, 47.54985114506313, 50.467792306627544, 77.72616944994245, 23.879297937665665, 0.2797009285007204, 0.4793923188533102, 0.052575349541647096, 0.13262611547751085, 0.10126310733280011, 0.0864890454603093, 0.19625900739005633, 0.4597220772079059, 0.3507546457861151, 0.6600726779018129, 1.3058169760874339, 1.1348107350724084, 0.5877593010663986, 0.2552803174725601, 0.21240229186202797, 0.22451233704175266, 0.6627799783434186, 1.1986105058874403, 69.33367661067417, 70.81441416059221, 54.71719591958182, 34.42769520623343, 35.78052336829049, 49.777860505240305, 32.64465890611921, 35.930451597486226, 36.67278323854719, 24.392069782529557, 23.452216488974436, 19.9293304170881, 17.76457745688302, 41.47635432652065, 59.177251543317524, 60.489314624241416, 48.7359607560294, 4.943717122077942, 0.8497800497072083, 26.74998787471226, 64.3621849332537, 57.30960702896118, 59.57939938136509, 58.691252844674246, 62.3065117427281, 58.92419120243618, 64.255113192967, 61.74846717289516, 58.47418417249407, 55.23835597719465, 59.472501346043174, 60.8248222896031, 57.56391109739031, 59.55737359183175, 52.11165966306414, 45.341744899749756, 46.200302532741, 46.39308030264718, 46.70582219532558, 46.55219752447945, 47.210987499782014, 47.36915976660592, 45.90536887305123, 45.666983127593994, 49.842645508902415, 46.32409858703613, 47.85644735608782, 52.89378363745553, 50.52369056429182, 53.821274348667686, 52.02899694442749, 56.22914130347115, 51.07579442432949, 50.43343693869454, 49.72717339651925, 49.04490545817784, 49.29805612564087, 57.73686218261719, 54.628766196114675, 62.48814460209438, 40.82164989198957, 36.04038599559239, 28.45260051318577, 31.832952976226807, 33.75583566938128, 26.588556902749197, 35.19271271569388, 51.80687345777239, 50.18313503265381, 57.24423490251814, 38.49385050364903, 38.60618550436837, 40.60902459280831, 32.4060959815979, 28.623250007629395, 20.316464935030254, 14.713178770882742, 20.191114221300396, 10.517251099858965, 5.0744991557938715, 6.929261709962573, 7.036909282207489, 7.493158834321158, 6.5696611659867425, 7.678929345948355, 18.04958040373666, 35.5978239604405, 39.00259413037981, 58.00199154445103, 52.22451230457851, 51.775457177843364, 49.61682210649763, 37.73326941898891, 41.89953088760376, 48.18144587108067, 43.33396911621094, 50.0793810571943, 47.63601228169033, 49.60166808537075, 41.296906675611226, 43.287617683410645, 39.51464857373919, 40.770757811410085, 33.746285370418, 40.53813559668404, 40.55242109298706, 41.7586214201791, 41.98454557146345, 44.530369009290425, 38.565038272312705, 44.13217469624111, 43.52823380061558, 42.29517868586949, 40.99966968808855, 41.02741731916155, 42.14224188668387, 44.30068588256836, 42.77114765984671, 40.75582960673741, 41.41183335440499, 46.06092166900635, 46.350887366703574, 51.189147336142405, 52.72253138678414, 56.878422669001985, 56.116028104509624, 51.43891770499093, 51.95508548191616, 51.28957659857613, 52.028520992824006, 48.158735683986116, 56.45079926082066, 60.743062836783274, 61.22263445172991, 65.21484701974052, 61.407588550022666, 40.31142977305821, 1.9570076848779405, 10.884417363575526, 53.2530471937997, 39.3197238104684, 43.39132302148001, 15.560292720794678, 18.79150210108076, 57.82952683312552, 64.05463681902204, 20.21422914096287, 17.114931310926163, 28.34982102257865, 24.54702503340585, 49.882271085466655, 35.440242290496826, 51.243624687194824, 38.46992090770176, 47.35575321742466, 55.47868374415806, 87.88561003548759, 24.372776372092112, 0.5050497363720621, 0.9632830534662519, 0.3064829228179795, 0.7783257524882043, 0.36288907751441, 0.40960260374205454], [0.06166533713362046, 0.18997060268052987, 0.30437349315200535, 0.8024207481316158, 0.6461295432278088, 0.6250134791646684, 0.31759941631129807, 0.22900510739002908, 0.2196165168923991, 0.09576647156583411, 0.31299525765436037, 2.071872264146805, 57.886213711329866, 54.30508089065552, 36.49544436591012, 28.01907287325178, 40.13692923954555, 28.594480991363525, 21.896749326160975, 18.872912406921387, 13.31311501775469, 7.920856067112513, 16.17501027243478, 13.701482840946742, 7.153340245996203, 23.37548405783517, 45.42370932442801, 48.08317402430943, 49.3634386743818, 28.760287591389247, 0.47168112120458056, 6.996617112840925, 52.217234066554475, 50.48976251057216, 55.8326666695731, 57.31960201263428, 59.59783295222691, 61.96131828853062, 56.514510767800466, 58.09698036738804, 53.12734038489205, 55.76740224020821, 50.68221718924386, 53.29756430217198, 54.34856966563633, 50.333712918417795, 49.4817248071943, 38.80241652897426, 43.27363443374634, 41.01436512810843, 42.49196556636265, 38.70852204731533, 39.190733977726524, 41.17983995165144, 39.33208812986101, 41.644184589385986, 43.139978885650635, 40.023628439222065, 43.23491907119751, 41.66483463559832, 43.200588021959575, 41.76201908929007, 43.666058267865864, 43.75150721413748, 47.427475997379844, 45.85861097063337, 42.390369006565635, 43.30683987481253, 48.624035699026926, 53.11790820530483, 52.29793391908918, 47.66683449063982, 31.13741397857666, 23.730424097606114, 10.950156007494245, 16.62618981088911, 21.993779182434082, 14.878662279673986, 23.939446755817958, 45.65719658987862, 21.60690348488944, 18.158863408224924, 10.193125452314105, 23.273163148335048, 29.640785898481095, 26.16140076092311, 17.286258254732402, 14.00209925855909, 11.416850004877363, 9.704524653298513, 3.108316157545362, 2.9549179545470645, 1.989414083106177, 2.745300356830869, 4.27599219764982, 3.6666056513786316, 2.1935252334390367, 7.64521929195949, 23.228097132274083, 23.330607380185807, 45.3031268119812, 42.70262105124337, 35.49707855497088, 35.15046419416155, 25.75052945954459, 35.423066343579976, 41.35894019263131, 43.58703293119158, 41.63125399180821, 44.80659464427403, 42.07139457975115, 42.46658032281058, 43.95966134752546, 40.44527987071446, 37.60592630931309, 36.477486746651785, 37.645392077309744, 36.49982867922102, 36.69231115068708, 34.27346951620919, 37.81838485172817, 36.04201534816197, 33.709546770368306, 37.706362519945415, 37.144576345171245, 39.08820635931832, 39.099632671901155, 35.73926149095808, 38.57885823931013, 37.803599085126606, 40.025386333465576, 40.15838180269514, 42.10612167630877, 44.80118547167097, 46.6221832547869, 47.00623798370361, 48.877808230263845, 48.715435777391704, 49.71958943775722, 52.13849013192313, 51.815471853528706, 50.673365184238975, 50.33333771569388, 48.665297576359336, 56.57014846801758, 60.705709321158274, 60.54383713858468, 55.94359813417707, 15.35507767541068, 0.9397457050425666, 30.047217300959996, 47.12095969063895, 35.97959968021938, 40.2311954498291, 9.102119309561592, 10.122521332332067, 45.674977030072895, 59.6000702721732, 42.48495830808367, 13.597174746649605, 14.196713089942932, 10.9634096963065, 28.207402059010096, 21.814904757908412, 32.797144072396414, 26.015182869774954, 28.741419758115494, 56.83874498094831, 57.21562222072056, 44.89741454805647, 1.0373583414724894, 0.2763168572315148, 0.6184428717408861, 0.8529835492372513, 0.596711132143225, 0.07508187435035195, 0.028067215977768813, 0.08547452704182693, 0.14358380463506493, 0.5803066524011748, 0.07040267650570188, 0.13621327227779798, 0.07081887631544045, 0.10891092981078795, 0.14888131751545838, 0.13142190580921514, 0.18292941765061446, 4.973760264260428, 73.83473355429513, 59.0964162009103, 46.92722306932722, 30.07991204942976, 40.68713276726859, 40.57860190527779, 28.274478231157573, 22.333660738808767, 22.750660351344518, 14.893719026020594, 22.06908028466361, 21.108545678002493, 7.8690937246595105, 27.725888422557286, 48.758663994925364, 55.48073346274239, 55.76897948128836, 40.000063623700825, 1.076558340873037, 5.722208925655909, 55.41933223179409, 55.797039781297954, 59.59789548601423, 57.91044902801514, 61.48303209032331, 62.6148658479963, 59.98447241101946, 58.97822734287807, 54.307453700474326, 54.126946449279785, 54.38021523611886, 58.171861103602815, 52.9814247403826, 50.9459673336574, 47.60855647495815, 42.0063351222447, 42.94262572697231, 42.911108698163716, 44.95077671323504, 42.915333202907014, 41.884039878845215, 46.41325787135533, 42.4322840145656, 43.60721049989973, 46.055613245282856, 44.642634528023855, 44.5175495828901, 45.68049737385341, 45.22234010696411, 45.838617529187886, 48.96853085926601, 48.7580178124564, 48.55253873552595, 48.80148574284145, 47.05672012056623, 45.005142893110005, 48.11114052363804, 50.409559454236714, 50.05982535226004, 50.51078428540911, 31.135843685695104, 29.219370705740793, 27.57050585746765, 27.165144477571758, 29.35034077508109, 34.27244118281773, 40.61758477347237, 42.88666493552071, 32.64371395111084, 33.331113134111675, 19.716663428715297, 28.389265945979528, 39.09018659591675, 27.79814621380397, 23.903939723968506, 19.534163781574794, 12.822425416537694, 17.233585698263987, 4.408407492297036, 3.497168834720339, 4.050250436578478, 2.6644708769662038, 4.760092735290527, 3.870872267654964, 1.686357545001166, 9.55364625794547, 28.789555140904017, 34.79171827861241, 44.43435532706124, 42.433305399758474, 41.94808142525809, 43.137689454214915, 30.721039703914098, 31.45720134462629, 45.677273409707205, 41.331668513161794, 44.41395889009748, 43.31275626591274, 44.604860646384104, 44.02358130046299, 46.75855902263096, 42.77232885360718, 41.498018809727256, 38.753393513815745, 38.531784193856375, 38.594710554395405, 41.84145436968122, 38.63454805101667, 39.66938843045916, 38.30909095491682, 38.63891499383109, 38.85022708347866, 40.60331664766584, 40.77502053124564, 40.95661864961897, 39.43246875490461, 43.37702710287911, 40.44048908778599, 41.5916040965489, 42.08753177097866, 47.26784808295113, 48.00764710562569, 51.638331004551475, 50.683526924678254, 54.407681465148926, 51.97367191314697, 51.13758128029959, 52.040343352726524, 53.222846848624094, 52.21789067132132, 51.353395802634104, 47.75940534046718, 56.939966338021414, 60.810119901384624, 60.171476227896555, 58.01937941142491, 13.606320313044957, 1.5256427803209849, 37.19831371307373, 52.74327175957816, 40.63251992634365, 45.390149525233674, 10.43546211719513, 11.667879734720502, 43.67611231122698, 56.32144464765276, 36.95035334995815, 15.341410568782262, 19.78690276827131, 13.23931212084634, 31.789756025586808, 20.733263049806865, 42.779238837105886, 27.222852740968975, 32.57965850830078, 64.63608292170933, 61.39171191624233, 64.33751882825578, 1.6598778516054153, 0.09974945855459996, 0.15591239237359591, 0.12457856802003724, 0.1083452623071415, 0.06515713262238673, 0.10228101164102554, 0.2513150673891817, 0.5542460765157426, 1.0730428780828203, 0.6326039518628801, 0.7521468943783215, 0.477873648915972, 0.4421220730457987, 0.38223834495459286, 0.23115777330739157, 0.9537006190844944, 5.328850558825901, 82.43069049290249, 68.20307268415178, 45.52585826601301, 37.43781811850411, 54.528666973114014, 42.532820974077495, 33.90708405630929, 28.81898249898638, 21.35266716139657, 10.2904132604599, 22.07737990788051, 19.928017207554408, 15.290327412741524, 36.422846112932476, 55.50660508019583, 58.76939228602818, 58.0671170098441, 37.36033875601632, 0.8483509463923318, 9.096532089369637, 58.76579311915806, 58.72835622514997, 64.9893501826695, 60.96987983158657, 66.7581114087786, 64.46432345254081, 64.7439328602382, 62.88414328438895, 55.15427930014474, 55.80194868360247, 56.3135792868478, 62.9033967426845, 56.47494772502354, 58.414221218654085, 53.59815379551479, 44.760833808353965, 46.71921137401036, 47.34897872379848, 48.01025268009731, 44.29621124267578, 44.97261837550572, 48.798633507319856, 43.51114123208182, 45.20808587755476, 48.078188691820415, 45.97706733431135, 47.942570277622764, 50.59019872120449, 50.43404838017055, 51.92959948948452, 56.11325577327183, 56.786668232509065, 55.764515263693674, 54.76341186250959, 50.174838883536204, 47.38058955328805, 52.03487859453474, 59.31713267735073, 56.29002489362444, 61.655993597848074, 38.39893116269793, 37.39523260934012, 28.366376842771256, 27.747314929962158, 32.82419340951102, 29.99262877873012, 45.78414365223476, 45.87794433321272, 33.12628371374947, 36.01490000316075, 30.7552387373788, 41.00334528514317, 44.03388547897339, 37.07270417894636, 31.51461430958339, 22.461641345705303, 14.571193201201302, 21.99704483577183, 8.103913307189941, 7.487914681434631, 7.411494919231959, 5.274850027901786, 4.711480966636112, 2.103029723678316, 1.0115489321095603, 10.995442628860474, 32.801733357565745, 38.166628565107075, 49.45064204079764, 48.069982869284495, 46.28616142272949, 45.87644352231707, 37.01820598329817, 38.54556941986084, 48.04732826777867, 42.56821162360055, 48.4143043245588, 49.075550488063264, 49.370675223214285, 45.96997322354998, 48.756864411490305, 43.02692822047642, 42.300167492457796, 38.436830111912315, 38.75562388556344, 39.81982735225132, 42.83682203292847, 41.33430882862636, 43.18959249768938, 41.114071777888704, 41.66840948377337, 43.19308396748134, 42.87652751377651, 43.99198089327131, 45.16526065553938, 40.33187484741211, 45.51196881702968, 42.99073505401611, 40.846656458718435, 42.741524015154155, 47.30969360896519, 47.61407681873867, 51.325648171561106, 52.75187015533447, 58.82091317858015, 54.79881293433053, 51.68684332711356, 52.40243135179792, 53.70111567633492, 51.487082617623464, 52.43310764857701, 48.72092138017927, 60.83484854016985, 65.69627380371094, 65.16036619458879, 64.74174417768205, 22.82492617198399, 1.7164351024797984, 34.63639824731009, 57.478291920253206, 43.24626547949654, 51.53781836373465, 17.024391072137014, 16.089783668518066, 48.926772185734336, 59.54013511112758, 43.67781114578247, 19.302500418254308, 20.377339839935303, 16.41328658376421, 40.47685943331037, 28.147607598985942, 45.774652412959504, 35.14141763959612, 34.17050068719046, 70.78601687295097, 72.51119899749756, 69.18386650085449, 2.032605388334819, 0.39715251752308434, 0.937778713447707, 1.0680780644927705, 0.5350369672690118, 0.17214848686541828], [0.03361355273851326, 0.26682673075369423, 0.20262404584458896, 0.8813578209706715, 0.7708288090569633, 0.504302262195519, 0.44881060985582216, 0.15595048532954284, 0.47005410279546467, 0.2853117345699242, 0.7223227290170533, 6.934140648160662, 65.25895418439592, 51.68616587775094, 28.539711815970286, 22.06745788029262, 38.727685179029194, 22.372409105300903, 21.54410740307399, 13.781171730586461, 12.795364788600377, 13.814281633922032, 20.302151645932877, 7.421922428267343, 6.275483122893742, 15.523858104433332, 46.90915427889143, 53.340969698769705, 46.84851387568882, 52.0157710484096, 16.94295471055167, 0.28574141008513315, 28.88704357828413, 57.5311017036438, 59.57698835645403, 61.46523775373186, 70.06571796962193, 67.92360224042619, 57.59817613874163, 60.407833099365234, 55.846639496939524, 55.78202472414289, 53.237354687282014, 51.20446463993618, 52.35511064529419, 46.88796574728829, 45.39568723951067, 40.636171204703196, 42.169739382607595, 40.719546113695415, 43.09799786976406, 38.10529334204537, 38.2722932951791, 39.06690665653774, 38.43714278084891, 42.085548060280935, 43.38584089279175, 42.03156055722918, 41.63473503930228, 42.01242174421038, 41.82869400296892, 40.99633802686419, 44.6955554825919, 42.913557938167024, 46.18196276256016, 43.50321681158883, 46.47729246956961, 48.73935842514038, 48.241467884608674, 50.71736117771694, 52.107428210122244, 44.26127917425973, 25.259665284837993, 17.405864545277186, 8.830678377832685, 16.305236884525844, 22.55114803995405, 15.609908069883074, 27.264611414500646, 46.49767848423549, 16.59240766933986, 3.4900197897638594, 2.438878502164568, 4.5475951092583795, 6.921150990894862, 7.209001396383558, 5.537431137902396, 8.318037680217198, 14.222714117595128, 9.32463276386261, 2.0354639206613814, 0.48411334838185993, 2.5355144824300493, 0.979427192892347, 0.13431546411343984, 0.5972712763718196, 1.3840249223368508, 5.929760302816119, 24.939963034221105, 27.21758426938738, 44.33858830588204, 37.92684275763375, 28.954156228474208, 27.08036082131522, 23.470601422446116, 26.743628535951885, 41.256336144038606, 46.307600089481895, 43.50166041510445, 46.15148101534162, 44.78760869162423, 44.21275642939976, 42.78520733969552, 43.069652693612234, 36.22854321343558, 39.990218026297434, 38.591080120631624, 37.4839437348502, 36.37081452778408, 35.045198985508506, 36.97742005756923, 36.226354530879426, 36.8712272644043, 37.57943630218506, 38.333208152226035, 37.36917686462402, 35.92898552758353, 37.69610003062657, 38.63488156454903, 39.79843732288906, 41.28791223253523, 40.68008034569876, 49.7123806817191, 47.521735259464805, 51.26628623689924, 49.66865914208548, 50.49441432952881, 48.18424946921212, 52.63599852153233, 53.718441009521484, 53.05765690122332, 51.15619203022548, 52.20972653797695, 50.70559092930385, 56.33253744670323, 56.65152924401419, 61.676803452628, 45.57448870795113, 3.811320560319083, 5.15398394209998, 55.1016640663147, 39.27865300859724, 53.85513292040144, 38.75421340124947, 3.338762717587607, 12.214616111346654, 43.51918377195086, 60.046464238848, 52.65327174322945, 23.044470139912196, 18.92305929320199, 10.598822951316833, 23.147180148533412, 32.123589175088064, 31.368417263031006, 57.47555433000837, 33.01148905072893, 44.60775804519653, 54.13045876366751, 65.53788961683, 7.422151718820844, 0.15158840082585812, 0.8925889325993401, 0.7231888111148561, 0.3991721362939903, 0.16520203889480659, 0.05499906984290906, 0.021562197445226566, 0.040962293943656344, 0.16974426087524208, 0.09334939412240471, 0.1870216623480831, 0.06553154146032673, 0.1699471835579191, 0.26117757388523644, 0.2573525362781116, 0.6826089971831867, 13.42173273222787, 78.49596732003349, 55.90134613854544, 34.220951557159424, 23.465470177786692, 43.708803585597444, 32.76367807388306, 29.490725653512136, 18.29583845819746, 17.698553936822073, 18.730887753622874, 23.65859362057277, 14.905895744051252, 12.452214973313467, 16.338522229875835, 51.8431430544172, 56.108235699789866, 54.39681100845337, 58.21481834139143, 25.419201135635376, 0.9288850192512784, 22.988533667155675, 58.79216848100935, 62.57184260232108, 63.60886124202183, 67.53388472965786, 63.63982936314174, 61.93805571964809, 59.65957464490618, 55.51580796922956, 55.68658774239676, 58.158433709825786, 55.58695752280099, 53.219810485839844, 48.14457178115845, 45.997435978480745, 43.52140372140067, 44.808717318943565, 42.97507381439209, 45.628660338265554, 44.22193499973842, 41.831851959228516, 44.30552877698626, 42.78056246893746, 43.7331292288644, 47.40411267961775, 45.59066064017159, 46.60875586100987, 46.62494516372681, 47.69673258917672, 45.91742747170584, 50.816324370247976, 48.744642530168804, 51.44127661841256, 49.71928024291992, 50.05153267724173, 49.38905668258667, 51.008845056806294, 48.80425807407924, 53.250028201511924, 45.606829098292756, 28.184525115149363, 26.929989644459315, 18.363451378686086, 19.84002869469779, 26.926612819944108, 29.369111333574565, 36.6216653415135, 42.75282526016235, 24.409626143319265, 12.282674585069929, 5.4070625220026285, 9.705547775541033, 15.578886100224086, 12.763920715876989, 15.691245419638497, 21.72993176324027, 20.870945078986033, 9.501775349889483, 6.435147949627467, 1.6642241669552666, 2.4999012734208788, 1.3045575065272195, 0.5213320798107556, 0.3351709762854235, 0.6069857808096069, 5.780767474855695, 26.69893251146589, 34.98365184238979, 44.06368282863072, 38.797007356371196, 33.956263405936106, 35.99754340308053, 29.289047241210938, 25.55859763281686, 42.019672189440044, 43.97606257029942, 44.573645864214214, 46.380507537296836, 47.634910992213655, 47.117707933698384, 46.57394538606916, 46.34343889781407, 39.25204488209316, 40.56625843048096, 39.11007581438337, 39.369247095925466, 39.76274790082659, 40.45617117200579, 41.1835537637983, 39.49262973240444, 39.836259841918945, 39.616172177451, 39.13791724613735, 40.329133783067974, 39.588351590292795, 38.86837925229754, 41.47077144895281, 41.876792907714844, 41.03064475740705, 43.50435284205845, 53.068030561719624, 49.82450376238142, 54.9171199117388, 51.85161290849958, 53.8002074105399, 52.807643345424104, 55.72166919708252, 51.69242967878069, 54.5704916545323, 52.31896959032331, 53.67793301173619, 51.624559674944194, 56.299231256757466, 58.779585293361116, 63.668469837733674, 41.85872411727905, 3.5101404700960432, 7.871303251811436, 59.55392728533064, 43.80673149653843, 56.080356052943635, 37.662422112056184, 3.508965573140553, 15.085921832493373, 44.23231560843331, 55.88476078850882, 47.805325984954834, 20.30732457978385, 21.043489694595337, 11.482421023505074, 27.77104823929923, 27.064673525946482, 34.29374435969761, 57.94251496451241, 31.57187441417149, 54.06895678383963, 60.214291027614046, 78.01378318241665, 9.70066145488194, 0.29672062237347874, 0.6391365070428167, 0.16003423476857798, 0.17853544200105326, 0.05050855562356966, 0.14675637653895787, 0.3091413415968418, 0.5382021431412015, 1.2286615733589445, 1.125426975744111, 0.9487890026399067, 0.4194480925798416, 0.5989338500159127, 0.6137156539729663, 0.43888204119035173, 1.447461758341108, 15.903622320720128, 90.40729890550885, 65.49094758714948, 37.387169224875315, 28.419415916715348, 54.58990839549473, 33.97706283841814, 32.49060344696045, 18.250298227582658, 16.673995154244558, 18.81945644106184, 30.940001760210308, 9.717825242451259, 17.308261462620326, 27.71184263910566, 56.768797465733115, 61.28401483808245, 56.90318604878017, 59.99170548575265, 20.396730525153025, 0.9982054595436368, 32.12249483380999, 64.79754516056606, 69.31177588871547, 65.66984285627092, 72.64779363359723, 72.53769247872489, 64.78769956316266, 64.36596475328717, 57.85419988632202, 58.950149672372, 59.83619090488979, 60.211254664829795, 59.923918860299246, 55.12478419712612, 50.042284624917166, 45.53376531600952, 47.7200403213501, 47.69797631672451, 51.0238218988691, 46.012169633592876, 43.54805701119559, 46.29452705383301, 43.686499868120464, 45.019814014434814, 50.24843420301165, 48.33340297426496, 49.42736904961722, 51.82199273790632, 51.65763657433646, 50.227509702954976, 59.20309884207589, 55.31362233843122, 57.62288045883179, 56.42764438901629, 53.44221884863717, 50.72796760286604, 51.83578143801008, 55.64861931119646, 61.325662340436665, 56.51154736110142, 34.57326691491263, 35.19443934304373, 17.715808050973074, 23.441365139825002, 30.657970905303955, 26.754829032080515, 40.98705870764596, 44.65838262013027, 28.960008348737443, 16.1940917628152, 6.969523480960301, 9.900474275861468, 14.147688337734767, 13.073944994381495, 19.37004906790597, 24.723858424595424, 22.679618494851248, 16.48359019415719, 12.923919490405492, 6.460533627441951, 5.676738177027021, 1.319738126226834, 0.28204551126275745, 0.34523584906544, 0.5870710494262832, 7.171597072056361, 29.664173534938268, 39.32620300565447, 52.68463243756975, 48.08357701982771, 38.790590694972444, 40.94503252846854, 37.86249549048287, 30.05863666534424, 45.731142793382915, 46.54025704520089, 46.0629540170942, 51.54067407335554, 53.52202238355364, 49.05597046443394, 46.727493626730784, 47.35212973185948, 39.83024270193917, 40.93710115977696, 40.35784026554653, 42.1611270904541, 40.89793416431972, 42.7839948790414, 44.88917398452759, 40.10081945146833, 43.57567957469395, 42.534690039498464, 43.797073500497, 43.360858644757954, 39.87069858823504, 38.948582308632986, 44.25317062650408, 44.33840070452009, 43.35606091363089, 43.55075986044747, 53.41351931435721, 48.92965221405029, 55.89221967969622, 54.44409697396414, 57.80818544115339, 54.47752823148455, 55.04400096620832, 53.839530740465435, 54.94747311728341, 51.162580898829866, 52.763612610953196, 52.333317620413645, 61.090187890189036, 61.7071601322719, 68.35653059823173, 54.86541141782488, 6.663466189588819, 6.848749024527414, 65.00847857339042, 47.09810011727469, 59.386503492082866, 49.185735021318706, 9.783718483788626, 17.316647938319615, 49.36099638257708, 58.20264509746006, 55.695099285670686, 30.40330900464739, 25.82515832356044, 14.742107595716204, 34.825760977608816, 43.46871900558472, 38.32160813467843, 75.30010863712856, 36.93106515066964, 59.44925267355782, 67.67962319510323, 86.33207620893205, 12.595475537436348, 0.5874360469835145, 1.477989103112902, 0.8294415867754391, 0.5770648834960801, 0.2478721264217581], [0.06680699730558054, 0.12991534093660967, 0.579142720571586, 0.3318593996976103, 0.6586912891694477, 0.6546612254210881, 0.10527083370834589, 0.14921970292925835, 0.4096306950918266, 0.3906049531485353, 0.577256556068148, 14.402080127171107, 67.93547671181815, 48.59129926136562, 32.722499574933735, 34.63201740809849, 33.78890214647566, 23.37289932795933, 17.61882335799081, 18.430077654974802, 20.393124410084315, 24.977552788598196, 27.030882699148997, 16.02644041606358, 4.5438118151256015, 5.107336776597159, 28.841944558279856, 57.653004373822895, 45.54965237208775, 41.45895256314959, 45.38350357328142, 4.949952261788504, 1.040754490665027, 28.542093311037334, 46.95769092014858, 62.24900150299072, 59.8722242627825, 54.23047113418579, 56.04277672086443, 60.68822765350342, 56.14703791482108, 56.1157397542681, 53.183162212371826, 48.69098506655012, 44.893370696476524, 42.853952816554475, 41.51023374285017, 42.487091405051096, 42.98630905151367, 42.066801820482524, 41.04116780417306, 40.86523594175066, 38.67508731569563, 40.53600597381592, 40.104533263615195, 45.367401123046875, 43.27372823442732, 40.564736774989534, 42.49158341544015, 41.85573986598423, 41.705488545554026, 43.1411566053118, 45.70422894614083, 45.01246976852417, 45.23151172910418, 46.268592902592246, 43.20056022916521, 48.99784878322056, 50.91225119999477, 50.5464528628758, 48.236597197396414, 43.71375070299421, 18.264611516680034, 11.985934393746511, 12.875124897275652, 12.523068359919957, 17.135980878557476, 23.043856961386545, 23.60485451562064, 32.876183305467876, 9.364160197121755, 3.745151996612549, 2.170291325875691, 1.3330350241490772, 0.23106101421373232, 0.14112730430705206, 0.08481742694441761, 1.9746825993061066, 4.773069798946381, 5.388882560389383, 1.9182128523077284, 1.3546351279531206, 0.4045737364462444, 0.02559765045797186, 0.4070524520107678, 0.5534036617193903, 0.230555424200637, 6.561675080231257, 28.675483090536936, 31.959931305476598, 45.664016246795654, 37.5534222466605, 26.304931436266216, 21.873566661562236, 15.917126144681658, 16.38403466769627, 32.422452041081016, 40.874372822897776, 43.92789070946829, 46.91848223549979, 45.93781001227242, 44.422362736293245, 45.444404533931184, 44.49166406903948, 40.4669999395098, 40.30327953611101, 40.782531533922466, 37.275174685886924, 36.48797505242484, 37.50735221590315, 37.51772935049874, 37.08231006349836, 37.29454626355852, 36.78580263682774, 36.38672242845808, 38.90045213699341, 35.62937920434134, 37.756469454084126, 40.37934146608625, 36.84835032054356, 39.704758235386436, 47.99906260626656, 53.24385125296456, 50.47270120893206, 53.42031812667847, 50.85100282941546, 52.25604322978428, 49.69873789378575, 52.24089615685599, 53.23869568961007, 56.17691169466291, 50.97866555622646, 54.10999979291643, 48.093408720833914, 54.7986843926566, 56.96648761204311, 56.8811011995588, 18.104082073484147, 0.5139935878770692, 23.554403645651682, 55.14190803255354, 35.57489837918963, 46.453147479466026, 20.192543813160487, 0.22292341158858367, 14.43790590763092, 25.039457763944352, 36.28760984965733, 48.33494200025286, 30.656866141727992, 18.573283502033778, 14.397599407604762, 20.790417194366455, 28.898850304739817, 22.456247806549072, 38.57516179765974, 26.684626170567103, 43.11234242575509, 57.311427456992014, 65.40205233437675, 12.964092237608773, 0.2354526828442301, 0.9207715860434941, 0.6099801287055016, 0.5413539654442242, 0.02979757696656244, 0.022645375125908425, 0.09886818405772958, 0.10215945209243468, 0.005848567708328898, 0.4066723366933209, 0.2699251116386482, 0.06527346066598382, 0.27695340450320927, 0.23741438186594419, 0.36132920693073955, 0.5910139349954469, 21.24059792927333, 77.44357926504952, 55.97934661592756, 31.806841645921978, 35.455952167510986, 43.363335677555625, 31.13259540285383, 26.334016595567974, 21.391698666981288, 22.623360667909893, 28.40101534979684, 28.600166354860576, 15.957104342324392, 10.046635712896075, 8.007482733045306, 27.748200825282506, 60.4678863797869, 50.015408992767334, 43.996434688568115, 51.02099745614188, 7.774456654276166, 0.1886837881590639, 19.676219701766968, 38.6779464994158, 55.12696245738438, 52.7424761908395, 53.60388605935233, 60.47176347460066, 61.35518523624965, 57.101668289729524, 56.2885935647147, 56.51353801999773, 53.65162018367222, 48.143633774348665, 45.96176740101406, 43.731239318847656, 43.18739339283535, 45.024094104766846, 43.47345767702375, 43.928314549582346, 42.68240874154227, 43.908230781555176, 44.02997016906738, 43.875490869794575, 45.074729101998464, 46.45056274959019, 44.20451586587088, 48.899615151541575, 47.432655879429404, 46.30962201527187, 47.25207914624895, 47.98410313470023, 52.5426390511649, 51.11245659419468, 50.78359835488455, 49.976255893707275, 52.07476472854614, 49.34427901676723, 50.9305944442749, 51.15766852242606, 45.43368346350533, 23.376993553979055, 23.159507989883423, 11.61282742023468, 14.382877043315343, 22.16398572921753, 28.522346530641826, 27.180717127663748, 39.58057655606951, 20.218293837138585, 4.255373852593558, 0.9126512046371187, 1.28476773415293, 0.4968103670648166, 0.5980420921530042, 0.43490023485251833, 1.8679267849240984, 7.343463369778224, 9.548524567059108, 1.2703563017504556, 1.3958835431507655, 0.5697933222566332, 0.012806453658933086, 0.3790249116718769, 0.42726440887366024, 0.24291029838579042, 8.558610371180944, 33.93775340488979, 34.11931678227016, 45.448761054447715, 34.670892579214915, 28.597814389637538, 27.536470106669835, 21.7018940448761, 17.774337938853673, 32.153362206050325, 39.22547149658203, 43.98411553246634, 46.59908744267055, 48.57645443507603, 46.609106745038716, 47.81014108657837, 47.23022358758109, 41.75665160587856, 41.041932106018066, 40.93322059086391, 37.67402212960379, 40.436539036887034, 41.302169936043875, 40.8286258833749, 38.44308001654488, 40.06691224234444, 38.29303019387381, 38.05779545647757, 41.40734829221453, 38.95638166155134, 38.83092498779297, 41.41217729023525, 37.8049887248448, 41.6922105380467, 48.761752469199045, 55.10481507437569, 51.11705977576119, 55.12054232188633, 53.27051843915667, 56.56135899680001, 54.03537961414882, 56.57050282614571, 52.94496406827654, 57.24143477848598, 52.85450199672154, 55.436007908412385, 49.81515843527657, 57.54132597787039, 57.37388481412615, 58.879451751708984, 15.126487152917043, 1.384644831929888, 31.47165012359619, 61.80125263759068, 37.81099544252668, 47.69291107995169, 18.687668221337454, 1.3272236159869601, 21.65160993167332, 25.02122047969273, 34.08294643674578, 43.78398309435163, 21.799988712583268, 18.6571968964168, 17.529599802834646, 21.901682547160558, 29.901551791599818, 23.32597640582493, 41.640425613948274, 28.209641116006033, 47.88178743634905, 59.68744386945452, 75.76001685006278, 17.981263978140696, 0.13822659424373082, 0.4418120096836771, 0.06563313850866896, 0.15953456158084528, 0.2598092130252293, 0.13840701670518943, 0.21827294970197336, 0.5687314963766507, 0.7568909940975053, 1.351192186985697, 1.1778092277901513, 0.3380049185029098, 0.5461959913372993, 0.6413571621690477, 0.5933569435562406, 1.4880503118038177, 26.989226511546544, 92.36282770974296, 63.4007487978254, 40.869158199855256, 42.56306300844465, 44.79588052204677, 34.72321598870413, 25.36115414755685, 24.04089740344456, 27.02393971170698, 34.060184138161794, 37.15445668356759, 21.393536465508596, 10.73405487196786, 17.81909302302769, 42.00872530255999, 63.35503659929548, 54.44516699654715, 46.311400754111155, 50.313851492745535, 5.875632098742893, 1.5358749798366, 33.84315368107387, 52.894273485456196, 65.31153120313371, 67.39816556658063, 68.54251997811454, 67.79776341574532, 68.93570463997978, 59.161798749651226, 58.672367640904014, 60.771626881190706, 58.891687529427664, 53.186205523354666, 50.806992939540315, 48.812901633126394, 46.99521814073835, 49.42440216881888, 46.54826136997768, 48.18218585423061, 45.66239384242466, 44.75792251314436, 47.32168272563389, 46.778465611594065, 46.981234891074045, 50.31615482057844, 45.40821136747088, 50.17654119219099, 52.09818710599627, 52.36773204803467, 52.914635181427, 58.34018816266741, 60.57609067644392, 57.486463001796174, 54.858049801417756, 51.12936156136649, 52.59201642445156, 51.98117944172451, 55.85369191850935, 60.15263271331787, 52.708197253090994, 30.683265822274343, 35.38593864440918, 13.843325972557068, 19.971222843442643, 29.025145973478043, 32.421430655888145, 38.084726674216135, 43.61844226292202, 26.324700798307145, 9.691102470670428, 3.905891622815813, 2.9297292147363936, 0.4746655896306038, 0.27734755192484173, 0.2509044451372964, 4.234569208962577, 13.458839586802892, 12.014241354806082, 5.049152127334049, 2.6527429691382816, 0.9207142634051186, 0.07565765881112643, 0.6874889667545045, 0.873780159013612, 0.2976763796593462, 9.029491526739937, 35.89359835215977, 37.90288189479283, 51.13089711325509, 45.392088072640554, 41.61629104614258, 34.62981482914516, 32.40692976542881, 23.860261610576085, 32.576882702963694, 40.121452127184185, 44.9658647264753, 51.42953763689314, 52.99790934153965, 50.60550560270037, 50.66932480675833, 50.03244597571236, 43.79619107927595, 41.220653670174734, 42.12457956586565, 37.60829911913191, 43.35787091936384, 44.85744850976126, 43.83322497776577, 39.76231363841465, 45.02269751685006, 41.90175778525216, 38.95125389099121, 44.6250764301845, 40.41767815181187, 40.45160273143223, 44.163556235177175, 41.19494880948748, 43.235558305467876, 49.547291483197895, 54.43471343176705, 50.96593645640782, 55.63272530691964, 56.55933012281145, 59.48920481545584, 55.91433926991054, 56.99048668997628, 52.09766251700265, 57.52698489597866, 54.6940028326852, 56.74227966581072, 49.57156501497541, 60.72247532435826, 62.895024163382395, 63.536488805498394, 25.61077686718532, 2.558060084070478, 30.700570310865128, 66.42618901388985, 41.08637625830514, 50.95641395023891, 26.732494047709874, 3.914390138217381, 21.48616984912327, 30.744465555463517, 37.1612867627825, 50.37214340482439, 38.666492394038606, 28.707356214523315, 18.53681414467948, 31.531633922031947, 41.158811228615896, 29.24820225579398, 53.75809090478079, 31.54451240812029, 55.7365939276559, 66.84988321576799, 85.55136271885463, 26.791882038116455, 0.40847292436020716, 1.427128615123885, 0.8183627384049552, 0.6081279995185989, 0.33301795752985136], [0.06846056678997618, 0.036234977788158824, 0.46408652301345554, 0.18332842338298047, 0.569022886455059, 0.925528170807021, 0.18788874867771352, 0.09459735572870288, 0.2210010133151497, 0.37016625702381134, 0.5985154381820134, 18.567050967897686, 66.86821951184953, 54.20974465778896, 40.41412762233189, 31.42218589782715, 31.384665625435964, 25.87308004924229, 24.735548768724712, 30.043079648699077, 22.38765171595982, 27.783779076167516, 28.102322714669363, 23.40244480541774, 9.064209938049316, 2.603375801018306, 10.271547164235797, 46.377575397491455, 59.56357833317348, 42.24378286089216, 45.22056484222412, 23.400641747883387, 0.09668760999505009, 0.42668146586843897, 5.333065075533731, 18.443541526794434, 22.160214594432286, 37.89993238449097, 53.78970520836966, 59.23059981209891, 56.01675919124058, 54.40622581754412, 51.65120949063982, 48.10037776402065, 44.028163637433735, 39.62141806738717, 42.811249188014436, 48.06169366836548, 49.93902397155762, 50.26358822413853, 41.8457726751055, 38.4327688898359, 41.45778179168701, 40.35476221357073, 38.633693422589985, 43.21388687406267, 42.21104294913155, 45.17386599949428, 44.75107158933367, 42.99631445748465, 41.700958320072715, 45.200724261147634, 43.68033334187099, 44.80731725692749, 47.22542585645403, 45.51013101850237, 47.75560120173863, 48.827041217258994, 47.28187302180699, 49.447320801871165, 46.07452276774815, 35.636431625911165, 12.740979501179286, 6.14905674116952, 9.414421728679113, 8.171735542161123, 15.074990579060145, 26.21375891140529, 41.350192410605295, 27.14474630355835, 0.7592401366148676, 0.9812867045402527, 0.7527695181114333, 0.44793179844106945, 0.29496707075408524, 0.10401893659893956, 0.08297045462365661, 0.11961218022874423, 0.4583976854171072, 0.9719617877687726, 0.11524674376206738, 0.08300759084522724, 0.14210857450962067, 0.5954607820936612, 0.28014194912144114, 0.2283309149955, 1.3039101298366274, 9.991599900381905, 44.352029596056255, 54.78848443712507, 57.649092538016184, 32.28458588463919, 21.302558490208217, 20.265089954648698, 5.174731697354998, 10.565602745328631, 26.557823283331736, 37.084387574877056, 45.12128203255789, 44.68404231752668, 43.6590336390904, 44.69367599487305, 44.38370990753174, 40.59875862939017, 41.4752321924482, 38.16544042314802, 38.2728283064706, 37.25360400336129, 38.943808896201, 37.94875042779105, 37.65088810239519, 40.615229334150044, 38.78559841428484, 36.18229947771345, 40.55552693775722, 37.44127137320382, 37.097464084625244, 38.350967747824534, 37.69646481105259, 36.99092040743147, 39.79557466506958, 48.51355586733137, 54.03860010419573, 52.97800622667585, 56.798348154340474, 52.6692282812936, 49.671949114118306, 53.18594149180821, 52.87562452043806, 51.29320355824062, 53.98990018027169, 55.541363443647114, 51.78483029774257, 55.27807535443987, 53.97247757230486, 54.673331941877095, 44.74856676374163, 2.3517528687204634, 3.021189872707639, 45.91261237008231, 48.73168761389596, 38.369918959481375, 48.84208059310913, 11.661251153264727, 0.5782751185553414, 25.71621925490243, 25.800269876207622, 15.242718355996267, 34.99528660093035, 24.83025618961879, 23.444722856794083, 9.462483286857605, 21.314139400209697, 26.296333040509904, 21.35434341430664, 47.89082704271589, 19.152982132775442, 30.943274361746653, 51.155806405203684, 62.23899609701974, 14.37433249609811, 0.530831190092223, 1.1089093706437518, 0.5865477089371, 0.47634097401584896, 0.1355248713599784, 0.050571954543037076, 0.08770577409969908, 0.20721345315022127, 0.09136682336351701, 0.22639652022293635, 0.4869891426392964, 0.41155371761747767, 0.3917929594005857, 0.12469663311328207, 0.24404592173440115, 0.36356001294084955, 26.539530413491384, 76.07411711556571, 58.34779644012451, 38.95864677429199, 32.7698654447283, 37.80477333068848, 32.28365135192871, 27.331823076520646, 26.370677028383525, 21.45919520514352, 28.879629850387573, 28.608122042247228, 16.469643422535487, 6.956173820155008, 5.270916044712067, 11.079230087144033, 44.75799199513027, 59.79356370653425, 46.29336323056902, 45.54858234950474, 28.437536818640574, 0.0988574835604855, 0.3198526139770235, 3.6217068263462613, 16.241049425942556, 21.86079066140311, 44.94864361626761, 59.41538715362549, 60.943344661167686, 59.28121049063546, 56.47045571463448, 57.8300792149135, 53.16516637802124, 49.365592615945, 46.291282245091026, 44.865279129573274, 48.94832897186279, 53.10880953924996, 54.402862889426096, 46.996361119406565, 42.6026816368103, 43.759209292275564, 43.28038808277675, 41.74523571559361, 42.61902379989624, 48.05293198994228, 48.858033657073975, 47.90828786577497, 45.791178703308105, 44.229327883039204, 46.753938470567974, 46.02542332240513, 52.68900980268206, 53.25534357343401, 51.12165948322841, 48.22533416748047, 50.937146595546174, 48.13938842500959, 52.689940861293245, 50.925897462027415, 38.81293262754168, 21.444458075932094, 13.92563954421452, 10.003186021532331, 7.46168349470411, 18.222706930977957, 29.69952596936907, 41.370258808135986, 33.426640442439485, 7.100477482591357, 2.871436217001506, 0.5552990542990821, 0.23545990245682852, 0.24966204751815113, 0.27768339961767197, 0.10023647027888469, 0.2951702784214701, 0.8051476989473615, 0.6009955650993756, 0.13755055623395102, 0.01552825015304344, 0.27341408442173687, 0.6634777294737952, 0.2540681010910443, 0.2878976858087948, 1.0540840668337685, 10.541657515934535, 46.598590646471294, 55.84430490221296, 57.54187835965838, 32.89157703944615, 26.573769399097987, 18.989852326256887, 13.551025680133275, 14.435751097542898, 25.807171174458094, 35.6859792300633, 43.77761159624372, 50.013300214494976, 46.6557743208749, 47.29164218902588, 46.41844817570278, 44.45840304238455, 41.67350251334054, 38.99710505349295, 38.64003017970494, 40.280718735286165, 39.50252744129726, 41.67900548662458, 39.79632159641811, 41.776422704969136, 40.945150647844585, 40.19757659094674, 39.18662411825997, 39.7214651788984, 37.975118841443745, 39.21856498718262, 39.82287761143276, 38.9025365965707, 39.022611890520366, 48.84524549756731, 53.02852310453142, 51.84699583053589, 56.82681144986834, 57.87591995511736, 55.247148922511506, 59.91028649466378, 56.94401018960135, 54.96632705415998, 55.2940423148019, 61.1198080607823, 55.71441180365426, 56.538700921194895, 54.34327861240932, 59.17752947126116, 38.640217781066895, 1.3419060281344821, 5.739535127367292, 51.636163166591096, 52.93772404534476, 39.87458610534668, 48.8383389881679, 11.02520958014897, 1.0829657741955347, 25.551432303019933, 24.710828815187725, 21.805031367710658, 37.502262660435264, 20.641755274363927, 23.487504652568273, 13.437681453568594, 23.61749850000654, 31.80943332399641, 20.46024748257228, 57.676197460719514, 21.275015830993652, 32.30173751286098, 56.963857718876426, 70.5812326158796, 20.890950679779053, 0.487208716571331, 0.5599156980003629, 0.2977527284196445, 0.08218336078737463, 0.1077425739328776, 0.15269359866423265, 0.2901866558407034, 0.6532536180956023, 0.5329686839665685, 1.1158977385078157, 1.153916327016694, 0.8737740793398449, 1.1738597197192056, 0.3985071991171156, 0.6439921036362648, 1.341967584831374, 35.134594508579795, 90.26249149867466, 66.09485026768276, 48.97132750919887, 39.84383685248238, 38.271768706185476, 36.85133457183838, 32.54909685679844, 38.828312465122764, 27.867649044309342, 36.132901259831016, 36.102673121861045, 31.19804743358067, 14.32225227355957, 10.18571867261614, 21.66749003955296, 51.45024674279349, 63.46898705618722, 45.648341110774446, 49.26243618556431, 28.088666030338832, 0.1870508664952857, 1.6048404106072016, 8.526384626116071, 26.323073182787212, 38.32894195829119, 55.8318259375436, 70.03985677446637, 68.25918633597237, 63.053498676845, 62.08502401624407, 62.93826975141253, 59.201090812683105, 54.21991334642683, 47.5541729245867, 48.3263783454895, 52.39151573181152, 58.551100730895996, 55.670582566942485, 48.93587779998779, 44.85924114499773, 48.13815859385899, 46.90589904785156, 43.7302040372576, 47.337618419102256, 51.11376632962908, 51.65979398999895, 53.955527441842214, 52.879470348358154, 50.58965676171439, 52.45558854511806, 51.70190702165876, 59.11871991838728, 60.26422078268868, 54.60457256862095, 53.29386438642229, 53.262180600847515, 49.27980668204171, 55.685639313289094, 57.7118695122855, 47.754836899893625, 31.7990631375994, 27.02152521269662, 12.417661581720624, 14.82963057926723, 30.072578225816997, 39.31045838764736, 45.47501482282366, 40.503022875104634, 20.977176087243215, 3.0263647607394626, 2.5180651673248837, 0.9382138443844659, 0.48763945060116903, 0.39670270308852196, 0.12986636427896364, 0.5541814799819673, 1.9627848948751176, 0.8196405012692723, 0.2375511202429022, 0.20542113003986223, 0.49159921812159674, 1.1451883039304187, 0.6671639659575054, 0.40319215772407396, 1.5236376821994781, 15.47082597868783, 46.39960813522339, 53.295966216496055, 62.37276976449149, 46.94884238924299, 41.21161406380789, 30.057521479470388, 26.26958073888506, 19.9161878994533, 26.138471705572947, 37.90519217082432, 48.027133328574045, 54.163792746407644, 47.333296639578684, 52.18567534855434, 49.25766972133091, 49.84910385949271, 44.42944642475673, 43.89900009972708, 40.59891496385847, 41.1533534186227, 40.72738715580532, 45.03544051306588, 40.4891369002206, 44.20053454807827, 41.956287247794016, 39.687728200639995, 41.53138058526175, 42.423049858638215, 38.40035901750837, 40.75861930847168, 40.73995992115566, 40.63441331045968, 40.51761409214565, 50.49015160969326, 53.20603915623256, 54.59118338993618, 55.474956035614014, 59.214354923793245, 58.25151177815029, 59.31400598798479, 56.22368001937866, 55.05998877116612, 53.982041767665315, 62.322527340480256, 56.102753571101594, 58.873114994594026, 56.88513115474156, 62.28390230451311, 48.126346656254356, 4.494889114584241, 5.217440102781568, 56.301329612731934, 59.44409711020333, 44.529552595955984, 52.01144232068743, 18.899867943355016, 1.725977367588452, 37.252110140664236, 32.802376065935405, 18.888700451169694, 40.214759486062185, 32.079968384334016, 36.06470816476004, 11.565383383205958, 30.7208833694458, 43.81645202636719, 28.02575182914734, 59.263798304966514, 22.50649717875889, 42.98074701854161, 65.05224527631486, 80.99596391405377, 30.985689640045166, 0.6776278987526894, 1.7263788431882858, 0.6970586446779115, 0.5250487146633012, 0.48243774686540875], [0.10077828049127545, 0.0703084347769618, 0.1304964247558798, 0.09385867536600147, 0.994838297367096, 0.7583357851420129, 0.8333953289049012, 0.5004905781575612, 0.04150454520380922, 0.2426350845822266, 0.8064789846539497, 34.141915798187256, 68.00519493647984, 48.229402337755474, 31.665664672851562, 46.17787027359009, 34.12670619147164, 30.35070766721453, 30.3910037449428, 28.837806906018937, 27.299029316220963, 35.81159223828997, 26.713815552847727, 21.79291718346732, 10.723379833357674, 3.6147345261914388, 8.621328285762242, 30.1704957144601, 56.35873910358974, 45.50729267937796, 41.943756171635215, 43.96966675349644, 2.6031806000641415, 0.694787072283881, 0.4328217463833945, 4.564001543181283, 13.645283205168587, 45.52703251157488, 60.53247683388846, 55.35828535897391, 59.52374431065151, 52.206867354256765, 52.72587694440569, 46.58971084867205, 42.426239081791465, 43.71263204302107, 47.65134000778198, 51.29128238133022, 52.58331380571638, 52.859737464359824, 48.411987100328716, 44.253243582589285, 38.5464448928833, 40.58092607770647, 42.2871014050075, 43.544489111219136, 46.099188872746055, 47.0376091003418, 44.73427431924002, 43.821663175310405, 42.98372779573713, 43.245376110076904, 43.89246531895229, 46.73772484915597, 46.81059408187866, 49.25935465948922, 45.77971070153372, 44.230210304260254, 50.35679483413696, 47.02158308029175, 48.61248084477016, 18.963985919952393, 10.543622119086129, 2.783057302236557, 8.93451486315046, 8.105861408369881, 13.648139783314296, 55.34651511056082, 53.05490888868059, 7.92961687701089, 6.726184104170118, 1.538059536899839, 0.6922614563788686, 0.9509147171463285, 0.49122629527534756, 0.4394323059490749, 0.23030748750482286, 0.1877665173794542, 0.5614128176655088, 0.02106566248195512, 0.3285135163792542, 0.05474184400268963, 0.17584040947258472, 0.3897576800414494, 0.32787550347191946, 0.1688199197607381, 0.7811419442296028, 10.833653824669973, 40.45611906051636, 65.07664040156773, 73.90583447047642, 29.622995035988943, 25.93285366467067, 8.061005575316292, 3.865954680102212, 4.593771968569074, 21.1471620287214, 37.26177508490426, 46.22248465674264, 43.58704335348946, 46.474579198019846, 43.14440141405378, 42.38654054914202, 39.025005544934956, 40.187644141060964, 36.534263951437815, 40.732504504067556, 39.60046230043684, 38.14065967287336, 40.1141391481672, 40.50192853382656, 41.61793082101004, 41.05381005150931, 40.320097650800435, 39.47418573924473, 36.26352391924177, 38.93301486968994, 37.867043086460654, 38.222804750714985, 38.92586864743914, 37.69593327386038, 47.897653647831504, 51.92250190462385, 52.281949588230674, 52.63433790206909, 53.21266426358904, 53.306763717106406, 53.27080678939819, 56.65486785343715, 54.20272697721209, 57.6062673160008, 56.57130881718227, 56.4852796963283, 52.06886223384312, 53.42986495154244, 54.946493421282085, 9.287333965301514, 0.27122119494846886, 15.317871809005737, 50.540063994271414, 36.96070269175938, 41.909980978284565, 47.40347344534737, 3.5952973748956407, 1.9899121820926666, 23.0005418913705, 32.24243116378784, 10.581133706229073, 34.67447437558855, 16.053369896752493, 18.852561133248464, 19.75481425012861, 15.504109586988177, 33.111803667885916, 25.416362796510967, 32.421656472342356, 32.17576667240688, 40.09974595478603, 55.94181592123849, 62.550893783569336, 12.528947404452733, 0.7100091097610337, 1.0650776369231088, 0.5647135376930237, 0.5058715237038476, 0.30840735669646946, 0.07084985143904175, 0.023911015962117484, 0.09352727886289358, 0.0659838936158589, 0.7076022646256855, 0.4787226862141064, 0.640804400401456, 0.39141618247543064, 0.2689542094511645, 0.3073260432907513, 0.8244475147553852, 48.050312519073486, 76.90410028185163, 50.63027245657784, 37.40163884844099, 41.5190440586635, 37.403341157095774, 37.3270707811628, 30.315546308244976, 28.48091789654323, 25.540591376168386, 32.50101184844971, 27.385579551969254, 19.853339706148418, 8.33634270940508, 4.566823814596448, 11.318756205695015, 32.424227305821006, 58.40231895446777, 48.38719940185547, 43.1538405418396, 50.5368469783238, 4.655622661113739, 0.46246726704495295, 0.39832019486597603, 6.214540473052433, 20.002279554094585, 52.35759115219116, 64.77126707349504, 60.28671210152762, 63.42238548823765, 55.91676071711949, 57.169482707977295, 50.91819190979004, 46.242894990103586, 48.445077896118164, 52.14280843734741, 54.521600655147004, 54.885293688092915, 55.73153911318098, 51.846832547869, 47.01978349685669, 42.23509761265346, 44.222278935568674, 43.4726551600865, 46.93543931416103, 49.018116678510395, 51.81453384671892, 49.75814846583775, 49.06401995250157, 46.889480454581125, 44.75283990587507, 47.04695095334734, 49.99266059058053, 50.87594338825771, 52.87265069144112, 50.05661875861031, 46.836354528154644, 52.89373847416469, 52.625704765319824, 50.601625033787315, 23.752220596585953, 19.51831841468811, 4.3926867587225775, 9.56128580229623, 4.371992417744227, 16.40360426902771, 54.42048004695347, 59.81419290815081, 25.51658535003662, 7.59422733102526, 2.2683119518416266, 0.5284179395862988, 0.8772884021912302, 0.2622806004115513, 0.645583512527602, 0.3188731079655034, 0.3541330173611641, 0.18191460067672388, 0.0859502615141017, 0.1093279913600002, 0.10372794007084199, 0.1684051855866398, 0.18639521167746612, 0.318481946097953, 0.12021589997623648, 1.4456951788493564, 12.929806351661682, 48.73338297435215, 65.29369517735073, 67.87644481658936, 31.055915083203995, 25.089776618140085, 10.519128850528173, 6.600235845361437, 10.825884001595632, 23.763586112431117, 39.16703019823347, 47.276373522622244, 46.12424407686506, 47.9396242414202, 44.994473934173584, 45.623449189322336, 43.66047886439732, 41.60847084862845, 39.400451455797466, 44.013850348336355, 39.93933636801583, 39.57250622340611, 42.96828889846802, 43.60277754919869, 42.67832667487008, 42.078189917973106, 41.963412625449045, 38.88843870162964, 38.18885932649885, 39.74343885694231, 39.908906732286724, 39.765822478703086, 40.92550809042794, 39.88232639857701, 46.94999579020909, 54.289787905556814, 51.74808127539498, 52.8596818787711, 54.626851967402864, 55.960756710597444, 56.60948569434029, 58.66297367640904, 57.78751802444458, 60.549736159188406, 57.842943804604666, 58.1392045702253, 56.62082862854004, 59.68962560381208, 46.04773398808071, 3.82088041305542, 0.05415704181151731, 18.877869946616038, 55.11662701198033, 40.8317734173366, 47.0299973487854, 49.90739229747227, 7.1531617641448975, 2.5194409106458937, 16.89574691227504, 31.550161293574742, 15.684717587062291, 43.49375336510794, 15.72462282861982, 19.097297532217844, 22.600476775850566, 17.79363829748971, 34.2627032824925, 28.361049311501638, 41.34792729786464, 30.233130250658306, 44.961855615888325, 58.361776215689524, 73.95245688302177, 18.747912577220372, 0.49906728310244425, 0.8113883755036763, 0.28574515559843605, 0.15860282443463802, 0.16357396197106155, 0.19570260867476463, 0.21608984470367432, 0.29106237313577105, 0.1460844911634922, 1.2579768917390277, 0.6293795534542629, 0.7278131086911473, 1.2839553377458026, 0.3847864610808236, 0.4201597129659993, 1.0946167090109415, 55.46425233568464, 86.62104484013149, 63.044361795697895, 40.689515999385286, 58.28698580605643, 42.51284490312849, 42.43937117712838, 42.047353812626426, 42.26261247907366, 33.06159945896694, 45.48317895616804, 35.31649487359183, 27.10955367769514, 15.421462501798358, 11.816914251872472, 17.330881323133195, 38.530439717429026, 61.31690066201346, 50.57636138371059, 49.355788707733154, 50.74144015993391, 3.460103452205658, 1.0249928278582436, 1.6942667663097382, 9.682259150913783, 27.96612238883972, 58.66736493791853, 71.27243941170829, 67.46386078425816, 67.43385846274239, 61.265317235674175, 62.76731627328055, 53.9304826600211, 50.299583366939, 50.08894872665405, 54.6846262386867, 61.318999017987935, 59.55011967250279, 57.15529796055385, 53.44221190043858, 47.577921867370605, 46.847659247262136, 49.34850352151053, 45.60883017948696, 49.83593354906355, 53.65284654072353, 54.26304081508091, 52.1999261038644, 54.50226729256766, 51.10082183565412, 48.84970971516201, 50.48564917700631, 59.306189264569966, 55.838982582092285, 54.92728165217808, 54.064638478415354, 48.20562212807791, 55.70087323869978, 53.77610410962786, 58.875866481236045, 34.072319167000906, 30.703571932656423, 12.273014851978846, 13.974875347954885, 16.14979178564889, 27.208958080836705, 55.65337535313198, 49.574566636766704, 42.05551447187151, 12.158178499766759, 1.7995239411081587, 1.255190446972847, 1.1523636217628206, 0.3087661660143307, 0.9200553787606103, 0.5839929974504879, 0.5986538050430161, 1.2614015936851501, 0.13575235701033048, 0.33950771072081154, 0.20034312323800155, 0.19891764330012457, 0.5629868560603687, 0.46662603531564983, 0.3393806346825191, 2.4253477539334978, 20.400294951030187, 51.56559726170131, 54.77465752192906, 64.05872930799211, 44.60223422731672, 45.54294736044747, 20.41105076244899, 16.734753676823207, 19.66471348490034, 24.278289556503296, 39.90004777908325, 51.86390079770769, 51.075002329690115, 51.44748830795288, 48.20712293897356, 49.84197848183768, 47.43826654979161, 46.72514166150774, 39.25895833969116, 42.46523584638323, 40.65601178577968, 41.01551505497524, 46.03955248423985, 45.309279441833496, 43.78027275630406, 46.04744563783918, 42.62199762889317, 40.853694983891074, 39.42431851795742, 41.1308273587908, 40.27807147162301, 41.84310456684658, 41.7869735445295, 42.320140089307515, 51.19473716190883, 57.441324029650005, 51.59937245505196, 51.403620856148855, 53.53303180422102, 57.69937317711966, 56.60831492287772, 60.27726255144392, 54.65500259399414, 60.23602499280657, 60.71971688951765, 62.89662224905831, 55.74258327484131, 57.55233192443848, 57.9579747063773, 10.479914954730443, 0.3787955125527722, 19.36338574545724, 61.31861686706543, 51.434988498687744, 53.426415170942036, 55.153153691973, 8.771114076886859, 5.881777780396598, 31.99565199443272, 42.49610321862357, 13.730647904532296, 41.90886926651001, 22.191318205424718, 30.399529184613908, 27.04770428793771, 19.61640613419669, 49.96013607297625, 32.50344371795654, 40.004666805267334, 38.56531967435564, 50.46397427150181, 68.94041551862443, 83.2282464163644, 27.45995828083583, 0.7126070846404348, 1.768053378377642, 0.7629489004611969, 0.6080086316381181, 0.3308420857148511], [0.12145710337374892, 0.16905990402613366, 0.05043535526575787, 0.0167779759503901, 0.6797256576163428, 0.5320758947304317, 0.1742017474025488, 0.20668247235672815, 0.12116902454623155, 0.3159434108861855, 1.365900980574744, 43.50519357408796, 61.801016398838584, 42.656888008117676, 21.645559787750244, 37.86715773173741, 36.15925925118582, 27.121752977371216, 26.168390648705618, 28.615355116980417, 21.147797788892472, 40.053279876708984, 25.23664242880685, 18.247941051210674, 4.344996929168701, 1.83402196424348, 9.647261943135943, 40.24093335015433, 46.92688955579485, 34.56151056289673, 41.289204597473145, 50.327306679316926, 13.40596900667463, 0.28940848473991665, 0.24199286475777626, 3.4252638816833496, 20.254565170833043, 55.32215820040022, 60.54079382760184, 54.3687333379473, 60.2987950188773, 49.284555775778635, 45.91647209439959, 43.512982504708425, 43.32157005582537, 45.12694828850882, 52.760857650211875, 50.69580439158848, 53.60622065407889, 54.00357076099941, 50.957306793757844, 45.10489470618111, 40.74394818714687, 39.94821616581508, 42.28862306049892, 45.91586412702288, 50.745577812194824, 49.37178693498884, 52.391508783612935, 45.4555390221732, 45.164263589041575, 44.42169223512922, 44.18261514391218, 44.1708414213998, 48.33843347004482, 46.869403634752544, 48.09710168838501, 45.111412116459434, 47.52730771473476, 45.2092080116272, 37.970814432416645, 9.92142309461321, 7.383053336824689, 4.672730428831918, 3.9557475532804216, 11.41379974569593, 23.35595961979457, 67.00381360735211, 22.776285307747976, 5.389446667262486, 3.1384865386145453, 0.9161791524716786, 2.1929817540305, 0.5358859502843448, 0.08476007716464144, 0.05433872634811061, 0.04511201734255467, 0.12719996592828206, 0.26641540282538956, 0.10090542438306979, 0.02564927000951554, 0.11738126565303121, 0.10626129806041718, 0.24877075105905533, 0.3368780346853392, 0.39491424762776917, 1.35337652691773, 6.657990140574319, 15.39741131237575, 34.63219458716256, 61.735779762268066, 53.57176453726632, 14.716963802065168, 1.550991328699248, 4.227793846811567, 2.1425992803914204, 15.149609020778112, 40.26605803625924, 44.81471708842686, 44.216782910483225, 43.90016392299107, 44.971544878823416, 39.399728843144004, 37.770334584372385, 38.103017807006836, 38.32435614722115, 39.64572981425694, 38.12684317997524, 39.607087407793315, 40.31611633300781, 40.04025547845023, 44.41590438570295, 41.24038655417306, 42.908815792628694, 40.8281638281686, 39.01998894555228, 37.05559423991612, 38.93386254991804, 39.39814117976597, 41.81881366457258, 37.66647291183472, 43.670654501233784, 51.194275106702534, 54.347534384046284, 50.817147731781006, 49.756592069353374, 51.42307581220354, 53.468139103480745, 51.58431223460606, 60.21668815612793, 59.50930595397949, 55.72220073427473, 57.70206560407366, 63.75630896432059, 49.626223019191194, 8.803051471710205, 0.0327902047761849, 0.9335315184933799, 24.903285230909074, 56.7780316216605, 42.823742049080984, 42.38473054340908, 44.65570408957345, 11.131011537143163, 2.4056422284671237, 5.8378104482378275, 30.205080372946604, 9.29149419920785, 17.39616138594491, 16.347261326653616, 15.921126570020403, 24.297197341918945, 16.684021404811315, 43.610910415649414, 13.52796287196023, 39.488433020455496, 33.746323585510254, 39.51455477305821, 47.912258761269705, 66.37208339146206, 12.4210809639522, 0.535583703645638, 0.24123795383742877, 0.27268335648945397, 0.7393252966659409, 0.4420322078679289, 0.1756931809442384, 0.2794549731271607, 0.04155885175402675, 0.08643378556839057, 0.409265398979187, 0.28143132850527763, 0.09320910700729915, 0.15188504276531084, 0.12132849384631429, 0.5801400584833962, 1.345909167613302, 53.171916552952354, 71.72854001181466, 50.16320759909493, 30.285651683807373, 35.402913093566895, 39.74442550114223, 34.34444536481585, 25.529317923954554, 27.548537390572683, 24.531877960477555, 31.876886435917445, 27.160506555012294, 20.740306786128453, 6.808065150465284, 2.891805946826935, 10.629091909953527, 43.996347836085725, 50.34086261476789, 36.01938853945051, 42.69207715988159, 53.65715094975063, 17.119836739131383, 0.04924860430349197, 0.30061658046075274, 3.6093529292515347, 22.668574333190918, 56.17281573159354, 59.62871074676514, 56.62810686656407, 60.374314989362446, 53.37065935134888, 49.331487383161274, 44.50042574746268, 44.08379091535296, 49.34005103792463, 56.36772312436785, 56.092508452279226, 56.50064563751221, 56.868399892534526, 52.536951950618196, 49.371738297598704, 43.595627852848594, 42.69242109571184, 43.810695443834575, 48.92302710669381, 52.68186705453055, 54.82862418038504, 55.82732697895595, 49.208816937037874, 50.960892064230784, 47.17385285241263, 48.70754957199097, 49.67288017272949, 54.0242486000061, 51.656201771327424, 50.013532979147776, 49.183376107897075, 54.6033809525626, 49.68484844480242, 41.22814730235508, 17.349740471158707, 11.726607646260943, 3.223162497792925, 3.9955689821924483, 7.76639153276171, 24.51505810873849, 62.85367543356759, 43.12727757862636, 5.337787679263523, 4.041399734360831, 2.9728390957627977, 2.641083240509033, 0.6426224399890218, 0.08292314716215644, 0.16307289100119046, 0.02267684388373579, 0.1450950378285987, 0.6315255154456411, 0.12869997615260736, 0.06761849126113312, 0.10868018719234637, 0.08643824354346309, 0.23652951791882515, 0.3520351770733084, 0.32930523103901316, 2.0437548586300442, 11.559693677084786, 19.513852460043772, 43.592876366206575, 63.125412532261436, 54.18174689156668, 18.583287170955114, 4.881977166448321, 6.494947186538151, 10.037643875394549, 18.98720679964338, 43.4575845173427, 45.281073229653494, 46.747695514133994, 44.34531763621739, 48.25872026171003, 45.16026142665318, 43.884905678885325, 42.74882657187325, 41.947633266448975, 43.18816811697823, 39.896507671901155, 39.94235536030361, 44.279775278908865, 43.56285320009504, 46.8796626499721, 42.789032323019846, 42.91759136744908, 41.701819896698, 40.6121095929827, 36.70277166366577, 41.23188543319702, 41.82490723473685, 43.244021211351665, 37.75207471847534, 45.827965940747944, 54.19566065924508, 55.813923903873985, 53.64058297021048, 50.028332642146516, 51.999630383082796, 55.383166858128135, 54.46624435697283, 62.497691426958355, 62.33174760001046, 59.38612134116036, 60.40374755859375, 65.30220672062465, 40.271390778677805, 4.9694832137652805, 0.07140138505824975, 1.564259022474289, 32.806242738451274, 57.80906091417585, 47.3838586807251, 44.89184904098511, 47.02244118281773, 16.518577848161968, 4.872772974627359, 4.9736425791467935, 32.064439160483225, 14.368573307991028, 24.19705990382603, 19.365206173488072, 18.92090014048985, 26.122346673692974, 16.808665139334543, 45.55888652801514, 20.998258658817836, 42.5926901272365, 28.502016101564678, 40.175613335200715, 54.31115361622402, 77.220792225429, 18.738046135221207, 0.33417523971625734, 0.17604448566479342, 0.21302332782319613, 0.5034197866916656, 0.3280527911015919, 0.1817748360335827, 0.25035765447786873, 0.18826620413788728, 0.24502936324902944, 0.5081854366830417, 0.6937381657106536, 0.19196210296026298, 0.3219232585813318, 0.368755718427045, 0.5174114501902035, 1.3261475137301852, 63.719476563589915, 83.69228880746024, 62.137406485421316, 33.09019477026803, 48.575412205287385, 43.918281350817, 39.58940076828003, 35.59038243974958, 39.32657126017979, 27.497624465397426, 52.05586910247803, 34.69247020993914, 22.963763339178904, 9.371414116450719, 9.85281137057713, 17.829930475779943, 49.01653943743025, 55.448271478925435, 42.04504353659493, 46.20442976270403, 57.077651841299875, 16.914816243307932, 0.2832427998738629, 0.4666803723999432, 5.435267431395395, 27.706211124147686, 61.39461626325335, 64.73001561846051, 61.30390058244978, 61.59291090284075, 53.18906123297555, 53.97510051727295, 48.706879070826936, 46.47725078037807, 50.71221603666033, 58.72850213732038, 58.119551590510774, 58.85056114196777, 57.64014325823103, 54.679616587502615, 53.14479078565325, 45.911399909428184, 47.869992869240896, 46.67166485105242, 49.83023950031826, 57.7386930329459, 56.127287660326274, 54.4719557762146, 51.06397206442696, 55.59310320445469, 47.99243402481079, 50.61900247846331, 54.1908802986145, 58.26670748846871, 54.208539145333425, 54.06707729612078, 52.926857062748496, 55.691917010716026, 50.82462051936558, 53.185698304857524, 24.241557904652186, 22.534265654427664, 6.5370732460703165, 10.449037160192217, 23.845434154782975, 35.86304364885603, 53.3238319669451, 41.195390020098, 25.012999023709977, 11.242157527378627, 5.438505291938782, 3.774449510233743, 1.3777734977858407, 0.23562921051468166, 0.20852166866617544, 0.18674320514713014, 0.31502084753343035, 0.980890440089362, 0.10840077325701714, 0.13947782638881887, 0.14981340749987535, 0.2516360144530024, 0.33814545667597223, 0.4100899004510471, 0.6514180994459561, 2.943766095808574, 15.437761238643102, 29.790700231279644, 48.55950777871268, 57.86069645200457, 63.58981622968401, 29.500619888305664, 12.08149470601763, 14.985252857208252, 19.440342256001063, 22.40797345978873, 42.48321083613804, 48.97152900695801, 51.8460612978254, 49.46958630425589, 52.2467291695731, 46.297466141836985, 48.18915489741734, 41.82950346810477, 40.75907094138009, 44.908611570085796, 43.28429644448416, 42.9055883543832, 47.25355216435024, 46.229054178510395, 48.12225764138358, 45.02540731430054, 44.69515943527222, 43.31398262296404, 42.330628395080566, 37.15246255057198, 39.56434556416103, 45.63489634650094, 45.77802576337542, 45.18174525669643, 50.23100464684622, 56.176665033612935, 55.93240458624703, 52.23587955747332, 52.25087377003261, 56.16739961079189, 57.43774570737566, 55.16736970629011, 62.01038646697998, 63.11953435625349, 62.344539233616416, 64.02412727900914, 64.93704414367676, 51.49791833332607, 10.057115333420889, 0.0807511837088636, 1.354946602668081, 35.49841260910034, 64.8230311529977, 54.13217496871948, 53.4086903163365, 50.60607188088553, 14.694628817694527, 7.668771948133196, 11.671281746455602, 39.43127366474697, 13.403474603380475, 24.949916328702653, 23.933247225625173, 28.919786964144024, 37.866813795907156, 23.002096550805227, 59.08905111040388, 21.539917639323644, 47.64111573355538, 39.82724108014788, 49.263280391693115, 64.30302102225167, 83.76376492636544, 24.884538991110666, 0.7906670559729848, 0.4103999909545694, 0.6158936428172248, 0.5853794344833919, 0.366658230977399], [0.22980520874261856, 0.1930096253220524, 0.1323602790279048, 0.08367246695395027, 0.11246230067419154, 0.034186158262725384, 0.03888352048982467, 0.011245147125529391, 0.03745178785175085, 0.423204598150083, 0.5267552030938012, 26.305362224578857, 62.945641790117534, 32.373995304107666, 21.539830786841257, 35.66353307451521, 31.124702249254497, 28.541170937674387, 22.3614205292293, 39.8256117275783, 21.1084657737187, 33.03071819032942, 26.172806228910172, 23.59113703455244, 7.987547482763018, 0.863305641072137, 5.7614840524537225, 35.49825974873134, 55.58383778163365, 47.35327965872628, 45.23701817648751, 53.850123269217356, 25.217651265008108, 0.9575388474123818, 0.22616906171398504, 1.3406934589147568, 18.106487887246267, 51.09368256160191, 62.50733552660261, 54.6561872618539, 56.305317878723145, 49.30082150868007, 44.96597242355347, 44.61373349598476, 43.52258144106184, 50.04409463065011, 53.49041502816336, 52.426624979291645, 53.50170585087368, 54.81553030014038, 50.277665274483816, 46.85948508126395, 41.30754436765398, 41.1614202771868, 41.17236368996756, 48.05986976623535, 51.521528312138145, 52.336121218545095, 51.10224274226597, 47.12897791181292, 46.39964982441494, 47.124722140175955, 45.05920335224697, 44.669808932713096, 48.46822581972395, 47.70137051173619, 43.39347696304321, 45.144832951681956, 51.11239753450666, 45.094736439841135, 30.210413115365164, 5.731100882802691, 0.8982301098959786, 3.7659501263073514, 1.5206701500075204, 6.827291250228882, 53.2452061516898, 46.03596373966762, 4.750728734901973, 8.177468674523489, 0.9031979090401104, 3.410569961581911, 0.4032796344586781, 0.11205755453556776, 0.2454740751002516, 0.03582903403522713, 0.10804081042962414, 0.13196117830063614, 0.3840185765709196, 0.03359784804550665, 0.07562361670924084, 0.09045926920537438, 0.04532917568992291, 0.042176715563982725, 0.05426120372223003, 0.08999781110989195, 0.5018024849040168, 4.120764664241245, 3.732779426234109, 7.830542513302394, 19.98280027934483, 28.64435863494873, 4.042725103242057, 3.922705829143524, 3.5537688604422977, 4.166937180927821, 12.111573457717896, 34.54824297768729, 42.14801236561367, 42.853129455021445, 42.34724153791155, 40.56171778270176, 40.724305629730225, 38.92741462162563, 39.557463373456685, 38.20758472170149, 37.137013231004985, 38.63409294400896, 39.68709244046892, 41.71357972281319, 43.06685951777867, 42.372946398598806, 43.65345423562186, 45.14317928041731, 42.92401497704642, 36.63538803373064, 38.44136381149292, 37.157482624053955, 38.5683525630406, 36.95964309147426, 35.23721940176827, 41.87264483315604, 50.103647640773225, 53.052577768053325, 53.00711570467268, 49.63291066033499, 45.79793930053711, 47.35918910162789, 48.12694420133318, 50.667202132088796, 53.11494132450649, 55.89436667306082, 51.29886981419155, 32.97849900381905, 3.836320613111768, 0.27871189585753847, 0.3733396295990263, 4.651791163853236, 49.53421497344971, 41.96867935998099, 25.885949850082397, 48.240748746054514, 47.35560730525425, 38.27596194403512, 3.80992614371436, 5.307730640683856, 26.434348583221436, 14.781955514635358, 14.002536126545497, 4.923124398503985, 17.17529031208583, 23.680857385907853, 23.600982631955826, 26.364864860262188, 21.517181396484375, 44.495958055768696, 37.075587681361604, 41.90492268971035, 47.048024450029644, 70.76816000257219, 7.835177830287388, 0.28757616877555847, 0.08543990818517548, 0.23656105622649193, 0.09805233390735728, 0.048087563033082655, 0.15609957304384026, 0.06665794351803404, 0.10455090126820973, 0.034206517705959935, 0.06349611960883651, 0.0884359252772161, 0.020579220727086067, 0.050228161205138476, 0.047664754292262454, 0.1946242536817278, 0.6375221365264484, 36.51556287493025, 74.00016321454729, 38.43840387889317, 21.153776713779994, 36.614887373788015, 36.3385922568185, 35.03791379928589, 28.044037750789098, 34.28202622277396, 23.244050196238927, 32.27557407106672, 26.930752209254674, 29.215504033224924, 15.211046729769025, 3.310828570808683, 6.89117602791105, 39.15776824951172, 55.99214172363281, 51.04256813866751, 46.47021572930472, 58.13785661969866, 30.24083580289568, 1.8114030808210373, 0.3070758267172745, 1.7287556699344089, 17.150830915996007, 53.390499932425364, 61.73434148515974, 56.91369867324829, 57.71617044721331, 50.687626361846924, 47.90413284301758, 45.29730074746268, 45.94400780541556, 52.86633130482265, 55.5286134992327, 56.664379937308176, 55.807990142277305, 54.694041047777446, 53.765407357897075, 47.76508549281529, 45.09382969992501, 45.11324296678816, 44.047198227473665, 50.61048746109009, 55.43035902295794, 53.439446517399375, 52.18198585510254, 51.19466420582363, 50.591345173971995, 48.84414073399135, 46.62655367170061, 49.80821023668562, 50.63014391490391, 48.82087121691023, 48.36639649527413, 49.955956731523784, 53.50198725291661, 42.725293023245676, 32.70951339176723, 9.078960963657924, 5.435869753360748, 1.6303877426045281, 1.9756197375910622, 9.725096532276698, 53.5379650252206, 59.064794949122835, 15.798572506223406, 8.112352762903486, 3.30208534853799, 3.7994482602391924, 0.4504310329045568, 0.05400647149820413, 0.3445789728845869, 0.08521850220859051, 0.0765219699325306, 0.036831304896622896, 1.000816028032984, 0.06742693404001848, 0.03635078675246664, 0.1220862546137401, 0.04338269620867712, 0.12297626185630049, 0.035383596151534996, 0.09683432962213244, 0.6260679768664497, 3.4969397612980435, 6.136027131761823, 11.984824419021606, 27.76263918195452, 35.06463309696743, 6.931437798908778, 3.880122491291591, 4.803104255880628, 9.770208580153328, 16.945304938725062, 37.70341648374285, 43.017593315669465, 42.873769078935894, 45.08277859006609, 44.70732920510428, 44.8608843939645, 43.79441581453596, 43.23275818143572, 40.568725040980745, 39.22263663155692, 40.8314642224993, 42.72507415499006, 44.17569473811558, 44.6750339780535, 44.40389095033918, 47.4418830871582, 46.93305608204433, 43.15624114445278, 39.49428340366909, 39.86730786732265, 40.15260090146746, 41.11905363627842, 39.85215732029506, 40.42601946422032, 43.22614349637713, 51.42528533935547, 55.75603151321411, 55.65405627659389, 50.55494008745466, 49.10131788253784, 47.74285473142351, 48.87964950289045, 52.82522923605782, 52.27279186248779, 53.09557669503348, 45.129800524030415, 21.55599750791277, 0.8416450119444302, 0.7050688862800598, 0.7059475077050072, 5.920777150562831, 56.69969415664673, 39.10276630946568, 29.401701859065465, 54.86672462735857, 50.605185985565186, 44.95575509752546, 4.309545048645564, 6.9593265652656555, 35.148014954158235, 18.03617559160505, 18.419952392578125, 8.605649675641741, 19.0404543195452, 23.81373473576137, 24.168452433177404, 27.98826629774911, 24.206158569880895, 38.38484716415405, 40.83714437484741, 47.17137929371425, 55.48993287767683, 78.46253258841378, 9.869626879692078, 0.42480718929852757, 0.07867927024407045, 0.0933042172608631, 0.09872024306761366, 0.058536666445434093, 0.30451129004359245, 0.14503019702221664, 0.2809778228402138, 0.13095063609736307, 0.10359725422625031, 0.14703882352582046, 0.12834905141166278, 0.1093787457793951, 0.17261001281440258, 0.4423222408763, 0.7297201177903584, 52.17439147404262, 85.46333599090576, 48.904451097760884, 31.75297921044486, 45.6386900629316, 38.187223025730674, 39.77605717522757, 32.903493200029644, 52.86487218311855, 26.26449465751648, 46.713044847760884, 35.29848166874477, 30.98338978631156, 15.682824202946254, 5.43318601165499, 15.141795771462576, 43.55357388087681, 63.14069856916155, 56.1912909916469, 54.14455318450928, 58.92278071812221, 31.965368270874023, 2.050119842801775, 0.4638780770557267, 3.0882295668125153, 20.155970232827322, 55.442250864846365, 67.36071477617536, 57.60938010896955, 62.46708461216518, 53.87282303401402, 51.50722891943795, 47.62301915032523, 50.03337356022426, 55.221979073115754, 60.06019387926374, 57.43920830317906, 60.58374759129116, 55.54819004876273, 56.978574003492085, 50.32535770961216, 46.75470624651228, 46.84117657797677, 46.42041104180472, 53.001324381147114, 57.78114652633667, 54.833077975681846, 53.77175453730992, 52.44814702442714, 55.37293563570295, 51.585868631090435, 51.64624500274658, 51.00196634020124, 53.63673366819109, 48.42912483215332, 51.31734160014561, 48.164009366716655, 53.58817965643746, 46.74444375719343, 37.56401130131313, 18.153871127537318, 14.755085093634468, 5.629536458424159, 5.1974800995418, 18.256119080952235, 55.74614422661917, 54.58130999973842, 30.423014095851354, 20.278060504368373, 12.458079252924238, 6.63750250850405, 0.7264791631272861, 0.19484057064567292, 0.39365100541285103, 0.11564557307532855, 0.2447695386196886, 0.2255511741553034, 1.8867118912083762, 0.08429139945656061, 0.12493607455066272, 0.27404390062604633, 0.1650893342282091, 0.13249161626611436, 0.146616041926401, 0.18005272772695335, 1.0160591815199171, 6.531480814729418, 16.30278938157218, 22.7972115448543, 32.86725834437779, 31.93808616910662, 12.507375853402273, 11.232291953904287, 10.715022887502398, 19.518438271113805, 25.81473776272365, 41.820359638759065, 45.92609534944807, 46.94365208489554, 47.581024238041465, 46.59586347852434, 47.684639249529155, 46.816058840070454, 44.264871392931255, 42.95912422452654, 42.06913988930838, 42.758088520595, 43.63538891928536, 47.78987666538784, 46.828569071633474, 47.9330165045602, 49.89747026988438, 49.99187544413975, 43.857543672834126, 42.34571640832083, 42.540231227874756, 42.00032493046352, 41.77339676448277, 44.41717938014439, 44.87250873020717, 46.04526737758091, 55.17121206011091, 58.42808287484305, 54.2205491065979, 51.60915551866804, 50.30870982578823, 51.27977269036429, 50.37683343887329, 53.56380884987967, 55.533789907182964, 60.91792120252337, 54.06523949759347, 33.504984855651855, 3.964096248149872, 0.5413996715630803, 0.8136099534375327, 5.273803021226611, 59.84354209899902, 48.21989025388445, 36.29596505846296, 58.931167193821494, 56.552711963653564, 45.35009316035679, 10.547815356935773, 9.833999991416931, 34.696076325007844, 21.705687761306763, 23.42860129901341, 8.26161743913378, 27.334013496126445, 35.5192745753697, 34.5110353742327, 36.527076039995464, 28.49457631792341, 54.62158523287092, 47.27150283540998, 53.959421907152446, 63.82043388911656, 91.75535365513393, 14.376089521816798, 0.5280780749661582, 0.235498307538884, 0.3215928391686508, 0.1384502529565777, 0.18400188295968942], [0.027870142266952565, 0.06533296140176909, 0.05465547667284097, 0.10035216728491442, 0.027519690804183483, 0.06733948444681508, 0.04313991637900472, 0.051934985510472736, 0.07051666360348463, 0.08107776261333909, 0.09444058021264416, 32.71651022774832, 61.27853965759277, 34.56653411047799, 43.39451919283186, 33.66017287118094, 28.13694211414882, 32.73860897336687, 22.82121409688677, 31.28959689821516, 24.507284811564855, 27.522229773657664, 29.861488478524343, 20.7273952960968, 15.944847720009939, 1.198692798614502, 1.3850293712956565, 21.06570134844099, 56.76939501081194, 47.083654812404085, 44.51304367610386, 48.471901416778564, 34.01834208624703, 1.7811634348971503, 0.15281591138669423, 0.6549299795712743, 13.249674490519933, 48.2541309765407, 58.53826740809849, 58.570152691432405, 53.32771600995745, 45.96696465356009, 44.676645960126606, 43.93400859832764, 45.99480608531407, 52.463582447596956, 55.08126415525164, 52.79130118233817, 52.125135694231304, 54.263402121407644, 53.14082336425781, 45.38879115240914, 40.700817244393484, 40.61940172740391, 42.3257611819676, 50.53490495681763, 51.07554081508091, 52.06611769539969, 50.06056533540998, 48.833714962005615, 47.02666916166033, 45.866486753736226, 44.398627689906526, 48.04475743430001, 45.2812955720084, 46.60933256149292, 48.73746504102434, 47.86104358945574, 45.23934234891619, 39.04630524771554, 21.821147714342388, 4.57261644090925, 2.7268346505505696, 2.046153941324779, 3.2448617219924927, 0.5741285096321787, 9.225389906338282, 14.383806364876882, 3.8669018064226424, 2.912810351167406, 0.7454255436147962, 0.1070012744250042, 0.075910704875631, 0.03745710078094687, 0.15650172717869282, 0.08679999091795512, 0.02120027195529214, 0.06395392718591861, 0.7555211133190564, 0.107212631297963, 0.01636783206569297, 0.0459129431151918, 0.025361935874181132, 0.04395073179953864, 0.07363278139382601, 0.02386687895549195, 0.05250643413247807, 0.12570364693445818, 0.26851994703922955, 0.3170332738331386, 0.18147633490817888, 1.0295963351215636, 0.30871761004839626, 1.0835357436111994, 3.085344110216413, 5.570405117103031, 7.113619565963745, 27.517369508743286, 38.34757355281285, 43.744444370269775, 41.33800874437605, 42.15631546292986, 39.155902658190044, 36.45678111485073, 38.08971200670515, 35.40261779512678, 37.2445296560015, 38.87007461275373, 39.03677579334804, 40.51645026888166, 42.100649969918386, 45.77391242980957, 46.9071809904916, 46.96040071759905, 43.620026452200754, 36.38288354873657, 37.52631037575858, 38.32464449746268, 40.964136600494385, 41.057537760053364, 38.486725125994, 38.97322409493582, 45.943875789642334, 52.52281584058489, 52.38766295569283, 52.42401940482003, 51.26940597806658, 50.06892054421561, 49.13474914005825, 49.02314370019095, 44.46725157329014, 29.25139147894723, 12.302135620798383, 1.044995823076793, 0.09775094222277403, 0.32352506262915476, 0.15418389226709092, 8.826168996947152, 49.33371080671038, 48.6742433820452, 36.73953110831124, 51.87893322535923, 49.20753846849714, 38.35194049562727, 0.11581087777657167, 11.256296242986407, 22.50878139904567, 21.157212597983225, 15.750812326158796, 9.611988544464111, 22.703195469720022, 30.334542683192662, 19.03599010195051, 29.17304359163557, 30.02078982761928, 35.281420367104666, 31.833053725106375, 45.45337813241141, 50.93196323939732, 50.36456292016165, 1.0424075105360575, 0.03933124164385455, 0.023355668976104686, 0.03958061683390822, 0.032130292151123285, 0.11455664650670119, 0.12729877419769764, 0.04729822324588895, 0.02169480693659612, 0.03196444122919014, 0.04593554850933807, 0.03913023582260523, 0.04899025209514158, 0.07261911114411694, 0.03991190137873803, 0.0756917619811637, 0.279566795698234, 45.26828159604754, 71.26861095428467, 40.22741910389492, 44.70196519579206, 41.061119556427, 28.38719538279942, 38.193090779440745, 23.927745989390782, 34.295040198734824, 21.8636828490666, 25.801244361060007, 24.766909463065012, 25.487696477345057, 18.12437081336975, 3.7764106392860413, 2.700160081897463, 20.96716720717294, 61.210495948791504, 50.37274442400251, 48.813829217638286, 51.748265402657644, 40.07788692201887, 2.591212327991213, 0.1406396683305502, 1.48040067085198, 13.1728013583592, 50.07293660300118, 58.876304217747276, 59.76759134020124, 56.15214484078543, 48.634503160204204, 46.83252259663173, 46.426317010607036, 49.846849169049946, 53.866138866969514, 57.14708171572004, 54.32385492324829, 53.76606396266392, 56.31856461933681, 55.91400923047747, 48.312891892024446, 44.53177601950509, 43.668570041656494, 45.74118988854544, 51.55949674333845, 53.07697984150478, 53.988798890795024, 51.312536920819966, 50.18597337177822, 49.02328961236136, 48.80945880072457, 47.7025899205889, 50.09296478543963, 49.916664668491904, 49.679793630327495, 50.116401059286936, 53.18989849090576, 48.118637629917686, 39.823971952710835, 26.10182343210493, 8.450835125786917, 4.313611047608512, 1.895268814904349, 4.665481720651899, 0.6207552648016385, 10.09149762562343, 18.24579926899501, 7.905737655503409, 3.222235130412238, 1.266278903399195, 0.06145077757537365, 0.046575149188616445, 0.011824018072469957, 0.05411802265526993, 0.006251958049168544, 0.020697845611721277, 0.09792029777807848, 1.0521080642938614, 0.3503974920936993, 0.019008337520062923, 0.018455385762665952, 0.03441273806882756, 0.07885543829096214, 0.027641277494175092, 0.013108849575343941, 0.07484215471361365, 0.044747623681489906, 0.6169739791325161, 1.0882757178374698, 0.6324297040700912, 0.8666638465864318, 0.9022402518561908, 1.3357539411102022, 3.8586113027163913, 8.043362362044197, 15.222030094691686, 33.56533343451363, 40.10023580278669, 45.32480519158499, 43.779946190970286, 42.87333481652396, 40.079262665339876, 38.94214480263846, 40.84763615471976, 39.12339898518154, 41.28821447917393, 40.77250875745501, 40.39200455801827, 42.72222539356777, 46.4269562448774, 47.334137371608186, 48.37637063435146, 48.37620040348598, 45.732865946633474, 39.842356886182515, 40.7976473399571, 41.397200448172434, 43.657063824789866, 45.32793188095093, 42.486882959093364, 40.25504514149257, 45.497297695704866, 53.98595012937273, 55.49144411087036, 54.702590806143625, 54.72252171380179, 53.40520926884243, 53.58885015760149, 50.17443936211722, 43.71763127190726, 27.378039019448416, 10.35913702419826, 0.6764076756579536, 0.13524256008011953, 0.2514024626995836, 0.5319553869111198, 11.665838701384407, 52.488811356680735, 51.42469474247524, 42.86983987263271, 54.85152544294085, 54.9836037499564, 35.523085662296836, 0.18563171050378255, 20.13256869997297, 31.937043939317974, 20.862780945641653, 18.294983829770768, 14.01067246709551, 22.946905272347585, 38.28202772140503, 21.415133203778947, 32.21501357214791, 28.19081323487418, 38.872478689466206, 36.67739684241158, 49.238308565957205, 58.413081714085166, 57.4145804132734, 1.9722713572638375, 0.04440681929034846, 0.009726085334217973, 0.025018748128786683, 0.08341699173407895, 0.03209185314231685, 0.21444461441465787, 0.23716495239308902, 0.14175826045019285, 0.11816540786198207, 0.10685414089156048, 0.09388775737690074, 0.13224494164543493, 0.27963844899620327, 0.12209057009645871, 0.18270073777862958, 0.40324462205171585, 58.94355583190918, 82.01560510907854, 48.78025552204677, 57.34531382152012, 45.50420420510428, 37.6910834312439, 44.90205594471523, 30.26167345046997, 43.555668762751985, 33.906663690294536, 36.944843428475515, 41.988221168518066, 26.126821313585552, 23.610192469188146, 5.304771142346518, 7.336617657116481, 29.3031416620527, 68.91020475115094, 55.963768754686626, 54.561184542519705, 56.034324237278526, 43.92831802368164, 3.550934212548392, 0.1861923025654895, 2.450021024261202, 15.667466947010585, 53.093283789498464, 61.96381269182478, 63.15904876164028, 59.396029472351074, 50.0718492099217, 50.23057038443429, 49.195108141217915, 51.86241388320923, 57.778527055467876, 61.48776381356375, 55.56284727369036, 56.858057498931885, 59.55674130575997, 58.474496841430664, 50.850495610918315, 48.9102771622794, 47.67821216583252, 48.223694392613, 53.70768172400338, 57.67827844619751, 57.04690258843558, 52.72058241707938, 52.008155822753906, 54.419910294669016, 51.602916036333355, 49.624833379473, 53.56727947507586, 53.312721797398154, 52.23725530079433, 51.36586781910488, 52.80353001185826, 51.07174015045166, 43.14572157178606, 34.64404126576015, 17.398518562316895, 12.455608299800328, 6.368103044373648, 9.811748385429382, 2.9953597273145403, 11.103753754070826, 26.898126942770823, 18.03495270865304, 8.306924905095782, 2.3534410638468604, 0.26927067818386213, 0.14099102733390673, 0.11893539583044392, 0.16873122166310037, 0.1488440523722342, 0.21629968844354153, 0.14630515075155667, 2.325929020132337, 0.1940772458910942, 0.0970661850380046, 0.1370410578591483, 0.13207228162458964, 0.23101164400577545, 0.11208171038223164, 0.08838388842663594, 0.12038767790155751, 0.5483979731798172, 1.8900778591632843, 2.89016769187791, 1.2285205466406686, 1.4577000375304903, 0.9570988310234887, 8.026147331510272, 11.249663318906512, 16.087947607040405, 24.25305196217128, 39.24809830529349, 43.694622312273296, 46.14800691604614, 44.758544376918245, 45.07988813945225, 43.45569460732596, 42.18936456952776, 43.29943309511457, 42.16899592535836, 42.9480105808803, 43.588443415505544, 42.95001861027309, 44.66666834694998, 48.79150812966483, 49.08950594493321, 51.02919980457851, 50.35355697359358, 49.953358105250764, 41.956603390829905, 42.203903675079346, 42.918362617492676, 45.69546379361834, 46.35774523871285, 44.42536783218384, 42.647487095424104, 49.58301912035261, 56.01584897722517, 56.15517772947039, 57.30933952331543, 53.44704784665789, 55.71801444462368, 53.07982860292707, 48.664199760981965, 46.56235579081944, 33.70013543537685, 15.508528641292028, 2.189474433660507, 0.13662086826350006, 0.9329117174659456, 0.5452184123652322, 11.634011609213692, 56.12746831348964, 54.439236709049766, 44.356386116572786, 58.9801242010934, 58.82677745819092, 47.46685143879482, 2.45135703257152, 17.509055716650828, 30.57342175074986, 31.442846366337367, 22.99282591683524, 13.188027467046465, 33.15107488632202, 43.67068576812744, 27.19498004232134, 40.46079172406878, 40.44933067049299, 48.034592219761436, 38.48068366731916, 59.469089780535015, 64.77115590231759, 71.37571048736572, 3.646891874926431, 0.1313336148325886, 0.14689292492611067, 0.15652197466364928, 0.15324790749166692, 0.1924632146422352], [0.10372661014220544, 0.08267779568476336, 0.11203161414180483, 0.04039313877001405, 0.0369804061816207, 0.02071962658581989, 0.054797582261796506, 0.05664938575189028, 0.10103018661694867, 0.17702252604067326, 0.06646242365241051, 36.231131417410715, 63.55906350272042, 35.33524806158883, 25.907859257289342, 27.77160062108721, 43.649490288325715, 30.020508425576345, 35.11319405691964, 29.41058165686471, 24.946320635931833, 25.63659289905003, 31.443892070225306, 20.05972899709429, 24.2284049647195, 6.737918743065425, 1.9970670895917075, 14.757852213723318, 48.62831231525966, 47.414924076625276, 41.58591004780361, 50.790709836142405, 38.592907496861045, 5.6088903205735345, 0.06295926270208188, 0.38221052501882824, 8.042903780937195, 48.98983403614589, 58.023041112082346, 58.12257405689785, 53.150644642966135, 49.16132252556937, 44.91791868209839, 46.21688788277762, 47.78829247610909, 53.37374087742397, 55.06689528056553, 53.76193673270089, 52.758415358407156, 52.061688218797954, 51.39421646935599, 47.032144342150005, 40.157322202410015, 42.102880341666086, 44.94224085126604, 52.096272877284456, 51.58977699279785, 51.03084305354527, 47.24417209625244, 49.26148428235735, 46.16624593734741, 45.141574246542795, 45.13262496675764, 47.03010851996285, 46.81290783200945, 49.85021904536656, 46.50344896316528, 50.73988028935024, 43.565684591020855, 34.13775382723127, 15.517015865870885, 4.080305303846087, 4.221552193164825, 4.429864398070744, 2.582116484642029, 0.05245738962133016, 0.20776449143886566, 0.2185843022806304, 0.25625803215163095, 0.1181929563837392, 0.09772224697683539, 0.01733640518172511, 0.0351436763469662, 0.018793326736028706, 0.08824883281652417, 0.03435798368549772, 0.03053304785862565, 0.06577439592885119, 1.1196963403906142, 0.5537623624716486, 0.06646688162748303, 0.1496015145842518, 0.053868304805031846, 0.03490999906456896, 0.05327356207583632, 0.018147639597633054, 0.04460072424262762, 0.09016720737729754, 0.043867804642234526, 0.03086288712386574, 0.0832887961130057, 0.1850172970443964, 0.06518128846905061, 0.8739273739712579, 6.135945924690791, 4.220287621021271, 7.433661409786769, 17.655695710863384, 34.975619724818635, 41.189577851976665, 43.01229184014456, 41.73669637952532, 40.25239440373012, 37.93632704871041, 39.13413742610386, 36.92200122560774, 38.39474139894758, 39.09553670883179, 39.24907105309622, 44.20560325895037, 44.20315054484776, 44.456183092934744, 47.68415634972708, 48.888501507895334, 42.385911737169536, 38.93674952643258, 37.84128264018467, 40.98555094855172, 42.64294644764492, 43.03884785515921, 39.49861560549055, 40.662838390895296, 40.94753040586199, 48.377968720027376, 53.308643204825266, 55.1639928817749, 51.873489311763215, 55.33253880909511, 52.96862268447876, 55.24674245289394, 47.09369843346732, 17.624373231615337, 4.657525599002838, 0.14378828794828483, 0.12340163545949118, 0.650387106197221, 3.0019520478589192, 25.00040020261492, 42.25927734375, 56.28656816482544, 43.4316851070949, 46.63125760214669, 55.760339396340505, 17.512682676315308, 0.1750807895192078, 22.03178756577628, 22.121785845075333, 24.645807572773524, 9.756015147481646, 13.108368975775582, 26.090534346444265, 21.087068796157837, 23.67348187310355, 29.022194726126536, 32.95627866472517, 30.003016335623606, 23.105367626462662, 35.405272006988525, 54.1095620564052, 42.976022243499756, 0.6579989120364189, 0.10082387804452862, 0.031583640591374466, 0.029459225479513407, 0.10648592707834073, 0.016200296680576036, 0.07075652573257685, 0.019026749567793946, 0.0389623255468905, 0.043704416802419085, 0.10079548135399818, 0.012393044324458709, 0.05946309744779553, 0.07717151114983217, 0.07242277703647103, 0.16643904894590378, 0.052469084172376564, 43.99632004329136, 72.28720991952079, 43.16840396608625, 27.58363274165562, 32.86330829347883, 36.77433810915266, 34.38417863845825, 31.102846690586635, 33.773841926029746, 29.583449363708496, 22.669993502753123, 21.917526176997594, 23.24091308457511, 31.43393530164446, 6.604370892047882, 4.8662659866469244, 18.153935398374283, 55.504419871738975, 53.64258057730538, 44.93408366612026, 54.978385652814595, 44.01861333847046, 7.315369197300502, 0.05910314140575273, 0.800311372748443, 8.075417876243591, 50.268559660230366, 61.13716466086251, 58.97427381787981, 55.09329843521118, 52.04640565599714, 46.96034860610962, 48.99543081011091, 50.00353799547468, 54.7408823285784, 57.47118738719395, 56.743843010493684, 52.49067347390311, 55.3256288255964, 54.092611925942556, 48.611515045166016, 43.67438915797642, 44.303246293749126, 46.07592282976423, 53.07783794403076, 52.83042301450457, 52.423279421670095, 48.78103372028896, 52.755465848105295, 48.543478284563335, 47.362916810171946, 46.96624067851475, 50.25885302679879, 48.861181191035676, 52.395170484270366, 49.307158265795024, 53.90329783303397, 43.02905436924526, 35.962031160082134, 20.525383370263235, 8.578132203647069, 4.439731274332319, 4.7286951286452155, 2.4184985671724593, 0.017209313876394714, 0.20876313213791164, 0.22891114386064665, 0.07156746328941413, 0.17892619674759253, 0.04349187927852784, 0.0716761171019503, 0.04049799278644579, 0.023116566806233356, 0.07901331303375107, 0.05693028228623526, 0.029569711336599927, 0.04703843932864921, 0.3986089793699128, 0.6574808369789804, 0.04859036087457623, 0.019289715814271143, 0.028402374957555106, 0.03500313138855355, 0.05578702881133982, 0.08783969655632973, 0.05006550279046808, 0.03143636456557682, 0.05315953426595245, 0.044134221239281554, 0.05632683734542557, 0.06155595050326415, 0.07674558793327638, 1.0098251274653842, 7.899860348020281, 8.833947505269732, 13.006594368389674, 23.539336477007183, 39.96138647624424, 43.687597683497835, 46.56511769975935, 42.124186992645264, 43.54269995008196, 40.60987227303641, 40.78756897790091, 41.36247335161482, 41.55104398727417, 41.67636169706072, 41.540201323372976, 45.93295669555664, 47.79145390646798, 46.697456564222065, 50.22711018153599, 49.919839995247976, 43.632665225437705, 41.03544248853411, 39.78952625819615, 44.220246587480815, 45.13996226446969, 45.259714467184885, 43.097257886614116, 41.8637615612575, 42.98035791942051, 49.37343365805489, 54.64260005950928, 54.890883513859336, 53.860344069344656, 55.883728981018066, 56.12851401737758, 57.46800511223929, 48.990914481026785, 20.79137257167271, 5.857640607016427, 0.2757685195122446, 0.22994164856416838, 0.2863943779042789, 3.9025712524141585, 29.398655073983328, 43.84047194889614, 57.848019463675364, 48.70108427320208, 50.76444564546858, 64.47602421896798, 19.285885538373673, 1.097900275673185, 27.176244224820817, 26.548722880227224, 21.136500017983572, 15.638305357524327, 12.975099921226501, 28.29252965109689, 27.184408358165197, 21.84533613068717, 29.124048369271414, 29.427055835723877, 33.40074103219168, 23.827313252857753, 38.353010518210276, 63.661869049072266, 47.582809925079346, 0.8580062825764928, 0.10092967522463628, 0.07629509496369533, 0.07300215094749417, 0.036689348585371456, 0.006678089915242578, 0.11254886817187071, 0.15657207768942627, 0.283113851078919, 0.17746717003839357, 0.2369820736348629, 0.1574525311589241, 0.12933967182678835, 0.17253327050379344, 0.1848486132387604, 0.30772021785378456, 0.33592843849744114, 57.88136386871338, 84.48652349199567, 52.2061482157026, 36.823583466666086, 35.60505703517369, 53.16662549972534, 41.15981176921299, 45.70038659232003, 39.65961578914097, 33.92174128123692, 35.00349242346627, 43.709543568747385, 26.596496956689016, 31.61553689411708, 12.83664664200374, 6.619971769196646, 20.941821915762766, 58.421322277614046, 58.32458945683071, 50.58177055631365, 58.9614474432809, 46.13232830592564, 7.574614303452628, 0.11776174737938813, 1.909771008150918, 10.131523592131478, 53.84328971590315, 62.498205593654085, 61.38575036185128, 56.67578193119594, 53.62869112832205, 50.310214110783164, 51.64155844279698, 51.817896774836946, 58.01948363440377, 61.8714085987636, 58.136744907924104, 57.192679268973215, 56.386827196393696, 56.82739857264927, 50.153685092926025, 46.35541411808559, 48.28744411468506, 48.48666633878435, 55.31059292384556, 57.85019424983433, 54.29477323804583, 51.0501833643232, 56.50596448353359, 50.66993277413504, 51.24567787987845, 50.860441957201274, 52.885664667402, 51.05274724960327, 54.24598298754011, 50.7025580406189, 54.293991565704346, 46.08066150120327, 38.628794942583355, 29.252127987997874, 17.811371837343486, 9.956078103610448, 11.356240000043597, 7.954736351966858, 0.222561277449131, 0.34926688990422655, 0.4971727047647749, 0.43618114611932207, 0.4263317489198276, 0.18055974266358785, 0.1152765043079853, 0.08443349147481577, 0.10976198914327792, 0.13306178924228462, 0.20139350901756967, 0.09620973813746657, 0.21668002089219435, 1.895149392741067, 1.4807777191911424, 0.211041069190417, 0.15532726448561462, 0.15592567808926105, 0.13503325916826725, 0.13831290389810288, 0.15296721112515244, 0.13337363036615507, 0.2328312849359853, 0.12355684355965682, 0.2514955848455429, 0.15800122171640396, 0.21118905767798424, 0.18990387554679597, 4.51153005020959, 16.497132233210973, 17.585531064442225, 21.920121329171316, 30.35584933417184, 43.426064014434814, 47.21101529257638, 47.93967982700893, 44.06760508673531, 45.99297176088606, 42.01714651925223, 44.18708283560616, 43.59189667020525, 44.821231024605886, 45.094976152692524, 43.29073395047869, 49.65394980566842, 48.643164089747835, 50.54169682094029, 53.914804049900596, 53.69899647576468, 45.795191287994385, 44.6324519429888, 43.37636702401297, 46.44941282272339, 46.45084415163313, 49.67107016699654, 42.881102902548655, 45.14665337971279, 45.14907830102103, 52.85331385476248, 58.102504185267854, 57.527770042419434, 55.51792369570051, 58.29178006308419, 56.665526390075684, 58.73913982936314, 50.28803546088082, 22.669244834354945, 7.21066505568368, 0.5549761259130069, 0.7075770231229919, 2.2428092403071265, 4.24094591821943, 29.233051708766393, 48.7682455607823, 61.00103555406843, 51.6942709514073, 55.6825647354126, 64.4325840813773, 23.47711362157549, 2.1030625104904175, 28.89059410776411, 29.823405402047293, 35.71007210867745, 17.233500582831248, 15.98715009008135, 39.62165778023856, 28.054079634802683, 30.222162519182476, 40.26495327268328, 44.37227317265102, 38.87860352652413, 30.462608405521937, 48.491967814309255, 71.83447919573102, 61.27738625662667, 1.2811107018164225, 0.21552332224590437, 0.20189091589834007, 0.15254398169262068, 0.18707990779408387, 0.11443813358034406], [0.02416281691486282, 0.05080374549808247, 0.0257229385564902, 0.08163264141018901, 0.13767273324940885, 0.03820961308000343, 0.0696964572582926, 0.12732396141758986, 0.1089511194399425, 0.07061096640037638, 0.03996057269562568, 26.635851553508214, 62.44826889038086, 36.501103673662456, 41.94197743279593, 36.603037221091135, 37.950876576559885, 33.107877935682026, 30.871985844203405, 34.71347114018032, 22.712744031633648, 20.320871829986572, 32.10385281699044, 21.25700957434518, 11.480109878948756, 6.996270137173789, 2.9279061811310902, 32.081691537584575, 46.242610113961355, 49.46757132666451, 43.01120097296578, 50.8180718421936, 47.526616368974956, 14.278178981372289, 0.06559678938771997, 0.6335542265857969, 5.044310535703387, 47.18005064555577, 59.795933042253765, 59.153196879795615, 54.089318479810444, 51.58172403063093, 45.16716793605259, 48.05044453484671, 50.448455469948904, 53.71522051947457, 53.1091638973781, 54.39181872776577, 52.337458746773855, 53.52767474310738, 49.62073046820504, 46.935741560799734, 41.24133150918143, 42.48748745237078, 43.48282037462507, 51.82391391481672, 50.86833511080061, 51.8824976512364, 48.36223105021885, 49.57898569107056, 43.59159442356655, 47.464541162763325, 43.39213943481445, 46.859227997916086, 46.107971395765034, 47.57789407457624, 49.01962096350533, 45.81672722952706, 34.99866342544556, 36.59432418005807, 11.677126049995422, 1.9315520908151353, 4.799366125038691, 4.176366754940577, 0.5890291929244995, 0.019735301279329827, 0.11317577346095017, 0.190731213295034, 0.032515533800636015, 0.009824656964545804, 0.08119278108435017, 0.040858332200774124, 0.07062894757837057, 0.020496361423283815, 0.03844229630859835, 0.015199454135394521, 0.04318623996472784, 0.0916175963357091, 0.1385948351983513, 0.8907715986881937, 0.02536359489230173, 0.04425833886489272, 0.013825144219611372, 0.07818119161363159, 0.035981100518256426, 0.056195751165172884, 0.07752354868820735, 0.0420590508063989, 0.06432392554623739, 0.03468051852126207, 0.10834041756710835, 0.06524758812572275, 0.09999723240200963, 0.1895358245819807, 7.577179057257516, 7.983962212290082, 7.428072452545166, 12.732614738600594, 29.251381056649343, 38.35815913336617, 42.418332031794954, 40.61373199735369, 39.134689807891846, 39.11803150177002, 37.2005649294172, 37.78865350995745, 37.00958326884678, 39.099194935389924, 40.835372584206716, 44.97656842640468, 47.79273584910801, 46.24842923028128, 46.6569242477417, 47.481425285339355, 43.28079802649361, 39.123815877096995, 36.50841317858015, 41.45435285568237, 44.54976143155779, 44.67254652295794, 43.55629410062517, 40.90760605675833, 42.04806252888271, 43.520021029881065, 48.31902367728097, 53.25654213769095, 53.423222473689485, 51.895872933524, 53.29750524248396, 55.62685407911028, 57.44164712088448, 24.26901718548366, 4.651522355420249, 0.5412923001817295, 0.20930066757968493, 0.5112219623156956, 5.205756706850869, 43.620756013052805, 49.301377364567344, 47.63283348083496, 49.08761950901577, 51.95966781888689, 33.89973633629935, 7.486540675163269, 1.0554282175643104, 31.06628179550171, 22.698158025741577, 33.22205073492867, 11.123079299926758, 19.954889365604945, 20.068070309502737, 31.28539671216692, 26.772159576416016, 24.888737440109253, 26.196430104119436, 33.146131243024556, 32.566165106637136, 42.75364167349679, 54.245764119284495, 25.445446218763077, 0.35187732268657, 0.25531695836356705, 0.06057511456310749, 0.05568162178886788, 0.08031370504094021, 0.10533697730196373, 0.07578371026154075, 0.12246546069426195, 0.07031242456287146, 0.060410196626824994, 0.08524536540997879, 0.02790647612086364, 0.015203679712223155, 0.049812816349523406, 0.14162777816610678, 0.05444989074021578, 0.039113496363695176, 35.860219206128804, 74.23793751852853, 44.52371610913958, 45.16084507533482, 42.52365977423531, 40.434138434273855, 35.73168100629534, 29.67494671685355, 34.670145647866384, 27.92329716682434, 20.568448305130005, 22.35463387625558, 15.893453632082258, 20.168249436787196, 10.617823668888636, 4.091008569513049, 35.13020672116961, 52.22985199519566, 53.655851636614116, 50.07099805559431, 55.30496488298689, 50.74796104431152, 17.884652750832693, 0.09848047593342406, 0.7104308328458241, 6.054846984999521, 46.12047815322876, 61.312926292419434, 59.71509769984654, 55.26507874897548, 54.73702260426113, 47.73622267586844, 49.64993722098214, 53.16025052751814, 57.51862621307373, 55.56365326472691, 55.96369232450213, 53.06565775190081, 58.22039079666138, 51.61015258516584, 48.88329383305141, 43.964851651872905, 44.539252281188965, 45.485471861703054, 54.28950302941458, 51.40218257904053, 53.95289754867554, 51.97782346180507, 52.25693259920393, 47.199960708618164, 50.97320774623326, 47.09973989214216, 50.463790144239155, 49.279615606580464, 50.056820256369456, 48.677467346191406, 48.99951982498169, 40.57089982713972, 42.30698367527553, 20.083926098687307, 5.123358888285501, 5.20970675774983, 4.13812734399523, 0.214651472600443, 0.06136146879621914, 0.05906440384153809, 0.10791509824671916, 0.04032024714563574, 0.032101871711867194, 0.07736188772001437, 0.008534728815512998, 0.013772621368324118, 0.016339007898100784, 0.06139162289244788, 0.05877831990697554, 0.04792080626689962, 0.0371964822656342, 0.1379023359290191, 0.7483323333518845, 0.0779022526528154, 0.03222328537542905, 0.025729114921497445, 0.06783003812389714, 0.03768352452399475, 0.019898159861830727, 0.03456019390640514, 0.01931818205464099, 0.07505098743630306, 0.04905705726040261, 0.06561354920268059, 0.10580755490809679, 0.11074056556182248, 0.03651225094550422, 9.43440648487636, 12.10209698336465, 12.241202524730138, 19.89039444923401, 34.06397785459246, 41.727010590689524, 43.79275172097342, 42.95077248982021, 41.93978180204119, 40.78001281193325, 41.09019776753017, 39.63143389565604, 42.17866781779698, 41.68719046456473, 42.58020421436855, 47.00518880571638, 49.51045560836792, 49.469040870666504, 49.0320964540754, 49.08130012239729, 45.4390926361084, 41.14462300709316, 37.75002499989101, 44.894909722464426, 46.20742791039603, 46.51617111478533, 45.50001096725464, 43.591309547424316, 45.42619330542428, 45.65439993994576, 49.1870447567531, 54.67226191929409, 52.99972629547119, 52.76824358531407, 53.41595465796334, 56.997396673474995, 57.66497264589582, 28.90813830920628, 5.959505106721606, 0.32841730011360987, 0.22304470650851727, 0.24813773216945784, 7.877165794372559, 48.83141163417271, 50.699167319706504, 52.84406927653721, 51.110055991581504, 56.96929121017456, 38.950322832380024, 5.64969448532377, 1.5550450597490584, 33.59783015932356, 25.359505687441143, 29.225460801805767, 12.208334071295601, 14.520556466920034, 27.649444341659546, 30.378048828669957, 23.778206859316143, 30.73344918659755, 23.605752570288523, 34.86144345147269, 31.95010655266898, 46.53297185897827, 63.30000686645508, 31.724880695343018, 0.4751906671694347, 0.1458784065076283, 0.052307413026158295, 0.09742566610553435, 0.01308160469800766, 0.06583268208695309, 0.188612039866192, 0.19834698177874088, 0.188166133793337, 0.14609363781554358, 0.24571704491972923, 0.12357918093247072, 0.20788901618548802, 0.39054423783506664, 0.25506193776215824, 0.3858599306217262, 0.17882672351385864, 48.0802001953125, 87.12171118600028, 52.03148439952305, 54.22414479936872, 48.791181564331055, 48.762044293539866, 45.74954162325178, 39.970717906951904, 46.743974753788535, 29.89817496708461, 29.153744970049175, 43.70219932283674, 29.815970829554967, 16.274164540427073, 12.772922107151576, 8.170421464102608, 41.8779011453901, 58.315855571201865, 59.2535914012364, 53.20053965704781, 62.01317964281355, 56.673440388270784, 19.203370468957083, 0.24767133433903965, 2.052484401634761, 7.402312006269183, 50.99102987561907, 63.7167945589338, 63.787666184561594, 58.570771081107004, 58.25731004987444, 50.04011331285749, 52.37011180605207, 53.49065474101475, 60.91081319536482, 56.63326937811715, 58.82559626443045, 55.8468861579895, 60.12177576337542, 54.3779570715768, 52.019814899989534, 47.19436046055385, 48.82433141980852, 49.26163714272635, 58.142449378967285, 55.26212576457432, 55.60849346433367, 54.98425340652466, 55.98176111493792, 49.1997286932809, 54.7935323034014, 49.12001895904541, 55.63551500865391, 52.21107448850359, 54.1833484513419, 47.590817723955425, 52.04376881463187, 36.4156026159014, 46.532106808253694, 23.90733913012913, 11.867088930947439, 10.638934901782445, 11.311168772833687, 2.6192737136568343, 0.2150642525936876, 0.1897235752216407, 0.2597872284906251, 0.20088903180190495, 0.0715192873030901, 0.17227535934320518, 0.14119850977190904, 0.1174729900168521, 0.08399163625602211, 0.15121756786746637, 0.18451508613569395, 0.19355394611401217, 0.10871237010828086, 0.3569166122802666, 3.394365676811763, 0.18625251576304436, 0.1620353702455759, 0.10112963949463197, 0.20016455996249402, 0.08942146346505199, 0.1990018223545381, 0.1363970467022487, 0.07627510532204594, 0.13431516555803164, 0.1860302819737366, 0.16409044925655636, 0.13940188474953175, 0.14245282246598176, 1.2663038734878813, 18.265724965504237, 18.9651323727199, 21.844524928501674, 29.23914180483137, 40.68545477730887, 43.03055170604161, 46.195935589926584, 45.30914395196097, 43.9235063961574, 43.97098691122872, 43.98678364072527, 43.69838128771101, 45.10230302810669, 43.51927409853254, 44.63401528767177, 49.587017808641704, 55.12423528943743, 50.14111580167498, 52.266576698848176, 49.47000667027065, 46.3256619317191, 43.85507358823504, 39.44188008989607, 45.7947222845895, 48.81580250603812, 48.28329604012625, 47.56267751966204, 45.327455929347444, 47.755298955099924, 47.63850668498448, 52.2923857825143, 56.84093018940517, 55.70763383592878, 55.52198839187622, 57.139890330178396, 58.58064447130476, 63.103213037763325, 29.549285071236746, 8.39621012551444, 0.8580775016120502, 0.4164541246635573, 1.0990062334707804, 8.136149474552699, 48.92402069909232, 58.95788996560233, 55.14968306677682, 57.91016067777361, 61.474791526794434, 41.5324957711356, 12.293716141155787, 3.3925322209085738, 40.074152265276226, 29.82778971535819, 42.59955147334507, 14.135785205023629, 27.977986437933787, 32.071453366960796, 41.84839909417288, 38.16941131864275, 37.38200323922293, 34.712988240378245, 44.81763185773577, 43.96335778917585, 55.75603151321411, 70.58857686179024, 42.2232335635594, 0.6890764672841344, 0.30835890929613796, 0.1606600611869778, 0.13399391993880272, 0.1893613596579858, 0.18881408045334475], [0.08382055722177029, 0.03971330435680492, 0.05798229654984815, 0.030436824807631116, 0.010319948512395578, 0.08135750903082745, 0.06500431975083691, 0.06948750239929982, 0.07140512378620249, 0.024594375364748493, 0.014636787452868052, 25.452512536730083, 62.735507420131135, 39.770401341574534, 21.960565056119645, 28.36281415394374, 28.438718012401036, 29.455380167279923, 30.811220373426163, 43.70552403586251, 31.314252580915177, 15.109347684042794, 17.676540306636266, 48.81284952163696, 14.569658517837524, 12.120835406439644, 0.8868549317121506, 16.805748632975988, 51.13823788506644, 45.32770953859602, 47.729538508823936, 50.54148142678397, 48.47394071306501, 21.567840712411062, 0.1614574755408934, 0.20316301978060178, 2.8390372012342726, 37.38726649965559, 59.83658695220947, 58.92191914149693, 57.72737789154053, 52.84133516039167, 47.56678737912859, 51.260199614933555, 53.23439475468227, 54.93022421428135, 55.38400411605835, 52.71814012527466, 53.42822865077427, 53.5693222454616, 52.37673691340855, 46.95227132524763, 42.94262225287301, 42.82112257821219, 45.37371008736746, 51.96186692374093, 49.52063471930367, 53.081965173993794, 50.17966093335833, 48.19807638440813, 46.94241530554635, 46.6223395892552, 44.84630012512207, 45.6447627885001, 44.28951317923409, 47.89745909827096, 44.5951748575483, 46.16308103288923, 55.88811329432896, 29.01160740852356, 9.569738285882131, 4.322843900748661, 5.746425134795053, 1.8177091138703483, 0.07520686050078698, 0.02612486368577395, 0.12190272446189608, 0.0445057021986161, 0.06225490264062371, 0.08183569979986974, 0.10192064169262137, 0.04897566359224064, 0.019224489939266017, 0.05560661652790649, 0.05864336607711656, 0.007906099199317396, 0.011274188424327543, 0.09621941404683249, 0.018115621226440583, 0.14333738785769257, 0.041702948843262026, 0.16287980707628386, 0.05901821596281869, 0.00962109221810741, 0.02891946444287896, 0.04526046384125948, 0.07577552034386567, 0.12533437460660934, 0.02186430837692959, 0.056179306868995936, 0.018007612022172128, 0.0508070940683995, 0.04922239588839667, 0.04030071890779904, 2.8880137503147125, 8.406236376081194, 8.067316276686531, 8.868299399103437, 19.895454474857875, 38.73097167696272, 40.7606794493539, 40.96475499016898, 38.50300128119332, 37.799371106284006, 38.05182000568935, 37.66217197690691, 37.88317332948957, 40.5088072504316, 41.285834721156526, 45.39322757720947, 45.90677240916661, 45.9835604258946, 49.33527762549264, 47.60296317509243, 43.520142623356406, 36.40354054314749, 40.18059866768973, 43.228773389543804, 47.186498573848176, 47.96739271708897, 49.479838371276855, 43.41217109135219, 41.8064979825701, 42.488435881478445, 43.38697692326137, 47.06324795314244, 50.19127137320382, 51.03263568878174, 54.708969252450125, 53.29846061979021, 56.78348248345511, 37.95505244391305, 4.8289988892419, 0.15072710918528692, 0.033870619123003314, 0.7653245872684887, 16.803796189171926, 48.8951370375497, 49.93742935998099, 51.24603918620518, 44.013009616306846, 27.397606883730205, 36.54020813533238, 2.1320842674800327, 3.3502565579754964, 43.940911633627756, 20.14734057017735, 17.83898745264326, 12.89289925779615, 29.546787193843297, 20.447520119803293, 36.74872357504708, 29.890726498195104, 20.479825769151958, 26.382963180541992, 41.01121759414673, 32.94799641200474, 38.61906051635742, 59.9967429297311, 19.747560330799647, 0.13184953214866774, 0.16812200578195707, 0.04861169062288744, 0.049860164523124695, 0.08285717320229326, 0.0855468860162156, 0.0838497681543231, 0.04530572551967842, 0.05377316741006715, 0.05002713163516351, 0.054045707785657475, 0.03830453334376216, 0.014178635519264, 0.07210894101964575, 0.05244279772575412, 0.1168410839246852, 0.04798580313633595, 32.10336644308907, 72.85966505323137, 47.413388524736675, 23.585460356303624, 33.26928458895002, 33.132564885275706, 34.08022274289812, 28.47191650526864, 40.625443186078755, 34.13045127051217, 18.805784123284475, 13.200673188482012, 23.819824831826345, 14.247065816606794, 18.607166392462595, 1.5057471564837863, 16.58540562220982, 55.280771255493164, 50.12894255774361, 50.736583369118826, 57.18401139123099, 54.032701083592, 27.0005590234484, 0.19301337083535536, 0.15255649387836456, 3.449931723730905, 39.202288831983296, 61.59092371804373, 59.3227607182094, 59.1148567199707, 54.449276856013704, 51.26675524030413, 54.40866463524954, 55.35651009423392, 57.16937153679984, 57.65584618704659, 54.09978594098772, 54.51659100396292, 56.71810340881348, 53.63342979976109, 48.763697964804514, 46.16082981654576, 46.204467977796284, 47.719387190682546, 54.002750873565674, 53.73452608925955, 55.32198102133614, 50.49095065253121, 50.804105963025776, 49.257475171770366, 50.63354853221348, 47.29527262278965, 49.55775894437517, 46.58119930539812, 49.963651861463276, 45.45345456259591, 50.78146873201643, 55.4932541166033, 33.59769466945103, 15.110153675079346, 5.564523032733372, 6.800352215766907, 1.1540227213076182, 0.2638247018413884, 0.03786489014912929, 0.023942779882677963, 0.03346733862001981, 0.07902233076414891, 0.008536289446055889, 0.06769692990928888, 0.04699208181617515, 0.04518108542210289, 0.010390959746603454, 0.023430798069706986, 0.04192261777019926, 0.033950669291828356, 0.04625888740909951, 0.016380805655249527, 0.9119230551379067, 0.08505618306142942, 0.10818453093192407, 0.04155580173911793, 0.01496541892577495, 0.05416864476033619, 0.05249977091859494, 0.03157554566860199, 0.06527564554874386, 0.0984862841931837, 0.019522103880132948, 0.12055231763848237, 0.00666711715582226, 0.09214621582733733, 0.022968744559745704, 2.2194628587790897, 11.202977504049029, 11.674248627253942, 14.029078245162964, 26.90092532975333, 42.03028208868844, 43.16925164631435, 44.067959444863455, 41.076558453696116, 42.20822198050362, 40.90003946849278, 42.77190153939383, 40.81554937362671, 43.1409273147583, 44.19033459254673, 47.298875263759065, 46.03763130732945, 47.39732081549508, 49.98439918245588, 49.69579880578177, 45.2251159123012, 38.70122643879482, 42.12612901415144, 47.015089988708496, 50.466593742370605, 49.203227111271445, 52.081146648951936, 44.02470343453543, 43.037864685058594, 44.42703192574637, 43.936881678445, 48.49929468972342, 52.580273968832834, 51.81130640847342, 57.02410554885864, 54.43395607812064, 59.59551920209612, 38.659933294568745, 6.14829808473587, 0.2740692235529423, 0.147924542427063, 1.9655576603753226, 23.235634190695627, 52.76128149032593, 53.63651827403477, 56.29257140840803, 45.944348267146516, 29.618183408464702, 33.78620971952166, 1.7441872933081217, 5.444293141365051, 49.569386754717144, 27.885716097695486, 14.921378067561559, 11.78159395286015, 30.932251044682094, 25.703064577920095, 27.636798620224, 27.770745992660522, 25.296610593795776, 24.018574578421457, 43.35996927533831, 32.47765895298549, 43.512603827885215, 69.86102403913225, 28.11706852912903, 0.16408914646932057, 0.2903421217841761, 0.07843885850161314, 0.011556199452440654, 0.0893102583608457, 0.1603640163583415, 0.17383607131029877, 0.16542273919497216, 0.19503498449921608, 0.14389044818069252, 0.154875550153, 0.23230862298182078, 0.2938307688704559, 0.33478573124323574, 0.16600109530346735, 0.31132109463214874, 0.10445948903049741, 40.85608516420637, 84.960800579616, 55.031362192971365, 31.649558748517716, 40.2259704044887, 35.63204036440168, 41.12889575958252, 40.8044114112854, 57.575705664498464, 41.82891287122454, 22.005014419555664, 26.056463854653494, 62.667428970336914, 19.210693870271953, 19.90736542429243, 4.875391576971326, 23.011429718562535, 60.68999249594552, 55.8845453943525, 58.61016736711775, 61.439633641924175, 58.797678402491975, 27.379407814570836, 0.5012271414910043, 0.6877092463629586, 5.127131760120392, 40.27821043559483, 64.77199663434709, 63.26710714612688, 62.151323727199006, 56.70006241117205, 52.46473584856306, 57.1938465663365, 59.16024235316685, 59.46816567012242, 58.63542406899588, 55.2390091078622, 58.464831897190635, 60.043851716177805, 55.38115188053676, 50.904323305402485, 49.627015113830566, 49.42299863270351, 50.14920350483486, 56.56365885053362, 56.48351485388619, 61.66907705579485, 53.06676598957607, 53.76428174972534, 51.33822788511004, 54.75916998726981, 47.52460486548287, 52.57125520706177, 48.04280151639666, 52.130760260990684, 48.95549256461007, 45.71487358638218, 60.20258331298828, 45.14752537863595, 23.302258729934692, 11.804264187812805, 11.83317824772426, 6.658592462539673, 0.2425846287182399, 0.09779094186212335, 0.20217092015913554, 0.1592375532324825, 0.11681110624756132, 0.16247401599373135, 0.23451763444713183, 0.15604044550231524, 0.08546086813190154, 0.12012437917292118, 0.11745541595986911, 0.21667981733168873, 0.0773081545318876, 0.15650151004748686, 0.12043687169040952, 2.1104028480393544, 0.38541019761136597, 0.20971709809132985, 0.18465862343353884, 0.14992851418043884, 0.23454265881861958, 0.14324970756258282, 0.12331793137959071, 0.33442000086818424, 0.13101295275347574, 0.10782983353627579, 0.13592807043875965, 0.14803582217012132, 0.14365528151392937, 0.3077259175479412, 7.794023650033133, 19.862396683011735, 17.304664032799856, 25.53221879686628, 33.101711409432546, 48.21051018578665, 44.571630886622835, 45.30293921061924, 43.37568610055106, 42.14237042835781, 44.3587589263916, 44.74967500141689, 43.28836808885847, 44.74021850313459, 45.11100912094116, 49.41799940381731, 49.24555206298828, 50.82482549122402, 51.86802455357143, 52.05825580869402, 47.590379987444194, 41.91897889545986, 46.65511771610805, 48.605966908591135, 50.51003040586199, 52.38849326542446, 53.57504408700125, 46.96399641036987, 45.18595239094326, 47.29713821411133, 48.08347279684884, 51.32028068814959, 56.470785754067556, 54.47998094558716, 59.78149468558175, 55.16864470073155, 61.66330310276577, 40.197618280138286, 8.714023334639412, 0.6285316560949598, 0.21024081856012344, 1.7082977848393577, 21.051853588649205, 55.00461162839617, 59.87215478079659, 58.63158866337368, 53.18273489815848, 34.0284343447004, 44.22080244336809, 4.84869920355933, 7.11907433612006, 53.2486628804888, 27.86550031389509, 26.128502777644567, 17.436386244637625, 39.27784701756069, 28.181577341897146, 48.88056666510445, 42.22539445332119, 31.183418001447404, 35.51274674279349, 51.03895160130092, 42.147279330662315, 53.50694479261126, 78.54692540849958, 36.53364208766392, 0.37890109260167393, 0.3927314547555787, 0.16885949192302568, 0.14072021043726377, 0.27049763234598295, 0.2598424612411431], [0.07354682457766362, 0.016706811197634255, 0.04747617583987968, 0.03754432985026922, 0.049783422212515555, 0.030179598967411687, 0.06263977448855128, 0.1469384003430605, 0.10326547095818178, 0.02896234785605754, 0.08068878562854868, 17.391891717910767, 70.20496681758335, 41.41777753829956, 39.00812489645821, 46.00839328765869, 30.37565517425537, 29.65748241969517, 28.371553250721522, 42.52919054031372, 29.336333206721715, 19.16106288773673, 10.907732043947492, 24.290633031300136, 19.265463045665197, 12.435827646936689, 1.5414255048547472, 7.081300454480307, 55.172990798950195, 50.55773673738752, 45.469008105141775, 49.99319907597133, 53.12806647164481, 25.120006493159703, 0.9388536214828491, 0.0391229212151042, 2.682819983788899, 31.414699213845388, 57.95347922188895, 58.29526111057827, 60.321842193603516, 54.198342663901194, 51.65164722715105, 52.52067232131958, 54.02408184323992, 54.79667983736311, 55.21046590805054, 53.51145069939749, 52.954107897622244, 55.10848024913243, 50.26235491888863, 46.298039368220735, 40.727540016174316, 43.24124193191528, 45.78912551062447, 50.28431470053536, 50.21671567644392, 52.744334833962576, 50.68596574238369, 50.75805677686419, 47.35544402258736, 48.376759733472554, 42.724365438733784, 43.6996180670602, 45.722568716321675, 43.86645821162632, 49.34123917988369, 57.60663904462542, 27.52184067453657, 17.026004791259766, 14.778783661978585, 7.405082600457328, 5.224442149911608, 0.771147829081331, 0.10575438490403549, 0.004223355050531349, 0.04719469915809376, 0.04790691326239279, 0.04918980585145099, 0.06408670970371791, 0.04294849486489381, 0.022782647849193642, 0.029759534900741916, 0.04421947916437473, 0.01864116865077189, 0.0912003515820418, 0.02366302328716431, 0.07867042893277747, 0.036833961361220906, 0.3624262623488903, 0.25979132684213774, 0.0468538981596274, 0.048702258084501536, 0.06385786698332854, 0.031132801568933895, 0.017507575818204453, 0.007531359575555793, 0.03667249038283314, 0.0415326738730073, 0.08829748377736125, 0.02727882783593876, 0.020854580415678874, 0.03869681140141828, 0.018686007941141725, 0.4899260593312127, 5.316773286887577, 10.631104281970433, 9.044391070093427, 15.830978904451642, 34.81601612908499, 37.256904397692, 43.83268301827567, 39.725133827754426, 40.20856864111764, 37.087086950029644, 39.04586751120431, 38.15157181876046, 40.11446571350098, 43.40590729032244, 43.943642275674, 45.42830555779593, 44.41616494315011, 49.193162645612446, 48.05279650006975, 44.769651072365896, 38.29493052618844, 40.132572719029014, 44.51399210521153, 50.10439109802246, 49.338956696646555, 48.72452402114868, 44.07897233963013, 43.08211081368582, 42.07840183803013, 44.113682065691265, 43.45778948920113, 48.040974140167236, 48.69583490916661, 52.552953651973176, 53.24983712605068, 59.319529805864605, 38.90512132644653, 4.573296061583927, 0.3476490452885628, 0.5471453975353922, 4.223955835614886, 37.69432476588658, 45.436747619083945, 46.88825757162911, 44.466740880693706, 41.39565447398594, 53.26655101776123, 37.451492173331125, 0.27613031438418795, 11.301661900111608, 31.777263164520264, 11.073875631604876, 24.215078319822037, 15.182847465787615, 17.101358004978724, 30.449167115347727, 43.01136425563267, 23.816514015197754, 23.871967588152202, 23.65661859512329, 33.509237153189524, 29.766464914594376, 35.572727067129954, 62.68552207946777, 12.935448288917542, 0.21371871765170777, 0.036900817416608334, 0.04700477720637407, 0.030132474710366557, 0.13141075069350855, 0.0377456511903022, 0.04332297494901078, 0.011198441863858273, 0.019538741558790207, 0.010039189381391873, 0.01983702216031296, 0.02933699757392917, 0.07393418664910964, 0.019553530229521648, 0.24670884598578724, 0.11058307079864399, 0.08391221373208932, 23.022633688790457, 80.37352343967983, 48.174532413482666, 37.100173882075715, 45.61207846232823, 34.59324993406023, 37.72264562334333, 24.034109013421194, 33.32669407980782, 27.56777695247105, 28.768545525414602, 15.145940371922084, 15.176337003707886, 8.073722515787397, 15.967936583927699, 3.9695957473346164, 7.759507605007716, 58.266540731702534, 55.18546976361956, 49.00710378374372, 53.73821210861206, 56.2369510786874, 29.653240544455393, 1.9876001690115248, 0.13975470938852855, 2.7286919908864156, 31.034792559487478, 57.27411215645926, 59.94606276920864, 61.09001418522426, 57.59058175768171, 54.33820990153721, 55.88074820382254, 56.43702793121338, 56.47682721274239, 56.06058495385306, 54.98131084442139, 56.79157713481358, 55.38331971849714, 53.46523475646973, 48.23935563223702, 44.21100548335484, 45.431192534310476, 47.00472675051008, 54.34588418688093, 52.69112205505371, 52.27260078702654, 51.71635232652937, 51.18717057364327, 51.69755050114223, 50.17327206475394, 45.362384523664204, 49.74703482219151, 50.331576347351074, 47.425342900412424, 47.56161444527762, 52.844406264168875, 30.260679858071462, 24.856523854391916, 25.093294143676758, 12.84033613545554, 6.081600589411599, 0.7675460023539407, 0.1075858459142702, 0.06241545759673629, 0.028783021228654043, 0.10330580307969026, 0.036615286488085985, 0.03765990811267069, 0.016964693520484225, 0.04374297794752887, 0.01878228527493775, 0.03194852958300284, 0.03278226252379162, 0.01882192020171455, 0.03794157139158674, 0.10200153663754463, 0.1168653347662517, 0.3503729019846235, 0.5703144914337567, 0.02916374722761767, 0.02513570890628866, 0.03215973378558244, 0.04584017023444176, 0.06759493252528564, 0.027876500140077302, 0.05064734996163419, 0.006546061419482742, 0.039253671520522664, 0.05629971630073019, 0.03300210786983371, 0.017299207892002802, 0.019456038318042244, 0.13896698451467923, 6.086355762822287, 15.160177230834961, 14.951164994921003, 21.38101407459804, 41.95822926930019, 41.06585475376674, 47.205630438668386, 43.36753586360386, 44.02200753348214, 40.188210419246126, 41.94769927433559, 42.101779052189414, 45.41110181808472, 44.33902256829398, 46.093032768794465, 46.788300786699565, 46.38531221662249, 49.82388537270682, 49.722045625959126, 45.38545254298619, 41.61779185703823, 41.64180483136858, 47.01982866014753, 51.68010010038103, 51.64714479446411, 49.218936988285606, 46.96258592605591, 44.79813173839024, 43.6394362449646, 46.58077893938337, 47.59262425558907, 48.58906888961792, 52.55519444601876, 54.69643817629133, 55.38011659894671, 58.0063202721732, 39.15231391361782, 4.784220789160047, 0.6731437050870487, 1.2862597512347358, 8.659223760877337, 43.55955975396292, 48.25094175338745, 50.09042869295393, 48.25127179282052, 46.25673232759748, 56.238302503313335, 32.03358221054077, 0.12084758893719741, 13.487665925707136, 42.422775404793875, 14.636449813842773, 12.170557584081378, 13.816026500293187, 19.252549818583898, 25.50132015773228, 30.66515186854771, 30.055398804800852, 26.379047870635986, 19.359123025621685, 36.66259023121425, 31.012304714747838, 45.11492095674787, 69.96937424795968, 17.395450932638987, 0.18516060364033493, 0.19095690761293682, 0.028037731934870993, 0.1181488244661263, 0.06632784980216197, 0.0592723883954542, 0.1644680132823331, 0.08869258793337004, 0.15294903995735304, 0.19781239117894853, 0.1406991079981838, 0.1635432243347168, 0.15351884652461323, 0.22776045703462192, 0.46960371839148657, 0.28521608827369554, 0.25977862466658863, 31.716588020324707, 94.82978561946324, 56.207320485796245, 52.37443011147635, 58.70628874642508, 40.60682896205357, 40.34892920085362, 38.80018963132586, 55.73634726660592, 39.493244647979736, 29.375653062547954, 19.99853273800441, 36.41465418679373, 27.37792263712202, 17.55207896232605, 6.292154891150338, 11.880116803305489, 64.3172995703561, 59.856250354221885, 54.897074358803884, 59.97008269173758, 62.63614123208182, 31.666342122214182, 1.9887357652187347, 0.25981301282133373, 4.261909067630768, 36.747990540095735, 59.82115500313895, 61.82142325810024, 66.22526795523507, 58.66416876656668, 55.25462518419538, 59.842777797154014, 58.12432500294277, 58.90919698987688, 59.00001689365932, 56.91090202331543, 57.467796666281565, 59.04275526319231, 55.10689953395298, 51.30416781561715, 47.17502709797451, 48.36867550441197, 51.25829928261893, 56.47415910448347, 56.14944893973214, 54.696511132376536, 54.86963939666748, 54.375240325927734, 54.0872757094247, 55.90929140363421, 47.650853633880615, 52.21020596367972, 50.72200257437569, 49.901823316301616, 49.26655299322945, 60.26706954411098, 41.47714989525931, 25.41389618601118, 27.290085247584752, 15.82232666015625, 10.73170030117035, 2.534682435648782, 0.1218224944812911, 0.10260005880679403, 0.2793952891869204, 0.14733969952378953, 0.10619229104902063, 0.128804972661393, 0.12235671867217336, 0.09465876993324075, 0.051115759648382664, 0.11300183100891964, 0.11053599403905016, 0.18987036948757513, 0.12086770071515016, 0.22548969888261386, 0.18691435882023402, 0.7029693360839571, 0.7442506466593061, 0.10894059536180326, 0.16050604730844498, 0.16979116121573107, 0.1221694430070264, 0.15088850552482264, 0.055306069619421444, 0.3308909402361938, 0.20882418671888964, 0.20340536534786224, 0.12481150909193925, 0.09581320227256843, 0.11563094386032649, 0.166108493826219, 2.338303110429219, 14.489534497261047, 21.143538543156215, 23.487857273646764, 28.830238580703735, 44.23022420065743, 43.50442579814366, 50.99587971823556, 45.08595044272286, 46.98027603966849, 41.5526316506522, 45.79451731273106, 43.45817858832223, 45.866049017224995, 47.57227645601545, 48.39056927817208, 49.27769095557076, 46.996882234300884, 52.45984779085432, 51.792713029044016, 48.8169698034014, 43.72161953789847, 44.79712077549526, 49.00985179628645, 54.42133467538016, 52.534447125026155, 51.38554164341518, 48.66343893323626, 47.3938432421003, 46.5466320174081, 47.6470946584429, 48.163793972560335, 49.89341599600655, 54.238954884665354, 57.11622476577759, 59.63467924935477, 59.71878024509975, 42.50450359072004, 6.370867558888026, 1.4265383439404624, 1.294261253305844, 6.843792353357587, 48.106297629220144, 51.01019648143223, 55.936222621372764, 53.303466796875, 52.69407851355416, 62.87299837384905, 47.18842322485787, 0.6559500076941082, 16.938460963112966, 39.721857752118794, 17.386948074613297, 34.207444259098594, 21.403708628245763, 22.140214204788208, 41.29197345461164, 55.55973448072161, 37.14432621002197, 33.559538636888774, 31.590307985033306, 44.91111639567784, 40.92310053961617, 53.594898564474924, 79.66111074175153, 25.781534058707102, 0.4000346085854939, 0.27363357692956924, 0.18330880015024117, 0.10923175473830529, 0.2570650002786091, 0.1536996896777834], [0.07035352342895099, 0.02551976142318121, 0.029745204241148064, 0.06009113589035613, 0.06242359323160989, 0.07907841168344021, 0.06548410507717303, 0.08394446450152568, 0.07650862314871379, 0.03782384556585124, 0.055686551345778365, 8.823118737765721, 65.76995944976807, 46.83307497841971, 32.48842518670218, 56.365541390010286, 47.99316011156355, 29.684059279305593, 35.05090345655169, 54.56569044930594, 39.25649867738996, 22.159637893949235, 10.613934414727346, 23.180635724748882, 44.876351084027974, 35.72787339346749, 6.168175578117371, 2.1677339545318057, 37.043414047786165, 55.14938429423741, 44.59262139456612, 51.522737298692974, 48.32262979234968, 37.80039249147688, 7.150744225297656, 0.11164349211113793, 0.04740781682942595, 11.542374423571996, 47.971061365945, 60.3516013281686, 59.95166996547154, 58.063583850860596, 55.62794842038836, 56.70428344181606, 53.81582696097237, 56.245368821280344, 52.36281272343227, 53.54794263839722, 55.83015489578247, 53.13443449565342, 52.71532610484532, 48.87754072461809, 45.303429058619905, 43.706198011125835, 46.9120169367109, 50.105964865003315, 50.841233662196565, 51.63134459086827, 51.425625801086426, 49.93797131947109, 48.193209171295166, 44.41065502166748, 43.60528932298933, 46.12207971300398, 47.528596605573384, 44.758707659585134, 46.25920588629586, 28.98012512070792, 23.195331164768763, 29.573641981397355, 25.20234612056187, 13.666562063353402, 5.7375761696270535, 0.08443080447614193, 0.07739403670919792, 0.0726358031055757, 0.10462793534887688, 0.05836610309779644, 0.02881835593975016, 0.03026326572788613, 0.0372789649825011, 0.01757343951612711, 0.02750478678249887, 0.01331561106988894, 0.08413245941379241, 0.017626882630533407, 0.027385386671604853, 0.07771511269467217, 0.03898481898275869, 0.3848442722644125, 0.6885066607168743, 0.1381238776126078, 0.05084271037152835, 0.0370526973025075, 0.034653349979115386, 0.012370599234210593, 0.032441420813224146, 0.08786920604429074, 0.04707445936011417, 0.05546661439750876, 0.03601436569754567, 0.0836907806141036, 0.06382722434188638, 0.07938004764063017, 0.10365127918443509, 2.953077333314078, 10.313164268221174, 16.0303053515298, 12.34984368937356, 30.995573452540807, 44.82371847970145, 40.287708623068674, 40.38094997406006, 39.33514533724104, 38.33821780341012, 39.10747371401106, 40.754439967019216, 40.84068100793021, 44.415084498269216, 45.43585130146572, 41.965170519692556, 45.83974313735962, 48.04959685461861, 44.64238786697388, 41.5285005569458, 37.38205187661307, 43.09579529081072, 44.245965344565256, 50.31261123929705, 48.3715729032244, 50.06484889984131, 46.009974002838135, 44.517702443259104, 43.07791062763759, 46.451827321733745, 46.58047669274466, 49.98281499317714, 51.88289369855608, 53.01350804737636, 53.20969043459211, 60.17298398699079, 28.778648206165858, 2.5645355880260468, 0.008531943429261446, 11.740937437329974, 29.639563015529088, 41.270586899348665, 47.478027616228374, 44.209021772657124, 46.11688246045794, 47.70025879996163, 53.29217250006539, 11.668452961104256, 0.25369259981172426, 21.991781575339182, 17.01801609992981, 17.58714825766427, 16.940868513924734, 11.565722107887268, 22.534514052527292, 34.50674486160278, 24.816849640437535, 20.29115785871233, 30.943531445094518, 42.28392260415213, 41.97299419130598, 35.12515190669468, 46.632883480616975, 59.842909812927246, 10.385167581694466, 0.4238461937223162, 0.12404572804059301, 0.05254823188962681, 0.06100145847137485, 0.015142947435379028, 0.03848031462569322, 0.08372858858534268, 0.0317547637304025, 0.05053235523934875, 0.05409308310065951, 0.024782565355833088, 0.011285057707157518, 0.06510356228266444, 0.11731337143906526, 0.05200862352337156, 0.054026735946536064, 0.1004783883690834, 12.370969687189374, 78.86675793784005, 53.086947032383506, 35.18121692112514, 55.438630853380474, 30.456216062818253, 35.55809416089739, 34.56869500023978, 32.01049334662301, 27.313123737062725, 20.17277271406991, 18.62866759300232, 29.16388933999198, 41.40741777420044, 36.85474961144583, 10.416113989693777, 2.0897161066532135, 37.926641259874614, 61.327580043247764, 50.82922717503139, 57.81213549205235, 52.48908928462437, 45.93978330067226, 9.700735279491969, 0.11211537928985697, 0.1257805520934718, 10.461613399641854, 48.20810610907418, 62.50451455797468, 61.95586395263672, 60.41297476632254, 57.900457518441335, 60.28589916229248, 56.27750423976353, 58.15752002171108, 55.75016723360334, 55.615504196711946, 57.63051305498396, 55.78393200465611, 53.863911969321116, 50.06990024021694, 47.67981025150844, 45.4340934072222, 49.18315723964146, 53.77808782032558, 52.024379866463796, 52.24045147214617, 54.03049503053938, 52.107942376817974, 49.67175109045846, 48.294746671404155, 47.1452818598066, 49.88209043230329, 51.23728445598057, 45.48008005959647, 46.14209399904524, 34.38791676930019, 28.559180668422155, 34.816168989454, 30.692552089691162, 20.65390419960022, 6.2194220168249945, 0.7421194495899337, 0.11351018265954085, 0.0708263334152954, 0.02689619006456009, 0.023091779922002127, 0.07801760360598564, 0.10576632712036371, 0.09818334544875792, 0.013320767936030669, 0.029028477878975015, 0.022343484718086462, 0.026410627012540187, 0.01824973876188908, 0.019439188597191657, 0.03191663504445127, 0.03258982320715274, 0.14934630399303778, 0.37864001946789877, 0.2310994735785893, 0.06410690969122307, 0.07514537165739707, 0.012193877333109933, 0.05057674160759364, 0.029027544893324375, 0.05288493114390543, 0.05421669861035688, 0.03757680453626173, 0.0661905821678894, 0.025842051986338835, 0.06639235812638487, 0.12311798068029539, 0.3368823773094586, 6.904830540929522, 16.279881170817784, 22.3906272820064, 20.45199649674552, 33.90051106044224, 48.22777993338448, 42.47328880855015, 43.72995737620762, 42.125875404902864, 42.0637480872018, 41.900461946214946, 43.2967962537493, 43.160583768572124, 45.729735783168245, 46.57210758754185, 43.75611386980329, 48.79422834941319, 48.92043890271868, 47.862214360918315, 42.966597012111116, 40.43478809084211, 44.948733942849294, 47.86669594900948, 51.727438177381245, 50.83748858315604, 52.1092277935573, 49.23073155539376, 45.988983494894846, 44.792048590523855, 47.69839320863996, 50.06061397280012, 54.12827008111136, 55.6854065486363, 54.81490843636649, 56.15230117525373, 60.70283971514021, 28.516414506094797, 2.288016391651971, 0.49584478459187914, 18.778100763048442, 34.21756083624703, 47.00914927891323, 51.0959928376334, 48.73093373434884, 51.04486451830183, 52.04879583631243, 52.06054176603045, 11.20188055719648, 0.10402525375996317, 28.43324109486171, 22.753743614469254, 9.509486981800624, 7.09592467546463, 13.654414875166756, 22.41226397241865, 31.65443638392857, 25.72814062663487, 25.128573622022355, 31.203421865190776, 40.195499079568044, 49.62166500091553, 36.43847608566284, 53.67286082676479, 66.53604698181152, 13.6730968441282, 0.29782839864492416, 0.18662573716470174, 0.05478681730372565, 0.07270249631255865, 0.06923679728060961, 0.06532971121902977, 0.2394057735800743, 0.15483611369771616, 0.2048495185694524, 0.27706639415451456, 0.11120160975094352, 0.18422893434762955, 0.22355713615460054, 0.18583521672657557, 0.16176033286111696, 0.17081238356019768, 0.21708023441689356, 17.863424267087662, 94.40682792663574, 62.19627857208252, 46.63373463494437, 72.31239019121442, 58.30810832977295, 36.63932071413313, 49.20908096858433, 68.75000013623918, 50.02774551936558, 27.35494668143136, 15.733935151781354, 30.761328833443777, 58.319593702043804, 48.72967611040388, 11.445922136306763, 5.494954628603799, 44.767385959625244, 65.50785950251988, 54.73605680465698, 61.52342196873256, 57.940194266183035, 47.77050508771624, 9.613397291728429, 0.5961358972958156, 1.0620534334863936, 15.038375309535436, 52.98984595707485, 65.4796359198434, 63.54613290514265, 63.26543957846505, 60.59213406699044, 61.15975325448172, 58.50263704572405, 60.16447244371687, 55.27976376669747, 56.7572843006679, 60.07218647003174, 60.96203531537737, 56.86419970648629, 53.03735773903983, 50.23765059879848, 48.634023734501426, 51.39838538851057, 56.41407455716814, 54.815405232565745, 56.642458370753694, 55.00384732655117, 56.41293157849993, 53.639575481414795, 52.39118569237845, 47.97134971618652, 53.92834608895438, 52.491830348968506, 49.14041887010847, 50.22997283935547, 40.59671238490513, 33.49131774902344, 37.14835616520473, 35.30192102704729, 22.720032691955566, 11.40774439062391, 1.4065447939293725, 0.25695328627313885, 0.20544358954897948, 0.17424946198506014, 0.2275517260921853, 0.13407454346971853, 0.28341132083109444, 0.19129688079868043, 0.16126162319311074, 0.11795423419347831, 0.10342249074684721, 0.18271362994398388, 0.04817087356267231, 0.15776377517197812, 0.135030558598893, 0.14214569037514074, 0.9874330375875745, 1.0633201769420078, 0.4289230741560459, 0.11528710302497659, 0.1610017985637699, 0.13196491024323873, 0.10727454083306448, 0.175085417128035, 0.19642275146075658, 0.1213588107909475, 0.16619694765125, 0.14122730679810047, 0.17067189966993673, 0.14585138724318572, 0.5004625139491898, 0.6995267208133424, 11.238745961870466, 22.73867644582476, 24.221227475575038, 24.315676076071604, 39.57232904434204, 52.196646554129465, 44.38251829147339, 46.25468955721174, 43.405396597726, 44.553339753832134, 44.74131284441267, 45.370566027505056, 45.323453766959055, 49.994425433022634, 49.68575171061924, 43.81687239238194, 50.93273101534162, 52.18118333816528, 50.67699214390346, 45.3664596421378, 42.61394814082554, 48.14393949508667, 49.65547146115984, 54.7821615764073, 53.073408467429026, 53.09536477497646, 50.6622063773019, 48.418289116450715, 47.184601715632844, 50.63542454583304, 52.170535223824636, 55.45629317419869, 56.13075481142317, 56.686801774161204, 58.38009861537388, 61.01386192866734, 34.47830935886928, 3.946894245488303, 0.5366718024015427, 16.161025285720825, 36.05485561915806, 52.44622932161604, 55.067607470921104, 56.32638829095023, 55.20978845868792, 56.97205311911446, 60.72755445752825, 17.139017241341726, 0.377367549176727, 28.630695002419607, 21.51201367378235, 28.335981948035105, 27.189609084810527, 16.872923816953385, 30.1708014351981, 46.93327842439924, 34.061872550419395, 30.28648199353899, 40.080534185682026, 52.434837750026155, 54.30025536673409, 48.76976721627371, 61.0886801310948, 78.47882611410958, 18.986786433628627, 0.6977801716753415, 0.35669044298785074, 0.22793239780834743, 0.16952539261962685, 0.13279717415571213, 0.14429626640464577], [0.061531923578253815, 0.07045991093452487, 0.031023659211184298, 0.08362729009240866, 0.11750003642269544, 0.07128873467445374, 0.07179642136075667, 0.02948647883853742, 0.08245670183428697, 0.035843317197369676, 0.03029874971668635, 2.398874900170735, 51.47192859649658, 57.60300166266305, 26.446252584457397, 65.09754753112793, 93.975754737854, 34.27373702185494, 38.823108264378135, 47.2701792035784, 33.92529875891549, 32.601434162684846, 11.225019795554024, 23.363788502556936, 45.26321635927473, 41.34859779902867, 11.31465242590223, 2.099617506776537, 32.02355595997402, 57.49198334557669, 46.71123136792864, 49.25266701834542, 54.49792466844831, 48.90587200437273, 18.907523121152604, 0.6002688812358039, 0.3667784673827035, 2.0026669033936093, 25.071805102484568, 57.69566283907209, 59.62528528485979, 55.96084008898054, 58.31807204655239, 53.81554555892944, 55.95765086582729, 55.944654260362896, 53.0563645362854, 53.41771602630615, 55.33226088115147, 54.084909847804475, 53.38712658200945, 48.609069279261995, 43.46098913465227, 42.89699690682547, 47.478705065590994, 50.046040126255576, 48.3525070462908, 52.93845360619681, 52.10581970214844, 47.523177010672434, 46.99463449205671, 45.13729068211147, 45.47890928813389, 45.71135779789516, 46.96754346575056, 42.31556122643607, 38.778361865452354, 26.206649167197092, 24.935028076171875, 31.100755282810756, 33.34399856839861, 21.725436278751918, 6.14826421226774, 0.6953315287828445, 0.33996477190937313, 0.7935327536293438, 0.2598704440253121, 0.09316849668643304, 0.01349820738791355, 0.05009502584912947, 0.10022389023963894, 0.051581075215446096, 0.05762610637715884, 0.04707051707165582, 0.020958888211420605, 0.03218551811629108, 0.03813013627326914, 0.04266096904341664, 0.08946524254445519, 0.08483027839767081, 0.40987152074064526, 0.0581952819068517, 0.025312470671321665, 0.03979233672310199, 0.04433598701975175, 0.019374931330925653, 0.020190362485923936, 0.054766885337552855, 0.0240497695880809, 0.017161265115386674, 0.04516088204192264, 0.04570558959884303, 0.19642246647604875, 0.3065335415303707, 0.032433427670704465, 5.489702658993857, 12.6590176820755, 20.507741894040787, 29.343701771327428, 26.050312961850846, 38.55953529902867, 42.05957569394793, 41.52172606331961, 41.10159976141793, 41.110180786677766, 38.64834369931902, 39.7531281198774, 42.36197171892439, 43.272175312042236, 42.64708757400513, 43.98044688361031, 45.24975422450474, 44.641613142830984, 43.45099067687988, 39.35880742754255, 38.415162154606406, 40.004444462912424, 48.57160806655884, 49.961789744240896, 53.29365941456386, 50.79330151421683, 47.34192630222866, 43.137748513902935, 46.691821575164795, 47.29810053961617, 49.98533718926566, 52.52776990618025, 53.86632994243077, 52.13756602151053, 54.25723212105887, 48.45486790793282, 14.515325341905866, 0.6511201411485672, 12.004513876778738, 41.11282457624163, 46.653919151851106, 42.355982371738975, 48.911962100437705, 47.24325493403843, 47.78565216064453, 47.17605195726667, 42.723833901541575, 6.5008227569716315, 0.6121110000780651, 26.156872272491455, 16.168475491659983, 17.966820410319738, 8.48912056854793, 13.796182445117406, 18.90655037334987, 19.342898981911794, 22.299037865230016, 26.3688531262534, 34.00990349905831, 35.886115142277305, 27.988978488104685, 23.111438614981516, 49.57578951971871, 45.67296552658081, 3.599617200238364, 0.34333320973174913, 0.016240409974540983, 0.028747720444308858, 0.04385677844818149, 0.07049495048288788, 0.024220253207853863, 0.034951413449432166, 0.08585566016180174, 0.026110107245455896, 0.014969013465036238, 0.043303246543343575, 0.093486105357962, 0.04804514780906694, 0.06457309717578547, 0.05643366250608649, 0.04303528967180422, 0.02890765793355448, 4.5354830963271, 62.382149832589285, 64.67162990570068, 27.47284197807312, 75.83945560455322, 73.0985163279942, 23.689549582345144, 46.83733769825527, 47.4965306690761, 42.847358976091655, 19.26907089778355, 11.533473781176976, 32.97463927950178, 49.795627049037385, 39.79423018864223, 12.89706643990108, 3.034820718424661, 37.074517658778596, 66.8288927078247, 53.700955867767334, 56.51392364501953, 58.861205782209126, 54.38412012372698, 24.584041561399186, 2.3172374750886644, 0.4373849758080074, 1.5635874356542314, 23.702339478901454, 56.651275634765625, 62.11362974984305, 58.0715777533395, 60.77381556374686, 55.568520477839876, 59.361316272190635, 57.53990854535784, 53.760717323848176, 55.089400495801655, 57.206784112112864, 56.79232406616211, 56.16957787105015, 51.16134064538138, 45.85106175286429, 45.71382440839495, 50.188964571271626, 52.287063462393625, 50.94793367385864, 55.517479010990684, 52.34354884283883, 49.53923852103097, 50.789413997105186, 48.695893968854634, 49.94174419130598, 50.55216080801827, 49.498306683131624, 46.430551937648225, 39.27610649381365, 33.752226080213276, 30.72522599356515, 39.409362520490376, 34.62149436133248, 28.565541744232178, 18.30043469156538, 2.2437574522835866, 0.6931500658392906, 0.6718344039150647, 0.18737369988645824, 0.025655159693477408, 0.07284686142312628, 0.04530961013266018, 0.07530380958425147, 0.020767066361648694, 0.010397293022833765, 0.08510378229298762, 0.008582630843323256, 0.024292164349130223, 0.045605461578816175, 0.06380267494491168, 0.04956106628690447, 0.34935284672038897, 0.44084276312163895, 0.06483911682984658, 0.04469048764024462, 0.06401070021092892, 0.044292506495756764, 0.03036275253232036, 0.013459614012390375, 0.028986985462584665, 0.047653636495981894, 0.04948972850771887, 0.06376864641372647, 0.16442628337868623, 0.3653219783944743, 0.5968112839119775, 0.11843942744391305, 13.351496866771154, 21.779316084725515, 22.00471043586731, 35.0335989679609, 33.83599008832659, 41.01740149089268, 46.47744880403791, 44.68163824081421, 43.96094329016549, 43.249270575387136, 41.92167132241385, 42.66406897136143, 46.07330335889544, 45.37003796441214, 44.75071375710623, 46.53696707316807, 47.95939186641148, 44.5266968863351, 46.42618152073452, 42.324315956660676, 41.728469712393625, 42.882259777614046, 49.863250391823904, 52.78486715044294, 55.34834943498884, 52.199158327920095, 49.54157658985683, 43.58826276234218, 48.38725846154349, 49.363987582070486, 52.711000851222444, 53.434131145477295, 56.69872488294329, 55.353953157152446, 57.086927686418804, 46.703869751521516, 13.353381565638951, 1.6573462103094374, 18.4819963318961, 48.19259425571987, 50.25963122504098, 45.38593544278826, 53.917916842869346, 50.072161878858296, 50.87047168186733, 49.22181354250227, 47.87508589880807, 6.037979798657553, 1.784070821745055, 35.24612351826259, 14.309707301003591, 5.082436604159219, 10.62785165650504, 17.059323140553065, 19.965108428682598, 25.64791325160435, 18.147433621542795, 32.255201952798025, 25.778768675667898, 40.69850696836199, 36.56291484832764, 25.15820942606245, 57.26809849057879, 54.58013228007725, 4.106236415249961, 0.232626204511949, 0.027843438521293656, 0.020229398605546782, 0.02702589881872492, 0.08874277238334928, 0.01887271533321057, 0.1842768524906465, 0.1653903459331819, 0.09257093803691012, 0.17140908725559711, 0.28884435072541237, 0.20522563053028925, 0.1476629264652729, 0.2090918416423457, 0.20678106349493774, 0.10941520346594708, 0.13662059684949263, 8.47633067199162, 76.886597769601, 71.17283698490688, 40.06177404948643, 77.60364491598946, 118.97076661246163, 45.90184613636562, 49.30790867124285, 58.21339396068028, 46.7444611276899, 46.84635646002633, 16.68676594325474, 35.314236709049766, 60.58741624014718, 53.188866683415, 16.77205855505807, 5.569210026945386, 39.94168833323887, 69.4777683530535, 55.37541961669922, 62.22926861899239, 65.09053679874965, 60.682634353637695, 25.463379519326345, 2.430530675819942, 0.5755974022405488, 3.053466860737119, 30.333684580666677, 62.12647696903774, 63.79530920301165, 60.52001176561628, 63.68185206821987, 58.20116860525948, 60.08514486040388, 59.61030496869768, 54.009174483163015, 56.79032645906721, 60.11103384835379, 59.73751258850098, 59.522187914167134, 56.324929169246126, 49.14586278370449, 47.387364046914236, 55.0620037487575, 54.577245303562705, 52.166984694344656, 59.112904276166645, 55.89440141405378, 52.94730561120169, 54.4706495148795, 52.399766717638286, 52.990175996507915, 52.327290058135986, 53.35464027949742, 47.50808204923357, 46.085289001464844, 41.37198543548584, 34.50564009802682, 37.962282044546946, 39.806452069963726, 30.71498087474278, 15.612928799220494, 1.9639602260930198, 2.188807623726981, 1.0936092202152525, 0.4651234330875533, 0.16936243564954825, 0.0942856842385871, 0.15591301662581308, 0.15450986049004964, 0.10911153868905135, 0.13932476245931216, 0.12664009311369487, 0.08251852315983602, 0.11726263059037072, 0.11002474504389934, 0.1251265121889966, 0.20818370394408703, 0.45606184218611034, 1.358125077826636, 0.31353615862982614, 0.16243938356637955, 0.13212854574833596, 0.21791074770901883, 0.10447709022888116, 0.08580591675958463, 0.10665003755795104, 0.23723983551774705, 0.13921874814799853, 0.1033028175256082, 0.26131121814250946, 0.6622077290500913, 1.3911445460149219, 0.22665813618472644, 17.05386880465916, 28.072676488331386, 27.517030784061976, 40.1160603250776, 33.33161340441023, 44.95158270427159, 48.12497786113194, 47.7395578111921, 45.645975249154226, 45.57941498075213, 44.125309876033235, 45.38812065124512, 50.12653848103115, 47.67993879318237, 47.01279708317348, 48.23328290666853, 49.218509674072266, 47.19774423326765, 47.621056284223286, 43.44060659408569, 43.91583211081368, 43.474444321223665, 53.431000982012065, 54.52694729396275, 56.65675776345389, 52.98304714475359, 52.504469122205464, 46.44353812081473, 51.5284799848284, 51.81809132439749, 56.63460690634591, 55.60430717468262, 60.47240270887102, 56.76159565789359, 60.03016376495361, 51.515733514513286, 17.660238095692225, 1.3877023650067193, 14.33547556400299, 46.76835945674351, 54.817124911717, 49.631156240190776, 58.549822262355256, 53.43440212522234, 55.076219763074604, 54.090603896549766, 52.12144272668021, 9.624669875417437, 2.1575735168797627, 33.3815153666905, 25.064328840800695, 27.42392144884382, 16.590960706983292, 16.71816485268729, 27.40325924328395, 26.363393579210552, 29.273083754948207, 37.85574878965105, 41.46465008599417, 47.7726868220738, 38.98055444444929, 35.93150772367205, 67.09618295942033, 66.46064513070243, 7.987715108054025, 0.6733474827238491, 0.26298766104238375, 0.10688252401139055, 0.07720442009823662, 0.08733571467122861, 0.18322261263217243], [0.04704992353383984, 0.03992086821900947, 0.03821721267221229, 0.04812281292730144, 0.12669016899807112, 0.0774486723488995, 0.06617032789758273, 0.018983330111950636, 0.011529353214427829, 0.032177959236183336, 0.042522167920001915, 2.398551808936255, 55.304183210645405, 58.17078760692051, 28.06621813774109, 31.487905434199742, 82.25471346718925, 53.57959863117763, 22.459551674979075, 23.030922889709473, 14.553144386836461, 19.497894184929983, 10.175944294248309, 12.313711319650922, 46.99393272399902, 39.61476516723633, 18.704107659203665, 0.4247865618339607, 15.806213787623815, 45.05103921890259, 28.279378448213848, 31.55431284223284, 44.37539986201695, 54.10814809799194, 47.43184641429356, 22.37490177154541, 2.2066451694284166, 0.02299748730313565, 5.210817166737147, 32.47632489885603, 60.327157565525596, 60.05611528669085, 57.181239059993196, 57.995693002428325, 57.532411439078196, 57.03769622530256, 49.643812383924214, 52.33274091993059, 55.94131217684065, 53.096681458609446, 54.345585414341514, 49.16769402367728, 47.3401962007795, 46.055783476148335, 49.209160872868125, 53.230771269117085, 51.76350627626692, 53.94095359529768, 47.30947821480887, 49.36662094933646, 45.11930179595947, 46.73084960665022, 45.74363912854876, 50.19870941979544, 45.55625663484846, 47.601570061274934, 30.002679347991943, 27.956149986812047, 37.24532869883946, 31.917328425816127, 20.767191103526525, 23.805047750473022, 17.34737287248884, 3.9788086244038174, 1.480480249438967, 0.792672968336514, 0.5893338822892734, 0.07373919604080063, 0.03549134411982127, 0.020075328747874925, 0.04247748299634882, 0.05759411345102957, 0.08833158694739852, 0.09015631689024822, 0.009688890589001988, 0.09443555226815598, 0.04788992274552584, 0.11892505495675973, 0.051749762413757186, 0.13953461976987974, 0.43711608595081736, 0.25591450344238964, 0.06169451413942235, 0.03436055194054331, 0.08870754284518105, 0.02775924589617976, 0.01537381558279906, 0.011376373253629675, 0.005635950880657349, 0.05850316717156342, 0.07624067645519972, 0.06558089131223303, 0.6500501185655594, 0.6776793045657021, 0.7679612657853535, 5.704147951943534, 18.70065266745431, 17.712980134146555, 24.606331382478984, 31.971944740840367, 36.31117466517857, 40.99453149523054, 41.31642416545323, 43.57564830780029, 43.150251797267366, 40.44698565346854, 41.585350717817036, 42.38452557155064, 44.78086199079241, 41.15821368353707, 43.964858600071494, 46.34097228731428, 47.24019077845982, 42.98818506513323, 39.454918384552, 39.211040088108604, 45.55131993974958, 48.237927777426584, 53.17536285945347, 49.61101688657488, 50.14938415799822, 47.42076403754098, 44.65010036740984, 45.19313335418701, 52.10071277618408, 50.2639217376709, 53.57334872654506, 52.175576141902376, 56.42767913000924, 53.97918953214373, 27.07996129989624, 5.227808552128928, 13.07680070400238, 46.37176322937012, 49.115127427237375, 48.410527978624614, 48.45771666935512, 44.8182988848005, 45.821052483149934, 50.97311741965157, 49.53036914552961, 35.155519008636475, 0.2357446157506534, 2.591567120381764, 30.44625234603882, 12.13592255115509, 14.181571228163582, 6.0545212881905695, 16.712835584368023, 18.183630262102398, 29.261070319584437, 28.944018806729996, 28.305107627596172, 36.43242073059082, 22.868326357432775, 21.082797391074045, 29.72272253036499, 53.091835090092246, 38.35569599696568, 0.7942702397704124, 0.15112576207944325, 0.04731197375804186, 0.023522025406626717, 0.05647784531382578, 0.03079607178057943, 0.03223885775410703, 0.07457197563988821, 0.03718355617352894, 0.08644894404070717, 0.05865756781505687, 0.055315148417970965, 0.02458658578273441, 0.04150228907487222, 0.018408193652118956, 0.05362096182735903, 0.04867734227861677, 0.03179132319720728, 3.3645972056048254, 68.95859200613839, 66.25738252912248, 34.39332594190325, 38.92841863632202, 90.5097153527396, 52.55625057220459, 27.644613606589182, 22.562504870550974, 21.08094048500061, 30.914071083068848, 8.6045857327325, 21.235466684613908, 49.37064048222133, 42.46785879135132, 23.411738021033152, 0.28561919235757416, 12.78916004725865, 51.11933183670044, 33.143025398254395, 34.3724570274353, 52.16281924928938, 62.84303774152483, 55.49674906049456, 31.901649815695627, 4.826950039182391, 0.09787002511854682, 4.25939816236496, 29.675919464656285, 60.488758768354145, 61.312919344220845, 59.668739318847656, 61.4406133379255, 60.00817271641323, 55.43714393888201, 51.02804640361241, 52.964828968048096, 57.8858072417123, 53.500813007354736, 57.740951197487966, 49.808738299778526, 47.71057687486921, 48.33580705097744, 51.7801194190979, 54.570102555411204, 53.749190262385774, 55.374300956726074, 49.31790712901524, 52.06985582624163, 48.177353382110596, 49.95852409090315, 50.42556810379028, 52.7412428855896, 47.32677575520107, 43.976625374385286, 34.326067379542756, 35.38106448309762, 43.98494931629726, 31.567580427442277, 22.431029319763184, 26.273515156337194, 19.73069531576974, 5.375933723790305, 1.549568576472146, 0.7169409692287445, 0.9473434516361782, 0.03918317173208509, 0.04894256465403097, 0.013309130212292075, 0.08499401568302087, 0.07993522499288831, 0.11513280416173594, 0.0401995764779193, 0.07284175205443587, 0.018536799786878482, 0.07913950019116912, 0.05924666513289724, 0.11151488258370332, 0.13791913645608084, 0.7151365546243531, 0.1124007711187005, 0.030564111191779375, 0.02030217827164701, 0.08463786622243268, 0.09675333968230657, 0.0050722180499828285, 0.08424470946192741, 0.03412734284730894, 0.05516824219375849, 0.021074882076521004, 0.33798334108931677, 1.4915477527039391, 1.489311844110489, 0.6630455298083169, 10.450385110718862, 23.81503231184823, 21.20991121019636, 26.45737143925258, 30.881536143166677, 40.13800968442644, 43.825547218322754, 44.99188920429775, 44.909667696271626, 46.03239236559187, 42.55155679157802, 44.99120133263724, 44.24186590739659, 46.962599822453086, 43.1542192186628, 46.76540299824306, 48.20614324297224, 48.71516479764666, 46.71315949303763, 40.96061038970947, 41.031006063733784, 47.682718072618755, 50.76653357914516, 52.666660921914236, 52.13971301487514, 53.15148884909493, 49.58145924976894, 46.58823783057076, 48.185524463653564, 52.48506280354091, 52.600177083696636, 55.855498450142996, 54.183654172079905, 58.9610652923584, 50.65815905162266, 25.141134228025162, 6.353972579751696, 19.449216842651367, 53.26800666536604, 53.44713122504098, 52.30240855898176, 53.87499782017299, 48.43744877406529, 49.96688972200666, 53.68393278121948, 53.477991649082725, 32.40915666307722, 0.6589992897851127, 6.786321631499699, 33.17936100278582, 7.5718888725553235, 10.449677262987409, 12.925674779074532, 19.09223403249468, 24.36822877611433, 27.250853981290543, 23.663307973316737, 35.55023922239031, 22.259245531899587, 33.25011798313686, 19.741029024124146, 32.634139333452495, 60.978356633867534, 45.9058552469526, 0.9844200164079666, 0.17240372459803308, 0.018581790051289966, 0.055971145895974975, 0.06692742370069027, 0.0780063263539757, 0.13547835099909986, 0.14305205031165055, 0.17022642785949366, 0.23913278537137167, 0.13337740302085876, 0.19371887083564485, 0.09664243991885867, 0.16040649265050888, 0.13331888616085052, 0.17232844792306423, 0.1738461543406759, 0.2181078621319362, 5.320117541721888, 83.94957365308488, 73.01657622201103, 44.1463941846575, 42.4669485773359, 80.43968418666294, 67.64148453303746, 28.167159829820903, 30.432963916233607, 18.193941388811382, 31.04635088784354, 18.88124677113124, 19.95529236112322, 52.78796257291521, 49.460946219308035, 25.342055286679948, 2.750644172940935, 20.789814438138688, 58.86490222385952, 38.424670764378135, 40.38682815006801, 52.797234943934846, 63.00821031842913, 57.51480122974941, 32.3259311403547, 3.59078517130443, 0.190304591187409, 7.2509389860289435, 38.26093646458217, 64.57547378540039, 62.542083467756, 62.348124504089355, 61.9408141544887, 63.140830584934776, 55.644307953970774, 50.756159918648855, 54.3897933278765, 61.31314863477434, 57.78980050768171, 60.606607164655415, 52.61915956224714, 50.797081334250315, 51.145773206438335, 52.46615675517491, 58.1847048486982, 55.670523507254465, 58.94173540387835, 51.27379723957607, 53.66844177246094, 49.77121107918875, 52.72568586894444, 51.82141951152256, 54.68594639641898, 52.32456636428833, 53.096740518297466, 41.739173412323, 38.65150512967791, 45.51786436353411, 39.4500789642334, 28.17913852419172, 30.80384486062186, 30.209565435137065, 10.031618918691363, 4.780813566276005, 2.4595098750931874, 1.2114749870129993, 0.14290574459092958, 0.23690960609487124, 0.13182456205998147, 0.1557616897459541, 0.12540781923702785, 0.17598397391183035, 0.22231249936989375, 0.14224527217447758, 0.1904249768704176, 0.23000035541398184, 0.2217831877725465, 0.25380539947322434, 0.23035810621721403, 1.0619188121386935, 0.5777599747691835, 0.14249388740531035, 0.16297759754317148, 0.1521035853241171, 0.15168174010302338, 0.11156774046165602, 0.26438726165464943, 0.15018433545316967, 0.19597886742225715, 0.18005252416644776, 0.6307359178151403, 1.5243814651455199, 4.2496945687702725, 5.189106217452458, 17.33189402307783, 31.901826994759695, 23.9722353049687, 34.475352900368826, 37.87672192709786, 43.760616302490234, 44.30276339394705, 46.964486258370535, 46.64179801940918, 48.278744970049175, 44.86991705213274, 46.18559667042324, 47.99046073641096, 48.1976386478969, 43.77664232254028, 46.66582489013672, 51.88104200363159, 52.845615250723704, 48.055686950683594, 43.02698380606515, 44.819625990731375, 50.98531150817871, 52.91344703946795, 56.746135916028706, 54.95690529687064, 57.029191630227224, 53.23679535729544, 49.100994791303364, 50.503579003470286, 54.145175048283164, 55.103084972926546, 58.82379668099539, 56.9581914629255, 60.545240674700054, 54.297017506190706, 32.075028215135845, 7.355181506701878, 15.805001326969691, 54.81846591404506, 56.95532533100673, 57.44803946358817, 58.034307616097585, 51.8383800642831, 54.98393726348877, 58.843425342014854, 57.83026334217617, 46.68739209856306, 1.503684627158301, 5.653630205563136, 39.81921591077532, 22.642497743879044, 22.90961602755955, 10.185559732573372, 24.485033205577306, 27.335265908922466, 36.28190885271345, 42.56546361105782, 37.668355873652864, 44.396414688655305, 34.296447208949495, 28.853996208735875, 45.633833272116526, 68.55792413439069, 59.893888745989116, 2.033848898751395, 0.3602819288415568, 0.23256654771310942, 0.12148124564971242, 0.14615528950733797, 0.1474106471453394, 0.24145313086254255], [0.0523866828797119, 0.1120346946907895, 0.1198113981102194, 0.11733037552663259, 0.1420188993215561, 0.04424100908051644, 0.11357726941683463, 0.032056287729314396, 0.05684581485443881, 0.03337349044159055, 0.03746241031746779, 0.1571097352675029, 37.32913787024361, 61.367900439671104, 34.72739880425589, 34.93924937929426, 23.957654510225566, 15.6828658921378, 32.61593157904488, 37.7616354397365, 48.067359924316406, 19.42369784627642, 21.79679775238037, 18.96809230531965, 34.389514854976106, 60.08427633558001, 37.022937706538606, 4.372932161603655, 0.5406093139733587, 23.72672070775713, 26.038502761295863, 64.86488710130963, 57.3930618422372, 36.87749106543404, 37.7388071332659, 47.76578378677368, 34.429630279541016, 14.789626325879778, 0.7478001990488597, 5.36500985281808, 35.12717035838536, 57.49315411703927, 52.48219319752285, 54.626004287174766, 50.16225569588797, 52.92404304231916, 49.385276862553184, 51.73252773284912, 55.347991602761404, 54.07181944165911, 53.335636956351145, 48.87266308920724, 47.46447515487671, 50.27667168208531, 52.843499524252756, 50.069868973323274, 53.79870659964425, 52.76879596710205, 51.61893163408552, 51.16525942938668, 48.34819221496582, 47.145740440913606, 48.361755098615376, 44.31783403669085, 42.56621749060494, 34.504285199301584, 28.700823170798166, 40.4454014641898, 30.40597711290632, 18.080178533281597, 23.30753936086382, 18.387539046151296, 11.804995485714503, 3.7431886962481906, 0.9400920293160847, 0.48715427092143465, 0.4065077783805983, 0.03786984684744051, 0.015526421501168182, 0.07787111468080964, 0.04181484944586243, 0.03333053578223501, 0.10606918444058724, 0.1804832581962858, 0.06592921047870602, 0.026476468658074737, 0.025745781437893, 0.04774090627740536, 0.03362219727465084, 0.2661410304052489, 0.2251101942466838, 0.06548086167978388, 0.05563888765339341, 0.05316750365974648, 0.07863342163286038, 0.03515647351741791, 0.08765180342431579, 0.07889249308833055, 0.10210643136607749, 0.14220513004277432, 0.04952772307608809, 0.09967417509428092, 1.9669922462531497, 0.7020734527281353, 3.97776118346623, 6.093009531497955, 11.737967950957161, 14.562064136777606, 20.877580608640397, 19.606117589133127, 23.431741884776525, 38.03198289871216, 44.74693046297346, 39.33721937452044, 44.46839107785906, 37.31309795379639, 40.86145959581648, 43.99633046558925, 44.42720215661185, 43.38894673756191, 49.07128776822771, 44.43879175186157, 47.46472529002598, 42.59369414193289, 40.83479935782296, 40.86724744524275, 46.69944722311837, 47.472892897469656, 49.96550008228847, 52.826879433223176, 49.028028283800396, 44.46005323954991, 46.25563798631941, 48.7935265813555, 49.168319361550466, 50.44580820628575, 52.53237656184605, 51.047192164829795, 50.76095070157732, 36.91990634373256, 12.436673590115138, 12.119046245302473, 47.93770653860909, 45.51946939740862, 50.26901476723807, 36.462780884334016, 37.04596403666905, 50.73290777206421, 47.07329852240426, 48.26736034665789, 42.69356060028076, 2.107488078730447, 0.5708240440913609, 19.681488173348562, 25.140918833868845, 12.308529700551714, 10.130236438342504, 7.833537186895098, 20.603970970426285, 21.72479009628296, 33.96365281513759, 23.479455164500646, 28.048951864242554, 33.395443030766074, 25.59912994929722, 31.24601779665266, 36.30577938897269, 54.433115346091135, 21.188152926308767, 0.28891749680042267, 0.07023066787847451, 0.03660563432744571, 0.025931671195264374, 0.036764062076274834, 0.04984311633078115, 0.02809128870389291, 0.04155361685635788, 0.0279846891561257, 0.040386190571423085, 0.11520510885332312, 0.027927229114409004, 0.06413293150918824, 0.10187796862529856, 0.07880243113530533, 0.06082357373088598, 0.03893057689336794, 0.004543552757240832, 0.3624061234295368, 47.681887762887136, 68.78515802110944, 37.617137227739605, 38.75787162780762, 32.09676218032837, 20.43189709527152, 40.663901465279714, 34.01027870178223, 36.333801473890034, 24.000220911843435, 29.63906969342913, 32.859462465558735, 45.455605030059814, 59.9991956438337, 44.57244035175869, 8.821528468813215, 0.11387391814163753, 21.491879531315394, 28.04398911339896, 63.78870841435024, 61.85335023062569, 41.64165197099958, 41.68833691733224, 50.8003191947937, 42.572866916656494, 22.057714768818446, 1.3153314484017236, 4.065434856074197, 32.31905589784895, 58.89308411734444, 54.343118803841726, 55.57960632869175, 49.44077212469918, 52.3749338558742, 51.93451533998762, 54.80660881314959, 56.25219195229666, 56.82000568934849, 57.758141040802, 53.494174003601074, 50.23842879704067, 53.47964184624808, 52.58201796667916, 51.903821672712056, 56.70499563217163, 54.25777060644967, 53.16079248700823, 51.502021244594026, 50.95704623631069, 48.60999338967459, 50.65555347715105, 47.97267682211739, 44.010497842516216, 36.14686713899885, 33.083368165152415, 42.34610898154122, 26.644894633974346, 22.059359754834855, 25.520333903176443, 20.18935285295759, 13.468745112419128, 10.458439809935433, 1.2382821142673492, 0.9187703962836946, 0.5467221545321601, 0.05546033794858626, 0.02605585158536477, 0.010617909354290791, 0.03305712688182082, 0.02016539409357522, 0.057444727181323936, 0.1628766315323966, 0.0033907891899746445, 0.045761290538523874, 0.053382952098867724, 0.06321723493082182, 0.021176731879157678, 0.1542572011905057, 0.3441460132598877, 0.15154825869415486, 0.06102738529443741, 0.021192338184586594, 0.06271414192659513, 0.07386720167206866, 0.0675389805276479, 0.025816630671865175, 0.0748611061966845, 0.029875499928104024, 0.031007445616913692, 0.11793257535568305, 1.772843292781285, 2.6146362253597806, 3.085483942713056, 14.262209415435791, 14.058481284550258, 16.937972852161952, 27.63183239528111, 26.71954607963562, 23.41345422608512, 36.29031964710781, 48.53079087393624, 42.660452433994834, 45.802743979862754, 40.60882656914847, 44.61672816957746, 47.1034710747855, 44.903150285993306, 47.466528347560335, 49.23812096459525, 44.89082418169294, 48.19430351257324, 44.1687639100211, 42.16832195009504, 40.69508498055594, 46.3710857800075, 49.25160394396101, 51.12142324447632, 53.57059723990304, 51.557836123875205, 46.79337991986956, 48.31384726933071, 50.94815949031285, 52.60964053017752, 54.66844735826765, 54.059149401528494, 55.67711387361799, 49.61775663920811, 33.701983656202046, 13.074350595474243, 17.83100049836295, 51.9120101247515, 49.75597020557949, 53.476296288626536, 42.287535667419434, 42.53895623343331, 56.73832961491176, 52.92691959653582, 53.2557361466544, 39.59247882025582, 0.7641727605036327, 2.1516490919249396, 28.14017823764256, 24.43006079537528, 12.532047169549124, 16.309360640389578, 15.419199126107351, 19.40605810710362, 29.0754839352199, 22.584285736083984, 28.128322873796733, 28.421877316066197, 29.884497438158306, 35.86681652069092, 24.24286069188799, 42.908423219408306, 61.09240436553955, 26.377663442066737, 0.40115698693054064, 0.09812999902559177, 0.10521575023553201, 0.038228327075817754, 0.09457929312650647, 0.03966578994212406, 0.1072712702942746, 0.2097106520086527, 0.17987001181713172, 0.16930193746728556, 0.28723760694265366, 0.15179631752627237, 0.1349269598722458, 0.261327720114163, 0.20441879811031477, 0.22875860918845448, 0.11482327005692891, 0.1638152218822922, 0.7185336809073175, 58.58866269247872, 78.66922760009766, 46.65686171395438, 50.60662078857422, 30.65114082608904, 16.88624698775155, 41.934306621551514, 47.732293469565256, 62.665156909397666, 23.771840572357178, 33.56278344563076, 29.055044072014944, 41.628627572740825, 66.56951645442417, 47.71085827691214, 8.819043619292122, 2.5036300676209584, 30.36877645765032, 29.63001619066511, 66.80555370875767, 66.07203933170864, 47.89301225117275, 49.0321763583592, 58.67775249481201, 40.928103242601665, 18.59208706447056, 1.0324787518807819, 6.613736629486084, 41.337637015751426, 65.27469185420445, 55.93566676548549, 57.70046057019915, 51.90864372253418, 53.26991741997855, 51.91419185910906, 55.360640798296245, 58.34480176653181, 58.49290261949812, 61.44616494859968, 57.6786675453186, 53.262917109898154, 56.854764052799766, 58.03908450262887, 55.023000035967144, 59.667127336774556, 54.428981167929514, 54.449714592524934, 55.337951455797466, 53.14333166394915, 52.65146173749651, 54.127022879464285, 51.72576018742153, 51.54191780090332, 44.2645309312003, 37.27844728742327, 47.664736134665354, 35.249347482408794, 27.456690890448435, 31.691411222730363, 28.36427674974714, 23.5966990675245, 28.977029698235647, 3.387726673058101, 3.2073127882821217, 0.9999455490282604, 0.20254486080791267, 0.07921246984707457, 0.13790291946913513, 0.09867569045828921, 0.14811187237501144, 0.21575637188340935, 0.33808718408857075, 0.23019528495413916, 0.15025012620857783, 0.146337109750935, 0.13474386398281368, 0.28866570602570263, 0.25889579632452553, 1.171225158231599, 0.2185955931033407, 0.13406121704195226, 0.12915984647614615, 0.16706023418477603, 0.23304290643760137, 0.17308810858854226, 0.11074978006737572, 0.17405393533408642, 0.2288544997572899, 0.18367012004767144, 0.31686917692422867, 2.999267871890749, 3.4620832545416693, 9.342238630567278, 26.5608857018607, 22.420000791549683, 22.328486067908152, 28.163131611687795, 28.308173520224436, 33.706937721797395, 43.244698660714285, 49.08738327026367, 46.9730464390346, 48.9905948638916, 42.902677059173584, 47.75856460843767, 49.37540694645473, 46.7422377041408, 48.556169169289724, 53.07889059611729, 46.43279620579311, 50.899400506700786, 44.24010453905378, 45.36723436628069, 42.92659623282296, 48.62238550186157, 50.7984744480678, 54.430294377463206, 54.98090784890311, 52.677215235573904, 49.45293494633266, 50.404344831194194, 52.04693719318935, 54.808495249067036, 58.03597518375942, 57.10185241699219, 57.339418275015696, 53.28703083310808, 41.87743214198521, 17.03906740461077, 15.762956040246145, 54.957513264247346, 52.19577802930559, 57.39978422437395, 47.06406784057617, 44.30312817437308, 58.827187401907786, 53.59886251177107, 57.79686682564871, 51.82267018726894, 4.839376892362322, 1.2045686947447913, 28.444330419812882, 34.6393894468035, 22.720532962254115, 16.30094984599522, 11.2951340675354, 30.505051476614817, 31.252358027866908, 45.97185271126883, 32.61854062761579, 35.92119312286377, 47.20844098499843, 36.23834364754813, 42.2980135508946, 53.380630016326904, 69.09829248700822, 38.44494908196585, 0.6758130618504116, 0.22632116212376527, 0.1991105643766267, 0.1844236331858805, 0.1632059110062463, 0.16659790756446974, 0.2013657297939062], [0.03903342244614448, 0.07647521886974573, 0.03533661099416869, 0.0689601314121059, 0.0431512716625418, 0.11317704232143504, 0.0724194250734789, 0.09228336811065674, 0.12340934361730303, 0.010591271765796202, 0.08909929503819772, 0.1292389908007213, 20.0270550932203, 71.93429006849016, 45.82986627306257, 28.56008393423898, 47.30281489236014, 36.04830346788679, 28.641402176448278, 22.356956311634608, 44.4765830039978, 41.606622627803254, 17.490257365362986, 18.850818872451782, 15.412523644311086, 57.56190654209682, 52.71406848090035, 20.891570806503296, 0.43900629452296663, 13.932577320507594, 49.784315381731304, 62.07272570473807, 62.65631880078997, 48.053293296269004, 23.78812367575509, 47.9908880506243, 63.35812854766846, 50.414728913988384, 25.85183072090149, 1.8558234572410583, 5.300253076212747, 35.71650266647339, 51.332978521074565, 48.591122082301546, 49.610652106148855, 49.59333719526018, 53.43785885402134, 53.56491361345564, 53.661062785557334, 51.81551006862095, 54.23918764931815, 52.153272424425396, 52.62054225376674, 52.46910626547677, 53.20693894795009, 52.38231284277779, 51.632706437792095, 49.01066820962088, 48.53729438781738, 49.95939608982631, 47.53678158351353, 47.178772177015034, 46.43171228681292, 38.00223766054426, 39.37646974836077, 24.21686748095921, 19.85672174181257, 18.038242680685862, 16.56805944442749, 17.564962659563335, 12.782094597816467, 11.988970756530762, 14.244822416986738, 5.047683017594474, 2.6037060575825826, 0.3381686897150108, 0.390438549220562, 0.027238376970802034, 0.05814260723335402, 0.021072503811280643, 0.10290478888366904, 0.05485578699569617, 0.051837798939751725, 0.023328539449721575, 0.10757100635341235, 0.024001747968473604, 0.04321705563259976, 0.08542570644723517, 0.12493692950478621, 0.25800759398511475, 0.25342615268060137, 0.05828343039112432, 0.027061813677261983, 0.04654472028570516, 0.029371446796825955, 0.038552534500403066, 0.0188555823239897, 0.020740323600226214, 0.027312454335125427, 0.02808467298746109, 0.032956639238234074, 0.06432079071445124, 0.16906318813562393, 3.2158510386943817, 1.9938316174915858, 8.79989959512438, 16.62465078490121, 15.42548029763358, 11.441095743860517, 22.401225021907262, 12.334984966686793, 17.737309251512798, 44.17916188921247, 40.70120286941528, 40.83793299538748, 44.51676096235003, 43.47078262056623, 42.80161551066807, 46.78852660315377, 47.5975991657802, 45.206119537353516, 46.6241044316973, 48.36383955819266, 45.2716896874564, 37.45225647517613, 39.78930391584124, 45.66028159005301, 50.01830291748047, 51.10511929648263, 52.538407598223, 51.449642249516074, 48.55298342023577, 45.3436348097665, 51.869956152779714, 50.02362871170044, 51.2001393863133, 51.86371667044503, 52.5889835357666, 42.52588667188372, 26.51814385822841, 11.784801415034703, 41.84819064821516, 47.152952671051025, 42.87028455734253, 45.59044524601528, 36.62687301635742, 42.96087517057146, 45.79512875420706, 45.96098920277187, 54.3138564654759, 6.142303960663932, 1.2377416746956962, 27.998660802841187, 33.096719128744944, 25.977657386234828, 16.113478762762888, 6.751616248062678, 14.2828004019601, 25.029066732951573, 25.242425067084177, 35.31030750274658, 19.646038464137487, 28.712053196770803, 27.995179755347117, 21.608762128012522, 21.575217962265015, 41.34771190370832, 50.92563690458025, 5.199119005884443, 0.2574574649333954, 0.04760656991441335, 0.08190752273159367, 0.033933441287704875, 0.07842243795416184, 0.09971726206796509, 0.13761731050908566, 0.05971973296254873, 0.07980996742844582, 0.022322538342060785, 0.08591772575995751, 0.04374956312988486, 0.09821218318705048, 0.08404702506959438, 0.05038658216861742, 0.11981221235224179, 0.08536015317908355, 0.1924123109451362, 0.1360953293208565, 27.55890757696969, 85.56243119921002, 49.36300441196987, 30.745928151266916, 48.45745958600725, 22.23562513078962, 34.07231569290161, 27.236709186008998, 36.309225695473806, 38.92283228465489, 27.009378024509974, 28.718954495021276, 28.345235211508616, 60.496228081839426, 54.302607331957134, 30.44695063999721, 0.7966793105006218, 10.246330414499555, 52.437735148838584, 61.30722876957485, 57.97528961726597, 51.38259560721261, 28.586549622671946, 54.20261580603463, 62.67746911730085, 54.5056163242885, 32.159931727818076, 3.6067592969962528, 4.36676606961659, 33.20149448939732, 51.75918102264404, 49.245889050619944, 50.28203221729824, 49.599545410701204, 56.171398299080984, 54.55930158070156, 56.761776311056956, 52.27392789295742, 53.891927106039866, 52.03434705734253, 54.99687828336443, 54.010862895420615, 54.501982416425435, 53.00820657185146, 52.32888119561331, 50.172087396894185, 50.219807624816895, 53.458957059042795, 48.94497299194336, 49.59689814703805, 47.26888336454119, 43.446439606802805, 40.240620681217735, 25.19326135090419, 18.896647453308105, 22.93252944946289, 23.51259286063058, 22.582272495542252, 17.546457869665964, 18.011568546295166, 18.457595995494298, 5.229473948478699, 0.6444442250898906, 2.3542904811246053, 0.3435378558933735, 0.05615255223321063, 0.09151665746633496, 0.01116177043877542, 0.05316157326368349, 0.05987629134740148, 0.05793056504002639, 0.0557164001012487, 0.07635953543441636, 0.0033447425313560025, 0.03307928783552987, 0.10274529922753572, 0.07306663213031632, 0.09871784783899784, 0.12488696218601295, 0.07053624612412282, 0.02627903702003615, 0.04006072785705328, 0.054096048298690996, 0.010394781595095992, 0.032908792341394086, 0.04531230730935931, 0.03423221382711615, 0.027885427964585166, 0.0796455041106258, 0.04547511160905872, 0.36537289566227366, 3.5659195227282385, 3.6910342148372104, 12.393924798284258, 20.789123092378887, 19.70948941367013, 17.411100012915476, 28.05903717449733, 22.828693832669938, 18.972071886062622, 40.737389087677, 44.31984206608364, 41.52115978513445, 46.97219181060791, 44.65716668537685, 45.42937558037894, 48.34260586329869, 49.22441564287458, 45.278596196855815, 49.54122223172869, 50.07610150745937, 48.493656226566856, 37.17588145392281, 42.08803898947579, 46.87675830296108, 50.27951349530901, 51.46371929986136, 53.31215899331229, 51.8206239427839, 50.15816668101719, 49.60383244923183, 52.295971052987234, 51.295736176627024, 52.533189501081196, 54.69988795689174, 50.14356851577759, 40.0148354939052, 30.68120915549142, 16.944356509617396, 47.96677432741438, 47.60894557407924, 47.032839162009104, 49.478431361062185, 40.66886942727225, 46.80273566927229, 51.50929600851876, 52.048920903887065, 49.45968859536307, 2.5011582459722246, 4.171009693826948, 39.76988022668021, 32.7044620513916, 27.333553177969797, 20.66731595993042, 17.382094757897512, 17.688701391220093, 25.989663873400005, 25.610533680234635, 24.028899601527623, 29.954708984919957, 20.23048792566572, 32.057327679225374, 20.67968201637268, 20.939070429120743, 48.62044695445469, 59.07653045654297, 6.843306413718632, 0.2936500071414879, 0.17162036948970386, 0.0022747699903058155, 0.15943174995481968, 0.058472551671522, 0.0414426560247583, 0.1220316868275404, 0.23014108357684954, 0.23141170825277055, 0.15128360289548123, 0.13514700877879346, 0.1527350571538721, 0.2850251756608486, 0.2432239172714097, 0.25226952188781326, 0.3346224757177489, 0.19320574908384255, 0.3636152185499668, 0.3249882826847689, 39.49808406829834, 98.58409186771938, 58.018382344927105, 44.37534427642822, 61.12423406328474, 45.75588880266462, 37.726137093135286, 32.975097860608784, 55.525987080165315, 56.91858673095703, 24.200909205845424, 27.954982689448766, 20.577291624886648, 62.461359296526226, 62.5602182660784, 29.646671022687638, 1.8928039414542062, 18.592710665294103, 57.326098578316824, 68.14497184753418, 63.65350341796875, 55.17408514022827, 33.50254256384713, 57.804353509630474, 73.17877496991838, 60.92764173235212, 30.44049228940691, 2.9454542909349715, 6.722276610987527, 41.62684883390154, 55.78581149237496, 51.26465688432966, 50.32274866104126, 51.22037254061018, 54.62357241766793, 55.94713476725987, 60.109665053231375, 55.66044861929757, 57.40207018171038, 55.40106889179775, 58.20496232169015, 56.821954659053254, 56.343255043029785, 56.876074177878245, 53.894522258213584, 54.335948262895855, 51.38555553981236, 56.85075841631208, 51.55454267774309, 54.330778803144185, 52.15180288042341, 45.77617406845093, 47.30572966166905, 31.760295663561138, 27.675524405070714, 29.37553494317191, 25.75362661906651, 25.311128854751587, 23.419681549072266, 24.42942156110491, 28.886975833347865, 13.90814745426178, 2.994548959391458, 3.7218946388789584, 0.7645831927657127, 0.10313781816512346, 0.3058882275862353, 0.07761435702975307, 0.13241462968289852, 0.2150176236672061, 0.11354208059076752, 0.11536130761461598, 0.15739520852054867, 0.09522833901324443, 0.18715757291231835, 0.22899688354560307, 0.41920235433748787, 0.6348614650113242, 0.5841561715517725, 0.2906867361494473, 0.10200459683047873, 0.08424530657274382, 0.13405481167137623, 0.17292388954332896, 0.06154779451234, 0.1550501507839986, 0.1230807291077716, 0.15082822447376593, 0.1486324444413185, 0.1669991931744984, 0.5933221482804844, 7.056291716439383, 4.457912104470389, 24.619091749191284, 29.875558580671036, 23.790557282311575, 18.674787998199463, 30.682887145451136, 22.728646721158707, 24.08596168245588, 47.23627546855381, 44.89361388342721, 44.37326676504952, 48.16463817868914, 46.91899292809622, 48.211729594639365, 51.49371119907924, 50.39011492047991, 47.104398659297395, 51.82502562659127, 53.47565705435616, 50.65964249202183, 39.12344067437308, 45.986016614096506, 48.179462160382954, 51.96662991387503, 54.96526745387486, 57.618298121861045, 54.34893444606236, 52.35958528518677, 50.25344385419573, 57.07775606427874, 54.142784867967876, 56.16495384488787, 57.97852052961077, 54.315583092825754, 47.246576172964915, 32.9193559374128, 15.910311698913574, 47.53334222521101, 53.2103922026498, 51.42763383047921, 54.12957634244646, 43.176661900111604, 49.77408068520682, 56.24713018962315, 52.6463235446385, 64.46956239427838, 8.204727326120649, 2.6735654175281525, 34.26506219591413, 45.03725051879883, 36.42579214913504, 22.914801120758057, 10.176879695483617, 22.485242639269146, 36.74114656448364, 33.264267989567344, 47.08877216066633, 29.167974880763463, 37.01147665296282, 41.66632502419608, 26.964244263512747, 35.70713996887207, 55.85775661468506, 72.27338995252336, 12.04545439992632, 0.4325734025665692, 0.22695009623255047, 0.16153196511524065, 0.26966034727437155, 0.21918677352368832, 0.17906277227614606, 0.24126843363046646], [0.04426054749637842, 0.05015002450506602, 0.012616022805949407, 0.0781466473958322, 0.03842877310567668, 0.038845698947885206, 0.07549107167869806, 0.06809261082006351, 0.06920347442584378, 0.09569672495126724, 0.08429493462400776, 0.023211314043562328, 5.284495430333274, 55.07572644097464, 57.23374659674508, 33.6693514415196, 46.24670607703072, 62.774069922310964, 33.59516552516392, 36.081046853746685, 27.3327419757843, 34.894266741616384, 17.368196623665945, 27.21972952570234, 13.38259960923876, 32.63335766111101, 77.69920349121094, 47.318239893232075, 7.0826766320637295, 0.43721691625458853, 27.934367384229386, 58.32338741847447, 51.58050809587751, 62.22966466631208, 62.90448066166469, 46.69929436274937, 49.06505523409162, 44.56067705154419, 52.71287339074271, 35.59780658994402, 5.366597950458527, 8.172440784318106, 38.72211619785854, 40.604605538504465, 49.92423473085676, 47.36317389351981, 51.56359618050711, 51.663372312273296, 57.026662485940115, 55.99202707835606, 52.7327869279044, 54.01997198377337, 53.01566546303885, 49.9654722894941, 50.51408120564052, 50.192737443106516, 53.01074613843645, 51.13909946169172, 50.448524951934814, 47.28305768966675, 47.50311408724104, 46.45748315538679, 41.08215522766113, 42.33970621653965, 23.703432083129883, 7.905054994991847, 11.694286363465444, 22.488801853997366, 17.303595747266495, 9.014973265784127, 14.039321626935687, 14.384630594934736, 8.71289164679391, 1.5115833176033837, 1.5710400300366538, 1.1984564512968063, 0.022880336535828452, 0.07717799794461046, 0.04418514868510621, 0.0765392929315567, 0.006486108609741288, 0.03338215533377869, 0.021309019066393375, 0.09720069782010146, 0.04310384885008846, 0.04675283715394991, 0.0487773786964161, 0.04908784917954888, 0.11603463148432118, 0.011041640054567583, 0.08550351405782358, 0.016668898053467274, 0.03239299376894321, 0.06286332463579518, 0.014099178220411497, 0.07397253066301346, 0.03563383647373744, 0.04259874738220658, 0.0278387718967029, 0.04668631358072162, 0.06063520562435899, 0.10021498786019427, 0.029763151492391313, 0.3336018504840987, 4.782233604363032, 3.5227362513542175, 8.831391436713082, 19.626929180962698, 29.567194053104945, 12.435833726610456, 14.947213206972394, 14.821374382291522, 21.135132959910802, 43.7461119379316, 43.095190797533306, 40.64858416148594, 44.72457115990775, 43.137474060058594, 43.31550080435616, 45.35506459644863, 47.47768020629883, 47.90516812460763, 46.17098113468715, 43.10168041501726, 41.21577256066458, 40.37141009739467, 44.055741037641255, 49.53307894298008, 51.660662514822825, 50.98168454851423, 50.510308333805625, 48.85079710824149, 48.93384892599923, 47.100386074611116, 51.06514630998884, 51.209005287715364, 49.41633531025478, 32.998697417122976, 16.251827819006785, 31.16163887296404, 36.60256126948765, 42.0712000301906, 44.58955029078892, 47.377904074532644, 48.02002879551479, 46.256329332079204, 62.33540235246931, 33.77886547361101, 25.83163751874651, 6.027110644749232, 0.2709351245846067, 29.325504439217703, 50.1293386050633, 33.2749091557094, 29.530017716544016, 11.082845755985804, 8.6683589049748, 27.943516424724034, 20.34654368673052, 32.39457934243338, 25.157372168132238, 20.775219746998378, 32.76623501096453, 25.550907714026316, 25.66103492464338, 34.002045086451936, 47.60420342854091, 45.795910426548545, 2.1646074822970798, 0.07979811342167002, 0.08355955872684717, 0.0077372118331758034, 0.08782326922352825, 0.10369708708354405, 0.0158453278709203, 0.06133470058973346, 0.09205103093492133, 0.04885429742613009, 0.09235202228384358, 0.04538747541872518, 0.012194622025292898, 0.019724292048652257, 0.03084606284807835, 0.017608704677383815, 0.07356818486005068, 0.036516505360071144, 0.1379558044884886, 0.05349404524479594, 7.459489600999015, 65.98993246895927, 63.70806762150356, 28.689579248428345, 56.305686133248464, 45.244501386369976, 30.86417954308646, 42.691993781498496, 21.909733772277832, 33.27190753391811, 19.305145944867814, 29.3485655103411, 24.558708429336548, 46.16327905654907, 73.31357002258301, 54.78022650309971, 12.810913119997297, 0.458929819720132, 22.138117585863384, 63.35812159946987, 57.8151718548366, 64.24164758409772, 63.657588958740234, 51.86153841018677, 54.45949418204171, 53.479391711098806, 56.13360704694475, 44.9055369922093, 8.968545402799334, 8.794532111712865, 38.944069453648154, 39.86692919049944, 48.782590116773335, 49.65371356691633, 52.45111737932478, 54.148607458387104, 60.22028037479946, 58.836755071367534, 56.193858351026265, 57.45166989735195, 55.19947385787964, 51.6648279598781, 53.00095612662179, 53.559379373277935, 55.02557781764439, 52.11827087402344, 50.26261895043509, 49.822089263371055, 51.404666560036794, 48.58687673296247, 45.11891269683838, 44.00446680613926, 23.05756402015686, 11.966865062713623, 22.791736364364624, 31.16875035422189, 17.68417637688773, 15.698457649775914, 25.085863045283727, 18.598180634634836, 9.921772241592407, 7.7500346047537665, 3.8090537105287825, 0.7648021695869309, 0.06826423946768045, 0.11466677274022784, 0.037513083312660456, 0.04898265589560781, 0.027379980443843772, 0.12638284691742488, 0.05050428085295217, 0.05186038737052253, 0.016051458327897956, 0.04750153947887676, 0.06090221593954733, 0.01654130463222308, 0.3755024735416685, 0.0655645454036338, 0.03883835380630834, 0.02273359994537064, 0.03607186136235084, 0.006477795283509684, 0.03809744106339557, 0.0460061195439526, 0.011690191458910704, 0.045771638197558265, 0.06857869295137269, 0.016772179564993297, 0.06084949376859835, 0.039417907529111416, 0.09543981123715639, 0.12295594651784215, 7.685279130935669, 8.716209411621094, 7.808448110307966, 15.407244750431605, 32.01166411808559, 14.86875241143363, 19.740674665996007, 27.479309013911656, 23.941409621919902, 40.43937390191214, 44.76798003060477, 42.952301093510215, 44.636030265263145, 47.40339354106358, 44.54255614961897, 45.87502261570522, 48.97902263913836, 48.63946417399815, 47.77876649584089, 43.14624963487898, 43.22820711135864, 42.97156497410366, 47.110495703560964, 49.32254157747541, 51.94986391067505, 53.1011699948992, 50.652187074933735, 51.20349189213344, 51.46112067358834, 50.86741100038801, 55.061357566288535, 53.23261948994228, 47.96120882034302, 29.09804473604475, 14.957227298191615, 34.09066241128104, 41.60199165344238, 43.774988651275635, 51.438306263514924, 51.16164984021868, 55.0236496925354, 46.520423412323, 59.4916227885655, 36.44957930701119, 20.749851873942784, 1.9269235048975264, 0.9284671502453941, 39.4777432169233, 50.725921358381, 35.04825619288853, 30.878339971814835, 21.774558305740356, 16.931167091642106, 27.62806647164481, 24.70262472970145, 24.699006455285208, 26.76799934250968, 24.944781609943934, 22.131930215018137, 31.025325638907297, 15.960194553647723, 34.72376489639282, 53.2506674357823, 55.43843977791922, 2.151502311229706, 0.15502967259713582, 0.04782960776771818, 0.03257993695193103, 0.007037440364781235, 0.03463824239692517, 0.07463555437113557, 0.05879639607987233, 0.13580092654696532, 0.15888262513492787, 0.2479534149169922, 0.24639929831027985, 0.09060178870069129, 0.11055088109735932, 0.10981802935046808, 0.2622467822262219, 0.40946035566074507, 0.19629149564674922, 0.18045767742608274, 0.1338671695973192, 12.787362200873238, 81.00658076150077, 69.70525237492153, 44.92442567007882, 60.29523059300014, 75.10290486471993, 43.94728313173567, 49.071461473192485, 39.03487546103341, 43.287833077566965, 25.23806507246835, 36.82932267870222, 18.637288570404053, 39.47934825079781, 82.95725972311837, 56.63619804382324, 12.200483475412641, 1.5902572274208069, 36.91108907972063, 67.68466758728027, 59.351025990077424, 70.72319820949009, 71.16657665797642, 59.62736974443708, 59.2168493270874, 54.10361439841134, 61.59566933768136, 44.91700151988438, 7.549816182681492, 12.03806585924966, 47.44809477669852, 46.24100160598755, 49.90576294490269, 50.05143192836216, 52.84386083057949, 53.1433698790414, 63.0901643208095, 59.480915614536826, 58.885051999773296, 60.96184771401541, 57.07316677910941, 54.24350595474243, 56.093637534550254, 55.11212110519409, 57.32224232809884, 51.65069532394409, 54.521395683288574, 52.20515809740339, 53.37465109143938, 53.729693617139546, 48.76720333099365, 47.29712779181344, 31.2536712374006, 15.393539428710938, 23.413612297603063, 32.3231657573155, 24.92996805054801, 16.88875355039324, 29.769226823534282, 23.5912047794887, 19.457643270492554, 10.851565412112645, 5.9902013795716424, 2.1318775585719516, 0.17661376297473907, 0.1875533081058945, 0.11357095225581101, 0.2133322512464864, 0.16821420512029103, 0.24871804245880672, 0.1911593960332019, 0.16317862032779626, 0.1994849257171154, 0.10950534684317452, 0.174849965476564, 0.11419692795191493, 0.6150064989924431, 0.11412066061581884, 0.2504273535949843, 0.11796891769128186, 0.15364797173866204, 0.09967165094401155, 0.04946715025497334, 0.19313990404563292, 0.07231075769024235, 0.11798403545149735, 0.12549685660217488, 0.07893499652189867, 0.16270870768598147, 0.1369063686579466, 0.11418615281581879, 1.7989193392651421, 10.535218272890363, 14.43807874407087, 21.63526255743844, 26.538210255759104, 42.416164193834575, 18.262488842010498, 25.397588763918193, 24.820537396839686, 27.321748188563756, 46.468881675175254, 44.80552462169102, 46.10997942515782, 48.63489573342459, 49.0728372165135, 46.26629652295794, 47.85418224334717, 51.85374253136771, 51.78938136781965, 49.00860112054007, 47.3322822025844, 44.49636452538626, 44.09760046005249, 48.22533416748047, 50.61799151556832, 56.62884684971401, 55.46117428370884, 53.54036215373448, 54.52795478275844, 53.839103426252095, 52.493664673396516, 55.33876786913191, 54.849482672555105, 50.97439241409302, 38.79358536856515, 19.391145535877772, 34.238513129098074, 43.20998546055385, 49.48078332628523, 51.152523381369456, 54.69396461759295, 54.88506439753941, 55.502432686941965, 66.66805580684117, 40.01762172154018, 31.32537317276001, 8.475086075919014, 0.8476104204143796, 35.81237391063145, 59.77662399836949, 45.530096667153494, 38.77846956253052, 14.907261065074376, 12.712239146232605, 42.0053380557469, 28.649809496743337, 42.09952088764736, 35.989618982587544, 28.912225587027415, 46.00405066353934, 37.90578624180385, 36.951273986271445, 49.83423818860735, 61.879086358206614, 66.90257140568325, 3.554053302322115, 0.27517360714929445, 0.1664427537471056, 0.1199858630342143, 0.09056419786065817, 0.167015369449343, 0.181389523137893, 0.1499529278704098], [0.07183528784662485, 0.06566103308328561, 0.0552842547185719, 0.057883006520569324, 0.005786240874190948, 0.04272229503840208, 0.06466404122433492, 0.039229804051241705, 0.06935669441840478, 0.048079349366681914, 0.013267748057842255, 0.045137377588876655, 0.058465562760829926, 35.86310618264334, 64.54654843466622, 39.10837697982788, 25.911555698939733, 45.394971575055806, 39.02433156967163, 29.717639923095703, 30.009426048823766, 32.00230142048427, 35.45027896336147, 32.80918877465384, 23.282887152263097, 11.806063771247864, 67.7355284009661, 50.317051138196675, 44.35106379645211, 2.1975384695189337, 0.2966199277767113, 20.509951421192714, 55.292614459991455, 45.19368921007429, 50.426110063280376, 53.54977696282523, 43.13629286629813, 51.492477893829346, 49.97973346710205, 46.21941007886614, 32.92740542548043, 5.010649987629481, 20.144764525549753, 36.495854309626985, 42.818152223314556, 48.78114141736712, 49.34370231628418, 58.132958139692036, 54.91173505783081, 54.26519823074341, 54.659508500780376, 53.48586743218558, 54.29793119430542, 53.466888427734375, 55.57730647495815, 54.33659097126552, 50.08387654168265, 44.98910297666277, 44.69101136071341, 48.86202539716448, 44.614094802311485, 41.67249155044556, 47.62736177444458, 23.247340168271744, 6.940025772367205, 21.992728267397197, 28.535277128219604, 16.43424756186349, 8.393420423780169, 25.203985895429337, 24.95631214550563, 11.232784407479421, 4.717272290161677, 4.797193510191781, 2.3125077060290744, 0.14315221565110342, 0.03883363459525364, 0.030472434325409786, 0.022249794299049035, 0.04543861321040562, 0.05254845580618296, 0.042110466797436984, 0.06100352121783154, 0.058150172898811955, 0.04363209514745644, 0.014111724332906306, 0.02103718606355999, 0.037479709567768235, 0.07294614466705493, 0.07773455950830664, 0.03897963158254113, 0.04033757693001202, 0.018699085007288625, 0.03570534049400261, 0.004997728899719992, 0.014339943649247289, 0.008009902334639003, 0.016922215531979288, 0.02860698549609099, 0.06682498526892491, 0.12329703250101634, 0.03160554709445153, 0.05901987158826419, 0.11495116033724376, 1.9615042550223214, 5.268354330744062, 1.8373106334890639, 5.8586784941809515, 20.076196227754863, 29.506275721958705, 5.83910151038851, 11.926042658942086, 19.675366810389928, 23.84757419994899, 39.063387393951416, 46.40752560751778, 45.75627095358712, 43.90293625422886, 47.99462618146624, 46.8713595526559, 46.470719473702566, 48.02820682525635, 47.80514880589077, 44.268328121730256, 39.80407926014492, 42.81118318012783, 48.62246888024466, 48.46866355623518, 51.09541266305106, 48.359093938555034, 50.81702961240496, 47.262105396815706, 47.812347139631, 48.99814755575997, 54.674634729112896, 44.65547827311924, 29.32011958530971, 6.929410661969866, 10.234858070101057, 44.45421327863421, 42.9300251688276, 43.469549315316335, 46.94926275525774, 41.67336702346802, 44.81067671094622, 53.322737625667024, 41.101537227630615, 25.979050500052317, 8.973776527813502, 0.1327363909887416, 12.908862744058881, 51.68908412115914, 35.54857512882778, 33.81383228302002, 22.940957614353724, 6.44486847945622, 25.00850006512233, 18.26778163228716, 25.965537990842545, 34.59983682632446, 24.049426317214966, 29.001596791403635, 27.262674604143413, 33.86532538277762, 28.67732436316354, 38.81931454794747, 47.868620600019185, 24.573449032647268, 0.040694944360958676, 0.05635999395911183, 0.028510491031089, 0.06109127615179334, 0.03524999939171331, 0.10695033001580409, 0.03936406238270657, 0.020312205322885087, 0.0822089822696788, 0.01056340942159295, 0.036793249260101996, 0.07668860456241028, 0.08427426644733974, 0.0955360478588513, 0.06540010922721454, 0.022058050480804274, 0.022160555069733943, 0.03682444151490927, 0.06172542140952178, 0.050164182138230116, 0.1651942086006914, 43.80495623179844, 71.96747466496059, 37.60183034624372, 32.771755354745046, 47.37227603367397, 20.628392151423864, 38.05061796733311, 24.25655038016183, 25.216093131474086, 35.22157205854143, 33.357474599565776, 26.90187202181135, 23.273098877498082, 68.84578105381557, 47.48950604030064, 57.08063261849539, 5.935891219547816, 0.6430735300694193, 15.960152864456177, 58.260537488119944, 51.16923379898071, 54.53303739002773, 58.60132231031145, 47.666278634752544, 58.033501625061035, 55.523715019226074, 50.90280164991106, 39.931641238076345, 9.216114929744176, 20.865317038127355, 42.05829375130789, 42.69083343233381, 49.531512124197825, 51.76047338758196, 57.05948577608381, 54.512470722198486, 54.7050713130406, 54.75029713766915, 54.71216194970267, 56.516584805079866, 55.148689474378315, 59.04041372026716, 56.43848010471889, 51.501652990068706, 44.50030415398734, 45.576489789145334, 50.715856892721995, 46.78980507169451, 47.47647469384329, 46.12856585638863, 22.98037474496024, 12.70748484134674, 33.57994897024972, 38.3575998033796, 16.622109481266566, 13.934515867914472, 31.871821199144634, 26.556225197655813, 12.934499859809875, 11.54263584954398, 13.472742932183401, 1.0385391009705407, 0.012609215403374816, 0.07944674084761313, 0.030127650326383964, 0.02414603335117655, 0.046126372912632566, 0.04582957491012556, 0.03416087604793055, 0.025585784576833248, 0.04411473371354597, 0.00968011119402945, 0.022014649684673974, 0.07116746011057071, 0.1970038352800267, 1.17962737594332, 0.01949933054856956, 0.007507814410408693, 0.09763873967209033, 0.04468212130346468, 0.036250485706010034, 0.04353447770699859, 0.017252633248322775, 0.003336231369758025, 0.04977789893746376, 0.00984457366368068, 0.028742726426571608, 0.06844339985400438, 0.0380596195214561, 0.045225057883986404, 0.05681943680558886, 2.0592927677290778, 10.261519176619393, 6.090422630310059, 7.311394827706473, 15.094181503568377, 28.439610855919973, 8.577087368283953, 15.465376853942871, 35.42606101717268, 27.624911989484513, 37.493775435856406, 47.948719433375764, 49.628720896584646, 44.19352034160069, 48.15595293045044, 47.684132031032014, 46.676677976335796, 49.99067687988281, 49.5747264453343, 46.049387659345356, 41.539704527173726, 44.993633202144075, 49.446188245500835, 49.06072998046875, 51.11676795142037, 47.454963071005686, 52.51307446616036, 49.20771564756121, 50.3154148374285, 50.41682379586356, 52.90765571594238, 42.44457885197231, 25.217986515590123, 7.205258922917502, 15.551280907222203, 47.24360234396798, 44.82939863204956, 45.46088913508824, 50.38495588302612, 42.21150153023856, 49.257551601954866, 53.88558340072632, 50.16230085917881, 29.07598420551845, 3.809983466352735, 0.2548928739769118, 20.799715621130808, 54.70350796835763, 41.94905764716012, 40.46894890921456, 32.15071494238717, 14.535759993961879, 24.361805166516984, 18.622230087007793, 26.992052691323416, 20.73481944629124, 28.657775606427872, 24.83756743158613, 26.836404357637676, 36.712054456983296, 25.486096654619487, 39.90803125926426, 55.18559830529349, 28.309165375573293, 0.031345430695052655, 0.044959503026413064, 0.02308824984356761, 0.07261266506143979, 0.008153601632719594, 0.03467245073989034, 0.06930469149457556, 0.019721445594249026, 0.159193326319967, 0.16353253062282289, 0.19942491608006613, 0.19289287658674376, 0.121097506955266, 0.16736701343740734, 0.11719147940831524, 0.20087510826332228, 0.32039690762758255, 0.16207074906144822, 0.1845194287598133, 0.13041607263897145, 0.42543233718190876, 59.90368570600237, 78.62089593069894, 50.738323892865864, 38.432192189352854, 56.01618596485683, 52.41087341308594, 40.113760471343994, 44.95476497922625, 41.41796166556222, 51.59069415501186, 44.54855939320156, 30.00931487764631, 14.979638712746755, 73.79247461046491, 59.82139124189104, 54.08815118244716, 5.321307420730591, 1.317927034837859, 28.18731481688363, 65.58757618495396, 55.13602985654558, 61.1470172064645, 63.36943326677595, 56.41450187138149, 61.30943134852818, 58.256309509277344, 55.99492795126778, 39.876587186540874, 7.930655632700239, 25.086260829653057, 45.14955425262451, 48.46583563940865, 52.292774881635395, 54.8782308442252, 58.270021779196604, 57.86908292770386, 57.442241191864014, 56.90573603766305, 57.17511074883597, 58.98099272591727, 58.285655226026265, 60.763796261378694, 58.6162748336792, 53.03354665211269, 47.55671943937029, 48.43307835715157, 54.81650652204241, 50.556169918605256, 47.99234022412981, 51.43300826208932, 27.63128522464207, 15.03478135381426, 31.47738586153303, 38.594752243586946, 24.39694220679147, 15.801125969205584, 36.943009104047505, 34.23331240245274, 17.407372304371425, 14.15267106464931, 19.076204538345337, 7.191777680601392, 0.16040384636393615, 0.13103230457220758, 0.1395575813949108, 0.14309592438595636, 0.20700521075299808, 0.10698788014373609, 0.07185701453792197, 0.15911578333803586, 0.21852450977478707, 0.08620431181043386, 0.1519467080278056, 0.11602065366293703, 0.07678193026887518, 1.1978286164147514, 0.17189879954925605, 0.1692968484546457, 0.1655344260590417, 0.19451182042913778, 0.1261132920959166, 0.126296035147139, 0.1852531558168786, 0.08948351549250738, 0.1636802748377834, 0.07069779852671282, 0.24941394797393254, 0.16518226638436317, 0.14666676920439514, 0.18342322829578603, 0.307205996875252, 4.597733744553157, 17.885952063969203, 10.807727490152631, 10.592352441379003, 31.145234176090785, 43.550697326660156, 11.802497608321053, 18.633480957576207, 29.440177508762904, 29.882645743233816, 43.86484622955322, 47.956650802067344, 48.5453508240836, 47.46999897275652, 48.23801462990897, 49.66787052154541, 48.53154475348336, 53.75016301018851, 51.53579296384539, 50.52487175805228, 43.309546198163716, 48.19342109135219, 53.830928870609824, 52.14231858934675, 52.71654551369803, 51.66078758239746, 54.08514608655657, 51.11824791772025, 54.39614050728934, 53.143387249537874, 59.17757116045271, 47.0844851221357, 35.46968528202602, 11.422498890331813, 13.903902973447527, 48.6994514465332, 48.66060059411185, 50.2417847769601, 55.26253918239048, 50.533119269779746, 53.34421450751168, 59.850198473249165, 49.33099406106131, 31.97453989301409, 12.453575083187648, 0.27795712064419476, 17.984651224953787, 58.42482416970389, 47.00726979119437, 44.51606266839163, 28.625410897391184, 7.562319466045924, 37.026470865522114, 30.053283078329905, 36.80215869631086, 48.0434581211635, 31.455589362553187, 40.79682397842407, 39.05553592954363, 48.59365817478725, 40.24943447113037, 50.5238607951573, 66.43595123291016, 41.908289091927664, 0.31307850033044815, 0.2113537381270102, 0.19170955222632202, 0.2573287875524589, 0.11956092369343553, 0.24298765137791634, 0.23958192127091543, 0.1077701428106853], [0.03558770966316972, 0.022127847985497544, 0.008244631346315145, 0.025881493530635322, 0.04480904806405306, 0.029457027026052986, 0.0734448746911117, 0.03158587297158582, 0.09426532818802766, 0.1125549478456378, 0.02043802776773061, 0.059425615173365386, 0.20661879863057817, 14.18250662939889, 69.24335697719029, 42.78618008749825, 39.726325443812776, 34.03548329217093, 46.91782563073294, 32.45668928963797, 33.985966954912456, 26.499845777239116, 24.033838033676147, 29.3878402028765, 41.21992410932268, 8.759693843977791, 23.5979288986751, 32.71200779506138, 28.810569967542374, 37.043646812438965, 0.37635001806276186, 0.4715366746698107, 17.02169690813337, 59.23523426055908, 53.279672690800254, 55.36560181209019, 53.26806572505406, 32.082007680620464, 47.884518078395296, 56.665707043239046, 45.66208464758736, 28.218355894088745, 16.494399854115077, 34.50568873541695, 29.523350919995988, 33.43706274032593, 49.93714100973946, 53.27207483564104, 57.31286226000105, 58.714293071201865, 57.22211531230381, 54.84093638828823, 52.46948841639927, 52.54128762653896, 51.190415382385254, 49.88442850112915, 45.240645136152, 44.365998949323384, 44.91361774717058, 38.22329112461635, 45.458391257694785, 42.428323541368755, 22.835160868508474, 6.470848228250231, 27.29141582761492, 25.85412883758545, 7.410798362323216, 7.861594881330218, 7.812245300837925, 27.42713325364249, 12.57632109097072, 12.449090889522008, 8.240354214395795, 9.752125893320356, 0.5186750452433313, 0.19798192993870803, 0.011701693475645567, 0.05831287881093366, 0.04322822431900671, 0.04881361246641193, 0.019898502522015145, 0.04855013731867075, 0.033456604196024795, 0.02712843394173043, 0.06489565915295056, 0.050421675999781916, 0.12026863571788583, 0.024603471126673476, 0.13835690010871204, 0.10796352529100009, 0.08598614244588784, 0.03241546006341066, 0.0342571398110262, 0.058743015729955265, 0.03972223048497524, 0.08825646633548395, 0.04003062465095094, 0.05143986529271517, 0.09335408958473376, 0.02300245757214725, 0.059634373257202763, 0.06725779561591999, 0.06658995430916548, 0.30229296907782555, 0.3614696093967983, 7.4302776370729715, 1.667448022535869, 4.109076057161603, 4.9934371284076144, 16.24369321550642, 7.668084076472691, 3.6471763168062483, 14.268418499401637, 22.83584874016898, 21.679753610066005, 32.015746184757774, 44.91561882836478, 46.42287417820522, 41.5972112928118, 41.843059403555735, 48.05360943930489, 44.5962553024292, 45.27031741823469, 42.22705159868513, 44.32188136237008, 44.60023314612252, 45.715203625815256, 48.51959385190691, 52.218623706272666, 48.17844772338867, 48.610632623944966, 48.72317954472133, 45.51038115365164, 42.640903677259175, 39.93931552342006, 21.282813446862356, 5.425043157168797, 4.718187281063624, 32.26311247689383, 45.017507212502615, 50.10801458358765, 47.52721043995449, 39.31701748711722, 37.14452770778111, 40.26496369498116, 49.82619912283761, 47.353508949279785, 17.960327318736486, 0.5802826594029153, 3.3360913523605893, 42.4608028956822, 26.749671731676372, 49.884279114859446, 47.06632947921753, 9.070108090128217, 16.12475742612566, 37.01060465403965, 27.840749093464442, 28.324604272842407, 24.264292410441808, 31.937012672424316, 26.770014320101055, 28.740806579589844, 19.923554727009364, 20.790780237742833, 44.75930520466396, 47.471638747623985, 5.298125190394265, 0.2000685472573553, 0.09519956234310355, 0.06653400909687791, 0.11213513822960001, 0.03201930078544787, 0.04744318885994809, 0.02663240279071033, 0.011910174208294069, 0.034208458316113265, 0.056803223211318254, 0.07883394230157137, 0.052015388517507484, 0.034902209482554875, 0.039442453533411026, 0.057808849428381236, 0.01459650113247335, 0.16073585354856082, 0.11128155474684068, 0.010121460904234221, 0.04633305807198797, 0.18697941675782204, 17.838473285947526, 76.72761603764125, 48.81834207262312, 30.24747133255005, 46.148041657039094, 29.2816960471017, 29.64102213723319, 36.18727091380528, 16.96140044076102, 23.5362879548754, 29.038020985467092, 39.5436885697501, 17.749930654253276, 37.05157470703125, 32.663116795676096, 40.43186984743391, 47.29291023526873, 2.8298364835126057, 0.3237317715372358, 14.86080367224557, 60.088570322309224, 60.680480412074495, 56.62141922542027, 58.619811466761995, 35.625894682747976, 52.503746509552, 66.73242391858781, 49.82058150427682, 34.91668510437012, 19.996939863477433, 34.38153484889439, 30.29334681374686, 32.377121993473594, 48.300808974674766, 54.299247877938406, 57.273240157536094, 62.83019052233015, 58.104203019823345, 58.7122711454119, 55.64099366324288, 53.96478591646467, 52.30688319887434, 51.33251993996756, 46.43079512459891, 45.842244488852366, 44.08909586497715, 40.326451778411865, 46.29110506602696, 40.93615273066929, 22.794638974326, 14.883996759142194, 35.97107424054827, 37.82523577553885, 10.452037913458687, 12.43945460660117, 13.178294777870178, 27.674786158970424, 16.251852137701853, 17.550076144082205, 16.508581127439225, 15.22260332107544, 0.6367919785635812, 0.05751799539263759, 0.007508461563182729, 0.03768168569409421, 0.024642795623679246, 0.08584947870778185, 0.13714059894638403, 0.06110733029033456, 0.051262709977371354, 0.011751193453424742, 0.11364627642823116, 0.0356293886766902, 0.011870605438681585, 0.1347146869770118, 1.3814362840993064, 0.10416991742593901, 0.014096151954228324, 0.060850294439920356, 0.06708031799644232, 0.0903051331905382, 0.026277746107163172, 0.02840052086061665, 0.06849049018429858, 0.10631612368992396, 0.02370328755517091, 0.05898720691246646, 0.05995693523436785, 0.05686757547248687, 0.046716484640325816, 0.12958511151373386, 0.5295821971126965, 8.005375691822596, 7.713315112250192, 5.959381776196616, 8.000478948865618, 13.771715232304164, 11.759575980050222, 7.570798873901367, 19.399405206952775, 39.25221511295864, 27.883417981011526, 32.743507453373496, 42.54512970788138, 50.09358317511422, 40.197274344308035, 42.60874394008091, 49.545891421181814, 46.44937113353184, 47.660122530800955, 42.020179407937185, 45.02644606998989, 45.72232552937099, 46.81243882860456, 50.81845399311611, 52.54851027897426, 50.54989569527762, 48.48852150780814, 50.742388589041575, 46.70828880582537, 42.996026107243125, 38.30455378123692, 20.229805265154155, 6.489479388509478, 8.208444612366812, 37.898146697453086, 49.72427599770682, 51.98818670000349, 48.749075480869834, 42.981688499450684, 43.85600812094552, 44.43887513024466, 53.99171018600464, 47.23185641424996, 12.300968323435102, 0.305559653788805, 6.693075503621783, 48.12662805829729, 34.101928915296284, 53.21452638081142, 52.976696491241455, 18.172143152781896, 22.860382829393657, 32.37591995511736, 31.883987494877406, 25.386596713747295, 18.916786806924, 32.98111500058855, 22.736043078558787, 32.83874641145979, 22.358743735722133, 19.170236246926443, 50.69842038835798, 60.1011882509504, 5.703923004014151, 0.357169325862612, 0.23050423551883015, 0.0751632239137377, 0.03814132192305156, 0.02667977980204991, 0.047722226208341975, 0.043256590475461314, 0.03877472418493458, 0.17342421412467957, 0.12605003906147821, 0.11867040076426097, 0.19403893580394133, 0.14451738739652292, 0.192409501810159, 0.16170606363032544, 0.21684934252074786, 0.22130125149020127, 0.3197404114263398, 0.13839299817170414, 0.29956056284052984, 0.2158418401543583, 25.35020899772644, 88.23710550580705, 56.84292779650007, 53.56669235229492, 44.983936991010395, 60.24279253823416, 40.558966296059744, 46.572204862322124, 35.72165128162929, 32.50473608289446, 40.1667925970895, 56.16565213884626, 13.254236851419721, 31.209987912859233, 41.00425202505929, 40.36790820530483, 47.600680691855295, 2.43981694323676, 0.8032622401203428, 24.71819043159485, 67.19181796482631, 64.7606988634382, 64.52185453687395, 62.9111578805106, 41.0307594026838, 54.64352069582258, 66.17004367283413, 52.57436105183193, 34.724622998918804, 21.25985312461853, 43.58881861822945, 36.50517531803676, 38.58171394893101, 53.01065928595406, 56.230628217969624, 56.04045254843575, 62.84072399139404, 60.78237574441092, 60.70821762084961, 56.900726386478965, 55.66431876591274, 53.474444593702046, 51.965108258383616, 47.568128381456646, 47.52495922361101, 48.80061026981899, 42.18600511550903, 47.067336968013215, 45.42560965674264, 28.99004714829581, 16.793568440846034, 35.84258815220424, 36.44344057355608, 12.396624173436846, 13.059178335326058, 14.35893268244607, 35.78589085170201, 21.801637172698975, 17.800482273101807, 21.055273839405604, 22.234640223639353, 1.7686926126480103, 0.31039541001830784, 0.15588079978312763, 0.19618628200675758, 0.10798243606196982, 0.08618433573948485, 0.2383546142705849, 0.1559210369097335, 0.20108481629618577, 0.06473988108336926, 0.18650490364858083, 0.12585657515696116, 0.20190428303820745, 0.17525312384324415, 1.8747453561850955, 0.14680584174181732, 0.12256493392799582, 0.07039967059556927, 0.11217183340340853, 0.16224042352821144, 0.08476096604551588, 0.17507510339575155, 0.12634193125580037, 0.22233818870569977, 0.10258270866636719, 0.13840750525040285, 0.11632132610040051, 0.20021215240870202, 0.31407513256583897, 0.6423275758113179, 0.8375608825257846, 15.22940560749599, 14.606539555958339, 9.130289912223816, 9.993159770965576, 27.276369503566197, 15.682508059910365, 11.888267040252686, 23.20671057701111, 32.973468508039204, 28.70007450239999, 38.77727447237287, 48.192462239946636, 51.237534591129844, 42.628664425441194, 45.71381746019636, 52.50127642495291, 47.85192060470581, 49.314585890088765, 44.376938888004844, 48.130744865962434, 45.684607233319966, 48.302473068237305, 51.87310716084072, 56.4030373437064, 49.74513448987688, 50.01178898130144, 53.75086825234549, 51.614186014447895, 49.18261180605207, 44.77204820087978, 26.1009236403874, 8.11696115561894, 7.039278617927006, 37.56658213479178, 53.513493469783235, 54.97847945349557, 52.92982741764614, 46.944968768528526, 46.07505430494036, 50.22474431991577, 57.54489040374756, 55.61355870110648, 23.422389609473093, 1.2682022516216551, 5.4598149827548434, 50.0420275415693, 35.46934482029506, 58.62016582489014, 52.5305735043117, 11.48170188495091, 23.150280782154628, 48.339149134499685, 37.15795162745884, 39.050977911267964, 31.87597622190203, 43.34598255157471, 37.56944826671055, 41.96574027197701, 28.867272479193552, 31.492470400674, 57.12846401759556, 71.10315350123814, 10.996176532336644, 0.5836793514234679, 0.3424915006118161, 0.24829645508102008, 0.13013826683163643, 0.12233206070959568, 0.15617642392005238, 0.13101977881576332, 0.12374323712927954], [0.03835871436500123, 0.021306627230452638, 0.026874504085364084, 0.031652386366788826, 0.0159717134998313, 0.0669908124421324, 0.04854814921106611, 0.04110933926754764, 0.050032909360847304, 0.03361912011834128, 0.03582362950380359, 0.07177082023450307, 0.11140773511890854, 1.6015016926186425, 59.34831619262695, 54.726225103650776, 44.147630964006694, 22.328020538602555, 31.172019481658936, 29.93364552089146, 25.504563229424612, 30.340813432421, 27.90258632387434, 37.30632693426949, 35.68745224816458, 23.70835314478193, 6.607127155576434, 19.58772223336356, 9.143840636525836, 38.85893317631313, 24.09050406728472, 0.0649643676089389, 0.7513156075562749, 12.830827525683812, 51.32202468599592, 49.88918454306466, 59.028678212847026, 54.34301805496216, 40.67638042994908, 37.927148478371755, 47.17399181638445, 47.12563930238996, 26.465721436909266, 13.925182700157166, 10.711752023015704, 12.529593586921692, 32.832295009068076, 52.878330843789236, 52.731515407562256, 56.099574770246235, 56.74704613004412, 56.862799644470215, 58.40520245688302, 53.02770669119698, 50.260402475084575, 46.680304936000276, 44.61642592293875, 42.675769737788606, 36.412830284663606, 46.49658761705671, 31.216005052839005, 12.407115953309194, 13.327283263206482, 34.297479016440256, 26.753206627709524, 3.4375680557319095, 6.409769654273987, 2.905968112604959, 15.821932349886213, 17.52120464188712, 16.874011210032872, 15.266779967716761, 10.802617958613805, 10.464639340128217, 0.2709931528994015, 0.2792916361774717, 0.04193146247416735, 0.048923100877021036, 0.035190305273447714, 0.1065202270235334, 0.02084366787624146, 0.049087241890707185, 0.0072953345619940334, 0.03468119027093053, 0.05302555074117013, 0.05397887887167079, 0.023376762933496918, 0.07987227051385812, 0.956148339169366, 0.05202173960528203, 0.02147188613058201, 0.037344019527414014, 0.05281588342040777, 0.02960796035560114, 0.05692606858376946, 0.11063610509570156, 0.031786088299538405, 0.03323627030476928, 0.0695819001910942, 0.033311112717326195, 0.029155598022043705, 0.023947553376534154, 0.19292543269693851, 0.227451872878841, 0.25217639974185396, 3.6253730867590224, 1.3863805787903922, 5.517586648464203, 6.4153942210333685, 5.97626633303506, 5.492642615522657, 5.955013530594962, 7.689988272530692, 12.41477026258196, 28.336388417652675, 26.316706895828247, 23.14007908957345, 30.356307915278844, 40.40363236836025, 44.051665919167654, 47.02503286089216, 44.90009307861328, 49.65490518297468, 46.21714496612549, 43.78040477207729, 43.98982000350952, 52.08557265145438, 49.510365281786235, 49.5535865511213, 47.67918838773455, 45.84791421890259, 47.15446390424456, 36.64984376089913, 27.90376925468445, 17.888837303434098, 5.510146864822932, 10.379302433558873, 35.06475469044277, 48.0471510887146, 44.092493534088135, 45.283783027103965, 43.82907690320696, 45.81650141307286, 53.16501351765224, 50.1957425389971, 47.171646799360005, 13.561772806303841, 0.9263189626591546, 1.488582826086453, 36.58267552512032, 39.58631229400635, 19.340152706418717, 54.97596073150635, 19.51139279774257, 8.599291205406189, 33.767057010105674, 24.14134751047407, 28.980566331318446, 22.64650685446603, 30.085102353777202, 31.881312438419886, 23.98407503536769, 23.810618468693324, 19.108327797480992, 34.6672864641462, 45.95981495720999, 40.30379717690604, 0.9834266411406654, 0.21854721355651105, 0.0869692854051079, 0.04028564185968467, 0.02941727844466056, 0.030125360270696025, 0.014246877482427018, 0.048444224787609916, 0.05381330954177039, 0.037487529683858156, 0.03603770051683698, 0.07635021236326013, 0.049079123219209056, 0.027972344907798936, 0.04359633295929857, 0.06436709394412381, 0.10413727310619184, 0.0882638216550861, 0.03238913969003728, 0.08048766106367111, 0.09422017846788679, 0.04682078904339245, 2.7634043225220273, 65.4485079901559, 63.47857557024275, 38.40767894472395, 31.62945066179548, 28.690915039607457, 18.633805785860332, 39.23058884484427, 25.44380644389561, 23.60719953264509, 32.711667333330425, 33.72483280726841, 27.927054405212402, 17.099666118621826, 25.826902321406774, 10.694232140268598, 44.044266087668284, 37.30434669767107, 2.059866862637656, 0.5984188690781593, 9.401578852108546, 50.83381993430001, 57.527822153908865, 62.47215679713658, 58.63445826939174, 45.259200300489155, 46.06135245731899, 48.36939116886684, 50.228812490190776, 32.50581305367606, 15.239207778658185, 10.62970769405365, 12.55225774220058, 33.1635434286935, 51.29141092300415, 52.80011149815151, 53.39747244971139, 54.57974318095616, 55.25786304473877, 59.06855392456055, 53.4598707471575, 50.69409166063581, 47.115446295057026, 45.047992433820454, 42.355700969696045, 39.460570744105745, 51.27517645699637, 32.492736543927876, 17.800820997783116, 22.13169571331569, 43.839989049094065, 38.47076858792986, 8.492991583687918, 14.860433680670601, 8.815304619925362, 14.20051462309701, 26.537577969687327, 21.484554392950876, 16.420033284596034, 24.667049952915736, 16.621022088187082, 0.44676889798470903, 0.09609025490603276, 0.12130479940346309, 0.039295408209519725, 0.05646031875429409, 0.16342422286314623, 0.23640732733266695, 0.3478799100433077, 0.14433946194393293, 0.14333171530493669, 0.4025915999497686, 0.21778036041983537, 0.06429824299578156, 0.029810245215360607, 0.8477733231016568, 0.24289542489818164, 0.047782799029456716, 0.07886107691696712, 0.02883486808942897, 0.0591267001416002, 0.11688878493649618, 0.10030251209224973, 0.020948913746646473, 0.05399025451125843, 0.12002740294805594, 0.15518308936485223, 0.289895482893501, 0.11211679064269577, 0.32864034814494, 0.7103380635380745, 0.10301281165863786, 6.006188750267029, 11.97584821496691, 6.515956802027566, 7.283010567937579, 12.338475567953926, 6.354284380163465, 10.68047731263297, 13.534417748451233, 16.906549624034337, 42.86724124635969, 34.07510192053658, 27.310408728463308, 28.361219542367117, 41.165137563432964, 44.97488348824637, 47.94970955167498, 44.80514941896711, 50.545674664633616, 47.62256751741682, 46.9988694190979, 44.70982360839844, 53.73210464205061, 50.631589140210835, 50.69042648587908, 46.43579435348511, 49.52645036152431, 48.714768750326975, 38.74315881729126, 28.100135769162858, 16.515261820384435, 6.383684813976288, 15.412026848111834, 42.16220753533499, 53.061752864292686, 48.670314175742014, 47.9167229788644, 47.72350747244698, 50.73232412338257, 55.83456005368914, 55.49136420658657, 48.2062474659511, 7.178541362285614, 0.5886596898947443, 3.536974847316742, 46.32686397007534, 43.23682982581002, 20.925318207059586, 46.196595668792725, 26.90614516394479, 17.06367097582136, 32.29516799109322, 23.966841765812465, 33.81994322368077, 16.672975506101334, 30.813832896096365, 35.454124791281565, 23.518714223589214, 31.217127186911448, 14.885469777243477, 32.82168510981968, 55.51040227072579, 45.19670820236206, 1.5346696845122745, 0.3932902419141361, 0.09084609523415565, 0.028791458811610937, 0.041539978302483044, 0.02734067799922611, 0.04180425751422133, 0.030293277331760952, 0.08037611669195549, 0.09455715252884797, 0.14997052906879357, 0.17426261199372156, 0.12487135588058404, 0.07571898480611187, 0.20715769114238874, 0.22399521193334035, 0.16357972951872007, 0.22693301072078093, 0.15863939747214317, 0.13433227821120194, 0.17431225361568586, 0.2389765323272773, 3.649725002901895, 84.53748158046177, 68.66730267660958, 59.0861120223999, 32.57912349700928, 40.532761165073936, 40.71447740282331, 36.41225011008126, 42.38761404582432, 37.2535206249782, 50.176381383623394, 45.67408766065325, 33.35224608012608, 9.613479801586696, 30.983462742396764, 15.60706799370902, 50.71689564841134, 30.021192823137554, 1.4726129344531467, 2.2396838537284305, 18.408015387398855, 59.09425531114851, 62.470558711460654, 67.36364691598075, 63.16366236550467, 51.68269872665405, 48.98665176119123, 54.90141003472464, 56.543126923697336, 32.90577220916748, 18.467954022543772, 16.23005042757307, 19.86505436897278, 40.466312067849294, 55.51060029438564, 57.61880186625889, 56.62093979971749, 56.6682049206325, 55.88750185285296, 59.45649964468819, 53.564552307128906, 53.06516442980085, 49.19221421650478, 46.423409189496724, 46.06352724347796, 39.099462441035676, 53.70081690379551, 36.38427318845476, 21.424198865890503, 23.47506216594151, 43.816055979047505, 37.16123465129307, 7.581992421831403, 18.55216097831726, 7.706214921815055, 19.76858036858695, 31.186506475721085, 26.33735520499093, 18.095869302749634, 27.040745667048864, 20.321243558611187, 0.4654208485569273, 0.2950943910649845, 0.15148033733878816, 0.12088816533131258, 0.11192519270948001, 0.15905372452523026, 0.16114750717367443, 0.1756898018398455, 0.16406196435647352, 0.16950616293719836, 0.21365363257271902, 0.3155364527234009, 0.1931373934660639, 0.19939895533025265, 3.3484993151256015, 0.18321280101580278, 0.13540451281837054, 0.15007861969726427, 0.15939395555428096, 0.12883638883275644, 0.298908246415002, 0.253630771700825, 0.09864794516137668, 0.11776910269899027, 0.12187698084328856, 0.1629830122526203, 0.22414425893553666, 0.14718693414969103, 0.3403466242764677, 1.22579240160329, 2.1275922570909773, 8.926037192344666, 16.650039502552577, 10.118077959333148, 9.065975649016243, 16.6741167477199, 13.1383113690785, 11.924906628472463, 18.174555914742605, 16.851618903023855, 37.84123747689383, 32.6276010785784, 30.037382125854492, 33.288743019104004, 43.094881602696006, 46.56244611740112, 50.260308674403596, 48.343908650534495, 52.50683845792498, 48.72385004588536, 47.241809708731516, 47.80974503925869, 54.4619642666408, 52.804144927433555, 52.34840563365391, 49.48882239205496, 52.32783896582467, 51.451111793518066, 44.40425573076521, 35.38552175249372, 22.838843413761683, 7.690878510475159, 13.416558061327253, 40.73313679013933, 55.40873275484358, 51.13753611700875, 52.63920858928135, 51.508486543382915, 53.20684862136841, 60.37539196014404, 60.945026125226704, 53.208912236349924, 17.309942926679337, 1.8742644105638777, 2.201466373034886, 43.27586827959333, 49.578127588544575, 24.462185791560582, 63.143825258527485, 23.641480207443237, 12.88073991026197, 45.629080704280305, 30.70375258581979, 38.4203177179609, 31.698442799704416, 40.521741322108674, 45.797883714948384, 32.60794809886387, 36.78084509713309, 26.63384873526437, 49.26737635476248, 60.54096753256661, 65.00729737962995, 3.110168069601059, 0.4881585570318358, 0.1655494895364557, 0.08881193545780011, 0.20899596464421066, 0.2415089878652777, 0.1729243102350405, 0.26855618080922533, 0.18615115620195866], [0.03805145674518176, 0.04503741580992937, 0.036996395859335146, 0.03446246450766921, 0.10075537993439607, 0.039389809393989186, 0.05477462742211563, 0.005610556707584432, 0.06735389653061118, 0.07243818656674453, 0.051085731081132374, 0.08835545780935458, 0.005658155090973845, 0.09141744207590818, 23.502380745751516, 65.79354858398438, 40.44402224676949, 31.828964710235596, 29.798878261021205, 35.045077392033164, 18.71721543584551, 27.327351910727366, 20.33178571292332, 33.47003889083862, 38.22638307298933, 34.81981679371425, 11.139088818005153, 8.659815226282392, 18.181722981589182, 21.451444489615305, 54.0646766935076, 11.316733411380223, 2.096410695995603, 0.12838652011539253, 13.068994402885437, 52.23375688280378, 53.67321171079363, 39.264749663216726, 57.871122223990305, 40.662709849221365, 52.06210511071341, 53.420717648097444, 50.10321337836129, 25.753539766584122, 1.5255843720265796, 1.47148254939488, 5.262361075196948, 26.140646491731914, 53.67364944730486, 52.841060706547324, 54.53535114015852, 52.20389699935913, 46.67416967664446, 45.22235747746059, 46.97394970485142, 46.593754700251985, 48.75077778952462, 48.07434981209891, 44.71434341158186, 16.544261864253453, 12.083592193467275, 23.879061698913574, 39.89157445090157, 20.215250526155742, 6.054250308445521, 16.965011766978673, 6.807158844811576, 11.188153522355215, 25.185943160738262, 21.29722922188895, 17.30351758003235, 14.98554641859872, 15.940887246813093, 13.651256050382342, 0.40586371294089724, 0.06432189672653164, 0.03371975703963211, 0.05002897725041423, 0.12973495918725217, 0.025493357929268053, 0.16505421325564384, 0.05185584457857268, 0.047048634317304404, 0.04196211529363479, 0.045150527597538063, 0.06525993746306215, 0.4387136016573225, 1.8392569976193565, 0.943977375115667, 0.05649412676159825, 0.04285906734211104, 0.0336700645275414, 0.014478134091145225, 0.07383466591792447, 0.06693374086171389, 0.026328152777361016, 0.033396082265036445, 0.05545112005035792, 0.05160167893128736, 0.1182708657745804, 0.11038327616240297, 0.041799548481191905, 0.01086655427103064, 0.9526463385139192, 0.718133128115109, 0.7113610772149903, 4.71744338955198, 2.1407221811158315, 9.35655973638807, 9.162765792437963, 8.799982104982648, 6.10032902445112, 16.83085768563407, 12.274444443838936, 8.636982577187673, 27.15936357634408, 32.63210351126534, 24.139304740088328, 18.27654504776001, 32.12757396697998, 51.49362087249756, 45.1984417779105, 42.88638005937849, 45.622966289520264, 52.443456990378245, 52.01557649884905, 46.89401068006243, 48.8955191884722, 51.60355527060372, 46.83478076117379, 38.87458399363926, 35.56083175114223, 23.582547324044363, 10.698555656841823, 6.308142696108137, 10.453932166099548, 38.27184861046927, 53.91153492246355, 43.47438178743635, 47.829147883823936, 46.4155090876988, 45.717079639434814, 41.521198000226704, 46.19528940745762, 47.76970951897757, 17.867858954838344, 0.9608031979628971, 2.0708107096808295, 21.42506912776402, 55.75260257720947, 20.13429880142212, 22.10925129481724, 17.67479804583958, 8.67405208519527, 20.392045702253068, 32.54397256033761, 24.20840631212507, 24.097172600882395, 30.200640474046978, 31.94973134994507, 17.843809502465383, 27.90646689278739, 21.226114409310476, 34.01523971557617, 36.84166267939976, 59.3348297391619, 7.82292468207223, 0.42741865345409935, 0.16403193239654812, 0.12718365394643374, 0.04852460404591901, 0.04131003296268838, 0.03936400131455489, 0.08263614720531873, 0.05104044904666288, 0.05057181544335825, 0.039787810894527605, 0.04613330414784806, 0.11812983905630452, 0.010903273193564798, 0.03672581644994872, 0.04474528952102576, 0.0894166390810694, 0.07558256534061261, 0.0641076017969421, 0.08010959492198058, 0.17464648639517172, 0.08295132672148091, 0.11113694536366633, 0.08406364239220109, 30.432995183127268, 71.62688091823033, 44.35373885290963, 26.958301816667827, 36.87642451695034, 17.356158869607107, 26.104613133839198, 34.440907205854145, 20.701667853764125, 30.90299912861415, 31.89183895928519, 36.129659925188335, 17.44296792575291, 17.138133083071025, 14.096864002091543, 27.701387337275914, 59.7750050680978, 18.908501080104283, 5.0465530667986185, 0.5948575916034835, 10.293816140719823, 55.030538831438335, 58.92936066218785, 46.08231864656721, 61.30374772208077, 45.01047910962786, 56.39428608758109, 55.179205962589805, 53.13166216441563, 32.85427563531058, 2.5078741141727994, 1.6613678059407642, 4.211458197661808, 24.551407609667095, 50.89681230272566, 56.14893477303641, 55.72451795850481, 55.703228678022114, 48.19088847296578, 48.31603595188686, 45.00886017935616, 49.8402726990836, 46.75528294699532, 50.694734369005474, 43.11198459352766, 21.407980033329554, 18.34570915358407, 31.85415540422712, 47.33702087402344, 36.482736110687256, 10.009702563285828, 22.488186938422068, 13.61732712813786, 10.393932734216962, 28.598182644162858, 24.36468345778329, 19.81537996019636, 17.360503230776104, 28.697937931333268, 21.66353130340576, 0.438635135867766, 0.04908422580254929, 0.1766650602221489, 0.2666083239018917, 0.6897164615137237, 0.3650664421064513, 0.2109541759959289, 0.1602021043321916, 0.18903946264513902, 0.4668046800153596, 0.22057791958962167, 0.34977790819747107, 0.24683801191193716, 0.4777294195124081, 0.3656649099928992, 0.06403196549841336, 0.04448486099551831, 0.0689392461042319, 0.03620380928207721, 0.05750226695090532, 0.06632420606911182, 0.016048878198489547, 0.0709557503994022, 0.17708142288029194, 0.07229095803839819, 0.2674586639872619, 0.2046689468302897, 0.05476077512970992, 0.2536048245217119, 0.14976421371102333, 5.812848176274981, 7.466303178242274, 16.790660619735718, 8.633275713239398, 9.410370060375758, 10.77429449558258, 14.82391916002546, 4.265558174678257, 23.92301947729928, 17.19911915915353, 13.489203214645386, 37.41506624221802, 42.53618390219552, 32.02812440054757, 18.01644618170602, 31.512477738516672, 51.45605891091483, 49.32726287841797, 43.030482224055696, 44.67973096030099, 52.307762145996094, 49.45707259859358, 47.045161792210166, 49.87327664239066, 52.10412434169224, 48.23957102639334, 39.40769495282854, 33.75727047239031, 22.337612526757376, 10.813137531280518, 7.4606117350714545, 14.906319584165301, 41.463701656886506, 55.82888337544033, 46.58606651851109, 48.54785564967564, 50.4253249168396, 49.51071616581508, 45.27862398965018, 49.880940505436485, 50.391226632254465, 16.717282431466238, 0.32948165014386177, 4.585121895585742, 32.201631341661724, 54.19236373901367, 23.578449623925344, 23.54700902530125, 23.434978008270264, 15.976409912109375, 23.20748356410435, 30.40283305304391, 25.689916849136353, 27.41170825277056, 19.268945830208914, 41.06747715813773, 16.466629641396658, 28.911278894969396, 25.333286660058157, 28.8412184715271, 39.55778993879046, 67.64771011897496, 9.022908108575002, 0.44170645677617615, 0.04568926065361925, 0.03061817686206528, 0.0521795939920204, 0.03182699378313763, 0.06754127397601094, 0.06492865631090743, 0.03245532060308116, 0.029188822489231825, 0.2480010480753013, 0.11941676214337349, 0.20766568316945008, 0.09626756967710597, 0.3246230408549309, 0.17370664754084178, 0.20591868619833673, 0.1620251786495958, 0.38593207246490885, 0.17204648948141507, 0.3085881455668381, 0.16408153330641134, 0.22275392711162567, 0.13788877879934652, 42.09784984588623, 85.05086312975202, 54.793838024139404, 45.932359150477815, 43.235342911311555, 46.96533741269793, 28.831881829670497, 38.363092354365754, 28.91986165727888, 47.697166851588655, 47.62570810317993, 47.81404250008719, 15.006562982286725, 12.564326763153076, 27.625464371272496, 31.571158749716624, 65.27578966958183, 16.940338713782175, 4.191751369408198, 1.442593242440905, 17.49702491079058, 61.86329310280936, 61.94989545004708, 50.697531018938335, 66.58756787436349, 50.357962131500244, 58.377374921526226, 61.47791821616036, 55.47198568071638, 30.727762086050852, 2.625057654721396, 3.1146570401532307, 8.337887815066747, 31.87605265208653, 56.39893790653774, 58.43455164773123, 58.272387640816824, 57.43328496388027, 51.30611678532192, 50.03845616749355, 50.24200711931501, 51.02585424695696, 53.36489234651838, 52.17478404726301, 51.160010065351216, 22.952093839645386, 20.27748727798462, 37.14344031470162, 48.86398131506783, 28.26232235772269, 9.138197830745153, 32.71563128062657, 12.148214782987322, 15.323501586914062, 34.75323568071638, 29.103502546037944, 26.073556423187256, 18.888971430914744, 34.16507414409092, 23.76579737663269, 0.5502680156912122, 0.138773914160473, 0.21546891730810913, 0.1228569211172206, 0.24839934813124792, 0.25504994126302855, 0.24524741726262228, 0.1448000515145915, 0.14730816121612275, 0.23446723286594662, 0.5609411001205444, 0.4760522980775152, 1.3827484079769679, 5.067673419203077, 3.678966062409537, 0.0698102204395192, 0.1562056823500565, 0.09848043522132294, 0.09523731603154115, 0.180470895288246, 0.1361454187759331, 0.12416662941021578, 0.25478170279945644, 0.1323178841599396, 0.15326350022639545, 0.28580424242785996, 0.3236512430012226, 0.1478511927915471, 0.7582607120275497, 3.463561918054308, 4.358865099293845, 8.924719640186854, 20.18672295979091, 11.554907236780439, 11.55584350654057, 13.89219960144588, 19.78304304395403, 10.207202502659388, 24.433439356940134, 21.68279865809849, 12.280103751591273, 38.578622000558035, 41.93283360345023, 32.54500436782837, 23.092443977083477, 37.43075180053711, 56.886225496019634, 49.61886487688337, 46.36211912972586, 46.66619661876133, 54.87139729091099, 52.383765016283306, 48.82635334559849, 52.34323617390224, 54.9942101751055, 48.02000100272042, 40.64990431921822, 39.4844308580671, 27.811009066445486, 14.98450939995902, 8.77754637173244, 12.631604433059692, 41.98688016619001, 59.928678376334055, 48.91205242701939, 54.91600472586495, 53.429097175598145, 52.863805634634836, 49.891001496996196, 53.32011815479824, 55.131468364170615, 22.852425404957362, 2.132184147834778, 3.812053595270429, 26.717331341334752, 64.5460273197719, 24.3043783051627, 28.906059060777935, 25.01723221370152, 11.886070540973119, 29.18375771386283, 44.5424519266401, 33.015915053231375, 35.069253649030415, 40.81977040427071, 45.46689932686942, 24.052634647914342, 41.40828629902431, 29.194176537649973, 47.58808708190918, 50.0835326058524, 77.91316631862095, 20.847630398614065, 0.7159344032406807, 0.5440123570816857, 0.2485101121876921, 0.19087230786681175, 0.09584172109940223, 0.1911425819354398, 0.2508957598890577, 0.21643616897719248, 0.1111186859863145], [0.07115880200373274, 0.09742582216858864, 0.03426977752574852, 0.03708510074232306, 0.06656181546194212, 0.03813057392835617, 0.0745581810229591, 0.02021059300750494, 0.0858077352334346, 0.05610716841848833, 0.05443354143894144, 0.10463950437094484, 0.14172539221388952, 0.015408916199313743, 5.003858123506818, 66.79347773960659, 44.933677196502686, 36.89024100984846, 23.858323063169205, 30.342564378465923, 28.789794853755406, 25.570051738194056, 24.92757092203413, 26.112450701849802, 39.90221561704363, 32.1998803956168, 29.309801510402135, 9.38963576725551, 19.78952397618975, 23.550550869532994, 45.14890807015555, 90.99606840951103, 23.104198592049734, 0.7086668589285442, 2.0617048782961707, 26.576242957796367, 50.938751629420686, 47.632475648607524, 56.2039019720895, 59.39318765912737, 41.381233487810405, 47.71223749433245, 45.14296736036028, 53.72624731063843, 27.358240127563477, 2.6207682277475084, 0.6504727101751736, 1.071682333946228, 8.763440660067968, 22.014245101383754, 37.16047034944807, 41.867121015276226, 50.47241633278983, 52.66988141196114, 50.182273456028526, 43.012055601392476, 32.046043804713655, 14.49493064199175, 3.3616125200475966, 12.421585576874868, 46.431760924203054, 36.566215242658345, 18.49883529118129, 4.300082470689501, 14.638815675462995, 10.424958177975245, 11.334276744297572, 34.51452684402466, 22.32252103941781, 21.937135730470928, 18.71990438870021, 10.56318303516933, 16.964136293956212, 10.726923414639064, 0.7965532115527562, 0.261735275387764, 0.1628978561077799, 0.05444978895996298, 0.12018627513732229, 0.9207695232970374, 1.3763131818601062, 1.460201389023236, 0.8902995554464204, 0.10318737836288554, 0.25728557844247135, 0.1974046187741416, 0.13637313512819155, 0.0968287249228784, 0.8568147208009447, 0.5658586333904947, 0.05572250013106635, 0.06063570095492261, 0.031402000159557374, 0.06274782440492085, 0.0912049249080675, 0.09488320896135909, 0.019194032198616436, 0.025133144043918167, 0.11966065477047648, 0.42825327866843765, 0.576417398239885, 0.41967914732439177, 0.22430531600756304, 0.07913751886891467, 7.77053005354745, 5.02884167432785, 8.624818018504552, 3.064884270940508, 6.222943884985788, 12.199032170431954, 8.38173963342394, 10.045053260666982, 13.4194233247212, 24.129950727735245, 11.150565505027771, 8.591704641069684, 20.735314505440847, 26.49544061933245, 30.38406596864973, 14.679420948028564, 24.94990243230547, 46.889049666268484, 51.1767760685512, 48.46464054925101, 41.14976814814976, 46.58153976712908, 55.599443435668945, 52.2033828326634, 49.096527099609375, 44.54640545163836, 38.81067098890032, 21.618421861103602, 5.886757901736668, 3.4852850266865323, 10.729986701692853, 34.5373204095023, 40.220547335488455, 42.20114524023873, 45.967499664851594, 44.23880522591727, 41.14628710065569, 44.3695946420942, 45.008735111781526, 47.72030087879726, 45.76768684387207, 11.601928302219935, 0.15544021342481884, 10.881757072040013, 56.01339973722185, 44.10392679486956, 20.966639144080027, 10.361515045166016, 8.182364548955645, 11.904607466288976, 28.14178327151707, 30.814871651785715, 32.54592500414167, 28.94819814818246, 32.48141098022461, 21.99790641239711, 29.12304261752537, 32.23917245864868, 24.883571454456874, 31.837948731013707, 46.06145668029785, 47.45655420848301, 1.252212058220591, 0.06178422325423785, 0.040495729872158596, 0.1039348728954792, 0.04018777336126991, 0.03048369461404426, 0.06422448623925447, 0.06488778814673424, 0.054477161062615256, 0.04470355622470379, 0.10788555483200721, 0.037545072846114635, 0.04853596272213118, 0.0063961369866904405, 0.0459753445881818, 0.025355818880988017, 0.040316861255892684, 0.06588491571268865, 0.0871252670351948, 0.05958785968167441, 0.07377489376813173, 0.0736798717241202, 0.15266244033617632, 0.06409019737371377, 8.525566475731985, 74.12493896484375, 55.71973064967564, 25.414335659572057, 34.07383040019444, 29.65978227342878, 20.402534008026123, 33.565628732953755, 26.290084872926982, 28.812383447374614, 28.540934698922293, 33.40969031197684, 29.07446081297738, 18.97981912749154, 28.68978422028678, 32.453100545065745, 54.06489208766392, 90.3476972579956, 31.008587428501674, 1.15956141267504, 1.717813559940883, 24.69178032875061, 52.38168403080532, 51.65766784123012, 62.11568641662598, 58.8809039252145, 48.249753611428396, 52.02317782810756, 50.18737690789359, 56.55838516780308, 32.31800324576241, 4.858377609934125, 1.6309315477098738, 2.2082473805972507, 7.452188781329563, 19.687696388789586, 35.198677744184224, 41.82641151973179, 49.97530746459961, 51.43458897726876, 48.967349665505544, 41.864848954336985, 36.4850880759103, 13.681855916976929, 3.529265603848866, 18.467120238712855, 46.602356570107595, 48.17493888310024, 31.88758318764823, 9.128043907029287, 16.696908576147898, 19.649550778525217, 8.062985811914716, 35.05751119341169, 24.377871138708933, 27.05216155733381, 23.370401450565883, 20.593600784029277, 24.094334261757986, 14.06262675353459, 2.288685372897557, 0.557921185025147, 0.49321228585072924, 0.24085610147033418, 0.15236885180430754, 0.4549878298171929, 0.12530279558684143, 0.6571930295654705, 0.5501909341130937, 0.45989865916115896, 0.5167477343763623, 1.1328643709421158, 0.05723117185490472, 0.10661239922046661, 0.3248923106917313, 0.26531975876007763, 0.20166075682001455, 0.05141749060047524, 0.049335436429828405, 0.11185256910643407, 0.07228597080601112, 0.09447441196867398, 0.024471811584330032, 0.043431601620146205, 0.11401707545987197, 0.06540107953229121, 0.44635491019913126, 0.0957977520301938, 0.17318766324647836, 0.14315775249685558, 5.360756686755589, 6.168248534202576, 15.858307906559535, 12.59819141456059, 9.420177442686898, 11.818908384868077, 11.73921080998012, 12.868675231933594, 9.542682000568934, 34.00432756968907, 15.564404317310878, 13.783071194376264, 22.3960086618151, 33.89366708483015, 37.817558016095845, 17.30885205950056, 25.29337273325239, 42.50597660882132, 52.647984164101736, 51.53249256951468, 42.43732145854405, 46.54111862182617, 55.779162066323416, 50.21682684762137, 49.46434041431972, 44.23715155465262, 36.644233090536936, 21.187187126704625, 4.304293513298035, 3.57692004101617, 14.130793792860848, 39.32125241415841, 43.08335106713431, 45.83747455051967, 49.67340128762381, 47.78940418788365, 44.56630161830357, 47.1515074457441, 51.862000465393066, 51.89338895252773, 51.580605370657786, 14.679787465504237, 0.014784375604774271, 13.062311972890582, 63.95433957236153, 52.49931008475167, 27.920639480863297, 14.266218526022774, 14.31286438873836, 18.325033051627024, 27.883933884756907, 27.987449884414673, 34.142575877053396, 23.903171948024205, 33.71826328550066, 27.656241416931152, 21.6079318182809, 37.732612814222065, 20.009868724005564, 32.95715413774763, 51.61115312576294, 53.88301951544625, 1.3199624227625983, 0.11174892288233552, 0.09914733336440154, 0.05570383702537843, 0.08656147907355002, 0.01414387671476496, 0.06432823424360581, 0.044797458685934544, 0.021519958640315702, 0.05241743747943214, 0.3035824027444635, 0.2759844564965793, 0.15208592984293187, 0.10855538424636636, 0.10348826114620481, 0.11718468048742839, 0.24072723409959249, 0.1528023271156209, 0.1603522641318185, 0.21202137587325914, 0.19913609086402825, 0.17827799224427768, 0.2996226352240358, 0.13073024792330606, 12.137897576604571, 91.42785726274762, 57.98839044570923, 52.55627836499895, 37.41407264981951, 45.60471337182181, 41.89089775085449, 36.096895694732666, 34.99814925874983, 38.327899728502544, 52.79442092350551, 43.109236580984934, 41.00875793184553, 12.973406297819954, 31.610176358904155, 30.526750700814382, 59.84600176130022, 102.7263924734933, 30.24463299342564, 1.9215914138725825, 3.270735510757991, 31.644441400255474, 60.2606007712228, 57.31050334657942, 68.08802441188267, 66.36122335706438, 51.52867800848824, 57.898921966552734, 56.90710135868618, 59.676583835056846, 31.266747747148784, 3.6836452398981367, 1.2784463933535983, 1.930339195898601, 11.457681962421962, 26.587115151541575, 44.55202307019915, 47.59981216703142, 57.317944867270334, 58.80047157832554, 55.92616857801165, 50.536461353302, 39.81991767883301, 19.075546196528844, 4.6886821900095255, 18.164689472743444, 58.563920157296316, 44.53923143659319, 25.486497913088115, 7.060858419963291, 27.991976635796682, 16.2017434665135, 15.452729395457677, 45.2029025214059, 27.75649697440011, 30.95628833770752, 25.36309790611267, 17.906426668167114, 25.283252682004655, 20.23284683908735, 1.2913899102381297, 0.5044169074722699, 0.23201218460287365, 0.17054603142397745, 0.16434974462858268, 1.8353282255785806, 2.1341635159083774, 2.195065127951758, 1.8600790117468153, 2.799204481499536, 2.6984108729021887, 1.2035934499331882, 0.6033514929669244, 0.18162733609122889, 1.2802896201610565, 0.8040003776550293, 0.3003706250871931, 0.15568635878818377, 0.14667098969221115, 0.1758025200771434, 0.26221950511847225, 0.11431869784636156, 0.08996969261871916, 0.13308937847614288, 0.22438995646578924, 1.1607612797192164, 4.312512797968728, 1.6719064861536026, 1.0089932978153229, 0.1914756204932928, 12.61863648891449, 9.854338237217494, 18.56434464454651, 16.532828603472026, 10.076730966567993, 14.710434232439313, 14.381450925554548, 17.763920852116176, 17.069623844964163, 30.296987669808523, 22.00265724318368, 14.599811962672643, 28.219158411026, 33.26809644699097, 38.450389521462576, 18.143928255353654, 29.40994589669364, 49.64421190534319, 52.835446562085835, 53.10740600313459, 42.44498184749058, 50.58762788772583, 59.906965255737305, 55.853115218026296, 50.262049198150635, 48.0646779196603, 43.35626588548933, 24.29974733080183, 8.2624477488654, 4.276800359998431, 12.066509178706578, 37.41545534133911, 46.699513231004985, 49.24648312159947, 53.77817814690726, 51.68719073704311, 48.85049833570208, 50.93153245108468, 54.17456940242222, 54.85181031908308, 54.81270585741316, 14.223137089184352, 0.1550405291574342, 14.952535527093069, 64.7948978969029, 52.071526868002756, 29.258725302559988, 14.6741281577519, 10.331576994487218, 17.231850385665894, 38.09453753062657, 40.63848842893328, 43.0543075970241, 41.460835524967735, 44.76530497414725, 31.518776280539377, 41.383265835898264, 47.987024852207725, 32.43249566214425, 48.305137702396934, 56.539670194898335, 72.06858485085624, 4.1895739776747565, 0.4838343347821917, 0.24939068779349327, 0.1472240907273122, 0.17200110905936786, 0.25066185529742924, 0.26456617776836666, 0.15551842137106828, 0.12712095731071063, 0.13699684451733316], [0.01086870183436466, 0.008621647455064314, 0.002242277704811256, 0.0618489622803671, 0.07993622243936573, 0.09994530411703245, 0.03753789733829243, 0.0452368067178343, 0.030807878289903914, 0.011118697035791618, 0.035672930268836875, 0.10532653464802674, 0.03705201537481376, 0.036410402839205096, 0.16161480067031725, 30.612494945526123, 62.38803495679583, 40.62050649097988, 24.891957930156163, 28.765571696417673, 33.692103317805696, 27.562393835612706, 31.34235804421561, 23.873779330934795, 36.696421010153635, 32.23584427152361, 33.78597348076956, 16.429897989545548, 9.141114337103707, 13.274930323873248, 19.879716805049352, 39.08328703471592, 62.95784282684326, 7.83803527695792, 0.7653358780911991, 10.682229995727539, 49.837903363364084, 56.51819331305367, 51.409571988242014, 53.423298903873985, 46.54476990018572, 40.981639112745015, 53.10250057492937, 45.96113511494228, 57.94302913120815, 17.870978696005686, 3.776641232626779, 0.5566713778035981, 0.35905272194317406, 0.6908081429345267, 10.172258274895803, 17.772166626793997, 12.675511837005615, 9.14881728376661, 4.2507394041333875, 1.8201349037034171, 0.7840509052787508, 0.1254921204277447, 17.140785557883127, 58.723263195582796, 31.101995536259242, 15.61568375996181, 8.245253562927246, 16.12937797818865, 11.58067376273019, 9.356518047196523, 42.067823205675396, 27.503572123391287, 24.42814482961382, 24.71018089566912, 17.646742956978933, 3.239234983921051, 21.69242365019662, 8.311798197882515, 3.6194816657475064, 1.1242897510528564, 2.9501842771257674, 2.3626313592706407, 4.04279545375279, 1.5154405449117934, 0.6586111134716442, 0.8623582433376993, 0.26346255413123537, 0.6480112565415246, 0.41664302881274906, 0.2568176606936114, 0.06625519905771528, 0.1553535780736378, 0.20755168928631715, 1.492557304246085, 0.13330774461584433, 0.17216663089181694, 0.06973252817988396, 0.008988522857959782, 0.03351686489103096, 0.048335961132709465, 0.15985512866505555, 0.5801876645003046, 0.7605994322470256, 0.2569802648254803, 0.05290997926411884, 0.07159272514815841, 0.1829753816127777, 0.09427383023181132, 5.13677933386394, 8.39782818726131, 10.32172966003418, 6.858801330838885, 2.4210342253957475, 14.212904129709516, 10.964766332081386, 10.379230345998492, 15.654638835362025, 12.838331580162048, 17.497089181627544, 15.98375415802002, 21.070789166859218, 17.336992263793945, 21.470821278435842, 34.510726179395405, 22.00434044429234, 21.558293887547084, 35.773901735033306, 45.95303698948452, 57.51522854396275, 51.888118743896484, 44.474766050066265, 43.59884139469692, 45.493653365543906, 22.8195777961186, 11.160048059054784, 8.123337864875793, 0.08571844002498047, 4.669318863323756, 24.38990020751953, 42.73208141326904, 45.1733900478908, 48.21376889092581, 46.85926273890904, 46.86668688910348, 45.81752974646432, 48.47293669836861, 49.557717255183626, 46.552489348820274, 37.32117870875767, 6.554430280412946, 1.3762100445372718, 21.269603184291295, 25.53343299457005, 39.55828673498971, 14.431067143167768, 13.6588009255273, 14.33530707018716, 16.820383276258195, 28.15561887196132, 28.9930522441864, 25.428582940782817, 27.39941167831421, 26.84208103588649, 21.56429018293108, 31.27899742126465, 27.806650808879308, 31.305789675031388, 29.25818681716919, 61.285279410226, 30.91988672528948, 0.385632512824876, 0.08338867646775075, 0.09510162259851183, 0.04017566151118704, 0.08409933333418199, 0.035123676527291536, 0.08691220025398902, 0.07263304825339999, 0.07778120200548853, 0.03147335829479354, 0.08421325257846288, 0.04557641688734293, 0.025982108399538056, 0.03749825732250299, 0.06621039539043393, 0.05204938990729196, 0.02128188275466008, 0.12101524136960506, 0.0028207792742510457, 0.006225545649483267, 0.10178186771060739, 0.04483845577176128, 0.05951488324041877, 0.03631950968078204, 0.22872769513300487, 35.79096303667341, 71.36581625257219, 40.189051151275635, 23.8032968044281, 40.05128921781267, 20.720044101987565, 28.235618693487986, 31.360485894339426, 29.09086898394993, 31.03048815046038, 31.776022911071777, 34.9642003604344, 24.42854608808245, 18.73228086744036, 19.186529772622244, 30.480611188071116, 44.82046324866158, 65.13912555149624, 11.743619441986084, 0.819352639572961, 12.56988445350102, 56.74282857349941, 58.8146459034511, 54.99387666157314, 57.80220651626587, 49.643041133880615, 45.52238416671753, 55.69152096339634, 50.21416916166033, 61.48241370064871, 23.221694367272512, 7.080176583358219, 1.584725049989564, 0.034012728104633946, 2.1074235907622745, 18.262730291911534, 25.10217567852565, 17.629450627735682, 16.193706137793406, 10.163394110543386, 7.042099586554936, 1.311748023544039, 0.6534778603485653, 22.95490438597543, 56.09169898714338, 43.940018790108816, 24.46906450816563, 14.850803477423531, 10.49460518360138, 18.042349066053117, 11.966683541025434, 33.69884654453823, 31.035271985190256, 27.656585352761404, 30.091519015175955, 29.155596664973668, 10.008494445255824, 25.289492164339336, 9.555848836898804, 6.189158269337245, 0.22465694642492703, 0.11207775452307292, 0.5875712111592293, 0.548926361969539, 0.7098775825330189, 0.15606409923306533, 0.06991625510688339, 0.13536836047257694, 0.3947145954838821, 0.8662008142897061, 0.44571467169693535, 0.2470552245421069, 0.1047216613910028, 0.11245119984128646, 0.212782922866089, 0.12398859539202281, 0.08063007199338504, 0.05065245254497443, 0.06837513244577817, 0.08758804827396359, 0.10940326124961887, 0.10211905211742435, 0.1667956190982035, 0.43576368423444883, 0.13146431424788066, 0.042224158732486625, 0.039362640851842504, 0.1362243052572012, 0.04102304318387594, 6.536613362176078, 12.716502734592982, 16.459299291883195, 12.735853467668806, 10.808583855628967, 14.086927209581647, 14.387878009251185, 15.293964794703893, 13.814179147992816, 10.648304547582354, 28.011183193751744, 25.37746330669948, 24.1572710445949, 17.335263899394445, 33.59116336277553, 44.28225231170654, 27.041914701461792, 23.107339177812847, 35.2753198487418, 42.31981004987444, 59.339005606515066, 54.087157590048655, 46.78034162521362, 43.405500820704866, 45.5552213532584, 22.02089105333601, 9.481555223464966, 8.18249135357993, 0.24812112163220132, 7.701427612985883, 29.432020323617117, 44.668933459690635, 47.20896904809134, 51.06215858459473, 48.816101278577534, 52.25478907993862, 51.10557092939104, 51.93369197845459, 49.789040156773154, 51.2212028503418, 40.09649419784546, 7.204757349831717, 3.293318893228258, 28.278866018567765, 26.951096534729004, 48.33833966936384, 24.23649787902832, 15.22610000201634, 19.011520283562795, 20.995203188487462, 29.290548052106583, 23.21228650638035, 23.337479148592266, 21.473409482410975, 37.20838165283203, 19.449708427701676, 30.190530845097133, 31.973303113664898, 26.27675822802952, 34.39414235523769, 67.41265950884137, 31.149656704493932, 0.3074171026902539, 0.08034673612564802, 0.05179835569911769, 0.061056338383683136, 0.011712074213262116, 0.017382503154554536, 0.06696439707385642, 0.02660880164642419, 0.07881415622042758, 0.047412593715957234, 0.14787709925855907, 0.084122620656022, 0.045742956522319994, 0.12546716390975884, 0.178011843668563, 0.14989540167152882, 0.1523454694875649, 0.19768683505909784, 0.10892639362386294, 0.14900315526340688, 0.1552583524691207, 0.23758637692247117, 0.14356576917426928, 0.08203027650181736, 0.3253330870398453, 53.60537297385079, 80.2757761819022, 55.327831404549734, 35.71030487333025, 40.49512277330671, 51.86893129348755, 39.37173107692173, 43.79550668171474, 34.516065870012554, 52.03845344270979, 43.060383796691895, 48.05419308798653, 23.63982653617859, 13.575889808791024, 20.82695082255772, 28.88527352469308, 49.74885525022234, 71.89760357992989, 11.726261104856219, 1.5411581077745982, 13.390215703419276, 57.79315301350185, 66.42988545554024, 59.73659542628697, 61.901751382010325, 55.91556215286255, 51.861646107264924, 59.73280865805489, 51.727274894714355, 58.8494633265904, 21.397743599755422, 6.603314765862056, 1.6534514193023955, 0.6105775109359196, 2.865372828074864, 15.770183903830391, 26.66413245882307, 16.711736031941005, 11.810299566813878, 6.260388595717294, 3.591035089322499, 2.473649242094585, 0.9740023868424552, 18.78160091808864, 70.13651316506522, 40.1707113810948, 23.33354820523943, 12.808443035398211, 26.375643253326416, 18.39205711228507, 14.941274234226771, 56.07789986474173, 31.396991729736328, 33.73970195225307, 32.55175106866019, 25.174369198935374, 6.299909949302673, 29.49863965170724, 11.540650401796613, 5.432272757802691, 3.1319419869354794, 5.432299247809818, 6.36706645999636, 5.063522304807391, 2.9044801124504636, 1.2715389068637575, 1.20292001749788, 0.7365785869104522, 3.2661247295992712, 1.7386855142457145, 0.4794581096087183, 0.27636709596429554, 0.2572367239211287, 0.37527321012956755, 2.3399533075945715, 0.2131264108632292, 0.23258785371269497, 0.1482982523739338, 0.1460045597382954, 0.1694298277476004, 0.1567054098205907, 0.27638579638940947, 0.8793665649635451, 2.153732465846198, 1.019925745470183, 0.22795913208808216, 0.23881194687315396, 0.3695443661085197, 0.131606521617089, 7.174633434840611, 18.388584750039236, 22.997166803904943, 15.707148109163557, 10.04326844215393, 15.615186963762556, 18.719709839139664, 17.06302653040205, 23.623176915305002, 16.031863485063823, 22.25959815297808, 26.465481724057877, 27.268785544804164, 23.228717258998326, 29.560318810599192, 41.83329371043614, 29.85863276890346, 25.661337171282085, 40.82102108001709, 48.196485246930806, 59.23161424909319, 51.387963090624126, 46.92315142495291, 44.69787965502058, 49.33980437687465, 25.620681524276733, 13.98706683090755, 11.964070149830409, 0.4088183801089014, 6.785054453781672, 28.802525690623693, 46.280512537275044, 47.7148118019104, 57.3468667439052, 52.7042749949864, 55.12508296966553, 53.57594040461949, 57.83519308907645, 55.13929203578404, 55.57239062445504, 44.88242033549717, 9.69859870842525, 2.1746836730412076, 25.305106503622874, 32.34994758878435, 51.37499080385481, 18.94773060934884, 18.866949115480693, 17.839998415538243, 23.476203407560075, 38.08233649390084, 38.14884465081351, 37.29806205204555, 37.944598879132954, 39.12153686795916, 31.010230677468435, 46.418785163334434, 38.196057660239084, 43.961895193372456, 43.01958050046648, 74.31133134024483, 48.27892214911324, 0.6705241256526538, 0.17432988195547036, 0.22703244324241365, 0.1527397254748004, 0.25649959061826977, 0.11500540242663451, 0.1978506605540003, 0.18656749171870096, 0.15715118018644197, 0.22593715201531137], [0.02709248854911753, 0.03138879247541938, 0.03551923869443791, 0.030823922250419855, 0.041168395562895706, 0.03776064681421433, 0.06000614259392023, 0.01867180111418877, 0.07102783117443323, 0.023478984234056303, 0.045058056845196655, 0.030405910752181495, 0.009261272731237113, 0.18217523954808712, 0.1878338416240045, 2.883713032518114, 62.01199150085449, 49.87312725612095, 36.91205140522548, 22.125529187066213, 32.575812680380686, 27.303033215659006, 33.803538526807515, 27.972931623458862, 25.166951996939524, 33.75313976832798, 34.78157390866961, 31.547670364379883, 16.289747612816946, 18.79049113818577, 31.255887712751115, 35.403128487723215, 58.31982299259731, 33.844723973955425, 2.815347535269601, 3.5104920055185045, 31.960094588143484, 55.438787187848774, 53.302191802433555, 59.38175092424665, 51.53590760912214, 50.53365775517055, 50.943973200661794, 47.32955503463745, 45.71401200975691, 38.89380965914045, 35.74055732999529, 11.531997288976397, 3.143346586397716, 1.2506862772362572, 4.240199855395725, 3.894065788814, 4.917515899453845, 0.17702013759740762, 0.34384732214467867, 1.3854145620550429, 4.812121280602046, 30.35379614148821, 52.07564714976719, 27.246421030589513, 12.31573758806501, 13.988344430923462, 15.164042166301183, 14.96415638923645, 7.525758045060294, 30.82965394428798, 35.45643506731306, 27.802758080618723, 29.801539421081543, 25.527026755469187, 3.914249437195914, 12.794193148612976, 24.284937245505198, 14.306881989751544, 3.8375556554113115, 0.3029883860477379, 0.28311466532094137, 0.09585437577750001, 0.09481984057596751, 0.01942729896732739, 0.09453083894082479, 0.1008526547146695, 0.06530092097818851, 0.060516434854694774, 0.16318745485373906, 0.7051268603120531, 0.1428683708821024, 0.0453875670209527, 0.24353845896465437, 0.44996050958122524, 0.02807670529000461, 0.05465321715122887, 0.07426315399685077, 0.023751305782103112, 0.0818348109189953, 0.2806708535977772, 0.4768102488347462, 0.1968112534710339, 0.06438129568206412, 0.04205712715962103, 0.031618527469358275, 0.051273692066648176, 0.19682041369378567, 0.1663003292466913, 7.904847417558942, 6.198471895286015, 10.199403149741036, 11.114532147135053, 3.811808237007686, 11.502562114170619, 14.58638630594526, 17.30861929484776, 12.412647587912423, 20.140324626650127, 9.026007005146571, 11.622903176716395, 10.366639341626849, 6.697159741606031, 8.057290026119777, 9.871072104998998, 25.466591324125016, 30.107444286346436, 29.058070012501307, 26.607035636901855, 27.598943097250803, 34.88971567153931, 44.05721058164324, 31.21034574508667, 14.712113959448677, 4.374190654073443, 2.9786330248628343, 2.567919795002256, 1.0439196122544152, 20.52781002862113, 47.430856295994346, 43.03158003943307, 45.8059401512146, 44.38484246390206, 45.5308644430978, 44.3021172114781, 48.136286054338726, 45.347456318991526, 45.83220781598772, 46.355560030256, 31.870622634887695, 2.4709878649030412, 10.521268027169363, 42.32078627177647, 27.67477399962289, 14.891789163861956, 5.96225311926433, 26.256196771349224, 15.91753261429923, 26.453900814056396, 28.636145864214214, 33.89162084034511, 28.876155751092092, 32.797418526240754, 25.32081811768668, 27.524072783333914, 41.12561273574829, 25.191890818732126, 24.597309146608623, 44.376271860940115, 51.14721148354666, 4.147094862801688, 0.19849969287003788, 0.01821382051067693, 0.13125928810664586, 0.03269611232514892, 0.01341891463380307, 0.0205343475099653, 0.0636202304490975, 0.028348295716568828, 0.07689876042838607, 0.044942278414964676, 0.032996113012943945, 0.00852972801242556, 0.014155678135076804, 0.053097604374800406, 0.08263620148812022, 0.07084070478699037, 0.09985584606017385, 0.032379976074610434, 0.042502656645540676, 0.01906054400439773, 0.07932913715818099, 0.11616074400288717, 0.05160340919558491, 0.15095829963684082, 0.2964474441749709, 6.587458542415074, 69.48120771135602, 55.19269241605486, 25.93565378870283, 31.79493590763637, 28.549857922962733, 25.297885588237218, 32.02906240735735, 31.823631967817033, 30.411396707807267, 28.226956026894705, 36.09242800303868, 32.49566173553467, 27.051051582608903, 23.480962923594884, 30.1667297908238, 43.17099217006138, 63.71022851126534, 42.21144594464983, 5.746008242879595, 3.6330002546310425, 34.164535658700125, 59.511202812194824, 58.64505427224295, 62.05181162697928, 53.63148430415562, 53.34655605043684, 55.06166328702654, 49.586263929094585, 52.846834659576416, 44.865570953914094, 33.711860520499094, 12.311155251094274, 7.40365821974618, 5.453793934413365, 9.904342685426984, 9.596802387918745, 13.367288385118757, 1.1185518418039595, 1.0601590722799301, 2.662567504814693, 5.857327938079834, 39.72187859671456, 49.87099068505423, 42.58327531814575, 22.988893236432755, 21.721896171569824, 11.694877828870501, 13.553705079214913, 11.274898307664053, 21.112764971596853, 36.086991037641255, 31.501360620771134, 32.41705676487514, 32.897715772901265, 14.130817243031093, 16.360733883721487, 24.98006977353777, 12.656165446553912, 3.12513535789081, 0.3643810674548149, 0.19443403317459992, 0.14564625253634794, 0.030274624404098307, 0.03667276518951569, 0.11417340992816857, 0.10182205055441175, 0.05201096786186099, 0.08356692761714969, 0.2091821003705263, 1.1631328953163964, 0.7557653316429683, 0.18415326412234986, 0.3307126483746937, 0.19288062224430697, 0.07778038097811596, 0.09610831750822918, 0.015389929093154413, 0.15157732713435376, 0.25122892058321405, 0.25309402335967335, 0.3040286345141274, 0.09743941322501216, 0.030150954611599445, 0.025612444217715944, 0.014346533920615911, 0.0325187059518482, 0.08984050633651869, 0.02684469604199486, 2.5783705370766774, 8.722316009657723, 16.407573427472794, 15.986839158194405, 10.571823120117188, 13.386659962790352, 18.57153950418745, 21.491563388279506, 17.44968683379037, 9.748135021754674, 8.760576265198843, 17.96259764262608, 19.99330074446542, 15.923791204180036, 15.039796216147286, 19.953727279390606, 37.5726444380624, 33.78374310902187, 34.39242615018572, 30.271192482539586, 25.587868656430924, 30.73340402330671, 43.26962879725865, 30.18621948787144, 12.956071410860334, 5.213925617081778, 5.632726984364646, 2.768346663032259, 1.9845618520464217, 23.911574057170323, 52.20546381814139, 45.91458913258144, 49.07803794315883, 48.61594452176775, 49.12476110458374, 48.320600918361116, 52.02991758074079, 51.63845607212612, 52.66900246483939, 51.51814801352364, 34.657461711338584, 2.1851754529135565, 11.71684890133994, 47.40007925033569, 29.6922789982387, 17.341979333332606, 5.340435377189091, 24.13089394569397, 18.98191053526742, 27.838308538709367, 26.759812627519878, 33.54675742558071, 25.518796614238195, 31.039315836770193, 36.898846353803364, 19.40134722845895, 45.521050112588064, 27.47844222613743, 24.430545432227, 48.80862501689366, 56.73336860111782, 3.3529839430536543, 0.19625804387032986, 0.10102996948574271, 0.1535140424966812, 0.0194470239803195, 0.05436444282531738, 0.057609353347548416, 0.03544180427810975, 0.033312334080359766, 0.05049504938402346, 0.0449023059170161, 0.13669235871306487, 0.13314803104315484, 0.12481995006757123, 0.13422388902732305, 0.20925555857164518, 0.17284712009131908, 0.18769770035786287, 0.1788101401180029, 0.09807415559355702, 0.17669293444071496, 0.2284345951463495, 0.241834250411817, 0.15458245016634464, 0.30676063363041195, 0.459764580641474, 11.560557859284536, 89.78804070608956, 60.710177012852256, 52.50447954450335, 30.90978057043893, 47.42529773712158, 44.7761823790414, 46.60884271349226, 39.92259120941162, 38.51683167048863, 45.40844760622297, 46.8940349987575, 45.62180594035557, 23.360248395374843, 26.773941789354595, 38.02847753252302, 44.967341218675884, 67.89474637167794, 41.85571207318987, 5.424627133778163, 5.5458345498357495, 40.103077616010395, 64.94206769125802, 63.684610503060476, 66.89655426570347, 60.46766403743199, 58.76853765760149, 60.52810641697475, 52.41386113848005, 54.835495948791504, 46.30416767937796, 39.63139568056379, 18.013246536254883, 7.1824657917022705, 3.485652629818235, 7.537776691573007, 7.682091644832066, 10.185805525098528, 0.40257615649274414, 0.43367914323295864, 3.088563297476087, 9.254160659653799, 34.88390697751726, 63.26509911673409, 35.82339375359671, 17.78221893310547, 20.092719044004166, 21.527297973632812, 26.59388964516776, 14.539203694888524, 40.24208675112043, 43.6404367855617, 33.34337323052542, 36.31543043681553, 30.730009828295024, 7.783694284302848, 21.192952394485474, 40.72699110848563, 22.44751044682094, 4.987178972789219, 0.7120517715811729, 1.1670407141957964, 0.5695383016552243, 0.20582538763327257, 0.10821124485560826, 0.18562683862234863, 0.24860114444579395, 0.20163580030202866, 0.1910413580813578, 0.7876597344875336, 3.1431620248726437, 1.0658923132078988, 0.16675992815622262, 0.6414086222648621, 0.9636073389223644, 0.1332598671849285, 0.11471474516604628, 0.23089382318513735, 0.22345393097826413, 0.28974962500589235, 0.7102711871266365, 1.2180842437914439, 0.8247340193816594, 0.28984453848430086, 0.18405122602624552, 0.1459902562201023, 0.0937895801450525, 0.24284355768135615, 0.25354945606419016, 14.071063603673663, 19.3610737323761, 25.35163858958653, 22.26008973802839, 8.472189545631409, 14.473178437777928, 20.69378685951233, 26.266612121037074, 17.719447169985088, 28.513171434402466, 12.993706328528267, 11.98429809297834, 14.502474648611885, 13.038756711142403, 11.88043120929173, 13.509245293481008, 37.45728349685669, 37.37953315462385, 36.58773381369454, 33.782940592084614, 32.445012841905864, 39.18623849323818, 50.25766488483974, 37.77802276611328, 17.941103390284947, 7.811938711575099, 7.473787256649562, 4.347628125122615, 1.9675355085304804, 24.67883583477565, 51.984236649104524, 50.145170075552805, 52.252426692417686, 51.56096281324114, 51.58100489207676, 53.29271445955549, 54.967681952885215, 56.42622695650373, 55.98119831085205, 55.05958924974714, 38.53798198699951, 4.470781905310495, 12.746385199683052, 46.747577394757954, 31.24127565111433, 20.80228645460946, 8.288784895624433, 35.491092681884766, 22.19442057609558, 35.89885466439383, 38.55752032143729, 44.78269631522042, 42.5019223349435, 45.03960248402187, 36.059274673461914, 38.265188762119834, 58.07074396950858, 34.070245129721506, 40.00440277372088, 53.04810660226004, 72.63449478149414, 13.42070266178676, 0.4872504600456783, 0.27017614245414734, 0.34032393406544414, 0.09413205712501492, 0.07817741895892791, 0.14417391297008308, 0.10414168358381305, 0.1334785861628396, 0.1000333372503519, 0.20497426044728073], [0.09451467623668057, 0.04570230209667768, 0.057196139091891904, 0.03545558193166341, 0.05980259565902608, 0.04076799204839127, 0.07331275035228048, 0.022355467646515796, 0.09777598016496215, 0.07132948070232357, 0.08925840471472059, 0.048824136544551165, 0.050388427783868144, 0.028745786619505713, 0.013934762400042797, 0.44309739928160397, 49.03392730440412, 58.13096400669643, 47.55999551500593, 25.221981729779923, 28.79589363506862, 26.013878345489502, 30.76519203186035, 32.15710381099156, 29.592294420514786, 35.934144565037315, 32.606158937726704, 37.140664509364534, 23.67322826385498, 16.399219955716813, 29.674171992710658, 50.42667286736624, 44.00129842758179, 57.882475580487935, 18.50340894290379, 1.756496244243213, 11.15935150214604, 43.29094239643642, 53.91099991117205, 51.74933542524065, 53.55727754320417, 52.618433475494385, 49.640518937792095, 46.19380249295916, 44.8852413041251, 42.93109866550991, 33.32274750300816, 17.05520112173898, 0.6275466403790882, 1.6006045064755847, 4.927357154233115, 4.274351554257529, 5.093983207430158, 15.10145800454276, 14.669688258852277, 21.388163770948136, 44.20940044948033, 39.43482072012765, 24.64900200707572, 10.446119785308838, 13.013046639306204, 8.627652883529663, 19.35558291843959, 5.750808145318713, 19.759584188461304, 43.482643195560996, 29.706929274967738, 31.76480504444667, 28.448648725237163, 16.88906795637948, 5.663133604185922, 20.827023778642925, 16.684563364301408, 5.817282429763249, 1.6914905267102378, 0.18252125169549668, 0.24816196944032395, 0.049340040289929936, 0.13871057970183237, 0.06609656435570546, 0.038185881317726204, 0.12403601141912596, 0.09281841332891158, 0.06480863025145871, 0.10566297266632318, 0.4740475256528173, 0.5072121460522924, 0.11260418913194112, 0.24829490802117757, 0.27187760972550934, 0.04765262208612902, 0.08917600342205592, 0.027003671707851545, 0.052138169429131916, 0.45698573546750204, 0.04770915423120771, 0.1693988729800497, 0.014509495979707156, 0.04741840197571686, 0.020673062120165144, 0.05860271504414933, 0.031977112870663404, 0.060677566565573215, 0.5179266482591629, 0.9026655033230782, 3.3595302317823683, 5.964353212288447, 17.095592737197876, 9.643093023981367, 3.613404380423682, 14.649159806115286, 22.95017613683428, 20.239650862557546, 16.465641260147095, 25.697215931756155, 11.96528000491006, 3.3175509529454366, 2.9610427916049957, 12.400479555130005, 10.955811841147286, 5.928009791033609, 15.881712913513184, 23.862922770636423, 25.482334205082484, 23.638773884092057, 10.257953013692584, 4.660091655594962, 2.933686430965151, 3.9038935814585005, 0.1836934887937137, 1.8738640206200736, 2.3332691405500685, 5.413724107401712, 24.681698492595128, 47.248830863407676, 48.28738852909633, 43.62880202702114, 49.48438944135393, 44.878921917506624, 49.36276817321777, 44.21508755002703, 49.222358976091655, 44.994578157152446, 48.170742171151296, 19.634778908320836, 3.0098940559795926, 13.805942927088056, 48.22951003483364, 46.639324460710796, 54.88549518585205, 32.41947473798479, 21.696771485464915, 18.041537863867624, 26.17894843646458, 30.50994995662144, 26.133046899523052, 28.081728254045757, 33.16091006142752, 15.941616807665143, 44.335565839494976, 58.95765372685024, 23.309627294540405, 25.033147062574113, 49.286692346845356, 26.50733072417123, 0.2134998765374933, 0.010921045722040747, 0.024340940838945762, 0.028947236881192242, 0.036557794215955904, 0.050928833428770304, 0.02254460589028895, 0.052552499874894104, 0.012179539888165891, 0.05390923743003181, 0.03413286951503583, 0.12652619422546454, 0.027626773808151484, 0.07475099353385822, 0.029621045903435776, 0.025103790619011437, 0.048106738432709656, 0.024066480209252665, 0.021395503443532755, 0.11148777510970831, 0.026045090019969002, 0.05020669574982353, 0.0163661085867456, 0.04897484935021826, 0.04103697011513369, 0.047592337642397196, 1.0891237237623759, 59.62588282993862, 66.78500788552421, 44.01713684626988, 22.95827599934169, 34.229751450674875, 22.934716394969396, 31.43576615197318, 27.004879065922328, 35.10384178161621, 26.153306109564646, 25.574793883732386, 31.575966903141566, 28.735310554504395, 24.063030890056066, 37.88840879712786, 53.94557414736067, 46.64744690486363, 66.98920849391392, 28.1629353250776, 2.6123381086758206, 7.8105751276016235, 47.2474308013916, 56.652501991816926, 57.657864638737266, 57.14015088762556, 57.68788085665022, 54.113654545375276, 49.18075663702828, 48.0077999659947, 45.29353482382638, 38.11898824146816, 22.80994759287153, 2.94241749388831, 4.481850819928305, 9.531828914369855, 6.706696144172123, 7.253863309110914, 13.480513623782567, 2.36108820778983, 8.629451598439898, 47.83727380207607, 41.473717485155376, 38.333201204027446, 21.89810422488621, 16.81988648005894, 12.021944301468984, 11.109473858560834, 15.925024509429932, 19.297954559326172, 37.89362689426967, 34.49372393744332, 32.82122652871268, 34.38723931993757, 31.878171852656774, 9.466778142111641, 24.13055522101266, 23.291013070515223, 3.9226706538881575, 2.4245335119111195, 0.1644908527710608, 0.21593963062124594, 0.13344630146665232, 0.04311955693577017, 0.024930625089577267, 0.040527624410710165, 0.05879999910082136, 0.03509188037631767, 0.020359809643455913, 0.18416843616536685, 0.06768728792667389, 0.9628390201500484, 0.35679059475660324, 0.03835127083584666, 0.2667524447398526, 0.00613944634096697, 0.2641172047172274, 0.13911476944174084, 0.3985780110316617, 0.36838659537690027, 0.14461544927741798, 0.14653851251517022, 0.020968436895470535, 0.03396531207753079, 0.03885526289897306, 0.03516928425856999, 0.01256420139023768, 0.23882766174418585, 0.4737116236771856, 0.5725482829979488, 3.0527253576687405, 10.964468428066798, 24.505217722484044, 15.203056301389422, 12.061498658997671, 17.398416076387676, 28.090199845177786, 21.926404237747192, 17.3918673992157, 13.851992113249642, 15.694479806082589, 6.692621265138898, 7.885488867759705, 17.362377507346018, 14.66987759726388, 14.922823292868477, 28.877863270895823, 27.265472991125925, 31.51413140978132, 31.714875289372035, 13.25368446963174, 3.7230879919869557, 1.5847228786775043, 6.538416853972843, 1.3743918963841029, 6.583204507827759, 5.513638768877302, 9.948373419897896, 29.635776247297013, 48.550475120544434, 50.714588846479145, 46.4294958114624, 53.17515788759504, 47.79066528592791, 52.74867745808193, 50.068944862910676, 55.37488807950701, 49.09639508383614, 52.271669728415354, 21.483817883900233, 4.051416865416935, 18.332453727722168, 48.60311814716884, 45.50045565196446, 60.00705405644008, 16.781325714928762, 16.31203395979745, 23.02462955883571, 25.285073110035487, 27.795646599360875, 29.007782425199235, 23.394278935023717, 38.39773954663958, 17.409637417112076, 35.16302306311471, 64.17794649941581, 17.618950162615093, 27.935835191181727, 55.36235005514962, 31.58112941469465, 0.2342035270162991, 0.07307685765304736, 0.15861688368022442, 0.054745392740837166, 0.06284754191126142, 0.07695942824440342, 0.030359471815505197, 0.07025605865887233, 0.04443067318892904, 0.025992914069710032, 0.034598269898976595, 0.2976381374256951, 0.15066791379026004, 0.1795526881303106, 0.19010242846395287, 0.1975870496992554, 0.3108848508979593, 0.2390260382422379, 0.17218067656670297, 0.2408062969999654, 0.1507283712604216, 0.16655136006219046, 0.1326156524675233, 0.16801607289484569, 0.14450416953435966, 0.18917510179536684, 1.9819365186350686, 79.756210735866, 72.8313580921718, 62.86757183074951, 35.233689716884065, 37.67057234900338, 41.29717418125698, 44.39653280803135, 42.67764227730887, 38.50700691768101, 53.40737363270351, 42.8477897644043, 49.25963953563145, 30.99356542314802, 23.590640238353185, 36.722275257110596, 59.05312197549002, 55.093993255070274, 68.263320514134, 25.31750382695879, 3.1805157576288496, 13.81764108794076, 51.14352893829346, 61.85025133405413, 62.40828200748989, 63.59239401136126, 60.78247996738979, 57.91141482761928, 53.19524165562221, 51.98916639600481, 50.95136955806187, 41.35346153804234, 21.70951795578003, 1.5280914774962833, 3.7230324063982283, 12.305849432945251, 8.115659236907959, 8.051143475941249, 27.039295230592998, 27.786528825759888, 35.46129533222744, 48.64156947817121, 50.59514583860125, 36.01817260469709, 15.245082480566841, 19.594675643103464, 10.873197759900775, 30.973745686667307, 12.230342490332466, 25.962855986186437, 51.21067632947649, 34.52823911394392, 37.411317689078196, 36.60216869626726, 23.685106209346227, 9.771134427615575, 45.134987354278564, 33.795263222285676, 15.474899360111781, 3.6911827325820923, 0.21326385491660663, 0.4735144685421671, 0.23407433394874844, 0.13317152192550047, 0.1537272517702409, 0.1602940729686192, 0.15315391682088375, 0.18829208346349852, 0.11957169882953167, 0.43045531479375704, 0.7255016927208219, 3.2001164087227414, 0.8048957724656377, 0.7501210059438432, 0.6753699513418334, 0.2179612307144063, 0.32305356221539633, 0.15976109728217125, 0.20323953138930456, 1.0287361698491233, 0.7362586983612606, 0.46531944828374044, 0.15175234845706395, 0.29700712699975285, 0.125381736350911, 0.24352306979043142, 0.15690138430467673, 0.21762162393757276, 1.2869008311203547, 4.139108777046204, 8.387073244367327, 17.095370394842966, 36.54731266839163, 17.652866056987218, 8.893194794654846, 20.24314406939915, 33.88249438149588, 25.151094470705303, 20.1030718599047, 34.202788966042654, 18.95788540158953, 4.613670740808759, 3.6506095954350064, 19.557737282344274, 16.96957847050258, 9.131306954792567, 23.90224610056196, 35.01118060520717, 34.694964613233296, 30.343828950609478, 16.006474767412456, 5.657488192830767, 5.259675596441541, 7.740162951605661, 0.3263830521277019, 3.422569500548499, 3.2754418296473364, 8.708746177809578, 31.493220806121826, 51.66200351715088, 55.23604570116316, 49.27705519539969, 57.02387278420584, 51.93203135899135, 56.87690796170916, 53.565691811697825, 58.359545843941824, 54.54791348321097, 57.52599130358015, 26.701989718845912, 4.541845909186772, 16.718828405652726, 56.00080960137503, 54.213521003723145, 63.30610738481794, 40.95186608178275, 29.37868595123291, 27.632796457835607, 35.695334979466026, 41.170755181993755, 34.49891424179077, 40.20403494153704, 46.291994435446604, 25.033692496163503, 59.09545040130615, 72.26171697889055, 32.10856716973441, 39.721829959324424, 60.57076835632324, 54.41859013693673, 0.32921072468161583, 0.20062984499548162, 0.30693754128047396, 0.21534999726074083, 0.14603440170841558, 0.1642955703926938, 0.1378395850104945, 0.1601433160581759, 0.10812344242419515, 0.11148542737854378, 0.15722917100148542], [0.05281330159466181, 0.05696159667734589, 0.02227249808077301, 0.05803727824240923, 0.030219988764396737, 0.06524114204304558, 0.026905285826485072, 0.08497370034456253, 0.028256128608648266, 0.009130261189836477, 0.11108802977417197, 0.004553264289695237, 0.057007899907018454, 0.028960020480943576, 0.1688035942081894, 0.07368919479527644, 11.584940825189863, 72.99640560150146, 42.10977642876761, 38.944131987435476, 26.13787416049412, 37.09290954044887, 27.35291259629386, 38.669132709503174, 27.621726240430558, 35.18305124555315, 39.92218126569475, 43.19033595493862, 30.084793158939906, 22.32679418155125, 13.779260975973946, 37.36133582251412, 68.00087315695626, 47.36459480013166, 38.74950252260481, 12.01888883113861, 5.57270974772317, 33.56950582776751, 59.400670869009836, 55.660351344517295, 48.24584524972098, 46.75210414613996, 53.468055725097656, 50.22566843032837, 47.79721743719918, 45.321428367069785, 46.442061628614155, 27.688705137797765, 11.644465173993792, 10.102848376546588, 9.837984783308846, 9.628401058060781, 13.07232345853533, 6.469686142035893, 10.683023827416555, 56.59923015322004, 33.51074143818447, 21.454380103519984, 9.98195493221283, 16.433629172188894, 20.192868641444615, 14.932291950498309, 19.647773776735576, 7.850253684180124, 23.016686030796595, 33.19404602050781, 27.694892508643015, 31.0052627154759, 30.668855258396693, 9.01713762964521, 15.773623262132917, 23.365192038672312, 13.127787453787667, 0.9504978252308709, 1.0234692181859697, 0.31095511998449055, 0.06591743111078228, 0.06699781492352486, 0.08188814377146107, 0.07548269177121775, 0.14261903640414986, 0.029070072075618163, 0.11614905962986605, 0.1490996836551598, 0.041751189290412834, 0.19598186654703958, 0.19776584367666925, 0.3526175229677132, 0.09663604811898299, 0.0362200805518244, 0.015658221839528, 0.09368277873311724, 0.45945967414549416, 2.9414927320820943, 0.40148233090128216, 0.11794697386877877, 0.041262623720935414, 0.021969296404027512, 0.12776063941419125, 0.030828366654792, 0.04182923099558268, 0.1636802205549819, 0.21127934354756558, 1.0685012532132012, 0.2883940748870373, 2.524694834436689, 5.5996070929936, 12.448046922683716, 18.748166186468943, 4.194685246263232, 17.30630033356803, 23.107248851231166, 21.587471110480173, 23.050867693764822, 19.69380211830139, 18.068880762372697, 18.591263702937535, 16.493373257773264, 13.058406216757637, 17.150907346180507, 17.47275137901306, 10.54517330442156, 16.998988458088466, 22.5631388936724, 26.321657487324305, 36.844129289899556, 16.462111575262888, 1.8256268032959528, 1.406828801546778, 2.776525778429849, 0.7511271376694951, 0.4868705890008381, 11.323626892907278, 36.27571453366961, 45.00773457118443, 43.940025738307405, 42.54326064246041, 43.10578680038452, 43.830598558698384, 43.64975779397147, 45.827955518450054, 45.51237876074654, 47.14093576158796, 40.483866691589355, 16.536679642541067, 5.556680687836238, 30.577489921024867, 63.704093251909526, 48.37639842714582, 47.80533293315342, 55.20554658344814, 24.698714630944387, 16.932226691927227, 30.879861627306255, 27.852713891438075, 24.99067619868687, 31.99047211238316, 29.55223110743931, 34.86063051223755, 66.92971801757812, 36.63482175554548, 34.5801352092198, 38.31882538114275, 51.75227451324463, 5.945443255560739, 0.2028624287673405, 0.04347479376675827, 0.05721026619098016, 0.0788119374109166, 0.03338025204305138, 0.022041777514719536, 0.01374811607612563, 0.018396044482610056, 0.03924644512257405, 0.03164245600679091, 0.05174722130011235, 0.028799879431192364, 0.06898499293518917, 0.05161748540454677, 0.018897637924445525, 0.05636292523039239, 0.037447431656931124, 0.018719817644783428, 0.1552363679345165, 0.05037984770855733, 0.005890131794980594, 0.015686063827680688, 0.0982077591387289, 0.08082356982465301, 0.044141685124486685, 0.18953636740999563, 0.21361578388937882, 18.23835948535374, 81.82350826263428, 47.865087441035676, 31.04313734599522, 30.892583778926305, 40.42371266228812, 30.374866553715297, 32.535954339163645, 30.468882628849574, 42.12885618209839, 26.83993230547224, 36.99586752482823, 28.67371998514448, 31.72591597693307, 13.514834250722613, 41.485286235809326, 75.06268174307687, 56.55367428915841, 45.45065443856375, 17.598803860800608, 6.007513250623431, 34.15233809607369, 68.09666102273124, 59.303444726126536, 55.08155597959246, 56.63367584773472, 57.513005120413645, 53.64678423745291, 51.04277311052595, 51.01516791752407, 48.8152049609593, 33.50485978807722, 9.22139469214848, 10.26646021434239, 13.88708051613399, 9.65775546005794, 10.438065086092267, 2.0931446083954404, 11.91007309300559, 55.3695136478969, 37.04710006713867, 32.205595288957866, 22.65500102724348, 19.451249190739222, 21.439865316663468, 12.097779546465192, 22.84473201206752, 15.473721640450613, 19.82227952139718, 34.99769067764282, 29.640004226139613, 33.41304281779698, 33.640738759722026, 15.797450372150966, 14.61867458479745, 24.446781635284424, 18.990654843194143, 2.3636507902826582, 1.3795067476374763, 0.15915866675121443, 0.0038556900025079294, 0.056555215269327164, 0.046463971225810904, 0.09233034308999777, 0.1975918130150863, 0.03829829082159059, 0.11740972341171332, 0.1506731113685029, 0.021724043314212134, 0.26700787246227264, 0.10477107231106077, 0.372259401849338, 0.06598417860056673, 0.0142654371115246, 0.03247019748336502, 0.10041611242507185, 0.7943720200232097, 1.853228087936129, 0.4210130657468523, 0.05464790082935776, 0.10579031333327293, 0.07637710949139935, 0.17871955569301332, 0.023829958168789744, 0.013421937507311148, 0.4578554002302033, 0.6816872209310532, 1.2266700459378106, 0.16861007602087089, 7.621672715459551, 11.722308448382787, 22.593082155500138, 22.345246859959193, 13.2851311479296, 21.695109128952026, 27.439516680581228, 23.407047986984253, 27.292242663247244, 16.408751147133962, 16.05012682506016, 17.812349796295166, 16.39129900932312, 15.569294112069265, 17.973999636513845, 19.477171182632446, 21.223018986838206, 31.540506771632604, 30.05615268434797, 29.283829144069127, 45.58830520084926, 23.741454362869263, 3.4841133866991316, 1.9803736082145145, 2.782261950629098, 2.3128952852317264, 2.4633652567863464, 10.960254345621381, 41.33522946493966, 48.29864113671439, 48.49941628319876, 47.13355677468436, 49.13371385846819, 49.88789912632534, 47.535576071058, 51.18798351287842, 51.95517928259713, 51.497501441410606, 45.388752937316895, 17.06973327909197, 7.874810355050223, 38.87290252958025, 65.33163234165737, 51.7491443497794, 50.36864846093314, 45.44528348105294, 23.500044413975306, 22.502693040030344, 28.32102942466736, 28.637082133974346, 23.805643558502197, 24.793328251157487, 37.851121289389475, 23.195628200258525, 67.72172927856445, 41.00727449144636, 28.48792689187186, 43.22056061880929, 58.91282394954136, 8.185232417924063, 0.355851909411805, 0.05944910605571099, 0.028471587225794792, 0.03547372256538697, 0.015642997210047076, 0.046281007650707445, 0.027936251933819482, 0.03939505446968334, 0.034131064611886225, 0.023880251184371964, 0.03603344610227006, 0.21612093517822878, 0.13510810158082417, 0.16049174379025186, 0.21739614675087587, 0.16428001837006637, 0.1536728468324457, 0.1279673483222723, 0.20684172452560493, 0.10572743349309478, 0.13046040811708995, 0.18207909113594464, 0.1783809938601085, 0.18891022886548722, 0.14299908386809485, 0.4059300465243203, 0.16942077609045164, 28.101799862725393, 96.62802110399518, 56.44113779067993, 54.67667402539934, 35.18213060923985, 51.92119911738804, 39.502537863595144, 53.30120515823364, 36.07647841317313, 49.20795883451189, 52.78747272491455, 57.32647378104073, 40.26091289520264, 30.376895427703857, 20.53833654948643, 44.84986802509853, 78.23397159576416, 58.3189058303833, 48.503963879176546, 17.262818506785802, 7.789203337260655, 39.033906187329976, 72.43488693237305, 63.76062379564558, 59.27236543382917, 56.28194413866316, 61.61875125340053, 58.39284855978829, 56.00159822191511, 55.48996761866978, 52.27755832672119, 35.533170972551616, 16.165399176733835, 20.16622577394758, 24.11549847466605, 19.91960120201111, 22.84002808162144, 14.994280304227557, 15.406516926629202, 63.463643891470774, 45.332903317042756, 30.816945689065115, 16.639372280665807, 22.373524291174753, 25.627158982413157, 21.245062146868023, 30.374838760920934, 11.984288539205279, 31.80300624029977, 40.230048997061594, 32.97071702139718, 38.77367183140346, 35.66924449375698, 11.276270576885768, 27.903032745633805, 38.037048135484966, 30.11234971455165, 8.753705365317208, 2.2254102996417453, 0.4348876955253737, 0.1797985349382673, 0.1968617636178221, 0.1773585094405072, 0.33484394954783575, 0.3496338145009109, 0.1254103976700987, 0.34351785268102375, 0.331834538174527, 0.19857908146721975, 0.45588694299970356, 0.54647473352296, 0.6517386936715671, 0.4449441001883575, 0.2688060445444924, 0.1407845084156309, 0.1616291177592107, 0.4359867051243782, 4.9364354099546155, 0.5056630234633173, 0.37068503775766914, 0.35070847826344625, 0.2536810375750065, 0.2961884337876524, 0.11337258254310914, 0.19890340763543332, 0.3224467347775187, 1.2801895226751054, 4.37395007269723, 0.5570021771958896, 11.458795411246163, 19.924770661762782, 31.137681484222412, 34.26338768005371, 9.346039295196533, 22.432300840105327, 30.642396518162318, 25.530370576041086, 31.855065618242534, 24.73369881084987, 23.708212443760463, 24.970022678375244, 19.880321298326763, 15.07278105190822, 23.77503674370902, 22.611361128943308, 15.064135755811419, 23.56421102796282, 32.11971208027431, 36.78062622887747, 50.798641204833984, 20.726278373173304, 3.222594265426908, 2.216548957995006, 5.843470190252576, 2.9892939499446323, 1.1409432802881514, 16.22861041341509, 43.02176570892334, 52.36379589353289, 48.44888898304531, 52.66506978443691, 50.34357588631766, 54.392065388815745, 49.86998667035784, 55.098044054848806, 55.11186749594552, 56.729001658303396, 48.82918126242501, 22.739534548350743, 7.5205234459468295, 37.005108628954204, 73.001220703125, 57.81577982221331, 55.64885207584926, 65.95271791730607, 34.7547538621085, 24.362781388419016, 41.206409863063264, 37.31523105076381, 32.7234445299421, 48.9664637701852, 42.75125496728079, 45.75833109446934, 82.35000801086426, 47.01925890786307, 52.312924657549175, 49.296190534319194, 71.65489605494908, 16.7297613961356, 0.473004264490945, 0.2960418430822236, 0.15686983242630959, 0.22751512591327938, 0.11024218159062521, 0.14323034217315062, 0.1194953229278326, 0.13363596557506494, 0.13202037369566305, 0.0916365681748305, 0.14666714918400559], [0.07105437546436276, 0.042020452341863086, 0.003332479707231479, 0.11082497531814234, 0.056643872654863765, 0.017695524929357425, 0.03583607044337051, 0.04498297016003302, 0.041055460194391866, 0.05983424931764603, 0.031092106431190456, 0.050282372760453393, 0.049594141476388486, 0.05178767895059926, 0.05169644991734198, 0.11912907686616693, 1.2033358237573077, 59.498126302446636, 55.16381222861153, 46.01865577697754, 33.07640954426357, 34.09664828436715, 33.492481572287424, 33.7970905985151, 35.71903528485979, 21.104732854025706, 26.71241201673235, 34.546895027160645, 41.15609448296683, 24.821748120444163, 37.97744301387242, 37.450255393981934, 47.27373668125698, 59.63872310093471, 66.23718411581856, 36.71835994720459, 3.5982596959386552, 41.56025382450649, 54.344515391758506, 56.61687510354178, 40.04109968457903, 34.42261607306344, 52.85310888290405, 48.10561670575823, 52.856249468667166, 50.45726578576224, 44.88796847207205, 43.153083188193186, 10.330690230642047, 6.61610118831907, 8.155682597841535, 8.384272251810346, 8.168896334511892, 14.181242057255336, 42.43970121656145, 26.222470215388707, 19.383710963385447, 10.884574566568647, 18.079737322671072, 23.923755986349924, 14.062318427222115, 15.858839443751744, 7.680494427680969, 15.360344409942627, 40.853430952344624, 29.148436546325684, 29.141146148954117, 36.96505226407732, 18.428192956107004, 13.193589500018529, 15.49384536061968, 22.770137889044626, 5.939015303339277, 2.643943292754037, 0.7613744278039251, 0.10061328113079071, 0.09602830465883017, 0.02757390744851104, 0.03548574620591743, 0.042551019228994846, 0.03910008851172669, 0.18419195418911322, 0.41835649258324076, 0.38535556197166443, 0.07654297059135777, 0.2616322194891316, 0.21731989298548016, 0.09065277382199254, 0.1972739872123514, 0.19788432946162565, 0.04010069356965167, 0.35991470568946426, 2.2921540439128876, 0.7954824832933289, 0.38331922409789904, 0.15637125846530708, 0.40093592022146496, 0.08891414318765913, 0.06572501893554415, 0.030253443933491195, 0.10666296365005629, 0.11530850401946477, 1.048215770295688, 0.1357677054724523, 0.8333142846822739, 6.046490907669067, 4.47892085143498, 13.524132677486964, 21.700356755937847, 8.614380087171282, 13.092831066676549, 26.823732580457413, 23.62255505153111, 24.46956304141453, 23.975516591753276, 19.01567530632019, 15.57929083279201, 25.67108723095485, 16.844733238220215, 12.550390413829259, 14.743933234895978, 18.404602084841045, 13.19986024924687, 19.97978823525565, 27.8699506350926, 23.68274208477565, 39.68412555967058, 37.04919147491455, 10.048218165125165, 9.872356653213501, 11.884482877595083, 4.688567544732775, 5.658498287200928, 40.50872039794922, 41.23201050077166, 41.69693878718785, 45.08988312312535, 46.89739097867693, 44.96885592596871, 48.29674080439976, 45.22869423457554, 46.56278657913208, 46.01595292772566, 41.51690053939819, 22.453609228134155, 21.980657509395055, 44.88487652369908, 45.375718116760254, 40.20085614068167, 20.508975199290685, 41.985202176230295, 20.10377710206168, 22.10243684904916, 29.836884907313756, 26.995380878448486, 29.683864729745046, 41.57640838623047, 19.38122524533953, 57.756101744515554, 46.653335503169465, 20.89222741127014, 46.4336438860212, 45.4719888823373, 34.49519000734602, 0.6348504998854229, 0.147322396880814, 0.022883780101048093, 0.07566562481224537, 0.027432858677847043, 0.07572236391050474, 0.0317558188523565, 0.08085281468395676, 0.028284257277846336, 0.05948671046644449, 0.035709255641060214, 0.08041200440909181, 0.016765287345541374, 0.10577081902218716, 0.04411995504051447, 0.08426234458706208, 0.06934789381921291, 0.01680636076655771, 0.010139884826328074, 0.04982449393719435, 0.05353518482297659, 0.03935074952564069, 0.03398808032008154, 0.03222585702314973, 0.0767441697950874, 0.06755717883684806, 0.043021793610283306, 0.0284735922967749, 2.06928471156529, 67.08471843174526, 62.76422432490757, 43.2233225277492, 33.048175539289204, 37.8673939704895, 34.91949217660086, 35.249906812395366, 27.500122342790874, 32.40065901620047, 30.20651170185634, 33.71921171460833, 33.306391443525044, 32.24263613564627, 33.245962960379465, 41.54813616616385, 64.25477273123605, 65.06669058118547, 66.93863950456891, 39.808699812207905, 4.129386944430215, 46.07287604468209, 60.29215948922293, 59.41542189461844, 49.10710225786482, 48.48719787597656, 56.79101085662842, 50.893421581813264, 52.754666805267334, 52.1763265473502, 48.88471473966326, 46.552044664110454, 8.314606138638087, 9.46571159362793, 5.935741399015699, 6.82523067508425, 2.271837945495333, 13.646045769963946, 50.60796873910086, 30.287972382136754, 34.97759301321847, 22.22894617489406, 20.815288271222794, 24.588455404554093, 18.004604714257376, 15.237389087677002, 11.29441579750606, 16.338459696088517, 32.804005418504985, 32.6432067326137, 29.319021769932338, 39.798315729413716, 28.06983641215733, 15.378793614251272, 16.576355593545095, 23.609878063201904, 17.65592326436724, 1.3823999123913902, 1.4369685671159198, 0.046717421018651555, 0.03334784181788564, 0.08744663479072706, 0.06330065402601447, 0.025138728387121643, 0.1025222579815558, 0.33180783103619305, 0.2876028487724917, 0.0927614706701466, 0.16020374638693674, 0.14270449110439845, 0.21866639144718647, 0.23480555042624474, 0.3012552990445069, 0.2615092960851533, 0.057271850029272695, 0.8855622410774231, 2.4454708227089474, 0.9541166424751282, 0.2687179978404726, 0.15207653891827377, 0.07708899450621434, 0.17290832395000116, 0.15286259459597723, 0.16078700151826653, 0.35479111490505083, 0.058878960220941474, 0.13855625369719096, 0.021762899622055035, 0.168562632852367, 8.65304594380515, 12.354410392897469, 22.24617944444929, 20.49342165674482, 16.894055025918142, 22.318534510476248, 27.23209731919425, 24.82238561766488, 25.96182244164603, 22.332639353615896, 10.191859143120901, 16.45869653565543, 18.80907235826765, 18.181104591914586, 16.580859763281687, 16.080643313271658, 21.580880744116648, 24.1377101285117, 37.74014466149466, 43.81286675589425, 26.257984195436748, 44.434515135628835, 44.581792627062114, 13.410548738070897, 6.892205664089747, 0.6722439133695194, 4.936626051153455, 5.378969652312143, 49.04437392098563, 48.55914994648525, 46.92521503993443, 47.4465731212071, 50.826409680502756, 46.99132367542812, 52.70568895339966, 49.82671676363264, 51.163223607199534, 50.8366756439209, 48.39385577610561, 24.662669113704137, 28.876190492085048, 47.28038958140782, 50.10678127833775, 41.36716685976301, 21.22422276224409, 44.94960594177246, 25.031931127820695, 24.704912424087524, 26.55522813115801, 28.89109264101301, 23.209717409951345, 41.65132386343819, 22.02556197983878, 43.19975771222796, 55.844308376312256, 22.664987325668335, 46.593223163059776, 53.41341161727905, 43.032281807490754, 0.5828012728265354, 0.20152393701885427, 0.06541792077145406, 0.182835562686835, 0.007986857589068157, 0.019761423181210245, 0.1201833574367421, 0.059859762234347205, 0.025652504925216948, 0.07813007078532662, 0.09967285195099455, 0.07822233797716242, 0.15391569451561996, 0.1985260878822633, 0.09237143517072711, 0.23373723775148392, 0.14414982497692108, 0.0795956114307046, 0.12561439243810518, 0.12442960244204317, 0.12695798676993164, 0.1334979651229722, 0.15638603695801326, 0.19851367069142206, 0.17342462124569075, 0.2471048661640712, 0.19780936491276535, 0.1257905808410474, 3.8982208115713934, 87.18245233808244, 68.42416436331612, 62.03068215506417, 45.93216807501656, 41.77699245725359, 46.9312287058149, 48.940595626831055, 45.3831387928554, 27.883761916841777, 38.347177505493164, 44.78708757672991, 55.34098087038313, 34.88636316571917, 50.31227077756609, 43.19508852277483, 57.515902519226074, 70.04366438729423, 72.28486837659563, 45.73969949994768, 6.331760491643633, 49.40177536010742, 65.01950536455426, 65.55406502314976, 50.86793906348092, 45.7450669833592, 61.905677114214214, 54.75991691861834, 59.09399822780064, 56.41287251881191, 53.1130826813834, 48.58889865875244, 12.238351157733373, 16.283438648496354, 17.425826719829015, 17.25202100617545, 19.73257827758789, 25.578691823141916, 53.65154722758702, 41.20022249221802, 29.163208416530065, 16.753939390182495, 21.219718592507498, 33.03095095498221, 17.143293857574463, 23.898905754089355, 14.912387098584857, 21.77184850828988, 51.19913189751761, 33.17669984272548, 32.948566164289204, 43.5120062828064, 22.564302716936382, 20.17417277608599, 32.50493063245501, 32.98338706152779, 30.245265279497417, 15.524940286363874, 1.970064435686384, 0.21693360299936362, 0.25223727790372713, 0.16798997643802846, 0.16835941161428178, 0.08551598553146635, 0.2781894238931792, 0.576087087392807, 0.8405342772603035, 0.44581835184778484, 0.2188826405576297, 0.7307164243289402, 1.053647090281759, 0.4384494886866638, 0.32474137736218317, 0.4416372190628733, 0.1500585214900119, 0.7115910191621099, 6.264561857495989, 2.2233746945858, 0.9837732911109924, 1.180650498185839, 1.0071001308304923, 0.7189382506268365, 0.24091768530862673, 0.17092664885733808, 0.21080312053007738, 0.23186000276889118, 4.013833624976022, 0.3653802238404751, 1.2818438453333718, 13.735280615942818, 26.893205881118774, 29.208468982151576, 35.47337130137852, 17.166818720953806, 17.947499207087926, 31.23174967084612, 27.716928720474243, 29.799048491886683, 27.09108362879072, 24.857944761003765, 21.412604059491837, 29.311125142233713, 20.5620333807809, 16.035829169409617, 18.02541283198765, 22.553526060921804, 17.08067842892238, 23.964871951511928, 36.1247683933803, 33.25675351279122, 51.87386104038784, 46.77514784676688, 13.978306021009173, 25.500092063631328, 24.14981041635786, 13.324112279074532, 10.686842731067113, 49.36566209793091, 47.0397560937064, 47.46005262647356, 50.28978293282645, 53.554268973214285, 48.55842385973249, 57.02545002528599, 53.571205207279746, 54.94526011603219, 54.37436485290527, 50.676266057150706, 27.504259995051793, 28.580353566578456, 52.29386574881417, 56.81129959651402, 46.96708835874285, 29.06389955111912, 49.236012186322895, 26.869041783469065, 29.114687408719742, 39.75254447119576, 35.767109870910645, 42.714502470833914, 59.18415805271694, 27.432146378925868, 69.76974555424282, 58.69028009687151, 33.478307247161865, 63.76900332314627, 57.520825317927766, 61.42343739100865, 1.204630468572889, 0.36545187713844435, 0.19480591107692036, 0.23546495075736726, 0.16044135577976704, 0.24300279627953256, 0.24276862027389662, 0.17185377196541854, 0.13983208952205523, 0.17664184075381073, 0.15244081722838537, 0.15242948569357395], [0.014990392407136304, 0.03252841578796506, 0.0643238712634359, 0.04265915396224175, 0.03686745384974139, 0.004692640471538263, 0.04757841071113944, 0.08787430862763099, 0.06938256017331566, 0.06585108395665884, 0.03126367061798062, 0.04679377995697515, 0.0858667745654072, 0.20406178012490273, 0.02066691459289619, 0.06091179685401065, 0.07112675479480199, 25.74822439466204, 78.62571103232247, 46.1959216935294, 39.02202129364014, 32.479107652391704, 45.0385776247297, 32.29631791796003, 49.22466230392456, 29.456147943224224, 24.351099729537964, 20.70728373527527, 37.34209973471505, 30.612654754093715, 19.166499853134155, 53.1776488167899, 31.310528346470424, 33.04403441292899, 63.795719146728516, 22.079158646719797, 6.553725038255964, 42.81329195840018, 57.048101152692524, 59.322281292506624, 45.68809870311192, 29.540999344417028, 59.36870220729283, 46.87728636605399, 56.03353909083775, 30.277678625924246, 41.29502023969378, 44.980515003204346, 6.754581826073783, 7.967343858310154, 8.877420646803719, 6.397452235221863, 12.48066176686968, 43.053352219717844, 31.23933710370745, 24.700978006635392, 15.26207777432033, 9.97899065698896, 23.034622805459158, 13.435001185962133, 19.857230697359356, 19.949292591639928, 16.98768547603062, 32.6079272542681, 31.468665872301372, 25.847915410995483, 29.83495330810547, 23.936035190309795, 6.871911713055201, 14.911931991577148, 16.886170557567052, 21.319079569407872, 6.406405857631138, 2.4191375843116214, 0.5495474657842091, 0.14176347159913608, 0.06385237763502769, 0.051728432665445974, 0.03800622899351375, 0.022701898789299384, 0.09825391987604754, 0.26004960441163605, 0.5326604662196976, 2.1096991258008138, 1.1760778235537666, 1.0368818470409937, 1.0614182161433356, 0.3312032291931765, 0.27359354336346897, 0.37559290868895395, 0.4301971729312624, 1.8102734557219913, 0.5198512992688588, 0.33453755027481485, 0.828427366912365, 2.9423606055123463, 1.029652680669512, 0.13438637102288858, 0.10214866338563816, 0.15779713195349487, 0.026505470941109315, 0.7951087462050574, 0.06011489140135901, 0.04446500027552247, 0.07670443478439536, 3.5472425477845326, 5.784573350633893, 13.728005852018084, 24.548412936074392, 23.249884946005686, 10.093882594789777, 20.584165130342754, 26.92927745410374, 24.81084292275565, 24.688076938901627, 29.62876898901803, 8.99127904006413, 22.237150260380336, 22.23839919907706, 15.695673159190587, 14.755887610571724, 13.90771406037467, 13.183544141905648, 8.561159491539001, 14.885633059910365, 36.148347105298726, 38.67984683173043, 39.235928535461426, 56.80656439917428, 22.915019989013672, 6.882003102983747, 4.826376812798636, 8.388993552752904, 21.59934731892177, 37.8813841683524, 51.9479010445731, 47.01725435256958, 49.99407802309309, 43.520767961229595, 48.396902561187744, 46.45460312707083, 50.98137187957764, 43.40180785315377, 49.1911164011274, 13.873531528881617, 39.52029398509434, 57.84408678327288, 52.134022440229145, 37.055882590157644, 38.58337456839425, 55.36958660398211, 14.317671673638479, 26.018238340105327, 30.764181068965367, 29.586826188223704, 36.498025621686665, 24.718893936702184, 19.231644426073345, 59.01327405657087, 27.291836193629674, 24.991232054574148, 31.5237546648298, 59.315277508326936, 11.326599853379385, 0.2854277640581131, 0.06272195186465979, 0.012202328486767198, 0.009700371401517518, 0.013903322479953724, 0.019010325627667562, 0.06976642100406544, 0.008000317179331822, 0.09469550581915037, 0.1375690938106605, 0.05531911106247987, 0.013535050143088614, 0.025958914376263107, 0.036526255908289125, 0.07204619010112115, 0.012466022462051893, 0.05703597090073994, 0.08730917716664927, 0.10384954033153397, 0.04509160700919373, 0.05701053262289081, 0.0673511213223849, 0.09538951143622398, 0.1099277688190341, 0.10439289081841707, 0.19007943969752106, 0.11797878359045301, 0.19973765287016118, 0.1517748079661812, 31.643420015062603, 86.89794445037842, 51.756936754499165, 35.08750309262957, 32.856787409101216, 39.78399549211775, 40.77757746832711, 27.676363400050572, 25.901062182017736, 31.109972068241664, 24.55301785469055, 34.367742674691335, 32.75958558491298, 27.358102900641306, 56.862764903477256, 51.68405015127999, 34.66714750017439, 67.39938844953264, 29.202146121433803, 9.378020116261073, 46.10731479099819, 63.39440509251186, 62.86575835091727, 49.856125014168875, 33.43094832556588, 68.0654844556536, 47.05953761509487, 60.84628527505057, 35.63434716633388, 44.56631204060146, 46.453842299325125, 8.416624801499502, 4.995343974658421, 4.413927836077554, 1.7300169851098741, 16.408395051956177, 49.791503293173655, 33.42148487908499, 41.63315085002354, 28.697571413857595, 13.235417655536107, 28.293193204062327, 16.4536087172372, 21.9353118283408, 18.95693176133292, 16.2171128817967, 22.68339831488473, 33.682636397225515, 28.713767664773123, 29.94474526814052, 32.90354878561837, 14.697962215968541, 17.095794234957012, 18.80584839412144, 25.012715884617396, 15.590402739388601, 1.8157650296177184, 0.8918460724609238, 0.11836226444159235, 0.02610255854337343, 0.09091453227613654, 0.06567672759826694, 0.06913100010050194, 0.09387259890458413, 0.5008775602493967, 1.1660295341696059, 1.041429660149983, 0.8669755927153996, 0.4770519701497895, 0.7425138141427721, 0.7544038104159492, 0.14174929021724633, 0.2524463209722723, 0.7308665162750653, 2.704802564212254, 0.29756547989589827, 0.9708898110049111, 1.6469203297580992, 3.9201289159911017, 0.44456270922507557, 0.25296377177749363, 0.2288246170750686, 0.24079706892371178, 0.04278136490445052, 0.0373978443177683, 0.017084437987900207, 0.03494278587667005, 0.10997939176325287, 5.1166243468012125, 12.373498831476484, 26.39803556033543, 24.30403436933245, 20.50822479384286, 19.396186453955515, 23.333560364586965, 29.597522939954484, 27.013114418302262, 28.043547902788433, 19.28668805531093, 9.762751426015582, 20.62522898401533, 16.12570411818368, 15.76060060092381, 16.214324917112076, 15.415002414158412, 14.748425245285034, 11.8744409935815, 27.002605267933436, 58.371406418936594, 43.36300563812256, 40.81039728437151, 61.26226002829415, 30.948621000562394, 13.397203854152135, 2.6894029676914215, 4.0695538350514004, 29.036613975252422, 46.799001012529644, 54.77549130575997, 53.79580225263323, 50.72479575020926, 47.72396605355399, 54.92208787373134, 49.671973432813374, 53.64465808868408, 49.46232196262905, 53.29326684134347, 16.29029130935669, 41.985056264059885, 55.35178184509277, 58.84826823643276, 39.63293818065098, 42.577515261513845, 58.37876456124442, 21.12825424330575, 25.895944833755493, 29.50951358250209, 30.282160214015416, 27.41773407799857, 32.70460101536342, 15.474352189472743, 60.189861161368235, 35.154695647103445, 23.864400999886648, 38.03085381644112, 63.64432484763009, 11.25762595449175, 0.4370941828404154, 0.025327269520078386, 0.0720475200297577, 0.0557967793595578, 0.029382581556481973, 0.04536210499437792, 0.07828524495874133, 0.07025485086653914, 0.09263489674776793, 0.10271861923060246, 0.02816839742341212, 0.08942476114524261, 0.05571602690698845, 0.1973565106413194, 0.16652554859008106, 0.13135631861431257, 0.16109042880790575, 0.2281869298645428, 0.20443273521959782, 0.20208025430994375, 0.14961535669863224, 0.13940605095454625, 0.27380429634026116, 0.2549076931817191, 0.2081561011395284, 0.2960604892245361, 0.19752314527119907, 0.38527772043432507, 0.18450655016515935, 42.946103300367085, 98.24447086879185, 61.30132974897112, 54.09843104226248, 46.46296180997576, 60.071394375392366, 48.78190919331142, 64.96468407767159, 39.89888048171997, 33.19557809829712, 33.470445360456196, 51.954567841121126, 38.54814372743879, 25.844632387161255, 62.888652665274485, 37.347456795828684, 40.930333614349365, 72.66555322919572, 27.893633569989884, 8.999918256487165, 51.60253388541085, 67.1272691999163, 68.56295463017055, 57.0585686138698, 36.25655835015433, 70.19503784179688, 54.147638184683665, 64.62794658115932, 37.742916992732454, 46.58059481212071, 52.43082169124058, 10.910421865327017, 13.765799709728785, 17.99477127620152, 15.166227374758039, 20.141964401517594, 53.04748126438686, 40.714272430964876, 34.77491058622088, 21.40653654507228, 15.812712090356008, 30.150884423937114, 20.79261977331979, 26.33839222363063, 27.770930119923182, 22.709820577076503, 41.265341009412495, 38.656657218933105, 32.711246967315674, 33.35772820881435, 33.20015001296997, 8.420541848455157, 22.033144201551163, 29.637443814958843, 33.141086850847515, 28.510512011391775, 12.108200107301984, 1.3194596554551805, 0.2644214869609901, 0.14258282977555478, 0.31229001549737795, 0.1355404776654073, 0.1810685217912708, 0.3327427165848868, 1.0562870800495148, 2.043161004781723, 3.154127150774002, 3.283889319215502, 1.9691811459405082, 1.156521467225892, 1.6096593120268412, 0.44534408301115036, 1.2114539252860206, 1.0139656024319785, 5.7288331644875665, 1.644669221980231, 2.1969107432024817, 3.2006420833723883, 6.6257001246724805, 1.4800688943692615, 0.6975770454321588, 0.3524743520787784, 0.35792192976389614, 0.23977606371045113, 1.0038858290229524, 0.32324813891734394, 0.2635674556451184, 0.16391960770956107, 8.526060666356768, 30.026226793016704, 31.650628771100724, 35.599071162087576, 35.854987212589805, 13.616449049540929, 23.45187255314418, 31.193670068468364, 28.698200225830078, 28.598149640219553, 34.18755851473127, 17.002806493214198, 29.308488300868444, 24.69575469834464, 18.174503803253174, 20.67919216837202, 14.970493146351405, 15.815838779721942, 8.950541751725332, 16.806974990027292, 45.187286445072715, 45.44421693256923, 44.63182313101632, 69.57966368538993, 31.7811541557312, 17.14232632092067, 16.296537739889963, 10.747318983078003, 31.067897251674108, 42.927124295915874, 59.980609212602886, 53.86063241958618, 55.36371885027204, 49.63507155009678, 54.74708359582083, 51.31755352020264, 59.86213547842843, 50.895405292510986, 60.516044344220845, 18.389474119458878, 46.8174067905971, 66.77477318899972, 60.915579659598215, 47.32074819292341, 45.8898709160941, 66.72479479653495, 22.19472282273429, 34.28032044001988, 41.72876501083374, 38.524950640542166, 52.38225378308977, 35.717690808432444, 26.419819899967738, 77.30074514661516, 38.1736775125776, 39.79715538024902, 44.73554236548287, 77.16788169315883, 22.081859758922032, 0.522167546408517, 0.15534177156431334, 0.19785595312714577, 0.11651108520371573, 0.14534703216382436, 0.06231812174831118, 0.2928162233105728, 0.17602949004088128, 0.16097722202539444, 0.258281369294439, 0.1550914735666343, 0.25320326749767574], [0.023972718544038277, 0.1410501684461321, 0.061893148480781486, 0.03555221210366913, 0.025160916482231448, 0.02504399641683059, 0.09088707874928202, 0.18735422593142304, 0.07241949971233096, 0.07850252544241292, 0.003955405812510955, 0.01442556459057544, 0.0397768186272255, 0.1590893611844097, 0.04898656764999032, 0.16535237511353834, 0.017865467417453016, 3.4189766304833547, 64.30744702475411, 51.89034564154488, 50.431390694209504, 46.9077125276838, 39.11995267868042, 32.33585316794259, 41.8071928024292, 50.42001649311611, 26.773495367595128, 31.852713653019496, 21.647772789001465, 47.08081299918038, 15.986790520804268, 23.255643265587942, 8.727504576955523, 43.93695116043091, 71.65670258658272, 33.37514386858259, 8.075872114726476, 17.869576896939957, 45.06831244059971, 58.41753550938198, 42.77224200112479, 54.24359975542341, 55.45778356279646, 55.32445110593523, 46.36175434929984, 22.543037755148752, 44.66221802575247, 37.57437106541225, 6.653396078518458, 5.698874703475407, 3.562718140227454, 7.813741769109454, 48.772101811000276, 32.61733858925955, 34.74357073647635, 15.56080515044076, 11.741649627685547, 25.19885638781956, 18.432634592056274, 21.412609270640782, 27.686221156801494, 21.672906160354614, 15.127972330365862, 40.833305495125906, 28.418901750019618, 29.98946734837123, 26.054834502083914, 14.770492724009923, 13.031939659799848, 18.530765737806046, 16.76548729624067, 21.29281711578369, 7.02271671806063, 2.4687294832297733, 0.19967282563447952, 0.3241124025412968, 0.04297564983634012, 0.15708819856601103, 0.05409477943820613, 0.17465403170457908, 0.15187980447496685, 0.8561828689915794, 3.0543890169688632, 1.316656925848552, 2.38578753386225, 1.7916044060673033, 1.3889699769871575, 0.8484547351087842, 0.3007130409990038, 0.3171784531857286, 0.3938692494162491, 0.7831499193395887, 0.72291278306927, 0.5788269575153078, 0.3882206082344055, 1.383603144969259, 0.316474296684776, 0.06913317141256162, 0.08433224047933306, 0.11485973452883107, 1.3414027179990495, 0.2541834520442145, 0.12376839720777102, 0.050575784873217344, 0.3319926368338721, 3.56780834708895, 5.053473472595215, 14.822484357016426, 22.605142491204397, 36.60169274466378, 10.59038349560329, 20.613587277276174, 27.888903583799088, 30.845384665897914, 24.383526972361974, 27.365834508623394, 20.328315087727137, 9.891823768615723, 23.071555955069407, 21.335227182933263, 19.796574660709926, 20.278909921646118, 19.667987823486328, 17.926157815115793, 13.037978512900215, 5.420515537261963, 33.065719740731375, 50.4754353250776, 39.871494156973704, 56.05407796587263, 26.38701571737017, 0.3163696394434997, 1.5503569798810142, 9.090544479233877, 29.973222460065568, 48.53085340772356, 48.65662969861712, 59.164480754307334, 46.53008140836443, 45.75510365622384, 49.48086323056902, 50.24911512647356, 51.32790981020246, 43.09243931089129, 21.260973521641322, 51.296594279153005, 46.78983286448887, 43.05084044592721, 47.559450081416536, 54.22718463625227, 32.18211037772042, 15.936131204877581, 32.3223215511867, 26.42437618119376, 27.287920883723668, 40.70865828650338, 15.121519190924507, 46.14270544052124, 62.980396679469514, 23.503261429922922, 35.34942586081368, 51.433633599962505, 33.00859860011509, 0.15974260041756289, 0.1024708996659943, 0.11376901662775449, 0.053897637873888016, 0.12136635610035487, 0.036365205621612925, 0.02669639203564397, 0.08320285965289388, 0.11573219485580921, 0.04013842011668852, 0.07852918508329562, 0.07405578690980162, 0.04529086560277002, 0.030128484924456904, 0.175282409414649, 0.07913036032446794, 0.025545126758515835, 0.06135106685438326, 0.026310702553018928, 0.07260596113545553, 0.13411264999636582, 0.07407385629734822, 0.028110654093325138, 0.07921966231827225, 0.032452735384660106, 0.038549443773393116, 0.13481341382222517, 0.0476786846161953, 0.13798955482031616, 0.0027807582186401953, 4.14296372447695, 73.3108046395438, 59.74780287061419, 48.2884133883885, 49.26892580304827, 41.38741391045706, 33.23615557806832, 51.31321437018258, 32.009239196777344, 31.3893278666905, 29.05148833138602, 20.01209909575326, 40.20146063395909, 23.82552409172058, 30.778640270233154, 9.566929476601736, 43.08161401748657, 79.7177802494594, 42.01188325881958, 13.180769205093384, 19.671069349561417, 52.841946601867676, 63.53518254416329, 51.59285504477364, 61.24903760637556, 61.191159112112864, 56.28207268033709, 51.34776081357683, 25.544506686074392, 50.57829993111746, 40.88529886518206, 8.053683911051069, 1.149621688893863, 1.4658918551036288, 13.223926203591482, 52.504444803510395, 36.80985730034964, 51.309792382376536, 28.17138433456421, 15.622374875204903, 23.64745913233076, 19.498646327427455, 21.257935421807424, 24.394532918930054, 28.451554809297832, 20.24759786469596, 29.592926706586564, 33.557746001652305, 32.12143175942557, 27.93317403112139, 25.669511726924352, 17.30780288151332, 18.757619210651942, 19.143595116479055, 24.1910514490945, 16.345687559672765, 3.084550929921014, 0.45959814957209993, 0.4205969066492149, 0.05719432061804192, 0.0067934743710793555, 0.015686720310311233, 0.06350836038057293, 0.13440275085823877, 1.0166904905012675, 1.9340056734425681, 3.3686087046350752, 3.145665547677449, 2.122428225619452, 2.823022472006934, 1.0078749635389872, 0.3019213761602129, 0.1836844099951642, 1.3615737727710178, 2.180852153471538, 1.4272806069680621, 1.8562182017735072, 1.1873867767197746, 3.975270688533783, 0.8802423094000135, 0.29910456016659737, 0.04447393997439316, 0.14381838776171207, 0.14597990177571774, 0.13974396139383316, 0.11777565734727041, 0.023818116036376784, 0.5255810118147305, 2.9916578573840003, 9.750490461077009, 30.004774229867117, 25.048401832580566, 30.876714093344553, 16.295254060200282, 27.154840299061366, 25.896401677812847, 30.807794911520823, 28.103099175861903, 25.086165291922434, 12.497683116367885, 14.798872641154698, 21.540497813905986, 17.309268951416016, 17.852044854845317, 17.138520445142472, 20.346555846078054, 22.124813522611344, 15.847755329949514, 11.632687977382115, 57.50497647694179, 55.09660925183977, 40.877568994249614, 58.900247710091726, 34.47436278206961, 7.462187239101954, 1.5056659494127547, 4.527000214372363, 35.269490310123985, 50.45531334195818, 51.82907295227051, 65.1172456741333, 47.96449531827654, 46.742414883204866, 54.93624830245972, 54.40567690985543, 54.89796372822353, 45.71310526984078, 25.454348598207744, 52.609668322971885, 48.94246121815273, 45.45688349860055, 54.330889974321636, 57.52792290278843, 37.722843647003174, 22.56402131489345, 28.07564684322902, 27.81297540664673, 26.75895799909319, 36.65744161605835, 22.404521942138672, 39.70653002602713, 70.89517307281494, 26.10804033279419, 36.64583812441145, 61.795006207057405, 31.119487626211985, 0.26751517238361494, 0.08418862854263612, 0.07436513102480344, 0.08593095040747098, 0.059203856358570714, 0.05715457882199969, 0.005648838381083416, 0.10062968810754162, 0.08142323871808392, 0.09284128674439021, 0.007194088655523956, 0.05981341150722333, 0.06929538877946989, 0.08969558482723576, 0.34126180516821997, 0.2875231887613024, 0.12994367655898842, 0.22027903848460742, 0.1412460615060159, 0.1701307272804635, 0.28968958822744234, 0.24154695868492126, 0.2087245506367513, 0.15817898432058947, 0.11727523777101721, 0.1055777215265802, 0.2435179129242897, 0.271916747625385, 0.18212494653250488, 0.1731384287455252, 6.628891084875379, 90.51891476767403, 65.33646828787667, 66.48888955797467, 60.91453048161098, 55.47981630052839, 44.30194698061262, 64.22830704280308, 67.80409322466168, 34.35555553436279, 43.914901052202495, 34.87206724711827, 59.687492506844656, 20.64283571924482, 33.14298023496355, 8.846964086805071, 51.05760751451765, 85.20834405081612, 39.26482261930193, 12.960833532469612, 22.439448799405778, 57.364105224609375, 66.16734777178083, 53.02412142072405, 58.85040133340018, 65.88977418627057, 61.655222347804475, 56.17482376098633, 25.873655012675695, 51.35454225540161, 44.238933767591206, 11.127634712627955, 12.26243621962411, 8.14963071686881, 13.921728576932635, 60.39777905600411, 40.33523082733154, 50.24333075114659, 20.908722434725078, 19.14470682825361, 28.528106587273733, 24.92201410021101, 25.337009157453263, 35.78338255201067, 25.217194420950754, 18.328451565333776, 48.959710121154785, 36.33690731866019, 35.90114409582955, 31.27254949297224, 21.27201247215271, 19.67088348524911, 26.765204429626465, 29.10758634975978, 34.62592731203352, 28.3817549433027, 13.639487539018903, 0.7055068942052978, 0.8046018853783607, 0.2683761790394783, 0.5511950573750904, 0.21213880314358644, 0.4838014394044876, 0.3536306300333568, 1.955902052777154, 3.857605985232762, 2.8486150758607045, 4.109020037310464, 4.770214089325496, 4.35642671585083, 1.274874585015433, 1.2129444224493844, 1.4112733687673296, 3.8428336807659695, 2.5111764626843587, 2.6279691670622145, 4.106779677527292, 3.171061864921025, 3.965871947152274, 0.7297290744526046, 0.4283582344651222, 0.1210635666336332, 0.21720679476857185, 1.4513646917683738, 0.45728890491383417, 0.30893522979957716, 0.23820327382002557, 0.7321183862430709, 8.276120935167585, 22.154701198850358, 35.35096141270229, 32.25615733010428, 51.756617137363975, 16.392978736332484, 24.341983692986624, 31.132783004215785, 33.2377884047372, 28.823311226708547, 32.045015471322195, 29.351403849465505, 15.409655775342669, 32.743601254054475, 27.77211478778294, 26.188807930265153, 24.761107717241558, 25.275522811072214, 26.397979974746704, 16.707579272133962, 6.263055835451398, 44.46095650536673, 56.00603117261614, 45.34092501231602, 61.71943759918213, 36.082978452954976, 3.5000853410788944, 3.1099420360156467, 10.476677094187055, 41.099581309727256, 53.740195819309776, 52.36438649041312, 66.98925713130406, 51.89219733646938, 51.66827426637922, 58.10637433188302, 56.897537163325715, 59.10296835218157, 51.525662490299766, 27.911334105900355, 57.09741946629116, 56.09827545710972, 53.969083377293174, 56.87922518593924, 61.861618586948936, 40.5048954146249, 23.288329328809464, 43.04550770350865, 36.3608021736145, 38.46034976414272, 57.77273573194231, 24.243149042129517, 59.65093108585903, 78.12431512560163, 35.313594000680105, 51.75603001458304, 64.03251375470842, 54.77322619301932, 0.5215153928313936, 0.21960534820599215, 0.23681064854775155, 0.1363397240638733, 0.3386058562568256, 0.20648256236953394, 0.15613888736282075, 0.3852018602192402, 0.2123937966035945, 0.15390239522925445, 0.12896187709910528, 0.18658275875662053, 0.14401947839983872], [0.03037579736805388, 0.022999760395448123, 0.019151260743715932, 0.09431266957627875, 0.019902354904583523, 0.030351095300699984, 0.01547560770995915, 0.03925985297454255, 0.05855757210935865, 0.07693348106529031, 0.0717791390738317, 0.011567731155082583, 0.14564071569059575, 0.0816464563831687, 0.25506459761943134, 0.06797058986765997, 0.1754554629858051, 0.24126126830066952, 24.784446716308594, 82.47950158800397, 43.88124745232718, 47.4123706136431, 42.88071032932827, 40.01943520137242, 17.526582547596522, 38.93354640688215, 28.7878007207598, 32.631182874952046, 26.173612219946726, 40.63744967324393, 21.69091762815203, 32.48469400405884, 63.01289340427944, 62.53638594491141, 76.5730950491769, 51.38705287660871, 35.949736322675435, 12.217238187789917, 27.631184475762502, 59.544637543814524, 36.70547103881836, 34.41156843730381, 50.31863185337612, 53.87094702039446, 42.60904966081892, 24.601097651890345, 45.25050115585327, 34.81784003121512, 4.068459928035736, 1.1100404070956367, 8.41469841344016, 51.3550112588065, 44.44871377944946, 42.09221485682896, 17.176933561052593, 8.719086834362574, 23.715204068592616, 20.175008296966553, 28.01741746493748, 24.081598213740758, 27.03061866760254, 14.083770990371704, 12.666928206171308, 33.001525333949495, 27.863659041268484, 23.010826962334768, 25.026454210281372, 11.993884869984218, 18.4994832106999, 22.784393855503627, 17.404982124056133, 20.849028723580496, 6.648671737739018, 2.2253223615033284, 0.37264733389019966, 0.08914822419839245, 0.1206050126680306, 0.03169445553794503, 0.036881642016981325, 0.044673056075615544, 0.2679332313793046, 0.39451079070568085, 2.2910312584468295, 1.5082266862903322, 1.876713216304779, 2.078274812017168, 3.803580267088754, 2.2219976484775543, 0.9764579236507416, 1.6432020664215088, 0.6472637823649815, 1.5445524113518851, 2.518904162304742, 1.2858134380408694, 1.8925477266311646, 0.969194124851908, 0.1534748367433037, 0.10672022522028003, 0.5085770870958055, 0.7909828733120645, 0.11418536571519715, 0.22301827078419073, 0.24141507861869677, 0.06419129230614219, 0.21943614871374198, 0.8686017968824932, 1.3715033999511173, 15.15555146762303, 20.786833660943167, 33.77658299037388, 20.46603012084961, 5.593431881495884, 29.331083842686244, 31.592493193490164, 30.676856109074183, 25.042674779891968, 34.70753043038504, 17.567078386034282, 12.37789009298597, 17.96128269604274, 23.47601580619812, 20.406940902982438, 20.527750968933105, 17.329962423869542, 19.492749043873378, 20.680382047380718, 4.34797249521528, 34.367159026009695, 57.73961366925921, 41.17179046358381, 47.525501183101106, 10.698603425707136, 0.2912120579608849, 18.642244373049053, 57.49193818228585, 33.61022227151053, 50.925424984523225, 52.91634791237967, 52.59528207778931, 37.11440379279, 46.6115768296378, 50.78593642371041, 51.96752623149327, 44.404853275844026, 34.880898407527376, 56.231288296835764, 50.18284668241228, 49.0726044518607, 47.27014446258545, 48.22689751216343, 26.485223293304443, 16.781059946332658, 35.50806018284389, 24.28551047188895, 35.620336123875205, 35.92502852848598, 24.542394059044973, 69.19481686183384, 42.15869174684797, 23.29612694467817, 39.01046296528408, 47.27743659700666, 2.985847209181104, 0.038697720638343265, 0.08398373132305485, 0.019040630697937946, 0.08591141538428408, 0.06697382192526545, 0.03241521579080394, 0.030267981546265737, 0.02844481053762138, 0.08351645139711243, 0.027324267629800097, 0.0466487193480134, 0.08486047999135085, 0.04672779581908669, 0.04897567377026592, 0.08779411257377692, 0.005969071286796991, 0.019957862461784055, 0.041746344550379684, 0.07819847390055656, 0.06723291373678617, 0.024795428683449115, 0.12682479034577096, 0.09652500586318118, 0.042265705431678464, 0.02024282681356583, 0.19801816370870384, 0.08745992729174239, 0.3331597442073481, 0.03661313553207687, 0.14569951753531182, 0.3297577053308487, 28.772042206355504, 89.25662163325718, 48.53439004080636, 43.1783572605678, 46.90167801720755, 25.986122029168264, 17.556171451296123, 20.743687084742955, 21.718835490090505, 34.7156355040414, 21.430137838636124, 34.63611684526716, 27.53101055962699, 34.23383699144636, 42.07557392120361, 66.02914115360805, 77.2119471686227, 51.04531615121024, 39.157841205596924, 15.252980845315115, 27.550449882234844, 68.63040774209159, 39.279952321733745, 35.82146215438843, 56.92942592075893, 55.91495418548584, 47.86025844301496, 29.4583192552839, 45.46326541900635, 37.60435254233224, 3.337595420224326, 0.4603078972016062, 14.688538721629552, 58.094326155526296, 49.82640062059675, 54.09931346348354, 33.898902552468435, 12.719831790242877, 23.500878197806223, 20.51640108653477, 26.792934690202983, 23.542101860046387, 25.986005646841868, 18.222745146070206, 18.475112404142106, 37.45278106416975, 30.15081146785191, 27.735874720982142, 30.10417515890939, 20.405952521732875, 20.751232828412736, 21.84040812083653, 21.52329581124442, 23.62412187031337, 20.378529718944005, 5.6380840454782755, 0.7587520799466542, 0.022277100244536996, 0.14186872595122882, 0.11846591745104108, 0.02762920635619334, 0.09420480286436421, 0.17657254875770637, 1.1763524945293153, 3.3133577150957922, 2.8649242350033353, 1.666432934147971, 2.667649243559156, 5.287959975855691, 2.148489615746907, 1.2758857650416238, 1.0775519332715442, 2.7455320358276367, 1.8405673844473702, 3.2509539893695285, 3.7689148357936313, 2.451192012854985, 1.7604130740676607, 0.37052129368696896, 0.09020456073007413, 0.3326356980417456, 0.31978085211345125, 0.08383305583681379, 0.16359942060496124, 0.22344428221029894, 0.4293323393378939, 0.31626834773591583, 3.2270009432520186, 5.915645471640995, 30.68297052383423, 25.525383506502422, 35.017065729413716, 21.16922082219805, 12.373160975319998, 32.23135573523385, 30.760008675711497, 31.701642445155553, 29.18045731953212, 25.977443729128154, 14.880463600158691, 17.494455814361572, 19.750445570264542, 19.734872920172556, 17.749296631131852, 15.842985391616821, 15.677960463932582, 22.415279490607126, 22.096883501325333, 10.098064541816711, 60.37619795118059, 64.07046481541225, 43.20480557850429, 48.61764335632324, 17.07185595376151, 5.471538765089853, 12.689331804003034, 56.204680170331685, 39.93179062434605, 49.54701355525425, 54.25911855697632, 56.61191756384713, 37.28328323364258, 49.049678870609824, 55.407648835863384, 55.970251423971995, 47.7361010823931, 39.383848735264365, 57.978506633213584, 54.138435295649934, 56.02376644951956, 52.33997746876308, 51.113172258649556, 35.30218505859375, 22.071880408695765, 30.02848843165806, 25.336093732288905, 27.696573972702026, 32.03795262745449, 28.653233221599034, 62.61020360674177, 53.10923685346331, 24.96830299922398, 46.02353341238839, 47.95824193954468, 3.1207256402288164, 0.24841929706079618, 0.09683156798460654, 0.06508007140031882, 0.055226022843271494, 0.07038398286593811, 0.08699167027537312, 0.048398837580212524, 0.05903491470962763, 0.03942621958308986, 0.029822686154927527, 0.08308410923928022, 0.03154912351497582, 0.02575121141437973, 0.12392908787088734, 0.10682454997939722, 0.11658641616148607, 0.1714920313762767, 0.09036384004035167, 0.17083123326301575, 0.1772282307169267, 0.096443968425904, 0.21878661428179058, 0.18840311893395015, 0.1690848876855203, 0.18066853896847793, 0.2823995979768889, 0.1411276842866625, 0.3655417151749134, 0.20271008408495358, 0.6021995576364654, 0.4094223305583, 40.66089289528983, 100.77112075260708, 56.983031272888184, 62.881621088300435, 62.01354094914028, 54.02088567188808, 27.820446457181657, 57.3567019190107, 42.27015127454485, 42.78717367989676, 40.57225125176566, 53.83713708605085, 27.699735403060913, 45.36224208559309, 72.31084769112724, 75.25534834180559, 88.62591975075858, 59.134256090436665, 43.47539969852993, 17.741702250071935, 34.18006835665022, 74.52121557508195, 43.73290341241019, 39.71204342160906, 57.20258740016392, 63.51735346657889, 50.155397823878694, 30.480941227504186, 53.3113807950701, 43.08782570702689, 8.27807251044682, 7.183278730937412, 11.905097314289637, 61.57639503479004, 54.43197931562151, 50.98816721779959, 25.422138486589702, 10.325777854238238, 28.698571954454692, 24.37296049935477, 35.32379395621163, 26.67486047744751, 34.249543394361226, 18.572699853352137, 18.621299028396606, 41.86945908410208, 34.35813331604004, 30.4948410987854, 31.720888955252512, 15.943181889397756, 27.04511955806187, 28.355362210954937, 31.329681055886404, 33.929714339120046, 34.34598786490304, 16.891161101205007, 1.461176416703633, 0.2111407866967576, 0.26874454213040216, 0.17659956802214893, 0.06849672592111997, 0.36789218762091225, 0.847040125301906, 1.4116973174469811, 3.474119705813272, 4.009365499019623, 3.9028548257691518, 6.655370669705527, 7.6790127243314465, 4.41939389705658, 1.7627731817109245, 4.067108503409794, 4.830167055130005, 1.7333938096250807, 6.409979403018951, 10.018678767340523, 4.520147553512028, 1.008083843759128, 0.3271324804850987, 0.17628863613520349, 0.8372088042753083, 1.893172630241939, 0.11973400440599237, 0.8529417514801025, 0.4915667027235031, 0.7447347949658121, 0.660713757787432, 7.004400398050036, 22.60742323739188, 33.180292061397004, 31.565926756177628, 45.56712014334542, 28.403516701289586, 7.9870228937694, 34.59322214126587, 36.718954018184114, 34.59844371250698, 29.813462529863628, 44.676180430821006, 28.906243188040598, 16.019334145954677, 25.984906094414846, 30.193872928619385, 29.722340379442485, 24.265454496656144, 22.932847329548427, 30.394054004124232, 26.40475967952183, 5.391068203108651, 46.426779065813335, 68.12803908756801, 47.150044849940706, 53.62256976536342, 15.047682421548025, 1.4238844577755247, 24.05590898650033, 71.38892596108573, 45.70288446971348, 57.26721954345703, 54.75055769511631, 57.43278816768101, 38.50433880942208, 49.103576047079905, 59.21803746904646, 57.185619899204795, 51.22984988348824, 42.61956923348563, 65.82323823656354, 57.77801636287144, 54.847467694963726, 55.1512325150626, 58.1047762462071, 35.19821916307722, 24.680739641189575, 48.71178797313145, 34.33745200293404, 48.53094026020595, 49.31014946528843, 35.833645820617676, 82.67112595694405, 55.59932879039219, 38.35094690322876, 51.34859459740775, 71.1905826841082, 8.151393822261266, 0.5793127885886601, 0.19209639861115388, 0.2140373576964651, 0.17676708474755287, 0.15772205883903162, 0.16956102927880629, 0.2150232826492616, 0.20090805792382785, 0.17564495067511285, 0.13970666910920823, 0.20856452493795327, 0.11788783275655337, 0.15254023617931775], [0.04980082663574389, 0.04633355000987649, 0.06871647627225944, 0.06722712583307709, 0.14681975170969963, 0.05892119902585234, 0.08388480770268611, 0.11623169162443706, 0.024646841388727938, 0.011595550242678394, 0.11234367918223143, 0.07382612316203968, 0.05165121877299888, 0.13413390171314987, 0.02885748366160052, 0.13794101242508205, 0.07975214267415659, 0.040438739715942314, 0.437442597001791, 43.19284078053066, 56.3364006451198, 41.06076519829886, 53.987391880580354, 69.11709431239537, 62.05617509569441, 59.11637142726353, 42.02903141294207, 30.240387644086564, 15.663212912423269, 38.574265480041504, 26.36315039225987, 53.01950086866106, 90.0620985031128, 43.23368576594761, 71.03461647033691, 55.85921573638916, 68.07587896074567, 15.231245143072945, 18.995268447058542, 44.2899682862418, 72.09790624891008, 77.34358773912702, 38.04699795586722, 54.921017851148335, 45.93484313147408, 28.677100283758982, 60.064765793936594, 28.06570049694606, 1.4517621504408973, 3.7620621749332974, 52.1893926348005, 51.71219730377197, 46.75695398875645, 26.87798237800598, 9.691548892429896, 23.063631534576416, 22.714284794671194, 24.504680974142893, 26.176052774701798, 29.390171323503765, 24.573414291654313, 25.235791274479457, 24.85689558301653, 20.55174309866769, 24.835974557059153, 21.84803897993905, 18.24583227293832, 11.954856838498797, 21.130390814372472, 20.78636118343898, 15.872395379202706, 20.990997791290283, 7.637214967182704, 2.9172435189996446, 0.07313259930482932, 0.24971668315785273, 0.1344200535012143, 0.16935907011585577, 0.057566062813358646, 0.13510963506996632, 0.5968467305813516, 0.22968052114759172, 3.7366621664592197, 4.337309181690216, 5.569645592144557, 3.9683459401130676, 3.870344638824463, 4.900828497750418, 5.061460861137935, 3.4741314308983937, 1.147117623261043, 1.7606213028941835, 3.595070472785405, 2.566844778401511, 1.222786328622273, 0.48805938235351015, 0.2744362838566303, 0.22808058985642024, 0.24651532779846871, 0.2708344842706408, 0.13916069269180298, 0.17044001711266382, 0.06197157355823687, 0.04842566346217479, 0.5750674392495836, 1.7429265209606715, 6.141764606748309, 15.876783166612897, 26.093379633767263, 28.094102995736257, 30.163568360464915, 11.761046392577034, 13.327472601618085, 33.005840165274485, 37.85694735390799, 30.953470843178884, 33.22131422587803, 32.9801596232823, 17.38235878944397, 14.932274580001831, 13.008989759853907, 21.440221411841257, 22.1823011807033, 24.008075850350515, 19.45860733304705, 16.916153771536692, 21.345503568649292, 3.6803048934255327, 29.658924170902797, 40.64719452176775, 41.72905683517456, 39.55764750071934, 4.971484294959477, 4.123426692826407, 38.650671345846995, 45.932452951158794, 36.685085024152485, 48.83760942731585, 53.49094309125628, 56.45166083744594, 43.55993843078613, 51.526128019605366, 52.97204119818551, 52.736643178122385, 53.95941495895386, 56.820995807647705, 51.944347040993826, 60.52479212624686, 47.84184224264962, 58.642580713544575, 17.683174099240983, 25.03705195018223, 29.826740537370952, 26.37878210203988, 41.640331813267295, 29.55951976776123, 44.46239825657436, 66.32122257777623, 22.369562080928258, 32.0105767250061, 49.12010581152779, 18.012883492878505, 0.2680845989712647, 0.0657945212775043, 0.044697486728961976, 0.04007855297199317, 0.05216105302263584, 0.030357052838163714, 0.08883798441716603, 0.050839599288467846, 0.05705099366605282, 0.013279533362947404, 0.0334083060733974, 0.07112645623939377, 0.021935327244656425, 0.1160022382225309, 0.09597337046372038, 0.07469848849411521, 0.0502098746863859, 0.10084749106317759, 0.06945737544447184, 0.029720586990671496, 0.05620056876380529, 0.1616218981466123, 0.05072291162131088, 0.0901587867577161, 0.03711899695917964, 0.11342238701347794, 0.010142766903819782, 0.0416595361727689, 0.12826245677258286, 0.08491991287363426, 0.0507978558141206, 0.06687506793865136, 0.9166130891868046, 47.95432315553938, 67.37056732177734, 41.15183523723057, 52.701370647975374, 52.66948536464146, 37.600082874298096, 44.25312546321324, 19.043909311294556, 29.94192429951259, 20.497430767331803, 29.30158179146903, 30.256924356733048, 52.80244609287807, 74.32235813140869, 52.68561560767037, 81.0364580154419, 57.31310197285244, 67.02538776397705, 21.00592773301261, 18.215939385550364, 49.91802651541573, 67.58682305472237, 59.681412833077566, 45.04022782189505, 60.226304462977815, 49.924366746629985, 33.77303940909249, 59.888434410095215, 33.091942242213655, 0.5140662725482668, 9.9274263381958, 56.003352642059326, 54.942352294921875, 57.54734659194946, 45.936441217150005, 14.616324356624059, 19.70696895463126, 22.653455053056987, 22.707166365214757, 25.53894465310233, 27.52145504951477, 24.56788526262556, 24.368006433759415, 21.701906204223633, 19.152096237455094, 30.119231905255997, 23.942330258233206, 24.513885600226267, 16.44798936162676, 21.277682202202932, 24.614219324929373, 19.73706681387765, 25.470155750002178, 21.500931297029766, 6.2371503455298285, 1.293478603873934, 0.15738452837935515, 0.07766806986182928, 0.05711492523550987, 0.04495778294014079, 0.09635306508945567, 0.1820935167904411, 1.7065996016774858, 2.702114914144788, 3.975877353123256, 5.050018046583448, 5.43719208240509, 4.107427162783487, 5.358151546546391, 5.546567150524684, 4.539536067417689, 3.9991868223462785, 1.8115770029170173, 4.659375122615269, 5.064861135823386, 3.231880098581314, 1.309690379670688, 0.3008181596440928, 0.22063516080379486, 0.12795592179255827, 0.1834234997097935, 0.10123009660414287, 0.18295864893921784, 0.08956542145460844, 0.11384290909128529, 0.9629460658345903, 5.1326373389789035, 14.13126540184021, 27.623518875667028, 31.558898653302872, 31.853835787091935, 24.629687752042496, 10.666974357196263, 21.308686801365443, 33.53862108503069, 39.32207924979073, 30.41432884761265, 33.51598385402134, 17.042513711111887, 19.415476390293666, 18.715683358056204, 18.629100118364605, 18.080343552998134, 21.046665021351405, 18.946514674595424, 17.171844005584717, 16.615345409938268, 23.577629736491613, 9.375662071364266, 57.15432868685041, 46.49434682301113, 46.287356512887136, 37.0386962209429, 12.241067034857613, 10.386057819638934, 30.06230878829956, 55.26001698630196, 37.46584020342146, 49.37987116404942, 53.10785068784441, 59.888691493443076, 45.91170910426548, 56.96690450395857, 54.70553684234619, 58.47183568137032, 56.20901584625244, 58.15364292689732, 55.32510423660278, 63.50478417532784, 54.221796308244976, 59.37898554120745, 26.116353852408274, 28.890111207962036, 25.07651945522853, 26.20707995550973, 25.1795369216374, 32.605113233838765, 40.32761560167585, 68.68144226074219, 32.604359354291645, 34.919082232883994, 57.85077095031738, 18.35800572804042, 0.29817244304077967, 0.19270120401467594, 0.07890163974038192, 0.0717640755964177, 0.11642924030976635, 0.04725782327087862, 0.054305868289832554, 0.07729628016906125, 0.03681852129687156, 0.0126011790042477, 0.08231887101594891, 0.012339521482187723, 0.016899023205041885, 0.12642407470515796, 0.15158963575959206, 0.18677588339362824, 0.1579161469957658, 0.2731002484049116, 0.2111260217747518, 0.14765204276357377, 0.14633122006697313, 0.19278393100414956, 0.12660437503031322, 0.1504532117396593, 0.12834025759782108, 0.271323735160487, 0.13996164899851593, 0.2819277990077223, 0.22796149338994706, 0.1787713821977377, 0.19387049627091202, 0.2092548936073269, 2.3797988380704607, 74.03240980420793, 71.06158242906842, 59.33830383845738, 69.66821152823312, 86.36876269749233, 75.81022453308105, 83.09271485464913, 58.57393251146589, 37.32356888907296, 24.187558242252894, 54.828283718654085, 32.19218873977661, 66.37149974278041, 102.78878034864152, 55.215857710157124, 85.8031723839896, 65.8467161996024, 79.59858390263149, 20.78597903251648, 22.71458877835955, 56.87431975773403, 82.21464320591518, 82.93731144496373, 48.06202718189785, 66.32029846736363, 52.414448261260986, 34.33517646789551, 71.22255829402378, 34.16419172286987, 3.2795297588620866, 6.494440836565835, 61.389676094055176, 58.711437361580984, 55.80068758555821, 37.60637446812221, 11.410835470472064, 26.54565003940037, 27.228548526763916, 29.795772416251047, 31.91729368482317, 34.76707649230957, 30.946654660361155, 35.93862615312849, 36.50338963099888, 27.40967243058341, 34.88688428061349, 29.606760569981166, 25.448704923902238, 14.386102744511195, 33.018041202000205, 29.161530426570348, 26.602286543164933, 31.29508944920131, 35.31026928765433, 18.265073571886333, 2.519971796444484, 0.8600566525544439, 0.2511704851474081, 0.19173696504107543, 0.19177005040858472, 0.14322525316051074, 0.668491886130401, 2.717794827052525, 5.160758435726166, 7.134733838694436, 11.126065288271223, 7.882903269359043, 7.038701048919132, 8.127855062484741, 10.142690215791974, 8.353595086506434, 5.684932274477823, 2.7492121926375797, 7.807670780590602, 9.011163915906634, 6.610686804567065, 2.173524843794959, 0.3566348845405238, 0.29533429390617777, 0.4268793538212776, 0.433544820440667, 0.2954700823341097, 0.2095694760126727, 0.3186152103756155, 0.16692986046629293, 2.0129975719111304, 7.174257363591876, 28.291756664003643, 34.34575162615095, 39.01029968261719, 39.395143032073975, 42.49810777391706, 16.95835712977818, 17.013101986476354, 37.23589651925223, 44.08162655149187, 34.436533314841135, 37.379821504865376, 41.26271111624581, 28.12800325666155, 19.10572396005903, 17.519616978509085, 28.29823064804077, 31.848635060446604, 28.915807383401052, 24.66487169265747, 24.318087100982666, 28.417242867606028, 5.313999218600137, 43.980578899383545, 49.57600491387503, 53.79014294488089, 48.06109959738595, 10.280900308064052, 6.433324481759753, 43.48730196271624, 55.797237804957796, 45.708488191877095, 53.67709922790527, 55.218678678785054, 62.73196383884975, 46.49611861365182, 58.317787170410156, 60.01853248051235, 58.9298539842878, 62.11901460375105, 65.42639187404087, 60.297384534563335, 64.27624266488212, 55.944817543029785, 68.17921257019043, 26.337019954408916, 36.246035303388325, 45.553070885794504, 34.74801063537598, 56.55110692977905, 44.94360269818987, 58.98969881875174, 81.29801600319999, 38.02281127657209, 48.894476958683555, 67.73351342337472, 35.43830721718924, 0.34381743946245735, 0.3651330199624811, 0.1595964982573475, 0.23347844449537142, 0.22829109856060573, 0.176944833781038, 0.24821910208889417, 0.28624235891870087, 0.2063879474465336, 0.13566990143486432, 0.1758199312857219, 0.2539718034011977, 0.11446838267147541, 0.16918950421469553], [0.08102328982204199, 0.02076824361990605, 0.1793242661016328, 0.04435952539954867, 0.03396355467183249, 0.06257270808730807, 0.0748891704050558, 0.06866853098784174, 0.007612005158859704, 0.04385382342817528, 0.0013872275262006692, 0.05748999903776816, 0.015155581757426262, 0.1325722669384309, 0.05484800419903227, 0.21250276932758944, 0.028605234875742878, 0.07157371938228607, 0.345219618507794, 14.66266884122576, 73.79811654772077, 41.824021339416504, 43.660405908312114, 79.95265715462821, 76.57587432861328, 45.90813078199114, 48.736051082611084, 37.984971387045725, 19.284838097436086, 24.95739085333688, 36.239653382982524, 17.132348707744054, 50.166264806474956, 52.95239864076887, 61.061158316476, 47.02055474690029, 62.801056725638254, 41.044099943978445, 13.999215756143842, 32.43674101148333, 53.07558672768729, 73.01876490456718, 62.230053765433176, 53.01119429724557, 53.958014896937776, 52.446972778865266, 54.692429065704346, 17.783526931490215, 0.9133540583508355, 35.5215779032026, 65.93577126094273, 44.48644944599697, 39.712491580418174, 11.787630200386047, 20.546325240816387, 24.52589556149074, 21.420064687728882, 23.646779945918492, 26.25759162221636, 28.685260943004064, 25.845928226198467, 21.572864259992325, 18.776007618222916, 17.99102967126029, 14.506148508616857, 18.49826032774789, 12.499899591718401, 13.61263188294002, 25.839791229793004, 17.534427063805715, 18.51976500238691, 24.753556762422832, 8.758567367281232, 1.2054529615810938, 1.970103302172252, 0.7023239135742188, 0.07078985537269286, 0.14685050291674479, 0.11328316519835166, 0.049526192979621034, 0.454167372414044, 1.0297869763204028, 6.145635621888297, 6.582370289734431, 6.75554632289069, 4.1572070973260065, 2.6222848892211914, 9.068935581615992, 11.958674005099706, 7.684896980013166, 4.589316870485034, 1.943150588444301, 2.5372337273189, 2.584907272032329, 1.9985987331186021, 0.8033742255398205, 0.41831518337130547, 0.07211084091769797, 0.1081048980621355, 0.08140442972736699, 0.756204642355442, 0.20067557825573853, 0.19567594224853174, 0.05262304376810789, 0.5282815269061497, 2.5031832115990773, 13.905125856399536, 15.865678208214895, 23.47409462928772, 30.013667924063547, 29.953972475869314, 23.809204510280065, 13.714133773531232, 27.83593225479126, 33.53710290363857, 38.29657030105591, 34.35563543864659, 36.68442841938564, 25.836669751576014, 21.05069671358381, 14.329331619398934, 12.121527620724269, 20.54587013380868, 22.14922080721174, 26.68734986441476, 25.868367433547974, 21.50544936316354, 22.074946301324026, 4.297438246863229, 25.757990087781632, 28.221699714660645, 46.5026672908238, 32.33253192901611, 0.6155918847237314, 7.798524345670428, 42.8261148588998, 36.63152830941336, 32.74666540963309, 44.29740285873413, 44.73173475265503, 55.384507860456196, 50.81171076638358, 50.93496486118862, 51.49387795584542, 51.54150785718645, 52.39661570957729, 46.695045539310996, 35.730690887996126, 54.50949689320156, 45.50180360249111, 21.074619361332484, 22.75898081915719, 28.13425142424447, 25.13497117587498, 48.91179881777082, 31.930401461465017, 67.51898084368024, 37.62785829816546, 16.358229058129446, 31.785805974687847, 25.42946536200387, 1.1033206305333545, 0.15264866607529776, 0.06460048284913812, 0.11380431401942458, 0.0154332603394453, 0.03841505652027471, 0.03166812498654638, 0.0445820577442646, 0.08186369615473918, 0.04618236222969634, 0.041792240659041066, 0.06291686104876654, 0.03298701725101896, 0.05380717558520181, 0.060512397571333816, 0.10784496486719165, 0.07174948030816657, 0.16821413726678916, 0.08901067836476223, 0.023564462683030536, 0.03346022757302437, 0.15224394707807473, 0.03919091720932296, 0.046224234625697136, 0.05337224481627345, 0.04225671823535647, 0.12131496385804244, 0.09728543327323028, 0.27945440315774506, 0.06981266316558633, 0.2290013347353254, 0.14265396738690989, 0.021611588009233986, 0.45981462938444956, 21.779279606682913, 87.2916293825422, 45.19412694658552, 46.93009614944458, 92.77179867880685, 72.61713818141392, 58.68359592982701, 40.8044114112854, 28.037377902439662, 25.115682976586477, 22.763413769858225, 35.47074488231114, 25.876130308423722, 50.0645431791033, 60.431373596191406, 69.24932547977993, 52.330778053828645, 65.18062019348145, 43.84871598652431, 18.783546413694108, 33.50783014297485, 60.52762699127197, 67.6024148123605, 64.94411740984235, 58.7728385925293, 53.095726081303184, 41.44123813084194, 62.421372413635254, 15.24596837588719, 3.4760851774896895, 46.65417970929827, 68.08557864597866, 56.21566179820469, 57.03446878705706, 20.29359667641776, 17.392147064208984, 25.08816637311663, 20.214156184877666, 23.82099039213998, 27.17900265966143, 25.93347552844456, 25.284128155027116, 20.266060965401785, 18.1197224685124, 19.155632870537893, 12.911496111324855, 23.363927466528757, 15.044208322252546, 15.530842781066895, 26.266268185206822, 18.605795860290527, 22.957490852900914, 30.486242703029088, 25.319454533713206, 9.945378746305193, 3.44194780928748, 0.7140489986964634, 0.11484530887433461, 0.010666553529777696, 0.16128111071884632, 0.08804415951349906, 1.1277231382472175, 0.7635494853769029, 5.803180626460484, 8.988900150571551, 8.434985416276113, 6.102631483759199, 2.2730764618941715, 11.291730318750654, 12.545866268021719, 11.080412149429321, 6.2153356075286865, 2.033648920910699, 1.4726230310542243, 3.93560038294111, 3.3674631203923906, 1.5551550367048808, 0.6496605851820537, 0.029918583509113108, 0.039216335131121535, 0.11233557068875857, 1.7772746149982726, 0.025615136305402433, 0.24786270835569926, 0.23728290892073087, 0.9854446585689272, 7.020363450050354, 17.84738608769008, 24.731094973427908, 33.865374020167756, 26.983961514064244, 27.87741300037929, 28.956555094037736, 21.71284440585545, 29.435018471309117, 37.45969104766846, 36.51805033002581, 32.97831835065569, 28.093745163508824, 14.923559801919119, 18.36088923045567, 16.06872888973781, 14.81829285621643, 18.88395483153207, 19.363232885088237, 23.96400168963841, 23.834252766200475, 18.049875702176774, 25.152577911104473, 10.901047008378164, 47.866074085235596, 36.71557024547032, 42.4455064364842, 24.90179831641061, 8.83113261631557, 11.419673579079763, 32.72339589255196, 44.23264912196568, 36.36383506229946, 47.076324462890625, 47.09619631086077, 60.98123318808419, 53.59667035511562, 55.793329443250386, 53.2339882850647, 58.84280000414167, 54.680877685546875, 53.49272183009556, 40.51500851767403, 61.51666831970215, 48.77601712090628, 32.03934226717268, 18.202378238950455, 29.28261320931571, 21.751702206475393, 38.19979231698172, 40.10770511627197, 62.68516077314104, 50.07980489730835, 21.47631730352129, 40.11463247026716, 29.05316284724644, 1.4718335419893265, 0.21614889082099709, 0.034651100635528564, 0.05344722632850919, 0.10498696858329432, 0.10146830989313976, 0.03663106242726956, 0.05993187015077897, 0.09445725860340254, 0.0573716489598155, 0.030077811929264238, 0.061597320783351145, 0.03557893281270351, 0.02176151710695454, 0.04337711865082383, 0.2621271972145353, 0.14736287828002656, 0.1875460206397942, 0.13081715468849453, 0.12689632150743688, 0.08549243358096906, 0.3027244359254837, 0.10997695582253592, 0.1380911586540086, 0.10002632119825908, 0.15814941376447678, 0.18150693683751992, 0.19176150086734975, 0.3963203350348132, 0.19142103913639272, 0.3133640821490969, 0.3145676404237747, 0.16000983464930738, 0.616416657609599, 34.68482024329049, 97.6610028403146, 55.238213539123535, 58.591282163347515, 94.77964741843087, 88.66031333378383, 60.86988830566406, 69.55479608263288, 46.304737431662424, 26.618402889796666, 42.056796414511545, 44.92489814758301, 24.168832847050258, 60.182496070861816, 62.79895836966378, 77.00198650360107, 58.56139101300921, 73.9308340890067, 49.111413615090505, 20.34549103464399, 40.12368597303118, 66.28266702379499, 83.0971964427403, 73.9375113078526, 64.58852250235421, 56.259484086717876, 56.163664954049246, 68.91520745413644, 24.809079817363195, 1.3101001062563487, 43.56160599844796, 76.87552234104702, 51.924812180655344, 47.13558217457363, 13.773698943001882, 23.466211897986277, 29.648644311087473, 27.11076613834926, 29.420111111232213, 35.101632254464285, 33.10297250747681, 36.76619482040405, 32.633256912231445, 27.47244245665414, 27.418550491333008, 18.563609872545513, 25.160599606377737, 19.52185157367161, 19.064804281507218, 38.24804755619594, 25.488896778651647, 36.59159353801182, 36.210241658346995, 39.7467496735709, 14.62456144605364, 7.279389687946864, 1.0776849261351993, 0.20517247409692832, 0.0993694043053048, 0.2245333037738289, 0.17598200616027626, 0.9955449508769172, 1.5814336666039057, 7.782507010868617, 11.133116841316223, 15.191362483160836, 8.05516995702471, 6.095871755055018, 14.073069896016802, 18.59963628223964, 14.984087296894618, 8.901520473616463, 6.138416009289878, 6.403901032039097, 6.616632291248866, 5.993557793753488, 3.7539397307804654, 1.232918756348746, 0.21444857705916676, 0.16967716733259813, 0.2230979443660804, 2.0797222086361478, 0.5431964322924614, 0.8760224186948368, 0.22852652307067597, 1.2131997687476022, 10.081628578049795, 29.82859570639474, 38.65777587890625, 35.72260665893555, 44.65308461870466, 39.04662833895002, 32.85741622107369, 16.935344696044922, 31.150813579559326, 39.36679090772356, 43.077688285282676, 36.08121708461216, 41.34431423459734, 34.356997285570415, 26.909231901168823, 18.647453784942627, 14.418001924242292, 25.02458688191005, 32.37903274808611, 31.01773473194667, 33.05531481334141, 26.363270248685563, 30.2695666040693, 7.311971528189523, 34.86052628925869, 39.53527430125645, 56.60599422454834, 37.881846223558696, 5.084987895829337, 9.865564789090838, 51.39876406533377, 43.03994219643729, 38.800231320517405, 47.859977040972026, 51.51270409992763, 61.0311837877546, 55.56032855170113, 56.99778577259609, 59.02237619672503, 60.768951824733186, 60.975903919764924, 54.667019503457205, 46.38250861849104, 64.78703253609794, 56.76471539906093, 32.31556790215628, 34.25083228519985, 41.690164293561665, 34.45685332162039, 67.00013106209892, 46.68619006020682, 86.06844765799386, 54.408622946058, 31.9913649559021, 50.87174667630877, 56.46326780319214, 4.350205906799861, 0.6671683628644262, 0.31816754011171205, 0.15726144212697232, 0.18372840620577335, 0.31915839122874395, 0.16327851425324166, 0.1156527791172266, 0.23589945744190896, 0.17093086934515409, 0.16947318613529205, 0.21856495046189853, 0.22417423661266053, 0.18789010574775084, 0.11000953228878123], [0.1083132354542613, 0.20606568402477674, 0.08288319502025843, 0.07869417765843016, 0.08121773081698588, 0.01959756375955684, 0.07732510433665343, 0.02576804077917976, 0.07322377405528512, 0.06094673462212086, 0.03260773313896997, 0.0733081159581031, 0.054381867604596276, 0.03734128163861377, 0.0628138662182859, 0.11257933439420802, 0.01906400453299284, 0.081240658515266, 0.02284403660866831, 3.6756782616887773, 61.950638907296316, 59.95332363673619, 45.97070973260062, 44.84664406095232, 66.45539229256767, 17.919331210000173, 29.439784935542516, 53.00765766416277, 22.323393038340978, 20.914664881569998, 43.19625929423741, 21.360332761492046, 46.73617540087019, 51.63779946735927, 66.17171818869454, 67.27113859994071, 57.477520670209614, 65.57643127441406, 35.56574065344674, 25.60330581665039, 65.00838129861015, 44.4816551889692, 56.209464005061555, 54.4574270929609, 54.42795630863735, 60.24687113080706, 42.81010273524693, 5.579853364399501, 8.641518013817922, 51.498213631766184, 44.50519221169608, 35.73183386666434, 18.969964844839915, 15.732936348233904, 25.7158979007176, 22.787398951394216, 23.102313893181936, 24.630528484072002, 25.737234081540787, 33.86271980830601, 24.542616401399883, 19.80886254991804, 10.81920678274972, 7.980646184512547, 7.536427003996713, 10.279670476913452, 6.5834077426365445, 16.879370008196148, 21.72386598587036, 20.784596340996877, 29.421160289219447, 26.838935238974436, 13.735872949872698, 2.322071684258325, 2.1677306975637163, 1.4481145633118493, 0.7832846492528915, 0.46887969438518795, 0.4934075410876955, 0.16619704264615262, 0.3459366671741009, 0.6886783572179931, 2.995779876198087, 3.2252028797354018, 3.3907702011721472, 1.8098318108490534, 2.656292195831026, 12.514998027256556, 18.02228614262172, 8.311591488974434, 5.112495814050947, 1.5281495600938797, 3.0899568455559865, 1.4173915833234787, 1.0390305774552482, 2.7230092329638342, 1.0497544705867767, 0.09288319985249213, 0.07533821809504714, 0.04922977834939957, 0.23946211912802287, 0.18462549735392841, 0.2646019772759506, 0.23807174659201077, 0.5133853490863527, 3.2509155571460724, 7.880729351724897, 15.885225227900914, 20.787083796092443, 33.311623437064036, 22.987102338245936, 13.189236453601293, 14.974934782300677, 27.90298410824367, 35.015578814915244, 34.89408261435372, 35.71555771146502, 30.617118971688406, 28.002834933144705, 21.042721918651036, 24.45550683566502, 12.964762738772801, 11.746311868940081, 22.833778176988872, 23.880522557667323, 21.629280158451625, 24.727037225450786, 17.220688104629517, 19.70369287899562, 5.572980293205806, 26.34008410998753, 31.724175453186035, 54.68064839499337, 14.12749513557979, 2.7719241167817796, 5.230639943054744, 43.28865296500069, 54.06051819665091, 40.30545432226998, 40.347734110695974, 53.21459238869803, 56.149789401463096, 53.621558802468435, 49.90240696498326, 50.37512418201992, 53.92124850409371, 42.630655084337505, 53.237208775111604, 51.78563976287842, 36.19278430938721, 14.373925157955714, 31.558773585728236, 18.69167559487479, 35.4879138810294, 31.213969230651855, 40.27333280018398, 61.96445887429373, 24.68461847305298, 30.112446989331925, 21.967355183192662, 3.031900303704398, 0.08537805971822568, 0.07482150010764599, 0.065438840006079, 0.06130483826356275, 0.13793736190668174, 0.05884376460952418, 0.02105052606202662, 0.03531835161681686, 0.06244480423629284, 0.04334226230691586, 0.10867897261466299, 0.03400551527738571, 0.06806027862642493, 0.03566469963906067, 0.16243962783898624, 0.09376280515321664, 0.06300743190305573, 0.017700600371296917, 0.04735601407342723, 0.13299997470208577, 0.008479131352422493, 0.09488287647919995, 0.03762439698246973, 0.04432837385684252, 0.06987261173448392, 0.034303999439414055, 0.06300109438598156, 0.03421094175428152, 0.0224492700238313, 0.07938392207558666, 0.1542262328522546, 0.07264831529131957, 0.0825071848396744, 0.2948113333966051, 5.168302442346301, 72.54773957388741, 66.81434317997524, 47.36274310520717, 64.1317618233817, 79.28001594543457, 26.391721384865896, 41.13932500566755, 38.35255888530186, 26.773434570857457, 21.939296620232717, 35.94965294429234, 31.661989075796946, 55.425606455121724, 57.9246198790414, 72.51849460601807, 68.17403616224016, 64.05358069283622, 64.61532170431954, 38.72589601789202, 28.73405987875802, 69.00183759416852, 49.05245467594692, 57.81383432660784, 59.0449161529541, 57.30404847008841, 57.66627890723092, 47.86801610674177, 7.5059330974306375, 19.62835877282279, 50.278443472726, 52.77763407570975, 56.274325438908164, 29.018329790660314, 14.39110197339739, 24.539335114615305, 21.322994879313878, 20.84876642908369, 25.591026612690516, 24.836278540747507, 31.137639795030864, 23.01045002256121, 18.79667329788208, 12.438685093607221, 9.778194665908813, 9.351887941360474, 15.340635844639369, 11.464202846799578, 15.537648541586739, 22.336466073989868, 20.523323229381017, 34.34243038722447, 33.68785796846662, 30.968343462262833, 11.716661299977984, 2.7944614674363817, 1.3287004338843482, 0.1472790113517216, 0.8012673471655164, 0.18632207917315619, 0.199082486597555, 0.10479190333613328, 1.3335198781320026, 6.148397096565791, 5.278044896466391, 4.144322965826307, 3.719283853258405, 1.9325187589441026, 15.453311307089669, 18.25655508041382, 11.204938633101326, 5.915427037647792, 4.128418104989188, 2.623837160212653, 2.0087244297776903, 1.672551040138517, 4.991421282291412, 1.499356985092163, 0.25508785779987064, 0.2004185084785734, 0.8251341921942574, 0.19828941486775875, 0.48896194249391556, 0.2833211842392172, 0.5669798446553094, 0.8754691140992301, 7.155940609318869, 7.600279211997986, 24.465847492218018, 30.891138553619385, 31.625601359776088, 23.135354314531597, 17.832819189344132, 21.783285243170603, 32.42206989015852, 34.466914313180105, 37.51788221086775, 33.37262862069266, 28.280201809746877, 16.79881259373256, 18.75775817462376, 21.74558084351676, 14.091949888638087, 14.16918432712555, 19.857426983969553, 22.68041753768921, 19.91229169709342, 24.9372775554657, 16.07982168878828, 21.402742828641617, 9.696471691131592, 43.981016635894775, 41.79327208655221, 43.25168507439749, 12.872255291257586, 9.84835410118103, 2.5651583203247617, 38.57299048560006, 57.83078793116978, 39.622950145176475, 47.220850467681885, 56.587706565856934, 58.853555815560476, 56.316712924412315, 54.910512174878804, 53.479648794446675, 59.5781626020159, 46.4847583089556, 57.21508026123047, 57.70584542410714, 43.758156640189036, 20.81404628072466, 22.188306161335536, 21.292891808918544, 22.423132692064556, 38.091747828892295, 46.384391580309185, 64.80524376460484, 33.79721219199044, 35.319673674447195, 35.74458033697945, 9.321400114468165, 0.20781603295888218, 0.09282755998096295, 0.055305940697767904, 0.09127650356718472, 0.07864917043064322, 0.09785762828375612, 0.03600205367963229, 0.02700602961704135, 0.03235382872766682, 0.04073086600484593, 0.10971926857850381, 0.08265777890171323, 0.029256150126457214, 0.09321991607014622, 0.09334260198686804, 0.19572323613933154, 0.3465381477560316, 0.1892594572688852, 0.18205091836197035, 0.28705434820481707, 0.10008368454873562, 0.219507720587509, 0.23292986250349454, 0.1761371192655393, 0.1491294577717781, 0.16054389599178517, 0.1281516927161387, 0.30445505306124687, 0.09072165869708572, 0.1543635819107294, 0.17805867615555013, 0.1955005545169115, 0.1746473956320967, 0.6035026162862778, 8.617342625345502, 94.71549470084054, 71.37239619663784, 68.47271142687116, 63.57312665666853, 84.09960610525948, 29.973517758505686, 43.47299909591675, 70.12541689191545, 32.032178674425396, 36.911881174360005, 54.29615592956543, 27.31861628804888, 63.47905499594552, 61.50092370169503, 80.22510296957833, 75.76090621948242, 74.9925674710955, 75.03354794638497, 43.66811840874808, 29.648467132023402, 76.33604335784912, 50.27058506011963, 68.28909138270787, 58.122435092926025, 64.07660702296666, 67.5675904410226, 59.012419428144185, 6.317798520837512, 10.366410051073347, 59.853894914899556, 56.18849434171404, 46.98758207048689, 22.422766174588883, 19.896790266036987, 30.25241150174822, 27.338436024529592, 27.451349462781632, 33.27195964540754, 30.969500337328228, 44.08389861243111, 35.069833823612754, 32.947579520089285, 20.903160401753016, 13.721447621073041, 16.297541754586355, 17.411914689200266, 12.187258447919573, 25.221174001693726, 30.98354959487915, 30.707733903612407, 45.061225278036936, 40.92534133366176, 38.9016090120588, 18.68872955867222, 7.216404701982226, 3.0654889813491275, 1.0969640059130532, 0.654184025313173, 0.5767316413777215, 0.38532350797738346, 0.44590797275304794, 1.4146596384899957, 6.877555821623121, 8.431446177618843, 5.139588143144335, 5.19667888539178, 6.9897631491933545, 19.649498667035783, 21.93462916782924, 13.361892240388052, 10.381634422710963, 11.099695137568883, 11.900620068822588, 5.274129152297974, 4.815285316535404, 7.687651940754481, 2.0218662960188727, 0.28923358555350986, 0.1587964240461588, 0.6993818400161607, 0.632391163281032, 0.7167304062417575, 1.9259325180734908, 0.9489855063813073, 1.3831167710678918, 10.537343553134374, 20.502039160047257, 43.90995740890503, 35.247985635484966, 44.11704499380929, 28.996097292218888, 17.031016179493495, 20.907004492623464, 30.425355638776505, 39.05743973595755, 39.10701165880476, 39.48208931514195, 33.178311824798584, 35.091102259499685, 29.373992443084717, 31.38875116620745, 18.56318950653076, 14.93619510105678, 29.340741838727677, 31.856288501194545, 27.435544048036846, 30.999756268092565, 21.814871753965104, 29.093881028039114, 7.361784900937762, 33.29285287857056, 49.912447111947195, 67.99178491319928, 20.348277262278966, 5.680643933159964, 6.123263725212642, 56.57000255584717, 61.90234892708914, 43.97622585296631, 47.91627482005528, 60.679007393973215, 60.64471108572823, 58.7804468699864, 58.204910210200715, 55.26694086619786, 65.98988383156913, 50.306271008082796, 63.008252007620676, 61.7011638368879, 46.491049902779714, 21.742904050009592, 48.616924217769075, 24.491679157529557, 53.7818398475647, 50.235448019845144, 54.22638211931501, 78.78131593976701, 40.412143911634175, 49.51520470210484, 53.42574119567871, 17.913645846503123, 0.3738519235381058, 0.2308540338916438, 0.21923252035464558, 0.16964469264660562, 0.2218044259186302, 0.2224442030170134, 0.08038502585675035, 0.1903223009513957, 0.17479157075285912, 0.12225633620151452, 0.3281012385019234, 0.21027052482323988, 0.18144421306039604, 0.22028431748705252, 0.3188984308923994], [0.0992409372702241, 0.23575468521033013, 0.12577445884900434, 0.03231119637244514, 0.0668548136683447, 0.13369516097009182, 0.010446732780630035, 0.022007565779079283, 0.010872903662467641, 0.026849844426448857, 0.052014153583773544, 0.06249880205307688, 0.2185196786054543, 0.06765638065657445, 0.11095849065376179, 0.05123975853036557, 0.19790860744459288, 0.19417540276689188, 0.1625721321574279, 0.30739408678242136, 32.00390992845808, 76.79328346252441, 50.62562411172049, 44.85387366158621, 65.86005674089704, 60.762288502284456, 19.83409493310111, 61.463292258126394, 29.640740735190256, 16.693983384541102, 42.57288081305367, 23.532641887664795, 37.88366665158953, 59.6015293938773, 51.46798549379621, 60.08975151606968, 57.76169157028198, 65.48585455758231, 55.723277705056326, 42.0139433997018, 62.318976811000276, 55.420058318546836, 49.68918759482247, 63.68947424207415, 50.77651119232178, 47.862051078251426, 25.617813655308314, 2.689860028879983, 33.66615179606846, 55.694661549159456, 42.182729039873394, 20.93274756840297, 17.1185165813991, 24.66324234008789, 21.4738906451634, 21.280034167425974, 26.07964825630188, 22.979817152023315, 30.327240126473562, 32.09370844704764, 22.004656587328228, 18.57905224391392, 7.855140873364039, 4.979085624217987, 3.8171058041708807, 10.327851022992816, 5.750934515680585, 13.68349482331957, 24.604182652064733, 16.70003179141453, 32.90523372377668, 33.41122933796474, 21.236415113721574, 4.252541593142918, 0.6919885224529675, 0.13605076314083167, 0.5632057243159839, 0.5293090460555894, 0.7874944433569908, 0.5183683474149022, 0.0889055257929223, 1.3144176517214095, 0.9535693632704871, 1.0327289955956596, 1.618993348308972, 2.1179889781134467, 2.5200879616396765, 14.727756091526576, 26.397361585072108, 9.263158576829092, 4.322458275726863, 1.8789629127298082, 3.5010465809277127, 3.4886681480067114, 2.2943025571959357, 1.967838623694011, 0.7675672812121255, 0.11654030292161874, 0.17167408232178005, 0.8075606237564767, 0.6284879584397588, 0.07562895677983761, 0.13957834456648144, 0.22326691315642425, 1.7834323474339075, 0.5272153584020478, 2.1521591331277574, 3.1390949402536665, 19.172294650759014, 30.683324881962367, 30.391014167240687, 22.720324516296387, 16.90652530533927, 14.017386163984026, 38.639119965689524, 29.34616838182722, 34.733072008405415, 31.520784309932164, 21.140917335237774, 25.32088933672224, 18.812136513846262, 17.627833434513636, 17.276172944477626, 13.544788803373065, 30.241940566471644, 30.189182894570486, 27.35546432222639, 22.479400941303798, 23.21377863202776, 25.62959953716823, 8.593538096972875, 25.783036606652395, 45.356572355542866, 47.219349656786235, 6.73021970476423, 0.6526734435132572, 7.885792851448059, 71.21740967886788, 55.174752167293, 46.580789361681255, 52.32744639260428, 54.02179936000279, 50.36072404044015, 56.414633887154714, 52.243432249341694, 47.84712634767805, 48.51270818710327, 53.14168841498238, 42.28509684971401, 28.817971536091395, 16.58108557973589, 19.592007534844534, 20.140612976891653, 40.32111208779471, 33.355886936187744, 43.34686844689505, 41.5673166683742, 29.01494949204581, 31.83475603376116, 22.373006650379725, 1.2286230325698853, 0.2850652092269489, 0.03997357342658298, 0.07703249968056168, 0.07523763206388269, 0.03928289602377585, 0.004935620893125555, 0.062060543069882054, 0.08434422340776239, 0.05005466319354517, 0.04655946824433548, 0.07432239010397877, 0.04925326583907008, 0.08141727439527001, 0.049276509056133885, 0.08830295955496174, 0.17701032598103794, 0.21182021738163062, 0.05128870465393577, 0.1891566999256611, 0.03349231888673135, 0.09952278714627028, 0.061792352103761265, 0.02288869269458311, 0.03533952869474888, 0.023815276367323737, 0.0480579721209194, 0.031022302141147, 0.0728076488843986, 0.06752490092601095, 0.2112025333834546, 0.01869973131189389, 0.16053150594234467, 0.24844440285648617, 0.10131724764193807, 0.321031853556633, 36.315030915396555, 85.73018850599016, 53.98058959415981, 52.03431579044887, 81.69811412266323, 55.08037478583199, 25.57047384125846, 49.906374386378694, 25.338207721710205, 21.62921588761466, 33.14312267303467, 34.60607978275844, 44.561427456992014, 64.98375688280377, 58.50282464708601, 65.3271438053676, 65.37690680367606, 65.57628536224365, 56.69860328946795, 46.1112231527056, 67.06927258627755, 57.73068175997053, 52.156687464032856, 68.29341316223145, 51.115930693490164, 51.51153332846505, 27.522090809685842, 9.618493795394897, 35.92952748707363, 54.00260843549456, 67.31051404135567, 29.94843476159232, 17.765260117394583, 23.29946902820042, 22.063585996627808, 18.655887160982402, 22.092738900865825, 23.177100828715734, 29.030287640435354, 31.39835705075945, 21.592152459280832, 19.05268488611494, 10.426978366715566, 9.804490992001124, 5.857058261122022, 15.184317009789602, 8.075364896229335, 14.109457612037659, 24.03368169920785, 20.336949961526052, 37.38805512019566, 40.38248552594866, 34.534134660448345, 13.541106258119855, 3.3457161273275102, 0.0986230361408421, 0.5257529797298568, 0.762100026011467, 1.4345650332314628, 0.5816259416086333, 0.12711879956935132, 1.7760308874504906, 1.6672591183866774, 2.1289554068020413, 2.3031562992504666, 0.26999223232269287, 8.562675067356654, 20.13954642840794, 28.833981922694615, 10.969349537576948, 9.690190519605364, 6.728126559938703, 4.366507249219077, 2.9069497627871375, 2.5835747378213063, 5.462135681084224, 0.5181461136255945, 0.1038815536137138, 0.19689137488603592, 1.9838735461235046, 0.8871195060866219, 0.14280494142855915, 0.30252961495092934, 0.20283235609531403, 1.1478070148399897, 1.1550902468817574, 2.1853350443499426, 17.188068049294607, 31.703917980194092, 33.33471924918038, 28.28607824870518, 20.018083231789724, 23.842729568481445, 19.04922468321664, 37.83485555648804, 29.195472376687185, 34.45440755571638, 29.756237166268484, 16.303319181714738, 13.487348914146423, 16.604579176221574, 15.068504435675484, 17.124000447137014, 13.18315851688385, 32.057553495679585, 24.74027701786586, 26.606420721326554, 20.81575206347874, 23.291839906147548, 17.462233543395996, 14.925956930433001, 45.052939551217214, 51.53972564424787, 37.19229309899466, 8.519452060971942, 3.7754852260862077, 6.185946898800986, 70.56198610578264, 54.63524191720145, 42.76889991760254, 53.20107466833932, 62.00361197335379, 50.22789532797677, 59.379471915108816, 51.401588508060996, 54.45700672694615, 53.425984382629395, 53.66180624280657, 44.60357870374407, 37.869412422180176, 20.33435480935233, 19.845140831811086, 21.20560680116926, 22.989952836717876, 39.28431579044887, 47.149839878082275, 52.13533912386213, 36.27930327824184, 41.839175360543386, 31.291882855551584, 1.5022522125925337, 0.05107199074700475, 0.049335958901792765, 0.04752755451149174, 0.21061627912734235, 0.07182443128632647, 0.03381321506042566, 0.051421331108680794, 0.10787770418184144, 0.05062167080385344, 0.09502824582159519, 0.017901694402098656, 0.08155405348432915, 0.13515392983598368, 0.03284998031865273, 0.22633501780884607, 0.27994311121957643, 0.28752717854721205, 0.22131839128477232, 0.25739422546965735, 0.1570111576999937, 0.1938371259186949, 0.10783749419663634, 0.21915191039443016, 0.10449729021638632, 0.1117720744971718, 0.16259187752647059, 0.2682086894554751, 0.3576456031629017, 0.17389547026583127, 0.48986428550311495, 0.20304343476891518, 0.324114628136158, 0.4467903125498976, 0.16035895448710236, 0.43021486912454876, 52.59957259041922, 98.25333677019391, 68.10438741956438, 69.7204063960484, 82.7407260622297, 81.4019193649292, 31.671556745256694, 86.55359172821045, 40.16519798551287, 28.624907152993337, 57.560492583683555, 33.941085066114155, 48.95440864562988, 70.23341274261475, 64.38371045248849, 73.42950766427177, 74.67037255423409, 72.88033594403947, 65.8065973009382, 52.23605326243809, 72.92152486528668, 64.56498200552804, 57.587993553706575, 65.81324672698975, 59.58489540645054, 54.153134209769114, 39.27582161767142, 4.08092543057033, 39.53138678414481, 63.37009334564209, 56.35371208190918, 19.763987609318324, 22.201540742601665, 27.142896345683507, 25.474324669156754, 23.97504758834839, 29.70510537283761, 29.99385166168213, 39.8356032371521, 42.38324710300991, 37.63847861971174, 34.39304106576102, 20.82483857018607, 16.44715210369655, 10.33729362487793, 20.37530401774815, 10.874989526612417, 24.78758556502206, 32.144822869982036, 23.82634050505502, 47.99182258333479, 45.98339366912842, 42.6717015675136, 20.054828780038015, 4.162425194467817, 0.42867304757237434, 1.1613958456686564, 0.6431992490376744, 2.57498567870685, 0.6405815695013318, 0.16130872709410532, 2.2724674088614325, 2.9967921418803076, 1.0957635960408618, 4.361290889126914, 8.461718610354833, 18.862811463219778, 26.686375379562378, 31.044179575783865, 14.936891657965523, 15.122995683125087, 18.354778289794922, 16.49386136872428, 7.601623688425336, 11.10376591341836, 9.972646951675415, 1.1258918536560876, 0.1743269913962909, 0.3097461334296635, 3.7450086900166104, 2.025879749229976, 0.16084597978208745, 0.7808073993240083, 1.2594237455299921, 4.364949549947466, 0.5547947670732225, 9.092191202299935, 34.20698915209089, 42.096755504608154, 41.7665354183742, 39.71745606831142, 30.69830867222377, 27.558037315096172, 13.745626483644758, 42.892445836748394, 33.25755255562918, 39.96913024357387, 34.595070362091064, 25.88099578448704, 33.842820167541504, 27.88858049256461, 23.231784888676234, 22.50982015473502, 17.258366448538645, 39.21092544283186, 36.50891692297799, 31.656367983136857, 24.393018211637223, 29.56086424418858, 34.340113162994385, 13.423497574669973, 34.23087011064802, 66.3688107899257, 56.4481519971575, 12.473001377923147, 1.3827223522322518, 9.369840349469866, 80.81872926439557, 60.35233088902065, 48.972845690590994, 58.13057490757534, 62.18869808741978, 50.933880942208425, 66.56265163421631, 57.998600823538645, 58.512878690447124, 59.994922501700266, 62.195236342293875, 51.35905858448574, 38.22616073063442, 34.353901863098145, 32.53932074138096, 30.759459768022808, 60.19856030600411, 49.403929301670615, 56.406615665980745, 56.88282435280936, 44.33125795636858, 54.06532287597656, 46.514013699122835, 2.5735699832439423, 0.48433151096105576, 0.12376911645489079, 0.173354406441961, 0.27957165400896755, 0.1763004833566291, 0.07949115096458367, 0.1932242595191513, 0.15095551764326437, 0.17901665903627872, 0.13018044456839561, 0.2490809772695814, 0.22473538507308277, 0.22950388491153717, 0.11711450639579978, 0.2618612657700266], [0.20146050756531103, 0.2065347959952695, 0.05148277245461941, 0.12654486750917776, 0.09600922425410577, 0.05371368703033243, 0.03225417907482811, 0.04375507283423628, 0.048927253511335166, 0.05269261057089482, 0.05100566394893186, 0.05709011799522808, 0.03076469971399222, 0.09533904200153691, 0.06019072447504316, 0.06775161304644176, 0.14824866503477097, 0.05349885945075324, 0.08311203095529761, 0.04578113090246916, 3.1121991149016788, 74.00534657069615, 62.04681587219238, 44.56429706301008, 43.56508009774344, 89.32834093911308, 48.320097173963276, 39.61211442947388, 51.076836654118125, 18.13077184132167, 39.27329247338431, 32.16209609167916, 41.71325315747942, 70.23169653756278, 54.61909082957676, 63.71139580862862, 59.56802518027169, 57.608438628060476, 60.228243010384695, 68.38488619668144, 53.66348075866699, 56.338401726314, 56.74215807233538, 61.64190265110561, 44.41505670547485, 36.70276124136788, 3.767421407358987, 12.34321163381849, 63.191114698137554, 45.0673257963998, 21.027765921183995, 21.912028414862498, 26.917420353208268, 19.24157861300877, 20.117056846618652, 26.50600188119071, 24.390365736825125, 23.77633431979588, 31.325053555624827, 28.365081003734044, 22.43559776033674, 17.57867840358189, 8.121435795511518, 3.963754483631679, 1.7411571187632424, 8.747349500656128, 10.371087057249886, 12.307162642478943, 16.949904646192277, 18.719586508614675, 31.469742843082972, 35.1262914112636, 24.006859915597097, 4.902280671255929, 1.4452704702104842, 0.05207915045320988, 0.12839801449860844, 0.921373365180833, 2.308896596942629, 0.4209265389612743, 0.27840033971837586, 0.7492388561367989, 0.5961643414837974, 1.2245773353746958, 1.553744769522122, 4.15133934361594, 18.05280610493251, 26.190397330692836, 27.703122649874004, 9.00800335407257, 11.131153975214277, 3.8447448696408952, 2.731943096433367, 2.464276773588998, 0.9572053338800157, 2.75531444805009, 0.24801885283419065, 0.09465727037084953, 0.27682312577962875, 0.10915084622268166, 0.6885782054492405, 1.3101833760738373, 0.2521553651562759, 0.24973815200584276, 0.964946061372757, 0.8150430736797196, 3.065492672579629, 4.290460518428257, 13.222498348781041, 30.490703446524485, 30.537454400743755, 24.532880238124303, 21.88072851725987, 15.611214331218175, 20.99395251274109, 30.17251764025007, 23.79555651119777, 25.050529718399048, 22.01718418938773, 24.97411343029567, 26.756550448281423, 17.910468782697404, 14.081720403262548, 14.150812421526227, 15.025875500270299, 26.62488555908203, 26.182561499731882, 24.363849673952373, 22.102940593447002, 32.77660172326224, 31.630982739584788, 6.085778628076826, 36.642377921513145, 44.58837604522705, 28.92364321436201, 5.457038743155343, 2.190296709537506, 20.85622184617179, 63.00256838117327, 50.389750140053884, 51.77965388979231, 55.872632707868306, 60.5821008682251, 51.62706797463553, 56.30399424689156, 46.96999270575387, 55.092992714473176, 53.222898960113525, 46.88063192367554, 25.369842869894846, 15.696770974567958, 12.207492470741272, 27.465683596474783, 34.13645451409476, 82.41908700125558, 57.80950559888567, 41.52567264011928, 36.89801604407174, 28.67811472075326, 13.154855029923574, 0.30718053824135233, 0.09527281698371683, 0.08769433399928467, 0.04958758004275816, 0.03124759951606393, 0.02629201060959271, 0.046685265244117806, 0.018562724913603494, 0.1298882673893656, 0.09071836780224528, 0.023357495931642394, 0.03662304214334913, 0.03896651550063065, 0.05425056429313762, 0.09941687461520944, 0.046812419313937426, 0.06326230322676045, 0.19957678578794003, 0.06416516192257404, 0.12315103890640394, 0.1363272118781294, 0.028326088961746012, 0.04646667518786021, 0.09439876209944487, 0.06366023008844682, 0.08597479734037604, 0.06116879199232374, 0.02900343993678689, 0.02267627221798258, 0.03946648385109646, 0.04096357298216649, 0.06913954964173691, 0.16485255264810153, 0.04706817951851657, 0.059260690451732705, 0.08418765145220927, 3.6371491977146695, 79.56154305594308, 70.61333329336983, 47.103610038757324, 58.95146983010428, 87.54262610844204, 46.0615747996739, 40.775149072919575, 34.93359007154192, 23.008739028658184, 28.294287545340403, 41.232813017708914, 46.42979110990252, 75.70042215074811, 64.94613238743374, 65.99854128701347, 66.0483946119036, 61.09113284519741, 63.39203575679234, 70.95725522722516, 62.312535830906455, 56.94901984078543, 60.8885372706822, 64.46262114388603, 49.888461930411204, 35.06666544505528, 9.187655108315603, 23.0021938255855, 43.26354217529297, 64.13026796068463, 29.071143048150198, 18.441104446138652, 26.43091443606785, 19.637438331331524, 18.29691195487976, 22.57106852531433, 21.535611493246897, 24.284885134015763, 28.447495324271067, 30.0598977633885, 21.4767359324864, 17.608395848955425, 7.14438488653728, 9.05558635507311, 6.347484265054975, 12.805236441748482, 14.729513985770089, 14.295777899878365, 20.32294065611703, 22.48088264465332, 38.37365709032331, 41.75269113268171, 37.58665548052107, 13.972742250987462, 4.095072831426348, 0.20070432099912847, 0.05352780236197369, 1.0253230844225203, 2.973659634590149, 0.25936884379812647, 0.6249830265130315, 1.0688609310558863, 1.5959168608699525, 1.7111064855541502, 0.8781771745000566, 12.215380413191658, 29.06367894581386, 28.52658145768302, 30.708453042166575, 12.412906408309937, 16.176227944237844, 6.315102619784219, 5.008574213300433, 2.9246036154883246, 3.078198322228023, 4.165063338620322, 0.2083702196500131, 0.1700600782143218, 0.19846363551914692, 0.18694622282470974, 0.4002187358481543, 0.658435617174421, 0.2739316166511604, 0.5478639389787401, 0.6881602278777531, 1.4477903864213397, 2.6044206363814215, 10.480941551072256, 29.22736460821969, 34.583338328770225, 29.56265687942505, 19.622975655964442, 24.941667079925537, 21.70256802013942, 26.941818952560425, 31.595605986458914, 28.517543588365825, 27.337709937776836, 16.968866280147008, 14.923724821635656, 11.90445373739515, 13.224867684500557, 11.042177081108093, 15.033539363316127, 13.76556955065046, 26.945088079997472, 21.747748681477137, 26.301836013793945, 21.142459835324967, 37.07384020941598, 31.506842749459402, 14.059698956353323, 55.98687151500157, 44.45171192714146, 29.65775339944022, 17.03862793104989, 6.377255993230002, 15.567928791046143, 63.60571370806013, 47.26282106127058, 51.668284688677105, 60.04999392373221, 62.59681442805699, 52.879084723336355, 59.62867600577218, 51.440015520368306, 57.72752727781023, 55.477245467049734, 49.804357460566926, 30.261506693703787, 16.69726640837533, 16.027621609824045, 20.615878445761545, 24.171975169863018, 80.00495624542236, 56.159301485334126, 54.81999451773507, 43.65885993412563, 42.433899470738, 20.586550099509104, 0.5285660230687687, 0.012496682915038295, 0.15022440973137105, 0.04264551880104201, 0.1735737903841904, 0.047140752231436114, 0.0526148063529815, 0.051347567566803524, 0.1423501329762595, 0.16179778799414635, 0.12417511109794889, 0.19366214530808584, 0.03821476316079497, 0.019630326822932278, 0.178447924554348, 0.02401719651451068, 0.27713343341435703, 0.26099103103790966, 0.1582222477133785, 0.33924842891948565, 0.1649917337511267, 0.10420865499015365, 0.16769655075456413, 0.21297002211213112, 0.16102687721805914, 0.22803491087896482, 0.16545433178544044, 0.24004272797277995, 0.09733092226088047, 0.18988104962876864, 0.1277368092643363, 0.16771371769053595, 0.19232236434306416, 0.17320895567536354, 0.14174943949495042, 0.2711853140166828, 5.9618353588240485, 104.25813674926758, 78.83678340911865, 66.4639663696289, 63.019431659153526, 112.0071221760341, 68.8895686013358, 60.15004103524344, 68.37268515995571, 28.850812196731567, 55.8754015650068, 42.076612676892964, 52.81742293494088, 85.55819974626813, 71.18663610730852, 77.81378623417446, 74.22402027675084, 67.12693568638393, 71.30622850145612, 79.70944241115025, 66.24206175122941, 63.02596991402762, 62.85084056854248, 69.56279345921108, 54.38401590074812, 48.318603311266216, 7.139119020530155, 14.582530055727277, 67.0351847239903, 58.44133308955601, 24.662943567548478, 24.70513824054173, 35.577966008867534, 23.822279282978602, 23.969700949532644, 32.390980175563264, 30.05032661982945, 32.173369543892996, 41.57176351547241, 44.94868183135986, 38.246598856789724, 36.14530379431588, 19.925842421395437, 16.14722616331918, 13.360657198088509, 18.352153607777186, 16.518379824502126, 21.76213492665972, 24.159551790782384, 27.67055470602853, 48.65632745197841, 44.104051862444194, 46.73648806980678, 15.563528844288417, 3.3550440839358737, 0.2389397828706673, 0.19077147756304058, 2.0729286074638367, 3.771937736443111, 0.7184956829462732, 0.3525254321949822, 1.6199651190212794, 1.8790879803044456, 2.460422911814281, 2.272025763988495, 21.4452988079616, 38.11115762165615, 36.244868006025044, 32.495554038456504, 17.26876790182931, 22.94323488644191, 18.915202617645264, 17.38167612893241, 9.416148356028966, 10.4623464345932, 8.14970280442919, 0.8559062981179782, 0.1545185593089887, 0.8033370961036, 0.5459852655019078, 1.5049774263586317, 1.46748885512352, 0.4566089042595455, 1.6456731281110217, 1.8920939224106925, 1.7733746128422874, 3.570091264588492, 22.274943249566213, 42.752860001155305, 39.86074529375349, 42.423341682979036, 28.390040670122417, 33.048707076481406, 21.370517083576747, 25.12945430619376, 37.15332760129656, 31.807901246207102, 33.56242561340332, 24.567523956298828, 31.79570368358067, 37.32026154654366, 27.22451162338257, 19.40709512574332, 21.891816105161393, 20.18341040611267, 32.71578066689627, 32.099871499197825, 29.89623294557844, 24.38545162337167, 36.147537640162874, 38.12704120363508, 9.658733419009618, 52.29913248334612, 60.978572028023855, 37.15737492697579, 15.5236896106175, 4.835955338818686, 25.643151998519897, 70.98001752580915, 56.27025726863316, 59.572402545383994, 66.67419106619698, 66.43620136805943, 51.0613352230617, 62.42677811213902, 53.47926664352417, 65.73499611445835, 62.59595285143171, 61.508177621024, 36.867478711264475, 31.445198331560405, 23.47613045147487, 42.14019564219883, 54.82574415206909, 95.56669766562325, 68.18129702976772, 63.01784746987479, 48.512958322252544, 54.83962665285383, 33.55728742054531, 0.5125232839158603, 0.12315504226301398, 0.25235398592693464, 0.1346014937652009, 0.2373977984700884, 0.13611052850527422, 0.05086127508963857, 0.15153269310082707, 0.17005796118506364, 0.17118859051593713, 0.3308336175978184, 0.5017635641353471, 0.12651236568178448, 0.22088111617735454, 0.25952284410595894, 0.11088788229972124], [0.12908758249666008, 0.048585689160972834, 0.05749075899698904, 0.21122350011553082, 0.11656961563442435, 0.06717542825000626, 0.13008508325687476, 0.08000057470053434, 0.012076585769786366, 0.08174757845699787, 0.029395039459424357, 0.08942176880581038, 0.03395448265863316, 0.006008868637893881, 0.04098317925153034, 0.0537523601337203, 0.13542414962181024, 0.08184294655386891, 0.31903478928974693, 0.17131619581154414, 0.09959509862320763, 18.581775937761577, 85.5971096583775, 53.392567021506174, 45.98028435025896, 72.91816193716866, 75.54007162366594, 30.219341550554546, 53.81908219201224, 20.961551325661794, 38.3335451398577, 34.021416664123535, 37.334672110421316, 72.4124095099313, 52.78581210545131, 63.115080560956685, 59.12186745234898, 59.87058448791504, 60.04834025246756, 59.277152742658345, 61.351370675223215, 55.70734895978655, 59.848475319998606, 60.330965178353445, 45.50724056788853, 5.51076568875994, 3.8460324576922824, 42.799576214381624, 67.54871218545097, 30.785835129874094, 34.17721264702933, 30.753234182085308, 25.366530316216604, 20.05661620412554, 26.44585132598877, 25.689762251717703, 26.194937978472026, 22.748285804476055, 27.91688050542559, 25.625951732907975, 20.728731087275914, 12.551127791404724, 9.832439252308436, 4.38848830972399, 3.7227748887879506, 6.894851190703256, 6.703287184238434, 16.451291493007115, 22.18403823035104, 16.005646194730485, 32.53467239652361, 38.51395164217268, 23.67518244470869, 6.351806478840964, 3.06474899819919, 0.12421462897743497, 0.577019068811621, 1.1410327383450098, 0.32249645782368525, 0.48668537608214785, 0.37686269198145184, 0.028195089294708202, 0.08959728545908417, 0.5156887854848589, 1.3749827103955405, 9.690246105194092, 38.33957617623465, 27.898285388946533, 15.227187395095825, 11.076006991522652, 13.731018764632088, 3.5774678630488257, 2.696391769817897, 2.5058335150991167, 1.4755354119198663, 5.195365675858088, 0.3135926127433777, 0.44494488728897913, 0.19664076476224832, 0.6169046599950109, 2.1211237013339996, 0.32697050060544697, 0.3596598207950592, 0.05886420886963606, 0.2395942434668541, 0.3903772367962769, 1.5299559831619263, 5.144890487194061, 7.432179706437247, 30.04439980643136, 34.97822182519095, 24.400131429944718, 22.882304395948136, 15.56338119506836, 13.353429334504263, 21.39676216670445, 22.37566954748971, 21.727642331804546, 19.767162936074392, 25.153894594737462, 33.53960425513131, 31.18349095753261, 22.863585948944092, 20.37486801828657, 29.887349673679896, 28.941962139947073, 40.74649470193045, 32.03610093252999, 26.071795054844447, 16.675435168402537, 20.592681884765625, 19.298255068915232, 12.774380360330854, 49.80840131214687, 32.66696262359619, 25.865454401288712, 3.4926720474447523, 1.854910203388759, 18.21392614500863, 25.85372063091823, 24.73378392628261, 27.424439089638845, 41.69788721629551, 57.075223445892334, 53.445887497493196, 51.92411388669695, 51.84877804347447, 46.08212409700666, 46.49356862476894, 17.574533803122385, 8.763692532266889, 16.596692970820836, 26.230118444987706, 38.89159665788923, 39.15164688655308, 46.691828523363384, 37.304082666124614, 22.70461290223258, 31.05104787009103, 2.678650196109499, 0.2027636883514268, 0.034048320659037144, 0.04094887252098747, 0.18777660040983132, 0.08532344443457467, 0.07188067505402224, 0.06953121362520115, 0.03659389567162309, 0.061930807174316475, 0.059512847635362826, 0.07785877212882042, 0.0607292845046946, 0.03096618390242968, 0.033569675271532366, 0.10179779971284525, 0.11123312770255975, 0.26636747111167225, 0.08452856780162879, 0.0900310253990548, 0.1540435847959348, 0.13125863671302795, 0.06379581495587315, 0.030731563456356525, 0.0710762921454651, 0.04206913722945111, 0.021075443564248935, 0.007493272556790284, 0.1734266025679452, 0.061427103488573005, 0.01311929731829358, 0.12407599070242473, 0.07325478989098753, 0.11874281402145113, 0.05665583183456745, 0.21265398764184543, 0.06968023348599672, 0.0734754969765033, 23.599857023784093, 95.77696405138288, 58.01535293034145, 54.649141788482666, 86.87860066550118, 69.09892477308, 35.15067611421858, 43.65294701712472, 31.969700472695486, 32.349461214882986, 32.93486779076712, 49.47701045445034, 77.57321875435966, 64.40299170357841, 66.5728099005563, 67.2508568082537, 63.04838480268206, 66.66597134726388, 66.53365680149624, 69.75655092511857, 60.31527614593506, 69.90816756657192, 63.8008816582816, 44.57782520566668, 5.13569324357169, 16.372427701950073, 32.60677037920271, 60.8082160949707, 47.65093353816441, 26.549613986696514, 30.558410167694092, 23.73417612484523, 18.688957112176077, 22.638363565717423, 22.659213372639247, 24.042525018964493, 22.959127153669083, 26.72392691884722, 29.362559182303293, 22.192572355270386, 12.313812068530492, 10.712521536009652, 9.629174045154027, 8.839611155646187, 10.578144243785314, 11.07303055695125, 19.30492533956255, 22.903550250189646, 17.67471466745649, 42.207763399396626, 46.0063088280814, 42.03495127814156, 11.237193039485387, 3.456708171537944, 0.19449383925114358, 0.5963071595345224, 1.548059623156275, 0.3469354978629521, 0.6942170485854149, 0.47853888464825495, 0.12834476307034492, 0.4000437280961445, 2.0132661632129123, 0.7136148448501314, 17.706360237939016, 38.47160584586007, 29.363049030303955, 21.30816568647112, 12.484145419938223, 20.18451690673828, 11.03628500870296, 5.243490202086313, 2.9098849424294064, 3.5577866562775204, 6.183704801968165, 0.4711519724556378, 0.32938315400055473, 0.15800343374056475, 0.4228684790432453, 3.2669713241713385, 0.29387650213071276, 0.49861559591123034, 0.19702780113688537, 0.14330598525702953, 0.9172286561557225, 1.7524780141455787, 4.847868025302887, 28.04022318976266, 38.197197164808, 34.32673788070679, 19.276076419012888, 25.833178281784058, 20.643556594848633, 21.64586898258754, 24.80175120489938, 22.394749300820486, 20.317043372562953, 20.351452589035034, 20.30265017918178, 21.64480069705418, 15.280144827706472, 11.163919074194771, 17.006603683744157, 22.079089164733887, 26.98244854382106, 35.55359172821045, 28.017400094441005, 24.47409326689584, 19.229193449020386, 20.406975643975393, 16.52540271622794, 24.760435479027883, 57.70849963596889, 32.471930163247244, 31.87320041656494, 13.646210789680481, 4.405644280569894, 12.157379456928798, 21.848414182662964, 20.89815422466823, 25.235191992350988, 38.12882341657366, 59.09768077305385, 54.53993695122855, 56.263566153390066, 52.850683961595806, 52.420399393354145, 47.887811524527415, 27.131360598972865, 12.468918442726135, 22.418258530753, 20.045711006437028, 45.40264586039952, 46.84873621804373, 55.41280092511858, 42.94071497235979, 28.91486242839268, 45.69906643458775, 6.0067263671330045, 0.15293366435383046, 0.014418197396610464, 0.04375354613044432, 0.1695705559104681, 0.050284058919974735, 0.09817970850105796, 0.14176011963614396, 0.0072944787597017625, 0.06011559029242822, 0.04769368702545762, 0.16367517225444317, 0.0522193086466619, 0.12388826720416546, 0.042714871865298064, 0.07013910636305809, 0.11759752833417483, 0.3699974375111716, 0.10648065486124583, 0.1970311395291771, 0.4245122436966215, 0.20749801716634206, 0.17711335473826953, 0.3330330481486661, 0.14091933332383633, 0.13601598143577576, 0.171694709786347, 0.16055957015071595, 0.24678782746195793, 0.18671940213867597, 0.06808291455464703, 0.18236091387059006, 0.13673535069184645, 0.33619806117245127, 0.22051995912832872, 0.5390316386307988, 0.254996581269162, 0.24803353633199418, 35.46283435821533, 112.68845558166504, 71.1835858481271, 71.18232127598354, 93.8325662612915, 95.867109979902, 46.61262600762503, 74.33642128535679, 28.58602155957903, 53.47557020187378, 45.1341883114406, 50.7412108693804, 88.68810612814767, 71.78511224474225, 78.28532573154995, 70.59005682809013, 69.74819919041225, 70.27282987322126, 72.07939624786377, 75.7329466683524, 68.23289435250419, 76.10473087855748, 66.75057261330741, 56.32032251358032, 7.989424364907401, 8.106052483831133, 51.675865173339844, 79.41338661738804, 41.57258340290615, 37.31947292600359, 39.11784042630877, 28.175197158540996, 23.2126339163099, 29.610950333731516, 29.795261723654612, 30.403128351484025, 29.48999261856079, 40.75447470801217, 43.28007541384016, 38.611987250191824, 31.267480782100133, 26.76961132458278, 19.939302819115774, 16.042032173701696, 12.884418981415884, 11.503850136484418, 23.438398259026663, 32.04617234638759, 22.76117123876299, 49.62710544041225, 48.634735924857004, 53.18744230270386, 14.856094530650548, 4.771190745489938, 0.1481560721461262, 1.1811526140996387, 2.1854640202862874, 0.2916612210018294, 0.9231460243463516, 0.6575889683195523, 0.1716405219797577, 0.3380825700504439, 1.8042284143822533, 4.087748561586652, 31.939725943974086, 42.684694698878694, 34.84933621542794, 24.071775197982788, 16.761134249823435, 23.852345875331334, 23.597558907100133, 21.593858242034912, 12.217338068144661, 13.748941642897469, 10.188803672790527, 1.1763142794370651, 0.9685101615531104, 0.7961078211665154, 1.1657317387206214, 4.584832676819392, 0.24858358395951136, 0.5412836692162922, 0.5424164427178246, 0.45834731097732273, 1.4443918487855365, 1.4581092212881361, 14.764993224825178, 40.18025473185948, 45.528366565704346, 41.86198629651751, 31.04450614111764, 32.08087165015084, 25.34362210546221, 22.109808887754166, 27.536343302045548, 28.717137541089738, 30.54999589920044, 26.272530249186925, 30.630869456699916, 44.21568162100655, 41.89437185014997, 31.93306609562465, 26.326121704918997, 37.17986624581473, 35.38219356536865, 48.04102277755737, 39.18738147190639, 33.076249735695974, 20.90026647703988, 23.338978222438268, 25.212342841284617, 16.930837052209036, 62.701926776341026, 43.900313309260774, 33.48760741097586, 9.097935625485011, 4.93437613759722, 21.890362194606237, 26.44551260130746, 26.488589695521764, 32.01528065545218, 46.64382689339774, 66.857255254473, 56.24233940669468, 60.817839350019185, 58.7523900440761, 56.67183535439627, 58.92788069588797, 37.600819383348735, 21.33301591873169, 28.481482437678746, 40.24059983662197, 59.18811852591378, 55.06910828181675, 65.41385037558419, 53.501181261880056, 39.91662965502058, 64.76798057556152, 11.826491475105286, 0.5244940529976572, 0.12098564367209162, 0.1515961361250707, 0.2705306091478893, 0.17642746440001897, 0.22289057049368108, 0.2246010894221919, 0.1632756372647626, 0.19420924809362206, 0.1475201491266489, 0.27254767662712504, 0.19515508519751684, 0.2272139920720032, 0.11056646704673767, 0.23864510868276867, 0.36536475324204987], [0.11736031249165535, 0.1432567507560764, 0.036290950141847134, 0.3362103019441877, 0.04491693852469325, 0.06586448502327714, 0.06299731494592768, 0.03261290357581206, 0.040076242560254674, 0.059238088450261524, 0.031377043641571484, 0.04192171531862446, 0.039550354172076495, 0.09159010209675346, 0.10517399997583457, 0.036756978170680146, 0.1508503718567746, 0.037149049275155575, 0.19626689196697303, 0.019619724713265896, 0.024756390867488723, 0.5019519797393254, 40.44739212308611, 69.87020260947091, 43.70032330921718, 54.34091622488839, 88.85366085597447, 42.36460508619036, 49.46402774538313, 28.697333438055857, 28.380174228123256, 56.68447412763323, 25.719715935843332, 74.59351852961949, 66.82364681788853, 62.77438259124756, 60.02689116341727, 63.73883424486433, 57.61476148877825, 64.02288355146135, 51.26118278503418, 59.7607821055821, 53.762978962489534, 61.288565908159526, 20.79093483516148, 2.70106161066464, 15.112952062061854, 65.30404799325126, 52.96901178359985, 25.19140270778111, 36.067268575940815, 19.940562180110387, 20.7376160962241, 22.356622798102244, 25.35395928791591, 28.07298047201974, 22.890515429633005, 23.712139913014003, 30.771914413997106, 23.72312675203596, 13.621601138796125, 12.375857744898115, 6.4701521056038995, 5.476973993437631, 4.967917263507843, 8.636045438902718, 14.988918031964984, 17.901754004614695, 22.19115318570818, 17.904149396078928, 31.555184841156006, 40.50590290342058, 24.788002456937516, 8.160703539848328, 6.459649034908839, 0.6469701124089104, 1.0190676429441996, 1.1155076622962952, 0.7417659057038171, 0.15983725605266436, 0.06934124417603016, 0.17690872214734554, 0.20883106706397875, 0.7276210561394691, 1.3998047155993325, 9.886177488735743, 32.10829618998936, 23.61224045072283, 7.967779857771737, 13.912547401019506, 14.63267867905753, 3.628909719841821, 1.7191670473132814, 2.190075235707419, 2.5999357913221632, 2.9517367652484348, 0.5099221063511712, 0.04344640386157802, 0.2584127336740494, 0.2730131245085171, 0.08065833297691175, 0.13303441713963235, 0.10350702942482062, 0.09552403778902122, 0.6630411329013961, 0.6803555552448545, 2.2177703210285733, 3.210813811847142, 12.232163786888123, 24.136040823800222, 40.24668645858765, 24.464681931904384, 22.002697195325577, 20.145660843167985, 13.31949520111084, 15.106948818479266, 18.31397499356951, 18.85813879966736, 16.594810009002686, 16.164834635598318, 18.69354292324611, 31.606889860970632, 23.478260074342998, 18.4051353590829, 25.211271081651958, 25.356431109564646, 29.284989493233816, 39.34686347416469, 33.36275175639561, 39.54178476333618, 25.11402930532183, 33.580129623413086, 12.300983956881932, 28.029519489833287, 57.18970891407558, 28.381890433175222, 15.252800192151751, 0.8197770225150245, 1.3820693301303046, 3.3710229865142276, 4.402752527168818, 4.855841517448425, 8.005885515894208, 14.079677632876805, 40.38198178155081, 52.11953544616699, 47.23538957323347, 42.519640241350444, 38.38332550866263, 10.166803070477076, 12.136924828801837, 24.556962694440568, 26.811941487448557, 44.74421371732439, 40.154886858803884, 35.203548431396484, 28.92019864491054, 28.038866553987774, 16.425168003354752, 0.9507403607879366, 0.12116107211581298, 0.19307004208011286, 0.038896606037659306, 0.2555689662694931, 0.09165192342230252, 0.05159441182123763, 0.015271785968382443, 0.0644115786999464, 0.06625336701316492, 0.020987152587622404, 0.2521815566079957, 0.02820043615065515, 0.08812951921884503, 0.014031892991624773, 0.17019726442439215, 0.17325677882347787, 0.2662334740161896, 0.15719577350786754, 0.1341825933860881, 0.243337232619524, 0.1037417957559228, 0.01567045073690159, 0.046878450949277194, 0.10500779282301664, 0.06714792722570044, 0.0321436389349401, 0.0678830724209547, 0.08711553684302739, 0.1184504468526159, 0.023442845458963087, 0.16573330467300756, 0.0890020609700254, 0.10925149332199778, 0.09980817897511379, 0.16700922192207404, 0.030749897472560406, 0.05775730112301452, 1.1577307794775282, 50.64189679282052, 78.5149359021868, 44.81381034851074, 73.32816123962402, 87.05238900865827, 48.22626175199236, 39.07671403884888, 31.211266381399973, 36.7821478843689, 48.515077522822786, 39.04256016867501, 78.1361062186105, 72.69935621534074, 68.4453980582101, 67.1728354862758, 69.36915411267961, 62.55418722970145, 72.06636837550572, 57.12383304323469, 66.2731271471296, 57.20741639818464, 70.84934970310756, 20.62166976928711, 10.277572989463806, 22.688312428338186, 43.09449945177351, 72.22979000636509, 33.56466293334961, 46.169772148132324, 23.069966554641724, 20.384138652256556, 17.401746000562394, 17.85641700880868, 22.551450286592754, 23.121216467448644, 22.556187220982142, 30.811772755214147, 27.412687948771886, 16.347836290087017, 13.235559225082397, 8.522000312805176, 9.360846774918691, 9.662080713680812, 10.251205444335938, 19.237654617854528, 20.398606538772583, 26.190258366721018, 18.69786296572004, 40.851311751774375, 48.461979389190674, 41.35041127886091, 11.163648094449725, 5.967052587441035, 3.4909842865807668, 0.7122097345335143, 0.13531536688762053, 0.970730545265334, 0.2648709756987435, 0.14140151387878827, 0.08407817661230053, 0.423700498683112, 0.8384657225438527, 0.8300709415759359, 17.291078567504883, 41.35578571047102, 27.07218279157366, 11.377779415675572, 16.381872040884836, 18.741714784077235, 13.270991563796997, 6.071080148220062, 2.8554633940969194, 3.420912355184555, 1.8618290892669132, 1.2551546203238624, 0.07377420844776289, 0.19233905630452292, 0.6676456715379442, 0.1350921695785863, 0.29947447031736374, 0.07002725665058408, 0.12179881360914026, 0.21071563022477285, 0.8339403282318796, 1.2499785380704063, 4.73065756048475, 24.582773515156337, 36.8041215624128, 42.784658432006836, 20.51305205481393, 22.96665378979274, 22.797906364713395, 18.730106081281388, 21.534214905330114, 17.18257028715951, 18.139762810298375, 19.1763402393886, 16.735747269221715, 18.036288499832153, 22.592597518648418, 19.656853335244314, 17.574672767094203, 20.43505505153111, 21.46384702410017, 26.019384792872838, 28.962671245847428, 28.918716941561016, 36.58274153300694, 22.820871898106166, 26.98637080192566, 15.611782346452985, 42.435459341321675, 52.578488281794954, 26.19031568935939, 17.56321692466736, 4.746630600520542, 1.439947281564985, 1.9190418592521121, 3.339706369808742, 2.999491734164102, 6.476068496704102, 11.819906319890704, 41.9742031778608, 57.5908179964338, 51.766695499420166, 51.713715485164094, 45.84130300794329, 16.218038729258947, 21.15029740333557, 31.32023845400129, 21.030319384166173, 60.67558888026646, 47.42077098573957, 48.652349608285085, 36.59398719242641, 39.773309162684846, 27.36818473679679, 1.1791508815118243, 0.17533454804548196, 0.09203764343900339, 0.038657890632748604, 0.1567441270287548, 0.07850164334688868, 0.05877435047711645, 0.019504278765193055, 0.05533527037394898, 0.026539760708276714, 0.020931989386943833, 0.3385206865412848, 0.1156090000378234, 0.1581158669931548, 0.05571056130741324, 0.12445564461605889, 0.13035036330776556, 0.3825829050370625, 0.32068992619003567, 0.16345174424350262, 0.3035711119217532, 0.21992026987884725, 0.19669309338288649, 0.13073015292840345, 0.16226803990347044, 0.1450700813106128, 0.13966450494314941, 0.14621840683477266, 0.2992359516876084, 0.17929822392761707, 0.2175705438213689, 0.2817665519458907, 0.12784405850938388, 0.17386779960777077, 0.22590599368725503, 0.2844244007553373, 0.16963363252580166, 0.11585175272609506, 1.6255530991724558, 73.26502295902797, 90.81694384983608, 63.03445366450718, 81.22156497410366, 107.691714150565, 59.084090096609934, 71.8462563923427, 38.16646875653948, 36.95186110905239, 75.78489140101841, 36.241411277226035, 94.4693408693586, 82.1233855656215, 75.9849717276437, 71.17404597146171, 76.4929267338344, 64.4521154676165, 77.53494112832206, 61.26731831686837, 72.77149936131069, 63.9705844606672, 79.53941999162946, 30.297442776816233, 4.90887668303081, 18.49494082587106, 73.7777235848563, 65.45218358721051, 27.932922158922466, 43.962930474962505, 25.602102041244507, 25.388180903026036, 25.33713596207755, 32.167109216962544, 32.16969742093767, 29.806959015982493, 31.13562481743949, 49.261960233960835, 44.56571796962193, 30.276504380362375, 26.191800866808208, 22.90643722670419, 17.921264546258108, 14.405255453927175, 14.181513905525208, 25.616184302738734, 26.209206104278564, 33.679961340767996, 23.843615463801793, 47.900467668260845, 52.57232870374407, 51.218736239842, 17.762044838496617, 11.491917473929268, 5.139814828123365, 0.9726214323725019, 1.111013914857592, 0.8553786150046757, 0.24084934326154844, 0.20378634919013294, 0.1966459351990904, 0.4441051052084991, 2.6524782861982072, 2.310167683022363, 25.89074410711016, 40.636400495256694, 29.58303247179304, 14.987464121409825, 21.086080414908274, 23.86526083946228, 29.14374998637608, 20.226716790880474, 15.122653484344482, 12.04732607092176, 8.165166020393372, 2.3705885665757314, 0.12103672378829547, 0.4659697019628116, 1.0167862453630991, 0.24042995433722222, 0.29146952128836084, 0.18140664936176368, 0.3726578918950898, 1.0082326872008187, 1.233675784298352, 2.6437196476118903, 13.99898646559034, 33.25318908691406, 44.238777433122905, 49.99644388471331, 28.114417791366577, 31.00891399383545, 28.332361936569214, 21.910892384392874, 22.734118427549088, 24.80683207511902, 26.639799867357524, 23.947124515260967, 21.53310145650591, 25.63371287073408, 37.56381675175258, 32.12145260402134, 23.710731165749685, 27.35427096911839, 29.331469467708043, 34.919391427721294, 44.420667375837056, 41.110135623386924, 47.697837352752686, 28.67898498262678, 39.61746106828962, 17.21702814102173, 37.94858019692557, 74.19495596204484, 35.815198353358674, 22.13298113005502, 4.799020452158792, 2.1538527565343037, 3.74575822693961, 6.052301773003169, 4.413010239601135, 8.174743243626185, 19.788391419819423, 56.37915638514927, 60.30896718161446, 58.433043888636995, 60.79655006953648, 54.54645088740757, 25.678528751645768, 24.109797477722168, 35.67444174630301, 39.03947169440133, 62.51945318494524, 48.70901564189366, 59.36594377245222, 47.04457466942923, 56.49938801356724, 43.221126896994456, 1.328213734286172, 0.41916959466678755, 0.22192101180553436, 0.11485411625887666, 0.3227626606822014, 0.14513196370431355, 0.18798092087464674, 0.2665863665086882, 0.1425945684313774, 0.15058533607849053, 0.1928783016545432, 0.6800166677151407, 0.1701016045574631, 0.2832360416650772, 0.23705825954675674, 0.3088113564465727, 0.377566685634], [0.09645388860787664, 0.060167125027094565, 0.14383514757667268, 0.25829143875411575, 0.07550462202302047, 0.04423757230064698, 0.02108737899522696, 0.11054730521781103, 0.01296904422010162, 0.01905332439179931, 0.05407684575766325, 0.06360629333981446, 0.02875049225986004, 0.04694189058084573, 0.1031593345105648, 0.06806448554354054, 0.09704953378864697, 0.12148313197706427, 0.09681548670466457, 0.10602526965418033, 0.05619515744703157, 0.10519004732902561, 4.49441750560488, 66.21829891204834, 58.53399426596505, 45.38025876453945, 74.84245858873639, 70.03110204424176, 45.31420571463448, 56.10161059243338, 25.895390714917863, 44.15204654421125, 32.2523010798863, 68.61595548902238, 70.23742880140031, 66.06489658355713, 66.14348765781948, 65.76148959568569, 68.01115649087089, 62.64869662693569, 55.544517925807405, 64.31992598942348, 53.63231461388724, 32.92268065043858, 2.2882461164678847, 3.700248394693647, 38.9467271396092, 60.15571076529366, 26.834814957209996, 19.606716871261597, 26.425515685762676, 30.286857196262904, 23.5661461012704, 29.025776522500173, 35.361821447099956, 34.81845147269112, 36.68339661189488, 38.135764666966026, 29.06104384149824, 23.12545313153948, 15.450976712363106, 6.9867506708417615, 10.540945325578962, 6.434656798839569, 7.637181094714573, 10.45151766708919, 15.526925734111241, 21.261600596564158, 21.993631533214025, 21.548441341945104, 40.29464292526245, 42.5442716053554, 25.59238498551505, 8.702395524297442, 2.8835994728973935, 3.784935210432325, 1.816862736429487, 1.0274126465831483, 0.35831140886460033, 0.3027234316936561, 0.42475298792123795, 0.46132493977035793, 0.12947411675538334, 0.9979743233748845, 0.32518030809504644, 4.957332985741751, 18.339942148753575, 22.778451408658707, 15.31107473373413, 15.136515140533447, 13.235031161989484, 3.01377049939973, 2.574299978358405, 1.1772291617734092, 2.958381848675864, 1.4218635090759821, 0.29683735753808704, 0.10762809828988143, 0.2751800939440727, 0.11676890136940138, 0.3291881973189967, 0.4218196267528193, 0.21032305700438364, 0.10819954012653657, 0.12608145523284162, 0.5990731939673424, 4.807962349482945, 2.6620353162288666, 12.728759356907435, 25.222230127879552, 42.61603954860142, 29.196327005113872, 20.253456933157786, 16.908269303185598, 11.352719868932452, 10.7325644833701, 12.706154261316572, 16.953196355274745, 15.192441190992083, 14.121902704238892, 13.61409968989236, 19.26374510356358, 22.586637701307023, 20.655175719942363, 20.616093839917863, 33.97414459500994, 40.75342900412423, 53.914022377559114, 51.03837490081787, 37.26896299634661, 31.331748144967214, 33.70083025523594, 37.45856891359602, 15.568255356379918, 57.491198199135916, 59.37389945983887, 38.86136851991926, 28.848675625664846, 10.692014796393257, 0.03921940550208092, 0.34198444496308056, 0.36710587409990175, 0.7227225218500409, 1.6998136000973838, 5.106079152652195, 35.24609572546822, 45.582027503422324, 38.082725593021934, 25.48458194732666, 7.929857458387103, 22.559244428362163, 26.69447350502014, 28.79309003693717, 36.74530506134033, 48.62126336778913, 31.924200194222585, 24.362350600106375, 33.00404405593872, 7.044589647224971, 0.10428168571421079, 0.01852836729293423, 0.061403829737433364, 0.057936787206147394, 0.10340557486883231, 0.1868703897510256, 0.059483962399618964, 0.05782921904964106, 0.05092581394793732, 0.08284531241016728, 0.11373876753662314, 0.0630914888211659, 0.01635854292128767, 0.018449670801471387, 0.04844268112044249, 0.0884548971163375, 0.2016013307230813, 0.008663133086104478, 0.09152450133115053, 0.11122761121285812, 0.2731105892785958, 0.08533518309039728, 0.02462343532325966, 0.08083156296717268, 0.03635719890839287, 0.07554762757250241, 0.03937545498566968, 0.017411783636946763, 0.06474752138767924, 0.03224685089662671, 0.055514349336070676, 0.12328528027449336, 0.08382395668221371, 0.15960677127752984, 0.21660926326044969, 0.22370447324854986, 0.06406152926917587, 0.09693762300802128, 0.0999370531312057, 7.66258544581277, 80.84306880405971, 66.27576051439557, 57.43054042543684, 83.72488280705043, 70.35664599282401, 44.66514321735927, 36.92907796587263, 33.520778111049104, 40.391622407095774, 42.17756305422102, 75.79969801221574, 75.3279778616769, 68.80045795440674, 72.93835340227399, 70.90485886165074, 70.55276584625244, 65.71267850058419, 62.64605631147112, 67.65399129050118, 57.83252150671822, 29.715263639177593, 6.624682213578906, 12.509858097348895, 25.42186403274536, 62.53851209368025, 44.202685015542166, 24.150764056614467, 27.27303089414324, 25.926725353513444, 18.49518574987139, 24.463776929037913, 29.75665753228324, 33.49708127975464, 34.9728057043893, 33.392906938280376, 31.051280634743826, 29.892185619899205, 17.24913924080985, 13.19990975516183, 14.310455969401769, 10.477128727095467, 10.377611415726797, 14.80903264454433, 21.47010040283203, 22.849811145237513, 23.900519473212107, 20.84303763934544, 46.267151151384624, 55.45532042639596, 40.00750861849104, 13.986772400992256, 6.315247229167393, 8.251081364495413, 0.8111036622098514, 0.269585626998118, 0.3899160229734012, 0.35033227130770683, 0.3135321688439165, 0.28607068955898285, 0.08654536386685711, 0.6499088747160775, 1.10247631583895, 7.586323755128043, 24.608195236751012, 27.056033440998622, 16.93959699358259, 18.68551775387355, 17.606002194540842, 14.393534711429051, 6.382979571819305, 1.3683078799928938, 2.413423993757793, 1.5076037368604114, 0.5219284849507468, 0.10688309398080621, 0.8805473787443978, 0.3265514373779297, 0.15322962775826454, 0.3601359352469444, 0.22044964932969638, 0.04707135506240385, 0.27908959559031893, 1.4830037483147211, 1.6300934212548392, 5.838175662926265, 29.47970928464617, 34.95060968399048, 48.22459765842983, 25.159717185156687, 19.477626289640153, 20.682346650532313, 17.068185567855835, 17.499043362481252, 17.55841224534171, 18.394224950245448, 18.586829015186854, 15.432970455714635, 14.324510438101631, 20.006042003631592, 17.883949245725358, 12.205884831292288, 11.982376047543116, 18.971390962600708, 24.86689404078892, 35.25865112032209, 33.98100594111851, 29.487067426953995, 25.61832955905369, 29.27571017401559, 31.27699634007045, 23.328780003956386, 63.87153788975307, 48.93480430330549, 31.95182623182024, 29.407451493399485, 13.954082863671438, 0.044599815005702634, 0.26352299803069656, 0.4530256965330669, 0.42315045105559485, 1.6706588502441133, 4.915298555578504, 37.57713644845145, 51.31967619487217, 44.976224490574424, 28.716275964464458, 14.704269443239484, 36.92678158623831, 25.32466047150748, 27.195244073867798, 50.0066751071385, 55.038386821746826, 45.63956553595406, 35.80698210852486, 46.90337685176304, 11.301275406564985, 0.2221745667713029, 0.04274770278217537, 0.1659750531294516, 0.0352302777713963, 0.048384995465832095, 0.2280013369662421, 0.11317752408129828, 0.1494897734373808, 0.07292397692799568, 0.046375385086451254, 0.03522850000964744, 0.10977994996522154, 0.06517488309847456, 0.06858734427286045, 0.035792111552187374, 0.0672217993331807, 0.24948956391641072, 0.1776378894490855, 0.23548389545508794, 0.36047501276646343, 0.6447888665965625, 0.1795319113880396, 0.1844182727592332, 0.1295887077493327, 0.17145092572484696, 0.15790876453476294, 0.06456855777651072, 0.11343745049089193, 0.2001902221568993, 0.14799878772880348, 0.13025713259620325, 0.20853409942771706, 0.12410283354776246, 0.24089779066187994, 0.3398102287735258, 0.33211276467357365, 0.29585692871894154, 0.22077392121510847, 0.27574067243507927, 15.003385918481008, 99.84005519321987, 78.07744952610561, 68.95556259155273, 94.86166395459855, 86.89378942762102, 69.03883675166539, 76.26132243020194, 33.11687585285732, 61.5818841116769, 45.233714308057515, 88.57765061514718, 84.11822032928467, 82.3103129523141, 79.22654260907854, 78.85467502049038, 75.69937297276088, 76.45481586456299, 65.43601512908936, 81.64008276803153, 60.46817125592913, 45.167487553187776, 5.12973472901753, 7.827585186277117, 45.84340483801705, 72.55655683789934, 38.1242584500994, 23.974389246531896, 31.039774417877197, 33.16522836685181, 27.396477801459177, 32.60204560416085, 38.402676241738455, 40.84887988226754, 49.356646810259136, 51.109190940856934, 46.01200982502529, 43.65891899381365, 34.43380267279488, 22.731160231998988, 24.746921232768468, 15.01346949168614, 14.396699615887233, 19.03623676300049, 25.899976525987896, 30.56129367010934, 29.162145342145646, 28.03457604135786, 57.071124008723665, 60.25389575958252, 50.66976949146816, 20.085744789668492, 7.177607698099954, 13.873048629079547, 4.375144728592463, 1.4090154213564736, 0.5106292484062058, 0.36779127589293886, 0.4950395535145487, 0.7609623670578003, 0.20847286842763424, 2.198567888566426, 1.8029068452971322, 20.909082004002162, 30.949420043400355, 26.855982644217356, 19.637408801487513, 25.07340145111084, 26.76569775172642, 32.87229231425694, 22.048317330224172, 14.770623002733503, 8.67032263960157, 3.67000983442579, 1.026212453842163, 0.1552634143403598, 3.3416360148361752, 0.5333844359431947, 0.4987810498901776, 1.0924739497048515, 0.3650561555155686, 0.3306031599640846, 0.5698030388781002, 2.247135796717235, 3.501339925186975, 11.125921981675283, 40.58857604435512, 37.21041400091988, 59.425503730773926, 35.12428338187081, 29.76517254965646, 23.51583593232291, 19.728570904050553, 16.16248961857387, 20.637965032032557, 24.58570565496172, 23.636618205479213, 20.583329609462194, 20.945976938520158, 29.42162929262434, 27.783994470323833, 24.38799466405596, 26.145135028021677, 38.33824907030378, 46.6999648639134, 59.35618155343192, 59.323337418692454, 42.138448170253206, 38.31361075810024, 40.16638265337263, 44.5349200793675, 20.74796196392604, 72.30906200408936, 69.84466797964913, 47.37696259362357, 44.275641100747244, 19.352881806237356, 0.1287807353905269, 0.37920116792832104, 1.0046901915754591, 0.5175986172897475, 2.0771839448383878, 9.621234859739031, 55.678736277988975, 57.58913305827549, 55.55998461587088, 40.222673484257285, 20.68675528253828, 36.89281531742641, 41.71677936826433, 43.59871285302298, 55.18296493802752, 64.46556023189, 54.8969840322222, 42.94967120034354, 64.91606753213065, 17.045129707881383, 0.27699335664510727, 0.17916675098240376, 0.3219660334289074, 0.15972111799887248, 0.2358146405645779, 0.27604913445455687, 0.160622008943132, 0.28685130338583675, 0.19247407120253357, 0.31451495896492687, 0.21465858364743845, 0.28930000056113514, 0.116733956815941, 0.18252145525600227, 0.15947898956281797, 0.14843265659042768, 0.297318303159305], [0.3606711636696543, 0.1603592394718102, 0.10371884091624192, 0.059059939081115384, 0.11352659642164196, 0.2156123596110514, 0.030006660747208765, 0.02269226359203458, 0.03553862783259579, 0.05435759640697922, 0.025344802864960263, 0.005002365838403681, 0.004086720998332436, 0.06011909831847463, 0.04128047258460096, 0.0470645527488419, 0.11443293600210122, 0.2314267988715853, 0.04775883656527315, 0.13969491688268526, 0.05961118093026536, 0.05515707350735154, 0.7648959702679089, 33.65607690811157, 56.83731017793928, 39.390237603868755, 60.19824068886893, 84.91089166913713, 53.737975869859966, 54.78518404279436, 44.3353921345302, 41.37357657296317, 31.196164471762522, 58.164513383592876, 72.21239866529191, 63.77362387520926, 68.05327647072929, 63.99782139914376, 66.70333181108747, 64.98548003605434, 59.48928819383894, 34.78255360467093, 12.009187408855983, 2.8171794712543488, 3.858727250780378, 27.290519509996685, 53.5604806627546, 50.390573501586914, 19.963381801332744, 29.15684039252145, 40.087433746882844, 30.51174259185791, 28.99794203894479, 25.896526745387487, 25.064542497907365, 30.126843656812394, 29.541169575282506, 40.37094109398978, 31.720732620784215, 14.070487771715436, 10.586021763937813, 6.679318938936506, 5.362303963729313, 4.2745552233287265, 7.330608333860125, 9.494693398475647, 18.637670721326554, 21.73509427479335, 22.2216922555651, 26.971411330359324, 48.788787909916465, 41.59731204169137, 28.644296101161412, 7.505955679076059, 1.7851219539131438, 0.3057429668094431, 0.49404102138110567, 0.25109997178827015, 0.8700338314686502, 0.3432652476642813, 0.4568018253360476, 0.2874420088316713, 0.34731835446187426, 0.31734591562833103, 0.3917582726904324, 3.397218346595764, 7.32951659815652, 29.123713118689402, 32.93198776245117, 17.412738050733292, 5.966370361191886, 0.9717630041497094, 1.575767953480993, 0.8603332777108464, 1.4903678617307117, 0.9012965453522546, 0.068160450751228, 0.19368810605789932, 0.8212694195764405, 0.359709733831031, 0.6009309685656002, 0.452918216586113, 0.10675855566348348, 0.258458711206913, 0.3808006378156798, 0.36323781737259453, 2.5947048834392, 4.917323955467769, 21.568085636411393, 28.22679795537676, 36.53907905306135, 31.775738034929546, 24.513472182410105, 21.285921028682164, 15.822152955191475, 12.5059723172869, 9.84941109589168, 11.972250785146441, 15.911659649440221, 12.516835825783865, 16.824375016348704, 18.682818378720963, 32.72822836467198, 49.32679040091378, 62.057752336774556, 63.25969341823033, 77.42911311558315, 91.2338149206979, 111.97844001225063, 93.10827909197126, 70.80110141209194, 49.22290093558175, 51.797514234270366, 23.72521468571254, 28.501145839691162, 64.07261875697544, 32.230539321899414, 40.94282994951521, 36.68588754108974, 12.379789556775775, 0.8508497465934072, 0.18688820808061532, 0.2893805833799498, 0.12295444017010075, 0.6474492666976792, 3.276977381535939, 28.34287108693804, 37.935972690582275, 18.075191463742936, 14.944124732698713, 20.02124466214861, 32.603004455566406, 30.245977469852992, 54.505446093423025, 41.97077076775687, 22.43724795750209, 37.824520111083984, 28.111240727560862, 0.5309721625276974, 0.019522029241280894, 0.06824572224702154, 0.06776654760220222, 0.07545767418508019, 0.15164893972022192, 0.09310141671448946, 0.05249068872737033, 0.029783745030207292, 0.07790468180818216, 0.05205597848232303, 0.024191376453797733, 0.10186462184148175, 0.08362548518925905, 0.04883594305387565, 0.057183457272393365, 0.06145294888743332, 0.022533019904845526, 0.04788609920069575, 0.06398615081395422, 0.10475376288273505, 0.06234409606882504, 0.13257188695882047, 0.0523321625909635, 0.0389592619612813, 0.036878595394747596, 0.030651167234671966, 0.021724218036979437, 0.016692151448556354, 0.045654923389000554, 0.014546862903184124, 0.12466707612786974, 0.04125644226691552, 0.05351950048602053, 0.09199364044304405, 0.21760893533272402, 0.13276042469910213, 0.1525416611028569, 0.0483582883274981, 0.011040125225138451, 0.8832136413880757, 46.27012498038155, 71.51679365975517, 48.27759504318237, 78.49432754516602, 80.04870905194963, 61.217152323041645, 33.66838564191546, 41.474634647369385, 44.9385096686227, 36.81529426574707, 69.51648371560233, 75.85605485098702, 71.23528739384243, 71.80778421674455, 71.5833226612636, 66.98818710872105, 69.59890324728829, 56.28031478609358, 36.4718656539917, 10.79784541470664, 6.216350044522967, 11.583511233329773, 21.897715125765117, 45.4760605267116, 65.58115604945591, 27.009787968226842, 22.088993821825298, 37.06304965700422, 22.677336011614116, 22.95486617088318, 20.445202895573207, 20.63976808956691, 26.167509964534215, 27.728341136659893, 33.63022266115461, 34.275936126708984, 20.755433014460973, 19.827610526766094, 13.512636014393397, 12.745540125029427, 8.050419126238141, 12.599519389016287, 15.960823365620204, 21.426701954432897, 22.62008806637355, 20.630973407200404, 23.927582706723893, 60.794778278895784, 49.548198223114014, 42.14665051868984, 11.99527016707829, 5.189667284488678, 1.8004675933292933, 0.46965908684900826, 0.7670712992548943, 0.8576033413410187, 0.6471396375979696, 0.3987343454999583, 0.34245304124695913, 1.0212853125163486, 0.5847418829798698, 2.484275426183428, 4.638617379324777, 13.718995775495257, 33.60937111718314, 35.711447851998464, 19.23675308908735, 12.119886977331978, 11.065133060727801, 5.1467764888490946, 2.6000988568578447, 0.26932653518659727, 1.0692922621965408, 0.046329577187342305, 0.4483816128756319, 1.2419960349798203, 0.45436200339879307, 0.17232090261365685, 0.548041389456817, 0.1654948538967541, 0.3909915824021612, 0.3917800129524299, 1.360423845904214, 1.3220465566430772, 7.21489303452628, 38.17464678628104, 32.98325157165527, 45.506490162440706, 29.223056725093297, 21.017503431865148, 22.003930500575475, 20.030555248260498, 20.416581528527395, 20.625084808894567, 19.775750909532817, 19.309226274490356, 15.586885213851929, 17.426990543092998, 19.871029819761002, 28.431957415172032, 36.174652985164094, 42.17690297535488, 47.781754221235005, 58.05837270191738, 70.32889488765171, 80.97523743765694, 62.998121534075054, 54.235970633370535, 39.33525998251778, 40.740588733128135, 21.076271295547485, 40.09296451296125, 64.25660010746547, 37.86122744424002, 46.99108048847744, 42.62096929550171, 16.649718148367747, 0.7311439013906887, 0.8938499763607979, 0.20386676916054317, 0.15878153698784964, 0.4702454496707235, 1.4444745757750102, 30.83349629810878, 45.40281956536429, 27.57960626057216, 27.897338696888514, 26.006721700940812, 24.947095360074723, 37.622025285448345, 62.11594349997384, 51.83275897162301, 34.5753687449864, 49.60873787743704, 37.185796533312114, 1.6472605743578501, 0.06963830002184425, 0.05418789140614016, 0.09039686433970928, 0.20028468780219555, 0.015370238006913235, 0.03388127890814628, 0.04780199817780938, 0.023160885320976377, 0.05155862249167902, 0.06729184450315577, 0.08146894483694009, 0.14322827942669392, 0.06876150385609694, 0.06430682646376745, 0.007778789914612259, 0.1033007072817002, 0.17639057923640522, 0.4282280100243432, 0.2326821700802871, 0.3149174930793898, 0.2017205221844571, 0.27419518679380417, 0.2126268326703991, 0.08851205012095825, 0.11393797184739794, 0.21782616153359413, 0.11968204219426427, 0.07986349705606699, 0.2267703523061105, 0.1348350862307208, 0.19738495482930116, 0.10562513755368334, 0.10619937495461532, 0.1818658954330853, 0.5516355080263955, 0.16615825758448668, 0.334990920232875, 0.15974109406982148, 0.11604626157454082, 1.738173627427646, 64.35793263571603, 88.11078030722481, 57.645542008536204, 86.43162305014474, 96.79941231863839, 76.57895238058907, 71.74653584616524, 54.84821115221296, 55.76999044418335, 48.036478655678884, 78.28417233058384, 87.62548337663922, 77.7677127293178, 79.35541084834507, 75.0511199406215, 72.67584351130894, 73.01449176243374, 67.85397434234619, 43.813895089285715, 17.063274928501674, 8.840889624186925, 6.5649754745619635, 34.62092113494873, 67.72741290501186, 65.5397308894566, 23.777616262435913, 36.080671651022776, 46.00499561854771, 34.86324998310634, 29.700335434504918, 29.230289799826487, 30.82494306564331, 39.88088812146868, 39.703601360321045, 51.14024591445923, 50.586679458618164, 27.37543865612575, 23.55000196184431, 22.53837377684457, 18.96185108593532, 10.488555908203125, 12.697105969701495, 16.122490576335363, 30.278356075286865, 33.31998906816755, 28.021647180829728, 34.66305153710501, 71.54301616123745, 53.959421907152446, 52.046624524252756, 16.900047847202845, 6.094967186450958, 2.1359854638576508, 2.064214915037155, 1.1091141253709793, 2.4823477353368486, 1.6445473028080804, 0.3834555282124451, 0.22314954016889843, 0.7053754755428859, 0.7148424504058701, 3.2357917172568182, 11.89857816696167, 21.05483783994402, 36.64884669440133, 35.6709884916033, 27.523857389177593, 24.23339377130781, 27.433039222444805, 18.87369407926287, 10.567919969558716, 6.26297766821725, 2.6589420650686537, 0.30591659035001484, 0.37264909808124813, 2.781294413975307, 0.8185563651578767, 1.3654437022549766, 0.7784210730876241, 0.5908174855368478, 1.0297384474958693, 1.1259644840444838, 5.45990400654929, 3.5063775862966264, 13.635821495737348, 43.69395528520857, 31.933291912078857, 50.80484594617571, 37.78470345905849, 31.992511408669607, 29.697702067238943, 25.62782427242824, 22.944108622414724, 19.004592929567607, 20.20012777192252, 25.698063611984253, 19.879246064594813, 22.46747783252171, 27.00953435897827, 41.004595960889546, 52.58473123822893, 66.3359180177961, 67.02093396868024, 77.44705336434501, 88.96057973589215, 115.88095828465053, 97.82707868303571, 82.74836908067975, 56.522011348179404, 58.2076130594526, 28.900726318359375, 35.8941194670541, 79.53491061074394, 49.1347074508667, 48.31407308578491, 50.164138657706125, 21.498634917395457, 1.023125825183732, 0.8244079425930977, 0.2955056647104876, 0.15062568177069935, 0.49410833205495563, 4.846777592386518, 46.35551834106445, 57.22247314453125, 40.36923878533499, 28.246141740253993, 31.48931244441441, 48.47992658615112, 49.81343528202602, 76.48011425563267, 61.15693228585379, 40.91450561795916, 61.45412063598633, 50.261027812957764, 1.9207185464245933, 0.163156961490001, 0.16152725608221122, 0.34037254431418007, 0.2260779480316809, 0.2006917952426842, 0.3468999154865742, 0.08688938790666205, 0.06451303325593472, 0.2576500874544893, 0.1288918387144804, 0.1793102475681475, 0.31317840782659395, 0.3522123561373779, 0.096360026858747, 0.19678160149071897, 0.14106600545346737, 0.19361371147845471], [0.16092375346592494, 0.35272855843816486, 0.1561499067715236, 0.06909950929028646, 0.020172462732131993, 0.09060747482414756, 0.05743082399879183, 0.11123132279941014, 0.07320558253143515, 0.04356697274904166, 0.0634112823754549, 0.03295098364885364, 0.03466987569949456, 0.057384615764021873, 0.08286418925438609, 0.043710082569824796, 0.07190607261977025, 0.14005029281335218, 0.14535490317004068, 0.06538720349115984, 0.13388838060200214, 0.10925350857100316, 0.11769697442650795, 5.219030805996486, 58.95559011186872, 58.16745594569615, 44.503389154161724, 85.77577563694545, 63.73062147412981, 45.48691013881138, 52.662071636744905, 40.93786893572126, 33.69206510271345, 47.36147505896432, 74.6128762108939, 60.34548691340855, 67.09889275687081, 66.44911806924003, 71.88365854535783, 36.464719431740896, 14.844223533357892, 1.04394707935197, 0.6540669915931565, 0.8305335396102497, 26.315034117017472, 44.28613288061959, 43.29109525680542, 34.38956349236624, 22.55212947300502, 42.890802587781636, 33.78258970805577, 43.371593611580984, 49.29458897454398, 58.21077101571219, 61.59268856048584, 60.69594015393938, 58.79828984396798, 58.674966267177034, 47.23458705629621, 30.97084481375558, 15.143923657281057, 14.344028796468463, 7.23261832339423, 5.076746898038047, 4.647364727088383, 9.107299191611153, 16.443921191351755, 22.344143833432877, 28.906597546168737, 36.779712540762766, 47.73892552512032, 44.99871233531407, 24.369913714272634, 8.715159365109034, 4.268120322908674, 0.7304431647062302, 0.9578510820865631, 0.09329372032412461, 0.7091709290231977, 0.5913225327219281, 0.3159950338304043, 0.256917486765555, 0.22478190543396132, 0.7419786942856652, 1.7285230138472147, 5.285061708518437, 5.868961828095572, 23.433331285204204, 31.61814594268799, 9.419344527380806, 5.72746046100344, 1.1509365269115992, 1.1176229545048304, 0.6701429518205779, 1.2239036858081818, 0.6351651230028698, 0.5190387942961284, 2.145376605646951, 2.046980559825897, 0.3197791150638035, 0.26779747009277344, 0.35153973794409205, 0.5264295605676514, 0.3554519808718136, 0.15300611832312175, 1.990556844643184, 3.935513964721135, 6.502327476228986, 23.78582034792219, 36.176942416599815, 39.43613045556204, 36.4071501323155, 24.217954874038696, 27.849100828170776, 21.803518397467478, 21.556110416139873, 14.27919602394104, 12.125075544629778, 13.768776144300189, 14.128255094800677, 17.273516995566233, 23.031002793993267, 35.74212762287685, 48.85687678200858, 60.61887073516846, 54.07837159293038, 54.593257427215576, 62.977388109479634, 76.66144139426095, 84.16165351867676, 79.87360055106026, 78.1888291495187, 67.37381907871791, 59.51743534633091, 21.086033514567784, 43.13643877846854, 30.968642234802246, 18.33049259866987, 40.632481711251394, 44.5450644493103, 1.3628595152071543, 1.497613747205053, 0.1253618145627635, 0.27481504210403984, 0.18006871401199273, 0.4784505122474262, 2.592126016105924, 22.352783918380737, 22.409531593322754, 16.599781445094518, 26.858390195029124, 30.73461648396083, 35.95851189749581, 52.10957867758614, 35.08162839072091, 33.387237208230154, 33.7754921231951, 9.595722811562673, 0.2521101204412324, 0.12425074061112744, 0.06884980161807366, 0.016785821511543224, 0.05956124753824302, 0.1012763184096132, 0.048129357397556305, 0.08234616847974913, 0.0803466479160956, 0.04671609787536519, 0.02847109528790627, 0.028896686022302935, 0.06759564498705523, 0.14067246871335165, 0.07819974276104144, 0.07909453367548329, 0.07108122509505067, 0.03861031514991607, 0.10844954635415759, 0.24468578025698662, 0.09073430658983332, 0.01927099164043154, 0.032097047327884605, 0.04461061728319951, 0.0572162712258952, 0.06938260088541678, 0.03188722733674305, 0.04987140106303351, 0.09488065088433878, 0.07572958352310316, 0.09194348313446556, 0.07646696109856878, 0.06672466386641775, 0.08552136631416422, 0.15191717818379402, 0.09963484720460006, 0.09799931996635028, 0.10110395694417612, 0.23540366547448294, 0.14948814495333604, 0.043084351146327596, 9.315911037581307, 81.08213547297886, 61.309841292245046, 63.87909058162144, 87.60058103288922, 71.68745531354631, 36.56502015250069, 41.646112714494976, 48.23993928091866, 38.96960408346993, 63.369335991995676, 77.27849006652832, 69.45539515359062, 69.56868553161621, 72.09521034785679, 70.24422413962228, 38.831633704049246, 10.982007418360029, 1.5915290734597614, 0.276629309036902, 5.4464883378573825, 31.024981703077042, 41.78726536887032, 49.75408724376133, 50.99398980821882, 23.950853960854666, 35.29190867287772, 27.80052249772208, 28.884217398507253, 32.16198492050171, 35.47791542325701, 38.15072413853237, 40.886042322431294, 36.45185831614903, 42.32269007819039, 43.11024406978062, 27.099527427128383, 19.58670779636928, 17.162022726876394, 12.853100844791957, 9.92267290183476, 9.364326085363116, 15.230270658220563, 20.813295875276836, 24.347448451178415, 24.695365599223546, 35.361998626164024, 60.354762758527485, 52.5010575566973, 41.126668861934114, 8.964088133403234, 3.3074374156338826, 1.813736807022776, 0.8216773005468505, 0.03399488602631858, 0.2823849416204861, 0.15729207119771413, 0.1456349210015365, 0.33838166828666416, 0.3720031056020941, 0.416060384362936, 3.5746484143393378, 8.507240601948329, 10.182542477335248, 30.518861021314347, 39.33067069734846, 16.22580681528364, 13.134105103356497, 12.162429928779602, 5.428238894258227, 3.1145588968481337, 3.64385073525565, 1.2213723702090127, 0.40476481190749575, 4.137173269476209, 1.4736841512577874, 0.9744503285203661, 0.5845338170017514, 0.37257117511970655, 0.22160771861672401, 0.186896893328854, 0.5120617715375764, 2.0658829169613973, 4.501225003174373, 9.139500617980957, 38.8423547744751, 39.346137387411936, 40.79979433332171, 37.705410616738455, 23.640728064945765, 26.980006252016338, 22.85264948436192, 27.011620555605205, 22.851678473608835, 20.313598803111486, 20.781368902751378, 19.2116596698761, 21.113564014434814, 26.044175965445383, 35.42198937279837, 48.044034821646555, 56.34726415361677, 51.54556213106428, 49.09776735305786, 53.2697298186166, 66.76604625156948, 69.49780000959123, 65.9802953175136, 66.72749764578683, 58.39383520398821, 48.03813927514212, 29.804989201681956, 51.581494740077424, 34.60300520488194, 22.528665406363352, 44.11161845070975, 58.20967320033482, 4.433420138699668, 1.6578299786363329, 0.4031675676149981, 0.35606806352734566, 0.1651542836001941, 0.5987996086478233, 1.5127474665641785, 23.826918942587717, 33.01780148914882, 28.949242115020752, 26.0991153717041, 26.201234783445084, 43.726872376033235, 61.40305137634277, 47.590063844408306, 45.13413619995117, 46.662750312260215, 15.375067642756871, 0.0996601837021964, 0.1228168604097196, 0.04755047203174659, 0.035782235474990945, 0.053290593304804394, 0.06008942598210914, 0.019751467376149127, 0.12095725376691137, 0.09799208678305149, 0.03938172464924199, 0.03787973649533732, 0.039246414588498216, 0.1036551875461425, 0.1998303678951093, 0.08689816814980336, 0.05591151284586106, 0.023640406018655215, 0.06538776667522532, 0.24882704232420239, 0.5664082467556, 0.2880721778741905, 0.13728615827858448, 0.14120727644434997, 0.13775774011654512, 0.11893032038850443, 0.15844201163521834, 0.16193711837487562, 0.199240435979196, 0.19850251557571547, 0.1353419247482504, 0.1888153696698802, 0.206750325858593, 0.134472911379167, 0.11960215148116861, 0.30998714906828745, 0.28484091269118444, 0.2720515861042908, 0.37405724823474884, 0.33068933391145294, 0.2772211272801672, 0.3308844534414155, 15.627502645765032, 98.92762470245361, 74.81281757354736, 69.71293708256313, 100.76804270063127, 84.11467674800328, 65.02138137817383, 66.82694721221924, 51.60337461744036, 50.79453829356602, 68.46838269914899, 98.28834874289376, 75.15685067858014, 80.36947263990129, 74.33771365029472, 80.88191618238176, 43.17350046975272, 19.58556134360177, 1.9501107292515891, 2.290281504392624, 3.084436718906675, 32.32691083635603, 54.62254408427647, 57.757852690560476, 50.93949508666992, 27.622876167297363, 48.89334092821394, 37.11887148448399, 48.8669308253697, 54.55013690676008, 64.45704174041748, 67.41276373182023, 72.05482046944755, 71.46393871307373, 71.51461887359619, 65.57791818891252, 46.64995520455496, 27.31036877632141, 26.65648075512477, 16.009813376835414, 13.429546850068228, 8.862027781350271, 17.56372935431344, 30.56810290472848, 33.23928574153355, 31.115481989724294, 47.255202361515586, 73.03721932002476, 61.881281988961355, 47.847088132585796, 16.5999482018607, 10.439282757895333, 3.338502594402858, 1.2202900797128677, 0.17313648813537189, 0.5588947470699037, 0.8619486796004432, 0.24984283638851984, 0.2340584019465106, 0.9062915401799339, 1.38580778666905, 3.589298039674759, 19.30781579017639, 22.762253420693533, 40.248124735695974, 42.79470552716936, 26.966895001275198, 26.355444840022496, 26.110079629080637, 17.120354379926408, 9.439938988004412, 6.047938304288047, 1.7615716861827033, 0.684393869979041, 7.762835792132786, 2.2557428777217865, 2.231611132621765, 0.6503632217645645, 0.95561397927148, 3.0724291460854665, 0.8771924844809941, 0.8802629911473819, 7.18010470696858, 9.59099108832223, 15.504081794193812, 43.53703022003174, 37.867275851113455, 49.29356411525181, 48.34540598733084, 30.983921323503765, 36.225555488041465, 30.726754597255162, 36.07818072182791, 27.31740209034511, 20.255907910210745, 26.3293491431645, 25.301066126142228, 24.653426272528513, 25.852857317243302, 40.280572823115754, 51.0112942968096, 55.617383684430806, 50.936298915318076, 49.255210059029714, 56.07977587836129, 76.40041841779436, 83.68802956172398, 76.08124596732003, 81.59678159441266, 77.10072040557861, 70.17447117396763, 32.06784725189209, 56.21507814952305, 44.39863811220442, 30.053474153791154, 47.746877738407676, 60.599547794886995, 5.9250020895685465, 5.52812967130116, 1.3296153162206923, 0.43581446579524447, 0.3881776976798262, 0.60569857273783, 4.600705402238028, 34.30665758677891, 41.44271114894322, 31.63520724432809, 37.527595792497905, 44.16170801435198, 55.70694249016898, 72.27801050458635, 58.123633657182964, 51.94946091515677, 59.19628960745675, 19.92938252857753, 0.257022605410644, 0.2221871739519494, 0.18310965012226785, 0.1391488861824785, 0.12688589920955046, 0.16743344201573304, 0.14653875678777695, 0.2464463072163718, 0.16678491181560925, 0.1219309243772711, 0.22781658545136452, 0.13287437787013395, 0.2349436730146408, 0.33065917981522425, 0.29865366007600513, 0.15350796282291412, 0.12116099069161074, 0.1431573046637433], [0.13311204154576572, 0.07600114680826664, 0.1314364807414157, 0.003853385952035231, 0.005473768712753164, 0.04764977902440088, 0.05324775738907712, 0.02862980802144323, 0.11449508980980941, 0.026515095960348845, 0.09722209202923945, 0.019578724234764065, 0.0440240034035274, 0.038837539564285956, 0.010478126899605351, 0.16227591090968677, 0.0460851383395493, 0.2927072234451771, 0.12562039068767003, 0.13254676759243011, 0.039409765108887634, 0.07598790180470262, 0.07615439394222838, 0.39792851731181145, 18.395063945225306, 66.17271872929165, 45.328571115221294, 67.60406848362514, 80.31713185991559, 46.25980690547398, 45.221964904240195, 31.816159180232457, 25.8791458266122, 36.514993122645784, 67.79733957563127, 63.60362924848284, 71.96725232260567, 50.105422905513215, 18.250746386391775, 1.25631887785026, 0.09758900984057359, 0.36104183377964155, 1.2057076564856937, 8.22000641482217, 30.28655842372349, 29.245145048413956, 52.7459329196385, 22.488551718848093, 30.50530161176409, 44.39801972252982, 61.205298696245464, 83.81666156223842, 91.03331770215715, 93.19384615761894, 76.41799736022949, 60.10844217027937, 68.35766315460205, 77.79194109780448, 65.57977335793632, 63.78936154501778, 48.12912940979004, 30.50566986628941, 17.029593535831996, 12.890931180545262, 11.483101946966988, 13.385343279157366, 16.37935679299491, 16.170702389308385, 25.35170112337385, 36.278097765786306, 58.38337121691023, 43.62232630593436, 18.856959342956543, 7.6293313673564365, 5.473708774362292, 0.1549660667244877, 0.6947882665055138, 0.178102224533047, 0.6975113632423537, 0.446281546992915, 0.22291411565882818, 0.8854880364877837, 0.5004866697958538, 0.21154657777931007, 1.6019918663161141, 0.8176474539296967, 5.836346115384783, 16.13152323450361, 22.408317395618983, 5.562694787979126, 4.277225068637303, 5.014744213649204, 0.6553368834512574, 1.2972842625209262, 3.1581592772688185, 0.9100792855024338, 0.20125903694757394, 0.9458447034869875, 0.33839572753225056, 0.07560579837965113, 0.13317927079541342, 0.9309363663196564, 0.2885427554803235, 0.2503299702491079, 0.6505559257098606, 2.0913272202014923, 3.020268802131925, 6.533995628356934, 21.48209125655038, 36.7743033681597, 45.0391960144043, 41.17301334653582, 23.75567732538496, 30.305162225450786, 34.07921525410244, 25.24149748257228, 21.395782470703125, 15.965938976832799, 18.679519721439906, 28.27668081011091, 31.502083233424596, 43.185315881456646, 47.1083938734872, 54.07054444721767, 54.17270033700125, 61.36938040597098, 59.141878264290945, 67.19242940630231, 61.77165331159319, 67.84845052446637, 62.728878838675364, 68.48335606711251, 74.02937344142369, 64.39753736768449, 31.51519101006644, 33.94148806163243, 58.10164260864258, 45.3360265323094, 30.773512499673025, 40.10381065096174, 9.29556497505733, 0.5969017190592629, 0.26622014758842333, 0.18193102122417518, 0.152334083669952, 0.07374543856297221, 0.08751131953405482, 5.170638339860099, 20.929938759122575, 23.99833447592599, 30.20436818259103, 35.21434245790754, 47.47841324125017, 45.65258298601423, 34.13789626530239, 39.97880213601248, 30.765935489109584, 1.2051207508359636, 0.04742465128323861, 0.09919147206736462, 0.02943639616881098, 0.04909038690051862, 0.08752158576888697, 0.06855954469314643, 0.06248657485204084, 0.048722983936646154, 0.038590864943606515, 0.05899323230343206, 0.08196722024253436, 0.08415874586041484, 0.08424831248287644, 0.097579964968775, 0.10803952121308871, 0.04852345732173749, 0.03419283843998398, 0.021024692537529126, 0.02361277098368321, 0.1351322302860873, 0.10736418209437813, 0.003790691860818437, 0.11482476283396993, 0.04909126560336777, 0.0777657517631139, 0.028209574321018796, 0.11646373703011445, 0.04946409006203924, 0.1961444571082081, 0.07243374894772257, 0.015398755137409483, 0.04165119358471461, 0.05965847482106515, 0.06570488680154085, 0.05664554863635983, 0.14670879766345024, 0.23721576109528542, 0.20005887134798936, 0.08980383151876074, 0.03178705181926489, 0.08561142148183924, 0.6583698264190129, 39.68734952381679, 78.44969926561627, 48.714588097163606, 83.33681201934814, 81.83091504233224, 50.52582366125924, 37.50937066759382, 35.70424951825823, 33.61341496876308, 48.60561255046299, 78.42914649418422, 72.98033441816057, 75.59639372144426, 46.37428889955793, 17.08336217062814, 0.394142210483551, 0.12295950204133987, 0.19061084118272575, 2.617959635598319, 18.37468661580767, 25.401980025427683, 31.759951727730886, 53.32711499077933, 30.81222438812256, 27.166954483304703, 38.397395610809326, 41.8903523172651, 59.38213307516915, 70.78567641122001, 71.57734721047538, 61.91042273385184, 53.36823443004063, 52.897837911333355, 65.6523333958217, 53.823077406202046, 52.46940851211548, 35.42774248123169, 26.92217639514378, 17.551667281559535, 16.635868651526316, 14.242970722062246, 16.615706716264995, 17.352485009602137, 17.54960192952837, 23.459525993892125, 37.187571798052105, 64.08075509752545, 52.49326515197754, 33.11851562772478, 6.553538739681244, 2.517094373703003, 0.7824850093041147, 0.17371781622724874, 0.1677744872868061, 1.0467487233025687, 0.14477566496602126, 0.11212423417185034, 1.0159282514027186, 0.38604473641940523, 0.6650170811585018, 3.7668633801596503, 8.356282302311488, 15.343595777239118, 27.049351011003765, 33.74627494812012, 9.973068186214991, 17.07754479135786, 14.901379414967128, 7.289682575634547, 5.723177765096937, 3.55192346232278, 1.2575061512844903, 1.3989780970982142, 1.944425800016948, 1.0831508785486221, 0.12384997068771295, 0.4427337045116084, 0.4709629054580416, 0.24430900333183153, 0.19527245818504266, 0.45155843240874155, 2.9404583190168654, 5.247406814779554, 9.406280176980154, 39.91386774608067, 44.528781345912385, 43.51871476854597, 40.49721418108259, 21.316489628383092, 30.17493908745902, 29.120325871876307, 28.71226511682783, 26.68176003864833, 19.84069745881217, 22.282905885151454, 30.136734417506627, 33.66540833881923, 42.63582454408918, 45.55392551422119, 55.16295412608555, 56.64550862993513, 60.817290442330496, 54.91572332382202, 60.31927830832345, 59.855222020830425, 65.78370993477958, 61.71323980603899, 65.87808731624058, 69.1499662399292, 60.67385877881731, 33.235498973301475, 40.87555749075753, 55.556461879185264, 46.15418039049421, 37.46867854254586, 43.79328325816563, 17.565118994031632, 0.48717956670692986, 0.23208020095314297, 0.23283741889255388, 0.3885710308594363, 0.09589005314878055, 0.15618753832365784, 4.713947142873492, 26.562212807791575, 28.650539057595388, 26.3529052734375, 30.584399904523575, 54.09307745524815, 55.535773617880686, 48.17815242494856, 49.382157121385845, 36.95750652040754, 2.512349839721407, 0.07028548672263112, 0.06678200007549354, 0.02016677660867572, 0.09732414369604417, 0.06772137752601079, 0.02654860880491989, 0.04445565006296549, 0.020288093580997417, 0.07018245796539954, 0.02653503301553428, 0.024933242538411702, 0.006711453058025134, 0.034587627077209096, 0.06949603158448424, 0.04946763540751167, 0.037162202676492076, 0.02045921502368791, 0.024041359146524752, 0.21514537824051722, 0.24089187383651733, 0.20131782522158964, 0.11997738134648119, 0.198559878926192, 0.18403870026980126, 0.18886106221803597, 0.12260157481900283, 0.2657647148839065, 0.26121361766542706, 0.266791826912335, 0.1527043195175273, 0.12458434913839612, 0.16124844604304858, 0.20862095191010407, 0.40833048628909246, 0.18630797921546868, 0.35322665742465426, 0.3202594907156059, 0.21793797053396702, 0.1892628228025777, 0.22984849927680834, 0.2696633328284536, 1.3545814965452467, 58.73971652984619, 90.70083945138114, 62.72904559544155, 90.67674309866769, 95.87764344896588, 69.47217505318778, 61.55830887385777, 43.596795150211875, 40.665822642190115, 58.15798207691738, 93.51501274108887, 82.78927312578473, 89.94145693097795, 56.45296015058245, 20.781556504113333, 1.110579978142466, 0.22370578960648604, 0.3721724679427487, 2.9684580394199918, 11.530536430222647, 39.93460464477539, 34.194669995989116, 68.14508996691022, 28.595749037606375, 38.77972023827689, 50.06784009933472, 67.67670495169503, 90.62513187953404, 96.96828828539167, 90.84386811937604, 75.83397347586495, 62.04136153629848, 69.89258970533098, 87.18896280016217, 73.12282807486397, 76.29790469578334, 61.718249457223074, 43.08222893306187, 22.54701386179243, 20.194482360567363, 15.363752501351492, 22.796139785221644, 26.62526249885559, 23.297872679574148, 31.217043808528356, 46.27579471043178, 74.55692236764091, 58.730176653180806, 42.652069432394846, 16.496420042855398, 13.993542551994324, 8.098068135125295, 1.1353482433727808, 0.26306387409567833, 1.7402458190917969, 0.49532448393957956, 0.2308202971305166, 1.1343794039317538, 0.7004070792879377, 0.9167759375912803, 4.125034766537802, 20.192154714039393, 24.39460587501526, 37.28051437650408, 40.36108160018921, 16.97265304837908, 31.52543612888881, 25.4450831753867, 17.933514220373972, 10.408088820321218, 8.361064399991717, 3.5041289755276273, 4.108174962656839, 2.8825422610555376, 3.4171093021120345, 0.8391630936946187, 0.9737247845956257, 1.039137514574187, 0.6422155903918403, 0.33234976338488714, 2.079727419785091, 13.888530952589852, 11.21812197140285, 19.91816987310137, 43.435186999184744, 43.1625257900783, 45.51944507871355, 44.55850573948452, 28.531818662370952, 37.99828066144671, 41.41509205954415, 40.00160264968872, 34.51397098813738, 24.447827339172363, 27.240054743630544, 37.695627553122385, 34.00221184321812, 41.19902392796108, 44.369170801980154, 54.17144966125488, 55.85631833757673, 61.93077400752476, 57.90427902766636, 66.08157226017543, 63.280941009521484, 67.89920711517334, 59.00797952924456, 68.13830852508545, 78.60158688681466, 72.89979090009416, 41.46034567696707, 46.75692619596209, 66.22651863098145, 54.55170372554234, 41.173961775643484, 50.88339185714722, 19.592530386788503, 0.5130623121346746, 0.8901706337928772, 0.3434246762522629, 0.5234576857515744, 0.5572787480694907, 0.3240885723914419, 7.385758791651044, 34.30891922542027, 39.302718094417024, 40.8976423399789, 48.53685317720686, 65.44793823787144, 63.806197030203684, 56.037610735212056, 60.36870779309954, 45.58902086530413, 2.4021444618701935, 0.254744681928839, 0.07162423631442444, 0.18639861792325974, 0.23552167628492626, 0.1966620571911335, 0.10437714202063424, 0.1491285485348531, 0.12921613774129323, 0.15966475888022355, 0.11506283363061291, 0.2754524036177567, 0.09128130759511675, 0.21735558392746107, 0.22441320307552814, 0.17102256656757422, 0.14078848463084015, 0.12639149145356246, 0.1589324296052967], [0.0407976983115077, 0.025388904248497317, 0.05096946410568697, 0.04760249191895127, 0.07033365592360497, 0.03504954657650419, 0.007202835820083107, 0.03801873778658254, 0.05011493745925171, 0.04288563538076622, 0.0450438279658556, 0.06620274830077376, 0.032298657045300515, 0.11863054361726556, 0.02121076380301799, 0.06737229161496673, 0.07525913483862366, 0.11011253390461206, 0.049312888711158714, 0.1952373914952789, 0.029742021911910603, 0.03471044870093465, 0.12136487689401422, 0.16966670432261058, 2.47962577853884, 59.120609828404014, 70.75805732182094, 51.933111803872244, 84.91587352752686, 57.20403609957014, 42.819705145699636, 37.83714498792376, 26.343325444630214, 37.665673868996755, 59.73014054979597, 50.91953638621739, 11.494321550641741, 4.125974076134818, 0.041654528584331274, 0.35400691841329845, 0.06259260951940503, 0.6253104603716305, 5.110411788736071, 17.813049827303203, 39.26464196613857, 54.66058547156197, 48.31051213400704, 24.023662396839686, 46.781210150037495, 62.214566230773926, 91.49828420366559, 91.61131055014474, 82.52446338108608, 69.00290761675153, 62.3065117427281, 57.446660246167866, 64.95497744424003, 65.8934497833252, 71.93505437033517, 73.56308678218296, 74.56608704158238, 56.70451273236956, 32.735079288482666, 22.87316230365208, 16.705147402627126, 21.533742427825928, 20.769704614366802, 21.439531803131104, 21.731901577540807, 38.14421715055193, 54.52527625220162, 33.670039313180105, 18.006199325834, 5.711594683783395, 2.6482348910399844, 1.3161247372627258, 0.14734628131347044, 0.10820152823414121, 0.04803751429010715, 0.46554841314043316, 0.629515314740794, 0.2553391328879765, 0.5568259209394455, 0.23841163835355214, 0.9493034950324467, 14.114766904285975, 17.39981961250305, 15.172763892582484, 24.917132990700857, 7.904243792806353, 10.139963047845022, 9.222804307937622, 2.941361801964896, 5.308644328798566, 1.0726384712117059, 0.04073171756629433, 0.1472907228661435, 0.37426186725497246, 0.1756303757429123, 1.8349545427731104, 0.06539207537259374, 0.6089487011943544, 0.21612136944064073, 0.2738230510481766, 0.18043227307498455, 1.655690910560744, 2.609796805041177, 8.004738194601876, 16.50841610772269, 32.75329746518816, 40.9462901524135, 40.332993507385254, 30.173830849783762, 28.574228729520524, 25.830928802490234, 30.564465522766113, 23.694937910352433, 30.98353222438267, 38.56221035548619, 45.98390783582415, 48.5566520690918, 48.05456829071045, 46.07807329722813, 50.040749073028564, 56.81668445042202, 57.34138808931623, 55.18100554602486, 55.42599555424282, 59.53153324127197, 62.38608946119036, 60.615584237234934, 65.12160914284843, 62.85201481410435, 68.6846592766898, 63.145742961338584, 37.01152876445225, 44.28232526779175, 46.11333193097796, 31.722462722233363, 40.47915928704398, 24.382392678941997, 0.34450911091906683, 0.2603302736367498, 0.1729411514742034, 0.16555755053247723, 0.2202445010521582, 0.09203054596270833, 0.9177584562982831, 14.964566332953316, 38.7747140611921, 30.318582671029226, 50.59808145250593, 58.35094397408621, 42.80335603441511, 49.79863909312657, 39.49878583635603, 10.13535726070404, 0.35319460343037334, 0.12851545533963613, 0.0989950904622674, 0.09780487897140638, 0.14273806501712116, 0.07033481621848685, 0.0031737381359562278, 0.12005060884569373, 0.01741360211079674, 0.029145593023193733, 0.11235345008649997, 0.07310056566659894, 0.06759441683867148, 0.054381284064480236, 0.07508188113570213, 0.0684024231242282, 0.055208438608263216, 0.09651055985263415, 0.07895039248147181, 0.1614142528602055, 0.21778619582099573, 0.1334669017898185, 0.032989225882504664, 0.10537266145859446, 0.01773931927579854, 0.01631855345996363, 0.05839265417307615, 0.03168610955721565, 0.023492945092064992, 0.033511266977127106, 0.03387352325288313, 0.022320942088429416, 0.11727611986654145, 0.033672246017626355, 0.11862075914229665, 0.01865496326770101, 0.11103102604725532, 0.09962707119328634, 0.04007346395935331, 0.032183848920145204, 0.020616205974615047, 0.07982446772179433, 0.2392358955528055, 6.810542183262961, 79.55490752628872, 71.50158405303955, 65.47252096448625, 84.87907586778913, 63.64384542192732, 37.98181690488543, 33.35806172234671, 35.39927918570382, 45.78596755436489, 72.77314608437675, 56.34588146209717, 13.085019554410662, 3.6662009188107083, 0.08486398123204708, 0.2958873542291777, 0.20333173072763852, 1.3297723020826067, 17.928259645189556, 22.293430668967112, 32.43154375893729, 53.467350482940674, 49.7515025138855, 26.21318221092224, 34.838323320661274, 53.48327922821045, 67.98337759290422, 82.92729214259556, 71.15269415719169, 65.32479531424386, 61.20128958565848, 53.93478012084961, 57.951050826481406, 61.51886395045689, 65.42686435154506, 65.00248227800641, 59.15039675576346, 50.06586333683559, 27.38746772493635, 22.631010634558542, 17.21604323387146, 22.00484071459089, 18.533487694604055, 20.745444978986466, 21.9185562474387, 41.288971832820344, 62.13175759996687, 45.5632951600211, 33.9874712399074, 4.874127004827772, 4.518584643091474, 4.912403328078134, 0.3632523651633944, 0.05739865465355771, 0.08737130383295671, 0.37292214057275225, 0.6323974058032036, 0.20057077173675808, 0.3340279704758099, 0.13387913895504816, 0.7918646431394986, 24.039811747414724, 31.58842502321516, 25.108719144548687, 32.56357690266201, 12.624607597078596, 25.307018995285034, 21.426526512418473, 12.593492695263453, 15.047366278512136, 2.768724254199437, 0.4105469344982079, 0.23184681204812868, 1.1182118143354143, 0.7849966202463422, 2.403991162776947, 0.024269058535407697, 0.1591191217303276, 0.17552432071949753, 0.05265141331723758, 0.2596585511096886, 4.244797391550882, 3.965959233897073, 13.3578987632479, 29.40655517578125, 43.76584134783064, 41.275468008858816, 39.23683180127825, 28.760199001857213, 27.372911248888286, 22.903713532856532, 26.473607642310007, 23.55645510128566, 25.009064606257848, 36.626129559108186, 44.71737282616751, 50.24807637078421, 50.535356589726035, 48.34429774965559, 51.943770340510774, 59.846905027117046, 57.50161007472447, 54.32832956314087, 53.405508041381836, 59.71413190024239, 62.10000433240618, 61.479287011282786, 65.13113512311662, 63.58415344783238, 63.459905760628835, 60.89973776681082, 43.29609448569161, 46.7845070702689, 48.57192420959473, 38.527823720659526, 43.98997286387852, 30.241270065307617, 0.8302833501781736, 0.11578947678208351, 0.05724065777446542, 0.2604785742504256, 0.23620957508683205, 0.16353380626865796, 0.7711452235068593, 19.561892305101665, 34.685049533843994, 24.581406457083567, 46.59527635574341, 62.25669315883091, 48.77881724493844, 56.830917835235596, 51.067140442984446, 16.035037074770244, 0.08115868469966309, 0.08117084404719727, 0.028963114600628614, 0.07175997045955487, 0.08376303780823946, 0.08394308707543782, 0.017960643828181282, 0.1434644910373858, 0.07988050114363432, 0.056746331442679675, 0.07103066745081119, 0.024557340923430662, 0.0501788520653333, 0.04750293047566499, 0.03964856533067567, 0.02734120556020311, 0.043199383188039064, 0.06214544815676553, 0.028527169421847378, 0.19894796024475778, 0.3575788624584675, 0.2568472448204245, 0.10489945792193923, 0.17938732914626598, 0.16048275998660497, 0.13844170341534273, 0.13447410560079984, 0.20020277505474432, 0.14607659301587514, 0.18061752670577594, 0.21108558108764036, 0.20810234759535107, 0.24663304005350384, 0.1451745621327843, 0.31774728266256197, 0.17543335631489754, 0.13037000011120523, 0.2117847842829568, 0.3215482729886259, 0.2233516757509538, 0.12499214868460383, 0.30248513019510676, 0.4476421725537096, 15.452859674181257, 104.37808350154332, 82.23965672084263, 76.519517489842, 94.66534260341099, 76.30618000030518, 56.82657173701695, 51.37877409798758, 40.35185439246041, 62.14262458256313, 83.01965454646519, 68.9907899584089, 15.791315112795148, 4.709889829158783, 0.1647018093083586, 0.6045308953949383, 0.1736657183085169, 3.147503129073552, 11.019483395985194, 22.99991307939802, 49.460571016584126, 67.62360681806291, 63.52343314034598, 31.04355423791068, 57.871910844530376, 73.50172724042619, 96.53091308048793, 95.88733618600028, 78.8737130846296, 63.98792716435024, 57.90753425870623, 52.06974465506417, 65.07240894862584, 67.89476721627372, 73.63890552520752, 75.70916993277413, 81.84855651855469, 67.70032187870571, 38.33135298320225, 28.430666787283762, 22.08090090751648, 31.65661464418684, 26.95637890270778, 30.30232388632638, 28.217992850712367, 49.41050229753767, 68.94322953905377, 44.512265477861675, 40.702147824423655, 13.866565091269356, 12.164174795150757, 10.784666419029236, 0.3809525210942541, 0.2629026270338467, 0.2934311660272734, 1.1370316616126468, 0.6888591732297624, 0.6640994846820831, 0.7033899735127176, 0.3912518141525132, 1.474843523332051, 32.15634993144444, 39.188618251255576, 34.439319542476106, 38.09711531230381, 18.952554396220616, 36.27335214614868, 31.510883126940044, 22.529606887272426, 19.226938758577617, 3.5827198326587677, 0.4241646166358675, 0.8152078219822475, 2.5619035235473087, 0.884330727159977, 6.004996265683856, 0.12747823313942977, 1.0768874032156808, 0.8200633100100926, 0.42814731863992556, 0.3840535618364811, 6.916113981178828, 11.569214446204048, 20.586002928870066, 36.96821369443621, 42.029020990644185, 43.86775752476284, 41.001542227608816, 36.99675689424787, 36.58259909493582, 33.16580159323556, 39.05937480926514, 30.931535380227224, 38.167330333164756, 44.66158921377999, 49.221115248543875, 49.56716333116804, 48.55112130301339, 44.76552036830357, 49.01791518075125, 61.26697785513741, 61.55357020241873, 55.92395905085972, 51.79330710002354, 58.62564100537981, 62.89947101048061, 62.390133312770296, 69.53208242143903, 66.4993952342442, 69.08864838736397, 70.7942921774728, 47.1661125591823, 53.23146956307547, 55.26063537597656, 44.737776211329866, 54.2949469430106, 36.92497852870396, 1.7170134314468928, 0.6926003981913839, 0.23950114846229553, 0.796671276646001, 0.3330293840595654, 0.4193096714360373, 1.2530023072447096, 24.20856785774231, 49.32029383523123, 41.641895157950266, 67.98220334734235, 74.49040726252964, 64.04127543313163, 68.25077901567731, 62.18646771567208, 15.389283657073975, 0.5263676238911492, 0.23031921258994512, 0.1177978590130806, 0.18226513186735765, 0.2469244029905115, 0.16678872518241405, 0.056259295969669304, 0.22548051151846135, 0.22099662997892924, 0.16719066218606063, 0.1819822641887835, 0.18144822998770646, 0.2091543890003647, 0.20620211027562618, 0.1016012824007443, 0.11665926368108817, 0.13653073167162283, 0.11257829623562948, 0.18485537144754613], [0.02410607612026589, 0.0767478881669896, 0.12905385930623325, 0.059835742094687054, 0.10230818018317223, 0.04569911298209003, 0.04884882843387978, 0.0231224666682205, 0.06424301703061376, 0.025206934727196182, 0.051557265421641726, 0.011352683051622339, 0.060468150302767754, 0.030275859337832247, 0.03223039981509958, 0.06371200909571988, 0.14306735806167126, 0.06549680046737194, 0.02603968888122056, 0.026107849420181344, 0.029881973152181933, 0.042661352415702174, 0.04116585444925087, 0.04550702989633594, 0.9675763888018472, 50.1332573890686, 73.44090965815953, 73.43018163953508, 80.73386396680559, 80.7336346762521, 50.41908890860421, 42.86900608880179, 30.555231366838726, 28.81205514499119, 31.174524307250977, 5.647760280541011, 0.4032141694000789, 0.07831318703080926, 0.020085454186690704, 0.09785669190543038, 0.5856941118836403, 3.8871857694217136, 5.120976090431213, 35.523995876312256, 38.38248825073242, 70.50181470598493, 36.21566472734724, 47.19935621534075, 81.32151481083461, 78.8000830241612, 82.58338410513741, 70.28199454716274, 71.27876922062465, 63.20533071245466, 57.15870605196272, 59.11245264325823, 64.8706888471331, 65.82654557909284, 65.79992703029087, 72.93376064300537, 72.14805139814104, 70.6678488595145, 58.66768455505371, 42.48825870241438, 32.73133768354143, 27.19303628376552, 24.099340438842773, 23.898534025464738, 22.816299983433314, 27.276610953467234, 45.569739614214214, 31.755570888519287, 11.531042780194964, 2.954655877181462, 3.5348801825727736, 0.8153213816029685, 0.1376745110111577, 0.1203495306628091, 0.18985989290688718, 0.09461978131106921, 0.11839844392878668, 0.0034377164598221755, 0.3140214468751635, 0.03742138609024031, 0.17172342538833618, 8.455866490091596, 38.87858963012695, 19.398010356085642, 22.213978018079484, 8.337078349930898, 16.896662337439402, 12.198755979537964, 5.862119155270713, 16.038302728107997, 0.6371017162288938, 0.5585308894515038, 0.5228238254785538, 0.4456498308905533, 0.5347931289247104, 0.3596214699958052, 0.1056908265288387, 0.0807303458984409, 0.044880541906292946, 0.31522153105054584, 0.19088119667555603, 0.5827834137848446, 4.3377134799957275, 8.265232239450727, 22.71383489881243, 31.45959152494158, 48.40287801197597, 34.47346993855068, 26.433855261121476, 27.30614079747881, 28.3631146635328, 24.578239815575735, 33.39663117272513, 49.33922072819301, 55.87576634543282, 52.7235666683742, 51.52045828955514, 52.78611435209002, 51.302698271615164, 55.7793288230896, 57.58946309770857, 60.52720315115792, 59.263562066214426, 58.96477563040597, 58.47310025351388, 58.6467843736921, 61.28444562639509, 60.762976373944966, 63.41008717673165, 61.250594002859934, 69.36639567783901, 49.88872596195766, 42.397779260362896, 39.090065002441406, 44.91727944782802, 35.069757393428254, 34.216337953295024, 2.9199303005422865, 0.31736760160752703, 0.42028222924896647, 0.07625327685049602, 0.08646641631743737, 0.0996211204411728, 0.5756064131855965, 9.125550372259957, 31.73344087600708, 40.844426086970735, 54.55424329212734, 57.78168501172747, 58.17589800698416, 52.89191804613386, 26.323455333709717, 1.1814880818128586, 0.03953691917870726, 0.11171801561223609, 0.05100816435047558, 0.05180666436042104, 0.03270923858508468, 0.05419415767703738, 0.04717969335615635, 0.018471836844193082, 0.05686438635789922, 0.03992455944951091, 0.1186088847794703, 0.03470085421577096, 0.10773661639541388, 0.027467028005048633, 0.07212526657219444, 0.0707626189770443, 0.011839794859822308, 0.035735766004238806, 0.06731275016708033, 0.06692863827837364, 0.03497874144730823, 0.12222093024424144, 0.025128691157858287, 0.0462253067110266, 0.04557131430400269, 0.028366132705871547, 0.03164021684122937, 0.03841552470943757, 0.11826519322182451, 0.006915739596089614, 0.07601330615580082, 0.10407351795583963, 0.03583305096253753, 0.03318147181666323, 0.09711351285555533, 0.13146364928356238, 0.06382483589862074, 0.1520778959883111, 0.026277264347299933, 0.0964780580252409, 0.05812567099928856, 0.013187220369997834, 0.03618959058076143, 2.5208713710308075, 71.56640379769462, 81.34313065665108, 84.25680909837995, 88.69055189405168, 80.049195425851, 46.70833396911621, 28.83236125537327, 35.67018597466605, 41.6004387310573, 42.35559674671718, 6.762948325702122, 0.2315710282751492, 0.07393958778785807, 0.06918645676757608, 0.1397684836494071, 1.0577434876135416, 7.166129274027688, 10.692363943372454, 17.74647913660322, 40.10592985153198, 61.52604143960135, 41.592010566166465, 38.252456188201904, 61.708139828273225, 66.21050303322929, 77.69807093484062, 68.76254858289445, 71.08790220533098, 64.67178276606968, 58.02685914720808, 58.35245868137905, 65.79349994659424, 65.60535662514823, 64.76946749005998, 68.0798533303397, 66.82908030918666, 67.8402933393206, 49.01947505133492, 33.46344157627651, 25.460971968514578, 26.464121614183696, 20.943475587027415, 23.105883530208043, 21.078022241592407, 33.06879431860787, 50.72720677512032, 40.54468079975673, 27.127949033464702, 4.288060350077493, 1.5591051961694444, 3.5878575912543704, 0.23094134777784348, 0.05514405581301876, 0.2922387628683022, 0.04123987244176013, 0.13620553697858537, 0.054689060763588974, 0.5957544520497322, 0.18357515228646143, 0.037490817186023505, 9.961605395589556, 47.606176716940745, 28.706701346806117, 28.576196806771414, 11.19589468411037, 29.022802693503245, 23.04280083520072, 17.020138774599346, 23.658406019210815, 3.9799915552139282, 1.2476149563278471, 0.5456509377275194, 0.7838611326047352, 2.4556082444531575, 1.6749044167143958, 0.31497180302228245, 0.09791535125779254, 0.08151694440415927, 0.2740665636956692, 0.1466180503900562, 3.127906386341367, 4.042005096163068, 10.10142833845956, 26.579758746283396, 40.65960053035191, 48.9737663269043, 37.66211291721889, 26.403658390045166, 23.481656006404332, 23.812308618000575, 22.134488889149257, 24.109399693352835, 39.280921595437185, 54.844792638506206, 53.897989409310476, 55.895586081913535, 56.404986313411165, 53.43623992374965, 55.62727444512503, 57.53089325768607, 59.2271465573992, 59.444409779139924, 57.638684136526926, 59.54768085479736, 58.812582288469585, 61.33618886130196, 60.38507774897984, 65.32323891775948, 63.867598261152, 66.49030699048723, 53.79630599703108, 46.55326407296317, 43.91926104681832, 50.1177351134164, 38.031208174569265, 39.81702375411987, 5.345276100294931, 0.36937701223152025, 0.5158830093485969, 0.1284991433577878, 0.3912793898156711, 0.0321267230569252, 0.6855245264513152, 10.765590139797755, 29.194881779806956, 34.87137590135847, 57.720652035304475, 64.63998086111886, 65.623824937003, 61.53877053941999, 36.83260570253645, 2.3372945359774997, 0.09412362293473311, 0.1336940617433616, 0.04299559537321329, 0.04555658670142293, 0.06507304856287581, 0.012343162670731544, 0.03739231425736632, 0.045478687488607, 0.03521558070289237, 0.054382329008408954, 0.01905664073170296, 0.06266306181039129, 0.007017273879942617, 0.04374340881726571, 0.05373913887888193, 0.033159432999257527, 0.04989830158384783, 0.05763261352798768, 0.039634838567248414, 0.15970819869211741, 0.1849744272019182, 0.2942063787153789, 0.16444122471979686, 0.10150080493518285, 0.11239336151629686, 0.1442878254290138, 0.1123439980936902, 0.13642432380999836, 0.16509754450193473, 0.07787843607366085, 0.13810516361679348, 0.18417747425181524, 0.21886410298092024, 0.12791522326213972, 0.2027143317141703, 0.3328127142574106, 0.1650566424110106, 0.24770216697028705, 0.19060721780572618, 0.21308265892522676, 0.13845572194882802, 0.08280811512044498, 0.10855860728770494, 3.927969523838588, 94.38306508745465, 86.56582750592912, 93.1349949155535, 100.39907945905412, 96.73616981506348, 68.86502061571393, 57.87249796731131, 44.76028837476458, 54.65102127620152, 57.045561586107524, 8.27471739905221, 0.47594362390892847, 0.22957423542227062, 0.13606327532657556, 0.18527071630316122, 1.4421223934207643, 12.237714529037476, 8.909028002193995, 44.98944691249302, 50.72125564302717, 82.76312705448696, 47.907457556043354, 53.877766677311485, 94.84597492218018, 82.03155817304338, 83.64790371486119, 72.71867915562221, 73.17331368582589, 64.31795964922223, 55.28464487620762, 54.481495652879985, 63.6232579095023, 64.48302800314767, 67.20129530770438, 73.2334156036377, 73.13156196049282, 75.23702594212124, 64.43478666033063, 52.01703214645386, 43.481329986027305, 37.251373631613596, 29.011756794793264, 31.676559448242188, 30.54620565686907, 37.063796588352744, 58.22065135410854, 44.263189928872244, 33.295844078063965, 9.088487812450953, 6.96052382673536, 7.168984983648572, 0.2466247347848756, 0.1781045858349119, 0.5688277940664972, 0.2279890961945057, 0.2086708378046751, 0.11584646015294961, 1.2179861004863466, 0.13968258111604623, 0.20080740403916153, 17.23104613167899, 54.44629260471889, 35.107128279549734, 32.8393474306379, 16.838955811091832, 40.19662121364048, 35.05246680123465, 26.747456993375504, 29.999024595533097, 5.185292959213257, 2.2258905938693454, 0.5543781465717724, 1.0842294778142656, 5.08080073765346, 4.789770662784576, 0.45148810903940884, 0.15807451706911835, 0.12886791356972285, 0.33468959640179363, 0.6824525541492871, 5.034433671406337, 11.320496729442052, 15.136588096618652, 40.66179963520595, 39.48693568365914, 52.11731549671718, 40.19346325738089, 34.16192661012922, 34.2018335887364, 33.25153888974871, 30.216145379202707, 41.34978246688843, 57.40261214120047, 59.75810704912458, 53.09521538870675, 52.80071946552822, 54.4229952948434, 50.949531759534565, 58.17535604749407, 59.41128771645682, 62.260271481105256, 58.616260937282014, 57.3308059828622, 56.11149787902832, 59.42829690660749, 63.39776802062988, 62.76949800763811, 64.70670441218785, 64.98044259207589, 70.62971019744873, 59.201688357761924, 53.24490737915039, 48.07951579775129, 56.691175665174214, 44.96159505844116, 45.03950868334089, 6.6254096031188965, 0.5405579081603459, 0.7442732283047268, 0.3777582496404648, 0.9903981813362667, 0.423059418797493, 0.923670939036778, 15.309414114270892, 39.954570293426514, 52.728041308266775, 71.4483539036342, 74.51137692587716, 74.18327604021344, 66.887389591762, 41.347010135650635, 1.8235966265201569, 0.13440081024808542, 0.2991295302552836, 0.0877756564212697, 0.21699640820068972, 0.24283199544463838, 0.12017400722418513, 0.12295278454465525, 0.11323267540761403, 0.11419107898005418, 0.1458905522844621, 0.15168737194367818, 0.14079407575939382, 0.21321248981569493, 0.150361690936344, 0.12207499093243054, 0.18022101798227855, 0.09257589134254626, 0.2220319929931845, 0.16592766424374922], [0.030916372646710703, 0.08068944380751678, 0.07690000893282038, 0.05514009316850986, 0.0394588299760861, 0.101590283348092, 0.020124887249299457, 0.13373857364058495, 0.019085834700880305, 0.030447362456470728, 0.05189872120640107, 0.03176404608945761, 0.1408708044993026, 0.08637731788413865, 0.0856893105166299, 0.01232434350198933, 0.07191530748137406, 0.05310655425169638, 0.09034410145665918, 0.09616783181471483, 0.08514468438391175, 0.09786553321672337, 0.20257053657301835, 0.16491415005709442, 0.37119898732219425, 33.65585456575666, 84.56011881147111, 69.36690289633614, 70.31359495435441, 87.51363127572196, 61.271841594151084, 53.27581991468157, 38.26816953931536, 26.11420338494437, 7.981754422187805, 0.6932111882737705, 0.04048235594694104, 0.06219234849725451, 0.18147055378982, 0.5129606404474804, 2.1980706581047604, 3.5491428800991605, 48.6849227632795, 49.64012289047241, 49.37921803338187, 76.27299540383476, 39.85494007383074, 68.29671355656215, 80.60361303601945, 74.36596502576555, 61.43989767347063, 68.66684409550258, 64.2543419429234, 65.21620886666435, 61.34199060712542, 63.76602949414934, 62.68920462472098, 63.53591210501534, 64.00722231183732, 65.95042501177106, 64.64531707763672, 66.54530893053327, 65.69020802634103, 65.7524847303118, 58.10071849822998, 32.22881269454956, 29.59977068219866, 36.82605355126517, 31.56535700389317, 26.541898012161255, 43.377374512808665, 36.203053746904644, 9.892293640545436, 3.8177116002355302, 4.000335446425846, 0.9596614135163171, 1.5165883004665375, 0.24983303834285053, 0.17992794513702393, 0.09587967834834542, 0.6063914926988738, 0.28092557564377785, 0.21870892202215536, 0.05067428780187454, 0.10409377901149647, 0.037579905441296954, 16.61553474834987, 17.062772921153478, 22.872024536132812, 7.325064539909363, 23.883289677756174, 13.768753562654767, 6.185582986899784, 15.692853927612305, 4.0117917231151035, 0.5591306058423859, 0.1619562123503004, 0.05711521700556789, 0.7625469363161496, 0.2302758949143546, 0.05894500881965671, 0.07026584313384124, 0.0773726628561105, 0.23445377073117665, 0.07734431366303138, 2.9944308400154114, 3.9725934607642035, 14.356985449790955, 20.60552041871207, 30.399845327649796, 44.74272332872663, 38.222631045750205, 25.938478231430054, 27.05542026247297, 22.24728420802525, 28.66806067739214, 50.23607335771833, 60.43357617514474, 55.58226401465279, 52.67409202030727, 52.00626591273716, 53.79055288859776, 54.27886881147112, 58.37006541660854, 60.90346894945417, 57.83527646745954, 56.4018109866551, 57.79549108232771, 60.80217811039516, 61.662837573460166, 62.16089139665876, 60.63761002676827, 61.20751517159598, 61.45165402548653, 67.5558340890067, 60.998291015625, 43.70277949741909, 43.69231898444039, 42.02998331614903, 43.746150153023855, 39.19284275599888, 6.423754206725529, 1.422097576516015, 1.3930364102125168, 0.09107242058962584, 0.08937305677682161, 0.027544784725510647, 0.46651019581726616, 3.127976736852101, 23.946582555770874, 36.403356415884836, 56.448951039995464, 51.79619755063738, 46.4432497705732, 46.80255501610892, 8.31770156111036, 0.08120921520250184, 0.014943758391642144, 0.03489148862926023, 0.05610443731503827, 0.04188826693488019, 0.055644906259008815, 0.02816184956048216, 0.008760759856418839, 0.047905332275799344, 0.025753118097782135, 0.02690441899799875, 0.07815061682569129, 0.07717881218663283, 0.03465676301025918, 0.017309845624757663, 0.01626877613099558, 0.056367189822984595, 0.029534020394619023, 0.024856915830501487, 0.09116464028401033, 0.02067604088889701, 0.05520221644214221, 0.06706494239291974, 0.023173109129337326, 0.010315820474975874, 0.0943626029683011, 0.0962983819523028, 0.04747527678097997, 0.012700962667752589, 0.04602372752768653, 0.0321941931865045, 0.042589329316147735, 0.19413682126573154, 0.06882255843707494, 0.06788829035524811, 0.11708872206509113, 0.06570237622197185, 0.048183891257005076, 0.044192269910126925, 0.09174969353313957, 0.10683202064995255, 0.3124909432871001, 0.18542847569499696, 0.153349280623453, 0.6542900396244866, 45.26246247972761, 89.44026252201625, 72.12264878409249, 84.81389481680733, 88.04980291639055, 64.7701414653233, 36.86642953327724, 33.54933173315865, 40.874612535749165, 9.9229690687997, 0.4218358301690647, 0.16297094789998873, 0.16916927030043943, 0.05090652319735714, 0.8575492756707328, 4.447950993265424, 9.516136407852173, 27.20211410522461, 31.75139502116612, 45.74677276611328, 71.52435329982212, 41.46072435379028, 59.66646030970982, 73.6879528590611, 68.76910768236432, 65.36346898760114, 70.21087973458427, 66.27407210213798, 64.6454838344029, 60.29142992837088, 63.305141585213796, 66.54171671186174, 67.4063366481236, 63.13040133884975, 65.52550792694092, 63.46436650412423, 65.57793208530971, 60.98274094717843, 57.74011046545846, 40.84255007335118, 25.987872975213186, 21.64852145739964, 31.082693440573557, 30.61044522694179, 30.17375441959926, 48.49691840580532, 49.02117735998971, 20.03847966875349, 6.162891473088946, 1.1885034825120653, 0.6990596715893064, 0.9501459641116006, 0.15789451529937132, 0.11182575340249709, 0.17845682693379267, 0.6216350804482187, 0.06945205572992563, 0.13771519597087586, 0.08189771111522402, 0.1677096871925252, 0.7629643710596221, 21.936654567718506, 25.459215811320714, 29.287306717463903, 8.012117181505475, 32.51606512069702, 25.547259909766062, 15.209858587809972, 12.2981265102114, 4.912926614284515, 1.3869616218975611, 0.2239069209567138, 0.2769649124571255, 0.23632864441190446, 0.022701079458264366, 0.045670339704624245, 0.20484790365610803, 0.0886225766901459, 0.24640836353812898, 0.040794617762523036, 6.25596650157656, 3.6464263456208363, 13.133027264050074, 25.532262223107473, 37.802782671792166, 51.74046604973929, 38.95084742137364, 25.497483015060425, 23.0415484224047, 9.349648884364537, 18.836813041142054, 42.023198400224956, 54.58605561937605, 57.57457658222744, 55.0263421194894, 53.765254497528076, 52.08644812447684, 51.827405384608674, 57.98535755702427, 61.415280205862864, 58.36481952667236, 58.94997596740723, 56.4742112159729, 58.8954256602696, 61.26266302381243, 64.89732824053083, 60.25450720105852, 63.191107749938965, 63.24133627755301, 68.07789393833706, 61.238177571977886, 49.66404553822109, 45.75398499625069, 47.12673364366804, 47.601264340536936, 49.717095034463064, 11.780212998390198, 1.6668434206928526, 3.6303744869572774, 0.08446815104356833, 0.21794964133628777, 0.0469700701401702, 0.8349471656339509, 6.273350894451141, 31.789721284593853, 35.90917273930141, 57.08861609867641, 59.04265104021345, 52.66345085416521, 57.03093562807356, 13.223307813916888, 0.18006378784775734, 0.06935134077710764, 0.038854862563312054, 0.0781369579157659, 0.06743210447686059, 0.02907012975109475, 0.04908921303493636, 0.042430033042494736, 0.024002306063526442, 0.04046235273459128, 0.019436152152983204, 0.061721166994954856, 0.028069981007969806, 0.05584372719749808, 0.016586669787232364, 0.03181273436972073, 0.039934418563331874, 0.015596303822738784, 0.03194353895794068, 0.12383942625352315, 0.11634611976998192, 0.15610418708196708, 0.23692442529967853, 0.15324017219245434, 0.09148995032800095, 0.2336207197180816, 0.19414807137634071, 0.13897877745330334, 0.10923231113702059, 0.11398080097777502, 0.13317545742860862, 0.08766618836671114, 0.3779715267675263, 0.24512378818222455, 0.15542975041483129, 0.22517109954995768, 0.10597433203033038, 0.2563549812350954, 0.17460942481245312, 0.2528666598456246, 0.2862638277666909, 0.3486426919698715, 0.2667276646409716, 0.32398728068385807, 0.5420113844530923, 52.55946411405291, 110.7995252609253, 80.49687480926514, 88.9169589451381, 106.39301940373012, 81.59986659458706, 67.75461510249546, 53.386633259909495, 46.77487686702183, 15.200026886803762, 0.5203751825860569, 0.19073529807584627, 0.28979500542793957, 0.7082642976726804, 0.9240809913192476, 9.203551718166896, 12.412017038890294, 59.37556702750069, 64.84525149209159, 61.32199369158064, 88.38915293557304, 48.78965643474034, 78.20369829450334, 87.48986843654087, 75.31716646466936, 64.77493572235107, 71.1861149924142, 66.20084503718785, 64.30205522264752, 59.377568108694895, 62.08128588540213, 64.71224907466343, 64.03442450932094, 63.62277153560093, 64.932861328125, 65.33992154257638, 66.7556517464774, 64.9602163859776, 66.78110299791608, 69.71066502162388, 46.27371025085449, 35.51542179925101, 48.67107152938843, 38.22725159781319, 34.57664721352713, 52.128293650490896, 55.69070107596261, 27.289492913654872, 12.973543524742126, 3.3539123960903714, 3.0897062761443, 2.7827309540339877, 0.39215380432350294, 0.3691430262156895, 0.26531677320599556, 1.336624637246132, 0.7038758045860699, 0.5419338143297604, 0.40837909653782845, 0.5898130908608437, 4.079709495816912, 35.76162774222237, 31.548761231558665, 32.351469244275776, 11.77809032372066, 41.26544870649065, 35.11381939479283, 29.205387456076487, 23.73775965826852, 9.591508729117256, 2.121709304196494, 0.6765782865030425, 0.2722453214228153, 0.746041653411729, 0.4217400210244315, 0.22297745011746883, 0.44119494993771824, 0.16786041696156773, 0.445919507848365, 0.14950233990592615, 7.184175048555646, 6.339928099087306, 22.04835033416748, 37.227068832942415, 37.89619425364903, 53.57202509471348, 47.52051585061209, 35.90759202412197, 32.57895674024309, 28.759436437061854, 36.735779081072124, 61.48110743931362, 64.1399120603289, 55.47330583844866, 52.146310329437256, 54.18540164402553, 56.89181184768677, 53.29090445382254, 56.69124167306082, 60.911737305777415, 59.10159955705915, 58.36593818664551, 56.24819673810686, 60.97779382978167, 63.943958963666645, 64.26302719116211, 62.17949867248535, 61.66121864318848, 63.151523862566265, 69.28470570700509, 65.80988379887172, 52.98746967315674, 53.95252582005092, 52.92153474262783, 55.671927043369834, 50.375954491751536, 11.723804916654315, 3.409049174615315, 4.271703856331961, 0.43224575157676426, 0.4486576137798173, 0.11980705548610006, 1.3666744019304002, 8.658603634153094, 37.01411002022879, 46.14503656114851, 71.73535619463239, 65.44664587293352, 60.50276633671352, 65.96471745627267, 13.039467164448329, 0.24418407146419796, 0.1186598970421723, 0.16081978833036764, 0.24237417429685593, 0.1372604418013777, 0.13231962120958737, 0.11001610050776175, 0.1072183513481702, 0.20208608971110412, 0.20900459560964788, 0.15327153408101626, 0.11325077193656138, 0.10929563202496086, 0.1612683678311961, 0.06898299125688416, 0.1060276445267456, 0.13956252112984657, 0.11013502055513007, 0.1467842643282243, 0.15473731899900095], [0.08329596822815281, 0.07894539846373455, 0.058834550103970935, 0.02035333133036537, 0.035357662543122254, 0.06030719501099416, 0.04363649544705238, 0.1245920437255076, 0.05866395961493254, 0.02087609506478267, 0.05738874804228544, 0.061373580646302016, 0.0632959178515843, 0.06419848477733986, 0.015868593140372207, 0.06126676566366639, 0.03650345713166254, 0.03121278727693217, 0.05118876662371414, 0.0651765251532197, 0.028568061334746223, 0.001065685153922199, 0.018234822865841643, 0.040922260377556086, 0.16154571223471845, 4.685355305671692, 89.5309226172311, 66.9042111805507, 53.402711391448975, 81.45416981833321, 75.01963765280587, 44.519290106637136, 49.63561698368618, 22.745695863451274, 0.5115827258144106, 0.16595340786235674, 0.16090381810707705, 0.6412683012230056, 0.37630865456802504, 0.13987538005624497, 1.1003600465399879, 13.391258801732745, 81.32257093702043, 47.08586433955601, 64.6518553325108, 61.29037938799177, 51.34904970441546, 82.06132425580705, 73.26421696799142, 69.73603289467948, 68.94688429151262, 63.12080587659563, 64.77590152195522, 67.71414184570312, 67.76222337995256, 65.58210795266288, 65.6159109388079, 66.17778396606445, 67.39246109553746, 63.69902106693813, 63.47566427503313, 63.17036737714495, 64.96674074445451, 59.556977544512065, 65.27753366742814, 51.943902356284006, 28.5490779876709, 36.9624536378043, 27.632304872785294, 25.644845621926443, 39.37116479873657, 33.67556313105992, 12.180588177272252, 2.783979675599507, 3.2559757999011447, 0.6911931165627071, 0.2171122476990734, 0.15420677246791975, 0.0745413126423955, 0.07213510532996484, 0.18573524137692793, 0.6234657679285321, 0.7721780623708452, 0.16120478909994873, 0.17312571299927576, 0.6454481855034828, 3.903320789337158, 11.142144288335528, 20.850849151611328, 5.558658753122602, 22.785946777888707, 17.288664068494523, 6.525593084948404, 4.0529806443623135, 1.307552831513541, 0.2896444520780018, 0.16173739837748663, 0.6779119606528963, 1.5938964549984251, 0.027430387114041617, 0.078952000609466, 0.10457565422569003, 0.1322834010102919, 0.12053292510764939, 0.45371188542672564, 1.9284243157931735, 4.969244369438716, 16.182616812842234, 22.818856920514786, 26.919107028416224, 41.555251121520996, 35.23314775739397, 28.31890674999782, 30.122514929090226, 84.76383999415806, 52.805399077279226, 49.767104693821494, 64.0695823941912, 50.50244297300066, 57.057575021471294, 57.45228828702654, 61.35055078778948, 57.909761156354634, 54.24020903451102, 58.038782255990164, 61.674190929957796, 57.581854820251465, 67.51132392883301, 65.46363421848842, 59.85304028647286, 63.29417732783726, 63.19285869598389, 62.68040820530483, 64.4227523803711, 63.80688490186419, 68.2782313483102, 53.191176959446494, 37.24558230808803, 49.24955422537667, 47.63658203397478, 47.31798280988421, 8.158104913575308, 1.1621686156306947, 2.488195295844759, 0.7262504696846008, 0.3672318644821644, 0.21619997093720095, 0.14981883578002453, 4.858147885118212, 25.87432551383972, 42.96074315479824, 64.77428259168352, 46.12097494942801, 44.40469694137573, 29.735406466892787, 0.2500980741211346, 0.08045604133180209, 0.06385726308716194, 0.09273262614650385, 0.036999876743980815, 0.051013952254184654, 0.05954522054110255, 0.034455607911305766, 0.11850042774208955, 0.03311250212469271, 0.014749744873760002, 0.05873839490647827, 0.03638091370729463, 0.043251840730330775, 0.11605829878577165, 0.046194077136793306, 0.04839209633480225, 0.08209787216037512, 0.11000567142452512, 0.04414749677692141, 0.09677863546780177, 0.04699725903836744, 0.07273732551506587, 0.0188772683031857, 0.016418074191148792, 0.05848798155784607, 0.14781471474894456, 0.014803323695170028, 0.0552966040559113, 0.04003633113045778, 0.04814767445038472, 0.037151987331786325, 0.038134343190384765, 0.034219738960798295, 0.027662276456664716, 0.012276634856659387, 0.06432227670614209, 0.07287743621106658, 0.013597426171015416, 0.056863555152501376, 0.032824606501630375, 0.045691683023635826, 0.04863663696284805, 0.058150763224278174, 0.1451828402600118, 0.17271739776645387, 9.533958537237984, 103.48390592847551, 72.37944030761719, 63.90633446829659, 84.48095103672573, 74.1113760811942, 40.93165724618094, 33.076986244746614, 32.545918055943076, 0.9518123375517982, 0.15249085240066051, 0.06388678614582334, 0.6828482214893613, 0.43713872187903946, 0.43969612036432537, 3.571460928235735, 18.978627511433192, 83.33560303279332, 53.38640744345528, 68.62857341766357, 65.92455686841691, 51.620547090257915, 73.18809945242745, 73.68946756635393, 70.84019892556327, 70.68962451389858, 64.62627901349748, 64.9129616873605, 65.14165469578334, 68.77897412436349, 67.21002919333321, 65.49785409654889, 67.98567744663784, 66.23299435206822, 64.58986350468227, 62.32926709311349, 63.208130836486816, 63.220297132219585, 60.81790883200509, 55.480486801692415, 38.03915343965803, 26.43784179006304, 42.3503543308803, 29.491403102874756, 32.160709926060264, 46.87765114648001, 45.24592924118042, 20.680052007947648, 5.5726150785173685, 2.302766114473343, 0.6121968754700252, 0.3604411674397332, 0.0785726656072906, 0.04277377209759184, 0.11891128069588117, 0.5812235974839756, 0.1468073752309595, 0.554009946329253, 0.12657027186027595, 0.15682921532009328, 1.0400606478963579, 4.296161949634552, 21.010346787316458, 24.679103340421403, 8.473985654967171, 30.15680776323591, 27.834768431527273, 17.498796701431274, 4.049073585442134, 2.254464626312256, 0.7026172035506794, 1.501801773905754, 0.46739799103566576, 0.7001688320721898, 0.030632734830890383, 0.03478702477046421, 0.10306159832647868, 0.27441590066467014, 0.29879479535988396, 1.1370768249034882, 6.590205252170563, 2.7997985524790625, 16.91983457974025, 28.185437066214426, 28.020858560289653, 48.31244025911604, 31.880225045340403, 28.19016878945487, 28.679982049124582, 63.85281944274902, 36.829517228262766, 43.94227000645229, 64.32569994245256, 50.74619620186942, 55.3215571812221, 57.39739751815796, 62.79800646645682, 58.92249584197998, 57.161405427115305, 58.627308573041645, 65.05181448800224, 59.11728858947754, 67.71470464978898, 65.64848409380231, 61.16865389687674, 63.34958226340157, 64.09929289136613, 61.769506318228586, 64.96143926892961, 65.12674386160714, 69.39887850625175, 57.26557282039097, 43.05246979849679, 50.0852175440107, 54.46374647957938, 50.41822385787964, 12.489305325916835, 1.591838919690677, 3.256254813500813, 1.4147431254386902, 0.36349701774971827, 0.3509583962815148, 0.3346985802054405, 11.119071057864598, 33.16102818080357, 40.10779544285366, 70.31479004451207, 55.9780855178833, 54.32857275009155, 43.31822449820382, 1.3567202389240265, 0.03425325519804444, 0.03127893087055002, 0.04198920919692942, 0.10117058229765721, 0.06724417741809573, 0.010486437257246246, 0.08356617444327899, 0.026973371726593802, 0.06754136897091355, 0.015324575992833291, 0.043275877833366394, 0.02836326928809285, 0.06518999407333986, 0.06709422117897443, 0.03789115623970117, 0.04153660937611546, 0.014371307234146764, 0.05831323843449354, 0.08777024171182088, 0.024452179869902984, 0.2519799774246556, 0.1691248533981187, 0.1148619329822915, 0.16509571245738439, 0.13766336946615151, 0.2534729987382889, 0.14319907527949127, 0.21874226523297174, 0.16088157572916575, 0.2081517313740083, 0.18562856210129602, 0.1100605513368334, 0.19565698398011072, 0.15951736750347273, 0.1100218002019184, 0.14474967707480701, 0.2025190493358033, 0.08831932581961155, 0.12919826512890203, 0.10123718050973755, 0.1756208219698497, 0.307800827814, 0.15143910955105508, 0.25131020907844814, 0.26467061787843704, 9.135175364358084, 115.64309365408761, 84.79876164027623, 73.92592866080147, 101.86788000379289, 95.60496834346226, 59.673644747052876, 64.48311832972935, 32.299079826899934, 1.9912607840129306, 0.293629596808127, 0.3376908653548786, 1.3598456255027225, 1.1421645347561156, 0.8100566555346761, 7.048816757542746, 21.44950941630772, 96.92501490456718, 58.74650491986956, 76.74893311091832, 73.87729821886334, 62.78381824493408, 85.55325262887138, 76.00818565913609, 70.39019189562116, 67.69941861288888, 65.13326822008405, 64.19391345977783, 67.18238925933838, 69.23975086212158, 66.25252573830741, 65.17583983285087, 66.31902694702148, 64.63309519631522, 64.47457899366105, 62.89753246307373, 62.828780038016184, 62.23377799987793, 59.67110170636858, 67.30377428872245, 62.12608092171805, 34.24853937966483, 47.77200589861189, 34.94940069743565, 37.07592466899327, 48.04608106613159, 48.12506818771362, 28.905131476266043, 11.870734129633222, 2.220282529081617, 2.0739651918411255, 1.3726530011211122, 0.39395982027053833, 0.22173556818493775, 0.23115386494568416, 0.6891114254082952, 1.970678916999272, 1.6522292963096072, 0.41938287179384914, 0.4536255757723536, 1.2837471089192798, 19.495149646486553, 29.741802283695765, 31.591124398367747, 10.440675003187996, 38.02888747623989, 34.830141816820415, 29.219190052577428, 12.393379364694868, 3.3242937454155514, 1.234356273497854, 0.672820179590157, 1.1014024934598377, 4.198376042502267, 0.0852569140759962, 0.24499044248035975, 0.214269131688135, 0.27303410481129375, 0.25328249324645313, 0.844261280127934, 8.767364655222211, 11.250810640198843, 24.825043303625925, 40.01972702571324, 35.58229126249041, 50.60997676849365, 39.794841630118235, 36.31778587613787, 36.552339690072195, 90.80244295937675, 60.32079996381487, 56.131713662828716, 65.11507783617292, 53.701984201158794, 58.316918645586284, 56.33775554384504, 58.621235847473145, 57.72840275083269, 52.935490199497764, 58.760255404881065, 62.557744707380024, 57.52594266619001, 69.12460531507219, 67.2360918862479, 59.96239798409598, 63.780460902622764, 63.11375345502581, 61.50597504207066, 67.41427843911308, 66.98747839246477, 69.87747737339565, 60.84044878823416, 48.27263055528913, 61.14965752192906, 56.576853479657856, 54.75822155816214, 13.23966908454895, 2.0787320903369357, 6.239231765270233, 2.220548080546515, 0.9455419140202659, 0.665836534329823, 0.42255038182650295, 13.65630999633244, 35.724645955221995, 55.67111757823399, 80.0272877556937, 61.71398326328823, 62.633188247680664, 45.88959993634905, 0.9858658931085041, 0.19778435411197798, 0.11103462906820433, 0.15831509844533034, 0.22625822121543543, 0.08750057832470962, 0.09049272098179374, 0.1228570703949247, 0.15615316373961313, 0.19145671650767326, 0.07093874631183487, 0.1854734897081341, 0.08527579770556518, 0.1481676615242447, 0.1893070497150932, 0.1725575484867607, 0.0736707386427692, 0.22464117727109364, 0.30332493941698757, 0.30968175402709414, 0.19601075856813363], [0.06639207314167704, 0.049606975966266224, 0.09630875675273792, 0.009758716931433549, 0.05365724988015635, 0.05406089000669973, 0.04341796985162156, 0.014791266127888645, 0.02286778194164591, 0.08102022962910788, 0.04092243679666093, 0.04602678432794554, 0.022864061873406172, 0.058324658178857396, 0.027617277710565498, 0.048583690875342915, 0.03461489061425839, 0.1554263305983373, 0.004003813348910106, 0.05286820186302066, 0.06251183671078511, 0.05205327452027372, 0.05643438175320625, 0.04351601476914116, 0.172460192282285, 0.07048152227486883, 27.550533260617936, 81.00822748456682, 65.57315867287772, 73.53930309840611, 84.32879243578229, 45.919254847935264, 36.498925413404194, 21.674288851874216, 0.9824992737599781, 0.12447050453296729, 0.18078555911779404, 0.5637665199381965, 0.34934313009892193, 3.2539139219692776, 2.573403443608965, 24.253769363675797, 55.8174501146589, 43.5129269191197, 62.45713479178292, 52.011946065085276, 65.43826634543282, 78.4081837790353, 75.33383519308907, 68.1512530190604, 67.36227117265973, 65.9241886138916, 65.28923443385533, 67.6301520211356, 65.29728044782365, 63.85060296739851, 67.2752241407122, 66.77831677028111, 67.54332038334438, 67.03829056876046, 65.06224373408726, 61.208335059029714, 65.67163549150739, 67.41068622044155, 64.71028968266079, 63.5314096723284, 27.710593700408936, 15.512654134205409, 27.499561275754655, 28.79899079459054, 44.94877563204084, 36.55295460564749, 12.639501060758318, 3.7420804585729326, 3.7254955427987233, 0.7583033783095223, 0.11704429159207003, 0.08098228595086507, 0.06463590916246176, 0.020205337753785507, 0.07552515449268477, 0.5825345814228058, 0.3945753872394562, 0.42949114367365837, 0.26187641067164286, 0.25939294536198887, 4.3243642534528455, 6.848531893321446, 23.73636828150068, 8.623423167637416, 29.073727778026036, 25.428240742002213, 6.8214990581784924, 3.7093987379755293, 2.347292559487479, 0.08096285949328116, 0.23559387241091045, 0.5387623959353992, 0.7204226681164333, 1.2280412295034953, 0.09969829022884369, 0.12404093758336135, 0.07758191627051149, 0.40037596598267555, 1.0546935541289193, 2.588875561952591, 5.623473286628723, 8.246505975723267, 14.962429761886597, 28.49825017792838, 40.21747623171125, 29.16377122061593, 26.126968962805613, 26.505718742098125, 46.8139465876988, 49.43133994511196, 62.98432241167341, 57.368083068302695, 56.217107023511616, 65.06543295724052, 57.065506390162874, 51.3291848046439, 51.26405586515154, 56.09996039526803, 56.617927755628315, 52.5208078111921, 57.535618032727925, 57.63373701913016, 58.788284437997, 57.991183621542795, 62.863639150347026, 62.12416321890694, 67.65121895926339, 66.57501942770821, 63.04739815848214, 62.946989740644185, 61.6326059613909, 45.82241085597447, 49.42850160598755, 49.7766306740897, 61.74723039354597, 29.64617075238909, 0.9468721683536256, 0.6895763033202716, 0.570893471794469, 0.3125764386994498, 0.07544514842863594, 0.23831574778471673, 16.582419633865356, 44.02352224077497, 55.80294227600098, 57.54572418757847, 43.356158188411165, 43.14166382380894, 6.271017602511814, 0.2756932835493769, 0.08922880023185696, 0.10537401852863175, 0.046800555129136355, 0.024184513072084104, 0.03937152287523661, 0.04082994908094406, 0.025474560812913945, 0.05203141212197287, 0.03701438382267952, 0.015411043406597205, 0.011325715525474931, 0.02948911494708487, 0.02333144866861403, 0.05882087083799498, 0.03968797464455877, 0.09645765447723013, 0.05560419415788991, 0.03389067661815456, 0.0332095020982836, 0.08380048615591866, 0.05233159262154784, 0.06924801346446786, 0.03301161075276988, 0.023440808157569597, 0.03792096767574549, 0.1454843133687973, 0.05499471025541425, 0.05631373483421547, 0.025319347623735666, 0.12101336861295359, 0.03967562869989446, 0.0318142033980361, 0.031146982950823646, 0.014623690030670591, 0.05654744604336364, 0.06182590566043343, 0.02070647488082094, 0.04151037721229451, 0.051360642936612876, 0.03838827135041356, 0.0333973613035466, 0.07816591100501162, 0.06684692230607782, 0.02905173466673919, 0.15143787461732114, 0.06084554469478982, 48.11701175144741, 90.76654161725725, 69.71668216160366, 82.54966449737549, 82.96600750514439, 49.04457194464547, 31.281304223196848, 23.126973049981252, 1.444916112082345, 0.285603721759149, 0.15780296735465527, 0.5043589334402765, 0.7642526105046272, 6.0830501573426385, 4.924715101718903, 30.88303347996303, 73.09057453700474, 49.030272551945274, 63.602885791233604, 57.76095506123134, 62.29709693363735, 74.50546400887626, 76.03447069440568, 68.7345473425729, 69.94197055271694, 68.7482213973999, 65.6054469517299, 68.20817961011613, 66.12923690250942, 64.23354598454067, 68.41225515093122, 66.544905935015, 69.9183188847133, 66.81100109645298, 65.77380875178746, 61.57038484300886, 64.15641403198242, 64.98194340297154, 61.61082335880825, 52.05298907416207, 27.39558843203953, 20.73768731525966, 22.976343052727835, 29.01121657235282, 48.72902645383562, 45.74115514755249, 20.888699463435582, 5.741690805980137, 3.647445125239236, 1.7825496005160468, 0.23336339209760937, 0.056795660938535414, 0.1339414148990597, 0.03753759878288422, 0.2688733823597431, 0.8197058577622686, 0.2538306681173188, 0.6638894102403096, 0.2390662617981434, 0.5719438982861382, 1.7349069969994682, 17.9537056854793, 31.308572428567068, 14.270540305546351, 39.67668056488037, 33.64520297731672, 18.10001564025879, 4.296521953174046, 4.814098477363586, 0.07939530789319958, 1.2781436038868768, 0.4651495431150709, 1.2657206590686525, 1.7713500814778464, 0.4130604996212891, 0.12174991837569646, 0.07025879994034767, 0.2906262379671846, 4.3866031765937805, 4.594509780406952, 5.438569128513336, 7.319731797490801, 21.40017373221261, 31.00059700012207, 45.515331745147705, 30.310091972351074, 27.34374097415379, 26.106737545558385, 59.9440894808088, 50.49360833849226, 54.59042256219046, 58.68929345267159, 54.929070813315256, 64.33625425611223, 57.87606586728777, 54.32572398866926, 53.01297998428345, 55.05830383300781, 55.68856797899519, 55.06388323647635, 57.20331001281738, 59.59912531716483, 61.95669078826904, 60.41964503696987, 61.606626646859304, 64.32645729609898, 66.96775940486363, 68.79546914781842, 62.891953059605186, 65.3802627835955, 64.26766163962228, 50.52605642591204, 52.268668106624055, 58.56836700439453, 60.16629981994629, 29.38119077682495, 1.45245175915105, 1.5594971179962158, 1.4321073251111167, 0.659254147538117, 0.12220733240246773, 0.3685928428811686, 21.832026856286184, 40.12231370380947, 53.865110533578054, 68.70470482962472, 54.53246763774327, 57.03731060028076, 14.35777928147997, 0.10930222738534212, 0.053056766744703054, 0.0489177472357239, 0.05418224260210991, 0.03506148200748222, 0.04732400757659759, 0.04306385260341423, 0.06380103967551674, 0.026575687441176603, 0.016018403494464498, 0.032699711953422854, 0.01477064544867192, 0.01954796793870628, 0.008934086537919939, 0.05059268039518169, 0.05649528705648013, 0.07607718344245638, 0.05574084771797061, 0.052405817567237785, 0.13686746145997727, 0.06023667486650603, 0.1493395593549524, 0.13704679826540606, 0.2197612484118768, 0.15092369435088976, 0.2139454297721386, 0.1930985948336976, 0.10584391081439597, 0.16206956841051579, 0.17377991575215543, 0.16565718661461556, 0.17358532547950745, 0.12412267391170774, 0.09538229182362556, 0.14952283166348934, 0.2808088133377688, 0.17781804049653666, 0.12581732869148254, 0.23512782741870197, 0.10760924858706337, 0.12108119497341768, 0.10046569976423468, 0.17554399823503836, 0.19902500111077512, 0.1660329864493438, 0.3268868779497487, 0.10215536052627222, 53.1694256237575, 106.79087325504848, 82.04093824114118, 101.91166755131313, 100.45801407950265, 64.32697146279472, 45.654670919690815, 32.006578036717, 2.2680338067667822, 0.24505677606378282, 0.34896624460816383, 1.2039333688361304, 1.1948658611093248, 11.34655247415815, 7.116938633578164, 33.587838649749756, 70.9363272530692, 56.41963311604091, 74.37448351723808, 66.1387767791748, 72.57579639979771, 80.7960433959961, 78.17132663726807, 69.97010380881173, 69.69585841042655, 68.48908138275146, 64.45114271981376, 68.67983027866909, 65.24241747174943, 65.06707273210797, 67.15890434810093, 69.04251234872001, 68.1115232195173, 66.80966009412492, 67.87413106645856, 61.804414067949565, 64.34821210588727, 66.87164497375488, 65.72615800585065, 73.64352607727051, 34.62958206449236, 19.24483905519758, 30.436684676579066, 38.18197018759591, 50.66421440669468, 49.954045976911274, 30.871562004089355, 11.705727440970284, 5.201718934944697, 3.608300277165004, 0.9786982834339142, 0.26017928602440016, 0.16785743140748569, 0.22953588462301663, 0.5541998818516731, 1.4366227856704166, 2.74477424791881, 2.3499995342322757, 0.8490534744092396, 0.43183217091219767, 11.37788016455514, 28.32696144921439, 39.33951228005545, 17.141372680664062, 44.271096978868755, 41.14724942616054, 31.071961947849818, 9.874991757529122, 6.093477666378021, 0.1729366731430803, 1.2152835769312722, 2.407030999660492, 1.2106769212654658, 1.4504112686429704, 0.9695620536804199, 0.18240758350917272, 0.32230644087706295, 0.3955543232815606, 6.037634560040065, 11.247931480407715, 12.035670467785426, 16.184091567993164, 35.332218647003174, 43.50798674992153, 49.57466391154698, 36.30629702976772, 33.97223384039742, 33.6663567679269, 53.22981936591012, 54.314749308994834, 68.96001638684953, 59.987133571079795, 57.47932025364467, 66.18164716448102, 55.56721421650478, 49.39922884532383, 49.81781612123762, 57.15177174976894, 56.08509472438267, 53.05216087613787, 56.683431897844585, 56.69376039505005, 60.07918330601284, 61.45678874424526, 61.93007918766567, 62.442390714372905, 70.51990781511579, 70.15518992287772, 65.6464204788208, 65.97176987784249, 66.56777940477643, 54.88225037711007, 59.15954753330776, 60.48834882463728, 70.81961836133684, 38.870779854910715, 3.273226874215262, 4.489085631711142, 3.2021791551794325, 1.74639692902565, 0.2817935033568314, 1.2238981489624297, 31.36197975703648, 51.24491705213274, 65.34375, 73.14827932630266, 63.20376736777169, 62.46947479248047, 13.40357882635934, 0.3589225789265973, 0.2102075024907078, 0.20178043682660374, 0.11813526733645371, 0.12556051675762447, 0.18973942579967634, 0.09703505385134902, 0.1557311149580138, 0.10514013429305383, 0.10759837845606463, 0.2670249715447426, 0.10962267233324902, 0.10770478631768908, 0.11065103286611182, 0.17290763184428215, 0.10557045441653047, 0.3073757934783186, 0.16522870532103948, 0.18588066500212463, 0.2175850916121687, 0.1311369075306824], [0.11633178911038808, 0.04019360197708011, 0.04934780951589346, 0.06855916471353599, 0.14771235095603125, 0.06459297825183187, 0.06597298277275902, 0.07736329228750297, 0.04848343732633761, 0.0662791377731732, 0.052654514222272804, 0.044398632765348466, 0.032012807205319405, 0.036312276497483253, 0.010759220209105738, 0.017902240622788668, 0.05713072153074401, 0.045245892301734, 0.03101410883079682, 0.086899355586086, 0.044693330701972754, 0.024863098980858922, 0.13985167204269341, 0.09491245382066284, 0.08363294907446418, 0.08744234644940921, 4.935919940471649, 73.05427714756557, 76.79663249424526, 71.51482037135533, 81.11916242327008, 61.995941162109375, 33.115944794246126, 16.63915514945984, 0.8654271215200424, 0.13639863447419234, 0.22813650114195688, 1.4866127946547099, 0.522808734859739, 0.605808712542057, 5.947885113103049, 56.81439849308559, 53.185965810503276, 65.45792279924665, 70.03732068198067, 55.02709252493722, 72.06900174277169, 78.76491819109235, 71.48246955871582, 69.71027592250279, 71.78965636662075, 67.2632246017456, 64.95475510188511, 68.9479751586914, 70.04827104296002, 65.7400405066354, 64.6173505783081, 70.35873740059989, 67.45348712376186, 65.26900127955845, 65.64163316999162, 66.12089211600167, 62.999650137765066, 65.39607688358852, 64.44440991537911, 70.91091769082206, 57.63271563393729, 26.53610668863569, 29.491319724491664, 33.4978004183088, 44.14495938164847, 33.072143350328716, 14.359961884362356, 3.983740976878575, 3.228498714310782, 1.1679175985710961, 0.1451186237058469, 0.03473980212584138, 0.07913166311170373, 0.14176093387816632, 0.23699369015438215, 0.3094472251832485, 0.3008373486144202, 1.2319088791097914, 0.22116003478212015, 0.27255790893520626, 5.53780026095254, 6.087028435298374, 28.32958265713283, 4.4360548087528775, 19.046091045652116, 35.483227321079795, 13.993279388972692, 3.343086451292038, 1.9875469718660628, 0.19041982000427587, 4.189189221177783, 0.22567901015281677, 3.0939177530152455, 1.2196025337491716, 0.09945091671709504, 0.21291634999215603, 0.04150685900822282, 0.2396588942834309, 3.3228361436298917, 3.110807955265045, 5.206085009234292, 14.491351451192584, 15.872155666351318, 21.98930627959115, 27.969315086092266, 25.076945032392228, 27.328364610671997, 23.973512036459788, 11.739084005355835, 38.116351400102886, 62.3983530317034, 55.93284579685756, 56.41932739530291, 53.623737062726704, 59.66748169490269, 57.84165143966675, 57.479921272822786, 62.78770923614502, 58.442458697727744, 62.22090993608747, 62.73950958251953, 57.794535705021445, 58.77164350237165, 65.06611388070243, 65.56352152143205, 61.98255198342459, 64.570554460798, 60.918991225106375, 65.14550399780273, 64.40710503714425, 63.48269585200718, 48.93261562074934, 40.31880875996181, 54.95219094412667, 51.76792533057076, 44.72833013534546, 2.2036850196974616, 0.44285651934998377, 0.9149209856987, 0.2485392349106925, 0.3092861681112221, 0.33173699198024614, 30.788423333849224, 54.29914018086025, 56.074498721531455, 53.255638871874126, 52.532373087746755, 26.57608836037772, 0.20011327628578457, 0.0485023175632315, 0.020613502012565732, 0.08599225604640585, 0.03363018702449543, 0.058030608243175914, 0.039995897228696516, 0.05116942837568266, 0.02327822777442634, 0.07201364756162677, 0.029501053770737987, 0.04489997175655194, 0.02240128572365003, 0.02822940281060125, 0.060724073355751376, 0.07648568866508347, 0.05251680214756301, 0.039673152047076395, 0.04783542620550309, 0.013886181837213891, 0.14654356081570896, 0.051809252971517186, 0.020346551069191525, 0.02226530560957534, 0.05347767558747104, 0.0326930623102401, 0.07776902908725397, 0.052164099644869566, 0.05746190768799611, 0.0342411738820374, 0.052469796634146144, 0.06572586031896727, 0.02768740091206772, 0.10965879753764186, 0.008612291305325925, 0.021865314305094734, 0.02507407757054482, 0.03146685453663979, 0.05091279964627964, 0.03701602927009974, 0.0074669776284801105, 0.096312034076878, 0.03769928689247795, 0.04044418156679187, 0.08538575430533715, 0.1080432938677924, 0.15559870563447475, 0.29647067721400944, 12.330990621021815, 92.96055344172886, 80.25088078635079, 80.05118261064801, 84.18407535552979, 57.2929869379316, 34.60464497974941, 21.37811667578561, 1.5735548436641693, 0.2124612294137478, 0.360053615378482, 1.917674801179341, 2.0096837154456546, 1.7799485857997621, 11.990376029695783, 61.59360572269985, 60.75757762363979, 68.9675760269165, 72.4177804674421, 60.32447556086949, 73.97084181649345, 76.60311126708984, 73.00829396929059, 69.50783320835659, 70.56457083565849, 68.49892003195626, 66.80613040924072, 68.55043397630963, 69.32004424503872, 66.48493603297642, 64.46560886928013, 68.27706405094692, 68.50778593335832, 68.18986415863037, 67.37214456285749, 64.88727419716972, 62.999031748090474, 65.89516598837716, 62.96908501216343, 61.41565540858677, 45.344555446079795, 26.398647001811437, 25.738448279244558, 34.85005535398211, 50.663599491119385, 41.705512864249094, 18.723414966038295, 7.477951833180018, 1.478035352059773, 1.3857096433639526, 0.1704824934048312, 0.01750671407873077, 0.16277699545025826, 0.07248919204409633, 0.253971559128591, 0.5499675603849548, 1.43734843816076, 2.002553560904094, 0.5157661927597863, 1.4711008327347892, 2.992697915860585, 17.349672726222447, 36.66208301271711, 13.778577446937561, 26.277234179633005, 39.07783964702061, 25.255373035158428, 5.968318896634238, 7.004595381872995, 0.5192328553114618, 3.9319560527801514, 0.6753358617424965, 4.548857510089874, 1.2377547025680542, 0.22425480586077484, 0.38727622319545063, 0.031153008341789246, 0.3486774058214256, 0.8159980710063661, 5.880297379834311, 6.7332586731229505, 12.211597119058881, 18.13000406537737, 22.28064772060939, 36.21670000893729, 25.247007404054912, 27.2455837726593, 21.724142176764353, 18.72662329673767, 43.341480118887766, 61.25035081590925, 58.87210750579834, 57.4202675138201, 57.71172360011509, 60.66877269744873, 60.534540448869976, 57.84700502668108, 62.092660086495535, 59.41620009286063, 64.05047484806606, 62.03792217799595, 59.8036663872855, 58.87265641348702, 64.90378311702183, 65.11653000967843, 63.431008202689036, 65.59122398921421, 64.7299530846732, 65.7856137411935, 66.96919073377336, 64.14711734226772, 54.92808764321463, 44.60465914862496, 61.07198360988072, 54.442273071834016, 50.13174615587507, 4.191489509173802, 0.5218442380428314, 2.0146269244807105, 1.618611414517675, 0.8935354075261525, 0.6511901659624917, 38.55055475234985, 53.05723306110927, 61.076465197971885, 59.59501198359898, 61.21260820116316, 42.59755386625017, 0.7275125448192868, 0.07964695617556572, 0.03439446512077536, 0.029674969081367766, 0.0029807110383574453, 0.07098399781222854, 0.04219602667061346, 0.043776585787002525, 0.05106631480157375, 0.028093324308948855, 0.05941914873463767, 0.028118216366107975, 0.020106010405080657, 0.03010963861431394, 0.06849929078349046, 0.02278378778802497, 0.031376036017068794, 0.05089180577280266, 0.04147772949987224, 0.051114989511136494, 0.12147490813263825, 0.09636595046945981, 0.24176460557750293, 0.12065628277403967, 0.17500205231564386, 0.10894466657191515, 0.28059016221335953, 0.11731058944548879, 0.13028139700847013, 0.0905210566041725, 0.3487888755542891, 0.22095173810209545, 0.11836664777781282, 0.20394906188760484, 0.14544598971094402, 0.1135913897305727, 0.04278675925784877, 0.14744503530008451, 0.1420491755540882, 0.14359912595578603, 0.11170382065964596, 0.183780789109213, 0.08060099676783596, 0.20082940214446612, 0.3718341775238514, 0.19590677986187593, 0.24843438767961093, 0.2970678151718208, 11.330344932419912, 110.5797815322876, 92.58008398328508, 95.54531111036027, 101.44250433785575, 76.25956453595842, 43.664932659694124, 28.625680140086583, 1.844783203942435, 0.3656373343297413, 0.4842570349574089, 3.4515269867011478, 3.141707245792661, 5.350248839173998, 19.909691333770752, 71.35287175859723, 64.75499439239502, 77.76269612993512, 82.836270741054, 68.07011890411377, 80.08002458299909, 80.09259387425014, 74.32559599195207, 69.88829571860177, 71.31504576546806, 70.4963742664882, 67.10270731789726, 69.27770887102399, 69.57004043034145, 64.9089664731707, 63.451783316476, 72.77131870814732, 68.88740771157401, 66.53993797302246, 65.93183858054024, 67.42538860866001, 63.31325013296944, 67.49425220489502, 65.69818455832345, 74.66206945691789, 65.18435832432338, 35.41823039736067, 37.0607567514692, 45.64736488887242, 53.62401499067034, 45.50543403625488, 30.187338147844585, 14.859377554484777, 4.555273737226214, 4.561459371021815, 0.2058487699500152, 0.1100329892443759, 0.3769189018223967, 0.17999323377651827, 0.5147671720811299, 0.6262761514101709, 3.573357569319861, 2.1617639320237294, 0.8042132205196789, 0.8371928451316697, 15.6043929372515, 25.81955460139683, 44.24048668997628, 16.14758399554661, 28.924329348972865, 43.67184959139143, 32.25440638405936, 13.383511560303823, 9.22807799066816, 0.2637494115957192, 8.58236539363861, 1.190442572746958, 8.286018644060407, 4.453791388443538, 0.4849783448236329, 0.4521576059716088, 0.16544903921229498, 0.8313441446849278, 4.461017080715724, 8.122272184916906, 9.33598004068647, 21.82379845210484, 26.48214524132865, 30.130227429526194, 38.93303224018642, 31.99234117780413, 37.64043453761509, 28.266605922154017, 15.658541985920497, 45.30057334899902, 66.80501174926758, 59.400455474853516, 56.25149713243757, 52.48708472933088, 60.26440838405064, 62.03568485804966, 59.553572927202495, 64.18556867327008, 56.89390672956194, 64.31750801631382, 63.915367126464844, 58.22687694004604, 59.34033966064453, 66.61563164847237, 66.16504096984863, 62.22575977870396, 65.66643823896135, 64.18917478833879, 68.40213162558419, 68.77845995766776, 66.83732087271554, 57.06999840055193, 47.947684151785715, 68.81690434047154, 65.09312152862549, 56.50586026055472, 5.747453902448926, 1.2004660006080354, 4.957225288663592, 3.379730382135936, 1.3342307657003403, 1.4457837683813912, 53.068836552756174, 61.9647159576416, 70.39795303344727, 66.06404890332902, 71.86430086408342, 42.20525162560599, 0.6516936932291303, 0.14444698260298797, 0.09622439449386937, 0.1060489301702806, 0.06913295428135566, 0.17210101655551366, 0.19586320434297833, 0.12207572375025068, 0.13458406898592198, 0.20406216010451317, 0.10576488184077398, 0.18592732107000692, 0.1140643964920725, 0.14204887699867996, 0.18360891618898936, 0.19504498610539095, 0.13492827623018197, 0.16623875897909912, 0.1526655073144606, 0.1919956768729857, 0.25494514831474846, 0.294036826384919], [0.020729872464601482, 0.03997379055778895, 0.03147095628082752, 0.008651324880442448, 0.07020071055740118, 0.10392206215432712, 0.046734910258757215, 0.017623103190479533, 0.02069312979334167, 0.07736547038491283, 0.0781301793509296, 0.03442340124664562, 0.060450121627322266, 0.009318822678843779, 0.07662957880113806, 0.017627590003290346, 0.03591593062239034, 0.017861157023747052, 0.021293726583410586, 0.0711424085976822, 0.0680951824677842, 0.00619027709555147, 0.017769368199099387, 0.07863273631249156, 0.08201823929058653, 0.05098298391593354, 0.1960162411310843, 51.656715938023154, 78.69684668949672, 67.96365860530308, 84.36917536599296, 74.82235745021275, 38.4162460735866, 8.978002769606453, 0.6646357987608228, 0.2305730932525226, 0.4839082136750221, 0.3389625485454287, 2.789008868592126, 0.7677502685359546, 6.776036560535431, 73.42096138000488, 61.79676410130092, 63.52683080945696, 60.38165923527309, 62.02117701939174, 73.29273932320731, 74.01573412758964, 71.98303168160575, 71.09386375972203, 72.16412258148193, 72.30089092254639, 66.7883082798549, 66.65874522072929, 69.48728043692452, 68.8500611441476, 64.42486463274274, 66.15686988830566, 69.2238325391497, 67.13532216208321, 66.60570962088448, 63.35206971849714, 65.57304055350167, 65.224928855896, 65.61718940734863, 64.88191713605607, 67.34566497802734, 36.47180312020438, 25.277150426592144, 30.477505343300955, 37.902871472494944, 30.270619256155832, 17.13101465361459, 5.382681727409363, 2.6388174763747623, 0.1294732889426606, 0.1415939735514777, 0.11026966225888048, 0.16241553984582424, 0.12902830567743095, 0.14313815640551703, 0.15687908764396394, 0.15699073379593237, 1.3038639894553592, 0.3046633361705712, 0.5535731326256479, 4.607207179069519, 9.744977934019905, 33.95548520769392, 6.905395950589861, 5.095058875424521, 28.545527458190918, 24.148860250200542, 7.829886777060373, 7.055237327303205, 1.4530446359089442, 0.6643708986895425, 0.38001578993030954, 0.44409218590174404, 0.8720742676939283, 0.7794114628008434, 0.3248134377811636, 0.09413471698228802, 0.46825370511838366, 2.042999893426895, 5.014986532075064, 9.02639263016837, 10.453563911574227, 18.656929390771047, 23.796131474631174, 20.776995011738368, 27.3722494329725, 29.22905649457659, 27.036851201738628, 28.842913831983292, 49.34455347061157, 61.93506799425398, 61.72257123674665, 56.91061019897461, 57.684069769723074, 59.8722242627825, 59.59475490025112, 60.65350750514439, 57.27535588400704, 58.376631464277, 60.589104652404785, 60.06251457759312, 61.47953714643206, 63.12137562888009, 64.11648273468018, 64.88461303710938, 66.02983597346714, 61.604757581438335, 63.77404076712472, 63.621263776506694, 65.73672621590751, 62.800000599452424, 57.453664030347554, 38.39162860597883, 48.79954719543457, 43.49162721633911, 39.14307280949184, 8.720988035202026, 0.5958933074559484, 0.48955308220216204, 0.24991275263684137, 0.9216289286102567, 6.034665942192078, 42.30525357382638, 53.75572851725987, 60.64626053401402, 64.27027416229248, 55.55450248718262, 10.612077508653913, 0.10859824051814419, 0.15079827393804277, 0.1452841591089964, 0.07281331465180431, 0.03438890452629753, 0.02422578496459339, 0.026267875118979385, 0.018899641299088086, 0.037528533555035076, 0.06889983000499861, 0.1014294841193727, 0.027734555703188692, 0.0607575997710228, 0.02521435959663774, 0.012036417344851153, 0.04963644813480122, 0.019506492485691394, 0.07067786995321512, 0.04427534634513514, 0.047270807038460455, 0.01257087308580854, 0.05416994076222181, 0.04786036236743842, 0.021408848531012024, 0.04583609563165477, 0.00482636784935104, 0.03560355345585516, 0.07367565123630421, 0.03352654758574707, 0.008397680008783937, 0.0446150922216475, 0.08256718769137349, 0.023814831926886524, 0.08105818009270088, 0.006748610059730709, 0.04369197925552726, 0.04451867239549756, 0.07253173618976559, 0.023496127421302453, 0.034178287256509066, 0.07236429410321371, 0.05288816436326929, 0.08023952759270157, 0.009161292292576815, 0.03876805418570127, 0.035579316184989045, 0.02499533527796822, 0.04053419262969068, 1.1031196756022317, 74.09426266806466, 91.97431223733085, 73.18479905809674, 90.96578121185303, 73.723082951137, 42.07063375200544, 16.01122907229832, 0.9912048237664359, 0.6939699532730239, 0.9939019190413612, 0.5611541058335985, 4.502460045473916, 3.082565265042441, 10.648778762136187, 79.08003984178815, 62.51046221596854, 72.89412811824253, 65.24925449916294, 66.4515151977539, 74.53475066593715, 76.11695275987897, 71.84539481571743, 71.8248073032924, 70.3523450578962, 70.99274662562779, 67.11725684574672, 67.99297305515834, 67.9590311050415, 69.09840365818569, 65.04682568141392, 64.43887220110211, 68.30203587668282, 70.52141557421002, 67.59835706438336, 64.49413817269462, 63.73285184587751, 67.87444373539516, 63.168991633823936, 63.40536934988839, 58.13514682224819, 30.7276474407741, 23.6410858971732, 30.096129144941056, 43.74648366655622, 36.08545548575265, 18.02271693093436, 2.91942720753806, 1.5745506073747362, 1.7124798404318946, 0.3781705003763948, 0.1314117277839354, 0.14260452932545117, 0.1482726987451315, 0.13568778761795589, 0.24797537231019565, 0.26880498602986336, 0.9163519889116287, 0.3464002422988415, 1.387617900967598, 3.2749489418097903, 19.04402916772025, 39.90788187299456, 8.637326513017927, 10.065431458609444, 28.884061064038956, 34.71488857269287, 12.825468727520533, 9.396578754697527, 14.882713079452515, 2.428113571235112, 0.7022873269660133, 0.7558360078505107, 1.3165651879140308, 1.028530438031469, 0.28810900875500267, 0.06045956683478185, 0.7471822436366762, 12.270503946713038, 5.813340195587703, 8.482564943177358, 11.932824100766863, 21.958152294158936, 25.17316542352949, 27.00811866351536, 26.53732262338911, 30.01232692173549, 23.240577833993093, 30.133354118892125, 49.34164564950125, 64.74609375, 61.633217402866904, 57.32820388248989, 58.62902477809361, 59.48360456739153, 60.646316119602744, 60.54749189104353, 57.30210297448294, 59.79020772661482, 61.73804487500872, 63.01402596064976, 59.357355798993794, 65.0245497567313, 66.0277932030814, 64.00380379813058, 65.94838224138532, 64.97370283944267, 64.51760223933628, 64.55643572126115, 65.34967681339809, 66.17097473144531, 60.52286747523716, 45.58211783000401, 55.85883011136736, 51.29692779268537, 49.53032398223877, 11.058448893683297, 0.5394374568547521, 0.3401893127177443, 1.4080820828676224, 2.219041624239513, 6.4039396813937595, 43.215877532958984, 54.89680337905884, 68.6758211680821, 67.56033652169364, 69.85311004093715, 19.01273795536586, 0.06688211113214493, 0.11438850552908011, 0.07279430210058178, 0.039112895860203674, 0.05966328563434737, 0.023256650360833322, 0.04970903102574604, 0.005879782439608659, 0.049035004872296534, 0.035935998295566866, 0.030797961500606368, 0.019393463818622485, 0.01999066793359816, 0.04543095255004508, 0.041812942762460024, 0.05101098705615316, 0.034808581828006675, 0.0159700578743858, 0.013422912053231682, 0.0234241144997733, 0.02671566412651113, 0.015201713657006621, 0.06599961527224098, 0.0826338944690568, 0.14561752336365835, 0.06170082451509578, 0.13036340475082397, 0.19002358269478592, 0.15965239597218378, 0.19454635786158697, 0.17980308112289223, 0.22868568024465016, 0.14148649360452378, 0.18908215606851236, 0.0772454986082656, 0.11537561113280909, 0.14069271619830812, 0.13134725338646344, 0.11210990351225648, 0.13213060849479266, 0.13010652496346406, 0.21556885194565567, 0.1035418857687286, 0.08050281275063753, 0.14925227261015347, 0.17170009735439504, 0.12006635085812636, 0.15877068042755127, 1.0380567439964838, 80.67802824292863, 108.15146950313023, 87.84943076542446, 107.1500186920166, 92.23921925680978, 52.94466529573713, 17.835548094340734, 1.2353203360523497, 0.9906526591096605, 1.5295424567801612, 1.2572974881955554, 6.419649124145508, 5.300940947873252, 16.77703693934849, 89.54181044442313, 72.98287745884487, 80.48078972952706, 73.48947061811174, 74.88310555049351, 76.67396899632045, 76.97676454271588, 72.24174785614014, 73.13113117218018, 71.21120493752616, 73.5302426474435, 68.48865059443882, 68.03575311388288, 67.34863880702427, 68.06515094212124, 64.16782992226737, 65.35474899836949, 67.84468460083008, 71.87236772264752, 69.50775677817208, 62.30676187787737, 61.992467062813894, 68.92519896371024, 65.82268238067627, 67.14459105900356, 75.70633506774902, 48.257976804460796, 30.164280550820486, 40.52048717226301, 49.00099631718227, 44.111983231135774, 31.983913012913295, 10.600480096680776, 6.9973948768207, 2.7908898762294223, 0.44175536558032036, 0.3443510394011225, 0.16779868384557112, 0.2577329772923674, 0.5125700214079448, 0.8774022875087601, 0.3839846226785864, 2.4728682211467197, 0.38069961752210346, 1.1764572603361947, 12.383264524596077, 26.867596558162145, 49.01200573784964, 10.401952692440577, 7.899698802403041, 38.75444964000157, 40.76327460152762, 19.500650882720947, 15.609136819839478, 17.56209305354527, 2.7048924565315247, 0.9952642002276012, 1.3561524408204215, 3.8127188852855136, 2.0414024591445923, 0.5731994594846452, 0.1949082612991333, 1.0654929003545215, 16.233236176627024, 16.82212380000523, 15.638399158205305, 17.95815600667681, 33.345846789223806, 33.28723178591047, 32.471742561885286, 34.585954325539724, 40.73893158776419, 31.413080283573695, 35.29294048036848, 54.72409895488194, 66.98283004760742, 61.25802162715367, 56.14990752083914, 56.790680817195344, 58.783768108912874, 60.72546999795096, 61.6130050931658, 56.67647327695574, 57.5070435660226, 60.87356390271868, 62.642999104091096, 59.43798964364188, 64.89649445669991, 66.47348540169853, 64.58032362801688, 68.30972058432442, 65.7285064969744, 66.18407903398786, 67.03776250566754, 67.51625714983258, 66.99730314527238, 64.58489554268974, 49.206510135105674, 65.67742334093366, 55.74951410293579, 54.0837390763419, 13.0194103206907, 0.7332416602543422, 1.6390878643308366, 3.594876140356064, 6.92632131917136, 13.10853920664106, 57.78680235998971, 59.672769274030415, 75.84904411860875, 79.97639914921352, 75.82673345293317, 17.91685938835144, 0.2576230546193463, 0.21817537636629172, 0.19012080319225788, 0.20087993943265506, 0.1661528700164386, 0.10159082617610693, 0.09407206784401621, 0.1900689359754324, 0.205315712839365, 0.1021784171462059, 0.1478902492672205, 0.0943637564778328, 0.1911449432373047, 0.09239191335758992, 0.09128178256962981, 0.1304100336773055, 0.127490175355758, 0.0969918854534626, 0.12882891137685093, 0.11153871273355824, 0.12259193962173802, 0.129675098827907], [0.027041164160306965, 0.007089108261944992, 0.10422204927142177, 0.04380680434405804, 0.015433141595817037, 0.05895009783229657, 0.037221638951450586, 0.025147542557013885, 0.06816826068929263, 0.060737372642116885, 0.037926294175641875, 0.02777108802859272, 0.05145003992531981, 0.04992891029853906, 0.028592427527265887, 0.022554039223385707, 0.018939783430791328, 0.02010963547841779, 0.020352254156023264, 0.03250967465074999, 0.09592816646077804, 0.0715384152052658, 0.018138457322493196, 0.15961148031055927, 0.14248840484235967, 0.23491569023047174, 0.1399636303207704, 23.809364318847656, 82.61623518807548, 73.99272864205497, 79.5582218170166, 84.88422448294503, 55.94960832595825, 30.555610043661936, 0.4220562997673239, 0.42535590699740816, 0.20974726575825894, 2.6443484595843723, 1.9494120010307856, 4.683277360030583, 19.59442377090454, 72.60149778638566, 61.76256506783621, 66.70497853415353, 58.22949293681553, 65.42719091687883, 73.6634326662336, 76.42141587393624, 72.37820352826799, 72.56854248046875, 72.70840971810478, 71.83150536673409, 70.03352696555001, 70.23763029915946, 66.80270494733537, 68.19718061174665, 66.14022200448173, 68.40717601776123, 69.53945446014404, 67.09332030160087, 69.37551866258893, 67.20698588235038, 64.03306266239711, 60.979016712733674, 65.46053532191685, 64.47511400495256, 67.19735567910331, 52.209740434374126, 22.63587611062186, 32.185476779937744, 33.00680249077933, 20.88275875364031, 13.467979942049299, 8.00292558329446, 4.537244030407496, 1.9656920645918166, 0.021667850436642766, 0.010694629612511821, 0.06278213113546371, 0.10322633305830614, 0.1386113100286041, 0.07133649675441639, 0.3847109537039484, 0.3277199561042445, 1.1036300425018584, 2.841157704591751, 5.342458605766296, 16.65702244213649, 12.936672040394374, 3.1922985996518816, 9.587622949055262, 19.085921594074794, 29.788862432752335, 16.1870619228908, 4.19151817049299, 15.593157700129918, 4.075967456613268, 0.8054635162864412, 0.6935782485774585, 1.8102034309080668, 1.6114992818662097, 0.2114947105624846, 0.14623769080000265, 0.2815381299172129, 14.23446352141244, 8.938030651637487, 11.644405245780945, 13.17682089124407, 19.70848192487444, 22.605199813842773, 20.822198254721506, 23.144864661352976, 26.70316743850708, 24.58202484675816, 32.88962459564209, 56.35501486914498, 59.85236631120954, 60.275956290108816, 60.03105313437325, 57.364320618765696, 60.30693135942732, 60.64723328181675, 61.53237819671631, 61.18678174700056, 61.50674629211426, 65.300400188991, 63.44568974631173, 63.30937303815569, 63.786158425467356, 65.13138525826591, 64.61152798788888, 66.40093231201172, 64.97862911224365, 66.28721114567348, 65.03033760615757, 67.9218304497855, 64.36107322147915, 59.128655842372346, 41.11191783632551, 41.22120257786342, 45.93463121141706, 35.07358585085188, 11.563298055103846, 0.33709424308368136, 0.08947785651045186, 0.15723924046116217, 0.9319778361490795, 13.643917884145464, 50.63656405040196, 52.49145862034389, 63.28882721492222, 57.22236892155239, 37.61899587086269, 1.3472741629396165, 0.1550420762172767, 0.08924564825636999, 0.05967385042458773, 0.010546037228778005, 0.025030700523140173, 0.0683041780388781, 0.08448753000370093, 0.0479145433886775, 0.001247038904693909, 0.02959866781852075, 0.04351351436759744, 0.012836121754454715, 0.025341286357226114, 0.01953277723597629, 0.03488845218505178, 0.02374691905320755, 0.045615958515554667, 0.041661561599799564, 0.04685503470578364, 0.07004824373871088, 0.09463082786117281, 0.11245120662663664, 0.012098359958534794, 0.04125618442360844, 0.040563708903001885, 0.01716652206544365, 0.04762144000934703, 0.09388538250433547, 0.05437754194385239, 0.04036934933226023, 0.06344965353075947, 0.030258203856647015, 0.044061163373823674, 0.026569078510094966, 0.05104275945840137, 0.04360385451998029, 0.06423021307481186, 0.017000584630295634, 0.019871839488457357, 0.009808775852434337, 0.016942988881575208, 0.005278038501273841, 0.07368059097123997, 0.02106393052132002, 0.05139280888917191, 0.16920470339911325, 0.06945436274898903, 0.11219049990177155, 0.11513808316418103, 39.786746978759766, 99.8470242364066, 81.22662326267788, 87.60849503108433, 85.64230769021171, 55.815855503082275, 35.017364501953125, 0.8417562916874886, 0.8519262288297925, 0.14029865020087787, 3.74372718163899, 3.933748688016619, 6.708528297288077, 27.446145262037003, 85.74711431775773, 68.66112572806222, 75.86127989632743, 63.75061838967459, 69.65857437678746, 76.0031065259661, 74.3734690802438, 73.77217197418213, 72.88394900730678, 72.27414035797119, 71.95106301988874, 69.86965370178223, 69.45176819392613, 66.1362476348877, 69.50183691297258, 67.0917500087193, 69.74371065412248, 67.96591676984514, 69.23655469076974, 70.67319897242955, 67.37673732212612, 63.514845166887554, 65.0533778326852, 64.36739608219692, 62.53964465005057, 60.96299416678292, 42.95004292896816, 24.786444323403494, 33.760963439941406, 38.82158660888672, 27.46487065723964, 16.23853244100298, 4.927964687347412, 4.038914016314915, 2.5472334878785268, 0.1779001432337931, 0.06678401532449893, 0.05943385258849178, 0.17381215973624162, 0.036353511070566516, 0.07530359923839569, 0.3849298491009644, 0.47118280508688515, 1.8793103226593562, 4.9396776131221225, 2.593477657863072, 25.85802330289568, 18.146801335471018, 3.2910537804876054, 13.427646517753601, 19.615181514195033, 41.49044874736241, 22.71771546772548, 9.342937793050494, 17.991655009133474, 8.359218784740992, 1.0582396324191774, 1.3463679658515113, 4.6322150485856195, 2.094254800251552, 0.1846664808690548, 0.07184129966689007, 0.1374723889998027, 17.925400461469376, 8.140062178884234, 9.947266050747462, 10.688272322927203, 22.960900681359426, 25.058709485190256, 26.836583273751394, 23.832145724977764, 28.745585203170776, 23.743974821908132, 28.15697029658726, 55.75405822481428, 61.568279538835796, 62.438256536211284, 61.65288775307791, 59.13227585383824, 60.081059319632395, 62.25187110900879, 62.35169587816511, 62.264530726841514, 61.913361821855815, 66.79611805507115, 65.24223681858608, 64.86690902709961, 64.76862675803048, 66.99084826878139, 64.01173169272286, 66.89305237361363, 66.31154373713902, 67.20506123134068, 66.45949867793492, 67.6739604132516, 66.47966929844448, 62.91613973890032, 47.2479692867824, 48.051288740975515, 53.67896829332624, 43.13083158220564, 15.70128904070173, 0.28497219564659254, 0.12034763076475688, 0.08693380480898277, 1.7379457482269831, 20.68499391419547, 60.91758074079241, 59.14157254355294, 72.71106392996651, 72.2998070035662, 57.048795972551616, 4.797270808901105, 0.032699973189405034, 0.023611057682761123, 0.06630401965230703, 0.011355949349568357, 0.05118544180212276, 0.07249102408864669, 0.051007051553044996, 0.05371512213189687, 0.03597033556018557, 0.03117780201137066, 0.08110147741224084, 0.011691875073925724, 0.05776442574071033, 0.03557868854009679, 0.02367164577091379, 0.04350148054904171, 0.0808693573677114, 0.04812867546986256, 0.07392397469707898, 0.026414594746061733, 0.12434488055961472, 0.12490915028112275, 0.12495828978717327, 0.13700677827000618, 0.14533514423029764, 0.054516146292111704, 0.11992088652082852, 0.191867610173566, 0.13496840479118483, 0.08588960048343454, 0.21972877372588429, 0.14763923202242168, 0.11263855693063565, 0.12145985822592463, 0.07712538433926446, 0.24519009462424687, 0.16913560139281408, 0.045666896139404604, 0.07334943195538861, 0.096713658954416, 0.06684556523604052, 0.13103573795940193, 0.1829907572163003, 0.1393946379955326, 0.09552282321133784, 0.22157627530395985, 0.18508635833859444, 0.4491303355566093, 0.3281981875853879, 40.40471281324114, 115.1028642654419, 95.41875662122453, 104.6064429964338, 98.31934465680803, 73.1237382888794, 47.952064990997314, 3.563940154654639, 2.8886623212269376, 0.47192946502140587, 6.702472507953644, 6.8292202438626965, 12.340216091700963, 36.64581380571638, 88.0270962033953, 75.51664924621582, 83.03483636038644, 71.26793697902134, 77.21371895926339, 77.51725101470947, 75.55635125296456, 72.65230996268136, 73.10394287109375, 72.14243030548096, 75.92869826725551, 70.6754710333688, 71.52631964002336, 64.68912546975272, 68.55081612723214, 67.36458492279053, 68.35701002393449, 68.04300703321184, 69.6211861201695, 72.57785306658063, 66.85512215750558, 62.05667536599295, 65.38053376334054, 65.89695167541504, 65.12052522386823, 69.11508628300258, 65.60274410247803, 29.884268147604807, 42.25431980405535, 47.16650513240269, 34.89686189379011, 31.198964595794678, 17.91909670829773, 14.826684543064662, 4.53874397277832, 0.16725897709173815, 0.11920914399836745, 0.13938275006200584, 0.2415026096361024, 0.22836231759616307, 0.22375864748443874, 0.8253837845155171, 0.624802536198071, 3.9922069225992476, 4.276436013834817, 10.730736238615853, 34.16584192003523, 26.254098415374756, 4.880664391177041, 14.928454807826451, 25.687137569699967, 45.622334003448486, 30.852409294673375, 11.839521953037806, 23.22226585660662, 10.913057838167463, 3.4953017234802246, 3.225525970969881, 5.980275877884456, 2.3460323299680437, 0.44728814012237955, 0.20806350825088366, 0.6365719160863331, 20.274739265441895, 18.29881923539298, 19.908876657485962, 20.360881294522965, 28.884853158678325, 32.45066172736031, 32.77797399248396, 30.018375328608922, 36.34270906448364, 29.85551997593471, 39.6280813898359, 61.24214499337332, 61.664776120867046, 61.01828098297119, 61.198927198137554, 56.9375935282026, 59.25737122126988, 60.759363310677664, 62.90662070683071, 61.7073199408395, 60.21433271680559, 67.29398427690778, 66.27200153895787, 64.39951065608433, 64.63939026423863, 67.01901626586914, 65.40513038635254, 67.70288576398576, 68.85538346426827, 70.36712387629917, 68.39249447413853, 70.21577821459088, 67.80612904684884, 68.0856272833688, 54.594601903642925, 55.64308507101876, 61.43654864174979, 50.46861219406128, 20.63226577213832, 0.38194684631058146, 0.3255588763526508, 0.1834020715739046, 3.421715089253017, 28.77389563832964, 64.52699620383126, 61.04230090550014, 80.79883657182965, 76.30458886282784, 59.78596237727574, 3.496012828179768, 0.20443110673555306, 0.08990306726523808, 0.160733750090003, 0.207151041499206, 0.13048931370888436, 0.1430620654885258, 0.12263700791767665, 0.2682808041572571, 0.09902027089680944, 0.15385332357670578, 0.1673570525433336, 0.11361421564860003, 0.06803218049130269, 0.11953218095004559, 0.1279561524944646, 0.1997513457068375, 0.24598457770688192, 0.12173553343330111, 0.18648017783250126, 0.10752280322568757, 0.11704142817429133, 0.22555715883416788], [0.13858233658330782, 0.03095079812088183, 0.02475734251285238, 0.07612791750580072, 0.025990729186949984, 0.027342611824029257, 0.0786068569868803, 0.06082364836973803, 0.07797480840235949, 0.08679133959646736, 0.05386020988225937, 0.047088711988180876, 0.058060823407556326, 0.05517387742708836, 0.10753772421074764, 0.03063220896625093, 0.013027269310051841, 0.030767091549932957, 0.03426421353859561, 0.011732258085560585, 0.10296398427869592, 0.020983827766031027, 0.07036287364150796, 0.12456651723810605, 0.005383260198868811, 0.08119757832693202, 0.0425296046638063, 4.4075884733881265, 75.12382589067731, 81.65180437905448, 74.90504796164376, 91.25866862705776, 56.37477902003697, 49.37774501528059, 12.210666060447693, 0.5997506976127625, 1.0080096934522902, 3.941183260508946, 2.2616156254495894, 3.2945545869214192, 28.921715089253016, 72.93994453975132, 63.981896127973286, 59.451476097106934, 52.026495592934744, 73.11232239859444, 74.48530728476388, 74.98360429491315, 71.96008178165981, 74.82399027688163, 70.60619054521833, 71.67849213736397, 69.24405179704938, 70.73803261348179, 69.97498839242118, 68.84657314845494, 68.9436811719622, 69.35461848122733, 66.69936438969204, 70.63320514133999, 67.32228428976876, 68.21772643498012, 68.01576314653668, 66.64892741612026, 62.76917144230434, 66.2579105922154, 60.894603048052105, 61.15434755597796, 31.65150077002389, 24.571644238063268, 29.1867767061506, 18.796362365995133, 13.348108751433235, 2.3149378384862627, 1.7090049811771937, 2.114053040742874, 0.12748927968953336, 0.09816132698740278, 0.03590560331940651, 0.04754475198153939, 0.07683590094425849, 0.06830360128411225, 0.007589536319885935, 0.11028944834002427, 0.25057934543916155, 2.6479886642524173, 4.526825640882764, 20.16173897470747, 9.32946957860674, 6.171230614185333, 12.3565582547869, 12.088153685842242, 32.30872392654419, 19.574131556919642, 11.148611324174063, 14.011139733450753, 8.734014170510427, 0.25084440835884636, 1.5381491035223007, 1.3606900487627303, 1.9868339129856654, 0.21948406685675892, 0.09729713800230197, 0.27488202708108084, 14.786791460854666, 7.145182626588004, 12.28847633089338, 13.166192752974373, 21.63191873686654, 24.547365495136805, 23.82069683074951, 23.72519210406712, 26.38523176738194, 24.87693245070321, 44.191800662449424, 55.986458097185405, 63.44154861995152, 62.60478401184082, 60.44867461068289, 62.826765060424805, 59.82809625353132, 61.8251405443464, 61.68878214699881, 60.68119607652937, 64.81106635502407, 63.64749322618757, 63.380182129996165, 65.08415140424455, 66.39806270599365, 65.84267929622105, 65.96212577819824, 68.43457276480538, 66.071608543396, 65.43393761771065, 63.09258924211775, 68.70023713793073, 68.37955692836216, 60.655098642621724, 38.34127153669085, 36.87489938735962, 38.24806145259312, 40.82096202032906, 8.332058276448931, 0.07212376022445303, 0.1153141630015203, 0.18962745395089897, 5.390227905341557, 20.376288924898418, 44.36113173621041, 59.63233075823103, 47.03716441563198, 48.29545191356114, 16.750871760504587, 0.10749908842678581, 0.16708403719323023, 0.03516635977263961, 0.09172717974122081, 0.10636909013347966, 0.02122981028099145, 0.03898345512737121, 0.05483013837199126, 0.024919997534847686, 0.05350177715133343, 0.035391565545329025, 0.008227293928419905, 0.022229702877146856, 0.036855213078004975, 0.03532459753166352, 0.027022769075951407, 0.06112644462180989, 0.028386125740196024, 0.0562950445871268, 0.03326751684237804, 0.05136858179633107, 0.09627375791647605, 0.052990171925297806, 0.07172342456345047, 0.046147868902023347, 0.0299996650511665, 0.0074030163731159905, 0.0229732890480331, 0.01103395055646875, 0.1350425686687231, 0.052720647637865374, 0.01061167276930064, 0.08418715612164565, 0.05638011930776494, 0.043252773715981414, 0.01923295805629875, 0.04002671628924353, 0.008768300924982344, 0.08099819081170218, 0.016869260962786417, 0.0808322618582419, 0.028600023726799657, 0.012285968105840896, 0.08073852224541561, 0.07477486439581428, 0.014542515190052134, 0.15266211463936738, 0.018200975842773914, 0.10347218665161304, 0.2784502798957484, 12.170280524662562, 96.65156160082135, 90.26825850350517, 86.60939271109444, 95.8386710030692, 64.0045472553798, 56.482524735586985, 10.617142745426722, 2.846662849187851, 3.4637599417141507, 8.544341376849584, 4.703651215348925, 5.293888960565839, 34.942879813058035, 78.83817999703544, 69.54782009124756, 66.63476003919328, 58.15449060712542, 76.40933295658657, 74.99851512908936, 77.27315385001046, 74.85076168605259, 75.9560741697039, 72.85985960279191, 73.20429570334298, 69.5773777280535, 70.39550726754325, 68.26686409541539, 69.72266456059047, 67.785861151559, 67.24117101941789, 67.1037495476859, 70.90065520150321, 68.66339084080288, 70.21517372131348, 67.55270045144218, 64.93593938010079, 63.09442356654576, 67.87730639321464, 60.954044886997764, 50.68032380512783, 27.578082868031093, 29.12519482203892, 32.88785975319998, 25.77731650216239, 18.51961214201791, 7.9411977870123724, 1.8853513470717838, 1.420301467180252, 0.7445949081863675, 0.3405637554824352, 0.07349068937557084, 0.05370584995086704, 0.046743721035974364, 0.042636955689106665, 0.09980707974838358, 0.05850436817854643, 0.8991323986223766, 2.0075428017548154, 9.386801770755223, 34.27322980335781, 11.223756091935293, 3.3002905419894626, 8.43129939692361, 16.755862304142543, 40.160434995378765, 20.935466051101685, 15.29425140789577, 14.195229649543762, 9.16631371634347, 0.7358211246984345, 1.741700489606176, 3.8037756851741245, 3.313808045216969, 0.07286054068910224, 0.09801230034125702, 0.18601886901472295, 13.557998197419302, 10.245964765548706, 10.144139783723013, 10.532694339752197, 25.386641877038137, 26.813921724046978, 26.98012958254133, 24.16499396732875, 28.546842404774257, 24.986279726028442, 37.432815415518625, 57.923754828316824, 62.27270180838448, 64.50717299325126, 60.965314865112305, 62.803509439740864, 58.87100274222237, 61.48984827314104, 60.36702632904053, 61.51867634909493, 65.41180065699986, 65.85014166150773, 64.0704995564052, 66.5276188169207, 66.11363124847412, 69.11038930075509, 66.18759482247489, 68.68326268877301, 66.25919600895473, 67.26684461321149, 62.706908634730745, 68.88783155168805, 68.95094898768834, 64.43379306793213, 42.19910246985299, 45.09618166514805, 44.00298336574009, 45.728210653577534, 11.747599022729055, 0.2137624831604106, 0.12538819600428852, 0.8235565711344991, 8.28624793461391, 31.162719317844935, 54.78060865402222, 65.10005583081926, 68.42387948717389, 63.291377203805105, 30.97960649217878, 0.04763864426474486, 0.07178382096546036, 0.015073316171765327, 0.023458942005942975, 0.04748565836676529, 0.07026331219822168, 0.0554313509325896, 0.053802598866501024, 0.024959683351750885, 0.031570948593850644, 0.025754955231345127, 0.01858467552145677, 0.058857599938554425, 0.061964964627155235, 0.03501637978479266, 0.04828394124550479, 0.04019154262329851, 0.0639016664187823, 0.009311458029385124, 0.02024431450159422, 0.05970044221196856, 0.04406655094187174, 0.03922184822814805, 0.32475128397345543, 0.1945760641247034, 0.15439212109361375, 0.1118105813594801, 0.11942077907068388, 0.13379956036806107, 0.1707925974790539, 0.172290599239724, 0.13404121382960252, 0.16734462178179196, 0.23046965737427982, 0.19037380175931112, 0.16197882113712175, 0.13092432250933989, 0.1976947332067149, 0.07995092629321984, 0.10933643912098237, 0.1459111390369279, 0.14996818133762904, 0.10891242937317916, 0.1802437353347029, 0.13494149409234524, 0.13955383588160786, 0.28840457860912594, 0.09350853094032832, 0.2966579800205571, 0.30535986593791414, 10.201041187558856, 110.59380299704415, 104.628725869315, 101.13401821681431, 112.98563003540039, 76.0276128223964, 66.2994886125837, 20.078539507729666, 3.878291640962873, 4.797856628894806, 14.176208087376185, 9.10472401550838, 10.473907368523733, 42.38152742385864, 87.4184409550258, 80.85465839930943, 76.54776886531285, 64.84553636823381, 82.22742094312395, 77.12408024924142, 78.38760321480888, 73.63224220275879, 79.54527732304165, 71.65322848728725, 73.75639261518205, 69.19968060084751, 72.95449406760079, 67.10195691244942, 69.89486176627022, 68.01684011731828, 67.20537390027727, 67.19912052154541, 75.04959828513009, 68.54850237710136, 70.9902035849435, 64.11772646222795, 65.75718866075788, 61.82170813424246, 71.50052097865513, 63.54852308545794, 71.37451539720807, 38.98888186046055, 35.84656599589756, 41.289718764168875, 35.144843101501465, 27.60737473624093, 7.391682999474662, 2.0315499135426114, 2.6552547429289137, 0.8169974716646331, 0.386201478008713, 0.158844206482172, 0.21147150466484682, 0.1358152979186603, 0.18877939374319144, 0.18548963884157793, 0.1910825722983905, 2.141701008592333, 5.537216178008488, 13.221196430070059, 43.507434368133545, 15.56338119506836, 10.08318931715829, 22.588812487465994, 21.91852845464434, 45.5191775730678, 30.532951968056814, 16.883396489279612, 31.764711243765696, 20.295868737357004, 3.680595414979117, 5.311208214078631, 6.645561550344739, 4.115106659276145, 0.21523631550371647, 0.14006918322827133, 0.4477387145161629, 23.337675435202463, 19.026101078305924, 15.692259856632777, 19.75104832649231, 34.235223157065256, 34.462311131613596, 34.81760726656233, 31.88754149845668, 35.0304514339992, 28.684899636677333, 54.39062016350882, 61.3477715083531, 65.18312849317277, 63.31929506574358, 60.36053671155657, 64.54242120470319, 59.31437424251011, 61.923575673784526, 62.14604309626988, 60.41678237915039, 65.91225160871232, 64.21847534179688, 63.68880721500942, 67.48162037985665, 68.57426629747663, 68.06074578421456, 66.08815915243966, 70.21707057952881, 69.20650373186383, 67.1113508769444, 66.76860318865094, 73.28479058401925, 71.07222706930978, 67.36858708517892, 51.89042207172939, 52.08480487551008, 53.88930763517107, 59.51194626944405, 16.711958374295914, 0.2407911249569484, 0.4487517401576042, 1.1637060131345476, 10.485529099191938, 41.7668376650129, 51.26194361277989, 70.64593424115861, 73.87821538107735, 71.718902860369, 28.83244810785566, 0.10362509451806545, 0.3247724271246365, 0.11298451479524374, 0.3505575449338981, 0.14700136839279107, 0.2211783823690244, 0.1741181518882513, 0.17903107112007483, 0.09589470789900847, 0.22065194776015623, 0.15119453838893346, 0.13452860553349766, 0.2045653752450432, 0.14694240369967052, 0.13246340278003896, 0.12053996830114297, 0.09543534647673368, 0.18533323651977948, 0.10778515879064798, 0.10862100536801986, 0.10038116787161146, 0.12151648875858102, 0.20131530107132026], [0.05502206539469106, 0.03491558340777244, 0.05745028438312667, 0.03597476639385734, 0.0384475922744189, 0.019196293416566083, 0.07192561442830733, 0.06314824149012566, 0.04870329285040498, 0.015032144363171287, 0.01055620507603245, 0.04012040501194341, 0.021899417475132004, 0.017387610826907412, 0.05107357512627329, 0.0380321117118001, 0.0182055016713483, 0.05738262765641723, 0.021723339334130287, 0.049846973802362166, 0.08357796059655291, 0.00473923292676253, 0.01650654837223036, 0.007162170368246734, 0.08478892847363438, 0.024638181585552435, 0.07696533149906568, 0.16413880166198525, 37.03939798900059, 83.55590261731828, 66.32511356898716, 86.85749898638043, 69.79616260528564, 47.257286821092876, 31.14448377064296, 5.358587111745562, 3.813477541719164, 1.1166126430034637, 0.9044888083423887, 2.4040011508124213, 37.82077503204346, 69.76948152269635, 67.75601169041225, 58.58290958404541, 53.952105454036165, 69.69840839930943, 75.69213989802769, 77.85428728376115, 73.08755901881626, 77.34034987858364, 72.11246967315674, 72.02467918395996, 70.71479783739362, 73.44967133658272, 70.57297120775495, 70.47174985068185, 68.54023402077812, 73.40304197583879, 67.56934138706752, 70.08319268907819, 71.6660270690918, 70.49943147386823, 63.80292442866734, 67.89744922092983, 62.747437477111816, 70.4531078338623, 62.93915912083217, 60.12324183327811, 34.28596237727574, 26.07127567699977, 26.257727112088883, 19.70647736958095, 19.150103841509136, 5.874112180301121, 0.5777582377195358, 2.3453040719032288, 0.9918158309800285, 0.30294965526887346, 0.030517736715929847, 0.06263841063316379, 0.07434299042714493, 0.23278593165533884, 0.14669663831591606, 0.19210287183523178, 0.2691277244261333, 0.5339191215378898, 9.895032099315099, 21.993994576590403, 12.256362625530787, 7.57505030291421, 6.7369681426457, 10.980842726571218, 36.015087604522705, 7.985161645071847, 15.497599124908447, 2.053781109196799, 1.9874071393694197, 1.168479208435331, 1.0230436410222734, 1.6950134805270602, 1.0398289688995905, 0.07439440302550793, 0.13952674876366342, 0.10757072136870452, 6.3127745389938354, 5.174200594425201, 12.201745441981725, 11.193477579525538, 21.115763119288854, 22.936608042035783, 29.101956571851456, 21.110904591424124, 27.287484884262085, 25.324679579053605, 40.90703283037458, 57.740454401288716, 62.48186343056815, 63.115747588021414, 61.352253096444265, 62.79646396636963, 62.5598361151559, 60.97589002336775, 62.175058773585725, 64.22366564614433, 63.41216468811035, 68.41269983564104, 67.82115800040108, 66.97218540736607, 64.57902431488037, 66.61766052246094, 66.89237145015171, 65.61409051077706, 67.89847755432129, 67.64327716827393, 65.44547857557023, 65.01910931723458, 69.0118430001395, 61.95407131740025, 38.985282693590435, 29.828060695103236, 37.71274791445051, 36.992066860198975, 7.189107835292816, 1.3179324631180083, 1.5137291167463576, 2.9623160489967892, 13.770163178443909, 41.239855016980854, 60.19833101545061, 57.525293009621755, 40.074666431971956, 30.136991500854492, 5.224556360925947, 0.1542391385883093, 0.03616889865536775, 0.0808440072994147, 0.08006216532417706, 0.07101655392242329, 0.028227238283891763, 0.06847461246486221, 0.04945668724498578, 0.006174852298240044, 0.07534939356680427, 0.03959335293620825, 0.02744220380139138, 0.022274686356208155, 0.12469752877950668, 0.03498186270839401, 0.11264711325722081, 0.03934001170897058, 0.01700151422327118, 0.030685331472860913, 0.01577483826050801, 0.06098976731300354, 0.06466295556830508, 0.09980643514011588, 0.05828205296503646, 0.07325215717511517, 0.03257311088964343, 0.02011370499219213, 0.03173844496320401, 0.04071641320894871, 0.018162072037479708, 0.07038343325257301, 0.015215747457529818, 0.038827826335494, 0.05537044223664062, 0.05070221291056701, 0.04779773697789226, 0.05490033621234553, 0.04953211998300893, 0.06102273054420948, 0.01509523794188031, 0.11053203139454126, 0.03726545535027981, 0.08885947362120662, 0.07680224560733352, 0.043870165944099426, 0.018135242762842348, 0.0389594621291118, 0.05933546501078776, 0.0337165000715426, 0.05733982566744089, 0.5063837362187249, 64.10249601091657, 98.57127938951764, 79.24997193472726, 100.74229267665318, 66.54916518075126, 57.2121376991272, 34.95964581625802, 4.618746834141867, 8.345767072268895, 3.7528970667294095, 1.5841346702405383, 3.216637922184808, 45.390305859701975, 77.95707198551723, 72.79078756059918, 66.97652803148542, 60.158114842006135, 75.85586724962506, 78.4391519001552, 76.1179324558803, 73.5650531223842, 77.90345273699079, 72.56092030661446, 73.91880675724575, 70.60373783111572, 74.00551332746232, 73.82664585113525, 71.77651037488664, 68.08994211469377, 71.13778332301548, 68.6501545224871, 72.61802755083356, 69.61643355233329, 70.03170653751918, 63.60520648956299, 67.20328944069999, 65.12342957087925, 68.57088252476284, 63.051101548331125, 55.3001115662711, 33.36976596287319, 29.250870364052908, 30.53865991319929, 23.859005723680767, 22.800161055156163, 8.294907127107892, 4.184357617582593, 3.4774843709809438, 1.958094209432602, 0.8069080359169415, 0.12304575741291046, 0.06649934952812535, 0.1414686209921326, 0.428281451442412, 0.045946740944470675, 0.19140947689967497, 0.4247199296951294, 3.198367633989879, 17.903536217553274, 28.937593460083008, 12.720725502286639, 2.804527670145035, 2.1620920172759464, 16.070974894932338, 48.221540451049805, 11.266556126730782, 12.088097231728689, 0.7895500787666866, 6.284362052168165, 4.416522988251277, 1.0991206616163254, 4.245559522083827, 2.429661499602454, 0.08500354910003287, 0.06142286264470645, 0.08702480314033371, 3.6008235812187195, 8.223121813365392, 11.355857849121094, 9.39610367161887, 20.346932785851614, 24.69950498853411, 30.596392495291575, 21.964607170649938, 28.404760428837367, 26.81212214061192, 37.187880992889404, 57.93440989085606, 63.08264636993408, 64.96013300759452, 62.440931592668804, 61.84328229086739, 60.47761385781424, 62.86315972464425, 63.04036658150809, 65.93160928998674, 63.371496881757466, 68.8682028906686, 65.77267619541713, 68.72203363691057, 66.16732692718506, 68.99598721095494, 66.98633193969727, 67.52535234178815, 67.48717893872941, 69.86223997388566, 65.74159690311977, 67.42374883379254, 69.62616797855922, 66.09192507607597, 43.87203066689627, 36.205423082624165, 42.32692500523159, 46.587897368839805, 9.149677123342242, 1.1243289432355335, 1.6844321340322495, 5.217614242008754, 23.97375522341047, 50.69867747170584, 58.887504713875906, 71.71875694819859, 56.5974931035723, 51.43556867327009, 9.42275435583932, 0.16830997355282307, 0.08542972337454557, 0.11352042853832245, 0.033194024714508226, 0.09338561432170016, 0.021253910148516297, 0.10275866636740309, 0.059823168840791495, 0.027471122963886176, 0.07887872561280217, 0.08827172658805336, 0.024511921485619884, 0.05854036446128573, 0.037774200551211834, 0.08294596629483358, 0.07319771831056901, 0.049224146508744786, 0.009449789267299431, 0.021277134705867087, 0.00982287835462817, 0.011091877091010767, 0.08530895771192652, 0.07825106036450181, 0.21282075797872885, 0.19072605642889226, 0.2036053024764572, 0.09407601691782475, 0.1280407386698893, 0.18385390804282256, 0.13557234166988305, 0.20442385998155388, 0.06565619512860264, 0.20962204890591757, 0.15978435746261052, 0.122517748602799, 0.0874645956126707, 0.12300590026591506, 0.11854009489927973, 0.12941813761634485, 0.07966225714023624, 0.20320130272635392, 0.13209360119487557, 0.13554469815322331, 0.16805417942149298, 0.17854711280337401, 0.19869279036564486, 0.19984570278653077, 0.18315199070743152, 0.0751759803720883, 0.22460948968572275, 0.3739157329712595, 61.686565671648296, 117.21916743687221, 88.83084992000035, 109.5537896837507, 86.99868638174874, 62.474025862557546, 48.18499640056065, 14.333234769957405, 17.781355619430542, 7.071348897048405, 2.129951821906226, 4.358937621116638, 51.57509544917515, 94.79640647343227, 83.20046751839774, 72.42227595193046, 67.01324926103864, 81.66149711608887, 79.50497777121407, 77.31999165671212, 73.87444945744106, 79.93228503635952, 71.97651427132743, 76.50448853628976, 72.67288357870919, 75.68466363634381, 72.1540060043335, 73.98082637786865, 68.58285427093506, 73.63343034471784, 65.85625607626778, 74.52827494485038, 70.87527343205043, 72.40869222368512, 62.73834923335484, 69.17360401153564, 62.327731541224885, 74.09682655334473, 65.43297181810651, 70.18027291979108, 41.41364336013794, 35.57028477532523, 37.10750770568848, 30.749103478022985, 26.307332038879395, 9.794935481888906, 9.617685198783875, 7.321802360670907, 3.5335109531879425, 1.2375179209879466, 0.22913913162691252, 0.15617448330989905, 0.29146311591778484, 0.45591289017881664, 0.2189345620572567, 0.44607253106577055, 0.9416993430682591, 8.309694630759102, 22.64640610558646, 46.68316411972046, 14.797936371394567, 11.259220566068377, 14.195700389998299, 22.329347644533428, 49.18239641189575, 25.469134364809307, 20.99602655002049, 7.373853921890259, 7.517166597502572, 4.31785683121, 2.96655792423657, 6.687713665621621, 1.8707091041973658, 0.15805383532174996, 0.20327195179249558, 0.14803158811160497, 10.510977745056152, 22.71992152077811, 19.3330568586077, 15.352616276059832, 32.697166442871094, 28.302060842514038, 39.520075116838726, 26.760738474982126, 37.03227955954415, 31.63901138305664, 50.5712058203561, 62.12930488586426, 63.669414792742046, 64.70298017774309, 63.38521262577602, 63.47286415100098, 59.93430641719273, 62.522232464381624, 62.5351630619594, 65.1226305280413, 64.55685261317662, 71.91400827680314, 66.98247568947929, 69.89347907475063, 66.0192538670131, 69.19717230115617, 67.0455653326852, 71.85040446690151, 67.92253221784318, 72.48005717141288, 68.08957386016846, 69.64190564836774, 70.58719417027065, 71.25592354365757, 50.58930587768555, 44.580986636025564, 53.787214279174805, 60.97664042881557, 11.977332523890905, 1.4789782443216868, 1.9146692710263389, 7.417848178318568, 33.28075953892299, 54.731411933898926, 68.95995385306222, 83.88275282723563, 66.41523170471191, 55.70170702253069, 8.446416071483068, 0.18955346649246557, 0.14338507529880318, 0.09893544044877801, 0.2002219504543713, 0.2149172140551465, 0.059899388679436276, 0.26220362739903585, 0.18661736404257162, 0.11113242632044212, 0.1662317972098078, 0.2949324654681342, 0.11165337158100945, 0.19305105667029107, 0.2750151827931404, 0.1448568177542516, 0.2812280665550913, 0.1721214133181742, 0.10677549868289914, 0.1727458012423345, 0.1659664764468159, 0.12194733135402203, 0.14216500148177147, 0.18271599124584878], [0.08915958287460463, 0.08603070862591267, 0.04723585230697479, 0.04967781502221312, 0.10155194611953837, 0.03526351920195988, 0.037061165419540236, 0.03653958233605538, 0.02879545877554587, 0.04143925656431487, 0.03784893439816577, 0.014806231217724937, 0.04775416485166975, 0.03449219451951129, 0.03358404325055225, 0.03244391442941768, 0.08690311467008931, 0.005319179775792041, 0.04826514243281313, 0.03468608929376517, 0.043423445629222054, 0.054757250140288045, 0.1239404601177999, 0.04683090260784541, 0.17344461088734014, 0.05415884671466691, 0.10266044842345373, 0.03628174920699426, 14.03893165928977, 88.37363065992082, 67.28292274475098, 77.49802534920829, 90.8976193836757, 45.17702048165457, 38.67075858797346, 14.849884578159877, 1.2500828696148736, 0.2558049336075783, 0.2765345855482987, 2.8433594150202612, 35.442854813167024, 57.46581295558384, 64.08432647160122, 48.97980431147984, 55.459187098911826, 66.84775706699916, 77.65575640542167, 73.94475827898297, 75.87557234082902, 75.63090542384556, 74.26677254268101, 72.00321619851249, 71.40687315804618, 72.0433212007795, 70.85510975973946, 69.76986367361886, 72.17756039755685, 69.09205300467355, 68.29510852268764, 69.07074982779366, 70.45965998513358, 67.68880871364048, 69.2935368674142, 70.5172813960484, 64.98563984462193, 66.79841096060616, 63.53673199244908, 58.45753628867013, 35.222791467394146, 28.857362610953196, 25.106031928743633, 24.970312765666417, 22.046383993966238, 9.391345024108887, 3.439984291791916, 1.2833279371261597, 2.1413707520280565, 0.5579761735030583, 0.24234866138015473, 0.08735900199306862, 0.1029679604939052, 0.01591820762093578, 0.03760449215769768, 0.2101594486406871, 0.4415432826748916, 0.79165511152574, 10.002515520368304, 14.10446012020111, 11.378233654158455, 4.4088460973330905, 8.59369877406529, 6.8483846783638, 25.258334704807826, 4.428500379834857, 4.521156345094953, 0.48877037848745075, 5.169567448752267, 3.075204300028937, 0.42642180408750263, 0.08599677508963005, 0.33857149524348124, 0.012639492484075683, 0.32639206307274954, 0.12371844345969812, 0.4353619100792067, 2.7109059052807942, 9.294922266687665, 12.060348732130867, 22.416181019374303, 22.343848534992762, 27.302411351885112, 22.05638939993722, 27.91822498185294, 29.748149463108607, 36.85231079374041, 59.363331249782014, 63.207706996372764, 65.76151044028146, 61.011853899274556, 63.96986184801374, 62.566089493887766, 60.104030064174104, 59.74474566323416, 63.821538652692524, 63.3089839390346, 67.13279996599469, 64.80859974452427, 66.62116241455078, 66.6459744317191, 66.74456936972481, 64.25497422899518, 66.40188421521867, 69.34915719713483, 70.05023043496269, 63.549217905317036, 70.5923080444336, 71.37766987936837, 58.90584795815604, 34.47220884050642, 36.02264724458967, 39.49832725524902, 37.56780849184309, 6.1504329187529425, 3.392756734575544, 7.320946863719395, 17.511925322668894, 27.94380303791591, 51.45679889406477, 54.41702331815447, 40.05893918446132, 38.73818390710013, 20.342459883008683, 0.27994520110743387, 0.16397102709327424, 0.10355878807604313, 0.11123356875032187, 0.01209815894253552, 0.0651828490995935, 0.06107412278652191, 0.020780223155660287, 0.011933265603147447, 0.02915810520893761, 0.07227961971823658, 0.04231702642781394, 0.04313642870900886, 0.0535766975954175, 0.02282541082240641, 0.07219339827341692, 0.041110194221671136, 0.023096409227166857, 0.015131885618237513, 0.0718201972278101, 0.044175788294523954, 0.0944865984576089, 0.06488210880862814, 0.08320382995797054, 0.07270247595650808, 0.08483063123588051, 0.04299813648685813, 0.021082934590854814, 0.05639084694640977, 0.007636115204409829, 0.05474859542612519, 0.012599934740657253, 0.04985617134453995, 0.04287548449688724, 0.08751006424427032, 0.1167416785444532, 0.07254403802965369, 0.03529409398990018, 0.03445365033777697, 0.026522452976288538, 0.0222992120044572, 0.02796314736562116, 0.04683869558253458, 0.005462819702058498, 0.022497174596147876, 0.06590722594410181, 0.01577775426475065, 0.020083484738799076, 0.04002263490110636, 0.026369567162224224, 0.11063426626580102, 0.04234731283837131, 25.803898572921753, 105.87627492632184, 74.90589564187187, 86.20193644932338, 87.18362658364433, 55.75540964944022, 49.251565728868755, 20.38411259651184, 2.512172443526132, 0.5081948818905013, 0.0591166103258729, 3.464933753013611, 41.4316600390843, 73.13014452798026, 74.95411614009312, 61.435784339904785, 64.23309435163225, 74.80012321472168, 77.9125062397548, 77.04218183244977, 76.67988886151994, 79.99957833971295, 77.5123872756958, 74.57061726706368, 70.88403511047363, 74.06417001996721, 71.42348630087716, 69.38453742436, 71.27945709228516, 70.01895659310478, 67.56938307625907, 69.51091126033238, 71.83477102007184, 70.42145878928048, 68.4935073852539, 71.69749546051025, 64.2959269114903, 68.26417514256069, 64.98675850459507, 58.008974484034944, 33.14683995928083, 29.246340138571604, 28.559392588479177, 27.99742923464094, 26.11541063444955, 14.629692690713064, 4.467157116958073, 5.006577908992767, 1.509583756327629, 0.7363006046840123, 0.040247552296412845, 0.12492179817387036, 0.05091641963060413, 0.3193306034164769, 0.18715481806014264, 0.41118654874818666, 0.7758928516081401, 1.095489467893328, 7.097531446388789, 13.087116173335485, 10.435666220528738, 1.8655596205166407, 2.085724583693913, 5.597154813153403, 21.343287093298777, 6.703525160040174, 3.034151954310281, 0.0433001218895827, 13.001917362213135, 4.9109624453953336, 0.5332691935556275, 0.5251494092600686, 0.29494961883340565, 0.03472018228577716, 0.07902132653232131, 0.10661661970828261, 0.5862235320465905, 6.008052170276642, 9.674510172435216, 11.02277944769178, 23.378664595740183, 26.624492985861643, 28.231781550816127, 23.51938819885254, 29.48201608657837, 30.130119732448033, 42.447823660714285, 62.71619837624686, 65.6968435559954, 65.35234492165702, 61.19164548601423, 62.165352140154155, 62.491021156311035, 59.89721693311419, 60.66514573778425, 65.08890397208077, 65.97621672494071, 66.58727605002267, 66.36470440455845, 65.57974556514195, 67.22251510620117, 68.55909837995256, 67.02283777509416, 67.0208853312901, 69.29418304988316, 69.9359325681414, 65.10892173222133, 69.0001700265067, 72.27957384926933, 63.094757080078125, 40.802271366119385, 39.08996425356184, 48.8676951272147, 42.34602560315813, 9.275786059243337, 3.126387336424419, 11.472769975662231, 25.32180823598589, 41.0465144429888, 58.32347079685756, 70.23665755135673, 69.79667677198137, 52.02547768184117, 34.60420029503958, 1.3875011929443903, 0.07974282638835055, 0.031381393051041026, 0.06261016322033745, 0.0587892850328769, 0.03435778691034232, 0.058324033926640234, 0.06082607073975461, 0.013604491416897093, 0.08421849765415702, 0.06765792771641697, 0.036256266824368916, 0.019343594887426922, 0.03117897587695292, 0.06547286853726421, 0.012240838741750588, 0.07056108729115554, 0.026901725213974714, 0.04341848214556064, 0.02664009907415935, 0.02713937362256859, 0.10326533525117806, 0.0837648223553385, 0.030577780279730047, 0.1822822852326291, 0.1658947960074459, 0.11203431471117906, 0.1761340115751539, 0.19051782760236943, 0.13516967184841633, 0.1536872453455414, 0.2843770390110356, 0.1494375533823456, 0.19885907215731485, 0.1185158576284136, 0.16347636149397918, 0.14577255504471914, 0.13936434819230012, 0.09742291803870883, 0.22458686732820102, 0.22947356796690396, 0.12942125887743064, 0.20669958500989846, 0.11248836998960801, 0.20898509451321193, 0.19397504494658538, 0.25547706548656735, 0.05567810358479619, 0.30645138451031273, 0.11892733483442239, 0.3608198714043413, 0.22089535184204578, 26.80686582837786, 124.63685580662319, 89.67642484392438, 97.8647518157959, 107.6376085281372, 62.097641944885254, 59.718043736049104, 29.883722714015416, 4.082157867295401, 0.5003346779516765, 0.30006900270070347, 3.8003415380205428, 49.30974299567086, 83.0787489754813, 84.01272583007812, 68.37978621891567, 70.88528578622001, 77.83515194484166, 81.72484384264264, 76.35768004826137, 76.48912606920514, 80.00137097494942, 76.74796036311558, 75.3259698322841, 71.35324696132115, 75.24085439954484, 69.17531326838902, 70.33034706115723, 72.58138969966343, 68.26653058188302, 67.95853083474296, 72.422011920384, 73.43346118927002, 70.13408824375698, 68.91376917702812, 71.6992255619594, 63.79168919154576, 71.1048002243042, 66.34611102512905, 68.4257207598005, 43.114538056509836, 38.84004102434431, 34.05712693078177, 39.123506682259695, 30.497693334306987, 21.6312986101423, 7.867534722600665, 15.252206121172224, 4.948368941034589, 0.9723427444696426, 0.374039606324264, 0.4534797178847449, 0.20938328600355557, 0.36684423099671093, 0.5121665916272572, 1.8758151616368974, 2.7988661910806383, 2.4547668610300337, 23.968832424708776, 33.69245767593384, 20.18440226146153, 9.340929763657705, 16.720082555498394, 16.8127315725599, 42.96002401624407, 15.95488612992423, 8.585511190550667, 0.3899350219539234, 16.485653809138707, 11.228417464665004, 1.2962001264095306, 0.6251455492206982, 0.7070309381399835, 0.1256899405270815, 0.41388576105237007, 0.20408516244164535, 3.4880760312080383, 16.255520786557877, 15.471312352589198, 14.520991597856794, 33.191638469696045, 33.1368727684021, 35.87734304155622, 30.34083775111607, 36.69976656777518, 34.431343010493684, 48.63677522114345, 64.73506001063755, 69.20020171574184, 69.4255734852382, 63.06233678545271, 63.11300999777657, 62.80364840371268, 58.91747924259731, 59.88061073848179, 65.85583918435233, 67.5512969153268, 67.29752090999058, 65.49362959180559, 67.68269429888043, 68.87743704659599, 67.98427391052246, 67.84960392543248, 70.49502631596157, 71.78848212105888, 70.96854604993547, 68.74222510201591, 72.37454182761056, 73.4898110798427, 67.63431399209159, 47.88133232934134, 47.70022405896868, 57.787452016557964, 52.06984887804304, 11.078933920179095, 3.963919937610626, 14.555261850357056, 30.918924399784633, 46.35373265402657, 60.927558353969026, 78.42030143737793, 73.41370051247733, 65.97445883069719, 39.78652116230556, 1.089069875223296, 0.33587089872785975, 0.14066011937601225, 0.2717140827860151, 0.26027034542390276, 0.3337344362267426, 0.21277050567524775, 0.219545379281044, 0.11012794343488556, 0.19902292479361805, 0.23266547811882837, 0.13382499186056002, 0.2144789347159011, 0.2080577949860266, 0.11607182877404348, 0.08968343905040196, 0.2376206565116133, 0.18170577473938465, 0.08219459054193326, 0.16714969224163465, 0.2037499797131334, 0.19889264607003757, 0.19785037556929247, 0.11912997253239155], [0.05243096746770399, 0.036082490613417964, 0.015126231725194624, 0.006446434667200914, 0.03538708382153085, 0.023069003197763647, 0.051205461977847984, 0.08849791623651981, 0.02795272846040981, 0.11750033497810364, 0.04311808112210461, 0.12028686116848673, 0.05366129394886749, 0.02944061326395188, 0.09074066446295806, 0.012262013275176287, 0.055915360139416795, 0.05154855642467737, 0.05188195799876537, 0.04388035414740443, 0.029984319981719767, 0.05018013110384345, 0.016362960184259073, 0.03040896076709032, 0.1847434403108699, 0.02832987349081252, 0.06895324428166662, 0.10584330013287918, 2.717723173754556, 65.66866861070905, 91.34210954393659, 87.31804643358502, 97.26422595977783, 62.57435090201241, 37.17710781097412, 19.759193352290563, 2.836897590330669, 0.13364015892148018, 0.3032415067510945, 1.87482374055045, 27.823229210717336, 61.585941859654014, 62.858407156808035, 53.653124468667166, 50.72056082316807, 68.31264577593122, 77.02635383605957, 78.02132892608643, 75.88146441323417, 78.18285369873047, 76.17563724517822, 73.18596635546002, 71.59503037588937, 73.30344649723598, 73.4367824281965, 69.46525464739118, 72.28882190159389, 70.62876524244035, 71.43884181976318, 72.96074744633266, 73.36116518293107, 67.0067387989589, 66.86163261958531, 65.3436666216169, 66.00651781899589, 64.89002568381173, 64.80584825788225, 50.821160316467285, 34.39088017599923, 30.57591962814331, 21.170424597603933, 24.656643288476126, 19.578380380358013, 10.193736893790108, 4.759571620396205, 1.1886310470955712, 1.9187330986772264, 1.073959823165621, 0.13276267743536405, 0.025620886889685477, 0.1933136090104069, 0.15271620745105402, 0.10653400806976215, 0.015049470754872476, 0.3680923011686121, 1.474120693547385, 1.4640600276844842, 0.8130956238933972, 3.915431499481201, 0.3437423120651926, 2.549183543239321, 1.3378027911697115, 2.1449911977563585, 3.8245012930461337, 2.2292087929589406, 0.17169970380408422, 11.226721235683986, 1.9677235441548484, 0.3363662835742746, 0.043268437696886916, 0.10378407527293478, 0.011647328401782682, 0.024771067579942088, 0.05033274720023785, 0.4093498358769076, 1.105863671217646, 6.903280224118914, 10.575575147356306, 14.632873228618077, 22.242538588387625, 27.411649193082535, 22.54769652230399, 24.79130458831787, 29.565700190407888, 32.916545391082764, 53.07021229607718, 63.56670652117048, 67.085691179548, 63.58572374071394, 62.24753543308803, 62.18127046312605, 61.48991775512695, 59.466122899736675, 66.64229188646588, 66.85142571585519, 66.87433392660958, 65.42489801134381, 68.22639083862305, 65.71517290387834, 67.85425227028983, 65.43415996006557, 65.33022880554199, 68.77121993473598, 67.54420280456543, 67.85892145974296, 68.27490316118512, 69.67523615700858, 54.15205029078892, 37.508533409663606, 34.5982734816415, 44.11784403664725, 31.548795972551616, 12.129552790096827, 14.979854106903076, 15.11910469191415, 26.731896502631052, 37.47000217437744, 45.64998088564192, 48.168459687914165, 34.0217501776559, 40.55193471908569, 9.386298894882202, 0.10409851518592664, 0.11929121959422316, 0.12515084445476532, 0.17737081806574548, 0.019374468230775425, 0.01158084808516183, 0.0495473971989538, 0.05368710881365197, 0.05847848206758499, 0.03969336221260684, 0.05476558255031705, 0.01741506944277457, 0.06269581469574145, 0.03357798393283572, 0.09542909038386174, 0.021263301073174392, 0.04972016578540206, 0.032927200996450016, 0.07277714194996016, 0.015050419007561036, 0.022326188860461116, 0.09530306607484818, 0.08451995719224215, 0.012113626996454383, 0.011428996188832181, 0.03891340995739613, 0.024098693659262996, 0.032277666564498625, 0.020265608626816953, 0.08389961333679301, 0.008805890916846693, 0.1262802659933056, 0.055663521867245436, 0.02333789984030383, 0.0493371463380754, 0.07978699223271438, 0.07837798033974, 0.03737622619207416, 0.016493512018184577, 0.03223333108638014, 0.015777808547552143, 0.05641069748838033, 0.05976185641650643, 0.02121013615812574, 0.046875458609844954, 0.0034051985172222233, 0.10671699539359127, 0.017625902147431458, 0.04698292498609849, 0.020872963625671606, 0.05909956552620445, 0.08969248392220054, 7.692873511995588, 90.18348353249687, 90.3124976839338, 88.78731945582798, 100.64511517116001, 59.82406629834856, 52.96096576963152, 24.559371982301982, 2.7046114887510027, 0.20285379780190332, 0.4190991355904511, 2.7608536822455267, 39.34263896942139, 73.38619259425572, 74.79540538787842, 61.13223838806152, 63.052942820957725, 75.14209965297154, 82.59970542362758, 77.15231772831508, 79.00648621150425, 78.83561611175537, 79.65766443525041, 74.05141312735421, 74.67884240831647, 75.47527967180524, 74.1890708378383, 69.6187264578683, 71.87926033564976, 70.87261922018868, 70.15117386409214, 71.34845965249198, 73.93380096980503, 66.39608941759381, 67.24957833971295, 67.00586332593645, 67.0211215700422, 65.17042023794991, 66.22523321424211, 56.63513496943882, 34.37356873920986, 29.81009612764631, 25.390256677355083, 28.439609118870326, 25.722239868981497, 12.59856835433415, 5.260026480470385, 5.426961728504725, 0.19278925071869576, 0.7985167290483202, 0.11374309659004211, 0.08828197246683495, 0.5607711406690734, 0.6161408466952187, 0.532090713935239, 0.12841047240155085, 1.3141883611679077, 0.2395987489393779, 1.5037161111831665, 2.9677716876779283, 3.398375004529953, 0.3567599249737603, 2.651945880481175, 0.9905658066272736, 3.5965465307235718, 4.801308146544865, 1.719170412846974, 0.47622551449707573, 7.900756665638514, 3.0284870011465888, 0.38920290981020245, 0.051217214204370975, 0.07294727103518588, 0.03990185906046203, 0.04708923785282033, 0.02072937543770032, 0.2203734769885029, 6.4931241529328485, 9.497152192252022, 11.33755542550768, 11.526542953082494, 21.86562487057277, 29.399620873587473, 23.18813283102853, 26.070328984941753, 31.375587803976877, 38.27394001824515, 59.26039368765694, 66.57542242322648, 65.74800314222063, 62.789258684430806, 61.79490198407854, 61.578236307416645, 64.20713588169643, 62.86784281049456, 68.19688183920724, 67.85578782217843, 68.66507925306047, 66.69887801579067, 69.13925906590053, 66.54707377297538, 71.22103663853237, 66.1159449986049, 64.56264046260289, 69.7753596987043, 69.84801701136998, 68.98865686144147, 69.84143706730434, 71.13981219700405, 58.21766015461513, 44.69501352310181, 41.30547727857317, 51.76566021783011, 37.104419231414795, 13.026568702289037, 20.50475764274597, 27.149669102260045, 40.20988185065133, 44.439420563834055, 62.078784533909385, 65.80446420397077, 50.35993194580078, 52.82161269869123, 14.934656075068883, 0.15827757545879909, 0.12780184006052359, 0.08442397841385432, 0.01924644733246948, 0.06255374981888703, 0.05329571285152009, 0.06717262590037924, 0.1415271514228412, 0.08861925865390471, 0.04615289006116135, 0.05183415859937668, 0.046781508651162894, 0.09171873198023864, 0.0029719503030979206, 0.08667446872485535, 0.040001223728592904, 0.09245378218059029, 0.06956932693719864, 0.0412784437648952, 0.05834956719939198, 0.019687106633292775, 0.12508746928402356, 0.10155827685126237, 0.040158609926168404, 0.14130593543606146, 0.12467722701174871, 0.14755567722022533, 0.08551360387355089, 0.11637398041784763, 0.18157943151891232, 0.11081981845200062, 0.22281739727727004, 0.14017023066324846, 0.32279642458472935, 0.16845104098320007, 0.2890922874212265, 0.22317961284092494, 0.15168492921761104, 0.1825189853885344, 0.1319350954145193, 0.11455265672079154, 0.10629420700882163, 0.14715299382805824, 0.1824596949986049, 0.13374434118824347, 0.13162907612110886, 0.21419561920421465, 0.3124310422156538, 0.30594177756990704, 0.16427834917392048, 0.16970601864159107, 0.20717586231018814, 5.828663144792829, 93.02160031454903, 111.2805073601859, 102.91134657178605, 116.60074996948242, 79.86756256648472, 56.80088077272688, 36.95152759552002, 4.283980020454951, 0.35551693024379866, 0.9467073657682964, 2.9651122646672383, 49.748945576804026, 93.57865824018205, 85.66555636269706, 71.27302306038993, 69.2157517841884, 80.13051714215959, 85.10779666900635, 76.74342318943569, 79.19172518593925, 81.3388227735247, 80.38927500588554, 75.83495317186627, 72.00493240356445, 79.07713549477714, 74.44815526689801, 71.32721900939941, 72.6230719430106, 70.94671480996269, 71.28777408599854, 74.2071431023734, 74.54784802028111, 67.54134014674595, 66.83713327135358, 67.29286561693463, 66.41288321358817, 67.20356736864362, 65.47561986105782, 63.11862414223807, 45.0397310256958, 38.98328161239624, 29.071575573512487, 36.498598848070415, 31.430339608873638, 19.863628251211985, 8.684208614485604, 13.439320359911237, 4.343001493385859, 2.4657028913497925, 0.2721168340316841, 0.12245908246508666, 0.3682755327650479, 0.26739178757582394, 0.35073496827057427, 0.18175955542496272, 1.2381694231714522, 4.428820431232452, 4.185217891420637, 10.97849336692265, 10.697877338954381, 3.7593619312558855, 10.11777137007032, 2.9806701498372212, 9.611508250236511, 17.04122655732291, 5.885084254401071, 0.5944189322846276, 25.629189593451365, 8.592937077794756, 0.5733005883438247, 0.11545498615929059, 0.1832944152078458, 0.11920431282903467, 0.08721289983285324, 0.07336714171937533, 0.6851310304233006, 13.772272825241089, 11.868246674537659, 16.952333041599818, 19.443246603012085, 28.133488859449113, 32.86899886812483, 29.818062237330846, 32.32759175981794, 35.37252862112862, 44.637430327279226, 61.60782173701695, 68.48445388248989, 71.2868847165789, 65.5080679484776, 61.73111752101353, 60.924257959638325, 62.895760672433035, 60.34472261156355, 70.9867433820452, 70.8997449874878, 70.55897058759416, 67.2104182924543, 70.49271951402936, 66.7933109828404, 73.05722318376813, 68.29750565120152, 67.10497937883649, 70.60423810141427, 72.87160900660923, 72.33410331181118, 69.99466569083077, 72.94116742270333, 65.76629774911063, 46.904408659253804, 48.160347666059224, 59.708406584603445, 41.83575684683663, 16.811559064047678, 23.543554033551896, 33.746900285993306, 43.32575634547642, 46.10151999337332, 67.05565411703927, 77.82139451163155, 64.67372826167515, 62.78697967529297, 14.7335022517613, 0.2217166099165167, 0.35173768017973217, 0.2568645067512989, 0.2210386177258832, 0.17807714587875775, 0.14429774561098643, 0.21578218335551874, 0.17793451781783784, 0.2039358304547412, 0.11795055653367724, 0.23407183693987982, 0.09280128710504089, 0.1959746197930404, 0.22147339582443237, 0.1728269268891641, 0.2029471913618701, 0.17596413354788507, 0.14693177784127848, 0.10456590367747204, 0.09259500567402158, 0.09594033937901258, 0.17086404721651757, 0.2518483687724386, 0.11037132716072456], [0.02244760761303561, 0.07194238102861814, 0.05473280591624124, 0.0037535454612225294, 0.03251642268151045, 0.1096473845786282, 0.05056443637503045, 0.02354182505847088, 0.05986637795077903, 0.05158078344538808, 0.05422174691089562, 0.07046875903116805, 0.0047590461493070635, 0.06960526893713645, 0.0636869982949325, 0.07596723362803459, 0.022291010212419287, 0.02681993121015174, 0.05428242490493825, 0.08268283041460173, 0.08498803100415639, 0.03693794685282877, 0.07977984725896801, 0.04669950430148414, 0.03746454091742635, 0.07776208088866302, 0.05897259126816477, 0.04527232802606054, 0.1813782730272838, 19.537474598203385, 94.80508477347237, 70.73136929103306, 91.8508358001709, 86.19480064937046, 38.36610787255423, 29.449776445116314, 10.476393955094473, 0.9678391175610679, 0.5510812806231635, 1.8780887424945831, 13.502226744379316, 49.3134776524135, 51.993568079812185, 49.30776623317173, 51.18718099594116, 65.04504694257463, 77.02706950051444, 77.166825566973, 78.63519532339913, 78.64940438951764, 78.36310386657715, 73.62925447736467, 73.56664425986153, 71.133544921875, 71.29732091086251, 70.52431992122105, 70.74764892033168, 71.07609721592495, 70.94497081211635, 70.01869256155831, 69.85670225960868, 67.10660525730678, 70.2737261908395, 67.76984555380685, 69.44216578347343, 65.3777961730957, 63.633089610508506, 47.41124847957066, 37.28694493430001, 24.407704966408865, 22.435132231031144, 28.243058477129253, 18.593205724443706, 14.608101163591657, 4.309291439396994, 1.6079076060226984, 0.804757079907826, 0.3806631394795009, 0.21109923321221555, 0.3683476746082306, 0.2924611323646137, 0.43431672187788145, 0.14978006428905896, 0.3170650021306106, 0.9665746539831161, 0.5810770339199475, 0.8715796970895359, 1.170376392347472, 1.1065257042646408, 0.22806297508733614, 0.2584759459963867, 0.18777433410286903, 2.253248908690044, 1.7976268657616206, 0.4677868187427521, 0.06234375001596553, 3.1412983877318243, 1.2334116441862923, 0.2574521452188492, 0.04295175861833351, 0.1211139682148184, 0.14867421505706652, 0.13066368363797665, 0.14112750786755765, 0.16488348027425154, 3.852916385446276, 6.936809190682002, 14.080589583941869, 22.73078850337437, 25.875426803316387, 26.31345340183803, 25.280954565320695, 23.216267824172974, 30.913980756487163, 33.60035930361067, 47.088622774396626, 65.3329941885812, 62.7385368347168, 63.58282634190151, 63.98497417994908, 60.06002017429897, 61.698210852486746, 62.37151214054653, 63.898892947605674, 65.78482859475272, 65.07722405024937, 68.45090103149414, 67.51486056191581, 66.61935588291713, 66.74608407701764, 68.31193705967495, 70.76417868477958, 71.02431924002511, 67.67899090903146, 71.08991023472377, 71.00568417140416, 67.66377435411725, 51.99818863187517, 38.28691577911377, 37.64475284303938, 53.06521306719099, 29.526633943830216, 28.54047438076564, 18.24905276298523, 19.05543463570731, 29.34469883782523, 34.83628749847412, 49.762115887233186, 35.38599075589861, 36.92243548801967, 25.667064223970684, 0.813140732901437, 0.15467425595436776, 0.16935195906886033, 0.09323987857039485, 0.08820095538560833, 0.048210920699472935, 0.10153914894908667, 0.010531467385590076, 0.05261039587536028, 0.04807030110220824, 0.042939063228134594, 0.08721305589590754, 0.07133684280727591, 0.12478529049881867, 0.02072279534435698, 0.04049975697749427, 0.03982788517272898, 0.055639589937137704, 0.039135816773133617, 0.11652046255767345, 0.051993373448827436, 0.03655277984216809, 0.0522274883863117, 0.03774200745725206, 0.08057569419699055, 0.016209785992811834, 0.026967899341668402, 0.05390671667243753, 0.0519126651010343, 0.030729331076145172, 0.05069647928965943, 0.04378823284059763, 0.03855877023722444, 0.017971980452005352, 0.06906136883688824, 0.00584019797887387, 0.034894633639071665, 0.049180981503533464, 0.06578941190881388, 0.03515001047136528, 0.06552710384130478, 0.014470841536032302, 0.07101100350597075, 0.05152348116306322, 0.06857882187302623, 0.01630910825250404, 0.007642294113923396, 0.08690008840390614, 0.03133067595107215, 0.07396545354276896, 0.0306966833637229, 0.03919426577963999, 0.05275735638237425, 0.33349705753581865, 43.57215683800833, 105.18723596845354, 83.20616504124233, 102.20436041695731, 78.35081250326974, 49.42312022617885, 46.86729138238089, 16.940500259399414, 2.278508867536272, 0.2193097240690674, 2.7738489849226813, 19.412514720644268, 66.56121335710797, 72.2271705354963, 60.80124705178397, 59.2294533593314, 74.16623905726841, 80.38196550096784, 79.93618992396763, 79.29249491010393, 81.04806150708879, 78.4207878112793, 77.92886229923793, 75.05478858947754, 72.20176097324916, 72.96859196254185, 72.56125382014683, 72.59334754943848, 72.56583268301827, 70.03397165025983, 70.93507657732282, 72.57517106192452, 69.49330452510289, 71.92322853633335, 68.7534464427403, 68.518951688494, 68.48762920924595, 67.85715661730084, 53.7569375038147, 36.97610337393624, 25.138288940702164, 25.00043841770717, 30.454677036830358, 24.628530876977102, 15.423826626368932, 4.553796810763223, 8.203624299594335, 1.9968649404389518, 0.6361499758703368, 1.0618905850819178, 0.821796885558537, 1.1458179844277245, 0.9613966175488063, 0.8256574241178376, 2.1829166369778767, 3.1203969035829817, 1.06680600132261, 0.31262442469596863, 0.46639017654316767, 0.7646435009581702, 0.6650817862578801, 0.23210153409412929, 0.4076794997922012, 1.7445551135710307, 1.8151691130229404, 0.4134212631200041, 0.4004782890634877, 4.055254442351205, 0.6651715700115476, 0.18949404039553233, 0.050999363751283715, 0.07048336789011955, 0.05638016341254115, 0.18000554240175656, 0.19584601026560577, 0.6426698831575257, 9.76067304611206, 9.689389739717756, 11.050319501331874, 17.156380789620535, 27.833868639809744, 26.569829770496913, 26.76269612993513, 24.777983154569352, 32.19263342448643, 41.38380432128906, 56.88313702174595, 70.99933351789201, 60.375753266470774, 62.31090995243618, 65.25946835109166, 61.13188402993338, 64.24171011788505, 63.95108086722237, 63.8031120300293, 67.66372571672711, 64.99515887669155, 67.62459346226284, 67.0582388469151, 70.20077010563442, 69.5624668938773, 66.84677042279924, 69.92129271371024, 73.19408879961286, 69.35967676980155, 69.76854351588658, 71.63429464612688, 68.55305344717843, 55.93326963697161, 41.70670100620815, 42.31185436248779, 55.23201922007969, 33.760525703430176, 37.4708811214992, 33.662045410701204, 32.87623194285801, 39.37131418500628, 55.703065395355225, 64.75367423466274, 63.28242097582136, 50.219567911965505, 35.505558831351145, 2.0099657688822066, 0.1350921288664852, 0.10213183571717568, 0.043075743929616044, 0.032341499746377976, 0.02554497748081173, 0.08094591647386551, 0.026951173453458717, 0.07399472554347344, 0.05246349982917309, 0.014700233869786774, 0.05797739074166332, 0.01696004725194403, 0.045825853145548275, 0.08207735326141119, 0.03825690357812813, 0.03173766804060765, 0.02502271925498332, 0.07028687771941934, 0.06333836021700076, 0.06469541668359723, 0.045734563044139316, 0.03555534354278019, 0.04999683843925595, 0.1325121894478798, 0.14559693661119255, 0.12836765684187412, 0.12573640660515853, 0.09149684424379043, 0.16100915388337203, 0.18035741709172726, 0.12386343282248292, 0.08753810131124087, 0.16901950405112334, 0.16278136521577835, 0.12775683961808681, 0.1756730963076864, 0.17115413450769015, 0.15333364717662334, 0.10498706357819693, 0.11179339406745774, 0.053701076457010846, 0.12929264934999601, 0.21735042706131935, 0.19821525099022047, 0.23121026477643422, 0.2663781376821654, 0.20332995296588965, 0.16380178688892297, 0.10734324250370264, 0.1917976803545441, 0.14356046303042344, 0.2878612077661923, 0.2516472509929112, 37.52777991976057, 119.01431792122978, 88.03211280277797, 112.26149572644914, 103.78008678981236, 58.57848358154297, 55.273371423993794, 26.44790278162275, 3.7560754333223616, 1.3224798419645853, 2.9601106473377774, 26.465544257845195, 79.28624153137207, 76.15922560010637, 70.50301674434117, 65.4929278237479, 80.66972514561245, 82.06526388440813, 82.90751756940568, 79.28041894095284, 80.84082453591483, 79.98055417197091, 76.90721307482038, 73.34945052010673, 74.10508796146938, 72.6306732722691, 71.63817174094063, 70.9010373524257, 73.30615629468645, 69.03879506247384, 71.40212753840855, 72.90558569771903, 70.82323837280273, 71.75326170240129, 68.57119519369942, 69.46842997414726, 70.00754070281982, 67.89435727255685, 60.564716475350515, 44.790863922664094, 31.10969066619873, 29.49668025970459, 40.888519355228965, 29.248497554234095, 29.51928969791957, 7.843555620738438, 17.891585315976823, 1.7137184653963362, 0.4329991154372692, 1.3166150195258004, 0.8314888083509037, 0.7088590200458253, 0.5962510854005814, 0.9783345886639186, 2.6266055830887387, 2.977552362850734, 1.863760905606406, 1.7509088069200516, 2.5740316041878293, 5.872986572129386, 1.7284825188773019, 1.879978435380118, 1.414825092468943, 5.83596179315022, 7.974115746361869, 0.9353725739887783, 0.5616507391844476, 14.15870818070003, 2.671082522187914, 0.3658759072422981, 0.27737037784286905, 0.24522236574973377, 0.2428997132394995, 0.3034980201295444, 0.2556203177997044, 0.5500870911138398, 14.45479610988072, 9.764140197208949, 17.91902548926217, 30.67701244354248, 34.6498430115836, 32.0132691519601, 32.32962758200509, 32.057605607169016, 37.93666056224278, 47.31013829367501, 55.5974006652832, 71.86755956922258, 65.29219436645508, 64.72784778050014, 66.5887907573155, 60.443095207214355, 66.33820397513253, 66.00651781899589, 66.7457366670881, 69.80420861925397, 67.22467599596295, 71.68998445783342, 68.8528265271868, 72.62460749489921, 73.83148874555314, 72.5592874799456, 71.2599048614502, 74.70898369380406, 70.32783876146588, 72.61957005092076, 72.63646112169538, 74.77613803318569, 62.37588950565883, 49.60845994949341, 50.83738088607788, 62.74320602416992, 44.90080526896885, 39.679564067295615, 40.38064425332205, 32.221708161490305, 39.74127796718052, 55.393543992723735, 80.56163896833147, 74.25933102199009, 69.1449635369437, 35.519260678972515, 1.1801171153783798, 0.2203029500586646, 0.29627411918980734, 0.1778381929865905, 0.1927014754286834, 0.07613507605024747, 0.22145042062870093, 0.10605883678155285, 0.17038097099534102, 0.1653530943606581, 0.09880840512258665, 0.1612654501306159, 0.18077360333076545, 0.22049599327147007, 0.17399349143462522, 0.14648991583713464, 0.11164170077868871, 0.16022537808333123, 0.1812664233148098, 0.19145504731152738, 0.19138730237526552, 0.13200210753296102, 0.1465286330452987, 0.1743799035570451, 0.3552371838263103], [0.004908290774827557, 0.14770813046821527, 0.08529969570892197, 0.022940729545163255, 0.02652162855624088, 0.03335469841424908, 0.05903211236000061, 0.09804457146674395, 0.03507340047508478, 0.03380468248256615, 0.03487822666232075, 0.028635914836611067, 0.048862843574689965, 0.04114503699487873, 0.05430334074688809, 0.05303413760183113, 0.0355618676569845, 0.05134995601006916, 0.011104494449682534, 0.07272665894457273, 0.0811109361904008, 0.042578703457755704, 0.018176823388785124, 0.04657374122845275, 0.02476978854143194, 0.20224741819713796, 0.047565789959792576, 0.0577489754983357, 0.04854420352993267, 2.248939288514001, 68.87147549220494, 89.35773181915283, 78.90853745596749, 102.74086557115827, 63.65387167249407, 30.35563394001552, 26.355634178434098, 12.374573196683611, 2.2386678968157088, 3.2598400839737485, 8.511184573173523, 36.32760715484619, 41.16578027180263, 47.652934619358604, 51.62168312072754, 61.03523458753313, 71.79520797729492, 82.0441483088902, 76.35080133165631, 79.34550966535295, 77.29652759007045, 78.60444259643555, 74.9186247416905, 75.74978215353829, 75.21529197692871, 72.49054200308663, 68.94502217429024, 72.33641011374337, 70.88023444584438, 72.11479037148612, 73.03930377960205, 71.11257525852749, 70.20557825905937, 69.80316638946533, 64.94921738760812, 69.59420626504081, 61.13496208190918, 42.20231253760201, 31.35401017325265, 26.35680147579738, 26.34013795852661, 26.434294734682354, 21.694902420043945, 13.460252676691328, 6.244023850985935, 9.112725734710693, 1.5413759989397866, 2.2503113406045094, 1.457173385790416, 2.7572938161236897, 2.335562914609909, 4.79030784538814, 0.6678023317030498, 0.6692156387226922, 3.5050524345466068, 0.23924715923411505, 0.9093988505857331, 0.3861086815595627, 0.0602811189102275, 0.22064012768013136, 0.06586141804499285, 0.32568524671452387, 1.409566608922822, 0.12271517515182495, 0.12808784257088388, 0.27424309136612074, 1.341480668101992, 0.7143921202846936, 0.26059199816414286, 0.08121007694197552, 0.14690645491438253, 0.11909155387963567, 0.11962853292269365, 0.2825736014970711, 1.1461897130523409, 6.857856375830514, 5.933177513735635, 23.330718551363262, 17.920224053519114, 14.829446452004568, 32.60069070543562, 22.410182986940654, 27.83802887371608, 29.92661394391741, 36.43547446387154, 33.996066161564414, 58.13137742451259, 63.971063886369976, 66.96313190460205, 61.17989608219692, 61.94000816345215, 60.42743396759033, 64.41196182795933, 66.14610712868827, 65.48345742906842, 67.1946667262486, 71.28993497576032, 69.81101090567452, 65.07591778891427, 64.70628752027238, 68.66774041312081, 67.98495483398438, 71.95994281768799, 72.12922872815813, 74.09872341156006, 74.84918444497245, 64.6258065359933, 47.863131523132324, 50.174890995025635, 50.30867855889456, 38.920334407261436, 29.015152726854595, 18.40278513090951, 19.39044550486973, 22.624406371797832, 35.15663766860962, 43.66363334655762, 38.28433799743652, 32.034502846854075, 30.368637493678502, 6.926577968256814, 0.19953437734927448, 0.11472295543977193, 0.0940809091553092, 0.16922694577702455, 0.04718509788757988, 0.08764355922383921, 0.10589092650583812, 0.04827077088079282, 0.1144097979579653, 0.09417895068015371, 0.07186412558491741, 0.1276574478085552, 0.0764440605416894, 0.07932108973285981, 0.03862431672002588, 0.05600262652816517, 0.05253505473956466, 0.02785114328643041, 0.013350503885054162, 0.07147398151989494, 0.03764806428392019, 0.06897617197994675, 0.06883889756032399, 0.06080992839166096, 0.04970303277618118, 0.013334776291490665, 0.14021747027124676, 0.05262947967275977, 0.03831263844455991, 0.13305356539785862, 0.014861557266807981, 0.16224862023123673, 0.031158558758241788, 0.11189215483942203, 0.058612492733768055, 0.06379808126283543, 0.09686493155147348, 0.0450715902261436, 0.058260713038699966, 0.060321525670588017, 0.028487583688859428, 0.08506737888923713, 0.04433275380038789, 0.01850583653764001, 0.058665153836565356, 0.06299875344016723, 0.02713241015693971, 0.05891803026731525, 0.07506974214421851, 0.06922024102615458, 0.09807710043553795, 0.03693618266178029, 0.11436675169638225, 0.0926289799224053, 7.546946576663426, 91.7179515021188, 90.44483307429722, 95.42650386265346, 96.21491595676967, 59.0028726032802, 46.35414259774344, 37.08445010866438, 16.93260015760149, 5.212766136441912, 2.562170160668237, 11.763162119047982, 47.22399800164359, 53.48997034345354, 59.296892574855256, 63.137822014944895, 67.98578861781529, 79.00902925218854, 85.63239261082241, 80.54308727809361, 82.39917346409389, 78.2408642087664, 80.32986790793282, 79.4194871357509, 77.89448956080845, 78.12291158948625, 74.18151119777134, 70.70721735273088, 71.88908508845738, 70.50973565237862, 74.09784099033901, 72.94867147718156, 69.97152124132428, 72.03431633540562, 67.59222180502755, 66.17440714154924, 70.74769755772182, 65.34848172324044, 47.45159319468907, 36.332814829690115, 27.752605983189174, 26.32623635019575, 28.37098870958601, 27.14310826574053, 16.150411912373134, 4.524985236780984, 12.498657601220266, 9.126997334616524, 4.191833879266467, 0.5074307971767017, 0.7377919160893985, 0.6043849289417267, 0.9135394884007317, 0.9252396034342902, 0.40634224297744886, 3.033042196716581, 1.3636828767401832, 0.7966937497258186, 1.9896726863724845, 0.20900364566062177, 0.33217725264174597, 0.04837601844753538, 0.3546893617936543, 1.2716746138674873, 0.12362902611494064, 0.5214663754616464, 0.25672817549535204, 1.0650180344070708, 1.0018521781478609, 0.0945425775966474, 0.20992327774209635, 0.1090421856247953, 0.13928937007273945, 0.15662903391889163, 0.224085144964712, 2.7028709650039673, 8.943488461630684, 12.00474056175777, 34.55339159284319, 24.531695570264542, 22.38151819365365, 30.459512983049663, 25.83658811024257, 27.23569996016366, 33.8294483593532, 40.346535546439036, 43.53105476924351, 61.53824247632708, 65.88860688890729, 64.57817663465227, 63.771004404340474, 63.2099860055106, 66.57523482186454, 65.60496057782854, 67.39774867466518, 65.34012304033551, 67.92607579912458, 69.76239436013358, 72.62473256247384, 67.17366232190813, 65.59128652300153, 67.35787991115025, 72.59120750427246, 73.55644430433, 73.32864761352539, 73.39195959908622, 76.1600454875401, 64.10913154057094, 53.46700654711042, 50.25885650089809, 51.58145999908447, 44.15716389247349, 41.8949659211295, 40.53173630578177, 34.74846921648298, 29.805037839072092, 51.79173680714199, 56.14699969972883, 62.87474931989397, 43.88214724404471, 41.750867230551584, 10.798977971076965, 0.13997416118425982, 0.18279012798198632, 0.07435115320341927, 0.12172759457358293, 0.051083824397729974, 0.035498031082430055, 0.07401381951889821, 0.02791529198709343, 0.08094373159110546, 0.04009060375392437, 0.08625688470367875, 0.08864740428647824, 0.044657806001071415, 0.1569912223411458, 0.09393162466585636, 0.04785633186942764, 0.11333543275083814, 0.125151305858578, 0.013054342857295913, 0.06844899776790823, 0.008176337644856955, 0.07341879180499486, 0.05729198216327599, 0.0877822789230517, 0.05157003884336778, 0.13974678409951075, 0.28602308354207445, 0.08826764859259129, 0.1756385995873383, 0.1693205428974969, 0.12289965525269508, 0.16963475889393262, 0.14028393956167357, 0.1988736470895154, 0.15258587444467203, 0.09360898804983922, 0.1491706177060093, 0.1515885093914611, 0.1230836875204529, 0.21509059332311153, 0.16037471007023538, 0.13995362871459552, 0.13532664413963044, 0.09272700787654944, 0.19132136234215327, 0.1929828774716173, 0.1845689346747739, 0.16721114037292345, 0.1176533717662096, 0.14175539703241416, 0.4097567940396922, 0.14026291854679585, 0.1970672375921692, 0.1200882268271276, 5.143647628171103, 98.23433344704765, 111.85546384538922, 102.35798508780343, 116.7609476361956, 83.7953792299543, 47.21798433576311, 46.39579357419695, 26.72508726801191, 7.788928014891488, 3.578121427978788, 16.39096028464181, 61.64083957672119, 61.52768121446882, 66.85644231523786, 71.5905487877982, 76.04920087541852, 82.18794822692871, 87.67001438140869, 80.3239688873291, 83.0173338481358, 80.7237126486642, 80.04526274544853, 78.73339421408517, 80.062410899571, 79.3380125590733, 75.21723052433559, 69.36890397753034, 75.4068329674857, 69.6180316380092, 72.73939868382045, 73.8366026197161, 71.34286635262626, 75.49779878343854, 70.0318524496896, 64.87656007494245, 71.24527890341622, 65.73094531467983, 52.783908299037385, 42.90739836011614, 35.2504939351763, 34.32879454748971, 39.78106335231236, 32.95043175561087, 23.707380396979197, 11.5003673519407, 22.157992907932826, 9.12866403375353, 8.535422495433263, 1.9151261150836945, 5.812627136707306, 6.0894781095641, 7.174452347414834, 2.5779679758208136, 4.583097364221301, 16.319937535694667, 1.8944715091160365, 1.1815819910594394, 3.0382846125534604, 0.36142900586128235, 1.034697289977755, 0.16574735034789356, 0.6643148788384029, 6.100799764905657, 0.1502213698944875, 0.73566413883652, 0.4400307738355228, 4.244197675159999, 1.4919310978480746, 0.3828675097652844, 0.35135219086493763, 0.18301335243242128, 0.18971220297472818, 0.2292500856731619, 0.4125635677150318, 1.3733616088117873, 21.74165337426322, 9.431401388985769, 36.787188802446636, 20.047359466552734, 17.994135516030447, 37.406676292419434, 28.556067875453405, 37.110738618033274, 37.45086683545794, 47.15202161243984, 44.41441747120449, 65.20799609592983, 66.88722283499581, 67.99201420375279, 64.18323407854352, 63.40377821241106, 64.89584827423096, 68.30078520093645, 70.41824177333287, 69.84623827253068, 71.87909357888358, 70.9561574118478, 72.47602026803153, 69.3046817779541, 71.20946093967983, 70.81274659293038, 69.11871324266706, 76.16896002633231, 75.5753754207066, 76.70142827715192, 78.03499603271484, 71.55852454049247, 57.51767430986677, 58.17065906524658, 57.76308121000017, 60.32947826385498, 45.06600563866751, 48.65562220982143, 32.82477010999407, 27.734789064952306, 54.913607597351074, 65.08584676470075, 71.7222102028983, 64.17144993373326, 47.80601038251604, 9.308466911315918, 0.1978239534156663, 0.27949644518750055, 0.23738555769835198, 0.2829393318721226, 0.15726714182112897, 0.15796363087637083, 0.12294931044535977, 0.12280552887490817, 0.21263555863073894, 0.08689730641032968, 0.11899323415543352, 0.22630554224763597, 0.17396511510014534, 0.2381442684148039, 0.1879929716565779, 0.149928229195731, 0.10108993162534066, 0.24116643624646322, 0.1628747044929436, 0.21703731029161386, 0.13202919465090546, 0.17716647045952932, 0.19489588482039316, 0.1360647545329162, 0.1131002457280244], [0.1061519453568118, 0.10185372456908226, 0.048017392334129126, 0.046149683983198235, 0.057752503880432675, 0.11295533100409166, 0.029176890450928892, 0.1416124975574868, 0.07922688193087067, 0.12676843122712203, 0.03848257414730532, 0.08836330845952034, 0.057407482394150326, 0.019333094558013336, 0.03441878720851881, 0.010773847727770252, 0.0639406753970044, 0.03366512479260564, 0.07420992970998798, 0.04949433576049549, 0.008827044246053057, 0.06448696394051824, 0.04166722058185509, 0.028507973666169813, 0.05486777670947569, 0.029046526910471063, 0.12352287609662328, 0.02153405690166567, 0.06667283736169338, 0.08325507292257887, 27.26900441305978, 74.1819211414882, 73.87634631565639, 89.92720617566789, 90.28039005824498, 45.123727798461914, 33.946202414376394, 21.421240670340403, 8.686902778489248, 11.473622867039271, 10.43963016782488, 35.465596267155235, 62.41420882088797, 44.76887287412371, 57.66186680112566, 58.289195333208355, 73.80446025303432, 74.82423346383231, 80.08131694793701, 77.2989455631801, 77.07798589978898, 77.71584442683628, 77.71420465196881, 74.69295419965471, 76.58142593928746, 73.69499138423375, 71.17653342655727, 74.36891106196812, 69.94570173536027, 72.57367025102887, 71.64324392591203, 68.96800681522915, 74.40763337271554, 72.13364778246198, 66.60366685049874, 63.09745992933001, 51.05212191173008, 32.2743581363133, 40.356961318424766, 24.339977400643484, 29.462950229644775, 28.602791036878312, 21.906671353748866, 10.50898448058537, 10.267122030258179, 10.628172142165047, 5.834537412439074, 1.1999305550541197, 0.13443253854555742, 0.1147074034171445, 0.08635493979922362, 0.06290194006370646, 0.3094243992652212, 0.22340230803404534, 0.32187595111983164, 0.09622771931546074, 0.1719500832259655, 0.05178821838593908, 0.2384353056550026, 0.08763212590877499, 0.03913455130532384, 0.06381144840270281, 0.49727481071438107, 2.1519459102834975, 0.7308831810951233, 0.21918880912874425, 0.9917301727192742, 0.43439602905086105, 0.612321888761861, 0.2747761213353702, 0.17210371712488787, 0.1283621878496238, 0.2720756876681532, 0.14999868827206747, 3.2565251418522427, 4.1631152374403815, 4.372544365269797, 8.382747990744454, 8.928795627185277, 14.140553406306676, 30.32607282911028, 24.608777148383005, 24.69073462486267, 27.508533137185232, 38.70898757662092, 27.735535996300833, 54.91502850396292, 58.36629254477364, 64.43883746010917, 56.617041860307964, 62.015139034816194, 56.64850330352783, 62.82638985770089, 61.03359481266567, 67.70872919900077, 69.01771422794887, 68.92965275900704, 66.08002281188965, 68.91385950360979, 69.0019348689488, 73.0800758089338, 69.61269542149135, 73.34491334642682, 76.43987723759243, 73.4123386655535, 70.38791288648332, 54.88644361495972, 47.09362547738211, 66.85939529963902, 49.20406436920166, 44.00654084341866, 17.90256346975054, 12.384614212172371, 22.570597784859793, 38.050767353602815, 51.685658659253804, 38.50780596051897, 33.20843573978969, 35.856317792619976, 13.817697542054312, 0.844845634485994, 0.08075454245720591, 0.13219487933175905, 0.09332113992422819, 0.09173924409385238, 0.0790862962603569, 0.09613615101469414, 0.06280961858906917, 0.02624730532988906, 0.002453994201329936, 0.1263239500778062, 0.21388288241411957, 0.07020006594913346, 0.020607597061565945, 0.09977261695478644, 0.09222628295953784, 0.02175148157402873, 0.04266188167301672, 0.07593909478081123, 0.04034020286053419, 0.07634802748050008, 0.08148787596396037, 0.0587498757189938, 0.06763153948954173, 0.025911467815084115, 0.22191806696355343, 0.027548219809042554, 0.02147950098982879, 0.05244913863550339, 0.059002731793693135, 0.044961450421916585, 0.030649206268468072, 0.025568310603765503, 0.00867072250028806, 0.044378880610955615, 0.04070999087499721, 0.053049150189118724, 0.1130195746996573, 0.004787648096680641, 0.15225085456456455, 0.007976101960853806, 0.018709597211065035, 0.021862874971702695, 0.06081087834068707, 0.10687929418470178, 0.03885645033525569, 0.040950338156627755, 0.08274406820003476, 0.07831882565681424, 0.02208930210742567, 0.02937165035733155, 0.04375212799225535, 0.1420328500015395, 0.009230588529525059, 0.09025538978832108, 0.5607755375759942, 49.429526465279714, 95.27572795322963, 86.92497294289726, 105.4131635938372, 80.12771701812744, 53.777497223445344, 46.31984976359776, 37.2764253616333, 17.46160994257246, 15.029874188559395, 9.98272270815713, 38.40329810551235, 67.97199644361223, 54.07534565244402, 65.29782240731376, 71.39948722294399, 76.97385324750627, 83.20392772129604, 82.78135912758964, 80.99143368857247, 80.35991191864014, 80.34067930494035, 77.95206928253174, 76.1846421105521, 80.59125913892473, 75.88661997658866, 75.55024378640312, 74.38270323617118, 71.26538699013847, 71.51272201538086, 73.52096680232457, 70.35174751281738, 75.83307021004813, 71.9384937286377, 68.75280026027134, 66.00453758239746, 61.53409440176827, 39.661352838788716, 41.72961616516113, 28.574491024017334, 30.910246099744523, 33.323310307094026, 24.797187975474767, 14.111497776848928, 7.278827318123408, 14.798358474458967, 11.207106471061707, 0.8946659011500222, 0.11120352321969611, 0.04591207459036793, 0.3381067801799093, 0.10653498516018901, 0.3053250163793564, 0.3592189901641437, 0.12130843635116305, 0.7314673726047788, 0.15191077281321796, 0.07424881655190672, 0.3604990057647228, 0.09246573118226868, 0.11572962999343872, 0.24362962692975998, 0.7149623611143657, 1.8993541385446275, 1.159075147339276, 0.6631125690681594, 1.936685941049031, 2.1817582419940402, 0.6486761665769986, 0.6934373304247856, 0.1201646298702274, 0.32400459689753397, 0.16752840977694305, 0.040996790664004426, 3.58998287149838, 5.095157887254443, 22.185280220849172, 21.955491134098597, 16.142188719340734, 20.771485090255737, 32.3294677734375, 28.89881556374686, 30.758678095681326, 32.97715105329241, 44.164306640625, 35.18949569974627, 61.60082490103585, 61.51395852225167, 61.24051911490304, 60.396986961364746, 65.27273941040039, 61.643896784101216, 65.18722098214286, 62.97473389761788, 68.15189225333077, 69.28349672045026, 72.2064162663051, 70.49267087663922, 73.05550697871617, 66.56885637555803, 72.6844870703561, 73.94790581294468, 73.55653463091168, 75.8656086240496, 74.3623102733067, 68.21491241455078, 57.85249062946865, 50.87820502689907, 69.52020100184849, 52.4909131867545, 57.059103625161306, 42.53109434672764, 29.170504025050572, 32.96296977996826, 49.19195018495832, 60.378101757594514, 55.455223151615684, 49.75381278991699, 40.796500887189595, 20.567454712731497, 1.0616468553032194, 0.0994047491944262, 0.1354446413793734, 0.018759523817737187, 0.11315821976001773, 0.051854073602174006, 0.10148300017629351, 0.057878684252500534, 0.05207928616021361, 0.06033451283084495, 0.012749448235678886, 0.04955254388707025, 0.03375527834785836, 0.03275100580815758, 0.08101820759475231, 0.07160556981606142, 0.045665172660457234, 0.0850598132237792, 0.12712141871452332, 0.0458005370040025, 0.06520852486469916, 0.06185851605342967, 0.11035789216735534, 0.14713774036083901, 0.027340513454484086, 0.06428412946739367, 0.11604328959115914, 0.1577854747218745, 0.26704853028059006, 0.14321727358869143, 0.1742881384811231, 0.202030924814088, 0.10171125935656683, 0.2059380380170686, 0.1822314222476312, 0.1110225443595222, 0.1401899488908904, 0.26989034350429264, 0.13721717840858869, 0.2913145710315023, 0.11292732786387205, 0.186203199837889, 0.1518793430711542, 0.21023148191826685, 0.19635389372706413, 0.18099766916462354, 0.18291447630950383, 0.16401229559310845, 0.1563771888613701, 0.1048821077815124, 0.11221969726362399, 0.09723085870168038, 0.3008444868028164, 0.11560406030288764, 0.2013681453785726, 0.4210668871445315, 39.24923780986241, 98.94457135881696, 97.4176560810634, 119.41200501578194, 102.73357691083635, 65.8698537009103, 48.39984164919172, 42.98379727772304, 23.97828197479248, 20.927140372140066, 12.28643182345799, 52.107251031058176, 90.75395842960903, 66.87551512037004, 75.6198091506958, 79.19840240478516, 83.43173830849784, 83.98433549063546, 83.71607943943569, 81.5353456224714, 78.95795999254499, 80.59649808066231, 80.25286102294922, 76.64562034606934, 78.56842313494, 75.98837634495327, 74.65018803732735, 75.60794162750244, 70.64114693232945, 73.67457062857491, 71.20472921643938, 70.29066589900425, 78.87882695879254, 74.38389832632882, 67.2921221596854, 66.06557055882045, 60.870687348502024, 42.6686235155378, 50.05021251950945, 33.7262293951852, 39.32150254930769, 39.44808830533709, 30.288872173854283, 19.482366698128835, 16.418563740594045, 25.10821713720049, 14.737196956362043, 0.9876921836818967, 0.13439133789922508, 0.16786889864930085, 0.5161958411335945, 0.18082883608128342, 1.1192583867481776, 1.1377731646810259, 1.2527096143790653, 0.6856147987501962, 0.28514592775276726, 0.17908175768596785, 1.3214316410677773, 0.400093993970326, 0.3188729722584997, 0.5246320398790496, 0.9545505791902542, 4.5432603018624445, 1.3205887377262115, 1.461561607463019, 2.799236399786813, 5.2781864660126825, 2.377647719212941, 0.8971411968980516, 0.3214544180248465, 0.6954736411571503, 0.5013230049184391, 0.3421795644930431, 7.166715528283801, 19.493688787732804, 16.55174854823521, 15.647209474018641, 15.028053760528564, 18.02795934677124, 38.661468846457346, 28.28242870739528, 33.476153305598665, 37.696072237832205, 54.80853346415928, 35.51221520560128, 70.09134987422398, 61.15849563053676, 67.95266655513218, 59.61629431588309, 66.53688076564244, 60.815310205732075, 69.66789191109794, 66.2038883481707, 75.13270568847656, 71.81322465624127, 74.93535600389752, 72.03086308070591, 79.39859390258789, 70.25008841923305, 72.6632672718593, 75.00695719037736, 77.87737614767892, 75.94959150041852, 76.97702857426235, 73.68531254359654, 61.31331539154053, 56.666763169424875, 76.17138494764055, 65.12843227386475, 62.908573150634766, 40.71966423307146, 26.391961097717285, 31.396668638501847, 56.510435649326865, 72.03551142556327, 68.34587206159318, 67.25725609915597, 57.36746120452881, 19.91418160711016, 0.6290324692215238, 0.10455067735165358, 0.2743948389376913, 0.17958613990672997, 0.3231670404119151, 0.18740791162209852, 0.23151994815894536, 0.1868967033390488, 0.10447445072765861, 0.18915640137025289, 0.21262569273156778, 0.3179380867098059, 0.1382229301546301, 0.16357508833919251, 0.24505012642060006, 0.21147514161254677, 0.3035939378397805, 0.2447463870048523, 0.17109895603997366, 0.11802345833608083, 0.19028712569602899, 0.18643752512122902, 0.2077851053327322, 0.16916442556040628, 0.10577136185020208, 0.26397490235311644], [0.0606983568785446, 0.12253905460238457, 0.04561868283365454, 0.1294896009245089, 0.05519184164170708, 0.05095997818612626, 0.017059452632176023, 0.12088441981800965, 0.03404657682403922, 0.08968280122748443, 0.08995560623173203, 0.04286869575402566, 0.02539483125188521, 0.0022372567577154507, 0.05678613769954868, 0.07393095003707068, 0.04064851560230766, 0.19485619052180222, 0.04985886512856398, 0.0444662894920579, 0.1323027799704245, 0.03965533711016178, 0.08641172639493432, 0.023998275565515672, 0.026028828928247094, 0.10539185721427202, 0.16467088168220861, 0.0861118139166917, 0.30526172263281687, 0.19060396083763667, 1.8307480599199022, 48.92489269801548, 77.96871021815709, 76.31022385188511, 84.13638292040143, 92.505140713283, 49.31977619443621, 32.50530236107962, 20.98551913670131, 10.985101972307477, 17.043112993240356, 26.54061780657087, 70.61262457711356, 72.71517031533378, 63.57366861615862, 59.83561420440674, 67.89947809491838, 77.82630688803536, 74.35088743482316, 79.4958895274571, 77.93631771632603, 80.9916421345302, 79.18101106371198, 79.65056337629045, 73.48790727342877, 78.06801387241909, 73.2003630229405, 75.61953817095075, 70.59270409175328, 74.7284803390503, 74.11124406542096, 74.90608324323381, 67.75479575565883, 69.22930077144078, 59.12955215999058, 66.52981444767543, 38.17555005209786, 29.763355595724924, 36.68193401609148, 25.340995686394827, 31.75276381628854, 24.20966567311968, 22.988408599581035, 8.70237728527614, 12.516654304095677, 6.463190879140582, 1.33453203524862, 0.27962086136851994, 0.4881861869777952, 0.09473479978208031, 0.08900965377688408, 0.1020297636943204, 0.04615702233942492, 0.2282622472516128, 0.22539968442703995, 0.8608192716326032, 0.14016917214861938, 0.03578420661922012, 0.11961646857006208, 0.11403329244681767, 0.03082596803350108, 0.26639700095568386, 0.4829595131533486, 2.0362827224390845, 2.825967422553471, 0.7598865362150329, 3.396924350942884, 2.4024981686047147, 1.3533577450684138, 0.48683383954422815, 0.19479958713054657, 0.18825677250112804, 0.1512429043650627, 0.2682321396257196, 1.7534395796912057, 1.5714238094432014, 3.3632475180285315, 0.5171044266649655, 13.865005220685687, 18.34328075817653, 29.595619133540563, 27.964442661830358, 23.674202748707362, 39.1642370223999, 30.353407042367117, 19.319655520575388, 33.715650762830464, 48.30148294993809, 63.09528514317104, 59.42965875353132, 62.385908808027, 63.61186286381313, 62.64906488146101, 64.13378374917167, 70.9909748349871, 73.91410282679966, 70.6433356148856, 66.80294118608747, 69.57010296412876, 75.92248657771519, 68.87259415217808, 73.86747346605573, 75.174943787711, 75.36900697435651, 70.27947929927281, 63.951219831194194, 45.83235720225743, 67.74954291752407, 53.07684435163225, 56.358982290540425, 31.270131519862584, 9.08371353149414, 20.18812128475734, 45.17432805470058, 65.59856128692627, 44.75482709067208, 30.38776241030012, 34.103832721710205, 16.737083060400828, 1.827495651585715, 0.17809511348605156, 0.12505643309227057, 0.3876904552536351, 0.159287601975458, 0.05363388791946428, 0.01066622868113752, 0.10452896423105683, 0.047394015427146635, 0.08210007061383554, 0.12633994993354591, 0.022450983324753385, 0.11824432148465089, 0.07344454899430275, 0.04566307259457452, 0.04997711342626384, 0.08807575210396733, 0.04934794861557228, 0.11422271228262357, 0.012323659029789269, 0.026099449156650474, 0.17648167934800896, 0.029000345817101852, 0.02800526742690376, 0.11911914311349392, 0.11876036093703338, 0.07006987543510539, 0.022010797302105596, 0.09709205757826567, 0.05784558531429086, 0.10564174130558968, 0.09531748494399445, 0.05905077885836363, 0.01665087277069688, 0.1407738554158381, 0.02353064789037619, 0.09651022058512483, 0.05593621152053986, 0.0634815718180367, 0.05864054337143898, 0.02893548465466925, 0.05034814994516117, 0.029575265145727565, 0.06712149828672409, 0.07939521289829697, 0.046883824946624894, 0.07132724153676204, 0.047239139809140136, 0.040980797593614886, 0.06711400726011821, 0.039140471523361545, 0.026020443931754147, 0.03462615768824305, 0.15369228007537977, 0.05840659128235919, 0.061948184456144056, 0.06080405906374965, 7.489715133394514, 71.63931819370815, 89.62971210479736, 96.17158699035645, 90.59399700164795, 70.77596977778843, 61.811556816101074, 43.93014192581177, 36.11829962049212, 35.42834002631051, 28.205406188964844, 28.108659471784318, 69.8569940839495, 72.22853238242013, 68.40051964351109, 71.28738498687744, 75.87261935642788, 81.67417063031877, 80.65601634979248, 82.68627302987235, 81.04357297079903, 82.32601588112968, 82.61878517695835, 81.50756672450474, 77.25069727216447, 78.9567996433803, 78.4267007282802, 77.8074425288609, 73.89694772447858, 76.01327174050468, 76.01173618861607, 70.70109598977226, 65.82915115356445, 71.37793391091483, 64.15826225280762, 69.03623812539237, 47.57965891701834, 33.74136257171631, 45.266909326825825, 28.40252137184143, 38.40576819011143, 25.15968244416373, 24.76553545679365, 10.23725780418941, 13.49521427495139, 8.489513141768319, 10.96379097870418, 0.35158682827438625, 0.13024267980030604, 0.07240526404763971, 0.09260512263114963, 0.19700323816921028, 0.01300794632905828, 0.39319356424467905, 0.26615601245846066, 1.6830011308193207, 0.4116393487368311, 0.2486418836883136, 0.04048611503094435, 0.17814075175140584, 0.005108947150542268, 0.1402399433510644, 0.2138975387705224, 3.668373533657619, 3.45877982037408, 1.1443330241101128, 5.870563387870789, 6.045040471213205, 1.5257172563246317, 0.2902844191661903, 0.136891793725746, 0.3410052917897701, 0.1644769428031785, 0.10100343198116336, 0.8334191047719547, 2.1277644421373094, 16.758191687720164, 8.372509820120674, 14.124818342072622, 18.10541091646467, 28.567509821483068, 28.585331950868877, 30.839145183563232, 38.12958771841866, 39.97128071103777, 34.751001834869385, 42.7506365776062, 54.96849141802107, 65.16076919010708, 60.894234793526785, 65.76738861628941, 66.8576443535941, 65.60008294241769, 66.56485421316964, 70.88078335353306, 75.81619998386928, 73.69474124908447, 73.35414055415562, 69.97336251395089, 71.76782512664795, 72.81550925118583, 75.79365307944161, 75.76631191798619, 75.82029942103794, 72.66969435555595, 63.10443592071533, 52.23915215900966, 71.78832926068986, 57.03761979511806, 66.29905087607247, 54.89807489940098, 27.403670924050466, 33.07527003969465, 51.770339829581125, 66.43896675109863, 62.662085805620464, 53.26497030258179, 40.315911361149375, 27.379927192415508, 3.53554590685027, 0.0657601331227592, 0.22482035122811794, 0.08064163423010282, 0.0374254064102258, 0.044160466973802874, 0.05253031856513449, 0.022445787442848086, 0.08924866773720298, 0.015369198151997157, 0.11878626740404538, 0.0800712373373764, 0.0632164953276515, 0.03568167997790234, 0.08540535718202591, 0.10261951240577868, 0.20599150657653809, 0.021186402699510967, 0.014946886438078113, 0.028768690569060187, 0.05531185752313052, 0.15167849670563424, 0.09154570555048329, 0.08974053098687104, 0.0627861480627741, 0.04738673135372145, 0.025407545301797133, 0.10694344288536481, 0.2660076847033841, 0.08801861267004694, 0.1466398992176567, 0.16182473940508707, 0.16170381089406355, 0.25151439383625984, 0.17572948256773607, 0.13430558464356832, 0.29417234339884346, 0.24799287851367677, 0.11283813443567071, 0.1096686227247119, 0.14110518406544412, 0.12552158241825445, 0.17719343544117042, 0.1688407100737095, 0.32442062028816765, 0.18022940467510903, 0.09704732176448617, 0.20390000380575657, 0.14339730249983923, 0.2886485798018319, 0.08787522464990616, 0.16560257811631474, 0.29717605507799555, 0.23792341883693421, 0.2251671233347484, 0.35421796994549887, 0.199678810313344, 3.4883958654744283, 69.94956493377686, 103.09899657113212, 105.06045913696289, 102.76772035871232, 107.79435988834926, 70.15339728764125, 48.04820026670183, 40.40934378760201, 47.38603694098336, 32.63977779660906, 37.61507708685738, 88.08639213017055, 94.34664957863944, 82.8472488948277, 78.5406025477818, 80.49369253431047, 82.9475461414882, 79.55961840493339, 81.65789794921875, 79.18473529815674, 83.52017498016357, 83.73538153512138, 79.6413848059518, 77.58929688589913, 81.55135427202497, 79.9556587764195, 78.01144858769008, 72.04027788979667, 76.67844363621303, 75.94422054290771, 75.42303616659981, 69.78272478921073, 74.08798149653843, 61.83263070242745, 70.04262910570417, 46.40423910958426, 37.81745726721627, 52.38811806270054, 33.38085528782436, 43.4021761076791, 25.71480529648917, 32.76065560749599, 17.59776336806161, 22.40308540207999, 12.606460639408656, 15.892209904534475, 0.452221578253167, 0.3663058270301138, 0.2782666140369007, 0.22331723331340722, 0.3687124821756567, 0.13833642192184925, 1.2677560469933917, 0.24076992752296583, 2.328294664621353, 0.5303537185703004, 0.37236775032111574, 0.2399262370807784, 0.30074908477919443, 0.1498331664396184, 0.8448313581092017, 1.9906732269695826, 8.10909058366503, 10.635066492216927, 1.5640202867133277, 8.962796636990138, 11.07197790486472, 6.095729316983904, 0.5604992381164006, 0.993521722299712, 1.1251730407987321, 0.4816157966852188, 0.25253482908010483, 7.767752511160714, 3.0538322925567627, 11.467265265328543, 6.479713261127472, 20.43930561201913, 21.602043219975062, 35.03088917051043, 28.834796598979406, 29.93685906273978, 49.777995995112825, 43.32348428453718, 30.518426758902415, 48.22193649836949, 56.56474624361311, 68.693420955113, 61.80334404536656, 65.62006596156529, 70.63205174037388, 67.5743579864502, 70.47480010986328, 75.2970027923584, 76.94741535186768, 75.40258066994804, 74.68759713854108, 73.51021099090576, 75.18667234693254, 71.41871983664376, 77.39412198747907, 78.66429437909807, 77.86399391719273, 75.19124426160539, 68.85198579515729, 53.722206933157786, 74.80531351906913, 67.94637148720878, 71.43518011910575, 49.53834220341274, 23.04285294669015, 35.32970339911324, 62.512379918779644, 84.39276450020927, 71.65183189937046, 66.2949583871024, 52.883330072675435, 24.61365130969456, 2.190691236938749, 0.1330792275922639, 0.29420564589755877, 0.360582845551627, 0.13368806349379675, 0.24877916489328655, 0.0669299139242087, 0.1454183461942843, 0.15117989560323103, 0.15009113188300813, 0.22600648472351687, 0.22408120946160384, 0.297238181744303, 0.1683550282780613, 0.10649750967110906, 0.2887384992625032, 0.25507548132113045, 0.11676117964088917, 0.22150914104921476, 0.11780944839119911, 0.16415170739803994, 0.2836915286523955, 0.10347258698727403, 0.163589405428086, 0.1617465586002384, 0.18715738292251313, 0.15589967662734644], [0.01722144947520324, 0.04766773645366941, 0.0234884989913553, 0.06460080176059689, 0.1854984869382211, 0.16082837858370372, 0.03863713763920324, 0.011910298889103745, 0.053774052898266485, 0.040545788793159385, 0.10276194369154316, 0.22201680737946713, 0.07847171995256629, 0.030938285935137953, 0.13789986606155122, 0.042373008959527524, 0.017052906465583613, 0.02785920937146459, 0.0929837180301547, 0.05952461343258619, 0.01829922092812402, 0.08933984248765878, 0.04388057467128549, 0.03773747823600258, 0.048557872617883344, 0.26833052720342365, 0.03442685838256564, 0.087939658335277, 0.14482692150132997, 0.17636839114129543, 0.11324997805058956, 11.926516873495919, 63.86425617762974, 66.50765664236886, 74.0569577898298, 96.54306547982353, 76.42586272103446, 44.60633713858468, 24.001521962029592, 20.510370050157817, 14.571979216166906, 23.516329254422867, 45.132072584969656, 77.49353681291852, 65.76950781685966, 67.35648332323346, 64.59680475507463, 73.89192417689732, 79.18066365378243, 79.69462190355573, 86.55666978018624, 79.57061045510429, 77.35605280739921, 75.1242288861956, 80.12415954044887, 78.72717557634626, 74.15559441702706, 74.6670582635062, 70.20917047773088, 73.3760621207101, 75.6221923828125, 71.506927217756, 74.05371992928642, 72.82541738237653, 64.39201354980469, 41.48562669754028, 19.763634988239833, 22.782604694366455, 38.35335097994123, 29.064936569758824, 16.845718145370483, 31.422894614083425, 22.96712453024728, 14.566973907606942, 5.003251024654933, 9.781108566692897, 5.899971638407026, 0.5102835212435041, 0.10803285799920559, 0.060713535706911764, 0.06291677283921412, 0.018166085572115014, 0.11872137231486184, 1.0976026973554065, 0.19032504223287106, 0.18176156388861792, 0.1633292551019362, 0.1843830296503646, 0.23406274457062992, 0.16634956374764442, 0.08787240872957877, 0.468208161847932, 0.06233527511358261, 0.026349348515006046, 0.04923616675660014, 0.5727919042110443, 0.15252868751330034, 1.5979355296918323, 8.608695592199053, 1.2498484764780318, 0.09257053770124912, 0.1887827864182847, 0.5491395305309976, 0.48612354908670696, 1.2008476087025233, 4.349784237997873, 5.980173826217651, 6.248577092375074, 42.55223076684134, 29.237769535609655, 27.75634411403111, 27.4497617994036, 27.493703944342478, 37.952881131853374, 12.530796493802752, 16.847906827926636, 29.002635547092982, 35.77576037815639, 44.87798391069685, 58.925247328622, 58.913622992379324, 61.07124710083008, 58.69173921857561, 59.71874550410679, 65.30717468261719, 67.9470385142735, 70.3526577268328, 64.21759292057583, 70.98972415924072, 68.32935619354248, 73.39898422786167, 71.4229929787772, 77.93330914633614, 68.04393114362443, 63.554832049778526, 50.492677279881065, 67.18231977735246, 62.4194130216326, 60.58799294063023, 39.665150029318674, 14.204845956393651, 22.591914858136857, 53.91061776024954, 77.8796204158238, 52.64537511553083, 31.477302483149938, 26.035195418766566, 20.12426733970642, 2.103078143937247, 0.6507896674530846, 0.3379343780023711, 0.21192420965858869, 0.20276839738445623, 0.17808918308998856, 0.013711921321893377, 0.12334229078676019, 0.0662738655560783, 0.05713627873254674, 0.15947729322527135, 0.2533406844096524, 0.15417511202394962, 0.10238481392817837, 0.01775785515617047, 0.19264879396983556, 0.07163623959890433, 0.08143988996744156, 0.0454050359050078, 0.1593139019927808, 0.05628447640421135, 0.05474629858508706, 0.133157096271004, 0.022048861420314227, 0.07962547375687531, 0.024417152195902805, 0.1435139969523464, 0.08261351127709661, 0.09337421493338686, 0.02395940399063485, 0.057187514911804876, 0.00291122926449004, 0.08719804670129504, 0.058806580890502246, 0.05726112239062786, 0.054407923349312375, 0.09349071261073862, 0.07975697384348937, 0.027279165407110537, 0.054235738302980147, 0.09846759055341993, 0.12325983521129404, 0.08764474666012184, 0.055572357294814925, 0.04416898258828691, 0.049890773237815926, 0.09609940834343433, 0.054626204672136476, 0.012631051508443696, 0.05395778661061611, 0.07071544043719769, 0.07780442147382668, 0.06645517689841134, 0.14694164374044963, 0.18559755305094378, 0.020998633400137936, 0.059046707648251734, 0.12701909563371114, 0.10435509641787835, 27.102614164352417, 85.82316929953438, 84.88822664533342, 94.19458130427769, 95.50069672720772, 73.28704180036272, 63.27088001796177, 45.257108892713276, 45.48869582584926, 36.6558643749782, 40.558632782527376, 49.879168714795796, 73.63520213535854, 67.16956983293805, 76.98527608598981, 75.07195063999721, 81.70307513645717, 83.44933809552873, 81.20650822775704, 88.68666785103935, 81.9465400150844, 78.2226390838623, 76.00896385737828, 81.25015681130546, 78.93137618473598, 78.99644606454032, 80.63023158482143, 73.70765795026506, 74.33899211883545, 78.7470474243164, 72.24302632468087, 73.14015688214982, 71.82806600843156, 67.97731181553432, 53.84933117457798, 28.881035123552593, 32.21148041316441, 43.956902912684846, 27.83971381187439, 24.41983652114868, 33.76270048958914, 27.769566535949707, 18.686622517449514, 15.308771405901227, 10.15887257031032, 7.947313938822065, 0.3545830760683332, 0.04711771936022809, 0.17919119181377546, 0.1308620601360287, 0.04696180558364306, 0.09363443989838872, 0.7432327355657304, 0.3743372660662447, 0.44436737256390707, 0.0769926764603172, 0.08330727940691368, 0.06191390486700194, 0.08803557604551315, 0.20393998308905534, 1.2125976639134544, 0.1122743600447263, 0.07792744665805783, 0.3540075698069164, 0.5387229323387146, 0.7737977526017598, 3.6899542042187283, 5.973230838775635, 0.6413493454456329, 0.15518376789987087, 0.628951370716095, 0.585355170071125, 1.3185104663882936, 5.029549087796893, 8.572300927979605, 11.866110103470938, 28.16610196658543, 42.94567946025303, 29.00826358795166, 23.880366223199026, 23.4438282762255, 23.51897825513567, 46.337939398629324, 29.2139823777335, 27.37277228491647, 40.47398635319301, 37.97217280524117, 52.235021454947336, 63.1765582220895, 62.022858483450754, 60.97544533865792, 65.32856818607875, 63.54506983075823, 67.51885577610561, 70.1232351575579, 73.80710751669747, 69.26573712485177, 67.35374573298863, 71.94887433733258, 77.01751572745187, 75.48611886160714, 77.88211481911796, 74.29790047236851, 62.031356130327495, 55.023868560791016, 77.05703708103725, 67.99364703042167, 70.75994723183769, 65.581698008946, 30.481684684753418, 33.78868327822004, 59.4326742717198, 69.53489644186837, 70.97435474395752, 49.093285764966694, 36.010772773197715, 30.727890627724783, 6.146573194435664, 0.32626224575298174, 0.2624024653009006, 0.15446563357753412, 0.061539251756455214, 0.10265766642987728, 0.021778938493558338, 0.11240952422044106, 0.03082994424871036, 0.06814636436424085, 0.06318953713136059, 0.12799351263259137, 0.10511035339108535, 0.06256648592118706, 0.045444068631955555, 0.046299901458301713, 0.09403236676007509, 0.10619649796613626, 0.06341608640338693, 0.020943901069196205, 0.07953299621918372, 0.045402274267481904, 0.1453443451651505, 0.09690166065203291, 0.05326451381136264, 0.11393087437110287, 0.03865489150796618, 0.0613588292949966, 0.15453725973410265, 0.0997223307245544, 0.08215150356824909, 0.20903404402945722, 0.20907924803239958, 0.19816233882946627, 0.15244578410472187, 0.0704446913940566, 0.12718305683561734, 0.25693415158561295, 0.21598149623189652, 0.27351890451141764, 0.15014894306659698, 0.17935371452144214, 0.24142422527074814, 0.1141710893384048, 0.13893267778413637, 0.1440034242612975, 0.1558688711374998, 0.13874627064381326, 0.08242819657815353, 0.14210678317717143, 0.20615424641541072, 0.2855497103716646, 0.2793679306549685, 0.2582704041685377, 0.2272924714322601, 0.28652457520365715, 0.26025406058345524, 0.3164450925375734, 0.09991146557565246, 18.213493619646343, 90.1797662462507, 88.54869052342006, 107.75325434548515, 116.35168484279087, 94.17421613420758, 62.08044515337263, 41.72620807375227, 47.31224012374878, 45.4624524797712, 42.769771916525706, 68.41589600699288, 93.02733952658517, 81.83204065050397, 85.71668120792934, 84.96921484810966, 85.01692117963518, 85.67031587873186, 81.06062385014125, 87.97664533342633, 81.10989352634975, 79.96214144570487, 76.96265275137765, 80.70455646514893, 78.75107043130058, 79.63499246324811, 82.47060789380754, 71.45002147129604, 73.51877811976841, 79.35245786394391, 70.86637278965541, 73.38278797694615, 77.14605740138462, 70.92910112653459, 51.73303495134626, 29.900856971740723, 34.85278252192906, 50.872000285557334, 37.13143035343715, 22.54243152482169, 41.05797897066389, 32.65399381092617, 24.8871636731284, 16.093282086508616, 14.749097483498709, 21.576668398720876, 0.7004733043057578, 0.1559357882610389, 0.1608770838273423, 0.24260153781090463, 0.16426567413977214, 0.1629556944327695, 3.0477022443498885, 0.7189134433865547, 0.96515939278262, 0.1663678977638483, 0.28723418712615967, 0.26955075029815945, 0.17991095462015697, 0.3210806537951742, 2.2139223217964172, 0.1714878651712622, 0.11753594449588231, 0.5202388241887093, 1.2883993621383394, 1.851216584444046, 7.047012831483569, 14.256332107952662, 0.8641476216060775, 0.27808400669268196, 0.5253378791468484, 1.7777821591922214, 2.527099996805191, 7.646074788911002, 12.884980916976929, 10.25193761076246, 24.063696180071148, 46.27499566759382, 33.75599895204817, 36.432062898363384, 31.16056537628174, 35.93957805633545, 51.71611956187657, 24.054630517959595, 22.842831679752894, 41.84468180792672, 46.151376792362754, 56.881552832467214, 62.27990709032331, 68.12991510118756, 70.88679354531425, 73.97032764979771, 68.9665060043335, 67.21542794363839, 73.16670594896588, 80.12609113965715, 78.12530176980155, 73.43375996180943, 74.90174756731305, 78.50149808611188, 79.22766126905168, 82.56952939714704, 77.51372132982526, 66.3177067892892, 58.37392861502511, 75.62860557011196, 72.15342930385044, 71.35222557612828, 53.80900730405535, 24.082169703074864, 39.111329964229036, 73.90140846797398, 88.35099342891148, 74.152113369533, 61.141687938145225, 50.98687137876238, 32.35939366476876, 4.372266437326159, 0.48548659469400135, 0.40526071244052475, 0.30521167388984133, 0.17800173349678516, 0.3218444942363671, 0.18508510983416013, 0.2835637197962829, 0.2558503140296255, 0.09290676537368979, 0.1694644330335515, 0.2609449992222445, 0.34376291238835877, 0.12129367142915726, 0.24096909112163953, 0.40789451396891047, 0.1915124242327043, 0.25120025926402634, 0.1912254582026175, 0.2145874731774841, 0.17968740447291306, 0.12784864540610993, 0.17511193427656377, 0.23349106524671825, 0.1018396992502468, 0.25460585366402355, 0.17396230596516812, 0.13830039171235903], [0.03816338788185801, 0.08289523223148924, 0.06773734345499959, 0.11990475095808506, 0.08969793255840029, 0.09005111682095698, 0.1653986240604094, 0.12300710805824824, 0.07913890308035271, 0.06649728678166866, 0.08670775086752006, 0.14098416055951798, 0.00728651021407651, 0.027628979046962092, 0.04404312452035291, 0.05033296772411891, 0.06538294229124274, 0.120801000722817, 0.035969222762754986, 0.0542776344477066, 0.05906736903956958, 0.1282071154564619, 0.06786093182329621, 0.04975978205246585, 0.11830106058291026, 0.052555085093315156, 0.11353414173104934, 0.1003047376871109, 0.2540394940546581, 0.18917088130755083, 0.169056823477149, 0.3198134217943464, 19.012312378202164, 82.04350907461983, 73.47426101139614, 69.9729734148298, 88.29178782871791, 76.55247974395752, 45.14008385794503, 26.102302857807704, 12.188995497567312, 17.90123462677002, 33.08171796798706, 54.59900706154959, 73.01883438655308, 63.774596623011995, 66.5828778403146, 70.83661365509033, 77.65521444593156, 78.36278424944196, 83.24904932294572, 84.02184186662946, 77.68169403076172, 79.94807134355817, 80.93256855010986, 75.62023299080985, 70.84280450003487, 74.60223157065255, 80.95524747031075, 75.16827351706368, 79.46173218318394, 74.46580369131905, 70.8204243523734, 68.72706413269043, 54.134294169289724, 30.092311109815324, 22.4603750365121, 12.979192410196577, 29.381086553846085, 37.69512728282383, 29.0484676020486, 29.85110786982945, 18.01699161529541, 13.609976802553449, 2.0259581335953305, 8.453836747578212, 2.568942482982363, 0.12462497981531279, 0.17328335025480815, 0.032677279585706334, 0.24355672512735638, 0.2777273415454796, 0.31839731921042713, 0.1865380975816931, 0.19086351405297006, 0.1895169070256608, 0.18839451510991367, 0.08101761726928608, 0.3534387674714838, 0.053058398621422906, 0.11388334977839674, 0.04213816798957331, 0.297660800495318, 0.3184016618345465, 0.4777634548289435, 0.4514930216329438, 0.23394546657800674, 1.6564824623720986, 9.243282386234828, 9.015285066195897, 1.0315935079540526, 0.6741182985050338, 0.11548873649111815, 0.6810486923371042, 1.682691284588405, 2.207370387656348, 6.170418977737427, 13.039820654051644, 22.4398170539311, 15.358312061854772, 23.332455601011002, 34.321634428841726, 50.81354856491089, 23.753274985722133, 6.735089523451669, 19.380478313991002, 16.25123722212655, 40.749447686331614, 34.80521862847464, 42.162631375449045, 51.060338156563894, 61.68585000719343, 59.14843041556222, 59.113091877528596, 59.504935537065776, 67.13810838971818, 63.910538128444124, 69.18229620797294, 65.71331078665597, 62.4318641935076, 69.20321723393032, 74.74740723201207, 68.52373204912458, 59.65601716722761, 61.14143780299595, 65.88734926496232, 64.60149478912354, 57.818374974387034, 36.232976164136616, 17.964440652302333, 38.23514822551182, 57.02950429916382, 77.25603348868233, 67.35081359318325, 40.53570372717721, 27.66817147391183, 21.61887523106166, 4.149156306471143, 0.18741557906780923, 0.22734376867966993, 0.08365897767777954, 0.2970754419054304, 0.1801376667405878, 0.10144564682351691, 0.13079344667494297, 0.03374408930540085, 0.0869382085012538, 0.20752420861806187, 0.35837855669004576, 0.13028074561485223, 0.13545389659702778, 0.01707233801218016, 0.07281084478433643, 0.04883097617753914, 0.061525938899389336, 0.15125152175979956, 0.033991734231156964, 0.07005530728825501, 0.04832274666322129, 0.11214497698737041, 0.1324156474854265, 0.06379635099853788, 0.15924243868461677, 0.1021096408367157, 0.2544190122612885, 0.05212523315900138, 0.026756501756608486, 0.024262050965002606, 0.04616151424124837, 0.0323381749247866, 0.07373405274535928, 0.02096002475757684, 0.18551013059914112, 0.0517211893041219, 0.09355359923626695, 0.03999614489397832, 0.023548040439241698, 0.22644948666649206, 0.09641582957868065, 0.024559729366696308, 0.08650826157203742, 0.10034292563796043, 0.08620436609323535, 0.009902008260334176, 0.015518993239051529, 0.16642816524420465, 0.058540629089943, 0.04153976117127708, 0.05891653749027422, 0.11479764857462474, 0.15326963418296405, 0.042541027800845246, 0.14279815607837268, 0.22034248150885105, 0.09786198447857584, 0.13121411124510424, 0.166843265827213, 1.0947175664561135, 41.73319101333618, 88.55436025347028, 91.30698640005929, 98.81459835597447, 89.2398486818586, 78.87747900826591, 61.032149587358745, 40.672701358795166, 40.92589371544974, 42.74491821016584, 52.53863688877651, 63.07899161747524, 66.09979738507951, 65.02684266226632, 79.98953124455043, 81.87056146349225, 84.07659367152623, 82.95459856305803, 87.10652937207902, 85.40115656171525, 82.36621815817696, 81.46261187962124, 86.96644674028668, 79.69246101379395, 77.2150877543858, 79.83924865722656, 83.80002062661308, 77.34824998038155, 76.7659284046718, 71.16279683794293, 73.18843991415841, 69.04848085130963, 61.38317952837263, 35.716252531324116, 27.897145884377615, 25.549868958336965, 44.06047623498099, 31.94928319113595, 22.126474142074585, 25.381592273712158, 25.45015709740775, 25.7151666028159, 11.720316052436829, 9.143133657319204, 1.7859327218362262, 0.2148124753896679, 0.22581661705459866, 0.14036391169897147, 0.20614850600915297, 0.12212763167917728, 0.21647864526935987, 0.3265729062259197, 0.27917245828679627, 0.2895876451262406, 0.11805425025522709, 0.0370963237115315, 0.17815557095621312, 0.11007387776459966, 0.18529690775488103, 0.11497136711009912, 0.24880845046469144, 0.381225047899144, 1.3032610160963876, 0.8617073925478118, 0.9832611871617181, 3.309052437543869, 14.893981320517403, 8.061861072267805, 0.3647104012114661, 0.37036468780466486, 0.3281288141650813, 1.4251319851194109, 6.487499586173466, 6.974321212087359, 14.327264530318123, 27.99718083654131, 26.1777047089168, 19.227680478777202, 25.52461920465742, 21.08721818242754, 34.129926681518555, 36.9736020224435, 14.362621307373047, 19.076789924076625, 25.975897754941666, 46.6966609954834, 39.05512251172747, 47.20233004433768, 59.929039682660786, 69.44953087397984, 68.04846136910575, 61.266679082598, 62.30947167532784, 68.43482289995465, 73.58721787588937, 69.0611821583339, 61.97092069898333, 69.46120384761265, 75.3038467679705, 77.63834421975272, 75.34340981074742, 63.89380686623709, 61.541327476501465, 77.54515498025077, 71.73656518118722, 75.468081338065, 59.663952010018484, 30.960019520350865, 38.172861099243164, 59.00851454053606, 72.82425703321184, 73.29261425563267, 55.87683636801583, 37.60050324031285, 30.460857459477015, 10.112065161977496, 0.23634346361671174, 0.11240956493254219, 0.32191223917262896, 0.07251146156340837, 0.11408164485224656, 0.16563009949667112, 0.028948210578944002, 0.07677696339253869, 0.1062027947711093, 0.08063892009002821, 0.17407610985849584, 0.1541072992341859, 0.13616559840738773, 0.0648708858394197, 0.05356716078573039, 0.07685146653758627, 0.09241609634565455, 0.17953108357531683, 0.0483977960289589, 0.03614510582493884, 0.0655071616971067, 0.06785850945327963, 0.2354683434324605, 0.06090438046625682, 0.09129004034080676, 0.19858851310397896, 0.09363658406904765, 0.09101655680154051, 0.14248795700924738, 0.1135111665353179, 0.16048562340438366, 0.20458790260766233, 0.22328687565667288, 0.16060812611665043, 0.29052766039967537, 0.12943398819438048, 0.24171026849320956, 0.14915966615080833, 0.1441291296588523, 0.38174051738211084, 0.1386206466704607, 0.19470513505595072, 0.20718956871756486, 0.174454162429486, 0.13793310070676462, 0.18178881385496684, 0.13776772815201963, 0.13342187420598098, 0.1355086136609316, 0.17814100959471293, 0.12477896655244486, 0.18305141824696744, 0.13390727101692132, 0.1385096383414098, 0.17943147463457926, 0.26284793711134363, 0.5801970011421612, 0.23867135441729, 0.25792478557143894, 0.3107882546527045, 30.39849042892456, 101.70816176278251, 101.17463043757847, 106.27039759499687, 112.46023505074638, 97.53261402675084, 61.234328269958496, 36.108565194266184, 36.05988958903721, 45.52175188064575, 52.91206087384905, 74.77583926064628, 87.25001662118095, 80.3989121573312, 88.44139644077846, 86.96318108694894, 83.76206261771065, 85.32542814527238, 89.53327805655343, 84.78726931980678, 78.75391919272286, 84.67908586774553, 89.00947420937675, 77.54835809980119, 76.54112638745988, 82.06741782597133, 83.72348621913365, 77.41107559204102, 80.78022929600307, 72.58808776310512, 74.66055474962506, 73.56774207523891, 67.33222021375383, 39.416932582855225, 28.96087166241237, 22.806504760469707, 46.16609655107771, 50.00225952693394, 36.91219384329659, 31.50022111620222, 29.58763565335955, 27.263091496058873, 11.205522281782967, 13.312054548944745, 6.037868193217686, 0.41165739776832716, 0.29747689036386354, 0.24429532406585558, 0.3890776793871607, 0.5775558171527726, 0.37270813062787056, 0.2949336054069655, 1.2971158772706985, 1.9107209571770258, 0.7131438872643879, 0.3485800767583506, 1.6561904209000724, 0.11544712872377463, 0.3524183322276388, 0.18103946692177228, 0.49116712702172144, 1.1241739115544727, 1.8407914638519287, 2.895416621650968, 1.672264644077846, 5.915739272321973, 21.74979145186288, 23.804858412061417, 2.9142920545169284, 0.6288824315582002, 0.5116327202745846, 2.5911274296896796, 10.714097908564977, 11.038997411727905, 14.206808822495596, 18.222131967544556, 27.53914863722665, 25.137130328587123, 38.34427315848214, 44.48889521190098, 62.480480739048545, 38.12889984675816, 9.872640660830907, 31.481245585850306, 22.73240222249712, 53.50149393081665, 46.33433675765991, 55.72668579646519, 64.00138582502092, 77.72209085736955, 77.88129493168422, 69.83341884613037, 67.1536306653704, 73.4578354699271, 79.59201090676444, 78.00818293435233, 68.16149466378349, 74.81518690926688, 82.31794207436698, 80.31955678122384, 80.453017779759, 72.69750799451555, 62.67967864445278, 72.38983481270927, 77.77760001591274, 72.44151551382882, 46.563432761601035, 28.684168338775635, 49.22849770954677, 76.77098669324602, 88.52286406925747, 78.91731303078788, 65.50581673213414, 48.09272084917341, 33.81535741261074, 7.1690245015280585, 0.22561957048518316, 0.255733280309609, 0.4060996802789824, 0.18844476741339478, 0.16832473847482884, 0.25582539822374073, 0.1996569207736424, 0.21907664729016169, 0.28629159341965404, 0.21827052054660662, 0.3561537489295006, 0.2781388323221888, 0.2533698614154543, 0.10858380807829754, 0.09641618920224053, 0.12468527443706989, 0.20158843855772698, 0.2908066197165421, 0.1736847987132413, 0.1344602227743183, 0.07301607448607683, 0.1788595781794616, 0.25165159361703054, 0.1612661693777357, 0.28740197526557104, 0.335987851023674, 0.22280655428767204, 0.12798987568489142], [0.091065913438797, 0.0615922249853611, 0.07086465707314865, 0.0786417947549905, 0.06764348849122014, 0.06540031957307033, 0.08322485775819846, 0.057178626103060584, 0.056418124054159434, 0.04619872510167105, 0.08417840301990509, 0.04078542700569544, 0.04820608274478998, 0.02943323419562408, 0.08094360266945191, 0.05798815230705908, 0.06212775196347918, 0.10648554709873029, 0.07589812483638525, 0.028303785515683036, 0.02992238330521754, 0.034874447222266874, 0.016478677546339374, 0.0465511222636061, 0.15872444505138056, 0.11217190804226057, 0.07437718859208481, 0.06409597849207264, 0.11235511249729566, 0.05820113766406264, 0.35896082116024836, 0.4552769943007401, 0.8908748445766312, 30.41326924732753, 74.78057098388672, 69.67147023337228, 62.23931571415493, 81.03989737374442, 79.67229039328438, 48.787922859191895, 25.16627107347761, 12.808197242873055, 23.226129055023193, 36.817878995622905, 67.50896848951066, 84.69123826708112, 76.58444145747593, 66.40675490243095, 74.13966914585659, 86.31271157945905, 85.38485608782086, 86.52648680550712, 81.6447866984776, 79.9269905090332, 76.44840962546212, 77.0137220110212, 67.84779739379883, 69.23144776480538, 71.07446438925606, 73.29871477399553, 71.55160413469586, 69.12003340039934, 65.20358398982457, 57.137670380728586, 37.58958414622715, 32.38869421822684, 21.704494408198766, 11.415441257613045, 22.243150029863628, 41.181448459625244, 40.350099972316194, 32.55399881090437, 26.752763680049352, 10.256901230130877, 5.399911522865295, 2.979651153087616, 0.5514701083302498, 0.6570610137922424, 0.7126978997673307, 0.15732884779572487, 0.3923851576234613, 0.08081584809614079, 0.3134610583739621, 0.5255718380212784, 0.10348347747432333, 0.2013013639620372, 0.3243231826594898, 0.10741990339010954, 0.11052858443664652, 0.3414348858807768, 0.38229509762355257, 0.04602721519768238, 0.21853928826749325, 0.6149417396102632, 0.24414151374782833, 0.08166510931083135, 0.7384008605565343, 1.8614376017025538, 4.671997393880572, 8.434010931423732, 3.5640024713107517, 1.0516124623162406, 0.21003181620367936, 0.7675318345427513, 0.9563920689480645, 4.217448847634452, 17.5443925176348, 9.95757804598127, 27.00904972212655, 37.759314741407124, 17.886388063430786, 32.545935426439556, 35.11594901766096, 14.984125511986868, 16.429338659558976, 27.889997925077164, 26.371469123022898, 36.09132323946272, 40.313159874507356, 38.32844516209194, 35.63971812384469, 40.064615862710134, 49.0345595904759, 53.07279702595302, 60.060596874782014, 59.21220098223005, 59.915421213422505, 72.04114641462053, 67.0956757409232, 64.3435776574271, 66.35458087921143, 61.03255953107561, 52.79048824310303, 62.33770220620291, 72.89932537078857, 66.49645614624023, 59.10326712472098, 36.559447697230745, 25.91046483176095, 53.69715520313808, 70.15792056492397, 74.6043507712228, 61.65501390184675, 40.208217757088796, 25.999005726405553, 10.900572793824331, 4.0911219120025635, 0.15537735394069127, 0.3079353134546961, 0.3920898863247463, 0.6952720348324094, 0.5079792163201741, 0.05906677192875317, 0.019868258519896438, 0.08624741914016859, 0.05805858424199479, 0.1677474815930639, 0.3420260527304241, 0.4143059642187187, 0.12541290824966772, 0.042785442899912596, 0.04769886424764991, 0.034431923646479845, 0.028976237467889274, 0.11956757333661829, 0.16335034397031578, 0.0650041229756815, 0.06332261141921793, 0.11624786789928164, 0.03180046984925866, 0.06237342913768121, 0.06895985999809844, 0.06148209196648427, 0.14921822372291768, 0.05585947599528091, 0.06539920677563973, 0.0210618813455637, 0.021765571353690963, 0.05210239367027368, 0.12089961900242738, 0.02721145609393716, 0.061016101257077286, 0.23241786711982318, 0.09428678346531731, 0.046588241521801264, 0.009733249815846128, 0.1070649888632553, 0.05592600635385939, 0.1604263194437538, 0.10205214177923543, 0.08431503961661033, 0.05419830013332622, 0.21526497682290419, 0.18305030544953688, 0.05153442593291402, 0.1016781943451081, 0.04836179296086941, 0.08664558348911149, 0.01583886143219258, 0.08403778342264039, 0.16697579728705542, 0.04989178425499371, 0.11908003235501902, 0.14881467180592672, 0.32199540042451447, 0.2700397026325975, 0.01661612668872944, 0.21194109160985264, 3.6701809338160922, 56.445522103990825, 86.46235493251255, 87.98057106563023, 96.77628176552909, 92.47719505855015, 81.0791824885777, 72.5343712397984, 40.782100745609824, 37.40782274518694, 43.918889318193706, 53.30020114353725, 73.23458984919957, 78.76282678331647, 81.01097202301025, 81.08136422293526, 84.82911137172154, 91.13194043295724, 85.82081386021206, 86.14444705418178, 82.87844630650112, 81.40547684260777, 76.67276695796421, 78.93288394383022, 74.26072066170829, 72.46240874699184, 75.86562252044678, 79.59219850812639, 75.12682751246861, 70.36581761496407, 70.97600146702358, 56.84903873716082, 43.117956570216585, 36.65733739307949, 25.106113570077078, 13.921514051301138, 27.59039855003357, 41.53950650351388, 27.08215171950204, 21.09966935430254, 21.690705708095006, 11.060599361147199, 11.205683827400208, 8.43721752507346, 1.6461147729839598, 0.7772602896605219, 0.4891626802938325, 0.3218132544841085, 0.22814203798770905, 0.08674137906304427, 0.40019984543323517, 0.601828046143055, 0.07947874734444277, 0.05947877160672631, 0.6707806661725044, 0.3071520397705691, 0.06387267940278564, 0.2609699150281293, 0.11915355840963976, 0.05142102237524731, 0.4928088017872402, 0.6305388712457248, 1.3433191180229187, 0.6353556013533047, 0.681190587580204, 4.523628166743687, 14.556225044386727, 18.460316215242656, 3.606511333159038, 1.171939628464835, 1.5978961203779494, 1.4702774712017603, 1.178565495780536, 6.159542875630515, 23.247414861406597, 16.635175568716868, 39.64346817561558, 36.82014758246285, 18.195093052727835, 22.6816143648965, 35.49930545261928, 24.798056500298635, 15.700922523226057, 27.875483138220652, 26.492968797683716, 51.98726953778948, 53.60158967971802, 54.92548206874302, 53.022488594055176, 54.857570375714985, 54.078409808022634, 55.147522177015034, 65.748336655753, 70.75130367279053, 68.78854874202183, 66.57014874049595, 74.68354633876255, 76.96281950814384, 74.40376322610038, 65.5508757999965, 63.69407394954136, 62.979034832545686, 77.18221582685197, 80.20496014186314, 80.66226278032575, 55.401124477386475, 31.21327441079276, 46.40975250516619, 67.24315820421491, 74.20171655927385, 74.49188028063092, 60.18901348114014, 37.79126950672695, 26.533228397369385, 9.126431056431361, 0.5229778800691877, 0.1667797142373664, 0.570385601903711, 0.28869664722255295, 0.04909032243969185, 0.044757520114736896, 0.07389787145491157, 0.037246836349368095, 0.07861841243824788, 0.030397781902658086, 0.24212976598313876, 0.3168874702283314, 0.13726707787386008, 0.007014134383228208, 0.09667806979268789, 0.1159540486655065, 0.06935249428663935, 0.025964834594300816, 0.05958790039377553, 0.15649298764765263, 0.04651980108714529, 0.03796189690807036, 0.08311469081257071, 0.18887841914381298, 0.2542732357978821, 0.2707679606974125, 0.08229254385722534, 0.05542487092316151, 0.16091246264321463, 0.2193782561059509, 0.11069956169064556, 0.18427423334547452, 0.17089321065161908, 0.07807097717055253, 0.12348050837005888, 0.3308914287814072, 0.1749346059347902, 0.17801192509276526, 0.06886167598090001, 0.13748110138944217, 0.11983055993914604, 0.23150035206760677, 0.21967492518680437, 0.18340424288596424, 0.13720096142164298, 0.16550368842269692, 0.18104193678924016, 0.0954192719821419, 0.14641039153294905, 0.09430922261838402, 0.11920492351055145, 0.0990886197292379, 0.2168380788394383, 0.23395173624157906, 0.186301695981196, 0.22682204310383114, 0.1686270258256367, 0.4651658279555184, 0.3744258555982794, 0.4320255262511117, 0.3201163469680718, 1.3739915064402988, 42.160640716552734, 93.02906962803432, 101.88672351837158, 104.82197611672538, 106.97351360321045, 101.42834390912736, 74.89000511169434, 43.494020870753694, 29.914701257433208, 43.27008737836565, 51.702139786311555, 79.78982612064907, 100.79550198146275, 98.56963961465019, 88.01089995247978, 88.34047385624477, 91.10293170383999, 86.60755838666643, 86.54889474596295, 79.54319981166294, 79.44814150674003, 78.4267771584647, 82.09666974203927, 76.2429791859218, 73.25003569466728, 77.08564976283482, 80.41337135859898, 78.87107971736363, 72.01701532091413, 71.02380507332938, 63.72143595559256, 51.06873852866036, 43.48517581394741, 34.74848311288016, 17.79539966583252, 29.972968850816997, 51.18193163190569, 55.3001879964556, 42.03727545057024, 42.121786390032085, 12.955975004604884, 13.48322776385716, 13.61345785004752, 3.138331724064691, 1.3518026513712746, 1.193034793649401, 0.5190794521144458, 0.6034115297453744, 0.22433959559670516, 0.5037695850644792, 0.9206818022898265, 0.18597761408558913, 0.48037570608513697, 1.3316188944237572, 0.5698124298027584, 0.2913701023374285, 0.34503443273050444, 0.5891374871134758, 0.28266816213727, 1.5144432612827845, 1.9937276116439273, 2.068905383348465, 0.86754431362663, 1.2309398225375583, 7.0745333433151245, 23.058535030909947, 33.83339841025216, 12.38426853929247, 4.766350890908923, 4.3602282490049085, 1.5327797744955336, 1.0907567675624574, 11.21635799748557, 22.828382900782994, 18.51712121282305, 31.75961126599993, 47.765273094177246, 26.02435622896467, 46.309959002903526, 41.43738535472325, 20.828759091241018, 23.56156029020037, 36.74551350729806, 30.15699883869716, 46.27057661328997, 51.960279260362896, 56.99749047415597, 58.6772244317191, 63.80119432721819, 66.66369233812604, 63.91837569645473, 68.11403151920864, 75.88633510044643, 81.00498267582485, 81.6262628010341, 78.74983365195138, 83.51730537414551, 83.70225252423967, 74.72930022648403, 68.71402931213379, 69.93282672337124, 75.75228350503104, 77.50288908822196, 71.39637442997524, 50.445234979902, 36.8879793712071, 69.50414371490479, 85.9524335861206, 94.16196646009172, 78.61238438742501, 64.50010667528424, 41.06351668494088, 24.319176231111797, 5.477991036006382, 0.20076784544757434, 0.38061488206897465, 0.5367219054273197, 0.7861764026539666, 0.30962236864226206, 0.19291704600410803, 0.17658328318170138, 0.10179575732243912, 0.1267109185989414, 0.18043733494622366, 0.3617082637335573, 0.39945155701466967, 0.20378960615822247, 0.09880383179656096, 0.19179749036473887, 0.25745597215635435, 0.13373796295906815, 0.161539510424648, 0.22950801040445054, 0.2397544320140566, 0.15296244780932153, 0.2551393721784864, 0.16670869876231464, 0.23397488785641535, 0.2255996758384364, 0.7674757061260087, 0.2440081409045628, 0.2370792669909341, 0.16321015863546304], [0.08480270951986313, 0.03884111883650933, 0.08174618067485945, 0.03758008525307689, 0.05433090283934559, 0.018362475658899972, 0.0394811232441238, 0.06004441875432219, 0.08732918716434922, 0.0778936216873782, 0.06226992540593658, 0.019232352463794605, 0.06334944747920547, 0.17557006755045482, 0.013288137186983866, 0.03192202261249934, 0.07966042509568588, 0.10560225056750433, 0.04982593921678407, 0.016036226913066845, 0.017721843606393253, 0.036392330058983395, 0.021559561336679117, 0.12491655988352639, 0.10835095521594797, 0.2927345005529267, 0.04456578308184232, 0.048436289320566824, 0.11109573793198381, 0.14804066691015447, 0.13695170836789267, 0.09931551505412374, 0.3928222698824746, 1.5794542985303062, 29.732220717838832, 66.14681584494454, 66.44647080557687, 50.15705149514334, 59.940323557172505, 72.1061190196446, 52.63968106678554, 32.3599008832659, 18.350600685392106, 26.191917249134608, 45.50183139528547, 70.37669849395752, 87.52772222246442, 81.62417139325822, 71.76449693952287, 72.41651589529855, 82.80570561545235, 83.19108745029995, 90.55936023167202, 86.25776522500175, 77.26275239671979, 71.42886420658657, 72.06534004211426, 69.98476450783866, 68.35126386369977, 63.325541496276855, 63.87756197793143, 59.86198261805943, 45.80604090009417, 44.05271857125418, 43.95830992289952, 36.72192784718105, 30.539069856916154, 25.091986145292008, 30.436094079698833, 24.24030375480652, 31.428286416190012, 24.04218976838248, 45.950306347438264, 30.49418101991926, 2.7690595047814504, 3.2860304500375475, 0.2788275996489184, 0.7159847233976636, 0.06938435150576489, 0.004234398207959852, 0.6165292944226946, 0.6416823161499841, 0.15272030580256665, 0.28416674743805614, 0.20820860617927142, 0.13291002810001373, 0.01834368872057114, 0.1671672255865165, 0.4224366864987782, 0.06774367418672357, 0.20933544928474085, 0.09295080908175025, 0.17091081185000284, 0.38314565484012875, 0.211816119030118, 0.06327895447611809, 0.13852324975388391, 1.5475202692406518, 5.739968521254403, 9.165320123944964, 2.802327479634966, 2.0973098363195146, 0.39238844173295157, 0.1489434984645673, 0.2606545319514615, 7.525897009032113, 15.322756392615181, 17.269311598369054, 9.46460509300232, 20.672829355512345, 24.551603896277292, 23.05883206639971, 18.65372106007167, 20.024723972593033, 26.324445452008927, 14.517667753355843, 22.981302329472133, 22.97338833127703, 28.93999579974583, 29.78404038293021, 35.66416883468628, 40.265818323407856, 47.198612758091514, 54.89743219103132, 63.16696275983538, 58.749041012355256, 65.98755618504116, 69.12887150900704, 62.919231687273296, 58.38185650961739, 56.80192647661482, 52.30009480885097, 64.94909926823208, 71.53358745574951, 61.9563364301409, 48.63995054789952, 33.834878376552034, 42.31252833775112, 60.58304582323347, 55.36106811250959, 61.67291940961565, 50.527466910226, 35.08324384689331, 27.27730229922703, 11.701475143432617, 3.583199692623956, 0.5512028740985053, 0.4193392012800489, 0.08876737606312547, 0.48985022625752855, 0.602425754070282, 0.14597220718860626, 0.021797243672023927, 0.10345035139471292, 0.20191321255905287, 0.06742243535284485, 0.1972627913845437, 0.4366534879165036, 0.025597935442679694, 0.01619772842553045, 0.08448884636163712, 0.038948944836322746, 0.028974564879068306, 0.05654426032145109, 0.033428539987653494, 0.07280471082776785, 0.06993169177855764, 0.07578517589718103, 0.03929200196372611, 0.2507900169917515, 0.05400707878704582, 0.04974405361073358, 0.071089496436928, 0.11903334914573602, 0.0437275514538799, 0.04351083076159869, 0.01688025492642607, 0.04000656379918967, 0.07639744518590824, 0.022984788520261645, 0.0204364009800234, 0.04312579267259155, 0.11437314349625792, 0.10133406852505036, 0.053285541611590555, 0.08848610972719533, 0.04609985237142869, 0.09312270235802446, 0.14522427160825047, 0.03784754679405263, 0.041268330200442245, 0.06683863060814993, 0.030042059919131652, 0.14609517130468572, 0.21623311058751174, 0.16341221279331616, 0.04278788562597973, 0.013574916619940527, 0.12405885090785367, 0.04508922535127827, 0.042706553025969436, 0.09719615163547651, 0.060679866799286435, 0.19447982071765832, 0.15121987488652977, 0.40474543294736315, 0.1504840850830078, 0.2371571356696742, 0.4754551329783031, 4.3112026282719205, 50.63880484444754, 82.41597420828683, 87.22558675493512, 88.57874843052456, 88.7776962007795, 84.42450387137276, 75.42732320513043, 50.14736918040684, 39.538922105516704, 46.12105137961251, 57.24691343307495, 79.74032715388707, 96.22959055219377, 89.11273833683559, 86.64934485299247, 79.54335267203194, 84.33308642251151, 86.90007059914726, 90.44326278141567, 86.14214025224958, 82.36616257258824, 79.22127587454659, 75.80313042231968, 75.01662213461739, 72.15235928126744, 70.636873790196, 74.80776623317173, 64.66113117762974, 52.920058250427246, 53.22293717520577, 54.01333992821829, 48.18119921003069, 34.4980457169669, 26.073179483413696, 36.12980931145804, 38.29733460290091, 34.800959382738384, 30.815215587615967, 44.101995195661274, 26.409123148236954, 13.609144755772181, 8.185401780264717, 0.34182037519557135, 1.209801665374211, 0.04334000278530376, 0.07829622365534306, 0.6484784686139652, 0.34731710595744, 0.4299201135124479, 0.10407676813857895, 0.14154969235616072, 0.1075515595397779, 0.10717366303184203, 0.11055082681455783, 0.06741531752049923, 0.1344737663332905, 0.3700712349797998, 0.5366074229989732, 0.9012455738016537, 0.6001628126416887, 0.3828272047851767, 0.19046726317277976, 0.27196201948182924, 1.8855176695755549, 15.707851614270892, 18.341363055365427, 7.75478196144104, 1.9868669169289725, 0.5412974027650697, 0.08850048788424049, 0.6660162104027612, 8.49596107006073, 21.78512477874756, 28.257781709943497, 17.723346846444265, 25.408285515648977, 26.398853710719518, 26.648175920758927, 30.10991437094552, 26.08929409299578, 33.50243139266968, 20.81807276180812, 27.39732548168727, 31.452539103371755, 49.228456020355225, 47.10700075966971, 54.57166242599487, 57.517736843654085, 59.18934140886579, 62.24515220097133, 72.5632687977382, 74.47751140594482, 68.9724953515189, 67.54450852530343, 74.99787589481899, 66.10499463762555, 65.72683198111397, 68.2654675074986, 75.3743223462786, 72.51454108101981, 73.89900439126151, 73.81818989345005, 50.96970585414341, 40.522265911102295, 56.88326208932059, 57.70475108282906, 66.9333519254412, 73.73977252415249, 51.70895249502999, 35.550371238163535, 21.268387249537877, 6.527361835752215, 0.5650643674390656, 0.427594746862139, 0.34754764501537594, 0.3334515414067677, 0.17045050726405211, 0.0980693922777261, 0.03928338796166437, 0.049540506675839424, 0.1769383605569601, 0.20042718015611172, 0.14342254400253296, 0.23895880899259023, 0.012482452339359691, 0.06006302418453353, 0.04609815603388207, 0.05939531858478274, 0.14647283032536507, 0.09062973077275924, 0.08872633147984743, 0.020142805662804415, 0.09658958882625614, 0.06768534053117037, 0.006245662516448647, 0.26022328223500935, 0.30114157657538143, 0.386261731918369, 0.141005045867392, 0.028248452681249807, 0.08582919729607445, 0.10281770569937569, 0.09842037130147219, 0.16971853082733496, 0.15016155024724348, 0.17465875430830888, 0.06473921611905098, 0.09256923491401331, 0.15605564468673297, 0.2133810921971287, 0.13530436104961804, 0.193801543542317, 0.1674341612628528, 0.16894449879016193, 0.17726479018373148, 0.40305740066937035, 0.13991393441600458, 0.13685934618115425, 0.12685502586620195, 0.15249174806688512, 0.27116582649094717, 0.3021886375333582, 0.13863679580390453, 0.13086429930159024, 0.23971274282251084, 0.2047054927263941, 0.1824883020349911, 0.25715969662581173, 0.15035957390708582, 0.2017481792718172, 0.20024689340165683, 0.374626946236406, 0.3551843123776572, 0.32479821145534515, 0.5328387852225984, 1.2671845576592853, 39.92245919363839, 84.96890912737165, 103.75225230625698, 100.34832981654576, 96.31617900303432, 96.93308871132987, 76.15848214285714, 56.263507093702046, 39.68970496313912, 41.78526081357683, 55.90377105985369, 78.82358183179582, 106.53538799285889, 100.81295585632324, 93.49124295370919, 80.52165903363908, 88.36687701089042, 91.80048220498222, 97.00856004442487, 89.20307881491524, 89.45387404305595, 86.02616786956787, 84.31566034044538, 85.10164056505475, 77.93900666918073, 73.73331764766148, 79.65999208177838, 70.12886319841657, 58.070848192487446, 55.70302718026297, 54.780622550419395, 45.56599800927298, 35.924806186131065, 32.74681479590279, 37.904045718056814, 35.61111239024571, 45.85599497386387, 31.30556733267648, 56.679443631853374, 42.61660235268729, 15.649370363780431, 9.637838448796954, 0.7389145929898534, 2.847542013440813, 0.14253952567066464, 0.45177298518163816, 1.015625461935997, 0.8752881895218576, 0.45936630772692816, 0.5475455703479903, 0.48222930090767996, 0.21599388628133706, 0.17365330111767563, 0.7899089423673493, 0.5719829819032124, 0.14994137920439243, 0.5060606449842453, 0.7507526949048042, 1.6789737812110355, 0.8073179796338081, 0.3641329136277948, 0.31382342321532114, 0.16870839574507304, 2.878859064408711, 27.987123319080897, 27.170866319111415, 13.817253725869314, 6.622698937143598, 0.9009079347763742, 0.22776607530457632, 2.049452164343425, 12.442268627030508, 24.376193148749216, 33.874361515045166, 17.599795716149465, 32.77481951032366, 43.78132193429129, 37.26416526521955, 27.295369352613175, 28.02067617007664, 38.81256089891706, 17.632822241101945, 27.353775909968785, 27.35899227006095, 43.1230218069894, 51.56243930544172, 56.20987742287772, 57.35030262810843, 65.02157592773438, 66.37812832423619, 79.77524880000523, 80.08675043923515, 77.19010203225272, 70.99125971112932, 78.21253640311105, 71.16689627511161, 73.99009527478898, 71.27140413011823, 81.18814413888114, 74.67177609034947, 72.42077514103481, 62.40159089224679, 52.13730893816267, 56.811674799237935, 81.73207691737584, 80.20812852042062, 81.75968211037772, 76.04271820613316, 57.84862048285348, 41.26023060934884, 21.890086003712245, 4.712858012744358, 0.7315907574125698, 0.5017419052975518, 0.3775477952190808, 0.7786694711872509, 0.5531285564814294, 0.18130292849881308, 0.0817758801526257, 0.20969941546874388, 0.20918850574110234, 0.2580917594688279, 0.32156029662915636, 0.3725784761565072, 0.08666942720966679, 0.11031007580459118, 0.1602314848984991, 0.12737734855285712, 0.29827289336494034, 0.2591057893420969, 0.12388889145638261, 0.14095999114215374, 0.1613347285560199, 0.153316751654659, 0.13034307584166527, 0.3037180011825902, 0.29590627178549767, 0.46070361882448196, 0.2226504369505814, 0.19042805741940225, 0.15504567245287554, 0.1365101584898574], [0.11481043217437607, 0.05212098213710955, 0.07885057319487844, 0.05675584450364113, 0.1103134820503848, 0.10654799946184669, 0.021734168753027916, 0.1473332941532135, 0.08727639713989836, 0.11806779381419931, 0.09985781381172792, 0.13376157597771712, 0.07284993518676076, 0.12215444738311426, 0.05433216491448028, 0.07515777527753796, 0.05483956661607538, 0.09497446513601712, 0.08601474948227406, 0.07170811002807957, 0.007071826399104404, 0.09278260025062732, 0.05929010494479111, 0.20659886327173027, 0.16436054690607957, 0.04395400573100362, 0.12011293907250677, 0.11529918094830853, 0.04951370454260281, 0.13844440398471697, 0.11825160895075117, 0.2250136522842305, 0.5669307187199593, 0.5328061069761003, 2.23322137764522, 38.00602442877633, 62.83688858577183, 45.02971519742693, 39.086907046181814, 54.31225837979998, 77.66883291516984, 65.73598275865827, 46.19071749278477, 23.238951955522808, 26.208360161100114, 43.205483027866904, 63.07998520987374, 71.42400741577148, 77.00377913883754, 77.36318860735211, 78.43775531223842, 72.130861554827, 70.43814836229596, 81.357179914202, 76.64882346561977, 69.97248009272984, 67.81229904719761, 67.1159644808088, 55.56064469473702, 56.882490839277, 50.54264872414725, 46.101179531642366, 52.92115953990391, 53.109226431165425, 40.42437621525356, 16.82169474874224, 7.705182245799473, 11.110755801200867, 11.41786617892129, 22.588751690728323, 20.994902678898402, 9.055270212037222, 35.392296246119905, 57.90043667384556, 19.67475710596357, 5.5756362421172, 0.9571224983249391, 0.5291947264756475, 0.02509323600679636, 0.35407526046037674, 0.3028072171977588, 0.5692779613392693, 0.15862338404570306, 0.3477452615542071, 0.8801510057279042, 0.05407332416091647, 0.3757470989865916, 0.21846052392252854, 0.11975893378257751, 0.22753256426325866, 0.5074279744710241, 0.36693786882928436, 0.5401969818132264, 0.4362005522208554, 0.12215862715882914, 0.2838468317474638, 0.053107276891491244, 0.6094190616692815, 5.019422088350568, 4.485979786940983, 1.1315621265343256, 1.2747326897723334, 0.6296311542391777, 0.585422697876181, 4.310979851654597, 19.109330075127737, 30.47864137377058, 31.32310458592006, 18.017672538757324, 23.501034532274517, 13.343209402901785, 10.48852550983429, 13.541151421410696, 20.39127618925912, 12.323536940983363, 16.285781928471156, 9.143805027008057, 13.303030576024737, 15.744932413101196, 29.798822675432476, 27.456020389284404, 31.531560965946742, 43.19182286943708, 54.18540164402553, 57.075824465070454, 57.98890808650425, 61.09496825081961, 58.61568423679897, 62.00123568943569, 69.00638171604702, 65.10235568455288, 59.909633363996235, 59.14756883893694, 55.34898519515991, 45.75950534003121, 40.59427356719971, 47.45708574567522, 51.02253300803048, 42.72822863715035, 48.439943177359446, 42.48127923692976, 29.791363784245082, 30.351649148123606, 12.112646954400198, 4.449581214359828, 0.3550727612205914, 0.07248573830085141, 0.210956835853202, 0.14633417847965444, 0.32526786625385284, 0.0533078111309026, 0.025339739297383597, 0.07078281217919928, 0.34575112855860163, 0.18417124530034407, 0.33122008400303976, 0.3871978931128979, 0.20831656110073837, 0.07259830726044518, 0.0747294704030667, 0.16672023385763168, 0.03752066933416894, 0.06543537947748389, 0.0337188138759562, 0.030089496302285364, 0.10952944162168674, 0.04682670926143016, 0.08315874130598136, 0.08861395251005888, 0.03705754543521574, 0.05658916237631014, 0.1235083554472242, 0.12720289719956263, 0.04076282500422426, 0.04247245844453573, 0.08305556327104568, 0.08587743435055017, 0.012903256009199789, 0.15088128591222422, 0.044802432347621234, 0.05771299957164696, 0.04565820410581572, 0.054076723621359894, 0.10127409281475203, 0.10857752484402486, 0.05851815601012536, 0.07985395685370479, 0.04829002770462206, 0.06393888406455517, 0.11812209018639155, 0.006841995986178517, 0.020121971245056818, 0.01320869176249419, 0.14356255291828088, 0.15126707378242696, 0.06229630684746163, 0.012738528062722512, 0.048616426797317605, 0.1363973045455558, 0.10864048610840525, 0.20638992876878806, 0.22683538310229778, 0.10991305139447961, 0.12845108950776712, 0.18867898413113185, 0.3007888469312872, 0.3971887512930802, 0.20473381477807248, 0.6112100684217044, 1.1084098603044237, 8.062792130878993, 47.306209087371826, 76.7007543018886, 74.67916202545166, 77.91649450574602, 88.16149520874023, 88.29285785130092, 82.25565147399902, 63.31491075243269, 37.74692610331944, 43.857825074877056, 50.06723213195801, 70.07692541394914, 95.45333085741315, 97.50981698717389, 98.10825143541608, 88.13663455418178, 83.51574897766113, 83.02447659628731, 85.94533947535923, 79.22484030042375, 80.36590821402413, 79.40561853136334, 78.90840544019426, 74.3992885862078, 65.68591403961182, 68.81595938546317, 67.0978227342878, 66.37344523838588, 69.36180291857038, 55.91839354378836, 26.018205336162023, 14.758387225014822, 19.669684920992168, 25.38490309034075, 29.98246009009225, 34.01361731120518, 15.929834399904523, 46.42435414450509, 64.1372925894601, 38.86484956741333, 12.343579019818987, 2.6121363937854767, 0.03250142027224813, 0.05650724284350872, 0.07318046316504478, 0.3085275931017739, 0.44414261462432997, 0.12610038635986193, 1.0102535273347582, 0.49928712844848633, 0.04823987378871866, 0.496102899312973, 0.3740856652813298, 0.14953584596514702, 0.42069084303719656, 0.16646909447652952, 0.15675714133041246, 0.8583912562046732, 0.6087270102330616, 0.1387810930609703, 0.4495571883661406, 0.23265201598405838, 1.3031660211937768, 15.898786374500819, 14.86520883015224, 6.840409449168614, 1.9438182669026511, 2.049080869981221, 0.5424833191292626, 2.1100213485104695, 18.646668638501847, 31.25060360772269, 40.4853709765843, 28.34746732030596, 32.80962651116507, 34.73760570798601, 23.82320860454014, 23.637517997196742, 25.42315466063363, 20.327246802193777, 18.155934742518834, 14.426482200622559, 16.43637544768197, 30.329282896859304, 46.19105795451573, 36.47568021501814, 44.30161346708025, 57.01365893227713, 69.96557358333042, 72.36332743508476, 71.60550131116594, 61.92340891701834, 73.86913408551897, 77.34208692823137, 81.14316150120327, 80.7499282019479, 77.46897493089948, 63.1873140335083, 67.24260929652623, 66.46527263096401, 51.796218395233154, 46.101985522678916, 54.69905764716012, 49.29473836081368, 55.92506728853498, 60.675387382507324, 48.71730484281267, 35.61001804896763, 20.630634682519094, 7.160086946828025, 0.4424198142119816, 0.17806417228920118, 0.16521180979907513, 0.3772169415439878, 0.191577835008502, 0.008883816422894597, 0.14487209836287157, 0.1637351411793913, 0.39716196273054394, 0.4033741679574762, 0.2856001119528498, 0.15830946660467557, 0.1913200459842171, 0.1055405717343092, 0.05293420296428459, 0.10544702211128813, 0.054683988714324575, 0.11021572551024811, 0.0455993717270238, 0.06904920948935406, 0.08641059324145317, 0.03136655009750809, 0.096532530816538, 0.09419744754476206, 0.11677608026989869, 0.04218182832534824, 0.10596817093236105, 0.026027273386716843, 0.09274756070226431, 0.04128425881000502, 0.003939404684518064, 0.23389506499682153, 0.170970672209348, 0.22339649977428572, 0.1077106488602502, 0.24589300262076513, 0.15614442420857294, 0.09781657012977771, 0.24584287245358738, 0.18916989064642362, 0.15923797392419406, 0.1959009716021163, 0.1257194568003927, 0.1523920984140464, 0.2618834674358368, 0.16411932770695004, 0.24594294279813766, 0.12522773604307855, 0.261915385723114, 0.18390802799590997, 0.1571395229548216, 0.12267321454627172, 0.10936142956571919, 0.3631639656211649, 0.21716513271842683, 0.16640632998730454, 0.25457692093082834, 0.30164599950824467, 0.18272930410291466, 0.14288386862192834, 0.20288644890700067, 0.4169584661722183, 0.4220479673572949, 0.5111976979034287, 0.7022069341370037, 4.364478809492929, 39.718136991773335, 79.7742760522025, 90.20867075238908, 98.71609374455043, 93.02934060777936, 105.09144810267857, 99.68851498195103, 71.91762828826904, 40.85457393101284, 38.89421612875802, 47.65481410707746, 77.00275775364467, 102.88185841696603, 107.59830256870815, 101.92131165095738, 89.53347260611397, 85.92436286381313, 84.4750589643206, 90.43695381709507, 83.62641988481793, 86.07971068790981, 85.26547908782959, 87.80025836399624, 83.32755007062639, 72.51566668919155, 68.72117900848389, 62.933176721845356, 67.69319302695138, 63.95153250013079, 50.07826239722115, 19.632466895239695, 12.131997687476021, 19.541846752166748, 20.405434880937847, 28.45472492490496, 27.501305273600988, 14.00899360861097, 45.93993616104126, 70.85082272120884, 37.177958965301514, 10.933360474450247, 3.2190591522625516, 1.1252655386924744, 0.13464810912098202, 0.3646100323115076, 0.312773620975869, 0.9287767793451036, 0.16357542760670185, 1.6795667665345329, 1.2902456287826811, 0.07293104047753982, 0.8271766911659921, 0.8104058025138718, 0.2617031399692808, 0.4624006620475224, 1.9768925607204437, 0.5537648051977158, 1.874763812337603, 1.048255939568792, 0.40654200368693894, 0.8276167618376868, 0.324580184583153, 1.4127304277249744, 17.227462598255702, 14.1314069713865, 7.419324670519147, 3.5906928905418942, 3.236743837594986, 0.559113832456725, 7.391690816198077, 29.81798233304705, 44.58794525691441, 54.86882298333304, 32.653656823294504, 34.20393194471087, 31.292980670928955, 13.497076392173767, 18.74455312320164, 23.27283137185233, 14.79043926511492, 24.1315244947161, 15.237350872584752, 22.38602410043989, 33.741067273276194, 45.67256253106253, 43.72073711667742, 50.944153853825156, 54.17780378886631, 63.10390785762242, 67.0904506955828, 80.3395745413644, 68.97220352717808, 77.37506307874406, 78.60227475847516, 85.65110410962785, 83.08248710632324, 82.22316864558628, 68.1283517565046, 65.81248242514474, 63.41823741367885, 59.926045009068076, 66.01692622048515, 79.2202683857509, 73.6066311427525, 76.2325360434396, 63.60962554386684, 54.76341533660889, 44.470110757010325, 20.477386951446533, 5.204665839672089, 0.35164083966187065, 0.21648716766919407, 0.37793024469699177, 0.4970644105757986, 0.4896495427404131, 0.13153767745409692, 0.14295890102429049, 0.2572390580815928, 0.35271971034152166, 0.43642083182930946, 0.5256168384637151, 0.40491085978490965, 0.1924267773117338, 0.12196848807590348, 0.1353234007422413, 0.18027150098766598, 0.21014282453273023, 0.17831210898501532, 0.25887763872742653, 0.1555214204958507, 0.16083398328295775, 0.12814725509711675, 0.12122249310570103, 0.24380278906651906, 0.23610375076532364, 0.2804367318749428, 0.20948266424238682, 0.21326536126434803, 0.10348500417811529, 0.11032755486667156, 0.22792612814477511], [0.15076611137815885, 0.04937691527551838, 0.1018405474190201, 0.018772358307614923, 0.059692421928048134, 0.09742105885275773, 0.04973419788958771, 0.06509687192738056, 0.03390190637271319, 0.16613411530852318, 0.21066429226526193, 0.13032767309674195, 0.13189770813499177, 0.017827866399394612, 0.07883543507861239, 0.1371406532291855, 0.13896120339632034, 0.026766913876469647, 0.08328680122005087, 0.012053262824857873, 0.07529082920934473, 0.104914840310812, 0.06593726468937737, 0.15984147654048034, 0.06423541065305471, 0.057801629815782817, 0.058308902595724375, 0.1641281893742936, 0.13405321032873221, 0.0581635536093797, 0.13147906559918607, 0.21219973558826105, 0.36021092693720547, 0.635791003704071, 0.6728563862187522, 1.5093201590435845, 19.925898006984166, 48.702015331813264, 38.89367069516863, 29.558856214795792, 52.20754132952009, 71.71120425633022, 72.82363169533866, 51.85452420370919, 37.98631238937378, 33.267526694706504, 41.94639996119908, 56.008709703172954, 51.7353869165693, 63.8236300604684, 62.326849120003835, 80.31135790688651, 69.48240280151367, 61.83048370906285, 67.36318833487374, 54.610836369650706, 51.09928628376552, 49.575827734810964, 51.38110521861485, 50.1503256389073, 51.07488421031407, 44.816436767578125, 45.00178343909127, 36.059087072099956, 24.20298845427377, 19.337298733847483, 15.529960359845843, 18.89749687058585, 8.978537780897957, 10.041713782719203, 7.4928175040653775, 15.802227258682251, 19.949928351811, 47.866390228271484, 21.06308535167149, 6.611351226057325, 3.173170860324587, 1.7740503251552582, 0.2729925513267517, 1.5955808503287179, 0.9748000183275768, 0.04668865791921105, 0.22817251778074674, 0.9213366700070245, 0.10592495503702334, 0.2243529220244714, 0.03175865852140954, 0.05019795282610825, 0.6294254224215234, 0.08524041888969285, 0.2744444805596556, 0.16532859924648488, 0.017253362673467824, 0.5241552740335464, 0.3604198885815484, 0.2902563006750175, 0.5031386560627392, 0.617157400718757, 4.07722681760788, 1.6341107828276498, 0.650072374514171, 1.0095253778355462, 0.9369636029005051, 0.0866867977061442, 6.597397940499442, 24.070508888789586, 33.37820455006191, 40.016416209084646, 30.712503841945104, 30.5692389351981, 8.170749766486031, 7.946844935417175, 9.971130507332937, 19.367646728243145, 16.19562210355486, 17.453192199979508, 12.848791224615914, 13.388150351388113, 9.535865817751203, 10.264786567006793, 18.53044785772051, 24.140287910188945, 31.418583256857737, 44.179488454546245, 41.48044334139143, 52.784901891435894, 62.21239839281355, 61.104202406747, 56.43574946267264, 50.462734018053325, 43.03170510700771, 37.9755357333592, 41.27354335784912, 39.59506702423096, 34.2846804346357, 48.00767837251936, 48.30672189167568, 33.78567123413086, 34.91590690612793, 34.49510315486363, 26.35906137738909, 13.30525313104902, 11.049921716962542, 1.9306538190160478, 0.05659513009179916, 0.11163481364824943, 0.016646294355658547, 0.14587858292673314, 0.2290266848036221, 0.19587381663067, 0.0740460092201829, 0.16761667361216886, 0.12258048595062324, 0.1568424603236573, 0.18199629629296915, 0.38618570885487963, 0.10341810062527657, 0.031517968579594574, 0.053692262287118604, 0.07011710147240333, 0.24798006777252468, 0.11078068055212498, 0.07187735701778106, 0.08061897794583014, 0.07663008091705185, 0.04913172325385468, 0.06103530379810503, 0.13915386662951537, 0.04224986503166812, 0.13898382575384208, 0.02861513470166496, 0.19276426705930913, 0.06272647769323417, 0.04375059789578829, 0.06907169613987207, 0.0568665067798325, 0.11612680368125439, 0.05534402686836464, 0.05441586560170565, 0.03819007466414145, 0.055619634222239256, 0.13340276665985584, 0.06223099785191672, 0.039710457902401686, 0.030954143298523765, 0.053468070924282074, 0.09793929675860064, 0.060903064108320644, 0.04836000841377037, 0.07893275735633713, 0.057932471723428795, 0.07443399554384605, 0.038582746272108386, 0.06734847503581218, 0.16913276511643613, 0.11616016046277114, 0.1347286512276956, 0.02424630555989487, 0.019344180123880506, 0.10905500993664775, 0.10697434337011405, 0.19080148238156522, 0.03109953299696956, 0.08233505407614367, 0.17260218252028736, 0.2139431227530752, 0.30033664405345917, 0.3135644942522049, 0.291601971324001, 0.3794618067996842, 0.34527419986469404, 7.83504147189004, 37.029027802603586, 67.36231286185128, 66.07550648280552, 71.5253677368164, 86.79788344247001, 91.410660471235, 81.7501700265067, 61.03601278577532, 41.0555088860648, 41.09803533554077, 39.72010333197457, 59.33566352299282, 80.07284014565604, 99.49227006094796, 86.51301424843925, 87.49059799739292, 79.40910652705601, 80.57494476863316, 77.0891238621303, 59.7483309337071, 63.67204121180943, 60.88391671861921, 61.58851964133126, 69.05777754102434, 62.07949325016567, 60.81376075744629, 66.50844873700822, 56.7177733693804, 34.023938860212056, 23.492585522787913, 18.0406710760934, 21.382716383252824, 15.084938662392751, 18.210610117231095, 18.30091064316886, 29.5738400050572, 37.199130126408164, 49.29022550582886, 37.28202213559832, 15.322101524897985, 4.243183672428131, 1.5709279903343745, 0.8775570477758134, 0.24749141399349484, 0.3686434073107583, 0.06614362754459892, 0.7874985688499042, 0.37084093796355383, 0.16548245027661324, 0.061552876739629676, 0.11643735558858939, 0.4249240873115403, 0.18172254812504562, 0.5255520247987339, 0.5240423115236419, 0.3473743200302124, 0.9450739962714059, 0.9818313781704221, 0.30148749372788836, 0.2885057074683053, 0.21941508698676312, 0.8128005968672889, 9.675350035939898, 5.6788070031574795, 3.863761220659528, 1.7328883281775882, 1.7412902201925005, 0.4662921960864748, 5.535734474658966, 26.752037593296595, 37.368808610098704, 50.95857484000069, 42.02478953770229, 35.84315095629011, 19.47264964239938, 13.62501357282911, 16.3200660773686, 21.130448137010845, 20.76503368786403, 23.886970485959733, 19.470480067389353, 19.79418100629534, 16.03954471860613, 24.616239513669694, 34.586013385227744, 37.82062217167446, 41.66876384190151, 57.56580795560564, 66.1171053477696, 71.79252597263881, 79.09442261287144, 77.235994883946, 70.31021118164062, 65.36785330091203, 52.57605641228812, 41.17635543005807, 50.09293351854597, 59.81139973231724, 45.80492918831961, 48.7833822114127, 49.75507041386196, 41.98927729470389, 41.74411358152117, 47.04630477087838, 41.22235597882952, 26.49079748562404, 20.035585744040354, 3.9725478632109503, 0.524415017238685, 0.06803626527211495, 0.2264358074005161, 0.12320927078170435, 0.24071122067315237, 0.0037834985414519906, 0.05666504634012069, 0.1916575085903917, 0.17715184124452726, 0.17865063010581902, 0.2533932573028973, 0.11544119832771164, 0.06737440864422492, 0.031047859162624394, 0.11419534017997128, 0.020621965040585825, 0.13316166959702969, 0.11812888910727841, 0.06914441473782063, 0.07538093187447105, 0.06944845949432679, 0.12400483952036925, 0.04930912284180522, 0.22254329627113684, 0.15593255843435014, 0.07120744617921965, 0.056146119721233845, 0.022315657996971692, 0.0415422106826944, 0.036887531700943194, 0.08946614499602999, 0.027521353214979172, 0.28537505545786446, 0.15943888814321586, 0.14492863390062535, 0.159596552540149, 0.1319109938506569, 0.24115663820079394, 0.1052486388278859, 0.09009547265512602, 0.13740015216171741, 0.17863239108451776, 0.25978394438113483, 0.11200634549771037, 0.18232007963316782, 0.16766099551958696, 0.10702414105513267, 0.20032033803207533, 0.20075351478798048, 0.1335747345749821, 0.3060852741556508, 0.17088905801730497, 0.26966045583997456, 0.19806906740580285, 0.23982239408152445, 0.20688931697181293, 0.26774283445307184, 0.18508648047489779, 0.24668474442192487, 0.1686022321560553, 0.22392174016152108, 0.19664731941052846, 0.26444721700889723, 0.3002685462789876, 0.5386653382863317, 0.7245405071548053, 0.8548964208790234, 2.7095939985343387, 23.18868521281651, 70.85183021000454, 82.22547544751848, 90.74908774239677, 98.88811724526542, 102.21080139705113, 100.72840322766984, 80.80538177490234, 55.3157172203064, 50.04529319490705, 45.647868633270264, 72.70552621568952, 88.59199864523751, 105.12183952331543, 85.09445612771171, 87.27109745570591, 79.51677581242153, 83.10994638715471, 81.05981091090611, 69.26693916320801, 69.51055690220424, 68.19758360726493, 67.67339760916573, 71.38531984601701, 62.26029232570103, 65.57044887542725, 64.70134040287563, 49.76075404030936, 34.56212200437273, 28.676191806793213, 19.96787554877145, 18.826310838971818, 10.547721556254796, 12.70512853349958, 12.062437534332275, 28.833842958722794, 34.27022123336792, 58.19177464076451, 34.02122211456299, 22.607709850583756, 6.384570275034223, 4.563579440116882, 1.5852550672633308, 1.9623447699206216, 2.6574555848326002, 0.1956781814140933, 1.074034190603665, 1.7454062678984232, 0.25452814783368793, 0.6575248060481889, 0.1359162503587348, 0.9825185984373093, 1.5045591230903352, 1.4067164361476898, 0.9054636188915798, 0.783618651330471, 1.2868227724518095, 3.4566593170166016, 0.9690519039119992, 0.543122119137219, 0.8067996874451637, 1.2585808421884264, 7.021492098058973, 4.363466543810708, 2.7772221182073866, 2.1285767299788336, 3.710281593458993, 0.3517278549926621, 12.89150961807796, 39.84281894138881, 50.23026466369629, 61.172808919634136, 48.48221254348755, 43.59624971662249, 13.173550026757376, 13.790900945663452, 9.860664572034564, 19.054840564727783, 19.60350854056222, 29.080078431538173, 30.675695759909495, 33.14642654146467, 22.879111698695592, 27.071588720594132, 33.6200088092259, 38.598243713378906, 38.85927711214338, 55.6722640310015, 64.93881593431745, 71.47983619144985, 74.76593807765416, 70.91627475193569, 65.93224157605852, 67.5453770501273, 61.0753812789917, 51.98576872689383, 56.259449345724924, 64.31502750941685, 59.280779702322825, 75.56619685036796, 80.20794786725725, 69.27016312735421, 57.76866408756801, 53.13758202961513, 47.21643836157662, 27.595364774976456, 17.469204323632376, 2.0873634900365556, 0.2569474237305777, 0.163755578654153, 0.45855553980384556, 0.3177045892391886, 0.3447175297353949, 0.2249634406928505, 0.07681956182100944, 0.20823905883090837, 0.21314717403479985, 0.2714211999305657, 0.45930730232170647, 0.2976928273481982, 0.19860213808715343, 0.07642444409430027, 0.17583370554660047, 0.16975373322410242, 0.25548841059207916, 0.21192130552870886, 0.21861957253089973, 0.15307414824409143, 0.13840632459947041, 0.15467827288167818, 0.120844481246812, 0.21353578461068018, 0.2165391163102218, 0.21704638909016336, 0.1665845811367035, 0.15935145212071283, 0.08749555038022143, 0.153380208249603, 0.20028293718184742, 0.16836314355688436], [0.018797915329092314, 0.023889772727021148, 0.1720666012593678, 0.17673789417105062, 0.10057423822581768, 0.04140058006825192, 0.06435916186975581, 0.1253139642732484, 0.06764392275363207, 0.07422928152871983, 0.1382191167878253, 0.2844255678355694, 0.1983378351266895, 0.09181497538728373, 0.01659925830816584, 0.09806159591036183, 0.07526893288429294, 0.033872359565326145, 0.09653919403042112, 0.06284284644893237, 0.11836831697395869, 0.061383962232087336, 0.05723337030836514, 0.10806646583867924, 0.13125759176909924, 0.04791315578456436, 0.07119121562157359, 0.07240915205329657, 0.15848242518092903, 0.0821991910093597, 0.24736786633729935, 0.1309339984187058, 0.12697652434664114, 0.4428287265556199, 1.0288469067641666, 0.9094779949103082, 1.7017940538270133, 12.166894146374293, 41.8530787059239, 46.75205550874983, 22.710140194211686, 42.556701932634624, 59.54344940185547, 79.81447138105119, 68.10007953643799, 52.11411585126604, 49.82041474751064, 56.28711012431553, 52.26466594423567, 42.62691347939627, 50.37931741986956, 55.16261713845389, 65.39056696210588, 67.01117174965995, 57.86577558517456, 50.30991186414446, 61.76562922341483, 55.43097046443394, 61.6638172694615, 48.88487107413155, 35.4529435975211, 34.23653289249965, 30.097358976091655, 24.561305318559917, 20.361749819346837, 22.631820099694387, 22.149022783551896, 19.0085186617715, 13.164157799312047, 9.703660471098763, 9.533921190670558, 8.517682007380895, 16.90028234890529, 24.02615680013384, 24.05046854700361, 16.06152187074934, 3.470756994826453, 1.0934303041015352, 2.5538370992456163, 4.685576779501779, 2.182080464703696, 0.3840682996170861, 0.14165403747132846, 0.24887627682515553, 0.29025212089930263, 0.05413440927597029, 0.4613321051001549, 0.21369917584317072, 0.41143383405038286, 0.20270276947745255, 0.2727693404470171, 0.7220866531133652, 0.7266796295131955, 0.4795563614794186, 0.10837245799068894, 0.2202647892492158, 0.4346348190946238, 0.8615476925458226, 1.1476704393114363, 0.32445457418050083, 0.8718504054205758, 0.6419389652354377, 0.4768623603241784, 1.9643784207957131, 7.149506143161228, 28.812042985643657, 56.7025602885655, 70.78815691811698, 40.46240023204258, 37.122950077056885, 34.456290517534526, 20.135441780090332, 13.253068685531616, 8.566899572099958, 8.814236334392003, 7.799821921757289, 17.86517173903329, 11.29263358456748, 13.650972042764936, 17.98308961732047, 11.232741849763052, 15.828463656561715, 25.75901668412345, 28.98788799558367, 30.809278351919993, 31.13148716517857, 27.954399040767125, 34.746388231004985, 35.0758752822876, 33.913754326956614, 39.89729629244123, 42.75949900490897, 38.76399646486555, 31.611607687813894, 37.25941269738333, 29.692998136792863, 24.118397610528127, 21.079823562077113, 29.539088589804514, 24.688274962561472, 14.396922826766968, 5.902210261140551, 0.7345679519431931, 0.0616200856332268, 0.0966150067480547, 0.05743332779301064, 0.08157362921961717, 0.12225512840918132, 0.14989316250596726, 0.06656457031411783, 0.19449474848806858, 0.14309101179242134, 0.06266731622495822, 0.2534450430955206, 0.32012001105717247, 0.24490956110613687, 0.0294696206359991, 0.05507824130888496, 0.17618959716388158, 0.06434178458792822, 0.05383923636483295, 0.03840594718764935, 0.10517689053501401, 0.02626450449627425, 0.024388187232294252, 0.08927356997238738, 0.10442617296108178, 0.019156331096642783, 0.03443373872765473, 0.07444500138184854, 0.10805957192288977, 0.05339141682322536, 0.06570464252893414, 0.08077339894537415, 0.24943788668939046, 0.11007628656391587, 0.07021973667932407, 0.07943215913006238, 0.10476056858897209, 0.09136022121778556, 0.02417382614554039, 0.06733242089727096, 0.1310991267008441, 0.05085486971906253, 0.029270884514387165, 0.049947773572057486, 0.057190324046782086, 0.0982937023841909, 0.13886189301099094, 0.03438787654574428, 0.12108184636703559, 0.08473537848996264, 0.016113907298339263, 0.023615032201632857, 0.07391965921436038, 0.04141545694853578, 0.1308494665260826, 0.14597682122673306, 0.04464331249307309, 0.25984569106783184, 0.10319437405892781, 0.05279501846858433, 0.05060774047992059, 0.1050449697566884, 0.12707390769251756, 0.4247322247496673, 0.5771145522594452, 0.45552949075187954, 0.4492170251905918, 0.3211992617164339, 0.3680873342922756, 0.7035573816725186, 6.557286858558655, 28.762102808271134, 51.908039229256765, 58.30302224840437, 64.67592389242989, 76.67104380471366, 87.7166645867484, 79.65093857901437, 66.85975660596574, 49.677049091884065, 48.763096945626394, 42.38099936076573, 47.627427782331196, 61.94080720629011, 81.54328741346086, 78.11218357086182, 74.3489488874163, 78.26430048261369, 76.70836952754429, 60.1584483555385, 73.49584906441825, 79.50233050755092, 81.75760459899902, 62.09147889273507, 45.42508159364973, 46.30800308500017, 48.0805093901498, 39.14752313068935, 26.21251344680786, 25.77644624028887, 28.857463359832764, 26.372474874768937, 22.41280766895839, 18.248993703297206, 13.974527938025338, 15.537063155855451, 26.28470696721758, 43.98925025122506, 32.185244015284944, 32.329488618033274, 3.003083518573216, 1.9967170740876878, 0.653182290494442, 0.6341338583401271, 1.576228923031262, 0.3693200424313545, 0.5654843534742082, 0.7152201501386506, 0.2626287160175187, 0.11114272648202521, 0.2180523443967104, 0.27782969176769257, 0.314876238150256, 0.8205860533884594, 0.2112575490027666, 0.2367291429213115, 0.5179681203195027, 0.5253859737089702, 0.3606534946177687, 0.29155637377074783, 0.4328126540141446, 1.0611177065542765, 3.553020626306534, 1.5180436223745346, 1.5435697840792793, 0.34206611343792503, 0.6792233788541385, 1.6281992771795817, 9.344581910542079, 32.59661558696202, 47.915020670209614, 60.02907984597342, 48.97588900157383, 47.104707854134695, 28.140636818749563, 22.323201962879725, 15.130857569830757, 18.53028631210327, 20.854877369744436, 20.74528169631958, 27.616327490125382, 20.782947880881174, 23.1825464793614, 21.35884584699358, 22.01102634838649, 34.31759752546038, 41.988981996263774, 46.480245453970774, 42.12191840580532, 40.198021275656565, 38.76818970271519, 39.9887832232884, 34.10719564982823, 34.66597325461251, 38.34780631746565, 48.46784714290074, 54.1428404535566, 50.59265143530709, 46.76655987330845, 44.78487804957798, 35.66885192053658, 31.380736419132777, 37.98357827322823, 38.44512973512922, 24.291779484067643, 10.617504920278277, 2.440564743110112, 0.12348156688468796, 0.11975047923624516, 0.075200020867799, 0.0988628575578332, 0.16443932482174464, 0.21757198231560843, 0.03998617042920419, 0.06474102780755077, 0.12413804951523032, 0.1760637696300234, 0.21932328119874, 0.031503641312675815, 0.05150169679628951, 0.23652313968964986, 0.015949326933228543, 0.07542868038373333, 0.05391470302960702, 0.14621730760804244, 0.03107868500852159, 0.04866055192958031, 0.07924139579491955, 0.07189458502190453, 0.12751741175140652, 0.14388510132474558, 0.13571851168360027, 0.023160359456336925, 0.08927329855837993, 0.020252182115135447, 0.046164944235767634, 0.05222632469875472, 0.06560945085116796, 0.056877845099994113, 0.07195626385509968, 0.22596023577664578, 0.1299029237457684, 0.23976640137178556, 0.5095857701131276, 0.22707759296255453, 0.3091212569602898, 0.17623267056686537, 0.2435727385537965, 0.11750900665564196, 0.11639730845178876, 0.22326449757175787, 0.22855380017842564, 0.2921845886324133, 0.15246149897575378, 0.17330032720097474, 0.16437375119754247, 0.16555069732878888, 0.15922704951039382, 0.14687233817364487, 0.13190119580498763, 0.24221976686801228, 0.1539107140685831, 0.19532136698918684, 0.3283923571663243, 0.130733884871006, 0.13958491278546198, 0.2320206527199064, 0.2509352777685438, 0.3827878768954958, 0.36225016894085066, 0.37371890353305, 0.4193724494959627, 0.36925788862364634, 0.40517101011105944, 0.8391383407371384, 1.1927615340266908, 2.47948203768049, 14.713135344641548, 51.36866099493844, 86.95858832768032, 88.01413781302315, 93.81125613621303, 93.75230067116874, 106.80773653302873, 97.97071879250663, 86.05420385088239, 75.25336810520717, 65.50870718274797, 74.35438932691301, 80.91819272722516, 91.64847646440778, 78.34405190604073, 74.83502401624406, 78.80465493883405, 79.25561387198312, 66.41653796604702, 76.97172709873745, 82.17612934112549, 85.20411259787423, 63.28207356589181, 52.029670919690815, 45.53343875067574, 42.12875543321882, 36.41639123644148, 24.012793677193777, 28.678140776497976, 32.5686490876334, 25.434706040791102, 19.514317989349365, 14.845566272735596, 8.936887672969274, 9.608544843537466, 28.72589921951294, 45.28887953077044, 32.502074922834126, 42.650978565216064, 4.2633742690086365, 1.57272127696446, 6.039801095213209, 9.470227922712054, 3.433142053229468, 0.6007319135325295, 0.6600622556039265, 1.5710942042725426, 0.5458984130195209, 0.14256944906498703, 1.1879342730556215, 0.9019498931510108, 1.900794804096222, 1.4671508904014314, 1.331293740442821, 1.9522030055522919, 2.754768145935876, 2.092115406479154, 0.9920268825122288, 0.42046426662376946, 0.6981263331004551, 1.4855086824723651, 2.1882419969354356, 0.8040946668812207, 1.4486385009118488, 0.6714187062212399, 0.6107503473758698, 2.473702222108841, 18.474573918751307, 44.923042978559224, 65.43163081577846, 83.12195287431989, 48.61907121113369, 51.274495533534456, 48.489438670022146, 35.09357929229736, 27.041871275220597, 19.840383052825928, 18.87324592045375, 21.6977824483599, 30.56042514528547, 27.22400266783578, 29.423119681222097, 32.52516378675188, 27.215522391455515, 36.14737435749599, 39.81342111315046, 43.9750794001988, 42.775104658944265, 40.74486187526158, 44.13211216245379, 52.20993150983538, 54.38844885144915, 54.18652377809797, 57.688787596566335, 62.071961402893066, 70.79361820220947, 67.60035814557756, 76.36106382097516, 75.53681986672538, 58.76144354684012, 44.72072533198765, 48.43978336879185, 42.66665022713797, 23.65744195665632, 9.382587688309805, 1.1271806359291077, 0.15654231714350836, 0.2078358597521271, 0.12352017552724906, 0.1935331015182393, 0.4946168533393315, 0.3285686948469707, 0.10319484903344087, 0.23360381062541688, 0.20339590656970227, 0.20827419337417397, 0.3487592100032738, 0.2963067702949047, 0.16125394217669964, 0.18114615976810455, 0.11280850959675652, 0.3725972580058234, 0.1692598411547286, 0.29775229415723253, 0.17665527574717999, 0.1286880610776799, 0.11355530523828097, 0.23224266937800817, 0.22983216015355928, 0.2072786060827119, 0.2059639444840806, 0.09921784672353949, 0.17123844926910742, 0.20953727274068765, 0.1086910098258938, 0.160624519522701, 0.3130792874310698, 0.285321478332792, 0.13684314276490891], [0.033894900498645644, 0.11869756930640765, 0.023823836086583988, 0.1474825447159154, 0.14360037446022034, 0.06309978051909379, 0.028611728455871344, 0.07417533799473729, 0.13328007395778382, 0.03089986728238208, 0.04658614484859364, 0.09099175634660892, 0.1672274659254721, 0.04100216126867703, 0.0577181021549872, 0.07512976535196815, 0.06915754439043147, 0.05745398918432849, 0.178361072071961, 0.045337121334991286, 0.013349743925833275, 0.12275549370263304, 0.2711280456611088, 0.2096269072166511, 0.40104448582444874, 0.08901653412197318, 0.09772095776029996, 0.11699348288987364, 0.0938877777329513, 0.05221329343372157, 0.154602548373597, 0.05643173885930862, 0.2144267146608659, 0.29101549993668285, 0.2910063804260322, 0.710658494915281, 0.191196186201913, 0.4894400111266545, 9.541603292737689, 27.397938660212926, 35.83890560695103, 26.464634043829783, 27.765062366213115, 52.93042148862566, 81.36965193067277, 69.40511798858643, 56.148187841687886, 47.61970485959734, 53.08211803436279, 52.91701146534511, 46.449992997305735, 44.46917275020054, 37.816946574619834, 43.008796896253315, 47.4015348979405, 40.588954721178325, 38.746799673352925, 45.04977117265974, 36.15986027036394, 39.046673502240864, 41.047650473458425, 34.79632840837751, 24.806118147713796, 17.220880917140416, 10.792805365153722, 8.051120894295828, 14.761527810777936, 13.229492579187665, 16.36408291544233, 20.193535668509348, 16.843341861452373, 17.46687146595546, 29.311128616333008, 32.89890044076102, 46.41405691419329, 26.869278022221156, 6.2450452361788065, 0.6352235855800765, 3.105098707335336, 3.6478585430553983, 2.43708803824016, 0.36313468004976, 0.27143352212650435, 0.10263387020677328, 0.1335061482552971, 0.6571050914270538, 0.24945968123418943, 0.24078081122466496, 0.47638858003275736, 0.45083913100617273, 0.20297019369900227, 0.21705472150019237, 0.2969493700989655, 0.3370950844671045, 0.4830547794699669, 0.13362989947199821, 0.22142730972596578, 0.4373334342879908, 0.37161349079438616, 1.2247712335416248, 1.13870661173548, 0.6653248646429607, 3.2399523854255676, 5.773674666881561, 14.366115382739476, 28.499968120029994, 31.96879025868007, 56.61736842564174, 49.15662554332188, 57.01897430419922, 62.64514609745571, 46.63159111567906, 32.03641707556588, 22.941808768681117, 12.043086801256452, 6.61564347573689, 6.046800971031189, 7.017894668238504, 4.390689151627677, 7.588830317769732, 7.694482019969395, 13.755388702665057, 14.535957149096898, 15.140668426241193, 23.209872007369995, 33.45462083816528, 41.80437878199986, 43.9379551751273, 47.289922509874614, 47.52608830588204, 39.17202247892107, 33.871453693934846, 32.447955404009136, 28.566250460488455, 25.738265889031545, 15.119377408708845, 17.18236878940037, 18.869650227682932, 12.24007865360805, 3.960748953478677, 1.1021449736186435, 0.384207833558321, 0.09205173661134072, 0.0492377918479698, 0.15959879170571054, 0.0521736228838563, 0.0826103560892599, 0.005217430057070617, 0.08953033440879413, 0.05713272999439921, 0.22282145491668157, 0.11973625714225428, 0.28830803664667265, 0.35160723860774723, 0.17602809225874289, 0.13125471478062017, 0.13933793960937432, 0.0345697544648179, 0.0632021918094584, 0.07659063767641783, 0.12929655771170342, 0.07809480053505727, 0.06618161193494286, 0.1361553660993065, 0.08385407006634132, 0.06963941960462502, 0.12623340636491776, 0.07313608697482518, 0.05054279450061066, 0.14732030699295656, 0.16886561230889388, 0.07727844826877117, 0.099769726395607, 0.06108699459582567, 0.005299040008269782, 0.06568871731204645, 0.026222813608390943, 0.10141424422285386, 0.021304657782561014, 0.051906605783317766, 0.06422032681959015, 0.030516467855444977, 0.036635096317955425, 0.0842072678995984, 0.01849722083924072, 0.0887418088636228, 0.044999092152076106, 0.03071588251207556, 0.12160799599119596, 0.1189726609736681, 0.2150989393038409, 0.11189930659851857, 0.06368655724717037, 0.04563900495746306, 0.10448026577276842, 0.058177857127572806, 0.02489528020045587, 0.05335215339437127, 0.1263970961528165, 0.2471006049641541, 0.15143080428242683, 0.04731368027361376, 0.013595237047411501, 0.09150619445634739, 0.24109936984522, 0.20982569083571434, 0.34684579553348677, 0.15409051227782453, 0.26747085047619684, 0.4268163586301463, 0.7364216010485376, 0.7909135541745594, 0.5555697083473206, 2.757887452840805, 19.174360002790177, 43.073991843632285, 44.87406512669155, 51.750992570604595, 62.51922389439174, 85.67112186976841, 89.74026489257812, 62.6054927280971, 51.545600346156526, 46.329407010759624, 41.38931771687099, 48.45663969857352, 66.03661046709333, 71.4982350213187, 62.71753243037632, 51.95536340985979, 52.53062908990042, 54.752583095005576, 48.929026876177105, 49.28454882758004, 54.17225912639073, 48.89150660378592, 49.075626918247764, 42.99494218826294, 31.54641968863351, 26.713270119258336, 21.28611731529236, 21.464017254965647, 36.97633613858904, 32.203622000558035, 24.138398000172206, 23.853415897914342, 17.885172128677368, 19.390056405748638, 35.40636287416731, 49.78418336595808, 50.70582021985735, 38.25974484852382, 4.622399415288653, 0.7271966189146042, 2.6911526109491075, 3.611960675035204, 0.6410385221242905, 0.37253130440201077, 0.0834281604204859, 0.031155403570405076, 0.09146428134824548, 0.37959303547229084, 0.6700911117451531, 0.08084453655672924, 0.4465973643319947, 1.0780507922172546, 0.28267809588994297, 0.27852120037589756, 0.510747910610267, 0.27157585163201603, 0.28899061573403223, 0.34443829900452066, 0.09076401285294976, 0.06788654652025018, 1.888844336782183, 1.2566946234021867, 0.47410680247204645, 0.20045250308300766, 2.806984509740557, 3.548876677240644, 17.087600571768625, 37.68276296343122, 57.603755542210166, 71.90857478550502, 59.45587430681501, 58.720115661621094, 60.506997789655415, 45.65432350976126, 34.23537254333496, 19.7460195677621, 19.95217261995588, 19.109423875808716, 22.370025873184204, 21.033663204738072, 16.799800974982126, 18.267003434044973, 15.402681521006993, 17.16930443899972, 24.5963294506073, 23.184962715421403, 25.54622289112636, 31.847874232700892, 33.725298336574006, 36.12039450236729, 48.93899406705584, 55.81601531164986, 56.34114973885672, 48.455892767224995, 45.54640408924648, 41.993418421064106, 35.573432309286936, 29.389059611729213, 27.130690097808838, 31.381104673658097, 26.917670488357544, 16.45954074178423, 6.847636444228036, 1.0063564564500536, 0.07440107981009142, 0.011665642910104777, 0.1761838160455227, 0.0832899564078876, 0.07523664818810565, 0.041622840998960395, 0.07534713404519217, 0.0735891040946756, 0.054397670685180595, 0.29324345609971453, 0.18496213214738028, 0.11211915872991085, 0.1601414025894233, 0.11755953037313052, 0.07082104084214993, 0.14951690126742634, 0.07296445832720824, 0.06684703765703098, 0.1250984344099249, 0.028755482884922197, 0.014539487227531416, 0.11991031494523798, 0.06614970721836601, 0.13019860216549464, 0.18937707452901772, 0.1422448650534664, 0.06270991465342896, 0.05200885761795299, 0.07770621710057769, 0.07285437959113292, 0.09355260857513972, 0.0941623876403485, 0.08539684156754188, 0.02791559902418937, 0.14703562084053243, 0.2446124441921711, 0.13396999479404517, 0.30711105625544277, 0.29770816223961966, 0.12031527821506773, 0.1309326006365674, 0.17899440308766706, 0.1238396976675306, 0.20917640067636967, 0.1178839515362467, 0.21902308373578958, 0.2644311492996556, 0.2564278558960983, 0.2730179013950484, 0.13740787389022963, 0.1933740529098681, 0.11724588434611048, 0.38189476196255, 0.1843404990753957, 0.23532332692827496, 0.1755968425422907, 0.29071382326739176, 0.37556840000408037, 0.5296252433742795, 0.2306234405509063, 0.3268396519124508, 0.2800373461629663, 0.2989280324961458, 0.26803322029965265, 0.22869990233864101, 0.06921574912433114, 0.23404504837734358, 0.5232253553611892, 0.6196417074118341, 1.0654610906328474, 0.5154821308595794, 0.928927902664457, 10.358677574566432, 33.303466251918245, 67.16592897687639, 74.51374626159668, 73.15235791887555, 92.07258061000279, 107.61838286263603, 103.68176977975028, 90.30905137743268, 77.67802538190568, 69.57524463108608, 80.58172621045793, 87.44014017922538, 88.6697142464774, 75.99114172799247, 64.53254781450543, 68.22557095118931, 66.96914904458183, 58.012278352464946, 61.645258631025044, 60.73959568568638, 52.99648496082851, 50.50568430764334, 44.74223000662667, 32.59377724783761, 27.166515009743826, 21.199865852083477, 18.840240240097046, 29.986000197274343, 25.88929193360465, 20.885331324168614, 20.11926637377058, 17.889485222952707, 21.10367325374058, 39.64543104171753, 54.16265671593802, 65.08190018790108, 40.7210955619812, 5.259746381214686, 3.828819598470415, 3.6751024297305515, 7.506286587033953, 2.40399637392589, 0.5713911365185464, 0.41107263628925594, 0.26107837206551004, 0.16170401445456914, 1.501241683959961, 2.1460644773074558, 0.27492852030055864, 0.6239588728972844, 1.7398517259529658, 0.488194112266813, 0.6395857515079635, 0.41389061936310356, 0.4842103517481259, 1.3090950059039252, 0.3759168413068567, 0.18999315718454973, 1.294159744467054, 3.238648078271321, 2.3742780600275313, 1.1748083659580775, 0.7570410317608288, 4.100548880440848, 7.563426835196359, 33.22567422049386, 46.727844510759624, 58.71937220437186, 79.9519623347691, 66.34661824362618, 72.83026027679443, 79.5619877406529, 72.84615775517055, 63.41014276232038, 51.75898994718279, 32.14095619746617, 24.30653919492449, 26.359382731573923, 31.24154315676008, 27.510999747685023, 29.789022241319927, 27.418084962027415, 30.316376617976598, 43.212900229862754, 47.087497166224885, 54.52826050349644, 62.66617829459054, 65.78549562181745, 63.01461655752999, 70.70116547175816, 76.313385282244, 78.14181763785226, 77.77158982413155, 85.40499891553605, 78.8678765978132, 61.71923610142299, 41.39911815098354, 34.949449334825786, 37.06158011300223, 24.145740509033203, 12.145347782543727, 4.484099864959717, 0.5202520149094718, 0.1344146795038666, 0.10091928006815058, 0.38254892400332857, 0.17001089799617017, 0.1359806026199034, 0.08328414136277777, 0.16218072601727077, 0.15389242076448031, 0.36984555423259735, 0.2881614187998431, 0.41137868272406714, 0.2549378201365471, 0.24438380503228732, 0.22071001678705215, 0.20362578066332, 0.25185176144753185, 0.1692356445959636, 0.24365584552288055, 0.28793492381061825, 0.15079931888197148, 0.14834861324301787, 0.30125410482287407, 0.15113740574036325, 0.4020970564867769, 0.41577987798622673, 0.29388977427567753, 0.1321524708930935, 0.23209824998463902, 0.3449748573558671, 0.12809008173644543, 0.19991173781454563, 0.14837869948574475, 0.14721695253891603, 0.19786774606576987], [0.0939710611211402, 0.049356722073363404, 0.08031409859125103, 0.07828255117471729, 0.07600812214825835, 0.12301240063139371, 0.014920540619641542, 0.0891519697116954, 0.05696559324860573, 0.07356521966201918, 0.14199192076921463, 0.12217683903872967, 0.13618672798786843, 0.2280676976910659, 0.06294337141194514, 0.10594680386462382, 0.12234184518456459, 0.04657721872042332, 0.11099134531936475, 0.15114101554666245, 0.18667996568339212, 0.22483474974121365, 0.5137582176498005, 0.28067565762570923, 0.1258791025195803, 0.08786195250494139, 0.4459160066076687, 0.4887891603367669, 0.1450712348201445, 0.11537400979016509, 0.28434636922819273, 0.39145852306059425, 0.1760024164936372, 0.07086292002350092, 0.2413476865206446, 0.7153562371219907, 0.6362840543900217, 0.4698483166950089, 0.426033437784229, 3.2972524421555653, 21.7790207862854, 40.39340114593506, 31.65750401360648, 26.525363036564418, 47.09015832628523, 66.41454383305141, 67.49935218266079, 50.09491375514439, 40.59926584788731, 38.529050077710835, 37.374863965170725, 36.90162910733904, 35.69422674179077, 32.284245422908235, 41.30397994177682, 48.655392919267925, 49.91204759052822, 44.27085379191807, 43.257500716618125, 35.61535773958479, 38.55864940370832, 26.255356039319718, 18.331401075635636, 15.159998314721243, 14.257588863372803, 18.14778103147234, 24.262263536453247, 27.128751550401958, 34.272455079214915, 26.64877346583775, 28.760211161204747, 53.41023281642369, 65.24626677376884, 57.38069404874529, 52.1674085344587, 35.87699910572597, 14.471556901931763, 6.507100020136152, 5.80703774520329, 3.8077218277113776, 3.0634446910449435, 1.065945293222155, 0.08272000734827348, 0.21557399524109705, 1.0170103247676576, 2.8494097760745456, 0.3858654403260776, 0.2535787687769958, 0.698738480252879, 0.37851085354174885, 0.3692305029502937, 0.4823325467961175, 0.31939685557569775, 0.2812500239482948, 0.15101270457463606, 0.43101562187075615, 0.5119664509381566, 0.45949115817035946, 0.9849326631852559, 0.9118804974215371, 2.7491138322012763, 1.6911173867327827, 2.7628832076277052, 7.334182313510349, 25.763427053179058, 26.929169757025583, 30.13560880933489, 43.183446816035676, 46.71228402001517, 64.36112185886928, 75.61471612112862, 71.89233684539795, 62.57904788425991, 49.785027572086875, 47.35186570031302, 35.09780727113996, 22.552211114338466, 16.101477486746653, 9.188862357820783, 3.1509285909788947, 2.988207859652383, 13.56396756853376, 21.610695464270457, 32.304773875645225, 39.018425600869314, 43.39336231776646, 43.99440581457955, 36.308110509599956, 22.512941632952007, 15.160295350211006, 14.774520942143031, 15.372760840824672, 11.755441801888601, 10.845986877168928, 11.295611756188528, 12.711182151521955, 17.22225492341178, 11.015694890703474, 1.237382431115423, 0.7069477226052965, 0.21375347221536295, 0.21061034873127937, 0.06519628409296274, 0.19810702465474606, 0.37385276492152897, 0.11079436660345111, 0.11065936527614083, 0.11825124254184109, 0.008355914482048579, 0.11409210786223412, 0.14913997506456717, 0.251828881246703, 0.21590000417615685, 0.0882581016048789, 0.12560129671224526, 0.054889696783253124, 0.09228140714445285, 0.036267550861729045, 0.035530040971934795, 0.13235333082931383, 0.05453245148860982, 0.11855625760342393, 0.03651142652545657, 0.10456181889665978, 0.06828754714557103, 0.11744325661233493, 0.37443239667585915, 0.3136746340564319, 0.10464742287461247, 0.037575376220047474, 0.15289984616850102, 0.02165664273447224, 0.06287473759480885, 0.015124204601826412, 0.1586095690727234, 0.018425452190318277, 0.04259856757042663, 0.030027254285024743, 0.08406345240239586, 0.0893288366496563, 0.10817724346582379, 0.10792583267071418, 0.04629982681944966, 0.06941177110586848, 0.07561040563242775, 0.03690657478624156, 0.06305418296584062, 0.038850635290145874, 0.05838772122349058, 0.21170414718134062, 0.3422913599227156, 0.19232885113784245, 0.16486524125295027, 0.01799623298990939, 0.031833775740649016, 0.07943093098167862, 0.06911429456834282, 0.07169021705963782, 0.3301105163991451, 0.1595952497529132, 0.09324398370725767, 0.12794013906802448, 0.25119643232652117, 0.3103987212691988, 0.18713921175471374, 0.4729926479714257, 0.3050121303115572, 0.43752068281173706, 0.3279057389923504, 0.22077168204954692, 0.3092917592397758, 0.46374296716281344, 0.7817837297916412, 1.287607158933367, 0.6776143280523164, 7.522835459027972, 33.461621148245676, 44.2711421421596, 46.25324085780552, 56.194730349949424, 73.23281111036027, 81.36381544385637, 66.94803346906389, 51.60648741040911, 37.84497560773577, 32.922093527657644, 34.0016907283238, 47.987865584237234, 57.594827107020784, 55.158712250845774, 48.78011308397566, 46.446126324789866, 50.062983308519634, 41.70130920410156, 41.38495772225516, 39.023845195770264, 37.42349440710885, 24.61440692629133, 21.95190586362566, 18.068106038229807, 23.779198714665004, 31.558752741132462, 28.048390797206334, 25.66024283000401, 25.96137601988656, 21.88845317704337, 25.176636048725673, 39.40201827457973, 56.68309491021292, 61.74367291586739, 72.82532705579484, 41.49223790849958, 20.015762533460343, 10.807882956096105, 1.9975701825959342, 4.958485518183027, 2.407605311700276, 0.26259145087429453, 0.04163952956774405, 0.14944203171346868, 0.12851265977535928, 0.8134176837546485, 0.17707839661410876, 0.145588074943849, 0.09707414425377335, 0.37170834998999325, 0.36047137581876343, 0.09037186032427208, 0.0754159442814333, 0.405391452567918, 0.27564812025853563, 0.17144286472882542, 0.9865220636129379, 0.062414358370006084, 0.02351644615243588, 0.4565376309411866, 2.868437852178301, 2.015838082347597, 3.699626530919756, 9.136650119509016, 33.06080389022827, 44.5582833971296, 47.76422044209072, 66.57631874084473, 65.05884606497628, 70.10705975123814, 71.9467968259539, 71.52646555219377, 65.85960510798863, 50.00092199870518, 31.099726949419292, 17.837870529719762, 17.68334433010646, 22.234066997255596, 14.910154989787511, 15.392665692738124, 21.843680722372874, 36.74193518502371, 37.702315194266184, 40.54653944287981, 41.62153346197945, 44.88008574077061, 45.897711958204, 46.4537797655378, 39.79806906836373, 34.50624111720494, 31.496872084481375, 27.903687613351003, 22.888333695275442, 21.70745955194746, 24.341827358518326, 21.773337159837993, 25.44017079898289, 17.897362743105205, 8.953243732452393, 2.572710795061929, 0.4893788886921746, 0.049552971364132, 0.08944917483521359, 0.24961815987314495, 0.3297681547701359, 0.07387047899620873, 0.103032719876085, 0.10441292117216758, 0.14641340422843183, 0.059777313444231234, 0.06119193682180984, 0.2138605314706053, 0.25342235288449694, 0.24258880849395478, 0.09697021304496697, 0.03808303576494966, 0.007815280679746397, 0.0279445521134351, 0.060561598145536015, 0.039390742379639826, 0.07194979741637196, 0.07506421208381653, 0.09074492566287518, 0.14854331208126886, 0.08537700120359659, 0.10139839364481823, 0.19581034646502563, 0.12584075172032627, 0.01931211764791182, 0.09758107098085539, 0.0875725776755384, 0.015744679075266634, 0.08576466183045081, 0.022352119076198766, 0.0810908515538488, 0.029979410780859844, 0.20551970760737145, 0.11116704517709357, 0.2606437568153654, 0.2173396519252232, 0.19564516390008585, 0.16459675851677144, 0.22856720803039415, 0.1322287789412907, 0.12092821246811322, 0.1545703722430127, 0.15211779384740762, 0.14710457356912748, 0.14526244598839963, 0.27510347376976696, 0.3691434604781014, 0.293604491012437, 0.26981100918991224, 0.14224163522677763, 0.18286563535886152, 0.19959123858383723, 0.3234243408909866, 0.27842932673437254, 0.48219309427908486, 0.3980738323714052, 0.24396599030920438, 0.2163606344589165, 0.5744453040616853, 0.6534557129655565, 0.6074640665735517, 0.6347728754792894, 0.32911803679806845, 0.44789757313472883, 0.3870764353445598, 0.21654235970761093, 0.3825784538473402, 0.4337698226528508, 1.1681616540466035, 1.1760366771902357, 0.49369518565280096, 4.002843311854771, 26.424065249306814, 55.23625414712088, 74.87082113538469, 67.71793556213379, 81.92450032915387, 98.20947279248918, 97.91565431867326, 81.79257488250732, 68.40966347285679, 67.82113715580532, 67.96901566641671, 79.38418333871024, 79.79341139112199, 74.65674713679722, 71.86790697915214, 71.9393344606672, 79.46430996486119, 69.03639793395996, 72.02073955535889, 65.26240049089704, 59.90826456887381, 45.81842606408255, 42.604672295706614, 36.56508616038731, 37.31552982330322, 39.98645557676043, 31.781279223305837, 34.50799553734915, 43.72161953789847, 36.150198800223215, 51.2970598084586, 91.25255421229771, 88.94969885689872, 80.56761441911969, 74.36446421486991, 44.90367487498692, 17.27082804271153, 15.726118428366524, 14.381147810391017, 6.850818284920283, 3.416236434664045, 1.7688871622085571, 0.1759092400648764, 0.22184697006429943, 1.411523503916604, 5.792156440871103, 0.4462118207343987, 0.37062505526202066, 1.3916023671627045, 3.272327082497733, 2.3956290057727267, 0.41713119404656546, 0.3693016677030495, 0.4888574481010437, 0.2600192060428006, 0.4264528809913567, 1.134659937449864, 0.5759344984378133, 0.8659806432468551, 0.5907256390367235, 5.888941807406289, 9.506147503852844, 18.079278741564067, 33.81441593170166, 52.745620250701904, 49.94235563278198, 55.30137961251395, 67.80615683964321, 65.95018877301897, 78.44234112330845, 90.31383868626186, 93.75391265324184, 94.3868657520839, 82.46793283735002, 82.30177361624581, 74.2755411693028, 73.10338701520647, 64.54001017979213, 55.560898303985596, 59.68787465776716, 79.67107445853097, 94.76097066061837, 91.12941823686872, 90.76438072749546, 86.97803633553642, 85.70058223179409, 76.08998680114746, 71.80434485844204, 71.16680594852993, 78.68185247693742, 75.98301928383964, 65.7448069708688, 48.72325944900513, 38.33541420527867, 33.00403363364083, 29.030694110052927, 24.821652582713536, 14.378604769706726, 7.323970198631287, 1.7727841245276588, 0.6679544863956315, 0.34894067740866114, 0.16983308110918316, 0.2021390697253602, 0.49214552023581093, 0.2117508982441255, 0.19862018711864948, 0.2053914644888469, 0.16773328664047377, 0.25543676050645964, 0.19040932985288755, 0.40004883067948477, 0.27301274452890667, 0.2415931262075901, 0.25188232266477173, 0.12129934398191315, 0.15748401518378938, 0.18633103583540234, 0.11367959249764681, 0.13806282303162984, 0.19496932945081166, 0.15174872508006437, 0.2250863912382296, 0.25748805329203606, 0.44446939708931105, 0.1679695661046675, 0.37872060228671345, 0.32279846018978525, 0.19989429946456636, 0.12283125892281532, 0.16331944348556654, 0.11852812554155077, 0.1082462640479207, 0.15692511945962906, 0.16773837565311364, 0.0875566117465496], [0.07462671305984259, 0.07524297213447945, 0.0832867876493505, 0.21208176548991883, 0.0752739743994815, 0.0696131738701037, 0.0840007761227233, 0.20004787908068725, 0.13317629881203175, 0.11856841695095811, 0.09882598596491984, 0.12887327399637016, 0.03157777126346316, 0.1373615978019578, 0.31694188873682705, 0.3056640938988754, 0.3865196023668562, 0.1346753862287317, 0.10297452871288572, 0.12152330125016825, 0.13278800036226, 0.2116011862776109, 0.11953793492700372, 0.06525444132941109, 0.04342762879761202, 0.1124709519956793, 0.3166668920644692, 0.37661719801170485, 0.3490289141024862, 0.8599480869514602, 0.6228201282875878, 0.5311341424073491, 0.3498192988336086, 0.03383957953857524, 0.19808019538010868, 0.2572188920208386, 0.3566945141979626, 0.6184713702116693, 0.27036710934979574, 0.28876184086714474, 0.7295777340020452, 9.170268109866551, 35.406960419246126, 28.814415795462473, 33.49101897648403, 49.880506243024556, 51.170401096343994, 46.4615478515625, 30.806683199746267, 32.12976264953613, 44.314068113054546, 23.221991402762278, 18.347880465643748, 28.91239755494254, 24.616470541272843, 21.146053791046143, 19.455614396503993, 23.26519356455122, 27.44589512688773, 33.72414493560791, 39.16092273167202, 47.103002071380615, 50.27281543186733, 49.152772767203196, 48.35345547539847, 56.61215032849993, 61.26774215698242, 66.0872072492327, 58.35259069715227, 46.69741834912981, 45.66306781768799, 61.136191913059776, 69.4543320792062, 65.28425257546562, 66.03243459974016, 46.69348566872733, 30.11356564930507, 30.900504725319998, 28.78861713409424, 14.581677164350237, 11.199838655335562, 5.8721180473055155, 0.3505700299782412, 0.18251586412744863, 0.786871928189482, 1.279169765966279, 0.8567100635596684, 0.5046342558094433, 0.8077217893941062, 0.8433491119316646, 0.04872896183016045, 0.2071018341396536, 0.4542728438973427, 1.0450227473463332, 0.8319348501307624, 0.5310529896191188, 1.063739891563143, 3.1475378700665066, 1.5958915650844574, 2.4494369413171495, 5.629791804722377, 13.584985869271414, 21.173905645098003, 40.61220339366368, 50.63371876307896, 68.58186762673515, 68.09700843266079, 63.6701443535941, 55.19259861537388, 54.74384920937674, 62.69278294699532, 70.92038808550153, 78.04152039119175, 59.163292612348286, 60.49355302538191, 49.563539845602854, 31.50912175859724, 20.202896629061016, 10.973898870604378, 5.9765594601631165, 5.264323507036481, 8.508673667907715, 12.004753589630127, 14.524770549365453, 15.496445723942347, 11.869664107050214, 13.101086395127432, 13.256714752742223, 6.205507814884186, 2.5253787977354865, 4.035138538905552, 5.951681000845773, 6.828402527741023, 3.548030734062195, 7.815907870020185, 8.350548301424299, 2.2764415613242557, 1.0869362354278564, 0.45283589671765057, 0.6622544122593743, 0.08599140109228236, 0.11088923936975853, 0.07478817725288016, 0.13987809419631958, 0.14779363945126534, 0.09417426878852503, 0.4905954748392105, 0.33380744659474915, 0.17141106857785157, 0.09044618705021483, 0.14461471645959786, 0.06891004195702927, 0.09620801465851919, 0.13353327608534268, 0.01520698587410152, 0.010631084808015397, 0.03379751376009413, 0.03364690612735493, 0.13974018873912947, 0.3028978151934487, 0.06848565901496581, 0.20114372670650482, 0.1162159088999033, 0.05405514620776687, 0.2063917201012373, 0.15712561298693928, 0.06602390682590858, 0.13498766161501408, 0.13287087662943772, 0.1656898105783122, 0.44565639910953386, 0.43467018433979576, 0.24119042924472264, 0.024370828610179678, 0.01258367025626025, 0.06971544945346457, 0.07290596182325057, 0.13480015524796077, 0.04876325838267803, 0.08511487634054252, 0.07360308191605977, 0.15077756504927362, 0.10935389104166202, 0.28910930507949417, 0.23050635254808835, 0.03978847585884588, 0.059985962962465625, 0.12368782795965672, 0.03526783129200339, 0.06123486773243972, 0.4317447213189942, 0.44188027030655314, 0.2690310467566763, 0.11490499281457492, 0.10701569329415049, 0.08125161685581718, 0.1280835678002664, 0.14168409657265457, 0.15394441011760915, 0.07607610457177673, 0.12848395774407045, 0.2900840070630823, 0.2461408850337778, 0.16527736985257693, 0.36527781933546066, 0.16583511206720555, 0.31474525375025614, 0.31233580304043634, 0.7079171591571399, 0.7905864460127694, 0.3556933222072465, 0.27305622505290167, 0.3262448752565043, 1.1352887494223458, 1.1536345992769514, 0.5059589190142495, 3.5668701231479645, 22.691647563661846, 45.29245090484619, 40.31139155796596, 52.22521407263619, 70.075653893607, 68.03778198787144, 53.5809257371085, 41.885353088378906, 32.50218609401158, 26.645389693123953, 25.085103954587662, 35.46007939747402, 36.84582117625645, 34.21799162455967, 29.03457989011492, 34.953896181924, 42.8806790624346, 42.00348636082241, 47.41757134028843, 45.966155188424246, 36.44452101843697, 26.937689985547745, 21.068049839564733, 22.405416522707256, 29.46034812927246, 26.57381456238883, 25.68010425567627, 29.548048291887554, 28.01081841332572, 53.857318128858296, 88.98985944475446, 88.56254523141044, 81.39209461212158, 62.57061971936907, 57.46439552307129, 35.536283765520366, 31.530598640441895, 34.92515843255179, 18.004457065037318, 12.64172101020813, 3.3863007724285126, 0.27319358768207685, 0.06838572437741927, 0.5408400701625007, 0.6269529493791717, 0.47353037340300425, 0.3991124794951507, 0.5088461669428008, 0.7940177704606737, 0.15871385990508965, 0.3762664496898651, 0.7850860240203994, 0.5490888303944043, 0.4907580518296787, 0.7203724565250533, 1.5545719308512551, 1.8588878299508775, 0.47117108000176294, 1.8782025192465102, 4.958040399210794, 8.250662735530309, 12.772659812654767, 32.18585198266165, 55.165674345833914, 64.20491245814732, 67.00150680541992, 65.19707352774483, 65.32981191362653, 64.24852630070278, 63.01369244711739, 68.58239568982805, 71.13487897600446, 71.74222796303886, 61.97868183680943, 49.73207535062517, 44.37302010399954, 35.02102967670986, 29.91302326747349, 24.152610540390015, 26.4503242288317, 28.28704057421003, 22.741299390792847, 21.903360537120275, 14.60233415876116, 7.525659901755197, 12.359468681471688, 15.364313568387713, 14.277571882520403, 14.77825038773673, 15.939772060939244, 15.393664496285574, 18.538240262440272, 17.65676052229745, 14.93043157032558, 14.082914624895368, 6.705743372440338, 4.227384337357112, 0.5374096685222217, 0.35053132634077755, 0.0908925070294312, 0.28591478935309816, 0.14022475773734705, 0.17624170865331376, 0.07815919350832701, 0.07652224134653807, 0.2349403074809483, 0.09824283261384283, 0.11862207550023283, 0.0484868062527052, 0.1929634849407843, 0.24960040939705713, 0.21742556802928448, 0.1092444569138544, 0.11010156199336052, 0.0300047845978822, 0.02690812379920057, 0.06541698439312832, 0.027954423101618886, 0.12869218657059328, 0.3553456137222903, 0.2425093384725707, 0.20794521245573247, 0.07164822931268386, 0.086973254834967, 0.15395168401300907, 0.07881779316812754, 0.09692666466747012, 0.11222213998969112, 0.4132872660245214, 0.3674430517213685, 0.14509054592677526, 0.05336485556992037, 0.03723035134109003, 0.08538932339953524, 0.08764264998691422, 0.1531831616801875, 0.23282908648252487, 0.20762327473078454, 0.20199060626327991, 0.1345593567405428, 0.19286580303949968, 0.1517506249781166, 0.28557055496743744, 0.3721433180783476, 0.22422575099127634, 0.15128149943692343, 0.2710999814527375, 0.169569605961442, 0.2679146666611944, 0.5344688977513994, 0.39920956428561893, 0.3524562759058816, 0.21485537237354688, 0.14962052713547433, 0.18867844130311692, 0.2018285585301263, 0.23665879241057805, 0.219463439392192, 0.21467918397060462, 0.22942935462508882, 0.4733825613345419, 0.6222625896334648, 0.7106428614684513, 0.9223733629499162, 0.904546782374382, 0.694683772112642, 0.5608799776860646, 0.5814998426607677, 0.49726976241384235, 0.4008249118924141, 0.2694432703512055, 0.7308110392519406, 1.3840001693793704, 1.1850073443991798, 0.6725863835641316, 1.5204361911330904, 14.094483375549316, 44.25950738361904, 57.85236208779471, 69.34872640882219, 84.94409016200474, 84.60799189976284, 65.9673855645316, 60.364837646484375, 62.56779180254255, 70.1030923298427, 74.90253966195243, 84.41003772190639, 81.47325651986259, 73.16210624149868, 59.01650496891567, 62.60984230041504, 65.73771980830601, 68.25639316013881, 77.44960335322789, 76.34272752489362, 74.13485404423305, 72.36986568995884, 65.35269233158657, 64.8620730808803, 72.0513116291591, 84.07052094595772, 88.29046072278703, 85.1410368510655, 82.85874816349575, 93.00527204786027, 114.54004628317696, 105.45119108472551, 92.77845505305699, 73.2584638595581, 58.332406180245535, 41.16709348133632, 42.53056975773403, 43.208613191332134, 22.87481597491673, 16.266398191452026, 8.383769375937325, 0.37800605062927517, 0.2163252013602427, 1.263264687997954, 1.8726626336574554, 1.904922034059252, 0.6155069864221981, 0.8689980613333839, 1.2965347255979265, 0.20047455547111376, 0.3289959547775132, 2.3345287186758856, 1.5045393641505922, 1.065476724079677, 1.5461523426430566, 2.6864378239427293, 3.471845039299556, 0.6297618672251701, 1.2178442052432468, 8.065292613846914, 21.24922932897295, 36.43259790965489, 60.25104004996163, 71.31790147508893, 91.5932035446167, 88.32643154689244, 83.01285920824323, 81.96417454310826, 78.09894725254604, 83.25462872641427, 91.02326365879604, 98.40928213936942, 101.30053874424526, 103.10187312534877, 98.82998166765485, 90.36121845245361, 78.00924600873674, 67.5660479409354, 53.91444969177246, 53.31364243371146, 60.57611846923828, 58.18251964024135, 57.42550298145839, 49.872717312404085, 48.77562802178519, 58.9712860924857, 63.58356285095215, 60.18021011352539, 48.21632930210659, 36.33561495372227, 36.4389694077628, 31.965503760746547, 31.081230844770158, 20.1858457497188, 11.612983754702977, 2.810578682592937, 2.04997849038669, 0.5916756966284343, 0.5736670515366963, 0.5297700156058583, 0.3671149121863501, 0.07401300527687583, 0.22419343915368828, 0.2288857666509492, 0.20904092437454633, 0.4341394885310105, 0.30441618657537867, 0.18419196775981359, 0.1256316407982792, 0.1844464455332075, 0.2636631019413471, 0.2614787891507149, 0.19066185344542774, 0.1513800634337323, 0.2222183458507061, 0.12713078249778065, 0.23761919087597302, 0.22765566408634186, 0.37290482435907635, 0.42096635539616856, 0.3035001371588026, 0.32217529362865854, 0.1582620641482728, 0.23905809223651886, 0.2499047459236213, 0.19257418225918496, 0.2344617774443967, 0.24102836794086865, 0.5412241752658571, 0.7886303652610097, 0.5485135412641934, 0.2657960632017681, 0.17275474433388027, 0.23874042928218842, 0.24442622704165323], [0.04963966099811452, 0.08110484973128353, 0.07562165574303695, 0.057584898945476325, 0.1575827013169016, 0.33230457295264515, 0.5209220818110875, 0.2185891063085624, 0.0889660171898348, 0.13259715560291493, 0.09206384167607341, 0.02120350856733109, 0.1266147701867989, 0.0771314368716308, 0.22489299518721445, 0.28265255583184107, 0.57296094085489, 0.30783698015979355, 0.07641132122703961, 0.2059677985629865, 0.2311552491571222, 0.09772018423037869, 0.04299060135547604, 0.02857354050502181, 0.026012542391461984, 0.17445361960147107, 0.27289799068655285, 0.10467121231236629, 0.39421017255101887, 0.7379866284983498, 0.2715936835323061, 0.31184400085891995, 0.28464411039437565, 0.3311662897467613, 0.3545464894601277, 0.39201041630336214, 0.07403935957700014, 0.15487484447658062, 0.5168561914137432, 0.2715872238789286, 0.31908608653715675, 1.6029009946755, 6.5593035731996805, 18.442289113998413, 28.22693865639823, 35.685003008161274, 50.19297020775931, 46.99251529148647, 28.55607656070164, 30.570444447653635, 28.570949179785593, 21.833180257252284, 26.466697658811295, 24.705047913960048, 9.509879555021014, 5.299815339701516, 2.3443237245082855, 7.909064105578831, 12.289715715817042, 11.643983142716543, 13.918786883354187, 21.24057534762791, 23.174700226102555, 33.67763369424002, 33.79828568867275, 36.31841121401106, 37.14756407056536, 41.479727676936555, 37.905213015420095, 38.923457622528076, 56.96598734174456, 62.337139402117046, 59.41708946228027, 73.93948459625244, 63.77248437064034, 44.450575896671836, 42.42159768513271, 50.054159096309114, 37.75081362043108, 23.69591760635376, 10.825383731297084, 1.1624245047569275, 1.5240951776504517, 3.9428516966956, 1.7277295078550066, 1.2871715937341963, 0.9574129113129207, 0.6752402697290693, 0.48758733911173685, 1.1081002312047141, 0.898695313504764, 1.2175541179520744, 0.7547764075653893, 0.302212901945625, 0.3189717126744134, 0.2788200271981103, 1.7299230758632933, 0.19742531409221037, 1.6081832540886742, 2.345782846212387, 0.5442853995731899, 5.017027999673571, 13.052101595061165, 42.39301627022879, 64.88378620147705, 86.5918971470424, 93.01346397399902, 75.5864508492606, 54.71450349262783, 49.991458552224294, 43.859676769801546, 48.55817025048392, 53.177905900137766, 48.1542888368879, 48.719972951071604, 35.116880076272146, 26.25612381526402, 19.920103209359304, 11.402719105992999, 5.400771362440927, 3.837031500680106, 4.992653284754072, 7.538956148283822, 8.700278929301671, 8.258515068462916, 6.038314180714743, 7.582688110215323, 8.553519078663417, 5.865676632949284, 2.5448561183043887, 1.277934615101133, 2.697246398244585, 3.4769530509199416, 1.346522020442145, 0.9420537011963981, 0.26677660058651653, 0.1981165784278086, 0.4598851427435875, 0.5768880301288196, 0.028515407017299106, 0.04259257271353688, 0.13018573714154108, 0.12142556506608214, 0.16470227071217128, 0.32662018654601915, 0.1520172349576439, 0.19660952500998974, 0.12669030470507486, 0.17460349441639014, 0.22793731040188245, 0.28023157002670424, 0.03485038297783051, 0.04985497373023203, 0.053487337926136594, 0.08581685474408524, 0.09370867162942886, 0.0455790903153164, 0.17519053577312402, 0.16823656963450567, 0.3387698174587318, 0.1055619523727468, 0.3673800565302372, 0.18296177020030363, 0.052132201713642905, 0.07789640368095466, 0.15800882130861282, 0.005859885672439954, 0.08802351169288158, 0.07374746738267796, 0.1565218118152448, 0.7382588024650301, 0.7247920536569187, 0.30649470218590324, 0.19603841565549374, 0.11857943635966096, 0.03749148893569197, 0.0481294082876827, 0.044221375669751845, 0.07821215316653252, 0.029586399905383587, 0.14324236581368105, 0.4570098913141659, 0.6634180726749557, 0.3157409631780216, 0.12813079383756432, 0.0837658333725163, 0.15630982390471868, 0.03238263253920844, 0.029506553297064135, 0.2490240888936179, 0.34481054331575123, 0.43327601200767923, 0.480381894324507, 0.18882423133722373, 0.09444921117808137, 0.23731330728956632, 0.29378964964832577, 0.20585711593074457, 0.022489429118910005, 0.008230613660998642, 0.07220205638025488, 0.18062204574900015, 0.034599637147039175, 0.26381335673587664, 0.48107834266764776, 0.5547038433807236, 0.36349623064909664, 0.17646709084510803, 0.5379762724041939, 0.9269665564809526, 0.6188910848328045, 0.2020600882491895, 0.11101554866347994, 0.16921783983707428, 0.5202467494777271, 0.4635103110756193, 0.12058230888630662, 2.2813150712421963, 15.710038559777395, 34.539116518838064, 45.64496776035854, 55.47171470097133, 63.71238245282854, 50.76929896218436, 43.57683644975935, 39.24198736463274, 35.27603203909737, 28.111918176923478, 22.361901691981725, 13.333655629839216, 9.929002710751124, 11.321414760180883, 9.592061979430062, 10.519585694585528, 13.728839635848999, 13.290164249283926, 16.927986553737096, 15.732298851013184, 19.162681818008423, 23.522695541381836, 29.569313253675187, 42.61315604618618, 55.841185161045615, 60.92010988507952, 63.092082023620605, 77.46001175471714, 88.9380189350673, 88.62773323059082, 92.57471997397286, 90.37353760855538, 77.70140607016427, 57.830749716077534, 55.219991888318745, 56.014945711408345, 52.30624743870327, 30.47659512928554, 16.974265030452184, 5.921253102166312, 2.2827218643256595, 2.5835234948566983, 2.073104266609464, 2.102468873773302, 1.1770855294806617, 0.5657256948096412, 0.29878887853452135, 0.40982092916965485, 1.584746545978955, 0.8677287665860993, 0.47587549899305615, 1.4927687900406974, 0.2874812552971499, 0.22910368495753833, 1.1979433702571052, 0.23515149472015245, 1.0832034243004662, 1.6242384782859256, 4.062693791730063, 14.47692004271916, 27.453270639692033, 54.60378047398159, 69.906416620527, 83.20482403891427, 93.09690489087785, 85.96928296770368, 69.61394609723772, 66.0171902520316, 68.03514862060547, 60.25718920571463, 64.26057447705949, 63.887317248753135, 68.97656699589321, 60.20009585789272, 52.71094526563372, 47.31225749424526, 39.322228636060444, 24.969553674970353, 19.25744308744158, 18.757547991616384, 13.906680515834264, 9.87689208984375, 6.4840845465660095, 4.6682818446840555, 6.020417358194079, 6.10128961290632, 7.252206598009382, 8.26193184512002, 10.621501871517726, 11.434757249695913, 10.106168746948242, 5.454828781741006, 2.244991191795894, 1.0828692593744822, 0.8553226494363376, 1.0409933349915912, 0.6914553567767143, 0.10219449842614786, 0.33104583621025085, 0.5075576560837882, 0.3904453617121492, 0.13473470376006194, 0.21541553017284187, 0.11804591784519808, 0.1449689795928342, 0.06332672334143094, 0.025303339286308204, 0.1073159993227039, 0.32642628837909016, 0.3288341648876667, 0.14388024301401206, 0.08265140745788813, 0.05868213078273194, 0.10143970285675355, 0.07146391884556838, 0.12215793505311012, 0.06915998711649861, 0.190665137554918, 0.3219298268003123, 0.5862551246370588, 0.26726867418204037, 0.04641045177621501, 0.12841344438493252, 0.20805987130318368, 0.08140023638095174, 0.0006099147722125053, 0.1440398615917989, 0.6425033978053502, 0.5953086274010795, 0.5435342341661453, 0.15684977493115834, 0.1731043934289898, 0.12754475671265805, 0.1063238318477358, 0.1235670487263373, 0.2238752469420433, 0.11212949281824486, 0.1319907759981496, 0.200045395642519, 0.5398314414279801, 0.897429167159966, 0.4761781798941748, 0.28156863685165134, 0.2132510577461549, 0.28070792875119616, 0.1700694691389799, 0.1862502358853817, 0.6127411691205842, 0.4913582567657743, 0.586691504078252, 0.9650552783693586, 0.4670918903180531, 0.31380670411246164, 0.3450934924185276, 0.29388757582221714, 0.3788267251636301, 0.19638073657240185, 0.22257597451763494, 0.21472199953028134, 0.40712934359908104, 0.4396827125123569, 0.6321981879217284, 0.8242875976221902, 0.8141628237707275, 0.6510755206857408, 0.4874486465539251, 0.6736760565212795, 0.9035329424909183, 0.650968040738787, 0.3473609393196446, 0.33260016994816916, 0.6735816044466836, 0.9697494379111699, 0.510644827570234, 0.5503980772835868, 1.8361053381647383, 9.866930978638784, 29.79507759639195, 51.91178778239659, 66.23804569244385, 74.21511963435582, 64.23009967803955, 58.18258564812796, 53.256684575762065, 55.86443383353097, 54.942644119262695, 53.72675452913557, 50.83975716999599, 34.18435192108154, 30.90416295187814, 33.23199013301304, 34.04121208190918, 32.343159198760986, 29.208729539598735, 32.181224482400076, 29.76710067476545, 32.57513870511736, 45.22202743802752, 55.23423569543021, 71.53942394256592, 86.67062718527657, 95.20484937940324, 92.32731546674455, 114.55383845738002, 123.92844527108329, 110.69141129084996, 103.35807405199323, 97.8380012512207, 73.65872178758893, 54.29482534953526, 61.449666840689524, 66.66524873461042, 51.496629442487446, 40.74613339560372, 28.360199894223893, 12.278461371149335, 7.343838572502136, 6.775822903428759, 2.5653845710413794, 3.6224014290741513, 1.355729034968785, 0.8693903631397656, 0.6958657258323261, 2.0089904155050005, 3.853469635759081, 1.9905794262886047, 1.6874727308750153, 3.7293027213641574, 0.656108024929251, 0.7090727314352989, 2.978948082242693, 0.17849198861845902, 0.7524286764008659, 1.9467701656477792, 5.2687938043049405, 16.816365480422974, 30.248669896806987, 68.17161818913051, 80.21385383605957, 94.56187002999442, 106.26276847294399, 101.27257919311523, 88.61198166438511, 83.6899333681379, 86.96081869942802, 73.16034139905656, 75.62465204511369, 76.72266892024449, 82.4841638292585, 73.42861134665353, 71.84998062678746, 71.50259849003383, 56.93410553250994, 39.803509507860454, 35.801565987723215, 36.927365234919954, 28.183486359460012, 19.00410829271589, 18.885325363704137, 22.06685859816415, 30.033115931919642, 26.38537073135376, 20.648272684642247, 25.564170088086808, 26.45950279917036, 21.76258134841919, 16.314913988113403, 7.477471538952418, 1.4289834584508623, 0.5158819779753685, 0.7343142341290201, 1.048576099531991, 0.911166787147522, 0.38525212609342163, 0.33067774453333443, 0.48152080178260803, 0.360576223049845, 0.1802399762506996, 0.39860520671520916, 0.386602627911738, 0.23231437695877893, 0.22592871103967938, 0.40846784891826765, 0.5382702137742723, 0.4442790544458798, 0.4765920862555504, 0.19172255295727933, 0.17872848521385873, 0.22653266148907797, 0.23069826939276286, 0.22871379873582295, 0.4465641975402832, 0.12356086048696723, 0.4218551819877965, 0.8361634803669793, 0.6910149604082108, 0.6118166787283761, 0.17736201068120344, 0.18876753295106546, 0.19202370036925587, 0.07528787079666342, 0.13221843806760653, 0.29774667588727816, 0.6965688509600503, 1.0222196280956268, 0.8213310305561338, 0.4534344731697014, 0.5999790110758373, 0.3200804931776864, 0.17753469784344944], [0.06703885272145271, 0.026595675386488438, 0.06386767181434802, 0.10135099797376565, 0.21338308709008352, 0.3377009076731545, 0.3525983339973858, 0.38918730350477354, 0.22840278542467526, 0.12908902099089964, 0.04577108858419316, 0.021223779801013212, 0.024213023417230164, 0.11579495934503418, 0.22029066857482704, 0.19876433509801114, 0.26749682479671066, 0.06367973118488278, 0.03558888352875199, 0.1613298702452864, 0.03870976124224918, 0.04830492494095649, 0.08336163684725761, 0.03932658689362662, 0.11556576378643513, 0.2653711645730904, 0.18127774127892085, 0.02020100870036653, 0.12867014775318758, 0.1543008852750063, 0.031241299318415777, 0.2928833711360182, 0.5540378476892198, 0.20523332511740072, 0.275951153997864, 0.34213852669511524, 0.04792720145945038, 0.08730562842850174, 0.14389454653220518, 0.10636627421315227, 0.2939545879406588, 0.6773290176476751, 0.10601643512823752, 0.543599753507546, 3.711837989943368, 21.216845512390137, 19.09747471128191, 21.390025888170513, 31.055029187883648, 25.5535706111363, 24.79490896633693, 22.217188085828507, 20.223256587982178, 9.871046917779104, 1.6147092410496302, 2.9157192579337528, 1.6996218732425143, 3.1314002445765903, 6.3263669524874, 5.2429973142487665, 4.939085279192243, 12.755320583071027, 15.4801504611969, 18.600676774978638, 19.039780344281876, 22.035511800221034, 24.96247693470546, 31.061796733311244, 34.27625574384417, 34.884681701660156, 45.92077997752598, 49.93441384179251, 48.27150494711739, 48.44270856039864, 42.794966084616526, 44.654192856379915, 57.43766232899257, 69.09381784711564, 50.01728848048619, 20.723697117396764, 2.4718876566205705, 5.6931615471839905, 2.724441864660808, 2.458825260400772, 2.025251588651112, 4.344802813870566, 2.83599237033299, 0.38324067688414026, 0.5011315494775772, 1.607149492417063, 1.6702384842293603, 2.390065235751016, 0.7333407806498664, 0.773325220814773, 0.740110171692712, 0.7886061008487428, 4.1379558103425165, 0.6673107466527394, 1.182192672576223, 1.256600279893194, 8.337530851364136, 11.114007558141436, 24.68098282814026, 33.206663949149, 45.428687708718435, 53.44130168642317, 63.06767300197056, 60.74651609148298, 47.70916291645595, 32.17586742128645, 31.86341040475028, 24.985576220921107, 32.1518440246582, 20.366568395069667, 18.604696307863506, 18.366565908704484, 17.209650891167776, 14.663909094674246, 9.502982599394661, 3.2032211678368703, 2.4671730867453983, 1.9835068115166254, 3.576525730746133, 4.25736711706434, 0.721543336553233, 1.3756153221641267, 2.0845989755221774, 0.6308565342000553, 1.1256336846521922, 1.7378113440104892, 0.20253244361707143, 2.2247736709458485, 0.6223552503756115, 0.048641474917531013, 0.22761443629860878, 0.06802428234368563, 0.26614466735294884, 0.3620395245296614, 0.18680290265807084, 0.06425009415085826, 0.2095591758510896, 0.16903515106865338, 0.14413803203829698, 0.07345767864691359, 0.19294870644807816, 0.06816467802439417, 0.12798554663147244, 0.14573011946465286, 0.10253700254751102, 0.061688522675207684, 0.22419147140213422, 0.04145377382103886, 0.02033787769531565, 0.15753163477139814, 0.18669908680021763, 0.055620302579232624, 0.02659197906697435, 0.1882126270128148, 0.16060011940343039, 0.10709373839199543, 0.1768010114984853, 0.07554863180433001, 0.16509047416704042, 0.29519451569233623, 0.08413709380796977, 0.11481398769787379, 0.14093436965984957, 0.08655396090554339, 0.050869814452848265, 0.15431319390024456, 0.1065849931910634, 0.4366668957684721, 0.18545108448181832, 0.042960057101611576, 0.02887523074501327, 0.09902768728456326, 0.10142363514751196, 0.022939521752830063, 0.07729636159326349, 0.16659245214291982, 0.21684574628514902, 0.6234983376094273, 0.6262709402612278, 0.1829403827765158, 0.07660197599657945, 0.08931546272443873, 0.17546538316777774, 0.053117003690983565, 0.03896317371566381, 0.2345709130167961, 0.22529106454125472, 0.3874218910932541, 0.23022467909114702, 0.08785206624971968, 0.04095479613170028, 0.2827544446502413, 0.48444289926971706, 0.10982208020452942, 0.09019015543162823, 0.09727772511541843, 0.09753273893147707, 0.1314142383635044, 0.1462190853697913, 0.2403410119669778, 0.1679711810180119, 0.21494189915912493, 0.06266015768051147, 0.10163896145032984, 0.5804334027426583, 0.5408595576882362, 0.11455178819596767, 0.029810526807393347, 0.14534937989498886, 0.23658876759665354, 0.1942070224987609, 0.2001920270600489, 0.11509456192808491, 0.7538311811430114, 3.438285674367632, 8.180667451449803, 19.31602508681161, 38.48896939413888, 35.79109157834734, 38.20135566166469, 44.320456981658936, 42.12918274743216, 49.57556022916521, 31.729622840881348, 13.520586490631104, 10.637727652277265, 8.473522731236049, 6.328612523419516, 5.050432767186846, 4.031389551503318, 7.10076322725841, 14.222077488899231, 20.409096581595286, 22.942234345844813, 24.444129160472325, 29.792607511792863, 34.03042500359671, 45.72790493283953, 60.53645815168108, 70.58105196271623, 73.73051752362932, 85.2445650100708, 91.18487180982316, 94.11922809055874, 91.40993785858154, 80.71888365064348, 65.58660343715123, 58.085081577301025, 61.00610079084124, 69.25231320517403, 51.45250490733555, 36.389703205653596, 18.36890745162964, 5.733695600714002, 8.232947434697833, 8.09483027458191, 5.071519247123173, 0.4699766955205372, 1.670480476958411, 0.3794895995940481, 0.5676718960915292, 1.1090995775801795, 2.1550921414579665, 1.8221965645040785, 0.9274636783770153, 3.225847542285919, 1.2492603766066688, 0.46151395248515265, 2.188192491020475, 1.3393599476133073, 3.15831105198179, 2.7683438403265814, 1.7093290495021003, 10.011279804365975, 27.398692539760045, 49.428310530526296, 64.97881671360561, 76.90200887407575, 88.67618301936558, 82.70208018166679, 69.79299422672817, 59.115072114127024, 52.527544089726035, 50.311468260628835, 49.20061458860125, 42.3541202545166, 42.77593149457659, 38.07156678608486, 42.226499216897146, 39.87262323924473, 33.09553446088518, 22.79970942224775, 18.554457357951573, 16.52284230504717, 9.843483413968768, 3.8584858008793423, 1.0924011021852493, 6.3178927557809015, 5.911638966628483, 2.9988475058759962, 2.3138569593429565, 2.1471290716103146, 5.514967611857823, 4.908438077994755, 1.608372918197087, 0.3378422329468386, 0.11596524449331419, 0.23457145584481104, 0.4680264773113387, 0.22989349971924508, 0.2841805624110358, 0.054025355127773116, 0.42217664473823135, 0.5530877900975091, 0.46999862577234, 0.2064789661339351, 0.18156487015741213, 0.07955448542322431, 0.07328711529927594, 0.1293697716402156, 0.06531620158680848, 0.053500043494360786, 0.14057212695479393, 0.1000359021127224, 0.31058515555092264, 0.34416379087737625, 0.08410927387220518, 0.06208241225353309, 0.07783661117511136, 0.11346666142344475, 0.13431189501924173, 0.26383949390479494, 0.49063314710344585, 0.4478609865265233, 0.1969726498105696, 0.13168434958372796, 0.4699034137385232, 0.272085431431021, 0.0787592763081193, 0.09458376467227936, 0.30366360981549534, 0.48649245500564575, 0.3344991723341601, 0.3552385951791491, 0.19888287516576902, 0.3462806301457541, 0.37723162504179136, 0.19952801269079956, 0.24616248958877154, 0.05983422217624528, 0.12846136252794946, 0.2590860575437546, 0.2809751087001392, 0.5198677469577108, 0.4561190019760813, 0.3590421639382839, 0.5101023795349258, 0.30922651131238255, 0.21431855617889337, 0.0744341719629509, 0.07071715034544468, 0.40097663232258385, 0.5566298514604568, 0.36566841123359545, 0.35953741307769504, 0.2909102998673916, 0.2738332019320556, 0.45870156053985867, 0.3642739403460707, 0.1954728974295514, 0.1443108141954456, 0.17561338522604533, 0.2541135629372937, 0.2532146940273898, 0.23840629149760517, 0.4464152455329895, 0.26392433792352676, 0.20119331404566765, 0.14295264493141854, 0.37276401477200644, 0.9025240966251918, 0.5342199025409562, 0.32468766453010695, 0.41988273497138706, 0.5037420636841229, 0.3135746994188854, 0.25214825410928043, 0.5787229516676494, 0.8019527760999543, 0.9506504684686661, 2.274955298219408, 3.8833329933030263, 10.644012297902789, 29.700974668775284, 28.69794487953186, 34.201503549303325, 50.82134444372994, 52.272586890629356, 61.69926003047398, 52.10663264138358, 31.565832955496653, 20.67706080845424, 15.934501852308001, 12.27252413545336, 9.370708874293737, 7.9962440218244275, 11.547697612217494, 15.347049031938825, 22.554926122937882, 27.315001487731934, 31.815162113734655, 38.04042148590088, 44.942706380571636, 55.223247119358604, 72.33247743334088, 95.221024785723, 109.3845385142735, 117.3293936593192, 112.73643289293561, 105.0795041493007, 95.56688526698521, 71.69980921064104, 64.54381779261998, 63.47593525477818, 72.17148072378976, 86.47668211800712, 64.93955244336809, 46.17060593196324, 33.45618070874895, 14.941969054085867, 12.146985820361547, 9.50990126814161, 7.27481039081301, 7.552608489990234, 3.6632244842393056, 0.6766276838524001, 2.238799261195319, 3.43987637758255, 4.648901147501809, 4.557829805782863, 1.2405634032828468, 7.473518013954163, 3.4530896799904958, 1.4883234628609248, 9.226960199219839, 1.8170442581176758, 3.7496843934059143, 8.299755232674734, 17.83208441734314, 23.577282326562063, 43.743704387119834, 54.40966517584664, 62.66297517504011, 66.95833764757428, 75.1960802078247, 83.54235363006592, 80.41413566044399, 69.84751674107143, 61.98649161202567, 66.50459943498883, 62.869572911943706, 41.354257106781006, 42.923059599740164, 38.57825027193342, 50.866959367479595, 47.74357039587838, 42.18439660753523, 33.72817489079067, 27.009376287460327, 23.2066011428833, 14.421305792672293, 11.713625805718557, 11.421292509351458, 16.36804859978812, 14.203834124973842, 9.12981482914516, 8.139608808926173, 4.533225800309863, 8.75531474181584, 6.512580411774771, 2.094874058450971, 0.349026688507625, 0.2913114497704165, 0.19894642675561564, 0.5976642838546208, 0.27392719260283876, 0.3233649283647537, 0.15603265592030116, 0.4442062069262777, 0.3530101233295032, 0.3127182796597481, 0.1924715470522642, 0.21962984332016536, 0.15907040291598865, 0.2839428037405014, 0.29477784090808457, 0.22577595923628124, 0.29285913386515205, 0.3327064556734902, 0.1694557884974139, 0.40215796179005076, 0.4530814992530005, 0.24987437469618662, 0.16337044217756816, 0.1506275273859501, 0.2844348501946245, 0.3445404592369284, 0.4517396284001214, 0.46164309126990183, 0.37998389878443306, 0.27249179248298916, 0.49205872203622547, 0.5453769181455884, 0.25546325051358765, 0.20990389878196375, 0.28214229749781744, 0.6391014946358544, 0.4535287623958928, 0.3125402592122555, 0.4934423906462533, 0.35588627042514936, 0.47259578640971867, 0.3689819962850639, 0.26409413452659336], [0.06693275698593684, 0.06718775723129511, 0.05730659102222749, 0.07260773211185421, 0.15442063313509735, 0.14782715908118657, 0.023636947186397653, 0.09850769875837223, 0.04945842429463353, 0.1232462509402207, 0.1378315511558737, 0.06606158587549414, 0.046167006982224326, 0.10347856488078833, 0.24550944034542355, 0.13906085304915905, 0.12124839957271304, 0.11189844485904489, 0.07153745168553931, 0.07703648268112115, 0.003320499535350661, 0.039391020578997474, 0.012082470364735594, 0.020089235323082124, 0.06415621204567806, 0.054045103889490874, 0.10064065323344298, 0.05468308626274977, 0.06229484121182135, 0.027317302467833673, 0.10642004132802997, 0.09967883662985903, 0.17243176166500362, 0.03637679839240653, 0.25841338506766726, 0.21656339429318905, 0.35111196232693537, 0.18855101242661476, 0.3554628645735127, 0.1870513686111995, 0.06596198372010674, 0.22914621553250722, 0.06660174724778958, 0.20781520514615945, 0.5857285814625877, 1.223688617348671, 1.8284742619310106, 1.8983809564794814, 10.25463785443987, 21.919226748602732, 27.918897220066615, 19.635388612747192, 11.067525846617562, 4.067866725581033, 1.777002983859607, 0.7757485136389732, 0.880004767860685, 0.6644829926746232, 2.8462227242333547, 3.2853820962565283, 7.070884670530047, 6.387314813477652, 8.865661689213344, 9.36610916682652, 6.782021999359131, 14.015415481158666, 8.765807390213013, 17.200887475694927, 25.11617282458714, 27.67332182611738, 18.097668886184692, 15.082720449992589, 17.897649356297084, 21.55950461115156, 24.46710511616298, 44.791673387799946, 56.68690252304077, 68.06434495108468, 66.01548099517822, 39.36793736049107, 6.597457000187465, 6.555092096328735, 3.150405739034925, 3.217585048505238, 3.830359058720725, 3.3206737339496613, 5.999747770173209, 1.2591438634055, 0.7473980720554079, 0.6444060642804418, 0.6730367679681096, 0.548840269446373, 0.38818795712930815, 0.4230025032801287, 0.5930217472570283, 4.272159831864493, 3.5875488306794847, 5.1756670985903055, 5.771651004041944, 7.834627185549055, 11.606055532182966, 19.126245464597428, 33.015220233372276, 55.456459930964876, 63.38785988943917, 62.357469831194194, 62.01229722159249, 50.56780120304653, 32.924692153930664, 21.453782558441162, 17.844806568963186, 12.49757194519043, 16.28005313873291, 18.388246025357926, 12.628041744232178, 11.780978168760027, 11.205398951257978, 9.812667284693037, 8.595749361174446, 7.600176726068769, 4.13408088684082, 1.8676603649343764, 2.993987023830414, 1.9508439813341414, 0.6903877226369721, 1.240073989544596, 0.6469453051686287, 0.7503143612827573, 0.7995161297065871, 1.3093727167163576, 1.567831807902881, 0.7787454128265381, 0.5851540522915977, 0.22562585371945584, 0.20878578163683414, 0.03288867717076625, 0.04760906692328198, 0.134455337322184, 0.02005590059395347, 0.11598541055406843, 0.18440251717610018, 0.1749255678483418, 0.3356989308127335, 0.08041048449065004, 0.14635429025760718, 0.11041005793958902, 0.14830224215984344, 0.04814797639846802, 0.012492217306446816, 0.04968954689268555, 0.08317250878150974, 0.12512101605534554, 0.03725008313943233, 0.08693995233625174, 0.03364051093480416, 0.1325329119073493, 0.07410445822668926, 0.14097016916743346, 0.1526251616222518, 0.0952039524646742, 0.06253538187593222, 0.13750892132520676, 0.08777126629969903, 0.1779603428606476, 0.05706488327788455, 0.0577560526185802, 0.08305818241621767, 0.06108354763793094, 0.06063250505498477, 0.09194428380578756, 0.08669232098119599, 0.08416487303163324, 0.11832341152642455, 0.06262726908815758, 0.04615250668887581, 0.14267741755715438, 0.1203895913703101, 0.03388988273218274, 0.11955309339932033, 0.19070704387766974, 0.2600457231913294, 0.17131744431597845, 0.13773826616150991, 0.10486457443663053, 0.11122655269822904, 0.17147595009633473, 0.1390008841242109, 0.047498404647090604, 0.13555706106126308, 0.012898583447427621, 0.23178340973598616, 0.06565650725471121, 0.05965550962303366, 0.04138769468824778, 0.033704048953950405, 0.12699978452708038, 0.07665786014071532, 0.020401453033887913, 0.01983286443698619, 0.05613202654889651, 0.18409002465861185, 0.15606168364839895, 0.09047136069940669, 0.07191802840679884, 0.11997242804084506, 0.06070590897330216, 0.08751838986894914, 0.17738407664000988, 0.3259962328842708, 0.06090593431144953, 0.04475814775962915, 0.27157273037093027, 0.5282494457704681, 0.1814552460397993, 0.09108540096453258, 0.035499303335590024, 0.38836573330419405, 0.6020018053906304, 0.9901000601904733, 1.71211581996509, 2.2718327343463898, 3.7897407582827976, 7.4413226672581265, 9.713609422956194, 15.00022622517177, 30.30713551385062, 41.24236331667219, 27.96023552758353, 22.406833955219813, 21.20896625518799, 7.124285919325692, 1.3923354021140506, 1.96576241510255, 4.481992823737008, 9.943573083196368, 20.142419508525304, 22.774880034582957, 22.72862066541399, 21.780617134911672, 24.046075548444474, 29.601625851222447, 35.28273705073765, 44.81395278658186, 50.50820302963257, 58.71225724901472, 67.71063300541469, 72.42418670654297, 68.67787783486503, 64.8032009942191, 59.29157025473458, 55.739508696964805, 62.27975422995431, 67.82877322605678, 73.38638019561768, 63.10633972712925, 40.796698910849436, 18.108574083873204, 5.055129315171923, 4.213771513530186, 4.834152715546744, 5.524854029927935, 3.1659139011587416, 2.8574818457875932, 0.6057758171643529, 2.083867460489273, 2.172330839293344, 0.7289260689701352, 0.7470032732401575, 1.0375321550028664, 0.7258114846689361, 1.4858500127281462, 3.2219100849969045, 6.367245376110077, 5.8197833469935825, 8.50926079068865, 11.08766520023346, 15.621158940451485, 25.67319600922721, 41.39085326875959, 59.22893224443708, 59.71415274483817, 67.00564098358154, 75.30129677908761, 72.62793568202427, 62.94404370444161, 49.440115519932334, 42.589879580906455, 38.52086162567139, 34.22105230603899, 22.545832668031963, 19.755073070526123, 20.7170216356005, 27.722216299601964, 24.98598963873727, 18.371415751320974, 17.795118263789586, 12.82786238193512, 8.823950784546987, 2.897040545940399, 1.055050409265927, 1.822191787617547, 1.9647451554025923, 0.8444603894438062, 0.8045296349695751, 0.1545676581029381, 1.182232516152518, 1.8341125079563685, 1.016526447875159, 0.22000786874975475, 0.052561761877898655, 0.14018447989864008, 0.05915311550987618, 0.046096120428826125, 0.03880941089508789, 0.038051673876387734, 0.021018485638446043, 0.33321902102657724, 0.3897177278995514, 0.3058209983365876, 0.034604519206498346, 0.1202033877904926, 0.0539498036461217, 0.13627453041928156, 0.031476296351424286, 0.020006535475009253, 0.06570018455386162, 0.07799931030188288, 0.058471472800842354, 0.1012401185663683, 0.09137460616018091, 0.07089979161641427, 0.07899531149970633, 0.009936750949626523, 0.20376823230513505, 0.16542529048664228, 0.11165357514151505, 0.16692698347781385, 0.19641802885702678, 0.029668573888817003, 0.19366044897053922, 0.34758246743253296, 0.11023279745131731, 0.043906155441488535, 0.05837521582309689, 0.278578197317464, 0.3025914430618286, 0.052272750064730644, 0.057191687902169566, 0.041248890172157965, 0.06240884866565466, 0.13006460507001194, 0.1389280366046088, 0.19050085065620287, 0.14993569308093616, 0.19435103477111884, 0.33204330982906477, 0.28568267609391895, 0.24349619980369294, 0.14757399766572885, 0.24417655329619134, 0.28060468286275864, 0.24740581001554215, 0.20462056728346006, 0.23613094644887106, 0.24868715554475784, 0.21401567171726907, 0.26272096963865416, 0.19288755687219755, 0.18225104548037052, 0.21894046531191894, 0.15426785419029848, 0.20425322199506418, 0.1453455529574837, 0.1306793306555067, 0.12183331032948834, 0.1321603147579091, 0.41434168230210033, 0.567898092525346, 0.31472090791378704, 0.12585996783205441, 0.22918193361588887, 0.10324675017701727, 0.13420923267092022, 0.3112851322761604, 0.6247226861970765, 0.09831561227994305, 0.3184962767575468, 0.4021864059780325, 0.6000702604651451, 0.601109830396516, 0.37771224496620043, 0.18538176534431322, 0.47796886094978874, 0.8923401002373014, 1.3557567191975457, 1.1730689278670718, 1.4911294494356429, 1.2044583920921599, 2.9731472049440657, 5.871773677212851, 12.653067418507167, 29.466545922415598, 49.239336899348665, 36.503486905779155, 33.06898191996983, 33.62782205854143, 10.769403832299368, 2.765248634985515, 4.624853866440909, 4.293629331248147, 10.46006395135607, 22.38193334851946, 26.523064919880458, 23.07342849458967, 26.16367977006095, 29.7093402998788, 37.94446338926043, 46.37912137167794, 59.12138107844761, 62.73734869275774, 76.40397589547294, 78.4464475086757, 73.47147478376115, 62.89593437739781, 56.829681055886404, 55.093413080487935, 55.136238302503315, 75.74687780652727, 77.89248153141567, 80.78639929635185, 85.29747554234096, 76.29310349055699, 48.38443749291556, 23.156940630504064, 9.573860304696218, 7.972891126360212, 10.63982253415244, 9.140811221940176, 14.240518007959638, 2.3687221067292348, 3.3319482718195235, 3.8911401629447937, 3.602142653294972, 1.0344867812735694, 0.8548621141484806, 1.584557641829763, 5.9476189102445325, 10.163550445011683, 17.003325871058873, 9.425084607941763, 11.779935938971382, 22.807981252670288, 27.956389699663433, 49.15079253060477, 65.8522539138794, 78.40543229239327, 83.3506111417498, 75.06723976135254, 79.11953340257917, 70.81351089477539, 71.08458791460309, 61.700601032802034, 43.849619252341135, 49.48357302801949, 41.10786703654698, 32.55410303388323, 23.324213300432476, 22.717687674931117, 28.0456497328622, 23.86058643886021, 22.130863666534424, 23.787442752293178, 17.676338808877126, 9.426666191646031, 3.8110361184392656, 2.505285693066461, 2.6064251916749135, 4.671653458050319, 1.9290952512196131, 0.6210200563073158, 0.42250006166952, 1.3228461423090525, 2.0070603362151553, 0.9696427179234368, 0.5607298857399395, 0.21155223676136561, 0.16821463938270295, 0.1662035837237324, 0.09148579769368682, 0.2069286855735949, 0.14625263214111328, 0.28203793881194933, 0.3828088029154709, 0.36427947719182285, 0.34450688532420565, 0.2881375886499882, 0.1726865651352065, 0.22012544529778616, 0.3248669063406331, 0.15005617375884736, 0.10256038486425366, 0.19883227002407822, 0.08429718736026968, 0.1767676682876689, 0.20391312667301723, 0.14723889636141912, 0.10393692207123552, 0.17714589727776392, 0.1250530132757766, 0.2837158202060631, 0.2534363849886826, 0.2356688641011715, 0.17232709085302694, 0.16696274227329663, 0.09802283799009663, 0.28665971223797115, 0.33260513682450565, 0.20435554507587636, 0.1468734374003751, 0.3053504207304546, 0.2567961375628199, 0.3382517152598926, 0.14491142625255243, 0.17044112991009439, 0.1707110104284116, 0.12228889231170927, 0.3708293214440346, 0.22588273350681576], [0.03493383939244917, 0.031744765516902716, 0.055000545656574626, 0.17339536281568663, 0.0954011483117938, 0.16651741974055767, 0.1463753655552864, 0.08753277481134449, 0.027173229127324054, 0.01312665009338941, 0.021278727566823363, 0.08054764355931963, 0.05813662933983973, 0.028099892527929375, 0.018115644975166236, 0.02640720210703356, 0.0355581492850823, 0.014881976081856658, 0.028860557425235, 0.045323981504355154, 0.07491842204970972, 0.08463104016014508, 0.08556498254516295, 0.10977505772773709, 0.26725312215941294, 0.08075387070753745, 0.11064905832920756, 0.08429774375898497, 0.10161597946924822, 0.05403898689629776, 0.12592423866902078, 0.0480749422817358, 0.13972579022603376, 0.02952983383355396, 0.0924854086978095, 0.044264371041208506, 0.102810621793781, 0.02384339316215898, 0.08649780534740005, 0.19254530380879128, 0.1889070397508996, 0.17040359335286276, 0.11782605892845563, 0.2748934807521956, 0.3037136856998716, 0.17677331369902405, 0.14477551568831715, 0.23893796439681733, 1.5060195475816727, 1.5109906579766954, 5.545660410608564, 7.028670021465846, 7.232701701777322, 3.349366537162236, 1.2690023801156451, 1.4217413727726256, 0.33391147958380835, 1.81290845147201, 0.8246343561581203, 1.207749992609024, 3.5557471428598677, 5.644941048962729, 6.1216491375650675, 8.854930196489606, 13.277792113167898, 10.054464595658438, 10.103384256362915, 12.849503414971487, 10.209675192832947, 8.075412665094648, 7.924577695982797, 3.4123717163290297, 7.36987520967211, 8.04436811379024, 17.875566244125366, 27.382899284362793, 42.49008955274309, 57.90153796332223, 64.15025792803083, 51.808652196611675, 17.914695024490356, 2.6494951205594197, 5.2943835854530334, 3.4301545449665616, 0.7254100090691021, 2.7463406324386597, 2.716519615479878, 2.9581158629485538, 1.254956488098417, 1.5911433398723602, 0.0571267588862351, 0.8002831456916673, 0.670098385640553, 1.3109176052468163, 5.149265246731894, 7.518007329532078, 4.528712945325034, 8.254988857678004, 13.10921665600368, 17.01185999597822, 22.692950350897654, 38.9615615436009, 51.256211348942344, 54.25802768979754, 57.328947339739116, 61.937451226370676, 57.87784113202776, 44.84449706758772, 21.452705587659562, 10.911605664661952, 16.076833963394165, 17.117559467043193, 6.445547665868487, 2.5830998718738556, 2.272626348904201, 8.213790382657733, 4.235376068523951, 2.439809343644551, 3.4836257100105286, 1.9086799238409315, 0.28570200077125, 0.5583171780620302, 0.35322144627571106, 0.1541787896837507, 0.11874913796782494, 0.1998803759259837, 0.012148418031366808, 0.18561522210282938, 0.16733725289148943, 0.10078666718410594, 0.06356181536934205, 0.10454667399504355, 0.16784133655684336, 0.09116155294967548, 0.08966291336608784, 0.034901334172380824, 0.029081566458834068, 0.018125711042167883, 0.07576600728290421, 0.15773759729095868, 0.07891147849815232, 0.035870689300021956, 0.05916290677019528, 0.007995234103873372, 0.06595575476863555, 0.025083002002377595, 0.04231677197718194, 0.015516530156933835, 0.08415717844452177, 0.03663087243746434, 0.01799391070380807, 0.0459198709577322, 0.04091916965054614, 0.03129248460754752, 0.06259030250034162, 0.020226048338892202, 0.08253164602709667, 0.041652957775763104, 0.09998628763215882, 0.028612233964460235, 0.05572094289319856, 0.019867975231526152, 0.11419771505253655, 0.05331240820565394, 0.06411581207066774, 0.04589780160625066, 0.035996703431010246, 0.028145761495190005, 0.05173538425671203, 0.039137835414814096, 0.10778054475252118, 0.0676976762978094, 0.08950562894876514, 0.02526005044845598, 0.020978728575365882, 0.032945996416466575, 0.02944789394470198, 0.13348746140088352, 0.11187209734427077, 0.10655700362154416, 0.11004961335233279, 0.12661825785679476, 0.09888207366956131, 0.14171811831848963, 0.11356965625392539, 0.021276859899184535, 0.019623767085639492, 0.0663603109174541, 0.0478713682054409, 0.02573788329027593, 0.026942120099972402, 0.029338198580912182, 0.06783575138875417, 0.012887053441123238, 0.004171784268692136, 0.0845508508916412, 0.05865743889340332, 0.05685017444193363, 0.030956005877149955, 0.1285782741116626, 0.24244525762540953, 0.15893295886261122, 0.20631587345685276, 0.1495294813066721, 0.08996015241635696, 0.10645143035799265, 0.08049521315842867, 0.1772764338446515, 0.12033872838531222, 0.12791385262140206, 0.06896308303943702, 0.03004955094573753, 0.16049006102340563, 0.022991992865822146, 0.08646541208560977, 0.13340611862284796, 0.1611626927873918, 0.24557968229055405, 0.4628535977431706, 0.4900310965520995, 0.37429535974349293, 0.36753571246351513, 0.40813650669796125, 0.7303549551538059, 2.937393294913428, 5.96106367451804, 12.329587953431265, 11.050867540495735, 13.006211348942347, 4.660947586808886, 6.3585075821195325, 1.6502261523689543, 0.3611517021698611, 3.975536891392299, 6.509565327848707, 10.384309479168483, 13.679516111101423, 13.185083167893545, 11.99290691103254, 14.008747816085815, 18.688298770359584, 19.95879772731236, 22.659753595079692, 27.451646498271398, 31.907312597547257, 38.601526737213135, 39.34981298446655, 40.99442032405308, 36.899839946201865, 34.56402233668736, 42.01830686841692, 54.76465559005737, 62.90389701298305, 66.36702510288784, 65.73567008972168, 50.533213070460725, 22.205433470862253, 6.358021642480578, 1.248591503926686, 2.2843916032995497, 3.57831033212798, 5.7892842292785645, 6.862116055829184, 1.2005979078156608, 4.7561022979872565, 1.207028791308403, 0.6156700519578797, 1.6354909773383821, 2.033029011317662, 3.352183380297252, 6.469688747610364, 8.877512710435049, 2.741462345634188, 5.020364872046879, 8.48229570048196, 15.956298351287842, 24.15789290836879, 40.09678602218628, 54.62989180428641, 68.02870764051164, 71.61816092899868, 66.63542011805943, 66.48084354400635, 66.33172825404576, 53.48314026423863, 38.95830978666033, 30.336502075195312, 33.25686468396868, 20.78391020638602, 10.855016929762703, 13.422173074313573, 14.375125459262303, 12.221973385129656, 8.950837918690272, 8.497934358460562, 6.234026261738368, 3.4793167412281036, 1.647128558584622, 0.5726269387773105, 0.2613953836262226, 0.34300642726676805, 0.48320058307477404, 0.1375662846756833, 0.037863960556153736, 0.055082672142556736, 0.1741569098085165, 0.14072858355939388, 0.2157437511320625, 0.14361328019627503, 0.029684950331492082, 0.09092342787023101, 0.06616567993270499, 0.046116120248500786, 0.05604250742388623, 0.06637510298086063, 0.07180715578475169, 0.12811666673847608, 0.16107661383492605, 0.13470750807651452, 0.029775314232600585, 0.018794731303517307, 0.07018504996917077, 0.06964669350002493, 0.03281507647729345, 0.09688387624919415, 0.024728920377258743, 0.085712055010455, 0.027159325944791948, 0.05809140498084681, 0.05662025285086461, 0.04790625169074961, 0.020018116371440034, 0.028687011916190386, 0.13994845827775343, 0.28411759436130524, 0.07489661393421036, 0.12383113455559526, 0.06109158827790192, 0.016627970517479947, 0.0470071690423148, 0.028019657458311746, 0.06230534493391003, 0.06340159968073879, 0.08351594928119864, 0.016979292201410447, 0.001049612885773448, 0.051831247684146674, 0.04704529931768775, 0.041185338582311354, 0.08492744461234127, 0.11054572423121758, 0.05005735358489411, 0.16290020383894444, 0.20534680331391947, 0.15913337096571922, 0.27674113160797525, 0.2573609772537436, 0.2892873798097883, 0.28851615690759247, 0.19729392257119927, 0.1300686898508242, 0.12730944076819078, 0.12241965958050319, 0.12433699598269803, 0.16961966827511787, 0.09194771719298192, 0.13849838823080063, 0.14846484629171236, 0.09960213503135101, 0.15788360445627145, 0.09357657443199839, 0.1861433530492442, 0.19276586840195314, 0.2011103020714862, 0.14664150056030067, 0.2742845362850598, 0.3527989089488983, 0.343026729034526, 0.2655853373663766, 0.23884345803941998, 0.11651312080877167, 0.28738018072077204, 0.354716421770198, 0.39722517505288124, 0.38649389946034973, 0.20144035507525715, 0.17375379215393746, 0.18384416427995476, 0.15386542864143848, 0.11335540882178716, 0.25430005150181906, 0.39468077729855267, 0.26722549221345354, 0.3145124619560582, 0.40381768558706554, 0.5543231038110596, 0.4871366290109498, 0.3803871385753155, 0.8740379480378968, 0.3578993209770748, 1.881195672920772, 3.2452384446348463, 8.307201964514595, 10.069609063012258, 16.964141505105154, 7.9550672599247525, 9.01559773513249, 3.0096660682133267, 0.552814421909196, 4.326462609427316, 5.876075480665479, 8.697082757949829, 11.306237288883754, 12.857477341379438, 13.331399202346802, 16.16835389818464, 21.751427752631052, 21.35181427001953, 26.875689472470963, 31.884473868778773, 31.32690872464861, 35.636261395045686, 37.92692961011614, 36.82438250950405, 40.81182166508266, 41.9652886390686, 55.244206360408235, 63.9568270274571, 73.63896111079625, 78.92543547494071, 74.33102253505162, 67.88399750845772, 51.638417857033865, 25.894926922661917, 12.148437125342232, 2.5598394743033817, 4.5045614412852695, 9.906189169202532, 13.773394959313528, 20.524407148361206, 11.754610623632159, 1.9652495511940546, 0.8811298874872071, 1.4935543707438876, 2.4096341856888364, 4.827039497239249, 14.687618085316249, 20.129667827061244, 13.736786637987409, 12.929358192852565, 19.549036400658743, 30.78635277066912, 47.7003630229405, 66.47737639290946, 76.09046622685024, 77.23136043548584, 79.46930571964809, 80.28594834463937, 79.12493910108293, 77.86734294891357, 59.48463290078299, 50.56684235164097, 49.4001772744315, 41.911172594342915, 29.185317584446498, 20.082975932529994, 14.832107612064906, 14.44483586720058, 7.241857690470559, 5.111650305134909, 5.255410705293928, 2.973377364022391, 2.335263707808086, 1.5166397605623518, 0.7187550461718014, 0.314403407807861, 0.2823048744882856, 0.305763485708407, 0.1345166497464691, 0.25767646889601437, 0.18412183438028606, 0.10088831851524965, 0.13254916960639612, 0.17294856107660703, 0.33997500421745436, 0.36518209161502974, 0.12057613421763692, 0.11639771557279996, 0.14091328079146997, 0.17305477894842625, 0.23717225342988968, 0.35083197163684027, 0.16754436892058167, 0.1829000777964081, 0.15716416734669889, 0.15118514746427536, 0.16264240124395915, 0.15172861330211163, 0.12805869270648274, 0.11977890985352652, 0.2523069498794419, 0.09999820270708629, 0.18384056804435595, 0.1638908649661711, 0.12805979193321296, 0.14333825638251646, 0.21345878445676394, 0.13044423184224538, 0.1285626542355333, 0.22302474400826863, 0.4093606381544045, 0.13571377550917013, 0.19532661885023117, 0.14700861514679023, 0.2023036823208843, 0.16679584980010986, 0.10781874627407108, 0.22262139565178327, 0.15962541741984232, 0.11315020626144749, 0.1433914942400796, 0.16839461401104927, 0.20767930815262453, 0.17869047368211405, 0.19486179522105626, 0.17555166568074906, 0.1369729736553771, 0.10897924471646547], [0.02926525267373238, 0.06954109309507267, 0.07607018096106392, 0.03722744721121021, 0.01933688926510513, 0.1378233137407473, 0.043482936186982055, 0.11100404749491385, 0.033147199012871296, 0.042381714563816786, 0.09940424029316221, 0.12599564769438334, 0.016476730150835853, 0.02028557112706559, 0.04864027051787291, 0.007309874719274896, 0.04663263128272124, 0.024029087840712497, 0.11504311540297099, 0.033757551440170834, 0.09811036900750228, 0.16499376935618265, 0.08521278894373349, 0.11188101329441581, 0.03534855999584709, 0.046447564249059985, 0.042514626003269634, 0.08578489574470691, 0.006905679466269378, 0.012472686524103795, 0.0687266339414886, 0.06787220228995595, 0.050231994927993844, 0.04767380594941122, 0.03382343040513141, 0.11099489405751228, 0.04428904935983675, 0.09508869650640658, 0.04215344859819327, 0.01456217743855502, 0.07725438741700989, 0.05147940692092691, 0.12153844615178448, 0.054236878241811476, 0.019351491338706443, 0.10388831860784974, 0.09286671145153896, 0.016774367840428437, 0.0799474793353251, 0.11363637660230909, 0.032652384135872126, 0.1320823917963675, 0.2787761666945049, 0.6274465428931373, 0.46638577963624683, 0.08038715645670891, 0.7471665559070451, 0.4224034925656659, 0.3482598896537508, 0.13957886025309563, 0.5386616470558303, 1.2954175855432237, 1.1287126051528114, 2.3784877998488287, 3.833330716405596, 3.8065406339509145, 4.969196600573404, 4.222476737839835, 4.801584337438856, 5.0795235718999585, 9.911313465663365, 4.952932604721614, 5.557840168476105, 15.614377498626709, 13.912794930594307, 21.45697178159441, 37.294667857033865, 51.58043513979231, 53.37921953201294, 54.25744751521519, 38.70995685032436, 17.891984837395803, 0.48463473469018936, 6.08842545747757, 4.049529126712254, 2.711209454706737, 2.7755808234214783, 7.525337679045541, 6.054939917155674, 8.721967731203351, 6.332205176353455, 4.256568074226379, 5.383419539247241, 7.134401627949305, 12.367448687553406, 13.748879977634974, 14.623229128973824, 18.1106915473938, 20.307880435671123, 22.94242021015712, 27.453583308628627, 42.93061923980713, 47.447775159563335, 54.15916524614607, 57.382636070251465, 59.579170090811594, 52.66563606262207, 34.3868293762207, 24.237347296306066, 22.632643461227417, 15.390615974153791, 5.09858421768461, 3.4056786469050815, 3.1143456740038733, 6.7084605523518155, 2.5699999119554247, 1.0720146532569612, 2.3936913268906728, 0.5203551522323063, 0.6921630959425653, 0.20514743615474018, 0.07778829948178359, 0.10986803738134247, 0.005311272298318467, 0.019444672856479883, 0.09275578454669033, 0.019405884402138845, 0.041062411785657914, 0.13638315030506679, 0.08820723183453083, 0.15951256347554071, 0.01040500118064561, 0.055442316058490954, 0.08401963939624173, 0.0784221054720027, 0.10478697717189789, 0.025700896346409405, 0.08264810977769749, 0.0345858187813844, 0.006444196349808148, 0.04385259188711643, 0.07338269374200276, 0.03408151798482452, 0.01342944719363004, 0.030851423274725676, 0.045513472586338005, 0.04946868035144039, 0.029269177998815264, 0.051516288691865544, 0.02828352615636374, 0.07529735671622412, 0.1300152755741562, 0.05650065087580255, 0.06767447040017162, 0.07285015231796674, 0.07058997931224958, 0.041417770752949376, 0.06318359994994742, 0.12771619537046977, 0.06416487015251603, 0.04371213174558111, 0.03731667117348739, 0.09946085725511823, 0.12588056815522058, 0.031004097046596662, 0.0572556805397783, 0.038899798544922044, 0.029434065401021923, 0.02377359226479062, 0.09215951511370284, 0.008265509868838956, 0.05593905118959291, 0.031594710890203714, 0.02331365748042507, 0.037497063100870164, 0.022110894788056612, 0.04038538311475089, 0.009881023716713701, 0.07154700545860188, 0.03235505009070039, 0.019826135065938746, 0.09542696656925337, 0.08132575359195471, 0.06642500923148223, 0.057615487304116995, 0.037016375322959254, 0.05266903487167188, 0.04664192721247673, 0.013104477265317525, 0.05505161898742829, 0.025376809361789907, 0.02007088773617787, 0.041757326639656506, 0.026072010896833878, 0.06805666882012572, 0.055714479847145934, 0.04540741077757307, 0.06805723878954138, 0.036357477107750516, 0.15315436465399607, 0.050330039845513444, 0.11555464938282967, 0.1431815419346094, 0.053893254537667544, 0.04059446011004703, 0.020588609955406616, 0.08504955377429724, 0.08245670183428697, 0.06809657346457243, 0.051622906899345775, 0.04772019060328603, 0.07150494985814605, 0.04930289389033403, 0.04511735402047634, 0.06785253155976534, 0.06730878752257143, 0.03569310650761638, 0.160763076373509, 0.1973737861428942, 0.12751095209802898, 0.07634792570024729, 0.20463150526796067, 0.29069007454173906, 0.054103580037398, 0.28749450030071394, 0.33223118260502815, 0.529435362134661, 0.6034935510584286, 0.7065631289567266, 1.4826128035783768, 1.4654226345675332, 0.9236851611307689, 0.46557381749153137, 0.6514916526419776, 1.301782135452543, 2.1162812411785126, 2.321546878133501, 3.3858178726264407, 4.661903832639966, 5.263668205056872, 8.430621079036168, 8.728711826460701, 11.367232050214495, 12.553215725081307, 15.450115135737828, 20.92207166126796, 23.67430349758693, 18.220658949443273, 17.336330447878154, 23.610463448933192, 31.53064032963344, 44.97262532370431, 60.288039207458496, 66.47637585231236, 64.4089046205793, 58.45472226824079, 32.93198776245117, 6.892259078366416, 5.870489128998347, 9.34655693599156, 2.1526170628411427, 4.635561040469578, 7.7628887721470425, 8.313279032707214, 6.849548935890198, 13.053401776722499, 9.202056118420192, 8.653971791267395, 8.472646389688764, 9.138285551752363, 13.989933831351143, 14.96198855127607, 15.895110777446202, 20.277105127062114, 21.76240416935512, 29.805051735469274, 33.07172645841326, 50.497276987348286, 60.01315457480294, 64.48804460253034, 67.753739629473, 69.09026036943708, 61.10757923126221, 55.57385669435774, 41.286890847342356, 30.988771166120255, 29.045108148029872, 24.32739073889596, 16.504691873277935, 12.43225714138576, 6.868314283234732, 7.429544602121625, 6.345460167952946, 4.6065297297069, 3.6383655667304993, 1.4917049556970596, 0.48041495255061556, 0.29319642005222185, 0.16310714344893182, 0.017688432542075003, 0.038688197399356535, 0.13463016865508898, 0.03755071825746979, 0.01538456357749445, 0.055931933357247283, 0.053652622271329165, 0.051091122041855536, 0.08311082994831459, 0.05233398785016366, 0.01848233717360667, 0.019877250805231075, 0.10963887574949435, 0.08533390744456223, 0.012963218996966524, 0.01940606251758124, 0.06628594347941023, 0.11200561267989022, 0.03959093056619167, 0.05712107954812901, 0.06886938413871185, 0.034835987857409885, 0.014861888052629573, 0.04751901514828205, 0.03638887292306338, 0.01909388042986393, 0.02487052385030048, 0.07929306623658963, 0.05240369035995432, 0.05162501375057867, 0.08073178439268044, 0.0061142595451591265, 0.06413121481559106, 0.06980936548539571, 0.05931846092322043, 0.0637978437755789, 0.05451487064627664, 0.0728005717641541, 0.0691864499822259, 0.11082211190036365, 0.11614965674068246, 0.029316342967961515, 0.046539549848863056, 0.052522288103188784, 0.02862314141488501, 0.10511712517057147, 0.01668446703947016, 0.040819418217454634, 0.06401762126811913, 0.1105434647096055, 0.0336444600086127, 0.028546639984207492, 0.03427412693521806, 0.1505241050784077, 0.12959932003702435, 0.16693089183952126, 0.11186380564634289, 0.12282580350126539, 0.2535168321004936, 0.22928547805973462, 0.20816501708967344, 0.10007428683872734, 0.19270718869354042, 0.25706424031938824, 0.16315217103276933, 0.12522427551448345, 0.10478836816868611, 0.15120243653655052, 0.08059157870177712, 0.09442350827157497, 0.08028800891978399, 0.2151075838399785, 0.1545454700078283, 0.22975651706968034, 0.2575732230075768, 0.11681413251374449, 0.3652462267449924, 0.13026752775268896, 0.11080440213637692, 0.14828861717666897, 0.18106458628816263, 0.10128283234579222, 0.09441653293158327, 0.22425686860723154, 0.13011496593909605, 0.16388341465166636, 0.20804589348179953, 0.11717318610421248, 0.24488320680601255, 0.2021376990846225, 0.15607529506087303, 0.16042338817247323, 0.12517307326197624, 0.12970871345273086, 0.18946486338973045, 0.16761846494461807, 0.21527328209153243, 0.21282069012522697, 0.23252095015985624, 0.3293218958590712, 0.16675683403653757, 0.2349290709410395, 0.2581683796431337, 0.3361536035580294, 0.3989937901496887, 0.39327569412333624, 1.0051941531045097, 0.9206485812153135, 0.5480682594435555, 1.4769371024199893, 0.8121794930526188, 2.129014466490064, 2.5764995174748555, 2.9913996883801053, 3.25860156757491, 3.5499616818768636, 3.633061919893537, 4.849737090723855, 5.940154807908194, 7.230855218001774, 8.834220222064427, 12.499037146568298, 18.590754747390747, 29.127154214041575, 27.63150235584804, 33.903651646205354, 55.97204058510916, 48.30677400316511, 56.650143078395296, 69.48538357870919, 66.65229034423828, 65.77899210793632, 70.00828416006905, 59.52109704698835, 50.38357319150652, 33.17926720210484, 17.309129987444194, 9.963149632726397, 13.909013373511177, 19.858531747545513, 25.136697803224834, 24.004825830459595, 22.317196982247488, 14.130813768931798, 15.428580931254796, 13.193771021706716, 14.537264278956822, 20.538664851869854, 20.178206205368042, 18.102683748517716, 26.4508991922651, 33.18109457833426, 47.854435852595735, 55.02347946166992, 67.70904881613595, 71.04741505214146, 74.73168345860073, 78.35181304386684, 78.23307527814592, 73.89502307346889, 63.28505434308733, 59.838706152779714, 53.51953840255737, 44.322332995278494, 27.010418517248972, 14.993284974779401, 11.931171298027039, 11.728583540235247, 8.463625022343226, 5.721228361129761, 5.424789982182639, 2.3831611147948673, 0.7266239353588649, 0.2161218851272549, 0.21937094149844988, 0.13689342220979078, 0.09913845134100743, 0.13395961320825986, 0.16106912280832017, 0.19207294844090939, 0.09431668650358915, 0.11802136844822339, 0.19518324440079077, 0.19932437076100282, 0.18804562597402505, 0.12675215995737485, 0.1905204603182418, 0.12194640854639666, 0.24837258671011242, 0.15959784175668443, 0.2363504118153027, 0.3062190812613283, 0.1695625220558473, 0.1650738636297839, 0.33008820616773193, 0.21480829561395304, 0.17413153259881906, 0.08261948238526072, 0.09384161021028246, 0.1990504190325737, 0.22082247718104295, 0.1413301048534257, 0.10001370044691221, 0.19477323283042225, 0.15167840171073163, 0.10018883033522538, 0.1666756948190076, 0.2354529813996383, 0.15396171276058468, 0.13959179313055106, 0.15603376871773175, 0.16931956580707005, 0.12040865820433412, 0.10737725746418748, 0.1206222881696054, 0.17700204785381043, 0.2074442229100636, 0.13125456550291606, 0.14544968094144547, 0.14242432399519853, 0.09217224443065268, 0.14383931378168718, 0.1602563192801816, 0.11227963904717139, 0.1607332072619881, 0.16346251937959874, 0.08451237117073365, 0.12350568201925073, 0.06437425248857055], [0.03631334858281272, 0.09527776350400277, 0.029349879561258212, 0.06991628224828414, 0.1246731693723372, 0.05936378027711596, 0.05105703244251864, 0.09308737103960343, 0.12657221247042927, 0.05010202493784683, 0.022349713669557656, 0.04880804508658392, 0.055877592880278826, 0.08533510166619505, 0.07290643001241343, 0.009254337255177754, 0.021480617179934467, 0.09257081590060677, 0.041543893449540646, 0.04965018168357866, 0.06854817244623389, 0.05006749089807272, 0.12227891784693513, 0.10622013812618596, 0.15310852282813617, 0.03647688909300736, 0.04423775550510202, 0.05329383330951844, 0.03390592669269868, 0.024025846139660904, 0.041273124050349, 0.028097595686891248, 0.036839080907936604, 0.01615082299602883, 0.035660506292645416, 0.07037808639662606, 0.024071425033201064, 0.04924677565161671, 0.06160612138254302, 0.023068994716075913, 0.06991440949163266, 0.03630811707781894, 0.14124131176088536, 0.03817880080480661, 0.08773004529731614, 0.015453519698764597, 0.03508914588019252, 0.08727396119918142, 0.07415764858680111, 0.03764471910627825, 0.01832577369974128, 0.09046435143266406, 0.09628958813846111, 0.05282068405566471, 0.07995530962944031, 0.13226790327046598, 0.09332786420626299, 0.10423499571957759, 0.1326323308582817, 0.22630341164767742, 0.14411931804248265, 0.13824380189180374, 0.7138377300330571, 0.8536557331681252, 1.3007851775203432, 0.7464762415204729, 1.8335047577108656, 0.23946369332926615, 3.1149340995720456, 3.922929040023259, 3.8085768904004778, 2.287894581045423, 4.143301580633436, 10.339986051831927, 11.70600015776498, 15.299827337265015, 29.878195422036306, 45.934968199048726, 57.04314708709717, 54.96910980769566, 50.296074526650564, 35.46052755628313, 21.86459653718131, 4.723207354545593, 2.061651029757091, 2.600572854280472, 1.3005720632416862, 9.5283556835992, 14.272585681506566, 14.685582263129097, 12.693345257214137, 15.98452193396432, 16.59675897870745, 21.36906143597194, 27.394794600350515, 28.871057510375977, 28.242176055908203, 32.83629022325788, 29.41598735536848, 30.45216178894043, 33.86874737058367, 44.80391263961792, 51.303205490112305, 53.856348855154856, 56.83909586497715, 54.51556267057146, 50.31271546227591, 36.78673022133963, 20.119830914906093, 16.674589225224086, 7.965889947754996, 4.141910203865596, 1.380583501287869, 3.2064820442880904, 3.39285118665014, 2.449066949742181, 1.8587823041847773, 1.127105291400637, 0.07600469554641417, 0.10329326375254563, 0.1770196897642953, 0.055067740979471376, 0.05888957929398332, 0.040976980834134986, 0.0500872294817652, 0.005990788648237607, 0.03679671996672239, 0.04702531646138855, 0.09049037325062922, 0.08565834896372897, 0.1077290235885552, 0.08191747005496706, 0.055477755942514966, 0.04309466487861105, 0.01663005192364965, 0.026893039965736013, 0.05696941340076072, 0.04903384457741465, 0.08442098607442208, 0.03793113213032484, 0.029097342398017645, 0.048268786165863276, 0.03406936881531562, 0.025562159683821455, 0.050814476529402394, 0.06942802880491529, 0.10439673811197281, 0.08754110722137348, 0.05026536188753588, 0.014087753387035003, 0.058477213207100115, 0.050644048888768466, 0.09519128421587603, 0.030087633723659173, 0.00889399105549923, 0.03477629373914429, 0.0516023099688547, 0.021509816238124455, 0.06637553724327258, 0.1394626407751015, 0.018827501152242933, 0.01658634578676096, 0.06528088383908782, 0.0576511307486466, 0.11022308082985026, 0.06601638187255178, 0.021413279364683797, 0.03423140976311905, 0.060542103834450245, 0.03796661611912506, 0.0389612195348101, 0.025801755487918854, 0.04385917367679732, 0.029072925315371582, 0.08079773121114288, 0.0939137791948659, 0.053583404914076836, 0.04509954247623682, 0.09548542236110993, 0.013412839200879847, 0.16049502789974213, 0.03425081925732749, 0.08835306936608893, 0.07407922350934573, 0.07960204394268137, 0.045863118288772445, 0.028601173843656267, 0.03257568932271429, 0.05754833947867155, 0.10463387253029005, 0.03585213136726192, 0.0694643711405141, 0.02303462691738137, 0.030677097450409616, 0.03467032353260687, 0.07544416455285889, 0.054712521111858745, 0.04658562916197947, 0.03760153374501637, 0.09160360494362456, 0.07634165603667498, 0.07693071942776442, 0.02415407568748508, 0.047092281082378964, 0.09164371314857687, 0.01851180086045393, 0.01940677497935082, 0.06246366750981126, 0.03449637768790126, 0.04260082030668855, 0.050837743495191844, 0.06883187472288098, 0.07803187319742781, 0.010933032891313945, 0.07696529078696455, 0.08059543956603323, 0.06539267248341016, 0.025541150543306555, 0.038427005521953106, 0.02916279049324138, 0.05567318759858608, 0.022000783821567893, 0.08961991460195609, 0.04069855755993298, 0.05187052807637623, 0.017196129940982376, 0.0251640258689544, 0.0431570426028754, 0.08590139342205864, 0.07482764084956475, 0.21536871125655516, 0.11285367288759776, 0.14105973578989506, 0.39342027636510984, 0.11775033442037446, 0.3527718489723546, 0.23315025067755155, 0.23332875967025757, 0.864117006106036, 1.0095034475837434, 2.2245608823640004, 2.6143750165190016, 4.4227346777915955, 6.50562960760934, 9.97497546672821, 12.110984597887311, 14.96208930015564, 12.81038418837956, 15.842118603842598, 24.34997238431658, 24.625478880746023, 32.88751581736973, 55.33040918622698, 63.789132254464285, 64.02683012826103, 65.75445107051304, 54.0961138180324, 31.74241100038801, 13.27324538571494, 2.6066527451787675, 3.8298097167696272, 2.2816926624093736, 7.5244761024202615, 19.93000786645072, 20.259918757847377, 17.56138607433864, 18.647441625595093, 20.62246707507542, 20.331830876214163, 25.15032148361206, 31.67188331059047, 33.436142104012625, 36.42031349454607, 38.35586622783116, 40.770535469055176, 43.01813874925886, 46.478873184749055, 54.75246844972883, 59.78473949432373, 65.67230946677071, 64.66680785587856, 66.55993488856724, 59.99238640921456, 46.43799693243844, 36.72591263907296, 30.79501370021275, 26.67910930088588, 17.215348414012364, 11.197332092693873, 6.508269054549081, 5.749370302472796, 4.541051208972931, 2.4958589417593817, 2.1950890123844147, 0.7764026213969503, 0.5826141600097928, 0.2829605835889067, 0.0443747720814177, 0.047999004035123756, 0.05993801089269774, 0.08344093044953686, 0.01561366074851581, 0.020932712026738694, 0.012536642690455275, 0.08260725518422467, 0.05177327025947826, 0.0896900954789349, 0.0337087172748787, 0.053554292369101725, 0.012587901770270296, 0.05626170476898551, 0.03397617203050426, 0.029059839767536948, 0.10186045563646726, 0.01549835390012179, 0.018381554367286817, 0.14065337473792688, 0.04318379723866071, 0.0365966030263475, 0.05024675984999963, 0.03778673309300627, 0.04844901863751667, 0.10484379090900932, 0.030365714337676764, 0.0441468962734299, 0.024022173568872467, 0.0453272249017443, 0.05798509889947517, 0.04062607305656586, 0.0400158868703459, 0.03332010330632329, 0.03969617134758404, 0.03540817268991044, 0.03261063726884978, 0.022275573540745035, 0.05383421181301985, 0.03877593197726777, 0.05343731971723693, 0.17832724031593117, 0.023171858928565468, 0.09655115660279989, 0.01331874166083123, 0.04868825990706682, 0.010086259355635514, 0.04582500497677496, 0.024592633226088116, 0.01908323251908379, 0.028977553825825453, 0.019859771743150692, 0.07351401740951197, 0.10002225677349738, 0.04917660155998809, 0.18386851011642388, 0.16080597335738794, 0.14676727381135735, 0.14912862995905535, 0.3074798264673778, 0.16996018428887638, 0.19084830129785196, 0.19338151679507323, 0.3128946716231959, 0.17373362609318324, 0.0671706377927746, 0.11749205685087613, 0.17637464723416738, 0.12861393791224274, 0.25894649646111895, 0.15214152900235994, 0.13259848553155149, 0.16587769692497595, 0.1595148162118026, 0.11915429122745991, 0.11682467694793429, 0.08651361521333456, 0.20892980747989245, 0.18510362026946886, 0.20553948011781487, 0.1708348702107157, 0.14245773505951675, 0.13636292996151106, 0.2027690623487745, 0.11108719517609902, 0.22815072323594773, 0.11704191671950476, 0.1710244800363268, 0.13663251192442008, 0.11978676728904247, 0.23644396822367394, 0.20297506558043615, 0.1330130568572453, 0.1737984533288649, 0.12136186419853143, 0.14306634025914328, 0.09051110249544893, 0.19089790220771516, 0.11306640040129423, 0.1942128036171198, 0.1386811855648245, 0.12176313623785973, 0.1520503746079547, 0.2826744318008423, 0.11232105682470969, 0.11922741016106946, 0.11215233230697257, 0.23736729153564998, 0.1730801154460226, 0.2877965840910162, 0.25331937841006685, 0.21348237033401216, 0.4420770454619612, 0.12704502924212388, 0.2538901892091547, 0.18796545027622155, 0.1281070722533124, 0.5030316103781972, 0.8942264275891441, 1.9837760542120253, 1.7243616942848479, 3.166864718709673, 4.8427693503243585, 9.165752649307251, 12.824750457491193, 14.289293493543353, 16.5576753616333, 25.262430667877197, 35.322279248918804, 46.350494793483186, 48.228443486349924, 65.71667371477399, 69.8042642048427, 76.30792399815151, 72.01884964534214, 71.52876540592739, 61.37460545131138, 55.054173128945486, 39.45050975254604, 28.17995320047651, 22.846753937857493, 29.583004678998673, 35.52648333140782, 32.63431303841727, 26.367649350847515, 26.83314217839922, 27.12756167139326, 25.848144701548986, 28.586733749934606, 37.142057623182026, 35.467055388859336, 40.38589014325823, 44.87939786911011, 52.42382485525948, 59.04542337145124, 67.24791077205113, 69.10358701433454, 74.07616261073521, 73.55731282915387, 73.05955777849469, 77.28559112548828, 70.74667617252895, 64.06920719146729, 52.54826014382498, 44.24176863261631, 27.720025879996165, 18.111263036727905, 13.536503076553345, 9.40997748715537, 7.409016149384635, 4.362139003617423, 2.7039657405444553, 1.5520018573318208, 0.5679902647222791, 0.45644920425755636, 0.3187712462885039, 0.22293346747756004, 0.11093206850013562, 0.1683671876255955, 0.15156201938433306, 0.08803975582122803, 0.11708908847400121, 0.1030943240704281, 0.18981926222997053, 0.17020315410835402, 0.16543994684304508, 0.22417866066098213, 0.1986970379948616, 0.3097684165196759, 0.18387133282210144, 0.06729044672101736, 0.2149000878312758, 0.23782655117767199, 0.18117737237896236, 0.11638025008141994, 0.3349411157625062, 0.16201301930206163, 0.17314822679119451, 0.42860231708203045, 0.2532333130283015, 0.1956976553691285, 0.2876781118767602, 0.20154558228594915, 0.17907950494970593, 0.12816918534891947, 0.11185805166938476, 0.13050995474415167, 0.17514891443508013, 0.1975280578647341, 0.19526293155338081, 0.12246535212865897, 0.17935888495828423, 0.18046478847307817, 0.201206789751138, 0.16593225114047527, 0.10756966285407543, 0.11669427608805043, 0.177050861663052, 0.14694308223468916, 0.19932017741458757, 0.09367058545883213, 0.20428435318171978, 0.14768789655395917, 0.14959552990538733, 0.2398325449654034, 0.13696104500974926, 0.10656720200287444, 0.1149483240608658, 0.1471802166530064, 0.21779699809849262, 0.1729561606688159], [0.06124988371240241, 0.09556318925959723, 0.12140955163964204, 0.05183854193559714, 0.07507915342492716, 0.038650314789265394, 0.04732628406158515, 0.04025010358808296, 0.023089420316474776, 0.06127958997551884, 0.048437880485185554, 0.07516100510422673, 0.029024969852928604, 0.05123197573370167, 0.08088995769087758, 0.03067892270960978, 0.03763787268794008, 0.051284504522170336, 0.06423543779445545, 0.03275461561445679, 0.1550980010735137, 0.045892135838844945, 0.09006297761308295, 0.060652962885797024, 0.0969502709007689, 0.052627596738083024, 0.04634838278538414, 0.0043438615975901484, 0.06360678867037807, 0.13082764483988285, 0.05488933376701815, 0.04007032912756715, 0.08888837242765085, 0.01030194019300065, 0.055937453239623985, 0.05452515384448426, 0.02487060527450272, 0.046814346353390386, 0.05785243173262902, 0.04668718210554548, 0.03298869323251503, 0.11466065235435963, 0.013943692769056984, 0.05644582863897085, 0.06161570229700633, 0.1163028563771929, 0.09833960527820246, 0.06569428808454957, 0.030527453337396895, 0.04382716378729258, 0.043333909540836296, 0.02020662697032094, 0.02247203148103186, 0.06880615146032401, 0.12140364838497979, 0.04704251732411129, 0.06877306609281472, 0.020193957025185227, 0.115513218034591, 0.14599980999316486, 0.18352278295372212, 0.355331120214292, 0.2204040517764432, 0.31440826611859457, 0.380544015871627, 0.9527904050690787, 0.7315700213823999, 1.4755725413560867, 2.23057867373739, 3.7136862107685635, 5.167100403990064, 6.578365521771567, 5.7113849350384305, 12.944681576320104, 15.869859286717006, 22.292390176228114, 38.845481463841026, 47.02160392488752, 50.19093438557216, 57.57317304611206, 53.324599742889404, 54.54852145058768, 38.05785799026489, 29.710757732391357, 17.302534409931727, 10.650742496762957, 9.439033116613116, 14.909871850694929, 15.332277161734444, 22.859389236995153, 23.909249884741648, 23.30208328792027, 30.481847967420304, 36.313821928841726, 40.88425663539341, 46.420814037323, 43.25390154974801, 44.54878520965576, 38.53531040464129, 37.33134044919695, 42.97249950681414, 43.89531408037458, 44.24255725315639, 49.55732815606253, 59.2023206438337, 49.65680551528931, 52.21703256879534, 32.165806429726736, 25.0866117136819, 16.0528279372624, 13.84791612625122, 7.570468834468296, 4.08692650284086, 1.808398527758462, 2.4695174523762295, 1.1873470417090823, 0.2829769769949572, 0.21780531693782124, 0.13273413825247968, 0.01870057439165456, 0.018920531695974723, 0.03237805921318276, 0.07236818210887057, 0.027366218057328036, 0.02382593784880425, 0.12325469191585268, 0.030086449680051634, 0.03612912293257458, 0.03346027507047568, 0.02477218207371022, 0.11613702241863523, 0.019422053891633238, 0.014973427335332547, 0.05313127328242574, 0.022887708818806068, 0.03734258103317448, 0.018409552418493798, 0.05493030710411923, 0.05589550620477114, 0.029510302203042165, 0.05067464403275933, 0.06840908633811132, 0.042346763225006204, 0.01664425026891487, 0.04283719815846, 0.03722459736413189, 0.07549631675439221, 0.015465455129742622, 0.03480953856238297, 0.03900923267272966, 0.057917971430080276, 0.022636172494718006, 0.05096755402960947, 0.008201840383532857, 0.034064395153628926, 0.0691344402730465, 0.06196306472910302, 0.049158386287412474, 0.06208447499998978, 0.09483311272093228, 0.020960815250873566, 0.041763575947178264, 0.11988366208970547, 0.024596012330480983, 0.044900036217378717, 0.061613056010433605, 0.06490798134888921, 0.03406692608924849, 0.029135309824986116, 0.06831928222839322, 0.03963445519496288, 0.04501012173880424, 0.04205191261800272, 0.11143741424062423, 0.06505634981606688, 0.15806222201458045, 0.07331701833754778, 0.07526249358696596, 0.09263757696109158, 0.09930798331541674, 0.06885270574795348, 0.06887272253100361, 0.055641140389655314, 0.03178125373753054, 0.05304659550477352, 0.008914529462344944, 0.03497931480939899, 0.06780889497271606, 0.02885653031989932, 0.048848889502031465, 0.021996295312419534, 0.0605369062562074, 0.02535052800418011, 0.013398388101320182, 0.010951365211180277, 0.07939846308103629, 0.024403104824679236, 0.10916253738105297, 0.10828404487775904, 0.029185131258730377, 0.05688133955534015, 0.034935566264071634, 0.017960311346022145, 0.032014004819627316, 0.0406322816519865, 0.011274130748850959, 0.008912535417558891, 0.09474970041108982, 0.01369631416829569, 0.03096169200060623, 0.11588506879551069, 0.029427548072167804, 0.04105516842433384, 0.03279999603650399, 0.07661496315683637, 0.03430122083851269, 0.05121808612186994, 0.13376693640436443, 0.10445750092289277, 0.04342462967282959, 0.013133984208772225, 0.07190196748290743, 0.04198738054505416, 0.04282264358230999, 0.0077835371152364784, 0.08934734708496503, 0.0911718870380095, 0.038030537510556836, 0.04671759404508131, 0.08989219034888915, 0.14503809516983374, 0.10427688847162894, 0.09649648703634739, 0.15325642989150115, 0.09354758741600172, 0.15671298227139882, 0.2976025550493172, 0.1377095098474196, 0.41087738105228966, 0.37835511618426865, 1.0429157061236245, 1.0031488857098987, 1.4125365295580454, 2.08423484648977, 4.931487424033029, 6.487210801669529, 7.612556678908212, 7.963333879198347, 12.115087509155273, 24.07554806981768, 22.7040570463453, 27.85939458438328, 52.43885380881173, 63.23271356310163, 66.42849581582206, 67.26343999590192, 65.59078625270298, 59.30229132516043, 37.914534023829866, 22.092492239815847, 10.584016340119497, 7.450013995170593, 14.355875475066048, 25.959803989955358, 28.100743736539567, 29.483871255602153, 32.93298135484968, 28.76181619507926, 35.408982345036094, 43.83608763558524, 49.32676260811942, 51.295486041477744, 54.13578455788748, 55.5324558530535, 50.97180073601859, 51.861493246895925, 53.99419069290161, 57.848210539136616, 58.187793322971885, 63.700070244925364, 67.30694266727993, 60.62479060036795, 59.38744844709124, 47.01321050098964, 35.295115266527446, 26.84673285484314, 16.27805379458836, 7.905218277658735, 5.817051836422511, 4.211452986512866, 3.66111136334283, 1.930860093661717, 1.18851857313088, 0.7437548818332809, 0.19016308949462005, 0.0779447221596326, 0.07982912247202226, 0.06639101462704794, 0.02096392972660916, 0.035326297261885235, 0.07479479296931199, 0.021881307375484278, 0.016297605387600403, 0.05483485758304596, 0.06022284632282598, 0.06781437075031654, 0.05475613734285746, 0.03336179928321924, 0.06769551855645009, 0.025390831287950277, 0.01082868523163987, 0.020530520572460124, 0.04195559796478067, 0.07142074366233178, 0.03906908624672464, 0.03185488157240408, 0.019203324735696827, 0.0599548996293119, 0.01490934139915875, 0.04234651895239949, 0.058347850505794795, 0.039210418305758915, 0.040148045135928054, 0.018173769981201206, 0.01449421706742474, 0.02315383534213262, 0.08086974413267203, 0.019061677157878876, 0.07123787847480603, 0.006214827340694943, 0.032140225903796296, 0.03470670318763171, 0.024524401440950375, 0.06929760758898088, 0.013683137018233538, 0.12154570647648402, 0.07885186241141387, 0.07034994754940271, 0.19035861614559377, 0.057810491483126364, 0.08197485376149416, 0.06590573316706078, 0.012185987667180598, 0.0445275883456426, 0.05786510676677738, 0.03841337375342846, 0.05446941219270229, 0.03071081724816135, 0.045493961311876774, 0.03468705281349165, 0.015418736297371132, 0.07109970160360847, 0.12876588904431888, 0.18925199338368007, 0.34256619374666897, 0.20166205960725034, 0.12268417967217309, 0.0839543914688485, 0.24079370339001926, 0.14855737132685526, 0.1549784160618271, 0.13033676546599182, 0.15623886271246842, 0.21910095241452965, 0.04873655802969422, 0.1374711947781699, 0.20593752233045443, 0.21271702354507788, 0.13341344680104936, 0.12164260127714702, 0.15555081463285855, 0.17776335057403359, 0.14853624174637453, 0.2192100744162287, 0.1471035150544984, 0.13816065421061857, 0.21453754657081195, 0.09372957729335342, 0.1373968951936279, 0.1676286022577967, 0.16368731803127698, 0.1685450045125825, 0.14390408673456737, 0.1670701407960483, 0.12541453673371247, 0.17342057717697962, 0.20944519553865704, 0.1204785473112549, 0.1651609196726765, 0.1813832534743207, 0.15308326775474207, 0.1301019787788391, 0.09017832856625319, 0.23694383140121186, 0.2607000209391117, 0.14040442023958477, 0.13592208575989517, 0.15745331825954573, 0.1752620262226888, 0.11498465282576424, 0.054849575007600446, 0.11106042696961335, 0.16239343317491667, 0.10284686234912702, 0.25312130046742304, 0.17187617719173431, 0.36712731580649105, 0.18424981965550355, 0.21253907095108712, 0.18594511225819588, 0.233945439436606, 0.3117881981389863, 0.45905526727437973, 0.4539419359394482, 0.49647783062287737, 0.5489192509225437, 0.8591820480568069, 0.9241579643317631, 0.9418377642120633, 1.8576234749385288, 3.871934473514557, 7.270178982189723, 10.537727441106524, 15.425277062824794, 18.98665268080575, 34.52232619694301, 43.42871127809797, 53.99950953892299, 72.23134640284947, 71.85437883649553, 71.87122821807861, 74.30922603607178, 70.24733693259103, 70.12259592328752, 60.45885372161865, 62.38242081233433, 54.84981618608747, 50.64011457988194, 46.64588703427996, 49.46475730623518, 45.15191664014544, 46.1247512953622, 44.81889990397862, 39.94462047304426, 44.760330063956125, 49.30697413853237, 53.6259639603751, 61.76543467385428, 58.42017582484654, 65.87589863368443, 64.71725872584751, 64.91285051618303, 67.53648335593087, 65.15850407736642, 63.16925566537039, 70.65676648276192, 79.98410470145089, 68.72994763510567, 75.98789691925049, 60.76960495540074, 53.21375513076782, 33.85421173913138, 27.77289124897548, 17.273280756814138, 9.800396765981402, 4.205005058220454, 3.672145102705274, 1.7887177552495683, 0.9092657491564751, 0.4544974932713168, 0.23132062171186718, 0.19373293008123124, 0.11580916786832468, 0.13413614087871142, 0.2096085324883461, 0.1445921076727765, 0.14970379695296288, 0.3327923039240496, 0.07626624365470239, 0.17886303870805673, 0.11740896345249244, 0.18456623410539968, 0.21775847088013375, 0.12626506680888788, 0.16134132391640119, 0.1280288371656622, 0.11003252105521304, 0.08849388573850904, 0.12043631529169423, 0.10913391677396637, 0.12237104933176722, 0.12963657160954817, 0.13877217711082526, 0.18479541609329836, 0.05763385524707181, 0.09426656990711178, 0.1415896037859576, 0.10790587017046553, 0.1815455047679799, 0.11055480981511728, 0.1873970822032009, 0.10441746057144233, 0.18777472765317985, 0.08373467504445996, 0.12010289675423078, 0.10233527408646685, 0.09829507981027875, 0.14550240311239446, 0.10091417748481035, 0.16884696616658143, 0.15845134827707494, 0.3209134627665792, 0.2584821885185582, 0.14830389778528894, 0.15527568225349697, 0.193435650318861, 0.13236390240490437, 0.2175892171050821, 0.08992665992783648, 0.16646267553525312, 0.09316136528338705, 0.10728812510413782, 0.1589742409331458, 0.20263397959726198, 0.17887340672314167, 0.13871387738202298, 0.17168123408087663, 0.16220861380653723], [0.006952775309660605, 0.11899252847901412, 0.12457493107233729, 0.11414430077586855, 0.059934516437351704, 0.08391054453594343, 0.11504629094685827, 0.059735746388988833, 0.03830923559144139, 0.07744375975536448, 0.12300653808883258, 0.04210029895018254, 0.028672477696090937, 0.020354310117129768, 0.04085326354418482, 0.01667359860480896, 0.14439797880394117, 0.036232982895204, 0.023015694094023535, 0.05333048098587564, 0.04600043681317142, 0.04840446602819221, 0.06970031133719853, 0.04633035071726356, 0.010900707483025534, 0.04736287745514086, 0.039221441107136865, 0.022159576282969544, 0.010184299184142478, 0.053275268591408215, 0.01044249108859471, 0.02677709359808692, 0.09545726994318621, 0.04623115907556244, 0.04357742218832884, 0.03789792801918728, 0.007647758865329836, 0.0697880866272109, 0.020070775777899792, 0.019853725996134535, 0.03392865761582341, 0.008083263844517725, 0.031532265312437496, 0.054489822526063235, 0.10887117444404534, 0.03825902400006141, 0.026233039131121974, 0.05732601069446121, 0.023159557088677372, 0.029975057978715216, 0.038557508162089756, 0.030417768151632378, 0.035190179744469266, 0.06548103809888874, 0.019635347982070277, 0.038432895205914974, 0.02511175492379282, 0.06722990104130336, 0.006196353800727853, 0.07407904709024088, 0.06550798272447926, 0.01403887172429157, 0.2654170063989503, 0.14030391563262257, 0.1527853908815554, 0.0807713158428669, 0.06916754599660635, 0.490505148257528, 1.9949016400745936, 2.2463906024183546, 1.7728730397565025, 7.392224958964756, 11.371111750602722, 14.06818791798183, 18.379981143133982, 26.791557209832327, 39.6858035496303, 48.133472033909385, 41.347979409354075, 50.08924055099487, 55.86421843937465, 52.62800809315273, 49.311900411333355, 50.90225969042097, 40.22079399653843, 34.68236058098929, 27.58175151688712, 29.66224888392857, 33.572771481105256, 43.18046951293945, 44.142065456935335, 39.270829336983816, 48.333590575626914, 48.44804130281721, 46.90844556263515, 54.42659098761422, 53.15284027372088, 43.27090726579939, 42.496693815503804, 43.20819282531738, 46.613709926605225, 35.95674358095442, 53.85630021776472, 55.08110434668404, 63.32761205945696, 42.87319585255214, 39.14042901992798, 29.454285826001847, 26.85351082256862, 14.096257771764483, 9.087316172463552, 3.126893252134323, 1.8736914013113295, 1.5873156424079622, 0.5904526508280209, 0.3044054928634848, 0.12424375170043536, 0.041301744657435586, 0.09562853218189307, 0.07972289102950267, 0.06423482711293868, 0.07453500905207225, 0.050768122409603426, 0.0794405322521925, 0.050634322089276144, 0.0178242345407073, 0.020636682465140308, 0.08880901775721993, 0.023086706176400185, 0.010690128380831863, 0.004123753319228334, 0.07736053064997707, 0.08110706854079451, 0.019610220133992176, 0.009327657204786581, 0.04947361330102597, 0.04533541142674429, 0.034812320555959425, 0.03804631344974041, 0.054674787779471705, 0.038216222011085065, 0.10167193825223617, 0.07282763852604798, 0.10504001645105225, 0.04287863629204886, 0.030028590999011482, 0.021457831974008253, 0.02667296731046268, 0.022311464650556445, 0.02186383000974144, 0.06372047042740242, 0.07194177034710135, 0.013291219432306076, 0.028644352419567958, 0.025374251284769604, 0.04072155311171498, 0.06845085016850914, 0.02775025530718267, 0.07356141986591475, 0.03854854471449341, 0.08642441499978304, 0.0641812024904149, 0.03363613438393388, 0.04771095574168222, 0.08267272024282388, 0.10279656254819461, 0.006121430812137467, 0.07130449025758676, 0.07434986398688384, 0.05598493033487882, 0.038512626463281255, 0.016737732038434063, 0.061864636439297876, 0.0723087220851864, 0.06513417099735566, 0.03183004040537136, 0.02715459994838706, 0.07121745457074471, 0.056511402263173034, 0.05204463676948633, 0.15651601712618554, 0.06949358207306691, 0.07676467512335096, 0.08461715054831334, 0.042033527711672444, 0.06930821987667254, 0.0747417179601533, 0.01227614885595228, 0.07713482276137386, 0.024098004946219068, 0.08079406712204218, 0.023985851589324217, 0.03620941398133125, 0.054131535680166314, 0.0413579646764057, 0.05616489478519984, 0.011140818973737103, 0.05269540274249656, 0.10384673119655677, 0.06781314938728299, 0.03310860054833548, 0.018103377062029073, 0.059477285615035465, 0.06934270302632026, 0.028909167673970972, 0.016529677934678536, 0.01516047738758581, 0.014707904708172594, 0.050947632241461954, 0.072134820345257, 0.052530939424676557, 0.02771233198499041, 0.09255817479320935, 0.0777766965329647, 0.022260421853778616, 0.04433036196444716, 0.07283712444560868, 0.07360462897590228, 0.037906504701822996, 0.04280739690044096, 0.02844096833307828, 0.10006790860955204, 0.08197169178830725, 0.058463011469159804, 0.02733709872700274, 0.03897194378077984, 0.04505327995866537, 0.023633060877078345, 0.06923215610108205, 0.06801153267068522, 0.04047311090731195, 0.018711145967245102, 0.07885356553431068, 0.041071558437709293, 0.05446529687781419, 0.05151221748175366, 0.010549426511196154, 0.0777511971869639, 0.15213812275656632, 0.25978394438113483, 0.47621357228074757, 0.27043235727718895, 0.27569485775062014, 0.9497596876961845, 2.516745660986219, 4.049667656421661, 3.430198839732579, 5.248254060745239, 7.337287289755685, 15.423668554850988, 22.584984030042374, 30.424511432647705, 49.226090158735005, 60.39291531699044, 57.038943426949636, 68.15820121765137, 67.38375500270298, 66.87810679844448, 58.38472611563546, 54.51762975965227, 43.78576878138951, 35.318353516714915, 35.1078474181039, 40.19775029591152, 45.76711014338902, 55.479038102286204, 56.878738812037874, 48.95291478293282, 60.57736914498465, 57.78817115511213, 57.957953861781526, 68.75570460728237, 69.06030668531145, 59.38293906620571, 60.37082699366978, 59.920625414167134, 60.36865220751081, 52.849877970559255, 61.703012057713096, 60.162436621529714, 70.40185792105538, 52.85318531308855, 51.63851860591343, 38.749089104788645, 30.898142337799072, 20.685148511614116, 12.778680426733834, 7.063695890562875, 4.908405074051448, 3.775336708341326, 2.271143342767443, 0.945093320948737, 0.27640864944883753, 0.04481440849070038, 0.045875447270061286, 0.05379236316574471, 0.04361623099872044, 0.06076899915933609, 0.020862984071884836, 0.03954199801332184, 0.023307781367163573, 0.0045139868660563865, 0.018841716460883617, 0.052563451430095096, 0.054202663113496134, 0.029105905509952987, 0.012037571702551628, 0.037571749450372796, 0.03982307096677167, 0.05520503914781979, 0.07193590780454022, 0.014100374138381864, 0.004544161318335682, 0.004452123980237437, 0.030305694522602216, 0.044251163357070515, 0.06298111831503254, 0.07015053967812232, 0.06278697587549686, 0.024565915909728835, 0.02906459290534258, 0.017439184577337334, 0.03095092364986028, 0.028300654076571976, 0.01909106450953654, 0.05077778814094407, 0.05482553790456482, 0.0670696310698986, 0.02090214063147349, 0.06788852105715446, 0.0559530086549265, 0.023584735613050203, 0.07798409754676477, 0.021177340864336917, 0.020434309395828416, 0.06863767121519361, 0.03118206321128777, 0.03188630792179278, 0.09435101359018258, 0.09979222661682538, 0.10310287361166307, 0.052612482370542626, 0.09167474934032985, 0.017431698639744093, 0.079204625982259, 0.04882734601518937, 0.08120992766427142, 0.028233948995226195, 0.059686457605234215, 0.06082001142203808, 0.05299163416826299, 0.05000690111358251, 0.09567557501473598, 0.12057352864316531, 0.14896305384380476, 0.1665267428117139, 0.21786410521183694, 0.20351048399295124, 0.1749859167529004, 0.17386771818356855, 0.10739368479698896, 0.14019112954182283, 0.29351022892764633, 0.12965774190212997, 0.20818041983459676, 0.23248439069305146, 0.14126641755657537, 0.0921040652319789, 0.27056692434208734, 0.2576350782598768, 0.14279230710651192, 0.1328081257109131, 0.1522257759102753, 0.07349484200988497, 0.12301504691796643, 0.216200445911714, 0.13477926994008677, 0.16910460591316223, 0.18083871555115494, 0.10663610723401819, 0.1432567507560764, 0.1246897391974926, 0.14602281233029707, 0.08322019622262035, 0.13890021666884422, 0.24527054173605783, 0.1795213669538498, 0.1057236608383911, 0.18357889779976436, 0.1807462583695139, 0.07565102273864405, 0.13182382924216135, 0.15418147668242455, 0.13976002910307475, 0.12277126285646643, 0.21492300874420575, 0.10321287092353616, 0.1357189052339111, 0.17352902064366, 0.0750597066112927, 0.09711225078042064, 0.22389024256595544, 0.1192443056830338, 0.1258497355239732, 0.22802877692239626, 0.1809812621878726, 0.12117787264287472, 0.09145594215286629, 0.08497433138212987, 0.10153399886829512, 0.12649205034332617, 0.13655838875898293, 0.16294885479978152, 0.09265778373394694, 0.2919300022934164, 0.3629922148372446, 0.5093764013477734, 0.34988601239664213, 0.1513773492936577, 0.8393915157232965, 2.112966081925801, 4.081091318811689, 6.055735920156751, 13.033906000001089, 20.37978039469038, 26.969273022242955, 41.57773201806204, 53.86911269596645, 69.12109647478376, 76.51459121704102, 66.51625851222447, 74.09348446982247, 70.7261928830828, 69.6736033303397, 68.93815040588379, 71.03419957842145, 69.50883374895368, 67.34204496656145, 63.146542004176546, 70.05184936523438, 66.55856609344482, 68.9765739440918, 66.3360847745623, 57.98098019191197, 67.5641232899257, 67.8614922932216, 67.92064925602504, 73.77085876464844, 75.3690973009382, 68.59631987980434, 69.91843700408936, 68.8384507043021, 71.68202877044678, 61.29544462476458, 75.72545651027134, 71.40113394601005, 82.26254408700126, 67.5452936717442, 63.49926035744803, 54.867568833487375, 46.055936336517334, 29.382993834359304, 16.592786346163066, 7.3056217432022095, 4.980093547276088, 3.880314435277666, 1.5389738764081682, 0.6104484264339719, 0.20454729907214642, 0.18342035130730697, 0.252264853566885, 0.13828311621078423, 0.19599140674940177, 0.14720108839018003, 0.16184171635125363, 0.17765494781945432, 0.07116944143282515, 0.11814844448651586, 0.10234848516327993, 0.12187953213495867, 0.1653873196669987, 0.12737730784075602, 0.1114590595077191, 0.14214810595980712, 0.1494137096617903, 0.11175426295293228, 0.10975599767906324, 0.13132977432438306, 0.11097715036677462, 0.1274882076042039, 0.11087746678718499, 0.1839204587574516, 0.20260871095316751, 0.24622502337609017, 0.14966415693717344, 0.21719844878784247, 0.1379333042672702, 0.09450386717383351, 0.11385725332157952, 0.08309385300214801, 0.10995674904968057, 0.11006274979029383, 0.21366272494196892, 0.14468138931053026, 0.12222272157669067, 0.135322152237807, 0.05379855140511479, 0.1266464984842709, 0.15531955632780278, 0.11778232056115355, 0.20375079395515577, 0.19615493368889603, 0.4218473109815802, 0.14925122766622476, 0.19267791669283593, 0.14351581542619637, 0.20564393379858562, 0.16397384979895183, 0.14002853898065432, 0.11437595263123512, 0.17003869079053402, 0.13705321720668248, 0.2085168646382434, 0.0918533465425883, 0.16850241965481214, 0.18623498241816247, 0.16649931642626012, 0.14073445967265538], [0.04173400539106556, 0.019965222870398844, 0.009305016187551831, 0.01626570406369865, 0.07131888198533229, 0.011007351983737732, 0.06574483215808868, 0.09071731607296638, 0.048321108001151254, 0.030062110628932714, 0.08115058299154043, 0.09563220305634396, 0.02148798607023699, 0.04560754468132343, 0.04062287376395293, 0.135604287098561, 0.10007985761123044, 0.056953589964125834, 0.02337409459453608, 0.03630592201703361, 0.09484258506979261, 0.06793913298419543, 0.06463732730065073, 0.022850460638957362, 0.037982381880283356, 0.09436042487089123, 0.0668616397306323, 0.019737735523709228, 0.03496257535048893, 0.026019293814897537, 0.01976463265184845, 0.00801800997994308, 0.04072009086874979, 0.04030357554022755, 0.000651973500290686, 0.055090634751000574, 0.07763722365988152, 0.08633922492819172, 0.02336538050855909, 0.014746940827795436, 0.04387123802942889, 0.015974251220801046, 0.03020380570420197, 0.05012725965519037, 0.07549291729394879, 0.020555901174832667, 0.005472272967121431, 0.06835330397422824, 0.030880912406636134, 0.06777836089687687, 0.03339882354651179, 0.045381195577127595, 0.046458152788025994, 0.06160669135195868, 0.006830860378353724, 0.07764233302857194, 0.018513005260112028, 0.022393733628892472, 0.04278118848534567, 0.11340126421834741, 0.054216708788382154, 0.028505968595189706, 0.023978623495038067, 0.05766178374843938, 0.06921735725232533, 0.0600233298859426, 0.056746724992990494, 0.09871968666889838, 0.3072682592485632, 1.762621624129159, 2.7588046150548116, 4.33303039414542, 7.392074704170227, 10.170246771403722, 15.802319322313581, 26.389602184295654, 28.63078532900129, 45.392869744982036, 46.62851653780256, 50.67431708744594, 54.05633190699986, 53.165367875780376, 52.192185810634065, 48.38754333768572, 51.019402844565256, 54.148590087890625, 51.35289553233555, 48.42277765274048, 53.16943257195609, 61.27787957872663, 60.481768880571636, 45.486955302102224, 39.93991306849888, 60.38412584577288, 50.60388667242867, 41.90925489153181, 44.57046706335885, 40.21026400157383, 41.74806710651943, 38.24332972935268, 43.450341020311626, 48.752792767116, 64.72722939082554, 53.814388683864046, 50.80534274237496, 41.42772388458252, 38.37778084618704, 30.976111548287527, 16.69330767222813, 10.160005126680646, 4.770087284701211, 1.2399517446756363, 0.675529705626624, 0.25122441511069027, 0.3322983304304736, 0.1878306389387165, 0.10951127723923751, 0.028265914779954722, 0.01502341331381883, 0.05057428191815104, 0.039584664295294454, 0.026481600079153265, 0.007199632286626313, 0.02946524747780391, 0.03368205424132092, 0.08480566114719425, 0.03263383977381246, 0.06947038974612951, 0.03428776888176799, 0.050122313134904416, 0.02418238586480064, 0.029010086187294552, 0.10033490535404001, 0.009119074691885283, 0.07574868428387813, 0.02779450936109892, 0.010235966233137463, 0.005720731710815536, 0.05027370108291507, 0.04078842613047787, 0.031182619610003064, 0.04868805295388613, 0.04400136747530528, 0.03286643140017986, 0.05184469285554119, 0.02226370935594397, 0.08541634944932801, 0.067734120413661, 0.047175547507192404, 0.03203272220811673, 0.03337200105722461, 0.04336020955815911, 0.06278435673032488, 0.11718008002000195, 0.02871876396238804, 0.04494737760562982, 0.044795083813369274, 0.08549322746694088, 0.008402230434252747, 0.041421302527721436, 0.13206821041447775, 0.03518033080867358, 0.06981527552540813, 0.0212421358696052, 0.08033108910811798, 0.043115763925015926, 0.027307365322485566, 0.02700424676627985, 0.032151974737644196, 0.11067951776619468, 0.022037692733907273, 0.12212456470089299, 0.06441951755966459, 0.05497683085767286, 0.06888636787022863, 0.07169194053858519, 0.08300906326621771, 0.050478951140706024, 0.05454715873513903, 0.06032779533416033, 0.038883880113384554, 0.04495766758918762, 0.03464448491909674, 0.08387143377746854, 0.0517182274987655, 0.08768592695040361, 0.058952160578753264, 0.11961170525423118, 0.06489918753504753, 0.05757706865136113, 0.13779508668397153, 0.05282945751345583, 0.026470662094652653, 0.03876737904335771, 0.03464901414034622, 0.03498026815110019, 0.06368085755301373, 0.06819331898753132, 0.03958923762132015, 0.01912107102439872, 0.0412663420928376, 0.01653131659674857, 0.04024776942761881, 0.07777073221015078, 0.07536641801042215, 0.026286682413358773, 0.05459102941676974, 0.015177249076909252, 0.04992393324417727, 0.043899180101496835, 0.05098895841677274, 0.06574854374464069, 0.07530302248362984, 0.07169802699770246, 0.027371966945273534, 0.026707123066963892, 0.03269671282864042, 0.04620297612356288, 0.09303596522659063, 0.027891153103805015, 0.03105496342426964, 0.013709343736991286, 0.04258628947926419, 0.08473571775747196, 0.02914568123274616, 0.012078056494439287, 0.02631201721461756, 0.06470290092485291, 0.00214791829265388, 0.05838719875152622, 0.025245894511629428, 0.043788226055247445, 0.046986494080296586, 0.0941499840202076, 0.06120225055409329, 0.11601190056119647, 0.029710809301052774, 0.05999147266681705, 0.016258577749665295, 0.07333098937358175, 0.034438583467687876, 0.04866579021992428, 0.10272078375731196, 0.4281392033611025, 0.999914716397013, 3.1301645508834293, 3.9988385438919067, 6.003153690270015, 8.352094275610787, 15.9114442552839, 22.826268911361694, 30.382082257952007, 42.69839654650007, 59.57951055254255, 50.77838373184204, 64.26514639173234, 69.12188162122453, 63.28879942212786, 65.52417387281145, 62.16701275961739, 67.10657051631382, 63.70059830801827, 63.62976142338344, 60.40333066667829, 65.81046744755336, 73.12831715175084, 68.95201901027134, 59.67911992754255, 52.00249998910086, 69.61308452061245, 63.80797576904297, 51.48936857495989, 54.22432197843279, 51.43838964189802, 52.882763794490266, 56.29968636376517, 64.8952785219465, 56.10581772668021, 73.58696774074009, 66.1738234928676, 68.15385859353202, 48.16200828552246, 46.20941162109375, 34.28972830091204, 27.225050108773367, 16.89514241899763, 11.169641784259252, 4.5159595268113275, 3.0809261415685927, 1.1280314645596912, 0.7769222163728305, 0.4485621846147946, 0.11333930040044443, 0.0618978100163596, 0.025020841409319212, 0.024865190565053905, 0.1268505203936781, 0.015643904750634516, 0.038398038862007, 0.026284202367865613, 0.011179425919960653, 0.09446312793131385, 0.027359010319092443, 0.05991003489387887, 0.02059669978916645, 0.08339498684342418, 0.03523148556372949, 0.015407046835337366, 0.08544971980154514, 0.023089461028575897, 0.03655454742589167, 0.05673659107248698, 0.040918199345469475, 0.03884308658806341, 0.059590146344687255, 0.016438830577369248, 0.027029693525816714, 0.012229457164981535, 0.06452675323401179, 0.02999428766114371, 0.049533066539359946, 0.003233221696323848, 0.09947572395737682, 0.043383693655154536, 0.01480784104205668, 0.056193243978278976, 0.014303221334038036, 0.03703715545790536, 0.06925342817391668, 0.12210125023765223, 0.011117421389956559, 0.0352137079462409, 0.09625614314739193, 0.049880218625600846, 0.04832800191694072, 0.005205007353132325, 0.031192665320954154, 0.044631505983748605, 0.036864057781973054, 0.095417311015938, 0.06270464922168426, 0.06005059342299189, 0.06434382019298417, 0.03332816769501992, 0.0196800922775375, 0.16527466928320272, 0.004805419776987816, 0.04594387074134179, 0.03584674719188895, 0.09906993287482432, 0.026729611413819448, 0.04418823941211615, 0.10016462020576, 0.1284622989062752, 0.1597037882144962, 0.20668340873505386, 0.21894623285957746, 0.15862099560243742, 0.12273148713367325, 0.15433398421321595, 0.2522850196276392, 0.2885100772338254, 0.17903567158750125, 0.19993471301027707, 0.17236507524337086, 0.15408754029444285, 0.1825410784887416, 0.20310690493455955, 0.16887751381312097, 0.18444625554340227, 0.11661384254693985, 0.16512901495609963, 0.1648006582898753, 0.10557143150695733, 0.2644658631512097, 0.15601544827222824, 0.16709958921585763, 0.1213679031601974, 0.13748353054480894, 0.1636864495064531, 0.15402915914143833, 0.07640167924442462, 0.13032756453113897, 0.15799316072038241, 0.12027196053947721, 0.17787833511829376, 0.18692514752703054, 0.15544915651636465, 0.2694976345768997, 0.1594572900129216, 0.0869027686172298, 0.21579058361904963, 0.13635200554771082, 0.12442148716322013, 0.18698948621749878, 0.18487492682678358, 0.13124016698982033, 0.10860199281679732, 0.1471316335456712, 0.14914144070020743, 0.13317676021584443, 0.1513919649379594, 0.07198579369911126, 0.1968049295246601, 0.10926454155040638, 0.15325953758188657, 0.1406801768711635, 0.19017311824219568, 0.15471297316253185, 0.1531563052641494, 0.13466014633221285, 0.17622055193143232, 0.1589465838457857, 0.17739828516330036, 0.08846953990203993, 0.10198178448315177, 0.13792665462408746, 0.19217840635350772, 0.2543597083006586, 0.42872228207332747, 0.574667863547802, 2.514862699168069, 4.438008555344172, 7.912614635058811, 13.979200601577759, 19.26994115965707, 30.212650435311453, 45.88669211523873, 52.45749929973057, 73.94079085758754, 68.50827925545829, 76.09500340053013, 77.48170403071812, 68.96970912388393, 73.15309442792619, 71.02590342930385, 77.43408107757568, 77.52355997903007, 77.99293858664376, 77.01474339621407, 79.05292797088623, 83.2162538255964, 80.98069177355084, 66.02597972324916, 59.9833676474435, 79.60048076084682, 71.74841185978481, 59.536390032087056, 62.81620379856655, 59.92832401820591, 62.61687387738909, 66.98018278394426, 69.62220750536237, 67.82232529776437, 83.45111683436802, 78.85168729509626, 73.91185855865479, 66.81576756068638, 59.70973369053432, 50.25105019978115, 30.118266105651855, 19.501415184565953, 9.380442431994847, 4.2248925396374295, 2.568715580872127, 0.8275736612933022, 0.46360519741262707, 0.3206843893442835, 0.18237019622964518, 0.16883843019604683, 0.19461110367306642, 0.10711871526603188, 0.25948381477168625, 0.19714814610779285, 0.0862762365224106, 0.1210201946752412, 0.07687228399195842, 0.14804423600435257, 0.09980176681918757, 0.1594302300363779, 0.06343224232218095, 0.13291859121194907, 0.177567864635161, 0.1476563582462924, 0.24235427965010914, 0.0986484812040414, 0.1879016137016671, 0.24072804834161485, 0.12743320555559226, 0.08603548551244394, 0.09695924791906561, 0.15351397464317934, 0.12255995348095894, 0.1905262821487018, 0.1414888006235872, 0.10337310696818999, 0.10731437762400933, 0.11102037304746253, 0.22277254611253738, 0.11224483698606491, 0.10671889529164348, 0.08104164419429642, 0.12909919901617936, 0.11841608583927155, 0.22787852212786674, 0.2752658064876284, 0.11290579794773034, 0.12500915277217114, 0.15890637386058057, 0.17398563399910927, 0.18251479204211915, 0.18120255959885462, 0.20956307064209664, 0.29581811651587486, 0.13672310992011003, 0.21081302714134964, 0.16474921176476137, 0.1278988298560892, 0.10339333409709589, 0.1056535274588636, 0.10354390101773397, 0.2678549555795533, 0.1454096066632441, 0.1380233322935445, 0.11896253723118987, 0.2238811637674059, 0.15257197804749012, 0.2044522634574345], [0.04462171472342951, 0.07019597438297101, 0.1282276886382273, 0.07996680401265621, 0.05715388671628066, 0.007913007533976009, 0.01593345430280481, 0.04104267320196543, 0.043570131329553466, 0.03343580709770322, 0.06055245827883482, 0.024401354204331125, 0.0505281110028071, 0.04954692900979093, 0.06356431237821068, 0.03095923570383872, 0.03496553376317024, 0.04354286100715399, 0.03867642481678298, 0.0959463037018265, 0.017938747503129498, 0.06161661831928151, 0.04804703074374369, 0.02868678799963423, 0.05727480165660381, 0.04958181928044983, 0.030840841521109854, 0.05814324505627155, 0.017721385595255663, 0.04078672979293125, 0.01272361895202526, 0.11483544297516346, 0.03679918304884008, 0.056378823305879316, 0.034387567812310796, 0.02150468312070838, 0.019762558031028936, 0.035701211608414135, 0.021741554606705904, 0.026026221657437936, 0.07610841640936476, 0.046961422211357524, 0.031989665768508396, 0.0629829028621316, 0.025506955771041766, 0.12498118355870247, 0.028196346280830245, 0.019167223280029635, 0.03967359648751361, 0.07984303922525474, 0.03423325198569468, 0.04477597287456904, 0.04771467072090932, 0.016360339342749546, 0.019439175026491284, 0.018778999469109943, 0.010724373195054275, 0.0393929170843746, 0.03473691835201212, 0.023650687520525286, 0.013959174393676221, 0.046098909207752774, 0.1650547832250595, 0.025449141194777827, 0.13813896823142255, 0.1375468107206481, 0.037890148615198474, 0.13767219042139395, 0.014900352506499206, 0.33698309904762674, 0.6983110031911305, 2.0984072174344743, 2.8318981443132674, 8.796119775090899, 10.534495660236903, 24.559300763266428, 27.966204030173166, 43.10548455374581, 44.61143364225115, 55.194102900368826, 57.74739217758179, 59.07359831673758, 54.94593061719622, 51.51230110440935, 42.96672902788435, 43.037687505994526, 44.67054544176374, 44.26090397153582, 48.4252929006304, 59.206802231924875, 65.33837904248918, 58.23630217143467, 52.0199955531529, 68.17086083548409, 89.26273604801723, 26.47204950877598, 23.136662312916346, 24.242304836000713, 31.04671219417027, 34.4537023135594, 52.266944953373496, 59.8885177884783, 57.98363787787301, 52.51193496159145, 43.67369433811733, 38.93524176733834, 25.842773744038173, 18.384295974458965, 9.255055240222386, 6.5146631343024115, 3.0257570104939595, 1.1202359114374434, 0.3180668183735439, 0.11136942503175565, 0.13096609312508786, 0.06935585303498165, 0.02653493293161903, 0.0814806834927627, 0.030147721392235587, 0.05528047188584294, 0.12062015756964684, 0.05393673845433763, 0.056707705836743116, 0.026151350300226892, 0.05778738736574139, 0.028766753351581947, 0.034906100880886824, 0.04935650494215744, 0.13667269476822444, 0.08499212257031884, 0.012190951999010784, 0.09770699350961617, 0.03213442103671176, 0.06184634313519512, 0.08403263334184885, 0.031052812468260527, 0.04558178409934044, 0.0013259877263668127, 0.007370532357266971, 0.053756261710077524, 0.02726820876289691, 0.04750735791666167, 0.025700611361701573, 0.001367103131737427, 0.06248878687620163, 0.04139037490157144, 0.05114439043349453, 0.1688834306384836, 0.01489305995138628, 0.08767235625003066, 0.027062178389834504, 0.03417894204280206, 0.018234059513945664, 0.02824527713736253, 0.006844876791417066, 0.0249385402005698, 0.05324205430224538, 0.05452967967305865, 0.11130706087819167, 0.032716699077614715, 0.04024898400530219, 0.07672863134316035, 0.0642251715596233, 0.12683217280677386, 0.01231357006223074, 0.007588190276042691, 0.05532784041549478, 0.03821978771260806, 0.06924949267080852, 0.041178722865879536, 0.04529054669131126, 0.08717913593032531, 0.08754112079207386, 0.01406234479509294, 0.045811244286596775, 0.02242480544373393, 0.015302538871765137, 0.09044110482292515, 0.09949202236852475, 0.0532236693959151, 0.06481713229524237, 0.0155520158420716, 0.018391545795436417, 0.0600915022992662, 0.028202319085331898, 0.05962278387908425, 0.11282205315572874, 0.0031673454879117863, 0.059812488699597974, 0.07353363385690109, 0.07336686352001769, 0.03137236174994281, 0.019587757232199823, 0.0209112482677613, 0.08308278609599386, 0.022002600599080324, 0.04222388392580407, 0.08695259344364915, 0.07885519401835543, 0.04932572998638664, 0.07737912929483823, 0.029176853131502867, 0.029238643922976086, 0.020162861461618116, 0.0059226416799772, 0.029080864175089767, 0.024203379738277624, 0.06133114506623574, 0.06443821798477854, 0.041827704291790724, 0.017801741104839102, 0.05284263127084289, 0.032201042997517755, 0.029317106319857494, 0.02644928145621504, 0.03527468449569174, 0.016342134248199205, 0.023033185030466745, 0.0618378682328122, 0.06243001895823649, 0.08969725402338163, 0.03779044807223337, 0.047070564569107125, 0.07229027271802936, 0.05860551739377635, 0.034156435036233494, 0.05208267204995666, 0.06337345404816525, 0.1005616717572723, 0.028584722762129137, 0.05300272821581789, 0.0502439642857228, 0.03314006421715021, 0.039183541533670256, 0.012912971782498062, 0.0480551595932671, 0.04127520376018115, 0.13019723152475698, 0.061886749895555634, 0.01722349695462201, 0.08006086932229144, 0.03197062607588513, 0.044724573846906424, 0.19256614840456418, 0.06493130938283034, 0.7068882829376629, 1.331165415900094, 4.656541994639805, 8.187142304011754, 12.269468665122986, 18.934655836650304, 27.702453885759624, 31.88528333391462, 54.22873408453805, 54.285396644047324, 65.01050744737897, 72.18717670440674, 66.86885874611991, 67.07314968109131, 65.25273554665702, 62.23696722303118, 65.79990618569511, 60.57404095785958, 51.09325177328927, 54.019558565957205, 71.34069156646729, 81.48604815346854, 63.10685389382498, 59.14066232953753, 77.67999172210693, 99.63579205104283, 38.04504203796387, 40.074937411717, 38.951316424778526, 50.597921643938335, 60.66517353057861, 66.84990406036377, 73.20479597364152, 74.65120247432164, 56.51729352133614, 50.96559599467686, 43.027793271201, 36.75268752234322, 29.99898985454014, 17.607721873692103, 11.217078004564558, 5.878544696739741, 2.49453552705901, 1.3201865021671568, 0.4589137520108904, 0.11888175085186958, 0.12852087004908494, 0.023358339011403065, 0.07245056983083487, 0.04037038070548858, 0.014272980724594422, 0.09967355084206377, 0.07614809713725533, 0.04580753270004477, 0.03136076219379902, 0.034139318990388086, 0.041798126950327835, 0.01918118753071342, 0.05284187809697219, 0.03165904279532177, 0.01220683056661593, 0.023506960232875178, 0.08735595537083489, 0.03822858152644975, 0.04374016881255167, 0.05371743254363537, 0.02145854613211538, 0.04738567962444254, 0.009256376252908791, 0.011133696900547614, 0.06517705441053424, 0.03014641521232469, 0.040347649782363854, 0.05698444295142378, 0.03369446464681199, 0.04617988896955337, 0.043235264119825194, 0.02755489489728851, 0.07536282177482333, 0.11388602320637022, 0.12669798572148594, 0.01310567487962544, 0.05313703743740916, 0.0263370483714555, 0.0074761454847508246, 0.023643547635791556, 0.04928220535761543, 0.011736541337865804, 0.011311185546219349, 0.07856837048062257, 0.0949002266196268, 0.08325577859899827, 0.13927617935197695, 0.08006543586296694, 0.010609993395129485, 0.07325044726686818, 0.14150811173021793, 0.12440813359405313, 0.09260374520506177, 0.09942067441131387, 0.015949079267946736, 0.005616992612236312, 0.07178308136229004, 0.05244790030909436, 0.02982130872883967, 0.024905278413955654, 0.019780997220160704, 0.15933514013886452, 0.21587298491171428, 0.23227268776723317, 0.12605968782944338, 0.12922122675393308, 0.1498999342854534, 0.09427488874644041, 0.17087813360350473, 0.1254453829356602, 0.16763852243976934, 0.1465023873107774, 0.16771316129182065, 0.12417342833110265, 0.15912015310355596, 0.23334545163171633, 0.13248991992856773, 0.08988007849880628, 0.09203351794609002, 0.19099174360079424, 0.12040993385016918, 0.17463139577635697, 0.2130943432982479, 0.17342924885451794, 0.12245974742940494, 0.11972910538315773, 0.21268092548208578, 0.164805231615901, 0.11433013794677598, 0.08207693256969963, 0.14856910998267786, 0.1425498936857496, 0.1631274452166898, 0.2116573146943535, 0.09756892520402159, 0.18738659205181257, 0.16681749506720475, 0.13009988889098167, 0.14609488631997788, 0.09859377771083798, 0.15093977563083172, 0.14910602117223398, 0.13217776667858872, 0.1846210325935057, 0.16409012355974742, 0.14641073080045836, 0.19677879235574178, 0.16124149784445763, 0.1205877914492573, 0.20829665288329124, 0.20319229178130627, 0.1785417523767267, 0.15074186053659233, 0.1859860686319215, 0.10460809498493161, 0.13897846532719477, 0.08686517099184649, 0.09233324721987758, 0.1531605664640665, 0.10075423999556474, 0.13170007802546024, 0.21071292965539865, 0.24064632558396884, 0.33528830856084824, 0.16818341320114477, 0.15668601728975773, 0.14649733901023865, 0.12960786957825932, 0.21957660546260221, 0.1460416620331151, 0.43162600483213154, 0.8166537529655865, 3.2442728621619086, 6.634970758642469, 13.207044686589922, 20.31676891871861, 35.29213448933193, 42.49356017793928, 67.0666253226144, 66.95543330056327, 82.93659578050885, 82.54064573560441, 77.3406903403146, 74.31547941480363, 75.09038421085903, 68.35768399919782, 72.92875794001988, 71.8012112208775, 62.452055658612935, 72.68881579807827, 82.48231560843331, 95.54634639195034, 81.12171241215297, 73.97850567953927, 88.78436647142682, 109.36082431248256, 42.22348369870867, 45.498009886060444, 46.43174007960728, 61.65546553475516, 68.24913229261125, 71.91281318664551, 83.05167184557233, 83.30493368421281, 73.58425794328961, 65.85545008523124, 58.722637857709614, 41.74094867706299, 31.80979115622384, 16.890612193516322, 11.228839567729406, 6.011194058826991, 1.9747097407068526, 0.5900635517069271, 0.390632013125079, 0.1939303973423583, 0.20804859405117376, 0.15984914398619107, 0.206468082432236, 0.14114322273858956, 0.1477142372833831, 0.2514107951096126, 0.1739975762154375, 0.10419528785028628, 0.12662945368460246, 0.14899071093116487, 0.13965710891144617, 0.1388263649174145, 0.1517330373504332, 0.2611982827740056, 0.17840652034751006, 0.08742828041847263, 0.23581377203975404, 0.21163686364889145, 0.14529211153941496, 0.19996517923261437, 0.09266692360064813, 0.19921180180140904, 0.11209272979093449, 0.0972409417320575, 0.17820894452078, 0.182975938011493, 0.1312325538269111, 0.13446460611053876, 0.12634100844817503, 0.17036927305161953, 0.06583998312375375, 0.1701542724456106, 0.20327910355159215, 0.1864060546670641, 0.21454913594893046, 0.09213895550263779, 0.2239563183060714, 0.07697496669633047, 0.10955490025558642, 0.08264501565801245, 0.08657547725098473, 0.15627338657421724, 0.1169644823031766, 0.2265714601214443, 0.27191194359745297, 0.10386640871209757, 0.24435723360095704, 0.12152777958129134, 0.16050289890595845, 0.09091030500297036, 0.14809836952814034, 0.2139196183000292, 0.13577481651944773, 0.1755423561802932, 0.08378557874155895, 0.09382162735398326, 0.17091548017093114, 0.20390060091657297, 0.23561783826776914, 0.07078654412180185, 0.1158816489790167], [0.06556709669530392, 0.07031321844884328, 0.06082781457475253, 0.00588682817760855, 0.09692410659044981, 0.06523774258260216, 0.12320591881871223, 0.005088186947562332, 0.02739735772567136, 0.04846565970884902, 0.03733743434505803, 0.04379330828253712, 0.01657619490288198, 0.027075129927002957, 0.04337539517187646, 0.0305668592586049, 0.024715614305543046, 0.041928130867225785, 0.049884357689214606, 0.0279087559985263, 0.05309230501630476, 0.17860804524804863, 0.028092150443366597, 0.013541328288348657, 0.1023659302986094, 0.018717310457889522, 0.08979695795902184, 0.0440284715566252, 0.017571790676031793, 0.02270741867167609, 0.0416146544739604, 0.07177310689751591, 0.10784823540598154, 0.04708491897742663, 0.055898057496441264, 0.03675598072420273, 0.03929404096145715, 0.01252249353897891, 0.030068339580403905, 0.06856245560837643, 0.02879894644554172, 0.10495579668453761, 0.024752845522016287, 0.03844907148075955, 0.06826736751411643, 0.022224678325333765, 0.012550224417022296, 0.028789134829172065, 0.07047692859279257, 0.050830805474626164, 0.06317797489464283, 0.0933891087770462, 0.06198562601847308, 0.035975054771240265, 0.10212097237152712, 0.02485904303778495, 0.021837993092568855, 0.054033863956906965, 0.04793648721118059, 0.019013126280957034, 0.06604317043508802, 0.03516259051061102, 0.03501205751672387, 0.2033529688737222, 0.08081765299929039, 0.06413285008498601, 0.11024133342185191, 0.08467717375606298, 0.1272018386849335, 0.08191023687166826, 0.0911033617864762, 0.28011195787361687, 0.6620647481509617, 3.225146859884262, 3.6920946836471558, 7.5796352454594205, 19.344523123332433, 33.204833098820274, 37.810807841164724, 41.22904709407261, 48.17555727277483, 53.26929555620466, 68.3033560344151, 60.12469400678362, 47.90281615938459, 36.74013907568795, 33.18685463496617, 28.82153422491891, 26.87694362231663, 26.323154824120657, 23.44612291881016, 30.32008695602417, 26.52420268739973, 40.53201075962612, 51.3437899180821, 14.125724213463918, 14.16079785142626, 23.427949905395508, 37.07283966881888, 49.046215193612234, 51.98709583282471, 58.70247418539864, 54.113901206425254, 40.320087228502544, 36.29696559906006, 24.71820953914097, 18.0821361882346, 8.680270722934178, 1.8936752889837538, 0.7344840850148882, 0.647046434027808, 0.2970022958304201, 0.198943129075425, 0.08055619988590479, 0.0637546753776925, 0.19041570808206285, 0.08519795616822583, 0.04619771069181817, 0.10371681209653616, 0.04429954629657524, 0.05652684572019747, 0.016181019500696232, 0.039260222776127715, 0.009575950131485505, 0.060111715857471736, 0.08085076550820045, 0.015547396714932151, 0.013584979294267083, 0.015078009937756827, 0.026365263553868448, 0.005388883981920246, 0.048565224544810395, 0.03607513190114072, 0.031141171298388923, 0.00798587201695357, 0.005938094042773757, 0.005129854934888759, 0.039015712682157755, 0.020731456843870025, 0.029654246621898243, 0.02503800155994083, 0.010281364466728908, 0.0873442574271134, 0.0826761672007186, 0.08795362258596079, 0.048966167494654655, 0.03989131123359714, 0.03485563483887485, 0.0424342704936862, 0.017795530813080922, 0.023754476236977747, 0.04581138677895069, 0.04649780298184071, 0.05240266577207616, 0.027928599755146673, 0.02235083664501352, 0.007396825589239597, 0.040639962668397596, 0.0361743438988924, 0.06038855814508029, 0.026088239758142402, 0.0210861796845815, 0.017935853551274965, 0.05420701252296567, 0.07391173392534256, 0.04909955390862056, 0.0935279166858111, 0.028774692211300135, 0.06170258192079408, 0.06374799180775881, 0.04899322747119835, 0.16038347674267633, 0.10443352828068392, 0.03649089066311717, 0.04202524619176984, 0.05580953921058348, 0.07809692434966564, 0.031179203186184168, 0.04670485794278128, 0.01745290625175195, 0.029707240206854682, 0.021986790733145814, 0.1274265559124095, 0.007629105089498418, 0.09931020212492772, 0.026060906671253697, 0.05922698083200625, 0.0387952973667, 0.0238482548655676, 0.09850649775138923, 0.098908841876047, 0.015216804275821363, 0.09419884532690048, 0.04707020494554724, 0.0660035711313997, 0.03002157833959375, 0.07358251551964454, 0.13040619316909993, 0.023202549067458937, 0.0296329813344138, 0.025296964449808, 0.016051901071997624, 0.04505572947008269, 0.07759548018553428, 0.024926268894757544, 0.0527575836916055, 0.04682694335601159, 0.0029147606151777184, 0.015021779740761434, 0.014439136987285954, 0.012146841285617223, 0.05637941023867045, 0.011444210640287824, 0.0033976987968864186, 0.08021381790084497, 0.030064499072198356, 0.022663334251514504, 0.015091215925557273, 0.11391438597014972, 0.05851535366049834, 0.13613577000796795, 0.022045943719734038, 0.023569901141205003, 0.04105251195973583, 0.05174439520175968, 0.04598299167784197, 0.1439558725271906, 0.016706490589837943, 0.06131112149783543, 0.015862136879669766, 0.04199404375893729, 0.03356259136593767, 0.04558277136779257, 0.003927646520813661, 0.02490739374687629, 0.0442466036017452, 0.005494400842248329, 0.03224365160401378, 0.08831104769238404, 0.08089959967349257, 0.0992474579917533, 0.0836997644177505, 0.06943030868257795, 0.09542616589793138, 0.06578010919370822, 0.18747394665011338, 0.41562891751527786, 1.1656428234917777, 2.5073184754167284, 7.853250094822474, 11.081271120480128, 17.939857925687516, 26.781160967690603, 41.45952231543404, 47.929830755506245, 56.520451477595735, 65.58591556549072, 64.25570378984723, 73.41014998299735, 67.74990422385079, 58.66252899169922, 54.64246456963675, 49.932812282017295, 49.61187151500157, 41.19553940636771, 40.284363065447124, 37.8261981010437, 39.56380360467093, 36.84978859765189, 48.00009093965803, 56.97554111480713, 22.304552997861588, 28.703036172049387, 48.37893104553223, 59.941796575273784, 62.7758069719587, 70.25269399370465, 68.95907143184117, 60.647330556597026, 48.96630048751831, 44.82053620474679, 34.20693704060146, 25.56018877029419, 17.258514097758702, 6.707461748804365, 4.189135806901114, 2.4718900450638364, 0.6974926899586404, 0.34181635826826096, 0.1941687259823084, 0.09714881703257561, 0.0730724675314767, 0.11788045029555048, 0.047634444132979424, 0.042329162026622465, 0.04819196582372699, 0.0910466362589172, 0.04281959696007626, 0.06538716277905873, 0.0271035232248583, 0.03229330340400338, 0.02127132983878255, 0.0033400360428329024, 0.03242159401997924, 0.07526186933474881, 0.0226830151597304, 0.027964473901582614, 0.05553524821464505, 0.039631286436425786, 0.01755146515954818, 0.01953110464715532, 0.10133599556450333, 0.048127338755875826, 0.011187606507779231, 0.030173865346504108, 0.01851820114201733, 0.03132615351517286, 0.06951441309813942, 0.085334626691682, 0.1271641528499978, 0.02965952901701842, 0.04666014248505235, 0.007631904046450342, 0.04829415998288563, 0.024975106452724764, 0.018782918008842638, 0.07017661577888898, 0.0275818089888032, 0.039839294739067554, 0.024469641968607903, 0.12594236912471907, 0.04652183669220124, 0.05662498563261969, 0.04085054261876004, 0.06045101050819669, 0.05891235092920916, 0.094502211548388, 0.057257594008530886, 0.03842875953497631, 0.1352989599108696, 0.06467860258583512, 0.04639496760708945, 0.07671797834336758, 0.009793459620725895, 0.0726358031055757, 0.11426854053778307, 0.022890188864299228, 0.1259100708578314, 0.06957145075180701, 0.06270118190773896, 0.02368083143872874, 0.016877944514687573, 0.16191225685179234, 0.1761680468916893, 0.10922139350857053, 0.08382182608225516, 0.17596076801419258, 0.13247716347021715, 0.2501538225582668, 0.07922150114817278, 0.18670669996312686, 0.12967602163553238, 0.14884137894426072, 0.1934401693620852, 0.07125296909362078, 0.16097180731594563, 0.196932602673769, 0.09055720894996609, 0.12725253882152693, 0.14220572715359076, 0.06093570842806782, 0.24830017345292227, 0.29875264476452557, 0.1930425071290561, 0.08081279468855687, 0.14422930856900557, 0.12486138141580991, 0.12193518557718822, 0.14596946590713092, 0.2556024587580136, 0.07492066800062146, 0.12952754460275173, 0.123392787362848, 0.21312790364027023, 0.19421015733054706, 0.10596863233617373, 0.16994217596948147, 0.11695796836699758, 0.18090086935886315, 0.15171747175710543, 0.17129825534565107, 0.1536657086440495, 0.08233327631439481, 0.1562005661960159, 0.11358128634414502, 0.16557424249393599, 0.2203996820109231, 0.11319311681602683, 0.09415066934057645, 0.09903857098626238, 0.16754572599061898, 0.10839598279978548, 0.17974142943109783, 0.15422672139746801, 0.12886315025389194, 0.14729817318064825, 0.13600878896457808, 0.15066370687314443, 0.08523294821913753, 0.0671035171087299, 0.13865047506988049, 0.11877450160682201, 0.14616257697343826, 0.16544861852058343, 0.10357578537826027, 0.22697782117341245, 0.12131481458033834, 0.18984301095562323, 0.1502836729798998, 0.18033100850880146, 0.23453666056905473, 0.18924853285508497, 0.3638854926185948, 0.7034486532211304, 1.4366980216332843, 5.698027891772134, 9.60764331477029, 14.659688064030238, 30.224837575639995, 42.837127753666465, 56.13601459775652, 62.85647555759975, 76.51980236598423, 73.74250316619873, 84.01729079655239, 81.85543523515973, 76.80920873369489, 68.42424774169922, 66.12361580984933, 57.39140469687325, 51.603947843824116, 45.93136555807931, 41.56158093043736, 55.83249296460833, 48.19884763445173, 61.18766416822161, 80.04979991912842, 29.517309461321148, 32.39981828417097, 56.16274779183524, 68.13270132882255, 78.52612945011684, 81.49185684749058, 82.5714748927525, 71.33303465162004, 59.40365859440395, 49.650913442884175, 35.41470071247646, 26.835443769182476, 13.615650006702968, 4.671085008553096, 2.159632137843541, 1.236219150679452, 0.3830192301954542, 0.3765138164162636, 0.2393833819244589, 0.2695781902543136, 0.2959653043321201, 0.2495518805725234, 0.09782479397420372, 0.2225450604621853, 0.13241462968289852, 0.20517088632498467, 0.20580466517380305, 0.12737257166632585, 0.16231632445539745, 0.09581275443945612, 0.18513950120125497, 0.11744576719190393, 0.11216487163411719, 0.1712594838546855, 0.12786259608609335, 0.10007858196539537, 0.1731182084019695, 0.13999368942209653, 0.0982315553618329, 0.0747517059956278, 0.1605916377156973, 0.11521823172058378, 0.10349919234535523, 0.1357455580894436, 0.07715146044003111, 0.05248922309173005, 0.2710787568773542, 0.16008238361350127, 0.2096406543361289, 0.17537705147905008, 0.14789331624550478, 0.13117436266371182, 0.13297599527452672, 0.09949511648820979, 0.060792598607284684, 0.2150816773729665, 0.1154762650174754, 0.11796566072319235, 0.20863005785005434, 0.16594997447516235, 0.07032487568046365, 0.12279790214129857, 0.12698337755032948, 0.1473182306757995, 0.17725823553545134, 0.1761797991182123, 0.18348209799400397, 0.0995153436171157, 0.2670748031565121, 0.21613667719066143, 0.13437966709690435, 0.21070603573960917, 0.21095558734876768, 0.14702291866498335, 0.16754268615373544, 0.09011224604078702, 0.2308249654514449, 0.21609392948448658, 0.1852199211716652, 0.1257307611938034, 0.2861995840711253], [0.05487687586407576, 0.09646598010190896, 0.15893861784466676, 0.02606905926950276, 0.1415550663535084, 0.13723893224128655, 0.11891432053276471, 0.05015044519677758, 0.07085462154022285, 0.0231240493511515, 0.013770768967723208, 0.03697464202663728, 0.06087831115084035, 0.04132306422772152, 0.07136775007737534, 0.07148569303431682, 0.014558857705976282, 0.05522305764524, 0.06962633744946548, 0.045030460825988224, 0.04637517134792038, 0.0048600638983771205, 0.007529955008067191, 0.04951498358111296, 0.06589133465396506, 0.01957585063896009, 0.05204488782744322, 0.01474498664694173, 0.043312264273741415, 0.12343550792762212, 0.047390110458114316, 0.06957239391548292, 0.045816031351153336, 0.06306200647460562, 0.054468777762459855, 0.07365317137113639, 0.052921436327908716, 0.02929795127628105, 0.07039280382118054, 0.051478613034955094, 0.021619470889813135, 0.03471819078549743, 0.04152360185980797, 0.025273266614281704, 0.03651922967817102, 0.04406712769663759, 0.04670855935130801, 0.026715723498325263, 0.004759467689187399, 0.047656801861843893, 0.049200591165572405, 0.023117672818313752, 0.05924187467566558, 0.06349903052406651, 0.01664485246874392, 0.04143147716032607, 0.06523866539022752, 0.005700359120965004, 0.09820849874189921, 0.033553302221532376, 0.06527384743094444, 0.1269593709813697, 0.10005261443023171, 0.12391181236931256, 0.04442842384534223, 0.05706633534282446, 0.08627632473196302, 0.07245395572057792, 0.06194821838289499, 0.0659580889290997, 0.13391814114792006, 0.06325067313654081, 0.14276778485093797, 0.6459976360201836, 1.304266659276826, 1.4415327736309596, 4.649347134998866, 10.558171646935598, 21.107513870511735, 28.50432116644723, 38.87905863353184, 44.09802777426583, 46.40683078765869, 64.17684868403843, 66.44717257363456, 62.49024990626744, 49.5582731110709, 38.2536894934518, 44.58817107336861, 27.7643814427512, 18.941946234021867, 16.904503379549297, 25.657605988638743, 16.380326066698345, 10.634505425180707, 29.836433274405344, 38.81040695735386, 37.454073429107666, 46.18691335405622, 38.028644289289204, 34.46494797297886, 39.822676113673616, 26.54300103868757, 19.37963237081255, 12.818516186305455, 5.6667258228574475, 3.122358466897692, 0.27442849427461624, 0.49004548149449484, 0.3107838034629822, 0.14278261762644562, 0.10724127904645034, 0.15359337681106158, 0.02164729591459036, 0.1397631232227598, 0.04725536018876093, 0.09635699380721365, 0.05964593549392053, 0.05603448374729071, 0.033136847961161814, 0.06411046521472079, 0.06280725050185408, 0.068525217606553, 0.037832948113126416, 0.03474391744072948, 0.07690889774156467, 0.04717969335615635, 0.03235200007579156, 0.0232717715137239, 0.0157489640239094, 0.008044153934211602, 0.07360062561929226, 0.027138135296159556, 0.02925143430807761, 0.041839470089014084, 0.015863018975194012, 0.0338061141914555, 0.02681259285392506, 0.008248397215668644, 0.0914944422298244, 0.006533528453603919, 0.05673556309193373, 0.028847919710512673, 0.07307824864983559, 0.07295575272291899, 0.019132183731666634, 0.053697853415672264, 0.0581669666405235, 0.020798971078225544, 0.019561257047046508, 0.048490938530968766, 0.015588517633399792, 0.05026747213144388, 0.10288702483688082, 0.029898288526705334, 0.061071116876389296, 0.030278536158480814, 0.01729997802924897, 0.03806805031906281, 0.09401541695530925, 0.027967817382887006, 0.05495929751279099, 0.013167106047538775, 0.049605439084448984, 0.035793030967137644, 0.07316145061382226, 0.055742279426859956, 0.057955650479665825, 0.062166197757635794, 0.055330490094742606, 0.02383717269237552, 0.036889489274472, 0.09861256634550435, 0.03315869678876229, 0.07325194004390921, 0.10270219868315117, 0.024848142372710363, 0.14699755502598627, 0.10112087960754122, 0.11177176915641342, 0.022137366135471633, 0.0303340165742806, 0.03146629474524941, 0.03400392072009189, 0.06319774740508624, 0.06654181224959237, 0.04052537167444825, 0.07766920980066061, 0.013877161562309732, 0.0311620158941618, 0.06613115607095615, 0.0503712812039469, 0.01986187689804605, 0.045618774435882053, 0.04500630497932434, 0.08051424606570176, 0.06464269451264824, 0.04100459720939398, 0.05587881424331239, 0.023189356650358865, 0.02684546957191612, 0.01708636842002826, 0.07884960288980178, 0.04229657198967678, 0.04969777412978666, 0.037934809790125916, 0.06910987052002124, 0.016544013683285032, 0.023969266497130905, 0.04828352055379322, 0.040805949297334464, 0.01933234477681773, 0.03366558958909341, 0.03831449763051101, 0.10268460427011762, 0.022277766905192817, 0.08046118462724344, 0.013955690116355461, 0.05526474005143557, 0.023090538202918003, 0.10965443455747195, 0.05286236306918519, 0.03398130175524524, 0.011116179670872433, 0.013790815436680402, 0.025550303980708122, 0.07732711958565883, 0.11066000309905835, 0.10184096811073166, 0.08549444882997445, 0.016608469421043992, 0.026623067845191275, 0.05130269265334521, 0.019954556299905692, 0.015769482922873328, 0.011645243602937885, 0.11161088850349188, 0.037001057394913266, 0.0500299475554909, 0.09161589321281229, 0.029525409785232375, 0.03646289091557264, 0.13431004940399102, 0.07061513939074107, 0.019077244447544217, 0.14868257460849627, 0.2767596149018833, 0.31626682781747406, 0.7307462255869592, 2.4486478865146637, 3.263783403805324, 5.03434247629983, 12.526041320392064, 21.884020226342336, 30.892653260912212, 36.707413060324534, 50.086902482169016, 58.17875024250576, 62.05224241529192, 76.52334594726562, 73.82712527683803, 71.47768224988664, 63.78190612792969, 54.158202920641216, 56.91059977667672, 42.35293558665684, 29.445934091295513, 32.53561040333339, 40.06688444955008, 33.547063146318706, 32.209316049303325, 42.72469547816685, 47.17838307789394, 49.810471875326975, 63.099224771772114, 64.85948140280587, 49.178060735974995, 49.14374705723354, 42.023507595062256, 30.527039051055908, 21.393140418188914, 14.143062574522835, 9.109359332493373, 3.371775563274111, 2.26288041472435, 1.0061509417636054, 0.5094747617840767, 0.27119896614125794, 0.14576623109834536, 0.04434944236917155, 0.19337581710091659, 0.05120138058971081, 0.03674697656450527, 0.024529159667768648, 0.17545474373868533, 0.018830257700756192, 0.0923027606414897, 0.05164497625082731, 0.04774271457323006, 0.05134490092418023, 0.04106374510696956, 0.04484685603529215, 0.0358809589275292, 0.07570716472608702, 0.017454093688034585, 0.02094924453246806, 0.03287966961839369, 0.03684090955981186, 0.05689395012866173, 0.03715826717338391, 0.07144215144217014, 0.023843381287796155, 0.05116705350311739, 0.05850545383457627, 0.09220275815044131, 0.008193480832103108, 0.02320055417450411, 0.07810224406421185, 0.0476390242443553, 0.05889505507158382, 0.07503679926906313, 0.028586975498391048, 0.0556787990831903, 0.02058900350571743, 0.0375142130734665, 0.020376783196947405, 0.04865433654880949, 0.014150802860967815, 0.016419522863413607, 0.025807663831593733, 0.030942150192069154, 0.014839572732203772, 0.02158208191394806, 0.047804966768515963, 0.019427777334515537, 0.028140314555327808, 0.02874126418360642, 0.02171658112534455, 0.055768857643540413, 0.04880921555949109, 0.0901934327557683, 0.08133323783321039, 0.09073252204273428, 0.10931326715009552, 0.05801756680011749, 0.04667884630284139, 0.010444078860538346, 0.044493593741208315, 0.04096482148660081, 0.05552935853068318, 0.028170965678457702, 0.025012291868084242, 0.19805088266730309, 0.127744693841253, 0.27959418137158665, 0.19815216080418654, 0.19919785112142563, 0.22835308951990946, 0.1440890689513513, 0.15999045568917478, 0.13520538993179798, 0.1462208902729409, 0.1508203534675496, 0.22142435131328447, 0.1348956794078861, 0.14627304247447423, 0.14292022452822753, 0.10694686948720898, 0.035876392386853695, 0.15087684829320225, 0.21073616269443715, 0.13048997867320264, 0.10368823898690087, 0.12863746950668947, 0.15939888171851635, 0.10995260320071663, 0.1444764310227973, 0.13615067063697747, 0.1493107351873602, 0.11070547851600818, 0.16025686210819653, 0.1707173479454858, 0.12973457920764173, 0.1852920087320464, 0.14597114867397717, 0.11317764621760164, 0.1321220996656588, 0.15444522324417317, 0.16529836372605392, 0.19396125711500645, 0.17819587593632086, 0.09512933396867343, 0.1931736408067601, 0.11494502638067518, 0.18033121206930705, 0.17641124741307326, 0.22745740972459316, 0.12621351171817097, 0.14756669662892818, 0.15156899472432478, 0.10390644227819783, 0.09790304263255425, 0.21720864038382257, 0.17658529164535658, 0.19579380378127098, 0.3070864661463669, 0.09269698270197425, 0.09625840945435421, 0.12513004057109356, 0.08087759478283779, 0.13794802847717488, 0.16409070709986345, 0.2701709855880056, 0.1914555901395423, 0.15410419154380048, 0.2838235987084252, 0.10617283745003597, 0.15382899131093705, 0.1700504565877574, 0.18836400817547524, 0.15053687510745867, 0.2730426543525287, 0.24916929538760865, 0.29785334159220966, 0.6426106606210981, 1.348654248884746, 2.501030138560704, 3.6965971163340976, 9.661043695041112, 18.146136045455933, 28.568479095186504, 37.13617944717407, 52.268994671957834, 62.31556524549212, 67.21368394579206, 86.04442078726632, 94.62921891893659, 98.27282646724156, 84.12722519465855, 78.65444878169468, 74.63511739458356, 56.06495189666748, 44.32404225213187, 47.746474742889404, 57.18019683020455, 41.69317981175014, 38.09790045874459, 62.81821182795933, 75.32865183694022, 71.68936606815883, 81.19095815931047, 81.61771651676723, 59.18629114968436, 52.7674480165754, 42.80318580354963, 29.90820469175066, 18.800190823418752, 10.440865210124425, 5.767185049397605, 1.6308400269065584, 1.4486081025430133, 0.8502990475722721, 0.39673212436693056, 0.4301281523491655, 0.3307762678180422, 0.11103739749108042, 0.3381268376750605, 0.1644848273800952, 0.2670431562832424, 0.22334149772567408, 0.37625496887734955, 0.11823582622621741, 0.23397258083735192, 0.14788148259477957, 0.1737850047647953, 0.16144100071064063, 0.2345987329525607, 0.16093659134847776, 0.1536415120852845, 0.18842043514762605, 0.18674245875860962, 0.10415173268743924, 0.08243716681110007, 0.15365983253078802, 0.11100750802350895, 0.13735433747725828, 0.27859168659363476, 0.15527041682175227, 0.2308509669133595, 0.16797583576823982, 0.1756565807653325, 0.14471351115831307, 0.14768116548657417, 0.1987430698105267, 0.1798169096665723, 0.16702712167586597, 0.2526224415217127, 0.1406913726989712, 0.13047696437154496, 0.17238681550536836, 0.09009224961378745, 0.19047031658036367, 0.13766670785844326, 0.09469556688730206, 0.13456828626138823, 0.11486349361283438, 0.11443261030529227, 0.08039333112537861, 0.075428049346166, 0.09654640685766935, 0.09832648919629199, 0.21352142680968555, 0.05311879163075771, 0.14843051241976873, 0.10819051561078855, 0.1523566653153726, 0.16253114864230156, 0.2571421632809298, 0.18606095175657952, 0.20902086687939508, 0.15769007269825253, 0.11703149442161832, 0.13144374106611523, 0.08306083548814058, 0.143672733434609, 0.0956648134493402, 0.1957586013845035, 0.13839250962649072], [0.03579444571265152, 0.05598257242568901, 0.14875103879187787, 0.07634781034929411, 0.09714298163141523, 0.12544104031154088, 0.024562552072373883, 0.035511835877384455, 0.05137945192732981, 0.002289018589570852, 0.11900575991187777, 0.07215487784040825, 0.05937205840434347, 0.03426342983064907, 0.03409928881696292, 0.022968564747965763, 0.027909928167771016, 0.010654376370699277, 0.030344320128538778, 0.06612036736415965, 0.0840969177495156, 0.0781202388129064, 0.03815321324925337, 0.08871253007756812, 0.02101528804217066, 0.015595379318775875, 0.04069977553029146, 0.01701534615962633, 0.15296095503228052, 0.08206617100430386, 0.08554607855954341, 0.0728418877614396, 0.0726982011858906, 0.04264789028093219, 0.04462319053709507, 0.044059446680226495, 0.042122534542743645, 0.07718840667179652, 0.033369198707597594, 0.03169641650414892, 0.08433840157730238, 0.03442099584000451, 0.024437903493110622, 0.03015988413244486, 0.012425977869757583, 0.04709023869197283, 0.008103453653997608, 0.07065861312938587, 0.03491237732980933, 0.043656617403030396, 0.023667243774980307, 0.015687641421599046, 0.08401163268302168, 0.06837603489735297, 0.046611254036958726, 0.009376716982972409, 0.05141754488327673, 0.018861236217032586, 0.03965514372768147, 0.0928079638896244, 0.044990277982183864, 0.0690937213865774, 0.061377509364059994, 0.05178326168762786, 0.10048805749309914, 0.052635773085057735, 0.05104335317654269, 0.11523153100694929, 0.09146960784814187, 0.04203396536675947, 0.011375938143048967, 0.017779325700498054, 0.1429155290658985, 0.04525446219901953, 0.1096676184928843, 0.04808742393340383, 0.18547833444816725, 0.6527323403528759, 3.451667687722615, 6.352280259132385, 11.222884093012128, 17.8650484085083, 16.93007275036403, 14.569542135511126, 31.752520629337855, 55.8388922555106, 54.46026195798601, 48.05205651691982, 36.43776042120797, 46.53051567077637, 51.091302803584504, 33.00199086325509, 33.79406813212803, 29.48897123336792, 36.70150709152222, 42.01517670495169, 54.557977948869976, 49.82431616101946, 18.79086807795933, 20.939365727560862, 12.258057117462158, 8.904038327080862, 4.921893264566149, 3.2161928032125746, 1.0420601006065096, 0.48863657138177324, 0.19962878871176923, 0.23488675749727658, 0.15878786093422345, 0.0613090791074293, 0.06083075263138328, 0.1391550065683467, 0.07415819141481604, 0.09158918607447829, 0.0453683373385242, 0.08153361600956746, 0.04533121129497886, 0.0506400183907577, 0.03525710365335856, 0.022923888306000402, 0.00596699836231502, 0.027687232974650602, 0.044105950077729564, 0.034851014015397856, 0.03736276066462908, 0.05219021985041244, 0.02646656713581511, 0.026464545101459538, 0.007274169358424842, 0.030422656996441737, 0.08154843521437474, 0.06709858415914433, 0.05430867742480976, 0.037022773908185105, 0.07367008046380111, 0.03122717221932752, 0.012081502604165247, 0.0890995053840535, 0.04785742431080767, 0.046654246015740294, 0.04810096070702587, 0.006123151322494128, 0.04684745207695024, 0.039195063058286905, 0.025515530757339935, 0.009115336812101305, 0.1249221238706793, 0.031066719043467726, 0.049904723917799335, 0.0765432555760656, 0.035315803717821836, 0.01177989294020725, 0.015160999859550169, 0.04151741362043789, 0.05238927488348313, 0.025025596243462393, 0.027994706029338495, 0.005871118395589292, 0.07167273121220724, 0.020215636219031045, 0.05609669862315059, 0.05533311941793986, 0.010120723845570214, 0.06754622049629688, 0.049349373539111445, 0.04887432777988059, 0.09924262682242052, 0.06318231073341199, 0.07104889968676226, 0.06429189869335719, 0.04779146392164486, 0.06949749043477432, 0.07669425675911562, 0.06380919566644089, 0.01958947053312191, 0.12099156049745423, 0.07318342157772609, 0.12448763075683798, 0.10684321647776024, 0.027443588012829423, 0.04901876074395009, 0.10054782964289188, 0.07438571099191904, 0.031656240445694754, 0.055823092947580984, 0.022414856424022998, 0.07942916000527994, 0.01825331294509981, 0.039772269049925466, 0.0576069513335824, 0.02402364768620048, 0.038368037436157465, 0.04407766195280211, 0.01569497468881309, 0.05340790183150342, 0.010613659180567732, 0.03497861931100488, 0.026024114806205034, 0.01478549518755504, 0.010369609642241682, 0.044246037025004625, 0.08694060372986964, 0.023697996678363, 0.021223192868222083, 0.11774382048419543, 0.06556158699095249, 0.09737451813582863, 0.03284502022766641, 0.02976056288129517, 0.05957511679402419, 0.07235299649515323, 0.03742258031187313, 0.049699517964784584, 0.04094073688611388, 0.048503881586449485, 0.041027657222002745, 0.06431695699159588, 0.03845631144940853, 0.00469012777154733, 0.0327944218713258, 0.011997902000855123, 0.023293106351047754, 0.018701575230807066, 0.07916290286396231, 0.01759326970204711, 0.05336494717214789, 0.04989049503845828, 0.03143202872680766, 0.04332512929769499, 0.05356654331886342, 0.030867100826331546, 0.02392693269731743, 0.03755742896880422, 0.020549231175599352, 0.05651636574683445, 0.021694930769237022, 0.04144881373005254, 0.023859231865831783, 0.03320213320798107, 0.05433604274211185, 0.05446684393765671, 0.03231368998863867, 0.048060363956860135, 0.08406607154756784, 0.075984495558909, 0.04463314803849373, 0.07898326750312533, 0.023769000279051915, 0.26435238495469093, 0.09117881488054991, 0.4136705568858555, 0.5577260383537838, 1.9524188339710236, 3.595904690878732, 8.645442008972168, 14.665609666279384, 20.58948745046343, 28.97776620728629, 26.608439173017228, 26.250077145440237, 46.00733716147286, 68.78232315608433, 68.24892384665353, 63.805787086486816, 52.00548076629639, 60.37116745540074, 54.28163072041103, 45.44605820519583, 46.45060791288103, 45.34366260256086, 55.00288847514561, 59.61237553187779, 72.22398826054165, 65.62288693019322, 42.52916274751936, 28.327902930123464, 19.845997197287424, 17.28286405972072, 9.728888511657715, 5.840734337057386, 3.4966896261487688, 2.0783820748329163, 0.9160817691258022, 0.45987086636679514, 0.19974428894264357, 0.05231077177450061, 0.12376611733010837, 0.11570294999650546, 0.07066598880503859, 0.09812447575053998, 0.06217833674911942, 0.08785061418477978, 0.06003265974244901, 0.08444424625486135, 0.018417816975020936, 0.049907343062971316, 0.022352785736854588, 0.03954836606447186, 0.03623664019895451, 0.015719595331964747, 0.06029167012976749, 0.031148166994431188, 0.06414728931018285, 0.05684597770284329, 0.013324152129436178, 0.03878038316699011, 0.03710150432639888, 0.040678740944713354, 0.04287830720256482, 0.050649643409997225, 0.13452937906341894, 0.043999372582350454, 0.019428964770798172, 0.047370015643537045, 0.021903804204027568, 0.046315453480929136, 0.02330499598091202, 0.03436560024108205, 0.0456198058091104, 0.05034267756023577, 0.01643594171452735, 0.08793940727732011, 0.0884689020791224, 0.01983292041612523, 0.09790389758667775, 0.12254798412322998, 0.053323933122945685, 0.04738957780812468, 0.13410844307925018, 0.0469564146229199, 0.059699661896697113, 0.021304991961057698, 0.008188837108069232, 0.006294840190093964, 0.03457011408837778, 0.03165956187461104, 0.05447345965408853, 0.02071285480633378, 0.023047507208372866, 0.018462803846757327, 0.058846804446407726, 0.027943814206602316, 0.02230881666764617, 0.13053826322512968, 0.08857404786561217, 0.04093466399769698, 0.09848550387791224, 0.053911327317889245, 0.07526530950729336, 0.04397834478212254, 0.039599558138953786, 0.06902981695852109, 0.07521620392799377, 0.25009194016456604, 0.26541073673537796, 0.26634423807263374, 0.09324086923152208, 0.1677505892834493, 0.11223483537989003, 0.1030585245628442, 0.09107493795454502, 0.10449729021638632, 0.1636507042816707, 0.18624905523444923, 0.1366032806358167, 0.1711399531258004, 0.07068187330982514, 0.1128286010186587, 0.11141486652195454, 0.1071928045047181, 0.11008132807910442, 0.1734024060091802, 0.11015248604651008, 0.15855209715664387, 0.08272556455007621, 0.1479206069239548, 0.1392388463552509, 0.16888828894921712, 0.06633757999432938, 0.11829267389007977, 0.20658128921474728, 0.1699584200978279, 0.1798384463680642, 0.15722196495958737, 0.21314507057624205, 0.15027155434446676, 0.15797118975647859, 0.2089525248323168, 0.2006053498813084, 0.1781851008002247, 0.1852481753698417, 0.17190671126757348, 0.1874531970492431, 0.15354970629726136, 0.12555062371705258, 0.10412541909941606, 0.09351520772491183, 0.1382962390780449, 0.09880603025002138, 0.13800521540854657, 0.11454425645726067, 0.12284511460789613, 0.1149819658270904, 0.183250758264746, 0.10250295366027526, 0.16414794831403665, 0.16313201854271547, 0.10608557784663779, 0.16765851208141871, 0.0829426007611411, 0.2037044364426817, 0.15813813651246683, 0.1454226073942014, 0.10778222073401723, 0.15410252234765462, 0.08329252127025809, 0.2253645227423736, 0.13362115994095802, 0.19889602517443045, 0.2931392059794494, 0.19782845888819012, 0.14480743397559437, 0.19381928044770444, 0.1475919924144234, 0.1949635754738535, 0.18220726640096732, 0.28243086487054825, 0.28238513161029133, 1.2154031076601572, 2.198559637580599, 5.456011712551117, 11.103168368339539, 16.22481495993478, 23.616211346217565, 27.21590801647731, 29.587274347032817, 52.39759540557861, 81.93834808894566, 91.61483328683036, 89.54295689719063, 78.80452987125942, 89.30244500296456, 95.68324674878801, 73.20695686340332, 73.04300716945103, 66.15074852534703, 67.1699936730521, 85.78125776563371, 102.95329979487828, 85.38324410574776, 64.46329511914934, 36.1153917993818, 17.390764372689382, 14.526503256389073, 8.12750504698072, 4.207353983606611, 1.8904380798339844, 1.0436707798923766, 0.6097625632371221, 0.37309831540499416, 0.33256236197693007, 0.16126049682497978, 0.27343395192708286, 0.30255176233393805, 0.15734776535204478, 0.26692848386509077, 0.18766295936490807, 0.1998849492520094, 0.11115521152636834, 0.1691597979515791, 0.1189776278500046, 0.21781469429177897, 0.10625941173306533, 0.16320060486240046, 0.08194677598242249, 0.18326815590262413, 0.17812925736818994, 0.20194188744894095, 0.1141598392277956, 0.11188565447394337, 0.12036662974527904, 0.10455776125724826, 0.18876518521990093, 0.12979616304593428, 0.12467555781560284, 0.13864158626113618, 0.2253546839846032, 0.13986403495073318, 0.13457995706370898, 0.15263692741947515, 0.16855020209082536, 0.148792741554124, 0.1673574596643448, 0.17609275664602006, 0.13860003277659416, 0.16214166954159737, 0.15004615858197212, 0.17918201802032335, 0.2827224720801626, 0.1510109675249883, 0.23745175557477133, 0.22302557182099136, 0.1723017543554306, 0.09605244014944349, 0.18034732049064978, 0.1274737005255052, 0.17034209093877248, 0.08899722301534244, 0.11305730124669415, 0.10582390760204621, 0.11515929416886397, 0.16708042738693102, 0.17678809219173022, 0.22126037654067787, 0.120879629360778, 0.1865626469786678, 0.16476678582174437, 0.1554089601018599, 0.2787012292870453, 0.21443738123135908, 0.13992901146411896, 0.1706503222563437, 0.22071142813989095, 0.18687784006553038, 0.1238104799496276, 0.152376546391419, 0.12692431786230632, 0.13970707623021944], [0.05734161699989012, 0.0608312954593982, 0.03804122782977564, 0.01587930042296648, 0.05046253737860492, 0.05955263014350619, 0.043540910218975375, 0.026170030369290283, 0.07336548609392983, 0.0783156772543277, 0.04863259967948709, 0.006314548239710608, 0.025681327396471585, 0.037241218079413684, 0.05209907902670758, 0.035581708020929775, 0.10487082374415227, 0.03587108285033277, 0.04028320252629263, 0.08429146731006247, 0.08176878946168081, 0.004797227738890797, 0.039289067299770455, 0.07026031985878944, 0.03147369756230286, 0.0041783876866767445, 0.03393881867772766, 0.013614292007072695, 0.019163840782961676, 0.07405293027737311, 0.040191674937627146, 0.1145808973482677, 0.0134946433827281, 0.03356025381279843, 0.05445893561201436, 0.05260869275246348, 0.020635096389534216, 0.06274511705019645, 0.03433982948107379, 0.06644528385783945, 0.056696065568498204, 0.010377389046230485, 0.0350588832183608, 0.036957525980791876, 0.045187494185354025, 0.06707247413162674, 0.06875127833336592, 0.07287776190787554, 0.03845711212073054, 0.0512992321247501, 0.020116308870326196, 0.030976992965276753, 0.027290905759270703, 0.0447304058553917, 0.02361281169578433, 0.03127053739236934, 0.048150269846831045, 0.05723180289247206, 0.009950734708192093, 0.07876042303230081, 0.02248048093835158, 0.0032429459513098535, 0.023800268869048784, 0.012729217714097883, 0.029187679157725403, 0.04129643851358976, 0.04181332613474556, 0.09518664303634848, 0.018686939230454818, 0.05746145985488381, 0.13225361332297325, 0.03581522924027272, 0.034981045073696544, 0.11816060383405004, 0.09133045388651745, 0.0400037851982883, 0.05620309630674975, 0.03862815383555634, 0.08994275477847882, 0.08291239916746106, 0.39920082475457874, 0.8782883999603135, 0.8505064621567726, 2.339397017444883, 1.9941121510096957, 3.684011323111398, 17.734149558203562, 36.02839687892369, 45.44614158357893, 33.012718881879536, 31.76156370980399, 35.997275897434776, 38.475350924900596, 42.88512938363211, 38.71428905214582, 36.850646700177876, 35.58320147650582, 18.50282529422215, 3.8072315454483032, 1.8493208118847437, 0.4795991363269942, 0.2430448111678873, 0.022617733305586234, 0.10746342462620564, 0.09953730779566936, 0.04900757170149258, 0.054013134712087255, 0.02535161535654749, 0.02930421076182808, 0.06487878398703677, 0.04844842152670026, 0.12355203953172479, 0.03566449268587998, 0.0644916051200458, 0.029260832018085887, 0.09266729679490839, 0.020356722309121063, 0.05328304460272193, 0.11473495193890162, 0.05965829161661012, 0.06017851084470749, 0.04741554195061326, 0.05790594778954983, 0.04995517638911094, 0.029385533183813095, 0.03935510232778532, 0.02297328395902046, 0.03590399519141231, 0.006819970739473189, 0.0708730641220297, 0.0281274664947497, 0.043901683895715644, 0.016080547124147415, 0.015704652294516563, 0.05236229972381677, 0.021151687151619365, 0.08124649391642638, 0.01792996725998819, 0.022629475354083946, 0.04434728802048734, 0.10435363078223807, 0.05635867081582546, 0.08384347134935004, 0.03725591175524252, 0.09042513889393636, 0.037239464066390476, 0.049139451767717085, 0.049163119069167545, 0.018938268601362194, 0.07166730971740824, 0.08391421541039433, 0.051891637300806384, 0.07719802151301078, 0.0877141540071794, 0.07908531916993004, 0.039879063676510534, 0.03742587799206376, 0.023032252044816102, 0.027500973415694067, 0.04202726483345032, 0.03502940087180052, 0.10867148837340729, 0.019167012934173857, 0.019897235357867818, 0.029813549680901424, 0.061761261629206796, 0.054255605808326175, 0.023873803405357257, 0.024759362850870405, 0.01201224623114935, 0.07034485853676285, 0.013934664012465094, 0.014260616120217102, 0.06376087718776294, 0.034222005267760584, 0.09415670830224242, 0.04510413615831307, 0.12194982836289064, 0.05367031167926533, 0.046560123030628474, 0.023871506564319134, 0.016797792565609728, 0.0755704195637788, 0.028988593590578864, 0.12299505727631704, 0.12224998511373997, 0.06950304763657705, 0.024412624670990875, 0.06699805241078138, 0.03145236781399165, 0.05345027634341802, 0.023473282843562107, 0.052792765732322416, 0.015889760040278946, 0.040561910785202465, 0.0643660964976464, 0.07649196511400597, 0.11778213057134833, 0.06690788189215319, 0.031342143192887306, 0.02725173732531922, 0.04600573617166706, 0.008239825622045567, 0.008087824448011816, 0.027747084852308035, 0.004826812289788255, 0.096183410978743, 0.023882429281781827, 0.05498433545497911, 0.041617487357663255, 0.05323137076837676, 0.030320591758936644, 0.008494546819877411, 0.034206945183021684, 0.01198624137655965, 0.045183901342430284, 0.05065582486401711, 0.0339708285672324, 0.03669436974450946, 0.049084208839173825, 0.008418424520641565, 0.042517994929637225, 0.10617034722651754, 0.02301957701066775, 0.011465866933576763, 0.06088897093598332, 0.10290313325822353, 0.05498906823673418, 0.027052329454038824, 0.07507621536829642, 0.046467933870319805, 0.03707168949767947, 0.060023737006953785, 0.019587942132992402, 0.021158691329349364, 0.09374440328351089, 0.027121770727847303, 0.05885753208505256, 0.02217940816522709, 0.0349226842767426, 0.02439752726682595, 0.04232919934604849, 0.031666489717151435, 0.02884627426309245, 0.03517663957817214, 0.029024885036051273, 0.04064485490588205, 0.03985932509281805, 0.05017052983332958, 0.07493729889392853, 0.019081624391089593, 0.01228936162910291, 0.06864907738885709, 0.12387883556740624, 0.4430506889309202, 0.812058225274086, 1.5099098873989922, 2.8296265176364352, 3.401579426867621, 3.886355459690094, 3.1506836669785634, 7.0410009026527405, 21.184437377112253, 41.246174403599326, 55.680066858019146, 55.3087933404105, 53.603576864515034, 55.05495480128697, 61.01177052089146, 61.70069830758231, 55.78067329951695, 54.76638569150652, 50.2398601259504, 31.250061648232595, 10.047029154641287, 4.90868604183197, 1.4507515132427216, 0.7667750237243516, 0.2941030242613384, 0.40774778755647795, 0.09703473493989025, 0.03554492124489375, 0.03636611485853791, 0.03035633698371904, 0.056900223184909136, 0.06014787498861551, 0.05249323323369026, 0.11107399088463613, 0.006090704201986747, 0.014326625703168767, 0.07662572472223214, 0.08115191292017698, 0.07645037091736283, 0.02030375925824046, 0.08716599949236427, 0.004050304447965962, 0.06734413241169282, 0.025006115503076996, 0.04687552307067173, 0.052793359450463734, 0.027108220383524895, 0.07955254481307097, 0.019518456754407713, 0.007782173259848995, 0.045667360935892375, 0.04341668063508613, 0.02770128034587417, 0.015553003110523735, 0.023906378175265024, 0.03658458956384233, 0.08051312648292099, 0.03051185720999326, 0.03347625796283994, 0.052032877757613144, 0.022911148811025277, 0.004940592010305929, 0.029359782779855386, 0.03822059516928025, 0.07005756002451692, 0.03324855178860681, 0.061012600016381056, 0.03360588190012744, 0.049084809342665334, 0.03164345345326832, 0.0681585372824754, 0.04942387329148395, 0.029556544364563057, 0.006266596169942724, 0.07997672419462885, 0.05345466985766377, 0.10632159268217427, 0.05553638476080128, 0.03156112340678062, 0.043558647124362845, 0.03801354020833969, 0.02707703661040536, 0.012047309528238006, 0.030768411300544227, 0.10353847273758479, 0.043802142808479924, 0.027550194345946823, 0.020580643954287683, 0.02626539846616132, 0.010416418380503143, 0.07741984139595713, 0.019495557893865874, 0.08269914918180023, 0.042271201565329514, 0.03934140270575881, 0.05392453160935214, 0.07336282623665673, 0.022031974380037615, 0.10025409861866917, 0.18996252811380795, 0.16970643933330262, 0.11351186542638711, 0.13036216981709003, 0.12127988359757833, 0.1553978728396552, 0.13738286308944225, 0.1748436822422913, 0.17311824911407062, 0.15250709652900696, 0.08993417809584311, 0.1431514285504818, 0.08275856849338327, 0.16466995887458324, 0.11104053232286658, 0.15871763255979332, 0.10029455287648098, 0.17222482205501624, 0.18673104579959596, 0.11257394682615995, 0.26843314883964403, 0.19693432615271636, 0.14959337216402802, 0.15140583419374057, 0.17036601608353003, 0.08531985498432602, 0.13608447276055813, 0.1683014240115881, 0.14264648993100437, 0.18505247229976313, 0.2602499622319426, 0.06542703349675451, 0.06944802523191486, 0.20670742887471402, 0.11583560359265123, 0.221550993089165, 0.1642844695597887, 0.13245849018650396, 0.12193093794797148, 0.18895094096660614, 0.08203609833227736, 0.16253547769572052, 0.11861146321254117, 0.10361842451883213, 0.21752357562737806, 0.2030332838850362, 0.12981373710291727, 0.12055736593902111, 0.21529567374714784, 0.2436792142689228, 0.07865719749991383, 0.094672897032329, 0.23076720855065755, 0.11474124874387469, 0.1394441167690924, 0.1478885800710746, 0.12495337719363825, 0.09733209612646274, 0.1950377800634929, 0.10082862100430898, 0.10139656160026789, 0.18365606080208505, 0.10766266286373138, 0.07389867212623358, 0.12394975604755537, 0.09852790553122759, 0.16243918000587396, 0.101629943719932, 0.09629121662250587, 0.1492481335465397, 0.14434263748782022, 0.12674472321357044, 0.30043875000306536, 0.20489166916481086, 0.14083172088222845, 0.17194869901452745, 0.12346957038555827, 0.3065450223428862, 0.5167414375713894, 0.6619752900941032, 1.388111548764365, 1.8163661573614394, 3.2775417055402483, 2.9974572147641863, 8.90660308088575, 25.62355981554304, 55.75074393408639, 78.09430585588727, 87.35041114262172, 87.63545404161725, 85.50080067770821, 83.39558683122907, 96.58168356759208, 88.13711397988456, 86.32498904636928, 70.64808123452323, 48.24803045817784, 12.99634838104248, 2.9532536438533237, 1.2928870299032755, 0.5430677820529256, 0.4142967632838658, 0.3812639143850122, 0.2181677632033825, 0.11436424111681325, 0.11243083700537682, 0.10778366601360695, 0.20180243493190833, 0.23612359112926892, 0.15763102658092976, 0.2535389523421015, 0.2693227082490921, 0.06330278462597302, 0.10421579996390001, 0.1716559518660818, 0.19075193575450353, 0.10750493061329637, 0.20289685763418674, 0.10892090427556209, 0.09819905353443963, 0.09527057781815529, 0.1227270495146513, 0.1376639122941664, 0.10813671456915991, 0.16935373683060917, 0.1485823549862419, 0.10182807594537735, 0.14017139774348053, 0.17810625503105776, 0.0680821274540254, 0.15137300666953835, 0.09903876776141779, 0.06592884406979595, 0.13570040836930275, 0.18270244768687657, 0.1276679379599435, 0.146986739177789, 0.09161351155489683, 0.3014633650226252, 0.13779343105852604, 0.18726912406938417, 0.14973046337919577, 0.07428260759583541, 0.16641116115663732, 0.12284602384482111, 0.18445958197116852, 0.13322545188878263, 0.08752315997013024, 0.23596413539988653, 0.2317330352962017, 0.13386176845857076, 0.14317627650286469, 0.24499402514525823, 0.15651280087019714, 0.13139336662633078, 0.11478965543210506, 0.15877776433314594, 0.16608739138713904, 0.13114513137510844, 0.10226312545793396, 0.14838123720671448, 0.1423814541527203, 0.07020052735294614, 0.16243380600852625, 0.1337549534759351, 0.10464487158294235, 0.1407625103103263, 0.16234947767640862, 0.10780363529920578, 0.1711621005088091, 0.13331655200038636, 0.14753479191235133, 0.12589595732944353, 0.20774256118706294, 0.10993713260229145], [0.01385062829857426, 0.04373705094414098, 0.038798890209623745, 0.07098943966307811, 0.01949937634968332, 0.00529505403911961, 0.10912829850401197, 0.00758714702845152, 0.011119311958152269, 0.018388529707278525, 0.0350395551483546, 0.03732165162052427, 0.06157602156911578, 0.027200621586026888, 0.06931598231728588, 0.07583504822105169, 0.009792988038887935, 0.028459090307088833, 0.04147935119856681, 0.005882518207986972, 0.028790926161621298, 0.060659958581839285, 0.039554225214357884, 0.022602406895852516, 0.02741901486712907, 0.027926401301686252, 0.043560848970498355, 0.056867667074714384, 0.02157300990074873, 0.04001457729775991, 0.01383949862793088, 0.062087575905025005, 0.009851272500652288, 0.04397274686821869, 0.030266512517950366, 0.06944558250584773, 0.041048213440392695, 0.010589839208738079, 0.02747321454808116, 0.045423963639353, 0.07074220864368336, 0.008665671655242997, 0.0656957740762404, 0.043962989534650526, 0.040641943990652046, 0.01488888865735914, 0.05343171841065798, 0.010855546736690615, 0.02262584858440927, 0.02605025197512337, 0.02703108112992985, 0.02782853110693395, 0.037751869963748116, 0.06264835117118699, 0.03983487069074597, 0.01160256629477122, 0.02313211204351059, 0.02977689861186913, 0.016613473616806523, 0.02171387885963278, 0.03054546844214201, 0.07109259734196322, 0.03977189585566521, 0.05306403046207769, 0.029893969651311636, 0.04674005355419857, 0.016530292008870413, 0.01686368340493313, 0.030088274939251796, 0.030439111470643963, 0.026257021951356103, 0.08169176216636385, 0.039010627062192986, 0.03391842530774219, 0.07745506414877516, 0.05562328813331468, 0.07672748461897884, 0.06753871589899063, 0.013351068765457188, 0.036349843588790724, 0.03602278970980218, 0.06366691365838051, 0.03518359795478838, 0.0714059719549758, 0.04991755840767707, 0.06435685485069241, 0.12958678070987972, 0.5849454977682659, 3.8078655685697282, 8.904341442244393, 21.535182441983903, 20.182908398764475, 32.47233663286482, 36.41945539202009, 20.42444862638201, 16.94782713481358, 7.4991768428257535, 1.8808723645550864, 0.16605159187955515, 0.018195125174575617, 0.033628823169107945, 0.040607487982405086, 0.027429043614704694, 0.008332446500259851, 0.01830484767976616, 0.012652181088924408, 0.025686794692384343, 0.018785978201776743, 0.037288199844104905, 0.04847160367561238, 0.05824073018240077, 0.02749326525788222, 0.0022940558639155434, 0.0398859609849751, 0.08280073944479227, 0.07901925021516425, 0.09328897057899407, 0.0320744588971138, 0.05673584468396647, 0.053872494758772, 0.06995630224368402, 0.018623679410666227, 0.05035957647487521, 0.031055095738598278, 0.06026404018380812, 0.1240252498537302, 0.013153671902338309, 0.01315335723172341, 0.0723566741549543, 0.0638682282130633, 0.027998989281643714, 0.010403787451131003, 0.13825404777058534, 0.016532203781285455, 0.07532578733350549, 0.017208406335807273, 0.07209748734853097, 0.01373438592002328, 0.03344559835802231, 0.044766293572528024, 0.023064752175871815, 0.006716533164892877, 0.04596285954383867, 0.038769597852868695, 0.036037859972566366, 0.05796823051891156, 0.02161183737085334, 0.07222048539136137, 0.06091268573488508, 0.029500090251011506, 0.10520646109112672, 0.02771648292296699, 0.03109417935567243, 0.025617015847404088, 0.01316367435668196, 0.007264585051286433, 0.06725821630763155, 0.041599414577441554, 0.02381962238411818, 0.022877764888107777, 0.035717693224017105, 0.02483694993757776, 0.014357806083613207, 0.029416284390858242, 0.03136618368859802, 0.047202227504125664, 0.07619547245225736, 0.06370772075440202, 0.0500588667179857, 0.022901245592428104, 0.03157802571409515, 0.03702994602333222, 0.04967425610604031, 0.04808682342991233, 0.03334563318639994, 0.0424559564728822, 0.040550541930965016, 0.022907932555036883, 0.07371761184185743, 0.05262306073148336, 0.024480349251202176, 0.012411117952849184, 0.08031995434846197, 0.033426782581955194, 0.05687685783154198, 0.016127683255555372, 0.02419110164711518, 0.020646909684208885, 0.0244360833229231, 0.03337043703400663, 0.041294185777327845, 0.0492201702935355, 0.022415838603462492, 0.020696631034037898, 0.030468641314655542, 0.029700135945209434, 0.006644115242774465, 0.0015351969299704901, 0.013491650195127087, 0.05059886184920158, 0.028111534492511834, 0.0055271397328137285, 0.03638134118435638, 0.057352629623242786, 0.012600852459269975, 0.049574402892696004, 0.03569652293143528, 0.008536685540873026, 0.015820111813289777, 0.026626258656116467, 0.05300344746293766, 0.04893164363290582, 0.050413930522544045, 0.045423831325024366, 0.01573189377917775, 0.02381502361302929, 0.03890719457662531, 0.011560039960646203, 0.05674540184970413, 0.05036666377314499, 0.037130983280284066, 0.07545699565006153, 0.06055029375212533, 0.04609639184283359, 0.06842447551233427, 0.011002303683198988, 0.022700363603819693, 0.015550986165180802, 0.07007266421403203, 0.0264665705284902, 0.0787929112889937, 0.02387929444999567, 0.011192382546141744, 0.025883856528837765, 0.024537118883537393, 0.06321548431047372, 0.021446229025189365, 0.054025087106440745, 0.032339854298957756, 0.007484467716754547, 0.017648677175332392, 0.03383881618667926, 0.03868140187114477, 0.019494253410292522, 0.048740944758589776, 0.05308921428929482, 0.021483952179551125, 0.006521349598187953, 0.03771899833476969, 0.09109772316047124, 0.08633651078811713, 0.0311613136104175, 0.02159097750804254, 0.0748687329302941, 0.02689096873759159, 0.02569651640286403, 0.005718866587683026, 0.05366555175610951, 0.11829247032957417, 0.11923989520541259, 0.10896046965249948, 0.1831279977091721, 0.04784698844222086, 0.7028532794543675, 3.560293870312827, 10.11202347278595, 26.57600324494498, 27.576773132596696, 46.53090129579817, 43.09039306640625, 26.713231904166086, 20.761731556483678, 9.3744443995612, 2.6422034204006195, 0.38765886266316685, 0.11678939312696457, 0.07236075893576656, 0.05996809035007443, 0.048982930702290366, 0.01885307683343334, 0.051152071449905634, 0.04455044140507068, 0.058213609137705395, 0.02819459226780704, 0.07962589444858686, 0.06471886006849152, 0.06542888589735542, 0.02541333490184375, 0.025158531431640898, 0.026580530484872203, 0.07687697945428745, 0.01862102124973067, 0.026530703962115303, 0.024563003298161284, 0.026426418218761683, 0.05753992564444031, 0.05981571852628674, 0.056375902212624035, 0.027964994677209427, 0.05568712131519403, 0.03071861361552562, 0.06415999827108212, 0.013738859162133719, 0.03947525730888758, 0.03381317774099963, 0.011194090758051192, 0.01903422023834927, 0.023838970810174942, 0.07217978686094284, 0.01725844320441995, 0.07194173642035041, 0.046726415000323734, 0.036266767153782506, 0.02115469136541443, 0.0065959023611087885, 0.04576347881395902, 0.01758492541765528, 0.026552819114710604, 0.020724116791305796, 0.01352041499090514, 0.025763207913509438, 0.0755693678344999, 0.09077932060297046, 0.030178459028580358, 0.07981452718377113, 0.009252933535857924, 0.01948644177589033, 0.04424200313431876, 0.018682813737541437, 0.023606070450374057, 0.02328716408062194, 0.039976552195314846, 0.04430115442456944, 0.04469563093568597, 0.03413904418370553, 0.012440286476963332, 0.013497376182515706, 0.019511383026838303, 0.015441533377660173, 0.03465052727343781, 0.02866545825132302, 0.012518485093356242, 0.022254002912502204, 0.029802805078881126, 0.04182779250134315, 0.03504724634279098, 0.050703838001936674, 0.026788513342450773, 0.04333110719120928, 0.03889904537105134, 0.05020315718970128, 0.02594352180936507, 0.153522184916905, 0.16779197991958686, 0.32633539182799204, 0.15669113344379834, 0.12129322359604494, 0.08036751286791903, 0.43847188034227913, 0.127239443095667, 0.15396036926124776, 0.0982862656403865, 0.11539197739745889, 0.08968665530639035, 0.20773160963186196, 0.10430959385952779, 0.1724219364779336, 0.17849458062223025, 0.14899472785847528, 0.18925306546900952, 0.10898983664810658, 0.0700563658028841, 0.11912062231983457, 0.09600144824279205, 0.09454203476863247, 0.07355162182024547, 0.13661761129541056, 0.10878949239850044, 0.19292119863842214, 0.15140413785619394, 0.06942745205014944, 0.1015952095123274, 0.13423824682831764, 0.1642838724489723, 0.08263844743903194, 0.23380709971700395, 0.13186512488339627, 0.19457123295537063, 0.11589642747172288, 0.12225818181676523, 0.132779667952231, 0.12474858175430979, 0.14277153036424092, 0.0572736006496208, 0.13379026443830558, 0.190962553024292, 0.17358844674059323, 0.1523067115672997, 0.13499390413718565, 0.10957605019211769, 0.1333576576518161, 0.16071897159729684, 0.11425370776227542, 0.09104599843599967, 0.1934051162430218, 0.10815664314265762, 0.19821043339158806, 0.09481928417725222, 0.11050963295357567, 0.1561677793839148, 0.07534735796174832, 0.18256705280925545, 0.1063776600307652, 0.18778440356254578, 0.22216525727084704, 0.21929187859807694, 0.11628881070230689, 0.16556989986981663, 0.1106968746919717, 0.14373533507542952, 0.10895981147353138, 0.15835519986493246, 0.13162187007921083, 0.2967240964727742, 0.11431134252675942, 0.1508799966956888, 0.16732159230325902, 0.14725587330758572, 0.13042701062347206, 0.15512267260679177, 0.07522087224892207, 0.11757291108369827, 0.1099636633215206, 0.13690870281841072, 0.2116711296673332, 0.18414696731737681, 0.1765340215393475, 0.1660840937069484, 0.26642229674117907, 1.567831699337278, 7.694603613444737, 23.387124027524674, 48.34623977116176, 49.368205138615195, 76.4803157533918, 61.26542840685163, 40.50683396203177, 30.33493525641305, 12.06477039200919, 2.800016335078648, 0.38317532039114405, 0.15553372912108898, 0.2380738364798682, 0.12842056900262833, 0.14760476244347437, 0.10510568507015705, 0.1385618991085461, 0.06662607951355831, 0.16966618863599642, 0.0677888917603663, 0.14638501432325157, 0.162064737241183, 0.24983086703079088, 0.09371757400887352, 0.0816412316635251, 0.07687049265950918, 0.1376461618180786, 0.27140258092965397, 0.19744340383580752, 0.11089373127158199, 0.12368516810238361, 0.17350605901862892, 0.18154680755521568, 0.10779404081404209, 0.12368173471518926, 0.1794606652110815, 0.1219276674091816, 0.229778881583895, 0.11461159427251134, 0.09240301419049501, 0.08910192775407008, 0.13412542002541677, 0.09811071506036179, 0.18443952447601727, 0.22118503201220716, 0.11660917422601155, 0.13400074600109033, 0.1764126859073128, 0.13904939937804425, 0.14301862567663193, 0.11915537688348975, 0.12758550952587808, 0.07495981268584728, 0.08397455752960273, 0.08967079115765435, 0.14704358684165136, 0.1688398008367845, 0.14337079892201082, 0.16313595404582365, 0.12701231028352464, 0.1830008402466774, 0.12232002349836485, 0.14614475864384854, 0.10977771079966, 0.11505265560533319, 0.09702094032296113, 0.13800498470664024, 0.10991688511733498, 0.16168105282953807, 0.16630570324403898, 0.10139960822250162, 0.11889676004648209, 0.07781331706792116, 0.07475452870130539, 0.10133110332701888, 0.1203166488558054, 0.09927341195621661, 0.11205862662089722, 0.15413197076746396, 0.1298332924821547, 0.08060747677726404, 0.20125713704952172, 0.11974919001970973, 0.10321923558201108, 0.11414008028805256, 0.15279514821512358, 0.11014631816319057, 0.1763572088841881], [0.02011857008827584, 0.019109820913789526, 0.026639803911426237, 0.0313430490371372, 0.0353911787803684, 0.06258741194116217, 0.041612774931958744, 0.05879923914160047, 0.06648068302976233, 0.06965457129159144, 0.038629829817052395, 0.0371080725453794, 0.0004889502670266666, 0.045981312303670814, 0.02481264990222241, 0.09134599233844451, 0.024696925754791925, 0.022625936793961694, 0.028490189263331037, 0.03621441478441868, 0.08614341329251017, 0.04274623714653509, 0.029413288658750907, 0.030533302309257642, 0.02331689409246402, 0.03272426813574774, 0.02299452549777925, 0.018051058619416187, 0.043866250797041824, 0.05825842637568712, 0.04886606661602855, 0.03444036462211183, 0.0074740564450621605, 0.038054231953408034, 0.039298736423786194, 0.03217983877818499, 0.07478774977581841, 0.04054010945505329, 0.048376954825861115, 0.028988898931337253, 0.05582352720999292, 0.01686011939974768, 0.020211860171652267, 0.010804051865956612, 0.031693766824901104, 0.022416679986885617, 0.07607214192726783, 0.01746559824927577, 0.04924715902390225, 0.046170233416238, 0.003365597941280742, 0.028883105143904686, 0.03225645895249077, 0.009467271722054907, 0.053750728257000446, 0.03231520312173026, 0.06667530044381108, 0.03949093146781836, 0.014942302934027143, 0.05077580003333943, 0.02738568353067551, 0.017731158195861747, 0.04126005546588983, 0.07199860444026333, 0.050251322998000045, 0.07318480578916413, 0.0649938295994486, 0.02661426894233695, 0.024382652082879628, 0.024080720962956548, 0.00903057336940297, 0.030289039880569493, 0.017588121317593113, 0.041310667392930815, 0.07044189582977976, 0.06300607483301844, 0.010840006588426019, 0.02977818443572947, 0.036286054511687586, 0.038533471059054136, 0.02829270334249096, 0.032145684718021324, 0.012522000752921616, 0.08442137283938271, 0.10017332581004926, 0.022184322455099652, 0.10876186245254107, 0.08865093266857521, 0.13114081589238985, 0.07855624505983931, 0.2314965794129031, 0.6413081990821021, 2.2956967566694533, 2.566910352025713, 0.09466301756245749, 0.05827916240585702, 0.1244602043713842, 0.11164140900863068, 0.07596967635410172, 0.04154823607366, 0.05496833899191447, 0.04959899300177183, 0.04334983815039907, 0.036381198692002466, 0.01288763274039541, 0.03777600884703653, 0.08270494387085948, 0.04428110710744347, 0.061789319052227905, 0.04697157988058669, 0.06933722724871975, 0.02051705165233995, 0.08749073278158903, 0.06147559160100562, 0.033508627475904565, 0.024529283500409553, 0.023784118039267402, 0.06289176882377692, 0.003135871641071779, 0.03283362423202821, 0.0802994015227471, 0.06007038628948586, 0.07250973129911081, 0.022243943630850742, 0.035843632716153345, 0.012794283285204853, 0.02234278921969235, 0.041903771460056305, 0.025584490271285176, 0.05634209081264479, 0.021198126088295664, 0.021534883018050874, 0.02778166638953345, 0.04399502995823111, 0.059908983164599965, 0.056882096121885946, 0.03299711045942136, 0.03541046953094857, 0.020614172065896646, 0.039792021204318316, 0.026139426743611693, 0.05332324440990176, 0.02654512961661177, 0.031022308926497186, 0.0337430070420461, 0.03489444025659135, 0.02063987497240305, 0.03612130960183484, 0.020992141516347016, 0.07584667152592114, 0.05933006387203932, 0.04756862962884562, 0.10211635154805013, 0.04020430586699929, 0.014018891412498695, 0.026678951989327158, 0.08471611488078322, 0.020393817818590572, 0.017217651375436356, 0.01300213552479233, 0.03126434236764908, 0.03650838329589792, 0.050394188546176465, 0.055612614777471335, 0.03281624695020063, 0.0394495917218072, 0.04622849921828934, 0.03101378313398787, 0.012300368315274162, 0.03081666531839541, 0.01200839554491852, 0.028354538238740394, 0.026608693080821207, 0.014227428972455007, 0.03567881995279874, 0.028800961694547107, 0.05779443055923496, 0.056746236447777064, 0.07653522172144481, 0.08575992565602064, 0.03885520861617156, 0.024590288887598684, 0.01417776444993381, 0.08555424133581774, 0.08163233606943063, 0.0494213355705142, 0.03378014665629182, 0.03678455383383802, 0.013914497951710863, 0.044674609920808246, 0.047318928741983006, 0.020659220005784715, 0.021167992348117486, 0.03654096654749342, 0.08298546381826911, 0.031838410134826384, 0.04093139685158219, 0.01877258561684617, 0.06309482042810746, 0.035997968898820024, 0.01117445225827396, 0.014015418161371989, 0.03853622930390494, 0.006174954502577228, 0.054737440310418606, 0.04571090252803905, 0.018101655279419253, 0.04611242223264916, 0.026641306866492544, 0.04216435944129314, 0.03321217213358198, 0.028479210566729307, 0.04620287773598518, 0.07045152424169437, 0.018159593688324094, 0.02963300169046436, 0.0364923834401582, 0.05830195439713342, 0.04044679731928876, 0.006180305599368044, 0.03969443090526121, 0.03717995315257992, 0.031471913015203815, 0.022472438602043048, 0.018434827847938453, 0.03383549815043807, 0.005589971227371799, 0.011158878183258432, 0.030367902613111904, 0.07066505242671285, 0.029867181088775396, 0.0519458997462477, 0.020865518400179486, 0.05106050314913903, 0.02301785353172038, 0.026089298272771493, 0.11649374184863907, 0.0986526541944061, 0.01557373914069363, 0.04048666464430945, 0.024889533008847917, 0.020852144474961927, 0.05321664995114718, 0.01345332823361137, 0.02195471299013921, 0.024023652775213122, 0.04069883915196572, 0.05314558697864413, 0.015649363564859544, 0.07399334811738559, 0.038720804399677684, 0.06551104970276356, 0.029747378945882832, 0.028182789151157652, 0.024551938088344674, 0.04008379465501223, 0.0593411647049444, 0.012378377790030624, 0.04218744320262756, 0.038083497168762345, 0.0900581328730498, 0.04230766264455659, 0.015709926207949008, 0.07426742198211805, 0.04874460206234029, 0.19582649559846946, 0.44560303911566734, 0.7893288763506072, 2.1378530093601773, 1.9400271560464586, 0.24855060715760502, 0.12972868952367986, 0.13232092399682316, 0.03244075924158096, 0.04825347163049238, 0.0314264850957053, 0.05493840881224189, 0.07250648790172168, 0.057334784152252335, 0.022605587528752427, 0.023222725306238447, 0.037418101980750046, 0.04783286473580769, 0.02666710816057665, 0.030907857032226663, 0.01917237675349627, 0.046977703659129996, 0.03727805235290101, 0.10680767481348344, 0.06500955125583069, 0.042801307048648596, 0.027882858013202037, 0.06416657327541284, 0.030088922940194607, 0.04092005513874548, 0.020062646928376386, 0.044501471532774825, 0.03724426130897232, 0.06110515897827489, 0.021950845340532914, 0.06796608439513616, 0.04029522616682308, 0.08822488731571607, 0.03838385748011725, 0.02596192028639572, 0.013401931750455072, 0.03956267297534006, 0.017653820470773747, 0.02610581720780049, 0.0519994666932949, 0.034426159491496425, 0.06003457999655178, 0.04219881205686501, 0.05059333857414978, 0.06106897270573037, 0.024739649712241123, 0.04260897969028779, 0.0396643141284585, 0.01866169094241091, 0.035495527288211245, 0.013804083340801299, 0.03448923271415489, 0.01450776232273451, 0.01716735666351659, 0.027144063995884996, 0.016006127099639604, 0.07227432714509112, 0.033422066763575585, 0.10552948447210447, 0.03722079756802746, 0.0330199804822249, 0.02325503884016403, 0.04939729846747858, 0.05497310230774539, 0.027756633536357964, 0.0357105686063213, 0.09145528397389821, 0.045186425492699654, 0.008176428398915699, 0.04415891652128526, 0.049800802887018235, 0.03695757347824318, 0.04629196599125862, 0.02905469647209559, 0.029892388664718186, 0.011730316627238477, 0.018714126432314515, 0.018279244857175008, 0.027039511927536557, 0.015683826358456696, 0.03789277793839574, 0.07949641639632837, 0.09059030788817576, 0.12571788259914943, 0.1896805153893573, 0.14174090352441582, 0.12198167879666601, 0.16851962730288506, 0.09510396354432617, 0.22850453853607178, 0.19879249430128507, 0.17169337985771044, 0.16686841233500413, 0.1700128521770239, 0.09911143207656485, 0.1446152050048113, 0.14506875138197625, 0.2506563998758793, 0.1320219071848052, 0.18746197729238442, 0.14236776131604398, 0.13436967906142983, 0.16260821664971964, 0.12421810307673045, 0.18031340731041773, 0.18294410114841803, 0.07775763648429088, 0.12920422266636575, 0.11208146610962492, 0.10970413724758796, 0.12080044432410172, 0.21494388048137936, 0.13424770560647759, 0.21347443147429399, 0.09680594650230237, 0.09001891354897193, 0.13252646582467215, 0.1277813890150615, 0.16478514697934898, 0.13216536305844784, 0.09501824421542031, 0.12688699843628065, 0.11020733881741762, 0.12762753798493318, 0.09905017393508128, 0.14103388360568456, 0.19411456531711987, 0.15301284939050674, 0.16528590582311153, 0.09334261555756841, 0.08876819709049803, 0.05905130133032799, 0.07020046628479447, 0.1196477897465229, 0.1289584165705102, 0.10112271165209157, 0.1723366446260895, 0.17695913729923113, 0.1098004485081349, 0.16850106258477482, 0.08120730173374925, 0.10912251738565308, 0.2200036346912384, 0.17842820632670606, 0.14246662386826106, 0.0971818481172834, 0.15181420370936394, 0.07693493991558041, 0.16214565932750702, 0.07081111387482711, 0.09293446317315102, 0.1204935565058674, 0.1414570723261152, 0.18839402656470025, 0.1402209172291415, 0.19553108859275067, 0.15508039987512998, 0.14632820737149033, 0.14132588436560972, 0.11603756275560174, 0.10520627788667168, 0.10158255483422961, 0.16028816971395696, 0.1379992850124836, 0.0929664968113814, 0.15942917152174882, 0.21820599186633313, 0.1071263352142913, 0.30101553191031727, 0.222650531945484, 0.23418865352869034, 0.19724831144724572, 0.7286084602986063, 1.5482160661901747, 4.3298376968928745, 4.181263932159968, 0.4835482644183295, 0.2411401362291404, 0.17911744862794876, 0.14433889197451727, 0.15552462318113872, 0.15782377123832703, 0.16182460369808332, 0.16090011330587523, 0.1470550676541669, 0.11052850979779448, 0.09945975802838802, 0.16025112170193875, 0.20071453973650932, 0.22708538254456861, 0.156406148735966, 0.1570260447583028, 0.1604210811534098, 0.08766692118453127, 0.23608040916068213, 0.18213348250303948, 0.1428952951516424, 0.1045014157092997, 0.12130722855882985, 0.11059370344238621, 0.18922253139317036, 0.09745636981512819, 0.15754870671246732, 0.12447585138891425, 0.16965409714196408, 0.09059832138674599, 0.1389425029712064, 0.11849786287971906, 0.15648599873696054, 0.13559117780200072, 0.15389037158872398, 0.19343096842723234, 0.16004538988428457, 0.05940540161515985, 0.1577045933476516, 0.15546245580273016, 0.14639827289751597, 0.146316441574267, 0.11905955416815621, 0.10906159172632865, 0.19543101824820042, 0.2010530744280134, 0.12051947654357978, 0.14146733177559717, 0.07965357867734772, 0.10783708707562514, 0.09146170970052481, 0.08528729887413126, 0.08457924758217164, 0.1932592447847128, 0.10412005188741855, 0.16016052370624884, 0.1330605000257492, 0.1152738444507122, 0.16667293996683188, 0.09760591214788811, 0.13804295552628382, 0.08435768554253237, 0.13076570816338062, 0.0765368841322405, 0.08205849677324295, 0.12359324017805712, 0.13984575521733078, 0.21035386249423027, 0.16301521552460535, 0.11831073649227619, 0.14356160296925477, 0.1527125026498522, 0.1178380689982857, 0.07683985001806702, 0.149483340925404, 0.07238661111997706, 0.08832821462835584, 0.20107519466962132, 0.16527439786919526, 0.09783769971025841, 0.11043884139508009, 0.1254883070609399], [0.05053690481664879, 0.029341927130839655, 0.035985273508621116, 0.010545925270499927, 0.026517158706805537, 0.0652986139591251, 0.048985380213707685, 0.029822316353342364, 0.028973625108067478, 0.03605780890211463, 0.021292493346014192, 0.043597014886992316, 0.017187042660745125, 0.04546485894492694, 0.028486898368490592, 0.023252954041319232, 0.03191894884886486, 0.03805181636874165, 0.0431502131479127, 0.0034294287906959653, 0.009564343789991523, 0.027877855513777052, 0.03088819308738623, 0.07803832606545516, 0.049165066464671066, 0.012974902521818876, 0.04196239010031734, 0.053515571768262556, 0.005307102276544485, 0.04831388499587774, 0.05412580884460892, 0.04368620831519365, 0.008871489986112075, 0.022219959114279066, 0.05941775095249925, 0.05112405813166073, 0.023810467250379067, 0.019850046639995914, 0.03305373081405248, 0.07148232071527413, 0.041541053780487606, 0.010941964956665677, 0.006644464264224682, 0.04803467122837901, 0.003093041874568111, 0.016656597909916724, 0.0430749636143446, 0.07315383745091301, 0.06739884269024644, 0.07839314559740679, 0.055673957735832245, 0.035780705378523896, 0.03412055071177227, 0.01887593328553651, 0.055687297734298875, 0.05409891850181988, 0.033623476313160996, 0.04943229730374046, 0.021997950937865034, 0.05344002367928624, 0.07595013454556465, 0.033796187224132676, 0.020861012927655662, 0.04723685993147748, 0.01633464322159333, 0.013404611115609961, 0.07588331241692815, 0.05658319466082113, 0.043069742287376096, 0.05603962365005698, 0.03392975005720343, 0.067397261703653, 0.06304329926414148, 0.057160909553723674, 0.03367080752338682, 0.00988782603027565, 0.05016745946237019, 0.05971780592309577, 0.03833527098010693, 0.04114183770226581, 0.0523232262847679, 0.04666404066873448, 0.021883639839610884, 0.06665503938815423, 0.023246487602591515, 0.058628336526453495, 0.12740149082882063, 0.04403374716639519, 0.020533360241513168, 0.028842840875898088, 0.028810457792133093, 0.017979985468887856, 0.0023528110593490836, 0.06337643281689712, 0.056892535383147855, 0.04149560550493853, 0.14087328793747084, 0.06581574585288763, 0.03228848919804607, 0.059813106166464944, 0.054692894486444335, 0.029465125341500555, 0.12891501747071743, 0.005894488413884703, 0.022158224301944886, 0.04233755211212805, 0.04253338749653526, 0.015121130838191934, 0.02685350681921201, 0.0530221037832754, 0.03129911050200462, 0.021975947743547813, 0.03247814991378358, 0.09490214687372957, 0.04864111529397113, 0.03454786831779139, 0.005948244078483964, 0.05721996245639665, 0.0330041163334889, 0.015575669572821685, 0.05783822320933853, 0.040220404110316715, 0.06901837685810668, 0.0012212387768418661, 0.04632759586508785, 0.03191758160080228, 0.02451301223066236, 0.05124599087451186, 0.01956173880690975, 0.02602082900037723, 0.07212656935943024, 0.045402067314301214, 0.03858939252261605, 0.03891648032835551, 0.02320998750760087, 0.029386452598763362, 0.020497470828039304, 0.030604765617421696, 0.007499614314708326, 0.02479774927321289, 0.06526607141963073, 0.08813508320599794, 0.035817071462848356, 0.0158919415303639, 0.018142262207610265, 0.05930441524833441, 0.021986459947324226, 0.03483235090970993, 0.01296971766610763, 0.015760892669537237, 0.08076902917985405, 0.02699511538126639, 0.0936372083212648, 0.0421071962586471, 0.029094428090112548, 0.113168526706951, 0.043049138571534834, 0.008022538353023785, 0.017523043023954545, 0.023585147823074033, 0.03501447310139026, 0.03170078626966902, 0.04582984632413302, 0.004621665708587638, 0.030296211995716606, 0.030678736112479652, 0.04804734965520246, 0.011137185418712241, 0.017059652800006524, 0.005050424353352615, 0.030761161153869968, 0.04613721250955548, 0.051341749129018614, 0.026792557411161915, 0.04195499746128917, 0.011596447605240558, 0.0351416644906359, 0.06873860329921756, 0.059960409333663325, 0.035231298966599364, 0.02742169508045273, 0.08927126295332398, 0.03310523162196789, 0.0163861423331712, 0.039758718705603054, 0.04321633977815509, 0.05314564804679581, 0.03461796777056796, 0.019840765977278352, 0.03559300223631518, 0.019276682852900455, 0.02740666383345212, 0.017859464078875523, 0.0779166647366115, 0.04243399229432855, 0.10806676439408745, 0.046863173733332326, 0.0276660491113684, 0.04518522787839174, 0.016473296763641492, 0.0635793622849243, 0.03377472855416792, 0.09702041785099677, 0.047133420660559616, 0.004603382582510156, 0.03409038304484316, 0.01383412123790809, 0.02155713048497481, 0.03960711701906153, 0.06069336286080735, 0.06740059331059456, 0.12089790909418038, 0.036417812441608736, 0.024963544216006994, 0.08357122274381773, 0.03591721983892577, 0.07581829519144126, 0.03298380099503057, 0.025529115028413277, 0.023138380010745356, 0.089108292412545, 0.055829623847135475, 0.019129813948114003, 0.01959183013864926, 0.02094630817217486, 0.045598292856344154, 0.062282993990395746, 0.06684310893927302, 0.031027530253465687, 0.030224701190101247, 0.035285228929881535, 0.024527739833242128, 0.04097485362685152, 0.02597518734234784, 0.048407241236418486, 0.013961495831608772, 0.04578272885243807, 0.04051821313000151, 0.02950267886210765, 0.007522639552397388, 0.027782399207353592, 0.014831296301313808, 0.03270157792472413, 0.012996752197588128, 0.039437754678406885, 0.045449771718787293, 0.05017380715746965, 0.0010083241359097883, 0.0630565442677055, 0.02155236547280635, 0.029274328079606806, 0.03452339695234384, 0.0353091947867402, 0.05864886899611779, 0.026454891244481717, 0.02502044276999576, 0.02796691153863711, 0.021156993295465196, 0.038556161270077736, 0.08270336966961622, 0.027395657995449643, 0.12274547852575779, 0.05728418579591172, 0.007758433864052806, 0.0599004811208163, 0.04119989315846136, 0.1799891082836049, 0.05700422224721738, 0.0554978202230164, 0.0476056912115642, 0.0330058262417359, 0.02677465426469488, 0.03398943060476865, 0.03458558129412787, 0.04562129858615143, 0.02906152592705829, 0.022988898746137108, 0.07139711028763226, 0.05948236105697496, 0.012205528627548898, 0.03945563068347318, 0.04999005987441965, 0.035007667395153215, 0.021675292269459794, 0.039561397329505, 0.05464439958866153, 0.04097920982167125, 0.05009783159143158, 0.039358589997781177, 0.026857742574065924, 0.048927460464515855, 0.006273863279992449, 0.010753274546004832, 0.033466124042336426, 0.0883736221918038, 0.020141721703112125, 0.008261867832126362, 0.023812496070084826, 0.06872944986181599, 0.016431348032451103, 0.04851034463250211, 0.03201764516000237, 0.00921066674137754, 0.02686210555423583, 0.03806927507477147, 0.04600909831268447, 0.0607515743800572, 0.05691229771556599, 0.032439303783965964, 0.02127882425806352, 0.03494279605469533, 0.11017987850521292, 0.011294390956339027, 0.07326602643089634, 0.012160574834394668, 0.014165214096595134, 0.016707849356212785, 0.05492339961762939, 0.047651061455586126, 0.02150084770151547, 0.0583219440387828, 0.06396567262709141, 0.03543669830209442, 0.028764727924551283, 0.040946168558938165, 0.026029198729832257, 0.029325957809175764, 0.010365754715166986, 0.05051417050084897, 0.03187012146892292, 0.03053976535531027, 0.014683986348765237, 0.022897812205233743, 0.004422809571094278, 0.02141010042812143, 0.04394683361585651, 0.01345137574909521, 0.04168189390163336, 0.0419439848379365, 0.014720839281965579, 0.0708807994212423, 0.02212049945124558, 0.04897977551445365, 0.017302956797980835, 0.01654183558587517, 0.010829354436802012, 0.04054049961268902, 0.03425419157637017, 0.0450376024070595, 0.03364304526309882, 0.04198469354638031, 0.03404360144798245, 0.11011836252042226, 0.17353210119264467, 0.09826483750449759, 0.17120517391179288, 0.1403006858059338, 0.17985880241862365, 0.14672338616635117, 0.08596812055579253, 0.16166631504893303, 0.15747520779924734, 0.08089322822966746, 0.13675110627497944, 0.11360972374677658, 0.18608900239425047, 0.0627531169780663, 0.15669744381947176, 0.11242723398442779, 0.1301304501082216, 0.19739187588649137, 0.20784747627164635, 0.07186042078371559, 0.06609867459961347, 0.12853007098393782, 0.1567573177495173, 0.1046970577112266, 0.14134292916527816, 0.1438048713441406, 0.15834210413907254, 0.10887783765792847, 0.12324957576181207, 0.2266498716281993, 0.12399561144411564, 0.10354377888143063, 0.11669882227267538, 0.1521701224680458, 0.1388121156820229, 0.14601445277886732, 0.09614326206168958, 0.26357394243989674, 0.14105145766266755, 0.19907002869461263, 0.07868280541151762, 0.12737675144204072, 0.13307654059359006, 0.2078923817191805, 0.13316460086831025, 0.15037146184061254, 0.11955705604382924, 0.10527531203946897, 0.17966939615351812, 0.1394846388804061, 0.19555789072598728, 0.11415735578962735, 0.13410560680287226, 0.20685764295714243, 0.07518592091011149, 0.18609307360436234, 0.1982199057404484, 0.10675828424947602, 0.16565720018531593, 0.12515674770942756, 0.2296926804951259, 0.17027566236044678, 0.06400286313146353, 0.19093964568206243, 0.07850873403783355, 0.14712742662855557, 0.20230562293103763, 0.12791496541883263, 0.17812005643333706, 0.14500118286481925, 0.11263795981981925, 0.1620955155896289, 0.11219467289213624, 0.10839614564818995, 0.18267723332558358, 0.16162172172750744, 0.19863846685205186, 0.11142478670392718, 0.12763726817710058, 0.10393660994512693, 0.07951624318957329, 0.10094675395105566, 0.2004078147666795, 0.15717368040766033, 0.21115070687873022, 0.26763858433280674, 0.15001642517745495, 0.12459696988974299, 0.12215363314109189, 0.36031544847147806, 0.14513611633862766, 0.20995009344603333, 0.20161905405776842, 0.13868098200431891, 0.0842990872583219, 0.22412041521498136, 0.12379555217921734, 0.14966298985694135, 0.10816932496215616, 0.1450429263391665, 0.15076981617936067, 0.1647307691829545, 0.10858329239168338, 0.10429677633302552, 0.14637071080505848, 0.12063796232853617, 0.16227506952626364, 0.11837373168340751, 0.12017474004200526, 0.1955743519855397, 0.09483814066542046, 0.09611143876931497, 0.10563192290386983, 0.12467971044991698, 0.11013953281300408, 0.18831195096884454, 0.12189089081117085, 0.24174411381993974, 0.07659064446176801, 0.13325912079640798, 0.1763201201600688, 0.17181075284523623, 0.08498943557164498, 0.15246061688022955, 0.12902173745845044, 0.16251738795212337, 0.17653697995202883, 0.09380661815937076, 0.11567658212568079, 0.20732758274035795, 0.2657171088669981, 0.13643427113337175, 0.15390972340745585, 0.12399809488228389, 0.23213643793548855, 0.08947445705000844, 0.23209830426744052, 0.1297015074108328, 0.12442987385605063, 0.10764414564307247, 0.24902324751019478, 0.12125187367200851, 0.1441820825317076, 0.13441847929997103, 0.1636402141302824, 0.08940238306032759, 0.12654983438551426, 0.10160860379359551, 0.14813030138611794, 0.10744446635778461, 0.1275075458522354, 0.13256782931940897, 0.11007590658430542, 0.11510712839663029, 0.19131441414356232, 0.09002658099468265, 0.13621791345732553, 0.1388723695916789, 0.13876140197472914, 0.09556835969643933, 0.13291544280946255, 0.05843586328306368, 0.07259268220514059, 0.1456185954489878, 0.08696702588349581, 0.16671680047043733, 0.10208028062645878, 0.08043025700109345, 0.0723687724343368, 0.08065275541905846, 0.14916554226406983, 0.17675727313118322, 0.12804654692964895, 0.19469729119113513, 0.09260168924395527], [0.022395463893190026, 0.06413314185504403, 0.021561454449381148, 0.015220634606001633, 0.032798730568694215, 0.12166146455066544, 0.0685446033520358, 0.022545394687248126, 0.08499621413648129, 0.022395630134269595, 0.024750331549772193, 0.0674558939146144, 0.009331546906780983, 0.036862883916390796, 0.03434788029907005, 0.005994493873523814, 0.03467476793697902, 0.03692490201709526, 0.024206911513049687, 0.029451086451964717, 0.023398669436573982, 0.026230935672564164, 0.031042420704449927, 0.0507969533625458, 0.04124461200886539, 0.016420201398432255, 0.0786675519442984, 0.03292969800531864, 0.053838462834911685, 0.05002436660496252, 0.0369272395702345, 0.02844331436790526, 0.07377292601657764, 0.027911960380151868, 0.04447403496929577, 0.03026604772146259, 0.03146457465897713, 0.010767678148113191, 0.09906419246856656, 0.04043691784941724, 0.020494673567424928, 0.050589158798434904, 0.08288128833685603, 0.0035437596088740975, 0.024270985574860657, 0.04390412662178278, 0.05793520621955395, 0.032091473162706406, 0.023487934110952274, 0.016899856106777276, 0.02659399601231728, 0.05691993462720087, 0.06333443828459297, 0.01617463448617075, 0.017647043602274995, 0.023794109467417, 0.07683027588895389, 0.04397213618670191, 0.026984408098672117, 0.04182049485721758, 0.01735964330977627, 0.05318195306296859, 0.030681389184402566, 0.045126846725387235, 0.012366714621228831, 0.07987561569150005, 0.07064848260155746, 0.025926344695367982, 0.09452802980584757, 0.08561001012900046, 0.026346719191808785, 0.03564388218468853, 0.020484074850433638, 0.07080156688711473, 0.059715749961989265, 0.029882532943572317, 0.028656393023473874, 0.07484061443912131, 0.07536159362643957, 0.06239008717238903, 0.04094251464786274, 0.020120661672470824, 0.016595516187537993, 0.01250185420004917, 0.03173533048746841, 0.039568654261529446, 0.013075836302180375, 0.08464951666870288, 0.026667476265824268, 0.08050196458186422, 0.10126334482005664, 0.09721099798168455, 0.04795541833820088, 0.0403079690544733, 0.031201866255807023, 0.01431849176463272, 0.09775204144950424, 0.04172809195837804, 0.03996321898219841, 0.03857978107407689, 0.009009928093291819, 0.038291651356433115, 0.06500322730945689, 0.02957979097430195, 0.017274600819551518, 0.022159228533772484, 0.03277750599331089, 0.03576518388997231, 0.03132814162277749, 0.015378702731270875, 0.05759871391845601, 0.06718843576631375, 0.030935660004615784, 0.025731206505692432, 0.04711128006290112, 0.0384050684848002, 0.08873396499880723, 0.01848747198736029, 0.03075954963320068, 0.03717059954734785, 0.033293117968631644, 0.024337515933439136, 0.02444571682385036, 0.05599933563332472, 0.02931583745937262, 0.06609489515955959, 0.02872583768995745, 0.0348151941517634, 0.01118009936596666, 0.07886252219655684, 0.0233835482836834, 0.052666548040828536, 0.04271662927099636, 0.05768895907593625, 0.01932140170330448, 0.06865977110075099, 0.026659795249413167, 0.03694878305707659, 0.0419388144010944, 0.0015736752726037853, 0.04699865003515567, 0.009906312716858727, 0.02237276520047869, 0.05813716538250446, 0.02429902773084385, 0.027528233560068265, 0.022988296546308056, 0.03677584144419857, 0.03478144381993583, 0.06528555216001612, 0.036346905532159975, 0.02086345395738525, 0.026798849127122333, 0.02091341618714588, 0.02248135455218809, 0.03762169302042041, 0.0640328475939376, 0.03398115587021623, 0.010067396082117088, 0.015558516207550253, 0.04034173634967633, 0.04144876962527633, 0.03688847486461912, 0.0829416915242161, 0.01580248856251793, 0.010724240032556866, 0.05824370216578245, 0.027463833801448345, 0.03918319208813565, 0.04685693121116076, 0.029229402276022092, 0.19557452840464457, 0.025759370797978978, 0.04666527220979333, 0.037768331223300526, 0.009495631093159318, 0.03476336086168885, 0.05305571501542415, 0.06620349468929426, 0.02508555499038526, 0.010514898408603455, 0.08697068997259651, 0.017189219061817442, 0.01299523567182145, 0.09945535433611699, 0.03464639499517424, 0.02094343288003334, 0.051883538985358815, 0.08464541153184005, 0.03308085525142295, 0.017209744746131555, 0.0028394226600149913, 0.06190301437995263, 0.010245576833507844, 0.03368847318259733, 0.023562148878616945, 0.06880317269159214, 0.0357677487523428, 0.02956881227770022, 0.010742068540171852, 0.07851451515619244, 0.05341025974069323, 0.045198588232908926, 0.07034092981900487, 0.018617611611261964, 0.02546827757864126, 0.04406332450785807, 0.02277526878086584, 0.07845333165356091, 0.03232569666579366, 0.0332351032245372, 0.07575049597237792, 0.04823344127674188, 0.011011887142168624, 0.016105970134958625, 0.04592742644516485, 0.02180229706157531, 0.08510165169302907, 0.015293758628623826, 0.014626505950997983, 0.043314567900129726, 0.03947610887033599, 0.026411105379728333, 0.040930284054151604, 0.0510983179057283, 0.026167000710432018, 0.04206284720982824, 0.00971367662506444, 0.059646403683083396, 0.05777664615639618, 0.035338215729487796, 0.025394788843446543, 0.048105225299618075, 0.05501009264428701, 0.011008339252189865, 0.019357530300372412, 0.06676648876496724, 0.057917876435177665, 0.05037061284695353, 0.013023531430267861, 0.03579797748742359, 0.050053977873176336, 0.025241685898176262, 0.03544023346954158, 0.003064520291185805, 0.03512156967605863, 0.05295360567314284, 0.019376179835359966, 0.0714696321104254, 0.04064184221039925, 0.07239828192229782, 0.028649709453540187, 0.08025590742805175, 0.01779480817328606, 0.03754350882289665, 0.058331443529043875, 0.01777531216586275, 0.00589708041765594, 0.02781960497876363, 0.0231047467262085, 0.005737641651649028, 0.027672344220003912, 0.022424958114113127, 0.03868459098573242, 0.06574786520962204, 0.057526700996926854, 0.06629397054868084, 0.10552292303847415, 0.12821305942322525, 0.015700430110363022, 0.007018949861438679, 0.016384549472214918, 0.0166451137047261, 0.012441769075979079, 0.031704619992524385, 0.034834732567625384, 0.04733915587088891, 0.04812146942796452, 0.04973337346954005, 0.04806386859023145, 0.03888916590117982, 0.06255634182265826, 0.016306482321981872, 0.026625753147527575, 0.027975281268092136, 0.05288101260417274, 0.03727916854300669, 0.037036711017468145, 0.04805996022852404, 0.03277427955929722, 0.02970611723139882, 0.00456308905268088, 0.03176619026011654, 0.017750075752181665, 0.06448192921067987, 0.01733168597067041, 0.019228732479470115, 0.01634617492423526, 0.07853756499077592, 0.036142137234232256, 0.04722166074705975, 0.03182693950033613, 0.013593324426827686, 0.02902865090540477, 0.019931740559903637, 0.06412525049277715, 0.011009663243645003, 0.014626850307519947, 0.03923551731609872, 0.04195767767461283, 0.06591115466185979, 0.04348103628892984, 0.0839953546279243, 0.032256944105029106, 0.0067382115105699214, 0.07081960913326059, 0.010197966575755604, 0.03153842641040683, 0.02296013055768396, 0.05308615748903581, 0.024309884291142225, 0.04094870288723281, 0.011643553202572678, 0.03665072976478508, 0.03898515146491783, 0.0528229978600783, 0.06641781676028456, 0.034098403328763585, 0.04484613678817238, 0.02382495397302721, 0.05121319727706058, 0.03325863481898393, 0.03693328870992575, 0.039704429118760994, 0.026332132385245392, 0.029929833619722297, 0.030774216167628765, 0.023312658337610107, 0.05896342426006283, 0.04092478792050055, 0.042747444938868284, 0.04012010984921029, 0.029247308815164224, 0.008481485868937202, 0.0033336838948473868, 0.037221075767385106, 0.03779755572655371, 0.04154004954866, 0.039761578730706654, 0.03991714306175709, 0.05495364870876074, 0.035543866122939756, 0.06239821602191244, 0.16206660999783448, 0.24289843759366445, 0.10807188054812805, 0.13722086963909014, 0.18927722131567343, 0.11970355175435543, 0.06318279249327523, 0.15831395850649901, 0.09955042387757983, 0.16414668623890194, 0.1582784846957241, 0.1983623845236642, 0.15105953706162317, 0.11208325065672398, 0.07564735186419316, 0.17099344384457382, 0.08894790709018707, 0.15378335304558277, 0.13750034464257105, 0.09645107947289944, 0.09191481502992765, 0.07304872559117419, 0.18049435902919087, 0.09574915535215821, 0.14057869517377444, 0.15045444667339325, 0.16359720858080046, 0.23264832475355693, 0.1404883007385901, 0.08392349098409925, 0.07329095580748149, 0.13311523066035338, 0.06184612600398915, 0.11643498071602412, 0.1063149566096919, 0.13913646899163723, 0.07452157405870301, 0.3091478283916201, 0.14334067196718284, 0.07991480787417718, 0.17694058615182126, 0.23864057606884412, 0.12178243377379008, 0.15962154977023602, 0.14285897995744432, 0.07766415471477167, 0.1171157956123352, 0.14247650333813258, 0.13852091559341975, 0.07817292027175426, 0.13079641865832464, 0.19779526495507785, 0.1713305671832391, 0.1606548907501357, 0.14170599968305655, 0.1326277982443571, 0.10725457154746566, 0.12922871778053896, 0.1439757128911359, 0.14079180945243153, 0.11343067192605563, 0.09534172900021076, 0.12394630908966064, 0.11792934552899428, 0.15766962165279047, 0.08742279785552196, 0.11015512554773263, 0.22466203543756688, 0.1509883723088673, 0.12558658607304096, 0.0768544656623687, 0.13291061164012977, 0.13719868154398032, 0.1639289307807173, 0.07702238272343363, 0.1721246295741626, 0.1343182461070163, 0.17685042241854326, 0.15796633144574507, 0.14989738299378327, 0.10627561514931065, 0.10798440381352391, 0.09825073754681007, 0.07751335709222726, 0.1062773996964097, 0.14493294938334397, 0.1707901411822864, 0.182887484186462, 0.13929737678595952, 0.2122965082526207, 0.2232657325054918, 0.19758635759353638, 0.14173637091049127, 0.21744645333715848, 0.0859015698411635, 0.15710769966244698, 0.11440104485622474, 0.08715191989072732, 0.18561010594878877, 0.11952470349414007, 0.11038158661020653, 0.12419628139053072, 0.08192727488598653, 0.15023675906871045, 0.12305090070835181, 0.08567702903279237, 0.11883216351270676, 0.16132699325680733, 0.08876432944089174, 0.12522378696927003, 0.11105320735701493, 0.13574307465127536, 0.1390624815332038, 0.09008793413106884, 0.09546250823353018, 0.1698387400912387, 0.052549700917942185, 0.09363749330597264, 0.17074429935642652, 0.1799609355096306, 0.14449070739958966, 0.1512219783450876, 0.14809269697538444, 0.13404665568045207, 0.1503929171179022, 0.09760724886187486, 0.10004118790051766, 0.15511565655469894, 0.15498613779033932, 0.0860557940655521, 0.1364507188222238, 0.17031116331262247, 0.14578901630427155, 0.11926312824445111, 0.07235789551798787, 0.11274986381509475, 0.08238253795674869, 0.17838484793901443, 0.16566564116094792, 0.20813664075519356, 0.06590856265808855, 0.1574495184634413, 0.13557702356151172, 0.11048707166420561, 0.06433425963457141, 0.10647377451615674, 0.11031225390200104, 0.08897127583622932, 0.16683715901204518, 0.12624290585517883, 0.11748124100267887, 0.09276282095483371, 0.07970792933234147, 0.21303993836045265, 0.1940178062234606, 0.16365609184971877, 0.10235303134790488, 0.06466722355357238, 0.10208481324038335, 0.058425902388989925, 0.1304080116429499, 0.19557733753962175, 0.20851603682552064, 0.13361288181373052, 0.11924448210213866, 0.13665194516735418, 0.07681846937962941, 0.11982750653156213, 0.07551262195089034, 0.0985096257978252, 0.22135486932737486, 0.09819604762430702, 0.12928519903549127, 0.12682720593043736, 0.258875983101981], [0.008393392515634852, 0.006254623419538672, 0.045747974288782904, 0.032040868021015606, 0.048559480745877535, 0.07228982488491706, 0.018331166356801987, 0.04424542295081275, 0.021611318291564072, 0.020525027831484164, 0.041190057793366056, 0.034358180460653136, 0.014632833290046878, 0.03750421485996672, 0.017320810750659024, 0.0363463389554194, 0.02262662720334317, 0.03483801667711564, 0.020203254651278257, 0.023845907134403075, 0.009218321464556669, 0.004893844764280532, 0.037760161661676, 0.02565212324926896, 0.07312600394444806, 0.03113322226064546, 0.029695854389241765, 0.01939509908801743, 0.02999869474608983, 0.05188951687887311, 0.0769111979752779, 0.07915659248828888, 0.024315110707123364, 0.009639354988134332, 0.020976279063948562, 0.025533362657630017, 0.05634068285248109, 0.016651390153648596, 0.020277235324361494, 0.002732162600815562, 0.03721044312364288, 0.015350519779271312, 0.033196626896304746, 0.0514390985481441, 0.020013307254495363, 0.026311978198853985, 0.027443138483379568, 0.018052003479429653, 0.03681834487776671, 0.006226883635723165, 0.01840309106877872, 0.0073325615376234055, 0.08726689764963728, 0.03528191428631544, 0.04659346963411995, 0.05941495538822242, 0.04612166387960315, 0.06028755142220429, 0.0525621927476355, 0.04813082642587168, 0.02808944648131728, 0.045986180792429616, 0.019552337704226375, 0.05401614062221987, 0.03283548002530422, 0.046035323691155226, 0.013297172728925943, 0.05118223572415965, 0.010086950613185763, 0.041986776648887565, 0.03565352077462843, 0.014126557956582733, 0.008954157603771558, 0.04622948309406638, 0.022596237316195453, 0.050742921619010825, 0.04566677400310125, 0.02954395075461694, 0.012220414837689271, 0.04192042949476412, 0.017279993476612226, 0.019608885116342987, 0.02106914167026324, 0.03429648466408253, 0.025947341961520057, 0.030656849965453148, 0.006607437456425811, 0.03257105492853692, 0.03431657608598471, 0.0926352563713278, 0.053135300387761424, 0.034332806643630774, 0.07908265931265694, 0.06647273738469396, 0.037998955098113844, 0.036782100929745605, 0.007736871717497706, 0.05959106915231262, 0.03792558849922248, 0.02029877032951585, 0.04796624436442341, 0.10571448704493897, 0.010836093985874738, 0.05359841410868934, 0.024786741738872867, 0.03323447557964495, 0.024288739443623593, 0.05344264282445822, 0.02354189969732293, 0.05299117276445031, 0.045333399570414, 0.033406691160053015, 0.0781698397227696, 0.056098995464188714, 0.03667801705056003, 0.038600367826542685, 0.0433685487535383, 0.027954012587932602, 0.017859116329678466, 0.09880732625190701, 0.011387117855649973, 0.02559777768328786, 0.08442929134305034, 0.024585011581491147, 0.0677027449543987, 0.032550050877034664, 0.005695815480846379, 0.052741994349552054, 0.06160615530929395, 0.019944678526371717, 0.025062664611531154, 0.06436062750539609, 0.017477769471172775, 0.01122312357516161, 0.060898409358092716, 0.012748477082433445, 0.06562274335218327, 0.02428154188341328, 0.060612929319696765, 0.018455038013468896, 0.034935851248779466, 0.028771889861673117, 0.05102059171934213, 0.0511282921901771, 0.08988255515162434, 0.013740344305655785, 0.06390344418053116, 0.03560646437108517, 0.04184257099404931, 0.049496398506952186, 0.057578764988907745, 0.010195197304710746, 0.011641830571794083, 0.0604692834562489, 0.010000269460890974, 0.007825094840622373, 0.05271283430712564, 0.013976620377174445, 0.059940881095826626, 0.0346494246540325, 0.015899273101240396, 0.03009520617446729, 0.010047465812281837, 0.02228521552336003, 0.004590132065849113, 0.00881106050552002, 0.033699312779520235, 0.03380439071250813, 0.037858179437794855, 0.04202774998598865, 0.040455865939813, 0.053941729079399786, 0.019675976962649395, 0.036345616315624545, 0.011128682526759803, 0.030421303319079534, 0.013815157880474414, 0.02498005297301071, 0.08921958572630372, 0.04233177777911935, 0.040964275265910795, 0.04461768422541874, 0.03742393059656024, 0.06939245321388755, 0.042352717369794846, 0.037745410310370583, 0.02380926115438342, 0.028490633703768253, 0.012570488017185457, 0.030289514855082546, 0.032439117186835835, 0.027614914712363055, 0.04215476834880454, 0.008023074395688517, 0.034804147601659806, 0.015320296133203166, 0.018850126902439764, 0.017787753105429665, 0.04200178584350007, 0.05468180383156453, 0.05154356240694012, 0.042745517899415324, 0.019786425500309894, 0.03757346275129488, 0.04732643333928926, 0.059211951281343184, 0.01922821340018085, 0.02906909159251622, 0.009080924060461777, 0.01565778927345361, 0.12458113288240773, 0.008006889639156205, 0.021059153634788733, 0.004108456595401678, 0.01126946582059775, 0.008969795291445084, 0.015118320006877184, 0.009400540347477155, 0.04777556245348283, 0.04259040818682738, 0.04959220425891025, 0.07628769214664187, 0.03083711297118238, 0.04770622295992715, 0.045906724341745885, 0.038690728334976096, 0.056259543634951115, 0.008994340447575917, 0.023168839447732483, 0.030369218971048082, 0.005620207171887159, 0.03875097885195698, 0.04693621463541474, 0.03646076370828918, 0.024417801893183162, 0.04586173068465931, 0.07294900808483362, 0.03775436697261674, 0.028575582895427942, 0.016523292920153056, 0.02878899572949324, 0.04769037916724171, 0.015449280551235591, 0.02200940121630473, 0.03607569169253111, 0.043290340807288885, 0.030310488372508968, 0.06798196889992271, 0.03713957014094506, 0.11088605704052107, 0.06298838542508227, 0.09141896199434996, 0.037322377652994225, 0.05739744007587433, 0.02853508453283991, 0.048777595827622075, 0.013012127801110702, 0.02920509036630392, 0.04002225831417101, 0.09399081327553306, 0.02913022759769644, 0.048168400302529335, 0.03790113748982549, 0.03635199793747493, 0.08051145728677511, 0.0632910527555006, 0.09158066367464406, 0.0487297862502081, 0.09299038124403783, 0.025759034923144748, 0.050578885778252564, 0.11606308924300329, 0.03547860462484615, 0.060722071677446365, 0.042827366186039786, 0.012129577658405262, 0.04134032276592084, 0.06293347158602305, 0.04947838340220707, 0.029543102585843632, 0.02334415084416313, 0.04571586261902537, 0.058680095177675994, 0.03408874777544822, 0.014945731232208865, 0.1102345073595643, 0.0519917347867574, 0.05805292525993926, 0.035000688662486415, 0.0915134751370975, 0.054658621682652404, 0.019427804475916282, 0.06509280750261885, 0.041912958824208806, 0.04108105453529528, 0.07171046454459429, 0.005975669191684574, 0.04673940555325576, 0.07011649757623672, 0.023774633816044246, 0.06145980887647186, 0.0071496361301147515, 0.024290705498840128, 0.007625632686540484, 0.065096050900008, 0.06204163908426251, 0.04600301863891738, 0.010433432646095753, 0.0400929989825402, 0.0598551956936717, 0.049426835096840344, 0.055745627997176986, 0.034986171405762434, 0.131609140762261, 0.11545304554913725, 0.028320363822526166, 0.028272561030462384, 0.03849516097190125, 0.03968649883089321, 0.03417582078171628, 0.034948740021458695, 0.058713214471936226, 0.02083274346244122, 0.020847450708970428, 0.031295704256211004, 0.03769144302766238, 0.037921415508857796, 0.03109648298206074, 0.020922466147957102, 0.027081954292953014, 0.07052374072372913, 0.011529091130276876, 0.02809603505634836, 0.010163867646562201, 0.030043966602534056, 0.06588414896811758, 0.033703543445361514, 0.008137349022685416, 0.03786337023068752, 0.05543879446174417, 0.03731387560921056, 0.02675602847843298, 0.06312043512506144, 0.041842557423348935, 0.04245342214458755, 0.05219614685380033, 0.016587619736258472, 0.04718182056343981, 0.005051166925113648, 0.023411437769287398, 0.00572159345028922, 0.00927825561458511, 0.07868820655026607, 0.08878545223602227, 0.1612418642533677, 0.12142586362149034, 0.16773254025195325, 0.14385570718773774, 0.1353011176522289, 0.20228225418499537, 0.15898228835846695, 0.10747046781969921, 0.093713224599404, 0.10429745486804418, 0.14780464528926782, 0.14346446389598505, 0.14379047283104487, 0.1459018023950713, 0.11307769800935473, 0.05614411125757864, 0.09159438365272113, 0.09363860610340323, 0.09432753627853734, 0.07667854188808373, 0.13967518508434296, 0.11103663753185954, 0.24178849001015934, 0.1884740801262004, 0.12436862928526742, 0.09169708671314375, 0.1765681654214859, 0.17842931912413665, 0.15881749934383801, 0.16579620486923627, 0.1107999916587557, 0.06549205750759159, 0.17536513640412263, 0.11868831408875329, 0.14316251581268652, 0.1101730592282755, 0.13317194261721202, 0.08782066364905664, 0.08473999931343965, 0.13033846180353845, 0.12413209197776658, 0.12268557745431151, 0.09848824515938759, 0.16428174184901373, 0.11813935211726598, 0.13343726338020392, 0.17033763974905014, 0.16011488544089453, 0.1665495823004416, 0.09279272399310555, 0.14872164465487003, 0.1377119661441871, 0.12360451743006706, 0.15557429194450378, 0.14594665355980396, 0.15903114287980966, 0.11746819955962044, 0.17296868642526014, 0.15190113761595317, 0.11768268447901521, 0.09259907009878329, 0.11126476779047932, 0.13063171106789792, 0.17341031772749765, 0.15089643081384047, 0.1685854180582932, 0.07208372665835278, 0.12716287720416272, 0.15777702017554215, 0.12169966607221536, 0.06630445391471897, 0.20869100386542933, 0.13205656675355776, 0.11728047606136117, 0.12048662187797682, 0.1700109794203724, 0.09296693107379334, 0.16272632245506558, 0.2708401839647974, 0.1052948742040566, 0.09231719308133636, 0.19398906348007067, 0.1636276069496359, 0.20119123772851058, 0.09609880444726773, 0.08476083712386233, 0.2029624991118908, 0.24799990813646997, 0.118817982130817, 0.1124428470752069, 0.1623291080551488, 0.19270607589610986, 0.19319007492491178, 0.1861888420368944, 0.12029736489057541, 0.1797793595386403, 0.10861951259097882, 0.16943172764565262, 0.18660068565181323, 0.25530447331922396, 0.10325940485511508, 0.16351055965891906, 0.13347872186984333, 0.13020994727100643, 0.15198081119784287, 0.09375047617192779, 0.1781229605632169, 0.18585637344845704, 0.13594255037605762, 0.14352479922984326, 0.1533139289489814, 0.2135782473321472, 0.17026404584092752, 0.15817130330417836, 0.18234266127858842, 0.12105444712298256, 0.13829345708446844, 0.1977405614618744, 0.10255853246365275, 0.1408285724797419, 0.2630108669400215, 0.0798650441159095, 0.4068242199718952, 0.09649004095367023, 0.09605801770729677, 0.158397608303598, 0.0947273223261748, 0.19882414117455482, 0.0764492309785315, 0.11717471959335463, 0.21872745959886483, 0.13254123074667795, 0.21493991783687047, 0.17551399341651372, 0.14161559167717183, 0.2267773819289037, 0.19771510282797472, 0.07830153658453907, 0.1643369881702321, 0.14450036973825522, 0.1507360522768327, 0.12679710611701012, 0.1357148883066007, 0.16646677388676576, 0.13907054252922535, 0.1239135494189603, 0.1352922695555857, 0.10327577790511505, 0.12944751818265232, 0.13357374391385488, 0.1448266500873225, 0.17048285981374128, 0.12050621796931539, 0.0791389098657029, 0.25715942521180424, 0.17748473052467617, 0.11603976120906216, 0.14616789668798447, 0.0964474289544991, 0.12990624856735977, 0.13334391053233827, 0.15566908328660897, 0.1217141052974122, 0.06781969725021295, 0.18594154316399777, 0.14343344127493246, 0.12617737294307776, 0.19412365768636974, 0.1765676633055721, 0.15481053292751312, 0.09056009950914554, 0.06219568010419607, 0.11693945793168885, 0.14395047138844216], [0.005264507240748831, 0.03442468028515577, 0.04438085854053497, 0.06099569092371634, 0.05053363088518381, 0.014536774783794369, 0.03871132526546717, 0.02116751906994198, 0.06556565820106439, 0.02833249093964696, 0.038219180423766375, 0.025476394553801844, 0.06726370565593243, 0.050259886109935384, 0.04931920587218233, 0.019628627092710564, 0.0235636280849576, 0.012556135305203497, 0.04547182071421828, 0.022345949496541704, 0.0387722034273403, 0.0128061703705628, 0.02392165539120989, 0.021301489024023925, 0.045830362010747194, 0.038812586438975165, 0.0394623481801578, 0.018546163570135832, 0.04219377732702664, 0.033437184523791075, 0.024956875913111225, 0.05168541693793876, 0.007954447363902415, 0.009319146679315184, 0.011368298686907759, 0.028441151537533318, 0.02250064191009317, 0.026222140162384937, 0.03717040955754263, 0.018096949639064924, 0.030707770625927618, 0.029684136089469706, 0.07078855258545705, 0.06699977588972875, 0.06451116049928324, 0.0414986860539232, 0.0501137873423951, 0.0026057398645207286, 0.0373972913117281, 0.04539963137358427, 0.012186462641693652, 0.03579212512288775, 0.05112806148827076, 0.02681340031059725, 0.04956863534503749, 0.05539538518392614, 0.04760583709659321, 0.03327097397829805, 0.043502803692328076, 0.025049998059070537, 0.03233286878094077, 0.0391526953317225, 0.0659686333632895, 0.04549684508570603, 0.011562251984806997, 0.018422727872218405, 0.03414867938097034, 0.09505641859556947, 0.06089607519762857, 0.047251614675457985, 0.02079346137387412, 0.049654883931257894, 0.053534353617578745, 0.07601343507745437, 0.010053987381979823, 0.043322761210479906, 0.05823704573724951, 0.014955178136005998, 0.003162890057345586, 0.01236784438203488, 0.020895506255328655, 0.08206772484949656, 0.06121779579137053, 0.06121779579137053, 0.013657887882020856, 0.06314151720809084, 0.02311320466521595, 0.050623672482158454, 0.008329009720390397, 0.022441224294847677, 0.018200438103771636, 0.03687652247026563, 0.03875751992953675, 0.03424382016861013, 0.021979184355586767, 0.030910276009568145, 0.06214211654982396, 0.01382622478662857, 0.02233806491962501, 0.034492669494024346, 0.009412955841980875, 0.03774812784312027, 0.06380714649068457, 0.02936672080042107, 0.020596881297283938, 0.017238339908154945, 0.036224450317344496, 0.057469547992306094, 0.018038502328896096, 0.01678796228952706, 0.0550974506352629, 0.0317838830607278, 0.04164189086960895, 0.005341113420269851, 0.022393462214885012, 0.04757696882422481, 0.02089905838615128, 0.04440011875703931, 0.0039089719648472965, 0.06711832274283681, 0.029011355047779422, 0.031767733927283964, 0.09291284504745688, 0.00867553670624537, 0.041590288281440735, 0.04091950213270528, 0.01818010919461293, 0.02980347682854959, 0.032109973419989855, 0.013886229334665197, 0.041706422942557504, 0.0660387124600155, 0.06323159273181643, 0.0241469374990889, 0.0212847834918648, 0.04354925619970475, 0.031558171779449494, 0.0054262445441314155, 0.015874986636585424, 0.05113894518996988, 0.04269750136882067, 0.042582516824560504, 0.012216488664437617, 0.028042322224272147, 0.04506959533318877, 0.037045467511883805, 0.005469899790893708, 0.049119007507605214, 0.0568524509269212, 0.02100048240806375, 0.02491099337515022, 0.025273358216509223, 0.03882149899644511, 0.025691552919202616, 0.024560786184987853, 0.05849486868828535, 0.07655779658151524, 0.029412057117692063, 0.07202917922820364, 0.04227859420435769, 0.052437545864709785, 0.0631886278944356, 0.03195533189656479, 0.014512342434110386, 0.013767472135701349, 0.046142477941300185, 0.029301160746919255, 0.017044073635978357, 0.03712412329124553, 0.03198874296088304, 0.03384807140433362, 0.0399809932070119, 0.05231409320341689, 0.04469790402799845, 0.03618924113522683, 0.0458409030522619, 0.0301168887609882, 0.02437505079433322, 0.04529029902602945, 0.07712328088070665, 0.02083930150339646, 0.048874629727963886, 0.01261818309181503, 0.03373532263295991, 0.00388318084878847, 0.06673161885035889, 0.04360511659511498, 0.0203577570750245, 0.03962845355272293, 0.012983827801820422, 0.024117227843297378, 0.009555106383881398, 0.03524555838001626, 0.05294305784627795, 0.03686188307723828, 0.08200797984110457, 0.06045503422085728, 0.02075090705017958, 0.02736086950504354, 0.05749364955616849, 0.06345804022358996, 0.025200271513313055, 0.038086526827620606, 0.021689516059788208, 0.019880886056593487, 0.032331732234784534, 0.03315465611272624, 0.03662646874519331, 0.011913888339352394, 0.04001970362982579, 0.024929441045969725, 0.03145720576867461, 0.016245956998318434, 0.06296766296561275, 0.031597988214343786, 0.015590800903737545, 0.01976228492068393, 0.04086651194042393, 0.09214062469878367, 0.019531737381060208, 0.06469273647027356, 0.026873211476153562, 0.021963411809078286, 0.06554909516125917, 0.0618611623400024, 0.03611844279138105, 0.029883784840681722, 0.04542709507846406, 0.07137607570205416, 0.041813153108315806, 0.02265805864174451, 0.06472829849060092, 0.02566845728350537, 0.028231222980788777, 0.05152438700731311, 0.02067008674410837, 0.08855894367609705, 0.012238026214098292, 0.019872406065197926, 0.06737733991550547, 0.028570816186921935, 0.01758506621367165, 0.00831871379965118, 0.02083621416906161, 0.021944991279659525, 0.03092389420739242, 0.027583025262824128, 0.041370432757373364, 0.04513806290924549, 0.05501846576641713, 0.02419657912105322, 0.02394305299302297, 0.036579459839101346, 0.05374780037839498, 0.052547997795045376, 0.06915411100323711, 0.033156155675117455, 0.031316827051341534, 0.0034760712878778577, 0.06265955378434487, 0.009836848542493368, 0.068830856920353, 0.05545982565464718, 0.03737557479845626, 0.010817435121030679, 0.02785969282766538, 0.043909188493021896, 0.05448213472430195, 0.04059639732752528, 0.06457777906741415, 0.1417482452733176, 0.035613225972546, 0.09661008736916951, 0.04304499611524599, 0.04954059827806694, 0.039898072835057974, 0.02998734964057803, 0.05650053552484938, 0.04802199619423066, 0.004117378906812519, 0.03178825282624789, 0.041078913757311444, 0.013160985661670566, 0.011884668076943074, 0.013225471085336591, 0.022653130781171576, 0.07419090358806507, 0.02794893375331802, 0.056547004995601516, 0.059579839397753985, 0.022990038684968437, 0.016923302884346673, 0.0289103585029287, 0.013517141059440161, 0.03631039017013141, 0.05636915418186358, 0.055086203917328797, 0.06085796867098127, 0.02881156719688858, 0.00687969199913953, 0.05310004370819245, 0.03535330295562744, 0.01705850098681237, 0.05128565124635186, 0.040902952663600445, 0.010888656701094337, 0.08128979123596634, 0.0884453569139753, 0.019630353964333023, 0.024739910948223302, 0.026613724417984486, 0.023289547434874942, 0.03345631581864186, 0.030685049880828177, 0.006532656536104956, 0.02796226696643446, 0.03251204952331526, 0.06998301616736821, 0.030162706838122437, 0.045217651674257855, 0.02391506851251636, 0.029363915058118955, 0.020321022885452424, 0.08820702148867504, 0.020342861535027623, 0.05474182364663907, 0.06080479188156979, 0.029201874110315527, 0.03248872488204922, 0.036185197066515684, 0.06915390744273152, 0.034028137634907446, 0.05768387684864657, 0.02413326332212559, 0.07002906833908387, 0.0347647925705782, 0.00943698700783508, 0.05931718527738537, 0.061383365121270926, 0.05636974111465471, 0.027527380302282314, 0.07092201363827501, 0.0762298945337534, 0.028724199027887413, 0.033259011405919275, 0.03795678075402975, 0.05188652114676578, 0.03710330583687339, 0.04907162540725299, 0.06062492581882647, 0.02824173348822764, 0.006253027589991689, 0.11536136189741747, 0.12923198831932886, 0.13481969705649785, 0.18798283434339932, 0.2330800901566233, 0.14029223125960144, 0.12219388383839812, 0.16264966156865868, 0.12050243174391133, 0.10861276116754327, 0.11879573975290571, 0.16803497688046523, 0.17769385501742363, 0.11302549152501992, 0.1181183989558901, 0.1357786977397544, 0.11347944502319608, 0.148427866133196, 0.16892190357404097, 0.1470919121056795, 0.14836911857128143, 0.07100501882710628, 0.09515948806490217, 0.17298916461212294, 0.16139431750135763, 0.0738491594259228, 0.14918830032859529, 0.08015319758227893, 0.1541088055819273, 0.13671389541455678, 0.13331789549972328, 0.11633892729878426, 0.06707170060170548, 0.06956594104745559, 0.12157145009509154, 0.13929063214787415, 0.10551281965204648, 0.20211253900613102, 0.1156287318361657, 0.1160353235900402, 0.11668016255966254, 0.22853949666023254, 0.16374712410782064, 0.1718611679971218, 0.1413140371441841, 0.10400296388460056, 0.1080942450623427, 0.10334763476358992, 0.15201534863029206, 0.12329465762845107, 0.07973910801644836, 0.17773603275418282, 0.12239395667399679, 0.0862114771402308, 0.10994523431041411, 0.18424939896379197, 0.12075640740139143, 0.13365215542060987, 0.14907221655760491, 0.11962565593421459, 0.15509813678051743, 0.13259517428066048, 0.27411813235708643, 0.1848549914679357, 0.12659104860254697, 0.038637215670730383, 0.11021992564201355, 0.14543659878628595, 0.11104866795774017, 0.17890848698360579, 0.0870271237300975, 0.10126719211361238, 0.15654393205685274, 0.18574254241372856, 0.09335157221981458, 0.1832717792796237, 0.20304674601980618, 0.12113349645265512, 0.17176325539393084, 0.2161028997174331, 0.15866936157856668, 0.16035116490508827, 0.12292500532099179, 0.15202354533331736, 0.10504127174083676, 0.1833205795181649, 0.11991108847515923, 0.10893872939050198, 0.08324849791824818, 0.08191401631172214, 0.12762267967419966, 0.15964239436600888, 0.15781884507409163, 0.134002008076225, 0.3328392585473401, 0.11124344822019339, 0.19962603385959352, 0.1735325897378581, 0.13147420728845255, 0.14653813253555978, 0.12400444597005844, 0.19062758742698602, 0.11904050090483256, 0.04558452877349087, 0.1335888888154711, 0.07114059690918241, 0.13015136255749635, 0.11108628593917404, 0.10466686968824693, 0.06862885704530136, 0.19209329092076846, 0.13734083463038715, 0.15275987796485424, 0.13129734035049165, 0.11311866116843053, 0.09027341167841639, 0.10705574043095112, 0.0891922814771533, 0.10372433026454278, 0.2853040264121124, 0.14502893494708197, 0.1590736327426774, 0.17935091895716532, 0.11856292081730706, 0.12919378679777893, 0.07975778808551175, 0.09539753172014441, 0.1336994357407093, 0.1719577642423766, 0.11702621541917324, 0.15346210742635386, 0.16402704694441386, 0.09507671357797724, 0.14471969939768314, 0.13511810318699904, 0.06963609478303365, 0.11075828211115939, 0.1280055905559233, 0.07833392306097917, 0.1451876171465431, 0.09326607002211468, 0.13393548450299672, 0.07962590123393706, 0.15515757644815104, 0.12509250401386193, 0.14733735179262503, 0.1387930895601, 0.16775243489870004, 0.15633416974118777, 0.14008333746876034, 0.11764122598937579, 0.10593554696866445, 0.07930534093507699, 0.1304404998996428, 0.1503031062228339, 0.14762666555387632, 0.2603696829506329, 0.1265272255986929, 0.1396345408367259, 0.13110846334270068, 0.11087017253573452, 0.1077749061265162, 0.12364650517702103, 0.13706273026764393, 0.12998878556702817, 0.15307151552821907, 0.12845716918153421, 0.12485150194593839, 0.158903659720506, 0.08483418675937823, 0.10447297830666814, 0.14103363933307783, 0.2141855361738375, 0.181264211290649, 0.11872160301676818, 0.12121211151991572], [0.050190013966390064, 0.04573504819667765, 0.02128857989529414, 0.021775281189807823, 0.05236697822277035, 0.029945769014635255, 0.020262080244719982, 0.03150748521355646, 0.05682924502928342, 0.013318993566956903, 0.042858812891479046, 0.05592096823134592, 0.030882208408521752, 0.02920955851940172, 0.013509818818420172, 0.04193065841017025, 0.0262137992706682, 0.04983597135703478, 0.009322733585057514, 0.012879753252491355, 0.11034989223948546, 0.04198252223432064, 0.07305280358663627, 0.050837672249014886, 0.005585682461969554, 0.01679102417879871, 0.05462232005915471, 0.05962129110204322, 0.05797376057931355, 0.024034203994753103, 0.05993786161499364, 0.039947392152888436, 0.019768123714519397, 0.04205522047621863, 0.025438586582562754, 0.05274825044242399, 0.022182059540812458, 0.06403404181557042, 0.03718269443405526, 0.07076017625097718, 0.019354332704097033, 0.03964863996952772, 0.02381518646143377, 0.02822908729181758, 0.01423550523551447, 0.023544657942173735, 0.05576159392616578, 0.02394803852907249, 0.02950533532670566, 0.06267495652926819, 0.029354727693966458, 0.055750286140080006, 0.0049783096515706605, 0.022019180602260997, 0.0711788527135338, 0.05194807445098247, 0.07815088823969875, 0.01450818301444607, 0.017867725242727568, 0.03315809628527079, 0.053045788048101325, 0.007431622561333435, 0.02506221677841885, 0.02055378584191203, 0.030891650223306248, 0.09613819340510027, 0.08124808847372021, 0.032985972307090244, 0.1172896498548133, 0.03279759741521307, 0.006751483655534685, 0.016628036674644266, 0.027302895473050218, 0.022338919873748506, 0.012335502010371004, 0.0383795148559979, 0.025803255050310066, 0.043422302297715626, 0.0441878628251808, 0.029377421297665154, 0.05013344110921025, 0.03145498017381344, 0.014844490414751428, 0.06383826410663979, 0.023083388140158992, 0.029291355915899788, 0.04124029991882188, 0.022299541093941246, 0.04111809915463839, 0.060560492133455615, 0.06397323829254933, 0.02729483108435358, 0.032026371120342186, 0.024318393120276074, 0.06477490706103188, 0.03315509037513818, 0.021324174146034887, 0.06226778123527765, 0.06602298401828323, 0.012358595949730702, 0.0575759762099811, 0.01567915634119085, 0.04027852742001414, 0.009231691148930361, 0.03129824876253094, 0.053535849787294865, 0.03002679966656225, 0.02175022119523159, 0.10567348995911223, 0.018547215299414735, 0.01710368293736662, 0.03539831357608948, 0.026450774233256067, 0.10741348444883313, 0.020317297728200043, 0.007076591835357249, 0.0272177851293236, 0.010107072569163782, 0.0652668381642018, 0.01933227353064077, 0.06329535466751882, 0.04900894234223025, 0.06289305125496217, 0.03500246981691037, 0.06258632628513233, 0.04543257764141474, 0.0670737497774618, 0.006482530609771077, 0.04131049097382596, 0.08438676755343165, 0.09836591886622564, 0.08411721951727356, 0.005513875221367925, 0.014268617744424512, 0.010338235031148153, 0.01936401709515069, 0.009198392042890191, 0.03610928596130439, 0.016484299208968878, 0.05794708736773048, 0.018165191602227942, 0.01728133697594915, 0.005979575432970056, 0.022826969756611755, 0.03967673471197486, 0.02758540352806449, 0.022195648900898438, 0.022336992834295546, 0.03575105339820896, 0.028234812431037426, 0.04356480822233217, 0.07286391300814492, 0.030482958403549025, 0.04320494717519198, 0.030860067810863256, 0.01725739486781614, 0.051768764786954434, 0.0734157587534615, 0.031175067515245507, 0.022632554206731062, 0.026347402815840075, 0.01783492316358856, 0.049046438187360764, 0.01161818447456296, 0.021679071709513664, 0.03839694981330207, 0.02577190673244851, 0.05433402070775628, 0.06603355559387378, 0.03046907896974257, 0.07066359357642275, 0.025206485197746327, 0.05634512047150305, 0.011080997630155512, 0.05167376309899347, 0.06992063165775367, 0.02777650104170399, 0.026284131121688654, 0.006339759632412876, 0.03172099304252437, 0.02317040686362556, 0.04073945625818201, 0.037604831425207, 0.0488671420940331, 0.044554203881749084, 0.021211835888347456, 0.0345927466239248, 0.052600991380001814, 0.06669613146888358, 0.04012498173064419, 0.050140698041234694, 0.01882969112401562, 0.039708269626966546, 0.0777040050764169, 0.05026225758982556, 0.0059155081565092716, 0.10421820197786603, 0.004093696762408529, 0.024560168718120882, 0.044043487536587884, 0.026362540932106118, 0.033966014361275096, 0.0404472824718271, 0.04269705692838345, 0.09304417550031628, 0.01825304831644254, 0.0423698096669146, 0.018089119344949722, 0.0363319302642984, 0.018786051144291247, 0.009878705671456243, 0.056430870334484746, 0.010995059473706143, 0.02735853025556675, 0.00837708986364305, 0.05384004042883005, 0.006318084679410926, 0.02961806034935372, 0.047861909427280934, 0.006545166601426899, 0.019893905447263802, 0.03344193087624652, 0.02715962958921279, 0.04553666491327541, 0.0033882275082370533, 0.017127558888335313, 0.046425997013492246, 0.08527608947562319, 0.027897405804001858, 0.043820921265121014, 0.10058235350464072, 0.009459896894570972, 0.10940778707819325, 0.016352327540516853, 0.036689331621995995, 0.010759715539669352, 0.05320278748071619, 0.02193335270775216, 0.05123410972633532, 0.028335213561409285, 0.032325655953692536, 0.03777947276830673, 0.025765879645145366, 0.011182321568152733, 0.08800739648618869, 0.03993860512439694, 0.07336473292005913, 0.014397865094776665, 0.013430878054350615, 0.056231540494731495, 0.03556088038853236, 0.04526966477611235, 0.041205528391791243, 0.033921655134430954, 0.023122376762330532, 0.017129558870302777, 0.032478791129376204, 0.04173214281243937, 0.04328181840745466, 0.03343223461083003, 0.06966892230723586, 0.02318292244204453, 0.03933977761438914, 0.060469032398291996, 0.052602002397179604, 0.046620441401111226, 0.017828337981232574, 0.01639159775472113, 0.05717596624578748, 0.05878954287618399, 0.032135004576827796, 0.02565654899392809, 0.057360894179769924, 0.02333339606411755, 0.017734002953927432, 0.01006206703771438, 0.03649126725005252, 0.06650689483753272, 0.030639652495405505, 0.03542620475803103, 0.0651872663625649, 0.0655427508588348, 0.010351088180738901, 0.05084025068208575, 0.06878250451492411, 0.015877073131767765, 0.04924538126215339, 0.04906606820545026, 0.04357225175148674, 0.05486632464453578, 0.054907677961247306, 0.0371798140529011, 0.059885376931301186, 0.024522605019488504, 0.019905153861535445, 0.04713103221729398, 0.010868907939376575, 0.06242942184742008, 0.036762233424399576, 0.03868831953565989, 0.01896628870495728, 0.03547344436602933, 0.0032453441485163887, 0.012694346103151994, 0.015084216836839914, 0.034122012954737456, 0.06273130886256695, 0.024802880694291422, 0.030512576457113028, 0.015160965932799237, 0.09485118889382907, 0.060174351425043175, 0.0313914964374687, 0.020450519597423927, 0.043712603327419074, 0.035975729913583825, 0.038557192643306086, 0.048464180502508364, 0.0031698755753625718, 0.0195630687355463, 0.024211130304528133, 0.019652321535561765, 0.03785858316613095, 0.04341714882424899, 0.013369932038975614, 0.02464247671222048, 0.02173456908868892, 0.03945488429495266, 0.03477072635931628, 0.005665399724551077, 0.03076524593468223, 0.030885129501777034, 0.031208688925419534, 0.06102454223270927, 0.0727637205272913, 0.011748188391460903, 0.001231122699599447, 0.010707341117917426, 0.05757505340235574, 0.01678848815416651, 0.03876812882455332, 0.011375263000705411, 0.015813475740807395, 0.018945768109655807, 0.044514004074569256, 0.029228740704378912, 0.05598526281703796, 0.00835827408757593, 0.038631624542176723, 0.026133185917777673, 0.02069498728295522, 0.04347718221002391, 0.1038365735273276, 0.066532557031938, 0.09709433067057814, 0.09629569495362894, 0.10710922256112099, 0.24549744384629385, 0.13840609389756406, 0.11868773054863725, 0.14068829214998654, 0.10029215086251497, 0.10717642466936793, 0.12339626146214348, 0.14519753732851573, 0.10705124174377748, 0.15829771437815257, 0.0882207550374525, 0.11688022182456084, 0.11472086555191449, 0.15357998252979346, 0.1566923548068319, 0.23409170444522584, 0.14885138055043562, 0.2501761870724814, 0.09252283668943814, 0.14279354204024586, 0.13283116876014642, 0.19168106732623919, 0.1289854765470539, 0.1554193959704467, 0.10082029537963015, 0.18053940018372877, 0.08420562584485326, 0.13498763447361334, 0.14274981724364416, 0.095118911670787, 0.17867583089641162, 0.12839897801833494, 0.14956958272627421, 0.09812267763274056, 0.13370437547564507, 0.08709945556308542, 0.15263266621955804, 0.10333340588424887, 0.17808693035372666, 0.05760338223938431, 0.09354431687721185, 0.14440255212996686, 0.2617585084268025, 0.1107455799356103, 0.14081342757812568, 0.17630588449537754, 0.1770328940557582, 0.08227355166205338, 0.10279975844813244, 0.1636852417141199, 0.10140542326761143, 0.17343109446976865, 0.14122736108090195, 0.1215811667165586, 0.10425488358097416, 0.09448923117348126, 0.1303084162729127, 0.2207952950681959, 0.16665954568556376, 0.18774302649710858, 0.15866542607545853, 0.1108405137700694, 0.09608842286148242, 0.21718768722244672, 0.15439635515213013, 0.11967486329376698, 0.1393692743565355, 0.10578200806464468, 0.12203346458928925, 0.08113964500703982, 0.09166240678834063, 0.11606002226471901, 0.10714533419481345, 0.07315009193761007, 0.12177667979683195, 0.12285112642816134, 0.10804311066333737, 0.10260904939579112, 0.08967936105493989, 0.16686157270201615, 0.12459337365414415, 0.20860930824918406, 0.23917184184704507, 0.14239886536129884, 0.12191744867180075, 0.11320709463741098, 0.0944285158600126, 0.14099106804600783, 0.1729665965374027, 0.10925840080848762, 0.19582192227244377, 0.07943014388105699, 0.13986355997622013, 0.17133773251303605, 0.041955706530383656, 0.22111928196890013, 0.14068628368633135, 0.1242488000009741, 0.14372557774186134, 0.15431248822382518, 0.16035864236099379, 0.10912947236959424, 0.1341129214103733, 0.14290490320750646, 0.08676613880587475, 0.1072467751801014, 0.09227397040064846, 0.1983623438115631, 0.2921652910964829, 0.10076226706483535, 0.1322150318218129, 0.11462911404669285, 0.12378485846732344, 0.21224774872618063, 0.12100321772907462, 0.13162932039371558, 0.19478493077414377, 0.0785592645406723, 0.1329875167991434, 0.12913852690586022, 0.18628632037767343, 0.11960365782891001, 0.12067562102207116, 0.10592473790581737, 0.2193864392382758, 0.15587096102535725, 0.136483654912029, 0.1941648040499006, 0.061836796147482734, 0.1290091574192047, 0.15716218602444443, 0.1253575805042471, 0.06431279078658138, 0.12985986391348497, 0.19674953392573766, 0.13847633584269456, 0.07691597486180918, 0.1542607567140034, 0.1527758099670921, 0.11413394633148398, 0.13230500556528568, 0.11637024847524506, 0.13167574575969151, 0.15668297745287418, 0.14443510824016162, 0.08780249926660742, 0.17443745689732687, 0.07183814447905336, 0.13442863018385, 0.19055271787302835, 0.1463517253952367, 0.15668026331279958, 0.21989190711506776, 0.18945389826382908, 0.09748177416622639, 0.055924041994980404, 0.10402030723967723, 0.15229130882237638, 0.14251629263162613, 0.0999194790742227, 0.17293781308191164, 0.07661540420459849, 0.15828191808291844, 0.13678871068571294, 0.06458690536341496, 0.13944981646324905, 0.16232788669211523, 0.11175133168165173, 0.058208241925707886, 0.09459128284028598, 0.14619264964546475], [0.017708393345986093, 0.0690422612907631, 0.041175856055425744, 0.031810895539820194, 0.00629102300652968, 0.09158589517963783, 0.06744709331542253, 0.04258181454081621, 0.005959021335002035, 0.047837648407689164, 0.02036822178134961, 0.010959381254256835, 0.021352830376209955, 0.017680912677730833, 0.020192155514710715, 0.033248419474278174, 0.009970945721891309, 0.04340848053938576, 0.050270824094436, 0.009959699003957212, 0.02714777727877455, 0.023087167580212866, 0.028774715960025787, 0.04227680626458355, 0.014027267079135137, 0.022647081641480327, 0.006711322015949658, 0.05483621804575835, 0.08143562876752444, 0.0395104427422796, 0.06385272368788719, 0.07180523553064891, 0.030019593624664203, 0.02582989603147975, 0.05127553089654871, 0.04712432150595954, 0.02521188972916986, 0.05396826997665422, 0.024227162390681248, 0.052130946423858404, 0.023575809484879886, 0.02879966908533658, 0.025584257873041288, 0.013967970752024224, 0.02361754108486431, 0.06693627858268363, 0.011255571119753378, 0.012381800151030933, 0.035548653187496324, 0.028937330269919972, 0.03837533847295812, 0.0348839229638023, 0.026686458282970955, 0.048347845673561096, 0.03253816294350794, 0.024849421411220516, 0.01625913075570549, 0.11837508875344481, 0.044408322245414765, 0.023466007251824652, 0.047238162718713284, 0.032124253189457316, 0.03542018275974052, 0.054416232010615725, 0.022637668664434125, 0.06521642979766641, 0.027085158674578582, 0.06280218863061496, 0.02172394153395934, 0.00869502083930586, 0.04076495221150773, 0.015890235014792, 0.0061405990023298985, 0.029299885101084198, 0.03490740706079772, 0.06010374307100262, 0.0856651139578649, 0.035106913319655826, 0.00411929831274652, 0.03453811437689832, 0.024516408298430697, 0.06392206996679306, 0.032346849995000024, 0.006626326175007437, 0.08170758560299873, 0.019004434247368147, 0.05952998742993389, 0.05864194793892758, 0.0482546149619988, 0.019043136188494306, 0.04432152743850436, 0.020461165811866522, 0.0554596153087914, 0.06717050208577088, 0.006668086612730154, 0.005154786855980221, 0.009906078622277294, 0.03924973941008959, 0.05095453294260161, 0.05762107164732047, 0.052929894266916175, 0.046853779415999136, 0.021866574683891873, 0.04462508704247219, 0.056936382316052914, 0.018800866956423436, 0.0028089076679732117, 0.05544074185724769, 0.06747388866330896, 0.03348317223467997, 0.06270084942557982, 0.05206669255026749, 0.05490349140018225, 0.05035431782848068, 0.09465871565043926, 0.04693894913153989, 0.006257446549300636, 0.034566558564880064, 0.0353444887857352, 0.06087556986936501, 0.021389077716906155, 0.006825466873124242, 0.012792643774966044, 0.03471438081136771, 0.04248725050794227, 0.015383026695677211, 0.013788432930596173, 0.04286298927451883, 0.03976998917226281, 0.02550151222385466, 0.08856165781617165, 0.022078435369102017, 0.025423414539545774, 0.01616962520139558, 0.04127810110471078, 0.01157923910899886, 0.02297334502717214, 0.025751202932692, 0.041130529916180034, 0.08033089233296258, 0.03641729336231947, 0.03367404752810087, 0.07861354734216418, 0.053296876539077075, 0.042550174452896626, 0.02954970473157508, 0.02871243662333914, 0.01688944229057857, 0.01884145352856389, 0.05962536909750529, 0.03656280519706862, 0.018515682080760598, 0.044774588663131, 0.08106014105890479, 0.024274722606475865, 0.03650430190776076, 0.02470499862517629, 0.02230866569360452, 0.04291307533692036, 0.010631737897970846, 0.05032863527802484, 0.009025161204460477, 0.08002643367009503, 0.010507355643702405, 0.025059723162225316, 0.05430088105744549, 0.01533644357030945, 0.04977376665920019, 0.09252850245684385, 0.02182536046685917, 0.022065765423966304, 0.04364902798884681, 0.06924273446202278, 0.03967593064797776, 0.03305730330092566, 0.040939318747924905, 0.02111400810203382, 0.04841581452637911, 0.022697296625535403, 0.03658953269145318, 0.03237114833401782, 0.06448444657559906, 0.042991877001311095, 0.029314721269266944, 0.03650201524474791, 0.013670474706616784, 0.009656096991550709, 0.038085512417767725, 0.05576925797920142, 0.006841955274077398, 0.06931254893009152, 0.00292239646660164, 0.03821794209735734, 0.005355142555864794, 0.054116794506886175, 0.027898852779929127, 0.011016049106339259, 0.06399438144373042, 0.015065896391336406, 0.025197301226268922, 0.029651725864303962, 0.04721273461888943, 0.007142146799846419, 0.017195478547364473, 0.04247634984286768, 0.02389091605852757, 0.0885616306747709, 0.04726438809718404, 0.010392863037330764, 0.028033148430820023, 0.05372931708448699, 0.04891994908185942, 0.03994890867865511, 0.017153026003922735, 0.04588467534631491, 0.015882917014615874, 0.03954756539314985, 0.021875560183876326, 0.029835150843220096, 0.015181936057550567, 0.019208586774766445, 0.09734888308282409, 0.007615565771370062, 0.0447259919850954, 0.03596567063193236, 0.05387145660019346, 0.03213971700253231, 0.0535282026976347, 0.03649493473182831, 0.06565530624772821, 0.04595058823802641, 0.025263149657153657, 0.020495988229023557, 0.08553138827638966, 0.040801084201250754, 0.026207914675718973, 0.03699638568130987, 0.029650691098400524, 0.0587383270529764, 0.028896699593003308, 0.039735522985990555, 0.002735074152172144, 0.024971801987183944, 0.004224668863961207, 0.053602824586310556, 0.011481518191950662, 0.00931460049469024, 0.04843944450840354, 0.03419555597273367, 0.07100303750485182, 0.055068412729139836, 0.06488662785185234, 0.03491364958296929, 0.030019030440598726, 0.06969953102192708, 0.02415678813122213, 0.009866880502418747, 0.009838118251147015, 0.056168009260935445, 0.06753396615386009, 0.03855258539052946, 0.020363855408504605, 0.02835914209884192, 0.019436196257759417, 0.02590905223041773, 0.04629813048190304, 0.0593443809609328, 0.038848820208970986, 0.08570244016924075, 0.06857373964573656, 0.0018011875342511172, 0.02367028021918876, 0.030164623699550117, 0.011793725724731172, 0.02651942501376782, 0.030609705352357457, 0.03165127696203334, 0.0482409594447485, 0.03625505563936063, 0.06955590551452977, 0.08263934989060674, 0.008450347896931427, 0.02596242749132216, 0.023415054360936795, 0.019933986510815363, 0.032764498477003405, 0.012313707465572017, 0.025820786698854396, 0.04516896678666983, 0.04003470264641302, 0.027523734872894626, 0.034598269898976595, 0.032366005038576465, 0.023014725485284413, 0.03879269518490348, 0.034196112371448956, 0.034804815958653174, 0.024333610964406813, 0.05083713959902525, 0.022052286325820854, 0.04934887481587274, 0.030000631963568072, 0.06132120452821255, 0.03583344451284834, 0.07375997278307166, 0.03929232426785997, 0.05420932972005435, 0.022416052341993366, 0.029662765629057373, 0.041464891617319415, 0.023327940642567616, 0.022853327449411154, 0.025541652659220353, 0.08425944724253245, 0.04082017478400043, 0.017245288106745908, 0.04490718797647527, 0.04406946864245193, 0.04618775997576969, 0.041701856401882, 0.04046167419957263, 0.07762752060911485, 0.03109179430508188, 0.006095225365632879, 0.03831598362220185, 0.00708507776393422, 0.016871116756062423, 0.03758818356852446, 0.015122547280043364, 0.029305628900017058, 0.03475137793325952, 0.021709495523412312, 0.09892521492604699, 0.018231659196317196, 0.017517114324229102, 0.059135609306395054, 0.035814733909709115, 0.0692221884216581, 0.08386878749089581, 0.0166347219409155, 0.016688332992738912, 0.04815407982096076, 0.03456499793433717, 0.023350656298654418, 0.03439894684457353, 0.026908464763047438, 0.005153690173756331, 0.01729097217321396, 0.009165410151971238, 0.041813706114356, 0.03327153376968844, 0.044611244928091764, 0.17156369824494633, 0.15074256621301174, 0.11283967471016304, 0.15423319462154592, 0.08994595067841665, 0.1642956111047949, 0.14682999758848123, 0.0925703002139926, 0.11353949537234646, 0.13631463183888368, 0.11354760386581932, 0.11004853448165314, 0.17904299976570265, 0.09952005265014512, 0.2627672185855252, 0.08454150067908422, 0.09000862017273903, 0.20246283949485847, 0.12020934532795634, 0.10097451281866857, 0.12737894989550114, 0.09161096026322671, 0.09824973331498248, 0.17066727206110954, 0.08252486746226038, 0.10238793518926416, 0.1415406135576112, 0.06491311785898038, 0.16345036003206456, 0.12532665287809713, 0.15143486192183836, 0.22931175093565667, 0.20142716435449465, 0.1976298109761306, 0.21706371887453965, 0.15187352124069417, 0.12876430127237523, 0.11133261450699397, 0.19425959539200577, 0.12406398063259465, 0.1002145671684827, 0.1864716825740678, 0.0912637606795345, 0.1170422966991152, 0.2083230750369174, 0.12921999182019914, 0.0805562473833561, 0.13121937667684896, 0.09248863173914806, 0.183497745011534, 0.148405488048281, 0.1417014534984316, 0.2277238161436149, 0.1768073218741587, 0.09900823368557862, 0.09671387608562197, 0.10394117648580245, 0.1457519954336541, 0.11175065993198327, 0.1879827393484967, 0.08377284263925892, 0.12873763484614237, 0.19099425418036325, 0.2018131964973041, 0.0878790719434619, 0.1438941801232951, 0.09102868900767394, 0.13507787963109358, 0.1135896323248744, 0.07164199357586247, 0.15710864961147308, 0.13496640989823, 0.06548447827143328, 0.11981059743889741, 0.10603626192148242, 0.25517538881727625, 0.17518228478729725, 0.11274291561650378, 0.09646296062107597, 0.14464820894811833, 0.14366613807422773, 0.1125395315300141, 0.1606633317257677, 0.14693245637629712, 0.08988184268985476, 0.10889540492956128, 0.1840074062347412, 0.1834313842867102, 0.0943049614184669, 0.201196747432862, 0.32083011152488844, 0.12563408352434635, 0.16963374109140464, 0.2102761838052954, 0.06887656303920917, 0.15545340414558137, 0.10156938446951763, 0.12246149804975305, 0.1159084646829537, 0.09469502405928713, 0.1973540543445519, 0.18143280010138238, 0.11818385044378893, 0.18104769076619828, 0.14348752051591873, 0.08935815614781209, 0.10010424415980067, 0.19640254468790122, 0.11845252316977296, 0.0975654578900763, 0.1771983616054058, 0.08730993034051997, 0.1724310695592846, 0.16550512691693647, 0.20800697271312985, 0.10703433943646294, 0.11219766523156847, 0.14854713901877403, 0.1385142252381359, 0.1893319926623787, 0.2063540749784027, 0.12568181167755807, 0.11743971465953759, 0.12964053425405705, 0.121896536222526, 0.1367347128689289, 0.12000495700963906, 0.13925552474600927, 0.17460529931953975, 0.08415900370372192, 0.17301956298095839, 0.05982300599238702, 0.18567517745707715, 0.14028094043689115, 0.09432557531233345, 0.11457089574209281, 0.07263437139668635, 0.15467086327927454, 0.16445672245962278, 0.1538744531571865, 0.12130861277026789, 0.11926322323935372, 0.15391372676406587, 0.15832413653177874, 0.16852167647864136, 0.23857530100005014, 0.0778856421155589, 0.07794511570994343, 0.09155844843813352, 0.18797028144555433, 0.1042825270976339, 0.10222985010061945, 0.09668806461351258, 0.19659710781914846, 0.09761621909482138, 0.1544049454054662, 0.19465174792068346, 0.11394304728933743, 0.11886995791324548, 0.2786897484745298, 0.17980175119425568, 0.22035939060151577, 0.139086284541658, 0.09623064380139112, 0.10437218871499811, 0.19232769762831076, 0.20623320075018065, 0.13317209189491613, 0.15873186822448457, 0.17807048266487463, 0.12578197701701097, 0.1180022337606975, 0.1915941605610507, 0.16995285611067498, 0.15933748787002905, 0.16678662172385625], [0.0339568236044475, 0.006961265479081443, 0.034410448013139625, 0.08306878113320895, 0.06157864071428776, 0.030174455671970333, 0.03384224957387362, 0.09139187487640552, 0.053568141268832345, 0.06907103796090398, 0.03781682612108333, 0.020368554263508747, 0.03104421203689916, 0.060487949954611916, 0.030453784790422236, 0.041784980334341526, 0.027005764988384078, 0.11558833186115537, 0.020789814248148884, 0.08047332361872707, 0.0035651260404847562, 0.04074095582057323, 0.050299868785909245, 0.04077298267345343, 0.07254032644310168, 0.01858634641394019, 0.03654627947668944, 0.1037732662100877, 0.02070028324877577, 0.060373847505875995, 0.05934583981122289, 0.010109582300564008, 0.05182317651009985, 0.02145096519961953, 0.06648138192083154, 0.03096031118184328, 0.052414574061653445, 0.11754004284739494, 0.0322600585807647, 0.019223677393581187, 0.017454633123374412, 0.047446008172950575, 0.020303521770983934, 0.07894342392683029, 0.041115225558834415, 0.01805307386842157, 0.05370108324236103, 0.05246346250974706, 0.02655094805439668, 0.13548386070345128, 0.04935531072052462, 0.032694850250014236, 0.02337414718100003, 0.06335670101855483, 0.011586869235283561, 0.06000679398753813, 0.04222044714593461, 0.030046945371265923, 0.046857219588543685, 0.03350369791899409, 0.01464911813049444, 0.013449593746502484, 0.05079830364723291, 0.10013413362737213, 0.07604837963091475, 0.057048856280744076, 0.03032692927601082, 0.006798059147383485, 0.05315272855971541, 0.0698464202827641, 0.025805975975734845, 0.04908570840156504, 0.02072171138466469, 0.0106803074346057, 0.05896902217396668, 0.015085395791434815, 0.024167909320177774, 0.09298253059387207, 0.01965259464590677, 0.045033402275294065, 0.06977568300706999, 0.009343841961318893, 0.04101464292034507, 0.032157470871295245, 0.03734249282362206, 0.03186450319896851, 0.04519193858972617, 0.010188060812652111, 0.03672224057040044, 0.020110661762633493, 0.05086707995672311, 0.061009851949555535, 0.020817506958597472, 0.034261553681322506, 0.10280616381870848, 0.03950659544872386, 0.08719937662993159, 0.0688464225136808, 0.06757996404277426, 0.024767205019348433, 0.06895528667207275, 0.00739387989908989, 0.0522141348171447, 0.011249858703065132, 0.023158613925001452, 0.053473997927669964, 0.06860054856432335, 0.04325807307447706, 0.04216937381508095, 0.036471311535154066, 0.03155399539640971, 0.03339833839397345, 0.026280538278764913, 0.023646675682227527, 0.03857314160891941, 0.020734293120247976, 0.021079441831846322, 0.024433825497648547, 0.015684348830421056, 0.05025884455868176, 0.07872290004576955, 0.03277181647717953, 0.03246271324210933, 0.026481649272942116, 0.06583849713206291, 0.03623928309285215, 0.04035561917615788, 0.0212093524501792, 0.03775331185066274, 0.011693788542678314, 0.039865018001624515, 0.06567071577800171, 0.025222788697906902, 0.06308465597352811, 0.021842322145987834, 0.04057419226904001, 0.016317586547562053, 0.027602706171040024, 0.01181511314851897, 0.04166353274402874, 0.030935422517359257, 0.009766635435101177, 0.023081671446561813, 0.040890755996640236, 0.05387076449447444, 0.03309738436447723, 0.033645511737891605, 0.03691297676414251, 0.0518590472638607, 0.033919242942439656, 0.03522205731964537, 0.015463807985984852, 0.008495775816429938, 0.014996265127722706, 0.026722152617626956, 0.08833326971424477, 0.051050338694559674, 0.05175399647227355, 0.051558083056339195, 0.02709269380596067, 0.025101018803460256, 0.06331623997539282, 0.05890534844781671, 0.07064694911241531, 0.029524493762957196, 0.02735072879918984, 0.05690414850999202, 0.011510858894325793, 0.056607520141239674, 0.03203261364251375, 0.0392384926921555, 0.006878722542231637, 0.008094336687853294, 0.033283689724547524, 0.05349380436486431, 0.08720787867371525, 0.0074970257036121824, 0.03352411164503012, 0.03131070666547332, 0.0502550108358264, 0.06933504915130989, 0.03175537780459438, 0.03466464758717588, 0.08648838728134121, 0.041323725799364705, 0.054948342564914904, 0.013624647299626043, 0.03648097387381962, 0.053260700444557836, 0.06963287174169507, 0.00906493268640978, 0.035921287656362565, 0.02581495469036911, 0.10892217992139713, 0.06132930623633521, 0.005961073903433446, 0.08005172945559025, 0.01254175290731447, 0.015803777779053365, 0.011017244176140853, 0.05836110908005919, 0.020957872105230178, 0.04085752474410193, 0.015562624737088169, 0.04108433525211044, 0.03176466355632458, 0.053384000435471535, 0.030051786718623977, 0.09418477251061372, 0.04948142323909061, 0.04149670473166874, 0.05426343610244138, 0.03499285497569612, 0.008023033683587397, 0.023374881695157716, 0.07302150276622602, 0.05473550987829055, 0.009342718137694257, 0.06818090858204023, 0.03381415143875139, 0.027279867690854838, 0.05677775100671819, 0.05017020074384553, 0.08819753556911435, 0.06247096176126173, 0.03481085831299424, 0.022725559305399656, 0.03562011310298528, 0.04329403203779033, 0.038589365381215296, 0.009109383515481437, 0.022731067313413535, 0.05992664543113538, 0.013256922031619718, 0.08955662085541657, 0.031878823680537086, 0.027245740772091916, 0.10197284139160599, 0.01153744728903153, 0.08048710466495582, 0.0770326421729156, 0.059177719189652374, 0.036364394772265635, 0.00853537512011826, 0.02540011195066784, 0.017652303945007067, 0.05571799465854253, 0.056116803615753136, 0.012732697750574775, 0.04049996053799987, 0.026054626829656105, 0.05452771531417966, 0.0274407127206879, 0.04921223482649241, 0.006633239174594304, 0.011484141577966511, 0.01773011834094567, 0.042928328804139576, 0.009061067581309803, 0.026495262381753752, 0.02233754244766065, 0.03482283106339829, 0.028715914115309715, 0.027405167663736, 0.03581386199221015, 0.02079389393994851, 0.051418298057147434, 0.023183080201436366, 0.005955879717865693, 0.003592172870412469, 0.06810333167335816, 0.004021428117994219, 0.013676421217886465, 0.04882007211978946, 0.0160835666049804, 0.009422582557557948, 0.07525046316108533, 0.084470831256892, 0.02921335831550615, 0.057540488828505786, 0.021536128129810095, 0.036461187792675834, 0.026242923690006137, 0.032873318530619144, 0.02414876445462661, 0.04960575121055756, 0.03948324705873217, 0.021731188287958503, 0.01809840340034238, 0.0176682783556836, 0.030787257610687187, 0.028349922504276037, 0.008597403398848005, 0.06703392655721732, 0.06362883427313396, 0.04349393184695925, 0.0317564702459744, 0.02151091207217957, 0.06861289790166275, 0.01134115134898041, 0.02383461800803031, 0.027112769960824932, 0.02548115617329521, 0.04106721920626504, 0.009491813485510647, 0.021337744846407856, 0.02673669531941414, 0.048332032414951494, 0.039756136879857094, 0.08550111882920776, 0.04793315899691411, 0.08148021530359983, 0.05120947551248329, 0.04156110109761357, 0.02332975233106741, 0.03356448108596461, 0.0036050548577415092, 0.01409683473009084, 0.02772850656349744, 0.041450452392122576, 0.06396572012454271, 0.020340800484908477, 0.04561851659257497, 0.03989777088697467, 0.024331120740888373, 0.04406001325696707, 0.04207548153187547, 0.016194602075432028, 0.013107047216700656, 0.06510742993227073, 0.026424294404153312, 0.0343408778176776, 0.07744121524904456, 0.028846525321049348, 0.06460090354084969, 0.030482018632548194, 0.03014224561463509, 0.0693411220397268, 0.02545384344245706, 0.051610143655644994, 0.01930336793884635, 0.049733346328139305, 0.06614503211208753, 0.048810372461697886, 0.013033782398062093, 0.08941539736198527, 0.040734248501913886, 0.060243263441537104, 0.027309360215440392, 0.029182505328208208, 0.028136406193620393, 0.03964237030595541, 0.07807758610163416, 0.15936188798929962, 0.08715121421430792, 0.08914049568453006, 0.1843655098761831, 0.09708638502550976, 0.15969114032174858, 0.2604347680296217, 0.1444889839206423, 0.09906814154237509, 0.12018999350922448, 0.14935363217123918, 0.17821023373731545, 0.17624729978186743, 0.13311224510627134, 0.1651545957263027, 0.06030494227473225, 0.14256988332739898, 0.1440691471632038, 0.14131341289196694, 0.09841626616460936, 0.20117921408798012, 0.09465539761419807, 0.09079570722367082, 0.12748518133802073, 0.059653060111616335, 0.1423866788723639, 0.22827332094311714, 0.11902171905551638, 0.18629815402839864, 0.08838916742908103, 0.22421063323106083, 0.1846946400723287, 0.10050033897693668, 0.13742441657398427, 0.1079136665378298, 0.17803768228207315, 0.10157902645213263, 0.10002379026263952, 0.17443476989865303, 0.08606164303741284, 0.14094087002532824, 0.1226252828325544, 0.1451000047049352, 0.11345189650143896, 0.16283334099820682, 0.11565272483442511, 0.1427852367716176, 0.22602658293076924, 0.1798832839620965, 0.17218172151063169, 0.11886937437312943, 0.08010179855461631, 0.1681574931634324, 0.07722450473478862, 0.0873304967369352, 0.09005961886474065, 0.10791152915252106, 0.15378283735896858, 0.216900178364345, 0.15352400339075498, 0.14405348657497338, 0.16124691255390644, 0.15908288796033176, 0.16112575334097656, 0.15769569096820696, 0.14705890816237244, 0.09458707592317037, 0.12683951455567563, 0.10635674079614026, 0.15497954242995807, 0.1252600343099662, 0.08480378839054278, 0.08729849702545575, 0.1442953571677208, 0.08102397514241082, 0.11043852248362132, 0.16592029535344668, 0.10825858624385935, 0.08289479118372713, 0.11827948316931725, 0.15179139136203698, 0.12924428337386676, 0.10741066174315554, 0.0799416032220636, 0.1341556826872485, 0.12271847283201558, 0.08541168112839971, 0.08351660746016673, 0.10540013534149953, 0.16014480883521692, 0.16799516044557095, 0.11261163266109568, 0.06789787805506162, 0.11499941774777003, 0.09943433332123927, 0.19301993905433587, 0.16977731910135063, 0.10657438090337173, 0.1494447865656444, 0.19884447008371353, 0.13492606420602116, 0.1412478256970644, 0.1388535334595612, 0.09063533547201327, 0.06712193254913602, 0.17280197037117823, 0.17653045244514942, 0.1421137856585639, 0.09733905111040388, 0.10594717705888407, 0.1144249157181808, 0.0994814575782844, 0.11477263777383737, 0.12254068308642932, 0.09461254134242024, 0.07401500016983066, 0.15549376340849058, 0.12722394535584108, 0.15304913744330406, 0.18153219191091402, 0.08752999960311822, 0.17105931602418423, 0.21112480041171822, 0.22105479400072778, 0.11739202721842698, 0.12572514292384895, 0.06224771016942603, 0.07447362198893513, 0.06726002799613134, 0.1049459104293159, 0.21697773491697653, 0.13943582507116453, 0.1628687469554799, 0.13436092595968926, 0.22215229725199087, 0.15462552356932843, 0.1209588958216565, 0.1268569529056549, 0.16444761651967252, 0.10773055707769734, 0.09774772596678563, 0.11382677352854184, 0.14350642450153828, 0.12296311184763908, 0.08978092417653118, 0.14600432903638907, 0.11278895421751908, 0.16573044125522884, 0.13079451876027243, 0.1259186475404671, 0.10672038128333432, 0.09171358868479729, 0.12457299046218395, 0.12119919221316065, 0.1929601872605937, 0.1309349076556308, 0.14123623631894588, 0.23301204666495323, 0.14762408712080546, 0.09370941801794938, 0.23045869224837848, 0.15035135006265982, 0.10303362232765981, 0.17733326793781348, 0.05843764104481254, 0.19357568637600966, 0.12118916346558503, 0.17235881915049894, 0.1447545082441398, 0.17030524648725986, 0.10486353627805199, 0.09900583845696279, 0.10925758656646524, 0.13890994686101163, 0.13579103350639343], [0.053168602886476686, 0.01402081930012043, 0.014401429099962115, 0.025266513494508605, 0.019484019405873756, 0.02314948253998799, 0.04702621212761317, 0.07762526787285294, 0.05278265895321965, 0.02380968184609498, 0.0349174086669726, 0.026473593365933214, 0.01634549130020397, 0.05310106829607061, 0.006036378567971821, 0.016134645024846708, 0.027383500344253013, 0.05982866497444255, 0.03201904972749097, 0.05649597916219916, 0.030762087354170423, 0.04488901002332568, 0.0339946756804628, 0.012901230582169123, 0.04034583470118897, 0.018386767212567583, 0.04882589055757437, 0.02988034806081227, 0.01331981798700456, 0.02422820563827242, 0.044813081954738924, 0.015698380934606706, 0.03380657559526818, 0.011946504669530051, 0.03510619407253606, 0.05659985948087914, 0.05116071259336812, 0.034702883035476716, 0.014560789834441883, 0.054559528428528986, 0.04016917132373367, 0.018442573325176324, 0.005672820353148771, 0.013159955136610993, 0.027140159026852677, 0.012251445092260838, 0.014470076487798775, 0.03302177520734923, 0.025628438984443034, 0.076609127755676, 0.020495187557701553, 0.026789649888607006, 0.01818335259200207, 0.03405676502734423, 0.015225323282980492, 0.0369748320164425, 0.042946323552834134, 0.030839609980051006, 0.02224149920844606, 0.08913728621389184, 0.016354057804814408, 0.05606551315369351, 0.013692659409051495, 0.06479982965226684, 0.008184680232911237, 0.07199692845876728, 0.006508549035061151, 0.021778953760596256, 0.03642460457714541, 0.012992882851644285, 0.025688762443938425, 0.08660839977008955, 0.02770502755551466, 0.018712925425331508, 0.049760677718690464, 0.05517561108406101, 0.0439107898356659, 0.021156250299619775, 0.03274184558540583, 0.04184641150225486, 0.016053829807788134, 0.008044259955308266, 0.04778561155710902, 0.05007406250972833, 0.04003024806401559, 0.039390857730593, 0.01881708394336913, 0.0661426300981215, 0.04382061931703772, 0.03825602148260389, 0.008914698247930833, 0.06657998662974153, 0.06353728632841792, 0.03975770429575017, 0.015239358779841235, 0.029777020748172487, 0.01774578571452626, 0.03332736702369792, 0.07631222797291619, 0.02198763720558158, 0.013035471102089753, 0.01906582639951791, 0.014916516906980957, 0.04772391576053841, 0.06683730746486358, 0.10328242076294762, 0.044860206211784055, 0.0480706234063421, 0.018840739370456765, 0.04199597419106534, 0.013622014583753688, 0.03923024509900382, 0.03757379523345402, 0.032853583339601755, 0.055951373385531564, 0.05014175994853888, 0.0054064864525571465, 0.04471382585221103, 0.02686087062050189, 0.030416906412158693, 0.04448275075161031, 0.01539148124200957, 0.023514191719836423, 0.01626512221992016, 0.010104554356075823, 0.04300519325105207, 0.044259075075387955, 0.04868062638810702, 0.0783033821997898, 0.04627964040264487, 0.034734495981995545, 0.026014315064198205, 0.03804487495550087, 0.02669706887432507, 0.02052467838594956, 0.032530895833458216, 0.013962668000853487, 0.023473632289096713, 0.04828426694231374, 0.0536232824171228, 0.03634435763316495, 0.024289158438997607, 0.028193070653027723, 0.014120094062361335, 0.05938237892197711, 0.08456607721745968, 0.016277907516009042, 0.0779129056526082, 0.05217203850458775, 0.01572214492729732, 0.01777043010640357, 0.016517806964527284, 0.033105106092989445, 0.0452608031087688, 0.007122985819088561, 0.01893596667131143, 0.03596389965553369, 0.026937358480479037, 0.06112877878227404, 0.012141876105618263, 0.053720832004078796, 0.015661141236445734, 0.024799172500414506, 0.021043252166626707, 0.039918727441025634, 0.040589584835938046, 0.038798740931919644, 0.04715770882155214, 0.02060111196312521, 0.020758174160229306, 0.027639438664274554, 0.03565892530605197, 0.0018575561947987548, 0.09906471494053092, 0.058267729090792794, 0.0067855448412176755, 0.01880099418173943, 0.04132576479709574, 0.054764415470084975, 0.06557993457785674, 0.029278182158512727, 0.05224058411217161, 0.03241772637037294, 0.026072053305272545, 0.04711243017975773, 0.022990462769355093, 0.0548928723271404, 0.024069632004414285, 0.023627498586262976, 0.02205269005415695, 0.017498286673799157, 0.0381364296855671, 0.03668509077812944, 0.0303120286470013, 0.012423685269563325, 0.013803686397815389, 0.036228599558983526, 0.008843856647477617, 0.031234649675233022, 0.025302058551460505, 0.07348850449281079, 0.040880954558295865, 0.03536474984139204, 0.06369411612727813, 0.04649967234581709, 0.03194113355129957, 0.0031060029536352624, 0.03807484245459948, 0.029260597923504453, 0.05597777518310717, 0.14572773102138722, 0.008789199803556715, 0.03026687553418534, 0.05603564064949751, 0.04801364342815109, 0.012309936507205878, 0.02958201996183821, 0.03219143833432879, 0.02653086681051978, 0.01707224640995264, 0.024385625762598853, 0.04616128353934203, 0.02901821842949305, 0.027152104635855982, 0.03457871791241424, 0.050189868081361055, 0.02389088722078928, 0.014036620684367205, 0.057378122183893404, 0.03849403799644538, 0.07396237299378429, 0.05450867562155638, 0.0073219314383875045, 0.09213236014225654, 0.023615882066743712, 0.019100927016032592, 0.016601648447769027, 0.027356012890647565, 0.043559688675616465, 0.06252827761428696, 0.03733255567827395, 0.033315923530608416, 0.033002118047858985, 0.05913206735359771, 0.02950703166425228, 0.04152478590341551, 0.017645221735749925, 0.08442754072270223, 0.0021214535185468514, 0.0786330145118492, 0.022444250561030846, 0.05424454229484711, 0.01343145311277892, 0.019318760505744388, 0.04565275546961597, 0.01595789174150143, 0.01486407802440226, 0.01214005847993706, 0.04262280823396785, 0.024771361046337655, 0.04566722522888865, 0.027311458584985564, 0.02274932838710291, 0.036428112603191815, 0.04461285984143615, 0.020841613611472503, 0.031181316822767258, 0.03748727184055107, 0.04028953665069171, 0.035276550466993024, 0.030247601746980633, 0.04330365366435476, 0.015459867393864053, 0.02379304077476263, 0.038153199678553004, 0.05107142756293927, 0.013865751147802387, 0.015295885835907288, 0.02547766002161162, 0.02239758601146085, 0.016284538499478782, 0.02725289422752602, 0.02650062959375126, 0.04698457382619381, 0.09781617657946688, 0.04061792724366699, 0.02102512849627861, 0.03290951498118894, 0.05897386691399983, 0.0413910975413663, 0.05284409012113299, 0.06287089030125312, 0.009601486796912338, 0.004555254093637424, 0.04804621650172131, 0.0072673721338755316, 0.0058688427587704995, 0.020905933642227734, 0.024578322922544818, 0.013675315205806067, 0.049892523858164034, 0.026894430962524245, 0.026483019913679788, 0.044848342026982985, 0.01414716336876154, 0.012958823786383229, 0.018245589520250047, 0.05517256785450237, 0.044214831199496984, 0.031981655662613254, 0.024471205991825888, 0.026900790531986525, 0.03455078262569649, 0.027972421242988536, 0.02964158176577517, 0.033315401058644056, 0.04205562420455473, 0.02516526080268834, 0.049072687314557176, 0.013835211982950568, 0.03935212016637836, 0.046009559716497145, 0.05724437614636762, 0.1255258164767708, 0.08018032541232449, 0.0024794191205208854, 0.038764464735452614, 0.0160367273326431, 0.03385808318853378, 0.03809736981721861, 0.015804152669651166, 0.011572938063181937, 0.053492708530809195, 0.0070880137001430345, 0.024657117801585367, 0.025693517278081605, 0.001941117358260921, 0.0021715554841128843, 0.03141128930396267, 0.02264812828174659, 0.019097804058609263, 0.030147663716759, 0.009210444521158934, 0.04284157470933028, 0.04143092076161078, 0.03813024823154722, 0.006440373653146837, 0.007739996371258582, 0.059153549772288115, 0.08405052631029061, 0.07183939976883785, 0.0642312987308417, 0.12743427764092172, 0.14909912725644453, 0.11993307300976344, 0.1650911391313587, 0.10239573155662843, 0.15431491737919195, 0.09475611256701605, 0.2615184970200062, 0.1379670410283974, 0.10951521952769586, 0.0937544930992382, 0.13408795132168702, 0.10609436487512929, 0.12494971310453755, 0.09191181590514523, 0.09483328235468694, 0.13444217374282225, 0.15150513100836957, 0.1314866380499942, 0.19838354124554566, 0.11270086680139814, 0.1371743899903127, 0.11986254607992512, 0.10847603636128561, 0.14409407653978892, 0.1337895587618862, 0.1542601188910859, 0.14219017513096333, 0.205153760101114, 0.0906453642195889, 0.19250294965292725, 0.07426128124019929, 0.12106193814958845, 0.11110101014907871, 0.1570725922605821, 0.10447749734989234, 0.13588243217340537, 0.18537552282214165, 0.12514177922691616, 0.1494170751954828, 0.1437120884656906, 0.062018670673881254, 0.09113788564822503, 0.1889270701046501, 0.09449747537395783, 0.11423033901623317, 0.11512319610587188, 0.14115964328604086, 0.11843281851283141, 0.16058170396302426, 0.12358779832720757, 0.1239897081894534, 0.10230030239160572, 0.10953102939363037, 0.20559796983642237, 0.1293504876749856, 0.09910696053079196, 0.20376953509237083, 0.11476133338042668, 0.2709397114813328, 0.21871350891888142, 0.07796399255416223, 0.06801459964896951, 0.146202773387943, 0.13682584012193338, 0.13788937591016293, 0.15710309919502052, 0.15463221392461232, 0.15447406098246574, 0.11427077970334462, 0.09069135532315288, 0.20042195543646812, 0.13141548686793872, 0.12052647902497224, 0.14583135688943522, 0.2210362157119172, 0.1173806685422148, 0.11736361017184598, 0.1571580469608307, 0.07761089650115796, 0.042216392899198193, 0.10290245472320489, 0.11373724761818137, 0.18063640354999475, 0.13853061864418642, 0.11819998600653239, 0.06969222998512642, 0.10707267666501658, 0.08584848126130444, 0.10625985278082745, 0.20030319823750428, 0.19267761813742773, 0.09526386710682086, 0.18553649846996578, 0.09143162345779793, 0.14861097559332848, 0.1516318270670516, 0.13160857079284533, 0.2060650054897581, 0.18076337102268422, 0.09833455019231353, 0.09904462351862874, 0.08604331580655915, 0.14378969930112362, 0.16257795398788794, 0.1338051107845136, 0.08725441939064435, 0.08820341846772603, 0.19371710664459638, 0.1057613127465759, 0.05573100217485002, 0.1202957635479314, 0.15616570306675776, 0.13867602869868279, 0.20021791995636054, 0.1631423458456993, 0.0686053458069052, 0.15481383060770376, 0.14074948243796825, 0.11670908172215734, 0.09169294086417981, 0.09680716107998576, 0.09546312570039715, 0.09670698895518269, 0.07066362750317369, 0.0870603583753109, 0.09498037517602954, 0.2117483876645565, 0.2833080478012562, 0.13684551763747418, 0.11359915895653622, 0.11179479863494635, 0.15641923089112553, 0.13164048908012255, 0.08924081030168704, 0.1343713482575757, 0.09111855418554374, 0.13788614608347416, 0.09749005907880408, 0.08930962732327835, 0.08716793331716742, 0.12807147630623408, 0.1249989883175918, 0.1727038270660809, 0.1374006135655301, 0.1896184565765517, 0.09310870418058974, 0.22518663800188474, 0.17247236520051956, 0.10263587867042848, 0.04681366103302155, 0.05981837838355984, 0.07429982202925853, 0.1197445352694818, 0.051584104874304364, 0.054253115584807735, 0.18339641259184905, 0.10056416198079075, 0.14939279721251555, 0.09914169473839657, 0.13457805716565677, 0.09023735432752542, 0.15727703486170086, 0.10014289351446287, 0.10828524588474206, 0.18758580993328774, 0.12125137155609471, 0.09756501005696398, 0.0876758439200265, 0.09838247512068067, 0.13067943922110967, 0.08067028197859015, 0.13396675139665604, 0.16079659600343021, 0.2336862933422838, 0.13550063408911228], [0.0174589808365064, 0.029372851364314556, 0.04348265798762441, 0.05167097432006683, 0.016620655909978917, 0.017146435732554113, 0.04316109006426164, 0.04916129380996738, 0.020278865504743795, 0.06375719274261168, 0.015126486175826617, 0.042584426900638, 0.07924486989421503, 0.05314769722255213, 0.042897296005061696, 0.020598007665414895, 0.0354421808650451, 0.05192132999322244, 0.0368527907079884, 0.016194327268749475, 0.03953144000843167, 0.03632593880008374, 0.05120850181473153, 0.026525465671771338, 0.018533290064494525, 0.03320192964747548, 0.04463557719386049, 0.08344127650239638, 0.05473609341840659, 0.05454643609534417, 0.020366194657981396, 0.018427340214007666, 0.05779570620507002, 0.02973307542768972, 0.0385536201564329, 0.03987363878903644, 0.060160862148872445, 0.04327789647504687, 0.003391859366924369, 0.05102494791416185, 0.028297651559114456, 0.07377097862107412, 0.03422645306480782, 0.020698524146739925, 0.03193381555112345, 0.09797852965337889, 0.022820499925208942, 0.02375807925792677, 0.018376500977735435, 0.026626044917585592, 0.039183555104370625, 0.008728787286340125, 0.031987962645611594, 0.04818769783845969, 0.019795600990099565, 0.045029453201485534, 0.014949088284213628, 0.04620274202898145, 0.07918312999286822, 0.04489524576014706, 0.012340155064261385, 0.03292915517730372, 0.0320028666672962, 0.04638400248118809, 0.02319883748090693, 0.025838598243093917, 0.019014074533645595, 0.033993474673479795, 0.05762429468865905, 0.01117253624501505, 0.031534809818757434, 0.04558264923148921, 0.04917104096551027, 0.031158891240400926, 0.04940000582220299, 0.06581489089876413, 0.027880272794780985, 0.01440272679818528, 0.02860929590782949, 0.05600529317078846, 0.07577777986547776, 0.08782059579555478, 0.016944210244608775, 0.029315732286444733, 0.02081837209074625, 0.0544787454418838, 0.04969930083357862, 0.05025036287094865, 0.042546435724943876, 0.02053326355027301, 0.02619438129477203, 0.04687077671821628, 0.02484806943019586, 0.07012673666966812, 0.02483466497090246, 0.024500515311956406, 0.021895476883011203, 0.04446466440068824, 0.066392398838486, 0.06813322792627982, 0.05383047987041729, 0.021366647045527185, 0.03466555343142577, 0.07311216183006763, 0.02024116101009505, 0.07139885412263018, 0.03301350386547191, 0.10138225808207478, 0.06535312067717314, 0.013236507457414908, 0.015846011494951587, 0.018316588031926324, 0.020834616219092692, 0.04335590086079069, 0.013229646620207598, 0.030473241782081977, 0.03499499236100486, 0.020132374883230244, 0.06731117596583706, 0.03147754824853369, 0.038314850468720706, 0.040848103285368, 0.029714554814355712, 0.006132500262797943, 0.010007660403581602, 0.03879282071388193, 0.09437257743307523, 0.04213198653555342, 0.02871433991406645, 0.02321773807385138, 0.03968300098287208, 0.021575803768688014, 0.028480306400784423, 0.036860844918659756, 0.08706176294279949, 0.06592171266674995, 0.03299075258629663, 0.009607245014714343, 0.037980638045285425, 0.0423737248139722, 0.009827210800722241, 0.029085569815444093, 0.03400096570008567, 0.015270052311409796, 0.0571689298376441, 0.020136610638084154, 0.04048334660806826, 0.042106259880321364, 0.017108376703358123, 0.027513655235192606, 0.03060308624325054, 0.078689441484, 0.007929730877679373, 0.01986129505426756, 0.03990047484902399, 0.035040925789092264, 0.052325638476759195, 0.01031576279949929, 0.021110425437135354, 0.07151344511657953, 0.007486004598571786, 0.04426666448957153, 0.0149924772059811, 0.030511039575295787, 0.044765228272548745, 0.034896265515791516, 0.03504780613418136, 0.07061746676585504, 0.032047938355909925, 0.03323722364647048, 0.010445084788703492, 0.058211980653660636, 0.06136560107448271, 0.02369926723518542, 0.017680425828854953, 0.018528384256309698, 0.03145704631294523, 0.03085879555770329, 0.0635556678420731, 0.07514035049825907, 0.02965682166229401, 0.008037198102101684, 0.030852678564510176, 0.0712246945393937, 0.00792786236187177, 0.05537634209862777, 0.020351170196330974, 0.04093029083950179, 0.03561327007732221, 0.05164046060027821, 0.019659054299284304, 0.012191545717152101, 0.05935305263847113, 0.013867069202076112, 0.045051682008696456, 0.006823367655410298, 0.046042970780815394, 0.041604408595178805, 0.028450304974934885, 0.023110653373545835, 0.04108422668650746, 0.0394543618229883, 0.06257134423192058, 0.010196267693702663, 0.04231755229245339, 0.030376553934599673, 0.027299658861011267, 0.07361707330814429, 0.06009951579783644, 0.04648949092786227, 0.020460409245320728, 0.009909274522215128, 0.052172197960317135, 0.03051142973293151, 0.03800835280812212, 0.016543282561802437, 0.05350524107260363, 0.04608934525666492, 0.01695457486701863, 0.006954063678027264, 0.08960628283343144, 0.044387111240731816, 0.025696440067674433, 0.018227593075217943, 0.08850478301090853, 0.014492471536089267, 0.05135263961606792, 0.009613878542690404, 0.04354275583422609, 0.04554508553285684, 0.05308809131383896, 0.06958546928529229, 0.02127988277269261, 0.047580174902187924, 0.027538939146324992, 0.05774077879531043, 0.011290573348690356, 0.055959302067224465, 0.02367848201122667, 0.00784677148996187, 0.016427259858963743, 0.02622351249946015, 0.034714967744158845, 0.017232950643769333, 0.024054707626679113, 0.015519624276618873, 0.06903600519789116, 0.022913767956197262, 0.07099643535912037, 0.037874209827610424, 0.04887533201170819, 0.05465924593486956, 0.02703255015824522, 0.026816896462280835, 0.044327691929148774, 0.06406987524990525, 0.01105627351041351, 0.053938587462263446, 0.03755149518006614, 0.019884344888851047, 0.031983026303350925, 0.02885035565122962, 0.026379283783691268, 0.025851349612431865, 0.059147151187062263, 0.025974732723885348, 0.06843252972300563, 0.021583623884777938, 0.03943361561479313, 0.03439313179946371, 0.02904694081683244, 0.018612595541136603, 0.03650403727910348, 0.035308841948530505, 0.05423214206738131, 0.06267651715981108, 0.022351130111409084, 0.03144226103488888, 0.06920041423290968, 0.0344575485214591, 0.05819259490817785, 0.04171096573450735, 0.05981187801808119, 0.07279768120497465, 0.04030391141506178, 0.02796755445056728, 0.016254906875214407, 0.02159876878639417, 0.03425577934831381, 0.051433826331049204, 0.03031422370778663, 0.06311759206333331, 0.051347587922854085, 0.009144365388367857, 0.04702941481290119, 0.03916383009137852, 0.06299478401030813, 0.03080977140260594, 0.045084960758686066, 0.0494251014398677, 0.028151255932503512, 0.06680623056100947, 0.04044750638838325, 0.03924357152677008, 0.02475517289713025, 0.05290898521031652, 0.01516158170332866, 0.028251538319247108, 0.057465307148439546, 0.07975020206400327, 0.059301416123551984, 0.03441798314452171, 0.027427896890523176, 0.014729207315083061, 0.040524815275732956, 0.0714379580957549, 0.0064539952436462045, 0.07660131103226117, 0.019632791601387516, 0.021115947015849606, 0.018219292895602326, 0.02369413072509425, 0.02768231529210295, 0.09308821920837675, 0.08217939814286572, 0.027815074061176608, 0.05034635861271194, 0.06463316788098641, 0.04586169336523328, 0.025926183543301055, 0.0028761229228361374, 0.02441317428435598, 0.038383375720254014, 0.0702484454959631, 0.030180769440318857, 0.0545110776355224, 0.04688308534345456, 0.043792772239872386, 0.010508494734364961, 0.014609671497185315, 0.009312511455001575, 0.010052883914405746, 0.0029987144807819277, 0.03272966927449618, 0.08682398391621453, 0.022355613531544805, 0.05157156893983483, 0.06960482110402413, 0.030063993563609462, 0.02258696683150317, 0.05992541049740144, 0.020969658258504102, 0.10981744581035205, 0.1523643463317837, 0.16228144775543893, 0.12158875273806707, 0.08487891578780753, 0.09751765509801251, 0.11944821902683803, 0.12944956735840865, 0.07622041539954287, 0.13198502202119144, 0.044366639839219194, 0.1613322858299528, 0.1474255206329482, 0.1432352140545845, 0.1021638557847057, 0.11736894345709256, 0.11846413968929223, 0.1526219453662634, 0.13625675280179295, 0.09036523103713989, 0.15643943766398088, 0.0880133133115513, 0.0697450064388769, 0.11726689179028783, 0.1612912073199238, 0.14208060529615196, 0.29121805621044977, 0.12769634143582412, 0.18255390280059405, 0.21734334315572465, 0.16650938588593686, 0.08626947152827467, 0.16957511566579342, 0.1515021183128868, 0.1698505873126643, 0.12246992545468466, 0.16367943345436028, 0.1262361883584942, 0.1965931180332388, 0.15849979567740644, 0.1716405219797577, 0.13878080807626247, 0.1352517610149724, 0.0774351152192269, 0.12224698598895754, 0.15317354005362305, 0.12914909848145076, 0.13882329793913023, 0.21352168465299265, 0.15483527231429303, 0.10874033932174955, 0.1508342091526304, 0.08151765008057867, 0.15497145429253578, 0.14087650419345923, 0.13409009549234593, 0.10115885042718478, 0.15925987703459604, 0.13272851998252527, 0.1474163739808968, 0.07320642391485827, 0.1656654104590416, 0.07828567243580307, 0.1718075094478471, 0.14772879864488328, 0.18479249839271816, 0.21502302480595453, 0.21560276512588772, 0.07885978770043169, 0.15039679833820888, 0.1415715411837612, 0.11949909558253628, 0.14587289680327686, 0.13071704363184317, 0.16871576463537558, 0.17634563307676995, 0.054119936124022515, 0.06465098621057612, 0.10276638809591532, 0.25615793466567993, 0.1499918079269784, 0.24287452601960727, 0.08719597038413797, 0.12651190427797182, 0.10575482595179762, 0.11268078216484614, 0.16689395239310606, 0.11291330933038678, 0.1386190996106182, 0.11536459172410624, 0.14179562058831963, 0.10259924456477165, 0.1562967553202595, 0.2815117213342871, 0.17975806710975512, 0.08659747535628931, 0.10827679812375988, 0.15182503312826157, 0.11619663850537368, 0.16006487741002015, 0.11739259718784265, 0.08525244931557349, 0.1429018090878214, 0.16228992944317205, 0.11651742272078991, 0.2285570300051144, 0.12638310476073197, 0.15721268260053226, 0.21696657980126993, 0.15943421982228756, 0.0847814374470285, 0.10215478377150637, 0.11991247268659727, 0.19942745380103588, 0.1998865913067545, 0.09015618796859469, 0.11418839198138032, 0.06733298408133642, 0.10049835765468222, 0.13956906220742635, 0.13522357467029775, 0.1551855592323201, 0.14849345332809857, 0.15365695554230893, 0.10615898176495518, 0.15870642316128525, 0.13690222959433282, 0.10814625477152211, 0.08568121559385743, 0.13988904575152056, 0.0914903778050627, 0.0964357377961278, 0.12596511361854418, 0.18356445857456752, 0.15667080453463963, 0.11745048979563372, 0.10281734607581582, 0.07664318342826196, 0.09620496125093528, 0.11374890484980174, 0.11527355946600437, 0.13743582953299793, 0.1280476190149784, 0.11355675730322089, 0.07837317631180797, 0.09299844902540956, 0.11326080746948719, 0.1489776966295072, 0.2678942291864327, 0.08228186371603183, 0.18729763611086778, 0.25256036913820673, 0.08264689520001411, 0.14047527286623204, 0.1697779840656689, 0.10262157515223537, 0.2075600488377469, 0.07516789223466601, 0.11936904756086213, 0.19952250298644814, 0.1432661281100341, 0.14215547485010965, 0.09630883817694016, 0.10933086834847927, 0.11240870997841869, 0.1575030277350119, 0.12391278945973941, 0.1167265200721366, 0.14820384101143905, 0.1421996746212244, 0.09535914020878927, 0.23340025011982235, 0.11734461119132382, 0.09998924604484014, 0.16454700832920416, 0.11032394506037235], [0.05675644161445754, 0.010064125543327203, 0.06363433040678501, 0.05631408767242517, 0.03063869576102921, 0.04131538660398551, 0.04169577672811491, 0.01679252034851483, 0.036098470113107135, 0.0291731211889003, 0.05270127546308296, 0.06548335190330233, 0.023240387572773864, 0.022730217448302677, 0.03011275309004954, 0.011689238117209502, 0.05176303455872195, 0.02631718765145966, 0.02027636849587517, 0.024453606489779692, 0.037133632959531884, 0.04434308110337172, 0.055503815079906156, 0.023326868557238152, 0.020172374522579566, 0.06044725820954357, 0.013191460365695613, 0.06270277646503278, 0.03803811674671514, 0.04363093824524965, 0.025577065401843617, 0.06812247993158442, 0.021246607415378094, 0.058356461115181446, 0.01513568202166685, 0.019420423711250936, 0.0329017050431243, 0.04561944279287543, 0.021962231158145835, 0.06984971796295472, 0.023097920663920895, 0.030628497379698923, 0.053121308995676894, 0.024000402772799134, 0.023338062688708305, 0.04248571701880012, 0.03150939868230905, 0.022761716740205884, 0.0821601820311376, 0.04028544508452926, 0.04478590662724205, 0.012029659984234189, 0.04801036949668612, 0.025997643458790014, 0.05907766241580248, 0.05191976597000446, 0.010295484780466982, 0.016476141521707177, 0.020920457684301903, 0.043686323666146824, 0.07680494617670774, 0.015103244655100363, 0.018599772925621698, 0.0668868473065751, 0.005035517787161682, 0.058626368774899414, 0.02215461279930813, 0.0595012650425945, 0.018667371976854544, 0.03036864221628223, 0.0382819211642657, 0.007166154216974974, 0.016500541640977775, 0.01771370797151966, 0.023429100035822818, 0.04590743001816528, 0.04321949157331671, 0.033898530660995414, 0.014190819463692605, 0.05092734743707946, 0.019069308980501125, 0.02367381369029837, 0.07146085865263428, 0.01787706697359681, 0.04877335837643061, 0.03582121052646211, 0.0627728555617588, 0.04589249546240483, 0.017220665767256702, 0.05679050407239369, 0.06133993888007743, 0.041401468949126344, 0.05892685800790787, 0.06744563446513244, 0.03973632365731256, 0.027975076011248996, 0.030064407469970838, 0.021967211605182717, 0.03714331904692309, 0.08110648500067846, 0.07953045171286378, 0.009043453660394465, 0.09045073323483978, 0.03704920284716146, 0.03807055411328163, 0.017115966117541705, 0.037282791920006275, 0.019284582696855068, 0.0464715538546443, 0.04764745504196201, 0.06483501169298377, 0.02147983686466302, 0.08620032202452421, 0.025378274997430186, 0.047393496347857375, 0.0911152632907033, 0.06200964615813323, 0.0547786613128015, 0.037957815519933186, 0.03486614195363862, 0.04052907308297498, 0.014175864551881594, 0.06115494987794331, 0.026187365242679204, 0.0420402757424329, 0.023154654673167636, 0.04453885541962726, 0.08274119799690587, 0.014378190971910954, 0.022303166167278374, 0.04017275398863213, 0.015614771849608846, 0.005253063747659326, 0.03350666990237577, 0.008656189128357385, 0.02326791064946779, 0.025327384871031557, 0.010733754789855863, 0.009197876356276018, 0.08960094276283469, 0.015452842860083495, 0.04396982238228832, 0.02118266057888312, 0.04302151880360075, 0.030206462168799977, 0.022903863041262542, 0.04023057195757117, 0.06288030158196177, 0.042234241762863736, 0.06292460991867951, 0.045755889399775436, 0.037782268332583566, 0.04708083080393927, 0.023035157871033465, 0.02941670168989471, 0.01982009271159768, 0.020287727172087346, 0.014193693059496582, 0.018800705804356506, 0.04464823526463338, 0.02166126525428678, 0.037297567020037344, 0.04932767738189016, 0.03128724631720355, 0.060441592442137856, 0.04460940609819122, 0.018124811983268176, 0.03948651420484696, 0.04321762899469052, 0.02287790229144905, 0.07436813014958586, 0.11870496533811092, 0.02298256801441312, 0.04393705931891288, 0.0510268308488386, 0.009835572896658309, 0.038799643383494446, 0.06235078642410891, 0.02657440161731626, 0.0633461701550654, 0.027664761591170515, 0.030325802907879864, 0.04119822396231549, 0.04728746507316828, 0.04527514733906303, 0.018293704438422407, 0.03785988934604185, 0.042182554357818196, 0.02095228945836425, 0.018117999491680945, 0.040602992687906535, 0.00906085129827261, 0.059840233996510506, 0.0352417687619371, 0.04728857108524867, 0.023900537685092007, 0.025997180358639786, 0.005329525314404496, 0.045256358704396656, 0.05725096472139869, 0.053904966052089415, 0.06192370969802141, 0.07356629853269883, 0.012253758048505654, 0.015357410302385688, 0.03753634010042463, 0.05272284609132579, 0.03742227157843964, 0.0078075385951836196, 0.020246004053790654, 0.018549345899373293, 0.04120522305103285, 0.07571587711572647, 0.039365188750837526, 0.012660843436606228, 0.031779021357319186, 0.01987154602206179, 0.02537472456294511, 0.03872401726299098, 0.034585041858788045, 0.028641258299882923, 0.013410647532769611, 0.02841101779735514, 0.029134448085512434, 0.062017327174544334, 0.02773539369393672, 0.017937885763655816, 0.02553862808937473, 0.007690428539977542, 0.018049574324062893, 0.03931534017569252, 0.07131786418280431, 0.02918587764725089, 0.04030452209657856, 0.03993546350726059, 0.03680038744849818, 0.01599458691530994, 0.013426208037084766, 0.04391197048659835, 0.06630779230701071, 0.028207121416926384, 0.032261636174683056, 0.0394652082052614, 0.017000177509284446, 0.02966292169211166, 0.005673616359542523, 0.01995184724884374, 0.029944191420716897, 0.04444012178906372, 0.028956939931958914, 0.04611098034573453, 0.05224593096811857, 0.0670693257291402, 0.03938847607267754, 0.033326271189642806, 0.02643327651146267, 0.021305565323148454, 0.021410102124458978, 0.06629377377352544, 0.005222473268596721, 0.018397711982418383, 0.038725201306598525, 0.007073137243943555, 0.02029993401707283, 0.029725441908729926, 0.05358340830675193, 0.04846507277605789, 0.045581682319087644, 0.020192822175366536, 0.04018975129084928, 0.026758325319471102, 0.0015998716012940609, 0.05153038525687797, 0.10302260291895696, 0.07095127206827913, 0.05262960859441331, 0.0207929185458592, 0.057914436262633116, 0.04126407578587532, 0.009886937149401222, 0.03500289390129702, 0.005655418050342372, 0.0610042472503015, 0.016018244038735117, 0.05912078331623759, 0.029159723514957086, 0.03148623688944748, 0.025663719412737658, 0.028659843374043703, 0.068937685473689, 0.028621702920645475, 0.04423232383227774, 0.04007230705714651, 0.03426412193636809, 0.03092325638447489, 0.03877865968804274, 0.05165537819266319, 0.0058384214893781716, 0.10405464111162083, 0.01348862053626882, 0.008101311179676225, 0.004297027838349874, 0.03342531694631491, 0.04109229786055429, 0.03578874262581978, 0.020571249636954496, 0.05250583362898656, 0.004040987313991147, 0.020541572211576358, 0.0048556360332960525, 0.07635126409253903, 0.03480501951915877, 0.0766601807304791, 0.03463390316548092, 0.026461864888135875, 0.012617689457588961, 0.06067682696240289, 0.04721670744142362, 0.04891500934692366, 0.06182051130703517, 0.020145568996667862, 0.09423096038933311, 0.08054395232881818, 0.03087020173136677, 0.010235277520093535, 0.03132414844419275, 0.06020023753600461, 0.015786410675251057, 0.05177989615393536, 0.018714036526424543, 0.03211200223969562, 0.034298326886658154, 0.02713072399741837, 0.0773825083992311, 0.05075486044266394, 0.03416450621028032, 0.07784018705465964, 0.02179535904100963, 0.045009283748056204, 0.04359157642881785, 0.046391177989010296, 0.02748141125110643, 0.04127481360254543, 0.03394449123048356, 0.014928530369486128, 0.020267732441425323, 0.037608939954744916, 0.08678135156099286, 0.03092928177544049, 0.006291697300704462, 0.022975073595132147, 0.0760209464601108, 0.308786114943879, 0.17187952915472643, 0.1391278515969004, 0.1050212142456855, 0.10574265981891326, 0.15505540264504297, 0.08882044428693396, 0.11634990599538599, 0.15614084154367447, 0.1418615470507315, 0.09768317014511142, 0.17305518606943743, 0.17158854619732924, 0.06372342205473355, 0.10679644505892481, 0.07631142730159418, 0.15908094735017844, 0.1432202455720731, 0.12476686148771218, 0.0901128499369536, 0.1412560088293893, 0.1242185780512435, 0.11117142851331405, 0.09349547592656952, 0.15340051001736096, 0.20265189292175428, 0.14019174022333963, 0.14707036183348723, 0.11127689999661275, 0.11265934724360704, 0.11669819802045822, 0.12794319247560842, 0.17106174517955097, 0.09513431441571031, 0.08348460096333708, 0.11610039509832859, 0.1397883240133524, 0.16517905012837478, 0.14405385298388346, 0.28196804970502853, 0.1351771628750222, 0.09890834654548339, 0.18041529612881796, 0.09364784775035721, 0.1062089219423277, 0.13547589470233234, 0.10539603020463671, 0.13005416920142515, 0.17702714007880005, 0.1282678171992302, 0.09977079169558627, 0.11879088144217219, 0.13644311923001493, 0.10488318665219204, 0.16672688350081444, 0.2417446837893554, 0.13527739606797695, 0.09355851861515216, 0.10884596008275237, 0.10487009092633214, 0.14521570849631513, 0.12526231418762887, 0.15930460606302532, 0.13890586208019937, 0.0874838660072003, 0.16097490143563065, 0.08595659224582569, 0.07655399000006062, 0.11123117352170603, 0.07816650133047785, 0.12644698204738752, 0.07620339774127517, 0.15405874326825142, 0.21027002270732606, 0.08606532069721393, 0.15488977224699088, 0.17036830953189305, 0.1405043548771313, 0.15283793663339956, 0.09071521261440856, 0.08183835965714284, 0.1283845387931381, 0.23314756367887768, 0.12841864196317537, 0.17038992765758718, 0.16058664369796002, 0.11585036851465702, 0.12482430626239095, 0.1637474498046296, 0.14490332454442978, 0.13331705411630018, 0.08985925425908395, 0.181650080585054, 0.16943704736019882, 0.12627509555646352, 0.07769610014344965, 0.1481504538761718, 0.13834703420954092, 0.1521472151258162, 0.20138866427753652, 0.3097026529056685, 0.11158996248351676, 0.21253159349518164, 0.11504174476223332, 0.10847972759178706, 0.07779558016253368, 0.1069011769390532, 0.125807557787214, 0.1603699874665056, 0.14623834219362053, 0.11639103878821645, 0.14306088483759336, 0.2023133718009506, 0.13524592561381205, 0.15039998745279654, 0.1729637874024255, 0.18147592778716767, 0.1484708445412772, 0.13331914400415762, 0.16203207256538527, 0.0924593461677432, 0.08279519581368991, 0.15780678072146007, 0.0783730609608548, 0.10603807360998221, 0.07127162880663361, 0.1041518005409411, 0.1822616984801633, 0.06642868689128331, 0.12066747860184737, 0.09673115158719675, 0.09782710099326712, 0.11777221038937569, 0.08788703794458083, 0.12395518432770457, 0.09968699940613338, 0.14084172248840332, 0.2019467321889741, 0.09799379669129848, 0.20931958513600485, 0.151060622717653, 0.12038230390420981, 0.10442830356104033, 0.10165009620998587, 0.13033816324813025, 0.21046230596091065, 0.13913251991782868, 0.08865315826343638, 0.09682808031461068, 0.10554892450038876, 0.1443467086979321, 0.13478335472089903, 0.1036563478410244, 0.0729016259844814, 0.1774490802947964, 0.08388354562755142, 0.14078828107033456, 0.12070086252476488, 0.14924137533775397, 0.13295637204178742, 0.09762225127113716, 0.10357372263180357, 0.0788198694852846, 0.16032215074769088, 0.190768071317247, 0.08173123254839863, 0.08895067551306315, 0.09610472127263035, 0.13225020707717963, 0.09751614196492092, 0.1033284729346633, 0.1933122926524707, 0.07775773826454367, 0.10348226968199015, 0.13456501572259835, 0.15688336241458142], [0.006164983854562576, 0.01754767045245639, 0.04065130438123431, 0.018144170587350215, 0.02799025653595371, 0.03734855553401368, 0.02351636642457119, 0.01024277278754328, 0.029743541830352375, 0.058548493310809135, 0.0753997815772891, 0.05845843814313412, 0.028961031498121362, 0.0570135996011751, 0.04741630869518433, 0.0540747117650296, 0.07053021394780704, 0.02005725766399077, 0.05070151062682271, 0.02315496340660112, 0.052192665969154665, 0.021030543205727423, 0.07901834776358944, 0.043540462385863066, 0.03640119851167713, 0.01828953653707036, 0.030288402057651962, 0.01650611580615597, 0.023715022818318436, 0.02158332702570728, 0.04098699940368533, 0.038058499938675334, 0.06039211366857801, 0.049891913176647255, 0.10892042930104903, 0.04377248065013971, 0.038642569312027523, 0.022976318706891367, 0.05905890092253685, 0.03990556046898876, 0.00802976729547871, 0.0324156873726419, 0.037562453520617316, 0.025262723876429454, 0.047367861294852834, 0.04484477632545999, 0.06091084011963435, 0.01647582769926105, 0.024801599959443723, 0.015776853509513394, 0.056577494966664484, 0.022926320854042257, 0.040524068887212446, 0.04966350471866982, 0.06009277794510126, 0.0582938798304115, 0.04423137388325163, 0.021146823751873205, 0.013342637967850481, 0.02090639334970287, 0.03082311140107257, 0.07057332127754178, 0.03518260729366115, 0.06134924838053329, 0.02688900098603751, 0.05955266407025712, 0.06858735784356083, 0.036701060099793334, 0.02839313161426357, 0.020030613290145993, 0.029385428010885204, 0.04753561211483819, 0.0857363940615739, 0.02286021288351289, 0.06479408246065889, 0.014259655993165714, 0.02137618724788938, 0.07382398577673094, 0.026401232695207, 0.0485851531183081, 0.003834391636441329, 0.03909455505864961, 0.02385848038829863, 0.06289300375751086, 0.022136351725618755, 0.015091287171734231, 0.04342365597507783, 0.04769420949742198, 0.00902896439324, 0.032096541819295714, 0.0528735012215163, 0.08678025233426265, 0.04688701406121254, 0.024900464207998345, 0.023742976764749204, 0.030707641704274074, 0.034992983897349665, 0.02504102952246155, 0.026247442733230333, 0.041615224443376064, 0.011142545845359564, 0.026895620095144426, 0.040572991262057, 0.07881839027894394, 0.022068411710539033, 0.023588082487029687, 0.03832522866183093, 0.0653403913602233, 0.031183471171451465, 0.02069388296721237, 0.027721266594848464, 0.07325185861970697, 0.04474662623501249, 0.041577002565775595, 0.03886699476944549, 0.05260358677644815, 0.045314987522682974, 0.045367553630577664, 0.026588009637115256, 0.033486052615834136, 0.036631913988717964, 0.020890076278841922, 0.0247072038639869, 0.04637497118008988, 0.05113799524094377, 0.045579497436327596, 0.04893488363761987, 0.01352251590495663, 0.03111533947022898, 0.012336954923479684, 0.03766385040112904, 0.036486090027860234, 0.03796675521880388, 0.05093209378953491, 0.03269169506217752, 0.013210340602589505, 0.057801908015140464, 0.034420717640646865, 0.04807923401572874, 0.044201419954853396, 0.028731415247810737, 0.07166207142706428, 0.03058709656553609, 0.056098992071513615, 0.010832170357129403, 0.02812898810952902, 0.014488473268491881, 0.05841820780187845, 0.03709113970398903, 0.04567567977522101, 0.014552513403551919, 0.019040983536147645, 0.03291448525020054, 0.006961485578878117, 0.02955056307837367, 0.03732151591352054, 0.035933918585734706, 0.019271234216700708, 0.03497619015563812, 0.053494666104338, 0.038289201845015795, 0.012325043241227311, 0.05876348713146789, 0.03852645839963641, 0.015880036633461714, 0.010041075708743716, 0.012696575938857027, 0.014572360552847385, 0.03276716511962669, 0.022400664864107966, 0.07255222116197858, 0.06031118479690381, 0.02530856739862689, 0.04697920322152121, 0.06961476164204733, 0.0671858573332429, 0.06366322921322924, 0.012337686893131052, 0.0825971450124468, 0.022246199759787748, 0.080854097115142, 0.055709730102015395, 0.035681924250509055, 0.02925608227295535, 0.023817753020141805, 0.07760464719363622, 0.025646666131381477, 0.03674423528302993, 0.039178147180272, 0.10801869018801621, 0.04315778559872082, 0.0352277163017009, 0.01324043023799147, 0.04126353635053549, 0.05559193981545312, 0.06890658821378436, 0.01900567257377718, 0.012226859224028885, 0.028428737739367143, 0.0371569202813719, 0.023557159949892333, 0.025209743862173388, 0.037587891798466444, 0.0687777411990932, 0.04085188951077206, 0.01144079676097525, 0.04353887800659452, 0.03382689432640161, 0.08494573113109384, 0.030309294150876145, 0.03577354683407715, 0.045984324999153614, 0.06351951549627952, 0.04707076134426253, 0.023910339123436382, 0.08527454241578068, 0.03654314125222819, 0.06214525138161012, 0.0532134269098086, 0.05347179947420955, 0.04014292558921235, 0.09335837792605162, 0.04629154529954706, 0.021562847142506922, 0.019339876515524726, 0.03010781335511378, 0.04608709930575319, 0.03275875128539545, 0.012947274272197058, 0.04478932983641114, 0.03273576930431383, 0.028779767653239623, 0.030630536377429962, 0.014858625995527421, 0.055217758286744356, 0.021564697846770287, 0.056676157351051054, 0.04304066027647682, 0.03467572467135532, 0.0938134238656078, 0.009677176530073796, 0.05856042874178716, 0.042044455518147776, 0.03928785950743726, 0.05180691881105304, 0.006323080393485725, 0.04519607765333993, 0.046259080791579824, 0.02581101579458586, 0.030085445448224033, 0.043966670587126694, 0.057999551695372374, 0.02418942905829421, 0.050134285885308466, 0.04919581427904112, 0.012930804530956914, 0.005409802368376404, 0.024929451223995005, 0.01853150042838284, 0.009383428542475616, 0.07389787824026176, 0.02493361064365932, 0.02595607131453497, 0.011710345645302107, 0.06679348767335926, 0.05120433221704193, 0.03496280265972018, 0.06250900043440716, 0.06293393977518592, 0.025260187851797258, 0.032141141926071475, 0.013425055375721837, 0.0682724497414061, 0.03882333104099546, 0.012702374868760151, 0.03672836434894374, 0.03629641913409744, 0.05945129772382123, 0.01882359279053552, 0.1022984024935535, 0.04579922743141651, 0.060600525699555874, 0.02756700844370893, 0.05469142206545387, 0.014175957002277886, 0.04987730092502066, 0.0690739420907838, 0.076826605014503, 0.017925349829186286, 0.07069226846631084, 0.05136255640536547, 0.023492960359102914, 0.04674769046583346, 0.04508971728916679, 0.05953280335026128, 0.04603804122390492, 0.05050742247008851, 0.025055451784282923, 0.013310025030347918, 0.019458109546186667, 0.024299590914909328, 0.060241845303348134, 0.041362314085875235, 0.042589013797364066, 0.0409107049261885, 0.019552352971264293, 0.0435000827669033, 0.030828431115618775, 0.025246981863996813, 0.05116976425051689, 0.046634188520589044, 0.06040850028927837, 0.00538180092449433, 0.0280037407231118, 0.04752956297514694, 0.03103328762309892, 0.05486761386107121, 0.07661640843642609, 0.021945328850831305, 0.04526325262018612, 0.015303353113787515, 0.04487993461745126, 0.028515613970479796, 0.04230754729360342, 0.0770540228113532, 0.04104783006810716, 0.06663320413125412, 0.009024721004867127, 0.04352966010836618, 0.08488850348762103, 0.059929936325975826, 0.01633971187818263, 0.011581155122257769, 0.016557847315977727, 0.04874843917787075, 0.01008050113783351, 0.0661208423386727, 0.014896869925515992, 0.07114310748875141, 0.04685295499595148, 0.05838189260768039, 0.030966261933956827, 0.04874743494604315, 0.034601228311657906, 0.018174938757770827, 0.05372536461800337, 0.04587874495025192, 0.060604997245328765, 0.02695062892910625, 0.0053929115113403115, 0.03768286634502666, 0.03330017812550068, 0.15144103659050806, 0.11274455767124891, 0.14244453076805386, 0.16694064917308943, 0.18289958925119468, 0.25755802382315907, 0.0715435788567577, 0.10594090739531176, 0.05305039869355304, 0.17539227780486855, 0.22953612889562333, 0.12640004099479743, 0.16680895909667015, 0.15868916123041085, 0.11359079261975628, 0.19926012706543716, 0.12865536926048143, 0.08112051031951394, 0.14325178387973989, 0.1629107618438346, 0.1062598799222282, 0.055408816784620285, 0.1280041384909834, 0.054969523035522015, 0.16995585523545742, 0.09261037449219398, 0.13824297407908098, 0.15266409596162184, 0.10167301712291581, 0.064422224914389, 0.12357041426002979, 0.09020354971289635, 0.18049533611961774, 0.10133296929832016, 0.1410233663128955, 0.15582389783646378, 0.1030267555532711, 0.18284241589052336, 0.0987413658627442, 0.12238460646143981, 0.0677870325744152, 0.10380169682736907, 0.09231586315269981, 0.1317135537309306, 0.09829632831471306, 0.11618679974760328, 0.17109639117760317, 0.06717211699911527, 0.10032802500895091, 0.12821893553648675, 0.16098202605332645, 0.12929805048874446, 0.09922074406806912, 0.1470273562840053, 0.24872515350580215, 0.09893965415124382, 0.2639719439404351, 0.18583149835467339, 0.09844167730105774, 0.06437756373946156, 0.13169730960258416, 0.13185118777411325, 0.12342216792915549, 0.19112287727849825, 0.10322378176663603, 0.19819034875503608, 0.09813730006239244, 0.13275258083428654, 0.08641376878534045, 0.10725388622709683, 0.17077666547681603, 0.11240455055875437, 0.16810454029057706, 0.1770013693187918, 0.0957447380891868, 0.1194052134773561, 0.15409132651984692, 0.15278456306883267, 0.08968751026051384, 0.10820052400231361, 0.12460364667432648, 0.11920020090682165, 0.13466771878302097, 0.14541806120957645, 0.104900177169059, 0.14360493421554565, 0.08898884310786213, 0.13845496198960713, 0.1266960043992315, 0.16633469026003564, 0.16487252871905053, 0.2668744996190071, 0.2835936024785042, 0.12474145713661398, 0.15856664494744369, 0.0824118981670056, 0.17491529482815946, 0.12400790649865355, 0.0736988503485918, 0.12560201595936502, 0.11317732052079268, 0.14135314790265902, 0.11752428726426192, 0.23399138982806886, 0.11020703347665922, 0.1326922726418291, 0.1255202524896179, 0.1438910724329097, 0.11209065347377743, 0.1870519250099148, 0.19399876653083734, 0.1977217796125582, 0.08269866742193699, 0.11146315785923175, 0.11299302362437759, 0.10052754823118448, 0.10511654163045542, 0.15950144907193525, 0.1268215605190822, 0.1331808857087578, 0.16862606230591023, 0.11238986706095082, 0.09393619799188205, 0.10724026124392237, 0.14171719551086426, 0.1922582292131015, 0.1434475276619196, 0.16541955008038453, 0.09690427301185471, 0.13356751496238367, 0.21438478119671345, 0.10789393473948751, 0.08177108291004385, 0.08576797986669199, 0.205283292436174, 0.14375840526606354, 0.12124440978680338, 0.05545658564993313, 0.11073338666132518, 0.14223099579768522, 0.14507674452449593, 0.1740216642085995, 0.09135184809565544, 0.13740224204957485, 0.13948816726250307, 0.10072078821914536, 0.09410498357777085, 0.19903268212718622, 0.12267957920474665, 0.08157466737819569, 0.18175697699189186, 0.07048292684235744, 0.10722355571176324, 0.13103526298488888, 0.11331721408558743, 0.13558239755885942, 0.15863592337284768, 0.08734026764120374, 0.10087908365364585, 0.13354949307228836, 0.1287557381604399, 0.13369593450001307, 0.08497733729226248, 0.14573523561869348, 0.17775359324046544, 0.110287874138781, 0.09354488006127731, 0.14984673713999136, 0.12494769107018198, 0.0673049334436655, 0.1623537660177265, 0.1576406346367938, 0.10161264107695647, 0.10133978857525758, 0.1696700562856027, 0.12816185717071804], [0.0031255210134466843, 0.0492680171903755, 0.0248753092185195, 0.04840506313900862, 0.019099113631195257, 0.018098033598757217, 0.017998733391453112, 0.029306242974208932, 0.0455096626122083, 0.015142558974080851, 0.040279786102473736, 0.07786279584148101, 0.040286500206483264, 0.012364248146436043, 0.017013666785455177, 0.008850692887790501, 0.038148765452206135, 0.059317409193941524, 0.04445028963631817, 0.02254406645494912, 0.08136417224471058, 0.024771342386624644, 0.056449482550046275, 0.040084456226655414, 0.03586366646257894, 0.0403859836182424, 0.04771905405712979, 0.010309817984567156, 0.026814779433022653, 0.045732486726982255, 0.006216704762274665, 0.06626368753079857, 0.028440277923696806, 0.012623878545127809, 0.04598873208409973, 0.03398866725287267, 0.03147151267954281, 0.053756224390651496, 0.022946207019101297, 0.0888123425788113, 0.01743062655441463, 0.022803685827446834, 0.014855335100686975, 0.01986512538444783, 0.03423114174178668, 0.04927135897534234, 0.036052560433745384, 0.030353982467204332, 0.018944845302030444, 0.10067279543727636, 0.022817782392459254, 0.06503382923879794, 0.055145151647073884, 0.02880335013781275, 0.06203219387680292, 0.006540442725443947, 0.02573300462349185, 0.013104805506632795, 0.032486634994191785, 0.07238946775240557, 0.058658097072371414, 0.024129212468064258, 0.021720810094848275, 0.019135476322844625, 0.02074490880061473, 0.014680234050112111, 0.029090960776167255, 0.01767693306984646, 0.022549652494490147, 0.045609556537653716, 0.01562561483920685, 0.0583393145352602, 0.07666203313108001, 0.017440322819831114, 0.028907841138009514, 0.07117950410715171, 0.04901884895350252, 0.09188772791198321, 0.011986036119716508, 0.03753066076231854, 0.023258660520826067, 0.013808198655689401, 0.04153833285506282, 0.04759548943755882, 0.014442770542310817, 0.03869955607556871, 0.02991073964429753, 0.05741379276982375, 0.026560472989720956, 0.013336649896310908, 0.04653594682791403, 0.01771666468786342, 0.02865787222981453, 0.04513172199949622, 0.006962203129660338, 0.0373891590695296, 0.10689167066344193, 0.0668264509045652, 0.01819567648427827, 0.019157498176874857, 0.1030010933588658, 0.05002298239352448, 0.004712002468295395, 0.03772409413275974, 0.01382906615201916, 0.033498676759856086, 0.06431319112224237, 0.0640578991068261, 0.024480478172855716, 0.06291579574878726, 0.020711065170222094, 0.028603260338838612, 0.023538591839107018, 0.08944865236324923, 0.03367737574236734, 0.05343729257583618, 0.00025067219913970415, 0.02168994184051241, 0.026401799271947572, 0.06810475659689733, 0.05109096597880125, 0.0565204064228705, 0.030919171603662626, 0.05225236348009535, 0.050062116900725026, 0.02255486194709582, 0.05540927818843296, 0.06220547814986535, 0.06314609053411654, 0.029631929605134895, 0.040216963937772174, 0.043750452010759285, 0.017163924972659776, 0.026314281825242297, 0.010601223330013454, 0.052585259545594454, 0.02748989633151463, 0.01013180856326861, 0.0150777724505003, 0.031263921675937514, 0.05009509030995624, 0.04202200957973089, 0.01413701502938888, 0.050916887819767, 0.023591159643339257, 0.04396176138626678, 0.07187826625470604, 0.036805540921964815, 0.029882512587521757, 0.0625410612140383, 0.02138584789021739, 0.030863165323223387, 0.015555552705856306, 0.051332375167735984, 0.033605946360954216, 0.021592723039378012, 0.01227982566758458, 0.04011112943823848, 0.019466816846813475, 0.030114788695105484, 0.10228935083640472, 0.032477892070476494, 0.02322726640185075, 0.013393288062486266, 0.08196953404694796, 0.019324738399258683, 0.048134633007326295, 0.03220341108473284, 0.01963166692959411, 0.04399243795445987, 0.030473479269338504, 0.0595881175249815, 0.014955551330266255, 0.04292809131688305, 0.04109111042427165, 0.016598040337807367, 0.04261558862136943, 0.0039697360480204225, 0.03563157355945025, 0.018730012633438622, 0.07574913211699043, 0.006780705614281552, 0.032636611589363644, 0.009674676128530076, 0.039847169137958965, 0.031875512429646084, 0.03459099939625178, 0.014428850396403244, 0.02919995385621275, 0.029550454512770687, 0.05781159070985658, 0.04248504866180675, 0.0568312161735126, 0.007130373369104096, 0.028904058305280547, 0.01412395662295499, 0.004980876634363085, 0.062168185865240436, 0.0469095753505826, 0.09111795707472733, 0.06482173276266881, 0.09242767893842288, 0.06384441841925893, 0.03024960003261055, 0.020324600461338247, 0.053226668520697525, 0.01874214823224715, 0.06202642632914441, 0.00936513439020408, 0.021112262570698346, 0.02771832175286753, 0.04639600237299289, 0.06359168448086296, 0.008961462881416082, 0.06278148652719599, 0.10806278139352798, 0.052319423095988374, 0.024676552740857005, 0.02340780251792499, 0.024962368654087186, 0.0399718092355345, 0.10444038148437228, 0.044239903068436046, 0.023278436423944573, 0.03969663614407182, 0.10891006128596407, 0.03506053205845611, 0.036919287139815946, 0.01632237191578107, 0.043940336643052955, 0.047837984282523394, 0.04333917157990592, 0.05037599362965141, 0.01069609948899597, 0.03767959241356168, 0.013754693624962653, 0.06932654710752623, 0.02378963283263147, 0.02899260712521417, 0.03682640587378826, 0.05869386265320437, 0.008766907383687794, 0.05101523129269481, 0.021224751802427427, 0.022596652918894376, 0.0032789575010870715, 0.012733000546826847, 0.06268688517489604, 0.04525196519015091, 0.04302033815266831, 0.029561222863516638, 0.032921019542430124, 0.058696359662073, 0.058346540933208804, 0.032223865522869995, 0.004631832707673311, 0.058429607190191746, 0.014495380754981722, 0.04299313907644578, 0.0675020817933338, 0.0183487556808229, 0.07227071055344172, 0.031238378225160495, 0.0488291916304401, 0.0375471491632717, 0.039387821286384544, 0.03702175610565713, 0.03226808565003531, 0.032357441926641126, 0.07029660791158676, 0.0362556731062276, 0.03903894232852118, 0.07426073162683419, 0.06765693705528975, 0.031019353906490972, 0.0408245072300945, 0.05672165990940162, 0.018573927526761378, 0.004398586719097304, 0.00932028831448406, 0.029018086115164415, 0.05555159751591938, 0.05899705924093723, 0.10581596195697784, 0.05004932312294841, 0.004649608628824353, 0.02948932529294065, 0.06870333304894821, 0.036381029058247805, 0.04089446758319225, 0.027823238533788493, 0.044563068941767724, 0.027259018006069318, 0.052264940126666, 0.044717072642275264, 0.029781706032476256, 0.04599881850715194, 0.010231573567060488, 0.05005892100078719, 0.03886775133599128, 0.01479690645023116, 0.058645992007638724, 0.009492280826504742, 0.027040963992476463, 0.06423518673649856, 0.020371841765674095, 0.010290122657482113, 0.040775330404617956, 0.012101235250676317, 0.02161740475068135, 0.005116422910110227, 0.03840802350480642, 0.014087301313078828, 0.013444598880596459, 0.09741699442799602, 0.046885148089911254, 0.04195644613355398, 0.05814144693847213, 0.048190096459750614, 0.027260766930079887, 0.06896665891898529, 0.12135197115795952, 0.038583384095025916, 0.05998639722487756, 0.02448600484058261, 0.016428194540951933, 0.011017497778604073, 0.030937939882278442, 0.031023872949715172, 0.021530173985021453, 0.007374696017775152, 0.015235691298065441, 0.031472696723150353, 0.028364965625639473, 0.04920028582481401, 0.06705409261797156, 0.025873552974579588, 0.03828673537022301, 0.02025752218573221, 0.043632760111774714, 0.03969474981671997, 0.024293718194322925, 0.02782367618887552, 0.013854585854070527, 0.030601640963660817, 0.08767009672841855, 0.03231150510587862, 0.030366094317287207, 0.01101075398868748, 0.04061566772205489, 0.026159955820600902, 0.04506014673305409, 0.10118637180754117, 0.1307175321770566, 0.12494714824216706, 0.1041046084303941, 0.12916181422770023, 0.06151648012122937, 0.1344531931515251, 0.09652035111295325, 0.13177793313349995, 0.06778871534126145, 0.11788665210562092, 0.11952185364706175, 0.10783355190817799, 0.05534703956384744, 0.12615800755364553, 0.2044068287525858, 0.17597632003682, 0.17295854911208153, 0.08053297363221645, 0.08872732892632484, 0.14232175664177962, 0.23828252671020372, 0.23945506236382894, 0.10130502044090203, 0.2641616351902485, 0.24301400567804063, 0.12109857904059546, 0.11085266633225338, 0.05269135867378541, 0.26733457350305145, 0.07109520291643483, 0.165245315858296, 0.0945235514747245, 0.07038613382194724, 0.12123419104942254, 0.1525283075336899, 0.16406961823148386, 0.12234906479716301, 0.16034133971801826, 0.15852046385407448, 0.12745243523802074, 0.07003383844026498, 0.0629828010818788, 0.10966121990765844, 0.13249830662139825, 0.18053534254431725, 0.11418046669236251, 0.07284421513655356, 0.10473974434924976, 0.20967076772025653, 0.13398192343967302, 0.18007522794817174, 0.18233641875641687, 0.09961641140814338, 0.13032736097063335, 0.06794065968798739, 0.18434595449694566, 0.059433642242635996, 0.09154586839888777, 0.1900334350232567, 0.09652689897588321, 0.09745201362030846, 0.10007573890366725, 0.1128644955211452, 0.13064548532877648, 0.0759403161438448, 0.15825972998780863, 0.07456736838711159, 0.10664417501538992, 0.16394811975104467, 0.15933142176696233, 0.11921086747731481, 0.1532085117484842, 0.15680435379701002, 0.14950147138110229, 0.19249034247228078, 0.15584508169974598, 0.21605574153363705, 0.16969182368900093, 0.0767462800389954, 0.19601678395909922, 0.06708793115935155, 0.10915621343467917, 0.16566047072410583, 0.0895170419077788, 0.12127228400536946, 0.11692231813711779, 0.1287129633128643, 0.20970735432846205, 0.10196819342672825, 0.08200055666800056, 0.06711229056652103, 0.10712003162396805, 0.15098231977650098, 0.1038078104278871, 0.1442340583141361, 0.1858292727598122, 0.17361972720495292, 0.08992676170808928, 0.16972982165004524, 0.15834409903202737, 0.1433000277195658, 0.08917715693158762, 0.11657095913376127, 0.11670942098966666, 0.08965568696813923, 0.2012662294187716, 0.157012406204428, 0.12569398459579262, 0.22244619790996822, 0.11786962087665286, 0.19256557843514852, 0.11748174311859266, 0.12484148676906313, 0.09813377168029547, 0.10636067629924842, 0.12548392372471945, 0.08221299241163901, 0.15705216835652078, 0.14978072925337724, 0.1385719957096236, 0.16267137468925544, 0.13721236080995627, 0.10822972136416606, 0.1037798479997686, 0.2512211852840015, 0.1904362676931279, 0.11801941426736967, 0.10797839199325868, 0.15530713913696154, 0.1104712685836213, 0.10107247970466103, 0.10092077284519162, 0.10704385928277459, 0.10568089956151587, 0.11272897172187056, 0.12225158645638398, 0.0891530689384256, 0.11409491699721132, 0.15993267164698668, 0.17999771210764134, 0.09600408095866442, 0.12342467850872449, 0.1402529440820217, 0.10324928111263684, 0.21610640095812933, 0.1265992181641715, 0.08946964623672621, 0.07323500380984374, 0.10434442306203501, 0.12945191508957318, 0.14476805180311203, 0.12189390350665365, 0.18795686002288545, 0.13306940240519388, 0.059442191783870967, 0.15683230943977833, 0.14153766871563025, 0.07930810257260289, 0.26071462301271303, 0.3200597571475165, 0.11723676483545985, 0.15804658856775078, 0.19418737212462084, 0.21071267181209155, 0.1405818842883621, 0.1723056220050369, 0.0822057727990406, 0.09011624939739704, 0.18457618142877305, 0.12465491678033556, 0.13474417610892228, 0.07390099271599736, 0.07885690392660243, 0.15135464551193373, 0.11162911395409278], [0.03000334949631776, 0.03838220185467175, 0.03774402949160763, 0.08603758218565158, 0.07501358658607517, 0.02043184292103563, 0.1155609597585031, 0.06401945331266948, 0.04140613727005465, 0.03533041936212352, 0.03329632743926985, 0.041764081455767155, 0.08250238759709255, 0.04251417817015733, 0.011967244940543813, 0.02753829114538218, 0.02072273088353021, 0.05372240959799715, 0.055627766464437754, 0.019730312350605215, 0.037043051927217414, 0.058224031435591836, 0.004582251305691898, 0.04124650512156742, 0.056195506892566166, 0.002211601136618161, 0.04777772019484213, 0.02647612939056541, 0.018939885211044123, 0.022877769977120415, 0.04841469833627343, 0.02919724310881325, 0.03886455882872854, 0.029381397512874434, 0.03836924522849066, 0.02820100442373327, 0.06856216383831841, 0.012772760154413325, 0.04294521754075374, 0.06121206217046295, 0.013303969953475254, 0.05630365858918854, 0.023341095740241662, 0.03366391360759735, 0.036653671214090924, 0.061663701864225526, 0.020220419890912514, 0.0172560106563781, 0.026020060559468608, 0.025978651263618042, 0.022574581871075288, 0.006884204257013542, 0.0387151250615716, 0.028826396579721143, 0.05143418934728418, 0.04319020260923675, 0.07323389779776335, 0.03766334489254015, 0.03573405609599181, 0.034428052604198456, 0.01375256641767919, 0.055930382904729674, 0.013870676463869, 0.035016088014734645, 0.010931943842609013, 0.03372828961749162, 0.08494395336934499, 0.028965384300265993, 0.022668397819091166, 0.05310644907876849, 0.04756334723372545, 0.07589991616883449, 0.0684676846223218, 0.004737770683797342, 0.06582147947379521, 0.042818708079201837, 0.027517368518082157, 0.02703722017551107, 0.03424614754372409, 0.007209605903231672, 0.03339194320142269, 0.0254926318967981, 0.011821644896242236, 0.02283724956214428, 0.0298376105326627, 0.008665778524508434, 0.0501163488120905, 0.026939448368336474, 0.03072887985035777, 0.019759509712457657, 0.006960355818072068, 0.07343975853707109, 0.02761205129458436, 0.030099260421203713, 0.040807543854628286, 0.01632765431090125, 0.051050057102526934, 0.056661663843052726, 0.0112522717432252, 0.13486612242247376, 0.032025451705391915, 0.02780494692602328, 0.03489073545538953, 0.03444737049617937, 0.020261557772755623, 0.035418635699898005, 0.04559418771948133, 0.03327972708003862, 0.005308941954613796, 0.054845174708004506, 0.03267784616244691, 0.010250011908023484, 0.03962763252535036, 0.0525163543144507, 0.02303531902310039, 0.02150052709371916, 0.01491699697050665, 0.0377279821384166, 0.04879292054101825, 0.05764682205127818, 0.016140412572505217, 0.01777504414453038, 0.01562716020271182, 0.015318289365885513, 0.05110733563612614, 0.05555950244888663, 0.033873367189828835, 0.07177975654069867, 0.0874701663851738, 0.03864582967279213, 0.004713141558957952, 0.06005956365593842, 0.06769964404936347, 0.09572367636220795, 0.05751960352063179, 0.07539393260542836, 0.017647023246224438, 0.012343929415302617, 0.05561657742198024, 0.022121137274163108, 0.06988328509032726, 0.06198125625295298, 0.0030705567083454555, 0.02563875271672649, 0.011424281218621348, 0.027246478678924695, 0.05345743488786476, 0.034525296850396056, 0.04391254045601402, 0.06758503948471375, 0.07053431229931967, 0.013704554127928401, 0.005045971891377121, 0.0281841954149838, 0.04134428541042975, 0.019172551476263573, 0.023926478078854934, 0.08474481691207204, 0.021239677876500145, 0.04425509546750358, 0.023135798184999397, 0.03151330025866628, 0.018103327868240218, 0.026305367571434805, 0.018847813098026172, 0.026287764676713517, 0.04078912502154708, 0.03908619211454477, 0.027882096357643604, 0.04685780991400991, 0.03646596807188221, 0.038434601721486876, 0.03425741461770875, 0.07716258841433696, 0.021010847030473605, 0.00485536631562614, 0.015088734183726566, 0.07269204008792128, 0.05800598420734916, 0.048923514783382416, 0.03373043378815055, 0.05524636193045548, 0.048776863009801934, 0.06157490877168519, 0.06181021114545209, 0.0064644374734988165, 0.05392229922914079, 0.029606304730155637, 0.01849275777515556, 0.025466708466410637, 0.060086067233766825, 0.0420342503514673, 0.03293739598510521, 0.050076237214463096, 0.02136969706043601, 0.02082013967446983, 0.014822631409125668, 0.05911418117050614, 0.02846337016671896, 0.02585842164366373, 0.034486616961658, 0.019322673956464444, 0.01970034315516906, 0.014324975166735905, 0.025319790367835333, 0.014061203159924065, 0.016016434046572874, 0.03280184165175472, 0.07741595339030027, 0.030352815386972258, 0.015256220375054648, 0.043578134650098424, 0.005080668355471322, 0.03026695017303739, 0.05189133196004799, 0.03741550997697881, 0.04508221269186054, 0.05459438477243696, 0.006251442362554371, 0.020083537325263023, 0.03293592695678983, 0.10165407921054534, 0.013559298440148788, 0.027442373435146043, 0.03855013587911214, 0.009779762543205704, 0.01796073203773371, 0.0072706503061843765, 0.051527779682406356, 0.07743700154657875, 0.051119556051812, 0.006624918638928128, 0.0312798943902765, 0.023006376111879945, 0.04646475493375744, 0.0574131685176066, 0.008892935933545232, 0.03310092292459948, 0.07622026612183877, 0.027118008251168897, 0.008589701178217573, 0.0463502623273858, 0.07682551935847316, 0.013031800227638866, 0.07006940046059233, 0.021014838512720804, 0.07539758312382869, 0.017912362668929354, 0.036916851199098995, 0.02323649956711701, 0.023114743243370737, 0.06531687333647694, 0.10232653455542666, 0.08360438953552927, 0.07749590517154761, 0.01794055410261665, 0.03860456456563302, 0.011822126656105476, 0.007021821336820722, 0.04034261505252548, 0.05874990964574473, 0.036403013592852015, 0.07323831506073475, 0.03828427228810532, 0.05115980674911823, 0.061545372142323425, 0.07099684248013155, 0.03698952569227133, 0.023005543210144554, 0.02736621127197785, 0.05780321080237627, 0.023774264014459083, 0.10013217944651842, 0.04299402795732021, 0.050214556578014574, 0.04875617786975844, 0.04635799762659839, 0.012360975063139839, 0.026146985623719435, 0.02368889413108783, 0.006754675314628652, 0.029370822544608797, 0.032825729477086237, 0.00402882118110678, 0.018827850597777536, 0.04950635940102594, 0.005837354917145733, 0.010668787606326597, 0.07554420775600842, 0.026933848758095076, 0.020717200823128223, 0.009717013321018644, 0.056676703571741066, 0.03219322966677802, 0.04019533224137766, 0.040536099313093085, 0.019304970977827907, 0.07675264469747033, 0.019829453102179935, 0.04465198417061141, 0.03294279373117855, 0.05756092630326748, 0.02589159013171281, 0.041725415137729475, 0.005844119063112885, 0.01935298241940992, 0.023392710202772702, 0.0869085429502385, 0.025990900517042195, 0.07297013766531434, 0.0086444843992857, 0.04058934395600643, 0.03190820085416947, 0.045213030850780864, 0.048410172507699044, 0.006605618982575834, 0.06428820067750556, 0.037594514300248454, 0.029133518492536883, 0.024183486787868396, 0.03134904389402696, 0.034606347858373604, 0.009526011650450528, 0.0288481063076428, 0.06308003515005112, 0.018777260723124658, 0.02671023754269949, 0.044473166444471905, 0.016795721337465302, 0.054457999233688624, 0.048812506454331536, 0.019305071061743156, 0.052821613648640256, 0.06983926852366754, 0.03209293879834669, 0.0826832986037646, 0.04919649620673486, 0.026200157324118272, 0.0204163960713361, 0.030457571015826294, 0.03887724743357726, 0.022090686318863715, 0.03374313596369965, 0.03064928429999522, 0.02797038563793259, 0.026066229778474996, 0.020376861228474548, 0.004684693130132343, 0.017118895692484717, 0.04960418379466448, 0.03713671011584146, 0.03766355184572084, 0.04879198416269251, 0.166986043165837, 0.16822882076459272, 0.11942030409617083, 0.2069361630295004, 0.24306286019938333, 0.23325477221182414, 0.16151550385568822, 0.2502605968288013, 0.09822200158877031, 0.14344157012445585, 0.11559157525854451, 0.17609758781535284, 0.10339918306895665, 0.15066449397376605, 0.1197481993585825, 0.09282647432493311, 0.16775243489870004, 0.11287569813430309, 0.19405157012598856, 0.11222553266478436, 0.20057501936597483, 0.13290434197655746, 0.1413445576493229, 0.16196713676410063, 0.10625477055353777, 0.10960135954831328, 0.16686577961913177, 0.09316950091826064, 0.07416758912482432, 0.14857413114181586, 0.10780913143285684, 0.11991598749799387, 0.11305171690349068, 0.10770716119025435, 0.13301256831203187, 0.16931772019181932, 0.11253680381923914, 0.10119814439011471, 0.202730548701116, 0.08599624583231551, 0.09377634871218886, 0.10592960300190107, 0.15241609141230583, 0.1157611683011055, 0.15323083555059774, 0.10525040301893439, 0.09692369946943862, 0.15341532922216825, 0.11658486910164356, 0.15670093148946762, 0.16155012271233968, 0.1392954226051058, 0.16599340071635588, 0.13222037867775985, 0.06273628930960383, 0.09692772996744939, 0.1207399597125394, 0.14407207843448433, 0.11274723788457257, 0.11916212152157511, 0.11715905900512423, 0.11876334649111543, 0.09831552407039063, 0.15920385718345642, 0.12588449008762836, 0.18721741970096314, 0.1235547943839005, 0.20266901914562496, 0.1473849985216345, 0.13776178418525628, 0.1824051679245063, 0.14648804308048316, 0.09886624344757625, 0.12587139436176845, 0.21049026160367898, 0.17431180578257355, 0.19316015153058938, 0.11107819101640157, 0.09585765988699027, 0.1122322433761188, 0.06166558140622718, 0.09172505592661244, 0.11859010293015412, 0.11835615762642451, 0.07745804291750703, 0.17990307004324027, 0.21191998917077268, 0.11422054097056389, 0.1563424342977149, 0.10295831851129021, 0.1782273328197854, 0.12474879888551575, 0.09500727230416876, 0.13294668256172112, 0.07210657293243067, 0.2538986030433859, 0.18625152510191711, 0.1329305334282773, 0.26032546960881775, 0.1025473094944443, 0.13093270920217037, 0.1753936213042055, 0.08911091155771698, 0.06347867447350707, 0.11961766279169492, 0.14258444468889916, 0.1056243572384119, 0.07872987538576126, 0.15698260494640895, 0.13876911013254098, 0.10988019672887665, 0.16319676435419492, 0.09747007622250489, 0.12212020850607327, 0.1709169050944703, 0.08973781006144625, 0.15166914649307728, 0.2281259431370667, 0.23291729603494915, 0.05553729060505118, 0.13051493519118854, 0.09889755105333668, 0.1014982129314116, 0.08815590066037007, 0.19152366077261312, 0.10381939302065543, 0.17110289154308184, 0.12386834541601793, 0.1271099786141089, 0.06670372427574225, 0.14611043834260531, 0.0877967860017504, 0.24464202831898416, 0.15102856872337206, 0.11396672816148826, 0.08958026101546628, 0.14700831659138203, 0.20715748758188315, 0.10460279562643596, 0.2936512285045215, 0.14984362944960594, 0.09305848580385957, 0.09340623500091688, 0.16697667938257965, 0.09902189259550401, 0.10430600440927915, 0.08874599542468786, 0.1753038511212383, 0.12491647845932416, 0.15454836056700774, 0.14931368002934114, 0.08788992171841008, 0.11829097755253315, 0.11640918281461511, 0.0713797194351043, 0.11896480353815214, 0.29713352450302666, 0.21960963654731, 0.17325387469359807, 0.14220179165048258, 0.19265236306403363, 0.04791044503716486, 0.13208965212106705, 0.13416911768061773, 0.22462063123072895, 0.12331586863313403, 0.10326313679771763, 0.07116395886987448, 0.22084188328257628, 0.25673249097807066, 0.06704480347356626, 0.11756759136915207, 0.15062584461910383, 0.09328907235924687, 0.07896481813596827], [0.018764772286106433, 0.017167404160967896, 0.030190896575472186, 0.04220857956845846, 0.054293525737843344, 0.06614604312926531, 0.019313069293275476, 0.0321765241346189, 0.020789478373314654, 0.030273138412407467, 0.0351622003529753, 0.03526615531050733, 0.028064859764916555, 0.03697926624278937, 0.01916814099864236, 0.05811697896569967, 0.0222633175019707, 0.0421027281055493, 0.07478114763008696, 0.024988224230972782, 0.029208079313061068, 0.04299039779497044, 0.03383561350139124, 0.07653408856796366, 0.04137330635317734, 0.055653133496109924, 0.04018889972940087, 0.03868204647941249, 0.015770958736538887, 0.017737950331398418, 0.011010663234628737, 0.0605973976531199, 0.052770747270967276, 0.06584996437387806, 0.031676891658987315, 0.019348025721098696, 0.00891245314518788, 0.042647961527109146, 0.08016378272856985, 0.03081018870164241, 0.03072278660589031, 0.011678083001502922, 0.08526418797139611, 0.07736862557274954, 0.021564857302499667, 0.04819143995908754, 0.0656854807000075, 0.00890015809064997, 0.02497110648878983, 0.06456102603780371, 0.03498742330287184, 0.007120766161408807, 0.02941547693418605, 0.01692963531240821, 0.02331079406264637, 0.03782718735081809, 0.026911319699138403, 0.02714801306969353, 0.05948449165693351, 0.07349816004612617, 0.03996931222666587, 0.06551535161478178, 0.0628848545519369, 0.047220951677965264, 0.087258809512215, 0.029339508153498173, 0.08125807650919471, 0.021155466591673236, 0.09950312320142984, 0.07333200039075953, 0.01958197441750339, 0.03385057519855244, 0.04025391695488777, 0.01191990270412394, 0.020207107033846632, 0.039566649190549336, 0.02089356564517532, 0.0678442195057869, 0.05217944810699139, 0.03489520021581224, 0.010344620045673634, 0.039238105927194865, 0.024433669434594255, 0.052527584069009335, 0.044515744516892095, 0.05365196069968598, 0.02474701520986855, 0.03024345589801669, 0.011311831002655839, 0.058233849837311676, 0.013097902260986822, 0.02252061289202954, 0.035326361722712, 0.013610744965262711, 0.03660322552812951, 0.03103139790307198, 0.015532192441501787, 0.013137689858142818, 0.0354370613183294, 0.046441443863191774, 0.028742946950452666, 0.060396164522639344, 0.014933510816523006, 0.026589575356670787, 0.01323444047011435, 0.08293077389576606, 0.023019694057958465, 0.025223148321466785, 0.05626486334949732, 0.007651481478075896, 0.005960573059772807, 0.019177009451336095, 0.06685243879577943, 0.015077434879328524, 0.028377513434471827, 0.07660855100091014, 0.08920346373426062, 0.07200825320822851, 0.051229875667818954, 0.02380300166883639, 0.0565183470690889, 0.04116136594010251, 0.029302829943065132, 0.02163990497189973, 0.02041353434989495, 0.09296111602868352, 0.0578829183110169, 0.04147851999316897, 0.03936719721449273, 0.026059802355510846, 0.028446615440770984, 0.03342095057346991, 0.05070464885128396, 0.07387318635093314, 0.058611271370734484, 0.05409989898492183, 0.012091008879776512, 0.01904195044854922, 0.042117499812905274, 0.08100416191986629, 0.02115475243356611, 0.015428612374567559, 0.02666949830017984, 0.03815599524282983, 0.01336035197268107, 0.02747562843641, 0.01276990182564727, 0.055497867720467706, 0.04666471241840294, 0.032806289448801956, 0.041003969564501724, 0.019428123387375047, 0.06750747614673205, 0.03778627508186868, 0.06855277291366033, 0.008285586023703218, 0.026719401158126335, 0.03194187993982008, 0.061227831324296336, 0.06536696957690374, 0.01682020627361323, 0.036281111384076734, 0.01305082465322422, 0.058898400249225755, 0.053122370902981074, 0.04194093482302768, 0.03180218993553093, 0.027984991104208996, 0.022692607948556542, 0.02636424744767802, 0.030071647438619818, 0.07068524562886783, 0.021321483754685948, 0.010139664302447012, 0.025565981532313993, 0.024278851492064338, 0.050822310216192684, 0.0570491955482534, 0.04347486840561032, 0.010776410045634423, 0.03266091671373163, 0.015397903575961078, 0.05555340920441917, 0.05552559944667986, 0.058159489184617996, 0.05312428097905857, 0.0659827876037785, 0.012991674211142319, 0.03830466565809079, 0.0051452195122172785, 0.021917000013802732, 0.05222858761304191, 0.03761973883956671, 0.04123771809307592, 0.07877270451613835, 0.06290200791720833, 0.038627963845751116, 0.07247828120099646, 0.018618162920964614, 0.04458548095343368, 0.05885795956211431, 0.02968672470056585, 0.03536972011040364, 0.02468691736326686, 0.03365204942279628, 0.010617228274765824, 0.07479811100555317, 0.049337824873094044, 0.05708019781325545, 0.023181921602892022, 0.033313843820776255, 0.009760624463004726, 0.04118178645148873, 0.04371742771140166, 0.0959637216957552, 0.031889524177781174, 0.03576121785278831, 0.01978431356006435, 0.09292861420129027, 0.014170259004458785, 0.033213552952344925, 0.04319847734378917, 0.017687832038583498, 0.06672511848488025, 0.016981762068878328, 0.09210218568997723, 0.008084103531603302, 0.03131633511345301, 0.020235685232494558, 0.02636209479533136, 0.04240864222603185, 0.09727163865630116, 0.05642167618498206, 0.026510573524449552, 0.07269209437072277, 0.028647948655166795, 0.057029938724424155, 0.016017115974266614, 0.02684768329241446, 0.03079521343378084, 0.03266696246074779, 0.021093516344470636, 0.05474135545747621, 0.0509004706649908, 0.08621577905224902, 0.042426314670592546, 0.02556439715304545, 0.0724667189642787, 0.027988897769578865, 0.08496474368231637, 0.031065976047622304, 0.037401952847306214, 0.06226335718695607, 0.0370193642697164, 0.014966567346294011, 0.029330273291894367, 0.03729255943159972, 0.018876014709738747, 0.055114098491945436, 0.050733394987348995, 0.07349127970103707, 0.03605174619172301, 0.037225265721125264, 0.04282220931989806, 0.08476927809949432, 0.030794969161174128, 0.029808745652969395, 0.020630674037550176, 0.03491081330659134, 0.024446519191509912, 0.007542414607347122, 0.046661106004778824, 0.013528038331839656, 0.005599604304214674, 0.023872636325125183, 0.060990262643567154, 0.01552975650078484, 0.07643382823360817, 0.005122602667792567, 0.05758509572063174, 0.0704392156164561, 0.09609463824225323, 0.00454199467120426, 0.018685672066307495, 0.040858824138662646, 0.037974208925983736, 0.03306244998904211, 0.03524830983951688, 0.01153743711100625, 0.0155964463150927, 0.04968988276751978, 0.023159499413200786, 0.03601242169471724, 0.06225548618073974, 0.01584889187610575, 0.0646627452224493, 0.04719954389812691, 0.02337662722649319, 0.029715749035988535, 0.060558700801006386, 0.010893385242005544, 0.05635565133499248, 0.03781684647713389, 0.018644459545612335, 0.11238833357180868, 0.020430904846372347, 0.06893757690808602, 0.04313348725970302, 0.08352999495608465, 0.04890065833127924, 0.029017784167081118, 0.07545717885451657, 0.0455125701347632, 0.0158929457621915, 0.02981492710698928, 0.02702210411163313, 0.03577450696112854, 0.031100866318281208, 0.012299677057723914, 0.03376213155154671, 0.021907834702038338, 0.04656088977519955, 0.03713878982567361, 0.028115994163921902, 0.030996388888784816, 0.05991198228938239, 0.036448132778917036, 0.028280035093692795, 0.020753948583400676, 0.06333669780620507, 0.010858949589809137, 0.024401847838557193, 0.036681474186480045, 0.02134485080439065, 0.05587438680231571, 0.03503756025539977, 0.023398287760625993, 0.05170991544478706, 0.021872075906555568, 0.020042453726221408, 0.058026231692305634, 0.021658562988575016, 0.0480031498840877, 0.017449510183983614, 0.05715469417295285, 0.018376767302730253, 0.04863855382427573, 0.05166522712845888, 0.05500434206000396, 0.013689382933080196, 0.050568263312535625, 0.03047282448304551, 0.09837625973990985, 0.17417722514697484, 0.14869975511516842, 0.11100449532802616, 0.13956505885081633, 0.1461068285363061, 0.09714970591345004, 0.12388294748961926, 0.0764370784163475, 0.09466902938272272, 0.12942281950797352, 0.09026602921741349, 0.11903891313288893, 0.11576139900301184, 0.10362102330795356, 0.13595137133130006, 0.07634916741933141, 0.12428101684365954, 0.19626533133643015, 0.18395256703453405, 0.13572646411401884, 0.17800410836935043, 0.1635928795273815, 0.1321393751672336, 0.1645724262510027, 0.16298773485635007, 0.08763089776039124, 0.12972212130469934, 0.10300992109945842, 0.07959022386265652, 0.15085752361587115, 0.13978706193821772, 0.14736826584807464, 0.14716238475271634, 0.14724239760211535, 0.06777231514986072, 0.07208201675010578, 0.13651729667825357, 0.20140940030770643, 0.11202258284070662, 0.10667614758546863, 0.060865853247897964, 0.15319826586970262, 0.13736794888973236, 0.0909131412793483, 0.14052924354161533, 0.13618109614721366, 0.16336140409111977, 0.08586679492145777, 0.12255913923893656, 0.12531633914581367, 0.10357189058725323, 0.15244268998503685, 0.11071221636874334, 0.14519964078707354, 0.14421520861131804, 0.14683101539100918, 0.1500882413238287, 0.13501561725778238, 0.1174375976302794, 0.16103945725730487, 0.13133866313312734, 0.0998928669307913, 0.11898088481809412, 0.1744342813534396, 0.1148890879537378, 0.14320500567555428, 0.16044170861797674, 0.13902216298239573, 0.18753840747688497, 0.1273171217846019, 0.10995878465473652, 0.09701154939830303, 0.12678012917084353, 0.14158022643199988, 0.1345085073262453, 0.208388445100614, 0.1427657628165824, 0.1580720336309501, 0.12256749879036631, 0.05759418808988162, 0.14605074083166464, 0.1628168254558529, 0.11570446991494723, 0.12262437359562942, 0.12912981451622077, 0.08060909847595862, 0.07488290074148349, 0.1485893846090351, 0.10317033356321709, 0.08503565737711531, 0.08154236232595784, 0.09586822467723063, 0.16101922334304877, 0.09497031250170299, 0.0799722322928054, 0.08937825435506445, 0.08994280227593013, 0.08520498579101903, 0.13304323809487478, 0.09956482239067554, 0.19898416687335285, 0.056618278313960345, 0.0953570231795311, 0.14105015487543174, 0.11024644279054233, 0.08647843317261764, 0.06685490187789712, 0.13797451848430292, 0.15214428385453566, 0.08596497893865619, 0.08639973668115479, 0.16517064986484392, 0.054904811150793514, 0.12351351231336594, 0.18795770140630857, 0.18570097535848618, 0.19972740699137959, 0.09660334951643433, 0.1635796209531171, 0.17401269397565297, 0.12061707702066217, 0.0737465445750526, 0.10616680527372019, 0.14711689576506615, 0.09212403451757771, 0.1145586006875549, 0.11028410148407732, 0.13426730169781617, 0.05974984634667635, 0.11729262183819499, 0.09934610341276441, 0.13947036250361375, 0.24150334245392255, 0.13206987961062364, 0.11280020432812826, 0.13205442258289882, 0.08137129686240639, 0.15208911895751953, 0.13666396880788462, 0.1193368307181767, 0.08645965810865164, 0.09774692529546362, 0.14297633937426976, 0.10150013318551437, 0.14690474500613554, 0.08124742350940194, 0.1205240362989051, 0.09588337636419705, 0.14637250213750772, 0.12960435476686272, 0.14040952282292501, 0.15101296241794313, 0.10771763777094227, 0.13915412447282247, 0.11337646376341581, 0.21484694496861526, 0.10396489128470421, 0.10862875423793282, 0.1159356739372015, 0.11987380976123468, 0.16579410141067846, 0.060021246783435345, 0.12551007446433815, 0.13154721765645913, 0.16405844954507692, 0.13504896046859877, 0.06457363321845021, 0.10368532128632069, 0.12960153206118516, 0.1534683228071247, 0.1267478173332555, 0.11573845094868115, 0.06083555665931531, 0.11701922650848116, 0.16300786020500319], [0.061405831415738375, 0.007601676159538329, 0.05039180349558592, 0.02429423727361219, 0.029385258377130543, 0.03609087730624846, 0.027579498577064702, 0.03197548777929374, 0.015799872810021043, 0.022556631227156947, 0.021528431846361076, 0.062026100632335456, 0.039112950143005164, 0.0339245931910617, 0.033490534339632304, 0.06136762310883828, 0.03988226975447365, 0.03201991825231484, 0.028374594037554095, 0.014457143610343337, 0.033363515976816416, 0.026315777994958416, 0.02148438135295042, 0.028397861003343548, 0.02237892969112311, 0.020667986678225652, 0.005944163114431181, 0.04261457760419164, 0.03849207703024149, 0.043819333493177376, 0.061657656117209365, 0.02052505497288491, 0.021178105912570442, 0.017937975669545785, 0.050376712876771174, 0.024137521129367605, 0.00589051898402561, 0.021182295866310596, 0.027178000924842696, 0.04612172834042992, 0.011942139993022596, 0.02843946877068707, 0.011543846722426159, 0.05774909084928887, 0.012115180841647089, 0.04014827923050948, 0.05364342812182648, 0.06378181677843843, 0.025206015312245915, 0.03624927452100175, 0.05430846368627889, 0.030775254326207296, 0.015433642015393292, 0.02059373289479741, 0.012836991127447357, 0.0712998965755105, 0.012262155767530203, 0.05341075846393194, 0.08924492222390004, 0.02565172121727041, 0.017597417247348597, 0.052714059062834294, 0.0390442552577172, 0.07305793331137725, 0.007812531764752098, 0.00965728866867721, 0.056959187878029685, 0.033266492254499874, 0.06588271725922823, 0.021882633911445737, 0.05174715005393539, 0.037926239892840385, 0.019351072343332425, 0.03950945547382746, 0.01759591938129493, 0.01970103695722563, 0.00829381580531065, 0.02589457398945732, 0.02979010290333203, 0.023091881702254926, 0.03290505022076624, 0.0551338981437896, 0.06953316780605487, 0.11395120328026158, 0.032286216105733595, 0.028566772118210793, 0.015440573250608785, 0.05828719626047781, 0.018613282557842985, 0.045413351351661344, 0.016057936640988504, 0.029902288490640264, 0.06185042791600738, 0.09620252531021833, 0.023867294558190873, 0.01717669839438583, 0.015280411844807011, 0.04264065709763339, 0.04992347523303969, 0.020888647962627665, 0.027441398041056733, 0.0662391245631235, 0.03370905654238803, 0.04109444542388831, 0.05940310138144663, 0.06609404020543609, 0.009811928495764732, 0.06258176652980701, 0.06006073073617049, 0.01722341892309487, 0.06082132099462407, 0.04853937914595008, 0.05242705571332148, 0.04854576076780047, 0.04586986292685781, 0.009194781388422208, 0.020797456248796413, 0.04224112889330302, 0.039286729746631215, 0.05281982231619103, 0.030181095137127807, 0.07588851678052119, 0.08248055234019246, 0.07237119480435338, 0.015691553175981556, 0.05297143418075783, 0.019764507122870003, 0.03237067335950477, 0.03165175532922149, 0.0028755472282812533, 0.023679359017738273, 0.056794972225491486, 0.02003263702083911, 0.04548087237136705, 0.031011448973523717, 0.015353461228577154, 0.054596454304243834, 0.03696980746462941, 0.05747889141951289, 0.03592808657724943, 0.0491761469415256, 0.033591035553919416, 0.056386718060821295, 0.0743722759985498, 0.014220945570351822, 0.06467822939157486, 0.03140954886163984, 0.027082692199785794, 0.0041692240712498975, 0.02889334423733609, 0.018250174720638564, 0.008851140720902808, 0.014869467288787876, 0.04881159043205636, 0.0024361752356136484, 0.03479357263339417, 0.019497015047818422, 0.05025976736630712, 0.04760398808866739, 0.05380674132278987, 0.026144503881888728, 0.01190053646652294, 0.016156746606741632, 0.06939861431185688, 0.08067815298480646, 0.07563353689121348, 0.048006746119686534, 0.05738930444100073, 0.0072636809033740845, 0.03978338006085583, 0.04345564211585692, 0.0332346045012985, 0.06880149671009608, 0.06755638495087624, 0.12280911153980664, 0.022719656050737416, 0.027887499192729592, 0.007107276037069303, 0.0035839201882481575, 0.015938935169417943, 0.023011683952063322, 0.050898360421082804, 0.0195308892122869, 0.0444863707359348, 0.050613816761012585, 0.0497775257432035, 0.05334377009421587, 0.019759604707360268, 0.002938986647807594, 0.024141755187883973, 0.0881877646648458, 0.05390696433771934, 0.03474524397669094, 0.01722369033710233, 0.027126932683001672, 0.01268578808022929, 0.008173706625322146, 0.015909262833052447, 0.08313445653766394, 0.027515141226883446, 0.008798080978782048, 0.06956571034554924, 0.012445824170884277, 0.035328767129353116, 0.03536650724709034, 0.08076461870223284, 0.019588422196518098, 0.051096848877412934, 0.0126961128387068, 0.0422899834146457, 0.05193869031167456, 0.028938042731689553, 0.02299519724744771, 0.10564116455082383, 0.07417452375271491, 0.010228639751273607, 0.029908900814396993, 0.013300506032205053, 0.02605181430200381, 0.04569918083559189, 0.06069480814039707, 0.04192282811605504, 0.017085888356502568, 0.023919867451435754, 0.03586295060813427, 0.026164111847590123, 0.05120143147983721, 0.05550584050693682, 0.03471397029768143, 0.01972668558093054, 0.019466961035504937, 0.03583549029592957, 0.02536227005267782, 0.04131061650280442, 0.0391653975072716, 0.021257240059120313, 0.05033959022590092, 0.01723698792713029, 0.01635561165000711, 0.05142001135806952, 0.0507562344760767, 0.029853199874716144, 0.02907859447545239, 0.0046363021330242705, 0.02899613550731114, 0.037237051874399185, 0.0653464642486402, 0.031207379352833544, 0.018450921002243246, 0.05435758962162903, 0.015806456296039478, 0.03549177498955812, 0.04317684564739466, 0.05798509889947517, 0.033644056280276606, 0.023936705297923515, 0.01763144408219627, 0.05656083353928157, 0.0593085882386991, 0.11114866366343838, 0.014048145601658948, 0.025950883914317404, 0.044896551940057955, 0.03839174884238413, 0.011150767145279263, 0.030958245042711496, 0.06323440186679363, 0.05067476277638759, 0.022842092605839883, 0.0321861593318837, 0.09069351306451218, 0.053749900444277694, 0.03300807558532272, 0.03999666736594268, 0.061686914547213485, 0.05553911586425134, 0.042736819080476246, 0.021160072148112313, 0.033001972162829976, 0.08198556104408843, 0.030165804350482564, 0.01566228287161461, 0.026507438692663397, 0.02929266548848578, 0.028684185817837715, 0.07522091974637338, 0.052666548040828536, 0.022091629482539635, 0.0018543588105655673, 0.05825649255088397, 0.0322373683697411, 0.030944480959858214, 0.04272416440237846, 0.03416303718196494, 0.045956002947475226, 0.05468054175642984, 0.062079582762505324, 0.046884109931332726, 0.050917084594922404, 0.05885812919586897, 0.044900612972144566, 0.03804013878107071, 0.03674156864040664, 0.014773837955934661, 0.06606073092137064, 0.016773180404145802, 0.0504338828447674, 0.05158063077500888, 0.06856010787721191, 0.08011543032314096, 0.0464110556723816, 0.04555641706766827, 0.01869144639931619, 0.0373283148344074, 0.030332218456481184, 0.034757508497153006, 0.05550784557791693, 0.03879197593778372, 0.023042131514687623, 0.015577365910368306, 0.014222704672387667, 0.033064695939953835, 0.027393647835456898, 0.03877544682472944, 0.016800654287050878, 0.04974299170342939, 0.016484898016122834, 0.0523079151420721, 0.009511960886551865, 0.006076076259237847, 0.02371859360885407, 0.10051108697163207, 0.06410070109580245, 0.02885258463876588, 0.017547646703730737, 0.02788505985933755, 0.01812801806123129, 0.06329577535923038, 0.006407243756776941, 0.04295381118676492, 0.03222114120477012, 0.13202247715422086, 0.042091294790485075, 0.03401996807328292, 0.04290197789669037, 0.059103881008923054, 0.021819754071267586, 0.028409382527960197, 0.029587353247084787, 0.016974147209631543, 0.06090026854404381, 0.022657615897644843, 0.13193866450871738, 0.07475121745041438, 0.0944054185279778, 0.09664980880916119, 0.17568643630615302, 0.20628029108047485, 0.08246080697114978, 0.17457287891634873, 0.15229448436626367, 0.2335973781134401, 0.06771623423056942, 0.09300497653228895, 0.148877083456942, 0.07589047774672508, 0.19147158999528202, 0.13119747356644698, 0.14944946845727308, 0.08189263567328453, 0.08998323617769138, 0.08245841174253396, 0.15809921574379715, 0.1307634554271187, 0.19006998091936111, 0.13866202373589787, 0.10404033759342772, 0.15373939754707472, 0.1735818920923131, 0.18137906012790544, 0.08443225654108183, 0.1435231707457985, 0.12845339652683052, 0.12763080852372305, 0.1723496996398483, 0.10442933493426867, 0.09076672020767416, 0.14549526492399828, 0.07165971691054956, 0.21473360247910023, 0.1672350112348795, 0.16471091524830886, 0.09932135045528412, 0.078051564283669, 0.08690724016300269, 0.14711424947849341, 0.15749702948544705, 0.1529906748660973, 0.1281161510518619, 0.22713530915124075, 0.1210650729813746, 0.08170133629547698, 0.12686962793980325, 0.0972670992570264, 0.11150555951254708, 0.07432550457971436, 0.06721172308815376, 0.07311098796448537, 0.11885984774146761, 0.1370033041707107, 0.17291110594357761, 0.10339374121810709, 0.17990226937191828, 0.1066383056874786, 0.08172938014779772, 0.17573025609765733, 0.17314211997602666, 0.07868221508605139, 0.11759868184370653, 0.1376316411686795, 0.1734746564179659, 0.09919141099921294, 0.18357793428003788, 0.09563166701367923, 0.11542217220578875, 0.1513811219483614, 0.0693511643580028, 0.05916028083967311, 0.10959574806370906, 0.07462482673249074, 0.12030671510313239, 0.12442284423325743, 0.15031392207103117, 0.17045299070222036, 0.17934413360697882, 0.3209946969790118, 0.09518951323947736, 0.09900774514036519, 0.09908576309680939, 0.17905524053743907, 0.10989627122346844, 0.11172896038208689, 0.1558042067502226, 0.10359259947602238, 0.15851720688598497, 0.1833730981286083, 0.22841399482318334, 0.1341655214450189, 0.10932455118745565, 0.1306144627077239, 0.1707088662577527, 0.13820565465305532, 0.10191321173416716, 0.16058462166360446, 0.18092035688459873, 0.14064310171774455, 0.17174432426691055, 0.11338365623461348, 0.06024227278040988, 0.17592758765178068, 0.11452806661171572, 0.11402523145079613, 0.18575414536254747, 0.14616207485752447, 0.057021395968539376, 0.12877175158688, 0.12223517947963305, 0.11157637142709323, 0.0973633833761726, 0.16837360656687192, 0.1136193046612399, 0.16893775415207657, 0.17621787850345882, 0.22525787060814245, 0.17693727490093025, 0.16263602301478386, 0.10113376498754535, 0.10957467955138002, 0.06986239299710308, 0.08273308950343303, 0.1235854234546423, 0.07923106849193573, 0.14292599207588605, 0.1337627973407507, 0.16084608834769043, 0.10341890129659857, 0.12745732069015503, 0.12858503232044832, 0.15320463052817754, 0.1332276232008423, 0.13305355182715825, 0.13425597016300472, 0.08768773185355322, 0.13450161341045583, 0.13024137701307023, 0.14311556118939603, 0.05715558983917747, 0.15402221094284738, 0.08793889159070593, 0.06478881024356399, 0.10681659076362848, 0.09512286074459553, 0.06545145397207566, 0.13924113980361394, 0.08387608174234629, 0.10967403743416071, 0.09529468616736786, 0.26918105727859903, 0.07994231568383318, 0.13745584631604807, 0.12662222050130367, 0.12332274897822312, 0.08062745284821306, 0.12896134784179075, 0.11737296038440295, 0.19187972880899906, 0.16428845934569836, 0.235979470291308, 0.10860370272504431, 0.08759818558714219, 0.107129598967731, 0.16919856944254466, 0.08612091307129179, 0.13331349859280245, 0.15904455073177814, 0.14973475172051362, 0.1368703113070556, 0.07527675639305796], [0.029131890008492128, 0.017894756381532977, 0.026468212583235333, 0.0077040874499029344, 0.044943438709846566, 0.04523202304595283, 0.015794939860435467, 0.05502978712320328, 0.05267004928152476, 0.04361773734646184, 0.004416318111387747, 0.04304977300177727, 0.08478968164750508, 0.02906015867899571, 0.03009403570156012, 0.03456375960792814, 0.03244993303503309, 0.027527517705623592, 0.08319497507597719, 0.01640428975224495, 0.025468128300937157, 0.011021885355668408, 0.018631675945860997, 0.0315423042380384, 0.07760358867900712, 0.057316504418849945, 0.01400495260687811, 0.0386136637202331, 0.029376362783036063, 0.04998598527163267, 0.007566410998281623, 0.05651390945006694, 0.007358617282339505, 0.03657575843057462, 0.022989165071131926, 0.005545500890418355, 0.02265803319668131, 0.030810046209288493, 0.04899648783196296, 0.022486251878685186, 0.0070948524849622375, 0.020930026724402393, 0.050851236164037666, 0.05049420800060034, 0.03346324026850717, 0.05452850580747638, 0.05980237852782011, 0.05354227551392146, 0.032503184463296614, 0.06055689589785678, 0.07932374959013291, 0.01152480618163411, 0.022720543235274296, 0.029203495809010098, 0.012398056153740202, 0.01388346854530807, 0.09598257818392344, 0.04852256504818797, 0.0301251736735659, 0.03464042727968522, 0.07128756759422165, 0.02813479636928865, 0.046514294775468965, 0.04178342648914882, 0.054785439877637794, 0.028233309475971118, 0.10542177382324423, 0.052864639554172754, 0.03911519609391689, 0.04600966488942504, 0.026590299692803195, 0.0704418754737292, 0.026794491235965064, 0.03704499253737075, 0.058472463461969576, 0.06684895112578358, 0.01613082317635417, 0.05518275945048247, 0.01780832459085754, 0.022510775830596685, 0.023442767427435944, 0.05285599501803517, 0.08285325126988546, 0.013869626430927642, 0.07400994508394174, 0.038411422965249846, 0.011771181398736579, 0.018128377684791173, 0.01340661957926516, 0.018745886960199902, 0.08242253081074782, 0.02261616419335561, 0.0687591154128313, 0.059365829452872276, 0.08123155936066594, 0.08955244786505188, 0.05659243291510003, 0.017763595562428236, 0.04129516965310488, 0.02523527034957494, 0.04552867855610592, 0.10099465852337224, 0.03472535272261926, 0.0074679360591939515, 0.036473778009946854, 0.007259105881010848, 0.052681533486715386, 0.024233705164598565, 0.03228355624846049, 0.01888676779344678, 0.04674249288759061, 0.07798516963209425, 0.04397869083498206, 0.0275790473512773, 0.03897335852629372, 0.02179490781522223, 0.018939228728413582, 0.026677337075982775, 0.03168316471523472, 0.026444993114897182, 0.024689614539965987, 0.09464416107428925, 0.06716042584074394, 0.0221071102589901, 0.047488287689962556, 0.01940607269560652, 0.033372886545423947, 0.02460560342296958, 0.04575159427310739, 0.032493294815399816, 0.0239218267213021, 0.026584632229059935, 0.03338312903153045, 0.050458941143006086, 0.05073960019009454, 0.022265448101929257, 0.03981829747291548, 0.014949973772412964, 0.04807795836989369, 0.08172029456389801, 0.015968117264232466, 0.00852783489972353, 0.02180059054600341, 0.04898494255862065, 0.03216461245236652, 0.027929291860865693, 0.04643732176295348, 0.02466437134093472, 0.03477764741650649, 0.08791986546878304, 0.03027313162705728, 0.006997665490156838, 0.03206685930490494, 0.020477180934644172, 0.03795552207157016, 0.04128277960366436, 0.02390083624050021, 0.03077885734715632, 0.0493184696616871, 0.01656615936995617, 0.03744858516646283, 0.07530919715229954, 0.053610620953674824, 0.0571442311629653, 0.038316329675061364, 0.018875614374077747, 0.02813225016663117, 0.06216530887676137, 0.03142773699281471, 0.02511714758085353, 0.07709913181939296, 0.02524230506138078, 0.05330944300762244, 0.055169005545654466, 0.056293721443840435, 0.01200663813922022, 0.028760704211890697, 0.016627580359844223, 0.027198591069983583, 0.02253128624787288, 0.015948215832135508, 0.03746608119191868, 0.05165254530896034, 0.04986953169905713, 0.0756418082330908, 0.03061743386621986, 0.01618361659348011, 0.1437419168651104, 0.01822990009428135, 0.03626155261216419, 0.021542718401178718, 0.04699518611388547, 0.012774118072619396, 0.08429236976163727, 0.09430612849869899, 0.05173242584403072, 0.011965524854271539, 0.029110451694577932, 0.02044295223562845, 0.019431916398129294, 0.059413082631570954, 0.05068766511976719, 0.0038037201572608736, 0.03101178484835795, 0.0676001776009798, 0.09136927287493433, 0.0287220955693296, 0.025901520491710732, 0.026449008345870034, 0.027218933549842665, 0.020635174421061362, 0.031654500003371916, 0.06794620331908975, 0.022791246584217464, 0.005933235732040235, 0.019332729845440814, 0.020970525086990426, 0.0378374230515744, 0.03763141303456255, 0.0299659282900393, 0.050321385131350586, 0.04608492120834334, 0.0695709486358932, 0.01743240261982594, 0.053530662387077294, 0.0411560971156827, 0.06969773968947784, 0.04919950890221766, 0.018360884494281242, 0.030713419429957867, 0.027893522887357643, 0.005890999047551304, 0.014162111495222365, 0.009812059113755822, 0.028679045915071453, 0.056060135763670714, 0.050268045493534634, 0.028916875831782818, 0.013924615757007684, 0.042310190187501054, 0.08856304881295987, 0.03488207395587649, 0.036459053800042183, 0.05537462540503059, 0.026243456339995776, 0.01223654022240745, 0.03294461899037872, 0.02384861109645239, 0.053257127957684655, 0.0468622814597828, 0.05128735776192375, 0.06260288932493754, 0.026065887118290578, 0.026407147824232067, 0.106973359494337, 0.05081248502912266, 0.016219775724623884, 0.0495938836330814, 0.04940439933644874, 0.011070954463710743, 0.07163908266063247, 0.016343370878270695, 0.043735300323792865, 0.04119607300630637, 0.04961899621412158, 0.05602300972012537, 0.036541282066277096, 0.03180031378620437, 0.05593677131193025, 0.01987542045701827, 0.03370747894846967, 0.06785595816160951, 0.07150062759007726, 0.016237095330974886, 0.0641467057700668, 0.044830140325107744, 0.07006400610719409, 0.1044377623392003, 0.060551291198602746, 0.05269433404984219, 0.04800066305324435, 0.048110874103648324, 0.02123526400620384, 0.0018709224864973553, 0.04037160885387233, 0.06704941751169306, 0.11661791375705174, 0.07510345176394496, 0.03172963418598686, 0.029705923848918507, 0.08589796003486429, 0.02050050048689757, 0.029520524333098104, 0.027320396587518708, 0.009173301514238119, 0.029142807636942183, 0.023217539602358426, 0.02349321311339736, 0.02958217941756759, 0.02038262877613306, 0.05131852287533028, 0.043750153455351076, 0.0489245258005602, 0.05129137468923416, 0.03021741033132587, 0.03976825551529016, 0.025162178557366133, 0.03336095450712102, 0.02945402790127056, 0.05752262978681496, 0.03195848369172641, 0.03294144005381635, 0.021447842242196202, 0.04162446948300515, 0.024315219272726347, 0.065620368479618, 0.020239632609965544, 0.0404313674329647, 0.028190996032208204, 0.017948531978098408, 0.0800884042733482, 0.03416628736470427, 0.07394481929285185, 0.04176212727491345, 0.009053573162028832, 0.06907335855066776, 0.046210819988378456, 0.015150670860228794, 0.015155542741662689, 0.03497877876673426, 0.027248298849112222, 0.050214729604444334, 0.02581477996760181, 0.023553757096773813, 0.04947448521852493, 0.04227780710373606, 0.018489149665193896, 0.049453979890261374, 0.08888361589717013, 0.03851336606645158, 0.005162955145351589, 0.025791131325864365, 0.057835956902376244, 0.005394682487738984, 0.04384068699021425, 0.014229701216598707, 0.06201466731727123, 0.029332559954907213, 0.04838703107088804, 0.039906697015144994, 0.022582088164719086, 0.019288124649652412, 0.1235434492783887, 0.07629409073186771, 0.11785481524254594, 0.07824377968375172, 0.21017069875129632, 0.08467995574963944, 0.15564393677881785, 0.0895716164793287, 0.14310686237045697, 0.09996153467467853, 0.1240501520889146, 0.2590401071522917, 0.2085544147661754, 0.11742068853761468, 0.1477872205099889, 0.08545764509056296, 0.13240674510598183, 0.2088634738964694, 0.09323285573295184, 0.17426255771092006, 0.08008125251425163, 0.1191345187170165, 0.13280766430710042, 0.10906004466648613, 0.1820013445935079, 0.12208157272211143, 0.09885934953178678, 0.09669960649417979, 0.16794536954590253, 0.11655185158763613, 0.0901983996321048, 0.12340668376002993, 0.11113752211843218, 0.12005185735012804, 0.17997631111315318, 0.15014719244624886, 0.11233695490019661, 0.15031533342386993, 0.11210857358361993, 0.08392564872545855, 0.07036760303058795, 0.12301951167838913, 0.10612053597079855, 0.18217929718749865, 0.11086376716515847, 0.17073674047631876, 0.18266591536147253, 0.07466291290308748, 0.14572726961757454, 0.10605209892881767, 0.16202645429543086, 0.13118729554116726, 0.05016813799738884, 0.09196778825883355, 0.11945439369550773, 0.0991753636460219, 0.1744326800107956, 0.09578646799283368, 0.10291291094784226, 0.12012638763657638, 0.1527885664254427, 0.11998184610690389, 0.1058272799210889, 0.08552399903003659, 0.1821915108178343, 0.10000945960304566, 0.1915157354835953, 0.16412953287363052, 0.08485383713351828, 0.112135647130864, 0.11081006111843245, 0.12855023704469204, 0.1245003736444882, 0.13556566488529953, 0.14009903876909188, 0.20848296502871172, 0.07965792130146708, 0.12131245327847344, 0.2241839939462287, 0.12923128264290945, 0.041863327380269766, 0.11724450013467244, 0.1997134427406958, 0.13303821693573678, 0.1586417452033077, 0.13082830980420113, 0.1257161862616028, 0.1256425923534802, 0.12602786453706877, 0.08947509487292596, 0.11975976159530026, 0.16909422432737692, 0.13202896394899913, 0.12786518808986458, 0.18916022830775805, 0.2579353435763291, 0.11669314971991948, 0.07535972765513829, 0.21950127450483187, 0.09603336653006928, 0.27707258239388466, 0.17522968724370003, 0.1692605604018484, 0.20602761821023055, 0.16909426503947803, 0.07416302258414881, 0.17941361559288843, 0.10539772654218332, 0.1456532957298415, 0.15126843085246428, 0.22617233225277492, 0.21812198923102447, 0.14790171650903566, 0.10809087274330002, 0.21238578989037446, 0.08699178562632628, 0.15957815067044326, 0.12181315783943449, 0.08175063864993197, 0.10914390480944089, 0.08748814756316797, 0.19642412210149424, 0.10218063595571689, 0.12520242668688297, 0.14921065127210958, 0.09148549235292844, 0.06839981754975659, 0.08660293077783925, 0.08726552700889961, 0.15141557795660837, 0.11826931871473789, 0.09753474739513227, 0.10443772162709918, 0.12549844437411853, 0.16904959029385022, 0.08904373659087078, 0.12708190083503723, 0.11977517791092396, 0.13757700552897795, 0.10581959890467779, 0.0845782704917448, 0.11877025397760527, 0.08941977391285555, 0.1299453864672354, 0.15860350296965667, 0.13776014213051113, 0.15592506740774426, 0.1733322183468512, 0.0863878894597292, 0.19423685089818069, 0.14813566181276525, 0.10619078470127923, 0.11683861405721732, 0.061005787524793825, 0.0699497340247035, 0.09286791245852198, 0.06693150848150253, 0.10018221461879355, 0.13776831169213566, 0.14923476640667233, 0.10333053568111998, 0.15029837004840374, 0.1781493012926408, 0.09249106767986502, 0.09079158173075744, 0.09076560741024357, 0.2950793547289712, 0.18092018046549388, 0.1516972514135497, 0.05078973374994738, 0.16224849809493336, 0.09300393158836023, 0.14330515744430677, 0.1581430762474026, 0.10006512661597558, 0.09357925464532205], [0.041258606793625016, 0.024915020480485897, 0.043441179141934426, 0.0455237184651196, 0.03115341207012534, 0.01710172027482518, 0.017301022973177687, 0.02039363461413554, 0.03943503036030701, 0.06964277835296732, 0.01417230733204633, 0.010298991958344621, 0.0398363091849855, 0.013061022186385733, 0.02448046629849289, 0.039682895809944184, 0.0078077735379338264, 0.023177263459989002, 0.01906149395342384, 0.04991948205445494, 0.054435258132538626, 0.05346681563449757, 0.013942854778308953, 0.024980003779221858, 0.039365487306245735, 0.03433242327134524, 0.046349482012114356, 0.04828536616904395, 0.02197132522373327, 0.05784144625067711, 0.048929869263832054, 0.04904768669179507, 0.02680177870206535, 0.025241516264421598, 0.08057384858173983, 0.037428375000932386, 0.009552586474455893, 0.036625780032149384, 0.0465215551001685, 0.07373743863510233, 0.12470561691692897, 0.06613839603960514, 0.029154814314097166, 0.0927475674876145, 0.02705218017633472, 0.08772517341588225, 0.007681589773190873, 0.02794277774436133, 0.029655810645116226, 0.08982905945075409, 0.04356257584212082, 0.010618635386760746, 0.034723686919148476, 0.03227491510499801, 0.03437781726409282, 0.03958204175744738, 0.021745641083855714, 0.02616407283182655, 0.030179242736526897, 0.06127912178635597, 0.0023484949405038996, 0.021051672786208134, 0.031661163217255046, 0.002598797603111182, 0.029979777189769914, 0.01572575473359653, 0.013860501831264367, 0.019679176255262325, 0.0692227448203734, 0.045209529610084634, 0.03185063733586243, 0.03090580107112016, 0.04414509476295539, 0.015026750009773033, 0.05431604292243719, 0.030438371867473637, 0.029105997112180506, 0.030072000276829516, 0.027399988745206168, 0.012140288333674627, 0.03795563063717314, 0.04943337956709521, 0.08506731782108545, 0.05174015096521803, 0.03564854711294174, 0.07309559200491224, 0.03368927385391934, 0.07180670795163938, 0.02717181438181017, 0.06393979330148016, 0.08770016940044505, 0.016169821976550987, 0.022746480236362134, 0.023015225904860666, 0.03191477585850017, 0.025266477871420126, 0.01947572431527078, 0.05464802635833621, 0.006021578446961939, 0.025705026928335428, 0.033353242956634076, 0.026199724758043885, 0.020744891837239265, 0.02466120258239763, 0.03751955653673836, 0.02091274443747742, 0.03263580413269145, 0.04426913096436432, 0.021152158733457327, 0.012226027170462268, 0.02447863425394254, 0.04819443229851978, 0.057144482220922194, 0.028264131929193224, 0.022581774342272962, 0.05081466312653252, 0.03935842375670161, 0.04396379020597253, 0.010484566196932324, 0.03536786770980273, 0.06125739509505885, 0.005917928830188299, 0.031217506487986872, 0.05616249616390892, 0.020892517308571508, 0.051977017362202914, 0.031821948875273974, 0.0271063103074474, 0.020735970798081586, 0.08489606236772877, 0.05695569342268365, 0.02031253950138177, 0.029681041969784668, 0.010039771225170364, 0.02572154755970197, 0.049557096857045374, 0.03891376958095601, 0.014112282427959144, 0.022475698962807655, 0.02519235131330788, 0.027021630833457624, 0.03183305988620434, 0.07131096348166466, 0.03938348205494029, 0.02468731769892786, 0.036865146830677986, 0.05409355128982237, 0.06932504075978484, 0.031408609090639014, 0.07200049076761518, 0.03989090071991086, 0.04644407657906413, 0.0027963392910481033, 0.008371761667409112, 0.016396428924053907, 0.03467702067324093, 0.011356554942072501, 0.017223697122452513, 0.012221056901450669, 0.07522938107805592, 0.059284690235342295, 0.010179128747300377, 0.02179691967155252, 0.026919029553287795, 0.07162438559212855, 0.01483846502378583, 0.012063803866372576, 0.025501826046300784, 0.021897816132487993, 0.04027285147458315, 0.006154184121572013, 0.03381739144346543, 0.007005908842464643, 0.010945068406207221, 0.05244397159133639, 0.03216957254335284, 0.09243375182683979, 0.0022134813147463967, 0.03237336375085371, 0.05921290123036929, 0.05258650805002876, 0.014489083950008665, 0.009793396008067896, 0.012315219750494828, 0.0339188731408545, 0.03878477328856077, 0.008968012440683586, 0.08706496562808752, 0.029763589147478342, 0.011776104170296873, 0.01714411853546543, 0.012300460765670453, 0.037229621915944984, 0.056391617083655934, 0.07662647789610283, 0.038501668122730086, 0.04073927644640207, 0.06184637706194605, 0.023083021731248925, 0.013903281767852604, 0.0683191397360393, 0.025738509238830636, 0.009288350519325052, 0.07010569529873983, 0.05823694395699671, 0.0043636718515439755, 0.07563256658613682, 0.07383790252996342, 0.02379188726523093, 0.03605569526553154, 0.04112255712971091, 0.03285361387367759, 0.01048770866223744, 0.027831565854804854, 0.1371946239045688, 0.07314597323004689, 0.005709959967394492, 0.029314344682331597, 0.06593366166842834, 0.04762280047205942, 0.05783224531582423, 0.021411116534311856, 0.06811273616871663, 0.07564141468277999, 0.05696614964732102, 0.026334955090922967, 0.05217099016798394, 0.026474908027531843, 0.0301816515358431, 0.038271546363830566, 0.008126967436900097, 0.050221952609717846, 0.009046762366779149, 0.017419569826285754, 0.02145141133639429, 0.010904238409628826, 0.031767530366778374, 0.04734170716255903, 0.0353347993056689, 0.019981270223589878, 0.058020185945289474, 0.06382974170680557, 0.05028098515634026, 0.0356078010850719, 0.0418483996098595, 0.03083797131798097, 0.019009236578962634, 0.05205926259181329, 0.05852270219475031, 0.06067209757332291, 0.038521064046238146, 0.047148328074919324, 0.011318128655797668, 0.029249011938061033, 0.01626087798337851, 0.03768721914717129, 0.05128461987312351, 0.03154484535168324, 0.0496540289771344, 0.027605542447417974, 0.04656736978462764, 0.021603649149515798, 0.05513614070202623, 0.04220054910651275, 0.04372711379879287, 0.07594899460673332, 0.015456301692341055, 0.02377669995517603, 0.009493135780628239, 0.05605242082050868, 0.09001709507512194, 0.026246592868119478, 0.043092303576746156, 0.04107759061402508, 0.048158147638397555, 0.03613682769771133, 0.04922155111229845, 0.028847695793956518, 0.024745213699394038, 0.027399408597765223, 0.043633479358894486, 0.04440470226109028, 0.059601600015802045, 0.016799751835476075, 0.02930482822869505, 0.015148767569501485, 0.013633059437519737, 0.024164199429963316, 0.05450508617130773, 0.013021103123069873, 0.01427421735466591, 0.04250086531309145, 0.037451272165136676, 0.009727897022717764, 0.06477815045842103, 0.0352659178232508, 0.06842938132051911, 0.04022413266024419, 0.018370110874197314, 0.011211706375304078, 0.03584091518340366, 0.026028557514239634, 0.008553929660203201, 0.016462928748556545, 0.024684237149943198, 0.02741829053099666, 0.029051690561962978, 0.037001671469105143, 0.007477243863312262, 0.01933867550854172, 0.05173299242077129, 0.007862165753197457, 0.01290543919562229, 0.03315675278593387, 0.038750195144010444, 0.05218904259215508, 0.03554621724677937, 0.02252046700700053, 0.053345368044184785, 0.03382818354293704, 0.02282204868138901, 0.029540147565837418, 0.02697664056904614, 0.04747909354045987, 0.03049467670332108, 0.05107734099562679, 0.033211269682007175, 0.026088636701128314, 0.07196731040520327, 0.0631631760458861, 0.07959810165422303, 0.07625909868095603, 0.02172151068225503, 0.06966445754681315, 0.002640547014639846, 0.04029529062764985, 0.026787320817155496, 0.016475264515195574, 0.034041664230504205, 0.027092191690046872, 0.04798891421939645, 0.04517708545816796, 0.03986890600728137, 0.043849735254687924, 0.03219708374568394, 0.07333791721612215, 0.026298855331593325, 0.02442002748804433, 0.06887956894934177, 0.018136474303901196, 0.07046447068985019, 0.06657193920442037, 0.1938544014202697, 0.05318177664386375, 0.2468240883733545, 0.1419358059231724, 0.15031139792076179, 0.11923986806401185, 0.11358997159238372, 0.0929185040295124, 0.13490790660892213, 0.13538904221994535, 0.07268287986516953, 0.2957641865525927, 0.11974425028477396, 0.10596765524574689, 0.06929321068206004, 0.11193995084613562, 0.08694123476743698, 0.11208376634333815, 0.10266746447554656, 0.13392472293760094, 0.12611525984747068, 0.1187868102320603, 0.15128303292606557, 0.13077849176313194, 0.15274279245308467, 0.10550772385405642, 0.16175198688038758, 0.10185085436595337, 0.12270255440047809, 0.08477256899433476, 0.15098728665283748, 0.17461348245186464, 0.08807890050645385, 0.06678217649459839, 0.1932088839156287, 0.16680974619729177, 0.09471559045570237, 0.12159656946148191, 0.20303721938814434, 0.1452764780925853, 0.15064214303025178, 0.16369090069617542, 0.09831382773284401, 0.21676095654921873, 0.13157454904701027, 0.17277340404689312, 0.13386763100113186, 0.11266305204480886, 0.14778324429477963, 0.19828134030103683, 0.10236861051193305, 0.07273275897439037, 0.11339548988533871, 0.12951774655708245, 0.11036765628627368, 0.1140086751963411, 0.09392912087163754, 0.10563633338149105, 0.08983485413981335, 0.1038317559286952, 0.11546353570052556, 0.10119934539709773, 0.09973175557596342, 0.09868054198367254, 0.17094803628112587, 0.1697575601616076, 0.11131588861878429, 0.11261214156235967, 0.2105866950005293, 0.07245183190596954, 0.12216292907084737, 0.1295077856630087, 0.11251138589744057, 0.09876544707055603, 0.11691589919584137, 0.12989216218037264, 0.14934895027961048, 0.10997437060411487, 0.07591986509838275, 0.15083989527608666, 0.1147918945976666, 0.12988729029893875, 0.19879469275474548, 0.11353498311447245, 0.11466228083840438, 0.15837573233459676, 0.09945000069481985, 0.12229285495621817, 0.10711496296737875, 0.1288779423172985, 0.14558590363178933, 0.08420278278312512, 0.06839697448802845, 0.1524470326091562, 0.13726607364203247, 0.14163095370999404, 0.14609260644231523, 0.13555636895554407, 0.09487362126154558, 0.1293713729828596, 0.17423316357391222, 0.24587848197136605, 0.1380322618143899, 0.22412789267088684, 0.13561947271227837, 0.15977268666028976, 0.14139288291335106, 0.14271936459200724, 0.0701263974021588, 0.11536843223231179, 0.06173902603664568, 0.13219107953565462, 0.12135817296802998, 0.10257657470979861, 0.17218459849911077, 0.09873238205909729, 0.18878103579793656, 0.1211816452975784, 0.15658042367015565, 0.131988061858075, 0.114473607391119, 0.08293636502431971, 0.11069899850658008, 0.17021049585725578, 0.08613248209335975, 0.19523747291948113, 0.08394702936389617, 0.10860630151416574, 0.10318424353109938, 0.15494572424462863, 0.23066333841000283, 0.15717228262552194, 0.12102977558970451, 0.08218722165163074, 0.11908522993326187, 0.11578323425991194, 0.1036158325150609, 0.06857156833367688, 0.14595156615333899, 0.08351507397102458, 0.07259725553116628, 0.13384834703590187, 0.18147794982152327, 0.08662771087672029, 0.10378242643283946, 0.14135047447468552, 0.10757348300623042, 0.17614675446280412, 0.12140515473272119, 0.1573844062430518, 0.10323585290461779, 0.12674479106707232, 0.1407727561891079, 0.1561613604426384, 0.148531383435641, 0.1578355370355504, 0.11847416843686785, 0.09802347581301417, 0.10479066840239934, 0.2413598730095795, 0.348944857184376, 0.12676402074950083, 0.10025618172117642, 0.12617699296346732, 0.17372414017362253, 0.12635343920971664, 0.11891596258750983, 0.08219560834446124, 0.13638476521841117, 0.15991471761039325, 0.10095427890441247, 0.08509975179497685, 0.18954389914870262, 0.07092655303754977, 0.17468627568866524, 0.10185166860797576], [0.01997675626937832, 0.053873970572437556, 0.0691499990810241, 0.1163584283952202, 0.019110328118715967, 0.06942521966993809, 0.041475381768707714, 0.06262076872267894, 0.034620454601411305, 0.020202610043010542, 0.04270992195233703, 0.024946930286075388, 0.022776681830042174, 0.02278251214218991, 0.052284892448889356, 0.029913202726415226, 0.010354707316894616, 0.05476853417764817, 0.02108784039903964, 0.04391282883339694, 0.041522974214915714, 0.07725138150687728, 0.023049047482865195, 0.01810096826271287, 0.03737160197592207, 0.05097761331126094, 0.05138770291315658, 0.01378835320273148, 0.044011399615556, 0.05248575917045985, 0.03025998840374606, 0.02676909027754196, 0.017740167444571853, 0.07795320384736572, 0.047729893654052696, 0.051352130714803934, 0.01914920817528452, 0.001246063510604602, 0.03533738452408995, 0.02031142500761364, 0.06788110466940062, 0.04094081152496593, 0.032118563673325946, 0.02874288588230099, 0.03392610293147819, 0.055142193234392574, 0.06724661335881267, 0.04189306078478694, 0.12384204539869513, 0.028181837505793998, 0.010498897704694952, 0.036244070157408714, 0.07914386317133904, 0.05343366241348641, 0.06253652860011373, 0.014900740967797381, 0.03857929592153855, 0.04260587878525257, 0.022773251835522906, 0.0051951821660622954, 0.03200445443923984, 0.015352741981457387, 0.041916287038475275, 0.036688286678067276, 0.013679608636136566, 0.015863644923748713, 0.060014624281653335, 0.008797029249503143, 0.029673021685864245, 0.03972716343456081, 0.03991488354014499, 0.004559196382095771, 0.045974951037870984, 0.039840665379805226, 0.07465542866183178, 0.009688767604529858, 0.03434717801532575, 0.010675850307701953, 0.022538383724167943, 0.03973461714174066, 0.0665862834347146, 0.02375485621658819, 0.029596109741500447, 0.05770109128206968, 0.034386780711689165, 0.01796311030297407, 0.0771497166050332, 0.0775939127696412, 0.04388958222365805, 0.031927389824496846, 0.014277710113674402, 0.07379661367407866, 0.01988892160755183, 0.026798307995444963, 0.05934943604682173, 0.012508517413932298, 0.02559868013486266, 0.05769077754978623, 0.06844301308904376, 0.04892067172165428, 0.05384881727929626, 0.02302356849291495, 0.049656254571995566, 0.03867248592099973, 0.02501119942670422, 0.02139731852470764, 0.053176249976136854, 0.0043078487755597705, 0.06344276640032019, 0.023582645725192766, 0.06157097326857703, 0.05062495152066861, 0.027629060471164327, 0.021599864620449286, 0.01803477547530617, 0.027643911906384995, 0.044073906261473894, 0.013328301371075213, 0.04612135175349457, 0.028378911216610243, 0.05445574649742671, 0.05487368335681302, 0.010006995439263327, 0.037604095214711766, 0.018138345364215117, 0.07273953075387649, 0.028176587341087203, 0.017971191655046174, 0.08690405783376523, 0.02739949002196746, 0.018542141553812792, 0.058013081683644226, 0.04277744297204273, 0.026470429696408764, 0.039414447000516314, 0.0396791231552405, 0.04712341566170965, 0.01693916194407003, 0.038112772562141926, 0.030795790188546692, 0.05270454939454794, 0.03373248974925705, 0.04899561930713909, 0.012252747879496642, 0.020167490766782845, 0.029899106161402803, 0.019079680388261164, 0.04589739448523947, 0.05286284822172352, 0.014080888308983828, 0.06854707321950368, 0.02081264186251376, 0.037989903440965075, 0.04506921535357833, 0.09829996526241302, 0.054420438927731345, 0.046399106670703204, 0.049417617198612006, 0.010548586824110575, 0.02814231623363282, 0.012763978214934468, 0.033318257691072564, 0.04104930927444782, 0.03679390743907009, 0.09217839874327183, 0.04159886496407645, 0.030746328378362314, 0.03284273695732866, 0.06248381321451493, 0.03646467885534678, 0.04629186081833073, 0.018446719174140265, 0.10763189130063568, 0.06573259817170245, 0.04981509283451097, 0.01887809102689581, 0.03739270780767713, 0.0011129628234942044, 0.05624516208523086, 0.03492475041587438, 0.07803289099995579, 0.059529064622308524, 0.02549075405113399, 0.012020426818967929, 0.020869932270475795, 0.0090004871266761, 0.03493427365486111, 0.04532309601615582, 0.02592929293002401, 0.0029045094353412943, 0.019698188806484853, 0.03794586991092988, 0.020114300406670997, 0.021894074011860148, 0.019659100100398064, 0.08507655946803944, 0.06789088235901934, 0.06765042990446091, 0.03369409145255174, 0.005257173973534788, 0.017299307975918055, 0.01678435587590294, 0.053388136106410196, 0.01636070914433471, 0.009816629895275193, 0.046491994722081084, 0.026219332723745277, 0.026272558706945608, 0.044837661885789463, 0.07689597843480961, 0.03135266048567636, 0.03415268613025546, 0.02097741900277989, 0.015884900033207874, 0.04988627455064228, 0.0292003304431481, 0.07766854483634233, 0.06730318282331739, 0.016665926070085595, 0.018834681749077778, 0.024804047774523497, 0.0521389802784792, 0.0455843116422849, 0.01807684464646237, 0.04635134119806545, 0.040486488225204606, 0.016430331926260675, 0.009743616134593529, 0.07872330038143055, 0.05186365790931242, 0.014894028560125401, 0.04598906456625887, 0.0260593239883227, 0.07029520334409815, 0.020093639015353153, 0.015789311412455778, 0.016609188668163757, 0.049666466524026225, 0.041564900893718004, 0.01430703470084284, 0.017430602805688977, 0.0109847644011357, 0.0354218994533377, 0.02479489772979702, 0.016196920968858258, 0.09915994733039822, 0.04895137882392321, 0.08649968488940171, 0.013496429626164692, 0.032071344421378205, 0.042959276786340136, 0.013185019372031093, 0.027938679392848696, 0.02842367926080312, 0.025703668161960583, 0.03875916876963206, 0.03339779895863362, 0.0558353337193174, 0.03165889012494257, 0.03680588018947414, 0.04396627703681588, 0.003009468624700925, 0.03245174472353288, 0.039444692698972564, 0.03402387982766543, 0.06359995582274028, 0.03139252441802195, 0.09808734631431953, 0.016666501128513898, 0.05570172678147044, 0.05631290362881763, 0.043867204138743024, 0.03098753061411636, 0.07119721387113843, 0.032549698038824966, 0.06940034457615443, 0.025420864944213202, 0.05647686483072383, 0.03794905224016734, 0.06425390073231288, 0.016126779107643024, 0.048906208747731786, 0.02351927903613874, 0.04548292833247355, 0.008389558792779488, 0.017240575681041394, 0.012448537462790097, 0.052027181456131597, 0.024009037130911435, 0.06298193255705492, 0.08252865368766443, 0.04090284409799746, 0.051303079418305836, 0.0579326684985842, 0.037847556972077916, 0.02882910393444555, 0.029778554237314632, 0.06237356484468494, 0.11108152940869331, 0.040077986395252604, 0.018727503750207167, 0.029498349808688675, 0.03242661178644214, 0.04303308104031852, 0.1107517003214785, 0.02267847745679319, 0.010603604139760137, 0.007763469442059951, 0.008516594967139619, 0.04193214100918599, 0.05220292541863663, 0.055715718173554966, 0.05573600637061255, 0.018041986606216857, 0.08092271736157791, 0.044349615395601304, 0.03338754968717694, 0.010734436717549605, 0.07766965763377291, 0.02802212054042944, 0.020879854148785983, 0.010986385251661497, 0.03392456265698586, 0.08061821120125906, 0.062268215497689586, 0.016856937070510218, 0.08672953862696886, 0.03518082953191229, 0.04302322531917265, 0.03783709056941526, 0.044175113152180395, 0.05758841375687292, 0.05693796330264636, 0.023803907513086284, 0.06927216931113175, 0.035214590041765144, 0.013499160729614752, 0.03221526509150863, 0.0035425034709208247, 0.021383637562394142, 0.019683461203905087, 0.02524457815369325, 0.03363804446001138, 0.026924632556204284, 0.012955342901737561, 0.016804225077586513, 0.018635231469358717, 0.009052657139753657, 0.04817852743768266, 0.03773620937551771, 0.026794842377837216, 0.046575203471417935, 0.15957764855452947, 0.15421705905880245, 0.2066587507724762, 0.21621175030512468, 0.11735668911465577, 0.1966483372130564, 0.14356846974364348, 0.14519642453108514, 0.09697809083653347, 0.14845259194927557, 0.11940201079206807, 0.20819466906998838, 0.1037519805665527, 0.12906964203076704, 0.12260606672082629, 0.10929523847465004, 0.11632492233599935, 0.15679260157048702, 0.11337881827993052, 0.13066107806350502, 0.14744354252304348, 0.12012659119708197, 0.13778524792620114, 0.10987493808248214, 0.10064374735312802, 0.10535839865250246, 0.12975862648870262, 0.07483290628130947, 0.07169213731374059, 0.14745452121964522, 0.06325870020581142, 0.1223481148481369, 0.14576932521803038, 0.2645067652421338, 0.12108492691602026, 0.1787735263683966, 0.12881329150072166, 0.17357140194092477, 0.1486031860113144, 0.15170847438275814, 0.17792780032115324, 0.13662510232201644, 0.12233586050570011, 0.11336009749876601, 0.12330602987536363, 0.13738773497087614, 0.19451534881123475, 0.09878775730196919, 0.19837861508131027, 0.1553444992750883, 0.07576207177979605, 0.10068606079689094, 0.22680214845708438, 0.18542090324418886, 0.1071200587653688, 0.10964977980724402, 0.1295591914760215, 0.1806649970156806, 0.0853281466822539, 0.05661310109176806, 0.08032863959670067, 0.13133706179048332, 0.11935000786823885, 0.10587456024118833, 0.12230942478137356, 0.1548620065940278, 0.15089934851442063, 0.22002252510615758, 0.08639766036399774, 0.17049957891660078, 0.1318389062902757, 0.13685721558119568, 0.14948591935847486, 0.0935663285532168, 0.15288050792046956, 0.08664751731391464, 0.1368558585111584, 0.08189085791153566, 0.09454467426985502, 0.08416270171957356, 0.14056588443262236, 0.1722841260156461, 0.1901879103056022, 0.14898289420775004, 0.13940398820808955, 0.12727740034461021, 0.09372076990881137, 0.15524993863488945, 0.12859320188207285, 0.17097991385630198, 0.1176081406218665, 0.18292130237179144, 0.14707561369453157, 0.16542189781154903, 0.17371736839413643, 0.11052568030676671, 0.15427235966282232, 0.14645851323647158, 0.1372841905270304, 0.1768530279930149, 0.10482033395341464, 0.1145093526159014, 0.25010051684720175, 0.12587501773876802, 0.09584611122097288, 0.18621687910386495, 0.1936897345419441, 0.14723365807107516, 0.1727917787751981, 0.1391375410769667, 0.11130959859916142, 0.19556639955512115, 0.09393324636455093, 0.12017815985849925, 0.11976288285638605, 0.16405250557831355, 0.1753728717033352, 0.11410717133964811, 0.11990682727524213, 0.10214577961180892, 0.11544987000524998, 0.15222291249249661, 0.1667858889060361, 0.17595166207424232, 0.060281166407678805, 0.14643750579229423, 0.11662957098867212, 0.11047948564269713, 0.22349712651755127, 0.14971035160124302, 0.06358970994395868, 0.1310143233942134, 0.1818143810544695, 0.10887088267398731, 0.1449466829321214, 0.15330550154404982, 0.09834263832973582, 0.11240717648927655, 0.11339830580566611, 0.11687957043094294, 0.12674291831042084, 0.08635477695081915, 0.12382079368191105, 0.2058119119278022, 0.13213326835206576, 0.10398414132318326, 0.10446975526532956, 0.1371968223580292, 0.1682893189468554, 0.09710139422012226, 0.12404924285198961, 0.08139677585235663, 0.11966541808630739, 0.1840782995734896, 0.1149719235088144, 0.16282001457044057, 0.12236311047204904, 0.11336037569812366, 0.09830130876174994, 0.11182130221277475, 0.1015318004148347, 0.11209028706486736, 0.11639293868626867, 0.1800587802593197, 0.10190373259995665, 0.13658272102475166, 0.09410426433065108, 0.11706603185406753, 0.11144725978374481, 0.13884141482412815, 0.11017865035682917, 0.06031115087015288, 0.11966977428112711, 0.17159070393868855, 0.0986147987257157, 0.0907641892720546], [0.054963253371949704, 0.0542925418620663, 0.03980196174234152, 0.02861874450796417, 0.06453078373202256, 0.02587175146410508, 0.02861308891858373, 0.03593418321439198, 0.07409094859446798, 0.032018659569855244, 0.06530240696987935, 0.02906927140429616, 0.07034390858773674, 0.011191020387091806, 0.04687707352318934, 0.021832356162901436, 0.03119525732472539, 0.031160282237189155, 0.00493035715771839, 0.0016764314495958388, 0.05182359380913632, 0.06718436455620186, 0.017415194971753017, 0.029034197929182222, 0.027476519013621976, 0.002932712955433609, 0.05496553324961236, 0.04630885812054787, 0.05081670551693865, 0.04281275732708829, 0.043382662281926186, 0.03167570083002959, 0.06391664847199406, 0.016245956998318434, 0.03688997103433524, 0.03343300135540111, 0.049719019061220546, 0.022041433158197572, 0.026115599986431853, 0.04788946473438825, 0.011441711086912878, 0.025630849480096782, 0.05014152924663254, 0.03395138853894813, 0.025656274187245538, 0.015856812076110924, 0.07081473725182669, 0.014831428615642446, 0.09712181812418358, 0.022658328359414424, 0.0033349381244209197, 0.06277181061783008, 0.04876224397282515, 0.01342681617409523, 0.013572624019746269, 0.021161934726738503, 0.026236854194264327, 0.030540823869939362, 0.00424984293723745, 0.007155487646481821, 0.02274406634803329, 0.006703178747557104, 0.018116281101746217, 0.06077995749988726, 0.037490277750683684, 0.030425710404025655, 0.022975618119484613, 0.03202753820057426, 0.06414547083633286, 0.02460803766734898, 0.014976752156923925, 0.009351185406558216, 0.016821342819769467, 0.057248915545642376, 0.059424943423696926, 0.07522606982716493, 0.06116240019244807, 0.11077291132616145, 0.05201451999268361, 0.04541947173752955, 0.04143993849200862, 0.04311876644247344, 0.04529720990519438, 0.05307094473391771, 0.04266922342191849, 0.03620436228811741, 0.02328006660432688, 0.002875992940971628, 0.046904367594314475, 0.031004388816654682, 0.030362552364489863, 0.027548864417310272, 0.05427862171615873, 0.036712866609117815, 0.1398445881370987, 0.019443717818441134, 0.02615615093548383, 0.06061354000121355, 0.030149499153984443, 0.011095402080432644, 0.037365213568721495, 0.025528553540685346, 0.022803183711533035, 0.015592456529183047, 0.02415491876724575, 0.06978765915014915, 0.056214665328817706, 0.06727889805499997, 0.040551882037626844, 0.011617768871864038, 0.03278064761044724, 0.053816217064325295, 0.05922470773969378, 0.011607757935832654, 0.010879580447051142, 0.02533822107527937, 0.04575922779206719, 0.045622937248221467, 0.04090206378272601, 0.050886855859841616, 0.0444420420431665, 0.05037261452525854, 0.030239357546504055, 0.02417264549460794, 0.054838555598897595, 0.036032469011843204, 0.026506532848413502, 0.04701284498774579, 0.042614435111837726, 0.01294808681788189, 0.055591139144131115, 0.03153289635000484, 0.021143892480592643, 0.017316681865070547, 0.00962731777690351, 0.06261684000492096, 0.03680541878566146, 0.025808927603065968, 0.029120351520500014, 0.03692847789664354, 0.01067353819962591, 0.05920399206557444, 0.039379627976034365, 0.04432304396427103, 0.017353977542370558, 0.021952869071226035, 0.03389549421678696, 0.049535682291856835, 0.07768670921879155, 0.018661809686039175, 0.047655044456145594, 0.014823762866269265, 0.02313540463468858, 0.051920549677951, 0.023625668238050172, 0.03784750947462661, 0.042552420403808355, 0.017487911873364022, 0.026288609452811734, 0.05323253106325865, 0.012612353627836066, 0.0634743861321892, 0.029799955231802802, 0.03818654967471957, 0.04650839491348181, 0.028222714151654924, 0.022187657454716306, 0.1274151022412947, 0.027658963509436165, 0.022000950062647462, 0.02052051218093506, 0.011125489171328289, 0.02701598033308983, 0.09053168246256453, 0.036623439086335044, 0.019503944586696367, 0.00309978736082225, 0.006569945852139166, 0.046752942326877794, 0.04175192889358316, 0.030639808558459793, 0.009069194734495665, 0.0396613998205534, 0.08502525543527943, 0.05176283439089145, 0.06551605050585099, 0.05801643364663635, 0.01603829474853618, 0.06821655202656984, 0.0373058722886656, 0.019416849528040205, 0.02459423796140722, 0.041078767872282436, 0.020499933910157, 0.021298014924728444, 0.05338208357404385, 0.05240062338167003, 0.01372585419033255, 0.013279528273934764, 0.054468234934444935, 0.03680929322061794, 0.03647263128576534, 0.033633298107555935, 0.028536282147147825, 0.008758664031379988, 0.005960746510286948, 0.013634929649664887, 0.059816899177219184, 0.048096241495971165, 0.06433596954281841, 0.03149253369442054, 0.022123875162963356, 0.02753799089363643, 0.02282826236582228, 0.058825512017522535, 0.014619740956862057, 0.030256958744887794, 0.01946734101511538, 0.020673713513783047, 0.0318246969420995, 0.08376160609935011, 0.023702878737822175, 0.10320874543062278, 0.043432541391147036, 0.0733276034838387, 0.06425108481198549, 0.05064791314569967, 0.015790739728670036, 0.06167433450796774, 0.014620439847931266, 0.05394796820889626, 0.016996111388185194, 0.0353634640175317, 0.02480208850465715, 0.009880003369679409, 0.04278504256425159, 0.029901565850845406, 0.0821958254756672, 0.014007383458582419, 0.011273857638505953, 0.0023099840493939284, 0.029691087680735757, 0.0195758184085467, 0.02299091569148004, 0.015165815761845027, 0.024779608639489328, 0.040640651381441524, 0.007817558012902737, 0.021616571848945956, 0.00963990799417453, 0.02538727067543992, 0.06529032226119723, 0.03326248550521476, 0.036696849790002616, 0.03639239112713507, 0.04156323169757213, 0.0342247092298099, 0.059277131355234554, 0.0517282189269151, 0.005434527336287179, 0.03569675702601671, 0.019273950053112845, 0.026230084111115763, 0.01880726045263665, 0.03181440356586661, 0.044533294825149436, 0.034676206431218555, 0.021126018171863895, 0.05275395352925573, 0.04403665468895009, 0.029890682149146284, 0.060415937033082755, 0.07064831975315299, 0.04409795354253479, 0.030275740594203984, 0.021491377048992684, 0.03845388229404177, 0.018819287485842193, 0.036872570003781996, 0.02750330587982067, 0.020007001967834573, 0.04687229324398296, 0.0324065508986158, 0.03526260996503489, 0.008235989354683884, 0.030513088751052107, 0.0726916261815599, 0.05965525856507676, 0.087455801798829, 0.040391995438507626, 0.038933233357965946, 0.03321633833859648, 0.044536436442285776, 0.12424391454883985, 0.05130489110680563, 0.028152324625157883, 0.035855571539806466, 0.002435821125150791, 0.05596110357769898, 0.05725831325565066, 0.04012760766116636, 0.021750204231856123, 0.023026647345562066, 0.017600818404129574, 0.055509423171835284, 0.009390986574414586, 0.06585158607257263, 0.010089128710595625, 0.012576662685855158, 0.01567521574907005, 0.037781423556485345, 0.022449090212051357, 0.08479181224746363, 0.041700326305414946, 0.02721883516226496, 0.03312786415751491, 0.08425427680569035, 0.03958196372592023, 0.03791653684207371, 0.09657953972262995, 0.047412536040480645, 0.008462916909983116, 0.02021094414937709, 0.039490419173879285, 0.08652035985141993, 0.022299817596961344, 0.06243763890649591, 0.003179737869816433, 0.030824916304222176, 0.013089716584155602, 0.03329563194087573, 0.021567966689222624, 0.015426359638305647, 0.03394862011607204, 0.039460092051220794, 0.01618384729538645, 0.027396521431260874, 0.03258571467761483, 0.033846334354685884, 0.01502319278993777, 0.015442820897858058, 0.012733081122860312, 0.07503677212766238, 0.05342101112806371, 0.02402124906490956, 0.023948516896260635, 0.0563936900081379, 0.021351866856483475, 0.06360541124429021, 0.0731616270329271, 0.033472485308136256, 0.012212299558866237, 0.15435267106762954, 0.14810599626174994, 0.18054501845368318, 0.11393270641565323, 0.14653920462088926, 0.08757933588432414, 0.18163916974195413, 0.1263213309326342, 0.14216728135943413, 0.11939016357064247, 0.12268012203276157, 0.12333940022758075, 0.217580626851746, 0.1394895650446415, 0.10208987511162247, 0.07258870598993131, 0.13855691866150924, 0.10373508504458837, 0.11145451332309417, 0.12492315524390765, 0.18927977260734352, 0.15577075497380324, 0.11855184712580272, 0.1682500181985753, 0.11033827571996621, 0.08462574080164943, 0.07533523932631526, 0.16519988115344728, 0.17670182324945927, 0.13967726140150002, 0.0874515405989119, 0.13941322985504354, 0.12084461695381574, 0.1276121623814106, 0.09895749962223427, 0.14005619606801442, 0.18679651085819515, 0.09111168741115502, 0.10369337549699204, 0.0832973320835403, 0.09397087113133498, 0.08056646612073694, 0.12082955347640173, 0.08642160586480584, 0.14712171336369856, 0.13841578337763036, 0.1803962021533932, 0.07630423483039651, 0.28483201031173977, 0.11441975885203906, 0.16789849634681428, 0.10961011943540402, 0.11265744734555483, 0.10022298100271396, 0.12750670446881227, 0.08599547230239425, 0.08075652377946035, 0.14967299146311625, 0.09203245943146092, 0.1824834437242576, 0.23005851943578037, 0.13271759556872503, 0.09501747747084924, 0.15491829785917485, 0.0967358945469771, 0.13250959744410856, 0.1536974505122219, 0.1535494891660554, 0.13135432372135775, 0.0925108062635575, 0.08481518777885608, 0.08108166418969631, 0.12481688308928694, 0.11283928115985223, 0.09096097799816302, 0.15569363268358366, 0.18966824747622013, 0.1914055956793683, 0.11146249968026366, 0.13655741166855606, 0.10521342964576823, 0.16810952073761395, 0.23309800348111562, 0.1198293250054121, 0.13711527601948806, 0.13010652496346406, 0.14855330011674336, 0.12392801578555789, 0.10043722843485219, 0.13413095687116894, 0.12830603229148047, 0.13671009561845235, 0.11093901669872658, 0.13771757084344113, 0.17838077672890254, 0.15978177902953966, 0.13503171210842474, 0.21953997814229556, 0.09944234003445931, 0.1185319796204567, 0.12466605832534176, 0.08033260224120957, 0.1251473839261702, 0.11183519182460648, 0.17855609660702093, 0.1283506934664079, 0.13479239280734742, 0.20860470778175763, 0.08117148865546499, 0.14557214294161114, 0.15970844296472414, 0.11027554515749216, 0.17686540447175503, 0.1365832502820662, 0.06157855250473533, 0.2126575160239424, 0.152213684416243, 0.18675767151372774, 0.0885072121662753, 0.1095926064465727, 0.07232333094413791, 0.1664389403803008, 0.13687324257833616, 0.1501860860735178, 0.15088357936058724, 0.14646996690758637, 0.09472306791160788, 0.18778490567845957, 0.1847667819155114, 0.08660060340272528, 0.17423568772418158, 0.24175307048218592, 0.1048643301640238, 0.07339171147240059, 0.1531827681298767, 0.09846137517264911, 0.12146109315965857, 0.08511727835450854, 0.11792977979140622, 0.13911732073341096, 0.144969481708748, 0.12371553932981831, 0.11728300021163054, 0.24069455585309438, 0.1220287691269602, 0.14371221060199396, 0.16543480354760373, 0.09198640047439507, 0.1653966698795557, 0.111826696566173, 0.18052661658397742, 0.09980208573064633, 0.1656710830117975, 0.16323108465543815, 0.1291109783841031, 0.1584271245769092, 0.10603640441383634, 0.09389172680675983, 0.09360923910779612, 0.1887410700853382, 0.09055631328374147, 0.19962243762399468, 0.10094082355499268, 0.08201982706253018, 0.1515538226813078, 0.12399299229894366, 0.1523420632417713, 0.3189880789390632, 0.08964437578937837, 0.11086312255689076, 0.12589510237532003, 0.08788932460759367, 0.13234617907021726, 0.2373208797403744, 0.15583978912660054, 0.10478317737579346], [0.034800093354923387, 0.026401068150464977, 0.041207998259259124, 0.03448207416970815, 0.0061891257064417005, 0.01673008325243635, 0.036407858332885165, 0.043703795942877016, 0.030683770842318023, 0.016791071676250015, 0.019477725993575792, 0.025309955002740026, 0.02154585492930242, 0.01670856521065746, 0.0053567629823062035, 0.017950184210868816, 0.03760930975633008, 0.04932055276419435, 0.05290432367473841, 0.007195711202387298, 0.04233378285009946, 0.07287844722824437, 0.05265252272199307, 0.029350771834807735, 0.024579254211857915, 0.01545585725190384, 0.02542235772125423, 0.031006516023938144, 0.04718961014545389, 0.03212033464972462, 0.02094937175778406, 0.04392074055171438, 0.1101171343720385, 0.07045465907348053, 0.02858063458864178, 0.04639461476887975, 0.061736752944333215, 0.0382701248329665, 0.02395003511836486, 0.0693944888189435, 0.04108328352283154, 0.08888768710728202, 0.032546481782836575, 0.026828853945646967, 0.036280588912112374, 0.020757697489378706, 0.04604895206700478, 0.05041856152404632, 0.07229285115110022, 0.02533289966439562, 0.04970278171822429, 0.03993746518556561, 0.018525210408759967, 0.04833776603585907, 0.021281243235405003, 0.0140073427464813, 0.026004486484453082, 0.06429696056459631, 0.04271280572616628, 0.027151960447164517, 0.05864997500819819, 0.03385082286383424, 0.009167799443405653, 0.08294835473809924, 0.022384198515542915, 0.04816693466688905, 0.027356515006561364, 0.056716065388172865, 0.03699242303680096, 0.005771783413365483, 0.020720669833411063, 0.057373392794813426, 0.06916010925280196, 0.02064709458500147, 0.020831603523609892, 0.05550395417958498, 0.04491850933326142, 0.05373951546581728, 0.029618908518127034, 0.05394335077809436, 0.05746572105480092, 0.01003235568558531, 0.07562194751309496, 0.04127178394368716, 0.018684208127004758, 0.010773342219181359, 0.03422016304518495, 0.02451122598722577, 0.05610766035637685, 0.05067332088947296, 0.03373333452535527, 0.035159889941236804, 0.048119684880865474, 0.022811044539724077, 0.014707682487953986, 0.027730542168553387, 0.007006853702478111, 0.046089307937238894, 0.021614936579551016, 0.012105112230139119, 0.02681031806527504, 0.060602079544748576, 0.022071297180705836, 0.04562117984252317, 0.029018880001136234, 0.039910513774624894, 0.008235828202616955, 0.11158353675689016, 0.030684737754719596, 0.03292848003496017, 0.02238445126983736, 0.02975596919921892, 0.019506621407344937, 0.04150995312790785, 0.02502973869975124, 0.03632113477215171, 0.04787023165928466, 0.02970091626048088, 0.008043025021574326, 0.03242245236677783, 0.09273871939097132, 0.045069466411535225, 0.051435210542487245, 0.024792056364406432, 0.044306294327335696, 0.021123041099469577, 0.009771968720347753, 0.08999154823166983, 0.01688619889318943, 0.056068593702678166, 0.0163726615386882, 0.07824562529900245, 0.026874565153515766, 0.04699526075273752, 0.0669818286384855, 0.029371409477399926, 0.07056629844009876, 0.014478251138435943, 0.016990141976358633, 0.0714087335925017, 0.06529148255607911, 0.03542101735781346, 0.016961022646033337, 0.03916146539683853, 0.004578081708002303, 0.04074159025081566, 0.058247318757431846, 0.02209788896808667, 0.04287187808326312, 0.02792765150245811, 0.018554998096078634, 0.05567933512585504, 0.037158552158091745, 0.020548998777355467, 0.040786590693252425, 0.03549773931237204, 0.05023419338145426, 0.05591882745336209, 0.029171024515692676, 0.026587081740477254, 0.030828400581542934, 0.036616165190935135, 0.037075845524668694, 0.0502219763584435, 0.05614024021529725, 0.06728140184921877, 0.02213752898387611, 0.059207038687808175, 0.022877049033663104, 0.03005640414942588, 0.07528153327958924, 0.05444049981555768, 0.07041814710412707, 0.0352125544367092, 0.024291967573974813, 0.024866781729672636, 0.020149302635607973, 0.029702541351850544, 0.015641445061191916, 0.016278207767754793, 0.049780711465116055, 0.04954018437170556, 0.024025120107190948, 0.08793623851878302, 0.04847230935203178, 0.04192148461671812, 0.020743205677717924, 0.007853038609027863, 0.06398572333689247, 0.013923724331626934, 0.03901589588661279, 0.03158297562705619, 0.017338837729766965, 0.053576443144785504, 0.020762141893750856, 0.010354004184981542, 0.022955043241381645, 0.013566565550198513, 0.01100631636966552, 0.022501306874411445, 0.008971645147539675, 0.012645144680781024, 0.06614482176623174, 0.048060323244759014, 0.034309763594397476, 0.021898384405566112, 0.03117011420960937, 0.11588455310889653, 0.05930947033422334, 0.04000550867723567, 0.06385634706488677, 0.04765812500513025, 0.015797328303701112, 0.04270579645942364, 0.04194438178092241, 0.032448043315006156, 0.028495682004306997, 0.04772377326818449, 0.05810189513223512, 0.032793173366891484, 0.017561397215883647, 0.037617357181651254, 0.026461515442601273, 0.03570133713739259, 0.05790602921375206, 0.05801488658679383, 0.03778428018891385, 0.02009856348325099, 0.013214579750118511, 0.06290009444845573, 0.05003080590228949, 0.024561481683381965, 0.02007903524541429, 0.07509944840733494, 0.09176821075379848, 0.027564075476090823, 0.0490927549877337, 0.0190696719967361, 0.05880377175552504, 0.02254938447315778, 0.01167357074362891, 0.05467590396957738, 0.041147757920303514, 0.0587505271126117, 0.03007195277937821, 0.003997636559818472, 0.06302817471857582, 0.029128035929586207, 0.039060384035110474, 0.03815169672348669, 0.040697600825556686, 0.01115234982821026, 0.028014902624168565, 0.03320002296407308, 0.01941102939391775, 0.017576457300622548, 0.027264436108193228, 0.018044604055051292, 0.03939679491200617, 0.010917751434525209, 0.05084903431790216, 0.0037524967005343308, 0.02601484771418784, 0.0473912741456713, 0.04326646655265774, 0.047783508098551204, 0.030740900098213127, 0.0651249632771526, 0.02333266324629741, 0.02524115494452417, 0.06454883276351861, 0.032087171250688176, 0.04028641199693084, 0.03651071745636208, 0.06066056926335607, 0.01777409080282918, 0.03189300845510193, 0.02207296807318926, 0.02842008472154183, 0.03210677412737693, 0.03531438897230795, 0.03903706278651953, 0.019346996044207896, 0.10042848211846181, 0.04451581237039395, 0.04761838320908802, 0.034563009826732535, 0.044807602784463336, 0.0033155661616807003, 0.0074205573515168256, 0.024720896700663225, 0.016929728610973274, 0.026817418934245194, 0.03607258739482079, 0.03438702837697097, 0.03348607975723488, 0.1009039655327797, 0.07169779629579612, 0.053447046516729255, 0.029439486895820925, 0.053601850888558795, 0.07938521807747227, 0.014397077994155032, 0.046996068209409714, 0.011483376529732985, 0.03231003607756325, 0.029935054946690798, 0.02025062996628029, 0.0023661476651406182, 0.06964321261537926, 0.03106630513710635, 0.02437460296122091, 0.07888519883688007, 0.039789079755012474, 0.06064893238778625, 0.045434419863990376, 0.0500755349307188, 0.01316228844890637, 0.010268017682912094, 0.018250128919524804, 0.01837193782973502, 0.047869149395929914, 0.039570615227733336, 0.05435832922479936, 0.022943046742251942, 0.029468446770416837, 0.01405227109457233, 0.037089826738727946, 0.03710326851744737, 0.017623433976301124, 0.020375171676278114, 0.06637472978660039, 0.06342754007450171, 0.014751977253971356, 0.02609509296183075, 0.02432847106164055, 0.03452474045168076, 0.021798836532980204, 0.02766583876551262, 0.017613081228254095, 0.030209586822560856, 0.015290710310052549, 0.02906033509810056, 0.04143394024244376, 0.026598859412063445, 0.02198530304511743, 0.048939036271933994, 0.03155085377927337, 0.06671802100858518, 0.05200597723679883, 0.07728076885853495, 0.05647846278069275, 0.12493257330996649, 0.12360890076628753, 0.13212960426296505, 0.11472366111619131, 0.25310914111988886, 0.13466063487742627, 0.1486229585217578, 0.14346271327563695, 0.14489275296883924, 0.13743995502591133, 0.11932328715920448, 0.11568210540073258, 0.11829857714474201, 0.08620415574737958, 0.0909907114026802, 0.10891206974961928, 0.1726930383592844, 0.09367337423775877, 0.18726068309375218, 0.10173232786889587, 0.15158130334956305, 0.17869744902210577, 0.15808375871607236, 0.12438605406454631, 0.0962593254766294, 0.09005410916038922, 0.10820437129586935, 0.22561062739363738, 0.1230934312833207, 0.113328878102558, 0.07671661448798009, 0.20370181729750975, 0.11311579096530165, 0.16110634723944323, 0.18057365263147013, 0.12368837078767163, 0.13035490949239048, 0.11563004819410187, 0.1389658445758479, 0.1244408796940531, 0.060154877470007966, 0.16019116634769098, 0.1408148253602641, 0.06136331441146987, 0.13023096828588418, 0.13517649791070394, 0.12107021627681595, 0.09232238387422902, 0.1969763274703707, 0.20967884228697845, 0.15941043038453373, 0.1171440633812121, 0.09888898115605116, 0.15875250925975187, 0.13035671439554009, 0.11545476902808462, 0.08494041141654764, 0.24716533720493317, 0.14530450158885547, 0.13880691810378007, 0.16967039555311203, 0.12749195311750683, 0.13427108792322023, 0.16203523453857216, 0.10269612579473428, 0.10882729358438935, 0.12249125859567098, 0.1613176159028496, 0.06958256515541247, 0.04231557775554912, 0.10686735875372376, 0.13516885760639394, 0.23060313878314836, 0.13718388948057378, 0.2257790940680674, 0.10912066498505217, 0.20496556162834167, 0.1626402706440006, 0.09305751549878291, 0.16722366612936768, 0.17031007765659265, 0.12598534753280027, 0.1779185722448996, 0.07937476863818509, 0.14626518503895827, 0.05479139741510153, 0.08489296146269355, 0.08274761693818228, 0.13688043504953384, 0.08629541870738779, 0.1342431322804519, 0.15186764512743267, 0.12270589279276983, 0.1780426220170089, 0.2424961748932089, 0.08747991693339177, 0.12958992911236628, 0.21345080488494464, 0.18929679026561125, 0.12913947685488633, 0.09870074197117772, 0.17531626831207955, 0.0970642783546022, 0.1192499782357897, 0.13086820766329765, 0.12243587656744889, 0.12335108460060187, 0.2873310547854219, 0.09462347932692085, 0.12665827785219463, 0.13883024613772119, 0.1212842126509973, 0.0723840801843575, 0.09965720493346453, 0.07494759905551161, 0.062267693025725226, 0.10680948650198323, 0.13957959307091578, 0.14376376569271088, 0.1654459722340107, 0.3052236975303718, 0.1545920039394072, 0.14261002545910223, 0.08003352436103991, 0.18512194071497234, 0.15059024867202553, 0.26556115437831196, 0.2000405237610851, 0.11660002757396017, 0.15034440186406883, 0.09088967075305325, 0.1731820178351232, 0.11526777834764548, 0.13607422688177653, 0.13892419609640325, 0.10767130739986897, 0.20656822063028812, 0.1261591746338776, 0.18272630497813225, 0.17328605082418236, 0.1918303586010422, 0.09777998352157218, 0.07165124200816665, 0.08913622091391257, 0.12616381581340516, 0.09578197609101023, 0.1214149392076901, 0.11771754760827337, 0.09419791573392493, 0.09633299402360405, 0.1167350560426712, 0.08714255610746996, 0.08892701499696289, 0.14981376033808502, 0.17569324879774026, 0.07766618353447743, 0.18215282075107098, 0.1378392728843859, 0.13339489565363952, 0.12202095240354538, 0.11584435669439179, 0.061102716252207756, 0.13030172591762884, 0.13314884528517723, 0.1363530233502388, 0.17139730788767338, 0.13565776922873088, 0.14445478575570242, 0.1746942281190838, 0.11156715692153998, 0.1747521207268749, 0.09766662746135678, 0.24183411470481328, 0.09126921610108443, 0.14289691006498678, 0.10948789492249489], [0.02708867348597518, 0.027341806063694612, 0.036170907119022946, 0.0052377945893178025, 0.042498018858688216, 0.03314075632286923, 0.030848841448979716, 0.024600107289318527, 0.01865114820455866, 0.0066734143848797035, 0.06291520542332105, 0.02410539419257215, 0.03466698853299022, 0.020043539382251244, 0.021268764976412058, 0.02437065728008747, 0.038636659272015095, 0.017980278935283422, 0.0040830641186663085, 0.05144139878185732, 0.042156603786029985, 0.026106261648237705, 0.04685309070295521, 0.01922092423774302, 0.022527515289506743, 0.04039082835827555, 0.03585621954074927, 0.0656360290678484, 0.011779244091095669, 0.04634837939270905, 0.0399937937701387, 0.004655275244398841, 0.023307180863672068, 0.05547045151303921, 0.020836648431473544, 0.03047002213341849, 0.014898303330742886, 0.026711297753666128, 0.019388970220461488, 0.03773621955354299, 0.022055753639766147, 0.01987265033780464, 0.05782053380140236, 0.10495238365339381, 0.0319606482184359, 0.047329422286046405, 0.01386047893070749, 0.017985527403652668, 0.07333265178437744, 0.008506165035734219, 0.005718233853778136, 0.03661190399101802, 0.016782413569412062, 0.012406083223010813, 0.014830198770921146, 0.04063263788287129, 0.01039051785067256, 0.051527718614254675, 0.05901370370494468, 0.035841556398996284, 0.048054206251565895, 0.04414961380617959, 0.05440243400101151, 0.07335082973752703, 0.03952287689649633, 0.01745366960364793, 0.014741795836016536, 0.03365511300840548, 0.02953759966684239, 0.010321813635528088, 0.014778448601386376, 0.03560857122231807, 0.05208146765029856, 0.01392552923477654, 0.020725054865969077, 0.06358953352485384, 0.03132948512211442, 0.07644705288112164, 0.05357076380667942, 0.0039040559786371887, 0.027917990860130106, 0.02739276913260775, 0.020087391404168944, 0.05792240226375205, 0.04202885599806905, 0.03314606925206525, 0.06680182008338825, 0.05018488084897399, 0.004781803789748145, 0.05147959351805704, 0.01657870378611343, 0.03071518022833126, 0.042450708004512956, 0.026884390340585793, 0.041650766107652865, 0.017956196031134044, 0.09346745243029934, 0.041934729620282135, 0.04297239965360079, 0.030169526115059853, 0.029726147585149323, 0.029438255354762077, 0.060650194462920935, 0.056014375362013064, 0.028506446962377856, 0.030096593778580427, 0.011795246491341718, 0.0410703540380512, 0.042683761034693034, 0.022006563243589232, 0.043629903479346206, 0.009280482905783823, 0.05719415098428726, 0.040132465971899886, 0.05314930874322142, 0.01114071549714676, 0.06703046602862221, 0.02662662336868899, 0.022717825702524612, 0.037457599504185576, 0.01678849833219179, 0.008173516635516924, 0.03249663320769157, 0.04399072465353778, 0.04575790125610573, 0.023806682721312557, 0.03913494146295956, 0.03407944166766746, 0.028588291856327226, 0.039432723341243606, 0.029654395899602344, 0.06109020406646388, 0.01636870567952948, 0.026472894474864006, 0.02056736672031028, 0.03058565467862146, 0.033059830843870125, 0.048305566156549115, 0.0326386404090694, 0.012090750188300652, 0.05117214930110744, 0.048276602889278104, 0.022539767935605984, 0.05450526937576277, 0.0628459405686174, 0.01825420861132443, 0.05098588804581335, 0.017390813512195433, 0.02966890297830105, 0.08537349996290036, 0.041098726979855976, 0.023974433541297913, 0.03867015176053558, 0.00857307537392314, 0.08983324601181916, 0.052325356884726455, 0.06512848487389938, 0.027596651942336133, 0.049308210212205134, 0.004227825748135469, 0.03708375724298613, 0.07078623878104345, 0.08762918785214424, 0.04396532030243959, 0.03494912339374423, 0.016186364660305635, 0.03851507258202348, 0.10265219065227679, 0.032008820812084844, 0.0344614670611918, 0.03501700742968491, 0.020863396281908666, 0.025537389762965695, 0.016119379683264663, 0.023485969752073288, 0.01672595606318542, 0.01695577417766409, 0.02538165240548551, 0.09878315683454275, 0.025708302556137954, 0.037784602493047714, 0.027429827322651232, 0.031646564536328824, 0.02590828887852175, 0.03773641972137349, 0.08639473587806736, 0.026884826299335276, 0.05175540443243725, 0.03541244067517774, 0.023311450545276915, 0.0432620187556105, 0.03367997792416385, 0.034180662129074335, 0.013144111343925553, 0.05967518035322428, 0.05291611322068742, 0.0380356265231967, 0.031024351316903318, 0.0918559046196086, 0.005501354978020702, 0.008642835559190383, 0.043653418110417466, 0.023357501020655036, 0.02684094543967928, 0.05772173910268715, 0.003556024977504941, 0.05684111599943467, 0.04784254403784871, 0.021172301045485904, 0.03471351567921894, 0.04475019872188568, 0.03184399108535477, 0.01355261995922774, 0.053715837986341546, 0.03413949880216803, 0.02587628916704229, 0.05637557651581509, 0.06445716946784939, 0.037845307628491094, 0.05443738194714699, 0.014706630758675081, 0.05785024006451879, 0.04502888323206987, 0.06326697154768876, 0.010094403472196842, 0.0277779022165175, 0.03673433545710785, 0.04544538838256683, 0.08455830120614596, 0.034533639438450336, 0.007501519301773182, 0.08867487138403313, 0.021038465102070143, 0.05198015897933926, 0.017519056630719985, 0.05345521607835378, 0.07909850310534239, 0.019355957795466696, 0.03128473573763456, 0.014796241485912884, 0.02363217029986637, 0.017551884154922197, 0.022543881554156542, 0.05026534153148532, 0.036918517002569776, 0.025996067561209202, 0.028264057290341173, 0.019740181642451456, 0.07459806531135525, 0.03225208918697067, 0.008005267092292863, 0.03469953107248459, 0.014847382670268416, 0.033303876141352315, 0.007975783897563815, 0.017845457419753075, 0.024577922586883818, 0.03552362203065838, 0.04949475645220705, 0.025806354259007742, 0.006156228208315692, 0.023259610469852175, 0.01673753187060356, 0.06158841161855629, 0.05132176966539451, 0.05567289922120316, 0.06254103407263756, 0.03368693630078009, 0.06299968981849295, 0.03974140588460224, 0.02222598111256957, 0.03662412779937897, 0.03028241398611239, 0.0438477403617331, 0.07191008276173047, 0.03666440563808594, 0.03175338969698974, 0.043744857489530525, 0.05318150183718119, 0.03468723601794668, 0.011180547199078968, 0.03226168027945927, 0.024614967206226926, 0.028250230442998663, 0.013768339812356447, 0.02808055597623544, 0.04220398249370711, 0.03728061382259641, 0.05341657690171685, 0.009890187332140548, 0.04773860265101705, 0.01976757579749184, 0.010614459003720964, 0.021366743736767342, 0.12157037800976209, 0.01361434459353664, 0.029476215996380364, 0.07073091103562287, 0.035502519591578414, 0.011840234211246883, 0.021855806333145926, 0.03059867237295423, 0.02728205087727734, 0.02542002864980272, 0.05233862902969122, 0.01862616793784712, 0.0396489012055099, 0.03521570623187082, 0.05849450906472547, 0.03941492536770446, 0.034110732310052426, 0.030643136772726263, 0.03462599144716348, 0.041873668253953965, 0.0736350884128894, 0.011501359404064715, 0.010038973946523453, 0.03662178006821445, 0.032047656763877184, 0.02459786642741944, 0.038102764170616865, 0.003405255132487842, 0.05608905153349042, 0.0186975413401212, 0.012475667837341982, 0.042117109655269554, 0.036536210017012696, 0.02275552850083581, 0.049880910731319866, 0.023119231752519096, 0.04218003360022392, 0.03899196734918015, 0.05520656245893665, 0.02116364802766059, 0.05064512436677303, 0.03682175451623542, 0.1404530712004219, 0.014905906315626842, 0.036597006754683595, 0.048380544276109765, 0.02579127381821828, 0.019626817100548317, 0.036613454443535635, 0.05828304362616368, 0.10009599995932408, 0.07848443569881575, 0.045717725197651556, 0.006875735715896423, 0.020208224920289855, 0.014264594031763929, 0.005505135690327734, 0.013495488158826317, 0.10588194270219121, 0.14597306214272976, 0.12723052714552197, 0.07314922341278621, 0.21023529528507165, 0.07959542144089937, 0.08516495901026896, 0.10339025354811124, 0.10479919080223356, 0.14677936530538968, 0.08852075572524752, 0.11392170057765075, 0.11932442709803581, 0.1189494686467307, 0.1397753232823951, 0.14605053727115902, 0.08966511181954827, 0.16019274054893426, 0.1128905580512115, 0.10185308674616472, 0.1996341762798173, 0.08432571975780384, 0.20174133963882923, 0.14305143963013375, 0.10918543793793235, 0.11179732278521572, 0.08176586497575045, 0.1259961633809975, 0.0831250384716051, 0.12889888190797397, 0.16425040710185254, 0.09412655420601368, 0.11481750250927039, 0.10436602761702878, 0.1136406920850277, 0.229289494987045, 0.09527323767542839, 0.11134133368198361, 0.07777681866926806, 0.10434373774166618, 0.11528700803007398, 0.10900123603641987, 0.17769910687846796, 0.16462486343724386, 0.1428770697010415, 0.1172154995479754, 0.16406826116144657, 0.13117679181907857, 0.15414843202701636, 0.13418034064982617, 0.12055486893015248, 0.17687810664730413, 0.18839880345123156, 0.0889226927288941, 0.10612862410822085, 0.13980201685002872, 0.0900310253990548, 0.12552061889852795, 0.1824453914804118, 0.20360827445983887, 0.1760377681681088, 0.10457900618868214, 0.14711913493062767, 0.1293362927223955, 0.09558064118027687, 0.14761605326618465, 0.09185188769229821, 0.0958590508837785, 0.10888838887746845, 0.08665107962276254, 0.06117204896041325, 0.13849852393780435, 0.12162799920354571, 0.10128881023930651, 0.16165711411408015, 0.0990751168823668, 0.1068607633933425, 0.27487665308373316, 0.11816512287727424, 0.12624279728957585, 0.09054839478007384, 0.12963803724518844, 0.1231029172028814, 0.19609222348247254, 0.15867054222949914, 0.12003401187913758, 0.13350015000573226, 0.14394752654646123, 0.10736055871737854, 0.19066918162362917, 0.1572357527911663, 0.08443228368248258, 0.07909180596470833, 0.12036139145493507, 0.10706835439694778, 0.17677703207092627, 0.3704485275915691, 0.13329577525811537, 0.11918177189571516, 0.05992257422102349, 0.17460805417171546, 0.0872714574049626, 0.12149371712335519, 0.1787052114627191, 0.10089103944067444, 0.1009016042309148, 0.153317552325981, 0.11759942823222705, 0.11907924525439739, 0.11726758389600686, 0.13136801655803407, 0.16443153523973056, 0.13188803222562584, 0.0900712353842599, 0.15769277326762676, 0.1532345132103988, 0.1440883632749319, 0.11687144158141953, 0.24488426532064164, 0.08823257511747734, 0.0950591191649437, 0.11134184936859778, 0.09106853258396898, 0.1702999539141144, 0.14229393670601503, 0.1085348314206515, 0.11049572977104358, 0.13183471294386045, 0.18681709761066095, 0.12683230851377758, 0.10631988955927746, 0.15122978149780206, 0.07611425859587533, 0.11604276033384459, 0.1174598400081907, 0.11261281331202813, 0.12493137908833367, 0.18275762615459307, 0.1795479112437793, 0.1858152677970273, 0.17872776596673898, 0.12619846181145736, 0.0727417292073369, 0.20513294264674187, 0.12555801974875586, 0.11142947538090603, 0.21041802476559365, 0.0817966093974454, 0.09112216399184295, 0.13963540936154978, 0.08263538046074764, 0.07382810448429414, 0.13641490574393952, 0.10147558378853969, 0.19408416694828443, 0.08839117589273623, 0.17511705043060438, 0.16503136019621575, 0.13993614965251513, 0.13638511805662087, 0.281523907823222, 0.09312798814581973, 0.25869456997939516, 0.2222547967519079, 0.08589276924197163, 0.0773101154980915, 0.11234810323055301, 0.1437371535492795, 0.20943333474653109, 0.13893980240183218, 0.17594999287809643, 0.06804961205593177, 0.06242554062711341, 0.13924614739205154, 0.13801907109362738, 0.120580721114363], [0.012506356279897903, 0.06588891228394848, 0.02377627756712692, 0.03342147643810936, 0.06076580325939825, 0.05549031562571015, 0.025653666916436384, 0.03856172864990575, 0.04345501107828958, 0.05836038983293942, 0.024535346210801175, 0.023350140612040247, 0.05445522741813745, 0.01778721367008984, 0.04095846361347607, 0.01775749383627304, 0.03497993566894105, 0.04496580322406121, 0.010709969592945916, 0.021805306364383017, 0.0654089641092079, 0.034012443119926114, 0.045154347749693055, 0.042768418456294706, 0.004269753699190915, 0.05464894577328648, 0.019987297310893024, 0.017624943716717616, 0.0169224852496492, 0.032380359446895976, 0.008315672266430088, 0.04949159447902015, 0.030246743400182043, 0.03906119827713285, 0.030936331754284244, 0.04151070969445365, 0.03158755913110716, 0.021599018148013523, 0.015778805994029556, 0.03516564052551985, 0.028547647608710185, 0.02099004653947694, 0.028334270397733365, 0.022925732224913578, 0.020980589457654526, 0.015345690306276083, 0.01677021350977676, 0.03139406129983919, 0.026188674815265194, 0.0282037999880101, 0.03179115695612771, 0.0456774405735944, 0.0390431492456368, 0.03665279929659196, 0.020881272286974957, 0.030465883069804738, 0.08066412088062082, 0.014173431155670966, 0.07682577720178024, 0.029389634928000823, 0.040922667498567274, 0.02462880253525717, 0.018965087697974274, 0.03994970256462693, 0.023541165183165243, 0.05340612067707947, 0.03547292867941516, 0.037450953253677914, 0.06617152211921555, 0.043370445258915424, 0.013219779872867678, 0.02180525377791907, 0.08004812643464122, 0.02907173109373876, 0.005427010440533715, 0.03323956798495991, 0.020195144461467862, 0.019568692094513347, 0.034440754779747555, 0.039885299413331916, 0.027904165709125142, 0.02952130125569446, 0.016678280496437634, 0.0254478265331792, 0.0376358099414834, 0.035636618467313905, 0.05676396317513926, 0.045593990944325924, 0.024277223008019582, 0.013529357234282153, 0.013721302068526191, 0.09813627547451428, 0.008682306789393936, 0.05102824220167739, 0.08138591250670807, 0.02287359020140554, 0.02998695269759212, 0.03240048140287399, 0.03615435764991811, 0.07381650832082544, 0.02849140384101442, 0.027846417290025523, 0.024278234025197368, 0.022194994114605442, 0.06364179429199014, 0.01623725309036672, 0.03910623603899564, 0.03417620076132672, 0.024655331558148776, 0.03340281333242144, 0.06417546208415713, 0.058190518591020785, 0.012911449319549968, 0.027448156249842474, 0.03243156848475337, 0.018063106008672287, 0.008666094891460878, 0.05689310874523861, 0.03574842407501169, 0.02788012521341443, 0.022207105964688317, 0.03302014672330447, 0.010971230172019984, 0.014739383644025241, 0.03870051959529519, 0.054348039241241555, 0.025145540878708874, 0.034675680566579103, 0.029073189944028854, 0.013416658504866064, 0.016589884346883212, 0.027047795143776705, 0.01658861548639834, 0.03284451471907752, 0.008899862079748085, 0.038160195374595265, 0.010378390733551766, 0.031506151892244816, 0.014722769714093633, 0.03065754207117217, 0.023671491404197047, 0.08313349980328764, 0.03795565777857389, 0.04662039729633501, 0.015855270105281045, 0.05377095538590636, 0.0178343243564346, 0.013301731636082488, 0.017764816925461804, 0.02370985407781388, 0.04902565465973956, 0.03799203743359872, 0.026203319297305176, 0.038574736166213236, 0.029995485275451626, 0.029677106466676508, 0.02621515973338059, 0.038510156595813375, 0.014298546227759548, 0.026445429073646665, 0.020677776242207204, 0.010245642990672162, 0.04946355062669941, 0.048887555820069144, 0.03439866525254079, 0.008234650096190827, 0.07319148935909782, 0.09875519440642425, 0.029783833239759718, 0.028861225782228366, 0.028289020593677248, 0.03537534855838333, 0.015426997461223176, 0.037485205701419284, 0.03298127345208611, 0.023576925674985563, 0.023205670328544717, 0.04056498794151204, 0.04597428607355271, 0.036229067748146396, 0.07758549215005976, 0.038259909488260746, 0.02936563514439123, 0.024380368812541877, 0.05993471321250711, 0.02048875674206231, 0.019435074978641102, 0.061778245360723565, 0.02599160449712404, 0.040843502817941565, 0.03129597906289356, 0.04938600425209318, 0.01957404743214803, 0.09733426065317222, 0.06754195929637977, 0.008902942628732749, 0.02722344241504158, 0.037821138211126835, 0.04685734172484704, 0.027756816740812998, 0.030027739437563077, 0.04393788034628544, 0.01088123267982155, 0.0340440764224955, 0.05196500050702265, 0.008360339378538941, 0.026023980795538852, 0.06048949022910424, 0.042221597262791226, 0.04677076744181769, 0.09436639597905533, 0.011678306069890303, 0.06962766737810203, 0.05266745049240334, 0.028797294212771312, 0.029249201927866255, 0.03558575887499111, 0.043272288383117745, 0.023699346963050108, 0.05838839297315904, 0.008926343605188387, 0.03622836885707719, 0.06038148781018598, 0.012414550491874772, 0.012120838975533843, 0.022922599089464972, 0.02328452966841204, 0.07094545702316932, 0.021562845446169376, 0.03787579759955406, 0.007489723818642753, 0.021886827257860984, 0.027902216617284075, 0.02671753857950015, 0.13327250150697573, 0.0028134095357797506, 0.020334622423563684, 0.035536005294748714, 0.01840312499552965, 0.03178144033466067, 0.042923372105828354, 0.03457084012084773, 0.030566319823265076, 0.06674945753599916, 0.015220425956483399, 0.04756235996527331, 0.021632458050070063, 0.03663966625130602, 0.06452100604240384, 0.0264047475066036, 0.04708885448053479, 0.0403074635458844, 0.06758545339107513, 0.004141036878406469, 0.004190010567461806, 0.00965681708683925, 0.05255660840443202, 0.05768909478293998, 0.019788910634815693, 0.015670735721609423, 0.05153719096311501, 0.023525160238412873, 0.039975897409021854, 0.029864897818437645, 0.048034623730927706, 0.04580180586448737, 0.0123053691183616, 0.025888153351843357, 0.010522613351765488, 0.03705489236329283, 0.10099938112710204, 0.047282898532492776, 0.027757291715326052, 0.03677461329581482, 0.0158809458703867, 0.09029789322188922, 0.01845959946513176, 0.01184489405048745, 0.018626644608697722, 0.02403941175102123, 0.045823183110249896, 0.02394252543204597, 0.1089733075350523, 0.03227571238364492, 0.00939947589566665, 0.07477158028632402, 0.010388277836942246, 0.03551942189889295, 0.032107242316539795, 0.07444183262331144, 0.016336414197992002, 0.008980533108115196, 0.11658248065837792, 0.03344313866857972, 0.040765956443335326, 0.03819316878382649, 0.03405918400468571, 0.017131533407207047, 0.012288448999502828, 0.023235712466495376, 0.02465818988691483, 0.05769310492490019, 0.04963905710194792, 0.0310612093391163, 0.036258366890251637, 0.026898376643657684, 0.023033544654026628, 0.02736757512736533, 0.023189061487625753, 0.06607157391096864, 0.024411640795213834, 0.013216784988929118, 0.013762916621219898, 0.013725332566536963, 0.02111208445525595, 0.029848735114293437, 0.06722108687141112, 0.08936338765280587, 0.0325964694576604, 0.03495036850550345, 0.056709683766322475, 0.020184031754199947, 0.010307108933505203, 0.029595136043748686, 0.017367402357714515, 0.026877150371936814, 0.01708196133508214, 0.04582002113706299, 0.005571178351861558, 0.023009322650198425, 0.06414168461092881, 0.03283317300624081, 0.08335013567869153, 0.05806652310171297, 0.034855516095246585, 0.013863943700146462, 0.00953668076545, 0.008501479751430452, 0.01482726919597813, 0.028944488814366714, 0.004133734993437039, 0.026525455493746058, 0.020597298596320406, 0.03442485670426062, 0.035219122655689716, 0.01860424447139459, 0.06884543185255357, 0.02125103316003723, 0.01369308858245079, 0.04387599116723452, 0.03317533107474446, 0.030073208069162707, 0.0893434387232576, 0.19434065318533353, 0.17162098017122063, 0.0872455577233008, 0.19791137586746896, 0.10354836577815668, 0.09604705936674561, 0.16214365086385182, 0.09150466096720525, 0.15605606537844452, 0.09815967136195727, 0.33975999004074503, 0.15079713399921144, 0.09277332467692238, 0.16703778824635915, 0.13252075255981513, 0.11385873252792017, 0.1872359165655715, 0.15695634564118727, 0.09982649263526712, 0.09837885174368109, 0.06380483268627099, 0.12684639490076474, 0.2759805481348719, 0.0638409171785627, 0.12326819476272378, 0.10921319002019507, 0.12521648593246937, 0.0994830182088273, 0.20589454392237322, 0.16653869859874249, 0.09285526456577436, 0.08022840640374593, 0.15737186691590718, 0.20501333049365453, 0.11735128797590733, 0.15309943045888627, 0.10463358754558222, 0.1872570054339511, 0.11386068670877389, 0.19128993260008947, 0.13204988996897424, 0.10808843680258308, 0.11530954896339349, 0.09897037821688823, 0.12592171451875142, 0.18537158731903347, 0.08631464838981628, 0.09736133420041629, 0.07968545625252382, 0.07601203050996576, 0.1715500596910715, 0.13643934657531126, 0.10427114806537117, 0.09017657794590507, 0.12478587403893471, 0.19558117804782732, 0.09173300157168082, 0.28823402204683846, 0.10071201476135425, 0.11316873705280678, 0.19718999814774307, 0.09115491687719311, 0.13106198369392327, 0.18783738357680185, 0.14672762022486754, 0.14479907442416462, 0.16190864704549313, 0.11135055497288704, 0.21818692503230913, 0.14806639695806162, 0.11098812906337635, 0.21442176135522978, 0.09905218239873648, 0.14506244100630283, 0.0676121808854597, 0.2035374218331916, 0.13812547895525182, 0.13523802746619495, 0.18065024566437515, 0.11088492388703994, 0.13602672943047114, 0.15020307659038476, 0.10956727673432656, 0.11694407196981565, 0.14929073197501047, 0.19341304153203964, 0.1872918549925089, 0.11238916816988162, 0.1062906039878726, 0.09522302608404841, 0.22557670064270496, 0.11712444014847279, 0.10153418207275015, 0.18456497203026498, 0.15691870051835263, 0.13533451514584677, 0.1086932218500546, 0.140518278415714, 0.16954200315688336, 0.06824987488133566, 0.14808838149266584, 0.18522441307348864, 0.13007661513984203, 0.14484441413411073, 0.1373334385986839, 0.16532755430255616, 0.10888894527618374, 0.1429204416594335, 0.19883589340107782, 0.141617925837636, 0.10806132254323789, 0.12897037235753878, 0.13719803015036242, 0.07903400156646967, 0.12986751778849534, 0.1775231763188328, 0.11739243433943816, 0.14705056218164309, 0.13432995762143815, 0.07357623907072203, 0.09646507086498396, 0.0884407428758485, 0.08776277104126555, 0.08056956024042197, 0.15279403541769299, 0.09834658061819417, 0.12177711405924388, 0.11344768279897315, 0.11687007094068186, 0.0448229342832097, 0.14168590147580418, 0.09902419961456742, 0.09271661272006375, 0.1342533374471324, 0.08892081997224263, 0.12428892856197697, 0.06525094008871488, 0.11104230329926525, 0.08728569306965385, 0.06986578567219631, 0.17629884130188397, 0.10730375855096749, 0.10624143734042134, 0.10556579288095236, 0.14338704305035727, 0.13273169552641256, 0.293357395700046, 0.07139895590288298, 0.06992748486144201, 0.15598827973008156, 0.13190123651708874, 0.13424617211733544, 0.15427659372133867, 0.08198161875563008, 0.09435429091432265, 0.170244341183986, 0.11344259378633328, 0.11594482058925287, 0.17968192190996238, 0.13763318822852202, 0.06784620761339154, 0.10880707324083362, 0.12477652382637773, 0.11924441424863678, 0.10786350244390112, 0.11051161427583013, 0.2219594033168895, 0.08351416473409959, 0.054747706545250754, 0.13017466345003673, 0.12703514977225236, 0.0571934792346188, 0.1321714563029153, 0.07479273022285529, 0.1066097461485437]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04612763159509216, 0.006944659606753183, 0.03887206681870988, 0.01763928116166166, 0.03762826802475112, 0.043032300725047073, 0.026481298131069968, 0.009570836521951216, 0.10087746874030147, 0.03811235187043037, 0.032409000410033126, 0.048013572181974135, 0.027378036441015344, 0.054078576021960804, 0.03369132302967565, 0.07044700519847018, 0.019838732068559954, 0.0027554925431364347, 0.088275824939566, 0.006263227243575135, 0.04094455025291868, 0.007065781924341406, 0.08550831130040543, 0.04275591644857611, 0.0727400735818914, 0.054369701471711905, 0.03931015956082514, 0.011832820367999375, 0.03745692436184202, 0.02941236924380064, 0.04635326823751841, 0.009732541594920414, 0.021924133113186275, 0.06890463403293065, 0.060154334641993046, 0.047805641910859516, 0.02038969741468983, 0.030343729803072553, 0.029261666616158824, 0.09646068074341331, 0.030319173620747666, 0.04805104767105409, 0.014096741431525775, 0.01364619841998709, 0.07328707458717482, 0.03440521311547075, 0.01974692628053682, 0.017487007725451673, 0.03315588765378509, 0.05379753020991172, 0.052331707972501, 0.02119633136317134, 0.03910038706713489, 0.03191438570086445, 0.008765691109666867, 0.05412818032449909, 0.014087821240536869, 0.06350420096090861, 0.026707233328904425, 0.03012272755482367, 0.023625312007165382, 0.07283316180109978, 0.00927466616433646, 0.037022173404693604, 0.046206535039735694, 0.07007925278906312, 0.03222782477470381, 0.05972049292176962, 0.029293055646121502, 0.035067643105451546, 0.030543748355869735, 0.008664822638300913, 0.1078019186056086, 0.02976384699078543, 0.02736811456270516, 0.02578300078000341, 0.024885166636002914, 0.01616865659265646, 0.026466451784861938, 0.008600897006025272, 0.022338602658627287, 0.030728574509599378, 0.04842335983578648, 0.01584616586166833, 0.026293876580893993, 0.04909178128998194, 0.0685969116166234, 0.01712581335699984, 0.04906283159341131, 0.051427258112068684, 0.06706324605537312, 0.026935585807742815, 0.009219723487538951, 0.05770166125148535, 0.02614098907049213, 0.01841392388035144, 0.045700235957545896, 0.024212746914210062, 0.007394485491594034, 0.01618106530180999, 0.009933422735360051, 0.026784230090145553, 0.04128186697406428, 0.056713296965296776, 0.016199879381539564, 0.05873224737920931, 0.03764870549951281, 0.0385070828321789, 0.030312629150492803, 0.0707109078232731, 0.011269583716057241, 0.01801044660221253, 0.05246766942686268, 0.01830190114144768, 0.0534865813595908, 0.057520003856292794, 0.017160286328622272, 0.027017814073977724, 0.0549126007328076, 0.03341694721685989, 0.0292123303349529, 0.026452317900423492, 0.07058212187673364, 0.025054391573316286, 0.059710437032793245, 0.007999585209680455, 0.008735532772594264, 0.02699148012990398, 0.04272512452942984, 0.02945697952860168, 0.03469333265508924, 0.028405272302084734, 0.013237809396481939, 0.024123865612117306, 0.03771011291870049, 0.006605005332468343, 0.0370704681346459, 0.05589430859046323, 0.032140018950615606, 0.008481533366388508, 0.02745697381240981, 0.05410762071343405, 0.07405229245445558, 0.05770269941006388, 0.043096676734941344, 0.0885251322761178, 0.037848001412515125, 0.005854252983616399, 0.04070063726976514, 0.009448831684754362, 0.014113246795854397, 0.038623997808567116, 0.047361391463450024, 0.03923454022567187, 0.020435133815876076, 0.041588642834020514, 0.015977089193516543, 0.07336628676525184, 0.00693004353836711, 0.028073395735451152, 0.02121319804739739, 0.04336660135803478, 0.011374050119359578, 0.06711984266127859, 0.019224406818726232, 0.018461594358086586, 0.013074034791705864, 0.030510629061609507, 0.013052815305335181, 0.018399009680641547, 0.0036049161821470727, 0.025526740155848007, 0.026687510012249862, 0.1073578717187047, 0.012137488528553928, 0.014386421601687158, 0.021177086413704922, 0.015342477442962783, 0.029309218350265707, 0.049241204879113605, 0.06407705415040255, 0.0433705097197422, 0.08975767078144209, 0.042581604194960425, 0.032585053105971644, 0.03310439023854477, 0.019239716265084486, 0.019845622591674328, 0.04096257892836418, 0.021129794219242673, 0.020217817709115998, 0.016060891660994718, 0.04272431028740747, 0.04594387752669198, 0.03075639105268887, 0.06150841233985765, 0.03145207265125854, 0.054672467189707925, 0.05771951350782599, 0.05480922253004142, 0.03493153576606086, 0.04121779291225331, 0.008443949311705572, 0.032159140067441125, 0.010403320110136909, 0.03943675383925438, 0.09213469430272068, 0.06477578915655613, 0.020788798141958456, 0.06029766159398215, 0.01282637205440551, 0.01457548011759562, 0.0372329772716122, 0.012569455795788338, 0.029701482837221453, 0.06718045619449445, 0.0056557823388305095, 0.026094685840819563, 0.0664497689743127, 0.01799605317812945, 0.02401975798420608, 0.031467387186629434, 0.06404080680970635, 0.02813973101521177, 0.05959091308925833, 0.06067937146872282, 0.04642092835690294, 0.04048094798677734, 0.0799683646431991, 0.0455336081130164, 0.0780410198494792, 0.021254040766507387, 0.01631162052841059, 0.0567548538425139, 0.05899478614862476, 0.02644762922344463, 0.019673446027029837, 0.04421257846323507, 0.004497123998589814, 0.10308485850691795, 0.06259998519505773, 0.004322503011540643, 0.04307278212425964, 0.05644868527139936, 0.05885085530046906, 0.055645751035107036, 0.021118679815637212, 0.033670318978173394, 0.04965753361050572, 0.017028904985636473, 0.024352660835055367, 0.09349516380046095, 0.04778839694336057, 0.0494053221440741, 0.041528704443148205, 0.0017036347666622273, 0.054254146958036084, 0.022499590180814266, 0.05092730333230325, 0.043677889475865025, 0.0503179144247302, 0.03053020479689751, 0.018808352894016674, 0.030227968336216042, 0.022455035875152265, 0.052901287230529954, 0.062033455951937606, 0.034186500922909806, 0.024057747463562658, 0.06572867623929467, 0.014466780503945691, 0.06271568220108747, 0.028896156764988388, 0.02641446073539555, 0.04781856121761458, 0.021180389182908193, 0.024004216139603938, 0.04249317751133016, 0.0283759477149163, 0.028129819314926863, 0.00829895825258323, 0.05326398455404809, 0.04110468451731971, 0.007560731660175536, 0.05725846253335476, 0.06240552384406328, 0.03943722202841725, 0.05424589936488441, 0.011658112019566553, 0.011562195157499185, 0.0764795479231647, 0.030933142639696598, 0.039641349110752344, 0.01862352334761194, 0.03625942879755582, 0.024441226618364453, 0.034028436190315654, 0.01404483859161181, 0.007802173927692431, 0.02338723442517221, 0.046068887425852675, 0.038863710659955225, 0.046163434495351145, 0.06122715278927769, 0.034876957801835876, 0.02570895055708076, 0.03455177328682371, 0.0518071868323854, 0.022519625623577406, 0.01972177129105798, 0.03165292240945356, 0.024830269760319164, 0.03166742609547717, 0.033052499272993634, 0.02837163392853524, 0.014956765907949634, 0.03300457773730159, 0.026722001643585305, 0.01548283071523266, 0.03126238140144518, 0.022683233987273912, 0.029893667703228335, 0.02224734648396926, 0.018488954586376036, 0.028392444597557187, 0.04686967409881098, 0.04371997561039669, 0.007480749344852353, 0.06966510894043104, 0.002845367686989318, 0.014967659787674035, 0.0792409683178578, 0.0152017747251583, 0.05305526039696165, 0.016730841515319686, 0.03922800932611738, 0.11219852018569197, 0.019301842931391935, 0.03179302292742899, 0.03463107706712825, 0.028328904882073402, 0.10226066237581627, 0.03765355363222105, 0.031130888100181307, 0.02193883527070284, 0.08521400352141686, 0.075015072577766, 0.028990459561880146, 0.06944493789758001, 0.06692101833011423, 0.01619672928271549, 0.027442353079095483, 0.15950678235718183, 0.12353400407092911, 0.1329321754830224, 0.08562140951731376, 0.14751845278910228, 0.16749976202845573, 0.16005171383065836, 0.11657733736293656, 0.16024950678859437, 0.10158191701131207, 0.0843720772702779, 0.15145950631371566, 0.12445185839065484, 0.08043041306414775, 0.0849669353504266, 0.13726458086499146, 0.11572676657566003, 0.09186590622578349, 0.17572584562003613, 0.11166440456041268, 0.14030705046440872, 0.08940170452530895, 0.15017465954380377, 0.19823525420257024, 0.13255211444837706, 0.16616300732961722, 0.1582958009094, 0.1240782162972859, 0.11933076461510998, 0.08569021975355488, 0.23501459349478993, 0.13917114213109016, 0.11874807945319585, 0.14762775120990618, 0.12327895632811955, 0.11105556865887982, 0.10463413037359715, 0.08797326617475067, 0.12219697795808315, 0.21706769508974894, 0.14781330339610577, 0.19985379092395306, 0.1098534149516906, 0.13875761574932508, 0.13126198867602007, 0.11402998119592667, 0.0722811667780791, 0.08266056768063988, 0.10355736315250397, 0.1789717807301453, 0.16583326645195484, 0.12780675265405858, 0.2151641058070319, 0.06772420023168836, 0.1597041953355074, 0.09876459890178271, 0.04974927833037717, 0.13048668099301203, 0.12977132866425173, 0.12567870398717268, 0.08936481936169521, 0.17364400518792017, 0.03319960566503661, 0.17134838551282883, 0.15501342846878938, 0.1277791362787996, 0.13405707797833852, 0.06117233394512108, 0.21506539253251894, 0.10730932253812041, 0.1289788811866726, 0.125235756326999, 0.1812050158956221, 0.07574689973677907, 0.16998780066413538, 0.16379310164068425, 0.19980906189552375, 0.12184736957507473, 0.11665553173848561, 0.07735148577817849, 0.14344292719449314, 0.1327470711299351, 0.14464188500174455, 0.14230140059122018, 0.12460747361183167, 0.20253320357629231, 0.1498925925365516, 0.12856650831443922, 0.12632650136947632, 0.08263791139636721, 0.1690109816512891, 0.11882687093956129, 0.10512416836406503, 0.147621413692832, 0.06438690716666834, 0.11028598781142916, 0.13640330279512064, 0.0969860093402011, 0.1721267330327204, 0.087626195512712, 0.09137558325060777, 0.09192035866103002, 0.14316524352346147, 0.21491436420806817, 0.10952234414539166, 0.11757045478693076, 0.08090897702745029, 0.133030183081116, 0.11318185313471726, 0.1276189341608967, 0.12019695527851582, 0.08938465294029031, 0.10307910452995982, 0.15229166166058608, 0.1596431000424283, 0.13730696216225624, 0.14258107915520668, 0.12907129765621253, 0.08990530643079962, 0.14855391079826014, 0.07660858492766108, 0.1820363841418709, 0.1551401245274714, 0.06340368278324604, 0.14788616448640823, 0.07979697348283869, 0.10467569064348936, 0.12274279152708394, 0.18199725981269563, 0.1294734382203647, 0.1164256576448679, 0.11987839665796075, 0.08767018493797098, 0.09034015238285065, 0.19035454493548187, 0.14989142545631953, 0.13306952454149723, 0.17872091276305063, 0.1684325441185917, 0.1318601444363594, 0.10138347944510834, 0.08894921666277306, 0.11515887347715241, 0.23857823227133068, 0.12886438518762589, 0.1483822821506432, 0.08866014038877827, 0.08369311477456774, 0.11688429303467274, 0.11703920257943017, 0.0924416771158576, 0.07531550752797297, 0.11935824528336525, 0.11058674167309489, 0.07743226537214858, 0.1242957953363657, 0.17265772739691393, 0.18159767054021358, 0.0928494223792638, 0.09512170044971363, 0.16488718507545336, 0.12312351752604757, 0.11335931718349457, 0.14408739975520543, 0.08302819116839341, 0.14201257537518228, 0.0805104123428464, 0.11556675444756236, 0.057374980566757064, 0.15484492108225822, 0.17691288835236005, 0.06901636839445148, 0.12626267836562224, 0.1911333402884858, 0.15838759312672274, 0.11254460018660341], [0.020149087200739553, 0.017440209165215492, 0.046530508369739564, 0.0135811939170318, 0.03282081349087613, 0.03295554679685405, 0.05224998860753008, 0.0647916193785412, 0.03788856423592993, 0.02983705074127231, 0.011598442498195385, 0.048974771318691115, 0.025689866759681275, 0.06608946009406022, 0.06188916548022202, 0.03850548827488508, 0.10844901031149284, 0.015954154709886228, 0.05392508800806744, 0.02035914298280009, 0.036057815687464814, 0.03541654581204057, 0.014476268119843943, 0.054212186352482865, 0.05164629939411368, 0.0424209169245192, 0.007407651615462133, 0.05055365106090903, 0.02419385819562844, 0.03966523693608386, 0.0758754617667624, 0.02141120474386428, 0.020866529417357275, 0.025877332414633462, 0.010087455273605883, 0.00862536667513528, 0.06130046849804265, 0.057355411616819243, 0.02419508634401219, 0.04932747721405966, 0.054656541972820244, 0.025521732567410384, 0.06829378966774259, 0.056592541480703015, 0.061843791843525, 0.048892088433993716, 0.06477097155792372, 0.07020028308033943, 0.06671520508825779, 0.11173374405396835, 0.0238304076982396, 0.10458131999309574, 0.037885619393948994, 0.07681237613516194, 0.01319749339018017, 0.024530501470768025, 0.028956135867961814, 0.038793818160359345, 0.014365904399060776, 0.04505892537002053, 0.021873760369739363, 0.017621771565505435, 0.00439174666202494, 0.018987667647057345, 0.027925354661419988, 0.03292452756847654, 0.05568710435181856, 0.05395286383905581, 0.013662361124131297, 0.020365797714995484, 0.030327268543520143, 0.024949864950031042, 0.019670945625486116, 0.09705424282167639, 0.030691017596317188, 0.11050898155995778, 0.02571255018535469, 0.050143429144684754, 0.02578767079726926, 0.05234710732474923, 0.02207178742225681, 0.008382199232333472, 0.03744757075660995, 0.0020936581796766923, 0.012242913362570107, 0.05621518440810697, 0.04181504961369293, 0.01034987869206816, 0.03316329725618873, 0.05220366162913186, 0.02569604312468852, 0.04728521912225655, 0.01260974635702691, 0.021615085857255117, 0.03446142974176577, 0.038247583899647, 0.0036958725291437334, 0.03645002928429416, 0.01732542139611074, 0.04022266702460391, 0.02455301017367414, 0.013621040037833154, 0.06955108791589737, 0.050200419300901036, 0.017376128318054334, 0.024564686065007533, 0.029895937402865717, 0.0035030135810042596, 0.0038277441136805074, 0.01300175639335066, 0.019905094489721314, 0.04702463114101972, 0.01580237321156476, 0.059050344595951695, 0.021043856062793305, 0.025592357884826403, 0.0492507959716022, 0.027966699496443783, 0.013062566701721932, 0.012521475736450936, 0.03558577583836658, 0.004111556228183742, 0.043372935482433865, 0.01921888524001198, 0.00994834880943277, 0.031447068455496004, 0.03818624094128609, 0.014811997069045901, 0.03851673499281917, 0.07169903122953006, 0.028066279599443078, 0.024756356940737793, 0.07509910235447542, 0.10285511333495378, 0.045581926591694355, 0.005164062429685146, 0.05130896570959261, 0.05306097026914358, 0.04644524026662111, 0.03680373601881521, 0.031709257779376845, 0.023207219084724784, 0.01412302109279803, 0.0382167580537498, 0.04398438374378851, 0.07672223954328469, 0.0065740891565967885, 0.053247360446091206, 0.058825417022619925, 0.03119214963433998, 0.054167006098266156, 0.01842227834276855, 0.01725831937177905, 0.04528250605134027, 0.06701043567487172, 0.10879118873604707, 0.02597230187218104, 0.09831317633922611, 0.04908443954108017, 0.005824074714577624, 0.06207320453333003, 0.028128350286611488, 0.04271737226684179, 0.030249352367328744, 0.08079976681619883, 0.007345207734033465, 0.006420700802534286, 0.026739202506308044, 0.01150763500481844, 0.01683082365031753, 0.010136244485953023, 0.030223401795540537, 0.035285663192293475, 0.08198943547904491, 0.02572777820751071, 0.04049204203433224, 0.0429674768820405, 0.00602810425750379, 0.03435218560376337, 0.024206884371648942, 0.02246612822636962, 0.13528507708438806, 0.02924449968018702, 0.02558432233386806, 0.02473881681050573, 0.020338522303583365, 0.046731093499277315, 0.10453331364052636, 0.043667480748678954, 0.055629805462168794, 0.04388966704053538, 0.04876018461904355, 0.04315591284206935, 0.01764773910066911, 0.03428980787949903, 0.03087365547461169, 0.030816441401839256, 0.039767040937606773, 0.02108602022885212, 0.04698760009237698, 0.026287489870030965, 0.034019048658332655, 0.04950300404535873, 0.021894562557073574, 0.07405356810029064, 0.04089352781219142, 0.011479698021763136, 0.04645963538704174, 0.0179129428163703, 0.009514899791351386, 0.05463715962001255, 0.06919333711266518, 0.0737381103847708, 0.023742584910775934, 0.051157944170492034, 0.029457318796111003, 0.03417116603148835, 0.029700329327689748, 0.02116550212459905, 0.1009378447862608, 0.02257431554608047, 0.04131051132987652, 0.013315799363356615, 0.026136356372652308, 0.018973146997658268, 0.030976691017193452, 0.007100530550815165, 0.030540881545415947, 0.017898973476673876, 0.029324973933398724, 0.028055706327514987, 0.04457993392965623, 0.04903804810185518, 0.014897847015942847, 0.02717966672831348, 0.03577073769909995, 0.031806352747870345, 0.04956573121515768, 0.03163559262507728, 0.02010444468552513, 0.05101005407050252, 0.015363003127276897, 0.030105414733822857, 0.03343392755570156, 0.03250602752502475, 0.018791550670617392, 0.04139505000784993, 0.03969551995396614, 0.04354449288387384, 0.07608471518116337, 0.01743993944754558, 0.0536827288701066, 0.022498796294842447, 0.043077633649642975, 0.03100295371509024, 0.016490782611072063, 0.0386601026569094, 0.02767147739151759, 0.024058578668960502, 0.007843447516539266, 0.02200507894823594, 0.04972095627869878, 0.010482668843386429, 0.10063799337616988, 0.03889446186700037, 0.054111199985657416, 0.05896259644734008, 0.025492326556039707, 0.033724611957690546, 0.08229957348001854, 0.013309804506466856, 0.016123203228094747, 0.026607257979256765, 0.027472118714026043, 0.06589366881442921, 0.06746111184890781, 0.022011280758306384, 0.05349339045850294, 0.028061088806550418, 0.09534856863319874, 0.1112237571339522, 0.044729944451579025, 0.015868825538616096, 0.02430691570043564, 0.01393661055979984, 0.04087147542408534, 0.011226174438239207, 0.008763269587819065, 0.06015980363424335, 0.018201493225725632, 0.032750615650521855, 0.013349913559587938, 0.048078301030078104, 0.022954196768945882, 0.06450610541339431, 0.011332765504318689, 0.029050547230456556, 0.04996128659695387, 0.01788967245790575, 0.024550514861143062, 0.03944323384868247, 0.07334965587194477, 0.019076839022870575, 0.003140028516229774, 0.01729513837822846, 0.03746729237692697, 0.02194905570442123, 0.0374422747907894, 0.022377684579363892, 0.0650228573275464, 0.01846775715239346, 0.03287711154137339, 0.014417693584359117, 0.012240126279981008, 0.0650757627029504, 0.07956635300070047, 0.03454529667007072, 0.05992767001901354, 0.0368118750463639, 0.06628588241125856, 0.05069195006840995, 0.004509196832909116, 0.055128537717142274, 0.034561025111802986, 0.04364564888445394, 0.014603040513715573, 0.01495051829676543, 0.02111285289616457, 0.03332857142335602, 0.022947793094707385, 0.0788903082055705, 0.08561117042388235, 0.023861586382346492, 0.026054542012778775, 0.008990196294949522, 0.03627171367406845, 0.02886936141710196, 0.08353369297193629, 0.030910893476435115, 0.015619613196966904, 0.03147758896063481, 0.06299702996121985, 0.0016478982038928994, 0.018654159203703915, 0.003380658874188417, 0.035119425505399704, 0.0527313752765102, 0.020929069990026097, 0.09926022123545408, 0.016677266086584756, 0.04449168027245572, 0.04242538168494191, 0.12002367100545339, 0.15616188969995293, 0.1039931590535811, 0.1556985859892198, 0.10514558971460376, 0.20167472107069834, 0.1492200829088688, 0.12073968829853193, 0.15328538976609707, 0.08569455559232406, 0.11828003956803254, 0.12032810252692018, 0.11365065976445164, 0.20265808116112435, 0.15287921870393412, 0.11613149914358344, 0.2508582504732268, 0.12084962454225336, 0.159055570140481, 0.06023139586406095, 0.14494675078562327, 0.07212817070207425, 0.05676591735599296, 0.1459904054978064, 0.09729012195020914, 0.13264519588223525, 0.13039638155273028, 0.1722039096057415, 0.1401931108640773, 0.13898685202002525, 0.133506908214518, 0.09210010937282018, 0.09853506407567433, 0.07608238102069922, 0.13163431441145285, 0.10642538139862673, 0.1643311527690717, 0.09991870554430143, 0.16697552587304795, 0.07350767310708761, 0.15401756976331982, 0.1125496281310916, 0.11092392607991185, 0.21483254645551952, 0.21484336230371678, 0.13585267162748746, 0.17175518082720892, 0.16368965219174111, 0.11303264328411647, 0.21177228566791328, 0.12874541085745606, 0.11879616044461727, 0.08592895551451615, 0.26541141527039663, 0.10260802480791296, 0.12563012087983744, 0.15740717787827763, 0.1091258218511939, 0.10951119581503527, 0.10830355954489537, 0.09321724942752294, 0.07566253747791052, 0.11793834290334157, 0.062376455403864384, 0.14217876217194966, 0.13596533558198384, 0.17472283515547002, 0.11146857935403075, 0.0665842681857092, 0.085451897898955, 0.18655934929847717, 0.1619536339172295, 0.1362953885857548, 0.1691210400313139, 0.1330334400492055, 0.23286637876714977, 0.08580751131687846, 0.12197426919426237, 0.10133533738553524, 0.10668033414653369, 0.09335164685866662, 0.12430305566106524, 0.1327075803918498, 0.0882653280028275, 0.10123986072306122, 0.12483623490801879, 0.1168025295649256, 0.12176107349140303, 0.09082206830914531, 0.14966776674347265, 0.1551042300249849, 0.1273707803338766, 0.12507195797349724, 0.09327234647103719, 0.1151633925203766, 0.1197769692433732, 0.148933116878782, 0.18626523150929383, 0.12957196150507244, 0.11285069411886589, 0.11053237744740077, 0.0955574827800904, 0.12032658260847841, 0.24707145509975298, 0.1856271100363561, 0.08597057006720986, 0.08623430305825812, 0.11249854122953755, 0.07854070660791226, 0.09819974564015865, 0.1155524237879685, 0.12418197787233762, 0.13042120236371244, 0.202513580343553, 0.13208898715674877, 0.07281554703201566, 0.15206102760774748, 0.10842613011066403, 0.07723763438739947, 0.07532099009092365, 0.13856785664600985, 0.168440632256014, 0.08324179399226393, 0.08026563762021915, 0.13756865954824857, 0.17140330613723823, 0.182852336072496, 0.12928921596280166, 0.13478233691837105, 0.15103452626083577, 0.10414033329912595, 0.09616397773580891, 0.23572865660701478, 0.23144720920494624, 0.1366826963743993, 0.09457916420485292, 0.14641292925391877, 0.12150052961494241, 0.13454332974340233, 0.3214753711862223, 0.0912623561120459, 0.15091354346701077, 0.10699502511748246, 0.17933353488998754, 0.11939527972468308, 0.1609426981636456, 0.1777351913707597, 0.0987539594726903, 0.10143050192190067, 0.0871226614607232, 0.12069516283060823, 0.15986081478851183, 0.10829272334064756, 0.080346044019929, 0.17698823288083076, 0.20312437042593956, 0.15499647866402352, 0.2439368133034025, 0.1742333128516163, 0.07474244399262325, 0.14446737936564855, 0.18698583569909843, 0.193793903238007, 0.11387756866003786, 0.13685703916209085, 0.1784456039645842, 0.11967007283653532, 0.07833827925579888, 0.10202518358294453, 0.09810661670884915, 0.07626954812024321, 0.10940278627510581, 0.1981183969016586, 0.18251424921410425, 0.22139991048191274, 0.07860517422003405], [0.04202140907623938, 0.05814574885049036, 0.02924132752897484, 0.014818728136430894, 0.031072798717234815, 0.014768450387886592, 0.05204765285764422, 0.01825617466654096, 0.04503102061737861, 0.03121736060295786, 0.033234865737280676, 0.02171305104691003, 0.040910172276198864, 0.06066003322069134, 0.01863931625017098, 0.005950973485596478, 0.08510391799999134, 0.1255807913839817, 0.03536315867677331, 0.06206402395452772, 0.05181038951767342, 0.05249663269413369, 0.0268819272584681, 0.046197201790554185, 0.03274216788953968, 0.06229027467114585, 0.005706369244892682, 0.012371729843185415, 0.04949509571971638, 0.030394036389355148, 0.01197343657258898, 0.011913622862526348, 0.03628088407484548, 0.04253044265455433, 0.04721491950164948, 0.0493276061357132, 0.03175930652235236, 0.05985801839934928, 0.033541987650096416, 0.04482914287863033, 0.04676330355661256, 0.007050056875284229, 0.030818409153393338, 0.02773772276538823, 0.030022857378103902, 0.012301002745516598, 0.011276516647610282, 0.01916360668838024, 0.05153986099841339, 0.008945919340476394, 0.008116888647366847, 0.03141455305740237, 0.059920898239527426, 0.025720390657495176, 0.029431782130684172, 0.06495847113962684, 0.017716145608574152, 0.008705858739891222, 0.03849185989903552, 0.024145590607076883, 0.044522550223129134, 0.044123748051268716, 0.014112864271737635, 0.012987159408761986, 0.03589497067566429, 0.05264220559703452, 0.0646729368184294, 0.025880043162032962, 0.032915000936814716, 0.06475026945450477, 0.027272619240518128, 0.04112475897584643, 0.030591259377875497, 0.05080916020753128, 0.025446662845622216, 0.04465752440903868, 0.07661129228238549, 0.023290239540593963, 0.07008776161819696, 0.0494582851949547, 0.04470904218032956, 0.0419456913535084, 0.005462204779697848, 0.02861637302807399, 0.081831051834992, 0.029640760738402605, 0.03014817601069808, 0.06220097267734153, 0.006865963539374726, 0.029136205491210734, 0.0594955924898386, 0.028731462745262042, 0.03887073689007333, 0.0396304280896272, 0.03066248519878302, 0.05993089984570231, 0.05973877265517201, 0.06347130558320455, 0.038823884047035656, 0.03982540173456073, 0.020125847376350845, 0.028597526717931032, 0.01302218877909971, 0.015529768375147666, 0.04191536083817482, 0.054404160872633965, 0.013527996771569763, 0.03223018268389361, 0.056285026017576456, 0.05261398193293384, 0.01552171416447631, 0.04212546581402421, 0.019230605236121585, 0.060625183662133555, 0.03216690929340465, 0.0180229367355683, 0.02086915704421699, 0.028261097181322317, 0.08441217190452985, 0.017126032184543352, 0.024335907805444937, 0.010960057244769164, 0.033455029994781525, 0.03728606924414635, 0.012107370055413671, 0.08532434010079928, 0.06741832343063184, 0.04914128381226744, 0.03343407004805548, 0.0691643568820187, 0.025467704216550504, 0.10764072582657848, 0.0411710588128439, 0.07928827577935797, 0.05273391299747995, 0.08850793819874525, 0.016822740601907884, 0.06333960872143507, 0.02505187251205955, 0.020495767705142498, 0.03166344988026789, 0.013154454762116075, 0.019659083137022595, 0.06062517687678337, 0.01498925416464252, 0.04958569032273122, 0.051758047326334884, 0.020960202873019234, 0.03183846441762788, 0.06096580145614488, 0.03285924232165728, 0.010272920946590602, 0.05281723031241979, 0.01959444589114615, 0.045957495724516254, 0.04142045096627303, 0.07922857826841728, 0.0187568317300507, 0.03405576079551663, 0.02472721386168684, 0.03961021113874657, 0.059129081799515655, 0.04277619107493332, 0.06076802885425942, 0.015112113107794097, 0.032286670724196095, 0.019352865372119204, 0.029723165423742363, 0.08946957159787416, 0.013381825909683747, 0.025208461430988142, 0.045148356285478385, 0.04274975874328187, 0.048683269282004664, 0.007603737209657473, 0.038951061865580935, 0.03564697630437357, 0.01707135752907821, 0.04155563210536327, 0.021398611133918166, 0.05332704081333109, 0.07762924408806221, 0.03816393070987292, 0.0171210636118693, 0.04385930599112596, 0.07301457492368561, 0.017808210936241915, 0.03313335011314068, 0.0639827445681606, 0.05519870502342071, 0.045346213704241176, 0.03924626191811902, 0.08180185447313956, 0.03538962493517569, 0.045397670407380374, 0.017243286428440894, 0.00854169821832329, 0.02083606319501996, 0.021727281622588634, 0.053644391641552956, 0.037787672864007096, 0.03693624712260706, 0.05559512214469058, 0.019847361337659613, 0.02078492201066443, 0.03598395036533475, 0.0685049836922969, 0.0329692803456315, 0.01278148781109069, 0.010738714032673409, 0.04463955340906978, 0.05332827574706503, 0.025561749170135175, 0.049611915701201985, 0.05099991675732391, 0.03606539831629821, 0.018472479756123254, 0.02702869099032666, 0.05699713834162269, 0.03791717466499124, 0.085522886232606, 0.03069204218419535, 0.042967110473130427, 0.07639173870640141, 0.061724552884697914, 0.06659961664783103, 0.04561153785990817, 0.04984439197661621, 0.0115634309394019, 0.05466815509966441, 0.04603656201756426, 0.03736468431140695, 0.011306253444802548, 0.05564642617745059, 0.01580562678697918, 0.03991747215124113, 0.04990464588627219, 0.053302789971764596, 0.02946450448195849, 0.023136719296287214, 0.010628987286639, 0.029269032113786255, 0.03115101684150951, 0.011014774308672972, 0.0390057483954089, 0.06330491522593157, 0.03071554663724133, 0.029897925510470356, 0.017132493534258435, 0.07363759220710822, 0.02964213477181537, 0.008024534094147384, 0.042704775264220576, 0.020224477530324032, 0.03705768453489457, 0.0785529880917498, 0.016729543817096522, 0.026881676200511198, 0.02002898310976369, 0.04404681235817926, 0.03829652323786702, 0.03828693214537842, 0.010807649797892995, 0.06288993677922658, 0.048963456747255156, 0.056082286539354494, 0.015713463071733713, 0.03177691789876137, 0.04275408101135066, 0.03523654404229351, 0.05864266040069716, 0.025997295709592954, 0.017530467893396105, 0.07219654667590346, 0.04334928175168378, 0.014955344377085567, 0.02144244788879795, 0.011828254675492644, 0.09627982401954276, 0.071006063771035, 0.062157770352704186, 0.027787924178742936, 0.06013948829578502, 0.02069066840756152, 0.030356184313339845, 0.04299017387841429, 0.005516080460178533, 0.030819654265152555, 0.019774841211204017, 0.020232168724760413, 0.06228409321712596, 0.015201952840600694, 0.009579837288973587, 0.018003457691520452, 0.015580538061580487, 0.0037332504788147552, 0.033581664985311885, 0.02030558791011572, 0.02087012734929366, 0.038346449844539165, 0.02671860727215452, 0.013785281983603324, 0.03693870681204966, 0.09689744016421692, 0.011290492772656893, 0.11740532650479249, 0.023635356021778922, 0.07988033150987965, 0.035311386454850435, 0.062162784726492, 0.06276816688477993, 0.07544234607900892, 0.03179095678829721, 0.022741593087890317, 0.008872096426784992, 0.009960132418200374, 0.04776347435212561, 0.03827867437420147, 0.035452718513884714, 0.10006769147834607, 0.12324412034026214, 0.009769361449538596, 0.016570524046463624, 0.021271490990849476, 0.007980624396753098, 0.02395248123710709, 0.008437001961283386, 0.05874764333878245, 0.02086772533532764, 0.014983544292460595, 0.03167513086061392, 0.024006733504523124, 0.024453129818929092, 0.04516533323164497, 0.04119009172011699, 0.04911126881571753, 0.02582670352421701, 0.02932554729548948, 0.02754812142146485, 0.027358923805877566, 0.0340394081015672, 0.006755640106608293, 0.02252966963819095, 0.017678140862179652, 0.013465526596909123, 0.007386571228770273, 0.014870120378743325, 0.04949731452922736, 0.03650246647053531, 0.02292201215667384, 0.044986932804541926, 0.013902846657271897, 0.14485312652375015, 0.23184822340096745, 0.06608864585203783, 0.06249920238873788, 0.13295277580618858, 0.20036319430385316, 0.12704547707523617, 0.08441071305423975, 0.1878644706947463, 0.12791861593723297, 0.07754913624376059, 0.15769110407148088, 0.12066804857126304, 0.12962735710399492, 0.1408690538789545, 0.0804619649425149, 0.1844368510480438, 0.18461504791464123, 0.16933967758502277, 0.1486343579100711, 0.10261208244732448, 0.13703465248857225, 0.12711266561278275, 0.1658860971885068, 0.21197534405759402, 0.15684896068913595, 0.2260642551950046, 0.08919122296252421, 0.1285527611949614, 0.10057122553033487, 0.09465128569198505, 0.09141248877027205, 0.07905510400554963, 0.07799369881727866, 0.0945196838251182, 0.1442424857190677, 0.092219775808709, 0.17602414318493434, 0.12630725811634744, 0.13657744202230657, 0.14835351226585253, 0.0734953305550984, 0.10098381553377424, 0.11861444876662322, 0.19504874518939427, 0.12075408681162766, 0.1789334842136928, 0.10201027616858482, 0.10992483754775353, 0.14650341868400574, 0.12068425198750836, 0.17809341714850493, 0.12850071755903109, 0.12898995487817697, 0.1322424989193678, 0.0979225980117917, 0.05854447638349874, 0.15432658818151268, 0.08935223932244948, 0.12228722311556339, 0.11805306960429464, 0.18121675455144473, 0.12422799611730234, 0.060279354719179015, 0.08121645517115082, 0.12423256944332804, 0.09219505677797965, 0.08801124377974442, 0.11319775799555437, 0.15855278926236288, 0.14469563854592188, 0.1281192180301462, 0.1180478720260518, 0.15928646203662666, 0.1373448244162968, 0.12925572347428116, 0.16376795513289316, 0.08625117822417191, 0.18016208043055876, 0.22953246480652265, 0.08825899048575334, 0.1369531468621322, 0.07815820284719978, 0.13925825245678425, 0.2354213073849678, 0.12002236821821757, 0.1503835804760456, 0.20590206209037984, 0.09349318926355668, 0.1606283871723073, 0.11469147141490664, 0.10070022860808031, 0.12440385882343565, 0.07802358149949994, 0.0944889122620225, 0.08432990631886891, 0.1987621502152511, 0.15671325368540628, 0.10746381817651646, 0.1459057786102806, 0.13907301239669323, 0.11643426146890436, 0.13959521294704505, 0.19148589351347514, 0.23495374247431755, 0.13606693941567624, 0.1509014791143792, 0.12673356809786387, 0.22432731411286763, 0.12412382742123944, 0.16767417266964912, 0.10429755664829697, 0.12193282427532331, 0.09043864852615766, 0.13653780200651713, 0.07334185271923031, 0.11647728058908667, 0.09126857827816691, 0.11419128254055977, 0.08026768679597548, 0.09551176987588406, 0.09663882332720927, 0.1033242999442986, 0.11748827062547207, 0.1056924346568329, 0.11220622155815363, 0.1569507952247347, 0.19510298727878503, 0.06255191777433668, 0.17468396866960184, 0.09757551377905266, 0.21550322403865202, 0.11171907412686519, 0.17246434491659912, 0.117631482226508, 0.17306269066674368, 0.08977158074932438, 0.11117750818708114, 0.10009517893195152, 0.09255486354231834, 0.13711120480937616, 0.07789921281593186, 0.09286376660955803, 0.23128305801323482, 0.17373548527913435, 0.08457107802054711, 0.10865160051201071, 0.08957817112760884, 0.14166323840618134, 0.17329692095518112, 0.11972419278962271, 0.15236247357513222, 0.1316562175218548, 0.08850089500525168, 0.07999659848532506, 0.13693254653896603, 0.14120070822536945, 0.08500803421650614, 0.12650521392268793, 0.0920886964138065, 0.17696295066603593, 0.16178956414972032, 0.1606054934007781, 0.180091865626829, 0.13913988880813122, 0.17203990769173416, 0.10399357974529266, 0.11718535902244703, 0.18504418060183525, 0.0820014930463263, 0.10468151247394936, 0.20772107876837254, 0.11609959442700658, 0.07643484603613615, 0.11388413687901837, 0.16606250272265502], [0.07370505894401244, 0.049200757406651974, 0.05431429569476417, 0.015265660493501594, 0.03404603060334921, 0.018249489400269728, 0.09010947083256074, 0.02843378434356834, 0.017312807430114065, 0.01053656657625522, 0.012446235532739332, 0.020084836719823734, 0.0365242610153343, 0.009992913293120052, 0.02320227426077638, 0.009455360039802534, 0.017147312739065716, 0.05167610065213271, 0.028350421227514744, 0.05666246112169964, 0.015027625319947089, 0.03058907449511545, 0.03812401928007603, 0.06094228343239852, 0.048604694926845174, 0.016398037052048103, 0.0131898971906464, 0.038862777674304586, 0.04049741603167994, 0.029377058281430175, 0.04608938257609095, 0.03857240879109927, 0.04320169699245265, 0.009224523274627115, 0.012755877354980578, 0.01941639490957771, 0.05704361120504992, 0.051445578557572195, 0.010070273070596159, 0.04317141736724547, 0.014347470298941647, 0.03399052304614868, 0.05417941989643233, 0.02084731839464179, 0.01763282829363431, 0.010916884606038886, 0.03268653141068561, 0.05232713125380022, 0.024738050065934658, 0.01635278555165444, 0.018066566537267396, 0.026367255054148178, 0.04085925840107458, 0.05077035478981478, 0.02287031796627811, 0.06258878936725003, 0.04599304078146815, 0.02598064615657287, 0.044246070951755555, 0.020903653764565076, 0.019023767406386987, 0.02484732643435044, 0.031126979738473892, 0.02742788501616035, 0.03595998450847609, 0.04155940815274205, 0.020502084866166115, 0.02649617670769138, 0.021267777707959925, 0.0041550384485162795, 0.025659900956920216, 0.012203953578136861, 0.02417429263836571, 0.030041737614997795, 0.020444326269041215, 0.05941073490040643, 0.02500740811228752, 0.034141524229198694, 0.062233881625745974, 0.06335464505744831, 0.044823853698159964, 0.06004594545811415, 0.017436623107641935, 0.08383662493101188, 0.03147697149376784, 0.026327832169564705, 0.02863160613924265, 0.07646384662283318, 0.05128550875399794, 0.032413824794015715, 0.03434091852977872, 0.023403914512268136, 0.030184874577181678, 0.06784535265926804, 0.09762949123978615, 0.08212427395795073, 0.046832510735839605, 0.03189820942601987, 0.07246352306434087, 0.03996535636750715, 0.05453671268852694, 0.011524740024469793, 0.007433699726659272, 0.02028364408761263, 0.04187473016125815, 0.027749559808788554, 0.019199609756469727, 0.04600510174142463, 0.08594711989696537, 0.08175333921930619, 0.0393584271493767, 0.07447067036160401, 0.032973551723573885, 0.09286206348666123, 0.09164669191730873, 0.02169648291809218, 0.01917235809378326, 0.04345694151041763, 0.042901184010718546, 0.007553544277990503, 0.01651125740525978, 0.033749599009752274, 0.0053683680515470246, 0.019536914603252496, 0.05355331527867487, 0.07184153036879641, 0.100118228766535, 0.07514523595039334, 0.05043720766635878, 0.05299402939687882, 0.03409624219472919, 0.026156654747735177, 0.058014126627572944, 0.0191812994889915, 0.02141100287969623, 0.021939656298075403, 0.063688253584717, 0.014672132341989448, 0.008817565111842538, 0.05853157064744404, 0.06165660438793046, 0.05591845086642674, 0.01229474665264466, 0.015464513662404247, 0.04316579231194087, 0.04902406010244574, 0.018627452065369914, 0.040641248492257934, 0.018779242045379112, 0.032135099571730406, 0.010824286628381481, 0.044450472840773206, 0.006876751398002463, 0.02391633058765105, 0.03859562825943742, 0.0047964966174082035, 0.02526189267103161, 0.015254549482571227, 0.029950291450534548, 0.026225140983504907, 0.03523248979555709, 0.016439583751239946, 0.004864440873331789, 0.028345374623313546, 0.0390744263173214, 0.026365248286830525, 0.015361413658995713, 0.036558825589184246, 0.0068725796798909345, 0.09799991029181651, 0.012835128548821169, 0.031529330648481846, 0.09825998597911426, 0.013094877691141196, 0.029309069072561603, 0.03942396006147776, 0.013291119348390825, 0.027974171863336648, 0.08402191927390439, 0.012808306059533996, 0.039007539727858136, 0.019899744241099273, 0.03216666841347303, 0.040991871285119226, 0.024756060081667135, 0.03297388420573302, 0.056948134542575905, 0.05828248044209821, 0.1180753798357078, 0.0475028253027371, 0.017726959760433862, 0.02041688122387443, 0.0070729277462565476, 0.023701872809657028, 0.04856859686385308, 0.052101111239088435, 0.08387454146785395, 0.06034502333828381, 0.026279729125755172, 0.039860495565725226, 0.023334759919505035, 0.05587314508323159, 0.03571877209469676, 0.022066462618697966, 0.023710790456139615, 0.028364029247313738, 0.02988154228244509, 0.02412300217630608, 0.029024498271090642, 0.05505853665194341, 0.043806163128465414, 0.008621228459690298, 0.03750776020543916, 0.03920521394216588, 0.057587911640959125, 0.047680933959782124, 0.00699820407732789, 0.04038154260654535, 0.011135951333147074, 0.03969491605779954, 0.03991469694301486, 0.01668228385304766, 0.029899696486869028, 0.03199947399220296, 0.03209923221064465, 0.055678035731294324, 0.002001090524052935, 0.028236824287367717, 0.03194797996963773, 0.00641237136109599, 0.02350974901180182, 0.05719792363899095, 0.01973364904655942, 0.06980893800833396, 0.027605883411264846, 0.048824828650270186, 0.061524602185402594, 0.04582520853728056, 0.04544024847980056, 0.07487447333655187, 0.013785732361221952, 0.028272705219153847, 0.03909855841525963, 0.039933997871620316, 0.03214205116299646, 0.0663345130160451, 0.02047588154008346, 0.036775760019996336, 0.020026235042938163, 0.02382270632577794, 0.036830538152051825, 0.03449739209775414, 0.03805932775139809, 0.007081783052334296, 0.047458689992449114, 0.018491029207195555, 0.08031198156199285, 0.05534845770203641, 0.015004524595237203, 0.07257770693727902, 0.04524179395022137, 0.014169875632173248, 0.03851877059787512, 0.04243496259940522, 0.003678251398793821, 0.03327718596639378, 0.026574177700760107, 0.06026064072336469, 0.05003119945260031, 0.01968429240930293, 0.027595741009073596, 0.027575856540352106, 0.13059878854879312, 0.05416068893724254, 0.013892125803977251, 0.04235678518723164, 0.025446111535919563, 0.01959079028373318, 0.05863397515245846, 0.0201873192563653, 0.02005856723657676, 0.02423962707897382, 0.036412960916225395, 0.06849656985806567, 0.052385498836104355, 0.036010786425322294, 0.018415762710251977, 0.011747017918553735, 0.06334494200668164, 0.09532443314258542, 0.05677943716623953, 0.015433553805840867, 0.008371441059612801, 0.05637499976104923, 0.06362461378531796, 0.004578675850228007, 0.04856559434639556, 0.030986852079097713, 0.03279102241088237, 0.09560972997652632, 0.008710477018861898, 0.044095161370933056, 0.02378517994657159, 0.033588586042502096, 0.011843757504331214, 0.00573570909909904, 0.03587108285033277, 0.028187847629721676, 0.047332526583756716, 0.07056595238723926, 0.0463692409518574, 0.01814751067597951, 0.09442766769123928, 0.020553412647651773, 0.04441248505775418, 0.03150125626208527, 0.008444398841155427, 0.04681216825598052, 0.037372585851699114, 0.02158100134693086, 0.026472960632028322, 0.03884430455842188, 0.029231275032673563, 0.06872375695300953, 0.020561007150847996, 0.06540418043732643, 0.034626927825489213, 0.03689944677587066, 0.050810826011002064, 0.02836509115461792, 0.024383155895130973, 0.02554501310390021, 0.016458352029855763, 0.09818868551935468, 0.015357973486451166, 0.024506578022348027, 0.06825105553226811, 0.05634377357949104, 0.01030991637214486, 0.07047431623297078, 0.05888212897947856, 0.023090443208015392, 0.026107116602361202, 0.042112509187843115, 0.05478259342323456, 0.03359315936852779, 0.04398658898259912, 0.020190618632893478, 0.05014514583828194, 0.023191972402855754, 0.03710702420877559, 0.05716737599245139, 0.17004099780959742, 0.13077492266893387, 0.17896164341696671, 0.07297997642308474, 0.11001914712999548, 0.09246053360402584, 0.20568467304110527, 0.09285628915365253, 0.13425052831215517, 0.1529833466878959, 0.13773853757551738, 0.11326588969677687, 0.29916416268263546, 0.13292682862707547, 0.09165450185537338, 0.09722866703357015, 0.05246064319674458, 0.11175996264708893, 0.09748516005596944, 0.1416006096239601, 0.2061956777636494, 0.16237333496766432, 0.12964270556611673, 0.19625387766531535, 0.1172547053013529, 0.10289150995335408, 0.11679069591420037, 0.1484953532261508, 0.18162675255111285, 0.15234890287475927, 0.09289198688098363, 0.14779055890228066, 0.1626737088497196, 0.11010396400732653, 0.09267601596989802, 0.14940319236900124, 0.1576792975621564, 0.12520881848675863, 0.12515604203300817, 0.11548902147582599, 0.07944205217063427, 0.10671910563749926, 0.21588104590773582, 0.06051670626870223, 0.10078077071479388, 0.14456537339304174, 0.12584649212658405, 0.1804396826773882, 0.10872646328061819, 0.1274893611137356, 0.14808986069900648, 0.11308248846658639, 0.18462700370166982, 0.20089481292026384, 0.19859098297144684, 0.13544462780867303, 0.14955776264624937, 0.10475989683930363, 0.16940525120922498, 0.09356125989662749, 0.13816492898123606, 0.16007170347230776, 0.14399266269590172, 0.14892561228147574, 0.11809011761631284, 0.10195141325571708, 0.10626578317689044, 0.09354300051927567, 0.11889695003628731, 0.21678097333226884, 0.08674885651894979, 0.14245407097041607, 0.06341656816325017, 0.09654318381633077, 0.1620426034288747, 0.12459454073437623, 0.12238064381693091, 0.15918827801942825, 0.12734378821083478, 0.135963449254632, 0.13438966870307922, 0.39336224805031506, 0.11451104895344802, 0.17394280486873218, 0.15139602257737092, 0.12226888909935951, 0.1043835406058601, 0.24213017310414994, 0.15246076615793364, 0.10740249218153101, 0.16625291321958813, 0.11090629774012736, 0.18818066801343644, 0.16888932032244547, 0.1623775554554803, 0.15305901691317558, 0.13830432721546718, 0.11106922078345503, 0.17403182866317884, 0.11572821864059993, 0.09878942649811506, 0.07825388307017939, 0.12216235910143171, 0.1286676778857197, 0.1521561989294631, 0.10962012104157891, 0.11428740381130151, 0.17283379366355284, 0.19759433716535568, 0.0970332557335496, 0.07181837875396013, 0.1599424154098545, 0.15853338316082954, 0.12050339526363782, 0.20487744707081998, 0.09494571560727698, 0.10245836712419987, 0.16426400494362625, 0.13153546542993613, 0.16842598947031157, 0.15181051247886249, 0.08584592996963433, 0.08258961327373981, 0.15488149411976337, 0.1449876528765474, 0.1626387642962592, 0.14770324501608098, 0.15581547043153218, 0.07677872079823699, 0.18947072593229158, 0.11304434801318816, 0.10516274986522538, 0.1825164748089654, 0.09994636941701174, 0.10606118451271739, 0.0865833279011505, 0.19045089690812997, 0.0552954980438309, 0.09278652896838528, 0.11729397890823227, 0.19736105682594435, 0.17407302930951118, 0.11784653711531844, 0.07999145518988371, 0.11764433367976121, 0.14036582516772406, 0.09912982037557022, 0.1563089418091944, 0.07554909999349288, 0.17360003611871175, 0.1066622579736369, 0.13023289532533713, 0.10338311535971505, 0.1344673473920141, 0.14102557833705628, 0.131165636703372, 0.047041319709803374, 0.19274628588131495, 0.11092256222452436, 0.1442322398402861, 0.14990682820124285, 0.12136145707752023, 0.17937464054141725, 0.11249077200357403, 0.16074115969240665, 0.12001862270491463, 0.13816080348832266, 0.20758480179522718, 0.11854641884565353, 0.1306166068783828, 0.1013258175392236, 0.0535878900305501, 0.18321337098521845, 0.1036167892494372, 0.10056672005781106, 0.1245524308511189], [0.0414091737142631, 0.045904108589248996, 0.0852324121764728, 0.021215611935726235, 0.04717980192175933, 0.041224876817848, 0.0444323525631002, 0.007660951282429908, 0.044735688250511885, 0.04461450528885637, 0.0571033629987921, 0.02595335038911019, 0.011809097935578652, 0.042650953866541386, 0.05518513771572283, 0.03946083504706621, 0.04891983712358134, 0.04491777651544128, 0.022517364405627762, 0.006464450620114803, 0.055192832302834303, 0.04456059907429984, 0.041220496874302626, 0.029216584749519825, 0.09266785997897387, 0.05767671151884964, 0.029374961608222554, 0.05948816931673458, 0.035519062275333066, 0.03990028825189386, 0.018177278007247617, 0.012209896696731448, 0.008709342169043208, 0.0567398921453527, 0.07278282807341643, 0.07165637851825782, 0.039700608966606, 0.0390027356999261, 0.043450027238577604, 0.03843763138034514, 0.030322332201259475, 0.022225256776437163, 0.026108063158712218, 0.010258866790016847, 0.0038736643951519257, 0.06433553528040648, 0.027937339286186864, 0.05550598978464093, 0.09391846108649458, 0.021196429750749042, 0.022007650595956614, 0.026270791123222028, 0.09798430398638759, 0.02201045973093382, 0.02430636778340808, 0.03122088559237974, 0.038149773076708825, 0.030411725797291313, 0.03872377299038427, 0.029413190271173204, 0.008866178753253604, 0.027898476192993776, 0.024669032876512835, 0.05588732646512134, 0.08291847205587796, 0.09252487907984427, 0.006802655798050442, 0.02156925420942051, 0.06330156326293945, 0.027473631847117628, 0.08521688050989594, 0.06841123729412045, 0.02190666422913117, 0.043935787065752914, 0.033649162256291935, 0.022501790330612233, 0.02400525429818247, 0.050605959325496636, 0.04287492809817195, 0.01789215250339891, 0.08389637672475406, 0.03320897623364415, 0.028597815095313957, 0.08094588254711457, 0.021961077648614134, 0.046678283118775914, 0.06660502457192966, 0.024796297208272984, 0.050304431933909655, 0.044718436497662745, 0.015569479637114065, 0.05367788073739835, 0.03812303540429898, 0.05348082059728248, 0.046668237407824824, 0.03852173240323152, 0.033788438354219706, 0.029947183760149137, 0.033874327316880226, 0.01225890897746597, 0.03136445003162537, 0.07280803564935923, 0.04301102186686226, 0.05823453515768051, 0.050640489972595654, 0.05553074613479631, 0.04318974459809916, 0.008846028807706066, 0.009148256786699806, 0.06027947685548237, 0.04765388076858861, 0.044915523779179366, 0.028657512606254647, 0.023251322164599384, 0.010088173672556877, 0.021630861796438694, 0.031256345832454305, 0.04577745324266808, 0.0760314433968493, 0.0032542352897248095, 0.020307862698765736, 0.005319770101258265, 0.017591378285682628, 0.03572198495801006, 0.037636698822357824, 0.03030099906027317, 0.059366779401898384, 0.010880262374744883, 0.054959273764065335, 0.0453114082504596, 0.0799122362264565, 0.03829568524711898, 0.023451508654813682, 0.02246775840675192, 0.05427860136010817, 0.04392962936045868, 0.015183510258793831, 0.02771674415894917, 0.027800787506358962, 0.03586328987564359, 0.008417745137454143, 0.0362362432559686, 0.01498590050531285, 0.005874745165263968, 0.05756182875484228, 0.054282000820551596, 0.04589983042595642, 0.018398560151191692, 0.021289253341300145, 0.05032230793897595, 0.0077588223253509826, 0.031040758293654238, 0.024099166937438504, 0.08549670156623636, 0.04236759425007871, 0.03069007782531636, 0.03692552626931241, 0.024129870647032346, 0.03396495245397091, 0.0015864728671398812, 0.02637010150855141, 0.05523222804601703, 0.018635212809645703, 0.0247034888847598, 0.025442800285028558, 0.033067501682255945, 0.09327337784426552, 0.030351339573306695, 0.055614619848451445, 0.063062420380967, 0.030219259339251688, 0.035341130037392886, 0.05537473736330867, 0.03675844380632043, 0.06400411163589784, 0.07117495792252676, 0.03017797048336693, 0.04199499710063849, 0.021215830763269748, 0.059543266360248835, 0.05974768181996686, 0.008422695898583956, 0.01837911333755723, 0.05939939658024481, 0.020341558747791817, 0.051584254152008464, 0.005122239227473203, 0.028793236573359797, 0.04419604256483061, 0.026516636234841177, 0.024022221066323773, 0.026367336478350416, 0.04176353523507714, 0.013890709362125822, 0.061858088576367924, 0.046646442863025835, 0.05019928954009499, 0.03831792423235519, 0.0229584545761879, 0.022736765311232636, 0.07740835379809141, 0.03494234482890793, 0.033812668839735646, 0.036100678744592836, 0.06060751461024795, 0.01008688869686531, 0.03118627012840339, 0.04915066795157535, 0.04104559090254562, 0.05542712365942342, 0.033260789167668135, 0.0328336819075048, 0.017589380000052706, 0.016740103518324237, 0.05152664313625012, 0.016989309074623243, 0.01380078905328576, 0.02658363478258252, 0.006217337072095168, 0.02694396741156067, 0.03331846125157816, 0.09229300330792155, 0.01986228741173233, 0.039701209470097504, 0.002588022467015045, 0.026987824522491013, 0.009596910078211554, 0.06121292390993663, 0.05194247653707862, 0.021875321000282253, 0.030822320907775844, 0.0552813438033419, 0.020957943351407136, 0.0356353156800781, 0.022445901097463708, 0.02755667774805001, 0.009238483284467032, 0.03991861209007246, 0.025658116409821168, 0.05428955630798425, 0.018415448887805854, 0.050447972624429634, 0.08422707433679275, 0.05863024999520608, 0.05364896157490356, 0.02790652701099004, 0.06919171541397061, 0.036644972395151854, 0.04488979373127222, 0.005847462120332888, 0.09652064288301127, 0.05635492190984743, 0.014019208627619913, 0.029305421946836368, 0.033213424030691385, 0.051675890306276936, 0.034408202062227895, 0.03197240723030908, 0.0056324984096655884, 0.04585668577679566, 0.009792239954029875, 0.03525815198996237, 0.0162712765325393, 0.015873395471966693, 0.05648638467703547, 0.015182470403877752, 0.04026869544759393, 0.02460169336492462, 0.01864213217049837, 0.038174899228449376, 0.015886867784761956, 0.029355131422302554, 0.017822558559211235, 0.025600605477978076, 0.05605342844501138, 0.034948438073375394, 0.013229315834386008, 0.0697110186197928, 0.03295740259013005, 0.036320398561656475, 0.04459487527076687, 0.08837860942419086, 0.0093619240713971, 0.06306172148989779, 0.06262946754161801, 0.0557787065793361, 0.012731145601719618, 0.02815692000357168, 0.024124131937112128, 0.11785687798900263, 0.009500643770609583, 0.007400434547370034, 0.0671048266813159, 0.06164023812328066, 0.05254903595362391, 0.03744024936375873, 0.0069242547864892656, 0.026451111804427843, 0.03132364632827895, 0.041483636147209575, 0.025324278876983693, 0.04753266048750707, 0.0995491821584957, 0.022669446155694977, 0.045771597485457144, 0.024030204030818174, 0.03072188076164041, 0.0659225404794727, 0.06379099735724074, 0.005379634277362908, 0.08429693630231277, 0.01954752010559397, 0.03399149335122534, 0.02875399010788117, 0.023925419564225843, 0.0463465473481587, 0.034727802234036584, 0.04240215203857847, 0.02319037784556193, 0.0796096638909408, 0.0657587285552706, 0.017447657783382704, 0.050331424056951485, 0.056291553524455855, 0.023629094839894345, 0.027424996153318455, 0.020207622720460807, 0.012488642275067312, 0.05237645057163068, 0.034000466976846964, 0.02736227916154478, 0.012056071959835078, 0.019332497447196926, 0.032098322973719666, 0.027058565190860202, 0.026136332623926655, 0.029984499793499708, 0.06134977763784783, 0.03896399474303637, 0.03310207982680627, 0.03917405561410955, 0.012924287202102798, 0.015890559015263404, 0.04425075962873442, 0.06691517614360366, 0.042661372771752734, 0.02090969611890614, 0.08435735306037323, 0.025584062794223428, 0.0301414381579629, 0.06871813868305512, 0.022444528760388494, 0.08862947739128556, 0.09048896868314062, 0.1617420395570142, 0.17601880989968777, 0.1921179217419454, 0.09359972604683467, 0.06896873523614236, 0.15755642844097956, 0.11891897528299264, 0.12541544597063745, 0.12320141334618841, 0.1013919339914407, 0.08579382526555232, 0.18891849342201436, 0.09156923035957984, 0.09630473304007735, 0.17347996256181172, 0.2152099340621914, 0.12632215874535696, 0.11265397324625935, 0.16359777855021612, 0.10729720390268735, 0.057945357103432925, 0.09546546664621149, 0.08650698592620236, 0.17637542076408863, 0.15207311910177979, 0.20515939194176877, 0.14493664061384542, 0.07471070890980107, 0.19325073595557893, 0.147153713075178, 0.12329762961183276, 0.1464436533195632, 0.14720604169581616, 0.10721478225397212, 0.12098801854465689, 0.1033786234578916, 0.14206725172698498, 0.13126205652952194, 0.06982085986861161, 0.10708719731441566, 0.11704328736024243, 0.1909288162631648, 0.09389763684677226, 0.1688022507088525, 0.16225085939679826, 0.15306513729904378, 0.19869383530957357, 0.08537015478525843, 0.2900230474770069, 0.1316036989114114, 0.19343413040041924, 0.10153659765741654, 0.11857007257640362, 0.15930898939924582, 0.10096862992005688, 0.09681190403976611, 0.15672014760119574, 0.11709986361009733, 0.07702289162469761, 0.177784941558327, 0.11186150541262967, 0.15657214554292814, 0.11106329038739204, 0.1440021757568632, 0.24551416294915335, 0.1136510804561632, 0.1402028410562447, 0.10641340525554759, 0.2682133306350027, 0.15709320615444863, 0.10149166506848165, 0.16573048196732998, 0.09487234561571053, 0.13642057829669543, 0.07942578768623726, 0.11022147948720626, 0.15028876199253968, 0.1892707480915955, 0.13457250674920423, 0.20365164641823086, 0.11540803153600011, 0.13991886058023997, 0.1355484572372266, 0.10822923960430281, 0.29845900194985525, 0.10074683717851128, 0.23452276417187282, 0.16621932573616505, 0.10670127373720918, 0.11922743730247021, 0.0900919714144298, 0.14475617744028568, 0.1112397705603923, 0.09534906396376235, 0.1424219355519329, 0.11925126745232514, 0.14249387383460999, 0.15566398070326873, 0.12869514498327458, 0.2192151905702693, 0.13741368214998925, 0.0870879679652197, 0.12857504428497382, 0.15401413637612546, 0.08898914844862052, 0.1200444477477244, 0.3572898065405232, 0.15595746066953453, 0.1227327220674072, 0.11838230836604323, 0.11444376542099885, 0.1287014146468469, 0.13682806571679457, 0.11341411567160062, 0.16907388184751782, 0.17491871464465344, 0.16424347247396195, 0.13621100597083569, 0.13842864840158395, 0.08112091065517493, 0.13089239065136227, 0.1265947941158499, 0.11297492031008005, 0.13197218413863862, 0.1306741059358631, 0.09762671603155987, 0.1221882655684437, 0.15970522670873574, 0.1573769287871463, 0.13368910843772547, 0.17665584571659565, 0.10424088540353946, 0.1601369378290006, 0.10210907765265022, 0.11348401156387158, 0.08527254752282586, 0.13743097122226441, 0.11733364606542246, 0.07602609654090234, 0.14243857323059014, 0.1463422937584775, 0.14903700059013708, 0.18515664099582604, 0.18200795352458954, 0.2222685438713857, 0.15899219496973924, 0.08963900857738086, 0.07231230475008488, 0.07119910698384047, 0.13901005791766302, 0.09942116974187748, 0.19802473192768438, 0.15095983312598296, 0.11507588864437171, 0.15765435461487087, 0.08431931438722781, 0.09704899774598223, 0.12299391733748571, 0.14701286277600698, 0.15166780299374036, 0.1288313812443188, 0.09983802773058414, 0.07567817771009036, 0.1189018219177212, 0.16007261270923273, 0.15388435976845877, 0.15965914061026915, 0.16753454373351165, 0.11723837974880423, 0.22572490626147815, 0.11294570259217705, 0.1503471838576453, 0.18670956338090555, 0.13849361134426935], [0.03390264258320842, 0.03911045652681163, 0.050567574599491696, 0.00984513430323984, 0.008075562472056066, 0.02146115679559963, 0.01802926237827965, 0.04020777318094458, 0.033983615559658835, 0.03731899854860135, 0.08361578892384257, 0.061086960669074736, 0.031500218103506734, 0.01813154305065317, 0.026725601271859238, 0.014091601528759514, 0.009108729577357215, 0.04156232924599733, 0.06480263200189386, 0.05119976228369134, 0.02767605919923101, 0.008189937182968217, 0.051835217114005766, 0.0938073984746422, 0.025276218241612827, 0.019164805999025702, 0.0048400318482890725, 0.031651249820632596, 0.028012258033933382, 0.04888991033658385, 0.02798078757976847, 0.057889031911534924, 0.0025103403854050805, 0.05973940369273935, 0.03951250548873629, 0.04443788940885237, 0.022052501760689274, 0.020602314666445767, 0.01709337259775826, 0.09608991563852344, 0.1452425377709525, 0.011705869010516574, 0.02427933325192758, 0.013142070649856967, 0.022264018089377453, 0.014985824170123254, 0.022823195405570523, 0.0260890692672027, 0.02073891055104988, 0.020996875994439636, 0.03522246444065656, 0.018765500014913932, 0.08794938852744442, 0.03909756096878222, 0.054397857282310724, 0.045850582354302914, 0.021827362145164182, 0.028077690862119198, 0.06579591227429253, 0.009125246816048664, 0.02981744786458356, 0.0703690822369286, 0.026355046512825147, 0.011158923136203416, 0.023365965745012676, 0.008227862201498022, 0.04581315436267427, 0.013193199959849673, 0.05339291638561657, 0.018029477813148072, 0.018484944444415823, 0.06585029007068702, 0.0011890542705909216, 0.024292535847052932, 0.027058689023501108, 0.02519297895820013, 0.021232911186026673, 0.04019493190571666, 0.048469870018639734, 0.03547003472756062, 0.03534951673022338, 0.07213513247136559, 0.04191078072679894, 0.021166526712477207, 0.05046931594344122, 0.0055024779534765655, 0.008193136475581144, 0.071303262109203, 0.004599943258134382, 0.0436600813243006, 0.034985557331570556, 0.03868323391569512, 0.02790342440961727, 0.04909512307494879, 0.032837040655847104, 0.0304815640140857, 0.05057162206087794, 0.025037046521902084, 0.008790724811011126, 0.0439547690828996, 0.017866035690531135, 0.03577540602002825, 0.06449222937226295, 0.026074177119880915, 0.047924076805689504, 0.014052070078573056, 0.054786545889718194, 0.033101153626505814, 0.011564934742636979, 0.05680664981316243, 0.02920271549373865, 0.04829507600516081, 0.042813666564013274, 0.019568768429702947, 0.029012444096484354, 0.04600991255470684, 0.054799943563661406, 0.02633337919334216, 0.031055163592100143, 0.06661642396024295, 0.047763396320598464, 0.07486675839338984, 0.048779543223125596, 0.004743322796587433, 0.028617010850991522, 0.034961476123758724, 0.053840128638382466, 0.04253266146406531, 0.043512136941509585, 0.01863269883740161, 0.04098652442917228, 0.05294952767768076, 0.012030732917732425, 0.058874251187912056, 0.014734962988378746, 0.006330494660817618, 0.035389414589319906, 0.04610536886113031, 0.021049674500578215, 0.05779080039688519, 0.004592373351832586, 0.037711469988737784, 0.013365708158484526, 0.044861627742648125, 0.035789098856704574, 0.021164540301210115, 0.036564460822514126, 0.04405812353694013, 0.043431133430983336, 0.023450316129518405, 0.04523537840162005, 0.03347621725073882, 0.06798279671264545, 0.09092154154287917, 0.05540066079369613, 0.026900666699345623, 0.007243861743648137, 0.019605015770399144, 0.04173894851867642, 0.021986565120252113, 0.027216205839067698, 0.0517613009017493, 0.017632475455424616, 0.049719198873000484, 0.03081373743978994, 0.03037201114264982, 0.07175717489527804, 0.028987351871494735, 0.005312854981249464, 0.014250071686027306, 0.0621804062809263, 0.018401106353849173, 0.015375325323215552, 0.04423038322212441, 0.06862212597791638, 0.013058842392638326, 0.02185880036891571, 0.016435563431254456, 0.02936652741794075, 0.031591009481676986, 0.006106162926049105, 0.011464839801192284, 0.030334437265992165, 0.0375979510801179, 0.08884251024574041, 0.036991476480449946, 0.02541216103626149, 0.0099333735415712, 0.021183026987793188, 0.07782246371997253, 0.01579580838525934, 0.019721381133422256, 0.018291546697063104, 0.04325110451983554, 0.04211339806871755, 0.05043451048965965, 0.06614162586629391, 0.04115219214665038, 0.013889336176881832, 0.05179208942822047, 0.03045813080721668, 0.03903897964794721, 0.03255498721929533, 0.007217555789143911, 0.05306968605145812, 0.0687123779207468, 0.02598794040802334, 0.010863628936931491, 0.018923057542581643, 0.12109030091336795, 0.030212236501808678, 0.05523564786251102, 0.03969887191695826, 0.025111724389716983, 0.03845880167292697, 0.10587891643600804, 0.01765493835721697, 0.09278010324175869, 0.023002715415454338, 0.011893027628372823, 0.035118828394583294, 0.05219227920419403, 0.042982245196721384, 0.006295043326515172, 0.05267298733815551, 0.031059489252844026, 0.033707787681903155, 0.07049266381987504, 0.06443500851414033, 0.013681081905295807, 0.054043482190796306, 0.055559444773410044, 0.028122592916978256, 0.08798932709864207, 0.08205483946949244, 0.049247223484729014, 0.03274909233940499, 0.040800137644899745, 0.018662947928532958, 0.0265350737276354, 0.013737524144484528, 0.01375171570439956, 0.011457479392577494, 0.02515775111636945, 0.007850954658351839, 0.043014122771897485, 0.03528299315699509, 0.08542238162564379, 0.033471847485218725, 0.023855722143447826, 0.018322645653305308, 0.028131865098008087, 0.015055165360016482, 0.06040130103273051, 0.04196604401139276, 0.012015230088893856, 0.009954408975318074, 0.06540727455701147, 0.06589108359600816, 0.034514552248375754, 0.018927805591374636, 0.06386113752211843, 0.027946401121360914, 0.035881908876555305, 0.029080487588154416, 0.032175974521253786, 0.02951777626627258, 0.0034390094931170878, 0.05257463029452732, 0.020105584624356458, 0.04597124284399407, 0.07197410254073994, 0.0519841555505991, 0.019901569500299435, 0.040427910297044685, 0.040520041781876764, 0.03889408867274012, 0.07001171141330685, 0.06353189197501966, 0.007029663505298751, 0.01981318522510784, 0.038592880192611895, 0.01011061791463622, 0.003274820981979636, 0.03236687695607543, 0.03559827106073499, 0.009865074751100369, 0.0195985374573086, 0.012389492193636085, 0.036065279572669945, 0.052528744363891225, 0.045020717063120434, 0.023579943459481, 0.07090233612273421, 0.031739079393446445, 0.03887219913303852, 0.03833073836618236, 0.02718716623660709, 0.031235681048461368, 0.020716478183333362, 0.01704944424065096, 0.018339249405211637, 0.04340116932455983, 0.06367606709578208, 0.032321747591985125, 0.039551083597221544, 0.051051519345492125, 0.029375758886869465, 0.022095290178965245, 0.015324767678976059, 0.07601556567741291, 0.030209722529564585, 0.04464848632259028, 0.03615547723269888, 0.00514120894617268, 0.08145077366914068, 0.019037302483671477, 0.02949114376679063, 0.01231493306944945, 0.04685360638956938, 0.015148111086870943, 0.029549334929989915, 0.04902904394215771, 0.04732237909255283, 0.06106087778295789, 0.033613556131188355, 0.025544794276356697, 0.011464849131048789, 0.015471200625013028, 0.03449597056689007, 0.024761164361344914, 0.06928297158862863, 0.016069955192506313, 0.02530055050738156, 0.035207838618329594, 0.014363220793062022, 0.027794736670330167, 0.009259475461606468, 0.027849489357322454, 0.012864763565760638, 0.04824444032939417, 0.04143419808575085, 0.09493211098015308, 0.04870407995102661, 0.03506558035899486, 0.018753184604325464, 0.08214656383331333, 0.009124553013992096, 0.04073688121778624, 0.021108583214559724, 0.032982294647289176, 0.0256713291829718, 0.17353482890341962, 0.08819639563028302, 0.12472893138016973, 0.06378708221018314, 0.050664387975952456, 0.13407132721373013, 0.15140120658491338, 0.12333758175373077, 0.19198971933552197, 0.0913746604429824, 0.14559959646846565, 0.16651347066674912, 0.19506125737513813, 0.24498262575694493, 0.11368696138794933, 0.10320099656070982, 0.07131042065364973, 0.10457248546715293, 0.13510419321911676, 0.1725977584719658, 0.11502543278038502, 0.07929998050842967, 0.11843967171651976, 0.1458221288131816, 0.08321643035326685, 0.08493053194667612, 0.11425012509737696, 0.09512410924902984, 0.09959382976272277, 0.20482268929481506, 0.1279234742479665, 0.1638201887586287, 0.1414911076426506, 0.15622233359941415, 0.09354747885039874, 0.07920064976704971, 0.13384570074932917, 0.06578351543950182, 0.17248335746782167, 0.21638024412095547, 0.12171969642596585, 0.18031681355621132, 0.11963223772389547, 0.102340227392103, 0.11053835534091506, 0.13775508025927202, 0.17430823668837547, 0.12272843372608934, 0.13588032871484756, 0.15455293389303343, 0.1508403838213001, 0.10937318179224219, 0.21108663960226945, 0.08214626527790513, 0.08820499945431948, 0.11403999637280192, 0.12058358453214169, 0.18080621372376168, 0.21645785495638847, 0.12084883744163172, 0.11341732514223882, 0.1904195485902684, 0.11247182730585337, 0.09081051285777773, 0.0914684407679098, 0.15181634788002285, 0.0741920978096979, 0.07239205297082663, 0.10178986763847725, 0.13380749922777924, 0.13383835900042737, 0.15758602613849299, 0.08906456083059311, 0.11523364803620748, 0.07298642929111208, 0.08828917172338281, 0.07526371494999953, 0.15985402943832533, 0.16493830590375833, 0.22346778666334494, 0.18035661642040524, 0.16132248778428349, 0.2074129017336028, 0.08616567602647202, 0.12263319455087185, 0.13412079241658958, 0.09334415583206074, 0.12046980778021471, 0.08675327378192119, 0.07507271412760019, 0.1934247123343604, 0.05840890508677278, 0.0990064355677792, 0.1764785038041217, 0.16181072087160178, 0.1664013766816684, 0.1387936866709164, 0.06974525071148362, 0.08144635640616928, 0.15151738535080636, 0.07414477677749735, 0.15232279284724168, 0.13393576948770455, 0.08513602627707378, 0.08229208923876286, 0.12815078347921371, 0.16132573118167265, 0.11596183824752058, 0.1400989166327885, 0.09623822303754942, 0.08476360554673842, 0.08319029318434851, 0.12915592454373837, 0.12110524225447859, 0.15599516007517064, 0.1564831081777811, 0.13641957406486782, 0.15748991843845161, 0.07027501692729336, 0.2683669781046254, 0.18823971413075924, 0.14567126333713531, 0.1289300945188318, 0.14219401563916886, 0.10092058964073658, 0.16541048485253537, 0.12296809229467597, 0.11224698115672384, 0.12567491776176862, 0.1400630357010024, 0.12623571338398115, 0.12575282715260983, 0.14893169195524283, 0.11507345948900495, 0.12282854478274073, 0.14628749527037144, 0.1881138323140996, 0.092590981961361, 0.10801225767603942, 0.19805234830294335, 0.07651817692177636, 0.1199291782187564, 0.09804358080561672, 0.1472727416881493, 0.0890668271375554, 0.07988531195691653, 0.10676182620227337, 0.08899351142879043, 0.10416583264512674, 0.10023325402289629, 0.09318735995995146, 0.1270718313753605, 0.13478825374373368, 0.10451522389692919, 0.06673783423112971, 0.12108745106628963, 0.06278595807296888, 0.08754857110657863, 0.12605980996574673, 0.11356242985597678, 0.07943483934338604, 0.15505445269601686, 0.11088792979717255, 0.16953779623976775, 0.11208102506186281, 0.1092961137848241, 0.19980751483568124, 0.13039392525596277, 0.09635434073529073, 0.09599393686013562, 0.20505488397819654, 0.14110613401447022, 0.10843115805515222, 0.10325692141694681, 0.21827886652733597, 0.15766624254839762], [0.08992444111832551, 0.04110796184145978, 0.03360204478459699, 0.010045286866703203, 0.009345532361684101, 0.011863649606571665, 0.019494579107101475, 0.020626786031893322, 0.03780180335577045, 0.018607379303180745, 0.04857794029105987, 0.04521757025005562, 0.015704453823023608, 0.012719244945661297, 0.058990776006664546, 0.020824724874858345, 0.01060318005537348, 0.02483928240170436, 0.0997856380417943, 0.020877755779240812, 0.044191170683396716, 0.03576168943462627, 0.031225849076041153, 0.030536969791033437, 0.030505187210759947, 0.006508164390522454, 0.09084473816411835, 0.007103888026904315, 0.013088033817309355, 0.0557634429340916, 0.05651692893089993, 0.008082067078378583, 0.06941696868411132, 0.1053281631320715, 0.024341556609475186, 0.0407019095229251, 0.06690968679530279, 0.058129552219595225, 0.0029850623562067214, 0.06532359761851174, 0.03566268778273037, 0.07314395119569131, 0.04765500035136938, 0.028370887540014725, 0.04454749656308975, 0.0732759398275188, 0.07905027962156705, 0.027988108972619687, 0.032415134366601706, 0.04636987538209983, 0.03833914541506341, 0.027752667499173964, 0.036776808356600146, 0.06050399052245276, 0.010307065676897764, 0.026761375334379927, 0.019952330705044524, 0.05905291624367237, 0.04506936463128243, 0.025118219666182995, 0.012438967574520834, 0.026351465544264232, 0.060158039443194866, 0.008926437751922225, 0.019469403761572072, 0.051440170633473566, 0.01160259428434074, 0.08962421651397433, 0.05344090238213539, 0.043390445078590086, 0.028883271384984255, 0.011283257893020553, 0.029325102855052267, 0.042587066401860545, 0.020670112189171568, 0.03510435863531061, 0.04488640444885407, 0.02614347929401057, 0.04684301106525319, 0.048606526971395524, 0.012404699859741544, 0.028057867461549382, 0.03509230785337942, 0.03136801573314837, 0.04885254341310688, 0.04109261337933796, 0.03489961747878364, 0.05164420611358114, 0.02754938688927463, 0.007463925069064966, 0.012463850301823445, 0.03661948322717633, 0.028415097489154766, 0.03735468949058226, 0.03947131162775414, 0.026385987709675516, 0.035867469651358466, 0.058097633932318, 0.03287947623591338, 0.0331420285760292, 0.04061607823574117, 0.09107678356979575, 0.03930152181003775, 0.021673548434461867, 0.05966249853372574, 0.05599301168695092, 0.010748266109398432, 0.010929544373149318, 0.02408887865021825, 0.00498762890596741, 0.09018285439482757, 0.01617920950853399, 0.040908092566366704, 0.0664797466514366, 0.026634487589555125, 0.027033868212518946, 0.06143753257180963, 0.04144166197095599, 0.03245420441297548, 0.007551987040122705, 0.015728190674313476, 0.04629531456157565, 0.03942831625629749, 0.04398222260975412, 0.044188900983759334, 0.024541320711640374, 0.03521142806857824, 0.02724653635440128, 0.03815138120470302, 0.030877831857651472, 0.026607196911105087, 0.018817501242405603, 0.028125822743667022, 0.052698792024914703, 0.02189302906793143, 0.06401222012937069, 0.06971214498792376, 0.025614698650315404, 0.05162925459444523, 0.020954308100044727, 0.042134212130414586, 0.047335257687206776, 0.00820186413225851, 0.01147216882756246, 0.03060735422851784, 0.027247681382245252, 0.02963852496551616, 0.014788112636389477, 0.014435362636244722, 0.032602562702127864, 0.006451973209290632, 0.030113825175379003, 0.020011498958670666, 0.029257744683751037, 0.017950230011982576, 0.0646288049008165, 0.016322963937584842, 0.052055890272770605, 0.04973790608346462, 0.029156364766614776, 0.010491332887405795, 0.04198707520429577, 0.031573608451123746, 0.02750025756124939, 0.020877413119056394, 0.014355673787317105, 0.03986802051908203, 0.036439881793090274, 0.039645240509084294, 0.07321316855294363, 0.04391903403614249, 0.04235830510567341, 0.02613244970728244, 0.035669300106487105, 0.024753088098285452, 0.0271789797116071, 0.05137726704456976, 0.02687891117031021, 0.019992589884038483, 0.025609400988157307, 0.015624225538756167, 0.04557390970044902, 0.03917336690106562, 0.100436020642519, 0.024593330420819775, 0.022701754600607922, 0.07341864931264094, 0.04009100069691028, 0.0582510099879333, 0.02113691883693848, 0.034421372426939864, 0.02584091035116996, 0.03548082682703223, 0.050475904518472295, 0.036013575204248936, 0.039292636393968544, 0.058536272895123274, 0.07157622996185507, 0.06838226384882416, 0.045511399661856036, 0.03661947983450123, 0.03669848505939756, 0.024663650397477404, 0.02076743446689631, 0.03461160311209304, 0.028917605256927863, 0.015551271149888635, 0.03840795225862946, 0.06847610524190323, 0.012968458135479262, 0.04495912304680262, 0.04281816864386201, 0.048176427371799946, 0.06528353012566056, 0.00976448193458574, 0.023712205201653496, 0.0350602877858494, 0.013647926139778324, 0.01128807379531541, 0.021283278840460947, 0.014415110062275614, 0.07023692397134644, 0.011779266991652548, 0.021346720168367028, 0.013210960613962795, 0.013114019164017268, 0.06611907814762422, 0.01935913333935397, 0.04275358907346215, 0.0390367744091366, 0.044292146872196875, 0.07953446864017419, 0.022535616997629404, 0.056198109074362686, 0.019218237239069173, 0.024027783357139145, 0.015589813635285412, 0.020798596187627742, 0.02291655503878636, 0.014833040136311735, 0.04866052478817957, 0.03206520028678434, 0.01925244727837188, 0.05739532304661615, 0.039091725567621846, 0.0717763706509556, 0.05486315588599869, 0.02267679468994694, 0.03572071949020028, 0.03543077129870653, 0.04152416843654854, 0.010257922778172153, 0.04467176685908011, 0.028390453097277453, 0.040134128382695575, 0.11053212638944387, 0.05279649767492499, 0.022321479827431694, 0.018099411024845073, 0.022269909469676868, 0.023731205878513198, 0.028074389789253473, 0.049813036873404465, 0.048314336221665144, 0.0193245789435293, 0.07212960919631378, 0.014435379599620188, 0.02782432927883097, 0.04396099124902061, 0.02469817256288869, 0.008070592203044465, 0.02257841220125556, 0.023579614369996955, 0.03959771930905325, 0.023329599660688212, 0.02912354063508766, 0.013475378077211124, 0.027607640816963146, 0.046591237253908596, 0.06295169703662395, 0.02802774220305894, 0.016109715648261563, 0.01007491849096758, 0.020617084677464197, 0.01294934210766639, 0.03145602172506707, 0.010772901171419238, 0.02607911515847913, 0.0483827834416713, 0.0016570149579950208, 0.043487628256636005, 0.02838744718714484, 0.022112587732928138, 0.026569826594953026, 0.02413589264532285, 0.019176917849108577, 0.0763002789712378, 0.0517676282407982, 0.04135335063827889, 0.04817441551546965, 0.04846046552328127, 0.03349399486822741, 0.010160740448295005, 0.04258572629519871, 0.01397597067989409, 0.01349231431127659, 0.0259018614555576, 0.026864711128707443, 0.04862208917204823, 0.04347334509449346, 0.03254921967163682, 0.020359265119103447, 0.022097108652815223, 0.04612082928153021, 0.023869367482672845, 0.07811608617859227, 0.026522190043968812, 0.02375488166165139, 0.06274618235017572, 0.0406913209839591, 0.017713156661817005, 0.014965461334213614, 0.02827285958587059, 0.017706776736304164, 0.024847904885453836, 0.03995935133259211, 0.001735027931447673, 0.07624136856091873, 0.03161421537931476, 0.017922876569043313, 0.03385893814265728, 0.04178608295374683, 0.06119910215160676, 0.03624104389122554, 0.037499217449554374, 0.02809246426581272, 0.04812909955424922, 0.07327119008238826, 0.021461932021858435, 0.00855034020995455, 0.023111338693914667, 0.04821543635002204, 0.08700391104710953, 0.025487447889255624, 0.0323904356919229, 0.0403461230785719, 0.018604700786194632, 0.01956356067343482, 0.03490286087617278, 0.0460647076501378, 0.011756269743533006, 0.03627357964536973, 0.17508659777896746, 0.10626755415328912, 0.07614631937550646, 0.07733330103967871, 0.11235551283295665, 0.08633704004543168, 0.12923208331423147, 0.14406282321682998, 0.11173912483666625, 0.10885117801704577, 0.20446092156427248, 0.14801425832722867, 0.10172785632312298, 0.07993365757699523, 0.1435764493154628, 0.07148223929107189, 0.14294721665126936, 0.09219069379780974, 0.1387064813503197, 0.19856674570058072, 0.16447159594723157, 0.10020120002861534, 0.15953819852854523, 0.12400208466819354, 0.12159300036728382, 0.08297700927193676, 0.1768859098000186, 0.11662731825241021, 0.14188843060817036, 0.12670230120420456, 0.08659271882580859, 0.1210301827107157, 0.1338647540126528, 0.1760194477226053, 0.16867856734565326, 0.11001330494348492, 0.10097151369388614, 0.1718059488173042, 0.09093976699348007, 0.12877635205430643, 0.0987633503973484, 0.17496283299156598, 0.11028577068022319, 0.1298307819025857, 0.11550612055829593, 0.1646477843501738, 0.18098736900304044, 0.14458927139639854, 0.0730708594034825, 0.12011634531830039, 0.2121373646493469, 0.08325940197599785, 0.1848180927336216, 0.0957976027524897, 0.14527047984302044, 0.1534872810755457, 0.0714510538216148, 0.19464672676154546, 0.12491091447217123, 0.12473239190876484, 0.09724734710263354, 0.14246922944273266, 0.11539360588150364, 0.08689229203654186, 0.14152016251214913, 0.10161366566483464, 0.08955096187336103, 0.15515255528901303, 0.13839933568877832, 0.22092328034341335, 0.1140655092895031, 0.04890233092010021, 0.07380039311413254, 0.13182465705488408, 0.14239924534090928, 0.12341356410511903, 0.09492204830582653, 0.11806797023330416, 0.1320438917194094, 0.20987222476729325, 0.2367989777454308, 0.08750370637114559, 0.08365580891924244, 0.1442162942673479, 0.12049114092120103, 0.12990977694945677, 0.10416399381522622, 0.0876924137451819, 0.149062649213842, 0.15940692914383753, 0.09641925618052483, 0.13827388813453062, 0.10702283826789685, 0.1361027524939605, 0.08077812833445412, 0.06531843396701983, 0.10549477740590062, 0.1934651258800711, 0.10048925171473197, 0.12932671180793218, 0.08209369917001043, 0.18990896455943584, 0.12920418195426464, 0.10617399774491787, 0.13920048198529653, 0.17433547308402403, 0.11608164039041315, 0.09195334224828652, 0.1408511676958629, 0.12630386544125421, 0.24455346592835017, 0.06108538646783147, 0.24324891450149672, 0.14376932967986378, 0.09452777196254049, 0.10369165880339486, 0.11072357504495553, 0.07445146103522607, 0.1626466488731759, 0.166864951806409, 0.19141875925873006, 0.11077511656497206, 0.09511422977915832, 0.14182964233415468, 0.11744389443525247, 0.15535437874495983, 0.09347906894981861, 0.105390764772892, 0.129177488386631, 0.10814176965504885, 0.12854045256972313, 0.07807211710938386, 0.10822288173117808, 0.14187095154608997, 0.10255867495600667, 0.12000615123127188, 0.12498629971274308, 0.10856123321822711, 0.12875465250441007, 0.13118819120739186, 0.17808650966201509, 0.14169947217617715, 0.07280115530427013, 0.12966734995799406, 0.1576388840164457, 0.11138804403266736, 0.13180446385272912, 0.06061058837388243, 0.06309542432427406, 0.16640311373131617, 0.11662996453898293, 0.13355218007096223, 0.0907002305611968, 0.08818394451269082, 0.11312764497207743, 0.20937565926994595, 0.1572982594370842, 0.15856375438826426, 0.09712183169488396, 0.07959772845996277, 0.12094642434801374, 0.15286173964185373, 0.14985285752585956, 0.08184927050024271, 0.25270454425896915, 0.09485496154853276, 0.2324602891291891, 0.13660241211099283, 0.11602319138390677, 0.2629285199301583, 0.12481410109571048, 0.13754814064928464, 0.10347468366048165, 0.12704449998480932, 0.07199197515313115, 0.1221573922250952], [0.010285420409802879, 0.028332543526110903, 0.05660792047690068, 0.03791453177109361, 0.020910040475428104, 0.067571767339749, 0.007872989234913672, 0.06063029303082398, 0.05196278848286186, 0.06448889097997121, 0.03764574369415641, 0.05259546471227493, 0.027200075365336876, 0.06111716904810496, 0.017126052540593913, 0.009475815326108463, 0.049410319554486444, 0.04447902898703303, 0.011732751719786652, 0.014133356029300817, 0.02189263212494552, 0.04963631242779749, 0.030895612867815152, 0.058888839690812995, 0.02742930654702442, 0.052433861419558525, 0.020335509608100568, 0.038035959005355835, 0.027782889448904564, 0.038820440481816015, 0.0712658069761736, 0.009605429085370685, 0.025394815984847288, 0.05809558475656169, 0.028620708866843154, 0.04350746862058129, 0.03109014207231147, 0.03762586261811001, 0.022227394161745906, 0.03529654010864241, 0.01792643209254103, 0.025620506910075034, 0.031118640543094704, 0.056682613611753495, 0.009173992771788366, 0.04343793913722038, 0.01227079436648637, 0.06926175379859549, 0.09172489307820797, 0.037412171584687064, 0.03527476591989398, 0.025207496214924113, 0.027373919429789697, 0.021208080197019235, 0.0896375293710402, 0.026519221453262225, 0.061495425179600716, 0.008581975208861488, 0.036784852389246225, 0.02875155077448913, 0.06301426475069352, 0.031756996110613854, 0.015881853410974145, 0.0345327030601246, 0.024815453948186975, 0.03762394575668233, 0.057622204800801616, 0.04876940590994699, 0.07477699499577284, 0.06868084639843021, 0.02661654881999961, 0.04970940761268139, 0.02139727950894407, 0.04890270411436047, 0.0419999130868486, 0.04069471026637724, 0.008586277120879717, 0.030475467376943146, 0.026956024978842055, 0.04362336579444153, 0.08043261151760817, 0.051789684021579366, 0.01935326401144266, 0.02803462933349822, 0.03464497685698526, 0.07707382924854755, 0.03545221300529582, 0.026684492227754424, 0.07367141717778784, 0.029483337221401076, 0.028963179061455385, 0.02117404488048383, 0.06003294472715684, 0.025023011025041342, 0.044051589244710546, 0.02741779011142041, 0.02990013753463115, 0.04380177979224494, 0.028571128313030516, 0.04064126206295831, 0.007141797354311815, 0.07736204378306866, 0.0834469422698021, 0.02701553758899016, 0.032905589656106064, 0.06867763014244181, 0.0979197888768145, 0.03799269561256681, 0.06173418129661253, 0.06646922257329736, 0.09785018475460154, 0.008888463539603566, 0.03932450718379446, 0.02372954855673015, 0.04472198523581028, 0.05842802620359829, 0.09558881752725158, 0.008386763228502656, 0.046675647010228465, 0.018469548484842693, 0.02681270650854068, 0.02558979302245591, 0.050067480720047436, 0.015849885929908072, 0.04478477008108582, 0.022922768723219633, 0.06326771793620926, 0.05598301347345114, 0.0066818926799377155, 0.04743443236553243, 0.020273194648325443, 0.017635993659496307, 0.039330522396734784, 0.03862974500017507, 0.015034403884783387, 0.00874352761145149, 0.05356853481914316, 0.01583802853045719, 0.03540226604257311, 0.03727101933743272, 0.017776703162650977, 0.02949327775942428, 0.04391608919416155, 0.0034350705973338336, 0.034723463002592325, 0.04582664703152009, 0.04548190713727048, 0.04032681875729135, 0.04919217393866607, 0.01010082835065467, 0.02060171077027917, 0.01841995944934232, 0.046449637173541954, 0.03733747505715915, 0.016717604993443404, 0.019348110537976027, 0.03455267913107361, 0.06537119685006992, 0.020766097752909576, 0.09460607490369252, 0.05347977565335376, 0.04681498417630792, 0.026030274207836816, 0.05305261750306402, 0.031217330068882023, 0.04268100957519241, 0.07121537146823746, 0.06793404397155557, 0.01417455158662051, 0.029547608058367456, 0.038733547287327905, 0.07909842846649033, 0.043569249234029224, 0.026059922795476656, 0.013496902056171425, 0.09577636460640601, 0.09667101981384413, 0.04731027402782014, 0.07149652245321444, 0.021235542205561484, 0.026200939335727265, 0.055011544709226916, 0.025359365922798003, 0.06935965283108608, 0.04645693821034261, 0.027239123359322548, 0.02517551007414503, 0.03160867174821241, 0.00606148224323988, 0.08188889015998159, 0.011913232704890626, 0.024995370901056697, 0.027759118670863763, 0.039564477878489664, 0.0323925459358309, 0.06768753898463079, 0.0630035846095, 0.060453819643173895, 0.012114283479084926, 0.04071709852931755, 0.0384328816352146, 0.06660290075732128, 0.029399975801685026, 0.07671526420329298, 0.002563551313609683, 0.03577305150351354, 0.017127886281481812, 0.04601436713710427, 0.04799070215917059, 0.02908327636708106, 0.035165148587631326, 0.046663765862051926, 0.007296411736336137, 0.05087945982813835, 0.03328178982649531, 0.0427549156094236, 0.02630587647269879, 0.03605373429932764, 0.08678279684058257, 0.018641609698534012, 0.050962583760597875, 0.05444662020142589, 0.015071855625137687, 0.03887022798880935, 0.05431908615199583, 0.03135798020022256, 0.0077060713166637075, 0.0397177792952529, 0.05322589499077626, 0.020096901072455303, 0.00600518546499578, 0.04502007245485272, 0.07942411849009139, 0.030581736138888767, 0.05557589924761227, 0.031949333646999936, 0.0357494283068393, 0.03499845288959997, 0.02781087053673608, 0.03495396474110229, 0.012110121514914291, 0.030929315702191422, 0.03491692690710936, 0.01208864079256143, 0.04092224680685571, 0.0335116707054632, 0.03334755004782762, 0.09154289641550609, 0.06451590345906359, 0.034424870274960995, 0.009461410875831331, 0.04116802576131054, 0.056305585628641505, 0.037861382123082876, 0.025470715215695754, 0.006861883423490716, 0.024365493628595556, 0.0027746895710671587, 0.018685500736215284, 0.004570929948905749, 0.061239264639360566, 0.018983240206060664, 0.03697087276460869, 0.041826862908367596, 0.045751190544771295, 0.02329947440219777, 0.0591913102460759, 0.026157022852982794, 0.021422668593004346, 0.07138162611850671, 0.024155731312930584, 0.029674229478197436, 0.022900833382404277, 0.02645843998262925, 0.018162976185392057, 0.024890871419172202, 0.025731284537219574, 0.031617160221295695, 0.03005352376827172, 0.05034913382093821, 0.07805204604353223, 0.049030523148498366, 0.0494306247149195, 0.008618806937842496, 0.017908255835728984, 0.07387617190501519, 0.05758755201739924, 0.017900238944483653, 0.06335381724472557, 0.02582471032759973, 0.060486620025975366, 0.03313847644520657, 0.02893523359671235, 0.05530523502134851, 0.03988853602537087, 0.03718600229227117, 0.05600001077566828, 0.03205532420958791, 0.031868571016405306, 0.015842137059995105, 0.023490665214402334, 0.038265368302485774, 0.012307419990455466, 0.09915315519486155, 0.01726769163672413, 0.07687726443899529, 0.052996339808617315, 0.026970923911514025, 0.021686382924339602, 0.08179633798343794, 0.0060069153052089465, 0.015260147396475077, 0.04653446762157338, 0.0019095455479275966, 0.03646103172962155, 0.004188603455466884, 0.0058926546729968065, 0.06609924456902913, 0.051968698522874286, 0.06690693872847728, 0.0418886129877397, 0.0156273196584412, 0.06593569727348429, 0.04451736282291157, 0.04148147162050009, 0.036559443056051216, 0.0396296240256301, 0.02855325909331441, 0.03133541551817741, 0.023404001025483012, 0.0914310874151332, 0.06276482170713799, 0.019743357186338732, 0.050909905694425106, 0.020560686543051685, 0.015317777071946433, 0.018340594600886106, 0.05101671049903546, 0.023250870938811983, 0.12621862787221158, 0.027799537305587103, 0.027191904107374803, 0.05278210933985455, 0.034563230350613594, 0.013354608173748212, 0.017950813552098613, 0.028078941062891057, 0.01869218091347388, 0.010118356606523906, 0.03352966884683285, 0.017328094824084213, 0.003515227635424318, 0.17092546820640564, 0.14100869638579233, 0.17196275826011384, 0.06963756720402411, 0.06678797796900783, 0.14782562559204443, 0.07084640448114701, 0.16114118322730064, 0.13177616894245148, 0.1097901619172522, 0.09994975530675479, 0.18773705538894447, 0.14226811166320527, 0.1820155938288995, 0.08978686135794435, 0.0982514771499804, 0.1265186353453568, 0.1423311068543366, 0.06448988842644862, 0.13463084719010762, 0.1489582091037716, 0.20292479970625468, 0.12333435192704201, 0.19677700102329254, 0.0986031550647957, 0.17965430553470338, 0.16991084122232028, 0.09442241583019495, 0.09901508688926697, 0.11795370493616376, 0.0957603986774172, 0.13507652256105626, 0.09859858852412019, 0.12035779521933623, 0.07542424276471138, 0.12709148174950055, 0.0897905525884458, 0.10559042370212929, 0.07500864006578922, 0.18850184577916348, 0.10400603086288486, 0.18466182611882687, 0.18048354318099363, 0.2314247361251286, 0.14775284592594418, 0.14678556711546012, 0.11556976714304515, 0.09031867674951043, 0.14503276188458714, 0.15639054243053707, 0.11581589893570968, 0.08270792942494154, 0.10966322837131363, 0.12853427790105343, 0.08948318301034824, 0.12070145963558129, 0.19852236951036112, 0.12495193869939872, 0.12053843481200081, 0.09292787459811994, 0.09154434169509582, 0.08705536435757365, 0.10273306524114949, 0.13321391679346561, 0.10471940186939069, 0.16417454688676766, 0.14750991681856768, 0.15635620855859347, 0.14102257921227387, 0.20231700874865055, 0.0746827329109822, 0.17121608475489275, 0.12955374962517194, 0.12648981117776462, 0.0980464510087456, 0.16410623198109014, 0.14647308816867216, 0.16484778933227062, 0.1272185713584934, 0.19649945305926458, 0.13660893961787224, 0.1407364002828087, 0.11125972627529077, 0.09250748144196612, 0.10241800107594047, 0.11051980419350521, 0.17354696110955306, 0.1718476108674492, 0.15917687863111496, 0.07535560894757509, 0.10556691924908332, 0.11953053889530045, 0.1287446916103363, 0.1197673747582095, 0.13731237687170506, 0.12932922238750116, 0.12386985176375934, 0.11079900778297867, 0.11540670160736356, 0.129488148859569, 0.16705534873264177, 0.23625302846942628, 0.1707903311720916, 0.16138025825577124, 0.254313730767795, 0.12170115884925638, 0.1981211653245347, 0.04718932176807097, 0.16021633999688284, 0.1217218813087259, 0.16811725603682653, 0.06587365203137908, 0.12080469195331846, 0.1322180988000972, 0.171185129987342, 0.13991877915603773, 0.15109254100493022, 0.0950026379099914, 0.18787627720407077, 0.10808495591793742, 0.17202666268817016, 0.07467644967670951, 0.11989671710346426, 0.08004093396344356, 0.1503301119165761, 0.14781014142291887, 0.15395766869187355, 0.23757606319018773, 0.09469934632735592, 0.1682758160999843, 0.09169427079281636, 0.10008869892252342, 0.07477590255439281, 0.118385429627129, 0.09086983038910798, 0.17413716443947383, 0.192191624215671, 0.1517459973692894, 0.08495086085583482, 0.10979293712547847, 0.1853971273771354, 0.15839657693036965, 0.10757205129734107, 0.12580769349421772, 0.08326341211795807, 0.10610395936029297, 0.14592371907617363, 0.10684467532805034, 0.13943064106362207, 0.1067951897691403, 0.09201151305543524, 0.1166667275662933, 0.09696967700230223, 0.17924759164452553, 0.18014449280287537, 0.13349037910146372, 0.09841230352010046, 0.13576155794518335, 0.09662172424473933, 0.17759972863963672, 0.08633549298558917, 0.11376707601760115, 0.07724978016423327, 0.2202365214803389, 0.12468996989939894, 0.14753088355064392, 0.18460231859769138, 0.12439585211021559, 0.08229875923799616, 0.08277458191982337, 0.1310780785445656, 0.1169237702020577, 0.05997203263853278, 0.09769168575959546, 0.07246838816042457, 0.14158987519996508], [0.005843509653849261, 0.037913256125258546, 0.07647863868623972, 0.026258190727925727, 0.05389223673513957, 0.009256133676639624, 0.03333278512582183, 0.023809702202145542, 0.07389342026518923, 0.005631601471187813, 0.03587180209745254, 0.030397693693105663, 0.01913109977197434, 0.028206595552286932, 0.05185398878529668, 0.0536450735692467, 0.06707271161888327, 0.07080006053937332, 0.05207774927839637, 0.06463314752493586, 0.011284422428746308, 0.042460468730756214, 0.03363784429218088, 0.037950799467840364, 0.05607698378818376, 0.048573753729994805, 0.06913726297872407, 0.030529706073658805, 0.03964751699407186, 0.02325804644663419, 0.023604270636237094, 0.05098212896181004, 0.022663780388289263, 0.02623532240145973, 0.027656217138948183, 0.055000708504979096, 0.012783039111777075, 0.008038384690215545, 0.04033256934157439, 0.05283997480624488, 0.04032286289813263, 0.03338155143761209, 0.050307108754558225, 0.01465560492527272, 0.012387578724883497, 0.006137588003184646, 0.029244163805352788, 0.02347629045003227, 0.032130383753350804, 0.07673093836222376, 0.11382439865597657, 0.008155028252596301, 0.0396201856035207, 0.020869642196755325, 0.03391115141234227, 0.04393755464947649, 0.008328955437588905, 0.04777218334908996, 0.019183333397709897, 0.022444779818345393, 0.035710660208548815, 0.0420454495719501, 0.05371494910546711, 0.04500760776656015, 0.02637762646190822, 0.024764484093923653, 0.025122881201761108, 0.012753472796508243, 0.014183010373796736, 0.041073380304234366, 0.023628160157906156, 0.044889054128101895, 0.02731608280113765, 0.04097367636859417, 0.019029572273471525, 0.04789853674758758, 0.008367419043289763, 0.03468459990939923, 0.027865487516724637, 0.024930791330656836, 0.05703997425734997, 0.04800191495035376, 0.01429850042664579, 0.05560914067817586, 0.016872068401426077, 0.06363027276737349, 0.05459661715264831, 0.03520389632987125, 0.0275751067591565, 0.013904281758836337, 0.039035115391016006, 0.030563653180641786, 0.06569109218461172, 0.055763490431542904, 0.010790529511203724, 0.05006505495735577, 0.06149118433573416, 0.046223125220941644, 0.0424669521328594, 0.019682619820481966, 0.04225821101239749, 0.04119639531044023, 0.021851843688637018, 0.03265559360651033, 0.01964970408672733, 0.0386428814381361, 0.0208086079718279, 0.0186429447161832, 0.013842485030181706, 0.037542582622596195, 0.00820922793354839, 0.024744484274248992, 0.012092404965577381, 0.07865905668586493, 0.028091936704835722, 0.027321797762332217, 0.039363092077629905, 0.0436748394609562, 0.028065438216019954, 0.03176612579928977, 0.044551533846450705, 0.008916092637394155, 0.012997668219863303, 0.03242019623784082, 0.04869211059329765, 0.02705594095667558, 0.04409302398562431, 0.013869897844935102, 0.035587526458714686, 0.02122783744042473, 0.033006742264011076, 0.07210493766303573, 0.019926777076242224, 0.04009919061458536, 0.050325778645596335, 0.03996812818305833, 0.05420229331191097, 0.007013948210182467, 0.0313902411476842, 0.058186779863068035, 0.07611602957227401, 0.051457605590777736, 0.021146372526085803, 0.03203065606898495, 0.02837013266980648, 0.035279525843049796, 0.019538738166115115, 0.008661451167427003, 0.07623974686222416, 0.01483129121230117, 0.021824782015755773, 0.10432566156876938, 0.06045177046741758, 0.03204432515693562, 0.031157588453165123, 0.03088334495467799, 0.019969102394367968, 0.04066147222848875, 0.03749272047675081, 0.04244917790804591, 0.008266451336177332, 0.023468222668660537, 0.018890671066141555, 0.008683710508713765, 0.06148694349186761, 0.022635539760813117, 0.1327171070235116, 0.07179687597921916, 0.02124916040338576, 0.03802359609731606, 0.07949493718998772, 0.012049515615217388, 0.036213349484439404, 0.0352188817757581, 0.06809590850025415, 0.0648523143359593, 0.06317952195448534, 0.016428240342065692, 0.018315166501062255, 0.046117789444646666, 0.05123710206576756, 0.022339628942842995, 0.023735665549923266, 0.04154272636930857, 0.005803881512422646, 0.012913000620236354, 0.013208390662579663, 0.01655365396956248, 0.07516565306910447, 0.005405334215278604, 0.026918157635788833, 0.058810306047754626, 0.05133522501481431, 0.026496132602915168, 0.08836370200983115, 0.08386493341198989, 0.03132411451744182, 0.014676888872470175, 0.006901894089034093, 0.02078010101935693, 0.04176408484844225, 0.012260614644869097, 0.03774659435397812, 0.02242506159070347, 0.01868326835600393, 0.018413962896115015, 0.06327917839267425, 0.034662140400281975, 0.018880991764100533, 0.05813227314502001, 0.017756501478808265, 0.02067792721624885, 0.014982185526085752, 0.04281961053077664, 0.04426171796928559, 0.037078973571104665, 0.011881760554388165, 0.019990243849211504, 0.08366625157317945, 0.02167040003197534, 0.02657784178986081, 0.044594970265669484, 0.03673163488773363, 0.012562460947914847, 0.05106755991333297, 0.025255321059376, 0.03220105996089322, 0.036037778548364124, 0.03345234978145786, 0.07102637232414313, 0.041228951420634985, 0.020862990857235024, 0.03477231752393501, 0.028705305220293145, 0.004939540281027023, 0.008343352254347076, 0.01522816634470863, 0.026217736470113908, 0.05510596964242203, 0.028108287702447603, 0.027340883256069252, 0.02443254815547594, 0.026625145858685886, 0.008535360701249113, 0.026951029264767255, 0.05598368861579469, 0.038291125491793664, 0.054718824702181985, 0.07052901294082403, 0.03687067689107997, 0.07099108850317341, 0.024596748540976217, 0.01817427040077746, 0.006554481614979782, 0.015997765851872306, 0.03314251372856753, 0.01064138496959848, 0.05693020764738321, 0.014085657561996152, 0.00831044330594263, 0.03876136722309249, 0.07089875345783574, 0.04262215005499976, 0.035901457470442565, 0.05365376899551068, 0.039421140748475275, 0.031883760022797754, 0.03582008755100625, 0.05494628321113331, 0.03363725396671465, 0.021806641382032206, 0.03774970543703862, 0.021686511845993142, 0.03147337186549391, 0.03857943841389247, 0.021765133698603938, 0.039305962821734805, 0.04500093776732683, 0.030037873358066593, 0.03045087048251714, 0.009938578753333007, 0.033147718092160564, 0.010170417205829705, 0.06407320685684681, 0.043282632649477036, 0.08812002651393414, 0.03845697641372681, 0.06851214223674365, 0.046128822424049885, 0.08967692511422293, 0.05416903831064701, 0.03255984553002885, 0.06330792792141438, 0.047451653584305725, 0.05177328043750354, 0.0347413491856839, 0.08599438664636441, 0.09837402057434831, 0.0178513420147023, 0.058505067069615634, 0.029134705928819518, 0.03595672754038658, 0.0709081579531942, 0.07300749780344111, 0.049056633176015954, 0.017512571532279253, 0.051347547210752964, 0.037557734309562614, 0.01660976033391697, 0.07099632000816719, 0.08579145039298705, 0.020286336175299118, 0.021388770679810216, 0.01819764423583235, 0.030179816098617654, 0.042380944426570616, 0.07644818603460278, 0.06896802955972296, 0.021581459358068447, 0.05711374458457742, 0.05557840982718127, 0.05367123448689069, 0.006284051907381841, 0.04624768479594162, 0.022069421031379273, 0.019818482887265936, 0.02495854171658201, 0.05237978217857225, 0.07026318327656814, 0.06700143151517425, 0.03684020388339247, 0.04049077317384737, 0.025564717760841762, 0.02493531207021858, 0.045962024945765734, 0.021713716011228304, 0.03933700240616288, 0.038598963259054084, 0.0478737770047571, 0.0394838814889746, 0.038380312134644816, 0.02174398036939757, 0.07878781549100365, 0.028228340903297067, 0.028369130134316425, 0.044966797277863534, 0.06611730038587536, 0.05596090340986848, 0.01985690662903445, 0.058974647229271274, 0.028027338474722843, 0.05018681806645223, 0.1442714048815625, 0.13132233758057865, 0.10638048952179295, 0.12855861016682216, 0.1635452735104731, 0.08752873752798353, 0.11327659697937113, 0.13518743589520454, 0.10998190234282187, 0.08749072599623885, 0.10575986746698618, 0.06605498372976269, 0.2030886523425579, 0.08143466524779797, 0.20312306763870375, 0.1707060978348766, 0.18210773888443196, 0.2026214131287166, 0.1748781789626394, 0.13708570546337537, 0.06402893244688, 0.07883470226079226, 0.1358433078442301, 0.11971683747002057, 0.11815552839211055, 0.1774792479617255, 0.14630521860505852, 0.16615409137947218, 0.09167776203581265, 0.10723027999379806, 0.09467179102024861, 0.13044839804725988, 0.20828978610890253, 0.0831628939402955, 0.08547230144696576, 0.13669237228376524, 0.0881775798542159, 0.08897699588643652, 0.17029451206326485, 0.11996880466384546, 0.09700566649969135, 0.08086544222065381, 0.13451069220900536, 0.13039373526615755, 0.10510042642376252, 0.13622976067875112, 0.21925080008804798, 0.15577622396605356, 0.21046141029468604, 0.12152974733284541, 0.2307113515479224, 0.10170827380248479, 0.08421176658677203, 0.14345119175102028, 0.08329965267330408, 0.13957298413983413, 0.05990233352141721, 0.17761969113988535, 0.18912282745753015, 0.06629104606275048, 0.08782031081084694, 0.09906430103416954, 0.13679688024733747, 0.15732268669775554, 0.1261367965489626, 0.056603781413286924, 0.14999431850654737, 0.11236795037984848, 0.06676943360694818, 0.13437689867402824, 0.09964954427310399, 0.13649004671190465, 0.14955765408064636, 0.1514237339475325, 0.17699490966541426, 0.06530025601387024, 0.06118400474744184, 0.08289469618882452, 0.14848722437662737, 0.21437980074967655, 0.2580464333295822, 0.15450619640094893, 0.09878469032368489, 0.12190528932426657, 0.09045258563544069, 0.1403527430125645, 0.13274711184203625, 0.13253870659640857, 0.12664689203458174, 0.08529398244406496, 0.11421218141913414, 0.15189862703638418, 0.13593717637870992, 0.17107216747743742, 0.11260040969188724, 0.13515671182956013, 0.19868624928806508, 0.13012313550072058, 0.10052549227007798, 0.08798436022230557, 0.15540136050965103, 0.0986381946131587, 0.10590025636234454, 0.19885725368346485, 0.119171213890825, 0.10320625520710434, 0.11167714066271271, 0.14769564542387212, 0.1437383070588112, 0.13370497258646147, 0.18305064471704618, 0.1393657052623374, 0.1170277896204165, 0.1959943108792816, 0.14397075958549976, 0.16812406852841377, 0.11117711463677031, 0.24370423864041055, 0.18868720797555788, 0.11075981560030154, 0.19499252177774906, 0.1606140293713127, 0.10051549744925328, 0.17060476541519165, 0.14744475031537668, 0.10821886480386768, 0.11947728746703692, 0.13457866784717354, 0.17592221365443297, 0.09315438315804515, 0.1754575121615614, 0.1844565692756857, 0.1153677808386939, 0.15009795794529573, 0.09032725343214613, 0.08650904867265906, 0.17935648294431822, 0.059928022857223234, 0.0768852982936161, 0.1293099248515708, 0.11943095709596362, 0.14050028366701944, 0.1111391641731773, 0.12119186403495924, 0.11941060104540416, 0.14821373405201094, 0.06031271828604596, 0.15486197945262703, 0.1410137311156307, 0.058746062352188995, 0.09564903751015663, 0.14801446188773426, 0.13711773231625557, 0.17359264008700848, 0.10590087382921151, 0.12842373097581522, 0.17970081232488155, 0.09820687025785446, 0.1199158246495894, 0.07053596113941499, 0.16685123182833195, 0.11010580962257725, 0.09175191912800074, 0.12340956074850899, 0.15352586257670606, 0.10103025447045054, 0.2613839570965086, 0.14446139468678407, 0.11293499530958277, 0.09295065301869597, 0.3129698804446629, 0.16001979554338114, 0.08641567546874285, 0.09539650713226625, 0.09646805641906601, 0.19915595836937428], [0.047342548545982154, 0.051015543418803384, 0.04992055074710931, 0.02041839774964111, 0.04051930217870644, 0.01785557946589376, 0.05255427424396787, 0.03069443062746099, 0.023265398373561244, 0.04228005644732288, 0.034656712120132785, 0.06743637246212789, 0.0291106688257839, 0.007868211500213614, 0.006468670683846409, 0.05487113885049309, 0.03628560667857528, 0.03730460682085582, 0.025966169611950005, 0.05603464659569519, 0.03610708750784397, 0.02702029581580843, 0.03850103708516274, 0.03221102085496698, 0.02382160709904773, 0.007040738893140639, 0.0239257673134229, 0.06276687088289432, 0.019351549014183025, 0.021291804632970264, 0.07204033434391022, 0.055812657078994174, 0.03997543600520917, 0.04469590234969344, 0.0609522375411221, 0.013378602020176393, 0.010144451367003577, 0.09863590795014586, 0.026764903716476898, 0.030804794348244156, 0.04400583902107818, 0.046673292493713756, 0.04343726060220173, 0.08417469821870327, 0.030815189504729848, 0.034345047415367196, 0.045305501603122265, 0.014560248702764511, 0.04860114958137274, 0.025792993904490556, 0.056501505829926045, 0.03769844211637974, 0.01666593624811087, 0.008620773841227804, 0.03707261569797993, 0.0678988415747881, 0.012271149749202388, 0.015473775665408798, 0.018932102414380227, 0.06080964340695313, 0.04162847623229027, 0.039844926579722335, 0.08664641130183424, 0.09161277873707668, 0.026088721518005644, 0.049452300516090224, 0.028260718898049424, 0.041573769346411736, 0.014379671874589153, 0.01484140647309167, 0.02971651578055961, 0.05882986821234226, 0.028877140821090767, 0.027355943340808153, 0.03261668640854103, 0.05704246448086841, 0.02537870586716703, 0.021759274548717907, 0.019701371135722314, 0.06746326280491692, 0.036463325177984576, 0.02059556493934776, 0.052532001331980736, 0.017818923307848827, 0.02020159563315766, 0.01234902606146144, 0.048871023314339776, 0.06237401267779725, 0.03717004654130765, 0.05561346973159483, 0.09578629157372884, 0.027590003995490924, 0.024324885004066994, 0.07889942771622113, 0.011349612680662955, 0.03325145931116172, 0.0559420129949493, 0.0360646010376513, 0.08702546810465199, 0.02363845014146396, 0.030923300489251102, 0.04981522175616451, 0.036905777507594655, 0.04126560248966728, 0.02333009838392692, 0.04924970353022218, 0.035540140965687375, 0.07937107740768365, 0.045580243824848106, 0.023022291150742343, 0.04123979101755789, 0.10303833136068923, 0.06204697236950908, 0.03212401230952569, 0.06759649315582854, 0.03874466508360846, 0.06806244993848459, 0.015991000857736384, 0.01919225274053003, 0.041314911629472456, 0.03986455320513674, 0.03598482567550881, 0.05836522778762238, 0.04732056401137795, 0.010313048659424697, 0.060043149893837314, 0.03287475363218358, 0.027823615120723844, 0.04822051179196153, 0.032025268500936885, 0.05575613171926566, 0.018921267906469957, 0.06981886497565679, 0.00636813002971134, 0.03957135822357876, 0.013258989018920277, 0.03455622108387096, 0.02576574563447918, 0.03638736318264689, 0.049338316810982566, 0.016908885711537938, 0.0035121335157392813, 0.057126168560768874, 0.013260128957751607, 0.010304038562545819, 0.02915676510227578, 0.036275289553616724, 0.06699670212609427, 0.049844880521829636, 0.06519137828477792, 0.034305797557213476, 0.03984362718516162, 0.03247097779863647, 0.03981429411630545, 0.02488170610740781, 0.017027868523395488, 0.015822111795257245, 0.02443200023844838, 0.06523974426090717, 0.10819080059549638, 0.002833533824221896, 0.046580105886927674, 0.052195939900619645, 0.05938784791422742, 0.007548965862952173, 0.08934340479650668, 0.01263274614965277, 0.06026177387684584, 0.01423688605427742, 0.06614630775792257, 0.034324691364807744, 0.04863999231851526, 0.018551975222570554, 0.01986000414139458, 0.11384227126836777, 0.024680364411324263, 0.01278683721154396, 0.031449185484754186, 0.05035760533064604, 0.07815968205354043, 0.05852565382208143, 0.007106591988953629, 0.054734783845820596, 0.0712258480489254, 0.06506980516548667, 0.006541025841475597, 0.05857437942177057, 0.08069501458001987, 0.014507551976878728, 0.03805726839761649, 0.01208980193561209, 0.07757315638342074, 0.03144646116665431, 0.03105416614562273, 0.05663247326655047, 0.07310908806643315, 0.061352138939712725, 0.03268449919830475, 0.10358951892703772, 0.07998954850648131, 0.03889653818415744, 0.02252301829867065, 0.021170463911922913, 0.11142907504524503, 0.030653657458190407, 0.027130118404914225, 0.06483873685023614, 0.04403500245617969, 0.027042382130665437, 0.028613971014107977, 0.030300781929067204, 0.02936106521104063, 0.06330824683287314, 0.03368832729756832, 0.0036862975518618312, 0.02257594233378768, 0.05900369531341961, 0.03012940433940717, 0.036675072208579095, 0.04309884804700102, 0.0366568976481046, 0.08332697049315486, 0.028215406329504082, 0.02799665512117956, 0.04053356498479843, 0.04597303078376821, 0.03720361366868019, 0.0152210773501013, 0.022039548527183275, 0.05071770047236766, 0.05022801871278456, 0.02217103504309697, 0.05404601651909096, 0.020252222827236568, 0.028388383565470576, 0.09082068409770727, 0.032197864060955386, 0.018261114401476722, 0.01013159312840019, 0.03897036618686148, 0.03326074167021683, 0.00033213825320542255, 0.0625784620642662, 0.03832705731370619, 0.043235131805496554, 0.027089133193450313, 0.03650475313354816, 0.04815166423629437, 0.011042044631072452, 0.04518582159653306, 0.08191823679953814, 0.06808855996600219, 0.065792763871806, 0.008676568079473717, 0.055051948076912334, 0.029071558067309003, 0.021479865702401315, 0.03657023515552282, 0.060015146753617694, 0.015290447377732821, 0.031024334353527853, 0.049368847494146655, 0.009117871140395957, 0.02796374447643757, 0.01003823773602822, 0.18667421170643397, 0.035815782246312926, 0.0646341788981642, 0.020375054628987397, 0.004536452736439449, 0.04231638181954622, 0.09706177456038338, 0.040649482514709234, 0.02220444950009031, 0.03912984566496951, 0.035671898895608525, 0.031108920528952564, 0.04397731680156929, 0.027794504272086278, 0.05776874800877912, 0.05573954153805971, 0.047041601301836114, 0.0177960210546319, 0.0370866342314652, 0.08368427346327476, 0.03512799879536033, 0.04762850355889116, 0.04353779574323978, 0.02209693901906056, 0.01641632187446313, 0.03207040125770228, 0.0592791669602905, 0.07121049280145339, 0.010708056972362101, 0.028528034553996155, 0.04754434486052819, 0.02677962792638157, 0.052025946522397656, 0.08400096611252852, 0.013845627495486821, 0.055267555971762965, 0.017717333044856787, 0.03658502382625427, 0.02173268954668726, 0.053056505508720875, 0.01970850762778095, 0.029790842506502355, 0.04037633824295231, 0.02906862340335335, 0.028220242587849498, 0.03975448803976178, 0.004237830322901053, 0.019592573134494678, 0.026516110370201722, 0.03926394793338009, 0.053900816810450385, 0.013737147557549179, 0.0359888934929456, 0.019571526674553752, 0.026748164257566844, 0.03178871423006058, 0.013723386867370988, 0.023341602945168103, 0.027061652525195053, 0.041604466270655394, 0.04228141012468508, 0.020975215460306833, 0.05583997489884496, 0.04976092877664736, 0.042980596356626065, 0.01317410174358104, 0.016539543833849684, 0.06876827563558306, 0.015309812767165048, 0.03339830107454743, 0.010307359143293329, 0.016695900354534388, 0.08446751322065081, 0.018509297066235116, 0.030901672185531685, 0.024384692776948214, 0.09639926653887544, 0.030831053653465848, 0.021992744877934456, 0.015626435866579413, 0.03440090102542724, 0.015447095668475543, 0.03379834496549197, 0.009587241802364588, 0.028323044035849825, 0.04046687517049057, 0.011058604278202568, 0.1289309901850564, 0.16512384451925755, 0.1473071841256959, 0.17411992965000017, 0.13243831055504934, 0.045878554960446696, 0.14735436945089272, 0.10311463940888643, 0.10049413716686623, 0.13874643349221774, 0.17070346511900425, 0.15614685336393969, 0.08487882079290492, 0.1373574315969433, 0.11307309754192829, 0.1420761812478304, 0.14599390673850263, 0.15546768052237375, 0.1575449069163629, 0.17543634186897958, 0.1335949684892382, 0.1489756474537509, 0.1601478758135012, 0.15413163149995462, 0.07356019850288119, 0.17601419586156095, 0.08816817535885743, 0.23715735280088016, 0.11439512803086213, 0.08483690768480301, 0.18173347253884586, 0.17957278633756296, 0.18355856889060565, 0.1243704477591174, 0.1020025544400726, 0.11884140515966074, 0.14744135764028343, 0.12713375448116235, 0.11437293993575232, 0.09640870496098485, 0.15615324516381535, 0.11449698970786162, 0.1567613346768277, 0.1456947135073798, 0.14172299019992352, 0.16065094167632715, 0.07421009934374265, 0.11826511179762227, 0.11328929915492024, 0.10757952196789639, 0.1356886832841805, 0.13051079612757477, 0.12476265457059656, 0.1859491156148059, 0.11197013208376509, 0.22576617476131233, 0.13604544342628547, 0.08776618407240935, 0.2343436037855489, 0.11361791366445166, 0.1443528833666018, 0.1470374528850828, 0.18634453868227346, 0.20003733464649745, 0.1390090129737343, 0.14299265135611805, 0.1396031110946621, 0.108427147913192, 0.1196508024420057, 0.11525244345622403, 0.12155261396297387, 0.09986015475754227, 0.12147389033011027, 0.11478030521954809, 0.2121687808207103, 0.12566510614539894, 0.11769252323678561, 0.09111740746136222, 0.12306403714631285, 0.0820253367668816, 0.09941098493124757, 0.14294064843228885, 0.24133151024580002, 0.0643665986135602, 0.14270681169416222, 0.08514785314244883, 0.23920177881206783, 0.14135044733328478, 0.12201914750039577, 0.22861370124987193, 0.14818577840924263, 0.1706497251455273, 0.14528828460190976, 0.129157403750079, 0.20675215790314333, 0.13821390563888208, 0.13076991508049624, 0.09564104436763696, 0.19608689019722597, 0.14483505035085337, 0.22676367552152701, 0.09675383501287017, 0.10365925197090421, 0.12512297023619923, 0.1790869552642107, 0.13240343385509082, 0.10835198658917632, 0.14301055110991, 0.16104434270943913, 0.16890401739094937, 0.15261387079954147, 0.14811001318906034, 0.20961959260915006, 0.09071462907429252, 0.1641867740878037, 0.1022353937317218, 0.1607099063694477, 0.0932179686746427, 0.07516369888825075, 0.22466417960822582, 0.10571531485766172, 0.1777286502931799, 0.16856909250574453, 0.11775683478585311, 0.15114117839506694, 0.1381841722343649, 0.11048600636422634, 0.10129617234425885, 0.13009188217776163, 0.0703812822965639, 0.09957544146371738, 0.11219148377754859, 0.19729735595839365, 0.08119721191802196, 0.11794675673757281, 0.09108027802514178, 0.158462666241186, 0.11036462323474032, 0.07790912621255432, 0.1978122011891433, 0.12853008455463819, 0.09769872216773884, 0.11689719877072743, 0.09299253898539714, 0.11337616520800761, 0.11529555757130895, 0.06575150215732199, 0.17464614712766238, 0.1789579386157649, 0.17752171068319253, 0.1368460604654891, 0.12019783737404005, 0.0751347118722541, 0.20864144366766724, 0.13982739405972616, 0.12326941612575736, 0.19727963262370654, 0.1081902374114309, 0.17042487221104757, 0.15493104074682507, 0.09165521431714296, 0.1773104691611869, 0.19155217281409673, 0.18433321160929544, 0.10047370647745472, 0.1481684214834656, 0.17899193322019918, 0.14478661652122224, 0.16510190069675446, 0.13531011502657617, 0.1442965513893536, 0.13307979756167956, 0.07946877966501883, 0.08157231964703117, 0.2738009850893702, 0.16467578070504324], [0.01983835208894951, 0.0771391653854932, 0.04404690735308187, 0.05633483388062034, 0.03927351527714303, 0.04687505488150886, 0.0110462507000193, 0.003599870002030262, 0.034992454640035114, 0.04414428052093301, 0.04138950298407248, 0.023646334718380655, 0.04293478506484202, 0.012421942282734173, 0.008732790642950152, 0.03893845468493445, 0.06832122962389674, 0.05012916633859277, 0.06852776889822312, 0.04553030364747558, 0.011529613602241235, 0.030590672445084368, 0.06878108637673513, 0.04080188826524785, 0.0676759360358119, 0.04085353156551719, 0.06909340926046882, 0.01598993386141956, 0.05909962659435613, 0.05124118006122964, 0.021093758920739804, 0.02279765874014369, 0.041538000372903686, 0.02889477933890053, 0.020785866870677898, 0.07074165224496808, 0.03781785070896149, 0.03998376162988799, 0.05048896971025637, 0.005843570722000939, 0.0032020886012885186, 0.019439733121544123, 0.046092680256281576, 0.04769343596750072, 0.0188150924430894, 0.06493787081646067, 0.04884424153715372, 0.030466656599725996, 0.04698031262627669, 0.02342533247013177, 0.02682823478244245, 0.0379832130856812, 0.034234632804457626, 0.037901300338229964, 0.06939921820802347, 0.023844741750508547, 0.04048308876476117, 0.03274966570149575, 0.060216495235051425, 0.023701513186097145, 0.08319028639899832, 0.04655748352940593, 0.045298991059618335, 0.054706193772809844, 0.03409150602029903, 0.048107165909771404, 0.05210466676258615, 0.05439790477976203, 0.032490950476910384, 6.845488665671187e-05, 0.033017161169222424, 0.03999795997515321, 0.025644449018208042, 0.06368031472499881, 0.04144829465076327, 0.04928473968591009, 0.018112598352932503, 0.025622193069596375, 0.05225704537172403, 0.03731331242514508, 0.012240648751945367, 0.03351434752611177, 0.07305674587509461, 0.019368558190762997, 0.07805584583963666, 0.06494512435581003, 0.050457947089203765, 0.011812525385591601, 0.04729550571313926, 0.03994668647646904, 0.03470785669716341, 0.03405164208795343, 0.015490696632436343, 0.042720900648938756, 0.01916431575747473, 0.008932330828559185, 0.013042181813424187, 0.01940842890845878, 0.05526225322059222, 0.0139056557922491, 0.04208965952109013, 0.0064757380501500195, 0.05950962459402425, 0.017731663704450642, 0.06722276285290718, 0.02073017441268478, 0.01924676794026579, 0.03516259390328612, 0.00788948526938579, 0.047452888518039665, 0.022838021395727992, 0.07408527604171208, 0.04145979581932936, 0.014483421575278044, 0.01857777651665466, 0.017550191210050668, 0.02087156075452055, 0.04397404287010431, 0.019165732199326158, 0.024714971393612877, 0.0821836254160319, 0.038218111731112, 0.026951032657442347, 0.022022649612543837, 0.029891499783843756, 0.008451921250005918, 0.0363299726907696, 0.04445697320625186, 0.055341896268406084, 0.018980563385412097, 0.02339144643130047, 0.055786930423762114, 0.017384757587153996, 0.03689176915213466, 0.05924906036151307, 0.04865063514028277, 0.062098608884428225, 0.029222864591117417, 0.04212139121123722, 0.016166463228208677, 0.024521103760759746, 0.025964517379179597, 0.016335810301825404, 0.05971456252570663, 0.03292862931266427, 0.07120192290416785, 0.048337650684905906, 0.04050162634147065, 0.03798377626974668, 0.05198261866878186, 0.01464731662001993, 0.042051373182662895, 0.021039528705711876, 0.0064586962190722776, 0.043039601761847734, 0.03601790425766792, 0.0008922025153879076, 0.01218451270168381, 0.057126338194523535, 0.07624757037098918, 0.027082632827971662, 0.03065334872475692, 0.05283792223781347, 0.01827048327374671, 0.022831744946805493, 0.010809668439573475, 0.04214429176811661, 0.012560365122875996, 0.01027644339150616, 0.014933224135477628, 0.039883552185658894, 0.05926538591406175, 0.027871682541444898, 0.011001284184333469, 0.005146275058255664, 0.06100519719932761, 0.03582127498728888, 0.0215637122746557, 0.01088929791668696, 0.011151540675200522, 0.018495093631957258, 0.030756017858428613, 0.01752511764477406, 0.040232831479183266, 0.026546934519761374, 0.03216996270098856, 0.030690512087728297, 0.052006954327225685, 0.029933955719960586, 0.026344105135649443, 0.03947155250768576, 0.030566798190453222, 0.03937870516840901, 0.06874277628958225, 0.042451719021690745, 0.010047277518814164, 0.030166598236454383, 0.10359635856002569, 0.06162362080067396, 0.047292601583259444, 0.00899923692590424, 0.04090514772438577, 0.07847296167165041, 0.021136253872620206, 0.05684264609590173, 0.042050589474716356, 0.00360452475225819, 0.010174508771992155, 0.03222114799012031, 0.06490015784012419, 0.023871036678818718, 0.04380294008712683, 0.03855219862556883, 0.029410727189055512, 0.03817268381161349, 0.019369190924667885, 0.04649383694465671, 0.0287518154031464, 0.03619174492944564, 0.014852173127500074, 0.021931607176416686, 0.040910321553902965, 0.03553657526416438, 0.019762276438996196, 0.037234955201191564, 0.03648473635049803, 0.07262949272990227, 0.0437583230169756, 0.005306160809206111, 0.025694234828863825, 0.08341788061495338, 0.035812355644468746, 0.0425075658464006, 0.014130615595994251, 0.028871017042547464, 0.06436932632433516, 0.060213468968868256, 0.06003329078001635, 0.04606319451704621, 0.04058010570172753, 0.02457243323858295, 0.0216973022491272, 0.022813280312610523, 0.05791495194924729, 0.00875328155234456, 0.016640672693029046, 0.02507174849909331, 0.012769757636955805, 0.08380399418196507, 0.07710619536893708, 0.03633164527959057, 0.0361279049622161, 0.02522413050090628, 0.045013612801475186, 0.05905151167618377, 0.005311646340747497, 0.010781298042275012, 0.020872000105945126, 0.06098538397678307, 0.0055301596377311, 0.04405240687940802, 0.026415327563881874, 0.03639916969197137, 0.02533775118977896, 0.07841541511671883, 0.02663840612928782, 0.008387971869004624, 0.017845320016411797, 0.03132033168471285, 0.023605044166158353, 0.007323675273385431, 0.07567283085414342, 0.044376465026289225, 0.04996691504493356, 0.04112064026828323, 0.03283560894695776, 0.0610576140295182, 0.03919716651684471, 0.07090823937739645, 0.014996631536632776, 0.026173811505681703, 0.034891101864299605, 0.045331062017274756, 0.01428221388986068, 0.01998524643879916, 0.012595402126732682, 0.03227479975404484, 0.06766706079776798, 0.016514553389112865, 0.03780732323814716, 0.008539166434534957, 0.0433115687753473, 0.07127909269183874, 0.02699636049302561, 0.009112646420752364, 0.03012394891785724, 0.07756229303777218, 0.020974845658721666, 0.025483256239177923, 0.0498963575810194, 0.023586265709517256, 0.06448192921067987, 0.04657210595905781, 0.009386030724272132, 0.009508661510023688, 0.042305067248110256, 0.015203791670501232, 0.05239860134731446, 0.007897349490251924, 0.018660876700388532, 0.03379437214295779, 0.07934541521327836, 0.036002667753824165, 0.018876323443172232, 0.00854374484957329, 0.02782724697941116, 0.04848706748868738, 0.04075627714129431, 0.08013203407504729, 0.017248456865282993, 0.00832953812953617, 0.016304341543998038, 0.049058818058776, 0.01508834572242839, 0.012677709272663509, 0.05174653258706842, 0.04794060591874378, 0.022151440648095946, 0.01826251218361514, 0.021502837505457655, 0.004740269389003515, 0.04351887818691986, 0.039041826102350435, 0.011449525265821388, 0.015374202347759689, 0.019864850577765276, 0.05704791311706815, 0.059198713063129356, 0.043603481325720034, 0.020825610363057682, 0.029138821243707622, 0.038618213297533135, 0.008286268799565732, 0.0658853906872017, 0.05612423696688243, 0.052793359450463734, 0.09602300530033452, 0.03308672118665917, 0.041141549324882884, 0.0385855011242841, 0.04178906850782888, 0.01563596080190369, 0.06911090189324957, 0.1804788748600653, 0.1289293481303113, 0.13809503987431526, 0.1364813886050667, 0.15121296740003995, 0.0911616479445781, 0.08565367385745049, 0.1481382945286376, 0.12862202604966505, 0.18301746435463428, 0.10027323330619506, 0.10419129806437663, 0.1808698603085109, 0.09255341147737843, 0.13211197592318058, 0.10595045438302414, 0.19485935249498912, 0.14180094030286583, 0.11059244815260172, 0.08265713429344551, 0.1890502513519355, 0.1785931989018406, 0.1396644642310483, 0.12628592497536115, 0.1148221165473972, 0.15379194329891885, 0.12471998828862395, 0.10036087288920369, 0.17258165005062306, 0.08333972016615526, 0.08076532437865223, 0.14493646419474057, 0.15657722098486765, 0.12879146981452191, 0.10097238900406019, 0.0761052340801273, 0.09659349718796355, 0.13159122743776866, 0.0934190796688199, 0.1074321713032467, 0.10138959304562636, 0.16636640498680727, 0.08066403945641858, 0.1538075903164489, 0.12957719979541643, 0.12178741422082696, 0.1138006363596235, 0.1413997768291405, 0.09627110484455313, 0.08272287755140237, 0.12579261644610337, 0.1001177334359714, 0.11451111680694989, 0.19550393362130436, 0.08528897485562734, 0.14849912588085445, 0.09325013801987682, 0.14723114749150618, 0.13086590064423426, 0.13718551796461853, 0.11168951714145285, 0.15605670320136206, 0.20792439500136034, 0.1330060408051525, 0.1093108719214797, 0.1137295530310699, 0.12949303431170328, 0.09896124513553721, 0.11904256365128926, 0.11875980453831808, 0.10761525362197842, 0.15248014511806623, 0.14054719757820877, 0.20078323462179729, 0.15985027035432203, 0.1338684181017535, 0.0959068468904921, 0.13603142489280018, 0.1321532851351159, 0.11782067136040755, 0.10257458660219397, 0.1783866664128644, 0.11247748628790889, 0.13940297040556157, 0.1182503333049161, 0.1223116639469351, 0.1010316318965384, 0.148372049842562, 0.12364228468920503, 0.12303396447428636, 0.08962629283113138, 0.11275866441428661, 0.1110277690791658, 0.12003754026123456, 0.12476015756172792, 0.10103762336075306, 0.10528751888445445, 0.08234134409576654, 0.1624565776437521, 0.08966852485069207, 0.10027592709021908, 0.11878367540027414, 0.0613480880856514, 0.12635219070528234, 0.14456636405416898, 0.11603521502443723, 0.21880611537822656, 0.06860912524695907, 0.12692933902144432, 0.21607201280338423, 0.1945132589233773, 0.122692254238895, 0.15185324661433697, 0.0810072628249015, 0.09129791134702307, 0.13168728085500853, 0.1660899291081088, 0.13395307213068008, 0.12045718702886786, 0.18257060833275318, 0.10884497620697532, 0.07269390605922256, 0.17106060524071964, 0.14269965993506567, 0.15138645523360797, 0.14963648627911294, 0.11851227496351514, 0.07098328535045896, 0.10798299246068511, 0.13231165520846844, 0.1738032302153962, 0.11422169448009559, 0.09060784801840782, 0.0934566840795534, 0.18567502817937306, 0.22134758186127457, 0.09529849953417267, 0.06712482989366565, 0.11826212624354021, 0.11483002826571465, 0.14128374734095164, 0.11166907966669117, 0.07740511040070228, 0.11241048774016754, 0.11760375728564602, 0.17647546396723815, 0.2129611333033868, 0.08922891558281013, 0.2112453625138317, 0.08541085331567697, 0.09401635333363499, 0.12927474959620408, 0.12845984260950769, 0.1995320024767092, 0.23976330725210054, 0.0967684777985726, 0.10454695897975139, 0.15085670937384876, 0.10119645483791828, 0.2286091414945466, 0.12335223811013357, 0.16018060834280082, 0.11413746114288058, 0.10408700723201036, 0.09394199946629149, 0.1859423438353198, 0.1757105921528169, 0.14426471452627862, 0.10764511594814913, 0.15981660144669668, 0.2260081810610635, 0.0937601588666439, 0.136936183486666, 0.12185028727565493, 0.10544255056551524], [0.026803995815238783, 0.004730950982775539, 0.038200191621269496, 0.04515957586201174, 0.02489403508869665, 0.021109122649899552, 0.02412544490237321, 0.01814326983211296, 0.04475988820195198, 0.0658374996855855, 0.03921739025307553, 0.01199240077819143, 0.03066856147987502, 0.05749618727713823, 0.06317677388765983, 0.03686687709497554, 0.006753903056960553, 0.010991874599962361, 0.107683643166508, 0.029974399799747125, 0.02594330976717174, 0.06377614422568254, 0.038513902109116316, 0.019336203944736292, 0.046214148202644925, 0.017932874782543098, 0.03475051958646093, 0.023456516243251305, 0.0765211149784071, 0.06629604008048773, 0.048688378650695086, 0.07480763085186481, 0.03688243929562824, 0.030975948021348034, 0.02838725210832698, 0.01297895167954266, 0.048823912627995014, 0.022168393845536878, 0.01396901484778417, 0.013438005216552742, 0.028740263344453912, 0.050159483283225975, 0.0047251329690750155, 0.024999620226610984, 0.028470772983772413, 0.08219621902597801, 0.02921759576669761, 0.018700277532583902, 0.03707967585484896, 0.01640016765200666, 0.0031272283771873583, 0.04494143703154155, 0.029116558509745767, 0.018019301484205892, 0.027234214158462625, 0.03956449484186513, 0.04423190314056618, 0.0387759692966938, 0.042834344918706586, 0.08439413644373417, 0.08920841703989676, 0.049133002292364836, 0.04926484503916331, 0.037586080109966655, 0.016572325556938137, 0.07521889092666761, 0.02175698958204261, 0.025861356307619383, 0.05522517128182309, 0.042186611997229714, 0.04640313038336379, 0.009582608256355991, 0.015490270851712142, 0.027702676431675042, 0.07591057595397745, 0.06072215988699879, 0.00848654774017632, 0.02560159783544285, 0.06564000528305769, 0.03340245031618646, 0.051172916045678515, 0.0565149340379451, 0.06535079330205917, 0.020286512594403963, 0.03525192303849118, 0.01939177935543869, 0.00570334933997531, 0.036674010301274915, 0.04060027515515685, 0.015414970428017634, 0.017171410910253013, 0.023989785396094834, 0.02910204464569688, 0.009542980963098151, 0.030613735850368227, 0.04364175070077181, 0.05956731364130974, 0.05265224112996033, 0.024702878203243017, 0.06719336193054914, 0.0406209331537996, 0.05160336848348379, 0.03623889972056661, 0.01333902052803231, 0.052007982307778935, 0.051142456608691385, 0.024006677525384084, 0.03670130097972495, 0.026986598070444803, 0.030157997805093015, 0.010926100807929677, 0.02436080664795424, 0.07490215077996254, 0.03510275050731642, 0.05467672160427485, 0.03414407212819372, 0.09382464683481626, 0.009233950670542461, 0.07664659645940576, 0.031781939057899375, 0.03310364724269935, 0.02829330214964492, 0.05173310098637428, 0.06042951451880591, 0.022359971422702074, 0.011956018578660275, 0.06079014909586736, 0.017357717966660857, 0.044216588605195284, 0.030060709454119205, 0.028935627147023166, 0.013500171746792538, 0.02853924055982913, 0.012591016246005893, 0.023864727999482836, 0.02498967799225024, 0.018020248040556908, 0.03886083706415125, 0.0220138574950397, 0.01971329638867506, 0.04984613581161414, 0.0051565896387078935, 0.04676806687244347, 0.049190579381372244, 0.03007605452356594, 0.019615950362224664, 0.05253564167235579, 0.01680003003483372, 0.05714208699230637, 0.040313292161694596, 0.027866905654913614, 0.015457867411896586, 0.04979407521230834, 0.04846563256744828, 0.048326180050415654, 0.025797132968104312, 0.02153813828980284, 0.0887806142813393, 0.05502226556252156, 0.02505650181722428, 0.014363627914073212, 0.010043028193259878, 0.053867331107280085, 0.1171524500740426, 0.025748979034168378, 0.008865327191805201, 0.044577162114105055, 0.033079362474381924, 0.07741474559796707, 0.03148110377203141, 0.02489373822962599, 0.023311197790982466, 0.01564781989769212, 0.04037931701168418, 0.005191381521789091, 0.02232226523171578, 0.021238841582089663, 0.03793449427134224, 0.013754390828710581, 0.010930646992554622, 0.046046058115150244, 0.026047734610204185, 0.10420066863298416, 0.0035328725144998835, 0.0752843152731657, 0.07428705878555775, 0.04090470667662365, 0.05962682116244521, 0.04851573559322527, 0.02511483377643994, 0.010208576318940945, 0.029147866115506207, 0.028220022063968436, 0.026713738783395717, 0.04195294489285775, 0.05427196868030088, 0.057765857449599674, 0.053264605413590155, 0.04692147006945951, 0.005192251742950508, 0.019032785136784827, 0.030412557002689158, 0.04265580199924963, 0.02463390172592231, 0.0535738341776388, 0.049286493698933294, 0.05525525073919978, 0.052964482589491775, 0.09373442203338657, 0.013268865944285477, 0.0318329309645508, 0.0066723028597022805, 0.025654820425968086, 0.058838010632566044, 0.034496204661471505, 0.026620350312441587, 0.058527635144335885, 0.08605989241706473, 0.033613824152520726, 0.026711955932634215, 0.012980235807065452, 0.02845785876602999, 0.018165430785822015, 0.05439322628080845, 0.054040411819836924, 0.03909818182832428, 0.01488725678063929, 0.042526079674384425, 0.028382933232933283, 0.022686424798199108, 0.030467494590474025, 0.03480646479874849, 0.09244289169354097, 0.00834435987884977, 0.035289924392210584, 0.032788179349154234, 0.052401871886104345, 0.0035954578280715005, 0.07048118979270969, 0.02104690098868949, 0.061900334166628976, 0.04018574793423925, 0.024854211868452172, 0.03275394725746342, 0.06202327792665788, 0.06387603815112795, 0.018299580551683903, 0.012970469991809555, 0.0024440280062013437, 0.026489786604153256, 0.0309514155877488, 0.023416497944188968, 0.011274808435700834, 0.04334225891424077, 0.06539087436561074, 0.021903442884130136, 0.0453444936179689, 0.041239373718521426, 0.05368743451046092, 0.027610285407198325, 0.021095970944900597, 0.028110881402556385, 0.01846032210492662, 0.03157120982983282, 0.04208935418033174, 0.03185207922277706, 0.005392939076825444, 0.11672348023525306, 0.0327238338733358, 0.06072074853416, 0.034101639940802536, 0.04457583897081869, 0.006263312484536852, 0.03387285489588976, 0.027011357813275287, 0.034053691263709746, 0.024749632658702985, 0.013310283721823777, 0.002762551003667925, 0.011856758235288518, 0.08557561518890516, 0.015734623186290264, 0.0231875313911587, 0.05786864871957472, 0.09270947453166757, 0.06259270451430764, 0.018459877664489404, 0.08308237218963248, 0.028454489839662398, 0.04232615611648985, 0.06570230836846999, 0.025184463343716094, 0.0562567887827754, 0.019045682391151786, 0.02953645633533597, 0.010274887849975909, 0.023862936667033603, 0.030822052886443477, 0.02810562275616186, 0.04377802428124206, 0.052088911179453135, 0.00929696367321802, 0.009129806571373982, 0.05669266271537968, 0.053903622552752495, 0.05698572538260903, 0.046299436661813936, 0.010335052701910692, 0.04043133689888886, 0.012770746601745486, 0.008659097499081066, 0.058725109190813134, 0.02964245029059904, 0.04961979349276849, 0.007416685461066663, 0.048274007492831776, 0.03695799416995474, 0.02594655316456088, 0.06633901848856892, 0.07904942466744355, 0.08723358158022165, 0.01679640496149659, 0.004775082052219659, 0.03868282679468393, 0.0369415973712291, 0.04527678939380816, 0.026074458711913655, 0.035831571756196876, 0.027768772527841584, 0.02294721464360399, 0.03500889215086188, 0.020739429630339146, 0.014093546379756714, 0.10318290003176246, 0.061317289381154945, 0.04433404980227351, 0.02609164939661111, 0.054291802258895974, 0.018126118163179075, 0.11357661802321672, 0.023586236871778965, 0.04711795684748462, 0.0036164088690254304, 0.013896816177293658, 0.02172813148769949, 0.02019157536726977, 0.04542950727045536, 0.003558727031174515, 0.04318286086033497, 0.03223188919946551, 0.031097042773451124, 0.0547539083553212, 0.09586591765816722, 0.12201618908771447, 0.10471680308026926, 0.14481518284550735, 0.14691060754869664, 0.09838172194680997, 0.16156932525336742, 0.07377116861087935, 0.16290457360446453, 0.2041602898389101, 0.13867825429354394, 0.18779842209603104, 0.12147873507014342, 0.14614790704633507, 0.14494254386850766, 0.2044832996491875, 0.08919648839426891, 0.13506282972437994, 0.23936036601662636, 0.18068308675927774, 0.16393239130931242, 0.14743031109017984, 0.12014142397258963, 0.0847803314349481, 0.26237716951540535, 0.09589567820408515, 0.09457832960677998, 0.09302439620452267, 0.1589322667568922, 0.1380361294639962, 0.16299297314669403, 0.16731045075825282, 0.2006784145321165, 0.12178142954196249, 0.09080013805734259, 0.11129607539623976, 0.18850241574857915, 0.12440300386931215, 0.15510285938424723, 0.10986849199980497, 0.11393411776849202, 0.17587658895977906, 0.1655479831887143, 0.11875334488494055, 0.0964814710563847, 0.15003275073000363, 0.15789511241018772, 0.12497038128120558, 0.11466644704341888, 0.21623657111610683, 0.07545865127550704, 0.1072900453582406, 0.15395047622067587, 0.10478921633745943, 0.06793148589453527, 0.1255848083112921, 0.13419106150312082, 0.10099346430173942, 0.14248871696846827, 0.140665167676551, 0.11838480537491185, 0.2114837590072836, 0.2026660471622433, 0.10529332035886389, 0.16055756168706076, 0.17468992620706558, 0.09182710080806698, 0.06762681010046176, 0.1763076622571264, 0.17551056002931936, 0.1125465611528073, 0.05238052178174257, 0.09026360006204673, 0.17419108083205564, 0.11328455619513988, 0.20527576069746697, 0.07822618527071816, 0.12612310371228627, 0.1423457089279379, 0.12820574481572422, 0.1339823305606842, 0.20886644587985106, 0.20235742229436124, 0.12040766754320689, 0.11128737657730069, 0.07943814380892686, 0.06267443405730383, 0.09351796257708754, 0.14036190323531628, 0.12878804999802793, 0.09295057837984391, 0.21616822906902858, 0.10715809743851423, 0.11618298638079848, 0.08077315467276744, 0.13066850123660906, 0.07693374569394759, 0.11654493053044591, 0.1484020139489855, 0.2018142007291317, 0.1864609345793724, 0.10453327971377543, 0.1638732094849859, 0.0827857166794794, 0.19421789262975964, 0.09301884578807013, 0.07392390684357711, 0.1527367534914187, 0.20399687146501883, 0.1435007790901831, 0.08699971770069428, 0.17479855966355118, 0.11347804045570747, 0.17533088395638124, 0.11037260280655962, 0.10127485955932311, 0.18853566396449292, 0.06965656618454627, 0.12334830260702542, 0.10356883039431912, 0.1672604562980788, 0.08875932185245411, 0.10633571299591235, 0.12247527231063161, 0.11155708746186324, 0.06498018426022359, 0.21716427776430333, 0.202601233497262, 0.14993234111794404, 0.15581627110285418, 0.2628212028316089, 0.13393171184829303, 0.10501422533499342, 0.10753705924642937, 0.12867909084473336, 0.1219690309039184, 0.11165295088929789, 0.0902998066906418, 0.07460265220808131, 0.1321373667035784, 0.1630834218646799, 0.11224617370005165, 0.10372202324547938, 0.1861592171979802, 0.1620554548821279, 0.0999855955264398, 0.07491851025926215, 0.09438194800168276, 0.13029318994709424, 0.18068197396184715, 0.10344687051006726, 0.10603095577763659, 0.1669770593621901, 0.15753992646932602, 0.1493676778461252, 0.13431982030825956, 0.1277560389467648, 0.21335601354283945, 0.12466369702347688, 0.10261429447148528, 0.07606611653630223, 0.091194027635668, 0.0991674315716539, 0.24860581276672228, 0.16927860943334444, 0.13155584862189634, 0.0924565913155675, 0.08398942423186131, 0.1442576984741858, 0.11184813148741211, 0.11900516280106135, 0.11886526245091643, 0.13379656124327863, 0.1075097821386797, 0.107645183801651, 0.13179545290768147], [0.044521729195756574, 0.02027234647955213, 0.012817087999012853, 0.011955347677160586, 0.00355766894062981, 0.06781913406614747, 0.015196614466341478, 0.06813329577978168, 0.03179423750511237, 0.03845393318416817, 0.028727276184196984, 0.03747919388115406, 0.0795558492786118, 0.03816226151372705, 0.016914514159517627, 0.04109328512900642, 0.014306885423138738, 0.07505515364131757, 0.03480261750519276, 0.04237298181812678, 0.04415407517392721, 0.04704734170809388, 0.11057530157268047, 0.01395696830669684, 0.004898180178965309, 0.023243817567293133, 0.02518623771278986, 0.05341706205425518, 0.018180772462593656, 0.031982334197631905, 0.01305672197070505, 0.05996429055397, 0.041568436061165163, 0.05992990918457508, 0.014179438735092325, 0.037447248452476094, 0.06940098918442215, 0.02547681694185095, 0.02761486721491175, 0.03512000904551574, 0.017287796629326682, 0.04866269610023924, 0.04985549620219639, 0.030991388085697378, 0.0451950869922127, 0.012155629162277495, 0.049685662279703786, 0.05814078197415386, 0.04231000019769583, 0.06767348652439457, 0.032056803415928564, 0.021203913992004733, 0.014944101051826562, 0.02652820016789649, 0.049025376460381916, 0.03600267793184944, 0.021121790898697715, 0.05449125084227749, 0.04583093537283795, 0.03377501014620066, 0.028449485643899868, 0.029234844126871655, 0.0520236632520599, 0.05125772613765938, 0.014954475852261697, 0.04432703714285578, 0.006326473068578967, 0.04258253378793597, 0.03218517206343157, 0.08000657973544938, 0.07588983992380754, 0.021178623295522163, 0.015665125933342745, 0.034461579019469876, 0.03158570673050625, 0.03060146454455597, 0.06087006016501358, 0.07635643452938114, 0.040724484382995536, 0.006099756283219904, 0.027809978263186555, 0.03544071862207992, 0.03339414504755821, 0.014268302225640841, 0.022139086221743907, 0.03817782371437975, 0.023628477373027375, 0.03524687813062753, 0.08336559949176651, 0.04550296886424933, 0.02462621731683612, 0.0543630280798035, 0.04070110206625291, 0.018884350512442843, 0.009759820399007626, 0.021989979847733463, 0.03815194099609341, 0.02021850981483502, 0.04134168662130833, 0.01183768461591431, 0.05030424872945462, 0.07449817138590983, 0.07460778871817247, 0.034520713346345086, 0.07222347094544343, 0.027370752367590154, 0.01682274229824543, 0.016348682111129165, 0.03901996709672468, 0.04512601551998939, 0.015973664288009917, 0.04222424015668886, 0.052964798108275445, 0.05381914494293077, 0.03479753188522799, 0.04160778769957168, 0.0420506166161171, 0.014933792408555746, 0.041280343662947416, 0.014333102319921767, 0.03874827828258276, 0.06017071447734322, 0.014245265961757727, 0.02927815162443689, 0.04628653771110943, 0.04121481075084635, 0.06115277178053345, 0.043303847046835084, 0.03322216695440667, 0.030257376043924263, 0.03727090059380446, 0.032714700791984797, 0.019066627070839916, 0.04218770783128483, 0.08471964326288019, 0.04461440011592848, 0.039218282526625056, 0.01328610667094056, 0.012055596985322024, 0.013099348388745316, 0.012366176034057779, 0.0395420692594988, 0.06924157416714088, 0.007362143119930157, 0.02908937300422362, 0.11109210098428385, 0.024958919999854903, 0.07706850274865117, 0.10586981049605779, 0.04829039750620723, 0.018159132284511412, 0.017674434364640286, 0.0069389179282422575, 0.015043185824262244, 0.011290979621532773, 0.03847147670707532, 0.02315633574367634, 0.013989727977397186, 0.03619652860132711, 0.05305552502561893, 0.008339823024081332, 0.0074271840941427004, 0.050158791177506955, 0.01854809230592634, 0.017555203887500932, 0.020948755987254635, 0.019196758213053857, 0.04770075396767684, 0.023143916856497526, 0.04890666336619428, 0.012589902600406535, 0.006472874208286936, 0.03619845224810498, 0.036341836875570674, 0.02497163744244192, 0.014377950091979333, 0.02875481452792883, 0.05480522935145667, 0.04310001851990819, 0.05370195855253509, 0.014645893392818314, 0.05838239472359419, 0.028219977959192226, 0.037446203508547375, 0.02085914017100419, 0.01377662642127169, 0.022944493718179207, 0.02254367120830076, 0.05185393450249519, 0.03325434647766607, 0.029035772130425488, 0.007298130126270864, 0.11548565594213349, 0.07037901598960161, 0.015943696788911308, 0.04748420290915029, 0.049751734627144675, 0.015103241262425269, 0.012276857076877994, 0.05032415694690176, 0.021804458195609704, 0.03351491749552744, 0.04036969199244465, 0.032723023023988516, 0.029502122463392358, 0.02348362371724631, 0.04214348091876932, 0.027510445764554397, 0.03160375915467739, 0.03715850126796535, 0.0290868726026799, 0.01666407027680959, 0.04456169151567987, 0.044024349456386905, 0.03716028920773949, 0.0391840199008584, 0.02106578801093357, 0.04575220834729927, 0.07401257779981409, 0.05993775983474084, 0.05579488624685577, 0.0407647656143776, 0.02584226572486971, 0.0070667674964559925, 0.01139160042761692, 0.08723613287189178, 0.03123999313850488, 0.05938050616532564, 0.0673548804063882, 0.019782296614721417, 0.03381919634661504, 0.035107473111046214, 0.016708907870841876, 0.011120527384004422, 0.035680339871240516, 0.04253840187032308, 0.039022450534892936, 0.022927567662139024, 0.023630655470437238, 0.011482124632623578, 0.023208308133429716, 0.056766724812665155, 0.07435086821871144, 0.013379158418891686, 0.023211946777467216, 0.052729794289916754, 0.05472019873559475, 0.004297907813452184, 0.03618911560624838, 0.014342055589492832, 0.05343508394435048, 0.048101503535040786, 0.023971731275586144, 0.05360421219042369, 0.04702182200604251, 0.04833114692675216, 0.03500485147482582, 0.01440190407447517, 0.06019437499344349, 0.03446363837325147, 0.019923720275983214, 0.04115684011152812, 0.030065520267401422, 0.01772147380480809, 0.048176366303648264, 0.05730525430824075, 0.02412185545212456, 0.05045097853456225, 0.015382714569568634, 0.031297302206179926, 0.05067206899236355, 0.013740010127159101, 0.04633022518828511, 0.10844658794147627, 0.017551161515127336, 0.01787351823544928, 0.03492697601073554, 0.009862010317322398, 0.08041099339191403, 0.05113143380731344, 0.04131372419318982, 0.017450103902124932, 0.04964696542759027, 0.04658185989995088, 0.037284176131444316, 0.013481412798033228, 0.024067258828186562, 0.05024340110165732, 0.017649409993152534, 0.05784856408302273, 0.01747676184667008, 0.038175408129713366, 0.054682285591427765, 0.05924399849027395, 0.06382396737379686, 0.007114908707860325, 0.03764886834791728, 0.03278358566707798, 0.02245111733541957, 0.023777880606108477, 0.016298730059393814, 0.07437843709651913, 0.04654745478183031, 0.019724592300398008, 0.02211889301958893, 0.008045106427744031, 0.03893870235021625, 0.05497547718031066, 0.01098933263814875, 0.052751517588538785, 0.02058679996324437, 0.08238736234073128, 0.0020375719593305674, 0.10553363710641861, 0.04279465740546584, 0.04397141354690705, 0.0023622899815174086, 0.021634078052427088, 0.06615215672978333, 0.03673708013125828, 0.009609609709254332, 0.02700344948763294, 0.02483405259304813, 0.015334923651867678, 0.06560399542961802, 0.04919412472684469, 0.012074622259076153, 0.005131810387995626, 0.036606716590800455, 0.012169016658195426, 0.030715692522270337, 0.017203168045463305, 0.027584568929991553, 0.0495820364116558, 0.013589041174522467, 0.11458389647305012, 0.05005076840253813, 0.004598126056537564, 0.06088253842400653, 0.02987708430737257, 0.05325084472341197, 0.06200566315757377, 0.016551852459087968, 0.037396439750279696, 0.06086184310593775, 0.012531053258239158, 0.04063244789306607, 0.03291155397891998, 0.02532495741200234, 0.021216249758643762, 0.023748488165438175, 0.016963701163019453, 0.14079065594289983, 0.08649744572384016, 0.16504817429397786, 0.14256111665495805, 0.09794452147824423, 0.13663462895367826, 0.0704716970877988, 0.15789264254271984, 0.17324921994337014, 0.13231793844274112, 0.12474632901804787, 0.12148484188531126, 0.1324011404067278, 0.10083305862333093, 0.13160547667316028, 0.1245257779955864, 0.17011201328464917, 0.1601205172815493, 0.20260470759655747, 0.12826637870499066, 0.2490607297846249, 0.24445689682449612, 0.13329983289752687, 0.1424006295523473, 0.1261170104678188, 0.06831854941057307, 0.13198697620204516, 0.1263771607939686, 0.07858373251344476, 0.12563312000461987, 0.1444596169250352, 0.163882491844041, 0.10051967722496816, 0.14522876351007394, 0.09410561461533819, 0.17216473099376473, 0.1316959796739476, 0.17381389678588935, 0.11874159265841756, 0.1734564716794661, 0.08585524625544037, 0.10975861003888504, 0.23844108677336148, 0.14908424019813538, 0.09113616895462785, 0.056097255021865876, 0.14395239842789515, 0.11674006363110882, 0.1680968999862671, 0.1994965829487358, 0.13278637187821524, 0.14327298131372246, 0.10751559718378953, 0.06446954594658953, 0.1748825351574591, 0.20342102593609265, 0.13499465052570614, 0.09496380535087415, 0.18222600753818238, 0.11740555720669882, 0.08183384739926883, 0.2159042518053736, 0.11293253222746508, 0.13474272404398235, 0.11261655203998089, 0.13119687645563058, 0.15492772949593409, 0.19585390841322287, 0.12460470518895558, 0.14854430274239608, 0.2148226262735469, 0.0966494491856013, 0.21509219466575555, 0.07748530645455633, 0.11639019740479332, 0.1437463816255331, 0.1299071849456855, 0.1296615009861333, 0.1268482676574162, 0.138003301939794, 0.08790069006915603, 0.10632729237633091, 0.11973540218813078, 0.1412252304809434, 0.11845668937478747, 0.13122544277991566, 0.11249278046722923, 0.17856357406292642, 0.11294203850307635, 0.11231343687645026, 0.07291002624801227, 0.15460082489464963, 0.10467720377658095, 0.07778034705136504, 0.12702307184892042, 0.10403670064572777, 0.09374054920460496, 0.17122462072542735, 0.1478376763739756, 0.09891294701290981, 0.16747370628373964, 0.10971167577164513, 0.24136161005922727, 0.1658900734037161, 0.15564367893551076, 0.12801226734050683, 0.14152788424066134, 0.13508535708699906, 0.06701898521610669, 0.11112861973898751, 0.07526566234550305, 0.13594573949064526, 0.14575177830244812, 0.20259885862469673, 0.1066980981933219, 0.10427880872573171, 0.1734014017773526, 0.12142757352973733, 0.08149337888296161, 0.0782474030607513, 0.16308012418448925, 0.1851725729980639, 0.13578363747469016, 0.1638050709984132, 0.12069223155932766, 0.11303286041532244, 0.09653633061264243, 0.14069046346204622, 0.11636625868933541, 0.1045963495437588, 0.13543905025081976, 0.11674140713044576, 0.10851142874785832, 0.16717981919646263, 0.12154281591730458, 0.1851223206945828, 0.18498296317245277, 0.2671250690306936, 0.07866611345005886, 0.11697836512965815, 0.056978743257267137, 0.112452930105584, 0.1487480125256947, 0.06717153345899922, 0.10297766354467187, 0.16792949182646616, 0.056902408067669184, 0.12704178584473474, 0.1844298078545502, 0.16878371313214302, 0.08355746205363955, 0.08484124352357217, 0.10339657749448504, 0.08394758576261145, 0.17597710713744164, 0.07388140341000897, 0.11044332651155335, 0.10705232739980731, 0.1207357392247234, 0.3606369655047144, 0.1001689899712801, 0.026352812436276248, 0.16008174579058373, 0.06451840725328241, 0.09480671770870686, 0.13218464702367783, 0.0908083686871188, 0.1019954773198281, 0.17803039481597288, 0.19916950192834648, 0.16479691277657235, 0.09893044643104076, 0.1446163992264441, 0.1457807653184448, 0.10684223260198321, 0.07727846862482173], [0.04106833878904581, 0.03177141158708504, 0.04582746805889266, 0.029425003565847874, 0.07870561097349439, 0.057434080966881344, 0.03599846762205873, 0.01634405450230198, 0.054722305586827655, 0.03456927609762975, 0.03310280925195132, 0.04368436609261802, 0.019494300907743827, 0.03964955938447799, 0.05256101888205324, 0.06313701852091722, 0.012226903328805097, 0.010414157162553497, 0.07612580047654254, 0.050499405578843186, 0.08156821451016835, 0.03552187819566045, 0.026711732016078064, 0.06339193734207324, 0.05361543515963214, 0.04693929857707449, 0.04447017071236457, 0.05491436492385609, 0.03862530738115311, 0.012353402612331723, 0.03776952205225825, 0.016752500353114944, 0.013937121157401373, 0.019976975096921836, 0.036931334529072046, 0.028305978880130818, 0.12442709186247417, 0.043838417290576866, 0.04238869668915868, 0.04092447579439197, 0.028827651869505644, 0.0836782752137099, 0.04473414797601955, 0.02336020498270435, 0.02333300929915692, 0.019322453432583382, 0.0053814943114827785, 0.042685840744525194, 0.039656806138477156, 0.005727187547433589, 0.03219962485932878, 0.017233751315091337, 0.05290207093847649, 0.024466437586982335, 0.022405845478975346, 0.03374645739261593, 0.027982687477820685, 0.030097628544483866, 0.0025740932032931596, 0.02043992088043264, 0.0896199620994074, 0.01188456460035273, 0.027492859833208576, 0.07235574456197874, 0.025839344631614428, 0.012794024593728994, 0.034677736527685604, 0.048489567890231094, 0.027074783874143447, 0.04352767539343663, 0.01802301815977054, 0.03458352194034627, 0.012240653840958007, 0.021857858901577334, 0.03040965287280934, 0.10996309335210494, 0.023711036425083876, 0.017230889593650187, 0.04818181154717292, 0.04839282236727221, 0.06682182329573802, 0.040478739355291636, 0.03909714366974575, 0.05025857653734939, 0.09548681335789816, 0.013711721154062875, 0.07151350618473121, 0.02509855232866747, 0.07226887850889138, 0.06344026260610137, 0.025545335408034067, 0.07398340079401221, 0.01568911723526461, 0.024875483941286802, 0.01428604930905359, 0.03249482151919177, 0.019396992200719457, 0.051680860575288534, 0.03397481496046696, 0.04347890229629619, 0.010057980560564568, 0.04601838745708976, 0.0036012224071393056, 0.01446149980516306, 0.03608344056244407, 0.04907818005553313, 0.010979928142790283, 0.048838616481849124, 0.03776481980457902, 0.006583933427464217, 0.023102125884698968, 0.0494781153808747, 0.06535448453256062, 0.015459054848179221, 0.044909851226423464, 0.030166170759392635, 0.029454044864646027, 0.0183889945037663, 0.0372971361503005, 0.06895018408873252, 0.02385308942757547, 0.023230894867862974, 0.02390070053349648, 0.03807715965168817, 0.052637700124510696, 0.04855758763317551, 0.02279868672069694, 0.02720633315454636, 0.04352703417784401, 0.02395438283149685, 0.04108038278562682, 0.07449092463191066, 0.04906145077464836, 0.09179899588759456, 0.013678299911719347, 0.046306150765823464, 0.058078146406582425, 0.02416288137568959, 0.07735136364187513, 0.07008261832275561, 0.02191695082001388, 0.0261545597708651, 0.009994855599610932, 0.04448293395606535, 0.01698763309312718, 0.008717409102246165, 0.05850160654102053, 0.00927233200387231, 0.04470277251675725, 0.025020469911396503, 0.049580818441297324, 0.019942351151257753, 0.05159660688202296, 0.036137719971260855, 0.05008339575890984, 0.02804178448526987, 0.021666013303079774, 0.04190329309286816, 0.04470662659566317, 0.042950981695737155, 0.04473457884575639, 0.02399825181679002, 0.01964383475881602, 0.0394592845945486, 0.057468353770673275, 0.011064097019178527, 0.04467854203124132, 0.05303918250969478, 0.022775150037237575, 0.0509021262904363, 0.01946515104334269, 0.048350220546126366, 0.04723239856372986, 0.02887875573443515, 0.04063398138220821, 0.050413214668099365, 0.02796320504109774, 0.04409665414797408, 0.02972255813490067, 0.07874126120337419, 0.028436674902747785, 0.059171042405068874, 0.07911073709172861, 0.036069903788822036, 0.09238613223923103, 0.08474679144897632, 0.017175041072602783, 0.06509242073765822, 0.058600333386233876, 0.07279599165277821, 0.036654699194644175, 0.06127058581582137, 0.03176745233525123, 0.023777817841619253, 0.041713252397520204, 0.09880945006651537, 0.03140826643045459, 0.06976404613150017, 0.009941230977087148, 0.0354849557126207, 0.037813769320824316, 0.06327310550425734, 0.04636619093694857, 0.026271754642948508, 0.05057145581979837, 0.08587488305888005, 0.018166457070037723, 0.014844671922868915, 0.004337019844180239, 0.028944278468510935, 0.031697773574186225, 0.07440382109156676, 0.10773952731064387, 0.02151026067856167, 0.011241071674573635, 0.03310049884021282, 0.09200868356440749, 0.01739818579517305, 0.02318139573825257, 0.05193536888275828, 0.03685046672554953, 0.015208558379007238, 0.07395017971949917, 0.08592409041843244, 0.0682888635035072, 0.030081248709133694, 0.012871643910849733, 0.06686086620071105, 0.01589527992265565, 0.009282563463784754, 0.036996640131941864, 0.018618444512997354, 0.03610577793525798, 0.055511652159371545, 0.022140467040506855, 0.00992833117821387, 0.031382641555475335, 0.04204773962763803, 0.06875220114099127, 0.07201022774513278, 0.006206015715309019, 0.007980220668417002, 0.026326921236302172, 0.0644083149465067, 0.02798067731782794, 0.0489395383878478, 0.05426945810073188, 0.02094870848980333, 0.0166212411464325, 0.03966146428138018, 0.025530904664524963, 0.04915353136935404, 0.010612355545163155, 0.06967857107520103, 0.03271257697737642, 0.03072682049657617, 0.04878122938264694, 0.025720792689493725, 0.04480767742331539, 0.009516545238771608, 0.058324617466756275, 0.029442251926021915, 0.05889328409518514, 0.05857822671532631, 0.009611643617972732, 0.022666645502405505, 0.014089295357864882, 0.017415929485910704, 0.01861105696298182, 0.0214456845008369, 0.03602011628182871, 0.02031474813286747, 0.03508483039747391, 0.06166153055216585, 0.03596919222867914, 0.051872746885887215, 0.02751438126766256, 0.03240202507004142, 0.01447687201601054, 0.060132669018847604, 0.0032783851992072804, 0.023600835552705184, 0.023796004276456575, 0.042925051479999504, 0.054665413818189075, 0.05246634628357632, 0.047708665685994286, 0.059870673077447076, 0.050854170827993324, 0.04440064462167876, 0.055435734268810065, 0.044724237972072194, 0.07705765975905315, 0.0648235919486199, 0.02654533996246755, 0.01999572471582464, 0.022275068032156144, 0.018931418790348938, 0.04325542000255414, 0.08112517185509205, 0.013924985558592846, 0.03783981488751514, 0.02922100540516632, 0.03747659509203263, 0.02527282217384449, 0.06159520375409296, 0.06691166811755725, 0.03391895117238164, 0.018396363394068818, 0.04858138385627951, 0.05304440383666328, 0.058961252948003154, 0.0446194110970412, 0.002316411048273689, 0.03962247905188373, 0.03293683619371482, 0.06209334345268352, 0.06870069354772568, 0.013882378648434366, 0.02873377315700054, 0.04012953470061932, 0.019685886966596757, 0.019484684370192032, 0.04577168569500957, 0.02617580639863653, 0.04455593414604664, 0.09830499320690121, 0.05695055012724229, 0.02034311768199716, 0.01777888634907348, 0.03880566538178495, 0.028162636661103795, 0.02817760853629027, 0.02565848281873124, 0.059167541164372645, 0.06255207383739096, 0.01295165591207998, 0.0323677929783506, 0.03014792495274118, 0.01634575762519879, 0.04343288065865636, 0.02259067163270499, 0.022701391584372947, 0.03946606655205999, 0.024292905648638095, 0.06706228932099682, 0.034243704817656956, 0.03080819041601249, 0.06565434272800173, 0.024689175188541412, 0.07430200691201858, 0.008019819972105324, 0.09936652731682573, 0.21835810584681375, 0.18537996044116362, 0.12606903804200037, 0.19066813667970045, 0.16411267806376728, 0.11213528072195393, 0.10320088799510684, 0.31702013739517754, 0.12556366516011103, 0.10588163736143283, 0.11652051684047494, 0.11830785950379712, 0.2236798559980733, 0.17788621969521046, 0.11026634422263928, 0.10175976103969983, 0.12821428078625882, 0.2794720450682299, 0.18573784695139953, 0.148438926254, 0.16774639593703405, 0.1305898997400488, 0.15505570120045117, 0.14889012490000042, 0.12372322034622942, 0.17502410470374993, 0.10134356122996126, 0.09730539577347891, 0.12854153822575295, 0.13048315261091503, 0.057096109459442754, 0.10545015694307429, 0.10528810242457048, 0.13591576181352139, 0.16075977869331837, 0.21735790451722486, 0.12361408477383, 0.11706975022596972, 0.09811517303543431, 0.15299231692084245, 0.06892732424395424, 0.0679955735270466, 0.1309464020388467, 0.12421636602708272, 0.09967761526682548, 0.14672334545425006, 0.1626660685454096, 0.12266177444585732, 0.2121655781354223, 0.1289207035941737, 0.1603968981653452, 0.12949159581746372, 0.09678336485688176, 0.17521496303379536, 0.06375785092157976, 0.12397885162915502, 0.14229789935052395, 0.07628189745758261, 0.07391786109656096, 0.2463121744138854, 0.12686953294490064, 0.2595072106591293, 0.1793932459716286, 0.12527889758348465, 0.11817223392426968, 0.24396897586328642, 0.15863137718822273, 0.16197108583790915, 0.19966172480157443, 0.11931661037462098, 0.09406858017402035, 0.049809077621570656, 0.12888105000768388, 0.10263596009463072, 0.16169121728411742, 0.14198210915284498, 0.12622089417917387, 0.09098811939890895, 0.07354235303189073, 0.18525272155446665, 0.09999379222946507, 0.16751133783587388, 0.1430367697030306, 0.17936865586255277, 0.09842867657010045, 0.09762280766985246, 0.11031346169433423, 0.1354847563696759, 0.1745806820690632, 0.08587408238755805, 0.1935651283711195, 0.08190115807311875, 0.10073534958064556, 0.07410495355725288, 0.09638896637729236, 0.14390590520841734, 0.1428740027227572, 0.12327264595244612, 0.14115763482238564, 0.07106602591063295, 0.08902785208608423, 0.07401540050549166, 0.13418567393507275, 0.11260376165487937, 0.2353805410010474, 0.12672884549413407, 0.10078223635043417, 0.2581937297114304, 0.18452875183096953, 0.11560007051697799, 0.12434021223868642, 0.11698173066335064, 0.13110768981277943, 0.11431352740951947, 0.06652369536459446, 0.1148422011839492, 0.12404686797942434, 0.09788637102714606, 0.13597145596785204, 0.05004109588584729, 0.059182719992739816, 0.12242383935621806, 0.1282299142330885, 0.10837828660649912, 0.12314793121601854, 0.11579160738204207, 0.08991235640964337, 0.08957697012062583, 0.12424737507743494, 0.21980261190661363, 0.16083439040396894, 0.1862875281700066, 0.13160373962351254, 0.09641494069780622, 0.24685285825814518, 0.09211831446737051, 0.1340832422886576, 0.1610966713300773, 0.15547491370567254, 0.17213650393698895, 0.15164219508213655, 0.1006846765854529, 0.20271468455238, 0.10874718574008771, 0.0737090419445719, 0.15867379919758864, 0.12647155858576298, 0.1302472666970321, 0.10611518232950143, 0.1440884718405349, 0.13514988576727255, 0.14500194282404014, 0.13659859874418803, 0.13701311578708036, 0.17884154271866592, 0.09041373950562306, 0.15401222290737288, 0.12954555292214665, 0.13039126539868967, 0.10453039593994617, 0.0944507107404726, 0.18944165749209269, 0.09955789454813514, 0.15084077737161092, 0.04828587167763284, 0.07825615616249186, 0.2770755136651652, 0.10563566163182259, 0.15363672162805284, 0.06997547085796084, 0.19894411973655224, 0.13319927400776319, 0.127417368548257, 0.19382113963365555, 0.06494295982910053], [0.06196424538003547, 0.03421738105160849, 0.0454076482648296, 0.028976498703871454, 0.04632640842880521, 0.05088255734049848, 0.02145300250101302, 0.023461718910506794, 0.006648093578405678, 0.08686760014721326, 0.058187356617833884, 0.056243679486215115, 0.05829226491706712, 0.022826447284647396, 0.014080935806435133, 0.025687281541260223, 0.025575448792161684, 0.016644087420510392, 0.06313089134969882, 0.029998477614883865, 0.008963581607011812, 0.012714693672023714, 0.05093570359583412, 0.03485521753983838, 0.09381118470004626, 0.03249558826376285, 0.007752092954303537, 0.04364919422992638, 0.07559245159583432, 0.03055499168112874, 0.027788733331752673, 0.0449590823347015, 0.04656238255224057, 0.024390982796571085, 0.04911192360201052, 0.04335448272260172, 0.007116947705591363, 0.03783618472516537, 0.024531062958495956, 0.02418980564522956, 0.005662206369119563, 0.05103727689545069, 0.034675629676452706, 0.06587160964097295, 0.04470718638705356, 0.021433849153774123, 0.025495339251522506, 0.014863694652116724, 0.04893744171464017, 0.034170395894242186, 0.0531411323962467, 0.0544002796523273, 0.03926829395017453, 0.03256922966933676, 0.03763571494658079, 0.08153872537825789, 0.014639299728774598, 0.03430587898141571, 0.05780190122979028, 0.026168885341446315, 0.015565554312031184, 0.01795466084565435, 0.01757177201631878, 0.02449561289644667, 0.05059555059831057, 0.014031051608201648, 0.02412508867148842, 0.043681682486619265, 0.026482573776905025, 0.12750586308538914, 0.024570909927466085, 0.0452243589929172, 0.03920552946094956, 0.04702935374474951, 0.015554302505084446, 0.079453030867236, 0.013273059290700724, 0.007254700492402273, 0.04056193453392812, 0.03013679019308516, 0.033204816813979826, 0.03653843900454896, 0.019511849519663622, 0.012852575380488165, 0.01747259564165558, 0.04603759339079261, 0.051864010747522116, 0.03598556188600404, 0.054291320499032736, 0.0525178131647408, 0.01064112882262894, 0.06661851384810039, 0.0395938279107213, 0.005829343114913042, 0.019164655024984052, 0.05638650771496551, 0.04792537620025022, 0.0309453901967832, 0.06157629976847342, 0.05262291823912944, 0.033315787823604684, 0.06856337163065161, 0.013534771943730968, 0.01690598836700831, 0.053562489072127004, 0.031115624454936812, 0.0543357679354293, 0.015165734337642789, 0.014455331921843546, 0.02990615274757147, 0.008018179613697742, 0.01215460118172424, 0.06799681524613074, 0.04710538698626416, 0.007079011660867504, 0.03242114957954202, 0.023013217441205467, 0.013210209136429642, 0.040871970754648955, 0.027874817373231053, 0.05065800974677716, 0.0028734609451411025, 0.030957227240183523, 0.004525376500428787, 0.06305068172514439, 0.031665597443601916, 0.02081487254638757, 0.04961827018165162, 0.015557953023484774, 0.12389108990984303, 0.013986043532245925, 0.030106513960553066, 0.04300122382119298, 0.0271017912642232, 0.03672357049903699, 0.009996905623536025, 0.03260081886712994, 0.0414985842736704, 0.055037729375596554, 0.06500117813370057, 0.06888019320155893, 0.054606706968375614, 0.05458124494180083, 0.015820870076173117, 0.06428520155272313, 0.004009410838729569, 0.017578445408227186, 0.08245478158018418, 0.07371528446674347, 0.035126628154622655, 0.0725274614191481, 0.05514076152550323, 0.06120817416480609, 0.008856540163313704, 0.04501833540520497, 0.044762846614633284, 0.05959704704582691, 0.03393455408513546, 0.026409917943445698, 0.015351096534037163, 0.046732087553079636, 0.03768668310450656, 0.012385902743387436, 0.014814711209120495, 0.06307373155972787, 0.02169617757733379, 0.004257043466038469, 0.038312533271632025, 0.04964641242155007, 0.045867216640285084, 0.03938021830150059, 0.012030058623557644, 0.04107739383886967, 0.0490996353328228, 0.012449907255358994, 0.014362035053116935, 0.004856929066590965, 0.04282894038728305, 0.0146216272842139, 0.07109517577503409, 0.009185042714567056, 0.006030036385969392, 0.03801372341279473, 0.040423231798091104, 0.04676805669441819, 0.04670562808002744, 0.039060780978096385, 0.06507232931575604, 0.059915605666381974, 0.020733967423439026, 0.03311737061345151, 0.03656530559861234, 0.025870938918420246, 0.01332592056132853, 0.012188325220319842, 0.022625170049390624, 0.01639214906442378, 0.04915988924247878, 0.09085476012634379, 0.015624678460881114, 0.03670907699103866, 0.0982832597302539, 0.054436191118189266, 0.04143894783088139, 0.025295507295855453, 0.007925437447348875, 0.017457693316308514, 0.07298075673835618, 0.013636665002975081, 0.018256614017965536, 0.060386685388428826, 0.004013785693262304, 0.03783422715163656, 0.03406466996031148, 0.021675482259265015, 0.02710481413773128, 0.010960008899149085, 0.08883647806942463, 0.03277135846604194, 0.03929929621517658, 0.035089234089744945, 0.06116675638726779, 0.025862268937219466, 0.03449935306395803, 0.019741241853418093, 0.07206690577524048, 0.04163218103349209, 0.03756626010207193, 0.05347210142229285, 0.0439553254816149, 0.02368600696458348, 0.02366552538504558, 0.06554876267910004, 0.018353693719421114, 0.03538414237222501, 0.029392569591956477, 0.027188752312213182, 0.020594061984281455, 0.014228616408737642, 0.017221973643505147, 0.048224036781383414, 0.04215726535767317, 0.030505499336868525, 0.04708132952717798, 0.03193168495116489, 0.09017577048923288, 0.023961319155724983, 0.019607237972585217, 0.012825914891436696, 0.0928674985521606, 0.04491697245144418, 0.08409824767815215, 0.008549959382175334, 0.028058379755488465, 0.008999438790072287, 0.01469253419366266, 0.009245599420475108, 0.09618113788643054, 0.010879355682326215, 0.029121325218251774, 0.06151672439383609, 0.033805520473314185, 0.04713936123464789, 0.07282482939107077, 0.03969224941517625, 0.08341543110353605, 0.020532216910006743, 0.07957841735333204, 0.017226373943101083, 0.02332046827567475, 0.024312785028346946, 0.042364014977855344, 0.013825506387677575, 0.01885395892895758, 0.029862231175814356, 0.08023211120494775, 0.03793092178446906, 0.022169291208099042, 0.020307557358007346, 0.009548248939349182, 0.033905770629644394, 0.01846640686770635, 0.05328994869653668, 0.022629887564107776, 0.03805659664794803, 0.033638231057141504, 0.05874389104012932, 0.0332146691424506, 0.009126846462355127, 0.014619834255427122, 0.019947194194953357, 0.04264344587656004, 0.03186038788408041, 0.028666041791439056, 0.05618591240740248, 0.02884196556572403, 0.01590642994934959, 0.033812723122537136, 0.03204314111332808, 0.015552592596837451, 0.018522078969648907, 0.038112026173621416, 0.06281270592340402, 0.050691620978925905, 0.048011685854622295, 0.03958963117163096, 0.03758109966292977, 0.03178992880774396, 0.039321318069206815, 0.027566947375557253, 0.035551309652094326, 0.05741405739848103, 0.10660776482628924, 0.018225895041333776, 0.0528430791039552, 0.04334705615682261, 0.03341087432844298, 0.03234618163800665, 0.06051837546484811, 0.05048903077840805, 0.016373155172914267, 0.04442980466410518, 0.044072518657360754, 0.05517693083467228, 0.03350773859503014, 0.02641884746429111, 0.07477191276848316, 0.012832168439802314, 0.06697315017559699, 0.022102482650162916, 0.024483272040795003, 0.03891950998721378, 0.02466928223813219, 0.040127037691750696, 0.05183099662618978, 0.05503895752398031, 0.02575299596147878, 0.04832533188164234, 0.028122553901214684, 0.036979296776865206, 0.026440769234406095, 0.0047339505316423515, 0.02430941949465445, 0.07006507819252354, 0.08091674625341382, 0.061057403683662415, 0.0036488568377015845, 0.044248001383883614, 0.014833586357001747, 0.02659748537865068, 0.0230464096779802, 0.02003395677145038, 0.13253107986279897, 0.10835480929485389, 0.11034535284021071, 0.20237309645329202, 0.12568452581763268, 0.09953578109187738, 0.07405335775443486, 0.11959858238697052, 0.1453850572662694, 0.10092737499092307, 0.17099204606243543, 0.1943695316357272, 0.1322942982826914, 0.05798321257212332, 0.08100923736180578, 0.15354791496481213, 0.08922096315239157, 0.08650610383067812, 0.1635368461055415, 0.10569974247898374, 0.06785612779536418, 0.09733858970659119, 0.24642288418752806, 0.205825876178486, 0.16155517101287842, 0.1795169971883297, 0.08893416675605945, 0.14017476327717304, 0.11946659375514303, 0.08925501882497754, 0.16692235586898668, 0.1776149413947548, 0.12437073274382524, 0.06623444945684501, 0.11973325801747185, 0.06042215919920376, 0.09901098853775434, 0.16906936280429363, 0.09643424501908676, 0.12205060438386031, 0.10333035926201514, 0.13857734256557055, 0.09615805412509612, 0.1648937261530331, 0.08390422737491982, 0.2099098970315286, 0.11902625166944095, 0.1336895969829389, 0.163450047905956, 0.12532252738518374, 0.10103447495826653, 0.16349063787077153, 0.11879377200135163, 0.1787904083196606, 0.10961340354489428, 0.2480639075594289, 0.11851927744490759, 0.09626178177339689, 0.11457393557897635, 0.08448932133615017, 0.10018255388630287, 0.13764875382184982, 0.10780696012079716, 0.08140346620764051, 0.11181266446198736, 0.11788532217698437, 0.09467378591320344, 0.17430587538651057, 0.13783992427800382, 0.2544974237680435, 0.12197272213441984, 0.137255868475352, 0.07799446556184973, 0.16287588514387608, 0.08738182791109596, 0.33199252826826914, 0.10720438031213624, 0.08020662542964731, 0.08198739308863878, 0.15225035244865076, 0.0953283550749932, 0.17573336378804275, 0.10496531653084926, 0.0892043797565358, 0.16598935664764472, 0.11235671383993966, 0.1012927864545158, 0.18937680311501026, 0.13655487394758634, 0.11516464102481093, 0.10858695648078408, 0.12702541958008493, 0.1951714786035674, 0.14163803761558874, 0.20470602198370866, 0.17411778547934123, 0.11828998689140592, 0.09841267671436071, 0.16819450046334947, 0.16808919182845525, 0.19522648065217904, 0.1830555030277797, 0.08013134196932827, 0.18375222278492792, 0.077950957896454, 0.1768266194100891, 0.12690412466015133, 0.10698809727494206, 0.12396895858858313, 0.11329748907259532, 0.11153428868523665, 0.1345316453703812, 0.21829797407346113, 0.16041612784777368, 0.0884091095732791, 0.07736648140209061, 0.0903350565848606, 0.09852749162486621, 0.08782780862280301, 0.12699715181120805, 0.15058442684156553, 0.0820683558870639, 0.09027305884020669, 0.10257384021367345, 0.11429389060607978, 0.10805806557514838, 0.10291628326688494, 0.13194771616586617, 0.14050740828471525, 0.13736454264393874, 0.09351083117404155, 0.09645527960466486, 0.08680617915732519, 0.09962808221046414, 0.10747550933488778, 0.10540272734527077, 0.15149260525192532, 0.1524838770606688, 0.138430616153138, 0.13622944855264255, 0.1669626065662929, 0.10124520079365798, 0.25748995319008827, 0.12567985749670438, 0.13195413510714257, 0.06913085082279784, 0.12980567610689572, 0.19664331605391844, 0.08272151369601488, 0.1174531632236072, 0.15229106454976968, 0.11780486149447304, 0.1799212276403393, 0.11452388683600084, 0.11014923586377076, 0.12727630111788, 0.16167326324752399, 0.17623592753495487, 0.11802846592451845, 0.1821895566369806, 0.11527182241635663, 0.15563309378921986, 0.12221907105829034, 0.10352779938174145, 0.24784588068723679, 0.07164546088980776, 0.1451684824590172, 0.10565627552568913, 0.2094196690512555, 0.15042989727641853, 0.1309233047068119, 0.10205329528876714, 0.08621113787272147, 0.13495617759014877, 0.11652479161109243, 0.07618151498692376], [0.01042105192651174, 0.044224164448678493, 0.017578073910304477, 0.028591314729835306, 0.03327051257448537, 0.08675112282591206, 0.004227919894869306, 0.02038122760131955, 0.05153929102899773, 0.017151509478156055, 0.08364474201308829, 0.028671480249613523, 0.02110831010421472, 0.03159526389624391, 0.0057410080335102975, 0.0740196006372571, 0.03985202744869249, 0.015483936727313059, 0.029260777735284398, 0.03675249644688197, 0.011388052537638162, 0.03172027040272951, 0.11023839536522116, 0.06212091911584139, 0.015093492410544838, 0.04352830643100398, 0.02050381343412612, 0.02979797390954835, 0.11092878439064537, 0.062064315724585734, 0.016374089854902456, 0.060583562324089665, 0.03621434014556663, 0.022054349072277546, 0.01952551182226411, 0.058221615850925446, 0.06544738276196377, 0.04371394343408091, 0.07512462884187698, 0.029701401413019215, 0.03851830580138734, 0.047061356848904064, 0.02413704276217946, 0.05693736619182995, 0.05269941288445677, 0.040199997169630866, 0.028949509973504713, 0.059917620915387354, 0.022737170735906278, 0.0028066441175594392, 0.034862274304032326, 0.013391460258779781, 0.04489168684397425, 0.045098555207784684, 0.0068574008515237695, 0.01471050180095647, 0.0855202738727842, 0.03631542829264488, 0.022103916055389812, 0.05234352805252586, 0.010071994005037206, 0.02159239225355642, 0.014636646656851684, 0.06830151139625482, 0.05488893682403224, 0.06794867318655763, 0.04490293695458344, 0.03430289342733366, 0.0793228539239083, 0.047694029685642035, 0.08142151523913656, 0.011850460582146687, 0.03561120733086552, 0.007432752322139484, 0.051180807407945395, 0.07207171658852271, 0.011978213459120264, 0.017502244229295423, 0.010704622736998966, 0.03931602888873645, 0.06959151503230844, 0.027159773777904253, 0.07623649667948484, 0.029779992731554166, 0.08421683524336133, 0.04462696658447385, 0.06820081001413719, 0.03830806851120932, 0.04503732420770185, 0.0715494074725679, 0.046401746171925745, 0.0322287815090801, 0.009222712434296097, 0.02593425302101033, 0.023235432570800185, 0.029630430042743683, 0.05475040711462498, 0.03378097107633948, 0.0875743350812367, 0.013942665636672505, 0.0462288215224232, 0.05382778947906835, 0.04012962969552193, 0.04746652367923941, 0.019155747556526746, 0.05485307964097176, 0.026810199321646775, 0.036806551939142604, 0.005988797147957874, 0.03995964649532523, 0.044197060367358584, 0.0456972707595144, 0.02512410086845713, 0.026984129899314473, 0.12879247404634953, 0.017149467087749923, 0.07735743653029203, 0.031031883055610315, 0.06262015125581197, 0.040329264876033576, 0.04993098661569612, 0.04245659429579973, 0.06570524642510073, 0.0564816993927317, 0.05393799713679722, 0.020749957101153474, 0.07466690947434731, 0.06447166297584772, 0.04264761208157454, 0.044377567645694525, 0.04678537630076919, 0.06040501940463271, 0.027441272512078285, 0.02038583655043372, 0.025939586306256906, 0.0301734684035182, 0.03322385311392801, 0.05174638670203941, 0.014170845089081143, 0.02433642009938402, 0.04357087093272379, 0.022997336329094002, 0.03923188036839877, 0.05708829952137811, 0.06722035405359097, 0.034859539807907174, 0.014194562432489224, 0.038644445461354086, 0.0012263220643425094, 0.003200272671944861, 0.03686921464811478, 0.012911209287787122, 0.053728312852659395, 0.05002837335424764, 0.020334593585825393, 0.07988816858934504, 0.05293559056839772, 0.00860838039911219, 0.05888200005782502, 0.015299132625971521, 0.0040292885221008745, 0.0360336225213749, 0.010718236693979373, 0.02124617145662861, 0.01889174654414611, 0.0686629805713892, 0.027534640626981854, 0.03162041040403502, 0.026212822180241346, 0.029053414040910344, 0.04934308351948857, 0.018755233780081784, 0.008825565887881177, 0.015891118806653788, 0.00390736002009362, 0.05733564589172602, 0.06792472768574953, 0.026102767192891667, 0.025214999115892818, 0.03229684196412563, 0.050369164174688716, 0.07456031840826784, 0.05850675662181207, 0.005150339058932981, 0.02045426850340196, 0.034502803414527855, 0.0818400899214404, 0.028236244139926772, 0.05808867048472166, 0.01868614025547036, 0.01549468981102109, 0.11143392657062837, 0.048609878934387646, 0.006810088725095349, 0.046230779095951996, 0.01662988228989499, 0.018923956601481353, 0.03936904961509364, 0.028190629623298134, 0.08485053266797747, 0.017961422447115183, 0.017098822930295552, 0.037913588607417684, 0.046201357817543406, 0.06542712170630693, 0.07715433742851019, 0.01804475672543049, 0.0675544918381742, 0.07743685905422483, 0.009582988235966435, 0.02292895526625216, 0.05535336351022124, 0.02728113315866462, 0.033580949130867205, 0.02192827726581267, 0.0032428138490234104, 0.03255957750869649, 0.03639252344146371, 0.036159321133579524, 0.05395799695647188, 0.029281276278197765, 0.0246632025643651, 0.03326781539778624, 0.08533882682344743, 0.044110479298979044, 0.01448912635844733, 0.04031092068180442, 0.050155218690633774, 0.030546058767608235, 0.023326330818235874, 0.03542089182883501, 0.04358306420700891, 0.009922847767094416, 0.010247794794850051, 0.027811348903924227, 0.061492202138262134, 0.07320066993790013, 0.01456676603161863, 0.027680559582742195, 0.02877870574593544, 0.018712716775813272, 0.06243962022875037, 0.050088094613913975, 0.030768197562013353, 0.004797434692071485, 0.05194311775267124, 0.0793398240847247, 0.05718892626464367, 0.03749610297381878, 0.012714122006270503, 0.04195718573672431, 0.027252453179763894, 0.021765328777421798, 0.007577866365733955, 0.03187573973887733, 0.040490104816854, 0.08474917310689177, 0.031646774882184606, 0.014203506372203785, 0.00911318076707955, 0.015899661562538574, 0.0428956369869411, 0.03147335150944335, 0.04907748116446393, 0.03835663804784417, 0.06764529339436974, 0.029599590626146113, 0.018252142472192645, 0.01625112404248544, 0.031516720075160265, 0.03377155979563083, 0.01107173053813832, 0.04886649748576539, 0.06738519735102143, 0.05252965360081621, 0.09571157808282546, 0.02416426728346518, 0.029150271522147313, 0.015731624061507837, 0.01335454371292144, 0.04499123810923525, 0.06280712158020053, 0.028874847372727733, 0.03573856496119073, 0.032838893056448014, 0.008671387464606335, 0.03853375943643706, 0.022890497597732713, 0.040876706929079125, 0.019037209185106412, 0.05835348913179977, 0.02952225459739566, 0.03817444460998688, 0.036504705636096854, 0.07073128422988312, 0.04741995242823448, 0.03883979569322296, 0.043960879290742536, 0.08716815723372356, 0.03946414629795721, 0.020785936420517306, 0.0722534554079175, 0.05911273589091642, 0.025882667396217585, 0.00827358104288578, 0.013673800376376935, 0.08007029417370047, 0.013820258767477103, 0.043170596339872906, 0.035486302604632716, 0.036975608939038854, 0.011616263372291411, 0.0424255343553211, 0.07283809475068535, 0.020378991828433106, 0.06912817060947418, 0.022910850255617073, 0.029325991735926697, 0.015876688063144684, 0.025294628593006303, 0.05216359752895577, 0.0358242808974215, 0.062410205735691955, 0.027057927367942672, 0.011239217577635177, 0.02431938038872821, 0.012551374533878905, 0.007681566872633994, 0.05526043474674225, 0.0610939088676657, 0.07623557387185947, 0.03650637483224273, 0.04692337675286191, 0.0717823485444699, 0.03501099221674459, 0.051397646843854866, 0.006506370089482516, 0.012002401536197534, 0.02670063796852316, 0.00530695469517793, 0.03254002891480923, 0.004477080498223326, 0.014606901377971684, 0.03628316395250814, 0.0390819580560284, 0.018078654638624618, 0.04056420762624059, 0.034026716104043384, 0.025854236778936217, 0.00791264112506594, 0.07562861751232829, 0.023901085602119565, 0.1698980847639697, 0.1299296851669039, 0.08667844494006463, 0.1560253548835005, 0.1277128298367773, 0.24191144055553845, 0.10385501610913447, 0.0972790482587048, 0.12508320808410645, 0.15312879745449337, 0.1906442115349429, 0.14431612033929142, 0.09303316287696362, 0.07188748076025929, 0.09278713964990207, 0.21946092881262302, 0.10673876958233969, 0.1143040279192584, 0.08578140807471105, 0.09576465309198413, 0.19987259991467, 0.09268875207219805, 0.12399223233972277, 0.18766366504132748, 0.09688627826316015, 0.10168664889144045, 0.12412130327097007, 0.11378838880253689, 0.17406560613640717, 0.11693389394453593, 0.13394290767610073, 0.1651678407298667, 0.1323256873126541, 0.13823799363204411, 0.12057603922273431, 0.19394213599818094, 0.12140343125377383, 0.16644724564892904, 0.13374618680349418, 0.15523349094603742, 0.08683013144348349, 0.0849634748218315, 0.09532790045653071, 0.16656959908349173, 0.11526944754379136, 0.10728608949908189, 0.16559925329472336, 0.2669272625020572, 0.08083079622260161, 0.061445417148726325, 0.2165940912174327, 0.12517191975244454, 0.14535817370883056, 0.10490969023002045, 0.07948796863534621, 0.10157275678856031, 0.15904011311275618, 0.06996654812246561, 0.11562194648597922, 0.11750436547611441, 0.20806365752858774, 0.14362742086606367, 0.08735195201422487, 0.26210749255759375, 0.12001334370246955, 0.11699519279812064, 0.11621552892029285, 0.1767465794192893, 0.1532964770283018, 0.11867901815899781, 0.16433621464031084, 0.25447777339390343, 0.07479741889983416, 0.12355251450623785, 0.11376456543803215, 0.19030886595802649, 0.13352961199624197, 0.07426812087318727, 0.1636307282107217, 0.13357215614191123, 0.19317151020680154, 0.09598267317882606, 0.21775038274271147, 0.111307800481362, 0.15071980814848626, 0.22953995583312853, 0.10356097974415336, 0.1306298111698457, 0.09929734388632433, 0.16779066356165068, 0.1131027088101421, 0.11457867175340652, 0.05787968848432813, 0.21209657112402575, 0.07932881824672222, 0.16621893218585423, 0.17241829953023366, 0.21202508067446096, 0.26367547842008726, 0.20271959714591503, 0.08591794967651367, 0.17617332589413437, 0.095384381711483, 0.10319356660225562, 0.10167180254523243, 0.2087509592196771, 0.08421842980065516, 0.171638676364507, 0.12453472108713218, 0.06693025997706822, 0.1510003823786974, 0.11604379170707294, 0.11028649671269314, 0.08415550924837589, 0.20949916621404036, 0.12020602050636496, 0.11223493716014282, 0.0850428973457643, 0.13975008177970136, 0.14327189565769263, 0.13868342473038606, 0.13709395644920214, 0.19747279797281536, 0.13357048694576534, 0.14705736110252993, 0.1196090318262577, 0.17650780294622692, 0.11761454599244253, 0.11598459631204605, 0.14268003670232637, 0.19128332366900785, 0.1281300610197442, 0.19351240620017052, 0.1394589359738997, 0.13419779257050582, 0.08978676636304174, 0.061099215011511526, 0.1812279232378517, 0.08978830663753407, 0.12349874739136014, 0.16049605927297048, 0.09488429461738893, 0.14147050731948443, 0.1562267169356346, 0.1735947842576674, 0.08875605809901442, 0.11651787055390221, 0.1138663999736309, 0.12712318290557179, 0.07053934702915804, 0.11212543517883335, 0.07537496755165712, 0.17262115435940878, 0.11232884640672378, 0.12700868690652506, 0.15382549007024082, 0.15911009721457958, 0.17431830614805222, 0.12073948473802634, 0.061772762797772884, 0.06362702258463417, 0.1359463773135628, 0.059705504083207676, 0.07555442649338927, 0.09536984749138355, 0.13955488082553658, 0.06060748068349702, 0.13852942442255362, 0.10079645165907485, 0.08568236910338912, 0.18426964644874844, 0.14256182233137743, 0.08399363793432713, 0.1490291567253215, 0.14387291483581066, 0.12636760702090605], [0.010467985345582877, 0.024118254127513086, 0.03627968646053757, 0.052288539574614594, 0.08944145989205156, 0.01331622599224959, 0.03602331557444163, 0.047587696462869644, 0.031554473763597865, 0.03423041231664164, 0.011467313061335256, 0.04614047287032008, 0.05541214160621166, 0.008907812813829099, 0.03368116196777139, 0.033677742151277404, 0.020569361613265107, 0.016783159957932572, 0.05777459019528968, 0.02879836969077587, 0.028340428103027598, 0.018714954245037267, 0.014447440559576665, 0.019243130992565836, 0.0741094115323254, 0.06944489718547889, 0.028656413379524435, 0.02252075368804591, 0.027893487264269164, 0.06163907104304858, 0.03741883479857019, 0.07945510039904288, 0.02676433713973633, 0.10411499680152961, 0.03278427438012191, 0.05071845364623836, 0.025897371250071695, 0.00768900107193206, 0.02315616441358413, 0.023367797789563025, 0.041481949987688234, 0.02965332381427288, 0.05482209433934518, 0.023243144121287123, 0.005309066635423473, 0.0980940977377551, 0.01380962273105979, 0.01454560422072453, 0.01283309464010277, 0.016708154696971178, 0.04017190581985882, 0.06956491645957742, 0.05669493580769215, 0.09290676537368979, 0.035999990933175595, 0.033262885840875764, 0.039174581478749, 0.08602708524891309, 0.02451046772434243, 0.029485481392060007, 0.0564394809438714, 0.018894827093130777, 0.03811976147283401, 0.03516478557139635, 0.012525117773163532, 0.033312364614435604, 0.009795777665983354, 0.044126567364271195, 0.02218709427065083, 0.016741401216547405, 0.03338007562394653, 0.03219562828806894, 0.04215937899425626, 0.02013142154152904, 0.024291416264272163, 0.05815889207380159, 0.012818159236173545, 0.030264605834547962, 0.048653169468577416, 0.006508790339077157, 0.00817861667435084, 0.010486365162900515, 0.025329405209049582, 0.020560506731271744, 0.038876680856836696, 0.024049096142074892, 0.00941313904643591, 0.023014677987833108, 0.026650730021564022, 0.09197225980460644, 0.0344553907800998, 0.027103070302733352, 0.035835832956113985, 0.03898459845887763, 0.033323540086192746, 0.04467831811468516, 0.015719563101551363, 0.07430119266999619, 0.0293577166407236, 0.018755511979439428, 0.011935949209146202, 0.02453044379529144, 0.03567485391561474, 0.06252113942589078, 0.051767455214368444, 0.04206845530175737, 0.016670122809175934, 0.02307473003332104, 0.03587046877614089, 0.05941515216337783, 0.03648662607052496, 0.01548299695631223, 0.031358377143208466, 0.04756934887596539, 0.0343763719845031, 0.030593359443758215, 0.0022647210987218258, 0.043299881009651084, 0.04865498115707721, 0.02345997846818396, 0.048012639196323495, 0.03646151348948479, 0.019863023622227565, 0.056234702467918396, 0.08612004454646792, 0.01813917656961296, 0.11293109373322555, 0.03806000967909183, 0.03809192796636905, 0.025606093129941394, 0.021726735401898623, 0.0631715627387166, 0.006721747282426804, 0.014155857946856745, 0.029750408604741096, 0.01955227493973715, 0.03270566949088659, 0.0252499758997666, 0.028496978006192615, 0.03632089728489518, 0.02800450237867023, 0.01146479569641607, 0.03770648954170091, 0.03898372654137867, 0.02050893467717937, 0.04546170375709023, 0.04946274656270232, 0.054270194311227114, 0.042777619391147576, 0.04199583848406162, 0.06656045839190483, 0.08499209542891809, 0.002400757191935554, 0.031662859554801664, 0.030766721748347794, 0.019322974208210195, 0.023621987185574005, 0.03820435104093381, 0.04105862556025386, 0.039740147202142646, 0.038378324027040174, 0.01990627683699131, 0.044134987983852625, 0.04897349228018096, 0.030056217552295754, 0.02334363346121141, 0.0589146443775722, 0.015618892253509589, 0.05162138019555381, 0.038287088208432705, 0.06913123080240828, 0.05647598273519959, 0.05071221451674189, 0.037951681563364606, 0.0682549299672246, 0.030994285430227007, 0.0040694560988673145, 0.020134929567575455, 0.02151679157811616, 0.02253207504483206, 0.0820695636793971, 0.03714914766273328, 0.06731399867151465, 0.06358358277274029, 0.049915166571736336, 0.05088534951210022, 0.040710577807788334, 0.015256829360233886, 0.022899272751861384, 0.015858678047412207, 0.01832498999179474, 0.045171613073242564, 0.048115457607699294, 0.024651428285454, 0.052160374487617185, 0.02605172778878893, 0.034118996866579564, 0.028376029139118533, 0.034912879445723126, 0.024387890373223593, 0.018069840468732373, 0.033298936406416554, 0.019558778697890893, 0.011919823824428022, 0.035211390749152215, 0.0389705595693418, 0.03433862168874059, 0.012468474517975534, 0.040353770168232064, 0.02496224482144628, 0.0338039564500962, 0.028703880296753984, 0.011764457116701772, 0.05054661126009055, 0.07004584851009504, 0.04374460982424872, 0.006203723963283534, 0.026034477732277343, 0.036525879321353774, 0.038477400317788124, 0.029510132569287504, 0.0702625522390008, 0.059795593177633624, 0.024098166098285998, 0.029777668749115298, 0.0762047887380634, 0.049843201147658486, 0.023014920564102273, 0.0384497025183269, 0.06807826658976929, 0.03376186013753925, 0.013993593930665935, 0.05568517391969051, 0.02562044923459845, 0.04659954591521195, 0.035511048776762824, 0.043316661180662255, 0.04294767723019634, 0.029525151941925287, 0.08809462894818612, 0.12724544134523186, 0.038616842656795464, 0.03079730671431337, 0.03446539917162486, 0.011807381241981472, 0.024820369934397082, 0.047732265133942874, 0.012844310823961027, 0.02845104457810521, 0.032408959697932005, 0.03131988724427564, 0.07899590182517256, 0.06855466602636234, 0.00896944584591048, 0.06426874029317073, 0.008724619384988077, 0.04517205072832959, 0.022594349292506064, 0.007765528795841549, 0.003933343246379601, 0.06365467967199427, 0.017359585634299686, 0.028034732810088565, 0.05227431408794863, 0.10080802746649299, 0.08594228872763258, 0.015476452486057366, 0.0103952294282083, 0.02828549051524273, 0.020657041908374855, 0.01877138121718807, 0.02956176908420665, 0.025157520414463112, 0.015272260942895497, 0.045801198575645685, 0.019812428658562045, 0.013733375751014267, 0.02125636305260871, 0.06326981460941689, 0.05585049897698419, 0.019709710331101502, 0.08448005254779543, 0.06061456458909171, 0.08909519668668509, 0.05227673306529011, 0.08479497422065053, 0.021730192537818636, 0.06799555317099605, 0.031191939288484197, 0.017290817806497216, 0.06730517771627222, 0.024864111694374254, 0.028292055341548154, 0.07376303297600575, 0.04885156971535512, 0.024966336387608732, 0.029673978420240537, 0.025571684619145732, 0.01918809162452817, 0.03149478643068245, 0.020682354657245532, 0.00821431609801948, 0.036897940428129265, 0.05790920475763934, 0.04269224272242614, 0.03479356584804399, 0.03330324849646006, 0.050288153878812275, 0.016535533691889474, 0.020844845134498816, 0.06915508809366397, 0.0610350730961987, 0.03712662708546434, 0.027792200645697967, 0.016889869767640318, 0.02400051473107721, 0.02801061258651316, 0.0856163137193237, 0.019022871740162373, 0.08306767512112856, 0.028238062613776753, 0.013212533967037286, 0.05656257398160441, 0.0508219505926328, 0.025655537976750305, 0.01505011536314019, 0.05007970452840839, 0.015141079767740198, 0.056156633621347804, 0.05049129708537033, 0.09846747520246676, 0.022613482283694402, 0.018157254438847303, 0.02791331914652671, 0.046204591036907265, 0.012057582548420345, 0.05499801811363016, 0.00905537127982825, 0.013672511159841503, 0.03828848259789603, 0.022163888373013054, 0.04373932742912855, 0.03293593374214002, 0.034725427361471314, 0.0740955083497933, 0.03281371262190597, 0.059438378417066166, 0.022814298115138496, 0.018445514774482166, 0.02681079473612564, 0.10816020545150552, 0.041498492671442885, 0.09059444016643933, 0.09627289617700235, 0.12159186042845249, 0.10472314738269363, 0.17597512581518718, 0.09810342759426151, 0.13722945989242621, 0.1631819044372865, 0.13901180853801115, 0.11821293245468821, 0.08467064624918358, 0.11810937444014208, 0.1124038313116346, 0.15298675293368952, 0.08008997168924127, 0.09506441173808915, 0.21094460865216597, 0.14736488674368176, 0.2022369144750493, 0.07257359501506601, 0.09883346342082534, 0.14379980947290147, 0.0653009277635387, 0.15349874831736088, 0.1789542609559638, 0.1997884480016572, 0.11031959565090281, 0.1097776565168585, 0.1001513684168458, 0.17075527805302823, 0.09019420628568955, 0.14942243562213012, 0.08912170026451349, 0.24115853809884616, 0.15432866449866975, 0.1653201582708529, 0.08188621673200812, 0.08617415771420513, 0.1274577278111662, 0.11931808958096163, 0.10774913536650793, 0.1630780342966318, 0.13949526473879814, 0.08855363753225122, 0.1107923174276948, 0.30785663053393364, 0.1211051879716771, 0.08208565853003945, 0.11451887924756322, 0.1501958705484867, 0.13075094324137482, 0.13637066526072367, 0.201523163488933, 0.13014604284295014, 0.16043884520019802, 0.0823078787486468, 0.14198007354778902, 0.12980514684958117, 0.13036739453673363, 0.08840257528104953, 0.14119644702545234, 0.15762848885996, 0.12258835695683956, 0.19266141472118242, 0.17089197571788514, 0.08292373748762266, 0.10982015316507646, 0.11866312686886106, 0.12431782058307103, 0.07682578398713044, 0.14568357196237358, 0.16631400851266726, 0.10572085170341389, 0.14632055349648, 0.1315813208264964, 0.11682236992887088, 0.15013945714703628, 0.10210067738911935, 0.1958824475961072, 0.06646779086440802, 0.13138127513229847, 0.06073700623320682, 0.12678528603698525, 0.09686721821448632, 0.21939262747764587, 0.05797580975506987, 0.167802863621286, 0.11404401330011231, 0.19669393476630959, 0.3128912518067019, 0.08120950018720967, 0.1453846094331571, 0.11121763674808399, 0.08957217966339417, 0.16481000850243227, 0.13590231324945176, 0.11735789690698896, 0.15768726356327534, 0.1241905681256737, 0.09147017103220735, 0.08947434169905526, 0.1676771039409297, 0.17862789918269428, 0.16948409697839192, 0.10655105965478079, 0.15536234474607877, 0.10161233573619809, 0.15655031028602803, 0.11496612881975514, 0.15346152388623782, 0.10729142278432846, 0.18880093044468335, 0.13808119775993483, 0.10977746652705328, 0.13717206940054893, 0.16879889874586038, 0.12882253314767564, 0.14513493568769523, 0.14670889265835285, 0.06705791277012654, 0.1257211531379393, 0.10531461278774909, 0.08252137979226452, 0.13951659787978443, 0.10579000799251453, 0.0855517511122993, 0.22215482140226023, 0.10923816689423152, 0.10149104760161468, 0.13026336154767446, 0.1455419345625809, 0.17010767066052981, 0.12927135692111083, 0.1263836340180465, 0.1462014570300068, 0.08544082420745067, 0.11895013361104897, 0.15224693263215677, 0.09234949813357421, 0.09825024221624647, 0.14174672535487584, 0.09323614662779228, 0.095699554442295, 0.11409980244934559, 0.08694277504192931, 0.07927796204707452, 0.22332678708646977, 0.15776229596563748, 0.1979119729782854, 0.1409136743417808, 0.20213596203497478, 0.12954978698066302, 0.11013607906975917, 0.10872338951698371, 0.152187886514834, 0.09644242815141167, 0.11142153652118784, 0.1641645859926939, 0.12818149397415773, 0.07908188578273569, 0.09745015443435737, 0.11645973367350441, 0.09991071918713194, 0.1000716405521546, 0.16647431919617312, 0.10220942619655814, 0.136851841583848, 0.05702908377030066, 0.14475844374724797, 0.10823706311306783, 0.13774004392325878, 0.16613180828945978, 0.15474434862179415, 0.13518257758447103, 0.16076108148055418, 0.1058778782774295], [0.03285043154444013, 0.009325013462720173, 0.0795024282165936, 0.031761433729635816, 0.04439834778064063, 0.08714534488639661, 0.043619857768395116, 0.03731979921992336, 0.07065256738236972, 0.05616014164739421, 0.03802366055814283, 0.0591728880203196, 0.021006202458270958, 0.016603607717635374, 0.04766073736495205, 0.05848405284008809, 0.031310129910707474, 0.026686083392373154, 0.017035038942205052, 0.015422047548262137, 0.07873026893607207, 0.03766086145437189, 0.012003361663248922, 0.020302617623071586, 0.013697376075599874, 0.020337969297543168, 0.015363064195428575, 0.006054224463046661, 0.054269692195313315, 0.06770614441484213, 0.025792291620746255, 0.07178107968398503, 0.07082514597901277, 0.007812745503282972, 0.012737736721257014, 0.023678118994991695, 0.01831837427536292, 0.10513420389699084, 0.06184363578047071, 0.04927674315071531, 0.0063861739721947485, 0.07196038256266288, 0.008128759617518102, 0.0729682445526123, 0.03154228048931275, 0.048085059238863845, 0.05035760872332113, 0.03424574720806309, 0.05195707521800484, 0.013156493759847112, 0.019132685847580433, 0.022688621555321982, 0.0069273616287059015, 0.0388087018259934, 0.032693031776164255, 0.025364707689732313, 0.03505580945472632, 0.025819789252376983, 0.002228385548473203, 0.025344319408759475, 0.025896819940369045, 0.06865165582192795, 0.031883888944451294, 0.07248191136334624, 0.03511998190411499, 0.010439848194697073, 0.019767205995906676, 0.06336495878973178, 0.03187737840094736, 0.025819802823077356, 0.07035827995943171, 0.039806857372501066, 0.010646102484315634, 0.013545908399724534, 0.04338480305991002, 0.05218058804582272, 0.021286345818745236, 0.017506273030968647, 0.006527583638671786, 0.05879150384238788, 0.07755722438118287, 0.045388489828578064, 0.05724930909595319, 0.0014946307138805942, 0.039107603287058215, 0.010895622711229538, 0.03534599852615169, 0.06267692428082228, 0.030133743570851426, 0.04407355681593929, 0.08337773848325014, 0.034137256243931394, 0.03407390142924019, 0.011459880558374737, 0.02623107477224299, 0.02788329736462661, 0.04188306596396225, 0.045060319759483845, 0.08434062038681336, 0.05675481652308788, 0.03585075394117406, 0.02721410577318498, 0.03445059014484286, 0.02512137994303235, 0.02794167342861848, 0.0055439466211412635, 0.021197914046102335, 0.026577032636851072, 0.015251960871475083, 0.025814718899450133, 0.04555277333461812, 0.044104179101330895, 0.048816747298198085, 0.034399672877043486, 0.01842912476110671, 0.023248960862734487, 0.05309299372934869, 0.1062789060441511, 0.027804804433669363, 0.04311072580250246, 0.008487346715160778, 0.0252616229533617, 0.044331624039581845, 0.005842450291051396, 0.012180237082897552, 0.020482856880075166, 0.007672303173291896, 0.03833631253136056, 0.018988410642902766, 0.02549254029457058, 0.05667648304786001, 0.03971527550103409, 0.051366386735545735, 0.11512382035808903, 0.02306875553248184, 0.030914778089416877, 0.02273089937599642, 0.04954081540927291, 0.05656401247584394, 0.030151555115090947, 0.03949610869001065, 0.06379928905516863, 0.055058217740484645, 0.030952681055558578, 0.01728243281000427, 0.06481599235641104, 0.06056959807340588, 0.026655959830220257, 0.01281394892638283, 0.04409827584666865, 0.08320366710956607, 0.07824686023273639, 0.03409818619755762, 0.018235917003559213, 0.017970794712060263, 0.06782047756548439, 0.04649241202111755, 0.02213486234125282, 0.07967891517494406, 0.035782944544085434, 0.06902540648089987, 0.025549540628812144, 0.04400091285684279, 0.01987381572169917, 0.0639460493943521, 0.03772564797795244, 0.03371936688199639, 0.029762869900358573, 0.0542789406276175, 0.056841682576175244, 0.013488137080068035, 0.07070746765072856, 0.07282235952360289, 0.03999327469084944, 0.05811023432761431, 0.012041312126841928, 0.057589913319264135, 0.006528002634045801, 0.07706653499709708, 0.009166198948930417, 0.024433835675673823, 0.044857159589550326, 0.034844629000872374, 0.05845696572214365, 0.06457241864076682, 0.08166394223059927, 0.031460520412240706, 0.046259101147630384, 0.008613155589305928, 0.028319288344521607, 0.027722628753898398, 0.047995319589972496, 0.03795602758015905, 0.05150565604812332, 0.031809026175843816, 0.02058374655566045, 0.13544667698442936, 0.06082530399518354, 0.01700537508752729, 0.03890407670821462, 0.04362437681161931, 0.04611788443954928, 0.02094480860978365, 0.01726496053327407, 0.06507577627365078, 0.01807628315873444, 0.04332237783819437, 0.009468757713745748, 0.050161858155791245, 0.021706036691154753, 0.05002253795308726, 0.05446964967995882, 0.005517608860308039, 0.04399745911359787, 0.014057247300765343, 0.028182246323142732, 0.03842452886913504, 0.06344218964555434, 0.03763202032340424, 0.046945619130773206, 0.04427975003740617, 0.013517498138493724, 0.06291069995079722, 0.013884389656595886, 0.031131743054304804, 0.029029678885958025, 0.03890115561495934, 0.01618383202834853, 0.021143113861658742, 0.01177970295040203, 0.020149438342611705, 0.031238303586308445, 0.020931349867688756, 0.03953753664557423, 0.015903120394796133, 0.02257031388580799, 0.03860258663605366, 0.041728146241179535, 0.03708438488787838, 0.046986059817884646, 0.017484067972483378, 0.028639901229845624, 0.018804201956040094, 0.04975870657446129, 0.03965081128158739, 0.018481426240344132, 0.03957341079201017, 0.04579929528491838, 0.0997561149831329, 0.035892202252788205, 0.05082219825791461, 0.028041762432881763, 0.06682009981679064, 0.04397256366376366, 0.010862952098250389, 0.049413983643587144, 0.02629760852349656, 0.0806808942662818, 0.04177243761452181, 0.01058764329978398, 0.02991664289895977, 0.032875286282173226, 0.010173144916604673, 0.00759031409065106, 0.024686209990509918, 0.029227539697395902, 0.052404694591781924, 0.026850120929468955, 0.05934526305645704, 0.07736857807529823, 0.05638078087940812, 0.04581226548179984, 0.07860163226723671, 0.06705278304538556, 0.03685286195416536, 0.007324588751154286, 0.05867896880954504, 0.04011075963665332, 0.03896024583705834, 0.05692943411746195, 0.027815314941108227, 0.04090405189033065, 0.022780001562620913, 0.006489524609475795, 0.01648002952736403, 0.011272038316487201, 0.023419768482978855, 0.04609198136521237, 0.021769276154892783, 0.026227254620087997, 0.04030592666406717, 0.06000217316406114, 0.04159352828615478, 0.02083466710921909, 0.02006787504069507, 0.0710036481863686, 0.04512510967573949, 0.013279770850203931, 0.05890469705419881, 0.02750146365724504, 0.010318884060585072, 0.027159376834918345, 0.023960445541888475, 0.0424231255560049, 0.023503693086760383, 0.030058052989521196, 0.02211896256942834, 0.07682950235903263, 0.0051300411079345, 0.1292692670332534, 0.0019465462745366885, 0.05066786886059812, 0.017847791580217223, 0.023592596441241245, 0.05125265069571989, 0.023377124253394346, 0.002772325724695942, 0.024804193659552505, 0.07169035276664154, 0.07873385838632073, 0.03583202637465937, 0.0426750927498298, 0.01301639069736536, 0.04618477102901254, 0.050543384826076884, 0.04504526646009513, 0.01704522714551006, 0.025905654466311847, 0.04864180739969015, 0.024623508265774165, 0.0601661072245666, 0.02511734944502158, 0.014579461421817541, 0.016146717859166007, 0.039322498720139265, 0.052201120515487025, 0.040670846189771376, 0.04871933002557073, 0.010365857343588556, 0.023709053406491876, 0.034446030389517546, 0.010381166789946812, 0.02513315761461854, 0.04386052056880934, 0.028968108618365865, 0.023645834298804402, 0.03355754306539893, 0.026208274299278855, 0.07318594572799546, 0.018699151164452945, 0.03705277194135955, 0.02360799240081438, 0.10535620019904204, 0.09795640262642077, 0.18134381701903685, 0.07379710221929209, 0.08119450456329755, 0.2661196158400604, 0.1781912754688944, 0.15164182867322648, 0.13958119441355976, 0.1619681002838271, 0.20177069306373596, 0.14987714907952718, 0.09588973423732178, 0.08299515329833541, 0.17254872753151826, 0.16574545044984135, 0.2031382939645222, 0.11083505156316928, 0.14351551687078817, 0.09898080730012485, 0.2301484660378524, 0.10326853793646608, 0.07559811057788984, 0.17102019169500896, 0.18085225911012717, 0.10727959591895342, 0.05182086270568626, 0.11994912714830466, 0.1442927923053503, 0.1805287336132356, 0.0804981105029583, 0.14820378672863754, 0.10141616447695664, 0.11977919483823435, 0.12084980096135821, 0.10342675873211452, 0.1567198219043868, 0.13494454749992915, 0.16781682787196978, 0.13010561572653906, 0.20952853320964746, 0.12750164259757313, 0.11751197863902364, 0.18361454802964414, 0.08942151774785348, 0.16976300201245717, 0.18291801826230117, 0.12094713002443314, 0.13493922778538295, 0.1040843270186867, 0.10644997829305274, 0.11106631665357522, 0.09737662159438644, 0.13520887760179384, 0.12598746456205845, 0.1101976561227015, 0.13064220121928624, 0.15767571489725793, 0.0775454585839595, 0.07862928256924663, 0.08793814520218543, 0.1846739583249603, 0.09484979111169066, 0.19306453237576143, 0.07772902266255446, 0.1863470764032432, 0.08885242364236287, 0.13870405219495296, 0.13904851728252002, 0.11375476739236287, 0.15554181725851127, 0.1504888076867376, 0.1464521757193974, 0.1236609308315175, 0.1311959536480052, 0.16663019226065703, 0.15486370293157442, 0.11641820733036314, 0.17250318426106656, 0.12238957333777632, 0.13182643481663295, 0.15124681272677012, 0.17756196138049873, 0.17991347877042635, 0.1173564719834498, 0.06255721034748213, 0.060955840562071116, 0.14525469711848668, 0.1274455413222313, 0.08997719721602541, 0.22498805794332707, 0.06528901947396142, 0.0846250554812806, 0.11700102819928102, 0.14563511099134172, 0.15651978978088923, 0.16959393822721072, 0.1206054197890418, 0.12439050525426865, 0.10370140256626265, 0.12025269014494759, 0.11687359932277884, 0.13289782804037842, 0.10677967167326383, 0.12065430145178523, 0.11589549109339714, 0.09102722337203366, 0.07032654487660953, 0.0555540470273367, 0.13425117970577308, 0.09794406007443156, 0.1355444538806166, 0.16459183235253605, 0.22213899796562536, 0.13136575025107178, 0.11024074309638568, 0.0980513703876308, 0.15245529716568335, 0.11417516054851667, 0.19778081215918064, 0.1482176695551191, 0.10046251743499722, 0.16525029630533286, 0.13312027896089212, 0.060071926563978195, 0.11436027847230434, 0.13783436029085092, 0.11110454531652586, 0.09904404676386289, 0.13913967167692526, 0.10974691209516355, 0.11196101935846464, 0.07320537218557936, 0.1735499602343355, 0.07853706966021232, 0.13517809925334795, 0.08253170709524836, 0.10329612038497414, 0.16862184181809425, 0.09542579270367112, 0.10925601915057216, 0.1505726474736418, 0.14668523892760277, 0.2141551785171032, 0.18165054198886665, 0.1495098037911313, 0.1933058194283928, 0.19905701439295495, 0.08754739045564618, 0.11527916416525841, 0.13228098542562552, 0.18985766731202602, 0.11019566122974668, 0.07309035371456828, 0.14768820868006774, 0.10176842593188797, 0.15982395676629885, 0.0656915060909731, 0.16484153323939868, 0.10687399482620613, 0.11296693395291056, 0.13947250667427266, 0.08768063437725816, 0.15159981378487178, 0.1123667358021651, 0.07434988434293441, 0.1161848862788507, 0.13690221602363245, 0.1190616711974144, 0.16795960521059378, 0.11983146917607103, 0.10021954761551959, 0.17153524048626423, 0.1403698149536337, 0.19635176312710556, 0.1089302341320685], [0.02925909496843815, 0.040482647716999054, 0.10295988592718329, 0.026657586617927467, 0.06403161266020366, 0.017311923638252274, 0.06942072776811463, 0.03982604295015335, 0.07177231301154409, 0.06740215394113745, 0.07373481948993035, 0.011357574440938021, 0.02442200541762369, 0.025137267840494002, 0.06780303243015494, 0.0636656651539462, 0.03809607720800808, 0.07939042244106531, 0.06202229405088084, 0.010094179555640688, 0.037856235434966426, 0.03374730556138924, 0.02218147091168378, 0.05328133130179984, 0.08135303069970437, 0.01489037464904998, 0.007226096848691148, 0.018293980941442505, 0.0483155643700489, 0.0717895749424185, 0.12814325174050673, 0.03041221434250474, 0.024860371270083954, 0.029002679977566004, 0.027586852200329304, 0.008323551754334142, 0.013003791998406606, 0.011693625694273837, 0.012209706706926227, 0.038898356658007414, 0.011720478717636849, 0.020689837202163677, 0.05665112280153802, 0.06521800399890967, 0.027630948494853716, 0.0684573505339878, 0.04057754423203213, 0.04956466930785349, 0.017879260338044593, 0.07292906594063554, 0.018644239021731273, 0.004728043884305018, 0.027401958193097795, 0.021314181021547744, 0.06144502359841551, 0.0243492817306625, 0.03431472707805889, 0.015633058368361423, 0.05332699670855488, 0.03427538901035275, 0.037162165357066054, 0.036351166732077084, 0.023041308790977513, 0.05262974090874195, 0.047298569298748455, 0.031975128155733855, 0.029853023455611298, 0.04083147917741111, 0.04240766852828009, 0.05447261827066541, 0.02644981749887977, 0.07901657000184059, 0.09117941199136631, 0.03559165534430316, 0.04178747734321015, 0.026378026797569225, 0.053415837298546515, 0.04489976480337126, 0.028813538341117755, 0.017558881547302008, 0.05994335774864469, 0.07320367584803275, 0.030961790388183932, 0.0295121919230691, 0.03917904284649661, 0.03861102761168565, 0.020602416446698562, 0.04697311676240393, 0.026329389407432506, 0.007307484579671706, 0.050698752381971905, 0.019999390501262884, 0.052126831108970303, 0.04178247993279781, 0.03556849015876651, 0.0383047606529934, 0.016020342408280288, 0.007988408889754542, 0.040854159210409434, 0.020446631591767073, 0.023232114534558992, 0.015414546343630977, 0.014010216342285275, 0.03323055025456207, 0.018857943625854592, 0.04248672125062772, 0.05731927284172603, 0.002394480743013056, 0.058276468621832986, 0.030638648263577904, 0.03504043045852866, 0.038801003846206834, 0.052642354874738624, 0.03469005533094917, 0.008884908864274621, 0.016269848216325045, 0.019050963089934418, 0.05204183102718421, 0.033246146381965706, 0.043516401534101794, 0.09248207030551774, 0.11142328035618577, 0.03111362616930689, 0.034243949090263674, 0.025627685810572336, 0.024094870114432912, 0.03576690736891968, 0.0152337795256504, 0.034718187392822335, 0.044894163496792316, 0.0695693947907005, 0.036331974369074614, 0.10426258495343582, 0.03145449162860002, 0.03376693557947874, 0.014244814735970326, 0.05834058339574507, 0.03958380934117096, 0.0557791069149971, 0.06798405200242996, 0.02367944553095315, 0.08259411874626364, 0.02293705358169973, 0.031624176273388524, 0.09523494794432606, 0.054611853656492064, 0.01158160125903253, 0.03858736031023519, 0.08041258794920784, 0.039021212208483896, 0.06099304463714361, 0.04246994447229164, 0.006909656529647431, 0.025745742422129427, 0.02069423919809716, 0.04529613442718983, 0.027456554817035794, 0.05691257591492363, 0.05277885915711522, 0.05587399325200489, 0.038783908156411986, 0.05121789273938962, 0.10988591677908387, 0.0374588412232697, 0.019591777552185313, 0.0272443684350167, 0.0243048512576414, 0.050728628278842995, 0.06722713940377746, 0.08075334823557309, 0.008125679916702211, 0.025991585837411027, 0.044211743865162134, 0.01125490021825369, 0.06866331305354834, 0.03252006641456059, 0.0241857683618686, 0.024421555888173834, 0.006291004770901054, 0.03759621063779507, 0.034908852340387445, 0.0324462146631309, 0.014087195291982164, 0.02765153524731951, 0.02799855332289423, 0.0021955469980769393, 0.03798091624464307, 0.007138919517663973, 0.05291366031659501, 0.02113342607792999, 0.04409148371113198, 0.05704882913934333, 0.03174626847196903, 0.06304393708705902, 0.036355275261615, 0.01178090226104749, 0.017252166755497456, 0.022597005757104074, 0.09885330378477063, 0.02564172978912081, 0.08150528038718871, 0.03796731161751917, 0.052650307305157185, 0.020417335842336928, 0.021175630956089923, 0.04031304788908788, 0.056512562558054924, 0.0321307331988854, 0.05002786106030856, 0.04476686354194369, 0.012570413378333407, 0.027766002408627952, 0.021086150846843208, 0.036687160309936316, 0.050058612267353704, 0.02583061358226197, 0.025696419711623873, 0.03309424953269107, 0.01600500412418374, 0.04777826641553214, 0.010083741142547556, 0.028890694558088268, 0.0160882094808455, 0.021478739334270358, 0.03591758624783584, 0.017822712925927978, 0.043601520359516144, 0.03334313278485622, 0.01452538387716881, 0.03470952928598438, 0.025651080001677786, 0.038771189017487426, 0.02960949045206819, 0.031216356371130263, 0.06592241155781917, 0.0843796090089849, 0.02154487444620047, 0.02984799211844802, 0.06923818827739783, 0.018095796129533222, 0.08828362130693027, 0.010180767409370413, 0.0341977985309703, 0.06888334838939564, 0.05561618387166943, 0.04455272467540843, 0.021596892637067606, 0.06873407747064318, 0.045113320129790475, 0.017833949465836798, 0.02613577283253627, 0.015725527424365282, 0.07347378028290612, 0.02662825694174639, 0.07192314456083945, 0.031150131353310177, 0.012382068172363299, 0.058278877421149185, 0.045220213143953254, 0.020768995097439204, 0.023230899956875613, 0.03457364247047475, 0.021656444262979285, 0.07505030890128442, 0.01179734994989953, 0.015169310217191066, 0.053689381905964444, 0.04048646447647895, 0.0231575096092586, 0.018040273305294768, 0.007214816204006118, 0.03650483795042549, 0.021525380135114704, 0.0041567411473287, 0.02680009084620646, 0.03350376577249595, 0.022168125824204514, 0.01593988172576896, 0.0325162937598569, 0.033917281976235766, 0.014190782992435353, 0.03639318501310689, 0.0499222097652299, 0.009695118692304407, 0.026795313959675174, 0.061233273175145896, 0.02137190060290907, 0.024861672360982214, 0.01988776640168258, 0.037106644229165146, 0.021829664075214947, 0.05297009746677109, 0.00895236203047846, 0.03284856557313885, 0.024026000506377647, 0.018475409331066266, 0.02390902446183775, 0.04003766784444451, 0.0249863328146083, 0.026726559702573077, 0.03268075029232672, 0.020156954814280783, 0.025484190921166112, 0.024357627711391876, 0.01689815298388047, 0.017540118357698833, 0.08971756257648979, 0.040304515311228375, 0.07361346350184508, 0.03341400237487895, 0.04748742934316397, 0.04403536547241466, 0.0753448609528797, 0.05708696959274156, 0.023259836082745875, 0.10429825553936617, 0.019932400435209274, 0.013444562409339207, 0.01320196663229061, 0.019758113626656786, 0.04631871384169374, 0.0032825070874033762, 0.022347890106695037, 0.05268036301380821, 0.017410784494131804, 0.033401303592004945, 0.03876982855477503, 0.07500474527478218, 0.022509595179664235, 0.04836916524384703, 0.026250211156106422, 0.05003438517451286, 0.056059185814644606, 0.03453111868085606, 0.07201159160052027, 0.03380704717710614, 0.01278647334714021, 0.05966749933681317, 0.06368523410388402, 0.029056972957083156, 0.02344624831208161, 0.0448286034432905, 0.01057304292252021, 0.055255600184734376, 0.07989247050136328, 0.10374180254127298, 0.013195696968718298, 0.025355645854558264, 0.053274824150971005, 0.009683983932648386, 0.03316464075552566, 0.06984820482986313, 0.09737059620342084, 0.1520203155066286, 0.13781563272433622, 0.0978414723649621, 0.20802895724773407, 0.09298827778548002, 0.1588691630001579, 0.10871939294572387, 0.12518481191779884, 0.2010110052568572, 0.11820739560893603, 0.18937034346163273, 0.16854283320052282, 0.08557643621627774, 0.16552534726049217, 0.10963696228074175, 0.1368965706122773, 0.20248714461922646, 0.18665800829018864, 0.059837743772992065, 0.06934007709579808, 0.15433530057115213, 0.1624873017093965, 0.1305014866271189, 0.1648358471159424, 0.10978143595691238, 0.12964609824120998, 0.09908524741019521, 0.07207128232611076, 0.16250860770898207, 0.17164190619119576, 0.11070046414222036, 0.08211529693965401, 0.12983359103756292, 0.0860810966363975, 0.12563586128609522, 0.11160261037626437, 0.16618014712418827, 0.10467735983963523, 0.10499118907111031, 0.10537046300513403, 0.10215332492121629, 0.10552276019006968, 0.13903103822043963, 0.10678467926170145, 0.15358602149145945, 0.07090965751558542, 0.1334698602024998, 0.07777603156864643, 0.11899028931345258, 0.09480617488069193, 0.10614547213273388, 0.12213586909430367, 0.14178089637841496, 0.13490657668028558, 0.07017724681645632, 0.10379951872995921, 0.09089760961277144, 0.10490914740200553, 0.20751312135585717, 0.11666489552174296, 0.1063593327999115, 0.14672151340969972, 0.11013810110411473, 0.10796311816998891, 0.10148025889481817, 0.1107312628467168, 0.15408374049833842, 0.2425610428409917, 0.17583517118224076, 0.14000879361161164, 0.1709990349731275, 0.19537014008632728, 0.10740392389042036, 0.13454809305923326, 0.18101609817573003, 0.2002110667526722, 0.09441148463104453, 0.1934367088334901, 0.11291544671569552, 0.11283202762050287, 0.1745452761117901, 0.10926690285227128, 0.06868256309202739, 0.1826393167887415, 0.11321966789130654, 0.1294379915509905, 0.17193588827337536, 0.11557936162820884, 0.16947925223835877, 0.13466713524290494, 0.09523881559393235, 0.11128778369831187, 0.08827532282365219, 0.09566994995943137, 0.1274963907365288, 0.09988773720605032, 0.09191723739994423, 0.09875906884138073, 0.0744290558089103, 0.1444733776152134, 0.13504396645086153, 0.1312736730490412, 0.13492904976010323, 0.11237387399056128, 0.21589053182729653, 0.09611873302076544, 0.10062403591083628, 0.16194047033786774, 0.15566037089696952, 0.11439442235444273, 0.14508903957903385, 0.1338173108441489, 0.1134271231879081, 0.10524654894002847, 0.10311762496296849, 0.22248802280851773, 0.14255076221057347, 0.1387771304164614, 0.11598564125597477, 0.16907320331249917, 0.18028893933764525, 0.059621725364455154, 0.10621686758739607, 0.11513425622667585, 0.1182785467909915, 0.09292455656187874, 0.11374659104538815, 0.08489828796258994, 0.11083075643650123, 0.1893846741212266, 0.09291758800723723, 0.22650425801319735, 0.10570436330246073, 0.07221596634813718, 0.09354848986757652, 0.15816748993737356, 0.14459721025611671, 0.13469103324626172, 0.19567537227911608, 0.1162547618150711, 0.1106097304395267, 0.13878618207361015, 0.1057920368122203, 0.1990069385085787, 0.08419643169535057, 0.08733400476298162, 0.11143106993819986, 0.1258908954582044, 0.11209937264876706, 0.15134507816817078, 0.11810077061610562, 0.09791398061705486, 0.079992011588599, 0.07713803223201207, 0.11941341018038136, 0.10529842294220414, 0.10625770861016852, 0.21165614761412144, 0.14307241993291037, 0.08190466609916516, 0.09390490395682198, 0.15579677000641823, 0.10323294198938779, 0.13498931724045957, 0.15115910529025964, 0.12459321080573968, 0.18498263747564384, 0.20657975572560514, 0.1919688611690487, 0.08844834246805736, 0.13524817835007394, 0.12396640729691301, 0.15133650148553507, 0.1198854534221547, 0.15820909770471708], [0.05695822435830321, 0.03455947805196047, 0.05573647116710033, 0.012798792998572546, 0.04766569406326328, 0.013989533746748098, 0.010766761277669241, 0.0721179044672421, 0.04315620121945228, 0.07710262627473899, 0.006682421089083488, 0.04568008007481694, 0.02070043931183006, 0.03133913728275469, 0.0355318458750844, 0.01349673666326063, 0.04524936300835439, 0.055111252037542205, 0.032325370968984704, 0.017725456805367554, 0.021560511285705224, 0.008286218757608106, 0.05495613553960409, 0.006607325074063348, 0.02364295391765024, 0.020826054803494896, 0.06582206979926143, 0.0398591011762619, 0.028298304649069905, 0.02700731035188905, 0.026655644311436584, 0.023993875265919735, 0.034468120097049644, 0.07011915064815964, 0.0723206235894135, 0.057107257789799144, 0.03726512286812067, 0.022220934508368373, 0.029357869311102798, 0.045075491802500825, 0.04254947556182742, 0.018614156171679497, 0.07283158081450633, 0.028922955505549908, 0.008447761830341603, 0.0182768394505339, 0.0263039884490094, 0.025394697241219025, 0.0331530242360064, 0.08153683905090604, 0.0787738783817206, 0.050160630007407496, 0.035946379881352186, 0.058815340777593, 0.01553328997189445, 0.021896153721692305, 0.05393244332766958, 0.05396145748506699, 0.03648625287626471, 0.08200428861060313, 0.03735293547755905, 0.02998624023582254, 0.03540354508108326, 0.03594430695687022, 0.027337018999138048, 0.021129322637404715, 0.026422793145424554, 0.05578442323686821, 0.022034318718527044, 0.024039700128404156, 0.051458036460514577, 0.04799433232152036, 0.03575517549844725, 0.01519792403892747, 0.0222226274532399, 0.022633268364838192, 0.08336594554462604, 0.06893020123243332, 0.01911682339518198, 0.023771049454808235, 0.0447345245629549, 0.01846981141716242, 0.05603701129023518, 0.04622488262663994, 0.03979367682976382, 0.039130317246807475, 0.02417737658002547, 0.019708241302786127, 0.04153847195474165, 0.027858625831348554, 0.07269828261009284, 0.026266287347035747, 0.03944424147318516, 0.0036206208751536906, 0.027922041714191437, 0.017530817338930707, 0.0031334865904812303, 0.015523573350427406, 0.01095650511394654, 0.04049200132223112, 0.07148939105016844, 0.024170530161687305, 0.04535932300080146, 0.03431452691022839, 0.042078202457300255, 0.029379297446991717, 0.01811599442070084, 0.008551922892885548, 0.05992703219609601, 0.01120232732500881, 0.05629193689674139, 0.056964636514229436, 0.03161616956016847, 0.033526154035436254, 0.011626807806481208, 0.042335357051342726, 0.027619062257664542, 0.01725820402082588, 0.020112844949055995, 0.03322216695440667, 0.019071476899885705, 0.05343490752524563, 0.008864943819519664, 0.02077914767765573, 0.02089902785207544, 0.04416516922148211, 0.037069318017789295, 0.018080206787479774, 0.06965996564498969, 0.05117077866036977, 0.031189455850315944, 0.04195904153000031, 0.029317245419536318, 0.041795959030943255, 0.02806243230588734, 0.037895349586116414, 0.022803438162165027, 0.020314782059618404, 0.010458963374341173, 0.013338375919764596, 0.057431332900055816, 0.021890547326100723, 0.02847140741401485, 0.03299694761101689, 0.038435551670512984, 0.03454066566856844, 0.027776322926261594, 0.027667993114196827, 0.06688021123409271, 0.02430247638507613, 0.039266020857862065, 0.022720570376675044, 0.010639256065977471, 0.05570341633366687, 0.06126948658909116, 0.0430423803627491, 0.07774091738143138, 0.04105253231578639, 0.11572602018713951, 0.02923936995544604, 0.016864136327058077, 0.01838554415319647, 0.02908337814733386, 0.0468741829640099, 0.029099741019308567, 0.08555363065430097, 0.03876965892102037, 0.04832368304154702, 0.014803656177329165, 0.03394963113324983, 0.024104247468390634, 0.0362076769316835, 0.0931935210579208, 0.024880634022078345, 0.08157587517052889, 0.03061810222321323, 0.09547991265675851, 0.023078176991215775, 0.06004122963973454, 0.07946474916700806, 0.03511547643159117, 0.05090366317225354, 0.032771578989923, 0.04969538229384592, 0.049729214049875736, 0.05056555595781122, 0.024861957345690047, 0.053853709516780715, 0.11113402766308614, 0.03137752200875964, 0.019521281156422834, 0.05508594268134662, 0.0266942427759724, 0.034963498158114295, 0.0467000267734485, 0.02852936108995761, 0.028573129991335527, 0.038900361728987524, 0.030239873233118227, 0.07322217949799129, 0.004217970875158373, 0.037185866585267444, 0.038846984771745544, 0.03600707144609519, 0.03690195057008948, 0.008609734924643167, 0.07240691967308521, 0.016654623373012458, 0.046841206162103584, 0.04590359290263482, 0.019312063365110328, 0.019510748596595864, 0.07155344475592886, 0.02265626222028264, 0.019414990342089107, 0.022921913769096136, 0.07999068844531264, 0.030419661264334406, 0.07381073398781673, 0.0246524070722184, 0.0034643048545279142, 0.019158283581158946, 0.03020777174138597, 0.023828409412609677, 0.019894064902993183, 0.03405510600922363, 0.02485589124262333, 0.022670560649463108, 0.05766866409352847, 0.030440600855009894, 0.07946069152759654, 0.062470798912857256, 0.02885852860552924, 0.08000643045774528, 0.019371891494042108, 0.0761517747970564, 0.03241971108530249, 0.023646801211205975, 0.02682739170268178, 0.027445643973935927, 0.012034118807475482, 0.018903927944068397, 0.03448871363486562, 0.0025233597760753973, 0.017012155348701135, 0.06967283745429345, 0.04076357478541987, 0.03799757767202599, 0.044380726226206334, 0.06004943312811, 0.03252929109813912, 0.06629563295947653, 0.009406354544418198, 0.05940852966159582, 0.030520098017794744, 0.04558929208932178, 0.03252299090049096, 0.05192912296791162, 0.027524569470967566, 0.03909204447908061, 0.04409116479967322, 0.04750641475298575, 0.019559962741498436, 0.07326547681753125, 0.042284246401063035, 0.07889609610927956, 0.012100536359607108, 0.011558877121257995, 0.04572882603055664, 0.024784405882071172, 0.02306368857223008, 0.07049058071736779, 0.027914811923567737, 0.017882993976984705, 0.010626297743458833, 0.028036948226924454, 0.029153413139283657, 0.10971302605633225, 0.05118697529126491, 0.1002016207203269, 0.046940207813999484, 0.09195319975593261, 0.020134317189721123, 0.01622415566816926, 0.03957799768873623, 0.0550606502885265, 0.0070867359338860425, 0.053972582066697736, 0.026061142462172678, 0.04655628252242293, 0.009132623339870145, 0.07670342376721756, 0.027784794435969422, 0.07463788174624954, 0.052405390090176036, 0.01217639827102955, 0.04415631094681365, 0.05406651506200433, 0.04910348941172872, 0.04032384677390967, 0.012993783606881542, 0.011309482423322541, 0.03601513244211674, 0.04128213838807174, 0.12819255409496172, 0.06366071184831006, 0.08231312382434096, 0.007541628354894263, 0.03365075681358576, 0.03287688423214214, 0.018829424799020802, 0.010504851001314819, 0.056044478568115404, 0.06392707755523068, 0.03601067107436912, 0.06587731612047978, 0.13401194182889803, 0.03035750745662621, 0.024777917390955344, 0.03588844316878489, 0.017723733326420188, 0.0036254690078619334, 0.04917609944407429, 0.018432799028232694, 0.08621066289820842, 0.03894089741100158, 0.023787590442225337, 0.026627759914845228, 0.031886399524020295, 0.024760265302445208, 0.02958427948345031, 0.036235167777964046, 0.04696082849321621, 0.034521042435829125, 0.019375304525185908, 0.029416423490537063, 0.06579564086028508, 0.046305533298956494, 0.004598923759268863, 0.05535108023988349, 0.0517124056683055, 0.05949345510452986, 0.0478929557970592, 0.021851925112839257, 0.019227804582832114, 0.007701515802182257, 0.019330258281635385, 0.05726073562566723, 0.029733570758253336, 0.03411789085449917, 0.03934222712580647, 0.014287253708711692, 0.15077232675892965, 0.2643803948802607, 0.13415148934083326, 0.13712244134928497, 0.0896301536953875, 0.10235686507076025, 0.07352476540420737, 0.16635033727756568, 0.1850448591368539, 0.11806446899260793, 0.10912534009133067, 0.20433065641139234, 0.26559776812791824, 0.16337512406919683, 0.14297769644430705, 0.12764596699603967, 0.1487216989376715, 0.18461598429296697, 0.15874191054276057, 0.09931481616305453, 0.12915824513350213, 0.10294164690588202, 0.12597279463495525, 0.15450036099978856, 0.15310472303203174, 0.2110871145767825, 0.11015153609748397, 0.14983442851475307, 0.11673413323504583, 0.16092375346592494, 0.20297741331160069, 0.07930643337645701, 0.18683368100651673, 0.12955353249396595, 0.11620909640831606, 0.2564375453761646, 0.15121641435793468, 0.13175185024738312, 0.10533306215490613, 0.15563263238540717, 0.14040615728923253, 0.08009987151516335, 0.1505115521805627, 0.166004175852452, 0.2279355190694332, 0.16485553820218357, 0.12276841300938811, 0.12336784441556249, 0.17579094426972525, 0.1065460859930941, 0.1403409500739404, 0.08482465334236622, 0.13321032055786677, 0.1738384190414633, 0.13792902949665273, 0.12534821672098978, 0.08746811720941748, 0.19621270416038378, 0.12542638395513805, 0.16958948703748838, 0.16440017335116863, 0.07452013556446348, 0.10004789182650191, 0.1813152099826506, 0.11633128699447427, 0.10369843736823116, 0.08032743180436747, 0.15788911416062287, 0.09932491954948221, 0.1279967560299805, 0.12022933496960572, 0.11538482563836233, 0.1462340945644038, 0.18981276186449186, 0.07612269278615713, 0.15222798793443612, 0.18833115350987228, 0.17944930653486932, 0.14413970123444284, 0.08513880827065025, 0.11426754987665586, 0.13182680122554302, 0.1011936389175909, 0.10048845104340996, 0.14069813090775693, 0.09937630500644445, 0.05528622247012598, 0.24580623156258039, 0.23691438298140252, 0.12402241357735225, 0.10857145874095814, 0.0693498547854168, 0.18447201273271016, 0.10155059583485126, 0.15892276726663113, 0.18146456911095551, 0.10145798259015594, 0.07619357933955533, 0.206731041893363, 0.14207007443266256, 0.15601548898432935, 0.19646667981786387, 0.1387407337980611, 0.277469416814191, 0.08367472647556237, 0.1680609376302787, 0.1131008021267397, 0.08037297507481915, 0.12443835554378373, 0.16362973754959448, 0.09955454937049321, 0.1539862078747579, 0.1504583821765014, 0.10124317197395222, 0.06579760861183916, 0.18984268525881426, 0.09802147413470916, 0.1620338231857334, 0.0976719878880041, 0.11145265413714306, 0.11095653647290808, 0.12245992384850979, 0.0818202563428453, 0.1643790980534894, 0.1138220169980611, 0.10421611887535878, 0.16894439022455895, 0.05863240773656538, 0.23708751797676086, 0.12156356551817485, 0.14873719667749746, 0.10275559938911881, 0.12860876747540065, 0.1309349076556308, 0.06414270919880696, 0.09946661123207637, 0.14288637920149735, 0.1571619960346392, 0.1659642644226551, 0.12376241252890655, 0.22981299832463264, 0.2626524918845722, 0.06700390138264213, 0.12731793602662428, 0.10765614214220218, 0.14466464306627, 0.16813385300338268, 0.19864221236535481, 0.15737831299858435, 0.11403735008622919, 0.14133119050945553, 0.08190811984241009, 0.08918546898556606, 0.11337284038641623, 0.12295503728091717, 0.125843398006899, 0.12600939481386117, 0.0885516901367477, 0.18936540372669697, 0.05423864921821015, 0.1650423388928175, 0.16571604274213314, 0.07689456708197083, 0.2309488659458501, 0.0849365641229919, 0.12741398944386415, 0.14023756847849914, 0.11656644009053707, 0.13138423354497977, 0.12391880128000464, 0.0937006174187575, 0.14870550909212657, 0.15785061408366474, 0.09221634242151465, 0.15150749231023447, 0.12648910550134523], [0.017041970177420547, 0.046193401994449754, 0.08285115459667784, 0.03688698548025318, 0.0312354639172554, 0.02662241305889828, 0.030818792525678873, 0.015054066133286272, 0.04233151315046208, 0.01859107071400753, 0.02168525825254619, 0.010183763141477746, 0.03215186617204121, 0.0473630097694695, 0.05090476579165884, 0.044346758763172796, 0.03859470205913697, 0.00947063131856599, 0.03581708503354873, 0.054252348840236664, 0.030388027961765016, 0.043287087231874466, 0.029848446736910512, 0.010920189919748476, 0.01566127863978701, 0.031749888456293514, 0.020934739150106907, 0.1132651229522058, 0.03916878339701465, 0.02919693776805486, 0.05657314894987004, 0.05601756786927581, 0.01672182378492185, 0.024821633705869317, 0.04527549339192254, 0.015029981532799346, 0.020494259661063552, 0.026881503174081445, 0.029495584778487682, 0.018155098393825547, 0.0411675948915737, 0.028514684377504245, 0.03229517276797976, 0.016626280965283513, 0.03506413507940514, 0.03305350011214614, 0.02840172526027475, 0.053482778170811276, 0.07288578897714615, 0.038309988765312095, 0.044212887196668556, 0.016032284624608498, 0.11758219344275338, 0.0363003546372056, 0.027957484990890537, 0.04529621245871697, 0.06683615395533186, 0.041789614728518894, 0.04322485539263912, 0.04365131804453475, 0.01888025724994285, 0.016734676934512596, 0.04599593473332269, 0.016557068697043827, 0.016315718879923224, 0.032525304704904556, 0.0180830057444317, 0.023473174277959124, 0.06471450387367181, 0.027710055500002842, 0.031533578277698586, 0.05750203624899898, 0.028997733457280055, 0.018874550770436014, 0.007308941733624254, 0.011798834245252823, 0.06639900776956763, 0.033229026943445206, 0.06334981388811554, 0.0647227412887982, 0.023001008899882436, 0.014847625246537583, 0.03228091674723795, 0.08474877277123076, 0.019797429641974822, 0.05124161771631666, 0.0068234728283381885, 0.01647164622720863, 0.05985113126891, 0.039155904802360704, 0.03229531186765858, 0.03071193004559193, 0.03006575096930776, 0.052547580496008904, 0.0009412010133798633, 0.021329003619030118, 0.06782788716788803, 0.012980252770440919, 0.023580769575866203, 0.08267894919429507, 0.03953307527782662, 0.03883773973211646, 0.021575457715828503, 0.03436980376552258, 0.06728547305933066, 0.08242986577429942, 0.012228663279009717, 0.040851431499634466, 0.06791712809354067, 0.07840618025511503, 0.015830288142231957, 0.08339975015925509, 0.03564405521111829, 0.046458492055535316, 0.03578282580045717, 0.03143991330372436, 0.05052625860220619, 0.03120811895600387, 0.016702371882274747, 0.031213014586163417, 0.028980519023856947, 0.07303098868578672, 0.06635469943284988, 0.02166089884537671, 0.0211787301647876, 0.06821844513927187, 0.04083231377548405, 0.023892069568059275, 0.020396014575713446, 0.03219353161486132, 0.0834723941183516, 0.017527341543297683, 0.021053274128852145, 0.016265775309875607, 0.003432424734845491, 0.004411054375980581, 0.0023911024867889603, 0.05490294178681714, 0.017740689916536212, 0.04104547555159245, 0.0418155178028558, 0.027170867825459157, 0.02571433473245374, 0.032054079097828696, 0.08438391770635333, 0.033425791920827966, 0.009058577357791364, 0.01610202615016273, 0.024768238088914325, 0.013606935839301773, 0.0035880681576340324, 0.048750729233558686, 0.00416939497725772, 0.021561771664502363, 0.05001916563404458, 0.02612350322306156, 0.009818238871438163, 0.02706257702915796, 0.09990938925849539, 0.046982287163180966, 0.06568025598036391, 0.03085393046161958, 0.02930835321811693, 0.01373127059611891, 0.015267584140279462, 0.06142943086368697, 0.029990983195602894, 0.038546787308795114, 0.018789493013173342, 0.020632848742284944, 0.04323989172865238, 0.010753501007067305, 0.029611149470188787, 0.03777239225538714, 0.011314829279269491, 0.043521378588463576, 0.034496445541403124, 0.05503088974260858, 0.06716544699988194, 0.052959342686725516, 0.004014758966929678, 0.04779245119009699, 0.04102595070643084, 0.02813862161045628, 0.023475830742557133, 0.02260209646608148, 0.03573818498158029, 0.004046683191388313, 0.015346820067082132, 0.0836914252223713, 0.04866227540852768, 0.012414795612650258, 0.025908064961965595, 0.028679300365703445, 0.01812667795456946, 0.08067633451095649, 0.039561356617403884, 0.04057872827563967, 0.013996200353306319, 0.04051657446793147, 0.053096220163362365, 0.035989514352487664, 0.03282195682238255, 0.060479264706373215, 0.013405613651100014, 0.013710496398354215, 0.06299151347151824, 0.0688946188560554, 0.022050357590030347, 0.037140316529465575, 0.026637113520077298, 0.09186522090541464, 0.011156572860532572, 0.015525071216481072, 0.0337346746320171, 0.0785782974479454, 0.05855831849787917, 0.07970483521265642, 0.019802930864638517, 0.011547644822193044, 0.054952390026301146, 0.02044046201211001, 0.05645476155249136, 0.03956227603235415, 0.04770957153024418, 0.05005199655092188, 0.033700194875044484, 0.04170569012473736, 0.0349664599634707, 0.07658814745289938, 0.041205396077462604, 0.05954266246408224, 0.00836622906250081, 0.03640372944729669, 0.030024418008646796, 0.012345401836293084, 0.026639062611918365, 0.035261961964092085, 0.011512322833628526, 0.022695603680663874, 0.021440926274018626, 0.0059359804061906675, 0.04490896573822413, 0.014907892726893936, 0.0321340987325779, 0.04784051861081805, 0.02616172849333712, 0.041759090830705, 0.011295480005043958, 0.008590490823345525, 0.02123900443049414, 0.053195262527359385, 0.025072228562619005, 0.05097290088555642, 0.048336897511035204, 0.03197426302358508, 0.04419773890237723, 0.010420913675001689, 0.01578564732335508, 0.03394766677437084, 0.07322914805263281, 0.009864069671103997, 0.04298135631584695, 0.07302482080246721, 0.01709323689075453, 0.020224190849278654, 0.023185461859351823, 0.010654631669500043, 0.027703156495200734, 0.0719395854643413, 0.016068260551297238, 0.033945298687155755, 0.02367499264489327, 0.03413788049614855, 0.07913326445434775, 0.05256572452240756, 0.04455085191875696, 0.035500467023147006, 0.04184005023645503, 0.06564719775425536, 0.029897413216531277, 0.02053563333382564, 0.04461219487711787, 0.0297556265390345, 0.008667499458949481, 0.04882345461685743, 0.025851873780733774, 0.09892019376690898, 0.055582362293664894, 0.03828276254768882, 0.01063805166631937, 0.0322324998809823, 0.055446173530071974, 0.05871345195919275, 0.023810909994478737, 0.031140031359557594, 0.025248902118099586, 0.035184157746178765, 0.05214386233793838, 0.02976226939686707, 0.0286579366906413, 0.01827243066925023, 0.09480987968189375, 0.037664321982967, 0.04013388750276395, 0.012479342104467963, 0.01443289446511439, 0.03901145826759083, 0.0028755836995385054, 0.0284465323202312, 0.02357757876494101, 0.03301758864628417, 0.015856050420552492, 0.10149998390781027, 0.009995300040048147, 0.05794583886329617, 0.030452787343944823, 0.05118113310475435, 0.009983053331130316, 0.006970224685833922, 0.10346876004976885, 0.03168075252324343, 0.011694955622910388, 0.030628130970788852, 0.04974138357543519, 0.023854733178658143, 0.02800217330721872, 0.04506158183461853, 0.06993500981479883, 0.0512580179077174, 0.020674078226355568, 0.03982881137302943, 0.07146201216216598, 0.04265542880498937, 0.09353593018438135, 0.03513859751235161, 0.034670971533549685, 0.024854926026559303, 0.03416444514212864, 0.02832788199053279, 0.015034069706286703, 0.021284372978178517, 0.029160819349012206, 0.01990977468501244, 0.01634182721110327, 0.04536137556923287, 0.02739935601130128, 0.01645924260706774, 0.02756110010003405, 0.01918062604298549, 0.020468337927013636, 0.048458911678088565, 0.15415859648159572, 0.1370250987155097, 0.2629767230578831, 0.13754774709897383, 0.13557410586093152, 0.10372132435441017, 0.11684473444308553, 0.12181231645601136, 0.13458409612732275, 0.07756417936512403, 0.12735661252268723, 0.11461645258324486, 0.19112502144915716, 0.13485114036926202, 0.2275408288197858, 0.16620788563575062, 0.17305518606943743, 0.12338243291846343, 0.11508323039327349, 0.21466304840786116, 0.1156662819640977, 0.19852196238934994, 0.12672869621643, 0.10328183722283159, 0.1054962430415409, 0.16717304741697653, 0.07669003627129964, 0.216583587495344, 0.09497574078185217, 0.14767584577202797, 0.16502183356455394, 0.16844506987503596, 0.10624960690204586, 0.08386755934251205, 0.13101942597755364, 0.18032677445028508, 0.12676024809479713, 0.06322351816509451, 0.20251910361860478, 0.17439875325986318, 0.23731157023991856, 0.11347533988633327, 0.1413966827094555, 0.12415376438626222, 0.17718521159674439, 0.10259190960122005, 0.13458548033876078, 0.1304186646427427, 0.12019744382372924, 0.11331720051488706, 0.13940336395587238, 0.13911015540361404, 0.19137156036283287, 0.12815547894154275, 0.16156015145991529, 0.20994610366012367, 0.20288705958851747, 0.09734872023441962, 0.1735746046262128, 0.20053475509796823, 0.13636525055127485, 0.07643483925078597, 0.1805016329245908, 0.12612722920519964, 0.18502714937286718, 0.09910012768315417, 0.13107646363122122, 0.11468038415270192, 0.14736058483166353, 0.1680532566138676, 0.08213661650993995, 0.2170733269304037, 0.09274225455841847, 0.13447546267083713, 0.04860350409788745, 0.14741687609681062, 0.13304816425911017, 0.09357198074992214, 0.11552482098340988, 0.17648876325360366, 0.0838474543499095, 0.07843129283615521, 0.15198283323219844, 0.18160262384584971, 0.17835259038422788, 0.14208569430879184, 0.14988215666796478, 0.09211834839412145, 0.16448596731892653, 0.11518810476575579, 0.10229466376560074, 0.10769102562751089, 0.0891316340171865, 0.1859381776303053, 0.10015624029827969, 0.10834930637585265, 0.21498339836086544, 0.08995229498084102, 0.17645818846566336, 0.24683801191193716, 0.13861418701708317, 0.16382568489227975, 0.1874575261026621, 0.12777016604585306, 0.1821550734873329, 0.15696648295436585, 0.21304248965212277, 0.10623580549976655, 0.15574568989021437, 0.17756980524531432, 0.08111136366746255, 0.1925597566046885, 0.12850508732455118, 0.10544930877430098, 0.08923416065850429, 0.12925481423735619, 0.1549256667494774, 0.11804039457014628, 0.08907883042203528, 0.20717046117143972, 0.09530324927930321, 0.1390255827988897, 0.10725448333791324, 0.15417333426220076, 0.08422944242400782, 0.12547321644212517, 0.1785340170775141, 0.12344416603446007, 0.10739160169448171, 0.06382503267377615, 0.14223457846258367, 0.1682929830359561, 0.15627478435635567, 0.06505604447530848, 0.06809047343475477, 0.10945045336016587, 0.08069090944315706, 0.17562794658754552, 0.0689394021672862, 0.11954322750014917, 0.16937559922891005, 0.07788591352956635, 0.09551002604088613, 0.11904474853404931, 0.2185912640499217, 0.11938411103827612, 0.14467038347252778, 0.13711404108575412, 0.1601450802492244, 0.08268285755600248, 0.09524503776005336, 0.222789305927498, 0.09600809788597481, 0.15804912628872053, 0.0919206707871386, 0.14719039467828615, 0.19731582568160125, 0.18085394187697343, 0.23122106705393108, 0.13593158525015625, 0.17975844708936556, 0.14033466683966772, 0.13377110260937894, 0.1301475084785904, 0.13175138884357043, 0.11804576856749398, 0.10955257966582264, 0.12194245947258812, 0.0691887027184878, 0.08503343856760434, 0.19874760242445128, 0.12553328036197595, 0.07628685754856893, 0.10442461233053889, 0.15043472844575131, 0.187930682141866], [0.030741493816354444, 0.049910226836800575, 0.040601893461176326, 0.04005331825464964, 0.03250735406098621, 0.04317825021488326, 0.026435088199962462, 0.015795704908668995, 0.034206249684627564, 0.01429179819699909, 0.01640503105175282, 0.04039273504167795, 0.01738885763500418, 0.039647167548537254, 0.025552907858842185, 0.04922368849760719, 0.00792351973775242, 0.06938568821975163, 0.045536335823791366, 0.026031393790617585, 0.0292024406870561, 0.03792903884979231, 0.020339446807546274, 0.02899357064494065, 0.021205098035612276, 0.05109740188345313, 0.03890994603612593, 0.025393111165612936, 0.05045344500935503, 0.04699666192755103, 0.027513170082654272, 0.07628463873905794, 0.01682945470591741, 0.029005506075918674, 0.01610245362722448, 0.08521251752972603, 0.060928977360682826, 0.05376363738573023, 0.03755248923386846, 0.00992948723225189, 0.0614277073847396, 0.021718017923246537, 0.025594130557562624, 0.051643317232706716, 0.05158323974215558, 0.021030005466725146, 0.04103164022256221, 0.041128976070987325, 0.061328159512153695, 0.027674737752282193, 0.03939341241493821, 0.053660177758761814, 0.022096077279586877, 0.0038314972605024067, 0.04838211169200284, 0.046006306141082726, 0.06074867025017738, 0.036787885440779586, 0.09390235945050206, 0.03726041383509125, 0.045093428875718794, 0.04698897073311465, 0.048635625945670266, 0.029109532279627662, 0.019491371332800815, 0.04749319010547229, 0.08189379596816641, 0.013048582943156362, 0.05670906290678041, 0.032406048782702, 0.024880564472238933, 0.03354931243562272, 0.017978009235646044, 0.07655945899231092, 0.02739629751470472, 0.03959309509290116, 0.07232414518616029, 0.05357361026108265, 0.05281277573002236, 0.10247984275754009, 0.04873652410294328, 0.03740299100588475, 0.03811806852796248, 0.023006330310766186, 0.003579728538170457, 0.0691289577100958, 0.009601312074145036, 0.012795223904374455, 0.03942337652136173, 0.04004097570266042, 0.07232908492109605, 0.025578144272523265, 0.02269317622163466, 0.0314575145021081, 0.012358530640735157, 0.07082051837018558, 0.022694322945816175, 0.04209547456619995, 0.07741581089794636, 0.025589891410033618, 0.09506556524762086, 0.018216056283563375, 0.04565551371446677, 0.04738020723951714, 0.05448820422004376, 0.02984183102047869, 0.03908471290820411, 0.006023306166753173, 0.009034280715111111, 0.029551268754793063, 0.024595975011054958, 0.011888098071462341, 0.006260206914573375, 0.03279538539105228, 0.023283140367961357, 0.019048318499699235, 0.022243368572422435, 0.005381915427278727, 0.056448264579687796, 0.05055480117776564, 0.02730145358613559, 0.01315386443664985, 0.04462045604096992, 0.04062857345810958, 0.020988567333136286, 0.016342159693262408, 0.029542281558471065, 0.006498240391790334, 0.025169455845441138, 0.0143241744954139, 0.05413648559312735, 0.03200550277584365, 0.009329722495749593, 0.0961934057995677, 0.04693725618666836, 0.05832188975598131, 0.018185873349596347, 0.023486990947276354, 0.02634973358362913, 0.09165967229221549, 0.04548452288976737, 0.04500703779714448, 0.03228117798322013, 0.054715415063713274, 0.03679477257121887, 0.014432830004287618, 0.028992288213755404, 0.01626652678740876, 0.05069711711257696, 0.015934911456757357, 0.028349622252530286, 0.0352349935897759, 0.023555290585915958, 0.06315088099134819, 0.036486917840582986, 0.05509375940476145, 0.04264394459979875, 0.03239671553352049, 0.02399822467538927, 0.010680175120277064, 0.07496928503470761, 0.02989710448309779, 0.05012915276789239, 0.03936624387279153, 0.07605155517480203, 0.00793689875198262, 0.04106326334710632, 0.006576276159778769, 0.009450902912898787, 0.07663019626800503, 0.011573619990875679, 0.0090029977062451, 0.09278426944677319, 0.05167372917224254, 0.053304343816957304, 0.022252878240708793, 0.0741822522665773, 0.08177997171878815, 0.022709335533103774, 0.05112592410296202, 0.04329182001362954, 0.04012395714276603, 0.021636213741398284, 0.029406574554741383, 0.032942552851246934, 0.03604867921343871, 0.05840180082512753, 0.02700950880534947, 0.005210612476470747, 0.03188287792727351, 0.02643877943046391, 0.017177745034652095, 0.013163545435028417, 0.0731195578617709, 0.07148881429540259, 0.009808163474580007, 0.0439363977472697, 0.02412013875852738, 0.023594635438972285, 0.0581637028870838, 0.053583516872354915, 0.03144573852685945, 0.06168806805674519, 0.013355396122538617, 0.015957913793889538, 0.038369285940591774, 0.024700174241193702, 0.08045782587890114, 0.06603137749646391, 0.06397016452891485, 0.031042118756366626, 0.02838423602016909, 0.022385925387165377, 0.010809727811387606, 0.06458769924938679, 0.03771022826965366, 0.028245808091014624, 0.017033734458631704, 0.01998601487970778, 0.08157605158963374, 0.07254492012517792, 0.04078330658376217, 0.04928690081994448, 0.04727217089384794, 0.11408315119998795, 0.03852612252480217, 0.013689802776622986, 0.056667444961411614, 0.025337608697425042, 0.03525504090690187, 0.03530022794646876, 0.03015740747962679, 0.03170079305501921, 0.03390860690602234, 0.033869930409959385, 0.029671505160097564, 0.010189379715094609, 0.02346856363250741, 0.03430254398179906, 0.035488171968609095, 0.04830785281956196, 0.08593095040747098, 0.03837095174406256, 0.06362241533185754, 0.03845495777204633, 0.03485906822606921, 0.016696779057383537, 0.03338082540514214, 0.03919278318062425, 0.03782963686223541, 0.05726934623505388, 0.0751900328323245, 0.0132858734245279, 0.06078919914684125, 0.10653641008372818, 0.007265717356598803, 0.07471286665116038, 0.03511976816558412, 0.05324958943362747, 0.06423254044992582, 0.06963878856705767, 0.04307451917390738, 0.06677768459277493, 0.03201633558741637, 0.022049131137984138, 0.022188181623018215, 0.03196955399055566, 0.050289375241845846, 0.04162017096366201, 0.029218063955860477, 0.054867159242608717, 0.1318510113550084, 0.03763477856825505, 0.039368069131991694, 0.06537834860916648, 0.08201189498816218, 0.030320445873907635, 0.04326701955869794, 0.012484092697767275, 0.013095093974178391, 0.04330188608063119, 0.04363208157675607, 0.03456797331039395, 0.041669829549001794, 0.042442436662635634, 0.013502834996740733, 0.0067562151650365975, 0.038968758058867285, 0.02708647333617721, 0.0388991675073547, 0.015191435547811645, 0.03807805192523769, 0.016312098895598735, 0.006145876308437437, 0.1268915446209056, 0.026781639782711864, 0.03059500489117844, 0.01664601106728826, 0.035113118522401364, 0.02658573484846524, 0.01806973699214203, 0.05370544622253094, 0.055541602695094686, 0.025485149351879954, 0.053923038832311115, 0.027683480675997477, 0.027570043191579834, 0.041145444115889926, 0.04016911704093218, 0.011911588105639177, 0.04179306847176381, 0.018726903246715665, 0.04739329278735178, 0.014238124380686452, 0.011102857483950044, 0.039649956327463896, 0.03214254988623517, 0.058383344672620296, 0.028392685477488806, 0.07302508543112449, 0.05516067992097565, 0.02850981928142054, 0.0207242915140731, 0.03546230960637331, 0.0064542335790715045, 0.011956624171164418, 0.032581195634390624, 0.03312880053584065, 0.03590569492163403, 0.025965577590146234, 0.03666855148704989, 0.018716048382754837, 0.07529933125312839, 0.032182386677180014, 0.047291648241558244, 0.016421198844909668, 0.009387325029820204, 0.04218461710427489, 0.08125604090413877, 0.021628994128799865, 0.049573975415634255, 0.013979205595595496, 0.07042206903653485, 0.010381175271634544, 0.016376924434942857, 0.053880352194287946, 0.055787625922156234, 0.09700793959200382, 0.010449803999758192, 0.02074629131571523, 0.07349998530532632, 0.027179958498371497, 0.17938342078455857, 0.08444791034396205, 0.1595245599746704, 0.12862620582537992, 0.08473396713712386, 0.12929193010287626, 0.09364485541092497, 0.1494776683726481, 0.09319756512663194, 0.12210665137640067, 0.23285902344754764, 0.0913644145642008, 0.1277280833039965, 0.09645248404038803, 0.13782450796238013, 0.1598080519054617, 0.11033111039016928, 0.25036180711218287, 0.18261920501078877, 0.06424797712160008, 0.11740133671888284, 0.10127035408679928, 0.0829239206920777, 0.1772309855691024, 0.14076013543776103, 0.13314501834767206, 0.14172426584575856, 0.08515069620417696, 0.1421587589595999, 0.1289230513253382, 0.1824704972761018, 0.13645305298268795, 0.14107325220746653, 0.18597679984356674, 0.08807212872696774, 0.16914454448435987, 0.13595880807510444, 0.17310680901365622, 0.1609841702239854, 0.08224948402494192, 0.12103149906865188, 0.12796848826110363, 0.09252572046326739, 0.1359186116605997, 0.23602767341903277, 0.1348498918648277, 0.14842338780207293, 0.12509031913110188, 0.1962268448301724, 0.18616727819400175, 0.09077818744948932, 0.15984545275568962, 0.12940779674266065, 0.08989459236285516, 0.09958218610180275, 0.1272492954241378, 0.22512779544506753, 0.11933894774743489, 0.1914182435721159, 0.1674327634807144, 0.17010939413947718, 0.24326978623867035, 0.09518114690269742, 0.20942242390343122, 0.14365085746560777, 0.1876941719757659, 0.12475337221154145, 0.20405283703335694, 0.20945629637156213, 0.15939999451594694, 0.14362170760120663, 0.11146990249731711, 0.14129670735980782, 0.167102914037449, 0.12944963521191052, 0.14206293624426636, 0.15821904502809048, 0.13903563868786606, 0.27662724629044533, 0.2604369936244828, 0.15185573005250522, 0.12790769152343273, 0.1217422102178846, 0.12015622960669653, 0.15388955734670162, 0.23759997476424488, 0.09459427517971822, 0.08493627913828407, 0.13605057315102645, 0.09602724614420108, 0.10256085983876671, 0.2375164878155504, 0.0646866432258061, 0.11674998381308146, 0.06747177163405077, 0.19515652369175637, 0.08813211800796644, 0.2035322513963495, 0.22820590170366423, 0.19425046231065476, 0.09586433667157378, 0.14120258098202093, 0.15284515624599798, 0.1492396518588066, 0.15874572390956537, 0.1636457916881357, 0.10360847719545875, 0.09219801519066095, 0.12923003413847514, 0.14098420127161912, 0.11435615297939096, 0.11091563438198396, 0.12919902508812292, 0.13209913804062776, 0.09765245965016739, 0.1321146222097533, 0.11235371471515723, 0.06680713979793446, 0.1312313053224768, 0.14792421673025402, 0.21452698856592178, 0.09618163321699415, 0.15732514299452305, 0.07578729971178941, 0.1387005645249571, 0.09776992084724562, 0.19963581833456243, 0.12580113884593758, 0.14015249375786099, 0.06833243902240481, 0.12702455105526106, 0.10537271574139595, 0.09536993570093598, 0.13827601873448916, 0.09942864041243281, 0.11489033645817212, 0.16860061724271092, 0.08905485777982644, 0.10268783409680639, 0.10886742214539222, 0.12228718240346227, 0.1478414083165782, 0.13691058914576257, 0.1411212110625846, 0.16926748145903858, 0.09394106308796576, 0.05855827100042786, 0.12475230012621198, 0.0932598342852933, 0.14588038782988275, 0.15326223815126078, 0.10523783655038901, 0.12480902565377099, 0.1055896705282586, 0.11135278056774821, 0.12374239574585642, 0.3169063063604491, 0.12093646345393998, 0.1221349055745772, 0.16722320472555502, 0.11811126076749393, 0.12248523320470538, 0.09652986417391471, 0.10630599994744573, 0.12726054553474697, 0.08142768312245607, 0.12418075650930405, 0.0813906147543873, 0.08056873921304941, 0.18219050658600672, 0.1864826205585684, 0.1333744174667767, 0.23163500055670738, 0.09146518379982028, 0.15710126715047018, 0.0893431401678494], [0.053051440244806666, 0.033256036029862504, 0.06516329372035605, 0.010436949153829898, 0.039742803666740656, 0.008588670653158, 0.013460008410869964, 0.09082570525684527, 0.06552234731082406, 0.021985296259767244, 0.027976899574111615, 0.06052613112011126, 0.026514834724366665, 0.03392489853182009, 0.02185527707583138, 0.02659249644992607, 0.05322349297681025, 0.019648321571626833, 0.02011482627131045, 0.005089166582495506, 0.033943670203111, 0.036393358039536645, 0.06417456641793251, 0.0628090961171048, 0.0433506252510207, 0.056916837114840746, 0.018170200887003114, 0.010433922887646725, 0.03704589498894555, 0.052508805612368245, 0.0530918334344668, 0.01144264916157616, 0.021514562590579902, 0.02982243170429553, 0.019703895285991684, 0.04523686100063579, 0.029989548094038452, 0.07502478241388287, 0.036165010649710894, 0.01621580120575215, 0.03110993154613035, 0.02695550081054015, 0.08524531791252749, 0.04965835803055337, 0.02137599895442171, 0.020274763760556067, 0.04401262776393976, 0.01759969033966107, 0.03301098310787763, 0.04967836802825332, 0.018323098575430255, 0.03161784214898944, 0.0416732425801456, 0.0061339158564805984, 0.043252532836049795, 0.008472537688378776, 0.03911272622644901, 0.04354878801054188, 0.04081378637679985, 0.08966342905270201, 0.04137469734996557, 0.023292315857751027, 0.04193242938656892, 0.03208223490842751, 0.04364150303549, 0.029219695832580328, 0.053019895151789696, 0.02681031806527504, 0.04980434483981558, 0.0559563232984926, 0.03239528721730624, 0.06255819422325917, 0.01684363099879452, 0.033353541512042284, 0.07015199174306222, 0.04754872141139848, 0.023122621034937244, 0.12245520124477999, 0.045620854145714214, 0.04931680385821632, 0.007533623338011759, 0.044831263300563605, 0.03561002667993307, 0.053405174120728455, 0.012818043885220374, 0.05039425639967833, 0.021184560476935337, 0.044849990867078304, 0.05481006730613964, 0.023778038365500312, 0.12859345972537994, 0.03342499124950596, 0.04078876879066229, 0.03693206734689219, 0.043068802516375265, 0.061795622642551146, 0.006447078427299857, 0.01475748695832278, 0.03567074199340173, 0.01830168061756662, 0.031320233297135146, 0.03159894494872008, 0.042643225352678976, 0.025297778691830378, 0.05108446900599769, 0.02623406032632504, 0.018691583802657466, 0.027845090754064064, 0.03279586715091552, 0.010599793317461652, 0.024301360194970454, 0.03724581515416503, 0.017315743790407265, 0.03952980813171182, 0.02208324957505933, 0.07603242727262632, 0.024539237609133124, 0.019604686680915098, 0.013688067423312791, 0.016633171488397887, 0.017848877236247063, 0.006633097106324775, 0.04583879620102899, 0.06369526963680983, 0.03712648459311042, 0.02117537989813302, 0.0973176026184644, 0.05515494630006807, 0.036193750000425746, 0.07651378680020571, 0.04236176563426852, 0.05081913806498051, 0.035556978812175136, 0.028334752157596604, 0.04597055413095014, 0.0214726935872542, 0.05261105066165328, 0.03189597365313342, 0.016697980064366545, 0.029654477323804582, 0.03958841659394758, 0.015446515521034598, 0.01592248578422836, 0.03155881978039231, 0.033354718770299635, 0.03114177180188043, 0.034041701549930234, 0.017986628326720426, 0.016796618700027466, 0.017168679806802953, 0.032215261698833535, 0.03525532249893461, 0.08859395608305931, 0.026227875479630063, 0.0710174020911966, 0.010448089850667332, 0.0680275596678257, 0.039636392412441115, 0.0228765723628125, 0.005333194916602224, 0.005301850839584533, 0.04455583915114403, 0.023217575225446905, 0.03106932122526424, 0.024625988311267326, 0.03757875193176525, 0.026142916109945093, 0.04715545947796532, 0.0028722590899893214, 0.004331664930629943, 0.00427278717480866, 0.08038541262171098, 0.09621110199285404, 0.048003360229943476, 0.022320577375856892, 0.06784008044217314, 0.023033281721706902, 0.04557890371818628, 0.023835791873612573, 0.035122031079871316, 0.07220382735665355, 0.005650830305447536, 0.03458052620823894, 0.05577059808586325, 0.025793682617534484, 0.0363958923678313, 0.0040354750651334014, 0.020123447058722377, 0.03441086531217609, 0.02651313499414495, 0.04039886899824653, 0.014972925219418747, 0.02354303285080407, 0.05008795212156006, 0.03566451982728072, 0.025565238536468575, 0.07636103499680758, 0.03649169472711427, 0.060737352286066325, 0.07667896936514548, 0.023949186949591552, 0.010958540719002485, 0.02683819567651621, 0.02588832807461066, 0.03348192712292075, 0.02868652676365205, 0.021669828366222124, 0.012730504386126995, 0.028648912174893276, 0.05515205574088863, 0.032147370877542665, 0.009351528914911407, 0.023310997623151967, 0.06573119360421385, 0.054537119809538126, 0.03417434496805072, 0.0042346055852249265, 0.054543216446680684, 0.045597247912415435, 0.048577685840427876, 0.023144641192629933, 0.01688504877633282, 0.024274290040401474, 0.017139007470437458, 0.03222065944490688, 0.07167445469115462, 0.03886661818251014, 0.0006938277666839504, 0.12394833112401621, 0.04362324705081327, 0.05869021213480404, 0.040282530776624165, 0.026747889450884292, 0.03839303466624447, 0.01175381853577814, 0.00739164582254099, 0.058191665315202305, 0.028168455098888705, 0.03683015477976628, 0.04741249872105462, 0.025920724729076028, 0.026323308037327867, 0.031963643950543234, 0.014074569451622665, 0.06569365026163203, 0.03389861547787275, 0.018018834991380572, 0.08045770374259778, 0.015250398544594646, 0.030984049729470695, 0.021371652937627265, 0.044409316299217086, 0.009262197235200022, 0.05016254008348499, 0.04205971916339227, 0.039624643578593216, 0.05058650911918708, 0.045223880625729046, 0.05702149774879217, 0.026093742677143643, 0.02934370149991342, 0.017427735995235186, 0.024072644699897085, 0.04580777357997639, 0.06608584350241081, 0.01821332348377577, 0.09177735062049967, 0.04134202928149274, 0.020638748604272093, 0.03636754656742726, 0.02050650043279997, 0.026944267663306425, 0.017488739686086774, 0.04232565400057605, 0.0717039302523647, 0.03144773002713919, 0.026603919586965015, 0.019498609605112245, 0.03291274480787771, 0.038636004485722096, 0.016130037772070085, 0.04847245184438569, 0.029885606707206795, 0.039866755051272254, 0.09282333949314696, 0.026850617956370115, 0.060954415638531954, 0.040978958763714345, 0.01835269288026861, 0.04904095562441008, 0.0828338587390525, 0.05739095328109605, 0.066175213349717, 0.017592228150793483, 0.0299924352605428, 0.03584016540220805, 0.002840622394744839, 0.015474516964916672, 0.03652918717956968, 0.03046305357877697, 0.031581170723906586, 0.0258630305927779, 0.044636781593518596, 0.02277068866948996, 0.051622920470046144, 0.03397321022514786, 0.05539702384599617, 0.012451753718778491, 0.06852441014988081, 0.05594154480578644, 0.06940926052629948, 0.025544153060764074, 0.018706801646788205, 0.007343201814884586, 0.03930076524349196, 0.02248139526428921, 0.06694217505199568, 0.06453117728233337, 0.02671903814189136, 0.03823138387607677, 0.03989712967138205, 0.013427931516032134, 0.05291835917159915, 0.016493030258321335, 0.041036898868956735, 0.062187062709459236, 0.026329043354572992, 0.017955509014427662, 0.012665207264944911, 0.03410338377580047, 0.05071052496454545, 0.01826237647661141, 0.01243294557623033, 0.01728364738768765, 0.046315015825842104, 0.04228574935612934, 0.023939083563163877, 0.022088403048525964, 0.0365753682729389, 0.04229155083053878, 0.0559730898988034, 0.01655248349665531, 0.014707599367414202, 0.0066305271549416435, 0.03702667887721743, 0.031874721936349354, 0.02823206945322454, 0.010692119881111597, 0.062176511489919255, 0.009323196685207742, 0.05569897532196982, 0.013652771727980247, 0.1479225339634078, 0.19467032620949404, 0.10692156691636358, 0.13203713351062366, 0.1393050170902695, 0.06537838253591742, 0.0879419246422393, 0.19182806515267917, 0.13184065691062383, 0.10289130639284849, 0.09055548547101872, 0.12378389494759695, 0.09790091881794588, 0.10391660673277718, 0.10717884025403432, 0.08593461449657168, 0.11729836224445275, 0.14171760263187544, 0.09325129152940852, 0.0496704427392355, 0.14856840430625848, 0.09704249738050358, 0.15322262527687208, 0.1479839685239962, 0.08942249483828034, 0.08488567399659327, 0.07868760943944965, 0.14972940486456665, 0.18488469773105212, 0.10354681871831417, 0.12956172919699124, 0.13360106173370564, 0.16868605837225914, 0.16309559478291444, 0.16271281960819448, 0.12725065249417508, 0.0956325355385031, 0.1355169867830617, 0.1196377474282469, 0.09626016007470233, 0.09267214153494154, 0.08491607915077891, 0.16915645955928735, 0.15180379498217786, 0.08987266211105244, 0.1779032644948789, 0.10754716941820723, 0.17159358092716762, 0.1359713745436498, 0.1626428355063711, 0.19264211718525204, 0.15172424353659153, 0.15794704748051508, 0.1396294789654868, 0.09749357389020068, 0.08985047401594264, 0.13143770210444927, 0.09677087981253862, 0.11192973889410496, 0.18666383012064866, 0.09917399300528423, 0.10961946286261082, 0.13582387460129602, 0.1293073057063988, 0.24713968858122826, 0.11570307213280882, 0.1608687107052122, 0.08038516834910427, 0.14630968336548122, 0.1756832879036665, 0.13161127136221953, 0.22336675279906817, 0.09955888520926237, 0.14399832167795726, 0.13196037762931415, 0.15963524260691234, 0.15629013281847748, 0.20866056478449277, 0.1833800191857985, 0.10334029980003834, 0.16175387320773943, 0.14388457206743105, 0.19589540761496338, 0.140157514916999, 0.09036043379455805, 0.1255419384688139, 0.15953894491706574, 0.1265075887952532, 0.14685669115611485, 0.13714551153991902, 0.22939208948186465, 0.13862937263080052, 0.10504032857716084, 0.13177785170929773, 0.1142679705683674, 0.13967043533921242, 0.10945421922951937, 0.11709622666239738, 0.15261155020977768, 0.11843279137143067, 0.09109223381217037, 0.11254331097006798, 0.13379699550569057, 0.1294917179537671, 0.1040288092834609, 0.12316534242459706, 0.11934851509119783, 0.1549505011311599, 0.20451433584094048, 0.11536604378904615, 0.07476308502789054, 0.24552059546113014, 0.07595727273396083, 0.17790512368083, 0.16444365387516363, 0.2694255741579192, 0.13706376164087228, 0.12820347850876196, 0.06215586366930178, 0.10642398361648832, 0.14207582840962069, 0.15206178756696836, 0.18504886249346392, 0.0972910447578345, 0.18064959427075727, 0.10942831276250736, 0.13525268382259778, 0.16572768640305313, 0.14140223312590802, 0.16081088595092297, 0.11255280367497887, 0.10947004945150443, 0.13651163769619806, 0.12598169701439993, 0.09465221528496061, 0.12621363385447434, 0.17742835783532687, 0.12848293994154247, 0.09663727626736675, 0.11195694814835276, 0.13807138614356518, 0.17470144773168222, 0.14529345503875188, 0.11421052579368864, 0.2663954810372421, 0.08250087446400098, 0.19269338729126112, 0.11363185755908489, 0.09450422679739338, 0.08237905707210302, 0.15209141240588256, 0.08406454484377589, 0.131700905838183, 0.08507565701646463, 0.14580030712698186, 0.10946583574903862, 0.1133042744227818, 0.06651725606726748, 0.08362161075430256, 0.09103941664631877, 0.07068536776517119, 0.12530917381601675, 0.1823658128934247, 0.19985274598002434, 0.09551320837012359, 0.11412220767566136, 0.11506378357963902, 0.08889857759433133, 0.09890555776655674, 0.10633059005652155, 0.09780831914395094, 0.14650962049407618, 0.17277866947863782, 0.06345833877899817, 0.18403210490942, 0.295701978462083], [0.05762770093445267, 0.00832067646219262, 0.025436854621927654, 0.012602180691568978, 0.06846664646374327, 0.0705812872786607, 0.021735593676567078, 0.05841659288853407, 0.03776956954970956, 0.04253441208441343, 0.04052396371428456, 0.030746077320405414, 0.025605516375175545, 0.06603662257215806, 0.010781769624112971, 0.02163658015030835, 0.08978146700454609, 0.020479489650045122, 0.028964475063341003, 0.007865045286182846, 0.056135361548513174, 0.014935023949614592, 0.022697642678394914, 0.04625342520219939, 0.06618583920810904, 0.05359911299975855, 0.02939240335087691, 0.01262268262715744, 0.015657180288274373, 0.04419711125748498, 0.05384489195421338, 0.067744563067598, 0.007621859183668026, 0.06562452111393213, 0.01764307077974081, 0.034835485741496086, 0.03336165679086532, 0.021266597057027475, 0.054954524018934796, 0.035296621532844644, 0.04314001137390733, 0.056061543723834414, 0.061368993749575954, 0.06731865342174258, 0.025785943925646797, 0.04365086681874735, 0.027529013875339712, 0.08485556739781584, 0.03726397953661425, 0.031154670752584934, 0.05390558012628129, 0.015367325395345688, 0.04142758576199412, 0.06607147213071585, 0.011681752179616263, 0.017412429941552024, 0.0694153673414673, 0.002743760884706197, 0.013205852941609919, 0.025769771043477312, 0.051540668455085585, 0.04500528039144618, 0.020945848464699726, 0.035695396563304324, 0.03682545592476215, 0.020949434522273283, 0.01145046842949731, 0.025173277693933675, 0.02802370661603553, 0.057176142664892335, 0.0877120912607227, 0.0500651397742331, 0.02415986868020679, 0.02036260181505765, 0.0158097828139684, 0.04582937813497015, 0.0729984665023429, 0.11014234194798128, 0.04932795558124781, 0.04075538147506969, 0.010547559691726096, 0.0630356657451817, 0.03199806942471436, 0.03166719539357083, 0.012690337657529329, 0.03237236969705139, 0.012808943882451525, 0.027276720984705856, 0.017288660065137913, 0.04722417811197894, 0.04540531410436545, 0.05362119931461556, 0.06064165170703616, 0.0413896420837513, 0.05152932334957378, 0.02497909284595932, 0.06710308963166815, 0.03261500024901969, 0.027093911776319146, 0.031236736170415367, 0.03481828148609825, 0.03896812362862485, 0.028861368274582282, 0.05412533726277096, 0.04537822698642101, 0.029301428768251623, 0.05453503331435578, 0.04708847789359944, 0.02204184197554631, 0.03536178803603564, 0.01967073867230543, 0.025984966728304113, 0.0270760374675904, 0.008635411537917597, 0.022105025460145304, 0.04972668650693127, 0.04808028574500765, 0.005060027744288423, 0.02591887063213757, 0.13199562073818275, 0.07652851779546056, 0.033206950806613476, 0.04339634154790214, 0.02870264197034495, 0.013547698884004993, 0.03768643543922475, 0.04982546763494611, 0.010632690391503274, 0.052922393062285016, 0.024132399886314358, 0.023474175117111633, 0.024771357653662562, 0.0429968472703227, 0.07737383672169276, 0.022507988748007586, 0.03984353219025901, 0.02911665689732347, 0.03026867365198476, 0.0076383195950516635, 0.03761986097587006, 0.012555002999891127, 0.015925561244200383, 0.007785532008191305, 0.04736387150894318, 0.08343746992094175, 0.10095900150814227, 0.047227092419884036, 0.030937030645353452, 0.04736293852329254, 0.01651252626574465, 0.01950764769156064, 0.020157394165705358, 0.07139012816229037, 0.004877657887326288, 0.03124857321381569, 0.07247252722403832, 0.03152455036927547, 0.014786762351702367, 0.04244126618972846, 0.06780270673334599, 0.02767983015759715, 0.042510534437107186, 0.03170370397024921, 0.0744334730718817, 0.043581018423927684, 0.01072928324408297, 0.049560747375445705, 0.05200961418449879, 0.03820167761296034, 0.04388495800750596, 0.04864870131547962, 0.05928390992007085, 0.039187130983918905, 0.03621675233755793, 0.02332970144094101, 0.07889499009719916, 0.01207832366760288, 0.01423523891051965, 0.03923681331798434, 0.04382005613297224, 0.02437022641035063, 0.03755202783005578, 0.07395515338118587, 0.051133706899625916, 0.03443737906802978, 0.04981406485395772, 0.015942980934466635, 0.015027002764067479, 0.002688199044704171, 0.03522432701928275, 0.0776432151240962, 0.031183898648513213, 0.02253462464016463, 0.07714202880327191, 0.03230645680533988, 0.0563152276112565, 0.015375530580058694, 0.01807146895277713, 0.015056281550122159, 0.06084055067705257, 0.04417602238910539, 0.0513788548165134, 0.044380410707422664, 0.008482998153860015, 0.02185925668371575, 0.039600195961871316, 0.030986692623368332, 0.03917527697714312, 0.025354979193902442, 0.04345476680568286, 0.0335489731681134, 0.02309442960124995, 0.02476942043618432, 0.039864621058638604, 0.04561037756502628, 0.03399976469310267, 0.011011722597426601, 0.06337846842195306, 0.024003544389935474, 0.026001383883080313, 0.037660891988447735, 0.010752939519339373, 0.019688665567498122, 0.07418012166661875, 0.02065757625470204, 0.06160129699856043, 0.08359334977077586, 0.008470425748133233, 0.10744770975517375, 0.04314614533047591, 0.038172843267342875, 0.06272842508873769, 0.04204354288854769, 0.03622256738266774, 0.026443439269704477, 0.044981392566114664, 0.09807949566415378, 0.024553369797234024, 0.02873561198690108, 0.01829902415296861, 0.11947279556521348, 0.007203706041244524, 0.04476533344547663, 0.09325441957584449, 0.06158319368426289, 0.02394637102926416, 0.08326521702110767, 0.024640456374202455, 0.006886108819994011, 0.006700071057171694, 0.018524838910837258, 0.07319860719144344, 0.09512127297265188, 0.06553701723792724, 0.03395047251667295, 0.03375993309808629, 0.03992266294413379, 0.049240794365427325, 0.04080386958750231, 0.020661415066570044, 0.06762098827000175, 0.05030627754916038, 0.04158315009304455, 0.03221093603808965, 0.04083674121648073, 0.014461219909467866, 0.007929564636599804, 0.05053922879908766, 0.02973643078335694, 0.08663085927920681, 0.053832478156047206, 0.028518056696546928, 0.10588967121605362, 0.025685561454987953, 0.08667210063764028, 0.07214358701769795, 0.04092249786481261, 0.04006118247551577, 0.03569499962031841, 0.017245892002912502, 0.051299544250858684, 0.06032039251710687, 0.044270389646823914, 0.066494606568345, 0.03681710655135768, 0.09869364449488265, 0.02596840199216136, 0.04585312007527266, 0.029282246583274434, 0.025890372161354338, 0.03358206871364798, 0.09605091344565153, 0.03493096918932029, 0.023150675065283264, 0.03176833103810038, 0.05703985212104661, 0.0166416497834559, 0.027271635364741087, 0.015827136347070336, 0.03752699667321784, 0.042722227184900215, 0.04984813748991915, 0.01387220062315464, 0.012251629993053419, 0.012463535631208547, 0.02739132215668048, 0.03867383620568684, 0.006444674292911908, 0.03275122633203864, 0.05540480664266007, 0.048725945742002556, 0.057324117581759176, 0.008851977863482066, 0.037021501655025144, 0.011514332993621272, 0.038263926415571144, 0.08797664527914353, 0.01607248273545078, 0.050073468791587014, 0.05876029123153005, 0.029980408227337257, 0.04081619178344097, 0.03553048201969691, 0.037754560355097055, 0.009206918683568282, 0.02139476384036243, 0.04298808738323195, 0.07223983042474304, 0.04262751726699727, 0.0153004235388445, 0.014734311594760843, 0.061993734511945925, 0.03039960376918316, 0.05524031279076423, 0.012668377719819546, 0.05356798181310296, 0.03049752315772431, 0.013913658264625286, 0.02150003345949309, 0.027069879762296165, 0.07162002261195864, 0.018602734730978097, 0.052540435522262535, 0.02666941348330251, 0.016583553615159223, 0.03524043883330055, 0.061730110086500645, 0.037312817094581466, 0.029644971048193317, 0.012291337862344725, 0.022967038044173802, 0.02671415777876973, 0.0828944519162178, 0.06791534354644162, 0.1904550902545452, 0.14261136895843915, 0.15610232789601597, 0.17817106869603905, 0.10865166836551257, 0.09932059728141342, 0.06392768823674747, 0.18164983631244727, 0.12345361124191966, 0.07013072645557777, 0.14374250040522643, 0.09211271655346666, 0.08868920204362699, 0.23533649050763675, 0.21687699960810797, 0.2205701842904091, 0.1490535025617906, 0.12574901378580502, 0.11159790812858514, 0.12147451458232743, 0.12451079594237463, 0.08418480160513095, 0.1632800613130842, 0.1317711749247142, 0.1133281249286873, 0.09104150653417621, 0.1069304896518588, 0.22401361380304607, 0.1526271022324051, 0.12692606848265442, 0.1736053829746587, 0.11298999735819441, 0.08948226020272289, 0.16388272254594735, 0.10035960402871881, 0.08900686499795743, 0.13707136123308114, 0.13508189655840397, 0.20319607800671033, 0.13533412159553596, 0.0897557573126895, 0.13471217639744282, 0.13198323068874224, 0.05611976881378463, 0.1304782943001815, 0.2714155273778098, 0.1019829244219831, 0.16020970392440045, 0.12768226861953735, 0.14674824768943445, 0.22249836368220194, 0.08958836272358894, 0.06494138562785727, 0.10881274579358952, 0.20976483981524194, 0.1343006177672318, 0.08712593878486327, 0.1160941661468574, 0.12542623467743397, 0.11443440163774149, 0.13257876730390958, 0.13008941231029375, 0.26874614347304615, 0.15686282994491713, 0.12494097357349736, 0.18932499018098625, 0.17274335851626738, 0.12882360523300512, 0.20562018507293292, 0.17647557253284113, 0.1079295306865658, 0.08628997007118804, 0.12873010310743535, 0.1261684705636331, 0.13534081195081982, 0.16284126628722462, 0.2302606685885361, 0.1792171797049897, 0.13977188989520073, 0.1822343806603125, 0.1541460028716496, 0.15846022351511888, 0.16709916852414608, 0.15492916799017362, 0.17295394864465508, 0.11471067395593439, 0.2468268025134291, 0.1639964585857732, 0.07027933919536215, 0.17140029344175542, 0.11955325624772481, 0.1539668289146253, 0.1941653468779155, 0.1647894624620676, 0.1501249907804387, 0.11342561684016671, 0.21046297092522892, 0.09878314326384238, 0.062204439991286824, 0.18072812791381562, 0.1083125840606434, 0.14094070717692375, 0.15661307477525302, 0.11488851798432213, 0.223145740372794, 0.14454273746481963, 0.14295751681285246, 0.11242390237748623, 0.11017112540347235, 0.08241875815604414, 0.10140790670577969, 0.09297195223293134, 0.09938081047896828, 0.19429019732134684, 0.21089275500604085, 0.08795002635036196, 0.11012006564331905, 0.186798397185547, 0.12001445649990014, 0.09810515107320887, 0.09200726542621851, 0.17018023319542408, 0.12929397927863256, 0.149507537484169, 0.08179259247013501, 0.08816508802452258, 0.10706608808998551, 0.06751168306384768, 0.11978736439985888, 0.1504174800855773, 0.11734862811863422, 0.12505920151514666, 0.21270866399364813, 0.156811084864395, 0.07473673751311642, 0.13178736477025918, 0.11714175636214869, 0.12611553126147815, 0.17502151269997868, 0.07559784594923258, 0.14091786768819603, 0.12125532062990324, 0.16254708064453943, 0.21953989671809332, 0.07928577198513917, 0.13455969600805215, 0.11636653010334287, 0.08166405079620224, 0.1872205545327493, 0.10995991102286748, 0.17768875243408339, 0.05132871786398547, 0.14772429317235947, 0.10753716102668218, 0.1001015164490257, 0.1357786570276533, 0.1072899978607893, 0.17561278811522893, 0.11061981346990381, 0.06559123897126742, 0.1069414819191609, 0.16228747314640454, 0.23364085863743508, 0.05124618425699217, 0.10307350661605597, 0.1396371056990964, 0.09882888330944947, 0.13847607799938746, 0.2110022705580507, 0.1294731396649565, 0.12040014937520027, 0.10106401837297849, 0.1598439056958471, 0.07563603390008211], [0.021314442257529924, 0.031919227048222504, 0.014671068738347717, 0.010625790538532394, 0.008420244690829089, 0.019800169227112616, 0.043007646155144484, 0.015153956666056598, 0.008795008063316345, 0.02928172071863498, 0.08207581298691885, 0.05894708513681378, 0.05129834324387567, 0.04868402245587536, 0.03744497536016362, 0.05987042880484036, 0.02994962309354118, 0.07493467296340636, 0.042115277610719204, 0.06587159607027258, 0.03592942329123616, 0.059895717804985385, 0.04702629355181541, 0.03674278661076512, 0.10422088219118969, 0.04872003570199013, 0.053311617712357214, 0.037407537190509696, 0.04995284562132188, 0.021409172531483427, 0.029133396356233528, 0.018231725353481512, 0.03841456797506128, 0.00447579806703808, 0.00471172554119091, 0.04801400983706117, 0.021822283310549598, 0.051655286590435674, 0.09950592555105686, 0.003918500292846667, 0.050321208712245734, 0.08259168280554668, 0.04996677255257964, 0.05767435700233493, 0.04067057138308883, 0.05336294210116778, 0.03414607380649873, 0.011206918462578739, 0.020279102992000322, 0.009867584482500595, 0.06535182467528752, 0.010317428602970071, 0.03155165784327047, 0.032567200849631, 0.05470059925158109, 0.02029739799244063, 0.03106666136799114, 0.01574574946425855, 0.018125124109376754, 0.09132193148668323, 0.034142701487456045, 0.03398678431819592, 0.02773814176076225, 0.021720638764756064, 0.08715096994170121, 0.030181702425969497, 0.029050547230456556, 0.09386354724743537, 0.04373439447954297, 0.07318741136363574, 0.03203268149601562, 0.04274038138932415, 0.03148164660004633, 0.010868851112068763, 0.03808321218405451, 0.082268116596554, 0.036808665575725694, 0.048246072206114016, 0.0415668584672468, 0.048047006995018036, 0.020796828603904163, 0.008580676662469549, 0.06753942157541003, 0.023302970553881357, 0.0598368209653667, 0.0196812966771956, 0.025805584121761576, 0.07273421782468047, 0.08567012154630252, 0.073363599766578, 0.036712062545120716, 0.018960853639457906, 0.02568234859167465, 0.01361265588950898, 0.04316254212920155, 0.001498531866153436, 0.014672826144046016, 0.020248770780329193, 0.005866190110931971, 0.05212537904403039, 0.056397832464426756, 0.047011728797640116, 0.01795269818311291, 0.047571981591837745, 0.05232876313052007, 0.07631766303841557, 0.04387515996183668, 0.03181387430855206, 0.0815549830773047, 0.06770020723342896, 0.032321666167782884, 0.033536389736192565, 0.04885949839704803, 0.018958840086790066, 0.013849938737361558, 0.004648771062160709, 0.038916697459561486, 0.059055935724505355, 0.03522062221808093, 0.06392680614122323, 0.04150886068652783, 0.03910267373014774, 0.0442852054589561, 0.03577529066907508, 0.045524006842502525, 0.015428237483969756, 0.04780106179948364, 0.06580435324992452, 0.026676987630448172, 0.039060197437980344, 0.03707173699513078, 0.03206235043970602, 0.08591565622815064, 0.03835338107975466, 0.006514428540997739, 0.02346998855604657, 0.004845248086244932, 0.03555318919409599, 0.04852995429454105, 0.015038215555250645, 0.036259425404880724, 0.03805642362151827, 0.03846637412373509, 0.04052224702068737, 0.03777332863371287, 0.08151855253215347, 0.022439797674970965, 0.0384517584794334, 0.03977719860683594, 0.04388671541320426, 0.03225937665307096, 0.007534469810447523, 0.029369719925203493, 0.036156535747327974, 0.03392847101869328, 0.06468675857675926, 0.021858603593760302, 0.012457343150994607, 0.004514103489262717, 0.02699317816378815, 0.03862359068755593, 0.03769497140975935, 0.011547808518766292, 0.022241784193153893, 0.023590179160237312, 0.023981776986537234, 0.02620718185789883, 0.07518463169357606, 0.009365549992903002, 0.059989627051566324, 0.04332365348402943, 0.0012519800179039261, 0.06201389378734997, 0.0462194848805666, 0.00903674803807267, 0.06428359342472893, 0.07232825032302312, 0.024500320233138542, 0.04025765907551561, 0.05436011377189841, 0.0069608956774962795, 0.04991936670350177, 0.07057053928396531, 0.0160188801653151, 0.03568360023200512, 0.04902441294065543, 0.017344094679823945, 0.05433422087558678, 0.026962471061519215, 0.03542575692491872, 0.058665527030825615, 0.038433210724698644, 0.059766823292842934, 0.019920546428433487, 0.044954641323004446, 0.037838383178625784, 0.04429668966414673, 0.04038863329749022, 0.03964678417625172, 0.05603932509464877, 0.04556867141010506, 0.032908042560198476, 0.0226643893734685, 0.05830842083586114, 0.027707560187471763, 0.02583085615853114, 0.035316064953804016, 0.005327437546968992, 0.032111099788120816, 0.017663950998602167, 0.04583869781345129, 0.05372012293498431, 0.04119463111939175, 0.04739967780187726, 0.052353159857115576, 0.04873595413352762, 0.03221818618476391, 0.01941950259996312, 0.04738957102277449, 0.020506225626117418, 0.01655971328727901, 0.05630667467734643, 0.022083982392879467, 0.04242471332794853, 0.045214153826236725, 0.07049324057464089, 0.04021592577919364, 0.01626423673172082, 0.027978936875505105, 0.0384609967337123, 0.014494878639067923, 0.013171938913209098, 0.022807667131668756, 0.01782771203267787, 0.032060026457267146, 0.052323355206421444, 0.007842326237420951, 0.04411903901823929, 0.047725442464330366, 0.022860214579850435, 0.0041319406923971, 0.046583512132721286, 0.04347514999764306, 0.07096755690872669, 0.019453517560447966, 0.05893385370395013, 0.03212424979678222, 0.04614340074892555, 0.051378715716834576, 0.0338404548487493, 0.03532688758735146, 0.10242690345538513, 0.060898802908403535, 0.012560894380190542, 0.04337564283715827, 0.09195952370230641, 0.00793891484915678, 0.05490581538262112, 0.040080211990113766, 0.09369607123413257, 0.014669733720698526, 0.05518080526962876, 0.06673047212617737, 0.016395989572629333, 0.03292070741632155, 0.058777939927365096, 0.012842125093032206, 0.040039896831980774, 0.009386956076403814, 0.04522986191191843, 0.03309512484286513, 0.02996680360021336, 0.024184938852808306, 0.03498150987018432, 0.0403088715060481, 0.11664927564561367, 0.03603017217080508, 0.029223370099706308, 0.03742019526128258, 0.019125444182593907, 0.03152939171663352, 0.04020655181791101, 0.010864121722988784, 0.01841963714520846, 0.03571067377924919, 0.03063438706366079, 0.03536540802036013, 0.025662090928692902, 0.02156578519913767, 0.062334739070917876, 0.06076602717595441, 0.029314405750483274, 0.07241654808499984, 0.05965370471988406, 0.05569398808958275, 0.0034398525728777584, 0.029290521317826848, 0.02536563728270786, 0.027523655145029937, 0.05373166481565152, 0.03616718874712076, 0.03285176147307668, 0.018426804171342934, 0.07770605425217322, 0.010008154885976442, 0.009683601408531623, 0.06108094206345933, 0.04616896794842822, 0.01499362732283771, 0.037924238214535375, 0.038137874965156825, 0.05300959159753152, 0.010568716413607555, 0.06630908830889634, 0.08801064666892801, 0.008857189012425286, 0.016212612091164504, 0.1031175163973655, 0.052752956082778316, 0.06257827885981117, 0.051501191287700615, 0.028901683432715278, 0.04499454257477607, 0.04222761247573154, 0.009398077265359461, 0.10002898105553218, 0.06470950985593454, 0.03512133897415229, 0.050678454006889036, 0.036807613846446784, 0.009267775641222085, 0.02959442018930401, 0.04774127607899053, 0.07993645992662225, 0.020021344501791254, 0.03161299740895629, 0.04277379923899259, 0.029026632263724293, 0.021292586644579257, 0.021872060639517646, 0.0329944302460977, 0.034373647666403224, 0.05836368751313005, 0.04806295596063137, 0.04360697578106608, 0.05557639118550079, 0.04498642390327794, 0.018612731248140335, 0.03333688347733446, 0.05667044408619404, 0.03261192648538521, 0.029772990250161717, 0.18739401522491658, 0.06261521830622639, 0.090560662693211, 0.09361819577004228, 0.07882510777562857, 0.11374704566385065, 0.1680999941059521, 0.08410445627357278, 0.0662954565403717, 0.14811793847807816, 0.140151693086539, 0.10450123929019485, 0.16320709165717873, 0.1689401018832411, 0.13746734069926397, 0.12326202009405408, 0.07000835945031472, 0.08618974366358348, 0.16925027381096566, 0.12132207490503788, 0.09470428606229168, 0.18922824465802737, 0.15256429703107902, 0.1054535156914166, 0.12231619656085968, 0.09547252341040544, 0.11859026577855859, 0.16203013195523194, 0.10657674220523664, 0.16254721635154315, 0.1319952407585723, 0.14384540702615464, 0.0796805029468877, 0.08037007094493934, 0.14605596555130823, 0.13973672821053437, 0.07608461340091058, 0.12296054698526859, 0.18396650414381707, 0.11438892622079168, 0.116847516436662, 0.15972909757069179, 0.13856795164091246, 0.12035608531108924, 0.10341706246669803, 0.16083836661917822, 0.12055022775062493, 0.2523632140031883, 0.1344760733523539, 0.15006678604653903, 0.14493099520249025, 0.06371833304209368, 0.12293089500495366, 0.0753582688048482, 0.1147789888616119, 0.03836161849488105, 0.14464985100286348, 0.11879107143197741, 0.12026989779302052, 0.1469422137098653, 0.11279715770589453, 0.12333294057420321, 0.1316636406949588, 0.07927447437707867, 0.15084863480712685, 0.08843481926513569, 0.22441097748066696, 0.1354243124702147, 0.2088920266500541, 0.15817812936646597, 0.1522750375526292, 0.15467895141669682, 0.13571590610912868, 0.1288478017917701, 0.08796594478189945, 0.2051781602203846, 0.1816451544208186, 0.14176056746925625, 0.13199384297643388, 0.1636775606977088, 0.18176697859806673, 0.10592110095811741, 0.15990900434553623, 0.12026661368353025, 0.16827629107449735, 0.17287781701556273, 0.1393215326326234, 0.1928265837154218, 0.24194205605557986, 0.26504804619721, 0.07120514594550643, 0.11536604378904615, 0.09078553598374128, 0.09722460260880844, 0.16263014690152236, 0.1285462879708835, 0.14377170455242905, 0.1874226358320032, 0.10131698301328079, 0.2399445575262819, 0.14121355967862265, 0.17253160130764755, 0.0964200704225472, 0.13201280124485493, 0.23042666539549828, 0.15325330863041536, 0.1373626563165869, 0.08159121684730053, 0.17630407959222794, 0.14564482761280878, 0.12952051497995853, 0.09007899103952305, 0.15077364311686584, 0.17640254859413418, 0.095191901682743, 0.08447043770658118, 0.09375856430935008, 0.1292849683335849, 0.09195985618446555, 0.157206087240151, 0.10012896997588021, 0.1504462363996676, 0.21635644111250127, 0.19526428862341813, 0.10352103438760553, 0.09026082485382046, 0.156282546796969, 0.167469499366624, 0.10475401394069195, 0.12347170098551682, 0.15838031923132284, 0.16611811545278343, 0.18625026302678244, 0.2206512013716357, 0.18403955522392476, 0.15715001310620988, 0.14068301314754145, 0.232185211032629, 0.1921852052743946, 0.08552017887788159, 0.11562170221337251, 0.16683422774076462, 0.1626326846224921, 0.1332503134118659, 0.17162575705775193, 0.12208307906985283, 0.07154569588601589, 0.16213151865771838, 0.12243158822613102, 0.19654481991061143, 0.19916346296668053, 0.11609415257615702, 0.17226348498037883, 0.09520361998251506, 0.07232931562300239, 0.08912032962377582, 0.086494819793318, 0.12584406297121728, 0.1097643029476915, 0.18055506077195915, 0.10999267069356782, 0.08729164382176739, 0.16948511478091988, 0.07575319654175214, 0.10450197889336518, 0.07280112137751919, 0.1398996716099126, 0.14908050825553282, 0.09068589311625276, 0.2113553394696542, 0.12714796300445283, 0.14956338091620378, 0.17224660302911485, 0.14733908884227276, 0.08192092379821198, 0.14842720116887773], [0.0640036773734859, 0.01440408217188503, 0.03927267389371991, 0.026199317637032697, 0.009804496840972985, 0.0335299470461905, 0.051406871527433395, 0.05661295859941414, 0.036738640761801174, 0.014069135234292065, 0.01304661519160228, 0.030560782977512906, 0.052217167868678055, 0.01565248821862042, 0.030950122978538275, 0.04725573677569628, 0.014917366772091814, 0.05612031503447464, 0.012451961520127952, 0.033297348634472916, 0.09463044109621219, 0.019520673867581145, 0.06880311162344047, 0.013789604251672114, 0.015258914159078683, 0.06315009389072657, 0.020325243373268416, 0.0715373566906367, 0.03069503452362759, 0.03162003042442458, 0.050223818581019125, 0.03517965905900512, 0.034446848024215014, 0.0269000000386898, 0.03445074960057225, 0.043456985615193844, 0.06911248966519322, 0.023083350820732967, 0.11431499304515974, 0.07745386314179216, 0.04181903600692749, 0.03042127617767879, 0.033636175096035004, 0.03289828183395522, 0.06473591843886034, 0.010488363448530436, 0.036516155914536545, 0.04291502273242388, 0.10965727761920009, 0.08674310254199163, 0.0681659197434783, 0.020880863469626223, 0.010342970357409545, 0.040003042202442884, 0.03220202008794461, 0.014952925399744084, 0.05990579405001231, 0.02961573636691485, 0.04311358582760606, 0.03497982031798788, 0.07979835090892655, 0.03168200781302793, 0.032701398112944195, 0.018201014858537486, 0.03661751886829734, 0.033161190404955826, 0.013158738014421292, 0.03796381716217313, 0.012167430582589336, 0.030049788432994058, 0.0071178789949044585, 0.06916533397244555, 0.003320492325916088, 0.07120615696268422, 0.056095066746430736, 0.11344034105007138, 0.03186610793428762, 0.008945334104022809, 0.043423072434961796, 0.057950201843466075, 0.06276086584797927, 0.08761830415044512, 0.08493634020643574, 0.030404682603797743, 0.01854859442184014, 0.06397787947207689, 0.017994836904108524, 0.02467916001166616, 0.051677983586809466, 0.03660267252208931, 0.06189388129860163, 0.02558782696723938, 0.010390198091045022, 0.047521807319883785, 0.09343678264745645, 0.01772197931339698, 0.019482770901439444, 0.04914258999217834, 0.01618217470656548, 0.08536039066634007, 0.016558228991925716, 0.02210543427749404, 0.02522732809718166, 0.07637197298130818, 0.008267626049928367, 0.060117028786667755, 0.02017787065623062, 0.014807818989668573, 0.04403124337217637, 0.030819698369928768, 0.032226121651807, 0.018281305907294154, 0.007243822727884565, 0.029623291854347502, 0.030061496554740837, 0.041365533734538724, 0.016975765515651022, 0.01980064420162567, 0.0696153858942645, 0.039104275072791746, 0.03137737273105553, 0.048439566644706895, 0.07169056989784751, 0.035160656685807874, 0.020849750942683647, 0.01351944129315338, 0.0617797856352159, 0.06496271876884357, 0.02565681022991027, 0.022185051880244697, 0.032975516082452874, 0.02642821124754846, 0.043112225364893675, 0.04045037319883704, 0.005658138975767153, 0.05716320978743689, 0.02431315482993211, 0.02397036742019866, 0.0637170234695077, 0.008977491574894105, 0.031633343281490464, 0.010062855834673558, 0.060970917610185485, 0.04657780226053936, 0.03413280505420906, 0.016787902917712927, 0.024345132489023463, 0.052895302551665475, 0.051095105042415004, 0.026222018026081578, 0.027459465732265795, 0.04543624512319054, 0.09125016962311097, 0.03032704462696399, 0.011973291535728743, 0.032878448255360126, 0.03235749281676752, 0.03878648658948285, 0.002156131747012426, 0.05886773046638284, 0.032182671661887846, 0.042066786105611494, 0.04450069121750338, 0.0254884148016572, 0.029832555446773767, 0.03199411017288055, 0.04905342370537775, 0.05001204101634877, 0.052122993993439844, 0.04392372610579644, 0.05791883995490415, 0.011068860335009438, 0.014773500384762883, 0.036567806000156064, 0.03771522228739091, 0.03051507007330656, 0.0626057256013155, 0.012808723358570464, 0.06594803982547351, 0.05213289721203702, 0.026908541098237038, 0.03309600015303918, 0.023192903692168847, 0.051053595662649186, 0.04232758443270411, 0.008529396378435194, 0.024462028805698668, 0.028028262978685752, 0.055380189392183504, 0.02000448969192803, 0.036434385659439225, 0.03459540308852281, 0.014349746783929212, 0.04805541404389909, 0.04368055611848831, 0.029863734130880663, 0.0321185874220516, 0.06429217689271484, 0.015604805866522449, 0.013350944932816284, 0.056077499474797926, 0.05342404757227216, 0.01732128402883453, 0.019793372002563307, 0.06388652830251626, 0.0691350848813142, 0.06151109255318131, 0.09191564284265041, 0.01676938060804137, 0.0311346064720835, 0.028024690491812568, 0.014868729381955095, 0.018739013400460993, 0.012109344592317939, 0.11535707355609962, 0.006240871635132602, 0.014129921793937683, 0.03337523427658847, 0.13579001570386545, 0.02090555875162993, 0.04996647399717143, 0.01664179057947227, 0.03908768489158579, 0.02328563228781734, 0.10303833136068923, 0.07376946548798255, 0.09714734461158514, 0.06771181696759802, 0.08856075536459684, 0.0489897398012025, 0.027196265391207168, 0.021662554470822215, 0.039378209837845395, 0.057765301050884385, 0.04316699671159897, 0.03788213850930333, 0.04622588685846754, 0.022811461838760545, 0.10523605200328998, 0.013725620943919888, 0.009480352180876901, 0.04137498912002359, 0.03708630853465625, 0.06199376165334668, 0.0708183945555772, 0.0798103813348072, 0.07399530908358948, 0.023310329266158596, 0.06679889559745789, 0.0356784399731883, 0.03974374004506639, 0.07869008609226771, 0.07765197501118694, 0.08429614920169115, 0.10220337366419179, 0.034482040242957215, 0.052282931482685466, 0.04194124694913626, 0.07090292644820043, 0.07160672332559313, 0.11764160596898623, 0.09245863370597363, 0.04239873561475958, 0.032775253257048984, 0.09599813699190106, 0.056182058328496556, 0.03987786266952753, 0.03612898722557085, 0.02954297366419009, 0.07678273772554738, 0.07477010107998337, 0.06522125418164901, 0.05515845093343939, 0.02660643355920911, 0.008701698472058135, 0.08990246336907148, 0.04189615151179688, 0.029664282154824053, 0.03088353155180812, 0.030851443630776236, 0.03981583099812269, 0.037711751580770524, 0.018105061525212865, 0.04515158950484224, 0.009377633853416358, 0.08438589224325758, 0.12067642169339315, 0.03448904611702476, 0.02109731105156243, 0.03924707955281649, 0.03703854984736868, 0.08408172535044806, 0.013234298825929207, 0.03737477073445916, 0.05081240699759551, 0.026211242889985442, 0.005684993271383324, 0.04242741728999785, 0.013539465709722467, 0.04766803840175271, 0.05057052283414772, 0.03096292693434017, 0.025263682307143296, 0.07454009806471211, 0.07001291242028986, 0.03524887980893254, 0.0427978906248297, 0.015966855189097778, 0.06141283389713083, 0.012603569143850888, 0.026742971768336635, 0.016934876995427266, 0.04089529539591499, 0.06121830469263451, 0.062388302625289986, 0.021202848692025458, 0.035001265417252264, 0.03591116052120924, 0.05968896818480321, 0.01853660640439817, 0.008143110633162516, 0.036754023150673935, 0.019786121855889047, 0.056056156155786345, 0.019131947940747653, 0.033873896447143385, 0.05822933079408748, 0.04314771953171917, 0.04089607571118644, 0.027932313038036227, 0.018754841926108514, 0.011440705158747733, 0.01653006300330162, 0.0637807243370584, 0.024354711707149233, 0.0636921144489731, 0.04802246777606862, 0.008566442694115852, 0.04594626936263271, 0.01726284689669098, 0.09675047626452786, 0.024212589154818227, 0.016728205406772237, 0.008246653380670717, 0.03735476752210941, 0.004020133812446147, 0.03755643830767699, 0.01359675866219082, 0.0300675897992083, 0.008548915286415389, 0.046454709222806354, 0.046229937712528875, 0.1362628053341593, 0.06189192033239773, 0.1712111993027585, 0.12606386760515825, 0.09996903927198478, 0.12470150499471597, 0.11932819975273949, 0.11846522534532206, 0.10664362540202481, 0.07753103292946305, 0.08024406020662614, 0.08886182813772134, 0.14994528756609984, 0.07893556649131434, 0.1924167349934578, 0.13854379579424858, 0.0979316360982401, 0.17040868236550263, 0.11189839736159359, 0.16358753267143453, 0.1799110360443592, 0.08548833522945642, 0.15037805720099381, 0.06682575201349598, 0.12815081062061445, 0.16420061620218412, 0.1041346336049693, 0.09035250850554023, 0.12985360782061303, 0.1635313228304897, 0.15933964561138833, 0.12605579303843634, 0.12449930155915873, 0.172628767522318, 0.07781909140092985, 0.10321386158466339, 0.2298232034913131, 0.09934401352490697, 0.21780195140412875, 0.22276747067059788, 0.19724000617861748, 0.17896738382322447, 0.22686515721891606, 0.13984279680464948, 0.16865241660603456, 0.195000487778868, 0.12589764009628976, 0.08086796637092318, 0.19860899129084178, 0.20084655550973757, 0.22601814195513725, 0.21884979946272715, 0.19307559249656542, 0.1147562036556857, 0.1643500296132905, 0.15467821859887668, 0.13186376781335898, 0.15251088275441102, 0.18773964739271573, 0.22838150656649045, 0.23261765497071402, 0.11662172712385654, 0.21732661048216478, 0.08075109549931117, 0.1878078265913895, 0.21016087356422627, 0.1262776061360325, 0.1529111098498106, 0.16726646811834403, 0.2234739206199135, 0.1778820263487952, 0.13958259219569819, 0.15019364495362553, 0.10848544085664408, 0.20550586549299105, 0.2671103041086878, 0.19219344268952096, 0.16872238713715756, 0.17797326216740267, 0.1490615364164114, 0.2250509038567543, 0.21736080864710466, 0.12819008422749384, 0.1379849679235901, 0.24216586404613086, 0.1595723152692829, 0.10636731915708099, 0.16075999582452433, 0.2020714876375028, 0.10938076781375067, 0.10181009476738316, 0.12387305444904737, 0.07442687771150044, 0.1756958408015115, 0.26659076341560906, 0.16164616255887918, 0.11631156876683235, 0.11555973839546953, 0.1288224517234734, 0.18428837401526316, 0.08514230951134648, 0.16099373756774835, 0.09923125457550798, 0.2579949732337679, 0.13504137444709027, 0.15168767049908638, 0.06568987760692835, 0.13985657106552804, 0.19124345295131207, 0.16303193462746485, 0.166372362524271, 0.1320423310888665, 0.10109696803348404, 0.17849858397884028, 0.09812791592308454, 0.18374547814684256, 0.1470750437251159, 0.06562772379922015, 0.15199379835809979, 0.13912447249250753, 0.16640045387404306, 0.13051116253648484, 0.17409444387469972, 0.183087787723967, 0.14498492516577244, 0.06773905336324658, 0.13115205243229866, 0.12724774836429528, 0.1860406907009227, 0.09489040821790695, 0.08731865630085979, 0.08510687641267266, 0.12265599332749844, 0.12086650649351732, 0.1347948219627142, 0.125126091497285, 0.10280101373791695, 0.17473206323172363, 0.14560152350791863, 0.13163557648658752, 0.13195566859628471, 0.15034560965640204, 0.1145268723900829, 0.17736933885940484, 0.06155310065618583, 0.09169520038579192, 0.10489814156400305, 0.11103513118411813, 0.11123933629798037, 0.08618161481406007, 0.16545817229364598, 0.23078086067523274, 0.1883237710488694, 0.11371911037713289, 0.08761301836264984, 0.08766111971012183, 0.09089554686631475, 0.14449001529387065, 0.06365041847207717, 0.1200740590159382, 0.1067176264311586, 0.08812389416354043, 0.18716019205749035, 0.07435145175882749, 0.13634759507008962, 0.09430623027895178, 0.14791634572403772, 0.13132164547485964, 0.10686991004539387, 0.11178309390587465, 0.20600006968847343, 0.07512585020491055, 0.14721296275300638, 0.08823419681617192, 0.11260697112551757, 0.13542385106640203], [0.033375543010021956, 0.07334694851722036, 0.04078421921336225, 0.047951296237962585, 0.02764500774044011, 0.0757898645741599, 0.02757043674189065, 0.019557318151263253, 0.03155848729823317, 0.04614853047366653, 0.0064230409001798505, 0.013008939534691828, 0.02065098598333342, 0.0556663004681468, 0.0282834226797734, 0.021283068494605165, 0.05603743876729693, 0.028687324042298963, 0.020712323852681687, 0.038975003973713944, 0.017025827829326903, 0.033169122479323826, 0.05976621261132615, 0.04745044579197254, 0.025353637390903065, 0.0864566182717681, 0.01367012526108218, 0.03409702251000064, 0.030811745939510207, 0.10462505157504763, 0.0869588970339724, 0.010841801313550344, 0.04537403364000576, 0.04884068940633109, 0.01742387004196644, 0.014088183408603072, 0.004718854399730584, 0.08490180955933672, 0.026580484683758447, 0.02391078695654869, 0.03991346540195601, 0.01635221897491387, 0.021360217926225493, 0.03029896006254213, 0.04396703021068658, 0.04926527251622506, 0.04218602167176349, 0.04671432350629142, 0.05554775022236364, 0.02099539339542389, 0.08670412070517029, 0.013182142383552023, 0.054803678898939064, 0.033573112051401816, 0.01684148682813559, 0.013791597448289394, 0.025846374254407625, 0.012862037551323218, 0.08141236180173499, 0.09740072994359902, 0.007734690227412752, 0.04495388814913375, 0.005314196360164455, 0.12620422935911588, 0.0022628281980619897, 0.07933025674096175, 0.024890165742752806, 0.0419540780463389, 0.055861633736640215, 0.010243508998038513, 0.04604840245363968, 0.06580361364675419, 0.007304795036491538, 0.08847046949501548, 0.024983981690768684, 0.14148766068475588, 0.298342266785247, 0.08311642107686826, 0.07906338891812734, 0.056098842793809514, 0.05468630251873817, 0.08850670326501131, 0.10911896186215536, 0.1290594640054873, 0.29043890801923616, 0.14478511017348084, 0.15212521702051163, 0.0590992873268468, 0.20620272095714295, 0.02564182478402342, 0.11934630306703703, 0.14949163262333187, 0.1519797526832138, 0.20874284394085407, 0.17803823868078844, 0.01808059185610286, 0.11825850286654063, 0.053761873194681745, 0.1342665824506964, 0.09601138199546508, 0.01956954874497439, 0.023825610455657755, 0.07453673253101961, 0.032077773540679894, 0.09453737323305436, 0.013343932273398553, 0.030014694601829563, 0.0747857006000621, 0.07944746688008308, 0.12209454631166798, 0.03115885052829981, 0.03218331627015557, 0.06685781279312712, 0.041542041048939736, 0.06426949346704142, 0.015602705800639731, 0.013641050035533096, 0.041875802246587615, 0.0654634843979563, 0.10461018487278904, 0.032705638956810744, 0.027066858585125635, 0.032435748260468245, 0.06620420036571366, 0.05223211260246379, 0.04616672878286668, 0.008265512413345277, 0.024221627241266624, 0.04016379393371088, 0.02508328529074788, 0.04758547426068357, 0.055726025120488236, 0.06272233184427023, 0.01080490682008011, 0.026731436673019613, 0.017466203841779913, 0.012403690538901304, 0.01355274803271251, 0.019657125563493798, 0.035403935238718987, 0.04501369083300233, 0.020027829600231986, 0.057970259338617325, 0.007624125490630311, 0.0470850852185062, 0.04038676732618894, 0.04689079010859132, 0.04087518701063735, 0.037067882916224856, 0.09347675514540502, 0.04791727449212756, 0.0510126223255481, 0.014289694738441279, 0.06149587979806321, 0.09293514170816966, 0.01759420777671039, 0.024841962615028024, 0.042851830766137154, 0.019010340894705484, 0.025071877420746853, 0.04530609532126358, 0.0337168020196259, 0.035892948641308715, 0.07685511027063642, 0.05548989154132349, 0.023032065447685972, 0.05156649349789534, 0.02700860974644976, 0.04576508015660303, 0.016596703623820628, 0.027998181824971522, 0.03409179100500686, 0.03952879711453404, 0.045121364162436554, 0.014742535439186862, 0.05190147266590169, 0.02465040878658848, 0.035142285350177965, 0.06154771987348795, 0.07142000405916146, 0.05512346227520278, 0.05172881264505642, 0.06651314414505448, 0.05436535206224237, 0.03345909441954323, 0.009964016183013362, 0.04437353375500866, 0.07265134155750275, 0.03987857173862202, 0.020693346924547638, 0.0037067006757882026, 0.024450849941266433, 0.021137816199500645, 0.01480361885790314, 0.020109360671735237, 0.003779704258444586, 0.02095052526731576, 0.022322453525183455, 0.026612309672470604, 0.021479970875329206, 0.035717730543443134, 0.05059910612180829, 0.011429821457048612, 0.021365973599521176, 0.015045935587425317, 0.04287516897810357, 0.08365384795303855, 0.010855561155559761, 0.047569566007171354, 0.041746928090495725, 0.0716047284326383, 0.009093455754087439, 0.029951862259102718, 0.034640474777136526, 0.03517849876412323, 0.01817507276843701, 0.011041494169538575, 0.04164973473442452, 0.03417436532410128, 0.05612663558817335, 0.07866863760032825, 0.05553217784368566, 0.01898739792938743, 0.027118625718035867, 0.033789374732545445, 0.02143563370087317, 0.10134497258280005, 0.02668287561807249, 0.0470235353069646, 0.0264046202812876, 0.06461932576660599, 0.01730250726853098, 0.06536071348403182, 0.04706881394875901, 0.021294937768418874, 0.027031101485980407, 0.03326900622674397, 0.07385115431887762, 0.038747311370181184, 0.027995174218501364, 0.02001262702313917, 0.03312262925984604, 0.00973467219487897, 0.04287777115990009, 0.03532095040593829, 0.028367815472717797, 0.00484051530448986, 0.02386135228776506, 0.03193276721451964, 0.07403463018792016, 0.10231223103723355, 0.3136458098888397, 0.1753936077335051, 0.0739996177809579, 0.041952598839998245, 0.04591143337477531, 0.028406429204291532, 0.12683986739388534, 0.18757412556026662, 0.18130948314709322, 0.37583704558866365, 0.13666038614298615, 0.12053662990885121, 0.07669676733868462, 0.2523139795022351, 0.08859582883971077, 0.12967968572463306, 0.13523774248148712, 0.22642051322119577, 0.41560145041772295, 0.3655136509665421, 0.09175373760185071, 0.11056405824742147, 0.04654992804197328, 0.13286748395434447, 0.12525950505265168, 0.041722154776964865, 0.062131517832832675, 0.06879540346562862, 0.08289936450975281, 0.04627216633941446, 0.0583542762324214, 0.049677370581775904, 0.06778116324650389, 0.009513272155475403, 0.010099727427586913, 0.03460512988801513, 0.016903063881077936, 0.0474839484585183, 0.040203905531338284, 0.03654295465509806, 0.06439050340226718, 0.03545848945421832, 0.0709664916087474, 0.01631925574370793, 0.007003627268464437, 0.013328560062551072, 0.02493231973078634, 0.010487019101024737, 0.03913959621318749, 0.02225918013469449, 0.06080443225800991, 0.019339294671746235, 0.015978042535217743, 0.03212203098727124, 0.0356939037862633, 0.01919126886475299, 0.03737813626815166, 0.024814827999632274, 0.05648745336968984, 0.05210177620340671, 0.03418008876698358, 0.0630266751561846, 0.01561009674333036, 0.037573320258940966, 0.015820047352463007, 0.012348663045226463, 0.03270739296983395, 0.021744843805208802, 0.039287442208400795, 0.018260897270270755, 0.021927817558337535, 0.023277437281129614, 0.007369065025289143, 0.04587542352133563, 0.05664521615420069, 0.08135243358888797, 0.09122182721538202, 0.05867968127131462, 0.0066132469884386015, 0.07639028664146151, 0.023284482170960734, 0.020656091959348748, 0.05818039484854255, 0.02007136949604111, 0.057662815121667724, 0.03441014267238123, 0.015135519173262375, 0.014307859120890498, 0.04076231949563537, 0.017649932465116893, 0.016252503164910843, 0.05092176987922617, 0.03402303165889212, 0.06172700918146542, 0.036197359806724956, 0.04618495084079249, 0.03889885198857103, 0.0015340532804007775, 0.03614393195935658, 0.02886952765818153, 0.02383129488277648, 0.06937187324677195, 0.13292444018380983, 0.12353960877018315, 0.11973215879074164, 0.10083540635449545, 0.12256259976753167, 0.10152528647865568, 0.1050790525706751, 0.09325216683958258, 0.07626846924956356, 0.08174487110227346, 0.12854278673018726, 0.08309000570859228, 0.13133319414087705, 0.13223318941891193, 0.09541667997837067, 0.16940628258245333, 0.04641292503635798, 0.08621873067958014, 0.12222027885062353, 0.1430030736540045, 0.16186410800686904, 0.13531149923801422, 0.07874850795737334, 0.07968483200030667, 0.1137679513277752, 0.07792494286383901, 0.14329263168786252, 0.04609896009787917, 0.1934558842331171, 0.2011481100427253, 0.09676098677196673, 0.20046240969427995, 0.15233499290687696, 0.12508637005729334, 0.18219662697187491, 0.1900573330266135, 0.1148884365601199, 0.07709024301064865, 0.1343659335481269, 0.1205008439719677, 0.1779300666281155, 0.20819582257952007, 0.087599488374378, 0.10149448098880903, 0.16683752542095526, 0.055622830122177086, 0.15009524380522116, 0.15302518515714578, 0.10063531316284623, 0.20584628651184694, 0.1656163523771933, 0.11411703723881926, 0.1907338188695056, 0.18442541094762938, 0.16540604723351343, 0.20663517846592835, 0.07832635061017104, 0.12241102861506598, 0.13109376627419675, 0.18549461928861483, 0.13192404886441572, 0.22838584919060978, 0.3170960790344647, 0.15416246413120202, 0.17192585952579975, 0.13986109010875225, 0.20469147419290884, 0.1402087171695062, 0.1410102570163352, 0.13166266360453197, 0.15169962628611497, 0.08294235648853437, 0.12233849322157246, 0.22157124057412148, 0.4110187334673745, 0.4268836150211947, 0.17668051724987371, 0.13879893853196076, 0.13866576924920082, 0.18806731195322104, 0.21240943005042418, 0.2459220439195633, 0.4480178366814341, 0.5059754209859031, 0.29292793731604305, 0.22095707138734205, 0.1945539303123951, 0.4130770287343434, 0.1900016660136836, 0.22270526258008821, 0.3333188199571201, 0.34910021456224577, 0.47891430450337275, 0.5308736392429897, 0.12477326685828821, 0.18283839896321297, 0.1382986003799098, 0.29926472157239914, 0.15216432777898653, 0.2728186292307717, 0.08099183293857745, 0.3161760669733797, 0.21706291820321763, 0.1475065919969763, 0.17166789408240998, 0.09612616297921964, 0.1728421396442822, 0.14525614918342658, 0.18692654530916894, 0.11290442052164248, 0.1785167008638382, 0.16200039855071477, 0.11949388443359307, 0.11591499218983309, 0.10168960730412177, 0.12404769579214708, 0.16932625616235392, 0.13897822105458804, 0.14301616937986442, 0.1100549805643303, 0.1464488101857049, 0.09850575136286871, 0.12829923337059362, 0.09665521673325982, 0.1764391487730401, 0.11354748172951595, 0.10371619462966919, 0.09420792412545, 0.09883743285068444, 0.05689252520512257, 0.12334447566952024, 0.07697110583207437, 0.18916139538799012, 0.13490602028157028, 0.12841542570718698, 0.1706410806093897, 0.120989769165005, 0.13714910777551786, 0.10216562676110438, 0.09277840011886188, 0.09041045539613281, 0.20741827573095048, 0.13088631097759518, 0.08749954016613108, 0.1977518658552851, 0.1589195645813431, 0.13518299827618258, 0.10277932097337075, 0.18930208283875669, 0.19386177031057222, 0.17422099065567764, 0.15463378812585557, 0.17030531434076174, 0.28538550489715164, 0.12639743542032583, 0.14359721248703344, 0.13515626399644784, 0.08720471670052835, 0.10589535733950989, 0.13009516628725187, 0.09845264921230928, 0.1041707248826112, 0.1661040290657963, 0.12087481176214558, 0.15463066686476978, 0.1496377076421465, 0.10959715263119765, 0.2146230148417609, 0.14912944420107774, 0.08096456261617796, 0.09956281392702035, 0.2045795294855322, 0.17718114038663252, 0.0852767883666924, 0.18732048917029584], [0.0497264184855989, 0.034936821553856134, 0.02950030398954238, 0.022448216598214846, 0.030834144380475794, 0.016984469423602735, 0.0241920448107911, 0.027861080431778516, 0.04298911875646029, 0.05423409964091011, 0.02630001732281276, 0.009785590310847121, 0.07856318647308008, 0.018998407160065005, 0.02776042145809957, 0.04078746261075139, 0.0375960443967155, 0.016357737160953026, 0.0459709782153368, 0.020084811274760535, 0.0019570775621104985, 0.02517613602269973, 0.03614358590649707, 0.01508333474131567, 0.026399517697947364, 0.019891510218647972, 0.10801675636321306, 0.038636849261820316, 0.03187213671792831, 0.07807024435273238, 0.014285526837089231, 0.006624088705783444, 0.0478336620144546, 0.044884935420538695, 0.030145214205341678, 0.05760704632848501, 0.010306526241557938, 0.017023956769012978, 0.06447989360562392, 0.05156539427116513, 0.027481375628017952, 0.02056736163129764, 0.01705149850541992, 0.049023222111697705, 0.011159301419476313, 0.035574675005461485, 0.012816187243775597, 0.03769623687756913, 0.036885350210858245, 0.03743571335715907, 0.11521702392825059, 0.011818938389686602, 0.036778826998280625, 0.033855409760560305, 0.028785358781793287, 0.04188385306458388, 0.046248906158975193, 0.0754619896677988, 0.01611206677210118, 0.07751350636993136, 0.04302210234371679, 0.011281987336198134, 0.05408716627529689, 0.03688249357842973, 0.03143127555293696, 0.06496475437389952, 0.0942072184490306, 0.026724288306598152, 0.06856570579111576, 0.02380262847457613, 0.026206503322880183, 0.10418746434152126, 0.03901429454396878, 0.021529564999842217, 0.08494787530175277, 0.3898820962224688, 0.4018861949443817, 0.07689158152788877, 0.20444450101682118, 0.13066756485828332, 0.03426781655954463, 1.109851177249636, 2.663499649081911, 2.900008729525975, 7.0016376205853055, 2.980063485247748, 1.0330242940357752, 0.8601553929703576, 3.505519049508231, 2.7290717533656528, 2.412540486880711, 3.153677906308855, 3.1645989545754025, 3.8778282829693387, 2.4115095479147772, 0.47320717360292164, 0.4899233994739396, 0.10058454517275095, 0.05866020731627941, 0.3696471777345453, 0.06085838257734265, 0.0492321735780154, 0.027483548636415174, 0.08660433534532785, 0.14168320090642997, 0.10204264228897435, 0.024820756699357713, 0.03229743907494204, 0.03991667826526931, 0.05080889218619891, 0.057951572484203746, 0.04653513937124184, 0.031213442063225166, 0.04408343628581081, 0.04991370772144624, 0.016858669031145315, 0.03254337748512626, 0.019732856856925145, 0.04686638320397053, 0.027524413407913277, 0.05591529907126512, 0.04448961752599903, 0.02546731914792742, 0.057000157822455676, 0.05308614391833544, 0.05111008031027658, 0.03405666324709143, 0.030084441216396432, 0.03205104943897043, 0.08140013460069895, 0.031177320251507417, 0.02400790567376784, 0.03875716369865196, 0.04587801213243178, 0.03302770560341222, 0.09696772960679871, 0.09336961446596043, 0.0034216990045803997, 0.01478298969699868, 0.04771503034446921, 0.028539576434663365, 0.04096325067803264, 0.0630897314154676, 0.029776382925254957, 0.02564959740266204, 0.13570526668003627, 0.028790105134248734, 0.014923341272931014, 0.033888413703867366, 0.013809163023584654, 0.018670881699238504, 0.04020344752020069, 0.07890959217080049, 0.0625023575765746, 0.03544713756335633, 0.03596298363325851, 0.03698132559657097, 0.015860762846257006, 0.08993070399654762, 0.07926456098045621, 0.041009116252618175, 0.058165847057742734, 0.04791856370866299, 0.028482850907104354, 0.030947948273803507, 0.0964425570730652, 0.035085617498095543, 0.05879140206213508, 0.04786503068836672, 0.03684908929946167, 0.02566264563107065, 0.03208939345287425, 0.056875789138887606, 0.058300353054489405, 0.014453815396076866, 0.05734605461891208, 0.03941091861841934, 0.011028068506025841, 0.011474809176953775, 0.0445483209831374, 0.04391715110146573, 0.0222722538081663, 0.05196397591914449, 0.030309952329844236, 0.0783035789749452, 0.021232129174417684, 0.03355472714507154, 0.036291791525270255, 0.022993723130119697, 0.004290198383387178, 0.01955975578831775, 0.05255634716844984, 0.004851468556028391, 0.005197495122307113, 0.05407168210617133, 0.09202798110033784, 0.026741431493844305, 0.018083450184868913, 0.013269328196266932, 0.021258057693817785, 0.030273314831512313, 0.03515993743868811, 0.06147754578185933, 0.03455084030117307, 0.0077308598972324815, 0.06651429765458618, 0.0702850388895188, 0.03421660073633705, 0.07627029450876371, 0.024747524111132537, 0.017236633392583047, 0.011979967472143471, 0.019223270272569995, 0.013134776398406496, 0.015040631139917033, 0.022737543930166533, 0.08730545879474708, 0.042173723224550486, 0.0352503556225981, 0.035200116889817376, 0.031662449041115384, 0.0237334399550621, 0.015519617491268685, 0.03538222551079733, 0.06774184214217321, 0.016024532362020442, 0.09225032345524856, 0.026898291826780354, 0.0319323329521077, 0.05308886145108512, 0.033158591615834405, 0.03063411225697824, 0.044669968741280694, 0.07568602836025612, 0.03566470303173576, 0.033637467705245526, 0.05653698981872626, 0.02491016386608992, 0.06907416600733995, 0.024322627178792442, 0.07892943932009594, 0.026662290561944246, 0.05091843827228461, 0.06496153133256094, 0.034958205584968836, 0.058097247167357376, 0.03524464235774108, 0.09320000785269908, 0.007320258001397763, 0.09328527934849262, 0.17095096755240644, 0.27312204294971054, 0.2032532785087824, 0.1397504210472107, 0.14871620280402048, 0.41030733021242277, 0.8216626441904477, 3.979660212993622, 7.2012554577418735, 9.061651263918195, 16.891369547162736, 9.44326022693089, 3.928572280066354, 4.895564368792942, 10.650381190436226, 9.116802590233938, 8.869485804012843, 9.655324459075928, 9.17306215422494, 12.666742341858999, 9.656549947602407, 4.106619434697287, 3.040563838822501, 1.1514484137296677, 0.11186518307243075, 0.21152064417089733, 0.17605144743408474, 0.026314061301361238, 0.031763954487230094, 0.09265876082437378, 0.08205002187086002, 0.02720890480226704, 0.004547003107810659, 0.04285199700721672, 0.026989103561001163, 0.022846358894769634, 0.054043587363724194, 0.04539376204567296, 0.02548789741870548, 0.018974982434883714, 0.029666019204471792, 0.08847531423504863, 0.025972505432686636, 0.03890545752697757, 0.014299272260229503, 0.007197127644238728, 0.03863854899204203, 0.044729506796492, 0.04255635251424142, 0.0646460804023913, 0.057373019600553174, 0.008087192562275698, 0.026195110719917074, 0.07359602515186582, 0.0047142246704814685, 0.021287611286555017, 0.05603659399119871, 0.08958780632487365, 0.03351270207869155, 0.04567515730325665, 0.05130744918382593, 0.028015915337683897, 0.0645520965169583, 0.03006786460589085, 0.015189988571884376, 0.027310513724972094, 0.03575963686619486, 0.037059479260018895, 0.06983658831034388, 0.03281287123848285, 0.01741231119792376, 0.01408986871995564, 0.02835175963783903, 0.007092726125847548, 0.026687618577852845, 0.014062436397320457, 0.03734806359612516, 0.037196624757988114, 0.039988881176603694, 0.08661508334002324, 0.06303207629493304, 0.012885731146005648, 0.03270383066098605, 0.011845439423008688, 0.06440376197653157, 0.0696076505950519, 0.017915114128429974, 0.041471079856689484, 0.0586813979649118, 0.04403117212599941, 0.06885743513703346, 0.02547611465810665, 0.04913957729669554, 0.06279200381998505, 0.018628515669011643, 0.01577347779779562, 0.02960174497483032, 0.025943825453785912, 0.09756083706659929, 0.033595954932804616, 0.01753772482542055, 0.025771728617006114, 0.14837386831641197, 0.05732881982943841, 0.19937150180339813, 0.1051962762804968, 0.08196271477001053, 0.12555092227246079, 0.11246209711368595, 0.13551991805434227, 0.1599017847329378, 0.11586076367114272, 0.12744778048779282, 0.12045946690653052, 0.1309215405157634, 0.13354396979723657, 0.2067557405680418, 0.16068642905780248, 0.10796601551451854, 0.10927680267819337, 0.21184384397097997, 0.23461178796631948, 0.16127505818647997, 0.0929643390700221, 0.08280189295432397, 0.052598823460617235, 0.11766178560044084, 0.14142946952155658, 0.11176274464066539, 0.15932060591876507, 0.10833598673343658, 0.1360794244600194, 0.22078867256641388, 0.20654052283082688, 0.1635944672993251, 0.0874487314639347, 0.1100303293871028, 0.2184911665639707, 0.12930931417005403, 0.08348495380154677, 0.12524706072040967, 0.1263115464576653, 0.17141071573964187, 0.08191789753202881, 0.0939447068210159, 0.1133263132401875, 0.11249486356973648, 0.1279521355671542, 0.0958159299833434, 0.20474764332175255, 0.27028812787362505, 0.12782056762703828, 0.2535862326622009, 0.08367613104305097, 0.10960819918130126, 0.16662716599447386, 0.11133726247187171, 0.11789590732327529, 0.12535059159355505, 0.17876724313412393, 0.14855435863137245, 0.12454603905124323, 0.12800031155347824, 0.10015602316707373, 0.13492883262889727, 0.1374160841639553, 0.13046982618314878, 0.13049373775720596, 0.20031740676079476, 0.07458883044975144, 0.1965761003749711, 0.16430344139891012, 0.14902129928980554, 0.19838318840733596, 0.07504336070269346, 0.14375869025077137, 0.2360758494053568, 0.5921842721956116, 0.515007210629327, 0.24110398388334683, 0.1769438295492104, 0.2021463979035616, 0.4452943599649838, 3.0275007912090848, 5.786853228296552, 6.834569488252912, 12.977371982165746, 8.089079771723066, 2.492263900382178, 3.9916376045772006, 8.944613201277596, 7.858970199312482, 7.50389119556972, 7.33247218813215, 7.102005217756544, 10.013484120368958, 6.759840743882315, 2.521562499659402, 1.5516176436628615, 0.4545990563929081, 0.09258630006973233, 0.46652794629335403, 0.2672470967684473, 0.08868359055902277, 0.1194482325975384, 0.19867893468056405, 0.21622742446405546, 0.2292417532631329, 0.14405535933162483, 0.1767879564847265, 0.15161164743559702, 0.23875752836465836, 0.11810147629252501, 0.21366585977375507, 0.12353886238166265, 0.13290550905678952, 0.1413180540714945, 0.1453338550137622, 0.11114419211766549, 0.07763868251017161, 0.08517023801271405, 0.10109716480863945, 0.127933353717838, 0.155060898778694, 0.10680750517972878, 0.2588321497397763, 0.15193935270820344, 0.21860392551336968, 0.12141405711216585, 0.14983208078358853, 0.14828089544815676, 0.11347217791314636, 0.10156174416520766, 0.16733291026737007, 0.1270651410200766, 0.13385100689317497, 0.17860915804547922, 0.17705204231398447, 0.120593165446605, 0.12936808887336934, 0.05913199271474566, 0.12804455203669413, 0.1168850122817925, 0.11339959502220154, 0.10020110503371273, 0.1694499123841524, 0.14629631622561387, 0.1817875789212329, 0.0684703987623964, 0.05989758377628667, 0.1255463489464351, 0.07279544203941311, 0.0940409434427108, 0.08130613714456558, 0.1547422180218356, 0.10733691177197865, 0.18052509666553565, 0.07929411118051835, 0.11779899895191193, 0.10005234980157443, 0.16844606053616318, 0.10931617127997534, 0.18031092387224945, 0.2380170023867062, 0.15040815701442106, 0.1336565116154296, 0.14032226321952684, 0.19354049754994257, 0.11990514450839587, 0.1393151951155492, 0.09030421038291284, 0.0905967132587518, 0.0827799423464707, 0.10730139724910259, 0.17273270551647457, 0.17062989835228237, 0.11029394024184772, 0.1174549681267568], [0.026247147570497224, 0.015827334818563292, 0.041437875745551925, 0.07407856533037764, 0.08001432860536234, 0.055711541790515184, 0.03852249914780259, 0.0362925718405417, 0.08492522580283028, 0.11125591969383614, 0.03135481144168547, 0.06213755000914846, 0.023801386755492007, 0.043716535437852144, 0.06372880962278162, 0.04830721499664443, 0.0569600835442543, 0.028305770230612586, 0.05314839272094624, 0.009903954807668924, 0.03247036711711969, 0.10904174457703318, 0.026565402546631436, 0.03019198223150202, 0.02702834493746715, 0.02766676666215062, 0.10904458763876132, 0.010204346501268446, 0.019383966024698954, 0.06616082162197147, 0.024619130018566335, 0.011221643520652183, 0.06444568865533386, 0.09592675510793924, 0.03480340460581439, 0.0237074605455356, 0.0913734594359994, 0.024928923663018004, 0.010485533957502671, 0.038816009648144245, 0.08038330916315317, 0.04885159346408077, 0.01663315961403506, 0.05716477720332997, 0.02979221993259021, 0.02300163993744978, 0.05589698880378689, 0.022789309366739223, 0.006556593555225325, 0.053931588373546085, 0.09197002742439508, 0.04598173978073256, 0.07672397659293242, 0.0005843456113195446, 0.02826007259344416, 0.03468654391222766, 0.04142026436914291, 0.012042173866315611, 0.02037899861378329, 0.04330892248877457, 0.012872055272704788, 0.011239248111711016, 0.006795479017975075, 0.07951687422714063, 0.1027653431519866, 0.018683548251699125, 0.06319672281720809, 0.009027989847319466, 0.12873561281178678, 0.062166224899036546, 0.11223311868629285, 0.16778903507760592, 0.6032990014978817, 0.17086110237453664, 1.7761309849364417, 10.449721557753426, 20.268426827022008, 38.94049113137381, 37.38407032830374, 43.656907490321565, 56.20247411727905, 63.57843508039202, 80.38600935254777, 87.31001431601388, 105.42776870727539, 85.56129169464111, 82.55900982448033, 78.81504944392613, 87.02859837668282, 91.70064353942871, 92.32960142408098, 94.84443937029157, 85.01407241821289, 93.69561031886509, 89.48373045240129, 77.21758215767997, 73.32739693777901, 60.424272537231445, 39.997266973767964, 16.576914923531668, 3.1277767590114047, 0.4666426458529064, 0.11226257389145237, 0.29301324273858753, 0.41157488791005953, 0.2077471073716879, 0.016946123713361363, 0.02549999569808798, 0.020657664464254464, 0.0615361440660698, 0.055605055897363594, 0.04941032633983663, 0.033089523536286185, 0.03526926300089274, 0.10672919545322657, 0.0034821327260163215, 0.004338591500917184, 0.04192219029313751, 0.03363671113869973, 0.05746617567326341, 0.07379913782434804, 0.006020191691017577, 0.028286311542615294, 0.03678307123482227, 0.007550211822880166, 0.09151798060962132, 0.02395270176098815, 0.013368664874828287, 0.031169072658355747, 0.0503841801546514, 0.04255681052537901, 0.005845616505082164, 0.09954349603503942, 0.02301780433793153, 0.010629884649201162, 0.035826665948012044, 0.07877186313271523, 0.06114985407995326, 0.00782909310821976, 0.03949544372569237, 0.021606688986399343, 0.03167462195934994, 0.05703681906951325, 0.01737055754555123, 0.04284141186092581, 0.05186450947076082, 0.022387599672323892, 0.05333459969343884, 0.014597289929432529, 0.031151081302336285, 0.058459686647568426, 0.039416387610669644, 0.0172334188329322, 0.01657173183879682, 0.01214800073233034, 0.0521633770050747, 0.021674652750204717, 0.05778342472123248, 0.022209396020376256, 0.047210196897919686, 0.012510173887546574, 0.0653500265574881, 0.028811607908989702, 0.05330624032233443, 0.0592187230608293, 0.0258680008617895, 0.0845368459288563, 0.008015028666704893, 0.06176694096731288, 0.0670378552749753, 0.07660276988255126, 0.0019455789380507277, 0.004704497446904757, 0.03810528492821114, 0.04633865598589182, 0.052758550604007075, 0.05437353519456727, 0.016860421347830976, 0.03271668211423925, 0.03512184448274119, 0.04562413486252938, 0.00918803844667439, 0.028669305544878756, 0.056445611507764885, 0.03600121568888426, 0.06173124323998179, 0.02123799341331635, 0.03700665191614202, 0.02562756197793143, 0.04988030344247818, 0.03813385125249624, 0.049735239440841336, 0.07687697945428745, 0.039690807528261624, 0.02552557477195348, 0.045298790891787837, 0.07892614163990531, 0.0751631221334849, 0.05044757228876863, 0.07526206610990421, 0.02744429708192391, 0.031216424224632125, 0.06262283825448581, 0.025875544474859322, 0.01733104475507779, 0.030153332876839807, 0.014445316744968295, 0.018751695219959532, 0.0480886961865638, 0.05540938336136086, 0.006916806168322052, 0.027954005802582418, 0.14931106088416918, 0.028256272797339728, 0.04148099325331194, 0.08644443856818335, 0.0328339295727866, 0.03392234045479979, 0.03135653831330793, 0.008694051382397967, 0.022407719931964363, 0.017075732383610945, 0.038881467921393256, 0.007908602145367434, 0.03371468838304281, 0.09205198766929762, 0.007991603941523602, 0.057757050065057616, 0.03217585917030062, 0.010922598719064678, 0.027783249072464447, 0.06946878161813531, 0.07127648033201694, 0.01104984269477427, 0.044491157800491364, 0.041417258459010294, 0.029648434969463518, 0.03944687418905752, 0.012126374124948467, 0.13990748833332742, 0.10310071587030377, 0.015611743887088128, 0.04386960615270904, 0.016337912064045668, 0.14021703600883484, 0.06641414588583366, 0.08032717396106039, 0.22072585379438742, 2.3535557091236115, 1.025144168308803, 6.632624438830784, 22.02327949660165, 37.76290348597935, 61.02783475603376, 60.117426191057476, 68.09304795946393, 80.77055740356445, 89.22008800506592, 104.73847961425781, 111.70315933227539, 127.02332578386579, 110.86714512961251, 107.41390432630266, 107.31861673082624, 111.50797053745815, 117.62772151402065, 120.09980719430106, 122.68998445783342, 112.04033456529889, 120.62616103036063, 116.07473659515381, 109.88276604243687, 100.6019321169172, 89.28192697252545, 68.24229526519775, 34.27978195462908, 10.564111488206045, 0.9930092926536287, 0.17908095701464585, 0.10082551331392356, 0.1456881452883993, 0.29563895612955093, 0.12847752523209366, 0.021123069937207868, 0.08674405249101774, 0.011178758411136056, 0.08647155961287872, 0.015291365096345544, 0.08448524334068809, 0.042666851942028315, 0.04415806156716176, 0.045658587478101254, 0.044345038676900525, 0.059382134649370394, 0.015553369519433804, 0.049499560480139086, 0.11046408968312399, 0.03884056243779404, 0.017255199807030813, 0.06072648894041777, 0.03218766228695001, 0.011467846559493669, 0.04255216595317636, 0.01421873948337244, 0.06981615762093238, 0.019741482733349715, 0.027448868711612055, 0.047388258057513406, 0.01062395510130695, 0.037958022473113875, 0.03387400840542146, 0.02125883800908923, 0.016786757889868956, 0.051723567569362264, 0.008297489224267858, 0.014547434568937336, 0.023342776810750365, 0.029870787502399514, 0.1289608185844762, 0.03189544439581888, 0.041056260865713866, 0.057834348774382045, 0.03961429252688374, 0.02820900435160313, 0.030739716054605584, 0.025588817628366605, 0.009968991541037602, 0.023714159382507205, 0.040574687599603615, 0.024592232890427113, 0.033966889671449146, 0.011188695556484163, 0.04382216637688024, 0.0923382548083152, 0.03161307204780834, 0.0357103684384908, 0.0057064112292469615, 0.007857753579238696, 0.039883423264005353, 0.02640890353359282, 0.03649415780923196, 0.014922661041574818, 0.05737166931586606, 0.018736392558951463, 0.07435443731290953, 0.006070231952305351, 0.06185059076441186, 0.04124825234924044, 0.00962974947677659, 0.024637966150684015, 0.013196912394570453, 0.03864634196673121, 0.12166366300412587, 0.19343858159014157, 0.11088700698954718, 0.12796415920768464, 0.20000325861786092, 0.12845012598804065, 0.11813604086637497, 0.16319080681673118, 0.14491480535694531, 0.2034222608698266, 0.0806615153061492, 0.17562563956848212, 0.054850521563951454, 0.13843808003834315, 0.1515382163758789, 0.1627366497580494, 0.17858086313520158, 0.16765513297702583, 0.11222197035593645, 0.08567784327481474, 0.17593727713184698, 0.1850369202771357, 0.16852057725191116, 0.13843471450465067, 0.10207110004765646, 0.10293699215565409, 0.22978422843984195, 0.11107690179986612, 0.07997316867113113, 0.20929944621665136, 0.06674829045576708, 0.05368007240550859, 0.09694242025060312, 0.17332406235592707, 0.09042430429586343, 0.07866742302264486, 0.1907714232802391, 0.0792266647996647, 0.11500871367752552, 0.19205313521836484, 0.16060797683894634, 0.12444686437291758, 0.09919066461069243, 0.1334617313529764, 0.18812107906809875, 0.08373519751642432, 0.1296493552092995, 0.055855272470840385, 0.12096782534250192, 0.1299300380051136, 0.13794665783643723, 0.15304512051599367, 0.1641092582472733, 0.0816943948822362, 0.16043062135577202, 0.1463993585535458, 0.13614772579499654, 0.11148877255618572, 0.10824573479060616, 0.14905974508396216, 0.1381201185286045, 0.1983368851776634, 0.11749888291316372, 0.2500514180532524, 0.23848644005400793, 0.23122611535446985, 0.10640974795179707, 0.12840876249330385, 0.30853869393467903, 0.16417580896190234, 0.20262158954782145, 0.21314521985394613, 1.578780431832586, 0.7519007761563573, 4.336962640285492, 18.31094557898385, 33.28676625660488, 58.61344691685268, 58.064688614436555, 66.23821939740861, 82.54149341583252, 92.96623706817627, 114.57159805297852, 122.23264013017926, 141.30059541974748, 118.13266100202287, 116.80237279619489, 116.64652470179966, 124.29533794948033, 129.83449745178223, 131.36489377702986, 132.55188233511788, 121.15844862801688, 132.8181928907122, 128.40373829432895, 116.03170640127999, 104.94748837607247, 91.95371082850865, 66.28140939985002, 28.425723143986293, 7.747002584593637, 0.7270003323044095, 0.16840316355228424, 0.6147422503147806, 0.47145036501543863, 0.4872254356741905, 0.19920329297227518, 0.1179987732321024, 0.10896885634532996, 0.17105512267776898, 0.1944948434829712, 0.15273147448897362, 0.17504471859761647, 0.1271621850984437, 0.15517783750380787, 0.10669107535587889, 0.12881555780768394, 0.1859829066587346, 0.13051090469317778, 0.15472087131014892, 0.16310924690748962, 0.06273345981857606, 0.11446230299770832, 0.21259382872709207, 0.1355519720486232, 0.12377347264971052, 0.13246539767299378, 0.13290720539433615, 0.10377150201903922, 0.1073275479887213, 0.11844812626285212, 0.08049106052411453, 0.1932425256818533, 0.12364145687648229, 0.10884249955415726, 0.10775127275181667, 0.14979583344289235, 0.20758605029966148, 0.07566886142428432, 0.16939944294946535, 0.1558046138712338, 0.1242000540452344, 0.190815446632249, 0.17554289900830813, 0.19327778236142226, 0.10242358541914395, 0.14660095130758627, 0.17538570958588803, 0.1530440484306642, 0.13729271292686462, 0.1211392232882125, 0.10916492582431861, 0.1253677856709276, 0.2045669223048857, 0.22069647322807992, 0.08867723268589803, 0.11536198614963464, 0.16396622306534223, 0.13676572191928113, 0.13061994527067455, 0.08241050038486719, 0.15960856260997908, 0.18449521863034793, 0.13737910400543893, 0.1370904009257044, 0.11359820900751011, 0.23099193934883389, 0.18423474260738917, 0.2378567595567022, 0.13026562785463675, 0.18719691437269959, 0.10320152581802436, 0.23415288116250718, 0.11183559216026749, 0.10277530404606036, 0.17096441611647606], [0.04250328768310802, 0.04824807049174394, 0.012732146440872123, 0.036157156606870036, 0.08258799836039543, 0.04779094484235559, 0.03042420744895935, 0.025850340291591625, 0.051405541598796844, 0.005761371293504323, 0.04511284176260233, 0.10156947267907006, 0.01151006924919784, 0.07537662317710263, 0.012897803980324949, 0.14535075053572655, 0.016808979911729693, 0.059072268062404225, 0.0935092434020979, 0.012448072666302323, 0.015921534138864706, 0.05746197554149798, 0.0044314973638392985, 0.03665378995771919, 0.03622595666508589, 0.026797773649117777, 0.06184777484408446, 0.04127643869391509, 0.036833103014422316, 0.09458271294300045, 0.04420986432316048, 0.026561804614695053, 0.03082431240805558, 0.04526655708572694, 0.016559440176934004, 0.05091658926435879, 0.026855908833178024, 0.06021355039307049, 0.010397818039304443, 0.03198839012267334, 0.012294917982736868, 0.06208332149045808, 0.034849718013512235, 0.02389159289720867, 0.06879197007843427, 0.00874503904820553, 0.015681878962953175, 0.0035154352247315857, 0.009557945204765668, 0.07941240697566952, 0.03460827150515147, 0.05357540498620697, 0.08543531450309924, 0.019815933291933367, 0.025477593864447305, 0.057917747513524125, 0.04409310540982655, 0.09313893970102072, 0.03892448704157557, 0.03646781029445784, 0.0599863293713757, 0.06574568711221218, 0.07375675652708326, 0.02051843756011554, 0.2500429227948189, 0.09457868244498968, 0.04820912258167352, 0.9318435404981885, 2.835437600101743, 14.627799306597028, 26.277618067605154, 36.901521410260884, 55.40908363887242, 55.69629437582833, 75.53732013702393, 83.23529883793422, 90.49111502511161, 94.03118051801408, 96.90856851850236, 104.00788348061698, 105.85627801077706, 100.35561152866909, 98.54985114506313, 97.15084525517055, 93.06931359427315, 104.43959590366909, 101.25166511535645, 97.04836627415249, 100.55617128099713, 95.40636798313686, 101.88608428410122, 89.8444322858538, 99.25482927049909, 103.23987824576241, 108.2639330455235, 101.49233681815011, 105.84203420366559, 105.10398265293666, 107.79060091291154, 106.97414588928223, 83.26570415496826, 50.00938490458897, 41.248936312539236, 24.88331437110901, 12.090292862483434, 2.2924819120338986, 0.060935484511511664, 0.01987682163183178, 0.30015688655631884, 0.10795256695044891, 0.03894398135266133, 0.08370441916797842, 0.015825390815734863, 0.005710902706986027, 0.06187087217611926, 0.0363385595514306, 0.02969042950176767, 0.05453506724110671, 0.05277010266269956, 0.03774188871362379, 0.03034666446702821, 0.06059260041053806, 0.03409608952435, 0.08250315434166364, 0.05613356003803866, 0.027533493902800337, 0.022266562595697384, 0.029548025357403924, 0.04154939976121698, 0.05464000268174069, 0.03543043203119721, 0.03300831985792943, 0.0536171620312546, 0.018221311537282806, 0.027418426238000393, 0.04115209375907268, 0.0888899601995945, 0.02601185707109315, 0.09500007304762091, 0.015016322622873952, 0.025423400968845402, 0.021514891680063944, 0.02182515012100339, 0.01458200762447502, 0.030363760156823055, 0.0715288275054523, 0.06720377065773521, 0.04734344421220677, 0.04403491085395217, 0.03676898484783513, 0.07062116478170667, 0.05127455380612186, 0.03407761640846729, 0.042210564283388, 0.026769991032779217, 0.03923099148752434, 0.049054634890386035, 0.06653069106063672, 0.010469816541964454, 0.019945616601035, 0.03869250270404986, 0.055948604962655475, 0.014797610430313008, 0.02337764502902116, 0.06859692518732377, 0.03827185509726405, 0.0701944748205798, 0.05378015632075923, 0.04162076468180333, 0.017976625024208, 0.03418493350701673, 0.03233206471694367, 0.021610926437590803, 0.025766566661851745, 0.023739015816577842, 0.03634971805981227, 0.03765294973605445, 0.011935414014650243, 0.003843040837507163, 0.05076965589874557, 0.03839148082105177, 0.060324904774980884, 0.053993735395904095, 0.03522354331133621, 0.03655492740550211, 0.04484068136662245, 0.04984252600531493, 0.06903216468968562, 0.02683044002125306, 0.055992170303527794, 0.04095178682889257, 0.032561256882867644, 0.04578114447316953, 0.03780352344204273, 0.021900453937372992, 0.0095773580916492, 0.05578361578019602, 0.0067009671474806964, 0.049988628165530305, 0.08686746444020953, 0.027970562057037438, 0.02891027368605137, 0.04576912422531417, 0.06399990471878222, 0.029722330825669423, 0.03149750057075705, 0.04623220401949116, 0.030438035992639403, 0.03583771249811564, 0.02529104762444539, 0.05119600998503821, 0.01094819899714951, 0.020343877641218047, 0.03413832832926086, 0.04590037325397134, 0.048158927953669, 0.02261950258564736, 0.018960046182785715, 0.012719193207366126, 0.02569206351680415, 0.029253676866314242, 0.01442639749231083, 0.032676031081272025, 0.05422424391976424, 0.011598426382988691, 0.05780413361000163, 0.028044220425986817, 0.044660727094326697, 0.022536538108917217, 0.03234993054398468, 0.05678113689646125, 0.04500145006126591, 0.048679920711687634, 0.0430238054666136, 0.03730636422655412, 0.028232296762455786, 0.04540863214060664, 0.03483516683003732, 0.013999648159369826, 0.0407270628160664, 0.12032154787864004, 0.05561768004138555, 0.2773599826863834, 3.2311357728072574, 8.003096682684761, 25.870873996189662, 43.66362987245832, 58.67750930786133, 78.47083568572998, 83.52979128701347, 97.99975531441825, 103.33624281202043, 107.60675852639335, 105.95467145102364, 110.55660928998674, 120.52154895237514, 116.13456753322056, 110.53016444614956, 108.74003056117466, 110.38727474212646, 100.50580378941127, 112.68017332894462, 109.44802420479911, 104.478394644601, 113.50859315054757, 105.1054904120309, 112.9033008302961, 100.26963451930455, 106.56855869293213, 112.84036404745919, 118.56140654427665, 112.03893797738212, 114.62589822496686, 115.1126264844622, 122.75564493451799, 123.36215318952287, 110.1017176764352, 80.18905571528843, 69.44219357626778, 47.347411905016216, 29.18151691981724, 8.677333371979849, 1.7421929431813103, 0.030118890439293215, 0.06907008122652769, 0.10479505852396999, 0.09276698715984821, 0.01840185104603214, 0.05791023613086768, 0.053698664265019555, 0.007844707047167634, 0.040020796071205816, 0.01876142032311431, 0.06388395665479557, 0.04635616897472313, 0.059203591729913435, 0.004213906026312283, 0.021929066062771847, 0.0402088690149997, 0.0205147938270654, 0.027888506817232286, 0.038075429387390614, 0.058795507198997905, 0.01569859976215022, 0.017994019269411052, 0.024933110224083066, 0.04050428959141884, 0.01433839150039213, 0.0459945708779352, 0.006414678804243782, 0.06732359994202852, 0.09181993547827005, 0.0394715864344367, 0.08222013738538538, 0.04728714276903442, 0.01580602881897773, 0.012587204575538635, 0.05264160170086792, 0.020149192373667444, 0.06035936078322785, 0.04853298056072422, 0.013793571137024887, 0.05897639784961939, 0.05704109384013074, 0.03412680680464421, 0.0704776681959629, 0.01751331452812467, 0.029287617187947035, 0.013595372754415231, 0.043878111589167795, 0.03347497892432979, 0.029086085502058268, 0.07938346745712416, 0.047066262657088895, 0.02268463176941233, 0.04558755164699895, 0.09074408427945205, 0.07609059129442487, 0.02740381229003625, 0.041109261236020496, 0.035595984397722144, 0.04045826456110392, 0.03542267298325896, 0.06372209891144719, 0.0377507198468915, 0.023459152351798754, 0.03839861900944795, 0.010543144973261016, 0.05195587760369692, 0.04020627361855336, 0.05759485983955009, 0.018454281446923102, 0.2088121087955577, 0.08698652019458157, 0.07529677317610808, 0.2005557082593441, 0.1518700878534998, 0.1557724377406495, 0.12635004653462342, 0.13006472720631532, 0.11264855175146035, 0.10257708361106259, 0.09494178688951901, 0.18300660779433592, 0.10477690771222115, 0.11046732629516295, 0.14258772879838943, 0.15210321891520703, 0.13872820804161684, 0.12291642863835607, 0.18485362082719803, 0.06791720273239271, 0.15947889456791536, 0.12942269737167017, 0.22318057636065142, 0.16412016909037316, 0.08185300922819547, 0.11057451447205884, 0.12158177739807538, 0.13681657133357866, 0.13285524318260805, 0.21122337797922747, 0.12716025805899075, 0.12696706556848117, 0.1391498361315046, 0.1522390344845397, 0.11991746670433454, 0.1293666503791298, 0.10015308511044298, 0.17385215259024075, 0.15557235133435043, 0.15853336959012918, 0.11438724345394544, 0.12044132288013186, 0.10386444774589368, 0.10931887184934956, 0.2098961906241519, 0.1354479119181633, 0.07885584541197334, 0.06148891124342169, 0.15700704577778066, 0.271547868847847, 0.09134946643773999, 0.1400247256138495, 0.1289670882480485, 0.19419946361865315, 0.174217109435371, 0.0972891855718834, 0.16191236541739532, 0.15695730916091374, 0.1641912388482264, 0.11601541537259306, 0.18869744028363908, 0.13669322723788874, 0.13632544768708094, 0.1043660140463284, 0.37928202216114315, 0.1425324281943696, 0.1877850413854633, 2.193009112562452, 6.979846332754407, 24.73721981048584, 43.598890032087056, 57.69998114449637, 80.67451245444161, 84.28506047385079, 106.51514789036342, 115.80609839303153, 122.01637050083706, 124.75088964189801, 130.09390149797713, 133.77751677376884, 131.57224191938127, 127.70743152073452, 120.62506321498326, 121.00126647949219, 112.80496992383684, 127.84016990661621, 124.86278343200684, 119.89882360185895, 124.82773671831403, 120.40730667114258, 126.67130225045341, 114.75308500017438, 122.31995119367326, 125.5344102042062, 130.54672949654716, 123.27648190089634, 131.5346243722098, 132.25912693568637, 140.33055741446358, 142.20490346636092, 119.03200803484235, 84.02138328552246, 69.69371141706193, 47.94141687665667, 27.078389269965037, 6.529190514768873, 1.1117585663284575, 0.17919299671692507, 0.3780376160783427, 0.2906913773289749, 0.12885437001075062, 0.15009805294019835, 0.16106852569750377, 0.13086490998310701, 0.1920508417700018, 0.1456062596823488, 0.09325619055224316, 0.12634992439832005, 0.10000326457832541, 0.1370533529136862, 0.0888583811798266, 0.14485650562814303, 0.24396121342267307, 0.16284997867686407, 0.12119900222335543, 0.19714197143912315, 0.13475303777626582, 0.10121889399098498, 0.16508462519517966, 0.14663916639983654, 0.13582857006362506, 0.07967613996671778, 0.20806390180119447, 0.07767736579158477, 0.17116081129227365, 0.13913911527820996, 0.1750049971576248, 0.21799044843230928, 0.15508409110563143, 0.11512854296181883, 0.16452445382518427, 0.1605262133691992, 0.09691336538110461, 0.15500914012747152, 0.24778918230107852, 0.12462225210453783, 0.13601903484335967, 0.17251193736280712, 0.1409934836306742, 0.10599464058343853, 0.11148752405175141, 0.09968685012842927, 0.07818250797156777, 0.09859229850449733, 0.20334455503949098, 0.1140664592385292, 0.1624427626707724, 0.1662289880748306, 0.13398201843457563, 0.11602982745638915, 0.20914005834077085, 0.15066069417766162, 0.09373723795371396, 0.12490118428000382, 0.16738765447267465, 0.13412567786872387, 0.12127480815563883, 0.13102589920163155, 0.09888497779944114, 0.1465175322123936, 0.11919618397951126, 0.13285429323358194, 0.1420787325395005, 0.12444085255265236, 0.1423338617065123, 0.12728984467685223], [0.02680955471337906, 0.010521218962302166, 0.09460537601262331, 0.03047246825216072, 0.031073612959257195, 0.028168656963056753, 0.06345326333705868, 0.12006650013583046, 0.05964563015316214, 0.02710092782841197, 0.016838984730254327, 0.019349973116602217, 0.08952363048280988, 0.08334303820239645, 0.008941672559428428, 0.02855404619393604, 0.008467655628919601, 0.08900695999286004, 0.01641686470247805, 0.06603259207414729, 0.03909676029746022, 0.02031213407670813, 0.021247689678732837, 0.03685061600325363, 0.047057635084326775, 0.00392680471330615, 0.030863270496151278, 0.05689616893817272, 0.08142737099634749, 0.016471424006990025, 0.02890858074117984, 0.051868238020688295, 0.020228843903169036, 0.03666356425466282, 0.01811670688247042, 0.04755248049540179, 0.029271512159279416, 0.08876976450639111, 0.0295759504660964, 0.04561876765053187, 0.016284183964931538, 0.03674547021676387, 0.028671663454068557, 0.020382827247626016, 0.06456001502062593, 0.0074420253513380885, 0.041480324896318574, 0.02673834246317191, 0.03750396719468491, 0.03651367586904338, 0.11932593344577722, 0.011927610861935785, 0.0693904718916331, 0.016047719599945203, 0.02399172430991062, 0.04679398351748075, 0.11922833296869483, 0.05312393153352397, 0.04376697773113847, 0.07273721694946289, 0.02472684914911432, 0.13600239716470242, 0.14118044716971262, 0.8266773436750684, 10.557182397161212, 20.149174894605363, 35.007254873003276, 59.21272209712437, 62.42870971134731, 83.12980433872768, 94.84748268127441, 88.05464581080845, 82.6116841179984, 77.02220576150077, 81.74711281912667, 88.41374955858502, 81.18267590659005, 80.14676897866386, 80.21348558153424, 64.1855547768729, 85.01879719325474, 80.02590506417411, 81.10756587982178, 84.71224961962018, 87.60122026715959, 77.64802306038993, 77.85185541425432, 83.20333017621721, 86.58540058135986, 90.68192645481655, 95.24781009129116, 103.10529858725411, 86.11528546469552, 95.3672148840768, 83.56064823695591, 89.27108083452497, 100.1111808504377, 85.79467473711286, 73.11255863734654, 87.3009260722569, 98.86363874162946, 112.21167019435337, 103.15226146153041, 102.8362226486206, 100.50234358651298, 84.34506511688232, 59.733225549970356, 31.86840615953718, 8.809790355818611, 3.1467950642108917, 0.1922029693211828, 0.12343744853777544, 0.18160239314394339, 0.024512406638158218, 0.0480450154947383, 0.04308402884219374, 0.08471977218453373, 0.05325726366468838, 0.03421716731307762, 0.1012631616156016, 0.041334456830684624, 0.06116824916430882, 0.04828321182035974, 0.032745641988835165, 0.03067759278097323, 0.03028468368574977, 0.02613854973710009, 0.03781456999214632, 0.025797187250905802, 0.02910718454846314, 0.04597269490893398, 0.04549148465905871, 0.043957785171057494, 0.05497557217521327, 0.0683756684884429, 0.024826700666121075, 0.07102531380951405, 0.008337995220374848, 0.07783002260008029, 0.044899473033313236, 0.0608857139678938, 0.06401620991528034, 0.04440391855314374, 0.04579524103818195, 0.08270836368735347, 0.02098635021996285, 0.044451704381832054, 0.021242451388388872, 0.03250404281009521, 0.016906071487548094, 0.01659394028995718, 0.026935280466984426, 0.01821617841986673, 0.020413802371227315, 0.03686291445046663, 0.04362025810405612, 0.028203245285632353, 0.07289684231259994, 0.08157086758209126, 0.03811448586306401, 0.049992166725652556, 0.04023199688111033, 0.023158535893474306, 0.06877847401691334, 0.06503847720367567, 0.011146103065194828, 0.013915640435048511, 0.010102148949434715, 0.02262289186806551, 0.016647570001493608, 0.09150527164872203, 0.011942623449223382, 0.029824932105839252, 0.03314621513709426, 0.02008557801933161, 0.06318722332694701, 0.02360544110914426, 0.042033022203083546, 0.04669102600642613, 0.016228686585756283, 0.04978709987231663, 0.0324495768041483, 0.0734000913798809, 0.03499921963417104, 0.030219676638288156, 0.011989884261441017, 0.04081500095448323, 0.05361398648736732, 0.050025370836790116, 0.040879115728395324, 0.0245039826259017, 0.027886535673003112, 0.028593411403042928, 0.061494020612112114, 0.00828479468223772, 0.07248797068106276, 0.08251588365861348, 0.03821696161425539, 0.07491523293512208, 0.013648790423758328, 0.024477129602538686, 0.01897583738900721, 0.012727274559438229, 0.026460711378604174, 0.062411922429289134, 0.02177397331355938, 0.013427200394549539, 0.031814132151859145, 0.017515533337635652, 0.06793432217091322, 0.013240013787123774, 0.04185110357190881, 0.07875135101910148, 0.007683976520118969, 0.04219911400494831, 0.03587199208725776, 0.033241501809763055, 0.028255280439874957, 0.02382946283822613, 0.039739468667123995, 0.040124506756131134, 0.032965901241238625, 0.04905969336895006, 0.06872111066643681, 0.05373600743977087, 0.030148094586495842, 0.13541721499391965, 0.0346129262553794, 0.02946789376437664, 0.04931337386369705, 0.03337744969342436, 0.08531368031565632, 0.09008031418280942, 0.015666522019143616, 0.08100657071918249, 0.07009418734482356, 0.009948364924639463, 0.08467607452933278, 0.5339415946177074, 4.142919429710933, 19.93611707006182, 35.614881787981304, 55.6351432800293, 80.08426298413957, 82.48523385184151, 103.01941885266984, 109.80115250178746, 101.07773086002895, 94.92217581612724, 94.0846608025687, 101.96776035853794, 108.90990706852504, 98.43057141985211, 100.1194839477539, 98.0611218043736, 82.8470960344587, 102.18232073102678, 100.56333487374442, 102.93602657318115, 101.60496016911098, 113.9084689276559, 93.19846670968192, 98.57760225023542, 105.99540179116386, 112.85999965667725, 113.49009009769985, 115.99526309967041, 120.77089200701032, 103.79519217354911, 112.5230884552002, 100.16390378134591, 110.8782205581665, 119.37017686026437, 107.6625178200858, 93.44253608158657, 98.69679859706334, 110.38132708413261, 119.5360859462193, 114.91896629333496, 118.84849221365792, 117.21099635532924, 110.11814321790422, 84.98053346361432, 54.13300180435181, 20.8546359198434, 10.01106527873448, 2.693746243204389, 0.0967696855909058, 0.11152898932674102, 0.13172845435994013, 0.06965265782283885, 0.08091230863439185, 0.04118143700595413, 0.07795435735689742, 0.011203882866539061, 0.0442083477973938, 0.06388649437576532, 0.055039510530020506, 0.07909857095884425, 0.01596559481030064, 0.019712178502231836, 0.047001479526183436, 0.02280385376486395, 0.0529459959029087, 0.022579448663496544, 0.01796531893445977, 0.08231169211545161, 0.07449448015540838, 0.03287319639431579, 0.09064037698720183, 0.039161838591098785, 0.021581500070169568, 0.03429396390648825, 0.05146165983751416, 0.06703883915075234, 0.022734948533720205, 0.06792585405388049, 0.020232543615358214, 0.02427678874560765, 0.06367901193776301, 0.08231313060969114, 0.03513232106342912, 0.0857965936884284, 0.016719847551680038, 0.007080609186752034, 0.046406967498894246, 0.08977639156260661, 0.014505358612430947, 0.046847960978214226, 0.0757313748555524, 0.0121417955295848, 0.09452684915491513, 0.02205519045570067, 0.022615590831264853, 0.024531074832858782, 0.017313916834869554, 0.06531407098684992, 0.06927273249519722, 0.0639191386955125, 0.061313360663396974, 0.04493373565907989, 0.04476456670090556, 0.05063019320368767, 0.00477443405127685, 0.010076110168094081, 0.01987701840698719, 0.05897851487887757, 0.07009599224797317, 0.03126944834366441, 0.03459981017346893, 0.033605328894087245, 0.050796325717653544, 0.11614561267197132, 0.09117789207292454, 0.19647835062018462, 0.09251208869474274, 0.12701867494199956, 0.1158459580370358, 0.19958255333559854, 0.20430822404367582, 0.11630330421030521, 0.08102003963930265, 0.16856959462165833, 0.15912332864744322, 0.13360734496797833, 0.13372029390718254, 0.1037318077204483, 0.1615474357136658, 0.18305608656789574, 0.1870788899915559, 0.080969766979771, 0.1633774989417621, 0.3183178763304438, 0.13839046045073441, 0.10974068992904254, 0.1216442161904914, 0.12717412731477193, 0.09543396226529564, 0.09006699454039335, 0.20915305907172815, 0.11429314421755926, 0.10091540563319411, 0.11470646703881876, 0.11107952094503812, 0.09688966415290322, 0.13016376617763722, 0.1573744182075773, 0.1397505567542144, 0.18262987158128194, 0.10699426515826158, 0.11124559239085231, 0.09335590127323355, 0.09896974717932087, 0.06925440526434354, 0.10544764636350529, 0.1512240275208439, 0.2992686027927058, 0.07177202124148607, 0.16742168978921004, 0.1474885836775814, 0.12188448544059481, 0.09688313664602381, 0.23776586300560407, 0.17286485699670656, 0.17420044461531298, 0.10855203228337423, 0.10407930585954871, 0.22073607253176825, 0.23579651010887964, 0.20122489306543553, 0.15080693204488071, 0.15659508002655848, 0.07138719689100981, 0.3048207291534969, 0.43065048860652105, 3.080341841493334, 17.371286834989274, 34.860154560634065, 55.27388211659023, 84.41852147238595, 90.93211718967983, 114.21264021737235, 122.26229504176548, 115.19725554330009, 108.13990770067487, 101.60367475237165, 106.14105687822614, 110.33855397360665, 104.25480161394391, 100.50111375536237, 102.53427478245327, 85.16466072627476, 106.43686253683907, 102.35504599979946, 106.71433189937046, 106.93257481711251, 112.41441862923759, 100.71811294555664, 101.90204429626465, 105.97663470676967, 109.95042760031563, 115.31118515559605, 118.97752026149205, 127.44367790222168, 113.52742276872907, 120.22708429609025, 107.82237502506801, 115.03287506103516, 124.012448992048, 109.9354750769479, 94.96471963609967, 107.45371750422886, 121.32899911063058, 133.89692851475306, 132.86853953770228, 135.11239079066684, 135.51542799813407, 119.9359964643206, 89.25108391898019, 55.21649694442749, 19.445275477000646, 8.065667816570826, 1.6406731392656053, 0.1454386886741434, 0.3572051525115967, 0.21355304654155458, 0.22810034879616328, 0.14434085972607136, 0.29856566765478676, 0.1267417376594884, 0.10524016392550298, 0.1680667730314391, 0.07240875850298575, 0.15286349026220186, 0.15908425860106945, 0.1389012344713722, 0.11276577546128205, 0.0930617834840502, 0.13376951483743532, 0.13865059720618383, 0.11475391020732266, 0.07043200957455806, 0.2539871111512184, 0.1836470634277378, 0.09125318231859378, 0.10250736413789646, 0.16453003138303757, 0.0872989719999688, 0.15467895141669682, 0.13632232642599515, 0.15961789925183567, 0.08155857931290354, 0.15920213370450906, 0.12610156701079436, 0.13037751827921185, 0.1759680826216936, 0.14687738647418364, 0.13159936985799245, 0.14591510168143682, 0.11088375002145767, 0.10251114357795034, 0.1374628216560398, 0.14117454391505035, 0.06224207832877125, 0.087199573405087, 0.14964061177202634, 0.07209250690149409, 0.16267117112874985, 0.10960462330175297, 0.14842478558421135, 0.1313630361109972, 0.12127209401556424, 0.11087282560765743, 0.19387454033962317, 0.15692501089402608, 0.1449297195566552, 0.15225789775805815, 0.22284019605389663, 0.09986376456384148, 0.0771576961768525, 0.15403818365718636, 0.08456690503018242, 0.194964430427977, 0.14149284469229834, 0.09138855005481414, 0.13737086659031256, 0.1444611639848777, 0.08544804382004909], [0.11366724994565759, 0.1451895713273968, 0.10961520844804389, 0.08583368241254773, 0.07388141698070935, 0.025561124917918017, 0.037210992737007995, 0.0665581106607403, 0.027897010557353497, 0.014390915199848158, 0.06348054723015853, 0.06337143879915987, 0.02806130424141884, 0.028543871561331407, 0.029309303167143037, 0.037547298440975804, 0.0228515462949872, 0.10374567697622947, 0.04384175229019352, 0.029001115954348018, 0.021011973398604562, 0.03164107179535287, 0.03940723756594317, 0.022696718174432005, 0.041196364776364396, 0.03921716972919447, 0.07462200402681317, 0.02825851535557636, 0.0657802652567625, 0.0440026634771909, 0.03255002373563392, 0.02970866173771875, 0.0189087964328272, 0.03360364951991609, 0.06771339795419148, 0.0459706253771271, 0.018263105901756456, 0.027278641238808632, 0.045442270514156134, 0.007572918997279235, 0.07537669781595469, 0.030144267648990666, 0.13148556596466474, 0.058982674298541884, 0.035486784364495955, 0.05503555467086179, 0.11319274362176657, 0.013340695661359599, 0.054352025634476116, 0.06261494689221893, 0.05126266247992005, 0.051577689325703044, 0.034989445337227414, 0.017891312816313336, 0.02273053296708635, 0.024824334275243536, 0.10868958490235464, 0.06747731526515313, 0.0833785595106227, 0.1478963289409876, 0.6534382339034761, 13.580122998782567, 34.10563577924456, 62.61651951926095, 89.47406550816127, 95.3856554031372, 96.85122503553117, 84.31771700722831, 85.89224134172711, 72.08258547101701, 71.23343917301723, 78.834518296378, 79.51774161202567, 70.51790673392159, 63.551392691476, 53.34756006513323, 52.36922591073172, 59.653404644557405, 90.20084708077567, 90.700332232884, 67.23738425118583, 55.83804110118321, 59.41114180428641, 50.24425833565848, 51.847259862082346, 64.70431423187256, 58.29437868935721, 62.90817015511649, 49.24221692766462, 44.032690388815745, 46.723863192967, 49.35449634279524, 50.06620727266584, 53.66148662567139, 58.47558076041085, 65.43224225725446, 55.85452570234026, 59.93152713775635, 75.07716873713902, 81.09826919010708, 93.36024856567383, 83.20726285661969, 90.74007592882428, 87.91665458679199, 80.18553992680141, 89.74713666098458, 95.14306599753243, 97.12444904872349, 91.96357032230922, 88.55078193119594, 66.02066435132707, 39.43838514600481, 11.964655535561697, 0.8481148162058422, 0.13814533288989747, 0.3249987049826554, 0.010500807780772448, 0.07956928427198104, 0.00767749735885965, 0.020021619308473806, 0.023366216802969575, 0.014122526610403188, 0.05303948785045317, 0.03506499681887882, 0.020997347576277595, 0.08191525124545608, 0.04246728461501854, 0.06049689983150788, 0.06939672119915485, 0.0510073535011283, 0.014818049601412244, 0.023099627179492797, 0.020018386089109948, 0.044741411693394184, 0.0678416546434164, 0.07042192654418093, 0.02275313836123262, 0.07257052803678171, 0.04578902565741113, 0.03830653502206717, 0.05335919998053994, 0.0434797979625208, 0.007777097817909504, 0.0763726175895759, 0.06985401987497296, 0.04417367126526577, 0.04256769422707813, 0.03837786601590259, 0.04628550973055618, 0.050745927529143434, 0.02030440217017063, 0.013976361685698586, 0.0034186706179752946, 0.0416684215888381, 0.04213737410360149, 0.06373070952083383, 0.023753870644473603, 0.08033097375716482, 0.020215078123978207, 0.11434787485216345, 0.024861093909878815, 0.03954226603465421, 0.056769584837768755, 0.030942309647798538, 0.04576915815206511, 0.032318358309566975, 0.08019580958145005, 0.015514255368283816, 0.02690895670093596, 0.06556260479348046, 0.042625848070851395, 0.06261244309800011, 0.04826115943225367, 0.03189897956326604, 0.044056413628693135, 0.05838172975927591, 0.02590252472353833, 0.092317070945033, 0.13115256811891282, 0.03365503836955343, 0.10114058426448277, 0.07782810913132769, 0.011472938964808626, 0.032418496507619105, 0.11079349807862725, 0.0063517616446396065, 0.029859123485428945, 0.010380067563216602, 0.04750151573015111, 0.04281416867992707, 0.0919402465224266, 0.05600222619250417, 0.0333113128851567, 0.05564735916310123, 0.03654753476647394, 0.03409130585246852, 0.09806564676442317, 0.022894346587625996, 0.03442850722266095, 0.04169205157086253, 0.02620939557839717, 0.04331340081989765, 0.071085384514715, 0.033816312572785785, 0.03338083897584251, 0.036048896344644685, 0.025292876276320646, 0.025185048580169678, 0.010493327780360622, 0.030795729120395014, 0.06778111574905259, 0.04534956905990839, 0.03793146461248398, 0.029176917592329637, 0.03677323247705187, 0.024777313494788747, 0.03605614988399403, 0.026695046839969497, 0.08148111096982445, 0.0028168323208644453, 0.02889668262962784, 0.07146080436983279, 0.08974500253264393, 0.03455095565212624, 0.006644567740815026, 0.059570638462901115, 0.017202033195644617, 0.026770028352205242, 0.03669123152004821, 0.02198533697186836, 0.013147681286292416, 0.024807698292923824, 0.11783551770661559, 0.03481970301696232, 0.10571201717747108, 0.04357502356703792, 2.7834757140704562, 25.78278820855277, 50.97803327015468, 83.61952032361711, 105.80301312037876, 107.75803470611572, 106.94847229548863, 95.73319040025983, 97.63131318773542, 86.77116761888776, 90.93768269675118, 103.84564304351807, 99.61701107025146, 89.98465388161796, 69.91380255562919, 73.7223811830793, 74.34373079027448, 83.91952964237758, 114.71639156341553, 109.16539927891323, 95.1176564352853, 81.76924283163888, 91.53275421687535, 72.4177804674421, 81.18308585030692, 92.86702374049595, 77.99013151441301, 86.28294549669538, 73.2255641392299, 72.87277630397251, 72.66214861188615, 71.55274363926479, 73.02508776528495, 83.41864790235246, 78.94470977783203, 86.83041490827287, 89.54688957759312, 86.84835515703473, 100.88449450901577, 103.98100090026855, 118.3142591203962, 100.5596592766898, 105.88671112060547, 101.67714500427246, 88.54162420545305, 98.87573555537632, 102.51752267565045, 113.4586078098842, 113.55554907662528, 111.21984263828823, 92.00094468252999, 63.37148993355887, 25.059960160936626, 4.417226927621024, 0.07181340509227344, 0.2679796431745802, 0.04067392334608095, 0.04651576380378433, 0.04742395917751959, 0.05278441296624286, 0.02739174454472959, 0.0047682602307759225, 0.06796073075383902, 0.023057376500219107, 0.06211886315473488, 0.0904829500775252, 0.04404284632099526, 0.019040045461484363, 0.03647197649947234, 0.07270721891628844, 0.03387045627459884, 0.02541814910780106, 0.027302050696952, 0.018917008402890394, 0.01471587410196662, 0.015213487935917718, 0.051058104527848105, 0.031044741294213703, 0.04391709342598915, 0.039380845946392844, 0.02520359124589179, 0.02585569054021367, 0.021885826418708478, 0.0462334423459002, 0.0749827471694776, 0.014212775160558522, 0.021311151362689476, 0.051686638300972323, 0.0634741350742323, 0.02309501144502844, 0.11045013900314059, 0.02780510638175266, 0.038464270665177276, 0.014025379055445748, 0.08805926370301417, 0.034288847752447636, 0.011235183686949313, 0.01974579312705568, 0.027390792899365937, 0.032805936610592265, 0.02958534817610468, 0.030060451610812118, 0.08375208625303847, 0.08212126126246792, 0.08446557261049747, 0.03229440263073359, 0.05778895478163447, 0.02920005902914064, 0.045496017272983275, 0.014249829109758139, 0.05919947980770043, 0.054952444309102635, 0.07837837389005081, 0.11664848854499203, 0.06735726884965386, 0.05497403529339603, 0.1864602424736534, 0.15077114610799722, 0.19031794475657599, 0.115588318290455, 0.12310948542186193, 0.14958643753613743, 0.13916536101273128, 0.14406621589192323, 0.10549375960337264, 0.12550170134220803, 0.0911085322233183, 0.08511987035827977, 0.15890577674976417, 0.11627135878162724, 0.1651051848062447, 0.07217973936349154, 0.06667357017951352, 0.31168264523148537, 0.15585162277732575, 0.07075576577335596, 0.11331156867423228, 0.08020682220480271, 0.12421179270105702, 0.09290021751075983, 0.15055524983576365, 0.11356479794319187, 0.26596425846219063, 0.10092616719858986, 0.1989216466567346, 0.20475255591528757, 0.10692808763789279, 0.1525783155645643, 0.09028863800423485, 0.08490703427898032, 0.19978120124765805, 0.1976822345916714, 0.07618173211812973, 0.0987147062218615, 0.1777675710618496, 0.12829589497830185, 0.21398506978792803, 0.1862268399979387, 0.212730417826346, 0.14588538184762, 0.12917694555861609, 0.15823676836277756, 0.2304668075272015, 0.10954379263733115, 0.1713776168014322, 0.2145433412598712, 0.1673674884119204, 0.10074982273259334, 0.11212333850562572, 0.11410589569381305, 0.07183383578168494, 0.15123146426464829, 0.22104954213968345, 0.20171102269419602, 0.1819838655314275, 0.2945564756436007, 2.1745911751474654, 22.622754437582834, 51.0920010975429, 88.25763048444475, 117.05550956726074, 122.28377887180874, 121.85158702305385, 106.74883665357316, 107.23359857286725, 92.55471611022949, 90.17512484959194, 99.02929074423653, 98.29196875435966, 88.82445062909807, 82.21233640398297, 72.65979317256382, 74.82030773162842, 83.77488204411098, 109.54634816305978, 112.18081324441093, 90.94648606436593, 75.89269965035575, 81.99635859898159, 71.77863652365548, 70.58962603977749, 88.59235300336564, 81.2128519330706, 83.19521468026298, 65.66866861070905, 62.324431146894185, 66.52885559626988, 66.8992988041469, 70.60487038748605, 77.030015536717, 77.39745017460415, 85.33370344979423, 77.73031752450126, 79.38005610874721, 98.55383941105434, 109.84180641174316, 118.33932822091239, 105.78191144125802, 113.37611879621232, 109.7375556400844, 100.31599290030343, 110.41289969852993, 117.46018654959542, 126.83668327331543, 126.46120262145996, 122.57954978942871, 97.03610965183803, 62.42820249285017, 22.658120768410818, 3.3433704589094435, 0.19198126478918962, 0.5045683022056306, 0.15378236238445553, 0.14077203694198812, 0.0974662017875484, 0.1905899965869529, 0.1441546290048531, 0.10688032555793013, 0.15324817890567438, 0.1615531218371221, 0.15504081414214202, 0.1716451495885849, 0.12592719708170208, 0.20203182048031262, 0.12422140075692109, 0.172042811821614, 0.14055694134107657, 0.11469185139451708, 0.20022831511284622, 0.09092362464538642, 0.1478580052831343, 0.23149478808045387, 0.07747214966054473, 0.14947145299187728, 0.09213189873844385, 0.14168622717261314, 0.17150320006268366, 0.15588108476783546, 0.07399862711983067, 0.17242726976318018, 0.18066439990486416, 0.07374384400567838, 0.10224715274359499, 0.10216680741203682, 0.08733528040881668, 0.11497314487184797, 0.15886235050857067, 0.14529846262718948, 0.08799752380166735, 0.12065587565302849, 0.11265918439520256, 0.11818466468581132, 0.07814602314361505, 0.11280241635228906, 0.10332799796015024, 0.2031656660671745, 0.1620509765510048, 0.13446919300726481, 0.1627883676971708, 0.166864151135087, 0.12864019721746445, 0.15544098695474012, 0.1216497394655432, 0.1519132698220866, 0.13232646084257535, 0.155630515356149, 0.13153072925550596, 0.09820093307644129, 0.12129943897681576, 0.16191912362618105, 0.10445233048605067, 0.16872701474598475], [0.03717439255810209, 0.09996652869241578, 0.03304357314482331, 0.041988829217318974, 0.067531998402306, 0.05991460821990456, 0.03453559022662895, 0.059019226979996474, 0.0661535816533225, 0.03643067068021212, 0.030814724708242074, 0.029326504029865776, 0.03342225675338081, 0.051201984485877414, 0.04443241363125188, 0.028922368572758775, 0.016863680012258034, 0.08386912675840513, 0.05005342825981123, 0.03533245496717947, 0.017337775822462778, 0.054638177422540526, 0.014960626772205745, 0.03739955422601529, 0.02957337542570063, 0.011329547551992749, 0.02638639652702425, 0.057103064443383894, 0.09197463467717171, 0.013079540255213422, 0.059176674245723655, 0.03335085451336844, 0.0544022372258561, 0.024833840550854802, 0.024083543668634126, 0.07795103253530604, 0.015052173020584243, 0.042782657513661046, 0.03327573050877877, 0.029963631449001174, 0.018660834291949868, 0.07293604806597744, 0.04926366778090596, 0.026272631649460112, 0.0517035677496876, 0.01823721979079502, 0.053665701033813615, 0.030954133120498488, 0.020012577829350318, 0.03679865379152553, 0.15146135192896637, 0.03125814734292882, 0.03968477535194584, 0.0920761503013117, 0.050364129444850345, 0.04550499768395509, 0.19464523398450442, 0.05623115372977086, 3.5512386304991583, 15.81146662575858, 52.78292860303606, 83.88237067631313, 91.30840383257184, 76.72946425846645, 76.0577471596854, 76.02267265319824, 73.91622202736991, 64.7608447756086, 64.47236946650914, 62.406322615487234, 61.77100018092564, 47.44460678100586, 51.34762184960501, 44.750852721078054, 67.72929586683, 83.77957902635846, 59.0022611618042, 55.54627234595162, 36.45645454951695, 32.25445849554879, 36.54582922799246, 32.219338825770784, 24.95397060258048, 29.864587375095912, 24.64150663784572, 29.647320679255895, 34.835637841905864, 30.610987186431885, 29.283651965005056, 30.232807159423828, 30.274583203451975, 21.333198308944702, 29.158879688807897, 28.562390736171178, 25.076515981129237, 44.44977685383388, 18.738994564328873, 27.484749453408376, 48.43086188180106, 40.69708258765084, 54.90343543461391, 68.05544430868966, 86.43562521253313, 64.94886997767857, 84.22547272273472, 78.39844935280937, 71.77952589307512, 71.70620850154332, 73.65781157357353, 81.43506922040666, 92.36402974809918, 95.33181381225586, 92.85182108197893, 63.44647489275251, 24.98698844228472, 4.676661806447165, 0.17634895789836133, 0.42643423484904425, 0.059031372756830285, 0.05739065472568784, 0.05428350377561791, 0.1077656237674611, 0.020445907255634665, 0.06265792530030012, 0.03545624689598169, 0.061131879687309265, 0.05671421638024705, 0.03798397983025227, 0.019619371875056198, 0.05480237950437835, 0.06405192121331181, 0.018539785340960537, 0.08269495583538498, 0.02686307077029986, 0.027098154316523244, 0.024838676809200218, 0.009535081967312311, 0.058388671172516685, 0.026272850477003624, 0.03909968478339059, 0.04704108900789704, 0.02855836846200483, 0.04889903663258467, 0.0319354949252946, 0.014183584584056266, 0.060636711972100396, 0.08798057399690151, 0.03513205982744694, 0.040699711069464684, 0.028533561221723045, 0.048546836245805025, 0.02400942050319697, 0.023485761102555052, 0.04497094651950257, 0.037930246642125506, 0.023825454392603466, 0.12211642228066921, 0.02033636286588652, 0.0067497678101062775, 0.040089229720511606, 0.004642686299380979, 0.02721893015716757, 0.02763566092055823, 0.06680905326668705, 0.03065485507249832, 0.05851646645792893, 0.11199693421700171, 0.06787625314401728, 0.06379645277879067, 0.026210152144942964, 0.02838088575351451, 0.03754367845665131, 0.10933778262031929, 0.046814756867076666, 0.04293189789833767, 0.005088622482227427, 0.041436399931886365, 0.05361152679792472, 0.05432082659431866, 0.06485335249453783, 0.0216551821878446, 0.07405928136514765, 0.011425266790735935, 0.028258284653670022, 0.015732460355918323, 0.022869289985724857, 0.01271971992017435, 0.0038666699713628206, 0.02564807578788272, 0.009006811921218676, 0.03772947830813272, 0.023860409124089137, 0.047542964041765244, 0.02104966771522803, 0.10008916711168629, 0.06961050044213023, 0.03802997771916645, 0.02940690703690052, 0.011408647771791687, 0.014899346578334059, 0.04123281228489109, 0.056867110675999095, 0.03789530208866511, 0.036997332237660885, 0.022674302770090953, 0.11754644821797099, 0.046408629909689934, 0.03417223133146763, 0.028787248501820222, 0.013862380525097251, 0.039873211311974695, 0.03818419515820486, 0.031571477851165194, 0.032371453674776215, 0.016463456309533546, 0.07074138083096061, 0.04629371321893164, 0.04992510710975953, 0.0024285001563839614, 0.05893238806830985, 0.0326237838848361, 0.016035996211160506, 0.03044655839247363, 0.04406050519485559, 0.02026284359661596, 0.03601213331733431, 0.08488954164619956, 0.03386705681415541, 0.07983140234968492, 0.005976228558990572, 0.07052725553512573, 0.031035051814147403, 0.21266196721366473, 0.2410335519484111, 7.889335564204624, 30.066477707454137, 73.26942116873605, 100.60027149745396, 101.94710336412702, 84.93614142281669, 87.79372010912213, 87.37841933114188, 89.01832621438163, 86.99094608851841, 82.43961892809186, 89.28706169128418, 85.42658696855817, 81.16622257232666, 76.26886817387172, 71.5781670979091, 83.75995036533901, 85.5920444216047, 64.62784930637905, 64.33652523585728, 59.427115712847026, 53.13090133666992, 47.11476537159511, 42.725807189941406, 40.16866166251046, 38.2934262411935, 39.322999886104036, 44.019030230385916, 49.00594343457903, 43.84427261352539, 35.60093675340925, 39.487411635262625, 43.108618191310335, 32.101813520704, 46.04809876850673, 44.11374112537929, 41.42669555119106, 58.098262310028076, 36.23436580385481, 48.21862915584019, 65.82722650255475, 68.44354288918632, 91.00243990761894, 94.39781611306327, 111.87092358725411, 84.27454784938267, 101.18622698102678, 104.30913652692522, 94.03665569850376, 90.19563593183244, 85.8098565510341, 89.3112553187779, 101.35689558301652, 105.01104354858398, 109.64180251530239, 87.6390323638916, 44.38414764404297, 13.332071440560476, 0.5015377476811409, 0.2621965706348419, 0.10285448908273663, 0.026136480205293213, 0.04681492650083133, 0.06488511471876077, 0.019852726853319576, 0.005129619568054165, 0.03583492711186409, 0.05400308560846107, 0.05298492345692856, 0.0581655620730349, 0.0343069408887199, 0.07413071074656077, 0.0396476968058518, 0.034143135749867985, 0.09388996940106153, 0.0551707459879773, 0.05014717805066279, 0.02635422718179013, 0.03349482607362526, 0.0354531765250223, 0.06440464407205582, 0.03594404911356313, 0.06208812551839011, 0.03588837192260793, 0.01339703781663307, 0.08378762791731528, 0.08436776178755931, 0.015887746487611105, 0.05915289159332003, 0.06604979293687002, 0.007336324014301811, 0.0614989467763475, 0.07144289104534046, 0.03640462172084621, 0.028139753067599874, 0.07850846262382609, 0.01794746158910649, 0.03147559406767998, 0.03497309942862817, 0.035753781108983924, 0.01890856403458331, 0.003560984008280294, 0.011194188297460122, 0.041295902470925024, 0.055239023574228795, 0.010029021534137428, 0.02122122172399291, 0.08465712304626193, 0.10048425091164452, 0.03984285704791546, 0.019686194003692696, 0.08963865573917117, 0.02512979208092604, 0.025628557728071297, 0.0609498762392572, 0.041285039125276465, 0.10091273899057082, 0.0438489922588425, 0.09159422080431666, 0.20767933529402527, 0.12840071506798267, 0.10252800517316375, 0.12357610038348607, 0.14703225530683994, 0.08164455648511648, 0.13233848448310578, 0.1069325998957668, 0.1111698407413704, 0.08886697821851287, 0.1626357923128775, 0.08705600896584136, 0.18210704677871295, 0.11627127735742501, 0.1319085918366909, 0.11208599193819932, 0.1522531480129276, 0.21076003355639322, 0.17784561615969452, 0.12143939360976219, 0.08734782652131148, 0.10513334894286734, 0.12028368562459946, 0.17077872822327272, 0.09031939599663019, 0.10635203854846102, 0.14790186578673975, 0.14074108217443737, 0.19783847406506538, 0.08606812983219113, 0.06699477508664131, 0.12719745534871305, 0.1192454591925655, 0.0881932879398976, 0.11648680722074849, 0.17861141078174114, 0.19383232189076288, 0.14677350276282855, 0.1604404736842428, 0.09213411076260464, 0.20560171534972532, 0.13245265478534357, 0.23497920110821724, 0.15585006214678288, 0.13712565760527337, 0.15633191700492585, 0.058283681449081214, 0.06195019970514944, 0.07824141838188682, 0.24332455758537563, 0.1564210086528744, 0.2148461171558925, 0.20444712016199315, 0.26875045895576477, 0.1469330806285143, 0.3338221843753542, 0.2464591993817261, 5.94389728137425, 27.15121160234724, 80.44014971596854, 112.34260204860142, 116.357729775565, 94.6368966783796, 92.31030627659389, 92.50519629887172, 92.37062358856201, 85.40106623513358, 83.62163952418736, 82.03995854513985, 77.94114671434674, 63.11462892804827, 69.25998401641846, 58.88522570473807, 85.87646198272705, 94.31987122126988, 72.5416043145316, 70.36770057678223, 51.25090639931815, 45.9818685395377, 49.99423088346209, 44.75895432063511, 39.329750061035156, 47.357959270477295, 36.179610524858745, 42.452565806252615, 52.14259999138968, 46.75705473763602, 44.55007757459368, 44.036240918295725, 49.465681416647776, 34.29097897665841, 44.04130962916783, 44.95023822784424, 41.09690625326974, 65.58899361746651, 28.512983833040508, 38.65353052956717, 64.25411265236991, 56.923856939588276, 72.7337567465646, 84.96538639068604, 110.024245262146, 86.15970529828752, 105.12684917449951, 101.8765652520316, 93.27140889848981, 92.4441841670445, 94.44041551862443, 100.65197999136788, 116.37589931488037, 120.37225995744977, 122.06165885925293, 93.4930772781372, 41.81860869271414, 10.193709100995745, 0.19081976211496762, 0.5657863286989075, 0.21320270534072602, 0.23061806655355863, 0.12306915330035345, 0.17969923812363828, 0.13611396189246858, 0.1391074684049402, 0.10269955239657845, 0.23806235566735268, 0.1487630760031087, 0.14634712492781027, 0.13936365608658108, 0.15994861721992493, 0.17339292008961948, 0.0804400211200118, 0.20560501302991593, 0.12071398539202553, 0.1897018485303436, 0.08274771193308489, 0.10867642132299286, 0.14668166983340467, 0.21136483895991529, 0.07714200844722134, 0.15678285780761922, 0.07370687063251223, 0.16568496583827905, 0.24852854119879858, 0.12410459773881094, 0.12043826947254793, 0.11458718058254037, 0.17207334589745316, 0.11321829046521868, 0.19807138799556664, 0.16123521461018495, 0.10729265093271222, 0.1983165969806058, 0.21560933334486826, 0.2196528185158968, 0.14900969634098665, 0.12719980307987758, 0.11963693318622452, 0.0850589107722044, 0.05556306475773454, 0.11452050773160798, 0.17000670464975493, 0.14163095370999404, 0.14695332811347075, 0.08468891919723578, 0.1685349621943065, 0.20472458670181887, 0.14319357914584024, 0.13100657452430042, 0.11532567095543657, 0.09546790937227861, 0.1915325088692563, 0.18056736939719745, 0.08744061618511166, 0.12604416294821671, 0.14154116995632648], [0.08087173224027668, 0.047225796417998414, 0.15763215294906072, 0.08010557120931999, 0.10922610932695014, 0.034428201881902556, 0.0636491971090436, 0.03755301170583282, 0.04657612967171839, 0.1168389804661274, 0.06468901809837137, 0.058151930304510255, 0.05740567070565053, 0.056960911356977055, 0.04579976347408124, 0.049831469277186055, 0.030692612153611014, 0.05055712176752942, 0.06351868768355676, 0.023959597373115163, 0.024508403281548193, 0.044375284375356774, 0.033369870457266054, 0.04154964403382369, 0.029434455558657646, 0.02988396125978657, 0.07018085662275553, 0.06655729641871792, 0.02454224691194083, 0.036712859823767624, 0.09165849164128304, 0.029524585365184715, 0.056200799465711625, 0.01108769646712712, 0.03884923750800746, 0.04577496301914964, 0.11105779425374099, 0.05004571670932429, 0.037102501772876294, 0.037261316286666055, 0.0443217547477356, 0.054115746170282364, 0.0416136468494577, 0.012756626288007413, 0.04803886118211916, 0.03839435441685574, 0.0742183028321181, 0.05146904229851706, 0.055800304348979674, 0.06526294337319476, 0.09838930118296828, 0.042759661961879046, 0.14957321967397416, 0.060038305153804164, 0.02981571081493582, 0.21598358611975396, 11.583084787641253, 36.928344930921284, 67.94787229810441, 84.96412181854248, 82.42223453521729, 69.23184381212506, 73.68943977355957, 65.61987836020333, 59.40455491202218, 73.8935570035662, 62.60434627532959, 64.62899575914655, 50.84460006441389, 38.01523774010794, 39.28371477127075, 22.967796768460953, 28.025486060551234, 31.804392405918666, 21.39372754096985, 76.57567977905273, 87.69796003614152, 62.797033718654085, 32.661091395786826, 34.33530500956944, 45.310471057891846, 53.272985049656455, 43.668705531529014, 56.9025468145098, 43.616656575884136, 56.37063094547817, 33.299669061388286, 50.7766501562936, 54.55690792628697, 63.84817804609026, 52.08579499380929, 40.93396404811314, 37.29621730531965, 51.78816543306623, 51.87239497048514, 31.56239707129342, 54.82764795848301, 39.43704761777605, 33.8453562600272, 26.910496473312378, 21.949037994657242, 27.69468753678458, 28.26399861063276, 37.60890361240932, 31.753990173339844, 41.14982373373849, 45.955479281289236, 52.44361332484654, 61.803024428231375, 78.17605141230992, 59.98974609375, 61.20055307660784, 69.94144943782261, 86.55449499402727, 90.13207381112235, 75.0493550981794, 39.61143698011126, 6.450956838471549, 0.41201118592705044, 0.3028823174536228, 0.1261184625327587, 0.10827763272183281, 0.04643503509994064, 0.04399194601657135, 0.05817470872508628, 0.026550261037690297, 0.03174424304493836, 0.047847113971199305, 0.04790431108059628, 0.10928111137556178, 0.05945310941232102, 0.003847712551110557, 0.032674999708043675, 0.026614850786115442, 0.018042088386469653, 0.034916017670184374, 0.10623663331248931, 0.019268533647326485, 0.011202343440215503, 0.07753699725227696, 0.05080378960285868, 0.0242299986670592, 0.019689622301874415, 0.009882367216050625, 0.05248405944023814, 0.03768684256023594, 0.04070168221369386, 0.02660474061433758, 0.0418006578859474, 0.024237450677901506, 0.02147385897114873, 0.028526250006897107, 0.056987272442451546, 0.04784368736935513, 0.010375557001680136, 0.013980143670258778, 0.0876452284199851, 0.04117543536371418, 0.04855233577213117, 0.0285969397851399, 0.051070094241627624, 0.021312893501349857, 0.1067499586247972, 0.03423370321148208, 0.04209154584844198, 0.00878477151439126, 0.08898357089076724, 0.10390821325459651, 0.038519282891814194, 0.04040901648945042, 0.054288925270416906, 0.029344044160097837, 0.09083551687321492, 0.006866459718107113, 0.073569833700146, 0.021424169851733104, 0.03515834966674447, 0.03731999938775386, 0.12029636065874781, 0.07314996301595654, 0.0846761084560837, 0.014697831855820758, 0.04867719639358776, 0.0678932097341333, 0.07606714112418038, 0.1384513114712068, 0.02895497896575502, 0.09143749278570924, 0.04815219688628401, 0.022098341890211617, 0.05760000992034163, 0.05391233154971685, 0.030035847931035926, 0.051507277746817896, 0.03754083539492317, 0.020600862601505857, 0.04792891136769738, 0.01647657578411911, 0.042236392718872855, 0.099102122576109, 0.05624841905332037, 0.02366528789778905, 0.04232455477384584, 0.02393491905448692, 0.008077064578953599, 0.07782791914152247, 0.06085180078766175, 0.030444617782320296, 0.007831822515332272, 0.05191475159621664, 0.08721686247736216, 0.015068157609286053, 0.08198811912110873, 0.016048326888786893, 0.07869719035391297, 0.059510472762797556, 0.0372691228320556, 0.012499933097777622, 0.04812937436093177, 0.011113337457313069, 0.03699673851951957, 0.041020196729472706, 0.055033973684268336, 0.03031425763453756, 0.028962218934403997, 0.04244177848366754, 0.08848651684820652, 0.04055494223056095, 0.14225306175649166, 0.06087564450821706, 0.07312077243945428, 1.3354843727179935, 22.276956490107946, 56.73562329156058, 86.79468032291958, 101.80702073233468, 88.55561092921666, 82.3258421761649, 85.51081998007638, 87.02064963749477, 85.72835418156215, 108.94307776859829, 90.84003966195243, 87.0751235144479, 77.32816968645368, 52.11539779390608, 54.56299454825265, 25.87469550541469, 32.52924932752337, 19.243086372103008, 28.757183483668737, 74.12239592415946, 84.10767991202218, 49.15411376953125, 21.392530713762554, 20.418685095650808, 39.505737509046284, 50.497336047036306, 32.92386531829834, 61.74151202610561, 30.45406559535435, 49.84428875786917, 36.262697083609446, 47.686192171914236, 47.53146273749215, 54.446080684661865, 47.46647276197161, 33.06573363712856, 30.610441752842494, 39.980768476213726, 42.42034353528704, 32.961812904902864, 37.56960807527815, 26.539123943873815, 22.745289393833705, 25.39533233642578, 32.39529153278896, 39.13745519093105, 45.61322838919503, 49.70623847416469, 51.602033615112305, 67.82110936301095, 72.87339469364711, 75.870375088283, 83.23834909711564, 105.17411082131522, 82.07460226331438, 77.83065646035331, 81.69499438149589, 95.12888472420829, 100.90303925105503, 93.2708044052124, 61.29939814976284, 18.119487966809952, 1.5210448099034173, 0.2051375431141683, 0.1156928398247276, 0.035489274588014395, 0.026887559099122882, 0.028822528930114846, 0.08740395493805408, 0.028786064458212683, 0.043972363495933156, 0.08797429076262883, 0.053581684827804565, 0.03957667115277477, 0.031039268909288303, 0.05214821174740791, 0.01621945681316512, 0.0368357696570456, 0.03566133749804326, 0.0283083724124091, 0.11538402496704034, 0.04607669057856713, 0.06213757036519902, 0.09747053084096738, 0.001991868597022923, 0.07984554301947355, 0.05142697991271104, 0.0337275466216462, 0.03746880890269365, 0.020833623861627917, 0.04574028309434652, 0.03503813022481544, 0.012001989326173705, 0.03156400378793478, 0.029958287985729318, 0.04652143296386514, 0.057539158899869235, 0.05471276877714055, 0.03425025607326201, 0.009566191101579793, 0.026126602431759238, 0.06744014511683158, 0.02051189648253577, 0.051760049004639895, 0.032606678017015965, 0.04999197334317224, 0.061270443323467455, 0.05679367283093078, 0.021553157662440623, 0.02059307641216687, 0.03453826365460243, 0.06982847981687103, 0.03017667108880622, 0.036573641401316435, 0.031818861540939124, 0.14751303807965346, 0.06675728783011436, 0.054368357972374985, 0.03786740412137338, 0.021723654852913957, 0.10611299066139118, 0.17035068119210856, 0.3067830524274281, 0.11617675742932729, 0.1345222680164235, 0.0778057174757123, 0.0892371122858354, 0.17203183312501225, 0.18884035332926682, 0.2392364383808204, 0.16114099323749542, 0.27837881658758434, 0.15169079176017217, 0.1473773175052234, 0.15874451611723217, 0.10612070560455322, 0.09087863777365003, 0.16766309897814477, 0.11785206039037023, 0.08450836781412363, 0.12257437913545541, 0.11148447742951767, 0.1788871538426195, 0.17455203432057584, 0.0938540952546256, 0.11360023104186569, 0.10730428780828204, 0.11194068366395575, 0.14992589503526688, 0.14503722664500984, 0.17476550143744263, 0.09570370029125895, 0.13421438953706197, 0.1352845478270735, 0.19410902847136768, 0.12080133999032633, 0.17215418655957493, 0.10845814339284386, 0.21271748494889053, 0.12134814422045435, 0.1225859278014728, 0.22937889876110212, 0.1339106365506138, 0.0831680575917874, 0.10432951564767531, 0.1766671636807067, 0.16452130542269774, 0.1300198489001819, 0.09606299136898347, 0.09874657022633723, 0.20883884307529244, 0.10045397467911243, 0.3470114395022392, 0.11148250289261341, 0.12637657725385257, 0.6671387244548116, 19.22563770839146, 54.71820340837751, 96.86676815577916, 109.70257146017892, 100.62695258004325, 85.94876493726457, 91.0793147768293, 84.29277297428676, 79.91635281699044, 93.82337379455566, 82.99657957894462, 81.36324569157192, 68.41786234719413, 52.331163678850444, 53.345350537981304, 31.686022894723074, 39.91773789269583, 46.74189724240984, 25.827560663223267, 79.7836561203003, 105.09101731436593, 83.15970938546317, 47.8902816091265, 47.32159587315151, 62.57524027143206, 75.18535218920026, 61.4527587890625, 82.82866941179547, 62.002687862941194, 77.26100839887346, 44.509100573403494, 69.73675550733293, 79.14822946275983, 86.12565912519182, 76.78971903664726, 62.644201142447336, 51.83156040736607, 72.65063544682094, 69.59579740251813, 44.840540068490164, 75.09131526947021, 53.92489978245327, 51.360538550785606, 38.00275877543858, 36.46792949948992, 42.66317612784249, 44.128877776009695, 54.31471109390259, 49.19933264596121, 60.24694061279297, 61.602416038513184, 69.35701560974121, 83.59777246202741, 101.53391483851841, 80.38125678471157, 79.12575898851667, 88.49726690564836, 106.56577246529716, 116.06627368927002, 103.88364274161202, 62.29486656188965, 14.854614564350673, 0.8246164971164295, 0.39705065584608484, 0.17883107970867837, 0.3498328966753823, 0.08531064726412296, 0.15060770059270517, 0.14699212674583706, 0.09427191676305872, 0.15872812271118164, 0.14717683754861355, 0.11947487188237053, 0.1934208446847541, 0.17763098196259566, 0.12386842684022017, 0.124703798443079, 0.09464091767690011, 0.17257266624697618, 0.10284680806632553, 0.24163180270365306, 0.09181369974144868, 0.14316122659615108, 0.16134585653032574, 0.09463996094252382, 0.14121050627103873, 0.27335624609674725, 0.15423996640103205, 0.1215969222996916, 0.06899300643375941, 0.12803053350320884, 0.12905647845140525, 0.17510271977101052, 0.0517877094846751, 0.19893144470240387, 0.1230965932565076, 0.10851496391530548, 0.12223123040582452, 0.09525393335414784, 0.11660692148974963, 0.1409843505493232, 0.1764908531414611, 0.14365989555205616, 0.12496720573731832, 0.08534116776926176, 0.07010422287774937, 0.15626622124442033, 0.11771685550255434, 0.10799517216426985, 0.08530829274760825, 0.16838819506977284, 0.23465795548898832, 0.20418399785246166, 0.11730949021875858, 0.12071228905447892, 0.22027652790503843, 0.16908351704478264, 0.16254264302551746, 0.13098513281771115, 0.10724163188466004], [0.011943113690774356, 0.012968948377030236, 0.06538196520081588, 0.041141735922013006, 0.05536109541675874, 0.028490365682435886, 0.06320084152477128, 0.01563216439847435, 0.020940883284700767, 0.08039108517446689, 0.09456716770572321, 0.05862244684249163, 0.06228711948330913, 0.011386217100412717, 0.03165955848193594, 0.02226093245138015, 0.09055414875703198, 0.0611688123483743, 0.01301989533073668, 0.05888106367949929, 0.00897936093887048, 0.02730072076831545, 0.030845289318157092, 0.011092012798014497, 0.13651113558028424, 0.06070876560573067, 0.04364074307626911, 0.013947232177348008, 0.021276493490274464, 0.07454046447362218, 0.038908666997615776, 0.0216078407995935, 0.023571382043883204, 0.0524165519912328, 0.02762421403479363, 0.021321831503883004, 0.054431644933564324, 0.05235800798982382, 0.07237169692026717, 0.028018975530618002, 0.041066941006907394, 0.02603839966468513, 0.016153462497251372, 0.025463977362960577, 0.0053828789470052076, 0.04475206469318696, 0.046787347444998365, 0.020314602247838463, 0.02515999197826854, 0.08914387478892292, 0.10247856032635484, 0.0233725560163813, 0.029605863682393516, 1.2704177498817444, 15.939111982073102, 49.58047260556902, 76.25408935546875, 82.3875560760498, 71.40942314692906, 69.91467802865165, 69.68640191214425, 71.52595833369664, 62.481613295418875, 46.586705752781455, 42.08605180467878, 18.593137979507446, 23.11440028463091, 25.17036529949733, 18.818957907812937, 41.858588627406526, 43.68952233450753, 75.19824109758649, 49.57123844964163, 77.88515813010079, 53.09338801247733, 27.090616362435476, 25.09321771349226, 59.62284646715437, 88.98165362221854, 86.34621579306466, 47.03216518674578, 46.79614182880947, 61.334681102207725, 38.18465566635132, 59.31652123587472, 43.00059802191598, 40.75657306398664, 50.630241189684185, 40.40267351695469, 43.272474084581646, 47.22816344669887, 52.64884921482631, 67.87620857783726, 55.20991005216326, 64.55834647587368, 55.63040113449097, 72.75120367322648, 83.76027693067277, 82.2113983971732, 76.01277147020612, 63.30446066175188, 39.62650762285505, 32.60376875741141, 20.85966294152396, 21.37522622517177, 24.218479463032313, 21.584952388490947, 23.747886657714844, 30.64141682216099, 30.27297122137887, 34.40697915213448, 54.8364964893886, 70.55551733289445, 70.60289709908622, 69.57659258161272, 73.5956390925816, 77.8874579838344, 72.58938707624162, 33.40399278913225, 6.920457908085414, 0.6733033508062363, 0.18897703742342337, 0.2576314684535776, 0.09404264656560761, 0.05601903689759118, 0.097987411676773, 0.03755241459501641, 0.04722254623525909, 0.03397589383114662, 0.025506380712613463, 0.0695915828858103, 0.02160775089370353, 0.07002952974289656, 0.033730817160436084, 0.016714451501944234, 0.04357006008337651, 0.05053050283874784, 0.06752488735531058, 0.03799608489498496, 0.04092271838869367, 0.055453786692981205, 0.0555220642792327, 0.03302458094965134, 0.034372918241258175, 0.020517195841031413, 0.01743289116503937, 0.04481097849618111, 0.04414154263213277, 0.05053557488801224, 0.05054938307564173, 0.03645872810323324, 0.029925803121711527, 0.040311514399945736, 0.04894978765930448, 0.005305755384532469, 0.02005989377253822, 0.04164905280673078, 0.06318642944097519, 0.016961005682657872, 0.014032298416298414, 0.04044586094096303, 0.07685673196933099, 0.05724880698003939, 0.02348166105470487, 0.09961716458201408, 0.05807311846209424, 0.02710449692261006, 0.055417929509920735, 0.037966795930905003, 0.0343212003021368, 0.01750702959751444, 0.01743608876131475, 0.06621669219540698, 0.015212921359177147, 0.01399205026349851, 0.045745599416217635, 0.06137506663799286, 0.008603557711467147, 0.0443842580009784, 0.023366210017619387, 0.06080422191215413, 0.012945208133065274, 0.07999041703130517, 0.020786601384835582, 0.027233656063409786, 0.0983058006635734, 0.016189380748463527, 0.02534262816022549, 0.017735387165365473, 0.04784888155492289, 0.04280149025310363, 0.01612855856572943, 0.04917928177331175, 0.019424026732199957, 0.03673066458265696, 0.0445084604434669, 0.008294090611993201, 0.029637045759175504, 0.03255917717303548, 0.03720347796167646, 0.060039058327674866, 0.08549984996872288, 0.007422295249333339, 0.03713551589420863, 0.05956299815859113, 0.02387386277717139, 0.049578033055045774, 0.08603779931685754, 0.025310311233624816, 0.04535385061587606, 0.053978902620396445, 0.025119551291157092, 0.03953268851286598, 0.010245051817037165, 0.0139592736294227, 0.060416011671934805, 0.022180704167112708, 0.0675264276298029, 0.05508386297151446, 0.04878187059823956, 0.02102917935033994, 0.042571799363940954, 0.09878100587853364, 0.02919714811391064, 0.05621448890971286, 0.06161448771932295, 0.20893325443778718, 0.03366383218339511, 0.1264156744416271, 3.996245563030243, 31.138490949358257, 71.44731167384556, 93.85726710728237, 93.27779429299491, 84.50679833548409, 82.12197508130754, 85.84140832083565, 98.50991984776088, 94.11107090541294, 67.1158811024257, 58.13755784715925, 23.61873527935573, 28.985087871551514, 22.39330233846392, 21.674323592867168, 22.502684354782104, 16.729690177100046, 26.984852620533534, 23.181679691587174, 38.10978882653372, 25.065954719270977, 13.984523790223257, 21.290154218673706, 48.55681882585798, 50.043604782649446, 46.95795842579433, 23.99128031730652, 18.88878035545349, 25.696479422705515, 16.82121011189052, 14.617955446243286, 17.55448477608817, 11.465279817581177, 15.779365948268346, 17.843826872961863, 16.237292187554495, 19.48295555795942, 21.02623210634504, 34.04988343375069, 28.68544159616743, 33.229721546173096, 28.371697425842285, 31.045961788722447, 29.704473086765834, 58.865944453648154, 40.09195007596697, 23.770520414624894, 19.453344072614396, 20.864976576396398, 14.243690729141235, 19.870322840554373, 19.675516196659633, 19.430972610201152, 22.063763175691875, 48.284379959106445, 52.872706277029856, 50.26642656326294, 81.24519579751151, 99.92558751787458, 94.70901897975376, 78.9932359967913, 82.40054225921631, 86.79725115639823, 94.2737351826259, 55.34268665313721, 18.0173077583313, 1.9269843016351973, 0.14003540575504303, 0.4437578852687563, 0.12865492142736912, 0.04395587509498, 0.06240384786256722, 0.09079535438546113, 0.056694518508655686, 0.045677057201308865, 0.03307748632505536, 0.023234703145655136, 0.036507548697824986, 0.05425583651023252, 0.08053178619593382, 0.08299197775444814, 0.1011284656290497, 0.03249620233795472, 0.04022574757358857, 0.020659101262156452, 0.07789680401661567, 0.04516760632395744, 0.035326466895639896, 0.06711761028106723, 0.0028041642841084725, 0.09262699181480066, 0.013540892329599177, 0.0475606568423765, 0.030938577705195973, 0.017695032991468906, 0.009676766016387513, 0.034892788023820946, 0.07362919872892754, 0.022376907656767538, 0.0814383632636496, 0.038344631370689185, 0.08767356404236384, 0.02648866532503494, 0.018721356222938215, 0.042759658569203954, 0.07711300107517413, 0.03404657682403922, 0.016233936750463078, 0.11321708945823566, 0.05215435588200178, 0.08354444775198187, 0.0403471782005259, 0.04355985830937113, 0.023807907477021217, 0.03164319900263633, 0.03570401735071625, 0.052638334554753134, 0.05091827542388013, 0.07092686516365834, 0.07713728584349155, 0.048179619879062684, 0.01634874826829348, 0.15979256773633616, 0.12929072231054306, 0.12868557763951166, 0.12726393820984022, 0.1123491142477308, 0.13713830549802097, 0.1411792529480798, 0.09597197268158197, 0.12512191172157014, 0.23736655871782983, 0.16158371019576276, 0.13296842282371862, 0.1460195825036083, 0.17004950663873128, 0.09127879023019757, 0.10594025600169386, 0.11920073016413621, 0.08942859486809798, 0.13462399398641928, 0.1629726170961346, 0.1308308203837701, 0.09634369452084814, 0.0916384273607816, 0.09635638991104704, 0.2360024590577398, 0.14337691930787905, 0.07410501462540456, 0.10123732300209147, 0.15859331137367658, 0.15837057546845504, 0.16929194943181106, 0.22485826776496, 0.09344950517905609, 0.16657919356865541, 0.15494604994143757, 0.11371166006262813, 0.09048856156212942, 0.12376124544867448, 0.1367578509130648, 0.16051429829427175, 0.11984643765858241, 0.15280780967857155, 0.2499134854546615, 0.1203455680183002, 0.08881817797997169, 0.187626752736313, 0.1445238741913012, 0.13865359633096627, 0.12212322120155607, 0.13397261393921717, 0.259670900447028, 0.14631011762789317, 0.12430004296558243, 2.680346642221723, 28.609579426901682, 73.29396220615932, 103.79403182438442, 102.32691274370465, 89.73107242584229, 83.98671872275216, 89.68461677006313, 89.56779670715332, 84.27546501159668, 58.63859939575195, 56.055839334215435, 25.696217128208705, 32.89725719179426, 35.40399701254708, 27.428981474467687, 61.21452590397426, 59.8604679107666, 100.91557380131313, 66.3735772541591, 109.48280688694545, 72.05074187687465, 37.417525904519216, 40.49140548706055, 77.81627368927002, 111.79481996808732, 112.46986525399345, 61.04739393506731, 66.2095650264195, 85.74781608581543, 52.91024739401681, 82.15330450875419, 64.59950065612793, 55.76981326511928, 68.3828295298985, 55.55464145115444, 61.17943055289132, 64.55339935847691, 75.11339664459229, 92.84073870522636, 78.8582602909633, 88.86405536106655, 72.84906905038017, 98.09368106297084, 114.50453404017857, 101.41032028198242, 93.80218873705182, 83.69720813206264, 55.120681285858154, 46.37565074648176, 31.908240182059153, 34.86611611502511, 37.191594805036274, 33.904631342206685, 36.41224316188267, 46.07944556644985, 45.05186258043562, 52.42084755216326, 77.38692365373883, 88.93742138998849, 90.53042793273926, 85.61642565046037, 91.79377719334194, 102.3590898513794, 105.41722134181431, 59.16624559674944, 15.511575426374163, 1.1167141518422534, 0.30550254828163553, 0.44431615674069946, 0.3226672586585794, 0.13732056000402995, 0.18883203448993818, 0.20473298696534975, 0.16239561805767672, 0.08197649581623928, 0.16521617956459522, 0.09064497066927807, 0.12400284462741443, 0.12245300279131957, 0.12082029825874738, 0.12556084245443344, 0.10194420721381903, 0.09049859030970506, 0.18919467074530466, 0.2268661478800433, 0.2786821760237217, 0.25888160137193544, 0.11992870324424335, 0.16199905505137785, 0.1367865258029529, 0.3345458284020424, 0.13426857734365122, 0.11182923428714275, 0.08488409300999981, 0.10021495393344335, 0.1780330953853471, 0.12937525420316628, 0.20692570001951285, 0.09714250665690218, 0.15289402433804103, 0.06648581275450331, 0.17333447108311312, 0.1253227580870901, 0.21617795926119598, 0.10682655844305243, 0.19258615161691392, 0.12178678996860981, 0.18172808497079782, 0.22532634836222443, 0.1185333774025951, 0.11907967951680933, 0.1119023532207523, 0.16592850562717232, 0.11748778208025865, 0.1405939214995929, 0.07672975771129131, 0.1323941514960357, 0.1175543192241873, 0.10963169684899704, 0.1185317760599511, 0.15836646354624204, 0.12877510354987212], [0.03381424982632909, 0.09174296246575457, 0.04484679835981556, 0.0918768442102841, 0.02740304045645254, 0.1323990776602711, 0.036177285348198245, 0.02116767513299627, 0.04293014727798956, 0.0701145501807332, 0.054893119992422204, 0.04640891828707286, 0.02491943265444466, 0.0931468310632876, 0.09510912719581809, 0.047499961884958405, 0.04109106292682035, 0.05264709104916879, 0.037547688598611524, 0.04826391767710447, 0.06627792319548981, 0.039202842462275705, 0.07803863140621356, 0.026183100650087, 0.013912891520054212, 0.02079191940304424, 0.036032021178730896, 0.05500667282779302, 0.03675898663433535, 0.07520793258611645, 0.015217922162264585, 0.04964676865243486, 0.008200239040888846, 0.08058707322925329, 0.020840929987441217, 0.10629303314323936, 0.03178206458687782, 0.022950483486056328, 0.023500860203057528, 0.005580164275930396, 0.060228790289589336, 0.04258462028311832, 0.04713435025353517, 0.06672884364213262, 0.03668840542169554, 0.01566606231166848, 0.05122289014980197, 0.027583557912813764, 0.01145595099244799, 0.021906279160508087, 0.1360425664378064, 2.65866066302572, 23.74549126625061, 54.07928875514439, 78.0936666216169, 77.69552789415631, 71.6112196786063, 67.7495151247297, 65.63998644692558, 75.33722591400146, 60.0714499609811, 37.16869354248047, 18.827733482633317, 27.522433008466447, 31.85820620400565, 65.17654160090855, 52.91875893729073, 51.92297438212803, 53.94873557771955, 64.18634687151227, 74.43707289014543, 70.52111680167062, 66.91569655282157, 46.28233296530587, 62.525185448782786, 72.27758666447231, 69.25867775508335, 60.54144695826939, 57.18428931917463, 50.9426634652274, 66.43575668334961, 75.25570269993374, 78.27019950321743, 81.97254712241036, 78.29954869406563, 72.23589747292655, 83.0862043925694, 77.3535167149135, 78.4697517667498, 77.3864998136248, 68.7281549998692, 71.37176391056606, 67.27957371303013, 68.34155028206962, 61.64534895760672, 73.95383957454136, 85.64133494240897, 66.49321133749825, 84.23341451372418, 81.9562258039202, 79.99889046805245, 78.9176812853132, 71.32896995544434, 64.83867849622453, 57.60369995662144, 69.1421147755214, 64.88147939954484, 52.708773953574045, 27.504412855420792, 31.48825284412929, 25.695133209228516, 21.497352974755422, 23.376778159822734, 34.46755354745047, 70.26874433244977, 68.1870709827968, 67.75198868342808, 65.91919980730329, 71.51865577697754, 60.557983670915874, 41.23067644664219, 10.668799127851214, 1.6394392911876952, 0.1724711845495871, 0.07411856496972696, 0.05694972909986973, 0.025021874478885105, 0.1507032247526305, 0.046874413665916236, 0.06892707318599735, 0.032367467281541655, 0.07287584165377275, 0.05290509381198457, 0.03234506205522588, 0.008540999327254082, 0.03793302524302687, 0.03467241342046431, 0.0156177574036909, 0.0696199999323913, 0.05987430323979684, 0.008517101323897285, 0.08816928815628801, 0.04263857399512615, 0.012445650296285748, 0.03202057643128293, 0.006097956469082939, 0.03615944666255798, 0.04314201644488743, 0.02287682850978204, 0.023817912475871186, 0.046920547261834145, 0.029905406359050955, 0.02863704799009221, 0.0698423015752009, 0.004440274638389903, 0.024633528531662056, 0.07648839601980788, 0.07969707955739327, 0.03148211818188429, 0.08040380770606653, 0.07444716590855803, 0.11242831285510745, 0.0378501252271235, 0.028204661727483784, 0.04449029606101768, 0.09198010366942201, 0.06702956357704741, 0.12195252893226487, 0.036791824336562834, 0.0808056565001607, 0.04319808718615344, 0.08394857642373868, 0.05871822206037385, 0.06948286800512246, 0.03213127263422523, 0.1058192460664681, 0.018749710505029986, 0.03408688858949712, 0.035420542383300405, 0.1267562447381871, 0.04244542221671768, 0.025420091414291943, 0.04675121545525534, 0.07590107646371637, 0.039240131354225535, 0.046537568526608605, 0.07171762308904103, 0.06554226909897157, 0.0634044563131673, 0.011282620918271797, 0.011866533380400921, 0.011883507782061185, 0.05279610751728926, 0.010572461926910495, 0.009956251197893704, 0.028037614887580276, 0.04103657995749797, 0.038589348417839835, 0.03724118075998766, 0.05892703442701271, 0.006299792223476938, 0.04508375635902796, 0.05864497420511075, 0.13857123575040273, 0.0526397051954908, 0.04303241946867534, 0.021382495927225267, 0.09015164856931993, 0.009487018787435122, 0.02996585365118725, 0.017869399527886083, 0.061357424727508, 0.03532252121450646, 0.042478110641241074, 0.03753629938832351, 0.02200136736168393, 0.11009542125144176, 0.05312596374590482, 0.03892420205686774, 0.06599837355315685, 0.023485028284734914, 0.023354469665459225, 0.01229396803371076, 0.017381147780854787, 0.050459198986313174, 0.04533381008410028, 0.17484415721680435, 7.139337454523359, 41.33815813064575, 75.76547118595668, 93.64153943743024, 88.5797837121146, 87.41537679944719, 88.33604090554374, 89.06008488791329, 97.61850765773228, 80.51785836900983, 46.51782826014927, 31.521183831351145, 23.038859469549998, 21.531114271708898, 30.65661253247942, 32.42940718787057, 27.50466125352042, 18.525379146848405, 48.52619464056832, 52.78019796098982, 52.57755027498518, 55.921089444841655, 49.69971064158848, 58.139319215502056, 61.85693550109863, 55.12280396052769, 52.62798377445766, 57.36176715578352, 50.34805400030953, 52.490683896201, 63.741703850882395, 66.86858776637486, 65.99706826891217, 61.15334701538086, 56.826536996024, 57.91460405077253, 57.75059182303292, 48.48237930025373, 51.562835352761404, 53.79451336179461, 55.973183563777376, 58.790723255702424, 57.34040144511631, 53.15977457591465, 64.21054744720459, 74.21766962323869, 62.33441570826939, 74.0022337777274, 69.16686425890241, 55.4991010257176, 54.93105452401297, 46.08950655800955, 40.76575510842459, 33.140711648123606, 33.25879280907767, 33.69334009715489, 31.21206542423793, 21.72293492725917, 23.81536408833095, 29.927763870784215, 27.563972813742502, 34.866380146571565, 51.067001479012625, 91.67872892107282, 89.95418603079659, 81.47156115940639, 77.69816820962089, 81.9003483908517, 79.54013565608433, 63.36960697174072, 23.546482699257986, 5.775850321565356, 0.185081866436771, 0.12354909468974386, 0.022655736355643188, 0.033476434381944795, 0.05984988954982587, 0.07793586049228907, 0.05116936730753098, 0.057862243348998685, 0.07544043939560652, 0.036809635880802355, 0.038954613996403556, 0.027609518662627255, 0.038582369685173035, 0.08207737361746174, 0.03956563138802137, 0.03541058148922665, 0.04225713214171784, 0.006578948739583471, 0.08479411248117685, 0.011073836541202451, 0.053374365238206725, 0.09037052361028534, 0.0034753696402601364, 0.07386579031922988, 0.013376876844891479, 0.008223997096398046, 0.07377327885478735, 0.03923776665968554, 0.0626149604629193, 0.06735677351909024, 0.06526785596672978, 0.026852494105696678, 0.03526593817930136, 0.04957742576620408, 0.043041172570415905, 0.0350333804796849, 0.098462935803192, 0.05585009864132319, 0.027548050175287893, 0.058901575793113024, 0.03757267565067325, 0.0512166001301791, 0.03499495504157884, 0.03602196189707943, 0.12090933562389442, 0.004762086410274995, 0.13300393734659466, 0.04580136142405016, 0.08858195279857942, 0.017070171789133122, 0.036709962479237995, 0.01699433023376124, 0.04681003426334687, 0.09699871830110039, 0.16395120030002935, 0.1220910722123725, 0.247981424842562, 0.15718421127114976, 0.22247134441775934, 0.15603728352912835, 0.145327626062291, 0.12818028618182453, 0.27458545299513, 0.1986900490841695, 0.12745755139206136, 0.129287845322064, 0.18575842013316496, 0.14771545864641666, 0.11616389240537371, 0.13586511595972947, 0.14056684795234883, 0.12007012351283006, 0.1390371857477086, 0.12943127405430588, 0.07864257507026196, 0.15392478688486985, 0.12226054311863013, 0.11508560526583876, 0.17026758779372486, 0.09329388995787927, 0.2038053481706551, 0.16335142962634563, 0.1680287207875933, 0.10228285725627627, 0.2054279696728502, 0.14010783258293355, 0.20093937910028867, 0.09082972896950585, 0.26015955422605785, 0.099446913360485, 0.16542227779115948, 0.15995678678154945, 0.13885482267609664, 0.1577656479286296, 0.13327156512865, 0.11661456179405962, 0.1470167032842125, 0.14928611793688365, 0.2714578408215727, 0.12058783216135842, 0.11849786287971906, 0.11859249137341976, 0.11508962219314915, 0.33008405353341785, 5.018334261008671, 38.01517173222133, 83.67297976357597, 105.45049626486642, 97.02615983145577, 87.78627164023263, 82.97358798980713, 84.094909123012, 92.33767523084367, 75.64091777801514, 47.65172563280378, 26.86816109929766, 38.54039648600987, 45.311214515141074, 90.54891014099121, 75.03320053645542, 72.39615072522844, 73.0178199495588, 94.77943897247314, 108.65533202035087, 104.42937510354179, 97.86333438328334, 68.0797838483538, 89.35106154850551, 103.29301112038749, 95.51434298924038, 82.81956032344273, 85.01792866843087, 77.1925686427525, 98.837096623012, 108.90705135890416, 112.37494591304234, 118.96488843645368, 108.08482238224575, 95.67838300977434, 110.67318616594586, 106.59303024836949, 104.86966855185372, 106.3600640978132, 97.39105142865861, 97.59072181156704, 92.70711094992501, 96.65414633069719, 87.01666831970215, 105.74654511043003, 113.65205260685512, 100.16955266680036, 107.74213027954102, 115.50949369158063, 116.68197441101074, 110.24931131090436, 96.68692098345075, 84.70400210789272, 75.96048627580915, 91.66288702828544, 87.17907551356724, 78.41805716923305, 42.18119696208409, 45.78121498652867, 42.771279675619944, 34.172623361860005, 37.001526832580566, 52.307953221457346, 93.35364777701241, 90.95145402635846, 85.93181828090123, 80.30158873966762, 96.5258617401123, 89.57623182024274, 68.24353899274553, 21.808116367885045, 4.132841936179569, 0.23361719133598463, 0.2244606191026313, 0.2050976316843714, 0.18138550621058258, 0.2029672081449202, 0.20188415768955434, 0.14724425678806646, 0.1415627880820206, 0.22098996676504612, 0.12563126081866877, 0.11815518912460123, 0.10238275118172169, 0.09452522745622055, 0.17132477249417985, 0.15214222110807896, 0.14860630727240018, 0.15832809917628765, 0.07611048594117165, 0.22611654310354165, 0.11718094854482583, 0.12295724930507795, 0.1683969481715134, 0.140706137620977, 0.20539435504802636, 0.10736600735357829, 0.15366543723004206, 0.15291780020509446, 0.09939588074173246, 0.17504207231104374, 0.25231948920658653, 0.12708849619541848, 0.10429887979158334, 0.11646626118038382, 0.2404345412339483, 0.24964030725615366, 0.15877460235995905, 0.17299441647316727, 0.16654367904577935, 0.17150363432509558, 0.12765516793089254, 0.18464746831783227, 0.16243449811424526, 0.16189343429037503, 0.15688712149858475, 0.21311509289911815, 0.05591971294156142, 0.1897062590079648, 0.060802417009004524, 0.14591003981019768, 0.10611721114920718, 0.1061553041051541, 0.09960923929299627, 0.35326617530414034], [0.11766147347433226, 0.07690124386655432, 0.14037668172802242, 0.12828431917088373, 0.08965033332684211, 0.0532374741908695, 0.02403720990488572, 0.011921642298278, 0.04535822377407125, 0.03646275181589382, 0.03291330799194319, 0.059709839921976836, 0.056344475863235335, 0.037756487394550016, 0.03133011615968176, 0.012878481847500163, 0.05286899235631738, 0.010398631433158048, 0.059344944144998274, 0.04866077245346137, 0.011040167633577116, 0.06353480289024965, 0.014274008705147674, 0.06519070653510944, 0.01233353849966079, 0.02484250713938049, 0.019103968549253683, 0.0989886104528393, 0.009201844089797564, 0.018190748623705337, 0.02342753261992974, 0.025080757747803415, 0.07166154216974974, 0.024794992724699632, 0.09628898424229451, 0.0013298189047158562, 0.028829443201954876, 0.018303945228191357, 0.06289565682943378, 0.060906714626720974, 0.021786234441346357, 0.08254447712429933, 0.06110646855086088, 0.08559198823890515, 0.08991871428276811, 0.008655385912529059, 0.1221049821802548, 0.14516293204256467, 0.045667289689715417, 0.41094854580504553, 14.294563702174596, 62.20599215371268, 78.42358793531145, 76.43171310424805, 62.88153770991734, 70.6025983265468, 63.95954377310616, 39.57317672457014, 38.15434067589896, 28.885372536523, 31.15233870915004, 29.23894030707223, 43.77377271652222, 59.88643332890102, 71.59470381055559, 129.40218053545271, 51.9990154675075, 46.695670877184185, 61.816434451511924, 33.168066705976216, 31.785232748304093, 36.07932717459542, 35.167379583631245, 27.448295729500906, 33.966491154261995, 38.088287625994, 44.49746928896223, 47.91159520830427, 77.27546065194267, 72.58025019509452, 43.67561204092843, 37.66928693226406, 26.46379852294922, 29.364977155412944, 26.699905259268625, 31.434463364737375, 30.532503809247697, 36.861468519483296, 45.46942152295794, 44.23072099685669, 42.00904144559588, 41.61798293249947, 38.76692165647234, 43.893788950783865, 41.42733131136213, 32.40199654442923, 31.027715819222585, 44.95376443862915, 50.71818106515067, 51.199135371616904, 51.81903975350516, 43.60737378256661, 54.011679308755056, 51.80827351978847, 52.462168489183696, 56.57262202671596, 55.274090562547954, 52.144243240356445, 70.75092847006661, 72.74559647696358, 44.22029175077166, 54.66507748195103, 51.69676882880074, 40.38570254189627, 20.139449153627666, 31.027576855250768, 51.71136351994106, 62.08564240591866, 56.64676625388009, 61.436374936785015, 67.0517909186227, 65.39361027308873, 48.170690059661865, 19.064170258385793, 0.35076482381139484, 0.2726255995886666, 0.06462118495255709, 0.10296652878501586, 0.0821405587983983, 0.05005651220147099, 0.02806362822385771, 0.027409488235467246, 0.039206530300102065, 0.14855492860078812, 0.05283058388158679, 0.06529585910694939, 0.07234545797109604, 0.08085868401186806, 0.007794637948141566, 0.035789081893329105, 0.05110192431935242, 0.08740407028900725, 0.008727780510006207, 0.0262058671963002, 0.03236963180825114, 0.016184888846640075, 0.031459550107164044, 0.019339143697704588, 0.026714178134820292, 0.020771772002003024, 0.019386702217161655, 0.020585371647030115, 0.04690828613404717, 0.036419583418007405, 0.02843496499450079, 0.022547465915392553, 0.0346578079541879, 0.006793121956954045, 0.10037540710930314, 0.01738957009677376, 0.1289618635284049, 0.049374906811863184, 0.05495977248730404, 0.05904274500374283, 0.07085620931216649, 0.09332544183624641, 0.04006503994709679, 0.08226348220237664, 0.05359664313229067, 0.09368558108274426, 0.020198381073506813, 0.11371199254478727, 0.08443010558507272, 0.04456611895667655, 0.06225104856171778, 0.12477892584034375, 0.1363756185663598, 0.052445382944175174, 0.04246725068826761, 0.12365276126989297, 0.018851124348917177, 0.012248813224557255, 0.07916106403406177, 0.07310489472001791, 0.08027331863663026, 0.05748889981103795, 0.0906863273786647, 0.016624051977747252, 0.042782504843281846, 0.11980257715497698, 0.02389093641457813, 0.049150287971964905, 0.010063429196764315, 0.035114227927156856, 0.034283945336937904, 0.04122279371534075, 0.01003014705409961, 0.041774106810667684, 0.01962213690525719, 0.09041287776614938, 0.014944241847842932, 0.014577040748138512, 0.05269066656806639, 0.01737707487440535, 0.013132868018666548, 0.022921362459393482, 0.04835264630881803, 0.03714829610128488, 0.016845649640475, 0.03379619400948286, 0.0607588007780058, 0.0937959583742278, 0.03807185011516724, 0.021466323839766637, 0.049564584490976164, 0.03861651695998652, 0.06017497567726033, 0.021866133636129752, 0.006756115081121347, 0.0938477645229016, 0.0562050301315529, 0.015877677027934363, 0.11379904858767986, 0.07773935675088849, 0.09028918083224978, 0.8206900049533162, 27.64440516063145, 82.02225453513009, 88.7113686970302, 87.11804948534284, 78.39355782100132, 90.75766181945801, 87.16500541142055, 62.264148575919016, 54.77324703761509, 43.25041355405535, 46.04178980418614, 21.887669767652238, 14.917235204151698, 34.686644145420615, 54.05408763885498, 124.96439388820103, 48.33294439315796, 48.036513396671836, 58.608965328761506, 40.86429793494088, 41.61363336018154, 41.24676500047956, 38.05501617704119, 28.107233354023524, 33.472206728799, 38.96119328907558, 44.682551928928916, 54.77736037118094, 85.6545990535191, 78.43221759796143, 47.41297858101981, 37.418373584747314, 25.820204257965088, 27.667457546506608, 23.934405837740215, 28.56638421331133, 27.58707904815674, 35.006011145455496, 46.4998220035008, 47.97649138314383, 44.79764189038958, 46.69493089403425, 42.63543544496809, 45.83035612106323, 43.02373899732317, 32.6246793610709, 28.98911087853568, 45.561415672302246, 58.035064969744, 60.13916015625, 64.523195539202, 47.47988278525216, 54.28079693658011, 53.65719263894217, 54.45509944643293, 58.65016119820731, 54.27417877742222, 51.34711115700858, 47.58542592184884, 44.57262447902134, 32.04074232918875, 36.211982182094026, 32.42359849384853, 32.12499271120344, 29.235490526471818, 48.20314162118094, 72.48866598946708, 89.47471863882882, 75.98433944157192, 72.85812255314418, 79.25779560634068, 81.69343798501151, 69.65033381325858, 35.27745294570923, 2.315049226794924, 0.11621081988726344, 0.13323482924274035, 0.041606956494173834, 0.08952135060514722, 0.05649825564718672, 0.05242359179205128, 0.022475753245609145, 0.07463170029222965, 0.01004049216862768, 0.04696903537426676, 0.020190262402008687, 0.02920558230419244, 0.07830328720488719, 0.024691828260464326, 0.05406744126230478, 0.037725322281143496, 0.01713371659362955, 0.0158984435921801, 0.029379534934248244, 0.0564884236747665, 0.04194171174562403, 0.058578294568828175, 0.01811758897799466, 0.04123006421806557, 0.014737095284674848, 0.010935715649143925, 0.010227000241034796, 0.025459112266876867, 0.07187820518655436, 0.02140897066731538, 0.0832242877887828, 0.05417178977014763, 0.0162278248462826, 0.12630586033420904, 0.050558689183422496, 0.07492452886487756, 0.10684882796236447, 0.019005675966452275, 0.05498919376571264, 0.024941362906247377, 0.10457387646394116, 0.01773006745081927, 0.05527715724227684, 0.06315471471420356, 0.017409758209916096, 0.06720399457429137, 0.06611032504588366, 0.06164821090974978, 0.08008199890277215, 0.007010233655039753, 0.06639136746525764, 0.223954011287008, 0.16398803118084157, 0.23758648548807415, 0.25584510288068224, 0.20664174668490887, 0.10597684260989938, 0.1847887257380145, 0.1400768371032817, 0.15364284201392106, 0.21274647196488722, 0.16831021782542976, 0.06979588299457516, 0.13111110962927341, 0.15498764413808072, 0.1587138870464904, 0.13219924909727915, 0.17163293595824922, 0.08261499726878745, 0.1176380640161889, 0.16150646576923983, 0.09354708530008793, 0.12550774030387402, 0.07817512551056487, 0.22257273112024578, 0.10175010548638445, 0.13368049104298863, 0.16213240075324262, 0.20010099480194704, 0.08982417399861983, 0.07270624861121178, 0.12161231147391455, 0.19454220522727284, 0.1578863321670464, 0.12218312227300235, 0.18230409334812844, 0.1683202872851065, 0.06852799281477928, 0.09221914477114167, 0.21947542232062134, 0.1334731714533908, 0.14549594345901692, 0.29551814975483076, 0.13929922240121023, 0.16354599275759288, 0.15761702161814484, 0.12631633691489697, 0.11264491480376039, 0.2237765879503318, 0.22955227802906716, 0.5612914956041745, 26.371472597122192, 87.14393847329276, 100.97256987435478, 94.64813886369977, 80.18479646955217, 87.89385059901646, 80.38792705535889, 53.494920934949604, 48.84598895481655, 39.236512184143066, 43.98614093235561, 44.78062922613961, 58.58078343527657, 83.20406668526786, 94.56027889251709, 146.28716468811035, 72.15898786272321, 68.87472724914551, 92.69987092699323, 53.301677635737825, 52.08283853530884, 56.776541233062744, 57.98337384632656, 47.303395066942485, 53.29502126148769, 58.476907866341726, 68.14143521445138, 70.02902453286308, 96.98061438969204, 92.84979220799038, 64.66281958988735, 55.22158302579607, 42.554165840148926, 46.095596654074534, 41.72529785973685, 49.36425508771624, 48.54654938834054, 53.625776359013145, 71.19614124298096, 69.64938191005162, 66.22191197531563, 63.3182041985648, 61.76223155430385, 66.16255351475307, 64.52808707101005, 50.57291507720947, 50.725316865103586, 62.503986494881765, 75.7367195401873, 70.42211886814663, 79.22675800323486, 66.633439881461, 81.86866460527692, 77.34574168069022, 80.3677842276437, 86.18638638087681, 81.53392818995884, 75.635484286717, 97.40040370396206, 98.35437747410366, 63.12405068533761, 75.29726682390485, 68.97861671447754, 54.63457836423601, 33.91628347124372, 45.982403550829204, 72.41565431867326, 83.86406912122453, 75.0054702758789, 81.92278412410191, 88.71703842708042, 94.31814806801933, 77.2532958984375, 34.60917173113142, 1.5061227934701102, 0.2923424701605524, 0.1777594829244273, 0.27130386765514103, 0.18256298159914358, 0.19401617773941585, 0.14474089683166572, 0.08320074262363569, 0.20903316193393298, 0.24696313376937593, 0.14295230566390923, 0.12928692251443863, 0.1783487091639212, 0.15906166338494845, 0.12935329680996283, 0.1341857010764735, 0.24464137692536625, 0.18409429942922934, 0.12555831830416406, 0.07818368862250022, 0.23235180495040758, 0.09161862770893744, 0.0957995637186936, 0.11101383875523295, 0.17558491389666284, 0.08971505878227097, 0.08540904162717716, 0.15351507386990956, 0.14393833918230875, 0.2002116231513875, 0.13070805982819625, 0.16184285629008496, 0.15258309245109558, 0.11403678011681352, 0.18533289725227015, 0.1858962577368532, 0.22146636620163918, 0.14800775796175003, 0.10895758587867022, 0.18755471945873328, 0.18065764169607842, 0.2740772031247616, 0.10132404656282493, 0.17963985273880617, 0.14840972210679734, 0.1264131638620581, 0.22053118209753717, 0.21323294086115702, 0.22771857785327093, 0.19646095298230648, 0.13371467563722814, 0.16638543110873016], [0.07139337834502969, 0.06553240319980042, 0.03553070593625307, 0.04246860097295471, 0.046969656233808825, 0.059043308187808306, 0.04847463333447065, 0.11476772518030234, 0.05071199060018573, 0.09415722398885659, 0.05430119318355407, 0.040272525777774196, 0.012528573212745999, 0.025049692718312144, 0.03679765973772321, 0.03513915051839181, 0.005066420392332864, 0.03399916758228626, 0.04927666172651308, 0.0498451519358371, 0.042566968194608173, 0.02545797063170799, 0.03305150521919131, 0.05505289463326335, 0.04391565153907452, 0.0347451150550374, 0.024334718672824756, 0.034628291680876694, 0.011794678218263601, 0.02134732067185853, 0.009939106314310005, 0.049618687480688095, 0.02266539869430874, 0.053224198653229644, 0.06566794056977544, 0.028327951540372202, 0.028905174495386224, 0.0028923876192753334, 0.08378344814160041, 0.09065582044422626, 0.06113883467125041, 0.0737353487472449, 0.12342587273035731, 0.06056146243853228, 0.043347548094711134, 0.048831471508102756, 0.042722057551145554, 0.2509946902947766, 3.205516896077565, 31.661113602774485, 68.76998315538678, 72.51651436941964, 73.12083394186837, 64.40593773978097, 61.204596928187776, 57.29966763087681, 31.168017319270543, 28.21357032230922, 27.184853042875016, 29.311284950801305, 33.01417800358364, 51.61260529926845, 58.993819100516184, 47.322749274117605, 43.95376927512032, 46.226695265088765, 39.0088336127145, 29.576254504067556, 23.50131072316851, 25.95811905179705, 22.239184345517838, 20.177726779665264, 14.988888502120972, 5.642961246626718, 4.377681255340576, 6.591116768973214, 5.673096886702946, 12.95248874596187, 23.392395973205566, 13.547244123050145, 8.467232874461583, 3.920461126736232, 2.3707540205546787, 2.3511835506984164, 1.902370525257928, 1.903232536145619, 1.9461884711469923, 3.312182818140302, 4.77308543239321, 4.718827383858817, 7.268453223364694, 6.870824754238129, 7.763873679297311, 4.8230230041912625, 5.577591725758143, 5.14987712247031, 2.164912985903876, 4.353295249598367, 15.338181393487112, 39.55082089560372, 36.3625670160566, 22.96485768045698, 16.846261841910227, 18.896716935294016, 27.407407317842754, 29.19221714564732, 37.431081839970176, 36.362407207489014, 51.813977990831646, 47.89001062938145, 58.14934546606881, 41.02165378843035, 130.21277127947127, 87.2182980946132, 23.026753970554896, 19.655255249568395, 12.970368197986058, 26.576630319867814, 35.58977794647217, 48.649914264678955, 55.171858242579866, 57.35930401938302, 62.73917606898716, 74.36063575744629, 41.46087374005999, 13.612214122499738, 0.5131786401782716, 0.7677027168018478, 0.06879910148148026, 0.07531334300126348, 0.07827461910034929, 0.02833330348533179, 0.02429089548864535, 0.012919206671150667, 0.02472327326956604, 0.013731954220150198, 0.0378976667832051, 0.09126592520624399, 0.04199570616973298, 0.051592321933380196, 0.027218199035684978, 0.0350761044371341, 0.054196881995137246, 0.05289293785712548, 0.01513987367174455, 0.03733229444229177, 0.020621311950630376, 0.03443068192739572, 0.042714108513402085, 0.013105020941501217, 0.06552072561212949, 0.0405776561903102, 0.016799073300457427, 0.031407021318695376, 0.04560322919860482, 0.018114842607506683, 0.02241104984256838, 0.012740883427405996, 0.04943415988236666, 0.043860042201621194, 0.07345758365201098, 0.06865043445889439, 0.014742180904639619, 0.027874142230887498, 0.02948928458083953, 0.023011280223727226, 0.030151541544390575, 0.015735946329576627, 0.04566042630800179, 0.02999598060601524, 0.062017456096197875, 0.045221000244574885, 0.015188056443418776, 0.004220997989510319, 0.040992488751986196, 0.02339076280726918, 0.004990887146310082, 0.05439771478995681, 0.08163046331277915, 0.0704279180083956, 0.00973465183882841, 0.011194687020698828, 0.03672916841294084, 0.055111513273524385, 0.06348923926374742, 0.10426850177879844, 0.010314260692601758, 0.01896862286542143, 0.07874248935175793, 0.013679559442347713, 0.03283882520294615, 0.028770665105964457, 0.034136024702872546, 0.05241010930123074, 0.04643505884866629, 0.08086904524160282, 0.014746476031307663, 0.021442347804882696, 0.02120652635182653, 0.04388360772281885, 0.019405633344181945, 0.018252970284915397, 0.00840471132791468, 0.013319837494886346, 0.06371027883142233, 0.044159778260758946, 0.08402983777757202, 0.08130734493689877, 0.03833216328972152, 0.055274697552834234, 0.05796627633805786, 0.0780591978026288, 0.04535631709066885, 0.05555400631523558, 0.009249269446757222, 0.06952187019799437, 0.10984444471874408, 0.0325418473886592, 0.05480057799390384, 0.025267510940986018, 0.014426787649946553, 0.03500340280256101, 0.1564462637262685, 0.1482556268040623, 7.5588253906794955, 52.140897682734895, 84.27872371673584, 84.97481509617397, 90.95185702187675, 83.8956139428275, 86.67155129568917, 74.4357179914202, 50.01299449375698, 33.430441107068745, 26.39249610900879, 18.013276066098893, 22.360678809029714, 35.340855257851736, 45.376148905072895, 47.92399426868984, 48.62898281642369, 51.93993493488857, 38.58389220918928, 30.49163450513567, 22.900543417249406, 23.0949262210301, 18.086216517857142, 16.305356740951538, 11.061995949063983, 4.211219787597656, 2.601518894944872, 3.733688337462289, 2.9748762207371846, 8.561198575156075, 15.233395610536848, 8.216945733342852, 5.9901010649544855, 2.438892832824162, 1.568272584250995, 1.8967294565268924, 1.0992604941129684, 1.3368802006755556, 1.8622672600405556, 2.444310690675463, 2.89303925207683, 2.502290802342551, 4.563242452485221, 3.6104948222637177, 4.495744177273341, 2.0917719049113135, 1.9547966378075736, 2.8159231500966206, 1.1611662294183458, 1.7274628707340784, 7.806536487170628, 29.470058236803325, 27.28691339492798, 16.752860682351248, 14.277906264577593, 16.27288954598563, 24.24250112261091, 29.92852817262922, 37.99143321173531, 37.7545656476702, 57.67819159371512, 50.28717735835484, 51.2022134235927, 33.501048701150076, 109.93273748670305, 72.33045550755092, 17.15346428326198, 15.532979352133614, 22.705205236162456, 40.564722878592356, 57.36960472379412, 74.69307926722935, 75.35162952968052, 69.70059708186558, 73.2357918875558, 86.78293786730084, 60.63235024043492, 29.100011076245988, 3.1866638277258192, 0.3357795679143497, 0.1485172834779535, 0.08950252125837974, 0.05505201253773911, 0.18089267265583786, 0.03747244245771851, 0.04895345174840518, 0.03170778535838638, 0.01776078133843839, 0.058507821921791346, 0.022263744979032447, 0.030709975864738226, 0.02168151273924325, 0.1037596615829638, 0.046628142773572884, 0.05637563758396676, 0.025477829655366283, 0.08043171585138355, 0.03456795973969357, 0.02743741504049727, 0.024380066864458576, 0.08971518770392452, 0.035370164550840855, 0.04369515819208963, 0.04921696760824748, 0.02831681678071618, 0.05768716095813683, 0.04962554068437644, 0.009952143516524561, 0.03791898635349103, 0.04864187864586711, 0.010887002771986383, 0.04104264606056469, 0.04125130236414926, 0.05824417035494532, 0.07326446580035345, 0.03685508415635143, 0.07072789834014007, 0.034137558192014694, 0.10068936526243176, 0.003178501663829333, 0.06452222062008721, 0.06367252514298473, 0.0278824237507901, 0.025101573505838002, 0.055429467997912846, 0.03297978746039527, 0.014997841025303518, 0.039686773637575765, 0.14618556573987007, 0.21428910775908402, 0.1521904378065041, 0.15187669678458146, 0.15043972246348858, 0.1922743512051446, 0.110547922684678, 0.2245428982589926, 0.10768288320728711, 0.18637732549437455, 0.08790440844105822, 0.10181648656725883, 0.1561076340398618, 0.08331432938575745, 0.14110170996614865, 0.16349238849111966, 0.09484432211944036, 0.13921135211629526, 0.17914330081215926, 0.18225796653756074, 0.11219752952456474, 0.12420754507184029, 0.18420859186777047, 0.16692034740533146, 0.09942001623234578, 0.09813768682735306, 0.10178087704948016, 0.19458793848752975, 0.12334976824266569, 0.1262088298265423, 0.1727418793099267, 0.11798950444374766, 0.10527048765548638, 0.14273700650249208, 0.15773704089224339, 0.1317895089409181, 0.1109261109626719, 0.15068763201790197, 0.1776964741625956, 0.23178587960345404, 0.2044425875480686, 0.232991772038596, 0.13259437360933848, 0.15979578399232455, 0.1299822987722499, 0.18156269884535245, 0.15389145724475384, 0.19511323315756662, 5.5226054191589355, 51.711717878069194, 95.14389283316476, 92.438722882952, 89.19790935516357, 83.66268253326416, 81.00894314902169, 71.05268873487199, 41.80410085405622, 39.89803974969046, 37.9007522719247, 42.38186093739101, 46.0471225466047, 71.26139872414726, 86.65145015716553, 67.90231990814209, 62.7677401133946, 64.59511634281704, 59.29147297995431, 46.63381106512887, 37.01312337602888, 40.48222344262259, 37.38781540734427, 32.684638840811594, 23.294035536902292, 10.549770406314305, 9.262706075395856, 11.484649658203125, 9.176153234073094, 17.50602282796587, 29.8348525592259, 20.95792089189802, 14.740243741444178, 7.956995385033744, 6.175759971141815, 4.489109081881387, 4.523715453488486, 3.4035881076540266, 4.141023874282837, 7.235325081007821, 8.137118748256139, 8.6333886214665, 12.869730489594595, 11.170744810785566, 13.424034323011126, 9.546762330191475, 8.361898183822632, 9.900254539081029, 5.181454513754163, 8.49664112499782, 20.414550917489187, 50.08270577022007, 47.89754942485264, 34.17512123925345, 28.415736845561437, 31.298983914511545, 41.514277594430105, 45.55512407847813, 56.107634680611746, 57.95096744809832, 78.4448355266026, 69.73567853655133, 80.54502582550049, 59.91973604474749, 141.44022641863143, 103.76243836539132, 37.75317600795201, 31.239399637494767, 23.984962667737687, 37.51050322396414, 51.99759456089565, 68.92946515764508, 74.42436463492257, 76.61340849740165, 82.00223677498954, 96.66031633104596, 65.29794747488839, 25.90918288912092, 1.8800068795681, 0.8811290732451847, 0.18050250144941465, 0.29975530239088194, 0.13644355349242687, 0.3312152256923062, 0.14362602308392525, 0.13392663640635355, 0.0883541889488697, 0.08962279159043517, 0.11784082385046141, 0.1664879848914487, 0.1353785384978567, 0.09652140284223215, 0.17306796966918878, 0.13575466402939387, 0.09107740103666272, 0.1252592879214457, 0.16159763373434544, 0.08559313496308667, 0.17686062758522375, 0.1059268820764763, 0.14646409079432487, 0.06140243195529495, 0.1004505277212177, 0.16995932933475288, 0.12109602774892535, 0.12986541432993753, 0.12707318844539778, 0.06653004645236901, 0.17411425709724426, 0.12014814146927424, 0.18821846241397516, 0.10292783871825252, 0.16518778965941497, 0.12618512181299074, 0.12924664467573166, 0.14625626908881323, 0.1465067977883986, 0.17473013619227068, 0.2354146848831858, 0.14660967726792606, 0.15078539534338883, 0.13272946993155138, 0.13744984806648322, 0.08910584968647786, 0.17958106446479047, 0.1405130944081715, 0.10360399886433568, 0.12245526909828186], [0.02085496548430196, 0.030521122605672905, 0.07599924012486424, 0.03508559714204498, 0.07369279103087527, 0.018497700902766416, 0.0462737541113581, 0.0312412382502641, 0.03164318882461105, 0.05313418419765575, 0.08441879440631185, 0.051293596891420226, 0.02817990368099085, 0.0433576039836875, 0.01451367575542203, 0.029001533253384486, 0.011406428962280708, 0.029819432579513108, 0.03160906869119831, 0.028513249275939803, 0.025381150289571712, 0.02472199423105589, 0.03803645094324436, 0.03635615735713925, 0.01097742180406515, 0.019484536788825477, 0.05392703540357096, 0.054097076279244254, 0.06594999400632721, 0.020323426595755985, 0.026516551417963843, 0.04947088898292609, 0.0018482831656001508, 0.009982507958609079, 0.023685537079083066, 0.0441506621427834, 0.06688979214855603, 0.0430935860079314, 0.02615158269847078, 0.06206390181822436, 0.011373958517132061, 0.12195936856525284, 0.060059787572494576, 0.09470822156539985, 0.031957679627729316, 0.09976876287588052, 3.9095333474023, 19.88405248097011, 49.2270941734314, 82.9115058353969, 79.10197530473981, 76.08976445879254, 60.11340318407331, 55.29576894215175, 30.252977779933385, 36.45160470690046, 30.58526495524815, 42.14374269757952, 47.02941370010376, 67.77997602735246, 65.92168726239885, 54.05435514450073, 40.80639164788382, 37.78559977667672, 29.480841841016495, 16.571519647325786, 17.127394642148698, 12.046995162963867, 7.622688889503479, 2.3458518939358846, 0.7913894514952386, 0.5682801891650472, 0.1721916009805032, 0.059453061914869716, 0.11030411148177725, 0.11044789305222885, 0.09985117773924555, 0.6493893340229988, 0.9566305875778198, 0.37737707580838886, 0.15686703686203274, 0.09276168101600238, 0.029288560351622955, 0.08422939492655651, 0.04354951065033674, 0.08690781013241836, 0.07815749717078038, 0.06072572898119688, 0.18952344810324057, 0.1852222281907286, 0.07886155189148017, 0.12912746678505624, 0.038543927283691506, 0.04061374407527702, 0.1781005146248, 0.06816317846200295, 0.062153427728584835, 0.2760428105081831, 0.4289004925106253, 0.6373928348932947, 0.4985021991389138, 0.5884667688182422, 0.6284171736666134, 1.5286564528942108, 2.157847970724106, 6.967680037021637, 9.75671865258898, 12.326340539114815, 17.9319908278329, 25.24830150604248, 37.85703420639038, 54.7934558732169, 33.44700561250959, 29.936876433236257, 49.037745339529856, 57.226096630096436, 36.93790217808315, 35.12710435049874, 23.01800271442958, 24.57080524308341, 36.43098592758179, 57.75495529174805, 51.323622771671836, 62.33356802804129, 68.50898797171456, 72.85642719268799, 48.56553186689104, 11.07223151411329, 0.25011370756796425, 0.2910914958587715, 0.051994923901345046, 0.06245558615773916, 0.04249602735840848, 0.02473932401543217, 0.012200085080361791, 0.09428796411624976, 0.05305184397314276, 0.052974735253623555, 0.030486897299332277, 0.07776210124471358, 0.07874790406120674, 0.035730863588729074, 0.021654340804421475, 0.002686878233881933, 0.06026942775185619, 0.025074793424989496, 0.04481110063248447, 0.02491061169920223, 0.01725365105085075, 0.03225470154679247, 0.06874943950346538, 0.06789118091442756, 0.03042304715407746, 0.02005473860273404, 0.035432647448033094, 0.01858268741385213, 0.08716366533190012, 0.05308550609541791, 0.052447988518646786, 0.05079582020906465, 0.03979339184505599, 0.027672305204240338, 0.05004407126190407, 0.012496290212896253, 0.04704706011606114, 0.024271321449694887, 0.018270646122151186, 0.023962638906336257, 0.015580247987860014, 0.013370876050820308, 0.037033080855118375, 0.03817035643649953, 0.007632658916658589, 0.009471037591408406, 0.004395798788339431, 0.03483961123440947, 0.07239551349942173, 0.037038709303098064, 0.06687165490750756, 0.015348458729152168, 0.007613525077301476, 0.0598441016461168, 0.037991263903677464, 0.055003894226891656, 0.009489305450447967, 0.06449104193598032, 0.03419161368427532, 0.06308745153780494, 0.09617038989173514, 0.016961399232968688, 0.020201710984110832, 0.027146447350138, 0.03931152341621263, 0.07634671790791409, 0.054966086255652566, 0.03548727630238448, 0.037944590872419734, 0.039560830752764425, 0.028784310445189476, 0.021008312702178955, 0.07558789862585918, 0.024718443796570812, 0.02616885650370802, 0.038990664561944346, 0.0252477418232177, 0.02116458610232387, 0.02008165099791118, 0.03647710283153823, 0.05692893200154815, 0.04561300349554845, 0.04541848446907742, 0.014338890223630836, 0.0852391364585076, 0.06924998121602194, 0.03021425175081406, 0.05634526974920716, 0.007893588709911066, 0.09158525735672031, 0.1392802098499877, 0.08330356782036168, 0.07075071068746702, 0.06735141309244291, 10.577585782323565, 39.20584978376116, 69.50081552777971, 96.06649548666817, 93.32812704358781, 92.79838248661586, 82.40444714682442, 78.72527176993233, 48.06310067858015, 50.7655017716544, 28.635178327560425, 20.763640574046544, 22.985389607293264, 36.76485729217529, 42.098068714141846, 54.09753819874355, 47.77412509918213, 40.09104681015015, 25.04872144971575, 12.55278319971902, 10.805213110787527, 6.152233370712825, 3.931221280779157, 0.6140032985380718, 0.07359033224305936, 0.3090255835226604, 0.31748998218349045, 0.07100219612142869, 0.26733362355402535, 0.25743151775428225, 0.25789579855544226, 0.6562603424702371, 0.8091299938304084, 0.210450092330575, 0.20622475977454865, 0.3975831429873194, 0.09162240036364112, 0.18845472830746854, 0.12693810569388525, 0.1561409229678767, 0.4860023898737771, 0.3138499403638499, 0.14047960191965103, 0.10466450160103184, 0.030579900701663325, 0.042563229466655424, 0.01542587109309222, 0.05443952611780592, 0.17083986422845296, 0.07973114880067961, 0.05417779819773776, 0.0803384647837707, 0.3147032931447029, 0.7672966814466885, 0.8546878663556916, 0.5822670214942524, 0.24408733951193945, 0.29727886670402115, 0.08643245563975402, 2.5816644174712042, 4.537719547748566, 7.626720581735883, 12.998422418321882, 23.355579205921718, 36.86812489373343, 54.52441120147705, 37.529232093266074, 33.04264824731009, 45.27361781256539, 43.06123842511858, 25.131554399217876, 21.34722672189985, 26.252225875854492, 39.77371563230242, 55.3979491506304, 79.70551667894635, 76.8318737574986, 78.89582920074463, 79.85356889452252, 85.52427864074707, 71.40663691929409, 25.45384659085955, 1.8059905426842826, 0.17819477670959064, 0.16127769090235233, 0.06892937341971056, 0.04250830884224602, 0.009999628245298351, 0.036745673777269464, 0.01321537109158401, 0.028347891988232732, 0.04666121117770672, 0.009173118309783084, 0.0834652152178543, 0.07345195859670639, 0.040051085874438286, 0.08131152471261364, 0.026179914928174446, 0.05730638067637171, 0.056845821639789004, 0.042815596996141334, 0.01287525795799281, 0.0355256203162883, 0.04939238587394357, 0.06338247856391327, 0.036197057858641656, 0.022612749465874264, 0.025292474244322096, 0.04174594760739377, 0.011605901294387877, 0.03706638335383364, 0.024238556689981903, 0.033444387173014026, 0.05441641860774585, 0.06319898912417037, 0.02121260772193117, 0.0585934937532459, 0.08318511596215622, 0.04796437839312213, 0.04292179451190999, 0.027823282638564706, 0.08094856276043824, 0.014462008706427045, 0.056035990095032115, 0.06598687916994095, 0.037983335221984556, 0.016853997317541922, 0.009621427244772869, 0.005996494703660054, 0.03924875892698765, 0.15227510540613107, 0.13263104164174624, 0.15625901520252228, 0.13488126732409, 0.20960929244756699, 0.11059189175388642, 0.13591437760208333, 0.11332243880523102, 0.10310454280780894, 0.11310003538216863, 0.2708255276083946, 0.15042939516050474, 0.27299548259803225, 0.08144304515527827, 0.11828465360615935, 0.1243570399071489, 0.06143532733299902, 0.1274341826460191, 0.08087410032749176, 0.08138669282197952, 0.10634705810142414, 0.142688355541655, 0.13033208357436316, 0.11860515283686773, 0.20601821371487208, 0.10128225559102637, 0.10094948844718081, 0.1011256564940725, 0.11952182650566101, 0.12815995727266583, 0.15618095653397696, 0.11664725361125809, 0.16128974168428353, 0.10916877990322453, 0.1645949807550226, 0.08377676457166672, 0.23675395016159329, 0.1520185920276812, 0.1579551084765366, 0.2163989581167698, 0.07744688780180045, 0.28995353834969656, 0.14047497431082384, 0.27937156760266846, 0.1421929028417383, 0.11876639989869935, 7.556722692080906, 38.06155443191528, 75.72713102613176, 105.91551835196358, 95.75147111075265, 95.02125712803432, 77.03760296957833, 69.47033378056118, 40.02459076472691, 48.83402068274361, 43.08353172029768, 58.56935364859444, 61.978369167872835, 86.80754143851144, 91.38098471505302, 76.0466091973441, 59.73362159729004, 58.250556400844026, 43.91097184589931, 27.39977819578988, 24.581628799438477, 18.273034470421926, 11.791328379086085, 4.556639926774161, 1.5828890970775058, 1.0660209634474345, 0.5344228659357343, 0.3474953163947378, 0.39266273272889, 0.5098010014210428, 0.6124261117407254, 1.0780981268201555, 1.4358126691409518, 0.8937579670122692, 0.5200210415891239, 0.5387950198990958, 0.13754872418940067, 0.40358513806547436, 0.1657671635704381, 0.46000738761254717, 0.4312150297420365, 0.26194553981934277, 0.3178795427083969, 0.5149993939059121, 0.34741660633257454, 0.44466353952884674, 0.15381798547293457, 0.18392775979425224, 0.42288598524672644, 0.30831542877214296, 0.13906291579561575, 0.4896001453910555, 0.8867124393582344, 0.9164426411901201, 1.1262171162026269, 1.5696943593876702, 1.3005115922008241, 3.794140705040523, 3.9752415929521834, 8.883674894060407, 14.083120465278625, 17.591963359287806, 26.32243047441755, 41.138873372759136, 60.89246995108468, 77.51926599230084, 51.55785696847098, 44.99140283039638, 70.04636028834751, 80.45064149584088, 54.45410932813372, 49.50228452682495, 33.51208244051252, 35.058695861271445, 50.69541529246739, 75.87732328687395, 71.38597297668457, 80.72077356066022, 87.07922295161656, 98.33965424128941, 73.75202219826835, 22.58102876799447, 0.9247493211712156, 0.33620183382715496, 0.19803649772490772, 0.1274714885013444, 0.1467691601387092, 0.10463904296713215, 0.10318943432399205, 0.15319038129278592, 0.13781229433204445, 0.12042092611747128, 0.13948557525873184, 0.19267894806606428, 0.24359434310879025, 0.16705684150968278, 0.15636787936091423, 0.146561826978411, 0.1593873601938997, 0.2035721085433449, 0.09232775108622653, 0.09474094052399908, 0.09783948425735746, 0.11931055784225464, 0.12817350083163806, 0.14943139228437627, 0.10545790581298725, 0.10204100701957941, 0.12680222227105073, 0.12631392133023056, 0.19506147450634412, 0.14667537302843162, 0.11724094461117472, 0.19092583070908273, 0.06714981355305229, 0.1162222328462771, 0.14025735455964292, 0.1259098265852247, 0.09987143879490239, 0.1514516488781997, 0.13280098752251693, 0.14169381319412164, 0.1236938126385212, 0.13997790669756277, 0.1044986540717738, 0.10858108036752258, 0.11489108284669262, 0.09496470101709877, 0.1288316390876259, 0.07301910753761019], [0.010338855890690215, 0.015104645829913872, 0.009571034145275397, 0.03731071363602366, 0.061969755084386895, 0.0347365281943764, 0.026284500923273817, 0.04276088671758771, 0.022343525430187583, 0.022662036553291336, 0.07431803390915905, 0.0593458873086742, 0.03525839286989399, 0.0016416569539744938, 0.03008327752883945, 0.05785551228161369, 0.00878233218099922, 0.00799271504261664, 0.07860016663159643, 0.06579930494938578, 0.042586275908563814, 0.035136337990739515, 0.0578766418620944, 0.09785435095961605, 0.05583810553486858, 0.03486909358096974, 0.018429559023518647, 0.005851420523997928, 0.010574117552355995, 0.032716193569025824, 0.03985146426462701, 0.019781032843249183, 0.03164120071700641, 0.03058705585343497, 0.05249445798939892, 0.03238124493509531, 0.0533057008869946, 0.016184829474825944, 0.07239022771162645, 0.015164557079385434, 0.034835556987673044, 0.18048555164464883, 0.023634436606828655, 0.12140021499778543, 2.5695873626640866, 21.2684098311833, 60.3307706287929, 77.3331515448434, 72.7045465196882, 59.91665799277169, 52.64202955790928, 51.12252105985369, 38.017582757132395, 29.09336338724409, 26.958541529519216, 24.969928877694265, 51.82387569972447, 76.17154475620815, 59.15379442487444, 56.893010411943706, 45.284477846963064, 32.926175594329834, 21.268171855381556, 6.3356857895851135, 1.3164144988570894, 0.44943453637616976, 0.0465773815688278, 0.2440315910748073, 0.22376588066773756, 0.006471378462655204, 0.008352159638889134, 0.05202411108517221, 0.043213432255600176, 0.01944752948890839, 0.10850588511675596, 0.18214345696781362, 0.029592890092836957, 0.32849221037966864, 0.7476026639342308, 0.13084322400391102, 0.2113992271146604, 0.17550574243068695, 0.10850078931876592, 0.044070075931293626, 0.11121022714568035, 0.235072594668184, 0.36485427777682033, 0.40376049865569386, 0.3113268757505076, 0.2154150144862277, 0.07302883094442741, 0.2784339136310986, 0.2445017887013299, 0.07936868217906781, 0.05806732377303498, 0.1300268785229751, 0.13048194481858186, 0.3726505637168884, 0.32640270250184195, 0.39391240424343515, 0.17819787082927568, 0.04362897727904575, 0.013647904935558992, 0.06959965066718203, 0.08647747643824134, 0.41127405262419153, 0.21353256835469178, 0.16168141923844814, 0.07822076377591916, 0.5125531394566808, 2.45211894597326, 8.421769942556109, 36.66932303564889, 45.44359506879534, 44.32820769718715, 44.63725314821516, 55.55636807850429, 59.99444307599749, 43.55528661182949, 30.47137008394514, 18.70278923852103, 25.795673642839702, 31.08805397578648, 41.24081039428711, 47.86701209204537, 60.88157517569405, 63.28996671949114, 73.51809024810791, 42.97866603306362, 8.447891695158821, 0.08180046347635132, 0.15872468932398728, 0.017354238778352737, 0.03904655209875532, 0.09535268734076194, 0.00860908777186913, 0.054707058904958625, 0.01970461114043636, 0.03655643036056842, 0.10526577862245695, 0.05906483131859984, 0.07834165836019175, 0.01846687844954431, 0.022563513268583586, 0.03961926279589534, 0.06599280956600394, 0.054441914561071565, 0.026820682687684894, 0.03600547688880137, 0.017439247341826558, 0.025182083382138183, 0.04001181226755891, 0.045570852900190015, 0.034555919135787656, 0.019033657054283788, 0.029871934226581028, 0.05470274342224002, 0.026578918964202915, 0.08796703722327948, 0.02082118801107364, 0.027223976761368767, 0.029181667337460176, 0.02236740816650646, 0.047743030092013736, 0.0509699492582253, 0.06638406642845698, 0.021198478926505362, 0.02554194612561592, 0.08698312751948833, 0.042859864620757956, 0.0680263586608427, 0.033508176250117164, 0.026384915624346052, 0.05903247876891068, 0.01712244443063225, 0.04100102811519589, 0.05093015657205667, 0.06407766483191933, 0.033910859642284255, 0.042128732960139, 0.07164537268025534, 0.04415224312937685, 0.04500985371747187, 0.030275757557579448, 0.016111819106819372, 0.04516410508326121, 0.04739369651568787, 0.0579495368791478, 0.021168384202090756, 0.03988970989095313, 0.07310652998941285, 0.02442134214964296, 0.051860733423382044, 0.03569137624331883, 0.04597720716680799, 0.031160289022539343, 0.030357171581791978, 0.005938669525286449, 0.010471633319476885, 0.08395236943449293, 0.023167994671634266, 0.04091916625787105, 0.02167367735611541, 0.0022407117732135312, 0.025794722472450564, 0.03579302757446255, 0.03327094344422221, 0.017170404982087866, 0.034864482935518026, 0.009747699219068246, 0.011301031269665276, 0.04739591193252376, 0.045300110642399104, 0.025007862730750015, 0.051457904146185944, 0.07505060745669262, 0.07463165279477835, 0.22691743155675276, 0.034886983156736405, 0.1976089799510581, 7.369259425571986, 40.37849725995745, 78.19264371054513, 95.02630152021135, 90.79344504220145, 79.74728230067662, 75.45507431030273, 77.41245828356061, 59.01303781781878, 37.79531683240618, 23.456981216158184, 13.166990058762686, 20.67407829420907, 53.96235057285854, 52.502204009464805, 55.13869101660592, 51.80998625074114, 32.69799327850342, 17.300797360283987, 3.8014250227383206, 0.2309034312410014, 0.273284484233175, 0.237156837114266, 0.12078239529260568, 0.33094207463519915, 0.09261712591562953, 0.056336133275181055, 0.04475767957046628, 0.07201672132526125, 0.07150491593139512, 0.20226394731019223, 0.2439133088503565, 0.2064099455518382, 0.30552616130028454, 0.6238202346222741, 0.33929961760129246, 0.365073526012046, 0.12905556921448025, 0.2320752612182072, 0.28276977954166277, 0.1679239956928151, 0.19806614970522268, 0.1561710499227047, 0.35249221112046925, 0.2255087657166379, 0.4184169093413012, 0.27905428462794846, 0.3215337794806276, 0.3787160968141896, 0.07275464172874178, 0.12455496857208864, 0.079170387105218, 0.17721772699483804, 0.1504881562931197, 0.4273286254278251, 0.6133368143013546, 0.399567966482469, 0.023111501542319144, 0.047689279940511496, 0.09560805399503026, 0.0787405012441533, 0.2906918115913868, 0.27686307792152676, 0.3732515014708042, 0.420619542577437, 0.47195964625903536, 0.7268453006233487, 6.695168648447309, 35.53144087110247, 49.71356187547956, 48.49186706542969, 45.06266008104597, 49.8998396056039, 42.843353339603965, 26.90788916179112, 21.16176019396101, 21.476214817592076, 45.84901550837925, 49.44393702915737, 62.50533444540841, 71.43688242776054, 79.12087440490723, 73.97483703068325, 87.83342906406948, 62.684097698756624, 19.327011925833567, 0.5731699296406337, 0.1999129048947777, 0.11539562791585922, 0.051034813813332996, 0.12366892397403717, 0.022855380017842566, 0.01691781183970826, 0.026536588557064533, 0.031151691983853067, 0.047509498694645505, 0.04734236534152712, 0.03814482655642288, 0.027564326534047723, 0.03495454828121832, 0.004777535804480846, 0.03471984301826783, 0.013116416088970644, 0.04611371144918459, 0.0238561869399356, 0.02905298995652369, 0.023730810631864836, 0.042007241265050003, 0.032592591630028825, 0.008976859689157988, 0.03899671030896051, 0.06539341208658048, 0.08694255112537316, 0.012525649574984397, 0.021506990139771785, 0.025375910302890197, 0.02874837183792676, 0.019232508526848893, 0.0505789197050035, 0.024678296575854932, 0.029371942127389566, 0.014755794013451253, 0.10969466489872762, 0.02911746096132057, 0.026177407741280537, 0.024013729200565388, 0.03271331318787166, 0.010503691554601704, 0.04341409541666508, 0.014861942335431064, 0.029898668506315777, 0.047146719946925125, 0.10159523665372815, 0.1267145284052406, 0.11281222118330853, 0.06555835716426373, 0.21569196533943924, 0.12817445078066417, 0.1195061659174306, 0.2284826354256698, 0.07574206178209611, 0.12987038120627403, 0.18256188237241336, 0.17728920387370245, 0.12403884769550391, 0.0922033620466079, 0.1335383379565818, 0.1422436029783317, 0.10141392531139509, 0.09779760507600647, 0.1780181404735361, 0.1479218825697899, 0.1940632409283093, 0.11933520223413195, 0.16088035436613218, 0.25237388057368143, 0.16831157489546708, 0.11175427652363266, 0.07795022507863385, 0.08709986268409661, 0.1482018596891846, 0.10872476694307157, 0.11536286824515887, 0.1229007001966238, 0.1293223284717117, 0.13314546618078435, 0.1162297645849841, 0.19043276645243168, 0.30767388748271124, 0.11728234881801264, 0.20081778562494687, 0.1418959352054766, 0.12065469500209604, 0.35153718665242195, 0.15497815821852, 0.20394478711698735, 5.367948940822056, 38.89547722680228, 89.00822353363037, 103.06333146776471, 93.10713263920375, 79.1846102305821, 71.3288379396711, 66.25390148162842, 52.9020276750837, 37.960298333849224, 38.449812820979524, 33.20040709631783, 67.06201866694859, 94.95598575047084, 80.69213308606828, 79.30224323272705, 69.13948835645402, 52.864677633558, 33.555612904684885, 10.95045564855848, 2.5928462403161183, 1.0541183735643114, 0.5448784934622901, 0.49239945518118994, 0.5181465478880065, 0.1750558465719223, 0.17712136145148957, 0.17682617157697678, 0.2634982450732163, 0.16537104839725153, 0.5583758034876415, 0.8664276621171406, 0.36969263958079474, 0.5633210209863526, 1.664969904082162, 0.7386926306145531, 0.8501125861491475, 0.8420254801000867, 0.4800940869109971, 0.955032827598708, 0.43885446552719387, 0.5520349751625742, 1.7556742940630232, 1.9411423419203078, 0.984209941966193, 0.6080815334405217, 0.40346954283969744, 0.7471587391836303, 0.695485094828265, 0.4108899746622358, 0.4596015693885939, 0.46384192470993313, 0.42528080674154417, 0.759618704872472, 0.7865621905241693, 0.6304260715842247, 0.37051545828580856, 0.10060497586216245, 0.17462021351924964, 0.2600892037153244, 0.27154089350785526, 0.6351291877882821, 0.61277922136443, 0.5463904866150447, 0.8274731295449393, 1.4727191116128648, 4.360822754246848, 15.80742277417864, 58.05577754974365, 68.81072739192417, 67.51181030273438, 64.92258494240897, 81.64621802738735, 83.4219969340733, 61.42236042022705, 43.34810175214495, 29.51941476549421, 39.539780208042686, 44.2975036076137, 56.4606066431318, 65.20385496956962, 79.70311260223389, 81.2666518347604, 98.56620025634766, 65.85838222503662, 16.291574989046367, 0.35689511629087584, 0.40718300214835573, 0.20826025626489095, 0.16503331437706947, 0.1646169652896268, 0.08478689965392862, 0.10198271407612733, 0.18625288217195443, 0.08064688609114715, 0.153826806428177, 0.19010575328554424, 0.22434096623744282, 0.13379922110055173, 0.12821177020668983, 0.10312271397560835, 0.11411129683256149, 0.15778019571942942, 0.1437700760683843, 0.09173757489770651, 0.08210788055190019, 0.10929535382560321, 0.08541503987674202, 0.11699680771146502, 0.09397855893309627, 0.1481450255960226, 0.1607768777757883, 0.2467685027846268, 0.16690167412161827, 0.20573287616883004, 0.10380737616547517, 0.08059470674821309, 0.1104906950412052, 0.11457008150007043, 0.09163734849010195, 0.1130547703110746, 0.09451797391687121, 0.19203443479325089, 0.1198666715728385, 0.26665508853537695, 0.07298860738852195, 0.12466080646429743, 0.07636406126299075, 0.0744432643322008, 0.2027927025088242, 0.20022383678172315, 0.13195157024477208], [0.03578013540910823, 0.0039378588969287065, 0.056698745781821866, 0.06510238841708217, 0.0313697086780199, 0.09865703074527638, 0.05115447685654674, 0.05765761075807469, 0.09311273467860051, 0.030901485588401556, 0.005364404134784958, 0.036200688020991426, 0.030622940177896192, 0.008022923421646868, 0.023737942034910833, 0.034206941790346584, 0.025221918476745486, 0.024846810747736266, 0.020900374744087458, 0.0367592614410179, 0.027559128955804875, 0.007412265653588942, 0.02683543403899031, 0.035498682476047955, 0.030758833778756003, 0.022016858316159675, 0.0309922803592469, 0.08711443083094698, 0.03335843714220183, 0.09698461155806269, 0.09351884467261178, 0.01583097515893834, 0.054001684433647563, 0.036699319657470496, 0.0066398994198867255, 0.02306748158298433, 0.02913591032847762, 0.03165421841133918, 0.07732159631060702, 0.13854271013821873, 0.02487578080035746, 0.23363502323627472, 0.5918679663113185, 20.936256408691406, 59.07541874476841, 75.11150673457554, 74.0090638569423, 59.25304249354771, 51.6518417767116, 51.610968998500276, 39.75146402631487, 23.959186588014873, 33.3347817829677, 38.760775974818635, 58.71043682098389, 70.50556673322404, 78.17831652505058, 47.21081032071795, 32.7450464793614, 36.06485060283116, 13.681726506778173, 4.745604872703552, 0.14721754964973244, 0.07519284196730171, 0.030255995225161314, 0.04548263656241553, 0.015418508988139885, 0.07371098934007542, 0.13957136922648974, 0.09768566715398005, 0.03193516583581056, 0.053969603297965865, 0.028444223604830246, 0.023771251318976283, 0.03909396134050829, 0.0689077213672655, 0.11406341940164566, 0.1497807835361787, 0.15440658746021135, 0.22368174232542515, 0.07028271151440484, 0.2788097677486283, 0.19249064102768898, 0.014683336651484882, 0.14862164216382162, 0.353996604681015, 0.45074438037616865, 0.3513238552425589, 0.08405177481472492, 0.5687826850584575, 0.22399074717291764, 0.05326667155272194, 0.013123578026092477, 0.1107228829392365, 0.4360875082867486, 0.07886514812707901, 0.03677357513723629, 0.0625203794666699, 0.14139007377837384, 0.16769364662468433, 0.043363934715411494, 0.1654081642627716, 0.14929374467049325, 0.21626695591424192, 0.11203281514878784, 0.40899854472705294, 0.3238507865795067, 0.17914591995733126, 0.1359070222824812, 0.07275706409875836, 0.023457535742116824, 0.07590951065399817, 0.12111335753330163, 7.563802906445094, 28.877161502838135, 34.23876673834664, 38.97059072766985, 38.32138926642281, 53.36367641176496, 59.283232416425435, 42.40856286457607, 21.432621819632395, 28.74512835911342, 30.99824503489903, 42.58564812796456, 41.511661597660606, 57.02769776753017, 61.76491355895996, 71.08603313991001, 64.8718352999006, 33.7796436718532, 3.5508332465376173, 0.26600244641304016, 0.0608087545260787, 0.015171091371615018, 0.03403344038607819, 0.14672315546444484, 0.08947787008115224, 0.042905302718281746, 0.08115386710103069, 0.06203429733536073, 0.053555510339460204, 0.013855830965829747, 0.023573153020281876, 0.017229259413267885, 0.056707719407443485, 0.03436906076967716, 0.05090411100536585, 0.04654015035235456, 0.019958230567031672, 0.01736262207850814, 0.01184076686123652, 0.08990812235112701, 0.09584903570690326, 0.04469214326569012, 0.05444052356428333, 0.017567644827067852, 0.05815109570643731, 0.023469002983931984, 0.041140707941459756, 0.011126933602749236, 0.04923738472695861, 0.03292255981692246, 0.026664439821615815, 0.057337328658572266, 0.1031678636957492, 0.04226908114339624, 0.014669759165761726, 0.02674227287726743, 0.016440090956166387, 0.026785760186612606, 0.044362232754273076, 0.01926637251329209, 0.028086111481700624, 0.012379216628947427, 0.04387485122840319, 0.044323335734329054, 0.06967247104538338, 0.019654265538390194, 0.07924322105411973, 0.06357558963022061, 0.060151898701276095, 0.016435527808165977, 0.06509753010634865, 0.1240207850933075, 0.05350177715133343, 0.04406374180689454, 0.0217315665712314, 0.03170741216412612, 0.04842720373666712, 0.08504591004124709, 0.0057794491627386636, 0.03139638867495315, 0.08156376332044601, 0.03950821375474334, 0.050316082380179844, 0.005695357045624405, 0.060294994951358864, 0.05205986988065498, 0.01905792994823839, 0.027357035782188177, 0.05776663776487112, 0.03273550806833165, 0.0828113110203828, 0.0465786368586123, 0.029383093850421052, 0.028891705575266054, 0.03854778475527253, 0.010528266396639603, 0.05817420660917248, 0.03235153867197888, 0.01382483887885298, 0.037447044891970496, 0.04222582114328231, 0.041085315735212395, 0.1552303425435509, 0.06694362711693559, 0.159535606524774, 3.463643342256546, 37.86989879608154, 80.10280772617885, 92.12394864218575, 89.2156342097691, 74.34080559866769, 71.85100201198033, 71.96440356118339, 65.12005969456264, 36.080671651022776, 30.77878965650286, 26.69869453566415, 28.5279415675572, 40.83115502766201, 64.1816359928676, 47.526050090789795, 32.995661054338726, 35.89653744016375, 10.04740001474108, 1.9107713316168105, 0.1585096072937761, 0.04180624901450106, 0.02103059409585382, 0.06435930436210972, 0.029403504183781997, 0.05347094452008605, 0.11201475254659142, 0.05284466687589884, 0.08333547932228871, 0.2856859602034092, 0.05054780887439847, 0.0467750829245363, 0.024703784047492912, 0.08107633768979992, 0.2131599440638508, 0.22645712697080203, 0.12979705871215888, 0.3014359250664711, 0.3717303345245974, 0.30633204377123285, 0.16132102214864322, 0.05744365509599447, 0.22026402928999492, 0.4318401776254177, 0.40923250360148294, 0.2940544682954039, 0.13684517836996488, 0.4388319381645748, 0.6921227095382554, 0.06930107490292617, 0.028733077658606426, 0.1402504335024527, 0.4789118617773056, 0.10282686592212745, 0.06661933487547295, 0.04648998625842588, 0.03613899222442082, 0.21278581342526845, 0.10408914461731911, 0.055553036010158915, 0.038954128843865225, 0.10948365407862834, 0.039920844470283816, 0.3006390263991696, 0.22463796101510525, 0.34773174513663563, 0.24400385256324494, 0.08589209749230317, 0.0296501007729343, 0.16064035653003625, 0.28188434562512804, 5.39586159161159, 27.183006559099468, 37.526480606624055, 45.04087053026472, 40.13732181276594, 46.09132351194109, 36.88435935974121, 23.981368712016515, 13.35921197278159, 27.088934898376465, 48.008130005427766, 63.574488503592356, 65.12633391789028, 80.16452857426235, 75.6547794342041, 82.48212800707135, 79.59376185280937, 52.08701440266201, 10.414797306060791, 0.13960942147033556, 0.11045042398784842, 0.02342707969780479, 0.032376729284546206, 0.14589686266013555, 0.057028744502791336, 0.04875281572874103, 0.03410960254924638, 0.04687954678333231, 0.05152413255668112, 0.030515324523938552, 0.024374855715515356, 0.060908214189112186, 0.03728944495586412, 0.06665890703776053, 0.010373316987949823, 0.031634520539747815, 0.009651804409388984, 0.044284421751009564, 0.021317363350785205, 0.1123688460460731, 0.040773142129182816, 0.030660927960915223, 0.04840290539764932, 0.03662801919771092, 0.06673360695796353, 0.01789308209637446, 0.08565916320575134, 0.012143832830978292, 0.08165567088872194, 0.02349906038892056, 0.08040315631244864, 0.13116053412003176, 0.05877250486186572, 0.0419188824349216, 0.03243362444585987, 0.020295920482437526, 0.017335512908175588, 0.01870972613271858, 0.02046966615931264, 0.02445213746146432, 0.017654560073944073, 0.013009843682604176, 0.017903100665924803, 0.11398772203496524, 0.24818262404629163, 0.10250008345714637, 0.2735896078603608, 0.14232562429138593, 0.16999739514929907, 0.10345803919647421, 0.1519916813288416, 0.22463996947876044, 0.13011401599006994, 0.10011047989662204, 0.2069000242544072, 0.0978279627327408, 0.09606540695364986, 0.12407885412020342, 0.07423292526176997, 0.11941772566309997, 0.14021521753498487, 0.09934923145920038, 0.14274877229971544, 0.12688152944403036, 0.09599924300398145, 0.15389616627778324, 0.12030997207122189, 0.21183566083865507, 0.1254698916205338, 0.1406452866005046, 0.20337918746684278, 0.10924136279416935, 0.11663008667528629, 0.17673817915575846, 0.15684711507388524, 0.15723735413381032, 0.1308968418410846, 0.11551526721034731, 0.06762987029339586, 0.19635769352316856, 0.13228158253644193, 0.13678910423602375, 0.24790960869618825, 0.09867123926856688, 0.4577408635190555, 2.5095903192247664, 34.136871406010215, 89.24044622693742, 103.71031992776054, 95.81333092280796, 74.9962500163487, 71.70659760066441, 67.80747699737549, 53.971605573381694, 32.32882506506783, 45.1552517754691, 53.067019598824636, 74.59499154772077, 92.5583986554827, 100.15513515472412, 63.945056779044016, 50.18699823107038, 53.65699461528233, 22.459174735205515, 7.674889836992536, 0.5148910454341343, 0.26249987578817774, 0.14551013841160707, 0.0934787228969591, 0.18924127253038542, 0.3009116074868611, 0.3492923213967255, 0.4341576189867088, 0.3205462396144867, 0.5414672536509377, 0.23158332332968712, 0.25209272280335426, 0.2259315201746566, 0.2820322391177927, 0.5537867354495185, 0.533402892095702, 0.35895213591200964, 1.0454536442245757, 0.9677604074989046, 0.937898569873401, 0.46085984472717556, 0.28940924469913754, 0.3435794365193163, 0.9267030677625111, 1.4475493707827158, 0.9350418831620897, 0.3262557860996042, 1.4075022339820862, 1.4663155866520745, 0.2887374407478741, 0.13353299110063485, 0.4758751732962472, 1.1971683204174042, 0.4240006554339613, 0.2299930000943797, 0.2535441092082432, 0.3577206219945635, 0.24932880539979252, 0.3533339202404022, 0.4713285544088909, 0.38684331785355297, 0.43500092944928576, 0.4420063149716173, 0.9076986589602062, 0.6497864669987133, 0.6079899040716035, 0.3985013094331537, 0.23564660815255983, 0.15917100251785346, 0.5205307570951325, 0.29936837458184784, 12.262431008475167, 45.87320566177368, 56.51822110584804, 60.57729966299874, 56.57476207188198, 76.24718284606934, 81.65964194706508, 60.38806547437395, 31.126717226845876, 41.11725057874407, 41.90961619785854, 52.711959702628, 57.064762932913645, 76.11314514705113, 75.78445366450718, 89.19221878051758, 91.51527949741909, 52.03966242926461, 7.83810475894383, 0.18156392020838602, 0.13619430043867656, 0.09591137271906648, 0.13145245345575468, 0.2699860440833228, 0.13563012571207114, 0.11292403696903161, 0.18611019982823304, 0.16258663923612662, 0.15076818769531591, 0.09053958061018161, 0.12868177784340723, 0.11760443582066468, 0.14978736532585962, 0.1296458946807044, 0.16186725640935556, 0.12129232792982034, 0.1295416581311396, 0.14537268078752927, 0.07376975725804057, 0.31416651766215054, 0.2115034365228244, 0.11146551916109664, 0.1298057303896972, 0.10160828488213675, 0.16615443064698152, 0.17029092939836638, 0.1271502428821155, 0.18238939877067292, 0.21785449715597288, 0.2700618500156062, 0.14904089538114412, 0.20622057999883378, 0.2608077180172716, 0.11880815694374697, 0.07617971686912434, 0.1870527799640383, 0.11673417394714695, 0.07740457435803753, 0.15193163097969123, 0.11253046630216496, 0.08009248905416046, 0.18471936588840826, 0.08695301413536072], [0.039902859899614535, 0.03416582935356668, 0.048178727605513165, 0.023363855501104678, 0.03875597965504442, 0.0257474116182753, 0.023995312063821723, 0.011749201104976237, 0.012625052410710071, 0.02238858354810093, 0.020471314999407957, 0.11918017055307116, 0.04890569306111761, 0.03282132578481521, 0.054225394036620855, 0.05104779079556465, 0.02401992761796074, 0.020432548597455025, 0.020769543014466763, 0.025979991370279874, 0.00878127197003258, 0.05023189654041614, 0.02917563516114439, 0.028084294704188193, 0.024611756039251174, 0.04441867329712425, 0.040973462630063295, 0.02898574374350054, 0.020595968667683855, 0.03968408663890191, 0.04170494034354176, 0.05471064496253218, 0.04332157038152218, 0.017428450153342316, 0.05552271228017552, 0.01690813762667988, 0.04998788516968489, 0.09293207472988538, 0.10380973746734005, 0.21129893963890417, 0.16861979264233792, 14.256643908364431, 47.52186380113874, 79.41025992802211, 76.44082219260079, 67.94807379586356, 56.19326080594744, 63.619978359767366, 43.21474150248936, 23.497258186340332, 15.406900814601354, 40.13789503914969, 45.38559150695801, 51.99588877814156, 68.70091806139264, 62.304218837193076, 43.346323013305664, 29.548718793051584, 20.130882024765015, 2.6644819506577084, 0.4084367448730128, 0.17786694930068084, 0.03737342384244714, 0.10896859850202288, 0.11900025020752635, 0.034543345881892104, 0.141836604103446, 0.09467141104063817, 0.08470711750643593, 0.03116654511541128, 0.05945742489503963, 0.1098532656739865, 0.09172470308840275, 0.20361925315644058, 0.09115710175995316, 0.1390451653195279, 0.1319710984826088, 0.07619772518851928, 0.26637135233197895, 0.0854321186031614, 0.32522387004324366, 0.09934083119566951, 0.12302238866686821, 0.07475747354328632, 0.2527956579412733, 0.07567132450640202, 0.014935760160109826, 0.1416582308177437, 0.1107597816735506, 0.487422699374812, 0.1039360739024622, 0.1346212119928428, 0.2234820630401373, 0.0329344884625503, 0.38583914030875477, 0.008545680370713984, 0.08933959142970187, 0.3429789873106139, 0.12227899927113738, 0.4955400952271053, 0.19741820304521493, 0.024394229586635317, 0.045572511918310604, 0.01717283753012972, 0.06407568350966487, 0.052840880650494776, 0.13982223719358444, 0.04148358864975827, 0.10297649646443979, 0.030000903377575532, 0.009515818358132882, 0.06756336707621813, 0.04731843341141939, 0.03443232398214085, 0.34877519628831316, 6.580519897597177, 21.083005837031774, 46.460745334625244, 45.606863839285715, 49.37154027393886, 43.56148440497262, 123.16355977739606, 75.95749855041504, 22.445759500776017, 28.993656737463816, 31.135058539254324, 44.14359753472464, 45.7571360043117, 56.575585433415, 58.68811225891113, 70.6791605268206, 52.85984863553728, 22.33519802774702, 0.5265209185225623, 0.2703740032655852, 0.04559923602002008, 0.009119801572524011, 0.11366748743291412, 0.016955531601394926, 0.04280851309054664, 0.05134121647902897, 0.01867799274623394, 0.10624875873327255, 0.04320150700264743, 0.046761288307607174, 0.06923311962080853, 0.013029068276020033, 0.01266932682067688, 0.0372308161375778, 0.015464120112093431, 0.02843723808681326, 0.025918144599667618, 0.026796262212363735, 0.029548456227140765, 0.04570629866793752, 0.02308611585093396, 0.02880902947591884, 0.06037521814661367, 0.021626663361010805, 0.04803395537393434, 0.051404737534799745, 0.04023543026830469, 0.02806470200552472, 0.020957717738513435, 0.04057732710082616, 0.04954773307378803, 0.030467284244618247, 0.06722166362617697, 0.052694456186145544, 0.047237843807254515, 0.008508224389515817, 0.011442957895009645, 0.03372506657615304, 0.006341897441806006, 0.05075162722330008, 0.04883807026115911, 0.03389853405367051, 0.012221156985365918, 0.028595158630715947, 0.033332757984421084, 0.04027455120480486, 0.03844870846452458, 0.02301931577468557, 0.03518141646470342, 0.026817870160032595, 0.058873626935694895, 0.02605187876283058, 0.056985399685800076, 0.059859009060476503, 0.043002034670540264, 0.06676925040249314, 0.07432537565806083, 0.010770836728625, 0.012555941922723182, 0.035987380359854014, 0.010239609118018831, 0.03942951047793031, 0.026630526641383767, 0.012843583095153528, 0.0270484499300697, 0.11295637594802038, 0.012497994183961834, 0.06717996086393084, 0.070414761214384, 0.05591883763138737, 0.07406059093773365, 0.01853301016879933, 0.035622603326503716, 0.03434713051787444, 0.04882418743467756, 0.0559287612060351, 0.012556797725015452, 0.04468297965026327, 0.10325099780623402, 0.05869260736341987, 0.18135501284684452, 1.5678150888000215, 28.974903549466813, 68.82945278712681, 90.85365118299211, 91.09011227743966, 87.15313788822719, 80.71392958504813, 79.8232330594744, 48.00632694789341, 20.829361847468785, 14.727297510419573, 23.005033901759557, 18.861998523984635, 27.07777782848903, 53.18119934626988, 60.088570322309224, 44.13618033272879, 29.03833191735404, 13.695265071732656, 1.2597825548478534, 0.31764588238937513, 0.049746855960360596, 0.05640231418822493, 0.04093150880986026, 0.10263062680938415, 0.054903335337127955, 0.18693318138165133, 0.06339284657899823, 0.11457599832543305, 0.013462060979301376, 0.04670392495713063, 0.10997221286275558, 0.06036345913474049, 0.2860138826072216, 0.09269288435046162, 0.11802511396152632, 0.07246393018535205, 0.06298390030860901, 0.17140858513968332, 0.16518588976136275, 0.3458139609013285, 0.09928006838474955, 0.26930370926856995, 0.4306351537150996, 0.35065813096506254, 0.2967324017414025, 0.14249504091484205, 0.2933338098227978, 0.6499615833163261, 0.8859077511089188, 0.8011367970279285, 0.6278405274663652, 0.651329021368708, 0.35966929314391954, 0.5950124061533383, 0.22761533196483338, 0.19417381499494824, 0.18282493682844297, 0.46374752691813875, 1.4095888648714339, 0.5397468688232558, 0.22432579419442586, 0.12348709015973977, 0.0656898979629789, 0.09639319365045854, 0.1324438609715019, 0.09626744075545243, 0.2958721007619585, 0.2482578871505601, 0.09562542449150767, 0.0892180861639125, 0.1591928649161543, 0.1284672657826117, 0.005992116032367838, 0.3866247481533459, 3.847538479736873, 19.166906322751725, 49.092445032937185, 49.32517841884068, 49.18428979601179, 34.993952546800884, 84.17111696515764, 45.245265688214985, 13.999627436910357, 28.33881160191127, 42.318184171404155, 68.97329439435686, 71.55794784000942, 76.3680328641619, 71.30959142957414, 79.12526566641671, 68.04784992762974, 39.16680785587856, 3.0212513208389282, 0.1471059713512659, 0.07877712856445994, 0.05042041392464723, 0.13814202163900646, 0.052342527213373354, 0.02661182451993227, 0.013458609780562776, 0.0514817241180156, 0.02623971930838057, 0.0166698378244681, 0.06145239248871803, 0.0820675077182906, 0.029602929018437862, 0.020007775497755835, 0.008274156101314085, 0.048909703203077824, 0.03907010404925261, 0.04598569903256638, 0.005591245600953698, 0.05240075569599867, 0.05368830982063498, 0.031110270813639675, 0.015271870785259774, 0.04531093327594655, 0.04059287912345358, 0.06974134234977619, 0.05205969685422523, 0.08431368254657302, 0.05075433457802449, 0.01931223299886499, 0.022244908846914768, 0.013939980334336204, 0.012965505659979368, 0.03489868110045791, 0.02226711220906249, 0.08818805643490382, 0.018596066428082328, 0.02441396308131516, 0.07788155054939644, 0.026421753290508474, 0.04867830240566816, 0.022230963255943995, 0.08527971963797297, 0.08869846404663154, 0.18617394140788487, 0.11258568548198257, 0.1179459560662508, 0.09715389925986528, 0.08150366547384433, 0.11252133322081395, 0.07761540197368179, 0.1270111296325922, 0.124388917482325, 0.19084052528653825, 0.11025485662477356, 0.14167361999196665, 0.20767943028892788, 0.12698735376553877, 0.12127879794154849, 0.06575380239103522, 0.12442395703068801, 0.1598421415047986, 0.09703944397291966, 0.13667264048542294, 0.09433855568724019, 0.22389373023595127, 0.2767826308097158, 0.0882550956947463, 0.16968635469675064, 0.08787906515811171, 0.1001783808959382, 0.11197958407657486, 0.14220232090779714, 0.16885989904403687, 0.11083296846066203, 0.21783479249903134, 0.20391775428184442, 0.13205223770013877, 0.07909519863980156, 0.19814954165901455, 0.2677065464002745, 0.2986751017825944, 0.7727212160825729, 26.094645942960465, 71.42794704437256, 106.58212852478027, 95.09593636648995, 86.64598192487443, 75.08574281420026, 83.47409452710832, 57.07349681854248, 33.798032079424175, 23.256450993674143, 55.03561449050903, 61.34073993137905, 68.30040999821254, 90.93741171700614, 82.57182230268205, 63.62329265049526, 46.967797074999126, 30.0491350037711, 4.681952425411769, 1.1054256090096064, 0.34921030008367127, 0.1354202548308032, 0.35141336758221897, 0.3424093707331589, 0.29990892271910397, 0.3618499147040503, 0.2666824199259281, 0.2996896744838783, 0.08298789297363587, 0.3397857743714537, 0.25088026214923176, 0.3093868898493903, 0.6143028853195054, 0.36521297852907864, 0.6262339193906102, 0.507628278008529, 0.4080333965165274, 0.6002263778022358, 0.3653604377593313, 0.992032419357981, 0.4282580826963697, 0.6643652532781873, 0.94144649377891, 0.6417113574487823, 0.4003739303776196, 0.28401983103581835, 0.5414028742483684, 0.7027113299284662, 1.3013065095458711, 0.7414743527770042, 0.7303621204836028, 0.8161643935101373, 0.2330551472093378, 0.7890949174761772, 0.342514055115836, 0.3856877455753939, 0.7323436598692621, 0.4401432749416147, 0.7257597531591142, 0.42076906455414637, 0.16005639572228703, 0.12329902739397117, 0.15330675004848413, 0.21464554220438004, 0.22545170092156955, 0.30803131258913446, 0.4048574183668409, 0.3526158130594662, 0.2042133512773684, 0.29845384508371353, 0.3178443945944309, 0.1974989487124341, 0.29030949782047955, 1.0122039083923613, 11.137112924030848, 35.00870704650879, 68.80404322487968, 65.51260512215751, 71.10568264552525, 65.46125793457031, 151.90868813650948, 90.25943429129464, 30.600940091269358, 39.48470531191145, 41.54240390232631, 55.520602226257324, 63.32852227347237, 75.81125286647251, 74.42904772077287, 91.05727509089878, 77.4870194026402, 37.974816594805034, 1.9809110079492842, 0.33807917737535065, 0.2136740293353796, 0.13241540321281978, 0.2968697915119784, 0.13929468978728565, 0.1567020985696997, 0.21519660763442516, 0.1232583967170545, 0.11993398224668843, 0.10589047867272582, 0.1927620686058487, 0.23634045092122896, 0.10211622262639658, 0.04762579281149166, 0.1752807537892035, 0.13617386296391487, 0.13583478544439587, 0.12972896093768732, 0.07722097635269165, 0.13083852854158196, 0.1670908632555178, 0.16842635587922164, 0.11472621240786143, 0.16325066717607634, 0.10160939767956734, 0.19039214934621537, 0.24439547583460808, 0.19228186937315123, 0.13810308729963644, 0.06348830967077188, 0.10776081295417887, 0.18002716052745069, 0.12463293224573135, 0.15496609386588844, 0.129208524578384, 0.16580573150089808, 0.16978092890764984, 0.10196449541087661, 0.16249821255249636, 0.13417920071099484, 0.11587814773832049, 0.15420059779925005], [0.004193451588175127, 0.03281855736193912, 0.020035609004220793, 0.014279949279235942, 0.017193502314122658, 0.026561553556738154, 0.0072611168891723666, 0.008991968119516969, 0.010223365837841161, 0.009600448638333805, 0.018749703719679798, 0.021104150684550405, 0.007169761478767863, 0.031760083444948704, 0.05051965306379965, 0.04585489783702152, 0.02860588626936078, 0.019750113698786924, 0.029002004835222448, 0.06312530022114515, 0.025370400598538772, 0.04326652083545923, 0.04648701088236911, 0.036710956533040316, 0.044386229145207574, 0.030634441346462284, 0.029885674560708658, 0.04762877497289862, 0.02316596415559096, 0.015756595846531645, 0.05706951767206192, 0.06608693594379084, 0.044611414561846426, 0.0404785595435117, 0.0245793373323977, 0.07363880678479161, 0.11991657103810992, 0.03804760266627584, 0.10953077155032329, 6.674931151526315, 38.01252099445888, 76.40912451062883, 83.37759099687848, 71.78908661433628, 66.1876643044608, 49.94501331874302, 38.941859926496235, 22.91275487627302, 41.07259103230068, 145.70428030831474, 125.40111596243722, 59.863643237522666, 56.36285938535418, 65.85449818202427, 51.78001172201974, 34.68905864443098, 15.653834581375122, 3.026542374065944, 0.09976748723004546, 0.12483955972961017, 0.0018761200647402021, 0.10300834011286497, 0.11646764539182186, 0.060835081684802256, 0.06033039412328175, 0.07893540364290987, 0.01965441651243184, 0.0321003144739994, 0.02734151598997414, 0.035422018196965964, 0.11052807553538255, 0.11891489050218038, 0.044647146215928454, 0.030707034415432384, 0.06165982742926904, 0.04108577713902507, 0.11428395685340677, 0.29416504236204283, 0.29198216806565014, 0.09320313589913504, 0.13338417480034487, 0.07689191401004791, 0.07978709401296717, 0.033057662924485545, 0.37029547723276274, 0.09771085437387228, 0.10395005172384636, 0.038586315366306474, 0.04963454145139881, 0.06694343034178019, 0.24161570785301073, 0.06956028206540005, 0.14769047498703003, 0.04460847989789077, 0.22594890424183436, 0.026753896182136874, 0.058483238598065715, 0.047012288589030504, 0.12369179060416562, 0.26522584951349665, 0.13064435896064552, 0.02027746263359274, 0.07644213350223643, 0.14111380146018096, 0.051504991083805046, 0.12764003659997666, 0.1352219054741519, 0.07434141622590167, 0.06630395179880516, 0.07695405424705573, 0.054590025184942145, 0.025009855927367295, 0.04878659998731954, 0.014851774488176619, 0.01994362340441772, 0.12763406549181255, 0.5425287538341114, 3.99980651480811, 15.693520954677037, 34.35690695898873, 42.86334678104946, 34.423102446964805, 43.72355808530535, 66.75783348083496, 50.131586347307476, 31.660814830235072, 17.623416117259435, 26.19805771963937, 33.26033183506557, 43.37441110610962, 54.29146589551653, 67.16836779458183, 68.82490171704973, 50.38447993142264, 7.323719194957188, 0.05291261537266629, 0.22050139441021852, 0.12250754343611853, 0.062197240734738965, 0.007614363068049508, 0.07060044232223715, 0.04232872776421053, 0.03183015575632453, 0.09313240540879113, 0.024013072717934847, 0.05527890107727476, 0.03737034329346248, 0.029635902427669083, 0.04008421873939889, 0.03972554173586624, 0.018161403680486337, 0.049587481655180454, 0.038811707736126015, 0.03494181896426848, 0.08169242713068213, 0.016241483756207993, 0.0033348172603707227, 0.0804469557479024, 0.07347246392496995, 0.03512248230565872, 0.04661474509962967, 0.0403405489133937, 0.025015282511178936, 0.028150557041434304, 0.04820907508422222, 0.02455233672766813, 0.016995750068287765, 0.04235251380928925, 0.0351768092119268, 0.021962463556389724, 0.04289493809587189, 0.03941855892272932, 0.011122786057447749, 0.03457850756655846, 0.0498628718778491, 0.015333844781188028, 0.040065413141357045, 0.015151683573744126, 0.008999076622006084, 0.03676391958392092, 0.009430865773798099, 0.009067342333894755, 0.07572798896580935, 0.02492156155806567, 0.03332749594535146, 0.013298609526827931, 0.00695035293964403, 0.02626544257093753, 0.017363792551415305, 0.0193429791168975, 0.015329050931281276, 0.01742388021999172, 0.018817528383806348, 0.03924023652715342, 0.011499059170351496, 0.06467012089810201, 0.007805335900879332, 0.02015552989074162, 0.04128669475072196, 0.042860346380621195, 0.043894779801900895, 0.021626427570091825, 0.032733777804034095, 0.05698391369410923, 0.022538061420034085, 0.024013459482895474, 0.014137391616324229, 0.05729952747268336, 0.038650389428117445, 0.04087306658870407, 0.03670362835483892, 0.02832381417309599, 0.10975620802491903, 0.09668648362691913, 0.7641626096197537, 15.870925835200719, 60.1899653843471, 92.05780179159981, 95.92502321515764, 92.99871294839042, 89.1234872000558, 73.47489329746791, 65.45468493870327, 40.145395619528635, 44.70054081508091, 121.05749130249023, 74.82201698848179, 34.20509576797485, 45.16895014899117, 58.676863125392366, 53.7360269001552, 33.96356248855591, 11.986859372683934, 0.8351284701909337, 0.2930472509137222, 0.06289185703332935, 0.03364443965256214, 0.08287189062684774, 0.04841891882408943, 0.0800800718633192, 0.07024049985089473, 0.06201280813132014, 0.061253758147358894, 0.1437083836644888, 0.08272992074489594, 0.18075813273234026, 0.2570723013154098, 0.4452287863407816, 0.2824526051325457, 0.3583111917333943, 0.5658240009631429, 0.4963782216821398, 0.8263919247048241, 1.0886106427226747, 1.0622023854936873, 0.8857117901955331, 1.049879646727017, 1.0665039718151093, 0.6984258113162858, 0.7071469404867717, 1.4459626844951083, 0.781662082033498, 0.6471779612558228, 0.47323632346732275, 0.6142243381057466, 0.46628991620881216, 1.593930327466556, 0.8072805245007787, 0.8506275128040994, 0.9686428287199566, 1.4878844235624586, 1.109945303627423, 0.5950974130204746, 0.23377857410481998, 0.4352189020386764, 0.45015850609966684, 0.23812383094004222, 0.3264964489000184, 0.19910129558827194, 0.13802919483610562, 0.10832694864698819, 0.2618747279047966, 0.07547112953449998, 0.6371409626943725, 0.40968587355954306, 0.10817659885755607, 0.10351203022790806, 0.12200845378850188, 0.1590620433645589, 0.06993391737341881, 0.02116436218576772, 0.1224507771964584, 0.15898888371884823, 1.0828934695039476, 13.152396236147199, 35.691864354269846, 48.950243200574604, 39.79885768890381, 40.45473289489746, 29.245079040527344, 24.95110968181065, 21.986705916268484, 18.326905591147288, 40.69368144444057, 52.7761367389134, 65.69770513262067, 71.08055101122174, 81.75730582645961, 79.84225722721645, 69.4653102329799, 16.69138649531773, 0.1348819187177079, 0.4007183276116848, 0.12662517891398498, 0.020512610640642897, 0.014319553671936904, 0.06427783266242061, 0.021805092625852143, 0.06774251389184169, 0.14774815046361514, 0.018680633943794028, 0.07550092400716883, 0.05452967288770846, 0.07768946407096726, 0.014956397802702017, 0.041424668061413934, 0.007705307964767728, 0.014847781309591872, 0.033246458508074284, 0.054003631829151084, 0.07014907404248204, 0.03680841451776879, 0.035056776367127895, 0.04348650188850505, 0.0368156884131687, 0.05240189902750509, 0.015845592499577572, 0.033721256602023325, 0.014997632375785282, 0.025315766655174748, 0.043428609280713966, 0.04457757602046643, 0.02393222357412534, 0.028498945757746696, 0.014754470870164888, 0.03263875236734748, 0.026262938776718717, 0.026950306624972394, 0.018769489800823585, 0.0055746079222964385, 0.03795801908043878, 0.05838546848722866, 0.12939782227788652, 0.13979491937373364, 0.15224553485001835, 0.16495878409062112, 0.08623502230537788, 0.13631598890892097, 0.17392141744494438, 0.1547369390193905, 0.1021434250952942, 0.08568115452570574, 0.07336813916585275, 0.16611644625663757, 0.09564030476446662, 0.10571667192769901, 0.11072206191186394, 0.12308854583118643, 0.09670133675847735, 0.14657667332461902, 0.07396351293261562, 0.11194172182253428, 0.0986065680959395, 0.09797637191201959, 0.1967477561639888, 0.15030419187886374, 0.2175622656941414, 0.18049837595650128, 0.14207852897899492, 0.12797796060996397, 0.14146567615015165, 0.19589422696403094, 0.10052564833313227, 0.18077893661601202, 0.16963108123413154, 0.2227359459336315, 0.09607565961778164, 0.23932597786188126, 0.1639268273221595, 0.19944411862109387, 0.54813828425748, 13.506910698754446, 62.99033955165318, 102.57980632781982, 108.58584308624268, 92.51806436266217, 85.40114266531808, 68.47297545841762, 50.25891556058611, 31.564085483551025, 50.31325742176601, 155.22389602661133, 140.08192307608468, 78.09469495500836, 78.21997792380196, 95.76768125806535, 71.25351946694511, 52.63152040754046, 24.961257525852748, 4.5486438529832025, 0.681834870151111, 0.21245628967881203, 0.11392688458519322, 0.2921000431690897, 0.23394853355629103, 0.18403347555015767, 0.1465169893843787, 0.19621516045715126, 0.2347592200551714, 0.35125233765159336, 0.2979668197887284, 0.2236940645213638, 0.4613165259361267, 0.31298100841896875, 0.271000155380794, 0.12448604298489434, 0.33811969948666437, 0.39806134732706205, 0.42209201785070555, 0.7581992638962609, 0.7287653918777193, 0.49394521223647253, 0.7845250655497823, 0.47720396199396675, 0.24972322423543247, 0.4725017143147332, 0.8279548894081796, 0.45335304896746365, 0.42916639681373325, 0.22651340466524872, 0.39853092070136753, 0.3650558298187596, 1.1053921708038874, 0.36691360441701754, 0.37147102558187073, 0.33989398713622776, 0.6494621815426009, 0.5028066624488149, 0.25653859281114166, 0.14019448150481495, 0.2978073369179453, 0.2470721879175731, 0.3223515770265034, 0.23430872708559036, 0.23372608263577732, 0.31325812212058474, 0.2557061660502638, 0.4962332866021565, 0.45660901282514843, 0.46548115674938473, 0.2699856369623116, 0.27373739278742243, 0.1745062739189182, 0.23368504483784946, 0.2791088931262493, 0.23077279967921122, 0.12148410906749112, 0.40955003084880964, 1.122114422065871, 6.972599361624036, 26.34641739300319, 52.65590858459473, 62.63225718906948, 50.923701831272666, 64.58090032849992, 94.18191473824638, 65.09537969316754, 44.85021196092878, 26.168838807514735, 33.75621782030378, 46.63198716299874, 61.46283367701939, 71.62845121111188, 84.2773688180106, 91.96400805882045, 73.72297177995954, 13.217120443071638, 0.1564641363386597, 0.42308493171419415, 0.28071471410138266, 0.18820186544741901, 0.09537161846778222, 0.1523437595793179, 0.13616999531430857, 0.18543239762740477, 0.36410452372261454, 0.08110071745301996, 0.09270768998456852, 0.13582957429545267, 0.150393419233816, 0.06473391676055533, 0.1419648336512702, 0.09834075878773417, 0.1348266452550888, 0.13095360808074474, 0.18461530575794832, 0.22730345012886183, 0.07151494467897074, 0.09700874026332583, 0.18325866998306342, 0.1974458194204739, 0.11971404190574374, 0.13773959609014647, 0.11027770968420164, 0.10103146904813391, 0.0795605175995401, 0.15588567166456155, 0.14895617349871568, 0.1460798228425639, 0.09934693122548716, 0.14858046865889005, 0.14526445445205483, 0.11804487290126936, 0.1586014809353011, 0.11413200572133064, 0.12083553815526621, 0.08971843788666384, 0.14596854309950555], [0.011975840282892542, 0.025079366751015186, 0.025937404816171954, 0.03009442925187094, 0.09634452233357088, 0.022015721770003438, 0.06255484904561724, 0.07182053649531943, 0.014430697707991515, 0.069115210590618, 0.0346388327223914, 0.14990718103945255, 0.03324834144275103, 0.05018173583916255, 0.03704348618962935, 0.0644006882128971, 0.03393988058503185, 0.03361867228522897, 0.027998426097578237, 0.027045279475195066, 0.022100964428058693, 0.011510093846092266, 0.04186849442443677, 0.03153649937095387, 0.04488193290308118, 0.029037044383585453, 0.042852268421224186, 0.041068121657839844, 0.03410243382677436, 0.005292432349441307, 0.026388404990679452, 0.08041572956634419, 0.08341869485697576, 0.07416896655091218, 0.14936714858881064, 0.03245431976392865, 0.054985801090619395, 4.032851278781891, 44.712092195238384, 79.20893587384904, 87.1021728515625, 89.54963411603654, 59.33510071890694, 50.93525321143014, 39.45711401530674, 37.197931562151226, 25.4106513772692, 28.710436003548757, 20.221496956689016, 36.49519075666155, 88.701842716762, 64.93663419995988, 46.04975938796997, 23.96991286958967, 11.27209210395813, 2.0804721798215593, 0.05415525726441826, 0.17021342712853635, 0.06311270661119904, 0.14371005286063465, 0.10336648446640798, 0.05935283550726516, 0.031131430928196226, 0.14498344595943177, 0.06967752613127232, 0.0663480158629162, 0.015506623545661569, 0.034671884163149765, 0.03209035357992564, 0.10681547796619789, 0.15045399884028093, 0.24889869562217168, 0.13775155187717505, 0.12414787470230035, 0.08469235258443014, 0.11063772679439612, 0.06820427732808249, 0.15863082078950747, 0.2899724287646157, 0.33355212743793217, 0.550927280315331, 3.614959474120821, 3.4599731734820773, 3.691097617149353, 12.189764142036438, 3.18934366106987, 0.9221106341906956, 1.4005060493946075, 1.271062195301056, 1.2390615067311694, 1.6762534528970718, 0.8701014678393091, 1.3246966430119105, 2.1826962488038197, 1.18690159704004, 0.21603765179003986, 0.26649891691548483, 0.5106671378016472, 1.060100012591907, 5.309535001005445, 1.0300489451204027, 1.5603720481906618, 0.5308234819344112, 0.2929525545665196, 0.08353148773312569, 0.10472774785012007, 0.0983389810259853, 0.20478463705096925, 0.6802989925656999, 0.04281115937711937, 0.060239042953721116, 0.04293907340615988, 0.2264829927257129, 0.04631684108504227, 0.03312564195532884, 0.013173105993441172, 0.022308784437232783, 0.1883880283151354, 0.2490637424801077, 1.368318410856383, 20.23231530189514, 32.41815458025251, 45.58876378195626, 61.681556020464214, 52.00368118286133, 58.42103740147182, 54.62188400541033, 29.082336596080236, 23.066344806126185, 25.273514781679424, 42.84867565972464, 41.035053389413015, 54.54113204138619, 60.77837358202253, 66.799161366054, 24.05995978627886, 0.940103645835604, 0.47242604408945355, 0.056657205867980204, 0.038303271268627474, 0.10904632468840905, 0.05221776158681937, 0.0946669327095151, 0.023761746739702563, 0.039059152494051626, 0.011477439348319811, 0.012636066730400282, 0.02200619174566652, 0.048044326781694374, 0.0380018388719431, 0.009676595534464079, 0.0028249346651136875, 0.032119740931583304, 0.030215300087417876, 0.037381627330822606, 0.02864300213488085, 0.024870556080713868, 0.036861024730439694, 0.03801740785794599, 0.03049021872824856, 0.01980404875108174, 0.0143476687704346, 0.04308205769796457, 0.0314540980782892, 0.013615386144790267, 0.004792448307853192, 0.022328258392267993, 0.011608351653973972, 0.0235837093288345, 0.03347983384238822, 0.016659914249820367, 0.03461176596049752, 0.011768791259133389, 0.017529643473348448, 0.06629274240029709, 0.024905524382899915, 0.01996319574703063, 0.033290777022817304, 0.048279279709926674, 0.02527317840472928, 0.061137972931776724, 0.03004733213622655, 0.03635357553139329, 0.03914293121280415, 0.02511637913994491, 0.03619122924283147, 0.08395482573126044, 0.026284799478682022, 0.06868317377354417, 0.094240853429905, 0.01554914903161781, 0.06389631956283535, 0.045102246438286135, 0.04798286168703011, 0.05202267937628286, 0.014465323349993144, 0.005923621314910373, 0.06159750398780618, 0.053726535090910535, 0.0279211562259921, 0.027356341980131607, 0.025598076238696064, 0.028935732319951057, 0.04276742100981729, 0.039000839194548984, 0.027870337345770428, 0.029999240966779844, 0.08309534577918903, 0.030517000505434613, 0.040287226238953214, 0.2777678636567933, 0.08166754525154829, 0.16518526550914558, 12.23924400125231, 67.57716505868095, 98.1176870891026, 102.4777581351144, 106.40698528289795, 74.27172660827637, 75.24063900538853, 66.47789750780377, 47.94903557641165, 24.611683232443674, 13.6311514377594, 15.251544305256434, 33.945601395198274, 72.20717361995152, 60.67880589621407, 50.037695339747835, 25.947799239839824, 8.603124005453926, 0.7018050242747579, 0.28082591242023874, 0.2532083972224167, 0.1688535479562623, 0.12959200542952332, 0.041888297468956025, 0.0558054137176701, 0.062476091486002715, 0.09811929852834769, 0.11099511797406844, 0.2212561017700604, 0.2006931116006204, 0.2845393717288971, 0.22649471781083516, 0.5487645992210933, 1.0528108094419752, 1.1723888729299818, 1.749090007373265, 1.4770965852907725, 1.0179335666554314, 1.138793898480279, 1.718555171574865, 1.8206914109843118, 1.8563879983765739, 4.417577377387455, 4.6966730526515414, 15.159574474607195, 12.595514621053423, 11.780361516135079, 18.140117168426514, 8.535008209092275, 4.618604396070753, 4.930512939180646, 6.8736370376178195, 8.319908482687813, 5.611907575811658, 5.077691418784005, 6.271732832704272, 5.46376633644104, 2.3618171172482625, 1.2340391533715385, 0.32796772995165413, 0.6120578572154045, 0.9610265174082347, 1.4558032878807612, 0.379117843828031, 0.6052954686539513, 2.0102593302726746, 0.18943428860179015, 0.18146957669939312, 0.09204717007066522, 0.16511711345187255, 0.5210606658032962, 2.353932648897171, 0.22060111191655907, 0.17793742194771767, 0.2429361641407013, 0.20457852525370462, 0.3263995540993554, 0.18406198759164127, 0.022296996587621312, 0.010062262964701014, 0.13899894351405756, 0.38875491384949, 0.4268708314214434, 16.07007336616516, 34.53549650737217, 50.81601170131138, 62.49425901685442, 37.8395733833313, 34.51227215358189, 25.543683324541362, 18.874534811292374, 28.4689895766122, 43.785442216055735, 69.2745474406651, 62.256644521440776, 69.80430589403424, 70.96762888772147, 83.93749073573521, 41.83477020263672, 4.1706796543938776, 0.2545965441635677, 0.025480233365669847, 0.020933198875614574, 0.18429393800241606, 0.04244285735434719, 0.033628728174205334, 0.0377508250198194, 0.010860427947981017, 0.0027064473958619472, 0.00431056970098455, 0.05370855052024126, 0.06571993670825448, 0.024388536677828858, 0.048569696090583286, 0.05985182337462902, 0.016730843211657236, 0.04398621239566377, 0.03833980020135641, 0.07240358128079347, 0.029766924147095, 0.045427027224962196, 0.04465599770524672, 0.04388550762087107, 0.02863893431744405, 0.04010366555303335, 0.014429155737161636, 0.05079746226380978, 0.02099652315622994, 0.011025741130911877, 0.026293800245704393, 0.02521812546599124, 0.04826230276376009, 0.024586833448016217, 0.015122856013476849, 0.03888295730575919, 0.0351155612484685, 0.02427369462592261, 0.012846387989286865, 0.03396980058667915, 0.10944936770413603, 0.15386514365673065, 0.1504956880318267, 0.07909878130470004, 0.16488593657101902, 0.14155544633311884, 0.18264151524220193, 0.15493560050215038, 0.11085018967943532, 0.10048289384160723, 0.17058392081941876, 0.2644693915333067, 0.09513954592070409, 0.1539589443377086, 0.1175013527806316, 0.19348766681339058, 0.09751703084579535, 0.07228622186396803, 0.12289490550756454, 0.09885607899299689, 0.15161015465855598, 0.16788123441593988, 0.12018210893230778, 0.12040462770632335, 0.12889714485832623, 0.10163111080016408, 0.15513510336833342, 0.13130754551717214, 0.1280263401567936, 0.10786454060247966, 0.14373682785247052, 0.18678466363676957, 0.21717414366347448, 0.14885664598218032, 0.348584310816867, 0.1831559669226408, 0.2506263814866543, 10.908313087054662, 69.90527711595807, 109.30586406162807, 114.2157530103411, 111.30568763187954, 77.01338154929024, 70.898654120309, 54.885147775922505, 45.94009596960885, 36.23552615301949, 39.870490142277305, 27.292815889630997, 45.74873563221523, 110.2619639805385, 88.240079334804, 66.47149126870292, 39.62290498188564, 18.33083827154977, 3.520179097141538, 0.5785190654652459, 0.5748975883637155, 0.22061827885253088, 0.5539990897689546, 0.2693339176476002, 0.20517471326248987, 0.18751127964683942, 0.3720945178398064, 0.19657375264380658, 0.15365470280604704, 0.19693929302905286, 0.3035412835223334, 0.14864933996328286, 0.2517179272004536, 0.5567629528897149, 0.3256943662251745, 0.4998612233570644, 0.5000857913068363, 0.5177879014185497, 0.5443943994385856, 0.5222923425691468, 0.8311949212636266, 0.8189719542860985, 2.10631730726787, 3.0931360806737627, 12.421057513781957, 9.675631437982831, 13.56085911818913, 24.28629388128008, 9.933665820530482, 4.09002149105072, 5.106415271759033, 5.573413252830505, 4.824349241597312, 6.18073661838259, 4.225499638489314, 4.368281211171832, 5.402082400662558, 2.827625002179827, 1.6706566789320536, 1.3349919191428592, 2.3670276147978644, 2.1077110724789754, 9.944888029779706, 3.751964271068573, 4.301708783422198, 4.165845879486628, 0.8598642200231552, 0.2981274425983429, 0.20514626907450811, 0.27530266450984137, 0.9260974888290677, 2.302450405699866, 0.20406241794782026, 0.28720981414828983, 0.17735491320490837, 0.5172540843486786, 0.2570475754993302, 0.22617491068584578, 0.12547499420387404, 0.10410532089216368, 0.35886829612510546, 0.4310250942196165, 3.352485409804753, 31.854134559631348, 51.9169259752546, 62.80730315617153, 85.32677609579903, 77.1744407926287, 83.18982287815639, 73.1215843473162, 42.01953322546822, 32.75614970070975, 33.23681565693447, 56.65879705974034, 55.3752771786281, 69.11951923370361, 78.68054621560233, 95.32802704402378, 42.00755105699812, 3.02779934661729, 0.4853566959500313, 0.12208701457296099, 0.07768246158957481, 0.265128384743418, 0.12956873167838368, 0.15392019998814377, 0.2268854318452733, 0.12448244674929551, 0.15529678469257696, 0.08774886107338326, 0.10285716929606029, 0.1198383630918605, 0.09396460146776267, 0.0685988183000258, 0.10847106948494911, 0.08603935994740043, 0.1040889478421637, 0.116849918450628, 0.1183007891689028, 0.09906816868377583, 0.17118546925485134, 0.10581482201814651, 0.21158439932124956, 0.0926611628383398, 0.1373280103185347, 0.12194045100893293, 0.1294042140777622, 0.04938158020377159, 0.07708448903369051, 0.09323687944561243, 0.1027137812759195, 0.12583761688854012, 0.1247320119291544, 0.22337725652115686, 0.13714203744062356, 0.1205446230513709, 0.12543046873595032, 0.1462196281978062, 0.11390697636774608], [0.023007585600550686, 0.010119804430619946, 0.03349594904908112, 0.08522264127220426, 0.020361667133069465, 0.044706538386110745, 0.05601437196933797, 0.006921620374279363, 0.024770244856231978, 0.031181798582630496, 0.04554939083755016, 0.07079083246311971, 0.015454228767859084, 0.024300306769354, 0.04850895702838898, 0.03190610418096185, 0.0785597666565861, 0.04958421111639057, 0.01878801889584533, 0.020534695259162357, 0.02463650730039392, 0.04945323350174086, 0.09453829604067973, 0.006457290803414902, 0.09889942380998816, 0.0160039948033435, 0.08829987900597708, 0.08601529909563915, 0.02780701985050525, 0.03378471998231752, 0.041487897347126684, 0.09900038982076304, 0.04925101310280817, 0.07699070192341294, 0.07685568702540227, 0.8049954356891769, 27.062884364809307, 75.02525874546596, 84.43213994162423, 77.1898032597133, 57.86175257819039, 53.56804725102016, 64.4363569532122, 44.156163351876394, 31.899527141026088, 32.963813986097065, 49.17342628751482, 76.06969111306327, 46.92021581104824, 40.062180519104004, 29.902798993246897, 30.120694501059397, 9.877018025943212, 0.6409158972757203, 0.1355110699576991, 0.04250792546996048, 0.13370246200689248, 0.27826273281659397, 0.15786934165017946, 0.058542990391807895, 0.02649649222647505, 0.09703518277300255, 0.08883955183305911, 0.03279807578240122, 0.05554518875266824, 0.0260603282201503, 0.06832588437412467, 0.14409094170800277, 0.06149748792605741, 0.20343613012560777, 0.9615412269319806, 0.6642366573214531, 2.603724079472678, 2.519671503986631, 0.5734292928661618, 0.36537976243666237, 1.933745767389025, 6.169578679970332, 2.9296228204454695, 6.362049860613687, 2.81992227264813, 18.57031488418579, 16.70877957344055, 13.716928686414446, 11.369760325976781, 9.51810622215271, 5.588234628949847, 6.899924678461892, 1.4899841908897673, 1.4920346694333213, 2.950771834169115, 1.370670810341835, 3.5018197851521626, 5.9926957828657965, 5.510993242263794, 3.241144435746329, 2.9121361587728773, 1.2674147167376109, 2.0065585459981645, 0.9435650429555348, 1.125774277108056, 2.214792800801141, 0.1730894927999803, 0.180670615285635, 0.30053078649299486, 0.3738240764609405, 0.19107757828065328, 1.9480948831353868, 2.8705850626741136, 0.5595742048961776, 0.2502383951629911, 0.11408059990831784, 0.09875940810889006, 0.03882877628452011, 0.03345917923642056, 0.07587717167500939, 0.043440297046410184, 0.04108615033328533, 0.05632287130824157, 0.1618356095360858, 0.2013033724256924, 1.5590250747544425, 19.39293122291565, 36.41954919270107, 41.25250768661499, 49.84075212478638, 52.82450662340437, 62.76651723044259, 37.85227121625628, 22.685593945639475, 17.465502670833043, 34.3990512575422, 48.30189984185355, 50.561384541647776, 55.30582993371146, 67.5871913092477, 41.96609115600586, 8.3907253912517, 0.04454585790101971, 0.03701279605073588, 0.12492576081837926, 0.04869867202692798, 0.018674840951072316, 0.027052395611203144, 0.03294716010402356, 0.06297078422669854, 0.058866705878504684, 0.029452735292060033, 0.05182956152462533, 0.07442026199506861, 0.033902330457099845, 0.02030468885121601, 0.03205638950956719, 0.009472710180229374, 0.031139916008604423, 0.012271518702618778, 0.026684890867077878, 0.028391791507601738, 0.06888124493083783, 0.03307226160541177, 0.013467577469002987, 0.05560686758586338, 0.02818485189761434, 0.04423981485888362, 0.02773076608510954, 0.05394745930763228, 0.10071608597146613, 0.03745225943358881, 0.01964253536425531, 0.03214749301384602, 0.06583148786532027, 0.021790171640792062, 0.04021489779864039, 0.04598084750718304, 0.022946966978322183, 0.06562424969992467, 0.02240004570090345, 0.00954155603955899, 0.03909577302900808, 0.047968978860548565, 0.025176531269348094, 0.07069465690957648, 0.03803907008841634, 0.009705662278325429, 0.0614213834383658, 0.037331202000911744, 0.013739798933134546, 0.08136513576443706, 0.11131238059273788, 0.03657675587705203, 0.07312339158462626, 0.060090206297380586, 0.05694219057581254, 0.04800884957824435, 0.04232200348217573, 0.0233764202733125, 0.07275135761925153, 0.020323255265663778, 0.08071741980633565, 0.0839187955217702, 0.06004737038165331, 0.08524843238826309, 0.03265325605337109, 0.05377804946952632, 0.07847888528236321, 0.03655948376815234, 0.02328624127299658, 0.09550849255174398, 0.05014022645939674, 0.1471716942531722, 0.1154176260211638, 3.348829354558672, 46.642548424857004, 98.75075830732072, 93.09433405739921, 93.31413337162563, 78.78769438607353, 78.42549174172538, 100.07796846117292, 63.320351191929404, 34.68777322769165, 17.135060242244176, 21.928269829068864, 44.650722231183735, 37.53957796096802, 42.96094117845808, 39.8417523929051, 31.058489390781947, 7.454612834112985, 0.21572920334126267, 0.2416456448180335, 0.07981731596269778, 0.3101891896554402, 0.25384109041520525, 0.05544779183609145, 0.16262709349393845, 0.042306152904140096, 0.1970474243696247, 0.17169000075331756, 0.2395791799894401, 0.2367027343383857, 0.1841936505266598, 0.5180902566228593, 0.8794276873980249, 1.783502263682229, 3.3938339224883487, 4.032073949064527, 3.5689478516578674, 7.666911567960467, 6.116491402898516, 4.720036804676056, 5.349637397697993, 5.608597193445478, 16.21627562386649, 8.786672830581665, 11.22308645929609, 9.448473112923757, 14.877307380948748, 16.10196907179696, 18.932838882718766, 11.515809723309108, 16.220930916922434, 9.248328515461512, 8.733356697218758, 6.506921104022434, 8.944681814738683, 7.55867166178567, 3.560665164675031, 3.760106691292354, 0.8154905810952187, 3.3979114294052124, 2.0493231884070804, 1.0360169048820222, 2.118914608444486, 1.7911090212208884, 2.559271893330983, 1.4148551651409693, 1.9174109867640903, 0.7133525503533227, 0.6978950883660997, 0.2885503007897309, 0.32843477917569025, 0.2840809534702982, 0.5001460452164922, 0.9525559033666338, 0.6891756962452615, 0.5671405217477253, 0.4460472895630768, 0.12617417025778974, 0.3758570488010134, 0.11480201834014483, 0.18560330702790193, 0.10225566835807902, 0.04222186867679868, 0.084980994596013, 0.06767897587269545, 0.4943777918815613, 0.3158946649304458, 13.127303685460772, 37.427333286830354, 47.65372323989868, 52.086600984845845, 40.98217064993722, 32.99082858221871, 20.15619604928153, 20.690086943762644, 25.801350321088517, 52.95508411952427, 74.43368216923305, 72.79415743691581, 69.35464627402169, 76.44962556021554, 60.673963001796174, 18.99298596382141, 0.05807338309075151, 0.11299430605556283, 0.16472888285560267, 0.08512110529201371, 0.05917164630123547, 0.0670735462169562, 0.04007649361821158, 0.02821698222708489, 0.02052243922038802, 0.05782332258032901, 0.037941822449543645, 0.020619954880593077, 0.049881976031299145, 0.03419531509280205, 0.04583942045324615, 0.04888635142041104, 0.03868328141314643, 0.03152866568416357, 0.04414814817053931, 0.04105770614530359, 0.02154413653936769, 0.03481341299733945, 0.04663386960913028, 0.012567512641128684, 0.0448195212520659, 0.0252659638811435, 0.05031910525368793, 0.031819479007806094, 0.054376249334641864, 0.024569579998829534, 0.06483267753251962, 0.0678618885576725, 0.06734804755875043, 0.03148146339559129, 0.03779273134257112, 0.02566664559500558, 0.030231771524995565, 0.07130107044109277, 0.11018684705985443, 0.04735872142815164, 0.12787448401962007, 0.1735740075153964, 0.13704996023859295, 0.2312163987330028, 0.17194719266678604, 0.08144404260175568, 0.07984554301947355, 0.18700140129242623, 0.09765986246722085, 0.20182588510215282, 0.19111332350543567, 0.20560870426041739, 0.15900655277073383, 0.09120103011706046, 0.11953300876276833, 0.1283651598330055, 0.15445507557264396, 0.14601236289100988, 0.08535228217286722, 0.13882358292383806, 0.2535315155982971, 0.15643650639270032, 0.1872487273067236, 0.16745872423052788, 0.23095670981066568, 0.18923170518662247, 0.10266489282782588, 0.21464030391403607, 0.2025199042899268, 0.21199399019990647, 0.22421133890748024, 0.183772348133581, 0.2523079812526703, 3.4004412250859395, 53.14142090933663, 111.73945672171456, 104.7088872364589, 96.69093704223633, 75.89327635083879, 70.35499926975795, 83.25508730752128, 55.67804840632847, 42.8012819971357, 50.598282950265066, 66.21653406960624, 98.43137046269008, 69.36285209655762, 57.99123573303223, 49.255262170519146, 47.030858925410676, 16.678261348179408, 1.3622246235609055, 0.5204179031508309, 0.20698915661445685, 0.5194190996033805, 0.6652382292917797, 0.45989692211151123, 0.2112585532345942, 0.08797593281737395, 0.18979790194758347, 0.3301319581057344, 0.2022457897130932, 0.33127906226686066, 0.19480551752660955, 0.32845440240842955, 0.48541651559727533, 0.7663942841546876, 1.0464522306408202, 2.482804362262998, 2.7319719748837605, 5.624010469232287, 5.08744842665536, 3.4414976962975095, 4.990261801651545, 7.029991047722953, 15.433701753616333, 9.62550973892212, 14.803890977587018, 12.630193080220904, 35.369426250457764, 32.234346934727256, 32.23283570153372, 21.986233438764298, 21.265493324824742, 13.344640731811523, 16.71727548326765, 9.052552597863333, 5.233494784150805, 5.919970725263868, 3.6991306032453264, 8.7348427431924, 11.779895118304662, 18.371796165193828, 13.478966781071254, 7.028822013310023, 5.031164109706879, 4.631193229130336, 11.46096932888031, 5.1419422796794345, 6.064026423863002, 1.933345377445221, 1.3195787519216537, 1.2028999328613281, 0.9672990036862237, 0.7397221582276481, 3.6890096834727695, 6.148555602346148, 1.2116473891905375, 0.873385197349957, 0.4940810820886067, 0.13376247164394173, 0.20324958727828094, 0.1984993400318282, 0.41195304904665264, 0.26471629685589243, 0.13728382411812032, 0.24098203756979533, 0.2892155908048153, 0.6934159430009978, 3.0564128969396864, 28.867932558059692, 51.96083511625017, 58.610799653189524, 67.96670886448452, 78.34804017203194, 84.05826432364327, 50.96178490774972, 32.16550418308803, 23.314491033554077, 44.78597239085606, 63.990949630737305, 67.62245341709682, 68.33285113743374, 88.19272041320801, 67.08331489562988, 17.425408090863908, 0.13592013157904148, 0.1455562109393733, 0.29851567319461275, 0.23945329817278044, 0.20733569801918098, 0.139209669349449, 0.19143926458699362, 0.11525107281548636, 0.12171667015978269, 0.16377906953649862, 0.1724544654467276, 0.1022294226235577, 0.13385551236569881, 0.10328446315335375, 0.14035236303295406, 0.1345481609127351, 0.1002659322693944, 0.11636511875050408, 0.1569724404918296, 0.1458948813378811, 0.12057854980230331, 0.06863860080816916, 0.11208197501088892, 0.162007319607905, 0.09259774695549693, 0.2287630603781768, 0.11884672487420694, 0.16636124812066555, 0.1962810597781624, 0.1322073508054018, 0.1423597274614232, 0.17196081764996052, 0.10615169429885489, 0.11254238816244261, 0.09310121315398387, 0.13833623193204403, 0.1808612429137741, 0.18645034943308147], [0.03397512708657554, 0.013572185516490467, 0.18661916894572123, 0.06283323160771813, 0.04531529286344137, 0.03801865975505539, 0.025075254828802178, 0.02834277753052967, 0.08422666721578155, 0.017423120260770832, 0.04469474884016173, 0.03352466804374542, 0.06651926453092269, 0.041646036718572886, 0.05443046088995678, 0.146450560806053, 0.04760450377528157, 0.05315280659124255, 0.0263157372828573, 0.040788405774427314, 0.044413207697549036, 0.04007580490516765, 0.023214477713086774, 0.031118942491178, 0.07771636119910649, 0.011750709997223956, 0.03446048657808985, 0.04171011417305895, 0.05786388540374381, 0.08888020965137652, 0.09954473096877337, 0.014918620365538766, 0.10376275570264884, 0.05454090603494218, 8.674755590302603, 53.47580296652657, 95.01057079860142, 72.6953123637608, 77.49018778119768, 58.201067856379915, 65.78185476575578, 44.2209518296378, 18.916479349136353, 38.76106085096087, 45.04154450552804, 59.672741481236045, 56.353166648319785, 38.452703271593364, 56.17770031520298, 49.70165613719395, 15.938271250043597, 0.8438149669340679, 0.0630468072901879, 0.04970093610297356, 0.10286352038383484, 0.08292925397732429, 0.04259472366954599, 0.10823800627674375, 0.12643391346292837, 0.11232263781130314, 0.114289860108069, 0.044410737830081155, 0.0737960912021143, 0.2085580245724746, 0.1004840609218393, 0.07337092115942921, 0.4212798928575856, 0.6512637734413147, 0.8501576408743858, 3.8761576754706244, 3.3670892204557146, 4.882603807108743, 9.991130028452192, 6.782927002225604, 3.6964425189154486, 3.3334330150059293, 11.290835738182068, 10.189495018550328, 4.926207227366311, 9.361327069146292, 6.626600784914834, 8.017287509781973, 18.90482895714896, 13.200893793787275, 8.288796186447144, 14.268037217003958, 12.874121751104083, 17.26104324204581, 15.656455789293561, 27.242682899747575, 11.907358084406171, 6.883681961468287, 8.041177153587341, 5.531026201588767, 4.728254786559513, 2.21927547454834, 0.5585536882281303, 1.6745040267705917, 3.3615569344588687, 2.978937877076013, 4.421709384237017, 2.477715675319944, 1.3754583363022124, 0.7169969890798841, 1.238524432693209, 1.5461713416235787, 0.7516908102801868, 0.58591314298766, 0.4869022901569094, 0.08901984537286417, 0.7370985618659428, 1.7389910178525108, 0.3571850135922432, 1.6701672651938029, 0.054140404132860045, 0.1313111146113702, 0.02766103813025568, 0.05463315287072744, 0.11246213782578707, 0.10266487925712552, 0.05915675245757614, 0.08443877726261105, 0.5099070157323564, 2.08808154293469, 22.348488194601877, 58.16600724628994, 61.154500416346956, 51.45662866319929, 48.802580084119526, 59.253862380981445, 44.807991232190815, 27.484488895961217, 19.417911733899796, 35.48958492279053, 50.752626759665354, 49.24986342021397, 60.94362258911133, 63.74760981968471, 26.446945667266846, 0.988031668322427, 0.29588860273361206, 0.09826401647712503, 0.09869960203234639, 0.04323236338262047, 0.061147167081279416, 0.02918056471805487, 0.027013296727091074, 0.0363965437614492, 0.043834824447653124, 0.037385847818638594, 0.04836867330595851, 0.06453418997781617, 0.09958606053675924, 0.013229032546015722, 0.05591388093307614, 0.09639260332499232, 0.01027227209747902, 0.012665388773062398, 0.029295881744474173, 0.05951440826590572, 0.026425098468150412, 0.025231209317488328, 0.028828537357704978, 0.023125379279788052, 0.047185783207948716, 0.04535805414031659, 0.012622928596101701, 0.022118192432182174, 0.026789224107882807, 0.053318599837699106, 0.02331750138130571, 0.020033605629578233, 0.07907089351543359, 0.011344008829577692, 0.01556277571112982, 0.028733817261776755, 0.022424613757591163, 0.04501494951546192, 0.06519025870199714, 0.08203178284955875, 0.07344051171094179, 0.04030804369332535, 0.015061686081545693, 0.02179111650080553, 0.009402614120127899, 0.04394627721714122, 0.01267383823038212, 0.030533095356076956, 0.034475773972059996, 0.04567319294437766, 0.03321198553645185, 0.13015631586313248, 0.042521065300596614, 0.05208409358082073, 0.019526879070326686, 0.014540194600288357, 0.008797690821146327, 0.06479095441422292, 0.03758285367595298, 0.010649272091021495, 0.04898218431376985, 0.04214499405186091, 0.026635305224252597, 0.025886261935478876, 0.021807645613859807, 0.0549744525924325, 0.060165313338594775, 0.05986859676029001, 0.11414955263691288, 0.09022645026977573, 15.838316202163696, 76.2619686126709, 108.98546178000313, 84.69567816598075, 99.03742013658795, 82.7373492377145, 102.2080499104091, 61.00350216456822, 26.096247502735682, 27.107639448983328, 18.97953598839896, 44.73199878420149, 40.079596178872244, 42.235090664454866, 59.25534929547991, 48.71418162754604, 11.314956409590584, 0.05797003542206117, 0.36276023728506906, 0.1228360900921481, 0.11578372280512537, 0.039767325922314606, 0.14377516508102417, 0.27971341354506357, 0.37280638249857084, 0.4226210851754461, 0.3999127165547439, 0.7218410234366144, 0.8784571109073502, 0.8175100098763193, 0.705698946756976, 1.9117121611322676, 3.1998649707862308, 3.0094396003655026, 5.1794004525457105, 5.43349781206676, 6.970262161323002, 7.375187107494899, 8.643892560686384, 9.549363562038966, 6.763865487916129, 7.010815322399139, 13.892055426325117, 13.075486625943865, 14.053880708558218, 12.192501732281276, 11.963945950780596, 13.259182231766836, 21.52690713746207, 17.087308747427805, 13.788096479007176, 13.491460510662623, 15.416112388883318, 19.485387427466257, 14.513375503676277, 10.278393745422363, 4.414976145539965, 0.8701732297028814, 2.0269050427845547, 1.9927446586745126, 3.4061046583311896, 1.7475224286317825, 3.2734513878822327, 4.337752997875214, 8.018412249428884, 7.524159090859549, 9.429977008274623, 7.148015320301056, 4.4663554685456415, 3.488759560244424, 3.308396701301847, 2.7524066269397736, 1.0487987675837107, 1.0171103136880058, 0.7277643084526062, 0.17521916995091097, 0.09797029902360269, 0.16837763706488268, 0.6902555440153394, 0.6344429446118218, 0.2251411625849349, 0.056804492071803124, 0.019852988089301755, 0.15578389141176427, 0.2849373460880348, 0.10210215659546, 0.058900775121791024, 0.05810116909976516, 0.48762739981923786, 0.6714751060519899, 17.81219867297581, 57.678872517177034, 69.03493881225586, 50.936778341020855, 30.66818823133196, 26.99572307722909, 18.05841851234436, 21.13260555267334, 29.3268906048366, 61.13731057303292, 81.58827699933732, 66.64031164986747, 73.20448330470494, 79.76248495919364, 43.83013302939278, 2.1219246983528137, 0.5270781857626778, 0.11234608798154763, 0.09716449797685657, 0.07392856159380504, 0.029262711560087543, 0.025420856462525468, 0.07852178905159235, 0.04920667762468968, 0.04570254636928439, 0.02851035532408527, 0.03601455908002598, 0.04794997309467622, 0.038898678962141275, 0.07661062053271703, 0.0366156800383968, 0.11648843570479325, 0.04244502527373178, 0.011318529839627445, 0.01515494563084628, 0.029986959482942308, 0.07850370609334537, 0.047388183418661356, 0.05337130165259753, 0.014636047849697726, 0.016674903088382313, 0.03654165865321245, 0.029372132117194787, 0.04341301993866052, 0.029235716044370617, 0.06654821083481822, 0.040556716599634716, 0.07990747969597578, 0.06523242286805596, 0.016756758160356964, 0.03977117660854544, 0.025001813591058766, 0.08917204077754702, 0.08794772611664874, 0.29228436042155537, 0.19215776531824044, 0.1753663577671562, 0.14699665935976164, 0.09935245450053896, 0.08727334373231445, 0.23745902947017125, 0.1072669073141047, 0.13724038430622645, 0.14261842572263309, 0.10943602092031922, 0.125411863305739, 0.14931456212486538, 0.1771190408617258, 0.12550248844282968, 0.09564337174275092, 0.09476210403123073, 0.12759365194610187, 0.16335402163011686, 0.27618484145828653, 0.10223283565470151, 0.15656603872776031, 0.11298095248639584, 0.16587446709828718, 0.14825891091355256, 0.15774268630359853, 0.17906617852193968, 0.14969090478760855, 0.1374964905636651, 0.19300989673605987, 0.20398843048938683, 0.17137149641556398, 16.806754384722026, 82.97067669459751, 125.55025209699357, 90.83716310773576, 100.20435619354248, 77.18559959956578, 84.7924040385655, 54.37821762902396, 24.62913015910557, 51.24134220395769, 61.98540769304548, 77.26100145067487, 77.20437363215855, 56.209842681884766, 74.90013558523995, 69.11587142944336, 22.87010509627206, 1.6582255916936057, 0.5383696598666055, 0.16111071700496332, 0.5843558779784611, 0.43193419543760164, 0.13615829737058707, 0.39828130123870714, 0.32664222536342485, 0.24832492641040257, 0.35961682881627766, 0.5130510755947658, 0.49914984724351336, 0.5368012126002992, 0.5632757491299084, 1.9424084339823042, 2.5281654596328735, 2.6473939418792725, 4.830385489123208, 8.771359869412013, 9.88223351751055, 14.699827807290212, 21.668617384774343, 17.02646163531712, 11.558938929012843, 14.789482150759016, 25.23382146017892, 21.691704511642456, 22.2499748979296, 21.086731808526174, 18.567744050707134, 24.99568932397025, 40.025153568812776, 26.605543511254446, 19.179760490145, 23.911257914134435, 23.705287252153667, 32.20477887562343, 29.457391670772008, 39.13936594554356, 22.68971422740391, 19.038008553641184, 22.568146807806833, 11.193028552191597, 11.924309083393641, 6.04072824546269, 2.992081480366843, 2.085089692047664, 4.3725999508585245, 3.141242367880685, 5.8747440321104865, 4.023462525435856, 2.150498730795724, 1.7645603886672427, 2.935422177825655, 3.664266279765538, 2.0469840339251926, 2.903368183544704, 2.7204034413610185, 1.0845045830522264, 6.267521790095738, 5.873499436037881, 1.3259664263044084, 3.8833547064236233, 0.2679961994290352, 0.23330685655985559, 0.09209103057427065, 0.6062114909291267, 0.46250369080475395, 0.3133078994495528, 0.2219350574804204, 0.2012835592031479, 0.7553343804819244, 5.027119389602116, 32.883600507463726, 75.52785669054303, 76.90547602517265, 73.65153735024589, 71.18746989113944, 78.57029914855957, 57.30180767604283, 36.29281752450125, 23.55740179334368, 46.08173847198486, 68.80423082624162, 64.04003865378243, 77.34208692823137, 91.51632172720772, 45.50488860266549, 1.5929295697382517, 0.45098526030778885, 0.3043616595012801, 0.14271510339209012, 0.19889544163431438, 0.1738768784063203, 0.157971786867295, 0.16787341769252503, 0.08372365563575711, 0.12474650543715272, 0.10722745728812047, 0.08560998298759971, 0.269056179693767, 0.2498792872897216, 0.11815919248121125, 0.13196413671331747, 0.21020211492265972, 0.16398971394768783, 0.058424029632338455, 0.12329460334564958, 0.19041637304638112, 0.10950150633496897, 0.092773019336164, 0.10298689840627567, 0.1326881471489157, 0.12381543325526373, 0.12741261880312646, 0.12834617442318372, 0.11813194251486234, 0.13128800370863505, 0.12035879945116383, 0.13255590067378112, 0.18293302745691367, 0.15209312231412955, 0.19639946413891657, 0.12959708087146282, 0.07734926018331732], [0.0183293512756271, 0.01728194596112839, 0.07755857466586999, 0.07213685595031295, 0.06277841276356153, 0.06440404017588922, 0.08663626720330544, 0.016950311970763972, 0.045549896346139054, 0.06938372046819755, 0.0457822131658239, 0.03271598322317004, 0.06545828681971345, 0.026886507369843975, 0.03915685475138681, 0.05032900507961001, 0.06134079383420093, 0.007161268764840705, 0.017259040315236365, 0.0403909029971276, 0.04540841840207577, 0.023257191492510692, 0.039277671304132254, 0.016651581839791367, 0.06874307484499045, 0.18272363155015878, 0.21631468406745366, 0.1657785629587514, 0.07435987237840891, 0.137262599542737, 0.1073836764054639, 0.08267209599060671, 0.018758159962349703, 11.688536729131426, 82.68543924604143, 84.99026094164167, 76.88794572012765, 74.05706201280866, 57.77752651487078, 37.52017511640276, 21.704523938042776, 34.51053510393415, 55.93958902359009, 65.02898965563092, 70.75004604884556, 41.16208035605294, 51.407504899161204, 70.96521091461182, 29.630940301077707, 0.711603612772056, 0.7065787081207547, 0.043945853132754564, 0.3206970643784319, 0.0780219869422061, 0.022446155548095703, 0.030360964592546225, 0.021333558285342794, 0.04692777705245784, 0.18521131734762872, 0.30916229475821766, 0.17636119867009775, 1.2382959020989281, 0.24591916693108423, 1.9651581389563424, 0.9484524492706571, 1.6202055918318885, 1.0297053349869592, 1.3471786252089908, 7.069219274180276, 14.307980673653738, 7.3841059889112195, 6.603313897337232, 11.709463834762573, 8.151168874331884, 7.4499384335109164, 7.084093630313873, 4.923024952411652, 7.085113278457096, 9.088100450379507, 6.869488963059016, 10.955387132508413, 0.9960815906524658, 5.050556966236659, 17.220137459891184, 16.003787551607402, 9.304859059197561, 8.167950510978699, 10.174485172544207, 12.735843913895742, 21.612041677747452, 9.596428053719656, 4.0946924175534924, 2.56446002636637, 0.6836311966180801, 11.057886958122253, 32.03200149536133, 53.60150630133492, 56.49266563143049, 61.38087967463902, 62.97963237762451, 58.53801727294922, 53.097185203007285, 47.47821521759033, 39.25121457236153, 33.20086220332554, 23.676316738128662, 14.470461692128863, 8.809135488101415, 3.22938243831907, 1.4572892252888, 0.6683121014918599, 0.456488450723035, 0.04987971650968705, 1.3594309048993247, 0.3735753526645047, 0.6512470000556537, 0.1495270657220057, 0.07371691295078822, 0.046066251317305226, 0.12886411377361842, 0.11458709915833813, 0.054838290970240317, 0.11033788895500557, 0.2523696736565658, 0.33757394020046505, 3.7549711040088107, 42.665180683135986, 71.97651427132743, 56.10826349258423, 50.116863114493235, 60.60739231109619, 63.91789627075195, 37.360429082598, 25.166813032967703, 22.066855124064855, 30.263799599238805, 43.514406885419575, 58.9091830934797, 63.41119194030762, 34.0074577331543, 3.8412612165723528, 0.23540903947183064, 0.11400087204362665, 0.040282642734902244, 0.0996481329202652, 0.04440402372607163, 0.03327587300113269, 0.04552203230559826, 0.037399323524108956, 0.009145804730776166, 0.06529538413243634, 0.06770567622567926, 0.02076345825168703, 0.035153834016195366, 0.013707974792591162, 0.009082990199593561, 0.013820205332844384, 0.05549153359606862, 0.05966121610254049, 0.027847496160705174, 0.01951050093131406, 0.08459964434483222, 0.021973125037870238, 0.041707698588392565, 0.0464223532804421, 0.08158230089715549, 0.08195807359048299, 0.06662319573972907, 0.06303067172744445, 0.07850029984755175, 0.08086096388953072, 0.03915136879576104, 0.018075280623244386, 0.0637969888214554, 0.04432418051042727, 0.04157697542437485, 0.013772172687043036, 0.04341590031981468, 0.009968482639773615, 0.005768258848027992, 0.058487974772495885, 0.0707232164485114, 0.07547822701079504, 0.046682439145765135, 0.06332200073770114, 0.0678801072229232, 0.040313702675380876, 0.06864115209983927, 0.02405641583858856, 0.052956289279141595, 0.021517629568864192, 0.03221620486250945, 0.10952993695225034, 0.056187612137624195, 0.02413279004395008, 0.04059207166678139, 0.05841771925666502, 0.03180033414225493, 0.014358184366886104, 0.04364625278062054, 0.13707335612603597, 0.15077428093978337, 0.24843221636755125, 0.15563086819435867, 0.1870511650506939, 0.11665194907358714, 0.11080972863627331, 0.13255100165094647, 0.06863898078777961, 21.47994773728507, 103.15770884922573, 97.747084072658, 91.65921143123082, 98.33430412837437, 80.56580093928746, 60.1064132962908, 29.124645914350236, 25.105628933225358, 28.103450059890747, 48.60026938574654, 55.13291706357683, 43.01463338306972, 61.364627838134766, 76.90626811981201, 26.44814944267273, 0.2584732861391136, 0.6129495607955115, 0.0371065153075116, 0.1661283884729658, 0.07215072520609413, 0.19928753988019057, 0.11157139776540653, 0.1453111648027386, 0.08254482317715883, 0.7783036051051957, 1.4032931455544062, 1.391171253153256, 2.879306788955416, 3.2036745377949307, 2.429608085325786, 2.291964488370078, 4.014073772089822, 2.0452819424016133, 0.8096305898257664, 1.9215738262448991, 2.750611820391246, 2.1130264444010596, 2.0518201972757066, 1.3974460193089075, 0.4696549613560949, 1.9714644977024622, 3.272661030292511, 5.616695753165653, 7.42214390209743, 10.680146404675074, 11.998498473848615, 10.575093116079058, 9.68445565019335, 14.786569118499756, 23.793623174939835, 19.662424053464616, 10.873312405177526, 9.168431179864065, 10.128617508070809, 16.928384338106426, 12.952680689947945, 3.9793128030640736, 0.5410568756716592, 1.6961437570197242, 1.326697289943695, 19.186698266438075, 45.9475930758885, 67.37830761500767, 71.25038582938058, 73.33499826703752, 75.80329023088727, 71.29388155255998, 66.58933271680559, 61.245980398995535, 52.4743069921221, 47.16921840395246, 39.03344760622297, 27.771489449909755, 19.352984292166575, 9.695029071399144, 5.6196014029639105, 2.215665885380336, 1.2520192457096917, 0.404045076242515, 0.5100393572023937, 0.20513120559709414, 0.142139040731958, 0.2555403320917061, 0.17480314656027726, 0.05525284193988357, 0.19943174214235374, 0.12306380644440651, 0.05614429785470877, 0.10428617761603423, 0.0776353237618293, 0.41330868058970993, 0.42122148456318037, 37.43034185682024, 77.92009367261613, 63.31215231759207, 40.94934388569423, 46.152391229357036, 39.8193097114563, 9.160944495882307, 18.146141256604874, 32.976265157972065, 55.34081063951765, 68.11849921090263, 74.64216981615338, 73.14267907823834, 52.03728267124721, 7.510943617139544, 0.2060503898454564, 0.03990394216296928, 0.0677408446956958, 0.050734314402299266, 0.021851538347878625, 0.07808960295681443, 0.0601040551971112, 0.08422080467322043, 0.038334511020886045, 0.0356074007494109, 0.02915004760559116, 0.055486977233418396, 0.017230443456875424, 0.03721292316913605, 0.011546238558366895, 0.03507300692477396, 0.037874884969953976, 0.05700169809694801, 0.023454979361434068, 0.039743868966719935, 0.038258840795606375, 0.06521341710218362, 0.020432808137099658, 0.10670164014611926, 0.035232798528990576, 0.0763844648110015, 0.09279087837785482, 0.05357560176136238, 0.065216741923775, 0.04104783346078225, 0.05211868529607143, 0.04925532180017658, 0.030852593747632842, 0.05016120336949825, 0.04174129624984094, 0.06756849001560893, 0.10235692613891192, 0.2227314811732088, 0.28725210045065197, 0.20395267169390405, 0.200707469401615, 0.221425789807524, 0.14854764113468782, 0.2248275029872145, 0.09632019006780215, 0.14786993392876216, 0.11183831308569227, 0.11406422007296767, 0.23652335682085582, 0.1270915088909013, 0.1552977075002023, 0.2241865995207003, 0.11245217014636312, 0.11183655567999397, 0.07792361293520246, 0.10823282905455146, 0.12981782188372953, 0.10453676738377128, 0.21719934445406708, 0.2643376743154866, 0.25742809793778826, 0.3505391702055931, 0.31546580365725924, 0.22673334500619344, 0.25373184627720285, 0.24354437579001698, 0.222543011286429, 0.1706637165376118, 24.767951692853654, 115.67170633588518, 108.87659740447998, 96.91451617649624, 97.67296763828823, 74.6787451335362, 46.224301610674175, 28.071113143648418, 47.508262702396934, 78.03398854391915, 87.29622909000942, 96.5702815737043, 63.327042307172505, 71.2506776537214, 91.5377777644566, 43.62407030378069, 2.268729929413114, 0.9880452390227998, 0.1811793808426176, 0.5997075970683778, 0.20800942900989736, 0.2606291004589626, 0.16266011100794586, 0.2222139218023845, 0.11125430478049175, 0.41095823528511183, 0.745367243885994, 1.05824191229684, 2.636768192052841, 3.4577087121350423, 3.7159960525376454, 4.725231451647622, 8.850731747491018, 6.950933575630188, 6.520649441650935, 14.359646609851293, 31.157355308532715, 22.908308029174805, 20.130360909870692, 29.270217623029435, 23.67369900430952, 20.498818670000347, 22.487903799329484, 14.3499173947743, 18.740955693381174, 25.033329452787125, 18.151915209633962, 25.158419609069824, 13.771140268870763, 18.693511656352452, 33.63511419296265, 28.182237420763286, 20.522981030600413, 16.101098809923442, 17.499759026936122, 28.178497552871704, 42.784502097538535, 26.16486791202, 15.222358397075109, 8.878660900252205, 1.1213514230081012, 14.014111825398036, 42.74498421805245, 72.25103759765625, 77.94858128683907, 84.59283787863595, 89.41633292606899, 82.02246992928642, 75.47846194675991, 71.36833150046212, 59.77259404318673, 50.12990140914917, 37.81553956440517, 25.283646992274694, 16.14235200200762, 8.275791764259338, 4.8853166443961005, 1.9541306963988712, 1.4276039153337479, 0.5913029366305896, 3.0497072339057922, 0.8052159324288368, 1.1628664753266742, 0.5813508363706725, 0.19024543650448322, 0.13501989202839987, 0.4099928970847811, 0.2744720290814127, 0.24891690750207218, 0.2729438325124127, 0.2912433791373457, 0.8180493095091411, 7.211236110755375, 56.22797400610787, 88.31564794267926, 73.71733679090227, 73.7100967679705, 88.20929881504604, 86.47942665645054, 52.15771927152361, 32.25073078700474, 26.374382155282156, 41.254706791469026, 62.61170441763741, 75.11559227534703, 88.00969791412354, 56.132981709071565, 6.066806137561798, 0.49896582854645594, 0.23356065579823085, 0.15997763137732232, 0.1389185506850481, 0.13223157450556755, 0.2787884074662413, 0.1339722475303071, 0.146822275859969, 0.0932141010250364, 0.13045799253242357, 0.1454812599612134, 0.09243007416703872, 0.15582256790782723, 0.05634932738861867, 0.1603764606905835, 0.26046560066086905, 0.12429130343454224, 0.16896070220640727, 0.1239976334784712, 0.1427533184843404, 0.14086640759238175, 0.14554506939436707, 0.15275349973567895, 0.21154181446347917, 0.11931226775050163, 0.17900303405310425, 0.11190206145069428, 0.19932373293808528, 0.14533070661127567, 0.1603268054979188, 0.09646026683705193, 0.17618369390921934, 0.12349425548953669, 0.13449214106159552, 0.1914962072457586], [0.08770430167870862, 0.07023585867136717, 0.04146273387596011, 0.09742728780422892, 0.044653917995414565, 0.05483298821906958, 0.054225241366241655, 0.04318762756884098, 0.05348817252420953, 0.0338033525539296, 0.026816053382520164, 0.025684299379853264, 0.045053452985095124, 0.03763122304475733, 0.04652289181415524, 0.017597819279347147, 0.026008476270362735, 0.015766422729939222, 0.03936073077576501, 0.04175254636045013, 0.015311773733368941, 0.05581599207861083, 0.07515873201191425, 0.145458759739995, 0.06411894011710371, 0.27549390281949726, 0.218551759741136, 0.3492378486054284, 0.13652675545641355, 0.2412206104823521, 0.23985260246055468, 0.15865911569978508, 11.090665084975106, 87.86765589032854, 87.74611105237688, 86.0757085255214, 72.90651675633022, 58.72892597743443, 42.13667637961251, 31.051728793552943, 69.95011384146554, 79.69059194837297, 59.22930744716099, 53.190141677856445, 56.97651038851057, 92.77620383671352, 72.7568108694894, 17.101712363106863, 0.3678409175149032, 0.0892060353819813, 0.5839213984353202, 0.04442092264071107, 0.11188937284584556, 0.03985308935599668, 0.16586446549211228, 0.0947697443355407, 0.14662087309573377, 0.24866788515022822, 1.586916663816997, 1.8708971398217338, 0.48209869648729053, 2.6391887707369666, 3.027946561574936, 0.35805988950388773, 2.620182190622602, 3.7659683653286526, 5.926474239145007, 5.146189366068159, 6.512930427278791, 3.5386756360530853, 4.8153183204787116, 3.7554692029953003, 4.368169605731964, 7.452845386096409, 4.794737756252289, 3.8649814980370656, 9.14108567578452, 9.429660865238734, 7.3104559523718695, 5.624516384942191, 9.047218986919948, 14.082629748753138, 11.454687288829259, 12.852815968649727, 15.394861323492867, 9.56597409929548, 8.088694146701268, 5.167876865182604, 1.407963637794767, 0.8276672448430742, 0.5409029839294297, 1.8564741994653429, 4.179127361093249, 45.82565219061715, 69.22042097364152, 60.60903903416225, 53.34604188374111, 52.00880200522286, 54.88626643589565, 57.987702574048726, 59.09627723693848, 55.11277770996094, 49.49023287636893, 47.23440292903355, 48.754112924848286, 47.049198695591514, 47.60485308510916, 44.831691537584575, 40.07311003548758, 32.22215632029942, 23.661395481654576, 15.541855675833565, 7.027745042528425, 2.347453236579895, 1.3044719568320682, 0.27320677840283936, 0.1265728502933468, 0.40239971024649485, 0.37491828203201294, 0.07760506788534777, 0.08886695107711212, 0.11864135946546282, 0.2195893619209528, 0.08289580898625509, 0.10907947790942021, 0.16849879627781256, 0.1533882828163249, 11.225491404533386, 53.003064904894146, 49.26043857846941, 24.466318232672556, 49.98600769042969, 84.10718658992222, 66.3359180177961, 38.84694058554513, 13.797062260763985, 29.806743621826172, 42.98346723828997, 49.13951907839094, 60.12952995300293, 45.64701747894287, 9.741016592298235, 0.2744103638189179, 0.08414464590272733, 0.13960592022963933, 0.07372605281748942, 0.05751013795712164, 0.012305418312150453, 0.03724258532747626, 0.05660058551334909, 0.02421846696441727, 0.03705077365572963, 0.047210247788046084, 0.04849021589117391, 0.055652838333376815, 0.01850675086357764, 0.06130153379802193, 0.04664394585415721, 0.028246449306607246, 0.0067954268555955166, 0.11057366630328552, 0.07523834452565227, 0.06972277763166598, 0.14996997267007828, 0.10798388812690973, 0.11321970181805746, 0.12403610641402857, 0.11945245308535439, 0.04847830420892153, 0.0898106372249978, 0.24661773230348313, 0.18804095765309675, 0.13038274299885544, 0.09131281876138278, 0.19684670014040812, 0.09111051354557276, 0.13364929200283118, 0.03523317172325083, 0.11421060721789088, 0.07994973885693721, 0.04188400912763817, 0.05255752781938229, 0.03161144695643868, 0.006571226586986865, 0.02822543677341725, 0.05311612838080951, 0.036263676426772556, 0.050766812837017436, 0.0656080734250801, 0.027405659601624523, 0.05222187690170748, 0.030000621785542796, 0.015084934387622135, 0.044388475096119304, 0.01873879287657993, 0.03861176721485598, 0.06398418984775033, 0.02232053836009332, 0.07492668660623686, 0.05874477992100375, 0.11058011917131287, 0.22496283001133374, 0.1445583166288478, 0.12994371727108955, 0.08564948729638543, 0.21243187598884106, 0.4055676816829613, 0.09569363083158221, 24.77834098679679, 107.68093054635185, 102.03952830178397, 102.17997918810163, 98.57252311706543, 80.30513232094901, 71.880615234375, 31.201955795288086, 31.354975972856792, 57.54045745304653, 53.21775034495762, 53.84456818444388, 62.9082396371024, 100.85978671482631, 66.93098953792027, 12.122595037732806, 0.11310846957245044, 0.08958177414855786, 0.41147204914263313, 0.018043886504269073, 0.08788304137332098, 0.0660467938120876, 0.11633391971034662, 0.4798024797013828, 0.8247682175465992, 1.3611080263342177, 4.365469362054553, 4.737903663090297, 1.2516664074999946, 3.1626328315053667, 0.9712238673652921, 0.2034114178802286, 0.7709121874400547, 0.7073150000401905, 0.5846802720001766, 0.6070359924009868, 2.024938919714519, 1.4921346583536692, 1.4380424980606352, 1.7597640688930238, 1.7413818495614188, 1.1964431021894728, 0.73631216692073, 0.434630205056497, 2.486266085079738, 2.7485881575516293, 5.620614537170955, 6.585371911525726, 10.038590567452566, 16.90426366669791, 14.533305542809622, 15.660303354263306, 23.090479373931885, 21.439615181514196, 17.832450934818812, 11.53342774936131, 5.989257293088095, 3.3329598861081258, 0.8427273024405751, 1.2284753833498274, 7.476528320993696, 59.172165461948936, 76.80059991564069, 68.4743720463344, 60.664846965244834, 59.290270941598074, 62.077096121651785, 66.21161474500383, 67.2968886239188, 66.44239221300397, 63.692705154418945, 61.545169830322266, 60.6381311416626, 59.84846837180001, 62.21187727791922, 60.975605147225515, 58.36062976292202, 53.685958181108745, 45.05096278871809, 32.12991203580584, 16.603547368730815, 5.68069908448628, 3.8960977026394437, 0.829121969640255, 0.14087183587253094, 0.24905850418976375, 0.4806813725403377, 0.14528136354471954, 0.08773863555065223, 0.06840388875986848, 0.33152672754866735, 0.11585604106741292, 0.04326767773766603, 0.1401587227093322, 0.5895023761051041, 5.915737535272326, 52.29264633996146, 58.91769463675362, 27.27578932898385, 48.270077092306956, 73.10554790496826, 34.78812953404018, 8.041947535106114, 14.630389247621808, 51.68225751604353, 68.0169790812901, 69.3470379965646, 70.03436769757951, 58.89275060381208, 19.039346081869944, 0.12099344682480608, 0.012996168657472091, 0.0206419580749103, 0.01631040425438966, 0.07915809205068008, 0.009237379816892956, 0.022288275716294135, 0.08087733693953071, 0.016780888561957648, 0.04314904606768063, 0.029057525963123356, 0.049046271946281195, 0.06816705289695944, 0.04815445301522102, 0.04369104626987662, 0.0026135061218935463, 0.05489227182364889, 0.03716007886188371, 0.06598501998398985, 0.05376098431380732, 0.08791605888732842, 0.06226091446088893, 0.07581976761243173, 0.16704625636339188, 0.05962444628987994, 0.05210501281544566, 0.07764233302857194, 0.08418049969311271, 0.15959600971213408, 0.17408569077295916, 0.179635333695582, 0.07282614574900695, 0.08594814448484353, 0.07914973249925034, 0.23917656445077487, 0.22370147412376745, 0.24749195682150976, 0.2615741640329361, 0.2371862041098731, 0.14631197681384428, 0.16378656056310448, 0.09703549489911113, 0.1931084200207676, 0.11039469590676682, 0.14522629364260606, 0.10777806809970311, 0.1268557044012206, 0.15606107296688215, 0.16282348866973603, 0.0959697470867208, 0.14441165806991713, 0.10911536562655653, 0.1096580307930708, 0.09297619986214808, 0.07130353352321045, 0.08992497716099024, 0.1641568506934813, 0.21462017856538296, 0.20074936215366634, 0.36020609576787266, 0.3311108670064381, 0.35046219719307764, 0.22251098443354878, 0.41364021279982155, 0.620203968669687, 0.2470566358949457, 30.51776668003627, 124.54331915719169, 111.16215174538749, 108.231123651777, 95.61828804016113, 75.22222627912248, 56.75642967224121, 44.99139935629708, 91.6244843346732, 103.87003816877092, 84.75949042184013, 77.80127947671073, 74.1330475125994, 111.61104011535645, 86.49742249080113, 24.03527283668518, 1.3826033643313815, 0.22564834036997386, 0.9655575028487614, 0.14827568429921353, 0.1767973338386842, 0.20126465521752834, 0.3449972490114825, 0.23321821274501936, 0.4580439786825861, 0.7783328092523983, 3.8197673984936307, 5.494639788355146, 2.6352428453309193, 6.459336365972247, 8.67392441204616, 3.695425476346697, 8.005660567964826, 8.34855764252799, 12.93049509184701, 13.11777857371739, 19.03452229499817, 14.248896666935511, 16.926546539579117, 14.889155796595983, 14.092221736907959, 20.083318131310598, 16.510771547045024, 13.137631314141409, 21.754722935812815, 20.921368156160625, 21.94346727643694, 18.826065914971487, 25.375731468200684, 28.301602261407034, 23.866864136287145, 22.166495765958512, 31.192162309374126, 24.270109789712087, 22.039437532424927, 13.993497388703481, 6.894094705581665, 6.733071940285819, 3.4426389379160742, 3.6489763345037187, 6.0602162054606845, 64.42929758344377, 92.33423587254116, 83.51107978820801, 72.52028029305595, 70.78491905757359, 67.44389166150773, 71.72322463989258, 71.8493344443185, 72.35586506979806, 68.66462067195347, 69.84120777675084, 73.23434666224888, 70.67836148398263, 76.44507449013847, 71.67603247506278, 66.7774760382516, 59.68383775438581, 48.5244471686227, 29.945526940482004, 12.441044007028852, 2.7898296245506833, 3.50509803209986, 1.1042436552899224, 0.4648944139480591, 1.3590522280761173, 0.8349465685231345, 0.22366954226578983, 0.32379636807101114, 0.2773318641952106, 0.4727007693478039, 0.2698361964098045, 0.30727944150567055, 0.5032405991639409, 0.5435359169329915, 18.306245122637065, 69.65042413984025, 66.21062115260533, 35.09212711879185, 69.49625056130546, 112.9958438873291, 100.10651166098458, 54.714347158159526, 19.290537357330322, 40.92990977423531, 59.814380509512766, 65.83275726863316, 79.98184653690883, 67.73488916669572, 19.09937678064619, 0.2820857891014644, 0.1317077183297702, 0.19202873509909424, 0.20050432958773204, 0.24261689984372684, 0.13097894457834108, 0.21552253514528275, 0.1589566125933613, 0.14339066642735684, 0.14272448074604782, 0.15812371085797036, 0.13309395180216857, 0.1740793939679861, 0.11960954751287188, 0.18535033560224942, 0.23648017485226902, 0.10929722658225469, 0.11785143613815308, 0.20585250189261778, 0.11909539438784122, 0.19272394850850105, 0.29857210016676355, 0.2176350453602416, 0.2758947270257132, 0.2599146030843258, 0.38835859511579784, 0.13451787110950264, 0.2184726425579616, 0.29156264343432015, 0.22823982845459664, 0.31513997114130426, 0.2357303122324603, 0.3359594882598945, 0.26811383025986807], [0.2591343420956816, 0.2225903458893299, 0.11256442697984831, 0.09964304390762534, 0.07428230225507702, 0.146237120830587, 0.3796600747321333, 0.07297380853976522, 0.06625303453100578, 0.053662708694381375, 0.010628787966977273, 0.0883960545595203, 0.0807035912626556, 0.01828290385726307, 0.023885330018986548, 0.04065229164968644, 0.07123654854616948, 0.05967269012970584, 0.045779349748045206, 0.027530367552701916, 0.05723865609616041, 0.10318795511765139, 0.049668749794363976, 0.13553604004638536, 0.06198525960956301, 0.05045627789305789, 0.05344022384711674, 0.06155316850968769, 0.07425281312316656, 0.02751174007010247, 0.25001914692776545, 29.257717813764298, 84.13710553305489, 78.6774959564209, 81.35243429456438, 77.1886568069458, 53.45263419832502, 44.41020686285836, 31.361875534057617, 66.0695310320173, 83.22103418622697, 53.435760498046875, 61.07790347508022, 85.85959870474679, 108.10273483821324, 35.22891977855137, 0.7128454404217857, 0.3687898080263819, 0.07763991744390555, 0.05851054284721613, 0.20144381560385227, 0.041814293047147136, 0.14341798424720764, 0.038913810293057134, 0.08377369759338242, 0.07060898507812194, 0.1242196908486741, 0.5224866207156862, 1.9574462899139948, 2.5115818466459, 1.7539831676653452, 2.7971740875925337, 4.1748120955058505, 1.7326350446258272, 2.5884512875761305, 3.7486117652484348, 1.8173145864691054, 0.4509864002466202, 1.1454250855105264, 1.0958610879523414, 0.935527931366648, 1.1605481654405594, 1.3525157102516718, 0.6907935408609254, 1.0331289512770516, 0.850116385945252, 2.1674883791378567, 1.697995017681803, 5.028085623468671, 11.22632258278983, 5.527582934924534, 7.509278655052185, 3.153454912560327, 9.501853517123632, 18.770499433789933, 15.43632469858442, 8.727747763906207, 7.676970822470529, 16.49059224128723, 0.5733747386506626, 0.7525664461510522, 12.152156148638044, 67.65041991642543, 51.320270265851704, 44.034559454236714, 44.426788738795686, 55.41022661754063, 63.94365324292864, 73.53220898764474, 78.69714546203613, 81.6416322163173, 81.71688120705741, 85.87530163356236, 82.05478600093296, 77.62089034489223, 69.10820756639752, 64.04941177368164, 59.65469700949532, 56.30524492263794, 54.56797988074166, 56.888928345271516, 55.4542121887207, 50.03820603234427, 41.52932391847883, 22.552311863218033, 8.93115975175585, 1.6512236531291689, 0.40048982415880474, 0.18409830278583936, 0.1731930508145264, 0.25719536042639185, 0.03232254487063203, 0.08243477836783443, 0.25883149834615843, 0.06782534266156809, 0.06818584153162581, 0.0492936183166291, 0.9654083337102617, 1.7829265402896064, 24.299655267170497, 69.67101165226528, 84.69089780535016, 90.62288066319057, 119.02439280918666, 82.98530960083008, 58.05991867610386, 20.720936945506505, 22.703732218061173, 36.50211116245815, 48.188880443573, 57.48189456122262, 59.11810152871268, 21.34104629925319, 0.40422825355614933, 0.07117656605052096, 0.026744559540280273, 0.33955119124480654, 0.025878640290881907, 0.12184092349239758, 0.06524437186973435, 0.02233733719081751, 0.12445507464664322, 0.054605624705020867, 0.13682012685707637, 0.21155197891805852, 0.07644462372575488, 0.05780942618314709, 0.08201635974858489, 0.03254811365955642, 0.08971689761217151, 0.02483530618649508, 0.028268523747101426, 0.06229721608438662, 0.10060505050101451, 0.059941159295184274, 0.0950239710509777, 0.0138808935049123, 0.024964533180796673, 0.07968341386211769, 0.04460085655695625, 0.23107713620577539, 0.28289870119520594, 0.17092656743313583, 0.2796136417559215, 0.14864330100161688, 0.1913886730160032, 0.09063794104648487, 0.20678483614964144, 0.09027060932878937, 0.044548534721668274, 0.030537963844835758, 0.18726828268596105, 0.16225061512419156, 0.04766223014199308, 0.08793946834547178, 0.1091472092749817, 0.059681198958839686, 0.07261869723775558, 0.034157015183674436, 0.043751181435904334, 0.07120637409389019, 0.04487272857555321, 0.09221073093691043, 0.032063693939042945, 0.04720628514353718, 0.0027544056148534374, 0.028135466422619562, 0.02491653530991503, 0.03294071062867131, 0.15577300771006516, 0.09302160742559604, 0.07767636155975716, 0.039828370325267315, 0.04309261231017964, 0.08239758786346231, 0.024308744352310896, 0.8005224242806435, 46.65812976019723, 100.39008154187883, 90.07627977643693, 98.98524611336845, 103.10552092960903, 86.29522296360561, 71.57512378692627, 28.294721807752335, 32.653201716286794, 76.35592910221645, 55.57612180709839, 56.775940213884624, 94.28559575762067, 111.50010517665318, 27.901342596326554, 0.3880594697381769, 0.34577164745756556, 0.03756777662783861, 0.11688398090856415, 0.14061484751956804, 0.11635552426534039, 0.24979251623153687, 0.07794758557741131, 0.6676215699740818, 0.4051379790263516, 1.8617205236639296, 1.6487170904874802, 1.7508378050157, 0.5233788128410066, 0.5131576870168958, 0.868548816868237, 0.8305542756404195, 0.7985445761254856, 1.0935563487665994, 1.9064769106251853, 1.8179205996649606, 1.2611589495624815, 1.9259783327579498, 1.1897049780402864, 0.5136329329439572, 0.6015593462756702, 1.0958272154842104, 0.1353457381150552, 0.48444056510925293, 0.7927936390042305, 0.7858622137989316, 0.38859605523092405, 1.5616913373981203, 6.758600490433829, 9.500564626285009, 8.417695692607335, 4.352317724909101, 9.391156554222107, 27.199440785816737, 18.689719676971436, 16.57122434888567, 10.925597599574498, 9.53376659325191, 0.6054500117897987, 0.598029607108661, 19.117579323904856, 79.10394859313965, 56.54606253760201, 49.82793617248535, 52.16025536400931, 64.09445694514683, 73.88399628230503, 79.98589733668736, 82.49290466308594, 87.60448592049735, 87.5535556248256, 94.77210862295968, 92.12046759469169, 90.29027039664132, 81.86150101252964, 77.01774501800537, 69.67676476069859, 67.57089083535331, 64.20812252589634, 68.85371589660645, 67.18715572357178, 67.52241325378418, 62.71091079711914, 44.4708194732666, 21.646327563694545, 6.15965621812003, 1.969428892646517, 0.13776916664625916, 0.25652203655668665, 0.1657101394874709, 0.11908821548734393, 0.16808797046542168, 0.21912087420267717, 0.20104932891471045, 0.16867062848593506, 0.1253502523260457, 1.0646105876990726, 0.30503240493791445, 20.167113406317576, 63.90841197967529, 79.16391849517822, 93.54799583980015, 124.1131978716169, 70.6737756729126, 23.735812425613403, 12.969002876962934, 37.260520935058594, 59.66181196485247, 68.91151796068463, 70.2380541392735, 72.22204276493618, 36.40303679874965, 0.4117065779864788, 0.09814937798572437, 0.039998312813362906, 0.280421749821731, 0.028297174888263856, 0.08395015062498194, 0.04279270661728723, 0.033694769987570386, 0.06121495272964239, 0.041097549721598625, 0.15464539107467445, 0.08632927081946816, 0.025237623169752102, 0.041165084312004704, 0.025173589820042253, 0.05094325229791658, 0.00958618922491691, 0.02637831517495215, 0.05546818520607693, 0.048185088871312995, 0.025339574752641574, 0.014730773034638591, 0.06115730439445802, 0.11214250711990253, 0.032341445463576486, 0.03293827808062945, 0.06038564722985029, 0.20504790863820485, 0.1700890516596181, 0.15015627124479838, 0.22822351647274836, 0.1803326369928462, 0.13119869492948055, 0.2690041224871363, 0.4832547573106629, 0.2474282830953598, 0.12373900307076317, 0.11053564120084047, 0.32692699294005123, 0.4907432326248714, 0.31519742948668344, 0.22836381037320408, 0.2094328190599169, 0.09802542320851769, 0.19508435470717295, 0.1148590152817113, 0.12468931850578104, 0.19950385684413569, 0.11047850176692009, 0.19073289606188024, 0.18388780765235424, 0.11204732901283673, 0.1379273874419076, 0.14363690678562435, 0.1437199730426073, 0.15775513063584054, 0.2393179168658597, 0.20757979420678957, 0.09466607097004141, 0.10017055060182299, 0.09970124864152499, 0.15339398251048156, 0.10479786765894719, 1.2442880719900131, 54.53704650061471, 117.82555062430245, 99.46264294215611, 104.3883181980678, 100.30147116524833, 69.01027965545654, 59.291361808776855, 40.51722846712385, 92.60363837650844, 116.59765107291085, 75.72164194924491, 81.48972375052315, 101.40581090109688, 128.58979715619768, 45.6630608694894, 1.7696333335978645, 0.6534591870648521, 0.2231319389705147, 0.18751398021621363, 0.20550910889038018, 0.3033385101173605, 0.3482078053057194, 0.09855153212057692, 0.22096043692103454, 0.2557343931070396, 0.6642214038542339, 1.0940374029534203, 5.335489562579563, 6.61795939717974, 6.315463057586125, 12.448985798018319, 8.22643436704363, 9.024183103016444, 8.019054957798549, 9.149909887995038, 4.799858578613826, 1.8691874487059457, 2.970466503075191, 2.6054418044430867, 2.1693982652255466, 2.2745134362152646, 2.8327262827328274, 1.4784108804804938, 2.6966306141444614, 4.627109859670911, 7.86609731401716, 11.378211072513036, 14.542543172836304, 27.887024096080236, 15.19219626699175, 17.185542379106792, 8.732162475585938, 16.80403937612261, 34.74580805642264, 27.20753196307591, 18.811690092086792, 15.51080243928092, 28.732018845421926, 3.8035164305141995, 1.1613785837377821, 19.001469714300974, 87.72600296565464, 67.32057503291539, 56.08705759048462, 59.26995440891811, 68.29847839900425, 76.14272362845284, 83.44965771266392, 89.7900139944894, 92.4377362387521, 90.38571780068534, 96.11319432939801, 90.46588611602783, 87.41183321816581, 78.32543073381696, 76.28149999891008, 71.47892597743443, 72.05864197867257, 70.78385598318917, 79.01294108799526, 81.6321826662336, 81.50961644308907, 71.76719978877476, 45.674177987234934, 16.506276062556676, 3.1573430810655867, 1.2949407654149192, 0.7277370584862572, 0.8858515141265733, 0.7438129644308771, 0.16764723482940877, 0.3174700332539422, 0.4360528215765953, 0.6045108107583863, 0.18832588807812758, 0.1975365531231676, 1.3470966581787382, 4.22123691865376, 36.900388853890554, 87.28778008052281, 95.14326054709298, 96.80159405299595, 135.65095955984933, 122.56734875270298, 86.42609923226493, 30.03100367954799, 30.04735279083252, 51.69714750562395, 66.77475234440395, 77.45237568446568, 86.24865613664899, 36.645198890141074, 0.38202452499951634, 0.14748303326112883, 0.1571340403918709, 0.4996016430003302, 0.15072131449622767, 0.22954001011593, 0.17502855589347227, 0.17510335759392806, 0.17249185272625514, 0.14426300461803163, 0.3037868860576834, 0.24494109941380365, 0.13962798618844577, 0.16894615441560745, 0.2035688922873565, 0.10775446865175452, 0.23590914692197526, 0.10597666619079453, 0.11761693443570818, 0.1425110407705818, 0.14102485908993653, 0.14939264793481144, 0.20717434239174637, 0.17952389110411915, 0.13637513002114637, 0.11747262360794203, 0.19879022799432278, 0.396892421479736, 0.2751562095114163, 0.22764302976429462, 0.28608808719686096, 0.29024604122553554, 0.25005215087107246], [0.19779652703021253, 0.1539765726774931, 0.18064983854336397, 0.36932243087462013, 0.15197133884898253, 0.20014721660741738, 0.11189154415790524, 0.14236636353390558, 0.04336305261988725, 0.015074296654867274, 0.14431454613804817, 0.06243296380021742, 0.04498040869033762, 0.13716544689876692, 0.04210540831887296, 0.08290921005287341, 0.04653630645147391, 0.014223852244737958, 0.03706309585166829, 0.031007584716592516, 0.0781820872798562, 0.02180735214746424, 0.110904974596841, 0.1871860713831016, 0.1705787775239774, 0.0400759304341461, 0.06396306026726961, 0.07082642162484781, 0.12860270137233393, 0.5475986589278493, 44.29841034752982, 89.74926280975342, 83.22293799264091, 81.01186834062848, 85.29919174739292, 50.68546894618443, 28.02709456852504, 34.92832681110927, 76.80647809164864, 83.46943923405239, 44.07404954092843, 63.88087626865932, 111.22956316811698, 76.67902033669608, 8.903434702328273, 0.2563987603144986, 0.041727620376540084, 0.079239665530622, 0.10551288072019815, 0.06549005582928658, 0.1910403674202306, 0.03702726581000856, 0.10253282955714635, 0.07790241550121989, 0.023692405549809337, 1.1303021141460963, 1.4528290246214186, 1.4304329178162982, 4.077846075807299, 4.548200905323029, 1.7712883076497485, 2.2271447437150136, 1.2417055134262358, 2.788205700261252, 7.674622331346784, 11.491599593843732, 14.365796634129115, 17.760516234806605, 17.39458588191441, 18.966197184153966, 17.21042387826102, 13.85872404915946, 12.192122186933245, 7.446111713136945, 3.532700836658478, 1.1671138874122073, 0.43117320484348703, 0.731459230184555, 0.8420850283333233, 1.2647598534822464, 5.550455101898738, 8.780034695352827, 7.278330521924155, 2.7841661913054327, 10.758555088724409, 7.880368913922991, 7.447132229804993, 4.115075392382486, 2.145824981587274, 0.6345439106225967, 9.006926383290972, 72.43469933101109, 50.75733069011143, 53.04787383760725, 62.08509349822998, 70.7983707700457, 80.94704164777482, 85.37202971322196, 85.92220197405133, 81.94175270625523, 78.54857907976422, 82.21863147190639, 84.48468221936906, 89.93052741459438, 96.30339431762695, 95.68166950770787, 95.90244156973702, 88.41025461469377, 88.88107149941581, 82.58542687552315, 74.26520919799805, 65.8484115600586, 60.202055249895366, 59.094227518354145, 60.65752356392996, 54.877480438777376, 37.91861261640276, 17.74671016420637, 3.1028388057436262, 0.2753651440143585, 0.20690428545432432, 0.3451855017670563, 0.24219851515122823, 0.10437065522585597, 0.14654079239283288, 0.3295522720686027, 0.20261260574417456, 0.059691322701317925, 0.33491904980369974, 0.3813400188727038, 4.876994873796191, 46.31692804609026, 69.66886465890067, 67.66521957942417, 48.77055583681379, 67.45650264195034, 62.978235789707725, 28.622600351061138, 25.342541660581315, 26.075039863586426, 48.004579475947786, 58.34938062940325, 71.33930192674909, 25.947543893541607, 0.16644860271896633, 0.049986660413976224, 0.03905675048008561, 0.021486800330291902, 0.008334107214717992, 0.029342452995479107, 0.04754975278462682, 0.025957414813871895, 0.02651753699007843, 0.002147639669211847, 0.049514712167105505, 0.14375061568404945, 0.030019759865743772, 0.06476226595363446, 0.004765950667206198, 0.06020700253014054, 0.023122425956119384, 0.025468637202201144, 0.058731975965201855, 0.08346184289881162, 0.13747337966092996, 0.02962142927572131, 0.03666436492598482, 0.037918148362743, 0.06683956020112548, 0.15127292275428772, 0.10122481760169778, 0.12874836927013739, 0.09309041087648698, 0.08504658179091555, 0.05334036724109735, 0.2588198818266392, 0.20641233399510384, 0.16005953055407318, 0.17996588881526673, 0.23876491082566126, 0.13642770291439124, 0.12039028347602912, 0.11823901534080505, 0.14786967608545507, 0.04257944306092603, 0.053541742863931825, 0.058093576292906485, 0.05981146411171981, 0.09833028220704623, 0.09720634323145662, 0.07128692977130413, 0.05965288369251149, 0.02543693095711725, 0.014205304490003203, 0.05074064852669835, 0.04200728197715112, 0.03307531162032059, 0.06654548312404326, 0.10813433291124445, 0.2051649966410228, 0.049565931382988176, 0.07125102169811726, 0.10797477540160928, 0.1607618142983743, 0.248468884399959, 0.9881465307303837, 62.84831142425537, 103.29743712288993, 95.12764794485909, 103.70517826080322, 106.2307859148298, 72.95946897779191, 40.32492664882115, 27.255490166800364, 28.506282295499528, 68.84918567112514, 41.52052402496338, 65.14697006770542, 126.45800645010812, 72.79379613058907, 4.322132578917912, 0.3419270951833044, 0.014050410212283688, 0.18386696305658135, 0.024700091120653918, 0.08968791059617486, 0.18689640478364059, 0.5884896218776703, 0.493581517466477, 1.5661339504378182, 1.6389817957367216, 0.9253458891596112, 0.8472727271062988, 1.439873022692544, 1.7502819491284234, 2.175194582768849, 1.1609430185386111, 1.3270071361746107, 4.465894716126578, 6.645353972911835, 12.579666648592267, 17.739756754466466, 23.315338713782175, 25.281361034938268, 25.02932902744838, 29.519796916416713, 26.46654306139265, 23.097465787615093, 22.447920390537806, 13.689911484718323, 7.5182192495891025, 2.381020201104028, 0.40123743404235157, 0.21888506971299648, 1.20351419704301, 1.0960706195660999, 4.248934609549386, 4.212030121258326, 5.831804599080767, 3.7678309168134416, 10.611164689064026, 12.13421242577689, 11.141769085611616, 5.287095359393528, 0.8836229337113244, 0.5895285404154232, 13.679605569158282, 79.81782736097063, 55.59118550164359, 59.925926889692036, 68.32939788273403, 80.80811936514718, 86.91626685006278, 88.03555910927909, 85.85084397452218, 82.64425032479423, 80.80877249581474, 85.4187980379377, 85.75571618761334, 89.99905054909843, 92.89994430541992, 94.0901220866612, 93.8407234464373, 93.13256304604667, 93.71177877698625, 89.4002547945295, 81.09144605909074, 74.2072195325579, 69.10526153019497, 68.95978709629604, 74.64653328486851, 74.98804419381278, 61.95835140773228, 34.81749609538487, 9.782317553247724, 2.236460975238255, 0.24328349264604704, 0.2840785378856318, 0.2781880668231419, 0.30952512100338936, 0.18476986246449606, 0.20109655495200837, 0.4407302891569478, 0.0610694612509438, 0.1598846720797675, 0.7388990681086267, 1.7547621258667536, 45.453305176326204, 71.76314898899624, 68.01670115334647, 53.724777766636436, 71.98473399026054, 38.20824132646833, 14.129203523908343, 38.385792119162424, 47.61541434696743, 68.89976855686733, 69.83038943154472, 81.04189845493862, 42.03207124982561, 0.4761811654482569, 0.13663438468107156, 0.05680361676162907, 0.04910004923918417, 0.035686979336397986, 0.04787052342934268, 0.05026150441595486, 0.03108030670721616, 0.052649469314409156, 0.05745251676333802, 0.05956051472042288, 0.0693293223157525, 0.03735889640769788, 0.05084921752235719, 0.015031292801722884, 0.07974198500492743, 0.04860497312620282, 0.05957304047686713, 0.06310830291892801, 0.05351465574598738, 0.08760111685842276, 0.18755750145230973, 0.055182545711951594, 0.05563109128602913, 0.08078249131462403, 0.10466938705316611, 0.07548962639910833, 0.06195586547255516, 0.1517564875206777, 0.08209645402218614, 0.10879270865448884, 0.11574903609497206, 0.24409032506602152, 0.21639680037541048, 0.23132119168128285, 0.36297530574457987, 0.21877293501581463, 0.2244702542998961, 0.20507879555225372, 0.23091390782168933, 0.07337433419057302, 0.19720109898064817, 0.17409329036516802, 0.11473297061664717, 0.13321082267378057, 0.16361683181353978, 0.23653725321803773, 0.13924278185835906, 0.17127553799322673, 0.10517839688275542, 0.17791653663984366, 0.20143643314284937, 0.2266707026532718, 0.1857270718153034, 0.17639769028340066, 0.3216261959501675, 0.283903855830431, 0.16249168504561695, 0.2865432756287711, 0.2532146397445883, 0.45634905248880386, 1.5074027819292886, 75.88325704847063, 120.52732985360282, 103.07358006068638, 105.89319378989083, 99.48259122031075, 61.67136301313128, 35.95458269119263, 42.584494726998464, 99.35953862326485, 111.1361585344587, 58.527574130467, 80.19252286638532, 134.56698499407088, 97.50785064697266, 13.036742602075849, 0.5618458315730095, 0.1937088556587696, 0.4008879613663469, 0.1886294646454709, 0.23775440933448927, 0.22638664075306483, 0.378209149731057, 0.4257258442895753, 0.5991521754435131, 0.90037873174463, 2.2307471675532202, 3.7897407582827976, 6.997672370501927, 13.601045761789594, 9.98723382609231, 3.492946718420301, 4.038623929023743, 3.4664599682603563, 4.440104740006583, 9.342178702354431, 14.64755129814148, 19.603722197668894, 21.89725307055882, 20.54151013919285, 25.11221582548959, 23.085620846067155, 21.308393239974976, 19.545492819377355, 11.229209559304373, 5.874600725514548, 2.4920726077897206, 1.5948563920600074, 1.7974165741886412, 4.293564626148768, 8.660556946481977, 13.320915239197866, 17.131349904196604, 18.051545006888254, 9.39148051398141, 21.244659151349747, 17.287597520010813, 16.092696700777324, 10.979609421321324, 5.516206128256662, 0.6732288205197879, 14.939846379416329, 83.87752778189522, 63.78333050864083, 66.18327304295131, 76.79762608664376, 85.53520815713065, 89.0407966886248, 94.62955243246896, 93.54356983729771, 90.7782632282802, 88.84376662118095, 92.53747068132672, 90.96690682002476, 95.76024668557304, 101.18688011169434, 100.99772930145264, 100.18913269042969, 97.23503657749721, 96.57895987374442, 90.64054298400879, 83.77677195412772, 75.81251743861607, 74.4200359072004, 77.16842365264893, 88.46106679098946, 90.61473042624337, 65.51861531393868, 31.15446833201817, 5.43242518390928, 1.683887351836477, 1.0613180100917816, 1.1235056902681078, 0.6763967648148537, 0.39449396303721834, 0.4054692941052573, 0.49351740947791506, 0.5769132173487118, 0.2465498245188168, 0.6916257504905973, 0.9079891805137906, 10.099286556243896, 65.66861302512032, 84.9103775024414, 78.08908081054688, 62.39076559884207, 96.3901286806379, 93.83855560847691, 41.372725418635774, 33.7315308707101, 36.0876441683088, 66.33445194789341, 72.40512084960938, 96.6439950125558, 46.806824684143066, 0.3749465633715902, 0.23225694575480052, 0.20597853298698152, 0.2325596266559192, 0.2418664943959032, 0.1350040550210646, 0.1371444665959903, 0.18309750434543404, 0.19618972896465234, 0.09074182475783996, 0.13803634659520217, 0.24862540885806084, 0.11130126618913241, 0.1736127111528601, 0.14393692782946996, 0.27024920710495537, 0.13011586160532065, 0.18337654508650303, 0.12972810598356382, 0.2818845084735325, 0.16892203928104468, 0.26735316536256243, 0.1345964726060629, 0.11409030295908451, 0.08453651344669716, 0.21755736667130673, 0.2871679349669388, 0.1977568870144231, 0.2192397535379444, 0.14240532501467637, 0.19458949911807263, 0.23059600059475216], [0.11010234230863196, 0.08474320199872766, 0.17221237772277423, 0.18825742389474595, 0.19028741068073682, 0.1272708728377308, 0.09256189316511154, 0.12624015100300312, 0.06497390102595091, 0.042210184303777556, 0.03692515307505216, 0.0826085511861103, 0.04798172853354897, 0.019500465398388248, 0.028042323920609694, 0.004384506269291575, 0.04919953265094331, 0.05343101951958878, 0.04337047240031617, 0.030992480527077402, 0.07518826864127602, 0.09162263785089765, 0.07645820799682822, 0.02478893849599574, 0.03009735034512622, 0.13020683958062104, 0.054181730308170827, 0.0985907039472035, 1.3207588600260871, 40.367810930524556, 92.55831527709961, 79.6613608769008, 76.29386084420341, 48.58034195218767, 37.59471191678728, 34.91459717069353, 50.827000277382986, 77.62877655029297, 65.63952091761998, 53.30320971352713, 88.3997072492327, 114.31624480656215, 42.01910591125488, 0.542768520968301, 0.5549814456275531, 0.18497320583888463, 0.11645601530160223, 0.044398805791778226, 0.06932941052530493, 0.09866598062217236, 1.2450655102729797, 1.401123787675585, 0.205106859760625, 2.445993023259299, 4.7918616362980435, 1.4883589638131005, 7.254341432026454, 2.6332517521721974, 0.3881175251943724, 0.29906601937753813, 6.431220046111515, 25.201152767453873, 45.35328933170864, 51.80281918389456, 57.79415702819824, 65.72289930071149, 76.03950119018555, 83.45436164311, 90.07520280565534, 83.41144956861223, 78.43620586395264, 88.01721586499895, 86.77321733747209, 79.87348937988281, 69.15512180328369, 50.11849594116211, 26.942717007228307, 7.733850513185773, 0.7975329618368829, 0.6389599793723651, 0.48211834686143057, 1.099163979291916, 2.164233148097992, 2.0173862278461456, 1.5784825278179986, 4.707252987793513, 8.48796716758183, 4.370883311544146, 0.1622689627110958, 5.794463242803301, 48.555644580296104, 60.84973158155169, 60.558747972760884, 69.10583128247941, 76.3505095073155, 89.24623407636369, 95.94727829524449, 92.64047077723912, 83.67067990984235, 76.74061611720494, 77.54971994672502, 77.76800455365861, 80.37610122135708, 78.50609084538051, 77.7654754093715, 77.71866539546421, 80.2443425314767, 84.92989499228341, 85.92620413643974, 87.67282145363944, 87.96527113233293, 83.7797805241176, 78.833753994533, 74.43311936514718, 71.09483650752476, 67.1170345033918, 67.48382990700858, 58.652766772678916, 42.47059290749686, 16.12591951234, 2.0863334195954457, 0.07223215619368212, 0.22092889861336776, 0.20931734597044332, 0.14020166040531226, 0.09805372490414552, 0.1726761156959193, 0.3592894220990794, 0.11935230131660189, 0.00972082668782345, 0.3648467867502144, 1.395232692360878, 16.882694721221924, 53.17333051136562, 45.913185596466064, 29.905175277165004, 45.684381416865754, 65.37899821145194, 28.73263897214617, 22.89117203439985, 38.9260527747018, 51.994235106876914, 54.96628189086914, 68.92924281529018, 41.22053555079869, 2.6652497266020094, 0.04217773675918579, 0.009677665923455996, 0.09552112687379122, 0.02348175604960748, 0.1011671760518636, 0.009793929506226309, 0.046389006676950624, 0.03455162400911961, 0.009673358074256351, 0.05066375693838511, 0.025506051623129418, 0.02331235130051417, 0.03865716460027865, 0.03070428974128195, 0.07408973401678459, 0.048593234470380206, 0.11031407237585102, 0.11483842852924551, 0.1766975891909429, 0.10103378285254751, 0.11106492565678698, 0.10617461521178484, 0.01907013340054878, 0.024105628287153583, 0.010204423684626818, 0.020419659824775796, 0.0336229233071208, 0.022179269065548266, 0.06194952795548098, 0.06107362067060811, 0.1127134400552937, 0.07666197206292834, 0.10727426941905703, 0.08521304000169039, 0.09041545619922024, 0.10746569093316793, 0.02527731916468058, 0.112024598089712, 0.05002921473767076, 0.08654730447701045, 0.0541796370276383, 0.0557629917083042, 0.03708793023335082, 0.08609307956482683, 0.027258466696366668, 0.009494480976302708, 0.059485984433974536, 0.031192326053444828, 0.0630804490564125, 0.09714456940335886, 0.06272681696074349, 0.015008499114108937, 0.052947352972946, 0.09614858177623578, 0.021152404702401588, 0.056525939875947576, 0.0863559033189501, 0.03392744643081512, 3.6713729841368536, 62.101373127528596, 104.26784338269914, 94.69497667040143, 99.69749205453056, 72.67161900656563, 69.11091041564941, 45.48395368031093, 21.272054161344254, 30.672648974827357, 53.530335903167725, 56.44557768957955, 95.21685586656842, 123.16446304321289, 34.21265540804182, 0.49534853122064043, 0.5691745526024273, 0.32466288443122593, 0.12922068392591818, 0.08374949424926724, 0.09307883506906883, 0.8138880985123771, 2.3577150745051245, 4.6919808472905835, 1.0830609862293517, 1.1095728150435855, 0.7274502281631742, 1.4135642115558897, 1.8699456708771842, 2.1896770170756747, 0.8154460149151939, 1.6276950985193253, 11.362328359058925, 34.811517170497346, 57.94559301648821, 61.72958891732352, 72.93987505776542, 79.45451300484794, 88.98926189967564, 95.14442089625767, 99.01458835601807, 93.72934382302421, 88.74765219007219, 100.90526962280273, 99.35076999664307, 91.5615336554391, 82.30302429199219, 63.05367933000837, 36.681996549878804, 11.880632707050868, 1.8748191807951247, 0.5679648603711809, 0.4429687490420682, 0.548282513661044, 1.3823089344160897, 0.32936347648501396, 3.0340611934661865, 8.952706984111241, 11.110693267413549, 3.7146311657769338, 0.12209479058427469, 7.334181444985526, 56.42774166379656, 68.0143735068185, 67.79015513828823, 76.69794028145927, 83.77736255100795, 92.64216613769531, 97.99145916530064, 95.80591024671281, 87.59393855503627, 81.65451417650495, 81.31510162353516, 81.83154038020542, 83.88334342411586, 83.19376250675747, 79.36137935093471, 78.51934106009347, 79.09873744419643, 83.76707921709333, 85.14485836029053, 86.34581974574498, 87.54175758361816, 86.94965989249093, 83.5390601839338, 80.14068930489677, 76.97779287610734, 72.23932988303048, 78.39840071541923, 77.82038007463727, 65.29492500850132, 33.95668377195086, 8.63389149733952, 1.224603391119412, 0.012046847276256552, 0.13940173547182763, 0.266499432602099, 0.04764874765117254, 0.039113347085991075, 0.31132128462195396, 0.08346239251217671, 0.04863427226830806, 0.554220617881843, 0.24165614854012216, 13.947973660060338, 58.67363221304757, 49.28413193566458, 31.024908746991837, 51.53874247414725, 40.32067435128348, 9.299957973616463, 34.43328503199986, 58.56328787122454, 70.53046907697404, 68.7663631439209, 79.45070539202008, 61.18976252419608, 7.012063826833453, 0.08918764029762574, 0.07105007355234452, 0.11786559037864208, 0.048790562631828446, 0.08764777292630502, 0.11515256310147898, 0.10957806544112307, 0.01714121949459825, 0.029294650203415325, 0.15778499974736146, 0.018116920621001294, 0.07356733669127737, 0.027280327398329973, 0.02083008360516812, 0.0526457814765828, 0.055515482489551814, 0.11992000442530427, 0.08262736696217741, 0.11056312865444592, 0.08457632309624127, 0.051830223096268516, 0.009966159505503518, 0.030775138975254128, 0.07493696641176939, 0.06406153605452605, 0.06883257361395018, 0.021901276661083102, 0.04919072526640125, 0.0819648928674204, 0.12603280427200453, 0.16118245172713483, 0.12853727702583584, 0.20412834441023214, 0.18404172653598444, 0.30305325399552074, 0.30806276947259903, 0.27809095489127295, 0.19770458553518566, 0.12997134721704892, 0.11515326877789837, 0.14190928877464362, 0.12869513141257422, 0.109006990013378, 0.22933140130979673, 0.16732708843691008, 0.12313427909144334, 0.1804779249110392, 0.19007855760199682, 0.14702351577579975, 0.1297500498060669, 0.16395058961851255, 0.10321441798337869, 0.1599359286150762, 0.23828662506171636, 0.1537045751299177, 0.2421209178864956, 0.14515268616378307, 0.14682454216693128, 5.329376884869166, 78.57863698686872, 114.01044069017682, 98.2555046081543, 96.96928187779018, 60.77494812011719, 47.17204284667969, 42.6759295463562, 62.323305538722444, 103.04373059953961, 95.34156908307756, 70.89871665409633, 107.91404260907854, 134.41843250819613, 53.81439215796334, 1.2127297882522856, 0.7927778427089963, 0.7403625867196492, 0.2519179864653519, 0.23347038349934987, 0.1415080303060157, 0.25660332505192074, 1.4201098488909858, 5.299855291843414, 1.9093680126326424, 5.772649373326983, 12.907347168241229, 14.689283915928431, 18.803458213806152, 12.531645042555672, 3.718130452292306, 0.67366916260549, 7.4421668733869275, 29.700873919895717, 57.70719684873308, 66.94569887433732, 78.38982663835797, 88.26594747815813, 94.79034764426095, 101.68665708814348, 109.83776256016323, 104.61693477630615, 99.11288452148438, 110.02794865199498, 108.4118879863194, 100.73487200055803, 89.06577546255929, 65.51940046037946, 34.417161737169536, 8.908261963299342, 1.4133032198463167, 4.469126496996198, 2.071730043206896, 4.390953183174133, 7.209226778575352, 5.2459116492952615, 6.952126928738185, 10.180002910750252, 19.4428505556924, 10.889186433383397, 1.1411221964018685, 7.238815248012543, 58.265032972608296, 73.58490412575858, 74.97646849496024, 81.91353607177734, 85.57348578316825, 94.2388482775007, 98.2820953641619, 101.18251664297921, 92.9280914579119, 88.41949571881975, 86.47889164515904, 85.89057377406529, 89.73280252729143, 91.068482535226, 84.40158176422119, 83.84710856846401, 83.85500867026192, 88.06036417824882, 89.35998998369489, 93.27097811017717, 96.58490058353969, 95.88696098327637, 89.51296152387346, 86.16419383457729, 82.38023962293352, 80.25449384961809, 90.56531483786446, 94.69956248147147, 75.7617677961077, 31.99281018120902, 5.640359580516815, 0.8889192523700851, 0.6343009950859206, 0.557737220610891, 0.5215465511594499, 0.17983782211584703, 0.2665128404540675, 0.5125262694699424, 0.2239047767860549, 0.11304126067885331, 0.8457307698471206, 3.187546466078077, 25.77790709904262, 72.50753729684013, 58.617970194135395, 40.13764837809971, 65.99444184984479, 92.42833532605852, 39.719474520002095, 31.187128339494976, 49.353978702000205, 68.02771404811314, 70.25815527779716, 91.95135538918632, 65.14215496608189, 6.118207173688071, 0.22592143714427948, 0.1662057821771928, 0.22909714387995855, 0.1231295293463128, 0.1994278880634478, 0.1724280568638018, 0.15933227672108582, 0.20909100025892258, 0.1164453351604087, 0.21962065595601285, 0.12535572131829603, 0.17246107437780925, 0.13026280514895916, 0.14055162162653037, 0.13802935768451008, 0.13503708610577242, 0.2247432560792991, 0.12022295674043042, 0.2384081371128559, 0.21731546893715858, 0.20571530211184705, 0.311972298260246, 0.1444402786770037, 0.13944088694240364, 0.2036769829158272, 0.18677456703569206, 0.12884143713329518, 0.15653345547616482, 0.14672158126320156, 0.16111005204064505], [0.028353878363434757, 0.056944517950926504, 0.03542723273858428, 0.29955985716411043, 0.5610398405364582, 0.5043166471379144, 0.1010608971118927, 0.07055149959134203, 0.08537276035973004, 0.05040890597073095, 0.09553001568253551, 0.022646238561719656, 0.03811942899067487, 0.0023302627045528163, 0.008604877462078418, 0.019451755065737025, 0.037258585183215995, 0.1857352006648268, 0.08191185857036284, 0.0671898674752031, 0.1801480890384742, 0.10313359089195728, 0.026455400145745704, 0.013795384521862226, 0.061856161536914964, 0.6611802099006516, 0.21870451154453413, 1.9030657793794359, 60.65290996006557, 87.53062656947544, 79.6498338154384, 69.03054755074638, 66.17107200622559, 46.594869886125835, 28.512507881437028, 45.865576539720806, 72.65168462480817, 65.73539216177804, 57.08944640840803, 95.41007832118443, 85.9884113584246, 21.971202748162405, 0.16664293514830725, 0.07570559731019394, 0.17999777996114322, 0.04066973678501589, 0.03515157110190817, 0.19420167564281396, 0.09524313107665096, 0.9204225476299013, 0.9062243923544884, 1.2478599888937814, 1.3075501173734665, 4.585443249770573, 4.034303018024989, 0.9458960550171989, 0.9202629561935152, 1.1675927702869688, 12.996355329241071, 39.250394684927805, 65.79436847141811, 71.27783816201347, 74.73143332345145, 64.79610688345772, 68.1223624093192, 69.68807642800468, 70.40680503845215, 63.973954336983816, 62.57692173549107, 57.27882998330252, 59.59233692714146, 60.583462715148926, 60.8315828868321, 62.596932547433035, 71.83829375675747, 79.80978829520089, 82.38263675144741, 79.88581548418317, 49.32083926882063, 20.39486493383135, 2.308075189590454, 0.2927945644727775, 2.102902267660413, 1.8283342123031616, 0.4265026854617255, 0.8251324008618082, 1.3558133904423033, 1.5356073656252451, 1.8533301396029336, 34.17858491625105, 56.27272040503365, 65.48502077375139, 69.20926216670445, 81.22726944514683, 91.42340346745083, 91.96810054779053, 89.82125309535435, 83.48004218510219, 78.02801309313092, 72.99748952048165, 68.48441219329834, 68.77723707471574, 68.26664175306047, 68.52768557412284, 68.90044948032924, 67.87734808240617, 70.2061688559396, 72.58043779645647, 82.47257423400879, 80.60455799102783, 67.73805059705461, 64.38849081311906, 65.66131046840123, 72.41312517438615, 75.7101218359811, 73.80088193075997, 72.49195943559918, 66.05033315931047, 63.001296860831125, 55.495751993996755, 34.64962414332798, 12.487128802708217, 1.5588737343038832, 0.2413595744541713, 0.0650162755378655, 0.23237889206835202, 0.09994113112666778, 0.038535299710929394, 0.21575254494590418, 0.3461182160036904, 0.07576779183000326, 0.18784952935363564, 0.13429509449218, 12.747681907245092, 72.64105388096401, 68.73151097978864, 24.9976487159729, 39.497840881347656, 69.07195881434849, 35.62722526277815, 20.542501994541713, 34.34101642881121, 46.564471517290386, 66.24913501739502, 68.77622263772147, 67.25458104269845, 11.385000331061226, 0.04094231448003224, 0.3217078372836113, 0.03510537983051368, 0.017306025472602675, 0.059775657818785737, 0.04445996215300901, 0.12244747951626778, 0.14243933318981103, 0.18749053004596913, 0.03909444310037153, 0.07098915467837028, 0.1637191820357527, 0.056882448960095644, 0.15776045035038674, 0.0845388068950602, 0.0386200894468597, 0.09479898240949426, 0.030483630153217485, 0.05448693875223398, 0.11039749825639383, 0.16397735103964806, 0.04228225829345839, 0.027872813998588493, 0.030000306266759123, 0.07338059706879513, 0.18090479129127093, 0.23447122265185627, 0.21905056440404483, 0.0029732626322324252, 0.10160882092480149, 0.02596102122749601, 0.07161399722099304, 0.1797150479895728, 0.3989146186837128, 0.23283747317535536, 0.06347944800342832, 0.1089680828154087, 0.012341951485723257, 0.0670554768294096, 0.08952584929232087, 0.01656412546123777, 0.003452617724958275, 0.054344785665827136, 0.08007338150803532, 0.09063405982617821, 0.05109889805316925, 0.10502087497817618, 0.07287739549896546, 0.04806235545713987, 0.4169016049376556, 0.13157602825335094, 0.06242140834884984, 0.015144312987104058, 0.018707062882770385, 0.5922764443925449, 0.3479541146329471, 7.662845134735107, 88.81471620287213, 103.81458459581647, 95.50705432891846, 85.63490091051374, 90.94508252825055, 66.62917368752616, 29.17585413796561, 15.562821865081787, 38.720413889203755, 58.176346165793284, 66.46737098693848, 100.49768829345703, 87.93522712162563, 16.835094349724905, 0.264894643000194, 0.09093617075788123, 0.20679820328950882, 0.25360699583377155, 0.07447611221245357, 0.3614785117762429, 0.6395589358040265, 3.612242294209344, 2.4474808062825884, 1.866458760840552, 0.6185115937675748, 1.3402968687670571, 1.4016170012099403, 1.2148416063615253, 1.1448744407721927, 3.366330998284476, 23.097026314054215, 51.68987968989781, 75.26777866908482, 80.6544669015067, 78.93419020516532, 72.56148311070034, 73.08332061767578, 73.06260803767613, 74.90765353611538, 70.53422805241176, 67.52027320861816, 63.50424916403634, 64.74981103624616, 65.13410895211356, 68.58155495779855, 69.26983656202043, 79.48768370492118, 88.74975054604667, 93.51949432918003, 89.99496500832694, 62.09935120173863, 26.832862513405935, 3.484302290848323, 0.33138114107506617, 0.8782644069620541, 1.2418517512934548, 2.5961978776114325, 0.6990390441247395, 0.8565936269504684, 0.4022146873176098, 3.7099993228912354, 45.40569611958095, 63.31666169847761, 70.39772374289376, 73.90641811915806, 86.41095910753522, 95.98966925484794, 92.36923394884381, 89.02924878256661, 84.10154465266636, 78.21811580657959, 76.33535548618862, 72.3736594063895, 73.6874178477696, 72.43994522094727, 70.05419090815953, 71.07010092054094, 70.00958347320557, 72.86215250832694, 73.04423700060163, 79.46666540418352, 79.6743470600673, 68.3527090890067, 66.90001446860177, 69.93108967372349, 74.85742500850132, 75.98697280883789, 75.14403820037842, 76.7792967387608, 74.61807346343994, 75.33890737806047, 79.53896141052246, 59.28369099753243, 26.172712428229197, 4.3297352109636575, 0.5002150929399899, 0.05789947456547192, 0.06582287047058344, 0.08086542864995343, 0.013959520446535732, 0.04877977053235684, 0.3996808747095721, 0.09061244170048408, 0.10690302933965411, 0.3987743247832571, 8.172647493226187, 71.95459270477295, 74.11357171194894, 23.978024891444615, 40.82926164354597, 45.46833412987845, 10.88083209310259, 30.681893553052628, 52.98811585562569, 69.3624074118478, 85.1314274924142, 77.97778456551688, 85.93604278564453, 20.81114193371364, 0.052468863648495505, 0.3352120683661529, 0.06385017239621707, 0.017560961257134165, 0.06321728921362332, 0.0976096848025918, 0.11044770306242363, 0.1674003837896245, 0.1444889432085412, 0.05909264446901424, 0.1323389323162181, 0.16365181707910129, 0.00792114740969347, 0.09789350921554224, 0.08365996833890676, 0.05022572526442153, 0.09136701335332223, 0.03064396119277392, 0.043708772997238805, 0.07286929379084281, 0.08109944859253508, 0.02286866742984525, 0.04390782803030951, 0.05160937691107392, 0.15198873648686068, 0.12275826212550912, 0.15564127692154475, 0.144374976466809, 0.037235816940665245, 0.33847650034087046, 0.2697453541415078, 0.1273645513824054, 0.2627981597823756, 0.7210183132972036, 0.6666995765907424, 0.24965819343924522, 0.1439303731811898, 0.13437646441161633, 0.22053479190383637, 0.20769169820206507, 0.11753698943981103, 0.10982687744711127, 0.10442846640944481, 0.13762193811791285, 0.22732396902782576, 0.1527127062103578, 0.46968894238982883, 0.2814544258373124, 0.1531546496387039, 0.40614234656095505, 0.256938955613545, 0.17441260894494398, 0.11946576594242028, 0.1561917180993727, 0.8309388150061879, 0.3759940857333796, 11.36777835232871, 110.90517262050084, 113.8819546018328, 102.64728723253522, 91.6504636492048, 79.53349317823137, 54.931113583701, 36.58616699491228, 61.1277984891619, 106.62149006979806, 100.01382269178117, 77.79420621054513, 112.88604150499616, 104.54567405155727, 31.245149271828787, 0.3602180651256016, 0.2248658537864685, 0.4033547347145421, 0.33237104224307196, 0.26089177493538174, 0.44068583154252594, 0.25953133936439243, 3.2290115782192776, 7.019475383417947, 4.781362473964691, 2.841084965637752, 13.781645945140294, 12.436773470469884, 4.192277695451464, 1.3361283838748932, 1.474388416324343, 17.59255395616804, 47.726846081869944, 80.48264489855084, 90.23017542702812, 91.48552731105259, 79.4500870023455, 82.57251712254116, 80.99128777640206, 81.5543281010219, 78.15872955322266, 77.24030276707241, 69.61898354121617, 74.28859683445522, 75.75673730032784, 77.7298172542027, 78.60361576080322, 91.03396388462612, 101.30318600790841, 107.19506386348179, 98.65262195042202, 64.27826459067208, 26.85696928841727, 3.3230971353394643, 2.2540388320173537, 6.776936786515372, 3.566705320562635, 5.957562216690608, 2.7668536688600267, 4.3998546940939764, 4.122328877449036, 3.5329008144991736, 47.14000817707607, 67.88851383754185, 74.9722717830113, 76.15429932730538, 86.3170472553798, 96.7093984058925, 96.69235447474888, 98.6670047215053, 91.37673241751534, 86.76426110948834, 80.29523808615548, 77.72449493408203, 78.68408979688371, 77.30995845794678, 74.91291332244873, 78.1044363294329, 78.75478076934814, 81.41595472608293, 80.8597583770752, 84.06567805153983, 87.72486346108573, 78.29784638541085, 75.19217532021659, 77.8885280064174, 82.77424417223249, 87.37511198861259, 86.31844384329659, 84.04742513384137, 79.61695493970598, 84.40032414027623, 94.99472890581403, 67.55164432525635, 24.992241280419485, 2.0014016798564365, 0.40824585940156666, 0.3096988802509648, 0.2836358073566641, 0.22652017644473485, 0.0864914542596255, 0.2787668029112475, 0.4008195378950664, 0.23421500782881463, 0.3214030936360359, 0.7022437378764153, 17.436964682170323, 88.59593132564, 85.07154791695731, 33.912312575748985, 58.113843645368306, 99.22502149854387, 49.375486850738525, 27.92477192197527, 41.46777330126081, 62.95930889674595, 81.73203522818429, 86.59860910688127, 100.70909418378557, 22.880086183547974, 0.24878266613398278, 0.6066126408321517, 0.13748950165297302, 0.0776630419173411, 0.22912499095712388, 0.19993862137198448, 0.3108488071177687, 0.28216392919421196, 0.4205326629536492, 0.2252865590687309, 0.4019396906452519, 0.25898997698511395, 0.1394370464341981, 0.19350908137857914, 0.15991665822054657, 0.07380911907447235, 0.21352119610777923, 0.21127907213355812, 0.14422264535512241, 0.2125665923314435, 0.2502711819750922, 0.12854034400412015, 0.16986303164490632, 0.07905919557171208, 0.29392188255275997, 0.20774189622274467, 0.2139524051121303, 0.3478873467871121, 0.15524190478026867], [0.07281691088740315, 0.1109883054824812, 0.12502451480499335, 0.10283122890229736, 0.23996415361762047, 0.09443070752812283, 0.03396141389384866, 0.014248463558033109, 0.0921242448634335, 0.02588261311341609, 0.04618177529690521, 0.0367489205673337, 0.03518243765990649, 0.06424749536173684, 0.0451097951403686, 0.008575672466707016, 0.06894062353031975, 0.03611900597544653, 0.0437264454417995, 0.07250247097441129, 0.09413025222186532, 0.035658708174846, 0.009242811489717236, 0.06578642635473184, 0.34148094483784264, 0.24749594660741941, 5.155334063938685, 57.0563382421221, 87.5607192175729, 69.46191951206752, 71.49821417672294, 65.12263747623989, 33.55154473440987, 45.08506107330322, 83.19254657200405, 84.30820492335728, 47.058950492313926, 54.63698591504778, 80.25108923230852, 64.7371792112078, 8.03036836215428, 0.31082554693732944, 0.08695530758372375, 0.08793749380856752, 0.0373515546587961, 0.05582272314599582, 0.09094953789774861, 0.04038294378135886, 1.6985403427055903, 13.557725480624608, 0.9024061943803514, 2.348143062421254, 0.19123887962528638, 0.10968136561236211, 0.38176255619951655, 3.3334849093641554, 25.18243432044983, 59.271510805402485, 73.23334612165178, 74.34075001307896, 69.1677953175136, 63.64932060241699, 61.69233267647879, 66.70522172110421, 61.28520992824009, 61.56087275913784, 61.9780912399292, 62.09585625784737, 66.92864104679653, 64.79741314479283, 64.77590152195522, 67.79350417000907, 73.87991074153355, 76.23128536769322, 71.32757336752755, 67.02353259495327, 66.8462701525007, 63.836407797677175, 73.87961196899414, 82.98249558040074, 65.39622279575893, 33.47625058037894, 8.347730806895665, 1.3229610047170093, 1.0328909754753113, 0.9082559262003217, 1.5089316027505058, 0.7219519774828638, 9.25146302155086, 47.43954849243164, 39.86517129625593, 53.93483918053763, 65.75719560895647, 73.43906838553292, 74.27104568481445, 69.73774909973145, 65.90290628160749, 65.24447413853237, 67.59716197422573, 70.87295273372105, 67.12813077654157, 68.8004787990025, 67.45435564858573, 64.93703719547817, 62.820025307791575, 64.9783581324986, 64.96776907784599, 66.3059504372733, 62.363688468933105, 62.05752304622105, 71.02650792258126, 68.32744543892997, 66.95849050794328, 66.52035100119454, 66.0121180670602, 63.510669299534385, 70.88704368046352, 72.96656308855329, 71.90084144047329, 67.97868061065674, 63.520771980285645, 49.43873282841274, 27.371090820857457, 8.262883748326983, 0.9824757150241307, 0.15302959563476698, 0.028823153182332004, 0.23992140591144562, 0.19123160572988646, 0.18697915891451494, 0.133406702162964, 0.07477859633841685, 0.26891634719712393, 0.49606278432267054, 2.299090083156313, 50.952113015311106, 87.37967695508684, 43.87435483932495, 30.10036059788295, 70.43911416190011, 38.10192346572876, 23.25531496320452, 24.966449567249843, 38.724759987422395, 53.397521087101524, 51.850431714739116, 65.26628453390938, 16.7835647719247, 0.4167168805641787, 0.023246438408802663, 0.08044777677527495, 0.058611176375831874, 0.15981839277914592, 0.10404309244560343, 0.23513409708227428, 0.1833414105432374, 0.052415829351437945, 0.09913714176842145, 0.11691752767988614, 0.0663547944277525, 0.07211415216858898, 0.005854490470872926, 0.027040550086115087, 0.008940268840108598, 0.09494864687855754, 0.02637821339469935, 0.08688581202711378, 0.09190378883587462, 0.04676745279825159, 0.08171063222523246, 0.05918133578130177, 0.09425894995885235, 0.18341433948704175, 0.08261248668921845, 0.028876550495624542, 0.027067313203588128, 0.09528154972940683, 0.08362072187342814, 0.02501073632655399, 0.041691043946359835, 0.06772290422980275, 0.05432462639042309, 0.0755668572549309, 0.040420968883803914, 0.013247958584023374, 0.018243547129843916, 0.006695536322825189, 0.027949819241517355, 0.05515351119850363, 0.056591174232640436, 0.03415515260504825, 0.03386702288740447, 0.06768952709223543, 0.02907364795516644, 0.08321161953998463, 0.08269238418766431, 0.054427641576954296, 0.019966323793466603, 0.03603901008942297, 0.13009804327573093, 0.1707071970616068, 0.1983646508306265, 13.142284001622881, 84.43880326407296, 99.49286065782819, 89.78138433183942, 96.71660368783134, 88.53368241446358, 51.76339857918875, 34.33429752077375, 32.195124353681294, 70.64730998447963, 47.15822287968227, 63.15980611528669, 89.94247136797223, 64.06324563707624, 4.732123630387442, 0.17840361621763023, 0.0738631168912564, 0.15389540631856236, 0.08169718366116285, 0.05066102922761014, 0.5488273501396179, 0.1848774238356522, 0.3959138111344406, 4.721467265060969, 0.4297295537378107, 0.8445465362497738, 0.5875579118728638, 0.579249983387334, 1.1390208005905151, 7.9846075262342175, 37.934798445020405, 74.3630815233503, 83.22565473828996, 82.79016249520438, 74.27705587659563, 69.46937492915562, 68.54240185873849, 75.16507039751325, 69.7536952154977, 70.6666954585484, 70.86074474879673, 71.89924335479736, 76.57135105133057, 77.49199431283134, 75.28663608006069, 79.58317974635533, 82.27078465053013, 84.23713874816895, 78.5402203968593, 75.66024071829659, 75.97295134408134, 74.40406199863979, 83.478346824646, 92.58794239589146, 76.66037137167794, 42.483325481414795, 11.91763881274632, 2.0977041465895514, 1.119823145014899, 0.7936235144734383, 1.4351252317428589, 1.2422973045281, 15.370174373899188, 56.96012653623308, 46.77218096596854, 59.707086426871165, 67.7950188773019, 74.85626465933663, 72.22573225838798, 72.18391105106899, 67.25579002925328, 67.55002539498466, 69.28942353384835, 72.19008105141776, 69.85248470306396, 72.7316722869873, 73.14585440499442, 68.34867913382394, 65.6500335420881, 69.42337785448346, 70.59404509408134, 69.15089729854039, 65.19245992388043, 67.06855692182268, 74.33338492257255, 71.85524041312081, 69.92236273629325, 71.44499792371477, 70.9822826385498, 68.97064018249512, 72.8259037562779, 72.88665185655866, 77.70022487640381, 75.7826818738665, 77.84963199070522, 75.90925025939941, 51.13040031705584, 16.386327573231288, 2.2396851565156664, 0.42297172493168284, 0.0590088725356119, 0.12305855458336216, 0.16337379414056027, 0.2055657258523362, 0.17672607409102575, 0.12760867471141474, 0.09066618167396102, 0.47198315071208136, 1.1845205362354005, 47.40995611463274, 93.33381761823381, 43.83480569294521, 37.04235097340175, 42.26931401661464, 9.535655634743826, 29.288335050855363, 43.43861940928868, 62.93032101222447, 75.28372478485107, 59.392333030700684, 78.53913647787911, 30.478380816323416, 0.47659273764916826, 0.04624654485711029, 0.07361987565777131, 0.04929824253278119, 0.41601462396127836, 0.16676176020077296, 0.23225727145160946, 0.021832909168941633, 0.00478906962754471, 0.09839783036815268, 0.13366226559238775, 0.06254002305545978, 0.08510220130639416, 0.07741858610617262, 0.04685777259458389, 0.01359678665176034, 0.05673268271077957, 0.10445638134011201, 0.02793977183422872, 0.010036687283510608, 0.05090545789737787, 0.113711327580469, 0.05658377820093717, 0.09548110009304114, 0.21430375054478645, 0.02043013640546373, 0.09138126258871385, 0.03211482833804829, 0.407926296549184, 0.14665664546191692, 0.19966690880911692, 0.3324638658336231, 0.4082587787083217, 0.16021629928478173, 0.11421807110309601, 0.09243542102298566, 0.18650824204087257, 0.16577546883906635, 0.20867765029626234, 0.17610986929919037, 0.11641606315970421, 0.1574859693646431, 0.08841263795537607, 0.12762314107801231, 0.1156505670930658, 0.27802228714738575, 0.19623367089246, 0.2738324962556362, 0.2554557052041803, 0.151239240275962, 0.08228060164089714, 0.16298324295452662, 0.6056430957147053, 0.24564734580261366, 15.729576894215175, 104.46295574733189, 111.69983809334892, 92.9902014051165, 94.09102535247803, 83.12216132027763, 46.00979682377407, 58.49212442125593, 106.61654990059989, 120.43861525399345, 67.6270809173584, 73.95625059945243, 99.0324730191912, 83.33872972215924, 12.104726876531329, 0.5825713308794158, 0.17532415288899625, 0.18376747625214712, 0.25234122946858406, 0.13875236388828072, 0.24261801264115743, 0.17603455191212042, 3.8107343060629706, 26.661238534109934, 4.472555433000837, 7.1681051680019925, 3.0806868629796162, 2.5836770066193173, 0.7631688000900405, 4.481226350579943, 32.79563978740147, 78.69068363734654, 92.9467682157244, 91.39693777901786, 81.9749025617327, 79.06456620352608, 74.35397243499756, 81.72514261518205, 75.48235988616943, 76.59110477992466, 75.2771656853812, 77.0419316973005, 82.4296760559082, 81.13394124167306, 78.40900366646903, 84.66990729740688, 85.73178659166608, 88.77269349779401, 81.24744701385498, 78.78296266283307, 77.45947674342564, 79.41662447793144, 91.78090218135289, 99.09135205405099, 76.86038916451591, 40.95539576666695, 8.735878024782453, 2.5764000713825226, 3.2137733101844788, 5.545804151466914, 4.740630831037249, 1.507813919867788, 14.232146297182355, 60.88065801348005, 54.50539745603289, 65.57825865064348, 73.45710590907505, 80.79450784410749, 78.98505101885114, 78.40502234867641, 77.22012519836426, 77.06663254329136, 78.37765339442662, 78.45241601126534, 72.37019225529262, 77.49433585575649, 78.89726052965436, 75.42323071616036, 71.73913601466587, 72.56263651166643, 74.18704196384975, 75.04091998508999, 76.0227838243757, 73.1628566469465, 74.83594117845807, 74.16029139927456, 73.8596497944423, 79.57755170549665, 77.9210455758231, 75.64349555969238, 83.16389220101493, 83.95684146881104, 86.26863915579659, 80.6485400881086, 85.67932769230434, 87.91040815625871, 61.28418159484863, 15.01269997869219, 1.1014504794563567, 0.5459701748830932, 0.1405093353241682, 0.2617558485695294, 0.2732268087565899, 0.2841658246304308, 0.28890615169491085, 0.22039926131921156, 0.2713278335119997, 0.6136150136590004, 3.276020267180034, 60.39798750196184, 103.72858674185616, 55.318340165274485, 47.794719559805735, 103.64189406803676, 51.11981821060181, 31.82847833633423, 33.81413105555943, 52.677062375204905, 69.22347818102155, 68.05943952287946, 94.3900271824428, 37.48596566064017, 0.6008208830441747, 0.1459049236561571, 0.13174199791891233, 0.20510063080915383, 0.6930258667894772, 0.5743719137140683, 0.5093837838087762, 0.33390008019549505, 0.1625075220529522, 0.16643355281225272, 0.26291991610612186, 0.16804607771337032, 0.1983491802322013, 0.10106375374432121, 0.15740074536630086, 0.1220446875584977, 0.11528999358415604, 0.18844855363879884, 0.2248976227960416, 0.2298888856811183, 0.1322107706218958, 0.24620409735611506, 0.14597224790070737, 0.1669572325689452, 0.2463169784418174, 0.26197756667222294, 0.22377432164336952, 0.15389103655304226], [0.0587709103045719, 0.17493437523288385, 0.05315024172887206, 0.031093253155371973, 0.010724250210582145, 0.12061061736728464, 0.12098862922617368, 0.13595176488161087, 0.08328941357987267, 0.06683802671198334, 0.012902076206436115, 0.062152742408216, 0.14556622611624853, 0.035391545189278464, 0.03641545792509403, 0.029173036372022967, 0.029945341537573507, 0.03983695040057812, 0.07883777602442674, 0.2513325735926628, 0.14301011684749806, 0.08735604358038732, 0.03251212416216731, 0.14893469108002527, 0.1553314035492284, 17.470970903124126, 76.4896263395037, 88.00989246368408, 77.9592537198748, 59.64604650224958, 43.04514292308262, 32.44054862431118, 35.55113901410784, 65.6018408366612, 66.34464495522636, 27.445754425866262, 77.86366735185895, 92.20158781324113, 71.54539244515556, 2.883588833468301, 0.41154275249157635, 0.1292288534875427, 0.1038374759789024, 0.07985669134982995, 0.06601173390767404, 0.025254522084391544, 0.1844302692583629, 1.9985822311469486, 13.812140720231191, 2.0039162763527463, 1.372033091528075, 0.2588930550430502, 0.2474927982049329, 8.89778060572488, 33.274165698460166, 72.89909608023507, 76.43082373482841, 68.21354361942836, 62.9452804837908, 62.97813851492745, 60.84682723454067, 66.41505799974713, 66.66392162867955, 67.71669878278459, 68.92080770220075, 65.35345663343156, 65.73582989828927, 65.40743718828473, 62.573711667742046, 63.993444034031455, 67.67525277818952, 72.30676909855434, 74.18356091635567, 71.59642001560756, 68.00384698595319, 72.56823675973075, 70.03285299028668, 70.08012853349958, 60.906470571245464, 56.22751195090157, 68.43257863180978, 79.96310029711042, 79.38070229121617, 29.096007176807948, 6.12799197435379, 6.063857930047171, 8.60376410824912, 19.10611653327942, 21.51072825704302, 35.99336406162807, 39.930887358529226, 47.271544524601524, 46.128628390175955, 52.4643988609314, 51.8077072416033, 54.729344844818115, 55.27539682388306, 52.751307351248606, 55.41190460750035, 60.65428570338658, 62.142249379839214, 61.809541838509695, 57.05612979616438, 59.12618228367397, 61.89690153939383, 61.29118537902832, 61.63429437364851, 56.23466164725167, 51.562279496874126, 70.21890490395683, 81.7310346875872, 77.30010591234479, 77.61211477007184, 71.28783661978585, 69.74618421282086, 67.65777111053467, 66.5152371270316, 63.35324396405901, 65.9327210017613, 71.72067465100969, 74.322420665196, 70.94558225359235, 57.88410840715681, 37.18206187656948, 19.516643898827688, 3.8239962458610535, 0.33697625941463877, 0.029557809832372835, 0.06900579003351075, 0.022662350375737463, 0.07361287996172905, 0.06052379695964711, 0.12789321158613476, 0.15739269794097968, 0.14228493933166775, 0.2032505100859063, 30.910037653786794, 92.43734019143241, 65.9330197743007, 41.747000558035715, 64.07689189910889, 48.004235540117534, 30.003794533865793, 32.32250567844936, 41.965347698756624, 57.35043811798096, 60.98206697191511, 57.285694803510395, 18.55478913443429, 0.8496436370270593, 0.11497390483106885, 0.12781641499272414, 0.02871350192331842, 0.1533229263233287, 0.04614406571324382, 0.04102188288899405, 0.07515968196094036, 0.0813285152294806, 0.10254599313650813, 0.07835108321160078, 0.08976682421884366, 0.0913134633696505, 0.023033787230295793, 0.07290041140679802, 0.04050916147285274, 0.10560961267245667, 0.09254929276981524, 0.0377543364385409, 0.05824051983654499, 0.054124068402286084, 0.03344763396307826, 0.06766189036092587, 0.0750165314280561, 0.02297254265951259, 0.08507928039346423, 0.03838852919372065, 0.016531009559652636, 0.04058610734396747, 0.029404192896825925, 0.0872713081272585, 0.020881253627261946, 0.0854949238044875, 0.07012843979256493, 0.16544203673090252, 0.033955625990139585, 0.08751410152763128, 0.0297165700633611, 0.026131667695673447, 0.060435933460082324, 0.05211670397381697, 0.09841944170849663, 0.01398519960431648, 0.08295934022005115, 0.006163158171278025, 0.14232574642768928, 0.29753931558557917, 0.1998864555997508, 0.05002554725589497, 0.0389651346818677, 0.11032030811267239, 0.1708486309008939, 31.144872869764054, 100.88015883309501, 97.94965185437883, 99.46576268332345, 77.52150331224713, 63.61159883226667, 59.07395962306431, 23.562286376953125, 28.70114799908229, 53.78375060217721, 29.83787849971226, 80.88236781529018, 96.49745750427246, 72.48909677777971, 1.7328798600605555, 0.6291904864566666, 0.026206391364602104, 0.053525597123163085, 0.07691064836191279, 0.1316428096698863, 0.6128508203795978, 0.5038543748004096, 1.8043839888913291, 2.513211633477892, 0.9226053676434925, 0.48573569847004755, 0.34890409080045565, 1.0538904943636485, 15.726236547742571, 49.08049413136074, 85.34892695290702, 86.56002576010567, 75.49438026973179, 71.62542179652623, 71.80055114201137, 71.50274440220424, 75.87170914241246, 73.40680095127651, 74.27563149588448, 77.14659241267613, 76.32993589128766, 73.18208926064628, 73.76178441728864, 72.09502969469342, 71.12982763562883, 76.40791552407401, 78.01014232635498, 81.73304966517857, 78.90980202811105, 75.31942462921143, 76.31451089041573, 75.66200556073869, 76.4865482875279, 67.49395343235561, 65.37954711914062, 72.35057054247174, 86.85925688062395, 88.24908420017788, 40.43326990944998, 13.058737993240356, 8.393739172390529, 13.45613065787724, 30.713254247392925, 25.904404265539988, 38.2303991317749, 49.22648273195539, 50.08488055637905, 52.26256758826119, 57.9419139453343, 55.71865715299334, 58.772122928074424, 60.45764473506382, 57.046874795641216, 61.31082098824637, 67.94990812029157, 67.03129373277936, 65.79919052124023, 64.51095976148332, 62.91721670968192, 65.92396627153668, 66.76393399919782, 66.22175216674805, 63.0468145098005, 63.194373403276714, 76.18250901358468, 81.47035912105015, 74.59179537636894, 77.43586676461356, 73.30291843414307, 71.57164968763078, 71.35783277239118, 73.30734443664551, 71.15801647731236, 69.87123094286237, 73.25761617933, 75.15710081372941, 76.43973132542202, 77.90014539446149, 67.55523654392788, 36.870966706957134, 8.094633987971715, 1.0994692657675063, 0.028692294311310564, 0.024874109907874038, 0.07524822399552379, 0.08829738878245864, 0.09544920894716467, 0.1267099143671138, 0.06987056934407779, 0.15352407124425682, 0.3637283167668751, 26.271566186632427, 96.6182449885777, 66.893233026777, 49.62273154939924, 38.71679735183716, 14.100464037486486, 29.931508949824742, 45.05430139814104, 60.02097129821777, 76.5266671861921, 69.82600511823381, 67.14944090162004, 29.788455963134766, 1.4320387116500308, 0.07855317808155503, 0.2156937973839896, 0.08178183769008943, 0.08220493820096765, 0.16284066917640821, 0.05337845341169408, 0.12919636523084982, 0.07574481663427182, 0.07536502022828374, 0.07762474540088858, 0.041461054501788955, 0.021671109101069824, 0.04346501607713955, 0.03531462645956448, 0.06404149213007518, 0.12529451745961392, 0.04642684178959046, 0.060335645984326086, 0.06624766731900827, 0.10556025603520018, 0.03244931556816612, 0.08451087160834245, 0.06987237424722739, 0.05839165672659874, 0.07137544466448681, 0.03754526962127004, 0.14627026048089775, 0.22955871054104396, 0.11766118848962442, 0.2438433383192335, 0.1455537953547069, 0.19178002487335885, 0.16156049072742462, 0.20445725747517177, 0.1792020212326731, 0.14271407201886177, 0.1383632104843855, 0.25408769718238283, 0.27499162405729294, 0.1654730322105544, 0.16168536831225666, 0.10607341849910361, 0.18994044858430112, 0.0897636418896062, 0.21636566918875488, 0.5445587677615029, 0.3484740081642355, 0.26229357400110787, 0.09177004279834883, 0.2014643345028162, 0.16846816720707075, 32.40762111118862, 117.31835991995675, 107.96707820892334, 102.27230685097831, 76.56049796513149, 53.912893295288086, 43.67324617930821, 51.697244780404226, 88.21949182237897, 96.06974029541016, 39.309245926993235, 98.88668591635567, 107.3331732068743, 90.60368973868233, 5.221383639744349, 1.0902171965156282, 0.3089169364954744, 0.2441662395639079, 0.17682109613503727, 0.2502169263150011, 0.4397614225745201, 0.3929475817297186, 5.75882636649268, 30.658207144056046, 7.2730598790305, 2.8962475827762058, 1.6609388632433755, 0.4991108721920422, 12.59144297667912, 44.18103095463344, 89.9549503326416, 95.8442017691476, 80.73870686122349, 76.66235160827637, 77.21938174111503, 77.62327357700893, 80.54957689557756, 81.99467713492257, 85.50954151153564, 86.4083604812622, 82.12384414672852, 80.75839110783168, 80.79655061449323, 80.2526386805943, 78.14280428205217, 81.70744555337089, 86.02477822984967, 87.58936664036342, 83.7484302520752, 80.11321612766811, 83.55654185158866, 80.25495937892369, 79.14842401232038, 71.0766600200108, 67.90703078678676, 80.7562232698713, 93.29027325766427, 93.18568202427456, 37.82577773502895, 11.512683033943176, 7.955904517854963, 13.336480941091265, 27.69762315068926, 29.509357248033794, 48.159559045519146, 54.002125535692485, 56.51774862834385, 59.61764921460833, 62.958009583609446, 61.40159225463867, 63.564024516514365, 66.9887638092041, 63.62106922694615, 63.475837979997905, 68.0673326764788, 66.09945692334855, 69.53824547358921, 65.94681194850376, 66.05696174076625, 71.6575711114066, 70.84627859933036, 71.92453479766846, 70.60800402505058, 69.365325655256, 77.72143077850342, 85.04775033678327, 76.72910295213971, 76.13511535099575, 74.35972554343087, 77.04405089787075, 78.32226930345807, 79.85729312896729, 76.67042541503906, 76.66286577497209, 81.8335553577968, 83.0886710030692, 80.25857939038957, 84.29760892050606, 84.19623470306396, 44.691702706473215, 6.25719633272716, 0.774470750774656, 0.18355267920664378, 0.24391664724264825, 0.11252716862197433, 0.2193420087652547, 0.1848775731133563, 0.278296279587916, 0.2153455460710185, 0.39451567615781513, 0.6163428872823715, 37.307789530072895, 107.80220440455845, 78.59811973571777, 60.58812495640346, 94.01165607997349, 64.67668124607631, 39.99974053246634, 38.657324245997835, 52.47569663184029, 74.45449202401298, 75.79270812443325, 83.02635955810547, 38.28483131953648, 1.8822385541030338, 0.2454058959015778, 0.2756840283317225, 0.171479125640222, 0.3905708635491984, 0.37467137670942713, 0.2745994579579149, 0.1821905201567071, 0.1760366689413786, 0.1971030913825546, 0.14115452713200025, 0.15803361497819424, 0.17102822554962976, 0.08245190459170512, 0.16555081946509226, 0.20132329421383993, 0.2510432191193104, 0.29794844506042345, 0.2749107969658715, 0.11948776404772486, 0.15807427279651165, 0.22993054773126329, 0.2219475425247635, 0.13168601877987385, 0.15735007237110818, 0.1298461982182094, 0.16354525993977273], [0.0068756377524031055, 0.06128542537667921, 0.020533311047724316, 0.16081179518784794, 0.22538820361452444, 0.16613081762833254, 0.09470643701830081, 0.11064574707831655, 0.09943453688174486, 0.19753237334745272, 0.08889233507215977, 0.1192085604582514, 0.10312251720045294, 0.2085428118173565, 0.032573942095041275, 0.10254771661545549, 0.03580717502960137, 0.03597592329606414, 0.1031873512214848, 0.03596807264589837, 0.046191980463585684, 0.028014858519392352, 0.023357606193582927, 2.357259533235005, 46.00055224554879, 86.79395771026611, 84.08104051862443, 78.1064374106271, 68.35293143136161, 48.785914829799104, 34.39880459649222, 28.526296581540787, 63.80602332523891, 54.58684771401541, 48.6019925389971, 85.71623652321952, 79.8492888041905, 51.71577215194702, 3.900647904191698, 0.05540957335116608, 0.17660256714693137, 0.050589477709893665, 0.08324414172342845, 0.15522237654243196, 0.11020214802452497, 0.11534893113587584, 2.895069863115038, 1.7123536872012275, 1.220535003713199, 0.3497814637209688, 1.22198609156268, 14.917322056634085, 49.05261448451451, 75.65248652866909, 90.19961030142647, 70.96546799795968, 61.6067795072283, 64.00910527365548, 67.3501535143171, 63.56770706176758, 67.9641032900129, 64.67075443267822, 58.124807902744834, 60.31069728306362, 60.55022948128836, 63.92735276903425, 63.76730796269008, 63.087690762111116, 65.09694303785051, 67.92615917750767, 65.81096771785191, 64.68636703491211, 69.9741962977818, 71.24910736083984, 73.64813273293632, 71.53960459572929, 67.25603321620396, 65.9456377029419, 66.44167654854911, 64.1298302241734, 58.360018321446006, 56.90144552503313, 60.53323418753487, 72.60305418287004, 65.224928855896, 41.49495118004935, 56.652613162994385, 68.11381612505231, 43.44678701673235, 43.548345361437114, 51.72288710730416, 52.92720447267805, 64.91778373718262, 64.32480362483433, 62.310486112322124, 64.78997162410191, 67.84271826062883, 64.90843841007778, 67.1198902130127, 68.45032433101109, 68.79883902413505, 63.73649270193917, 64.71579265594482, 52.40692336218697, 59.61197253635952, 66.87037345341274, 60.77226611546108, 59.37082140786307, 70.33828885214669, 66.2426870891026, 67.26662227085659, 58.36794621603829, 64.67573629106793, 73.67723873683384, 67.27231979370117, 67.18257686070034, 65.2418268748692, 67.87786224910191, 67.93440668923515, 65.97186020442417, 66.15454918997628, 70.29723194667271, 72.80634457724435, 65.8713128226144, 42.889232294900076, 25.515704665865215, 8.532756992748805, 0.21096731243388994, 0.18250027139272007, 0.08189379596816641, 0.13655069417187146, 0.12493569457105227, 0.003035673647121127, 0.19465974106320313, 0.11757950644407954, 0.07034154728587184, 0.2594745595540319, 21.921781948634557, 83.57777554648263, 73.63313157217843, 45.74402822766985, 65.97158922467912, 54.30067573274885, 34.030918325696675, 38.07358523777553, 36.359475067683626, 52.21502453940255, 53.19772563661848, 67.09844807216099, 34.15505484172276, 1.1987412188734328, 0.09247985149600677, 0.1026765297033957, 0.029148632860077277, 0.038902570360473225, 0.03287719975092581, 0.04730283389134066, 0.10706250542508704, 0.10272839692022119, 0.04027782174359475, 0.10625234139817101, 0.028334329769547497, 0.010669033575270857, 0.03640798046918852, 0.02895692636125854, 0.05338258229728256, 0.03843670518004468, 0.03953754682359951, 0.10682874332581248, 0.10866889636963606, 0.14684393469776424, 0.12136813386210374, 0.07044706626662187, 0.05500172630750707, 0.020136059328381504, 0.010244360559486916, 0.02130846436401563, 0.056455168673502545, 0.03308850573375821, 0.08406571192400795, 0.21910727636090346, 0.16494335420429707, 0.05633353448605963, 0.08456786854990891, 0.06743009601320539, 0.0985236850434116, 0.15995788600827965, 0.0574278248740094, 0.21078052531395639, 0.0695995149601783, 0.031402844935655594, 0.03569758144606437, 0.05580289296007582, 0.027915444657472626, 0.0981464060023427, 0.029232072311320474, 0.1195867487362453, 0.03377680826400008, 0.03442727228892701, 5.0756208556038995, 66.99679592677525, 102.69228376661027, 93.85910143171037, 96.78798253195626, 86.05371052878243, 69.3172163282122, 52.67471040998186, 18.083468505314418, 37.433645725250244, 60.9905229296003, 52.58733333860125, 76.68018763405937, 91.04972239903041, 50.13561282839094, 1.8883985664163316, 0.4016707736466612, 0.15084904192813806, 0.021044219079028283, 0.03945984099326389, 0.3497507667967251, 0.6722156863127435, 1.0270577456269945, 1.7406373066561562, 1.3539945908955164, 0.3033420113580567, 1.61335531941482, 2.7051795039858137, 28.40791491099766, 69.78341266087124, 87.83754239763532, 94.30892780848912, 76.15687710898263, 70.92318820953369, 75.98598616463798, 74.89582075391496, 72.222487449646, 76.3570338657924, 70.9167263848441, 66.46186801365444, 69.99900136675153, 68.43654605320522, 71.7200562613351, 72.41015829358781, 71.1563002722604, 72.80025795527867, 76.94521972111293, 77.47820213862828, 74.04554884774345, 77.12077290671212, 79.53537614004952, 80.02111080714634, 77.83449186597551, 71.66581862313407, 72.82285349709647, 76.78258323669434, 72.08125836508614, 69.8493788582938, 64.94135202680314, 68.32669503348214, 82.53380175999233, 78.46636799403599, 52.461240904671804, 67.42771625518799, 79.66927487509591, 44.743855885096956, 46.62123482567923, 57.17121280942644, 58.01391117913382, 71.30787522452218, 71.48501259940011, 69.86530412946428, 68.31654371534074, 70.74905245644706, 69.47025040217808, 71.98134326934814, 73.87665898459298, 74.42176600864956, 70.22497762952531, 68.58700234549386, 55.80121912275042, 64.05066244942802, 70.78498853955949, 67.93032809666225, 69.74837289537702, 75.35120568956647, 72.20262949807304, 71.85730402810233, 62.96151842389788, 66.68692016601562, 72.49508612496513, 68.65340627942766, 67.51259544917515, 67.95906584603446, 71.73570360456193, 71.12337275913784, 69.67162309374127, 70.21047673906598, 73.38458061218262, 74.10417079925537, 77.02483912876674, 71.49005004337856, 48.063027722494944, 18.36829948425293, 0.9848904311656952, 0.1414213813841343, 0.18401598291737692, 0.07037467336548225, 0.1786202045955828, 0.037422146049461195, 0.044238664742027006, 0.12325933309538023, 0.05758339259773493, 0.36917239321129663, 18.875511033194407, 87.26942988804409, 77.5513527733939, 51.082033906664165, 46.1486530985151, 17.95687406403678, 28.340939487729752, 53.30002743857247, 51.73909725461687, 69.05425480433873, 64.0661986214774, 76.13991655622209, 50.487577302115305, 2.7274549944060187, 0.15165720427674906, 0.13945554329880647, 0.080326868620302, 0.091113505885005, 0.020364472875371575, 0.009160493317592357, 0.05783134964959962, 0.06600279081612825, 0.02353870210104755, 0.040747734385409524, 0.006420980698229479, 0.003338663069631106, 0.03251973053972636, 0.03206024019579802, 0.021819408018408076, 0.0885502312864576, 0.015076737684596862, 0.04056106600910425, 0.053774012186165364, 0.03982659595619355, 0.12455442574407373, 0.09155671138848577, 0.06241663146231856, 0.08832073717245034, 0.06097190148596253, 0.10304635164460965, 0.12889859692326613, 0.18467722886375018, 0.19309754988976888, 0.2892401266310896, 0.1787443629332951, 0.14926403840737684, 0.1578826137951442, 0.13612974461700234, 0.23875150297369274, 0.24991245408143314, 0.21240592880972795, 0.36838675822530476, 0.4360511659511498, 0.21149388274976186, 0.24017403806958879, 0.14037662744522095, 0.2009235013808523, 0.19441421995205538, 0.20637918077409267, 0.16825518863541739, 0.19418705999851227, 0.14894406843398297, 5.178453760487693, 77.25424085344586, 122.28391783578056, 101.63462202889579, 103.93850571768624, 86.73222991398403, 59.070687021527974, 45.5264002255031, 38.540333952222554, 91.06767654418945, 80.23989568437848, 69.03585597446987, 112.01909392220634, 96.6425358908517, 67.68916307176862, 6.202725061348506, 0.9063395261764526, 0.5723071045109204, 0.24822895441736492, 0.16553526744246483, 0.4951071898852076, 0.4574616327881813, 0.9113397321530751, 7.293421575001307, 9.226752621786934, 5.8505812372480115, 2.537359880549567, 1.7636814415454865, 27.810882261821202, 74.76677186148507, 97.7042623247419, 105.2225397654942, 82.65868173326764, 77.07954924447196, 82.68423025948661, 84.88671193804059, 81.24227060590471, 83.29125268118722, 79.22072696685791, 75.16576521737235, 77.26057066236223, 76.43565273284912, 81.66042014530727, 81.35359464372907, 77.93156514848981, 79.3752201625279, 83.07407283782959, 82.30438613891602, 79.38908876691545, 83.67173603602818, 84.6515918459211, 82.59935106549943, 78.04389667510986, 71.76762362888881, 73.43926988329206, 77.72018705095563, 70.69461332048688, 74.76624379839215, 70.1627356665475, 72.33305413382394, 90.4099600655692, 81.09250913347516, 49.66945471082415, 65.83952481406075, 86.14364801134381, 56.90514196668352, 54.11341830662319, 64.02614225660051, 60.47091579437256, 72.39150932856968, 73.51271929059709, 70.18175983428955, 71.49590042659214, 72.67036833081926, 69.4633230481829, 71.71013423374721, 74.95403970990861, 76.45020920889718, 70.26343590872628, 72.36751025063651, 64.60863058907645, 66.53794384002686, 72.01649420601981, 68.03075735909599, 71.21891048976353, 79.26559843335832, 77.53888075692313, 81.29920414515904, 69.36920969826835, 69.53661959511894, 75.80524267469133, 70.44846643720354, 70.38589096069336, 71.8473333631243, 78.23483317238944, 77.78898811340332, 75.04447051456997, 75.13148280552456, 81.09995760236467, 79.14393547603062, 79.2846851348877, 83.06139237540108, 64.35234628404889, 20.67682978085109, 0.506593756377697, 0.2783654358770166, 0.254529206348317, 0.23956123952354702, 0.24043828674725123, 0.13077884460134165, 0.580852845949786, 0.22682559862732887, 0.1353156790137291, 1.0987603323800224, 30.175626959119523, 99.2336789539882, 86.34871714455741, 61.41090284075056, 91.96608557019914, 69.18735449654716, 47.23846762520926, 47.908777713775635, 44.00337246486119, 69.90713923318046, 68.3518614087786, 92.03115545000348, 60.46852561405727, 4.341768188135965, 0.2853194698691368, 0.26004887159381596, 0.13309908152690955, 0.19575976846473558, 0.11955819598266057, 0.21101058939737932, 0.20543185089315685, 0.2125976692352976, 0.08875054160931281, 0.15544002343501362, 0.15162356251052447, 0.09752036245273692, 0.1880445403179952, 0.14044414167957647, 0.15823518059083394, 0.19472688888864859, 0.2352209495646613, 0.21386355773678847, 0.209218401994024, 0.17384661574448856, 0.21561007973338875, 0.14223643764853477, 0.10676824514354978, 0.17564336290316923, 0.16062073329729692], [0.1398019625672272, 0.06583485339901277, 0.12148906237312726, 0.11073590402624436, 0.10397498788578169, 0.1450255015598876, 0.08796040793614728, 0.11577678817723479, 0.13753853259342058, 0.07298753530319248, 0.11938496599239962, 0.13718924990722112, 0.05106373976117798, 0.14743548152702196, 0.10138698747115475, 0.048647873502756865, 0.06661627468253885, 0.03704206465876528, 0.042750722263008356, 0.04911433918667691, 0.023414611616837125, 0.07531277303184782, 5.404255015509469, 61.63236972263881, 88.19885567256382, 80.14422593797956, 69.39949689592633, 70.96041665758405, 51.23235470908028, 34.33069140570504, 37.421913691929404, 82.90370995657784, 45.15418175288609, 32.89589881896973, 72.93087019239152, 88.46294280460903, 54.53816863468715, 1.981974516596113, 0.06665980270398514, 0.04105349922818797, 0.09451347522969757, 0.014687806500920227, 0.13159406371414661, 0.07607043880437102, 0.030200450348534753, 1.6492133438587189, 0.38150685706308907, 1.3208047832761491, 1.711494390453611, 15.720973287309919, 48.26082903998238, 79.63526344299316, 71.62510912758964, 69.56844929286412, 61.8474303654262, 66.30322674342564, 65.3047845023019, 62.2534761428833, 55.44920253753662, 60.70077610015869, 59.520103454589844, 54.964287757873535, 57.17359604154314, 60.66492339542934, 61.15441008976528, 65.71504783630371, 69.66001960209438, 75.23787362234933, 77.18421690804618, 83.00011621202741, 81.78131185259137, 78.12094524928501, 74.15885312216622, 79.37216990334647, 77.69096292768205, 81.07758440290178, 75.3731689453125, 75.45052324022565, 74.85363129207066, 80.98863356454032, 77.58503764016288, 71.20307554517473, 66.97927951812744, 60.62276867457798, 71.85167598724365, 75.35588877541679, 76.32066699436733, 70.12083802904401, 60.65953854152134, 62.538380077907014, 53.28143753324236, 61.316587993076865, 69.19899272918701, 70.74905245644706, 70.53199073246547, 68.7594357899257, 71.61621543339321, 79.51139095851353, 80.19245338439941, 78.1400944846017, 80.48743915557861, 76.12799344744, 66.38064357212612, 49.97036729540144, 63.35306331089565, 71.74263790675572, 74.84050614493233, 77.53043869563511, 70.79637663705009, 66.63156386784145, 67.67152854374477, 61.543703760419575, 66.71608870370048, 63.02743598393032, 66.15350696018764, 67.2955823625837, 63.627273968287874, 61.966126441955566, 60.12458283560616, 65.02288913726807, 71.18812302180699, 72.03328800201416, 61.06718240465437, 65.22118377685547, 66.94073786054338, 48.46937574659075, 28.89051594052996, 15.530854940414429, 1.3429861473185676, 0.3154500616448266, 0.09122701122292451, 0.011664967767761221, 0.09237267688981124, 0.033459413331002, 0.08308913718376841, 0.20167883299291134, 0.16280522250703403, 0.10350785723754338, 20.320031097957067, 75.06746905190604, 76.94541427067348, 50.65768657411848, 58.86595140184675, 65.17194884163993, 29.980650084359304, 38.497467041015625, 43.23407139096941, 46.19808258329119, 61.93529033660889, 63.161557061331614, 48.41342190333775, 6.867872638361795, 0.13811391671853407, 0.06874591112136841, 0.023135431776089326, 0.08552572929433414, 0.054106708083833964, 0.114194783781256, 0.03595139764781509, 0.027742801600002816, 0.09771227929741144, 0.043562891360904486, 0.07243596775723354, 0.034462491649069955, 0.08203498553484678, 0.02482903652292277, 0.007861343029487346, 0.03225225882072534, 0.03854535220723067, 0.12537814011531218, 0.09174113042120423, 0.06790281778999738, 0.1430213533874069, 0.03143886496712055, 0.09944216361535446, 0.07555313049150364, 0.13482299473668846, 0.0728455993479916, 0.06804722361266613, 0.06449554062315396, 0.028132107674277256, 0.06921543021287237, 0.03485277481377125, 0.03640189401007124, 0.15020152953054222, 0.06309467115040336, 0.11782696816538062, 0.09030058700591326, 0.018591299719576324, 0.07669518635209117, 0.11971909020628248, 0.033011030605328937, 0.04567543889528938, 0.05060902630378093, 0.04785887298307248, 0.02899423221658383, 0.031108241993933916, 0.02032603895557778, 12.533761637551443, 80.85656220572335, 97.14644009726388, 96.56427833012172, 94.84863608224052, 98.8808285849435, 82.2617380959647, 41.45889350346157, 8.479769161769322, 31.19083867754255, 44.22273404257638, 33.84130546024868, 75.89006628308977, 100.04557595934186, 55.06504358564104, 0.5293328219226429, 0.2906983798103673, 0.021032572025433183, 0.2986440791615418, 0.05910639837384224, 0.16580133459397725, 0.09618846606463194, 1.399059955562864, 0.8729991380657468, 1.1421175258500236, 3.4362468123435974, 5.11441091128758, 26.887376342500957, 73.13281958443778, 92.39775630405971, 79.19825649261475, 75.00553975786481, 67.97923646654401, 74.11664976392473, 72.21692194257463, 69.22688974652971, 64.77542904445103, 68.59513868604387, 66.28264617919922, 66.62177385602678, 68.2957547051566, 70.79272883278983, 71.62821497235979, 72.14544582366943, 76.50731645311627, 83.12790748051235, 81.73830945151192, 86.07088647569928, 84.93225737980434, 82.83883462633405, 81.74648053305489, 84.09818172454834, 82.33381870814732, 85.07175636291504, 79.0636351449149, 77.99989373343331, 77.07009274618966, 86.16750117710659, 88.18468134743827, 82.78886318206787, 75.19409302302769, 68.6084097453526, 75.54839556557792, 79.26918370383126, 80.34898240225655, 71.79682690756661, 60.045866693769185, 65.01122311183384, 59.3392071042742, 65.28855351039341, 71.00858851841518, 69.8343915939331, 70.22861153738839, 73.69021102360317, 76.36118194035122, 80.65120819636753, 82.89915888650077, 81.87173570905412, 83.93094553266252, 80.91461440495083, 70.31271948133195, 59.32456724984305, 70.45781176430839, 75.69669791630336, 78.22807257516044, 78.27659879411969, 75.23610877990723, 72.89266204833984, 70.74382741110665, 68.75408567701066, 73.59923131125313, 65.45267690931047, 67.3907309940883, 67.71650423322404, 65.18001570020402, 63.58231912340437, 61.625365938459126, 68.0602524621146, 73.02369117736816, 77.02072579520089, 72.89287744249616, 67.83785452161516, 72.8850120816912, 75.81799261910575, 54.682583468300955, 28.686636686325073, 4.06336863551821, 0.2791989211525236, 0.07958710260157074, 0.06589826928185565, 0.08665497441376958, 0.058531075316880427, 0.06516646926424333, 0.264507172363145, 0.18190307915210724, 0.15609391406178474, 17.49428732054574, 77.99664197649274, 82.52784715379987, 56.88143818719046, 43.00081689017159, 22.846345731190272, 24.949796472276958, 53.61671590805054, 56.859238692692344, 64.21640477861676, 73.12658010210309, 70.84807123456682, 65.93055316380092, 13.323913386889867, 0.1814288781689746, 0.10775386475558792, 0.055330449382641485, 0.013203976792283356, 0.054619714484683106, 0.05129362742549606, 0.019325479698766555, 0.04169956973886915, 0.05955810592110668, 0.06415754197431461, 0.04310075473040342, 0.06291471687810761, 0.0707032810896635, 0.046699348238429854, 0.06939481451575245, 0.07565156556665897, 0.04850369838199445, 0.05036461799006377, 0.008861423919110425, 0.07891139707395009, 0.07037892778004919, 0.009187338707436408, 0.08927091690046446, 0.026495535492098758, 0.12832929247191974, 0.10277841173644577, 0.18081492611340114, 0.19903281783418997, 0.25692402784313473, 0.18596924096345901, 0.08793847089899437, 0.259163356253079, 0.23856661575181143, 0.10457931152944054, 0.29265703899519785, 0.17983014109943593, 0.08053464961371251, 0.25130241949643406, 0.23018583974667958, 0.22526730224490166, 0.18060372530349664, 0.09762229198323828, 0.10436924387301717, 0.1965937829975571, 0.15058673386062893, 0.1585816541420562, 16.458967515400477, 98.70414284297398, 112.87987845284599, 99.40252017974854, 92.7221121106829, 88.49259771619523, 67.48970808301652, 45.03452335085188, 51.01568555831909, 111.64272390093122, 66.05479390280587, 46.10860368183681, 92.3853885105678, 105.99550601414272, 72.18780899047852, 3.503158833299364, 0.8556562172515052, 0.13903014255421503, 0.3912200315722397, 0.2084073219448328, 0.4037450280572687, 0.11670852532344204, 1.5689538334097182, 7.990687200001307, 7.090808629989624, 6.562347752707345, 4.428498642785208, 29.540954181126185, 85.0228966304234, 106.05687945229667, 89.94246441977364, 82.46593175615583, 73.49016543797084, 83.76911503928048, 80.39465985979352, 78.94318117414201, 73.90928077697754, 75.28143187931606, 75.8141085760934, 74.12850339072091, 76.43492317199707, 78.37421403612409, 79.36669472285679, 77.17207145690918, 79.98718275342668, 87.68190274919782, 87.38046210152763, 90.009368624006, 88.09661987849644, 84.11451693943569, 84.67415264674595, 88.86486135210309, 89.6568100793021, 86.81167561667306, 81.26501205989292, 78.04785020010812, 78.98343208857945, 83.84305082048688, 91.71777084895542, 91.21923065185547, 74.18820926121303, 74.42377403804234, 84.95302554539272, 87.69456931522915, 87.40571880340576, 80.24576691218785, 69.23318481445312, 75.40403284345354, 63.87091950007847, 68.39883123125348, 72.21491391318185, 72.59086009434291, 73.10808399745396, 75.36654731205532, 78.06113515581403, 85.12142208644322, 86.0233816419329, 84.11703913552421, 85.94629832676479, 83.84507274627686, 78.76347991398403, 58.66266795567104, 66.22250257219586, 76.1911039352417, 80.1339773450579, 81.2542006628854, 75.06825419834682, 74.04023347582135, 72.30101599012102, 70.1247707094465, 76.04907580784389, 68.98338317871094, 69.10709585462297, 70.52793993268693, 66.34454768044608, 66.29444422040666, 67.37508365086147, 73.76393141065324, 75.1206088747297, 76.34287343706403, 76.82337611062187, 79.92934594835553, 75.2184534072876, 79.62630721500942, 74.48309080941337, 39.00225019454956, 2.1310023026806966, 0.840754719717162, 0.2751077892524855, 0.1670195356543575, 0.17771267757884093, 0.09516324714890548, 0.17422922807080404, 0.493995369545051, 0.34603578756962505, 0.5314141873802457, 27.545997823987687, 89.64369882856096, 89.76240185328892, 67.96998841421944, 84.17628642490932, 81.92459065573556, 39.15235212871006, 46.6094194139753, 50.850711005074636, 63.1905449458531, 78.88216209411621, 80.9060194832938, 81.39098984854562, 19.227456399372645, 0.2306475963975702, 0.32544843799301554, 0.14665706615362847, 0.15219600179365703, 0.1027773939339178, 0.1878389577780451, 0.1321473547390529, 0.18394278255956514, 0.20935362045254025, 0.12240341545215674, 0.14999107510915824, 0.17818611860275269, 0.20228059855954988, 0.10950951983353921, 0.1732477271663291, 0.12143161759844848, 0.18675421098513262, 0.17789060303143092, 0.17052631319633552, 0.1085791058306183, 0.1385763111923422, 0.1127754852973989, 0.22479242272675037, 0.22512744260685785], [0.13431767613760062, 0.12044278851577214, 0.04094605320798499, 0.03961111019764628, 0.15862968085067614, 0.07696909736841917, 0.08958930588726487, 0.09217128769627639, 0.10202179769320147, 0.1349419690668583, 0.14143457210489682, 0.13832990798567021, 0.07647162941949708, 0.19602082802781037, 0.1914528352873666, 0.06477065264646496, 0.01944553798862866, 0.02013753174937197, 0.06342946711395468, 0.09006808698177338, 1.9656644889286585, 28.575026035308838, 72.21698447636196, 84.07942853655133, 76.86858109065464, 58.54211671011788, 49.185467515672954, 42.431599617004395, 31.944266591753276, 43.08602959769112, 122.25173377990723, 113.42123344966343, 84.04004614693778, 103.15304660797119, 95.09550557817731, 62.653692381722585, 2.2496377996035983, 0.17420846489923342, 0.10402540303766727, 0.045563178669129095, 0.0921822731782283, 0.12324770300516061, 0.10321794636547565, 1.2419032113892692, 2.6066950857639313, 1.5171283057757785, 1.5633653104305267, 7.070352264813014, 29.72180884225028, 55.362718309674946, 46.144098554338726, 55.93100799833025, 66.48556137084961, 61.64391762869698, 61.51175594329834, 58.61801883152553, 58.70533684321812, 54.84982660838536, 60.90091896057129, 58.913914816720144, 56.642889159066335, 65.72862461635044, 65.54537977491105, 69.05219118935722, 69.96042496817452, 75.73406532832554, 77.51647281646729, 82.71701186043876, 83.00161702292306, 84.34522492544991, 79.06923539297921, 78.13712760380336, 77.15306118556431, 77.65220587594169, 76.66614532470703, 78.00217274257115, 76.45155715942383, 65.8016779763358, 68.21265425000871, 76.3929352079119, 85.34775965554374, 83.25885323115757, 68.96121147700718, 70.97227723257882, 56.26022754396711, 70.55331475394112, 79.2423983982631, 74.22263758523124, 70.2154655456543, 58.509988239833284, 67.43115561349052, 74.16899054391044, 73.2899808883667, 67.41733564649309, 72.41256931849888, 81.48397064208984, 82.43130888257707, 77.86559895106724, 77.33929375239781, 80.68225274767194, 82.01714066096714, 82.05659253256661, 83.25519153050014, 82.73702267238072, 80.60962322780064, 79.51458712986538, 77.87848785945347, 72.25852080753872, 72.60105310167584, 72.22760132380894, 68.80407101767403, 71.2323066166469, 70.93708460671562, 68.46406786782401, 66.89622770036969, 65.79954487936837, 63.86088630131313, 60.90656784602574, 61.41994939531599, 66.33978816441127, 77.9452600479126, 82.53901290893555, 85.74430029732841, 63.741196632385254, 52.807421003069194, 61.30112130301339, 50.27503538131714, 29.497680800301687, 20.43202042579651, 3.1823498649256567, 0.21537073329091072, 0.06780163464801651, 0.012909417107169117, 0.03967993061191269, 0.1243405786475965, 0.15595645643770695, 0.08727052102663688, 0.11524554954043456, 0.24029932277543203, 13.511529513767787, 67.89635835375104, 74.79697568075997, 58.550440652029856, 68.16136959620884, 54.97310849598476, 27.206666912351334, 32.194832529340474, 33.15930502755301, 48.30791003363473, 66.86172294616699, 61.070017269679475, 59.09054497310093, 21.998821837561472, 0.25031186693481033, 0.04686432724286403, 0.03193421588678445, 0.023529314569064548, 0.02778738983241575, 0.036074707816754065, 0.051446772779205015, 0.09786793523068939, 0.14882851392030716, 0.0475346519877868, 0.03945211587207658, 0.04547752719372511, 0.027205223749790872, 0.03466063065986548, 0.020760739022599797, 0.022885978554508517, 0.017293691402301192, 0.10758769831487111, 0.10288429712610585, 0.09136816686285393, 0.10426920745521784, 0.04110191948711872, 0.055302853363433054, 0.0902542294934392, 0.11216812181685652, 0.04355128501941051, 0.06821316613682679, 0.19309539214840957, 0.04334033866013799, 0.05477994713666184, 0.04339550355715411, 0.04578187729098967, 0.08856145425566606, 0.035716102059398375, 0.025157936017162034, 0.10305284522473812, 0.034227918700448105, 0.10197280746485506, 0.1307805273681879, 0.05465745120974524, 0.07325734118265764, 0.028409960979063596, 0.06977420380072934, 4.1881856407438, 46.87760598318917, 90.78100081852504, 97.06276988983154, 94.59958485194615, 82.15194266183036, 74.77655492510114, 55.93288401194981, 37.08884137017386, 25.26010823249817, 73.68016392844063, 110.61389023917062, 79.43453693389893, 98.57690743037632, 100.82924938201904, 64.07684326171875, 0.9109601868050439, 0.0888534075181399, 0.018427204507003938, 0.07486816296087843, 0.0672976595482656, 0.15451190966580594, 0.5937122787748064, 2.012861430644989, 1.791119552084378, 0.4745118064539773, 2.914436012506485, 15.327333518436976, 52.449776376996724, 76.39328261784145, 59.527941022600444, 64.26611219133649, 76.22587272099086, 69.91524083273751, 70.08123329707554, 64.73119681222099, 66.37539768218994, 61.607217243739534, 67.94970662253243, 66.68796934400285, 68.55655533926827, 73.18296473366874, 72.22479425157819, 75.771377154759, 76.31466375078473, 83.62503024509975, 82.46895422254289, 85.86930533817836, 87.9982681274414, 85.9454367501395, 80.43204116821289, 78.38647065843854, 80.96355056762695, 81.27782453809465, 81.2314453125, 82.5412015914917, 79.55277442932129, 69.9225433894566, 74.57766274043492, 79.20777552468437, 88.49441814422607, 91.01739937918526, 73.28153882707868, 77.89888082231793, 66.21772221156529, 75.24056257520402, 81.52234554290771, 78.30614948272705, 73.15148244585309, 61.437465803963796, 70.98347078050885, 78.35896968841553, 74.64540072849819, 68.4047372000558, 73.61468410491943, 83.59798090798515, 83.20581763131278, 78.77454839433942, 79.84646088736397, 80.23237078530448, 79.50547109331403, 84.7254581451416, 91.74090835026333, 86.6324815750122, 83.84702519008091, 84.69959000178746, 80.47402218409947, 75.5587066922869, 74.15917273930141, 73.90661266871861, 71.53105136326381, 73.51993152073452, 74.18923759460449, 73.85022108895438, 70.58808353969029, 68.89781611306327, 65.83816296713692, 64.07384858812604, 64.62730734688895, 66.53056485312325, 76.13754722050258, 77.15281799861363, 88.98052106584821, 85.00788852146694, 64.76397841317313, 59.32811083112444, 70.65922614506313, 55.319653374808176, 33.52299806049892, 7.961917315210615, 0.5186800935438701, 0.11679175442882947, 0.10909838868038994, 0.02763662444028471, 0.080453673244587, 0.0633884903841785, 0.29712245081152233, 0.10250739127929721, 0.5218023860028812, 11.437203884124756, 69.3205097743443, 80.76497800009591, 65.22191333770752, 59.00823661259243, 15.371013368879046, 24.98252248764038, 51.79216759545462, 48.66230985096523, 68.2723809650966, 82.79158687591553, 67.17435019356864, 73.06148937770298, 33.703526156289236, 0.3003160980130945, 0.01985570731838899, 0.049345963900642734, 0.05548695009201765, 0.032006110064685345, 0.01579355395265988, 0.04934840662670987, 0.03950400683762772, 0.12385983658688408, 0.01102913635051144, 0.039625766554049084, 0.037329878857625384, 0.029461871766086136, 0.031401945876755884, 0.026285386411473155, 0.07663877973599093, 0.024826459786189452, 0.03600106980385525, 0.087892174454672, 0.1231645688946758, 0.04919493557619197, 0.05811935383826494, 0.06494048317628247, 0.18549413074340138, 0.17676035368016788, 0.07194941065141133, 0.24877533795578138, 0.293900305139167, 0.16806715301104955, 0.15423806650297983, 0.15944354289344378, 0.20236690821392195, 0.22834364431244986, 0.1817706562578678, 0.1614662693547351, 0.22392347721116884, 0.3238235094717571, 0.2426398071859564, 0.33986334449478556, 0.18624180848045008, 0.24407751432486943, 0.20430569989340647, 0.16271809861063957, 5.008925097329276, 52.6646911076137, 106.35194165366036, 107.85480921609062, 98.58626665387834, 79.78843648093087, 60.999812671116416, 56.893757343292236, 44.758082321711946, 60.46945667266846, 149.49342482430595, 135.96754728044783, 99.25120231083461, 123.68653678894043, 109.33353178841728, 80.72330965314592, 3.7692683253969466, 0.5263273460524422, 0.3127759279949324, 0.36557542479463984, 0.2825397833117417, 0.3271650773073946, 0.24482767550008638, 2.84600059900965, 7.453424692153931, 6.881271805082049, 4.6483326980045865, 15.740039144243513, 60.60172258104597, 88.96729864392961, 67.60508986881801, 68.70239802769252, 81.62018312726701, 79.36759104047502, 79.88646166665214, 74.1551010949271, 76.72100135258266, 74.63850116729736, 76.60821124485561, 74.767911366054, 75.89674350193569, 79.42485809326172, 77.8131331035069, 80.49694429125104, 80.20463357652936, 87.55809279850551, 85.82397529057094, 87.46747439248222, 91.86579527173723, 90.78195966993059, 84.84423760005406, 83.99144349779401, 84.15290573665074, 84.92002855028424, 84.49045617239815, 84.74676827022007, 80.82527446746826, 70.99400424957275, 74.83748367854527, 82.00858742850167, 89.45948123931885, 88.39398193359375, 74.82861777714321, 82.13951928274972, 73.35757991245815, 85.42997768947056, 89.13637610844204, 89.73867375510079, 84.66340378352574, 64.61031205313546, 72.8568023954119, 80.86678995404924, 77.45141683306012, 70.27987534659249, 73.97815132141113, 85.81155885968889, 86.27895028250558, 81.55142375401088, 81.48943887438092, 85.551696232387, 85.64366258893693, 93.98532935551235, 94.52198042188371, 83.83692945752824, 84.00704220363072, 87.15682043348039, 82.69090747833252, 76.33939238956997, 76.76665101732526, 77.73807866232735, 72.97983414786202, 76.99308586120605, 76.16042069026402, 75.77003615243095, 70.0510642187936, 68.40593923841203, 69.00655542101178, 66.16242844717843, 67.18727384294782, 69.20147323608398, 77.38640948704311, 83.63097790309361, 82.6496490750994, 75.47086061750139, 73.00459057944161, 68.92467784881592, 73.36462538582938, 69.76850182669503, 49.016160760607036, 5.965715493474688, 0.5599040271980422, 0.1876796648970672, 0.23997731719698223, 0.2000877633690834, 0.2609351740351745, 0.37975865229964256, 0.4746880627104214, 0.11675903547023024, 0.6403396310550826, 18.607949801853724, 80.79102679661342, 89.79227910723004, 74.57188183920724, 94.42721394130162, 74.51675483158657, 35.68472508021763, 41.178533690316335, 43.172812598092214, 64.76628521510533, 82.20035770961216, 74.95419257027763, 88.69492925916398, 42.235337325504844, 0.5435184921537126, 0.11491065179663044, 0.26641969116670744, 0.11090464890003204, 0.13071403093636036, 0.1699025495243924, 0.19448420405387878, 0.23450875920908792, 0.29827848449349403, 0.17828499472567014, 0.1817509244595255, 0.12108599900134973, 0.20946864570890153, 0.06916183951709952, 0.07696257664688996, 0.12048299850097724, 0.15716367880148546, 0.2251930840845619, 0.150002745911479, 0.1847554910928011, 0.11718298414988176, 0.08815841802528926, 0.17874885483511857], [0.08832113072276115, 0.050315956851201396, 0.08244453570140259, 0.05043236292632563, 0.020961402183664695, 0.020458107315269963, 0.04792665184608527, 0.10053870334689106, 0.06080937199294567, 0.14534315094351768, 0.0644058043669377, 0.037727792148611376, 0.08993336385382072, 0.1521320566534996, 0.3014857295368399, 0.25641854639564243, 0.14788319250302656, 0.06282907218805381, 0.1731801586491721, 2.2321309447288513, 56.43090656825474, 89.456590788705, 83.74310098375592, 58.41426985604422, 54.391849994659424, 64.15546907697404, 50.908745833805625, 49.714162894657676, 50.22428921290806, 56.51181486674717, 78.03097997392926, 87.2917127609253, 92.1163056237357, 85.19979081835065, 63.42606108529227, 4.680665705885206, 0.05033198384834187, 0.09755915429975305, 0.22527344977217062, 0.07720482043389763, 0.11215269193053246, 0.06312948678221021, 0.12839033348219736, 1.7374145367315836, 0.871290804019996, 1.0384520313569476, 20.18993650163923, 40.32110513959612, 61.31030682155064, 74.63586780003139, 78.49845477512905, 73.64649990626744, 69.64606067112514, 53.11695977619716, 53.05432871409825, 54.20211900983538, 53.85821097237723, 52.49904257910592, 56.572347572871614, 62.31015954698835, 73.1986676624843, 69.8711336680821, 73.92634555271694, 71.39880629948208, 75.61834308079311, 79.90960611615861, 78.10740321023124, 77.76546846117292, 78.85351467132568, 74.94427054268974, 74.37127344948905, 75.80041367667062, 79.09105968475342, 78.07496207101005, 78.89259828839982, 76.87478583199638, 76.74588285173688, 68.50472872597831, 72.14451476505825, 72.1949656350272, 75.0446720123291, 82.3455125263759, 73.82379708971295, 68.10957772391183, 57.40277542386736, 55.63534825188773, 64.52307741982597, 60.88619572775704, 59.95639474051339, 67.50988565172467, 74.01561600821358, 72.5631228855678, 66.3803378513881, 69.23088496071952, 77.07802064078194, 79.76654270717076, 74.0617242540632, 79.12621756962368, 76.99325956617082, 75.43513992854527, 72.95257636478969, 79.41779177529472, 82.47493662152971, 75.24519007546562, 72.72647503444126, 79.30850355965751, 77.58307824816022, 77.6995370047433, 73.47298254285539, 72.97797897883824, 74.49663979666573, 71.084045955113, 68.13751643044608, 62.98967252458845, 59.57607814243862, 69.96206474304199, 71.30319908687046, 69.72204617091587, 64.91862446921212, 59.76342242104666, 65.92288930075509, 70.75399957384381, 98.66588606153215, 107.42991992405483, 82.1951048714774, 47.22039883477347, 53.096473012651714, 52.67582212175642, 31.53918661390032, 27.042639051164898, 7.289644360542297, 0.0849387218643512, 0.09304226881691388, 0.015764348109119704, 0.12003725527652673, 0.05159995884501508, 0.02494066740785326, 0.010039617706622397, 0.02420308966455715, 0.34538157124604496, 14.076497094971792, 63.80908053261893, 76.55034664699009, 60.52965586526053, 64.74075753348214, 58.651557786124094, 27.993828330721172, 29.72051647731236, 34.72966044289725, 35.059157916477744, 67.78973824637276, 55.28479426247733, 63.373553548540386, 26.186525447028025, 0.8083558125155312, 0.03487894590944052, 0.0858844436172928, 0.025293339376470873, 0.08302949395562921, 0.02917045454627701, 0.06712791044265032, 0.11615500359662942, 0.05914244893938303, 0.09583009779453278, 0.0367908404607858, 0.1230474401797567, 0.031460913962551525, 0.08566097489425115, 0.07100182292716843, 0.020879889771874462, 0.07495614859674658, 0.09842476820839302, 0.08252183441072702, 0.22749718544738634, 0.07771176073168005, 0.03215731141556587, 0.117290803364345, 0.023286558488117795, 0.02690116542258433, 0.02324356142032359, 0.04149564282436456, 0.048275557945349386, 0.09886001449610506, 0.027855217889217392, 0.03658960393763014, 0.06269814207085542, 0.0561619567285691, 0.0675372231219496, 0.019427095406821797, 0.10623685044369527, 0.013428215652571192, 0.1158412897161075, 0.18777067001376832, 0.06104996015450784, 0.2446859431053911, 4.249451381819589, 76.00890132359096, 101.35877159663609, 93.6635513305664, 77.00915009634835, 79.77171911512102, 84.9031513759068, 63.551677567618235, 27.79388870511736, 22.895380905696324, 42.8925187928336, 90.91652543204171, 92.35155078342983, 93.90826688494, 92.5525482722691, 65.37875502450126, 2.467382184096745, 0.05677960679999419, 0.14668553748301097, 0.1582938331578459, 0.18618817707257612, 0.36631369803633007, 0.17660239072782652, 1.9741495421954562, 1.875322925192969, 1.0343736559152603, 2.469217377049582, 34.947184222085134, 59.20302241189139, 73.69861834389823, 82.79235117776054, 88.47629724230084, 80.49865354810441, 72.79582500457764, 60.74506391797747, 61.50439780099051, 62.564269065856934, 59.82356602805001, 59.32731873648507, 63.7151825768607, 68.49707181113106, 74.34774684906006, 74.62236745016915, 76.82675988333565, 79.37158625466483, 82.58268928527832, 83.45742579868862, 83.78579766409737, 81.81050123487199, 81.48053128378731, 79.58335345132011, 80.47657217298234, 81.80529008592877, 83.38430295671735, 81.13945116315568, 83.87694413321358, 82.739718573434, 83.85304233006069, 72.37385395595005, 73.99079704284668, 75.77538626534599, 80.73148073468889, 85.470992905753, 77.33534717559814, 72.53301634107316, 64.53960023607526, 64.96927683694022, 70.46301596505302, 65.41331536429269, 62.470107078552246, 70.02538367680141, 77.2984175000872, 71.59307793208531, 67.4520766394479, 71.3664276940482, 77.69912706102643, 80.44784832000732, 76.23046548025948, 79.07572501046317, 77.38766016278947, 78.40630081721714, 75.02147197723389, 81.11286040714809, 81.27173096793038, 77.57013375418526, 74.58168574741909, 79.33514295305524, 79.67304079873222, 79.91533837999616, 77.95912865230015, 76.62652669634137, 77.96976634434291, 74.89134611402238, 70.4882379259382, 66.6847870690482, 63.23683384486607, 71.13512216295514, 75.36544949667794, 73.11011981964111, 67.41340296609062, 64.03366020747593, 75.5188935143607, 74.2517157963344, 85.30654294150216, 93.84184905460903, 96.86617755889893, 76.05382142748151, 54.05429261071341, 65.69312626974923, 57.945683343069895, 39.23299292155674, 15.20101353100368, 0.5627335182258061, 0.15998356177338532, 0.08712349605879613, 0.19774142998669827, 0.14065550533788546, 0.014352479583716818, 0.07782268085117851, 0.15239007637969085, 0.7550104207226208, 13.620496375220162, 70.76567254747663, 81.78182601928711, 66.96073477608817, 55.938043049403596, 18.65348482131958, 26.574919325964792, 43.66428647722517, 49.82233592442104, 48.79564230782645, 83.19089984893799, 63.158770833696636, 72.07389327457973, 41.29959910256522, 1.0536300454820906, 0.051291815736996274, 0.14835748848106178, 0.07194296456873417, 0.059683926669614654, 0.023374338867142797, 0.03441385425893324, 0.03127517857189689, 0.09610423951276711, 0.04085896323834147, 0.025221061826284443, 0.043544577700751166, 0.06683647286679063, 0.15418690496257373, 0.015948427874328833, 0.010206083550916185, 0.07724229592297759, 0.04637324091579233, 0.03852940324161734, 0.0953033035621047, 0.062337717839649746, 0.048425985766308646, 0.24040197155305318, 0.10978017388177769, 0.20392933008926256, 0.1430104561150074, 0.10914209990629128, 0.2838006099419934, 0.13336943701973983, 0.14919729770294257, 0.15660364313849381, 0.18712954941604817, 0.13713173727904046, 0.10676758696458169, 0.16111425895776066, 0.22677396211240972, 0.35209106121744427, 0.5148569558347974, 0.4152720352368695, 0.2048560053642307, 0.4213295616209507, 6.208894627434867, 87.75360815865653, 119.14398520333427, 102.4491662979126, 78.18926688602993, 74.41096155984062, 78.95795999254499, 67.76678834642682, 66.14316804068429, 70.34488269260952, 75.37420422690255, 97.29454095023019, 97.76279394967216, 107.79030908857072, 100.76779951368059, 82.40803241729736, 6.537210038730076, 0.16927577315696649, 0.4560392605406897, 0.3961019553244114, 0.18443466616528376, 0.6084979910935674, 0.21491150079028948, 0.6790501081517765, 6.511793962546757, 4.4349769694464545, 4.228927271706717, 34.16488306862967, 73.08658627101353, 84.26470225197929, 86.76512963431222, 91.21026052747453, 92.39674186706543, 85.08205359322685, 72.41044316973004, 73.14449950626918, 74.69150202614921, 70.35438782828194, 67.19163731166294, 72.18238244737897, 76.02310344151088, 84.20762280055455, 83.6739525113787, 83.65363597869873, 82.7475700378418, 85.19476727076939, 87.39056478227887, 85.91965893336705, 85.10881805419922, 83.87989711761475, 82.54616955348423, 83.13059643336705, 83.13672474452427, 85.58894552503313, 83.41545173100063, 86.56982966831752, 88.76068006243024, 85.96314770834786, 72.16795798710415, 74.76429830278668, 76.89371272495815, 83.28572191510881, 84.59373419625419, 76.32548904418945, 75.48078264508928, 67.60970347268241, 72.20611749376569, 78.68176909855434, 74.02466256277901, 69.1153016771589, 72.94747638702393, 80.26003156389508, 74.40752914973667, 69.05694375719342, 70.3655674798148, 81.87324346814836, 85.06265422276088, 79.84031867980957, 82.50457763671875, 81.29827308654785, 79.62865570613316, 77.87296404157365, 85.3874477658953, 84.70802511487688, 82.20542294638497, 79.48775318690709, 83.0240319115775, 82.2312285559518, 81.71877111707414, 79.5541432244437, 76.14357825687954, 82.07356698172433, 75.38241699763707, 72.4061005456107, 69.67239434378487, 65.26817444392613, 71.67913137163434, 74.86463029044015, 72.00984477996826, 71.56461811065674, 69.61546080453056, 73.07865837642125, 72.56692355019706, 87.01545933314732, 89.97165380205426, 77.26353754316057, 68.06180885859898, 65.64848409380231, 69.71978800637382, 69.10810334341866, 59.03576537540981, 13.162858486175537, 0.43661804124712944, 0.24306736567190715, 0.1710427054869277, 0.5696409504328455, 0.1352819422526019, 0.09230550870831523, 0.2116437711353813, 0.16212695890239306, 0.670706895845277, 20.580029215131486, 81.34436048780168, 92.5650133405413, 73.03783770969936, 91.43068517957414, 77.265517779759, 37.25004652568272, 39.03292301722935, 43.22015067509243, 48.27914449146816, 89.27656296321324, 68.52237715039934, 88.10740348270961, 52.03599030630929, 1.576315666948046, 0.13691498605268343, 0.20805019539381775, 0.1086178705362337, 0.19586962328425475, 0.11570902967027255, 0.19967587904206344, 0.1927654477102416, 0.19367414180721554, 0.21684048085340432, 0.1532027849129268, 0.18417831563523837, 0.15262426595602716, 0.23882299342325755, 0.08751300230090107, 0.09318953127201114, 0.2638331970998219, 0.14761838742664882, 0.17259224876761436, 0.24769720009395055, 0.18624552685235227, 0.12744231149554253], [0.09144077010984931, 0.09162890751446996, 0.050945973223341365, 0.03834052284115127, 0.11979150346347264, 0.0676213139668107, 0.049502963333257606, 0.013274145794899335, 0.03727495823321598, 0.13173447975090571, 0.29859850874968935, 0.11555555861975465, 0.021595574582793882, 0.04751018740768943, 0.1559571756848267, 0.21833833333637032, 0.14426430740526744, 0.12179064404751573, 0.5104196082268442, 39.37465279442923, 85.9601252419608, 66.55684988839286, 62.48815849849156, 59.76771640777588, 42.43411833899361, 37.454750878470286, 43.049099922180176, 90.75531332833427, 106.87633609771729, 37.031470094408306, 49.7343613079616, 73.00556332724435, 79.17680740356445, 50.057264941079275, 2.592042637722833, 0.25794630870223045, 0.07163235837859766, 0.16621315106749535, 0.09328764743570771, 0.11844932048448495, 0.01224503293633461, 0.253367011568376, 2.8380881207329884, 2.920071218694959, 0.6643800182001931, 9.169508150645665, 44.90996299471174, 65.17872333526611, 79.29557991027832, 79.52927562168666, 81.57315771920341, 57.50574772698538, 59.64517797742571, 53.885486125946045, 52.8869674546378, 49.8436529976981, 51.067876952035085, 52.95576851708548, 66.74080344608852, 68.52398913247245, 69.65645517621721, 72.59871850694928, 76.40236391339982, 80.49750014713833, 80.3665474482945, 76.86238329751151, 80.6674530846732, 79.90854304177421, 78.61221763065883, 79.7476088660104, 81.8755989074707, 79.65763664245605, 83.02329540252686, 75.87391172136579, 76.83416666303361, 76.85075896126884, 79.12709304264614, 75.25174222673688, 66.43056637900216, 67.16062750135148, 74.9273933683123, 72.79766627720424, 75.24100725991386, 68.72275624956403, 68.49091570717948, 59.69109167371477, 64.38573237827846, 63.73941094534737, 58.335157666887554, 68.937059538705, 74.34213965279716, 70.9303309576852, 67.37131077902657, 73.12474577767509, 72.30701923370361, 73.58616869790214, 76.11677210671562, 77.63511330740792, 76.38161659240723, 79.53429222106934, 77.39060619899205, 80.34746074676514, 76.35395581381661, 77.21318394797188, 75.06193828582764, 72.21474020821708, 73.63221440996442, 73.75335625239781, 75.7839742388044, 78.47621359143938, 79.01448358808244, 79.856431552342, 77.47873020172119, 76.13012654440743, 64.75952461787632, 64.4494195665632, 71.49807521275112, 75.41694954463414, 64.477705683027, 60.69997010912214, 84.52742753710065, 84.10095405578613, 73.64746570587158, 77.0310230255127, 111.10990129198346, 123.6700417654855, 60.2122482572283, 48.87006793703352, 58.048096316201345, 30.358903067452566, 29.27012382234846, 8.417832051004682, 0.10189654691410915, 0.1933774591556617, 0.01966460980474949, 0.04491516415561948, 0.2126865844641413, 0.17901794825281414, 0.14738407571400913, 0.07778445218822785, 0.2410382745521409, 15.322683436529976, 60.43682793208531, 76.50885200500488, 61.60000501360212, 73.45779378073556, 59.988418987819124, 26.35548652921404, 25.451972314289637, 39.53907149178641, 31.991069657461985, 49.54366452353341, 60.68818596431187, 67.37225573403495, 36.88631180354527, 1.4395841296230043, 0.10258522603128638, 0.016517725540325046, 0.03241667803376913, 0.04392590081053121, 0.04285543378708618, 0.14137282541819982, 0.021445155243522356, 0.11599823486592088, 0.05743174680641719, 0.06877432138259922, 0.11084626774702754, 0.09341909323952027, 0.025034213638199226, 0.030212338282061473, 0.03442532489342349, 0.026544920967093537, 0.07857207528182439, 0.11243116270218577, 0.061523672592427046, 0.13217639603785106, 0.07196416878806693, 0.020501648907416632, 0.008497037043395852, 0.03325331849711282, 0.13595503542040074, 0.06426131033471652, 0.09974599802600485, 0.0905793427622744, 0.024782410989116346, 0.05701558770877974, 0.07236164781664099, 0.15234964926327976, 0.060811550090355534, 0.04237948218360543, 0.06620873976498842, 0.13509321452251502, 0.014577790529334118, 0.07040747374828372, 0.22390293117080415, 58.39995656694685, 97.51898860931396, 80.69498184749058, 91.12415150233677, 88.1893505368914, 59.644066265651155, 66.82108988080705, 41.43943507330758, 75.60723291124616, 92.33275590624127, 35.72469459261213, 58.846899441310335, 80.5197274344308, 92.57178783416748, 49.89260653087071, 1.485810929111072, 0.30525846566472736, 0.029254165411527668, 0.023745621354984384, 0.06029728161437171, 0.12799253554216453, 0.23164219302790506, 0.8622832245060376, 1.573477110692433, 2.1772149886403764, 0.5674701812011855, 16.4557591847011, 61.619585037231445, 74.04110200064522, 90.97530024392265, 85.0846174785069, 82.89971474238804, 66.70464502062116, 70.04169109889439, 64.35828699384416, 61.563186509268625, 58.4030693599156, 60.89300496237618, 59.98408331189837, 72.48175948006767, 72.57063388824463, 75.5076652254377, 78.77630628858293, 80.52909360613141, 83.35226481301444, 85.8839521408081, 82.58395385742188, 84.56072330474854, 83.60704135894775, 85.39188071659633, 83.51998737880162, 83.9537078312465, 83.57501016344342, 85.05236394064767, 79.84925406319755, 79.20025062561035, 79.39050619942802, 84.47624015808105, 79.95039204188755, 68.1645518711635, 69.63943903786796, 79.64034257616315, 77.30856187002999, 79.1665518624442, 74.27978651864188, 71.43966170719692, 69.58857127598354, 69.90568705967495, 72.22000694274902, 63.10160105569022, 65.22665200914655, 75.11111763545445, 73.67646748679024, 68.22309044429234, 73.81694616590227, 74.71209648677281, 73.791182245527, 78.1830551964896, 76.73506450653076, 79.09273420061383, 81.07645184653146, 78.05911323002407, 80.24947725023542, 78.12384264809745, 78.24050290243966, 77.15312371935163, 77.18712820325578, 74.21189567020961, 75.72842339106968, 78.38078008379254, 78.93769209725517, 79.57468209947858, 81.61705643790108, 79.0127534866333, 79.70867810930524, 68.07527446746826, 68.50169236319405, 72.82886368887765, 75.98824432918003, 72.94044481004987, 64.58140754699707, 82.38338020869664, 83.24973024640764, 78.59677178519112, 74.34630162375313, 84.14588110787528, 109.70262009756905, 96.19131292615617, 54.90120158876692, 68.61622646876744, 55.71373782839094, 40.77720921380179, 15.180386066436768, 0.3815984050078051, 0.08939013550324099, 0.06193743646144867, 0.19899598695337772, 0.28742531687021255, 0.041179153735616376, 0.16889990546873637, 0.03852657375058957, 0.3156464025378227, 13.957457082612173, 67.72728088923863, 81.00510774339948, 69.33702564239502, 62.308429445539204, 16.57550617626735, 17.5199122769492, 38.691540649959016, 57.433194637298584, 57.86111681801932, 65.17620808737618, 69.78048746926444, 74.98523712158203, 51.61799710137503, 2.168039241007396, 0.016403612913563848, 0.1270331684499979, 0.028309259596945982, 0.01297415019611695, 0.06317280445780073, 0.052359348096485646, 0.06997315705354724, 0.03278927518320935, 0.08313737423824412, 0.021173917655167834, 0.09218687364565474, 0.028972522488662174, 0.09380287264606782, 0.02347082145778196, 0.09734413333769355, 0.07009633151548249, 0.015270498448184558, 0.017299643850752285, 0.07001960956092391, 0.07745545091373579, 0.16476336600525038, 0.1140000442309039, 0.09116998713995729, 0.15650271783982003, 0.19030195847153664, 0.10250338113733701, 0.1498444572623287, 0.13654909282922745, 0.14972852276904242, 0.21626285756272928, 0.40306198756609646, 0.2727916235370295, 0.1508333541985069, 0.12540256737598351, 0.17502046775604996, 0.2607939573270934, 0.19172422215342522, 0.18768274544605187, 0.9913212060928345, 71.91548824310303, 114.12579468318394, 87.70669392177037, 85.72055830274309, 83.2607500893729, 54.94050407409668, 49.228438649858745, 57.3422566141401, 103.72969845363072, 115.42544828142438, 54.728504112788606, 70.18063422611782, 97.18072250911167, 96.47962842668805, 66.37665530613491, 3.9541103839874268, 0.47225060207503183, 0.1627251553748335, 0.2707258372434548, 0.17037798544125898, 0.26741236075758934, 0.2579277982669217, 0.9817115217447281, 5.410095410687583, 10.18786827155522, 7.094608860356467, 17.224122251783097, 79.65712247576032, 79.73491450718471, 94.12803145817348, 83.29996572222028, 90.39950997488839, 74.17750208718437, 82.0721217564174, 74.65182781219482, 72.36719758169991, 66.87438256399972, 72.1734540121896, 70.50357954842704, 81.52729266030448, 78.74906240190778, 80.24097960335868, 80.30646637507847, 85.57864829472133, 85.70620332445417, 90.83554417746407, 87.56485339573452, 87.96796703338623, 86.48864691598075, 88.895676612854, 86.81095995221818, 88.19096946716309, 88.4362895148141, 90.49513108389718, 84.87065465109688, 83.97214140210832, 83.09495217459542, 87.63559300558907, 83.40070765359062, 68.80234786442348, 71.1539031437465, 83.85571738651821, 79.11019502367292, 78.88779013497489, 72.75633144378662, 73.89675317491803, 70.36315645490373, 76.83605657305036, 78.53493976593018, 72.70196178981236, 68.55917481013707, 80.12980147770473, 75.5540930884225, 69.08764784676688, 76.83651515415737, 77.97542912619454, 76.67950671059745, 80.00533839634487, 81.4233615057809, 83.4847252709525, 83.13944843837193, 81.90068885258266, 83.77128982543945, 83.85539776938302, 82.04646900721959, 82.45744105747768, 79.17450060163225, 75.72736726488385, 77.7139892578125, 81.48287977491105, 81.77983883449009, 85.33977617536272, 85.32668576921735, 83.66332871573312, 81.83784239632743, 70.82365526471818, 70.60903235844204, 75.95231519426618, 72.3121817452567, 72.06651428767613, 68.7133344922747, 86.21435982840401, 88.4566616330828, 84.75414725712368, 79.02376638139997, 86.18555954524449, 92.37507738385881, 81.06615461621965, 64.52361243111747, 74.75692626408168, 65.22276101793561, 63.524037633623394, 13.122993196759905, 0.6888496737395013, 0.39118165363158497, 0.20718833378383092, 0.28683971400771824, 0.5873807328087943, 0.38919408885496004, 0.37927936230387005, 0.10331819312913076, 0.46106101678950445, 22.34106751850673, 78.0647760118757, 93.49328572409493, 75.45626940046037, 108.85238293239048, 78.90099171229771, 36.44662979670933, 35.34185579844883, 50.93370376314436, 43.768926348005024, 68.16915157863072, 77.0420150756836, 85.84689044952393, 66.13595581054688, 3.973785076822553, 0.17134310651038373, 0.18522800930908748, 0.1750801924083914, 0.1707286794802972, 0.15376841170447214, 0.21343943263803208, 0.16537283972970077, 0.22654950272824081, 0.16365670253123554, 0.13090866192110948, 0.17177306701030048, 0.11263429573071854, 0.12231213892144815, 0.10682366788387299, 0.12614686600863934, 0.2291349247097969, 0.17532038023429258, 0.22449284951601708, 0.1645765517439161, 0.19513816253415175], [0.14680261191512856, 0.10217619833669492, 0.008340077474713326, 0.10890273989311286, 0.020627089676314166, 0.07391355918454272, 0.04140984546393156, 0.06789570674300194, 0.09641928332192556, 0.09976644228611674, 0.009868107802633728, 0.061920886992343833, 0.08562029671988317, 0.01718869150084044, 0.1943033201886075, 0.12172577609973294, 0.17014610288398607, 0.21435336502535002, 11.617199574198041, 79.76714720044816, 70.22503321511405, 77.57059233529228, 51.44244391577584, 50.050354957580566, 39.159178733825684, 31.768973963601248, 72.49692044939313, 107.7142332621983, 105.54471383775983, 72.02390098571777, 82.4001601082938, 95.90272644587925, 43.99178286961147, 0.5230039358139038, 0.34685274373207775, 0.06794956206743206, 0.015830428938248327, 0.1072736315961395, 0.09093951593552317, 0.10679343914879219, 0.2979049916778292, 0.35721009224653244, 8.133229494094849, 2.8239950026784624, 4.073869100638798, 33.52494355610439, 60.541676248822895, 85.01289122445243, 80.0480489730835, 90.17973150525773, 69.34696156638009, 65.87943526676723, 60.72745023454939, 55.22291360582624, 53.820124421800884, 53.782635416303364, 57.861130714416504, 62.43361513955252, 67.41741902487618, 70.83710697719029, 83.91447830200195, 84.11552442823137, 83.3954826082502, 80.94394969940186, 83.11955574580601, 79.25019427708217, 77.85878276824951, 78.00128337315151, 77.48982647487095, 77.5988437107631, 74.79065976824079, 73.02897180829729, 73.24438680921281, 73.6449226651873, 73.37250464303153, 75.80915451049805, 73.7934820992606, 76.6208986554827, 69.42262744903564, 67.09701674325126, 74.04649380275181, 75.67875071934291, 75.41831833975655, 78.15481771741594, 74.27779933384487, 54.18014185769217, 37.56112779889788, 47.032366684504915, 40.66795226505825, 60.36770725250244, 73.27715451376778, 70.9858957018171, 64.3756991795131, 68.92787402016776, 69.75548090253557, 69.62904453277588, 73.20998627798897, 76.10776724134172, 72.67281409672329, 71.78752326965332, 71.68396036965507, 70.99827044350761, 71.34743131910051, 71.34046227591378, 75.6055861881801, 74.21318108694894, 70.628431728908, 72.03799888065883, 75.34866959708077, 75.27182946886334, 74.93339661189488, 78.25629615783691, 78.07327365875244, 76.25574997493199, 74.36796610695976, 73.7337623323713, 71.24282618931362, 65.0647520337786, 73.33598491123745, 62.41310405731201, 62.2341879435948, 74.49916894095284, 80.36127376556396, 76.72523975372314, 63.987760407584055, 92.4298986707415, 131.01803970336914, 73.07489245278495, 46.427595479147776, 57.95864520754133, 29.860720702580043, 31.308280604226248, 3.393224435193198, 0.04634897650352546, 0.5011717730334827, 0.05413161710436855, 0.09211640099861793, 0.03777492319100669, 0.0070690584003127045, 0.20503185449966363, 0.2915480413607189, 0.37500285463673727, 16.77404226575579, 58.69369861057827, 70.50901303972516, 58.60210745675223, 60.91885920933315, 51.53563315527779, 41.66552945545742, 24.2778639793396, 30.55951840536935, 44.762609073093955, 48.93756968634469, 60.72685963766915, 58.98106220790318, 49.58231040409633, 3.4325473308563232, 0.05268146902588861, 0.09465821353452546, 0.03255793545395136, 0.11164290178567171, 0.07641251544867243, 0.06053930827017341, 0.1321353039571217, 0.0785779378243855, 0.07370368151792459, 0.22091072744556836, 0.12983564021331923, 0.0891733028526817, 0.06629377377352544, 0.02786129417030939, 0.03752962260374001, 0.05245252452524645, 0.10944161204887287, 0.0631724651902914, 0.12690516960408005, 0.05335661136944379, 0.09444903475897652, 0.07309433671512774, 0.0334489197869386, 0.08469343824045998, 0.039698444439896514, 0.051120567068989785, 0.07141642817961318, 0.06224135908165148, 0.00755453493911773, 0.04410096963069268, 0.07054389321378299, 0.025400340956236635, 0.03600274578535131, 0.19221609218844346, 0.08584651350975037, 0.2057160349296672, 0.30359855187790735, 20.186288697378977, 94.83378778185163, 81.66220583234514, 95.60400254385812, 66.5674180984497, 64.06960323878697, 51.51583773749215, 26.607770408902848, 50.33991071156093, 119.30054201398576, 108.01471505846295, 70.24314022064209, 92.73431314740861, 106.49890995025635, 48.08101313454764, 0.24410310866577284, 0.2745116012437003, 0.04797884475971971, 0.01686705063496317, 0.031194595753082206, 0.1055689344980887, 0.09426933154463768, 0.45297255367040634, 1.513418293425015, 6.83610417161669, 1.4195222918476378, 5.340140513011387, 54.43532139914376, 71.60010256086076, 94.62639100211007, 82.0041753223964, 94.24276011330741, 76.02785600934709, 70.93517385210309, 68.34081377301897, 63.5308746610369, 60.90277412959507, 61.197343008858816, 64.66989285605294, 71.190110206604, 74.33349609375, 76.86664254324776, 85.24762916564941, 86.62732601165771, 84.04989174434117, 84.73962552206856, 84.91911833626884, 84.07314736502511, 83.4894083568028, 82.85762255532401, 79.79550279889787, 78.67605767931256, 79.4051946912493, 76.17435877663749, 77.78868934086391, 78.05458300454276, 79.92857469831193, 81.05823366982597, 76.35884039742606, 76.38518796648297, 73.87167017800468, 68.53264658791679, 75.91820648738316, 82.23194422040666, 77.82657786778041, 76.89053045000348, 76.55661392211914, 48.875355516161235, 40.77711888722011, 45.30303995949881, 43.603750297001426, 63.65386472429548, 74.2253473826817, 70.39028917040143, 65.97208949497768, 70.00874274117606, 69.68477603367397, 73.2264882496425, 73.06860433306012, 76.8571582521711, 75.59915910448346, 73.82226848602295, 71.46284089769635, 71.30851445879254, 73.27170017787388, 70.68233585357666, 74.20866475786481, 79.03922612326485, 76.04109232766288, 72.25724928719657, 78.4506789616176, 77.22507231576103, 77.85510717119489, 79.55342061179024, 78.27293709346226, 77.45034681047711, 78.89659350258964, 76.09330804007394, 75.211991582598, 68.89600958142961, 76.15412562234062, 68.46816730499268, 62.195090430123464, 70.25903769901821, 77.2742725099836, 77.27087484087262, 74.27705587659563, 71.40217617579869, 103.90673855372837, 104.71324375697544, 54.00773273195539, 71.03428990500313, 52.80589587347848, 40.646006379808696, 8.016869749341692, 0.13491120428911277, 0.3765840312199933, 0.015027749152587993, 0.11272011683987719, 0.22517237519579275, 0.0322350070678762, 0.3755774652319295, 0.05534516002184578, 0.38427313576851574, 15.793116433279854, 68.78037071228027, 75.8982721056257, 67.46204730442592, 45.72256176812308, 20.998526164463588, 17.00613294328962, 34.70713785716465, 39.77213144302368, 57.107320649283274, 68.33161435808454, 70.02680805751255, 69.92577430180141, 67.82163047790527, 5.537418110030038, 0.06227596436760255, 0.14048386311956815, 0.009777492843568325, 0.027137645054608583, 0.01957304828933307, 0.015610670105421116, 0.13707820086606912, 0.050485750061592886, 0.048408079227166514, 0.10832515731453896, 0.04035312895263944, 0.048348775266536644, 0.09375648120684282, 0.01574698439799249, 0.08768181502819061, 0.05076937430671283, 0.04964036667453391, 0.13776912593415805, 0.05125261676896896, 0.1511293447443417, 0.14279922816370214, 0.13686033684228147, 0.1974328729723181, 0.17748045575405869, 0.20405654183455876, 0.1889255637569087, 0.16824431850441865, 0.16776601916977338, 0.21757705775754793, 0.0849079503012555, 0.12574454902538232, 0.15766526545797074, 0.2555209259901728, 0.3135262248771531, 0.15410037817699568, 0.3413726235074656, 0.6582505128213337, 28.216219323022024, 108.90862165178571, 91.35492897033691, 103.8397718157087, 71.48050321851457, 65.55635098048619, 52.78617341177804, 47.35856376375471, 91.09270395551408, 116.51723957061768, 113.89583015441895, 92.26673412322998, 103.83251789637974, 114.89607892717633, 60.37601729801723, 1.4556223090205873, 0.47089651759181705, 0.35250909307173317, 0.16388454101979733, 0.1611586351479803, 0.22505744493433408, 0.22869984805583954, 0.40785154913152966, 0.8513103361640657, 27.768109151295253, 8.179487126214163, 4.892027735710144, 63.50083065032959, 76.80610983712333, 101.38602243150983, 83.82395022256034, 96.44957051958356, 79.84427220480782, 79.99629184177944, 77.81842068263462, 73.01508235931396, 70.9061929157802, 72.5621223449707, 72.98011902400425, 76.4647170475551, 78.36663355146135, 82.19271469116211, 92.08296816689628, 91.45091138567243, 87.65666689191545, 91.46910871778215, 87.70160784040178, 87.77847576141357, 86.81599739619664, 86.423736844744, 82.38574259621757, 84.3278613771711, 81.6392489842006, 79.93965707506452, 81.24819047110421, 82.61320577348981, 83.31090218680245, 86.75034386771065, 79.0377392087664, 80.04955673217773, 74.24774837493896, 69.6277938570295, 78.1022754396711, 85.65031896318708, 81.66097600119454, 79.80631419590541, 74.12954562050956, 59.7833012172154, 51.26459782464163, 59.38428701673235, 53.149459975106375, 66.63308552333287, 76.61725085122245, 73.65638024466378, 66.21674946376255, 71.4010922568185, 73.42611694335938, 74.89316654205322, 77.30313532693046, 81.35951450892857, 79.20608711242676, 77.53640025002616, 76.36938776288713, 76.71243422372001, 77.14962877546037, 78.17393915993827, 81.10640553065709, 83.51508889879499, 79.00680582863944, 76.6065923145839, 81.50467627389091, 79.77748611995152, 78.81935037885393, 83.02189881461007, 83.23327691214425, 84.8380606515067, 81.755005972726, 80.89599323272705, 78.45528561728341, 69.26213795798165, 69.99315098353794, 67.79358754839215, 72.35041768210274, 79.76424980163574, 84.72781358446393, 79.62482724870954, 76.74358994620187, 77.53492723192487, 93.56296920776367, 89.81999547140938, 61.02704960959298, 75.36983380998883, 64.57314613887242, 60.857694217136924, 5.746247955730983, 0.6916093028017453, 1.5073503447430474, 0.15048811558101857, 0.29178390013320105, 0.5347045393926757, 0.10897443390318326, 0.47146214438336237, 0.239371086869921, 0.6349839812942913, 25.132650477545603, 77.44322490692139, 88.57100118909563, 73.97012615203857, 84.57467528751918, 64.23970903669084, 57.01298843111311, 33.62359755379813, 38.66617277690342, 58.48272350856236, 67.88567897251674, 80.74810777391706, 80.76727785382951, 83.90978131975446, 7.326411621911185, 0.2386711644274848, 0.1892045909272773, 0.16427395226699965, 0.1715193899082286, 0.12222600568618093, 0.21405613954578126, 0.17949858174792357, 0.24937578716448375, 0.13309315113084658, 0.18930099718272686, 0.23545265570282936, 0.23784498018877848, 0.14758904757244246, 0.16758333040135248, 0.18411361053586006, 0.1351954968912261, 0.22814811766147614, 0.17144485962178024, 0.1588897361819233], [0.16850586661270686, 0.18393666217369692, 0.055814794464302916, 0.06935055367648602, 0.1014450497127005, 0.03939920710399747, 0.027321577238451158, 0.09358418080955744, 0.10306575096079282, 0.057395730167627335, 0.08562990477574722, 0.04861941235139966, 0.04701005281614406, 0.1299328471400908, 0.07563254623008625, 0.05212565724338804, 0.10620699490287475, 0.2597956694662571, 48.541060311453684, 74.86961909702846, 65.66813359941754, 58.98116643088204, 59.520687103271484, 49.78500672749111, 46.757207598005024, 84.80140890393938, 49.40939058576311, 70.61441721235002, 76.39765303475517, 74.07646138327462, 86.27141148703438, 49.08440596716744, 1.376702715243612, 0.17266112007200718, 0.04769052844494581, 0.18500536839876855, 0.10347971839032002, 0.05641226490427341, 0.16345593758991786, 0.10806137682603938, 0.29752525633999277, 1.252010669027056, 0.4001614403511797, 0.5737200858337539, 20.562478065490723, 72.88707569667271, 79.6062616620745, 83.40765585218156, 89.63008035932268, 81.48493644169399, 62.45496000562395, 58.52240467071533, 54.58884184701102, 50.430063588278635, 51.058333601270405, 55.28968232018607, 65.2708911895752, 73.44912937709263, 81.17763151441301, 79.07512051718575, 80.1157591683524, 86.9811977658953, 77.84666510990688, 80.19688633510044, 78.65230178833008, 83.62685762132917, 80.88733577728271, 75.83867740631104, 73.3878949029105, 75.15717724391392, 75.88174928937639, 73.54573713030133, 77.48528235299247, 76.5900000163487, 74.6228746686663, 75.78276525224958, 71.70223413194928, 68.10819503239223, 70.59359346117292, 66.7798662185669, 68.79952689579555, 74.86825030190604, 73.42601272038051, 66.26265621185303, 73.74134976523263, 22.02400037220546, 36.88217067718506, 25.280264956610544, 27.171962397439138, 59.852262088230674, 70.51170199257987, 72.04790701184953, 70.48452758789062, 65.53930010114397, 68.14968967437744, 74.16384887695312, 71.91339683532715, 73.82195581708635, 73.07851246425084, 74.38715008326939, 72.3784258706229, 71.50709397452218, 71.22973578316825, 74.21253490447998, 71.37705148969377, 73.00799519675118, 71.21804196493966, 71.08360821860177, 71.54240471976144, 72.23914228166852, 73.78031526293073, 76.73650278363908, 75.53991181509835, 74.71112373897007, 77.366350037711, 68.15770789555141, 72.07313592093331, 71.15408379690987, 69.74760164533342, 68.59694521767753, 55.28892844063895, 56.1722286088126, 55.59168924604143, 67.89057745252336, 84.73259394509452, 66.23225089481899, 78.31429971967424, 133.48160689217704, 65.88356944492885, 52.607517855507986, 49.6739501953125, 29.996676104409353, 22.388094663619995, 1.7896164613110679, 0.20135167054831982, 0.803821244410106, 1.788673351917948, 0.06605973347489323, 0.40127060083406313, 0.08890494225280625, 0.0822020476417882, 0.18874917179346085, 0.19987019790070398, 18.62142062187195, 57.05050522940499, 70.43644605364118, 63.955833435058594, 49.49164336068289, 66.2366213117327, 44.035341126578196, 44.91341624941145, 34.64718879972185, 32.9302785055978, 46.92917898723057, 56.15527500425066, 56.30439376831055, 58.99235303061349, 3.3934118194239478, 0.1113621172096048, 0.08007026024694953, 0.07569416399512972, 0.03629771513598306, 0.07117919198104314, 0.09245340898633003, 0.10184729205710547, 0.03713465415473495, 0.0997798637087856, 0.16624763421714306, 0.2964448386004993, 0.13088453321584634, 0.0728613142190235, 0.18580214492976665, 0.018132306402549148, 0.012047982126075243, 0.007294908781269831, 0.03329548605584672, 0.06714777116264616, 0.17060376118336404, 0.004618051237360175, 0.048978774675301144, 0.1144775700356279, 0.1104024379913296, 0.06903336569666862, 0.09502911434641906, 0.008109803045434611, 0.07821412770343678, 0.07706587681812899, 0.08243867315884147, 0.09517798492951052, 0.08295375587684767, 0.09794170555791684, 0.027700900366263728, 0.0972445108262556, 0.3552319998187678, 65.54158605848039, 85.79812799181256, 80.8675125667027, 75.95115484510148, 77.36377225603376, 64.73735986437116, 38.793182373046875, 35.489470277513774, 36.32632868630545, 78.64894580841064, 80.64159883771623, 81.24641868046352, 94.53054060254777, 53.17914267948696, 0.5594939749155725, 0.10562006889709405, 0.054819692325379164, 0.1845354557569538, 0.19065396886851105, 0.037665550131350756, 0.05375683846484337, 0.2707870682435376, 0.8044041331325258, 2.4613207493509566, 1.070960481251989, 0.47294287064245766, 32.91726105553763, 83.10254655565534, 83.06060028076172, 87.7426369530814, 95.53087275368827, 82.69236660003662, 66.37801715305874, 65.34110273633684, 64.11810166495187, 59.743196214948384, 58.692100524902344, 63.71373735155378, 71.855560030256, 76.59357139042446, 85.07658536093575, 84.36902250562395, 81.33179119655064, 87.32476534162248, 82.68267386300224, 82.21784632546562, 82.93881920405796, 82.31475285121373, 84.9259067262922, 80.7727530343192, 77.31389808654785, 79.11453764779228, 78.33181612832206, 79.35211045401437, 80.47861494336809, 81.10455730983189, 76.93521431514195, 77.98254408155168, 77.03161362239292, 72.97074590410504, 68.75778211866105, 69.93432058606828, 69.91638728550502, 77.05897562844413, 78.87258747645787, 70.87810829707554, 72.97669356209892, 25.25750960622515, 43.278869901384624, 34.23452486310686, 27.252703939165386, 57.723396573747905, 75.06809438977922, 70.5809268951416, 71.27143887111119, 68.5970355442592, 68.24623489379883, 77.7999176297869, 74.53112370627267, 74.58726515088762, 75.26074709211076, 76.35756192888532, 75.53893906729562, 75.64872060503278, 71.90673351287842, 76.50437041691372, 74.64104420798165, 74.14161464146206, 74.82660279955182, 75.13897296360561, 73.2560041972569, 76.7730850492205, 74.2577885219029, 78.76468195234025, 77.7429562977382, 74.73282991136823, 80.63722842080253, 73.01477663857597, 72.43592916216168, 76.0356866291591, 71.60060283115932, 75.067809513637, 64.2096928187779, 59.66206904820034, 54.988596030644004, 66.48349775586809, 79.09638200487409, 77.28948211669922, 63.309400830950054, 101.41075107029506, 91.22842311859131, 55.23022658484322, 69.59917422703334, 50.896906103406636, 29.875958102090017, 5.267243487494333, 0.4299052400248391, 0.854919002524444, 1.466052532196045, 0.07732419509972845, 0.035001346841454506, 0.11207089453403439, 0.5923062456505639, 0.13673568995935576, 0.304241803075586, 18.18348261288234, 66.87156159537179, 76.0377641405378, 71.83381911686489, 43.62779106412615, 38.901598589760916, 15.262529407228742, 46.736265727451865, 51.14514786856515, 47.11194787706648, 67.21628952026367, 64.37326731000627, 63.74018914358956, 75.78849056788853, 4.931128289018359, 0.1331288285021271, 0.11921599720205579, 0.08317856131387608, 0.012056125394467796, 0.09467352128454617, 0.08099389568503414, 0.05961941834539175, 0.01911721016014261, 0.06126228054719312, 0.058540500168289454, 0.135738039921437, 0.12648951262235641, 0.021553145788077797, 0.14543741302830832, 0.054733844074819765, 0.019256716959976723, 0.03308883821591735, 0.12097332147615296, 0.14178172419113771, 0.21782002757702554, 0.11948036801602159, 0.25286861402647837, 0.18319202427353176, 0.22462781013122626, 0.12672238584075654, 0.21999732431556496, 0.2535318141537053, 0.17783250686313423, 0.18552727039371217, 0.12594243697822094, 0.13539170207721846, 0.17562265401440008, 0.20930729008146695, 0.1658676681774003, 0.4288414328226021, 1.0667808141027177, 80.82506602151054, 101.78288963862828, 91.43869645254952, 76.17528288705009, 81.11635535103935, 69.3488028390067, 68.98458521706718, 117.01055472237724, 67.43537317003522, 79.72436714172363, 94.2027176448277, 93.62295300619942, 105.42051478794643, 64.3557231085641, 2.6196836573737006, 0.43173044494220186, 0.2986903009670121, 0.4216086837862219, 0.47728511478219715, 0.19686724618077278, 0.34836609395486967, 0.2955019734799862, 0.7781437965376037, 3.2303745107991353, 3.5785906485148837, 1.4719011783599854, 36.757877826690674, 88.07189123971122, 87.28568867274693, 94.55230236053467, 96.26003755841936, 87.96824496132987, 73.37149020603725, 76.43765381404332, 71.28978211539132, 68.82189314705985, 67.35467679159981, 69.9298528943743, 76.77213314601353, 82.68717629568917, 90.06660788399833, 90.57484776633126, 85.64265510014125, 94.46723556518555, 86.42349365779332, 84.46422672271729, 87.65488120487758, 86.5567878995623, 92.44885335649762, 85.02793407440186, 79.25272342136928, 82.49323122841972, 83.81903089795793, 82.71918664659772, 83.36222158159528, 84.17549433026994, 79.38817160470145, 81.92377076830182, 80.34839875357491, 72.06969656263078, 71.15843336922782, 72.4124789919172, 72.76508617401123, 80.33848367418561, 84.16282081604004, 71.66987637111119, 75.77853379930768, 31.702302524021693, 44.42152547836304, 34.97270148141043, 36.37349305834089, 64.8973560333252, 74.25997025626046, 71.48592976161412, 72.01199872153146, 71.71685314178467, 70.11576584407261, 80.27227428981236, 77.2106409072876, 79.19171128954206, 79.1636961528233, 80.82207134791783, 77.44237722669328, 79.2510072163173, 74.92811598096574, 80.98484679630825, 79.44853060586112, 79.37542166028703, 76.94158581324986, 77.04596165248326, 74.90384592328752, 77.702225957598, 78.7810171672276, 81.98233018602643, 80.11292430332729, 78.17362649100167, 86.0708795275007, 75.82134165082658, 77.5146176474435, 80.36149610791887, 73.27175576346261, 69.80154051099504, 63.2347354888916, 66.68646158490861, 68.53420993259975, 74.95622144426618, 81.41324492863247, 84.79729557037354, 71.09163338797433, 92.75747844151088, 84.28419194902692, 62.03694943019322, 74.2896807534354, 62.66528197697231, 44.956203256334575, 2.70305335521698, 1.0830146287168776, 3.0623557780470168, 3.6892459222248624, 0.21722388028034142, 1.225565608058657, 0.17373639451605932, 0.3435614417706217, 0.15762827172875404, 0.3911241410034043, 28.22390055656433, 77.59183992658342, 90.48682798658098, 81.09034129551479, 73.41831411634172, 92.12963226863316, 61.25628457750593, 61.504349163600374, 46.570558139256065, 45.92658519744873, 63.53122901916504, 74.51640047345842, 72.25781903948102, 92.10182557787213, 6.7707059894289285, 0.3233818917402199, 0.3629748986235687, 0.10492205313806023, 0.08803938262696777, 0.14476525623883518, 0.15807109725262436, 0.13578857720962592, 0.12639359491212027, 0.1384061753217663, 0.26670283025928904, 0.27835873195103233, 0.2242614147918565, 0.15865018617893967, 0.18742692417332105, 0.1220600495913199, 0.1110820383099573, 0.13826373725065164, 0.17275877483189106], [0.07302492936807019, 0.24339523379291805, 0.07590988384825842, 0.05069497972726822, 0.08090589647846562, 0.14530903420278005, 0.08554333727806807, 0.13793254430804933, 0.02965165122545191, 0.04076000569122178, 0.06604592528726373, 0.08362528841410365, 0.048135627061128616, 0.21894096742783273, 0.004387469346901136, 0.0993248720520309, 0.2356559990772179, 6.266616352966853, 68.26357759748186, 63.06763826097761, 51.572149412972585, 52.41407653263637, 40.6888177054269, 38.13664708818708, 45.252279894692556, 40.52515983581543, 24.26255362374442, 39.68999678747994, 71.42118644714355, 83.86231122698102, 61.4016478402274, 2.3586111749921526, 0.10174842271953821, 0.021086685193170394, 0.1912566843841757, 0.11278816711689744, 0.23073249469910348, 0.02187157209430422, 0.21263407942439827, 0.09731537023825304, 0.8480529880949429, 3.301329731941223, 0.9082089715770313, 2.8819887936115265, 56.03059305463518, 78.92947237832206, 81.30390112740653, 69.68278190067836, 81.27528844560895, 67.33853612627301, 62.476596696036204, 66.52406828744071, 59.11198711395264, 57.768997601100374, 59.489336831229075, 64.9140317099435, 71.85152312687465, 75.61022063664028, 79.01050921848842, 83.94424438476562, 79.18019812447685, 79.8931805746896, 83.1005802154541, 80.09686701638358, 78.08933789389474, 77.85070896148682, 80.53212996891567, 75.19430146898542, 74.04362419673375, 73.31397301810128, 71.01270880017961, 74.94140093667167, 69.35413905552456, 70.30379104614258, 70.84784889221191, 73.21152877807617, 74.32018334524972, 73.11894403185163, 67.2895096370152, 69.62044961111886, 65.74521691458565, 72.87329741886684, 70.62533283233643, 76.41358525412423, 59.15757424490792, 30.172465528760636, 54.20175770350865, 67.01602854047502, 25.680689641407557, 30.216398988451274, 77.0559948512486, 61.431024823869976, 66.90193911961147, 63.30557932172503, 66.79019124167306, 68.09124837602887, 71.4835604258946, 70.24080562591553, 74.67365210396903, 70.33840002332414, 70.30913421085903, 69.2328929901123, 70.43416009630475, 71.98370565686906, 74.91856915610177, 70.92411231994629, 72.69468702588762, 72.63158348628453, 70.27114840916225, 71.43253980364118, 69.82205159323556, 71.94705390930176, 71.43677820478166, 71.04911736079625, 76.39890371050153, 76.29425689152309, 69.33336394173759, 73.00139440808977, 67.30820723942348, 70.73198768070766, 69.2309683391026, 61.435089520045686, 56.46705109732491, 57.074090889522004, 63.53445298331124, 68.89422389439174, 58.07903664452689, 87.97347695486886, 113.62330790928432, 61.478230885096956, 60.735920088631765, 46.578371388571604, 24.826782090323313, 22.837328706468853, 0.48434231323855265, 0.3346580038113253, 0.8325008569019181, 0.3747746225978647, 0.07806640384452683, 0.21937088721564837, 0.49099407345056534, 0.19308927176254137, 0.14741963094898633, 0.4573538271444184, 20.267791066850933, 60.1553772517613, 73.74733216421944, 61.71530342102051, 41.034685134887695, 65.86880452292306, 32.69225059236799, 26.366791248321533, 39.64025810786656, 46.65817492348807, 44.93002244404384, 55.8417375428336, 58.134372098105295, 54.71119267599923, 1.3591882607766559, 0.029187601126198257, 0.023797188320064118, 0.047579231738512, 0.052115513144859245, 0.21683909664196627, 0.23754039938960755, 0.23649751820734569, 0.08160349833113806, 0.10736454850328819, 0.09825113788247108, 0.18819664072777542, 0.04744893605155604, 0.07666054713938918, 0.026249783679044673, 0.044280364111598046, 0.13442237409097807, 0.0987327281119568, 0.08664476246173893, 0.07211782982839005, 0.06623920598732573, 0.09660277954701867, 0.06436275810535465, 0.05224429230604853, 0.07576154930783169, 0.04652977215924433, 0.0414800093775349, 0.056979184305029254, 0.02910590890262808, 0.07592649438551494, 0.11598299496940204, 0.18960397663925374, 0.08678093765463148, 0.20480888789253576, 0.4350303778690951, 9.683208448546273, 84.45979377201625, 76.81128624507359, 67.9030772617885, 67.8581988470895, 51.614561217171804, 52.574847425733296, 49.27381386075701, 35.18799488885062, 23.9637393951416, 42.43469156537737, 79.73897920336042, 93.57789393833706, 65.09364264351981, 1.5934409137283052, 0.15071355205561432, 0.009354438981972635, 0.0807542981845992, 0.236567244465862, 0.11798403545149735, 0.1445248377110277, 0.2220244612544775, 0.3046869220478194, 1.7551519849470683, 1.957825400999614, 0.9522857921464103, 5.7062936425209045, 71.59585721152169, 84.74337060110909, 87.19439629146031, 74.8439107622419, 80.45832620348249, 73.20434434073312, 73.40532793317522, 75.65348012106759, 67.76069477626255, 65.22973700932094, 68.03887980324882, 72.09375817435128, 74.57739870888847, 79.65486431121826, 81.48851476396833, 88.92406695229667, 83.4296955381121, 80.23803356715611, 86.0412871497018, 82.60479150499616, 79.50384521484375, 83.41941220419747, 79.9881763458252, 82.55008833748954, 77.17430182865688, 79.38346072605678, 73.64164311545235, 78.51472745622907, 72.53414194924491, 75.41435786655971, 75.60449532100132, 77.05093656267438, 75.15941456386021, 78.20932633536202, 71.0914249420166, 66.89148902893066, 68.33722155434745, 77.96535423823765, 74.91275351388114, 80.30881486620221, 59.599743706839426, 37.620156220027376, 56.70405067716326, 68.43597630092076, 33.30137137004307, 26.106120892933436, 76.78955227988106, 61.74690382821219, 67.1841402053833, 64.49310289110456, 69.89873886108398, 70.53700733184814, 75.88748850141252, 73.65101623535156, 77.05263192313058, 72.4570586340768, 72.88571384974888, 73.98865699768066, 73.98391137804303, 72.32074887411935, 74.15096691676548, 71.16395718710763, 74.67498615809849, 75.44413784572056, 74.66869803837368, 72.92055211748395, 73.56537968771798, 73.08485616956438, 74.42954799107143, 72.94198036193848, 74.26546628134591, 79.32187884194511, 76.72401687077114, 74.07248701368059, 70.51271642957414, 72.63650975908551, 76.00450311388288, 70.00625528608049, 62.554993220738, 57.57231841768537, 68.54975305284772, 64.34302874973842, 68.72921807425362, 70.1898753302438, 97.03204495566231, 81.34518037523542, 62.41354179382324, 69.05434513092041, 43.16366182054792, 28.189008440290177, 2.442714559180396, 0.46957445996148245, 0.7982610570532935, 0.17111547158232757, 0.04951848142913409, 0.1708524985505002, 0.1586455992822136, 0.2777891696563789, 0.10107918363064528, 0.3291731338415827, 22.285209212984356, 71.4299133845738, 78.70168958391461, 65.9231185913086, 45.034471239362446, 46.71891607557024, 10.51467158113207, 36.23090212685721, 54.58876889092581, 61.447471209934776, 66.39514446258545, 67.76701763698033, 64.5936780657087, 73.90389592306954, 1.9009980389050074, 0.03567395146403994, 0.10774037547941719, 0.11929364874958992, 0.08954193057226283, 0.22965099130358013, 0.0568874904752842, 0.1113951550796628, 0.049136289794530184, 0.05481104778924158, 0.01780423302469509, 0.11637817376426288, 0.1800925713032484, 0.07076420674898795, 0.03525951584534986, 0.12675324561340467, 0.07421763108244964, 0.06663192170006887, 0.1920324263295957, 0.1847607565245458, 0.14404220932296344, 0.14670421076672419, 0.18130379702363694, 0.17621261307171412, 0.21451573845531258, 0.16277057650898183, 0.11078778481377022, 0.18334674382848398, 0.13512855262628623, 0.16023060280297483, 0.21663291699119977, 0.2600562540548188, 0.16187104263475963, 0.2613918281027249, 0.5377390565616744, 12.525565368788582, 104.14804254259381, 88.6766277040754, 78.45951012202671, 72.3204848425729, 55.0712240082877, 50.18611928394863, 66.59773308890206, 55.975354875837056, 35.879455293927876, 59.487036977495464, 88.42475550515312, 104.3936266217913, 76.1983231135777, 4.515580415725708, 0.2812130573604788, 0.11515081248113088, 0.2737423325223582, 0.47911656222173143, 0.3952031678387097, 0.1432923467031547, 0.31730604491063524, 0.3368835986724922, 1.32281074992248, 10.046182342938014, 2.7219674374376024, 5.514400030885424, 80.52283327920097, 84.71739823477608, 87.5960716520037, 79.14781257084438, 89.70505142211914, 84.25334194728306, 82.8086724962507, 81.62175342014858, 73.82532569340297, 71.33844035012382, 73.38799912588937, 77.80866541181291, 80.41013349805559, 82.0496026447841, 86.00996467045375, 93.98393971579415, 88.59125518798828, 84.7942453111921, 91.25696631840297, 85.8539845602853, 84.38255064828056, 86.16329751695905, 84.39651652744838, 85.54192011696952, 83.02970858982631, 81.31015450613839, 77.14793341500419, 82.44446877070835, 78.68169266836983, 76.98518575940813, 79.24469825199672, 80.80133792332241, 80.78121594020298, 80.15245955330985, 71.43905026572091, 66.87274973733085, 70.26838997432164, 79.95019054412842, 75.64700439998082, 80.43567507607597, 63.49880872453962, 36.78038304192679, 56.70866775512695, 62.66150910513741, 32.56264931815011, 36.43329620361328, 77.14513329097203, 65.06603050231934, 68.58287511553083, 65.41590009416852, 70.67398411887032, 74.27463095528739, 80.603349004473, 77.88656166621617, 79.33228029523576, 75.7663883481707, 75.22494302477155, 75.44036497388566, 75.4786912373134, 76.35323320116315, 80.60978998456682, 75.91300228663853, 78.8136042186192, 80.39932904924665, 77.72325120653424, 74.58238056727818, 75.91462816510881, 74.74746281760079, 78.09429195949009, 76.979140826634, 80.1128409249442, 84.09611116136823, 76.92931529453823, 75.51371015821184, 74.35545240129743, 73.49983733040946, 73.98680877685547, 63.280322619846885, 63.06892367771694, 68.40503597259521, 83.39972100939069, 75.16281223297119, 74.39401490347726, 75.0880148751395, 86.75128187452043, 79.66568265642438, 68.66912310464042, 76.24816949026925, 58.06422308513096, 38.52108744212559, 0.9875736300434385, 3.4448063416140418, 2.112531819513866, 1.0416956458772932, 0.19207175421927655, 2.0165374619620184, 0.6703442867313112, 0.5297066675765174, 0.17491559338356766, 0.590254898582186, 32.69014181409563, 79.13650785173688, 89.01030799320766, 74.713180405753, 60.25658471243722, 89.60203048161098, 48.75216048104422, 38.261210918426514, 49.047167096819194, 63.19657598223005, 64.96196733202252, 80.16762052263532, 75.062424659729, 87.11788967677525, 2.9741937773568288, 0.18240765136267456, 0.1848015229084662, 0.2800572136683123, 0.09016939904540777, 0.3619830161333084, 0.21614446677267551, 0.20764278939792088, 0.1280583127268723, 0.1666052493133715, 0.21605779070939335, 0.31093848230583326, 0.20026069480393613, 0.15642992460301944, 0.07844014771814857, 0.18958695898098604, 0.21399044378527574, 0.15338174173874514], [0.07332630069660288, 0.24953619284289225, 0.12209673119442803, 0.10764207611126558, 0.04677521523886493, 0.04134900801415954, 0.08383268264255353, 0.07316578645259142, 0.11374159024230071, 0.055920265947601626, 0.05057533025475485, 0.06325415402118649, 0.07066814654639789, 0.04499801667407155, 0.05097712137337242, 0.13835957353668554, 0.2999691223459584, 14.187161922454834, 68.96114199502128, 61.80384431566511, 67.87665326254708, 41.01686647960118, 52.73477758680071, 49.95185382025582, 27.472920145307267, 31.423287187303814, 52.81431014197213, 80.85563114711216, 82.16869476863316, 70.91102886199951, 4.925969685826983, 0.43501645433051245, 0.054828503102596314, 0.09087615433548178, 0.05463754638497319, 0.22195605135389737, 0.05830006806978157, 0.14055249015135424, 0.028607209412647144, 0.3011766975479466, 1.421590575150081, 1.2740972552980696, 0.8450410525713647, 23.45717055456979, 55.31043658937727, 79.58912740434918, 79.32316425868443, 55.505166803087505, 66.76937443869454, 61.16668060847691, 67.95222187042236, 63.88491317204067, 60.62381785256522, 65.0544548034668, 72.11333819798061, 69.07282733917236, 80.00490760803223, 80.33116027287075, 84.99527754102434, 84.26062365940639, 82.19619573865617, 82.29920973096574, 80.15177862984794, 79.93881634303501, 80.64488533564976, 78.48689992087228, 78.3627564566476, 81.79504149300712, 70.97850976671491, 69.68141310555595, 69.00916794368199, 71.1361504963466, 67.9543410709926, 71.94753333500454, 70.61800248282296, 74.14729131971086, 72.99555792127336, 73.09507696969169, 71.22568498338971, 67.11626325334821, 65.27096761975969, 68.01541573660714, 69.67827946799142, 70.68557371412004, 56.21849318913051, 55.052192892347065, 57.60755968093872, 59.419861793518066, 58.00157117843628, 19.377683401107788, 65.02584212166923, 64.4884614944458, 64.72383866991315, 64.39408411298479, 67.84699835096086, 69.3991425377982, 73.68755681174142, 71.25065680912563, 72.6941728591919, 71.45810222625732, 70.93380505698067, 70.21183858598981, 71.23375184195382, 69.62730053492955, 71.85897854396275, 73.78283745901925, 71.64220864432198, 73.99202687399728, 70.59773458753313, 68.21865749359131, 72.0055160522461, 66.89717265537807, 71.91039521353585, 71.18294661385673, 69.06607369014195, 70.3691735948835, 73.660827091762, 72.81795501708984, 71.67035579681396, 65.754944392613, 65.24465479169572, 70.89384596688407, 72.86612687792096, 60.37148707253592, 57.13979305539812, 50.63462550299508, 56.99890443256923, 57.717195306505474, 94.76399312700543, 98.42310905456543, 56.73812811715262, 62.753753389631, 36.43203510556902, 25.263967956815446, 18.86347327913557, 0.3657198984708105, 0.5992079781634467, 0.14095593350274221, 0.15912058736596787, 1.230389069233622, 1.6893934735230036, 0.09646549155669552, 0.01826400835333126, 0.2594200596213341, 1.0908708700111933, 33.9307496207101, 71.3265380859375, 79.31170667920793, 68.6774331501552, 48.30548163822719, 57.50944764273507, 38.36020885195051, 28.761263813291276, 30.77587836129325, 31.97559949329921, 42.02835743767874, 59.01152311052595, 60.27088410513741, 38.41073962620327, 1.7071865073272159, 0.11554863756256444, 0.1726336936865534, 0.06339663280440228, 0.0831930141097733, 0.09647341684571334, 0.17169846887035028, 0.055196893334920914, 0.23027977613466127, 0.111989558541349, 0.0736250528799636, 0.1627012709421771, 0.11133384944072791, 0.0769298712589911, 0.11507329664060048, 0.02549006024907742, 0.018326207962153212, 0.07072178473962204, 0.0705111538991332, 0.03737557819113135, 0.031202629607703005, 0.0632067583501339, 0.0384231412650219, 0.08963505271822214, 0.03720950335264206, 0.06683194703821625, 0.011503867439127393, 0.06705892378730433, 0.06434182530002934, 0.08407996115939957, 0.1547208170273474, 0.05780498177877494, 0.2518622651696205, 0.24825376165764673, 21.80378416606358, 83.12088285173688, 78.43872111184257, 79.72449220929826, 53.061454091753276, 63.72199875967843, 25.723999500274658, 15.797573702675955, 29.966447966439382, 57.89207451684134, 89.0748289653233, 92.76364149366105, 79.03830201285226, 4.491706839629582, 0.47863947067941937, 0.06423026735761336, 0.12030662010822978, 0.05251612361254437, 0.18228170169251307, 0.10581518164170639, 0.15971406123467854, 0.150081157418234, 0.30466917157173157, 1.2427023627928324, 1.2797629684209824, 1.2197379150560923, 38.32627385003226, 68.32392270224435, 82.28010218484062, 80.944762638637, 63.080110277448384, 71.97572217668805, 69.80199909210205, 75.78219549996513, 68.49638393947056, 66.6684101649693, 68.14681312016079, 74.59877831595284, 76.2258449281965, 83.61955506461007, 81.69610609327043, 87.89269024985177, 84.1674552645002, 85.13907745906285, 82.6543321609497, 80.71053886413574, 83.90108217511857, 82.51519448416573, 80.04140649523053, 83.0553057534354, 80.1391190120152, 78.74840927124023, 73.89807333265031, 74.72088595799038, 73.63469491686139, 74.28911100115094, 76.70333208356584, 76.15017209734235, 76.55826759338379, 75.98932824816022, 76.20130389077323, 74.22791126796177, 69.36737537384033, 66.23176452091762, 67.70474093300956, 71.27434321812221, 71.40553910391671, 61.17265605926514, 56.97444677352905, 59.442047391619, 56.40668167386736, 60.58299718584333, 24.965924978256226, 62.77836390904018, 65.5730197089059, 65.47746808188302, 65.49275411878313, 67.75663008008684, 71.70127528054374, 74.38946383340019, 73.75756686074394, 73.50604901994977, 73.76748888833183, 73.67264597756522, 71.15269415719169, 73.32363796234131, 72.57153020586286, 71.62472697666713, 74.09866087777274, 73.70961734226772, 75.02405670710972, 74.70278590066093, 70.51156997680664, 72.3495283126831, 70.1094777243478, 71.53257301875523, 74.13922446114677, 72.16969503675188, 70.9381685256958, 75.36163493565151, 74.24316256386894, 73.09365953717912, 70.74782957349504, 69.45937647138322, 74.35805797576904, 77.11485304151262, 65.97919055393764, 61.90418325151716, 60.84367275238037, 57.33554812840053, 64.36736134120396, 75.08747291564941, 93.1908792768206, 71.7321252822876, 67.85562106541225, 66.22713702065604, 36.42410026277815, 24.37775128228324, 2.165253881897245, 0.5032228486878532, 0.34887732937932014, 0.4789872605885778, 1.099056390779359, 0.40665075927972794, 0.05938159182135548, 0.36296643050653593, 0.1853637977370194, 0.6716511451772281, 37.79685238429478, 81.5035228729248, 82.2887874330793, 73.17017310006278, 53.32020500728062, 35.11509091513497, 18.89434586252485, 32.2802745274135, 48.577461923871724, 47.1701842035566, 60.48530551365444, 69.95464406694684, 68.53220885140556, 56.55859361376081, 1.8720134113516127, 0.04313245927914977, 0.1275922813053642, 0.0562134168243834, 0.09967790025153331, 0.050836532310183556, 0.07817055218453918, 0.018026585557631085, 0.1357463180486645, 0.03860395049144115, 0.026005414381091083, 0.10300637914666108, 0.08217736253780977, 0.06228324504835265, 0.020890732761472464, 0.051721871231815646, 0.023723884485661983, 0.2204186674207449, 0.19746491339589867, 0.19201873349291937, 0.22502780652471951, 0.1973848191222974, 0.1546431654798133, 0.11987904805157866, 0.16393966520471231, 0.20577489105718477, 0.1843967360577413, 0.10672090375529868, 0.19147214639399732, 0.170534699889166, 0.20838893364582742, 0.18792032769748143, 0.42385710456541603, 0.27495004343135016, 29.750713348388672, 103.01741082327706, 86.5699130467006, 92.37629331861223, 60.68050820486886, 74.74680968693325, 78.35457147870744, 39.609943117414204, 49.40866102491106, 74.98753697531563, 101.68170997074672, 100.05447660173688, 87.11848722185407, 8.229752131870814, 0.6274736842938832, 0.14744922864649976, 0.302941268576043, 0.22070483277950967, 0.36527857929468155, 0.36429380785141674, 0.40825082627790316, 0.3161017538181373, 0.9396851254361016, 5.988930293491908, 8.846667919840131, 1.97425919345447, 45.90855114800589, 78.94376482282365, 86.60791969299316, 87.64076941353935, 70.28857449122837, 82.43415069580078, 79.46696417672294, 83.06024592263358, 75.0711168561663, 72.90287590026855, 73.7274672644479, 80.59660925183977, 77.47402627127511, 86.80884769984654, 86.06665502275739, 93.3572747366769, 90.58484622410366, 89.5307697568621, 87.80799170902797, 84.80783598763603, 88.01645851135254, 86.60878821781704, 86.74236733572823, 85.85914707183838, 86.32800456455776, 85.31790324619838, 76.82452951158795, 77.82306207929338, 78.98801789964948, 77.13148702893938, 78.34394073486328, 77.94407190595354, 78.3994151524135, 78.60920211247036, 77.65527697971889, 77.34258719852993, 68.80274391174316, 67.08251585279191, 70.66281141553605, 72.04026399339948, 73.10460989815849, 60.5090058190482, 54.76504121507917, 58.79922090257917, 59.349476541791645, 56.816305773598806, 26.6231016090938, 67.70068318503243, 63.75705936976841, 68.73718070983887, 68.01938315800258, 72.06944642748151, 74.67181083134243, 78.52804715292794, 80.31095491136823, 78.330169405256, 78.07348210471017, 78.14205387660435, 76.16576385498047, 75.89954362596784, 77.21783924102783, 74.48876748766217, 79.76761967795235, 77.1073350906372, 79.0267402103969, 76.70499270302909, 73.36133888789585, 75.60580158233643, 71.76296833583287, 75.40027386801583, 77.5286808013916, 74.15565695081438, 76.18868596213204, 80.55730329241071, 80.79035976954869, 75.51399503435407, 71.1843432017735, 69.48738465990338, 75.7337874003819, 74.62291635785783, 66.0646117074149, 65.43956565856934, 68.49860041482108, 65.26868861062187, 72.68298625946045, 75.16437557765416, 83.79365607670375, 70.70475769042969, 71.9459421975272, 69.50362954820905, 55.71506493432181, 28.534005607877457, 1.773731685110501, 1.0662956344229835, 0.48701015008347376, 0.3596627792077405, 2.56721259866442, 4.117752620152064, 0.14034042081662587, 0.7198902081165994, 0.2621374566640173, 1.3129396396023887, 51.279178619384766, 88.83413641793388, 93.60935538155692, 82.27879592350551, 65.66793210165841, 80.90677683694022, 56.81158447265625, 39.85825089045933, 42.361617360796245, 45.903760365077424, 63.7364718573434, 80.42938000815255, 82.74155984606061, 70.06793444497245, 2.6214350376810347, 0.14064842143229075, 0.23078205489686557, 0.11138259539646761, 0.20440776513091155, 0.15740919991263322, 0.23058370554021426, 0.09990478879106895, 0.32356251776218414, 0.16263774649373122, 0.17219458653458528, 0.20038635948938982, 0.16547109160040105, 0.11926240899733134, 0.26236894567097935, 0.10305931844881602, 0.09406343009322882], [0.03278369423268097, 0.12722828797996044, 0.08514919664178576, 0.08917451743036509, 0.0750603105074593, 0.0920510512909719, 0.11676432804337569, 0.08493858615734748, 0.07512717334819691, 0.07442312541284732, 0.061641079506703784, 0.01840074673028929, 0.12332380749285221, 0.07751656656286546, 0.030257881552513157, 0.14525813050568104, 0.07877552722181592, 23.740538937704905, 65.17686121804374, 54.26156432288033, 66.36812986646379, 62.65965393611363, 40.475275244031636, 60.995713233947754, 76.74382618495396, 45.30930723462786, 71.84355354309082, 72.36407784053257, 77.73014381953648, 12.07146063872746, 0.16616455438945973, 0.023523002497053573, 0.07055897704724755, 0.0828422929293343, 0.19547318241425923, 0.1910544809486185, 0.24097074674708502, 0.09239747734474284, 0.21365870801465853, 1.2667535522154398, 4.059412939207895, 1.3990119695663452, 7.598717604364667, 57.09845127378191, 40.486694608415874, 55.09342697688511, 60.77703257969448, 55.90948942729405, 62.156048502240864, 62.36593968527657, 58.532146045139854, 61.46891335078648, 70.26670156206403, 67.49512767791748, 72.68919794900077, 79.91745063236782, 79.90336663382394, 80.12537547520229, 77.36063167027065, 78.97990935189384, 81.70713983263288, 76.9951981135777, 80.59184278760637, 81.10439055306571, 76.89308738708496, 72.70250374930245, 70.71060112544468, 75.81309413909912, 73.8441414151873, 66.83436788831438, 67.01303386688232, 71.32190363747733, 70.91016728537423, 71.16426985604423, 71.19548116411481, 72.13066005706787, 73.95091438293457, 70.69867106846401, 71.03363677433559, 72.44449629102434, 68.97282191685268, 64.87807478223527, 68.09738363538469, 62.65053789956229, 60.05214091709682, 54.92586421966553, 59.094665254865376, 55.424974169049946, 58.5713130405971, 46.62063380650112, 53.76475770132882, 64.74161216190883, 61.272369657244, 64.67556258610317, 67.83943176269531, 71.54510756901333, 66.10855211530412, 66.5510481425694, 64.14904199327741, 67.66670649392265, 68.13266658782959, 64.75236102512905, 66.52155998774937, 68.87032209123883, 65.73018796103341, 71.15826661246163, 70.64569105420793, 70.12042113712856, 69.7880471093314, 66.02177606310163, 66.33875983101981, 69.28920119149345, 66.21606159210205, 70.64623996189663, 72.53221035003662, 70.22197600773403, 70.16459083557129, 66.58019583565849, 68.32627119336809, 69.88252871377128, 67.84663704463414, 65.89721570696149, 68.41859885624477, 72.99033287593296, 67.3103472845895, 57.62881074632917, 47.077668939317974, 49.81084360395159, 62.751842635018484, 98.34298937661308, 87.62487193516323, 59.94008037022182, 63.967221532549175, 27.02624477658953, 25.945756469454082, 10.697205100740705, 0.06325582321733236, 0.6666087614638465, 0.14765862455325468, 0.13913275061973504, 0.034163169496293576, 0.28033354026930674, 0.047114204548831494, 0.11453893674271447, 0.03813429569293346, 1.8592404510293687, 56.76866544995989, 72.29950823102678, 74.46962520054409, 57.485580580575125, 32.21847724914551, 52.24195228304182, 44.16196857179914, 25.51680769239153, 33.71034928730556, 32.44917828696114, 41.31675073078701, 54.86293091092791, 56.87121738706316, 24.09968090057373, 1.1945324561425616, 0.034174697806260416, 0.04834258024181638, 0.034622212007109604, 0.06723230305526938, 0.15230464882084302, 0.2110823919730527, 0.11485172781561102, 0.16617394531411783, 0.11041625296430928, 0.1197107442255531, 0.19249676141355718, 0.08183104504964181, 0.05414682307413646, 0.13564569130539894, 0.044778456312737296, 0.0791082875803113, 0.015364463673904538, 0.02723902666808239, 0.04522865751226034, 0.035970980168453286, 0.05367897317877837, 0.07822564922805343, 0.08947122722331967, 0.023031963667433177, 0.030059138645551035, 0.0160617534004684, 0.0250051333236375, 0.07434710234935794, 0.0786636367972408, 0.028989747100110565, 0.08869794157466718, 0.007380248130565243, 34.545557498931885, 82.53544153485979, 64.92281423296247, 84.13965552193778, 67.47279616764614, 43.836191858564106, 41.28115510940552, 62.84492070334298, 54.47858435767037, 82.63540526798793, 80.65346636090959, 87.17905466897147, 11.655089838164193, 0.12768747976848058, 0.022694701229089072, 0.23926501827580587, 0.0709434010620628, 0.10077878260718924, 0.20926195037152084, 0.10543187042432171, 0.07779868106756892, 0.11592970282903739, 1.3158131539821625, 0.36343679098146303, 1.3433490821293421, 14.62260205405099, 74.91594968523297, 54.2017160143171, 63.956965991428916, 69.87533732822963, 65.32302352360317, 70.39360346112932, 69.03361170632499, 65.91687910897392, 69.60917963300432, 73.90905148642403, 72.54658617292131, 78.8116865158081, 84.19348321642194, 85.3947503226144, 81.31342015947614, 81.02780750819615, 82.47757693699428, 85.91634464263916, 79.3980519430978, 82.7049845286778, 80.12069238935197, 78.54443795340401, 76.12134402138847, 74.93908718654087, 77.00785078321184, 77.29356070927211, 73.30608681270054, 71.30773626055036, 76.45109163011823, 71.59544031960624, 75.0180743081229, 77.18562044416154, 75.66481263296944, 75.07718958173479, 73.34944357190813, 72.97574165889195, 75.87641307285854, 70.59709535326276, 66.19651630946568, 71.03019741603306, 63.067547934395925, 60.26331056867327, 57.76921994345528, 58.69278839656285, 57.39466340201241, 57.28824479239327, 50.29816246032715, 56.63260235105242, 63.56396893092564, 63.99617467607771, 64.52482141767229, 69.16202136448452, 72.01567431858608, 69.2747003010341, 68.72199889591762, 68.11231531415666, 68.48875481741769, 68.28625651768276, 65.83976800101144, 69.85504858834403, 69.62222140175956, 67.53114019121442, 70.58209419250488, 72.88884053911481, 71.59610039847237, 71.71417808532715, 69.69753987448556, 69.71867629459926, 70.60227176121303, 69.85033770969936, 69.76015009198869, 74.3705369404384, 71.82683617728097, 74.57860769544328, 70.99485192980084, 70.25418785640171, 71.37620380946568, 72.90977546146938, 69.68625599997384, 69.94234575544084, 73.06883362361363, 73.29110649653843, 63.29359367915562, 59.01678984505789, 53.56974261147635, 63.30704539162772, 75.79708548954555, 90.91312776293073, 69.34063870566231, 71.73974050794328, 55.63548026766096, 33.42707123075213, 16.893681560243877, 0.6327656603285244, 0.1552072994943176, 0.12588265804307802, 0.43914805405906265, 0.040537480131856034, 0.09513449083481516, 0.04804114784513201, 0.13980660374675477, 0.0520530811377934, 1.4699004228625978, 61.489869117736816, 82.19926684243339, 82.02909851074219, 66.33927399771554, 38.350335461752756, 28.024655750819615, 27.965955632073538, 32.84860937935965, 49.628529821123394, 48.22816555840628, 62.476555006844656, 62.24340125492641, 69.08903053828648, 39.24712208339146, 1.2329843299729484, 0.013647076274667467, 0.05887552683374711, 0.045751081979168315, 0.04529425149251308, 0.0732840211795909, 0.049807706980832984, 0.10971318890473672, 0.16593788298113005, 0.07900718586253268, 0.061300828121602535, 0.169564584802304, 0.060536655198250494, 0.06886650036488261, 0.07287104441119091, 0.017881562268095355, 0.11744837276637554, 0.14291156642138958, 0.10968796097274337, 0.11538946681788989, 0.13920240902474948, 0.14010737117912087, 0.19344590976834297, 0.15308566976870808, 0.17484763131609984, 0.08943238109350204, 0.10092191278402295, 0.07449830030756337, 0.20555913049195493, 0.22181395255029202, 0.10146626750273363, 0.5220721172434943, 0.15303829445370606, 46.45675359453474, 100.24917902265275, 78.87350463867188, 95.73209953308105, 89.96529620034354, 64.23780523027692, 90.67579814365932, 110.06999914986747, 65.7235941205706, 95.01678943634033, 87.84802722930908, 97.5957453591483, 16.242543288639613, 0.32191009500197, 0.10163282749376126, 0.2775952172066484, 0.19970900512167386, 0.3263454612876688, 0.3158283584884235, 0.7492823366607938, 1.039251399891717, 0.6248955226370266, 3.3396429674965993, 12.400153858321053, 4.293778717517853, 15.694802897317068, 88.05542400905064, 64.33571229662213, 77.23536259787423, 79.57579381125313, 73.50858511243547, 78.42934799194336, 75.12489591326032, 74.37316335950578, 75.28902626037598, 78.90707833426339, 78.20317023141044, 79.59535993848527, 86.69860063280377, 91.78964301518032, 84.95078127724784, 85.61375059400285, 83.25009155273438, 89.24398980821881, 84.19130843026298, 89.41495023454938, 86.29326357160295, 85.32009887695312, 79.82995196751186, 78.96829891204834, 82.2784902027675, 79.65413475036621, 75.91974898747036, 74.3181961604527, 81.36390577043805, 76.7096757888794, 77.82246453421456, 79.28277438027519, 80.13155937194824, 78.22423022133964, 75.79837785448346, 76.7577156339373, 79.03700964791435, 70.1810302734375, 69.56118147713798, 75.63560935429165, 65.62001037597656, 57.72484874725342, 56.28588376726423, 57.28680304118565, 55.22178452355521, 55.88288130078997, 50.14227615083967, 59.66946193150112, 65.84563228062221, 65.49574184417725, 68.64221273149762, 72.45808696746826, 76.46976838793073, 73.74336474282401, 73.71380710601807, 72.60878644670758, 72.83525603158134, 74.91335105895996, 69.01071739196777, 73.88346127101353, 73.22605051313127, 72.11583954947335, 74.78329467773438, 79.82931968144008, 75.62124742780412, 74.74941526140485, 71.23222323826381, 71.25414480481828, 71.33278451647077, 72.74725014822823, 72.90067332131522, 77.93304511478969, 75.865448815482, 77.18282726832798, 74.82979897090367, 74.52876131875175, 75.32043211800712, 74.81331784384591, 69.19364261627197, 72.83791719164167, 73.76279190608433, 74.687819480896, 65.9883621760777, 66.50476619175502, 61.542140415736604, 70.50202315194267, 75.11067989894322, 83.7481245313372, 71.24532754080636, 76.08240631648472, 62.16972255706787, 53.510460581098286, 16.344304868153163, 0.9371826882873262, 1.255223342350551, 0.14004683228475706, 0.2570481997515474, 0.1601061187684536, 0.5191435601030077, 0.35298067490969387, 0.2709878874676568, 0.10839907013412033, 3.760698590959821, 75.13556834629604, 86.62916728428432, 86.48178209577287, 76.61917550223214, 48.26121813910348, 79.74118178231376, 68.01954296657017, 36.62507343292236, 52.77858945301601, 46.79859801701137, 64.43354293278286, 73.60060705457414, 81.99715764181954, 51.00638539450509, 1.5527786442211695, 0.14403417546834263, 0.29819583892822266, 0.156523019607578, 0.21896966945912155, 0.1877825850886958, 0.23910936234252794, 0.24094618377940996, 0.2291519966508661, 0.17715451467250073, 0.17481310745435102, 0.24137241233672413, 0.2147177111889635, 0.12064007935779435, 0.1896990801074675, 0.18614101888878004], [0.054398403503000736, 0.12708416714199952, 0.02858879736491612, 0.1324653433901923, 0.08541848683463675, 0.0833964864058154, 0.06870209132986409, 0.04802838120875614, 0.036681565788707564, 0.09010934191090719, 0.10175980853715114, 0.06035883831126349, 0.07370164591286864, 0.035572693683207035, 0.030548077409288714, 0.07478124941033976, 0.2670394107699394, 19.088396889822825, 51.70716333389282, 57.57705361502511, 55.441444873809814, 43.21646465573992, 51.97242818559919, 26.111978224345616, 37.41866888318743, 59.20280701773507, 79.57461261749268, 75.39920384543282, 22.5061845098223, 0.27091978969318525, 0.08785419684967824, 0.1614218931645155, 0.054865418800285885, 0.10412381775677204, 0.03722719615325332, 0.45448451968176024, 0.09680948845509972, 0.40185082969920977, 0.1528067918760436, 0.48793257772922516, 0.5230440508042062, 2.3828299897057668, 54.29564871106829, 58.006462710244314, 42.63206556865147, 39.75393411091396, 52.96400213241577, 54.19536188670567, 56.11216490609305, 53.999613761901855, 64.42753968920026, 71.38305473327637, 72.3759662083217, 73.78324045453752, 80.96671894618443, 78.449449130467, 81.07684789385114, 77.30100222996303, 84.38665703364781, 80.91225201742989, 81.20481286730084, 79.05773612431118, 79.81568036760602, 74.57480008261544, 74.78228024074009, 73.68959263392857, 76.09371798379081, 75.03424971444267, 77.89308602469308, 74.76033088139125, 74.54199763706752, 71.70051792689732, 71.53624861580985, 71.2373857498169, 67.69174085344586, 69.3569530759539, 68.84656620025635, 68.13952445983887, 68.75997774941581, 68.37533937181745, 63.30698980603899, 60.685677664620535, 65.11860752105713, 57.96442263466971, 56.154145921979634, 58.49539702279227, 58.76355579921177, 59.79093033926827, 66.70902238573346, 63.098460469927105, 60.290429387773784, 59.57743304116385, 65.50187710353306, 62.881037439618794, 66.59075709751674, 68.77762617383684, 68.05121980394635, 66.89294120243618, 65.44636794498989, 66.40041814531598, 66.2119482585362, 65.84786265236991, 64.87800530024937, 65.50778307233537, 67.30847127096993, 68.35472406659807, 69.02404403686523, 67.42076110839844, 70.08494363512311, 67.75117574419293, 65.36205155508858, 66.79104587009975, 70.2349066053118, 68.04684938703264, 72.02561024257115, 67.95460510253906, 67.04088224683488, 70.77964537484306, 66.84185109819684, 65.1675853729248, 66.183974811009, 68.46770177568708, 69.60575417109898, 68.04029028756278, 73.226564679827, 69.61452974591936, 58.84769153594971, 47.69958829879761, 51.58029270172119, 66.73605782645089, 95.10251631055559, 76.46550219399589, 59.1906407220023, 55.77268981933594, 23.275839941842214, 26.043766021728516, 3.363033643790654, 0.3326967390520232, 1.1832048296928406, 0.9608500983033861, 0.05194174371925848, 0.2854821282838072, 0.5396829779658998, 0.05157453753054142, 0.053873237754617415, 0.06891996892435209, 5.128619543143681, 65.46664278847831, 74.364394732884, 80.72401142120361, 54.41307674135481, 50.07982574190412, 42.26759433746338, 35.60706853866577, 27.461085626057216, 39.06698308672224, 29.606100491115026, 48.22818987710135, 55.58858687537057, 66.24951022011894, 31.271660123552593, 1.0086807374443327, 0.0809087734669447, 0.024576297495514154, 0.04583274366866265, 0.10443792518760477, 0.2291205669088023, 0.25066465086170603, 0.11438313153173242, 0.15017243394894259, 0.1792223094297307, 0.24990135324852808, 0.19559713719146593, 0.060462409896509986, 0.13895566655056818, 0.05580951546185783, 0.03522348224318453, 0.08015537567968879, 0.004083209155526544, 0.035521694991205416, 0.09928395639040641, 0.0559372971765697, 0.08127928072852747, 0.011963806464336812, 0.059440020471811295, 0.027881840210674063, 0.01180535666311958, 0.06580791555877243, 0.05322269569816334, 0.0495885130284088, 0.07524956749486071, 0.15624734440020152, 0.18921860946076258, 29.663652420043945, 68.57001399993896, 71.57672187260219, 78.29296875, 58.35445281437465, 59.85221345084054, 32.46801137924194, 44.09746149608067, 67.26639298030308, 88.30099419185093, 85.6981086730957, 23.53146243095398, 0.3608113218631063, 0.025685298522668223, 0.23031907688294137, 0.037077531684190035, 0.08678479851888758, 0.09792978369763919, 0.3525695098297936, 0.07095667999237776, 0.7455335663897651, 0.03129805877272572, 0.31589965894818306, 0.2976409601313727, 4.418126719338553, 69.61191722324916, 69.21340329306466, 60.12467316218785, 53.20386784417288, 63.46424838474819, 63.152982984270366, 64.89675154004777, 59.706502778189524, 70.27446964808873, 75.00330243791852, 77.45756598881313, 79.2202683857509, 83.98739269801548, 80.89783450535366, 85.4808315549578, 82.96848801204136, 85.12346485682896, 80.90023163386753, 82.57057857513428, 82.63732991899762, 81.67289216177804, 75.20140252794538, 75.304381779262, 78.82769516536167, 80.13302544185093, 77.9849967956543, 81.5759995324271, 77.53268991197858, 81.07588209424699, 77.22817121233258, 78.02046734946114, 72.26644175393241, 73.30332837785993, 71.57900088174003, 71.04619216918945, 70.4335833958217, 72.98876258305141, 71.75800732203892, 65.54690143040249, 61.686454500470845, 67.53009796142578, 63.70624719347273, 59.686686515808105, 59.826289721897666, 59.232580048697336, 58.48902552468436, 70.27106503077916, 66.32596819741386, 62.518897329057964, 61.41023581368582, 65.25320107596261, 65.81149578094482, 68.3160434450422, 70.1990191595895, 72.35028566632951, 72.57071031842912, 69.47713606698173, 67.73877320970807, 68.4987324305943, 65.50869328635079, 65.88825947897774, 69.07714217049735, 68.90403475080217, 71.68375192369733, 70.58230263846261, 70.54091221945626, 72.07286494118827, 70.86817932128906, 69.38713605063302, 68.432252066476, 69.97338335854667, 69.47161224910191, 72.63518265315464, 71.40929807935441, 68.338180405753, 73.09826619284493, 70.75998892102922, 69.91064807346889, 72.0239565713065, 71.40467752729143, 72.42881420680455, 69.64059938703264, 68.462386403765, 73.69680486406598, 69.6769871030535, 59.4163043158395, 56.68666975838797, 62.02112143380301, 77.7400450025286, 83.1465425491333, 66.33972563062395, 71.69325705936977, 48.13489988871983, 31.664580753871373, 7.191828055041177, 0.3830276440296854, 0.8781041641320501, 0.27675280241029604, 0.03797481282215033, 0.23183978242533548, 0.13992294536105224, 0.03732150234282017, 0.06987247602748019, 0.1518758282597576, 6.46843329497746, 74.05830574035645, 83.58527265276227, 86.76040485927037, 60.789136341639924, 59.89673055921282, 24.108254977634974, 34.54414701461792, 38.29133483341762, 54.797732489449636, 43.08045366832188, 68.84399536677769, 67.5490665435791, 76.85250295911516, 46.23471001216343, 0.8458127911601747, 0.020057269538353597, 0.042388540626104386, 0.06843423284590244, 0.022039317825276936, 0.12320537599069731, 0.10522295627743006, 0.01863226287865213, 0.04190123034641147, 0.13614354601928166, 0.0867287175995963, 0.1534737782286746, 0.03426352482555168, 0.10245298634150199, 0.07473114638456277, 0.17719825303980283, 0.18744322258446897, 0.17042964909757885, 0.14968007536871092, 0.13283992186188698, 0.18864535593560763, 0.17814347946218081, 0.13678002543747425, 0.15398011463029043, 0.15967571043542453, 0.17187154958290712, 0.15556429033832891, 0.09976885787078313, 0.2089277311627354, 0.14932009897061757, 0.23580763808318547, 0.3801855593919754, 45.53442192077637, 86.02001176561627, 87.15453447614397, 79.67854377201625, 65.89452675410679, 82.97302518572126, 40.756753717150005, 53.51977811540876, 80.71461050851005, 101.21314430236816, 95.82394082205636, 31.390029634748185, 0.6451054438948631, 0.2099097477538245, 0.33650120347738266, 0.10500081748302494, 0.2562584935554436, 0.2269229276904038, 1.020568128143038, 0.8689720598714692, 0.8879397192171642, 0.3952128030359745, 2.43855910216059, 1.853294095822743, 4.079911862100873, 81.8174216406686, 76.32303633008684, 68.78016921452114, 62.07191971370152, 74.20180688585553, 70.5868398121425, 73.36195727757045, 68.44092341831752, 76.03920241764614, 82.28593172345842, 84.53371565682548, 80.65655136108398, 88.05336039406913, 84.25916453770229, 88.28761196136475, 84.28524112701416, 90.60982499803815, 84.4961884362357, 87.76894283294678, 86.50721945081438, 86.71392835889543, 79.93991415841239, 81.86728886195591, 81.96240275246757, 82.7887659072876, 81.36448941911969, 86.20826625823975, 81.1791809626988, 83.42663138253349, 79.43311950138637, 78.85728754316057, 75.8839032309396, 75.66333961486816, 74.53270789555141, 74.18756307874406, 72.40036133357457, 76.31164823259626, 74.74517686026437, 67.14798177991594, 62.728545325142996, 72.12587274823869, 63.90058830806187, 61.22662271772112, 60.738664627075195, 60.74946212768555, 60.12805693490164, 71.33277062007359, 70.81130831582206, 67.6560479572841, 61.28879519871303, 70.23054313659668, 69.52671841212681, 71.40043217795235, 73.2098890032087, 76.74776581355503, 74.00344276428223, 72.64368030003139, 74.10601902008057, 72.41674518585205, 70.46330778939384, 70.26400566101074, 71.69375038146973, 71.53583867209298, 73.91675009046281, 73.59729971204484, 73.91647911071777, 77.29813262394497, 74.39680807931083, 70.3622601372855, 72.4742762701852, 72.76674679347447, 72.90068026951381, 75.83804512023926, 74.39927468981061, 71.04064055851528, 77.53935323442731, 73.21658706665039, 72.79526220049176, 74.89599445887974, 73.1595493044172, 73.10465853554862, 72.29806300571987, 70.81977816990444, 73.50553485325405, 68.08985873631069, 63.71002006530762, 63.759546824863975, 68.23128931862968, 75.78960227966309, 75.67966093335832, 68.19840349469865, 76.18574687412807, 61.00796290806362, 47.66023717607771, 5.029287227562495, 1.3924250773021152, 5.926934557301657, 2.3631987231118337, 0.11954611805932862, 1.5090091185910361, 1.3988590006317412, 0.3663399980536529, 0.19536016562155314, 0.401057486555406, 18.707229137420654, 93.01775101252964, 85.53238718850272, 91.3274974822998, 71.95582948412213, 71.35300377437046, 63.51285103389195, 57.543771743774414, 37.54071399143764, 53.110261712755474, 45.61472225189209, 74.31911332266671, 74.10512965066093, 94.77620806012834, 57.08450971330915, 0.9993321533714021, 0.14023383653589658, 0.13921129783349379, 0.150359981028097, 0.1070863220042416, 0.2116330774234874, 0.4653715597731726, 0.1889605083103691, 0.1962864337755101, 0.21822421731693403, 0.2052965917225395, 0.24179959084306443, 0.10437040416789906, 0.2216872429209096, 0.20395899564027786], [0.025039570672171454, 0.07825467695615121, 0.0523855293701802, 0.11969038817499365, 0.16311462090483733, 0.07111344872308628, 0.15784042248768465, 0.01372072531376034, 0.011677435000560113, 0.03301797880391989, 0.07024253545595066, 0.011618159877668535, 0.11202552768268756, 0.009878113649652472, 0.06805217013295208, 0.08177886570670775, 0.5741951689124107, 22.35745484488351, 55.11750248500279, 48.074422768184114, 52.41758189882551, 51.00931058611189, 28.223322119031632, 32.739314215523855, 52.6736091205052, 74.5241060256958, 82.90063190460205, 34.268244470868794, 1.3201396018266678, 0.049535153034542284, 0.05633577365162117, 0.04763691060777221, 0.17628407637987817, 0.07865674966680151, 0.2650222618665014, 0.1675650370972497, 0.1101617141227637, 2.2110868053776875, 0.3495358611856188, 0.60562871077231, 0.8168153528656278, 31.877560411180767, 56.321267468588694, 40.16668142591204, 49.517935344151084, 43.554195744650706, 50.525806290762766, 48.77319962637765, 58.547779491969514, 62.98553834642683, 75.10532978602818, 70.59631020682198, 77.44409343174526, 80.8410746710641, 79.41704136984688, 80.34240245819092, 82.81614875793457, 78.05442319597516, 78.2851311819894, 76.97897406986782, 80.22252518790108, 76.2451400756836, 71.98092637743268, 79.46711008889335, 80.70574460710797, 82.90803868430001, 80.24298763275146, 77.33357538495744, 74.99808434077671, 74.68945925576347, 73.17316082545689, 73.15604046412876, 72.13610744476318, 69.59053761618478, 69.97751753670829, 67.7818798337664, 69.63091359819684, 69.86708981650216, 70.53864710671562, 68.02340616498674, 65.43261745997837, 64.32593618120465, 64.3532634462629, 60.162721497671946, 58.65567806788853, 56.524481432778494, 54.124570165361675, 51.497897488730295, 56.83356509889875, 50.53178868974958, 52.250446455819265, 59.385989325387136, 56.976788316454204, 65.61910016196114, 66.79147665841239, 66.85937445504325, 67.8174615587507, 68.72037301744733, 64.37016841343471, 64.0245441709246, 63.07336357661656, 66.9613948549543, 67.33704226357597, 69.37212794167655, 68.30746936798096, 68.85484150477818, 69.57559204101562, 72.02479035513741, 70.96293190547398, 70.24933801378522, 67.80694893428257, 64.2631036213466, 62.89423206874302, 65.7075229372297, 67.69620159694126, 72.6526712690081, 67.07628331865583, 65.37175124032157, 67.80325944083077, 68.02703312465123, 68.87976469312395, 64.64321872166225, 66.66286550249372, 69.52738543919155, 66.11688995361328, 69.65435682024274, 70.32635879516602, 61.00165394374302, 54.60632004056658, 58.456368991306846, 69.57854502541679, 86.88026823316301, 73.0537907736642, 56.55956288746425, 44.98663636616298, 25.109667573656353, 25.202290534973145, 0.26987430293645176, 0.27580540467585835, 1.1946849908147539, 0.10678718984127045, 0.08629061467945576, 0.025865337611841302, 0.13540753908455372, 0.10535037836858205, 0.06729535931455237, 0.514723040163517, 6.435302981308528, 66.90095942361015, 75.73765059879848, 80.47755881718227, 57.041729654584614, 52.37336703709194, 44.626785687037874, 39.15528079441616, 23.60014189992632, 38.842994008745464, 35.361383710588726, 48.404225962502615, 50.362756388528005, 62.24554130009243, 13.870180760111127, 0.32406023676906315, 0.2159864902496338, 0.096629317051598, 0.10977821970092398, 0.053035569310720475, 0.29384805794273106, 0.2796027309128216, 0.20613846369087696, 0.20624058321118355, 0.18686188092189177, 0.07998374703207187, 0.19971279134707792, 0.061120432801544666, 0.14314543030091695, 0.07086353749036789, 0.06658552347549371, 0.11902481317520142, 0.07027995666222912, 0.08628733735531569, 0.05655783780717424, 0.062775664696736, 0.11927749961614609, 0.01272023984763239, 0.027791332120874097, 0.05347045258219753, 0.030406015925109386, 0.0505097905573036, 0.150863521865436, 0.06542833628399031, 0.10524352267384529, 0.7058006184441703, 32.9663222857884, 70.50331551688058, 63.77676446097237, 69.85675089699882, 59.58468696049282, 41.31194257736206, 35.7872040612357, 57.69282797404698, 80.74189608437675, 92.1861767087664, 41.53805085590908, 1.23745473580701, 0.021037871383928826, 0.09010285511612892, 0.038006198459437916, 0.20105821772345475, 0.07152457309088536, 0.033407834491559436, 0.12552698355700287, 0.15201370657554694, 3.829730246748243, 1.088435309273856, 0.2399749830365181, 1.2204894061599458, 40.30165018354143, 66.02915505000523, 50.46999141148159, 59.5012321472168, 55.94379963193621, 61.05282742636544, 59.972333908081055, 66.53991712842668, 69.25314004080636, 78.28008678981236, 73.31451497759137, 82.98887402670724, 84.06116172245571, 82.03328132629395, 84.63440895080566, 85.69944272722516, 81.11881501334054, 80.86781133924211, 80.51571137564522, 82.96486800057548, 75.61372947692871, 77.51912008013043, 80.52500806535993, 80.74475874219621, 83.25213432312012, 84.68097577776227, 79.80869742802211, 77.24556950160435, 76.56649426051548, 77.47317164284843, 77.07617936815534, 76.16233839307512, 72.20360919407436, 74.58907863071987, 73.23077528817313, 72.99775355202812, 73.43867928641183, 74.02995014190674, 70.26789665222168, 68.51139204842704, 64.1781896863665, 62.810902323041645, 61.34806333269392, 63.496161460876465, 62.19349929264614, 58.90502112252371, 57.46368680681501, 61.003766196114675, 59.684025355747764, 57.76818813596453, 60.519191878182546, 60.93176201411656, 66.41383511679513, 68.13806533813477, 65.78280666896275, 70.23115457807268, 70.07366670880998, 69.98270089285714, 69.45959186553955, 67.14910043988908, 69.93028368268693, 68.71411963871547, 70.8132677078247, 71.08308015550885, 71.57046154567173, 71.62683922903878, 71.39362294333321, 71.73362609318325, 71.38952350616455, 72.04474558149064, 68.1549425125122, 66.90438488551548, 66.51846803937639, 69.36946678161621, 73.7194629396711, 72.35188375200543, 67.03904792240688, 71.0331642968314, 68.9087039402553, 70.8144975389753, 68.7752707345145, 67.74365084511894, 71.34633350372314, 68.53306347983224, 66.13636575426374, 71.3282334463937, 69.4722375869751, 65.11392443520683, 63.63945416041783, 65.77683121817452, 74.09097617013114, 80.746461050851, 66.25459630148751, 67.19359670366559, 42.95018884113857, 32.14921065739223, 0.755653726203101, 0.2811651256467615, 0.7333393150142261, 0.09640780250941004, 0.0759031188541225, 0.028206987406260202, 0.08550917303987912, 0.03950126894882747, 0.1318963917770556, 1.1791415448699678, 8.290919729641505, 73.73394298553467, 85.59161363329206, 87.25441483088902, 66.47905090876988, 53.0875688961574, 13.856175797326223, 30.62926094872611, 35.96238204411098, 50.38996206011091, 47.16244738442557, 71.55562019348145, 56.82789189474923, 75.68592820848737, 21.50393291882106, 0.3555992772536618, 0.2539366010044302, 0.0543067028879055, 0.09062008200479404, 0.06995702149080378, 0.07308158025677715, 0.06266713302050318, 0.14202489757112094, 0.08573029403175626, 0.18188279095504964, 0.09884210117161274, 0.14225787935512407, 0.06739102596683161, 0.08359864234392132, 0.13369799724646977, 0.18903472647070885, 0.16149137515042508, 0.19102940229432924, 0.22153971583715507, 0.13595738315156528, 0.197987059663449, 0.11683188298983233, 0.10577434740428414, 0.12305997950690133, 0.1671910285949707, 0.1785510347357818, 0.17895880714058876, 0.23495963215827942, 0.13211136524166378, 0.2985780712749277, 0.9349342946495328, 47.01822362627302, 87.60477079663957, 75.25372246333531, 81.86764322008405, 76.40581021990094, 43.861889771052766, 46.12814549037388, 78.02437223706926, 91.98260143824986, 103.68771048954555, 50.17024959836687, 2.1620705212865556, 0.16179132834076881, 0.2720603799181325, 0.19207507904086793, 0.4945916661194393, 0.08129615589444127, 0.9312264536108289, 0.8121918152485574, 0.43519642895885874, 5.7076203141893656, 1.4306041257722037, 1.1759020558425357, 1.4718884761844362, 43.40098449162075, 77.13628128596714, 58.2940034866333, 73.73198359353202, 65.95397554125104, 70.03836985996791, 67.74579089028495, 74.02530874524797, 73.26679474966866, 86.76361492701939, 80.97010271889823, 85.28978388650077, 87.30921527317592, 86.58629689897809, 88.5334392275129, 90.9428243637085, 82.22202914101737, 86.1229840687343, 84.2337132862636, 88.25049468449184, 79.37736020769391, 78.51056548527309, 85.6005768094744, 86.45742865971157, 88.2678999219622, 88.8032933643886, 84.36069161551339, 82.21033532278878, 78.97691467830113, 80.29582868303571, 78.63070678710938, 79.31183869498116, 74.99342209952218, 77.44155733925956, 74.57762799944196, 75.4642389842442, 75.88121427808488, 77.06619480678013, 72.24083764212472, 70.12258897508893, 64.4212098802839, 65.19533647809709, 61.14311926705496, 66.82753780909947, 64.16037450517926, 61.05375153677804, 54.35327707018171, 60.37955393110003, 57.75828000477382, 57.09866319383894, 62.13996342250279, 61.82994869777134, 70.25432682037354, 72.36815643310547, 70.89048303876604, 75.16246482304165, 74.39243766239711, 72.33757741110665, 70.12182467324394, 68.80261189596993, 72.74741690499442, 71.76196084703717, 74.66970552716936, 73.50305434635708, 73.5486831665039, 75.35843876429966, 77.69975934709821, 75.55001449584961, 74.45776462554932, 74.50508185795375, 69.92787960597447, 70.55435698372978, 68.76586287362235, 73.45710590907505, 77.69119916643415, 73.97605296543666, 69.04821681976318, 75.86328792572021, 72.2583748953683, 75.00665841783795, 68.84555871146065, 70.67751380375454, 74.78232192993164, 69.8502334867205, 68.22216633387974, 72.02577699933732, 68.33688804081508, 67.37501416887555, 68.12684399741036, 66.44856916155133, 72.63437666211809, 77.0799036026001, 67.0362616947719, 71.75765296391079, 58.10257019315447, 44.13720866612026, 0.38401512961302486, 1.7641604329858507, 6.041304077420916, 0.3172752394207886, 0.33867012709379196, 0.2109851036220789, 0.3313147803502423, 0.22078236219074043, 0.2694011740386486, 4.090005423341479, 24.28988262585231, 89.13862037658691, 89.75700310298375, 92.64342376164028, 71.25762585231236, 73.21646894727434, 63.550836835588726, 59.08193615504673, 37.07098797389439, 59.735393387930735, 51.547830717904226, 71.39682606288365, 69.3417295728411, 90.25161061968122, 25.726916006633214, 0.4563669115304947, 0.5892002380320004, 0.15434564144483634, 0.19546783555831226, 0.1638196866427149, 0.3466733662145478, 0.226692795753479, 0.1813934314996004, 0.21982348364378723, 0.2785283928470952, 0.08490362124783651, 0.23378150537610054, 0.16437616678220884, 0.17382826815758431], [0.09047385770827532, 0.028494263866118023, 0.08164085168391466, 0.03996980416455439, 0.1388236643480403, 0.13970254361629486, 0.10445519390382937, 0.016150785676602806, 0.08880985235529286, 0.017754420072638562, 0.06252778228372335, 0.03884503398356693, 0.06380435771175794, 0.07124392422182219, 0.019416014929967265, 0.08454826567322016, 1.0859888919762202, 27.102450881685527, 59.71006720406668, 51.26491744177682, 60.031879970005576, 40.2375738961356, 44.89363472802298, 37.00840207508632, 62.8060941696167, 84.80473014286586, 58.75068078722273, 3.717275389603206, 0.15003288643700735, 0.07582742148744208, 0.16484842715518816, 0.10940626037440129, 0.0626260070130229, 0.09352578608585255, 0.24916812830737659, 0.11642235996467726, 0.28232873177954126, 3.364434140069144, 1.6200910551207406, 0.754955595093114, 10.126340235982623, 63.531868253435405, 50.269911084856304, 47.941611426217214, 45.0594048500061, 48.21546425138201, 48.31873532703945, 56.435884952545166, 62.38977895464216, 71.68670490809849, 67.88034970419747, 75.34418106079102, 83.94497394561768, 79.59756251743862, 78.60072531018938, 80.7270894731794, 78.35633632114956, 75.27020359039307, 75.55458641052246, 77.64195728302002, 76.22695663997105, 74.82966000693185, 80.14800575801304, 79.84930270058769, 81.81708812713623, 78.78834751674107, 76.37290355137416, 77.17740767342704, 74.96514987945557, 76.53740910121373, 75.94514465332031, 73.14428411211286, 71.9859846660069, 70.9857428414481, 70.77180085863385, 71.53648485456193, 71.03648553575788, 71.43017741612026, 67.47968878064836, 65.14833191462925, 64.14854867117745, 60.60070814405169, 61.97948782784598, 58.250188146318706, 59.554483141217915, 55.43783875874111, 58.969104358128135, 66.42858614240373, 62.37003912244524, 65.87294564928327, 57.9735768863133, 57.82532664707729, 62.191095215933665, 63.63293675013951, 67.20110770634243, 66.02784184047154, 67.76037515912736, 64.58594472067696, 65.4515026637486, 66.62320518493652, 66.31396171024868, 68.45593847547258, 70.42616966792515, 70.64453070504325, 71.46853147234235, 67.99995599474225, 68.83610916137695, 67.07895142691476, 68.35125691550118, 70.37214047568185, 70.71347073146275, 69.11198738643101, 67.25199631282261, 65.29445253099713, 65.1338449205671, 63.95911993299212, 69.57405648912702, 68.96212863922119, 65.58733299800328, 59.78833171299526, 65.17333153315953, 66.13446194784981, 65.33541910988944, 62.10686220441546, 68.48332132611955, 67.74575614929199, 66.5326840536935, 68.59337384360177, 63.72781440189907, 57.97486925125122, 63.67231913975307, 67.57548359462193, 80.75021307809013, 66.75592967442104, 56.910519872392925, 37.91259547642299, 27.040565013885498, 11.603245854377747, 0.4412234755499022, 0.09209285583347082, 0.1653704648571355, 0.04294063742937786, 0.056050280042524846, 0.08751693780400924, 0.049287708276616674, 0.23447295970150403, 0.3972305219088282, 0.8551424848181861, 11.307992577552795, 68.80553013937813, 72.51742458343506, 76.37494632175991, 43.6305182320731, 59.767841475350515, 44.52473054613386, 35.72981194087437, 56.24409730093819, 36.39540072849819, 24.255247592926025, 45.04596355983189, 54.84624828611101, 48.41332810265677, 1.6833642827613013, 0.06548333154725176, 0.06906311267188617, 0.14761405837322983, 0.20607883403343813, 0.07492209292416062, 0.3098144754767418, 0.24888154225690023, 0.1877302157559565, 0.14993593735354288, 0.10156184594546046, 0.21048709963049206, 0.08899501777653183, 0.07566795218735933, 0.02672029343167586, 0.028927762926157032, 0.060761806688138416, 0.022260800137051513, 0.07902357248323304, 0.07561653280364615, 0.12742386891373567, 0.044635305779853036, 0.03518354367198689, 0.019947591137939265, 0.03418023465201259, 0.056786259835852046, 0.010448589422074812, 0.08054797604147877, 0.014946365662451302, 0.11124999608312335, 1.533624306321144, 38.61060108457293, 74.27775764465332, 69.48056152888707, 79.09733390808105, 61.609628268650596, 27.529853684561594, 26.849449600492203, 73.08301489693778, 91.10042340414864, 68.18022005898612, 3.623563515288489, 0.08978133808289256, 0.02400570043495723, 0.013919820210763385, 0.1607870286596673, 0.06422876100987196, 0.10508589898901326, 0.2211763739053692, 0.32871485128998756, 0.3563851836536612, 5.6272309592791965, 1.948106825351715, 0.42974081741912024, 16.934934752328054, 74.15451049804688, 59.860127449035645, 59.640883990696494, 55.17362308502197, 61.89360809326172, 57.20434182030814, 67.38060746874127, 68.76761381966728, 75.54593590327671, 74.37833281925747, 79.25397409711564, 84.64265646253313, 82.4326776776995, 83.39812292371477, 86.12701402391706, 79.59031554630825, 77.70945208413261, 81.29294381822858, 79.80349322727749, 76.48822975158691, 79.39632184164864, 82.68148572104317, 82.55128342764718, 80.08266489846366, 80.05314895084926, 79.38901928492955, 80.50230830056327, 77.5087742124285, 79.55041204180036, 77.57914556775773, 76.44494942256382, 76.49630355834961, 76.9875134059361, 72.53919328962053, 73.4310223715646, 76.05960232870919, 74.5533093043736, 68.6298518862043, 66.153076171875, 65.17120538439069, 63.16139030456543, 63.66740676334926, 60.12228993007115, 59.65674672807966, 62.70025226048061, 65.68577507564, 69.70019408634731, 65.85045433044434, 64.73729733058384, 57.91387448992048, 59.65652438572475, 63.962677410670686, 65.41895035334996, 69.86930629185268, 68.35812173570905, 70.13264301845005, 66.51509816305978, 68.23554161616734, 70.86181477137974, 69.105379649571, 67.99145139966691, 71.46061747414726, 71.88896002088273, 73.20510864257812, 71.41079889025006, 70.16637652260917, 70.87254279000419, 69.60562215532575, 71.10631493159703, 71.89282321929932, 70.37000043051583, 70.96878228868756, 69.9828884942191, 66.17232963017055, 65.33535657610211, 68.874650818961, 72.01176943097795, 69.16323729923793, 63.29045309339251, 67.68937151772636, 71.44212136949811, 68.5640732901437, 66.31241921016148, 70.95613656725202, 70.1486725125994, 65.30507632664272, 67.0904506955828, 70.41546944209507, 66.24573040008545, 67.40305015019008, 65.74097851344517, 72.94857420240129, 74.13254029410226, 67.24858474731445, 58.15610258919852, 39.14990288870675, 17.925426517214092, 0.21719620962228092, 0.17874046814228806, 0.10552242092256035, 0.0633687653711864, 0.1004065450813089, 0.08350411563047341, 0.01720710185223392, 0.19191757749233926, 1.121186077594757, 0.7473151279347283, 11.672594087464468, 77.970614024571, 81.35151018415178, 84.14505427224296, 51.61415127345494, 50.571838106427876, 21.697570528302872, 35.190951347351074, 62.98224490029471, 53.308789116995676, 36.857299600328716, 65.22704110826764, 65.26108033316476, 61.96363203866141, 2.7786032898085455, 0.1422921046614647, 0.07872861331062657, 0.16885679135365145, 0.02305333921685815, 0.02532487259512501, 0.09036340577793972, 0.0915333019303424, 0.16126346880836145, 0.06533013191074133, 0.059375966766050885, 0.03375530209658401, 0.09990911105913775, 0.03630387284127729, 0.14899680417563232, 0.14277762360870838, 0.23932269375239099, 0.0892772747735892, 0.2301238759287766, 0.16425460044826778, 0.17534841730126313, 0.14016352673726423, 0.13791761653763907, 0.13937527260610036, 0.1572006589600018, 0.17463325496230805, 0.12258932047656604, 0.2556144009743418, 0.08648215832987002, 0.24291244255644934, 2.872846701315471, 54.499022483825684, 90.24413435799735, 81.19897638048444, 87.50992093767438, 65.3097038269043, 72.38328266143799, 55.01430436543056, 81.65791184561593, 100.2361650466919, 81.76556723458427, 6.955523295061929, 0.28433445415326525, 0.27478040967668804, 0.2910931786256177, 0.3027794786861965, 0.28757844865322113, 0.21897118937756332, 0.42311188312513487, 0.6941610830170768, 0.8168624703373227, 7.952601517949786, 3.4300679096153806, 1.1867390743323734, 17.50600372041975, 82.99068055834088, 68.86313765389579, 69.22022642408098, 65.22297641209194, 70.16028295244489, 68.28317846570695, 75.87010410853794, 73.9604959487915, 83.4763457434518, 79.39606475830078, 81.17459515162876, 89.21651663099016, 87.87312412261963, 85.41410105569022, 89.90889767238072, 81.89875725337437, 82.18734373365129, 82.96637575966972, 84.26574448176792, 82.36742714473179, 82.7811506816319, 85.22407477242606, 86.4783774784633, 85.45157269069126, 85.34431334904262, 83.48562853676933, 83.82385989597866, 80.33965791974748, 83.39690698896135, 82.53056389944894, 83.24265698024205, 79.2600885118757, 77.33163683755058, 74.3919095993042, 74.95233045305524, 80.4695405960083, 76.64055510929653, 69.92956801823208, 67.76689256940568, 68.35666261400495, 64.67235946655273, 65.02548776354108, 61.30030836377825, 64.61184065682548, 62.66450377873012, 65.49151733943394, 70.03557668413434, 64.135833467756, 64.36462375095913, 58.21651717594692, 60.88277721405029, 68.15531076703752, 68.66443307059151, 74.10936110360282, 72.1815208707537, 73.012296131679, 70.89108058384487, 71.65782124655587, 74.3465656552996, 73.57077148982457, 73.83134978158134, 75.89722987583706, 74.22615337371826, 77.92804936000279, 74.44682816096714, 72.66528224945068, 73.50651454925537, 73.01697226933071, 76.04508754185268, 75.10412774767194, 73.59259578159877, 72.47730568477085, 70.85240691048759, 68.77000399998256, 69.81527015141079, 75.37452384403774, 74.87817927769252, 72.55766854967389, 64.96100153241838, 70.97488280705043, 71.38011564527238, 71.16385991232735, 68.09018530164445, 72.7105358668736, 71.52211597987584, 67.89736584254673, 69.8326336996896, 69.72062179020473, 68.19457503727504, 70.45055089678083, 64.33262729644775, 71.29659829820905, 70.44499928610665, 69.99835518428257, 66.85845729282924, 55.93172713688442, 19.983371768678936, 0.5010660301361765, 0.38305272268397467, 0.28745196972574505, 0.2456143961421081, 0.1897933286215578, 0.3387840124113219, 0.15889699650662287, 0.31633739545941353, 2.5640494312558855, 3.084946108715875, 30.248319012778147, 88.84653200422014, 87.36972713470459, 92.74912670680455, 59.87020928519112, 94.5467438016619, 65.10292543683732, 55.82747289112636, 68.4204957144601, 50.653840746198384, 40.94392776489258, 68.90907914297921, 74.91280909946987, 75.41915907178605, 3.385527568204062, 0.299243686986821, 0.21392740788204329, 0.296453632414341, 0.25734661945274895, 0.13891342096030712, 0.2832558548876217, 0.24263361894658633, 0.2433157909129347, 0.22742353725646222, 0.19570539066834108, 0.20594162068196706, 0.1590120489043849, 0.12360576593450137], [0.08068109104143721, 0.051675418724438975, 0.05987353649522577, 0.10074961917208773, 0.05450595130345651, 0.11311786049710852, 0.026457500211628418, 0.02965298793943865, 0.0321541324790035, 0.07087317947298288, 0.06201833140637193, 0.04886857380292245, 0.04962418022166405, 0.04907452953713281, 0.05145277442144496, 0.038183431806308885, 8.87832304409572, 40.035245827266145, 58.441208021981375, 50.98581872667585, 42.35791049684797, 46.63654170717512, 49.14802714756557, 52.48143931797573, 81.46673216138566, 74.96254430498395, 12.095772385597229, 0.46144246203558786, 0.04302134916984609, 0.10562223342380353, 0.262222517813955, 0.16763704323342868, 0.21011091981615337, 0.13544766764555657, 0.1431432454181569, 0.5299281414066042, 0.22397864210818494, 2.7563951100621904, 0.0345401330185788, 2.491675691945212, 50.812721729278564, 46.25991807665144, 46.95491164071219, 56.70756646565029, 50.60372338976179, 51.46864557266235, 55.22669342585972, 62.84418419429234, 68.38328116280692, 76.84627737317766, 80.92969199589321, 75.08237293788365, 78.71491200583321, 80.17238003867013, 80.26021221705845, 79.61097254071916, 76.53149618421281, 75.39750153677804, 78.20709596361432, 73.9818616594587, 78.24442863464355, 79.34081268310547, 79.32061426980155, 80.16393797738212, 78.19092055729458, 75.5362570626395, 77.60721629006522, 78.79175908224923, 76.17216314588273, 74.96155071258545, 76.41682311466762, 76.82716287885393, 78.07080010005406, 72.31707327706474, 72.3754381452288, 70.32601833343506, 70.63432380131313, 67.93384388514927, 69.57974011557442, 69.29416220528739, 67.4953430720738, 63.73561722891671, 62.69982147216797, 62.15931415557861, 60.064876965114046, 63.90318693433489, 70.20318807874406, 63.10834775652204, 61.37262521471296, 58.424580982753206, 57.660129751477925, 60.18336459568569, 61.171565192086355, 61.791559900556294, 64.8942015511649, 65.70307609013149, 68.90850939069475, 66.41263307843889, 66.2200151171003, 62.5345516204834, 63.164739336286274, 64.4192921774728, 66.79018429347447, 68.1689292362758, 68.5302494594029, 68.13177721840995, 66.80761037554059, 69.84817681993756, 69.32401166643415, 67.88507447923932, 68.24528993879045, 67.09012413024902, 67.11828517913818, 68.7008694240025, 66.24327768598283, 67.48505973815918, 61.09200831821987, 64.224520274571, 68.27533394949776, 64.41079453059605, 63.293392181396484, 62.75533063071114, 65.00274630955288, 66.69625854492188, 65.87781633649553, 70.22444956643241, 66.19487653459821, 59.24345397949219, 65.88420867919922, 65.65268080575126, 66.14220224108014, 74.7337748663766, 64.04664639064244, 69.87662274496896, 62.29688153948103, 51.94230427060808, 34.05534471784319, 24.809394223349436, 2.0333903176443915, 0.03904735616275242, 0.11375704727002553, 0.13104461319744587, 0.047142119479498694, 0.049613842740654945, 0.20636946415262564, 0.2612603280161108, 0.9840867200068065, 0.5536568367055484, 0.8656911530664989, 28.796025650841848, 73.00918333871024, 69.96457999093192, 64.48258331843785, 40.00151579720633, 43.79789686203003, 55.90779406683785, 69.13837664467948, 43.126318727220806, 35.956972871507915, 29.122964450291224, 41.93725960595267, 67.84664399283272, 20.001952988760813, 0.19331894229565347, 0.2062422116952283, 0.03729669849521347, 0.16514411914561475, 0.05254068658021944, 0.2618706566946847, 0.17121375059442862, 0.19542629564447062, 0.21997741609811783, 0.24322492150323732, 0.1669051753623145, 0.1433342123138053, 0.007255879446997174, 0.04672973303656493, 0.024315887629719715, 0.0860729610015239, 0.0720354217503752, 0.05413216332505856, 0.07368285049285207, 0.03502043403152909, 0.06969139538705349, 0.029454146644898822, 0.06920329800673894, 0.0718171913176775, 0.06485946609505586, 0.0485770208761096, 0.03553714523358004, 0.06721819631223168, 0.10349750957850899, 10.54907819202968, 50.281479835510254, 71.43969644818986, 69.95233726501465, 46.43035738808768, 46.279192379542756, 39.119063309260774, 57.33767080307007, 90.59802000863212, 87.08011926923479, 14.154408114297048, 0.48755775498492376, 0.054774026918624125, 0.12237563622849328, 0.18008284111108097, 0.16614782171589987, 0.38198687987668173, 0.0935297826571124, 0.09238480231059448, 0.8405477936778749, 0.35353104823401993, 3.638881036213466, 0.10983332352978842, 5.047906228474208, 62.498282023838584, 59.70853165217808, 61.181056431361604, 67.39637293134416, 61.78876672472273, 60.59260654449463, 66.5124647957938, 70.29986531393868, 75.58223329271588, 80.43577235085624, 86.84601361410958, 80.28974206107003, 79.3232615334647, 82.30741555350167, 84.38152926308769, 83.95774473462785, 78.5515251159668, 77.79042639051164, 78.4076418195452, 79.06574739728654, 81.01491165161133, 81.37857341766357, 79.93956674848283, 79.62649481637138, 80.21523652757917, 78.66500309535435, 77.6904696055821, 78.33192729949951, 78.85575199127197, 78.32254723140171, 78.81140858786446, 79.33120332445417, 80.12363842555455, 77.70774282727922, 74.66302136012486, 73.42260115487235, 72.46430560520717, 72.8183649608067, 73.25004959106445, 71.66221250806535, 69.8337037222726, 67.76522500174386, 63.94043622698103, 64.78379467555455, 62.74042674473354, 66.04523318154472, 70.76011398860386, 66.19561304364885, 64.88042327335903, 64.51073741912842, 61.60950320107596, 62.68964236123221, 63.59624331338065, 64.58365876334054, 68.60007885524205, 69.52953243255615, 70.29484176635742, 68.79850551060268, 69.11918572017125, 66.36334950583321, 65.7187442779541, 67.36788531712124, 68.88624041421073, 68.99636241367885, 70.45673479352678, 71.21863256181989, 67.7040044239589, 70.78587790897915, 69.90853582109723, 69.81554807935441, 69.53835664476667, 69.78371838160923, 67.67033345358712, 69.95027365003313, 69.39008208683559, 70.1013274874006, 65.65590476989746, 65.32394763401577, 69.82449735913957, 68.52283573150635, 67.88608196803501, 67.69251210348946, 67.43870830535889, 68.94192327771867, 70.21101175035749, 70.01241833823067, 68.57150786263603, 62.884407315935405, 65.0050322668893, 71.84924411773682, 69.35488946097237, 77.41764858790806, 65.0283226285662, 66.06756469181606, 71.25521482740129, 67.60368633270264, 53.01008258547102, 35.76553610392979, 4.248553327151707, 0.037897615893078704, 0.22712332622281142, 0.09844055771827698, 0.040417267475277185, 0.07578964744295393, 0.1491136343351432, 0.08013432073806014, 1.181385053055627, 1.3558074193341392, 0.488003851047584, 32.168352944510325, 80.44647257668632, 79.07903930119106, 71.88335977281842, 47.985114097595215, 33.26621001107352, 37.35700709479195, 74.67248480660575, 42.24182346888951, 29.00713971682957, 46.06559780665806, 54.920090266636436, 80.69594069889614, 26.398862395967754, 0.30718528798648287, 0.21444165600197657, 0.06703706138900348, 0.03184570438627686, 0.03871855505609086, 0.10432207890387092, 0.03341368007074509, 0.10901089158973523, 0.1360676722334964, 0.09938427100756339, 0.13017180003225803, 0.14224894983427866, 0.049639002819146426, 0.11916878473545824, 0.14033758454024792, 0.21377597243658134, 0.15896668205303804, 0.16239181826157228, 0.19700445953224385, 0.1503912614924567, 0.15075098004724297, 0.14098568047795976, 0.15694627618151052, 0.17626506382865564, 0.1940175483801535, 0.2397275348859174, 0.14389629715255328, 0.2248568699828216, 0.20592173960592064, 14.28991448879242, 68.05891840798515, 82.05366734095982, 79.66687774658203, 64.93136051722935, 71.6082319532122, 77.41210392543248, 78.96497072492326, 98.92606830596924, 103.42030211857387, 21.207408121653966, 0.7118285607014383, 0.21602990292012691, 0.4119143182677882, 0.4649149871298245, 0.5599566272326878, 0.9002938877258981, 0.24147693387099675, 0.6746781713196209, 1.4229349430118288, 0.6950129973036903, 6.0152188028608045, 0.20498833326356752, 4.487971748624529, 65.00928456442696, 63.358177185058594, 71.84423446655273, 79.63879312787736, 71.74750164576939, 67.60153933933803, 72.27442523411342, 77.28530624934605, 79.897794178554, 84.93764918191093, 87.06973171234131, 85.0366540636335, 85.20996992928642, 87.1469817842756, 87.94596903664726, 87.15427044459751, 83.38018962315151, 80.80508300236293, 82.2754955291748, 82.65521458217076, 85.02885818481445, 84.46896539415631, 83.41148430960519, 85.70453575679234, 83.16464260646275, 81.00880418504987, 80.03263786860875, 86.48313004629952, 82.54860142299107, 83.40238911764962, 82.29720170157296, 83.91140025002616, 83.0113445009504, 79.9592718396868, 78.05739702497209, 75.52520942687988, 74.59075314658028, 76.78832939692906, 76.78835718972343, 73.85199287959507, 70.17832047598702, 69.98183931623186, 64.89633464813232, 69.74771976470947, 64.89463928767613, 69.37660952976772, 75.42917837415422, 68.92164843423026, 66.94662298474992, 65.84252643585205, 60.11214556012835, 63.47423989432198, 66.79180322374616, 66.75861167907715, 69.8406936100551, 70.80429063524518, 72.83495725904191, 71.48465824127197, 71.66413021087646, 68.8937166758946, 70.60546098436627, 70.47878837585449, 72.40603801182338, 74.56090368543352, 75.22100339617047, 74.0614185333252, 71.16310950687954, 72.91848850250244, 72.70079449244908, 73.2593115397862, 74.03716237204415, 72.31250831059047, 70.83616202218192, 74.39120088304792, 70.2241438456944, 74.42496218000139, 65.7288955960955, 69.49618802751813, 74.52366134098598, 69.18741008213588, 69.72777843475342, 71.03549889155796, 68.92480291639055, 69.25682953425816, 71.47964859008789, 74.80322905949184, 69.7193363734654, 64.889052936009, 67.4539109638759, 74.06382261003766, 70.21891185215541, 76.55845519474575, 65.29126330784389, 66.29594503130231, 69.74137605939592, 71.05674648284912, 65.21637562343052, 51.887347493852886, 3.2366928117615834, 0.17715695739856788, 0.3778242032442774, 0.27768920787743157, 0.16841064100818975, 0.10123038837420088, 0.2917484263224261, 0.8857947885990143, 4.809001105172293, 1.8064060232469012, 2.0995313056877682, 52.68835319791521, 84.10188511439732, 84.51628957475934, 82.94576740264893, 53.64308432170323, 63.79896395547049, 78.95898832593645, 88.41819640568325, 57.8428430557251, 54.35552133832659, 46.36071559361049, 59.57718985421317, 94.17824608939034, 30.02675485610962, 0.3086826519242355, 0.31667644583753174, 0.18369488657585212, 0.23916087672114372, 0.19081180968454906, 0.24195918227945054, 0.2614160382321903, 0.2019386576222522, 0.29517125551189693, 0.2317264670772212, 0.22928792078580174, 0.23289094173482486, 0.10750418422477585], [0.014051508590845125, 0.10259312417890344, 0.09176081472209521, 0.09909191062407834, 0.042260667309165, 0.11878994506384645, 0.047542536564703496, 0.018461952285308923, 0.014901689220485943, 0.16088959601308617, 0.029907584456460815, 0.035095069490905316, 0.04458902969158121, 0.08048213100326912, 0.1295166201889515, 0.08246435570929732, 18.469119582857402, 52.24724333626883, 54.082019397190635, 51.398284639631, 84.4451539175851, 106.4821925844465, 44.04339061464582, 49.57859311785017, 78.88435077667236, 26.204342365264893, 0.357844278216362, 0.05968141609004565, 0.24085740425757, 0.07161484538976635, 0.42841504141688347, 0.16521711594292096, 0.25045767053961754, 0.20273459276982717, 0.14141978004149028, 0.34588450140186716, 0.07961998440857444, 0.09578533483935253, 0.7793928980827332, 27.297575405665807, 73.16038308824811, 80.15209824698312, 62.07558141435896, 50.29640804018293, 59.949884278433665, 62.90970570700509, 64.03432028634208, 63.88549682072231, 75.02916363307408, 76.99630287715367, 79.9126285825457, 76.46441827501569, 73.5375452041626, 80.22895921979631, 81.22460828508649, 75.44032328469413, 77.70832647596086, 76.52296379634312, 74.0739391871861, 76.1115470613752, 78.38799231392997, 77.17530236925397, 79.7902638571603, 76.74985027313232, 79.32840320042202, 80.12308951786586, 77.15493025098527, 76.40599087306431, 78.22128418513707, 76.42696748461042, 77.559572492327, 75.90118340083531, 74.87191895076207, 74.27604838779995, 71.54397501264299, 71.84436648232597, 71.9979008265904, 68.37378297533307, 66.98513684953961, 65.2864968436105, 65.67911175319126, 63.268309184483115, 64.42599718911308, 60.86300264086042, 59.25108310154506, 61.5119435446603, 59.49195630209786, 58.00738682065691, 59.018429619925364, 66.11824485233852, 66.20084503718785, 64.02218873160226, 62.12736633845738, 62.86756488255092, 66.61734785352434, 67.73738356998989, 71.82747541155133, 71.07522869110107, 70.79213823590959, 69.3693208694458, 66.22052233559745, 68.73628439222063, 68.53729493277413, 68.4297993523734, 68.33252457209996, 68.57043089185441, 64.3006169455392, 65.36393451690674, 70.10389832087925, 66.92124121529716, 66.4453660420009, 67.28403445652553, 67.07309409550258, 64.43960871015275, 66.90159170968192, 69.70914336613247, 66.80125277382987, 66.65613964625767, 62.267817224775044, 64.22368649074009, 67.1647755759103, 64.28989587511334, 61.88326917375837, 60.87159756251744, 64.27050345284599, 66.32704516819545, 66.32514136178153, 67.56157330104283, 58.67306246076311, 64.62386798858643, 62.912415504455566, 69.71168640681675, 63.60318456377302, 58.875310625348774, 63.18545191628592, 60.907749039786204, 42.861019134521484, 30.23633337020874, 12.199497699737549, 0.19091649406722613, 0.01431549433618784, 0.020632658752479723, 0.07438229117542505, 0.8763997384480068, 0.07840983755886555, 0.2623479925096035, 0.5294290653296879, 0.1664105640458209, 0.30171919986605644, 2.3255247218268256, 43.82983078275408, 70.97084590366909, 78.9655543736049, 50.64862959725516, 42.229987212589805, 40.96716601508004, 36.18172972542899, 73.26006194523403, 99.01622118268693, 60.2840370450701, 41.60290881565639, 65.43677943093437, 40.74285731996809, 0.04288806453613298, 0.05785939350192036, 0.10416296244199787, 0.013863582380249031, 0.13621981335537775, 0.05321425132985626, 0.36542400291987825, 0.19600663307522023, 0.12989759046052182, 0.24070902221969195, 0.23249649575778417, 0.10836072612021651, 0.06863970682024956, 0.07838147479508605, 0.10266238903360707, 0.029924887099436352, 0.10472322880689587, 0.06542459077068738, 0.06497886790228741, 0.02470663559090878, 0.06717812881938048, 0.033875239946480305, 0.11012102916304554, 0.05029619112610817, 0.03016210633463093, 0.015416754975116678, 0.15006928305540765, 0.035925240122846196, 0.09741592234266655, 27.07288977078029, 64.41861125401088, 69.8777414049421, 61.50919205801827, 95.15066732679094, 103.80714307512555, 41.52694068636213, 60.79797445024763, 86.78603676387242, 33.38377353123256, 0.34108731310282436, 0.2789532643343721, 0.3084155533994947, 0.11997062313769545, 0.2294322316135679, 0.3262040274483817, 0.27940606432301657, 0.22966410060014042, 0.17075020261108875, 0.25043872584189686, 0.3019483818539551, 0.16492944423641476, 1.8834325586046492, 37.49429307665144, 82.29280349186489, 85.69355065482003, 73.46647902897426, 61.73178454807827, 68.62072195325578, 69.2011536189488, 69.01665810176304, 70.39112295423234, 79.66234752110073, 81.37661402566093, 81.70825849260602, 81.72351673671177, 78.60414382389614, 81.05478736332485, 82.34399087088448, 79.90656975337437, 83.13388987949916, 78.41385350908551, 78.4014231818063, 79.89792619432721, 82.22365501948765, 80.8642052241734, 80.99590832846505, 78.9713213784354, 79.582505771092, 78.90374319893974, 81.17023863111223, 78.51390756879533, 81.7704587663923, 78.0839877809797, 80.2398817879813, 77.98895032065255, 77.18538420540946, 76.9655293055943, 73.31516116006034, 75.23145348685128, 72.92701394217355, 70.78135463169643, 71.56281157902309, 69.42498288835797, 66.57106590270996, 67.52498408726284, 66.85212053571428, 63.59820965358189, 61.24445179530552, 61.75597817557198, 61.89140551430838, 60.754972049168174, 62.60262312207903, 68.88716452462333, 68.39296000344413, 67.27672495160783, 63.601558685302734, 64.74013914380754, 69.52747576577323, 69.48771122523716, 72.3380012512207, 72.11393574305943, 72.83988353184291, 71.9636253629412, 69.98873887743268, 70.29545320783342, 69.33387810843331, 72.33333206176758, 68.93518352508545, 69.76308223179409, 68.03350189753941, 67.09848281315395, 69.7822801045009, 67.89282172066825, 68.29838807242257, 69.55833966391427, 71.66184425354004, 67.69020530155727, 69.84520993913922, 72.84067562648228, 71.01322991507394, 69.05294159480503, 64.32759680066789, 65.68754686628068, 70.01915114266532, 67.40140342712402, 68.86839744022915, 63.67935766492571, 64.23457431793213, 69.27279649462018, 67.08862331935337, 70.05203696659633, 61.878606932503835, 65.18593556540353, 65.62968226841518, 65.1419187273298, 67.75042533874512, 65.87337643759591, 63.296317373003276, 68.97899191720145, 60.10456507546561, 46.74575696672712, 21.565526962280273, 0.4517074929816382, 0.12917520850896835, 0.03840821349461164, 0.2936650977603027, 1.0330880220447267, 0.2724997449134077, 0.8689559378794262, 0.7069155871868134, 0.7465438778911317, 0.8314714921372277, 1.969107755592891, 51.52688537325178, 78.6955543245588, 90.43158285958427, 56.74860947472708, 45.23934929711478, 24.987354959760392, 26.29466894694737, 76.1579818725586, 105.60619844709123, 63.557138851710725, 51.09946346282959, 75.5458733694894, 49.22212968553816, 0.1289736157549279, 0.06266927719116211, 0.057901530526578426, 0.02814408721003149, 0.03253825793841055, 0.039358851233763356, 0.1875724427934204, 0.049026234807180505, 0.06924783704536301, 0.009713904782464462, 0.05835182672100408, 0.026920761513922895, 0.10023034310766629, 0.18189790871526512, 0.1483011565038136, 0.13133081926831178, 0.2824170770389693, 0.10575535520911217, 0.17487117648124695, 0.1332772241107055, 0.2028054996792759, 0.0926545878340091, 0.18294765667191573, 0.12017262301274709, 0.15175232131566319, 0.07126723868506295, 0.2763770568583693, 0.2758568376302719, 0.18386673235467502, 36.192655767713276, 79.98091547829765, 77.84087031228202, 74.75671086992536, 101.78403609139579, 137.6467740195138, 65.01100771767753, 70.6577044895717, 97.03763130732945, 49.547288009098594, 0.5622319451400212, 0.28513838244335993, 0.5156043214457375, 0.20432894650314534, 0.7406506655471665, 0.5162591891629356, 0.6413319749491555, 0.736325411924294, 0.6336278340646199, 0.8534520640969276, 0.7334699737174171, 0.46154440513678957, 1.6890333614179065, 40.37244537898472, 88.12375954219273, 91.69363280705043, 79.13923849378313, 66.27894278935024, 76.12380368368966, 76.6482606615339, 75.17611108507428, 74.91991710662842, 86.78179836273193, 84.60849911825997, 84.05756255558559, 80.93841893332345, 83.41113689967564, 85.29635688236782, 88.00717571803501, 83.96311569213867, 85.5690667288644, 81.90605981009347, 78.31627300807408, 81.9242501940046, 84.61949116843087, 83.4256933757237, 85.15182045527867, 83.25766508919853, 83.57885946546281, 84.7809534072876, 87.59842014312744, 83.07029996599469, 85.46259253365653, 83.3834205354963, 83.69265011378697, 81.63223130362374, 81.16278321402413, 80.56204891204834, 77.16633224487305, 80.28960309709821, 77.3821849822998, 71.86875465938023, 75.11531434740338, 73.02264199938092, 70.28145953587124, 68.95194952828544, 71.73163196018764, 66.90001446860177, 64.46877724783761, 65.07122080666679, 63.835462842668804, 63.59867518288748, 62.86816242762974, 70.23458003997803, 71.36272430419922, 69.93395233154297, 65.97904464176723, 66.8896894454956, 72.17757429395402, 73.61546230316162, 77.70472730909074, 76.25087233952114, 77.25079454694475, 74.54868875231061, 73.2760705947876, 74.82901382446289, 72.98752580370221, 73.8835585457938, 73.55310916900635, 74.10763100215367, 70.38696793147496, 71.0902715410505, 75.28081348964146, 72.17672661372593, 71.86819880349296, 72.94724709647042, 74.05362265450614, 70.1232351575579, 73.20051588330949, 75.91160569872174, 72.67127854483468, 72.272139276777, 67.32790538242885, 70.64873436519078, 73.47054372514997, 70.15837219783238, 70.23022351946149, 63.3695444379534, 66.21716635567802, 73.57915101732526, 69.93919127328056, 72.88715212685722, 65.82929011753627, 69.68192032405308, 72.85282107761928, 67.86614758627755, 64.22331128801618, 65.71870258876255, 62.310298510960166, 69.58099773951939, 64.54618018014091, 60.356749943324495, 27.106640645435878, 0.44045065130506245, 0.36315237624304636, 0.15348591043480805, 0.9059341964977128, 1.6876379677227564, 0.5235216851745332, 1.614645078778267, 1.8148707747459412, 1.1840716174670627, 1.4464880334479469, 7.250295843396868, 74.00206007276262, 83.17440482548305, 96.51113850729806, 68.13602951594761, 60.75130340031215, 59.91082150595528, 48.6660201890128, 90.95681108747209, 117.16843169076103, 77.62112658364433, 64.31188692365373, 86.42457062857491, 60.091502462114605, 0.3433733790048531, 0.1302942213203226, 0.22505726851522923, 0.16017887129315309, 0.15917613224259444, 0.1173075224672045, 0.3443899058869907, 0.1946397649922541, 0.17465595874403203, 0.3128233983048371, 0.2644481940993241, 0.18093680457345077, 0.15424551681748458], [0.08783808164298534, 0.047607994837952514, 0.05973226550434317, 0.006715595090229596, 0.07955783060086624, 0.05110286409035325, 0.04995288972609809, 0.1493415678186076, 0.01954961508246405, 0.06440328021666833, 0.10118920129856893, 0.043335015552916696, 0.05675090816138046, 0.022696319535108547, 0.05231891419472439, 0.466955586203507, 19.632421731948853, 45.522147927965435, 41.74106332233974, 43.37364680426461, 28.559109449386597, 23.49467693056379, 34.1076785496303, 70.44786889212472, 51.20397826603481, 1.0924891488892692, 0.3039706333407334, 0.14679157893572534, 0.13338407980544226, 0.06840214492487055, 0.22674344160727092, 0.30020907946995323, 0.05772422932620559, 0.09717914754790918, 0.12584377798650945, 0.0066874138345675805, 0.3384351097047329, 0.083958958009524, 14.170715536390032, 64.16400146484375, 74.43391145978654, 74.19328839438302, 71.812515939985, 76.47189453669957, 64.07819816044399, 62.52774238586426, 67.26827594212124, 75.61627946581159, 75.28439181191581, 77.0214067186628, 74.06755379268101, 78.09947531563895, 77.42627130235944, 71.90553147452218, 77.18130561283657, 82.15279729025704, 76.44720758710588, 74.4633787700108, 78.32174124036516, 74.66843400682721, 80.78357832772392, 76.9891323362078, 73.69305283682687, 78.90285382952008, 76.46220179966518, 73.61303043365479, 78.36771747044155, 80.22979300362724, 80.49785450526646, 74.33986759185791, 71.79106685093471, 72.80691432952881, 74.64767278943742, 70.07404885973249, 69.90146950313023, 66.34272725241524, 64.6989085333688, 67.64832850864956, 67.47393567221505, 65.11013766697475, 64.77107252393449, 63.95331123897007, 61.16345664433071, 62.37342984335763, 57.97599138532366, 59.58042771475655, 62.69074017660958, 60.98216424669538, 66.28928865705217, 62.55085904257638, 61.8341315133231, 58.79063292912075, 60.19959558759417, 62.53966549464634, 64.4132889338902, 63.298443521772114, 62.516215324401855, 70.00624138968331, 67.49466214861188, 65.42874036516461, 66.76683139801025, 63.55837563105992, 66.08039801461356, 65.99452522822789, 67.93362849099296, 65.16746725354875, 67.6410606929234, 63.169686453683035, 64.25093037741524, 63.85917009626116, 66.93498475211007, 65.78721182686942, 67.34776333400181, 62.090756280081614, 60.97199903215681, 66.29891886029924, 68.67442458016532, 66.7185970033918, 66.64618287767682, 61.00202914646694, 62.50898919786726, 64.03793334960938, 64.28779751913888, 61.337064334324424, 62.71400274549212, 64.2711843763079, 68.73339394160679, 71.09902627127511, 66.57642991202218, 59.499446460178916, 55.633159569331575, 52.57343694141933, 73.40459837232316, 63.99990585872105, 59.39512620653425, 58.14271688461304, 54.294144426073345, 34.18197911126273, 27.605934722082957, 3.332344536270414, 0.13336722499557904, 0.21283753136438982, 0.03146792322929416, 0.03528487609167184, 0.03380889279235687, 0.30755066552332466, 0.13034676707216672, 0.362152812736375, 1.4563706517219543, 0.6779101693204471, 7.781530788966587, 26.254246064594813, 74.39830889020647, 65.98100403376988, 30.452846186501638, 30.693931307111466, 36.88288981573922, 19.86148473194667, 17.70156076976231, 38.71647426060268, 54.50910431998116, 52.7424692426409, 44.261331285749165, 0.6905778210077966, 0.06823486568672316, 0.02720779539751155, 0.0999139557991709, 0.03978065574275596, 0.028115259649764215, 0.094633345226092, 0.11325029017669813, 0.19227813743054867, 0.15756587364843913, 0.24794766094003404, 0.06834474764764309, 0.05517602499042239, 0.06585164714072432, 0.06037546920457056, 0.13430840734924587, 0.02353912279275911, 0.042088604399136136, 0.0728048329640712, 0.09230250958353281, 0.09022725772644792, 0.028344601093392287, 0.06363281727369342, 0.040583423737968714, 0.05987021167363439, 0.002575965323818049, 0.02168775865408991, 0.02697622835902231, 0.46857174805232454, 29.475599425179617, 57.34473017283848, 52.23000832966396, 58.88246032169887, 53.683505467006135, 25.560718570436748, 33.374476841517854, 83.37475613185337, 60.28548921857561, 1.9519978165626526, 0.16647615124072346, 0.018709210446104407, 0.3143759678517069, 0.05329775863460132, 0.3371080309152603, 0.3645581379532814, 0.19467061119420187, 0.08790131432137319, 0.463555637214865, 0.6452814287372998, 0.25924391193049295, 0.9974335581064224, 21.90590705190386, 75.37738650185722, 81.78930922916958, 79.67340210505894, 76.58990274156842, 81.34913390023368, 68.38640785217285, 67.76617690495083, 71.39668709891183, 79.95044067927769, 81.60124928610665, 82.14124938419887, 80.27163505554199, 80.05398968287876, 82.03073828560966, 74.07743413107735, 79.02145263126918, 82.34594331468854, 78.8804736818586, 77.9114431653704, 80.86178725106376, 78.75457232339042, 83.42455387115479, 78.22184698922294, 78.28652776990617, 80.08784130641392, 76.96443843841553, 76.0816559110369, 79.58061586107526, 81.1866433279855, 79.40468747275216, 76.82186835152763, 74.44721726008824, 74.11954021453857, 77.80726187569755, 72.6105512891497, 70.85246249607631, 70.24696867806571, 69.52354308537075, 71.05804579598563, 70.40020424979073, 69.575772694179, 69.24148791176933, 66.26307310376848, 65.24100003923688, 64.67812647138322, 59.035786220005576, 62.35583005632673, 65.08898040226528, 69.04399231501988, 70.64169584001813, 68.47395515441895, 66.07818153926304, 61.984775406973704, 59.625055994306294, 63.564281599862234, 66.40872819083077, 65.66213730403355, 66.56028229849679, 69.41050979069301, 70.28412069593156, 67.11700671059745, 69.51860291617257, 66.71443503243583, 68.72057451520647, 66.04906858716691, 69.1515087400164, 67.65534618922642, 70.3680201939174, 67.18313271658761, 65.53611087799072, 67.29802812848772, 68.42656149183, 67.21915912628174, 70.18312862941197, 66.66737488337925, 63.42477566855294, 67.7996255329677, 69.75332001277378, 67.59019987923759, 69.12115900857108, 64.58942576817104, 65.02767644609723, 67.44193921770368, 66.03642286573137, 65.61274256025041, 66.50846263340541, 63.824324880327495, 70.04114219120571, 72.33511774880546, 67.13964394160679, 63.22227042061942, 60.90268380301339, 54.87448576518467, 75.08990478515625, 69.74009759085519, 66.60726601736886, 61.23698943001883, 67.27577304840088, 52.978027071271626, 39.92727082116263, 6.818296372890472, 0.06500556825527123, 0.06144493538886309, 0.03244923414396388, 0.17111803644469806, 0.045003485666321855, 0.1267523363764797, 0.7248931282332965, 0.9125324338674545, 0.4470762743481568, 0.8374316351754325, 5.3780511873109, 35.631105831691194, 84.22938455854143, 73.96023886544364, 36.54850081035069, 34.93448291506086, 31.197682653154644, 31.384505816868373, 37.27247878483364, 45.9282979284014, 63.60711029597691, 60.213519777570454, 54.09544331686837, 0.8517316792692456, 0.08517101832798549, 0.06229719572833606, 0.08683231632624354, 0.013364736157070314, 0.031004409172705243, 0.046462417380618196, 0.07712279912084341, 0.13753938754754408, 0.08347973586725337, 0.12470159998961858, 0.07216751216245548, 0.0969051822487797, 0.17087122611701488, 0.19407994646046842, 0.18942526408604213, 0.11582344424511705, 0.16473165127847875, 0.07932738653783288, 0.12088611615555626, 0.22666926415903227, 0.08741144596465997, 0.13028671672301634, 0.16369324842733995, 0.12864874675869942, 0.12259424664080143, 0.1775955217225211, 0.11645585245319776, 0.6734535513179642, 43.210965156555176, 72.46815490722656, 63.20648411342076, 61.874549184526714, 42.69834096091134, 36.633873326437815, 54.59803778784615, 91.16791125706264, 78.72627231052944, 2.5039121210575104, 0.9679354152509144, 0.17332493088075093, 0.4894386540566172, 0.17105744326753275, 0.6081391274929047, 0.7639705027852739, 0.7108986963118825, 0.27013936585613657, 0.8065627430166517, 1.1561794855764933, 0.4794119692274502, 1.0884860094104494, 22.62772066252572, 81.95011138916016, 80.00993810381208, 83.45201315198625, 79.64248956952775, 88.34428146907261, 74.59482479095459, 75.09822177886963, 75.76567963191441, 87.00857366834367, 84.1706931250436, 87.16541535513741, 83.56089837210519, 83.36303452083042, 85.08784144265312, 80.0038514818464, 81.32343251364571, 87.27834442683628, 83.93352331433977, 79.73950726645333, 82.85490580967495, 80.14179406847272, 85.15091718946184, 82.74577045440674, 81.40370505196708, 82.99595424107143, 80.845153263637, 79.82264246259416, 84.16511372157505, 84.8588844026838, 84.36463124411446, 81.5380345753261, 79.47834532601493, 77.60464545658657, 80.3760803767613, 76.0652164731707, 74.10954870496477, 73.07349586486816, 71.18674033028739, 72.25920867919922, 72.09509917667934, 70.41493443080357, 71.33904484340123, 68.27129009791783, 68.92109257834298, 67.60349873134068, 60.64170251573835, 63.46666635785784, 65.2861772264753, 68.25426006317139, 72.88033594403947, 71.64152077266148, 69.09037848881313, 63.25421823774065, 60.81174577985491, 64.66140910557338, 68.46317155020577, 70.0557473046439, 69.6324074608939, 74.23731912885393, 73.07352365766252, 70.66600063868931, 73.66772665296281, 69.84575189862932, 73.13593932560512, 69.84473051343645, 75.69047233036586, 71.23664924076625, 73.96819455283028, 70.37428746904645, 69.17541749136788, 71.82588427407401, 74.16359874180385, 69.99806335994175, 72.9268958227975, 69.50441469464982, 65.81084265027727, 68.74008505684989, 72.4492141178676, 70.01889405931745, 71.01467514038086, 67.22586413792202, 71.1050295148577, 69.57363959721157, 69.48046425410679, 68.64139979226249, 68.56663717542375, 66.20290170397077, 71.85283633640834, 76.92324951716832, 69.74038246699742, 66.42657811301095, 63.475025040762766, 59.151946204049246, 74.22117151532854, 64.72839668818882, 66.70998123713902, 62.076581954956055, 67.74492931365967, 61.38204002380371, 55.86437477384295, 5.988608070782252, 0.36819090587752207, 0.36176900618842667, 0.22832459104912622, 0.37475521649633137, 0.07811477660600628, 0.8472717500158718, 1.950978385550635, 1.712522723845073, 2.3378371468612125, 1.9813370193753923, 14.87162549155099, 65.54886777060372, 87.36399487086705, 79.67595904214042, 45.40615817478725, 48.15374340329851, 52.71871682575771, 32.563309397016255, 25.915896586009435, 58.46414402553013, 77.2288521357945, 74.25537749699184, 65.98179612840924, 1.2688889290605272, 0.17770525440573692, 0.19550333651048796, 0.24548387314592088, 0.1673808012689863, 0.1161956749856472, 0.21563009651643888, 0.13587867308940205, 0.2377668400960309, 0.2194028462150267, 0.24750585321869167, 0.1524211668542453, 0.1427997574210167], [0.13632955960929394, 0.0594430806647454, 0.05399286008573004, 0.03505313941942794, 0.03357301027114902, 0.05512517896879997, 0.01751336711458862, 0.07105094886251859, 0.1275207365729979, 0.0973430544670139, 0.09254222243492093, 0.13015430739947728, 0.0526801187412015, 0.07772690563329629, 0.061279440697814734, 0.11947078710155827, 16.807685443333217, 56.56402710505894, 50.68617071424212, 46.960876669202534, 36.53662633895874, 44.22155979701451, 46.821068491254536, 69.3135268347604, 6.214047150952475, 0.6937168868524688, 0.02954279045973505, 0.08708789332636765, 0.1022632068821362, 0.23989423736929893, 0.18137808303747857, 0.176263476056712, 0.17353542601423605, 0.09702338983437844, 1.7111182106392724, 0.985058382153511, 0.04919653691883598, 15.11696638379778, 52.45840603964669, 70.01651082720075, 83.6628770828247, 82.25687435695103, 73.4281666619437, 64.48610605512346, 59.36765302930559, 64.51724788120815, 74.70527335575649, 74.26406274523053, 77.80590002877372, 78.38733918326241, 78.65947927747453, 75.52094323294503, 81.39370659419468, 73.3048152923584, 78.0198003223964, 75.43830830710274, 76.35459504808698, 79.58309636797223, 78.6754184450422, 76.00724765232631, 79.42259992871965, 70.36550494602749, 75.72471305302211, 76.77994986942836, 75.46317590985979, 79.58880083901542, 76.85873549325126, 76.71316378457206, 72.3137172971453, 70.66515295846122, 71.95085457393101, 72.51522895268032, 74.38225855146135, 72.85995687757219, 73.39531557900565, 70.66640363420758, 66.02065740312848, 66.44203090667725, 70.1570520401001, 69.99273409162248, 67.46005317143032, 63.38536548614502, 60.4293030330113, 58.57789298466274, 61.57239287240164, 67.37693881988525, 63.844870703560964, 67.36925411224365, 63.095201764787944, 63.82310894557408, 60.30320017678397, 59.49965490613665, 61.81535053253174, 59.13867514474051, 65.5675584248134, 66.78318745749337, 68.29701232910156, 68.07489231654576, 68.45922497340611, 71.05116013118199, 65.7444178717477, 64.8717588697161, 64.44259643554688, 60.99380942753383, 63.052650996616904, 64.54657622746059, 66.48459557124546, 65.70291628156389, 66.54300212860107, 68.48650360107422, 65.1094081061227, 63.95199108123779, 66.18671934945243, 62.821630341666086, 63.267503193446565, 59.100175176348, 65.58699253627232, 67.74401909964425, 66.48237909589494, 67.01206111907959, 61.15726579938616, 63.23116411481585, 65.50543458121163, 61.72254344395229, 62.67117404937744, 60.61665425981794, 64.86383792332241, 66.1679105758667, 70.51961599077497, 62.957571847098215, 63.112843241010395, 54.87450660978045, 62.927979469299316, 68.71238258906773, 66.99732398986816, 56.17066873822893, 59.24092483520508, 45.909336294446675, 28.742550577436173, 17.31994833265032, 0.08782571194959538, 0.10394699831626245, 0.14403782598674297, 0.19744681008160114, 0.18456995247730187, 0.1365418325045279, 0.261364143873964, 0.8861010521650314, 0.8270947241357395, 0.41317321785858696, 0.8605993720037597, 9.777800355638776, 35.05726105826241, 75.76340757097516, 44.42717088971819, 16.223626817975724, 23.71242478915623, 27.04784151485988, 24.060293299811228, 39.77663734980992, 48.869602407727925, 53.545625414167134, 39.16235406058175, 0.22713311069778033, 0.08248185512742826, 0.03436338482424617, 0.15076900193733828, 0.04716377831729395, 0.025793156752895032, 0.01969409384764731, 0.10626472466226135, 0.07528485810118062, 0.20850385033658572, 0.12625847144850663, 0.16299692222050258, 0.030963958307568516, 0.14275304707033293, 0.055066933522799184, 0.08227676791804177, 0.03021917791504945, 0.05567396791385753, 0.1278154786143984, 0.01732597440215094, 0.07106434992913689, 0.06373279262334108, 0.053052746424717565, 0.056498720443674495, 0.033585851546376944, 0.06485113368502685, 0.03611672270510878, 0.028601893090776036, 0.17821098012583597, 23.860774040222168, 71.35784666878837, 62.658458845955984, 69.17665427071708, 30.752737385886057, 25.40075193132673, 54.27490486417498, 80.96263340541294, 7.0740673797471185, 0.6145587201629366, 0.07172590121626854, 0.5276900615010942, 0.31299840605684687, 0.3535849510559014, 0.0857576864904591, 0.16689220177275793, 0.09924445886697088, 0.12705142104199954, 2.9806562534400394, 1.5969777639423097, 0.1854677628725767, 22.764079059873307, 66.61384596143449, 76.24461896078927, 87.50746127537319, 85.70959404536656, 77.78386034284318, 72.10829380580357, 65.96194512503487, 71.05316121237618, 77.9168975012643, 77.54910850524902, 81.16554164886475, 83.76270880017961, 81.95911625453404, 79.59570734841483, 81.78001948765346, 78.71435614994594, 79.32185104915074, 76.05588504246303, 78.83931255340576, 83.65329551696777, 81.21611758640834, 78.53120163508824, 81.62451880318778, 76.70294993264335, 77.75699165889195, 78.30727509089878, 78.22845472608293, 79.60705375671387, 77.86224297114781, 75.54362215314592, 73.98867784227643, 73.39813654763358, 74.43022891453334, 74.59276812417167, 77.00871930803571, 75.85283783503941, 76.06855160849435, 74.99833447592599, 71.17176001412528, 71.94011960710797, 72.24759129115513, 72.4872694015503, 71.57968180520194, 66.3071733202253, 64.32133647373745, 62.27375793457031, 64.46319089617047, 71.34379741123745, 66.98170443943569, 68.27090099879673, 66.98274666922433, 66.18841470990861, 62.969960485185894, 61.69425732748849, 62.06385285513741, 59.91272531236921, 68.95772348131452, 69.0845558983939, 70.80478395734514, 70.49663829803467, 69.14021791730607, 72.7757933480399, 67.68409783499581, 68.09387479509626, 68.10436657496861, 63.877749579293386, 65.05455207824707, 64.81243515014648, 68.05549989427838, 69.63215732574463, 68.74189158848354, 68.75118132999965, 67.9834818158831, 65.15209089006696, 68.5579936163766, 65.79992703029087, 69.129517691476, 63.21308490208217, 66.1273191996983, 70.44584001813615, 69.19223213195801, 68.42398371015275, 65.02951771872384, 62.69322763170515, 68.05873080662319, 65.40235805511475, 65.13621425628662, 65.60761478969029, 64.99210861751011, 66.24537604195731, 70.50396864754813, 63.34603173392159, 67.1156587600708, 59.09975133623396, 64.63026727948869, 70.57356180463518, 73.94275024959019, 62.54506424495152, 64.21427862984794, 63.88278702327183, 44.69745234080723, 24.947611263820104, 0.4415343260126454, 0.18156259027974947, 0.11670874245464802, 0.08466747070529632, 0.24402293296796934, 0.14303083930696758, 0.45920850762299126, 0.8895938247442245, 0.4549724949257714, 1.0743453396218163, 0.8649606151240212, 7.6427266257149835, 41.744853564671104, 86.65862764630998, 54.36075333186558, 21.967883246285574, 21.346092428479874, 26.338004861559185, 30.69552591868809, 40.835080759865896, 52.4165153503418, 62.72324384961809, 45.030455180576865, 0.47356750283922466, 0.05568193391497646, 0.04342385953558343, 0.0847056315147451, 0.028447589138522744, 0.09255743519003902, 0.022104984748044183, 0.014853940711223652, 0.035178580188325474, 0.0915274326024311, 0.14711541655872548, 0.11148212291300297, 0.01914701989984938, 0.2823456680136067, 0.1407579369843006, 0.1226436575608594, 0.1146467559571777, 0.18535246620220797, 0.19958289260310785, 0.1267382635601929, 0.14681212497609003, 0.15475429594516754, 0.12139847794813768, 0.24338057743651526, 0.21923338887946947, 0.1956322988761323, 0.14473029811467442, 0.12994066386350564, 0.23234176263213158, 32.00451094763619, 87.98871435437883, 69.29553100040981, 67.99243109566825, 50.909645625523154, 66.86188970293317, 63.594270024980815, 96.55131993974958, 14.299318875585284, 1.5992163866758347, 0.20450498562838348, 0.7700340002775192, 0.6317238648022924, 0.4699267553431647, 0.2783750167914799, 0.46968421978609903, 0.6365649136049407, 0.6379099328603063, 3.677752298968179, 2.7640218436717987, 0.30462389971528736, 20.417618547167095, 68.50886290413993, 84.31900242396763, 92.50323690686906, 93.20913219451904, 80.86281558445522, 74.36375549861363, 72.4509094783238, 76.86495413099016, 83.64662524632045, 81.14671897888184, 85.65940025874546, 87.12736701965332, 85.36335141318185, 83.7882364818028, 86.0094713483538, 83.3855675288609, 85.64134189060756, 80.73264108385358, 80.21762670789445, 88.44248035975865, 83.82166426522392, 81.23717757633754, 85.95080770765031, 79.24626854487828, 81.7905946459089, 80.05686623709542, 80.21705695561, 82.65629155295235, 83.66572584424699, 81.46362631661552, 77.38917487008231, 75.73627485547746, 78.28652776990617, 78.67324365888322, 80.08863340105329, 80.49834782736642, 80.04491533551897, 78.62977572849819, 73.09795352390834, 74.10883304050991, 75.08201163155692, 75.72588729858398, 73.83738776615688, 68.66594777788434, 66.72696263449532, 64.94415215083531, 65.37259892054966, 77.252760887146, 70.40002359662736, 73.55715302058628, 69.78117534092495, 69.35899584633964, 63.820475578308105, 61.32462705884661, 62.5058069229126, 61.598302704947336, 70.92266014644078, 71.58018207550049, 75.76186507088798, 73.78024578094482, 72.2469173158918, 76.96885054452079, 71.25660446711949, 71.6483439036778, 73.07863753182548, 65.457339150565, 66.85845034463065, 67.86636992863247, 70.15982437133789, 72.7447487967355, 72.36193779536656, 72.56624957493374, 71.43264402662004, 70.22774301256452, 72.56374822344098, 68.70644187927246, 70.99863174983433, 64.18381077902657, 70.14780398777553, 72.54373046330043, 71.0503055027553, 71.85068934304374, 68.04269436427525, 68.37561729976109, 69.89216586521694, 67.6688951764788, 66.89503955841064, 65.21104635511125, 68.00289508274624, 68.52000086648124, 75.74671799795968, 64.74910926818848, 69.42428806849888, 61.470094544546946, 68.08061763218471, 65.57526397705078, 72.40319619859967, 63.73428317478725, 65.08290767669678, 67.17781039646694, 58.07156733104161, 31.88085733141218, 0.19023244934422628, 0.26557206522141186, 0.3300807151411261, 0.272414140935455, 0.2998728517975126, 0.3684529018189226, 0.5603500146950994, 2.771274025951113, 5.304404190608433, 1.3303475912128175, 2.879899340016501, 23.048722437449864, 67.07159328460693, 92.31851904732841, 64.19150243486676, 26.731116567339214, 36.86779138020107, 44.07057891573225, 38.39347335270473, 54.254588331495015, 67.14771774836949, 74.74506568908691, 59.350650787353516, 0.8953885680862835, 0.14071430718260153, 0.15381022303232125, 0.2991800404020718, 0.2201443085713046, 0.22216850066823618, 0.07875007537326642, 0.1089397743344307, 0.15616689728839056, 0.3131169596953051, 0.26880829728075434, 0.1478114306394543, 0.07303297000804118], [0.08857273150767599, 0.14417725136237486, 0.07397411843495709, 0.011740219845835651, 0.05721878859081438, 0.11742135350193296, 0.0156926099942731, 0.07593591923692397, 0.08143585946943079, 0.030391345998006206, 0.06993837534849133, 0.05776655634066888, 0.023912493472120593, 0.06333638568009649, 0.04295398421319468, 0.14848688510911806, 17.99320445741926, 50.6008746283395, 41.567340987069265, 36.010362829480854, 48.96051958629063, 50.33871909550258, 72.99562740325928, 33.84105879919869, 0.5310162944453103, 0.37712596356868744, 0.3952916759465422, 0.19743239799780504, 0.8214024667228971, 0.19221166814012186, 0.2160436636103051, 0.13055505018149102, 0.1284682700144393, 0.20552528516522475, 0.40741202128785, 0.13807399171803678, 6.672094549451556, 62.20907020568848, 70.15529414585659, 66.90594823019845, 69.34707273755754, 66.3012534550258, 64.90799372536796, 68.86914784567696, 59.223464012145996, 69.6219573702131, 70.69480092184884, 77.58568382263184, 76.20237391335624, 79.47619138445172, 77.47931385040283, 77.0387077331543, 70.98360974448067, 80.78940091814313, 71.76943710872105, 77.02781990596226, 77.58535030909947, 78.9637200491769, 76.38360377720424, 78.87230954851422, 75.51908111572266, 70.18441404615129, 75.86863803863525, 74.52865014757428, 77.40835189819336, 71.16641684940883, 72.33285958426339, 72.80195331573486, 73.83899974822998, 75.31886182512555, 76.43972437722343, 73.53434903281075, 75.3156795501709, 70.23030689784459, 71.12802805219377, 66.81972108568463, 65.34666129520961, 67.56318528311593, 66.56082425798688, 65.96673243386405, 60.96504388536726, 62.67695495060512, 62.22177846091134, 63.46391487121582, 61.33295794895717, 62.47657585144043, 63.05247729165213, 61.03425489153181, 64.12805148533413, 61.98164871760777, 60.89498519897461, 61.40461472102574, 56.028022221156526, 60.34482683454241, 67.22148677280971, 64.38293920244489, 66.60624463217599, 64.61134038652692, 65.73921367100307, 65.49565151759556, 67.13796942574638, 64.87286363329206, 65.83243070329938, 65.08943203517369, 64.65265437534877, 67.69347790309361, 62.95893369402204, 67.20306015014648, 66.91312571934291, 66.87034566061837, 69.906416620527, 66.18223776136125, 61.61256735665457, 62.64371476854597, 65.45268385750907, 63.91969585418701, 59.162583896092, 64.7576208114624, 69.45144162859235, 65.31866005488804, 69.79580824715751, 59.56678145272391, 60.40162835802351, 66.32318196977887, 60.58513028281075, 60.34279796055385, 62.637919970921104, 65.2030142375401, 69.22663266318185, 68.32982867104667, 62.95960072108677, 61.32278578622, 60.63824231284005, 66.5110056740897, 66.96737725394112, 61.52775764465332, 56.537370341164724, 60.48394366673061, 31.806869438716344, 26.675808906555176, 5.020221131188529, 0.24342156095164164, 0.12519395856985024, 0.3601502116237368, 0.46339164887155804, 0.3493867191885199, 0.756856307387352, 0.2970516931797777, 0.019808840904650942, 0.4968531419123922, 0.07155129379991974, 1.9560544788837433, 4.310271569660731, 54.558346203395296, 59.98183209555489, 28.186123200825282, 32.95733479091099, 30.639961174556188, 52.43146787370954, 60.19464152199881, 52.17723676136562, 47.53927946090698, 9.901127406529017, 0.024851655487769415, 0.04970864086811032, 0.02723977984195309, 0.05066312590081777, 0.029663691829357828, 0.11341881791927985, 0.03794120159000158, 0.049393481707998683, 0.13503381556698255, 0.2531910810087408, 0.09213541354984045, 0.14068380024816307, 0.18913101058985504, 0.12448524231357233, 0.0132628558203578, 0.16692549070077284, 0.11334114601569516, 0.04893592518887349, 0.07685203650700194, 0.06613271670149905, 0.042056967703891654, 0.0528340953003083, 0.030729090196213553, 0.10026726219803095, 0.04682814097031951, 0.084212384053639, 0.08814181427338294, 0.11718453120972429, 0.18385868492935384, 23.669281687055314, 62.50338894980294, 59.03920473371233, 58.71398735046387, 28.962059804371425, 46.71786342348371, 86.19836507524762, 42.16697399956839, 0.4166927790003163, 0.5029986064348901, 0.2745484049831118, 0.6806025419916425, 0.8516233850802694, 0.22845163994601794, 0.10731956841690199, 0.028763696551322937, 0.1734088928039585, 0.02313834778033197, 0.42071793015514103, 0.2702348493039608, 10.891474996294294, 72.88100297110421, 78.74699878692627, 77.85469027927944, 73.48965127127511, 73.23441614423479, 68.13662706102643, 73.81896809169224, 65.38488333565849, 72.5675002506801, 74.95155225481305, 83.21818542480469, 79.39821869986397, 83.22190965924943, 83.50752231052944, 80.0722495487758, 75.0897936139788, 81.02996144975934, 76.98972293308803, 81.04016140529087, 78.0224197932652, 82.54048592703683, 80.21800885881696, 83.2746673311506, 76.05910900660923, 75.31617982046944, 75.24879619053432, 77.93550477709088, 74.73705441611153, 73.61956174033028, 73.31796128409249, 72.68689114706856, 74.60938126700265, 78.2709082194737, 77.02168464660645, 76.98119054521833, 75.96078504834855, 72.66389260973249, 73.81996863228935, 72.89357921055385, 69.25638484954834, 70.90426131657192, 69.4919913155692, 67.88706166403634, 63.42369869777134, 66.71782575334821, 64.1236185346331, 67.54309804098946, 64.35532011304582, 64.73243359157017, 66.4644249507359, 63.702925954546245, 66.23060417175293, 66.53461565290178, 64.78634466443742, 64.04584734780448, 56.642159598214285, 64.10120364597866, 67.85298769814628, 63.687285559517996, 66.87386144910539, 67.59090164729527, 65.75754301888603, 66.88336658477783, 67.0749979019165, 65.81654017312187, 65.97816222054618, 69.41210092817033, 66.59036105019706, 68.51721463884626, 64.81620802198137, 67.78315830230713, 69.42296096256801, 67.20307404654366, 68.25852625710624, 68.69067641666958, 65.28100081852504, 66.10662746429443, 66.98829133169991, 67.51877239772251, 62.300626618521555, 63.482904297964915, 69.72674315316337, 69.45205307006836, 70.9831233705793, 64.52964346749442, 62.089033126831055, 69.02809483664376, 65.29111044747489, 63.508501461574006, 64.72183064052037, 67.03530284336635, 67.82133865356445, 68.28590910775321, 61.218027796064106, 63.30157021113804, 62.62767137799944, 68.38412884303501, 69.7719828741891, 70.26509652818952, 61.99551732199532, 69.02100767408098, 55.49082572119576, 35.20031751905169, 8.86889260155814, 0.26564990675875116, 0.1082186544580119, 0.19678442419639655, 0.10022279779825892, 1.7346352572951997, 0.5948048830032349, 1.565547913312912, 0.7731329511318887, 0.218521741351911, 0.5984483989221709, 1.0588920031275069, 13.014908756528582, 62.47642299107143, 69.6526267187936, 33.42698785236904, 29.551143714359828, 23.886868000030518, 48.78202036448887, 53.833527496882844, 53.92857190540859, 55.72580337524414, 13.076322146824428, 0.07224178460559674, 0.12515764337565216, 0.05747994314879179, 0.033136942956064425, 0.04690032013292823, 0.09999170234160763, 0.015000697657732027, 0.024483305967545936, 0.021896226664206812, 0.03687947749027184, 0.049623830776129446, 0.04577658471784421, 0.07501379693193094, 0.16137245510305676, 0.20778202478374752, 0.3287255992846829, 0.12142253879989896, 0.1633880976587534, 0.17915650510362216, 0.17682968638837337, 0.13201247554804596, 0.17068766882377012, 0.1002119615940111, 0.2702630492193358, 0.16616500222257205, 0.24677376821637154, 0.1997847974832569, 0.2972847835293838, 0.22631643952003547, 33.92163011005947, 73.95226928165981, 57.379978384290425, 52.49319566999163, 73.46195575169155, 70.71716022491455, 95.63106577736991, 53.466982228415354, 1.4306337641818183, 1.4301694290978568, 0.6474013892667634, 1.4002002200910022, 1.5992429852485657, 0.9062835606081145, 0.4873306357434818, 0.5296376741358212, 0.31238639461142675, 0.3772215555821146, 1.2199627544198717, 0.7344017380050251, 9.831891213144575, 83.51372010367257, 84.587571144104, 85.19322477068219, 81.87400082179478, 83.68618134089878, 78.68704972948346, 80.46259239741734, 68.1169080734253, 79.11486421312604, 77.16920185089111, 86.49850640978131, 82.76534352983747, 87.50389684949602, 86.25459684644426, 84.23324080875942, 76.90184211730957, 86.85278115953717, 80.77676214490617, 83.85466820853097, 81.07137271336147, 87.21989618028913, 81.95867156982422, 85.36437279837472, 79.30293805258614, 76.55061067853654, 80.90430327824184, 81.70115048544747, 79.39226409367153, 76.64748246329171, 75.38045065743583, 74.38250868661063, 78.19864695412772, 81.11556325639997, 81.72306510380336, 81.83511870247978, 81.72808865138462, 76.9727623803275, 78.2009676524571, 75.98313740321568, 72.12692192622593, 74.87502479553223, 72.35603182656425, 72.1974183491298, 66.8097504207066, 68.93819209507534, 65.77567781720842, 69.37919425964355, 67.77113097054618, 67.77906581333706, 67.89634445735386, 67.63040215628487, 69.9705901827131, 69.29473195757184, 66.62155846187046, 65.81884697505406, 57.46748399734497, 64.73846462794712, 72.33128234318325, 69.22243595123291, 70.4810882295881, 72.75229454040527, 70.02060331617082, 71.28966399601528, 72.10245731898716, 70.65912192208427, 70.4254401070731, 73.74880518232072, 70.63261454445976, 71.78499412536621, 66.74038655417306, 70.28251566205705, 71.62900011880058, 71.4186920438494, 72.89803995404924, 72.45852470397949, 67.03658826010567, 68.4615387235369, 69.86846555982316, 70.11910792759487, 63.85154792240688, 67.46777262006486, 72.33653518131801, 72.48579638344901, 74.7971076965332, 64.84307670593262, 65.32349600110734, 73.18857887813023, 67.69654900687081, 64.2204555783953, 66.03482478005546, 70.1222346169608, 70.78889342716762, 71.54013960702079, 64.59948675973075, 68.68546526772636, 65.26372759682792, 69.28297560555595, 64.14901420048305, 68.88591384887695, 62.09596048082624, 69.00833415985107, 61.140798568725586, 53.09807457242693, 6.46808979340962, 0.5149882116488048, 0.16349655469613417, 0.4975941021527563, 0.6359902215855462, 3.4942084678581784, 3.5027853676251004, 2.66835600563458, 2.122770424400057, 1.67715357031141, 1.7509542959077018, 7.073884555271693, 36.76312024252755, 74.78537913731166, 75.35429068974086, 47.38658584867205, 48.296813760484966, 42.7786934035165, 72.93519892011369, 80.3883786882673, 68.45462526593889, 68.82017694200788, 19.429977280753, 0.21950605139136314, 0.222259166517428, 0.18220831134489604, 0.12393246697528021, 0.24603066380534852, 0.17256740081523145, 0.09485418123326131, 0.10624124056526593, 0.2432126807315009, 0.32589203704680714, 0.2301426034952913, 0.11344463617673942, 0.28660019114613533], [0.09833995811641216, 0.1423820648342371, 0.054750366402523856, 0.05794714165053197, 0.04409249472830977, 0.07226260884531907, 0.02315952825093908, 0.12012383634490625, 0.05500118347949215, 0.0877332751240049, 0.047040776881788454, 0.09198211891842739, 0.038484657249812565, 0.033839942554810216, 0.035543024739516635, 0.21067512168415956, 30.383013316563197, 53.44986186708723, 40.85351433072771, 35.76008871623448, 41.58832107271467, 62.88667937687465, 74.2844487598964, 2.9051927370684485, 0.8153050424797195, 0.2229398592774357, 0.3305082193442753, 0.552136049738952, 0.12456174035157476, 0.2519518589334828, 0.26087144602622303, 0.5117489940353802, 0.10233505016991071, 0.26645915476339205, 0.18596616041447434, 2.2045420365674153, 39.19966241291591, 63.86477034432547, 77.83092049189976, 72.11907741001674, 65.43111664908272, 55.75398179462978, 53.322900908333914, 63.326423917497905, 68.48840740748814, 69.97093064444405, 81.07966191428048, 82.71891566685268, 80.88168689182827, 74.222811290196, 77.29219886234829, 71.84720134735107, 76.63584423065186, 75.50789451599121, 79.28748525891984, 73.75270312173026, 78.30840069907052, 80.27834006718227, 80.24904646192277, 72.30265576498849, 70.09216976165771, 73.62634318215507, 72.07515784672329, 69.26775905064174, 70.66094929831368, 73.77837671552385, 71.93385928017753, 75.27512986319405, 77.85050746372768, 73.9858568736485, 73.60544994899205, 71.36945016043526, 70.98975195203508, 71.38294356209892, 68.29769325256348, 71.48819487435478, 65.14700480869838, 65.73214040483747, 64.03101989201137, 63.746539797101704, 61.8972350529262, 62.52367768968855, 58.88513537815639, 62.63006155831473, 59.90757669721331, 62.30659512111119, 67.95041533878872, 62.879321234566824, 65.74559906550816, 63.20974281855992, 61.54350226266043, 58.37788214002337, 55.53063889912197, 60.03911999293736, 58.21018041883196, 59.757398332868306, 61.37230559757778, 62.27036721365792, 67.24138641357422, 67.28980146135602, 66.35883317674909, 63.552921295166016, 62.32533441271101, 64.64642878941127, 63.17766298566546, 64.09006568363735, 64.69826235089982, 65.21904373168945, 66.77388381958008, 63.723652430943076, 62.20840317862374, 67.15901551927838, 68.03300162724086, 61.57504708426339, 62.498122215270996, 62.91113008771624, 58.16377340044294, 54.95281975609915, 63.042944363185335, 66.90548964909145, 64.0648089817592, 68.545229775565, 60.21422849382673, 58.692531313214985, 63.497078623090474, 58.97116102491106, 61.826210566929404, 64.30398682185582, 64.96740777151925, 65.02219431740897, 61.65548637935093, 56.66534226281302, 61.00177206311907, 64.59588759286063, 67.65339374542236, 63.997029304504395, 58.17172908782959, 61.98750604901995, 45.51836115973336, 23.5092716217041, 21.590151378086635, 0.24771842466933386, 0.11190069080995661, 0.2667485092367445, 0.11905631077076707, 0.5815199272973197, 0.4079303949006966, 0.24682446835296495, 0.1815549364047391, 0.1641956221844469, 0.13714294667754853, 0.5211708598903247, 5.768549936158316, 20.192912067685807, 65.93821702684674, 35.888936110905235, 35.14791073117937, 42.630272933415, 34.79761382511684, 44.443210806165425, 48.77111169270107, 43.05993216378348, 0.5750794900315148, 0.07105477580002376, 0.021557203427489315, 0.018994958505832722, 0.08055320076112236, 0.04518789452101503, 0.11063411698809691, 0.058075377983706336, 0.06473198972110238, 0.0823561225884727, 0.1489332661564861, 0.17482703099293367, 0.15503797786576407, 0.11834114843181201, 0.1112459520144122, 0.1124111187777349, 0.041219502820500305, 0.06947799612368856, 0.043330482938992124, 0.07001340096550328, 0.003566650623854782, 0.04014743784708636, 0.04227670787700585, 0.07094496847795588, 0.04572113822879536, 0.12789127097598144, 0.109044648706913, 0.011163733949485635, 0.12225233284490448, 0.26203605639083044, 40.2240492275783, 65.06204223632812, 51.536671910967144, 33.371339729854036, 29.864292076655797, 69.89154052734375, 81.77311992645264, 5.291302493640354, 1.6375271252223422, 0.855397071157183, 0.7134681727205003, 1.1753613991396767, 0.0946396691724658, 0.5967113492744309, 0.06950811629316636, 1.0711653445448195, 0.28473443697605816, 0.12352350034884044, 0.12177031513835702, 3.553341111966542, 49.737317766462056, 70.04504013061523, 84.65993663242885, 79.14414392198834, 77.37660557883126, 67.211731501988, 61.18491268157959, 69.06382247379848, 75.8782126562936, 75.01159163883754, 83.15376867566789, 85.42997074127197, 82.8789257322039, 78.33327525002616, 78.46927234104702, 76.60086699894497, 80.81411566053117, 78.27541065216064, 83.00202696663993, 76.56661237989152, 81.42677307128906, 81.13678305489677, 81.51485538482666, 73.26940032414028, 72.02230290004185, 74.84632873535156, 75.95181492396763, 73.24341406141008, 73.70751203809465, 74.56844942910331, 73.65332303728376, 77.2078755242484, 77.51540279388428, 75.72175312042236, 75.92680140904018, 73.98904609680176, 74.03864233834403, 74.50169808523995, 72.23752335139683, 71.53280925750732, 69.52475902012416, 70.19312708718437, 66.25711849757603, 67.45734337397984, 66.21389375414167, 66.4362986428397, 61.32725347791399, 64.86523451123918, 64.09227521078927, 67.11438029153007, 70.77287782941545, 67.67017364501953, 67.9243665422712, 66.60084588187081, 65.29682881491524, 59.80246434892927, 58.613134247916086, 62.87308175223214, 60.86268997192383, 62.51223400660923, 63.86224814823696, 64.24210616520473, 67.07839557102749, 68.57049342564174, 68.18313830239433, 67.22384221213204, 64.46542821611676, 66.84582546779087, 65.69275801522392, 65.01491955348423, 66.6305980682373, 66.29408291407994, 70.67166342054094, 65.35678482055664, 62.724258286612375, 67.380051612854, 69.70286914280483, 64.24376678466797, 66.18887329101562, 66.69909340994698, 64.19153717585972, 57.83009658540998, 63.538899830409456, 68.54782145363944, 64.56705951690674, 68.90361091068813, 66.04907553536552, 60.3203135899135, 67.03170367649624, 64.85074751717704, 62.01259599413191, 64.86492879050118, 66.78348623003278, 63.975274494716096, 64.31624344417027, 59.25391796657017, 61.66545704432896, 63.806718145098, 68.23702158246721, 68.55019773755754, 63.74111325400216, 65.59897817884172, 66.61210891178676, 37.560867241450715, 28.452298266547068, 0.8502393907734326, 0.047100440465978215, 0.12018977637801852, 0.38483718835881775, 1.294227163706507, 0.24868623273713247, 0.27638449360217365, 0.160003198576825, 0.06518427402313266, 0.17859329389674322, 1.1188912178788866, 9.136715258870806, 27.153195313044957, 75.44237300327846, 43.116636412484304, 44.124743597848074, 28.078726632254465, 32.758651052202495, 53.34184169769287, 52.74744415283203, 49.19660547801426, 0.5433129774672645, 0.009335594368167222, 0.018618434334972074, 0.004499763499812356, 0.0209924756948437, 0.030121265311858485, 0.038015138158308606, 0.06196649133094719, 0.038971713078873496, 0.0938047861148204, 0.06428343736167465, 0.11890065483748913, 0.04869197149361883, 0.07791315671056509, 0.15576798655092716, 0.20929936479244912, 0.13208606945616858, 0.14330039412847587, 0.1532550456800631, 0.11501430480607919, 0.18773907742330007, 0.1814459501100438, 0.25423168231334003, 0.17364586437387125, 0.10416285387639489, 0.2210635199610676, 0.20235173617090496, 0.10823554997997624, 0.21037359429257257, 0.4976871428745133, 49.83672216960362, 76.47550759996686, 58.20352404458182, 54.257596901484895, 63.28759043557303, 77.39067568097795, 96.83490371704102, 7.454915949276515, 3.0834303157670155, 2.9465071601527075, 2.125905364751816, 2.4563425821917395, 0.5261327964918954, 1.0984072770391191, 0.5375822335481644, 1.1572393029928207, 0.881507967199598, 0.4818126804062298, 0.3034093220319067, 2.7185484894684384, 57.839341163635254, 75.88693959372384, 86.93216432843889, 83.21719183240617, 83.36268016270229, 75.4197357722691, 69.9739739554269, 76.87552234104702, 79.80291652679443, 77.30247524806431, 88.32698045458112, 89.69261414664132, 85.4805188860212, 80.63540799277169, 83.96897997174943, 80.6335597719465, 83.63005379268101, 82.25965363638741, 85.26543045043945, 80.89631284986223, 83.84544794900077, 82.56227547781808, 86.06443854740688, 75.08791760035923, 72.73133877345494, 76.45797034672329, 76.126770564488, 77.82069969177246, 78.35511343819755, 78.66002818516323, 76.13633823394775, 80.65928200313023, 82.38529096330915, 78.94721112932477, 79.95180252620152, 79.22059495108468, 77.8033014025007, 78.27271475110734, 76.40205124446324, 76.50678839002336, 70.65631484985352, 72.9070656640189, 67.62685162680489, 69.80809961046491, 67.57101590292794, 71.23327241625104, 63.83859648023333, 67.847658429827, 65.51138223920549, 70.361725125994, 73.72158908843994, 70.46149430956159, 70.78393241337368, 68.18773800986153, 67.07956981658936, 61.04477446419852, 58.641885893685476, 66.42504950932094, 62.01716096060616, 64.94395065307617, 65.47244453430176, 67.70656830923897, 70.37108434949602, 72.14924648829869, 71.71118341173444, 70.0461448941912, 68.54006031581334, 70.97837775094169, 69.1436572756086, 67.83479036603654, 70.30714007786342, 70.68759563991001, 74.28702654157365, 68.0623299734933, 66.99140412466866, 72.90427943638393, 72.72177805219377, 67.15944630759103, 68.80730887821743, 67.77397278376988, 65.92407049451555, 58.743141991751536, 66.40541390010289, 70.79345144544328, 68.58133956364223, 73.19407490321568, 66.72540623801095, 62.782824652535574, 69.86529718126569, 65.77964523860386, 64.06764384678432, 66.79491601671491, 69.24456596374512, 68.05811241694859, 67.07474776676723, 62.92694418770926, 67.06508977072579, 67.19185965401786, 66.40946469988141, 65.68932560511998, 65.9650023324149, 66.82381357465471, 66.57267093658447, 47.52231195994786, 37.14112309047154, 0.4457080491951534, 0.19381355361214705, 0.29923033341765404, 0.8142391996724265, 3.8291474665914262, 3.4708271282059804, 0.5178874017936843, 0.2234491812331336, 0.5781541221908161, 0.5681702122092247, 2.099077935729708, 19.996340581348964, 48.412664549691335, 84.37509523119245, 57.89308547973633, 55.016399247305735, 61.433338574000764, 53.42910064969744, 65.78931713104248, 63.87564427512032, 62.04129205431257, 1.6742942780256271, 0.1843368485569954, 0.15181448869407177, 0.06369020098022052, 0.20325604693165847, 0.3243461442845208, 0.2920356909079211, 0.1540393778788192, 0.17626939288207463, 0.12034381739795208, 0.1962798655565296, 0.09939603001943656, 0.18283823611480848, 0.16296592674085073], [0.13968301537845815, 0.08037971971290452, 0.06951171931411539, 0.10560636927506753, 0.1201519276946783, 0.043469144962728024, 0.0584043792581984, 0.026683844226811613, 0.07994363204176937, 0.027777050655069094, 0.04530400882608124, 0.09126204398593732, 0.19797525315412454, 0.049425433922026835, 0.16149113087781838, 4.019047379493713, 53.80704096385411, 47.203862122126985, 56.83478798185076, 58.63488210950579, 47.511146204812185, 77.80034841809953, 31.462092876434326, 0.41526668838092257, 0.6863890343478748, 0.632370970078877, 0.4179346609328474, 1.5737829399960381, 0.1381793139236314, 0.42762129115206854, 0.06934259446071726, 1.0834663701908929, 0.12954644858837128, 0.12412055688244955, 0.3702299307499613, 20.4930898802621, 52.38866349628994, 62.39275278363909, 84.63080283573696, 77.45779527936662, 75.90459496634347, 60.566912106105256, 62.587232862200054, 64.33375290461949, 67.61399745941162, 74.11837986537388, 78.64813981737409, 76.67922878265381, 78.2531486238752, 76.96054744720459, 73.2264187676566, 75.11279909951347, 73.7766466140747, 72.6518166405814, 77.09084006718227, 79.53533445085797, 76.08670725141252, 73.30147320883614, 68.5840424128941, 68.14010116032192, 76.2990858895438, 77.86392443520683, 76.73935849325997, 72.46264498574394, 70.6326492854527, 72.90591921125139, 74.49033083234514, 73.12074361528668, 72.40698296683175, 70.86993721553257, 71.3333820615496, 72.45284802573067, 71.50712871551514, 71.0015708378383, 68.7419193812779, 65.765866960798, 65.22878510611397, 63.687577383858816, 64.82317011696952, 61.969100270952495, 64.37090492248535, 58.74913828713553, 56.65603862489973, 65.7014502116612, 59.92364093235561, 63.22862107413155, 67.86314596448625, 64.19331591469901, 61.87841238294329, 63.940929549080984, 59.9656914302281, 56.123584270477295, 53.218028272901265, 53.01090942110334, 59.20888669150216, 59.76745932442801, 60.16461835588728, 62.74463735307966, 62.667317799159456, 63.612147739955354, 63.75846290588379, 63.00395107269287, 61.4521473475865, 60.6323641368321, 61.50845554896763, 61.083086831229075, 61.9299749646868, 65.02365343911308, 65.82083415985107, 65.26574257441929, 60.39934240068708, 58.47330869947161, 61.01247923714774, 64.65193176269531, 60.875182832990376, 63.692482812064036, 59.00324780600411, 54.66998291015625, 60.50778293609619, 64.49580574035645, 67.63279928479875, 65.20772511618478, 66.46862861088344, 60.36323261260986, 58.127913747514995, 60.926530020577566, 58.855570793151855, 59.90221963609968, 64.71211011069161, 66.33026913234166, 65.57783481052944, 62.585579190935405, 59.93580722808838, 58.76181180136544, 65.70147800445557, 67.57145363943917, 60.294195311410085, 59.41392803192139, 60.955677713666645, 25.539993831089564, 23.30429628917149, 7.1816511154174805, 0.14026537484356336, 0.7987279434289251, 0.24727292571749004, 0.24360172556979315, 0.07923729744340692, 0.47627616035086767, 0.2772060366613524, 0.28848594852856224, 0.20504685012357576, 0.7574580865246909, 4.656615384987422, 14.170077170644488, 27.932602541787283, 54.6385040964399, 44.35658066613333, 28.03866331917899, 38.14755923407418, 27.667337690080913, 50.15098571777344, 29.4669280733381, 0.06874475082648651, 0.1890505634780441, 0.032192286503102095, 0.08196602602090154, 0.04607050233919706, 0.13321190832981042, 0.027318992020030106, 0.07909263377743107, 0.03991078518863235, 0.11580433669899191, 0.18140470875161036, 0.2513117832796914, 0.15832648426294327, 0.09697846403079373, 0.04837868169748357, 0.03973010488386665, 0.07558346779218741, 0.06162032312048333, 0.04503483398418341, 0.045599490470652065, 0.049927702506205866, 0.1067331445270351, 0.005243137628505272, 0.029974525328725576, 0.05460633038144026, 0.06937719974666834, 0.1254489520298583, 0.12459702417254448, 0.2734865519617285, 5.249180342469897, 65.04060704367501, 58.94611276899065, 70.24161856515067, 34.20622485024588, 44.90516178948538, 89.25862966264997, 38.78658505848476, 0.819640229855265, 0.3861885315605572, 0.8493364506534168, 1.349334629518645, 2.4430563236985887, 0.3140049177621092, 0.2500282935798168, 0.11563441795962197, 3.2235033937862942, 0.054701498310480795, 0.018236268145431365, 0.13501092179545335, 26.537855897630962, 62.09590489523751, 71.40376731327602, 90.14403166089738, 80.27596378326416, 82.90515518188477, 67.80164051055908, 71.94865894317627, 72.72416823250907, 73.39398152487618, 78.55178914751325, 82.17662961142403, 79.34395326886857, 80.5114312853132, 82.01095676422119, 76.88937010083879, 78.17574569157192, 78.29674162183488, 77.8013003213065, 80.56319536481584, 83.03650392804826, 76.0884095600673, 71.62281622205461, 68.98358467647007, 71.82031181880406, 77.94044494628906, 79.13965538569859, 76.26850686754499, 75.55566338130406, 76.8092782156808, 77.8323448726109, 78.17178521837506, 74.49624374934605, 74.28405271257672, 73.09238106863839, 72.14610590253557, 74.9443608692714, 74.01117610931396, 72.05329186575753, 71.575790813991, 69.39541830335344, 68.04667568206787, 67.78966876438686, 67.55458341326032, 65.75558362688336, 66.56080341339111, 62.16074548448835, 61.244840894426616, 68.59345722198486, 65.02617563520158, 67.22635746002197, 68.96945204053605, 66.52964074271065, 65.8292623247419, 67.77516092572893, 62.05040809086391, 59.41917392185756, 57.047243050166536, 58.19234439304897, 61.621933528355186, 62.609814507620676, 63.163759640284944, 65.07242284502301, 64.3225176674979, 64.88173648289272, 64.4449657712664, 63.938435145786826, 62.85469681876046, 63.51433794839041, 63.6636130469186, 62.9132353918893, 62.04412691933768, 65.1132504599435, 67.57694271632603, 66.67765821729387, 63.865666661943706, 59.13200487409319, 62.58459254673549, 66.66170515332902, 65.44173349652971, 66.54368305206299, 62.96368626185826, 60.79240199497768, 61.43221991402762, 65.26816749572754, 69.35479913439069, 65.85720797947475, 67.67523193359375, 63.60512311117989, 60.29429258619036, 65.17845235552106, 65.04199668339321, 62.83582551138741, 66.4114657810756, 65.6444958278111, 66.27076475960868, 65.94372000013078, 63.236736570085796, 61.185037749154226, 67.29998057229179, 67.6695066179548, 68.93685109274728, 60.88507011958531, 71.87507057189941, 47.78072588784354, 30.92382982798985, 12.143013187817164, 0.25332461670041084, 0.9914986022881099, 0.11928632057138852, 0.3574238307774067, 0.26406425184437204, 0.5978983512946537, 0.43106252221124514, 0.3897211477160454, 0.19041046979171888, 0.924513190984726, 4.896141503538404, 24.5330365725926, 28.3498592376709, 67.29203183310372, 51.66224670410156, 30.54452419281006, 40.52326645169939, 33.81533309391567, 53.84252541405814, 36.44032778058733, 0.06092035996594599, 0.12365010141261987, 0.11046436788248164, 0.09848335292190313, 0.08340139221400023, 0.15497377488229955, 0.03692261874675751, 0.08833343256264925, 0.03431157867557236, 0.12644657492637634, 0.0618655796029738, 0.1533746849745512, 0.009781928766252739, 0.05183781590312719, 0.18621758478028433, 0.194505387917161, 0.14648750025246823, 0.18090628406831197, 0.30930969970566885, 0.12346946181995527, 0.161807599610516, 0.13285495819790022, 0.15407002052026136, 0.12170422582754067, 0.13498205691576004, 0.2806910467999322, 0.23934223556092807, 0.18346738735479967, 0.31938510334917475, 7.47722053527832, 83.14272103990827, 64.26099831717355, 78.37961278642926, 83.16792215619768, 64.44791180746896, 96.43984304155622, 53.87497697557722, 1.2727129352944238, 1.3519596372331892, 2.1353210423673903, 4.277441331318446, 6.233031366552625, 0.33603301431451527, 0.5212825196129935, 0.3877070929322924, 5.497376944337573, 0.3378983342221805, 0.3823050856590271, 0.6178631857037544, 29.205620220729283, 76.05817794799805, 78.56598431723458, 89.67313139779228, 85.6556065423148, 88.21096638270787, 73.56962503705705, 76.7644692829677, 76.74577168055943, 78.86996800558907, 80.92590522766113, 85.21453489576066, 82.58284909384591, 86.00642108917236, 83.9230523790632, 80.5223469052996, 82.28398622785295, 80.86462211608887, 78.40322971343994, 83.412081854684, 85.8439027241298, 80.64398206983293, 75.21076175144741, 71.7960695539202, 73.54032448359898, 80.39097036634172, 82.53273173740932, 80.32294750213623, 79.17075552259172, 79.6814967564174, 80.10415567670549, 82.07085718427385, 80.41583102090019, 77.54706573486328, 77.95119380950928, 76.8620775767735, 78.01063564845494, 78.71659346989223, 76.144912311009, 76.65775884900773, 72.19864818028041, 72.36426544189453, 71.04262079511369, 71.270354952131, 67.92302553994315, 68.4422505242484, 65.88107504163469, 65.13344887324742, 70.57966232299805, 66.90972805023193, 68.62912232535226, 72.18762138911656, 70.64465577261788, 68.10409559522355, 71.22451768602643, 64.52638476235526, 59.100015367780415, 56.101853779384065, 58.77960613795689, 63.28649262019566, 65.70171424320766, 65.87541225978306, 68.02217633383614, 67.92303943634033, 68.75686495644706, 68.18743923732212, 65.98496450696672, 67.2940537588937, 67.34572751181466, 67.80768544333321, 65.41990920475551, 64.47210543496269, 70.45962524414062, 71.68107686723981, 69.64876352037702, 64.81483227866036, 62.21829741341727, 67.06353337424142, 70.41610867636544, 66.82143729073661, 68.3277233668736, 64.36314378465924, 60.90904140472412, 63.34773404257638, 67.42546503884452, 74.5557759148734, 69.62844003949846, 70.88115855625698, 65.0790514264788, 64.54335921151298, 65.88616807120187, 65.90519223894391, 66.30198301587785, 68.71871934618268, 68.93677466256278, 68.76688425881522, 68.08553000858852, 68.45327731541225, 64.35451412200928, 67.75556700570243, 63.3344977242606, 68.88143226078579, 63.52251597813198, 71.8030594417027, 54.707468441554475, 47.63777017593384, 10.537693568638392, 0.3962516944323267, 1.501382276415825, 0.2746034748852253, 1.0660145580768585, 1.0038401229040963, 1.8078218272754123, 0.4475947565266064, 0.3767224795051983, 0.22487027783479008, 2.188559659889766, 8.393934590475899, 41.51155737468174, 41.97530099323818, 77.51889773777553, 57.58062498910086, 45.35706567764282, 54.674558298928396, 41.66125283922468, 66.95842102595738, 45.57441227776663, 0.12068908315684114, 0.23892903487597192, 0.18808241614273616, 0.19818703750414507, 0.19226969645491668, 0.16912205783384188, 0.09525073066885982, 0.19762455911508628, 0.13650242319064482, 0.162445476810847, 0.2378437045429434, 0.3516052844268935, 0.2704778462648392, 0.08830580940204007], [0.0758040730974504, 0.09550859433199678, 0.09619830482240234, 0.10483844405306236, 0.06179905602974551, 0.028157881826960614, 0.045020696707069874, 0.014987741031550934, 0.04057632965434875, 0.08166515680828265, 0.045988684586648426, 0.07984713079141718, 0.1358664051762649, 0.07685812975146941, 0.22574448878211634, 17.25259596960885, 63.767335755484446, 39.50804431097848, 42.33867788314819, 40.548780236925396, 51.33096701758248, 61.27069514138358, 2.1653372602803365, 0.4701963780181748, 0.29975429815905436, 0.022451655074421848, 1.3118776508740015, 0.5628696594919477, 0.5203951586570058, 0.24428112911326544, 0.38927621873361723, 0.2824804793511118, 0.08091564024133341, 0.066209852562419, 2.340947551386697, 38.353222438267295, 53.151329040527344, 67.93895775931222, 70.18212808881486, 86.38226304735456, 68.74813107081822, 72.08856092180524, 73.87735380445207, 61.15744645254952, 70.74107592446464, 73.96212182726178, 75.65059661865234, 75.754611151559, 75.88808604649135, 74.11463478633335, 73.02483763013566, 74.73722812107631, 73.85650226048061, 75.65729468209403, 75.95125906808036, 71.62931278773716, 67.51313046046666, 70.4795526776995, 74.54752145494733, 77.81483541216168, 71.6637966973441, 73.37188625335693, 68.78579030718122, 73.70120307377407, 74.57048525129045, 72.75540733337402, 71.64745453425816, 72.32843358176095, 71.05072239467076, 75.02946935381208, 69.29542677743095, 69.34716306413922, 66.87145737239292, 69.32579735347203, 65.40308066776821, 66.10828113555908, 63.90962791442871, 61.19495282854353, 59.996326037815635, 60.0834356035505, 60.676999364580425, 54.65440852301461, 58.74007783617292, 66.34948784964425, 58.537482261657715, 62.686473982674734, 63.76787771497454, 64.62067181723458, 66.67353098733085, 65.95209952763149, 61.28648144858224, 59.94803605760847, 56.245264598301475, 53.66611760003226, 60.06577328273228, 61.494086674281526, 60.816199575151714, 64.23567213330949, 62.833727155412944, 62.060719217572895, 60.91922746385847, 63.179247174944194, 60.23885290963309, 59.62649427141462, 60.318215233939036, 61.93644373757498, 62.73618834359305, 63.7812807900565, 64.59808322361538, 64.15740762438092, 62.88197544642857, 60.88199206760952, 57.31586735589163, 60.814802987234934, 59.97785772596087, 60.91939422062465, 60.55921350206648, 59.32766614641462, 55.49954571042742, 61.785806792122976, 65.00097451891217, 66.81726837158203, 65.73044504438127, 64.51631682259696, 58.11461836951119, 58.97793551853725, 61.009693009512766, 60.55184146336147, 60.18754046303885, 65.11185387202671, 66.08859688895089, 66.89078726087297, 62.03239836011614, 57.38591909408569, 60.99397618430001, 64.11041695731026, 61.67428820473807, 56.78701216833932, 61.13574028015137, 41.508705139160156, 20.2090961592538, 22.130208798817225, 1.074675813317299, 0.09930522846324102, 0.09978335816413164, 0.2900780088135174, 0.1915871309382575, 0.07711804259036269, 0.07948158362082072, 0.16267513377325876, 0.05632558884099126, 0.0619591563673956, 0.9180791590894971, 14.677621364593506, 12.854971647262573, 41.42863409859793, 57.88832943780081, 21.233488185065134, 29.07309549195426, 36.62344408035278, 49.46419450214931, 34.089425631931846, 0.0799313641286322, 0.13114443926938943, 0.011814912132519697, 0.07231856084295682, 0.05847880097904375, 0.1169671421604497, 0.16458033796932015, 0.0963760945679886, 0.1466399942125593, 0.04584180889651179, 0.036583955133599896, 0.14347350198243344, 0.19370782428554126, 0.1156092578811305, 0.023238660701151406, 0.09385166609925882, 0.05133513341258679, 0.09667674664940153, 0.06351486753140177, 0.07995497714728117, 0.019278414813535552, 0.056543096633894105, 0.02549474044436855, 0.03048912967954363, 0.02642830284977598, 0.04424736016829099, 0.03459376781912787, 0.060072001202830246, 0.40323536683406147, 21.355969292776926, 69.95647839137486, 50.01817784990583, 52.2254398890904, 30.800342968532018, 56.565239565713064, 75.29455702645438, 1.4588726546083177, 0.9301792298044477, 0.15589610753314836, 0.25295286093439373, 0.5810443013906479, 1.4727538526058197, 1.2247025115149361, 0.4442494974604675, 0.32744020968675613, 0.32476718883429256, 0.2087065830294575, 0.0652540884912014, 3.6269470708710805, 48.65413529532296, 60.83650915963309, 75.5736175264631, 70.03495829445976, 87.97822257450649, 73.11437906537736, 77.33938407897949, 76.13216236659459, 67.31972040448869, 74.59531116485596, 78.56268392290387, 77.1526790346418, 80.23915222712925, 77.13491249084473, 76.66618701389858, 75.28405135018485, 77.63594709123883, 76.642347744533, 80.19401672908238, 78.49775300707135, 70.74641908918107, 71.0149461201259, 72.32712037222726, 75.07109601157052, 80.7131096976144, 74.33434377397809, 76.12481117248535, 73.69667979649135, 77.00758675166539, 76.77232074737549, 76.79026794433594, 73.10146931239537, 75.92511299678257, 73.31177043914795, 76.6024511882237, 74.58217906951904, 69.39063099452427, 71.3233002253941, 70.20712075914655, 64.84891319274902, 70.18144021715436, 66.51911422184536, 65.56988607134137, 63.09590353284563, 62.670618193490164, 61.54329381670271, 57.974633012499126, 64.03578635624477, 67.81025627681187, 63.278043610709055, 65.32168252127511, 63.192066601344514, 67.70622784750802, 68.26545361110142, 67.24898079463414, 63.190308707101, 63.803556714739116, 60.5571220942906, 57.7076415334429, 61.87588323865618, 64.34143761226109, 63.76150621686663, 65.74548094613212, 64.28180122375488, 65.01598262786865, 61.968224797930034, 63.81378446306501, 63.98845522744315, 64.19068254743303, 63.822129249572754, 65.56115218571254, 64.47966507502964, 65.88935729435512, 65.65458461216518, 67.69720908573696, 62.57993030548096, 64.3847735268729, 58.94349329812186, 61.178666251046316, 62.10023362295968, 64.90700013296944, 62.44046606336321, 65.16900975363595, 59.81963334764753, 60.87633623395647, 65.90827029091972, 70.82035487038749, 67.34074565342495, 68.48652444566999, 62.077617236546104, 63.28982080732073, 65.00201674870083, 66.48321287972587, 63.8674384525844, 65.93890489850725, 66.98397650037492, 68.01948043278286, 64.14655453818185, 59.38746929168701, 61.89317035675049, 62.03835991450718, 64.9441590990339, 63.01103128705706, 65.03102547781808, 62.67615590776716, 36.5588709967477, 27.480563163757324, 3.234049456460135, 0.21733590641192027, 0.11131011428577559, 0.15871780897889817, 0.10344752190368516, 0.11066864763519593, 0.12239135109952518, 0.12871433395360196, 0.0741327056395156, 0.1541810017079115, 0.4137767069041729, 21.628380366734095, 16.248928683144705, 50.09013686861311, 67.75816563197544, 29.50929124014718, 32.78811488832746, 44.254890305655344, 55.9019193649292, 38.22965567452567, 0.12553021338369164, 0.13530757730560644, 0.04064644607050078, 0.155592055991292, 0.05793931135641677, 0.05116686012063708, 0.08586621816669192, 0.05457877168165786, 0.09169528859534434, 0.15016830845602921, 0.08748950463320528, 0.07750794916812863, 0.008793512741768999, 0.11803382635116577, 0.3352891770856721, 0.2276215609163046, 0.2264485638588667, 0.1750899768833603, 0.1986270538930382, 0.1301039465303932, 0.1937970652111939, 0.06417046806641988, 0.1194767989218235, 0.2375151850283146, 0.13859210748757633, 0.2324285065489156, 0.32139796391129494, 0.2863841727375984, 0.608801106257098, 26.904948336737498, 82.71648379734584, 56.30037423542568, 57.9215418270656, 59.67536095210484, 67.1371009009225, 95.91656030927385, 6.732860020228794, 2.4502791932650974, 0.5724361890128681, 0.9997787922620773, 2.756610069956098, 3.8727526238986423, 3.5979214055197577, 0.8781657751117433, 1.345968552998134, 1.0077775801931108, 0.5143886581063271, 0.23548731527158193, 3.464329476867403, 59.61921950748989, 69.74137605939592, 80.77438586098808, 74.41105883462089, 89.02956145150321, 78.7326854978289, 82.2974796295166, 82.43997328622001, 74.80293723515102, 77.80984660557338, 79.16939367566789, 81.75221279689244, 84.09454781668526, 81.01236861092704, 81.72430188315255, 78.50850187029157, 79.65642765590123, 80.76164286477226, 83.52474689483643, 81.1124574116298, 72.4433845792498, 71.68218163081578, 73.73958492279053, 76.21827833993095, 84.68246964045933, 77.05427169799805, 77.87457602364677, 74.62470204489571, 80.73380838121686, 80.21247809273856, 79.65181405203683, 76.96969822474888, 79.16390459878104, 78.90209647587368, 81.09155028206962, 76.98354598454067, 74.32471357073102, 75.4368839263916, 75.86389936719621, 70.46282836369106, 74.35598046439034, 69.96722030639648, 67.92667334420341, 64.51608058384487, 64.99845927102226, 65.67925766536167, 60.83367429460798, 66.37901074545724, 71.51677976335797, 65.101792880467, 69.68317794799805, 68.52792876107353, 72.93066869463239, 72.54919174739292, 69.55073138645717, 66.0478526524135, 67.30820723942348, 60.40283039637974, 59.178418840680806, 63.72712653023856, 65.72590787070138, 66.8378141948155, 69.30577959333147, 66.3329163960048, 68.40470940726144, 65.1438433783395, 68.23289435250419, 67.5824943270002, 67.30709552764893, 67.88110705784389, 70.23717866625104, 67.1072722843715, 68.48656613486153, 72.32246507917131, 71.77804592677525, 65.42796216692243, 65.44556195395333, 61.655215399605886, 64.78856113978794, 65.79853739057268, 65.68405887058803, 66.6061682019915, 66.03567940848214, 63.2690179007394, 64.19875635419572, 69.74179295131138, 74.47566318511963, 73.00743934086391, 69.14233711787632, 64.36463069915771, 68.9037846156529, 67.4167867388044, 67.31349481855119, 66.0661403111049, 70.71538843427385, 71.16483960832868, 72.15791089194161, 67.99453639984131, 62.48584474836077, 65.13723564147949, 61.69258281162807, 61.58064038412911, 64.55700547354562, 63.69698524475098, 63.780377524239675, 49.96489906311035, 39.49009016581944, 1.9045691958495548, 0.3464718141726085, 0.2584881867681231, 0.7224926341857228, 0.4799684222255434, 0.7053091419594628, 0.35071360798818724, 0.8099991157650948, 0.24356788024306297, 0.32932306293930325, 1.7170902958938052, 31.50218050820487, 26.13575495992388, 65.35939734322685, 77.6348979132516, 34.72354602813721, 43.80935096740723, 54.18546070371355, 63.214217458452495, 45.683412143162315, 0.16169526135282858, 0.3365117614822728, 0.15160132013261318, 0.27514548865812166, 0.10798757935741118, 0.16325370701295988, 0.2867766645337854, 0.12528832922024385, 0.13840289121227606, 0.23187332919665746, 0.1956965018595968, 0.2513570279947349, 0.3056674865739686, 0.2664432499025549], [0.19324768254799501, 0.04175267528210368, 0.0752804001261081, 0.13505533869777406, 0.12650400613035473, 0.089188413827547, 0.09772055742463895, 0.06961626120443855, 0.07204051076301507, 0.0879661144156541, 0.07622950776879277, 0.15035163504736765, 0.05016221099400094, 0.21706502166177544, 0.06822578688817364, 37.794496944972444, 49.38240030833653, 40.875606128147666, 30.913664613451274, 29.7002729007176, 72.16513007027763, 24.959461416516984, 1.346637642809323, 0.22491032497159072, 0.18139561638236046, 0.07625322935304471, 0.36918723955750465, 0.3929290441530091, 1.1619431248732974, 0.0800061115462865, 0.1897647487265723, 0.14483304188719817, 0.4603958896228245, 0.06930172629654408, 13.292845385415212, 47.860619749341694, 55.60368183680943, 65.80964061192104, 58.780349595206125, 73.45105402810233, 63.636966705322266, 65.69861534663609, 59.540315764290945, 62.67167431967599, 67.29968874795097, 75.31393555232457, 73.8970866884504, 76.54091794150216, 73.94839218684605, 74.32137148720878, 77.66945130484444, 74.07682963779995, 73.81548009599958, 74.60514286586216, 65.8922894341605, 70.76126044137138, 74.4291102545602, 74.14183003561837, 74.90098326546806, 73.52899891989571, 74.3811537878854, 74.0700968333653, 74.89107513427734, 70.02701650347028, 71.07775783538818, 70.39311708722795, 71.2615863255092, 72.43232999529157, 72.10449314117432, 71.79729243687221, 68.18113722120012, 64.25548144749233, 66.1210936137608, 62.133418219430105, 63.8412298474993, 64.92518356868199, 62.508634839739116, 62.17072309766497, 59.23872920445034, 61.20882838112967, 53.20477458408901, 55.95046642848423, 61.755484853472026, 57.21020262581961, 58.944452149527415, 55.824995858328684, 56.322796072278706, 57.59401764188494, 61.33230481828962, 60.38520976475307, 58.816139766148154, 58.658992358616416, 58.556749616350444, 56.71827711377825, 60.14075824192592, 63.40218012673514, 62.25308704376221, 64.57559190477643, 64.45775740487235, 63.02665778568813, 63.38389941624233, 62.90295900617327, 64.22171320234025, 62.25333023071289, 62.20426205226353, 59.79945577893938, 60.0658358165196, 62.85154233660017, 62.06404045649937, 64.75091579982212, 63.936899593898225, 66.36762959616524, 63.56964560917446, 59.63918168204171, 58.90228353227888, 60.76508167811802, 55.479072843279155, 63.17869131905692, 59.35136645180838, 53.842292649405344, 60.86002881186349, 60.206522941589355, 63.88944339752197, 61.697703633989605, 60.53991140638079, 57.09466103145054, 59.32595688956124, 61.00419698442732, 63.846920422145296, 63.67584882463728, 67.77166598183769, 66.59006922585624, 65.21902983529228, 59.20238317762102, 55.29821123395647, 63.64592293330601, 61.02366583687918, 54.655391693115234, 56.43344613483974, 54.939350673130576, 29.454025268554688, 22.302159343447002, 15.228361640657697, 0.1886908177818571, 0.14938309416174889, 0.0657744434263025, 0.0864910064265132, 1.0478233056409019, 0.14817583108586924, 0.030574479206864322, 0.056701395461069684, 0.20205753695751938, 0.24310530935014996, 5.752426207065582, 5.518251504216876, 15.178138324192592, 64.03246511731828, 21.856329917907715, 27.982346432549612, 30.43721968787057, 44.954421043395996, 37.89347055980137, 0.12405958372567381, 0.07061509189328977, 0.05244438549769776, 0.0517988544223564, 0.09041441125529152, 0.10835634956934623, 0.10132873523980379, 0.050910689402371645, 0.04247249237128666, 0.06560370365956, 0.1359549675668989, 0.05197598598897457, 0.22830143943428993, 0.09197901801339217, 0.0890024680910366, 0.09636274778417178, 0.03853890273187842, 0.10974988407854523, 0.11691454212580409, 0.043310822386826785, 0.04818447818979621, 0.0788900028648121, 0.05167823464476636, 0.030527874029108455, 0.0704323895541685, 0.024780753667333295, 0.03962150535413197, 0.05444854384820376, 0.11369927001318761, 44.28245728356497, 57.69714627947126, 53.86342559541975, 34.49771567753383, 26.078376735959733, 84.17838478088379, 34.5009674344744, 1.0192892253398895, 0.07083904916154486, 0.10384550304817301, 0.2505589893886021, 0.30888702667185236, 0.29497429036668366, 1.8156847996371133, 0.21929358850632394, 0.019952844695321152, 0.06296550522425345, 0.12855704953627928, 0.0723207728671176, 18.796285935810634, 61.55215276990618, 64.29435661860875, 74.11548941476005, 64.05171162741524, 74.88509968348912, 66.66352558135986, 70.91306468418666, 63.07378741673061, 67.4328509739467, 70.43759945460728, 78.65768664223808, 78.883864402771, 79.03200694492885, 75.44681985037667, 79.82280921936035, 80.67320619310651, 77.05975382668632, 77.18192400251115, 80.04768071855817, 68.56902040754045, 73.35163225446428, 76.0751176561628, 77.35956164768764, 76.98601259504045, 76.01234763009208, 78.24491500854492, 75.07976041521344, 77.21055058070591, 74.18919590541294, 73.14320714133126, 73.1616962977818, 74.5353343146188, 74.03184700012207, 71.59840720040458, 71.44826357705253, 70.5141269138881, 67.41737733568463, 66.48655496324811, 65.63469886779785, 65.14719935825893, 65.14303738730294, 67.07711015428815, 65.07026890345982, 63.68081678662981, 65.37400940486363, 55.72281912394932, 58.440402030944824, 65.13720090048653, 60.62122617449079, 60.0234101159232, 58.04155806132725, 57.68963875089373, 59.057096345084055, 62.7081732068743, 63.047696931021555, 59.95173249925886, 62.373471532549175, 63.209159169878276, 61.40116146632603, 65.17700713021415, 63.62323011670794, 64.08231149400983, 65.3199941090175, 65.85083648136684, 65.70094299316406, 64.42618479047502, 65.33137525830949, 67.96739673614502, 65.10324505397251, 64.83358546665737, 63.12776102338518, 62.087608746119905, 64.60725484575543, 63.67161042349679, 65.22936875479562, 65.10699708121163, 65.95373930249895, 66.1801255089896, 61.44863850729806, 59.60200187138149, 62.74335888453892, 59.070582798549104, 63.89967114584786, 65.95545550755092, 57.76881694793701, 61.051590647016255, 63.619721276419504, 66.96689782823834, 65.4972426550729, 65.35363033839634, 58.70574678693499, 62.61126668112618, 64.93529319763184, 66.44506726946149, 66.68364061628068, 66.99562168121338, 68.18004635402134, 68.78141294206891, 62.60452692849295, 56.74032027380807, 64.20498888833183, 63.04632813589913, 62.8896393094744, 58.15764161518642, 66.46606472560337, 53.671679633004324, 30.222826072147914, 21.71194461413792, 0.6312329311455999, 0.09311386783208166, 0.06691991910338402, 0.044043341651558876, 1.8165266173226493, 0.4831137848751885, 0.02932653117126652, 0.11929563007184438, 0.18065211842102663, 1.3254155644348689, 6.085336983203888, 5.766475030354091, 17.39196641104562, 79.80370167323521, 25.207941157477244, 26.48902222088405, 41.098295892987935, 50.20743635722569, 45.20750570297241, 0.23631425946950912, 0.10146456437983684, 0.06512133990015302, 0.02725169830955565, 0.0928271867867027, 0.04654701712674328, 0.07551136666110583, 0.03637670339750392, 0.06962479717497315, 0.08582090559814658, 0.08848185531262841, 0.03951158607378602, 0.03080351191705891, 0.10965045155691248, 0.2861311877412455, 0.18670047101165566, 0.1525364906660148, 0.28896504853452953, 0.25992290835295406, 0.1179732196033001, 0.17760443767266615, 0.14504265492515905, 0.11438682276223387, 0.20395404233464173, 0.13989712031824247, 0.24391550730381692, 0.15028509790343897, 0.33586251203502926, 0.45138983002730776, 53.40116194316319, 68.74005726405552, 57.72215979439871, 42.38031843730381, 43.98996591567993, 90.22228922162736, 54.34695420946394, 2.6012757079941884, 0.4513571789222104, 0.28552468600017683, 0.6909709913390023, 0.6694113282220704, 0.8197586206453187, 6.461064296109336, 0.41575444649372784, 0.4393330769879477, 0.2733662341322218, 1.047080825482096, 0.2791623616857188, 20.414328575134277, 72.34784684862409, 70.08721569606236, 78.85504327501569, 68.93799754551479, 84.86884811946324, 72.5060920715332, 77.31922040666852, 71.72558007921491, 74.01492118835449, 73.53466864994594, 82.93128735678536, 81.31289904458183, 81.90502452850342, 80.634094783238, 81.97270693097795, 85.49661091395787, 80.3175140108381, 80.03329099927629, 83.50616046360561, 68.92567838941301, 72.60899489266532, 78.3151751926967, 80.31496402195522, 78.4386238370623, 79.08556365966797, 80.18564414978027, 78.24009990692139, 81.60680784497941, 76.53837490081787, 75.86401053837368, 77.3617503302438, 76.250670841762, 79.88400200435093, 75.29409844534737, 76.66646494184221, 75.2801742553711, 70.89972414289201, 69.68515818459647, 71.16049698420933, 70.33361966269356, 71.00148051125663, 70.52548027038574, 69.25530787876674, 66.17135688236782, 69.71202686854771, 59.81538105010986, 61.96138777051653, 69.25937257494245, 63.95651435852051, 62.46258217947823, 63.298478262765066, 62.53000749860491, 63.76158959524972, 66.42243698665074, 67.54222951616559, 62.80810219900948, 67.22865731375558, 64.07814952305385, 61.0967469896589, 66.76047379629952, 67.50655051640102, 68.67318780081612, 70.11698872702462, 68.0953825541905, 70.73019504547119, 69.62390981401715, 69.77246229989188, 71.10753781454903, 67.30299609048026, 67.95682852608817, 66.24660587310791, 64.99679170336042, 68.20480973379952, 67.9573426927839, 70.86866569519043, 69.82448346274239, 69.78297492436, 69.81392914908272, 65.43885694231305, 61.587282861982075, 67.16851370675224, 60.19031279427664, 66.83171367645264, 64.72240734100342, 62.64181791033064, 63.156978198460166, 66.26854828425816, 70.88757869175502, 69.32012067522321, 67.20777102879116, 61.198663166591096, 66.57281684875488, 66.22478852953229, 70.06531497410366, 69.80953093937465, 71.21822956630162, 72.7696372440883, 74.15843623025077, 66.25905009678432, 59.79532854897635, 66.70295660836356, 60.867678778512136, 62.498414039611816, 58.47289180755615, 65.59875583648682, 60.333014896937776, 49.45469978877476, 23.696836505617412, 0.4669363158089774, 0.5129498381699834, 0.19296742044389248, 0.16220903449824878, 2.137827822140285, 0.748108253947326, 0.20698513968714646, 0.20131398471338408, 0.36256427637168337, 2.3524479057107652, 10.786034345626831, 10.131091935294014, 27.15944869177682, 89.60033512115479, 36.6442608833313, 45.05788319451468, 45.672882148197715, 60.42122227805001, 54.36828865323748, 0.5006592891045979, 0.19687553787870066, 0.18248098742749008, 0.1356764832245452, 0.19905064973448003, 0.23722458205052785, 0.1370291563549212, 0.07740762098027126, 0.1579823720135859, 0.19360460553850445, 0.28910330682992935, 0.09788860340735742, 0.26564550985183033, 0.2520469624016966], [0.05878214005913053, 0.1733287985303572, 0.11316182278096676, 0.20457663892635278, 0.061720400250383785, 0.051215924987835545, 0.03767444572544523, 0.010759354219771922, 0.029250871124012128, 0.09266797532992703, 0.13379000659499848, 0.03617205045052937, 0.03260944304721696, 0.13310991094580718, 4.937091580459049, 54.45682954788208, 53.5770069531032, 44.240920952388215, 40.609570026397705, 44.12854078837803, 59.17529909951346, 2.5672836005687714, 0.5975897535681725, 0.09086628165096045, 0.3116658718458244, 0.21412762999534607, 0.366795403616769, 0.1629484612494707, 0.29853936763746397, 0.973035393016679, 0.3791851002190794, 0.2011521133993353, 0.26434625099812237, 0.9824245806251253, 33.120541027614046, 56.663633005959646, 60.32271071842739, 60.51552322932652, 52.02500867843628, 43.89935098375593, 60.23111261640276, 65.50512191227504, 51.91619641440255, 60.8662474496024, 70.23346832820347, 74.22737625667027, 74.36422797611782, 74.89400032588414, 71.11550739833287, 75.95106451851981, 72.29118428911481, 73.62691293443952, 78.70479542868478, 70.6458022253854, 68.25880418504987, 76.37444605146135, 75.15125737871442, 76.90751879555839, 73.9918601172311, 72.1457029070173, 71.30458872658866, 72.3140924998692, 70.05594185420445, 68.319427217756, 70.05558054787772, 72.15120588030133, 68.03943565913609, 68.22364630017961, 68.3503189086914, 63.48888669695173, 65.51887239728654, 65.86391993931362, 63.43542725699288, 65.62577738080705, 62.41013022831508, 63.235791615077424, 62.950581959315706, 60.085047585623606, 61.609517097473145, 55.393391132354736, 50.96485948562622, 53.96564054489136, 53.222454275403706, 49.640758650643484, 50.20688744953701, 51.76519468852452, 53.911434173583984, 54.61457797459194, 62.18636349269322, 53.202978474753245, 52.908454758780344, 52.276616845812114, 56.08928796223232, 60.91041019984654, 59.87508692060198, 56.402398109436035, 61.82270172664097, 58.011934416634695, 64.45231001717704, 62.02964687347412, 60.64544759477888, 63.54913452693394, 65.91808114733014, 62.86992032187325, 63.50401987348284, 60.50665732792446, 61.47051838466099, 60.29611301422119, 62.79752704075405, 61.9458863394601, 62.422609192984446, 63.1948458807809, 65.8194306237357, 60.79985046386719, 58.83107839311872, 56.965806688581196, 61.36458614894322, 57.385088784354075, 61.59880992344448, 54.191345827920095, 57.53187642778669, 60.78036076681954, 64.32070418766567, 62.981015069144114, 63.38997214181082, 59.965455191476, 56.61573907307216, 58.1043176651001, 58.79728930337088, 62.6509895324707, 64.36642333439418, 68.66500282287598, 65.6213652747018, 62.02785423823765, 56.83318642207554, 58.6424834387643, 62.95356273651123, 57.9876435143607, 54.14486585344587, 55.762875488826204, 50.82745885848999, 20.319131306239537, 25.989342519215175, 4.9220621926443915, 0.1811960320919752, 0.2011448937867369, 0.019143976670290743, 0.9645800867250988, 0.1709994285234383, 0.13091147105608666, 0.14038976388318197, 0.0875430139047759, 0.23074747675231524, 0.491303485419069, 0.37089223521096365, 3.1663894184998105, 45.94988945552281, 38.971966470990864, 33.82091249738421, 31.352794238499232, 37.04599182946341, 40.98373399462019, 0.8428246315036501, 0.15445949962096556, 0.17646107902484282, 0.1078639163502625, 0.0605064807459712, 0.05328008279736553, 0.032364098355174065, 0.11472482819642339, 0.030436278586941104, 0.05501441830503089, 0.12173109581427914, 0.15296229853161744, 0.16664408865783895, 0.19374130320336136, 0.13740984164178371, 0.017884023653875505, 0.07724327301340443, 0.06326360601399626, 0.06811570815209832, 0.009043048235720821, 0.1080294856801629, 0.0531437447560685, 0.03745565889403224, 0.11044799483248166, 0.11420333332249097, 0.034775303078017065, 0.20273664194558347, 0.2779826878436974, 5.858338900974818, 62.707638195582796, 61.19182613917759, 62.5959597996303, 25.319937433515275, 42.92139203207833, 70.729722567967, 4.058110586234501, 0.4476943926087448, 0.1525147504040173, 0.19609055428632668, 0.1386639100632497, 0.4121670589915344, 0.0810883002621787, 0.4746627669249262, 1.1666929785694395, 0.6134711099522454, 0.5984191947749683, 0.4782964033739907, 1.357618293591908, 43.69507047108242, 68.25990894862584, 67.41335432870048, 67.15678514753068, 65.26260893685478, 53.4286663872855, 63.709373882838655, 68.9998643057687, 57.94781296593802, 66.50144495282854, 75.24137551443917, 77.05541815076555, 76.49825600215367, 75.18996579306466, 74.75587013789585, 78.23139381408691, 74.46125262124198, 78.51811122894287, 80.81074578421456, 70.22215666089738, 72.36665562220982, 77.27634307316372, 76.34709794180733, 77.80148792266846, 75.56352874210903, 73.25155735015869, 73.67586994171143, 76.18605259486607, 72.35057054247174, 71.95949813297817, 73.85618264334542, 74.23696477072579, 70.40662438528878, 73.06000941140312, 69.2657927104405, 65.29541138240269, 67.91265187944684, 66.11604922158378, 63.94424383980887, 65.87697560446603, 64.82246834891183, 65.29115213666643, 65.86015401567731, 64.90843146187919, 63.37147603716169, 57.83365753718785, 53.39619050707136, 56.82650572913033, 55.935770988464355, 54.49834850856236, 51.993707043784006, 56.22996813910348, 59.847641536167686, 58.54614666530064, 63.789715903145925, 57.62545476640974, 55.341672216142925, 55.07393380573818, 61.97790363856724, 61.99050767081124, 60.06218106406075, 60.88451426369803, 63.346962792532786, 61.85753304617745, 63.85298619951521, 63.945216587611604, 63.3594000680106, 64.36474881853376, 65.12743868146623, 63.798359462193076, 66.22676876613072, 64.18771566663469, 63.99677916935512, 62.49380043574742, 65.16755758013043, 62.64533369881766, 62.28932189941406, 64.71428489685059, 67.50451469421387, 62.45658588409424, 61.31139768872942, 59.42510073525565, 63.227655274527415, 59.70511313847133, 63.658165659223286, 59.44393035343715, 59.0955685206822, 61.25084413800921, 64.26159586225236, 65.23955481392997, 65.90990311758858, 66.42445891244071, 59.30584880283901, 63.19964708600725, 62.44621917179653, 64.46432345254081, 65.90357330867222, 67.36446680341447, 66.3934143611363, 64.10607433319092, 60.99712371826172, 59.865255219595774, 62.25362205505371, 64.49028887067522, 60.38275705065046, 59.83885901314871, 69.59000260489327, 39.563817501068115, 30.709596020834788, 10.115867563656398, 0.26628422843558447, 0.216937619926674, 0.05739976066563811, 1.336437035884176, 0.11818792165390082, 0.13487707397767476, 0.062042507609086375, 0.1290516879941736, 1.3116581312247684, 0.7540753994669233, 0.2618802104677473, 2.2433663989816393, 57.67530114310128, 41.828291007450645, 28.137039388929093, 45.83535187585013, 41.27410963603428, 49.82753665106637, 1.3285724350384303, 0.059754568950406144, 0.15535720145063742, 0.013967666259434606, 0.008654478371941617, 0.041311559666480334, 0.01846095483883151, 0.03071684603180204, 0.04119703313335776, 0.033456583839974234, 0.045404727171574316, 0.07884380820074252, 0.13074229870523724, 0.10591605944292885, 0.18199887472604, 0.16261534126741545, 0.2214343664901597, 0.20548674437616551, 0.18414866365492344, 0.1186239482568843, 0.11029838464621987, 0.14698481213833603, 0.1690668115126235, 0.20241102656083448, 0.2606167239802224, 0.16739722181643757, 0.4093117836330618, 0.4656589872070721, 7.604046872683933, 73.59662573678153, 68.27618857792446, 58.5002121244158, 58.06518193653652, 60.28960255214146, 80.51791395459855, 12.264160241399493, 1.235712149313518, 0.6178099885582924, 0.2971396584595953, 0.272332526743412, 0.6095874469195093, 0.16551101660089834, 1.2820123391492027, 2.654716257538114, 0.925641187599727, 1.0782702033008849, 1.0191238799265452, 1.8849889550890242, 48.63377707345145, 76.2501288822719, 73.23652839660645, 73.06043325151715, 74.17779391152519, 66.2036521094186, 72.27509920937675, 80.59426076071603, 66.80839552198137, 72.11235850197929, 77.43870857783726, 81.42839894975934, 80.01032025473458, 76.45216165270124, 78.20798533303397, 79.66569655282157, 75.9302338191441, 79.96313503810337, 85.28354440416608, 73.11000864846366, 70.8256424495152, 81.83856500898088, 79.75450842721122, 81.31877027239118, 79.54627091544015, 76.00057043348039, 76.785154070173, 78.65077318464006, 74.02963052477155, 74.02785873413086, 75.67248344421387, 78.80841391427177, 75.49780573163713, 78.3164814540318, 73.2387170791626, 70.00701263972691, 69.4206611088344, 72.03573376791817, 69.69923523494175, 71.81431552342006, 70.04992471422467, 67.78046240125383, 69.37575490134103, 69.60723413739885, 68.47543512071881, 63.125600133623394, 56.37839903150286, 61.45217514038086, 57.90435545785086, 56.58432626724243, 54.249999046325684, 59.0296995980399, 61.19071442740304, 61.14258425576346, 67.29073251996721, 59.98806462969099, 58.59932817731585, 58.57771927969796, 63.96448394230434, 66.70716721670968, 63.010822841099326, 63.278189522879465, 66.55857304164341, 63.64768082754952, 70.55519076756069, 67.59186049870083, 67.29706927708217, 70.2340589250837, 70.72992406572614, 68.71076365879604, 70.73160552978516, 67.8236107145037, 68.14447852543422, 66.98303849356515, 68.77165767124721, 67.0254294531686, 66.99846349443708, 70.1020987374442, 71.0847338267735, 65.53541605813163, 64.29820592062813, 64.11934539249965, 65.47919818333217, 61.22321115221296, 66.58591420309884, 61.169293131147114, 63.32463823046003, 62.9766446522304, 69.12257644108364, 69.20969990321568, 69.27649988446916, 68.83375372205461, 61.48758316040039, 63.583986691066194, 63.59802900041853, 67.01634120941162, 70.66094235011509, 71.72803974151611, 70.51849733080182, 69.36326204027448, 64.39095742361886, 61.424069677080425, 62.307442801339285, 60.71201828547886, 62.1095997946603, 60.32535798209054, 70.19906084878104, 51.521545682634624, 51.37378876549857, 8.325673750468663, 0.3112340250185558, 0.5537757160408157, 0.22734971264643328, 3.0823368430137634, 0.5501824117132595, 0.447677700647286, 0.27647093896354946, 0.23957869144422667, 2.759664237499237, 2.182687997817993, 0.5500676035881042, 5.439996114798954, 68.54770333426339, 57.62947429929461, 53.722950390407014, 42.98572540283203, 47.54834338596889, 60.4473683493478, 1.8833596025194441, 0.16280290191727026, 0.3316914758511952, 0.15033446811139584, 0.20184796463165963, 0.10391738704804863, 0.10214435468826975, 0.16348269901105336, 0.188045951670834, 0.14129073625164373, 0.36587628722190857, 0.37200975524527685, 0.21012469407703194, 0.22878314501472882], [0.23226386681199074, 0.16968354556177342, 0.1274019115205322, 0.1003706573641726, 0.08835586493036576, 0.08589344777699028, 0.05289158417976328, 0.04382094840652176, 0.05287409154698253, 0.03628758800082973, 0.03192907598401819, 0.006081270444805601, 0.13660701257841928, 0.0876960778342826, 15.743047714233398, 63.89142363412039, 31.449457577296666, 30.383430208478654, 41.26489632470267, 52.90504666737148, 24.16558109010969, 2.893469823258264, 0.1573266764836652, 0.05320140666195324, 0.2669665903917381, 0.15183834598532744, 0.25601785789643017, 0.5532110663396972, 0.21219491798962864, 0.3259282979582037, 0.15483179821499757, 0.9104573109320232, 0.21199867209153517, 4.216632434300013, 58.690307889665874, 58.694768633161274, 51.11549643107823, 49.858688899448936, 51.021716594696045, 40.84278283800398, 52.80796296255929, 49.976325375693186, 52.02826738357544, 64.0662819998605, 71.74106761387416, 69.64618573869977, 72.49511391775948, 69.44282586233956, 72.42506912776402, 76.13157871791294, 72.5299243927002, 79.84246567317417, 72.17257159096854, 65.6575653893607, 73.6216253553118, 71.79921013968331, 74.52182006835938, 70.66636194501604, 69.80670302254813, 71.04717881338937, 74.61505099705288, 70.36390686035156, 68.61747714451381, 68.86862673078264, 66.29847417558942, 68.02222497122628, 70.44743115561349, 67.17909581320626, 64.66224983760289, 65.0937260219029, 63.72112328665597, 62.332352093287874, 61.92074080875942, 64.60566370827812, 62.0607886995588, 61.5857264654977, 62.2822972706386, 63.342578479221885, 55.01130274363926, 50.46754911967686, 50.28180987494332, 52.522152287619456, 56.67546926225935, 53.24002626964024, 49.07505021776472, 56.24485118048531, 58.76616137368338, 57.67942142486572, 59.82635225568499, 55.74762766701834, 52.969157695770264, 54.31871673039028, 52.82213033948626, 51.54788630349295, 52.773979323250906, 54.324674810682026, 58.04276009968349, 56.96961777550833, 58.26789215632847, 58.600321769714355, 57.05967337744576, 57.90455000741141, 60.701234681265696, 60.20047106061663, 61.466036796569824, 59.622457368033274, 60.05664334978376, 60.849189622061594, 62.103825841631206, 61.71467113494873, 62.82955823625837, 62.596640723092214, 65.0239452634539, 62.49324457986014, 58.75525965009417, 58.47250965663365, 58.5580906186785, 59.440775871276855, 54.74161883762905, 54.756467138017925, 51.67447553362165, 56.34419304983956, 55.751480443137034, 61.72887325286865, 62.64561857495989, 63.9007967540196, 59.12376431056431, 56.49981532778059, 56.92907503673008, 61.43366513933454, 63.527720178876606, 64.50976467132568, 65.70526477268764, 63.1599520274571, 58.89623165130615, 61.631376130240305, 62.16625540597098, 65.3591194152832, 55.10183082308088, 56.929960932050435, 56.87460115977696, 39.610287053244456, 18.851843731743948, 20.78053511892046, 1.0725193747452326, 0.16370801334934576, 0.14746449568441936, 0.08800826501101255, 0.08529234038931982, 0.235854158444064, 0.08904600289783307, 0.17234706692397594, 0.040064049285969565, 0.10363911983690091, 1.0466431975364685, 0.8484630403774125, 25.49376572881426, 39.76745877947126, 19.255888428006852, 32.34385401862008, 32.948857988630024, 42.55163322176252, 0.5029957294464111, 0.04128031312887158, 0.06501320177423102, 0.10414551730666842, 0.10223527159541845, 0.13131351662533625, 0.09269941185734101, 0.13245296691145214, 0.05266292466382895, 0.05896231824798243, 0.03023038392088243, 0.013968003830606384, 0.09057822996484381, 0.15421798186642782, 0.03859626268967986, 0.06215536155338798, 0.07111947411405188, 0.0413866293882685, 0.013891568557093186, 0.0448310156352818, 0.026319112994575074, 0.10122576755072389, 0.05317134756062712, 0.04964260584009545, 0.12654302189392702, 0.04957464037995253, 0.20866946716393742, 0.2043853056217943, 18.862436260495866, 68.00620937347412, 47.61072431291853, 43.45859200613839, 28.82318615913391, 61.67782483782087, 28.68769976070949, 3.016344589846475, 0.0316588765542422, 0.032999556578163586, 0.252186116363321, 0.13081187568604946, 0.1356200155402933, 0.46556144101279123, 0.18021417834929057, 0.23817325543080056, 0.015976763496707593, 1.0130764501435416, 0.17354610615542956, 7.056839321340833, 68.73003101348877, 61.87328461238316, 65.67655481610979, 60.22467163630894, 63.354876790727886, 49.894267150333945, 57.213728836604524, 54.25456748689924, 61.31765801565987, 65.76738861628941, 76.5328093937465, 74.09394305092948, 77.97095448630196, 73.8767979485648, 78.38355936322893, 78.65235042572021, 76.29989188058036, 80.43471622467041, 73.99591786520821, 67.54382760184151, 75.90461581093925, 73.72802312033517, 76.32409245627267, 72.88606820787702, 71.78998293195451, 72.31210531507219, 76.33429936000279, 73.03967898232597, 71.5010073525565, 69.95592253548759, 70.09954874856132, 70.4216811316354, 72.18318843841553, 66.71585246494838, 65.95788737705776, 66.639283316476, 64.16899027143205, 64.69108486175537, 64.25241729191372, 65.45764487130302, 64.39067949567522, 63.277828216552734, 65.20039476667131, 65.5392097745623, 57.007766859872, 54.20715297971453, 54.67271702630179, 57.74537025179182, 58.78351102556501, 56.29891511372158, 54.046468939099995, 60.02029037475586, 61.53076621464321, 61.3395448412214, 62.94565568651472, 60.225505420139854, 58.17411926814488, 57.4575445992606, 54.657663754054475, 53.5078376361302, 54.678004605429514, 57.42997762135097, 57.97530351366316, 58.232428550720215, 57.56787157058716, 58.766147477286204, 59.36668722970145, 58.90888432094029, 59.85373510633196, 58.98108305249895, 60.739658219473704, 61.10208320617676, 62.1774628502982, 64.74762235369, 62.205012457711355, 64.2064619064331, 64.87077222551618, 64.13636153084892, 65.48327677590507, 65.23644202096122, 58.781315394810264, 62.02911186218262, 61.338704109191895, 62.82743903568813, 56.82912867409842, 59.71955149514334, 59.0839580808367, 59.86955615452358, 56.637334074292866, 61.54578821999686, 65.238602910723, 67.13762896401542, 61.6508241380964, 62.13717024666922, 61.63917200905936, 64.41638783046177, 63.98919868469238, 65.41442012786865, 65.79753684997559, 64.8254143851144, 60.683155468532014, 63.09676510947091, 61.55292401994978, 65.82038947514125, 63.959342275347026, 62.269866943359375, 61.57316412244524, 62.511379378182546, 31.604051521846227, 29.736983707972936, 2.740591432367052, 0.11382997621382986, 0.10879042877682618, 0.037948034437639375, 0.07292118814906903, 0.14931040949055127, 0.0716224517673254, 0.14853613318077155, 0.13852046776030744, 0.1368269393486636, 0.8002792373299599, 1.0026459012712752, 28.688472747802734, 50.99149540492466, 18.848340102604457, 31.30336127962385, 39.57521602085659, 54.0152576310294, 1.1745203414133616, 0.04279691692707794, 0.022789105806233625, 0.07317644623773438, 0.043882681522518396, 0.07316306552716664, 0.021641596220433712, 0.11192116899681942, 0.03715652333838599, 0.05889701603778771, 0.014590789563953876, 0.03798652094389711, 0.025251166728724326, 0.057517791832132, 0.21901370638183185, 0.20055383550269262, 0.2147547592009817, 0.1487411321806056, 0.17831149830349854, 0.15983785316348076, 0.11459889209696225, 0.17827956644552095, 0.1465475098895175, 0.14057902087058338, 0.22253423104328768, 0.15944074732916697, 0.33007354981132914, 0.3120671845972538, 22.644088881356375, 82.65527016775948, 42.82440560204642, 40.157916273389546, 62.47904941013881, 72.81090954371861, 35.832839829581125, 3.09638848900795, 0.23620031986917767, 0.15723189871226037, 0.5352162633623395, 0.27988557144999504, 0.3331325485238007, 0.5717378407716751, 0.5522034146956035, 0.991825059056282, 0.5432445811373847, 1.2607720217534473, 1.0177191495895386, 7.244823702744075, 77.14755126408168, 67.91213076455253, 70.09446266719273, 71.26976435525077, 73.30991527012416, 59.00544343675886, 69.7688353402274, 64.47500283377511, 69.31895337785993, 71.47256142752511, 81.02869687761579, 78.4631301334926, 81.27353055136544, 75.94497789655412, 81.7274980545044, 82.21845776694161, 77.80551092965263, 86.00218268803188, 79.36067758287702, 71.18691403525216, 82.86301435743059, 77.851945740836, 80.60022231510708, 76.76612990243095, 75.0221529006958, 76.87087399618966, 80.44415882655552, 77.54449490138462, 75.31968866075788, 72.36796883174351, 73.51008592333112, 73.76191643306187, 74.39009611947196, 73.22161061423165, 69.65790734972272, 69.9744325365339, 68.66029889242989, 68.98899037497384, 67.71505900791713, 71.29847431182861, 67.790023122515, 66.71136392865861, 67.40616294315883, 71.33562632969448, 61.82572419302804, 56.0208968435015, 56.43179941177368, 60.09708881378174, 60.540731293814524, 59.68635300227574, 54.05523756572178, 60.99578966413225, 64.78209236689976, 65.38423715318952, 66.7906984601702, 63.65783214569092, 60.53203909737723, 60.237949643816265, 58.551100730895996, 56.55244445800781, 57.00978878566197, 60.44564519609724, 62.12054320744106, 62.12687996455601, 63.50870295933315, 62.246027673993794, 61.49027211325509, 62.64375645773751, 65.34994084494454, 65.97033160073417, 64.36916787283761, 63.837394441877095, 66.31703281402588, 66.81166117531913, 67.20699283054897, 66.83429145812988, 68.37640244620187, 67.91142204829625, 70.84759875706264, 68.55012130737305, 64.21658543178013, 63.02474703107561, 63.21672575814383, 64.53093583243233, 56.4232496534075, 62.64675807952881, 59.04994664873396, 62.70912511008126, 59.34372343335833, 66.72669860294887, 69.04175499507359, 70.42715631212506, 65.42410591670445, 65.35786873953683, 62.82982226780483, 66.83090073721749, 66.20969704219273, 69.04695224761963, 69.83268928527832, 67.75102288382394, 67.43123204367501, 66.83452074868339, 64.89230469294957, 64.8400959287371, 63.83151626586914, 64.12040151868547, 60.628688539777485, 68.23353358677456, 44.95831898280552, 42.735308851514546, 1.308528402021953, 0.26637699774333407, 0.1915934413139309, 0.14894033649138042, 0.3388475232890674, 0.41215492678540094, 0.13782210594841413, 0.4899026091609682, 0.4001512351844992, 0.2204653099179268, 1.7204847080366952, 1.307567053607532, 38.57207332338606, 56.101099899836946, 34.554579734802246, 42.525122370038716, 44.30669607434954, 66.27744197845459, 1.9246045436177934, 0.16495518785502228, 0.1764726819736617, 0.27218077917184147, 0.1509322031800236, 0.21325283550790378, 0.12937737123242446, 0.2972334591405732, 0.1939079649746418, 0.1430618619280202, 0.15060379223099776, 0.2172745939876352, 0.13610850647091866, 0.1810005054410015], [0.1918844242713281, 0.15215894021093845, 0.08092720926340137, 0.08342246072632925, 0.09497729462704488, 0.08629165962338448, 0.03205097480011838, 0.06365058810583182, 0.0728673328246389, 0.03697097793753658, 0.028418405347370675, 0.07170072756707668, 0.09814513035650764, 0.030327848690961088, 30.822049140930176, 50.069948877607075, 25.831595829554967, 38.60263497488839, 26.509326594216482, 52.70836748395647, 1.4837252753121513, 3.1451129487582614, 0.12337137279765946, 0.11024283298424312, 0.11396226340106555, 0.18711639940738678, 0.21586866942899569, 0.3560198332582201, 0.19621646324438707, 0.548679375222751, 0.23498433083295822, 0.5456735193729401, 0.5497964067118508, 25.66782852581569, 55.928583077022004, 49.69620874949864, 52.22925445011684, 43.92309297834124, 44.57830810546875, 41.88049629756382, 46.67440244129726, 46.24317291804722, 49.988922459738596, 56.56735181808472, 63.62167372022356, 68.11251681191581, 69.68571404048375, 73.63274942125592, 75.0302961894444, 71.0500762122018, 75.10151522500175, 78.54213809967041, 68.99929455348423, 66.90737261090959, 69.00747953142438, 67.94492626190186, 67.39901324680874, 67.41832229069301, 70.72110680171421, 70.19120938437325, 68.67492485046387, 67.65381063733781, 69.29581587655204, 68.68009431021554, 66.44346918378557, 66.917982510158, 66.18868568965367, 64.94618797302246, 64.48877416338239, 60.26377609797886, 59.2017856325422, 62.89899853297642, 63.60500499180385, 62.403793471200125, 65.28564916338239, 62.10208184378487, 62.59083202907017, 53.157519885471885, 52.226735728127615, 57.09133979252407, 57.5802115712847, 57.55802249908447, 51.69274582181658, 47.87702792031424, 53.79100799560547, 52.79174586704799, 55.68186296735491, 56.96434409277779, 61.0855256489345, 58.942735944475444, 56.621596404484336, 57.62235239573887, 52.12131418500628, 47.494081429072786, 46.906218664986746, 46.93931640897478, 46.73410483769008, 52.197150298527305, 55.761909689222065, 55.64024673189436, 58.238063539777485, 56.27554832186018, 55.976622922079905, 56.593563897269114, 57.48216554096767, 58.25899498803275, 59.3074677331107, 56.974422454833984, 57.348909514290945, 57.94096204212734, 58.325221742902485, 61.7319860458374, 62.062372888837544, 62.10351317269461, 59.977822984967915, 59.364060810634065, 59.20707321166992, 60.975834437779014, 56.46712057931082, 52.96848372050694, 58.15100608553205, 56.6233160836356, 60.64915098462786, 55.58473409925188, 58.34353024618966, 65.55152893066406, 62.00256279536656, 57.897105012621196, 56.572194712502615, 55.99042551858084, 59.242474283490864, 63.85792636871338, 60.87275096348354, 65.08028820582798, 55.40779822213309, 56.6794992174421, 65.05819293430874, 63.72595228467669, 60.93193571908133, 51.057576247623985, 56.042137486594065, 51.50534248352051, 28.123412234442576, 21.623164006641932, 14.290150727544512, 0.2039483426404851, 0.14919034950435162, 0.1258207077958754, 0.08401374971227986, 0.08970614283212594, 0.0841364288436515, 0.12651228425758226, 0.04939747827925852, 0.06622077697621924, 0.1168303902127913, 0.24650542118719646, 6.174365554537092, 54.23193720408848, 27.684470210756572, 54.93030759266445, 29.159796851021902, 48.83916234970093, 3.5889866735254015, 0.13676863961986133, 0.06523956784180232, 0.06780918674277407, 0.0893376711755991, 0.06923071760684252, 0.08924725638436419, 0.04878209112212062, 0.16294186588908943, 0.04765423021412321, 0.03479779312121017, 0.05467237558748041, 0.15558722482195922, 0.17706744505890779, 0.09489127674273082, 0.0669824800321034, 0.04576736681961587, 0.03375473891251853, 0.14917852942432674, 0.04001532029360533, 0.04148059291765094, 0.029514288596276726, 0.012153928583887006, 0.06002822212342705, 0.11161379941872188, 0.07272811779486281, 0.03269595286941954, 0.08720019087195396, 36.6424126625061, 57.62096275602068, 39.073281628744944, 29.624784197126115, 24.145302772521973, 65.80344976697648, 1.9457038342952728, 3.6378998202936987, 0.2763410673609802, 0.15362287951367243, 0.09947077743709087, 0.039365782468978844, 0.19242331678313868, 0.3988829446690423, 0.7267005283917699, 0.2574920973607472, 0.45510426642639296, 0.31545331861291614, 0.3033879074667181, 34.58429370607649, 64.2383610861642, 56.84806946345738, 66.54578140803746, 59.160693986075266, 57.32750906263079, 49.01133523668562, 53.22912107195173, 50.94007873535156, 55.38714470182146, 61.23120852879116, 64.35803685869489, 70.06002044677734, 71.75496401105607, 76.02923175266811, 78.07021645137242, 74.01418467930385, 78.65829113551548, 79.38369001661027, 71.43461731501988, 72.28926658630371, 74.26553576333183, 72.48938860212053, 73.53721169063023, 71.4804059437343, 72.27500888279506, 72.71321787152971, 71.04466356549943, 67.286744253976, 71.86884498596191, 71.0424609865461, 69.72882066454206, 70.50891576494489, 68.70034136090959, 66.62321213313511, 67.37788377489362, 63.37055887494768, 62.011143820626394, 62.25087056841169, 64.79393209729875, 66.03670079367501, 64.20388412475586, 63.8723577771868, 62.49802494049072, 55.06920903069632, 55.29707520348685, 60.37956782749721, 62.39832523890904, 61.758569853646414, 54.87036200932094, 50.24743366241455, 58.337054525102886, 55.95152602876936, 57.63745430537632, 59.981345721653526, 63.12837246486119, 60.736066000802175, 60.817957469395225, 59.93291677747454, 54.93266998018537, 51.187517983572825, 50.563552379608154, 49.16399758202689, 49.86201013837542, 54.11309174128941, 55.33532156263079, 58.564066069466726, 57.52172858374459, 58.49695341927664, 57.35206399645124, 57.574944836752756, 59.15827601296561, 56.79093442644392, 59.31267193385533, 59.07165976933071, 60.33446707044329, 62.61444895608084, 60.68203680855887, 63.913859367370605, 63.416910307747976, 65.31065573011125, 63.327160426548545, 61.87035942077637, 61.44241292136056, 63.14764676775251, 62.00741263798305, 57.23143284661429, 63.335838726588655, 60.74329907553536, 63.512677328927175, 57.414055824279785, 58.05570806775774, 69.24594170706612, 66.63416944231305, 60.11042935507638, 60.434048652648926, 60.23480905805315, 60.629063742501394, 66.89692946842739, 63.621736254010884, 65.13724953787667, 58.79810919080462, 56.13106748035976, 64.50587368011475, 61.845213890075684, 64.31966195787702, 61.614318302699495, 56.223398617335725, 64.50988973890031, 51.441481590270996, 29.341950825282506, 24.700455154691422, 0.7005309526409421, 0.1506525788988386, 0.04934031170393739, 0.11256379594228097, 0.1545237297458308, 0.06549657655081578, 0.07096482241260153, 0.11382380833051034, 0.11339405139109918, 0.10120570327022246, 0.40475504100322723, 6.211917528084346, 60.91976247514997, 28.552015338625225, 51.44752999714443, 35.34364495958601, 56.4154120853969, 4.782024724142892, 0.1540285756013223, 0.07051794603466988, 0.09039818069764546, 0.10941276752523013, 0.0629013700942908, 0.06575038935989141, 0.006442959719736661, 0.09967315729175295, 0.04966009847287621, 0.052339429701013226, 0.06363435754818575, 0.12655695900321007, 0.09895845635661057, 0.2284222458090101, 0.2664503338081496, 0.10540537363184349, 0.1041477836136307, 0.13017268212778227, 0.15689991866903646, 0.12247612726475511, 0.1752524317375251, 0.19823856545346125, 0.12723366197730812, 0.27512233704328537, 0.22134783970458166, 0.21744574766073907, 0.1927066594362259, 44.06854656764439, 68.29648426600865, 34.09265307017735, 56.8475935118539, 40.690707615443635, 72.89205755506242, 4.327246453080859, 4.333242314202445, 0.364442162747894, 0.36261323945862906, 0.23123732475297792, 0.27220374079687254, 0.2666557127875941, 1.0989506478820528, 1.725575566291809, 0.9668609414781842, 1.1660254086766924, 1.6451300829648972, 1.1524668676512582, 38.74615001678467, 83.02432373591832, 64.42958940778459, 70.7019019808088, 68.30604498726981, 69.49242210388184, 58.73174694606236, 69.86848640441895, 64.32283033643449, 64.59100995744977, 65.69272327423096, 70.92582157679966, 75.18037033081055, 75.72319834572929, 77.04951913016183, 81.05733040400914, 75.40192059108189, 79.90592357090541, 81.1201421192714, 74.8288540158953, 74.93349388667515, 78.12581593649728, 77.39561585017613, 77.68555722917829, 73.18543134416852, 76.21467917306083, 77.11874403272355, 74.22234576089042, 70.98176847185407, 76.66351890563965, 75.46357890537807, 72.97824995858329, 73.88551098959786, 71.97057356153215, 69.54250471932548, 71.61533996037075, 65.22340720040458, 62.97176701681954, 67.22311265127999, 68.49049186706543, 70.88161713736397, 70.10228633880615, 66.6904706954956, 68.09650121416364, 58.95304707118443, 58.60923630850655, 62.525782993861604, 65.79561219896588, 65.10107026781354, 58.35241004398891, 53.44786425999233, 59.35069942474365, 59.81084387642996, 59.805862018040244, 63.75011811937605, 68.40286813463483, 64.75202751159668, 63.88589286804199, 62.95914213997977, 57.218557834625244, 53.228978633880615, 53.56552505493164, 51.75063821247646, 52.930956499917166, 57.387075969151084, 61.046316964285715, 60.36305890764509, 61.00670528411865, 62.59424359457833, 61.34135137285505, 61.496574129377095, 63.27714034489223, 62.346005303519114, 64.42222431727818, 62.7743478502546, 64.25830936431885, 66.41004834856305, 64.62922504970005, 68.0676383972168, 66.99715028490338, 66.98957674843925, 65.6819327218192, 65.33280658721924, 63.7080328805106, 65.12022645132882, 62.19103963034493, 59.751992634364534, 63.71919168744768, 62.855947494506836, 64.46038382393974, 58.508119174412315, 62.48407990591866, 72.63776043483189, 69.29186929975236, 61.843789509364534, 63.39211218697684, 61.644049644470215, 63.33943094526018, 68.36541734422956, 66.16547175816127, 68.40794726780483, 65.37543378557477, 62.04994256155831, 69.04160213470459, 64.715500831604, 62.201531410217285, 60.95049435751778, 58.35755171094622, 64.66678006308419, 61.73249326433454, 45.52180051803589, 31.155725955963135, 0.44950035427297863, 0.35368947259017397, 0.23427116338695797, 0.20337061078420707, 0.3518785440496036, 0.45846933871507645, 0.254664343382631, 0.49160122658525196, 0.2719264913882528, 0.375370159213032, 0.5164746918848583, 10.469955580575125, 69.66771820613316, 44.7704952784947, 79.90237998962402, 40.688657896859304, 70.08422797066825, 5.742810334478106, 0.32508968295795576, 0.11618540196546487, 0.1741271899746997, 0.35942635046584265, 0.10180902946740389, 0.12506544403731823, 0.12602481112948485, 0.2162938259009804, 0.16061991905527456, 0.13535515618111404, 0.22516770687486443, 0.20521300977894238, 0.2595662703471524], [0.07209444751164742, 0.15632293320127896, 0.11360074672847986, 0.07560148968228272, 0.12412568660719053, 0.03478615963831544, 0.09714797564915248, 0.05587832569809897, 0.03134694382814424, 0.08793713418500763, 0.14035373367369175, 0.06796352631811585, 0.05242828046903014, 1.0231953071696418, 49.603679588862825, 42.45185361589704, 37.50112662996565, 36.1215374810355, 30.30109405517578, 43.218243394579204, 0.3824004605412483, 4.546770879200526, 0.30643857376916067, 0.12479538709989615, 0.1636309860540288, 0.0880230502890689, 0.5901008982743535, 0.6370519388999257, 0.717972668153899, 0.16585008054971695, 1.524625954883439, 0.34647094564778463, 7.220079864774432, 43.45019163404192, 41.59271928242275, 45.37146234512329, 40.43546206610543, 41.363946369716096, 37.24363681248256, 48.22579969678606, 41.43701710019793, 43.35514027731759, 50.07445478439331, 52.64598308290754, 56.822385447365896, 60.930011068071636, 63.43374579293387, 67.8183787209647, 66.36907482147217, 71.3295327595302, 75.82359981536865, 70.97453539712089, 65.40317794254848, 70.05899211338588, 71.26629720415387, 71.7356619153704, 72.44780363355363, 70.79743971143449, 67.64349951062883, 66.99831758226667, 66.20861312321254, 66.88777174268449, 69.53395148686, 68.04329885755266, 65.22518593924386, 62.15032318660191, 62.400423594883506, 63.855299949645996, 62.2488625390189, 62.42390155792236, 61.104473386492046, 63.64307417188372, 65.78389058794293, 65.25848170689174, 62.16122491019112, 59.54374817439488, 51.333860942295615, 57.53972789219448, 57.830732345581055, 59.281724657331196, 56.62387888772147, 55.652221952165874, 47.543886116572786, 50.20398310252598, 56.046921321323936, 53.839138167245046, 57.07334048407418, 59.10649108886719, 57.734742982046946, 55.374360016414094, 58.63564641135079, 58.225799969264436, 56.313721724918906, 53.25362736838204, 49.466803550720215, 45.0909948348999, 45.787336349487305, 45.5545334815979, 47.60250806808472, 49.13228947775704, 53.287023884909495, 56.35906566892351, 55.902652399880544, 56.94992658070156, 56.34294932229178, 55.591949803488596, 55.7547356741769, 56.432403905051096, 55.2778252192906, 54.28198855263846, 55.15218094417027, 57.22411986759731, 60.387731960841585, 63.04475089481899, 60.75151184626988, 61.32853194645473, 57.9422995703561, 59.05502578190395, 57.7371574810573, 54.27092007228306, 57.288130147116526, 56.02676807131086, 60.616063662937705, 60.781437737601145, 54.461446625845774, 60.29197188786098, 66.2685135432652, 58.5725428717477, 58.4225104195731, 54.838198798043386, 59.70202119009835, 59.57813480922154, 64.5734727042062, 58.62673882075718, 60.13736752101353, 53.63149125235421, 62.38085051945278, 65.3180069242205, 66.27823407309396, 57.589383193424766, 48.2237673486982, 55.28208099092756, 44.97657190050398, 21.3674407686506, 21.56855637686593, 3.924850651196071, 0.354789703552212, 0.09729257824697665, 0.05930852038519723, 0.732320806809834, 0.49503385382039206, 0.052201083196060996, 0.048419512542230744, 0.04248543881944247, 0.14304320221500738, 0.21878504008054733, 0.7072088228804725, 47.48862361907959, 28.619440657751902, 30.762138298579625, 30.59528078351702, 42.120209148951936, 6.170779415539332, 0.219871103231396, 0.15028359155569757, 0.14975642412900925, 0.05874073585229261, 0.05759078184408801, 0.11520056266869817, 0.1013258718220251, 0.0690340306609869, 0.04942441611949887, 0.0299066887902362, 0.1180914475449494, 0.05616492531927569, 0.03390714466305716, 0.06504440759973866, 0.033769117069563696, 0.06311054208448955, 0.008137930866463907, 0.07117164667163577, 0.06594943082226173, 0.0215767893408026, 0.06049114585454975, 0.03281363459037883, 0.06400665614221777, 0.1285483914294413, 0.01943976365561996, 0.06089619054858174, 1.215672676052366, 54.94919974463326, 49.874280657087056, 46.68706553322928, 27.75333206994193, 38.93875060762678, 48.634503160204204, 0.7309410465615136, 6.9269661988530835, 0.2842534913548401, 0.09537360657538686, 0.08724352890359503, 0.0665788941883615, 0.7375060628567423, 0.7389290864978517, 1.7452263746942793, 0.1121937365138105, 2.7054806649684906, 0.1557432200227465, 10.06375433717455, 56.31511831283569, 52.73380831309727, 55.471381187438965, 54.18837199892317, 58.941700662885395, 51.820658683776855, 58.19664185387747, 45.798654964991975, 51.34116349901472, 59.66565431867327, 59.17833546229771, 62.8131674357823, 67.33511761256626, 69.48320184435163, 71.57321998051235, 68.9386020387922, 73.11545603615897, 78.36822468893868, 71.37206963130406, 68.03489153725761, 76.85464995247978, 76.00603866577148, 74.76156071254185, 74.76283918108258, 75.08172675541469, 70.84610489436558, 72.0125823702131, 68.9745728628976, 70.33560684749058, 71.58622006007603, 70.95425360543388, 67.1195011138916, 63.570354325430735, 65.7821535382952, 67.75453867231096, 65.35709054129464, 66.78614739009312, 62.83477633340018, 67.37845352717808, 67.76510688236782, 66.43987001691545, 63.728926113673616, 59.44834245954241, 53.339031151362825, 59.35740443638393, 60.54324654170445, 62.12837382725307, 58.140055724552695, 58.242864745003835, 50.42703069959368, 57.10379096439907, 60.04795810154506, 57.45033236912319, 60.10594776698521, 62.30087675367083, 62.51729924338204, 59.33810928889683, 61.81059101649693, 59.292237281799316, 57.9286150932312, 55.096199308122905, 53.68235554013933, 48.11900935854231, 48.98792328153338, 47.16758905138288, 49.47361625943865, 50.295605523245676, 56.47149794442313, 57.3779182434082, 56.87430586133684, 57.62378372464861, 56.727594648088726, 56.971302713666645, 57.83655841009957, 58.20168972015381, 58.18858194351196, 56.858641147613525, 58.43876920427595, 58.48204953329903, 61.21690913609096, 63.87740216936384, 63.58689103807722, 62.04009696415493, 61.3081876209804, 60.182801791599815, 61.08760316031319, 58.001498222351074, 60.13929912022182, 59.61763531821114, 61.172524043491904, 60.88484082903181, 56.25042016165597, 60.405519349234446, 69.89956569671631, 62.66357272011893, 61.319770268031526, 60.671218463352744, 61.396485328674316, 60.59737300872803, 66.18311323438371, 61.33158220563616, 61.629375049046104, 53.625932693481445, 61.40847097124372, 65.46000725882394, 65.25809955596924, 62.08454459054129, 55.917386054992676, 55.63810321262905, 66.3774196079799, 37.94283056259155, 31.958757059914724, 9.853648628507342, 0.2896852727447237, 0.24572279889668736, 0.06800231816513197, 1.2436130110706602, 0.5409296367849622, 0.03741481787125979, 0.07601153517940215, 0.016540965364713753, 0.265652593757425, 0.128427652908223, 0.689100134585585, 52.81206587382725, 32.43188769476754, 32.84602812358311, 38.06020648138863, 50.35573870795113, 9.015272038323538, 0.23081193757908686, 0.23819431715777942, 0.05078567611053586, 0.07021612008767468, 0.04382798820734024, 0.03825183152886374, 0.0426940679816263, 0.12864215139831814, 0.07080445744629417, 0.08229965490422078, 0.04633085622585245, 0.05433321664375918, 0.05538276782525437, 0.16760707912700518, 0.15275348616497858, 0.20820859260857105, 0.1189965589770249, 0.15765343180724553, 0.15078696954463208, 0.24056810406701906, 0.12819377545799526, 0.10890896205923387, 0.22852682162608418, 0.2555098794400692, 0.1766058105443205, 0.12466229924133845, 1.906024192060743, 67.43799264090401, 57.3152038029262, 51.81216451099941, 51.007257393428254, 48.444622789110454, 59.98875944955008, 0.853158556989261, 9.31633140359606, 0.36628213258726255, 0.249930095991918, 0.2529586963355541, 0.6941729709506035, 0.9626516359192985, 1.945775487593242, 3.355204543897084, 0.9629332550934383, 5.845322319439479, 0.6347478511078017, 10.999139939035688, 74.09702110290527, 62.63808672768729, 65.1719696862357, 62.648564611162456, 69.28342723846436, 62.00772530691964, 74.0013096673148, 65.40987600599016, 64.5956027167184, 69.69123091016496, 68.48761531284877, 70.70415319715227, 77.51893247876848, 77.82060936519078, 79.06642137254987, 75.92841339111328, 79.07341126033238, 83.10346371786935, 78.06436606815883, 70.31597818647111, 77.92040634155273, 78.34993008204869, 77.8035306930542, 77.46864141736711, 77.09956005641392, 72.44155025482178, 75.13469982147217, 70.90100261143276, 72.30474022456578, 76.85499736240932, 75.2825574874878, 70.3746418271746, 67.63635676247733, 68.47536563873291, 70.8388648714338, 67.55497946058, 69.62101241520473, 65.57348523821149, 69.56141076769147, 71.5917716707502, 70.635192326137, 68.58797509329659, 65.08232402801514, 57.245878151484895, 63.314848218645366, 64.54870932442802, 66.33775234222412, 64.29075050354004, 60.889725412641255, 53.96193020684378, 56.757770674569265, 62.99637058803013, 60.25613307952881, 61.556300844464985, 65.47964981624058, 65.38395922524589, 60.094531876700266, 64.38990129743303, 63.42655440739223, 61.157571520124165, 56.449037892477854, 54.97979613712856, 50.64034039633614, 50.833816460200715, 51.64498390470232, 54.96473591668265, 54.319484506334575, 59.33437810625349, 60.117606844220845, 60.45761694226946, 60.6897006716047, 60.27651909419468, 61.11618110111782, 62.62309946332659, 61.8040041242327, 60.415017536708284, 59.6800787789481, 62.70150988442557, 60.839371817452566, 66.61617360796247, 68.4958906173706, 67.22154930659703, 65.8749189376831, 63.352201734270366, 63.26572445460728, 64.34860120500836, 59.44907896859305, 60.601041657584055, 60.54840905325753, 65.83429976872036, 63.96153095790318, 57.21863079071045, 65.27617876870292, 72.21984018598283, 63.504402024405344, 64.96947138650077, 61.612004552568706, 62.93657439095633, 64.43430028642926, 68.30753884996686, 64.15895012446812, 66.84217766353062, 62.13307080950056, 65.8567146573748, 69.9956453868321, 68.15727710723877, 63.04138796670096, 57.70309393746512, 58.324825695582796, 67.50200639452252, 50.71716662815639, 46.69997181211199, 9.345582451139178, 0.3328850732317993, 0.8814461390886987, 0.18863639927336148, 1.8359361929552895, 0.6571012916309493, 0.16736466570624284, 0.29519701270120485, 0.5725954004696437, 0.39276397015367237, 0.38494113992367474, 1.667889884540013, 62.6984874180385, 39.01163373674665, 47.59140484673636, 43.812769481113975, 61.47331850869315, 11.49022124494825, 0.34284623871956554, 0.4254929982125759, 0.2613731005362102, 0.15192479134670325, 0.1815628209816558, 0.23473514563270978, 0.21899302463446343, 0.16258669351892813, 0.14225842218313897, 0.20379997417330742, 0.16042759508958884, 0.15553564258984157, 0.11969857130731855], [0.12908915669790336, 0.12327902418162141, 0.19450648714389118, 0.06608464249542781, 0.13431703831468308, 0.06289839811090912, 0.08884943130293063, 0.06196702737361193, 0.016525788232684135, 0.061113484602953703, 0.041209908335336616, 0.02215420567829694, 0.03486753634310194, 4.557241814477103, 58.25053555624825, 31.236999034881592, 41.74732712336949, 26.73091333253043, 47.55828973225185, 9.460932970046997, 1.5015003957918711, 2.028470341648374, 0.7835492236273629, 0.04554007115906902, 0.3468030478273119, 0.21965417558593409, 0.2407183317201478, 0.12658114199127468, 0.6083803059799331, 0.668643172298159, 0.72710113546678, 0.31530461087822914, 22.804587057658605, 45.46461336953299, 43.97127873556954, 39.19535800388881, 35.707588127681184, 35.51484162466866, 37.72637333188738, 42.03734145845686, 38.96163102558681, 45.6097925049918, 47.86674806049892, 50.62870563779558, 56.92382219859532, 60.13872241973877, 61.572816712515696, 60.94087110246931, 59.87714358738491, 66.29599366869245, 62.37930107116699, 56.635266985212056, 70.54220458439418, 77.44630295889718, 72.16105842590332, 72.83545058114188, 70.62175451006208, 70.54190581185478, 69.48445946829659, 64.86516502925328, 64.66933005196708, 63.24232292175293, 67.8907858984811, 66.77785124097551, 61.82688454219273, 64.59907681601388, 62.60248415810721, 62.08507265363421, 65.13287217276437, 64.68774277823312, 64.93613392966134, 65.27346897125244, 66.22219685145787, 64.23337922777448, 54.94732025691441, 51.88483919416155, 56.869410855429514, 61.05348750523159, 58.931014333452495, 57.84319393975394, 55.93320362908499, 49.59758601869856, 47.06893852778843, 51.033695289066856, 53.264487402779714, 57.838722773960654, 53.46929945264544, 55.71457508632115, 57.11719751358032, 57.297322613852366, 60.48004572732108, 57.747055189950125, 55.47974681854248, 53.011684145246235, 50.11361830575125, 49.160839625767295, 49.88844803401402, 47.7201132774353, 46.14778109959194, 48.4213011605399, 50.705017702920095, 55.1448540687561, 55.52229758671352, 56.701455524989534, 58.831029755728586, 56.96326017379761, 55.366129875183105, 53.903777258736746, 54.581483704703196, 53.85520240238735, 55.50268977028983, 54.20138250078474, 55.08449159349714, 59.598576409476145, 59.68744386945452, 56.98436532701765, 60.43067182813372, 55.70660202843802, 59.31743144989014, 59.10345472608294, 56.72401632581438, 55.89135810307094, 56.237051827566965, 57.57099478585379, 60.10876873561314, 57.205661978040425, 63.15771470751081, 63.102163859776084, 58.24919802801949, 55.75432573046003, 59.36843817574637, 58.82219859531948, 61.987415722438264, 65.72560214996338, 58.59819562094552, 49.48338195255825, 53.50061845779419, 68.88437134878976, 63.37178175789969, 60.38785702841622, 47.8204139981951, 45.65863834108625, 52.62169565473284, 33.80802706309727, 18.278905698231288, 20.763751745224, 0.8839624183518546, 0.24587910622358322, 0.04439642074118767, 0.1428295722497361, 0.7170255418334688, 0.054816686415246556, 0.17592965039823735, 0.026515637092026215, 0.5245984931077275, 0.17881156504154205, 0.33184075355529785, 30.217792102268763, 40.09804712023054, 25.67683686528887, 20.53773900440761, 45.862832001277376, 9.692846468516759, 0.5027900519115585, 0.2619700756456171, 0.10837910084852151, 0.10036110359111003, 0.03602632826992443, 0.10065397966120924, 0.06253133102187089, 0.08357287836926323, 0.05983253940939903, 0.12460342954312052, 0.06007266616714852, 0.02706763381138444, 0.031711744610220194, 0.12455363864345209, 0.029621307139417956, 0.15927990738834652, 0.04243985822956477, 0.049487655583236895, 0.0866897561188255, 0.03367716878918665, 0.01562336040660739, 0.0663943530193397, 0.05022319432880197, 0.010358449437522461, 0.04154954903892108, 0.212043021140354, 5.252283147403172, 67.35498251233781, 42.11037049974714, 49.45369577407837, 18.73607979501997, 60.11487620217459, 10.71619713306427, 3.043121427297592, 6.204317935875483, 0.8759153187274933, 0.10955165007284709, 0.21872372765626225, 0.17028651892074517, 0.8921137409550803, 0.18241905075098785, 0.8161116306270871, 1.6080623120069504, 1.1166739825691496, 0.3358653618821076, 34.220635414123535, 56.50854573931013, 54.557679176330566, 57.26423529216221, 52.1945412499564, 51.64747483389718, 51.66961179460798, 49.7847044808524, 44.97321939468384, 51.785455635615754, 54.32010637010847, 58.15120758329119, 64.19827692849296, 67.34385149819511, 69.16038853781563, 69.85374927520752, 69.24322496141706, 73.09989207131522, 66.89808981759208, 64.18984181540353, 74.99203940800258, 79.6141756602696, 74.15896429334367, 72.9312801361084, 73.52184227534703, 74.17146410260881, 72.43572766440255, 68.83465003967285, 69.47519057137626, 67.9197529384068, 69.7050369807652, 68.95754977634975, 65.22258731297084, 67.12804739815849, 64.57870469774518, 63.230545725141255, 67.28677899496896, 67.6957847050258, 68.30948434557233, 66.39788205283028, 66.98381669180733, 63.7961151940482, 56.359444345746724, 54.301255907331196, 61.723849705287385, 62.32883630480085, 60.569399561200825, 59.07210445404053, 58.55336584363665, 51.33701195035662, 53.2231456211635, 54.189115456172395, 57.32631049837385, 59.718252182006836, 58.52247415270124, 60.40646430424282, 59.17623710632324, 58.920175143650596, 62.51517309461321, 59.341764041355674, 58.99094254629952, 54.87518058504377, 51.08729369299752, 51.681791986737935, 51.80614389692034, 51.58078602382115, 48.23892136982509, 47.87588494164603, 52.045585768563406, 55.50329426356724, 57.71507610593523, 59.56830310821533, 58.82135786328997, 57.52370882034302, 58.075253350394114, 56.37618950435093, 57.24206359045846, 56.65539244243077, 58.298526763916016, 57.64029959269932, 58.595819337027415, 62.705185481480186, 61.52798693520682, 60.7212107522147, 60.925147329057964, 59.65122985839844, 61.54965836661202, 63.54377746582031, 59.04653508322579, 58.043500082833425, 60.48292228153774, 59.79016603742327, 59.88038144792829, 57.374388558524, 63.36547974177769, 66.22883238111223, 60.22622108459473, 59.61113180433001, 62.97254521506173, 61.88273416246687, 59.705585615975515, 67.22393253871373, 60.4953248160226, 54.358648027692524, 53.608669894082205, 65.91483633858817, 65.3870164326259, 64.10476807185582, 55.892699105399, 52.02676657267979, 57.049414362226216, 57.95149898529053, 30.337975093296595, 34.261984143938335, 3.1102512308529446, 0.16888976815555776, 0.3669798837176391, 0.08435919189027377, 0.5200277183737073, 0.06322734510259968, 0.06716720440558024, 0.16343953061316693, 0.444204144179821, 0.1905663835683039, 0.36555604583450724, 32.11983367374965, 43.43843528202602, 24.715371200016566, 31.872554234095983, 54.08537537711007, 13.025513444628034, 0.638807227568967, 0.3897404452519757, 0.1413633394986391, 0.02428548756454672, 0.04486608911039574, 0.07949863520583936, 0.05464234023487993, 0.06970985153956072, 0.04883454866441233, 0.06701175203280789, 0.06554259479578052, 0.08131532450871808, 0.019529328581744006, 0.18761692754924297, 0.17521017257656368, 0.1850010800574507, 0.141992735011237, 0.19706134790820734, 0.28091371485165184, 0.09097008393811327, 0.21705489791929722, 0.1090227591672114, 0.14421575143933296, 0.10835560318082571, 0.19451308250427246, 0.30461887855614933, 6.906797315393176, 80.75679302215576, 43.47108834130423, 60.18653992244175, 39.32826314653669, 68.65290600912911, 19.589742422103882, 5.854096157210214, 12.937195760863167, 1.2102638291461127, 0.2478662095963955, 0.8126605472394398, 0.6512365777577672, 1.5549985936709811, 1.0527566352060862, 1.1571622214147022, 3.4738673993519376, 2.339612194469997, 0.5271325228469712, 45.19200774601528, 69.88414069584438, 65.66559055873326, 65.95833900996617, 58.70769228254046, 62.59643922533308, 62.079701696123394, 66.875549861363, 58.74258613586426, 63.28356048039028, 61.43591635567801, 63.2010714667184, 68.12981782640729, 71.18284239087785, 73.68120615822929, 76.42953136989048, 73.67626598903111, 78.97922842843192, 73.49828788212368, 64.2677311216082, 75.18429606301444, 85.02814946855817, 75.83439036778041, 76.88007341112409, 74.825546673366, 78.53735079084123, 75.37120260511125, 73.16595554351807, 72.05586964743478, 69.21396609715053, 73.57522528512138, 74.07208401816231, 68.23106002807617, 70.96853910173688, 67.8086929321289, 67.85649653843471, 70.05007757459367, 71.11583396366665, 69.37239892142159, 70.22535978044782, 70.53397096906389, 68.60369191850934, 62.238009452819824, 57.91449635369437, 63.802028111049104, 66.3360013961792, 63.44184044429234, 63.01082978929792, 62.6381562096732, 56.13650097165789, 56.53768301010132, 59.00673580169678, 59.84766238076346, 63.335977690560476, 60.05642100742885, 62.2899819782802, 62.64572279793875, 62.68643924168178, 67.06675733838762, 63.127351079668315, 61.00277260371617, 58.57641996656145, 55.97279099055699, 55.861724036080496, 54.24320370810372, 53.015762737819124, 50.24308409009661, 51.91678006308419, 55.4067907333374, 58.43357195172991, 60.9228891645159, 62.88192680903843, 61.48171888078962, 63.203635351998464, 62.753885405404226, 58.03547143936157, 60.834278787885395, 61.13580281393868, 62.904577936444966, 60.95118222917829, 59.27028792245047, 65.70520223890031, 65.05832495008195, 63.37940393175398, 65.02699552263532, 63.6147255216326, 64.68859045846122, 65.03511101858956, 59.52921254294259, 57.74122217723301, 61.40424646650042, 61.433706828526084, 61.12497752053397, 62.00492518288748, 66.13458006722587, 70.92807974134172, 62.57335730961391, 61.85678958892822, 65.25183228084019, 62.537574086870464, 65.40690912519182, 71.81222411564418, 65.11687047140938, 60.77643503461565, 59.51615687779018, 67.49976907457624, 68.02442060198102, 65.33755915505546, 57.44413110188076, 54.467543670109336, 59.00222642081124, 64.12786388397217, 43.50579111916678, 47.635307039533345, 2.1784917201314653, 0.18124059827200004, 0.5258089452981949, 0.20395804569125175, 1.1913094690867831, 0.15529537333973817, 0.32763701198356493, 0.25485476745026453, 0.788956170635564, 0.2564022886965956, 0.5150618191276277, 40.78402887071882, 56.313103335244314, 42.19642046519688, 30.71096134185791, 65.23841530936105, 14.296524831226893, 0.7000826852662223, 0.46221333209957394, 0.17346529263470853, 0.33193569417510715, 0.1884289982595614, 0.14209428456212791, 0.13265553675591946, 0.16981883187379154, 0.12304765731096268, 0.229595242866448, 0.13506757946951048, 0.1546695197799376, 0.1250755406383957], [0.06432752178183623, 0.10186151415109634, 0.08668177654700619, 0.055660207223679335, 0.08182284156126635, 0.05180306812482221, 0.11322534722941262, 0.14242786594799586, 0.059601335387144766, 0.08979864751121827, 0.05503227056137153, 0.12805662996002606, 0.21167677507868835, 15.951544046401978, 54.04273428235735, 31.77735001700265, 45.930062770843506, 30.36222083227975, 61.99024363926479, 1.5303070843219757, 1.4563314595392771, 0.3304327662502016, 0.29855519107409884, 0.08614823767649275, 0.23476920809064591, 0.2379623938884054, 0.13547141637120927, 0.12630117844258035, 0.12611760757863522, 0.6201925692813737, 0.2163194745246853, 6.059997337205069, 40.60461943490164, 40.52065740312849, 42.17151117324829, 40.39919941765921, 42.93577132906233, 37.48250545774187, 39.271016938345774, 39.30209623064314, 45.94450807571411, 46.080796991075786, 52.37267221723284, 57.84796735218593, 61.71566472734724, 64.67773737226213, 66.12510967254639, 68.98309135437012, 67.6535257611956, 58.65238462175642, 55.837200369153706, 72.32288891928536, 72.57045323508126, 74.59892422812325, 73.15637397766113, 69.06093202318463, 70.7728430884225, 67.63234765189034, 66.21391459873745, 65.69120856693813, 66.35355254581997, 66.25093460083008, 65.96411296299526, 66.03613104139055, 63.33325399671282, 63.675598689488, 62.93123122623989, 64.27636078425816, 66.5718857901437, 67.68853773389543, 66.58649785178048, 63.79692118508475, 60.70865535736084, 53.17414345060076, 53.60578639166695, 59.58251912253243, 56.29319327218192, 57.50198180334908, 61.138241631644114, 56.68551288332258, 48.3316832951137, 47.35124731063843, 50.79738705498831, 53.808677264622276, 55.16751561846052, 53.910979066576274, 54.9533999306815, 56.00756672450474, 55.1629193850926, 54.706387996673584, 56.54942199162075, 56.93904570170811, 55.309008734566824, 49.07956307274954, 47.63154458999634, 44.50876358577183, 47.99579695292881, 49.48542472294399, 49.4967885017395, 44.82730722427368, 46.04814393179757, 49.52798938751221, 53.22929130281721, 60.27408027648926, 59.699943678719656, 58.210982935769216, 56.0401155608041, 56.34057303837368, 56.02509355545044, 53.29640047890799, 53.567842279161724, 54.93409088679722, 54.62558044706072, 56.37508821487427, 59.13380445752825, 56.73653697967529, 56.154705251966206, 56.53933320726667, 57.937150955200195, 59.09321308135986, 59.184324809483115, 55.01535701751709, 57.312740666525706, 54.68788841792515, 55.854400634765625, 58.17866686412266, 61.28811427525112, 63.22019290924072, 59.95240647452218, 55.11107887540545, 56.681656633104595, 57.33463444028582, 59.47151470184326, 64.14848613739014, 54.58369323185512, 52.71399899891445, 48.76557050432478, 60.768180574689595, 70.25372232709611, 62.62243938446045, 55.02397625786917, 41.440539836883545, 45.96116290773664, 46.58240829195295, 24.623670612062725, 21.63246590750558, 14.25404007094247, 0.12282376789620944, 0.21052778459021024, 0.16785184027893202, 0.0976578811449664, 0.07201872300356627, 0.13645519715334686, 0.041031212745500464, 0.24201821482607297, 0.11984579983566489, 0.35889709315129686, 9.42960180555071, 51.17146417072841, 20.52013921737671, 25.953670467649186, 44.44995403289795, 13.575899362564087, 0.2593725893114294, 0.39078547060489655, 0.03552535908030612, 0.32286330099616734, 0.032380488368549516, 0.1468465674136366, 0.038785475572305064, 0.2866997186626707, 0.051203382268015823, 0.06665599612253052, 0.026468828353764753, 0.07082977358783994, 0.07405324918883187, 0.021321705974904553, 0.04971834731155208, 0.09989538429571049, 0.06016644649207592, 0.05072367497320686, 0.050295451522937844, 0.1834712414337056, 0.0629177838563919, 0.01042072453336524, 0.06567910247083221, 0.0774044386510338, 0.13501248242599623, 0.36860258664403645, 19.710033110209874, 60.7438132422311, 44.634282793317524, 41.7596949168614, 28.452645676476614, 70.13299737657819, 1.939289127077375, 1.0368569855179106, 0.3393138939780848, 0.47033664477722986, 0.16853125739310468, 0.16517393397433416, 0.6942194370286805, 0.5613333476441247, 0.44949367748839514, 0.16471406365079538, 0.7390370007072176, 0.15271685884467193, 12.010268722261701, 59.708913803100586, 50.85115916388375, 59.97168772561209, 58.53650256565639, 60.34625816345215, 51.30395589556013, 52.988289560590474, 46.535959584372385, 50.67126335416521, 51.70911577769688, 57.88323640823364, 61.64172894614083, 64.54263659885952, 66.3159488950457, 67.74893842424665, 71.77270971025739, 72.16343470982143, 66.42798164912632, 60.570427894592285, 73.44336932046073, 73.07293306078229, 74.93178462982178, 74.65639277866909, 72.25922952379499, 71.533205304827, 72.44194630214146, 70.48060880388532, 69.1648701259068, 70.55483640943254, 70.12988458360944, 67.42326940808977, 67.40215383257184, 66.27059800284249, 65.85003743852887, 67.67339760916573, 66.68938677651542, 68.06426157270158, 68.62336226872036, 66.86808749607631, 65.73585074288505, 60.04163524082729, 54.0704471724374, 55.24013124193464, 61.824584688459126, 59.40826525006975, 60.502967834472656, 61.68830966949463, 57.988807337624685, 49.85037190573556, 51.01430286679949, 53.20294720785958, 58.61005619594029, 58.58219391959054, 58.88038975851876, 58.46294893537249, 59.987821442740305, 58.740981101989746, 58.2323625428336, 58.809726578848704, 57.77823175702776, 54.955984660557334, 51.524196420397075, 50.56171805518014, 48.22151265825544, 50.188224588121685, 52.09245136805943, 52.67746884482247, 48.026549679892405, 48.07492651258196, 48.92591755730765, 52.03431231634957, 59.42157105037144, 61.06399318150112, 60.40913241250174, 58.94329874856131, 59.25513390132359, 57.84352050508772, 56.11855377469744, 57.109960964747835, 57.611798082079204, 56.42508397783552, 58.174108845846995, 59.57658536093575, 59.43599551064627, 59.28797108786446, 58.452992166791645, 60.41090420314244, 62.372596059526714, 63.292252676827566, 56.31256832395281, 61.85002899169922, 57.84105736868722, 57.631065436771934, 58.737583432878765, 61.14141695840018, 67.46721676417759, 63.29729012080601, 59.87062617710659, 61.74388831002371, 61.35051604679653, 59.85351971217564, 63.93439129420689, 58.55776405334473, 55.37039259501866, 50.837408678872244, 56.86579779216221, 70.47468893868583, 65.41988141196114, 60.507289613996235, 53.680694920676096, 48.72118888582502, 57.870691435677664, 45.03343595777239, 32.33183363505772, 25.437217814581736, 0.31716129982045715, 0.05912366709006684, 0.11755995106484209, 0.15114600956439972, 0.027818734757602215, 0.07941764526601348, 0.019175513281619976, 0.1777361820318869, 0.020540781718279635, 0.3346198701432773, 9.614263210977827, 59.51481587546212, 23.940839869635447, 29.920252868107386, 53.51596008028303, 16.301378897258214, 0.2631770265953881, 0.278010724910668, 0.03447657125070691, 0.2815313445670264, 0.029640658958149806, 0.15277777771864617, 0.07787682794566665, 0.1522124766239098, 0.055068073461630514, 0.09150176362267562, 0.049387551311935694, 0.06552601139992476, 0.04178445107702698, 0.18853470044476645, 0.23148916981049947, 0.18373456730374269, 0.15445204930646078, 0.15011189505457878, 0.21931192252252782, 0.18969167050506386, 0.2543538457580975, 0.11819917176451002, 0.19279313193900244, 0.2174084825175149, 0.2936294068183218, 0.4686488839132445, 22.45059892109462, 72.59876714433942, 44.90852819170271, 60.304013116019114, 45.79914133889334, 79.83186272212437, 2.555334653173174, 3.675326943397522, 1.5091577449015208, 0.8571210386497634, 0.6353228688240051, 0.41000228800943916, 1.346142583659717, 2.1943032145500183, 1.5720247200557163, 0.8409478036420686, 3.8623511706079756, 0.42834762217743055, 18.200094018663677, 79.31024755750383, 60.727387700762065, 69.73753370557512, 67.03319059099469, 71.33754403250558, 62.65850748334612, 63.67368793487549, 60.442219734191895, 66.65116473606655, 59.524668421064106, 67.12637288229806, 66.1316340310233, 69.84035314832414, 69.93245846884591, 73.01312296731132, 76.00384998321533, 74.94918291909354, 69.59386580330985, 62.62057031903948, 76.81517028808594, 76.5352065222604, 79.18288707733154, 80.44006633758545, 77.20335224696568, 76.61731338500977, 75.65760040283203, 74.08617496490479, 71.22637285505022, 74.37089129856655, 72.3198664528983, 73.14426326751709, 71.92745998927525, 69.49814741952079, 69.48457758767265, 70.01305062430245, 67.81072180611747, 70.91302299499512, 71.08084283556256, 71.59196622031075, 67.64771011897496, 64.91016851152692, 58.388360023498535, 58.552865573338096, 65.49485247475761, 63.15483120509556, 64.02261257171631, 66.89379583086286, 63.914456912449424, 55.124752930232454, 51.38403041022164, 56.981290749141145, 61.78430598122733, 62.14677265712193, 59.95474106924874, 61.11511107853481, 62.724918365478516, 60.24564824785505, 60.89600658416748, 61.83625766209194, 62.69909885951451, 61.24420860835484, 53.92599412373134, 54.3300735609872, 50.70810617719378, 52.75511148997715, 54.65060091018677, 54.29226841245379, 48.89941712788173, 50.19493654796055, 53.547452790396555, 56.528049332754954, 65.92244461604527, 64.74776826586042, 63.98868451799665, 61.770242827279226, 61.42841924939837, 61.11829335348946, 59.36760439191546, 59.59978539603097, 60.07807159423828, 60.65894794464111, 63.63150542122977, 65.69297340938023, 62.44587871006557, 63.032285826546804, 63.877749579293386, 62.925165448869976, 64.73977783748082, 66.38345064435686, 57.41172470365252, 63.828827313014436, 57.51859494618007, 59.94711194719587, 59.579899651663645, 64.4013032913208, 70.41455227988106, 65.4234597342355, 61.08164855412075, 63.36597306387765, 63.57593372889927, 62.62316199711391, 68.90686961582729, 61.85330854143415, 62.316343443734304, 60.3852653503418, 62.64217921665737, 71.85435799189976, 68.07487842014858, 61.391107422964915, 57.88015488215855, 52.6796019417899, 60.19823374067034, 54.77153083256313, 44.08049399512154, 28.990066255841935, 0.2083842788955995, 0.4048794571842466, 0.26821248925157953, 0.332191773291145, 0.15648097757782253, 0.23726173862814903, 0.23680839581148966, 0.5210566488759858, 0.4003005400300026, 0.5236504982624735, 14.521554401942662, 68.97357927049909, 33.71580362319946, 37.25875609261649, 62.2351051058088, 20.875492674963816, 0.39992243317621096, 0.5994315690227917, 0.20009701858673776, 0.4605356678366661, 0.1797043542776789, 0.3690635290529047, 0.21001573492373737, 0.30094149016908234, 0.21302722261420318, 0.19574621133506298, 0.1138427055307797, 0.09154481666960887, 0.24371905784521783], [0.04443643395123737, 0.08018666292939867, 0.02884532092139125, 0.09751492060188736, 0.15449749758200987, 0.04560348704191191, 0.05322527073855911, 0.0744674133935145, 0.09700648752706391, 0.08771985370133605, 0.02518237006318356, 0.15264451344098362, 0.32684603014162605, 26.231904132025583, 50.59905767440796, 32.544924463544575, 38.7094600541251, 31.57654012952532, 51.7559883253915, 0.18936967849731445, 0.26173123131905285, 0.6626011707953045, 0.17936978223068373, 0.04190378842343177, 0.19756319240799972, 0.17985793389379978, 0.11358395977211849, 0.17840713102902683, 0.08091651555150747, 0.3291151055267879, 0.12494573688932828, 27.10931917599269, 44.14906924111502, 41.577308177948, 42.510920252118794, 43.0842091696603, 40.689661911555696, 37.05672679628645, 41.39838511603219, 45.89444630486624, 50.18684884480068, 55.22700956889561, 55.44279282433646, 57.8283908026559, 58.80655820029122, 63.86786924089704, 65.76560292925153, 70.36106504712785, 67.82409014020647, 57.939231940678184, 61.59334863935198, 67.43703378949846, 71.07977976117814, 71.51016507829938, 69.35766874040876, 67.67045852116176, 65.92338957105363, 66.88843182155064, 67.06918920789445, 66.67023059300014, 63.13584177834647, 62.9377555847168, 62.405801500592915, 60.90018939971924, 63.09196390424456, 65.79519530705043, 66.39419950757707, 67.02446365356445, 65.61240209851945, 65.81899983542306, 65.03388813563755, 59.7999004636492, 50.62205968584333, 54.94378014973232, 63.90689032418387, 58.12307432719639, 56.971618856702534, 60.48684106554304, 56.215158053806846, 48.63040372303554, 48.742877687726704, 50.04584905079433, 49.42840780530657, 50.65404919215611, 52.352414744240896, 49.73146390914917, 53.651005268096924, 54.91250630787441, 55.23558017185756, 55.04050254821777, 55.658815792628694, 52.61628300803048, 50.94332006999424, 51.11149774278913, 47.41409724099295, 46.424566064562114, 47.84514263698033, 50.084018979753765, 48.73567587988717, 50.900685923440115, 45.94811071668352, 49.43333407810756, 51.01583841868809, 50.88083144596645, 55.152007239205496, 59.20576695033482, 62.121849468776155, 58.48106983729771, 58.48243863242013, 55.663311277117046, 52.80819572721209, 53.91278559820992, 52.64566693987165, 53.20568132400513, 56.66646439688546, 56.279387201581685, 57.12285682133266, 56.53436177117484, 55.007873807634624, 58.95006629398891, 59.89862741742815, 55.74313218252999, 55.530395712171284, 55.89243507385254, 53.20942987714495, 56.57909427370344, 53.76513637815203, 61.18523924691336, 65.36994470868791, 56.785785811288015, 55.77169622693743, 54.98050137928554, 60.4791841506958, 59.35046318599156, 60.150944301060264, 49.43517535073416, 49.02241761343819, 49.594803265162874, 70.54865946088518, 64.67986352103097, 57.95161363056728, 44.5451408794948, 39.9828633580889, 46.43140309197562, 39.771620750427246, 17.39067578315735, 24.66613279070173, 4.612265033381326, 0.23980266228318214, 0.37017920347196714, 0.08690878043749503, 0.07659895651574646, 0.11392046564391681, 0.022398291687880243, 0.10932838491031102, 0.08616570995322295, 0.26521160027810503, 1.3941264088664735, 42.614080156598774, 38.81123379298619, 25.22973244530814, 40.16935648236956, 22.005474737712316, 0.3472723497876099, 0.3552418792886393, 0.07928550735648189, 0.15338133461773396, 0.04382158962211438, 0.09372939408889838, 0.07350134237536363, 0.009862706663885286, 0.027656398647065674, 0.1067926859749215, 0.08084691821464471, 0.05688932591250964, 0.025233263582257286, 0.055975882070405145, 0.09012205087180648, 0.009848922224981444, 0.0361494925538344, 0.12428576658879008, 0.05178471375256777, 0.16117065878851072, 0.08411527212177004, 0.10613282423998628, 0.03533409023657441, 0.05857205204665661, 0.05318142719832914, 0.28340852526681765, 32.48162637438093, 58.0358362197876, 43.288048471723286, 29.16015120915004, 37.7588700566973, 57.51769862856184, 0.026346583484805057, 0.27628192624875475, 1.1005291917494364, 0.25706168902771814, 0.17775799014738627, 0.09333285143865006, 0.12047405540943146, 0.09162711618202073, 0.22508537343570165, 0.554915654872145, 0.03295064777401941, 0.7888013018029076, 44.253851549965994, 56.75816672188895, 55.140653882707866, 60.64412743704659, 60.19626045227051, 57.83739219393049, 51.50765970775059, 53.02152974264962, 51.868764536721365, 54.92723648888724, 59.53868988582066, 57.74380343300955, 61.4713591166905, 63.275667326790945, 66.62906946454729, 69.29806709289551, 73.24870858873639, 68.40594618661063, 61.12445640563965, 64.89326354435512, 71.45293971470424, 70.97245788574219, 74.36333165849958, 72.60010119846889, 71.23243863242013, 67.95021384102958, 68.72144998822893, 70.49296270098004, 68.18547984531948, 68.24661009652274, 68.89572470528739, 65.87370300292969, 64.38965116228376, 67.0828424181257, 69.07696151733398, 67.1266508102417, 69.98625142233712, 66.8092987877982, 67.29160799298967, 65.77619893210274, 59.800803729466026, 52.449835436684744, 59.73007801600865, 62.67714255196707, 60.63265596117292, 59.954678535461426, 61.33363192422049, 55.514359269823345, 53.0389905657087, 53.14073303767613, 55.189885343824116, 50.15790612357003, 52.412672996520996, 54.80989531108311, 53.86495419910976, 56.33795356750488, 58.53329249790737, 58.84824044363839, 58.535911968776155, 57.11407429831368, 54.96038287026541, 51.67668853487287, 53.27045937946865, 51.42016799109322, 48.35329219273159, 50.16748768942696, 52.13863256999424, 52.124089990343364, 52.7631436075483, 49.42775467463902, 50.66586112976074, 53.29831123352051, 51.397079127175466, 54.80084875651768, 59.66073499407087, 63.03373800005232, 61.141750471932546, 60.39333915710449, 57.879251616341726, 56.85684503827776, 57.22567278998238, 56.911774022238596, 54.8622465133667, 57.665333952222554, 58.308608600071494, 59.98252691541399, 59.09934834071568, 59.40832083565848, 61.16854272569929, 62.510205132620676, 59.622200284685405, 59.08733490535191, 60.671280997140066, 55.46830660956246, 58.76748153141567, 52.43894413539341, 60.093878746032715, 66.75640215192522, 60.139841079711914, 61.43840381077358, 59.252952166966026, 61.00653157915388, 57.566488879067556, 60.78659330095564, 52.31739582334246, 51.56797354561942, 49.50345182418823, 65.44258117675781, 69.53737694876534, 63.47904109954834, 55.06222609111241, 49.35698727199009, 50.47559860774449, 56.92597614015852, 33.62416730608259, 37.072193486349924, 10.57172497681209, 0.26388709992170334, 0.5743681139179638, 0.021633708250841925, 0.11108492208378655, 0.0022480325299381676, 0.028667046023266654, 0.08121657730745417, 0.25824060291051865, 0.22431253562016146, 1.8172553096498762, 46.69192927224295, 36.87658085141863, 25.544459785733903, 48.11383295059204, 27.599384307861328, 0.276918174965041, 0.09310423263481685, 0.04551324188443167, 0.18811574578285217, 0.09550942893006972, 0.09287545098257916, 0.10912515688687563, 0.03914566231625421, 0.043474383253071985, 0.026190985227003694, 0.055077355820685625, 0.05205972399562597, 0.08710107726177999, 0.1842780602829797, 0.25569650371159824, 0.09567527645932776, 0.15470887481101922, 0.19582152872213296, 0.22209023843918527, 0.19215723606092588, 0.16971512458154134, 0.13207233590739115, 0.24853920776929173, 0.12577003480068275, 0.271185395440885, 0.377521278070552, 38.48870883669172, 68.69931302751813, 43.9329594203404, 55.76183673313686, 43.727174622671946, 67.42436027526855, 0.25792177287595613, 0.9511867825474057, 1.8218181048120772, 0.7455961001770837, 0.43276404376540867, 0.2683352498071534, 0.41543664783239365, 0.15423263822283062, 0.447640951190676, 1.4851369538477488, 0.6913514594946588, 1.7566757031849451, 61.583551679338726, 70.13677024841309, 63.39742061070034, 68.6234109061105, 67.75232219696045, 67.57813780648368, 62.30247483934675, 63.33079433441162, 64.66117981501988, 67.51450620378766, 66.96511214120048, 64.76803616115025, 66.02555588313511, 68.04538331712995, 73.87629767826625, 75.12267248971122, 76.86890765598842, 73.88288457053048, 65.7788531439645, 66.80408763885498, 74.06512887137276, 73.75277260371617, 76.30802127293178, 76.9686143057687, 75.07033865792411, 70.8653791972569, 72.41622407095772, 74.3149027143206, 71.94945798601422, 69.81158760615757, 69.94181769234794, 68.23149081638881, 69.0725633076259, 70.14814444950649, 70.62960597446987, 70.25447273254395, 72.00769083840507, 69.68795830862862, 71.19316741398403, 68.78078065599713, 64.98606368473598, 55.92093311037336, 59.30580711364746, 69.09530476161412, 66.95584324428013, 61.133919852120535, 65.41995784214565, 60.92511258806501, 56.177985191345215, 55.26805257797241, 57.73903349467686, 53.658919266292024, 55.94473763874599, 59.50850691114153, 56.88630540030343, 58.80856622968401, 60.17984185900007, 61.531766755240305, 59.28486524309431, 59.769272804260254, 56.78454903193882, 55.55269248144967, 55.09063032695225, 54.15862676075527, 49.45764929907662, 54.65285907472883, 54.67727504457746, 55.469373158046174, 56.22518083027431, 49.809665884290425, 54.35843958173479, 55.68013981410435, 55.69002015250069, 59.022751399448936, 64.90681947980607, 67.95973982129777, 64.28699847630092, 62.814536230904714, 61.40858909061977, 58.90356894901821, 60.22913932800293, 58.58174923488072, 57.60016679763794, 62.02577672685896, 61.32454368046352, 61.769770349775044, 61.83039338248116, 61.88686139242989, 63.8044182913644, 65.36996555328369, 60.489210401262554, 59.53267274584089, 62.081487383161274, 56.70469338553292, 60.69714914049421, 56.23212208066668, 63.64303248269217, 71.39465127672467, 61.032156535557334, 62.506654603140696, 60.827434812273296, 63.20090470995222, 62.00931644439697, 66.3559010369437, 57.647216524396626, 60.478808947971885, 58.47657435280936, 67.74575614929199, 70.8582295009068, 65.57453441619873, 56.33142226082938, 54.04078878675188, 53.88408258983067, 62.11550576346261, 42.73797001157488, 48.40247501645769, 10.280375719070435, 0.4315398037433624, 1.1790612063237598, 0.19786093357418263, 0.28598131292632645, 0.1288296849067722, 0.30013091223580496, 0.2611230196697371, 0.6156132178647178, 0.4089101723262242, 3.611888804606029, 56.19260420118059, 54.17522948128836, 39.42515924998692, 53.27972132819039, 33.53105797086443, 0.5552670274462018, 0.4670086205005646, 0.17316432164183684, 0.46208229341677254, 0.17764088857386792, 0.15798124564545496, 0.18923454146300042, 0.2286090872117451, 0.1054936306817191, 0.1457137939121042, 0.31330420821905136, 0.1582381525742156, 0.1937175951898098], [0.11512838011341435, 0.051755560495491536, 0.03071249322965741, 0.05774093485836472, 0.1392316674547536, 0.1289173923432827, 0.10208542392190013, 0.10180600320122071, 0.0339541637471744, 0.08413024060428143, 0.06689441975738321, 0.11165296445999827, 0.027922128227406313, 35.39226150512695, 39.669291155678884, 39.51316513334002, 24.33039062363761, 40.27150542395455, 35.24898270198277, 0.9888374422277723, 0.8626294944967542, 0.3600409132029329, 0.09423368810010807, 0.22199983043330057, 0.19071977319461958, 0.11858580101813589, 0.4662227141005652, 0.08490366195993763, 0.5980114223701614, 0.3029700927436352, 6.751216726643698, 44.37406233378819, 38.008973939078196, 42.34234653200422, 42.148550851004465, 46.3890677179609, 43.29897451400757, 45.6318530355181, 46.08441005434309, 50.96978923252651, 54.56896652494158, 50.19973427908761, 53.2443654196603, 59.764353479657856, 55.09077276502337, 57.311719281332834, 67.94713578905377, 60.444741930280415, 60.468365805489675, 59.379326002938406, 66.96787057604108, 69.9094043459211, 68.76010281699044, 68.72550773620605, 68.81147779737199, 66.35133607046944, 65.2811119897025, 64.73936789376395, 64.28193323952812, 63.34708786010742, 64.54558263506208, 63.20617839268276, 62.333081654139924, 62.540395055498394, 66.42840548924038, 65.37578814370292, 65.26772281101772, 64.04570838383266, 59.87556634630476, 63.99216556549072, 60.135658264160156, 51.49222428458077, 58.37765979766846, 62.23652253832136, 58.692357608250205, 60.79902362823486, 58.430111748831614, 53.01069402694702, 49.28505604607718, 50.94933720997402, 50.73573568889073, 48.48297337123326, 47.9004989351545, 48.20541368212019, 47.82358932495117, 48.271053314208984, 51.49176917757307, 54.23178434371948, 57.47694744382586, 53.36786617551531, 52.04114934376308, 53.79242542811802, 51.81166771480015, 53.997254848480225, 49.12513978140694, 46.18060786383492, 48.04810994012015, 47.742958954402376, 48.28694037028721, 48.86468308312552, 50.199793338775635, 48.426144054957796, 51.978407110486714, 54.06313419342041, 52.97377477373396, 51.65797356196812, 55.197712489536826, 60.415601185389924, 61.65717479160854, 57.86780445916312, 54.858529227120535, 54.62268304824829, 55.125089917864116, 51.60888453892299, 54.135666438511436, 54.06165075302124, 53.15460859026228, 55.25529568535941, 57.63702351706368, 55.83970866884504, 56.78980187007359, 56.6276969228472, 57.85705212184361, 58.656289509364534, 51.25923381532942, 53.93859120777675, 52.22956364495413, 54.75000878742763, 65.91010461534772, 61.38156059810093, 59.12779426574707, 57.48810625076294, 56.5526841708592, 57.7286285672869, 59.089697292872835, 54.185325213841026, 48.881761755262104, 44.077787671770366, 52.71109117780413, 72.85928985050747, 52.65325089863369, 52.122874055589946, 35.67685277121407, 39.590272767203196, 43.08213513238089, 27.41906292097909, 20.83121006829398, 20.291010209492274, 0.27678691915103365, 0.12772128438310965, 0.09152686941836562, 0.08334564377686807, 0.01692271595155554, 0.1291810574808291, 0.04724324833867805, 0.14471124485135078, 0.1557690179241555, 0.26514749228954315, 28.040186711720057, 43.50088916506086, 17.252161707196915, 35.6460896219526, 30.456521783556255, 0.06453700589814357, 0.055781020383749685, 0.06451763372336115, 0.13592021300324372, 0.03178324523781027, 0.14389715210667678, 0.031154857349715064, 0.13581385942442076, 0.11424528035734381, 0.07659549598715135, 0.039939622926924906, 0.02621498331427574, 0.0610767894291452, 0.08081208222678729, 0.08353965050940003, 0.12096583044954709, 0.03840280217783792, 0.07590550729738814, 0.03995457783873592, 0.07210591475346259, 0.11533327054764543, 0.07968941211168255, 0.09571837021836213, 0.09127684962004423, 0.031572675465473106, 0.10125001839229039, 43.09814725603376, 45.07332556588309, 44.284715448107036, 31.305459635598318, 44.15599659511021, 39.79775987352644, 1.221757126705987, 0.3047183517898832, 0.4302652435643332, 0.019675230574128882, 0.2812592791659491, 0.046123210939445665, 0.16084004938602448, 0.16056503914296627, 0.3036677624498095, 0.7232737636991909, 0.2695249659674508, 14.081007344382149, 63.584931646074565, 51.82358387538365, 58.66691330501011, 58.017319270542686, 61.19578661237444, 56.24763740812029, 58.61710861751011, 56.05842753819057, 53.65614346095494, 57.367416041237966, 53.69363594055176, 57.685692174094065, 62.03159931727818, 57.97143684114729, 59.8490937096732, 69.31247070857457, 62.531417982918875, 63.23640305655343, 63.80796882084438, 72.30120359148297, 73.53134741101945, 71.33769689287458, 70.68857533591134, 69.82470580509731, 70.8325628553118, 68.19934844970703, 68.03076430729458, 65.88701575142997, 66.89297594342912, 67.43112087249756, 68.29153714861188, 65.07980183192662, 64.21919795445034, 66.27337728227887, 68.90456281389508, 69.00542981284005, 66.2648240498134, 63.794920103890554, 65.0756607055664, 57.49207714625767, 54.74568700790405, 63.0478914805821, 62.64788368770054, 60.688679286411826, 61.645147459847585, 60.277686391557964, 54.86770779745919, 51.79606900896345, 54.25481414794922, 53.07966879435948, 53.966238089970176, 48.619977951049805, 50.44954981122698, 52.412686892918174, 51.92951611110142, 55.974976199013845, 57.27859027045113, 60.11282648359026, 58.94391713823591, 56.34837933949062, 57.3344155720302, 55.20475448880877, 55.81767245701381, 51.51807158333914, 47.287487166268484, 50.71721179144723, 49.49283150264195, 51.76001133237566, 50.017674105507986, 51.931183678763254, 49.51548957824707, 50.696940422058105, 55.75161940710885, 54.07243088313511, 54.29242822102138, 54.3631261416844, 59.57430635179792, 62.64718886784145, 59.551300866263254, 58.05700043269566, 57.40486683164324, 55.57805340630667, 55.28046553475516, 56.733983516693115, 56.4596860068185, 56.42466361182076, 58.502671786717, 60.83166626521519, 59.792597906930105, 59.11497483934675, 60.11703709193638, 61.17611626216343, 60.5863253729684, 52.95732838766915, 55.56497689655849, 55.5296175139291, 54.94154977798462, 65.46645518711635, 64.22839042118618, 62.61266326904297, 61.17289229801723, 61.8502721786499, 60.02482060023716, 57.41263491766793, 56.12214599336897, 51.46920837674822, 45.494886670793804, 48.263549259730745, 72.55094964163644, 60.28304345267159, 60.421159744262695, 49.43487310409546, 45.59858853476388, 51.417694432394846, 47.113816942487446, 33.25950847353254, 28.70784953662327, 0.732006943651608, 0.07944534306547471, 0.09880941613976445, 0.07890856079757214, 0.050028006945337565, 0.13502114053283418, 0.04090242679896099, 0.11125967877783946, 0.04480032888906343, 0.24888566774981363, 31.87848104749407, 44.22270972388131, 21.10863253048488, 45.05708762577602, 36.1071651322501, 0.021383228745045404, 0.036326081292437654, 0.09774222983313458, 0.1472177260688373, 0.08471504958080393, 0.13143606004970415, 0.056692048641187806, 0.10033331079674618, 0.05366037792659231, 0.1097107393933194, 0.04389056609943509, 0.09940702907208886, 0.050035752422575436, 0.19031985822532857, 0.17995666073901312, 0.20446438209286757, 0.15643517646406377, 0.18024688373718942, 0.14831413009337016, 0.15375835581549577, 0.19304570981434413, 0.16535154730081558, 0.149728943460754, 0.15984116441437177, 0.17582933578108037, 0.2434204210128103, 50.982132707323345, 53.967592988695415, 51.178787572043284, 39.1441775730678, 54.350681918007986, 49.292796339307515, 1.6049368168626512, 1.7869410791567393, 0.6760853986654962, 0.6014447552817208, 0.3667714649013111, 0.3502083979547024, 0.14880339455391678, 0.8745892984526498, 0.918274251478059, 2.830208646399634, 0.4880810411913054, 22.210255520684377, 83.65972260066441, 61.66907010759626, 69.9371554510934, 65.37635789598737, 73.55104555402482, 68.34126540592739, 67.57022380828857, 64.89230469294957, 65.04364340645927, 68.81260340554374, 62.86043603079659, 65.90617888314384, 70.0273917061942, 65.49749973842076, 65.66693156106132, 75.72816630772182, 64.23640169416154, 66.72376646314348, 69.72283131735665, 74.31271403176444, 77.85436371394566, 72.95106860569545, 75.59492765154157, 74.11684431348527, 73.10542978559221, 72.91697379520961, 71.6518805367606, 68.52459362574986, 71.02112306867326, 72.34248978751046, 70.17969621930803, 68.7666688646589, 69.22748729160854, 70.91812992095947, 72.41359765189034, 70.49975109100342, 69.12115206037248, 65.9838319505964, 67.99348027365548, 63.262701988220215, 57.22264684949602, 64.05915314810616, 66.43143490382603, 64.99232401166643, 65.85008607591901, 65.31368514469692, 59.195893560137065, 55.051119395664756, 56.672248772212434, 57.05851650238037, 55.25766502107893, 52.270985330854145, 53.26385164260864, 55.92586980547224, 54.868597166878835, 60.1647503716605, 59.61971977778843, 63.08603709084647, 60.842713900974815, 59.168580191476, 59.33236312866211, 57.155245849064414, 56.845887729099815, 55.02802358354841, 50.746383803231375, 53.86602422169277, 52.521766662597656, 52.14821066175188, 53.39126770836966, 54.422627040318076, 53.75952918188912, 55.95067834854126, 58.219515323638916, 57.47964334487915, 56.558902808598106, 60.67904213496617, 65.04042639051164, 64.67889077322823, 62.45864255087716, 59.872835704258506, 58.6417121887207, 59.44142900194441, 57.522850717817036, 61.05497441973005, 60.37198734283447, 58.72982924325125, 61.972213063921245, 63.49093641553606, 62.282464027404785, 61.51256193433489, 61.869268553597585, 62.86084597451346, 62.04331398010254, 55.47143677302769, 58.44783660343715, 55.400249004364014, 58.236124992370605, 68.7725053514753, 67.86191613333565, 64.51143223898751, 63.158492905753, 63.120979581560405, 64.14223275865827, 64.41478279658726, 63.79014669145857, 58.99139417920794, 58.11496230534145, 57.962199211120605, 72.99275084904262, 62.72696113586426, 62.130597250802175, 51.464007650102886, 52.74191338675362, 54.865268979753765, 53.85748488562447, 40.198278359004426, 35.203617913382395, 0.4666640875594956, 0.2013581030602966, 0.3123020391379084, 0.16021920341466153, 0.19289598427712917, 0.35728934513671057, 0.16149159228163107, 0.3374567979148456, 0.19470265161778244, 0.5406652795416969, 41.32033600125994, 56.06499011175973, 28.537974766322545, 48.324151447841096, 44.399020263126914, 0.09424500606421914, 0.16290948619799955, 0.18178257133279527, 0.16334444071565354, 0.1462583996887718, 0.34790490727339474, 0.1134939928139959, 0.13316089606710843, 0.18066605553030968, 0.1553864191685404, 0.10322779869394642, 0.14552559543933186, 0.07823482302150556], [0.0951044453041894, 0.09887884384287254, 0.039595717630748234, 0.097355756642563, 0.027107523188793232, 0.09519825277051755, 0.03801862582830446, 0.1441621607435601, 0.03172170550429395, 0.14658679706709726, 0.07257651271564619, 0.07027174638850348, 0.7865345062954086, 47.34076942716326, 37.84778962816511, 36.27910525458199, 20.59374843324934, 50.33382408959525, 20.740584714072092, 0.7971876689365932, 0.15754675253161363, 0.2972476812345641, 0.09173201769590378, 0.21786642580160073, 0.12054769002965518, 0.2103156881140811, 0.12672932046864713, 1.3380235050405775, 0.9459193966218403, 0.1001422828329461, 14.955947092601232, 45.32633032117571, 40.42193739754813, 43.02208880015782, 46.49566698074341, 45.70564637865339, 49.90480409349714, 45.946516105106895, 46.97423458099365, 49.65385947908674, 51.28871502195086, 51.68499163218907, 62.00827421460833, 60.15523133959089, 59.50745078495571, 55.83346571241106, 60.98294939313616, 58.414797919137136, 59.84065859658377, 57.04833739144461, 67.07786055973598, 67.57034192766461, 69.35904448372978, 67.35886655535016, 69.05077375684465, 64.23543589455741, 63.1989175251552, 65.67220524379185, 66.0809816632952, 65.52581364767892, 62.42025375366211, 62.603380475725444, 61.23614869798933, 63.30817794799805, 63.59898090362549, 64.38726098196847, 66.53943075452531, 60.522679873875205, 64.19680391039167, 56.34849745886666, 51.52652754102434, 61.91454996381487, 62.64853681836809, 57.934757300785606, 63.08133316040039, 58.13571310043335, 54.687384673527305, 48.46805558885847, 47.559338910239084, 51.8497507912772, 49.009532179151265, 49.33950560433524, 45.26886871882847, 48.2778069632394, 50.56852728979928, 53.396107128688264, 51.974839210510254, 55.988962922777446, 57.14815173830305, 52.2443459374564, 54.48347936357771, 54.03580692836216, 51.27565240859985, 53.68603808539254, 46.62090826034546, 45.876870836530415, 48.22032104219709, 46.81631244931902, 50.38461194719587, 52.14487900052752, 51.812049865722656, 52.613906724112375, 46.84752723148891, 49.5812577520098, 56.141006878444124, 53.50986998421805, 53.75604118619646, 54.23127712522234, 57.30698755809239, 59.08997522081648, 59.93690504346575, 55.49678727558681, 52.73840454646519, 50.53319569996425, 53.872468675885884, 53.11581679752895, 53.99407952172415, 53.911743368421284, 54.314450536455425, 56.51500756399972, 55.305795192718506, 57.962515354156494, 57.9768043245588, 58.649653979710166, 52.89616686957223, 50.926842417035786, 52.12086950029646, 52.48810611452375, 58.881980895996094, 64.15684482029506, 57.173057556152344, 55.625982080187114, 56.377186570848735, 57.857093811035156, 56.962561879839214, 56.0301970073155, 48.93060064315796, 48.58442749295916, 32.0197240284511, 64.36292144230434, 57.918310914720806, 45.435788767678396, 43.39365414210728, 32.503676482609336, 40.97119944436209, 36.385218143463135, 20.0454261302948, 25.061676365988596, 4.049924305507115, 0.24406570781554493, 0.349926941628967, 0.09734376692878348, 0.028838325225348984, 0.023990435093375187, 0.05317910660856536, 0.029509684736175195, 0.04990776714735797, 0.2609007315976279, 14.873904500688825, 43.53499092374529, 25.699460199901036, 37.27151298522949, 35.32430464880807, 0.09560540092310735, 0.04870406298765114, 0.04538050347140857, 0.08158077419336353, 0.087730513486479, 0.07388029061257839, 0.1824724514569555, 0.006643478692110095, 0.1157284357718059, 0.1678434264447008, 0.026299759479505674, 0.011774077895097435, 0.05235300040138619, 0.07260528938578707, 0.018604877205299478, 0.04321835841983557, 0.027862963366455266, 0.03079741188724126, 0.07588542266083614, 0.07652896562857286, 0.05402214226445981, 0.026283145549574068, 0.09346787990736109, 0.02460450249990182, 0.06080431690705674, 0.9319310443741935, 54.287088530404226, 44.75288506916591, 39.949459893362864, 16.510274750845774, 57.50430250167847, 24.125971146992274, 0.9718065389565059, 0.05100583697536162, 0.3522552124091557, 0.10258082233901535, 0.10418407845177821, 0.0350018523500434, 0.13167894844497952, 0.05547423095309308, 2.2359033823013306, 1.9329881966114044, 0.15608020765440805, 25.84027065549578, 60.10100064958845, 53.309584685734336, 58.97947107042585, 58.03188269478934, 58.3429604939052, 60.67390741620745, 54.00430727005005, 56.50984157834734, 53.43380805424282, 55.95988123757498, 57.56849690846035, 62.35177230834961, 61.33026899610247, 64.49046257564, 61.8000089100429, 65.75090054103306, 62.534162521362305, 63.63958617619106, 61.164464133126394, 70.10127885001046, 70.50990240914481, 71.21597140175956, 71.82708631243024, 71.24572358812604, 66.03310857500348, 66.96010943821499, 67.80464213235038, 67.60351957593645, 69.90700026920864, 66.79786900111607, 67.70219789232526, 67.4178776059832, 68.33946582249233, 65.05179364340646, 68.84145927429199, 67.1157421384539, 64.43730885641915, 65.28350217001778, 56.98903104237148, 55.58119051797049, 65.05585139138358, 64.83664962223598, 61.54800469534737, 64.66627284458706, 60.33354296003069, 56.9860189982823, 50.98048945835659, 51.650466033390586, 52.404147556849885, 52.61641502380371, 51.70214326041085, 47.01527411597115, 49.3787386076791, 53.57483911514282, 56.09954350335257, 56.30075986044747, 60.27363559177944, 59.35577160971505, 57.59182895932879, 57.50008841923305, 57.48947851998465, 53.961693968091694, 54.66561596734183, 47.51466546739851, 47.61795391355242, 50.25526775632586, 47.01383236476353, 52.83866705213274, 51.236353397369385, 55.079391615731375, 55.36620283126831, 49.41113805770874, 50.38050556182861, 58.39789295196533, 56.5602125440325, 55.47231919424874, 54.29459605898176, 57.15220948628017, 60.78561360495431, 59.982401847839355, 57.10169608252389, 57.002045018332346, 54.58808101926531, 56.19036340713501, 54.959184306008474, 56.038475785936626, 58.5563257762364, 57.61875670296805, 62.91087300436837, 58.875755310058594, 60.193772997174946, 60.566252027239116, 61.31246771131243, 56.587671824863975, 55.1968926021031, 53.24970858437674, 52.31140647615705, 60.00113419124058, 64.6573235648019, 59.47097274235317, 59.53232533591134, 59.10122435433524, 58.9945764541626, 55.49736745016915, 55.56023127692086, 52.39388854163033, 51.97137205941336, 36.44029998779297, 60.717090470450266, 66.76649788447789, 55.9174416405814, 57.055285590035574, 45.56518159593855, 47.173248359135215, 49.635571820395334, 37.626201152801514, 35.768412658146445, 7.749343258993966, 0.08062499655144555, 0.542133303625243, 0.15357428283563682, 0.06409930331366402, 0.035200975236615965, 0.005204528985944177, 0.10008333171052591, 0.061051385078047, 0.28623364652906147, 18.700225353240967, 45.14412423542568, 27.858677182878765, 49.27521044867379, 42.34592832837786, 0.4034714155963489, 0.12330145654933793, 0.1458993868104049, 0.08135480167610304, 0.14847608283162117, 0.06055421568453312, 0.09704707070652928, 0.011602628211091672, 0.1070296982569354, 0.0582141587510705, 0.028275514354131052, 0.009175890973503036, 0.038771989688809426, 0.2131956485765321, 0.1459119532789503, 0.17365049198269844, 0.1563409279499735, 0.1123126158490777, 0.14423157487596783, 0.23001235191311153, 0.26031157321163584, 0.16944960025804384, 0.23581553623080254, 0.1264420287417514, 0.10095616523176432, 1.6586480204548155, 68.1511835370745, 47.53383902141026, 48.310199465070454, 33.648110798427034, 67.73559093475342, 32.22162478310721, 1.414056122303009, 0.3325139960008008, 0.3441206089087895, 0.33707065720643314, 0.17334592475422791, 0.32639968980635914, 0.3526796767754214, 0.21756484412721225, 2.4175698970045363, 3.897684063230242, 0.16703834464507444, 39.43137093952724, 75.13122572217668, 65.24635710035051, 69.36838286263603, 68.0417285646711, 67.87647260938371, 68.18773800986153, 61.77148655482701, 65.79139464242118, 64.01737362997872, 65.84114374433244, 63.552268164498464, 69.21377849578857, 71.13417025974819, 70.48641054970878, 66.44833987099784, 68.70082773481096, 63.515498297555105, 69.79402256011963, 64.6000565120152, 72.7691786629813, 74.25731604439872, 75.38603006090436, 73.78251089368547, 75.19797011784145, 68.71885136195591, 69.57996245792934, 73.18094975607735, 70.65195832933698, 74.40622983660016, 69.78660188402448, 69.55315630776542, 66.01194436209542, 70.92411926814488, 68.45158195495605, 69.94244997841972, 73.96781935010637, 65.78033311026437, 70.45043972560337, 63.20248889923096, 56.653016158512656, 65.95740100315639, 68.16247435978481, 63.83421911512102, 68.69829164232526, 64.06066785539899, 60.43777288709368, 53.63507652282715, 55.107938289642334, 58.02406249727522, 55.80432496752058, 57.82696989604405, 49.84807552610125, 53.80489049639021, 56.45971032551357, 58.07132761819022, 59.03643935067313, 63.63973208836147, 60.74955940246582, 58.04380580357143, 59.53292982918875, 59.932451248168945, 55.81632798058646, 59.31809152875628, 50.54479571751186, 48.507549149649485, 53.29912764685494, 50.94221878051758, 56.315684591020855, 54.9012884412493, 58.294246673583984, 57.15171269008091, 52.10424593516758, 54.554660184042795, 60.085895265851704, 58.548877307346885, 57.75255816323416, 59.66457734789167, 61.60356943947928, 65.3890939440046, 62.489304951259065, 59.79796191624233, 57.28529528209141, 55.59022317613874, 59.471910749162944, 58.14692401885986, 58.096778869628906, 60.778985023498535, 60.248351097106934, 63.90150547027588, 60.14735208238874, 63.49229826245989, 63.013970375061035, 62.57007081168038, 58.17860433033535, 57.217366218566895, 55.80262265886579, 56.59393562589373, 62.376146589006694, 68.00691808973039, 63.653267179216655, 58.482181549072266, 62.045738901410786, 62.323076248168945, 61.576672962733674, 60.865448406764436, 57.59279475893293, 60.26729883466448, 48.86772639410836, 65.46927615574428, 67.09634971618652, 57.34658881596157, 56.9814019203186, 51.205360957554404, 52.329732349940706, 54.73612976074219, 42.82550341742379, 42.558991364070344, 8.282575811658587, 0.39186979670609745, 1.05235798231193, 0.23270855152181216, 0.3258122684700148, 0.11718062284801688, 0.13256849428372725, 0.41823088218058857, 0.2095890042505094, 0.2855504703308855, 25.566416093281337, 56.1892204284668, 39.34288215637207, 48.5587990624564, 50.547363076891216, 0.4539335492466177, 0.1985568662307092, 0.17116799019277096, 0.14906799606978893, 0.15698407058204922, 0.11908003235501902, 0.24177369794675282, 0.18859796704990522, 0.18204201598252567, 0.24255349753158434, 0.1148897936301572, 0.13957622753722326, 0.2261904084256717], [0.03009249542706779, 0.0540370564641697, 0.05939032456704548, 0.06141815361167703, 0.10219808109104633, 0.145138857620103, 0.13257823804659502, 0.07151500574712243, 0.0190102068840393, 0.030349202187997953, 0.06788043970508234, 0.302051274904183, 3.2801129732813155, 52.315214088984895, 31.623874732426234, 43.149539606911794, 31.86089515686035, 62.13316113608224, 11.697069985525948, 0.37125636424337116, 0.129653412848711, 0.08146383546824966, 0.04696676567462938, 0.21557292315576757, 0.15078460824276718, 0.41738192630665644, 0.2573677626039301, 0.6080723053642682, 0.7164449872715133, 0.39907586574554443, 28.339230230876378, 43.52005577087402, 41.86841685431344, 45.55701398849487, 51.589676243918284, 49.409095287323, 55.22394888741629, 51.78540005002703, 50.31137445994786, 41.00528730664934, 44.777179445539204, 53.96236794335501, 52.038991928100586, 59.022487367902485, 57.35184512819563, 60.648171288626536, 63.99466691698347, 65.10354382651192, 59.2489013671875, 57.23930515561785, 68.00725160326276, 65.5408078602382, 68.95936325618199, 66.9487977709089, 64.00406782967704, 64.92700399671281, 68.46633298056466, 63.467597416469026, 62.34323992047991, 62.74551977430071, 66.99763665880475, 62.24520778656006, 63.26318141392299, 60.79372215270996, 59.77032893044608, 59.44010884421212, 61.61979348318917, 68.03216784340995, 54.86805520738874, 55.6739559173584, 66.94368389674595, 61.388036319187705, 61.38065733228411, 60.67360864366804, 57.15227549416678, 53.15778391701834, 49.727670192718506, 49.92025688716343, 47.946113858904155, 45.68733440126692, 47.074608257838655, 48.22728313718523, 45.19217102868216, 43.97238349914551, 49.96453080858503, 55.89643376214163, 56.507493087223594, 55.89288323266165, 58.425859451293945, 55.5053266116551, 55.82011474881853, 54.9474071093968, 51.16651357923235, 45.10172632762364, 45.43769952229091, 46.50702381134033, 46.542414460863384, 43.45759146554129, 47.02503286089216, 49.99408149719238, 51.413456031254356, 52.34248229435512, 53.98106207166399, 44.79300396783011, 50.237574168613975, 57.63002668108259, 58.35446671077183, 56.92641387666975, 53.22679342542376, 52.84662273951939, 57.289835929870605, 59.39805834633963, 58.25763661520821, 54.83015625817435, 52.31749309812273, 50.11337511880057, 53.71777745655605, 55.931987694331575, 54.52090930938721, 56.60856853212629, 54.51851912907192, 55.37088244301932, 57.406364168439595, 56.10477549689156, 55.81664064952305, 55.82869577407837, 49.69203288214547, 51.542206151144846, 55.79603229250227, 60.93451350075858, 59.368966238839285, 59.08912754058838, 56.53613008771624, 56.81457914624895, 51.89162063598633, 57.173752376011436, 54.018589292253765, 50.69963979721069, 31.719902311052593, 42.39740058353969, 65.17092745644706, 43.23021861485073, 41.84173924582345, 33.28739159447806, 34.31623567853655, 39.64804356438773, 28.53138439995902, 26.642183099474224, 10.924468517303467, 0.3799108069922243, 0.19941020544086183, 0.13921260062072957, 0.033466290283415995, 0.06300568806805781, 0.05001384931217347, 0.10210836519088064, 0.086220508441329, 0.29106761142611504, 5.7431855372020175, 43.62502220698765, 35.45543452671596, 23.055861711502075, 45.19313335418701, 0.8231381050177983, 0.1925637192491974, 0.04436855670064688, 0.06195560762924807, 0.05622993915208748, 0.07562548268054213, 0.027666720861036862, 0.1729684014405523, 0.035308614639299254, 0.028715445926146846, 0.06048197206109762, 0.10533911468727247, 0.04160289206941213, 0.042595799147550545, 0.04409771944795336, 0.049563610793224404, 0.0854465306869575, 0.03021604647593839, 0.034269350048686774, 0.1498701058860336, 0.05169540497341326, 0.023607096734589765, 0.023972206250099198, 0.04711116131927286, 0.3643968366086483, 4.907861811774118, 61.49436460222517, 39.16064827782767, 40.3763815334865, 27.840634448187693, 71.3451314653669, 13.225737077849251, 0.4240130047713007, 0.16954578938228743, 0.07413799821266107, 0.03965071628668478, 0.21972463466227055, 0.04457329785717385, 0.0484101962564247, 0.15011425635644368, 1.171405051435743, 1.7956360982997077, 0.33569605382425444, 39.97086729322161, 57.57939863204956, 57.8063302721296, 58.12982450212751, 61.09320340837751, 59.27347019740513, 62.95342377253941, 61.90291173117501, 57.874370506831575, 51.3189640045166, 52.78810501098633, 57.83249371392386, 56.88199404307774, 63.41386699676514, 60.59226608276367, 64.38645499093192, 68.20348262786865, 64.94955090114048, 63.248972347804475, 63.249806131635395, 72.01738357543945, 68.60055828094482, 70.5679407119751, 69.9559086390904, 68.10577011108398, 69.56666360582624, 71.05596828460693, 66.43449211120605, 65.08993230547223, 66.20784187316895, 69.82337175096784, 66.907365662711, 66.82346616472516, 65.69675322941372, 63.880285671779085, 65.18989603860038, 65.4322144644601, 70.20550182887486, 56.91128764833723, 62.646146638052805, 68.29835333142961, 62.882204736982075, 64.69008432115827, 64.75468172345842, 60.723614828927175, 56.69017859867641, 50.05582318987165, 53.37073925563267, 50.93289777210781, 48.67133208683559, 49.44101531164986, 52.85607923780169, 49.096158845084055, 46.101881299700054, 49.40242154257638, 57.77555322647095, 59.73270443507603, 58.398726735796245, 61.02884224482945, 57.61033548627581, 58.61264092581612, 57.92452607836042, 53.49165528161185, 46.97682278496878, 45.949510778699604, 49.177303382328574, 49.56909145627703, 44.97409834180559, 47.97411857332502, 49.85758760997227, 52.67480421066284, 53.16867521830967, 55.743316309792654, 47.529145513262065, 51.12564427512032, 58.310505458286826, 60.04722854069301, 58.16340167181832, 53.959960392543245, 52.32511179787772, 57.80281795774187, 60.65427875518799, 60.73857430049351, 56.22574710845947, 56.05851091657366, 53.74756438391549, 58.27719579424177, 60.15209770202637, 59.65162590571812, 59.46505287715367, 58.623723302568706, 59.5009959084647, 60.70756449018206, 60.18720000130789, 59.41223267146519, 58.49370166233608, 52.771071502140586, 54.33392981120518, 56.996281487601145, 63.31263869149344, 61.516418184552876, 61.22304439544678, 59.76418672289167, 59.403943470546174, 52.977294036320274, 56.380573817661826, 54.43359824589321, 51.63668080738613, 37.84573296138218, 43.083382334027974, 69.21276405879429, 54.63636057717459, 54.81007249014718, 49.77427176066807, 43.08783265522548, 46.3750010899135, 43.854128633226665, 38.86208071027483, 16.28311903136117, 0.5045523973447936, 0.13717396929860115, 0.15553904883563519, 0.0632915480860642, 0.039025154496942244, 0.07978448165314538, 0.05004783034590738, 0.05594438786751457, 0.33084241141166004, 8.651495626994542, 50.929593903677805, 31.76705973488944, 30.612109320504324, 53.63091107777187, 1.1050925297396523, 0.12781494935708387, 0.03581945312076381, 0.0217639971524477, 0.07126197325331823, 0.07075399479695729, 0.024767103239095638, 0.09213957296950476, 0.055498183239251375, 0.05579598208091088, 0.06877187865653209, 0.05393354933974998, 0.06175698685858931, 0.20556960707264288, 0.16416031122207642, 0.10836854284363133, 0.16031943660761627, 0.19659807133887494, 0.22012833585696562, 0.24672420801860945, 0.15434665924736432, 0.14703716790037497, 0.14022133792085306, 0.13071897067129612, 0.4713454363601548, 6.058064000947135, 73.68302658626011, 41.64758920669556, 55.31414692742484, 48.56611204147339, 82.45838601248605, 18.065726280212402, 0.9359436290604728, 0.6858516888959068, 0.15848488147769654, 0.29403685352631975, 0.5800357269389289, 0.24183788735951695, 0.6300933180110795, 0.7688569862927709, 3.370625853538513, 4.009014614990779, 0.9397858743156705, 57.15182386125837, 69.26686968122209, 69.46843692234584, 70.25982979365757, 69.93309770311627, 67.93856866019112, 68.75332832336426, 71.56120654514858, 66.61777864183698, 61.68586390359061, 62.559321948460166, 70.44472135816301, 68.95238031659807, 72.18804522923061, 69.73826326642717, 71.07093470437187, 69.81562450953892, 69.50604057312012, 69.14947986602783, 69.1190606525966, 75.70072787148612, 71.72478103637695, 73.92976406642369, 74.39246545519147, 71.31856850215367, 71.35269805363247, 76.31669957297188, 69.42262050083706, 69.3326552254813, 70.83657891409737, 72.65750026702881, 70.11347988673619, 68.87383093152727, 68.81013679504395, 65.95584460667202, 66.4640427998134, 66.07592337472099, 73.26506464821952, 60.57021944863455, 62.46563243865967, 71.67383684430803, 65.51049286978585, 68.46365792410714, 65.55628149850028, 62.6805819102696, 59.926302092415945, 54.59734296798706, 57.136041028159006, 53.967773641858784, 50.29691178458077, 52.44749389375959, 55.986902781895225, 50.593617234911235, 48.98234040396554, 53.260672841753276, 59.687930243355886, 61.650636536734446, 59.86663096291678, 62.7959497996739, 58.46844496045794, 60.2064882005964, 60.32414204733712, 56.08001559121268, 50.81895773751395, 49.12486185346331, 50.92450087411063, 51.741199084690635, 47.54801682063511, 51.853655678885325, 54.25555413109915, 54.863511085510254, 56.51306206839425, 58.23537458692278, 47.81720393044608, 54.82936763763428, 62.26926245008196, 61.51948234013149, 60.06040927342006, 57.80193206242153, 56.764836992536274, 60.83733599526541, 63.500670841761995, 63.017666816711426, 57.585342815944124, 56.36629179545811, 57.47619009017944, 59.85338074820382, 62.129860741751536, 62.0966830934797, 63.184041431971956, 62.49392550332205, 60.925105639866416, 64.23094735826764, 62.499497958592, 61.029113224574495, 60.192286082676475, 53.947509220668245, 55.19228247233799, 61.10834353310721, 67.67051410675049, 63.85762759617397, 64.12636307307652, 63.215898922511506, 63.11360059465681, 56.3580755506243, 62.36147894178118, 61.8229866027832, 62.446559633527485, 48.58486870356968, 54.35331528527396, 68.39537102835519, 57.777265957423616, 52.53729241234915, 49.84888846533639, 48.54015357153756, 53.176995686122346, 47.95750195639474, 44.642266273498535, 19.759490387780325, 0.4457000967647348, 0.43495926739914076, 0.27645799251539366, 0.1330960009779249, 0.14753758747662815, 0.21429051911192282, 0.3045763751225812, 0.30832631247384207, 0.6560693212917873, 14.683671508516584, 60.471402168273926, 50.07234600612095, 33.16474199295044, 59.76503440311977, 1.4338585968528474, 0.24677615665963717, 0.0798773527411478, 0.07779959708984409, 0.1255100066108363, 0.14811960767422402, 0.11974681514714446, 0.28061315097979134, 0.12328130405928407, 0.15749849512108735, 0.18397039893482411, 0.2106858425374542, 0.13788237342877047], [0.01616371007237051, 0.05694223128791366, 0.03344385452302439, 0.08138393118445363, 0.057270085838224204, 0.05268780654296279, 0.09898297861218452, 0.09137442295572587, 0.04502263731722321, 0.12126370732273374, 0.10087673592248134, 0.4877859598823956, 11.316247037478856, 57.81018304824829, 31.880867753710064, 37.10440533501761, 21.427245650972637, 60.65170792170933, 3.5487021037510464, 0.033176437086824856, 0.11437994241714478, 0.025147116776289682, 0.17813554060246262, 0.08362304924854211, 0.24064613559416362, 0.21868689677545003, 0.43217344688517706, 1.3382113235337394, 0.5165399398122514, 2.1930712120873586, 48.18093517848423, 45.70356886727469, 51.242731843675884, 50.88239131655012, 53.646881512233186, 59.08224882398333, 56.573532240731375, 47.1033981187003, 42.51294217790876, 39.62087263379778, 40.69455691746303, 41.957993030548096, 46.98973601205008, 52.335120677948, 46.983711923871724, 57.726054259708945, 65.02634934016636, 63.768141746520996, 56.59992497307913, 60.22975076947893, 66.89092622484479, 66.38916206359863, 66.72880390712193, 62.9055506842477, 63.27555615561349, 64.61938640049526, 66.46322986057827, 65.17055225372314, 65.01305743626186, 64.67627825055803, 62.4247144971575, 65.63503238133022, 58.07697997774397, 59.412434169224326, 57.51348107201712, 60.887050356183735, 67.39686625344413, 56.15658473968506, 59.93329198019845, 66.87490367889404, 60.46024336133684, 62.0326623916626, 61.99112606048584, 60.064182145254954, 51.83579533440726, 48.716026374271934, 47.7567754473005, 50.555082525525776, 45.21226174490792, 46.451983656202046, 48.744996888296946, 49.617093086242676, 42.75942257472447, 43.66775362832205, 43.00897060121809, 54.58254677908761, 55.056709221431184, 58.16350589479719, 58.01488045283726, 55.809761932918, 56.81051445007324, 53.405660901750835, 46.69085577556065, 43.873569692884175, 43.146197523389546, 47.20060689108712, 47.82700089045933, 45.26673214776175, 43.983038561684744, 49.35666070665632, 51.030961172921316, 51.43850081307547, 48.48385579245431, 52.33631576810564, 47.571310656411306, 51.67773076466152, 58.974190439496724, 60.944984436035156, 58.70321764264788, 54.56852184023176, 51.18030227933611, 56.487694195338655, 59.3648042678833, 55.52353784016201, 56.33462538037981, 52.25665814535958, 51.57394552230835, 54.58743136269705, 53.71399763652256, 55.09763411113194, 55.02797842025757, 54.88379635129656, 54.886089256831575, 55.15813555036272, 56.36720200947353, 56.330727440970286, 51.770777566092356, 52.819420542035786, 51.07883078711373, 58.8917361668178, 58.523822103227886, 56.44370862415859, 56.51464973177229, 54.94150461469378, 53.82305308750698, 54.24836621965681, 56.21961532320295, 47.14298548017229, 40.36620242255074, 30.273752893720353, 57.33378676005772, 51.129319872174946, 35.004604135240825, 37.32973888942173, 31.514280796051025, 38.92758137839181, 36.12086350577218, 30.873896598815918, 16.048224755695887, 1.0633140972682407, 0.11458587779530457, 0.20844958110579423, 0.04387421340548566, 0.06304919573345355, 0.02744582378571587, 0.017060256696173122, 0.06786491482385568, 0.3643026830894606, 1.99650211419378, 25.30985038621085, 46.42830072130476, 34.553798062460764, 42.25545583452497, 1.5098096813474382, 0.09329648196165051, 0.16209984464304789, 0.08197659759649209, 0.1465598049440554, 0.0423656909593514, 0.11316302378794976, 0.10591040724622351, 0.19137659509267124, 0.058091635682753155, 0.08337475292916809, 0.06325507682881185, 0.11279337148049048, 0.057182106987706253, 0.06651967165193387, 0.05238491190331323, 0.10172430758497544, 0.022876960824110677, 0.04478051566651889, 0.03955171124211379, 0.07902196435523884, 0.04501618105652077, 0.07594808536980834, 0.17252071760594845, 0.6379763750093324, 15.252958263669695, 65.6791603905814, 40.08850029536656, 44.79942410332816, 26.474239928381785, 67.83424145834786, 4.497444748878479, 0.16378261148929596, 0.1051083652834807, 0.014666902533333217, 0.07851690359945808, 0.04942495555483869, 0.09561741099293743, 0.07651618202882153, 0.06767424648361546, 3.3089256329195837, 0.7094045622008187, 4.098916922296796, 60.45141914912632, 55.58853128978184, 62.332859311785015, 61.570148604256765, 62.758797781808035, 65.11816283634731, 62.57259995596749, 54.289478710719514, 51.49599368231637, 51.10034588405064, 51.07936232430594, 51.728577681950156, 56.96586922236851, 58.913546562194824, 57.29415076119559, 62.675412450517925, 66.29952335357666, 67.47155938829694, 60.80895260402134, 64.10008498600551, 69.19327436174665, 70.60638509477887, 69.6790576662336, 65.54431670052665, 66.5904791695731, 66.27652481624058, 67.33919620513916, 69.2637916292463, 67.1445563180106, 65.92630086626325, 65.10469027927944, 66.54138319832938, 62.14959362574986, 64.00358840397426, 61.970093863351, 67.74628421238491, 65.66035161699567, 56.544026715414866, 66.2874195916312, 67.3839773450579, 62.64024066925049, 65.23635169437954, 65.36870098114014, 62.691337721688406, 54.43845851080758, 51.256034169878276, 51.482135500226704, 53.94353485107422, 49.70066254479544, 50.1641595023019, 49.913621357509065, 51.47357184546334, 45.464060987745015, 45.75135162898472, 46.58801548821585, 55.0316435950143, 57.29778814315796, 60.329165594918386, 59.40688950674874, 57.08803939819336, 58.588245800563264, 53.97716760635376, 49.52026993887765, 45.864579473223, 44.90896592821394, 49.42548261369978, 49.064353466033936, 46.620602539607454, 46.87284646715437, 51.23355327333723, 52.37092474528721, 52.78457185200283, 50.10661104747227, 53.39036791665213, 49.463999952588765, 51.14800010408674, 59.50901412963867, 61.903592654636924, 61.58448273794991, 58.17408800125122, 54.65456485748291, 55.3755898475647, 60.016871861049104, 57.49731956209455, 57.23614372525896, 56.368285928453716, 54.97134712764195, 57.798986026218955, 57.1617875780378, 58.72565337589809, 58.26775319235665, 58.29045990535191, 57.32953098842076, 59.18162890842983, 59.56596851348877, 57.97604349681309, 53.94229112352644, 55.67771141869681, 50.98343549455915, 59.80579948425293, 61.94974258967808, 59.130997385297505, 57.588980197906494, 57.47429323196411, 54.8562502179827, 53.41567325592041, 55.29529646464756, 49.87369006020682, 45.9073942729405, 35.64051021848406, 59.43923337118966, 61.80147497994559, 50.564083916800364, 51.26082495280674, 44.932047843933105, 44.72682932444981, 45.27285351072039, 46.06338480540684, 22.90264524732317, 2.227785497903824, 0.014391354551272733, 0.47756548545190264, 0.022951080596872737, 0.0441567384238754, 0.0841045987659267, 0.15622085439307348, 0.03704706206917763, 0.3863217958382198, 2.3709240342889513, 31.373628411974224, 44.65606539590018, 34.83091654096331, 50.658926827566965, 1.4244125208684375, 0.08115629625639745, 0.1385398195790393, 0.02117830777673849, 0.21010364592075348, 0.02784196610030319, 0.14600510256631033, 0.05602664327515023, 0.13694261599864277, 0.0372272029386035, 0.03578911582008004, 0.03203290201989668, 0.08992714847304992, 0.19647300376423768, 0.15738945454359055, 0.15692646295896598, 0.19021836295723915, 0.194501058863742, 0.2411075122654438, 0.1298576518893242, 0.18207827689392225, 0.15323367182697567, 0.18083107524684497, 0.3268807439931801, 0.6749269493988582, 18.342954192842754, 77.67832415444511, 42.54743650981358, 52.14545917510986, 31.32555730002267, 79.24214826311383, 6.989575547831399, 0.21479153579899243, 0.26724538686020033, 0.17849399708211422, 0.5174389172877584, 0.14550376018243177, 0.36772214674523895, 0.3568752759269306, 1.290018726672445, 6.461879840918949, 1.355086435164724, 7.3189753123692105, 78.50802244458879, 64.88307053702218, 73.09085941314697, 67.97799273899624, 70.54690156664167, 72.21212768554688, 69.52892793927873, 66.33150591169084, 62.65233053479876, 59.77551228659493, 58.80283396584647, 63.195943696158274, 63.42043999263218, 68.98954623086112, 63.17179870605469, 70.76690932682583, 70.61367375510079, 72.28231143951416, 65.98612485613141, 68.34921414511544, 72.37541730063302, 73.4652908870152, 71.33359745570591, 67.59450776236397, 69.0909343447004, 68.86879348754883, 70.27722808292934, 74.25093759809221, 69.81193501608712, 69.38160528455461, 67.23374339512416, 72.02005168369838, 65.630585534232, 65.63063417162213, 63.984647614615305, 66.47309630257743, 69.80489649091447, 60.162221227373394, 66.06700883592877, 73.41944667271206, 64.85055991581508, 67.13122967311314, 66.97415869576591, 65.37745571136475, 57.833383083343506, 55.52759211403983, 53.98686729158674, 58.00352362224034, 52.202132156917024, 53.46254232951573, 53.05891799926758, 56.156838348933626, 48.90721648080008, 48.456038679395405, 48.36246381487165, 60.29113810403006, 59.2105473109654, 64.24822057996477, 63.36714036124093, 58.85045691898891, 62.19526413508824, 56.901122433798655, 53.152864592415945, 48.33592517035348, 47.400037561144146, 51.37854480743408, 52.885748045785085, 49.81813226427351, 49.31183787754604, 54.52572441101074, 56.10804115022932, 56.31625781740461, 53.54369034085955, 57.13632937840053, 53.69673831122262, 57.29272290638515, 63.42193385532924, 66.65034484863281, 64.15362780434745, 58.90017127990723, 57.72572422027588, 59.40755653381348, 62.87236608777727, 61.162157331194194, 61.440370150974815, 59.02065999167306, 57.37430170604161, 60.95635863712856, 58.56515693664551, 62.70978518894741, 61.39464405604771, 61.466405051095144, 61.45154285430908, 61.889592034476145, 60.243945939200266, 60.13450486319405, 54.48281233651297, 56.45266137804304, 52.38791309084211, 64.12041541508266, 62.98537853785923, 62.83285863058907, 62.195020948137554, 62.387791769845144, 60.26243509565081, 61.34505476270403, 64.21682861873082, 58.60124588012695, 55.27731800079346, 45.290481090545654, 65.2309182030814, 62.65597139086042, 52.17692061832973, 48.497088636670796, 47.488241468157085, 51.72659049715315, 50.6379189491272, 49.16741262163435, 25.458897931235178, 2.5557128957339694, 0.24315638946635382, 0.8562528938055038, 0.3006824797817639, 0.14666252157517842, 0.20187718234956264, 0.2558212455894266, 0.13325761444866657, 0.7120364638311523, 7.064063276563372, 37.44403328214373, 61.941599300929475, 49.104972634996685, 56.62565762656075, 2.3401422117437636, 0.21369800876293862, 0.31845670459525927, 0.0803866543407951, 0.2781106595482145, 0.12713277739073547, 0.3556806743144989, 0.11484910867043904, 0.1957060963447605, 0.14772199972399644, 0.18915937335363456, 0.19988505781761237, 0.2290374327983175], [0.007817945626032139, 0.05733872644071068, 0.038702080225838084, 0.0107799859251827, 0.006615135860296765, 0.046174935663917234, 0.04259255235748632, 0.06291097136480467, 0.040768222750297615, 0.06152777772928987, 0.07593328652105161, 0.22474500669964723, 21.400441237858363, 49.665935448237825, 36.25323016302926, 30.027237755911692, 40.41343975067139, 47.436602456229075, 0.9605376464979989, 0.025044641025098305, 0.01775190610039447, 0.032494940262820037, 0.23251017502376012, 0.03128474930833493, 1.218491147671427, 0.43675163122160093, 0.27977545878716875, 2.3882230945995877, 1.6448535663740975, 12.009860515594482, 60.22277477809361, 50.543555464063374, 55.3288562638419, 62.947246823992046, 68.13699531555176, 56.82510566711426, 42.96301521573748, 42.7274295943124, 43.58228383745466, 50.17904601778303, 51.2019806589399, 55.51103455679757, 62.07872200012207, 54.65154586519514, 56.28795085634504, 56.088881492614746, 59.65381458827427, 67.0298832484654, 56.32110071182251, 65.09776292528424, 62.4347824369158, 67.6735018321446, 62.72328553880964, 66.1086424418858, 61.95340429033552, 63.755190304347444, 66.43354020799909, 65.20527935028076, 62.115262576511924, 63.32340839930943, 62.447886739458355, 59.44475718906948, 58.524739265441895, 62.85004847390311, 59.913343702043804, 63.483453205653596, 53.248485701424734, 62.443856784275596, 67.1818403516497, 61.019559451511924, 65.08123316083635, 62.80554526192801, 60.333848680768696, 53.254770347050254, 44.795015471322195, 46.736213615962434, 46.46791240147182, 46.72689955575125, 46.085837909153526, 42.53926542827061, 44.00032567977905, 49.24702855518886, 44.79400103432791, 45.09807504926409, 43.142355169568745, 51.743954045431956, 57.66802290507725, 58.0608149937221, 59.60914461953299, 57.32087005887713, 56.05474846703665, 53.89344528743199, 44.05672768184117, 42.851962157658164, 43.83585139683315, 47.25948940004621, 46.86323710850307, 45.033515862056184, 43.107228551592144, 47.79190901347569, 48.13686622892107, 52.36565453665597, 52.83138186591012, 51.04686907359532, 51.97214330945696, 46.59335517883301, 53.13079016549246, 58.61976282937186, 57.82114383152553, 61.68098626817976, 56.11631645475115, 51.5439327784947, 52.51752131325858, 58.20450374058315, 53.89277826036726, 51.614939893995015, 50.96098586491176, 52.40337978090559, 52.250241483960835, 53.85782882145473, 52.95474018369402, 54.886905670166016, 51.19440712247576, 56.70706966945103, 57.016406944819856, 60.09169701167515, 54.07284777505057, 58.2807081086295, 51.93292767660958, 53.68694135120937, 60.64150101797921, 55.647438117435996, 52.04792731148856, 53.259248461042134, 53.58558103016445, 51.60087326594761, 52.96579129355294, 48.88862657546997, 44.78750794274466, 36.11422102791922, 38.21901103428432, 52.21289839063372, 39.99498449053083, 37.028735978262766, 35.772400924137656, 36.27911915097918, 40.2837689944676, 32.8944535936628, 21.81655842917306, 3.146908623831613, 0.25299902845706257, 0.08266615880919354, 0.09175265873117106, 0.14700569744621003, 0.1286119565899883, 0.02427149617246219, 0.06754734007907764, 0.21447951825601713, 0.6405060078416551, 12.92612554345812, 47.03912033353533, 24.27225157192775, 42.92892387935093, 5.561306016785758, 0.3241112897438662, 0.24015213495918683, 0.0585678858416421, 0.16497909942907946, 0.09126063941844872, 0.0341225456047271, 0.04553217640412705, 0.062346423443939, 0.08039158729038068, 0.21065243147313595, 0.01467868868660714, 0.07395018650484936, 0.015040522574314048, 0.08758785149880818, 0.01945888307610793, 0.018504474378590072, 0.03254581003316811, 0.029493840943489755, 0.04328378276633365, 0.012506476719863713, 0.101797026182924, 0.040459506280188046, 0.013332545607616859, 0.11090524601084845, 27.859000274113246, 60.1071081161499, 48.28391442980085, 29.06232057298933, 40.55575622831072, 55.351225989205496, 1.3796127076659883, 0.018949920743969933, 0.09427114323313747, 0.01590552580143724, 0.28846342116594315, 0.17334599260772976, 1.160156135048185, 0.4791802359478814, 0.7798386684485844, 3.978027820587158, 1.4551058624471938, 15.217432124274117, 68.49149935586112, 58.06037378311157, 66.11904389517647, 68.06209373474121, 70.70445196969169, 61.8535795211792, 51.030308042253765, 55.501043047223774, 52.234069551740376, 58.09334993362427, 59.53124836512974, 62.73164422171456, 63.36641080038888, 62.03368377685547, 59.706982203892295, 60.83132580348423, 61.64528642381941, 68.31418827601841, 62.9944737298148, 67.57905496869768, 66.0201779774257, 69.92022963932583, 64.16171550750732, 68.67750263214111, 64.11997767857143, 65.9197278703962, 68.86429105486188, 68.42588751656669, 64.29118824005127, 64.15446853637695, 65.05753980364118, 62.649259431021555, 64.58254705156598, 67.48960386003766, 66.38312407902309, 67.58905342647007, 56.92182459150042, 68.28149700164795, 68.54648045131138, 64.40534019470215, 68.40971211024693, 65.07421548025948, 60.80984892163958, 53.89977857044765, 48.02917609895979, 50.47861065183367, 51.23666606630598, 51.56370735168457, 50.14339828491211, 47.059860706329346, 46.71604994365147, 51.67590686253139, 48.55715233939034, 47.486886569431846, 45.60991062436785, 52.23106098175049, 59.506589208330425, 61.13672692435128, 61.35336480821882, 59.543275696890696, 56.718051297324045, 57.96124035971505, 47.67810099465506, 42.835036345890586, 45.86876228877476, 48.327288559504915, 49.126317501068115, 46.618031706128804, 47.087403365543906, 46.724321774074006, 48.43380444390433, 51.72320672443935, 53.224597794669016, 51.20808465140206, 54.96497562953404, 51.12522390910557, 53.79416595186506, 61.276191166469026, 60.42860126495361, 62.34446280343192, 60.04830551147461, 53.56868995938982, 55.00383343015398, 60.66998863220215, 57.94554090499878, 55.490992477961946, 56.05691977909633, 56.1409512928554, 55.93411036900112, 57.636922768184114, 55.396225997379844, 57.260267870766775, 55.848122937338694, 59.535479818071636, 59.53190844399588, 61.74048369271414, 56.87738391331264, 59.720857756478445, 55.314254624503, 54.960952622549875, 62.23269408089774, 58.45935671670096, 54.464139052799766, 55.47609554018293, 55.343311991010395, 51.060400690351216, 54.81867783410208, 51.66854524612427, 50.04749577386038, 41.327089650290354, 42.018859250204905, 62.19741807665144, 54.98612594604492, 51.08702618735177, 48.810296058654785, 46.73804794039045, 43.41532557351248, 46.24299921308245, 31.31595836366926, 4.465089159352439, 0.3766773704971586, 0.10000045544334821, 0.06404769394014563, 0.11457916029861995, 0.07853851493980203, 0.04242715605401567, 0.08379849126296383, 0.37217713626367704, 0.6307155074817794, 16.121257271085465, 50.462716647556846, 23.751643896102905, 55.2069535936628, 7.962402820587158, 0.2222772834024259, 0.1815990547516516, 0.0916154318089996, 0.10821581139628376, 0.10884169888283525, 0.07344516646116972, 0.00692927000844585, 0.12130285879330975, 0.05208114195348961, 0.1197980988238539, 0.056415318311857324, 0.03597830495397959, 0.10591179145766155, 0.11398898411009993, 0.09396822484476225, 0.13330503047576972, 0.21244677661785058, 0.10219475626945496, 0.23942664531724794, 0.1608037884746279, 0.2262926772236824, 0.12104544974863529, 0.2799527464168412, 0.27594757133296555, 33.078959533146445, 70.73540619441441, 47.557108538491384, 42.51019763946533, 53.86120217187064, 65.67062800271171, 2.3184149776186262, 0.15452557536108152, 0.2545614503324032, 0.1143270166856902, 0.40913957144532886, 0.6505717220050948, 2.2357702808720723, 1.3648017538445336, 1.1667105661971229, 5.889290085860661, 3.8040553501674106, 23.301341567720684, 83.78875064849854, 66.51818316323417, 75.87724685668945, 72.01007407052177, 79.3592254093715, 71.30500561850411, 63.89699608939034, 66.16459628513881, 60.0225624356951, 66.60502174922398, 64.04039996010917, 70.45966693333217, 73.11480290549142, 72.08808149610246, 69.50079468318394, 66.78215217590332, 68.46829932076591, 72.94677461896623, 64.5241265978132, 73.2043512889317, 68.77592386518205, 73.08156272343227, 68.16540649959019, 72.21599783216203, 66.07817459106445, 68.53377914428711, 72.93788092476981, 71.67122432163784, 68.56865215301514, 68.76613385336739, 70.00928470066616, 66.43295655931745, 66.93609646388462, 69.19874259403774, 65.00083555494035, 71.59457874298096, 59.422404834202354, 68.8762697492327, 71.48990413120815, 67.17692102704729, 68.80890696389335, 68.78453268323625, 64.47358540126255, 57.378793716430664, 50.60159724099295, 52.33392211369106, 53.995754037584575, 54.08228690283639, 51.16844170434134, 48.69042573656355, 49.494082178388325, 56.80894415719168, 50.91669804709298, 51.368188517434255, 47.56532825742449, 57.12853349958147, 64.68340710231236, 62.48319053649902, 62.64329092843192, 61.210051264081685, 58.82342842647007, 59.90893159593855, 48.95642709732056, 44.85293912887573, 47.61212090083531, 51.629687445504324, 52.348951067243306, 49.16450827462332, 49.52895171301705, 51.572312695639475, 52.103450366428916, 55.90505300249372, 55.573682989392964, 54.37984698159354, 57.18551220212664, 52.82154321670532, 59.82553236825125, 63.3289669581822, 63.623202323913574, 67.20763901301792, 60.90969453539167, 54.14829478945051, 57.94412694658552, 63.635215759277344, 59.914913994925364, 55.513459478105815, 56.66795825958252, 58.415388516017366, 59.35304791586739, 59.51364162990025, 57.489002568381174, 61.994141578674316, 57.105427265167236, 62.85548196520124, 62.09480707986014, 64.40438829149518, 57.914916719709126, 60.7950770514352, 56.57829523086548, 59.0878073828561, 65.93292944771903, 63.140497071402415, 57.97761378969465, 59.58309582301548, 61.18441241128104, 56.159985882895334, 63.704204423086985, 60.048437527247835, 57.682322297777446, 49.635134083884104, 50.96604067938668, 64.17526449475969, 55.41329424721854, 48.607269695826936, 49.49920300074986, 49.11444302967617, 46.356668267931255, 48.51499761853899, 33.816392694200786, 6.077640984739576, 0.4492078513971397, 0.24570371849196299, 0.2009243020521743, 0.47392837490354267, 0.1907971397574459, 0.22123259731701442, 0.12880756466516427, 0.6108335086277553, 1.8854015043803622, 21.49058542932783, 63.11558083125523, 36.24658421107701, 60.26815346309117, 8.825504575456891, 0.3567730342703206, 0.32143379056027954, 0.22361964280051844, 0.1484087450163705, 0.25234155516539303, 0.11608539947441646, 0.10359221949641194, 0.2746570791516985, 0.29452900854604586, 0.2288179402904851, 0.20107030921748706, 0.15873444665755543], [0.03126422701669591, 0.05306962159063135, 0.04260804331196206, 0.11211487717394318, 0.13030107452401093, 0.06358351491923843, 0.068955259530672, 0.04809147818014026, 0.15694551622228964, 0.003832038816264165, 0.07227552815207414, 0.40699420656476704, 54.44055339268276, 34.04472092219761, 26.90315396445138, 41.508361203329905, 45.82926525388445, 35.503311089106965, 0.1937874300139291, 0.04965984062956912, 0.0720015357115439, 0.1078427324869803, 0.31164000609091347, 0.030793293179678063, 1.3976375290325709, 0.23536900590573037, 0.36614346717085156, 1.5495756332363402, 1.975039997271129, 32.32109866823469, 59.88867064884731, 59.78020232064383, 66.7139972959246, 69.82794366564069, 53.6629387991769, 44.75197485515049, 50.518694809504915, 57.48834943771362, 68.31867681230817, 62.09457084110805, 66.50637122562954, 59.06300926208496, 59.56568363734654, 53.353584153311594, 49.11723273141043, 58.08816657747541, 53.80936861038208, 56.6804198537554, 65.9576163973127, 65.95028604779924, 63.063629150390625, 63.50545815059117, 64.8291803087507, 64.89279801504952, 64.97592626299176, 65.92899676731655, 64.26690428597587, 65.21315165928432, 60.30281802586147, 62.58039583478655, 55.839941433497835, 62.13419641767229, 62.89738655090332, 63.10364382607596, 65.25436837332589, 55.143860476357595, 56.185332911355154, 66.22958278656006, 62.364494459969656, 63.10932745252337, 59.870709555489675, 62.46123422895159, 51.06104687282017, 47.79652956553868, 48.88171311787197, 49.905613558632986, 44.979486669812886, 44.99363667624337, 47.34775236674717, 43.479770115443635, 44.53173780441284, 48.9347174508231, 43.75826781136649, 41.98759583064488, 42.45483091899327, 46.45328644343785, 55.251991816929404, 59.46398980276925, 61.33812740870884, 57.80635459082467, 56.49041788918631, 55.03080981118338, 40.394485064915244, 44.10278034210205, 43.580529417310444, 47.75743900026594, 47.58794116973877, 43.82332032067435, 44.464100565229145, 45.26360893249512, 45.16259254728045, 47.17090681621006, 49.69232470648629, 53.45659119742257, 53.353514671325684, 53.03819152287075, 45.905820505959646, 55.13988610676357, 59.70488384791783, 57.51776116234915, 61.442746434892925, 59.42369719914028, 51.42422226497105, 52.07375029155186, 56.86456101281302, 55.67662402561733, 55.49192006247384, 51.815763677869526, 53.00316217967442, 52.64226232256208, 52.13784394945417, 54.19636590140206, 52.75593137741089, 53.30402612686157, 53.22108200618199, 54.63809415272304, 56.60476091929844, 56.6181639943804, 53.09255770274571, 50.02994115012032, 54.940424169812886, 54.719902242933, 51.50810439246041, 53.38245391845703, 50.959321771349224, 49.866783550807405, 51.437948431287495, 52.1045377595084, 50.17616946356637, 42.50062649590628, 46.40078585488455, 41.97865349905831, 47.518994195120676, 37.918032441820415, 37.02857616969517, 34.66501440320696, 38.56691428593227, 36.40746627535139, 27.04608362061637, 6.504191764763423, 0.31931171300155775, 0.09720164776912757, 0.07389712506639105, 0.2407394748713289, 0.03856995588700686, 0.1302793071206127, 0.12375456866409097, 0.19130118271069868, 0.22007545083761215, 1.5100761013371604, 43.14175067629133, 23.640648160661968, 31.34161458696638, 22.34972323690142, 0.27245200318949564, 0.4755116956574576, 0.018368959061003158, 0.30192164757422035, 0.07514031657150813, 0.12679382200751985, 0.06702571628349167, 0.11577579751610756, 0.053475310892931054, 0.09570885715740067, 0.08649705217352935, 0.152782391756773, 0.011622990198832537, 0.03656704264826008, 0.03981863334774971, 0.017312330759263465, 0.07611334257360015, 0.05254667465175901, 0.014403334087026971, 0.05370031310511487, 0.132038164883852, 0.05285832239314914, 0.06302192541105406, 1.7836016012089593, 60.83482769557408, 46.75466455732073, 34.215962750571116, 28.198395456586564, 50.91932794025966, 40.15964984893799, 0.6062772274017334, 0.15692279886986527, 0.07264893275818654, 0.01963065082340368, 0.24429304418819292, 0.06857019090758902, 1.505295523575374, 0.055806275457143784, 0.06750125398061105, 1.5288444885185786, 2.9442954616887227, 35.974381583077566, 71.19666930607387, 65.63920824868339, 70.46109131404332, 73.54296479906354, 60.38309751238142, 54.293004921504426, 59.79258401053292, 62.48795700073242, 71.2878088269915, 65.7776927947998, 69.96971470969063, 65.55102866036552, 64.44259643554688, 59.0921083177839, 53.84919915880476, 61.58576120649065, 59.507867676871165, 60.65700939723423, 67.90158339909145, 67.71979767935616, 66.79111535208565, 65.84012235913957, 66.79522868565151, 68.00992665972028, 66.10327843257359, 67.66698442186627, 68.23655605316162, 67.29395648411342, 63.762583187648225, 65.2582871573312, 58.98046466282436, 66.12876442500523, 65.68190492902482, 67.09018666403634, 65.21396459851945, 58.62407071249825, 63.46511690957205, 69.31839752197266, 65.71662507738385, 66.208877154759, 62.45621762956892, 63.136508805411204, 53.018430846078054, 51.53691509791783, 52.58657945905413, 52.58131272452218, 48.84018720899309, 48.82331003461565, 50.56156519481114, 47.813316413334434, 49.20838267462594, 51.16185828617641, 47.528391633714946, 44.32519217899868, 43.831008502415244, 48.544576099940706, 56.837296281542095, 60.895367349897114, 63.19628415788923, 59.63650662558419, 59.71251991816929, 57.1714004107884, 43.88441930498396, 44.46646990094866, 44.9432761328561, 50.174161434173584, 48.841646330697195, 45.86186620167324, 47.42764275414603, 47.91514573778425, 47.18493522916521, 48.39179563522339, 51.86117015566145, 55.673490388052805, 56.87171418326241, 55.70121717453003, 50.723993233272004, 54.62462159565517, 60.94741630554199, 60.6634156363351, 61.516390391758506, 61.74265153067452, 55.76207297188895, 53.486954825265066, 59.63062844957624, 58.64972346169608, 58.33893748692104, 56.25780609675816, 54.90663160596575, 55.02617883682251, 55.57141440255301, 57.857024329049246, 56.75941392353603, 55.93601417541504, 56.4874301637922, 57.10542031696865, 58.24229499271938, 58.10009316035679, 55.92810712541853, 52.37766797201974, 56.436329637254985, 56.49618836811611, 55.65530695234026, 56.77706234795706, 53.432321139744346, 53.145058291299, 54.10820715767996, 53.819714478084016, 53.96118674959455, 46.675510678972515, 47.78914015633719, 52.33075373513358, 59.485015051705496, 53.402985845293315, 52.01820639201573, 47.01149429593767, 41.27095167977469, 43.49656738553728, 36.961084842681885, 9.365931987762451, 0.4878946883337838, 0.04645690767626677, 0.38209245992558344, 0.12614226554121288, 0.0706315938649433, 0.17737822766814912, 0.135138404954757, 0.08530401797699076, 0.262671626572098, 1.5971800216606684, 48.12095832824707, 25.505575929369243, 40.9984016418457, 30.393803868974956, 0.32215757029397146, 0.34787377608673914, 0.07008147838392428, 0.3066377102264336, 0.040171742971454344, 0.2149157077074051, 0.03745295832465802, 0.09835294527666909, 0.023669828993401358, 0.09648841925497566, 0.07262558436819486, 0.1415478874530111, 0.16686017491987773, 0.16698661313525268, 0.18484032154083252, 0.20563938761396067, 0.23629436482276234, 0.18667293606059893, 0.17353286115186556, 0.12038655153342656, 0.24053352592246874, 0.1642964660589184, 0.18429514579474926, 2.469840326479503, 76.98162133353097, 48.93055200576782, 36.18017332894461, 60.14468397412981, 59.83780983516148, 51.39931297302246, 1.0080240241118839, 0.24999368829386576, 0.17891819003437245, 0.25102381301777704, 0.5179996586271695, 0.22073276128087724, 2.448211887053081, 1.007836748446737, 1.0247213052851813, 2.891658080475671, 4.118396631308964, 46.9307735988072, 81.95872715541294, 72.65338693346295, 78.33048902239118, 79.37508119855607, 72.05481352124895, 61.93970939091274, 63.51790932246617, 67.87843200138637, 77.96057387760708, 72.05161040169853, 73.17329978942871, 72.94746943882534, 71.78943402426583, 69.78685201917375, 63.27798802512032, 67.73254067557198, 62.9506653376988, 68.6162473133632, 69.25099304744175, 71.19354956490653, 67.54046467372349, 71.6031528200422, 70.65878146035331, 71.04579612186977, 70.47041579655239, 71.71303163255963, 71.12472765786308, 72.90272998809814, 65.57440934862409, 71.21594360896519, 62.59141567775181, 68.9026242664882, 67.31799030303955, 70.87601688929966, 69.7687658582415, 63.58180495670864, 62.5848913192749, 72.16210760389055, 66.95842797415597, 67.89719213758195, 64.32031508854458, 67.95477880750383, 56.966310432979036, 54.070110184805735, 53.78618941988264, 55.1836701801845, 49.88989325932094, 51.678627082279746, 52.860202993665425, 48.2227702822004, 51.32339000701904, 54.93364272798811, 50.73570442199707, 48.13951696668352, 45.966832637786865, 52.088504791259766, 59.7331908089774, 63.56778349195208, 66.08158615657261, 62.14782878330776, 60.36801297324044, 60.092412676130024, 45.94911820547921, 48.50579125540597, 48.08882638386318, 55.02571330751692, 51.31674058096749, 47.74107599258423, 50.95536824635097, 50.11304160526821, 50.5460707119533, 52.68125908715384, 56.021796635219026, 57.98951605388096, 61.29354081835066, 60.317159107753206, 53.30644062587193, 59.85779980250767, 64.0235366821289, 61.194459506443565, 67.07336507524762, 64.55658163343156, 57.31008298056466, 57.17057010105678, 62.759082657950266, 60.7524220602853, 59.633845465523855, 58.31108215876988, 59.22520106179373, 59.889907428196494, 57.96109444754464, 58.86306095123291, 60.99712371826172, 57.268689087459016, 59.87339850834438, 59.488933835710796, 60.54119682312012, 60.185984066554475, 60.60805933816092, 54.56486708777291, 61.56877286093575, 61.812293325151714, 59.8147348676409, 62.28650093078613, 60.21759837014334, 59.268293789454866, 59.9491616657802, 60.64646897997175, 62.32120023454939, 54.855569294520784, 57.170879295894075, 57.41957269396101, 58.83802659170968, 52.597998823438374, 49.25005102157593, 51.46173211506435, 45.115254470280235, 44.242053508758545, 38.51343052727835, 9.642190626689366, 0.5169364213943481, 0.3966108565883977, 0.6729730399591582, 0.28556542524269646, 0.22218831389078073, 0.704279071518353, 0.27549886969583376, 0.45795560628175735, 0.5189437451107162, 3.944502762385777, 60.71937642778669, 34.59113073348999, 45.78372328622, 32.38575165612357, 0.4066931541476931, 0.49869924570832935, 0.1483603518988405, 0.5085307295833315, 0.16534978310976708, 0.21136239623384817, 0.15433078152792795, 0.2225081752985716, 0.2526677133781569, 0.15552044340542384, 0.18148628223155225, 0.2862590508801596], [0.06365494430065155, 0.08600128734750406, 0.10991288176072495, 0.04046890399019633, 0.08450238992060934, 0.2204383856483868, 0.24362791702151299, 0.16998586005398206, 0.036752431986055205, 0.17131603296313966, 0.4319286314504487, 23.361889907291957, 54.98056738717215, 21.988727842058452, 32.672041756766184, 27.935835191181727, 49.503854819706504, 16.556132861546107, 0.45227067704711643, 0.03709625925070473, 0.09877149281757218, 0.03968000525076475, 0.0685628695147378, 0.14956112817994185, 0.17662495880254678, 0.05013179226911493, 0.335745776870421, 0.5291140622326306, 1.848958202770778, 35.060050759996685, 61.673975535801475, 70.49809047154018, 59.82021699632917, 47.42685413360596, 47.31508193697248, 60.343013354710166, 65.13505390712193, 60.46403012956892, 61.066751616341726, 60.88109574999128, 64.22294998168945, 59.17324243273054, 55.43543120792934, 50.17765985216413, 49.3447619165693, 50.83305215835571, 60.014815194266184, 57.43646376473563, 60.50781767708914, 61.95762879507882, 64.70248685564313, 59.81649971008301, 66.48646463666643, 66.27484335218156, 63.76737744467599, 63.11674812861851, 64.45136506216866, 61.33882917676653, 61.9592616217477, 55.634952204568044, 62.267052922930034, 63.60943794250488, 66.25281061444963, 63.26439734867641, 55.855283055986675, 57.830207756587434, 65.9397942679269, 61.83497224535261, 65.39705657958984, 63.89325795854841, 62.21348231179373, 52.69010066986084, 48.95712191717965, 54.89442362104143, 51.867076124463765, 46.93065547943115, 44.035896982465474, 43.21337618146624, 46.3317346572876, 44.61442484174456, 45.07669196810041, 43.67228732790266, 45.686010769435335, 41.08513600485665, 43.072473662240164, 44.3848111970084, 54.291941847120015, 59.60972826821463, 61.982503346034456, 58.846753529139924, 57.70512975965227, 49.72955662863595, 41.93136405944824, 40.26204892567226, 43.48493957519531, 47.69935206004551, 46.608710697719026, 43.9977513722011, 41.651789392743794, 44.524056570870535, 43.81677164350237, 45.6555255481175, 47.43994801385062, 51.01389292308262, 52.88426807948521, 53.90416635785784, 53.61700078419277, 50.08542946406773, 51.8529052734375, 60.19373825618199, 59.468429701668875, 56.541872773851665, 58.10491173607962, 51.62460831233433, 50.504082747868125, 57.230908257620676, 54.8745448248727, 53.11499343599592, 53.16216475622994, 51.68962608064924, 53.13839149475098, 54.45966441290719, 52.34683186667306, 54.1743609564645, 52.11677006312779, 55.385174887520925, 53.945879868098665, 55.622560092381065, 53.995618547712056, 53.25793525150844, 51.319346155439106, 51.6363959312439, 54.54388700212751, 51.58953033174787, 51.87851633344378, 48.745948791503906, 52.874780314309255, 54.54691641671317, 55.10695511954171, 47.667147159576416, 47.561405999319895, 38.265550068446565, 49.892662116459434, 43.899931158338276, 36.27083689825875, 35.16709818158831, 32.873831340244834, 36.287477833884104, 28.579394715172903, 10.16575562953949, 0.7592550643852779, 0.20007986522146634, 0.09820040381912674, 0.01063607119223369, 0.01411656228758927, 0.0536643032516752, 0.03968410699495247, 0.18173282114522799, 0.05110237554513982, 0.5130608464990343, 24.189295291900635, 42.79325335366385, 19.80009044919695, 48.44534887586321, 0.789754290665899, 0.05032162261860711, 0.1993610252227102, 0.047325771767646074, 0.06858195670481239, 0.05023404071107507, 0.014481077236788613, 0.040882186099354706, 0.023093050478824546, 0.07982547873897211, 0.15495599726481096, 0.11829864499824387, 0.0745734412755285, 0.1632041603858982, 0.11153684676225696, 0.025603607995435596, 0.10183958389929362, 0.25659919955900734, 0.18909392186573573, 0.07961396580295903, 0.136670604880367, 0.0894273260076131, 0.28166998284203665, 32.84798404148647, 62.06536756243025, 31.392343384878977, 29.124218600136892, 29.547794682638987, 53.21213272639683, 22.422979831695557, 0.8441999948450497, 0.08496976484145437, 0.11369256608720336, 0.13066232656793936, 0.09531428904405662, 0.1370124372520617, 0.18536883246685776, 0.0815403742183532, 0.642284420984132, 1.2592806560652596, 2.789502190692084, 44.10268654142107, 68.69934776851109, 73.65142617906842, 68.62714903695243, 55.891385895865305, 55.71466541290283, 64.72898033687046, 65.93308925628662, 64.89841910770961, 66.22998578207833, 66.85470526559013, 70.11051995413644, 63.64328261784145, 59.736352239336284, 57.82933228356497, 55.08335903712681, 53.93689932141985, 62.14960057394845, 63.02970109667097, 63.69526209150042, 64.12942028045654, 65.71568012237549, 64.95539433615548, 69.35104710715157, 67.22621849605015, 67.16016892024449, 67.3506885256086, 68.3719972882952, 63.121486800057546, 66.08130128043038, 60.71656935555594, 67.50905186789376, 66.77972725459507, 69.88486330849784, 67.09505040305001, 58.985543795994346, 63.190378189086914, 67.65995979309082, 64.75683566502163, 67.77199949537004, 66.49072388240269, 64.86986201150077, 52.141651562282014, 51.86348737989153, 57.713200092315674, 53.795951638902935, 50.00125898633684, 47.133143356868196, 44.91289513451712, 48.49351378849575, 50.01084055219378, 49.49716370446341, 48.78419515064785, 49.259351185389924, 44.44774797984532, 44.897959981645855, 46.507402488163535, 56.0611686025347, 61.75276810782296, 63.16004235403878, 61.7945476259504, 59.63968195234026, 52.02264281681606, 44.39201647894723, 44.156104292188374, 44.73957926886422, 48.78780126571655, 47.30539614813668, 46.519725118364605, 45.453520570482524, 45.161862986428396, 45.87996278490339, 47.60598911557879, 48.94643906184605, 50.3858174596514, 54.750919001443044, 56.65212678909302, 57.87250491550991, 53.81865835189819, 52.818072591509136, 60.52495193481445, 62.63482107434954, 60.01160512651716, 60.10177189963204, 56.175445624760215, 52.034326212746755, 59.322864941188264, 56.13300950186593, 56.8156943321228, 55.8075350352696, 54.793219634464805, 56.28069346291678, 57.17633710588728, 54.78318296160017, 54.77535234178816, 56.39426524298531, 59.40187290736607, 56.93825013296944, 57.95889186859131, 57.34800624847412, 56.512999534606934, 54.476760455540244, 53.85683870315552, 56.958618777138845, 54.54260505948748, 55.739380155290874, 54.67158446993147, 55.94878149032593, 58.22093970435006, 58.33278833116804, 50.47088425500052, 48.61412756783621, 42.879327637808665, 57.65942450932094, 56.350373472486226, 50.389055320194785, 48.90641048976353, 37.09319789069039, 42.909930978502544, 38.81649010522025, 12.770535400935582, 1.1145048418215342, 0.19824240596166678, 0.026549770796139325, 0.02384137112780341, 0.05909188450979335, 0.10443588958254882, 0.07596897746303252, 0.19511362670787744, 0.13823489951235907, 0.1266264817012208, 28.663862228393555, 42.79330546515328, 23.710203102656774, 61.60469504765102, 1.2839479552847999, 0.08760019405079739, 0.18700932658144406, 0.02410169787305806, 0.009980578374649798, 0.03900642353775246, 0.04620342056400009, 0.03704363886000855, 0.018951398253973042, 0.14069039560854435, 0.21697227949542658, 0.108664709808571, 0.07694377444152321, 0.3120917204235281, 0.15260894463530608, 0.10597513948700257, 0.22312162523823126, 0.5049135951059205, 0.39861093355076654, 0.3921409664409501, 0.28988842612930704, 0.2751387847321374, 0.40206587101731983, 42.137899262564524, 75.43932274409703, 34.04616962160383, 44.09042991910662, 43.266137327466694, 60.813524518694194, 32.553137234279085, 2.0201079675129483, 0.12786270465169633, 0.29763542328562054, 0.19919307423489435, 0.45700972846576143, 0.3762768991291523, 0.35387769820434706, 0.3489754726844174, 1.2679857718093055, 2.1420056436743056, 4.690249877316611, 50.7579699243818, 76.69228444780622, 79.10314260210309, 74.44430596487862, 64.4564094543457, 63.680191448756624, 69.28328132629395, 70.02384117671421, 69.39004039764404, 70.89940452575684, 72.76692744663784, 74.74480165754045, 67.41074875422886, 67.76931054251534, 68.0203698022025, 62.26521165030343, 64.38876179286412, 66.37628010341099, 66.54817158835274, 67.39045306614467, 67.45601626804897, 70.45160702296666, 69.7432381766183, 73.35343878609794, 70.73637199401855, 70.23356560298375, 70.25254113333565, 71.55152075631278, 66.0961912700108, 70.89722973959786, 63.84615612030029, 69.81568704332624, 70.79421574728829, 72.11401912144252, 68.76969827924455, 63.111710684640066, 65.37345354897636, 69.2020707811628, 67.60704926082066, 68.43707411629813, 67.37862723214286, 68.95463848114014, 56.805998120989116, 52.75844662530081, 60.27326733725411, 57.39533390317644, 50.842915126255576, 48.66439083644322, 48.88289431163243, 53.28928899765015, 49.76972416469029, 53.344975335257395, 51.88986621584211, 52.99260786601475, 46.978129046303884, 47.58651678902762, 48.56906502587454, 59.19505282810756, 64.42099448612758, 64.76216493334088, 64.07227829524449, 63.623494148254395, 55.53002398354666, 45.97509752001081, 44.755813734872, 47.96138252530779, 53.66184793199812, 50.67171846117292, 48.83671658379691, 47.19046252114432, 49.693137645721436, 47.3941524369376, 51.48393508366176, 53.02776575088501, 55.49526909419468, 58.28071853092739, 58.807635171072825, 59.507103375026155, 56.20840787887573, 57.587941442217144, 65.97124181474958, 64.51607363564628, 62.92782660893032, 63.98220879690987, 57.78112915584019, 54.53796713692801, 60.708127294267925, 58.74982615879604, 56.809666769845144, 58.98498099190848, 58.55950110299246, 58.90861334119524, 59.0476051058088, 56.992661476135254, 58.937858309064595, 57.12848138809204, 60.33570384979248, 59.4343626839774, 60.01735128675188, 57.99800327845982, 61.391982895987375, 57.45454297746931, 59.12887123652867, 64.04412419455392, 61.61425576891218, 63.2098331451416, 60.17736830030169, 61.73714855739048, 64.86993149348667, 65.67130892617362, 55.729048183986116, 58.331308364868164, 51.08403846195766, 59.19824205126081, 56.85728972298758, 48.6827757699149, 48.657769203186035, 39.52964278629848, 43.85367005211966, 38.891874585832866, 13.396945033754621, 1.417355756674494, 0.42583576696259634, 0.22423466694142136, 0.25369591106261524, 0.21197983595941747, 0.26199311869485037, 0.18603849224746227, 0.35341211461595123, 0.20661084620015963, 0.7615615949034691, 36.65915782111031, 58.07806389672415, 29.582084042685374, 64.00582572392055, 1.0005836976425988, 0.17965726394738468, 0.3463805105004992, 0.07628146998052086, 0.191625536020313, 0.10621704400650092, 0.08592594960438353, 0.13412035815417767, 0.05873372658554997, 0.19172103303883756, 0.2757496019559247, 0.18358788160341127], [0.24565005994268826, 0.09945378013487373, 0.04784390110788601, 0.1800117034997259, 0.1536310219338962, 0.588819335613932, 1.536503683243479, 3.6226476558617184, 1.9895378478935786, 1.6887982083218438, 14.211154052189418, 57.88355949946812, 38.83321441922869, 29.007111924035208, 30.194887365613663, 39.6351511819022, 43.51739808491298, 4.689023520265307, 0.47353835297482355, 0.14572114923170634, 0.08471659664064646, 0.010989040868090732, 0.06992900477988379, 0.043076364789158106, 0.05685940930353744, 0.3705777478005205, 0.38531981674688204, 1.2131594909088952, 0.8341664161000932, 41.55304159436907, 65.07471575055803, 56.37073516845703, 43.77937296458653, 58.141626017434255, 70.82093851906913, 67.98682389940534, 63.49829455784389, 57.77544205529349, 64.51721314021519, 59.34639848981585, 67.22088922773088, 60.4591247013637, 52.716198103768484, 47.03476728711809, 48.657383578164236, 47.09007494790213, 55.82280370167324, 61.841253416878835, 58.44933046613421, 61.671439443315776, 58.384038243974956, 62.52315657479422, 62.82912049974714, 64.37275314331055, 63.55103833334786, 64.94412435804094, 63.329543658665244, 61.81922762734549, 58.51651954650879, 62.846101897103445, 63.64732646942139, 61.0161200932094, 65.04519980294364, 57.34741217749459, 58.719858578273225, 66.09586470467704, 63.23401982443673, 62.65936211177281, 63.31435489654541, 64.34095818655831, 50.657519817352295, 49.67232779094151, 55.089991092681885, 51.52815689359392, 51.05977187837873, 47.134935992104666, 46.57943098885672, 45.42867728642055, 42.4038519859314, 47.21182475771223, 44.1064316204616, 45.152170249394004, 42.774288245609824, 41.47862638745989, 42.872810227530344, 43.29252658571516, 45.50040354047503, 50.15964664731707, 55.002464635031565, 52.043206010546, 47.992962087903706, 45.42722858701433, 42.00257614680699, 42.57026481628418, 43.176158155713765, 44.546850136348176, 46.18781661987305, 44.270805154527935, 42.96725014277867, 43.374897480010986, 43.36517347608294, 45.58745057242257, 46.75910793031965, 48.87343781335013, 48.87305218832833, 53.486808913094656, 55.999458176749094, 55.60994216373989, 48.42450080599104, 50.108466216496055, 58.092728069850374, 60.07702241625105, 56.771430832999094, 58.707150323050364, 51.335518087659565, 52.66903025763375, 56.25263663700649, 56.49622310910906, 55.59688302448818, 53.72030312674386, 51.509834493909565, 54.97675282614571, 53.44536290849958, 52.91157797404698, 53.9061917577471, 54.67090702056885, 54.96083450317383, 55.29835714612688, 52.18017932346889, 53.29182161603655, 49.9876127243042, 50.03883831841605, 53.07998146329607, 49.972489970070974, 51.2464143889291, 53.92517076219831, 53.90997852597918, 55.90462916237967, 59.658754757472444, 47.138580322265625, 42.5282803262983, 39.68919079644339, 40.5449344090053, 51.64189543042864, 38.45975916726248, 34.98662567138672, 28.614050592694962, 36.501051562173025, 34.79733937127249, 10.024375421660286, 0.7282639816403389, 0.09831913387668983, 0.0590718270146421, 0.16229168006352016, 0.046427601748811345, 0.06531422704990421, 0.047121746465563774, 0.14022836754364626, 0.11973186023533344, 0.20970454519348486, 8.333705868039813, 60.39962727682931, 28.064411606107438, 33.39525195530483, 27.442153521946498, 0.10306822761361088, 0.23328028512852533, 0.08963504593287196, 0.09122319107076951, 0.12420518376997539, 0.012458042890232588, 0.10009456146508455, 0.3536800816655159, 1.213629579969815, 2.0915321920599257, 1.7540035779987062, 0.0518465995389436, 0.07077897167099373, 0.04760532819532922, 0.11321206829909768, 0.13086066235389027, 0.41169436435614315, 1.5119321388857705, 4.384918672697885, 3.4810603048120226, 2.800236288990293, 20.248205832072667, 69.50893102373395, 51.89295816421509, 38.74076863697597, 32.95597989218575, 44.46265186582293, 44.91163751057216, 9.243207693099976, 1.1364914391721999, 0.1695312008793865, 0.04113791237718292, 0.1061884912529162, 0.18504042151783193, 0.048725158641380925, 0.12407075241208076, 0.5296662811722074, 0.7396766149571964, 1.1146837579352515, 1.4576662736279624, 49.04625688280378, 76.7732240131923, 67.39868668147496, 55.183013575417654, 60.65423706599644, 70.26469353267125, 68.4280206135341, 64.2771806716919, 62.898352350507466, 67.97881262642997, 65.86162008558, 70.93283230917794, 63.5522403717041, 56.34390122549874, 53.737864698682515, 54.82444483893258, 51.756634507860454, 61.169439043317524, 65.52641119275773, 63.71555083138602, 62.912061146327424, 62.526067870003835, 66.63061196463448, 66.28905241830009, 66.27917902810233, 68.34385013580322, 64.19585200718471, 63.63973903656006, 63.74105766841343, 62.078409331185476, 66.74359662192208, 66.74623693738664, 64.18321323394775, 69.1393632888794, 57.90059995651245, 62.68501486097063, 67.45306328364781, 64.99137905665806, 65.51249395098004, 68.4910477229527, 63.97883197239467, 52.03077915736607, 55.162168979644775, 58.78619303022112, 54.200899600982666, 54.953337396894185, 49.15673671449934, 49.250544343675884, 47.276950223105295, 45.99391324179513, 50.381870882851736, 49.92624276024954, 49.62508698872158, 46.82051610946655, 43.98905570166451, 46.48426498685564, 46.55750247410366, 49.08678919928414, 51.50107281548636, 54.2180095400129, 51.258504254477366, 49.22377988270351, 46.8057998248509, 44.55305140359061, 45.54466009140015, 46.2598694392613, 47.73560428619385, 48.65382957458496, 45.06387601579939, 46.01485858644758, 46.07070125852312, 46.128225394657676, 47.26883472715105, 46.84710686547415, 50.475803579602925, 52.49872991016933, 55.40846177509853, 59.81100368499756, 58.30954660688128, 53.81200892584664, 51.37231574739729, 56.5020318031311, 61.59696170261928, 61.287544522966655, 59.5716312953404, 55.654136180877686, 54.07945203781128, 57.19627843584333, 57.6090361731393, 57.61324678148542, 56.405750615256174, 54.9128155027117, 56.26488978522164, 55.51588439941406, 56.33807863507952, 56.886406149183, 57.86014059611729, 55.62796926498413, 56.968342781066895, 55.94433116912842, 56.08479595184326, 51.92732048034668, 54.57438611984253, 56.51258611679077, 53.094666481018066, 56.68000643593924, 57.28414535522461, 56.335837841033936, 57.91277667454311, 60.84372138977051, 50.13700941630772, 45.800308636256624, 43.79311997549874, 47.387304987226216, 61.459290095738, 52.114150592258994, 49.49505492619106, 35.95427349635533, 41.23944854736328, 40.59513166972569, 11.596683280808584, 0.665836751461029, 0.29115671664476395, 0.18078749972794736, 0.18982688896358013, 0.013464092343513454, 0.051431017196072, 0.07629081340772764, 0.10984409188053437, 0.07491119565176112, 0.144765758354749, 9.791587318692889, 68.49739837646484, 28.337467125483922, 40.32914073126656, 37.72360100064959, 0.16820314499948705, 0.09398385150624172, 0.046659952495247126, 0.11030400291617427, 0.06291667105896132, 0.035255895861025364, 0.08291319305343287, 0.26281626309667316, 0.8268867124404226, 1.1472226061991282, 0.7921949539865766, 0.2933432278888566, 0.1626773186560188, 0.17791006341576576, 0.2652178970830781, 0.3285015198801245, 0.9112003339188439, 4.45813661813736, 7.463163461003985, 9.644371492522103, 6.0290444152695795, 26.18379133088248, 85.70254857199532, 56.82309416362217, 41.53303773062569, 43.8241297858102, 53.91401195526123, 56.32609646660941, 15.69398648398263, 3.5235821945326666, 0.3498418261962277, 0.3896353266068867, 0.11455334882651057, 0.41371262605701176, 0.11185613141528197, 0.5285487068550927, 1.2060304220233644, 1.4582476424319404, 2.660292838300977, 1.9943533837795258, 59.2832532610212, 82.37220750536237, 75.76935522896903, 63.85938549041748, 65.57638263702393, 73.71709360395158, 71.88071945735386, 67.8715671811785, 67.69949504307338, 75.45104435511998, 71.23072937556675, 75.96024308885846, 67.9323639188494, 64.43475191933769, 64.50342791421073, 64.3967591694423, 59.581303187779014, 67.2653785433088, 70.23200920649937, 68.73330361502511, 65.79172815595354, 66.65449292319161, 69.52282047271729, 68.71842057364327, 68.57838657924107, 71.59261240277971, 69.35916260310582, 68.9993987764631, 65.61395849500383, 65.33234800611223, 69.42407962254116, 70.5585606438773, 64.92623274666923, 73.6320754459926, 63.20939540863037, 64.91153035845075, 69.86086423056466, 68.80969211033413, 68.85243742806571, 70.94861166817802, 69.63973086220878, 56.9708753994533, 54.5033929007394, 61.40988145555769, 57.95272881644112, 57.87203938620431, 51.60086979184832, 51.53161709649222, 51.849299158368794, 48.391535077776226, 52.868947301592144, 50.79349953787667, 52.890045506613596, 49.325518880571636, 45.956465925489155, 47.1976261138916, 46.80499035971505, 53.28696482522147, 55.941412925720215, 59.148604120527, 56.83011531829834, 52.31647866112845, 48.94375705718994, 46.291462898254395, 47.25445543016706, 49.75792612348284, 50.790629931858604, 50.597810472760884, 48.41709402629307, 48.268121174403596, 50.146403380802695, 49.206958293914795, 50.788677488054546, 50.978669030325754, 53.240081855228965, 53.1177727154323, 59.7042168208531, 63.26665551321847, 61.87879453386579, 56.678682804107666, 55.50122717448643, 62.942674909319194, 64.87020942143032, 62.85991491590227, 62.993973459516255, 55.964675494602744, 57.20098236628941, 59.002386229378835, 60.351983479091096, 60.170566013881135, 59.658886773245676, 57.71037564958845, 59.675374848502024, 57.51612138748169, 59.394445283072336, 58.4487954548427, 58.80724607195173, 58.972244943891255, 60.356562341962544, 57.43178415298462, 61.43575654711042, 57.385380608694895, 57.97508464540754, 63.24117646898542, 62.3719151360648, 60.9703106198992, 61.54077162061419, 60.289435795375276, 63.743906429835725, 66.77871976579938, 59.72214317321777, 51.670865944453645, 52.10201208932059, 51.787154470171245, 60.57099764687674, 51.86449834278652, 47.89260925565447, 37.497360706329346, 41.781463623046875, 40.44256312506539, 11.815436891147069, 1.5442571129117693, 1.0716479186500822, 0.4357556232384273, 0.37510444489972933, 0.23218689379947527, 0.22536988316902093, 0.22914339282682963, 0.3677360431424209, 0.17623356623309, 0.4485085260655199, 14.875724928719656, 78.73355402265275, 39.1046735899789, 46.88537059511457, 39.734017099652974, 0.23163700902036258, 0.23360220928277287, 0.1898410567747695, 0.2502253401492323, 0.3523299869682108, 0.06975333206355572, 0.2917853929102421, 0.6167032165186745, 1.5768123545816966, 2.385677231209619, 1.8592745406287057], [19.145332166126796, 7.452303426606314, 2.9408930156912123, 0.4920436314174107, 2.294929849249976, 5.179872930049896, 5.164710657937186, 5.479054978915623, 3.3744703786713734, 1.1897792369127274, 33.81804289136614, 51.98702982493809, 29.734961782182964, 24.83650609425136, 24.91906806400844, 54.98150886808123, 21.55068908418928, 0.29538659538541523, 0.4415299291057246, 0.3169886533703123, 0.07919334873024907, 0.15369344715561184, 0.054625363288713355, 0.20091554895043373, 0.2455144343631608, 0.42800444630639894, 3.638179051024573, 6.341757646628788, 1.1877288669347763, 39.97596379688808, 46.47367245810372, 44.402202538081575, 64.60174492427281, 77.25455352238247, 75.45544951302665, 74.47971398489815, 73.97366973331997, 62.544529233660015, 62.44592039925711, 63.3401118687221, 65.61138766152519, 62.431551524571006, 53.20336757387434, 46.87771020616804, 46.76538215364729, 43.8579431942531, 55.7422775541033, 60.70548003060477, 57.671979904174805, 64.98573017120361, 59.78204359327044, 62.19021279471261, 60.90539360046387, 65.81453909192766, 61.45210565839495, 61.38782787322998, 61.274509702410015, 61.331123624529155, 61.488548960004536, 64.46830477033342, 63.76754420144217, 66.33120713915143, 55.13257312774658, 57.78280367170061, 63.38056428091866, 62.39834608350481, 61.15132508959089, 62.83601311274937, 59.746260370527, 49.83964041301182, 51.85397182192121, 57.44710840497698, 54.420156955718994, 53.092547280447825, 45.2839914730617, 43.702630111149375, 46.26288843154907, 43.748661926814485, 42.969119208199636, 46.82854127883911, 44.19106067929949, 44.548503807612825, 40.60543237413679, 43.48427602222988, 44.55293675831386, 44.78302982875279, 46.474037238529746, 46.291018213544575, 48.2947154045105, 44.99555785315377, 43.53115551812308, 44.06155320576259, 44.386287689208984, 42.53265074321202, 41.10844373703003, 45.87724951335362, 45.23838002341134, 44.8633371080671, 42.60664211000715, 42.33407817568098, 43.67886727196829, 41.91792971747262, 43.66259111676897, 47.10911996023995, 50.760429586683, 49.9315824508667, 53.90161289487566, 54.33747339248657, 57.79325723648071, 53.59380769729614, 49.98273856299264, 54.42121655600411, 57.209768363407676, 57.369267736162456, 57.09751326697213, 50.67640502112252, 54.8587064061846, 56.65501723970686, 53.337363583701, 55.35236201967512, 51.88637127195086, 50.92432369504656, 55.073388372148784, 53.40394122259957, 51.460054125104634, 56.29266173498971, 56.10709966932024, 54.496545451028005, 50.023152760096956, 49.9345771244594, 46.27465867996216, 46.151884010859895, 50.24173961366926, 50.24584599903652, 54.09423085621425, 56.98855856486729, 53.5162102154323, 55.46709067480904, 51.17261062349592, 49.1268629346575, 54.23667587552752, 49.52194792883736, 32.158225945064, 48.60849257877895, 43.3233904838562, 33.24179751532418, 27.766380786895752, 29.27015856334141, 37.07784584590367, 9.987173897879464, 0.6341863498091698, 0.18473126739263535, 0.17086841698203767, 0.5624974966049194, 0.17753644846379757, 0.07433036289044789, 0.11731259790914399, 0.008528526157273777, 0.07752032564686877, 0.1194315677774804, 3.476408920117787, 46.42563608714512, 70.45676258632115, 16.713933399745397, 46.582880769457134, 24.84545189993722, 0.04931021189051015, 0.27800008548157557, 0.07829270884394646, 0.03511363760169063, 0.04693352424406579, 3.9581668291773116, 12.043780752590724, 14.694298778261457, 18.495058945247106, 17.350348438535416, 16.607360192707606, 6.271830107484545, 2.6307367214134763, 0.4664045072027615, 2.169374163661684, 7.376205887113299, 11.304275291306631, 10.300886801310948, 9.797220570700508, 4.414491942950657, 45.413561480385916, 63.461913790021626, 41.43022871017456, 34.52466426576887, 21.799616983958654, 54.61663464137486, 26.476803813661846, 0.1992859792496477, 1.0511779827730996, 0.40763580213700024, 0.10230391219790493, 0.10665351165724651, 0.15146110765635967, 0.23584826876010212, 0.09620202997965471, 0.5886331998876163, 5.011047337736402, 6.063767169203077, 1.2062027156352997, 55.4363831111363, 59.90217099870954, 55.045039721897666, 68.42292758396694, 76.67952060699463, 77.83030905042375, 76.90346104758126, 76.22455951145717, 67.41063063485282, 65.34802314213344, 69.11018085479736, 68.54201275961739, 65.61765493665422, 59.06502423967634, 53.120176792144775, 54.4969345501491, 49.902518136160715, 60.65515422821045, 64.79844842638288, 61.187427929469514, 68.44803142547607, 66.17015484401158, 65.01155662536621, 62.76809447152274, 65.62963363102504, 63.784622873578755, 64.79894174848283, 64.35800211770194, 65.10557964869908, 64.7258050101144, 66.5815646307809, 68.22090176173619, 68.3061214174543, 57.79256589072091, 63.11304473876953, 66.51195062909807, 64.46023096357072, 66.35851355961391, 64.6849912915911, 60.11368806021554, 51.19469199861799, 55.67559221812657, 59.45287268502371, 55.229611669267925, 53.13839149475098, 46.1733261517116, 47.78991488048008, 48.025931290217805, 46.33648027692522, 45.95270695005144, 49.45855603899275, 49.24975224903652, 47.09907633917672, 45.689286845070974, 46.674704687935964, 47.10873433521816, 48.45407581329346, 49.427073751177105, 48.88112946919033, 50.69612053462437, 49.5114735194615, 46.27549246379307, 45.7833446093968, 45.760075092315674, 45.76920502526419, 43.27705989565168, 47.75882169178554, 47.84118216378348, 47.116353034973145, 46.932972703661235, 45.33030469076974, 44.06775099890572, 45.03569064821516, 45.03276893070766, 46.80940593991961, 52.9722010067531, 54.44626481192452, 54.808193002428325, 58.076858384268625, 60.73364107949393, 58.51656123570034, 52.8106449672154, 54.296142033168245, 60.269404138837544, 60.99630383082798, 59.381563322884695, 52.728263650621685, 54.012888295309885, 57.4457083429609, 55.74264580862862, 57.05931207111904, 55.28821277618408, 54.4047840663365, 56.534215859004426, 56.15494149071829, 53.74723087038313, 58.988580158778596, 57.36414691380092, 57.01115410668509, 52.80130311420986, 53.731201376233784, 50.00409732546125, 48.955534253801616, 53.6430287361145, 54.62424291883196, 55.31945187704903, 60.27483068193708, 55.37841429029192, 57.46606656483242, 52.35646901811872, 51.735901083265034, 56.50113548551287, 49.540739331926616, 41.34166349683489, 55.743153027125764, 55.890802247183665, 49.49203245980399, 35.80190297535488, 36.298633166721885, 40.79077557155064, 11.748419778687612, 1.352181219628879, 0.2313330796148096, 0.2901882571833474, 0.9876743789230074, 0.35742687061429024, 0.2322481790823596, 0.175543075427413, 0.13623197270291193, 0.05301436509138771, 0.13262752683034965, 4.854432770184108, 54.88649572644915, 67.3377857208252, 23.466696534837993, 57.03100858415876, 35.778977394104004, 0.05076509953609534, 0.1535027109618698, 0.09238080573933465, 0.06970421969890594, 0.05677799188664981, 4.0515580007008145, 12.486819607870919, 16.332192420959473, 19.77485285486494, 21.77995879309518, 25.74098437173026, 11.401896612984793, 4.686085735048566, 1.172848648258618, 6.581067068236215, 13.767466408865792, 23.54642537661961, 19.92977336474827, 25.688296181815012, 3.122759073972702, 71.71096106937954, 75.5213462284633, 48.16741050992693, 37.11184338160923, 36.98226295198713, 68.83355917249406, 33.4153322492327, 1.2651543808834893, 2.180853021996362, 0.6781213294182504, 0.21744033295129025, 0.2455225767833846, 0.2276623137295246, 0.44786739189709934, 0.500785442335265, 1.8013062626123428, 9.268284610339574, 12.68410849571228, 2.6259385560240065, 69.39421626499721, 64.46196106501988, 66.31384359087262, 75.53183800833565, 81.95173031943185, 81.95644119807652, 81.34331130981445, 80.60899788992745, 72.07398360116142, 70.14946460723877, 74.14754145486015, 73.1336533682687, 68.5645249230521, 67.44899858747209, 63.77403381892613, 62.08717795780727, 56.76361410958426, 67.66462898254395, 68.69223281315395, 66.5416750226702, 70.93257522583008, 67.50833620343889, 67.99593993595668, 66.6775678907122, 68.47284344264439, 67.18682221003941, 68.47817271096366, 66.9726995740618, 67.09754480634416, 66.71417794908795, 70.6017506463187, 70.21174131120954, 73.6332288469587, 62.57183565412249, 66.4180109841483, 68.17268126351493, 67.38586725507463, 67.6882598059518, 66.93870203835624, 65.94626304081508, 53.39748287200928, 56.52820566722325, 64.31597941262382, 58.11096361705235, 56.70719126292637, 49.69579880578177, 48.1905688558306, 51.4300274848938, 49.227549280439106, 48.46627337591988, 52.98414148603167, 51.512947286878315, 50.126482895442415, 48.38612937927246, 50.7438268661499, 50.25701175417219, 50.26185117449079, 52.277329036167686, 50.22729083469936, 53.668181215013774, 51.77318511690412, 47.2107686315264, 48.68854624884469, 47.84202289581299, 48.24988910130092, 47.39239454269409, 50.13844421931675, 49.94144541876656, 50.101410320826936, 49.54340744018555, 47.908023834228516, 47.524549279894146, 47.22067328861782, 48.3096262386867, 52.11779144832066, 56.52922705241612, 56.41138213021414, 58.47949954441616, 59.820390701293945, 63.82398441859654, 59.495020457676475, 55.45604651314871, 60.94192028045654, 65.26431819370815, 61.72836603437151, 60.600388526916504, 55.52277701241629, 58.95505510057722, 59.76009423392159, 58.943319593157085, 59.452789306640625, 57.03165476662772, 56.41197967529297, 57.6100367137364, 59.38842119489397, 56.25929648535592, 60.561388288225444, 59.13686861310686, 57.70889915738787, 55.41895702907017, 58.68595136914934, 56.08486890792847, 56.18854645320347, 60.347036361694336, 62.11158697945731, 60.028398922511506, 64.05046095166887, 58.642407008579795, 63.231713022504536, 61.98811749049595, 58.82713876451765, 62.621021951947895, 55.960697650909424, 46.971965994153706, 57.82594156265259, 57.93623379298619, 49.04878602709089, 36.90054866245815, 34.86940261295864, 41.622273445129395, 12.032836471285139, 2.189758224146707, 0.42935866649661747, 1.065022159899984, 1.3471070804766245, 0.5840769729443959, 0.3251523795936789, 0.28382579716188566, 0.15238243607538088, 0.3789958975144795, 0.2553012434925352, 8.129738892827715, 63.34608037131173, 79.63209506443569, 29.807264736720494, 67.39118957519531, 38.97911269324166, 0.1982822088258607, 0.3342282740133149, 0.16321441983538015, 0.0914407768951995, 0.3165605791977474, 7.111515130315508, 20.032664026532853, 25.36809366089957, 30.61857114519392, 30.702324731009348], [23.688555989946636, 24.060982908521378, 14.338797671454293, 6.516416251659393, 4.680683510644095, 2.7599753865173886, 5.676982666764941, 3.13363322189876, 1.1148250017847334, 4.009260841778346, 25.20196223258972, 48.88905736378261, 38.6166946547372, 19.67963821547372, 52.46153620311192, 54.25763859067644, 2.6979043057986667, 0.06306369602680206, 0.10278449141021286, 0.34810249667082516, 0.13145454334361212, 0.053424936453146596, 0.14177499312375272, 0.3101364810551916, 0.15145956059651716, 1.013541545186724, 5.018493635313852, 9.531395520482745, 6.306454718112946, 34.445486068725586, 36.769265924181255, 67.25647790091378, 75.55307865142822, 73.08728803907121, 75.04356724875313, 68.14016369410923, 71.17499787466866, 68.961350440979, 66.30067675454276, 63.790299551827566, 66.13879762377057, 59.13504123687744, 54.09962613242013, 46.70060409818377, 48.643886702401296, 47.47811099461147, 53.75402273450579, 59.86747864314488, 57.97148895263672, 63.45832851954869, 63.70136260986328, 64.2012368610927, 60.87871946607317, 65.48961353302002, 62.662078857421875, 63.541422026497976, 59.80056749071394, 61.86043044498989, 64.31265817369733, 60.092120851789204, 61.87111677442278, 57.987761633736746, 55.05191149030413, 62.92592280251639, 61.44307994842529, 62.91439574105399, 62.45949717930385, 56.08750922339303, 49.737025942121235, 57.25196129935128, 56.82210404532296, 55.266673360552105, 53.087238856724326, 44.922855377197266, 46.232173919677734, 44.16545309339251, 46.49130351202828, 45.63434049061367, 42.802143573760986, 44.726131030491416, 42.7089786529541, 42.50817223957607, 39.78635093144008, 42.29469231196812, 41.41042981828962, 47.501522949763704, 47.57642453057425, 50.0821464402335, 49.285347870418, 47.174870763506206, 47.442741189684185, 43.36245673043387, 43.69093976702009, 42.069324016571045, 41.80109575816563, 45.136015687670024, 42.77691119057791, 44.34711374555315, 43.86320645468575, 42.20312547683716, 43.12007924488613, 43.52078880582537, 45.0022211756025, 42.57029955727713, 47.13372005735125, 52.91874851499285, 50.97419786453247, 51.9003267288208, 56.5190931047712, 60.282438959394185, 55.26012815747942, 50.18164464405605, 53.17105497632708, 56.68319565909249, 58.00086246218, 52.54396268299648, 50.48137256077358, 53.56400339944022, 55.18310390199934, 52.45449767793928, 53.009676115853445, 52.36045381001064, 51.76886681147984, 54.187058789389475, 51.18529456002371, 56.005159173692974, 54.24778604507446, 54.69479145322527, 53.46519654137747, 49.32063429696219, 48.77418974467686, 42.2452072416033, 44.70692620958601, 53.58643218449184, 55.9942296573094, 57.60981089728219, 55.268073422568186, 50.855717182159424, 47.755802699497764, 51.27260214941842, 57.11796876362392, 56.608561583927695, 34.065562043871196, 37.74551214490618, 45.50595167704991, 28.269131592341832, 26.38042187690735, 29.15832383292062, 38.06387513024466, 11.34425435747419, 1.7598589552300317, 0.2630916126072407, 0.8337388304727418, 1.3510811243738448, 0.0298518665534045, 0.4721679293683597, 0.01548088331972914, 0.15776924416422844, 0.04944960333939109, 0.557747805757182, 2.308417171239853, 26.655681712286814, 80.36433792114258, 39.34773199898856, 16.724963665008545, 64.44993373325893, 8.75240431513105, 0.15143889241984912, 0.10082024788217885, 0.0559580807041909, 7.48026818888528, 19.27823904582432, 18.147001096180507, 10.345143352236066, 9.923757689339773, 7.386181763240269, 37.70325320107596, 31.48926728112357, 18.47877757889884, 11.631310497011457, 11.831409062658038, 7.0914739200047086, 9.04826990195683, 4.616670191287994, 6.363574990204402, 4.946900265557425, 43.36310986110142, 59.58386707305908, 51.943815503801616, 24.60000852176121, 39.91495861325945, 61.81314100537981, 4.854358511311667, 0.02465404403795089, 0.1963856763073376, 0.36693366191216875, 0.058378235303929875, 0.1196466362369912, 0.1496314922613757, 0.32317800553781645, 0.20629025197454862, 1.2135031010423387, 9.040521792003087, 18.13621575491769, 6.951574981212616, 47.07294416427612, 49.21716867174421, 72.97299017224992, 78.35691302163261, 73.99545233590263, 78.5017204284668, 71.08688776833671, 73.53632926940918, 71.64118725912911, 69.23729119982038, 67.1981338773455, 69.02899810246059, 62.98547581263951, 58.19850049700056, 52.909774916512625, 55.87880965641567, 54.725922857012065, 58.87390014103481, 63.489352226257324, 62.60386684962681, 65.50482313973563, 64.68435900551933, 67.78447846003941, 67.22170216696603, 67.31213297162736, 66.79133769444057, 64.30739143916539, 62.05607782091413, 65.47787802559989, 65.62084415980748, 63.59060137612479, 63.85034588405064, 60.4365291595459, 61.06018556867327, 68.06950051443917, 63.97962406703404, 67.02894524165562, 63.75034046173096, 56.173687730516704, 52.75102594920567, 60.16290215083531, 60.28038229261126, 58.74262087685721, 53.88546528135027, 46.92626421792166, 46.64261095864432, 46.62700877870832, 47.7793744632176, 46.94170658929007, 45.481004170009065, 47.08714975629534, 46.810767786843435, 46.158710615975515, 42.78573192868914, 45.1567838532584, 44.750314235687256, 49.54064553124564, 49.390474115099224, 50.19317170551845, 51.17843321391514, 50.2824421610151, 49.149281297411235, 45.508050033024375, 44.82568481990269, 44.19819300515311, 45.34639324460711, 47.73789719172886, 45.41000747680664, 46.991455691201345, 45.92612314224243, 45.993201051439556, 44.90853861400059, 46.34597846439907, 46.291601862226216, 45.64514493942261, 47.308616638183594, 52.87417582103184, 55.03975214276995, 54.64577191216605, 57.72512320109776, 62.2982086454119, 57.88790559768677, 53.87025914873396, 55.816814354487825, 56.493714809417725, 59.23081520625523, 55.93257829121181, 52.59100546155657, 55.51103455679757, 56.30454315458025, 56.54037543705532, 54.90285178593227, 54.65394994190761, 54.45641960416521, 55.70940562656948, 55.28127499989101, 59.640300342014854, 57.40846599851336, 56.78613322121756, 56.86825050626482, 52.23890549795968, 54.60176549639021, 45.592998708997456, 47.75780030659267, 58.296115739004954, 58.98974050794329, 58.92667865753174, 58.09415592466082, 54.16449798856463, 50.54341650009155, 54.053215639931814, 58.26159361430577, 56.76912750516619, 43.23475578853062, 48.3263053894043, 55.6182313646589, 45.44613463538033, 32.98979677472796, 33.19768687656948, 41.02482564108712, 13.559380888938904, 1.8183600732258387, 0.3355396107903549, 1.5551919490098953, 1.883913938488279, 0.05174781162557857, 0.3243056764560086, 0.04274960268022759, 0.18293916141348227, 0.06849131121167115, 0.6099691635796002, 3.1266967483929227, 37.53215381077358, 82.46905844552177, 45.985870701926096, 23.763831036431448, 76.1844961983817, 13.301600984164647, 0.26804475539496964, 0.04146805019783122, 0.13033946603536606, 7.553621189934867, 25.41344107900347, 30.920383521488734, 28.042528254645212, 30.398111752101354, 24.61303292001997, 42.9487019266401, 44.54379292896816, 30.692142145974294, 23.60815838405064, 24.753723519189016, 11.828784380640302, 21.395751203809464, 12.600901212011065, 25.871709517070226, 4.74935689994267, 77.62815121241978, 71.8660031727382, 59.48174245016915, 31.612413678850444, 73.27902357918876, 70.4503424508231, 8.974724956921168, 0.12340116048497812, 0.33982882063303677, 0.8679088226386479, 0.18036583092595848, 0.63487259298563, 0.1933589351496526, 0.6706250373806272, 0.3254462666809559, 1.4425630612032754, 13.535783069474356, 21.793914249965123, 8.849543605531965, 55.977936131613596, 61.99474607195173, 81.41462067195347, 83.84102194649833, 79.2474775314331, 82.90946306501115, 75.84775175367082, 78.2575329371861, 77.02507536751884, 72.7789408820016, 71.27668476104736, 72.15258162362235, 67.31063216073173, 65.78089591435024, 63.23891830444336, 62.446712493896484, 58.852242606026785, 66.1851282119751, 68.20153713226318, 66.43181010654995, 70.14600440434047, 69.83421788896833, 68.94548075539726, 68.95586136409214, 71.6544930594308, 68.4710716520037, 67.97566509246826, 64.29556560516357, 67.10385377066476, 68.13493170057023, 65.78720487867082, 69.15059157780239, 65.13044030325753, 63.25670569283621, 71.3601326261248, 68.02637304578508, 68.53993524823869, 68.26932375771659, 60.16499355861119, 55.33425848824637, 62.39986079079764, 61.37169415610177, 60.10316153935024, 57.29249014173235, 49.090499537331716, 49.968710150037495, 46.809808935437886, 50.05694532394409, 49.452861990247456, 47.49140289851597, 48.33943401064192, 48.27891867501395, 49.48935740334647, 45.58711705889021, 49.49900497709002, 46.741456031799316, 53.170342785971506, 54.194027832576204, 55.077835219247, 54.36808368137905, 53.214331831250874, 52.71020875658308, 48.07499252046858, 48.57036433901106, 47.48870699746268, 48.74591405051095, 52.313893931252615, 46.668256759643555, 49.952698026384624, 49.816020011901855, 48.02262394768851, 46.72418628420149, 50.06615168707711, 49.53892585209438, 47.81688778741019, 52.608563559395925, 55.550538539886475, 57.593979426792686, 56.9927795955113, 61.06035232543945, 65.87508569444928, 60.358764920915874, 55.06341423307146, 58.654601097106934, 60.45862443106515, 61.05376543317522, 55.96211855752127, 54.667387757982524, 59.38308497837612, 59.68049567086356, 58.11190162386213, 57.92037105560303, 57.56544317517962, 57.125233105250764, 59.03978143419538, 56.87908969606672, 62.19807815551758, 57.93255124773298, 59.4450490134103, 58.47286401476179, 58.510634422302246, 59.134700775146484, 54.15899848937988, 55.03180340358189, 63.449462618146626, 62.212050982883994, 64.08035210200718, 61.645522662571494, 60.16453497750418, 56.779765197208945, 61.030023438589915, 66.53264931270054, 62.840244565691265, 47.36782223837716, 50.18127291543143, 55.894568170819966, 46.30617570877075, 33.739326749529155, 32.89258452824184, 39.187374523707796, 12.912180508886065, 2.7200050055980682, 1.0349398255348206, 3.2826280040400366, 2.4176545781748633, 0.3222560392958777, 0.8131372045193399, 0.18055516933756216, 0.2861562935369355, 0.3671953050153596, 0.6117991996662957, 4.16682470696313, 42.896812779562815, 84.32706928253174, 52.72102015359061, 28.713390724999563, 87.00588471548897, 17.82877012661525, 0.3904540741017887, 0.1827119743185384, 0.1650550817804677, 12.528837970324926, 37.90384769439697, 39.11562047685896, 37.57305090767996, 38.16876513617379, 28.651548283440725], [5.946827684129987, 10.044112648282733, 11.935660702841622, 15.935556241444178, 4.158050869192396, 7.545279009001596, 11.624593326023646, 3.547930419445038, 2.8739197637353624, 4.722195088863373, 29.15656246457781, 48.67137377602713, 27.783096415655955, 30.094885417393275, 50.86528485161917, 25.42278814315796, 0.28304122069052284, 0.05440096836537123, 0.08427396110658135, 0.11009044758975506, 0.10817589996648685, 0.0871913359899606, 0.16555554206882203, 0.11533527901130063, 0.0990942379991923, 0.7486521676182747, 7.499050038201468, 1.6238856400762285, 19.21543080466134, 49.45281335285732, 58.69975049155099, 64.75571005684989, 72.95391041891915, 74.35368061065674, 68.94509860447475, 69.02731663840157, 66.78843334742955, 66.70001752035958, 68.41317231314522, 66.80290644509452, 67.36548818860734, 60.25033828190395, 55.55898754937308, 49.12315954480852, 52.2233693259103, 54.10937098094395, 52.1598037311009, 57.82084853308541, 59.79727404458182, 60.537396158490864, 59.90675680977957, 61.224920409066335, 63.4083640234811, 61.83591720036098, 62.74082974025181, 60.02439676012312, 65.26367201123918, 64.05622795649937, 62.49570424216134, 60.806263651166645, 57.28509031023298, 58.72884259905134, 61.486624308994834, 62.3904390335083, 60.552779470171245, 60.931504930768696, 52.77825593948364, 55.37653480257307, 59.12273597717285, 56.4834349496024, 58.57742050715855, 57.36090905325753, 47.74497740609305, 43.960324900490896, 45.597737380436485, 43.97176858357021, 43.19298669270107, 44.84531000682286, 42.52046707698277, 44.022021429879324, 42.63506719044277, 40.546046120779856, 39.71142503193447, 39.25865609305245, 43.28650944573538, 44.808658259255544, 46.429429803575786, 45.04105118342808, 45.39941494805472, 44.09246574129377, 43.08525487354824, 44.6260734966823, 43.101572717939106, 39.56488752365112, 40.001296928950715, 41.845939431871685, 42.55146299089704, 43.906181062970845, 43.2500696182251, 45.20484454291207, 43.76190171922956, 43.92223140171596, 44.06633356639317, 44.80593456540789, 42.07385424205235, 47.34053666251046, 54.35888426644461, 53.81514603751046, 54.05495268957955, 55.86155380521502, 57.57942642484392, 55.32883889334542, 56.80018942696707, 51.230367524283274, 54.52557849884033, 58.78323309762137, 52.49307060241699, 47.870739800589426, 55.13084997449602, 52.510653018951416, 53.148765155247276, 52.04423781803676, 51.93351132529122, 52.78649650301252, 51.98289564677647, 51.49986730303083, 55.317499433244976, 53.0824202810015, 52.893526554107666, 48.71773910522461, 49.22652094704764, 48.297369616372244, 44.1602315221514, 52.81603676932198, 53.73035717010498, 59.065371649605886, 50.89141355242048, 50.050618989127024, 47.28938055038452, 52.28812306267874, 57.01847055980137, 55.796146937779014, 41.77387966428484, 34.17453064237322, 43.871627671378, 27.748315470559255, 26.218615702220372, 30.371969154902867, 36.3792461667742, 13.048158492360797, 1.363048745053155, 0.6598528868385724, 0.5083199494651386, 1.7677968378577913, 0.263111344405583, 0.22276512293943337, 0.0598795958129423, 0.14472435414791107, 0.12778788938054017, 0.34153240493365694, 1.422572659594672, 22.717161348887853, 38.42098821912493, 43.77939033508301, 19.82387239592416, 45.445874077933176, 22.6274288381849, 0.07449638683881078, 0.1394635092999254, 3.4332147921834673, 19.634747641427175, 24.22885833467756, 18.976018462862285, 31.42494433266776, 34.43520968300955, 23.97100373676845, 20.815142359052384, 27.951941115515574, 26.7215211050851, 40.941756452832905, 12.520503606115069, 4.286243396145957, 2.916760402066367, 0.2717234737106732, 7.287967239107404, 5.8389425703457425, 53.437963077000205, 55.321727412087576, 47.12997497831072, 25.316440752574376, 52.95891605104719, 31.336389541625977, 0.5270899108478001, 0.0526520545328302, 0.11844044524644103, 0.10555623910788979, 0.07420004345476627, 0.032554770088089366, 0.44185114758355276, 0.2186070874865566, 0.6385459644453866, 0.6307906891618456, 8.388997026852199, 1.8404842231954848, 17.306929145540508, 52.13324771608625, 66.38776547568185, 71.24534838540214, 76.22133554731096, 77.00448785509381, 70.93199157714844, 73.52426024845668, 70.72155148642403, 70.63520622253418, 71.74937071119035, 70.70339584350586, 67.19073404584611, 63.95666027069092, 59.42806761605399, 55.09632437569754, 57.33924804415022, 62.066479274204795, 58.39534296308245, 61.547921316964285, 63.974273954119, 62.38399110521589, 62.84592819213867, 63.09480571746826, 66.03221920558384, 63.13876696995327, 64.02773339407784, 63.55287265777588, 65.63295486995152, 65.09632464817592, 66.42441722324916, 62.993758065359934, 61.434901918683735, 60.94570010049002, 64.79395989009312, 64.91548388344901, 63.97497572217669, 62.23765509469168, 54.83952937807356, 60.021777289254324, 60.44076061248779, 60.23668507167271, 61.654409408569336, 59.78501047406878, 50.163040842328755, 46.973755155290874, 48.60058900288173, 48.078428404671804, 45.475362232753206, 47.12350967952183, 44.70811435154506, 46.62175246647426, 45.267406123025076, 44.906485421316965, 44.34265995025635, 42.48949200766427, 45.21505492074149, 47.1331398827689, 47.8108081136431, 47.18531043188912, 47.85248688289097, 47.20029769624983, 46.85688645499093, 47.540043762751985, 46.340906279427664, 42.57435730525425, 42.40658262797764, 45.98077072416033, 45.09692512239729, 46.839244978768484, 46.39228820800781, 45.54014376231602, 46.76271404538836, 45.263007913317, 45.33430337905884, 48.27614286967686, 45.70687620980399, 48.7168219430106, 56.74328020640782, 56.010759421757285, 57.856669970921104, 58.277035985674175, 60.1679048538208, 57.39156103134155, 58.709116663251606, 55.77589988708496, 54.70195157187325, 59.50701304844448, 55.84734126499721, 50.377052307128906, 57.0945394379752, 54.63218470982143, 56.55134316853115, 55.993121419634136, 56.04130022866385, 54.0915071623666, 55.25635528564453, 53.97889423370361, 55.51750332968575, 55.99022054672241, 55.73808084215437, 52.09041207177298, 53.66774695260184, 53.561370032174246, 49.16498422622681, 57.052989210401265, 56.45188317980085, 60.07279791150774, 54.44375998633248, 54.40567690985543, 50.42699943270002, 52.523951871054514, 56.12423045294625, 56.56419038772583, 48.390899317605154, 46.28718628202166, 53.829181398664204, 41.600331033979145, 30.996751172201975, 33.18659060341971, 30.621322631835938, 12.40442178930555, 1.6249452403613498, 0.8766598616327558, 1.075843762074198, 1.5272672474384308, 0.11537709033914975, 0.24096732693059103, 0.021239216472687464, 0.1292746817427022, 0.20014577811317785, 0.23682139654244694, 1.5492243149450846, 30.813412530081614, 44.995950426374165, 55.887293406895225, 28.60018719945635, 57.57180425098964, 29.884883063180105, 0.07040546528462853, 0.0629957000325833, 3.2166151234081815, 27.647297348294938, 39.352199690682546, 33.954366547720774, 34.984159060886924, 37.39660835266113, 28.052248784473964, 30.959571361541748, 35.59768499646868, 41.47472149985177, 82.42991924285889, 23.650669200079783, 14.265838980674744, 24.277914353779384, 25.78811400277274, 32.31152752467564, 22.168661866869243, 75.06159782409668, 69.21586295536586, 42.03931474685669, 43.14214324951172, 71.26811068398612, 34.94102464403425, 1.8279158004692622, 0.23994849302939006, 0.2431395346564906, 0.326632807297366, 0.16654101918850625, 0.41462360003164833, 0.43042076379060745, 0.40854962595871513, 0.741857263658728, 3.5166242250374387, 12.43909764289856, 4.2053989342280795, 23.425097669873917, 62.168430192129954, 76.22401060376848, 77.21401078360421, 82.17510100773403, 80.17550672803605, 74.07097230638776, 75.78739275251115, 72.91775894165039, 75.21174839564732, 74.69182859148297, 75.42075715746198, 76.49387863704136, 69.59115600585938, 67.09220164162772, 61.48279585157122, 63.68288734980992, 64.57022789546421, 64.39671053205217, 69.6101940699986, 67.19990566798619, 67.02947330474854, 66.15213121686662, 67.10006005423409, 69.64947918483189, 66.80621378762382, 67.84193311418805, 65.4042410169329, 67.55520180293492, 67.70932674407959, 68.10991818564278, 65.6801609311785, 62.779892512730186, 64.30516801561627, 67.53731713976178, 68.82496425083706, 67.15905720846993, 66.86204256330217, 58.806731905256, 60.46823378971645, 62.260903767177034, 62.26932498386928, 62.77638367244175, 62.95818328857422, 52.461293016161235, 48.986762932368684, 50.282372679029194, 49.68082543781826, 48.18463509423392, 49.91425711768014, 47.49362632206508, 49.479907853262766, 46.76132093157087, 46.61992161614554, 46.25315053122384, 45.11838115964617, 47.4959921836853, 49.270843505859375, 50.778456687927246, 50.64015279497419, 51.48172903060913, 50.61205775397164, 49.981665066310335, 51.21479313714163, 47.72390699386597, 46.726215158190044, 45.57034410749163, 47.38618632725307, 47.20151710510254, 49.709987027304514, 49.11773647580828, 51.1603296824864, 50.2330995287214, 48.89181579862322, 47.69248029163906, 49.524101870400564, 47.355867862701416, 54.405270440237864, 58.83534458705357, 57.90323679787772, 60.31508159637451, 62.079917090279714, 62.815891129629954, 60.96874727521624, 60.19855335780552, 57.327050481523784, 59.06181417192732, 62.44592039925711, 57.47778122765677, 52.4362656048366, 61.622371264866416, 55.94757945196969, 58.864318575177876, 58.50695882524763, 57.24262292044503, 57.615133217402864, 57.47727748325893, 55.10415499550955, 59.84190927233015, 57.71134492329189, 61.26233645847866, 57.14297533035278, 60.20212473188128, 58.800165857587544, 55.55297040939331, 62.27450834001814, 59.69503130231585, 63.439908845084055, 58.61853299822126, 59.148541586739675, 56.962700843811035, 60.76387963976179, 64.31978007725307, 65.77310003553117, 52.59385074887957, 50.820097242082866, 57.772548130580354, 44.758759771074565, 29.525091443743023, 34.234493596213206, 40.92787395204817, 16.31444672175816, 2.7305962315627506, 2.4758761397429874, 3.2589611368519917, 2.7071434557437897, 1.0105159303971698, 0.5830416913543428, 0.20179440107728752, 0.32592780941299027, 0.43816320119159563, 0.2963431126305035, 2.283214100769588, 40.4587767464774, 49.087942600250244, 56.35320833751133, 34.196393149239675, 69.99008682795933, 38.69672053200858, 0.12538276772413934, 0.39742518003497807, 6.5989091736929755, 38.41575969968523, 47.720731667109895, 48.04005350385393, 55.680959701538086, 63.099190030779155, 59.26054654802595], [16.81435571398054, 10.170925089291163, 15.279073068073817, 15.68684026173183, 11.646569609642029, 21.49770212173462, 20.270664146968297, 10.247342245919363, 13.634063601493835, 20.145690373012, 46.27322040285383, 48.512204442705425, 36.906753403799875, 33.21024921962193, 49.723233767918174, 13.96464673110417, 0.21618615596422128, 0.0486606604951833, 0.1589634929384504, 0.09962620945381266, 0.12229191857789244, 0.11529755246426378, 0.3558485710195133, 0.28034013562968796, 0.23006028362682887, 0.7062086079801831, 4.796760984829493, 4.114960312843323, 43.16915784563337, 66.28915664127895, 71.25011484963554, 71.16502026149205, 74.30230563027519, 68.68535409654889, 68.05934919629777, 65.25714765276227, 65.68724114554269, 64.80254786355155, 67.75073105948312, 69.01965972355434, 63.6105010168893, 61.122927801949636, 56.118977614811485, 50.49600199290684, 52.55258887154715, 62.5573764528547, 56.785424504961284, 51.09186213357108, 59.94872392926897, 59.365596362522666, 59.48947579520089, 60.59678936004639, 61.846749441964285, 60.54583821977888, 62.54762118203299, 61.28049904959542, 62.51385988507952, 62.28193596431187, 61.93067673274449, 58.40961456298828, 57.12575422014509, 59.08029638017927, 60.44563824789864, 60.48766095297677, 60.64501680646624, 49.22484295708792, 55.18313864299229, 62.32694639478411, 59.307523318699424, 58.24646043777466, 57.89259215763637, 49.71989515849522, 44.88070413044521, 45.526289054325645, 46.4460950578962, 45.846409933907644, 44.708843912397114, 43.25018078940255, 41.45073979241507, 44.1217246055603, 44.269596167973106, 43.69699164799282, 40.39140353884016, 40.76355600357056, 40.668994494846885, 43.16283845901489, 44.204665252140586, 45.51451880591256, 47.99408769607544, 45.37432152884347, 43.63256447655814, 43.04174872807094, 40.294441427503315, 39.74595757893154, 37.729875223977224, 40.81874207087925, 40.696822030203684, 41.22900193078177, 43.695066996983115, 42.957206521715435, 42.105913230351035, 42.27901370184762, 44.39592831475394, 44.25996249062674, 43.36886296953474, 42.907582487378804, 46.60648380007063, 52.74523115158081, 52.72089508601597, 55.448983669281006, 56.14134039197649, 57.06638533728463, 52.11300761359078, 55.44389411381313, 52.12440960747855, 55.71451255253383, 54.70317098072597, 52.32193299702236, 51.46899993079049, 53.36312402997698, 56.074533462524414, 52.87978301729475, 52.95357288633074, 51.623652935028076, 52.533359731946675, 53.22819001334054, 51.01433065959385, 52.28595175061907, 51.70352247783116, 47.308755602155415, 45.71361943653652, 46.817868845803396, 46.79374470029558, 48.6561085837228, 57.02742331368582, 52.451749665396555, 52.80395385197231, 49.382250922066824, 47.96874066761562, 50.8165397644043, 54.01055717468262, 53.087735652923584, 49.010407652173726, 32.64344991956438, 38.52459280831473, 22.29153381075178, 26.791206325803483, 26.270939111709595, 10.761663539069039, 2.546337604522705, 0.0653207138446825, 0.09170689154416323, 0.32062543822186335, 0.2201105175273759, 0.3252907193132809, 0.1536488402634859, 0.027635688061958978, 0.09376408079905169, 0.13142972253262997, 0.35997265258005684, 0.7283888863665717, 27.916828393936157, 31.328381742749894, 30.901126589093888, 18.942300592150005, 45.24567215783255, 39.15815734863281, 0.4987194389104843, 0.1601858330624444, 11.760100569043841, 13.345324260847908, 19.83873459271022, 39.819872515542166, 52.50145360401699, 33.79311275482178, 28.432424681527273, 26.135680266789027, 21.166896649769374, 27.255043745040894, 36.923345702035085, 4.673202037811279, 16.933357511247905, 16.747844082968577, 11.294565183775765, 19.3239495073046, 24.907313449042185, 62.926527295793804, 57.237953730991904, 33.464216300419395, 24.211048364639282, 59.483403069632395, 16.583413226263865, 0.2905578687787056, 0.1632862359817539, 0.023565453344157765, 0.0780460885060685, 0.10160021031541483, 0.0859130642243794, 0.44411737312163624, 0.34550232333796366, 0.29773910343647003, 1.01947335260255, 6.378463676997593, 3.7830665792737688, 43.14678117207119, 66.45059108734131, 73.31916332244873, 72.25348336356026, 74.79444653647286, 69.83509336199079, 69.85090746198381, 66.03073923928397, 67.88508837563651, 68.53591224125454, 70.09631783621651, 72.72028418949672, 65.53383186885289, 64.71206842150006, 60.038876805986675, 57.73026486805507, 58.48889350891113, 66.23867797851562, 61.42998259408133, 56.512235232761924, 61.24142932891846, 61.96168654305594, 62.33422115870884, 63.78308037349156, 61.253602572849815, 63.895780154636924, 63.023746490478516, 63.94976070949009, 63.49620315006801, 64.42032051086426, 64.45027419498989, 62.89644854409354, 60.30783462524414, 62.20875753675188, 63.07829679761614, 64.13673673357282, 62.303447587149485, 53.20705359322684, 60.86283588409424, 62.46115779876709, 60.923382486615864, 62.575427872794016, 59.33656678880964, 51.92443697793143, 47.73666736057827, 47.95930848802839, 50.01279647009713, 49.7059987613133, 47.54015840802874, 46.854353836604524, 44.301547459193635, 45.54025840759277, 46.20800461087908, 45.82219893591744, 43.06974996839251, 43.867274624960764, 43.772542885371614, 47.102564334869385, 46.8718980380467, 47.62858118329729, 50.29684577669416, 47.276040009089876, 47.99629027502877, 44.72358798980713, 41.01849583217076, 41.306613309042795, 40.31972592217581, 44.400573185511995, 43.11823797225952, 42.58963291985648, 45.03469705581665, 45.954311983925955, 43.69010598318917, 44.15359251839774, 45.54191207885742, 46.79055200304304, 47.50985036577497, 44.453139781951904, 46.70624950953892, 54.57697779791695, 56.783993176051546, 59.45629119873047, 58.2667179107666, 58.589114325387136, 55.94509547097342, 59.067240715026855, 55.66312714985439, 59.263061795915874, 57.95487928390503, 53.91969558170864, 53.39078828266689, 56.77419621603829, 57.719700132097515, 55.927179540906636, 55.94615159715925, 54.054553168160574, 54.4774934904916, 56.52830294200352, 53.733275413513184, 54.47160141808646, 55.63794340406145, 51.49114383969988, 52.650530678885325, 52.185248034340994, 48.415707860674175, 53.30284145900181, 60.331701687404085, 55.028773988996235, 56.173517499651226, 52.016677788325715, 51.670876366751536, 52.68568508965628, 54.72087846483503, 54.97960506166731, 55.0128105027335, 42.70501470565796, 51.581505162375315, 33.55225692476545, 27.014217444828578, 23.628716366631643, 5.36171076127461, 2.1485102432114735, 0.0502932157500514, 0.14882779467318738, 0.05977057559149606, 0.13006574500884327, 0.06695972875292812, 0.14441359868007048, 0.04981783750866141, 0.1273148147655385, 0.10350614054394619, 0.28849780932068825, 1.0775416195392609, 32.97527503967285, 38.70273767198835, 41.22428410393851, 23.839410066604614, 51.32139587402344, 46.805004256112234, 0.4673458252634321, 0.13649928835885866, 16.88147531236921, 27.587165900639125, 36.176136425563264, 46.555390221732004, 63.6784474509103, 55.09302050726754, 44.396525859832764, 64.6016684940883, 46.35717896052769, 64.50650596618652, 79.240633555821, 53.56159584862845, 57.02486637660435, 50.419679505484446, 39.36215993336269, 39.412412779671804, 51.08269051143101, 74.37209333692277, 65.60243143354143, 50.4438453401838, 48.24862105505807, 68.58739144461495, 21.628435952322825, 0.2821758985519409, 0.1586599570832082, 0.19326432022665227, 0.27480589545198847, 0.23684593236872128, 0.44294814871890204, 0.5540913705314908, 0.6458820136530059, 0.6031497237937791, 4.737831575529916, 7.997707486152649, 6.835218276296343, 50.13731861114502, 74.26054000854492, 80.646698815482, 78.04054764338902, 77.81452969142369, 74.35374314444405, 74.54041344778878, 71.04987471444267, 72.34234387534005, 72.40081296648297, 73.95928696223667, 74.62535517556327, 70.4710967200143, 69.60756070273263, 65.7991418838501, 65.25096375601632, 61.073234285627095, 70.38049221038818, 65.3210015978132, 61.505440030779155, 66.2443824495588, 68.56756128583635, 65.3093981061663, 67.9935358592442, 66.66963304792131, 67.31391865866524, 67.5687507901873, 65.78888634272984, 65.94433838980538, 67.01932893480573, 66.85246099744523, 64.51691436767578, 61.310431889125276, 66.14717020307268, 65.79796763828823, 66.17305224282401, 67.65509605407715, 55.469126496996196, 60.35870933532715, 64.05233001708984, 64.29839352199009, 63.35900402069092, 62.962887219020296, 56.02125120162964, 49.453890323638916, 50.08822611400059, 52.24225452968052, 49.82326698303223, 51.072556563786094, 49.60215793337141, 47.11181933539254, 47.15802138192313, 50.028127670288086, 50.606290749141145, 45.296605927603586, 46.41465098517281, 45.14083773749215, 48.83269705091204, 50.08448103496006, 50.59234571456909, 54.077294622148784, 48.461656297956196, 50.487851755959646, 47.57617786952427, 44.33544077192034, 44.187103680201936, 42.37858138765608, 46.8109484400068, 44.843711921146934, 45.48808438437325, 49.03206171308245, 49.80826929637364, 46.1262903213501, 47.41819320406233, 48.83928394317627, 50.29823889051165, 49.73793963023594, 47.82179321561541, 50.62636756896973, 57.19345051901681, 57.597324984414236, 61.0906742640904, 62.124149322509766, 62.821199553353445, 58.657164982386995, 59.453602245875764, 59.084562574114116, 59.72229603358677, 61.36765725272042, 54.99577004568917, 56.754914964948384, 60.10034057072231, 60.534255572727744, 58.38016809735979, 59.177696228027344, 56.25160830361502, 56.79108381271362, 59.05469226837158, 57.09244455610003, 58.639655521937776, 60.186526026044575, 58.5299643107823, 60.78582205091204, 55.97531318664551, 52.802678857530864, 57.1245938709804, 60.8622522354126, 58.86679908207485, 59.79604421343122, 56.53118297031948, 57.74403619766235, 61.51429898398263, 64.02403000422886, 61.41300119672503, 60.67968831743513, 45.88414907455444, 53.74952377591814, 37.723059041159495, 28.360000133514404, 38.183213915143696, 23.635669776371547, 3.78010447536196, 0.19590653558926924, 0.40377002528735567, 0.5463085738675935, 0.37079610036952154, 0.5791260014687265, 0.41049544726099285, 0.16238124668598175, 0.21018450015357562, 0.3464114788387503, 0.4303357297820704, 1.9765484077589852, 44.08253329140799, 45.67245830808367, 40.489053521837505, 33.35494892937796, 63.7048019681658, 58.18178660529, 0.7048197282212121, 0.4147212276501315, 25.358211585453578, 36.58222736631121, 49.60913045065743, 71.62913908277238, 90.2309466770717, 75.73024381910051, 68.4835158756801], [1.0100106660808836, 54.32798562731062, 29.96410642351423, 22.31442812510899, 42.42296648025513, 33.37009252820696, 28.91486590249198, 23.108211176736013, 27.115866116115026, 33.873708384377615, 54.89246770313808, 54.6068446295602, 45.49237837110247, 40.98908758163452, 49.53325612204415, 1.847930520772934, 0.04816393554210663, 0.12029683563326087, 0.08334318069475037, 0.07393274136951991, 0.11773695370980672, 0.04185745805235846, 0.8640287965536118, 0.6660649563585008, 1.9935682373387473, 2.842906479324613, 3.528245521443231, 18.287314755576, 37.66745955603463, 54.06430149078369, 76.17922946384975, 66.65782111031669, 68.05669498443604, 63.9303891318185, 62.159717151096885, 59.184283120291575, 59.9920528956822, 64.67648669651577, 66.32061808449882, 67.07588727133614, 64.26408331734794, 60.831833021981375, 59.28581019810268, 55.00842271532331, 56.090173857552664, 62.63463347298758, 62.02614498138428, 52.902520997183665, 55.65762070247105, 64.13136577606201, 57.46635838917324, 60.63508783067976, 61.03312233516148, 62.10121331896101, 60.797071184430806, 62.829801423209055, 61.767282894679475, 62.42237295423235, 55.43562923158918, 57.362937927246094, 60.03238024030413, 63.95445769173758, 59.685741560799734, 60.713616371154785, 50.30522877829415, 55.513115542275564, 61.71257277897426, 55.09549059186663, 62.133862904139924, 59.27691650390625, 56.433665003095356, 46.761178493499756, 45.594120843069895, 49.80494805744716, 48.956579957689556, 44.810492583683555, 42.99386174338204, 41.96630655016218, 42.10546507154192, 40.370538098471506, 41.62245062419346, 40.47686290740967, 38.74013982500349, 39.98657022203718, 40.604966844831196, 40.377079827444895, 41.94728933061872, 45.69758299418858, 45.94173921857561, 44.6536682673863, 45.0057578086853, 43.5305232320513, 39.22384214401245, 37.49305977140154, 37.2609030859811, 39.509475639888215, 39.194586753845215, 38.271108627319336, 39.62660837173462, 40.88598326274327, 39.59355926513672, 41.81965439660208, 42.27949660164969, 45.13629361561367, 44.23807566506522, 45.743097169058665, 42.648150648389546, 47.14014366694859, 53.689661570957725, 56.551364013126914, 54.21139832905361, 57.10178640910557, 55.62259483337402, 53.570930753435405, 55.03457920891898, 53.293360642024446, 53.74667501449585, 54.31671217509678, 51.926799365452354, 52.65367473874773, 53.69478586741856, 53.48069797243391, 53.37938628877912, 50.84587505885533, 50.976362228393555, 52.266705240522114, 50.85185398374285, 53.68121950966971, 47.95975317273821, 45.67244093758719, 42.83910799026489, 49.83854259763445, 45.007498332432334, 47.427684443337576, 52.59844698224749, 49.62654611042568, 52.08071238654, 48.59852191380092, 48.57465485164097, 48.55953904560634, 53.037184034075054, 51.31569835117885, 51.43106624058315, 32.4580511365618, 31.96563230242048, 18.787044831684657, 21.751403433935984, 10.37096893787384, 2.518477065222604, 0.1650378198495933, 0.08170446434191295, 0.06566319760999509, 0.09754142417971577, 0.019712902838364244, 0.10292640700936317, 0.04881341569125652, 0.047045024511005194, 0.08625960562910352, 0.1755632007760661, 0.23213090108973639, 1.0131649311099733, 32.418679169246126, 25.250012499945505, 52.963807582855225, 26.255614859717234, 45.97404834202358, 39.67628799165998, 1.2613043189048767, 1.2710574184145247, 10.660230261938912, 7.416333471025739, 28.748458283288137, 28.686079093388148, 20.773060594286235, 2.4959286408764974, 2.8053590655326843, 18.059243610927037, 34.26079600197928, 39.507255690438406, 20.06072780064174, 32.99350711277553, 40.51196868079049, 32.39237676348005, 24.79363570894514, 38.018895966666086, 48.800863879067556, 62.468210220336914, 61.93316418784005, 43.16889728818621, 37.828018529074534, 61.52801472800118, 2.2048536198479787, 0.17219693426574978, 0.0631010765209794, 0.18290732455040726, 0.01520063478632697, 0.12209096364676952, 0.044226620745446, 0.18515214909400257, 0.7708995395473072, 0.5907907783985138, 4.075607453073774, 4.2154499377523145, 14.73547032901219, 47.21632024220058, 63.46359525408064, 77.6614122390747, 68.6570679800851, 71.76411478860038, 66.13890879494804, 64.85818208966936, 60.85526234763009, 64.0475913456508, 68.08671815054757, 68.01487377711705, 70.48887716020856, 65.70809268951416, 65.1962536403111, 62.69332490648542, 59.37833935873849, 59.669948305402485, 64.96665041787284, 65.35411671229771, 60.44414438520159, 57.9223130771092, 64.44372204371861, 60.46721935272217, 64.67304733821324, 61.27966526576451, 64.3028542654855, 64.30402156284877, 65.57764720916748, 64.76603507995605, 64.86203833988735, 58.0991655758449, 61.32443945748465, 62.52355262211391, 64.30403545924595, 61.80342047555106, 62.098156111580984, 53.36257859638759, 59.961717060634065, 62.67721203395298, 59.60742841448103, 64.83113970075334, 60.501911708286826, 57.4600042615618, 48.72655636923653, 49.05258321762085, 51.286297048841206, 51.51757478713989, 49.33365869522095, 43.88631616319929, 43.68943200792585, 41.919593811035156, 42.38841308866228, 44.05380596433367, 43.796392577035085, 41.150535924094065, 40.15023503984724, 42.64361000061035, 43.46941382544381, 44.234952449798584, 47.76842062813895, 46.97645453044346, 48.590677397591726, 45.26836150033133, 45.9730339050293, 41.08413199016026, 38.818890707833425, 39.577717372349326, 41.962134156908306, 41.88786833626883, 41.49790416445051, 42.006981304713655, 43.14918524878365, 42.245200293404714, 44.738050665174214, 45.08478314535958, 48.68832043239048, 46.3175881249564, 47.58329629898071, 45.29888146264212, 47.00676257269723, 53.88534368787493, 57.81524133682251, 56.83833156313215, 58.149050167628694, 59.103426933288574, 57.07306950432913, 57.552314553942, 54.88233722959246, 56.289771284375874, 58.69485201154436, 54.65353652409145, 55.14652511051723, 55.996421813964844, 55.79932573863438, 55.492149353027344, 53.69796119417463, 51.57271221705845, 54.05050931658064, 53.92464617320469, 54.92837599345616, 49.8501113482884, 51.44759253093174, 50.150415965488975, 55.081983293805806, 48.0670542035784, 51.33777972630092, 54.39675542286464, 55.57553121021816, 55.179841722760884, 52.939985683986116, 51.057020391736714, 51.12493903296334, 53.863568033490864, 53.70363439832415, 56.73527935573033, 44.211946964263916, 45.79167897360665, 26.117505516324723, 19.00966337748936, 5.515846124717167, 2.7454256415367126, 0.3957145389701639, 0.020472358246999126, 0.11169895556356225, 0.08447416286383357, 0.04649144510871597, 0.09976617765745946, 0.03410169083092894, 0.037595599956278286, 0.02987363395680274, 0.07430278044193983, 0.13025315638099397, 1.1918427433286394, 39.175899573734824, 29.495544229234966, 48.72696283885411, 29.66712999343872, 52.375489711761475, 50.211858885628835, 0.9531517113958086, 2.1735261465821947, 22.05337735584804, 19.562107699257986, 38.22713695253645, 45.988458905901226, 44.58463096618652, 22.775925738470896, 24.837079320635112, 40.38243688855852, 135.806001663208, 83.77123423985073, 95.0783782686506, 96.82941464015416, 72.91777978624616, 73.96843079158238, 59.215522221156526, 53.64306695120675, 68.20450401306152, 69.87823472704206, 71.67890208108085, 62.08389145987374, 57.64701155253819, 68.02110631125313, 4.272747823170253, 0.30398591394935337, 0.166440039607031, 0.4197195880115032, 0.09316815741892372, 0.4898915897522654, 0.1669850525047098, 1.694387816957065, 1.1940676867961884, 3.7941324540546963, 7.195000341960362, 5.5436701859746655, 17.42924870763506, 59.742862701416016, 73.75503771645683, 85.70431341443742, 74.10187789372036, 73.85909393855503, 70.94398416791643, 67.7311510358538, 64.71001175471714, 68.57084083557129, 74.98417404719761, 70.78116008213588, 74.19235733577183, 69.68276105608258, 69.7133400780814, 69.01032829284668, 64.61734363010952, 63.63595921652657, 69.46608843122209, 69.72084413255963, 63.74498340061733, 64.25108323778424, 69.28345503125871, 62.64418724605015, 67.50234685625348, 67.77989264896938, 65.77690070016044, 67.89759513310024, 69.90845244271415, 68.05315835135323, 68.40448706490653, 60.468296323503765, 62.50500093187605, 64.10198184422084, 68.54672363826207, 63.36171381814139, 65.81871495928083, 56.16081271852766, 60.8248222896031, 67.76391179221017, 60.8971391405378, 68.50350584302629, 64.49001094273159, 60.564945765904014, 51.18373121534075, 49.82396527699062, 54.76245995930263, 53.071563720703125, 50.484155314309255, 46.82128388541085, 47.92978211811611, 44.474012170519146, 45.22414663859776, 46.69813401358468, 45.513111795697895, 45.81976359231131, 44.38051373617989, 46.02597223009382, 46.65728555406843, 46.6599189213344, 51.84052358354841, 49.8433507510594, 50.72886392048427, 48.16682686124529, 48.98700264522007, 43.819578715733115, 41.98198168618338, 41.59995583125523, 44.794800077165874, 43.91375112533569, 42.682012694222585, 45.15879883084978, 45.99650839396885, 43.90915489196777, 44.42196321487427, 46.77737821851458, 50.948656286512104, 48.00445440837315, 49.19372544969831, 47.02221884046282, 51.97338008880615, 56.714705739702495, 60.32145309448242, 58.329883984157014, 59.760886328560964, 61.22321115221296, 58.70606640407017, 58.8475456237793, 56.53958681651524, 58.930347306387766, 60.56199278150286, 57.534117221832275, 59.190807478768484, 61.027313641139436, 58.6699983051845, 58.175849369594026, 54.94838333129883, 54.16097525187901, 56.6145544052124, 56.32304620742798, 57.65257705960955, 53.449104513440815, 54.89942979812622, 55.06697171075003, 63.03555147988455, 53.79585436412266, 53.35260098321097, 58.343321800231934, 58.40864181518555, 58.797463008335654, 57.43507065091814, 57.35296031406948, 57.974348136356895, 60.58466475350516, 60.82511411394392, 63.97609438214983, 49.39467082704817, 53.03979308264596, 30.82306010382516, 27.495491368430002, 30.331871100834437, 5.167723136288779, 0.7511173124824251, 0.21175851140703472, 0.14427166272486958, 0.1772238202393055, 0.18200996198824473, 0.24064141299043382, 0.10893502458930016, 0.14607567020824977, 0.1431285347789526, 0.3536537545067923, 0.25123263895511627, 1.6089841425418854, 51.2703891481672, 38.669459274836946, 67.87176867893764, 41.08463226045881, 60.49988283429827, 62.15445041656494, 1.2798006406852176, 2.890615633555821, 33.88533272062029, 32.50772033418928, 66.87780107770647, 64.84330599648612, 48.556231703077046, 24.92956679207938, 37.4389819417681], [28.221889053072246, 69.34414754595075, 27.735172952924454, 54.227181162152974, 26.35208191190447, 16.960420744759695, 13.068130220685687, 15.668835742133004, 23.27616129602705, 39.79734298161098, 62.38966083526611, 48.37815632138933, 27.046206951141357, 43.49960374832153, 41.33411775316511, 0.600070911858763, 0.13072367970432552, 0.04446878989360162, 0.1806778348982334, 0.06017296721360513, 0.08431752305477858, 0.0632437045818993, 0.22945950872131757, 0.3545173667371273, 0.8913037329912186, 1.1470193713903427, 1.9149862825870514, 22.072587387902395, 18.476851190839493, 25.231733526502335, 59.221414293561665, 71.4399813243321, 67.3714427947998, 60.934923444475444, 58.18515648160662, 51.194129194532124, 57.69178227015904, 58.304835728236604, 63.83409404754639, 65.3478285925729, 64.09813949040004, 63.38715117318289, 62.611982345581055, 59.43687793186733, 57.796467304229736, 60.64004189627511, 60.45703329358782, 60.499271392822266, 52.633174078805105, 53.36519806725638, 58.04308319091797, 59.09145518711635, 57.27349029268537, 59.62559795379639, 58.795552253723145, 60.00929832458496, 59.15702533721924, 59.28244032178606, 56.93131930487496, 62.70637362343924, 60.906616483415874, 61.536637442452566, 59.381042207990376, 52.497892652239116, 55.64283146177019, 62.14522320883614, 55.25501080921718, 60.532935414995464, 59.308725357055664, 57.663600376674104, 45.84343957901001, 45.57138633728027, 51.07972363063267, 50.658926827566965, 46.551009382520405, 44.036369459969656, 44.7629634312221, 40.980711528233115, 39.8724946975708, 39.2955892426627, 41.638650349208284, 39.445058890751426, 39.053413254874094, 37.17465162277222, 38.389804703848704, 41.29340130942208, 42.256081172398154, 45.83394833973476, 45.226578508104595, 45.99833229609898, 44.879439558301655, 40.75670507975987, 38.21057939529419, 34.488036836896626, 36.29249095916748, 34.85540199279785, 38.7701803616115, 39.730348450796946, 38.9432669367109, 40.69245161328997, 42.45076274871826, 42.57087625776018, 43.22475733075823, 46.60157837186541, 45.08013480050223, 47.598672662462505, 46.58124794278826, 41.06733819416591, 46.300724846976145, 53.60209689821516, 57.189479623522075, 56.118164675576345, 54.98994745526995, 58.32546492985317, 54.59990337916783, 56.558406012398855, 51.80356611524309, 53.602822984967915, 52.7150308064052, 52.193019594464985, 54.53391286305019, 52.762042318071636, 51.772198472704204, 51.777156012398855, 53.410027844565256, 48.641305446624756, 50.700035844530376, 50.60055501120431, 45.394283703395296, 46.34670455115182, 42.5743989944458, 42.23676518031529, 44.522479329790386, 47.02664136886597, 46.029981340680806, 49.51713282721383, 46.865484850747244, 49.5023192678179, 46.14692299706595, 46.92480162211827, 46.84180538994925, 47.14927012579781, 43.30816698074341, 25.168510130473546, 20.938733441489084, 22.927021265029907, 14.098882453782217, 3.425195051091058, 0.4836985734956605, 0.12263092824390956, 0.14027103382561887, 0.03634667483025363, 0.16047321978424275, 0.048534785463873825, 0.025228841230273247, 0.017382438693727766, 0.050311580300331116, 0.060968298465013504, 0.07684616039374045, 0.23849984790597642, 1.3196416114057814, 32.496961048671174, 23.252235174179077, 45.78097179957798, 26.562348297664098, 46.908886773245676, 34.29688147136143, 2.409248777798244, 0.7246517868978637, 9.45327171257564, 4.151893028191157, 11.606116328920637, 4.266961710793631, 2.3593921959400177, 1.1402202333722795, 0.7296533499445234, 8.351712124688284, 76.77912998199463, 45.116748332977295, 54.74383183888027, 41.94142157690865, 33.42834275109427, 33.981085845402305, 35.299068791525706, 39.000315121241975, 47.787892954690115, 69.77769429343087, 52.810387883867534, 26.715217351913452, 48.97049372536795, 50.27209629331316, 0.7947565051061767, 0.22893956090722764, 0.2088267651519605, 0.05051697963582618, 0.03327638529507177, 0.09472825191915035, 0.23920905270746776, 0.16746992005833558, 1.0403244623116084, 1.032204515167645, 3.222395590373448, 2.0988254121371677, 25.282509224755422, 36.54657963344029, 50.771046434129985, 71.27170290265764, 67.89575386047363, 67.28872449057442, 61.58844321114676, 61.70588166373116, 57.782299927302766, 59.02159799848284, 63.04218700953892, 67.40348788670131, 68.38268361772809, 67.26908888135637, 67.92519337790353, 66.50221620287213, 62.9352194922311, 62.051686559404644, 62.33477701459612, 63.50982856750488, 63.05644471304757, 57.25559173311506, 56.37099225180489, 60.78809411185128, 62.38289328983852, 62.402619225638254, 62.101407868521555, 61.72159848894392, 61.26172501700265, 61.54685129438128, 59.92291137150356, 61.696786471775596, 66.24616813659668, 62.60130991254534, 62.670465333121165, 61.39662429264614, 55.64499582563128, 59.88992827279227, 63.10892445700509, 58.201206820351736, 64.2075388772147, 62.21763038635254, 59.05605411529541, 47.1272999218532, 49.81977203914097, 52.39799492699759, 53.931295599256245, 47.79223557880947, 45.98095137732369, 45.70626824242728, 44.28238780157906, 42.25459425789969, 42.461004393441335, 43.30277170453753, 41.74025385720389, 40.74527529307774, 39.72312579836164, 40.18063340868269, 43.47446863991873, 42.8087408883231, 46.862604822431294, 49.2576836177281, 48.871634755815776, 44.976224490574424, 43.64059659412929, 40.26271595273699, 37.14337778091431, 39.39039741243635, 37.104120458875386, 39.529747009277344, 40.93892158780779, 40.88071305411202, 43.29509741919381, 43.91624205453055, 44.275255475725444, 44.53827953338623, 46.82193354197911, 47.561551911490305, 49.39913851874215, 48.208797454833984, 43.92406225204468, 47.15676375797817, 53.733817373003276, 57.32751948492867, 59.23096806662423, 56.73826360702515, 58.74383681161063, 56.02654572895595, 58.23291492462158, 53.947655132838655, 55.64395359584263, 55.82304341452462, 56.34640952519008, 56.52027082443237, 55.86324916567121, 56.42335040228707, 53.434259687151226, 54.71154703412737, 51.230864320482524, 54.31130647659302, 53.99684490476336, 51.718030316489084, 53.23354360035488, 49.375563280923025, 45.9872464452471, 49.47491904667446, 50.202141829899375, 50.1270318031311, 52.18895142418997, 50.825482095990864, 53.26541151319231, 48.809840951647075, 51.40796348026821, 48.450712885175435, 50.923538548605784, 47.72416755131313, 37.40479680470058, 33.81693465369088, 25.439915452684673, 14.34273816858019, 1.135360836982727, 0.771885586636407, 0.2869923843869141, 0.14045611103730543, 0.15206870862415858, 0.10394264890679292, 0.1185189246066979, 0.13419962461505616, 0.03345488750242761, 0.1659287634704794, 0.09118089798305716, 0.2912510058709553, 0.2646206777010645, 1.789402152810778, 39.80213723863874, 28.344276360103063, 50.670082160404746, 27.734313113348826, 52.457391602652415, 47.86634159088135, 2.418979512793677, 1.6889256643397468, 19.664843763623917, 13.761186105864388, 28.106644494192942, 19.865405253001622, 10.013683012553624, 2.1873235319341933, 6.053475150040217, 59.19649805341448, 134.5991829463414, 74.51845714024135, 135.36700057983398, 47.328057697841096, 31.371873991830007, 48.79879331588745, 56.92680644989014, 51.23130553109305, 58.8569187436785, 81.09273147583008, 63.18137332371303, 40.192153521946494, 59.00870909009661, 63.59937695094517, 1.7371678756816047, 0.3119078645748751, 0.35583421321851866, 0.26028980580823763, 0.18968755858285086, 0.3081692180463246, 0.3191786929965019, 0.4849287303430693, 2.3618342706135342, 1.317779277052198, 5.709742988858904, 4.222910565989358, 29.68661274228777, 44.610193388802664, 59.83990819113595, 81.74518816811698, 74.45281750815255, 75.24037497384208, 65.5631880078997, 65.70593874795097, 62.62660830361502, 64.71285356794084, 66.72043827601841, 71.33659212929862, 73.12323107038225, 72.27835791451591, 70.77788053240094, 71.80117647988456, 66.72785200391496, 67.50803048270089, 65.24907384599958, 68.92982646397182, 67.17108454023088, 61.67069598606655, 60.72238499777657, 65.68490655081612, 65.80281748090471, 65.27667209080288, 65.99329539707729, 63.69509533473423, 64.63096904754639, 63.944368907383506, 64.23390729086739, 63.274270738874165, 67.7792603628976, 66.29452065059117, 65.34607764652797, 65.46651077270508, 58.228054659707205, 62.48737335205078, 67.29447759900773, 59.43710722242083, 65.92762797219413, 63.25785214560372, 64.70806625911167, 50.89170190266201, 50.602132252284456, 55.06822238649641, 56.35819019590105, 49.93767254693167, 48.27555922099522, 50.40675933020455, 46.216172218322754, 44.205710956028526, 44.29071869168963, 45.419126987457275, 44.996575764247346, 43.707862104688374, 41.34275436401367, 41.50349051611764, 47.61530317578997, 45.70248147419521, 50.61492735998971, 50.34373916898455, 48.92558404377529, 48.28903177806309, 45.60495655877249, 42.35791744504656, 39.88242367335728, 41.08957242965698, 39.6615890775408, 43.31809248243059, 44.843534742082866, 44.14413949421474, 45.99541057859148, 45.2459431375776, 45.83583130155291, 48.73493242263794, 49.15205710274832, 48.71682889120919, 52.787312916346956, 51.38777548926217, 45.30906752177647, 50.06752743039812, 57.65363665989467, 60.683627946036204, 59.74919945853097, 59.043985094342915, 61.34374850136893, 58.494632720947266, 61.164526666913716, 55.78343520845686, 58.256198338099885, 57.44383927753994, 58.79411397661482, 59.36950819832938, 58.1937062399728, 59.53067166464669, 55.721630981990266, 57.421695368630544, 52.96479075295584, 56.71341684886387, 57.980806486947195, 54.61952856608799, 54.73306907926287, 53.90702901567732, 54.983186858040945, 54.51118877955845, 52.26550667626517, 54.87684120450701, 56.67492035457066, 54.577478068215505, 57.62058407919747, 55.152743748256135, 57.35938739776611, 56.938260555267334, 61.25196279798235, 57.36255925042288, 47.15059723172869, 39.05033867699759, 29.334356444222585, 26.595397404262, 16.73930648394993, 2.209105917385646, 0.5533310313309941, 0.29689628151910646, 0.25013088807463646, 0.31746178226811544, 0.20328120701014996, 0.26798748703939573, 0.05843409230666501, 0.3274167595165116, 0.1610243802091905, 0.41558568126388956, 0.3099658159273011, 2.4547866199697768, 49.63957050868443, 35.65395498275757, 68.10361616952079, 37.061045101710725, 63.248569352286204, 62.2286502293178, 2.6755610704421997, 4.398871958255768, 35.72152621405465, 34.06112214497158, 51.54645150048392, 22.8847553730011, 6.683745375701359, 2.027049435036523, 11.04221877029964], [55.443664823259624, 50.05203294754028, 64.3847804750715, 25.12745496204921, 9.039893848555428, 3.3951238989830017, 8.181928549494062, 13.731397441455297, 22.431527853012085, 36.8050491469247, 62.96253286089216, 45.839437416621614, 40.81284999847412, 51.28516449247088, 37.806263719286235, 0.27997356387121336, 0.08870914418782506, 0.23719103527920588, 0.17937458625861577, 0.08936221378722362, 0.058327216255877695, 0.040279114352805276, 0.11359952536544629, 0.41002904943057467, 0.23851379858595984, 1.0122415806565965, 3.8519301755087714, 11.70433519567762, 10.464181627546038, 10.435079966272626, 35.16849824360439, 59.830354418073384, 60.22386564527239, 66.0198792048863, 59.371530124119346, 55.68736941473824, 51.227452754974365, 54.68978180204119, 58.436087199619834, 62.506293296813965, 61.219827379499165, 64.08390957968575, 62.886853081839426, 61.58167566571917, 58.24286127090454, 60.06130559103829, 60.91623279026577, 60.67968831743513, 60.657037190028596, 51.77042668206351, 50.95153284072876, 53.491200174604145, 61.041126659938264, 58.908717564174104, 59.41931288582938, 60.49573475973946, 57.80259214128767, 55.75332171576363, 57.930925369262695, 59.9610778263637, 59.928747858319966, 62.56779180254255, 53.6882997240339, 55.45687682288033, 58.43375955309187, 57.19697672980172, 60.00987502506801, 58.69929885864258, 59.22825132097517, 46.995391845703125, 42.61475760596139, 51.03011349269322, 50.57526356833321, 48.26946912493025, 43.11407600130354, 44.96629898888724, 43.09844255447388, 40.71172244208199, 39.138556480407715, 39.41378852299282, 39.85369982038225, 39.41435827527727, 38.489525250026155, 37.21369702475411, 38.07582950592041, 40.68460362298148, 40.171086583818706, 47.215010506766184, 43.91246223449707, 48.68614912033081, 43.56817552021572, 40.32056318010603, 39.60120228358677, 35.04913861410958, 35.945192200796946, 37.107146399361746, 36.13155330930437, 39.23365994862148, 40.59351968765259, 39.49751779011318, 40.99345799854824, 40.81461484091622, 42.8863696370806, 43.938465867723735, 48.876675673893516, 47.01845291682652, 47.67844145638602, 45.135192326136995, 40.99479900087629, 47.80460337230137, 51.5576936858041, 54.22532251902989, 55.85925742558071, 55.30350923538208, 52.60498176302229, 53.85824571337019, 54.86676631655012, 52.76935529708862, 53.58515024185181, 52.939864090510774, 52.326800210135325, 53.15878793171474, 52.514981746673584, 52.56496013913836, 51.715654032570974, 52.310610907418386, 48.39199365888323, 45.69766984667097, 49.394187927246094, 50.94530030659267, 43.67839132036482, 38.39743382590157, 40.68505872998919, 44.826150349208284, 47.405398096357075, 46.55084957395281, 45.086058139801025, 44.052541392190115, 42.18622398376465, 47.14980861118862, 42.26562452316284, 38.02731023515974, 28.87296305383955, 11.837360194751195, 17.571513073784963, 20.670301948274883, 10.299150620188032, 0.8016448840498924, 0.4127281531691551, 0.08138571573155266, 0.09580505306699447, 0.010681259079969354, 0.019656869416524256, 0.06256723909505776, 0.06123153612549816, 0.09578617622277566, 0.06867581845394202, 0.04617361930598106, 0.04962778663528817, 0.18014964966901711, 1.8472956291266849, 34.97485542297363, 23.277352912085398, 31.647283213479177, 60.04148932865688, 47.59514992577689, 23.949573755264282, 0.9459432810544968, 3.393739687544959, 10.55183836391994, 4.297843847955976, 0.6455166903989655, 0.9107832248721803, 0.2201689122510808, 0.021488059012751495, 0.416968752763101, 42.66643830708095, 67.04412705557687, 55.08786146981375, 63.49914223807198, 17.55339217185974, 11.403111679213387, 17.857526983533585, 33.52863999775478, 40.78823947906494, 44.31835862568447, 70.9198739188058, 51.691943304879324, 40.84958165032523, 60.57728576660156, 42.041006633213584, 0.3763912729918957, 0.39902253289307865, 0.1319561842828989, 0.3272756513740335, 0.11717439389654569, 0.04168695577287248, 0.05289098367627178, 0.10380246357194015, 0.18897952086159162, 0.17674303746649198, 1.4617641908781869, 3.9447958895138333, 20.412563732692174, 16.612324680600846, 24.38257680620466, 58.9204808643886, 68.49215248652867, 64.47582966940743, 68.83804076058524, 58.010287693568635, 57.93797779083252, 57.04681921005249, 60.920860290527344, 64.72416523524693, 66.91288948059082, 67.19802270616803, 66.00603839329311, 67.43153081621442, 63.29594217027937, 60.958213806152344, 61.58435072217669, 64.55021013532365, 65.00282968793596, 63.49684933253697, 57.650610719408306, 57.60246665137154, 55.687956537519185, 62.638969148908345, 60.6519650050572, 63.40356281825474, 61.452091761997764, 60.192723819187705, 57.75603921072823, 61.28015858786446, 60.9461030960083, 61.758055686950684, 63.19145515986851, 54.81383841378348, 58.360928535461426, 61.83506952013288, 60.523006439208984, 61.63926233564104, 60.66723019736153, 60.7158328465053, 48.1146354675293, 48.600985050201416, 54.07532133374895, 51.87540354047503, 50.95157452992031, 46.15537200655256, 46.752173628125874, 45.84835890361241, 43.01408100128174, 41.681117738996235, 41.60704299381801, 41.01724515642439, 42.610956941332134, 39.25122152056013, 42.25210680280413, 41.471726826259065, 40.57908827917916, 41.820335320064, 46.505047048841206, 45.260100092206685, 49.258013657161165, 43.53748880113874, 40.59010812214443, 41.876827648707796, 36.92422464915684, 37.94475868770054, 39.00056873049055, 38.242200647081646, 40.066186155591694, 42.65100983210972, 41.99570437840053, 42.90482405253819, 42.990477970668245, 44.7661908694676, 45.51068687438965, 48.7621693611145, 49.714840344020296, 49.41794034412929, 48.141816820417134, 42.87021507535662, 51.280189582279746, 54.11990097590855, 55.751668044498985, 57.35866478511265, 57.739123821258545, 55.516513211386545, 54.75521993637085, 56.51090465273176, 54.03740848813738, 55.971800872257774, 55.355255944388254, 56.90949501310076, 55.20274298531668, 55.10162932532174, 55.0063591003418, 53.44430678231375, 53.607169083186555, 52.284548214503694, 48.922776971544536, 53.0758125441415, 53.291227545057026, 52.316044398716514, 44.503458636147634, 47.17374168123518, 49.42967932564871, 50.65249626977103, 50.92396933691842, 49.62239803586687, 47.90946905953543, 46.92423186983381, 49.00053426197597, 46.11005238124302, 42.919783524104524, 35.86027479171753, 18.73855856486729, 18.578126396451676, 18.991542475564138, 13.339611973081317, 1.7753990356411253, 0.8384398839303425, 0.122230592582907, 0.06154537892767361, 0.1373180765658617, 0.016567872670878257, 0.04373408913878458, 0.07332280624125685, 0.053951099648007324, 0.05727372957127435, 0.09149043887321438, 0.07788841053843498, 0.25572676637342995, 2.956457197666168, 43.912604672568186, 28.914120708193096, 40.388923031943186, 57.30758857727051, 53.74504566192627, 40.02864851270403, 1.4980078403438841, 3.9772044590541293, 24.477018458502634, 16.166073151997157, 7.897387657846723, 3.3897939792701175, 0.5284556118505341, 0.582730162356581, 1.2779258212872913, 89.94180434090751, 108.76714938027519, 121.56024905613491, 97.38440200260708, 13.413441794259207, 6.787763816969735, 22.91770199366978, 59.35575076511928, 55.11239903313773, 55.66294649669102, 79.0069864818028, 58.604310035705566, 56.96121392931257, 68.40053353990827, 55.17679841177804, 0.5738345682621002, 0.45098903296249254, 0.8279186827795846, 0.2894208612186568, 0.3448911261345659, 0.6314111415828977, 0.275530679417508, 0.30060477395142826, 1.2662402540445328, 0.7318228163889476, 2.452058800629207, 4.862038007804325, 21.88011360168457, 21.480974333626882, 33.586824212755474, 70.17348452976772, 77.31883130754743, 72.82600797925676, 78.13585608346122, 64.82474040985107, 65.07404177529472, 64.10428864615304, 65.17586762564522, 70.2009368624006, 70.98700741359166, 71.50072247641427, 70.02310466766357, 71.99101516178676, 65.94875744410923, 64.77987589154924, 65.555572782244, 68.88564981733049, 67.68169375828334, 65.24310534340995, 60.4575127192906, 63.6731390271868, 59.31858485085623, 66.44623456682477, 62.64620222364153, 64.01200267246791, 65.33204228537423, 61.48392840794155, 61.40128653390067, 62.683507101876394, 64.40901579175676, 64.76106711796352, 68.02797807965959, 60.816553933279856, 61.87195750645229, 63.23964091709682, 62.020989418029785, 64.05287892477853, 65.04271929604667, 63.46105221339634, 53.04769318444388, 49.785774503435405, 55.48384278161185, 54.44648715427944, 52.00782925742013, 48.59260204860142, 49.82927370071411, 49.231937067849294, 44.92253228596279, 43.66586719240461, 43.74122040612357, 44.027055399758474, 46.04879011426653, 42.96435969216483, 44.71452406474522, 42.813041823250906, 44.48723806653704, 44.076613426208496, 50.367995330265586, 47.10419021333967, 52.04571083613804, 46.739302090236116, 43.50082663127354, 44.39839839935303, 36.72087172099522, 40.16773407799857, 42.048597540174214, 40.92747095652989, 43.53449065344674, 44.66100903919765, 46.14852108274187, 44.27205235617501, 45.094778129032676, 48.81125143596104, 48.74843624659947, 52.17960262298584, 51.12366056442261, 51.11949511936733, 49.116704668317524, 44.56463752474104, 53.52988427025931, 56.67487171718052, 57.37652860369001, 59.19942324502127, 61.72812979561942, 56.10311140332903, 59.34484904153006, 58.38214833395821, 56.19550507409232, 59.506735120500835, 57.37733806882586, 58.100423199789866, 57.41194357190813, 59.17361763545445, 57.63976805550711, 57.32485832486834, 57.70485530580793, 55.41211652755737, 51.977628912244526, 55.85421650750296, 55.34561879294259, 55.2510781288147, 52.505556515284944, 53.07608004978725, 52.93892955780029, 55.50876249585833, 54.368330342429026, 54.51389510290963, 54.8838415145874, 52.37436062949044, 56.41133001872471, 52.9082567351205, 56.994273458208355, 51.73693636485508, 35.61751862934658, 22.35315912110465, 29.326577935900005, 28.46771284512111, 6.491526935781751, 1.299678351197924, 0.20094920428735868, 0.18079899411116326, 0.2868543432227203, 0.11420935871345655, 0.20374157944960253, 0.24836645275354385, 0.17698017188480922, 0.18947711773216724, 0.11874161979981832, 0.32072697420205387, 0.3691406106310231, 3.9754608954702104, 54.38518667221069, 37.143256187438965, 47.7450156211853, 68.29884665352958, 64.58094201769147, 56.59492227009365, 2.1989443940775733, 9.057863627161298, 43.95519712993077, 40.15069362095424, 34.99876764842442, 5.2800416350364685, 1.4943293120179857, 0.7630052460091454, 1.4175580143928528], [61.05713530949184, 73.25664343152727, 77.08128629411969, 16.382575545992168, 1.4454004232372557, 3.710236430168152, 5.393301180430821, 12.998842784336635, 22.62410065105983, 48.70085498264858, 60.29992757524763, 30.526462350572857, 32.56493527548653, 39.53140762874058, 34.841255460466655, 0.10309455477233444, 0.12097153014370374, 0.3169903632785593, 0.23942675388285092, 0.34467342495918274, 0.09035062896353857, 0.13416272588074207, 0.10374337674251624, 0.229284473827907, 0.44582643998520716, 0.09854727092065982, 4.837321962629046, 15.098188877105713, 8.792709078107562, 9.588467155184064, 20.460685219083512, 29.322829382760183, 34.282529967171804, 46.83276925768171, 59.504907744271414, 59.695448194231304, 56.474523884909495, 49.71128634044102, 51.71009199959891, 56.81974513190133, 58.96745763506208, 60.66269997188023, 62.242296491350444, 59.061612674168174, 58.18617786679949, 56.34107330867222, 61.32399477277483, 60.90314933231899, 61.38972473144531, 60.84565298897879, 57.29495675223214, 54.70435217448643, 53.4497263772147, 55.842018944876536, 58.998759269714355, 59.335378646850586, 56.015605790274485, 58.76759965079171, 59.72846603393555, 58.5081330708095, 59.89318697793143, 56.151547295706614, 51.853054659707205, 59.33262021200997, 59.71307577405657, 61.24334008353097, 59.92075742994036, 57.1927661214556, 50.89719097954886, 45.30593735831124, 53.4910820552281, 51.83128942762102, 47.75867230551583, 45.528880732400076, 45.955128397260395, 43.00601066861834, 43.237222399030415, 42.239412443978445, 40.63927010127476, 40.57139662333897, 43.46186113357544, 38.32051726749965, 37.36814158303397, 36.53132833753313, 38.57921607153756, 38.718027182987754, 39.16371938160488, 42.77750178745815, 43.21613114220755, 46.564033780779155, 39.2425536428179, 37.95974595206124, 38.90331826891218, 36.64021703175136, 34.081066949026926, 35.41334581375122, 37.31130184446062, 39.7324607031686, 42.79476458685738, 39.29815312794277, 40.71736785343715, 41.56817477090018, 40.95235592978341, 42.538608823503765, 43.34915787833077, 48.33933673586164, 47.484555448804585, 48.41727467945644, 44.153540406908306, 44.960910660879954, 49.980473450251985, 49.40627779279436, 54.75133241925921, 55.07051529203142, 54.10626861027309, 52.92861148289272, 53.140330042157856, 53.18462480817522, 54.578968456813264, 51.31400646482195, 54.57344811303275, 50.11750929696219, 51.45202200753348, 53.7501734324864, 50.053030014038086, 46.652154309409006, 48.02273859296526, 47.13815300805228, 47.04027026040213, 49.50914239883423, 44.856003284454346, 37.69400862285069, 41.05383089610508, 44.48154749189104, 46.330737590789795, 42.45627267020089, 41.38416910171509, 38.425487177712576, 38.66173982620239, 36.24980470112392, 31.052885668618337, 21.927769558770315, 2.580046138593129, 9.103262288229805, 16.61269988332476, 10.426239252090454, 3.531764132635934, 0.23605519479938916, 0.08801238371857575, 0.05495486667911921, 0.13117137710962976, 0.0119868435763887, 0.04622814298740455, 0.03267961713884558, 0.02140223790359284, 0.021975847659632564, 0.07855467764394623, 0.03885615856519767, 0.054997115662055354, 0.1351658720523119, 2.410390019416809, 33.67465986524309, 25.263528483254568, 40.62356717245919, 45.83476822716849, 47.14052929197039, 16.158549989972794, 0.41542668693831986, 4.34335150888988, 10.893787877900259, 7.132411403315408, 7.015563547611237, 4.543288963181632, 0.13691334399793828, 0.580705848123346, 4.787302315235138, 78.33213574545724, 40.385723386492046, 61.9483460017613, 19.360552617481776, 4.940075397491455, 4.6281455755233765, 9.778356211526052, 25.405283893857682, 38.903019496372764, 54.29482534953526, 66.93606867109025, 39.88757576261248, 32.14323173250471, 52.84232875279018, 38.85284308024815, 0.5724715813994408, 0.4714220293930599, 0.11942479599799428, 0.3869716966790812, 0.13893328846565314, 0.23202328543577874, 0.05584754395697798, 0.17921519838273525, 0.07964444559599672, 0.43412551070962635, 0.13818977693361895, 5.182425090244838, 14.599815436771937, 10.91995392526899, 16.35546714918954, 42.75941562652588, 53.01794794627598, 47.49819476263863, 57.482631070273264, 60.22452572413853, 59.49843897138323, 57.8443021774292, 53.63132796968733, 58.16878652572632, 62.294908251081196, 66.08503246307373, 66.0516255242484, 67.07021754128593, 62.30183560507638, 61.66725662776402, 60.17585359300886, 64.81666660308838, 65.75303363800049, 65.24011066981724, 63.46270588466099, 60.95526776994978, 57.914159366062705, 58.82528359549386, 56.567685331617085, 59.57981627328055, 59.505553926740376, 58.483939443315776, 61.38523619515555, 61.94266932351248, 60.14190469469343, 62.333623613630024, 58.26123578207833, 56.62218352726528, 62.34214210510254, 60.63460145677839, 62.97967406681606, 61.85590716770717, 59.854992730276926, 51.645022119794575, 47.5254282270159, 57.213773999895366, 53.97696958269392, 52.35885572433472, 48.52542686462402, 48.39258425576346, 44.918113231658936, 45.53218807492937, 44.911759104047505, 43.57424129758562, 43.37796858378819, 47.22026334490095, 40.84449904305594, 39.79972621372768, 38.959421498434885, 41.316139289310996, 40.51518569673811, 39.19749110085623, 43.65235989434378, 43.60145391736712, 45.8085526738848, 40.97830397742135, 37.7260502406529, 40.809455803462434, 37.976508481161936, 37.00960063934326, 38.964615276881624, 40.167105266026084, 42.582257407052175, 44.249032974243164, 41.51348549979073, 42.649477754320415, 42.90786041532244, 42.602966512952534, 44.45931673049927, 44.83777468545096, 48.66006210872105, 49.90385219029018, 51.416002546037944, 47.65631839207241, 46.43252175194876, 51.386788845062256, 51.049585819244385, 55.20581408909389, 55.07487876074654, 56.839200087956016, 56.58765098026821, 54.70401866095406, 55.12858138765608, 55.962594509124756, 52.979441029684885, 57.23468460355486, 51.904943806784495, 53.43950210298811, 55.12691729409354, 50.47922904150826, 49.081407819475444, 52.86657796587263, 50.743048667907715, 50.54170724323818, 50.30483967917306, 50.422653334481375, 47.64752197265625, 45.074704783303396, 48.711982522692, 49.85185187203543, 46.46187441689627, 45.564528465270996, 42.87497459139143, 43.4887888772147, 39.340057713644846, 34.733645234789165, 23.577890293938772, 4.604318031242915, 10.133461271013532, 18.946344443729945, 11.009206141744341, 2.1800615787506104, 0.5904573734317506, 0.09965255696858678, 0.043395679976258955, 0.08567069830106837, 0.018779194547927806, 0.006648724615973021, 0.018233952644680227, 0.029937942113195146, 0.048007139669997353, 0.04715771899957742, 0.03852814116648265, 0.023831891993592893, 0.19986088840024813, 4.078666831765856, 44.928340979984824, 31.5611081804548, 42.89490549904959, 53.53402887071882, 53.27999578203474, 28.90291326386588, 0.09413779074592249, 6.892833173274994, 22.019563947405132, 22.47385106767927, 17.430384738104685, 8.792789850916181, 0.25351346656680107, 0.29632576927542686, 0.2699125994529043, 102.23725318908691, 119.98992838178361, 159.71282141549247, 47.961247035435264, 6.015208380562918, 8.117116621562413, 20.569323778152466, 49.12435463496617, 47.92190286091396, 67.05014419555664, 77.4989355632237, 43.522022111075266, 44.582178252083914, 60.05164759499686, 48.75738205228533, 0.6045389292495591, 0.5240752069013459, 0.8505244297640664, 0.35217441245913506, 0.51380441231387, 0.45081321096846033, 0.4271130141402994, 0.2475049846938678, 0.5392346020255769, 0.6790287207279886, 0.43556215933391024, 5.884799378258841, 21.25459681238447, 24.614589316504343, 35.763840743473594, 56.75406381062099, 58.872934341430664, 56.90851184300014, 65.92839922223772, 70.4205902644566, 65.82279355185372, 63.49232605525425, 59.5312831061227, 62.79579693930489, 67.59361839294434, 69.81153896876744, 71.48627022334507, 68.74403858184814, 66.08087744031633, 65.60726737976074, 63.80039528438023, 69.19568538665771, 70.01082025255475, 68.21349498203823, 67.01732785361153, 62.15266472952706, 60.71741703578404, 62.35214056287493, 60.85078075953892, 63.99709183829171, 63.30249432155064, 60.32296085357666, 65.6461147580828, 64.39043630872453, 60.46337005070278, 66.42972564697266, 60.84920351845877, 59.17539637429373, 63.7585323878697, 63.98230607169015, 66.42405591692243, 64.70718383789062, 62.247570174080984, 56.60540362766811, 48.258869647979736, 61.01661341530936, 56.520451477595735, 53.93825422014509, 48.64605106626238, 52.45502574103219, 48.10643311909267, 48.853694507053916, 46.11500992093767, 45.943472794124055, 45.47558110100882, 48.797184807913645, 43.245084285736084, 40.632130827222554, 41.90151112420218, 42.803977898189, 43.37100648880005, 41.454113142830984, 46.31062602996826, 46.715379442487446, 49.55458014351981, 43.202140944344656, 39.58685425349644, 44.612701688494, 39.96577773775373, 39.71802234649658, 41.37870781762259, 42.15893840789795, 45.1169741494315, 48.032559871673584, 44.50496986934117, 44.31676401410784, 45.18994413103376, 45.11218684060233, 45.85245486668178, 46.95012780598232, 53.021536690848215, 51.88865722928728, 52.19143887928554, 48.84915733337402, 50.894460337502615, 54.31595829554966, 54.07466125488281, 57.424842902592246, 59.045597076416016, 59.46892997196743, 57.40045819963728, 55.26369605745588, 56.94553184509277, 58.220363003867014, 53.36919675554548, 59.66045706612723, 54.54811845506941, 56.97092056274414, 58.15205873761858, 53.34285266058785, 54.253910882132395, 56.16400194168091, 52.72653702327183, 52.35493346623012, 53.51443495069231, 52.09924670628139, 51.854690960475374, 52.22608259746006, 55.77108131136213, 53.717068740299766, 52.87135137830462, 51.83078915732247, 49.378255707877024, 50.233426094055176, 47.49109022957938, 46.336303097861155, 42.79951368059431, 25.448569434029714, 17.31499774115426, 26.354477303368704, 19.71288013458252, 9.681525247437612, 1.8889337948390414, 0.18805972593171255, 0.23237514655504907, 0.2241231972085578, 0.15429633909038135, 0.200692405924201, 0.14367153921297618, 0.11284910634692226, 0.13484693345214638, 0.1611042030687843, 0.1547930131533316, 0.18976548154439243, 0.3104856280343873, 5.713819410119738, 60.425745555332725, 39.79692261559622, 58.24214908054897, 54.23586988449097, 63.12027781350272, 56.9562702860151, 1.7509171664714813, 9.62370320728847, 44.12098809650966, 44.093744209834504, 42.06409897123064, 11.114506959915161, 0.5196241257446153, 0.6998869414840425, 5.752300705228533], [54.112737383161274, 72.82562582833427, 21.60429617336818, 7.813262343406677, 0.777193087552275, 0.34444584431392805, 3.6263803584235053, 12.439130646841866, 23.167258705411637, 58.091758796146934, 43.06327077320644, 45.94050938742501, 80.36194774082729, 45.21234164919172, 28.335313183920725, 0.33392461602176937, 0.376926989959819, 0.11158031371555158, 0.8218117047633443, 0.37781369952218874, 0.11825901855315481, 0.07998918888292142, 0.03964193604354348, 0.04225673519873193, 0.06003063092274325, 0.018183303398213217, 2.189148736851556, 23.97987311226981, 26.456247568130493, 21.30596658161708, 20.55197238922119, 20.476195335388184, 17.672114304133824, 26.80290014403207, 47.9598365511213, 62.55223478589739, 56.742627075740266, 52.63998678752354, 52.079927240099224, 50.93830347061157, 56.57045766285488, 56.767202854156494, 61.76236357007708, 62.40168121882847, 58.26288945334298, 56.290500845227925, 58.15933002744402, 57.97156538282122, 59.49115031106131, 59.53853702545166, 56.98592519760132, 60.64843532017299, 56.012791769845144, 50.61546237128121, 51.81792804173061, 53.82472760336739, 50.95593452453613, 57.577515670231406, 55.55819198063442, 58.1458956854684, 57.53214045933315, 56.14112499782017, 59.04374885559082, 57.85800402505057, 56.57382753917149, 58.819176128932405, 59.10372570582798, 52.87277575901577, 44.97007533482143, 53.41704205104283, 54.93037707465035, 53.33001586369106, 49.95523064477103, 46.50633941377912, 45.64595093045916, 43.17217683792114, 43.471991607121055, 41.569922242845806, 40.325611046382356, 44.93202699933733, 43.563773836408345, 38.40470511572701, 37.29158633095877, 38.53653676169259, 39.30777290889195, 36.544630663735525, 38.230048247746055, 38.14755228587559, 40.27628231048584, 38.89166613987514, 36.98378460747855, 35.026334626334055, 38.81524985177176, 37.3669638633728, 35.3348068509783, 35.52730321884155, 38.86713205065046, 42.3621141569955, 46.07507862363543, 39.857542174203054, 39.82674428394863, 41.42886338915144, 41.970468521118164, 42.385192598615376, 46.49504164287022, 45.92847858156477, 48.80699566432408, 49.54688501358032, 51.484991209847585, 43.54144927433559, 46.50790623256138, 48.22974279948643, 51.246282373155864, 52.212571825299946, 53.94978822980608, 54.043338775634766, 53.4705570765904, 53.51481015341622, 55.04234382084438, 48.44784675325666, 49.85104588099888, 49.545061111450195, 51.29413461685181, 51.08983325958252, 49.15334251948765, 44.525394099099294, 47.47583545957293, 47.3715568951198, 46.0242143358503, 46.168792452131, 41.892718178885325, 41.37672758102417, 34.42722272872925, 36.721552644457134, 39.35365881238665, 36.43016256604876, 33.34542294910976, 30.29886715752738, 30.291001796722412, 24.649505751473562, 11.822847144944326, 2.1398139212812697, 3.451866362776075, 4.6709369250706265, 4.382767336709159, 3.0559920966625214, 0.11242201605013438, 0.041325445885636976, 0.038651067963136096, 0.04091553948819637, 0.018801850832200477, 0.06422249813164983, 0.06811733663614307, 0.04813181030164872, 0.017664446329165782, 0.026768343889021447, 0.06411364075860806, 0.05561671991433416, 0.028870715094464164, 0.019548904317032014, 1.0697961151599884, 26.91064064843314, 25.35316024507795, 44.41917698723929, 35.15532445907593, 46.13260970796858, 8.97081138406481, 0.3664121670382363, 4.1562899351119995, 18.06713502747672, 10.579464401517596, 21.693905353546143, 17.4289516721453, 0.15600444243422576, 0.85478568396398, 12.927292840821401, 85.09218406677246, 55.567783968789236, 48.425501346588135, 16.4329708303724, 3.020417971270425, 1.0875491968223026, 7.16808910029275, 28.253275803157262, 37.61619574683053, 65.36660957336426, 54.3907903943743, 43.65584094183785, 65.47516822814941, 51.7363874571664, 35.04569230760847, 0.9923580076013292, 0.5818528980016708, 0.17231292304183754, 0.4415178511823927, 0.10907912507121052, 0.08391471074095794, 0.0595085932207959, 0.012352216024217861, 0.07385621619011674, 0.024964514521083662, 0.045752873311617544, 3.6290899387427737, 26.5900160244533, 25.706041881016322, 24.379728044782365, 34.943480832236155, 31.03848900113787, 30.11843286241804, 39.250815050942556, 55.632930278778076, 64.10011277879987, 60.516523769923616, 58.383009910583496, 53.84396021706717, 55.396219049181255, 60.976042883736746, 60.327477182660786, 66.41901847294399, 65.75522926875523, 61.22083486829485, 59.70988655090332, 60.92559201376778, 61.03008597237723, 64.23803452083042, 61.660864285060335, 59.84772491455078, 61.019045284816194, 58.59515230996268, 55.42271253040859, 57.16592870439802, 55.36708525248936, 56.94160263878958, 59.718808037894114, 57.60579831259591, 60.48634079524449, 58.882863317217144, 56.91930586951119, 62.163663727896555, 58.07356146403721, 59.375990867614746, 60.41382939474923, 60.59582356044224, 53.40487575531006, 48.18413482393537, 55.01531532832554, 58.9164856501988, 55.731004101889475, 51.570912633623394, 46.97615575790405, 47.030660901750835, 45.656442710331504, 45.08815649577549, 44.318115438733784, 43.30667311804635, 47.290867464882986, 46.68284797668457, 39.91610506602696, 40.36562919616699, 43.72742823192051, 39.6806514603751, 37.4797921861921, 39.49446405683245, 39.649791036333355, 41.25896256310599, 40.509290150233674, 38.84125695909773, 36.9247144971575, 39.635873794555664, 38.5328368459429, 38.03229556764875, 38.386674540383474, 42.00062370300293, 46.527854510716026, 48.70459311349051, 42.95679310389927, 42.23102944237845, 42.94556481497628, 43.94946139199393, 44.07378898348127, 48.53035661152431, 47.429338114602224, 49.65117400033133, 51.925541741507395, 56.30229193823678, 47.43260029384068, 48.783625398363384, 52.13483885356358, 53.207161290305, 54.236123493739534, 55.98886912209647, 55.70030001231602, 55.722332750047954, 55.213363306862966, 55.485993249075754, 52.36877427782331, 51.7009516443525, 52.76905999864851, 52.75533035823277, 52.58795172827584, 49.58121953691755, 48.221377168382915, 51.7333128792899, 50.85964986256191, 48.720334257398335, 50.3272510937282, 46.253056730542866, 48.5481961114066, 41.25720466886248, 41.98477486201695, 42.38066584723336, 40.54017489297049, 38.588922704969136, 36.62139088766915, 33.16188975742885, 26.510563373565674, 9.766143015452794, 1.3104417622089386, 4.320297385965075, 2.901732099907739, 2.071108179433005, 0.7082296652453286, 0.15150078838425024, 0.04223965307963746, 0.076081790695233, 0.038504769027765305, 0.10461759447519269, 0.027497884385021668, 0.056693595701030323, 0.015703778680680052, 0.03603321200768862, 0.008776243177375622, 0.01756318854833288, 0.007027197030505964, 0.03684878735137837, 0.02915934014267155, 3.8471897670200894, 39.73685891287667, 31.548535415104457, 44.78236974988665, 38.788579191480366, 53.99021979740688, 21.01353427342006, 0.41698077640363146, 5.680334738322666, 29.200145040239605, 21.162736415863037, 37.56204496111189, 29.151184558868408, 0.03031764013160552, 0.1554265884416444, 9.080456563404628, 94.04876640864781, 106.2041187286377, 110.56068093436105, 17.167781046458654, 3.0227579942771365, 0.252486951649189, 27.73478385380336, 48.82263258525303, 55.44461325236729, 79.85131072998047, 57.77865212304251, 58.32659748622349, 90.8574310030256, 60.82129260471889, 42.76244504111153, 0.9096178274069513, 1.3228460337434496, 0.5821004275764737, 1.6025934283222472, 1.340425084744181, 0.1990042786513056, 0.2182289127792631, 0.12490543190922056, 0.1645960799817528, 0.24677702518446104, 0.15856451434748514, 3.586723732096808, 29.676610810416086, 40.55007955006191, 55.13221876961844, 53.25741761071341, 41.31684800556728, 37.548520292554585, 48.814746379852295, 64.97553021567208, 71.37452929360526, 67.86484827314104, 65.91641357966832, 60.79836354936872, 63.67104761941092, 65.817505972726, 64.6942949295044, 69.69839450291225, 68.66834490639823, 66.0392507825579, 64.00506142207554, 65.42623901367188, 63.547279357910156, 67.48938151768276, 64.15632370540074, 63.872184072222026, 65.00004346030099, 62.050255230494905, 55.34693547657558, 58.29883943285261, 61.03825010572161, 57.48684515271868, 62.975699697222026, 58.285551003047395, 62.63441113063267, 63.38962473188128, 61.774126870291575, 64.46239880153111, 62.05906554630825, 60.414489473615376, 65.11406339917863, 65.60152121952602, 58.92945793696812, 49.8112222807748, 57.21435070037842, 60.12100451333182, 58.829244068690706, 55.155727999550955, 50.32945367268154, 49.8154467855181, 48.15517125810896, 48.16959571838379, 47.34333331244332, 47.401368141174316, 50.5316219329834, 49.86010980606079, 41.28780106135777, 44.0611641066415, 45.88989870888846, 40.825520038604736, 37.740158557891846, 39.92924758366176, 40.78094734464373, 44.383004665374756, 42.382225717817036, 39.25609220777239, 37.91398859024048, 42.02805866513933, 39.062331267765586, 40.72826957702637, 40.5805196080889, 45.34453460148403, 46.33851957321167, 50.1584689276559, 43.775572299957275, 42.731893811907085, 47.48821367536272, 48.10260813576834, 47.38790948050362, 50.879386220659526, 49.1044202532087, 53.23086506979806, 54.25502954210554, 57.65623876026699, 48.47599390574864, 51.546277795519146, 52.08469370433262, 56.70935910088675, 56.40313809258597, 58.809768268040244, 56.913177558353965, 57.2551713671003, 57.05871800013951, 58.4280481338501, 53.297519138881135, 52.53382526125227, 53.882074560437886, 54.774629729134695, 55.762722628457205, 54.168159689222065, 52.20831257956368, 53.340962750571116, 53.31023781640189, 50.81274604797363, 55.10744844164167, 50.63613326208932, 53.87124579293387, 49.2244017464774, 49.66438947405134, 53.66028458731515, 49.49230343954903, 46.90114648001534, 47.825889178684776, 44.74947002955845, 38.75689540590559, 18.345898491995676, 6.482594592230661, 9.652064885411944, 8.389162046568734, 4.778961871351514, 4.38703396490642, 0.48353067679064615, 0.11227024133716311, 0.2278259220932211, 0.10553114009754998, 0.2253475593669074, 0.10729425906070642, 0.14447086703564438, 0.12968849310917513, 0.10255714146686451, 0.10345943697861262, 0.224892615207604, 0.15978460173521722, 0.23432840460113116, 0.1710028483399323, 7.283631128924234, 58.27394751140049, 38.601526737213135, 61.21794441768101, 47.1095472744533, 62.09124265398298, 47.23993716921125, 0.46930999415261404, 7.691844310079302, 54.55415643964495, 38.2798181942531, 57.079211711883545, 34.94057648522513, 0.6098447473985809, 1.0536344966718127, 18.639614479882376], [67.24135862077985, 61.102646010262625, 10.467769503593445, 3.0406917291028157, 1.0096841007471085, 4.020053999764579, 5.612100388322558, 7.763623544148036, 33.17969799041748, 58.33656815120152, 34.938422543661936, 74.3661526271275, 96.4108065196446, 39.93116528647286, 25.3137309551239, 1.4485739043780734, 0.39051544080887524, 0.12291471873010908, 0.27967340712036404, 0.055150987048234255, 0.052413634290652614, 0.09680600757045404, 0.16569268756679126, 0.11757481098175049, 0.1466837597212621, 0.10480932133006197, 1.2323207770075117, 18.782358271735056, 49.14089829581124, 53.110751560756135, 31.50008910042899, 21.722733429500035, 17.943842717579432, 19.74082578931536, 43.8705541746957, 63.38140501294817, 63.14937686920166, 50.71242448261806, 51.551037311553955, 46.52239670072283, 49.89099454879761, 53.769576277051655, 58.45648711068289, 60.06342479160854, 59.34537015642439, 55.19726085662842, 54.16324731281826, 57.57896089553833, 58.9673673084804, 59.72010040283203, 58.154601778302876, 56.03215639931815, 55.61971827915737, 56.495490074157715, 54.35715763909476, 52.06869895117623, 53.63566711970738, 54.47262280327933, 57.52928474971226, 59.74831008911133, 53.92259298052107, 55.24194472176688, 59.27791009630476, 57.09768697193691, 56.67340564727783, 59.92327267783028, 55.71552698952811, 44.13834817068917, 54.52787487847464, 55.01821967533657, 56.825977666037424, 50.39302968978882, 48.611994470868794, 47.15238291876656, 44.61195475714547, 42.106496879032676, 42.145736830575125, 41.224985871996196, 47.357702187129426, 48.54975945608956, 43.89207969393049, 37.621889795575825, 36.99716683796474, 38.96046372822353, 37.25609840665545, 38.78758559908186, 40.206543241228374, 37.36743981497628, 38.87997579574585, 37.945550782339915, 38.57381384713309, 35.64075687953404, 36.271055766514365, 39.49030555997576, 35.477328300476074, 31.98002896990095, 40.62415429524013, 45.05972794124058, 50.23357548032488, 45.58954545429775, 41.66602625165667, 40.687011173793245, 38.702765464782715, 39.28094244003296, 42.37470429284232, 47.12794957842146, 48.044479506356375, 48.672165870666504, 51.78369426727295, 53.14179263796125, 44.07716580799648, 48.585111890520366, 51.385826519557405, 49.895021029881065, 52.11189590181623, 53.990146841321675, 53.904882022312705, 49.13999155589512, 54.32006468091692, 53.07886280332293, 51.335122040339876, 49.7357439994812, 50.07987437929426, 48.819189752851216, 45.935867990766255, 39.85878937585013, 44.716816970280235, 47.18836416516985, 44.23159646987915, 43.90410007749285, 40.32692425591605, 33.394835063389365, 33.621725014277864, 35.53775330952236, 30.780554498944962, 30.570941243852886, 32.39997809273856, 29.527335711887904, 17.344239234924316, 6.776984555380685, 0.9089294129184314, 0.18891280729855808, 0.21066246022071156, 0.02486216090619564, 0.36109997066003935, 0.06355327939880745, 0.03646979500938739, 0.01621324652140694, 0.03447136688711388, 0.026880381894963126, 0.040831618277089934, 0.04683784741376128, 0.07597510463425092, 0.022727045297090496, 0.051401144691876004, 0.011428257433830627, 0.07913509649889809, 0.050236710746373446, 0.07906870863267354, 0.059306559418993335, 1.341553298490388, 19.675999096461705, 23.643832172666276, 41.44679321561541, 43.30868114743914, 41.02971369879586, 5.727491293634687, 0.3284908261682306, 1.8387024445193154, 14.448991758482796, 10.466464110783168, 36.42556980678013, 40.26587738309588, 0.6204586092914853, 0.21856549328991345, 22.53941079548427, 79.6728879383632, 70.49663829803467, 19.526157719748362, 5.135430080550058, 1.5482260542256492, 4.999880714075906, 2.64670216185706, 23.11427000590733, 44.16967064993722, 74.17128344944545, 43.45847388676235, 68.84054906027657, 97.0858518055507, 47.072739192417686, 33.076225417000906, 3.900422087737492, 0.4174185943390642, 0.28662651830485886, 0.32511820857013973, 0.06960786094090768, 0.03435771905684045, 0.06615941026913268, 0.04286431581048029, 0.19081451025392326, 0.03644688427448273, 0.13438780951712812, 1.499691584280559, 22.873759848730906, 52.55419043132237, 55.59444420678275, 42.444349561418804, 31.210533346448624, 24.817481926509313, 32.58818047387259, 51.13728945595877, 63.399776050022666, 61.6249976839338, 57.901642186301096, 57.40178183146885, 50.514056886945454, 58.238438742501394, 60.82268919263567, 62.73955821990967, 64.70394597734723, 62.46058804648263, 59.597555024283274, 58.18792881284441, 60.659052167619976, 61.32170186723982, 61.167208671569824, 60.17460986546108, 60.66654927389962, 57.300063678196494, 59.05838871002197, 57.83377913066319, 55.699824060712544, 55.01635755811419, 58.2272903578622, 59.01706082480294, 63.65990270887102, 57.027398994990754, 59.83996377672468, 61.835868562970845, 61.08947222573416, 60.63472652435303, 63.496606145586284, 56.821141719818115, 46.36524929319109, 58.733511788504465, 57.20138536180769, 59.05231598445347, 51.0279769216265, 49.467310769217356, 49.18181276321411, 46.41073914936611, 44.8381290435791, 44.519442967006135, 45.33115584509713, 52.21424286706107, 53.14466919217791, 45.79151569093977, 39.41076258250645, 38.60783570153372, 41.66756180354527, 38.146638597760884, 38.69405242374965, 39.82901981898716, 38.91602305003575, 38.82688113621303, 38.36499963487898, 39.78582981654576, 35.95411368778774, 35.56115484237671, 38.78472294126238, 38.185371330806184, 36.99892125810896, 42.17529099328177, 48.50746577126639, 51.38889067513602, 48.76112365722656, 42.6174430847168, 43.22591420582363, 41.377116680145264, 41.27660403932844, 44.01847784859793, 48.13168287277222, 50.10126093455723, 51.3684594971793, 54.71511493410383, 58.101680823734824, 48.43517671312605, 49.589300291878835, 55.65693630490984, 52.411283356802805, 55.69259793417794, 55.31124258041382, 57.29373386928013, 52.82530914034162, 52.266868523189, 56.41702406747, 53.2786408833095, 53.24779435566494, 52.81353194372994, 51.4088146345956, 48.776645932878765, 45.103275775909424, 47.14448629106794, 50.407947472163606, 47.44901541301182, 46.56480850492205, 43.38740423747471, 39.49661452429635, 38.54825837271554, 39.37966591971261, 38.47805724825178, 37.08147627966744, 35.43555225644793, 30.498183182307653, 18.048746619905742, 6.750726010118212, 0.6741623218570436, 0.2284306325018406, 0.2755193885947977, 0.18145517818629742, 0.09686940988259655, 0.11510908257748399, 0.02162546574670289, 0.06272801796772651, 0.014620735010664378, 0.010194123523043734, 0.04522399936935731, 0.028089365057115043, 0.021426132514274547, 0.06653419230133295, 0.016859306854062846, 0.04430196527391672, 0.06846838351339102, 0.037806827907583544, 0.06897231790104083, 0.043425633904657195, 4.85405843598502, 36.01044620786394, 31.723605700901576, 46.45015975407192, 49.867478370666504, 51.89400386810303, 15.63245323726109, 0.4676629453897476, 2.136403441429138, 24.59308464186532, 22.04300890650068, 52.76702765056065, 55.62752110617501, 1.1407523133925028, 0.5923732849104064, 26.341308729989187, 98.8949751172747, 104.50376946585519, 38.70055593763079, 4.245259881019592, 4.212991578238351, 7.46332848072052, 23.309003693716868, 43.83816167286464, 56.26026575905936, 86.44146169934953, 49.240076882498606, 83.01153210231236, 108.34144714900425, 52.2267461504255, 41.92145940235683, 3.6072365513869693, 0.7013719560844558, 0.4526297577789852, 0.6645991035870144, 0.4337908572384289, 0.13319617988807814, 0.15549484906452044, 0.23184236085840634, 0.33994680430207935, 0.2146671467593738, 0.22906994819641113, 1.203095133815493, 23.972652196884155, 54.42598649433681, 67.58418273925781, 62.590484619140625, 48.974527154650005, 34.706522941589355, 44.82419443130493, 62.34436552865164, 73.05900192260742, 68.93139675685337, 66.7902329308646, 67.8920852116176, 58.007174900599885, 66.73434856959751, 65.37223066602434, 66.35005760192871, 67.68938541412354, 66.61127512795585, 61.37072140829903, 61.27126489366804, 62.145285742623464, 64.59190627506801, 64.25597476959229, 61.92430523463658, 62.21293340410505, 58.78670024871826, 61.7532753263201, 59.76669502258301, 57.24123328072684, 58.02182517732893, 58.72136633736746, 61.19300038473946, 65.94433144160679, 59.47024318150112, 60.31853485107422, 64.24200194222587, 63.449434825352256, 63.03101430620466, 68.85687732696533, 60.27934006282261, 49.24283879143851, 61.83057403564453, 59.40528447287423, 60.57274859292166, 54.12195764269148, 54.60770968028477, 52.276095730917795, 47.636206831250874, 46.68317454201834, 46.242148058755056, 46.25266415732247, 52.11300413949149, 53.70873090199062, 46.94989851542881, 42.74628005708967, 41.22587176731655, 43.76664733886719, 39.26117134094238, 40.23284217289516, 41.71497631072998, 39.61061709267752, 39.5684415272304, 39.64404140199934, 41.17069959640503, 37.13964659827096, 37.652493136269705, 41.90507207598005, 41.0947071484157, 38.209571906498496, 46.28307294845581, 48.83137689317976, 54.49430118288313, 50.83618232182094, 44.877577441079275, 45.70173454284668, 42.09640462057931, 44.31137221200125, 45.721960748944966, 52.08120918273926, 52.56645400183541, 52.05576140539986, 56.87429543903896, 58.78711019243513, 48.204030990600586, 52.552971022469656, 56.35440690176827, 55.68542044503348, 58.67956597464425, 59.493846212114605, 57.555750438145225, 53.703776836395264, 56.87627567563738, 57.00816638129098, 54.30915253502982, 54.885377066476, 55.67878144127982, 54.25771502086094, 52.81558166231428, 47.084547655923025, 50.50369017464774, 54.57316323689052, 51.075731890542166, 51.242742265973774, 49.93425750732422, 44.85731996808733, 45.262886319841655, 50.07449299948556, 44.969022682734895, 42.721620900290354, 46.0658722605024, 42.34492431368147, 25.206655740737915, 9.832631196294512, 1.4480244538613727, 0.6823933316128594, 0.35216428871665684, 0.2787434884480068, 0.7945786203656877, 0.2132372563438756, 0.16906633653811046, 0.15348118783107825, 0.10305813101253339, 0.07486081442662648, 0.1004849158759628, 0.13796009282980645, 0.12651991099119186, 0.21330479771963187, 0.1456917550946985, 0.18355113214680127, 0.12283439375460148, 0.12980547254639013, 0.10835143019046102, 0.20905530931694166, 11.314047932624817, 57.60538142068045, 38.67975650514875, 59.826039586748394, 55.74248252596174, 59.123055594308035, 41.852317878178184, 0.3789298896278654, 2.834359109401703, 47.900116784232004, 38.16964060919625, 67.48984704698834, 66.00499616350446, 1.2340391533715385, 0.7694258157696042, 45.78159713745117], [59.53615379333496, 38.62721422740391, 5.364369315760476, 1.4323683168206895, 7.54960252557482, 3.493877342769078, 6.001115696770804, 11.28141919204167, 33.92592757088797, 49.3322343145098, 39.18202788489205, 72.76747635432652, 73.680803162711, 31.988540513174875, 30.897808824266704, 6.345556139945984, 0.3374768282685961, 0.02337740923810218, 0.14768974216920988, 0.07035142675574337, 0.10343458224087954, 0.040822793929172416, 0.04863175829606397, 0.05113176628947258, 0.038543703367135355, 0.02733668142796627, 1.7885298281908035, 16.885077953338623, 51.595116683415, 68.96423394339425, 51.070843832833425, 26.957344702311925, 18.30536096436637, 21.057995796203613, 39.407215527125764, 59.952927589416504, 67.62416962214878, 59.54795183454241, 56.065101282937185, 45.23856067657471, 43.33233628954206, 49.607831137520925, 55.525309630802695, 59.15032032557896, 56.91744375228882, 57.61090176446097, 56.689376081739155, 55.7461268561227, 57.44671583175659, 57.284433705466135, 60.072019713265554, 56.063617842538015, 57.13573183332171, 55.51321629115513, 54.86976793834141, 55.468053000313894, 53.69348655428205, 54.54341452462332, 58.273332595825195, 54.271198000226704, 54.51976980481829, 60.203563008989605, 56.65569468906948, 57.652684756687705, 58.233182430267334, 57.92252847126552, 46.86653055463518, 50.66321039199829, 57.12040063313076, 54.73575108391898, 51.78132145745413, 47.68816546031407, 49.33567714691162, 45.46586404527937, 42.05601821626936, 44.029577595846995, 42.12293979099819, 47.70529971803938, 54.6616415977478, 47.33504063742501, 44.08301271711077, 33.98887825012207, 40.4670763696943, 40.45899214063372, 37.11815234592983, 38.04088354110718, 36.990034512111116, 38.06366321018764, 39.533554622105186, 37.84874847957066, 37.45615094048636, 37.01912661961147, 34.97031477519444, 37.89521108354841, 38.91599178314209, 32.59379114423479, 37.358469690595356, 47.224605969020296, 51.871953759874614, 50.24220861707415, 43.75900084631783, 39.97566155024937, 40.98890692847115, 40.02860682351248, 42.46588897705078, 45.05667073386056, 51.05236857278006, 50.00866576603481, 49.830777985709055, 53.71432072775704, 55.7304482460022, 44.7349066053118, 53.31224237169538, 48.6521828515189, 51.886711733681814, 51.600953170231406, 55.35670811789376, 49.61124965122768, 48.58521611349923, 50.95691074643816, 51.19089133398873, 49.19349268504551, 50.020863328661235, 43.67416681562151, 45.74565758023943, 43.199799401419504, 44.32739128385271, 45.786888190678184, 42.073472091129844, 41.29296704701015, 36.19875628607613, 30.874184949057444, 28.11946392059326, 29.89942216873169, 31.543616090502056, 31.624962125505718, 24.580051558358328, 11.544670803206307, 4.103197881153651, 0.930410583104406, 0.21717361440615995, 0.1322782305734498, 0.09547185166073696, 0.04195776249149016, 0.060033460413771014, 0.2789611896233899, 0.0771186329158289, 0.10398701831166234, 0.07316741493663617, 0.03973325667902827, 0.04669565022257822, 0.03988828157473888, 0.03303056902119091, 0.053143249425504885, 0.04033477118770991, 0.06792261744184153, 0.055607787000813653, 0.07332777311759335, 0.06403215548821858, 0.07157447934150696, 1.6312158810240882, 18.159506116594585, 24.755404983248027, 30.81174496241978, 45.3250344821385, 41.82285404205322, 21.59875672204154, 0.21328794290976866, 0.19216653199068137, 4.983462989330292, 17.436031886509486, 35.14487089429583, 62.556243896484375, 3.564822793006897, 0.22299610983048165, 18.56121621813093, 80.8582923071725, 69.94975253513881, 4.130922062056405, 0.7635074162057468, 12.942877650260925, 6.4277155484472, 2.44330341901098, 19.72144726344517, 44.4621376991272, 65.51660033634731, 44.13093096869332, 75.71402672358921, 79.62934357779366, 35.438088348933626, 41.096416405269075, 11.504917553492955, 0.5106839654701096, 0.18885283837360994, 0.1920607348105737, 0.03855908575600811, 0.029075113590806723, 0.07441497620727335, 0.010956813847380025, 0.05678882469822254, 0.06984234228730202, 0.046819411617304595, 2.0513807237148285, 20.954179286956787, 58.78480339050293, 74.26365280151367, 56.75163541521345, 35.13564716066633, 26.38368579319545, 31.61702033451625, 52.331146308353965, 65.34469495500836, 65.83487646920341, 57.90880577904837, 56.26977784293038, 48.75389405659267, 50.534335204533164, 56.449228967939106, 60.82735143389021, 62.74638135092599, 61.68548175266811, 60.780673435756135, 57.50045319965908, 57.83847958700997, 57.90700272151402, 61.50669765472412, 60.86241899217878, 58.38728305271694, 58.975837162562776, 58.0220753124782, 55.16423954282488, 55.84280409131731, 55.13063110624041, 54.92778192247663, 60.55577414376395, 56.87173850195748, 58.813568932669504, 61.83833517347063, 58.40573746817452, 60.028002875191824, 60.46709428514753, 59.09005165100098, 50.249983651297434, 56.07013177871704, 60.70110266549246, 57.67008652005877, 53.363881383623394, 50.30199786594936, 51.35847840990339, 47.48323876517159, 43.527670996529714, 45.95110886437552, 42.82535750525338, 53.47627544403076, 56.81868553161621, 50.41991574423653, 44.32945837293352, 37.60331726074219, 41.62881864820208, 42.64629200526646, 39.734128270830425, 37.89490188871111, 37.92370912006923, 38.44355944224766, 38.83111606325422, 39.3665303502764, 37.952453817640034, 36.183230536324636, 34.95821796144758, 39.52983038766043, 41.452605383736746, 35.89837176459176, 39.763498306274414, 47.98513841629028, 54.588838372911724, 52.17889043263027, 47.01099749973842, 40.79868956974575, 43.73245872770037, 44.111837318965364, 44.332400935036794, 48.26430661337716, 51.515698773520334, 52.905977725982666, 52.96665634427752, 56.032326630183626, 57.938109806605745, 47.203639779772075, 54.22765016555786, 52.35099383762905, 52.75371837615967, 53.36918633324759, 56.03533867427281, 52.93906157357352, 50.244185379573274, 53.149675369262695, 53.858044215611045, 50.58253138405936, 55.06785065787179, 46.58509029660906, 49.1273319380624, 45.15813527788435, 45.841976983206614, 48.339388847351074, 47.55868577957153, 44.36646795272827, 39.91003234045846, 34.753068923950195, 33.045034953526084, 36.251128332955496, 36.81038883754185, 32.64616666521345, 24.84738871029445, 13.730776446206228, 4.1818002462387085, 0.6597173969660486, 0.18596430122852325, 0.16997386355485233, 0.06076614252690758, 0.09853253314005476, 0.07132367244256393, 0.06451823761952774, 0.0522660970288728, 0.09685654485864298, 0.054213573956596, 0.00736933304662151, 0.0358533493376204, 0.03780702468273895, 0.030664042436650822, 0.02762530477983611, 0.07275569345802069, 0.025715630734339356, 0.0562608057100858, 0.07695351141904082, 0.15346175458814415, 0.042254876012780836, 7.27916430575507, 34.680873666490825, 34.66438559123448, 35.17023529325213, 46.915411131722585, 49.71989515849522, 34.63625233513968, 0.2023360484412738, 0.3595304377377033, 14.833021300179617, 28.303945541381836, 45.4052722794669, 79.32208728790283, 5.453176413263593, 0.2686265584613596, 41.39097138813564, 90.56127793448312, 87.93548420497349, 7.1863871812820435, 1.3255365065165927, 15.819795778819493, 14.325772404670715, 28.0501834324428, 41.86739546912057, 57.6620682988848, 77.6467376436506, 49.452782085963655, 83.55364445277623, 84.21939999716622, 44.59124217714582, 52.979774543217246, 11.232119117464338, 1.0408063850232532, 0.3202565594443253, 0.21559844964316913, 0.18019777137253964, 0.22561494287635597, 0.17640495060810021, 0.1467035322317055, 0.200973740113633, 0.09782226303858416, 0.11242899139012609, 1.8955278524330683, 23.69122236115592, 56.37677662713187, 69.72797298431396, 68.27401379176548, 52.12716456821987, 37.88412870679583, 47.825135299137656, 65.62524931771415, 75.15730925968715, 74.76643139975411, 67.86229133605957, 66.35806887490409, 60.7833137512207, 58.87078734806606, 61.30615874699184, 65.85196903773716, 64.17333289555141, 64.61314691816057, 63.77746622903006, 62.60532597133091, 59.76349190303257, 62.76407841273716, 63.54592445918492, 65.61860683986119, 61.241992133004324, 62.182013920375276, 62.29383128029959, 59.57306262425014, 59.834565026419504, 57.987799848829, 57.686994961329866, 64.41725635528564, 58.50967557089669, 60.10367570604597, 63.742065157209126, 60.9560181753976, 62.09486961364746, 64.70702402932304, 63.8962595803397, 54.91978801999773, 54.979490416390554, 64.65081310272217, 59.754660742623464, 57.36306994301932, 52.964537143707275, 53.51299319948469, 49.745276927948, 47.279392514910015, 50.91316836220877, 45.77030978884016, 53.64017302649361, 58.69962542397635, 50.73173700060163, 47.57973187310355, 37.86412831715175, 44.59101983479091, 43.12274040494646, 39.79091937201363, 39.877170835222515, 37.174022810799734, 41.25068378448486, 40.53675290516445, 39.67637137004307, 37.57912710734776, 37.815730639866416, 34.804280621664866, 41.319234711783274, 43.62150641850063, 36.53539303370884, 44.217981474740164, 51.11837298529488, 58.258720534188406, 52.603477478027344, 48.387675353458945, 44.35969693320138, 45.397010871342246, 45.52649750028338, 47.77059888839722, 51.205378328050884, 54.00970254625593, 54.449262959616526, 54.25897264480591, 58.477130208696636, 59.63994598388672, 49.1151065826416, 56.45646204267229, 53.114868368421284, 56.70286948340279, 57.64904737472534, 59.33456570761544, 53.68959208897182, 53.17802401951381, 55.76606123788016, 56.88691336768014, 53.399574279785156, 56.54477712086269, 49.559621061597554, 51.78089761734009, 48.07637868608747, 49.239267417362754, 53.077782358442036, 49.582987853458945, 50.482748304094585, 46.17773478371756, 41.078253814152305, 42.70765502112252, 44.13411324364798, 49.52467162268502, 46.20231403623308, 35.117908409663606, 16.842775583267212, 4.623280533722468, 0.9517765109028135, 0.18482163468641893, 0.30547692679933136, 0.17316523087876184, 0.30501422019941465, 0.21527714974113873, 0.3678759027804647, 0.5203407130071095, 0.15808793849178723, 0.1329823870744024, 0.1308312410754817, 0.10969270393252373, 0.09899085640375103, 0.17489070471908363, 0.3036266975104809, 0.16967032769961016, 0.19989212815250668, 0.10831711667456798, 0.19330054042594774, 0.23959706617253168, 0.20360321258859976, 17.106723751340592, 53.617792878832134, 44.50103024074009, 48.972908224378315, 57.16707515716553, 59.153926440647666, 53.81593465805054, 0.1763453616627625, 0.7018971964716911, 34.78221661703927, 46.27658680507115, 57.07013736452375, 93.88248906816754, 4.878982927118029, 0.39210695826581543, 58.19893128531319], [72.27685015542167, 19.6059056690761, 1.8810050317219325, 3.5709315623555864, 8.361045292445592, 2.580852998154504, 0.5884282280291829, 19.886324541909353, 44.642189843314036, 52.603682449885774, 43.943732602255686, 67.71695586613247, 73.36563982282365, 44.673050267355784, 34.23578943525042, 19.78350509916033, 0.6253320649266243, 0.0895533435312765, 0.06261795280235154, 0.03467494435608387, 0.13503766964588845, 0.0616886108847601, 0.07898241254900183, 0.021407901974661008, 0.1156710045678275, 0.06510299231324877, 0.24968690904123442, 10.401065928595406, 33.639005184173584, 61.610545430864605, 69.52677399771554, 42.6178252356393, 26.237883056913102, 27.295487471989222, 30.507431234632218, 40.24386201586042, 50.85634599413191, 59.439497402736116, 59.61368874141148, 46.720187595912385, 39.940027713775635, 47.25792605536324, 52.025647912706646, 57.47161817550659, 58.690266200474326, 56.4781299999782, 54.49964434759957, 52.491555895124165, 53.67808239800589, 55.449299812316895, 56.64564759390694, 56.112710339682444, 57.27582836151123, 54.15605592727661, 53.24636650085449, 52.72265298025948, 53.387814453669954, 52.707651819501606, 54.80538593019758, 54.19325310843331, 58.66045148032052, 57.60589211327689, 55.574360438755576, 56.260529790605815, 57.892251695905415, 46.9207820892334, 48.95769166946411, 55.82145922524588, 57.36088473456246, 54.39600501741682, 50.63064765930176, 54.14135701315743, 45.576625279017854, 43.33627591814314, 43.52214370455061, 42.42851461683001, 44.26269660677229, 54.789585726601736, 51.43900455747332, 46.179847036089214, 39.58861909593855, 37.876503058842246, 41.30425092152187, 41.57671758106777, 36.717223916734966, 37.117752824510845, 36.4301312991551, 36.062165124075754, 34.54490089416504, 35.54592786516462, 36.23277466637747, 36.04037209919521, 35.75536394119263, 40.9699696132115, 40.246394634246826, 37.362110546657014, 36.12927777426583, 42.399141107286724, 50.61283942631313, 51.1167505809239, 50.95389175415039, 41.12031126022339, 38.65449285507202, 40.14804288319179, 41.01173523494175, 44.23330225263323, 47.56585284641811, 52.805048193250386, 56.08685261862618, 52.59921475819179, 55.800711904253276, 48.49517093385969, 49.15852240153721, 54.24316201891218, 49.498643670763286, 52.89854662758963, 54.06058767863682, 54.46718583788191, 44.81818423952375, 45.4615353175572, 52.57019908087594, 48.10465438025338, 46.5156569480896, 40.13008526393345, 45.79935673304966, 39.94677788870675, 37.95795679092407, 42.190920966012136, 39.804419721875874, 32.94392476763044, 32.60519661222185, 29.57838065283639, 28.13494450705392, 27.14950408254351, 28.95669232095991, 18.703730719430105, 7.797208530562265, 3.623803662402289, 1.4575662847076143, 0.15855314210057259, 0.17841926323516027, 1.010601588657924, 0.8926808333822659, 0.2984899160053049, 0.6621644656573022, 0.40188687347940033, 0.6216750868729183, 0.10649128750498806, 0.02772115294023284, 0.059195659655545435, 0.037349240854382515, 0.03385959971430046, 0.12030543945729733, 0.053485203933502944, 0.05131086560764483, 0.010203140405272799, 0.048696290369012525, 0.15316295490733214, 0.02212506259924599, 0.06229134675647531, 3.754563331604004, 22.8950526033129, 24.418075152805873, 27.783098152705602, 46.8186331476484, 41.850688525608604, 40.40557786396572, 0.11513212562671729, 0.10356322569506508, 2.6107417600495473, 19.615066868918284, 29.2161363192967, 75.77715110778809, 11.067286133766174, 0.32618114724755287, 21.785828283854894, 85.8114824295044, 45.128925051007954, 1.182346184338842, 2.78330374615533, 12.869555047580175, 6.186299954141889, 7.056185756410871, 22.11773157119751, 55.33552653448922, 68.20633138929094, 45.25925588607788, 74.33850574493408, 81.68212631770542, 47.00299317496163, 42.73907824925014, 28.613550322396414, 0.3280225284397602, 0.07521825310375009, 0.09447239671966859, 0.059733710783932886, 0.10106815065124206, 0.05500991961785725, 0.09245449464235987, 0.07551486111645188, 0.098679612390697, 0.015879542999235646, 0.82074472201722, 15.138530118124825, 42.72437586103167, 69.3182932989938, 74.22962052481515, 51.08662666593279, 32.11470937728882, 35.43664312362671, 44.362990379333496, 54.046844141823904, 60.581162861415315, 63.70448235103062, 59.00982775006975, 49.07623141152518, 48.11041791098458, 51.94025107792446, 58.38912432534354, 61.52989074162075, 62.25527572631836, 61.74470124925886, 57.53416585922241, 56.63875150680542, 53.42416742869786, 56.93916382108416, 58.12846960340227, 59.62308965410505, 60.7561046055385, 56.11967243467058, 56.907691955566406, 56.90469033377511, 54.68165240968977, 53.89963265827724, 55.310158661433626, 55.67016914912632, 59.921577317374094, 60.836342402866904, 59.82963875361851, 59.951280866350444, 59.57054042816162, 50.61346476418631, 52.80706664494106, 59.660693304879324, 60.157343591962544, 55.98130253383091, 53.503769465855186, 56.03156580243792, 46.97823674338204, 48.016172545296804, 44.17288071768624, 44.365912096840994, 48.47629615238735, 58.301570074898855, 53.60036332266671, 48.39681918280465, 43.36348506382534, 40.43021617616926, 46.61947693143572, 42.51112174987793, 35.938657420022146, 36.55397946493966, 36.25900411605835, 35.40231554848807, 35.13044990812029, 35.924156529562815, 35.48811885288784, 35.31496626990182, 35.2097601209368, 38.83923850740705, 41.38840402875628, 39.24923433576311, 40.17033617837088, 43.772014822278706, 51.588606221335276, 54.12738765989031, 53.34720918110439, 45.65439993994576, 41.165481499263215, 43.52890430177961, 43.97620848246983, 45.125683716365266, 48.40141541617257, 53.650122846875874, 59.13612515585763, 54.99002735955374, 56.56929383959089, 54.76545115879604, 50.1018966947283, 56.03860780170986, 52.611245564052034, 56.53433050428118, 56.77301502227783, 56.58484043393816, 46.86178840909685, 48.4674128804888, 54.6575664792742, 52.09206574303763, 49.75055408477783, 45.98200402941023, 48.10252823148455, 43.14037145887102, 40.62572111402239, 45.70050471169608, 43.31228378840855, 36.67289093562535, 37.35853917258126, 34.1567884172712, 31.873259476252965, 32.028489180973594, 32.46349852425711, 18.850177901131765, 7.92061722278595, 2.7920287294047217, 1.4934360342366355, 0.40352586124624523, 0.47431904822587967, 0.3597788358373301, 0.5449650202478681, 0.5774246156215668, 0.4293724000453949, 0.2741133826119559, 0.9146566284554345, 0.1273225364940507, 0.0650596474962575, 0.020266667141446044, 0.010079435837854232, 0.04949050543031522, 0.10492212099156209, 0.03131083897980196, 0.024894615236137594, 0.03262045567056962, 0.04227436353851642, 0.04513465666345187, 0.057205435021647384, 0.06594666918473584, 12.970545377050128, 40.696787289210725, 34.042021547045024, 34.93834611347744, 49.830843993595664, 47.57859584263393, 48.644331387111116, 0.1741190475544759, 0.08548895948167358, 8.59896377154759, 32.260364464351106, 40.289473465510774, 87.30050223214286, 14.910505873816353, 0.44051665919167654, 42.67611367361886, 102.10923263004848, 53.236413206372944, 1.7645509434597832, 5.048728287220001, 19.4376220362527, 14.456211805343628, 31.225628307887487, 45.67767987932478, 70.38810048784528, 81.57309518541608, 50.53716312135969, 77.61574867793492, 87.13241836002895, 55.272179807935444, 54.8773067338126, 30.220995221819194, 1.0268667787313461, 0.12092522691403117, 0.18106250997100556, 0.12679627830428736, 0.2098292192178113, 0.12960701462413582, 0.14989704372627394, 0.11085610650479794, 0.13022001673068317, 0.2425111840878214, 0.9660360600267137, 15.53906944819859, 49.82206494467599, 68.63782146998814, 74.19597734723772, 63.02394798823765, 49.2534556388855, 50.7247644833156, 56.9904727935791, 59.24468381064278, 69.51199517931256, 77.25792339869908, 74.27367210388184, 61.989785058157786, 58.815764563424246, 60.16695989881243, 64.2872416632516, 66.16070529392788, 66.6912488937378, 65.00960418156215, 60.44696535382952, 59.52493940080915, 58.74362141745431, 60.249525342668804, 60.58501216343471, 62.34060655321394, 63.53061062949044, 59.06909588405064, 57.175169808524, 59.08443750653948, 57.32743263244629, 58.06829472950527, 59.71965571812221, 57.31257390975952, 62.07364981515067, 63.17321613856724, 59.98900958469936, 63.90818268912179, 64.41048186165946, 53.8252591405596, 54.01111650466919, 61.79517296382359, 63.001526151384624, 60.980844088963096, 55.58958394186837, 60.111124174935476, 52.22806283405849, 51.22468737193516, 46.75064155033657, 48.62713459559849, 49.68136044910976, 61.26367746080671, 56.44924633843558, 48.691923073359895, 42.654751437050955, 42.56946924754551, 49.06470087596348, 42.79571649006435, 36.21347951889038, 38.523526259831016, 38.17837449482509, 36.394994258880615, 36.72224746431623, 38.29725122451782, 36.54688882827759, 36.40469741821289, 34.52735321862357, 41.751509938921245, 44.66265228816441, 42.58686406271798, 40.468664033072336, 45.53054830006191, 54.239427362169536, 55.627621855054585, 54.66305208206177, 45.220575264522004, 42.68917281287057, 45.35089567729405, 45.35191011428833, 48.837143898010254, 52.547360352107454, 57.35437774658203, 61.268291064671104, 57.068303040095735, 59.70468929835728, 54.134603364127024, 54.147773674556184, 57.634702818734304, 55.12061527797154, 58.39289024897984, 60.41860280718122, 57.18095418385097, 48.697127274104524, 50.379108973911826, 57.12004974910191, 55.02132552010672, 53.23617001942226, 48.03268493924822, 52.06750386101859, 47.50800561904907, 44.6156963620867, 52.09327820369175, 47.501901626586914, 44.65579441615513, 47.302818366459434, 41.00781645093645, 38.122875758579795, 45.84470067705427, 42.35506173542568, 23.782778773988994, 8.507132904870168, 3.2940549680164883, 1.722556465438434, 0.6447397949440139, 0.5328376995665687, 1.3147966542414256, 1.094654055578368, 1.382112756371498, 2.097942339522498, 0.9013079447405679, 1.5114273088318961, 0.20928564481437206, 0.23606740842972482, 0.16250254160591535, 0.13489635794290475, 0.13392101813639912, 0.12311116818870817, 0.17096638386803015, 0.1874902043491602, 0.14438203323100293, 0.1494982008423124, 0.24009003543428012, 0.09045360343796865, 0.18798366215612206, 24.63696425301688, 56.406257833753315, 43.922234875815256, 45.45124503544399, 63.48796953473772, 60.07664721352713, 55.746317931583945, 0.2744929279599871, 0.29694882727095057, 21.82037125314985, 56.22014686039516, 50.37556191853115, 102.36751106807164, 16.451965468270437, 1.3061827336038863, 64.61291067940849], [66.44399029867989, 9.505807042121887, 1.1028979846409388, 5.87115832737514, 6.084301267351423, 1.4485463287149156, 1.7588334445442473, 26.0774404661996, 44.80927317483084, 53.6509496825082, 50.97483362470354, 45.834139415196006, 100.34081881386894, 72.35963794163295, 34.85918876102993, 35.17865303584507, 0.5988377694572721, 0.1254028116485902, 0.07901331303375107, 0.142918786033988, 0.15540212046887192, 0.018965623740639006, 0.098126877764506, 0.03577360790222883, 0.06919036512928349, 0.07185974224869694, 0.1112746676164014, 3.623002448252269, 34.63913236345564, 57.51177528926304, 72.030029296875, 60.567461013793945, 44.88266352244786, 42.5167567389352, 37.652923924582346, 29.743702616010392, 24.801023381096975, 29.427823611668178, 43.65661219188145, 52.42845582962036, 48.582700865609304, 42.14882183074951, 47.05967310496739, 53.90049076080322, 55.57005255562918, 54.732301303318565, 51.86945588248116, 52.68492078781128, 48.77665982927595, 53.09016752243042, 54.18122577667236, 56.59276138033186, 53.43279014314924, 52.861078466687886, 51.880923884255544, 52.800757680620464, 49.776616777692524, 50.452349935259136, 51.71745709010533, 57.08494397572109, 55.66078560692923, 58.03931379318237, 57.24200800486973, 58.017628465379985, 51.67425666536604, 49.66474730627877, 54.71827636446272, 57.016594546181814, 54.79919508525303, 51.43550961358206, 54.90177828924996, 47.677479130881174, 42.302644525255474, 42.84396825517927, 39.447178091321675, 46.4336508342198, 53.31840542384556, 52.996641295296804, 52.20781230926514, 45.74520942143032, 39.212749344961985, 37.45580005645752, 42.620785168239046, 38.71204478400094, 36.7837563923427, 37.86933946609497, 36.40075431551252, 35.95288733073643, 34.68714441571917, 32.7631048474993, 33.06563983644758, 36.89491367340088, 33.93198292595999, 37.51646825245449, 41.15047686440604, 38.57898678098406, 37.021711349487305, 39.825302532741, 43.5693358693804, 47.39535100119454, 49.557897908346995, 51.29131364822388, 39.9293726512364, 41.812077386038645, 42.73396437508719, 40.30832045418875, 43.53585250037057, 50.37711831501552, 51.576891558510916, 53.43095929282052, 54.39427144186837, 56.12059307098389, 46.76128619057791, 54.48149217878069, 54.779142584119526, 52.38242401395525, 51.450965881347656, 51.35119322368077, 49.625399657658164, 40.88399955204555, 50.08456441334316, 45.508644104003906, 41.959337506975444, 43.41635390690395, 45.00648389543806, 36.64391347340175, 32.8162134034293, 36.758975642068044, 31.899468081338064, 29.016045570373535, 25.82831801686968, 30.581113406590053, 26.78184536525181, 27.41618115561349, 14.88608295576913, 5.475283409867968, 3.3748464499201094, 1.6167118421622684, 0.7313405679804938, 2.134560648884092, 4.582136341503688, 6.639604772840228, 8.304911664554051, 2.7439430696623663, 2.0709876716136932, 1.4721649927752358, 0.8873832662190709, 1.3089942570243562, 0.11331038802329983, 0.05925651067601783, 0.0031873166818903492, 0.04695608553343585, 0.0709998891023653, 0.12062488017337662, 0.03210133227652737, 0.07794634385832719, 0.09528602127517972, 0.10162898020020553, 0.07368605317814009, 0.10209313207971198, 7.635138324328831, 31.647147723606654, 27.46218170438494, 24.131236144474574, 36.35311051777431, 31.385075569152832, 22.275949001312256, 0.9542503952980042, 0.07167443433510405, 1.55045870585101, 20.998288188661846, 30.760338715144567, 72.88297625950405, 15.46091263634818, 0.6898702989731516, 29.741600785936626, 87.19903768811906, 21.92217104775565, 1.3950356457914626, 5.1742066740989685, 11.539600355284554, 6.963770806789398, 11.72880675111498, 30.43862669808524, 57.013533864702495, 73.05579880305699, 50.93963405064174, 53.132009574345176, 120.10960415431431, 72.6045480455671, 41.07860122408186, 48.0245485986982, 0.4965732055050986, 0.1406611507492406, 0.06315869771476303, 0.10761560646018811, 0.048314862086304596, 0.13886196086449282, 0.047819185469831736, 0.03912494664213487, 0.06152635280575071, 0.08850521727332047, 0.2972383445927075, 5.765490557466235, 41.04089682442801, 62.470662934439524, 74.44692543574742, 64.22511087145124, 50.275452273232595, 49.812966278621126, 45.922412804194856, 41.264962332589285, 40.65828732081822, 41.50738845552717, 54.498251233782085, 55.687320777348106, 48.53996597017561, 48.38669218335833, 52.49038512366158, 60.411494800022666, 59.81574930463518, 58.4238166809082, 59.268953868321006, 57.615411145346506, 53.336244923727854, 55.30663939884731, 56.324192660195486, 59.193732670375276, 58.59774398803711, 55.55008690697806, 54.509813036237446, 54.59960113252912, 50.65872185570853, 54.658761569431846, 54.77000917707171, 60.462355613708496, 56.56532989229475, 60.681606020246235, 59.3570431300572, 59.806299754551475, 54.365516321999685, 54.115377698625835, 59.06322465624128, 61.0799948828561, 57.091200828552246, 55.3463066646031, 55.37852546146938, 48.43576036180769, 45.08681896754673, 43.589843477521626, 43.01031855174473, 48.07408925465175, 55.64068794250488, 55.16872460501534, 55.1978132384164, 46.036728041512625, 38.94513252803257, 40.48151125226702, 46.596190043858115, 43.23311601366316, 37.6753249168396, 38.44938203266689, 37.90191956928798, 35.75927577699934, 34.02278198514666, 34.278458322797505, 35.59634052004133, 38.503546714782715, 34.485684871673584, 38.29522582462856, 43.76838786261422, 39.20928566796439, 36.53817926134382, 41.41394908087594, 46.83688259124756, 48.53868055343628, 51.59348038264683, 53.998755659375874, 44.42652470724923, 45.48245981761387, 47.49201086589268, 42.70913846152169, 46.20610775266375, 52.192470686776296, 54.157105105263845, 55.3563746043614, 54.4766388620649, 57.14569207600185, 49.58773347309658, 55.309439522879465, 56.38219274793352, 54.471052510397776, 53.84704521724156, 52.89275530406407, 51.57796852929251, 42.80281754902431, 51.70997735432216, 49.12023087910244, 47.05218294688633, 47.10531234741211, 47.325493812561035, 40.57225819996425, 38.37903847013201, 42.50598703111921, 36.69422885349819, 35.66730942044939, 33.31656013216291, 33.21707929883684, 30.693510941096715, 28.809432200023107, 15.170752389090401, 5.601881325244904, 2.9988520656313216, 3.714524337223598, 1.8172947189637592, 0.7780249714851379, 3.7047873054231917, 5.514614990779331, 7.130080282688141, 2.6064065183912004, 1.6334441900253296, 1.3293243604046958, 1.535340728504317, 1.7151659705809184, 0.08629738645894186, 0.05067763297951647, 0.06276383104601077, 0.04256895969488791, 0.06652877759188414, 0.25334364282233374, 0.050370996219239066, 0.06488660749580179, 0.06831244938075542, 0.07847837638109922, 0.05462189597476806, 0.0461144069475787, 20.507799216679164, 47.415566784994944, 39.21464967727661, 31.27912596293858, 43.33986813681466, 41.88191373007638, 29.9881089755467, 0.6992516698581832, 0.12681348595236028, 6.336022777216775, 37.2459123475211, 41.07666267667498, 84.11339133126395, 19.64508134978158, 1.2100827417203357, 42.980993679591585, 100.3270127432687, 22.694437265396118, 1.3768079153129031, 9.314015047890798, 19.308710370744976, 15.709840536117554, 31.914816652025493, 46.57523775100708, 67.4716636112758, 81.32983875274658, 61.087804658072336, 58.322852407182964, 104.90451376778739, 79.31914125170026, 51.827989033290315, 52.253875391823904, 0.6374331127320016, 0.16573395606662544, 0.15387999000293867, 0.2443755811878613, 0.22518477881593363, 0.18119818983333452, 0.17429721727967262, 0.11677337970052447, 0.23460679394858225, 0.19850737388644898, 0.27114430336015566, 9.69495611531394, 47.27639089311872, 68.06162820543561, 74.63756316048759, 69.64052990504673, 63.69756889343262, 62.4332468850272, 57.92754854474749, 55.036979811532156, 52.39056035450527, 44.87784494672503, 65.15806634085519, 67.6057152066912, 58.21716683251517, 60.078537123543875, 61.36304364885603, 66.9716226032802, 63.48135484967913, 64.7888182231358, 62.10065051487514, 59.29603099822998, 53.590337072099956, 59.115871156964985, 59.19382299695696, 62.81260463169643, 60.44566604069301, 57.325337750571116, 56.52227190562657, 56.22897802080427, 53.03273023877825, 57.78326572690691, 58.24168355124337, 62.42182404654366, 58.863818304879324, 63.18440273829869, 61.082864488874165, 62.29503331865583, 57.709934438977925, 55.95696299416678, 61.59656565529959, 63.097063882010325, 60.23257868630545, 57.86060612542288, 58.84138951982771, 51.90773698261806, 48.473082610539024, 45.538510935647146, 43.231552668980186, 50.66898087092808, 58.49264553615025, 56.338495526994976, 57.37001814161028, 47.34802334649222, 42.723927702222554, 40.997613021305625, 47.04189266477312, 42.2578182220459, 36.74120562417166, 38.07221644265311, 37.817300932747976, 38.54016719545637, 34.79228455679757, 34.32524749210903, 35.523050921303884, 39.47488750730242, 34.21516718183245, 39.59051595415388, 45.951292991638184, 42.75652517591204, 39.08106708526611, 43.44073860985892, 48.186278343200684, 50.52792549133301, 53.164937087467735, 56.27775090081351, 45.53180939810616, 46.68471009390694, 48.3629640851702, 46.1775541305542, 49.577380657196045, 54.28398615973336, 55.456074305943076, 57.07743297304426, 57.7699738230024, 60.23168931688581, 52.07143654142107, 57.775647027151926, 59.16243798392159, 55.86592769622803, 57.012178965977256, 55.85301794324602, 52.73667444501604, 44.609310967581614, 56.22569152287075, 52.81934758595058, 49.955185481480186, 50.69297647476196, 52.37308216094971, 44.38733686719622, 43.48796204158238, 47.43522323880877, 45.12461716788155, 44.21517092841012, 40.50530883244106, 44.192780358450754, 43.45376648221697, 36.39324331283569, 19.624151638575963, 6.743758269718715, 3.911276476723807, 3.902394941874913, 3.1261220020907263, 5.126434334686824, 7.2438149111611505, 9.106515782220022, 10.906501344272069, 4.2593525648117065, 4.6455647093909125, 4.392215149743216, 3.182983670915876, 2.3913356704371314, 0.22048562525638513, 0.2776824768100466, 0.1364078489797456, 0.1479942144027778, 0.26638272457889145, 0.36314344672220095, 0.21777379220085485, 0.15488249835159096, 0.2771122631217752, 0.24683909756796701, 0.28978100046515465, 0.47306679827826364, 32.6876335144043, 63.386706488473074, 48.881674902779714, 42.86951330729893, 55.96190663746425, 54.0843505178179, 41.90919583184378, 0.7106156115021024, 0.32701463252305984, 17.26014518737793, 56.070579937526155, 51.64740187781197, 95.79336874825614, 24.08674509184701, 2.3310578763484955, 70.30478463854108], [49.64861011505127, 7.002664651189532, 0.7459773282919611, 4.971644537789481, 2.246941898550306, 3.052177969898496, 8.287503821509224, 6.9932164038930615, 42.52242646898542, 51.50591223580496, 41.14562702178955, 38.94095318658011, 56.10977472577776, 61.99233504704067, 38.740761688777376, 44.59441402980259, 2.1544804828507558, 0.32813128403254915, 0.37346846982836723, 0.01754305132531694, 0.09527295947607074, 0.05110750187720571, 0.07486812903412751, 0.06967304780014924, 0.015613502989123975, 0.045492672095341344, 0.027213791950738857, 4.652505525520869, 51.794519560677664, 67.8205326625279, 69.39457062312535, 65.97193663460868, 54.345585414341514, 54.40875843593052, 50.37042719977242, 49.74269567217146, 21.355128560747417, 11.800294160842896, 19.458523954663956, 51.67247097832816, 61.316803387233186, 49.297152859824045, 44.43382726396833, 52.281657763889854, 55.67465073721749, 54.672713552202495, 52.763824531010215, 52.8211020060948, 49.63210466929844, 53.35998691831316, 54.448807852608816, 53.92973572867257, 55.62993213108608, 53.25100094931466, 53.49506337302071, 52.50439964021955, 49.3223157610212, 48.41193151473999, 52.82673699515206, 56.347559452056885, 52.30465977532523, 55.971057415008545, 56.37714488165719, 54.28535148075649, 49.30773844037737, 57.25732183456421, 55.61357607160296, 55.61586897713797, 52.633080278124126, 54.51602125167847, 49.274477413722444, 45.01918520246233, 44.655745778764995, 42.773089681352886, 45.1876859664917, 48.11015040533883, 52.42651728221348, 50.68696975708008, 48.65131780079433, 43.55401856558663, 39.535586970193044, 37.995591708592, 45.53853178024292, 45.8501306942531, 37.23419073649815, 36.747330461229595, 35.50572558811733, 33.83839416503906, 34.29654448372977, 32.88178007943289, 33.39521026611328, 35.04445900235857, 33.518773555755615, 38.6256856237139, 44.883941990988596, 34.80201203482491, 34.84899227959769, 37.215889181409565, 42.76258053098406, 47.23274230957031, 46.49499300548008, 48.87526518957955, 45.52917603084019, 43.79627793175833, 44.6980915750776, 43.34874793461391, 41.69048738479614, 50.22159331185477, 50.25379821232387, 52.78060095650809, 52.35704224450247, 56.423527581351145, 52.62202222006661, 50.20533800125122, 54.34182643890381, 51.158408505576, 50.88435765675136, 50.63389246804373, 52.75242601122175, 43.68812574659075, 41.68855231148856, 43.96942009244646, 43.31513602393014, 39.211932931627544, 39.88979223796299, 35.9171701158796, 30.560876778193883, 31.435359682355607, 27.16290020942688, 26.38794677598136, 26.248336621693202, 31.164855888911656, 26.116720369883947, 14.849703924996511, 5.667228264468057, 3.180050228323255, 2.178913171802248, 1.7600337458508355, 5.651264343942914, 14.437276227133614, 15.333684171949114, 22.503903763634817, 13.778011168752398, 15.349762303488594, 13.669134633881704, 11.636856028011866, 10.955131786210195, 4.582570603915623, 1.256398347871644, 0.16825727852327482, 0.06373035668262414, 0.012003086008397596, 0.08640880869435412, 0.02910250604950956, 0.05428229259060962, 0.04479700746014714, 0.030981674856905426, 0.019296799719865834, 0.08594435825943947, 0.43855946564248627, 18.322003637041362, 39.58416530064174, 34.103447096688406, 22.868878739220754, 25.770026104790823, 11.821639026914324, 11.552559614181519, 0.9573512460504259, 0.24541732243129186, 4.492036010537829, 25.285102639879497, 34.15215744291033, 77.41810022081647, 18.663905382156372, 1.3669509185211999, 26.895820140838623, 78.52838066646031, 11.325456874711172, 0.6961570616279329, 5.664573184081486, 6.273600595338004, 3.504905653851373, 11.872476390429906, 16.302282163075038, 55.01099007470267, 68.04727322714669, 44.55754688807896, 37.2735800743103, 83.43897138323102, 72.16509532928467, 43.1422301019941, 58.47881167275565, 3.0121936925819943, 0.3048936580973012, 0.3285430462232658, 0.016353572652276074, 0.08893758657255343, 0.017847374281180755, 0.06101681371884687, 0.0051016164278345445, 0.05718982193086829, 0.019753375755889074, 0.26117141278726713, 6.979244010789054, 58.02726214272635, 66.78133228846959, 73.02993760790143, 70.56595352717808, 62.79119028363909, 59.82376752580915, 55.74097129276821, 55.97099140712193, 35.02398266111101, 20.80404782295227, 36.012506348746165, 57.22739246913365, 59.917040143694194, 51.01707172393799, 49.20234816414969, 55.86623689106533, 58.9837372643607, 60.71135125841413, 58.22139828545706, 57.714443819863455, 54.402011735098704, 55.24050644465855, 57.17189373288836, 56.99084104810442, 57.63045399529593, 57.04560327529907, 55.566078186035156, 54.06039660317557, 51.047115734645296, 52.2118353162493, 55.86320052828108, 58.50923783438546, 55.90351397650582, 60.904823848179404, 57.38338647569929, 56.7682728767395, 53.98946591785976, 59.51682390485491, 58.03348772866385, 56.34707307815552, 55.05314826965332, 57.805451325007844, 51.15284299850464, 49.32392774309431, 44.81971979141235, 45.786415713174, 48.122445242745535, 49.56873362404959, 52.6586913381304, 52.49969570977347, 49.827227456229075, 44.49329342160906, 40.199365752083914, 41.07492562702724, 46.889702796936035, 49.05042927605765, 37.96459232057844, 38.262604032244, 35.39393254688808, 34.998600891658235, 34.217143944331575, 33.639887605394634, 34.07794025966099, 35.74260010038103, 33.46972969600132, 41.40855380467006, 46.35738393238613, 37.98630196707589, 38.62838152476719, 38.07979345321655, 42.96377256938389, 50.13862834657942, 47.92283739362444, 50.94341039657593, 47.718873023986816, 46.64881222588675, 47.49644381659371, 49.42647968019758, 44.196751253945486, 50.9106878553118, 53.76173176084246, 55.47325720105852, 52.22879239491054, 57.10012926374163, 53.963667256491526, 52.85228204727173, 55.291124071393696, 55.5680375780378, 53.42981284005301, 51.28589057922363, 52.46181065695626, 46.35507713045393, 45.24591187068394, 48.98835754394531, 45.05942916870117, 43.94532721383231, 44.13760123934065, 40.70539263316563, 37.27146782193865, 37.837134565625874, 33.46944481985909, 33.69713381358555, 32.86217226300921, 32.895752906799316, 25.772207839148386, 15.14963333947318, 6.532170857701983, 3.430320216076715, 4.277950286865234, 5.129765127386365, 6.617911194052015, 12.982382501874651, 15.62209347316197, 22.411664690290177, 14.677921874182564, 12.719303727149963, 15.075866052082606, 12.765946984291077, 13.656654800687518, 4.615841618606022, 2.224094484533582, 0.14462971208351, 0.12079535531146185, 0.062004943910454, 0.08410648509327855, 0.043058923046503744, 0.003714543268350618, 0.01807198972840394, 0.041913891809859445, 0.11283955935920988, 0.09666234813630581, 0.8055739817874772, 32.424852643694194, 54.35873140607561, 46.952625683375764, 31.614435604640416, 32.9813859803336, 21.22060101372855, 17.37205982208252, 1.0270448263202394, 0.1415005392794098, 6.542696510042463, 41.96942629132952, 43.07538148335048, 87.830413545881, 22.145255122865947, 1.9055488918508803, 46.96238790239607, 85.25794724055699, 16.056673765182495, 0.8535023842539106, 11.961930973189217, 11.297309722219195, 13.396590675626483, 36.03452866418021, 19.54379051072257, 64.16114575522286, 74.04861995152065, 54.61106218610491, 51.959987436022075, 66.35467120579311, 76.98695060185024, 50.1900554384504, 68.74393435886928, 2.727225486721311, 0.39416940616709845, 0.5613160857132503, 0.0943776053775634, 0.2684938098703112, 0.10932607789124761, 0.26577725421105114, 0.20505930802651814, 0.1645201247717653, 0.14771286664264544, 0.46315600723028183, 12.556671585355486, 60.23535796574184, 73.35952540806362, 75.99251052311489, 71.78534848349435, 64.68189934321812, 62.56954969678606, 65.11183997562954, 70.18761021750313, 54.65552370888846, 29.88462597983224, 43.59256369726998, 67.8305311203003, 74.45352622440883, 62.25810364314488, 60.058915410723, 63.40857941763741, 65.0092637198312, 64.95135048457554, 63.53484903063093, 60.94142695835659, 57.56239639009748, 58.427478381565635, 59.42901951926095, 59.195963042122976, 60.106107575552805, 59.34423760005406, 57.8914144379752, 57.102998869759695, 54.19805778775896, 55.81590066637312, 58.96618611471993, 60.459833417619976, 56.04230424336025, 62.81857313428606, 61.49373926435198, 60.82979719979422, 55.824895109449116, 60.75561128343855, 61.42445877620152, 58.83606719970703, 56.93730865206037, 63.23576382228306, 55.00209290640694, 51.886774267469136, 50.051268645695274, 46.75588396617344, 49.49570458275931, 52.220742906842915, 56.348271642412456, 54.6848520551409, 51.65314456394741, 45.354185649326865, 43.279728003910606, 41.67421817779541, 48.31989915030343, 48.91045434134347, 37.959169251578196, 38.81013945170811, 36.97911194392613, 34.96551704406738, 36.07492549078805, 33.63557277406965, 35.032893725803916, 35.918368680136545, 34.654102257319856, 42.01910243715559, 48.545510632651194, 39.95518520900181, 40.57055589130947, 40.26706552505493, 44.80269323076521, 50.01292848587036, 49.50803068705967, 56.64734990256173, 50.381440094539094, 47.854487964085166, 50.267854418073384, 50.649261883326936, 47.78051744188581, 55.45022392272949, 56.2147342136928, 57.470829554966514, 54.82581015995571, 60.97706426892962, 57.178949628557476, 55.90098135811942, 57.976140771593364, 57.14902721132551, 55.17018372671944, 54.72261551448277, 55.94702359608242, 50.48996748243059, 47.371886934552876, 48.543349742889404, 48.737861088344026, 45.86670562199184, 51.245566708701, 47.63625546864101, 43.974183082580566, 47.19930410385132, 41.852772985185894, 39.37842566626412, 44.56248358317784, 43.715751784188406, 28.952631098883494, 17.751794508525304, 8.04699192728315, 4.3696877871240885, 5.433892122336796, 8.15088312966483, 11.061444435800825, 18.570248876299175, 20.424212387629918, 27.300920963287354, 19.262242555618286, 24.024049758911133, 17.210990156446183, 16.521810497556412, 18.520730801991053, 5.178181477955409, 2.7790338609899794, 0.6496542883770806, 0.18149823801858084, 0.15906687453389168, 0.1973077646855797, 0.14211290356303963, 0.12943134190780775, 0.1684395737413849, 0.14952142031065055, 0.20657077192195825, 0.17888300120830536, 1.2053096549851554, 44.57172816140311, 67.13909503391811, 56.49057422365461, 42.636950152260916, 46.67281130381993, 42.48522581372942, 25.382790837969097, 1.1612895599433353, 0.44920931703277994, 14.051927396229335, 64.4138239451817, 53.116626262664795, 100.2342334474836, 28.36719846725464, 2.398019837481635, 64.07790633610317], [40.04339953831264, 1.932029128074646, 0.039972060293491395, 6.4881939717701504, 3.150007954665593, 1.2508926604475294, 17.909162521362305, 1.4574175498315265, 25.362418719700404, 49.613771847316194, 44.710532324654714, 59.28753335135323, 41.18813957486834, 25.823098182678223, 43.019000325884136, 45.98290034702846, 6.892643400600978, 0.6340030367885316, 0.5564503382359232, 0.007699128207085388, 0.259951651096344, 0.09837040398269892, 0.32486354080694063, 0.1526958378297942, 0.156452831945249, 0.062332683109811375, 0.0968356527654188, 5.764536048684802, 57.32493822915213, 74.28223923274449, 52.85539484024048, 60.39481912340437, 53.38450363704136, 58.47722053527832, 50.886803422655376, 48.88157067980085, 26.62687795502799, 13.076263087136404, 5.086652423654284, 25.343717643192836, 53.624504838671, 57.175690923418315, 51.59148277555193, 49.03551149368286, 57.92057255336216, 56.38230044501168, 50.71998412268502, 51.84696108954293, 51.94691440037319, 50.86529527391706, 50.55601011003767, 53.0599741254534, 53.093995979854036, 55.04487296513149, 54.731797558920725, 50.778592177799766, 49.28754002707345, 48.357509749276296, 51.5192597252982, 52.89830344063895, 54.90895925249372, 58.16888380050659, 53.17438316345215, 51.69417715072632, 52.53191103254046, 56.17289563587734, 58.46727071489607, 53.82538768223354, 56.336376326424734, 48.97739328656878, 47.98487785884312, 44.90454339981079, 42.77872814450945, 47.02514403206961, 47.16381965364729, 49.88506773539952, 52.095046520233154, 48.57179914202009, 46.51900250571114, 44.559839793613975, 39.59142269407, 43.98448726109096, 47.78315428325108, 47.743945598602295, 42.080521038600374, 36.21565430504935, 35.9664363179888, 35.29874917439052, 35.70815440586635, 32.88462536675589, 33.81966182163784, 32.89272001811436, 38.56094578334263, 44.94691351481846, 44.875718797956196, 39.517511231558665, 36.36838265827724, 43.37478630883353, 38.46126692635672, 47.02847569329398, 47.21325956072126, 45.71812186922346, 46.55342388153076, 45.575204372406006, 44.611155714307515, 46.247720514025005, 44.72935152053833, 41.991865498679026, 48.7134416443961, 52.827060086386545, 53.74322870799473, 50.67525162015642, 55.63969087600708, 48.98340695244925, 50.71638148171561, 52.42576340266636, 52.80705969674246, 47.10461752755301, 52.31510639190674, 43.48989364079067, 42.445791312626426, 43.8275865146092, 40.77720921380179, 38.67461831229073, 33.98863506317139, 31.543577875409806, 30.049409457615443, 26.410828930991038, 26.45437502861023, 29.412124156951904, 30.36097710473197, 28.97597704614912, 16.364327839442662, 7.5224602563040595, 3.2216972964150563, 1.191892032112394, 1.6735489751611436, 3.652586792196546, 14.114616649491445, 19.728979110717773, 30.06864901951381, 39.22188970020839, 38.675608430589946, 33.24506664276123, 20.703521285738262, 26.448173761367798, 22.526285648345947, 19.982897554125103, 6.743814289569855, 0.8037160443408149, 0.1965450370418174, 0.11344646822128977, 0.03643867060808199, 0.03660015854984522, 0.06176985188254288, 0.04334355830880148, 0.02211201097816229, 0.07772486324289016, 0.1741283434842314, 0.26464309649808065, 20.91273328236171, 40.192535672869, 41.48698507036482, 20.46520675931658, 24.01222218785967, 9.850950990404401, 6.04552206822804, 0.5530513120549065, 0.17693613496209892, 5.838558682373591, 38.62512976782662, 48.399226733616416, 77.49760845729283, 13.110171164785113, 0.6854917396392141, 13.439155340194702, 63.754815101623535, 7.973032695906503, 0.1615135089627334, 6.738899741853986, 5.710831684725625, 3.1297035813331604, 23.379340308053152, 2.034643816096442, 38.849084104810444, 70.04344204493931, 44.47147955213274, 53.57414429528372, 57.02795832497733, 32.813652992248535, 49.772072655814036, 63.52885968344552, 9.06972072805677, 0.5652766674757004, 0.28139058926275795, 0.09088207116084439, 0.08998728024640254, 0.058972346995558055, 0.042336496990174055, 0.05640414623277528, 0.14671662795756543, 0.05685035764638867, 0.13023627442973001, 6.351834271635328, 59.5966864994594, 70.8478558404105, 63.17348711831229, 68.26951830727714, 61.16125406537737, 61.657383237566265, 57.03081750869751, 64.67049734933036, 42.67356368473598, 20.54192008290972, 18.07753300666809, 36.577832630702424, 61.46925381251744, 55.55537101200649, 53.006049156188965, 54.34694031306675, 58.476171357291086, 60.61358315604073, 57.858000550951274, 58.36204024723598, 57.59078325544085, 52.53787606103079, 51.77672522408621, 55.67128780909947, 54.36637442452567, 57.86864171709333, 56.468152386801584, 54.79526935304914, 53.309292861393516, 53.86012520108904, 53.771136147635325, 55.49066938672747, 57.3985960824149, 58.70294666290283, 55.078599521092, 53.63848461423601, 52.94741678237915, 57.86863824299404, 57.993188176836284, 55.78911188670567, 55.14548635482788, 50.101187978472026, 49.707569054194856, 46.95620400565011, 46.51469462258475, 50.321192264556885, 48.14391170229231, 52.214559010096956, 53.07200493131365, 49.01947157723563, 47.381145409175325, 45.348338740212576, 40.51077706473214, 46.7591461454119, 50.598873547145296, 52.36712408065796, 44.22490188053676, 37.54537623269217, 38.06143283843994, 35.918128967285156, 36.553882190159385, 35.538969244275776, 33.632755279541016, 35.21733365740095, 39.96082019805908, 46.883150645664756, 47.091586181095664, 42.4678761618478, 39.61995547158377, 45.255906854357036, 39.38447059903826, 48.20503847939627, 49.984736170087544, 49.74612808227539, 48.81783832822527, 48.599981035505024, 47.25519888741629, 47.22047873905727, 49.07151011058262, 45.95495121819632, 51.34688534055437, 54.93512964248657, 54.95172541482108, 51.66746827534267, 55.435663972582134, 51.8011794090271, 51.79761150905064, 54.504528931209016, 54.274345534188406, 50.08201789855957, 52.56604058401925, 46.551589557102744, 43.157464027404785, 48.642486640385215, 44.40260900769915, 41.72591624941145, 37.853702545166016, 37.0076516696385, 34.262446199144634, 33.18186930247715, 34.3808330808367, 35.19545725413731, 33.605792794908794, 28.42937442234584, 17.290854488100322, 7.7770761251449585, 4.139897831848689, 2.4988740256854465, 1.645598217844963, 4.3233068244797845, 14.521146195275442, 22.720588547842844, 34.795755181993755, 40.031928062438965, 38.824008056095664, 35.893268312726704, 18.6282958643777, 29.6712190083095, 27.723713636398315, 24.163522686277116, 9.190034866333008, 2.610937829528536, 0.29234019028288977, 0.08437899154211793, 0.0966499038040638, 0.02059850299597851, 0.05735868215560913, 0.06824919634631701, 0.007519370709945048, 0.07925207593611308, 0.18899801772619995, 1.475449862224715, 38.14918858664376, 49.99148634501866, 54.5821715763637, 29.56153474535261, 35.82887240818569, 13.138267942837306, 9.06674255643572, 0.5939579627343586, 0.27041642527495113, 14.004512889044625, 57.744095257350374, 58.81559085845947, 87.1508241380964, 14.5493289572852, 1.2632444947957993, 39.27180903298514, 69.19426100594657, 11.91952177456447, 1.1188663563558032, 13.406958256449018, 9.050116385732379, 17.284552471978323, 53.0287697655814, 2.3573865549904958, 51.541243825639995, 80.05970805031913, 51.08135298320225, 71.87821810586112, 64.04061535426548, 32.688832078661235, 62.78260925837925, 72.87643105643136, 8.11975519997733, 0.726957557456834, 0.5530528319733483, 0.1709530438695635, 0.3994765542447567, 0.16439935910914624, 0.3885208192680563, 0.2005992702075413, 0.35559048343982014, 0.15919764180268559, 0.16633949428796768, 9.46034584726606, 64.45260878971645, 78.02091898236955, 68.5022690636771, 72.28593839917863, 65.55549635205949, 66.28650937761579, 64.8350932257516, 70.70572349003383, 57.87657655988421, 37.48390899385725, 25.6725845677512, 41.475235666547505, 71.52994659968785, 66.01781558990479, 62.92504038129534, 61.93180234091622, 64.94520827702114, 63.79330117361886, 60.932137216840474, 60.35114969526018, 61.02421474456787, 56.669584138052805, 55.11939934321812, 57.207138470241, 57.34061336517334, 60.04380307878767, 58.94004699162075, 54.866985184805735, 54.33964123044695, 55.4424523626055, 56.96804748262678, 57.3049065726144, 60.72480297088623, 63.77702154432024, 57.93883241925921, 57.235219614846365, 56.26590074811663, 60.49811799185616, 62.185126713344026, 58.3664037159511, 59.20591981070382, 52.29910469055176, 53.402541160583496, 50.45119653429304, 49.16508844920567, 52.6210355758667, 52.111847264426096, 54.35602160862514, 56.70421743392944, 51.31910644258772, 48.92484406062535, 46.484122548784526, 41.173583098820274, 48.71518564224243, 52.77162388392857, 52.01996428625924, 42.73836953299386, 36.19860689980643, 35.821500369480674, 35.16299874441964, 36.71163756506783, 34.769643851688926, 33.93260826383318, 34.24036482402256, 40.10474518367222, 48.73853506360735, 50.654268060411724, 42.60143443516323, 39.572871003832134, 44.21877704347883, 40.23623636790684, 50.91140699386597, 51.54791062218802, 52.501759324754985, 50.760019642966135, 49.26976653507778, 48.52277612686157, 51.46482406343733, 51.21518223626273, 48.02929074423653, 55.039147649492534, 54.96305445262364, 56.04818589346749, 53.284623282296316, 60.05801909310477, 54.65039941242763, 55.63149547576904, 58.1620328766959, 56.8854056085859, 51.08635916028704, 58.50732013157436, 49.55954463141305, 46.72357831682478, 51.18074001584734, 48.064264501844136, 46.28987523487636, 42.64118160520281, 43.57269879749843, 43.72550358091082, 41.92323466709682, 40.54179034914289, 45.764070306505474, 44.41280548913138, 32.256761823381694, 20.119500875473022, 9.521555134228297, 4.275590070656367, 4.038639562470572, 2.7580774426460266, 8.795041935784475, 20.8362284047263, 28.896844012396677, 42.40570715495518, 45.65465007509504, 46.89871808460781, 40.32915462766375, 27.891443150384085, 44.51645524161202, 38.86846610477993, 30.438814299447195, 11.547545620373317, 3.9311313884598866, 0.24909709926162446, 0.2057302434529577, 0.13810145881559166, 0.17434339837304183, 0.14777768030762672, 0.3562704026699066, 0.14028151040630682, 0.21221047001225607, 0.351912579366139, 2.3588122384888783, 54.75251361301967, 60.105968611580984, 65.8774550301688, 40.39740678242275, 48.58278424399239, 36.7362619808742, 11.036029662404742, 0.5353674952472959, 0.3659496232867241, 20.938014302934917, 74.27638190133231, 65.90547016688755, 102.63418987819126, 19.4018839768001, 1.6945268894944872, 46.5753767149789], [47.70803036008562, 4.723138306822095, 0.25497258827090263, 4.456898970263345, 1.2578469387122562, 4.525652698108128, 14.399743795394897, 2.421559900045395, 5.901658313614981, 53.964841502053396, 40.30983863558088, 53.49842282703945, 66.44109984806606, 53.834267480032786, 48.83552844183785, 47.54732200077602, 12.707002810069493, 0.7137665652803012, 0.4143766132848603, 0.11736565934760229, 0.14189566379146917, 0.11131789708243948, 0.10144350943820817, 0.17380827851593494, 0.041081909489418776, 0.08140590893370764, 0.24686623896871293, 9.75724150453295, 75.21659129006522, 58.41738264901297, 38.54151167188372, 38.47912379673549, 41.7775239944458, 53.61660473687308, 45.945126465388704, 42.15514816556658, 25.93859808785575, 13.491948621613638, 6.942543191569192, 5.790956139564514, 24.31261018344334, 53.090257849012104, 57.26291513442993, 50.68111937386649, 56.17245789936611, 60.500223296029226, 56.08197498321533, 54.109513419015066, 52.5387966973441, 46.29200833184378, 49.07497031348092, 50.07516697474888, 53.39849730900356, 51.073348658425466, 55.494344983782085, 52.26910931723458, 54.91866588592529, 49.7135340826852, 50.771577971322195, 50.230827467782156, 52.15374837602888, 52.57760238647461, 53.1318393434797, 51.97364412035261, 52.57559783118111, 58.22799907411848, 55.51819814954485, 55.72795384270804, 53.690418924604145, 49.81433159964425, 44.014826570238384, 40.78732231685093, 46.81161894117083, 46.69967303957258, 53.176832403455464, 50.96389716012137, 51.72829627990723, 45.87748227800642, 45.70567764554705, 43.16654879706246, 43.23179933003017, 45.5634514944894, 48.891433647700715, 48.11024073192051, 46.96633447919573, 41.33369738715035, 44.602630274636404, 39.50486203602382, 37.331396034785676, 37.72848905835833, 43.03573158809117, 40.942802156720845, 46.01840911592756, 44.7967073576791, 47.27284036363874, 43.763110705784385, 38.918791907174246, 44.271621567862375, 42.800778252737864, 41.03090531485421, 42.576820441654746, 44.75001893724714, 44.76910563877651, 45.408183574676514, 45.91656936917986, 43.29637588773455, 47.827692236219136, 43.6052302633013, 45.311440331595286, 51.968141147068565, 52.93212032318115, 51.42176955086844, 51.563040324619834, 51.787189211164204, 47.826577050345286, 48.61518369402204, 47.58450181143624, 47.13465806416103, 47.4688594681876, 42.98850468226841, 40.03618383407593, 42.46552072252546, 38.82517882755825, 38.638623169490266, 33.11424943378994, 27.958732979638235, 24.92765256336757, 25.37597986630031, 31.235505172184535, 33.42699480056763, 25.221088886260986, 22.677530561174663, 9.510129690170288, 3.6614566019603183, 2.393310913017818, 0.8245551032679421, 1.0679222728524889, 9.899855017662048, 26.72185809271676, 33.20069892065865, 37.71512419836861, 53.91312605994088, 56.75533185686384, 52.11203833988735, 46.313759667532786, 19.38681333405631, 17.90823667390006, 18.95660867009844, 13.103513053485326, 3.133131431681769, 0.4644948925290789, 0.010205094586126506, 0.09844073413738183, 0.08374707866460085, 0.028712212706782987, 0.06518982443958521, 0.06744543090462685, 0.03405216795259288, 0.37767975670950754, 5.319465279579163, 42.156610761369976, 39.15245287758963, 48.36690371377127, 21.69861102104187, 27.178877592086792, 8.476916057722908, 6.176896435873849, 1.3107689789363315, 1.867274739912578, 32.176131452832905, 33.79957457951137, 47.75472920281546, 72.66491399492536, 4.365669991288867, 0.24276932595031603, 13.16691710267748, 59.512849535260884, 6.832537140165057, 0.5574087553790638, 4.306628108024597, 3.8582769206592014, 3.7109121424811224, 29.502732140677317, 1.533578274505479, 14.760775668280465, 75.31572123936245, 42.06839295795986, 56.04639673233032, 61.51706436702183, 52.89530529294695, 52.5457900592259, 67.2755229132516, 17.350958142961773, 0.8795661628246307, 0.2563107136104788, 0.19750599190592766, 0.08270154441041605, 0.12527382214154514, 0.06463379213320357, 0.17108683740454061, 0.11229623601372753, 0.017999986984900067, 0.1546978825437171, 10.084571140153066, 78.01603439876011, 67.9242970602853, 53.965974058423726, 57.37127576555525, 55.309866837092805, 60.71278258732387, 54.25789567402431, 58.739667892456055, 41.369320801326204, 27.52085750443595, 13.136418853487287, 19.818902696881974, 39.88051291874477, 54.08652182987758, 57.17321041652134, 53.24191965375628, 56.349550110953196, 60.91329370226179, 59.38957459586007, 58.1411257471357, 56.83194269452776, 51.52906363351004, 52.93170690536499, 54.11515883037022, 56.59969220842634, 56.55113124847412, 57.57274920599801, 57.18361186981201, 55.702447005680625, 52.924946308135986, 56.05738878250122, 52.588024684361045, 54.25312573569161, 54.649141788482666, 55.21780320576259, 53.87493528638567, 54.7828494480678, 59.56128542763846, 54.387020996638704, 58.11675146647862, 53.93905326298305, 52.27867003849575, 45.62335886274065, 46.18965441840035, 47.7467804636274, 51.0549567767552, 53.11074113845825, 52.35714646748134, 50.82661465236119, 44.7269161769322, 46.72574268068586, 44.55663667406355, 45.33016225269863, 46.22621236528669, 51.44601876395089, 49.607306548527305, 49.531856060028076, 43.973745346069336, 48.00723716190883, 40.30425923211234, 36.831865719386506, 39.59553950173514, 46.54280355998448, 42.539741379874094, 47.93989174706595, 48.150839056287495, 50.45941277912685, 44.35632010868618, 40.83333676201956, 44.471114771706716, 43.177839619772776, 40.602597509111675, 43.92502457754952, 47.183514322553364, 47.52791568211147, 48.37973356246948, 48.752490520477295, 45.582030977521626, 49.88891008922032, 48.79507950374058, 47.251610142844065, 54.63615560531616, 54.08712979725429, 53.69697454997471, 51.313502720424104, 54.06273119790213, 50.11614745003836, 52.34965283530099, 51.55040155138288, 49.8384244782584, 49.23221846989223, 47.49387993131365, 40.665694100516184, 48.25965826851981, 41.48887498038155, 42.91699382237026, 38.9109890801566, 35.00828320639474, 30.482900619506836, 32.73921346664429, 36.81237949643816, 35.50502382005964, 27.18039924757821, 25.1616279397692, 11.261672411646162, 3.68696300472532, 2.968061557837895, 1.4831903725862503, 1.470540308526584, 9.131144540650503, 27.928888729640416, 34.026363781520296, 42.12587193080357, 54.487290450504844, 56.48521716254098, 51.25826106752668, 49.986073698316304, 32.82940455845424, 21.599809374128068, 23.94320920535496, 18.035871607916697, 5.788626321724482, 0.4094682809497629, 0.008942755670951945, 0.10747446439095906, 0.0915443959778973, 0.0769443376255887, 0.032245995942503214, 0.05865302163043192, 0.10294239329440252, 0.5840007056082998, 10.092501640319824, 59.12153393881661, 50.45285715375628, 60.69488402775356, 29.537573882511683, 42.52787733078003, 29.91414887564523, 9.681981222970144, 1.9250572621822357, 2.3774883449077606, 53.437045914786204, 47.330406188964844, 61.081009319850374, 81.80570002964565, 4.036070900303977, 0.527638384274074, 29.743240560804093, 75.75456946236747, 13.704599976539612, 1.6247934656483787, 7.118479830878122, 5.03886662210737, 25.19938792501177, 50.12393290655953, 3.5804905465670993, 27.318305356161936, 94.3153132029942, 48.02517393657139, 64.55066176823208, 92.40150138310024, 71.0806552342006, 58.79364149911063, 79.09019115992955, 19.198817661830358, 0.8731960217867578, 0.47289977009807316, 0.2875785572188241, 0.20964423700102738, 0.34452892414161135, 0.35843598789402414, 0.4408449615750994, 0.26799446237938745, 0.4655183404684067, 0.38691421119230135, 15.714033773967198, 86.4514810017177, 75.08672251020158, 67.28421510968889, 63.62282712118966, 63.236924171447754, 65.07014383588518, 63.769281251089915, 67.90786457061768, 61.28248623439244, 46.34453671319144, 20.94393937928336, 25.017986093248638, 50.70029640197754, 64.27565901620048, 62.032162121364046, 60.67983422960554, 63.371795654296875, 66.88563169751848, 62.55051163264683, 62.407191140311106, 59.81769480024065, 54.04456513268607, 54.46032796587263, 55.647771630968364, 58.3758602142334, 58.82973739079067, 62.06289400373186, 57.995091983250205, 58.90129688807896, 56.37477554593767, 56.28095402036394, 54.476659706660676, 57.136426653180806, 56.8361359323774, 58.628197942461284, 56.79796947751726, 58.623473167419434, 64.45750726972307, 57.766548361097065, 59.10963862282889, 58.44631494794573, 54.17548656463623, 49.46837731770107, 45.990824767521445, 50.71678100313459, 50.51831265858242, 56.59947681427002, 54.321645396096365, 57.383355208805625, 46.29978684016636, 48.87162780761719, 45.00952025822231, 47.248257637023926, 47.72401816504342, 54.761577538081575, 53.614725249154226, 50.12628139768328, 43.96038048607962, 50.03251893179757, 39.481616837637766, 39.52069698061262, 39.21574401855469, 48.29630306788853, 42.953596932547434, 50.664551394326345, 50.9633378301348, 51.976777757917134, 45.82167782102312, 42.2979336466108, 47.10900184086391, 41.84907306943621, 43.591684750148225, 45.27266590935843, 49.32485185350691, 49.665876388549805, 49.88764551707676, 49.767174175807405, 48.71510921205793, 52.694040298461914, 49.309388637542725, 52.93867594855172, 56.78534460067749, 56.35464661461966, 55.09747082846505, 53.404830592019216, 57.532856123788015, 53.54538917541504, 53.42683901105608, 52.99473748888288, 51.736981528145925, 53.20757818222046, 50.35927881513323, 44.681839738573345, 52.89178255626133, 47.48310674939837, 50.20758921759469, 46.684341839381624, 41.86016239438738, 40.1677896635873, 41.864470277513774, 46.027733598436626, 43.61697619301932, 31.153099536895752, 28.504776273454937, 13.148376703262329, 5.30956757068634, 3.580604757581438, 2.2164703564984456, 7.003497566495623, 16.489096641540527, 32.53389767238072, 40.56726939337594, 49.646873065403526, 58.519896371024, 60.32260649544852, 59.82564353942871, 59.09541566031319, 37.213127272469656, 25.712422064372472, 30.78136396408081, 26.6998861517225, 9.662379486220223, 0.9640663542917797, 0.1046735125460795, 0.11603137451623168, 0.11095754749008588, 0.1444362753203937, 0.16987154047404016, 0.1269733759441546, 0.14374631377203123, 1.071843988129071, 10.776319026947021, 72.03489303588867, 61.16921670096261, 73.67136750902448, 39.11234440122332, 53.141528606414795, 41.411607537950786, 21.084244353430613, 5.119873932429722, 2.9795332508427754, 66.8336661202567, 56.33337470463344, 71.67706080845424, 98.3932248524257, 7.46709440435682, 0.6098128291113036, 31.002935068947927], [67.66052259717668, 9.74534010887146, 0.7660802581480571, 2.3437817650181905, 0.5062193678958076, 3.107857793569565, 8.525953837803431, 1.8129830360412598, 1.463786659496171, 40.470838819231304, 45.54390968595232, 38.16638537815639, 94.35382011958531, 71.41391168321881, 49.42297083990914, 52.038543769291465, 21.919845138277324, 0.7395572470767158, 0.4534485866980893, 0.102708814399583, 0.1783350706100464, 0.1732891992266689, 0.2560438593583447, 0.043778438187603436, 0.1585527756916625, 0.1653441512691123, 0.2368387941803251, 20.973001956939697, 67.5317029953003, 47.58090264456612, 26.925817251205444, 26.608590296336583, 24.677357605525426, 37.73460694721767, 43.46175691059658, 45.83097798483712, 37.750834465026855, 19.479653426579066, 4.83404632125582, 7.576368723596845, 7.411018099103655, 30.5651672908238, 51.43476963043213, 49.318563733782085, 48.12868472508022, 53.3978476524353, 58.48309176308768, 52.898970467703684, 51.020875862666536, 47.50820711680821, 47.42033672332764, 48.54587541307722, 50.72574765341622, 52.33093091419765, 54.102540901729036, 54.487832409994944, 50.74657835279192, 50.3223317691258, 51.539013453892295, 48.871857098170686, 49.074001039777485, 51.611774989536826, 54.77997636795044, 50.98354319163731, 56.21417835780552, 51.05739906855992, 57.73367990766253, 55.34763029643467, 51.604819842747276, 47.04067325592041, 44.0918265070234, 48.689574582236155, 45.70192561830793, 49.94088956287929, 50.86081368582589, 49.03649466378348, 46.4783798626491, 45.01718412126814, 42.44692734309605, 48.116803305489675, 45.8047902243478, 43.38733128138951, 47.29357031413487, 45.332861627851216, 46.85395778928484, 41.4737001146589, 44.45251096997942, 43.682994501931326, 39.2982052394322, 40.95235592978341, 46.12108959470476, 42.17677443368094, 46.57376820700509, 43.07350894383022, 47.04848303113665, 41.033139160701204, 44.04262631280081, 44.96764693941389, 38.69006068365914, 42.29035663604736, 41.660502433776855, 42.77222810472761, 44.00289303915841, 45.009214537484304, 46.886082785470144, 43.5292204448155, 44.28012963703701, 47.49650982448033, 45.66832760402134, 44.96171317781721, 52.65535620280674, 50.60839605331421, 51.171960966927664, 48.94571297509329, 48.160458837236675, 47.91043833323887, 51.44018922533308, 46.6100378036499, 43.44822876793997, 42.093955380576, 39.953805991581504, 38.89296892711094, 36.885783740452354, 33.01787097113473, 32.761155877794536, 25.191560779299053, 25.184418031147548, 26.744557857513428, 27.215051651000977, 26.70362080846514, 24.550646781921387, 22.750601291656494, 8.618833013943263, 2.635585044111524, 1.8268596742834364, 0.8983640798500606, 1.9895096208368028, 8.75006798335484, 28.10904335975647, 49.69589260646275, 51.52475227628435, 58.44251428331648, 59.203918729509624, 56.35765518460955, 28.699940749577113, 18.9058746610369, 16.0260009425027, 8.707403438431875, 14.0337187732969, 13.619070257459368, 2.2459350611482347, 0.8565470523067883, 0.1531585580004113, 0.01990212420267718, 0.038613857102713416, 0.10493185118372951, 0.04299961569319878, 0.10375635711742298, 0.018032147848446454, 9.130463617188589, 35.90823820659092, 45.9506641796657, 44.5512136050633, 25.166057416370936, 22.78850892611912, 40.77322094781058, 13.772712298801967, 1.9458104457174028, 10.988616892269679, 33.131970814296174, 29.572012628827775, 67.21513611929757, 41.35619912828718, 0.07893678106899772, 0.27283901242273195, 9.1747453553336, 55.24734694617135, 12.074497001511709, 1.568860684122358, 2.8906464661870683, 2.3484259843826294, 5.524667297090803, 25.11884961809431, 0.8607163514409746, 3.5551526376179288, 63.145736013139995, 48.18007707595825, 42.19553804397583, 100.64769990103585, 74.41042654854911, 49.446462699345176, 69.45585373469761, 29.02080682345799, 0.8633647550429616, 0.2989240155688354, 0.19905586088342325, 0.1478941033461264, 0.1692699920386076, 0.12134610861539841, 0.016058949354503835, 0.06400092930666038, 0.12886597295956953, 0.20928252355328628, 22.557847840445383, 74.1054492677961, 60.649929182870046, 46.599938596997944, 40.211664063589915, 44.968164580208914, 53.71064165660313, 56.26363563537598, 58.19594355991909, 49.61994184766497, 34.496048109872, 16.695541518075125, 12.24581526006971, 27.030575241361344, 43.384750025612966, 52.347759451184956, 49.04552732195173, 50.52002191543579, 54.82149185453142, 60.09323951176235, 57.33443641662598, 56.292283058166504, 53.12209102085659, 50.48199789864676, 51.636058943612234, 54.33582319532122, 56.51434053693499, 56.642090116228374, 55.460997104644775, 52.37310995374407, 54.96864775248936, 55.44038527352469, 52.19104630606515, 53.55468239103045, 52.74342809404646, 55.30854320526123, 53.78369501658848, 58.2531133379255, 54.436825684138704, 59.168135506766184, 56.79141732624599, 52.55690022877285, 47.42467934744698, 48.1537572996957, 49.81447056361607, 48.77059057780674, 50.430928639003206, 51.03798580169678, 51.038524287087576, 48.73139578955514, 46.346079213278635, 43.33395174571446, 50.76945877075195, 48.06401089259556, 46.11443322045462, 48.433707169124055, 46.60631704330444, 48.66787188393729, 43.64516503470284, 46.27850450788225, 45.328949792044504, 41.80248539788382, 44.368305751255576, 46.39964287621634, 44.01308604649135, 47.49853869846889, 43.80510561806815, 47.54228455679757, 44.2844375201634, 46.77793754850115, 48.78691189629691, 43.609058720724924, 43.24202013015747, 44.21364579881941, 44.51390872682844, 48.15131500789097, 47.231946740831646, 49.47647544315883, 48.05264016560146, 47.06429713112967, 52.78778886795044, 49.79387957709176, 48.8155871118818, 55.20238515308925, 53.645269530160085, 52.14830446243286, 50.87261520113264, 50.7441360609872, 49.06951945168631, 54.829391956329346, 50.214009353092735, 46.106540066855295, 44.96017762592861, 42.01333890642439, 43.12833717891148, 39.84660223552159, 36.07025630133492, 35.5306522505624, 31.748685223715647, 32.82599994114467, 33.333454677036826, 28.780289718082972, 28.683805295399257, 26.284736497061594, 21.355514185769216, 8.847104787826538, 3.7386063592774526, 1.991391496998923, 0.5011774727276394, 3.4410905752863203, 12.861121671540396, 31.358175618307932, 48.192337172372, 52.62074722562517, 58.38779027121407, 60.50748416355678, 61.27975559234619, 40.854132720402305, 22.1130884374891, 19.11995734487261, 9.927213549613953, 18.50444769859314, 17.245647771017893, 1.9807355659348624, 1.0409205960375922, 0.19955766467111452, 0.029755453512604748, 0.04085049172863364, 0.004068649914448282, 0.015660591623080627, 0.07554872679923262, 0.13051682151854038, 16.537563800811768, 50.94873966489519, 56.94035543714251, 56.754202774592805, 34.72106899533953, 31.95395932878767, 61.403308459690635, 22.08637261390686, 4.6760303889002115, 19.418637820652553, 44.64809928621565, 26.846022401537212, 78.59399945395333, 41.75940656661987, 0.10760002729615994, 0.2362993045576981, 22.515766075679235, 87.26343359266008, 27.51546049118042, 2.1116252967289517, 6.029052666255406, 1.4700046458414622, 23.527420316423687, 41.69486474990845, 1.9043366483279636, 7.063424042293003, 81.66521440233502, 60.67848627907889, 49.213850906917024, 119.5020397731236, 86.0526682989938, 55.23309619086129, 86.25124781472343, 29.8449204989842, 0.6717790897403444, 0.4982858821749687, 0.34112560961927685, 0.33432991855910843, 0.2551410820867334, 0.44032775504248484, 0.08842154033482075, 0.21720775828829833, 0.25666895295892445, 0.37090523594192093, 33.0805333001273, 81.14379378727504, 71.57723603929792, 60.54602582114083, 48.40337133407593, 56.09591654368809, 60.73272391727993, 61.51245771135603, 64.66110338483537, 63.111342430114746, 57.117378166743684, 39.910511766161235, 19.114403997148784, 34.616241523197715, 51.31858532769339, 59.964308738708496, 54.15436404091971, 56.90749740600586, 59.0609039579119, 64.75405638558524, 58.999648639133994, 56.79082325526646, 55.82329702377319, 52.828171798161094, 55.95120988573347, 56.1540972845895, 58.547334807259695, 58.83160645621163, 59.56831005641392, 55.228722299848286, 58.74810995374407, 58.580220631190706, 53.61562851497105, 55.87199347359793, 58.69540091923305, 57.90618283408028, 56.519475255693706, 62.337396485464915, 56.73571014404297, 62.66544873373849, 60.65812805720738, 53.80064862115042, 51.194514819553916, 48.89415386744908, 53.25333901814052, 52.06527001517159, 53.67153024673462, 53.73299748556954, 51.74517345428467, 49.78174107415335, 48.25787952968052, 43.13106434685843, 52.74066965920584, 51.4012063571385, 48.57360219955444, 51.74034793036324, 49.260733876909526, 51.194685050419395, 44.47116340909685, 49.12027604239327, 46.53962823322841, 42.070731026785715, 44.54646798542568, 49.03169345855713, 47.39219651903425, 50.560206821986604, 46.02541637420654, 49.395518507276265, 45.14575706209455, 49.25865636553083, 51.63925164086478, 44.346627371651785, 43.14704172951834, 44.75019611631121, 47.17322056634085, 48.78991004398891, 49.4895658493042, 52.11725296292986, 48.578601428440635, 48.41547509602138, 53.80853830065046, 50.34991611753191, 50.088170528411865, 57.74905974524361, 55.66742461068289, 53.298349448612754, 55.329495498112266, 53.057979992457796, 54.64355891091483, 58.726264817374094, 52.1215295791626, 51.105341638837544, 49.000965050288606, 45.137422697884695, 47.62512445449829, 45.456094878060476, 44.80029957635062, 42.118392195020405, 37.71101781300136, 39.87747655596052, 43.364235469273154, 38.4792731830052, 33.244333607809885, 28.106894629342214, 24.852473054613384, 9.693447487694876, 5.149988727910178, 2.3992088479655127, 1.1900258979627063, 5.67023640019553, 17.419969388416835, 37.963567461286274, 54.7056097984314, 60.41432271684919, 61.627575465611045, 66.2476897920881, 64.36718068804059, 48.52567005157471, 34.59353481020246, 43.54829324994768, 17.00041457584926, 23.04121838297163, 26.3648579120636, 5.282286771706172, 3.2622411208493367, 0.2511436423020703, 0.08600662741810083, 0.15067824109324388, 0.12496025753872735, 0.11979683674871922, 0.22685047372111253, 0.3014810069331101, 22.78023362159729, 67.35487828935895, 64.50046103341239, 68.38331590379987, 44.86197526114327, 39.24236604145595, 69.28606060573033, 38.47275577272688, 14.819552217211042, 33.84541184561593, 60.99089813232422, 49.816978863307405, 92.76897771017892, 55.68182127816336, 0.2607749583465712, 0.3078777736851147, 29.33901868547712], [67.59013734545026, 20.165513583592006, 3.1169697046279907, 0.8835812445197786, 0.30008919590285843, 9.14350972856794, 9.607240319252014, 0.6362401396036148, 1.6458310910633631, 32.134935583387104, 47.17611796515328, 36.08945764814104, 37.01920999799456, 39.538897786821636, 45.17426552091326, 53.8682268006461, 33.77458190917969, 0.3492374414844172, 0.2567867466381618, 0.0885549538901874, 0.1539549274103982, 0.012086497470071273, 0.09031118572290454, 0.014897434805919017, 0.15631985265229428, 0.015232748152422053, 0.9124367875712258, 32.049670764378135, 58.823122705732075, 36.017856461661204, 22.5389278956822, 21.881715161459788, 18.222323043005808, 26.43185591697693, 33.11666393280029, 45.23832096372332, 39.02595049994332, 33.80187790734427, 19.059772048677715, 10.417683414050511, 8.88557435785021, 17.951186963490077, 37.34832532065255, 44.11733681815011, 47.749768189021516, 45.2175076348441, 58.652516637529644, 55.210017749241416, 53.31811012540545, 46.436853953770225, 42.40459196908133, 43.67243324007307, 49.72258758544922, 54.35915524618966, 54.46574756077358, 53.512291431427, 48.58207205363682, 52.13793427603585, 51.32573502404349, 49.650680678231375, 52.847817829677034, 49.55508041381836, 50.204382623944966, 51.13111250741141, 53.379678113119944, 54.60116447721209, 54.12383018221174, 53.067165510995046, 51.09305722372872, 44.877671241760254, 49.8868534224374, 46.963457924979075, 48.519100529806956, 44.74027756282261, 47.37783806664603, 44.981842109135215, 46.91448354721069, 41.09133032390049, 45.75653498513358, 48.42065497807094, 42.947208063943044, 43.57361248561314, 45.14947782244001, 42.2535138130188, 43.420095511845176, 42.89062540871756, 41.63473156520298, 41.831139768872944, 44.548872062138145, 41.328246525355745, 41.03966004507882, 40.844787393297466, 43.26985808781215, 40.460155963897705, 42.735823018210276, 42.12217548915318, 40.82947356360299, 44.92836529867989, 41.79378277914864, 38.075353554316926, 45.471460819244385, 40.64481128965105, 42.02906615393502, 42.73690693719046, 45.4084267616272, 45.93779264177595, 47.89031982421875, 46.65234191077096, 48.835479804447715, 43.11528846195766, 52.376886299678254, 50.95194278444563, 48.0838097844805, 48.59093795503889, 47.84248495101929, 46.82940285546439, 49.80462496621268, 44.500790527888704, 41.66179132461548, 41.514885561806814, 36.59519270488194, 37.586019720349995, 34.28389876229422, 31.41040870121547, 26.714317560195923, 23.957618032182964, 27.905730383736746, 19.199771302086965, 19.58985706738063, 27.010383776256017, 26.27816002709525, 17.362024886267527, 5.889793395996094, 2.272055510963712, 0.8907022795506886, 0.4019138791731426, 2.0327289359910146, 15.072285992758614, 34.837791783469065, 46.61289698737008, 57.254049233027864, 56.45095212118966, 58.565573828560964, 48.72651468004499, 47.40993527003697, 45.505837031773154, 51.992313929966514, 26.86992941583906, 27.13772862298148, 37.57592051369803, 5.249846066747393, 4.7292006100927075, 1.6801825506346566, 0.05418677182335939, 0.009472967175367688, 0.0444831612652966, 0.08395219301538807, 0.24347394385508128, 0.2102298398635217, 11.577830212456838, 35.178343841007774, 46.70270940235683, 40.380182198115754, 29.642387458256312, 22.67097840990339, 42.18366357258388, 28.627208743776592, 5.129497621740613, 17.202051298958914, 15.78033869607108, 42.2409792627607, 53.32127155576433, 7.130445497376578, 0.29962676071694916, 0.37317998387983864, 7.696945156369891, 72.42256082807268, 19.394935778209142, 1.1493917469467436, 1.2987476182835442, 0.5754344452704702, 6.865705668926239, 16.306774173464092, 0.9100424274802208, 1.3652491526944297, 47.862283842904226, 53.83592462539673, 36.29873044150216, 49.48617860249111, 40.94045713969639, 49.24521507535662, 69.72605528150285, 46.518755844661165, 0.2929366225642817, 0.20440302895648138, 0.09820727737886564, 0.153377589104431, 0.04239940736442804, 0.07570889499038458, 0.0022120250089626226, 0.06854242525462594, 0.03939999081194401, 0.7921702010290963, 35.946290016174316, 67.78706318991524, 49.464666979653494, 38.349734442574636, 32.876148564474924, 34.67816039494106, 44.76499925340925, 50.99225970676967, 58.337061473301475, 55.226877553122385, 46.1460405758449, 28.513249601636613, 16.101944753101893, 21.794025421142578, 32.11375399998256, 46.401310443878174, 46.390043939862935, 47.08858455930437, 49.50033208302089, 59.38619777134487, 58.320253780909944, 59.47187600816999, 49.32847533907209, 47.48835958753313, 46.44950314930507, 55.32895006452288, 56.07832023075649, 58.31100572858538, 53.886712482997346, 53.66219186782837, 53.12872307641165, 55.093909876687185, 51.91366727011544, 54.78613247190203, 52.234437806265696, 53.72986732210432, 53.797949245997835, 55.777678625924246, 54.79879208973476, 54.7505715915135, 56.0969865662711, 52.58687823159354, 48.60283327102661, 51.53692899431501, 48.29337787628174, 48.961263043539866, 46.20827211652483, 49.68012714385986, 46.51095649174282, 47.1021648134504, 42.85065937042236, 47.72937870025635, 47.55594818932669, 44.639306340898784, 46.00731284277779, 46.41850028719221, 44.340606757572715, 47.26529809406826, 43.903582436697825, 44.26023694447109, 42.7724608693804, 48.347288949149, 42.755038261413574, 43.53374024799892, 43.98839562279837, 46.09128529684884, 42.47831930433001, 46.35149185998099, 45.277901376996724, 44.002719334193635, 44.15194232123238, 43.6056158883231, 40.97433655602591, 47.96869203022548, 42.69073615755354, 43.94638334001814, 46.48812123707363, 46.329021385737825, 45.440496172223774, 50.8874773979187, 50.39123010635376, 53.16407898494175, 47.01160546711513, 54.27595056806292, 54.086987359183176, 50.20210708890642, 53.17848954881941, 52.014249392918174, 49.54816000802176, 51.675472600119456, 46.9136323928833, 47.74684994561331, 43.41473150253296, 40.191340582711355, 40.431831632341655, 38.141177313668386, 35.340038844517295, 30.817477226257324, 31.548917566026958, 33.52275487354824, 22.209922007152013, 26.085720981870377, 28.051583494458878, 24.093959059034074, 19.922271047319683, 7.754017659596034, 2.42692369222641, 1.3895349523850848, 0.2157900407910347, 3.69151885168893, 15.308451788766043, 37.220697334834504, 50.62306022644043, 58.81782123020717, 56.03009625843593, 62.315169198172434, 51.65181050981794, 49.89411081586565, 47.23135266985212, 53.13795028414045, 23.76246224130903, 27.17814108303615, 32.91229656764439, 5.83736880336489, 6.975037745067051, 0.7032278850674629, 0.07982826073254858, 0.07126916572451591, 0.11292527190276555, 0.26762520362223896, 0.13138959397162708, 0.2458314187824726, 20.99408973966326, 51.00892496109009, 57.32140507016863, 55.652385234832764, 41.072639669690815, 31.243252413613455, 52.43077652794974, 43.21376180648804, 9.353216784340994, 27.481471640723093, 24.173647948673793, 53.33158268247332, 63.97085544041225, 5.750524571963719, 0.4125454644007342, 0.2537195783640657, 19.876294817243302, 89.73146152496338, 55.15785067422049, 4.786116344588144, 3.4134261054652075, 0.3166951462626457, 31.60521534511021, 30.450112070356095, 1.532910487481526, 9.622120755059377, 70.69778169904436, 63.17352185930525, 45.45459059306553, 55.1685265813555, 55.29677643094744, 59.83231381007603, 81.69251387459892, 51.84510939461844, 0.268994107310261, 0.351665484053748, 0.13187482793416294, 0.2888644082205636, 0.11679034307599068, 0.18116756076259272, 0.10893286684794085, 0.30227855699402945, 0.15947243491453783, 1.2362444464649474, 46.48618268966675, 72.54602336883545, 63.051330838884624, 52.49121543339321, 47.343114444187705, 46.63330732073103, 52.22419963564192, 58.12641641071865, 64.8398666381836, 64.94995389665876, 60.31565829685756, 53.253880977630615, 36.48236090796334, 35.2574907711574, 43.04290560313633, 52.79369831085205, 54.198856830596924, 53.65408679417202, 57.009382316044395, 63.42128767286028, 62.90920543670654, 61.28599507468087, 51.43651015417916, 48.711871351514546, 50.89311933517456, 59.198193413870676, 61.0786121913365, 61.96462563105992, 56.63187626429966, 55.82446084703718, 57.17595842906407, 58.28865337371826, 53.97556257247925, 59.30438968113491, 55.43852315630232, 56.00055946622576, 55.19990464619228, 58.18688658305577, 57.731192452566965, 59.93737057277134, 57.20884425299508, 57.56872967311314, 50.907606329236714, 56.00193520954677, 52.43056460789272, 51.11296033859253, 48.55077041898455, 50.77989843913487, 49.17294686181204, 49.815418992723735, 42.56760713032314, 49.018345969063894, 51.58731733049665, 45.844033649989534, 47.34205831800188, 50.24797909600394, 44.572874614170615, 48.363398347582134, 45.47661638259888, 46.172645228249685, 45.041165828704834, 49.18142366409302, 45.8838746207101, 46.28148181097848, 45.290703432900564, 48.59451627731323, 45.77607331957136, 49.305598395211355, 45.49532093320574, 48.48193808964321, 47.85751043047224, 45.99199206488473, 42.82670545578003, 49.682263714926584, 44.13053839547293, 46.79604107992989, 49.041087423052105, 47.73705645969936, 48.35938228879656, 52.27195807865688, 51.24795341491699, 55.40531424113682, 48.78475448063442, 59.00943865094866, 55.60640205655779, 51.13154329572405, 55.947339739118306, 56.06995807375227, 54.98696320397513, 55.68789747783116, 51.20704589571272, 50.95556974411011, 47.575253759111675, 44.61195823124477, 47.00818347930908, 47.160439355032786, 42.199922357286724, 39.71484701974051, 37.36715146473476, 46.53441708428519, 30.446262768336705, 28.630649839128765, 31.426969732557023, 26.41403205054147, 25.150026185171946, 10.815687520163399, 3.569619655609131, 2.675911303077425, 0.3900577553680965, 7.198148310184479, 25.914413145610265, 43.189012323107036, 57.97371932438442, 62.40435627528599, 61.370790890284944, 64.19874940599713, 59.99048955099923, 61.03340721130371, 59.1414544241769, 61.76821395329067, 44.10947493144444, 39.076797417231965, 45.63304117747715, 12.700215288570949, 11.957478046417236, 1.505322339279311, 0.05920684191265276, 0.1714826404516186, 0.23605926600950106, 0.2854076794215611, 0.22251110656985215, 0.3990777113607952, 27.858809198651993, 64.35004643031529, 67.89798423222133, 66.7610227039882, 51.81407526561192, 39.56150722503662, 61.40076541900635, 54.52327864510672, 27.452054704938615, 45.18236364637102, 44.30048091070992, 86.21531867980957, 85.78286279950822, 11.195350987570626, 0.9350131132772991, 0.43590348958969116, 32.535061495644705], [84.19194071633476, 33.441339356558665, 6.889134560312543, 2.5804135245936255, 2.5695274344512393, 13.930703912462507, 10.445816670145307, 2.2556275810514177, 6.826127861227308, 28.430097034999303, 50.84080982208252, 33.394682203020366, 47.81160020828247, 41.503608635493684, 44.816384656088694, 55.77455193655831, 43.5800986289978, 0.9556101794753755, 0.2729629671999386, 0.04249367284189377, 0.09876995254307985, 0.062269843981734345, 0.14681828607405933, 0.15338935490165437, 0.14822548627853394, 0.2792311651366097, 8.802741408348083, 50.1168874331883, 58.58081122807094, 35.865743024008616, 21.712948628834315, 20.666410957063945, 16.466362135750906, 22.144544669560023, 29.206902163369314, 39.476874692099436, 43.39834417615618, 40.835987499782014, 31.932294845581055, 32.736878871917725, 26.750488145010813, 16.710674694606237, 28.415483236312866, 39.880370480673655, 49.405669825417654, 47.62691708973476, 57.39860997881208, 53.910225187029155, 47.58648552213396, 44.93123837879726, 39.126980781555176, 44.21970462799072, 48.2432987349374, 50.642779214041575, 51.91586637496948, 50.8917053767613, 50.49453592300415, 49.5794130052839, 49.88756908689226, 47.56346614020211, 49.82234634671892, 51.99932813644409, 51.665765966687886, 52.263592447553364, 55.01730946132115, 48.780349322727744, 53.254096371786936, 53.73246594837734, 46.02017395836966, 48.47683463777815, 50.20990644182478, 46.45372417994908, 42.18950005940029, 45.389301845005576, 46.014125551496235, 41.259782450539724, 42.35130623408726, 42.82479122706822, 47.375013623918804, 40.92770372118269, 42.12975249971662, 43.524679797036306, 42.26216779436384, 41.02425241470337, 44.563254833221436, 41.850844860076904, 44.97314296449934, 43.55082586833409, 45.11136000497, 42.83054086140224, 42.61070680618286, 41.9114157812936, 44.190758432660786, 40.802184513636995, 40.95602805273873, 45.9444385937282, 43.77386999130249, 38.613679136548726, 43.52028506142752, 39.641731125967844, 38.817039012908936, 40.103049823216026, 40.256726605551584, 40.66112218584333, 41.94595527648926, 43.82551942552839, 46.02610771996634, 45.14276933670044, 48.98522390638079, 47.851976190294536, 44.97944150652204, 52.190858704703196, 43.812863281794954, 45.106131485530305, 46.925923756190706, 46.80051919392177, 47.16881888253348, 40.629403659275596, 41.12828779220581, 37.759950501578196, 34.95861053466797, 33.52863999775478, 32.113635880606516, 28.900750637054443, 26.8544887815203, 25.204677241189138, 17.958727496010916, 12.928349835532051, 24.036985567637853, 29.615209579467773, 23.595759323665074, 8.403500522886004, 2.162955548082079, 1.2278665474482944, 0.840737837765898, 0.10249688077185835, 1.7838693239859171, 19.128116267068044, 28.55563882419041, 32.85422699792044, 52.90063803536551, 56.10531745638166, 52.10247761862618, 52.55336012159075, 53.2089296068464, 54.721764360155376, 52.718112332480295, 52.06647900172642, 55.74827037538801, 44.91722386223929, 34.084975310734336, 14.564290165901184, 2.4343597846371785, 0.3605847997324807, 0.04148600762709975, 0.06156844233295747, 0.710100413433143, 0.22467395051249436, 0.17495185429496424, 20.17955415589469, 39.46460764748709, 47.45338235582624, 47.058582237788606, 27.617670229503087, 26.724851029259817, 23.758190836225236, 26.865734440939768, 16.187649045671733, 11.19914904662541, 9.422683136803762, 23.97854253223964, 10.185856768063136, 0.1553796881011554, 0.25060610686029705, 0.39455204563481466, 10.48124727181026, 86.5719975062779, 31.073341165270122, 2.8907778305666785, 1.6216288868870055, 5.200589418411255, 12.886860404695783, 10.09208561692919, 4.598995711122241, 11.663564034870692, 44.72611018589565, 55.291207449776785, 33.41906343187605, 48.198548861912315, 47.27610601697649, 51.09216090611049, 70.04872267586845, 53.87026957103184, 0.7565062376005309, 0.11053435198430504, 0.06795479357242584, 0.01392897279999618, 0.13548789120146207, 0.08722541201859713, 0.03046219183930329, 0.08431667488600526, 0.18582408875226974, 6.407605724675315, 52.729799202510286, 69.17857197352818, 47.48337425504412, 36.79954617364066, 30.331669603075298, 30.968124594007218, 36.49540615081787, 45.02035249982561, 51.505022866385325, 57.75261722292219, 52.87920979091099, 46.804257324763704, 37.22515460423061, 38.04513931274414, 29.219749382564, 39.315110206604004, 47.604616846357075, 48.38206468309675, 53.405917985098704, 61.29399939945766, 57.61820084708077, 53.83501788548061, 49.98734521865845, 45.55958482197353, 47.76586716515677, 52.529131753104075, 53.06486218316214, 53.77939060756138, 53.20437158857073, 53.59652096884591, 52.82561138698033, 53.861157008579795, 51.77155576433454, 52.658743449619834, 53.25442293712071, 54.44472231183733, 51.76356881005423, 57.73468392235892, 51.508340631212505, 55.62945965358189, 56.78383336748396, 48.06433398383004, 52.69529792240688, 51.76460409164429, 47.759808335985454, 43.26990672520229, 46.840113503592356, 46.4809923853193, 43.814999852861675, 43.165103571755544, 45.06050613948277, 49.26219299861363, 43.07316500799996, 42.61335406984602, 44.058391775403706, 43.70880011149815, 43.35127360480172, 46.94847413471767, 45.62906333378383, 46.317334515707834, 47.11993830544608, 48.18100813456944, 43.81881441388811, 45.70900583267212, 44.666421685900005, 45.92285748890468, 42.66952330725533, 41.804434367588584, 46.35076229912894, 44.79613413129534, 40.945716926029746, 45.292641980307444, 41.90665973935808, 39.59217309951782, 42.24197980335781, 43.14049652644566, 43.433300563267295, 44.67454760415213, 46.17902714865548, 48.015967573438374, 50.40282664980207, 51.03425114495413, 54.31406143733433, 48.14953974315098, 55.69619710104806, 47.73591695513044, 49.552759715488975, 50.30179636819022, 49.90929610388619, 49.72810098103115, 43.41171251024519, 42.81422996520996, 40.9409886768886, 38.11199140548706, 38.18973479952131, 34.84089762823922, 33.3498454775129, 31.263242380959646, 30.62333413532802, 19.53269076347351, 17.992384569985525, 26.964320693697246, 29.08251551219395, 26.622785466057913, 13.421761393547058, 3.984675509589059, 1.6652358898094721, 1.3748833728688103, 0.2122892207865204, 2.8728323706558774, 24.55766098839896, 35.08244480405535, 40.65416356495449, 59.13625022343227, 54.64556694030762, 59.42819268362862, 55.70072037833077, 61.579855237688335, 56.675583907536094, 63.330592836652485, 53.76470906393868, 58.031573499952046, 45.43548304694039, 31.181260585784912, 16.323875427246094, 4.564062774181366, 0.20215836726129055, 0.04345669723781092, 0.10642760020813771, 1.7671165657894952, 0.4444961856518473, 0.25186943049941746, 31.847735268729075, 51.49751533780779, 59.24455179486956, 57.70660277775356, 37.259742736816406, 38.245243958064485, 31.43348366873605, 43.634680203029085, 21.524603809629166, 24.43659210205078, 32.56640134538923, 43.39572123118809, 13.381406256130763, 0.18744444394750254, 0.192748470764075, 0.28154914932591574, 15.545939479555402, 104.98833683558873, 77.6890869140625, 20.366538865225657, 6.218012835298266, 11.82486993925912, 44.0860629762922, 18.220031874520437, 9.005193676267352, 33.8306747164045, 68.23967579432896, 62.49917834145682, 44.68906239100865, 64.30147157396588, 59.20111165727888, 60.40208693913051, 79.57024914877755, 67.06599303654262, 0.7348485397441047, 0.3562607131898403, 0.1340452307569129, 0.08146618319941418, 0.20108628193182604, 0.2209034671208688, 0.17446056780006203, 0.1771949960717133, 0.4926336854696274, 11.359399693352835, 59.975078446524485, 71.70020525796073, 65.40364347185407, 53.42675215857369, 46.13585451671055, 45.109605584825786, 49.90612077713013, 53.10810429709298, 58.821191106523784, 64.77094050816127, 62.67084053584507, 59.64030729021345, 53.22865554264614, 52.59558432442801, 41.087258679526194, 48.45941897800991, 55.14077547618321, 56.908727237156455, 59.21679374149868, 63.43922792162214, 61.20085184914725, 57.945537430899485, 52.31808022090367, 50.17403984069824, 50.82928623471941, 56.02526378631592, 55.904490198407856, 57.53089325768607, 57.01201568331037, 56.61316129139492, 55.41159193856375, 57.55187334333147, 53.5724732535226, 56.81168522153582, 56.37121112006051, 61.08614403860909, 56.53309719903128, 59.52818420955113, 53.43906089237758, 57.71417284011841, 58.57075023651123, 52.26984930038452, 55.75660126549857, 55.60237210137503, 50.48839718954903, 47.01665333339146, 47.63923624583653, 48.795760427202495, 45.691416467939106, 45.52396835599627, 46.1123765536717, 52.57333966663906, 46.160426821027485, 46.6390951701573, 46.969759941101074, 46.811660630362375, 44.01699788229806, 48.601731981549946, 46.591406209128245, 47.803748743874685, 47.10583346230643, 49.296464988163535, 45.691791670663015, 46.859533718654085, 47.54467126301357, 48.577976090567454, 44.68646376473563, 44.66126612254551, 51.44505991254534, 47.35579143251692, 44.05443130220686, 48.421857016427175, 45.02477502822876, 44.53011540004185, 45.122320788247244, 45.780374254499165, 44.47187212535313, 45.441722529275076, 47.5305038860866, 50.42887544631958, 53.16382190159389, 52.77278075899397, 54.91661269324166, 51.2235826083592, 56.636302266802105, 48.290612493242534, 51.80521283830915, 52.41003268105643, 54.020743233816965, 54.540562289101736, 49.45102071762085, 48.44480691637312, 45.673173972538535, 43.658185958862305, 45.079301016671316, 44.23469884055001, 39.06642723083496, 37.3621244430542, 42.352727140699116, 31.962092195238384, 23.818016563143047, 31.456419672284806, 33.348959582192556, 29.377497809273855, 17.59252268927438, 6.556590301649911, 2.0316693357058933, 2.0631220936775208, 0.5428362659045628, 6.867331547396524, 33.62452513831002, 39.48169674192156, 50.976431710379465, 62.412610735212056, 56.714420863560264, 62.1226624080113, 58.734616552080425, 62.68605709075928, 54.73669951302664, 59.83294609614781, 55.22557129178728, 68.37974452972412, 52.47079120363508, 43.40444469451904, 23.64528434617179, 6.818026261670249, 0.43366112134286333, 0.18618319662553923, 0.13851389954132692, 1.7080175770180566, 0.6623655834368297, 0.47513101037059513, 44.793309688568115, 63.3781532560076, 69.21004036494664, 69.06225218091691, 46.964545318058555, 45.38022402354649, 45.313375404902864, 62.7818796975272, 38.9480368750436, 39.117736203329905, 52.99428238187517, 61.59382111685616, 17.050193207604543, 0.33453489041754175, 0.36744383882199017, 0.6506379470229149, 32.36097090584891], [84.79020145961216, 44.70699569157192, 24.198958499091013, 4.989698563303266, 11.42105974469866, 20.93669761930193, 11.61224637712751, 3.1318132281303406, 13.089769516672407, 27.97887407030378, 48.923822675432476, 37.54429578781128, 38.42532736914498, 31.160968371800013, 41.15539618900844, 56.17166927882603, 41.14982025963919, 4.480346100670951, 0.4723097160458565, 0.19477081724575587, 0.14989844150841236, 0.04901477095804044, 0.2145119115178074, 0.11047099038426365, 0.01674035457628114, 0.3545735494366714, 24.206516402108328, 70.100709097726, 60.47771808079311, 38.46702350888933, 22.994752304894583, 24.30376512663705, 20.135929891041346, 26.628535100391932, 29.57810272489275, 41.527545179639546, 44.31263331004551, 44.01157133919852, 39.76913676943098, 42.13655478613717, 38.668986797332764, 20.186533621379308, 25.488511153629847, 36.534701687949045, 44.038297585078645, 48.128945282527376, 57.927322728293284, 50.01572166170393, 45.25718184879848, 40.969924449920654, 35.61209556034633, 41.309733050210134, 47.09345524651663, 46.868958950042725, 52.1532689503261, 49.55702938352312, 52.219669410160606, 50.426040581294465, 46.86596427645002, 51.05050645555769, 48.509546756744385, 49.097270556858604, 49.65314381463187, 48.46680838721139, 52.94454370226179, 48.38230439594814, 55.97211701529366, 50.00453506197248, 48.052532468523296, 49.576685837336946, 44.43142318725586, 43.26670013155256, 43.4141652243478, 41.37112733295986, 41.74647944314139, 41.91082171031407, 41.04656308037894, 44.10294015066964, 45.35875061580113, 46.50321272441319, 42.4511171068464, 37.31960841587612, 41.74119186401367, 41.78990568433489, 42.071193081992014, 42.20574494770595, 42.29257311139788, 44.47434220995222, 45.10319587162563, 43.3392983845302, 44.59458078656878, 43.09251921517508, 42.67812517711094, 41.612608500889365, 41.37517465863909, 40.229079723358154, 38.362817900521414, 41.98643200738089, 42.26825789042881, 43.06069993972778, 38.29791825158255, 35.92729016712734, 38.137404441833496, 40.90554938997541, 39.86853075027466, 42.319521699632915, 43.90822730745588, 47.90389313016619, 46.392385482788086, 50.158503668648855, 45.22093309674944, 48.72288424628121, 44.85752493994576, 45.619467871529714, 46.023814814431326, 45.95587532860892, 42.29517868586949, 35.382916178022114, 37.78920589174543, 36.761504786355154, 32.961753845214844, 34.220565932137625, 29.081973552703857, 31.694068908691406, 26.499491419110978, 15.895491191319056, 9.83783973966326, 11.120425956589834, 21.11635024206979, 21.001909937177384, 14.514989222799029, 5.218676882130759, 0.6112981694085258, 0.5158363804221153, 0.44375891664198464, 0.201185103771942, 0.39167717418500353, 17.445219142096384, 35.3420364516122, 49.36277859551566, 50.16676507677351, 53.863703523363384, 52.08850131716047, 55.101532050541465, 55.706845215388704, 56.01630755833217, 51.153430121285574, 58.21163954053606, 57.96430104119437, 32.90680749075753, 29.12043878010341, 15.802536453519549, 4.162126421928406, 0.41537739815456526, 0.0699732316923993, 0.3193872203784329, 3.508155022348676, 0.05822607382599797, 0.6627386691314834, 27.776193380355835, 40.99128321238926, 49.236696583884104, 47.234336921146934, 27.955069541931152, 16.54643838746207, 26.87724413190569, 16.753548554011754, 10.474266069275991, 8.397551996367318, 2.3961405668939864, 2.512718311377934, 0.1752462570688554, 0.19237770565918513, 0.3033011092671326, 0.5970760211348534, 11.505135553223745, 91.54575429643903, 45.1216641834804, 10.152521916798182, 5.469905069896153, 7.653879352978297, 20.97798034123012, 16.908609764916555, 6.0549472996166775, 22.982146535600933, 49.647713797433035, 57.754472391945974, 36.23349380493164, 48.240509033203125, 39.49197660173689, 43.71526541028704, 71.0206436429705, 60.074653080531526, 5.310770043304988, 0.12381953160677638, 0.1074402526553188, 0.11307718910809074, 0.04078672640025616, 0.09327134223920958, 0.11034247585173164, 0.004103362069664789, 0.5996143392154148, 24.784344230379375, 73.20051588330949, 67.5326896395002, 50.140066623687744, 37.181474753788535, 33.90754263741629, 30.864975111825125, 38.347521441323416, 42.23405885696411, 53.777712617601665, 56.83780697413853, 55.81281566619873, 52.11139563151768, 53.22778006962368, 50.52187361036028, 30.304627214159282, 35.093322208949495, 46.33892256872994, 48.93727786200387, 51.64460522787911, 60.971394538879395, 53.588801520211355, 49.55202668053763, 46.63892841339111, 42.668085030147004, 48.289945466177805, 49.69859198161534, 52.63959074020386, 53.31769323348999, 52.43464320046561, 54.81216737202236, 54.74473510469709, 50.03932816641671, 55.342700549534385, 50.39791774749756, 52.187513147081646, 54.35010174342564, 53.451248032706125, 53.88348504475185, 52.92099973133632, 56.89688055855887, 53.32176487786429, 51.2453339440482, 51.77603040422712, 48.07570471082415, 45.89995275224958, 44.68331970487322, 44.370946066720144, 43.303025313786094, 44.63311202185494, 43.93484238215855, 48.021661622183665, 46.23308760779244, 49.08221728461129, 44.82543468475342, 39.88253831863403, 43.199420724596294, 42.76041269302368, 42.722503321511404, 43.546469347817556, 45.100062234061106, 46.90898404802595, 49.17250565120152, 46.117181232997346, 44.45139578410557, 41.91845430646624, 42.16956567764282, 43.42590420586722, 40.8548310143607, 41.20724712099348, 40.652582849775044, 44.684789248875205, 44.02231672831944, 44.54001310893467, 40.84697607585362, 39.99729476656233, 41.18698269980294, 43.51464659827096, 43.24865913391113, 44.742382866995676, 44.912915979112896, 50.84745577403477, 49.24366910117013, 54.94676092692784, 48.898628507341655, 50.76498065676008, 48.16665663037981, 47.807452133723665, 49.01999964032854, 47.677607672555105, 45.12253270830427, 39.27836118425642, 42.28555890492031, 39.00125660215105, 38.86244549070086, 37.50944709777832, 35.01844147273472, 35.81775529044015, 32.86135932377407, 22.082234961645945, 17.803482157843455, 15.77272173336574, 21.11667159625462, 25.195522989545548, 22.403372015271867, 6.904830540929522, 1.519657124366079, 2.0929544014590125, 1.375500351190567, 0.28354822205645697, 3.7418264150619507, 27.032920258385793, 35.09727225984846, 46.56048672539847, 57.161773681640625, 55.33412994657244, 58.302306583949495, 57.515166010175435, 60.74297251020159, 58.61570508139474, 58.43758801051548, 58.57833766937256, 65.2967106955392, 37.62768111910139, 40.43745272500174, 27.640621866498673, 2.42119077699525, 0.9119676756007331, 0.11919317128402845, 0.170202462002635, 3.702059268951416, 0.07627659809908696, 1.6651918121746607, 39.19662605013166, 52.611179556165425, 58.31300680977957, 57.5749900000436, 35.82695470537458, 24.98636657851083, 33.90775803157261, 23.72917515890939, 21.0277224949428, 17.70672501836504, 16.508197239467076, 9.16630242552076, 0.10686611703463963, 0.08115578056978327, 0.21280789295477526, 0.5491756828767913, 14.565406220299856, 111.43484769548688, 77.18395287649972, 55.483147961752756, 11.404843517712184, 15.022102628435407, 45.65310410090855, 41.96396153313773, 15.468208244868688, 39.63069043840681, 74.30341039385114, 66.29974569593156, 50.43311037336077, 56.269875117710654, 47.31935507910592, 56.188859122140066, 76.40649114336286, 78.67974022456578, 6.141150559697833, 0.34094186233622686, 0.4007758673812662, 0.20568741432258061, 0.16837033602808202, 0.27501477567212923, 0.24891194062573568, 0.08179821074008942, 0.9124678373336792, 31.87848104749407, 74.35135991232735, 72.31997067587716, 63.458481379917686, 52.813476358141216, 54.88318143572126, 44.67383541379656, 53.37212194715227, 49.67650018419538, 61.660350118364605, 61.16486018044608, 61.52907085418701, 58.65878391265869, 60.776379449026926, 57.34753724506923, 45.47553593771798, 46.87916932787214, 54.160749435424805, 56.428836005074636, 59.67486763000488, 66.10315336499895, 55.44207715988159, 58.4495667048863, 51.955356461661204, 46.59503664289202, 51.56968627657209, 53.74462877001081, 55.15701689038958, 58.718614850725444, 55.20658533913748, 58.27445820399693, 57.513894489833284, 53.48233079910278, 57.5090411731175, 53.86320325306484, 54.40246336800711, 57.4187319619315, 57.48464604786464, 59.43500886644636, 52.26243209838867, 59.28836713518415, 57.20942095347813, 53.573477268218994, 54.139449732644216, 50.175919328417095, 47.2820918900626, 47.34524406705584, 46.869163921901155, 45.99177667072841, 46.31609426225935, 47.17975534711565, 51.135997091020855, 48.8858368737357, 50.264116287231445, 47.45475809914725, 40.92800596782139, 47.356673853737966, 46.19578620365688, 46.67119584764753, 47.26669120788574, 47.15090642656599, 47.39240843909127, 50.704270771571565, 47.611210686819895, 49.831431116376606, 46.48590823582241, 47.16025522777012, 45.16615349905831, 44.705130100250244, 44.509916986737935, 45.71628407069615, 46.52819149834769, 46.56084108352661, 46.79804563522339, 43.50391510554722, 42.09930549349104, 42.15986599240984, 45.61729655947004, 45.21995687484741, 45.014015742710654, 47.66993686131069, 54.05321216583252, 52.57689367021833, 56.771927629198345, 49.881902830941335, 51.560907227652415, 47.673379693712505, 51.43930680411202, 53.32760831287929, 50.48694501604353, 51.10526868275234, 43.29065752029419, 46.81859840665545, 45.435719285692485, 46.05253519330706, 45.044560023716514, 41.288930143628804, 43.64806243351528, 42.092795031411306, 32.46669122150966, 26.54556839806693, 25.302299431392125, 27.64588165283203, 31.873019763401576, 27.041532550539287, 8.695675747735159, 2.004591337272099, 2.4349202002797807, 1.9515850501401084, 0.7331151270440647, 4.346398728234427, 31.518248217446462, 49.19519846779959, 56.676890168871196, 56.96485478537423, 55.74537992477417, 59.71725858960833, 58.978727613176616, 63.14160878317696, 58.57828903198242, 61.23677403586251, 59.87232848576137, 67.95122132982526, 46.98630360194615, 40.13357325962612, 36.44137348447527, 9.140515923500061, 1.1125050634145737, 0.20598443624164375, 0.5108401913728032, 6.422969928809574, 0.13793846113341196, 2.100277368511472, 51.82932308741978, 62.303822789873394, 66.85319055829729, 65.76729828970772, 45.95072671345302, 28.839953899383545, 57.15433216094971, 38.718614305768696, 32.95315892355782, 29.432603972298757, 21.92968726158142, 10.263951046126229, 0.389696720455374, 0.44111241293804987, 0.4582746263061251, 1.2069729885884692, 21.39829077039446], [65.92401490892682, 61.12753445761544, 28.38620352745056, 24.360200132642472, 9.979427524975367, 23.686662605830602, 13.541672536305018, 4.121048671858651, 10.565336108207703, 19.984188182013376, 49.47529424939837, 40.00024427686419, 31.0485326222011, 32.61287089756557, 46.30525854655674, 62.49917834145682, 51.8621255329677, 11.68546301977975, 0.5721985389079366, 0.29334776050278116, 0.13367437065712043, 0.1496078928134271, 0.14663343956427916, 0.07765443130795445, 0.2059746246252741, 0.6636696734598705, 20.21306358064924, 58.53300762176514, 55.77916554042271, 36.31846332550049, 31.39125599179949, 30.763628687177384, 29.434299332754954, 32.48605237688337, 37.2058698790414, 41.56071935381208, 49.94801494053432, 46.586202008383616, 45.960607051849365, 40.12260552815029, 42.008989334106445, 27.936182601111277, 25.638783318655832, 34.401125294821604, 38.357398305620464, 52.56444944654192, 55.21069867270333, 45.22247559683663, 41.569390705653596, 34.46565668923514, 33.12833343233381, 38.90449946267264, 44.91572652544294, 45.09772416523525, 47.13570029394967, 50.4261656488691, 50.49430315835135, 50.75092792510986, 49.76274817330496, 49.21438939230782, 50.655160903930664, 47.945683070591514, 48.4458908353533, 50.38993774141584, 44.505296434674946, 51.606911250523154, 49.586771147591726, 46.91150624411446, 50.08168091092791, 47.98649678911482, 42.79472637176514, 43.92821032660348, 40.55506835665022, 39.97314282826015, 37.65505007335118, 38.58299241747175, 39.88001612254551, 43.331624099186485, 41.52477284840175, 45.627374921526226, 44.25458458491734, 41.55522332872663, 36.73379537037441, 37.38835389273507, 38.80663408551897, 40.27770321709769, 38.38115072250366, 40.51655101776123, 46.07766335351126, 42.069160733904155, 39.96817486626761, 41.10071734019688, 37.655307156699045, 37.04401854106358, 37.17789643151419, 35.637453011104036, 38.573056493486675, 40.82279634475708, 41.95062099184309, 42.08620466504778, 39.40034375871931, 38.46458469118391, 37.42283432824271, 40.97861664635794, 40.80550575256348, 44.8701046534947, 41.147388390132356, 44.30109930038452, 46.14592245646885, 49.76068803242275, 46.46446262087141, 46.383363246917725, 44.83992167881557, 42.15042686462402, 45.107983180454795, 41.45415483202253, 37.5000079699925, 35.02042865753174, 36.62217950820923, 35.078960282461985, 32.71442576817104, 34.75031396320888, 31.08561863218035, 35.73457840510777, 26.42905752999442, 22.890760353633336, 20.93599237714495, 13.108395900045123, 17.51821517944336, 17.705705370221818, 11.56214986528669, 3.319464530263628, 0.1864590346813202, 1.5241378439324242, 0.7433238763894353, 0.7096449264458248, 1.9224319287708826, 11.096766471862793, 41.54119144167219, 54.36085408074515, 49.209744521549766, 49.006992612566265, 49.662822655269075, 54.253730228969026, 52.984766823904856, 56.406667777470176, 54.62954092025757, 53.98846885136196, 54.91629655020577, 46.86870534079415, 26.677233287266322, 16.605023860931396, 10.08366526876177, 2.10770759837968, 0.5919669238584382, 0.9411097232784543, 2.064935790640967, 0.3501628004014492, 4.64964199917657, 35.80980307715279, 45.90668903078352, 52.49594020843506, 47.39182826450893, 22.531297036579677, 25.12328256879534, 17.76995188849313, 10.656744871820722, 2.321540798459734, 6.15791916847229, 0.9114628455468586, 0.5823452972940036, 0.13243992546839373, 0.6325886441128594, 0.3430579959281853, 0.40302423387765884, 4.904867572443826, 100.86270495823452, 57.249755246298655, 14.668619973318917, 8.342826247215271, 12.270489181791033, 28.342200585774012, 27.668744700295584, 15.862657478877477, 27.673710925238474, 43.51102658680507, 62.923546518598286, 35.72430549349104, 38.67937435422625, 45.010930742536274, 45.44436631883894, 74.24747739519391, 69.53995473044259, 21.74519521849496, 0.15049802219229086, 0.039674519295138974, 0.11615644209086895, 0.022076613502576947, 0.1165341961064509, 0.08020815213343926, 0.21897508416857037, 0.2827238291501999, 30.468118327004568, 61.64790589468819, 65.61878749302456, 50.09113393511091, 42.802775859832764, 41.35853024891445, 38.51220417022705, 42.73594461168562, 46.65711532320295, 48.66675669806344, 60.858451570783345, 59.03140190669468, 58.34275899614607, 53.40792948859078, 53.38828345707485, 38.250715664454866, 35.065307072230745, 44.916636739458355, 48.642858369009836, 54.6212934085301, 59.359148434230256, 52.945075239454, 46.96252686636788, 41.89525774547032, 39.028330257960725, 47.69728149686541, 50.897170134953086, 50.06571742466518, 51.34005873543875, 55.401947838919504, 53.47557020187378, 52.293716362544465, 52.295807770320344, 50.867233821323936, 53.429527963910786, 51.496841362544465, 50.91868870598929, 52.72592905589512, 47.02497727530343, 55.170169830322266, 51.805702686309814, 50.38140882764544, 52.80651773725237, 51.124730587005615, 46.1056124823434, 45.24105507986886, 43.12215328216553, 42.05088002341134, 38.59027760369437, 41.067605699811665, 42.39214079720633, 46.17205810546875, 44.59739133289882, 45.735815456935335, 44.014305455344065, 44.216018608638215, 38.21668686185564, 40.76933690479824, 41.738673142024446, 41.463736397879465, 42.395694800785606, 43.500454902648926, 47.48978049414498, 43.22820363725935, 42.208927222660606, 41.57744714191982, 41.831560134887695, 39.35166815349034, 39.87204653876168, 39.086677755628315, 41.24193252835955, 43.95551674706595, 43.56373562131609, 43.78131151199341, 42.943178108760286, 41.29706995827811, 39.89858865737915, 41.96217237200056, 42.18185009275164, 45.4730623790196, 45.47914205278669, 45.785543714250835, 49.826164381844656, 52.3395779473441, 50.65517827442714, 49.84053325653076, 50.96234771183559, 43.11961718967983, 48.667983055114746, 44.22527013506208, 41.07597827911377, 40.17735733304705, 38.77143798555647, 37.03919301714216, 38.605386461530415, 37.556691374097554, 38.583527428763254, 37.01759801592146, 34.03471899032593, 28.83873275348118, 30.42908682141985, 21.182576996939524, 20.954613549368723, 26.588275500706263, 17.46156304223197, 3.3737840269293105, 0.5027785439576421, 2.986330326114382, 0.9992495349475315, 1.0610307455062866, 0.916236475110054, 21.765829631260463, 50.98448467254639, 57.001770564488, 55.0686114856175, 52.019498756953645, 54.75374344417027, 57.14973592758179, 58.91099657331194, 57.00499105453491, 58.27321447644915, 56.153673444475444, 60.63510867527553, 49.094581604003906, 31.914733273642405, 26.026503222329275, 11.41720610005515, 2.402380266359874, 0.05144967690908483, 0.11486262508801051, 2.470173840011869, 0.5006748139858246, 7.094641864299774, 48.65400675364903, 54.95025587081909, 64.59884057726178, 56.08504261289324, 31.745113849639893, 30.1556613104684, 30.05076435634068, 18.85194969177246, 14.944425242287771, 12.789571728025164, 4.263742957796369, 0.6173248631613595, 0.13294314060892376, 0.7715084297316415, 0.5012633481195995, 0.44664535032851355, 8.319631423269, 100.71816158294678, 78.9778665815081, 64.84200668334961, 46.061296871730256, 17.18159580230713, 37.31512335368565, 66.35376099177769, 38.03029448645455, 45.50884212766375, 68.9776509148734, 75.15682288578579, 46.203206879752024, 47.948333808353965, 53.39355019160679, 60.422264507838655, 79.97113936288017, 85.20957388196672, 22.04922754423959, 0.37933836770909174, 0.21360188749219688, 0.278374473963465, 0.2701647159244333, 0.20765611582568713, 0.12544440584523336, 0.21277437332485402, 0.6387433367116111, 45.465089321136475, 66.05275808061872, 70.50027915409633, 56.76072713306972, 59.114300864083425, 54.868836879730225, 51.33771371841431, 54.71848828451974, 53.20773104258946, 53.8563940184457, 64.27756977081299, 62.52169745309012, 62.492959703717915, 57.660994802202495, 59.82366330283028, 53.02678952898298, 47.18105466025216, 57.53234543119158, 55.146664074489046, 60.2549866267613, 63.00486823490688, 55.203232833317344, 53.44222927093506, 48.705051694597515, 43.85662651062012, 51.847576005118235, 55.84500667027065, 52.45156553813389, 55.0739928654262, 59.09062835148403, 57.07661655970982, 54.78987060274397, 55.93952996390206, 53.81253004074097, 57.5052752494812, 55.3436906678336, 55.213908740452354, 57.06665631702968, 48.36824819019863, 57.95080416543143, 54.77798918315342, 50.07145316260201, 55.05476025172642, 52.76357092176165, 47.88285745893206, 47.8766006061009, 45.20268017905099, 45.884791782924104, 42.32727241516113, 44.07096801485334, 46.22161265781948, 48.19324391228812, 46.686263016292024, 49.3866491317749, 47.867720808301655, 46.63611439296177, 41.88186856678554, 43.21803494862148, 43.71867002759661, 42.89285578046526, 42.510593686785015, 44.610898630959646, 51.299585478646414, 44.20022535324097, 43.982010228293284, 44.90479353496006, 42.411491530282156, 41.617771012442454, 41.83897386278425, 40.193466731480186, 43.46784005846296, 46.95015212467739, 46.59261172158377, 48.074853556496755, 44.442884240831646, 43.384715284620015, 42.91724395751953, 44.51891837801252, 45.95325585774013, 48.600015776497976, 48.23319258008684, 48.754581928253174, 51.18348455429077, 54.927535261426655, 51.57379961013794, 50.594447544642854, 51.93586329051426, 45.30530159814017, 51.266796929495676, 48.86805990764073, 46.92791441508702, 43.71321569170271, 46.83137961796352, 42.261288847242085, 44.344542912074495, 44.64765807560512, 43.27080651691982, 45.221409048352925, 40.140559673309326, 33.20979758671352, 35.99855089187622, 27.745621306555613, 26.68967056274414, 32.26822982515608, 22.913711990628922, 7.5770218542643955, 3.0744200221129825, 3.665406218596867, 2.8263213464191983, 2.3107092082500458, 3.61151989868709, 28.93421142441886, 53.60992751802717, 54.36425174985613, 56.57222597939627, 50.904021058763774, 55.84443691798619, 56.63840062277657, 57.32999651772635, 57.209271567208425, 59.068630354745046, 56.38230391911098, 61.009262221200125, 59.66761371067592, 44.6631212915693, 36.31398868560791, 26.31929509980338, 8.407322900635855, 1.4848974581275667, 1.4184963468994414, 5.987910211086273, 0.6727427180324281, 9.51510112626212, 61.494857924325125, 65.23623357500348, 73.91831343514579, 64.3097677230835, 42.17240054266793, 41.49608373641968, 49.72531475339617, 26.612830434526714, 18.390608412878855, 16.529267651694163, 4.0029900925500055, 0.6690204377685274, 0.22231340860681875, 1.259773109640394, 0.7380701154470444, 0.7862249857613018, 6.807827174663544], [40.8243909563337, 47.60888998849051, 40.04981619971139, 44.29285873685564, 34.50815534591675, 17.47428171975272, 16.317691530500138, 8.808756811278206, 9.013852868761335, 23.103720903396606, 37.428156648363384, 41.68937567302159, 27.726348740713938, 25.24053168296814, 46.794654914310996, 68.5910392488752, 60.10334914071219, 43.68229273387364, 0.13334290630051068, 0.16632002033293247, 0.08210311723606926, 0.10470243849392448, 0.11733393105013029, 0.24048836263162748, 0.17719313688576221, 1.1837713250092097, 18.89943368094308, 59.04525661468506, 50.371716090611045, 34.77296509061541, 41.827040331704275, 39.135169233594624, 44.35752214704241, 42.044609274183, 43.0554644720895, 43.18187652315412, 51.76339857918875, 49.1305559022086, 48.7641669682094, 37.83437960488455, 40.1689395904541, 35.25769921711513, 28.72778218133109, 30.247384480067662, 41.22757755007063, 55.28214005061558, 55.87776395252773, 47.77109915869576, 37.03676462173462, 30.385726588112966, 31.43757963180542, 38.6458215032305, 43.712288107190815, 47.58540507725307, 50.063712869371685, 49.13482209614345, 48.21996668406895, 47.60440840039934, 48.37511995860508, 47.349204540252686, 45.611526080540244, 46.067932401384624, 47.2362824167524, 44.51709794998169, 46.00836896896362, 50.08150373186384, 46.888434750693186, 50.62495013645717, 49.948866094861714, 48.63860954557146, 45.072721072605674, 42.41562570844378, 40.01110083716256, 40.75477695465088, 38.023558207920615, 41.01451798847744, 40.9694311278207, 41.69832842690604, 44.48072065625872, 41.724061080387656, 40.65006065368652, 39.19124814442226, 35.513771602085654, 39.975828307015554, 38.44688415527344, 41.158974511282786, 40.77649007524763, 43.583572728293284, 42.3517404964992, 40.35386937005179, 42.309068134852815, 40.06568588529314, 40.47594574519566, 39.04242467880249, 38.113676343645366, 36.022289412362234, 37.21068845476423, 39.0024482182094, 40.74683516366141, 38.907455921173096, 37.8879154750279, 38.997424670628135, 38.545371396201, 36.19084576198033, 39.10516343797956, 40.66877910069057, 46.775283336639404, 43.77359553745815, 45.819364070892334, 48.72114372253418, 48.900556632450645, 45.38692903518677, 44.84597703388759, 40.596896512167795, 39.87143162318638, 38.28180537905012, 33.36131347928728, 33.71306255885533, 32.398091656821116, 35.18110922404698, 35.26569659369332, 38.026191575186594, 38.87441723687308, 37.16508395331246, 38.636222566877095, 37.76437650408064, 38.55470977510725, 29.01698531423296, 26.666145699364797, 19.914376156670706, 14.29230901173183, 7.82907383782523, 3.6117496235030035, 3.852174665246691, 3.0874858924320767, 2.8189840487071445, 6.122962347098759, 18.461987257003784, 39.51528433391026, 49.365634305136545, 46.52115644727434, 46.666616984776084, 48.73889984403338, 53.31309005192348, 52.19951268604824, 53.02372884750366, 49.84906564440046, 52.35046577453613, 51.609357016427175, 53.78643955503191, 44.7758002281189, 40.78346954073225, 25.14799210003444, 13.496233923094612, 2.115220772368567, 0.3161977529525757, 2.265518341745649, 0.25806016687835964, 9.887159790311541, 42.25229093006679, 46.3670870917184, 54.308002608163015, 41.619150229862754, 20.61135516847883, 18.96608601297651, 14.884641204561506, 5.884550545896802, 1.1622780497585024, 0.20348980224558286, 0.5933357189808572, 0.14382623162652763, 1.121326887181827, 5.040616699627467, 2.5486808844975064, 0.48600016427891596, 0.3021345447216715, 70.56575897761753, 76.32651737758091, 35.129477160317556, 23.80333501952035, 14.645423412322998, 26.22021378789629, 45.4995002746582, 31.671598434448242, 37.59263440540859, 51.80106476375035, 57.74402230126517, 40.74516759599958, 37.747061593191965, 34.235487188611714, 50.01481144768851, 73.01288672855922, 73.36392361777169, 56.849208968026296, 0.612906025988715, 0.16539483783500536, 0.02400665377665843, 0.1378706619143486, 0.08447490246700388, 0.1131944806714143, 0.2631215224308627, 0.640460410288402, 29.037812539509364, 66.96254130772182, 59.266980579921174, 47.07431990759713, 52.19464199883597, 50.67113133839199, 52.27258341653006, 52.049007756369456, 48.6106013570513, 51.50587402071272, 58.92732484000069, 59.242036546979634, 59.20577389853341, 51.45344986234392, 53.85779060636248, 47.77661950247628, 39.94400903156826, 42.55279357092721, 48.263729912894114, 58.988246645246235, 55.89740650994437, 51.846571990421836, 43.30205256598336, 36.01814481190273, 40.94426475252424, 46.09829255512783, 50.310877663748606, 50.79337794440133, 52.37802580424717, 51.29078211103167, 51.04663978304182, 48.91764225278582, 52.435438769204275, 50.07185615812029, 49.17545516150338, 49.24983215332031, 51.3846800667899, 46.03368125643049, 49.75631414140974, 53.32416548047747, 50.86929048810686, 54.16284431729998, 51.506867613111226, 51.604931013924734, 46.56296375819615, 43.244038581848145, 42.288720335279194, 42.043247427259175, 40.66977964128767, 41.694298471723286, 43.50850091661726, 45.071369647979736, 45.36611918040684, 42.97243002482823, 43.37393168040684, 41.68877117974417, 37.37785516466413, 40.26788888658796, 40.73814296722412, 41.687263420649934, 42.47923994064331, 45.84399543489729, 43.48129177093506, 40.56956924710955, 42.6593268258231, 41.57843031202044, 41.86094754082816, 40.94033554622105, 40.76310089656285, 39.57561901637486, 41.636371340070454, 42.713123253413606, 42.48289121900286, 41.49455165863037, 41.340920039585654, 40.419759137289866, 40.40188142231533, 38.40722036361694, 39.645048890795024, 40.04909706115723, 48.44148220334734, 50.510704381125315, 47.85285513741629, 50.96266385487148, 52.974764892033164, 50.015985693250386, 48.81394733701433, 43.508004120418, 42.108126231602256, 42.82599326542446, 39.03049462182181, 38.118956974574495, 38.57158694948469, 40.448604583740234, 39.861745834350586, 42.102793489183696, 41.36408533368792, 39.98411055973598, 43.674357891082764, 39.71679251534598, 42.48482281821114, 34.4935120173863, 31.200524466378347, 26.757142782211304, 17.786530290331157, 9.101067525999886, 3.2084789999893735, 3.936982205935887, 2.5833343735763004, 2.6186173260211945, 6.514848564352308, 24.689916474478586, 47.14685215268816, 53.31932258605957, 50.682370049612864, 51.22300590787615, 53.313176904405864, 55.82050384793963, 54.27137170519148, 59.3137697492327, 54.9430227960859, 57.93728297097342, 58.40211745670864, 59.015830993652344, 51.833401679992676, 44.886262689317974, 28.393770115716116, 14.806460074016027, 1.6946585795709064, 0.48941471534115927, 0.4793973671538489, 0.28382495577846256, 14.719633647373744, 56.85163388933454, 55.110495226723806, 66.9998253413609, 46.955662046160015, 32.605300835200715, 30.32316848209926, 28.377177817480906, 12.90940991469792, 6.84126581464495, 4.962766911302294, 1.6764420313494546, 0.11228096897580794, 2.192753766264234, 7.770785399845668, 7.433954102652414, 0.7987703382968903, 1.896271092551095, 67.39606721060616, 85.08648654392788, 67.63339682987758, 66.8396554674421, 63.95653520311628, 27.26386100905282, 58.742336000714985, 57.63214588165283, 61.16590935843331, 72.18580790928432, 66.21254580361503, 53.974419593811035, 41.11362361907959, 44.585645403180806, 63.68272059304373, 80.95118972233364, 84.50048242296491, 60.99642889840262, 0.29884592975888935, 0.1718184067202466, 0.21090594572680338, 0.18483995513192245, 0.21833361073264054, 0.5564760682838303, 1.192066605601992, 4.183347088950021, 41.4925297328404, 70.48260988507951, 68.05776500701904, 57.743480341775076, 63.85328497205462, 57.18494939804077, 57.84648738588606, 55.63276352201189, 52.67985207693917, 56.67146709987095, 61.07281739371163, 61.69202695574079, 63.01098264966692, 55.89764274869646, 60.25943347385952, 56.66175351824079, 52.509416239602224, 50.778178759983604, 56.95998409816197, 63.43290506090437, 59.44421522957938, 59.2910977772304, 51.20384277616228, 43.25036491666521, 46.15415259769985, 51.37491437367031, 56.110035283224924, 54.57150609152657, 56.27918570382254, 55.211396966661724, 53.93936940601894, 51.77209424972534, 56.718951089041575, 51.14677374703543, 51.527291842869346, 49.15133796419416, 54.03252043042864, 49.99979291643415, 55.229406697409495, 56.88420704432896, 54.78906808580671, 55.89253582273211, 55.64832748685564, 54.365363461630686, 49.26288087027413, 45.38558455875942, 45.50881780896868, 45.07133490698678, 42.28820269448416, 43.53679745537894, 45.0960704939706, 47.092555454799104, 48.44245147705078, 45.24128437042236, 47.36126661300659, 45.15922267096383, 40.24755498341152, 43.839627742767334, 42.7974465915135, 44.704435280391145, 46.219173840114046, 48.890196868351524, 47.568934372493196, 43.19374404634748, 46.07439770017351, 42.610779762268066, 44.263749258858816, 41.959406988961355, 43.35574129649571, 39.72520330974034, 43.56432621819632, 44.10187707628523, 47.1476720401219, 43.20738336018154, 42.27477877480643, 43.68989406313215, 43.6057687486921, 41.471949168613975, 43.99958917072841, 43.08991016660418, 50.38116564069475, 53.07370376586914, 51.603576115199495, 53.63799129213606, 54.39356619971139, 49.834165232522146, 50.36854771205357, 43.897784164973665, 47.173394271305625, 45.70566027505057, 42.75161279950823, 43.84806285585676, 44.06523922511509, 47.28031662532261, 47.49723591123308, 49.05453218732561, 49.55740111214774, 45.00369766780308, 48.48676361356463, 47.45017228807722, 49.33945001874651, 40.81888798304966, 36.6355756350926, 32.37265430177961, 22.803496190479823, 13.527816091264997, 7.930406366075788, 5.241506491388593, 6.602086237498692, 6.452888003417423, 18.30965668814523, 35.047224385397776, 50.32583366121565, 51.20691735403878, 50.87839610236031, 50.88195358003889, 54.68629033224923, 58.332836968558176, 58.147698743002756, 59.655120849609375, 56.94124828066145, 55.382232325417654, 58.71855926513672, 59.54391493116106, 58.64078113010952, 58.53809370313372, 42.768149512154714, 26.770662239619664, 4.6103251831872125, 1.4923791480915887, 4.158625398363386, 0.4435999494578157, 18.574817316872732, 69.9197085244315, 61.336987904139924, 74.59326839447021, 53.792025906699045, 43.735397815704346, 31.050707408360072, 48.495004177093506, 18.222840683800833, 8.311600174222674, 4.791731791836875, 1.4159105313675744, 0.20578848889895848, 1.6195589751005173, 12.135530846459524, 15.420851060322352, 2.741902253457478, 1.089243037360055], [14.931289672851562, 57.22476952416556, 29.93489272253854, 37.027697222573416, 41.830528327396934, 49.0851320539202, 19.95919030053275, 6.432451614311763, 9.235886028834752, 13.88247733456748, 31.529431343078613, 30.92117214202881, 24.2406233719417, 23.923940113612584, 44.11548512322562, 64.3081418446132, 70.93059498923165, 54.25966051646641, 3.317783066204616, 0.3469003497489861, 0.04798393037968448, 0.03280362280617867, 0.013753264460579624, 0.04942929478628295, 0.7966597144092832, 1.0876559168100357, 32.333570684705464, 63.842049734933035, 56.55835042681013, 48.09613936288016, 49.506953716278076, 48.93542616707938, 48.44246537344796, 46.42253024237496, 46.259931973048616, 46.67016404015677, 52.15251159667969, 55.97153684071132, 49.378443309238975, 41.89777646745954, 40.222708225250244, 36.01959351130894, 31.10509443283081, 30.709696769714355, 38.17788117272513, 51.929175649370464, 52.08075060163225, 43.450441769191194, 34.05750560760498, 30.979578699384415, 35.65734917776925, 42.0522974559239, 43.55084671292986, 47.74696806498936, 46.94512857709612, 48.633374077933176, 46.092612402779714, 45.79946790422712, 43.79765020098005, 48.31680025373186, 47.3669432912554, 49.68178081512451, 47.44409956250872, 43.26417098726545, 42.456262247903005, 46.3193564414978, 46.416763237544465, 50.448156697409495, 49.99335193634033, 49.979215826307026, 45.76324347087315, 42.15254259109497, 39.425746372767854, 38.44519574301583, 38.59507533482143, 39.16728033338274, 39.72829525811331, 40.508921895708355, 39.683670452662874, 43.77027082443237, 38.58253036226545, 38.86350161688668, 38.00046934400286, 37.19619798660278, 39.4001144681658, 37.83554342814854, 39.82898507799421, 42.18882608413696, 39.211453505924766, 38.864186014447895, 41.89542102813721, 39.54792349679129, 38.46219451086861, 36.959660461970735, 37.05527114868164, 36.721674237932476, 37.21713638305664, 38.820158754076274, 39.73982926777431, 40.172948701041086, 38.52340119225638, 40.03262288229806, 35.90686593736921, 37.57452392578125, 38.11187676021031, 37.34264169420515, 42.1200076511928, 49.15417282921927, 47.71417604173933, 47.095369475228445, 50.42185776574271, 45.72591079984392, 48.23578078406197, 39.60098341533116, 39.25628328323364, 36.56919254575457, 35.188644545418875, 33.20974547522408, 38.25020497185843, 35.212150301252095, 37.521217346191406, 40.438494954790386, 39.03512212208339, 48.00161606924874, 45.198598112378804, 31.5030003956386, 39.40131303242275, 42.55617734364101, 36.11837257657732, 27.302682331630162, 17.386866433279856, 12.296952264649526, 9.859842947551183, 8.290138057300023, 8.004895397594996, 13.127053550311498, 16.454373019082205, 38.01995209285191, 46.46500110626221, 46.73970855985369, 48.02508708408901, 44.27186822891235, 46.681135245731895, 48.950173718588694, 50.94241680417742, 53.18115070887974, 53.409218379429404, 53.16770594460623, 50.38769694737026, 56.851078033447266, 58.891833441598074, 58.87770080566406, 51.620699950626914, 31.066785539899552, 12.191779119627816, 1.6159132335867201, 0.39698565219129833, 0.1651527908231531, 19.758340460913523, 49.177595206669395, 48.906431334359304, 44.10383994238717, 34.744081429072786, 19.02149268559047, 18.297368798937114, 11.982620971543447, 4.919271622385297, 2.4618082089083533, 5.308950483798981, 0.48203344855989727, 2.0036522448062897, 4.202801176479884, 6.6997175472123285, 12.067692109516688, 9.499114189829145, 0.3938005273895604, 31.878599166870117, 66.71125275748116, 55.73145573479788, 42.25822121756417, 23.077995198113577, 33.757892336164204, 47.91768183026995, 32.7478083883013, 31.343261310032435, 49.842113971710205, 56.27021905354091, 27.974835429872783, 29.41602557046073, 33.95579440253121, 46.89951712744576, 76.75455420357841, 71.57407460893903, 68.94684955051967, 7.147711770875113, 0.45144783120070187, 0.2527911253273487, 0.18403609469532967, 0.1649581462677036, 0.040946955659559796, 1.1867370115859168, 3.6904310243470326, 38.62058564594814, 65.99399021693638, 64.64485154833112, 54.03223555428641, 56.557308197021484, 54.78445100784302, 54.753389086042134, 53.19423764092581, 54.59956986563546, 51.0056106703622, 61.51666831970215, 62.584550857543945, 59.85183824811663, 50.17612082617623, 52.66047355106899, 46.32373033251081, 40.25118889127459, 37.50570896693638, 47.49708652496338, 56.534181118011475, 54.483941418784006, 49.42625386374337, 40.324770314352854, 38.8985379082816, 43.34659399305071, 44.811256885528564, 49.7309810093471, 51.016366481781006, 51.778132234300884, 50.106048243386404, 47.326001031058176, 46.446647439684185, 49.488662583487375, 49.72856651033674, 52.56807293210711, 51.901212624141145, 50.67681149074009, 44.95779091971261, 45.88369049344744, 50.84371069499424, 47.250554016658235, 52.12495156696865, 53.41182395390102, 50.83523736681257, 47.93114396503994, 44.831691537584575, 40.142814363752095, 41.42642804554531, 39.784165722983225, 41.16372013092041, 41.128350325993125, 43.10146502086094, 41.502118246895925, 44.927580152239116, 41.61645432880947, 41.33217920575823, 41.193951742989675, 40.81135960987636, 40.33028718403408, 39.717793055943076, 40.809747627803254, 42.75421142578125, 40.30036129270281, 39.29702404567173, 44.60013239724295, 42.41473286492484, 40.58871848242623, 37.27514689309256, 37.672260761260986, 39.471368244716096, 40.50692776271275, 41.633731024605886, 41.93935796192714, 42.4362792287554, 41.639605726514546, 43.641961915152415, 41.344342027391704, 40.51417473384312, 39.843746525900706, 40.80928904669625, 41.560139179229736, 51.93023872375488, 52.63195814405169, 49.47730575289045, 52.44746610096523, 48.26936142785208, 48.085828236171174, 41.864306994846885, 40.363478728703086, 39.92205272402082, 38.78022050857544, 39.35517699377877, 40.493152959006174, 42.12612554005214, 42.63082878930228, 45.73414788927351, 41.93334082194737, 49.19610520771572, 44.78512471062796, 34.07733924048287, 39.255890710013254, 42.03502770832607, 38.04043538229806, 29.677847589765275, 19.42132329940796, 14.776676620755877, 11.448857750211443, 9.922401053564888, 7.059388875961304, 11.66287442616054, 18.18761157989502, 40.04155479158674, 52.50777299063546, 51.09023972920009, 51.97560003825596, 49.84097794124058, 52.40484585080828, 53.238918031964985, 55.34058829716274, 57.37918281555176, 57.67519692012242, 56.812692710331504, 57.62153250830514, 64.28603962489537, 66.3228484562465, 66.7541856765747, 62.00884396689278, 37.54982655388968, 15.914145367486135, 2.286711867366518, 0.13161114922591619, 0.230754126395498, 29.01265832356044, 59.71162360055106, 59.486335209437776, 53.605532782418386, 44.69872733524868, 28.545937401907786, 22.34190477643694, 21.928308044161113, 9.04964303970337, 2.3332509015287672, 4.66154556615012, 2.793817456279482, 1.9776703247002192, 10.935688120978218, 16.39053644452776, 17.899337768554688, 11.64620396069118, 0.6050736691270555, 22.09047031402588, 99.74435070582798, 54.87780353001186, 62.86705766405378, 73.30999170030866, 63.40176323481968, 55.89683328356062, 50.78814247676304, 53.24516098839896, 64.07593999590192, 59.721003668648855, 40.54933609281267, 40.77023669651577, 41.85312039511544, 60.615438325064524, 80.55132784162248, 84.08179092407227, 81.20650822775704, 8.592065947396414, 0.6433844619563648, 0.36884590930172373, 0.2872117411877428, 0.24711252003908157, 0.09428214228578977, 2.865506798028946, 15.43411864553179, 50.359515053885325, 74.11949157714844, 70.7787560054234, 64.8130326952253, 60.77013301849365, 58.09626817703247, 53.335730757032124, 54.2510655948094, 54.99587426866804, 53.659357002803254, 60.965530259268625, 65.20795440673828, 61.75547095707485, 54.65100737980434, 61.57987608228411, 59.89520195552281, 50.58592210497175, 50.57040677751814, 55.35261562892369, 62.29453999655587, 60.947374616350444, 54.75392409733364, 47.65202440534319, 44.13311965124947, 51.257010391780305, 50.882137707301546, 54.14074904578072, 54.85060828072684, 55.38639429637364, 53.204024178641184, 52.26047270638602, 50.34825897216797, 51.92334611075265, 51.43732309341431, 51.992529324122835, 53.99624388558524, 56.18845612662179, 48.242197445460725, 50.32477753502982, 54.354902948652, 52.837485858372276, 55.85225016730172, 57.33146953582764, 53.43777200153896, 51.218645913260325, 47.86797789164952, 43.188452993120464, 44.25111048562186, 43.73451886858259, 43.715835162571494, 43.6417430468968, 45.17916052682059, 43.1457702091762, 49.292358602796284, 43.93953589030674, 44.08753252029419, 43.987902300698416, 45.00954805101667, 45.34765086855207, 42.71067748750959, 45.42192016329084, 46.82578979219709, 44.90143755504063, 42.912984711783274, 47.24756281716483, 45.39537109647478, 43.33144692012242, 40.35285840715681, 40.36286728722708, 41.12796817507063, 41.684081145695274, 43.86950847080776, 45.8118565423148, 44.09348365238735, 43.609788281576975, 45.58692945752825, 40.97115428107125, 42.11719363076346, 44.28198480606079, 42.288866247449604, 42.580996309007915, 53.831915514809744, 55.9252097266061, 50.78285142353603, 57.18367787769863, 50.246391432625906, 53.39903579439436, 45.475817339760916, 45.844610350472585, 44.67204277856009, 44.41688755580357, 43.93596799033028, 47.760398932865684, 48.12152460643223, 49.87598296574184, 50.14112969807216, 48.57596806117466, 52.618648869650706, 51.67153991971697, 38.41020114081246, 45.97904757090977, 48.185514041355674, 41.671324253082275, 33.72719519478934, 21.093631369727, 16.56543128831046, 12.86803252356393, 11.445339356149946, 11.913368276187352, 17.27505428450448, 27.07010875429426, 47.6500962802342, 53.51912151064192, 52.51159449986049, 53.907619612557546, 50.59635135105678, 53.030034337724956, 54.04227917534964, 55.85739878245762, 58.06978164400373, 57.68104730333601, 58.57918534960066, 57.82691778455462, 61.87859998430525, 62.185828481401714, 59.697206088474815, 61.915925707135884, 47.13318157196045, 21.034290279660905, 5.682400958878653, 1.694395199418068, 0.2899225971528462, 34.43757207053048, 71.6390472139631, 65.20868396759033, 61.74657726287842, 52.40203183037894, 37.521026270730154, 28.56673162324088, 46.60706744875227, 17.062635694231304, 8.136509043829781, 8.571811948503766, 5.0663580383573255, 3.2753625767571584, 16.305210828781128, 29.978134836469376, 36.36136845179966, 23.917064871106827, 2.6638262144156863], [1.5901441020624978, 45.5641393661499, 48.78334052222115, 21.188715730394634, 12.480081592287336, 27.322361367089407, 30.51337194442749, 9.137884293283735, 0.38042760640382767, 8.952893716948372, 21.75610041618347, 28.488373313631328, 36.04257467814854, 26.18040234701974, 40.75428710665022, 61.272605895996094, 70.52238832201276, 62.646445410592214, 8.204381653240748, 0.08918060388948236, 0.0811266510614327, 0.01824840883325253, 0.10418133717030287, 0.29799824953079224, 0.36494913697242737, 4.225668566567557, 51.314454623631065, 54.22021211896624, 49.97164576394217, 58.55433859143938, 52.071311473846436, 52.47633239201137, 49.19081762858799, 51.37511239733015, 46.807210309164866, 47.22287239347185, 49.57721390042986, 56.67139761788504, 51.75992447989327, 45.71263974053519, 42.46607657841274, 38.513406208583284, 34.5733676637922, 33.83962399618966, 37.61110271726336, 47.35093811580113, 50.601044859204976, 40.38668918609619, 36.019607407706125, 36.90425552640642, 39.671667439596995, 42.10272748129708, 44.87267896107265, 47.13746166229248, 45.562760148729595, 44.84462213516235, 40.103230476379395, 43.35929877417428, 42.583688735961914, 47.17819547653198, 48.04944052015032, 49.37734201976231, 44.57546281814575, 42.87951871326992, 39.733975410461426, 42.79694284711565, 45.27793959208897, 51.657702582223074, 51.345464433942524, 47.7595408303397, 47.209434577396934, 41.223210607256206, 40.38939898354666, 38.5623527935573, 39.489162581307546, 40.40487609590803, 40.1730946132115, 40.11110625948225, 40.57541963032314, 39.07305233819144, 39.29535647800991, 39.585040773664204, 37.778651578085764, 37.30152572904314, 36.98506655011858, 40.992606844220845, 37.85777071544102, 40.51963254383632, 34.617648533412385, 36.68523441042219, 41.5103622845241, 38.418334007263184, 39.31339747565133, 36.47026409421648, 37.234649317605154, 38.57466152736119, 39.332612718854634, 37.035097054072786, 37.74500492640904, 38.34157725742885, 38.30835444586617, 39.12772076470511, 38.28626612254551, 38.303813798086985, 36.75575862612043, 37.02278484616961, 40.74535172326224, 45.37809787477766, 51.65120601654053, 45.73312997817993, 47.57133844920567, 44.04650340761457, 42.46534354346139, 39.244964667728965, 35.273693970271516, 34.38823638643537, 35.34387077604021, 37.78012807028634, 38.78235707964216, 40.54979119982038, 42.61066511699131, 42.12481580461775, 44.59865937914167, 52.29221902574812, 40.841785771506174, 29.751550606318883, 40.38858951841082, 35.9111772945949, 19.882555144173757, 24.582302774701798, 21.347287518637522, 14.283478719847542, 13.216072133609227, 12.616072603634425, 15.392120259148733, 24.920122453144618, 35.107788358415874, 43.92324583871024, 50.54549053737095, 49.23514366149902, 46.425021171569824, 45.88289492470877, 44.0956688608442, 46.395658084324424, 46.792612143925254, 49.40595122746059, 51.28810358047485, 54.58910935265677, 54.78092132295881, 56.07574592317854, 59.61540494646345, 63.37028789520264, 63.38209983280727, 43.092387199401855, 23.098006010055542, 6.8911104542868475, 0.08078410622796842, 0.4543582307440894, 28.48550718171256, 47.081365380968364, 49.33468355451311, 34.34583500453404, 31.630485943385533, 18.74147159712655, 33.29149103164673, 17.46214321681431, 14.098363075937543, 12.043128490447998, 8.34716887133462, 0.99065591607775, 0.7266751783234733, 4.6307298711368015, 6.178624366010938, 11.374078631401062, 2.9948377438953946, 0.26691293184246334, 4.419565864971705, 58.80631501334054, 54.84952783584595, 49.885821614946636, 51.2021369934082, 38.50816379274641, 44.506932735443115, 27.940183026450022, 21.68392947741917, 39.064280237470356, 45.70946093967983, 22.104708909988403, 37.408357756478445, 37.36732169560024, 44.16289963041033, 74.4510804585048, 69.62138066973004, 72.95944118499756, 17.724323068346294, 0.27467691951564377, 0.1919256927711623, 0.18086774327925273, 0.06221335594143186, 0.4286637652133192, 0.7357598936983517, 11.377083727291652, 57.301995277404785, 63.59414495740618, 62.63910116468157, 62.736494064331055, 60.77744252341134, 56.91782590321132, 56.082277229854036, 52.56657559531075, 51.491491249629426, 49.36499159676688, 55.45540380477905, 60.43997546604702, 61.335042408534456, 53.28006526402065, 52.84606340953282, 49.2074168750218, 43.743680068424766, 39.44659791673933, 45.02746050698416, 53.01397010258266, 54.238850661686485, 45.62135430744716, 43.01066248757498, 41.631973130362375, 44.54949392591204, 45.840014117104666, 49.90433856419155, 50.87738861356463, 50.40589427947998, 47.26233121326992, 43.72559043339321, 45.35767364501953, 46.75944144385201, 48.46263599395752, 49.05979892185756, 54.34492880957467, 49.883619035993306, 46.564558369772776, 45.55205992289952, 43.85354845864432, 47.739047118595664, 54.40790728160313, 51.67291218893868, 52.304222038814, 48.33200986044747, 41.45159442084176, 42.988619327545166, 40.426790714263916, 43.18783112934658, 42.87324448994228, 42.968559878213064, 43.2177848134722, 43.18137277875628, 41.595981461661204, 41.736529622759136, 42.66951288495745, 39.74084370476859, 38.62733582087925, 40.407057830265586, 41.935456548418315, 41.31878307887486, 40.78867721557617, 37.54130458831787, 38.07433911732265, 42.257849488939556, 38.94193288258144, 40.05107382365635, 37.80957453591483, 39.72081552233015, 40.85458435331072, 39.46587569372994, 36.46453183037894, 39.9671048436846, 41.19512251445225, 41.333881514413015, 42.16922174181257, 41.604197706495015, 41.5355668749128, 39.20626320157732, 39.73692144666399, 42.97568525586809, 48.0158702986581, 54.05627284731184, 48.31791891370501, 49.43779482160296, 46.15867240088326, 44.08222757066999, 41.45465857642037, 37.679737022944856, 38.43199763979231, 38.82401500429426, 40.95984261376517, 40.66776466369629, 44.36666945048741, 44.56958811623709, 45.06189577920096, 46.3172024999346, 54.01211704526629, 47.78483574731009, 40.15662390845162, 45.44142723083496, 40.450859274183, 23.907361711774552, 27.70244346346174, 23.897906950541906, 17.3281124659947, 14.844456298010689, 14.137626477650233, 17.09469815662929, 27.207188027245657, 35.89064884185791, 50.326226234436035, 59.38400214059012, 54.2802723475865, 51.01474060331072, 47.865730149405344, 49.39199577059065, 49.19822440828596, 52.66106762204851, 54.54722908564976, 58.05022593906948, 58.06669316973005, 61.90448202405657, 60.40053054264614, 66.68287631443569, 70.94780567714146, 73.36689744676862, 55.282873085566926, 31.809589658464702, 9.20519323008401, 0.04129918997309037, 0.5064684173890522, 37.322981766292024, 57.38041959490095, 57.82853324072701, 42.725907938820974, 43.01362589427403, 24.81666898727417, 27.692208766937256, 38.448697635105674, 17.47287470953805, 14.055240818432399, 8.08132905619485, 1.0740340820380618, 4.216317159788949, 7.728474344526019, 11.574280551501683, 18.38958876473563, 11.333548920495168, 0.6893623747995922, 1.2206665852240153, 70.43951020921979, 79.75838552202497, 48.64619697843279, 55.868033000401084, 48.26921898978097, 61.85031386784145, 55.68459708350045, 45.797102042606895, 55.026533194950645, 47.84142187663487, 40.885208538600374, 57.91961022785732, 42.90256936209542, 57.32028988429478, 76.60070719037736, 82.94817842755998, 84.90028871808732, 20.161554847444805, 0.6041580268314907, 0.3687018156051636, 0.24793145752378873, 0.24838949580277714, 0.5364059795226369, 0.922741943172046, 29.21607378550938, 66.99669865199498, 66.93645082201276, 64.32041236332485, 66.04237052372524, 58.033414772578645, 56.746160234723774, 53.819405283246724, 54.88337598528181, 51.46933691842215, 50.81617498397827, 53.74454539162772, 64.09299087524414, 62.83880628858294, 57.563185010637554, 58.44240311213902, 60.249157088143484, 53.189043862479075, 51.15716825212751, 52.29233019692557, 58.05147314071655, 58.32880006517683, 49.80028234209333, 47.34632451193673, 46.32512692042759, 50.778533118111746, 48.438536167144775, 52.95464985711234, 54.33434322902134, 54.29455784388951, 51.028379917144775, 46.57074226651873, 50.02779068265642, 50.82162584577288, 53.19078091212681, 53.94225638253348, 56.465074334825786, 52.05114780153547, 47.98167126519339, 48.53197206769671, 49.44493062155587, 51.37986149106707, 57.42208446775164, 56.00540583474295, 53.82745129721505, 52.393867697034565, 44.172328335898264, 45.01522472926548, 43.0571528843471, 43.76418072836739, 45.54544871194022, 44.624652590070454, 45.40575865336827, 45.29531703676496, 43.57945244652884, 44.68468502589634, 45.8027127129691, 43.453168937138145, 42.77870729991368, 43.02134881700788, 46.003765787397114, 43.08149937220982, 44.46461125782558, 39.76299108777727, 41.536814076559885, 47.19337729045323, 43.16040311540876, 44.265319551740376, 40.09095648356846, 41.70151417595999, 42.28034428187779, 43.36407913480486, 40.018267904009136, 42.27719327381679, 42.468678678785054, 44.115321840558735, 44.31881373269217, 43.20706374304635, 42.71434613636562, 40.914915561676025, 39.82141848972866, 45.028843198503765, 49.392232009342735, 55.942073004586355, 51.36866099493844, 53.905705383845735, 50.56752674920218, 50.43163735525948, 46.4122052192688, 42.61091872623989, 44.51497180121285, 42.80040305001395, 45.49947943006243, 47.6929041317531, 49.057537283216206, 51.99346038273403, 50.35978603363037, 50.779346057346885, 58.14165381022862, 54.81871952329363, 47.99692256110055, 50.077366079602925, 47.327192647116526, 29.712904725755962, 30.138728550502233, 24.234081642968313, 16.06454086303711, 13.406227827072144, 16.310870136533463, 23.728739159447805, 28.65643981524876, 38.06633826664516, 50.177555629185264, 58.90607724870954, 54.63944557734898, 51.6463040624346, 49.13456848689488, 50.3342479297093, 51.33843633106777, 53.04434415272304, 54.319039821624756, 58.07134846278599, 58.417104721069336, 60.70564678737095, 61.34107344491141, 63.15352494376046, 64.26481982639858, 65.54776300702775, 55.691489696502686, 36.149399757385254, 12.653582453727722, 0.21231197885104588, 0.6849537427936281, 43.283167362213135, 66.44470596313477, 62.90455709184919, 52.435817446027485, 48.10668672834124, 37.97803361075265, 44.900635038103374, 50.50608035496303, 26.742405652999878, 27.90709396771022, 15.79685456412179, 7.806667634419032, 7.865064638001578, 29.251533917018346, 20.403746468680247, 41.20192132677351, 24.117369277136667, 1.138902029820851], [0.2863976891551699, 11.243855493409292, 46.392340319497244, 23.08198172705514, 3.6866572839873175, 7.408289194107056, 20.238191740853445, 11.097022686685834, 7.0957066757338385, 7.531818611281259, 17.69422173500061, 26.04994297027588, 30.41592345918928, 27.59373368535723, 34.932700702122276, 61.65836293356759, 68.80209772927421, 56.45903982434954, 23.58607700892857, 0.21845193366919244, 0.12215613014996052, 0.057145330389695506, 0.2240934366626399, 0.9863316395453045, 1.4226494154759814, 9.910707235336304, 62.57430921282087, 40.84407867704119, 53.84953614643642, 58.551468985421316, 54.22582278932844, 51.646512508392334, 50.01595442635672, 47.52400384630476, 47.7267244883946, 45.62906333378383, 50.548433099474224, 54.01692172459194, 55.355787481580464, 46.512214115687776, 46.52785798481533, 44.53580944878714, 39.56789261954171, 41.178901944841655, 40.41578824179513, 45.38448326928275, 46.70338685171944, 44.5781899860927, 43.11609097889492, 41.82893718991961, 46.16527666364397, 46.48996598379952, 44.70804139545986, 42.044584955487935, 41.60811301640102, 40.32019492558071, 40.07214423588344, 39.87965134211949, 41.35293000085013, 43.60174921580723, 44.59100593839373, 50.549815790993826, 46.70355360848563, 45.7107880456107, 39.88259390422276, 36.63991131101336, 41.02171632221767, 46.985393387930735, 46.233278683253694, 49.777568680899485, 46.30377163205828, 41.4339668410165, 37.32254750388009, 38.509678500039236, 41.27135814939226, 40.41536092758179, 39.286125796181814, 41.92845971243722, 39.19369043622698, 40.059634004320415, 40.87702703475952, 39.273591245923726, 37.26017699922834, 39.84058856964111, 38.24403844560896, 37.593110357012065, 36.54461676733834, 40.027109486716135, 35.42168712615967, 35.52145283562796, 39.29813923154558, 37.657825878688264, 40.73828193119594, 40.1165988104684, 41.98856163024902, 38.45547907693045, 37.36977788380214, 37.20577607836042, 37.919790336063926, 38.28223269326346, 37.948173727308, 40.864784308842246, 38.635920320238384, 38.45500659942627, 36.36602374485561, 36.57559183665684, 37.13809714998518, 45.69789566312517, 48.06996202468872, 46.2256669316973, 44.03804397583008, 40.777667794908794, 36.0643572807312, 35.83617149080549, 35.48685080664498, 39.03044251033238, 41.377467564174104, 40.89773614065987, 43.12127086094448, 42.07570941107613, 43.65639679772513, 43.01719379425049, 49.930540221078054, 49.28941604069301, 47.60131645202637, 49.022702489580425, 51.98766558510916, 46.76382923126221, 27.92934557369777, 20.37906473023551, 14.656861884253365, 14.545842698642186, 21.49105269568307, 23.452966894422257, 24.0392941066197, 36.519287109375, 47.651385171072825, 50.79308264596121, 50.834295885903494, 54.65258114678519, 49.38161516189575, 44.85484293528965, 43.12631525312151, 44.55497258050101, 44.60718829291207, 46.17889513288225, 48.92989540100098, 51.650792598724365, 51.86348043169294, 57.74010699135916, 59.21194389888218, 61.10958726065499, 59.48543889181954, 49.51892893654959, 27.036776508603776, 10.427978038787842, 0.05346458664696131, 0.7231647638337952, 33.17304509026663, 51.585284982408794, 43.09661865234375, 27.821657180786133, 30.873451914106095, 32.647577149527415, 39.984961714063374, 19.66445640155247, 23.34641800607954, 27.245450019836426, 14.22032220023019, 3.7568510259900774, 4.459435062749045, 3.0092174751417975, 4.826239585876465, 13.088785478046962, 2.1889889282839636, 0.4177009734724249, 0.6671927901250976, 28.263536555426462, 50.34863070079258, 26.831542355673655, 36.732565539223806, 29.06038202558245, 37.442153794424875, 27.521811144692556, 16.414650167737687, 29.42625331878662, 29.001527309417725, 18.91741909299578, 38.84336573737008, 35.99280820574079, 39.14027268545968, 74.2369578225272, 68.91642338888985, 64.5640926361084, 30.991783210209437, 0.18610284450863088, 0.06467625485467059, 0.18884115400058882, 0.05697841756045818, 0.8553876802325249, 1.1942255411829268, 22.462165934698923, 71.02883556910923, 47.8527752331325, 62.24217142377581, 63.977477073669434, 59.62525749206543, 54.858675139290945, 54.99794135774885, 51.18610749925886, 51.48465422221592, 48.19033261707851, 56.3614558492388, 59.77675601414272, 60.383667264665874, 51.54504449026925, 54.853342396872385, 51.664108821323936, 47.95500407900129, 46.528858525412424, 49.16899333681379, 52.008607455662315, 50.901853220803396, 49.02220916748047, 45.26697186061314, 44.7254501070295, 47.78585365840367, 48.71510921205793, 46.781929288591655, 45.423216002328054, 44.44436420713152, 44.5467528615679, 44.186957768031526, 42.707283292497905, 44.382094451359336, 45.6718225479126, 49.83717032841274, 52.64095606122698, 50.86948503766741, 47.623960631234304, 43.569328921181814, 40.339802742004395, 45.72683143615723, 47.83931309836251, 49.59720039367676, 50.98402609143938, 49.764141287122456, 43.05149705069405, 41.243179730006624, 39.06922735486712, 42.188912936619346, 42.33245577130999, 41.91883993148804, 43.50747953142439, 42.48521539143154, 44.40726777485439, 42.81308003834316, 41.57626942225865, 40.53784029824393, 42.13205582754952, 41.285483837127686, 40.24632167816162, 41.04328005654471, 43.06438248498099, 38.394581590379985, 37.47849982125418, 41.93934753962925, 40.627506801060264, 43.84382445471627, 43.335793018341064, 44.27596419198172, 42.09289925439017, 41.31573976789202, 40.509814739227295, 41.37814153943743, 40.93673290525164, 41.250857489449636, 42.77225242342268, 41.70028781890869, 43.07874093736921, 38.925677571977886, 39.106219564165386, 39.33898074286324, 48.012090478624614, 50.92688410622733, 49.844427721840994, 45.4078048978533, 40.690099648066926, 38.72890111378261, 37.56464358738491, 39.249963896615164, 43.34650714056832, 45.590757914951865, 45.710228715624126, 46.973456382751465, 44.327426024845664, 44.799469266619, 44.89191157477242, 49.655947412763325, 52.72550868988037, 52.86068936756679, 52.91796684265137, 53.936517170497346, 52.00366728646414, 34.37717138017927, 23.704474312918528, 18.292220183781215, 15.716811316353933, 22.20424359185355, 26.092615331922257, 28.948736633573258, 40.62937934058053, 53.25264072418213, 56.854249886104036, 57.30016095297677, 58.653023856026785, 55.566592352730886, 48.724089758736746, 49.47728838239397, 48.82193429129464, 50.425852979932515, 50.42500529970442, 53.7613912991115, 55.63537951878139, 58.24344144548689, 62.83758340563093, 68.11958312988281, 66.80948638916016, 63.71698216029576, 57.405839579445974, 37.372786453792024, 16.698807171412877, 0.12609351958547318, 1.3083064939294542, 41.12218727384295, 60.318152700151714, 48.939369269779746, 36.13831390653338, 39.30705377033779, 38.584006854466026, 52.28299529211861, 45.9086206299918, 28.63344301496233, 27.610355513436453, 16.586741413388932, 6.164096985544477, 6.0969283155032565, 9.10090684890747, 9.597650936671666, 28.605228117534093, 5.800487765244075, 0.35361695076738087, 0.33303424237029894, 16.00419749532427, 77.31284890856061, 45.070400374276296, 34.08811937059675, 22.02501654624939, 36.21589401790074, 50.21625362123762, 40.48100750786917, 46.257652963910786, 35.847125325884136, 42.134529386247905, 52.46243599482945, 42.46085500717163, 50.00717190333775, 77.01563971383231, 80.92434883117676, 73.50888388497489, 37.42752088819231, 0.1496423352509737, 0.18754623777100018, 0.22352420006479534, 0.43744617966668947, 1.819053698863302, 1.1565798755202974, 39.74929966245379, 76.3458194732666, 53.54391963141305, 66.42005375453404, 62.224043573652, 59.414372716631206, 54.951405797685894, 54.23370899472918, 51.24678264345442, 51.94670942851475, 49.202643462589805, 57.03665052141462, 60.69276482718331, 62.593270846775596, 55.20387206758772, 58.61655970982143, 58.19081578935896, 56.434769766671316, 57.368246350969585, 56.38763318743025, 56.949047633579795, 54.700815541403635, 51.48049225125994, 50.00779376711164, 48.86712884902954, 52.493553502219065, 53.285224301474436, 51.954515729631694, 47.97893020084926, 48.115712438310894, 47.459052085876465, 48.76518487930298, 46.13898468017578, 48.76550449643816, 49.01762683050973, 51.77053090504238, 58.07059805733817, 52.37695230756487, 50.35932050432478, 47.54381316048758, 43.8361154283796, 52.13432468686785, 51.70661442620413, 53.647208077566965, 54.179127420697895, 52.62765720912388, 45.93885224206107, 43.371260098048616, 41.03774234226772, 44.62601791109358, 45.12058373859951, 44.82230799538748, 46.62643902642386, 43.758146217891145, 46.07011413574219, 46.669045380183626, 43.94867277145386, 43.62254517418997, 44.68716205869402, 43.659891741616384, 43.42168664932251, 41.86916725976126, 47.368704659598215, 42.441059589385986, 40.74940947123936, 46.35131468091692, 41.95747191565377, 45.88829020091465, 44.949265480041504, 47.83279568808419, 44.39343738555908, 45.5663697378976, 43.21204212733677, 43.84923710141863, 42.392884254455566, 42.118666648864746, 45.55126435416085, 45.530423232487266, 44.00677013397217, 41.915039266858784, 40.37148652757917, 41.289565903799875, 48.817893913814, 53.708518981933594, 52.827049664088655, 50.44463743482317, 46.23938267571585, 45.12771259035383, 45.42367805753435, 43.42894056865147, 47.98890086582729, 48.539389269692556, 49.37190505436489, 54.2454514503479, 50.14262008666992, 51.30573810849871, 50.213856492723735, 53.6261202948434, 56.6143980707441, 57.368840421949116, 55.94883360181536, 54.63126059940883, 54.17372867039272, 39.10138709204537, 27.129962274006434, 18.186470338276454, 17.329774822507584, 22.745325871876307, 28.298129899161204, 32.97653266361782, 41.74522876739502, 52.1717164175851, 56.44858625956944, 57.71459320613316, 59.48664787837437, 56.90266145978655, 49.92570080075945, 49.40095894677298, 49.76949487413679, 50.73886932645525, 49.55606358391898, 55.895450592041016, 56.12885100500924, 57.59514672415597, 62.53195994240897, 67.64802973611015, 67.25410161699567, 68.30757359095982, 62.516576630728586, 42.40494285311018, 22.405534642083303, 0.3276374733873776, 1.1655548853533608, 49.963186332157676, 69.56866468702043, 56.631928375789094, 43.662028312683105, 46.808735438755576, 51.78945084980556, 48.65244688306536, 48.05344615663801, 47.19789361953735, 49.12108898162842, 40.103814125061035, 24.194436958857946, 26.385358572006226, 13.24799302646092, 25.873363188334874, 59.74469007764544, 5.5278074485915045, 0.4421962504940373], [0.12794784722583635, 0.8270182396684373, 13.542715634618487, 8.686344317027501, 1.3200430870056152, 4.517093820231302, 10.214492900030953, 14.204863326890127, 11.51078530720302, 11.421139648982457, 17.016418014253887, 14.960866417203631, 30.89148943764823, 38.3685918535505, 27.821810041155132, 57.96341514587402, 67.75524044036865, 56.10124928610665, 47.07135302679879, 1.565840714744159, 0.029022971567298685, 0.06161281852317708, 0.03353243726970894, 1.082249241215842, 3.377395353146962, 18.69749297414507, 57.88055092947823, 56.293502467019216, 59.48054041181292, 58.99075494493757, 53.84735788617815, 53.29026869365147, 50.74929857254028, 49.168128286089214, 48.19562367030552, 46.488725730351035, 47.78840364728655, 53.750288077763145, 55.77860621043614, 50.85015514918736, 48.001192229134695, 48.36772012710571, 44.18532494136265, 46.4585462297712, 44.526561396462576, 48.233699798583984, 49.47076402391706, 47.25068950653076, 45.631036622183665, 44.120182105473106, 44.49717051642281, 46.22654587881905, 43.53526537758963, 40.78264617919922, 40.290949957711355, 39.23226336070469, 39.1621595110212, 38.663706166403635, 40.83612993785313, 44.265145846775596, 47.13235126222883, 47.38986192430769, 46.76980120795113, 41.82894761221749, 38.38682392665318, 44.408730370657786, 41.08221081324986, 40.377892766680034, 47.33071190970284, 50.58121817452567, 45.10004486356463, 40.88301638194493, 39.31676735196795, 38.92780024664742, 38.40796382086617, 40.78502593721662, 39.12380198069981, 40.62465803963797, 38.77922691617693, 40.651894978114534, 42.57460396630423, 42.59480585370745, 39.68081474304199, 38.88665301459176, 38.04156446456909, 38.089312485286165, 38.691328729902, 37.982810497283936, 35.772956780024934, 34.563035692487446, 40.12052454267229, 41.571721826280864, 40.55111483165196, 40.15114177976336, 40.69925389971052, 38.684595925467356, 40.80036061150687, 41.518925939287456, 42.20715543201992, 42.42694432394845, 40.04609543936593, 39.80181414740426, 38.6890983581543, 38.56958934238979, 37.56063100269863, 38.5815680367606, 36.881489753723145, 44.24602787835257, 49.17127582005092, 43.76369088036673, 38.063579831804546, 34.81025954655239, 37.051630292619976, 31.08298179081508, 35.28082629612514, 42.571067333221436, 45.24591881888253, 48.978258337293354, 46.99127851213728, 45.50320019040789, 46.49226583753313, 46.734424454825266, 47.98063598360334, 49.307835715157644, 49.75673450742449, 49.350876331329346, 47.64427716391427, 47.49044752120972, 49.38851472309658, 48.27220671517508, 30.43051815032959, 25.71886999266488, 33.86972706658499, 41.652956690107075, 39.194593702043804, 39.458187511989046, 50.150374276297434, 51.971917493002756, 54.54708317347935, 52.8316285269601, 50.93860919134957, 45.649028982434956, 45.165496894291465, 43.63217190333775, 45.73980024882725, 46.04194613865444, 49.86719696862357, 50.95238746915545, 54.47549588339669, 54.73788070678711, 62.49723284585135, 60.85454668317522, 62.53307165418352, 51.435725007738384, 33.12783663613455, 12.71732349055154, 0.3098203380193029, 1.8846128838402885, 37.15512023653303, 50.49777378354754, 39.68564026696341, 25.309148618153163, 32.387568610055105, 43.680576528821675, 30.448399339403423, 33.12273318426949, 41.37898921966553, 35.296379838671, 9.702254329408918, 3.785930105618068, 3.7528362699917386, 2.039975255727768, 17.742536033902848, 14.720260722296578, 0.4584495797753334, 0.08106171526014805, 0.0896432019237961, 3.456370532512665, 41.2928524017334, 25.741309200014385, 13.200626288141523, 9.487171973500933, 26.226972648075648, 19.849532093320573, 20.21516193662371, 19.849031823022024, 19.15093241419111, 18.178874220166886, 45.23692090170724, 42.22364003317696, 35.96894809177944, 64.57407024928501, 74.27719484056745, 60.91036851065499, 56.971010889325825, 2.6628104746341705, 0.014359543133260948, 0.18813197634049825, 0.339785421533244, 1.1258988018546785, 3.164066331727164, 28.401479142052786, 71.35565798623222, 61.15125560760498, 65.55293246677944, 61.79249095916748, 57.64244311196463, 54.73505278996059, 55.61239487784249, 51.769394874572754, 51.726552282060894, 48.99815797805786, 51.54586785180228, 59.157588141305105, 60.05274541037423, 57.02173273903983, 54.54383489063808, 55.0381749016898, 54.19470180783953, 52.3829277583531, 52.014044421059744, 53.5892288344247, 53.17924690246582, 52.2053040095738, 47.678875718797954, 47.790936265672954, 44.45080518722534, 48.24266297476632, 44.773086956569124, 44.36875738416399, 43.32734400885445, 43.06411150523594, 41.21088797705514, 43.648531436920166, 44.67098317827497, 48.66084378106253, 48.06081124714443, 51.52284499577114, 48.40084913798741, 48.55239282335554, 44.20583254950387, 46.92190074920654, 44.968369552067344, 42.78002745764596, 48.925990513392854, 53.15626573562622, 45.26153836931501, 42.27631780079433, 40.78039148875645, 41.85578850337437, 41.468846797943115, 42.292851039341514, 42.77722385951451, 42.698493821280344, 40.65890918459211, 43.06721387590681, 43.956413064684185, 46.31995746067592, 40.502970763615195, 39.11044406890869, 40.05290467398507, 39.77434097017561, 42.58386591502598, 40.308073793138774, 38.5208546774728, 39.076231139046804, 43.653572354997905, 45.110196181706016, 42.611533641815186, 41.353767258780344, 42.40822587694441, 41.42186655317034, 43.68071549279349, 43.90154661451067, 44.506647859300884, 44.90243114743914, 41.57178783416748, 42.17563492911202, 41.4656297819955, 40.234044211251394, 40.62397016797747, 39.81581129346575, 37.167317799159456, 43.59084401811872, 50.51895884105137, 45.339660440172466, 39.53938068662371, 37.835890838078086, 38.44204126085554, 37.0587591443743, 39.418329170772004, 45.07737636566162, 47.26254660742623, 49.94904327392578, 48.583010060446604, 46.36561407361712, 47.49111802237374, 47.930397033691406, 48.820020062582834, 52.338025024959016, 53.17225701468331, 52.85020800999233, 52.1402063369751, 53.13270092010498, 55.52133526120867, 53.10813903808594, 32.7786305972508, 29.354412419455393, 38.813040324619834, 45.42805889674595, 45.92912476403372, 46.07062830243792, 54.8175904410226, 59.04681995936802, 60.124416078839985, 59.03210367475237, 55.105777399880544, 49.982919216156006, 49.19121715000698, 48.69308689662388, 50.111075265066965, 50.3475467818124, 56.34394638878958, 55.91703864506313, 58.883155141557964, 60.612179619925364, 65.65545313698905, 66.97758415767125, 71.64952509743827, 60.93459687914167, 47.040565558842246, 19.278452702930995, 0.4331574855106217, 2.5180061076368605, 45.69669015066964, 58.943792070661274, 46.573465960366384, 34.559415681021555, 36.1475966998509, 58.10016959054129, 44.47457150050572, 48.55041953495571, 54.830420289720806, 47.222309589385986, 35.71870524542672, 20.192085232053483, 14.523168989590236, 9.802653193473816, 31.624305520738872, 30.33500473839896, 0.7714812883308956, 0.1371849344245025, 0.21665640787354537, 0.7515968467508043, 31.329264163970947, 34.76620101928711, 26.443890196936472, 13.941402401242938, 23.806637150900706, 36.164081301007954, 36.986285958971294, 32.39206756864275, 29.646789142063685, 39.26112617765154, 50.96497760500227, 55.82478741237095, 43.542411599840435, 71.51464666639055, 83.25274576459611, 71.11301299503872, 67.66180106571743, 2.61244906272207, 0.16619772118117127, 0.11784771776625089, 0.2810134052165917, 4.8368803177561075, 14.891987187521798, 40.85166610990252, 70.69339043753487, 63.927123478480745, 66.16376944950649, 59.65492630004883, 58.81567423684256, 55.423445565359934, 55.56894779205322, 56.14485618046352, 52.62032685961042, 50.40766954421997, 52.622435637882774, 59.035167830330984, 62.05035250527518, 60.06382778712681, 57.425461292266846, 61.4875762122018, 57.42036826269967, 60.110464096069336, 55.15813555036272, 57.854304109300884, 55.082626002175466, 55.25698757171631, 51.607640811375205, 50.35236883163452, 47.01716750008719, 51.15331547600882, 50.10109765189034, 46.53561217444283, 44.78200149536133, 45.20683172770909, 44.862253189086914, 46.34596456800188, 48.873059136526926, 51.96257216589791, 54.16996969495501, 52.54699557168143, 52.102970940726145, 50.47065496444702, 47.5283534186227, 50.1230400630406, 45.58244439533779, 48.42817292894636, 51.776461192539756, 57.13944911956787, 48.580258573804585, 43.56215143203735, 42.898588044302805, 43.50873020717076, 41.65258148738316, 44.93339579445975, 43.441610608782085, 44.59553616387503, 43.54221705027989, 45.53306007385254, 47.739356313432964, 46.7995742389134, 44.21010569163731, 43.38001135417393, 42.46023661749703, 42.25427116666521, 45.832391943250386, 44.69795608520508, 40.96880578994751, 41.313752583095, 45.31101996558053, 47.35828583581107, 45.8990911756243, 44.524872984204976, 44.67653131484985, 44.451475688389365, 45.915766852242605, 45.24208688735962, 46.953647068568635, 47.16556365149361, 44.26897430419922, 45.12056289400373, 43.933730670383994, 43.971233572278706, 43.39890350614275, 41.345689977918354, 37.79337133680071, 47.68888807296753, 54.81161846433367, 49.67749030249459, 44.98329775674002, 43.070597648620605, 43.59054177148001, 40.86759485517229, 45.43144266945975, 47.63265977587019, 53.24699183872768, 53.97520126615252, 52.29093708310808, 50.882968017033164, 50.65749897275652, 52.60053491592407, 51.900698457445415, 54.827752181461875, 54.04814692905971, 53.93706955228533, 53.02142204557146, 54.9215042250497, 55.57938398633684, 53.65162018367222, 35.95284216744559, 31.555341175624303, 40.683144501277376, 45.83065489360264, 46.10759966714041, 45.38919414792742, 54.321562017713276, 54.995714460100444, 60.11470249720982, 59.16983086722237, 56.59781272070748, 49.47947359085083, 50.85238899503435, 49.43140595299857, 50.81114101409912, 50.60677364894322, 57.07189873286656, 56.33320099966866, 58.91769463675362, 59.322573116847444, 64.8244068963187, 64.22269984654018, 69.59226771763393, 62.075630051749094, 54.46486861365182, 28.42676363672529, 0.5044354179075786, 3.315827799694879, 53.77185181209019, 66.49308626992362, 52.853299958365305, 41.25522790636335, 47.62407180241176, 58.719379152570454, 34.954278332846506, 58.63982922690255, 64.72647203717912, 54.80036585671561, 45.322029386247905, 24.39594166619437, 28.073399100984844, 36.18322011402675, 82.02474199022565, 39.434264864240376, 0.5817758164235524, 0.20355979991810663], [0.10605449415743351, 0.19291914946266583, 1.4260179890053613, 4.540355954851423, 4.670727610588074, 6.737632998398372, 5.5457655021122525, 10.90079687322889, 12.182364310537066, 16.110242639269146, 16.5451477595738, 15.28834022794451, 21.063719374792917, 26.211596284593853, 29.156558990478516, 47.31085395812988, 70.46933187757219, 57.1771674156189, 59.48975372314453, 7.13576477766037, 0.09266263525933027, 0.9041555119412286, 0.1782636208725827, 7.85770389011928, 27.010791982923234, 44.73228713444301, 65.65570327213833, 62.61216994694301, 64.26842594146729, 56.33929456983294, 58.54373564038958, 52.58204228537423, 53.47644567489624, 47.55894981111799, 48.74519143785749, 44.289773736681255, 47.05568831307547, 51.96979134423392, 56.79343230383736, 53.82493257522583, 49.27220187868391, 50.94078050340925, 48.926549843379426, 48.80558170591082, 50.370541845049175, 53.11543117250715, 52.569605009896414, 52.98465912682669, 54.29869897024972, 53.2209152494158, 50.24677358354841, 45.696533816201345, 41.89404875891549, 40.84334216799055, 40.381967885153635, 39.25242008481707, 41.2967711857387, 39.760496684483115, 43.119561604091096, 42.98679889951433, 42.40613099506923, 49.087633405412944, 42.68333980015346, 46.04601083483015, 41.73506007875715, 37.81683540344238, 44.797923292432515, 38.026525088718955, 42.46128926958357, 44.848242146628245, 37.95235306876046, 41.344282967703684, 38.52686486925398, 39.66061980383736, 40.49932295935494, 40.189349923815044, 38.38381883076259, 40.436358383723665, 39.08582660130092, 38.45415544509888, 38.884492124829976, 38.59359884262085, 39.3732944216047, 36.1216972896031, 37.86685201099941, 35.93572528021676, 40.44631167820522, 40.948794978005544, 39.72778109141758, 39.558922495160786, 40.341046469552175, 39.67309876850673, 39.91560132162911, 38.627387932368684, 38.3599066053118, 39.23484114238194, 38.47260638645717, 37.91696241923741, 38.90600374766758, 37.756587573460166, 37.95989186423165, 39.27888229915074, 38.643459115709575, 37.62553759983608, 37.40498093196324, 37.2199330329895, 35.24558155877249, 34.7823486328125, 39.84875965118408, 35.14300530297415, 33.24577188491821, 35.02328436715262, 34.556817054748535, 37.58474472590855, 35.60539402280535, 45.80369588306972, 50.67090899603707, 49.211846351623535, 51.67644534792219, 49.672557081495015, 47.01812287739345, 46.14316054752895, 46.64358718054635, 46.954341888427734, 47.09252071380615, 47.58002369744437, 49.155899456569124, 49.752708026341026, 51.418430941445486, 52.694349493299214, 49.49357148579189, 38.41842780794416, 47.60767752783639, 58.68411704472133, 51.84227105549404, 53.30686446598598, 54.34317091533116, 52.61595296859741, 54.431055205208914, 53.64258057730538, 49.95664807728359, 44.98833172661917, 44.74206672395979, 43.20682750429426, 44.90485259464809, 44.922879695892334, 47.163618155888145, 51.10873235974993, 51.848965644836426, 54.3420661517552, 60.33063861301967, 60.150207792009624, 62.78081662314278, 55.19191769191197, 36.44494833265032, 5.826407151562827, 0.5604515235338892, 3.6916156922067915, 49.42134148733956, 50.291916029793875, 34.019710881369456, 22.21649326596941, 37.86635521480015, 29.70442792347499, 23.10220445905413, 34.44136231286185, 36.10059213638306, 29.638096945626394, 11.246540972164699, 7.149450991834913, 5.409127005508967, 6.066332357270377, 25.16832947731018, 0.39215312578848427, 0.29108631185122896, 0.03886661818251014, 0.05275710193174226, 0.40808143679584774, 8.315761276653834, 15.378039734704153, 7.339760848454066, 4.355548637253897, 16.027321100234985, 20.305052518844604, 20.66434039388384, 19.46716230256217, 14.831086226872035, 24.52262122290475, 32.67067643574306, 33.362602370125906, 36.854006154196604, 53.814353942871094, 80.47763524736676, 61.76478154318673, 70.77885328020368, 9.401325242859976, 0.11151186310287033, 0.896988065115043, 0.2782513334282807, 10.273669838905334, 28.387631382261002, 50.27414948599679, 72.76878261566162, 67.07012721470424, 67.78876549857003, 61.81567709786551, 62.409581320626394, 56.982107162475586, 56.69522646495274, 51.69221428462437, 52.34816939490182, 50.443772384098594, 49.24435697283064, 58.805703571864534, 60.22510937282017, 58.95766067504883, 54.64884649004255, 57.83708994729178, 58.079731464385986, 56.71396575655256, 56.62846122469221, 57.39990234375, 56.31940535136631, 56.06684528078352, 56.44311107907976, 56.351332323891775, 52.47568620954241, 49.39299283708845, 42.84510775974819, 44.65867791857038, 42.78687143325806, 43.57912935529436, 45.32116780962263, 45.06510932104928, 48.184899125780376, 48.15706116812569, 49.66371897288731, 49.61831944329398, 47.709433896201, 53.020876611982075, 44.23944098608834, 40.46963678087507, 45.17875405720302, 41.020080021449495, 41.785142694200786, 45.40248952593122, 38.660075732639854, 42.07219362258911, 39.718599046979634, 41.1898592540196, 41.77200712476458, 42.47994518280029, 40.689842564719065, 43.21853869301932, 41.99373109000069, 40.82307079860142, 42.454202107020784, 41.02911615371704, 41.787070819309776, 39.1826810155596, 40.57942526681082, 40.04989262989589, 41.75806556429182, 43.54135199955532, 40.58193704060146, 42.53939744404384, 41.19422967093331, 40.903294699532644, 42.59385742459978, 40.87781565529959, 41.110069615500315, 40.16195317677089, 40.767148222242085, 40.20354161943708, 40.87272262573242, 40.64355366570609, 40.33776691981724, 42.57761948449271, 40.333174160548616, 40.95566674641201, 40.39752837589809, 39.37188046319144, 36.18124335152762, 36.16526596886771, 39.58532912390572, 35.628364767347065, 37.01101459775652, 38.508049147469656, 39.247347899845664, 39.99482468196324, 41.142055647713796, 46.178047452654155, 50.16928727286202, 49.628196307591026, 53.211569922310964, 51.64097132001604, 49.09828151975359, 48.54876586369106, 48.122942038944785, 49.25518921443394, 48.8470971924918, 49.727326256888254, 53.604348114558626, 52.275581564222065, 54.89263445990426, 56.496365547180176, 53.29238442012242, 46.82483441489083, 55.413273402622764, 62.645347595214844, 59.42149462018694, 57.956494740077424, 60.67961883544922, 56.60650144304548, 60.13601262228829, 59.47425924028669, 55.83086708613804, 48.124658243996755, 48.48149340493338, 47.06429713112967, 50.4781277520316, 49.78044523511614, 52.92614834649222, 53.39548179081508, 58.31554985046387, 59.28007098606655, 66.0650772367205, 65.3548115321568, 66.47973183223179, 60.517218589782715, 45.96733638218471, 7.659404039382935, 0.5952725836208889, 5.311224716050284, 60.87122235979353, 55.98330708912441, 42.71870265688215, 26.048947640827723, 45.13940640858242, 36.71243660790579, 22.05594645227705, 30.531562328338623, 48.32282086781093, 48.28682919910976, 18.840071746281215, 11.040569441659109, 18.051412991115026, 25.17170282772609, 47.83986895424979, 1.8644468230860574, 0.11031740398279258, 0.1883471262242113, 0.25686659663915634, 0.285236444324255, 3.2954296256814684, 16.68643764087132, 22.810241154262, 13.926221455846514, 22.25817550931658, 21.622507401875087, 35.495998110089985, 33.31425680433001, 31.857810156685964, 36.787213121141704, 34.70964615685599, 38.28803791318621, 44.431402342660085, 62.55947480882917, 84.47280774797711, 72.00600242614746, 78.17250783102853, 11.006279213087899, 0.3909378152872835, 3.392357647418976, 0.388136904154505, 15.07597201211112, 45.096869536808555, 61.268277168273926, 70.07999651772636, 67.60729939596993, 68.35309818812779, 62.06899452209473, 62.149649211338584, 61.059289251055034, 58.198761054447715, 52.72355624607631, 52.41087341308594, 50.98322010040283, 53.07403380530221, 59.55626882825579, 60.70655700138637, 60.85374069213867, 55.44825063432966, 60.39445781707764, 62.234966141836985, 60.082011222839355, 60.03013597215925, 61.04938111986433, 58.39686461857387, 58.08539424623762, 59.25309113093785, 60.124638421194895, 54.8817709514073, 52.43132543563843, 45.619912556239534, 47.089272430964876, 46.313836097717285, 45.95240470341274, 47.78250115258353, 48.098505224500386, 48.66060059411185, 50.940043994358604, 49.584849970681326, 55.72189153943743, 51.50946971348354, 54.10719272068569, 45.824578693934846, 46.012332916259766, 48.434377670288086, 43.34670169012887, 49.15468004771641, 50.01568692071097, 40.85433421816145, 46.91781520843506, 42.099868297576904, 45.495960167476106, 43.812686102730886, 45.91275828225272, 43.1051093510219, 46.36246306555611, 43.647579533713206, 44.975943088531494, 46.01971190316336, 45.13819394792829, 44.88592570168631, 40.103160994393484, 43.67219352722168, 44.19808183397566, 43.30693367549351, 47.77041128703526, 45.954673290252686, 45.47813803809029, 45.15860775538853, 45.28558955873762, 45.300754002162385, 43.51819017955235, 43.060453278677805, 42.42113215582711, 43.85032102039882, 41.93076304027012, 44.31259856905256, 42.88343402317592, 41.108388151441304, 43.9417210987636, 44.55695629119873, 42.52627229690552, 44.247712816510884, 40.751414026532856, 37.296425751277376, 36.40392616816929, 43.03565515790667, 40.63690076555525, 41.60941232953753, 44.03805092402867, 42.71280711037772, 43.02380500520979, 44.17281470979963, 51.06948546000889, 54.74935565676008, 52.00323302405221, 56.962040764944895, 55.313219342912944, 53.62383433750698, 50.16017818450928, 51.35373279026577, 50.85762446267264, 50.56403180531093, 53.45707062312535, 55.037184783390586, 53.92108522142683, 54.96063300541469, 57.36072145189558, 54.1761257989066, 49.35974570683071, 56.14633614676339, 60.81046036311558, 58.643324170793804, 56.515393189021516, 58.908926010131836, 57.514412130628315, 60.31565134865897, 59.775025912693565, 57.931199823107036, 49.117416858673096, 49.26956851141793, 46.23403256280081, 51.01468849182129, 49.45964690617153, 54.986730439322336, 55.847497599465505, 57.96611452102661, 59.34760052817208, 67.25786754063198, 65.1220121383667, 71.29893289293561, 63.71868446895054, 57.039989130837576, 11.526446546827044, 0.7530992861304964, 6.796619296073914, 66.13613646371024, 62.66068226950509, 49.32551193237305, 34.488120215279714, 56.1380295753479, 38.924072538103374, 34.40816729409354, 52.9095629964556, 57.420066016060964, 54.54134396144322, 35.03215374265398, 32.546460015433176, 42.085822514125276, 49.32222890853882, 65.0903422491891, 0.6644619852304459, 0.2965345952127661, 0.2940494199948651], [0.09430809625025306, 0.041502377284424644, 0.10857960116118193, 2.2230893841811588, 6.950790703296661, 4.499714204243251, 4.164721139839717, 12.67372441291809, 12.441803097724915, 13.042767558779035, 17.04973636354719, 22.976832900728496, 24.601465906415665, 18.206330026899064, 34.09080137525286, 35.598581314086914, 64.48073509761265, 58.76842648642403, 63.754662241254536, 22.651676314217703, 0.06810829854969468, 1.1144315600395203, 0.3259529966328825, 15.57727759225028, 59.65104920523507, 58.91868822915213, 64.65115356445312, 60.95193263462612, 61.17660958426339, 55.16744613647461, 59.065489768981934, 53.81257520403181, 53.16954721723284, 50.31857974188668, 49.0505439213344, 44.81686755589077, 46.11566652570452, 49.25181586401803, 56.26021364756993, 55.5183892250061, 55.24360881532942, 50.70601824351719, 54.482697691236226, 51.83270686013358, 52.48688670567104, 54.10976702826363, 53.773717403411865, 54.56809105191912, 54.520881516592844, 56.11525338036673, 55.42126383100237, 52.49563101359776, 44.36814594268799, 42.0449983733041, 42.427371638161794, 43.39779526846749, 46.377155031476704, 45.19223356246948, 44.04078851427351, 46.034577574048726, 47.406263147081646, 39.61164542606899, 50.94334438868931, 49.12784957885742, 46.57112789154053, 38.78381620134626, 37.701106207711355, 39.68760313306536, 33.450521400996614, 35.017048358917236, 34.99042633601597, 39.74750355311802, 36.44728292737688, 40.12613868713379, 38.43155990328108, 38.92481599535261, 39.84602900913784, 38.604837553841726, 40.4623133795602, 40.23470776421683, 37.01129599979946, 36.826539925166536, 36.0919520514352, 37.70154047012329, 40.965731212071006, 38.189661843436106, 35.36044222967965, 37.452030658721924, 36.20505830219814, 34.726089068821494, 36.116833550589426, 36.18832703999111, 42.420913287571494, 40.85878106525966, 37.54903098515102, 40.47100905009678, 36.431916986192974, 39.12779719488961, 36.937683309827534, 36.75351088387625, 42.626531328473774, 39.027892521449495, 37.34623391287667, 35.298551150730674, 36.289888858795166, 39.13019779750279, 34.472608361925396, 35.10928916931152, 33.603270598820274, 32.43355526242937, 33.536540099552695, 35.20627907344273, 39.55717849731445, 42.72307654789516, 49.270912987845286, 48.417681149074006, 51.09059061322893, 51.330696037837434, 47.85890007019043, 46.87967654636928, 45.66443313871111, 48.267169271196636, 45.55362326758248, 45.92421586172921, 43.99987404687064, 45.151287828172954, 43.616663524082725, 49.48965964998518, 47.60040276391165, 54.80270045144217, 47.54492139816284, 49.85820252554757, 54.658494063786094, 49.251558780670166, 54.02411311013358, 52.069682121276855, 53.60938555853707, 54.4176938193185, 53.07253646850586, 51.08089092799595, 46.10095371518816, 43.94199555260794, 44.70523084912981, 46.108555044446675, 48.147194726126536, 51.39863552365984, 52.34856196812221, 51.73915631430489, 55.17111478533064, 56.4766708782741, 58.767134121486116, 59.25960854121617, 61.444573811122346, 53.5973026411874, 31.43971620287214, 1.353050287280764, 0.32211094136748997, 9.758807454790388, 58.036013398851665, 46.37865236827305, 33.681615012032644, 24.754630259105138, 36.00011076245989, 37.05895716803414, 41.42263085501534, 30.507333959851945, 34.49614191055298, 30.807777541024343, 30.625227519444056, 15.414555992398943, 3.9462385092462813, 10.879285250391279, 1.782982125878334, 0.27771949768066406, 0.07742094062268734, 0.0723862379257168, 0.009197185946894544, 0.07371774754886116, 0.3197060232715947, 5.6333479796137125, 5.822605184146336, 8.7708318063191, 9.22751258100782, 15.153909955705915, 18.525669234139578, 14.537619505609785, 19.397431918552943, 32.710336753300254, 25.456372261047363, 23.44791555404663, 39.03400693620954, 44.5700466973441, 71.41475241524833, 63.3135211127145, 70.99028696332658, 28.074225936617168, 0.28705236688256264, 0.5468105812157903, 0.3686709286911147, 17.827460391180857, 63.28490148271833, 65.13947990962437, 68.41609055655343, 66.5096160343715, 66.79086521693638, 60.48420075007847, 61.872172900608604, 58.853924070085796, 56.180351052965435, 53.83361782346453, 51.302990095955984, 48.19068002700806, 49.53190469741821, 53.875769070216585, 62.27542550223214, 59.95802756718227, 59.89848150525774, 57.70479277202061, 60.19525991167341, 57.700193064553396, 58.426484789167134, 60.9260436466762, 58.250796113695415, 57.25611284800938, 58.30442578451974, 59.50642939976284, 57.774316447121755, 54.97555078778948, 47.542030947549, 43.86329678126744, 44.5041743006025, 46.882765020642964, 49.70815617697579, 49.003271852220806, 47.458735942840576, 51.495152950286865, 48.2389144216265, 45.499274458204, 56.67443745476859, 48.588394914354595, 50.94103411265782, 44.279483454568044, 41.037033626011436, 42.731980664389475, 38.11929048810686, 35.60417808805193, 37.55960961750576, 40.000748021262034, 39.1763060433524, 42.16354158946446, 40.59072303771973, 39.602380003247944, 44.13707317624773, 40.72528532573155, 41.18506152289254, 42.01546158109392, 41.16465466363089, 39.77742249625069, 39.64832149233137, 41.15011903217861, 41.9031856400626, 42.985607283455984, 40.42179148537772, 39.559367179870605, 37.60332768304007, 37.55655588422503, 39.464951583317344, 38.662205355507986, 43.34766401563372, 42.98235205241612, 40.07613945007324, 42.83690193721226, 39.23650523594448, 40.77953686032976, 39.35121304648263, 39.82242597852434, 44.23027283804757, 41.00803184509277, 37.61258963176182, 38.437139306749614, 41.01766552243914, 39.251930236816406, 35.42525502613613, 36.05953523090908, 33.61476639338902, 36.84874636786324, 37.01906408582415, 38.00786222730364, 43.55319520405361, 46.677688939230784, 49.211613586970735, 51.766942160470144, 50.89060408728463, 54.1373861176627, 50.46863998685564, 51.02234540666853, 50.57839025769915, 51.540361404418945, 47.194746085575645, 48.614464555467876, 46.85575042452131, 49.4304644720895, 47.14304453986031, 53.80478627341134, 53.85458748681204, 59.10836015428816, 52.85364389419556, 55.17718751089913, 59.41417816707066, 53.85407332011631, 59.310622215270996, 57.995932715279714, 57.58365787778582, 59.10658141544887, 59.570714133126394, 56.13976315089634, 51.24617467607771, 47.67028774533953, 48.296084199632915, 51.392746925354004, 52.670673506600515, 56.60750893184117, 56.370471136910574, 56.798032011304585, 59.357022285461426, 61.08058547973633, 64.52586364746094, 65.0739028113229, 67.86820425306047, 59.85919639042446, 40.621402808598106, 1.7511451542377472, 0.4683836581451552, 13.019013404846191, 66.36032009124756, 51.787147521972656, 41.90888316290719, 29.122740370886667, 46.0470426423209, 41.543546880994526, 28.435214383261545, 22.20850283758981, 42.34833240509033, 35.11156470435006, 31.20285906110491, 23.65330604144505, 21.690092529569352, 30.828438009534562, 7.637079477310181, 0.012136137395698045, 0.07062799084399428, 0.09628931672445365, 0.12216686457395554, 0.1422958094626665, 0.14506923992718967, 3.5584890757288252, 13.516215205192566, 15.01864242553711, 15.789312294551305, 34.18226746150425, 40.00512886047363, 28.716784920011246, 39.165070806230815, 45.90266602379935, 35.23057344981602, 31.088620253971644, 50.00480604171753, 50.93967226573399, 75.92926801953996, 71.482024874006, 77.46561200278146, 32.98095519202096, 0.31784200615116526, 4.796341921601977, 1.277535310813359, 19.46868916920253, 64.1604231425694, 61.71025208064488, 69.01887457711356, 65.97183935982841, 65.62816061292375, 60.3148592540196, 64.20566981179374, 60.474160603114534, 57.6662928036281, 55.47911105837141, 53.0660468510219, 49.02246972492763, 50.69155904224941, 54.073789255959646, 65.81478227887834, 60.90273938860212, 62.50884328569685, 58.265349115644185, 64.98375688280377, 60.54470566340855, 57.84404509408133, 61.38021264757429, 59.93480668749128, 58.26554366520473, 59.31408936636788, 62.37725135258266, 59.22129617418562, 56.72367933818272, 48.97850499834333, 47.12749794551304, 47.08089985166277, 48.51484475816999, 52.419273785182405, 52.66538940157209, 51.328604630061555, 53.24886785234724, 53.34448548725673, 49.94762584141323, 55.64648968832833, 51.15114763804844, 50.67193732942854, 45.085620403289795, 45.17602341515677, 45.60859741483416, 42.28607307161604, 39.52303504943848, 38.126530511038645, 43.32702439171927, 38.9969139780317, 44.58502353940691, 42.77661936623709, 43.46121147700718, 47.465107440948486, 42.29802049909319, 44.892324992588584, 45.43140098026821, 42.97140169143677, 42.15386274882725, 41.829277651650564, 43.343998840876985, 45.81144312449864, 44.79879181725638, 42.54703351429531, 42.710517678942, 41.28228766577584, 38.950760568891255, 41.750248840876985, 41.77094752447945, 47.70959370476859, 46.4746139390128, 42.400607177189414, 45.71593318666731, 38.91878495897566, 43.24136005129133, 40.315623010907856, 42.53354011263166, 46.861489636557444, 43.36272076198033, 41.730630602155415, 41.81846625464303, 42.97554976599557, 42.19218553815569, 36.15866865430559, 38.93149321419852, 37.43894720077515, 40.34291206087385, 41.572760581970215, 43.08617550986153, 46.91481706074306, 49.14270830154419, 51.105167933872764, 54.31610073362078, 54.04976238523211, 58.87378202165876, 58.04189852305821, 56.774123259953086, 55.822577885219026, 55.181290422167095, 50.07434708731515, 51.26258979524885, 48.76721027919224, 50.96569674355643, 48.12433515276228, 55.719213008880615, 55.22105496270316, 59.59954915727888, 51.853655678885325, 53.51186064311436, 58.32424899509975, 53.370176451546804, 59.057325635637554, 57.122884614127024, 59.03412560054234, 59.51374585287911, 60.135734694344656, 55.87913622174944, 51.39739179611206, 49.70076676777431, 49.885102476392476, 51.40513208934239, 53.11497259140015, 57.47953564780099, 56.29718153817313, 57.19252640860421, 60.577424730573384, 61.54601056235177, 65.44960580553327, 67.71203654153007, 69.95274026053292, 63.40071405683245, 50.78608928407942, 3.5132146137101308, 0.5012952121240752, 13.260519759995596, 69.7848231451852, 60.25632068089077, 47.900151525224956, 37.49948338099888, 50.33920199530465, 53.972842352730886, 56.94849525179182, 44.10961389541626, 51.563703877585276, 47.97900663103376, 48.92430904933384, 38.60260370799473, 40.55190692629133, 45.21747636795044, 4.692867611135755, 0.3824506178498268, 0.15733295971793787, 0.17062117239194258], [0.06331343084041562, 0.05657431263742702, 0.05583535407536796, 0.17830640929085867, 2.2043199113437106, 1.4034454630953925, 7.489610910415649, 14.251010656356812, 11.232995459011622, 11.028440492493765, 14.801959378378731, 31.38482195990426, 46.646911893572124, 25.883366857256206, 32.69534601484026, 32.891834122794016, 53.45984295436314, 63.28512382507324, 62.05335412706648, 47.38142681121826, 2.6346466030393327, 0.32450174593499725, 0.26337043621710365, 9.12066318307604, 56.501406465257915, 65.02388272966657, 65.68978418622697, 62.63104820251465, 61.923617362976074, 56.68870210647583, 56.29841136932373, 56.0604807308742, 50.13844769341605, 50.62136834008353, 47.23704671859741, 45.07696989604405, 44.810503005981445, 47.53771611622402, 53.28081566946847, 54.13134118488857, 53.42972251347133, 54.94115373066494, 53.69319472994123, 53.599602494921, 56.72163656779698, 56.62641845430647, 56.967449937547954, 56.54531908035278, 56.432994501931326, 57.526717390332905, 58.30656582968575, 55.160230432237896, 49.442029748644146, 42.185886996132986, 43.039167472294395, 47.262876646859304, 46.747233458927695, 50.46967874254499, 48.67482008252825, 46.45015280587332, 39.32814850125994, 49.52174990517752, 51.22778626850673, 45.164357389722554, 48.52671575546265, 45.3643856048584, 39.59222868510655, 39.2012049130031, 36.30232613427298, 32.77705683026995, 34.34849269049508, 40.67615461349487, 36.57021393094744, 38.34705591201782, 38.2130251611982, 38.432664666857036, 41.65614243916103, 37.867338384900776, 39.203317165374756, 37.48759501320975, 38.65877641950335, 38.04994746616909, 38.29828998020717, 37.97010224206107, 38.13783523014614, 40.22866630554199, 39.199252469199045, 37.37863336290632, 37.18140179770333, 35.18407263074602, 41.6855228969029, 45.02716868264334, 42.033881255558555, 38.28031151635306, 39.34568575450352, 36.988947119031636, 37.59278726577759, 35.405991145542686, 37.43515001024519, 40.657898221697124, 39.55109882354736, 39.101793561662944, 35.10836158479963, 36.05674205507551, 36.33810240881783, 38.3600629397801, 34.56038842882429, 31.804284708840505, 31.668833051409038, 34.66654300689697, 35.6143467766898, 40.090025424957275, 42.94241380691528, 47.10212312425886, 51.69716140202114, 55.45214857373919, 46.78584112439837, 44.25180877958025, 43.95668404442923, 42.22849334989275, 47.061292035239084, 47.93364879063198, 47.25458744594029, 45.23866489955357, 44.80157804489136, 47.07723120280674, 42.57250213623047, 50.256681714739116, 52.63689831324986, 52.28000061852591, 52.891174588884624, 51.23288972037179, 51.84065212522234, 51.99161911010742, 53.534039293016704, 51.86298710959298, 51.94485773359026, 54.275384289877756, 49.46454538617815, 45.82234832218715, 43.49626166479928, 43.423996925354004, 44.84013359887259, 49.511720180511475, 52.632864883967805, 56.02330092021397, 56.21108293533325, 55.89152833393642, 57.46588591166905, 57.72267048699515, 59.16027014596121, 60.36526148659842, 62.33793149675642, 54.95660999843052, 29.447198663439067, 0.8929989305990083, 0.16530240779476507, 17.3857547215053, 58.31463268824986, 48.292672634124756, 30.374175207955496, 29.493890557970317, 38.52237980706351, 37.84860604149954, 27.283032826014928, 40.12356090545654, 37.55014269692557, 31.994866847991943, 36.7451765196664, 30.198090485164098, 14.106171114104134, 0.5119744305099759, 0.043955678319824595, 0.04720139969140291, 0.14178256557456084, 0.1452912294438907, 0.04199736179517848, 0.07032303685056311, 0.07581778629017727, 1.1229618851627623, 5.3426770397595, 3.2741288372448514, 13.906082102230616, 22.727573224476405, 22.871168170656475, 14.042504770415169, 26.469702754701885, 38.32214314596993, 42.03618458339146, 27.91328133855547, 39.57813079016549, 37.25809253965105, 59.278848103114534, 71.0772089276995, 65.57254723140171, 55.71721887588501, 3.3370855961527144, 0.36008808495742933, 0.5170387444751603, 10.882347668920245, 61.40593487875802, 70.27028683253697, 71.4333666392735, 66.73069381713867, 64.01184981209892, 63.38110624040876, 57.91932882581438, 58.59382520403181, 54.60295016424996, 54.80511842455183, 51.81077139718192, 50.016419955662315, 47.85205956867763, 53.15815217154366, 57.83934811183384, 58.013622828892295, 58.84614903586251, 59.625028201511924, 58.27106400898525, 60.657669476100374, 60.73366887228829, 59.89984335218157, 58.55387306213379, 59.85799435206822, 58.219206128801616, 58.31999669756208, 60.00717912401472, 57.530660493033274, 52.8872731753758, 43.89432743617466, 45.971512249537874, 49.93886416299002, 52.007217815944124, 52.60630886895316, 53.924020835331504, 49.815161909375874, 46.90481512887137, 56.293363503047395, 49.336160046713694, 49.25746127537319, 50.6594375201634, 49.499088355473106, 44.06613901683262, 42.5295136315482, 39.6361517224993, 35.40457023893084, 34.797669410705566, 41.79308795928955, 38.86586400440761, 39.75399317060198, 40.8077917098999, 40.77482598168509, 44.1467798096793, 39.96829645974295, 40.65858956745693, 38.66401883534023, 41.132658209119526, 39.74660376140049, 40.84670162200928, 40.91917828151158, 39.35544102532523, 40.65745006288801, 42.10174431119646, 40.5331780569894, 37.76410205023629, 38.53716557366507, 44.81624221801758, 46.00173691340855, 45.643456527165, 40.82912615367344, 39.669951234545024, 37.78891406740461, 39.63641227994646, 38.8195994240897, 40.63166529791695, 40.58343090329851, 41.3076868057251, 42.31260129383632, 37.960444246019634, 39.73871408190046, 37.41258226122175, 38.22530262810843, 36.50310475485665, 32.04626267296927, 32.85301801136562, 36.556199414389475, 38.37757587432861, 44.70870494842529, 44.43886818204607, 49.61234746660505, 50.03914056505476, 55.19967882973807, 51.175838061741416, 48.49918351854597, 49.61790949957711, 49.19341972896031, 50.93991892678397, 51.81349856512887, 49.70335497174944, 47.71902935845511, 48.5749397277832, 48.825457027980256, 45.183607373918804, 51.73805502482823, 56.8256893157959, 57.10566350391933, 57.20016942705427, 56.560344559805735, 55.995779105595176, 56.21086754117693, 58.3484217779977, 56.645331450871055, 56.5946478162493, 57.19358600888933, 55.03078549248831, 49.08432258878435, 47.98980760574341, 48.937920570373535, 48.45778267724173, 53.881490911756245, 56.739444800785606, 60.57062939235142, 61.21937574659075, 60.790922028677805, 63.440561975751606, 63.688932282584055, 63.56806836809431, 66.04226630074638, 65.29584217071533, 61.597135407584055, 38.014622824532644, 0.7972060165234974, 0.12053895049861499, 20.740807056427002, 65.2854129246303, 55.600774015699116, 38.69451447895595, 36.578030654362266, 44.48689065660749, 41.60996471132551, 20.675910881587438, 40.78481749125889, 48.87247896194458, 33.9139905657087, 35.51821150098528, 33.12112815039498, 22.597996268953594, 3.093989623444421, 0.07935167809150048, 0.0341869046512459, 0.04103341119896088, 0.12550940950001988, 0.17879590445331164, 0.1863708794116974, 0.15090892942888395, 0.4912388346024922, 4.659454592636653, 5.134263217449188, 25.32280703953334, 70.32163402012416, 36.82761689594814, 30.956667014530726, 44.25324010848999, 52.55803973334176, 59.99461678096226, 39.39931889942714, 49.88751350130354, 45.85250697817121, 65.24686431884766, 79.5344798224313, 72.09592601231166, 59.591287749154226, 3.303881023611341, 0.6801123140113694, 0.7028586534517152, 12.393508774893624, 65.2103167942592, 68.93801839011056, 71.09221008845738, 66.32656574249268, 66.35843018123082, 62.72000598907471, 60.76911163330078, 60.254097257341655, 55.26084382193429, 56.42613662992205, 52.351462841033936, 50.928245953151155, 49.723518644060405, 52.971481868198936, 58.94802352360317, 57.9030248778207, 59.88943495069231, 59.5239041192191, 56.350012166159495, 61.98355252402169, 62.6317777633667, 60.502467564174104, 62.093459129333496, 59.938906124659944, 59.15631662096296, 60.78916413443429, 62.299646922520225, 61.6005608694894, 54.361691338675364, 47.04484564917428, 49.54173987252371, 54.28627559116909, 54.2056382724217, 58.00905091421944, 56.9013934135437, 51.80085631779262, 48.15947219303676, 54.82979495184762, 54.54228891645159, 52.1049268586295, 55.38356637954712, 53.40544203349522, 47.69073281969343, 45.929930755070274, 42.239137990134104, 37.65909392493111, 36.45733002253941, 43.066248076302664, 42.23432288851057, 43.476983887808665, 43.051559584481375, 44.21382645198277, 46.678856236594065, 43.21327543258667, 45.187321186065674, 42.83928516932896, 44.78554160254342, 42.59666449683053, 42.539560726710725, 43.643427985055105, 41.16586365018572, 43.732385771615164, 45.04859692709786, 44.14529289518084, 43.86938687733242, 40.64078480856759, 46.87406587600708, 48.84578398295811, 46.91536596843174, 43.41074671064104, 43.95934173039028, 40.31139155796596, 42.81782913208008, 39.591686725616455, 42.272631781441824, 43.760369641440256, 44.32688059125628, 44.91785267421177, 39.88443865094866, 41.224186829158235, 41.28363561630249, 41.37410463605608, 38.153121267046245, 35.17854186466762, 36.781571183885845, 42.23955488204956, 43.029683181217735, 47.62006964002337, 46.6229510307312, 53.25147690091814, 52.41853380203247, 56.193180901663645, 54.84569590432303, 55.302988120487754, 55.56353167125157, 55.417803628104075, 55.68412460599627, 55.57768862588065, 51.19374009541103, 50.39264406476702, 49.42401654379708, 50.89130932944161, 47.860421725681846, 53.44355985096523, 57.01875196184431, 55.93982178824288, 57.17780317578997, 56.32752432141985, 56.13488204138619, 53.79914433615548, 58.00194638116019, 57.140859603881836, 56.6328490121024, 59.163521902901785, 54.76613555635725, 50.99242646353585, 49.52665185928345, 49.6958543913705, 51.01817648751395, 55.5955559185573, 56.156949520111084, 61.96529265812465, 61.29498604365757, 61.873520851135254, 62.70037037985665, 64.1726519720895, 64.35767555236816, 69.29621192387172, 65.35215037209647, 67.11278915405273, 46.438493728637695, 2.158689571278436, 0.17839269180383, 22.34411777768816, 71.34424904414585, 63.04920469011579, 41.67900896072388, 42.380276748112266, 51.77437325886318, 54.40426295144217, 39.11136817932129, 53.1662711415972, 54.593299116407124, 46.71867288861956, 49.993296350751606, 54.56252554484776, 39.89477409635271, 2.151628247329167, 0.4773939517991883, 0.09472184654857431, 0.26499020787222044, 0.2469169662467071], [0.11589986085891724, 0.08128416618066174, 0.13373857364058495, 0.14755366875657014, 0.40286336679543766, 1.5443550390856606, 27.013225589479717, 43.8584816796439, 19.78923041479928, 9.570219448634557, 9.484425698007856, 29.233020441872732, 50.23029940468924, 37.225053855351035, 31.049637385777064, 37.26375184740339, 39.28906488418579, 63.1111478805542, 58.85664081573486, 61.086679049900596, 7.279348433017731, 0.1985553734536682, 0.464891428393977, 6.8057370696749, 56.08470909936087, 65.36410127367292, 65.69187559400285, 60.781437737601145, 60.37807396480015, 56.76708473478045, 54.204182624816895, 53.67410455431257, 51.93578338623047, 49.59125620978219, 47.34259680339268, 45.98052406311035, 45.67987898417881, 45.29943037033081, 48.97569097791399, 54.60356160572597, 54.162062644958496, 53.64466503688267, 55.65762070247105, 55.685906818934846, 55.9818514415196, 54.75752673830305, 55.142529896327424, 54.95032187870571, 53.51565783364432, 53.335848876408164, 57.20962939943586, 53.07505866459438, 50.93940476008824, 41.52168437412807, 44.34512308665684, 48.84472785677229, 48.522786549159456, 48.56381566183907, 47.099444593702046, 45.520956311907085, 51.820728165762766, 50.13690171922956, 43.890050819941926, 45.49281958171299, 42.58582183292934, 44.22043418884277, 39.559881346566335, 39.78574991226196, 36.32988268988473, 34.83543634414673, 32.7294408253261, 36.595936162131174, 39.16937174115862, 39.751915659223286, 36.23102372033255, 38.92572968346732, 39.601900577545166, 39.39598029000418, 39.68879474912371, 38.79602766036987, 37.27900314331055, 37.76029791150774, 38.55236823218209, 38.621798106602256, 37.31419229507446, 37.47199283327375, 37.543246609824045, 37.239099638802664, 36.359808581215994, 35.20714065006801, 38.74299553462437, 38.92314147949219, 36.88649593080793, 37.22134699140276, 34.08570487158639, 34.77073124476841, 34.65377221788679, 36.80279793058123, 38.451014859335764, 38.089920452662874, 40.877183369227815, 36.54729529789516, 34.956265517643516, 36.51049068995884, 36.272188322884695, 37.88819340297154, 33.78344781058175, 29.989835602896555, 31.036845752171107, 34.39318002973284, 38.10409130368914, 43.51413590567452, 46.15022339139666, 49.2811198915754, 53.3217579296657, 51.25252880368914, 46.36602749143328, 43.16965811593192, 42.85091297967093, 48.137192794254844, 48.666513511112754, 50.96994209289551, 50.39161920547485, 46.6824380329677, 46.20270660945347, 42.23728976930891, 43.87960420336042, 48.0131049156189, 51.27736861365182, 53.887716497693745, 53.581471170697895, 53.529436111450195, 53.256281580243794, 51.07536711011614, 49.49536759512765, 47.286125319344656, 49.788887296404155, 45.07301984514509, 44.260737214769634, 44.69127886635916, 44.945999826703755, 44.7987779208592, 48.402012961251394, 55.660497256687705, 56.03212513242449, 57.75020619801113, 58.351659638541086, 58.57603086744036, 59.94337381635393, 60.26642336164202, 59.916088240487234, 58.16589954921177, 60.29259722573416, 51.33982597078596, 24.25081637927464, 0.11050343114350523, 0.03334739737744842, 15.349722351346697, 57.9783433505467, 45.886730330330984, 30.016798087528773, 33.49458340236119, 36.51069566181728, 36.10592835290091, 27.909218379429408, 43.405021395002095, 34.50845411845616, 29.59772096361433, 58.643532616751536, 45.7793459211077, 9.356383425848824, 0.27092014253139496, 0.020573222477521216, 0.22860159618513926, 0.17028983017163618, 0.0808137378522328, 0.20623993181756564, 0.11348110743399177, 0.052341556908296685, 0.17943178676068783, 1.26748745569161, 1.6817461124488284, 24.001327412469045, 60.573068210056846, 31.379874842507498, 13.564399225371224, 22.640606096812657, 42.21669183458601, 58.118557998112266, 38.76377064841134, 38.99773733956473, 45.26737485613142, 45.01072229657854, 72.68996919904436, 64.60026495797294, 68.8252282823835, 8.2797418151583, 0.149013238293784, 0.5772309888686452, 8.680741463388715, 60.98705577850342, 68.28959165300641, 69.89613328661237, 64.0905590057373, 63.54672350202288, 60.36474731990269, 60.708717891148154, 57.72135032926287, 57.10851921354021, 53.247130802699495, 52.01463154384068, 49.16865634918213, 50.25564990724836, 49.44397871834891, 53.6731595993042, 58.11013330732073, 58.90608419690813, 58.211556162152974, 59.55501815250942, 58.5313470023019, 59.47961630140032, 58.60588032858712, 56.51708160127912, 58.23224094935826, 55.43828691755022, 55.711271217891145, 57.654699734279085, 56.60170718601772, 51.34269905090332, 44.54792363303048, 47.073211669921875, 51.35635226113455, 49.54530429840088, 51.42981556483677, 46.9528306552342, 49.440758228302, 55.13299001966204, 50.19784089497158, 50.065376962934224, 48.379983697618755, 46.165981905800955, 47.58216026851109, 45.049302169254844, 45.72698777062552, 42.92469590050833, 38.30428280149187, 34.49909142085484, 36.706818989345, 42.576570306505474, 42.59812709263393, 37.53975861413138, 40.6982672555106, 42.36149229322161, 41.87582015991211, 39.983665875026155, 41.20531899588448, 40.147476605006624, 40.40663399015154, 39.73248849596296, 38.22346830368042, 39.54019362585885, 39.28300258091518, 40.706674575805664, 38.95895249502999, 38.17929513113839, 38.776305198669434, 41.01038728441511, 40.83439288820539, 38.51403154645647, 38.21581833703177, 36.43090949739729, 35.70924874714443, 35.941579137529644, 39.90066269465855, 40.68129628045218, 39.148561886378694, 42.48280784061977, 38.803847857883994, 37.29276057652065, 38.746507849012104, 38.61363397325788, 38.901563848767964, 35.35416453225272, 33.071712562016074, 32.86582006726946, 36.47868183680943, 42.84954765864781, 47.299535342625205, 47.354606764657156, 49.85523911884853, 54.375566891261506, 52.29909079415457, 52.24239001955305, 49.0131139755249, 47.86378117970058, 53.91494648797171, 53.362526484898154, 54.30351407187325, 53.39709029878889, 50.69674587249756, 47.46611492974417, 46.528146335056846, 46.02428729193551, 51.33293335778372, 53.68185179574149, 57.08003159931728, 56.328667300088064, 56.92770276750837, 57.686491216932026, 54.172874041966026, 52.199182646615164, 51.957090037209646, 51.94232511520386, 49.31266123907906, 49.8346585546221, 47.54397644315447, 48.11571938650948, 50.86236660821097, 54.12192637579781, 59.21213150024414, 59.23816640036446, 63.45842579432896, 63.37896619524275, 64.12274306161063, 64.84061009543282, 64.4817703792027, 64.1492087500436, 65.85024588448661, 62.76291111537388, 59.711227553231375, 28.0970299243927, 0.15030109775917871, 0.024368947371840477, 18.135606050491333, 66.37793377467564, 54.455401693071636, 35.717895780290874, 38.92148780822754, 41.333964892796104, 40.36284644263131, 25.87338055883135, 50.352320194244385, 44.655394894736155, 22.661744253976003, 64.84876728057861, 60.48668820517403, 14.159251008714948, 0.16538513478423866, 0.05648753818656717, 0.06279991553830248, 0.13487176783382893, 0.08077702910772391, 0.23751836057220185, 0.21602151622729643, 0.2066975494048425, 0.183845955612404, 0.5168546172124999, 4.021952595029559, 57.71899488994053, 74.53420870644706, 45.61629949297224, 31.866926193237305, 35.48742403302874, 54.95860065732683, 65.75308227539062, 53.17714854649135, 47.955632890973774, 54.56044108527047, 52.11705493927002, 81.10589831215995, 67.02286556788853, 74.01771436418805, 8.090113316263471, 0.2751624248921871, 0.6560632416180202, 10.556747266224452, 65.64994321550641, 66.61302607400077, 69.61271626608712, 64.92603124891008, 65.91792133876255, 61.282604353768484, 60.7865446635655, 59.319015639168875, 57.62741763251168, 52.78461701529366, 53.33841276168823, 49.388212476457866, 51.55265276772635, 49.5057829448155, 53.06653669902256, 58.02990593229021, 59.413281849452424, 59.33017444610596, 60.365754808698384, 58.41426985604422, 57.98083775384085, 57.79412228720528, 57.59454917907715, 58.197433948516846, 56.27415173394339, 57.497885840279714, 60.3479118347168, 57.09451511928013, 53.80158315386091, 46.980359418051584, 49.044714382716585, 54.425851004464285, 53.421808515276226, 55.74301058905465, 53.774384430476594, 50.75358213697161, 54.978906767708914, 54.07415403638567, 51.389703614371165, 51.8579774584089, 50.98052419934954, 50.312138761792866, 50.08486318588257, 46.83451672962734, 45.13751302446638, 42.267952169690815, 37.20043291364397, 41.91835355758667, 44.882260526929585, 45.722679887499126, 40.851113728114534, 44.00223643439156, 44.74774687630789, 45.27160978317261, 43.94030019215175, 43.897030285426546, 41.185804980141775, 41.462294646671836, 42.2673476764134, 44.196914536612375, 42.11075265066964, 43.66762856074742, 42.786680357796804, 42.55452019827706, 41.89047391074044, 42.83978543962751, 43.96928807667324, 44.801188945770264, 41.279855796269004, 41.6477108001709, 38.04625449861799, 36.74834142412458, 38.46222230366298, 42.65470627376011, 41.99492965425764, 41.67353030613491, 45.17779173169817, 41.94032376153128, 40.57879992893764, 41.56233828408377, 41.134284087589805, 41.18531513214111, 37.3499824660165, 36.63250453131539, 36.95933737073626, 42.669047355651855, 45.724472522735596, 50.44393219266619, 49.838622501918245, 51.380914143153596, 56.67215844563076, 58.68651417323521, 56.290577275412424, 55.99837078366961, 56.092894077301025, 59.788095474243164, 56.294951166425435, 56.589381081717356, 55.03505516052246, 50.77716779708862, 49.30644607543945, 47.44364445550101, 47.74729463032314, 52.64530215944563, 56.05104507718767, 58.09837000710623, 55.64610058920724, 56.57755177361624, 59.19173853737967, 53.69647775377546, 54.041469710213796, 52.33744832447597, 54.07114199229649, 48.061311517442974, 50.82023620605469, 48.40855816432408, 50.86712612424578, 51.448752880096436, 55.41034473691668, 60.232898303440635, 59.2502076285226, 63.41716044289725, 64.82403169359479, 64.62074824741909, 66.96780109405518, 65.66613251822335, 64.98859977722168, 67.28035885947091, 66.60919066837856, 62.50498008728027, 37.65233680180141, 0.3548530244401523, 0.4930170848965645, 19.90272923878261, 71.82978916168213, 59.558916091918945, 43.04741150992257, 43.7235233443124, 50.633423464638845, 48.83075155530657, 38.88721581867763, 58.97050789424351, 50.99175943647112, 40.002856799534385, 79.43243857792446, 77.09617628370012, 14.213026591709681, 0.31043468362518717, 0.2785717376640865, 0.2413256477032389, 0.16788100371403353, 0.13797002658247948], [0.013843736927291113, 0.034899926212217124, 0.04202779069808977, 0.008060896785796752, 0.01670254660504205, 0.942567759326526, 28.916952099118912, 42.509033816201345, 26.01938305582319, 14.90677990232195, 13.526820761816841, 14.23972591332027, 32.28533976418631, 53.941474710192, 31.93345866884504, 34.934048652648926, 36.54777124949864, 63.90307576315743, 57.9281565121242, 63.359483446393696, 13.452266590935842, 0.09848782446767602, 0.6551498249173164, 3.4072734756129126, 53.97053902489798, 64.39689118521554, 63.347845213753835, 61.51425034659249, 60.249365534101216, 57.18158299582345, 54.21750232151577, 54.64801965441023, 52.23165852682931, 50.03868893214634, 48.97693123136248, 46.29505164282662, 45.29716873168945, 45.48765359606062, 45.22593232563564, 50.71134751183646, 51.53410802568708, 54.154499530792236, 53.13582760947091, 54.35660178320748, 55.00609506879534, 55.0690735408238, 56.247633934020996, 53.177082538604736, 52.57458686828613, 54.55215883255005, 55.33088861192976, 52.64254025050572, 49.035744258335654, 41.54284858703613, 43.274780886513845, 49.888531412397114, 49.84975699016026, 49.59610605239868, 42.75400645392281, 49.1019640650068, 48.022526672908235, 46.67304059437343, 49.271812779562815, 44.81923689161028, 42.02717276981899, 40.23256424495152, 41.20621531350272, 40.74939557484218, 41.76438842500959, 33.592160429273335, 35.26278877258301, 34.36378567559378, 51.66329935618809, 40.92316654750279, 33.89589398247855, 36.86560269764492, 38.804153578622, 40.025264739990234, 34.697775159563335, 34.44592033113752, 36.1316088948931, 35.24748189108712, 37.35050358091082, 37.55878973007202, 35.67991345269339, 37.51921626499721, 36.48895474842617, 34.6130279813494, 34.99766288484846, 35.93455450875418, 37.013102531433105, 37.26802846363613, 35.38033839634487, 33.85441323689052, 36.66687726974487, 34.88068996156965, 37.68865850993565, 34.81291723251343, 37.925689356667654, 39.55043874468122, 36.86601611546108, 36.497063296181814, 37.526428495134624, 37.42803505488804, 37.08855996813093, 35.3769268308367, 32.222993578229634, 30.269163608551025, 32.10158423015049, 36.992469855717246, 41.36096559252058, 44.90883738654, 47.54834338596889, 49.169948714120046, 50.52007402692522, 49.74632263183594, 45.719146728515625, 46.16742365700858, 41.05869810921805, 43.892538275037495, 50.45638336454119, 51.518443311963765, 52.19248110907418, 51.3197317804609, 45.72222825459072, 42.2145483153207, 42.86731767654419, 47.45928832462856, 54.20005886895316, 51.686061654772075, 50.12458603722708, 52.23299952915737, 51.23888601575579, 51.8110944884164, 46.066459383283345, 44.56507526125227, 43.37677001953125, 45.47128364018032, 44.05287490572248, 44.573989800044465, 43.66258416857038, 48.233546938214985, 51.25921991893223, 56.838324614933555, 57.56558213915144, 58.30565561567034, 57.2246618270874, 57.93536179406302, 57.6375481060573, 61.609593527657644, 60.72686658586775, 59.453560556684224, 53.890881402151926, 56.93948343821934, 18.186576298304967, 0.15976320074072906, 0.1704410756272929, 20.48343709536961, 63.34632355826241, 43.51539005552019, 35.162557533809114, 35.30625670296805, 34.04960897990635, 42.713765961783274, 28.378228732517787, 44.38981737409319, 30.74217959812709, 39.71112278529576, 68.42707565852574, 32.24395281927926, 0.2388041301497391, 0.08907858614942857, 0.16406667338950293, 0.1408342043203967, 0.17445831506380013, 0.07064968360854046, 0.0796672443726233, 0.02591851949026542, 0.04803087143227458, 0.04562105092086962, 0.19410122531865323, 1.0502718942505973, 35.29480607169015, 63.69014821733747, 36.19861732210432, 16.803068365369523, 17.49605737413679, 24.420170034681046, 43.50789294924055, 62.47169821602957, 38.3389265196664, 43.48551974977766, 39.1290409224374, 73.29196112496513, 62.279490198407856, 72.18181269509452, 16.26462640081133, 0.059392692654260566, 0.9145953974553517, 5.656505456992558, 62.04789979117257, 71.03028079441616, 69.89382648468018, 66.433915410723, 65.3323063169207, 61.6777275630406, 59.114085469927105, 57.86700194222586, 58.18435049057007, 56.03161096572876, 53.76330900192261, 49.90507159914289, 49.34590836933681, 49.81831986563546, 49.745401995522634, 55.16094609669277, 55.53736475535801, 57.63437972749983, 57.42889717647007, 59.89131791251046, 58.3741648537772, 57.998215198516846, 58.34538541521345, 55.212366240365164, 53.94984034129551, 56.17179434640067, 55.58740568161011, 55.631050791059224, 50.2301778112139, 43.84364032745361, 46.554660660879954, 53.15402494158064, 52.63601589202881, 51.13063655580793, 51.17566783087594, 51.927025181906565, 49.098594188690186, 51.168532030923025, 50.833601066044395, 47.550584180014475, 44.26421478816441, 41.9187148639134, 45.97701869692121, 43.41057300567627, 46.22176204408918, 36.54524557931082, 37.151555810655864, 35.504829270499094, 51.73135348728725, 42.57485062735421, 37.63087381635393, 40.258095400674, 40.593269552503315, 41.3790864944458, 37.43178013392857, 38.36962366104126, 39.96492658342634, 38.5852610043117, 40.330895151410786, 40.174609320504324, 38.27214738300869, 40.57926893234253, 38.06528908865792, 37.10946709769112, 38.8770158631461, 39.43466785975865, 40.299458026885986, 39.189236640930176, 39.58481495720999, 35.394596099853516, 36.63618360246931, 37.5578864642552, 38.23011078153338, 37.03750460488455, 40.963691915784565, 39.60796635491507, 38.39800010408674, 36.69320746830532, 38.98318086351667, 38.84806966781616, 38.88037879126412, 36.269204071589876, 33.10974700110299, 33.83359643391201, 35.24593244280134, 42.362072467803955, 45.34506613867623, 46.94432258605957, 49.24137966973441, 50.69645404815674, 50.498982770102366, 53.950931208474294, 49.13266120638166, 51.7460697719029, 48.313284465244834, 46.9141708782741, 54.19378464562552, 55.18881532124111, 54.925423009055, 53.88540274756295, 47.97091892787388, 45.105652059827534, 45.06113495145525, 49.75561237335205, 55.86616393498012, 56.55778762272426, 53.97966200964791, 55.71662480490548, 54.38332108088902, 55.36815527507237, 48.922269753047395, 48.3846389906747, 46.20841802869524, 48.70919976915632, 47.341950620923726, 48.34385653904506, 46.09441546031407, 53.85374675478254, 54.47580507823399, 59.08796719142369, 62.05976731436593, 61.69138077327183, 61.19755145481655, 62.998329980032786, 61.53425421033587, 65.9248070035662, 62.52468517848423, 66.59559999193463, 55.87065247126988, 64.17327036176408, 20.975767339978898, 0.025623046327382326, 0.1937933468392917, 25.635396071842738, 69.78256498064313, 53.913098267146516, 35.759383474077495, 37.310085909707205, 34.218585695539204, 50.954777649470735, 26.67873236111232, 61.20204693930489, 31.90217787878854, 38.4399984904698, 73.2777659552438, 40.10166713169643, 0.3222202669296946, 0.09042454856847014, 0.12932673894933291, 0.0775365833459156, 0.10158372191446167, 0.06287317017891578, 0.15558486352009432, 0.10415883694908448, 0.16460661084524222, 0.14557432782437119, 0.14827040529676846, 1.9079534028257643, 37.99330922535488, 72.23208291190011, 56.46491800035749, 32.339615617479595, 38.40992668696812, 34.23699842180525, 48.49813781465803, 75.40263625553676, 45.28088910239083, 49.88436596734183, 46.913104329790386, 79.33499009268624, 65.39525699615479, 79.4151167188372, 16.492157323019846, 0.17239369585045747, 1.2970675655773707, 7.661910602024623, 66.4598947252546, 71.00437791006905, 69.94247777121407, 67.50730092184884, 66.98779106140137, 61.6498235974993, 61.17442090170724, 59.62482670375279, 58.303140367780415, 57.05881527491978, 56.54305049351284, 50.68148415429251, 51.059181281498496, 51.46836069652012, 50.23970379148211, 56.59499870027815, 56.773883547101704, 57.817329270499094, 57.634386675698416, 59.41670036315918, 59.88965034484863, 58.65298911503383, 59.28263487134661, 55.6376758984157, 52.70756844111851, 57.61343090874808, 57.60759442193167, 56.939101287296836, 54.740250042506624, 44.73688336781093, 49.26900570733206, 56.447297368730815, 56.127648966653005, 53.308789116995676, 50.87255266734532, 53.24368102209908, 52.21039703914097, 52.679918084825786, 55.043274879455566, 54.42082745688302, 49.96657705307007, 47.058238301958355, 49.042734146118164, 50.33173615591866, 47.106569971357075, 41.74738965715681, 43.68510675430298, 39.1304930959429, 50.225150789533345, 47.00737401417324, 40.389742919376914, 42.95460442134312, 42.92581803458077, 43.60129063470023, 39.31661449159895, 39.33236953190395, 42.02516821452549, 41.811799458095, 44.20710406984602, 43.75243132455008, 41.96749816622053, 43.82325431278774, 40.35998378481184, 39.34902088982718, 41.06180395398821, 40.92956236430577, 41.484410762786865, 42.49456071853638, 40.97180046354021, 39.21326003755842, 40.736353806086946, 41.05400807516915, 41.12530354091099, 39.99984475544521, 41.75244447163173, 42.55477728162493, 41.96999256951468, 38.79876872471401, 42.28983204705374, 41.10471255438668, 40.079040322984966, 38.83506611415318, 37.67193072182791, 37.192908014569966, 38.794700554439, 44.806771823338096, 47.10541309629168, 49.76258141653878, 50.94277116230556, 52.568475927625386, 53.50493676321847, 59.688229015895296, 54.009723390851704, 56.48988287789481, 48.85237782342093, 51.11480508531843, 57.15965100697109, 56.430472305842805, 56.85657058443342, 55.16117538724627, 48.23178209577288, 45.843279770442415, 47.2287540435791, 50.13643271582467, 58.0020158631461, 56.899732794080464, 54.54880632672991, 55.93403741291591, 55.48701116016933, 56.48410545076643, 49.70057569231306, 48.31641810280936, 46.45429045813424, 49.05250678743635, 49.01514284951346, 48.84827143805367, 48.60028328214373, 52.429633549281526, 54.43435212544033, 59.97258404323033, 63.59106690543038, 63.45863424028669, 63.16618456159319, 61.86843476976667, 61.825654711042134, 68.28258786882672, 66.26408059256417, 68.74291297367641, 56.994572230747764, 65.28767108917236, 26.652926751545497, 0.27415577747992104, 0.31960920989513397, 27.612115144729614, 77.94135516030448, 55.65300709860665, 46.16338675362723, 43.49766172681536, 47.183701923915315, 55.35524899618966, 38.30344901766096, 57.652392932346885, 47.513015270233154, 51.97901160376412, 81.030850819179, 47.0791871207101, 0.1505589410662651, 0.23223585688642093, 0.21064233487205847, 0.1729849169829062, 0.24075250274368695, 0.19409138656088284], [0.2147744367165225, 0.021027549169957638, 0.12235526660723345, 0.12651206712637628, 0.03558164356010301, 0.08993494484041419, 9.50329874243055, 33.713823386601035, 26.586812904902867, 15.298392534255981, 13.731859496661595, 32.84237684522356, 38.60675873075213, 45.56187425340925, 31.2632771219526, 35.387133734566824, 40.196357182094026, 58.141427993774414, 59.149271147591726, 64.39643955230713, 25.325577633721487, 0.1515892014971801, 1.1362719195229667, 3.3478637720857347, 53.146569524492534, 59.31926577431815, 64.24626118796212, 59.42472553253174, 60.9701577595302, 55.417407580784385, 56.84579392841884, 54.300977979387554, 54.34626286370413, 50.07640722819737, 48.56738703591483, 46.54280703408377, 45.04443843024117, 44.81350810187203, 44.14996208463396, 46.46405267715454, 48.30354656491961, 49.67012868608747, 51.787206581660676, 53.305519989558626, 53.06173549379621, 53.35053389413016, 55.4296989440918, 54.624006680079866, 52.33055223737444, 55.44302558898926, 56.166638783046174, 51.85584088734218, 48.2964837210519, 44.388938426971436, 43.91741977419172, 48.974673066820415, 49.76031282969883, 56.65564605167934, 57.91334990092686, 47.187193393707275, 49.03208255767822, 50.124957765851704, 46.83707019260952, 40.69955267224993, 39.71764366967337, 36.63576671055385, 39.49684728894915, 41.05303185326712, 39.446139335632324, 36.48049879074097, 29.81160041264125, 32.581006458827424, 51.832088470458984, 39.501801354544504, 32.49206951686314, 36.54994603565761, 37.71346705300467, 39.820001057216096, 37.02921540396554, 36.90344606127058, 35.08262198311942, 36.43990741457258, 36.972427776881624, 38.56589984893799, 35.85274294444493, 38.21342815671648, 40.00571250915527, 39.40766021183559, 34.03186675480434, 40.171017101832796, 39.32964931215559, 36.84689467293875, 35.88105337960379, 37.67682920183454, 36.38361310958862, 35.2089958190918, 37.082560198647634, 37.72669294902256, 36.00021845953805, 36.355170658656526, 34.21744966506958, 36.7958254132952, 36.05111748831612, 38.69389956338065, 39.38799680982317, 33.857029233660015, 29.508718013763428, 32.87987627301897, 34.18752377373831, 39.01696647916521, 44.94898060389927, 45.450939314705984, 44.65211534500122, 45.48833451952253, 47.92939649309431, 49.508385045187815, 48.68352270126343, 48.03035381862095, 49.1953478540693, 43.45726490020752, 48.31125211715698, 52.85026706968035, 51.76822410311018, 51.706232275281636, 45.08230263846261, 41.31908532551357, 42.921312127794536, 48.53568935394287, 50.147383076804026, 51.6131819997515, 50.743159839085166, 51.646279743739534, 52.16432006018502, 50.66791084834507, 43.142799854278564, 43.2659775188991, 44.834752219063894, 42.90467814036778, 41.98716156823294, 44.03524385179792, 47.53061505726406, 50.451391083853586, 52.99821853637695, 57.33435651234218, 58.90489605494908, 57.52600867407662, 57.80892195020403, 56.85121699741909, 56.6387619291033, 57.5277943611145, 56.93510954720633, 57.80950559888567, 57.14722762789045, 61.98625537327358, 21.915304490498134, 0.17587202920445374, 0.41236399699534687, 24.29484016554696, 69.69785254342216, 39.737171581813264, 53.82733317783901, 40.10051720482962, 41.17294386454991, 28.67673029218401, 23.494013377598353, 45.76377848216465, 35.979516301836284, 50.4662880216326, 66.64755862099784, 6.1614614469664435, 0.28230677438633783, 0.03948357614821621, 0.08942428617072956, 0.0642263793519565, 0.10124546542231526, 0.05426465407279985, 0.1493204246674265, 0.06973118468054704, 0.04727121415947165, 0.09541269019246101, 0.008491138029577476, 0.014498963419880186, 14.926194906234741, 48.95643751961844, 39.902288573128835, 20.866454805646622, 16.969641004289898, 39.63975436346871, 41.435874121529714, 61.02604906899588, 35.930621828351704, 46.62567472457886, 43.94985049111502, 68.0146097455706, 64.66860743931362, 72.03754029955182, 26.671990871429443, 0.11833459378353187, 1.2433690641607558, 5.298289775848389, 61.186580249241416, 65.22258036477226, 69.6619928904942, 66.29602146148682, 66.18751839229039, 60.746828760419575, 62.1616279057094, 59.345168658665244, 59.5299004146031, 55.387429577963694, 53.242183685302734, 51.29730299540928, 49.60692439760481, 48.994173186165945, 48.028991971697124, 51.01846831185477, 51.32842397689819, 53.86104236330305, 55.16989885057722, 57.77464301245553, 55.77736248288836, 58.98454325539725, 59.21774564470564, 55.637439659663606, 54.29937294551304, 54.892547607421875, 57.38001659938267, 54.01960372924805, 50.81443446023123, 47.46103927067348, 45.71012796674456, 51.726534911564414, 52.68411479677473, 58.26188891274588, 57.65966074807303, 49.28678614752633, 51.801405225481304, 51.3767625944955, 49.52146850313459, 42.1762706892831, 41.52156278065273, 38.602899006434846, 44.188406467437744, 44.88123219353812, 46.107960973467144, 41.20935589926583, 34.227545397622244, 34.508179664611816, 52.02310487202236, 42.24466528211321, 36.442474773951936, 39.00710698536464, 40.05090011869158, 42.36551877430507, 39.93557391847883, 40.41512816292899, 36.530702999659944, 39.78326940536499, 38.837480613163535, 39.702684198107036, 38.905232497623985, 41.358912399836946, 43.16657311575753, 41.6729223387582, 36.910293510981965, 41.52249731336321, 40.09155750274658, 39.16788830075945, 38.42581026894705, 38.565201554979595, 36.923508984701975, 37.33287252698626, 38.91239261627197, 38.45585427965437, 38.501556055886404, 37.268066678728374, 37.47392095838274, 38.87119327272688, 38.10960122517177, 41.68862874167306, 41.17457321711949, 33.305328369140625, 32.95295395169939, 36.63883434023176, 39.73033455439976, 44.53457614353725, 47.327654702322825, 48.48597846712385, 47.058530126299175, 47.49326154163906, 49.71721315383911, 53.205198424203054, 52.677583490099224, 52.819048813411165, 52.21824502944946, 49.16466808319092, 50.748311928340364, 56.79694809232439, 54.49730280467442, 54.18291071483067, 47.807702268872944, 44.50355591092791, 44.40001038142613, 52.990314960479736, 52.32058504649571, 56.34421042033604, 52.92651660101754, 53.842323916299, 54.64743947982788, 55.3625202860151, 47.70293733051845, 45.83190209524972, 47.683284350803916, 47.85919884272984, 46.57222918101719, 46.178655420030864, 51.07006563459124, 54.92185163497925, 56.72053180422102, 62.0535695212228, 62.67488438742501, 61.39808341435024, 59.527649198259624, 60.85246222359793, 60.606280599321636, 63.51825673239571, 61.67581680842808, 64.40288748059953, 62.58764280591692, 68.61931146894182, 26.280225379126414, 0.15030382546995366, 0.45961497724056244, 29.46564265659877, 75.14939526149205, 47.20597784859793, 58.448086738586426, 37.629383427756174, 41.216939858027864, 38.921251569475444, 22.735292673110962, 58.8373178754534, 30.6525547845023, 57.03811659131731, 76.11607033865792, 7.8628637960978915, 0.34803515885557446, 0.03913001190604908, 0.042596681243074794, 0.020191258152148554, 0.024322471115738153, 0.03417025679456336, 0.21637598292103835, 0.10942424155239548, 0.10511989359344755, 0.21871198900043964, 0.11392307121838842, 0.1301876234688929, 11.344472357204982, 52.77007443564278, 52.45256955283028, 33.98213849748884, 42.20320885522025, 58.855570793151855, 48.91387980324881, 70.78811522892543, 47.02426508494786, 51.04069907324654, 50.812318733760286, 73.85605062757219, 67.90823977334159, 77.58022253853935, 28.474073920931133, 0.2628116219171456, 1.9582323048795973, 8.80101478099823, 66.33541079929897, 65.20459147862026, 70.89903627123151, 66.59122262682233, 65.51302201407296, 61.332471575055806, 63.44191687447684, 59.46521963391985, 61.21346977778843, 56.22783156803676, 52.96642357962472, 52.28415216718401, 50.434145654950825, 50.79865162713187, 48.97284916469029, 52.75463553837368, 53.145377908434185, 55.480153288160054, 56.58309991019112, 58.66531521933419, 57.0053071975708, 58.0675755909511, 59.60156413487026, 58.86026777539934, 52.24846969332014, 56.94848482949393, 59.792368616376606, 55.42237901687622, 52.25089461462838, 48.94165175301688, 48.29356895174299, 51.635235582079204, 53.62091261999947, 61.34242139543806, 60.26693752833775, 50.842647620609824, 55.10503394263131, 54.77123206002371, 54.80993700027466, 47.790310927799766, 46.000771113804404, 42.33950124468122, 48.7741619518825, 50.53883416312081, 48.293655804225374, 42.79523706436157, 41.29553440638951, 37.11015844345093, 55.85448748724801, 44.30324281964983, 39.7160108430045, 43.04611219678606, 43.31458364214216, 44.69635452542986, 43.65915175846645, 42.33212225777762, 39.10201937811715, 41.55585561479841, 41.9463061605181, 44.350966521671836, 42.6700895854405, 41.86233023234776, 46.74619122913906, 45.397104672023225, 39.08197382518223, 46.510911328451975, 43.146194049290244, 41.82788453783308, 40.77472523280552, 40.80306346075875, 40.85296194893973, 38.67573697226388, 40.36053269250052, 41.46464313779558, 40.98628050940377, 41.507339818137034, 40.8069475037711, 41.05551930836269, 40.24047129494803, 41.4358081136431, 42.01467990875244, 37.97466720853533, 36.60847418648856, 41.49896029063633, 42.53476994378226, 46.311466761997764, 49.39221116474697, 51.9163944380624, 49.514249324798584, 48.74392339161464, 50.77735539845058, 56.7101685660226, 53.72539963041033, 54.25638791493007, 54.95922252110073, 47.433788435799734, 50.2344057900565, 57.09539059230259, 56.9634964125497, 55.609379359654014, 48.81041765213013, 46.65964099339077, 45.79481955936977, 53.56336069107056, 52.722937856401714, 57.260858467647004, 53.04158224378313, 56.293158531188965, 56.54297753742763, 57.44423532485962, 47.916914054325645, 46.36127839769636, 49.74194874082293, 47.84855072838919, 46.7360885483878, 47.16340970993042, 52.22354997907366, 55.54939208711897, 57.08598620550973, 63.02141189575195, 63.071209635053364, 63.26028401511056, 63.08924715859549, 63.81053965432303, 64.43465464455741, 65.51522459302629, 65.03023338317871, 65.62441553388322, 63.484585762023926, 70.03164400373186, 28.17393258639744, 0.2501532525888511, 0.8167096099683216, 30.756520680018834, 83.25428131648472, 51.098327432359966, 74.73217678070068, 53.43807772227696, 54.46409388950893, 42.285725661686485, 31.841315133231028, 60.8973753792899, 48.94564001900809, 67.09837164197648, 88.64625017983573, 9.684941155569893, 0.9714951728071485, 0.2487461609499795, 0.23488200775214604, 0.1214616766997746, 0.2498320612524237, 0.0953613929450512], [0.09123614430427551, 0.07408714879836355, 0.05059382711936321, 0.08181581872382335, 0.02453290857374668, 0.07358020850058113, 0.5033598041960171, 14.873260055269514, 13.393068807465689, 9.300273248127528, 7.495584624154227, 18.724160160337174, 17.1645952974047, 44.93715129579817, 42.10796294893537, 31.30367394856044, 40.62983792168753, 54.062168393816265, 59.31936999729702, 59.82528918130057, 32.32304416384016, 0.1289176366158894, 0.7639429271221161, 3.0003061933176856, 45.491113798958914, 60.84143543243408, 67.14887114933559, 61.62861769539969, 64.38305037362235, 58.80304936000279, 59.3464332308088, 57.10205391475132, 58.015064580099924, 54.265816620418, 54.72033650534493, 48.92329461233956, 45.862112862723215, 43.7521881375994, 43.92369399751936, 42.06965405600411, 44.37328066144671, 47.128109386989046, 46.62049136843, 46.75811781202044, 49.50457395826067, 50.77365548270089, 53.677682876586914, 54.8530992099217, 52.42093093054635, 56.033313274383545, 53.99847773143223, 53.76326036453247, 46.911551407405305, 44.185123443603516, 44.09087460381644, 49.547437395368306, 52.06322724478585, 50.7086307661874, 48.1971001625061, 52.1655707359314, 48.85442059380667, 47.5160551071167, 45.71759728022984, 39.43913207735334, 35.85311467306954, 38.71032510484968, 40.51708950315203, 44.663979394095286, 42.72113452638899, 38.918406282152446, 32.751320702689036, 30.039306776864187, 44.83427626746041, 40.16559055873326, 33.14564834322248, 38.54497534888131, 36.84812102999006, 36.96896409988403, 36.313057626996724, 36.59557138170515, 37.23688663755144, 35.25622272491455, 33.42513963154384, 36.84487969534737, 36.320724964141846, 37.727088996342246, 38.94149514607021, 41.064267090388704, 36.614689350128174, 37.651079177856445, 35.62552295412336, 36.24924537113735, 33.75631856918335, 34.82350281306675, 35.467236042022705, 36.491567271096365, 35.83455603463309, 34.71389845439366, 33.060060432979036, 35.17791305269514, 36.83602769034249, 40.54910332815987, 37.56484508514404, 41.66617563792637, 40.14094877243042, 30.157832622528076, 29.566520077841624, 32.43281875337873, 35.707668031964985, 45.23173754555838, 44.630020073481965, 42.94362279347011, 44.372182846069336, 42.739918981279644, 46.36933830806187, 44.884410994393484, 50.030510902404785, 51.04881109510149, 52.42196273803711, 50.460590498788015, 49.78862673895699, 52.40518283843994, 54.03203753062657, 51.73560231072562, 48.7444931438991, 43.48729848861694, 40.24937193734305, 46.86316762651716, 52.29011024747576, 51.75881276811872, 50.426724978855674, 49.97088841029576, 52.43081474304199, 50.68378748212542, 43.696567807878765, 42.278534276144846, 41.99361297062465, 43.14433888026646, 44.34724228722708, 44.16823237282889, 49.89958599635533, 50.893438952309744, 53.76916633333479, 56.74202605656215, 58.436260904584614, 55.32599360602242, 55.58608552387783, 55.76855216707502, 55.96693365914481, 57.38681541170393, 60.41407258169991, 61.85767895834786, 60.97691140856062, 67.85994979313442, 29.836183139256068, 0.0902582396353994, 0.5411669611930847, 32.72018582480294, 64.94474274771554, 40.14843545641218, 47.10195984159197, 36.20950167519705, 41.249492168426514, 30.018302372523717, 29.429584980010986, 34.208132130759104, 44.794414452144075, 65.77104336874825, 33.70097269330706, 0.26530979786600384, 0.0550469947712762, 0.052227179652878215, 0.04906968479709966, 0.02791069321600454, 0.06301926555378096, 0.022106553860274807, 0.053654233791998455, 0.15221114669527325, 0.030693738521741967, 0.11334026392017092, 0.050123527712587795, 0.03252832418573754, 0.7525853908487729, 25.964884860174998, 24.992904833384923, 19.331955569131033, 14.770890508379255, 28.215588773999894, 20.52962350845337, 64.96243286132812, 44.93775231497628, 38.59184094837734, 47.677513871874126, 59.38087545122419, 64.75971916743687, 68.57740688323975, 35.37941081183297, 0.22287097440234252, 1.2784875397171294, 6.518897192818778, 54.36359861918858, 65.29956640516008, 72.00357055664062, 67.3213393347604, 70.20481395721436, 62.576240812029155, 63.64644404820034, 62.119167464120046, 64.08898871285575, 58.115177699497764, 59.47253608703613, 52.78908470698765, 48.868032114846365, 46.39781897408621, 46.25404684884207, 46.93789202826363, 48.81938082831246, 48.40586921146938, 50.90790510177612, 49.874277182987754, 53.47982944761004, 54.480099064963206, 57.789588587624685, 56.29882478713989, 54.63423442840576, 58.13625505992344, 55.99287475858416, 52.86801276888166, 48.73731565475464, 46.52995981488909, 47.40190315246582, 52.11612388065883, 54.771440505981445, 52.21637943812779, 49.88464042118618, 54.04568031855992, 49.01060220173427, 50.34175198418753, 47.98759460449219, 41.664900643484934, 40.07324205126081, 41.639081137520925, 45.32897411073957, 49.3173999105181, 46.22675779887608, 42.641365732465474, 38.396176201956614, 32.337086473192485, 46.50869137900216, 41.022755077907014, 35.50181027821132, 41.64373295647757, 38.97626740591866, 40.52051496505737, 38.1687581879752, 39.01039348329817, 40.60220493589129, 36.6435660634722, 38.37067978722708, 36.80510820661272, 37.45051942552839, 40.0720226424081, 40.67165218080793, 43.170978273664204, 39.36466128485543, 38.5110125541687, 38.51313870293753, 38.69112375804356, 37.59735918045044, 36.91493143354143, 37.37467288970947, 37.81635250364031, 37.188026905059814, 37.49753788539341, 35.4972140448434, 38.449427195957725, 39.58426604952131, 42.813889503479004, 38.88427325657436, 45.52636201041085, 42.650071825299946, 32.26562772478376, 34.047503675733296, 36.42624378204346, 38.22757816314697, 46.28162424904959, 46.232045378003804, 44.61459854670933, 46.841662951878135, 43.60494538715908, 47.23882893153599, 48.38387468882969, 53.82511670248849, 55.44789975030081, 54.88377203260149, 54.43812499727522, 53.95347772325788, 54.158220291137695, 55.88017497743879, 53.694865771702354, 51.30368491581508, 46.22578852517264, 41.878380571092876, 50.116863114493235, 55.467351232256206, 54.25760384968349, 53.70342247826712, 54.56772974559239, 56.939667565482004, 54.19387149810791, 47.2773288999285, 45.54726913997105, 47.108473777770996, 48.310380118233816, 46.87795339311872, 48.12230975287301, 51.841239248003276, 54.03450761522566, 56.78922516959054, 60.41412121909005, 63.11694267817906, 60.211720194135395, 59.92456504276821, 61.975951194763184, 62.36401503426688, 63.738959312438965, 64.38321713038853, 67.48922170911516, 65.31943825313023, 72.64670971461705, 34.76785469055176, 0.41264523618987625, 0.7685210300343377, 37.3783415385655, 71.08834689004081, 47.303242206573486, 55.73039266041347, 29.33575998033796, 46.53018910544259, 40.23782055718558, 30.335494586399623, 38.878992625645225, 37.877927439553396, 79.11544786180768, 35.55879592895508, 0.46075323330504553, 0.13126006163656712, 0.038032101533774815, 0.05723919213882514, 0.0028769132040906698, 0.08504738246223756, 0.044042720792016814, 0.14576975948044232, 0.21471165865659714, 0.10321200918406248, 0.23574078881314822, 0.12402010655828885, 0.17724094646317617, 0.3699159861675331, 22.54247842516218, 36.05914265768868, 24.55031153133937, 35.42129455293928, 47.635074274880544, 26.89567596571786, 63.41891138894217, 58.81978062220982, 45.841667788369314, 52.67771897997175, 67.8163151059832, 67.97443526131767, 75.25056103297642, 37.80964749200003, 0.382638300635985, 1.4268041125365665, 9.813409873417445, 58.68204648154122, 65.98332473209926, 73.87902137211391, 68.14984253474644, 70.62533978053501, 62.3002027784075, 63.31806523459298, 63.193636894226074, 63.267906188964844, 56.79249429702759, 60.2379218510219, 55.35548870904105, 48.90754304613386, 48.30529056276594, 48.715925625392366, 46.24908930914742, 48.817588193076, 49.67894942419869, 51.806022303445, 51.228345598493306, 53.801201002938406, 54.29178898675101, 57.016215869358604, 57.61849267142159, 56.50345965794155, 59.68824986049107, 56.87450735909598, 56.44870090484619, 50.28169870376587, 47.06092725481306, 50.93132400512695, 53.48207718985421, 59.04661846160889, 54.14607484000069, 52.11790261949812, 56.6820387840271, 55.480872426714214, 53.841597829546245, 52.026822158268516, 44.73303059169224, 43.77014575685774, 46.20765372685024, 49.04134450639997, 52.37716770172119, 52.33389779499599, 44.83875438145229, 41.39029393877302, 38.714994294302805, 52.21504885809762, 44.10207509994507, 38.333586829049246, 44.138139724731445, 43.18319320678711, 44.05719321114676, 40.069007124219624, 39.55442006247384, 43.458803926195415, 39.177383014133994, 41.29033715384347, 42.70132521220616, 41.66386883599417, 43.52465200424194, 44.201663630349294, 46.59990733010428, 41.065281527382986, 42.51558596747262, 41.5984445980617, 41.86044379643032, 38.61405086517334, 40.0892333303179, 40.28037132535662, 40.75727135794503, 41.595887660980225, 41.8248690196446, 36.86450835636684, 40.59285613468715, 41.288270064762656, 44.90787853513445, 43.58653613499233, 46.539447580065044, 43.744100434439524, 36.817621912275044, 37.35595096860613, 39.95850644792829, 42.9133494922093, 49.999021666390554, 50.17558928898403, 48.46391098839896, 50.108560017177034, 44.99637426648821, 50.790921756199424, 49.63585669653756, 55.58859382356916, 55.74527570179531, 55.63880845478603, 55.08941439219883, 54.443541118076865, 55.77066094534737, 58.12094817842756, 54.552061557769775, 51.855121748788015, 48.262211731501985, 43.542686053684776, 51.19071415492466, 55.554516383579795, 56.3507764680045, 53.96668972287859, 54.93532419204712, 57.71793181555611, 55.90356261389596, 48.554393904549734, 46.99077476773943, 47.239801679338726, 49.51836960656302, 48.144731589726035, 51.82371589115688, 54.79856627328055, 56.655580043792725, 58.34330790383475, 62.945718220302034, 65.9105006626674, 62.88661684308733, 61.34083720615932, 63.40008871895926, 63.955138615199495, 65.64876896994454, 64.37436512538365, 70.3315977369036, 64.43731580461774, 71.90644863673619, 33.844706603458945, 0.3640738810811724, 0.6682564073375293, 41.76200519289289, 76.48829228537423, 53.16353007725307, 60.60694762638637, 48.26532799857003, 54.51483310971941, 46.44084916796003, 37.82463475636074, 53.40282603672573, 52.96647916521345, 89.5986328125, 39.379777090890066, 0.3776427629802908, 0.2383560799062252, 0.14741850458085537, 0.16222797919596943, 0.2156387817646776, 0.1800965882305588, 0.1486038781170334], [0.0894016841692584, 0.0734184186107346, 0.031193021551838944, 0.052434292289295366, 0.07046626202229943, 0.12398611195385456, 0.19967465767902987, 1.718997142144612, 9.365831238882881, 3.7142203535352434, 1.8934928987707411, 27.089025224958146, 21.588158982140676, 27.24975095476423, 44.97379262106759, 35.10018702915737, 33.02366924285889, 44.53908552442278, 61.091987473624094, 60.132851191929404, 28.160519089017594, 0.5484222918748856, 0.6699156697307314, 5.343474345547812, 34.073090417044504, 56.91477216993059, 67.914381980896, 61.0323371887207, 62.940951756068635, 61.38886315482003, 63.613829204014365, 59.98700155530657, 61.176213536943706, 58.01390423093523, 58.929478781563894, 54.10837738854544, 51.80874252319336, 45.16861316135952, 45.72816549028669, 42.894745690482004, 42.99691200256348, 42.77135610580444, 44.68115881511143, 45.24169084003994, 43.1525342805045, 49.80912045070103, 55.80435276031494, 53.807801791599815, 51.785163811274934, 55.09104027066912, 52.89582988194057, 49.75981950759888, 45.68305778503418, 43.72016041619437, 44.090263162340435, 48.35578659602574, 48.70697634560721, 51.80737025397164, 53.182654993874685, 52.087997572762625, 50.44887236186436, 48.332134928022114, 43.86157710211617, 38.173795631953645, 37.42209781919207, 38.82673869814192, 42.19320344924927, 42.79589366912842, 46.6529255594526, 36.76192167827061, 32.84138672692435, 26.369587898254395, 36.941807065691265, 37.58065223693848, 31.87543773651123, 37.62681259427752, 39.076078278677805, 40.76130131312779, 38.982548577444895, 39.59865229470389, 35.97531264168875, 36.59327500207083, 34.99985156740461, 37.04997662135533, 36.50645726067679, 37.41448606763567, 37.79497289657593, 40.513604981558665, 38.61538144520351, 39.493689332689556, 34.82990557806832, 35.277209758758545, 38.46832282202584, 37.736013957432334, 35.043673855917795, 35.81492389951433, 37.02107211521694, 37.377778734479634, 37.86764757973807, 39.43076992034912, 38.98112072263445, 38.958031858716694, 33.28944478716169, 41.210415499550955, 37.23525381088257, 29.189990247998917, 33.64548090526036, 34.77067913327898, 35.703801359449116, 43.50204256602696, 42.68829386574881, 42.177371978759766, 40.79428441183907, 42.95584120069231, 45.47547687802996, 43.64638444355556, 50.970994744982036, 49.40345682416643, 51.078031744275776, 51.58882508959089, 54.593299116407124, 49.96771655763899, 49.41354560852051, 50.51780891418457, 49.231878008161274, 41.79149334771292, 41.20304693494524, 46.532374313899446, 50.61834239959717, 51.14010695048741, 50.691607679639546, 51.60888453892299, 52.39744601930891, 50.4009610584804, 42.08890751429966, 40.717350482940674, 44.81989002227783, 41.67188010896955, 43.99970729010445, 43.877776827131, 49.1114935193743, 51.316591194697786, 52.445301737104145, 53.77980749947684, 55.640277998788015, 57.98840781620571, 57.58555473600115, 57.294157709394185, 60.33624580928257, 60.051508631025044, 59.48099204472133, 58.296518734523225, 61.61525630950928, 61.812064034598215, 37.287903785705566, 2.5929335270609175, 1.4438642199550356, 38.971650327954976, 61.371916498456685, 40.98671129771641, 46.1961544581822, 29.32280853816441, 42.351625851222444, 27.846463986805507, 37.42744793210711, 44.9046893119812, 57.3700007711138, 61.97004522596087, 2.261144667863846, 0.13942648842930794, 0.16202363158975328, 0.04145185695961118, 0.07644929204668317, 0.06855089337165866, 0.07349870287414108, 0.15438389724918775, 0.02152926814077156, 0.05642256845853158, 0.03738903693322625, 0.014660581979634506, 0.002667686082921656, 0.1739068425127438, 0.20342850339199814, 4.011960216930934, 15.40698766708374, 11.924776349748884, 16.102344274520874, 29.642609800611222, 16.664047070911952, 38.90282842091152, 57.82147734505789, 38.3653678894043, 42.80934190750122, 48.95367213657924, 69.28068270002092, 65.50694234030587, 32.670370715005056, 0.797563197357314, 1.0953531094959803, 6.474738350936344, 45.91074330466134, 60.71133736201695, 72.93100915636334, 65.716062273298, 68.22671045575822, 64.86172567095075, 68.75318241119385, 63.20818642207554, 64.96942274911063, 62.30149514334542, 63.087253025599885, 59.35764067513602, 56.92825862339565, 48.8565536907741, 49.621241160801475, 45.52527461733137, 46.77971281324114, 46.49745961597988, 47.48960331508091, 48.48768424987793, 48.91786806924002, 53.11042499542236, 58.03688192367554, 56.02170978273664, 53.845155307224815, 54.47498171670096, 55.61650473730904, 51.956815583365305, 50.09744637353079, 45.35023212432861, 47.02247244971139, 49.71679973602295, 50.95005634852818, 53.004187038966585, 56.15253741400582, 53.55043009349278, 52.75732796532767, 49.752037525177, 48.54459694453648, 40.25266885757446, 41.079831055232454, 42.01286990301949, 44.562660762241904, 46.90182392937796, 50.72647026606968, 42.483238628932405, 36.47771603720528, 30.543006011417933, 39.81709671020508, 40.19006906236921, 34.07218367712838, 39.19441304888044, 43.16396059308733, 44.142291273389546, 42.41755730765206, 41.60984659194946, 38.08431325639997, 38.47057056427002, 37.56915644236973, 38.39854553767613, 38.69025175912039, 39.1036765234811, 41.31963423320225, 44.25166981560843, 40.33699219567435, 39.860116481781006, 38.31014360700335, 36.74413081577846, 40.54927703312465, 40.06895848682949, 38.35207945959908, 36.68458127975464, 38.243246350969585, 39.32247877120972, 39.39895759310041, 41.61539820262364, 39.9276807648795, 40.812655448913574, 35.70736231122698, 44.31622552871704, 41.13241502216884, 31.739162717546733, 38.24088396344866, 37.47516468593052, 40.50048678261893, 46.33830417905535, 46.559694630759104, 44.02012457166399, 42.2868651662554, 43.93748269762312, 48.3607371875218, 46.60700144086565, 51.80919763020107, 52.69530487060547, 54.149361337934224, 54.01492064339774, 55.86588600703648, 51.8227014541626, 53.401280062539236, 53.22785997390747, 52.086573192051475, 46.59928894042969, 43.57515498570034, 49.46064397266933, 52.94981043679373, 54.08938101359776, 53.69957317624773, 54.21417760848999, 55.810967445373535, 52.05254091535296, 44.7302200453622, 43.862737451280864, 47.25719649451119, 45.084084851401194, 46.71969427381243, 47.40935162135533, 51.423360688345774, 54.894236019679475, 55.916475840977256, 58.59087221963065, 61.64614800044468, 61.45762947627476, 61.69404888153076, 60.35140677860805, 64.9621479851859, 63.93685095650809, 63.72424302782331, 61.87942681993757, 67.90749631609235, 66.91193062918526, 43.25586788994925, 4.393815406731196, 1.9218643477984836, 44.54190649305071, 67.97192001342773, 49.12508766991751, 49.102829115731375, 31.31602089745658, 53.22153016499111, 36.96447556359427, 38.4408392224993, 45.01252882821219, 60.344729559762136, 71.03695106506348, 1.6068309609379088, 0.17748487980238029, 0.126633402758411, 0.06184503356260913, 0.05008824049894299, 0.04907105204516223, 0.04854411532038024, 0.10793208197823592, 0.13627803165997776, 0.13096975721418858, 0.08039149229547807, 0.20729081971304758, 0.10716811940073967, 0.21058427941586289, 0.2774580174258777, 2.1559854192393164, 20.633148193359375, 11.219676630837576, 42.5922280720302, 47.6567040170942, 35.37719781058175, 38.45027140208653, 64.73587989807129, 49.42898450578962, 47.903219154902864, 59.221858978271484, 71.25056648254395, 71.22205107552665, 35.00457286834717, 0.877419495156833, 1.5241644425051553, 8.035489184515816, 53.461906569344656, 64.96640028272355, 72.7020104272025, 66.67546953473772, 67.15135860443115, 63.88337762015206, 66.06036635807583, 65.5739438193185, 63.45509760720389, 64.59565830230713, 63.65492779867989, 61.060859543936594, 57.74789244788033, 50.19101776395525, 50.319580282483784, 48.146534647260395, 47.31293841770717, 47.46490594318935, 48.983660561697825, 50.033898149217876, 47.930952889578684, 55.336005960192, 59.58351271493094, 57.46621595110212, 55.39952291761126, 56.73421628134591, 56.98401096888951, 52.17209162030901, 50.99237782614571, 47.139615603855674, 50.32499640328543, 53.30232381820679, 53.45383276258196, 55.25872114726475, 60.03958552224295, 55.431950160435264, 55.56418480191912, 52.95473670959473, 50.04335464750017, 43.28691244125366, 44.57612637111119, 45.02545942578997, 50.49609579358782, 48.668729986463276, 52.95545584814889, 46.88108703068325, 41.454481397356304, 35.797553403036936, 48.35125289644514, 42.77732808249337, 37.394207750047954, 43.87343767711094, 47.73323842457363, 46.141979353768484, 45.04244777134487, 44.23473705564226, 40.37916428702218, 41.05284425190517, 39.45399080004011, 40.81341280255999, 43.173191274915425, 41.74824775968279, 43.12838234220232, 46.8127931867327, 43.36969675336565, 43.731572832380024, 39.568507535117014, 38.87848193304879, 44.23621007374355, 41.652039527893066, 41.36080578395298, 40.25251252310616, 43.12760066986084, 41.915091378348215, 42.10501691273281, 43.562582220349995, 42.98237637111119, 44.099969795772004, 37.6780868257795, 46.7966525214059, 43.091150420052664, 37.15757295063564, 42.52580329350063, 41.49281113488333, 44.50104413713728, 51.01808268683297, 49.07584926060268, 47.46812643323626, 45.82641649246216, 46.855983189174104, 49.38516569137573, 48.03948375156948, 54.27125358581543, 52.95345824105399, 53.419244629996165, 54.30972228731428, 56.14682946886335, 52.339011669158936, 51.62364946092878, 54.36490488052368, 53.09367636271885, 46.84881264822823, 46.06145320619856, 51.23942102704729, 54.89919703347342, 56.00704213551113, 53.36408635548183, 55.93111916950771, 59.05995205470494, 53.20574038369315, 45.87953894478934, 46.34521763665335, 50.47737387248448, 47.34431300844465, 49.52796506881714, 49.5795658656529, 52.79937151500157, 56.028459957667756, 55.94484186172485, 60.34723091125488, 62.25305230276925, 65.25283976963588, 62.17364134107317, 62.16852051871163, 66.52128900800432, 68.10436657496861, 66.06236049107143, 64.76057379586356, 67.90857328687395, 66.9303503036499, 41.24476739338466, 3.826129342828478, 1.7961926055806023, 47.451600142887656, 71.58886732373918, 56.26742240360805, 56.203179359436035, 39.99469266619001, 54.46991647992815, 41.98611239024571, 46.268342767442974, 66.25150435311454, 67.82940551212856, 82.55443096160889, 3.145611047744751, 0.182760353865368, 0.1936933443482433, 0.12426433845290116, 0.11508852296641894, 0.1601810697466135, 0.21579745039343834, 0.28095282561012674], [0.07391642260232142, 0.13304079536880764, 0.050121505678232224, 0.09354555181094579, 0.10689124318638019, 0.026315554078402262, 0.08031367789953947, 0.1010707358696631, 3.013611776488168, 2.651209588561739, 4.839834604944501, 31.332227570669993, 31.305244241441997, 28.339961528778076, 29.199526650565012, 40.82158735820225, 27.060627937316895, 37.534860134124756, 60.474966594151084, 65.13611698150635, 25.62644158090864, 1.9892777247088296, 0.9086355801139558, 8.00364819594792, 14.085057275635855, 54.208848340170725, 60.65869780949184, 61.401467187064036, 60.430498123168945, 64.43655150277274, 61.33598041534424, 60.4119325365339, 60.14378070831299, 59.15976987566267, 57.454685415540425, 56.922363076891216, 55.42070797511509, 45.90802308491298, 43.425258023398264, 45.54056412833077, 42.64453411102295, 44.107380049569265, 42.6499467577253, 46.69169650759016, 43.73460919516427, 51.56085511616298, 54.51146323340279, 53.25272757666451, 51.06195361273629, 55.29213503428868, 52.87091016769409, 49.14144025530134, 47.18161746433803, 43.77739272798811, 45.97352375302996, 49.33865097590855, 50.93493706839425, 50.091728006090435, 51.471511704581125, 50.19945635114397, 51.94126898901803, 47.24921996252877, 42.49318844931466, 37.830043928963796, 39.15643766948155, 39.36256292888096, 39.5375463621957, 41.0589656148638, 44.70328187942505, 42.86570569447109, 31.251736164093018, 25.901459966387065, 31.362827437264578, 41.105146816798616, 33.602012974875315, 37.505729811532156, 38.19462980542864, 38.954762731279644, 37.51023571831839, 38.128879002162385, 35.16796670641218, 35.82760436194283, 34.81403241838728, 33.73012038639614, 35.83515010561262, 37.43763746534075, 37.447948592049734, 38.65037604740688, 41.7314088003976, 38.523845876966206, 37.022878646850586, 37.46432202202933, 37.61051212038313, 36.14380645751953, 33.63264410836356, 37.05583395276751, 36.06445802961077, 35.78768348693848, 36.532384463718955, 39.639056069510325, 37.68643856048584, 37.60234451293945, 34.24489504950387, 44.016817229134695, 32.25546251024519, 26.148817573274883, 35.727824756077354, 35.44328907557896, 40.71866021837507, 42.25463594709124, 40.47182893753052, 39.14162758418492, 38.79707683835711, 38.0583130972726, 41.454773221697124, 44.716518197740825, 45.76229156766619, 47.4225149835859, 50.294584138052805, 50.24008594240461, 51.59150014604841, 49.5316024507795, 50.075701986040386, 50.95379100527082, 51.36712544304984, 44.29041991915022, 40.78538376944405, 46.86081566129412, 52.6067396572658, 52.377848625183105, 51.18993943078177, 50.567523275102886, 51.917839663369314, 47.686338084084646, 40.820631980895996, 38.632672037397114, 40.742218085697715, 41.66903134754726, 41.69404138837542, 43.76405218669346, 47.23249217442104, 49.915646757398335, 54.129089968545095, 55.39166797910418, 59.77121829986572, 57.53966188430786, 58.80498790740967, 58.962948254176546, 57.80704593658447, 56.42843300955636, 58.217601094927105, 60.4705753326416, 61.72464874812535, 53.76281220572335, 42.34327759061541, 8.797533733504158, 2.656476757356099, 40.10379328046526, 55.44781984601702, 32.26988697052002, 41.858863081250874, 28.584505115236553, 33.22105714253017, 29.534322125571116, 44.04265757969448, 52.775650365012034, 62.737584931509836, 20.318332263401576, 0.4539959744683334, 0.3164535335132054, 0.07283183865781341, 0.11144137688513313, 0.040548553823360374, 0.2163655606231519, 0.0533949112785714, 0.1461121482508523, 0.041456813657922406, 0.15961012324052198, 0.02815964092899646, 0.07915217522531748, 0.03965714879866157, 0.006683226425333747, 0.0497066900799317, 0.20806092981781277, 4.932662972382136, 4.651544937065669, 15.523125069481985, 43.087009293692454, 26.980515207563126, 30.73046840940203, 43.70134816850935, 39.401007311684744, 39.01959637233189, 41.82968412126814, 65.06732286725725, 69.22488171713692, 30.965251513889857, 1.717059571828161, 0.9221592715808323, 9.57375260761806, 20.352496555873326, 64.13212312970842, 63.40821116311209, 65.44952242715019, 63.495244298662456, 66.80427524021694, 62.74518626076834, 63.09247807094029, 62.95282622746059, 63.29496247427804, 60.26674992697579, 64.28200966971261, 60.97579274858747, 51.376276220594136, 46.5088129724775, 48.839204038892476, 45.489630358559744, 47.26567677089146, 45.18680354527065, 48.80981663295201, 46.687044688633506, 53.93517269407, 58.44348703111921, 55.60471364430019, 51.851484366825645, 54.84960774012974, 54.3924058505467, 50.95468732288906, 48.51081132888794, 46.47436032976423, 47.02418518066406, 51.51969051361084, 53.653794969831196, 51.87699120385306, 52.575420652117046, 51.88739960534232, 53.84783731188093, 50.97573341642107, 45.35954965863909, 41.247376441955566, 41.80209282466343, 42.04613787787301, 43.23762886864798, 45.23547567640032, 48.29203339985439, 48.36099427086966, 36.653957094464985, 28.891311509268625, 32.82139328547886, 41.1584256035941, 36.86959096363613, 40.49480315617153, 40.56469161169869, 40.952800614493235, 40.74982636315482, 41.67157091413225, 38.81101492473057, 37.575163160051616, 36.76946742194039, 35.22646706444876, 37.18574094772339, 38.35458428519112, 37.6697906766619, 42.57747704642159, 43.28871202468872, 40.14086191994803, 40.41484676088606, 39.21290915352957, 38.34186213357108, 38.87423658370972, 34.42142098290579, 38.236454486846924, 37.388864585331504, 37.00133923121861, 39.163920879364014, 40.35066277640206, 40.189926624298096, 41.50357389450073, 37.42735413142613, 48.84857021059309, 35.031556197575156, 30.324874264853342, 38.934362820216585, 38.92047337123326, 46.86825718198504, 44.78674364089966, 44.17973511559622, 40.96679776055472, 40.63074466160366, 41.030398096357075, 42.66511467524937, 47.58678082057408, 46.99601718357631, 49.13269247327532, 53.45521198000227, 53.309146949223106, 52.04914672034127, 53.23102140426636, 53.01551955086844, 54.06471838269915, 53.8081248828343, 47.684288365500315, 42.622998169490266, 49.288721220833914, 55.68829352515084, 54.93367746898106, 56.70045498439244, 54.33967249734061, 55.639326095581055, 49.5692651612418, 45.52561160496303, 42.4511205809457, 43.72576413835798, 43.95396382468087, 44.91740798950195, 46.36381796428135, 51.28049530301775, 53.97058418818882, 58.7837472643171, 59.42651816776821, 62.64748069218227, 59.777548108782085, 62.949227060590474, 62.75460106985909, 61.40251636505127, 61.315302576337544, 61.973491532461985, 63.56001540592739, 68.6402255467006, 58.73470687866211, 49.49398142950875, 11.758011766842433, 3.3408534739698683, 42.779325689588276, 61.2744471686227, 37.393908977508545, 46.03394876207624, 32.72784273965018, 46.854517119271414, 34.10054274967739, 40.440732274736675, 54.54295594351632, 68.232574735369, 18.170767409460886, 0.4268956115203244, 0.45878645884139196, 0.03389453748241067, 0.12111343895750386, 0.0562639676832727, 0.11109652503260545, 0.1389053463935852, 0.09626208711415529, 0.1487607689840453, 0.28426928765007425, 0.18546207674912044, 0.3269867854458945, 0.15996055943625315, 0.1630429404654673, 0.16417023140404904, 0.3814527913928032, 5.2055582489286145, 2.642405786684581, 51.11587510790144, 53.16465221132551, 54.098236492701936, 39.601025104522705, 44.169927733285085, 55.85853828702654, 40.059873717171804, 54.04990134920393, 69.1992359161377, 76.60671043395996, 34.98182446616036, 2.099438807794026, 1.9276105080332075, 8.57564127445221, 29.012899773461477, 67.36042990003313, 65.43894726889474, 67.66708169664655, 63.85033893585205, 67.87859180995396, 63.38451085771833, 64.78426020486015, 63.80306339263916, 63.55506828853062, 59.51553153991699, 64.36493641989571, 60.7773174558367, 51.13182817186628, 48.00091082709176, 49.60750804628645, 46.623270647866384, 49.215112004961284, 46.44287804194859, 50.614805766514365, 47.91099418912615, 56.030912671770366, 59.851365770612446, 57.37193584442139, 54.14775282996041, 55.81901345934187, 56.66648524148123, 54.2438394682748, 51.715449060712544, 47.0346109526498, 48.47361762183053, 53.075541564396445, 56.76786988122122, 54.03751271111624, 56.07782343455723, 55.68204014641898, 56.65861988067627, 54.61284787314278, 48.47666788101196, 43.157978194100515, 45.04647772652762, 45.16077559334891, 47.0200058392116, 47.364692074911936, 50.40942743846348, 48.31044265202114, 40.15952130726406, 35.99313824517386, 40.097904682159424, 43.766834940229145, 40.81776237487793, 43.597868646894185, 43.48703793116978, 44.59565428325108, 43.493652616228374, 45.84309564317976, 41.744881357465474, 40.63842936924526, 39.443971497671946, 38.67306538990566, 40.5364020211356, 41.41136087690081, 41.790364265441895, 45.57805660792759, 46.69941595622471, 43.22211354119437, 42.16413218634469, 42.856030327933176, 43.045823846544536, 41.84887851987566, 38.09537826265608, 41.3153715133667, 41.02285582678658, 40.077873025621685, 41.054484026772634, 45.76901742390224, 42.652719088963096, 43.98873608452933, 39.87366546903338, 51.47189038140433, 38.21459892817906, 35.06982340131487, 44.26177249635969, 43.05804572786604, 49.694638456617085, 47.450682980673655, 45.493979930877686, 44.6891770362854, 43.1997264453343, 42.60431793757847, 43.002251693180625, 49.867676394326345, 48.84174707957676, 49.874860831669395, 54.02928951808384, 52.86770009994507, 54.90139961242676, 53.140816416059224, 53.84940413066319, 56.17224597930908, 55.93433965955462, 50.06038120814732, 45.67671060562134, 51.15601485116141, 58.10568993432181, 56.76956524167742, 55.61355870110648, 55.72258288519723, 55.8597993850708, 51.7465318271092, 47.4469552721296, 42.52102640696934, 44.90541887283325, 45.87006855010986, 46.08728313446045, 47.38681861332485, 51.74866839817592, 54.286657742091585, 61.94670622689383, 61.04095295497349, 65.75027520315987, 61.60038716452462, 65.15804549625942, 64.68789563860211, 64.3036116191319, 63.89689186641148, 64.78292615073067, 65.71856362479073, 68.86974539075578, 61.748710359845845, 54.86819417136056, 11.154234153883797, 3.993038100855691, 47.37080301557268, 69.5841452734811, 42.67299740655081, 57.763209751674104, 37.59225920268467, 47.711719853537424, 42.25726236615862, 58.37574209485735, 68.58968435014997, 79.43491908482143, 29.387499741145543, 0.6189308198434966, 0.5562470491443361, 0.21903137543371745, 0.2802467963525227, 0.15340041502245835, 0.2547138492975916, 0.2958068528345653, 0.2377596204834325], [0.1001555278365101, 0.11411236891789095, 0.035888531378337314, 0.08551649443273034, 0.041469234241438765, 0.03929295191275222, 0.0983941052109003, 0.049844765170876465, 0.17251461079078062, 1.7573644433702742, 8.843860847609383, 46.4563228062221, 30.354053224836075, 29.117213078907557, 28.809631960732595, 37.52043914794922, 29.75888442993164, 33.964066232953755, 56.06033481870379, 64.25771876743862, 31.740055561065674, 2.2766658578600203, 1.2703440338373184, 7.546713812010629, 7.768790398325239, 49.53916209084647, 55.819103785923545, 53.24177721568516, 54.46728311266218, 52.48719937460763, 53.50916474206107, 56.70416532244001, 57.96674680709839, 60.35862595694405, 59.93780830928257, 57.40801089150565, 54.494565214429585, 50.4229416847229, 44.70204857417515, 44.11366816929409, 43.41621494293213, 41.36476625714983, 41.685925892421174, 45.24028035572597, 42.173734596797395, 48.33871487208775, 52.47736072540283, 52.20838206154959, 48.2299234526498, 52.28667088917324, 50.76331308909825, 47.61164494923183, 44.63081564222063, 44.55028602055141, 47.093361445835654, 49.201684611184255, 50.597928592136924, 52.99939625603812, 51.74194254193987, 50.86204351697649, 50.895353181021555, 47.05857181549072, 42.08875117983137, 39.554017066955566, 39.25089495522635, 38.12324748720442, 38.727633067539756, 41.90976905822754, 44.86689805984497, 48.2031694139753, 39.43955244336809, 23.964378629411968, 25.591212477002824, 38.290177958352224, 34.525612694876536, 35.851155281066895, 36.58356836863926, 37.61354153496878, 36.39664445604597, 34.42201157978603, 33.421092305864605, 33.75354971204485, 33.63372107914516, 33.84610666547503, 35.676109313964844, 37.414927278246196, 39.12629290989467, 39.0225111416408, 40.26299735477993, 38.97379037312099, 35.99525049754551, 36.59733622414725, 36.68919140951974, 39.40197311128889, 35.61241170338222, 35.00300257546561, 36.41086394446236, 37.93914106913975, 38.801183223724365, 40.303599153246196, 35.57781662259783, 36.33118895121983, 35.363614082336426, 41.69294009889875, 28.96812210764204, 28.28075245448521, 34.19278703417097, 40.269615513937815, 42.682304518563406, 41.98853383745466, 38.91579723358154, 37.33442197527204, 38.67515332358224, 39.97686011450631, 41.839859758104595, 41.63813965661185, 44.615724154881065, 46.37437227794102, 48.26670026779175, 50.07203681128365, 50.638766629355295, 50.784560680389404, 50.272492340632844, 49.377578258514404, 51.2129796573094, 43.96582439967564, 41.27535683768136, 49.02838264192854, 52.68597343989781, 50.02544566563198, 51.68766668864659, 51.10255888530186, 50.38370173318045, 46.766580717904226, 40.75956078938076, 40.61997495378767, 41.986015115465435, 41.56011833463396, 41.39726645605904, 44.9543411391122, 48.72240482057844, 52.77458381652832, 55.58749253409249, 58.151735646384104, 56.98603984287807, 57.35744885035923, 57.15292515073504, 57.673883710588726, 57.99435200010027, 56.16498163768223, 55.45762028012957, 55.83522360665457, 55.90469169616699, 49.711908204214915, 44.140377044677734, 16.47319916316441, 3.26156519140516, 37.34639719554356, 50.958731174468994, 30.79716416767665, 35.48336281095232, 27.005221264702932, 32.90641144343785, 40.04210022517613, 46.680777413504465, 52.678615297589985, 39.307686056409565, 0.15665297263434955, 0.06932362262159586, 0.009023843150186752, 0.05205428214477641, 0.049214528274855444, 0.023390559246763587, 0.059261402913502285, 0.0307351902260312, 0.02497752712640379, 0.0465538364036807, 0.09642883709498815, 0.028674034933958734, 0.050223950895347765, 0.06081910218511309, 0.027463743895558373, 0.05731239249663694, 0.07144802755543164, 0.12112297915986606, 2.297506328139986, 12.97028134550367, 58.91005856650216, 30.841688224247523, 29.455196040017263, 41.35610185350691, 36.45648234231131, 35.51077692849295, 44.30821772984096, 61.004898752485005, 71.01124273027692, 35.79050098146711, 2.8428589275905063, 1.910707060779844, 8.871201140539986, 11.52047370161329, 59.12809998648507, 61.928960527692524, 59.44682080405099, 58.248277391706196, 57.71861273901803, 56.40525381905692, 59.93958009992327, 59.56623254503523, 63.65724849700928, 62.46804346357073, 61.49769278935024, 56.84500183377947, 56.3334824017116, 48.60752330507551, 47.78972380501883, 44.57686982836042, 44.873210498264854, 44.054309708731516, 47.5444906098502, 45.02429212842669, 52.904337951115195, 56.1459505217416, 54.315214838300435, 50.416514601026265, 53.645088876996724, 51.80828046798706, 50.020227568490164, 46.035887309483115, 44.814651080540244, 49.92034373964582, 51.164647987910676, 51.800574915749685, 54.86489030293056, 54.62020254135132, 54.2562871660505, 53.96625198636736, 50.654716219220845, 45.145190783909385, 40.912695612226216, 41.28639752524239, 42.67130552019392, 42.33931016921997, 43.317262172698975, 48.194459847041536, 49.97914981842041, 44.415657724652974, 28.513994795935496, 27.969334193638392, 40.74174908229283, 38.51820741380964, 38.6934757232666, 40.249601227896555, 41.31699391773769, 41.30248260498047, 38.85407638549805, 35.72711256572178, 36.61121872493199, 35.64128146852766, 37.06881666183472, 38.89113460268293, 38.789093358176096, 40.49519225529262, 40.689620222364155, 40.80917092732021, 39.64800187519619, 37.57743869509016, 37.38472693307059, 38.44682509558541, 39.61829137802124, 37.74870484215872, 37.23249537604195, 38.13534082685198, 39.82540328162057, 39.18705143247332, 44.06732368469238, 38.292939867292134, 37.328668866838726, 37.80669798169817, 45.11273922239031, 31.51011882509504, 31.785753863198416, 37.61057812826974, 43.828215326581685, 46.75342082977295, 43.09801524026053, 39.96219246728079, 39.95065498352051, 41.722921575818745, 42.5072238104684, 43.94530636923653, 44.860960824149, 46.22926262446812, 46.97896977833339, 50.4047269821167, 51.82927097593035, 54.50828790664673, 52.41279458999634, 51.30825335638863, 53.28730876105172, 54.49487788336617, 45.16412115097046, 45.0066819190979, 52.95589011056082, 54.986720017024446, 52.57188401903425, 54.15043830871582, 56.29829324994768, 55.57424579347883, 49.73414938790457, 43.082301889147075, 44.008131980895996, 45.3901321547372, 44.45903532845633, 45.03129243850708, 49.40139320918492, 53.66534634998867, 56.659585680280415, 59.548841203962056, 61.01899664742606, 61.19021415710449, 62.17202935900007, 61.5717327935355, 61.18543379647391, 61.582009179251536, 61.87368065970284, 61.15430586678641, 60.46249457768032, 59.49110862186977, 56.780460017068044, 52.65139920370919, 19.906858205795288, 3.379382972206388, 38.399108341761995, 57.77636269160679, 37.52090120315552, 40.651203632354736, 33.36903987612043, 39.90445293698992, 40.57865054266793, 45.65161371231079, 60.13066945757185, 37.95491347994123, 0.13411623266126427, 0.03326976279328976, 0.03426995055217828, 0.08715255092829466, 0.05785116287214415, 0.037587067378418784, 0.033756448820765526, 0.005314552591049245, 0.1304914578795433, 0.14674402720161847, 0.1553212119532483, 0.05670939538893955, 0.2775020950606891, 0.14685955457389355, 0.09811467091952052, 0.16074379240827902, 0.20782615670136043, 0.20721170252987317, 1.89757496544293, 44.21199212755476, 68.69866684504917, 45.214419160570415, 38.08899286815098, 43.215842791966026, 53.74553550992693, 38.034887245723176, 49.45499161311558, 66.4188517161778, 75.16612652369908, 39.402553285871235, 3.519413492509297, 2.447752437421254, 8.393239770616804, 16.378639391490392, 62.64133848462786, 59.86242035457066, 61.03959110804966, 57.910094669886995, 59.35723073141915, 56.65554877689907, 59.960612297058105, 61.664268902369905, 64.12065860203334, 65.12160914284843, 63.086884771074565, 57.478000095912385, 56.80315283366612, 49.21100909369332, 47.684038230351035, 46.52494321550642, 44.95121444974627, 44.798968996320454, 49.27307735170637, 45.891079902648926, 53.60169390269688, 56.66147559029715, 54.382848603384836, 53.19344554628645, 53.834625312260215, 53.82744434901646, 51.543095520564485, 47.81637709481375, 47.41521937506539, 51.05788196836199, 52.74978569575718, 54.64467409678868, 57.079743249075754, 57.049264975956504, 55.04827758244106, 55.684364318847656, 53.83749491827828, 47.00030074800764, 44.10176937920706, 43.18785892214094, 43.71994502203805, 45.67628329140799, 46.50659997122628, 50.648129326956614, 53.23794181006295, 47.094014576503206, 33.998442445482524, 35.45853689738682, 42.83744042260306, 40.33544274738857, 43.27290487289429, 41.21630409785679, 43.31750883374895, 43.78762395041329, 40.37500579016549, 39.232815742492676, 38.9484919820513, 38.879576274326865, 40.64631904874529, 40.80457121985299, 42.90254156930106, 44.904050077710835, 45.024108001164024, 45.5715982573373, 44.45971972601754, 40.22442443030221, 40.281191212790354, 41.39485195704869, 45.15151364462716, 40.50544432231358, 39.44402360916138, 41.814537048339844, 41.71057115282331, 43.029763085501536, 45.36862053189959, 41.17261035101754, 40.18539639881679, 39.009893212999614, 47.37851899010794, 37.108039242880686, 37.817818573543, 42.66545513698033, 47.338028362819124, 50.06099959782192, 49.678911209106445, 44.08477061135428, 42.6428804397583, 43.396909373147146, 44.32080439158848, 44.77000890459333, 46.40995052882603, 48.268489428928916, 48.62599509102957, 50.99839844022478, 53.45190116337368, 55.91661133084978, 55.240228516714915, 55.21052496773856, 53.44976806640625, 57.58085775375366, 48.69486216136387, 47.63024180276053, 52.684986795697895, 59.47228595188686, 54.16013451984951, 55.93720579147339, 56.781627314431326, 59.011835779462544, 52.61820765904018, 46.099643979753765, 45.652020181928364, 47.1306072643825, 47.04203510284424, 46.21425104141235, 51.6374694279262, 55.417779309409006, 58.80277838025774, 62.7355352129255, 63.98393195016043, 62.24711159297398, 63.06386538914272, 62.12977736336844, 62.82580620901925, 64.70875413077218, 63.63606343950544, 63.17156941550118, 65.11268765585763, 64.32729802812848, 63.001011984688894, 56.55257299968174, 21.125798055103846, 4.1725704329354425, 43.865266595567974, 64.92398153032575, 44.52399403708321, 46.30362571988787, 36.67864751815796, 47.17877565111433, 55.910500390189036, 63.345107623508994, 67.89304406302315, 57.298288413456504, 0.3045079516513007, 0.11736103173877512, 0.1315328734261649, 0.14891289653522627, 0.09416194659258638, 0.10971719904669694, 0.13603496684559754, 0.14167440709258827, 0.26039622724056244], [0.12192455971879618, 0.05894070690763848, 0.021385462821594307, 0.03514292995844569, 0.09438231441059283, 0.07875658930944544, 0.11908073803143841, 0.06679563184401818, 0.10147943108209542, 0.12741122102098806, 5.867829271725245, 45.19378648485456, 50.056306089673726, 27.03620501926967, 34.83203867503575, 29.682009560721262, 36.946834087371826, 31.03737381526402, 47.745644433157786, 61.95502322060721, 33.84325442995344, 2.98161358492715, 1.8184033909014292, 6.790151391710554, 9.007087060383387, 50.81570250647408, 60.35391507829939, 57.84447588239397, 57.720155239105225, 59.35459736415318, 60.287816865103586, 62.38641602652413, 59.29065309252058, 58.91126755305699, 57.379721300942556, 57.36437620435442, 55.871833665030344, 51.238840852464946, 44.61599513462612, 43.85074833461216, 41.85856083461216, 42.296405042920796, 42.74061727523804, 42.83924348013741, 42.040982314518516, 45.57730967657906, 54.8189731325422, 51.64203439440046, 47.65808323451451, 50.34572287968227, 49.214118412562776, 46.37651579720633, 43.57570389338902, 45.35617978232247, 46.832258565085276, 52.14295434951782, 52.56563064030239, 49.85646200180054, 51.008011272975374, 52.90245498929705, 54.25039856774466, 47.9258702823094, 41.902115617479595, 42.487008026668, 38.13719946997506, 39.43964971814837, 38.93480750492641, 40.59960978371756, 43.433317933763774, 44.84339925221035, 44.38898359026228, 28.150557109287806, 21.221506016595022, 35.2952299118042, 36.07493938718523, 34.48962797437395, 37.578522614070344, 41.557102816445486, 40.38583108357021, 35.708831855228965, 32.93779993057251, 33.118689332689556, 32.96589149747576, 32.61318356650216, 37.921239035470144, 33.48626293454851, 36.69451372964041, 38.09857790810721, 37.40705149514334, 36.63843829291207, 34.86024488721575, 35.48254292351859, 36.94688272476196, 36.905801500592915, 37.50232172012329, 37.34373256138393, 36.61792721067156, 38.566747529166086, 37.9152045249939, 37.904827390398296, 36.72425201960972, 36.359089442661826, 39.66043567657471, 37.63404219491141, 26.467559235436575, 25.418520212173462, 35.31604324068342, 46.151790210178916, 42.490357058388845, 39.87639263698033, 37.60599231719971, 35.78256961277553, 37.42885146822248, 39.01280798230852, 41.21203095572335, 42.18701260430472, 43.36162642070225, 45.94409465789795, 45.463595458439414, 46.50143051147461, 48.49680723462786, 48.60676942552839, 48.486694131578716, 50.95823090417044, 47.17513826915196, 40.24069711140224, 41.06874173028128, 48.03678090231759, 52.89456530979702, 50.72336094720023, 50.23939459664481, 53.22050183159964, 49.52740226473127, 44.55348219190325, 39.631628445216585, 40.44735043389456, 41.27611071722848, 41.07830245154244, 42.57188374655587, 48.028606346675325, 54.57574796676636, 55.45251335416521, 55.56798546654837, 57.08888013022286, 56.193900040217805, 59.52209758758545, 56.60399661745344, 57.07112748282296, 57.33859143938337, 56.16275821413313, 54.671487195151194, 51.79114621026175, 52.98806027003697, 51.4155022757394, 51.31233194896153, 21.947193247931345, 2.7501215381281714, 42.19912678854806, 47.50251306806292, 27.890623262950353, 37.996307373046875, 24.10612882886614, 38.54756007875715, 38.59365095411028, 42.89563853400094, 53.99601459503174, 5.690613729613168, 0.37802694950784954, 0.16420437528618745, 0.06458781460033995, 0.08846284276140587, 0.03831598701487694, 0.09165049171341316, 0.049472951729382784, 0.08246284936155591, 0.002171667230348768, 0.08371911623648234, 0.05362612208617585, 0.007574451638252607, 0.044072057253548076, 0.05571399808728269, 0.048928675042199235, 0.12432236676769597, 0.05868804082274437, 0.22299887825335774, 0.51898136309215, 8.260012405259268, 62.168763705662315, 53.21195207323347, 23.88133897100176, 45.82373448780605, 32.10218524932861, 39.30471222741263, 43.546264375959126, 49.41475806917463, 69.55212797437395, 38.07120200565883, 3.9682534422193254, 2.1165945615087236, 8.588665672710963, 12.168627721922737, 58.42536612919399, 60.34255477360317, 61.19667598179409, 61.604834011622835, 63.7556071962629, 63.85885047912598, 64.74054908752441, 63.11356585366385, 62.98426682608468, 59.286025592258994, 62.17649705069405, 58.51007856641497, 54.23614433833531, 46.055609771183555, 47.0708840233939, 44.20758696964809, 45.86964818409511, 46.12554686410086, 45.67715181623186, 44.26580939974104, 48.90242222377232, 56.619769028254915, 54.93781859534127, 50.372018337249756, 53.39347723552159, 49.07476534162249, 48.44941009793963, 45.352118560246055, 47.18231575829642, 50.462810448237825, 52.8663660458156, 54.55344772338867, 52.85816717147827, 54.213340350559776, 54.60419736589704, 54.52651650565011, 49.31690658841814, 43.627870968409944, 45.004781586783274, 42.736354555402485, 42.095786230904714, 42.199366501399446, 41.853794370378765, 45.596726417541504, 48.08788142885481, 46.397290910993306, 31.533971990857804, 23.308916841234478, 36.119241101401194, 39.095439434051514, 38.375157901218955, 40.61659118107387, 43.04314184188843, 43.325401987348286, 37.90880175999233, 35.88509028298514, 35.518062114715576, 36.07818419592721, 35.159444740840364, 39.90172924314226, 37.34126247678484, 38.45201192583357, 40.91917480741228, 40.93860197067261, 40.14771979195731, 37.91341188975743, 38.19154480525425, 38.48563425881522, 37.729114396231516, 38.119488511766704, 38.50691311700003, 39.189396449497764, 40.19783020019531, 39.54395954949515, 37.4707213129316, 39.511139733450754, 37.86034154891968, 44.328464780535015, 40.730298451014924, 28.070802211761475, 29.560878140585764, 39.77550131934029, 50.39482927322388, 45.496953759874614, 41.19444159099034, 39.648814814431326, 39.30162722723824, 38.08785683768136, 43.67497975485665, 42.96258442742484, 45.485395431518555, 46.70237936292376, 47.32203360966274, 47.05293682643345, 49.13730607713972, 50.571792943137034, 52.161735330309185, 49.98446866444179, 55.164983000074116, 51.061658314296174, 41.911408833095, 42.91197027478899, 50.73223727090018, 55.491162708827424, 54.00911889757429, 52.75702919278826, 55.78945582253592, 53.27216516222273, 47.069206033434185, 42.33672891344343, 44.16337210791451, 44.942647320883616, 46.01978485924857, 46.353631905147004, 51.27659388950893, 58.44832297733852, 58.969250270298545, 59.08758504050118, 61.53217669895717, 61.716894558497835, 63.112370763506206, 59.74530846732003, 60.42416831425258, 60.68414906093052, 59.00680528368269, 57.7558377129691, 56.972355365753174, 58.92439270019531, 59.677855355399, 57.92086437770298, 24.61553774561201, 3.3434620882783617, 46.16578388214111, 52.302978311266216, 36.83979361397879, 41.91814858572823, 29.46866512298584, 48.82205588476998, 36.87687267575945, 45.426457336970735, 60.75607681274414, 2.7491216489246915, 0.21900024424706185, 0.15410079886870726, 0.0571341888446893, 0.06645850172000271, 0.06424606365284749, 0.11464949723865304, 0.03941817555044379, 0.0889255018638713, 0.012514204385557344, 0.12610376546425478, 0.09141409689826624, 0.19993137461798532, 0.16348286185945782, 0.16121245654565947, 0.13853877463511058, 0.2100730575621128, 0.14116199101720536, 0.3384183363190719, 0.9933050253561565, 25.088060413088115, 79.2185035433088, 63.06966713496617, 42.45153052466256, 44.51921715055193, 41.81704534803118, 47.690771034785676, 42.814011096954346, 55.799381324223106, 72.87829317365373, 41.96948535101754, 4.800755764756884, 2.9019023307732175, 9.646947537149702, 16.656218188149587, 60.54862444741385, 59.91494178771973, 61.44162777491978, 59.086911065237864, 62.135280336652485, 63.43157795497349, 65.78027057647705, 64.05380998338971, 64.29858807155064, 60.50438526698521, 61.932948793683735, 60.301553453717915, 56.825282846178325, 47.98054565702166, 48.0554507119315, 45.32489551816668, 47.37005608422415, 48.03842762538365, 45.899619238717214, 47.440806116376606, 48.552455357142854, 58.95124748774937, 56.72810186658587, 50.89323050635201, 54.39458063670567, 49.90118408203125, 50.80326523099627, 47.35035794121878, 48.80544969013759, 50.90757506234305, 56.33781460353306, 57.78743117196219, 55.0524708202907, 57.5380915914263, 54.1050248827253, 57.6908894266401, 51.48379611968994, 46.903123242514475, 47.16116196768624, 43.260109765189036, 44.823374543871196, 44.170570441654746, 45.193762166159495, 47.54004028865269, 51.76245709827968, 51.48311867032732, 36.27880995614188, 28.651133128574916, 40.815459047045024, 41.87222794124058, 42.755819933755056, 43.70740352358137, 44.941615513392854, 46.71707132884434, 41.40114007677351, 36.59630789075579, 37.2499075617109, 37.29432392120361, 37.99485867364066, 42.92796502794538, 39.24934550694057, 40.08006170817784, 44.216240950993125, 45.128230231148855, 40.99798822402954, 40.66024671282087, 40.920317786080496, 41.92350912094116, 39.68216964176723, 42.673188482012065, 41.695257323128835, 42.23639692578997, 45.24793379647391, 42.97576863425118, 43.87372602735247, 42.633330140795024, 41.133238383701865, 44.85994291305542, 42.56017255783081, 34.28524671282087, 33.454905714307515, 42.44071217945644, 53.287527629307334, 47.8661470413208, 45.73818131855556, 43.13788400377546, 41.124483653477256, 42.01108421598162, 44.78016717093331, 44.63491160529, 48.075624806540354, 47.93403441565377, 50.11761351994106, 50.5671272277832, 49.2774338722229, 51.96360049928938, 52.97680071422032, 51.19087743759155, 55.238206590924946, 55.1359395299639, 44.59350381578718, 44.34215273175921, 52.20680134637015, 59.41761057717459, 55.06277847290039, 55.15002005440848, 58.85691179547991, 54.83131660733904, 50.7998606136867, 44.50130122048514, 46.16229588644845, 47.03792176927839, 48.2251569884164, 47.7078149659293, 54.218280519757954, 60.08376216888428, 60.97941970825195, 60.3727377482823, 63.626891817365376, 62.88536616734096, 65.34024115971157, 61.46088818141392, 63.181442805698936, 63.201474462236675, 63.524913106645855, 61.63249479021345, 60.35506847926548, 63.80351502554757, 65.38877432686942, 60.39190782819475, 28.271537406103953, 3.7615718926702226, 52.537653718675884, 58.74458026885986, 44.00304937362671, 45.91782004492623, 35.93019798823765, 60.85737460000174, 55.907557828085764, 57.26553807939802, 75.87893526894706, 10.438582726887294, 0.8224374226161412, 0.3320660543228899, 0.15969799352543695, 0.18388632844601357, 0.24347068688699178, 0.4721473019037928, 0.1642727716160672, 0.12011848948895931, 0.1056460907150592], [0.10726994036563806, 0.1011105455192072, 0.06155568587460688, 0.04250249040446111, 0.029795616000358547, 0.09450968221894332, 0.06939912321312086, 0.06337035314313003, 0.25832007293190273, 0.029465155875576392, 1.9053354518754142, 41.73540054048811, 44.93742227554321, 37.72591127668108, 33.98410136359078, 29.163309165409633, 34.48271451677595, 27.604513815471105, 44.984878471919465, 58.97824818747384, 42.40171888896397, 3.657325029373169, 1.0557337211711066, 7.446169904300144, 14.379910162517003, 61.08450426374163, 57.26001426151821, 65.15757301875523, 62.22292491367885, 63.86612524305071, 59.62982940673828, 58.123411314828054, 57.81320204053606, 58.79501724243164, 57.62246356691633, 55.83464343207223, 51.420265265873496, 47.294786248888286, 42.64616346359253, 41.587046078273225, 42.01304360798427, 42.90845101220267, 42.595907143184114, 41.61414057867867, 41.94083445412772, 43.72864416667393, 48.51093987056187, 50.09612621579851, 48.06145395551409, 49.51415205001831, 47.76770148958479, 44.14223221370152, 43.399139744894846, 45.927669116428916, 49.988276277269634, 51.26719297681536, 51.251239912850515, 52.00471646445138, 52.13327203478132, 53.028429303850444, 50.12601389203753, 43.46479327338082, 42.857246262686594, 43.66884796960013, 42.102046557835166, 40.38894387653896, 40.940332072121755, 40.78029073987688, 43.18973840985979, 45.43750844682966, 45.87894139971052, 33.31051867348807, 20.665891579219274, 29.630596365247452, 37.35885878971645, 34.604676246643066, 37.7009950365339, 37.57276603153774, 37.20281614576067, 35.223753792899, 33.73018292018345, 33.80303130831037, 35.41041019984654, 35.19436291285923, 35.65559128352574, 39.03743239811489, 41.43459217888968, 38.06608465739659, 37.71842459269932, 37.690343448093955, 37.360637528555735, 37.17453350339617, 38.51819699151175, 36.32503284726824, 38.13830075945173, 35.257570675441194, 35.867601667131694, 36.66134997776577, 35.3146779196603, 36.160204206194194, 37.882600103105815, 33.132418973105295, 41.39169747488839, 33.79368598120553, 18.761996575764247, 24.93646114213126, 45.60563053403582, 46.70935188020979, 40.26179184232439, 39.02707263401577, 38.27361692701067, 35.93499571936471, 39.02575247628348, 39.389122417994905, 39.356907095227925, 40.781527519226074, 43.639286858694895, 45.82769843510219, 45.41490943091256, 45.54597677503313, 49.1186432157244, 47.74450840268816, 49.40020159312657, 46.28283323560442, 41.838206086839946, 41.40118524006435, 44.803461006709504, 48.54876586369106, 50.897941384996685, 51.90742083958217, 50.00707115445818, 52.469318185533794, 47.467653955732075, 43.13148818697248, 40.03040293284825, 41.334843839917866, 41.27531862258911, 42.02125290461949, 41.393257345472065, 50.81251328332083, 55.24628039768764, 52.77744994844709, 56.90215424128941, 54.45876462118966, 55.665479115077424, 56.728185244968955, 56.29461417879377, 56.52132000241961, 54.092035225459504, 53.55726017270769, 51.03127384185791, 52.40237576620919, 53.72836651120867, 55.75748021262032, 55.98137548991612, 22.220993961606705, 3.0408493663583482, 46.084510803222656, 40.24253838402884, 34.00516135351998, 42.38665172031948, 28.92374917439052, 45.310616970062256, 34.32910026822771, 47.74093702861241, 36.538481507982524, 0.06005326006561518, 0.05923797988465854, 0.08272359679852213, 0.022786500231762017, 0.005789779858397586, 0.0761370641578521, 0.0910372453342591, 0.039757446452443085, 0.02082522359809705, 0.028851997705974748, 0.0985508942976594, 0.05117413401603699, 0.08389900944062642, 0.05380236477191959, 0.07775107505066053, 0.052320698741823435, 0.07784018705465964, 0.03476732350619776, 0.2061116886990411, 0.13436088524758816, 2.304942637681961, 46.2068373135158, 54.824743611471995, 24.304067373275757, 35.244469846997944, 37.956261430467876, 32.764636925288606, 40.19681576320103, 50.729635170527864, 66.42105429513114, 47.9976486478533, 4.396866968699864, 1.3687969680343355, 7.087488259587969, 19.00164863041469, 66.58391312190464, 58.92220401763916, 66.9851576941354, 66.58337116241455, 69.35658482142857, 61.651234081813264, 62.55025454929897, 59.88754504067557, 62.51788289206368, 60.519303049360005, 59.561188152858186, 52.608032022203716, 50.46575648444039, 45.12402657100132, 44.8197614806039, 45.95587532860892, 44.59257275717599, 44.83056592941284, 44.86430638177054, 43.87892327989851, 45.49770416532244, 51.916408334459575, 52.41863802501133, 51.36498539788382, 51.533663340977256, 50.66080978938511, 46.38664627075195, 45.05051810400826, 48.585573945726665, 53.197267055511475, 53.975611209869385, 53.02955491202218, 53.34315838132586, 55.38882963997977, 53.75291102273123, 51.749939918518066, 46.37863499777657, 45.85141611099243, 46.16416842596871, 44.50126300539289, 42.95874902180263, 41.84201717376709, 43.19210079738072, 44.61683586665562, 48.69262484141758, 50.21510716847011, 38.165419578552246, 23.241178853171213, 34.10443721498762, 40.34514938082014, 35.682994978768484, 39.65142386300223, 41.007267543247764, 39.64440270832607, 36.92184141704014, 37.35442583901541, 35.827503613063264, 35.01012795312064, 36.599632603781565, 37.94092328207833, 39.459618840898784, 43.512690680367605, 39.4315550667899, 40.73013516834804, 39.88631119046892, 38.222287109919954, 37.78443595341274, 39.622352600097656, 39.10980830873762, 39.61216654096331, 38.08203077316284, 37.95156792231968, 37.75292934690203, 37.772985322134836, 38.535619599478586, 38.91149977275303, 34.211588859558105, 45.7632851600647, 33.65263754980904, 20.44351969446455, 30.789469037737163, 49.841297558375764, 48.78913531984602, 42.88712351662772, 40.87140246800014, 38.953032629830496, 38.48392152786255, 41.66878121239798, 43.255065373011995, 42.09981966018677, 45.17456429345267, 46.094686440059114, 46.86362273352486, 47.06709378106253, 48.73813901628767, 50.09559120450701, 51.07725702013288, 50.4514536176409, 48.43861607142857, 43.83904409408569, 43.07555866241455, 46.41308764048985, 53.03898361751011, 55.27632788249424, 56.23504727227347, 53.226317473820274, 55.359226839882986, 52.601747376578196, 45.44724287305559, 42.22929586683001, 44.090256214141846, 43.83397190911429, 45.70188045501709, 46.236599922180176, 54.931460993630544, 59.573681013924734, 59.356362206595286, 59.72985567365374, 57.28602136884417, 59.2669597353254, 59.208379473005024, 59.77064854758126, 60.15703787122454, 56.87496594020298, 56.673888547079905, 55.74839196886335, 56.29188353674752, 60.22856262751988, 61.1566196169172, 61.5751165662493, 24.739450182233536, 4.38715295280729, 49.598562240600586, 46.73472670146397, 37.64636482511248, 47.31647505078997, 35.37038162776402, 49.56794500350952, 37.75764717374529, 55.3458446093968, 37.37387384687151, 0.08893868579928364, 0.03983171550290925, 0.035741944065583606, 0.06829536386898585, 0.05900182255676814, 0.025299013625564318, 0.08901061051126037, 0.059052190211202414, 0.033093021384307315, 0.05785884388855525, 0.17712030293686049, 0.13839922712317534, 0.17052678817084857, 0.09237456321716309, 0.13292278455836432, 0.12878593296876975, 0.16677343100309372, 0.11665369969393526, 0.5217323069061551, 0.24354141737733567, 5.624837304864611, 70.78036103929792, 57.10137299128941, 50.61235305241176, 42.82359266281128, 43.515751361846924, 46.62567819867815, 38.39100326810564, 57.09050253459385, 68.95995385306222, 53.562248979296, 5.368805740560804, 1.8739573870386397, 9.787161316190447, 23.780126299176896, 66.73935127258301, 58.7299473626273, 68.12198025839669, 67.86491080692836, 70.3500452041626, 64.74828938075474, 63.651620456150596, 62.828300612313406, 64.69369738442558, 63.11866583142962, 60.460604667663574, 54.606486797332764, 51.356713567461284, 47.58039542606899, 45.62422043936593, 47.38758291516985, 46.727246965680806, 46.344887597220286, 45.09279441833496, 47.226912770952495, 47.72228806359427, 53.781700883592876, 53.486815861293245, 52.680536474500386, 53.42509501320975, 52.73421130861555, 48.96249287469046, 47.60771574292864, 50.811213970184326, 54.797895772116526, 55.84879343850272, 54.729251044137136, 54.714527811322895, 55.4506825038365, 56.04905094419207, 53.93503720419747, 46.44846091951643, 47.031904629298616, 49.64063010896955, 48.23246649333409, 45.24638087408883, 43.52302265167236, 46.82697793415615, 48.215898513793945, 51.69963148662022, 54.18086794444493, 42.49934802736555, 31.794098649706157, 36.156705788203645, 40.7134872845241, 39.603981563023154, 42.604981490543906, 43.64771154948643, 42.68552500861031, 38.122080189841135, 39.15242508479527, 39.01498624256679, 39.69958530153547, 39.13170208249773, 40.9234687941415, 44.32909706660679, 46.33914491108486, 43.474017007010325, 42.569163526807515, 43.09874480111258, 41.75481033325195, 41.51158169337681, 45.19653102329799, 41.371217659541536, 42.44326564243862, 40.11236388342721, 41.21183293206351, 40.97619867324829, 39.52649525233677, 39.37412125723702, 42.10981464385986, 39.15297746658325, 44.819111824035645, 38.01008217675345, 27.804769584110804, 34.235400336129324, 52.716111251286094, 51.42950636999947, 42.72092955453055, 43.18489898954119, 43.515733991350444, 42.01009062358311, 43.551124640873496, 44.756272315979004, 43.96925680977957, 47.75277328491211, 47.56802068437849, 49.555900301252095, 51.371610505240305, 51.12521001270839, 53.07381493704659, 51.4883645602635, 53.02350997924805, 50.996428625924246, 45.98985549381801, 46.61780588967459, 48.90913765771048, 53.13031421388899, 56.753337723868235, 58.360852105276926, 54.08957208905901, 58.61910969870431, 55.101010935647146, 49.08752918243408, 43.67697041375296, 48.014046396527974, 45.974301951272146, 47.2344411441258, 47.40132992608206, 57.605582918439595, 60.164597511291504, 60.99093287331717, 62.41153376443045, 58.99463898794991, 61.42590400150844, 62.235181535993306, 63.10410935538155, 61.90708065032959, 59.563355990818565, 61.97640282767159, 58.64770153590611, 60.798252378191265, 64.73398998805455, 68.83843680790493, 65.52634865897042, 28.929365055901663, 4.234359894480024, 55.639437266758506, 51.20199108123779, 49.51887335096087, 51.91682522637503, 47.3601826940264, 58.77223409925188, 53.83092539651053, 64.02365480150495, 49.76965468270438, 0.25367080526692526, 0.15949094534984656, 0.17760783034775937, 0.16232682817748614, 0.101251314394176, 0.1596762804048402, 0.2076058770929064, 0.11660122179559299, 0.07305663730949163, 0.08471865938710314], [0.04208070285884397, 0.06351566820272378, 0.049533341346042495, 0.11893280382667269, 0.04619758516283972, 0.05487236021352666, 0.046901354898831675, 0.0783518228147711, 0.061411144344934394, 0.20971473678946495, 0.2632649375924042, 9.851764798164368, 50.84573262078421, 50.32069199425833, 38.566264629364014, 36.01784603936331, 38.11352000917707, 26.970178025109426, 43.233859470912385, 57.24620124271938, 46.361726556505474, 3.8566866517066956, 0.926536636693137, 5.119134383542197, 29.833622728075298, 64.8714462007795, 64.40526376451764, 65.78660038539341, 63.61092485700335, 62.585544449942454, 59.64706093924386, 58.58020673479353, 57.349868365696494, 55.143697193690706, 53.03379678726196, 51.65471485682896, 47.78464467184884, 44.60198061806815, 43.71387229646955, 44.23680761882237, 42.584161213466096, 42.01501342228481, 43.891919885362896, 41.77768380301339, 43.21402931213379, 39.52663769040789, 44.68188142776489, 47.34481675284249, 47.78030899592808, 46.12565108707973, 45.246585845947266, 42.24174009050642, 41.98638684409005, 47.76641954694475, 52.34650182723999, 51.14583226612636, 53.6486359323774, 49.41693980353219, 52.78745188031878, 52.279938084738596, 49.291656834738596, 44.50373656409127, 42.937782832554404, 44.69470085416521, 43.92313814163208, 41.780150413513184, 41.004859992435996, 39.72265679495675, 42.93591376713344, 45.56256559916905, 47.171354975019185, 36.05426849637713, 15.971619129180908, 27.618024587631226, 40.757354736328125, 34.094949449811665, 32.28303296225411, 36.01730407987322, 38.58955846514021, 36.29588862827846, 34.37747015271868, 34.16421256746565, 34.232999733516145, 31.920437744685582, 34.97053016935076, 34.73645230701992, 33.43665279660906, 36.33407940183367, 35.241339683532715, 37.83781548908779, 37.831072262355256, 37.47939613887242, 36.4202162197658, 38.56348187582833, 37.683457783290315, 38.61134801592146, 32.380092348371235, 35.17129141943795, 42.72171122687203, 38.287391730717246, 33.01834692273821, 40.653517382485525, 36.17283603123256, 22.00888282912118, 10.919131432260786, 38.48720455169678, 48.732476234436035, 44.86084965297154, 41.66765560422625, 38.34611095700945, 37.60737500871931, 37.04252120426723, 39.37815816061837, 41.08596978868757, 42.14703266961234, 40.61682741982596, 42.64348145893642, 42.33263989857265, 45.39265782492501, 42.51149000440325, 45.98428651264736, 44.5764286177499, 44.615887437547954, 42.41069943564278, 40.75175796236311, 39.71942588261196, 45.99656745365688, 48.94090829576765, 51.8886468069894, 49.81666619437081, 47.6723096711295, 51.10895470210484, 44.80873121534075, 38.471887247903005, 39.67272356578282, 40.50992243630545, 42.54960087367466, 42.083463600703645, 43.59777137211391, 53.11080367224557, 56.24790491376604, 55.74185718808855, 53.07351963860648, 55.172167437417166, 56.649507318224224, 54.415842124394004, 54.76588889530727, 53.606053897312705, 50.708884375435964, 50.11465358734131, 51.63133069447109, 52.685379368918284, 56.152721541268484, 55.72487926483154, 60.74571704864502, 22.664799724306377, 3.878153545515878, 54.00603042330061, 34.11331353868757, 36.05369526999337, 36.428790296827046, 34.49298742839268, 50.43179368972778, 23.16566583088466, 49.39952066966465, 21.764229808534893, 0.15439513378909656, 0.11451844498515129, 0.048084458735372336, 0.07438029628247023, 0.054758597032300065, 0.0369224728617285, 0.012678183399007788, 0.07118866432990346, 0.07497826205300433, 0.07778373294110809, 0.035100474022328854, 0.07589216051357132, 0.12152672106666224, 0.11600886072431292, 0.041091093460896184, 0.05711461989475148, 0.06626243224101407, 0.06989342918885605, 0.07421554797994238, 0.11543267592787743, 0.259823027998209, 8.017230187143598, 64.65491253989083, 45.81118951525007, 29.699970654078893, 41.14220155988421, 35.367206301007954, 35.63779347283499, 49.94952269962856, 58.79198087964739, 52.46050092152187, 4.598567528384073, 0.8294371355857167, 4.979931133134024, 39.129287583487375, 66.30380344390869, 64.93623120444161, 70.6056763785226, 66.61072622026715, 64.88657937731061, 62.14836379459926, 61.49765804835728, 61.22282900129046, 58.24252775737217, 56.5021881375994, 55.743521281651084, 50.55894224984305, 47.185633523123606, 46.34605142048427, 47.68603236334664, 46.32511649812971, 45.11232580457415, 47.85482495171683, 45.7869541985648, 46.31201219558716, 43.25363057000296, 47.50620256151472, 50.36030714852469, 48.71946920667376, 49.54127434321812, 46.339877946036204, 44.949025767190115, 44.23276376724243, 51.3819911139352, 51.31985337393624, 54.43116985048567, 57.02245535169329, 52.01451342446463, 54.47645820890154, 53.6471802847726, 52.722183976854595, 47.45927790233067, 46.72497490474156, 48.05298062733242, 47.47165264402117, 44.35415921892439, 43.758886201041086, 42.46108429772513, 44.53048365456717, 48.61078201021467, 50.4792811529977, 41.75911126817976, 19.38996955326625, 30.462327003479004, 42.598266056605745, 36.766625608716694, 36.72838619777134, 39.33497858047485, 41.1658810206822, 38.88058376312256, 37.14179706573486, 35.913299969264436, 37.52170372009277, 34.73029967716762, 38.836108343941824, 37.22177083151681, 35.23116404669625, 38.39814601625715, 37.61093596049717, 40.55010386875698, 39.54344885689871, 39.03337812423706, 40.71872622626168, 38.95920957837786, 38.005131585257395, 38.003717626844136, 33.94683122634888, 39.47073595864432, 43.654114314488, 40.03783055714199, 35.77789000102452, 44.128287179129465, 39.744435923440115, 22.452500990458898, 15.99512141091483, 45.05650397709438, 51.39626618794033, 47.587611130305696, 44.61192349025181, 41.20376259940011, 38.529015336717876, 41.72442238671439, 42.39686557224819, 43.71149948665074, 44.55699450629098, 42.91951949255807, 44.79759325299944, 44.711769104003906, 47.118847438267295, 45.93441581726074, 45.407096181597026, 46.318303789411274, 45.47074862888881, 45.7054830959865, 44.12206506729126, 41.9722820009504, 49.82988166809082, 51.66825342178345, 56.86186511175973, 52.90915652683803, 53.3367451940264, 54.107533182416645, 48.719441413879395, 42.581732818058555, 42.212185927799766, 43.59942504337856, 44.71230411529541, 45.196058545793804, 48.03207697187151, 55.80959517615182, 59.428692953927175, 58.89571748461042, 55.15806259427752, 57.52337530681065, 59.56314754486084, 57.1745479447501, 58.371809414454866, 60.03976617540632, 56.43604128701346, 51.79177502223423, 55.2495391028268, 57.66666453225272, 62.25945159367153, 61.2960421698434, 66.32680892944336, 23.50238769395011, 4.868408637387412, 60.37168857029506, 37.89442593710763, 40.6128009387425, 42.605085713522776, 43.815764154706685, 48.113683564322336, 26.0489650113242, 59.8852938243321, 22.528245040348597, 0.10289681609719992, 0.08625812642276287, 0.03242523096767919, 0.037222982450787506, 0.01661070858660553, 0.05758711775498731, 0.046968102388616116, 0.051353423324014456, 0.0959022735644664, 0.016914366578151072, 0.1351555718907288, 0.19002145209482738, 0.2688066687967096, 0.31522324095879284, 0.11524329680417265, 0.16075981940541947, 0.12411929480731487, 0.2753717393747398, 0.194385897900377, 0.37631682412964956, 0.4958884822470801, 19.65810748508998, 76.40873541150773, 66.63970715659005, 51.57565130506243, 47.321436064583914, 56.45235913140433, 34.02617270605904, 56.41184765951974, 64.07314682006836, 57.084989139011924, 5.064303977148874, 1.6599057529653822, 6.899781806128366, 40.99342325755528, 66.14479391915458, 67.15372099195207, 70.48422881535122, 68.28988347734723, 67.11333806174142, 64.18564510345459, 63.1700963973999, 62.420156478881836, 59.866756030491416, 57.7063422203064, 57.66066476276943, 51.31246396473476, 49.34138856615339, 48.62808649880545, 49.14035286222185, 47.488456862313406, 46.70200068610055, 49.27744776862008, 46.7275561605181, 48.31587961741856, 44.26740748541695, 48.958372592926025, 52.67919199807303, 51.87985038757324, 49.19846759523664, 50.146952288491384, 45.20291294370379, 45.24293109348842, 53.29338843481881, 55.81197493416922, 56.31283582959856, 60.09842981610979, 54.06965160369873, 56.21588066646031, 57.25793327604021, 54.4745682988848, 49.62035526548113, 48.5523441859654, 49.40191084997994, 48.85927043642317, 47.63000556400844, 45.40893398012434, 45.23845992769514, 46.57358060564314, 50.7167705808367, 53.522772789001465, 42.60001352855137, 26.128778968538555, 34.39003944396973, 40.59242534637451, 39.82473625455584, 39.61281967163086, 42.95435776029314, 44.22340106964111, 43.25331442696707, 39.04644421168736, 40.51327494212559, 40.217323371342246, 37.540707043239046, 42.71776812417166, 40.235058648245676, 38.046918051583425, 42.323767048971995, 40.81130402428763, 42.47284759793963, 43.37147201810564, 42.5652551651001, 41.8098053250994, 42.6367312840053, 42.44887631280081, 42.101195403507774, 35.64203534807478, 42.06680876868111, 47.88791227340698, 45.376541478293284, 39.46849863869803, 43.0178781918117, 39.33994306836809, 29.86398983001709, 21.270916393824987, 44.80674055644444, 54.71247809273856, 48.83219678061349, 47.06918518883841, 43.87959378106253, 42.356677191598074, 43.992866788591655, 43.483244214739116, 47.235667501177105, 46.20493003300258, 44.88289976119995, 46.79400873184204, 47.88131495884487, 51.21920871734619, 47.56664146695818, 50.54098115648542, 48.31651190349034, 48.51298264094761, 48.9653833253043, 48.64622824532645, 44.068456241062705, 52.24205650602068, 53.29541730880737, 58.54042829786028, 52.91137300218855, 54.5248315674918, 54.8985265323094, 51.12437622887747, 43.15216255187988, 46.94603531701224, 45.24551929746355, 48.582263129098074, 46.17736305509295, 51.04771327972412, 60.21452726636614, 62.945336069379536, 61.3558383669172, 59.22637530735561, 59.30325712476458, 63.08719049181257, 59.14987564086914, 61.11698014395577, 62.6638298034668, 60.27301025390625, 55.30275535583496, 59.85871696472168, 61.11180373600551, 65.37869249071393, 65.73875508989606, 73.08108329772949, 28.495186022349767, 5.761673825127738, 64.47433580671037, 46.2984527860369, 50.5499894959586, 46.5165775844029, 58.01829201834542, 59.39922564370291, 34.27551576069423, 69.01742935180664, 32.329248905181885, 0.3063959889113903, 0.19080484791525773, 0.15358345662908895, 0.17850982051874908, 0.10327013249375991, 0.10552143704678331, 0.1661521236279181, 0.23889763227530889, 0.1441056387765067, 0.2607480340770313], [0.04804408250908766, 0.1051516897444214, 0.06031665378915412, 0.07479684893041849, 0.0803350992500782, 0.0472563271011625, 0.030839209644390003, 0.03318742596145187, 0.06370912532189063, 0.03445463082087891, 0.02938309045774596, 0.5103001317807606, 36.05261482511248, 47.005980900355745, 50.553383690970286, 51.225694860730854, 52.47426530293056, 23.42375145639692, 37.61525426592146, 56.2725328036717, 47.8223421233041, 5.6938572355679105, 0.8829218170472554, 3.4745018567357744, 54.603495597839355, 64.69515650612968, 63.974030767168315, 63.56703308650425, 60.95466327667236, 62.30673408508301, 56.761724199567524, 55.608128683907644, 53.9504656791687, 51.041800362723215, 49.90026344571795, 48.70103563581194, 44.810853890010286, 43.16737215859549, 44.40536396844046, 40.70069217681885, 45.10133375440325, 41.394747734069824, 42.083265577043804, 40.4782212802342, 40.475865840911865, 41.7397084236145, 42.41421869822911, 43.64933047975813, 46.56318262645176, 42.749962602342876, 44.030828271593364, 40.28757313319615, 44.40744842801775, 50.493458952222554, 50.453687463487896, 52.08315467834473, 47.29338618687221, 49.14040844781058, 52.49854578290667, 50.67513697487967, 48.66468266078404, 43.98849984577724, 43.35806894302368, 44.088036264692036, 43.62307671138218, 42.85843093054635, 41.27777133669172, 42.77839115687779, 41.60284628186907, 46.29670878819057, 46.778069564274375, 42.8225017956325, 17.42784169742039, 18.55874787058149, 43.76186350413731, 34.1735474722726, 35.767127241407124, 31.220219135284424, 36.227278641292024, 33.94414922169277, 37.69756262642996, 33.5173978124346, 34.99472032274519, 32.1198718888419, 30.639982019151958, 30.17949710573469, 31.742813995906285, 30.996789387294225, 33.836122104099815, 35.605741432734895, 36.00723614011492, 33.742602825164795, 37.54387194769723, 34.21246085848127, 48.12835815974644, 39.09328201838902, 39.44008050646101, 42.11581093924386, 35.50240434919085, 36.61096511568342, 44.20361954825265, 37.177198137555806, 31.18260853631156, 11.355106575148445, 20.525161027908325, 54.196911334991455, 42.691847869328086, 47.33196605954851, 37.65735687528338, 38.88763271059309, 36.42841509410313, 38.47111252376011, 41.02281413759504, 44.36660344260079, 41.32322645187378, 43.7184476852417, 42.78989737374442, 42.79093960353306, 39.15609720775059, 41.87501416887556, 41.45604821613857, 41.42536844526018, 39.5547570501055, 39.60221324648176, 40.819985798427034, 42.03086921146938, 47.20129476274763, 48.55320923668997, 52.21013995579311, 47.546116488320486, 50.05205726623535, 50.0357255254473, 44.07336514336722, 40.474681173052105, 38.428565229688374, 41.68589809962681, 41.31619834899902, 42.072075503213064, 42.85886866705758, 48.76784256526402, 55.50809894289289, 53.4203667640686, 54.47863299506051, 55.59314489364624, 54.965041637420654, 55.57981130055019, 54.699905327388215, 50.97247123718262, 52.48782818658011, 46.79897321973528, 52.98317568642752, 55.54760987418038, 58.280596937452046, 56.43344613483974, 65.03035845075334, 12.394979187420436, 4.291168800422123, 52.363931383405415, 27.930764743259974, 51.645852429526194, 25.530401842934744, 42.59429516111101, 48.11038316999163, 31.187760625566753, 49.651778493608745, 15.503949778420584, 0.287899911403656, 0.10965497738548688, 0.16938830140445912, 0.11206527626407997, 0.14495245047977992, 0.029278965866459266, 0.0469238313713244, 0.01719023347167032, 0.03358483374384897, 0.03558293616931353, 0.04197133319186313, 0.1702145127845662, 0.007236161219355251, 0.061088589153119495, 0.04747935138376696, 0.016302719845303466, 0.06616164264934403, 0.01914442959241569, 0.05117560982970255, 0.07060002163052559, 0.04943227355501481, 0.3574050489280905, 42.484878403799875, 51.753219468253, 40.94616508483887, 59.536327498299734, 48.682730606624055, 28.92716768809727, 50.468059812273296, 58.309185300554546, 56.40147747312273, 6.3717586653573175, 0.5260694484625543, 5.015602316175189, 60.92684268951416, 65.39943286350795, 66.96537617274693, 65.19669137682233, 63.531277656555176, 64.76329748971122, 61.111504963466096, 57.530410357883994, 58.04617861339024, 54.12283311571394, 52.49701370511736, 51.06328419276646, 48.0602936063494, 44.92954996653965, 47.586683545793804, 43.62247569220406, 46.967248167310444, 43.36553478240967, 44.109996046338765, 43.90755680629185, 44.47517946788243, 44.37058823449271, 42.19162620816912, 46.13052872249058, 48.733803340366904, 44.16878128051758, 46.27503040858677, 42.23367323194231, 48.163978099823, 52.29022141865322, 53.96525491986956, 52.685028484889436, 47.298687662397114, 50.69938618796212, 55.29386860983712, 52.9083366394043, 51.553875650678364, 46.37394496372768, 47.44904667990548, 47.413989543914795, 46.14978565488543, 46.508260590689524, 44.26578508104597, 45.516738755362375, 45.33415051868984, 51.802846976688926, 51.676876136234824, 48.807996204921174, 22.429212365831646, 22.72207372529166, 47.04680156707764, 37.442984104156494, 39.91180413109915, 35.46194846289498, 38.11102907998221, 36.95750304630825, 39.48639372416905, 34.204609394073486, 37.011841433388845, 35.43230744770595, 35.53379283632551, 33.21169444492885, 36.42627157483782, 34.24720532553536, 35.138582774571006, 34.906047412327354, 36.286508560180664, 35.26654774802071, 39.21042169843401, 33.559187752859934, 49.39608131136213, 42.751327923366, 45.77193219321114, 43.26106514249529, 36.181246825626914, 40.767405305589946, 46.166044439588276, 40.54849188668387, 30.876248564038956, 15.949013165065221, 27.25841883250645, 55.0496255329677, 45.48980406352452, 49.84482724325997, 40.03354351861136, 40.51136418751308, 38.36895315987723, 40.24926424026489, 44.90619012287685, 45.39031975609915, 44.40174743107387, 47.49923699242728, 47.15952219281878, 45.97347511563982, 41.81520754950387, 45.32337038857596, 46.298261710575645, 44.9943071774074, 43.55560622896467, 42.940166064671104, 42.898080825805664, 45.40110336031233, 51.40752921785627, 52.95543152945382, 54.146804400852744, 52.14114086968558, 55.37655912126814, 51.20330081667219, 44.841474601200645, 43.007980482918875, 42.24732296807425, 46.19194037573678, 45.256077085222515, 45.19215018408639, 45.61105012893677, 51.66445970535278, 58.66696194240025, 56.68915721348354, 59.17251982007708, 58.583298683166504, 59.185832568577354, 60.23619869777134, 57.67792408806937, 55.470359802246094, 56.94203690120152, 52.12140451158796, 58.63786288670131, 61.337856428963796, 63.012393133980886, 59.2691901070731, 66.02320044381278, 11.419236711093358, 6.233413517475128, 58.66087532043457, 31.114828859056743, 59.24410711015974, 32.78521401541573, 46.35952397755214, 51.398562567574636, 34.16825989314488, 55.49890995025635, 16.319557121821813, 0.5388753584453038, 0.2280816212296486, 0.15036272230957234, 0.09419720327215535, 0.14692115198288644, 0.03384599508717656, 0.028475210602794374, 0.06824604794383049, 0.047563527045505385, 0.03658938341374908, 0.2518496172768729, 0.2824757296059813, 0.18002641413893017, 0.17544554280383245, 0.2039089740387031, 0.08855031271065984, 0.18482227250933647, 0.10162857307919435, 0.1520619097032717, 0.16482287352638586, 0.09841030862714563, 1.3166833072900772, 57.91754313877651, 58.222787925175254, 58.930215290614534, 64.18458202907017, 69.20412049974713, 30.322956562042236, 51.193222454616, 64.73553248814174, 60.66925212315151, 7.672074948038373, 1.1640608055250985, 6.981548207146781, 62.916153635297505, 65.58952862875802, 68.6301576069423, 66.82475852966309, 66.36196681431362, 67.46309648241315, 64.14331667763847, 60.83905914851597, 60.794333594185964, 56.97099699292864, 54.73448303767613, 52.05356577464512, 49.89140796661377, 47.508085523332866, 50.01366152082171, 44.796592712402344, 49.39205830437796, 44.921226024627686, 44.1871349470956, 45.33490787233625, 45.820958682468955, 46.54429394858224, 45.77535418101719, 48.1719685282026, 50.01226840700422, 46.97360576902117, 48.37089197976248, 44.09399781908308, 49.67539542061942, 54.42469065529959, 55.45448316846575, 56.06558418273926, 47.444353171757285, 50.09698779242379, 57.19216857637678, 55.813986437661306, 54.46983310154506, 47.87863990238735, 47.93336044039045, 48.83761290141514, 46.78264495304653, 48.96420213154384, 47.414906706128804, 48.32379361561367, 46.75321238381522, 52.30355848584856, 52.472278118133545, 50.23386035646711, 27.428034782409668, 29.37494782039097, 43.571910176958355, 36.60978739602225, 41.70164966583252, 37.24569347926548, 43.15198884691511, 40.25496523720877, 44.530504499162944, 37.596386432647705, 40.843199729919434, 37.210083961486816, 39.35818556376866, 35.75851494925362, 38.6899425642831, 38.88628823416573, 39.6060278075082, 41.11312334878104, 40.61904042107718, 38.741133417402, 41.71968718937465, 37.69203533445086, 50.913703373500276, 46.959219523838584, 50.15787138257708, 47.547273363385884, 40.981715542929514, 42.403250966753276, 45.27287088121687, 41.427994864327566, 34.01609434400286, 22.707051719938004, 28.769909109388077, 59.87824140276228, 47.14847108295986, 52.834546770368306, 43.870258876255576, 43.48577683312552, 40.93990823200771, 42.6851532799857, 47.30375984736851, 48.763767446790425, 47.70151989800589, 49.836041246141704, 49.183984075273784, 48.38019214357649, 44.9072254044669, 47.406648772103445, 48.591806479862754, 46.14278881890433, 45.78050627027239, 45.13164874485561, 46.38133437292916, 47.499594824654714, 52.251217705862864, 54.77313586643764, 56.19465739386422, 52.52122817720686, 56.58540671212332, 55.01124368395124, 48.06027276175362, 45.613405568259104, 45.7089432988848, 49.57740844999041, 48.599578039986746, 47.68005691255842, 49.39474030903408, 54.489958558763774, 61.241929599217, 59.23093332563128, 62.74023219517299, 60.883326121738975, 62.178428649902344, 61.68088204520089, 59.24936689649309, 57.04529060636248, 60.28592695508684, 54.709278447287424, 63.220734868730815, 64.76559039524624, 68.917083467756, 63.68181732722691, 75.4843748637608, 16.154097931725637, 7.066482552460261, 64.90001024518693, 40.27767889840262, 63.79901259286063, 37.36320488793509, 59.6233606338501, 57.478833879743306, 47.07107857295445, 64.87015383584159, 22.419788871492656, 0.7900779247283936, 0.38111900644642965, 0.22607009059616498, 0.24611594208649226, 0.19218084907957486, 0.21111912785896234, 0.15788451369319642, 0.11769934929907322, 0.1880639192781278, 0.1621274474476065], [0.12177689692803792, 0.0796670950949192, 0.037225021448518546, 0.11695822621030466, 0.03748797412429537, 0.056046371680817435, 0.15319004202527658, 0.08791514965040342, 0.07599084664668355, 0.049980227901999436, 0.18876557877021177, 0.24610115002308572, 23.35168821471078, 58.23654535838536, 35.54530600139073, 42.832670484270366, 63.156102725437705, 25.06863498687744, 24.00097131729126, 54.63624940599714, 54.93194041933332, 10.82693144253322, 0.38105006728853497, 10.294684665543691, 63.52265494210379, 66.32787895202637, 66.0809886114938, 62.22203554425921, 59.88175024305071, 60.37210546221052, 56.506819111960276, 54.49389818736485, 50.21930735451834, 51.37156186785017, 47.79130799429757, 46.20201178959438, 42.186265672956196, 42.15830264772688, 41.6384071622576, 40.433186531066895, 41.83056306838989, 41.0246901512146, 40.291550976889475, 41.33570889064244, 42.460934911455425, 40.484457288469585, 39.51123006003243, 40.84306424004691, 40.58360113416399, 39.79027666364397, 39.961886746542795, 40.752852303641184, 48.537141527448384, 50.24219472067696, 49.434800148010254, 51.97570078713553, 47.37912000928606, 49.81986583982195, 51.59834064756121, 49.01107120513916, 49.707381452832905, 45.064327648707796, 44.39356592723301, 46.82746083395821, 45.77069541386196, 44.45109353746687, 43.155654021671836, 44.16670724323818, 41.36424166815621, 46.196432386125835, 46.592306000845774, 50.454604625701904, 26.4669634274074, 12.568770136151995, 37.41963815689087, 39.27759688241141, 35.19829559326172, 33.520017283303396, 32.374766554151265, 33.014970098223, 32.64902932303292, 32.90858275549752, 29.779725551605225, 30.82789257594517, 33.271052905491416, 29.193592888968332, 28.676327296665736, 33.14150374276297, 32.93645198004586, 33.00777871268136, 35.90253026144845, 39.35313074929373, 38.809020791734966, 32.302039759499685, 37.634914193834575, 50.234179973602295, 40.67757204600743, 44.536799567086355, 42.515346254621235, 55.47154794420515, 38.32950823647635, 45.14142138617379, 30.548453399113246, 11.203082595552717, 43.35874291828701, 46.783628123147146, 47.686998162950786, 43.46228844778878, 36.82081808362688, 38.4658979007176, 38.57221228735787, 40.16272790091378, 43.748363154275076, 40.80012437275478, 44.15190758023943, 43.36121995108468, 41.168559551239014, 43.0256358555385, 44.43944835662842, 40.80822944641113, 42.22493934631348, 40.13515050070626, 40.33621399743216, 40.88110910143171, 40.82961252757481, 40.64681237084525, 47.09968430655343, 48.111477511269705, 50.66800812312535, 48.61717087881905, 51.35690811702183, 44.64714738300869, 39.80595179966518, 37.97754723685128, 39.95502192633492, 38.02205739702497, 42.03114366531372, 40.8746611731393, 43.338356903621126, 43.93483543395996, 55.046564851488384, 55.817182609013145, 55.80062157767159, 53.74527842657906, 57.08851187569754, 54.08616747174944, 54.80732100350516, 50.61043187550136, 50.80898012433733, 47.27600874219622, 56.598639556339805, 56.4940413747515, 59.639702796936035, 55.74095392227173, 58.09385020392281, 3.7964961443628584, 10.348831108638219, 44.15996054240635, 37.147543225969585, 37.06488398143223, 22.9761780330113, 50.11423322132656, 61.886333329336985, 37.019474029541016, 45.01655183519636, 8.5644850730896, 0.31386389104383333, 0.085992188192904, 0.06801525104258742, 0.03310307388060859, 0.1023771193410669, 0.007974540482142141, 0.037606334380273304, 0.07602166570723057, 0.042692948398845534, 0.04979090306109615, 0.07652196314718042, 0.1744550580957106, 0.06776010830487524, 0.03965701309165784, 0.048453466434563906, 0.06308101224047796, 0.10884184816053935, 0.09892875687884432, 0.1400548389979771, 0.060084642310227664, 0.23015850835612842, 0.28469985883150783, 29.001635006495885, 66.00884546552385, 36.74097285951887, 55.790067264011924, 62.67417567116873, 25.487646102905273, 33.77391488211495, 59.193003109523225, 58.84336280822754, 14.557584285736084, 0.41734601823346956, 13.011786409786769, 68.2922180720738, 66.09545476096017, 67.64960697719029, 65.45044653756278, 63.30289731706892, 60.85011373247419, 59.91224588666643, 56.3721421786717, 53.74934312275478, 54.38724333899361, 50.64657640457153, 50.057094710213796, 46.871995312826975, 43.87157208578927, 45.73534297943115, 43.95334890910557, 43.21883051736014, 44.0763771874564, 43.078612395695274, 44.96357182094029, 43.48998049327305, 42.98855331965855, 40.086481843675884, 43.650483880724224, 42.699084418160574, 43.385375363486155, 43.226098333086284, 41.734907218388145, 51.67705678939819, 54.03282962526594, 52.870045116969514, 53.295306137629915, 49.878901209150044, 54.07279566356114, 52.61322580065046, 52.40599577767508, 51.427178723471506, 49.07812826974051, 45.89715262821743, 47.068598066057476, 47.99481725692749, 47.7022042955671, 45.497346333095, 47.857173442840576, 41.60233211517334, 49.915191650390625, 48.10697160448347, 52.58500221797398, 32.44747945240566, 15.094497646604266, 38.96196106501988, 42.97579295294625, 35.9881911277771, 37.17119141987392, 36.87403086253575, 34.916264738355366, 35.66640615463257, 35.23836932863508, 34.18539067677089, 33.853923388889854, 35.764511244637625, 32.63475424902779, 32.208895683288574, 36.87517384120396, 36.2605014528547, 35.37213952200753, 38.924965381622314, 40.793377671922954, 39.25031130654471, 33.192538261413574, 37.95974942616054, 54.157344818115234, 40.72677224023001, 46.20817484174456, 44.12668909345354, 55.70670625141689, 39.48371866771153, 45.544368267059326, 30.228707722255162, 16.383484022957937, 46.04407923562186, 48.090803146362305, 48.95999847139631, 45.44504724230085, 39.839396953582764, 40.60476187297276, 41.578086376190186, 42.77802985055106, 46.92756005695888, 44.16505357197353, 47.08085468837193, 45.74819367272513, 45.15262188230242, 45.6257768358503, 47.61271844591413, 43.97483273914882, 44.021104267665315, 43.70660448074341, 45.231775760650635, 43.55537346431187, 45.19628088814871, 43.56287751879011, 51.015807151794434, 51.417760440281455, 54.62300961358206, 51.44843326296125, 53.45488888876778, 45.811397961207796, 43.963736465999055, 42.51618698665074, 43.43579149246216, 41.237951210566926, 43.5234499658857, 42.76601641518729, 47.30181782586234, 46.169765199933735, 56.27313034875052, 59.40883500235421, 59.952601024082725, 59.07669721330915, 60.63819367544991, 57.390112331935335, 60.070004735674175, 54.72441509791783, 56.98055076599121, 52.01570504052298, 63.448225838797434, 61.70287309374128, 65.96791362762451, 60.873765400477815, 59.55576855795724, 2.654116541147232, 12.756489617483956, 52.45879513876778, 41.68601969310215, 48.79216820853097, 26.459412472588674, 55.49275384630476, 72.01193618774414, 42.91696950367519, 54.73758888244629, 9.627677576882498, 0.3955895256783281, 0.10990940766142947, 0.09095042677862303, 0.021643543615937233, 0.19529098219105176, 0.07266911238964115, 0.048751048145017455, 0.05417015450075269, 0.05008384019934705, 0.016198639358792986, 0.19809729446257862, 0.3145043466772352, 0.21032784746161529, 0.2707714076553072, 0.12770672302160943, 0.20498701690563134, 0.28187802167875425, 0.20347442664206028, 0.3255099946899073, 0.18279202788003854, 0.2744621496115412, 0.2846879708979811, 40.07651465279715, 77.22909532274518, 45.191962582724436, 56.328625610896516, 75.07882240840367, 35.668803283146445, 32.09883621760777, 65.16771044049943, 62.46039349692208, 16.1352961063385, 0.33109906049711363, 14.70680032457624, 69.69146714891706, 67.39401054382324, 69.99879986899239, 66.49954114641461, 64.68585286821637, 65.29061712537492, 61.91757937840053, 59.112584659031455, 55.48608704975673, 57.63852085386004, 52.3019152368818, 51.49714708328247, 47.39882857458932, 45.81160640716553, 46.043012687138145, 47.05184595925467, 45.68864066260201, 45.34889807019915, 44.38154901776995, 47.38437284742083, 46.69525745936802, 45.69220508847918, 41.81186546598162, 45.52781070981707, 46.35389246259417, 45.26210117340088, 45.097772802625386, 44.97545324053083, 51.285327775137766, 54.84402486256191, 54.04893902369908, 56.65896381650652, 50.49420588357108, 52.159275668007986, 54.2610501561846, 52.16017893382481, 54.91217279434204, 51.459967272622244, 48.52607304709298, 50.73827872957502, 48.38521916525704, 48.17199632099697, 48.36735882077898, 49.25680814470564, 45.055065699986045, 52.480268546513145, 51.925170012882774, 55.380047116960796, 35.00968326841082, 23.268853528159006, 41.216582025800435, 39.29345267159598, 38.836031913757324, 40.74374668938773, 40.1339693069458, 37.99299308231899, 38.395926066807334, 38.212497098105295, 37.71073988505772, 38.54775810241699, 41.120950494493755, 36.41740219933646, 36.81825072424752, 39.693456990378245, 40.596938201359336, 38.34519032069615, 41.67310994012015, 42.45978498458862, 42.9895156451634, 35.136234283447266, 40.239720889500205, 59.268113136291504, 45.54041474206107, 47.955744062151226, 42.72226013456072, 57.72987229483468, 44.35680995668684, 51.16542271205357, 38.66771527699062, 21.458231142589025, 48.88561453138079, 53.365135533469065, 51.767904485974995, 50.007220540727886, 40.66443647657122, 46.12116602488926, 44.733565602983745, 47.29025254930769, 48.981722014290945, 45.259422642844065, 49.56522478376116, 48.82471357073103, 46.979699339185444, 48.45950583049229, 50.84400599343436, 45.97831801005772, 46.871769496372764, 44.8515807560512, 47.14715092522757, 45.27366297585623, 47.34280177525112, 44.51474251065935, 52.246399130140034, 53.02602175303868, 56.547268050057546, 52.38689865384783, 58.596694810049875, 49.3486841746739, 46.278619153159006, 44.858070373535156, 46.2233566556658, 44.13437727519444, 44.91462523596627, 44.44002505711147, 49.82438216890608, 50.48569434029715, 61.59131281716483, 61.76045281546456, 63.78731182643345, 60.64555876595633, 64.42683792114258, 59.456048011779785, 63.44407081604004, 57.07360798971993, 61.562964166913716, 54.40133081163679, 66.85401739392961, 65.37336322239467, 70.98733397892543, 63.20453861781529, 73.06822913033622, 5.0378057190350125, 13.986246074948992, 59.613918031964985, 50.056021213531494, 49.51713282721383, 35.463067122868125, 66.4098607472011, 72.01779351915631, 52.32666819436209, 67.57939543042863, 15.304602486746651, 0.7208172498004777, 0.3667996105338846, 0.10588705207088164, 0.17175191028841905, 0.2853543465690953, 0.19160774483212403, 0.18823765138430254, 0.10259737180812017, 0.15987720819456236, 0.130338298955134], [0.03449796885251999, 0.036063484847545624, 0.10436275707823889, 0.03518740453624299, 0.1880490050784179, 0.09232762216457299, 0.10281316630010094, 0.009068218492237585, 0.2377684957214764, 0.002968228326478441, 0.1601653005927801, 0.21852355982576097, 14.060841066496712, 59.537717138017925, 36.83338737487793, 43.587654794965474, 57.261459486825125, 37.30875880377633, 18.316822017942155, 44.55847447259085, 58.86631965637207, 25.92958106313433, 0.20518718473613262, 20.114864689963206, 65.57044192722866, 63.43286337171282, 61.74870341164725, 60.40274701799665, 59.046222414289204, 55.53596469334194, 52.191869667598176, 50.72755765914917, 49.777054514203755, 50.00607408796038, 46.52240712302071, 43.20167541503906, 43.7963786806379, 42.74972636359078, 41.21236446925572, 41.32294504983084, 41.22394016810826, 41.48716572352818, 39.576789787837434, 40.37577704020909, 38.65515293393816, 39.99436262675694, 39.465014117104666, 41.40346424920218, 39.741090365818565, 38.24548714501517, 37.57152230398995, 41.05693326677595, 47.02342782701765, 50.9381228174482, 51.29666028703962, 52.09543561935425, 53.5305825642177, 52.6567771094186, 52.86579629353115, 51.11757394245693, 45.678954873766216, 45.97548314503261, 43.66757992335728, 46.86728096008301, 47.76629100527082, 46.96681390489851, 45.56711319514683, 43.03616237640381, 43.1642941066197, 44.91690077100481, 48.57054846627371, 50.21283858163016, 41.95033611570086, 10.518653767449514, 24.66167552130563, 33.31833192280361, 33.925965785980225, 31.584030287606375, 33.36968953268868, 33.228331906454905, 31.572770731789724, 32.07944032124111, 31.87431560243879, 29.992253576006206, 32.165754318237305, 26.392728873661586, 30.639248984200613, 36.18129546301705, 34.02847950799124, 38.89986501421247, 40.83268363135201, 39.93656403677804, 40.305030482155935, 39.72276449203491, 45.07157809393746, 45.914206981658936, 43.556141240256174, 42.22959463936942, 38.3522218976702, 33.146172932216096, 32.3289292880467, 34.48923192705427, 12.219387786728994, 20.642929519925797, 44.14902407782418, 48.86197328567505, 45.45259298597063, 39.31792075293404, 36.28126614434378, 37.611873967306956, 40.74194015775408, 42.493990966251914, 44.460702896118164, 46.19835703713553, 42.535624572208945, 42.52323940822056, 41.67863723209926, 43.70558656964983, 41.98961428233555, 40.098616872514995, 40.50061879839216, 39.0104421206883, 38.535532746996196, 39.82029635565621, 41.14761420658657, 44.96914775030953, 47.122543879917686, 48.649149962833945, 50.936795711517334, 48.94166912351336, 44.88421991893223, 40.489053521837505, 37.275407450539724, 39.63964319229126, 38.23902184622628, 39.87416573933193, 39.9479695047651, 41.1515017236982, 42.68642480032784, 39.29250771658761, 44.25721795218331, 49.15740026746477, 54.0377003124782, 53.71700620651245, 56.02139711380005, 53.57828542164394, 52.121887411390034, 47.74508857727051, 45.95677164622715, 52.97317375455584, 56.93836825234549, 59.51166139330183, 62.370789527893066, 61.17473357064383, 36.49259907858712, 0.17442798454846653, 16.227385793413433, 48.934001786368235, 47.15201466424124, 24.58909637587411, 20.739059584481375, 51.385760511670796, 59.56249441419329, 45.14339814867292, 53.72586168561663, 4.611772579806192, 0.16594422049820423, 0.03661571057247264, 0.08510682891522135, 0.02264505112543702, 0.07340098026075534, 0.07837270133729492, 0.055057264398783445, 0.13141928666404315, 0.16870945425970213, 0.08357984692390476, 0.006700706335582903, 0.008291191571126027, 0.07420159729995898, 0.08149096329829522, 0.15218005622071878, 0.13277536604021276, 0.10345891450664826, 0.1419932914099523, 0.23856528582317488, 0.07932277928505625, 0.2396145723760128, 0.21268912218511105, 13.465037379946027, 68.7077133996146, 40.53251450402396, 55.20023815972464, 61.62904848371233, 32.97735602515084, 19.369753769465856, 54.43197584152222, 64.2731715611049, 32.9158992086138, 0.0799451180334602, 26.030024221965245, 70.60298742566789, 66.72272423335484, 65.12029593331474, 63.452068192618235, 63.6023507799421, 58.49545955657959, 57.217647620609824, 52.75318683896746, 53.326656409672324, 53.208200045994346, 48.85208599908011, 46.126648153577534, 47.002562386649, 46.87508726119995, 44.03405570983887, 44.48706783567156, 43.486579350062776, 43.94278417314802, 43.13705369404384, 43.666648864746094, 40.940957409994944, 43.06584160668509, 40.65268359865461, 44.68328496388027, 41.63904987062727, 40.1871577671596, 41.46120030539376, 42.80721228463309, 51.46758597237723, 52.09056840624128, 53.96384443555559, 54.492720467703684, 55.0584636415754, 54.871727330344065, 53.966839109148296, 53.22276694434029, 47.5349611554827, 47.63956281117031, 48.175567695072715, 48.66755921500069, 51.16092375346592, 49.485403878348215, 46.727597849709646, 45.44609294618879, 46.52430050713675, 46.39972972869873, 52.18682180132185, 53.322730677468435, 46.726121357509065, 17.705036606107438, 25.14723127228873, 37.526643889290945, 36.99308477129255, 33.35155473436628, 36.078757422310964, 37.09182562146868, 33.835326535361155, 36.38798352650234, 34.56892081669399, 32.34296464920044, 34.57288476399013, 25.16150460924421, 31.728729997362407, 37.60932050432478, 32.98103857040405, 36.046892983572825, 38.61022935594831, 36.81069803237915, 41.29367576326643, 40.78853825160435, 44.25280237197876, 44.23357670647757, 42.38125991821289, 42.45046050207955, 41.33213056836809, 36.14826372691563, 34.72605085372925, 32.60582889829363, 16.310246535709926, 27.165653433118546, 46.5573148727417, 50.96781941822597, 47.97741549355643, 42.745244775499614, 40.58791249138968, 40.59225511550903, 42.52547672816685, 48.095451491219656, 47.312639645167756, 49.029810496738975, 45.71411970683506, 47.11267048971993, 44.33231060845511, 47.92016928536551, 46.08935022354126, 44.41879136221749, 43.055401938302175, 43.69458062308175, 42.85025290080479, 44.05790887560163, 44.511167662484304, 48.837189061301096, 49.95997626440865, 52.29674925122942, 52.56620386668614, 52.08441925048828, 48.806297370365684, 41.85324893678938, 41.88978951317923, 43.263135705675396, 42.06011765343802, 42.91629900251116, 43.85143273217337, 43.72620187486921, 44.55550759179251, 44.15352651051113, 46.99386324201311, 52.25946174349104, 56.43951538630894, 56.95231328691755, 59.91253771100725, 55.80209806987217, 55.61584118434361, 50.152285030909944, 51.341125283922466, 59.263124329703196, 60.71148327418736, 64.24918637956891, 67.28914138248989, 66.63134847368512, 39.69872719900948, 0.14036267676523753, 21.25961341176714, 52.968754700251985, 53.43794223240444, 34.75133187430245, 27.183986255100795, 56.77471733093262, 70.89839008876255, 48.785959993089946, 62.4029666355678, 6.572099549429757, 0.2955676556697914, 0.13556438923946448, 0.10561633695449148, 0.08793066774627992, 0.04310500914497035, 0.059083999932876656, 0.030887595976569822, 0.10375962087086268, 0.17476665494697435, 0.04844591773248144, 0.1806013232895306, 0.07510245431746755, 0.20533140056899615, 0.1406740564852953, 0.22324122382061823, 0.2792840094438621, 0.1763743215373584, 0.17815185258431093, 0.3872256859072617, 0.17489758506417274, 0.296019478568009, 0.4890538432768413, 21.350978749138967, 78.61256504058838, 44.02351181847708, 58.25166811261858, 67.40520409175328, 51.90472493852888, 23.25106266566685, 58.566748074122835, 67.4142506463187, 33.629993370601106, 0.2806998948965754, 25.993332522256033, 71.41133390154157, 68.79046644483293, 67.54744761330741, 66.51457704816545, 65.75685514722551, 61.40145329066685, 58.7328656060355, 55.37037869862148, 55.47108588899885, 56.11907488959176, 52.51903254645211, 47.82875183650425, 48.86366169793265, 50.671197346278596, 46.19284364155361, 47.75297130857195, 44.7374392236982, 47.19594464983259, 45.397962774549214, 46.307739053453716, 43.74496895926339, 45.70380163192749, 43.81862333842686, 47.81729425702776, 43.74064717973982, 42.06818103790283, 41.30456706455776, 45.435899938855854, 51.06859956468855, 54.325574602399556, 55.734870774405344, 55.34462867464338, 57.72772182737078, 58.12200083051409, 56.347701890128, 55.92809670312064, 49.27849347250802, 51.86501945768084, 48.14047581808907, 49.51165764672415, 53.58084235872541, 52.00604009628296, 50.1924421446664, 48.25743137087141, 48.93929283959525, 50.732223374503, 56.166947977883474, 58.12401580810547, 49.23814180919102, 23.793175016130718, 32.57838698795864, 38.89747830799648, 35.535536834171836, 36.60525369644165, 40.74777317047119, 40.029860973358154, 36.33098745346069, 39.563164370400564, 37.51319565091814, 34.93595245906285, 37.58038125719343, 29.673452854156494, 40.5774450302124, 42.567593233925955, 34.574594020843506, 38.92476040976388, 41.363466944013325, 39.361305304935996, 41.81766721180507, 41.30600186756679, 45.61794621603829, 47.33645806993757, 45.448403222220286, 46.176650864737375, 44.11784403664725, 41.67218235560826, 36.29805646623884, 39.0127489226205, 23.861750262124197, 32.21652480534145, 46.845977783203125, 54.678664684295654, 49.46423619134085, 47.314182145254954, 44.43416772569929, 43.18870312826974, 46.26183925356184, 50.49087422234671, 50.36748463766915, 53.76539693559919, 47.27836765561785, 49.613757950919016, 45.62344571522304, 51.412726470402305, 49.41481712886265, 45.976480211530415, 46.96954802104405, 45.43610838481358, 46.57738127027239, 46.35067892074585, 48.21648563657488, 51.5405490057809, 52.49601663861956, 55.78865677969796, 56.37483460562569, 56.79053143092564, 50.4669828414917, 46.23329257965088, 42.669175897325786, 45.34183522633144, 46.31326634543282, 46.19373648507254, 46.90723310198103, 46.213333879198345, 48.607766492026194, 46.39593948636736, 52.30664348602295, 56.56086220060076, 60.09233624594552, 62.144187927246094, 65.28705964769635, 57.29758317129952, 60.31677695683071, 54.29916797365461, 53.82554749080113, 63.27711950029646, 64.67927292415074, 68.84416907174247, 74.35664749145508, 70.13533891950334, 51.53937128611973, 0.3223993187504155, 22.26397725514003, 59.430339676993235, 59.819549969264436, 32.00622020448957, 32.83355958121163, 66.0646811894008, 80.11915683746338, 57.2062907900129, 71.30500561850411, 7.278396964073181, 0.4500412552484444, 0.2127298614276307, 0.21236761872257504, 0.10999444845531668, 0.1733296670551811, 0.1916107168155057, 0.13473405236644403, 0.2449115967111928, 0.4025210051664284, 0.2056746171521289], [0.1363218921635832, 0.050531490107199976, 0.061552204989961216, 0.061001899519136975, 0.03532012937856572, 0.05319328120510493, 0.189215678189482, 0.036128251015075614, 0.1926834671092885, 0.11455083824694157, 0.397411826465811, 0.4792518892458507, 4.08877602645329, 62.60497161320278, 45.962476117270334, 32.565796852111816, 55.025077547345845, 40.404723235539024, 22.419774975095475, 39.79018286296299, 59.57168688092913, 44.58046899523054, 1.4164518394640513, 30.65761307307652, 69.95174666813442, 60.683009556361604, 61.211878640311106, 63.155658040727886, 61.88242844172886, 52.64737272262573, 53.00809192657471, 48.25472157342093, 49.38924775804792, 45.823567731039866, 46.48316717147827, 40.80419601712908, 43.20996809005737, 40.503787176949636, 39.69288028989519, 41.046663829258506, 42.20580400739397, 39.1990579196385, 38.51950672694615, 38.80715520041329, 40.54149852480207, 38.49627195085798, 41.77163192204067, 42.56944840294974, 39.366210733141216, 38.00702149527413, 38.95887606484549, 43.33001906531197, 46.00705575942993, 49.869375228881836, 56.30787481580462, 51.059222970690044, 52.7812089238848, 51.43182012013027, 51.97439799989973, 49.292914458683555, 47.31974765232631, 44.61250019073486, 45.91828557423183, 47.57025800432478, 48.58696011134556, 44.29223687308175, 45.47317355019705, 39.87398508616856, 42.197393212999614, 40.59448548725673, 48.327059268951416, 48.92725508553641, 52.06093781335013, 20.02364526476179, 21.79843579019819, 33.46507092884609, 28.088377680097306, 30.780683040618896, 27.715926442827495, 28.356791802815028, 28.5414297580719, 29.06938862800598, 30.352795600891113, 32.50005647114345, 32.31349733897618, 15.778956004551478, 47.4843886920384, 59.55431638445173, 38.43897015707833, 27.189605610711233, 33.835017340523855, 33.24289880480085, 38.25033698763166, 39.41020672661917, 38.903391224997385, 38.262075969151084, 44.25583873476301, 36.16533545085362, 35.38948917388916, 37.14387805121285, 39.490319456372944, 13.822927798543658, 15.651807444436209, 33.944104058401926, 48.49773481913975, 49.04728174209595, 46.00172996520996, 40.61247784750802, 37.105603899274556, 39.65834774289812, 40.989681652614046, 43.93623202187674, 47.3709454536438, 44.60065698623657, 44.38044078009469, 40.6636825970241, 41.26998588017055, 46.57676982879639, 40.99214826311384, 39.17362403869629, 38.34912994929722, 38.52813638959612, 36.715285369328086, 36.768734386989046, 38.83563586643764, 43.20685182298933, 44.12413910457066, 45.72504922321865, 46.30262517929077, 46.143824100494385, 39.049862725394114, 38.510672092437744, 36.80794307163784, 41.5095979826791, 38.48729140417916, 38.726323332105366, 37.931459835597444, 39.655228001730784, 40.99582733426775, 41.65381131853376, 39.67900473730904, 42.78049646105085, 43.71748883383614, 48.052549839019775, 48.14257417406355, 46.23532840183803, 44.91016796657017, 46.46864543642317, 49.13056632450649, 55.870485714503694, 55.08237934112549, 61.8661071232387, 59.03173542022705, 60.64332144601004, 17.76914416040693, 0.4110488604222025, 24.63082378251212, 48.02340909412929, 36.98729692186628, 15.146623032433645, 20.948110035487584, 45.236938272203716, 42.0502199445452, 38.1674519266401, 58.33977821895054, 4.424850404262543, 0.06135119577603681, 0.06647724964256797, 0.10528310840683323, 0.03536927566996642, 0.06489549630454608, 0.06367828590529305, 0.23481754692537443, 0.051939904889357943, 0.3297716560108321, 0.07887457976383822, 0.02103882811830512, 0.12172101278390203, 0.015409698210922735, 0.027711383732301847, 0.0628037764025586, 0.06508272447224174, 0.19147967813270433, 0.2716776318848133, 0.06784867748085942, 0.12213603194270815, 0.42372462738837513, 0.36311139272792, 6.933134027889796, 73.90812042781285, 49.60135541643415, 37.44438764027187, 62.62535067967006, 41.57936831883022, 22.888219049998693, 48.13823502404349, 65.03358241489956, 51.708299364362446, 2.2049354783126285, 34.729271343776155, 75.81428922925676, 63.635361671447754, 63.17758655548096, 65.99651936122349, 67.51005240849086, 56.67737306867327, 56.568859577178955, 51.63421072278704, 52.19334615979876, 47.71154267447335, 49.473234108516145, 42.91855369295393, 45.986047880990164, 42.54992743900844, 43.074919428144185, 42.556410108293804, 43.39368193490164, 40.20315599441528, 40.70504869733538, 40.641941683632986, 43.2110971723284, 41.13150480815342, 44.17726503099714, 44.551404680524556, 42.64185210636684, 39.220593861171174, 42.61388908113752, 46.86790977205549, 49.61867380142212, 53.39098630632673, 58.984696115766255, 52.71659762518746, 53.14516946247646, 53.353695324489046, 54.897529465811594, 51.141795362745015, 49.11574234281267, 46.05436256953648, 48.54298843656267, 50.46368244716099, 51.388133321489605, 45.82623931339809, 45.922412804194856, 39.97734996250698, 43.65216187068394, 43.770597389766145, 53.65191200801304, 50.540032727377756, 56.43519013268607, 26.34811101640974, 25.211182492119924, 39.8549678666251, 32.66865103585379, 34.269522939409526, 28.46613734109061, 32.33276816776821, 30.13401072365897, 30.732069969177246, 30.478095940181188, 34.63317428316389, 33.30891711371285, 19.113389560154506, 61.91620363507952, 64.75229849134172, 38.704523359026226, 28.27472836630685, 31.69248124531337, 30.366334165845597, 35.86122669492449, 35.82498836517334, 35.47202335085188, 36.88092000143868, 41.44761657714844, 36.52721152986799, 36.46711308615548, 37.45533105305263, 36.20688220432827, 18.57776161602565, 21.31931233406067, 39.42298098972866, 50.23400626863752, 51.16838959285191, 48.11746685845511, 42.33818803514753, 42.13946260724749, 41.96917963027954, 45.688807419368196, 49.06507955278669, 49.61129134041922, 47.11831590107509, 46.706492696489605, 43.960272789001465, 44.633963176182334, 50.45134939466204, 46.20763635635376, 44.2652257510594, 43.84957408905029, 43.162675176348, 41.68076338086809, 40.440364020211355, 42.713217054094585, 46.72327954428536, 46.59703772408621, 46.59268467766898, 48.26853806631905, 49.43637391499111, 42.13183348519461, 40.55016987664359, 39.46941580091204, 44.16539403370449, 42.63661316462925, 41.635547978537424, 40.066332067762104, 42.860494545527864, 44.284656388419016, 45.63617828914097, 41.950207574026926, 46.74120937074934, 47.49479014532906, 50.77348525183541, 52.42334195545742, 47.91070236478533, 46.43629114968436, 51.155806405203684, 55.63783918108259, 60.708863803318565, 60.24218804495675, 65.8947560446603, 64.88365418570382, 68.78817353929792, 18.51150185721261, 0.3763366644935948, 33.58455215181623, 51.196477685655864, 47.83966745649065, 19.669836044311523, 26.133267504828318, 55.85642256055559, 57.784530299050466, 41.30352830886841, 64.6942949295044, 6.42903961454119, 0.15604752940790995, 0.03006262970822198, 0.020995982024552565, 0.06591466268790619, 0.04610516190794962, 0.036051383175488026, 0.1178161251757826, 0.10098347626626492, 0.23556949943304062, 0.06286316178739071, 0.21480682997831277, 0.27768158114382196, 0.13764396336461815, 0.15533980381275925, 0.22215265009020055, 0.1405183326985155, 0.3281278913574559, 0.580011353961059, 0.2713903401579176, 0.14116680861583777, 0.4174371590571744, 0.5353043643491608, 8.686138476644244, 89.52072266169957, 57.966058935437886, 44.95405626296997, 69.46089117867606, 52.85072565078735, 27.555885110582622, 53.28819465637207, 68.79205063411167, 51.38422843388149, 2.293459870985576, 37.84465946469988, 76.05648953574044, 67.04171603066581, 66.20199843815395, 68.94122150966099, 71.96263871874127, 59.80855097089495, 61.18133435930525, 55.577883175441194, 53.414554595947266, 50.279371057237896, 52.85442904063633, 44.66008145468575, 46.9638991355896, 45.601888929094585, 44.150299072265625, 45.74801301956177, 46.387872627803254, 43.78074870790754, 41.171279770987375, 41.09373787471226, 44.58876167024885, 41.77420622961861, 45.82213987622942, 46.837410654340474, 45.07483679907662, 42.15281009674072, 43.517415455409456, 48.577771118709016, 50.65557779584612, 55.73048298699515, 62.04808044433594, 57.56909792763846, 56.72857434409005, 55.29610940388271, 57.26822355815342, 53.27754306793213, 51.20893233163016, 49.14061689376831, 51.61975499561855, 52.34386151177542, 53.49296849114554, 51.375376428876606, 50.845041275024414, 44.553787912641255, 49.17580951963152, 47.18551540374756, 55.15858718327114, 55.23809194564819, 57.55033431734358, 32.1439335005624, 33.96681077139718, 43.62727689743042, 36.621095589229036, 34.08629199436733, 29.911800384521484, 34.08769900458199, 32.12207099369594, 33.199792180742534, 34.306824343545095, 36.27251141411917, 35.752094813755576, 17.634006908961705, 71.43274130140031, 65.72287845611572, 39.97415379115513, 27.158630541392736, 31.85767466681344, 31.820682457515172, 36.51351315634591, 37.485156195504324, 36.36193125588553, 38.15498685836792, 44.79814910888672, 38.361094747270855, 39.128533703940256, 36.48430640356881, 40.85287162235805, 21.711294957569667, 26.855636971337454, 43.71477556228638, 52.77533769607544, 56.90055962971279, 52.473299503326416, 45.96738154547555, 44.57799891063145, 46.99947738647461, 51.6357810156686, 53.283654008592876, 54.82079356057303, 49.80989864894322, 51.63720539637974, 47.36006804874965, 48.62281976427351, 56.5559081350054, 50.06239965983799, 48.48606531960623, 46.09651034218924, 47.92958409445626, 44.510121958596365, 42.58118391036987, 46.42430203301566, 52.019001960754395, 52.003052370888845, 50.25183187212263, 52.99291011265346, 53.344527176448274, 45.857867513384136, 43.601717948913574, 41.724259104047505, 46.98082842145647, 44.734062399183, 44.243543897356304, 41.09625659670149, 44.594108309064595, 46.737895080021445, 48.029224736349924, 43.171037333352224, 49.10901996067592, 50.5854947907584, 55.21114683151245, 59.79708644321987, 53.23754228864397, 49.098986761910574, 54.163921288081575, 60.14532320840018, 64.82721396854946, 67.59255531855992, 69.85932173047746, 71.6667913709368, 76.75281020573208, 26.181364672524587, 0.405282588409526, 35.23845270701817, 56.94162348338536, 51.49762998308454, 19.487089736121042, 33.00504459653582, 58.34394713810512, 59.17667484283447, 49.13472134726388, 77.52570697239467, 7.539022156170436, 0.3843609924827303, 0.10180827629353319, 0.18890690404389585, 0.1874253364013774, 0.23317489506942884, 0.3417587913572788, 0.23876572506768362, 0.1746245968554701, 0.5293100774288177, 0.1404766570776701], [0.11141690212701048, 0.14538402589304106, 0.13604074796395643, 0.13929599257452147, 0.33953767482723507, 0.2667075800044196, 0.4310702846518585, 0.7255090208990234, 0.2068080556179796, 0.07246116854782615, 0.33485640745077816, 0.1279060494686876, 3.3672142880303517, 53.78095047814505, 44.14714459010533, 35.49077306474958, 26.918259348188126, 33.820721421922954, 26.543475253241404, 30.430153369903564, 50.10990449360439, 63.846003259931294, 6.532159132616861, 26.378221035003662, 74.83068139212472, 55.99245091847011, 56.58329793385097, 57.25644983564104, 61.71625532422747, 50.39363765716553, 50.179890223911826, 47.13497768129621, 47.716521058763774, 45.41886643001011, 46.9433012008667, 39.574132101876394, 43.72440576553345, 41.51623698643276, 40.00052220480782, 40.43758126667568, 39.52067266191755, 38.72187648500715, 40.13578626087734, 40.484585830143516, 41.73991339547293, 40.576451437813894, 42.39431210926601, 43.51533794403076, 39.09655114582607, 34.167888164520264, 42.52548367636544, 43.37072161265782, 44.582824434552876, 54.202108587537495, 54.34135743549892, 51.09220606940133, 54.8789187158857, 53.5331950868879, 55.653458731515066, 53.67169352940151, 49.19285345077515, 44.23458766937256, 47.584831850869314, 48.52030604226248, 48.580970764160156, 43.34927599770682, 43.352711881910054, 40.19912951333182, 40.655146735055105, 40.89604772840227, 46.01391363143921, 44.85650702885219, 49.57529272351946, 28.127294540405273, 16.465623889650615, 36.06019183567592, 30.532170295715332, 28.836462429591588, 30.29827308654785, 28.20384805543082, 28.20450813429696, 29.513991696493967, 27.61588975361415, 29.964783872876847, 33.01469564437866, 28.83953700746809, 94.35776669638497, 77.92652770451137, 42.193397998809814, 30.41203941617693, 34.32315261023385, 34.631986141204834, 37.168544156210764, 35.40666512080601, 33.702591623578755, 29.59321505682809, 36.36020115443638, 37.91754259381975, 39.479171071733745, 33.36197355815342, 22.287262405667985, 28.611719472067698, 23.786067008972168, 35.79462821143014, 48.467218330928254, 50.28646516799927, 44.928035259246826, 39.907329491206575, 37.05259609222412, 42.115175179072786, 41.1264499936785, 43.1821231842041, 43.33541781561715, 44.08391598292759, 42.38256270544869, 39.09305967603411, 38.77662481580462, 38.74392659323556, 38.89444541931152, 40.19748279026577, 40.152854510716026, 37.95629269736153, 35.75393956048148, 38.55278164999825, 38.882980891636436, 41.25982413973127, 41.97072907856533, 44.64870030539376, 42.11138841084072, 39.3368684904916, 36.0140940121242, 37.64867857524327, 37.96934488841465, 40.25102908270699, 37.46292890821184, 38.93557528087071, 37.64032336643764, 40.78731884275164, 40.874678543635774, 41.4421101297651, 40.04476138523647, 43.61809137889317, 41.595672266823904, 44.91947855268206, 41.93874304635184, 42.646955558231895, 43.28234052658081, 48.04811341421944, 51.35249253681728, 55.99949639184134, 52.81991039003645, 61.12868785858154, 53.99354798453194, 55.6246897152492, 5.695761476244245, 1.532915590064866, 30.47038343974522, 45.50637551716396, 25.735067980630056, 22.694953169141495, 29.019880975995743, 44.13046891348702, 45.89410236903599, 23.703682218279155, 58.78779806409563, 6.855210849217006, 0.1565238745617015, 0.33715845963784624, 0.22673658840358257, 0.06158843197460685, 0.020531692741704837, 0.16365601042551653, 0.039332710672169924, 0.08442639399852071, 0.3385561874934605, 0.40158791095018387, 0.0908890939982874, 0.1950740274041891, 0.27156480508191244, 0.021587742592341135, 0.2936628450240408, 0.5104193910956383, 0.3717482478490898, 0.7403209518109048, 0.2159279462482248, 0.07509163846927029, 0.14775144814380578, 0.12924724178654806, 3.5796235416616713, 61.0201986857823, 47.69777134486607, 37.9462525503976, 34.84845379420689, 35.733692509787424, 28.01592707633972, 34.75822448730469, 56.93539094924927, 74.5115714754377, 8.728656240871974, 27.156940392085485, 80.44076115744454, 59.888733182634624, 61.57680497850691, 59.40199102674212, 65.62707669394356, 52.92884772164481, 52.87924105780465, 48.18412092753819, 50.70477451596941, 48.286016259874614, 50.61015394755772, 41.94635132380894, 44.61834362574986, 44.30494165420532, 41.57026270457676, 43.731152466365266, 41.562247957502095, 41.30592891148159, 42.175468172345845, 43.5235333442688, 43.921282972608296, 41.53566762379238, 44.408223152160645, 46.49885620389666, 41.903470516204834, 35.98700645991734, 44.69062226159232, 46.0038491657802, 47.668509006500244, 54.469489165714805, 56.92709480013166, 54.37386110850743, 54.44910315104893, 55.471294334956575, 57.09330265862601, 55.509651865277974, 52.17691019603184, 47.68770340510777, 51.85913780757359, 51.657327379499165, 50.120688097817556, 46.06654276166643, 44.984802041734966, 41.47458600997925, 43.13244703837803, 42.976845605032786, 48.320455006190706, 48.58804750442505, 54.48072092873709, 32.18458046231951, 22.71187550680978, 35.20910699026925, 31.83373464856829, 32.1967328616551, 32.07678958347866, 30.804682118552073, 31.51997137069702, 31.057985646384104, 29.604839393070765, 31.121085711887904, 35.33969490868704, 31.289454460144043, 96.03952257973808, 72.26881803785051, 38.998842103140696, 29.079852615083965, 33.297403948647634, 32.126017570495605, 33.68847288404192, 34.6384722845895, 31.616301195962087, 29.54765224456787, 34.39871079581124, 37.50640378679548, 36.92601728439331, 33.32553025654384, 25.945256199155533, 32.741235392434255, 29.85553387233189, 40.3404141834804, 49.91242626735142, 51.665369919368196, 48.081763539995464, 41.55485507420131, 40.427124227796284, 45.292978967939106, 46.15307215281895, 45.13152367728097, 47.628730569567, 47.40808357511248, 46.09833771841866, 41.95553684234619, 42.439815861838206, 44.660804067339214, 43.00410338810512, 43.020852020808626, 44.0879876273019, 44.01537547792707, 39.10691785812378, 40.91657270703997, 41.6252681187221, 44.00818061828613, 43.14391851425171, 44.6632011958531, 42.559651442936485, 40.379129546029226, 39.836704526628765, 40.222989627293174, 42.45629698889596, 43.97482579095023, 41.7785245350429, 42.235382488795686, 41.46228075027466, 42.97904123578753, 43.139016560145784, 44.095571586063926, 42.97582769393921, 49.46900960377285, 46.967091832842144, 48.52055617741176, 48.74517754146031, 47.85032251902989, 45.75343608856201, 52.91198444366455, 55.14628887176514, 61.16655554090227, 57.496819291796, 62.32094315120152, 59.94258866991316, 62.32311793736049, 5.278986377375467, 1.7387971196855818, 39.76048278808594, 51.10357679639544, 33.57292781557356, 23.291218042373657, 33.58857863289969, 50.45509794780186, 52.49699633462088, 25.04066675049918, 70.25538989475795, 11.680701766695295, 0.11472932009824685, 0.15937908206667217, 0.17363799336765492, 0.11191111310784306, 0.054648745605455976, 0.24108501204422542, 0.2089223571653877, 0.06938644139362232, 0.28972766761268887, 0.17880773810403688, 0.26457122606890543, 0.3224677693630968, 0.3246923057096345, 0.13250202499330044, 0.49190390748637064, 0.6972322410770825, 0.4947787789361817, 0.8336344446454729, 0.41880489566496437, 0.1554275791027716, 0.2921249589749745, 0.27581425277250154, 4.667124969618661, 74.71093613760812, 57.695089612688335, 48.61884886877877, 39.01365566253662, 42.9430183001927, 35.07629564830235, 41.82896498271397, 60.696412631443565, 77.29450566428048, 7.732690164021083, 30.4976863861084, 82.81987994057792, 61.43854277474539, 62.39485113961356, 59.39820425851004, 70.07368755340576, 59.5205203465053, 58.03076750891549, 50.84976257596697, 52.71785177503313, 49.98387459346226, 54.23117637634277, 43.1149445261274, 46.67304059437343, 45.32017421722412, 42.76135417393276, 44.52365704945156, 42.65892730440412, 42.87319585255214, 42.84013284955706, 44.21873188018799, 46.10193688528878, 43.0274840763637, 46.29006631033761, 50.12021214621407, 47.285902976989746, 38.32378986903599, 45.26818779536656, 47.07609864643642, 49.01444455555507, 55.803307056427, 58.081829820360454, 54.13235909598214, 55.35851812362671, 54.83408546447754, 58.56680365971157, 58.227901799338206, 54.339217390332905, 48.929756437029155, 56.195418221609934, 55.062274728502544, 54.98046663829258, 48.38024772916521, 48.5278309413365, 46.36715309960501, 44.61240291595459, 46.683605330330984, 51.507965428488596, 53.81776203427996, 59.38897010258266, 36.490650108882356, 29.608907563345774, 39.536521502903526, 35.645172459738596, 35.02126244136265, 34.42440176010132, 31.961970601763042, 32.58399765832083, 32.17086124420166, 30.28204209463937, 31.686238288879395, 37.495585441589355, 25.23558109147208, 88.3010914666312, 69.08342334202358, 42.07735960824149, 29.48225232533046, 33.724534034729004, 31.117118290492467, 36.360093457358225, 34.635366439819336, 32.8493389402117, 28.940786157335552, 36.52237210954939, 37.22675616400582, 40.83691161019461, 38.40160274505615, 31.307967935289653, 39.10481950214931, 33.542338371276855, 43.735415186200825, 54.77680451529366, 55.35453680583409, 51.416739055088584, 43.88447836467198, 44.351112433842246, 49.90410232543945, 49.46780756541661, 49.68250690187727, 52.59494856425694, 49.69264432362148, 50.569385392325266, 45.24447011947632, 44.92601333345686, 49.089915888650076, 50.40883684158325, 46.60430901391165, 46.13517359324864, 49.48612996510097, 45.02397945949009, 44.16904878616333, 44.888183866228374, 48.86653477805001, 46.97498498644148, 47.56818744114467, 45.03374515260969, 43.21384865897042, 41.661857332502095, 43.61546148572649, 44.175493240356445, 46.26466717038836, 43.91618994304112, 43.18256439481463, 44.85231031690325, 44.81402226856777, 46.06220013754708, 46.78568826402937, 44.5374561718532, 50.95999574661255, 48.36676822389875, 52.21446868351528, 55.37890761239188, 52.1333658354623, 45.256445339747835, 58.654337065560476, 61.70988382611956, 66.79410307747978, 64.39017227717808, 67.1014357975551, 67.93942328861782, 75.67908423287528, 9.106461065156118, 1.47540383040905, 42.652093751089915, 57.002788475581575, 36.09032269886562, 28.88166046142578, 45.39857769012451, 56.71625171388899, 65.70261750902448, 32.98600653239659, 77.31122303009033, 10.289864352771215, 0.4500629412276404, 0.742040576679366, 0.2128015961498022, 0.16958490014076233, 0.15444181699837956, 0.4259671042008059, 0.361018709306206, 0.13504031593246119, 0.3077792232590062, 0.4148690125771931], [0.13582790509930678, 0.08883176903639521, 0.09657317506415503, 0.016216023425970758, 0.0743455688602158, 0.1536379972738879, 0.16140935383737087, 0.08994840697518416, 0.021478120171065842, 0.17696504055389337, 0.22515386476048402, 0.11987841022866112, 3.160531218562807, 58.24724905831473, 50.93267542975289, 49.97791998726981, 22.94910090310233, 30.3547272000994, 18.522938592093332, 29.531879833766393, 43.71250350134713, 62.91383293696812, 13.210540499006, 16.14822322981698, 73.31344495500836, 54.90895577839443, 62.45310483660017, 55.122901235307964, 56.04867574146816, 46.94285651615688, 50.207940101623535, 45.70315892355782, 46.79859801701137, 43.15169702257429, 45.943087169102256, 42.40437657492501, 44.42396082196917, 40.83927747181484, 46.57190261568342, 40.839993136269705, 42.209469182150706, 40.310158252716064, 42.07736655644008, 39.26641723087856, 39.488071714128765, 40.77924156188965, 40.83259677886963, 38.0319516318185, 36.1667355128697, 34.375066076006206, 40.988514355250764, 38.42738056182861, 43.64063828332083, 45.99905490875244, 48.10927493231637, 49.6636494909014, 54.72653777258736, 55.5538215637207, 56.58646631240845, 52.04376881463187, 47.55135195595877, 42.147400924137656, 44.40971006665911, 45.01620095116751, 46.57082564490182, 44.143788610185894, 45.65716184888567, 40.7443824495588, 41.56058733803885, 37.16800914491926, 40.77986689976284, 42.01169913155692, 45.3335668700082, 33.737096377781455, 21.341482298714773, 26.114639384405955, 30.52010474886213, 34.14840888977051, 29.142012936728342, 27.659399373190745, 27.125326088496617, 28.514988388334, 33.42752981185913, 32.99081815992083, 35.96091250010899, 36.515271050589426, 53.99288443156651, 40.839472021375386, 37.27598762512207, 44.82947506223406, 44.15907464708601, 40.28327914646694, 40.103143623897004, 37.201628003801616, 33.83046974454607, 37.208590098789756, 34.089168548583984, 32.66610104697091, 31.325185571398052, 30.894463266645158, 32.29717602048601, 31.19949960708618, 26.687884875706263, 37.28836236681257, 45.84729582922799, 41.86793742861067, 43.15685258592878, 40.315928731645855, 40.253665924072266, 43.1400032043457, 44.85637501307896, 47.56092309951782, 45.751309939793174, 45.029958384377615, 44.70470626013619, 43.61479445866176, 41.835854121616904, 39.625465393066406, 41.000666754586355, 43.36646236692156, 43.5817870412554, 39.78701448440552, 38.565048694610596, 38.00972434452602, 38.12397357395717, 40.7104926109314, 42.21601785932268, 40.81661244801113, 38.71116236277989, 37.69312967572893, 37.44055223464966, 37.72817291532244, 37.42334502083914, 38.85319743837629, 38.39161123548235, 39.8531231198992, 39.37361403873989, 40.304655279432026, 38.819936411721365, 40.82266085488455, 41.630197865622385, 42.35130623408726, 43.86719124657767, 43.55439724240984, 43.31884636197771, 44.624798502240864, 46.41223301206316, 48.73143400464739, 52.31473118918282, 53.88039309637887, 54.96316909790039, 58.052272183554514, 55.18193660463606, 40.86823756354195, 0.6130388017211641, 4.2710120763097486, 41.49333919797625, 35.01642302104405, 15.763812405722481, 26.824220691408428, 26.255772931235178, 38.33196095057896, 41.05455698285784, 37.918039390019004, 63.38280854906355, 13.013848287718636, 0.24753565447671072, 0.13571039640477725, 0.07465556436883551, 0.047047239927841086, 0.08371887196387563, 0.023785291904849664, 0.04153477393889001, 0.06984880194067955, 0.04971685792718615, 0.06858203134366445, 0.043033919031066556, 0.07952952211988823, 0.08995212534708635, 0.012886470749175974, 0.19033482670783997, 0.13430405115442617, 0.1885181170489107, 0.06990432646125555, 0.020275126776791046, 0.1415171633873667, 0.14977355035287993, 0.031002329462873082, 4.51050215108054, 72.38954298836845, 51.703126430511475, 52.17385298865182, 31.84090518951416, 36.384026527404785, 21.669577973229543, 33.76068203789847, 49.748257705143516, 69.46414293561662, 17.088934625898087, 18.004622084753855, 76.61925193241665, 58.16812992095947, 65.92616190229143, 56.89727313177926, 59.81185136522566, 49.467164857046946, 54.820216860089985, 49.625795704977854, 50.59951278141567, 47.124055113111226, 48.01173612049648, 44.79342433384487, 47.96778181621006, 42.53638539995466, 47.0168583052499, 43.566421100071494, 43.48249380929129, 43.30009317398071, 45.82326201030186, 41.47115012577602, 43.9949060848781, 42.18308687210083, 45.10568332672119, 41.66364301953997, 40.42842354093279, 37.45035266876221, 42.967712197984966, 38.70356103352138, 44.26653201239449, 45.53144114358084, 49.45045791353498, 52.92340380804879, 56.48728425162179, 58.02132143293108, 58.75232056209019, 54.02777828489031, 50.584167684827534, 45.582176889692036, 49.11114958354405, 47.64131028311593, 49.71918991633824, 46.51407970700945, 44.47877516065325, 42.62647574288504, 44.12957954406738, 40.409743309020996, 43.07127857208252, 44.260052817208425, 48.2007132257734, 35.40578269958496, 25.9441305909838, 29.51564884185791, 33.21233367919922, 34.47088868277413, 30.395659037998744, 30.237479822976248, 30.554095336369105, 31.03994812284197, 36.083329336983816, 37.10926559993199, 35.30146592003958, 37.33508900233677, 49.87489557266235, 40.589923994881765, 38.052045822143555, 43.582940442221506, 41.45529433659145, 37.14551435198103, 36.213482992989675, 34.04937621525356, 32.77229036603655, 35.47242634637015, 33.07301882335118, 31.332630566188268, 31.909615925380162, 33.59253215789795, 37.37061166763306, 35.01085751397269, 33.39511299133301, 41.927111761910574, 47.31916052954537, 45.11537953785488, 45.325614656720845, 43.06974649429321, 45.71066992623465, 47.62234517506191, 50.890524183000835, 52.21343687602452, 51.24796036311558, 50.79130390712193, 49.6977755682809, 48.04239852087838, 46.30374731336321, 46.533600670950754, 46.568956579480854, 49.77482066835676, 48.566296168736045, 44.48340613501412, 41.78414215360369, 41.47029202325003, 41.93270853587559, 42.22058629989624, 42.06735420227051, 42.96040964126587, 39.68075220925467, 40.24911137989589, 41.30870124271938, 38.46786424091884, 41.86540481022426, 41.57365689958845, 42.07122434888567, 43.280440194266184, 43.005107402801514, 43.75746182032994, 43.186045442308696, 43.71128756659371, 45.38393088749477, 45.32594122205462, 46.737158570970806, 47.51141371045794, 48.754404749189106, 49.328888756888254, 50.246176038469585, 52.08304350716727, 55.168464047568186, 58.209617614746094, 58.638272830418174, 60.59040396554129, 60.796313830784385, 46.182480403355186, 0.577546697642122, 6.454240730830601, 51.10906934738159, 41.10549075262887, 17.849705048969813, 24.629659959248134, 26.34315868786403, 47.36201701845442, 46.8277804510934, 38.850088119506836, 71.67268344334194, 17.594125986099243, 0.22616778606814997, 0.21012482978403568, 0.0610417973782335, 0.027486987112622176, 0.014262432897729533, 0.02685343218035996, 0.004634511224659426, 0.0238718000307147, 0.01896981369437916, 0.027018931960420947, 0.13564752334994928, 0.16186764995966638, 0.21474851667881012, 0.20951854517417295, 0.3549291289278439, 0.450441373778241, 0.455720240516322, 0.24033224529453687, 0.09091762639582157, 0.15340213850140572, 0.26084910865340916, 0.2885817033903939, 4.546893341200692, 83.13986533028739, 63.17707238878523, 63.785324641636436, 33.01855189459664, 43.1602189881461, 24.853761945452007, 41.67511102131435, 57.40153864451817, 72.93881893157959, 18.18801804951259, 20.44543218612671, 80.7559870311192, 60.85877118791853, 66.9328863961356, 58.2446608543396, 64.90909848894391, 52.07074172156197, 57.176316261291504, 50.56785331453596, 51.9841046333313, 48.47970771789551, 52.068945612226216, 47.66443041392735, 50.110276222229004, 44.00560631070818, 48.48397043773106, 44.0705372265407, 46.47675398417881, 44.513140950884136, 47.03589289528983, 42.52935382298061, 44.17817177091326, 44.753510407039094, 46.60996832166399, 43.82090582166399, 43.524019718170166, 37.38953856059483, 45.924806458609446, 42.23156792776925, 45.53418915612357, 45.58983727863857, 50.67899669919695, 52.78316831588745, 57.0853921345302, 58.041366985866, 63.11355195726667, 58.30121571677071, 55.01056276048933, 49.21698107038225, 54.15032366343907, 52.306476729256765, 54.52880246298653, 50.217372281210764, 47.93789413997105, 44.90135070255825, 46.88506834847586, 43.149265153067454, 47.202885900224956, 49.8375038419451, 50.98767042160034, 38.20222071238926, 30.771692071642192, 34.362323079790386, 37.49029438836234, 34.559936795915874, 33.49883917399815, 33.50512381962368, 33.743339334215435, 33.47645207813808, 38.76115812574114, 39.677198205675396, 38.982625007629395, 41.44908264705113, 46.069030216761995, 40.41695901325771, 38.31876632145473, 42.11883340563093, 42.085256235940115, 37.88980538504464, 37.893870081220356, 35.511562074933735, 34.74018348966326, 37.889520508902415, 35.550482409340994, 32.45926707131522, 35.23512799399239, 37.94731909888131, 41.931263310568674, 38.350189549582346, 36.07217747824532, 47.339136600494385, 50.43891906738281, 49.19677570887974, 49.588647161211284, 46.535949162074495, 49.08107778004238, 52.452923910958425, 54.05926752090454, 56.752212115696494, 55.15209756578718, 55.92061349323818, 54.320384298052105, 52.94874388831002, 50.41538551875523, 49.228094714028494, 49.2270142691476, 52.94124330793108, 50.62336942127773, 48.064862046922954, 44.82812711170742, 44.511185032980784, 45.01392889022827, 45.2344126020159, 45.698326451437815, 45.45148474829537, 45.14051117215838, 42.11610276358468, 42.244307449885774, 41.63476283209664, 44.496531282152446, 44.72049951553345, 43.358405930655344, 44.29399129322597, 44.93049839564732, 46.46310077394758, 45.042239325387136, 46.50845514025007, 49.05645336423601, 48.875081062316895, 49.29228912081037, 51.055536951337544, 53.04527521133423, 52.150837080819265, 53.46704476220267, 56.288037708827424, 59.1771125793457, 61.72782407488142, 62.29183714730399, 65.72455992017473, 65.5755558013916, 60.30743857792446, 1.6215228182928902, 5.573967805930546, 59.00720133100237, 47.653226443699424, 23.426355293818883, 35.81331886563982, 37.71572869164603, 53.16200842176165, 55.60193089076451, 48.28728430611746, 86.16231782095772, 24.29160577910287, 0.49062381046158926, 0.44079613419515745, 0.1745162619543927, 0.14800484026116983, 0.11450785983886037, 0.11450874193438462, 0.15014897020799772, 0.10431012990219252, 0.09960841148027352, 0.1655960234680346], [0.11700467871768133, 0.03711784684232303, 0.1379028923277344, 0.008255465006056641, 0.10826157179794141, 0.12568733495260986, 0.025302148457350473, 0.222201423187341, 0.2798629898045744, 0.06584853266498872, 0.12913457783205168, 0.1918179006980998, 3.3041960809912, 55.4247761453901, 50.22380631310599, 44.88355984006609, 25.00417307444981, 28.387070315224783, 23.427376679011754, 26.25349392209734, 37.63910395758492, 60.12190777914864, 23.157100439071655, 11.529965809413365, 67.38176781790597, 57.84602533067976, 60.144718715122764, 54.556529249463765, 53.54229027884347, 45.736715248652864, 50.08909116472517, 46.83740370614188, 45.88489253180367, 42.25923218045916, 43.32194873264858, 42.12826558521816, 43.66084711892264, 40.86495106560843, 44.63156952176775, 40.39354010990688, 38.127027307237896, 40.66641671316964, 41.54155274799892, 38.53417090007237, 42.0362297466823, 39.32201671600342, 41.02998467854091, 39.82212373188564, 39.85786526543753, 39.24701091221401, 37.57969338553292, 37.64666359765189, 42.50858218329293, 44.874377795628135, 51.538388116019114, 53.44772182192121, 56.154531547001426, 52.74641234534127, 52.26842144557408, 49.491028445107595, 45.63491024289812, 42.35743107114519, 43.91708626065935, 43.86850445611136, 46.53100899287632, 42.5826221874782, 46.5188044820513, 45.91178553444998, 43.526910168784006, 39.737105573926655, 38.38546207972935, 39.98759160723005, 45.69930614743914, 35.60613053185599, 23.98874248777117, 33.833012785230366, 30.199577399662562, 35.57170220783779, 30.589902877807617, 27.93499445915222, 25.564541816711426, 28.051656450544083, 33.173458508082796, 36.84621722357613, 32.67506422315325, 34.31511354446411, 40.95461062022618, 43.97414834158761, 52.909663745335166, 59.44755731310163, 52.15335232870919, 40.94757556915283, 36.13246699741909, 34.82496540887015, 34.07503938674927, 30.46750341142927, 28.90521138054984, 29.855523450034006, 29.40417889186314, 37.363382066999165, 31.72265727179391, 32.822442463466096, 28.833460807800293, 35.58395883015224, 46.09218508856637, 43.49552168164934, 43.35998664583479, 39.0937579699925, 45.14383935928345, 44.47901834760393, 44.98526757104056, 44.769161224365234, 44.53402028764997, 43.9514034135001, 41.59282350540161, 39.95697784423828, 41.8473881312779, 42.82186950956072, 45.770066601889475, 42.97908639907837, 41.990027700151714, 40.81400339944022, 40.29266963686262, 40.11164127077375, 38.22624063491821, 37.75901249476841, 38.65569141932896, 37.95485094615391, 36.36975145339966, 37.25454201017107, 36.6479503767831, 38.08583491189139, 38.04496213368007, 38.55344867706299, 39.53301613671439, 40.21216433388846, 39.5290070261274, 38.835243293217246, 39.83831998280117, 38.24775920595442, 41.10559150150844, 40.59718486240932, 40.846312522888184, 40.74228409358433, 43.98135362352644, 44.987348556518555, 46.50856283732823, 49.5980932371957, 52.17970337186541, 53.08305604117257, 56.71697432654244, 53.371110984257285, 57.26747662680489, 21.7970826285226, 0.1546922642737627, 10.088759166853768, 45.44507156099592, 28.668519258499146, 17.623666252408707, 30.220724242074148, 28.204549823488506, 39.557737827301025, 36.462881633213584, 35.513834135872976, 58.42053018297468, 11.104413832936968, 0.27446518944842474, 0.03755173605999776, 0.11733333393931389, 0.09830952582082578, 0.027286678486104523, 0.08117403316178493, 0.21783023274370603, 0.18715738292251313, 0.04265580539192472, 0.016094438432316695, 0.12601954569774015, 0.06021626453314509, 0.08432094287127256, 0.08633199174489294, 0.036785744662795744, 0.060491349415055344, 0.028390327568299005, 0.11595630140176841, 0.23545295425823756, 0.08194920513778925, 0.2127859762736729, 0.08894554578832217, 3.558515565735953, 63.6053524017334, 57.77969782693045, 56.312401567186626, 32.48436049052647, 33.254957403455464, 27.025661127907888, 29.777314526694163, 44.61725623267037, 68.00809928349086, 28.39803978375026, 13.089932799339294, 69.8299308504377, 60.629348618643625, 63.55902181352888, 57.18010997772217, 57.258843490055625, 50.91427659988403, 53.10837180273873, 49.57977431161063, 47.94839286804199, 45.40260417120797, 46.400007656642366, 45.397736958095, 46.27322735105242, 43.64687081745693, 46.503931862967356, 42.20995903015137, 40.51998690196446, 42.762490204402376, 43.48649249758039, 40.93587132862636, 43.67283623559134, 41.205082757132395, 42.65014478138515, 42.54123871667044, 41.05978550229754, 39.75875963483538, 41.375813892909456, 37.959544454302105, 42.79056787490845, 46.31358248846871, 54.29041324343, 56.0500271660941, 56.55213526317051, 55.30073343004499, 56.112668650490896, 53.62931299209595, 47.86719274520874, 44.78450632095337, 48.065445695604595, 44.2913544518607, 46.78098085948399, 43.81931815828596, 46.06107800347464, 47.05899912970406, 45.080878257751465, 41.488551889147075, 40.96308742250715, 41.261762687138145, 48.02166857038225, 38.517620291028706, 27.606586115700857, 36.00725698471069, 32.460510798863, 35.56493813650948, 31.995801380702428, 30.319642271314347, 29.090881143297466, 29.854310989379883, 35.12365804399763, 37.49671452386038, 33.08423668997628, 32.90215914590018, 39.499751635960166, 43.5809463092259, 51.32488734381539, 58.885496684483115, 53.54761259896414, 42.21395077024187, 36.391186646052766, 33.0265006337847, 32.31524133682251, 31.56952244894845, 29.200791222708567, 32.974486419132774, 33.46015855244228, 42.67960166931152, 35.85238858631679, 38.43565239225115, 30.70630952290126, 38.19588048117501, 48.66157681601388, 44.775018555777415, 48.12736109324864, 44.822363580976216, 50.92356634140015, 50.377361501966206, 53.03758702959333, 51.01923261369978, 51.227015018463135, 51.50747210638863, 49.0241824558803, 46.37391022273472, 47.42388725280762, 49.35023014886038, 50.02255521501814, 46.0883983203343, 46.920177595955984, 42.868627411978586, 44.17525005340576, 43.01914276395525, 40.30738244737898, 39.71602473940168, 41.73914909362793, 42.9183417728969, 38.14725351333618, 38.83111606325422, 40.96230575016567, 40.06109312602452, 39.609411580221995, 40.37311935424805, 42.981337615421836, 41.47399888719831, 43.54840442112514, 43.268666471753804, 43.97559009279524, 41.8668326650347, 44.54416813169207, 43.09632682800293, 44.10440274647304, 43.78228425979614, 46.30691221782139, 49.8207552092416, 50.62788922446114, 51.30987228666033, 56.77674967902047, 55.74705444063459, 59.14562334333147, 55.413137912750244, 60.91378007616316, 22.488619463784353, 0.15756051322179182, 14.240044661930629, 52.95738744735718, 32.695505823407856, 19.548444066728862, 28.779209273202078, 28.452084609440394, 47.06271989004952, 43.62684958321707, 37.05255440303257, 67.01987089429582, 18.711264303752355, 0.4815295955964497, 0.19294044189155102, 0.07435105142316648, 0.11183767526277474, 0.007294147973880172, 0.08452300381447587, 0.09033114822315318, 0.2305329239794186, 0.027075326702158366, 0.06493597770375864, 0.23207298134054455, 0.15846981800028256, 0.24126536665218218, 0.18468784115144185, 0.18495149271828787, 0.2706364877521992, 0.08751313122255461, 0.258545672254903, 0.2293025500008038, 0.143063164715256, 0.3668943340224879, 0.20388508960604668, 4.914319728102003, 77.35229383196149, 63.02479566846575, 65.57127571105957, 36.50984798158918, 42.13121509552002, 29.667876924787247, 35.8315509387425, 50.47439309528896, 73.50374221801758, 29.69477687563215, 14.878325292042323, 73.5573684147426, 61.356797218322754, 64.55968747820172, 59.71771022251674, 58.69023840767996, 51.88628094536917, 57.19317953927176, 52.2772456577846, 50.94653013774327, 48.03721863882882, 48.502720151628765, 47.51051391874041, 48.89481047221592, 45.21091379438128, 49.51827927998134, 44.188364778246196, 41.76548971448626, 44.96780327388218, 45.30952957698277, 42.652329989842, 46.1984612601144, 43.46825000217983, 45.508942876543315, 41.485473837171284, 41.703129632132395, 40.69901418685913, 41.40973499843052, 38.157304082598, 43.81625052860805, 44.87060839789254, 54.1639039175851, 55.2811290877206, 58.947161946977886, 57.02322312763759, 58.41475622994559, 57.337889671325684, 52.90146139689854, 48.877422605242046, 50.75469732284546, 47.316593170166016, 50.405546869550435, 46.178777013506206, 50.92795760290963, 51.70144844055176, 48.343137400490896, 42.39317260469709, 40.93478046144758, 43.37656157357352, 48.270084040505544, 40.6750567981175, 31.403766223362513, 38.595377581460134, 33.82446650096348, 40.349895000457764, 35.38311767578125, 33.0506386756897, 30.963476249149867, 33.381098474775044, 37.985141617911204, 41.73126983642578, 36.342889717647004, 33.737878050122944, 42.811499323163716, 45.83709934779576, 54.11242471422468, 62.59838472093855, 53.537075655800955, 41.30775628771101, 38.39259787968227, 34.724900926862446, 34.51865059988839, 34.2840689931597, 32.48250184740339, 36.188434737069265, 36.712874344417024, 47.69422428948538, 41.02950177873884, 40.88338463647025, 35.4880667413984, 41.789589541299, 49.26642097745623, 47.23395129612514, 50.735836437770296, 48.75257737295968, 54.414066859654014, 53.570791789463584, 56.373910495213096, 56.765045438494, 57.970943519047324, 58.087388379233225, 53.55181973321097, 53.67852013451712, 55.26499884469168, 52.42239005225045, 54.214233194078716, 51.848819732666016, 49.90117365973336, 46.590051310403005, 47.59285354614258, 46.78871767861502, 41.612806524549214, 44.201448236192974, 45.23827927453177, 48.25796290806362, 39.48559815543038, 40.36896433149065, 44.180773871285574, 45.10418251582554, 41.86048201152256, 43.32715293339321, 45.034922872270855, 44.72146531513759, 47.20520312445504, 45.55160828999111, 47.69819171088082, 44.941771847861155, 48.004819188799175, 46.91715512956892, 47.80348471232823, 48.16578115735735, 51.06362812859671, 52.956543241228374, 53.76232583182198, 54.78819261278425, 59.844709396362305, 57.95622723443167, 65.52427809579032, 60.42201437268938, 66.44415705544608, 34.13561725616455, 0.17356301524809428, 13.695597716740199, 62.363473074776785, 40.44864974703108, 23.621688263756887, 40.411765234810964, 42.077272755759104, 54.57223565237862, 49.477170263017925, 48.29530947549002, 74.4779074532645, 21.07261480603899, 0.5038224565131324, 0.38603103001202854, 0.2813445303056921, 0.24654287632022584, 0.12423090024718217, 0.16998980912779058, 0.30495461768337656, 0.31214491756899015, 0.1643170935234853, 0.16343999201697962], [0.09111007928316082, 0.1391741819679737, 0.12114325378622327, 0.06677342339285783, 0.1047697491677744, 0.04944581032863685, 0.10594698706907885, 0.07693873971168484, 0.22994086146354675, 0.060985451830284934, 0.07526627981237002, 0.03907294711098075, 0.6677898466587067, 43.093724727630615, 53.80816657202584, 31.914563042776926, 36.06699064799717, 31.46331923348563, 21.798699821744645, 23.891936710902623, 32.57135888508388, 59.99117742265974, 34.70679044723511, 11.800162145069667, 55.113107749394004, 61.325780459812705, 59.96975612640381, 54.715434551239014, 54.02289717538016, 51.66673524039132, 48.11053255626133, 45.94673844746181, 44.95860733304705, 42.56524821690151, 43.194473607199534, 41.936133997780935, 43.144738401685444, 42.42186519077846, 43.18024022238595, 40.253818784441265, 41.392499991825645, 41.73943049567086, 41.81406109673636, 43.39219502040318, 41.52134043829781, 42.036730016980854, 42.26023619515555, 42.68451404571533, 42.31829186848232, 39.39090115683419, 40.43042114802769, 40.96165609359741, 44.05845430919102, 42.66404812676566, 48.246727670942036, 53.06825985227312, 51.43920258113316, 50.03824077333723, 48.088110719408306, 47.025463649204795, 44.06244952338082, 43.14780255726406, 47.123537472316194, 46.94336026055472, 48.066303798130576, 47.9633731842041, 46.64408050264631, 45.30918564115252, 45.5490721975054, 41.66959415163313, 43.437476430620464, 43.90127910886492, 47.90931967326573, 39.35593087332589, 22.209958485194615, 34.029553004673545, 29.941104412078857, 30.74566411972046, 27.88429171698434, 26.850349392209733, 22.804661750793457, 25.773812873022898, 28.918909754071915, 31.067480359758648, 35.04198891775948, 43.69875996453421, 43.87732172012329, 48.61385658809117, 48.85677603312901, 44.53356865474156, 37.62539168766567, 29.686755180358887, 34.88506037848336, 32.77977705001831, 29.36275373186384, 30.55200740269252, 36.51253693444388, 38.10370567866734, 31.62806797027588, 32.76600572041103, 30.60581077848162, 38.747296469552175, 25.87158271244594, 38.37778779438564, 45.06673867361886, 45.75880009787423, 44.08215808868408, 40.319923945835654, 43.75037465776716, 42.41409363065447, 42.79998615809849, 41.57893058231899, 40.426523208618164, 41.47184494563511, 44.44751868929182, 41.324345111846924, 43.18237679345267, 42.789716720581055, 44.770481382097515, 42.217921665736604, 40.75157730919974, 37.22266714913504, 38.11969348362514, 38.07862615585327, 38.151415484292166, 38.44540071487427, 39.506175245557515, 36.822697571345735, 39.879349095480784, 41.66744021006993, 39.29887574059622, 36.83780642918178, 38.34111867632185, 38.98501866204398, 39.469165665762766, 38.247088704790386, 37.37476669039045, 40.23453753335135, 38.311376912253245, 38.9151406288147, 41.19998625346592, 39.8421310697283, 40.54758167266846, 40.83190195901053, 44.820425033569336, 48.200049672807964, 53.43685483932495, 52.765464305877686, 55.019418239593506, 53.52176877430507, 56.23604433877127, 52.310214860098704, 53.17585618155343, 9.69255985532488, 0.35986161710960524, 19.375395706721715, 46.13672651563372, 26.32172175816127, 21.741109677723475, 23.953977176121303, 28.204308373587473, 22.50744387081691, 27.104550974709646, 27.35793788092477, 56.90591321672712, 17.569930621555873, 0.4817561177270753, 0.08650748804211617, 0.14362928005201475, 0.09916390318955694, 0.026123442154909884, 0.08162897732108831, 0.142527203474726, 0.08733809632914406, 0.06259017357868807, 0.06251385874514069, 0.07904147902237517, 0.10760890253420387, 0.054392995578902106, 0.02555920636015279, 0.2020956841962678, 0.04283551539161375, 0.16974347377462046, 0.0383739406908197, 0.2515772261789867, 0.04674618751076715, 0.040428656685565195, 0.23453826191169874, 1.0903366186789103, 55.33201422010149, 58.10023212432861, 38.66445657185146, 37.02155154091971, 34.87207766941616, 24.416213035583496, 28.620821612221853, 39.41877038138253, 63.911622047424316, 40.345409938267295, 13.937778915677752, 59.33389173235212, 66.33668231964111, 62.90464047023228, 59.588508469717844, 55.374412127903526, 52.764710426330566, 51.1148294040135, 47.68001522336687, 46.315190996442524, 45.806603704180034, 45.86778606687273, 44.90170158658709, 46.28421940122332, 44.1973557472229, 45.64301879065377, 42.51543658120291, 44.076776708875386, 43.35775627408709, 45.03069141932896, 44.16573796953474, 43.33527537754604, 43.082027435302734, 44.260490553719656, 43.40250614711216, 43.263872214726035, 39.88069357190813, 41.93864924567086, 42.59216206414359, 45.227249009268625, 46.75014475413731, 52.15335232870919, 57.22041995184762, 53.13756465911865, 54.72164971487862, 50.201266356876914, 47.476168973105295, 44.010609013693674, 43.78027623040335, 45.62151064191546, 46.56652818407331, 47.85682603291103, 48.58300658634731, 46.82909713472639, 45.33725983755929, 47.627278396061485, 43.34308515276228, 43.61916140147618, 45.08543627602713, 51.68623535973685, 42.56697484425136, 26.267689091818674, 36.79115969794137, 32.38590104239327, 35.77239397593907, 32.48411382947649, 30.45396137237549, 26.098054034369333, 29.082727432250977, 32.361999239240376, 34.44230031967163, 35.37830604825701, 41.47993612289429, 40.39306763240269, 44.24906076703753, 44.12138066973005, 40.586647919246126, 33.49537897109985, 25.944740295410156, 29.9337705884661, 33.34495741980416, 31.96035167149135, 34.154175894601, 37.10969986234392, 41.278959478650776, 35.41877235685076, 36.94715370450701, 36.49915817805699, 40.15235424041748, 30.358635561806814, 39.198366573878694, 47.24236903871809, 48.90155022484915, 47.81865610395159, 44.920117786952424, 49.057749203273225, 49.280345167432515, 49.89205067498343, 48.80824981416975, 47.9897346496582, 46.05632543563843, 49.22723661150251, 46.591826575142996, 45.32655961172921, 45.44996656690325, 47.016510895320344, 44.038537297930034, 46.21046774727957, 41.426143169403076, 44.36846208572388, 43.61878619875227, 41.78577845437186, 38.58334330150059, 41.05937555858067, 39.5005715233939, 42.72023126057216, 42.94415085656302, 42.01427343913487, 39.03963497706822, 41.62389932359968, 41.90358516148159, 43.48488746370588, 42.2267667225429, 41.49892554964338, 42.35679531097412, 44.16201720918928, 41.976822648729595, 44.24404764175415, 43.08789866311209, 45.52261345727103, 44.20869173322405, 47.32164798464094, 51.293328625815256, 54.94421788624355, 56.23359857286726, 57.64729642868042, 55.23643480028425, 58.84432165963309, 55.05835247039795, 60.19715676988874, 9.630086864743914, 0.2940896435507706, 24.44225662095206, 53.84761149542672, 29.13209785733904, 23.590709720339092, 23.863093001501902, 31.00171913419451, 31.438357830047607, 34.79734979357038, 37.85970231464931, 66.1121165411813, 23.566635949271067, 0.40467364394239014, 0.09496089443564415, 0.20509634246783598, 0.04378842283040285, 0.0403158977361662, 0.05174775395010199, 0.07872967861060585, 0.14379674249461719, 0.13523333200386592, 0.12124979735485145, 0.14743207528122834, 0.2796364948153496, 0.21166988116289887, 0.15537721823368753, 0.2817586266568729, 0.20950793288648129, 0.2695484161376953, 0.17937960741775377, 0.3324027433991432, 0.10985684155353478, 0.1606657337397337, 0.31648553322468487, 1.8545580165726798, 65.99141938345772, 69.64131505148751, 46.1142178262983, 49.53293997900826, 49.18722888401577, 27.98968894141061, 32.667952741895405, 44.93722425188337, 71.28506428854806, 41.83963394165039, 16.602312326431274, 63.28447069440569, 68.89058998652867, 65.90027291434151, 60.45070348467146, 57.34836755480085, 56.446696349552695, 52.48092515127999, 49.95258685520717, 48.4154611996242, 47.7591586794172, 48.478717599596294, 47.63823223114014, 46.803718839372905, 46.051100390298025, 47.563685008457725, 45.562447479793, 45.43031358718872, 44.40683003834316, 46.383655071258545, 45.82471418380737, 44.91501086098807, 44.4614428792681, 44.24118845803397, 44.66795376368931, 42.15063531058175, 40.92658158711025, 42.57456227711269, 42.78555474962507, 44.57211378642491, 47.47726331438337, 53.57150397981916, 59.93682166508266, 57.18993125643049, 58.07429102488926, 53.698193958827424, 53.36167533057076, 48.5211363519941, 46.25746883664812, 48.04282930919102, 48.982580116816926, 48.864700453622, 50.443112305232454, 49.099441868918284, 47.69946323122297, 49.16458123070853, 43.94303430829729, 46.045482771737234, 48.1336943762643, 54.29023606436593, 46.623930726732524, 29.443703719547816, 40.76235743931362, 37.680567332676475, 39.004105363573345, 36.39211770466396, 33.63152544839041, 31.425017288752965, 33.82672119140625, 34.60951566696167, 36.47288009098598, 37.0116468838283, 45.359032017844065, 45.611074447631836, 46.493047509874614, 44.37947498049055, 40.08031531742641, 35.85938889639718, 28.87598899432591, 35.78868055343628, 36.71874557222639, 36.32735354559762, 36.48123529979161, 42.99390343257359, 46.22865465709141, 39.47089924131121, 42.222417150224956, 38.97997426986694, 45.90984351294381, 35.032876355307444, 42.526921953473774, 49.81509937558855, 50.917073249816895, 50.915718351091655, 48.620853424072266, 53.48729876109532, 53.01606845855713, 54.582435607910156, 54.952719007219585, 52.95141894476754, 51.39754465648106, 56.24868311200823, 53.513194697243826, 52.97885390690395, 50.962403297424316, 53.06744343893868, 47.18865251541138, 49.06349188940865, 43.878363949911936, 46.427140372140066, 45.654431206839426, 44.64830425807408, 41.96340915134975, 44.01552833829607, 41.63158403124128, 44.87481205804007, 45.6250125340053, 44.58844552721296, 42.37128577913557, 43.478099073682515, 44.269835880824495, 46.42210292816162, 44.260806696755544, 44.105107988630024, 45.657411984034944, 46.211259841918945, 44.397606304713655, 47.331566538129536, 46.778826917920796, 48.02077225276402, 48.956399304526194, 51.982506547655376, 55.00980193274361, 59.56838648659842, 62.01349925994873, 62.547642026628765, 60.17007269178118, 62.62312030792236, 58.183600085122244, 65.03817517416817, 14.234861305781774, 0.33225080583776745, 25.88966887337821, 62.60458946228027, 35.81970773424421, 27.19448845727103, 31.056672436850413, 42.811085905347554, 35.68119886943272, 38.61902577536446, 40.056305817195344, 76.1374568939209, 31.80177640914917, 0.5564990841916629, 0.49677801451512743, 0.31730042664068087, 0.25716585772378103, 0.12171439028212003, 0.3099051277552332, 0.1978198414934533, 0.2140197700687817, 0.19046255413975033, 0.24359361029097013], [0.1471027143831764, 0.06203403949205365, 0.04482322605326772, 0.04971666454470583, 0.10167900180178029, 0.04068389781085508, 0.06162849946745804, 0.07693713158369064, 0.19294067259345735, 0.09621612315199204, 0.1203870807907411, 0.05386911226170404, 0.5635036283305713, 36.294912406376426, 48.649966376168386, 36.22128234590803, 43.186945234026226, 36.18594033377511, 21.634788342884608, 25.262583528246196, 32.84867538724627, 52.06484964915684, 48.515112263815745, 10.30224256856101, 42.054333278111045, 66.53827735355922, 61.14056232997349, 57.8507535798209, 55.4946402822222, 50.851259912763325, 46.398162909916465, 45.7459146635873, 43.42423663820539, 44.32123517990112, 42.23410054615566, 44.1943610736302, 45.545139517102925, 42.88779401779175, 40.97454847608294, 42.25131123406546, 40.39333513804844, 43.502237115587505, 43.31107480185372, 41.99252905164446, 43.04604271480015, 43.33647741590227, 43.66903904506138, 41.83909893035889, 41.60692834854126, 41.43851791109358, 38.784128870282856, 40.66712542942592, 40.06820808138166, 41.49935286385672, 48.1964088167463, 51.380271434783936, 49.96331834793091, 52.528162479400635, 49.78947441918509, 49.85414130347115, 45.78884410858154, 42.756684984479634, 43.806477887289866, 45.42478976930891, 43.154872349330354, 43.72578150885445, 47.500640528542654, 47.580812317984446, 43.967227935791016, 42.97982290812901, 39.75005006790161, 43.221800872257774, 43.19490786961147, 40.47833245141165, 21.350893633706228, 32.48320361546108, 28.201945986066544, 31.16778802871704, 27.459032433373586, 24.230875049318584, 22.567875828061783, 22.973367486681255, 25.957170622689382, 32.2588323865618, 34.79058224814278, 37.14393711090088, 34.498299326215474, 32.388913086482454, 28.022877011980327, 15.787238257271902, 16.90575752939497, 21.99568819999695, 33.08368083408901, 30.838120324271067, 30.74603932244437, 28.893310853413173, 38.16632284436907, 40.69282334191458, 38.35556745529175, 38.0516219820295, 33.17158249446324, 33.364085810525076, 26.09154530933925, 37.5729466847011, 47.03721652712141, 43.814030579158235, 40.42807960510254, 40.87545674187796, 41.46072782788958, 40.74615771429879, 42.770602226257324, 42.57467344829014, 45.108208996909006, 41.77925409589495, 40.270129680633545, 42.050122669764924, 42.40752410888672, 42.54509496688843, 43.498102937425884, 44.102193219321116, 41.41085713250296, 37.73743486404419, 38.257653440747944, 36.96681015832083, 37.52993038722447, 37.5732558795384, 37.97033153261457, 40.46765654427664, 39.38575948987688, 38.51447623116629, 40.246102809906006, 38.505537373679026, 37.48714338030134, 38.79678501401629, 38.71603652409145, 37.66965518678938, 39.689666748046875, 40.16934953417097, 40.937424251011436, 40.04616492135184, 40.4151212147304, 40.72191892351423, 42.06350490025112, 41.38212980542864, 45.736649240766255, 48.74067163467407, 51.73442806516375, 50.35194846561977, 55.122129985264365, 53.267978872571675, 55.799329212733674, 49.31875133514404, 47.79104743685041, 4.074373279299055, 0.42201493627258707, 37.57754986626761, 43.884975160871235, 29.60910211290632, 18.296213660921367, 23.444345917020524, 25.938208988734655, 31.27279962812151, 35.79654244014195, 43.65548658370972, 53.36870690754482, 12.122676679066249, 0.25056007504463196, 0.09505373159689562, 0.16241572983562946, 0.04974764645365732, 0.050404631200113466, 0.07859775783228022, 0.1734783069363662, 0.05892016086727381, 0.09046146087348461, 0.062161448012505255, 0.048162843100726604, 0.03924496252355831, 0.0650457443137254, 0.045078931975045373, 0.04368814892534699, 0.10034659651241132, 0.054591616349560876, 0.0944632093555161, 0.10535343177616596, 0.05026986396738461, 0.2067757166389908, 0.08941624553075858, 0.9313431616340364, 45.247631549835205, 51.388887201036724, 39.426871980939595, 36.49651091439383, 35.72716120311192, 24.941759143556865, 27.140214341027395, 39.96312699999128, 55.03966876438686, 55.83066211427961, 13.751984085355486, 42.19001770019531, 70.20437622070312, 61.991945947919575, 61.50366129193987, 57.3044410433088, 52.50610542297363, 48.34214033399309, 49.43550191606794, 45.98739235741751, 46.854784624917166, 46.61235850197928, 48.88071257727486, 48.33322926930019, 47.39711931773594, 44.12783554622105, 44.72154869352068, 43.307975905282156, 45.53270918982369, 45.815094402858186, 47.21697684696743, 44.67238324029105, 44.938151836395264, 44.629634448460166, 45.745299748011995, 45.481143133980886, 43.527139459337505, 41.742247990199495, 42.99622760500227, 43.73696116038731, 43.900212560381206, 49.92305701119559, 53.26800319126674, 52.7910475730896, 53.813728604997905, 50.72463941574097, 50.872139249529155, 45.55117402757917, 42.617432662418906, 45.06020736694336, 45.18675143378121, 44.4785806110927, 46.720357826777864, 49.32750606536865, 49.5133912222726, 47.8090363230024, 47.07864168712071, 44.716879504067556, 46.99293565750122, 49.34293801443917, 45.4596141406468, 26.501607145581925, 37.95645250592913, 35.184263706207275, 35.411660875592915, 31.895611831120082, 28.2477502482278, 26.15731348310198, 23.317735842296056, 28.02871002469744, 33.26137753895351, 33.166795185634065, 35.802601269313264, 37.81037357875279, 39.386843408857075, 35.29524380820138, 27.180572952542985, 27.698743547712052, 31.169208935328893, 34.5270231791905, 31.01043564932687, 32.45272881644112, 34.03222458703177, 41.892537525721956, 44.82008804593767, 40.40878793171474, 41.56150450025286, 38.1508526802063, 37.02973304476057, 30.63922119140625, 40.81675141198294, 47.98503419331142, 45.714387212480815, 42.97669274466378, 44.588438579014365, 47.055709157671245, 44.25532109396798, 44.83422415597098, 46.19696044921875, 44.535323074885774, 42.008423055921284, 43.06393780027117, 44.984329564230784, 45.25798436573574, 45.13655764716012, 45.0574836730957, 45.06077364512852, 43.93602010181972, 42.034464904240195, 42.20477914810181, 41.60444784164429, 40.76501859937395, 40.39325870786394, 40.29242297581264, 41.69526774542672, 42.059582642146516, 40.59511777332851, 41.23419918332781, 41.892356872558594, 42.004889896937776, 40.86714322226388, 42.76003054210118, 41.421272482190815, 42.26470388684954, 44.831931250435964, 44.220486300332205, 43.573094844818115, 45.61822066988264, 44.11699983051845, 45.35274737221854, 43.377072266169954, 48.87628310067313, 53.327250480651855, 55.53256007603237, 53.87220811843872, 59.178057534354075, 56.00338390895298, 61.83377020699637, 54.71086958476475, 51.60515683037894, 3.078045678990228, 0.7673966703670365, 45.10764271872384, 50.62376546859741, 34.16166605268206, 22.72225090435573, 28.275237321853638, 32.22515099389212, 33.00103548594883, 34.513022559029714, 53.022471223558696, 59.732023511614116, 20.097794703074864, 0.24762383688773426, 0.10954423368509326, 0.19520103558897972, 0.011826883186586201, 0.049920381113354645, 0.025270428641566207, 0.049900215052600415, 0.05069982785997646, 0.05296439777261444, 0.04620907276070543, 0.28644298815301483, 0.15080007884119237, 0.12534907167511328, 0.22320572286844254, 0.22843733642782482, 0.17111552586512907, 0.17113661473350866, 0.28172706120780533, 0.29810475238731926, 0.27882952668837135, 0.3305586480668613, 0.1612922115517514, 1.5139804461172648, 53.99083818708147, 63.286763599940706, 49.27678768975394, 54.84108230045864, 49.2028797013419, 28.695042269570486, 31.73524045944214, 46.65495095934187, 62.80414867401123, 58.002443177359446, 15.477194002696447, 46.89047752107893, 74.89199924468994, 66.24189499446324, 63.7031899860927, 59.95565128326416, 54.07107251031058, 50.271686349596294, 51.47572578702654, 48.61282478060041, 49.92262969698225, 47.82327318191528, 52.060548714229036, 50.57678174972534, 49.910296644483296, 46.96500389916556, 47.08808776310512, 45.59523255484444, 48.50302587236677, 46.91244077682495, 48.33537973676409, 47.80710472379412, 47.17918906893049, 48.07259886605399, 46.90844208853585, 47.654626505715505, 45.211288997105186, 43.72510058539254, 44.91128315244402, 44.34709984915597, 46.02913366045271, 52.9456067766462, 57.23051568440029, 54.27855266843523, 56.04715756007603, 54.20180981499808, 53.46062462670462, 47.387388365609304, 45.302230494362966, 46.54967532839094, 48.0153352873666, 47.061531748090474, 48.47458689553397, 52.34767607280186, 53.010277135031565, 50.79080016272408, 49.66819013868059, 47.98084790366036, 50.48017052241734, 53.948461123875205, 48.755433082580566, 32.17306729725429, 40.09685550417219, 38.003484862191335, 41.978316511426655, 37.4528922353472, 31.801474162510463, 27.972577265330724, 27.868792022977555, 30.38944387435913, 37.71529442923409, 36.238378388541086, 41.37641838618687, 41.09098638807024, 45.37350858960833, 42.89504098892212, 32.26619052886963, 33.782158919743125, 37.87524196079799, 44.15189020974295, 38.15752642495291, 40.17472396578108, 40.90708146776472, 47.45721081324986, 50.27888815743582, 46.56596885408674, 46.800536564418245, 44.60661506652832, 40.52698026384626, 35.55600275312151, 43.77827862330845, 51.18056631088257, 48.70039292744228, 45.60502256665911, 47.78954315185547, 49.61654417855399, 46.62177331107003, 49.138202394757954, 49.275137492588584, 48.80102021353585, 47.73870318276541, 50.51386233738491, 51.443736280713765, 49.467481000082834, 51.50624227523804, 49.36908755983625, 51.169483934129985, 47.350396156311035, 45.33466468538557, 45.595423630305696, 43.458487783159526, 43.00171320778983, 42.35578434807913, 41.91212102345058, 43.84905992235456, 45.84246335710798, 43.19588756561279, 46.44641120093209, 46.373646191188264, 44.548667090279714, 46.35285023280552, 47.02255235399519, 46.06312077386038, 45.4291775567191, 47.316384724208284, 45.2492470060076, 47.007422651563374, 48.02552134650094, 48.08463314601353, 49.934184551239014, 49.14911106654576, 52.24135473796299, 53.94090495790754, 58.24275009972708, 57.165786266326904, 62.35152217320034, 60.31136431012835, 65.40910475594657, 58.47172451019287, 59.086396898542134, 5.754069456032344, 0.5463501002107347, 47.49334144592285, 59.30910750797817, 39.90475170952933, 23.083369629723684, 32.169457708086284, 38.660593373434885, 46.95645066670009, 49.01812710080828, 54.141600200108115, 71.09681674412319, 25.250429391860962, 0.2545162599001612, 0.23079483849661692, 0.3674210129039628, 0.10970142310751335, 0.1540244229670082, 0.128688210355384, 0.36499446311167305, 0.1054916697155152, 0.1972832695714065, 0.1582015116832086], [0.02221683276418064, 0.057224963259484084, 0.06155059686196702, 0.02726449378366981, 0.04970553317772491, 0.08811451002423253, 0.15864870697259903, 0.047202994248696735, 0.1490681046353919, 0.10557439670498882, 0.03801492441977773, 0.11856188944407872, 1.3808614292315073, 40.68022278376988, 50.941426685878206, 32.16814449855259, 36.538867133004324, 45.05777549743652, 20.472656965255737, 23.047365801674978, 29.06390823636736, 44.53239788327898, 59.370175225394114, 18.718266350882395, 23.403188262666973, 67.45159026554653, 58.64305319104876, 62.575205530439106, 55.023892879486084, 54.592097078050884, 46.94527448926653, 46.78686598369053, 42.60247319085257, 45.17645072937012, 46.49809537615095, 48.42490380150931, 45.9316017968314, 44.47086811065674, 40.528852803366526, 41.534416948046, 42.920051029750276, 42.30507639476231, 41.89684888294765, 44.51695203781128, 41.18155268260411, 41.55577918461391, 39.16022791181292, 39.021239621298655, 40.33270863124302, 42.62485681261335, 39.07860394886562, 41.3262072290693, 42.3697259085519, 42.690013544900076, 42.06846591404506, 52.035646370479036, 50.13211441040039, 53.04016828536987, 49.65571812220982, 48.44911479949951, 45.242958886282786, 44.242911611284526, 42.10107381003243, 41.627828529902864, 43.79233135495867, 42.56590829576765, 43.960015705653596, 44.53002854755947, 43.79595831462315, 42.06678097588675, 39.41950341633388, 45.007397583552766, 42.035684313092915, 41.02008349554879, 22.797030891690934, 26.3378016267504, 28.739915473120554, 28.56372479030064, 29.445173263549805, 26.189021587371826, 22.65801133428301, 27.96089560644967, 31.046208449772426, 25.128172363553727, 22.524934223720006, 18.437060594558716, 16.437233550207957, 7.0536088432584485, 0.6940847613981792, 8.761905108179365, 11.776426230158124, 18.770954540797643, 28.85696656363351, 25.074725082942418, 26.497841221945627, 27.852083342415945, 38.189060824257986, 40.37695128577096, 37.66877971376692, 36.3953903062003, 29.44370024544852, 33.75957727432251, 27.456645727157593, 39.22470372063773, 45.409257071358816, 42.4465069770813, 42.5939998626709, 38.14578744343349, 41.23050274167742, 44.51828261784145, 44.516691480364116, 43.03893123354231, 39.139345100947786, 36.16300433022635, 38.6223817552839, 39.904310498918804, 40.9092493057251, 44.42575345720564, 41.846745422908235, 40.17267424719674, 39.543897015707834, 39.61642231260027, 39.04837233679635, 38.501969473702566, 39.117298466818674, 36.43668692452567, 38.78298589161464, 38.55744736535208, 39.585822446005686, 38.131314345768516, 39.83385229110718, 38.42372233527047, 38.87100567136492, 37.15578031539917, 38.691961015973774, 38.42889526912144, 39.95108229773385, 41.157352106911794, 40.97432265962873, 41.23886489868164, 42.88347918646676, 39.720784255436485, 42.37665673664638, 40.85656458990914, 46.3747752734593, 48.56402063369751, 52.854703494480674, 51.63068103790283, 54.69808142525809, 52.80777188709804, 52.15607949665615, 44.00432436806815, 34.89737606048584, 0.7553904546158654, 4.480970570019313, 48.287944384983604, 39.91256148474557, 27.766681296484812, 16.85534313746861, 22.475183384759085, 25.174268450055802, 27.642334597451345, 38.55936506816319, 31.047070026397705, 50.74066890989031, 23.99619790485927, 0.19023094299648488, 0.032913538693849526, 0.019522728132350103, 0.017343534888433557, 0.04545877927115985, 0.1212262250483036, 0.06256073872957911, 0.06852662217404161, 0.04497139774528997, 0.07654417159834079, 0.028318625076540878, 0.0946570939517447, 0.08233514907104628, 0.0585608087213976, 0.06520154952470746, 0.043957395013421774, 0.07924345854137625, 0.009150439973122306, 0.05524772917851806, 0.04578366523076381, 0.11156560307634728, 0.09578281747443335, 2.4073897004127502, 54.171168259211946, 55.37510347366333, 37.27611269269671, 42.26003122329712, 44.833331312452046, 19.849247217178345, 30.59269952774048, 38.737589836120605, 44.990384919302805, 64.02301556723458, 23.056309870311193, 23.877394131251744, 69.22839750562395, 61.63674013955252, 64.3311264855521, 57.802418436322895, 57.10954407283238, 50.628910609654014, 50.40253135136196, 47.649231229509624, 49.328280789511545, 49.78313766207014, 50.399019036974224, 48.48821578707014, 47.015902927943635, 45.62357078279768, 45.49339975629534, 43.59658670425415, 46.0614914212908, 44.45724964141846, 46.192805426461355, 44.918241773332866, 44.167183194841655, 41.68402903420584, 42.643912247249055, 41.75507436479841, 43.824862820761545, 42.50146722793579, 42.31502968924386, 45.082146303994314, 43.24708884102957, 45.55424860545567, 53.134566511426655, 52.60326903206961, 54.31686156136649, 51.873447622571675, 49.370400769369944, 46.55708558218819, 45.752692631312776, 43.720657212393625, 45.33165611539568, 46.0375131879534, 46.57659959793091, 44.16712066105434, 48.6926908493042, 46.2239750453404, 46.1019994190761, 44.33742448261806, 47.8218731198992, 46.27961621965681, 46.14486633028303, 27.79821743283953, 32.29066555840628, 34.58406094142369, 35.3953742980957, 34.14683164869036, 33.39994198935372, 30.960558005741664, 31.379023688180105, 34.655165331704275, 26.569614376340592, 27.23139033998762, 28.698862041745866, 24.812524386814662, 23.85446855000087, 19.035913671766007, 22.947950976235525, 26.375660623822892, 34.131118297576904, 39.858125822884695, 37.181287152426584, 36.311386585235596, 35.92582062312535, 42.78692007064819, 42.42794486454555, 42.84262030465262, 41.913392543792725, 34.46977697099958, 36.290048667362754, 30.922224794115337, 42.22907699857439, 47.155019760131836, 46.69121708188738, 44.86012356621878, 41.841207708631245, 44.327453817640034, 47.0229240826198, 47.559595993586946, 46.62851306370327, 42.31401872634888, 40.16568088531494, 41.04660824366978, 44.9321277482169, 44.8230688231332, 47.085148675101145, 43.5956243787493, 42.88098478317261, 42.22827795573643, 44.259118284497944, 42.68852315630232, 41.62691136768886, 41.70767027991158, 41.391634941101074, 41.32337236404419, 42.429800033569336, 43.2671274457659, 41.3238239969526, 42.42620434079851, 41.16292803628104, 40.67860732759748, 39.23044293267386, 42.02682883398873, 41.62330525262015, 44.39530297688076, 45.45487199510847, 45.863929816654746, 44.95714821134295, 44.96158116204398, 42.80588517870222, 44.693106242588584, 43.60823883329119, 51.140826089041575, 54.05047804968697, 55.73809126445225, 56.408092158181326, 58.2406656401498, 56.22085557665144, 57.12734883172171, 51.552451269967214, 39.80043145588466, 0.4420390475009169, 6.62776243686676, 54.23314619064331, 45.19846609660557, 33.19971922465733, 18.535471405301774, 19.076148952756608, 28.007990496499197, 24.51198353086199, 29.250008787427628, 35.58077655519758, 57.28764724731445, 34.287556988852366, 0.09289101657590695, 0.012158582485946161, 0.035978891886770725, 0.04886193433776498, 0.027480795480577008, 0.06570783842887197, 0.04863678963322725, 0.05173598476020353, 0.09656017433319773, 0.05896160578621285, 0.2882572008030755, 0.13574292537357124, 0.19072847201355866, 0.08932507756565299, 0.09946660444672618, 0.17188522884888308, 0.2803333502795015, 0.1347854853208576, 0.20103417044239386, 0.13593139526035103, 0.20982624723442964, 0.2740866483322212, 3.051413668053491, 62.50912816183907, 65.19664273943219, 43.723314898354666, 50.932602473667686, 62.72280611310686, 29.878563676561626, 30.97671604156494, 43.425094740731375, 53.82489783423287, 67.14682837894985, 23.71451619693211, 28.404824699674332, 72.64611911773682, 61.88623605455671, 67.29519326346261, 60.59883213043213, 61.14953245435442, 52.87868520191738, 53.35543237413679, 49.8966885975429, 51.497511863708496, 51.411329882485525, 54.19040434701102, 51.56631987435477, 49.83205992834908, 46.10531718390328, 47.556997367313926, 45.810095173971995, 48.79864392961775, 48.18209205354963, 51.1124461718968, 46.699582712990896, 46.39948306764875, 43.80713449205671, 44.78420754841396, 46.12872566495623, 47.26552043642317, 44.398499148232595, 44.96767473220825, 46.746222496032715, 46.2011502129691, 45.67034952981131, 57.14775916508266, 53.75936589922224, 56.65074757167271, 53.180435044424875, 52.3283566066197, 48.15339946746826, 46.408376761845176, 43.758222648075645, 45.45837736129761, 46.324710028512136, 47.87535687855312, 47.90901395252773, 51.999098845890586, 50.13526194436209, 48.49288845062256, 45.941568987710134, 52.31299761363438, 50.240825925554546, 51.24877677645002, 34.1811522756304, 37.22957713263375, 38.5221574647086, 40.47525092533657, 39.33218887874058, 39.045884881700786, 34.29354286193848, 36.92373480115618, 36.12142283575875, 27.849529879433767, 28.091278553009033, 27.50343837056841, 27.816428661346436, 24.911444153104508, 15.876753636768886, 35.081016949244905, 38.12555776323591, 44.94607278278896, 49.462634631565635, 41.155052253178184, 36.51693861825125, 37.0177960395813, 47.37629209245954, 46.49471855163574, 44.19563954217093, 45.18421186719622, 38.96673100335257, 39.04055213928223, 35.212640149252756, 44.03273902620588, 49.30322905949184, 48.85728325162615, 48.417483125414165, 43.0531576701573, 47.13399798529488, 50.001672404153005, 49.47291449138096, 49.60071965626308, 45.7774247441973, 43.00170278549194, 43.692718505859375, 48.349567958286826, 46.694635595594136, 50.35681915283203, 45.79612929480416, 46.72530494417463, 46.27451276779175, 45.76062747410366, 46.28909008843558, 44.251812253679546, 45.88765096664429, 42.98479781832014, 44.41757542746407, 45.73631572723389, 46.47140734536307, 43.496518748147146, 44.34111050197056, 44.586621625082834, 43.2912654876709, 41.97515160696847, 44.70748553957258, 45.17981365748814, 47.60842098508562, 49.86906255994524, 50.212612765175955, 49.228223255702424, 49.55562932150704, 45.40123537608555, 47.66558381489345, 46.07535655157906, 53.412504877362935, 56.47704608099801, 60.12121990748814, 61.11016396113804, 64.13442993164062, 58.869599206107004, 59.46578243800572, 56.06555986404419, 48.20715420586722, 0.9783496792827333, 5.772161262375968, 57.56928205490112, 52.56834043775286, 38.526441029139924, 23.256624698638916, 30.20422921861921, 37.955104555402485, 45.23676456723894, 54.204995564052034, 41.646772793361116, 66.12851428985596, 39.54665892464774, 0.281343688922269, 0.16361836530268192, 0.11227705382875033, 0.23726239002176694, 0.13557107959474834, 0.21805288722472532, 0.1567952342863594, 0.18657452134149416, 0.19440364837646484, 0.11822522750922612], [0.016268241784668395, 0.04318898803155337, 0.0734256450086832, 0.2022134643048048, 0.17262613480644567, 0.04376613295504025, 0.014449228499350803, 0.10082583901073251, 0.06206648025129523, 0.0944711889273354, 0.17125815392604896, 0.09537100778626544, 1.364951682942254, 44.32592521395002, 49.79708269664219, 28.87709375790187, 34.22163595472063, 44.87881074632917, 28.078573771885463, 15.030504737581525, 19.224482570375713, 37.23406914302281, 55.513779095241, 35.57259505135672, 14.498792103358678, 52.94805949074881, 60.990224157060894, 60.162506103515625, 56.304914883204866, 53.82904243469238, 46.43372031620571, 46.8019574710301, 48.12735761914934, 51.30877794538225, 50.87019375392369, 50.81148842402867, 46.49285643441336, 47.037987777165, 43.13876642499651, 42.67658962522234, 43.6603399004255, 42.428848130362375, 42.177069732121055, 43.394713742392405, 41.987060819353374, 40.59503786904471, 41.27113233293806, 40.44835444859096, 41.55626903261457, 40.52941908155169, 40.23560060773577, 38.719976152692524, 40.912032059260774, 42.50503165381295, 44.88215977805001, 46.71239519119263, 48.5085357938494, 51.00325175694057, 48.24473353794643, 49.493008681706016, 45.202329295022146, 47.3338212285723, 45.35232353210449, 48.502129554748535, 47.787531648363384, 48.82443216868809, 44.4764336177281, 43.60558809552874, 40.891076292310444, 40.971161229269846, 38.65239797319685, 43.34597560337612, 41.580754484449116, 42.4716351372855, 23.370884350367955, 27.857337917600358, 29.14561210359846, 26.999447311673844, 26.992184707096644, 26.015452112470353, 28.221576384135656, 14.13654169014522, 10.647204995155334, 5.390697343008859, 0.6183457598090172, 0.7714139233742441, 0.15822458187384264, 0.3728179447352886, 0.5278461788381849, 1.7495514111859458, 3.082706183195114, 4.078548278127398, 3.6582812752042497, 1.7302260824612208, 6.959765604564121, 25.771526915686472, 40.26395968028477, 39.314186096191406, 37.65559203284127, 32.79894018173218, 29.8307010105678, 32.952081952776226, 24.528515032359532, 40.827559334891184, 41.6331056867327, 44.97435542515346, 40.996011461530415, 39.84687668936593, 41.29010091509138, 42.10597576413836, 41.48747839246477, 40.903235639844624, 41.70894874845232, 40.542648451668875, 40.726681913648335, 40.367956842694966, 43.75521755218506, 41.48267023903983, 41.905381270817344, 40.490828786577495, 40.94463995524815, 40.26380334581648, 40.123981271471294, 39.37063673564366, 39.21758181708199, 39.40617329733712, 41.12839548928397, 37.645951407296316, 40.260489055088584, 40.45670965739659, 38.738899571555, 37.979398931775776, 38.5434502192906, 40.20212418692452, 38.97081307002476, 40.153250558035715, 39.74787180764334, 41.751812185559956, 42.564900806971956, 42.19509335926601, 42.38634599958147, 40.75485685893467, 39.84730052947998, 41.895674637385774, 47.83596059254238, 51.22459357125418, 50.674275398254395, 51.86188929421561, 53.78428561346871, 54.2543659891401, 53.7393342426845, 46.00252900804792, 26.26414724758693, 0.07649524922349624, 12.712299074445452, 51.92452730451311, 36.88109370640346, 25.611056532178605, 18.56193883078439, 36.118108545030864, 24.3414625780923, 72.04633671896798, 70.81055096217564, 36.00308459145682, 51.77747910363333, 28.47569806235177, 0.18485301014568123, 0.020943175036726252, 0.05812431392925126, 0.028212933069361106, 0.07900793903640338, 0.07924068333314997, 0.03204430140820997, 0.05479755851307085, 0.08450574866895165, 0.015256162699578064, 0.04126328868525369, 0.023350444256461093, 0.06989007044051375, 0.14584880881011486, 0.15426258875855378, 0.04565484196479831, 0.02985370877598013, 0.031120917028082267, 0.037225750873663595, 0.016147452373323695, 0.08816816857350723, 0.10857336542436055, 2.3531876717294966, 55.12195975439889, 54.698446205684114, 37.32434361321585, 41.38512100492205, 51.647919518607004, 26.75317883491516, 20.205458777291433, 28.696258204323904, 40.800023623875205, 62.12121023450579, 41.39211784090315, 15.318328653063093, 50.13461576189314, 65.843478339059, 63.36039366040911, 61.75799315316336, 55.6297584261213, 48.877825600760325, 48.58953441892351, 51.80146081107003, 55.53716325759888, 54.90857015337263, 54.661978585379465, 49.735532079424175, 47.83995580673218, 44.4150949205671, 47.51052434103829, 47.35680934361049, 46.010786942073274, 46.48848601749965, 45.54918336868286, 44.97490780694144, 43.204531124659944, 42.78401572363717, 42.53575311388288, 41.86530406134469, 42.06574222019741, 42.125045095171245, 41.52375841140747, 43.02800866535732, 45.02257592337472, 47.85385915211269, 48.17401129858834, 51.16244193485805, 51.32451214109148, 51.06553888320923, 48.755603313446045, 47.761660030909944, 51.31517028808594, 49.194722516196116, 50.69112477983747, 49.21462563105992, 52.391877038138254, 47.91032368796212, 46.592573506491526, 45.59540973390852, 44.39281552178519, 43.010784081050325, 45.85183647700718, 45.38000862939017, 47.46988432747977, 28.080468893051147, 31.012919630323136, 33.34165702547346, 34.645681040627615, 34.056254931858604, 32.627674034663606, 35.128361974443706, 21.4560216154371, 19.586582728794642, 12.298737951687404, 8.491851210594177, 5.159694927079337, 4.409792355128697, 1.76980345589774, 1.6271106898784637, 6.395405122212001, 10.38977336883545, 10.499372516359601, 11.123955641474042, 5.860200583934784, 12.62970757484436, 33.3689842905317, 43.26601920809065, 45.895693506513325, 41.92461388451712, 35.92427464893886, 35.170867579323904, 34.5822057723999, 28.48535779544285, 44.31383534840175, 43.90638256072998, 48.48639535903931, 43.84319911684309, 42.72238867623465, 43.04267283848354, 45.74371208463396, 44.235407556806294, 43.83390590122768, 44.67758396693638, 44.828071526118684, 45.64406449454171, 44.01380865914481, 46.40494782584054, 45.25638280596052, 44.009761333465576, 44.3801246370588, 43.84384529931204, 44.192009108407156, 43.416253158024375, 41.92128569739205, 40.75930370603289, 42.241100856236045, 42.25318029948643, 41.228717054639546, 43.372753960745676, 42.71350540433611, 40.731757572719026, 41.392517362322124, 41.095749378204346, 43.281597069331575, 42.52906894683838, 43.648760727473665, 44.002333709171836, 45.01279285975865, 46.59165634427752, 45.18893664223807, 46.67956495285034, 45.49943426677159, 44.55632400512695, 44.49185861860003, 49.012558119637625, 55.2022705078125, 55.78958436420986, 55.216267653873985, 57.48485796792166, 57.82363476072039, 57.17257118225098, 52.24730934415545, 27.918153762817383, 0.13696286348359926, 16.424299478530884, 57.18033926827567, 40.708203179495676, 30.185642787388392, 19.591660124914988, 32.59876952852522, 27.662665026528494, 83.85785048348563, 73.34283583504813, 42.12870332172939, 58.166149684361045, 35.215475014277864, 0.08984820770898036, 0.028414724294894507, 0.06754421881799187, 0.019846219702490737, 0.04231705356921468, 0.028824140450784137, 0.034719045739620924, 0.04069647106475063, 0.030097910136516606, 0.042367271945944855, 0.15364029072225094, 0.1902943860207285, 0.08545126686138765, 0.2975452866937433, 0.312837294702019, 0.1287078471588237, 0.14323810461376393, 0.24553622890795979, 0.16394740050392492, 0.13293526960270746, 0.2903050466307572, 0.1927431917616299, 3.395728175129209, 64.57834339141846, 61.880920682634624, 40.60528646196638, 46.55770744596209, 62.72009631565639, 38.26317031042916, 18.803824731281825, 28.11054243360247, 49.31992905480521, 65.1665153503418, 43.95808758054461, 19.08009031840733, 59.35890524727957, 66.9357282093593, 68.24665178571428, 63.70686558314732, 59.39197172437395, 50.51903527123587, 50.960273674556184, 53.68624653135027, 56.91220828465053, 56.08646004540579, 56.457160336630686, 50.34261008671352, 52.462227548871724, 46.84260095868792, 50.955472469329834, 48.82101365498134, 49.355951990400044, 47.57589994158064, 48.568095752171104, 47.86186000279018, 46.07950810023716, 45.838204111371724, 46.632153919764924, 44.20532533100673, 44.13708012444632, 43.5569611276899, 43.88121965953282, 45.86989484514509, 46.5323360988072, 51.89813109806606, 50.72365971973964, 52.85349103382656, 54.95268774032593, 53.709839139665874, 54.95529678889683, 48.97032349450247, 52.97391721180507, 48.929329122815815, 52.31995276042393, 52.59222487040928, 55.34918669291905, 50.567102909088135, 51.04451363427298, 48.681726591927664, 48.12731940405709, 44.42403377805437, 49.39974996021816, 51.64468165806362, 52.252614293779644, 34.44353015082223, 37.40515463692801, 39.434261390141074, 42.33246619360787, 40.46591602052961, 39.59143659046718, 41.58833496911185, 22.657432896750315, 16.493593863078527, 9.526924354689461, 4.732573526246207, 2.4649014600685666, 1.698468906538827, 1.1537792086601257, 0.8257651211959975, 4.544597830091204, 10.365275757653372, 10.77179227556501, 8.138068045888629, 2.8669581030096327, 9.757966722760882, 32.77275936944144, 47.675457205091206, 48.43848058155605, 48.02823461805071, 39.65653426306588, 40.07923487254551, 39.23304155894688, 32.677874769483296, 45.692562920706614, 46.04226228169033, 51.441207136426655, 47.68266248703003, 47.24752460207258, 45.797550201416016, 48.00870670591082, 46.420477049691335, 47.454198769160676, 45.84140723092215, 47.619135107312886, 49.12206867762974, 47.418287004743306, 49.35615348815918, 48.25250857216971, 47.6907501901899, 48.18784863608224, 47.35450254167829, 46.555063656398225, 45.87915331976754, 45.72496584483555, 44.39252717154366, 44.80090754372733, 45.64924785069057, 43.01429986953735, 47.15678807667324, 46.51355511801583, 43.95316825594221, 44.82124144690377, 42.8298773084368, 47.7205023765564, 45.7383029120309, 46.69835983003889, 46.38885579790388, 48.4881706237793, 49.584711006709504, 48.81408977508545, 50.58262171064104, 48.3908645766122, 47.40415436880929, 48.34610775538853, 53.985609667641775, 58.40757874080113, 58.570513997759136, 58.10935163497925, 60.27792263031006, 61.49505942208426, 62.012978145054404, 57.018960407802034, 37.13268102918352, 0.326138508106981, 15.862990992409841, 61.674156188964844, 49.79798248835972, 34.83628402437483, 25.94990975516183, 48.99259941918509, 39.10249880381993, 85.61418833051408, 87.05038792746407, 49.01997879573277, 65.84780706678117, 47.25445195606777, 0.22290644821311745, 0.10871083661913872, 0.11613786380205836, 0.12079888369355883, 0.22753086792571203, 0.1691663661705596, 0.12982038674610002, 0.21087642945349216, 0.1541329071457897, 0.10252855478652886], [0.024514549112479602, 0.058457684969263415, 0.04829629058284419, 0.06668323251817908, 0.021679528024313704, 0.03838933665039284, 0.15648333887968743, 0.0792982027466808, 0.14754643557327135, 0.039486171544662545, 0.17396534580205167, 0.08638514139290367, 1.5038568122046334, 47.8118121283395, 51.743874141148154, 46.68172584261213, 35.611237457820344, 39.14284699303763, 22.547724315098353, 23.793385199138097, 21.80502963066101, 30.2528110231672, 50.09160988671439, 50.52280814307076, 12.174529348100934, 31.882813249315532, 63.20357976640974, 58.856230872017996, 58.27803305217198, 53.23348454066685, 47.295943123953684, 46.49680995941162, 53.613095896584646, 54.03744322913033, 54.04502023969378, 53.67650515692574, 48.03948722566877, 46.12865618297032, 43.31150906426566, 42.712178298405235, 42.89316150120327, 43.52607291085379, 43.97523920876639, 44.79590136664254, 41.69115093776158, 39.78766066687447, 41.822145325796946, 39.47296633039202, 41.38597910744803, 39.06111533301217, 41.432969774518696, 40.507824080330984, 39.92144128254482, 42.814438411167686, 43.609934193747385, 43.55597448348999, 43.885986123766216, 45.065039839063374, 46.701760973249165, 45.04127352578299, 45.8846423966544, 48.09276253836495, 48.722238063812256, 49.70132957186018, 48.734480789729524, 47.415935039520264, 48.92514630726406, 45.618971075330464, 42.27117265973772, 40.895748955862864, 39.94369983673096, 42.207384722573416, 40.12306758335659, 40.95364134652274, 22.933731487819127, 23.799888713019236, 26.370425156184606, 21.808700016566686, 26.45407451902117, 28.80323440687997, 17.611746617725917, 1.5161521924393517, 2.060099844421659, 1.717326100383486, 2.5329019597598483, 0.8521981856652668, 2.0149437189102173, 2.4184351648603166, 2.8106928936072757, 0.6058161492858614, 2.794585015092577, 1.7318991869688034, 1.2265195740120751, 0.5398479976824352, 0.9709829602922712, 9.576594420841761, 32.29053006853376, 35.318721771240234, 35.952797004154746, 33.16040979112898, 26.87706174169268, 28.88181332179478, 25.95794187273298, 43.79051092692784, 43.229127747671946, 42.43930516924177, 42.54804795128958, 39.62697662625994, 40.158638886043, 42.68901995250157, 41.2707918712071, 44.65441172463553, 44.174371106284006, 43.14721890858242, 42.48025090353829, 41.08636583600725, 42.68532351085118, 41.66981996808733, 42.71878603526524, 39.84180450439453, 39.673501764025005, 38.974933351789204, 39.855614049094065, 38.52201502663748, 38.951403277260916, 38.22514976773943, 40.379574230739046, 37.96917118344988, 37.7968419619969, 38.97391891479492, 38.38969700677054, 38.962395327431814, 41.12216642924717, 37.62190021787371, 37.644509656088694, 40.69145802089146, 42.854057039533345, 42.16467761993408, 44.16339642660958, 42.70271485192435, 44.49087544849941, 42.67799663543701, 44.21477140699114, 40.70316226141793, 48.69879136766706, 50.68885966709682, 53.133534703935894, 53.37902498245239, 52.0815600667681, 56.49758495603289, 51.2757705279759, 48.22543839045933, 16.14618914467948, 0.30699920654296875, 31.01404176439558, 50.4183280808585, 33.377214431762695, 18.784923894064768, 27.381834472928727, 28.086367913654872, 27.519646780831472, 47.68526806150164, 54.07705838339669, 29.727853775024414, 47.626448086329866, 32.06220531463623, 0.3475596143731049, 0.11359002587518521, 0.04101786256900855, 0.021550443522366028, 0.13106127801750386, 0.05131126594330583, 0.019032620592042804, 0.07424401930932488, 0.04995970221768532, 0.016524337864081775, 0.05503237573429942, 0.0821778578683734, 0.14900242244558676, 0.03241770262164729, 0.06404447768415723, 0.05568226978981069, 0.1621334185557706, 0.14587029122880527, 0.08472828779901777, 0.05894781116928373, 0.1986522682543312, 0.08986672492963926, 3.975437011037554, 59.747622217450825, 58.432606152125764, 51.06910678318569, 37.39233521052769, 48.34783785683768, 24.598792587007793, 28.422954286847794, 26.189450638634817, 36.811677728380474, 53.720046043395996, 55.11063766479492, 14.589202063424246, 29.98677839551653, 65.29247924259731, 62.297729219709126, 61.67732456752232, 55.89547838483538, 49.72779178619385, 50.94062416894095, 57.5664506639753, 58.231518336704795, 57.858156885419575, 57.41676214763096, 52.95265572411673, 49.26423576899937, 46.45030566624233, 46.59217051097325, 45.74694299697876, 46.98614031927926, 47.835192816598074, 45.737736633845735, 45.06822558811733, 42.89277935028076, 43.312520027160645, 42.33174358095442, 42.66033778871809, 42.3720257622855, 43.30882011141096, 42.39159536361694, 41.05630445480347, 44.55131087984358, 46.2922237260001, 44.152519021715435, 47.11465072631836, 48.288486344473704, 48.277588094983784, 46.921327522822786, 47.92810412815639, 50.63939196722848, 49.86363254274641, 50.96586697442191, 50.14187315532139, 49.292772020612446, 49.65312991823469, 49.41050924573626, 45.023493085588726, 43.8334264755249, 43.9801515851702, 46.324821199689595, 43.71722480228969, 47.610772950308665, 28.211885384150914, 28.80946520396641, 30.837428978511266, 26.495319025857107, 35.81800889968872, 32.71444313866751, 27.084767716271536, 4.640581548213959, 6.378423290593283, 6.639577414308276, 4.8353217499596735, 1.7744559262480055, 0.7343548919473375, 0.39217448607087135, 2.0869431240218024, 1.544612122433526, 2.368659572941916, 1.9437861314841678, 1.4393740551812308, 0.9285619280167988, 1.5168466866016388, 15.21066631589617, 37.27382673536028, 34.910053048815044, 41.3109142439706, 38.33905853543963, 30.99408653804234, 31.109162603105815, 29.455925600869314, 47.61144692557198, 43.859617710113525, 45.718014172145296, 44.784270082201274, 42.46115377971104, 41.899888719831196, 46.36490535736084, 43.945163931165425, 47.46834182739258, 47.756490571158274, 45.98458528518677, 44.584221022469656, 43.47221394947597, 45.149703638894216, 44.66586235591343, 45.42443193708147, 43.4130847794669, 44.104274204799104, 42.145882742745535, 43.02485418319702, 41.91334738050188, 41.56371750150408, 42.74113491603306, 42.16705390385219, 41.47655929837908, 39.59828404017857, 40.892028195517405, 41.226948738098145, 41.96486479895455, 42.704403264181956, 41.35535144805908, 41.4096759387425, 43.4679651260376, 45.46947363444737, 46.61166715621948, 47.83128445489066, 45.958824838910786, 46.90706981931414, 46.59752409798758, 46.90169538770403, 45.00248173304966, 52.75468070166451, 53.19661739894322, 55.09831503459385, 56.27650369916643, 55.98052780968802, 59.882577078683035, 56.16272347314017, 55.268792561122346, 17.077560424804688, 0.46055998653173447, 38.870488030569895, 55.66602454866682, 37.628473213740754, 22.93759294918605, 31.583026272909983, 31.169611930847168, 31.837979997907365, 60.2006447655814, 64.75445938110352, 35.838843073163716, 55.73141404560634, 45.118686880384175, 0.9262786848204476, 0.12340228685310908, 0.049475160360868485, 0.036144505321447334, 0.07536030440990414, 0.039816580779318295, 0.010333078165006424, 0.03676470329186746, 0.05702653247863054, 0.020423169547159756, 0.11688375020665781, 0.16301248781383038, 0.2232319414615631, 0.17223168882940496, 0.21679078494863852, 0.07640866136976651, 0.26018048024603296, 0.10144239664077759, 0.22760957798787526, 0.09907327805246625, 0.41019246780446594, 0.24878163476075443, 5.997302438531603, 73.58882290976388, 65.15817056383405, 58.260804993765696, 47.41492060252598, 54.99496405465262, 30.408242225646973, 31.23889241899763, 26.548797573362076, 42.3246876852853, 59.336288860866, 57.29078088487898, 16.81447035925729, 36.22528450829642, 68.44240338461739, 64.47417599814278, 65.03818907056535, 59.30976063864571, 52.06306396211897, 52.74816329138619, 58.960968017578125, 61.14493274688721, 59.971458435058594, 59.03306252615792, 53.56080027988979, 50.66595493044172, 49.13489505222866, 50.880723748888286, 46.70445340020316, 49.747264112745015, 51.01012005124773, 50.75173739024571, 46.31740747179304, 43.89888892854963, 46.71715470722744, 43.74279069900513, 46.319641317640034, 43.90242208753313, 46.10220091683524, 43.33069998877389, 42.89285230636597, 46.83780322756086, 49.18778473990304, 46.39649534225464, 50.00393751689366, 51.31745277132307, 50.947575841631206, 50.34978757585798, 50.72289889199393, 53.04688719340733, 54.34745447976248, 52.003309454236714, 53.428840092250276, 52.83565500804356, 53.49005719593593, 51.272206102098735, 49.52650594711304, 46.08353110722133, 47.724066802433555, 46.84051997320992, 48.349755559648784, 50.340143476213726, 32.7375111579895, 34.10410370145525, 36.635784081050325, 32.830898421151296, 42.03963783809117, 36.75842326028006, 23.329228162765503, 1.4427736784730638, 3.2649417987891605, 5.372245533125741, 3.5144021042755673, 7.336547306605747, 7.564456905637469, 4.238575279712677, 4.090186510767255, 3.8400400706699918, 5.6208425249372205, 2.666640669107437, 2.1099416613578796, 0.7622422469513757, 0.8131974041461945, 14.954694679805211, 40.88548299244472, 38.35279164995466, 45.199807098933626, 41.82318755558559, 35.6480142729623, 34.824010031563894, 33.430705138615195, 51.30447006225586, 44.38053110667637, 49.03480972562517, 47.19851895741054, 44.273994377681184, 44.45136104311262, 48.85559136526925, 44.775883606501985, 50.30183458328247, 50.300799301692415, 48.249194281441824, 47.6982855115618, 47.88930191312517, 48.343762738364084, 46.452949455806184, 49.763849462781636, 47.19260604040963, 45.05298124040876, 44.89336027417864, 45.301191738673616, 45.31362901415144, 46.49510417665754, 44.80531964983259, 44.43757234300886, 43.90643119812012, 40.68398175920759, 43.10606472832816, 43.60403864724295, 44.52875702721732, 46.205624852861675, 43.60396569115775, 43.359667028699604, 46.16226461955479, 49.30139820916312, 50.361735003335134, 52.21718542916434, 48.61617381232125, 50.119100434439524, 51.022369725363596, 50.673392977033345, 47.96263667515346, 57.32835674285889, 56.92131389890398, 59.002177783421104, 61.690442766462056, 59.46950667245047, 63.075489725385395, 60.646232741219656, 61.54996408735003, 23.68400318281991, 0.4214883659567152, 38.08691188267299, 61.087672642299104, 47.25989586966378, 25.626238346099854, 37.54651573726109, 36.3613406590053, 41.636267117091585, 61.023763111659456, 62.91700826372419, 44.84570952824184, 60.376086780003135, 54.67234877177647, 1.403074711561203, 0.29030089399644304, 0.17642826507134096, 0.07129774561950139, 0.19291794167033263, 0.16302860980587347, 0.08301597075270754, 0.1554753886801856, 0.12870106180863722, 0.11479152818875653], [0.08078673215849058, 0.06574126984924078, 0.07107981374221188, 0.10291391517966986, 0.059657775929995945, 0.03131326813516872, 0.15004463866353035, 0.13122979897473538, 0.11021514197013207, 0.016801432905984775, 0.06609465088695288, 0.027602997941098044, 3.257770606449672, 49.22536407198225, 47.393836293901714, 26.03570784841265, 25.699001618794032, 44.5867258480617, 24.693282876695903, 23.199571302958898, 25.12847113609314, 23.46543369974409, 41.0924837248666, 59.2753392628261, 15.47546216419765, 18.380616903305054, 59.99299785069057, 59.88966424124581, 59.13628496442522, 51.92042786734444, 48.210180146353586, 51.106644426073345, 56.444945403507774, 54.986428192683626, 53.17291014535086, 54.013788087027415, 51.197071756635395, 47.00264923913138, 44.33421441486904, 44.28707436152867, 42.245561599731445, 42.214569159916465, 43.00100449153355, 43.263590812683105, 42.252148491995676, 41.144018513815745, 40.97859927586147, 40.59180695669991, 38.69578947339739, 41.70801074164254, 41.62711633954729, 42.20591517857143, 40.35135759626116, 41.35937792914254, 42.39446496963501, 43.73522411073957, 44.12368399756295, 44.20402601787022, 44.9491925239563, 45.65680054255894, 45.452544348580496, 49.69919300079346, 47.91153267451695, 48.22041484287807, 48.749600069863455, 47.94693374633789, 45.1135174206325, 46.47710139410836, 42.28562143870762, 41.46620300837925, 40.36891916819981, 43.165447507585796, 40.238108907427105, 40.9894871030535, 24.47943295751299, 24.752842835017614, 26.35111263820103, 22.56769691194807, 27.475150517054967, 24.321161678859166, 9.339980466025215, 7.175542346068791, 11.158227631023951, 8.427868723869324, 14.68777963093349, 19.127463136400493, 5.751831701823643, 0.8976014064890998, 1.647322022489139, 1.961833425930568, 1.0509911413703645, 0.973896643945149, 1.7646419214350837, 0.22843847636665615, 2.856329313346318, 14.304711546216692, 26.457314116614207, 39.75840180260794, 30.10611023221697, 35.50870983941214, 28.38342251096453, 27.637469121388026, 28.508992092950002, 42.41340228489467, 44.03155435834612, 43.87588344301496, 42.957345485687256, 41.57392093113491, 41.85609075001308, 40.27750866753714, 43.340955529894146, 43.651831831250874, 45.64412702832903, 42.521776812417166, 43.5738000869751, 43.15696028300694, 42.378390312194824, 42.80373818533761, 42.25598042351859, 39.35481916155134, 40.53115265710013, 39.853821413857595, 38.17199257441929, 37.73931435176304, 38.0165752683367, 39.20710045950753, 40.821146147591726, 37.899209771837505, 37.85858712877546, 38.03332737513951, 40.459812028067454, 37.74321576527187, 41.272146769932334, 39.17405135290963, 38.63126850128174, 40.0890839440482, 41.307870932987754, 42.41058826446533, 43.63856772014073, 42.67264652252197, 44.3024194581168, 42.38857637132917, 42.750622681209016, 45.173129490443635, 46.787546907152446, 50.87463365282331, 51.997125557490754, 52.90716239384243, 53.345308848789756, 60.99965981074742, 54.784610816410606, 50.85475485665457, 8.947389875139509, 2.683105945587158, 48.78462246486119, 47.11878490447998, 29.55580595561436, 14.992845501218524, 21.209631545203074, 19.66139919417245, 32.85607521874564, 24.3341999735151, 37.17924090794155, 26.93509657042367, 37.77035542896816, 47.019401345934185, 1.3792717031070163, 0.12415186448821, 0.03860249164115105, 0.0933839858376554, 0.016540453070774674, 0.044668414896087985, 0.012095509263287698, 0.08576017671397754, 0.0682816371055586, 0.01984748856297561, 0.053172473928758075, 0.01907358375111861, 0.11008494467075382, 0.060889825890106816, 0.1037906367065651, 0.0870555339913283, 0.0522969703722213, 0.05417137586378625, 0.05511631051610623, 0.019744027239669646, 0.16608291305601597, 0.15253103524446487, 6.001088338238852, 58.41732011522566, 53.67586939675467, 29.03916049003601, 32.79356575012207, 50.07035534722464, 26.198861973626272, 27.010743345533097, 27.354338714054652, 30.804755074637278, 42.65367446626936, 64.96819986615861, 18.015845162527903, 17.951240812029155, 60.99239894321987, 64.13190078735352, 62.22314725603376, 55.82655572891235, 49.26793221064976, 55.733439445495605, 59.75062383924212, 58.14564207621983, 56.15396874291556, 57.5424724306379, 52.95892994744437, 47.24797623498099, 46.722133091517854, 46.676257610321045, 44.21033845629011, 43.82561322620937, 44.60874121529715, 46.09664235796247, 44.37179027284895, 44.09214612415859, 44.32404225213187, 42.74990006855556, 41.35300990513393, 44.87280055454799, 43.625772612435476, 43.46987588065011, 41.38204642704555, 44.45677716391427, 43.176311016082764, 47.92654078347342, 46.32054458345686, 46.79020806721279, 48.00221014022827, 49.23744004113333, 48.11998210634504, 51.28236436843872, 51.46005065100533, 51.416732106889995, 51.05554042543684, 49.158782958984375, 48.009200028010774, 49.94196653366089, 46.19158601760864, 46.18546118055071, 43.66184418542044, 46.54464135851179, 44.86455651691982, 45.121070112500874, 30.089813232421875, 30.036895751953125, 31.57747118813651, 28.71698468072074, 35.03964042663574, 31.159047194889613, 16.732297488621303, 14.283046194485255, 12.653967210224696, 8.511100326265607, 3.0420142752783637, 11.281735335077558, 6.819719450814383, 2.6483289088521684, 2.864750095776149, 1.3673323094844818, 1.5690376460552216, 0.8845101861017091, 1.4263909118516105, 0.5501482135483197, 2.917132782084601, 16.092747075217112, 31.50355625152588, 44.0624668938773, 33.59352575029646, 41.57176351547241, 33.221797125680105, 33.09132037843977, 31.74807378223964, 47.93451731545584, 45.63786322729928, 45.540525913238525, 44.57559483391898, 43.828875405447825, 44.37133169174194, 43.444431577410015, 46.005068574632915, 46.66546358380999, 46.76040029525757, 45.581290994371685, 45.4244875226702, 45.93802193232945, 45.45193638120379, 47.151632513318745, 45.234339645930696, 43.30683292661394, 44.45602675846645, 42.04465791157314, 41.13174104690552, 39.60374879837036, 40.928551401410786, 42.46630586896624, 43.1948800768171, 41.7374780518668, 41.16854565484183, 41.01915938513619, 42.88625499180385, 42.12011534827096, 42.28242874145508, 43.453540665762766, 41.89430584226336, 44.209167684827534, 45.60277829851423, 44.89059836523873, 46.808992522103445, 46.53057473046439, 47.072826044900076, 48.689550263541086, 44.9096086365836, 49.32818351473127, 49.56754200799124, 54.38452311924526, 53.770302363804404, 55.16759899684361, 56.272911480494905, 64.01680387769426, 58.83695656912667, 54.17228691918509, 8.687264953340803, 4.056720946516309, 56.35035262789045, 49.16129125867571, 31.46033845629011, 20.29661566870553, 16.175699881144933, 11.518057465553284, 31.79478999546596, 38.56693860462734, 51.39566516876221, 32.81981951849801, 44.27489764349801, 55.93147005353655, 4.292522396360125, 0.13465720149023191, 0.06749710813164711, 0.05822010271783386, 0.04942684866754072, 0.022347389687118784, 0.03997685414339815, 0.05912104794489486, 0.06309412153703825, 0.04230285522394946, 0.11837382667831012, 0.18190713679151876, 0.14615269750356674, 0.12772858541991028, 0.20407954417169094, 0.15805345534213952, 0.16174528295440332, 0.192508798624788, 0.24764042028359004, 0.08067115050341402, 0.3044400710080351, 0.3596044251961367, 7.991144044058664, 68.91809095655168, 60.655904633658274, 36.479682377406526, 36.33641052246094, 61.49678257533482, 31.648693697793142, 29.8489921433585, 29.048288685934885, 36.728646755218506, 50.904827049800325, 70.34916973114014, 20.787518058504375, 22.484645094190324, 66.96712017059326, 67.06644466945103, 65.55605220794678, 58.00757442201887, 52.16301727294922, 57.51976571764265, 61.78891263689314, 61.07337324959891, 57.71535055977957, 60.274121965680806, 55.586853299822124, 50.64808416366577, 49.02918515886579, 49.909118924822124, 46.8550695010594, 46.724742140088765, 47.73208154950823, 48.40880135127476, 49.37167576381138, 46.56187983921596, 46.55902760369437, 45.34674760273525, 42.827473231724326, 48.263712542397634, 47.23617124557495, 44.55239827292306, 43.38994380405971, 45.98168788637434, 44.52232646942139, 48.55558552060808, 47.762003966740195, 49.62885638645717, 50.13308368410383, 50.55948420933315, 49.370873246874126, 52.937112603868755, 54.471729959760395, 51.95804194041661, 53.9577682358878, 51.97258104596819, 49.502402646201, 53.94874252591814, 50.50465250015259, 50.38249274662563, 46.47175822939192, 51.289124965667725, 50.742458071027485, 49.402181829724995, 35.562985692705425, 34.62864405768258, 36.656340326581685, 36.097194467272075, 41.91090508869716, 31.984062399183, 13.717265674046107, 13.328518305506025, 17.18733501434326, 11.512516277176992, 25.64340387071882, 39.7930976322719, 13.662892545972552, 6.092458886759622, 6.384913776602064, 4.8000427058764865, 4.252955879483904, 3.245754999773843, 4.863640870366778, 3.591714927128383, 9.377382619040352, 19.67801407405308, 34.584401403154644, 44.8016232081822, 37.51213952473232, 45.27278750283377, 37.19612503051758, 36.06361729758126, 35.094051769801546, 51.79951531546456, 45.6254745892116, 49.57957281385149, 47.33449867793492, 48.66322701317923, 45.505110945020405, 45.51828472954886, 47.79614394051688, 50.646027496882844, 49.90485273088728, 48.151669366019114, 48.45134169714791, 49.52346611022949, 48.148070199149, 53.01889637538365, 49.052148955208914, 48.468934535980225, 46.83409636361258, 46.12444904872349, 42.68302018301827, 41.52994925635201, 43.8879976272583, 44.42365162713187, 47.12713316508702, 45.130175726754324, 42.77537216459002, 44.46953753062657, 47.2379013470241, 43.85415990012032, 45.860535621643066, 45.83814852578299, 45.0491110937936, 47.16371543066842, 49.49147660391671, 48.99276965005057, 51.009376593998496, 50.18166896275112, 51.72189351490566, 52.76702765056065, 49.29628086090088, 51.9183156149728, 51.90614237104143, 56.99081672940935, 58.658040455409456, 58.93964399610247, 59.09465830666678, 68.34627505711147, 61.29141466958182, 61.12694386073521, 11.467079401016235, 3.1068824401923587, 57.43441752025059, 56.317244461604524, 42.143669741494314, 20.804237161363872, 27.899169547217234, 26.0653749193464, 46.563366753714426, 39.08581617900303, 48.08994851793562, 38.962207726069856, 47.306584290095735, 67.86431326184953, 5.9629718235560825, 0.24220473053199904, 0.1655197697026389, 0.1433947512081691, 0.11406778916716576, 0.20418135156588896, 0.06584541140390293, 0.15658449488026754, 0.13033619549657616, 0.1922784224152565], [0.13799304249031202, 0.028649349829980304, 0.03878466472295778, 0.10160459365163531, 0.0464452470519713, 0.05164620779188616, 0.021619418303349187, 0.04229362036234566, 0.13395403565040656, 0.10512239738766636, 0.14010009728372097, 0.23659655717866762, 6.221919025693621, 52.75527477264404, 49.98065062931606, 48.896853242601665, 24.88264386994498, 48.15145397186279, 32.22974027906145, 23.249806778771536, 24.35332315308707, 18.272812128067017, 27.90001722744533, 65.79481315612793, 22.224045957837784, 6.654114782810211, 52.5229617527553, 62.46586172921317, 57.01357902799334, 57.33945301600865, 47.44030237197876, 55.44703817367554, 58.112822260175435, 55.532146658216206, 52.846275329589844, 55.049080099378315, 51.793373107910156, 43.92691796166556, 42.308710302625386, 41.886930329459055, 42.38300044195992, 42.038453170231406, 43.03975806917463, 44.56157684326172, 42.721089363098145, 40.38018567221505, 39.648616790771484, 41.629221643720356, 39.8581987789699, 42.18458768299648, 40.54540341241019, 42.53710453850882, 42.727169036865234, 40.969900131225586, 41.540896143232075, 44.441803795950754, 42.635921818869456, 45.45405905587332, 41.71724142347063, 45.65039430345808, 46.16092014312744, 50.471471377781455, 47.509165968213765, 47.91546882901873, 48.27940852301461, 49.50006457737514, 46.44038711275373, 43.457473346165244, 41.65288025992257, 44.24421787261963, 40.970515046800884, 42.91832787649972, 39.334610325949534, 41.408435685294016, 27.00287103652954, 24.09895655087062, 26.14665147236415, 25.038448538099015, 27.741212674549647, 19.943282399858745, 24.41038175991603, 24.879089866365703, 14.945634228842598, 17.399150848388672, 39.83195890699114, 17.503184488841466, 2.482931818280901, 2.860048988035747, 1.2026275417634418, 0.10417639065001692, 0.17389659663396223, 0.13864873802023275, 0.39068735444119995, 0.5725178846291133, 2.4419409206935336, 13.378416793687002, 20.604884658540996, 24.415766613824026, 28.148392745426722, 34.236789975847515, 26.35439739908491, 29.269804205213273, 30.759741170065745, 42.45910406112671, 45.17592961447579, 44.26987757001604, 42.719571181706016, 39.99449116843087, 40.578647068568635, 40.43439204352242, 44.0279586655753, 45.81058849607195, 44.30144323621477, 44.8862418447222, 43.51079729625157, 42.49333436148507, 43.16903625215803, 43.00633028575352, 42.380672795431956, 38.72734471729824, 40.16917930330549, 38.11563573564802, 39.715305600847515, 38.43477691922869, 38.6339122908456, 39.42278644016811, 37.467080456869944, 38.84793070384434, 37.814142976488384, 38.52726091657366, 40.02642856325422, 38.48737825666155, 40.90511512756348, 41.12667581013271, 40.265008858272004, 41.81350524084908, 42.68474333626883, 42.880150999341694, 43.82096835545131, 43.985063961574006, 44.32534851346697, 43.70703526905605, 42.63954530443464, 44.20406770706177, 46.984639508383616, 51.76575749261038, 52.172404289245605, 54.81816714150565, 52.51900475365775, 61.22967297690255, 56.08755438668387, 48.15238503047398, 3.9370386600494385, 12.28110863481249, 55.61623723166329, 38.45666027069092, 22.9158068725041, 14.492809704371862, 35.46061788286482, 41.44314193725586, 35.95761210577828, 37.96264682497297, 31.151890550340923, 40.79803991317749, 41.52091312408447, 53.62360157285418, 12.770136748041425, 0.1488256369318281, 0.09957440330513886, 0.034090284657265456, 0.06684627091245991, 0.024823618420798863, 0.07836689307753529, 0.030971805565059185, 0.05348190286063722, 0.03414981592712658, 0.009614946387176002, 0.05117896179269467, 0.13733185082674026, 0.15736893564462662, 0.0784239171605025, 0.03101332512285028, 0.023437086392992308, 0.05376125233513968, 0.1564021860914571, 0.01892524751435433, 0.21403522709650652, 0.26498608237930704, 10.225786328315735, 63.50463131495884, 56.078229904174805, 51.10494211741856, 29.431384563446045, 51.063433579036165, 32.293232917785645, 27.10484801019941, 25.55719930785043, 23.486049004963466, 31.151275634765625, 70.71460328783307, 28.339301449911936, 7.402214731488909, 50.76527942929949, 65.76574189322335, 59.653217043195454, 59.98323563167027, 52.54306289127895, 58.22815193448748, 61.85867255074637, 57.758658681597026, 56.512666021074565, 58.861587933131624, 55.9181364604405, 47.571901253291536, 44.30691841670445, 45.400655201503206, 43.47466318947928, 46.416103158678325, 47.07990625926426, 46.54702459062849, 45.13558489935738, 43.034213406699045, 42.887001923152376, 43.2114063671657, 43.87863492965698, 42.25938504082816, 41.82535539354597, 42.73232807431902, 44.463635035923545, 42.611867155347554, 43.5564295904977, 44.41068628856114, 45.706789357321604, 47.04456772123064, 43.94358321598598, 48.525909764426096, 49.8649457522801, 52.846344811575754, 49.85369314466204, 51.38209881101336, 50.18295785358974, 50.39534343991961, 49.23226015908377, 47.38071462086269, 45.036100591932026, 45.543072428022114, 46.344026020595, 45.10032626560756, 45.57293231146676, 44.83610364368984, 32.94432776314871, 30.525416646684917, 29.88657147543771, 32.064077854156494, 33.11925561087472, 22.843316316604614, 27.179978881563457, 23.453720773969376, 13.097323945590428, 8.652302486555916, 33.7079313141959, 32.2481495312282, 11.842196140970502, 2.7920456656387875, 1.727645369512694, 1.032444987978254, 1.025144602571215, 0.09795567659395081, 0.6629504806229046, 1.3708054316895348, 5.244703965527671, 18.140615701675415, 24.497970751353673, 29.106830733163015, 32.7765530858721, 38.0582401411874, 31.796124049595424, 33.52330725533621, 34.982001645224436, 44.48154749189104, 47.398786885397776, 45.84331103733608, 44.688013213021414, 44.60774414879935, 43.63604204995291, 44.48873887743269, 45.43506962912423, 47.957964011601035, 48.207744802747456, 47.595139503479004, 47.34479243414742, 46.36488103866577, 45.40737758363996, 45.474462441035676, 45.23293958391462, 44.10046311787197, 43.133520535060335, 41.46390315464565, 43.04336765834263, 41.79408502578735, 41.39650215421404, 41.168903487069265, 40.47879450661795, 41.697546754564556, 41.1959354536874, 41.54493999481201, 41.28709929330008, 40.84173018591744, 42.38858331952776, 43.27082388741629, 43.764597620282856, 46.61159767423357, 45.38588333129883, 47.400440556662424, 46.40464905330113, 48.27109152930123, 47.08473525728498, 47.57826927730015, 46.993623529161724, 46.80170038768223, 49.97804505484444, 53.765004362378804, 55.0134254183088, 57.635071073259624, 56.64925718307495, 63.65577547890799, 59.919701303754536, 47.67659670966012, 3.8962119136537825, 16.732323544366018, 61.176581791469026, 41.31443003245762, 28.84895702770778, 17.528251852308, 22.883506434304373, 23.436949559620448, 40.1165988104684, 37.35837588991438, 39.922817025865825, 40.44925076620919, 48.144905294690815, 65.74266692570278, 27.440748248781475, 0.32437062582799364, 0.06053812761924096, 0.031212481936173778, 0.02022812974506191, 0.037545354438147376, 0.06333142558911017, 0.012786603116962527, 0.028289643149556856, 0.08465064303683383, 0.18710254372230598, 0.10045577279691185, 0.14756436246846402, 0.2714996657201222, 0.1723231417792184, 0.18492049723863602, 0.15299615742904799, 0.21768067005489553, 0.2825507755790438, 0.24435400377426827, 0.3633861722690718, 0.3720328254359109, 11.647995727402822, 76.16777188437325, 61.3789758682251, 61.79231725420271, 34.64832135609218, 64.39059611729213, 41.95974050249372, 30.24155146735055, 28.161517892565044, 28.49098583630153, 38.32599244798933, 74.8884973526001, 28.724744081497192, 9.333132147789001, 59.97912229810442, 66.58250958578927, 64.59557492392403, 62.560232162475586, 54.65402289799282, 61.76275266919817, 63.09906496320452, 58.94885035923549, 58.49604320526123, 61.062214442661826, 58.096202169145855, 48.68780626569475, 46.543710299900596, 47.1939366204398, 46.15429503577096, 48.26421628679548, 50.3500029700143, 50.85775647844587, 46.30128765106201, 44.869038105010986, 45.309724126543315, 45.16123764855521, 44.55018874577114, 45.36560501371111, 45.54911388669695, 44.99122217723301, 47.711994307381765, 44.67982128688267, 46.2218975339617, 47.06353282928467, 47.686793191092356, 49.89978749411446, 45.93064294542585, 51.4025855745588, 53.31839500154768, 55.311051504952566, 51.999331610543386, 53.17697484152657, 54.299334730420796, 55.93426322937012, 52.358845302036826, 50.081128529139924, 48.49337135042463, 50.68009451457432, 49.81604780469622, 49.20305688040597, 49.28421878814697, 50.75857441765921, 36.68788167408535, 38.576700823647634, 37.4127698625837, 37.31249693461827, 38.86890731539045, 27.16996305329459, 32.256779193878174, 35.910934107644216, 20.62744198526655, 22.345267704554967, 57.91617781775338, 51.433049951280864, 30.534001146044048, 7.859195147241865, 2.0402347275188992, 1.1623501373188836, 1.1240231139319283, 1.4957963590111052, 1.2072209524256843, 4.280079909733363, 6.510553274835859, 19.30625765664237, 27.64232243810381, 29.088254724230083, 34.914117744990754, 41.33945049558367, 35.45588615962437, 40.327368940625874, 38.208644321986604, 47.14253037316458, 50.3825101171221, 49.11105925696236, 47.99589422770909, 46.062960965292795, 46.361445154462544, 48.88009418760027, 49.69250535964966, 50.92920133045742, 50.55291816166469, 51.20143869944981, 49.54301486696516, 47.896993568965364, 47.39821365901402, 49.37751919882638, 50.8491268157959, 47.233728953770225, 46.707600934164866, 43.61716032028198, 46.660314968654085, 44.28331538609096, 43.681528432028635, 46.562498228890554, 43.1503039087568, 46.065378938402446, 43.67452464784895, 44.81146880558559, 45.34437479291643, 43.21648550033569, 46.66389329092843, 46.307884965624126, 45.91703142438616, 47.28778941290719, 47.13426201684134, 49.53848464148385, 49.43034635271345, 51.67153991971697, 49.918578897203716, 49.45163563319615, 49.79156582696097, 49.685411248888286, 52.11995581218174, 58.188335282461985, 58.042770521981375, 62.73778642926897, 57.01311002458845, 67.56576306479317, 62.893231528145925, 54.065871783665244, 5.142855533531733, 15.516187293188912, 66.10830198015485, 49.506849493299214, 36.87508698872158, 19.178579296384537, 45.29310056141445, 50.96598161969866, 50.0960567338126, 50.419516222817556, 40.4251127243042, 55.6302934374128, 53.763871806008474, 76.18706703186035, 27.384613752365112, 0.4005992854280131, 0.2634648068674973, 0.11240279315305607, 0.118673603449549, 0.15648055688611098, 0.16304097271391324, 0.16402611056608812, 0.12190257518419198, 0.1690225438880069], [0.023775582068732808, 0.027586711404312934, 0.07814901548304728, 0.0795979116644178, 0.20103057420679502, 0.05425394679020558, 0.09841445447610957, 0.04580101876386574, 0.2241640178752797, 0.06279414799064398, 0.161825865773218, 0.1758432321782623, 9.988158805029732, 54.56929656437465, 52.79184661592756, 28.492642981665476, 33.88004514149257, 46.52977221352713, 33.59521416255406, 26.572555201394216, 22.139811209269933, 19.305069514683314, 19.932022844042095, 55.29649155480521, 45.542728492191856, 5.775372632912227, 29.143882002149308, 66.73288249969482, 55.653295448848176, 55.7934684072222, 50.925140108381, 58.35001291547503, 56.77701023646763, 55.28942176273891, 55.093301909310476, 55.784633772713796, 52.72377858843122, 47.58571774618966, 42.04539442062378, 42.1469076020377, 41.28812762669155, 42.491197790418354, 44.274355684007915, 42.113055978502544, 41.694006647382466, 42.95133876800537, 39.55748769215175, 42.44968230383736, 41.22373172215053, 42.416403906685964, 41.20898764474051, 43.69038738523211, 41.4731616292681, 43.31114080974034, 41.53451074872698, 44.47091327394758, 43.430573395320344, 44.00314317430769, 42.57732418605259, 44.453681741442, 47.60649633407593, 47.56654071807861, 45.884545121874126, 48.500771181924, 47.211974143981934, 47.04711076191494, 44.579829760960166, 43.533365045275005, 43.18952996390206, 42.75283220836094, 40.4651551927839, 41.58315508706229, 39.543459279196604, 40.890037536621094, 28.82609919139317, 21.52335660798209, 23.04593620981489, 21.681707790919713, 29.025689670017787, 31.366468293326243, 28.837610619408743, 18.92391218457903, 19.932354620524816, 47.0061685017177, 45.98841721670968, 34.35777200971331, 12.08403514112745, 1.5335337626082557, 5.302959833826337, 4.659558815615518, 0.8637165618794305, 1.4694391276155199, 2.85096942952701, 3.7944846408707753, 10.412553037915911, 15.983828851154872, 24.299566677638463, 30.48878574371338, 37.161787033081055, 34.85558959415981, 24.998430388314382, 25.187404019492014, 29.054359674453735, 41.50349051611764, 45.64528737749372, 43.40899576459612, 43.73815972464425, 43.53519589560372, 40.93667037146432, 40.42306995391846, 41.705238410404746, 42.946857179914204, 43.34548922947475, 44.0368732043675, 43.804066862378804, 42.71614919389997, 42.47862849916731, 42.36174937656948, 38.44048833847046, 39.21617480686733, 39.72144086020333, 38.41208757672991, 38.86893163408552, 40.74567828859602, 37.88680028915405, 39.52615131650652, 38.07769162314278, 37.0626779283796, 37.667449133736746, 38.11930438450405, 37.869197028023855, 40.39950861249651, 39.97037049702236, 41.54298407690865, 44.894249643598286, 47.37364830289568, 46.98198529652187, 47.539015429360525, 46.60002892357962, 45.0484162739345, 45.41483300072806, 42.95160627365112, 43.326489380427766, 43.333322933741975, 46.90266466140747, 51.22455188206264, 48.364583015441895, 52.613767760140554, 55.99165187563215, 60.69578034537179, 58.02789095469883, 38.53302444730486, 2.523747056722641, 24.761743477412633, 58.66125052315848, 36.761181695120676, 19.29710861614772, 29.664830139705114, 72.12803363800049, 40.55058329445975, 25.220513922827585, 30.05745894568307, 24.564306940351212, 39.39915214266096, 46.123347759246826, 47.86666815621512, 51.02802208491734, 4.6651021753038675, 0.13877736111836775, 0.07718719887946333, 0.04384433411593948, 0.10097570704030139, 0.1247573619974511, 0.08131714298256806, 0.09475385983075414, 0.023160764881010567, 0.01622799617637481, 0.03166163479909301, 0.17703463110540593, 0.014993057353422046, 0.15004769207111426, 0.16014151115502628, 0.10794491986078875, 0.01986921695061028, 0.23757630746279443, 0.018480956354843717, 0.21300217110131467, 0.1877839828708342, 14.471833092825753, 63.83949974605015, 56.9561174256461, 26.01472428866795, 34.01363468170166, 49.390175342559814, 29.144194671085902, 25.418832881110056, 21.437694004603795, 24.342951229640416, 24.698754583086284, 58.50044141496931, 53.450671332223074, 8.311204995427813, 25.94158581324986, 69.47980417524064, 56.92913062231881, 60.25125544411795, 53.407804421016145, 60.892546381269185, 57.97883319854736, 59.0925668988909, 57.0620288167681, 58.92600468226841, 54.56552716663906, 51.29399217878069, 45.830762590680806, 45.918733733040945, 44.422911643981934, 46.98846101760864, 44.752697467803955, 44.21586227416992, 44.7757203238351, 45.936517647334504, 41.883748054504395, 43.741536549159456, 41.70692682266235, 43.697811535426546, 43.93880632945469, 45.28780950818743, 44.93126617159162, 46.66813169206892, 43.3740428515843, 45.219522612435476, 44.42282131740025, 45.75499595914568, 44.649297850472585, 46.26197821753365, 49.49636813572475, 50.31105831691197, 49.334798199789866, 49.76549965994698, 50.30180679048811, 48.60607113157, 47.76435940606253, 45.800214835575645, 46.49010842187064, 46.537759167807444, 44.82984331675938, 45.242013931274414, 43.93695116043091, 46.58155018942696, 33.82374388831002, 25.152895791190012, 26.815853323255265, 28.001011031014578, 37.34930501665388, 32.72249262673514, 28.910624027252197, 20.84999452318464, 14.493738157408577, 35.7250975881304, 52.431356702532085, 38.67709534508841, 12.85042839390891, 4.507538744381495, 3.906915613583156, 2.3089411088398526, 3.3345931470394135, 1.7153498807123728, 5.107910002980914, 6.624545420919146, 7.130070728915078, 14.617846012115479, 27.2904691355569, 30.56725869859968, 38.52416549410139, 39.69453396115984, 32.13420254843575, 31.503021240234375, 31.999793120792933, 43.079942975725444, 47.41540002822876, 46.65153244563511, 47.19465575899397, 47.05523668016706, 44.52976451601301, 44.879773071834016, 44.30719287054879, 46.17921475001744, 45.16276625224522, 46.5561649458749, 45.90983656474522, 44.23053339549473, 45.387818404606406, 46.80986104692732, 42.52121748243059, 43.09134496961321, 43.370822361537385, 41.51086950302124, 40.2769319670541, 45.39566986901419, 40.06730828966413, 42.094955921173096, 41.00789288112095, 40.30457190104893, 42.557424545288086, 41.63708700452532, 39.982852935791016, 43.74660873413086, 42.883486134665354, 46.63966144834246, 49.15844944545201, 51.179808957236155, 49.982634340013774, 50.36256531306675, 50.856009006500244, 49.9445721081325, 48.34990842001778, 46.09902559007917, 48.989173957279746, 46.90951211111886, 50.877249649592805, 53.7717684337071, 52.20672491618565, 55.55219221115112, 58.52069541386196, 64.81807708740234, 61.630868911743164, 38.52195596694946, 3.56520277261734, 28.91729256084987, 63.666600772312705, 38.03619350705828, 25.153845957347325, 32.15460245949881, 80.07351412091936, 49.39512593405587, 33.65677867616926, 31.09128836223057, 29.952794756208146, 47.418474606105256, 48.1230080468314, 57.652719497680664, 63.79098047528948, 10.866626501083374, 0.40682305289166315, 0.23541986889072827, 0.028690506371536424, 0.07784801056342465, 0.0651132178359798, 0.06751822414142744, 0.09153946981366191, 0.07702405870492969, 0.1253885217010975, 0.10823615387614284, 0.2963935684944902, 0.182293779615845, 0.33211827437792507, 0.2345158431146826, 0.15515531014118875, 0.07620240029479776, 0.3563934074980872, 0.09920633198427302, 0.4142860695719719, 0.38787091842719484, 19.868353026253835, 75.49156624930245, 62.96451309749058, 38.99834878104073, 43.100488798958914, 63.718705313546316, 43.8959950038365, 34.179515974862234, 27.60836485454014, 28.41630138669695, 30.51157236099243, 64.59143379756382, 53.40177685873849, 8.543821130480085, 34.08084808077131, 71.73009640829903, 58.461343901497976, 61.375209944588796, 56.51840870720999, 63.22521645682198, 58.699493408203125, 59.57668958391462, 59.98831476484026, 61.86526639120919, 58.40825966426304, 53.721116065979004, 48.61837639127459, 48.799971035548616, 47.55566678728376, 50.117634364536826, 47.89329712731497, 47.73211281640189, 46.460592474256245, 47.551525660923545, 43.48321989604405, 46.25857360022408, 45.314355100904194, 47.901325770786826, 46.38467993055071, 47.639191082545686, 47.85027388163975, 48.35929543631417, 45.83391012464251, 48.259838921683176, 48.33607108252389, 49.39924621582031, 46.94964838027954, 48.96024513244629, 51.7899545942034, 53.67496265683855, 50.84286648886544, 53.807940755571636, 53.42043277195522, 52.424874033246724, 51.38639974594116, 50.263240814208984, 49.910508564540315, 50.75016014916556, 48.25399201256888, 50.373946462358745, 48.798289571489605, 49.713752950940815, 40.61068173817226, 31.403505665915354, 31.178415298461914, 34.61959055491856, 38.86101416179112, 37.95817913327898, 37.08415828432356, 22.28507546016148, 27.308327742985316, 52.79552568708147, 55.75023324148995, 52.2328953061785, 36.8624621118818, 33.36435679027012, 17.616990770612443, 11.087733813694545, 10.335168344633919, 8.406972885131836, 13.570310405322484, 22.45759575707572, 20.38737998689924, 19.455466747283936, 31.899245738983154, 36.74569763456072, 41.98305170876639, 43.16608674185616, 33.63146638870239, 36.23439359664917, 36.03444528579712, 49.2332363809858, 50.31350755691528, 50.943674428122385, 49.49477352414812, 49.593288557870046, 46.14307369504656, 47.325441701071604, 48.48897314071655, 49.097624914986746, 47.63584899902344, 49.925447191510884, 51.37552234104702, 47.18249641145979, 48.874250752585276, 49.89778988701956, 44.83814293997628, 45.56387880870274, 45.56706803185599, 44.02131271362305, 43.322011266435894, 48.85062687737601, 41.54388039452689, 46.95945576259068, 42.31341075897217, 42.98407173156738, 42.690013544900076, 43.61413785389492, 43.46745443344116, 45.347060271671836, 44.81996645246233, 48.23825781685965, 51.07799352918352, 55.25867598397391, 52.55505200794765, 54.79416806357247, 53.33885397229876, 53.11311742237636, 51.00680228642055, 50.1976671900068, 50.9426599911281, 50.55994279044015, 51.743557998112266, 56.4650673866272, 55.10769510269165, 58.798887389046804, 60.51639175415039, 67.2948111125401, 63.352090563092915, 43.98532451902117, 4.6113218154226026, 29.93084192276001, 68.26865673065186, 46.1801631791251, 31.420250824519567, 34.782567501068115, 74.63805648258754, 41.09890733446394, 30.231956005096436, 43.165548256465364, 31.905700615474156, 54.703087602342876, 59.97158350263323, 62.73577839987618, 68.64199733734131, 11.505550708089556, 0.4825018548539707, 0.3291855917445251, 0.12944050213055952, 0.20495959052017756, 0.31172387301921844, 0.2021760634545769, 0.24798755879913056, 0.24079706892371178], [0.1126632352492639, 0.06342849002352782, 0.13134183867701463, 0.042995320566530736, 0.042860380307372124, 0.046615654336554666, 0.08115133616541113, 0.01990940997243992, 0.01277228772440659, 0.03922670653888157, 0.0856214841561658, 0.16683395632675715, 12.89528248991285, 56.278991154261995, 46.01385109765189, 40.50693471091134, 26.31587311199733, 47.44722972597395, 40.10327216557094, 36.53699459348406, 26.818568331854685, 14.540483900478907, 25.351174797330582, 43.86106988361904, 62.53944315229143, 19.472267491476877, 9.79395318031311, 64.54930686950684, 57.4114294052124, 61.512360436575754, 53.689835275922505, 59.225374766758506, 56.69165161677769, 57.81067637034825, 56.029686314719065, 57.302287101745605, 50.904014110565186, 44.954883098602295, 42.17671537399292, 43.42881550107683, 42.31471702030727, 41.84706851414272, 41.020073073250906, 41.42914131709507, 40.36141511372158, 42.1937940461295, 40.10454716001238, 44.363820689065115, 39.923185280391145, 41.891620363507954, 42.1578996522086, 41.18669087546212, 40.98400844846453, 42.516089711870464, 43.01919140134539, 41.84147868837629, 40.64783028193882, 40.94763810294015, 41.49957520621163, 40.91323062351772, 44.94679192134312, 45.75031634739467, 45.56646006447928, 45.54305853162493, 48.26720053809029, 45.77741779599871, 45.22830513545445, 44.015410218920024, 42.435535771506174, 42.51160464968, 43.55767331804548, 43.07412038530622, 39.238096373421804, 39.0597882270813, 28.093399490628922, 23.80116023336138, 23.2042578629085, 21.487057481493267, 26.77310974257333, 45.898128850119456, 32.99317012514387, 21.992278371538433, 52.63090549196516, 49.193322454180034, 49.35454150608608, 38.39256313868931, 32.806610992976594, 18.804307631083898, 4.641807036740439, 2.122897663286754, 1.768205913049834, 2.5161489844322205, 2.823008792740958, 6.111619847161429, 15.448603902544294, 22.041822501591273, 20.317442893981934, 36.71307584217617, 41.10096747534615, 30.58655732018607, 25.63976127760751, 26.786156722477504, 29.237898077283585, 38.83752925055367, 48.7680127961295, 43.0982723236084, 45.00079679489136, 42.29506056649344, 40.76402153287615, 40.80024944032942, 41.85910626820156, 43.776016984667095, 44.74542270387922, 42.68672704696655, 42.08282784053257, 41.78257533482143, 40.53038835525513, 39.78381136485508, 37.53656939097813, 39.551967348371235, 37.74733257293701, 38.92708110809326, 38.25032656533377, 38.696890762874055, 39.118712425231934, 38.150428840092246, 37.237445967538015, 37.706543173108784, 39.271944522857666, 39.674856662750244, 38.9249758039202, 40.054318632398335, 39.588129247937886, 43.68023606709072, 49.96746294839041, 49.93781845910208, 51.77158008302961, 51.93425130844116, 50.37072597231184, 48.69026245389666, 47.42321327754429, 44.23387895311628, 45.085759367261616, 45.48711163657052, 49.1515394619533, 49.200576373508994, 50.62340416227068, 53.94475078582764, 57.87018769127982, 59.05591515132359, 57.737424986703054, 29.486171109335764, 2.870132778372083, 41.53098106384277, 51.39112452098301, 29.713359832763672, 16.655858618872507, 43.16264043535505, 50.35019751957485, 18.101294108799525, 20.872211388179235, 43.00416592189244, 27.55253086771284, 27.36012656348092, 32.83753047670637, 48.03852142606463, 61.03116294315883, 29.050836937768118, 0.03851538131545697, 0.05429516100723829, 0.0812877556309104, 0.10644368148807969, 0.05512685834297112, 0.07771417631634644, 0.08115831829075303, 0.15521664970687457, 0.08921465956206832, 0.08277864634458508, 0.0698164968884417, 0.05196735502353736, 0.03136626511280026, 0.08635593724570104, 0.05767150715525661, 0.03552673989906907, 0.07228160782584123, 0.06588697167379515, 0.38657790209565845, 0.11306678038090467, 19.287551368985856, 66.96960762568882, 56.63309914725167, 42.07476098196847, 28.906566279275076, 52.07645661490304, 30.021394320896693, 32.292402608054026, 29.590967314583914, 17.785847629819596, 28.990128789629253, 49.54149668557303, 63.90336063929966, 26.32350049700056, 9.119854586465017, 64.02166761670793, 60.43128326960972, 66.16873741149902, 56.954255308423726, 61.9370482308524, 58.83976364135742, 59.257558822631836, 59.15438502175467, 60.31878498622349, 53.85458748681204, 49.95614433288574, 44.63643326078142, 46.18285213197981, 45.2424099785941, 44.84236397062029, 43.25994995662144, 44.81343861988613, 45.33391775403704, 44.883504254477366, 41.859582219805034, 45.88772739682879, 43.32018041610718, 44.81516177313668, 42.37068475995745, 42.33548171179635, 43.67750195094517, 45.24995572226388, 44.255755356379915, 43.37791994639805, 42.08384575162615, 43.537155287606375, 44.158504894801546, 43.90330798285348, 45.627194268362864, 47.069258144923616, 46.445747647966655, 48.80018295560564, 49.15835564477103, 48.39261204855782, 47.60065637316023, 47.31424815314156, 46.14576612200056, 44.63511310304914, 46.56283521652222, 46.870442390441895, 44.169844354902, 44.921215602329795, 30.973537240709575, 28.786623001098633, 25.28938446726118, 28.807432855878556, 32.57617398670742, 47.83263240541731, 37.14266906465803, 17.445912224905832, 43.0245623588562, 51.004471165793284, 53.025101116725374, 46.044815744672505, 33.87298924582345, 17.18891051837376, 3.9874708567346846, 6.452289589813777, 6.283041460173471, 6.38855550118855, 7.10169254881995, 17.55352939878191, 26.76573770386832, 26.344925267355784, 25.588858774730138, 40.68899488449097, 42.76871231624058, 34.047399452754426, 32.73069150107247, 33.340837138039724, 34.007978848048616, 40.42561994280134, 50.69023888451712, 44.14062023162842, 46.791010584150044, 45.58813149588448, 44.76616655077253, 43.7854665347508, 43.4534329686846, 46.869389738355366, 47.01233850206648, 45.07571922029768, 45.18496227264404, 44.12059552328927, 43.068402017865864, 42.053502968379426, 40.19418934413365, 40.24842003413609, 41.34412315913609, 41.91042913709368, 42.671920435769216, 41.61723600115095, 42.4959260395595, 40.37055894306728, 41.501260144369944, 40.502310684749055, 43.7519588470459, 42.653406960623606, 42.023754256112234, 43.189335414341514, 42.78881345476423, 46.50883034297398, 54.56524576459612, 51.67914124897548, 53.460798331669395, 53.73294537408011, 54.96944679532732, 52.566843100956504, 51.976058619362966, 47.81779105322701, 48.804525579724995, 45.34220348085676, 51.73078720910208, 52.03167200088501, 55.19568708964756, 55.220599855695454, 62.00232655661446, 60.35886914389474, 61.97659737723214, 27.0940192426954, 4.576480507850647, 50.70897470201765, 57.18122863769531, 30.75166736330305, 21.070554665156774, 36.35195016860962, 58.99047701699393, 27.62482861110142, 27.579277958188737, 43.434158665793284, 27.083814076014928, 36.938548360552105, 40.92091185706002, 62.31063897269112, 65.39440931592668, 46.26915570667812, 0.5667281353047916, 0.024322338801409518, 0.07855710001396281, 0.06550531608185597, 0.05974237567612103, 0.09504715659256492, 0.022350872268102, 0.09375488664954901, 0.1572706430618252, 0.12730994288410458, 0.25311771780252457, 0.14835693208234652, 0.16998283378779888, 0.15268377347716264, 0.14212198236158916, 0.18705695973975317, 0.22414799087813922, 0.18796224759093352, 0.44376057226743015, 0.3057838960417679, 24.230690922055924, 78.56395544324602, 59.327805110386436, 50.694571086338584, 35.916635104588096, 66.36822019304547, 51.63290793555123, 46.980435848236084, 33.73376819065639, 20.601276806422643, 38.90150826317923, 53.30051728657314, 71.22189821515764, 23.685568264552526, 12.033731920378548, 70.7897480555943, 61.6185428074428, 69.15937410082135, 57.83893469401768, 64.03185367584229, 60.318520954677034, 60.27549770900181, 62.615970611572266, 65.21694537571499, 54.537928921835764, 52.85966450827462, 48.25855350494385, 48.28314317975725, 47.03940520967756, 46.910370213644846, 46.30247926712036, 46.677734102521626, 47.00479275839669, 47.081959451947895, 44.78829656328474, 49.48332289287022, 46.56357519967215, 46.534983362470356, 46.05279575075422, 45.48891469410488, 44.74065623964582, 47.36596359525408, 45.55048268181937, 46.13872759682791, 45.13164527075631, 46.65797689982823, 47.08263342721121, 47.54924317768642, 48.77051067352295, 51.581633704049246, 49.24309240068708, 52.93268660136631, 52.26999521255493, 52.329364095415386, 50.9371292250497, 51.38779285975865, 49.350490706307546, 48.65029641560146, 49.885856355939595, 51.59568643569946, 46.96246085848127, 49.398047651563374, 38.8156042098999, 32.030386039188926, 29.90569986615862, 33.546694891793386, 35.51210403442383, 48.57436997549874, 37.11342062268938, 25.13997040476118, 58.28487702778408, 53.44202429907662, 56.26712015696934, 48.32528747831072, 47.77294737952096, 37.78248698370797, 31.789627483912877, 25.885744878223964, 17.388963052204677, 21.155979292733328, 19.698836088180542, 31.076189926692418, 34.82874870300293, 31.134638173239573, 26.137160233088903, 45.92415680204119, 45.01597513471331, 37.59749814442226, 31.81043039049421, 34.1745480128697, 37.59401362282889, 42.789494378226145, 53.07568400246756, 47.04314334051949, 49.83443621226719, 47.891045910971506, 47.19590296064104, 46.94851234980992, 46.7989558492388, 49.57611608505249, 49.861680098942344, 49.44731732777187, 47.7342528615679, 47.17113610676357, 46.600984300885884, 45.13000896998814, 41.927876063755576, 45.510304723467144, 43.73612042835781, 43.688285555158345, 42.60861887250628, 43.137303829193115, 45.65685960224697, 43.56343684877668, 43.842413970402305, 42.82571186338152, 46.08592823573521, 45.886997835976736, 43.78936447416033, 45.67441422598702, 44.67900834764753, 48.32643740517752, 56.43676389966692, 55.62338692801339, 57.0325927734375, 57.99516493933541, 57.46309273583548, 57.130027362278526, 53.763538292476106, 50.89004823139736, 51.70813608169556, 50.32555225917271, 55.17349106924874, 55.78499507904053, 56.229426179613384, 60.07430567060198, 63.4676946912493, 64.85975238255092, 61.6346834727696, 38.18434994561331, 4.639474179063525, 50.44825744628906, 59.97628743307931, 40.93397099631173, 26.602713857378276, 50.55757692881993, 54.093529088156565, 19.338295800345286, 27.61715258870806, 57.08518368857247, 36.747983591897146, 37.91747311183384, 45.65988554273333, 60.99533803122384, 76.08589431217739, 50.4147184916905, 0.5590302369424275, 0.15317781482424053, 0.2179910455431257, 0.15942381109510148, 0.14920895493456296, 0.27174122418676105, 0.1457729350243296, 0.22728014923632145], [0.028464279403643947, 0.08281032035925559, 0.0649948406166264, 0.04946902301162481, 0.03796527261978813, 0.07051916061235325, 0.06998418324760028, 0.021374331454613378, 0.15422992408275604, 0.028954503991241966, 0.06871821332190718, 0.06986085950796093, 23.411196061543055, 59.280710220336914, 46.697894300733296, 27.618870530809673, 25.76112025124686, 49.40529114859444, 30.315389973776682, 36.70452260971069, 19.781311205455236, 15.826799562999181, 19.80485691343035, 47.37679583685738, 51.74639981133597, 52.763595240456716, 8.213210208075386, 27.29591826030186, 68.16002164568219, 52.69593368257795, 59.812379428318565, 56.700250012534006, 57.93051542554583, 57.31606190545218, 56.714028290339876, 54.96990190233503, 50.82630893162319, 44.01805053438459, 44.68499074663435, 40.68565280096871, 43.135212421417236, 41.83119535446167, 41.07889304842268, 40.8947935785566, 41.76627833502633, 39.422282695770264, 41.51847778047834, 42.54758242198399, 40.210455077035085, 40.63323559079851, 41.166106837136404, 39.3067306791033, 41.32757602419172, 41.69716807774135, 43.71951423372541, 42.18851341520037, 43.61070196969168, 42.12012229646955, 42.59758513314383, 42.78276852199009, 42.97244044712612, 42.72777700424194, 42.37298461369106, 41.84464359283447, 46.4517092023577, 44.53091791697911, 44.480494839804514, 43.739785603114534, 42.59393385478428, 42.27902412414551, 43.72542715072632, 41.399993624006, 43.31761653082711, 38.68946313858032, 28.926151514053345, 27.426037175314768, 26.678244250161306, 25.45525881222316, 33.43217120851789, 42.493195397513254, 29.056173154285975, 43.66474505833217, 48.20061247689383, 47.154797417776926, 38.5077851159232, 40.47035591942923, 36.421456473214285, 28.69536362375532, 21.729266473225184, 9.185477716582161, 5.149821536881583, 6.9680257099015375, 7.044021197727748, 8.313140068735395, 13.906650985990252, 22.689391136169434, 19.64868746485029, 27.79475896699088, 35.74428503853934, 28.34182017190116, 27.95072865486145, 29.450367041996547, 29.507377011435374, 34.33007301603045, 47.94897651672363, 45.317158699035645, 44.320335388183594, 43.02112300055367, 42.62380068642752, 40.660986695970806, 41.381327288491384, 40.674553053719656, 42.15886197771345, 41.55206189836775, 42.29049212591988, 39.16025570460728, 39.579148701259065, 37.756254059927805, 38.948109831128804, 39.290430205208914, 42.61697060721261, 41.13211277553013, 39.83424139022827, 39.86956255776541, 40.164430209568565, 37.99123518807547, 39.706679412296836, 39.04371009554182, 40.38565737860543, 38.563426290239605, 38.560845034463064, 37.58916030611311, 40.56311437061855, 46.40068858010428, 52.44192491258894, 50.081250122615266, 52.596636976514546, 53.22850268227713, 52.76556852885655, 51.000288350241526, 51.92063283920288, 46.196818011147634, 46.240577765873496, 44.41183968952724, 47.031862940107075, 49.40282801219395, 52.80362728663853, 51.48570340020316, 62.41366686139788, 56.12568610055106, 62.01365212031773, 12.451382926532201, 11.250049812453133, 56.12124620165144, 44.33865431376866, 19.61090316091265, 18.113274540219987, 42.18523039136614, 20.43043623651777, 16.27371985571725, 36.967831543513704, 40.214047295706614, 33.30583906173706, 30.870040348597936, 27.025826147624425, 44.80076857975551, 57.771134172167095, 52.34762396131243, 7.702167596135821, 0.34449529594608713, 0.22135214161659988, 0.019987492389710884, 0.15417835542133876, 0.1576331571808883, 0.08033030200749636, 0.03957658294322235, 0.0657326253131032, 0.10189082007855177, 0.06430386805108615, 0.07693301287612744, 0.09686670252787215, 0.04705515843150871, 0.14353908917733602, 0.015771128370293548, 0.15299812518060207, 0.1216019977416311, 0.11358304374984332, 0.09623390076948063, 33.9785532270159, 67.87330423082624, 53.923569202423096, 30.101378508976527, 26.170581068311417, 55.3227835382734, 30.417271409715923, 31.609599658421107, 21.08299888883318, 22.254527705056326, 24.176189252308436, 50.38495935712542, 56.34885876519339, 58.491679736546104, 13.34900506905147, 22.416495425360544, 69.64357321602958, 56.279797145298545, 64.0353764125279, 57.776623249053955, 60.04579026358468, 60.21303340366909, 59.67502743857247, 56.50070817129952, 54.811854703085764, 47.43079028810774, 48.276080335889546, 43.78321531840733, 45.14397484915597, 44.238263266427175, 44.13246304648263, 44.65677063805716, 46.40633051736014, 43.327476024627686, 43.48442193440029, 42.66881111689976, 42.450620310647146, 43.493055071149556, 41.59211131504604, 42.881290503910606, 43.466255869184224, 44.2124993460519, 45.37532206944057, 44.47910172598702, 46.09056615829468, 45.38425745282854, 45.764424664633616, 44.135044302259175, 47.676492486681255, 45.06439018249512, 46.28224958692278, 46.12550170081002, 48.40780775887625, 46.32168756212507, 48.23853921890259, 47.07497303826468, 45.49897915976388, 46.35582406180245, 48.80834361485073, 45.01593344552176, 47.47382743018014, 43.281221866607666, 32.6599623135158, 30.57970987047468, 28.207002537591116, 32.31295885358538, 33.92870337622506, 47.74133655003139, 25.952279090881348, 34.83350127083914, 51.91987895965576, 49.3234726360866, 46.35742562157767, 45.04047448294503, 43.233585017068044, 35.56501109259469, 19.877067804336548, 7.68788036278316, 7.606642893382481, 7.740909014429365, 8.110640031950814, 14.117785028048925, 26.19859446798052, 35.9754307610648, 24.629345553261892, 32.440340178353445, 39.79600545338222, 35.05196305683681, 37.39883177621024, 37.73801156452724, 34.92112500326974, 37.372470310756135, 49.12295804704939, 48.0488395009722, 48.46804864065987, 45.91990450450352, 45.64610726492745, 44.55866207395281, 44.04268537248884, 41.600681918007986, 44.86233309337071, 43.32813957759312, 44.6974766595023, 42.41200222287859, 43.65108837400164, 41.34556838444301, 42.52479580470494, 42.57681349345616, 45.05860928126744, 42.85813910620553, 42.56510577883039, 42.3973137310573, 42.3632675579616, 40.414339542388916, 42.339535985674175, 42.16614021573748, 42.001665932791575, 40.57543700081961, 41.78275598798479, 41.68492535182408, 44.09076690673828, 50.21152884619576, 54.870389802115305, 53.987763609204976, 55.67552621023995, 54.36294548852103, 55.183322770254954, 53.86563859667097, 55.27450050626482, 49.67646196910313, 49.77834340504238, 46.90891804013933, 52.29639836720058, 51.07344593320574, 56.73839214869908, 52.784356457846506, 63.819308280944824, 58.72548661913191, 62.9866361618042, 10.530088765280587, 14.958775009427752, 63.83726937430245, 46.18824393408639, 22.23534893989563, 18.54113245010376, 40.55356407165527, 19.781570025852748, 19.949377707072667, 38.68380035672869, 44.158807141440256, 29.135637964521134, 40.33177062443325, 31.051134722573416, 56.43007973262242, 61.38542379651751, 64.62940570286342, 15.119809934071132, 0.6305590644478798, 0.33170686502541813, 0.04122940603909748, 0.12924087712807314, 0.11710622826857225, 0.049860480041908364, 0.03261435564075198, 0.12468679435551167, 0.17342413270047732, 0.13087302526193006, 0.20537422969937325, 0.20196674897202424, 0.16018786866750034, 0.19675409368106297, 0.14075305153216633, 0.3246811777353287, 0.1889586355537176, 0.2032181303948164, 0.1988514182823045, 37.32772043773106, 77.42626435416085, 59.44881493704659, 35.49656786237444, 33.29830721446446, 68.62758677346366, 40.50035129274641, 46.43217086791992, 23.054301840918406, 23.10922040258135, 31.056102684565953, 56.003050395420615, 60.7009984425136, 60.88464627947126, 12.432244982038226, 32.50848811013358, 71.27470452444894, 58.7416342326573, 67.1426316670009, 59.10914530072893, 62.027722222464426, 62.38604082380022, 62.22195911407471, 59.22081674848284, 58.54280458177839, 50.470314502716064, 51.11540610449654, 45.34704984937395, 48.0812736919948, 46.96209260395595, 46.83473212378365, 46.84910447256905, 49.48966312408447, 43.98600544248308, 46.32765259061541, 45.95388814381191, 43.75760078430176, 46.137032236371724, 44.579332964760916, 43.38391971588135, 46.25702067783901, 45.364125047411235, 49.08550378254482, 45.49600880486624, 48.40608460562569, 47.22095816476004, 47.15630865097046, 47.770320960453574, 49.56025334766933, 46.979303291865754, 46.56175477164132, 47.91660485948835, 50.92753723689488, 51.356129918779644, 51.284733704158235, 51.950496196746826, 48.01168748310634, 50.21896341868809, 52.285038062504356, 49.00265693664551, 51.74244976043701, 47.88714797156197, 37.449174949101035, 34.14983674458095, 31.246337413787842, 35.81588275091988, 37.10304348809378, 50.38346896852766, 31.219548634120397, 46.87490660803658, 58.12316117967878, 53.093704155513215, 48.79238707678658, 47.794031688145225, 43.20955119814192, 39.93683501652309, 39.081119196755544, 36.90354681015015, 28.026974712099346, 26.30965621130807, 23.65162284033639, 26.974122864859446, 35.514827728271484, 39.909552914755686, 28.51102270398821, 34.24081993103027, 44.16804824556623, 36.446410928453716, 35.17260462897164, 37.14951998846871, 37.34954472950527, 40.4357191494533, 51.49362087249756, 49.711533001491, 51.64847884859358, 46.80874933515276, 47.938533374241416, 46.36961276190621, 47.025491441999165, 44.058099951062886, 48.09530210494995, 46.32641233716692, 48.56023733956473, 45.186042717524934, 46.208598681858604, 43.10432767868042, 45.14525331769671, 44.28450700214931, 50.21056652069092, 47.28433615820748, 46.22414180210659, 44.622165134974885, 46.37048128673008, 43.16965811593192, 44.96061883653913, 44.35184894289289, 45.78189243589129, 42.994945662362234, 44.20883069719587, 43.906153270176475, 47.901926789964946, 51.97676386151995, 56.889390400477815, 57.164174284253804, 60.147532735552105, 58.91677747453962, 58.38344764709473, 56.575668811798096, 59.52673898424421, 52.791259493146626, 52.41109922954014, 49.43310826165335, 53.31019960130964, 55.06720447540283, 59.90558951241629, 55.475067206791465, 66.14783723013741, 59.576564516339985, 71.29080350058419, 16.227533442633494, 12.82863884312766, 68.26748943328857, 51.12223270961216, 31.605993543352398, 24.647980621882848, 51.568230628967285, 23.975179604121617, 20.09520649909973, 46.58493396214077, 54.56097609656197, 42.76295920780727, 41.99961274010794, 37.50644200188773, 56.45371750422886, 69.23030826023647, 72.76492636544364, 22.13264240537371, 0.7804285596523965, 0.4243940971791744, 0.10182008280285768, 0.24592025258711406, 0.33266634068318773, 0.20095615248594964, 0.12567110439496382], [0.16030092617230757, 0.015933179496122257, 0.01897944210629378, 0.06824394448527268, 0.06700887504432883, 0.14011145595993313, 0.15593821741640568, 0.08353376761078835, 0.04988331953063607, 0.011650792323052883, 0.02960759394669107, 0.3436582551470825, 36.09330347606114, 63.068423407418386, 38.580758571624756, 36.541073186056956, 31.362316744668142, 43.85378817149571, 32.76763507298061, 24.943143572126115, 19.228173800877162, 25.559521743229457, 18.777739456721715, 34.01932873044695, 56.44280188424246, 56.644956248147146, 39.54627329962594, 5.650512201445443, 39.42660100119454, 68.36129011426652, 60.03607668195452, 59.83538491385323, 57.372568130493164, 56.7144000189645, 56.61351217542376, 53.00370066506522, 44.537348474775044, 43.34843179157802, 44.85984216417585, 43.29127590996878, 44.77266311645508, 43.06130790710449, 40.3328788621085, 41.278358459472656, 41.27402973175049, 41.43324422836304, 42.76069409506661, 41.945642607552664, 42.53963368279593, 40.74543857574463, 40.567755767277305, 41.34437329428536, 41.939538615090505, 41.380194732121055, 41.87043878010341, 42.55458620616368, 43.055103165762766, 41.64870091847011, 43.53449412754604, 43.997077396937776, 43.643024989536826, 45.95713642665318, 44.27174663543701, 44.18493931634085, 44.47379330226353, 43.62081159864153, 43.29384674344744, 43.10862166540963, 45.18250955854143, 41.30925709860665, 45.15585279464722, 41.388435295649934, 45.975365025656565, 38.43160854067121, 27.873405626841954, 33.85822779791695, 29.46285990306309, 21.434206008911133, 34.66075863157, 34.32472290311541, 54.676590647016255, 51.30315337862287, 48.21195541109358, 34.60213668005807, 36.59255586351667, 33.38989836829049, 33.324963978358674, 36.7073609488351, 37.28732361112322, 21.52082920074463, 10.728434647832598, 8.795179162706647, 8.40490927015032, 12.189517480986458, 17.452082225254603, 25.139650787625992, 20.730329172951834, 27.078748839242117, 34.18975067138672, 27.45234305518014, 22.959693431854248, 36.28298929759434, 35.201463971819194, 32.563771452222554, 45.46920265470232, 47.41064051219395, 43.992147650037495, 43.2604467528207, 41.07614850997925, 40.99240187236241, 41.13434314727783, 39.714061873299734, 40.3103597504752, 40.06055464063372, 40.71419252668108, 40.18775183813912, 39.48749501364571, 38.922384125845774, 41.56971379688808, 40.675008160727366, 40.02611936841692, 39.46132114955357, 39.576706409454346, 38.03607191358294, 39.96584721973964, 36.05906275340489, 38.160024302346365, 36.61616236822945, 40.096383026668, 38.24138075964791, 39.44702870505196, 39.63935831614903, 41.65672261374337, 48.39920588902065, 54.70196894236973, 52.840032373155864, 50.27719974517822, 49.22033357620239, 51.95954622541155, 52.50327403204781, 53.05509301594326, 50.3909695489066, 48.85132169723511, 44.28507675443377, 49.863910470690044, 47.166602407182964, 54.42561476571219, 53.439370087214876, 61.01004041944231, 51.09243188585554, 37.439503056662424, 3.68602499791554, 27.611474173409597, 57.926037311553955, 44.62477765764509, 15.36441605431693, 12.156314645494733, 40.99025140489851, 76.62905584062848, 43.21746867043631, 32.52509430476597, 42.70110634395054, 31.225531033107213, 29.219780649457658, 29.642300605773926, 31.131143229348318, 52.32165159497942, 57.03988143375942, 19.35948085784912, 0.43360018889818874, 0.23942004995686667, 0.006641020274920655, 0.06783239942576204, 0.04713043510647757, 0.22697244717606477, 0.03942405166370528, 0.05433498422748276, 0.0366642767164324, 0.01714363168658955, 0.055425016808190515, 0.12504842637905053, 0.07235642988234758, 0.07291568523006779, 0.02018811314233712, 0.029623424168676138, 0.030015064403414726, 0.07965124451688357, 0.6225010539804186, 46.41184043884277, 71.8264262335641, 44.5027950831822, 46.76831776755196, 38.26814522062029, 47.189861501966206, 34.841033118111746, 16.915460688727244, 14.708858728408813, 26.03563836642674, 24.252035788127355, 35.00379467010498, 60.1420783996582, 59.16010338919503, 49.289812088012695, 7.172416090965271, 28.139669282095774, 67.09536307198661, 63.174119404384065, 62.08186953408377, 59.54332433428083, 59.8928256716047, 59.40071255820138, 55.478207792554585, 47.42446047919137, 48.058181353977744, 47.1959342275347, 46.70492240360805, 46.161823408944265, 46.24391290119716, 43.19983066831316, 45.17007923126221, 43.92096682957241, 42.82589251654488, 45.29593195234026, 42.9530792917524, 44.8226762499128, 43.49085944039481, 43.68269572939192, 42.61404194150652, 45.01242807933262, 46.115628310612266, 44.87804991858346, 43.84161492756435, 46.69253029142107, 46.457083633967805, 46.87765114648001, 46.86609629222325, 47.035489899771555, 46.894101006644114, 46.48942749840872, 46.118629932403564, 46.912385191236226, 46.77735389981951, 45.305496147700715, 45.02390302930559, 48.01544298444475, 45.10624960490635, 49.74662140437535, 44.71377713339669, 48.464946269989014, 41.3983017376491, 31.92092064448765, 36.5841554914202, 33.886253356933594, 24.834819419043406, 35.376364026750835, 36.243624278477256, 45.28419644492013, 47.811596734183176, 52.694255692618235, 43.51918724605015, 42.70531347819737, 42.16413218634469, 39.25916678564889, 38.790799140930176, 38.78911420277187, 25.444025312151226, 15.883267572947911, 12.274013655526296, 14.644480194364276, 17.782085180282593, 24.34731296130589, 35.43046270098005, 26.700287410191127, 29.91260290145874, 39.39570583615984, 30.789052145821707, 30.058820792606898, 41.90889705930437, 41.959268024989534, 35.58939926964896, 44.7027781350272, 49.41465732029506, 44.955199241638184, 46.824865681784495, 44.3710537637983, 44.432903153555735, 43.281451157161165, 42.402830600738525, 41.938447747911724, 43.940970693315776, 42.38745076315743, 44.02019057955061, 41.153655665261404, 42.149784156254356, 45.41705642427717, 41.61753477369036, 41.40730312892369, 40.90557370867048, 41.33341598510742, 40.86206061499459, 43.184819085257395, 39.996711117880686, 40.56790515354702, 40.323912211826865, 42.29748896190098, 42.3717165674482, 41.01900652476719, 42.43539680753435, 43.239588260650635, 50.84273794719151, 54.74407502583095, 53.82993875231062, 52.50055728639875, 53.514983858381, 56.18447828292847, 54.704407760075156, 55.77882160459246, 53.874431541987825, 51.63633687155587, 49.27100331442696, 52.53114325659615, 51.03069714137486, 57.14056430544172, 58.48067378997803, 62.79672104971749, 57.68246126174927, 36.556859493255615, 4.336028107575007, 33.16680908203125, 67.87914766584123, 47.01206404822213, 19.356203045163834, 11.94808668749673, 42.79978813443865, 58.81974588121687, 33.282336780003135, 32.02800975527082, 49.67132030214582, 23.31547246660505, 30.727751663752965, 28.645246267318726, 31.4439754486084, 66.05694089617047, 65.23240511757987, 38.909099170139854, 0.6193059682846069, 0.12246277369558811, 0.035590651112475565, 0.057220607064664364, 0.0954618975520134, 0.08635626294250999, 0.011138781672343612, 0.1800793670117855, 0.06768171715417079, 0.11373233502464634, 0.15909877925046853, 0.28822023421525955, 0.15058274407471928, 0.19485431776515075, 0.15759506422494138, 0.110247413095619, 0.09429516337279763, 0.16056931391358376, 0.6094965232270104, 53.99826928547451, 82.48690141950334, 53.2400575365339, 46.704116412571494, 43.86266449519566, 58.42797865186419, 44.08728238514492, 30.5527161189488, 27.45681769507272, 30.91565874644688, 31.674169267926896, 44.818118231637136, 64.30605738503593, 64.87268992832729, 45.44227491106306, 7.297511458396912, 43.41621494293213, 73.34197425842285, 64.28059918539864, 64.09890379224504, 61.357269695826936, 61.17175279344831, 63.49185357775007, 59.921209062848774, 51.84793036324637, 49.604443890707834, 51.602092674800325, 48.65328761509487, 48.390291350228445, 48.15515736171177, 46.36657987322126, 47.40004103524344, 46.48787110192435, 46.24026509693691, 47.796863079071045, 46.29292549405779, 46.34688173021589, 44.19965212685721, 46.385062081473215, 45.67402512686593, 47.18085663659232, 46.015942505427766, 47.2243002482823, 45.31328507832119, 48.66565540858677, 48.1419939994812, 50.99870763506208, 49.37798820223127, 49.41522707257952, 51.903210231236045, 50.70502117701939, 49.470576422555105, 49.77424396787371, 49.875378472464426, 48.746487276894705, 50.784723963056294, 50.86240482330322, 47.45313222067696, 52.25819369724819, 47.57455546515328, 50.23012222562517, 44.935845034463064, 37.470297472817556, 38.695400374276296, 35.701268741062705, 29.032981804439, 40.77246012006487, 39.96783787863595, 54.40646205629621, 53.8370988709586, 58.16069882256644, 47.03774459021432, 46.33527823856899, 40.924309526171, 40.233804498400005, 41.8472352709089, 49.02714238848005, 37.68662963594709, 33.59663506916591, 29.66490309579032, 26.335140466690063, 30.797066892896378, 32.482074533190044, 45.02176645823887, 31.059889452798025, 33.1587769644601, 42.4882378578186, 32.53473145621163, 28.33154378618513, 40.787506444113596, 41.006617886679514, 39.789328234536306, 46.34052412850516, 50.75611475535801, 44.32558822631836, 48.539833954402376, 44.615185669490266, 46.03611312593733, 43.47148438862392, 44.80137654713222, 45.24916362762451, 47.04424115589687, 45.106885365077424, 45.91526310784476, 44.95437240600586, 44.14280196598598, 47.11760023662022, 46.41692304611206, 44.88076319013323, 44.818493434361045, 44.51822703225272, 44.01186316353934, 46.92027139663696, 40.2276588167463, 44.29318182809012, 41.88548510415213, 45.72065796170916, 44.09154857907976, 44.34799269267491, 45.34890154429844, 46.00147288186209, 54.10928760256086, 59.83546134403774, 57.53182084219796, 54.278879233769004, 54.23459836414882, 58.26697152001517, 57.82061576843262, 59.695587158203125, 55.07694237572806, 55.49665525981358, 50.69394227436611, 55.691559178488596, 54.90523501804897, 60.09462915148054, 60.469644274030415, 67.8503612790789, 59.2763398034232, 43.42188119888306, 5.954478085041046, 31.502927439553396, 68.21601022992814, 52.52786718096052, 26.646140098571777, 19.26945652280535, 50.14514923095703, 81.59563514164516, 52.95288154057094, 40.080256257738384, 55.287399836948936, 39.56549201692854, 39.28756059919085, 40.863120215279714, 40.05087232589722, 70.85947322845459, 71.77871990203857, 50.54878398350307, 0.6848691159061023, 0.22633648344448634, 0.1295521618532283, 0.2400978250162942, 0.15121436518217835, 0.37150837214929716, 0.0772347573989204], [0.04212278899337564, 0.1366768338318382, 0.10570530646613666, 0.030608019192836115, 0.014359319216704794, 0.06825256188000951, 0.07331653657768454, 0.13151775566594942, 0.05724185878144843, 0.07458967183317457, 0.022965121182746122, 0.43043647866163937, 41.48948989595686, 54.10056413922991, 49.77085672106062, 21.117500168936594, 25.709969350269862, 46.05290692193167, 30.638793877192906, 23.893203020095825, 44.40328645706177, 32.28706986563546, 13.88772930417742, 19.620437826429093, 47.85019050325666, 53.748815059661865, 57.48278393064226, 25.065034082957677, 1.1067149341106415, 25.721609319959367, 46.47292900085449, 58.40536226545061, 56.02215794154576, 60.46446786608015, 53.77410650253296, 49.055803707667756, 48.02046653202602, 51.56206062861851, 47.52914898736136, 50.27528551646641, 45.03544051306588, 46.49616725104195, 43.01144763401577, 42.89159120832171, 40.423257555280415, 41.97123282296317, 41.134148597717285, 42.8152756690979, 39.89766454696655, 43.78208276203701, 41.49832105636597, 41.99509641102382, 40.941898890904014, 44.3846618107387, 41.28872864586966, 42.900655133383616, 41.91377469471523, 43.11106048311506, 43.831842286246165, 45.77482264382498, 43.381800515311106, 44.36648532322475, 41.87850911276681, 44.89327342169625, 41.05148240498134, 44.277392046792166, 41.76576764242989, 43.465328284672324, 44.981619766780305, 43.847475733075825, 43.20264121464321, 44.37741136550903, 47.939526966639924, 35.76418467930385, 30.6480210849217, 40.80682243619646, 23.50126208577837, 27.121916260038102, 28.08894395828247, 36.58249487195696, 45.848417963300435, 43.113600049700054, 38.03513043267386, 34.82049076897757, 29.781236784798757, 34.21368721553257, 36.56331089564732, 37.53038202013288, 39.431228501456125, 30.235614231654576, 21.674281903675624, 16.75858426094055, 15.543309586388723, 17.385459423065186, 21.18958078111921, 25.99394222668239, 32.44097593852452, 40.662202630724224, 31.7603269304548, 11.542461276054382, 20.959393909999303, 34.33462756020682, 38.17857599258423, 31.68429626737322, 41.7500820841108, 52.14452116830008, 46.00980724607195, 46.583978584834504, 45.16059494018555, 42.97273574556623, 39.57554606028965, 41.189723764147075, 39.33819907052176, 40.266742433820454, 39.997326033455984, 40.18843970979963, 39.799496923174175, 40.0602628162929, 39.64515658787319, 41.251990045819966, 40.052525997161865, 39.048507826668875, 40.8682792527335, 40.17604412351336, 39.667508942740305, 39.22565214974539, 37.20374373027256, 38.43754230226789, 38.756558418273926, 37.956355231148855, 39.43980952671596, 38.17889560971941, 40.59180000850132, 49.12075546809605, 52.3779285294669, 50.39747306278774, 50.629126003810335, 50.63279465266636, 51.41109364373343, 53.690502302987234, 52.23963853291103, 53.60719687598092, 50.79171732493809, 46.401602268218994, 47.71388421739851, 48.72215815952846, 51.927674838474815, 54.729403904506135, 57.608171122414724, 50.555304867880686, 26.114953790392192, 2.9242981118815283, 39.823370933532715, 41.9057286807469, 42.880123206547324, 15.074068205697195, 6.3172973820141385, 26.918785674231394, 67.0271942956107, 59.48690496172224, 37.649672167641775, 32.41164411817278, 33.45724030903408, 31.03898232323783, 37.85666595186506, 25.206040825162614, 33.6630494253976, 63.495800154549734, 51.30483831678118, 3.540235072374344, 0.2082827700568097, 0.3309485342885767, 0.045351672518466196, 0.22219960471349104, 0.07986678795090743, 0.1402229256927967, 0.04305586963891983, 0.1286594540412937, 0.010957428769740676, 0.024351205377440368, 0.07601563353091478, 0.0641180444508791, 0.12209474987217359, 0.048981790763459036, 0.11835326706724507, 0.09016759414225817, 0.018093592587060163, 0.9393936267920903, 55.22676638194493, 57.32255499703543, 55.035975796835764, 26.899191754204885, 27.918744359697612, 53.047946793692454, 33.20153965268816, 25.92039728164673, 35.732490471431184, 37.06054483141218, 16.38400513785226, 23.114766802106583, 50.706348282950266, 58.32138633728027, 61.14610004425049, 33.23026350566319, 0.8715782314538956, 14.287031854901995, 40.61410025187901, 58.91866043635777, 58.40702288491385, 61.70606231689453, 56.69522646495274, 52.17643077032906, 52.243869985852925, 53.78008542742048, 51.57658931187221, 52.887026514325825, 47.07083886010306, 50.56956257138933, 45.295403889247346, 46.35234996250698, 43.157825333731516, 43.827211311885286, 44.162878785814556, 44.47377593176705, 43.55999749047415, 44.963912282671245, 45.005434717450825, 44.814216818128315, 44.99294533048357, 46.4914459500994, 44.591183117457796, 44.7668787411281, 44.22075033187866, 43.81458990914481, 46.873023646218435, 46.843507698604036, 45.99445867538452, 46.115861075265066, 44.017553738185335, 47.09728022984096, 44.745082242148264, 46.6912761415754, 43.18098367963518, 46.7751339503697, 47.777449812207905, 48.08995546613421, 47.381009919302805, 47.862471444266184, 52.29532834461757, 38.10109315599714, 34.05379179545811, 40.52320391791207, 28.349068880081177, 25.382370471954346, 28.374803270612443, 37.66851568222046, 47.34721735545567, 42.69343205860683, 45.602483000074116, 41.427258355276926, 36.08945764814104, 39.25632497242519, 42.09436879839216, 44.96845293045044, 48.57223687853132, 39.07157932009016, 26.030630452292307, 18.56034595625741, 18.825378043310984, 20.613556010382517, 25.14442072595869, 35.66979340144566, 32.565282685416086, 40.47965955734253, 37.02105821881975, 12.16537422793252, 18.857245956148418, 35.41562482288906, 41.332484926496235, 36.56089987073626, 42.66656684875488, 55.11889212472098, 47.38672481264387, 51.37035288129534, 48.774742126464844, 47.33893510273525, 42.935924189431326, 46.139665603637695, 42.32461472920009, 43.660166195460725, 42.238067967551096, 41.8712934085301, 42.60183048248291, 43.07797316142491, 42.315071378435405, 44.176813398088726, 42.7834598677499, 41.77125324521746, 42.839959144592285, 42.17300851004464, 41.67953702381679, 41.45431464059012, 38.6729542187282, 41.25801065989903, 41.196328026907786, 43.376662322453086, 42.14297839573452, 41.93949692589896, 44.54580095836094, 51.58154337746756, 53.259745257241384, 54.106838362557546, 51.70080573218209, 52.14225605555943, 52.12294006347656, 56.37099225180489, 54.62704651696341, 56.77581167221069, 52.75496905190604, 49.991072927202495, 49.588132994515554, 52.55782086508614, 54.73568160193307, 58.5136707850865, 58.49579307011196, 55.093121256147114, 24.10664299556187, 4.2543220690318515, 47.168738978249685, 42.33504050118582, 48.49041141782488, 19.04764223098755, 7.142982218946729, 29.96422106879098, 60.19639941624233, 44.79222576958792, 36.09420326777867, 43.776986258370535, 29.95190191268921, 29.721068859100342, 44.628571374075754, 27.162894998277935, 46.47334936686924, 65.04127407073975, 71.05471760886056, 10.02850352014814, 0.25614371257168905, 0.17617179240499223, 0.06307436259729521, 0.07519523041056735, 0.06216051163417952, 0.0766001914494804, 0.2140054665505886, 0.25942646499191013, 0.17242337497217314, 0.1599278404776539, 0.11694428910102163, 0.18017974948244436, 0.2093821053526231, 0.3372382010732378, 0.20141311867960862, 0.21903609803744725, 0.14560533687472343, 1.1042618943112237, 63.144415855407715, 69.33011218479702, 62.936921800885884, 27.640529802867345, 33.95184782573155, 64.92192486354283, 41.37296513148716, 28.661164590290614, 55.249351501464844, 40.66498538425991, 23.8195903301239, 30.252286434173584, 58.51761736188616, 62.873741831098286, 69.52125017983573, 29.895152500697545, 2.122028921331678, 30.496845654078893, 49.23311478751046, 59.98664024897984, 59.7640060697283, 65.96324443817139, 61.09877586364746, 55.46287659236363, 53.445929186684744, 55.38328845160348, 53.7383371761867, 54.95090205328805, 48.205552646092, 52.188739504132954, 48.08823231288365, 49.01991973604475, 46.31266532625471, 45.700897284916465, 46.73737743922642, 48.11069931302752, 45.34084163393293, 46.97414772851126, 46.32194117137364, 46.11990145274571, 45.995077065059114, 48.16072286878313, 45.8437557220459, 47.07309355054583, 45.671169417245046, 47.1638057572501, 49.786135809762136, 50.26997709274292, 48.541557107652935, 48.296678270612446, 47.24830627441406, 51.724179472242085, 47.85895218167986, 49.235633509499685, 47.33519697189331, 49.51602111543928, 52.57431936264038, 49.28050150190081, 50.546498026166645, 49.69919300079346, 54.897974150521414, 40.1040712084089, 38.68616621834891, 43.63054255076817, 31.477045399802073, 35.42689480100359, 35.4472564969744, 41.19167273385184, 47.25842979976109, 46.98008843830654, 48.78414651325771, 45.6235534123012, 38.44873585019793, 41.111441884722026, 40.594895430973594, 40.063948835645405, 44.545109612601145, 42.58124297005789, 36.46542467389788, 34.29649237224034, 31.575181756700786, 33.382262298039024, 34.47647850854056, 42.7497124671936, 40.49329192297799, 49.16822556086949, 44.62733806882586, 17.765498093196324, 27.467335530689784, 37.55349520274571, 42.622414520808626, 39.7329227583749, 44.76598937170846, 56.09762232644217, 48.792786598205566, 51.00678144182478, 50.2224131992885, 48.81867558615548, 45.20009197507586, 47.60286590031215, 44.88038798740932, 45.483439513615195, 45.83531713485718, 44.77057865687779, 43.77146938868931, 46.19570977347237, 44.97974722726004, 48.48109040941511, 46.306151390075684, 44.0642352104187, 45.997950145176475, 45.71804196493966, 44.61725623267037, 46.04253326143537, 41.713357380458284, 43.24792262486049, 43.428346497671946, 44.68647418703352, 45.00709881101336, 44.23860025405884, 47.62368617738996, 54.62590701239449, 57.73141132082258, 56.269791739327566, 53.8918263571603, 54.360183579581125, 56.763395241328645, 58.348491259983604, 56.320426736559185, 59.215744563511436, 54.37015424455915, 50.00678627831595, 53.85798863002232, 54.31344652175903, 57.681002140045166, 59.62361076899937, 62.33349854605538, 55.99165882383074, 30.94215222767421, 3.604078595127378, 48.86709410803658, 49.390606130872456, 52.89387048993792, 23.565743105752126, 12.993761914116995, 33.487697737557546, 72.77257633209229, 64.68802765437535, 48.78581060682024, 44.33079937526158, 43.96136018208095, 41.11236252103533, 51.003133637564524, 31.681082725524902, 51.85426712036133, 74.56298119681222, 78.74127347128731, 12.791290538651602, 0.5957667742456708, 0.49712824715035303, 0.17943010399384157, 0.23861883580684662, 0.2312299965747765, 0.17074607711817535], [0.032709102878080945, 0.10105764014380318, 0.05795457839433636, 0.12190204592687742, 0.08894114888140134, 0.12214953478957925, 0.05515316175296903, 0.12169270430292402, 0.05121526341619236, 0.05885465509657349, 0.03200486495292612, 1.9348231724330356, 52.0907803262983, 52.75816869735718, 36.43277856281826, 32.729572841099326, 43.169932569776265, 39.08580923080444, 44.84619590214321, 19.90716913768223, 64.50264971596854, 53.631195953914094, 10.31106070109776, 17.959682873317174, 41.5173556464059, 58.505034174237935, 48.13507011958531, 59.79327188219343, 6.084634780883789, 0.252014338438, 13.207798566137042, 58.452665601457866, 61.011423110961914, 55.0426321710859, 54.45931352887835, 54.398898942129954, 56.529001235961914, 51.09839344024658, 52.266010420663015, 51.86177464893886, 49.62320055280413, 47.647980553763254, 47.74437638691494, 42.59987456457955, 42.75797734941755, 41.515743664332796, 42.09997252055577, 41.48931271689278, 43.84542948859078, 44.1907445362636, 43.399292605263845, 43.548491273607524, 42.04006862640381, 43.21429334368025, 44.48362847736904, 43.560497760772705, 44.666730880737305, 42.71856369291033, 46.017203603472026, 45.50298132215227, 45.4107335635594, 43.2579071862357, 42.777248178209575, 40.74719646998814, 41.62934671129499, 43.398702008383616, 44.00546039853777, 43.27173062733242, 44.66841581889561, 44.9405837059021, 44.46192577907017, 47.3100722857884, 47.80898073741368, 28.842460462025233, 27.862413576671056, 28.25832540648324, 23.34230293546404, 19.471041134425572, 17.461768014090403, 36.34551961081368, 43.632296970912385, 41.00343908582415, 35.17405332837786, 27.677634920392716, 26.77369339125497, 29.76488767351423, 31.52288614000593, 35.55809416089739, 36.01630701337542, 33.728821073259624, 30.686798981257848, 26.603561537606375, 27.96685368674142, 28.232153279440745, 32.07665409360613, 31.700902462005615, 33.96445533207485, 36.30586971555437, 27.33382589476449, 9.126694219452993, 9.63984647818974, 29.495589392525808, 35.034634249550955, 31.37364230837141, 31.98625108173915, 50.8657990183149, 45.71384525299072, 46.25758695602417, 44.841714314052034, 44.28061948503767, 42.24251481464931, 41.893670082092285, 40.5235652242388, 41.27023254122053, 40.09031030109951, 38.792949608394075, 37.90030063901629, 38.447509493146626, 38.703210149492534, 41.97391135351998, 38.88113614491054, 38.65570878982544, 39.852508204323904, 37.96819496154785, 38.17064462389265, 38.42021696908133, 36.340430055345806, 37.96613482066563, 38.04129695892334, 39.611023562295095, 39.38122926439558, 40.15290314810616, 43.61349514552525, 48.871461050851, 49.24803951808384, 50.507452624184744, 48.08114515032087, 50.77329070227486, 47.76344224384853, 52.08147668838501, 52.93011229378836, 54.63049977166312, 52.40533569880894, 51.90554830006191, 47.15124341419765, 51.08465685163225, 51.02592372894287, 62.0466491154262, 51.354424136025564, 54.21687698364258, 7.384015662329538, 12.068125503403799, 49.139539922986714, 32.7395087650844, 55.98329666682652, 11.846508366721016, 5.485756516456604, 26.296339988708496, 44.90209068570818, 63.60626261574881, 43.64754826681954, 30.51399380820138, 29.278809070587158, 27.483135734285625, 28.746113266263688, 30.677641255514963, 24.846718209130422, 52.5385674067906, 64.79138905661446, 22.8953982761928, 0.19417324502553257, 0.28829389597688404, 0.08498300984501839, 0.1142132535044636, 0.03857599145599774, 0.10764888860285282, 0.039593122234301906, 0.09606807359627315, 0.01777540037541517, 0.16525309186960968, 0.04338040615298918, 0.033281820360571146, 0.05427591096875923, 0.17256886645087174, 0.016732795696173395, 0.09873229384954486, 0.10482944667871509, 4.54313827412469, 67.34787450517926, 55.76452221189226, 42.39454139981951, 28.967138937541417, 37.85415070397513, 48.48101397923061, 41.12947246006557, 22.51175696509225, 58.934273038591655, 59.938968658447266, 20.465625388281687, 17.174343620027813, 46.281995977674214, 63.77069173540388, 53.064000606536865, 64.72253240857805, 9.917570318494525, 0.35024446887629374, 11.017764585358755, 57.041034834725515, 62.48617131369454, 56.910981927599224, 57.54418168749128, 59.197915485927034, 59.54337991986956, 55.67738832746233, 55.37046902520316, 52.37157440185547, 51.41420643670218, 49.247768538338796, 48.85743958609444, 45.047530378614155, 45.026039600372314, 43.19084317343575, 43.54407221930367, 43.67542096546718, 45.88749115807669, 45.93476322719029, 46.241838863917756, 46.44005707332066, 45.8939425604684, 46.90110131672451, 46.664518628801616, 47.06679153442383, 47.33623225348336, 46.667374338422505, 47.62210546221052, 46.683674812316895, 47.87949800491333, 45.95915487834385, 45.72561550140381, 45.88408654076712, 45.15018653869629, 45.455914224897114, 46.500826018197195, 47.70004687990461, 47.774309226444785, 46.77483170373099, 49.36588791438511, 49.84083897726876, 49.28485802241734, 27.929901429585048, 27.75484504018511, 27.500784158706665, 24.096187693732126, 18.152205296925136, 17.89580113547189, 39.816992487226216, 46.90070179530552, 39.576112338474815, 36.25501932416643, 33.70980385371617, 36.028327396937776, 36.8380183492388, 37.03648669379098, 41.59016234534127, 41.21652296611241, 37.80074337550572, 32.83088105065482, 29.645875453948975, 29.253965786525182, 31.84991352898734, 35.29894024985177, 37.967253480638774, 38.64542893001011, 43.05410609926496, 33.07935210636684, 8.631350193704877, 7.612998758043561, 34.539529936654226, 38.17508799689156, 30.42319474901472, 32.95209584917341, 51.46029731205532, 48.6034551348005, 50.42936529432024, 46.43661076681954, 50.15728078569685, 46.28268732343401, 46.50870180130005, 44.51406853539603, 45.08920914786202, 42.827129295894075, 41.70132657459804, 40.710944243839805, 43.80561978476388, 41.611468996320454, 43.43959910529, 42.50004979542324, 43.2671274457659, 42.07567119598389, 41.83160877227783, 40.80498811176845, 41.508034637996126, 39.44649369376046, 39.72928885051182, 40.87862859453474, 42.43531690325056, 41.906576360974995, 42.385765824999126, 46.92321048464094, 53.151655605861116, 52.411797523498535, 54.050241810934885, 50.373939514160156, 53.95137936728341, 48.705472060612266, 52.766739300319124, 57.3261958530971, 58.71220861162458, 52.77306563513619, 54.08057417188372, 50.931042603084016, 55.199446065085276, 54.28364222390311, 66.41789981297084, 54.93309729439871, 56.273571559361045, 5.585480970995767, 17.860177721296036, 52.04916409083775, 32.779763153621126, 59.02225112915039, 11.74844409738268, 6.815709471702576, 31.311772074018204, 53.56450366973877, 51.97064249856131, 35.28760426385062, 37.007783685411724, 31.17739043916975, 27.52315214702061, 35.93196283067976, 38.818091664995464, 34.78355067116873, 61.600546973092214, 72.96583352770124, 33.50155244554792, 0.30761387784566196, 0.28925627576453344, 0.07668259952749525, 0.025388257943892052, 0.015323229100821274, 0.0513874416771744, 0.15133723430335522, 0.13109899099384034, 0.09424318080501896, 0.20817153102585248, 0.1377402746251651, 0.2534728358898844, 0.11889734358659812, 0.2078543837581362, 0.17455143720975944, 0.24742404903684342, 0.12525031768849917, 4.93229124375752, 77.0859763281686, 65.67369215829032, 50.172274998256135, 41.28449024472918, 57.60471091951643, 54.199311937604634, 58.612300464085166, 23.13745961870466, 73.68140765598842, 58.38809599195208, 19.39352008274623, 28.99321378980364, 50.90374313082014, 68.82064247131348, 56.382967472076416, 71.17384447370256, 7.005465643746512, 0.33488262604389873, 17.46010913167681, 62.066986492701936, 65.24503694261823, 60.01768480028425, 58.997293199811665, 61.193055970328196, 62.75855459485735, 55.423772130693706, 59.04527051108224, 54.294985158102854, 54.48542138508388, 52.0256027494158, 54.526481764657156, 47.74603353227888, 46.70444297790527, 45.25668852669852, 45.05158812659127, 46.26477139336722, 47.24500240598406, 47.81448718479702, 48.58349296024868, 50.56491422653198, 48.20521565846035, 49.31952953338623, 50.08204569135393, 49.737609590802876, 50.04511601584298, 46.89106464385986, 51.878085545131135, 50.38163464409964, 50.558810234069824, 48.54710871832711, 50.439530508858816, 46.99012858527047, 48.223169803619385, 49.812528542109895, 49.91884987694876, 50.376159463609966, 49.055605684007915, 49.776505606515066, 49.476732526506694, 51.417760440281455, 53.015231200626914, 36.77349042892456, 39.22746562957764, 41.33263431276594, 32.8276675088065, 26.28895057950701, 22.90859464236668, 41.71676894596645, 45.8520553452628, 44.71729292188372, 40.58393464769636, 36.87046991075788, 37.293587412152974, 37.33512374332973, 36.047389779772075, 38.37517874581473, 40.10461664199829, 37.96222298485892, 38.69301019396101, 36.5680183001927, 38.088318892887656, 41.92237656457083, 43.5399797303336, 43.07447474343436, 43.039931774139404, 43.597757475716726, 38.42514671598162, 16.011239494596207, 17.497021436691284, 36.425882475716726, 47.07514674322945, 39.99743373053414, 36.267668519701274, 51.267241614205496, 47.59381239754813, 50.65984746388027, 47.67981025150844, 48.647982665470664, 46.03028358731951, 46.86712115151541, 45.2197380065918, 47.049348081861226, 46.85504518236433, 42.69795880998884, 45.392835003989084, 44.32107884543282, 44.66380568913051, 48.34941509791783, 46.41398048400879, 46.9785007749285, 45.25895711353847, 43.525662967136924, 43.53642225265503, 44.95228099822998, 41.57214566639492, 43.315184661320274, 44.903879846845356, 45.46309518814087, 44.90280287606375, 45.03626387459891, 49.79766634532383, 54.4971603666033, 52.43156862258911, 55.221100125994, 54.19545916148594, 54.83867474964687, 50.78465448107038, 54.35200902393886, 61.29877976008824, 60.352129391261506, 56.238955633980886, 56.48202099118914, 54.582098620278494, 58.98007556370327, 56.89104754584176, 69.32555416652134, 57.97076286588396, 62.823353494916645, 10.11868245261056, 14.343048231942312, 61.6093225479126, 38.54034437452044, 63.5743773324149, 19.246433666774205, 12.220981529780797, 33.0865295955113, 53.1841036932809, 71.18215451921735, 55.05682386670794, 40.88246400015694, 38.74018498829433, 37.428156648363384, 42.60051032475063, 42.051762444632395, 39.24189703805106, 69.15259265899658, 84.0873772757394, 40.101670605795725, 0.4658147788473538, 0.3305961303412914, 0.186382509501917, 0.1090745653158852, 0.0741030333031501, 0.24294224381446838], [0.032918590387063365, 0.06577084719070367, 0.05651124280744365, 0.05684010837493198, 0.08688290111188378, 0.037456133868545294, 0.023022440428446447, 0.12721532796110424, 0.13351380213030747, 0.13855002474571976, 0.20162522872643812, 6.861882856913975, 65.02640492575509, 44.6444410596575, 46.59478303364345, 41.93762786047799, 36.03201341629028, 37.87191724777222, 39.32281575884138, 41.089249338422505, 87.56918212345668, 57.409278937748496, 4.745177124227796, 6.533351617200034, 25.87425603185381, 57.753787994384766, 52.92113869530814, 51.54315110615322, 33.77273716245379, 0.8314586813960756, 1.0688189161675317, 53.195113113948274, 60.10817119053432, 57.58173670087542, 55.37421757834298, 59.547653062003, 55.73202201298305, 59.152133805411204, 51.129233019692556, 51.13145991734096, 47.939923013959614, 48.194133281707764, 47.026794229234966, 46.56474944523403, 40.872211933135986, 43.620839391435894, 41.63254983084542, 42.82851546151297, 42.691358021327424, 42.637558119637625, 42.41697365897042, 45.207842690604075, 42.67917088099888, 46.541566780635286, 46.28879131589617, 46.15989875793457, 44.58063922609602, 46.22979416166033, 45.818745681217735, 48.28544650759016, 43.08890962600708, 44.514916215624126, 45.13585935320173, 42.51596117019653, 43.09331478391375, 45.503815105983186, 44.27207667487008, 44.64481626238142, 42.6043700490679, 45.245161465236116, 44.23104756219046, 47.70669978005545, 28.621314934321813, 4.72512332030705, 9.416837096214294, 5.479707675320761, 7.3203041553497314, 9.934014967509679, 13.37825437954494, 41.41585636138916, 36.311754839760916, 49.40236595698765, 60.28873402731759, 32.64705950873238, 20.260502406529017, 26.834038496017456, 30.587797573634557, 34.80365528379168, 36.60904393877302, 32.00478540148054, 32.25566053390503, 36.653717381613596, 34.098524297986714, 37.38260425840105, 41.76475320543562, 41.68051324571882, 30.125582558768137, 25.048346246991837, 33.43521799360003, 7.402351089886256, 3.457155461822237, 10.16190459047045, 11.741092034748622, 14.793661492211477, 18.584082739693777, 40.069562980106895, 47.58470678329468, 47.778898511614116, 45.86707387651716, 44.49492972237723, 43.94647019250052, 44.49237625939505, 43.87581048692976, 44.658274923052105, 40.18073763166155, 38.703623567308696, 38.855281897953574, 40.63629627227783, 39.18922274453299, 40.05731678009033, 39.33475276402065, 42.125885827200754, 41.230874470302034, 41.033073152814595, 38.968374252319336, 39.54250042779105, 37.296675886426655, 38.88282108306885, 39.233646052224294, 37.005393505096436, 38.61594424928938, 40.62582186290196, 45.216263907296316, 49.59149939673287, 48.865152086530415, 49.21591452189854, 50.96171542576381, 54.223519461495535, 51.98807552882603, 51.42373589106968, 50.32512494495937, 54.24302305494036, 52.49024615968977, 54.16485234669277, 46.82658536093575, 50.453857694353374, 52.08265788214547, 56.261808259146555, 53.920025621141704, 39.179467473711284, 1.8167340861899512, 35.84866435187203, 37.770918233054026, 55.023215430123464, 49.565888336726594, 3.8269679035459245, 11.57385584286281, 16.59977970804487, 35.69679757526943, 45.772852829524446, 47.15402269363403, 32.899782861982075, 28.38499801499503, 19.10019666807992, 29.812521048954554, 22.52481436729431, 22.823784930365427, 49.21280172892979, 58.26363638469151, 34.80030625207083, 0.2804174886218139, 0.18415424121277674, 0.025448450785396353, 0.04445137529234801, 0.060982907323965004, 0.002831176551158673, 0.04106194020381995, 0.016235349799639413, 0.08362036224986825, 0.04090605696131076, 0.009497539472899266, 0.01883111604755478, 0.0013194117678462394, 0.09499944879540376, 0.07546703796833754, 0.26465767143028124, 0.03728009813598224, 8.772906712123326, 77.17838042122978, 48.59428698675973, 53.93035759244646, 34.22579097747803, 37.463126931871685, 45.2995936529977, 36.74577406474522, 32.02424035753523, 78.75639969961983, 52.12817900521414, 14.071600352014814, 11.457181692123413, 23.976372957229614, 63.519486563546316, 57.3306496483939, 56.95339720589774, 40.303342069898335, 1.749409407377243, 0.6127665734716824, 52.332341398511616, 61.1653048651559, 61.22234957558768, 56.783340045383994, 62.655964442661826, 59.745503016880576, 62.286229951041086, 54.41877426419939, 51.92818553107125, 51.66022825241089, 49.57344797679356, 46.371804918561665, 45.67690862928118, 43.05138240541731, 44.763338633946006, 43.0256393296378, 43.1451552936009, 43.250048773629324, 43.32710429600307, 44.25309419631958, 46.71254110336304, 45.92940616607666, 47.97965281350272, 48.070180892944336, 47.45935780661446, 46.035022258758545, 48.33247538975307, 49.238541330610005, 52.76911211013794, 49.079827104296, 49.78741775240217, 48.66316100529262, 48.112207072121755, 47.54360124043056, 51.51832866668701, 46.54037169047764, 49.666227272578645, 45.88261352266584, 50.829237597329275, 48.25186586380005, 54.06331832068307, 28.082575934273855, 8.469733357429504, 14.379541039466858, 10.66135847568512, 12.488373398780823, 12.425161293574742, 18.081886053085327, 44.4291615486145, 42.4408198765346, 50.95500694002424, 50.81273562567574, 36.00860493523734, 31.230853353227886, 36.67395748410906, 36.85802568708147, 36.39725937162127, 39.591728414808, 39.127752031598774, 38.78732851573399, 39.54659291676113, 41.012673241751536, 40.884531089237754, 45.4753691809518, 43.45815426962716, 33.46866314751761, 32.00608818871634, 37.302317823682515, 12.701574529920306, 7.428853256361825, 16.319993121283396, 21.787396839686803, 23.476403168269567, 21.018010650362285, 39.392784118652344, 50.562343393053325, 50.70217588969639, 50.242187772478374, 45.27716834204537, 48.43077850341797, 48.946227141789024, 47.87512411390032, 47.876534598214285, 45.16479860033308, 43.79782043184553, 42.26602751868111, 43.84603745596749, 45.10208763395037, 42.81169387272426, 44.446667534964426, 47.3278249331883, 46.065319878714426, 44.501214368002756, 41.4737001146589, 41.772048813956125, 39.87377316611153, 42.1645838192531, 42.06133358819144, 41.35048770904541, 41.33643845149449, 42.93933228084019, 48.77852194649832, 50.27023070199149, 53.8204996245248, 55.54778357914516, 52.751665183476035, 54.0453120640346, 53.06915616989136, 48.70076813016619, 52.09269455501011, 56.883988176073345, 54.20799371174404, 55.47780132293701, 50.44739934376308, 54.334395340510774, 56.79231711796352, 56.74109499795096, 60.9002171925136, 34.27898638589041, 3.74422093800136, 43.18925551005772, 43.288253443581716, 58.7577679497855, 45.53689200537545, 3.2982786042349677, 15.862219742366246, 25.11515838759286, 42.486129079546245, 46.94385705675398, 32.793416363852366, 32.58111415590559, 33.414283071245464, 23.096472195216588, 33.385986532483784, 23.575745037623815, 26.25889614650181, 59.362587792532786, 65.64479460035051, 44.36985172544207, 0.2907070107758045, 0.18206385123942578, 0.037782824731298854, 0.06460366517837558, 0.020373329453702484, 0.07519105742020266, 0.17972883582115173, 0.14538751356303692, 0.17153591902128287, 0.20443829920675072, 0.127791377050536, 0.1538599460784878, 0.14799467580659048, 0.20911565822150024, 0.26781557340707096, 0.29760190365569933, 0.35296314156481196, 10.418077724320547, 89.59546443394252, 57.75452102933611, 60.289845739092144, 51.62815884181431, 48.227602754320415, 51.2598591532026, 53.081131390162874, 48.017193930489675, 95.51840768541608, 59.95983409881592, 8.719833765711103, 16.829574005944387, 35.94767618179321, 70.07336793627057, 64.42818587166923, 60.30962726048061, 39.08195645468575, 0.8246236081634248, 1.7578206360340118, 58.837929316929404, 62.20608942849295, 64.45547144753593, 57.86063739231655, 66.91819095611572, 59.82553931644985, 65.68201610020229, 55.360897881644114, 54.73918349402291, 53.552253995622905, 53.12128850391933, 49.18747901916504, 48.932869229997905, 44.55776228223528, 48.00013262884957, 46.041991301945274, 46.60355166026524, 46.82362542833601, 45.7464531489781, 46.34799691608974, 49.77813148498535, 48.09237691334316, 49.16178110667637, 50.8262220791408, 49.624826431274414, 47.41991983141218, 49.09041615894863, 49.00175714492798, 52.52953822272164, 50.89590556280953, 52.10752548490252, 52.24186890465872, 49.097048214503694, 50.677499362400596, 53.88777903148106, 50.51961544581822, 49.96419382095337, 49.507999420166016, 51.1254323550633, 47.818944454193115, 54.58572210584368, 39.88379941667829, 30.113972118922643, 22.44642652784075, 13.809285010610308, 15.097464527402606, 18.346466507230485, 25.865091357912334, 49.94357851573399, 51.30209377833775, 59.913774490356445, 57.6020428112575, 42.16386120659964, 38.13726895196097, 41.751304967062815, 39.20745481763567, 32.79537922995431, 32.783021858760286, 33.31896768297468, 37.402337142399375, 40.578449044908794, 41.704970904758994, 43.6309802872794, 49.19446195874895, 43.51425402505057, 35.062538215092246, 34.82459715434483, 44.969630650111604, 18.60163562638419, 13.07683197089604, 13.786877938679286, 26.997901337487356, 33.82951784133911, 32.27697760718209, 44.74694435937064, 51.305793694087434, 50.46387004852295, 50.26118414742606, 47.89701093946184, 49.037373610905235, 51.52069105420794, 49.50395904268537, 48.45169952937535, 46.419664110456196, 45.029135022844585, 42.91900185176304, 44.409404345921104, 46.23215307508196, 45.327577522822786, 45.86175850459507, 51.25369610105242, 48.30065611430577, 48.41442939213344, 43.575512817927766, 45.38018233435494, 42.954163210732595, 44.92609323774065, 45.58486236844744, 44.37516014916556, 45.55392551422119, 47.16484451293945, 51.229589326041086, 54.76907811846052, 54.63567270551409, 55.499927861349924, 55.40906974247524, 56.53528240748814, 55.69088172912598, 50.84929704666138, 53.03439780644008, 59.345460483006065, 56.57217386790684, 58.049235820770264, 51.84780529567173, 56.36717421667916, 58.40536226545061, 58.87943090711321, 62.06989778791155, 45.09387833731515, 4.253740157399859, 41.166315283094136, 50.91976915087019, 61.45841462271554, 57.31171580723354, 9.32334908417293, 17.826814208711895, 22.771527528762817, 41.180892603737966, 52.13407107761928, 58.69709627968924, 42.12758118765694, 36.57490049089704, 28.15001514979771, 44.94904661178589, 30.187230450766428, 33.44157212121146, 66.21837534223283, 76.82496724809918, 55.89348772593907, 0.43769438777651104, 0.2879210002720356, 0.1828280852309295, 0.23626885190606117, 0.12363026104867458, 0.09390304477087089], [0.10804606229066849, 0.031923739306096516, 0.05170218014557447, 0.030028601177036762, 0.09057265240699053, 0.019317535750035728, 0.04543193303314703, 0.2000668780612094, 0.11232755040483815, 0.1746096826557602, 0.20510187931358814, 4.538704454898834, 59.216210092817036, 54.48510524204799, 38.9547175679888, 26.74283470426287, 37.36645664487566, 34.39002207347325, 36.330806800297324, 41.11056988579886, 58.214505672454834, 41.82808950969151, 14.17690290723528, 4.070671192237309, 7.350620014326913, 38.38007722582136, 58.026084423065186, 52.23649099894932, 52.77879442487444, 15.771200077874319, 0.12385914448116507, 23.95014524459839, 70.87730230603898, 51.86651332037789, 60.33465467180525, 56.94649417059762, 58.51824269975935, 48.893365246909006, 53.84312990733555, 51.087300641196116, 48.450514861515586, 46.159884861537385, 46.01344462803432, 43.733031954084126, 44.834005287715364, 41.030988693237305, 44.66133560453142, 42.755475997924805, 44.81241723469326, 42.426909582955496, 44.09929582050869, 44.07686356135777, 45.438324860164094, 44.10179022380284, 45.627708435058594, 44.738821915217805, 45.86575024468558, 47.58542939594814, 47.68738031387329, 47.58620759419033, 48.11477443150112, 47.10473912102835, 46.396217414310996, 47.72667932510376, 50.77420786448887, 44.5641268321446, 44.88722848892212, 44.363014698028564, 46.39159338814871, 47.18951756613595, 49.228303159986226, 33.428957666669575, 5.217709345476968, 6.732397096497672, 3.973767272063664, 0.941071399620601, 1.5667736189705985, 5.31863670689719, 21.978253432682582, 28.304760217666626, 28.19647775377546, 49.205318519047324, 63.30604485103062, 34.65859079360962, 20.826803173337662, 23.717488288879395, 26.87557656424386, 31.847439970288956, 32.81994111197335, 27.312976087842667, 27.917102847780498, 31.849441051483154, 35.75050367627825, 36.361208643232075, 21.37896261896406, 45.41212320327759, 64.57039465223039, 32.01891803741455, 20.50480628013611, 14.858156408582415, 3.8604160973003934, 2.4225708629403795, 1.5667136907577515, 5.381139661584582, 8.921284624508449, 20.484993491853984, 38.993714332580566, 47.397609165736604, 47.23830434254238, 47.84974234444754, 48.45133127485003, 45.340501172201975, 44.574153082711355, 44.930237838200156, 44.23158604758126, 41.861051763807026, 43.22007424490792, 42.075841426849365, 40.1681683404105, 42.53257431302752, 41.932642527988975, 40.131485325949534, 40.442132336752756, 39.81436606815883, 42.03889438084194, 38.301076207842144, 38.078466347285676, 39.11137512751988, 39.259448187691824, 37.17223712376186, 39.031074796404155, 39.10757793698992, 45.44537728173392, 46.35923910140991, 53.76670667103359, 46.95200034550258, 50.77302319662911, 52.602199009486604, 53.53239951814924, 49.77656119210379, 53.12777812140328, 54.402303559439524, 56.943954604012625, 51.92468711308071, 56.72610773359026, 51.938583510262625, 57.73530231203352, 53.655559812273296, 56.912673813956125, 9.984391144343785, 4.870538694517953, 49.441762242998394, 37.0164863041469, 59.61600249154227, 25.467477219445364, 1.185773708990642, 11.628694500241961, 28.5024607862745, 34.25342396327427, 30.026890345982142, 32.22521700177874, 44.68137420926775, 24.763225180762156, 30.939946174621582, 38.1766756602696, 40.340375968388145, 31.55850955418178, 41.45581892558506, 53.76309360776629, 41.30885410308838, 0.6653110225285802, 0.1685601765555995, 0.036852213953222544, 0.05958366633525916, 0.025474667682179382, 0.09455129677163703, 0.2757604313748223, 0.03792671826002853, 0.06740864752126591, 0.041817115752824714, 0.017563324255336608, 0.11280117463320494, 0.09895632575665202, 0.20435439156634466, 0.0818435504500355, 0.11737503670156002, 0.0985369843297771, 9.252921274730138, 71.35979911259243, 59.701659883771626, 43.901414598737446, 23.805353471211024, 41.50956671578543, 36.78091805321829, 39.827519008091514, 42.313810280391145, 59.23920168195452, 39.03099141802107, 14.113643901688711, 8.1107086454119, 8.044823220797948, 37.88343388693673, 65.59854044233049, 56.91816289084298, 58.480937821524485, 20.785166093281337, 0.04746637100886021, 18.514956848961965, 73.30182061876569, 55.944893973214285, 64.12509850093296, 57.5001266343253, 65.81840923854283, 53.083215849740164, 58.205605030059814, 52.956689153398784, 52.64211988449097, 47.49836499350411, 44.5344614982605, 44.14589044025966, 47.69958482469831, 42.331364904131206, 45.92280190331595, 45.10253579275948, 45.099280561719624, 43.04583426884243, 44.756015232631135, 47.403938974652974, 48.127830096653526, 45.01442916052682, 48.15668249130249, 47.373617036002024, 49.25834369659424, 50.7415964944022, 52.57726887294224, 52.631169523511616, 52.5443309375218, 49.355264118739534, 51.06635182244437, 50.81824207305908, 53.95808785302298, 48.743648937770296, 47.24481133052281, 44.5161634172712, 48.31977408272879, 50.946339062282014, 53.89948674610683, 34.73036221095494, 5.849595461572919, 8.729168670518057, 9.509749276297432, 2.5544211821896687, 4.3502150263105115, 8.380652240344457, 26.257855653762817, 36.23983056204659, 33.284035614558626, 43.48719426563808, 52.06340094975063, 34.652868952069966, 24.690050227301462, 31.461019379752024, 34.389462743486675, 42.78520039149693, 40.4335686819894, 35.655650343213765, 36.511616298130576, 41.16240692138672, 41.85703223092215, 43.033320563180105, 36.14954219545637, 44.30367708206177, 54.192881379808696, 38.349671908787315, 32.03945343835013, 18.59554726736886, 7.3894708667482645, 8.274261423519679, 5.080260515213013, 12.643328649657112, 13.961762360164098, 22.177597250257218, 40.226609638759065, 50.87513739722115, 48.483897481645855, 51.275388377053396, 52.011140074048726, 49.72837890897478, 47.586315291268484, 48.01516853060041, 47.586238861083984, 47.1074732371739, 43.335407393319265, 43.389155183519634, 44.743366037096294, 42.98983178819929, 44.487672328948975, 43.93621812547956, 46.60188756670271, 43.72233520235334, 45.096185139247346, 42.6697039604187, 42.23776224681309, 42.646073137010845, 41.47158786228725, 42.20320538112095, 42.522975376674104, 41.28411156790597, 50.64337675912039, 47.13899721418108, 54.93540062223162, 52.27229159218924, 54.4690375328064, 53.11301319939749, 54.10289525985718, 47.475790296282085, 53.65453495298113, 56.80549785069057, 57.95289209910801, 51.7775034223284, 57.01363808768136, 51.969496045793804, 63.04064450945173, 55.3398448399135, 58.583917072841096, 6.943099915981293, 8.004359517778669, 57.19018139157976, 42.81951754433768, 60.54680401938302, 24.29723903111049, 2.392615876027516, 18.188837936946324, 24.599699326923915, 41.74173729760306, 35.690697056906565, 23.900802612304688, 42.229782240731375, 24.03826924732753, 37.32578189032418, 39.868725299835205, 36.52279594966343, 32.16759559086391, 50.45090470995222, 63.31585570744106, 50.58683231898716, 1.501715355685779, 0.1351726981145995, 0.10485702234187297, 0.045157112779894044, 0.010582364297338893, 0.13729617345545972, 0.30237211340240067, 0.1494903705481972, 0.11471954919397831, 0.09459853637963533, 0.2673509940505028, 0.12732412426599435, 0.15851546983633721, 0.42160453115190777, 0.29518268204161097, 0.35066165934715954, 0.5285507696015495, 12.567363125937325, 89.45675754547119, 67.59906578063965, 54.50315318788801, 32.29453917912075, 49.356973375592915, 48.0509170123509, 50.34956175940377, 46.06484045301165, 68.95200511387416, 49.54696144376482, 21.597665854862758, 9.025301762989589, 17.087833336421422, 48.10937915529524, 68.20506681714738, 61.04539980207171, 63.51649188995361, 17.939943041120255, 0.18569642917386123, 27.90488965170724, 75.21854373386928, 55.469237668173655, 65.60850415910993, 61.49872807094029, 66.87288870130266, 54.284378732953755, 57.3578587940761, 54.59900706154959, 55.434979575020925, 50.07950265066964, 49.37195021765572, 47.55011517660958, 50.50923483712332, 45.573265824999126, 48.46828487941197, 46.87126922607422, 48.17229856763567, 45.223618575504844, 47.93251970836094, 50.08327899660383, 49.82442385809762, 48.13982268742153, 51.592010838644846, 50.401447432381765, 51.82121106556484, 55.267858028411865, 53.16612522942679, 53.93584319523403, 53.507792472839355, 51.855180808476035, 54.233010700770784, 53.588210923331125, 56.122674056461875, 52.921993323734824, 49.77557454790388, 50.56599814551217, 51.29128238133022, 52.48543800626482, 55.44928591591971, 48.192093985421316, 23.306147984095983, 9.121970312935964, 15.68261923108782, 2.982598057815007, 6.490558530603137, 7.470459069524493, 29.943796839032853, 43.53020708901541, 39.97585957390921, 62.56501252310616, 67.1357112612043, 39.835519858769004, 29.369858264923096, 32.615900312151226, 35.29365961892264, 37.992079394204275, 32.68118211201259, 32.46786199297224, 31.43136099406651, 37.508172103336875, 41.53210319791521, 44.807021958487375, 37.21097680500576, 45.21177537100655, 56.56774091720581, 44.14202724184309, 38.3225530896868, 22.883664505822317, 5.096792885235377, 6.689623985971723, 5.758600550038474, 16.25580392565046, 21.421416112354823, 33.305088656289236, 49.72174685341971, 52.819420542035786, 48.8809175491333, 50.90079362051827, 52.17305047171456, 50.54243332999093, 50.17994580950056, 48.94335058757237, 48.84054504122053, 47.75183527810233, 45.839593751089915, 44.75788082395281, 46.843309674944194, 46.06638642719814, 47.74880238941738, 46.58218247549874, 48.62577274867466, 47.133511611393516, 46.86942795344761, 46.15528515407017, 44.978437491825645, 45.5038046836853, 43.92247806276594, 43.96470921380179, 44.466285773685996, 42.7768486567906, 53.39693743841988, 49.7899295261928, 58.23327275684902, 53.322831426348, 55.78900766372681, 55.38033199310303, 58.713480131966726, 50.29752322605678, 55.37941830498831, 58.89320918491909, 61.94329466138567, 53.578664098467144, 60.93196351187569, 54.19253396987915, 64.65212631225586, 58.628788539341514, 65.72339957101005, 14.30298752444131, 6.662339278629847, 62.62859548841204, 46.405597482408794, 67.00134699685233, 33.62236424854824, 6.194792824132102, 17.77737603868757, 36.3518112046378, 41.588529518672395, 36.31536790302822, 37.13729115894863, 58.386574336460654, 31.383498328072683, 39.55592434746878, 48.88226202556065, 53.476511682782856, 40.27173471450806, 60.08019079480852, 71.22634506225586, 64.89003263201032, 2.1485497610909596, 0.3747968514050756, 0.2598219694835799, 0.19195811317435332, 0.12543797333325657, 0.3711564838886261], [0.11227614459182535, 0.07563796772488526, 0.06447618201907192, 0.049487943960619826, 0.11263245011546782, 0.004574745860216873, 0.06713988658572946, 0.10168382618576288, 0.006620311810235892, 0.36602309505854336, 0.11713027554963316, 8.695365684373037, 60.037987436567036, 47.24334178652082, 33.187031814030235, 35.62857321330479, 36.40485027858189, 36.68840626307896, 23.34505442210606, 14.06645347390856, 29.86139120374407, 26.615607976913452, 23.213976655687603, 8.686839376177106, 3.8032936538968767, 16.187232153756277, 58.38878386361258, 53.279658794403076, 46.5800632749285, 42.77012627465384, 2.8131582013198306, 0.4151293528931481, 43.35535567147391, 65.01302964346749, 59.33338451385498, 53.27422530310494, 56.63579504830496, 52.38563755580357, 55.128091539655415, 50.33776371819632, 46.23731211253575, 43.99125133241926, 45.22077676228115, 43.31238106318882, 42.273938042776926, 42.61333669934954, 43.89162458692278, 44.23994820458548, 43.7890031678336, 41.64112390790667, 43.211712087903706, 42.28487450735909, 43.49592120306832, 45.10744816916329, 47.31959479195731, 47.23856142589024, 47.24541582380022, 49.75198541368757, 52.46899162020002, 50.29898929595947, 47.559338910239084, 47.3350510597229, 47.6655455998012, 46.50680841718401, 47.5111357825143, 48.94108894893101, 49.58438444137573, 48.46129846572876, 47.13092688151768, 49.12966305868966, 41.20480830328805, 7.598681126322065, 4.703362430844988, 4.619849426405771, 0.8126585387757846, 0.15585791958229883, 0.08443803765944072, 2.29582508121218, 12.307667255401611, 12.999836376735143, 42.299875668116975, 33.71664088112967, 21.233918973377772, 26.53089553969247, 22.313125337873185, 20.01477415221078, 18.418699979782104, 18.350116048540386, 26.568407126835414, 23.373965876443044, 23.788550989968435, 20.7296256678445, 18.688144172940934, 10.489241174289159, 12.553695150784083, 26.163433109010967, 47.82239423479353, 57.7936498097011, 23.123929738998413, 14.470787388937813, 8.149646350315638, 0.8228476920298168, 0.5886669637901443, 2.372214879308428, 6.0125090054103305, 7.194819688796997, 20.267907449177333, 37.68312774385725, 48.36549322945731, 49.36792721067156, 48.073078291756765, 43.48921619142805, 45.364305700574604, 44.9977639062064, 44.353898661477224, 42.81284727369036, 42.078009264809744, 44.937741892678396, 43.336581638881135, 45.28493990216936, 45.15972988946097, 43.75766331808907, 43.45644848687308, 41.24713325500488, 43.240481104169575, 39.93155785969326, 39.08348853247506, 40.43115765707833, 39.49130957467215, 38.63228293827602, 37.494470255715505, 38.023499148232595, 43.84319216864449, 45.98073945726667, 52.71829298564366, 49.32087400981358, 51.73495960235596, 51.2080533845084, 52.245207514081685, 53.4389705657959, 52.051467418670654, 52.7250257900783, 56.7616651398795, 52.94520378112793, 52.90154824938093, 55.29164171218872, 56.75298336574009, 54.419934613364084, 39.24190398624965, 0.3751477082925183, 24.307407719748362, 48.980453968048096, 36.28852701187134, 56.07344606944493, 10.928278735705785, 0.3583224554147039, 20.99551933152335, 56.75353922162737, 42.807973112378804, 19.113283600125992, 12.443264825003487, 34.09195825031826, 28.306267976760864, 25.940593957901, 34.242115770067485, 30.962955134255544, 21.761817046574183, 38.318769795554026, 53.98060001645769, 38.835038321358816, 1.4110330045223236, 0.03514450415968895, 0.10925121512264013, 0.053866937556969266, 0.09783353350524392, 0.15090822375246457, 0.11175824595349175, 0.12158601145659174, 0.10407273764056818, 0.08600881908621107, 0.05293789080211094, 0.029694863728114536, 0.024217815570799366, 0.07572009081819228, 0.10396060972873654, 0.19942043774894305, 0.3037070089152881, 14.281462873731341, 74.60738713400704, 52.97400059018816, 35.22204801014492, 38.86524561473301, 42.367895058223176, 37.4880188533238, 30.386817455291748, 19.566742147718156, 33.691735063280376, 25.223901169640676, 18.070697716304235, 7.495614153998239, 5.944680256502969, 17.26271080970764, 61.644563811165945, 59.135138511657715, 50.45138760975429, 47.8803700038365, 4.637196038450513, 0.34181763391409603, 33.61374500819615, 63.13873222896031, 60.24616241455078, 56.30783312661307, 61.19584914616176, 59.590995924813406, 55.99599797385079, 52.12676157270159, 52.62075069972447, 47.58544329234532, 44.97330972126552, 40.516040325164795, 43.96323619570051, 44.73615380695888, 47.44610411780221, 45.85944822856358, 46.6865895816258, 43.258230277470176, 47.335579122815815, 46.38269621985299, 51.09285920006888, 49.26968663079398, 49.91464969090053, 50.141011578696116, 47.44114310400826, 49.20608629499163, 54.76377316883632, 53.46489429473877, 48.96404579707554, 46.650257451193674, 50.05708081381661, 47.351862226213726, 48.03193800789969, 49.631746837071006, 46.925718784332275, 49.362802914210725, 47.57950258255005, 53.49894046783447, 42.86288472584316, 10.712363464491707, 5.663579157420567, 8.363710795130048, 1.6987553025994981, 0.36273912127528873, 0.37162619296993527, 6.219619606222425, 13.61261190686907, 22.424515383584158, 46.74475990022932, 27.25754335948399, 24.87661283356803, 29.396494184221538, 27.723421812057495, 24.87771759714399, 24.136353492736816, 23.590207712990896, 32.58245863233294, 30.08201387950352, 29.28202608653477, 29.967476299830846, 28.366903168814524, 19.017546108790807, 15.337252071925572, 33.38364151545933, 43.288948263440815, 47.65212862832205, 28.49873307773045, 19.99180861881801, 14.244769436972481, 1.0234586873224802, 0.10578641175691571, 3.257377381835665, 9.642749956675939, 11.822310396603175, 20.13097061429705, 42.643467562539236, 51.41951486042568, 50.949382373264854, 49.653939383370535, 47.25928790228707, 46.50382763998849, 47.21399259567261, 48.48777110236031, 45.82242127827236, 41.944683756147114, 44.26668834686279, 46.476729665483745, 46.715025084359304, 44.40411329269409, 47.19837999343872, 47.41694252831595, 44.99579756600516, 44.499161175319124, 44.644065856933594, 45.32819938659668, 45.63660907745361, 44.388639654432026, 42.884000301361084, 41.753653458186555, 42.86536523274013, 48.99394736971174, 48.034081527165, 52.29557153156826, 55.83197184971401, 58.1423590523856, 54.88100664956229, 52.9326935495649, 53.05241795948574, 54.44794627598354, 55.30669845853533, 57.53883157457624, 53.87897218976702, 54.65671532494681, 57.58192777633667, 57.29980659484863, 57.737553528376985, 28.69388539450509, 0.28042641814265934, 33.193695136478965, 54.01076909473964, 41.870904309409006, 56.16434587751116, 10.8923339673451, 1.5321647503546305, 19.18796283858163, 39.66127640860421, 41.88899394444057, 23.526885305132183, 13.491801840918404, 38.46895858219692, 26.389352049146378, 28.823083673204692, 35.99279430934361, 33.397940908159526, 24.198510340281896, 41.760282039642334, 62.05941990443638, 46.41678408214024, 2.5756980861936296, 0.4133704001350062, 0.10890157959823098, 0.08889593809310879, 0.11444551604134695, 0.10206949870501246, 0.28318401159984724, 0.22866659983992577, 0.1347366307995149, 0.18747849283473833, 0.16880428631390842, 0.08616282617939369, 0.11892187941287245, 0.1428460335092885, 0.2260925636759826, 0.3180263505450317, 0.31052653012531145, 16.43808123043605, 89.2835111618042, 62.22671863010952, 47.699689047677175, 48.55758660180228, 51.93000248500279, 49.43008926936558, 37.2809590612139, 18.553616625922068, 45.38772807802473, 32.22609942299979, 32.09014402117048, 16.122556584221975, 10.767522607530866, 24.16927753176008, 65.78518990107945, 64.35289519173759, 53.82336228234427, 50.09019245420183, 3.0692095245633806, 0.41900202365858213, 49.295752797807964, 66.83330481392997, 61.83954416002546, 54.63670103890555, 62.25469902583531, 61.48459543500628, 61.205138887677876, 53.68623958315168, 53.8272636958531, 50.87203502655029, 50.34871060507638, 45.92086683000837, 48.58979150227138, 47.72259031023298, 50.55838291985648, 51.72215754645211, 49.735327107565745, 45.587381090436665, 49.73780066626412, 47.72298288345337, 52.97974675042288, 51.49683094024658, 52.22209780556815, 54.12779412950788, 52.349343640463694, 53.649195262363975, 58.8110328401838, 55.42311552592686, 54.48322228022984, 51.31560802459717, 53.163811479296, 49.45680161884853, 55.77215133394514, 52.36058235168457, 55.73132371902466, 50.60338640213013, 51.78016110828945, 54.17560468401228, 52.23345463616507, 31.128454276493617, 7.969581178256443, 11.603211981909615, 2.938891283103398, 0.30420318086232456, 0.3227493071130344, 8.918701631682259, 19.187188114438737, 32.36184637887137, 60.23918642316546, 44.09755529676165, 44.05787066050938, 38.263441290174214, 30.121611663273402, 28.618526969637188, 34.218585695539204, 28.414652926581248, 37.38133273805891, 35.27925600324358, 33.432112148829866, 28.568793501172745, 30.941749232155935, 18.097733157021658, 14.793114321572439, 38.91415398461478, 55.657103061676025, 58.20717532294137, 40.62944882256644, 25.37365048272269, 14.990622077669416, 0.9975876126970563, 0.41579852412853924, 3.462306899683816, 13.771720443453107, 17.356622661863053, 33.56126526423863, 51.26486185618809, 53.35940326963152, 51.03692272731236, 50.61699444907052, 46.431941577366416, 47.74576255253383, 49.630218233381, 49.653571128845215, 46.622079031808035, 44.323885917663574, 49.17637927191598, 50.122258390699116, 50.760592869349885, 48.376287255968364, 50.39905725206648, 48.81048018591744, 47.540943554469514, 49.06994676589966, 46.726482663835796, 44.711706570216585, 46.14896924155099, 45.4849715914045, 44.85455111094883, 42.894815172467915, 41.85633046286446, 50.869036878858296, 49.37941953114101, 54.13252932684762, 55.94090223312378, 57.9705822127206, 55.74806540352957, 57.736730166843955, 55.87479359763009, 56.54581240245274, 57.2331177847726, 61.571982928684776, 57.25551530293056, 58.782989910670686, 61.056975500924246, 63.92924962724958, 60.121303285871235, 46.57776689529419, 1.0926308270011629, 29.9307724407741, 63.85682855333601, 46.92080640792847, 62.83088534218924, 18.89353813443865, 3.1851523774010793, 28.24866567339216, 65.85774299076625, 50.8609630720956, 23.89973953792027, 15.765877757753644, 45.271196365356445, 37.29083939961025, 32.19112566539219, 42.75838729313442, 44.82418748310634, 31.61005823952811, 53.1404481615339, 73.57655933925084, 66.48524870191301, 4.300407733236041, 0.5872315093874931, 0.3682870407189642, 0.19203447550535202, 0.09945829239274774, 0.2596440033188888], [0.09482599488858666, 0.1640279833227396, 0.07734527718275785, 0.1546829140612057, 0.04113660280459693, 0.161668934194105, 0.0698356790734189, 0.3200680081333433, 0.16767405053334578, 0.10977609588631562, 0.38381615600415636, 7.992180194173541, 62.299362046378, 44.607132707323345, 32.914669377463206, 27.075691631862096, 37.35792078290667, 24.206405230930873, 16.74437345777239, 21.107699734824045, 29.264513151986257, 24.506091458456858, 14.433640582220894, 6.728674599102565, 6.560717531612941, 17.93963210923331, 42.84042814799717, 60.598297119140625, 55.880459853581016, 52.68155785969326, 17.352450268609182, 0.10585818040583815, 0.9449405691453389, 26.15106357846941, 53.392824104854036, 55.85220847811018, 54.38124704360962, 54.94105645588466, 51.674586704799104, 45.871142046792166, 47.24786853790283, 43.52497162137713, 42.12083796092442, 40.83457701546805, 40.647986616407124, 45.127768175942556, 47.714582511356895, 44.89612913131714, 45.20204789297921, 43.12103462219238, 42.38790587016514, 44.87108087539673, 46.91221843447004, 47.44740343093872, 47.8964272907802, 45.69432428904942, 48.06697082519531, 48.66675669806344, 50.846722739083425, 49.254807063511436, 47.38826731273106, 45.98488058362688, 45.22968087877546, 45.477231298174175, 44.62737280981881, 39.49521446228027, 34.29589830126081, 44.27622127532959, 48.33471270969936, 44.96839039666312, 21.184336628232682, 6.356810050351279, 2.9982638571943556, 0.8644162129078592, 0.5807382006730352, 0.37157343008688515, 0.1025741659104824, 0.7690905651875904, 6.170277842453547, 15.358600412096296, 31.05369860785348, 19.114197288240703, 15.148019620350428, 17.75663913999285, 15.057887588228498, 8.615826181003026, 7.986686774662562, 9.412391117640905, 11.554467763219561, 7.987896629742213, 4.643023840018681, 2.0197318962642123, 1.2842867885317122, 2.605625931705747, 7.513983454023089, 6.765074908733368, 19.077392680304392, 36.808266162872314, 24.93234086036682, 7.608903663499015, 9.662459390504019, 1.1349516532250812, 0.41177065883363995, 0.5565108635595867, 2.7659990404333388, 2.151166843516486, 9.758727550506592, 19.80046738897051, 41.434383732931956, 48.06370864595686, 48.19016586031233, 46.09916802815029, 45.161519050598145, 45.94665854317801, 45.207446643284385, 42.319889954158235, 41.08414936065674, 42.61121402468, 43.38214792524065, 44.4676684652056, 46.56728206362043, 47.92637750080654, 45.93872022628784, 43.22986078262329, 41.24790450504848, 39.73690755026681, 40.78107936041695, 39.93872492653983, 43.23448133468628, 40.3084385735648, 39.34922933578491, 41.392503465924946, 43.407352515629356, 46.18448148454939, 48.63181420734951, 53.80811446053641, 51.03197908401489, 51.50782993861607, 50.798933029174805, 54.48088421140398, 50.6050956589835, 53.35188184465681, 53.16530534199306, 53.86059420449393, 55.467573574611116, 54.91866588592529, 55.255629198891775, 56.0621726172311, 3.060771805899484, 1.0414464878184455, 41.47995696749006, 39.95983702795846, 51.26426083700997, 45.99614708764212, 6.775633999279567, 3.714288966996329, 18.170772620609828, 45.17132643290928, 65.96555124010358, 53.49549763543265, 12.34346090044294, 16.339948347636632, 30.77224097933088, 27.147329296384537, 29.115323168890818, 36.77284772055489, 28.622101817812236, 35.720091411045615, 55.3345433643886, 27.296922274998256, 0.9348251862185342, 0.267177370509931, 0.11264327953436545, 0.09003479805375848, 0.04645671768646155, 0.11428988724946976, 0.17675449113760675, 0.07390858552285604, 0.19263803240443977, 0.11891942311610494, 0.0832043117178338, 0.18707910712276185, 0.1384438747274024, 0.28664926279868397, 0.5231775322130748, 0.08842973025249583, 0.21238764907632554, 12.123355865478516, 78.54671001434326, 54.38977943147932, 36.91669627598354, 27.049599409103394, 43.595481940678184, 34.11743034635271, 23.268806627818517, 21.48297541482108, 34.11602333613804, 21.06631973811558, 16.62642083849226, 7.625685300145831, 7.336850421769278, 20.176290239606583, 45.72501795632498, 64.37781838008335, 59.046111243111746, 55.29438625063215, 20.570555346352712, 0.22738412794257912, 0.36539417452045847, 20.619567939213344, 51.69166190283639, 57.052662645067485, 61.24611241476876, 57.437561580113, 52.50571632385254, 49.27554048810686, 51.926406792231965, 46.62827682495117, 43.697227886744905, 42.719529492514475, 47.4790073122297, 50.299378395080566, 52.628286021096365, 52.23032099860055, 50.238022327423096, 47.20266008377075, 47.65645040784563, 48.40325321469988, 52.43353148869106, 50.974646023341585, 53.39447430201939, 51.547580582754954, 53.212556566510884, 53.82801410130092, 53.2987003326416, 51.37247903006417, 50.08521406991141, 47.98223059517996, 48.27338443483625, 52.145358426230295, 50.125093255724224, 44.156448228018625, 38.57703433718, 40.852367877960205, 46.83524629047939, 47.41369424547468, 20.00828627177647, 5.641302364213126, 4.6951375007629395, 3.0518370739051273, 0.49517526051827837, 0.5610950461455754, 0.5651784698878015, 4.0721046924591064, 9.922734567097255, 18.14725991657802, 29.901774133954728, 23.10946532658168, 24.122880935668945, 26.10136137689863, 20.68811365536281, 11.612209030560084, 8.245127626827784, 9.003266419683184, 10.785610505512782, 7.574537004743304, 3.3030281322343007, 3.0381834294114793, 2.206388737474169, 2.9598420560359955, 12.419640949794225, 13.827655179159981, 21.60435697010585, 36.982110091618125, 25.46271596636091, 13.528811420713152, 15.235671145575386, 3.120247734444482, 0.34088282978960444, 1.1854764563696725, 3.796623383249555, 6.806643809591021, 12.912335974829537, 21.55054317201887, 42.400548117501394, 49.20648929050991, 52.436355931418284, 48.29929774148123, 47.85295936039516, 44.308311530521934, 45.00347185134888, 42.85672514779227, 40.74533435276577, 43.045240197862896, 47.78224406923567, 44.854964528764995, 47.573916230882915, 50.123224190303254, 47.81084285463606, 43.42180824279785, 42.83026988165719, 45.20630019051688, 45.83656781060355, 43.05716678074428, 43.681861945560996, 41.04455852508545, 41.603853770664756, 42.8872902733939, 45.076125689915244, 44.62427738734654, 50.03688587461199, 55.56365326472691, 54.814283098493306, 53.636532170431956, 55.95812681743077, 53.808333328792024, 55.52111291885376, 57.898751735687256, 58.22978823525565, 55.411053453172954, 57.352331502096995, 55.20296880177089, 57.048604897090364, 46.28449732916695, 0.7472939576421465, 2.6026101963860646, 47.44442960194179, 46.21069703783308, 59.142677307128906, 51.82963228225708, 10.906314611434937, 5.0944543821471076, 13.805931636265345, 41.30766248703003, 59.40473556518555, 51.622864314488, 13.331233314105443, 25.390979290008545, 28.39963960647583, 25.864540713174, 33.81247738429478, 36.62426744188581, 25.66148829460144, 42.77647692816598, 67.37195001329694, 40.02092906406948, 1.4382021980626243, 0.5883156454988888, 0.19020453441355908, 0.20872854042266095, 0.11393429418759686, 0.07222718931734562, 0.19252489347543034, 0.32853267820818083, 0.1736958995461464, 0.2816164328583649, 0.19768329310630048, 0.344350985118321, 0.20130743006510393, 0.3453106779072966, 0.661451841039317, 0.24961981549859047, 0.31061406114271706, 16.442568029676163, 91.91020120893205, 59.937877791268484, 48.506055286952424, 35.01800373622349, 51.90552398136684, 41.40717806134905, 27.404466492789133, 25.765259640557424, 39.47522102083479, 29.072581325258525, 21.881301743643625, 12.187458208629064, 12.737981353487287, 25.241664239338466, 50.04346581867763, 68.8487548828125, 62.976616859436035, 61.72330774579729, 22.453703028815134, 0.31770575631942066, 1.6807102880307605, 31.93567861829485, 55.5870999608721, 59.06208515167236, 61.653353282383506, 57.82498271124703, 51.83405828475952, 50.8024696622576, 51.920653683798655, 48.351221629551475, 44.3004218510219, 43.19135734013149, 48.31519521985735, 51.315208503178184, 53.93891429901123, 54.380385466984336, 50.125197478703086, 47.757956641060964, 49.10852663857596, 50.478916372571675, 52.93648031779698, 52.945207255227224, 55.51937934330532, 56.640360014779226, 56.17273235321045, 57.06627069200788, 59.36024624960763, 56.13715410232544, 54.68902097429548, 53.56784922736031, 51.41344560895647, 55.864253180367605, 54.300602776663645, 51.37858302252633, 43.16725403921944, 48.941676071711946, 47.997325556618826, 50.22962195532662, 36.92173024586269, 14.131216764450073, 8.255252889224462, 6.446036645344325, 0.6431024085198129, 0.8671435979860169, 0.8393475466540882, 8.056663819721766, 20.498596327645437, 32.64533635548183, 39.78922748565674, 22.341817923954554, 32.18373278209141, 31.87271056856428, 27.270637239728654, 18.756293841770717, 16.4158330985478, 18.31762453487941, 16.923789841788157, 14.158286077635628, 8.619681562696185, 3.4530812118734633, 3.367354120526995, 3.02629006760461, 10.237023302486964, 27.67627133641924, 37.87583255767822, 44.30485827582223, 31.33572598866054, 29.339842047010148, 21.915940250669205, 4.309029144900186, 0.32178391462990213, 1.1724127573626382, 6.29471834216799, 13.706486412457057, 20.747244562421525, 31.01696000780378, 50.647271224430625, 51.934640407562256, 54.58746957778931, 45.50469057900565, 48.608853885105674, 46.16489103862217, 50.184580257960725, 43.33759607587542, 45.74916989462716, 47.75693525586809, 51.58307892935616, 48.90727554048811, 51.32506104878017, 53.74635192326137, 49.63271263667515, 47.821490968976704, 46.028873103005544, 47.02512318747384, 47.26139668055943, 43.782610825129915, 45.74969448362078, 44.14730092457363, 43.78538315636771, 45.259165559496196, 47.3943852015904, 45.8499048777989, 49.252809456416536, 57.78124380111694, 53.851818629673545, 53.49112721851894, 54.340329102107454, 57.7252447945731, 55.29783255713326, 57.196674483163015, 58.69592898232596, 56.90628147125244, 61.39312934875488, 62.65581158229283, 58.69394179752895, 63.747269357953755, 4.745807238987513, 1.8849993773869105, 51.63089990615845, 50.91724695478167, 64.82035609654018, 56.70158406666347, 12.545308675084796, 9.340044736862183, 25.727228675569805, 53.00395427431379, 69.9210842677525, 60.428114891052246, 15.878752980913434, 23.745654548917496, 41.968446595328196, 33.47965519768851, 40.32791090011597, 49.88522754396711, 38.57546751839774, 56.25018392290388, 77.14844063350132, 53.77187960488455, 1.6934105093990053, 0.5196382392730031, 0.20688428224197455, 0.2079393770545721, 0.2528103142976761, 0.22854155940668924], [0.08902734997017042, 0.27142092851655825, 0.06520492184375014, 0.11882691165166241, 0.0552359090984932, 0.18592804031712667, 0.27373030888182776, 0.15819305713687623, 0.42949611054999487, 0.11162012336509568, 0.14342479673879488, 6.983353001730783, 57.14892298834664, 47.225154876708984, 43.06731462478638, 42.384796551295686, 30.01455381938389, 23.69220379420689, 17.456777470452444, 29.135146379470825, 25.721320969717844, 21.925639935902186, 14.380037835666112, 2.8647874423435757, 4.356413687978472, 25.809568302971975, 53.38160276412964, 49.21107857567923, 47.210046018872944, 47.4999908719744, 35.44567925589425, 1.7813110841172082, 0.17899916640349797, 3.2166001413549696, 30.71612732751029, 55.38170426232474, 55.98545755658831, 52.35315472739083, 53.78578642436436, 49.14819737843105, 49.22582612718855, 42.01987716129848, 44.634758744921, 43.78078344890049, 50.14957523345947, 56.33100536891392, 55.65744004930769, 53.69381659371512, 50.35172264916556, 47.27161053248814, 45.27604273387364, 44.96344675336565, 48.70553806849888, 46.48589433942522, 49.80042478016445, 48.267040729522705, 53.084032263074604, 52.37633739198957, 50.956990650721956, 50.87284449168614, 50.56639419283186, 48.715189116341726, 46.81774377822876, 46.993314334324424, 48.812078271593364, 43.725173541477744, 35.11706072943551, 27.0641211441585, 39.64605985369001, 35.50505856105259, 3.0814670154026578, 0.8453478589653969, 1.9204573375838143, 0.9545358142682484, 0.0750360596658928, 0.6099556471620287, 2.366476535797119, 4.530260222298758, 4.616453494344439, 19.793331589017594, 25.215809992381505, 11.87404407773699, 11.003794363566808, 11.464844686644417, 6.017810046672821, 0.32809578308037346, 0.33224358622516903, 0.9444627719266074, 1.6559548335415977, 0.579354043517794, 0.24160040010299, 0.1299609113484621, 0.04412039608827659, 0.16729397592800005, 1.6659019397837775, 4.004498285906656, 5.996543347835541, 28.60179397038051, 33.33582748685564, 6.762570517403739, 13.463134442056928, 9.287776912961688, 2.045365103653499, 0.26970494059579714, 1.0583576432296207, 3.157669646399362, 4.850320305143084, 11.55263864994049, 28.384968485151017, 45.152455125536235, 49.99764244897025, 45.043806144169395, 44.06709092003958, 43.59923396791731, 41.06401348114014, 41.18353986740112, 41.150296211242676, 44.1348671231951, 44.126286097935264, 44.87896360669817, 47.6718476159232, 47.528964860098704, 48.07713951383318, 42.96693399974278, 42.26316138676235, 40.84508269173758, 38.34708023071289, 40.10323395047869, 40.33682196480887, 39.542156491960796, 38.01360838753836, 36.99791724341256, 40.0230621610369, 43.154340812138145, 47.42091689790998, 49.06272063936506, 50.96081910814558, 46.91200998851231, 50.13188164574759, 51.878033433641704, 51.52743080684117, 54.290586948394775, 54.54089232853481, 53.48529767990112, 55.33173976625715, 56.93879556655884, 58.304314613342285, 7.161734972681318, 0.469126572566373, 10.428405353001185, 47.34066867828369, 48.74451051439558, 56.053525584084646, 46.32141310828072, 19.995204550879343, 5.319699347019196, 4.4291335344314575, 30.1419803074428, 74.25620433262416, 72.10476412091936, 22.269047703061783, 13.27290231840951, 28.130195413316997, 28.749509198325022, 29.599923542567662, 37.50176586423601, 31.180746419089182, 42.9358686038426, 54.604926926749094, 30.031045368739537, 0.6343234138829368, 0.4694318047591618, 0.2454313545354775, 0.03936188089262162, 0.010856421198695898, 0.03231992233278496, 0.08904415728258235, 0.14794442350310938, 0.14089673810771533, 0.14858386133398327, 0.06715638855738298, 0.118630923596876, 0.3876147578869547, 0.7077774895089013, 0.5830455454332488, 0.24542779901197978, 0.04432650449286614, 12.363405704498291, 75.7985793522426, 51.81673295157296, 50.18410430635725, 36.772017410823274, 33.63389131001064, 34.04801436832973, 23.26341482571193, 29.169225556509836, 33.95168801716396, 18.446696008954728, 17.36137522969927, 6.297827226775033, 4.71085649728775, 26.841460909162247, 55.540873595646445, 51.78704677309309, 49.412103857312886, 49.85670518875122, 41.353947911943706, 2.848393819161824, 0.16321804321237973, 3.34028046471732, 29.686703068869456, 60.3827223096575, 60.34031745365688, 55.82496806553432, 53.236378465379985, 54.54287256513323, 50.17874724524361, 46.50567933491298, 46.651945863451274, 45.27287782941546, 55.075531891414094, 60.79943357195173, 56.674461773463655, 58.33314963749477, 52.02879197256905, 49.87013953072684, 47.30117164339338, 46.94754307610648, 50.83097812107631, 51.73541470936367, 51.344168594905305, 53.75897332600185, 56.16783387320382, 57.24576003210885, 55.91860893794468, 55.17301859174456, 50.83396932056972, 49.48129401888166, 50.74491078513009, 57.893519742148264, 54.37355538776943, 50.28395686830793, 43.31944043295724, 32.98728152683803, 44.668523515973774, 38.40669230052403, 6.911731404917581, 2.8677719107695987, 3.3770831184727803, 1.183515218751771, 0.3363715761474201, 1.055723516004426, 3.704810755593436, 8.830260617392403, 6.830987257616861, 17.80658973966326, 30.060113157544816, 20.685594933373586, 16.608937433787755, 16.922530480793544, 7.527827739715576, 0.18208209026072705, 0.5915729935680116, 1.9346648837838853, 2.0844710852418626, 0.32679356581398417, 0.18161120052848542, 0.2725252578301089, 0.23341683351567813, 0.18396681626992567, 1.8303930503981454, 7.358877079827445, 14.966986043112618, 37.10899462018694, 39.674971308027, 12.042378953524999, 18.818318673542567, 11.096919332231794, 3.212553684200559, 0.5784088713782174, 2.2479152977466583, 7.17979507786887, 9.844893029757909, 13.406127078192574, 32.666177477155415, 48.53468186514718, 49.100831508636475, 44.75310046332223, 46.58940512793404, 39.236588614327566, 45.12551695959908, 41.65995352608817, 46.116691384996685, 49.369028500148225, 48.77913686207363, 46.47767114639282, 49.3366881098066, 49.79714175633022, 49.53636196681431, 44.54032925197056, 45.59621572494507, 42.952936853681294, 42.99959748131888, 41.47598259789603, 40.936913558415, 38.7628048488072, 38.592987401144846, 36.82405594417027, 40.89644030162266, 42.175732203892295, 47.72127015250069, 50.46316828046526, 52.93658454077584, 52.0798716545105, 53.473996434892925, 52.05993379865374, 58.61144583565848, 57.37144252232143, 61.616840498788015, 53.39698607581002, 57.41609859466553, 61.961554527282715, 48.789996896471294, 0.6197369737284524, 0.18387715465256146, 12.80546920640128, 61.9219081061227, 53.071091243198936, 58.411504473005024, 52.99935456684658, 26.733267034803117, 10.320227112088885, 5.734098596232278, 31.304514680589946, 70.60770525251115, 67.27703762054443, 22.17820348058428, 21.72153660229274, 31.779076644352504, 27.333468062537058, 33.18869938169207, 38.95457165581839, 33.816597666059224, 51.09832395826067, 64.8716824395316, 39.6931061063494, 0.5276752422962869, 0.7770621574350766, 0.14212457436536038, 0.009428855613805354, 0.038626447319984436, 0.06544123523469482, 0.28946331036942347, 0.5846360857997621, 0.25160024208681925, 0.20415673431541237, 0.31735992059111595, 0.4148591602487223, 0.5393161890762193, 0.6043453567794391, 0.7510683493954795, 0.2869755838598524, 0.21887500025331974, 17.028556517192296, 90.39871788024902, 60.053780691964285, 55.93101494652884, 53.95999165943691, 44.990450927189414, 38.89194059371948, 26.464309215545654, 37.15246255057198, 40.35235813685826, 27.502234595162527, 21.52802058628627, 8.436807581356593, 11.563285027231489, 32.31791639328003, 63.21764986855643, 58.985064370291575, 56.39045763015747, 54.98905461175101, 41.93979917253767, 2.6749687365123203, 0.20296325907111168, 4.539495246750968, 34.16220453807286, 63.974475451878135, 64.49070576259068, 56.72070550918579, 55.492510659354075, 54.14158630371094, 52.86205816268921, 49.587285314287456, 47.91525343486241, 44.84228754043579, 52.81100974764143, 59.821731703622, 58.58198547363281, 59.3081556047712, 52.3962196622576, 52.286222730364116, 48.69559867041451, 50.085443360464915, 54.51448917388916, 55.502432686941965, 53.08442831039429, 58.59235913412911, 57.574368136269705, 58.34547574179513, 56.696327754429404, 60.40877110617501, 56.78193303516933, 54.95273985181536, 52.53181028366089, 60.575187410627095, 54.769158022744314, 53.0450667653765, 39.31683335985456, 40.54489271981375, 41.40646934509277, 46.32932710647583, 22.301165751048497, 6.039986959525517, 5.405220815113612, 2.702128593410764, 0.8859049826860428, 1.1506051846912928, 5.906114280223846, 18.12195631435939, 22.49493190220424, 21.258597237723215, 26.011074747358048, 26.86204321043832, 28.355402163096837, 23.020992176873342, 13.853756955691747, 1.4061969497374125, 0.4240599593945912, 2.2645115043435777, 2.2419754564762115, 0.4744277766772679, 0.3793264254927635, 0.34180761873722076, 0.2170447198940175, 0.5510466481958116, 2.68643348131861, 20.857354402542114, 33.034668241228374, 41.132449763161794, 37.33308792114258, 26.657081774302892, 29.683291503361293, 14.74563033240182, 4.395312309265137, 0.6533206573554448, 5.255772011620658, 10.157574994223458, 11.517429522105626, 23.058868544442312, 43.89912864140102, 49.16873277936663, 53.57909141268049, 44.557310649326865, 47.751706736428396, 43.078522069113596, 48.94080407278878, 44.44026129586356, 48.584625516619, 51.25997379847935, 53.187035833086284, 49.42835569381714, 51.98404209954398, 53.45394740785871, 54.02783734457833, 48.84700686591012, 49.21862779344831, 46.177224091121126, 43.97553103310721, 43.73334462302071, 44.43788153784615, 43.084153584071565, 42.345264775412424, 40.778081212724956, 44.72661740439278, 45.995414052690776, 51.7664384160723, 54.119407653808594, 56.45588534218924, 54.89411790030343, 53.46900415420532, 55.011288847242085, 56.49306862694876, 57.57337801797049, 58.08081538336617, 53.863189356667654, 58.90569509778704, 63.463171413966585, 68.40516104016984, 9.1551662002291, 0.5604247078299522, 12.124451943806239, 59.480443137032644, 54.96452399662563, 63.3485678264073, 56.39620379039219, 26.60210415295192, 12.049211638314382, 9.984323399407522, 40.39328302655901, 81.94216264997209, 80.54361534118652, 29.16635595049177, 19.968320233481272, 42.18802009310041, 36.87605973652431, 39.5936495917184, 53.65107822418213, 48.00813347952706, 64.57506384168352, 72.21262795584542, 49.22851160594395, 0.7876872015850884, 0.8595186557088579, 0.24844361575586454, 0.16672824057085173, 0.15540928579866886, 0.1785844729415008], [0.07937718422285148, 0.13273040630987712, 0.06150280764060361, 0.4326078992869173, 0.023211108786719184, 0.05277101529229965, 0.17271887697279453, 0.28813533591372625, 0.23008229530283383, 0.17996367679110595, 0.17673296800681523, 10.148068990026202, 52.36988946369716, 50.49837827682495, 21.21305874415806, 37.187571798052105, 35.98229210717337, 15.349301985331945, 21.831403255462646, 14.97879798071725, 26.89037275314331, 21.275281599589757, 22.7047119140625, 8.388731258256094, 1.675864679472787, 14.40039084638868, 50.84449584143502, 47.864316190992085, 44.552870750427246, 48.00258534295218, 49.40985264096941, 4.475477150508335, 0.05974111360098634, 1.5093534886837006, 22.324798311505997, 57.877518040793284, 57.69517299107143, 56.42365264892578, 54.65800768988473, 52.41857549122402, 47.07114110674177, 46.4415613583156, 45.13999005726406, 49.972549029758994, 55.23527792521885, 57.6047317641122, 55.896503244127544, 55.254892689841135, 50.835695947919575, 48.09738656452724, 41.1021590914045, 43.30336924961635, 46.54261943272182, 47.67222629274641, 48.3424391065325, 47.24937629699707, 50.859027998788015, 51.333218233925955, 50.95028911318098, 49.83205298015049, 47.879518849509104, 51.85452767780849, 47.73528814315796, 51.09256042752947, 50.72258274895804, 47.34216601508004, 41.55557768685477, 31.54000997543335, 35.85193347930908, 24.668495178222656, 4.01693686417171, 1.4478375038930347, 1.3181133334125792, 1.5452523337943214, 0.249075141868421, 1.5114953794649668, 8.10713813986097, 8.751441989626203, 4.763905993529728, 19.78348078046526, 16.045176233564103, 5.159199433667319, 7.345462713922773, 3.5069594979286194, 0.1622266356966325, 0.0666113281622529, 0.1916123317288501, 0.6213522670524461, 0.6234163162963731, 0.13852835233722413, 0.007793682061934045, 0.10300495422312192, 0.03685212913634522, 0.038944795594683716, 0.0505655661358365, 1.600837596825191, 2.332990344081606, 11.203023535864693, 20.549314703260148, 6.109206650938306, 13.507490004811968, 10.257407580103193, 4.005599141120911, 0.5034374286021505, 0.9169134902102607, 1.1317447338785445, 0.8896130951387542, 10.27303842135838, 18.645741053989955, 39.1158949307033, 45.85946907315935, 41.78653580801827, 44.53787653786795, 39.519338607788086, 39.244530405317036, 41.93788841792515, 45.926359380994526, 44.987115791865754, 49.403526306152344, 44.43222223009382, 49.31826843534197, 48.263257435389924, 49.25210421425955, 45.22984068734305, 42.09394148417881, 40.26874698911394, 40.27179030009678, 41.859599590301514, 42.77929442269461, 40.14396776471819, 39.42977632795061, 36.36705902644566, 38.77961948939732, 41.60220009940011, 45.68019165311541, 46.835149015699116, 52.670690877096995, 48.76831504276821, 49.904463631766184, 49.63419260297503, 56.084368637629915, 55.41212000165667, 53.44518920353481, 53.86010435649327, 60.246516772678916, 51.91999013083321, 6.482301465102604, 0.06341747740017516, 0.5064747684768268, 24.231243303843907, 44.570123127528596, 38.12798963274275, 54.91001885277884, 45.49278484072004, 46.26406962530953, 7.414819632257734, 4.485357923167093, 22.746156181607926, 63.55059364863804, 81.12096895490373, 39.796658584049766, 19.488307407924108, 25.164891856057302, 32.91481181553432, 24.93111797741481, 27.11458591052464, 24.457026754106792, 45.22445930753435, 50.87048210416521, 21.1761759689876, 0.15809766868395464, 0.24752626355205262, 0.11042691953480244, 0.1451491034988846, 0.1153008094323533, 0.02620588755235076, 0.06975305386419807, 0.11960045514362198, 0.025938843310411488, 0.4661132799727576, 0.056843334808945656, 0.09480189332472426, 0.2782472079353673, 0.47871318672384533, 0.3394246037517275, 0.060856218050633154, 0.15815495061022894, 14.896449668066841, 66.86805275508335, 56.78711986541748, 23.512775250843593, 34.65947668892996, 47.04569680350167, 25.175117867333547, 25.79952120780945, 21.330182790756226, 38.144839014325825, 19.6162828036717, 22.73246475628444, 16.23424366542271, 2.8760320161070143, 16.89066083090646, 53.78662715639387, 50.76724229540144, 47.3231383732387, 51.665842396872385, 53.772258281707764, 6.523557697023664, 0.08562110417655536, 1.6515447901827949, 23.166061878204346, 61.03677708762032, 62.47392858777727, 57.622373240334646, 53.789128507886616, 52.748423848833355, 50.842289788382395, 50.77946070262364, 46.0063852582659, 50.206831863948274, 55.6692658833095, 57.701537540980745, 56.906840801239014, 56.61257069451468, 52.4168975012643, 49.60132762363979, 43.451824460710796, 44.1590781211853, 48.394870213099885, 50.18878044400896, 50.97047015598842, 49.69995035443987, 52.4400315284729, 53.430615356990266, 53.98052706037249, 52.90884038380214, 51.65762267793928, 53.44966731752668, 52.42515890938895, 55.64000007084438, 54.36434555053711, 47.44077137538365, 40.544722488948274, 39.791881697518484, 41.50492531912667, 25.02893819127764, 3.852154689175742, 4.127032807895115, 3.5401786182607924, 1.8276263645717075, 0.4490674760724817, 3.1700198522635867, 12.627147163663592, 15.430656705583845, 7.967706033161708, 21.46076202392578, 21.652761595589773, 5.777309443269457, 8.937743169920784, 3.0622300590787614, 0.6589637888329369, 0.058031300348894935, 0.2538449444941112, 1.427576665367399, 1.0542380128587996, 0.18352975829371385, 0.022553579515910575, 0.12836898677051067, 0.013485003096450652, 0.012004756900881017, 0.05110634158232382, 2.125477833407266, 3.7839220762252808, 16.48038533755711, 23.778382301330566, 8.680400133132935, 16.54692128726414, 15.936251061303274, 5.776732308523996, 0.09768024565918104, 1.5118445264441627, 2.6286505247865404, 4.144575706550053, 12.411614043372017, 23.16971489361354, 43.014866147722515, 47.986159801483154, 47.89101811817714, 44.59282636642456, 42.5258970941816, 41.244281019483296, 44.82702234813145, 48.65877669198172, 48.52561446598598, 53.51434462411063, 48.08121810640608, 50.01384564808437, 51.58632026399885, 50.20752668380737, 48.73145832334246, 44.09547083718436, 43.92115790503365, 42.23762675694057, 45.133993761880056, 44.47549213681902, 43.492683342524934, 42.324048451014924, 40.74352087293352, 40.43977689743042, 46.062589236668174, 48.444751330784385, 49.24463490077427, 55.47156878880092, 56.012996741703574, 51.74260262080601, 48.83429513658796, 58.902846336364746, 56.22746678761074, 56.019729546138215, 56.8243795803615, 59.952149391174316, 42.63664443152291, 1.9098170399665833, 0.1438916695437261, 1.2406976989337375, 29.26830686841692, 51.78921113695417, 40.29688024520874, 58.377298491341726, 47.194311823163716, 52.13259111131941, 8.898678660392761, 7.630168625286647, 30.195863587515696, 59.89099134717669, 79.75008937290737, 37.97458035605294, 24.63828441074916, 31.270273957933696, 31.386534690856934, 27.578635249819072, 31.159220899854386, 29.294175011771067, 52.65532146181379, 61.602013042994905, 25.853942973273142, 0.46114797783749445, 0.29416216537356377, 0.08263619470277003, 0.14150960450725897, 0.11831608334822313, 0.02809945826551744, 0.361063899738448, 0.32558189226048334, 0.22445527224668435, 0.6557218570794378, 0.2874326721898147, 0.3104019510958876, 0.39698513650468414, 0.6807177843792098, 0.5568508910281318, 0.353560849492039, 0.2532703067575182, 22.90564513206482, 86.41983890533447, 67.45140266418457, 32.16487537111555, 49.384026186806814, 55.2198702948434, 27.326422589165823, 33.511286871773855, 21.99922830717904, 39.841516154153005, 25.017275639942714, 31.800973892211914, 14.998529127665929, 7.280244316373553, 21.53602143696376, 58.90602166312081, 54.42549317223685, 50.3227208682469, 53.48449168886457, 56.79286255155291, 5.804033517837524, 0.16360358680997575, 2.8327041353498186, 26.786064658846172, 64.00646495819092, 68.2500911440168, 60.8825409752982, 59.47239712306431, 56.03387260437012, 52.55477408000401, 55.76438672201974, 52.14154039110456, 50.90731450489589, 60.51213945661272, 62.11945234026228, 62.821936062404085, 63.21427304404122, 55.28348452704293, 50.50319685254778, 48.60694660459246, 47.93339170728411, 51.77134384427752, 53.070278303963796, 54.65126098905291, 54.53103630883353, 55.377114977155415, 57.84948205947876, 58.00634111676897, 56.02334260940552, 55.341665267944336, 55.2194881439209, 56.372239453451975, 55.14747701372419, 61.80781173706055, 50.96217400687081, 45.46677425929478, 39.97242021560669, 44.943230969565256, 35.296185289110454, 9.986233285495214, 5.197130518300193, 6.557650770459857, 2.919952882187707, 0.468385178063597, 3.7017283609935214, 19.34786868095398, 27.770382949284144, 27.635666063853673, 27.919109140123638, 36.031697273254395, 28.801801340920584, 21.504108360835485, 9.247845615659442, 0.9137057023388999, 0.12742392319653714, 0.41835350702915874, 1.759436417903219, 0.9845933956759316, 0.45027773827314377, 0.1982330150370087, 0.17105304636061192, 0.08546791132539511, 0.10232657526752778, 0.3922633741583143, 6.5165725861276895, 32.12493017741612, 37.64677824292864, 33.718454360961914, 22.329568249838694, 30.228457587105886, 22.212489366531372, 9.261605654444013, 0.6784437692591122, 1.3417050732033593, 5.994685573237283, 9.499415567943029, 16.640900884355815, 36.67107398169381, 51.4936660357884, 45.242573261260986, 45.934735434395925, 45.43785585675921, 45.1221227645874, 41.45324461800711, 46.43491193226406, 49.433584213256836, 53.14580522264753, 55.85285813467843, 50.813013553619385, 51.67369386128017, 55.0175769669669, 53.224889619009836, 53.84521089281355, 46.25345277786255, 47.56484883172171, 45.238946301596506, 48.838696820395334, 48.487395899636404, 44.7863267489842, 42.389125279017854, 44.35378401620047, 42.19853966576712, 47.89397457667759, 50.988736970084055, 53.904010023389546, 57.596063886369976, 57.289019516536165, 52.838465554373606, 52.75019563947405, 60.877392360142295, 60.750976834978374, 57.8573647907802, 57.90357378550938, 61.59635026114327, 57.33574267796108, 8.051571658679418, 0.23288388497063092, 0.8076001959187644, 29.028064216886246, 52.26503072466169, 45.06157268796648, 65.29061017717633, 53.460655893598286, 53.58119324275425, 13.426311595099312, 9.675706999642507, 30.269240038735525, 70.29143714904785, 86.45660182407924, 48.200789655957905, 26.694087879998342, 37.482644421713694, 40.76798548017229, 33.08006429672241, 36.55092920575823, 39.383292879377095, 61.06301348549979, 71.07023988451276, 38.478901454380576, 0.6215631014534405, 0.6817706535969461, 0.2557594174785273, 0.25876155495643616, 0.27906913097415653, 0.16399370373359748], [0.05341464646958879, 0.031176699391965355, 0.08038840496114322, 0.14387975446879864, 0.12042693793773651, 0.10268359325293984, 0.009025855006517043, 0.2100730032793113, 0.06521703369383301, 0.10624269941555602, 0.15957459514694555, 8.32828974723816, 48.075531005859375, 39.67731285095215, 33.83204003742763, 38.6702687399728, 22.86848269190107, 18.780541317803518, 26.708599192755564, 20.64178306715829, 14.10012618133, 22.78730341366359, 19.783432143075125, 17.911111491067068, 3.561162612267903, 4.392388420445578, 41.52389390127999, 55.14528138296944, 53.83999974387032, 53.94599451337542, 50.54074491773333, 13.297868932996478, 0.025060184566037993, 0.24892239006502287, 15.145994220461164, 52.07331255504063, 60.68674768720354, 58.174657753535676, 55.99895790645054, 49.840029512132915, 47.850225244249614, 47.52252388000488, 45.95330449513027, 52.3135986328125, 55.5519768169948, 56.12066602706909, 55.52716132572719, 54.877181666237966, 49.524376324244905, 51.46379920414516, 44.05488988331386, 44.93039764676775, 48.25135169710432, 46.15063680921282, 48.293426513671875, 48.61440202168056, 49.91299949373518, 51.2703856740679, 49.32684598650251, 49.11398097446987, 47.804262910570415, 49.754069873264854, 47.728597027914866, 48.42366702216012, 44.238030501774375, 40.1352790423802, 29.534005982535227, 38.03616918836321, 27.27828894342695, 7.727196744510105, 1.8253673315048218, 1.477615854569844, 0.0842019481850522, 0.2976417472319943, 0.24051935811127934, 0.7873221497450555, 6.079985133239201, 11.13895332813263, 3.8336876801082065, 7.841595360210963, 3.751021921634674, 1.556675715105874, 0.9587168927703584, 0.472269275358745, 0.09602948530976262, 0.0704879140747445, 0.10641413128801755, 0.6898903836097036, 2.0361324676445554, 0.0957554318010807, 0.24030760090265954, 0.18440992677850382, 0.0366370165720582, 0.0458824192173779, 0.07730294338294438, 0.3144640145557267, 1.7011517797197615, 0.8466932039175714, 5.300987413951328, 2.5103170573711395, 2.777711966208049, 2.337613935981478, 0.3098830075136253, 0.2493367035474096, 0.20480563092444623, 1.6204537728003092, 2.821064382791519, 10.569477234567914, 15.956557171685354, 30.047811371939524, 48.89136069161551, 48.090726716177805, 45.65682486125401, 45.36395134244646, 44.14228432519095, 41.66637713568551, 46.953313555036274, 44.10903024673462, 44.96527065549578, 47.26688575744629, 47.45805501937866, 49.20939711162022, 46.80307960510254, 45.65795741762434, 44.30685240881783, 41.571277141571045, 41.45491565976824, 42.77238096509661, 43.79339790344238, 41.19190897260393, 41.08336421421596, 37.451207297188894, 41.17429528917585, 44.911140714372905, 46.64980581828526, 47.91726493835449, 51.0460387638637, 51.71879809243338, 52.17051785332816, 48.6694769178118, 54.121311460222515, 49.30144337245396, 55.62815339224679, 53.912386076790945, 40.63791520254952, 3.17269686290196, 0.0331453907170466, 0.5030046861086572, 1.9799608417919703, 42.77472250802176, 28.993286745888845, 39.27702365602766, 52.87084068570818, 52.17652457101004, 45.1137432370867, 1.6956019060952323, 8.184171949114118, 21.223385504313878, 55.17426579339163, 60.99745028359549, 31.796183109283447, 25.574512481689453, 19.66215828486851, 31.294842788151332, 31.57389633996146, 31.791235991886683, 26.474455322538102, 50.544892992292134, 49.21427822113037, 14.91505173274449, 0.2453649938106537, 0.3122097583753722, 0.10862496801252876, 0.11427310029310839, 0.06455780299646513, 0.22398084056164536, 0.06480242844138827, 0.15304232495171682, 0.025286386088867272, 0.12207022761659962, 0.1994717214256525, 0.15233941695519856, 0.07140899822115898, 0.10955787902431828, 0.04611321611862097, 0.07387552051139729, 0.08968812772738081, 11.408694556781224, 60.20366028376988, 46.10416030883789, 36.2528931753976, 40.22401796068464, 28.940744468144008, 27.814785412379674, 27.801865237099783, 23.418444769723074, 24.015070949281963, 24.476440020969935, 19.21970742089408, 23.68002881322588, 6.22141397850854, 4.502468730722155, 45.32268599101475, 60.3430619921003, 55.070490973336355, 58.86976596287319, 55.77040386199951, 16.203963415963308, 0.03301539697817393, 0.634916290640831, 13.997733184269496, 52.79491771970476, 63.12932436806815, 60.885709353855674, 56.68548509052822, 51.367809840611045, 49.697115489414756, 50.0081342288426, 47.64498588017055, 53.61499622889927, 59.690160615103586, 58.84343229021345, 56.652501991816926, 57.03698403494698, 53.38932568686349, 52.52587652206421, 46.111785956791465, 45.65996197291783, 50.85647800990513, 49.73584822246006, 51.42420489447457, 51.718106746673584, 52.542996883392334, 54.048758370535715, 50.97513934544155, 49.07610981804984, 49.76366880961827, 51.8325366292681, 50.299277646201, 50.80928931917463, 47.58238608496529, 42.49026673180716, 30.466753005981445, 45.481622559683665, 30.112134320395334, 8.27925978388105, 2.5445173936230794, 5.593646841389792, 1.664610009108271, 0.29682343399950434, 0.6051422825881413, 2.004586777516774, 9.978812609400068, 19.778189727238246, 9.924693959099905, 8.36570840222495, 0.23878510402781622, 3.1671029116426195, 0.448731248400041, 0.38547487556934357, 0.024994363276554004, 0.0715155689311879, 0.06165355098034654, 0.44942861955080715, 1.2202355797801698, 0.21763622601117405, 0.27877138980797356, 0.07820260617882013, 0.07998898532241583, 0.03769314615055919, 0.16148760249572142, 0.44439711953912464, 1.3528249050889696, 1.2132818443434579, 6.560597240924835, 7.670951076916285, 8.769180740628924, 5.516970430101667, 2.854176240307944, 0.5573556125164032, 0.721586925642831, 1.605866355555398, 5.099495300224849, 15.047703266143799, 18.749178886413574, 33.571673665727886, 51.91493879045759, 50.68261671066284, 47.08540228434971, 48.82861845833914, 47.56796857288906, 44.65184089115688, 47.188892228262766, 46.441092354910715, 46.559739794049946, 50.441097327641074, 48.519253390175955, 51.55604696273804, 48.83098431995937, 47.86738382066999, 46.32978221348354, 44.98999582018171, 43.65220355987549, 45.437880175454275, 45.794729232788086, 43.4392204284668, 43.87741552080427, 40.7635212625776, 41.51756756646292, 49.0789828981672, 49.247699056352886, 49.92063903808594, 52.63924333027431, 56.08343757901873, 53.44946929386684, 51.05919170379639, 56.60913828441075, 52.81820808138166, 57.469783851078574, 55.430477142333984, 33.82213190623692, 1.3289139824254173, 0.15779833974582808, 1.1850743293762207, 3.19506202851023, 49.59975038255964, 31.85215084893363, 43.07478741237095, 56.54339790344238, 58.21661445072719, 42.24777112688337, 1.3563583897692817, 15.446415219988141, 25.73880958557129, 55.85662405831473, 62.82294355119978, 34.31030191693987, 28.12056347302028, 25.832957676478795, 27.744174344199045, 32.01139313834054, 30.296150411878312, 27.898146424974712, 59.02712876456124, 58.76469530378069, 19.744657720838273, 0.373423415103129, 0.25734192399041994, 0.06687693390995264, 0.17324299099189894, 0.031034349530403103, 0.1110212415722864, 0.1413017420896462, 0.30701215299112455, 0.18139284795948438, 0.237505848386458, 0.24312552969370568, 0.28211523752127377, 0.25540324087653843, 0.3636027606470244, 0.23296764333333286, 0.3268868236669472, 0.22920608946255275, 17.64381602832249, 77.67510019029889, 54.82186358315604, 45.08426203046526, 52.998701436179026, 33.72664628710066, 28.327369655881608, 37.82721253803798, 28.26515027454921, 25.66287793431963, 28.475847448621476, 27.669335297175817, 26.265674114227295, 8.763397233826772, 9.726949095726013, 52.63051291874477, 64.10840892791748, 60.74231937953404, 61.99519770486014, 59.344425201416016, 15.843525614057269, 0.08654476675604071, 1.3572152980736323, 20.21042673928397, 55.33235468183245, 66.66130215781075, 62.77504961831229, 61.0220399584089, 55.3095645904541, 53.73105198996407, 52.94702073505947, 51.02014282771519, 55.74725593839373, 63.30482196807861, 59.98256165640694, 60.472173418317524, 58.417806489127024, 57.03848137174334, 55.14420441218785, 50.58862842832293, 48.314906869615825, 54.28548697062901, 51.799178327832905, 55.08386625562395, 52.93245383671352, 54.287550585610525, 55.84440565109253, 55.437216894967214, 51.95683295386178, 54.084704875946045, 53.148688725062776, 54.660262380327495, 53.16089670998709, 56.93103095463344, 44.93628971917288, 44.52151700428554, 46.939326831272666, 38.9528728212629, 22.039691141673497, 2.4806104685579027, 6.367825984954834, 2.6329838122640337, 2.4584537489073615, 0.4616681699241911, 2.53691172174045, 14.258498208863394, 31.645730291094097, 18.363906485693796, 18.255109855106898, 19.667258262634277, 8.356400421687535, 6.098369198186057, 0.7131181029336793, 0.13725139014422894, 0.18883816844650678, 0.1213875806757382, 1.0641647087676185, 2.7829721868038177, 0.30762242738689693, 0.35471232341868536, 0.42242148731436047, 0.2159836268318551, 0.18798568419047765, 0.2801540813275746, 1.9148160517215729, 8.26368452821459, 22.606495652879985, 18.48165587016514, 18.35661087717329, 24.669961248125347, 9.096594623156957, 2.9695022233894894, 1.2745567049298967, 1.497347435780934, 4.89082396030426, 10.013467618397303, 19.495356355394634, 27.550911937441143, 49.90282038279942, 50.643112727573936, 52.940235819135395, 48.86621168681553, 52.529611178806846, 45.81680713381086, 48.78993436268398, 49.79019355773926, 50.70153318132673, 48.11238077708653, 55.17750365393502, 51.650372232709614, 55.708999156951904, 52.292535168784006, 50.77802242551531, 50.73052453994751, 49.08074426651001, 46.564763341631206, 48.74559790747506, 49.09285845075335, 45.87056882040841, 44.39942673274449, 41.80831841060093, 45.490412030901226, 50.25815125874111, 52.07390662602016, 54.22479445593697, 57.81192357199532, 59.55629662105015, 58.430181230817524, 53.15014089856829, 60.98021180289132, 54.59051636287144, 58.73292119162423, 56.460040364946636, 43.95375190462385, 4.963304093905857, 0.15373201508607182, 1.1017912668841225, 2.9750199615955353, 50.62489455086844, 37.18715490613665, 48.27435023444039, 60.058248383658274, 60.81783240182059, 53.3168386050633, 6.139854286398206, 13.293719121388026, 27.714290142059326, 61.028015409197124, 69.38452352796281, 39.100824287959504, 37.69463743482317, 30.388446807861328, 39.265503542763845, 42.93974222455706, 40.58273260934012, 43.02758829934256, 67.31704534803117, 75.84044224875313, 29.830120835985454, 0.5615331083536148, 0.5019820524113519, 0.3728878338422094, 0.22197494176881655, 0.10102318413555622, 0.294342574264322], [0.06763626209327153, 0.03359587011592729, 0.0427164596372417, 0.06366980421755995, 0.0545600237590926, 0.05115082294547132, 0.0287541767050113, 0.08801957618977342, 0.11572318391076156, 0.09857676005257027, 0.06963287852704525, 4.772181298051562, 43.11067485809326, 44.85841430936541, 32.52446549279349, 39.274473667144775, 39.86311115537371, 18.824936832700455, 26.853337117603846, 33.872464656829834, 18.400815316608973, 24.512235403060913, 27.944721937179565, 15.649868897029332, 7.892194747924805, 3.5420287932668413, 27.31352846963065, 49.08370072501046, 55.72434425354004, 51.370272977011545, 56.086487838200156, 19.360752378191265, 0.28176978177257944, 0.19237121886440686, 8.128542934145246, 44.78681312288557, 62.599822998046875, 58.965692792619976, 55.60214975902012, 52.50455250058855, 47.77317319597517, 44.320078304835725, 49.295606885637554, 56.79946681431362, 57.69359574999128, 55.61058834620884, 54.00625971385411, 54.76238005501883, 54.45042330878121, 49.53146348680769, 45.77458987917219, 45.09059878758022, 46.66535588673183, 48.21612433024815, 45.5574551991054, 49.25182281221662, 49.8675582749503, 50.78118732997349, 48.970729964120046, 48.213925225394114, 49.31519733156477, 50.789438315800254, 46.020417145320344, 43.40822104045323, 40.21398476191929, 37.58579737799508, 40.37555122375488, 37.83925029209682, 21.550463267735072, 2.1399628732885634, 1.5359456560441425, 1.3714681161301476, 0.2911135618175779, 0.6248816262398447, 0.35378381609916687, 0.1687761406813349, 0.5870022188339914, 3.851742139884404, 3.549547395535878, 1.1186572590044566, 1.1936209393399102, 0.49006187490054537, 0.06509324855038098, 0.07814643026462623, 0.08252353753362383, 0.037423319915043454, 0.07274514902383089, 0.5918070610080446, 0.38171009187187466, 0.015852104739419053, 0.07912305250231709, 0.0247515325567552, 0.017728700202756693, 0.00945534901360848, 0.018081166914531162, 0.11402270730052676, 0.33287543803453445, 0.7225941430245126, 0.8310263731649944, 1.1085651091166904, 0.5506418613450867, 0.2092457605259759, 0.1977405207497733, 0.30377328821590965, 0.5981540232896805, 1.895730435848236, 3.4132226535252164, 8.584379502705165, 17.070678234100342, 22.742221764155797, 41.5215037209647, 48.50293901988438, 44.056786741529194, 42.58779512132917, 40.43729986463274, 43.07683713095528, 45.032404150281636, 45.13686336789812, 45.28119829722813, 45.01379687445504, 45.65796436582293, 46.929363114493235, 46.903807640075684, 46.78093222209385, 47.60617324284145, 41.08701549257551, 40.07239089693342, 40.541755608149934, 42.78855984551566, 42.43035241535732, 41.05650247846331, 41.282294613974436, 41.136677742004395, 41.7917434828622, 46.19155822481428, 46.018926756722585, 47.913870743342805, 51.02292905535017, 51.024468081338064, 52.3548709324428, 50.79943677357265, 51.11188336781093, 55.01014934267317, 39.23672410420009, 9.750509568623134, 0.26311584987810677, 0.377020247812782, 0.18028067478111812, 5.148163957255227, 38.189807755606516, 69.3386515208653, 57.65468236378261, 50.45308991840908, 56.06668547221592, 19.975586312157766, 0.5731898514287812, 16.414842980248586, 19.884406839098247, 61.82607160295759, 53.554713657924104, 30.7287209374564, 27.28016495704651, 21.267996413367136, 34.86344105856759, 29.261146749768937, 29.863652842385427, 23.03353020123073, 45.738261222839355, 34.69999163491385, 5.000449597835541, 0.10086355877241918, 0.1251333789633853, 0.04636320538286652, 0.028550409246236086, 0.019535177553604757, 0.13310197208608898, 0.009550887592402952, 0.07763432631535189, 0.018273416241364818, 0.09407519589045218, 0.010449770921176034, 0.07308895593242985, 0.08706012088805437, 0.14703848425831112, 0.034882230018930774, 0.24908892969999993, 0.15202780653323444, 7.003528833389282, 61.04432283129011, 54.5845548084804, 34.1155960219247, 37.15934474127633, 39.82465287617275, 24.88526507786342, 29.332782677241735, 33.94160270690918, 26.692673921585083, 28.74796322413853, 26.47827856881278, 17.621668645313807, 10.177806411470685, 6.071797549724579, 30.392890180860245, 54.19991295678275, 62.73694569723946, 56.37487282071795, 59.366374560764854, 22.841346502304077, 0.2658095524779388, 0.34375072589942385, 8.74594943864005, 44.97054781232561, 63.61684472220284, 60.35899421146938, 56.35945476804461, 53.60112762451172, 51.26518494742257, 48.11754676273891, 51.06215858459473, 58.782149178641184, 58.670595850263325, 56.895393644060405, 54.911498819078716, 56.680037702832905, 55.92518193381173, 52.43266643796648, 47.01506219591413, 46.6962753704616, 49.05978849955967, 50.96321971075875, 48.60273947034563, 51.59999779292515, 53.13592141015189, 53.828872203826904, 49.56280333655221, 52.11950070517403, 50.88788734163557, 54.092611925942556, 49.30372585569109, 46.44808571679251, 39.22576332092285, 42.44215045656477, 43.162515367780415, 42.581031050000874, 21.336088759558542, 2.081530260188239, 2.7116267808846066, 2.9373168647289276, 1.0392869008438927, 0.9256822253976549, 0.36960654705762863, 0.09077191100056682, 0.3856649739401681, 4.635607072285243, 4.748732430594308, 0.40938642248511314, 1.0310248413256236, 0.16983285040727683, 0.15336845602308, 0.041355810327721496, 0.09583357189382825, 0.0497056858481041, 0.04825528671166726, 0.2489573210477829, 1.5371679961681366, 0.0308804781442242, 0.03752488982198494, 0.0979737052693963, 0.034583962988108397, 0.040492693427950144, 0.055397685417639356, 0.07844915866319623, 0.058597354617502005, 0.3507032128317015, 1.1427112711327416, 1.5702522780214037, 0.5242905467748642, 0.10037871157484395, 0.08288366999477148, 0.6272809260657856, 0.6056302849735532, 2.4564042474542345, 8.160152895109993, 15.50437535558428, 19.46018283707755, 27.04561288016183, 47.705247606549946, 47.77300991330828, 47.147908278873985, 44.913652488163535, 42.98658697945731, 47.2450475692749, 48.353795937129426, 45.516738755362375, 48.611737387520925, 47.31098249980381, 48.0190213067191, 48.58791548865182, 49.12169000080654, 48.9155786378043, 48.78117615836007, 42.31828839438302, 44.08449963160923, 45.050264494759695, 47.21377372741699, 44.65791709082467, 44.83088902064732, 42.13233028139387, 43.02507305145264, 43.807085854666575, 48.38670955385481, 49.07884046009609, 49.89081736973354, 52.61963203975132, 53.57964032036917, 53.242906297956196, 54.96136951446533, 54.106956481933594, 56.76951313018799, 39.84172460011074, 9.60660629613059, 0.2497461587190628, 0.1874921042472124, 0.22934855467506818, 6.11333692073822, 42.84185947690691, 66.602846963065, 61.57278891972133, 56.28467130661011, 60.31794425419399, 20.010636499949864, 1.6867087547268187, 20.044154609952653, 20.233328001839773, 59.91686643872942, 55.086645535060335, 35.62067311150687, 31.428550447736466, 27.692830630711146, 29.155607087271555, 27.590462820870535, 34.77713748386928, 29.357191698891775, 54.565249238695415, 48.53035313742501, 6.192436950547354, 0.11985022388398647, 0.06679318911795105, 0.011892719743108111, 0.04686819149979523, 0.027670495212078094, 0.05190098751336336, 0.1594038757362536, 0.3459423668682575, 0.16358962255929196, 0.23339886590838432, 0.16182206597711357, 0.1145702036363738, 0.18812023768467562, 0.1988950887961047, 0.30254017295581953, 0.37191972721900257, 0.2418788437332426, 12.796381831169128, 79.95666626521519, 63.73831312997, 46.323233536311555, 46.31987060819353, 48.57946300506592, 27.844259670802526, 37.69598191125052, 45.33151715142386, 29.952002661568777, 31.44167559487479, 35.90914147240775, 21.16837314196995, 15.255188635417394, 7.463786193302699, 35.67428193773542, 61.16470732007708, 66.1495395387922, 61.63339805603027, 64.17245047433036, 24.712242773600988, 0.4118961606706892, 1.1630943545273371, 11.61655947140285, 51.25843824659075, 66.52711159842355, 63.26214613233294, 58.38775553022112, 56.62343072891235, 53.42765889848982, 51.27859149660383, 52.58684001650129, 61.26799924033028, 61.746910776410786, 59.593823841639924, 56.00075054168701, 59.55769320896694, 58.74059200286865, 55.77129670551845, 50.79473631722586, 51.25928592681885, 51.82921539034162, 53.169543743133545, 51.212274415152415, 56.639758995601106, 55.273534706660676, 56.791445119040354, 52.67138222285679, 55.62362316676548, 54.413820198604036, 58.681761605399, 52.792569228581016, 48.20013305119106, 45.94697816031319, 50.19514151981899, 49.40877219608852, 44.44487142562866, 28.658404418400355, 7.352840832301548, 4.086993379252298, 6.532048395701817, 1.6777394988707133, 3.695893611226763, 0.8071923149483544, 0.2560803916837488, 0.9877681796039853, 9.474095463752747, 11.477029221398489, 2.8004477747849057, 2.2844031112534657, 1.819861969777516, 0.5217302984425, 0.2898473340485777, 0.23142731455819948, 0.1467407973749297, 0.16319945135286876, 0.6376866676977703, 3.2154968976974487, 0.08262200653553009, 0.2660630260195051, 0.28433084434696604, 0.3321605606802872, 0.11247805625732456, 0.1818247897816556, 0.3502998916166169, 1.022451849920409, 3.6861752527100697, 5.406296048845563, 8.045899323054723, 2.598160309450967, 0.2841832222683089, 0.3795088699885777, 1.134406871029309, 2.5964477956295013, 5.2716725298336575, 12.191193733896528, 20.954934903553553, 26.043606213160924, 40.35797922951834, 53.281003270830425, 52.62607649394444, 47.83230584008353, 47.17995337077549, 46.124178068978445, 49.488884925842285, 51.70928948266165, 48.133489404405864, 50.089209284101216, 49.540378025599885, 50.181373664310996, 52.57141154153006, 52.542524405888145, 51.6049588067191, 54.48480646950858, 45.82050704956055, 45.9573518208095, 47.066291264125276, 49.70166655949184, 47.25616816111973, 46.21107571465628, 46.70597505569458, 45.45706762586321, 46.46648454666138, 52.22753824506487, 51.95431423187256, 52.957675797598704, 55.693949358803884, 55.38523742130825, 55.79810632978167, 56.34706960405622, 56.80177361624581, 58.86880016326904, 43.66960532324654, 12.867927432060242, 0.7642571702599525, 0.7652637905308178, 0.3848297787564141, 7.743124621255057, 45.67215953554426, 75.54464353833879, 66.53774234226772, 60.68528856549944, 62.139942577907014, 25.427464280809673, 3.303708838565009, 23.98159452847072, 25.16722297668457, 64.8637614931379, 58.161178248269216, 36.985539027622764, 39.572718143463135, 34.13003437859671, 45.61543096814837, 39.49095174244472, 42.413874762398855, 37.20588377543858, 62.67219543457031, 65.51079164232526, 13.49770086152213, 0.2800850878868784, 0.2447703257203102, 0.1106201663081135, 0.11296492548925535, 0.13523800032479422, 0.17401014268398285], [0.05434749980590173, 0.028060917476458207, 0.026918990537524223, 0.027670664845832756, 0.09941658284515142, 0.03258063584300024, 0.014541758623506342, 0.09231917440359082, 0.033119921905121634, 0.15621906306062425, 0.08017919904419354, 5.200201622077397, 44.80270365306309, 47.056695801871165, 26.5184999534062, 40.125200680324006, 35.82554769515991, 27.021085739135742, 28.78697735922677, 30.159646102360316, 20.977801425116404, 27.176553419658116, 35.49086339133126, 17.92844203540257, 5.949685565062931, 11.447965775217328, 45.55318553107125, 48.44770778928484, 48.07948800495693, 54.714319365365164, 47.83164576121739, 26.656986236572266, 1.5454584998743874, 0.1522467155009508, 5.400033116340637, 33.176887444087434, 61.60756465366909, 58.830084800720215, 58.30639212472098, 51.93849318368094, 47.97794355664934, 44.850729601723806, 50.08132307870047, 54.87649032047817, 58.02003949029105, 57.41245773860386, 54.30930192129952, 55.01503045218331, 51.45183093207223, 47.46203981127058, 45.767141410282676, 45.09104694638933, 48.11890166146414, 51.390346322740825, 47.5922976902553, 47.31694752829415, 49.74867112295968, 50.96927159173148, 51.98207228524344, 49.30926356996809, 50.03807749067034, 45.80471726826259, 45.65326043537685, 46.89983327048165, 39.703886236463276, 54.5094621522086, 43.00837305613926, 26.096560171672277, 13.131563799721853, 2.1094502934387753, 1.3754809179476328, 0.5045333983642715, 0.18950427270361356, 0.4817028120160103, 0.061919448498104296, 0.09399248247167893, 0.030110103410801718, 0.05936010940266507, 0.046178942413202355, 0.03843356017023325, 0.1648100492145334, 0.11347890898053135, 0.027834614173376133, 0.034337912619646103, 0.014861669225086058, 0.03367489230419908, 0.036242010803627114, 0.11048789269157819, 1.131065656031881, 0.3237583158271653, 0.0453082971673991, 0.03719564427488616, 0.02955898709063019, 0.07943167058484894, 0.06141011297170605, 0.05483365657606295, 0.06727378190095935, 0.15322525799274445, 0.044439826626330614, 0.0606075892491, 0.04999401234090328, 0.06988798055265631, 0.009517235648153084, 0.11723595059343747, 0.5152093597820827, 1.331086597272328, 2.418224113328116, 6.490125570978437, 18.066645179476055, 21.33048677444458, 40.097407885960166, 48.44887856074742, 44.698296546936035, 43.33689430781773, 39.96659415108817, 36.70464072908674, 44.28704309463501, 43.9231972013201, 42.58606849397932, 45.63773121152605, 45.39936283656529, 44.98366601126534, 47.251756055014475, 47.228757517678396, 45.2096665927342, 41.63200439725603, 41.836455140795024, 44.52822896412441, 41.981891359601704, 44.84118972505842, 41.2875474521092, 41.56694493974958, 41.1371293749128, 42.00903797149658, 42.67195865086147, 46.978782176971436, 48.46077387673514, 49.18184750420706, 51.036036831992014, 48.413480963025776, 49.08293989726475, 49.88810757228306, 46.255130767822266, 28.30510241644723, 6.437840810843876, 0.033152637471045764, 0.28194541377680643, 0.9415683043854577, 7.806439212390354, 57.86589023045131, 40.44799314226423, 39.348597049713135, 54.96669183458601, 52.613604477473665, 14.830080475125994, 1.970291554927826, 22.71265196800232, 23.624373742512294, 53.79378032684326, 42.95420142582485, 28.54332661628723, 26.574424266815186, 18.3337356703622, 28.58266905375889, 34.33735472815377, 25.064849955695017, 29.730490616389684, 49.00761795043945, 35.66257422310965, 0.4842354304024151, 0.06641424766608647, 0.04129121718662126, 0.1540356052241155, 0.13040950441999094, 0.0714321837627462, 0.06721755848931414, 0.03894125024921127, 0.08098426048776933, 0.027133495812969546, 0.038237945309707096, 0.03258304124964135, 0.03655550416026797, 0.02947307437924402, 0.2133735604584217, 0.05158470198512077, 0.083327703310975, 0.13390828881944927, 7.790520889418466, 59.2441349029541, 55.778057302747456, 30.451755319322857, 44.29493277413504, 38.33803020204817, 32.23743888310024, 29.181009701320104, 29.789633682795934, 27.26851282800947, 34.16396243231637, 35.613811765398296, 21.62305109841483, 9.042327455111913, 10.565849406378609, 52.150493144989014, 51.455218178885325, 51.637723037174766, 59.05408082689558, 54.53312424251011, 31.41282320022583, 2.332174147878374, 0.07625686630074467, 5.2969761320522855, 34.678876059395925, 64.76160212925502, 61.88788972582136, 59.93074893951416, 54.23436212539673, 50.664030279432026, 47.86994423185076, 52.29919849123274, 56.837786129542756, 59.02015972137451, 58.437803404671804, 55.9879206929888, 56.598118441445486, 53.30701037815639, 51.14559602737427, 48.923530851091655, 47.034426825387136, 51.509309904915945, 53.70616006851196, 49.75973265511649, 49.45031894956316, 51.43097938810076, 51.88452999932425, 54.152123246874126, 51.861486298697336, 50.066756180354524, 47.8627667427063, 48.03368895394461, 50.75965486254011, 46.29676784787859, 60.78827476501465, 40.58262143816267, 31.537852559770855, 14.436759454863411, 2.690942645072937, 1.8577937058040073, 1.6653262163911546, 0.7732207807047027, 0.23732063546776772, 0.12432056186454636, 0.029562715640557662, 0.046472201855587106, 0.017107893247157335, 0.18853254270340714, 0.056222858639167886, 0.03487491201875465, 0.16224463044532708, 0.1247199611472232, 0.048079953262848515, 0.05093301659716027, 0.0723482874621238, 0.01905723275350673, 0.2330096582216876, 1.4253008046320506, 0.18142137357166835, 0.07334820380700485, 0.03454784456906574, 0.03096475897889052, 0.062345588845866065, 0.029997809257890497, 0.009250713030009397, 0.1085893042119486, 0.07972999529114791, 0.05423432695014136, 0.023509791420240487, 0.11172005121729203, 0.04824558366090059, 0.06712537950703076, 0.045972969715616534, 1.2867007447140557, 2.0024580231734683, 5.625893431050437, 12.751089130129133, 22.28743437358311, 24.46804486002241, 44.47520726067679, 49.35293994631086, 47.836909021650044, 44.59011656897408, 44.83591604232788, 39.17094203404018, 46.51604952130999, 46.416249070848735, 44.71954761232649, 48.20080355235508, 49.237638064793174, 48.349071162087576, 50.831228256225586, 49.2267849785941, 47.27519580296108, 43.927439076559885, 45.69778796604702, 45.752623149326865, 45.17159741265433, 44.899005685533794, 42.39190108435494, 42.72754076548985, 43.39824342727661, 45.00792217254639, 45.55610030038016, 49.61313261304583, 50.6784199987139, 51.67417328698294, 53.71969515936715, 52.050644057137625, 52.457631315503804, 52.908197675432476, 49.64151947838919, 30.907140254974365, 6.64227157831192, 0.13983256449656828, 0.10926371373768363, 0.7303868191582816, 11.435956682477679, 59.806403977530344, 40.94307313646589, 44.81999771935599, 61.52522155216762, 57.10821696690151, 15.238770042146955, 2.618787991149085, 25.853786638804845, 21.784758261271886, 55.18211030960083, 40.77764000211443, 33.87229790006365, 24.58785959652492, 25.653193882533483, 22.689896617616924, 33.8661140033177, 32.47300713402884, 32.48136929103306, 57.961313315800254, 46.7485362461635, 1.5719386275325502, 0.09281089516090495, 0.025531330445249165, 0.0682102484362466, 0.23027095517941884, 0.06428334236677204, 0.10752164293080568, 0.12267902280603137, 0.1785786511110408, 0.08045616346810545, 0.22847954130598477, 0.11749611449028764, 0.1580715857978378, 0.1792458003120763, 0.23456391053540365, 0.17932691238820553, 0.37451061819280895, 0.2486382738820144, 11.036939007895333, 78.33818067823137, 65.99378177097866, 39.474703380039756, 52.912964139665874, 45.066328729902, 37.893053667885916, 37.35624279294695, 38.423420088631765, 33.03365727833339, 34.13736472811018, 43.376912457602366, 25.91673731803894, 13.18013518197196, 17.2349979196276, 56.05311564036778, 58.34959602355957, 55.62106622968401, 64.13017068590436, 57.56051342827933, 33.13445479529244, 2.153717700924192, 0.36129479163459366, 8.43709419454847, 39.717879908425466, 65.399398122515, 64.53053978511265, 63.0287561416626, 56.4148770741054, 51.940511635371614, 49.83511713572911, 53.468799182346885, 60.402476038251606, 61.148524965558735, 62.34963921138218, 57.22191728864397, 58.91265719277518, 55.130440030779155, 53.31726939337594, 51.21783644812447, 51.3268050466265, 51.510682174137656, 56.53755446842739, 51.17853396279471, 51.715115547180176, 52.33466557094029, 55.6079306602478, 57.53761216572353, 55.719657693590435, 52.79042223521641, 52.828626905168804, 49.367715290614534, 59.171540124075754, 48.451584884098594, 58.857474599565776, 39.412336349487305, 38.988593510219026, 21.156858239855083, 3.8890179225376675, 2.7669081687927246, 4.201056744371142, 1.640094158904893, 2.5286572618143897, 0.17158205940255097, 0.2419705545263631, 0.19887754188052245, 0.2891246671123164, 1.0993028346981322, 0.1281797976366111, 0.24638276919722557, 0.43927035321082386, 0.3497841778610434, 0.2038981310491051, 0.09662173103008952, 0.0742149915812271, 0.12129772906856877, 0.3359649436814444, 3.5338737794331143, 0.3270031517105443, 0.19566674131367887, 0.09253070091030427, 0.1319664708737816, 0.17143261885004385, 0.13544496707618237, 0.11975187701838357, 0.21587465410786016, 0.33165526922260014, 0.23842092071260723, 0.17438392048435553, 0.2210656234196254, 0.09067415446043015, 0.10188269122902836, 0.10487152263522148, 2.9468608668872287, 3.717241951397487, 8.161342774118696, 17.806395190102712, 26.140686443873815, 34.32085970469883, 54.84832232339041, 49.07597085407802, 53.12124334062849, 45.31509508405413, 48.519371509552, 43.39476932798113, 49.41251727512905, 49.86260768345424, 47.58095128195626, 49.78381858553205, 50.136345863342285, 52.17851175580706, 55.52802637645176, 52.28979410443987, 51.264521394457134, 46.388018539973665, 49.176111766270225, 48.777031557900564, 48.81671272005354, 46.56867170333862, 47.57540314538138, 45.341612883976524, 47.2578079359872, 48.01361560821533, 49.3077141216823, 52.69836902618408, 54.22156354359218, 54.179116998400005, 56.96630001068115, 54.42709820611136, 55.931105273110525, 56.520555700574604, 54.46596990312849, 33.49547624588013, 10.1416141135352, 0.37186647579073906, 0.7291356548666954, 3.7097904426710944, 11.263904520443507, 64.21334062303815, 45.742489201681956, 46.887997014181956, 63.86750793457031, 60.42236178261893, 19.79804594176156, 5.503700239317758, 28.94637077195304, 27.967657940728323, 59.375921385628835, 48.3153897694179, 35.41158444540841, 36.626421383449006, 28.647295985903057, 39.681818757738384, 47.07335410799299, 36.209838662828716, 43.210690702710835, 64.91304506574357, 67.3074290411813, 4.627920193331582, 0.18520100361534528, 0.1889406136636223, 0.31462423024433, 0.2729546347899096, 0.1311879740761859, 0.40308668624077526], [0.01809463244197624, 0.08426692469843797, 0.062441900106413026, 0.08886653038540057, 0.04102675137775285, 0.05189752019941807, 0.045824672494615824, 0.06252200795071465, 0.08684094729168074, 0.05434242436396224, 0.04575095645018986, 2.4672180329050337, 39.91164084843227, 47.695985657828196, 26.65357640811375, 25.993283884865896, 32.15045438494001, 27.192873001098633, 30.37254932948521, 35.46690600258963, 20.67426242147173, 28.7068681035723, 45.10224396841866, 22.257892370224, 9.683841603142874, 3.3632968068122864, 35.9548328263419, 58.61014652252197, 46.942568165915354, 55.599717889513286, 53.92462880270821, 39.486150537218364, 3.505224619592939, 0.13850635423191957, 2.5237763694354465, 27.981498752321514, 59.66448702130999, 58.83710248129708, 59.53299931117466, 56.15830789293562, 49.60916519165039, 48.42692920139858, 52.92366783959525, 57.30047014781407, 57.788581098829, 54.619882924216135, 54.67843886784145, 56.187306199754985, 55.99400036675589, 51.90410654885428, 46.147742884499685, 46.423555101667134, 49.06725433894566, 49.991065979003906, 48.19473082678658, 48.70131703785488, 51.08138772419521, 51.03440400532314, 49.67519392286028, 47.983665398189, 44.679345335279194, 47.05813407897949, 49.81276478086199, 53.8231086730957, 57.78044128417969, 52.4492552621024, 28.593987669263566, 15.654838596071516, 7.6530134337288995, 1.6644702851772308, 0.8217000450406755, 0.22188509016164712, 0.31363278201648165, 0.20675762689539365, 0.0914760200040681, 0.11532210186123848, 0.12412432953715324, 0.014545597435374345, 0.12533225757735117, 0.12881213799118996, 0.02823019669657307, 0.06372413451650313, 0.022059962253219316, 0.06456345519317047, 0.052470373388911994, 0.07665978718016829, 0.08956422044762544, 0.16693535659994396, 1.4201243966817856, 0.47990941682032173, 0.016987636485802274, 0.0456758833357266, 0.060676704826099534, 0.04845362928296838, 0.018735498589064394, 0.14778363784509047, 0.002187607502232173, 0.11689114623836108, 0.023409497159134065, 0.1267822597708021, 0.1459507519113166, 0.10209481484655823, 0.09219158946403436, 0.08662774480347123, 0.34496104238288744, 0.6423936379807336, 0.301478129944631, 3.8050137673105513, 11.608524748257228, 21.240759474890574, 33.03692987986973, 48.88770593915667, 43.68242474964687, 43.32500941412789, 41.31977667127337, 44.954375880105154, 35.43067809513637, 44.16606453486851, 41.34690938677107, 44.77608857836042, 46.01644624982561, 47.46913044793265, 46.466936179569785, 46.61037826538086, 44.5041743006025, 43.860364641462056, 40.18921095984322, 40.600891726357595, 41.89948225021362, 41.71508053370884, 40.55200072697231, 39.89736230032784, 39.19446516036987, 42.20865624291556, 42.3794846534729, 45.954200812748496, 46.1926942552839, 50.8736435345241, 49.13160855429513, 53.47832863671439, 50.86090748650687, 50.27718237468174, 49.28695637839181, 27.179666212626866, 3.0492401846817563, 0.2861287450151784, 0.1290936078876257, 1.024978171501841, 24.197848524366105, 59.18569360460554, 40.76450443267822, 56.88657290594918, 37.38370207377842, 43.50756638390677, 6.4477380854742865, 6.0785147207123895, 34.639799390520366, 18.87543112891061, 54.57182918276106, 32.06901454925537, 24.35193177631923, 31.514016764504568, 17.05459836551121, 20.473197187696183, 29.13890709195818, 25.061745847974503, 24.966807399477275, 47.29574510029384, 28.382920503616333, 1.8402397334575653, 0.15912281296082906, 0.018905105202325752, 0.17052891877080711, 0.03411990949617965, 0.0556884885632566, 0.04409505619800516, 0.06273545471153089, 0.03761372023395129, 0.03456430922129324, 0.04932979441114834, 0.05807125927614314, 0.015686718613973687, 0.04635049302929214, 0.044895262723522525, 0.024475082123119916, 0.07257313361125332, 0.04372200443010245, 3.6547307457242693, 54.136951855250764, 58.630247661045615, 32.68287747246878, 29.65911177226475, 38.42280517305647, 36.52767358507429, 30.45824146270752, 31.038471630641393, 25.946341855185374, 36.95983416693551, 50.97772407531738, 23.068127019064768, 15.741850887026105, 3.1791382772581915, 36.396460328783306, 60.82694149017334, 51.310376031058176, 60.21126856122698, 57.47230952126639, 43.89571360179356, 4.264492494719369, 0.05412617864619408, 2.551627572093691, 28.12387602669852, 62.50620297023228, 60.196239607674734, 61.301427023751394, 58.74594906398228, 52.869395460401265, 48.96405274527413, 55.67846877234322, 58.481229645865305, 59.32324709211077, 56.42141880307879, 55.28708369391305, 58.17806584494454, 57.920555182865684, 53.98585980279105, 47.89637170519148, 47.1884058543614, 52.72666903904506, 51.92762967518398, 53.02788387026106, 51.162966523851665, 55.527984687260215, 54.83847672598702, 53.15517486844744, 48.85956573486328, 45.651408740452354, 51.48457431793213, 52.987886565072195, 56.57655470711844, 58.27337775911604, 47.09510891778128, 30.76150253840855, 18.941671780177526, 9.766387070928301, 3.207831297601972, 2.097313093287604, 0.6053293954048837, 0.3217749851090567, 0.7773052358201572, 0.035618267487734556, 0.039577122378562174, 0.08763644817684378, 0.18288319584514412, 0.13125050786350453, 0.1875570671898978, 0.017102787271142006, 0.061651311814785004, 0.03244479313226683, 0.06347294763794967, 0.017738342185371687, 0.11780235091490404, 0.028659507499209473, 0.07775714115372725, 1.3700139884437834, 0.6471508198550769, 0.0361427173816732, 0.16519407289368765, 0.06180593637483461, 0.01976608471678836, 0.020118052705324123, 0.1362375502607652, 0.013046070667249816, 0.08491546846926212, 0.015166724998770016, 0.05423856440133282, 0.06578133734209196, 0.05407647256340299, 0.08462925561304603, 0.013075075494790716, 0.15417212646986755, 1.8244679740497043, 2.0286829130990163, 7.834452612059457, 17.68406867980957, 26.017380237579346, 37.79049825668335, 51.1848464012146, 46.07784400667463, 44.96096624646868, 43.29244320733206, 49.65207379204886, 38.75538764681135, 44.420458929879324, 44.38191032409668, 45.96969182150704, 49.56641639981951, 50.455789293561665, 48.98761061259678, 48.740192208971294, 47.67882013320923, 44.32674510138375, 41.81416184561593, 41.92230013438633, 44.59188835961478, 45.35844489506313, 43.57438720975603, 42.86668539047241, 42.067378520965576, 43.43398496082851, 45.621371677943635, 49.309593609401155, 49.692870140075684, 52.79411520276751, 52.94120856693813, 55.30040339061192, 53.535661697387695, 53.762423106602256, 53.89271572657994, 28.542508465903147, 3.862514453274863, 0.23915539415819304, 0.36464170632617815, 2.0468648288931166, 29.919825553894043, 62.43851361955915, 46.94024051938738, 60.74417454855782, 43.29841865812029, 43.6397384916033, 5.3913083502224515, 8.709817937442235, 40.742527280535015, 17.54430045400347, 57.70898948396955, 32.824790954589844, 28.922837223325455, 27.22440913745335, 23.662588834762573, 18.97640929903303, 31.70432792391096, 26.965284756251744, 27.349426337650844, 57.56296961648123, 41.39617211478097, 2.4028384132044653, 0.10071870511663811, 0.02478189190982708, 0.013666123600809701, 0.02623428254654365, 0.02658853380541716, 0.022101651444765072, 0.1363816982401269, 0.10421286190726928, 0.16843846094395432, 0.165060659338321, 0.16654374689928123, 0.14520787820219994, 0.12241849250027112, 0.17499621691448347, 0.20473244413733482, 0.34015402889677454, 0.19752337597310543, 5.979456424713135, 71.80157947540283, 66.91170133863176, 40.25716086796352, 36.19124180930001, 42.55186251231602, 38.88334567206246, 41.54705919538225, 46.42082445962088, 30.219991207122803, 36.36192083358765, 58.39818477630615, 27.769318137850078, 18.008886541639054, 7.542593530246189, 43.30956356866019, 66.63007000514439, 56.58088343484061, 63.703586033412385, 62.61200319017683, 46.95993171419416, 4.866654651505606, 0.2396158208804471, 4.358286661761148, 33.73794753210885, 65.23697008405412, 63.75920636313302, 65.19688592638288, 59.278910636901855, 54.1981064251491, 51.17494174412319, 57.9000996862139, 61.342324120657786, 60.8206672668457, 59.13287339891706, 58.69997978210449, 61.57545007978167, 60.8375027520316, 58.14211586543492, 50.249469484601704, 51.00255346298218, 54.4771009172712, 55.13635294778006, 55.36439977373396, 56.67212717873709, 58.71098572867257, 58.06391389029366, 53.674681254795615, 50.69359139033726, 50.03269263676235, 56.53051594325474, 53.80238219669887, 59.827276366097585, 51.24014711380005, 50.49877779824393, 35.30990103312901, 34.54163176672799, 14.065082941736494, 4.875700771808624, 3.482413900750024, 3.0836127059800282, 2.6238551821027483, 0.8892844670585224, 0.13466029560991696, 0.16962148674896785, 0.19716641227049486, 0.5881577368293489, 0.2882293537259102, 0.42126767922724995, 0.14086707255670003, 0.13077007792890072, 0.2304582308445658, 0.19718770469938005, 0.07949222983526331, 0.2546181215771607, 0.15801708586513996, 0.2958446336644036, 2.70546937414578, 1.1039700699704034, 0.2191429401614836, 0.22626500656562193, 0.13338443264365196, 0.1862670499831438, 0.1366297842136451, 0.331754416759525, 0.1642256405736719, 0.20029601933700697, 0.15284721899245465, 0.215722811541387, 0.38466169206159456, 0.28193450293370653, 0.14706158159034594, 0.14234379545918532, 0.6648545041680336, 5.049871700150626, 3.562504483120782, 12.913585782051086, 25.132245744977677, 33.37124592917306, 45.591574328286306, 53.30145181928362, 48.920529229300364, 46.77479001453945, 45.22262845720564, 50.927217619759695, 43.9225822857448, 45.53945589065552, 46.402349199567524, 47.91090038844517, 51.652877058301655, 51.921320710863384, 53.486072404044016, 51.25179576873779, 49.68252774647304, 47.284582819257466, 44.940632343292236, 45.84242514201573, 49.22654179164341, 46.73511927468436, 45.93033027648926, 46.06434713091169, 44.102200167519705, 47.9982670375279, 47.90614087241036, 51.59940024784633, 52.063911642347065, 55.40525170734951, 54.93183272225516, 57.94729879924229, 57.72404970441546, 57.113289151872905, 56.68101045063564, 30.43477044786726, 5.928615587098258, 0.5514552891254425, 0.8419734771762575, 1.8368867933750153, 29.711528982434952, 68.06114877973283, 47.91299874441964, 65.04855578286308, 46.93748208454677, 52.94967842102051, 10.261257750647408, 9.916053005627223, 43.59305354527065, 23.171755926949636, 64.76848779405866, 36.78707068307059, 30.790876047951834, 44.42875507899693, 26.345401218959264, 28.489891495023453, 41.88425179890224, 35.76013387952532, 37.31292772293091, 65.90968077523368, 56.843382903507774, 3.907088015760694, 0.21755092058862957, 0.1308935305901936, 0.17563459623072827, 0.13209415759359086, 0.20849314305399144, 0.0800724383443594], [0.04114258069811123, 0.05490894342905708, 0.0428783682707165, 0.032616292858230214, 0.04649892256462148, 0.08842749787228447, 0.03923039437670793, 0.1329450812190771, 0.025306145028610314, 0.13816619105637074, 0.02969396806188992, 1.3293129610163825, 38.37818036760603, 47.3777859551566, 29.174499239240372, 34.85211549486433, 29.949789660317556, 28.347804307937622, 34.25813831601824, 34.426218714032856, 23.459823029381887, 33.52028826304844, 61.21894495827811, 48.99664674486433, 15.157264198575701, 2.813770077058247, 20.899380581719534, 59.91090488433838, 47.73916176387242, 53.84495728356497, 53.98656504494803, 41.955377033778596, 6.609919028622763, 0.19731130663837704, 0.5936723809157098, 16.443252427237375, 54.22921003614153, 61.84470667157854, 58.58093629564558, 58.327938488551546, 53.104536397116526, 51.95410231181553, 52.049605301448274, 57.43814522879464, 58.06644650868007, 56.284480231148855, 54.08983959470476, 56.16151448658535, 53.1262286731175, 52.697368485586985, 46.110622133527485, 46.359471866062705, 50.75692422049386, 50.207794189453125, 49.58604506083897, 48.42404222488403, 50.84286648886544, 50.66914415359497, 51.28106852940151, 45.00789090565273, 45.636869634900776, 50.673194953373496, 43.757333278656006, 45.319600990840364, 40.012528691973, 25.600936480930873, 11.721405182565961, 11.523401498794556, 5.733886676175254, 0.7875349383269037, 0.8040358243244035, 0.15658882393368653, 0.23002510837146214, 0.058862444678587575, 0.07204419520816632, 0.06161267603082316, 0.19862125920397894, 1.500386078442846, 0.4594826357705252, 0.5570999405213765, 0.08665389554308993, 0.02513945781226669, 0.1009755984746984, 0.05097646997975452, 0.05876590271613427, 0.07124755438417196, 0.006589096230787358, 0.028606625872531107, 0.8948393347007888, 0.7512400458965982, 0.10454324739319937, 0.05273735995537468, 0.043535295341696055, 0.06792632224304335, 0.10375372440155063, 0.03088848146476916, 0.06700635767940964, 0.06304399136986051, 0.26067344950778143, 0.17371864403997148, 0.6202784446733338, 0.6770492983715874, 0.24421845961894306, 0.0636173670313188, 0.21290287428668567, 0.7476424532277244, 0.6110404346670423, 1.9232841687543052, 8.501347661018372, 21.26959102494376, 29.367537566593715, 44.9657153402056, 44.83381421225411, 43.24481330599104, 39.97462279456002, 48.96434109551566, 48.16979374204363, 34.290840012686594, 43.49306896754673, 42.390396799360005, 43.10830552237374, 43.603569643838064, 48.0354642186846, 46.29118149621146, 47.766652311597554, 42.072308267865864, 40.57510348728725, 39.3009706224714, 39.70936836515154, 38.421054227011545, 39.89551755360195, 38.130157470703125, 42.06241750717163, 42.678333623068674, 42.599311760493684, 44.33405460630144, 46.20870637893677, 45.594944204602925, 49.91153342383248, 48.956896100725444, 52.0450507572719, 49.03011621747698, 51.615308148520334, 20.381918702806743, 1.2311346977949142, 0.17394779888646944, 0.1144929863512516, 2.4328103363513947, 42.25563996178763, 51.7621340070452, 52.51101085117885, 43.667208194732666, 32.71511363983154, 39.12814807891846, 0.612335568027837, 15.139292682920184, 21.834206853594097, 22.59937722342355, 45.86739001955305, 27.740321568080358, 22.505864892687114, 31.539047649928502, 18.410466364451818, 22.283225502286637, 35.23267180579049, 36.80647700173514, 37.31937912532261, 52.67561714989798, 34.39527491160801, 1.308761818068368, 0.06809292973152228, 0.16475233302584716, 0.04799336880179388, 0.042062714895499606, 0.0549594908952713, 0.05154364722381745, 0.052128239069134, 0.021002704610249827, 0.04309361654200724, 0.04086527700668999, 0.02972586260044149, 0.043640824500471354, 0.05136134522035718, 0.09667165085141148, 0.04377375290329967, 0.06295580895883696, 0.01712223238843892, 2.0907961172716956, 50.314348288944785, 61.0762220110212, 29.252975668225968, 36.035522256578716, 34.765467984335764, 31.350939069475444, 36.48384434836251, 29.08252419744219, 28.027254377092632, 36.876660755702424, 65.79946150098527, 47.4900723184858, 22.973040921347483, 4.392506539821625, 23.168559755597794, 63.40480654580252, 51.79788943699428, 58.781489099775044, 59.99307428087507, 45.434159415108816, 8.457506264959063, 0.15415771438607148, 0.5740379659192902, 16.51091398511614, 56.87002924510411, 64.71686267852783, 62.94631576538086, 59.62807846069336, 55.37021541595459, 51.41892773764474, 56.30714178085327, 58.83806133270264, 59.13984244210379, 56.519944259098594, 54.89516013009207, 57.28269665581839, 54.827786922454834, 52.35375574656895, 47.755229473114014, 47.662696838378906, 52.490284374782014, 52.8915810585022, 52.80081674030849, 50.40988254547119, 54.239819935389924, 51.3223477772304, 55.02498027256557, 47.927944319588796, 48.79474251610892, 49.069762638636995, 49.18165642874581, 46.289249897003174, 41.97476250784737, 30.432588713509695, 21.8724045753479, 13.277224966457911, 5.609749291624341, 3.860415663037981, 0.7919924248542104, 0.6389480914388384, 0.19555717147886753, 0.13584725691803864, 0.06484742209847484, 0.19419835082122258, 0.24430493212171964, 0.7570815810135433, 0.3349974884518555, 0.04859529721683689, 0.13111584580370358, 0.004814730125612446, 0.06689737138471433, 0.02556774063434984, 0.06514784347798143, 0.059350338498396535, 0.0872769874653646, 0.05159470019862056, 1.8206221461296082, 0.7586248410599572, 0.04440235113725066, 0.08652335219085217, 0.01615647180005908, 0.0360770996526948, 0.11448188551834651, 0.05680489240746413, 0.004947046998755208, 0.021777272690087557, 0.13107522869748728, 0.17199623717793397, 0.4044633795108114, 0.42435601779392784, 0.2548032802130495, 0.028780758314366852, 0.01591766648925841, 0.9522383489779064, 0.25287941630397526, 3.49247185247285, 13.498962828091212, 25.20742177963257, 33.55804477419172, 49.398141452244346, 47.13646806989397, 47.32805074964251, 42.56308732713972, 46.6526962688991, 53.5498811858041, 40.928575720105854, 41.61080891745431, 44.50026593889509, 45.89336585998535, 45.60790606907436, 49.6341370173863, 48.92848144258772, 48.42576885223389, 44.741222517830984, 43.34434277670724, 42.54136725834438, 42.295359339032856, 41.13270337241036, 43.33934007372175, 40.0971542767116, 44.30902719497681, 44.311031750270296, 45.42377185821533, 48.16930389404297, 48.90046977996826, 50.06459181649344, 51.47765391213553, 50.73503392083304, 55.52720996311733, 52.89088971274239, 55.77585472379412, 19.910782200949534, 0.9726204552820751, 0.1793957565511976, 0.13911665576909268, 4.775053943906512, 47.63523408344814, 54.950874260493684, 54.73575108391898, 44.484139169965474, 36.22655602863857, 38.128889424460276, 0.9724885480744498, 16.87551028387887, 27.50831253187997, 22.659873451505387, 49.05987882614136, 31.007923875536235, 23.39573631967817, 25.76722945485796, 21.621402638299124, 19.512919664382935, 42.192790031433105, 41.43961920057024, 40.930611542293, 61.933546338762554, 47.567621162959504, 1.3649371351514543, 0.03473991408411946, 0.04155329115954893, 0.04755437021542873, 0.01916936575435102, 0.027657126375873173, 0.10542256770921604, 0.159136600792408, 0.12156428476529461, 0.11420029348560742, 0.12044280208647251, 0.11570665479770728, 0.16136334916310652, 0.15176661126315594, 0.2530130334198475, 0.13059823215007782, 0.20979697523372515, 0.09100107263241496, 2.633083475487573, 68.99681404658726, 69.64783246176583, 41.61466516767229, 49.49418292726789, 38.71678692953927, 37.3087831224714, 50.188276699611116, 43.73979949951172, 32.77959639685494, 40.28895582471575, 68.17430019378662, 54.83398471559797, 22.882728236062185, 6.714622735977173, 28.52594917161124, 69.06463541303361, 56.64525154658726, 62.36706529344831, 63.14799417768206, 49.07153442927769, 8.09269196646554, 0.5156860713447843, 2.2442412206104825, 19.486480031694683, 58.85547351837158, 66.70365142822266, 65.18398312159947, 62.52342755453927, 58.04376758847918, 55.9682468686785, 56.55459492547171, 61.545392172677175, 61.077959060668945, 59.9445480619158, 58.40765517098563, 59.68123912811279, 57.158650466373985, 55.75654220581055, 48.85731451851981, 49.53900923047747, 54.69413137435913, 56.09601034436907, 55.804887771606445, 52.76178176062447, 57.244901929582866, 54.89893995012556, 57.68049144744873, 48.71384811401367, 52.895986216408865, 52.868123940059114, 54.23347970417568, 51.520329747881206, 48.54560443333217, 39.15273427963257, 29.402532168797084, 18.44312810897827, 8.88487606389182, 4.517458166394915, 1.9427725630147117, 1.2130976085151945, 0.8351963236927986, 0.16049025101321085, 0.16568146459758282, 0.3577745790992464, 1.9633969877447401, 2.9232031192098344, 1.0953274880136763, 0.6937666098986353, 0.25820113931383404, 0.12991126972649777, 0.21032260917127132, 0.13882624278111116, 0.11608051402228219, 0.0989037664341075, 0.21743972226977348, 0.11397203430533409, 2.4539771548339298, 1.0249813199043274, 0.15835739831839288, 0.14973089764160769, 0.09677924614931856, 0.12831060561750615, 0.29576046818069046, 0.15765367607985223, 0.07078146867986236, 0.13547315342085703, 0.3652443268469402, 0.2372689310993467, 1.1219167241028376, 2.1444503239222934, 0.7238319537469319, 0.14732405250625952, 0.17669308371841908, 1.6193174166338784, 2.5602259678500037, 7.336890373911176, 20.14604299409049, 33.45011493137905, 38.56333943775722, 51.23884432656424, 48.37859753199986, 50.60138532093593, 47.74945552008492, 50.20715842928205, 53.927804129464285, 44.42429780960083, 43.086151191166465, 46.80799545560564, 47.10037217821394, 49.381000246320454, 52.90970890862601, 52.69734764099121, 51.48279210499355, 47.09726285934448, 45.49328511101859, 43.69711324146816, 45.666673932756694, 42.945415428706575, 44.863934653145925, 43.78032486779349, 46.65696941103254, 49.03811011995588, 48.2346829686846, 49.764457430158345, 52.26830332619803, 53.19311203275408, 55.45452833175659, 53.70749759674072, 57.8808080128261, 55.72471945626395, 58.06576211111886, 24.033613954271587, 2.714769320828574, 0.8020176983305386, 0.5096410842878478, 3.545932160956519, 49.798757212502615, 59.98523671286446, 60.5129246030535, 50.51854542323521, 40.67032160077776, 46.638518469674246, 2.486469102757318, 21.076823677335465, 29.96508959361485, 26.794478927339824, 53.04700183868408, 35.27411781038557, 28.027315173830303, 46.66421290806362, 28.60902009691511, 30.289021560123988, 48.2870272227696, 51.5091883114406, 51.187406812395366, 67.43922942025321, 61.49193273271833, 2.306464293173381, 0.14625556341239385, 0.29464305671198027, 0.08630041951047522, 0.09687071266983237, 0.16410974679248674, 0.15149787068367004], [0.07559152200285878, 0.054410111624747515, 0.06794650865984814, 0.08580723311752081, 0.009484453076895858, 0.030881404344524657, 0.07548442882086549, 0.03087039850652218, 0.04637419425749353, 0.03540893943448152, 0.04348324831309063, 0.6742315867117473, 37.40796518325806, 50.72848871776036, 37.066645349775044, 28.860897506986344, 27.806160960878643, 32.456289768218994, 27.90521100589207, 39.153467314583914, 22.66230879511152, 39.36215645926339, 67.82780047825405, 65.39906460898263, 31.191734995160783, 3.880215423447745, 7.781718390328543, 53.57786505562918, 50.038358892713276, 54.318456172943115, 53.142358916146414, 47.94170522689819, 11.779782210077558, 0.13298511478517736, 0.17388735498700822, 11.373091987201146, 48.07579156330654, 63.705079896109446, 60.15764931270054, 59.099396978105815, 52.900162083762034, 51.3679244858878, 55.86877645765032, 59.399357659476145, 58.12321329116821, 56.433508668627056, 53.31306920732771, 56.997361932482036, 54.54756954738072, 52.92978572845459, 46.932757309504915, 48.934953689575195, 50.85326099395752, 50.35467215946743, 50.2513142313276, 50.34006009783064, 49.79280260631016, 50.76283713749477, 47.93287754058838, 40.95535755157471, 46.25710753032139, 47.5498754637582, 39.515572684151785, 36.63523169926235, 25.541218451091222, 15.064453635896955, 11.603168555668422, 11.854808858462743, 3.1869460982935767, 0.9060177377292088, 0.2019298638084105, 0.3963310830295086, 0.41771294283015387, 0.17991001824183123, 0.3992028332182339, 1.6772392285721642, 2.6285673635346547, 2.1568289739745, 0.38055682661277906, 0.5105415816817964, 0.18019542364137514, 0.006261517759412527, 0.044439344866467376, 0.10443375219724008, 0.05112489612240877, 0.14497311865644796, 0.03299425043431776, 0.14080468804708549, 1.3982171607869012, 1.0049051514693668, 0.05026133817487529, 0.0077145835384726524, 0.07600848177181822, 0.0470227346356426, 0.07831155176141433, 0.017852768634579012, 0.04968132304825953, 0.05737715187881674, 0.04375242994033864, 0.7526189376200948, 2.242711965526853, 4.262480556964874, 4.001713361058917, 0.9909161478281021, 0.41198238890085903, 0.12134960985609464, 0.8670449661357063, 1.0549370667764117, 8.175178374562945, 15.7946571963174, 26.364666836602346, 39.18470294134957, 45.80243478502546, 38.4054867880685, 40.151107038770405, 40.516485009874614, 48.062916551317485, 42.71117428370884, 36.44797774723598, 38.0766042300633, 40.22961820874895, 46.29150111334664, 44.642950671059744, 47.66268989018032, 46.930589471544536, 40.96169778278896, 38.280693667275564, 38.47920022691999, 40.623855522700715, 42.698254108428955, 41.737078530447825, 39.53583015714373, 41.067605699811665, 42.62615612574986, 44.945919922419954, 48.03806284495762, 46.51632744925362, 48.55115256990705, 50.33011375154768, 53.599126543317524, 54.281995500837056, 52.73183502469744, 50.1002847126552, 14.010408435549055, 0.3118663653731346, 0.08495310002139636, 1.7710560858249664, 16.610478196825298, 49.15414156232561, 47.02611330577305, 50.10873719624111, 46.07076031821114, 58.967714718409944, 25.618579694202968, 0.5811814740300179, 16.42274134499686, 21.61714165551322, 40.30673973900931, 50.084175314222065, 23.993026052202495, 23.521041870117188, 31.59832273210798, 21.327980211802892, 23.855795655931743, 31.748876299176896, 25.000532218388148, 28.436779464994157, 54.48076956612723, 34.08071953909737, 0.5607758089900017, 0.05965952655034406, 0.029496595795665468, 0.029258623386600187, 0.14197957143187523, 0.018311161448114684, 0.10202441683837346, 0.008691013241851968, 0.06804833641009671, 0.028463509266397784, 0.0223235357885382, 0.03653332285050835, 0.09452157693782023, 0.06775782842721258, 0.05024605756625533, 0.04372711379879287, 0.00841452633695943, 0.09683114729289498, 1.3117573601858956, 47.36231926509312, 63.5555477142334, 39.5453075000218, 33.03867735181536, 30.9739020211356, 36.364550726754324, 27.077058689934866, 31.922435351780482, 20.807888439723424, 36.0353033883231, 74.63519382476807, 62.83763204302107, 37.628594807216096, 4.766527201448168, 7.254660614899226, 54.51648678098406, 56.252435139247346, 58.06385483060564, 57.89812639781407, 52.1999261038644, 13.751663599695478, 0.14288818410464696, 0.054447638003953865, 11.462297303336006, 49.87874834878104, 63.42091941833496, 61.89634568350655, 61.19108963012695, 55.481226784842356, 52.89860916137695, 59.34678064073835, 59.86897945404053, 59.155496733529226, 56.76592091151646, 55.544132300785606, 57.41877365112305, 56.553243500845774, 54.47085101263863, 48.231754302978516, 50.848807198660715, 51.45347418103899, 51.20101833343506, 52.664308956691194, 52.56474821908133, 54.16173260552542, 52.85067701339722, 51.46002285821097, 42.379627091544016, 50.68468727384295, 48.444084303719656, 45.34696299689156, 39.06625699996948, 35.80878169195992, 22.167715174811228, 13.686069130897522, 14.02092366559165, 5.432307933058057, 0.7906248782362256, 2.0064756018774847, 0.45244541338511873, 0.40522589002336773, 0.260843137545245, 0.4365679925041539, 2.9896761008671353, 4.8905603630202155, 3.373176710946219, 1.5783142511333739, 0.44133062980004717, 0.06751466861792974, 0.035129752808383534, 0.025863598865856017, 0.08843937223511082, 0.094605328515172, 0.08127498560185943, 0.03504056616553238, 0.08038892064775739, 1.1818567706005914, 0.23953105828591756, 0.053040078175919395, 0.038302375602402856, 0.049198162010205646, 0.02376055930341993, 0.016790349036455154, 0.030869133038712398, 0.05324191859524165, 0.0663009730300733, 0.05473265324586204, 0.6438748527850423, 2.5324320878301347, 5.02651663337435, 4.897883764335087, 1.4644773538623537, 0.528042194034372, 0.4790046310850552, 0.6475508298192705, 2.127306946686336, 10.07199490070343, 23.595059292657034, 29.68334014075143, 44.95808621815273, 48.44129807608468, 43.10858692441668, 42.5238994870867, 45.15096126283918, 47.466684682028635, 49.95895140511649, 36.44824872698103, 39.18956320626395, 42.34398978097098, 47.54312181472778, 46.95496722630092, 50.36999988555908, 47.70312145778111, 44.78988422666277, 41.29685803822109, 41.29020166397095, 41.80537584849766, 46.648978982652935, 42.87561729976109, 42.20982354027884, 42.657916341509136, 46.369713510785786, 48.87022427150181, 52.36928844451904, 48.8257349559239, 51.73429257529122, 53.67263848440987, 55.19555854797363, 54.28212056841169, 56.068950584956575, 50.69652353014265, 13.137364677020482, 0.24213885835238866, 0.14164662786892482, 4.683850586414337, 24.984216111046926, 54.290816238948274, 51.6784360068185, 56.68784747804914, 52.37260273524693, 58.20995112827846, 24.92207142284938, 0.8953936163868222, 22.524651084627422, 24.973326546805247, 40.825064931597026, 54.97786801201956, 26.663666929517472, 21.472410678863525, 29.869305201939174, 28.37176169667925, 20.748490027018956, 39.040208203451975, 25.512315682002477, 32.960527488163535, 62.3872081211635, 43.17657504762922, 0.6411052899701255, 0.04796013076390539, 0.004032132856082171, 0.08158072669591222, 0.09447962311761719, 0.008945220449407185, 0.03663466205554349, 0.12582644820213318, 0.12452824786305428, 0.1435221800846713, 0.20243584737181664, 0.08338309890989747, 0.1428634582885674, 0.2084731398416417, 0.1947524289467505, 0.11053054540285043, 0.15538939115192207, 0.24378015313829693, 1.785346793276923, 62.46039349692208, 73.34701865059989, 52.159282616206575, 40.22337525231497, 35.66262286049979, 43.81700093405587, 39.550928592681885, 50.24638101032802, 29.671208586011613, 46.213024684361045, 71.75255298614502, 71.67591435568673, 42.39197751453945, 7.5337580272129605, 12.233324136052813, 62.805920464651926, 59.58442987714495, 62.8600469316755, 62.43371936253139, 56.603392124176025, 15.943035977227346, 0.6003789667572293, 0.3802791158003466, 15.14022547858102, 54.71891559873308, 66.52660437992641, 65.85237203325543, 62.40633651188442, 58.74262087685721, 55.778057302747456, 62.417418888636995, 63.548238209315706, 60.948833738054546, 58.70534379141671, 57.52714817864554, 58.04080418178013, 58.853931018284385, 56.357002053942, 49.963297503335134, 53.24319117409842, 55.247972284044536, 54.57644278662545, 55.84261996405465, 55.78022166660854, 55.01950856617519, 55.42675985608782, 54.38084404809134, 47.17265428815569, 53.84174721581595, 51.28234699794224, 52.51691681998116, 46.34366818836757, 43.616903236934114, 30.771952629089355, 18.3029534135546, 16.632272958755493, 4.618244392531259, 2.037322780915669, 2.234328095402036, 1.2444260588714053, 0.6694694651024682, 0.2626303716429642, 0.5259647369384766, 4.663993503366198, 10.471376487186976, 5.45246422290802, 2.0902765222958157, 0.8061448740107673, 0.24465578900916235, 0.059660903976431916, 0.1588893426316125, 0.14971454494765826, 0.13805883324572019, 0.1826619120048625, 0.09594627656042576, 0.2657748929091862, 2.458881063120706, 1.4828221180609293, 0.16657605873686926, 0.11924383070852075, 0.09298652716513191, 0.14069271619830812, 0.27446133536951883, 0.1323387287557125, 0.1848806943744421, 0.09363340852516037, 0.1516611533505576, 0.9361596746104104, 3.2662786756243025, 7.397906848362513, 8.54060845715659, 2.1428259653704504, 0.5154366961547306, 0.8433777189680508, 2.1551570636885504, 4.183906853199005, 17.477128744125366, 30.387380259377615, 36.02274104527065, 49.04816763741629, 48.75306027276175, 46.650684765407014, 44.014826570238384, 49.571891580309185, 49.25847571236746, 49.4468309538705, 41.096194062914165, 40.96651635851179, 45.24028035572597, 49.221622467041016, 50.56745726721627, 52.76696164267403, 51.13878331865583, 46.01423324857439, 43.375658307756694, 44.363066809517996, 47.13601991108486, 47.78805276325771, 47.706300258636475, 44.67704200744629, 45.387366771698, 48.3598895072937, 49.89113003867013, 53.77990477425711, 50.24145821162632, 52.794660636356895, 55.7834803717477, 60.48252623421805, 58.130564485277446, 58.7549261365618, 54.35941232953753, 18.104750837598527, 0.859464915735381, 0.7895261943340302, 4.431959279945918, 21.47039222717285, 61.202026094709126, 55.774051666259766, 62.99395956311907, 55.38597393035889, 65.6026120867048, 30.71894829613822, 2.5938016176223755, 22.48523047992161, 28.036128963742936, 46.875587531498496, 53.97547919409615, 29.774493558066233, 30.9294022832598, 49.19764075960432, 30.395419325147355, 31.74476991380964, 46.461318561008994, 33.45693111419678, 43.38077565601894, 70.77301679338727, 58.93764986310686, 1.5038151230130876, 0.23325045672910555, 0.08749178451086793, 0.1964021511375904, 0.2413390012724059, 0.1383181693298476, 0.2045953936342682], [0.05905457865446806, 0.027155743279893483, 0.07844056840986013, 0.032353638737861595, 0.0520589572510549, 0.01076804201251694, 0.012527303504092353, 0.03033313447875636, 0.1820645976279463, 0.011576412162477416, 0.1047766295128635, 0.37528075543897493, 36.33106388364519, 54.965152808598106, 29.10295363834926, 27.71401568821498, 33.52115331377302, 28.465803827558243, 35.49618223735264, 34.56973723002842, 41.71213797160557, 23.669297320502146, 41.05063819885254, 54.43834733963013, 45.094597475869314, 16.26435194696699, 2.8223528393677304, 42.44785145350865, 46.429634775434224, 56.41106251307896, 53.527428082057405, 48.59878594534737, 14.625280584607806, 0.4627707079052925, 0.13008759383644375, 3.159029539142336, 25.906504358564103, 62.709132058279856, 59.74300166538784, 60.14674064091274, 57.08873769215175, 54.17113699231829, 56.309528487069265, 58.53867735181536, 60.24049963269915, 55.53416510990688, 52.32794318880354, 58.35893440246582, 52.052335943494526, 53.3707913671221, 47.29849311283657, 50.02671718597412, 50.58828796659197, 51.26875979559762, 49.00806610924857, 53.20952715192522, 48.67061642238072, 51.250270639147075, 49.359620639256065, 45.51584243774414, 49.94642380305699, 42.338274887629915, 34.12660891669137, 29.62051452909197, 18.875879287719727, 16.04801630973816, 14.350976126534597, 7.951297862189157, 0.5528207729969705, 1.8026118725538254, 1.1611622124910355, 0.16769971272775105, 0.3313409989433629, 0.4125166945159435, 1.9539305014269692, 2.5106510051659177, 3.976825782230922, 1.2421338047300066, 0.8166977763175964, 0.3375923420701708, 0.03620167528944356, 0.035311274496572356, 0.06380847641932112, 0.05666185722553304, 0.058332101708011966, 0.028915003075131347, 0.051810579507478645, 0.032459188252687454, 0.8471381600414003, 0.051244674516575675, 0.12608908196645124, 0.03041332374726023, 0.025040998988385712, 0.025884222937747836, 0.026352137293932692, 0.04206422802859119, 0.040222354898495336, 0.07062060838299138, 0.060781898110040596, 0.5503541082143784, 2.7911111329283034, 4.498637233461652, 6.536065323012216, 4.609719821384974, 0.758866725223405, 0.04845498635300568, 1.6171509900263377, 3.852667987346649, 12.489634496825081, 16.935511452811106, 21.901791981288365, 38.85376371656145, 43.62016889027187, 41.482774462018696, 38.05379329408918, 41.860627923692974, 42.289887632642476, 52.477819306509836, 40.062034606933594, 36.013447829655235, 39.574604579380576, 43.24004684175764, 48.28382757731846, 45.40379926136562, 45.15650939941406, 42.628744329724995, 41.34938989366804, 40.24578666687012, 39.627831254686626, 39.48170716421944, 39.74742364883423, 40.538934639522004, 41.777510098048616, 47.44796623502459, 50.38638373783657, 50.667167391095845, 51.85523639406477, 50.54043919699532, 50.04560933794294, 49.31162248338972, 51.84049579075405, 52.69324820382254, 43.29324919836861, 3.4476095054830824, 0.1403623374977282, 0.7335244193673134, 15.973635843821935, 46.352638312748496, 45.72668204988752, 47.28103576387678, 50.12546151024954, 53.43672629765102, 55.629233837127686, 12.600566829953875, 0.7172265510473932, 21.72266742161342, 23.32098412513733, 49.88972997665405, 48.69506365912301, 16.233929259436472, 18.423464706965856, 27.96370962687901, 13.861033456666128, 31.26440273012434, 44.64148807525635, 29.210206031799316, 34.07303135735648, 55.724778515951975, 19.045496974672588, 0.197420279362372, 0.038945243427796025, 0.031038237536059957, 0.04294189950451255, 0.06576408898191792, 0.04793061109791909, 0.07406904548406601, 0.03164090894694839, 0.04873073959190931, 0.08535196326140847, 0.03858383192813822, 0.04731614335573145, 0.021323147861819183, 0.013396418653428555, 0.013930670833880348, 0.09304960378046546, 0.04609839012846351, 0.14953906222113542, 0.7498232104948589, 44.67297731127058, 67.53403064182827, 35.04191248757498, 27.046194791793823, 31.988047191074916, 32.80057995659964, 39.23073475701468, 27.015744311468943, 44.079879079546245, 25.032193422317505, 42.58794103349958, 54.38580158778599, 52.39992652620588, 18.784369775227137, 4.281465206827436, 45.79357235772269, 52.293872697012766, 61.51959351130894, 59.13106686728341, 52.46315860748291, 19.87445875576564, 0.9794961320502418, 0.23412704254899705, 2.55562995161329, 26.195464304515294, 63.3926055090768, 62.308540616716655, 59.464469228472026, 57.479938643319265, 56.76080356325422, 57.78431143079485, 60.238102504185264, 62.58013180324009, 55.69591222490583, 53.70338078907558, 57.5420138495309, 53.63893624714443, 53.8996639251709, 49.99893133980887, 51.339596680232454, 53.68569414956229, 52.59433364868164, 52.034770897456575, 54.455888066973, 51.02599321092878, 53.28591217313494, 52.23402091435024, 48.46764217104231, 52.37966905321394, 47.377820696149556, 41.20920998709542, 38.36152900968279, 28.056167568479264, 21.889799390520366, 16.931592668805802, 10.519878387451172, 3.9001789007868086, 4.066999503544398, 1.2597875488655907, 0.635150249515261, 0.4908608634557043, 0.5509762434022767, 2.768976777791977, 8.54712586743491, 6.892085807664054, 3.1928025611809323, 1.3489575811794825, 0.5233831011823246, 0.05977079950805221, 0.13077828820262635, 0.06978850731892244, 0.021918158612347076, 0.03894697029941848, 0.03071282571181655, 0.06793682596513204, 0.03901260159909725, 0.4072935219321932, 0.4395090075475829, 0.059298688412777016, 0.08589817038072006, 0.03679490827822259, 0.13083675077983312, 0.04535884802628841, 0.010902931381549155, 0.010407673760450311, 0.02221453083412988, 0.03716079471632838, 0.5201450235077313, 3.726452657154628, 8.640804086412702, 12.751803057534353, 9.439075674329485, 3.7107679673603604, 0.3735681873347078, 3.0469149265970503, 4.709413009030478, 16.520012651171, 19.92827950205122, 28.39312219619751, 41.997146129608154, 45.37400538580758, 46.36621509279524, 42.60365438461304, 45.04104770932879, 43.67213099343436, 52.03164768218994, 47.004163946424214, 36.43642636707851, 40.874595165252686, 45.267927237919395, 52.06353643962315, 47.62046568734305, 47.2574987411499, 45.89905990873064, 42.741093226841514, 42.80024324144636, 41.759166853768484, 39.75004311970302, 42.968611989702495, 43.10015875952584, 45.259773526872905, 49.97874334880284, 52.96146951402937, 51.91630758558001, 53.900879859924316, 52.331945351191926, 54.067184993198936, 52.24966130937849, 53.85006420952933, 54.23186077390398, 42.260173661368235, 2.194389198507581, 0.13715548600469316, 2.1915606302874426, 26.617242540631974, 50.07985700879778, 49.43692282267979, 52.38855927331107, 55.24657222202846, 56.4824344090053, 56.69739777701241, 12.860871536391121, 1.4520304160458701, 29.35894959313529, 20.299283776964458, 54.27625281470162, 48.780616828373496, 21.58327613558088, 17.732209273747035, 31.357261930193218, 18.8854695388249, 25.09162483896528, 48.728265626089915, 27.693256207874843, 42.258363655635286, 64.43307740347726, 26.152265616825648, 0.3055289297231606, 0.08816407700734478, 0.08955624087580613, 0.015791046765765974, 0.09183179627039603, 0.05394372057967952, 0.055236387465681346, 0.16254229018730776, 0.10068971810064145, 0.17667622890855583, 0.12250644420938832, 0.12901701485472067, 0.1176388104047094, 0.1054168680150594, 0.10031904799065419, 0.2240618440721716, 0.1914297786674329, 0.2734081675963742, 0.8678784785526139, 55.108942304338726, 78.08607918875558, 45.12168155397688, 39.61825663702828, 40.7699796131679, 38.76665415082659, 50.49170800617763, 46.86955302102225, 48.78112057277134, 32.41940525599888, 48.49482352393014, 55.55810860225132, 55.05882494790213, 24.46543754850115, 5.770155838557652, 51.07349109649658, 55.171285016196116, 67.0779995237078, 63.03761509486607, 57.13591596058437, 20.145754643848964, 1.0090694023030145, 0.39925733315093176, 5.181735481534686, 31.591471808297293, 67.67086846487862, 62.85050010681152, 63.25405842917306, 60.79060935974121, 58.17419917242867, 60.78575256892613, 63.03835160391671, 65.58896582467216, 57.532640729631694, 54.57860367638724, 60.31328201293945, 57.68608127321516, 57.97509854180472, 52.02375452859061, 53.88892895834786, 54.51191486631121, 55.28486374446324, 53.89594316482544, 59.556532859802246, 53.333750520433696, 55.80345644269671, 54.347096647535054, 51.86538423810686, 55.16259976795742, 53.133819580078125, 46.08886732373919, 45.157822608947754, 37.41290882655552, 26.14758947917393, 19.252374376569474, 10.054810268538338, 1.882077877010618, 1.9644763469696045, 3.3027545469147817, 0.8333016910723278, 0.6353742746370179, 0.5194365786654609, 6.485493728092738, 15.449774674006871, 13.353360721043178, 4.5839502555983405, 1.8505539000034332, 0.647764649774347, 0.2217382009008101, 0.18640658392437867, 0.2758233994245529, 0.10580263552921158, 0.16496012758995804, 0.17527631617018155, 0.14446269747401985, 0.123915612165417, 1.4892667893852507, 1.1120333458696092, 0.18042098225227424, 0.13521966630859034, 0.10403389829610075, 0.2222459486552647, 0.11873446804072176, 0.15083769682262624, 0.08603654402707304, 0.10298814691071, 0.0753624350098627, 0.8967061202440942, 5.906140335968562, 9.008093680654254, 16.594245467867168, 13.640645282609121, 3.5671688956873755, 0.258855898465429, 4.3826757073402405, 6.833902895450592, 19.018960067204066, 29.294536318097794, 33.83560446330479, 47.343475750514436, 49.00368179593767, 47.993267808641704, 46.47977645056588, 46.525103024074006, 48.13170371736799, 51.084427561078755, 48.337811606270925, 39.57710593087332, 40.950337478092735, 48.88696595600673, 54.13536419187273, 50.99151972361973, 50.05440575735909, 47.98455476760864, 47.565699986049104, 44.16181571143014, 45.43252311434065, 44.652323790958945, 44.54712111609322, 45.19979320253645, 46.50800698144095, 52.51329333441598, 57.12529216493879, 55.88495186397007, 58.11870738438198, 54.069894790649414, 56.10301412854876, 54.82390635354178, 57.290443897247314, 57.43236085346767, 49.702027865818565, 6.171002626419067, 0.424338158752237, 1.067787217242377, 24.72604537010193, 55.80084392002651, 53.43564932686942, 55.70241226468767, 59.30878789084298, 62.637322425842285, 64.36676379612514, 16.477286440985544, 2.768009675400598, 26.571295840399607, 30.020623070853098, 59.116607666015625, 52.18360478537423, 23.548183270863124, 23.647068296160015, 45.36473996298653, 17.687890189034597, 38.85798822130476, 54.55869361332485, 39.58013881955828, 50.53426572254726, 73.38825620923723, 37.76553337914603, 0.4508024901151657, 0.3338863466467176, 0.2220314908772707, 0.18547921654369148, 0.138722101226449, 0.17959817711796078, 0.23975063221795218], [0.07601314330739634, 0.01956338425432997, 0.05474487026887281, 0.021657075300546627, 0.1334648390433618, 0.02537216818226235, 0.004304321665715958, 0.038170878908463886, 0.06310531057949577, 0.0567496834056718, 0.26404954120516777, 0.07016984399940286, 25.185335193361553, 57.924244676317485, 37.40128449031285, 37.63719320297241, 43.9597829410008, 28.710130282810756, 21.00386585508074, 47.68281882149832, 25.35570502281189, 17.178542069026403, 25.024930817740305, 22.878330026354107, 21.58167631285531, 12.043287430490766, 3.401626761470522, 40.721314430236816, 46.74644136428833, 43.77077456883022, 56.604291915893555, 59.407924788338796, 42.012786524636404, 10.802037784031459, 0.09000570247215883, 0.4130266542945589, 12.502048322132655, 48.4382061277117, 63.2139812197004, 61.66963291168213, 57.22266074589321, 56.990535327366416, 60.97071361541748, 58.0683468409947, 58.86779267447335, 52.354634693690706, 54.08631338391985, 58.524739265441895, 55.66347108568464, 52.283863816942485, 49.18293489728655, 49.60636159351894, 51.950673375810894, 50.45556695120675, 50.64899090358189, 49.964739254542756, 52.98860917772566, 52.67085763386318, 45.072182587214876, 42.467490536826, 44.78771986280169, 35.24298988069807, 32.06408480235508, 25.016876118523733, 23.969947610582622, 23.449711663382395, 14.28351172379085, 6.743736556598118, 4.726215924535479, 2.15323805809021, 3.5199578404426575, 0.23115940179143632, 0.17984825798443385, 0.45598818042448586, 1.9552795376096452, 3.31763585124697, 2.503173223563603, 0.9197971011911119, 0.17318315777395452, 0.1784683484584093, 0.037232766925756416, 0.012524270452558994, 0.035860718227922916, 0.041053248170231066, 0.03975124124969755, 0.045802789740264416, 0.02694368751586548, 0.05782428610005549, 0.5881499201059341, 0.05283783742093614, 0.08618248333888394, 0.026930568041279912, 0.12088200423334326, 0.04112799898056047, 0.03867540701425501, 0.0149431782442012, 0.051765029451676776, 0.021835261989118795, 0.006308036848037902, 0.13599038709487232, 0.5697067954710552, 1.0405165148632867, 4.4559266567230225, 10.73051997593471, 5.719166483197894, 3.221646704844066, 3.5707767478057315, 5.559220688683646, 14.531703983034406, 13.659873553684779, 22.208891936710902, 36.759799003601074, 45.34406559807913, 40.05343621117728, 39.98614638192313, 40.16631664548601, 40.00618151256016, 44.71537174497332, 46.454210553850444, 32.282772404806956, 39.467928886413574, 44.297413281032014, 43.588419096810476, 45.79513570240566, 46.45250824519566, 41.69885648999895, 40.29664053235735, 38.66084698268345, 41.24726527077811, 41.06092848096575, 41.28694643293108, 39.65261895315987, 43.22461141858782, 48.58019951411656, 51.43950135367257, 50.93993282318115, 53.03312976019723, 51.60399300711495, 52.602028778621126, 53.53248984473092, 58.28829206739153, 55.357253551483154, 21.587396417345317, 0.06514125490295035, 3.381581208535603, 31.0574506350926, 47.910226413181846, 50.3424711227417, 51.640999112810405, 48.021644251687185, 47.200235162462505, 45.27389921460833, 47.9061895098005, 4.336162294660296, 4.1877626691545755, 29.667289802006312, 37.92355973379952, 64.26762689862932, 36.90062856674194, 10.278493625777108, 19.285932438714163, 24.612994704927715, 24.212887900216238, 26.57561067172459, 32.45416014535086, 32.62240035193307, 34.44649008342198, 57.61780479976109, 12.875249964850289, 0.027169604053986923, 0.0606377637013793, 0.0920160049572587, 0.03081620730725782, 0.10538357230169432, 0.02644775984143572, 0.0502925609637584, 0.06413462784673486, 0.028122279094532132, 0.062194472311862876, 0.015565720553110753, 0.05671626555600336, 0.030996887612023523, 0.018932261870109608, 0.0568739876284131, 0.11359480954706669, 0.031723961633230956, 0.138123375496694, 0.1033193873507636, 31.31015314374651, 71.11689703805106, 44.267171246664866, 39.96841805321829, 38.73768016270229, 9.58690641607557, 28.7541366985866, 37.94774293899536, 30.47951337269374, 20.250695024217876, 26.982313053948538, 22.08868636403765, 27.052093812397548, 16.368456806455338, 3.040825264794486, 43.32568686349051, 50.540640694754465, 50.102980613708496, 62.77928107125418, 64.49810559409005, 49.301457268851145, 16.42316344806126, 0.2625646623117583, 0.22504760617656366, 12.444162879671369, 47.15433536257063, 63.9568270274571, 62.21560846056257, 59.45684010641915, 59.39777347019741, 61.40751906803676, 60.575854437691824, 59.13546507699149, 55.240228516714915, 54.62276642663138, 61.25825786590576, 56.80369131905692, 54.896320479256765, 51.93237182072231, 51.43971674782889, 54.402175017765586, 52.68919045584542, 52.123634883335654, 55.61748443331037, 54.70254564285278, 57.62626075744629, 46.45391525541033, 46.95642287390572, 47.32273537772042, 41.58665350505284, 38.79768133163452, 31.317420959472656, 26.112054654530116, 25.400972536631993, 13.756526470184326, 8.31657942703792, 9.227028812680926, 4.214788121836526, 7.468008960996356, 1.9867540087018694, 0.5182021877595356, 2.0264130234718323, 6.376332317079816, 7.129296004772186, 4.548619534288134, 1.3587577981608254, 0.2096561249345541, 0.24139434258852685, 0.05184845193954451, 0.023622468945437243, 0.01886831672995218, 0.030877289029636552, 0.018376258401466266, 0.043877236278993745, 0.06565968958394867, 0.036256358426596434, 0.6650074731026376, 0.19307751953601837, 0.08332194254866668, 0.0375977543049625, 0.03885171416082552, 0.05761255603283644, 0.035839965234377553, 0.01910912711173296, 0.04448151242520128, 0.054981139555041275, 0.10551490953990392, 0.06772716542971985, 1.2825476761375154, 3.3097906836441586, 10.227662341935293, 19.26313713618687, 17.007388830184937, 5.705481571810586, 4.997105777263641, 7.50900593825749, 17.041791098458425, 20.91879037448338, 30.632693358830043, 38.512568950653076, 47.47471332550049, 43.96109962463379, 43.00963415418352, 42.67966420309884, 45.72164808000837, 43.216614042009624, 48.523995535714285, 37.961767877851216, 38.6369833946228, 47.410112449101035, 46.548709528786794, 47.77727263314383, 48.025674206869944, 45.34437479291643, 41.672508920942036, 41.71478523526873, 43.95696544647217, 44.44233880724226, 44.160981927599224, 42.28296722684588, 45.5508439881461, 51.16764266150338, 53.828392778124126, 54.18301146371024, 54.017835412706646, 53.65679659162249, 54.86971582685198, 55.50314487729754, 59.22594451904297, 57.001152174813406, 17.286511863980973, 0.1442048405962331, 7.158063718250819, 40.91679157529558, 53.01929589680263, 52.1692532811846, 56.13873829160418, 51.94923162460327, 53.81761612210955, 51.417194162096294, 51.2417174066816, 3.504233632768903, 7.651011484009879, 39.354506492614746, 35.94470930099487, 72.54786464146206, 37.938408034188406, 17.77071097918919, 20.662764889853342, 28.171870708465576, 26.191550731658936, 26.860332216535294, 39.39514998027256, 31.318303380693706, 43.642295428684776, 65.65553651537213, 16.986968074526104, 0.05190917064568826, 0.05461794350828443, 0.07036005772118058, 0.10509402783853666, 0.050568680611572096, 0.03658197720402053, 0.017651990122560943, 0.17867253321622098, 0.06471562345645257, 0.10770180076360703, 0.09674742964229413, 0.24628923993025506, 0.11997141023831707, 0.13914252152400358, 0.08400621797357287, 0.19216962611036642, 0.12703551618116243, 0.42623493554336683, 0.2216756942548922, 45.08862549918038, 83.8402715410505, 54.46043218885149, 50.47326053891863, 56.97066695349557, 36.0276186806815, 28.969798360552105, 65.65974017551967, 32.35860851832798, 25.60932469367981, 30.705885682787212, 27.990184000560216, 29.48306179046631, 19.512871026992798, 6.685144569192614, 49.63880273274013, 54.096693992614746, 53.37911530903408, 67.02338668278286, 69.95453984396798, 50.12883486066546, 15.762824024472918, 0.4996680308665548, 0.688688833798681, 16.950922557285853, 53.81124809810093, 65.85046822684151, 64.91597720554897, 60.80562441689627, 62.11087826320103, 64.20047950744629, 61.98098863874163, 60.66955089569092, 56.52106639317104, 56.37361172267369, 62.779447828020366, 58.644408089774, 56.16974115371704, 54.02643380846296, 54.035921573638916, 58.16428409303938, 54.3346072605678, 56.71381984438215, 57.833098207201274, 57.94212933949062, 60.41787324632917, 50.60739203861782, 49.937648228236604, 51.483431339263916, 46.326363699776785, 44.630826064518516, 37.76620388031006, 30.749207701001847, 28.344549076897756, 16.089403254645212, 8.194675888334002, 7.9522992713110785, 1.841397042785372, 5.797570824623108, 1.4952650389501025, 0.48148323808397564, 4.663173181670053, 15.127157654081072, 17.189308302743093, 11.012558647564479, 5.561752438545227, 0.8370025296296392, 0.2757442822413785, 0.16304245192025388, 0.10451449107910905, 0.128675657457539, 0.14282920584082603, 0.1371251419186592, 0.0937323932136808, 0.14004820292549475, 0.1560292632452079, 1.5144755052668708, 0.5983123662216323, 0.18772235832044057, 0.27622422363076893, 0.25241863674351145, 0.18345639508749756, 0.1132656725655709, 0.16207012480923108, 0.15697562960641726, 0.1253487052662032, 0.16350338075842175, 0.26590837431805475, 2.252628130572183, 7.810631581715175, 16.83418413570949, 28.90321203640529, 21.92869540623256, 4.879401121820722, 6.9621761952127725, 10.685555577278137, 20.056267057146343, 24.91366583960397, 35.64172615323748, 45.323443344661165, 51.887809549059185, 46.005447251456125, 46.13856084006173, 46.35812044143677, 48.01573828288487, 46.98321165357317, 46.73970855985369, 40.1545672416687, 41.55405603136335, 49.49577406474522, 48.06960071836199, 50.7683435848781, 52.666164125714985, 48.51166595731463, 45.86078923089163, 45.458839416503906, 46.002872943878174, 45.34039347512381, 48.42465019226074, 44.74364396503994, 49.723529066358296, 53.35717984608242, 57.08681651524135, 56.43829597745623, 55.53635379246303, 57.08102171761649, 57.480213097163606, 57.97943421772548, 61.71753379276821, 58.95759119306292, 26.50267369406564, 0.5367081718785423, 4.079596153327397, 38.13504205431257, 55.03292901175362, 58.752271924700054, 61.30465793609619, 56.87282589503697, 59.467297145298545, 54.09947327205113, 55.947054862976074, 8.151871510914393, 6.565925206456866, 38.77195562635149, 44.168093408857075, 68.21118123190743, 42.59371846062796, 16.490019014903478, 26.540150540215627, 41.296691281454905, 31.535055909837993, 37.47700943265642, 45.08932031903948, 43.075791427067344, 49.515937737056184, 79.4661442892892, 25.354991095406668, 0.09420827696365969, 0.1811277171862977, 0.17014513936425957, 0.30447117505328997, 0.18145869299769402, 0.2801829326365675, 0.12172501614051205], [0.03670977588210787, 0.030209851451218128, 0.029907153586723974, 0.046420979247029336, 0.09425346739590168, 0.02699768872532461, 0.020267489865156155, 0.034194280326898606, 0.12773071601986885, 0.005191881941365344, 0.07456858296479497, 0.057076615148356984, 11.658403260367256, 49.02280671255929, 41.86632892063686, 25.7673910004752, 82.22882447923932, 158.64389664786202, 19.828088215419225, 36.54436663218907, 25.4593790939876, 19.54448011943272, 39.38663843699864, 25.918736662183488, 27.45472628729684, 16.664069652557373, 0.8170053426708493, 9.980249149458748, 41.15775857652937, 50.329047203063965, 37.8896837915693, 44.165338448115754, 54.960480145045686, 35.775034291403635, 2.95045981662614, 0.11034373792686633, 1.4176457354000636, 27.29615797315325, 57.04038517815726, 61.09950542449951, 59.26966953277588, 58.82136481148856, 55.564636434827534, 57.49828536169869, 58.141563483646934, 52.08780997140067, 56.26926367623465, 56.80345508030483, 53.88550697054182, 50.93872036252703, 48.610313006809776, 50.23953703471592, 50.86643130438668, 51.75394555500576, 50.94228131430489, 51.76011902945382, 46.365089484623496, 50.99387168884277, 42.67537369046892, 41.507100105285645, 39.119459356580464, 33.95787191390991, 30.363565308707102, 29.394784927368164, 24.492002248764038, 17.755219970430645, 9.92817326954433, 8.775922230311803, 10.791122164045062, 2.3539102843829562, 1.532497069665364, 1.9233419256550925, 0.41874236187764574, 0.7065081404788154, 1.8229061492851801, 1.7227811962366104, 2.490186389003481, 0.5026085845061711, 0.03963476392839636, 0.010623755781645221, 0.08294743871582405, 0.01732730772346258, 0.04981279938614794, 0.05465863525335278, 0.056807379238307476, 0.06404440983065537, 0.016393894595759254, 0.04638843331485987, 0.02025951029333685, 0.16304482679281915, 0.13940545384372982, 0.05038261952410851, 0.04234471404924989, 0.08988682992224183, 0.10661902172224862, 0.051779241367642365, 0.025491787120699883, 0.08892111852765083, 0.026755494132105793, 0.0591721348464489, 0.11597627747271742, 0.56714942412717, 2.8455863126686642, 1.8221635605607713, 7.319182889802115, 17.031691891806467, 9.145664538655963, 10.568882295063563, 20.8679712499891, 18.98914361000061, 26.67735661779131, 34.356045382363455, 37.78711100987026, 42.36393805912563, 42.277210644313264, 40.13860028130667, 43.24637317657471, 43.50695146833147, 45.75724022729056, 46.56697634288243, 41.82233987535749, 44.895646231515066, 45.0060635294233, 45.98013148988996, 43.02900573185512, 42.17790699005127, 42.33918162754604, 39.370445660182405, 42.045526436397004, 40.59853628703526, 41.272945812770296, 40.66409254074097, 45.07146692276001, 49.919273717062815, 49.49063239778791, 49.710039138793945, 53.40971517562866, 50.33720438820975, 53.63581998007638, 52.35391208103725, 56.50501605442592, 41.070923464638845, 1.7571956238576343, 2.689613802092416, 39.01423583711897, 46.89640780857631, 40.12175784792219, 46.68199682235718, 45.48359932218279, 51.411381993974956, 45.46081270490374, 54.1860408782959, 28.79261061123439, 0.23186138698032924, 10.562800884246826, 40.58633525030953, 32.388280800410676, 62.143784931727815, 21.791958332061768, 6.997298470565251, 21.421007905687603, 27.89997032710484, 25.633749348776682, 28.229436533791677, 21.31608315876552, 19.221574749265397, 45.05369343076433, 46.86573845999581, 4.607072123459407, 0.1112854088257466, 0.08034984381603343, 0.07524398315165724, 0.07311921180891139, 0.13235402293503284, 0.08053160977682897, 0.05264208346073117, 0.09032083449086972, 0.05324398473437343, 0.06528599320777825, 0.061974036640354564, 0.11531714855560235, 0.11704921775630542, 0.09883323950426919, 0.0525038048092808, 0.04126757702657154, 0.0761178887582251, 0.0556891433495496, 0.07633386645466089, 17.17213930402483, 63.35587733132498, 49.360461371285574, 29.490218435014995, 88.75443363189697, 135.77781976972307, 29.523590632847377, 31.48384073802403, 26.113963672092982, 28.695750985826763, 44.226711886269705, 29.303134713854107, 25.422181912830897, 27.343582902635845, 0.9527414419821331, 9.386405723435537, 42.7186644417899, 52.99685321535383, 41.69879395621163, 47.460844721112935, 59.81026717594692, 43.346889291490825, 5.708468862942286, 0.06084321053432567, 1.0599212050437927, 24.443482978003367, 56.35520594460623, 63.053380557468955, 61.190540722438264, 58.724402700151714, 57.15646873201643, 59.37052958352225, 58.7051978792463, 51.721323762621196, 58.700514793395996, 59.165863445826936, 55.345188004629954, 51.880246434892925, 50.00535147530692, 50.66481195177351, 50.649671827043804, 52.53566653387887, 52.21900585719517, 54.20898035594395, 47.33509622301374, 53.016339438302175, 47.02704783848354, 44.34341382980347, 43.69942004340035, 39.34825658798218, 35.59384959084647, 33.53327792031424, 27.763096026011876, 18.001094136919292, 13.857046927724566, 9.841678619384766, 12.301619717053004, 8.040554421288626, 6.380403527191707, 1.7632533673729216, 3.310755614723478, 5.363403081893921, 0.9329383160386766, 2.266132171664919, 1.8769381642341614, 0.4073476418852806, 0.01900501948382173, 0.03832810565031, 0.07968585658818483, 0.012810608837753534, 0.039711014301116974, 0.07030596490949392, 0.007674334537503975, 0.01998654074434723, 0.050804257792021544, 0.04976666918290513, 0.3258055102612291, 0.1680702335600342, 0.03664414118975401, 0.05050837920446481, 0.0361990459662463, 0.10950958768704108, 0.05474322142877749, 0.047330426517874, 0.03776193263807467, 0.09934343677014112, 0.0977137042209506, 0.054049894346722534, 0.07945194521120616, 1.273098777447428, 1.7770114519766398, 5.423986596720559, 14.725765432630267, 23.535078968320573, 13.831693819590978, 15.540262801306588, 25.841827051980154, 25.874690294265747, 33.00473540169852, 38.20399597712925, 38.49112680980137, 45.08711774008614, 45.59992606299264, 42.91136578151158, 44.55147763660976, 47.16353130340576, 43.432598795209614, 50.92176328386579, 45.15550191061837, 47.91302306311471, 48.69769355228969, 48.07828944069998, 45.92963893072945, 43.90185580934797, 45.22377838407244, 43.03248677934919, 44.53604221343994, 43.811682088034495, 43.28607865742275, 44.53927659988403, 48.213136604854036, 52.21572630746024, 52.555944851466585, 52.91680996758597, 55.109039579119, 53.7367981501988, 55.21143865585327, 52.683649267469136, 57.01564611707415, 38.600060667310444, 1.809379743678229, 6.526398207460131, 47.691455432346885, 51.42255817140852, 44.83493634632656, 52.47315011705671, 47.96650334766933, 58.535258838108604, 49.615265710013254, 59.06894997188023, 22.22766249520438, 0.43247724058372633, 17.2374176297869, 44.44489574432373, 31.275478158678325, 64.00161511557442, 24.156030791146414, 15.400624854224068, 17.809798070362636, 35.65067890712193, 23.3506737777165, 32.63077987943377, 27.50713654926845, 17.95871012551444, 56.71091202327183, 52.42301191602434, 5.677403467042105, 0.03876846130671246, 0.05797533478055682, 0.0931654568495495, 0.06923950463533401, 0.031874521768518856, 0.06902729280825172, 0.0618033782978143, 0.20012361715946878, 0.14393789134919643, 0.16378968182419026, 0.10704316039170537, 0.24202578727688107, 0.2705671957560948, 0.2293443748993533, 0.14740124264998095, 0.2735172760273729, 0.14106615473117146, 0.3113784172705242, 0.16235148614006384, 26.572860922132218, 85.14155796595982, 58.785331453595845, 38.74606663840157, 92.56813308170864, 178.70683397565568, 27.905070304870605, 51.623892647879465, 34.24134452002389, 28.008716583251953, 44.07289266586304, 33.74293286459786, 35.51038782937186, 26.26673197746277, 2.196636723620551, 15.144356182643346, 46.54911599840437, 58.021557671683176, 50.09678282056536, 51.67974574225289, 63.11262089865548, 42.71397788184029, 4.721273584025247, 0.1629157287201711, 2.549999088048935, 34.24275153023856, 62.02724974496024, 64.03740528651646, 62.52066217150007, 62.473879950387136, 59.77114881787981, 60.72572708129883, 60.193856375558035, 53.3603447505406, 61.06755065917969, 61.384339877537315, 58.590260778154644, 53.59482560838972, 54.87203999928066, 53.58720690863473, 54.294669015066965, 56.188574245997835, 56.18603120531355, 54.97219828196934, 50.586860111781526, 55.576615129198345, 48.985734598977224, 46.70670461654663, 45.972929682050435, 45.31886795588902, 39.00235789162772, 38.214699677058626, 31.477319853646414, 20.43643079485212, 15.478425570896693, 9.987301571028572, 13.224146808896746, 6.31676150219781, 5.942462044102805, 1.9566971872534071, 4.843532349382128, 11.224286760602679, 9.05753185067858, 7.53285128729684, 5.573114046028682, 1.630548853959356, 0.14271637903792517, 0.17193406979952539, 0.16483834412481102, 0.08820422592439822, 0.16958008254212992, 0.11838240336094584, 0.128693231514522, 0.20262179310832704, 0.16966156102716923, 0.19376756250858307, 1.1253685674497058, 0.25869782694748467, 0.18633590771683625, 0.17399966610329493, 0.08356626265283142, 0.14652101988238947, 0.29239336028695107, 0.1489835184599672, 0.12492930277117661, 0.16607528632240637, 0.22864738372819765, 0.17620501347950526, 0.15092710059668335, 2.274255918604987, 8.396657415798732, 14.607025929859706, 27.610431943620952, 30.222773960658483, 14.693299974714007, 15.665389435631887, 28.195421627589635, 26.53668860026768, 35.30184807096209, 40.978724343436106, 43.233362674713135, 47.882023675101145, 47.54194062096732, 46.106779779706685, 46.538325445992605, 50.038956437792095, 44.49820579801287, 46.53540025438581, 46.897231170109336, 49.80925594057356, 51.42670277186802, 51.32923691613333, 48.235013008117676, 46.66235426494053, 48.13686275482178, 45.34048727580479, 48.791157245635986, 47.90596716744559, 46.48871530805315, 47.836961133139475, 50.54453863416399, 54.65278264454433, 55.44050339290074, 54.804062298366, 58.137578691755024, 55.5857971736363, 57.31915732792446, 57.68637309755598, 59.493262563432964, 48.09366580418178, 3.5924644640513828, 3.8798845154898505, 47.426715169634136, 54.58429772513253, 50.08589151927403, 56.48291383470808, 53.98652335575649, 60.73883833203997, 56.500729015895296, 63.95423534938267, 36.7830685206822, 0.9968867131641933, 15.242530754634313, 52.837287834712434, 37.482171944209504, 67.25797871180943, 28.928750140326365, 10.841652938297816, 28.74960994720459, 43.52125086103167, 33.236176422664094, 40.31496293204171, 29.758905274527415, 30.673479284558976, 59.077308654785156, 69.1940039225987, 10.463102051189967, 0.19844804278441838, 0.22176878925945076, 0.23006625473499298, 0.13158194507871354, 0.2057434477444206, 0.11191253803138222, 0.13975430226751737], [0.08376839823488678, 0.140463954902121, 0.08643831139696495, 0.09169654388512884, 0.04974783305078745, 0.062152131726699214, 0.04864771404702749, 0.009191044356807001, 0.03486689852018442, 0.12677654650594505, 0.016523774680016295, 0.05706401475306068, 5.265836043017251, 39.64582361493792, 43.573376246861045, 39.14200626100813, 39.10109874180385, 35.02202326910836, 23.210111720221384, 33.281155586242676, 34.57434041159493, 11.109162058149066, 36.94840438025338, 27.305800335747854, 30.832113606589182, 31.175288609095983, 5.976010118212018, 2.2927950152329037, 29.54219443457467, 39.261643818446565, 67.11678436824253, 58.89121505192348, 39.317837374550955, 44.21586922236851, 39.33602428436279, 13.23114538192749, 3.045287093945912, 3.9979648079190935, 30.915540627070836, 60.89973776681082, 59.538307734898154, 60.211761883326936, 62.16036333356585, 58.783323424203054, 55.70575087411063, 50.73054885864258, 56.50070469720023, 57.45637730189732, 55.865333625248496, 54.080768721444265, 50.79279429571969, 50.146705627441406, 51.53052622931344, 50.66188676016671, 51.3078989982605, 49.20969588415963, 51.20030961717878, 48.53255571637835, 39.08840090887887, 41.452997956957134, 36.216970988682334, 32.09746394838606, 33.95265729086739, 28.944810901369365, 25.546771798815044, 16.02382615634373, 14.604316132409231, 13.173737628119332, 10.719441941806249, 7.452100191797529, 7.524695839200701, 7.543588859694345, 3.3677173810345784, 1.5947440266609192, 1.1928236335515976, 1.2886605709791183, 0.3831522230591093, 0.26604608978543964, 0.08268634522599833, 0.04545040275635464, 0.06464344768651895, 0.054675910754927566, 0.09358193485864572, 0.03492293533469949, 0.1648633684962988, 0.0907098725438118, 0.04892371155853782, 0.01327100587410054, 0.2743648205484663, 0.02094860331687544, 0.037061949127486775, 0.052208021216626675, 0.09078618059200899, 0.045589407440274954, 0.09181725526494638, 0.05110965283321483, 0.03974142963332789, 0.08820637009505715, 0.01574262820317277, 0.05960265174508095, 0.13632067080054963, 0.39500256574579645, 1.224022022315434, 1.9589056287493025, 1.682690633194787, 11.23723212310246, 19.71183964184352, 12.904606972421918, 14.30851742199489, 20.679609060287476, 30.553021839686803, 35.30186544145857, 36.82717915943691, 38.67904084069388, 42.218265601566856, 42.40279238564627, 39.909921169281006, 42.67291055406843, 41.68240315573556, 49.420497281210764, 48.145377772195, 43.872589996882844, 44.0052033151899, 43.52219581604004, 44.78848416464669, 41.724387645721436, 40.58203778948103, 41.472748211451936, 46.09673963274275, 43.623128822871614, 44.72133329936436, 41.31766789300101, 46.51110240391323, 48.769527503422324, 51.68921961103167, 46.097038405282156, 51.284521784101216, 52.314630440303254, 53.263493810381206, 47.79557418823242, 45.92934363228934, 9.920008267675128, 4.079248743397849, 34.36104113715035, 48.5287481035505, 43.68190710885184, 50.08122927801949, 49.7807057925633, 55.340557030269075, 45.61030319758824, 54.60923480987549, 32.87511328288487, 1.3219610069479262, 1.7570567684514182, 33.70533963612148, 33.38706350326538, 36.01849569593157, 27.917323453085764, 6.350969220910754, 12.509513292993818, 28.327944619315012, 24.012286458696636, 29.725498335702078, 29.620601381574357, 23.316697086606705, 28.686834709984915, 50.41096993855068, 30.500941617148264, 0.7883070568953241, 0.225334992898362, 0.051842738674687486, 0.14570330376071589, 0.06762607728264161, 0.07144085544028453, 0.03241411317139864, 0.08913303179932491, 0.012754227666716491, 0.18118301779031754, 0.0659684840855854, 0.05200767357434545, 0.03810944434787546, 0.02907069632783532, 0.07454541099390813, 0.04792243814361947, 0.058669862869594774, 0.0753023846607123, 0.03094657084771565, 0.052018234971910715, 9.060034939220973, 57.40211534500122, 51.01894078935896, 40.882321562085835, 46.14877816608974, 50.84157412392752, 32.510999883924214, 36.24499307359968, 29.1743255342756, 19.87042358943394, 37.26125397000994, 35.89014857155936, 29.981685365949357, 39.10516343797956, 11.63581553527287, 2.6408650236470357, 33.62117958068848, 43.15482023784092, 66.2174859728132, 65.34784248897007, 42.81900685174124, 48.63947112219674, 48.35390363420759, 20.492078917367117, 5.412527280194419, 4.5643415706498285, 28.73389138494219, 61.49462168557303, 61.876188959394185, 61.44841616494315, 64.41497039794922, 60.82723331451416, 53.53555052621024, 51.274822098868235, 57.762104988098145, 58.68720204489571, 59.0312351499285, 55.814601353236604, 52.74509218760899, 52.397536345890586, 51.75892046519688, 51.46549456460135, 55.996876920972554, 51.449565819331575, 55.40259402138846, 50.186115809849326, 44.3648351260594, 45.226116452898296, 39.60100425992693, 36.32049567358834, 36.96969713483538, 30.80509901046753, 25.819198506219045, 18.20910930633545, 16.882008586611065, 18.911115339824132, 15.47440951211112, 16.05075911113194, 11.703474487577166, 11.657406193869454, 12.0019690990448, 2.2014618132795607, 1.1561453959771564, 1.3830611854791641, 0.7609059672270502, 0.3057403883763722, 0.043601723920021734, 0.08816601083214794, 0.05408377020752855, 0.0776686126898442, 0.07965586534036057, 0.033829330267118554, 0.12703836602824076, 0.038272123118596416, 0.05081260038007583, 0.07142486236989498, 0.14637867680617742, 0.0022495041027598616, 0.0070683400013617104, 0.041160911321640015, 0.11253322115434067, 0.02787954336963594, 0.01972553546407393, 0.044488691325698576, 0.03636178580511894, 0.08500731496938638, 0.03225803654640913, 0.07710729459566729, 0.08818659079926354, 0.3775582175169672, 1.87884435909135, 1.8158847774778093, 5.198857579912458, 12.917892796652657, 24.694274732044764, 16.963556119373866, 18.464639731815883, 23.546314205442155, 31.085566520690918, 36.44075509480068, 38.32897669928414, 40.41277967180525, 43.93829216275896, 45.166407108306885, 44.16106183188302, 45.21250145775931, 41.86336898803711, 47.36300713675362, 50.83202729906355, 46.19110311780657, 45.15494952883039, 46.3354936327253, 48.729370389665874, 43.495737075805664, 44.41995865958077, 44.27401522227696, 48.98161084311349, 47.549854619162424, 46.76450320652553, 42.77019575663975, 48.177137987954275, 50.891194684164866, 53.874441964285715, 48.71123211724417, 52.33816746303013, 53.014359201703755, 55.20940283366612, 47.077721050807405, 43.21190663746425, 8.935171467917305, 8.012769443648201, 43.04966967446463, 51.14394930430821, 53.50390148162842, 55.79209613800049, 56.54272045407976, 62.56092003413609, 49.10070991516113, 60.740429469517295, 28.93061399459839, 1.0980356569801057, 6.988025231020791, 37.94105529785156, 37.8517917905535, 35.303425312042236, 28.01207777432033, 12.088659167289734, 16.447115625653947, 23.74965497425624, 36.75495958328247, 21.58116388320923, 36.237440381731304, 23.745831727981567, 29.66498647417341, 60.09657464708601, 37.12537499836513, 1.2463560295956475, 0.21169751110885823, 0.07957766417946134, 0.0982841146843774, 0.04451572076816644, 0.06713867200804607, 0.025613346669290746, 0.04431352751063449, 0.12291675433516502, 0.27172086813620155, 0.15103299277169363, 0.19814825244247913, 0.08064015502376215, 0.16016549058258533, 0.2834934507097517, 0.2583218371229512, 0.16886798718145915, 0.1964838331831353, 0.3059931019587176, 0.18372190584029469, 15.77464291027614, 78.8410426548549, 58.49616132463728, 52.73885270527431, 49.16327496937343, 42.231633935655864, 28.94169463430132, 47.69102464403425, 44.7522805758885, 15.260747194290161, 44.17966215951102, 34.679553508758545, 39.575667653764995, 40.12490538188389, 10.582996691976275, 4.581622174807957, 38.114954812186106, 45.13902425765991, 67.2603063583374, 65.34903757912772, 49.241918155125205, 55.55080257143293, 47.4358867917742, 16.5991404737745, 4.376779292310987, 6.228429053510938, 36.29653828484671, 65.79791900089809, 62.028236389160156, 64.54507541656494, 65.6279799597604, 62.388000215802876, 55.53439787455967, 52.47036388942173, 60.14325959341866, 60.76135744367327, 60.7408116204398, 56.58469104766846, 55.66696950367519, 54.213246549878804, 55.06867401940482, 53.75144842692784, 57.691368852342876, 55.09242296218872, 58.6678443636213, 54.825170925685335, 46.75238902228219, 48.74883924211775, 43.62828091212681, 40.89318854468209, 41.93272590637207, 33.91346945081438, 29.51584686551775, 24.289300714220317, 19.978297846657888, 18.62163601602827, 13.547010489872523, 17.532615321023123, 14.1937974521092, 18.611062594822474, 23.431255510875157, 10.33863375868116, 7.247840089457376, 4.657111746924264, 2.640708689178739, 0.4556995044861521, 0.12883265689015388, 0.17046719922551087, 0.16933954187801906, 0.19421432353556156, 0.20186718074338778, 0.09506143975470747, 0.16352978934134754, 0.16337038789476666, 0.11031659652612039, 0.17554505674966744, 0.6589345304029328, 0.10295943130872079, 0.22261319894875797, 0.16088815751884664, 0.1889499638761793, 0.17315855409417832, 0.25223858069096294, 0.11465331060545784, 0.24758478041206086, 0.21287320873567037, 0.18498308530875615, 0.12323797281299319, 0.20351313027952397, 0.8720033200723785, 3.1307594903877805, 6.420188043798719, 14.393198592322213, 23.165500811168126, 31.506794112069265, 19.950307028634207, 20.088916642325266, 26.45340575490679, 36.26502125603812, 40.03260898590088, 43.84133699962071, 44.90255274091448, 46.81859493255615, 47.03331511361258, 47.060100419180735, 45.8730354309082, 45.105155263628276, 48.36407579694475, 51.81092425755092, 48.600015776497976, 48.64490808759417, 48.66959156308855, 49.90476240430559, 46.14019366673061, 45.7233920778547, 46.633647782461985, 54.02431460789272, 51.13029956817627, 48.95388405663626, 44.61687060764858, 52.28336007254464, 52.75028944015503, 57.749952588762554, 49.88975082124983, 53.55747209276472, 55.29930557523455, 55.599116870335166, 47.84545183181763, 51.364499023982454, 15.314767701285225, 5.665626270430429, 42.206012453351704, 57.81543241228376, 53.622656617845806, 57.62777893883841, 57.913422857012065, 66.72938060760498, 53.84999820164272, 63.719879559108186, 41.32881627764021, 3.763881734439305, 3.787765298570905, 45.733209882463726, 44.71328033719744, 41.431715624673025, 33.90248087474278, 11.30895403453282, 16.567701612200054, 42.62865400314331, 37.15054832186018, 36.10022388185774, 43.538405963352744, 30.913157394954137, 43.02460752214704, 65.05826936449323, 53.684877736227854, 2.3120682324681963, 0.3781922949211938, 0.25188338117940084, 0.24544055547033036, 0.17230746762028762, 0.18420876828687532, 0.11152513524783508, 0.16583405355257647], [0.027318494993128946, 0.07599653955549002, 0.05186059771637831, 0.00630938628455624, 0.1351618958371026, 0.06357031741312572, 0.041776166164449284, 0.05417032413450735, 0.06669611789818321, 0.007801678597128817, 0.013948452692212803, 0.07564841037882225, 3.302727839776448, 28.641480343682424, 54.42921045848301, 28.967305694307598, 34.46718181882586, 16.035129138401576, 27.923486505235942, 27.03001764842442, 43.1316271509443, 12.34853482246399, 22.13225851740156, 19.630745479038783, 19.711579084396362, 40.09665748051235, 13.146583199501038, 1.0067039749452045, 21.101435933794292, 60.24650982448033, 63.56594916752407, 65.24312618800572, 41.20696571895054, 45.00251299994332, 58.925705909729004, 61.275023869105745, 41.33116476876395, 13.502666217940194, 7.427645138331822, 30.955701214926584, 58.43836620875767, 60.16010897500174, 55.582986627306255, 52.88956955501011, 53.71385867255074, 53.0328483581543, 56.23032597133091, 57.32062687192644, 54.540749890463694, 54.16473075321743, 51.339436871664866, 49.675044536590576, 50.900147438049316, 50.05129991258894, 51.09498187473842, 49.83469329561506, 46.52777113233294, 41.071962220328196, 37.86419432503836, 40.387825216565815, 31.826550211225236, 37.91085147857666, 30.07800476891654, 30.5046033178057, 20.78654878480094, 13.114301000322614, 17.728203637259348, 15.461633511951991, 18.079151936939784, 11.370608006204877, 17.116981029510498, 12.053562079157148, 1.382553858416421, 1.1003478871924537, 1.1266753716128213, 1.3859281859227588, 0.43366915519748417, 0.08234831265040807, 0.09714315805052008, 0.03685508754902652, 0.05273510721911277, 0.01854884547979704, 0.037008124337132485, 0.038515208289027214, 0.13703717663884163, 0.08827937367771353, 0.021337202018392936, 0.02500671091755586, 0.1770248602011374, 0.130426752780165, 0.01736096984573773, 0.2040630422000374, 0.2011573381189789, 0.030165539721825292, 0.023336602142080665, 0.06983906496316195, 0.056145051028579473, 0.028392821184492538, 0.06571169929312808, 0.09350760134735278, 0.03877558931708336, 0.0938786853637014, 0.4142267384699413, 1.2243993963514055, 3.84097112928118, 1.5497140543801444, 12.098754031317574, 20.677250146865845, 10.99730040345873, 14.57239784513201, 18.716030767985753, 31.693009308406285, 27.93438301767622, 31.015785762241908, 36.736810888562886, 37.356117725372314, 46.21131195340838, 43.26188850402832, 38.922366755349294, 39.60453394481114, 47.8184928212847, 44.05042566571917, 46.40453093392508, 43.92879744938442, 42.087597778865266, 41.90883799961635, 44.1059695652553, 41.98743254797799, 42.396330560956685, 42.7020582471575, 44.333259037562776, 41.06651135853359, 46.88268511635916, 48.69643245424543, 50.17142731802804, 47.307032448904856, 47.353877203805105, 45.22389997754778, 47.327258655003135, 37.53987325940813, 24.388725961957658, 2.5535552629402707, 27.7489720753261, 43.3780380657741, 47.69559308460781, 35.8309325490679, 31.86052690233503, 36.48089483806065, 39.2693806375776, 54.58642039980207, 41.91805131094796, 3.2662576138973236, 6.064778566360474, 40.97664335795811, 54.698369775499614, 37.604901450020925, 29.65096848351615, 14.947986194065638, 9.340089900153023, 22.017564603260585, 31.60579899379185, 19.920650379998342, 38.32097932270595, 32.75631298337664, 21.651667254311697, 32.74691554478237, 58.30580152784075, 16.75884829248701, 0.21476892701217107, 0.22496719977685384, 0.05879038425960711, 0.1231159722166402, 0.09556409171117203, 0.1468449253588915, 0.052802774123847485, 0.008540095179341733, 0.06659065320023469, 0.08628601421202932, 0.0717446423534836, 0.08890836885465042, 0.080852095436837, 0.09536534201885973, 0.004354163879595164, 0.046919797480638535, 0.021093799632840922, 0.030222960747778416, 0.01415691476514829, 0.041719074227980206, 4.369504528386252, 44.93624108178275, 65.72024508884975, 28.027129309517996, 37.748305320739746, 18.55586784226554, 18.410534109388077, 33.48234762464251, 34.95700550079346, 19.101461240223475, 28.51520378249032, 20.86264545576913, 20.839804989951, 38.7600359916687, 21.39749346460615, 2.3049632651465277, 15.9295060975211, 63.18490300859724, 66.43947396959577, 64.56799752371651, 44.07739857264927, 49.83843837465559, 58.48837239401681, 63.99045630863735, 49.1457759312221, 20.25716379710606, 7.8375793014253885, 26.255350828170776, 57.80328001294817, 61.9242843900408, 55.94916016714913, 53.490845816476, 53.22452483858381, 53.05950164794922, 57.50261756352016, 59.11143820626395, 53.72659124646868, 55.21438469205584, 53.63454845973423, 53.08820118222918, 53.37120825903756, 53.77458592823574, 53.56253732953753, 53.18030997685024, 47.859907558986116, 44.607886586870464, 41.45931386947632, 42.004622391292024, 34.027718680245535, 38.162699358803884, 31.096058300563268, 35.46676009041922, 21.312583003725322, 15.81364836011614, 22.036003385271343, 17.462488889694214, 19.053148678370885, 15.144608054842267, 18.967480863843644, 14.92963079043797, 5.996899877275739, 2.612097744430814, 2.3195953028542653, 2.2084380217960904, 0.2320604691548007, 0.04543093897934471, 0.07332094705530576, 0.06279025319963694, 0.05418002039992383, 0.07171433219420058, 0.09057048109493085, 0.05512811702543071, 0.03227371749069009, 0.010283261820274805, 0.02879958426845925, 0.05302990015063967, 0.14982866096709455, 0.08014044790927853, 0.03166477641622935, 0.02185173342669649, 0.022113744635134935, 0.11279107124677726, 0.042466958918209584, 0.02268912027856069, 0.05960629547813109, 0.032590908863182576, 0.06490999659789459, 0.08274953719228506, 0.021804788981431296, 0.09726725532008068, 0.7187845217330115, 1.8030897783381599, 4.253378416810717, 10.52698813165937, 17.00633270399911, 24.118467092514038, 14.323669706072126, 18.34361253465925, 20.76448999132429, 34.22928939546858, 28.275798388889857, 31.92876168659755, 40.01454019546509, 39.40302576337542, 46.73323631286621, 43.18393666403634, 39.453316824776785, 43.0469251360212, 49.19513593401228, 46.45248392650059, 48.9253373827253, 45.99554606846401, 44.18995591572353, 43.88693107877459, 46.09967177254813, 43.66654116766793, 45.3026682308742, 46.19622046606881, 45.5092624936785, 44.19303049360003, 49.98027195249285, 53.19142362049648, 52.54729087012154, 49.45860467638288, 45.260134833199636, 46.60044581549508, 44.510577065604075, 38.215755803244456, 23.02014102254595, 5.059752907071795, 33.19688435963222, 46.217725140707834, 54.06239768436977, 36.13192851202828, 35.59214033399309, 42.30491311209542, 45.09671320234026, 62.20337963104248, 36.50050612858364, 1.962575797523771, 12.931599855422974, 47.52145733152117, 55.04369524547032, 47.179936000279014, 29.9831896509443, 15.172492912837438, 15.839961188180105, 19.869973693575176, 33.885318824223106, 27.082363639559063, 26.54605998311724, 42.28378711427961, 19.34035246712821, 37.59940889903477, 65.9055882862636, 21.328482219151088, 0.20918858716530458, 0.21190477641565458, 0.06451315539223806, 0.1304785114313875, 0.061630060098000934, 0.13788808669362748, 0.07357722294649907, 0.09767571304525648, 0.1338459314512355, 0.18761483766138554, 0.1516009537237031, 0.2018779015966824, 0.228801818298442, 0.10900169065488235, 0.11347670374172074, 0.1606204483125891, 0.1468869402472462, 0.1361626942775079, 0.18265253465090478, 0.1925686047013317, 6.648010356085641, 68.48510701315743, 75.77965940747941, 41.68446677071707, 45.28793804986136, 21.392270156315394, 34.45495646340506, 39.78735842023577, 59.51646259852818, 16.60757906096322, 34.498882974897114, 27.262023210525513, 26.17221736907959, 51.402300698416575, 19.771248476845876, 4.232030945164817, 26.81505949156625, 68.64834104265485, 67.38956369672502, 71.33001913343156, 47.261334146772114, 54.58500991548811, 63.48200798034668, 67.66095338548932, 46.45434604372297, 18.13585271154131, 9.306261726788112, 36.332137380327495, 62.13293184552874, 63.47722067151751, 57.58399486541748, 54.171022347041536, 55.346740927015034, 54.566089970724924, 57.864740303584504, 61.45428739275251, 57.53958545412336, 58.38335037231445, 54.592201301029746, 55.87637431280953, 55.210795947483604, 56.277000495365684, 55.10687868935721, 57.047996929713655, 50.306983198438374, 47.77895757130214, 43.69347585950579, 43.11866181237357, 36.13866826466152, 44.25242369515555, 36.01918009349278, 41.80639375959124, 31.214952400752477, 19.993019342422485, 25.681266341890606, 20.664635692323955, 25.79957331929888, 18.889162506375992, 27.01524404117039, 25.046263524464198, 13.17898438658033, 9.341715778623309, 4.965799799987248, 3.8373042174748013, 1.5494044252804346, 0.2156260795891285, 0.23732362102184976, 0.16514072647052153, 0.2673668717699391, 0.09892948291131429, 0.2467067560979298, 0.14663027759109223, 0.19018985091575555, 0.24391963279673032, 0.118960759469441, 0.1550154640738453, 0.7557034492492676, 0.24788968690804072, 0.12638771879885877, 0.26992934569716454, 0.44352826901844566, 0.22585484571754932, 0.25557898144636837, 0.16879074275493622, 0.17024100279169424, 0.09776871984026261, 0.1629473620227405, 0.18472841754555702, 0.07522363388644797, 0.14038254427058355, 1.9426170970712389, 4.05300235748291, 11.492698277745928, 18.1597649369921, 24.539086716515676, 27.86066610472543, 16.596350772040232, 23.868399688175746, 28.57164399964469, 40.241933890751426, 34.29385553087507, 40.02166557312012, 43.87881905691964, 42.407934052603586, 49.04274804251534, 46.1420453616551, 41.8309452193124, 44.752370902470176, 50.50337750571114, 48.77573224476406, 50.677662645067485, 50.03313384737287, 47.26560034070696, 47.0816467830113, 49.535052231379915, 46.79461669921875, 48.178638798849924, 50.02691520963396, 48.14797987256731, 47.86950996943882, 53.04213115147182, 56.053251130240305, 55.24625955309187, 52.620962619781494, 47.52444505691528, 47.869725363595144, 47.84779684884207, 42.28227935518537, 29.336968966892787, 4.336200509752546, 32.300643171582905, 52.79001923969814, 56.42053985595703, 44.654133796691895, 40.636265005384175, 45.97013303211757, 48.52033036095755, 65.80695165906633, 49.36249024527413, 6.014149214540209, 8.497091020856585, 50.26845891135079, 66.02521542140416, 45.23017767497471, 32.75821678979056, 19.5755455153329, 13.77536564213889, 30.693559578486852, 47.95180095945086, 28.79131129809788, 47.159838335854666, 45.60353912625994, 30.534021990639822, 46.51044232504708, 73.91897351401192, 37.038817814418245, 0.3287112143422876, 0.3227796240576676, 0.1520470633570637, 0.22829307988286018, 0.1543904518974679, 0.3740388735064438, 0.1384946291467973, 0.2912845526422773], [0.04288501791389925, 0.04654653197420495, 0.06471191865525075, 0.06527739616909198, 0.06756660368825708, 0.08999897140477385, 0.16186983484242642, 0.19783787695424898, 0.023941946980942572, 0.09369200002402067, 0.013686484740381795, 0.0882122190669179, 0.18650460509317263, 23.39945534297398, 58.50403363364083, 39.98253331865583, 31.836767537253245, 52.97985097340175, 43.373876094818115, 27.76445960998535, 42.68294722693307, 17.183027131216868, 14.45107534953526, 18.136368615286692, 12.38375437259674, 39.68198551450457, 45.774815695626394, 6.4685288327080865, 0.8458757592099053, 20.771141154425486, 49.05282293047224, 60.632614271981375, 61.01148564474923, 49.914812973567415, 47.823155062539236, 41.65520095825195, 54.621477535792756, 49.089839458465576, 18.532342978886195, 5.692094564437866, 22.246400049754552, 50.23353379113333, 54.57211058480399, 55.267764227730886, 50.80486331667219, 50.58371952601841, 54.09400503976004, 56.203144618443076, 54.8711575780596, 55.28341851915632, 55.93188347135271, 54.59075607572283, 51.60673754555838, 53.91933080128261, 52.451141698019846, 50.73507213592529, 52.40389742170061, 43.6564176423209, 41.7413238797869, 44.39291279656546, 35.91098621913365, 34.505219732012065, 29.125877482550486, 13.873731289591108, 9.03039218698229, 24.05913642474583, 24.30647839818682, 18.87765802655901, 17.852093492235454, 18.573596170970372, 19.257156474249705, 6.675135689122336, 0.7586490511894226, 2.709719283240182, 2.030396946838924, 1.73149445440088, 0.043807791612510166, 0.030051885106201683, 0.09376107488891908, 0.04259390603484852, 0.07691935396620206, 0.09785648834492479, 0.03245210434709277, 0.0679409582433956, 0.11883907099919659, 0.017901253354336535, 0.15410526362912996, 0.12286879548004695, 0.05582514890868749, 0.035805940095867426, 0.13609370083681174, 0.35445016462888035, 0.5484664237924984, 0.4435446081416947, 0.19744375667401723, 0.051753392576106956, 0.09793617549751486, 0.010354144132829137, 0.04106674423175199, 0.07576327957212925, 0.034152804873883724, 0.10319702713085072, 0.25830720790794914, 0.7681688975010599, 2.5798409496034895, 5.820758700370789, 8.053477202142988, 18.36564700944083, 13.911838684763227, 13.115456138338361, 10.471286160605294, 12.337649600846426, 28.030580827168055, 15.133324180330549, 24.577642270496913, 31.775925636291504, 34.151407037462505, 35.654920782361714, 37.68214804785592, 40.889780453273225, 46.18227890559605, 45.69400814601353, 43.695032255990164, 41.70449495315552, 42.26161888667515, 41.7206495148795, 40.4254914011274, 43.58076565606253, 46.31849486487252, 47.924480642591206, 45.20453882217407, 45.23121295656477, 46.36925145557949, 46.01780462265015, 47.819399561200825, 47.859702587127686, 40.46368217468262, 48.18114709854126, 36.06040375573294, 36.67204672949654, 12.942721315792628, 21.046387093407766, 50.28031601224627, 44.484021050589426, 48.428391797201975, 41.65833806991577, 42.54123871667044, 47.77779027393886, 37.25126593453543, 41.270357608795166, 3.1215177348681857, 1.3764935093266624, 41.43236180714199, 60.421020780290874, 52.861290386744905, 29.393471717834473, 12.994721634047371, 9.61623910495213, 12.47042793887002, 29.33210870197841, 22.37599437577384, 30.042798246656144, 37.056553091321675, 19.7043251650674, 31.896476881844656, 41.587046078273225, 51.32450519289289, 5.634745870317731, 0.11215484967189175, 0.13217726456267492, 0.0261190656040396, 0.1821356945272003, 0.017956682880009924, 0.07436103945864098, 0.04236105317249894, 0.14238514538322175, 0.03554984062377896, 0.1197053702282054, 0.08627199567854404, 0.022271498937958052, 0.03443690748619182, 0.01218152036225157, 0.03849944592054401, 0.08966349690620389, 0.05440800138083952, 0.19467971713415214, 0.021792816231027246, 0.07031082322022744, 0.19036143885127135, 31.306939601898193, 73.95090048653739, 43.521257809230256, 33.39941392626081, 48.374230589185444, 18.290151357650757, 33.17967714582171, 36.98349278313773, 20.77130617414202, 22.066584144319805, 16.18102046421596, 17.45390091623579, 38.28057554789952, 40.35104840142386, 13.409817440169197, 0.9196531432015556, 15.591040236609322, 53.01322317123413, 67.91677216121128, 62.92133699144636, 54.84361144474575, 53.458870206560405, 46.4407171521868, 59.024537086486816, 54.95646756035941, 24.41284315926688, 6.513311275414058, 19.85378439085824, 48.84123986107962, 54.85513503210885, 55.8238285609654, 51.71181515284947, 51.69773115430559, 55.92827040808541, 56.99882800238473, 58.25758102961949, 59.31935610089983, 57.6583058493478, 56.41657590866089, 53.54339851651873, 54.36855615888323, 53.07267195837838, 53.58305535997663, 54.75256225040981, 44.976981844220845, 45.33238220214844, 43.18469401768276, 35.26687431335449, 37.08260536193848, 34.13161161967686, 13.920920848846436, 11.21080812386104, 30.341588156563894, 25.991673639842443, 19.258815356663295, 18.249450547354563, 19.351570333753312, 23.65424404825483, 13.71511607510703, 7.061304407460349, 2.8276784164564948, 3.539665754352297, 1.9366275327546256, 0.06450788317514317, 0.028374924823375683, 0.0073850360432905805, 0.05064535167600427, 0.07959238838936601, 0.1082845198522721, 0.07506784903151648, 0.1011972012264388, 0.0796598686969706, 0.07728647533804178, 0.1212832084191697, 0.04942814127675124, 0.03629220203895654, 0.02087517734616995, 0.07410396968147584, 0.3002662664013249, 0.16893387293176992, 0.2590367959014007, 0.1786642822303942, 0.15865817932145937, 0.12328814369227205, 0.014111664112923401, 0.059868759608694484, 0.0577499797301633, 0.02523429156281054, 0.06978795770555735, 0.14154767032180512, 0.877109268946307, 3.6402476600238254, 7.834795679364886, 17.2620142527989, 24.903132370540074, 19.75086419922965, 18.08641975266593, 14.58175185748509, 17.82723457472665, 31.068262032100133, 17.321975469589233, 24.100136007581437, 35.25819601331438, 35.172618525368826, 36.210318088531494, 39.52036346708025, 41.48758608954293, 46.63813631875174, 46.464063099452424, 44.70996257237026, 45.11253077643258, 44.69713967187064, 42.80310937336513, 43.18510396139962, 46.329306261880056, 50.384382656642366, 50.07750851767403, 48.14346701758248, 47.44120563779558, 49.506762640816824, 50.296178749629426, 49.787310055324006, 51.72130986622402, 43.134243147713796, 45.3579272542681, 34.782282624925884, 39.721155984061106, 16.319041218076432, 26.806202275412424, 54.06594473975045, 50.61640385219029, 53.286124093191965, 44.40732683454241, 46.41650268009731, 49.199155466897146, 38.130893979753765, 39.37395797457014, 1.4328012764453888, 4.289435224873679, 47.67465121405465, 63.64804213387625, 69.15547616141183, 37.60010371889387, 13.024129884583608, 13.49323924950191, 17.363162653786794, 18.559229033333914, 35.24655430657523, 25.29123442513602, 32.97727264676775, 23.993877206529888, 24.043570722852433, 50.52884265354702, 55.139521326337544, 8.143102884292603, 0.12268379969256264, 0.12964113136487349, 0.0805253672546574, 0.17588756765638078, 0.012333643672588681, 0.08326322891350303, 0.07820774947426148, 0.1568787076643535, 0.10838429164141417, 0.13609323943299906, 0.1800045653113297, 0.22956902427332743, 0.10593404062092304, 0.3232155149536473, 0.18889536894857883, 0.2533345233116831, 0.15344648755022458, 0.18792579668973172, 0.09233249404600688, 0.13658873284501688, 0.29105640202760696, 44.47262600490025, 83.02263532366071, 54.44919695172991, 46.54568011420113, 66.37814222063336, 54.86856937408447, 37.80065304892403, 61.31550407409668, 22.90615929876055, 24.65970049585615, 22.343391690935405, 18.4501770564488, 51.41831282206944, 53.08829150881086, 10.563574739864894, 1.796362185052463, 26.959048748016357, 60.99943746839251, 70.4510303224836, 69.20210552215576, 58.92735263279506, 58.334045955113, 52.89692422321865, 61.025493213108604, 58.186758041381836, 22.361663716179983, 7.894160219601222, 27.975822074072703, 56.4696809904916, 59.380979674203054, 54.377762522016255, 51.7459169115339, 50.95976645605904, 56.32428993497576, 58.5797689982823, 57.92224359512329, 59.43311895642962, 59.288554736546104, 58.49443817138672, 55.40395586831229, 58.09872089113508, 58.64747224535261, 58.09534754071917, 58.43141106196812, 46.337407861437114, 46.51463903699602, 45.70940882819039, 39.91679988588606, 41.72502340589251, 43.603569643838064, 23.654523713248118, 14.603598730904714, 33.16388736452375, 30.836768899645122, 25.524113723209926, 25.496268817356654, 26.781753301620483, 35.65417732511248, 22.820243086133683, 16.755316870553152, 7.025148153305054, 3.8655786088534763, 2.697962062699454, 0.41844130946057184, 0.09041280312729733, 0.1510306993233306, 0.12126089818775654, 0.134075615555048, 0.2168853184474366, 0.4026690886488983, 0.23968722990580968, 0.320350278701101, 0.14006817899644375, 0.4432099275290966, 0.5029475263186863, 0.33064305782318115, 0.11119145208171435, 0.2695132680237293, 0.8332457797867912, 0.9534717627934047, 0.8037266837699073, 0.6170413440891674, 0.37311674441610065, 0.32330361594046864, 0.1651754674634763, 0.16557744517922401, 0.10632441538785185, 0.1519155361290489, 0.2810297714812415, 0.8562201069934028, 1.8516758169446672, 6.53719744512013, 16.29204225540161, 23.372543232781545, 33.04010173252651, 24.73499812398638, 22.026274170194352, 18.293684516634258, 23.91168349129813, 36.68239607129778, 23.627033165522985, 31.768716880253383, 38.535258293151855, 37.33188240868704, 40.28428316116333, 39.55757107053484, 41.70073250361851, 49.53243276051113, 50.91093451636178, 46.53778696060181, 46.75683239528111, 47.59093236923218, 45.674657412937705, 44.73361424037388, 49.6357489994594, 52.20824657167707, 53.059310572487966, 50.07321800504412, 50.27148485183716, 50.50392641339983, 51.80239186968122, 51.42797081811087, 54.365009103502544, 42.465513774326865, 46.39864580971854, 38.390509946005686, 45.08078793116978, 17.427291052682058, 25.938761370522634, 57.8341578074864, 53.64254583631243, 55.662960393088206, 50.26592629296439, 47.4610983303615, 51.26596661976406, 44.61295877184187, 51.063819204057964, 5.7108646886689325, 3.896901956626347, 50.6748104095459, 70.36845098223004, 62.45517539978027, 34.25664792742048, 15.949562072753906, 15.670301812035696, 16.095778226852417, 39.72079120363508, 36.765656335013254, 37.0068804195949, 52.8417728969029, 28.421609810420446, 43.693145820072715, 53.55643681117466, 73.30111190250942, 14.77152453150068, 0.2504072960998331, 0.49094646743365694, 0.13951286593718187, 0.31954616042120115, 0.08862449015889849, 0.17254012370748179, 0.17988082766532898, 0.27566986052053316], [0.043742553863142214, 0.050022470099585395, 0.019656238378956914, 0.07295846686299358, 0.09774783453238861, 0.046600997980151854, 0.06274407889161791, 0.136261556829725, 0.030559792316385677, 0.049401488421218734, 0.05255282896437815, 0.08628851800624814, 0.09395653368639094, 8.912639328411647, 60.239193371364046, 45.07536833626883, 27.108756371906825, 40.39177526746477, 49.67865412575858, 28.401611157826014, 37.441681316920686, 28.352343218667166, 7.295476504734584, 14.109246560505458, 8.100262028830391, 19.050895724977764, 64.9476123537336, 43.20491327558245, 6.896525706563677, 0.4229354368788855, 11.442186611039297, 38.99643455232893, 58.71200016566685, 54.569630077907014, 61.15046351296561, 57.00683927536011, 44.27692304338728, 51.73089143208095, 49.0244152205331, 14.09484555040087, 3.548884493964059, 24.813929659979685, 35.462869099208284, 50.195412499564036, 56.43359899520874, 52.673692498888286, 49.62439216886248, 54.892255783081055, 55.413137912750244, 52.83478648321969, 55.7706435748509, 51.9282272202628, 53.59900494984218, 51.80787399836949, 52.692463057381765, 52.35580546515328, 47.19844600132534, 39.71710518428257, 49.87506927762713, 38.36557980946132, 33.4515323638916, 23.718626056398662, 5.726448195321219, 3.0376686113221303, 21.2101856640407, 30.885270799909318, 17.847577163151332, 14.613597188677106, 20.414688144411357, 17.199239015579224, 18.1978497505188, 8.256021533693586, 2.096514484712056, 3.543887436389923, 2.5696399084159305, 0.44753458404115265, 0.10660648918045418, 0.03320154966786504, 0.022648939131093875, 0.05491681443527341, 0.07685543596744537, 0.004884525933968169, 0.028455521212890744, 0.21064947306045465, 0.09632916708609887, 0.16010313321437153, 0.27867492926972254, 0.3094148454921586, 0.11318660966519799, 0.05407972274614232, 0.3430790847965649, 0.6731045129043716, 1.4166829756328037, 0.9024808332324028, 0.4780600017734936, 0.21179961705846445, 0.05704957552786384, 0.03085831719051514, 0.08053091767110995, 0.01575992236446057, 0.06761862696813685, 0.09276320771979434, 0.037534786255231926, 0.44928471584405216, 2.2185954196112494, 5.368584700993129, 10.445727212088448, 16.316334894725255, 17.55863458769662, 10.251109038080488, 13.633365307535444, 5.88973433630807, 10.819858176367623, 22.48267354284014, 11.64584960256304, 18.33185965674264, 28.425900323050364, 34.373898778642925, 34.97841984885079, 41.43578379494803, 45.547289984566824, 45.627083097185405, 45.96065221514021, 43.375873701913015, 39.799941607883994, 41.65426989964077, 43.954345975603374, 46.028814043317524, 45.30031973975045, 46.35508060455322, 46.60249205998012, 46.960894039699006, 48.40135983058384, 50.21925176892962, 50.13461576189314, 51.11297423498971, 47.02462291717529, 37.33101388386318, 20.88901560647147, 20.50996879168919, 20.895460060664586, 37.968427726200645, 46.29589237485613, 43.152582917894634, 37.24854918888637, 55.30775111062186, 48.49335397992815, 50.09155430112566, 52.9683586529323, 9.486571822847639, 0.6283405263509069, 18.821674653462, 59.33335672106062, 40.630619594029014, 30.001800400870188, 17.100527695247106, 21.489595311028616, 13.420546327318464, 17.46682456561497, 35.548898220062256, 18.384605169296265, 36.99800409589495, 33.692113740103586, 38.30735737936837, 33.25723641259329, 49.49587481362479, 36.6888370513916, 1.4314405151775904, 0.15334164031914302, 0.034803587810269425, 0.08670726910765682, 0.053127894178032875, 0.04096006495612008, 0.04162422181772334, 0.04935923943828259, 0.0630798451602459, 0.06746724580547639, 0.09430173159177814, 0.007170115165146334, 0.06595815678260156, 0.028347966627084782, 0.10016023008418934, 0.03291263624227472, 0.08706431423446961, 0.028227664064615965, 0.06906828989407846, 0.041383752399789434, 0.04920679297564285, 0.16639574484101363, 11.876230154718671, 71.74509062085832, 54.610603604997905, 23.959066731589182, 47.7666140965053, 40.37727090290615, 28.050251177379064, 41.91677284240723, 21.395544494901383, 17.91017174720764, 15.308375358581543, 11.119135328701564, 29.377866063799175, 60.715930121285574, 45.95587880270821, 13.724085330963135, 0.49293120950460434, 9.199378456388201, 47.06353630338396, 64.6982831954956, 57.257825578962056, 65.77851963043213, 62.21352400098528, 50.548356669289724, 55.183013575417654, 54.44402401787894, 20.275718961443218, 4.582242735794612, 24.60987322671073, 38.00300196238926, 46.75336177008492, 56.3129608971732, 52.62322078432356, 52.53034768785749, 56.04094934463501, 56.18140023095267, 52.35804625919887, 55.92652988433838, 52.3172082219805, 54.516413824898855, 54.34423746381487, 53.07141433443342, 53.46581493105207, 45.99566418784005, 42.06363344192505, 49.36296272277832, 35.70777920314244, 35.91255303791591, 28.438502618244716, 6.531140352998461, 4.43608911548342, 28.711759635380336, 34.37309973580496, 22.94183656147548, 18.312404700687953, 23.71757687841143, 20.956654582704815, 24.550853490829468, 13.733536618096487, 6.740978990282331, 4.206383407115936, 2.1459265989916663, 0.4663089151893343, 0.07553450470524174, 0.10976506969226257, 0.03228995144101126, 0.053364373810057125, 0.04146890175927963, 0.04134156448500497, 0.06246053946337529, 0.16422557272017002, 0.10206947834896189, 0.157144340553454, 0.24969944836837904, 0.06416748929768801, 0.10285986986543451, 0.04626588310514178, 0.12271803856960364, 0.6094013111931937, 1.1098418406077792, 0.46395282447338104, 0.28386963052409037, 0.1442672793886491, 0.03048129938542843, 0.03706231553639684, 0.1029134402051568, 0.029118376983595744, 0.06374022936714546, 0.023104020693738545, 0.041778055884476216, 0.21725453649248394, 1.2311824666602271, 7.9100550924028665, 16.9444694178445, 22.14089686529977, 26.16803629057748, 16.960427692958287, 18.376588685171946, 10.546758362225123, 21.290367875780376, 27.663491862160818, 16.679963656834193, 17.045355524335587, 30.736172880445206, 34.97035993848528, 34.425193854740684, 41.73607798985073, 49.59605394090925, 47.35421419143677, 48.83871766499111, 45.706747668130056, 42.19614948545183, 43.62612002236502, 46.785368646894185, 48.39795521327427, 47.849026679992676, 47.46823065621512, 50.102928502219065, 47.54350743974958, 52.17785167694092, 51.68300792149135, 52.54933711460659, 50.765859603881836, 47.15803180422102, 38.27373504638672, 21.82906344958714, 17.44814954485212, 28.14620406287057, 42.266399247305735, 52.586353642599924, 50.10575989314488, 44.05302081789289, 56.76828677313668, 51.562321186065674, 50.64106995718819, 56.10592194965908, 8.746435812541417, 1.7835446042673928, 26.70654078892299, 68.41134493691581, 57.93925278527396, 42.24589511326381, 22.902879749025615, 16.065326009477886, 20.165313822882517, 17.165602786200388, 30.306416375296457, 27.95028223310198, 22.27174707821437, 41.99843154634748, 34.31063543047224, 30.841903618403844, 57.4796850340707, 42.03628185817173, 2.3605093359947205, 0.14489508712930338, 0.06907847470470838, 0.07747135577457291, 0.08510428440890141, 0.03005475870200566, 0.06000815784292562, 0.08021236583590508, 0.00984811392014048, 0.19947290207658494, 0.14122979023626872, 0.10554868701313223, 0.22211273866040365, 0.15263854233281954, 0.21234057231673173, 0.13384154811501503, 0.36107090221984045, 0.0694276691813554, 0.18401400159512246, 0.25900653323956896, 0.206804540806583, 0.24985838841114724, 18.941635302134923, 90.05608136313302, 59.868583406720845, 40.567106110709055, 50.29624823161534, 62.08447510855538, 35.33462272371565, 56.15060234069824, 38.173729624067036, 16.804496220179967, 23.71457178252084, 13.44627376965114, 29.296610355377197, 73.30737917763847, 53.40413229806082, 11.508165836334229, 0.5586117165429252, 14.682731764657156, 48.15210015433175, 67.13238307407924, 62.49953964778355, 69.48964977264404, 66.73692635127476, 56.96578584398542, 58.018743651253835, 55.54195751462664, 18.16858220100403, 5.3386019212859015, 32.95626824242728, 43.1687513760158, 51.835861342293875, 57.92609984534127, 53.072352341243196, 50.05610459191458, 59.22340842655727, 60.48575714656285, 57.714495931352886, 58.20752968106951, 55.486274651118684, 55.9135228565761, 57.40806300299508, 53.80622107642037, 55.95685877118792, 46.407501288822715, 44.423776694706504, 51.125408036368235, 38.73935815266201, 41.55252047947475, 41.174270970480784, 13.313252244676862, 5.944145245211465, 31.17592089516776, 40.952088424137656, 29.04113551548549, 25.015462160110474, 27.984227657318115, 29.65270205906459, 35.69045386995588, 21.526709113802227, 12.119693296296255, 7.041858570916312, 5.364274646554675, 1.691889613866806, 0.31787826706256184, 0.3195999003946781, 0.20226714999548026, 0.1856530707861696, 0.14990278413253172, 0.1287779262555497, 0.1316016497356551, 0.38012161425181795, 0.2107093741319009, 0.48206574682678494, 0.8395862281322479, 0.6219583345311028, 0.984270087310246, 0.1782553834574563, 0.7299843121852193, 1.226273998618126, 2.088679088013513, 0.9696505346468517, 1.0867032536438532, 0.4466794399278504, 0.21863090406571115, 0.12656147804643425, 0.3704996077077729, 0.10599719866045884, 0.20279723512274878, 0.09748549932347876, 0.16525254904159478, 1.4770849687712533, 5.364325889519282, 15.067813089915685, 23.4404844556536, 29.448470183781215, 31.616040638514928, 20.577461855752126, 21.36335870197841, 12.067589623587471, 22.89290734699794, 31.825407232557023, 22.480226039886475, 22.18712149347578, 34.55101530892508, 38.3900374685015, 37.044668197631836, 43.94488947732108, 50.36805786405291, 52.33846276147025, 51.10616500037057, 49.197439261845176, 44.56138229370117, 47.446951798030305, 48.73607887540545, 52.622369629996165, 51.87045989717756, 50.579015595572336, 51.732479095458984, 50.96965374265398, 54.374573298863, 54.87870332172939, 56.11104277202061, 55.45369107382638, 49.58260222843715, 43.914445945194785, 29.23187746320452, 24.613628728049143, 27.08246786253793, 46.67518758773804, 54.79200022561209, 55.46074002129691, 48.248871190207346, 61.561650957380024, 55.64003133773804, 53.17328534807478, 61.01270157950265, 14.488480976649694, 2.3431136522974287, 25.076069559369767, 68.83817972455705, 51.776179790496826, 39.37833881378174, 23.08495729310172, 25.446217468806676, 17.602262326649257, 23.735748154776438, 52.5065153666905, 27.263275623321533, 45.64669091360909, 52.561270645686555, 46.68637071337019, 47.60261229106358, 60.80811882019043, 61.03140613010952, 4.496885418891907, 0.34530823518122944, 0.10625196820391075, 0.24789774790406227, 0.20224198991698877, 0.14147345216146537, 0.11459674792630331, 0.2603218326611178, 0.1844668694372688], [0.06740125827491283, 0.09920013695955276, 0.027990268410316536, 0.10114490653255157, 0.05611254241583603, 0.006182927713130734, 0.02382589374402804, 0.04593118552916816, 0.08595425130001136, 0.05870655804340329, 0.023458373732864857, 0.03026698070711323, 0.025910863918917518, 0.5697360539010593, 46.02923093523298, 60.09018925258091, 31.824316365378245, 36.12206901822771, 69.25530093056815, 38.48646109444754, 30.092950344085693, 39.22493648529053, 8.530327728816442, 17.019395317350114, 13.68482974597386, 8.362217800957815, 50.49230555125645, 74.79407828194755, 36.85681670052664, 4.563561201095581, 0.7523669025727681, 15.451369285583496, 56.00960949489048, 56.025833538600374, 50.03735835211617, 58.71199321746826, 49.32021740504673, 37.90862110682896, 54.388275146484375, 45.942281178065706, 8.600057244300842, 11.870334608214241, 34.327269417899, 40.136946610042024, 47.69819518498012, 48.28019714355469, 49.9845346723284, 52.48663657052176, 56.267835821424214, 55.47176333836147, 56.23614508765084, 55.022770745413645, 53.373247555324006, 52.46667092187064, 53.38162708282471, 52.608639989580425, 44.650694438389365, 55.03696938923427, 43.916554723467144, 34.0768598147801, 14.952186380113874, 3.686715475150517, 0.5466842651367188, 18.98787730080741, 34.16060297829764, 16.92799002783639, 6.832092455455235, 14.441599743706838, 15.814105204173497, 14.920214244297572, 15.838246720177786, 8.035812275750295, 3.2987054841859, 2.664389452763966, 0.9451030918530056, 0.11176072939166001, 0.020726752899853245, 0.04769388719328812, 0.06936347298324108, 0.03169038772050824, 0.02853552558060203, 0.07804692310414144, 0.22223680200321333, 0.21554914728871413, 0.15432140417397022, 0.2477582682456289, 0.13554954289325646, 0.2999360098370484, 0.48693062577928814, 0.015506330079266002, 0.3671725605215345, 0.35928733221122194, 0.724275607083525, 0.6096350529364177, 0.6074636323111398, 0.12694730662873813, 0.22387919601585182, 0.07997143162148339, 0.1408699495451791, 0.06805309294057743, 0.0604075299842017, 0.045841340707348924, 0.031905483321419785, 0.19295986156378472, 0.7342222247804914, 5.142699199063437, 8.56320399897439, 14.556529896599905, 21.666284527097428, 17.956575291497366, 9.140532425471715, 11.815224971090045, 2.5059503316879272, 10.73841747215816, 20.142042568751744, 8.69583295072828, 10.99787449836731, 25.679626567023142, 33.533889361790244, 38.26208291734968, 45.87637056623186, 47.282067571367534, 43.93075336728777, 44.69917549405779, 43.16940450668335, 39.323316029139924, 41.654068401881624, 45.72242627825056, 48.58922869818551, 49.477555888039724, 49.97727033070156, 46.7447703225272, 44.583550521305625, 49.677709170750205, 51.08197137287685, 48.66172272818429, 36.83490555627005, 23.096008402960642, 7.351282698767526, 8.165002737726484, 36.80487544195992, 49.66516072409493, 32.99874952861241, 39.07633883612496, 38.24689415522984, 48.10854189736502, 35.39873027801514, 33.44342034203665, 30.150926113128662, 1.8146929442882538, 5.4011795691081455, 45.21545444216047, 34.211717401232036, 16.821191004344396, 17.516049078532628, 20.926240580422537, 19.709779500961304, 11.12497876371656, 27.51109528541565, 25.42832064628601, 22.787331206457957, 47.89078535352434, 33.228543826511924, 27.850747551236832, 32.86941576004028, 55.49164908272879, 28.078328847885132, 0.3535708375275135, 0.10594717027353388, 0.10026203747838736, 0.03908169682004622, 0.1419752152370555, 0.05227812406207834, 0.058284319271998744, 0.0608399332101856, 0.08245558903685637, 0.047115185031933446, 0.05307772329875401, 0.03388558082016451, 0.008721699139901569, 0.03428672733051436, 0.1387900361525161, 0.0577315032216055, 0.0393127413865711, 0.09308034820216042, 0.07032315220151629, 0.022594271260978918, 0.0940691569287862, 0.03064396119277392, 1.0201248547860553, 55.04979228973389, 68.5454660143171, 30.461135387420654, 43.324526514325825, 82.55799538748605, 23.21088297026498, 43.07832057135445, 32.098540919167654, 13.557940874780927, 20.538404294422694, 11.54734672818865, 17.617506674357823, 65.17409583500454, 70.73239762442452, 42.18172155107771, 7.253881113869803, 0.47822735565049307, 11.907226068632943, 61.82359804425921, 61.89949321746826, 55.93210928780692, 59.97279248918806, 52.436022417885916, 45.23527070454189, 61.18938732147217, 54.939513955797466, 13.755023053714208, 12.2760876928057, 40.437303338732036, 42.263053689684185, 46.560038566589355, 47.681217261723106, 50.30456869942801, 51.32197257450649, 59.75844056265694, 57.99567215783255, 61.02261665889195, 58.17889615467617, 57.48789085660662, 55.53165333611624, 55.70182861600603, 49.328287737710134, 47.29216677801949, 52.85210139410836, 43.36248104912894, 38.416388511657715, 17.940917525972637, 3.06260222196579, 5.252075569970267, 27.961868354252406, 33.68899747303554, 24.541252817426408, 12.051748599324908, 18.252353157315934, 20.12366110937936, 21.733871391841344, 20.015416860580444, 12.835978746414185, 7.019913988454001, 3.8320496422903876, 0.08079720195382833, 0.20363784501595156, 0.06320678549153463, 0.035444755905440876, 0.03070393351039716, 0.09719598200172186, 0.10851049915488277, 0.05926612551723208, 0.06694554058568818, 0.21308592946401664, 0.370527590491942, 0.318236343562603, 0.40165090614131516, 0.15380681678652763, 0.10396062329943691, 0.11397172217922551, 0.12703918027026312, 0.89400614798069, 1.1145948427064079, 1.2631618763719286, 0.8584112865584237, 0.19683794703866753, 0.0880558303158198, 0.09741204790771008, 0.18271626265985624, 0.11015422309615783, 0.023680079961195588, 0.07818949688225985, 0.03882914608610528, 0.3815678980733667, 0.37483509363872664, 5.5842116219656805, 15.05150740487235, 19.864312648773193, 29.178143569401332, 22.81593346595764, 15.762511355536324, 14.161479643413, 6.2636090857642035, 21.317476272583008, 25.51085134914943, 14.760523796081543, 11.054459759167262, 25.971695831843785, 35.14368970053536, 39.65955325535366, 45.74179090772356, 50.74493857792446, 45.9020128931318, 47.73070580618722, 45.90705728530884, 42.11460542678833, 44.86870459147862, 48.55843775612967, 53.5709342275347, 53.13431985037667, 51.95103815623692, 50.86821004322597, 46.335625648498535, 50.82221296855381, 53.10075657708304, 49.95215259279524, 38.31061955860683, 22.173952920096262, 7.5654513665608, 13.031151907784597, 43.878235408238, 51.041070801871165, 37.74662038258144, 43.09969323022025, 42.66826915740967, 53.51777008601597, 44.41848564147949, 39.75438574382237, 27.76724931171962, 0.5538702223982129, 9.912007416997637, 49.90059001105172, 44.17424256461007, 24.242678301674978, 22.933286803109304, 18.57753927367074, 15.995748485837664, 18.24968331200736, 19.301781279700144, 35.014783246176584, 23.300613743918284, 41.317383016858784, 41.9709027835301, 22.953730140413555, 36.51349925994873, 62.86238847460066, 33.66518252236502, 0.2491856345108577, 0.15312098073107855, 0.0663932945047106, 0.04825161922989147, 0.056837099072124274, 0.06563155752207551, 0.05914510879665613, 0.038457760121673346, 0.09771508164703846, 0.208499494141766, 0.12701079036508287, 0.26433856998171124, 0.20455039319183144, 0.29593645302312716, 0.26168878216828617, 0.12052029078560215, 0.22476635341133389, 0.19632692874542304, 0.12464543086077486, 0.13791867505226815, 0.22455693036317825, 0.12561394460499287, 1.5138084782021386, 69.45895957946777, 74.33056395394462, 47.43691512516567, 47.00806188583374, 83.93100806644985, 46.697668484279085, 42.32876280375889, 61.21139921460833, 12.592103924070086, 27.265877723693848, 19.845618520464214, 14.42980170249939, 60.19056292942592, 82.19528552464077, 45.93796634674072, 7.758128387587411, 1.378485796707017, 19.901801654270717, 67.78288037436349, 65.11789185660226, 59.46767234802246, 64.97601658957345, 55.91765008653913, 49.61393512998308, 62.36316735403878, 54.767059666769846, 11.358535511153084, 14.608912365777151, 45.0578727722168, 46.988839694431846, 49.77871513366699, 50.662185532706125, 53.69253812517439, 53.92277710778372, 59.885842732020784, 59.762574740818565, 61.68318884713309, 59.146936552865164, 59.13234533582415, 57.24051414217268, 57.142186709812705, 52.09109994343349, 50.61893994467599, 54.91014044625418, 46.293582098824636, 45.620652539389475, 28.318811212267192, 6.816579299313681, 6.330852448940277, 31.73018911906651, 40.24551568712507, 27.07750337464469, 15.380888496126447, 22.81920085634504, 27.39018794468471, 30.048749378749303, 31.177953243255615, 18.53260006223406, 11.225598233086721, 6.828151958329337, 3.4921895819050923, 0.2212001226310219, 0.12845464503126486, 0.12105650986943926, 0.11459163177226271, 0.13469164392777852, 0.4600992883954729, 0.0985481801575848, 0.42386538269264357, 0.4479084839778287, 0.9162072709628514, 1.3324272739035743, 0.9122201991932732, 0.8234082705208233, 0.8824871746557099, 0.3786130409155573, 0.5880409202405384, 1.339096024632454, 1.6359147088868278, 1.5373415925673075, 1.0760222439255034, 0.5646048092416355, 0.49001752585172653, 0.31981570167200907, 0.6871698381645339, 0.1943047179707459, 0.1824578900954553, 0.13501309310751303, 0.0621673512671675, 0.45186352889452663, 1.2449306717940738, 11.873385735920497, 20.731835194996425, 25.995799132755824, 34.21919713701521, 29.029794318335398, 15.93601655960083, 16.664920806884766, 6.440435094492776, 23.45532407079424, 30.50433233806065, 19.153682163783483, 15.571729455675397, 30.35863208770752, 35.64651346206665, 39.50465359006609, 50.87789235796247, 52.44313737324306, 48.4141514641898, 49.971496377672466, 48.55500882012503, 43.21204212733677, 48.063149315970286, 50.23013959612165, 53.65665067945208, 53.99994380133492, 56.53309025083269, 53.474364689418245, 48.412998063223704, 53.99792534964425, 56.77666630063738, 52.34448684964861, 42.82812288829258, 28.124442304883683, 9.550727146012441, 11.96906156199319, 43.83185965674264, 55.57482944216047, 42.62432180132185, 47.114431858062744, 46.810451643807546, 57.148877825055806, 43.4176983833313, 42.588062626974924, 38.04330151421683, 4.079372073922839, 8.54322097982679, 54.3779570715768, 46.54472473689488, 22.59036714690072, 25.02787859099252, 27.407876321247645, 26.672225373131887, 15.350799322128296, 36.985969815935405, 39.517327104296, 29.445784705025808, 63.14968258993966, 46.942568165915354, 39.394173758370535, 45.35040235519409, 70.4047622680664, 49.26564277921404, 0.6012377749596323, 0.2918373958340713, 0.21746538446417876, 0.11032414183552776, 0.16093626565166883, 0.13067107966967992, 0.24751486416373933, 0.1508329470774957, 0.13897619902023248], [0.04584759340754577, 0.023101238700162088, 0.017884905749399747, 0.010899967031686433, 0.06521142220922879, 0.04356763092800975, 0.02514755103870162, 0.0017077947164320254, 0.11933103602911745, 0.05775722648416247, 0.1408632727605956, 0.02054572314955294, 0.047884379114423475, 0.06603989311094795, 26.088481153760636, 61.283181054251536, 47.46968282972063, 24.187671150479996, 50.08385917118618, 64.65225832802909, 22.218765326908656, 35.1947728565761, 13.35546168259212, 11.286744117736816, 16.089359828404017, 8.275510362216405, 23.824330738612584, 85.66932923453194, 54.70333773749215, 21.36841004235404, 1.3229149729013443, 7.032294375555856, 25.71169945171901, 61.690706798008506, 53.56295422145298, 54.46112353461129, 63.172729764665874, 48.34816442217146, 35.68433598109654, 51.66016571862357, 30.241176264626638, 8.718027234077454, 23.295223678861344, 34.728319440569194, 36.572423458099365, 44.26896735600063, 43.91427918842861, 47.28626080921718, 39.599034445626394, 47.97237457547869, 48.10409505026681, 51.57103075299944, 47.98709086009434, 51.90787942068917, 46.69238437925066, 50.05182102748326, 46.40876933506557, 45.352000440870015, 28.32447052001953, 9.337031824248177, 3.1215188205242157, 4.8815541948590955, 20.615737744740077, 22.150971753256663, 24.786826474326, 4.863609603473118, 6.445587618010385, 17.00532521520342, 11.787364431789943, 18.86409514290946, 13.79006108215877, 9.520156809261866, 4.124035094465528, 1.6095238221543176, 0.3000975554542882, 0.025462918848331486, 0.06147371205900397, 0.04100549626829369, 0.1774339218224798, 0.15655165378536495, 0.2480391003191471, 0.06491528238568987, 0.13515490692641052, 0.09986664833767073, 0.5077342923198427, 0.8243906263794217, 0.6773897601025445, 0.5166272265570504, 0.13189360978347914, 0.21451664769223758, 0.10597136004694871, 0.3484116643667221, 1.4735893734863825, 0.5398552172950336, 0.10888899277363505, 0.6093003451824188, 0.4762821857418333, 0.17928216978907585, 0.07657332146274191, 0.10351805561887366, 0.02277089562267065, 0.08266609095569168, 0.09324860453073468, 0.46155938719000134, 0.13515912741422653, 2.0035510616643086, 8.58861790384565, 12.510345339775085, 18.201971769332886, 25.777879306248256, 14.714846338544573, 10.954082608222961, 8.75902247428894, 3.7186368022646223, 12.800245029585701, 18.483729907444545, 18.059259244373866, 10.552207486970083, 24.028027602604457, 41.190418584006174, 43.60519552230835, 43.37661715916225, 48.31268344606672, 44.05086687632969, 40.61446155820574, 44.00244140625, 46.578406129564556, 46.14982386997768, 46.866412435259136, 48.20780038833618, 46.9106377192906, 50.0298820904323, 51.056978702545166, 54.779955523354666, 51.61642680849348, 44.25564071110317, 19.6597455229078, 5.451999996389661, 8.363584859030587, 29.890500681740896, 47.856923307691304, 46.00835854666573, 47.21520158222744, 47.70805467878069, 47.76420654569353, 49.462652002062114, 32.65761382239205, 17.441868373325892, 2.4800632979188646, 0.7120914523090635, 31.145060471126012, 48.40126255580357, 21.692164829799108, 32.07781791687012, 19.611842904772075, 21.495329311915807, 9.776462827410016, 12.687572172709874, 33.50136137008667, 19.048220668520244, 31.155409812927246, 32.2053416797093, 21.31597719873701, 25.847660064697266, 36.432062898363384, 49.88804851259504, 9.444392783301216, 0.015873941692656705, 0.06402718861188207, 0.10435869265347719, 0.0259001040498593, 0.035340251334543736, 0.04113939158352358, 0.03181820336197104, 0.06727138667234353, 0.09316363159034934, 0.12222330511680671, 0.022975058328094225, 0.004343628775261874, 0.019984442374802062, 0.09029225459588425, 0.013476469670422375, 0.08717133277761084, 0.07498629590762512, 0.1141595813844885, 0.018695906070726256, 0.11550857685506344, 0.13314154424837657, 0.03242912236601114, 0.16098212104822907, 31.89397553035191, 69.14570004599435, 53.79540620531355, 21.59136210169111, 68.41283185141427, 52.450248854500906, 31.676851272583008, 39.40121923174177, 18.720432451793126, 16.781940630504064, 10.50888807432992, 15.986067908150808, 43.712698050907676, 102.85908222198486, 58.63678591591971, 32.50018848691668, 4.315593021256583, 3.9459297486713956, 22.214745794023784, 62.995258876255576, 57.84293685640608, 60.94904913221087, 64.01671355111259, 51.584069047655376, 44.43617922919137, 55.62235164642334, 35.277508531297954, 11.819763881819588, 21.042245967047556, 35.60366044725691, 41.58946752548218, 49.8852344921657, 45.8483693259103, 50.12563868931362, 41.378891944885254, 46.87940904072353, 48.718079566955566, 53.07016365868704, 48.44432054247175, 54.5950813293457, 48.40126255580357, 51.27928284236363, 48.136355536324636, 44.40065656389509, 33.5419214793614, 9.507841995784215, 3.382833404200418, 7.229780418532235, 25.876607997076853, 25.87344309261867, 30.77071237564087, 10.155674661908831, 9.858207515307836, 19.734513350895472, 18.180866616112844, 25.9581972190312, 20.732649871281215, 15.085166215896606, 5.369481887136187, 1.46065454185009, 0.2213588184011834, 0.0861293879736747, 0.02805498199138258, 0.09376946158174958, 0.03721422256369676, 0.10041631598557745, 0.1386129113712481, 0.044935279326247315, 0.1469898061560733, 0.6446444743445942, 0.5175095392124993, 1.040940789239747, 0.4132307847695691, 0.18479340762964316, 0.15259740953998907, 0.3729379368679864, 0.2764428476137774, 1.24086771266801, 1.8614273965358734, 1.2882969847747257, 0.8122977209942681, 0.5205900339143616, 0.1967550843421902, 0.37288384405629976, 0.1862109215664012, 0.10692156691636358, 0.02599500395756747, 0.1614555756428412, 0.039216871173786264, 0.4055090291159493, 0.4026104360818863, 3.7649847609656195, 13.031894496509008, 19.057614633015223, 25.292773451123917, 30.0354540007455, 17.03235718182155, 15.258390017918178, 7.24916068145207, 8.293128388268606, 21.38202851159232, 24.85853362083435, 26.445271151406423, 14.684977769851685, 25.68503052847726, 40.99944734573364, 46.6841333934239, 46.38538864680699, 50.56665127617972, 46.183543477739605, 43.44623463494437, 46.60850919995989, 49.33929368427822, 48.23659372329712, 49.05104071753365, 50.475046225956504, 49.06543738501412, 52.37922784260341, 54.11795548030308, 57.365811007363455, 52.528231961386545, 43.2062577520098, 17.266950947897776, 5.298948117664882, 12.1655626978193, 37.360380445207866, 51.63630560466221, 50.987166677202495, 50.46041679382324, 50.25397539138794, 51.5981183052063, 54.238878454480854, 32.59047337940761, 11.583177719797407, 0.8999197163752147, 2.4754325406891957, 38.92158160890852, 48.31288494382586, 28.09652270589556, 32.78945936475481, 24.190415688923427, 16.000311715262278, 11.989405018942696, 14.448404635701861, 27.506844724927628, 29.635185650416783, 26.627011707850865, 35.15427875518799, 26.742799963269913, 26.689498594829015, 43.00161245891026, 56.709098543439595, 9.456080521856036, 0.04319715080782771, 0.16501521106277192, 0.04622295219451189, 0.07456149905920029, 0.013255970386256064, 0.0823335816551532, 0.03637368052399584, 0.0642640787575926, 0.0742732302418777, 0.1455373748072556, 0.14825300765889032, 0.10520331268864018, 0.12287961132824421, 0.17796454977776321, 0.09300741247300591, 0.2699271472437041, 0.2275395124618496, 0.12039378471672535, 0.1642083107892956, 0.23569988672222408, 0.22712658319090093, 0.14588140563241073, 0.28628730507833616, 41.45029163360596, 83.8923066002982, 64.85350595201764, 35.288024629865376, 60.50274549211775, 78.16480922698975, 32.253589970724924, 52.95575114658901, 21.542085477284022, 21.30791207722255, 24.537412200655254, 13.976634979248047, 34.66745669501168, 90.6566002709525, 61.49519143785749, 30.12996687207903, 2.74524108001164, 10.698791027069092, 32.963272026606965, 71.6944660459246, 60.855526379176546, 64.27538803645542, 70.59121022905622, 57.12741483960833, 48.07683726719448, 61.12782628195626, 36.10625491823469, 11.456651891980853, 25.330354520252772, 45.14286661148071, 47.072103432246614, 52.47944865907942, 48.86299467086792, 54.54201793670654, 47.76431424277169, 53.197833333696636, 52.850048201424734, 57.0438141141619, 50.902513299669536, 55.08016633987427, 46.60132476261684, 53.375863552093506, 47.78002411978585, 49.15687220437186, 41.7458575793675, 17.182398319244385, 6.124106628554208, 9.49903689111982, 33.189331667763845, 29.712317602975027, 36.48779787336077, 11.748736790248326, 13.291163921356201, 26.050283432006836, 24.260703665869578, 33.038201400211875, 27.146453823362076, 20.511434861591884, 8.927387748445783, 3.6903450403894698, 0.6572062202862331, 0.12865726915853365, 0.12709589222712175, 0.18923306225665978, 0.23954853734799794, 0.28681859799793785, 0.4464582646531718, 0.30463809466787745, 0.5536529283438409, 0.8490785530635289, 1.0951459663254874, 2.9365886066641127, 2.6146703149591173, 1.4035588055849075, 1.549429503934724, 1.4031237832137515, 0.9693595788308552, 1.3397828106369292, 2.1042165628501346, 1.1589910089969635, 1.1598275069679533, 1.0920640059879847, 1.8859745136329105, 1.786562945161547, 0.6096740279878888, 0.36695295944809914, 0.054138249784175835, 0.30532748624682426, 0.09776806844664471, 1.6555803907769067, 1.0531068678413118, 6.165578688894, 22.231164387294225, 26.072712217058452, 32.64968940189907, 35.13954857417515, 21.958680357251847, 16.371618236814225, 15.528692313602992, 7.3306682620729715, 24.53490390096392, 29.721708093370708, 27.950542790549143, 17.11350519316537, 29.608004297528947, 41.8119592666626, 47.89313037054879, 48.710693631853374, 53.64450175421578, 47.862092767442974, 46.05597802570888, 50.76742989676339, 52.128814765385215, 50.72741174697876, 51.80861745561872, 54.60525696618216, 52.26522874832153, 54.22643075670515, 55.668970584869385, 60.20477894374302, 56.35168668201992, 49.06676796504429, 24.019276346479142, 7.550735081945147, 10.428847432136536, 36.09146220343453, 56.382057258060996, 54.9371064049857, 56.11813688278198, 56.217704568590435, 57.58254616601126, 56.29773391996111, 40.661893435886924, 22.215299912861415, 3.9867456385067532, 1.9655465866838182, 36.31555897848946, 55.32969004767281, 28.662208557128906, 40.98343174798148, 29.138429403305054, 28.616892405918666, 16.413039922714233, 17.3210391998291, 48.07261276245117, 30.712000097547257, 42.500894001552034, 45.78120109013149, 29.84203004837036, 39.88464362280709, 48.35411902836391, 72.03501115526471, 19.103851420538767, 0.09289000555872917, 0.12847270763346127, 0.17627098065401825, 0.11664209674511637, 0.0949950586738331, 0.27448421557034763, 0.18345431877034052, 0.1650559910173927, 0.18368407072765486], [0.03295540091182504, 0.04439071426168084, 0.02474273874291352, 0.03889713868764894, 0.1290743646344968, 0.093283182675285, 0.08409278547125203, 0.05955756309309176, 0.004996397274745894, 0.04119391187227198, 0.13411585268165382, 0.06394254136830568, 0.07489422549094472, 0.0798042541635888, 1.6036069967917033, 27.949203525270732, 62.11472061702183, 31.413257462637766, 45.13697106497628, 47.058821950639995, 30.684002331324987, 25.478830575942993, 14.14274730001177, 8.949697545596532, 15.717434917177473, 18.345933232988628, 13.028987543923513, 27.96838923863002, 50.65560906273978, 71.26055104391915, 14.533889191491262, 0.5529563171522958, 2.477808390344892, 27.90471073559352, 53.49665103639875, 51.37689461026873, 49.257141658238, 55.88048069817679, 47.045557839529856, 36.716810498918804, 54.6140638078962, 19.94069766998291, 6.22613354240145, 2.3766738857541765, 18.20863856588091, 38.36945343017578, 39.61544609069824, 46.031711442129954, 52.08787945338658, 53.11240175792149, 51.78719615936279, 47.80506195340838, 45.61559077671596, 49.904508795057026, 56.82045037405831, 52.275185516902376, 48.527605124882285, 22.800852400915964, 4.508543627602713, 1.2866091153451373, 9.50444085257394, 21.039654288973125, 17.4010876587459, 15.967660393033709, 8.194553426333837, 5.537036393369947, 11.29695188999176, 11.986385158130101, 18.453315905162267, 15.72486080442156, 13.685211028371539, 7.361336742128644, 3.3985428469521657, 2.0620755212647572, 0.3576975246625287, 0.08883314646248307, 0.25775868019887377, 0.07405594975820609, 0.12989873039935315, 0.10171677584626845, 0.03023876722103783, 0.04374119679310492, 0.4110840899603707, 0.33870638800518854, 0.6100364199706486, 0.648539482482842, 0.5678753480315208, 1.727400119815554, 1.115782658968653, 0.265878111656223, 0.07187196944973298, 0.6133763864636421, 0.42019467109016007, 1.4219053068331309, 1.9076170665877206, 1.2154342659882136, 1.187718118940081, 0.6292183335338319, 0.22180384237851414, 0.3047796370727675, 0.12499900188829217, 0.3518019238752978, 0.04980675703180688, 0.38529031404427116, 0.48833671318633215, 3.205595931836537, 3.9364380751337325, 12.53804954460689, 19.006217070988246, 21.92072582244873, 26.43703579902649, 12.37232198034014, 7.530959640230451, 4.46558552128928, 1.2103930222136634, 5.262623369693756, 13.573572584560939, 20.649240221296036, 11.312259640012469, 16.120880331311906, 42.952096121651785, 47.0625079699925, 39.9629567691258, 46.00157363074166, 47.62301915032523, 45.259037017822266, 43.128128732953755, 44.816144943237305, 53.170624188014436, 50.91874429157802, 50.26351179395403, 49.61343485968453, 48.70631626674107, 46.12350409371512, 43.52586099079677, 13.08799077783312, 3.2411958958421434, 6.820495912006923, 27.21542511667524, 46.71043579918997, 46.33931861604963, 45.35422386441912, 43.62333379473005, 46.70414073126656, 45.80414751597813, 44.09852804456438, 33.581112793513704, 4.138783514499664, 0.3577767504113061, 26.21777149609157, 52.97591134480068, 39.89887005942208, 54.668725286211284, 34.83715602329799, 15.024192299161639, 16.80505207606724, 5.032322721821921, 21.799500601632253, 26.698520830699376, 21.185606411525182, 31.050835950034006, 24.39734172821045, 23.456460101263865, 37.774500029427664, 43.633936745779856, 43.27771302631923, 1.5151669595922743, 0.005091351465255554, 0.05868830545140164, 0.05767330527305603, 0.030201169595654522, 0.04204592793913824, 0.14673710614442825, 0.03234704677015543, 0.0858315789539899, 0.01732492776188467, 0.048083356115967035, 0.03141011204570532, 0.09195085202476808, 0.022826881547059332, 0.044656757664467604, 0.06901638196515185, 0.10201088006475142, 0.06545595944459949, 0.021685989374028783, 0.08596940298697778, 0.0955214322145496, 0.02766942312674863, 0.02423020562023989, 0.1943356455968959, 2.4580943967614854, 36.988123757498606, 74.43676022120884, 22.362737212862285, 49.87135893957955, 54.006874629429404, 27.91229122025626, 37.391977378300254, 16.65034522329058, 17.9049779687609, 10.542256798063006, 16.531522342136928, 21.145013298307145, 46.50280278069632, 60.30720233917236, 75.41731779915946, 23.831827844892228, 3.288345502955573, 2.334269246884755, 28.416264908654348, 56.23150716509138, 56.643771580287385, 56.90864385877337, 56.95497097287859, 50.2034341948373, 43.07831709725516, 57.04093408584595, 26.630487544195994, 8.48087739944458, 3.413516649178096, 16.171807152884348, 37.38044336863926, 42.71600675582886, 50.60219131197248, 58.12942498070853, 58.03372744151524, 53.25687565122332, 50.39417266845703, 48.52358906609671, 52.045526708875386, 59.061890602111816, 53.69542162758963, 45.446009567805696, 24.50478867122105, 4.642559613500323, 3.2257667694772993, 14.29134408065251, 24.983627251216344, 20.533007281167166, 20.459330320358276, 13.36642507144383, 8.662095972469874, 12.851210066250392, 17.539441926138743, 22.841784238815308, 22.656993423189434, 18.362410885947092, 10.609776786395482, 4.581321230956486, 2.0615663485867635, 0.14855566141860826, 0.22001945812787327, 0.1085389501282147, 0.11670689683939729, 0.0912334912323526, 0.18157344684004784, 0.31356590560504366, 0.031556231169296164, 0.10434637045753853, 0.43146454063909395, 0.5121907474739211, 0.7657526614410537, 0.6940208162580217, 1.147323680775506, 1.9945907081876482, 0.3051203159349305, 0.6360105233533042, 0.5508368451680455, 1.3658359497785568, 1.6888646504708698, 0.7095189360635621, 0.9586483878748757, 0.9607502179486411, 0.6880670243075916, 0.24669093266129494, 0.3798776944833142, 0.06887574879718678, 0.114321588405541, 0.07676863098250968, 0.30789948680571144, 0.28901102606739315, 3.9425898364612033, 12.098628963742938, 19.141429015568324, 24.86407654626029, 28.55860570498875, 26.357383387429373, 14.57016486780984, 10.500801239694868, 5.727081784180232, 8.033055577959333, 11.362645370619637, 21.902459008353098, 28.44522500038147, 17.374694926398142, 18.823630571365356, 41.798149721963064, 49.947622367313926, 43.02708455494472, 46.04186970846993, 49.385433197021484, 49.09618316377912, 46.611198152814595, 47.398717403411865, 56.445306709834504, 53.17619316918509, 51.28538336072649, 51.18865053994315, 48.62038442066738, 47.274059772491455, 41.59361560004098, 10.150023170879908, 3.272160108600344, 11.1735805443355, 33.20171683175223, 50.62533923557827, 49.99194145202637, 49.34934772763933, 46.75232648849487, 52.02333068847656, 49.62725135258266, 49.95544951302664, 30.35562699181693, 2.106152504682541, 2.3536755655493056, 36.098789078848704, 57.58272334507534, 46.30592557362148, 57.22516904558454, 34.316023758479524, 18.3910722051348, 11.052342295646667, 8.046905074800764, 17.978125129427227, 27.833661930901663, 30.30713551385062, 27.552834851401194, 32.64903279713222, 20.99587368965149, 38.183787141527446, 52.68973936353411, 52.30501413345337, 2.167145311832428, 0.05401672076966081, 0.053755606923784525, 0.10066423232534102, 0.0725626095331141, 0.05067063049812402, 0.11607075668871403, 0.020595551368647387, 0.06022952310740948, 0.017117475857958198, 0.09583064740789787, 0.25341551325150896, 0.3358863964676857, 0.1702557812844004, 0.26431422414524214, 0.21653813921979495, 0.199855826529009, 0.1963924616575241, 0.12430610906864915, 0.16515606136194297, 0.25702841367040363, 0.2333881721964904, 0.19811418998454297, 0.3413975393133504, 4.583466487271445, 60.06680161612374, 78.54363196236747, 43.19371625355312, 53.68598597390311, 64.85933549063546, 38.88221311569214, 40.35629081726074, 24.766007934297832, 15.021008287157331, 23.80553933552333, 27.805544308253697, 17.302735907690867, 38.03563070297241, 62.20820862906319, 81.63774817330497, 21.83470364979335, 2.6960293778351376, 4.968956019197192, 33.76416308539254, 65.08378314971924, 61.184857095990864, 61.36176518031529, 62.881364004952566, 56.10640484946114, 46.60965912682669, 63.897204535348074, 26.88197759219578, 9.409911479268755, 5.1455166935920715, 22.51978734561375, 48.03788219179426, 47.307091508592876, 53.082309109824045, 56.769697257450645, 58.09008775438581, 53.74016802651541, 49.71890851429531, 46.838980947222026, 51.31685522624424, 61.155125754220144, 57.36424766268049, 55.107615198407856, 33.1218855040414, 10.061238220759801, 4.438577004841395, 19.649620260511124, 33.74129656382969, 23.63117950303214, 26.03507556234087, 16.786602871758596, 12.013173069272723, 17.342241627829416, 22.680883066994802, 31.833675588880265, 30.39303261893136, 25.79758266040257, 15.400940997259957, 8.899786898068019, 5.362013876438141, 0.44253063255122727, 0.249981800360339, 0.3681863732635975, 0.5109690587435449, 0.23109589091369084, 0.38684988607253346, 0.5159467373575483, 0.3053402155637741, 0.6985012644103595, 1.618552137698446, 2.3444883099624088, 1.7718617511647088, 1.1779214846236365, 3.192976917539324, 3.4113713928631375, 1.6672843056065696, 2.1489968342440466, 1.8806128927639552, 1.774633756705693, 3.7186207345553806, 2.948730366570609, 4.071527123451233, 3.3432914231504713, 1.767078242131642, 0.9097282386251858, 0.8902787108506475, 0.7153569427984101, 0.7981218216674668, 0.23109024550233567, 2.046835081917899, 0.5211507752537727, 8.21627870627812, 21.46856485094343, 25.124875443322317, 31.299598830086843, 36.416123730795725, 35.39202526637486, 18.492960589272634, 13.955338750566755, 9.15625011920929, 5.364402319703784, 12.258415818214417, 23.226745707648142, 28.315873861312866, 19.582577092306956, 21.772708347865514, 47.422445501599995, 52.188329560416086, 45.53246252877371, 51.52052777154105, 51.95341444015503, 49.899790968213765, 48.58425726209368, 49.41836071014404, 58.66711480276925, 53.342960357666016, 53.83664723805019, 53.82904590879168, 52.01929725919451, 49.43956661224365, 48.80491120474679, 16.725015776497976, 4.3741541760308404, 8.958807502474103, 32.473611627306255, 54.867488929203574, 54.17369392939976, 52.39676856994629, 52.98390872137887, 55.406311307634624, 54.1558335849217, 52.15419653483799, 41.04987737110683, 5.907322398253849, 1.9792488685676028, 32.204136167253765, 62.3514735358102, 49.63869850976126, 59.20176478794643, 43.89718314579555, 23.43657261984689, 25.867276566369192, 9.331873655319214, 29.604703903198242, 41.624159881046836, 34.91379117965698, 43.45418337413243, 39.6497562953404, 31.236644676753453, 54.06155695234026, 57.29697520392281, 66.22876984732491, 4.387078693934849, 0.22733772971800395, 0.23960857412644795, 0.11933475440101964, 0.160210233181715, 0.17557385377585888, 0.319924782961607, 0.11315717481608902, 0.14657960459589958, 0.11650785537702696], [0.07848306505807809, 0.025067663718281046, 0.03610232758468815, 0.114851035709892, 0.04305103846958705, 0.08199168821530682, 0.05460967895175729, 0.0288163271200444, 0.03987588134727307, 0.07678427800003972, 0.11477896172021117, 0.052804660451199324, 0.0772042776058827, 0.03624565792935235, 0.18300081310527666, 23.172964913504465, 64.38701779501778, 41.59107950755528, 43.642114775521414, 45.26174334117344, 43.236544949667795, 26.573500156402588, 27.37266285078866, 2.4290446298463, 12.981166567121234, 26.295902252197266, 16.717775753566197, 21.194124902997697, 49.725766386304585, 59.88388334001814, 77.76927607400077, 23.906248262950353, 2.332383028098515, 10.612900870186941, 47.47753429412842, 57.28003549575806, 43.08521318435669, 47.79809638432094, 61.400522232055664, 44.305052825382774, 52.2809351512364, 37.41697352273123, 19.09588704790388, 9.360052074704852, 1.2988504299095698, 4.417595182146345, 12.335720607212611, 18.621761083602905, 28.482496874673025, 30.657679080963135, 40.66845600945609, 40.50183820724487, 46.280401366097585, 35.52041407993862, 23.632496186665126, 13.857786910874502, 2.8760433069297244, 0.4070134769592966, 0.07360127022755997, 7.50822513444083, 19.872614009039744, 15.459788765226092, 7.911834699766977, 5.015679614884513, 1.0538228579929896, 5.531027938638415, 6.816391263689313, 14.630958999906268, 11.477867347853524, 10.427331856318883, 9.939698593957083, 7.387320399284363, 1.5073774861437934, 1.1705418463264192, 0.11468677595257759, 0.1692685399736677, 0.10068735679877655, 0.1245856654963323, 0.576193590249334, 0.47843851574829643, 0.9217782063143594, 1.2481611498764582, 1.3923892506531306, 1.0908304836068834, 1.0813393528972353, 2.087895895753588, 2.5934676698275974, 2.1369953410966054, 1.868497839995793, 1.2494235507079532, 1.871696834053312, 0.9992563745805195, 2.742290049791336, 3.56744921207428, 3.867090276309422, 3.7547661321503774, 2.8286318395818983, 0.6318484981145177, 0.6119759987507547, 0.35667217682514873, 0.07913543576640741, 0.11068311400179352, 0.08374122290738992, 0.17533974562372479, 0.5068150673593793, 1.348580424274717, 2.8682587189333777, 8.53829036440168, 17.497328894478933, 20.165185281208583, 18.051828145980835, 22.541618585586548, 8.93798201424735, 6.166363401072366, 5.825298479625157, 1.329717259321894, 4.308861519609179, 15.924044813428607, 30.433679580688477, 14.952156850269862, 12.887576069150652, 35.70305095400129, 51.01793677466256, 43.39429685047695, 40.25903688158308, 46.28290966578892, 51.889577865600586, 47.22509581702096, 43.19260106767927, 45.87905951908657, 45.53133692060198, 48.322014876774375, 49.19238097327096, 41.39065524509975, 10.193115898541041, 3.108703519616808, 5.49551352432796, 22.667552947998047, 41.708392892565044, 45.3573887688773, 47.46010821206229, 45.454559326171875, 32.446128027779714, 41.82424715587071, 46.096968923296245, 45.663852964128765, 22.558535712105886, 0.48977754158633097, 13.17557976927076, 54.18483883993966, 46.65069171360561, 37.75324896403721, 46.246007783072336, 20.41533258983067, 19.57046811921256, 12.224725740296499, 8.090136766433716, 24.090467589242117, 22.34385895729065, 22.16888073512486, 29.699772630419048, 21.572575909750803, 32.80212245668684, 35.70946066720145, 52.2278265953064, 36.73824916567121, 0.1125592158309051, 0.23845099338463374, 0.06419275115643229, 0.07955879412059273, 0.03663206665909716, 0.022937090901125754, 0.012770777983990098, 0.0556292015660022, 0.12256753950246743, 0.014231223679546798, 0.023856113997421095, 0.031684677848326306, 0.02689049206674099, 0.056897899202470265, 0.01553629248935197, 0.060005328351897855, 0.01885367733692484, 0.05860964288668973, 0.021999372468729104, 0.062430127523839474, 0.1907389485942466, 0.08617375059319393, 0.013924467327472354, 0.021953737596049905, 0.21898306374038967, 30.810167721339635, 76.47110939025879, 41.46582085745675, 36.332439626966206, 57.750956603458945, 29.32359368460519, 38.786630221775596, 26.833178656441824, 10.157891137259346, 13.926373447690692, 10.686241711888995, 20.775758232389176, 28.681409903935023, 51.78475039345877, 67.05415330614362, 77.67815739767892, 30.588183198656353, 3.244084609406335, 10.353653158460345, 48.49115834917341, 62.13969939095633, 49.1563024520874, 52.29395260129656, 61.94372544969831, 48.22526468549456, 54.997465406145366, 45.80598531450544, 26.559251138142177, 13.390994770186287, 3.249414746250425, 5.02021678856441, 10.968548757689339, 15.784007344927106, 24.54282832145691, 29.44546161379133, 39.12823840550014, 37.49676316125052, 45.334497928619385, 35.56086996623448, 23.491584982190812, 14.500129631587438, 4.01480941261564, 0.561708821782044, 0.6252950983388084, 12.357081975255694, 22.053886311394827, 18.700117656162806, 12.356621657099042, 6.5751828125544955, 5.909152380057743, 7.105337747505732, 10.590275798525129, 21.102419103894913, 14.805198975971766, 16.502963508878434, 15.573735748018537, 9.875432968139648, 3.0335259650434767, 1.9759806096553802, 0.05235249150012221, 0.34933411915387425, 0.0741762268756117, 0.05172876514760511, 0.154466393536755, 0.13416880555450916, 0.37716249589409145, 0.32610463563885006, 0.6509655437299183, 1.3587979674339294, 0.9794644308941705, 2.3488917308194295, 1.0218964282955443, 1.9856040818350655, 2.464409875018256, 1.6592474111488886, 1.0901929863861628, 1.6540727402482713, 2.447102563721793, 1.9693470341818673, 1.7607034870556422, 2.814057775906154, 1.5527075337512153, 0.7140854224562645, 0.5696797083531107, 0.5413372463413647, 0.23372917675546237, 0.16855632247669355, 0.3747513624174254, 0.20021245096411022, 0.35347242280840874, 1.3719962877886636, 9.987571682248797, 16.029059886932373, 24.446043389184133, 22.47990815980094, 20.884822368621826, 21.664187908172607, 11.165450283459254, 5.940162190369197, 7.566609110151019, 5.761810617787497, 6.646551668643951, 17.063726561410085, 37.89768464224679, 22.82143817629133, 18.536925315856934, 37.54260390145438, 53.62140941619873, 49.09595387322562, 43.25512443270002, 45.509853090558735, 52.743890149252756, 48.48903914860317, 44.585051332201274, 47.01759828839983, 47.45583854402815, 50.59148761204311, 50.473402976989746, 38.72256088256836, 7.2645600608416965, 4.066785412175315, 9.095213668687002, 25.336818081992014, 45.94626596995762, 46.926326751708984, 49.55175570079258, 48.46098232269287, 37.83456025804792, 46.77639157431466, 49.471691608428955, 50.933040210178916, 24.19004569734846, 0.7902859364237104, 17.523930072784424, 57.68206174033028, 49.991458552224294, 36.57140902110508, 41.45072589601789, 24.561234099524363, 14.435613870620728, 4.191895978791373, 10.554737499782018, 18.918695824486868, 29.41832889829363, 23.663526841572352, 25.57765133040292, 28.36270645686558, 25.046635253088816, 40.6489246232169, 58.988330023629324, 39.6124027797154, 0.2515160766031061, 0.202448413840362, 0.07382007741502353, 0.10803791308509451, 0.036047566416008134, 0.10464030504226685, 0.046916978167636056, 0.047827697691640685, 0.044532660394907, 0.03663262305781245, 0.12804977675633772, 0.1378110729690109, 0.13592273715351308, 0.28010766953229904, 0.1137886398604938, 0.14098197567675794, 0.10725099566791739, 0.1339824798383883, 0.1264276709407568, 0.19548934511840343, 0.3757277471678597, 0.24400534534028598, 0.22365498090428965, 0.19701355190149375, 0.40896616503596306, 45.0526442527771, 84.65915148598808, 58.43441963195801, 53.83236714771816, 62.102575165884836, 54.68978180204119, 35.60260432107108, 45.03366524832589, 6.911750946726118, 22.993982791900635, 38.28989655630929, 25.435386964253016, 28.27539713042123, 58.32677813938686, 66.59131295340401, 85.96180670601981, 30.246505532945903, 4.942247578075953, 15.851173843656268, 56.849799564906526, 68.43981170654297, 53.25554854529244, 54.565978799547466, 70.76286547524589, 53.06029026848929, 60.82100772857666, 48.0406927381243, 27.280420303344727, 15.357389688491821, 4.521330918584551, 6.996823821749006, 19.043184961591447, 24.03373728479658, 35.3600183895656, 39.23249959945679, 47.9922707421439, 46.352370807102744, 52.155895369393484, 39.89858170918056, 27.753924403871807, 17.789959226335796, 5.699529571192605, 1.52033175102302, 0.8700468593410083, 16.279863800321305, 31.03676584788731, 21.704593420028687, 16.543584414890834, 7.880652921540396, 5.883464021342141, 11.415544612067086, 14.266151649611336, 27.911212512425013, 22.730717284338816, 24.82952662876674, 22.223147903169902, 15.148662328720093, 5.238315531185695, 3.997455418109894, 0.25576916124139515, 0.4853806889482907, 0.2561874645096915, 0.3745942679899079, 1.7116576731204987, 0.7642046245081084, 1.5143286160060336, 2.5703829314027513, 2.6220770946570804, 2.7413327183042253, 2.606709850685937, 4.896518009049552, 4.13095680304936, 3.303248086145946, 3.5841418249266486, 4.812255033424922, 5.023308736937387, 3.523460383926119, 4.44258394411632, 6.267217372144971, 5.575789971011026, 7.054802196366446, 4.492554954120091, 1.4171273346458162, 1.8095063311713082, 0.621232302061149, 0.629315011203289, 0.5011306266699518, 0.453772845012801, 0.19531924995992864, 0.5954988886203084, 3.657656805855887, 16.96381320272173, 24.326355457305908, 29.311531611851283, 30.506458486829484, 27.518482957567485, 30.74791533606393, 14.390095353126526, 10.527851445334298, 9.078342573983328, 4.367797877107348, 7.38570841721126, 19.742625372750418, 35.62555769511631, 21.60465747969491, 18.24746683665684, 41.88839987346104, 55.144221782684326, 48.68340458188738, 45.17233739580427, 50.0212003162929, 55.3444619178772, 51.22586161749703, 46.89648771286011, 52.00911120006016, 47.810061182294575, 50.36780078070504, 52.893474442618235, 47.0160870552063, 12.012637189456395, 4.760055388723101, 7.781658462115696, 24.598115137645177, 48.73808690479824, 51.55783959797451, 55.38562304633004, 53.02406236103603, 41.761577878679546, 50.52036237716675, 53.12677410670689, 54.87899514607021, 26.79291558265686, 1.6041011874164854, 17.634474175316946, 63.57990115029471, 54.80339527130127, 44.781793049403596, 50.36403138296944, 30.163960933685303, 29.02827787399292, 20.96740344592503, 11.840399163109915, 35.31710631506783, 39.94050019127982, 32.04028722218105, 45.859597614833284, 33.50337634767805, 44.32449041094099, 52.20908382960728, 63.46303939819336, 58.976274899074006, 0.8014498459441322, 0.3635027988680771, 0.146388122013637, 0.1664562023111752, 0.14592658249395235, 0.2139807678759098, 0.19574467784592084, 0.14331133211297648, 0.15365980538938726, 0.1357506335313831], [0.05733767471143177, 0.02117844857275486, 0.028836140342588936, 0.003884129525561418, 0.043109755497425795, 0.05608437981988702, 0.036157665508134026, 0.052019639539399316, 0.020035174741808857, 0.057841717664684565, 0.08803975582122803, 0.14542701787182263, 0.048544234064008505, 0.030792119314095805, 0.10981297426457916, 11.713609303746905, 67.10111618041992, 49.033215114048545, 36.29620477131435, 39.430182797568186, 51.53175606046404, 21.122779062816075, 28.232729979923793, 11.007582868848528, 7.233976261956351, 23.346963439668926, 26.687747648784093, 21.469650506973267, 47.499879700796946, 30.387317725590297, 47.94547809873308, 52.96033695765904, 6.009537781987872, 1.349883428641728, 27.396215506962367, 59.88910838535854, 59.061445917402, 55.15464060647147, 55.676380838666645, 46.25813238961356, 38.444848333086284, 48.21661070414952, 27.785399743488856, 15.977155106408254, 8.15715387889317, 2.3591674651418413, 0.2647056302853993, 0.6682523904102189, 4.639347808701651, 4.15250403540475, 7.962074518203735, 7.691148621695382, 3.9852730546678816, 2.175686384950365, 1.3084406810147422, 0.1647671250892537, 3.9677879129137312, 2.9129100143909454, 1.2311377376317978, 17.326307671410696, 11.553938831601824, 5.472148035253797, 2.140205191714423, 1.054888755083084, 3.7335293974195207, 2.1755702197551727, 8.635443551199776, 10.024314624922615, 4.1029190846851895, 5.321596639496939, 3.2918893013681685, 1.983423433133534, 1.212820331965174, 0.6548930129834584, 0.32627193523304804, 0.0855655118024775, 0.04421494994312525, 0.08848378913743155, 0.3540827514869826, 1.67336691064494, 1.715670040675572, 1.0717207661696841, 1.7759326355797904, 4.951392275946481, 2.77395190511431, 4.673117356640952, 3.3939739721161977, 5.72411446911948, 1.7463626222951072, 1.0398386312382562, 2.506732438291822, 1.4522937961987086, 5.270377125058856, 5.932029323918479, 5.909489367689405, 5.905178878988538, 2.7508986507143294, 1.3477285099881036, 0.43350744673183983, 0.19114450897489274, 0.03579489693843892, 0.17291737560714993, 0.15915372701627867, 0.23698166651385172, 0.06288729727800403, 0.45937374447073254, 1.3773690909147263, 5.391213246754237, 14.330929705074855, 18.310198647635325, 13.648957933698382, 19.473066534314835, 24.266140631267003, 3.3283721208572388, 9.479832938739232, 8.060373289244515, 21.173342841012136, 28.05232868875776, 9.334433197975159, 23.42703448023115, 20.016671010426112, 15.596796819141932, 28.13542914390564, 42.655130113874165, 47.30391270773751, 42.582240036555696, 45.70576449802944, 48.81942251750401, 52.79324320384434, 47.78076410293579, 45.63351018088204, 37.87775373458862, 17.471471173422678, 1.489017739892006, 0.305294075182506, 14.98739116532462, 25.3337139742715, 46.02541290010725, 47.4345840045384, 45.08358110700335, 45.171962193080354, 46.612070151737754, 51.786932127816335, 43.760307107652935, 46.44667870657784, 46.1945355279105, 17.570964166096278, 1.196467095187732, 23.430951527186803, 59.12485517774309, 33.824487345559255, 43.63971764700753, 49.253789152417866, 16.778294563293457, 19.367401804242814, 11.54994796003614, 10.60151537827083, 24.409902334213257, 20.628133331026348, 22.234098264149257, 29.943174975258962, 23.799937350409373, 35.94773871558053, 37.06481449944632, 63.209999901907786, 12.36056649684906, 0.2691670794572149, 0.055611288241509876, 0.22777742041008814, 0.02873674514038222, 0.10095527635088988, 0.07198057576481785, 0.045634865893849304, 0.005670565920549312, 0.06579475876476083, 0.030102809159351245, 0.07799217211348669, 0.06426812282630376, 0.06020206958055496, 0.03406953166372009, 0.05950135325214692, 0.06531542805688721, 0.012873537023551762, 0.05183273706851261, 0.11756859560097967, 0.06337591034493276, 0.11116736408855234, 0.07575102522969246, 0.019488830219155977, 0.019052225165069103, 0.48016612018857685, 15.111155952726092, 72.7310538973127, 59.63184438432966, 27.636737823486328, 46.53139809199742, 38.73543242045811, 23.61632772854396, 36.049026080540244, 14.691748789378575, 16.718844039099558, 12.907757111958094, 20.237014021192277, 26.68937005315508, 51.04731723240444, 36.34922994886126, 48.28885112489973, 53.28771175657, 8.898522325924464, 1.324806837098939, 29.22536700112479, 62.9708012172154, 62.47971643720354, 59.69273144858224, 61.47770282200405, 52.50859635216849, 43.95630884170532, 52.159001214163645, 33.118696280888145, 22.05749590056283, 13.679115721157618, 5.207660947527204, 1.6429164303200585, 2.7019025598253523, 8.742103610719953, 5.842307235513415, 12.942916733877999, 12.449462618146624, 8.605681811060224, 5.116893155234201, 3.4242820143699646, 2.6812525136130194, 9.127457652773176, 6.745481422969273, 4.638588718005589, 21.50179808480399, 18.05289990561349, 10.80024514879499, 4.957391611167362, 5.035680873053415, 4.9068595341273715, 5.054836188043867, 14.422262907028198, 14.637564999716622, 7.81638469014849, 9.210354004587446, 8.239714111600604, 3.3646790640694753, 3.2456258067062924, 2.199407969202314, 0.2773202476756913, 0.015413311409897037, 0.15392397264284746, 0.05985978937574795, 0.21691564896277019, 1.2006718409912926, 1.5685725510120392, 1.527198959674154, 2.0152759296553473, 2.0376119996820177, 1.9441943381513869, 3.38662560071264, 2.723647164446967, 3.7557471309389387, 3.037197219473975, 3.5681935378483365, 3.5851855746337344, 2.105823985167912, 3.3474256013120924, 5.477561116218567, 5.729427235467093, 5.102090886660984, 3.7313650335584367, 1.9277655397142683, 0.9867507027728217, 0.3274072328848498, 0.06422559225133487, 0.1905723139643669, 0.12871360113578184, 0.19787881975727423, 0.5763024272663253, 0.06913192290812731, 5.7049504688807895, 13.691064885684423, 23.546444484165736, 23.432570457458496, 16.58219381741115, 19.508606570107595, 22.358026334217616, 4.43663889169693, 9.40686295713697, 11.403320125171117, 23.968087230409893, 23.44182893208095, 14.067243831498281, 33.96844359806606, 29.723618847983225, 23.020307779312134, 29.368242808750697, 41.923759256090435, 51.66880232947213, 45.610473428453716, 46.3479448046003, 50.581457887377056, 56.276778153010774, 49.204196384974885, 43.9569411277771, 33.773223536355154, 12.103077547890798, 1.2537962474993296, 0.7247953649078096, 19.88815712928772, 28.766652141298565, 49.40992212295532, 48.01618296759469, 47.65456049782889, 46.545683588300435, 50.846285002572195, 51.54663215364729, 47.06686796460833, 49.32176685333252, 47.95242977142334, 19.248299258095876, 1.9894073520387923, 29.734454563685826, 65.36229474203927, 40.836501666477744, 45.39915439060756, 51.47505875996181, 19.12504342624119, 10.565424697739736, 9.71161789553506, 10.602431671960012, 24.10885947091239, 29.80811936514718, 18.341048649379186, 32.526914732796804, 25.2665023122515, 33.58905805860247, 44.422602449144634, 67.93177332196916, 13.19046802180154, 0.3032338528760842, 0.24894741443651064, 0.21600844764283725, 0.16885326297155448, 0.07888830652726547, 0.05418314505368471, 0.06327457113989762, 0.0020439429790712893, 0.033078056294471025, 0.0978990528466446, 0.2070410374019827, 0.1841192152351141, 0.12258906263325896, 0.13147043463374886, 0.12431871624929564, 0.20200869600687707, 0.1803392730653286, 0.12814995566649096, 0.14059360937348434, 0.1925275261913027, 0.17906540499201842, 0.2569110813949789, 0.1486686510699136, 0.29018890857696533, 0.5747765919991902, 21.34771309580122, 88.2041710444859, 65.78912258148193, 49.171182019369944, 47.95448643820626, 70.9523011616298, 26.107604333332606, 45.581412587847026, 19.67157483100891, 15.730101483208792, 33.17150953837803, 36.494259698050364, 27.11328486033848, 57.483558654785156, 40.478686809539795, 56.64723873138428, 60.28212629045759, 10.25655208315168, 3.381709315947124, 35.387793813432964, 65.90538678850446, 68.12336989811489, 65.92083958217076, 65.24814973558698, 57.45022814614432, 51.77213246481759, 57.019502367292134, 35.24193722861153, 21.062220300946915, 12.51989129611424, 3.735264275755201, 0.8048779677067484, 1.941340799842562, 8.710338183811732, 7.288906982966831, 14.052908829280309, 10.02650591305324, 6.929471892969949, 3.153392595904214, 3.000236059938158, 1.6064250341483524, 8.384207980973379, 8.008993097714015, 4.565967883382525, 27.087682485580444, 21.65589349610465, 12.781717658042908, 5.032681422574179, 5.461308411189488, 9.5115419115339, 8.22195451600211, 19.56361198425293, 22.09231506075178, 12.96601949419294, 17.285113539014542, 13.288920521736145, 7.579268727983747, 5.755278008324759, 2.554673271519797, 1.6152269904102599, 0.16902547515928745, 0.23708249681762286, 0.24870683306029864, 0.672703200152942, 2.310980187995093, 3.0533969444887976, 3.191520401409694, 3.5547878571919034, 10.648410507610865, 6.112045424325125, 7.1692125371524265, 7.145982103688376, 9.302949173109871, 5.3222315311431885, 4.473317997796195, 7.158544012478419, 7.74405654839107, 9.97384204183306, 10.865977713039943, 8.88859248161316, 10.168724247387477, 5.67847956929888, 3.5232376073087965, 1.1903073000056403, 0.4872915521264076, 0.23352572481547082, 0.3492894172668457, 0.6331207784158843, 0.6009008958935738, 0.584804253918784, 1.9620310153279985, 9.391966019357953, 19.4957662991115, 26.577052422932216, 30.803396701812744, 22.50172550337655, 27.33953731400626, 27.192410945892334, 7.69077341897147, 13.318019577435084, 10.97254831450326, 26.806636537824357, 34.92251811708723, 14.396808181490217, 29.12234606061663, 25.65027216502598, 19.605341127940587, 32.91010441098894, 46.95253883089338, 53.35775654656546, 47.16467775617327, 48.7041449546814, 49.56748294830322, 54.93331963675362, 46.126391070229666, 47.09432029724121, 42.8137331690107, 22.01838970184326, 2.5964206542287553, 1.2310801978622163, 20.01531090055193, 28.533477544784546, 51.29931102480207, 52.91505207334246, 51.285755089351106, 53.690349442618235, 56.176244667598176, 59.62167222159249, 48.90668841770717, 52.63631813866751, 53.77396753856114, 22.917679412024363, 2.481317447764533, 30.77259533745902, 68.44221578325543, 45.31458439145769, 48.07917186192104, 54.049727644239155, 26.39104219845363, 27.7811769757952, 20.440974916730607, 15.878421204430715, 41.05787822178432, 34.80810560498919, 35.294687952314106, 47.16805110658918, 33.84771864754813, 53.132989270346506, 49.248400824410574, 81.65448638371059, 23.64983367919922, 0.43597644567489624, 0.38314334782106535, 0.22548474557697773, 0.2985357035483633, 0.1963057584528412, 0.2141660215067012, 0.20731236998523983, 0.1470190103032759, 0.15379521383770875, 0.22961996868252754], [0.07639800158462354, 0.035424905363470316, 0.07101474901927368, 0.06935356637196881, 0.0038475832053726272, 0.03403105194281254, 0.11744552291929722, 0.06253447942435741, 0.02067042431528015, 0.028355019998603632, 0.03890144738501736, 0.22915422224572726, 0.05652420961165002, 0.10842529551259109, 0.043024986117546044, 0.8957981318235397, 48.87549795423235, 62.17288398742676, 42.384605475834434, 38.19643633706229, 57.12479884283883, 36.56009040560041, 22.90197648320879, 24.525435243334087, 2.978259776319776, 17.3035557951246, 29.942598274775914, 17.485591650009155, 15.20916029385158, 26.27879752431597, 36.046945095062256, 73.1932133265904, 20.453834295272827, 1.670968913606235, 9.88945095879691, 43.17318432671683, 50.795802865709575, 47.303190095084055, 55.64536755425589, 48.571295397622244, 37.997519833701, 56.894681453704834, 56.88555499485561, 41.94298492159162, 10.916678718158177, 2.044288784265518, 0.3958836298968111, 0.9212408065795898, 19.77358133452279, 17.959682873317174, 12.34016137463706, 3.0617541074752808, 1.7465128770896365, 1.1136821316821235, 2.6784821365560805, 1.001103292618479, 5.337752504008157, 6.283289424010685, 8.392788137708392, 9.017624872071401, 2.398187679903848, 2.566060934747968, 2.3015391060284207, 4.284700896058764, 4.218009914670672, 1.9243554941245486, 9.185437764440264, 7.315580248832703, 1.31083368403571, 1.3476978944880622, 2.3061081979955946, 1.5990257454769952, 1.8209653220006397, 0.10330445279500314, 0.4687719430242266, 0.1661910851086889, 0.27758531059537617, 1.04744082902159, 2.5294595616204396, 4.942596725055149, 5.297658792563847, 4.912944419043405, 1.5450435621397836, 5.006330379417964, 7.699689694813319, 6.772279322147369, 2.2350537478923798, 4.451483283724103, 2.6403076478413174, 2.596958271094731, 3.8987488746643066, 5.4072900755064826, 9.27335592678615, 7.8348946911948065, 8.302769013813563, 4.886169101510729, 4.301951101848057, 2.989087675298963, 0.3911858062658991, 0.6256927741425378, 0.24237241010580743, 0.22667284682393074, 0.21834498297955307, 0.4778643665569169, 0.6836062265293938, 0.5736368702990668, 2.4587570812020982, 2.350993343761989, 6.170171448162623, 15.054958922522408, 13.065215451376778, 14.009599838938032, 24.61475954736982, 12.083013755934578, 7.507104737418039, 13.009493504251752, 20.496925285884313, 24.550379276275635, 5.487993836402893, 7.095304983002799, 19.64684966632298, 32.07432297297886, 17.056436164038523, 15.514318227767944, 20.75015585763114, 37.14802959987095, 43.627787590026855, 38.33859300613403, 35.15328516278948, 26.641375371388026, 13.733113646507263, 4.839542346341269, 3.0684810493673598, 2.802280362163271, 4.725788176059723, 25.874089275087627, 31.902928284236364, 46.971201692308696, 45.762579917907715, 49.78587177821568, 45.351965699877056, 49.42389495032174, 47.479306084769114, 53.076020990099224, 47.548798492976594, 43.89777374267578, 12.16708435331072, 3.7859483446393694, 43.530432905469624, 35.029051371983115, 18.003796986171178, 18.142024448939733, 12.56035760470799, 16.558349336896622, 13.362053786005292, 9.927612202508108, 13.195693935666766, 25.38777095930917, 16.83778851372855, 29.820084163120814, 24.85373936380659, 25.21223861830575, 25.127229145595006, 45.99521950313023, 44.789630617414204, 0.5158675387501717, 0.05460076639428735, 0.0955797251580017, 0.11592586232083184, 0.0017239501051205608, 0.03709607943892479, 0.05372903549245425, 0.08768691082618066, 0.011244282841549387, 0.03127303100856287, 0.03703489593629326, 0.050072121899574995, 0.03403872956654855, 0.032638050083603175, 0.08760833647102118, 0.034985143425209184, 0.05069529524605189, 0.09327458563659873, 0.028125797298603823, 0.03738527784922293, 0.032625164703599045, 0.046854882035404444, 0.0940781475177833, 0.04306574232344117, 0.055840809496917894, 0.08337491577757256, 1.1451085082122257, 52.9974889755249, 71.27115399496896, 38.81685488564627, 34.3165031841823, 56.82062407902309, 25.254497562135967, 36.168858187539236, 24.190613712583268, 14.398355024201528, 19.787918942315237, 14.69821582521711, 19.645739691598074, 26.77381672177996, 30.183829307556152, 42.96708338601248, 74.48209026881626, 29.2739349092756, 2.510374814271927, 10.570132970809937, 47.00031464440482, 56.96231869288853, 52.05406951904297, 60.1928071975708, 54.79859406607491, 44.58428703035627, 58.53542559487479, 58.52651105608259, 42.92870501109532, 13.384803925241743, 3.380378301654543, 3.0289051958492825, 5.405742364270346, 29.41971853801182, 27.638877868652344, 17.27103648866926, 7.3266278845923285, 4.821047978741782, 2.995526049818311, 3.6752366168158392, 2.8175637934889113, 7.313928314617701, 12.151113050324575, 16.5661677973611, 16.558073146002634, 9.486769846507482, 11.784606865474156, 5.093131184577942, 5.107971668243408, 3.6157711105687276, 3.2345701370920454, 10.770798683166504, 12.048008731433324, 3.7273259588650296, 4.224414416721888, 0.9644472024270466, 1.925169084753309, 2.4169213260923113, 0.6673645951918193, 0.5509974136948586, 0.06691801241998162, 0.31430328318050926, 0.6314138557229723, 1.1107846243040902, 1.9780911249773843, 3.191739703927721, 3.0321345882756368, 2.839205260787691, 5.539636322430201, 6.391140231064387, 6.909373360020774, 4.3007173623357495, 6.003214487007686, 3.717794333185468, 3.3342353148119788, 4.141072945935385, 2.863383037703378, 10.518811838967459, 9.988515768732343, 7.662274513925825, 6.174479765551431, 5.877157228333609, 3.0036760696343014, 1.3944788128137589, 0.5127192991120475, 0.21161029221756117, 0.1386963576078415, 0.37595538209591595, 0.8007879757455417, 0.5337055729968208, 0.6827544750911849, 5.065388764653887, 7.11799475976399, 14.537958230291094, 20.726109879357473, 15.564520699637276, 16.781207595552715, 23.41225392477853, 11.706052269254412, 7.186515288693564, 13.870242425373622, 26.07785040991647, 36.82171092714582, 7.785819564546857, 10.183428372655596, 30.59128209522792, 40.05674702780587, 28.742562736783707, 20.04968885013035, 19.846374137060984, 36.18208408355713, 43.68194532394409, 36.872974736349924, 34.59057487760271, 20.024718761444092, 12.805609038897924, 3.7182629023279463, 5.704481031213488, 8.0350410257067, 6.043312541076115, 28.119060925074987, 35.28057268687657, 47.64496156147548, 47.942785671779085, 51.86233050482613, 48.42666516985212, 51.44796773365566, 50.554450239454, 55.69846568788801, 51.461933612823486, 47.64712592533657, 11.821155258587428, 4.937331293310438, 47.33303608213152, 39.055334431784495, 19.816764388765606, 23.396672589438303, 21.023301703589304, 16.62138339451381, 8.983195679528372, 13.889580999101911, 14.304703729493276, 29.662141186850413, 18.61502480506897, 24.19027325085231, 27.57368118422372, 20.269639287676128, 28.7617449760437, 53.24929864065987, 50.52940893173218, 1.1700465700456073, 0.20711338280567101, 0.07457373983093671, 0.0850231112646205, 0.03687430366075464, 0.033037269554500065, 0.014832000281395656, 0.07772200661046164, 0.02317413710989058, 0.0997393958802734, 0.07170946709811687, 0.12309062214834349, 0.12688693058277878, 0.1790210966553007, 0.14578140314136231, 0.1707506233028003, 0.1498985229326146, 0.1331818899405854, 0.19936221944434301, 0.18523122556507587, 0.11448261833616666, 0.20201871118375234, 0.2625300298844065, 0.15141434302287443, 0.1253015742238079, 0.19754207639821939, 1.6005001749311174, 73.15004416874477, 75.68954821995327, 57.664791992732454, 47.29669352940151, 78.27961431230817, 46.054341724940706, 36.31109823499407, 40.2755423273359, 9.912250603948321, 25.55400661059788, 40.59610441752842, 25.16609215736389, 21.817131655556814, 36.23165600640433, 44.9637941632952, 81.24810014452252, 25.79176528113229, 3.40717185820852, 13.553048474448067, 51.869879722595215, 59.47127846309117, 57.06170572553362, 64.24139050074986, 60.579182624816895, 49.47262266704014, 64.94981493268693, 62.08083425249372, 45.55501290730068, 15.005546808242798, 4.407540270260402, 2.0579185443265096, 3.3260284066200256, 28.60671329498291, 25.999264546803065, 18.041150501796178, 5.258043638297489, 3.4917544509683336, 2.612322909491403, 5.35441254717963, 3.71977413552148, 9.700660586357117, 12.78395584651402, 16.660150868552073, 22.918084144592285, 9.428123576300484, 9.17258620262146, 5.18571549654007, 12.934159398078918, 10.869315453938075, 7.185483046940394, 18.139033249446324, 18.77997851371765, 7.5361021757125854, 8.953685811587743, 2.7281326608998433, 3.781381641115461, 5.3877942987850735, 1.0033984780311584, 1.821471780538559, 0.12740550775613102, 0.6491248682141304, 2.3355646516595567, 3.996672442981175, 7.444927045277186, 8.798230290412903, 9.051542503493172, 4.539356282779148, 7.259795333657946, 10.822397742952619, 9.959797126906258, 7.189006217888423, 9.48545663697379, 5.737002943243299, 6.7184798547199795, 7.778387597629002, 8.198830911091395, 17.82457515171596, 12.19475815977369, 14.317243490900312, 7.872038892337254, 9.108492544719152, 7.936026590211051, 4.108426400593348, 1.3880806075675147, 0.34110042239938465, 1.0964621071304594, 1.7101758612053735, 0.9508339443377086, 3.356825645480837, 2.637356834752219, 8.733816146850586, 9.605610966682434, 14.908353669302803, 23.216375521251134, 21.762553555624827, 19.96592136791774, 31.854443754468644, 16.819606815065654, 12.275127972875323, 17.004762411117554, 26.687751122883387, 36.7670807157244, 10.644757492201668, 7.8961248227528165, 24.664803947721207, 38.99163334710257, 23.583705936159404, 19.436843838010514, 25.419517278671265, 44.450961521693635, 50.098683152879985, 41.93082904815674, 41.848822934286936, 31.74485329219273, 18.29164695739746, 8.033919760159083, 4.414309987000056, 4.818382476057325, 7.9428896733692715, 28.8765743800572, 36.39658192225865, 52.46974549974714, 51.34961945669991, 55.775781767708914, 52.250557626996724, 56.15348584311349, 55.85728413718087, 59.94859191349575, 56.206344263894216, 50.684558732169016, 16.539286954062327, 5.583067774772644, 49.36773613521031, 43.13787358147757, 27.957586526870728, 23.15705180168152, 17.904976231711252, 24.785627910069056, 21.14421946661813, 17.31714994566781, 20.19372500692095, 41.976162569863455, 28.95407111304147, 44.363417693546836, 37.94006517955235, 35.2510358946664, 42.005549975803916, 57.94562775748116, 70.13515826633999, 3.9052840897015164, 0.4098771661520004, 0.34097888320684433, 0.2660425342619419, 0.3681891959692751, 0.1669478416442871, 0.12722638808190823, 0.1767147154148136, 0.10809482860245875, 0.18764212833983557, 0.15285164304077625], [0.04718055848830512, 0.07231845906270401, 0.13698205245392664, 0.03522117183144603, 0.02281320228108338, 0.06345396901347808, 0.021210107320387448, 0.02654733315908483, 0.02716948022134602, 0.04006863957537072, 0.030674865070198263, 0.3021588905581406, 0.13658903140042508, 0.13004975872380392, 0.05858425210629191, 0.20332916586526803, 13.934614011219569, 65.64182771955217, 45.482195786067415, 42.56807613372803, 51.12559911182949, 59.45793097359793, 19.60406265939985, 29.693943091801234, 6.742873242923191, 11.2907532283238, 25.90423229762486, 32.11452872412545, 11.084472502980914, 36.29067400523594, 44.284802300589426, 49.395706108638215, 49.68305580956595, 8.139220578329903, 4.021927842072078, 25.731411491121563, 45.61229733058384, 59.85295690808977, 58.024910177503315, 58.79161262512207, 45.75642033985683, 53.17113488061087, 50.9262170791626, 49.164390155247276, 41.476941449301584, 14.180230225835528, 6.279763647488185, 3.7678382992744446, 0.2722595977996077, 1.056912852185113, 1.2755446519170488, 3.5965732378619055, 5.326573286737714, 5.0585426177297315, 4.764561295509338, 6.584349223545619, 5.826041068349566, 10.398114681243896, 8.079745735440936, 0.21478902521942342, 0.34699670172163416, 2.9040384675775255, 3.8469087992395674, 6.12491956778935, 4.5949410029820035, 5.750182807445526, 6.745494885104043, 5.441701463290623, 1.6693282702139445, 3.3496286145278384, 2.249299292053495, 0.5852239685399192, 2.5196619502135684, 1.9255392934594835, 0.1855349378394229, 0.25125036228980335, 0.7920747718640736, 1.54952905859266, 5.465135131563459, 12.927549055644445, 16.488490411213466, 13.751575878688268, 5.8240221823964795, 2.1831741545881544, 7.0103306855474194, 7.14443439245224, 4.08819454908371, 2.0475116627556935, 2.7813688899789537, 3.796323307922908, 5.6848719120025635, 8.506758570671082, 8.390570793833051, 9.516936319214956, 2.951253648315157, 5.452417756829943, 8.70235904625484, 3.145144215651921, 4.4058253679956705, 3.362750287566866, 2.7847441945757185, 1.2690814158746173, 2.420076025383813, 0.6556068318230766, 0.5809421954410416, 1.620369200195585, 3.970220650945391, 8.222868204116821, 3.0415645965508054, 5.416096482958112, 11.350118637084961, 10.515972631318228, 21.230043615613663, 17.4306800365448, 9.89816313130515, 11.126339742115565, 13.183755193437849, 9.87587331022535, 4.00561477456774, 13.78444606917245, 9.44727281161717, 15.132886443819318, 25.265722376959665, 23.99821809359959, 10.606406041554042, 5.984896429947444, 5.727096114839826, 6.636924505233765, 12.728956512042455, 1.7163393476179667, 5.889011723654611, 4.198137632438114, 2.3785212380545477, 8.281740290778023, 6.413526024137225, 38.43631247111729, 44.35902295793806, 50.48860910960606, 42.563521589551655, 49.46675491333008, 43.89676625388009, 50.40515777042934, 42.97879804883684, 48.99906471797398, 43.15062699999128, 40.91396018436977, 7.548874701772418, 5.932897848742349, 31.322110993521555, 42.23640387398856, 32.138451371874126, 14.497142774718148, 15.548209803444998, 16.02518974031721, 7.827612979071481, 2.0227304782186235, 19.85977373804365, 20.817773989268712, 15.039975132261004, 26.378634452819824, 25.145353521619523, 28.543324879237584, 29.26817832674299, 52.57401016780308, 16.598973717008317, 0.1842792680753129, 0.0986694682921682, 0.004236048744392714, 0.01762730671492006, 0.03273118919293795, 0.03867484722286463, 0.042136603966355324, 0.0784303971699306, 0.04605554403471095, 0.06763182447424956, 0.013303548413594919, 0.02130509713398559, 0.04199780962829079, 0.05218505959159561, 0.1142833868839911, 0.06867298896291427, 0.0675337625933545, 0.12484820426574775, 0.04669172150482025, 0.0737661745931421, 0.06160373293927737, 0.06108295052711453, 0.2634308801165649, 0.08924967875438077, 0.14317741644169601, 0.12665496660130365, 0.34583988093904083, 19.900135823658534, 73.59746646881104, 53.65249218259539, 37.32560123716082, 60.7026173727853, 36.461443356105256, 22.446786097117833, 32.664082595280235, 15.40117723601205, 23.684892552239553, 20.17922932761056, 20.184084381375992, 17.31856390408107, 45.82916797910418, 55.43732806614467, 53.17431368146624, 54.97521727425711, 14.834765298025948, 4.398741679532187, 23.445111955915177, 50.71987295150757, 62.93405219486782, 60.81239891052246, 61.98072460719517, 50.252762930733816, 56.20914091382708, 53.81545870644705, 49.56964036396572, 43.8554870060512, 14.65486775125776, 7.483870829854693, 4.695592607770648, 1.8003477369035994, 3.787231590066637, 3.9135441950389316, 7.462041326931544, 6.208559376852853, 7.134462424686976, 4.305575890200479, 0.7062082822833742, 8.026308008602687, 20.88980770111084, 11.804985931941442, 3.3712941833904813, 2.206722902400153, 5.646420581000192, 7.160955037389483, 11.146376609802246, 6.471256869179862, 11.19153642654419, 10.382706182343618, 7.534089803695679, 1.8328312167099543, 2.9479643276759555, 0.9078326289142881, 3.2305736201150075, 1.8215866429465157, 3.0519825518131256, 0.35492633336356705, 0.09593489074281283, 1.4593539259263446, 0.491941688316209, 2.175238226141248, 10.137838636125837, 10.700426459312439, 8.181932023593358, 5.363978913852146, 5.090937290872846, 10.543380669185094, 12.727841326168605, 4.311643838882446, 4.525474216256823, 3.3471971792834143, 6.963568440505436, 9.13149629320417, 7.849856768335615, 14.293609193393163, 8.575470175061907, 8.061780299459185, 6.417256772518158, 7.552448681422642, 6.258175594466073, 2.639522067138127, 1.2687798206295287, 0.9582510377679552, 1.393903632249151, 0.3367750873523099, 0.30056360044649666, 0.7865675645215171, 4.318539491721562, 7.59780478477478, 13.039345570972987, 7.081047713756561, 16.50200465747288, 13.766415493828909, 13.253896389688764, 22.07629598890032, 14.27104926109314, 8.716456941195897, 9.970094357218061, 13.17476943561009, 15.969807386398315, 10.35296094417572, 9.573351349149432, 12.033719761031014, 21.882990155901226, 34.111069270542686, 37.1896527835301, 18.46414988381522, 7.374829275267465, 4.882463106087275, 5.689435141427176, 18.46100582395281, 4.431693511349814, 10.254847168922424, 7.339048658098493, 6.10985153062003, 12.774495874132429, 9.596923981394086, 40.01246963228498, 49.01278393609183, 52.13678434916905, 48.3949362209865, 51.657532351357595, 47.56202091489519, 51.83765050343105, 48.13500411169869, 51.43152134759085, 47.42092384610857, 41.791882446834016, 10.850514497075762, 10.17093116896493, 39.253351143428254, 42.399238382067, 35.6950501033238, 16.836082730974468, 20.88777014187404, 12.863475373813085, 8.301085812704903, 5.820145521845136, 22.784074238368444, 24.051781756537302, 11.829361081123352, 24.35009571484157, 27.93373509815761, 22.518840653555735, 34.02746507099697, 60.322502272469656, 18.903963906424387, 0.2101119783307825, 0.16043379689965928, 0.10930060568664755, 0.11953839633081641, 0.056161871911691766, 0.08846210315823555, 0.05979521319802318, 0.09363790721233402, 0.00497808531093012, 0.12461062201431819, 0.060164661944976876, 0.20637729444674083, 0.1916975285857916, 0.20160036720335484, 0.19080260874969618, 0.21286456419953279, 0.14077514463237353, 0.17174489423632622, 0.13110223439122948, 0.14808409315134796, 0.13634386312748703, 0.13814042029636248, 0.4190443642437458, 0.3822682004954134, 0.31112969347408836, 0.27488759106823374, 0.38989306134837015, 28.150232281003678, 86.18883909497941, 59.4348212650844, 58.03196954727173, 64.0724242074149, 80.88699531555176, 25.905750479016984, 47.733339173453196, 11.85604737486158, 21.29621478489467, 35.23247378213065, 43.94228390284947, 13.567386082240514, 47.11603341783796, 50.97618504932949, 64.40985652378627, 55.90956933157784, 13.816076006208148, 6.312394993645804, 32.60335881369454, 53.46788896833147, 72.25921562739781, 67.29695810590471, 69.14847237723214, 53.40554625647408, 63.724062374659944, 58.742301259722026, 55.038084575108115, 47.412891728537424, 18.64138627052307, 12.704830629484993, 8.560688751084463, 1.0990440143006188, 3.200171560049057, 3.331949357475553, 8.928205030305044, 9.954286336898804, 9.685536095074244, 11.184312905584063, 11.24617792878832, 12.252797331128802, 21.740143878119333, 15.917334590639387, 4.628461718559265, 3.566786527633667, 6.391323489802224, 11.908019031797137, 16.835434811455862, 11.681710992540632, 16.9972722530365, 15.771158388682775, 12.578398602349417, 4.821288125855582, 5.431311300822666, 1.3994700078453337, 5.402673866067614, 5.903299391269684, 5.472820707729884, 0.547460346349648, 2.3690703851836066, 5.512839291776929, 10.373741269111633, 14.396718723433358, 18.729202815464564, 21.10061083521162, 18.598958832877024, 12.313718267849513, 7.187869318893977, 12.525404691696167, 15.752544164657593, 5.548001953533717, 3.3035766056605746, 6.169837500367846, 10.474922674042837, 11.387774399348668, 12.42962030002049, 22.68932339123317, 14.611816712788173, 8.032723801476614, 8.604059406689235, 14.106661830629621, 16.191698108400615, 9.846088988440377, 7.528559906142099, 6.1443723525319776, 5.686490842274257, 3.82628915139607, 1.670687185866492, 1.0857852229050227, 7.065824210643768, 14.511074781417847, 17.273805345807755, 8.121966464178902, 12.441792675427028, 17.77689835003444, 15.508952481406075, 28.691291979381017, 22.4398934841156, 15.10779823575701, 16.934081860951014, 19.870890855789185, 13.42298253944942, 9.75907496043614, 17.696776935032435, 9.695936679840088, 19.40346642902919, 30.893160479409353, 30.798744882856095, 14.305592230388097, 8.302124568394252, 9.171714203698293, 11.204691972051348, 19.66434175627572, 3.1294197908469608, 8.323501569884163, 5.877317036901202, 4.334648021629878, 14.577252898897443, 9.284100447382245, 41.18206684929984, 50.866153376443044, 55.85105160304478, 52.23699821744646, 56.097997529166086, 51.261221000126426, 56.57144430705479, 49.179082121167866, 55.75967584337507, 52.24456827981131, 48.79624332700457, 12.185682075364248, 10.193287866456167, 38.88206025532314, 50.62508910042899, 41.2467372076852, 20.222483600888932, 24.751494884490967, 23.210410492760793, 14.913509232657296, 5.965624298368182, 30.86640296663557, 38.206844738551546, 26.689983231680735, 42.523809160505024, 39.048233372824534, 41.58150141579764, 40.37103142057146, 69.91320501055036, 34.30944381441389, 0.25928231701254845, 0.2743979873401778, 0.19241037033498287, 0.2664468597088541, 0.19236686266958714, 0.15166888864977018, 0.24444424893174851, 0.16843604535928794, 0.117044508723276, 0.4503750944776194, 0.22732862377805368], [0.052338262620781145, 0.01129180658608675, 0.11364537397665636, 0.04340001581502812, 0.018638958322948644, 0.04536198964342475, 0.10973676121128456, 0.03988633417923536, 0.08355771311159645, 0.05226399017763989, 0.11583674353148256, 0.03989015093871525, 0.11672567868871347, 0.03999923222831317, 0.050720862445554564, 0.05996672649468694, 1.0939505504710334, 50.964501653398784, 54.142357553754536, 32.140226636614116, 36.14755848475865, 76.32085459572929, 43.49013682774135, 27.33548477717808, 20.223560571670532, 4.693366578647068, 25.460113865988596, 38.232646874019075, 19.94530258859907, 14.199189254215785, 30.24495608466012, 52.98861265182495, 70.97631413596017, 38.79231037412371, 4.7675507579530985, 15.358383280890328, 58.046314103262766, 52.97244071960449, 56.110917704445974, 55.96792030334473, 53.88469403130667, 55.609372411455425, 52.657614367348806, 47.13430370603289, 30.05273069654192, 22.94906095096043, 12.076340011187963, 8.986589874540057, 7.583595718656268, 5.579818623406546, 5.403571052210672, 6.331519041742597, 6.5954537476812085, 3.1158940366336276, 1.1383590932403291, 8.31872034072876, 14.123014416013445, 5.421965105193002, 2.735442600079945, 2.955888096775327, 12.755970239639282, 18.854381561279297, 9.431588990347725, 3.07070859840938, 2.259953268936702, 2.166796381984438, 5.3074991788182935, 4.915428400039673, 1.933592255626406, 2.3780637426035742, 2.284608517374311, 2.7366535408156256, 1.0042754709720612, 4.265430501529148, 1.3303027536187852, 0.3049464209803513, 0.7209830837590354, 0.11632858642510005, 2.113778804029737, 7.611902679715838, 16.341115644999913, 19.952481814793178, 21.811719008854457, 15.341229915618896, 12.756617290633065, 14.369276813098363, 8.189285823277064, 2.4207469608102525, 1.7519839320863997, 4.269304990768433, 11.388548254966736, 11.20509844166892, 8.486801607268196, 5.244565001555851, 3.176622595105852, 9.712542005947657, 13.191363470894949, 13.786573086466108, 11.602769034249441, 6.939005255699158, 4.172691592148372, 4.480838119983673, 4.003394825117929, 0.8464049622416496, 1.2772521717207772, 1.2397843365158354, 5.821423990385873, 12.710412638528005, 9.114064131464277, 5.298503867217472, 9.792261293956212, 8.664311579295568, 16.638059071132115, 16.27684654508318, 13.023571423121862, 13.26649694783347, 8.373449563980103, 8.176082508904592, 11.909719603402273, 21.8842408316476, 20.76593174253191, 11.853529521397181, 11.621710692133222, 17.185255765914917, 29.11466482707432, 21.550513642174856, 5.054165252617427, 0.5187535381742886, 2.4895317384174893, 1.6482319108077457, 1.3078491070440836, 0.47235471648829325, 1.817590125969478, 3.1068526932171414, 11.710717116083417, 39.215938568115234, 43.25680589675903, 44.81685018539429, 48.63100126811436, 47.555694580078125, 46.408797127859934, 47.91090038844517, 46.867114203316824, 50.834108284541536, 48.61772673470633, 30.492079189845494, 7.8064826386315485, 20.506923743656703, 54.871074199676514, 49.36745473316738, 50.64089625222342, 56.98547009059361, 17.257635150636943, 15.471951586859566, 3.4920545262949805, 10.515945707048688, 15.6367107459477, 29.176343985966273, 28.67106056213379, 44.87791790281023, 30.48620101383754, 19.673061745507376, 43.672155312129426, 38.84494645254952, 1.3420860299042292, 0.14905070699751377, 0.11640171892940998, 0.033433439010488133, 0.09039530370916639, 0.0601249880024365, 0.08920054603368044, 0.06648681020098073, 0.028612305210637193, 0.032554407071854384, 0.06768027187458106, 0.037682123349181244, 0.04494076867454818, 0.033922849356063774, 0.035489817416029315, 0.12319688073226384, 0.029210745955684354, 0.034264230501971076, 0.011694788533662046, 0.028863064612128904, 0.02349624446859317, 0.011495926883071661, 0.05266619859529393, 0.028823204072458402, 0.0071038596132504085, 0.06052271130361727, 0.09071481906409774, 0.059234051166900566, 1.9116856711251395, 57.41163090297154, 64.2865468433925, 34.91436093194144, 38.52181352887835, 74.57049914768764, 30.612588746207102, 30.86339439664568, 26.07855044092451, 20.932492222104752, 28.408574989863805, 19.995303562709264, 23.362192153930664, 22.76568235669817, 26.49683199610029, 63.78244113922119, 71.37437643323625, 54.73771742412022, 8.325963837759835, 14.90002625329154, 58.52138328552246, 58.95174775804792, 60.411668504987446, 61.12529713766915, 60.8873074395316, 59.46247509547642, 55.946207182747976, 53.41848380225045, 35.04429571969168, 24.892840351377213, 10.573917133467537, 9.051496471677508, 8.6175171988351, 6.916532175881522, 6.488702493054526, 10.22648983342307, 10.424869588443212, 6.61429899930954, 3.083630293607712, 12.442571742194039, 27.192287615367345, 13.284299969673157, 6.620665720530918, 5.842360649790082, 17.075526339667185, 18.1377044064658, 8.191405892372131, 8.643547756331307, 5.538183280399867, 5.7776186381067545, 9.697955131530762, 9.76931573663439, 1.1140948981046677, 1.354024772133146, 1.609767117670604, 5.4083848510469705, 4.011839491980417, 5.807149350643158, 2.0630124424185072, 0.46914475730487276, 0.9523160819496427, 2.7073842542512074, 6.686594137123652, 14.634928158351354, 20.089823382241384, 17.703914472035, 13.416277527809143, 6.804519832134247, 11.334070035389491, 17.763163498469762, 7.3764325720923285, 2.112330321754728, 4.595670998096466, 7.830219422067914, 14.157594731875829, 16.059496470860072, 10.312047345297676, 9.747477548463003, 4.596177348068782, 10.863983580044337, 15.627285514559064, 7.585113900048392, 7.203778522355216, 5.204869074480874, 3.2905572014195577, 1.5818286282675607, 3.25933329973902, 2.819334498473576, 1.0085824855736323, 6.214883540357862, 8.542694653783526, 20.200146879468644, 9.142272080693926, 11.689222863742284, 17.177430357251847, 10.827597601073128, 20.29146705354963, 14.594903060368129, 10.677752750260488, 11.41134876864297, 8.464961682047162, 6.791170171328953, 17.606822081974574, 25.886503968920024, 15.03794973237174, 13.647352031299047, 19.319365433284215, 26.22831538745335, 40.90638664790562, 30.108740125383648, 10.64377692767552, 3.1314603899206435, 4.915150906358447, 3.274897698845182, 2.0640375188418796, 1.9517989243779863, 5.112998255661555, 4.886420973709651, 14.03515010220664, 41.19335767201015, 45.762493065425325, 47.75796706335885, 51.44494526726859, 49.85459641047886, 50.11510522024972, 50.57150459289551, 50.398352009909495, 54.57352801731655, 54.39652960641043, 33.77789272580828, 9.263969779014587, 28.989659786224365, 52.65958070755005, 49.55849197932652, 49.929261752537315, 60.53242819649832, 19.610474109649658, 10.868037853922162, 6.455887453896659, 15.985717024121966, 17.881944690431865, 30.817383425576345, 31.5777074268886, 44.39105415344238, 34.27781214032854, 20.727336236408778, 51.81702477591378, 43.68510675430298, 1.4514120263712746, 0.07717095475111689, 0.10784284105258328, 0.016002673356394683, 0.05656400569049375, 0.05842467424060617, 0.0590791076953922, 0.08027357647993735, 0.03486278320529631, 0.08076233203922, 0.13157552613743714, 0.07623776553996972, 0.13160401103752, 0.09889957987304245, 0.15673887516771043, 0.1786342231290681, 0.2076573779008218, 0.21989224638257707, 0.2512346202773707, 0.15763593917446478, 0.14231330209544726, 0.08963144291192293, 0.2424861325749329, 0.11376705566155058, 0.23786237782665662, 0.2396522717816489, 0.25975346458809717, 0.13755409818674835, 3.439189157315663, 77.70267759050641, 67.53587191445487, 50.963980538504465, 42.38633210318429, 94.10988971165249, 59.40049716404506, 41.12434468950544, 33.24459069115775, 12.610240459442139, 39.036254678453716, 48.41700022561209, 27.317490679877146, 19.258507898875646, 35.49454246248518, 63.71304253169468, 80.22976521083287, 47.6074343408857, 8.635647654533386, 20.056833335331508, 67.63070787702287, 62.04707990373884, 67.79518563406808, 64.74050045013428, 64.6386468069894, 64.60385717664445, 61.76601137433733, 54.97564806256975, 38.499190194266184, 28.6079101221902, 18.631568465914043, 15.428534030914307, 15.545017106192452, 12.61651815686907, 11.521137254578726, 15.340107781546456, 16.514707701546804, 9.974720988954816, 5.917475453444889, 18.834165777478898, 27.727538619722637, 11.9168085030147, 6.617118230887821, 7.805898121425083, 19.10745406150818, 26.779271057673864, 20.372389248439244, 8.089891842433385, 9.390736188207354, 11.26768694605146, 15.182347195489065, 14.370446716036115, 3.472592839172908, 2.1265954077243805, 3.2556155792304446, 12.257456966808864, 8.260556970323835, 8.763524906975881, 4.695621703352247, 3.272432174001421, 2.4373247112546648, 2.449000507593155, 5.936238195214953, 12.659322534288679, 27.093701362609863, 20.951189824513026, 30.351194041115896, 22.747403383255005, 19.56062252180917, 26.668546301977976, 13.42365390913827, 9.991321972438268, 14.926771606717791, 10.541474257196699, 18.824540785380773, 23.049714292798722, 16.289787564958843, 10.020713721002851, 5.363323177610125, 16.525543417249406, 24.041672127587454, 19.889600617544993, 16.76770724569048, 12.564288548060826, 10.430534975869314, 7.295803070068359, 5.600281068256923, 3.1430934114115576, 2.2626146461282457, 5.927902962480273, 10.59881513459342, 30.029002598353795, 13.71653437614441, 8.743140629359655, 16.537824358258927, 14.948217221668788, 24.578010525022233, 23.883850744792394, 19.26697427885873, 18.183244637080602, 13.124758907726832, 10.825439316885811, 15.48901115145002, 27.05559049333845, 26.94900165285383, 14.312637703759329, 17.049232619149343, 22.74726094518389, 38.92599718911307, 26.552328995295934, 8.04214642729078, 2.658833933728082, 5.71074526650565, 4.728325137070247, 3.6404928011553626, 1.7649211521659578, 4.784197338989802, 4.326065693582807, 15.203608683177404, 42.81689459936959, 49.33913387571062, 53.8668406350272, 54.777666091918945, 53.52013942173549, 51.77019044331142, 54.06855378832136, 53.31890916824341, 59.099216324942454, 57.604380880083355, 37.23329789297921, 11.38382955959865, 28.164417028427124, 60.73407881600516, 58.26795469011579, 55.966145038604736, 69.61068044389997, 25.632106099809917, 23.282701287950786, 11.335251229149954, 14.686914580208914, 28.797225952148438, 49.1131854057312, 39.49668400628226, 66.79679897853306, 45.63339900970459, 34.034802368709016, 55.67315687452044, 63.382447242736816, 4.667097611086709, 0.3151249890880925, 0.2948932461440563, 0.10068726858922414, 0.23297632858157158, 0.32240699976682663, 0.23361770702259882, 0.16530850103923253, 0.06906491078968559, 0.22220143675804138, 0.2402989970786231, 0.29321156495383804], [0.08517226004706961, 0.05103280195700271, 0.027902503298329454, 0.03274648337225829, 0.07498106440263134, 0.025737433760826076, 0.07527368262942348, 0.0759763667093856, 0.060523267702332566, 0.08948894377265658, 0.10312158760747739, 0.017799425604087964, 0.03659004159271717, 0.08580806093024355, 0.11050573137721845, 0.08768477344087192, 0.12481425037341458, 22.435318095343455, 65.7008387701852, 44.20069783074515, 44.59037365232195, 39.54785748890468, 53.05978652409145, 31.668266773223877, 32.25185292107718, 7.038569901670728, 13.858444384166173, 27.97860309055873, 30.024694715227398, 21.01717860358102, 64.33257171085903, 45.087770870753694, 45.41647277559553, 23.489700283323014, 13.078297172273908, 6.363610599722181, 41.91335085460118, 59.250131198338096, 52.59489645276751, 57.110832963671, 25.31336096354893, 33.06850249426705, 56.267151423863, 42.916517870766775, 46.648610728127615, 26.97551771572658, 18.03890449660165, 3.9240125247410367, 4.646348987306867, 8.596963558878217, 7.025472981589181, 10.296258432524544, 4.947963339941842, 10.478768501962934, 7.3159293958118985, 4.895953033651624, 3.3637490911143164, 5.612462997436523, 5.691461409841265, 4.033579536846705, 6.267594746180943, 10.356620039258685, 17.287052086421422, 4.94239045040948, 4.436214617320469, 4.1273367915834696, 2.1667334139347076, 6.550451568194798, 2.7343699719224657, 1.290887468627521, 1.9328657346112388, 3.331996474947248, 2.6921414264610837, 4.320522333894457, 1.6559147728340966, 0.7734704815915653, 0.6185444891452789, 0.46971217542886734, 1.9553902745246887, 8.063353197915212, 18.46302601269313, 27.694263696670532, 30.48960563114711, 27.812423024858745, 22.177416597093853, 23.233815499714442, 16.9238315309797, 20.334604944501603, 14.022720643452235, 2.1157134430749074, 10.378690123558044, 7.009463897773197, 6.238045360360827, 1.5762084041322981, 9.545711415154592, 23.071243286132812, 26.638319901057653, 22.67662034715925, 15.505669457571846, 9.397858091763087, 8.982833504676819, 1.907907371010099, 0.9999666107552392, 0.196494228339621, 1.565480928335871, 0.6513779844556535, 6.682741795267377, 10.452466096196856, 17.47205134800502, 6.595127616609846, 5.088937512465885, 7.315638439995902, 14.587258304868426, 12.244056497301374, 16.52697648320879, 14.087172133581978, 6.445094295910426, 7.706426841872079, 14.261439033917018, 8.68204425062452, 17.827507291521343, 14.958915710449219, 15.782339777265276, 11.100475941385541, 9.848656347819738, 19.230489288057598, 29.58763565335955, 7.813253658158438, 4.754044762679508, 3.1371839685099463, 4.569527098110743, 4.456989296845027, 5.816835139478956, 9.911814604486738, 14.487298914364406, 33.629288128444124, 54.189056396484375, 42.3438195501055, 48.51519216809954, 42.965130942208425, 47.004514830453054, 41.92647252764021, 52.37819256101336, 43.658529894692556, 53.55695792606899, 23.736569779259817, 8.743917090552193, 34.408705779484336, 65.94847951616559, 38.7263754435948, 56.6814238684518, 15.158064978463308, 16.131419011524745, 12.71109356198992, 5.871467522212437, 9.874256985528127, 35.779227529253276, 22.373209885188512, 26.467626980372838, 56.5638290813991, 18.559505224227905, 36.089742524283274, 42.23190491540091, 17.455453838620866, 0.24398832768201828, 0.026148491971460835, 0.11417579837143421, 0.0994656952098012, 0.11255310223038707, 0.050435535077537806, 0.06897312535771302, 0.13006088669810975, 0.02868613660601633, 0.1393168643116951, 0.01519455002354724, 0.12325203205857958, 0.06149647690887962, 0.025835590636623756, 0.09643721700246845, 0.09183711598494224, 0.17427279001900128, 0.02543157053046993, 0.07869571114757232, 0.05572105485147663, 0.022544648298727613, 0.054440177511423826, 0.10015246085822582, 0.042327886380787404, 0.19241684355906077, 0.06914677603968553, 0.2038126356367554, 0.12299265526235104, 0.27863684988447596, 29.55536821910313, 75.83162498474121, 47.454386370522634, 43.43301568712507, 42.319848264966694, 43.1694461958749, 33.25608648572649, 27.707842213766916, 19.56461947304862, 24.451329231262207, 18.509367023195537, 25.388575213296072, 22.69023707934788, 60.078168869018555, 53.33848919187273, 51.04802247456142, 30.005253655569895, 16.039850439344132, 10.111220955848694, 47.15203898293631, 66.6169101170131, 58.46229580470494, 62.46757793426514, 38.90835223879133, 45.08135420935494, 59.35588278089251, 47.83818054199219, 44.78491626467024, 32.380665574754985, 16.543528829302105, 6.400000052792685, 5.032103419303894, 6.350326946803501, 7.823537860597883, 5.565542680876596, 2.2458410433360507, 2.626694824014391, 11.526979821068899, 15.744717018944876, 9.16383581502097, 6.660535786833082, 4.677013124738421, 6.292698587690081, 13.860119768551417, 14.200193268912178, 14.604568004608154, 7.1379126395498, 7.188156366348267, 5.153257421084812, 5.698414385318756, 12.24615659032549, 9.53209034034184, 4.285464763641357, 3.5754088078226363, 9.991503494126455, 4.771639772823878, 5.099295539515359, 0.8790831544569561, 0.7502836914999145, 0.3814787385719163, 0.7559495674712318, 4.322076124804361, 13.778419375419617, 20.719274588993617, 27.076765128544398, 27.12941857746669, 20.80420242037092, 23.684604201998027, 26.49994478906904, 18.191777024950298, 19.03848797934396, 16.45672151020595, 5.943145573139191, 13.26619383266994, 10.19561117036002, 9.05340462071555, 4.319116626467023, 7.855150427137103, 24.69853745188032, 24.803979839597428, 18.06903883389064, 12.344213911465236, 7.640716859272548, 6.896874853542872, 3.133768060377666, 2.6580344566277097, 1.839512126786368, 1.7065966704062052, 4.210164529936654, 7.351822921207972, 17.004154443740845, 20.317086798804148, 8.254194157464163, 16.471345731190272, 11.27962395123073, 18.278605188642228, 14.389596819877625, 14.191574897084918, 11.787154248782567, 5.643057218619755, 9.073347687721252, 16.676456553595408, 12.452011738504682, 20.19514765058245, 15.327995334352766, 16.472050973347255, 16.73598871912275, 18.474591289247783, 28.313593115125382, 37.26112542833601, 13.759351781436376, 7.317013314792088, 1.7060733841998237, 1.9064569345542361, 4.082202162061419, 9.362781848226275, 9.918070588793073, 14.05554827622005, 37.99504280090332, 56.339780943734304, 45.27631718771798, 52.30911009652274, 48.32470382962908, 50.90256193705967, 45.73631572723389, 56.057854311806814, 46.93970898219517, 56.635395526885986, 26.35000092642648, 12.873406086649213, 43.01699229649135, 61.33803708212716, 50.68765068054199, 66.62929875510079, 23.0196042742048, 19.15111654145377, 11.334113461630684, 9.523586613791329, 11.753090705190386, 27.99250817298889, 29.596077714647564, 26.068796907152446, 59.681412833077566, 21.385073559624807, 42.70495217187064, 52.60229281016758, 22.289798498153687, 0.21904999443462916, 0.17136913511369908, 0.16160228848457336, 0.025044459516980817, 0.10087879188358784, 0.045863084362021515, 0.05451102335272091, 0.17264138827366488, 0.04996068270078727, 0.04794436839542218, 0.005156282601611955, 0.034553578189973316, 0.18395848385989666, 0.145474623888731, 0.23169381597212382, 0.21174621635249682, 0.36677656748465126, 0.09033951455993311, 0.17697867910776818, 0.15418286089386257, 0.12230033241212368, 0.10766392493886606, 0.21054629502551897, 0.15266607728387627, 0.2723913693002292, 0.2552245147526264, 0.3205340531255518, 0.2631634830364159, 0.40777549892663956, 40.4045912197658, 86.20172105516706, 57.548121316092356, 60.103210176740376, 44.033298356192454, 72.9514854976109, 47.57740075247628, 47.22664873940604, 12.922708766801016, 25.156663451875957, 32.783664567129954, 40.771435260772705, 25.354568992342266, 79.01220457894462, 53.77977623258318, 55.33509922027588, 28.48017270224435, 20.322760002953665, 10.467726945877075, 50.33960151672363, 68.90292998722622, 60.66125474657331, 66.21950789860317, 35.77960620607649, 43.59104551587786, 64.58672986711774, 49.835509708949495, 56.24900620324271, 32.584094933101106, 24.50648750577654, 12.365976537976946, 15.147522824151174, 18.85692286491394, 15.606341906956263, 22.50382559640067, 13.621232884270803, 19.39751877103533, 15.109213931219918, 14.898725203105382, 8.46004843711853, 10.74483152798244, 9.172123278890338, 8.786063126155309, 9.74266505241394, 18.320695638656616, 24.928102459226334, 7.7789000272750854, 11.673726643834796, 12.347443086760384, 10.150664142199926, 17.824488299233572, 12.242605192320687, 7.037425185952868, 4.963902941771916, 18.664445604596818, 8.127266202654157, 4.481433493750436, 4.5290186660630365, 1.9120717304093497, 1.5353721039635795, 0.6843103830303464, 5.217589923313685, 16.575959546225413, 26.180419717516216, 32.055486406598774, 34.15635068075997, 32.55678503853934, 30.72758490698678, 37.309974738529746, 26.671214410236903, 33.93280976159232, 23.931539705821447, 10.602445568357195, 16.486399003437587, 13.215890611921038, 8.851229412215096, 4.38668829202652, 17.44172419820513, 36.228369508470806, 38.27245657784598, 27.594527517046245, 20.65868977137974, 11.662236060414996, 9.350994229316711, 4.006345638207026, 1.9928844911711556, 1.354398780635425, 4.137269675731659, 4.251193642616272, 10.435264093535286, 27.73447639601571, 30.61961337498256, 8.953904679843358, 13.609968117305211, 13.603702579225812, 22.77466290337699, 18.139200006212505, 26.73860846246992, 19.462161336626323, 11.792160425867353, 12.36377135344914, 21.188785212380544, 10.958443471363612, 23.927688666752406, 19.250300339290074, 19.57930449077061, 14.62317180633545, 15.319112062454224, 28.187856776373728, 40.492878505161826, 13.058332392147609, 9.124151178768702, 5.948206467287881, 9.85538307258061, 10.128123317446027, 14.800514153071813, 16.67833604131426, 19.79592326709202, 38.8130715915135, 58.96131542750767, 47.35086863381522, 56.6211656161717, 50.141695976257324, 54.37268338884626, 46.92568751743862, 60.788462366376606, 48.14501993996756, 64.30915628160749, 29.246798719678605, 11.962669219289507, 42.44913339614868, 74.31087970733643, 46.841902664729524, 64.26398604256767, 21.22295297895159, 24.480254581996373, 20.372802666255406, 10.278100184031896, 13.999725580215454, 57.737126214163645, 35.279412337711875, 37.43641458238874, 75.01979746137346, 32.351611682346885, 51.15975298200335, 59.88721152714321, 39.30721010480608, 0.25843241118959015, 0.2450408712029457, 0.24331557378172874, 0.3779074730617659, 0.25859061841453823, 0.2761809602379799, 0.15175029928130762, 0.30034342940364567, 0.1404421060745205, 0.2727442889341286, 0.1595029282782759, 0.18927689561886446], [0.02545617421024612, 0.031981414782681634, 0.036295255446540456, 0.04265266377478838, 0.08928110849644456, 0.03843049658462405, 0.0331329904895808, 0.0175093349202403, 0.08632553887686559, 0.033296222266341956, 0.040632607348795445, 0.04235288021819932, 0.0824886065508638, 0.08015859872102737, 0.044870272278785706, 0.1314084708158459, 0.0804334461156811, 3.3458768044199263, 66.05306380135673, 53.07554503849575, 33.27176856994629, 39.51435327529907, 42.94450868879046, 25.02616238594055, 43.56161642074585, 20.686974150793894, 5.162922365324838, 20.15347409248352, 28.331819977079117, 22.863106523241314, 31.1685106413705, 39.3742949622018, 54.35566030229841, 66.84712478092739, 29.364348343440465, 10.918348891394478, 49.23534515925816, 57.73278706414359, 47.152532305036274, 57.97470596858433, 18.59326478413173, 12.301571079662867, 58.57598223005022, 48.78297574179513, 64.09021854400635, 38.469399792807444, 14.808902365820748, 7.491688421794346, 7.126323478562491, 4.066568715231759, 5.257220711026873, 6.989336269242423, 10.846247434616089, 14.561880009514944, 8.70983704498836, 1.4131784779684884, 8.872729744229998, 9.230896353721619, 8.932736124311175, 6.65016473191125, 8.109407595225743, 19.261113473347255, 15.680239473070417, 7.603226116725376, 6.025041818618774, 5.053911209106445, 1.3334138095378876, 2.069659045764378, 1.7468607212815965, 6.0279474684170316, 7.0686525617327005, 3.6645146778651645, 2.846468299627304, 2.959182628563472, 0.8553274806056703, 0.3700784274509975, 0.43619314261845177, 0.38784787537796156, 6.349901803902217, 15.794961180005755, 23.92197377341134, 35.63111972808838, 32.47510896410261, 40.186143330165315, 32.73065676007952, 28.25691144806998, 20.437363590512955, 36.932024002075195, 18.15210975919451, 4.463472834655216, 3.871959660734449, 4.307547875813075, 2.8971508485930304, 3.5902868551867346, 25.47664884158543, 37.93035159792219, 34.776400974818635, 26.130917276654923, 13.540314163480486, 12.14463906628745, 5.961774996348789, 0.8580058483140809, 0.12047412326293332, 0.27743690141609734, 1.4807646913187844, 1.7956582456827164, 3.862922659942082, 6.188684054783412, 25.765634843281337, 13.318657943180629, 7.160662344523838, 7.154059384550367, 14.299482158252172, 11.598816377776009, 15.092173474175588, 18.29347607067653, 8.52732002735138, 7.371219686099461, 16.633992637906754, 18.817118372235978, 17.49536429132734, 18.431373494012014, 19.397190468651907, 16.89599183627537, 16.246121610913956, 9.901196019990103, 18.684614488056727, 24.40459564753941, 22.53399988583156, 7.888137868472508, 2.681866777794702, 3.588630795478821, 8.454450794628688, 5.552130920546396, 18.29011835370745, 37.79749856676374, 41.74309567042759, 45.9579667363848, 44.524219853537424, 46.24818951742989, 39.59646708624703, 42.69908789225987, 46.62282248905727, 48.35509525026594, 40.20836366925921, 9.738661152975899, 24.335615668978008, 54.19339902060372, 58.6467079435076, 40.45898519243513, 27.61685381616865, 20.401342391967773, 18.598206690379552, 10.74815102985927, 10.89265011038099, 21.453235387802124, 30.20982599258423, 12.9159768308912, 67.98543425968715, 28.34871973310198, 26.90619032723563, 39.25064829417637, 39.902434485299246, 3.418599473578589, 0.29503150443945614, 0.07482490635343961, 0.050535564709986956, 0.03968159980805857, 0.10537732299417257, 0.03611055142911417, 0.039207799160586934, 0.0035670462945875314, 0.03605417534708977, 0.020219261292368174, 0.020285131775641015, 0.06696785081710134, 0.008507560273366315, 0.015570582256519368, 0.04056216862850955, 0.03664627518238766, 0.06843259757650749, 0.08557280605392796, 0.06254661163049084, 0.08384866892759289, 0.0640822449432952, 0.049490111880004406, 0.018319420915629183, 0.04020557472748416, 0.13703520888728754, 0.047449190502188036, 0.05891881736793688, 0.11072758518691574, 0.2430068403482437, 5.098456110273089, 73.95996788569859, 64.56428023747036, 34.47389030456543, 47.441344601767405, 45.70964159284319, 36.19923571177891, 37.26246990476336, 23.213761261531285, 22.23853816304888, 20.905665227345057, 22.27484597478594, 28.554966585976736, 39.29486663000924, 45.56856189455305, 59.54984869275774, 59.087876864842, 32.749972752162385, 15.064431054251534, 58.34107058388846, 62.44976970127651, 52.74317448479788, 61.951375416346956, 25.907895735331945, 21.230635949543544, 63.20482349395752, 53.97312722887312, 64.39449405670166, 40.0088461467198, 18.553748641695293, 5.094487386090415, 3.286948697907584, 3.868130769048418, 3.0671272362981523, 2.063141418354852, 4.011037843567984, 21.70421474320548, 20.277610608509608, 10.86715543270111, 13.554247038705007, 12.219927140644618, 10.032732367515564, 11.282523087092809, 9.884637594223022, 21.422006709235056, 15.827824422291346, 5.948913880756923, 9.609336938176837, 7.497619577816554, 5.164187805993216, 5.702255436352321, 3.1467472953455786, 11.574802534920828, 8.26694062777928, 9.525080476488386, 3.3479384652205875, 5.282682819025857, 1.2312331667968204, 0.34243686497211456, 0.47365402962480274, 0.5086528116038868, 1.9681002667972018, 11.842558315822057, 22.265330416815623, 34.6710593359811, 33.65569475718907, 37.500556877681184, 36.25954607554844, 31.753302301679337, 26.023583241871425, 36.86389691489083, 23.916005270821707, 6.723286271095276, 5.7891756636755805, 8.233625752585274, 4.233496146542685, 3.990995764732361, 26.929505007607595, 40.78171512058803, 36.68875019890921, 28.24863961764744, 15.114527566092354, 11.596355846949987, 7.474971924509321, 3.0855484306812286, 0.18103390293461935, 1.2833493245499474, 2.191580606358392, 6.244012560163226, 7.127804313387189, 12.814567003931318, 27.969209126063756, 10.910932557923452, 13.408096892493111, 14.736132144927979, 17.442370380674088, 12.74066162109375, 16.92139618737357, 11.076889412743704, 4.789020691599164, 11.447829416819982, 17.30182569367545, 18.1566139289311, 17.844455684934342, 17.574446950639995, 18.91478225163051, 16.75964559827532, 18.38712215423584, 18.914455686296733, 28.880505323410034, 28.16442745072501, 25.75293701035636, 15.084565196718488, 5.134578057697841, 1.1723572803395135, 6.887360164097377, 4.045317649841309, 19.332414150238037, 42.173109258924214, 46.68531458718436, 48.40387855257307, 47.65722860608782, 49.94413784572056, 45.792808055877686, 46.67924880981445, 50.5969488961356, 55.339528696877615, 43.4123204776219, 14.55402420248304, 32.595740113939556, 54.05360473905291, 60.734016282217844, 50.3915809903826, 36.046000140053884, 27.623539720262798, 20.10662760053362, 10.779339756284442, 11.366108179092407, 14.852184431893484, 38.59640938895089, 17.22847008705139, 59.830611501421245, 36.94460024152483, 28.82736028943743, 48.249239444732666, 47.77434744153704, 4.526337095669337, 0.2620379834302834, 0.07186071933912379, 0.057299778530640263, 0.012253215220490736, 0.016168269827695828, 0.045655520499816964, 0.04789662327883499, 0.094708445481956, 0.026141246913799217, 0.023108660176928555, 0.028498843977493898, 0.039287947716989687, 0.11602210572787694, 0.18724323117307254, 0.1989781279116869, 0.10913055802562407, 0.2208209844040019, 0.13139533437788486, 0.16317235066422395, 0.20114796076502117, 0.18515632886971745, 0.13956071622669697, 0.18140018970838614, 0.20513619961483137, 0.33627408423594063, 0.14433919052992547, 0.14647639941956314, 0.24845946633390018, 0.4270889668592385, 8.172458154814583, 90.83778149741036, 66.97706999097551, 49.86845806666783, 50.29772472381592, 54.834585734776084, 39.11557878766741, 64.4401159286499, 29.624961376190186, 14.3230174439294, 26.888093744005474, 38.98091227667672, 28.968485151018413, 42.5530298096793, 47.472601073128835, 62.30287783486502, 72.9863862991333, 35.28310530526297, 15.914133208138601, 56.353545325142996, 67.42169216700962, 57.86104038783482, 68.92601190294538, 23.2909540108272, 17.744959218161448, 68.9829454421997, 56.55335814612252, 69.64226695469448, 45.658579281398225, 20.532454899379186, 15.262157678604126, 17.299122844423565, 13.357683369091578, 17.979935135160172, 16.759821040289744, 23.76819624219622, 31.474377291543142, 19.31359495435442, 5.7888412816183905, 14.370134047099523, 16.156521115984233, 12.075330785342626, 10.193722128868103, 12.67592351777213, 27.12597053391593, 25.002416917255946, 11.989358987127032, 15.225014345986501, 15.703203269413539, 6.459494871752603, 8.920819963727679, 2.9483453929424286, 13.172035319464547, 14.544834341321673, 15.757982867104666, 7.823908720697675, 6.8336345212800165, 2.2783742461885725, 1.1565886693341392, 0.5763701179197857, 4.1519069245883395, 16.05221823283604, 23.525870868137904, 24.818131583077566, 40.9767302104405, 38.418455600738525, 45.68877615247454, 41.521618366241455, 36.31773723874773, 34.052245821271626, 46.324366092681885, 28.5950003692082, 15.57885135923113, 9.23622649056571, 9.05419671535492, 6.54862288917814, 17.36655511174883, 40.417528765542166, 47.50631373269217, 42.666834354400635, 32.917410441807334, 15.789305346352712, 14.503080878938947, 9.351868833814349, 2.973330246550696, 0.17499514482915401, 1.6484688009534563, 2.531027248927525, 13.037040506090436, 9.298665608678546, 17.52636889048985, 41.10861049379621, 17.003483942576818, 10.291089841297694, 13.64986641066415, 21.927694865635463, 15.930418048586164, 22.454079968588694, 23.584537982940674, 14.426178216934204, 10.927946090698242, 23.21041570390974, 24.278960057667323, 23.09605704035078, 22.58246009690421, 23.508062635149273, 21.591994387762888, 19.072079045431956, 15.104096582957677, 26.147978578295024, 32.5731862613133, 32.50767864499773, 14.856179646083287, 9.91988754272461, 15.261556659426008, 16.99473442350115, 10.840098278863088, 21.53280442101615, 44.79451520102364, 49.49240418842861, 52.37997129985264, 50.394877910614014, 53.0370728628976, 46.76203312192644, 49.78927986962454, 54.74739279065813, 58.20982606070382, 48.9610823903765, 15.428711209978376, 32.85053750446865, 62.88740198952811, 66.29797390529087, 46.0280636378697, 32.47858306339809, 31.770144735063823, 25.00446489879063, 18.34632233210972, 13.007191913468496, 33.1377169745309, 53.881866114480154, 21.451644250324794, 84.20093168531145, 41.92481190817696, 42.74536984307425, 53.52485377447945, 66.25536060333252, 10.602860723223005, 0.5795289427042007, 0.23575283959507942, 0.20772991329431534, 0.29878510587981766, 0.13348685071936675, 0.17285291478037834, 0.1136675485010658, 0.18062823398837022, 0.11360878058310066, 0.14765118780945027, 0.20673530309328012, 0.10425243406955685], [0.10724655126354524, 0.15912799696837152, 0.030940324932868992, 0.12254023525331702, 0.10184866948319332, 0.08938934840261936, 0.0027125824126414955, 0.01815978537446686, 0.05546979672674622, 0.04970364685037306, 0.09077451657503843, 0.13211549073457718, 0.05494407457964761, 0.020649140368082693, 0.16593937575817108, 0.10380877394761358, 0.03605046376053776, 0.24252546046461376, 33.81061526707241, 69.5178108215332, 40.581478459494456, 28.053155524390085, 33.028091771262034, 24.76247651236398, 35.38620267595564, 43.271515233176096, 5.614479712077549, 16.411125694002422, 27.95185947418213, 21.76144184385027, 21.445295333862305, 45.90864494868687, 25.8097037928445, 76.93850776127407, 26.713162422180176, 7.089381209441593, 27.872872352600098, 63.84865747179304, 55.4595171383449, 62.0032228742327, 62.86692564828055, 19.463881015777588, 51.344245025089805, 51.11692081178938, 52.58057621547154, 51.08523007801601, 20.812283175332205, 5.627618755613055, 3.5674409610884528, 3.2395268082618713, 4.028305419853755, 2.3309173924582343, 9.477099691118513, 5.954996594360896, 4.406463299478803, 8.152968457766942, 12.248785614967346, 7.209121252809252, 6.427192262240818, 7.8127082245690485, 17.20971863610404, 13.81457780088697, 11.09510498387473, 12.581177013260977, 2.354499795607158, 1.8751481345721652, 2.290493641580854, 0.8913619784372193, 1.8920680837971824, 5.052836409636906, 6.659606899533953, 3.7486200162342618, 1.5721947337899889, 3.224740607397897, 0.46038725865738733, 0.1605082457619054, 0.19252316999648297, 0.3970008242343153, 6.2233829242842535, 20.719347545078822, 32.475310461861746, 45.30823721204485, 40.41130665370396, 37.99768659046718, 40.20411137172154, 30.760640961783274, 23.250199351991924, 40.47923919132778, 26.32806372642517, 11.94282169001443, 1.5404167132718223, 3.343157018933977, 2.5901066958904266, 12.85786383492606, 34.95497662680489, 39.646139757973806, 29.536764417375835, 17.9724953515189, 14.877006871359688, 10.88270550114768, 4.1148982133184155, 1.478309263076101, 0.7422830579536301, 1.4133618452719279, 0.8806383567196983, 5.066232102257865, 4.294851345675332, 5.715560802391597, 22.137695482798986, 22.930267810821533, 12.569581338337489, 8.571561813354492, 13.463071039744786, 10.993468471935817, 11.928492767470223, 21.521279096603394, 11.745879343577794, 11.786648767335073, 19.316499301365443, 17.566277606146677, 21.258880376815796, 20.30528007234846, 21.463949510029384, 19.64047816821507, 17.482864482062205, 16.96390700340271, 14.815708126340594, 19.018784625189646, 28.39784002304077, 13.362531474658422, 4.082078397274017, 1.839152991771698, 8.017281430108206, 6.390104080949511, 11.046289546149117, 41.896491050720215, 46.484327520642964, 49.5630395753043, 50.40542180197579, 45.7544401032584, 43.605244159698486, 53.949044772556846, 47.19644144603184, 47.40686764035906, 38.621162346431184, 18.80925474848066, 47.34457703999111, 54.39088419505528, 52.45729085377285, 28.57860435758318, 40.700424671173096, 16.91893478802272, 15.710662160600934, 9.682817612375532, 10.876974105834961, 26.127957344055176, 12.759766561644417, 39.744383811950684, 54.859206676483154, 22.12848390851702, 28.05023901803153, 40.42556783131191, 17.70845685686384, 0.2931257167032787, 0.11498364859393664, 0.09146479024950947, 0.04393978702968784, 0.027709948630737405, 0.05375016846561006, 0.03726798628589936, 0.030867338313588073, 0.08711082102464777, 0.10986276516424757, 0.030858571641147137, 0.03281970747879573, 0.07431951990084988, 0.07218115750168051, 0.12909127372716153, 0.02889156647558723, 0.07450456997113568, 0.07061543794614927, 0.019867881932961087, 0.026799451326951385, 0.05015383447919573, 0.023915633392919387, 0.013135309048396136, 0.02991375233978033, 0.0969405814207026, 0.038959889606173546, 0.046877144769366295, 0.09567682351917028, 0.1311770768037864, 0.07132601338837828, 0.19667608929531916, 39.51081664221627, 84.62256922040666, 42.10227237428938, 35.14557613645281, 33.90291166305542, 27.04235938617161, 47.5068278993879, 32.30660820007324, 17.532667432512554, 23.112819569451467, 23.641535793031963, 27.815461124692643, 30.47525065285819, 55.983251503535676, 31.41452203478132, 68.64028113228935, 32.91602775028774, 10.321570719991412, 30.837328229631694, 68.92913859231132, 61.402050835745676, 68.84626742771694, 59.77763148716518, 21.994889157158987, 55.480188029153005, 53.125217710222515, 58.14982489177159, 53.247061320713584, 19.890444823673793, 4.553197528634753, 5.925341248512268, 2.7766818957669392, 1.0822890847921371, 5.684236151831491, 22.06445104735238, 19.495648179735454, 12.208697983196803, 12.541689532143728, 13.012878145490374, 8.876030138560704, 9.113349335534231, 9.657383731433324, 17.853062765938894, 20.508197001048497, 16.111394303185598, 9.286640013967242, 3.0690857597759793, 5.329740362507956, 5.741027253014701, 4.70271190575191, 3.9805647815976823, 8.893005456243243, 12.37698335306985, 8.98283611025129, 4.996363188539233, 6.621558564049857, 1.7521856469767434, 0.1647959356861455, 0.18711618227618082, 0.8894118145108223, 7.335883753640311, 19.98098679951259, 29.62111554827009, 42.59291941779, 38.19497374125889, 42.32206474031721, 44.907291412353516, 36.72268867492676, 26.773389407566615, 44.51042767933437, 27.87260832105364, 14.640582254954747, 4.202160205159869, 5.928627746445792, 2.8900830107075826, 17.278226137161255, 39.47249732698713, 45.494657380240305, 38.20460047040667, 25.700782094682964, 15.184518507548741, 12.43133476802281, 7.905274731772287, 1.8729038664272852, 0.07914570878658976, 1.1146548794848579, 0.49612005267824444, 5.2245064207485745, 6.502468177250453, 10.565018228122167, 28.83170291355678, 15.784584045410156, 12.844590170042855, 14.30710346358163, 21.06958191735404, 13.373901333127703, 16.92398612839835, 11.280497687203543, 12.40548573221479, 16.19123431614467, 17.388417618615286, 17.50621042932783, 22.21897724696568, 18.69955137797764, 17.900876794542583, 20.667581728526525, 16.670946632112774, 18.17770344870431, 24.353109495980398, 33.18417957850865, 35.82383843830654, 22.854527235031128, 9.968978302819387, 2.929530756814139, 2.649167469569615, 2.491469200168337, 11.71009177821023, 45.41312026977539, 51.4573130607605, 52.038554191589355, 52.426152501787456, 49.24114343098232, 45.344847270420615, 55.38107892445156, 51.67940180642264, 52.36912168775286, 40.261597292763845, 22.011444977351598, 48.92286729812622, 53.19559948784964, 57.232919761112754, 31.93732534136091, 38.15596308026995, 26.659562281199864, 15.720250674656459, 10.72097054549626, 12.366799899509974, 26.46983650752476, 20.920384986060007, 36.833898067474365, 59.406319754464285, 33.166941097804475, 32.563583850860596, 53.11969041824341, 22.461872373308452, 0.20323246105441026, 0.10102219347442899, 0.018076446007138917, 0.03954271726044161, 0.0360898018282439, 0.03716256230005196, 0.07135965515460287, 0.04039047212739076, 0.15787079371511936, 0.13727140692727907, 0.12435248015182358, 0.04816718911752105, 0.11907634112451758, 0.33617018695388523, 0.4013144341962678, 0.16983639236007417, 0.18120251888675348, 0.14899290938462528, 0.13343338215989725, 0.1572641291256462, 0.11376607857112374, 0.1663743302758251, 0.15338784855391296, 0.23499279894999095, 0.2753603128450257, 0.15687977974968298, 0.14902059361338615, 0.24748511718852179, 0.18323561336312974, 0.17841882897274836, 0.3873463294335774, 56.43183067866734, 86.44973700387138, 55.62527683803013, 40.388947350638254, 38.58534090859549, 32.38179465702602, 56.380188192640034, 60.690513610839844, 12.09582189151219, 23.18566448347909, 38.573355266026084, 29.974539143698557, 29.038903406688146, 52.94336945669991, 28.945196526391165, 87.68707915714809, 32.49880926949637, 11.543520876339503, 33.453206879752024, 74.50951480865479, 62.75628253391811, 74.62630707877022, 69.50427573067802, 22.2247633593423, 63.009467942374094, 56.95762171064104, 61.049325534275596, 57.34892341068813, 27.875604731695994, 12.733891470091683, 11.06156689780099, 6.804822078772953, 6.602886148861476, 6.18398403269904, 17.593773365020752, 14.412921922547476, 8.162633402006966, 12.339995486395699, 17.64634690965925, 9.54815023286002, 9.682484098843165, 11.264396974018641, 24.705949442727224, 22.588357380458287, 21.140495232173375, 22.26104858943394, 8.588392087391444, 8.095383524894714, 9.029495869364057, 7.119963271277292, 8.199899196624756, 9.36543345451355, 16.11692680631365, 15.148757866450719, 10.780061500413076, 9.673645990235464, 1.120765060186386, 1.0092312736170632, 0.846656183046954, 3.1852450924260274, 17.734797477722168, 30.718725953783306, 33.13569504874093, 47.318368434906006, 44.70235429491316, 41.72455440248762, 44.76038217544556, 39.57399313790457, 35.08887883595058, 46.54962321690151, 34.354502882276265, 24.744755131857737, 11.821350676672798, 10.448443957737513, 14.6179450239454, 31.049769401550293, 49.52946240561349, 44.38522808892386, 36.32073538643973, 23.89385267666408, 17.252913849694387, 17.92608485903059, 9.237906217575073, 2.5217583520071845, 0.6734037197061947, 2.319838272673743, 1.4377866089344025, 23.569726160594396, 11.529658351625715, 12.437146936144147, 38.88418640409197, 30.433995723724365, 15.946523972920009, 13.24583647932325, 20.23646685055324, 14.403403759002686, 18.813637324741908, 27.251630442483084, 18.789820637021744, 17.23427356992449, 27.357743331364222, 22.023635591779435, 28.03776526451111, 24.341959374291555, 25.957693474633352, 24.13664879117693, 21.103042704718455, 19.89319804736546, 21.23738612447466, 27.19582772254944, 34.05820042746407, 20.36976977757045, 5.587474669728961, 3.420990739549909, 20.106667552675518, 10.943452732903616, 14.33104087625231, 48.54982198987688, 53.92230115618025, 56.74472543171474, 57.39720296859741, 52.372522830963135, 50.24204533440726, 60.65622425079346, 54.84381989070347, 55.723003251211985, 47.940249579293386, 24.896116427012853, 56.698488644191194, 60.82259886605399, 60.564063344682964, 32.50012942722866, 48.46992465427944, 26.67920310156686, 23.081003768103464, 15.944281441824776, 15.205684457506452, 44.814644132341655, 23.896378346851893, 53.13962827410017, 74.32106576647077, 37.45682144165039, 40.44107273646763, 60.97818987710135, 39.665483542851035, 0.36083558627537315, 0.23471134262425558, 0.1428421658596822, 0.09135218736316476, 0.12783203486885342, 0.15004926627235754, 0.22159965762070247, 0.11959335766732693, 0.20094530949635164, 0.27053478892360416, 0.20709894358047418, 0.14189186399536474, 0.11218686295407158], [0.04255063246403422, 0.1792556390698467, 0.05519903072022966, 0.10000985315335648, 0.05330308513449771, 0.08450224742825542, 0.03436127797301326, 0.02600480878858694, 0.03166443036336984, 0.04184330041919436, 0.0868027186287301, 0.08990070596337318, 0.09987892982150827, 0.06547517555632762, 0.14628559537231922, 0.0650873656517693, 0.19394635648599692, 0.35233139832104954, 11.651438559804644, 79.42738723754883, 46.197186265672954, 34.09836796351841, 26.744085380009242, 46.82885047367641, 18.58361199923924, 43.52439839499337, 25.427471229008265, 18.234214884894236, 55.88817582811628, 32.00798504693167, 17.074881894247874, 20.574736424854823, 27.492152759007045, 70.15790666852678, 35.944229875292095, 12.735904710633413, 18.02228614262172, 38.57266392026629, 47.79000868116106, 50.87499148505074, 36.958340304238455, 29.305080209459575, 53.77220964431763, 49.17773764474051, 47.712199279240195, 45.542033672332764, 19.37494581086295, 2.2420896674905504, 1.522055555667196, 1.7241677961179187, 1.7715498421873366, 9.84019865308489, 6.925157930169787, 8.975393721035548, 13.476543596812657, 20.22536884035383, 19.009513991219656, 14.214409283229283, 10.502934336662292, 13.545540077345711, 15.871174233300344, 11.478524821145193, 7.47233247756958, 18.07317474910191, 18.030561447143555, 3.811085190091814, 2.787560386317117, 1.353910235421998, 3.7527077283178056, 6.851332451616015, 5.411322202001299, 6.622832255704062, 2.41715452500752, 3.96819829089301, 1.3673073393957955, 0.5357296700988496, 0.05044233399842467, 0.6250991917082241, 4.472538062504359, 18.743689809526714, 32.003194264003206, 42.89150435583932, 39.611899035317556, 32.94057921000889, 39.79643971579415, 32.17984526497977, 27.790558780942643, 42.98178230013166, 32.379772731236045, 17.55499025753566, 5.098298907279968, 7.193192941801889, 3.8255270208631242, 15.117541347231183, 31.968442848750524, 33.360090596335276, 23.067020518439158, 14.238221628325325, 8.963223082678658, 6.057828196457454, 1.3177917620965411, 0.08197210569466863, 0.5977644356233733, 0.9490593309913362, 1.1674880044800895, 3.6813801271574835, 6.429763095719474, 6.7455300603594095, 19.503520488739014, 21.939541544233048, 15.185315813337054, 11.899620396750313, 9.063204186303274, 11.19153208392007, 11.948886598859515, 25.80850522858756, 9.661983438900538, 19.300511496407644, 19.37529148374285, 19.444167239325388, 19.23429342678615, 20.846669810158865, 23.033019508634293, 20.406437158584595, 18.552977391651698, 18.511190925325664, 14.70818475314549, 13.32382219178336, 26.4150447504861, 29.23821074622018, 15.54940663065229, 6.171237128121512, 2.2703228039400916, 3.183643315519605, 9.316568510872976, 41.0848719733102, 41.4512574332101, 52.63144745145525, 41.953188351222444, 40.568818841661724, 52.45964976719448, 53.50695868900844, 44.07154471533639, 59.52064541407994, 32.711556162152974, 29.739189761025564, 55.47877059664045, 63.920821462358745, 42.701950550079346, 42.71930020196097, 49.25912536893572, 12.465585912976946, 24.57034318787711, 7.487103479249137, 11.555628980909075, 19.022298676627024, 23.075936794281006, 52.71666363307408, 39.27638789585659, 20.792093447276525, 35.40458413532802, 37.76444946016584, 3.3063565364905765, 0.4481993040868214, 0.24046113980667932, 0.14673493483236857, 0.1721582713403872, 0.06042177921959332, 0.07422493890460048, 0.07658697358731713, 0.030307119446141378, 0.04622963237177048, 0.07471503796322004, 0.0879008054201092, 0.17051960927035126, 0.03816413427037852, 0.04000802943482995, 0.14186249699975761, 0.029430727008730173, 0.09045276883989573, 0.0352934799157083, 0.05702350621244737, 0.03766142463843737, 0.05764954976205315, 0.044116226490586996, 0.0076702463640166176, 0.024566938801269447, 0.07768315369529383, 0.0691786129027605, 0.09168238964463983, 0.11129056569188833, 0.12838008760341577, 0.11256414199514048, 0.5592351545180593, 14.79299793924604, 89.94494492667062, 52.38658945901053, 26.17160245350429, 20.410672085625784, 34.27947275979178, 23.135640927723475, 33.70287649972098, 16.21247843333653, 28.397497824260167, 46.04974896567208, 30.789785180773052, 26.849654572350637, 23.146646874291555, 28.13228334699358, 73.85491807120187, 43.68928609575544, 17.109909500394547, 18.66232292992728, 45.11430604117257, 54.951433590480256, 55.36464990888323, 35.327535561152864, 26.79251606123788, 60.757049560546875, 53.43323482785906, 52.877448422568186, 49.10421528135027, 23.29505865914481, 3.543648809194565, 3.7086353046553473, 1.1670777350664139, 6.135083045278277, 25.414764710835048, 18.000032799584524, 18.908478498458862, 17.89307049342564, 21.427124057497295, 18.768890925816127, 12.672639625413076, 11.429827502795629, 12.608138629368373, 17.47159797804696, 13.838707157543727, 11.314697589193072, 19.52402809688023, 17.30283144542149, 5.130685763699668, 5.949569616998945, 4.778569298131125, 7.476556113788059, 11.157034277915955, 11.116870215960912, 14.858898128782, 4.182595814977374, 6.733046318803515, 1.791458276765687, 0.4160096028021404, 0.21788086502679757, 0.9391769298485347, 10.589298708098275, 28.937464918409074, 33.47808143070766, 42.75351660592215, 46.295579705919536, 38.945761340005056, 42.09306948525565, 37.132872104644775, 35.20594208581107, 45.610146863119944, 38.35724197115217, 22.246466057641165, 10.375708477837698, 9.5558705500194, 11.95196725640978, 25.66039742742266, 41.90568699155535, 42.46797343662807, 28.271947349820817, 18.816423552376882, 16.249427216393606, 11.559070076261248, 6.074126499039786, 0.534454947071416, 0.32515083253383636, 0.9218973027808326, 0.2222298809460231, 5.133729074682508, 9.645935705729894, 9.597745605877467, 29.116132634026663, 22.74382332393101, 12.146931103297643, 9.383619495800563, 12.281540291649954, 14.955151523862567, 16.81766653060913, 28.62004862512861, 14.216311352593557, 20.469837733677455, 20.741175310952322, 18.638553142547607, 19.500397273472377, 21.775168010166713, 21.196749585015432, 19.00159478187561, 18.49904547418867, 17.124570199421473, 16.410100834710256, 23.289665119988577, 39.0256621497018, 35.411883217947825, 27.25659840447562, 14.622530835015432, 3.8793951017515997, 1.1870478349072593, 9.622562834194728, 42.848713874816895, 45.93197005135672, 56.225430965423584, 48.24947220938546, 44.81274380002703, 50.8932444027492, 56.36358894620623, 47.240770953042166, 61.09456525530134, 36.35610866546631, 31.02925831930978, 54.80829375130789, 68.45973219190324, 49.26018149512154, 39.439125129154746, 46.986199378967285, 19.53706465448652, 18.97269548688616, 10.341444305011205, 19.027893713542394, 21.291689770562307, 30.433186258588517, 48.61579860959734, 50.731806482587544, 23.956801618848527, 42.2605037008013, 48.004655906132285, 4.726981094905308, 0.3191164306231907, 0.13912471676511423, 0.08057485281356744, 0.044350422852273495, 0.13882985258741037, 0.048858857181455405, 0.037472096404859, 0.10411071524556194, 0.036743359972855875, 0.09090457138206277, 0.1124740189739636, 0.07724833488464355, 0.06961903641266481, 0.16605108976364136, 0.43024857874427525, 0.30343269077794893, 0.2049127308917897, 0.12354621770126478, 0.15561727035258496, 0.16605535096355847, 0.19891049154102802, 0.11018010242176907, 0.17618891862886293, 0.11102702269064528, 0.20593297614582948, 0.26348828417914255, 0.1391349762145962, 0.21573284028896264, 0.2981348793421473, 0.2908266500702926, 0.8150164208241871, 20.519597257886613, 100.8534846987043, 61.554299763270784, 47.51594393593924, 37.198546477726524, 61.39336558750698, 28.79535688672747, 66.50903933388847, 36.61831283569336, 28.21459518160139, 65.51803861345563, 41.996159485408235, 22.928657565798076, 24.473865713391984, 29.013323613575526, 82.75481006077358, 44.726603507995605, 17.91553749356951, 21.873384271349224, 48.11598341805594, 55.18199913842337, 62.76331411089216, 38.10299348831177, 31.592840603419713, 65.32905455998012, 56.27503762926374, 55.95913083212716, 51.76065404074532, 23.878000361578806, 8.737216421536036, 9.765661852700369, 2.52781566126006, 6.070385328360966, 18.548077174595424, 12.000533427510943, 15.736007452011108, 19.50816535949707, 30.595843587602886, 26.903886999402726, 18.0893623147692, 16.3537300995418, 17.64973415647234, 27.182612248829432, 18.296585389545985, 9.440330692699977, 26.389124495642527, 28.928102220807755, 9.499696969985962, 7.707047837121146, 5.867063232830592, 9.530513099261693, 12.073750938688006, 14.987101078033447, 24.956732511520386, 10.613645195960999, 12.833561641829354, 2.3018930298941473, 1.324065442596163, 0.389418005411114, 1.652819024665015, 13.65492730481284, 34.44214745930263, 32.45796775817871, 47.73834882463728, 46.42620931352888, 38.41804913112095, 42.26401948928833, 40.35005828312465, 45.32384286608015, 45.1152787889753, 44.97395242963518, 32.71440144947597, 18.92813321522304, 14.726830244064331, 22.204578842435563, 36.53526796613421, 43.4246952193124, 42.139073508126394, 25.310962097985403, 19.24198681967599, 17.138763632093156, 16.57906539099557, 8.326250450951711, 0.4733835927077702, 2.374599631343569, 2.8852689947400774, 2.1662796097142354, 23.35992530414036, 16.18505563054766, 13.681705662182399, 31.002045699528285, 30.41364097595215, 21.23246853692191, 14.845036472593035, 15.38585819516863, 19.89827196938651, 21.769039699009486, 37.22190979548863, 13.354010377611433, 26.741130658558436, 25.86832400730678, 26.60723192351205, 26.618159702845983, 25.35122343472072, 28.608344384602137, 26.966264452253068, 23.55341352735247, 21.539577177592687, 19.384581225258962, 20.08080635751997, 32.531323364802766, 32.70890195029122, 25.164240462439402, 11.804338012422834, 6.111902986254011, 6.569201282092503, 13.06502958706447, 48.35911478315081, 47.91030631746565, 61.80808271680559, 50.21179287774222, 46.81997067587716, 56.86045810154506, 61.381366048540386, 46.520756925855366, 68.45196410587856, 39.312188489096506, 37.96016979217529, 65.30550711495536, 75.58988325936454, 50.21146283830915, 48.982621806008474, 58.575058119637625, 18.001458917345317, 33.6559032031468, 14.202004143169948, 21.436564922332764, 32.308348723820274, 37.8130555834089, 67.04706614358085, 51.55175297600882, 32.884715693337576, 52.02012756892613, 64.65117440904889, 9.913425718035016, 0.7121128940156528, 0.42149344139865463, 0.3316703327000141, 0.29491210941757473, 0.21266958037657396, 0.2233039883098432, 0.10804351778434855, 0.22173445538750716, 0.17581854707428388, 0.2151294190968786, 0.2894234396517277, 0.22577800841203757, 0.1288804800382682], [0.0442245138942131, 0.06303186594907727, 0.1960236235920872, 0.026892883902681724, 0.011525476234965026, 0.06581972206809691, 0.007391609351283738, 0.021235170707638775, 0.061892381736210415, 0.05725083579974515, 0.04525386169552803, 0.03571625133710248, 0.04804814014849918, 0.05577409254120929, 0.12024458843682494, 0.01876507593052728, 0.11870930796223027, 0.05345332296565175, 1.022071436047554, 63.14713954925537, 57.967764718191965, 41.96514967509678, 77.9657780783517, 64.46458748408726, 49.087918281555176, 58.176679679325645, 49.195320061274934, 18.772137471607753, 39.642530168805806, 40.38762024470738, 15.650297948292323, 52.592040743146626, 61.20517362867083, 66.66652025495256, 53.42011315482003, 40.07041760853359, 21.728014060429164, 23.993529796600342, 50.62065267562866, 48.521612303597585, 55.28172663279942, 26.249922548021587, 48.54130349840437, 50.44282395499093, 41.0814882005964, 30.792835439954484, 9.566193836075918, 0.9868214875459671, 5.483907861368997, 1.985675300870623, 8.378519143377032, 11.50712708064488, 12.940701127052307, 15.358819280351911, 19.284977061407908, 19.910066536494664, 15.988725594111852, 12.334426505225045, 12.971808212144033, 13.965827924864632, 19.796750102724346, 17.397465910230363, 12.212175556591578, 4.383757455008371, 9.823596801076617, 9.618591938699995, 4.795092114380427, 2.6918671897479465, 3.6461028201239447, 11.320431590080261, 9.657934376171657, 12.456800784383502, 1.0169525678668703, 3.1729148626327515, 1.2914206343037742, 0.4986582079104015, 0.446044711130006, 0.16276543321354048, 2.6831278758389607, 13.74691103185926, 39.719158376966206, 42.825142111097065, 49.040180683135986, 37.409111636025564, 38.739382471357075, 34.02598510469709, 23.571715082441056, 41.23970215661185, 35.73235150745937, 17.434704780578613, 10.021106294223241, 5.267613913331713, 5.887378028460911, 11.59147560596466, 18.686313322612218, 22.091641085488455, 14.243461438587733, 7.209864275796073, 4.2470685839653015, 0.29000003156917437, 1.8970929341656821, 0.20682299695909023, 0.4514780395797321, 0.7557806936757905, 1.2435762073312486, 5.030834938798632, 5.185137059007372, 7.79198522227151, 24.97883473123823, 17.51693844795227, 15.847350597381592, 18.764320748192922, 15.479870796203613, 23.03613577570234, 21.80882682119097, 9.136586717196874, 11.427429505756923, 20.58183922086443, 19.24655178615025, 21.319659743990215, 22.129218680518015, 18.907554388046265, 22.547286578587123, 24.818171535219463, 19.372717176164898, 20.023999622889928, 17.78272615160261, 21.304715905870708, 17.088901621954783, 24.453095810753958, 15.685987370354788, 5.999904104641505, 6.735523785863604, 0.7109387027365821, 4.312064204897199, 39.63248654774257, 44.39664050510952, 47.55275896617344, 36.28589711870466, 58.57466902051653, 48.68875469480242, 50.46562099456787, 50.624314376286094, 54.569168022700715, 39.52990334374564, 53.14109781810215, 53.62877798080444, 50.75562143325806, 45.083226748875205, 58.90919004167829, 21.825776951653616, 15.297546591077532, 21.480017219270977, 11.388370207377843, 13.732375400406973, 33.90158803122384, 27.79706229482378, 61.96311787196568, 35.86034427370344, 35.59656286239624, 36.53786311830793, 24.616185665130615, 0.2897474265524319, 0.0990095975409661, 0.08501135903809752, 0.029516829709921564, 0.03206225544480341, 0.0302726193331182, 0.052599240759653706, 0.06082845239767006, 0.09271974076649972, 0.09577732812613249, 0.06393983401358128, 0.028469127536352192, 0.06631009254072394, 0.11346208131206886, 0.04746620137510555, 0.07394322473555803, 0.04318785827074732, 0.014462151198780962, 0.04909217484029276, 0.055307908449321985, 0.11800747205104146, 0.01990324378545795, 0.032505545765161514, 0.031130077250834023, 0.03425439513687577, 0.09452951579753842, 0.029246355473463024, 0.11523436728332724, 0.13441587372549943, 0.01275203684677503, 0.22219322648431572, 0.15530145301350526, 1.4138520189693995, 68.44313294546944, 68.22393117632184, 41.7621545791626, 84.0391011919294, 64.69516345432827, 42.718414306640625, 49.30428865977696, 24.17385813168117, 26.971654517310007, 49.16822208677019, 35.431939193180625, 25.074335983821324, 45.06756550925118, 53.621114117758616, 70.98140716552734, 54.337157249450684, 39.98871374130249, 23.683332681655884, 28.439755031040736, 53.514626026153564, 53.183606897081646, 52.97779778071812, 24.995677164622716, 55.387756143297466, 52.292104380471365, 48.30188594545637, 36.581317152295796, 14.849547590528216, 2.331494527203696, 1.8966627972466605, 5.270072272845677, 24.026631014687673, 24.318939992359706, 21.199329103742325, 19.775756120681763, 21.336378846849712, 21.975953578948975, 15.661585296903338, 12.995743887765066, 12.412198560578481, 11.922492129462105, 20.24412897654942, 17.105546031679424, 13.33323005267552, 7.794711521693638, 16.036774124417985, 13.405321087156024, 3.17951261145728, 4.815820327826908, 8.032512749944415, 16.259767872946604, 16.200600487845286, 22.526563576289586, 4.967777865273612, 6.1341880304472785, 2.680942233119692, 0.5151226701481002, 0.3894239765192781, 0.37175147767577854, 7.738314730780465, 29.135598012379237, 40.920488016945974, 36.75171477454049, 46.24893992287772, 39.205794198172434, 43.4808783531189, 41.29901197978428, 33.630240031651084, 46.88275112424578, 42.914958000183105, 25.024698053087505, 15.799816233771187, 11.436074801853724, 11.025502273014613, 21.70363109452384, 34.162374768938335, 31.02353995186942, 21.7214549609593, 15.786998544420515, 8.687971064022609, 7.25998250075749, 4.569134524890354, 0.5034701068486486, 0.2767476455441543, 1.1120976167065757, 0.8383932007210595, 5.841610244342259, 10.084767426763262, 8.774271164621625, 34.32968044281006, 21.25439010347639, 11.13791022981916, 9.913370132446289, 20.13405908857073, 29.51561062676566, 27.56372094154358, 12.842313766479492, 11.72622983796256, 20.30168785367693, 18.318861314228602, 20.81170473779951, 22.126319544655935, 19.561456305640085, 23.113083600997925, 23.953706196376256, 19.190639632088796, 19.110570328576223, 17.639103412628174, 22.44411972590855, 27.369242600032262, 37.26209817613874, 23.219955580575125, 18.056354897362844, 16.36780193873814, 2.7192142137459347, 1.622686967253685, 40.10371337618147, 47.05791173662458, 53.27647304534912, 47.38988276890346, 58.73227500915527, 50.77741098403931, 54.26559427806309, 56.92102207456316, 54.80722720282418, 47.03475686482021, 54.33677509852818, 55.3989496912275, 51.2604011126927, 54.05437251499721, 51.736474309648784, 32.303471088409424, 19.549567937850952, 10.872118183544703, 21.024783406938823, 16.833973952702113, 36.02030570166451, 29.973340579441615, 59.105587823050364, 48.62783636365618, 38.827430043901714, 49.86645351137434, 31.924387795584543, 0.34259273803659845, 0.06550553321306195, 0.10779710100697619, 0.06933284391249929, 0.014971067729805197, 0.037063631894333024, 0.01149881913858865, 0.007696401344479195, 0.04959948154698525, 0.04392054716923407, 0.05255077978862183, 0.04069772296186004, 0.10376382778797831, 0.20453579111823014, 0.1472493050886052, 0.20707294211855956, 0.3698175443070275, 0.10289896026785884, 0.13457467806126389, 0.1616942435503006, 0.35718824341893196, 0.09013509231486491, 0.14200541004538536, 0.1547358940754618, 0.11420804235552039, 0.1387855035385915, 0.10040611760424716, 0.2111370683248554, 0.27583037476454464, 0.07428975256958179, 0.32942400180867737, 0.2346980704792908, 2.4064788350037167, 87.80637972695487, 73.0135954448155, 58.48319598606655, 84.40980843135289, 83.37589563642229, 62.0853853225708, 78.57446111951555, 64.10330200195312, 28.11410685947963, 49.23661320550101, 54.16980293818882, 20.440646614347184, 65.23017474583217, 66.04084192003522, 78.46106651851109, 62.50304848807198, 45.49238531930106, 27.13575186048235, 33.605476651872905, 57.91758482796805, 57.89173058101109, 60.29139518737793, 30.454576287950786, 58.16617400305611, 57.26071602957589, 46.922998564583914, 38.77837923594883, 15.084869180406843, 5.726218470505305, 11.023568936756678, 5.625454391751971, 16.629165376935685, 19.522240672792705, 20.612095151628765, 24.921176842280797, 28.277969700949534, 28.795197078159877, 19.347241606031144, 15.878422941480364, 18.12145778111049, 19.443161487579346, 28.772061313901627, 25.50568883759635, 17.911491904939922, 9.765404769352504, 16.178743192127772, 20.903916018349783, 8.849570529801504, 5.01544337613242, 8.931320428848267, 20.32464643887111, 22.297641277313232, 25.475379058292933, 12.583647097860064, 11.276981030191694, 4.67807229076113, 1.4615479281970432, 0.661154534135546, 0.40665778890252113, 9.174833944865636, 36.799605233328684, 49.101112910679404, 43.90558351789202, 52.479525089263916, 40.15579012462071, 44.202768393925254, 43.033046109335764, 39.912148066929404, 50.583479813167024, 48.52689640862601, 36.62086282457624, 26.90360733440944, 22.616419417517527, 23.217959710529872, 31.573361328669957, 38.833426339285715, 31.003682000296457, 23.787930863244192, 12.600302798407418, 6.622711965015956, 6.56008871964046, 4.455157143729074, 0.5104852361338479, 1.030808144382068, 1.7648008614778519, 3.01410488145692, 20.497620105743408, 15.886508907590594, 15.830178124564034, 33.051184109279085, 22.742744616099767, 23.36186385154724, 27.650498730795725, 21.031170538493566, 30.933810915265763, 29.261581012180873, 14.120651159967695, 19.13712634359087, 28.885393381118774, 23.04887877191816, 26.558707441602433, 28.12754120145525, 26.6856301852635, 28.48750478880746, 31.565221514020646, 25.275673934391566, 27.468365601130895, 22.7361855166299, 26.45797766957964, 22.853851522718156, 32.572553975241526, 19.91592734200614, 15.265303475516182, 12.467163154057094, 3.8479275788579668, 7.415053265435355, 44.807911327907014, 47.880161557878765, 57.99239608219692, 45.014394419533865, 59.599889619009836, 55.7686424936567, 58.14283847808838, 58.523863792419434, 59.6201297215053, 49.544546944754465, 62.1491767338344, 61.39697865077427, 57.5145754132952, 54.941400391714915, 65.98481859479631, 33.3161050251552, 21.7250645501273, 30.977511610303605, 18.082996027810232, 23.554139614105225, 52.218734877450125, 43.39419262749808, 74.09066350119454, 52.39999600819179, 46.63952595846993, 59.272323744637625, 46.48964984076363, 0.6319557609302657, 0.18562255028103078, 0.23950163700750896, 0.18180804353739533, 0.08459614310413599, 0.12072480124022279, 0.12497423536011151, 0.1997090322630746, 0.07265197259507009, 0.11917025037109852, 0.10691073749746595, 0.07594084540115935, 0.28771738548363957, 0.44965677016547745], [0.07486928254365921, 0.0911819768537368, 0.13382242699818953, 0.06331678280340773, 0.04714415169187954, 0.068918910409723, 0.10041301830538682, 0.11456024274230003, 0.07189178267227751, 0.02604682367694165, 0.04065208469650575, 0.04430723749101162, 0.011318924238107033, 0.014048939487630767, 0.07504943359111037, 0.10025700274854898, 0.10324962038014616, 0.06514164166791098, 0.47592815331050325, 20.726405177797588, 72.42863355364118, 35.62475865227835, 51.61207028797695, 78.07264832087925, 64.93864917755127, 81.69387572152274, 51.5546156338283, 11.375019243785314, 6.814391485282353, 37.02984421593802, 23.384843281337194, 45.55647202900478, 64.61746174948556, 51.155566692352295, 69.06995078495571, 63.91424151829311, 37.86527476991926, 13.57813320841108, 59.233392987932476, 54.553381715502056, 74.19415691920689, 63.55488763536726, 36.24890490940639, 58.01686416353498, 37.033554553985596, 20.95695161819458, 21.609752246311732, 3.512083794389452, 1.7303083751882826, 5.796997598239353, 14.460508397647313, 16.02312786238534, 17.027512550354004, 21.227116686957224, 23.081107991082327, 21.517886638641357, 20.791184970310756, 16.096702337265015, 13.517965282712664, 14.049499000821795, 17.318999903542654, 17.597044229507446, 15.25605194909232, 7.213819103581565, 1.8800581225327082, 4.988268971443176, 10.998989684241158, 4.9100682990891595, 10.412627731050764, 16.068855694362096, 12.618543556758336, 16.579800162996563, 2.240584296839578, 5.614261712346758, 2.49854268346514, 0.5313513821789196, 0.5338011107274464, 0.09368483469422374, 0.8065130742532867, 5.86023793050221, 18.868522882461548, 35.23713602338518, 48.96641860689436, 41.0010141645159, 30.62111071177891, 25.78070374897548, 25.628371443067277, 30.22805459158761, 33.35502883366176, 16.831842592784337, 13.684358136994497, 10.790977988924299, 7.088384142943791, 5.954864578587668, 10.951564754758563, 11.848341822624207, 7.44546639919281, 5.293820347104754, 1.3877881318330765, 0.3055353622351374, 2.7355741815907613, 0.4510239368038518, 0.29219631371753557, 1.0928568605865752, 2.9899027858461653, 3.4904989983354295, 8.880100914410182, 8.866551058632986, 26.944791044507706, 29.720975058419363, 29.37651811327253, 7.443381939615522, 2.2050505578517914, 9.541654535702296, 6.709410718509129, 4.178667477199009, 9.951011998312813, 16.408481904438563, 19.081118651798793, 18.817669016974314, 18.674254723957606, 21.57263844353812, 19.64901750428336, 23.626131636755808, 24.96257073538644, 21.220361300877162, 19.196274621146067, 18.847711290631974, 22.083379677363805, 22.038218123572214, 38.83288785389492, 15.17415005820138, 5.93983301946095, 4.5237792900630405, 0.2232126710670335, 25.22761150768825, 55.65455307279314, 27.1246851171766, 38.43087203162057, 72.35684476579938, 58.075090067727224, 47.19675758906773, 46.02720206124442, 53.631171635219026, 52.866230555943076, 56.367417403629844, 54.56201832635062, 36.71958630425589, 44.29596110752651, 60.933200291224885, 13.921636513301305, 24.218672275543213, 25.57448468889509, 10.581622685704913, 33.08271156038557, 22.164505107062205, 50.71557896477835, 60.39636857169015, 33.960842268807546, 39.945277077811106, 49.8132963180542, 8.416590060506548, 0.14520566617803915, 0.04862312733062676, 0.08436719181814364, 0.052322232230965576, 0.09757827541657857, 0.014261301440585936, 0.04255516168528369, 0.030506744448627745, 0.13412935552852495, 0.057944033960146565, 0.14119373288537773, 0.03319648779662592, 0.03367234779787915, 0.17916965511228355, 0.08304569737187453, 0.09229805839381047, 0.09207998402416706, 0.020128593746838824, 0.11757642589509487, 0.002284695685375482, 0.07764255015977792, 0.05701670050621033, 0.06742696118141923, 0.04488062672317028, 0.11270552833697625, 0.010434711684605904, 0.05524324745471988, 0.0601921086864812, 0.12763730888920172, 0.10340566307838474, 0.2111276774001973, 0.002658958002159904, 0.5547287591866085, 25.818606172289165, 82.84392765590123, 42.15032264164516, 59.26418045588902, 85.54801368713379, 64.0902532849993, 88.98832389286586, 62.768198694501606, 31.42891522816249, 20.484653030123027, 33.99121631894793, 29.11124631336757, 49.534631865365164, 63.867605209350586, 60.008735520499094, 62.866751943315776, 58.583514077322825, 43.085887159620015, 16.306082827704294, 56.39982380185808, 62.045447077069966, 61.620099203927175, 53.3616475377764, 46.08367007119315, 61.18022264753069, 39.68389279501778, 24.4526789188385, 20.064413819994243, 1.5609346351453235, 4.7046031185558865, 20.208331857408794, 26.51929031099592, 23.035986389432633, 21.409663234438213, 20.89502058710371, 24.44293233326503, 20.207864591053553, 21.967098099844797, 15.970561265945435, 12.95016370500837, 12.801347187587194, 18.277922528130667, 19.018894059317454, 15.765379224504743, 8.990963765553065, 3.82087824174336, 14.337251697267805, 11.35829406125205, 5.933345573289054, 15.219573906489781, 19.46613918031965, 19.50577344213213, 26.69619492122105, 7.538931829588754, 7.006961677755628, 2.391391473157065, 0.428184122379337, 0.05521422651197229, 0.09402075024055583, 3.123874259846551, 18.98252718789237, 42.30150154658726, 43.4967098236084, 50.48375579289028, 42.3407484463283, 38.97420726503645, 36.0438357761928, 31.881281171526226, 42.09890944617135, 42.318931102752686, 27.113413402012416, 23.171087162835256, 15.19737788609096, 13.808024781090872, 16.34572230066572, 16.649365527289255, 17.848195552825928, 14.975113698414393, 9.65472604547228, 2.8076028994151523, 2.505963359560285, 2.968507979597364, 0.3422646256429808, 0.3910058859203543, 0.5444566075290952, 2.1952829105513434, 11.170946308544703, 15.121783222470965, 8.425808582987104, 37.316526889801025, 25.26475136620658, 30.55883400780814, 15.499473401478358, 10.073395831244332, 15.134434155055455, 8.039380175726754, 5.662866532802582, 7.310438581875392, 14.272311227662222, 19.31875572885786, 19.65940679822649, 19.20542539869036, 20.708702904837473, 20.32904291152954, 22.737340654645646, 23.768389054707118, 18.771684101649694, 16.888579845428467, 18.93246715409415, 19.030144929885864, 30.191857951028005, 47.215851238795686, 21.14791590826852, 15.834843839917864, 11.239397355488368, 0.32965193529214176, 21.21765497752598, 57.05920089994158, 30.221516336713517, 45.71739925657, 69.4446462903704, 62.45478630065918, 52.919026442936485, 52.10979059764317, 53.94109255926949, 58.521404130118235, 58.319294929504395, 58.59880011422293, 41.054536138262065, 49.11768783841814, 57.33948080880301, 26.104397739682877, 14.528952496392385, 24.174754449299403, 15.873555728367396, 31.05210052217756, 30.608524050031388, 40.92134959357125, 64.93727343423026, 39.79613399505615, 42.90596355710711, 60.50785936628069, 11.987548981394086, 0.38309069350361824, 0.07118474239749567, 0.07558270104761634, 0.024695098799254214, 0.12288643739053182, 0.023166047276130745, 0.03194752195850015, 0.05013777016262923, 0.04883696424907871, 0.09645846871925251, 0.023641099820711782, 0.04151855695194431, 0.12887986935675144, 0.07809456304780074, 0.25773620711905615, 0.36040862490023884, 0.18170068572674478, 0.08621735325349228, 0.24032567707555635, 0.1106275012716651, 0.18585429713129997, 0.20635187652494225, 0.21350405631320818, 0.13446927443146706, 0.1967962578471218, 0.10694114265165158, 0.21891739512128489, 0.1447594886911767, 0.25385042705706184, 0.3007495733244078, 0.38734217679926325, 0.17944670096039772, 0.8198214801294463, 40.878607749938965, 93.08653817858014, 51.64527920314244, 64.6872980935233, 84.19053718021938, 80.94810472215924, 89.86342866080147, 69.96782479967389, 20.506784779684885, 12.116488439696175, 48.681754384722026, 30.31470557621547, 55.657308033534456, 72.88103076389858, 62.282429286411826, 77.17004258292062, 74.46227400643485, 46.64332662309919, 17.607237236840383, 64.77030127389091, 64.89796747480119, 78.3347065789359, 70.33859457288469, 48.218340805598665, 67.34565108163017, 42.90486921582903, 27.950249229158672, 28.957031045641216, 6.744436587606158, 8.764082499912806, 11.571935534477234, 21.347138132367814, 23.288575989859446, 27.432686601366314, 28.00640457017081, 32.51685721533639, 26.352907010487147, 26.42354760851179, 21.475198643548147, 19.057515621185303, 20.548904759543284, 25.25692422049386, 24.395592519215175, 21.43275383540562, 12.35995158127376, 4.557119786739349, 11.859883649008614, 22.05062586920602, 8.278149809156146, 16.863707031522477, 26.192370619092667, 22.968665293284825, 32.74163143975394, 13.695230330739703, 14.512537377221243, 8.725181273051671, 1.1620965280703135, 0.6948859212653977, 0.11271567922085524, 3.3466969089848653, 15.83500017438616, 38.44389295578003, 45.07409681592669, 51.497202668871196, 41.01412541525704, 39.10250922611782, 43.3170120375497, 40.0813228062221, 45.53471027101789, 45.65938874653408, 34.916716371263774, 33.81889404569353, 27.609283753803798, 24.005124602999004, 28.668187482016428, 24.389227969305857, 26.871793270111084, 18.21318789890834, 9.690276503562927, 1.7425094119140079, 1.7627127106700624, 5.384254625865391, 1.3165745245558875, 1.5687668834413802, 1.5424570952142989, 3.827165492943355, 25.6309301171984, 24.255046095166886, 15.614415713718959, 38.96119328907558, 38.87727642059326, 39.73682417188372, 14.335638846669879, 7.004852030958448, 14.08423478262765, 12.47573288849422, 12.1520163161414, 19.914676666259766, 24.695395129067556, 26.073617219924927, 21.962255205426896, 21.97392123086112, 29.15677785873413, 29.392068181719097, 28.66667972292219, 30.84853219985962, 25.447032145091466, 26.018771614347184, 23.153159073420934, 26.606641326631816, 24.738691091537476, 47.93748072215489, 19.699016741343907, 12.597162212644305, 7.576323560306004, 0.6916781876768384, 29.44881064551217, 62.12699113573347, 33.5565960747855, 44.47339725494385, 72.82255472455705, 62.7462215423584, 55.159209047045024, 54.384491852351594, 61.15641117095947, 63.00429848262242, 66.91518933432442, 63.0226834160941, 44.96096624646868, 53.12302902766636, 69.2849349975586, 23.299479450498307, 33.16567652566092, 36.82445199148995, 14.938611337116786, 51.83921037401472, 36.02318572998047, 64.80124855041504, 71.62597070421491, 48.058577401297434, 49.43763501303536, 77.10973221915108, 17.40636134147644, 0.6642922971929822, 0.24274115317634173, 0.29920693753021105, 0.08504960805709873, 0.20841629217777932, 0.25874660004462513, 0.22773448271410807, 0.2261005432478019, 0.23186600101845606, 0.23258584524903977, 0.2863946764596871, 0.18218490188675268, 0.17105665616691113, 0.33863905018993784], [0.045192712119647434, 0.15099948671247276, 0.08700830795403038, 0.0720392893999815, 0.05552929067718131, 0.03419127780944109, 0.032496151447828324, 0.08177426523928132, 0.02677578741817602, 0.14494679149772438, 0.03093692207975047, 0.056658186351082156, 0.033292222302407026, 0.003535708790877834, 0.06325827272874968, 0.08351048707429852, 0.07516411279461213, 0.09457075715597187, 0.05900216182427747, 1.3884889228003365, 59.4395112991333, 60.58719389779227, 37.29330253601074, 42.576931612832205, 58.3386595589774, 40.923517431531636, 32.15397712162563, 9.111339569091797, 26.872868503843033, 35.87553650992257, 31.736074243273052, 22.708813088280813, 63.275306020464214, 58.13300330298287, 62.92550591060093, 57.22687830243792, 58.002835750579834, 26.351255076272146, 36.51164756502424, 63.26831613268171, 66.45200851985386, 76.13225964137486, 37.74494934082031, 51.11206749507359, 42.280531883239746, 36.98429182597569, 7.888694592884608, 2.2699623661381856, 1.9675211778708865, 9.289468799318586, 22.060412406921387, 17.10517951420375, 20.584927695138113, 21.52666916166033, 23.076800107955933, 23.51149504525321, 19.17055412701198, 17.298023291996547, 13.078969410487584, 13.849314451217651, 20.52313562801906, 20.45089520726885, 15.33500259263175, 9.790581566946846, 7.248045061315809, 2.776299310582025, 8.26982499871935, 9.098887528691973, 11.802920579910278, 17.543661219733103, 19.817843096596853, 22.686500685555593, 5.377338996955326, 7.702254448618207, 3.8106305173465183, 0.30396067244665964, 0.4513096000467028, 0.3441642251397882, 0.9104690902999469, 5.470223818506513, 16.549792630331858, 33.96169689723423, 42.87217099325997, 31.092448711395264, 22.122822863715037, 19.155829157148087, 23.343053340911865, 29.240124974931987, 29.66763026373727, 19.02249148913792, 14.61354855128697, 9.434134636606489, 6.922022121293204, 6.123685394014631, 11.252209833690099, 10.418737803186689, 5.080980088029589, 3.5009740591049194, 0.49257088026830126, 0.5613734083516257, 0.957077117902892, 0.0774529403341668, 0.06984800126935754, 0.7863524417792047, 1.048923835158348, 7.184371769428253, 13.339876873152596, 11.1693160874503, 28.32288806779044, 28.58382592882429, 8.252896581377302, 4.892392516136169, 9.113177367619105, 11.325733065605164, 12.180626392364502, 8.632233483450753, 7.393915108272007, 15.346635614122663, 16.515390362058366, 20.549776758466447, 22.352092572620936, 21.460128000804357, 21.867506095341273, 21.1518885408129, 24.081797974450247, 23.03535236631121, 22.802431379045757, 21.620954479490006, 25.08249143191746, 19.032786982400076, 20.982897928782872, 43.62136050633022, 17.18292464528765, 8.130326884133474, 0.5046467408537865, 1.839240278516497, 50.60285833903721, 19.70400381088257, 29.551498072487966, 65.77750519343785, 51.45462758200509, 52.01939105987549, 54.17910657610212, 51.71734939302717, 50.10734755652291, 51.90888690948486, 49.30145032065255, 34.8203934941973, 54.38377618789673, 44.008816378457205, 10.071154168673925, 29.535406044551305, 9.151923997061592, 17.070431573050364, 28.94079484258379, 32.87953928538731, 63.63566739218575, 44.12230478014265, 29.502217973981583, 45.981906754629954, 25.851525000163488, 0.19022935522454126, 0.03933172340371779, 0.03750162285619548, 0.03865908485438142, 0.03466545165117298, 0.03202374518982001, 0.014336459371926529, 0.14667079970240593, 0.07209293437855584, 0.11265434644051961, 0.09750896306442362, 0.009486825404954808, 0.031698034810168405, 0.02281215224814202, 0.03428967556517039, 0.12524688430130482, 0.05964322813919612, 0.07349297603858368, 0.04717091650569013, 0.08976885982389961, 0.03994398929976991, 0.019226131994011145, 0.0902325910116945, 0.06330885751438992, 0.03296024565185819, 0.06519565984074559, 0.034515397024473975, 0.041364173271826336, 0.040779421970780404, 0.11301618880991425, 0.20783005149236747, 0.030558879686785594, 0.045296633150428534, 0.21230500351105416, 2.6681792608329227, 70.80488818032401, 68.01397051130022, 35.760721002306255, 46.48834357942854, 57.91113689967564, 46.110458850860596, 51.54296350479126, 17.06599862234933, 32.23148080280849, 36.06870337894985, 33.34620809555054, 32.93204682213919, 67.2341672352382, 64.47586441040039, 65.46699714660645, 60.5491247177124, 60.652826581682476, 29.875186852046422, 39.342156069619314, 65.76085036141532, 62.32384055001395, 66.24527181897844, 43.74590696607317, 56.59844153267996, 46.04391942705427, 39.5343918800354, 7.286434292793274, 0.7512469940951892, 11.211763501167297, 18.351417098726543, 32.89033331189837, 23.982506479535783, 20.858721460614884, 21.19987280028207, 21.562306472233363, 21.512784923825944, 17.21505832672119, 15.80230368886675, 11.598642672811236, 12.859969139099121, 20.01332892690386, 21.267379760742188, 14.540799174989973, 10.937009147235326, 8.27537226676941, 5.051090240478516, 13.657043031283788, 10.564710770334516, 15.056852306638445, 21.97609601702009, 25.953041655676707, 32.07143599646432, 9.55891820362636, 9.74300377709525, 1.9148523126329695, 0.45834866804736, 0.20080805543277944, 0.21918293301548275, 1.3388848645346505, 11.141174146107264, 27.002831084387644, 42.95937783377511, 48.56969731194632, 38.05367170061384, 29.94905662536621, 29.199363367898123, 30.143581867218018, 41.543105670383994, 38.51444149017334, 27.143526894705637, 25.88623125212533, 17.013756854193552, 13.65084958076477, 11.0273756810597, 14.13026920386723, 15.423607758113317, 9.958120005471365, 5.26311582326889, 0.8426842561789921, 1.5171820457492555, 0.6231533704059464, 0.5016294856156621, 0.4292730082358633, 1.296979627438954, 0.8588909836752074, 17.29748480660575, 17.932666540145874, 9.413541044507708, 34.949233940669465, 28.5265953540802, 12.53014075756073, 9.06311559677124, 14.841485943113055, 20.30475548335484, 18.931457928248815, 9.870491930416652, 8.564081209046499, 12.180060114179339, 18.31835756983076, 20.793978146144322, 21.55555977140154, 19.15719621522086, 21.77988236291068, 21.769515650612966, 22.560757398605347, 21.128405366625103, 20.060524565832957, 18.79906347819737, 16.120437383651733, 9.852592502321516, 26.031624044690812, 45.392216614314485, 19.5539105619703, 18.265804869788035, 2.759772368839809, 0.30843696796468323, 53.935659067971365, 23.40949375288827, 26.41588200841631, 64.85489559173584, 52.749469552721294, 53.439818246024, 54.91418777193342, 56.32751389912197, 54.247942379542756, 57.18257311412266, 55.37587124960763, 42.40050295421055, 54.226555824279785, 51.97651025227138, 16.44293107305254, 16.57663004738944, 11.975055251802717, 8.865409817014422, 27.82654176439558, 33.24202333177839, 58.189141273498535, 53.64761107308524, 31.728525025503977, 52.166025842939106, 31.011866978236608, 0.3702527295265879, 0.0066349533236851645, 0.08816912530788354, 0.033326284760343175, 0.04957056577716555, 0.03919518519459026, 0.06839245544480425, 0.048389463618929894, 0.06372192927769252, 0.05267593896548663, 0.036951982349689515, 0.04077057048146214, 0.05296082867841635, 0.04187171407310026, 0.001745238505204075, 0.32492417469620705, 0.26772511111838476, 0.15732754500848906, 0.14115397073328495, 0.16243974997528962, 0.22445703643773282, 0.11595522931643895, 0.19279026852122375, 0.1864435233707939, 0.16692437790334225, 0.1011970451633845, 0.1884710674307176, 0.140883845942361, 0.08155093222324337, 0.20738989939647062, 0.28301939900432316, 0.15729789302817412, 0.21883101761341095, 0.47069740827594486, 5.059536210128239, 90.4056452342442, 75.58816010611397, 55.10872343608311, 52.9823488507952, 71.00866494859967, 47.75221742902483, 43.97085836955479, 12.830998625074114, 33.841440950121196, 50.675029277801514, 38.20640352794102, 28.786265168871196, 73.77092824663434, 66.06434072766984, 74.72873742239815, 68.59946046556745, 68.9193833214896, 31.801488058907644, 42.66023703983852, 70.36939593723842, 73.68355464935303, 80.86549064091274, 44.5639774458749, 58.14256749834333, 48.71307338987078, 46.123653479984824, 14.17506684575762, 7.2048863257680615, 4.628906403269086, 14.351468580109731, 36.44129705429077, 29.24551330293928, 30.16969667162214, 30.413036482674734, 30.989424296787806, 27.059279986790248, 22.51343842915126, 22.42962404659816, 18.078245197023662, 17.796829257692607, 28.724931682859147, 28.50022346632821, 23.213978392737253, 15.201263666152954, 13.234909568514142, 5.1041353940963745, 17.21425928388323, 16.084928614752634, 17.666896206992014, 30.160281862531388, 31.97294180733817, 41.24047688075474, 14.152847375188555, 19.301908084324428, 12.335615515708923, 0.8589568829962185, 0.41535687925560133, 0.46952815673180986, 1.5943942282881056, 13.803623097283499, 29.845292227608816, 44.96529844829014, 49.31164680208479, 38.290674754551475, 32.8823150907244, 38.462840693337576, 38.144821643829346, 49.3430735043117, 44.903612341199604, 36.58001783915928, 35.39739274978638, 30.621475492204937, 26.132836716515676, 23.261149712971278, 22.908035312380107, 23.012265239443096, 12.908984337534223, 5.845203331538609, 0.3840994308037417, 1.925730368920735, 2.691042525427682, 1.5847614194665636, 1.0529709437063761, 3.3676843770912717, 10.180890543120247, 26.966413838522776, 27.87675986971174, 16.85783232961382, 42.902729170663015, 41.896122796194895, 11.78258320263454, 7.451440981456211, 16.4488422530038, 19.332506213869365, 25.691966567720684, 19.28804121698652, 19.059860638209752, 23.909911700657435, 23.49144775526864, 26.099754605974468, 27.374205350875854, 25.598383017948695, 29.597314493996755, 28.18308857509068, 29.77115842274257, 28.375319174357823, 28.638159104755946, 29.098147221973964, 32.30208839688982, 24.154392753328594, 24.19771477154323, 51.255526951381135, 20.237792219434464, 15.262550251824514, 1.148653826543263, 2.1981807436261858, 64.02921336037772, 24.330446209226334, 34.329531056540354, 70.28667763301304, 53.54835605621338, 58.11063357761928, 59.231016704014365, 59.29449544634138, 58.631741523742676, 59.89944035666329, 58.24297939028059, 45.10404355185372, 62.91442353384835, 56.6564485686166, 15.598888226917811, 41.01802682876587, 14.257988384791783, 27.004291943141393, 40.51804140635899, 47.59131104605538, 75.6624641418457, 58.1332117489406, 40.91483565739223, 62.449936458042686, 46.62933642523629, 0.7134313689810889, 0.11269436643591949, 0.1876152583530971, 0.12898582938526357, 0.2231816348752805, 0.12629238462873868, 0.1724372442279543, 0.15280535338180407, 0.1737880174602781, 0.21372326383633272, 0.2025248711662633, 0.10451465392751352, 0.2366958132811955, 0.0916640759844865, 0.13955218025616237], [0.07335905358195305, 0.08962517324835062, 0.10235826285289866, 0.21127675154379436, 0.1440021621861628, 0.11416818520852498, 0.05370858783966728, 0.053062418941408396, 0.012648366025782056, 0.04255164008853691, 0.021778477089745656, 0.08770765364170074, 0.04137210873886943, 0.11047309384282146, 0.05649061534287674, 0.1225286458751985, 0.08020355166601283, 0.10462328059864895, 0.04067061209518995, 0.46385842668158667, 19.562531539372035, 65.31677709306989, 55.804293700626914, 44.710653918130056, 72.72594697134835, 55.95393705368042, 19.3719094480787, 48.17094019481114, 27.90613685335432, 35.855021953582764, 39.1663944380624, 19.587678807122366, 45.69311877659389, 62.02546405792236, 54.64523342677525, 62.305135999407085, 64.71179049355644, 71.09526034763881, 39.63755873271397, 56.526472091674805, 54.46979488645281, 53.15609550476074, 47.91386032104492, 56.353673866816926, 39.59448684964861, 32.28267513002668, 0.7290739353213991, 0.801754535308906, 6.137979141303471, 29.140451329095022, 24.057512283325195, 18.100288357053483, 25.107574428830826, 19.279390709740774, 24.87832382747105, 24.09304015977042, 23.365398747580393, 18.39859710420881, 13.934492417744227, 11.776815329279218, 19.15887246813093, 19.78019428253174, 17.962750502995082, 11.380310297012329, 7.911051290375846, 10.276680145944868, 7.573001452854701, 15.762125730514526, 14.898751258850098, 19.179878609521047, 21.11915557725089, 26.158562421798706, 7.47448468208313, 10.375664183071681, 3.9308326159204756, 0.5421943717769214, 1.749102383852005, 0.21771735165800365, 3.3558274933270047, 11.595477768353053, 22.324914693832397, 31.913194247654506, 34.18470280511038, 22.18148650441851, 13.877049054418292, 15.544395242418561, 20.730450766427175, 25.661451816558838, 31.713273729596818, 18.237782784870692, 15.116690192903791, 11.32690383706774, 7.603914856910706, 5.849806947367532, 9.00245087487357, 10.491343004362923, 7.127660572528839, 2.9590423618044173, 0.7799318177359444, 0.1783923525363207, 3.131369411945343, 3.067530014685222, 0.09105521294155292, 0.5758513914687293, 0.5653896299856049, 5.929639143603189, 12.766911915370397, 11.684042981692723, 28.357523100716726, 27.973619495119365, 16.01787155015128, 12.065592885017395, 16.26939286504473, 13.41167868886675, 5.168767537389483, 3.156338632106781, 6.3111365011760165, 13.2915677853993, 15.874333926609584, 20.127896036420548, 22.620857579367502, 22.74165722302028, 19.74267748423985, 24.014141627720424, 26.82235857418605, 23.591083186013357, 21.990047999790736, 23.718341180256434, 25.29250247137887, 48.390291350228445, 26.262391090393066, 27.798835822514125, 47.79935053416661, 18.428123474121094, 7.531127265521458, 0.18212079389819077, 9.434705257415771, 56.838988167899, 46.509479999542236, 37.55855349131993, 46.07901130403791, 55.415350914001465, 50.738831111363, 52.60394300733294, 51.867274148123606, 52.14748804909842, 42.176326274871826, 36.417819091251914, 56.79927226475307, 26.579381806509836, 18.230839797428676, 17.738085712705338, 5.194480214800153, 33.228811332157676, 32.91795934949602, 35.09595905031477, 60.742284638541086, 33.52677093233381, 41.59277139391218, 53.80369540623256, 7.700714554105486, 0.33943774018968853, 0.05485287608046617, 0.05481296465066927, 0.14539889938064984, 0.0838602108082601, 0.0565651388439749, 0.0764662486367992, 0.11113988342029707, 0.03180247831291386, 0.03395584990669574, 0.02190666422913117, 0.04022831243595906, 0.10526950377970934, 0.10165244394115039, 0.019401139746020948, 0.15308281992162975, 0.09066857011722666, 0.051707387901842594, 0.0625283590384892, 0.07550065937851157, 0.010489934257098606, 0.04746790789067745, 0.07817145463611398, 0.030358810243862014, 0.09243221833769764, 0.034100985154509544, 0.0895867749516453, 0.05945989476250751, 0.05191757090921913, 0.059522523544728756, 0.11782539396413735, 0.12256079486438207, 0.1966692903744323, 0.09952064976096153, 0.4484020232089928, 25.707542691911968, 77.46119989667619, 59.368959290640696, 42.15784059252058, 72.51345021384103, 53.71024560928345, 23.56001431601388, 34.61430992398943, 32.00271136420113, 35.220800808497835, 34.20438357761928, 30.939841951642716, 52.3576397895813, 63.88950593130929, 59.949703625270296, 65.59385735648019, 64.2587262562343, 67.6772677557809, 42.3956218447004, 59.467623710632324, 57.2909163747515, 55.44852161407471, 48.81345748901367, 62.765676498413086, 44.13335589000157, 33.50161845343453, 0.6755083182028362, 6.4189812285559515, 17.43236150060381, 35.828747340611045, 29.293626104082378, 13.92556745665414, 20.92348735673087, 19.991895471300396, 22.667064837047032, 20.28977690424238, 21.339192867279053, 17.239920718329294, 13.277575850486755, 11.901882903916494, 16.45124285561698, 17.835885081972393, 14.043436697551183, 11.338130388941083, 8.91465778010232, 12.670823540006365, 11.64495415346963, 17.623932021004812, 16.578999383108957, 23.656328507832118, 24.376759426934377, 35.334963185446604, 12.02409563745771, 14.55322081702096, 5.999574499470847, 1.2885043450764246, 0.447761133313179, 0.11824334439422403, 1.3538063381399428, 6.749945640563965, 22.99205640384129, 40.68276582445417, 41.80132852281843, 29.17245646885463, 22.555777277265275, 27.670613765716553, 29.895253249577113, 37.81069319588797, 38.50937277930123, 27.608531611306326, 27.468356915882655, 20.05833762032645, 17.273607322147914, 11.142929434776306, 12.938076445034572, 12.370802061898367, 10.405390313693456, 3.2239079092230116, 0.6387118526867458, 1.0907049817698342, 2.111850678920746, 0.5012015200087002, 1.647582688501903, 1.323778286576271, 2.8896693757602145, 13.020432574408394, 17.733506849833898, 9.633370757102966, 32.34148120880127, 30.562412330082484, 13.312527026448931, 13.656602689198085, 20.217385360172816, 17.634561027799332, 10.945542403629847, 6.847164835248675, 7.071176929133279, 9.52007256235395, 14.702601875577654, 18.55358362197876, 23.718412399291992, 19.917502846036637, 21.247521809169225, 24.61471438407898, 27.655694246292114, 21.47566590990339, 21.503642831529888, 22.690944058554514, 28.36592694691249, 43.708153929029194, 27.87585139274597, 30.00677878516061, 44.716587679726736, 18.14930268696376, 17.980126210621425, 0.8685742755021367, 5.187936314514705, 57.12645251410348, 41.44117907115391, 39.801178387233186, 47.724824156079976, 59.4117671421596, 50.8266841343471, 59.06194618770054, 54.98802975245884, 60.436800139290945, 46.90542657034737, 39.680106026785715, 57.25718634469168, 38.728098596845356, 21.559652260371617, 16.37736439704895, 6.008865109511784, 15.814635004316058, 20.55607877458845, 31.555483613695415, 63.87098898206438, 44.048657349177766, 41.14088487625122, 63.50768157414028, 10.449989063399178, 0.4682974027735846, 0.11353868113032409, 0.12262505213064806, 0.0150723764007645, 0.05572753825357982, 0.0217696951502668, 0.09906965467546668, 0.07655764730381114, 0.05873428298426526, 0.03393124961959464, 0.05664790315287454, 0.10121728586299078, 0.12480468302965164, 0.14280750629092964, 0.02699115782577012, 0.2840196410460131, 0.23804799786635808, 0.15204652052904877, 0.309622911470277, 0.2019034687961851, 0.16248329835278646, 0.13178754118936403, 0.2095831281372479, 0.19922875160617487, 0.18391532903271063, 0.11993042672319071, 0.21105050082717622, 0.08346209395676851, 0.2032974511384964, 0.14789546041616372, 0.20575346292129584, 0.2977468658770834, 0.22008043128464902, 0.23589845321008138, 0.8284919091633388, 40.80336223329817, 90.6998597553798, 72.72527994428361, 63.88125147138323, 87.2156925201416, 70.7889073235648, 27.769853149141582, 65.76244844709123, 36.39564391544887, 49.55118594850813, 48.90495831625802, 25.407067843845912, 54.531883989061626, 68.86332525525773, 64.5653155190604, 75.01790755135673, 72.35657378605434, 78.41570172991071, 46.682618686131065, 62.771686690194265, 61.84287929534912, 62.4165712084089, 51.91487973076956, 65.45245456695557, 49.285431248801096, 42.90250335420881, 2.2146937889712195, 2.509276347500937, 11.425289460590907, 43.402714593069895, 32.48905052457537, 27.03910415513175, 34.41715826307024, 27.59057399204799, 33.0441004208156, 28.057522467204503, 28.491920369012014, 25.195418766566686, 20.26103741782052, 18.96934645516532, 27.283948251179286, 27.36567643710545, 26.489732674189977, 21.61082748004368, 16.197869845799037, 15.627679824829102, 13.965605582509722, 24.89199267114912, 24.201454639434814, 30.368995325905935, 32.45029694693429, 41.14165265219552, 16.9433559690203, 20.490129947662354, 16.353024857384817, 1.8321765661239624, 2.113705630813326, 0.2724975736013481, 7.696596009390695, 23.80947027887617, 29.86164481299264, 37.06311913899013, 40.373001234872, 32.92149598257882, 29.748552458626882, 38.92356531960623, 40.98525217601231, 44.93867295128958, 45.8278408731733, 34.33651399612427, 36.20667723246983, 31.983798367636545, 28.664402450834, 23.697081429617747, 21.56081782068525, 22.449122428894043, 13.887019719396319, 3.870342901774815, 1.3727665607418333, 2.329920543091638, 6.225339710712433, 5.942312657833099, 2.601245309625353, 1.5269610924380166, 9.965710043907166, 19.243588379451207, 30.59825461251395, 15.969732693263463, 38.76997538975307, 40.13058206013271, 24.967477900641306, 19.412792648587907, 23.001243659428187, 17.823869909558976, 13.797766634396144, 12.078690239361354, 17.004130125045776, 22.072212185178483, 23.378791400364467, 25.39869179044451, 29.383528845650808, 28.10161226136344, 26.76086006845747, 30.971737657274517, 35.301545824323384, 27.16136986868722, 26.377288239342825, 27.98226305416652, 31.82613331930978, 54.27153498785836, 32.583949020930696, 31.105445316859655, 57.69766044616699, 21.624687399183, 14.306214962686811, 0.36146922941718784, 12.80526076044355, 66.42663369859967, 55.689651897975374, 44.73454877308437, 52.08552401406424, 63.3374993460519, 55.94345222200666, 64.42621258326939, 59.11311272212437, 64.04294994899205, 51.30880226407732, 45.46351555415562, 66.28673866816929, 38.36488846370152, 27.9245582648686, 27.75828266143799, 10.456998927252632, 49.17180388314383, 46.522462708609446, 52.073454993111746, 70.67579065050397, 48.52329724175589, 50.19489138466971, 77.29216412135533, 15.018767493111746, 0.6976198745625359, 0.2841195214007582, 0.2184474824794701, 0.17247820060167993, 0.15449859680874006, 0.10896895812558276, 0.2333101678107466, 0.19396992879254477, 0.2463098131120205, 0.12712349503168038, 0.14457200946552412, 0.12065362291676657, 0.1976758020796946, 0.3716411478817463, 0.09541688353887626], [0.038816739073289294, 0.13788244128227234, 0.03944556461647153, 0.03687845290239368, 0.04583252314478159, 0.045596162256385596, 0.04297443186598165, 0.09210268102054085, 0.007360015912646694, 0.05127515770228846, 0.04279992622988565, 0.040744555448847156, 0.06401493426944528, 0.08265762962400913, 0.014972278914813484, 0.11273147551608936, 0.06959245141063418, 0.05137432898793902, 0.07007556155856166, 0.07480710159455027, 0.8324705670986856, 52.620493616376606, 57.35507951463972, 48.16939074652535, 49.81457131249564, 81.40303107670375, 40.98308433805193, 48.03029823303223, 38.09899132592337, 37.03694180079869, 44.26874501364571, 23.018716641834803, 37.89678485052926, 67.81941400255475, 67.57560866219657, 60.05610833849226, 60.876516887119834, 69.315826688494, 64.06238406045097, 58.087447438921245, 60.6273683820452, 56.51245410101754, 79.56033406938825, 61.34832041604178, 49.47053820746285, 14.30490175315312, 0.3931876745607172, 7.371728641646249, 19.564805337360927, 28.260672160557338, 24.22166521208627, 34.92328936713082, 17.83710970197405, 19.60567464147295, 21.666027443749563, 22.638933318001882, 19.415168932506017, 16.65212743622916, 12.468314817973546, 11.993491428239004, 17.53256494658334, 19.410503217152186, 13.584829534803118, 10.794054303850446, 10.273115720067706, 8.386204719543457, 13.257644942828588, 20.810030221939087, 15.768542391913277, 23.31947636604309, 26.10752442904881, 28.418741941452026, 10.038213627679006, 12.739935534340994, 4.984779238700867, 0.9884561598300934, 1.330738210252353, 0.07494068478367158, 1.5341901502438953, 12.507241232054573, 23.998907702309744, 29.538056782313756, 28.898607117789133, 17.652405738830566, 9.092568142073494, 13.349734629903521, 20.493225370134624, 27.78662610054016, 32.81551858357021, 18.495720761162893, 14.747693947383336, 9.428576946258545, 7.317737664495196, 5.002848029136658, 9.81342898096357, 13.249446937016078, 11.442765048571996, 3.4600467809609006, 1.495415402310235, 2.0955656213419775, 2.700260830777032, 1.6958349964448383, 0.6562073081731796, 0.4597288082752909, 3.110495069197246, 7.821527225630624, 14.195507577487401, 12.715534329414368, 21.21368408203125, 27.19604311670576, 21.378827129091533, 15.271763563156128, 19.031810760498047, 24.8845111983163, 20.469137702669414, 8.866093346050807, 8.454975383622305, 15.043150459017072, 16.99940708705357, 19.545803751264298, 21.580356155123027, 19.220469985689434, 18.205169677734375, 22.111040455954416, 22.901504005704606, 28.738892350878032, 25.95764136314392, 22.20027617045811, 15.030508211680822, 21.34985661506653, 20.89115391458784, 21.61299010685512, 27.042880501065934, 43.14167424610683, 26.267718621662684, 4.97457537480763, 0.0796900906467012, 33.12814583097185, 59.26036589486258, 43.511575494493755, 55.33030148914882, 46.81574617113386, 56.0465669631958, 52.28190789903913, 55.657196862357004, 52.99873617717198, 47.045634269714355, 42.077984946114675, 45.94134317125593, 19.773602179118566, 23.409591027668544, 5.716628219400134, 6.914290513311114, 64.68460219247001, 107.8792529787336, 54.64153698512486, 52.52848209653582, 31.024755886622838, 47.550730092184885, 51.51001862117222, 1.9806005103247506, 0.1341552348541362, 0.0759852012353284, 0.026190145539918115, 0.10274393537214824, 0.02413151609445257, 0.03451070834749511, 0.0836752625182271, 0.059624269870775085, 0.06590187908815485, 0.013391852112753051, 0.05166058934160641, 0.036858107029859505, 0.07721117152167217, 0.031152797995933464, 0.06270448637327977, 0.1264341441648347, 0.04752782931817429, 0.031663215785686455, 0.08113245253584214, 0.042722865007817745, 0.12678358969943865, 0.15515360023294175, 0.11308593542448112, 0.01720242335328034, 0.0299751156541918, 0.0326862328552774, 0.08285895774939231, 0.020701416402256916, 0.05307437812111207, 0.03835763210164649, 0.06248631700873375, 0.06884965234036956, 0.05092302516901067, 0.08331915376974003, 0.1316414661705494, 1.7630198427609034, 65.01479448590959, 70.83690547943115, 50.116870062691824, 58.471126965114046, 78.76393849509103, 38.46106890269688, 37.62545422145298, 31.82083531788417, 39.79961504255022, 36.08286033357893, 32.17899063655308, 43.71762432370867, 72.43348339625767, 70.83582850864956, 65.7015961238316, 67.3234029497419, 71.29922471727643, 66.29630633762905, 60.323718207223074, 65.00088419233049, 59.19579628535679, 76.31985405513218, 62.24121952056885, 54.16580772399902, 11.963203362056188, 0.66218693873712, 21.406460114887782, 20.3334185395922, 33.8811742237636, 11.113731367247444, 20.52134994098118, 17.166433095932007, 19.124458040509904, 19.948370218276978, 21.859072719301494, 17.183364118848527, 18.347444466182164, 10.341968894004822, 13.17463481426239, 14.250947254044668, 19.566403423036846, 13.523179905755178, 13.993678041866847, 12.583283185958862, 11.357532364981514, 15.517985139574323, 21.025698832103185, 16.354200839996338, 24.989458526883805, 29.338646956852504, 35.883947304316926, 13.276460664612905, 17.13798369680132, 9.488733581134252, 1.3339803048542567, 1.5356314671891076, 0.5602632707783154, 2.946222935404096, 18.797811065401348, 28.70910542351859, 39.65857703345162, 32.97830792835781, 22.794939483915055, 18.66632682936532, 22.66804105894906, 30.460065364837646, 41.59001990727016, 40.736232212611604, 27.514343568256923, 23.7236704485757, 21.29387845311846, 16.56426225389753, 10.234066843986511, 12.314987182617188, 14.73466260092599, 11.19973008973258, 5.848899773188999, 1.475469512598855, 1.4650578541415078, 2.5512291363307407, 1.535755557673318, 0.8341073564120701, 0.7606144685830388, 3.857939064502716, 8.988279155322484, 21.46135609490531, 11.115021126610891, 25.092211961746216, 33.49546234948294, 16.16222906112671, 11.835509368351527, 21.075493097305298, 25.597947018487112, 24.106625625065394, 11.678788406508309, 10.627944588661194, 14.952674491064888, 14.157959512301854, 15.546585662024361, 19.918327944619314, 16.81473091670445, 17.332720858710154, 25.347000667027064, 24.92574528285435, 30.744698320116314, 24.777364764894756, 23.210676261356898, 19.34964394569397, 31.076276779174805, 18.22143714768546, 21.0785642010825, 31.09908424104963, 40.945452894483296, 28.02879340308053, 15.783896173749651, 0.1894157374543803, 27.299711976732524, 66.19890648978097, 47.51274429048811, 60.41111264910017, 48.534063475472585, 62.314029693603516, 58.89697510855538, 61.87280518668038, 60.67642961229597, 51.73204483304705, 46.863299642290386, 52.45284400667463, 30.199945654187882, 27.801040138517106, 11.958418658801488, 9.013201475143433, 61.95865018027169, 93.74799278804234, 50.62936919076102, 58.59086527143206, 38.390020098005024, 51.13218947819301, 60.7584878376552, 3.079508491924831, 0.0630858705512115, 0.11989474935191018, 0.0327756943048111, 0.15043063009423868, 0.07535847915070397, 0.0496016155396189, 0.0540808864336993, 0.06008217244275978, 0.053008875743086846, 0.026419989099459987, 0.08414018114230462, 0.06356480770877429, 0.027015982029427375, 0.0656918589291828, 0.06908466972942863, 0.3400061625455107, 0.1553526281246117, 0.17513911638941082, 0.0774103147642953, 0.14181961358657905, 0.13953506760299206, 0.3551084521625723, 0.2182316676314388, 0.17412562934415682, 0.11998595802911691, 0.19780168389635427, 0.10183420311659575, 0.1099853493007166, 0.20227873937359878, 0.12513721947159084, 0.15335503460041114, 0.1763150990009308, 0.22572103861187184, 0.25250348076224327, 0.2871555584881987, 3.854015503610883, 88.2257729939052, 79.27400575365338, 68.41530541011265, 70.28995023454938, 95.8054586138044, 57.846143450055806, 61.74206788199288, 47.38517883845738, 48.85881880351475, 56.78026894160679, 28.645102092197963, 47.128356048039024, 75.32253047398159, 78.05456215994698, 70.50561537061418, 73.68000411987305, 78.89403656550816, 72.09611361367362, 65.3485164642334, 71.9707611628941, 64.76680632999965, 82.54708671569824, 65.6174395424979, 60.57067802974156, 18.60615716661726, 0.26720687321254183, 13.199580584253583, 27.105603626796178, 39.651420388902935, 34.83071156910488, 51.726100649152485, 23.121614251817974, 26.695602587291173, 28.471162625721522, 29.523166792733328, 24.652093955448695, 24.21918296813965, 16.671168974467687, 18.54218336514064, 23.530814511435374, 29.49939353125436, 22.25922121320452, 21.884675094059535, 15.753648928233556, 12.671381132943289, 17.976391553878784, 30.326722485678538, 23.451033558164323, 31.302305153438024, 39.22632959910801, 43.67089073998587, 17.876466035842896, 25.861426183155604, 23.107947145189556, 5.390306506838117, 3.777639167649405, 1.0486646890640259, 5.182047716208866, 27.536284242357524, 36.580337456294465, 38.77897678102766, 39.18570695604597, 30.27128628322056, 29.832267829350062, 34.761007240840364, 41.10264546530587, 50.48359945842198, 44.77377830232893, 36.435665539332796, 32.81612655094692, 34.31575277873448, 26.96961522102356, 22.99699136189052, 21.910916703087942, 20.144309418542043, 15.176039968218122, 7.254473013537271, 4.5540569339479715, 5.600127339363098, 4.538842116083417, 2.741375058889389, 1.2490409655230386, 1.196320531623704, 7.283582057271685, 18.66114173616682, 35.609000137874055, 19.431731700897217, 33.14661066872733, 38.381578036717, 29.466431277138845, 21.365651607513428, 25.79948820386614, 32.78606169564383, 28.58625258718218, 17.666265657969884, 17.753653151648386, 27.20826326097761, 25.658417190824235, 25.034416845866613, 26.76689284188407, 23.79993561335972, 23.11899130684989, 31.165456908089773, 28.647235189165386, 36.87550735473633, 31.74008682795933, 28.510729142597743, 18.381377731050762, 26.269976786204747, 25.1620899949755, 26.64482515198844, 33.54971040998186, 54.13881744657244, 30.559330804007395, 9.276078752108983, 0.26819826715758865, 37.89105953489031, 69.52409894125802, 51.76430879320417, 64.54552704947335, 55.745973995753694, 64.40950216565813, 59.65521117619106, 68.21191774095807, 64.20345333644322, 56.105946268354145, 51.85033791405814, 59.591662951878135, 29.893971306937082, 35.042867864881245, 12.294992004122053, 16.11365420477731, 87.3847074508667, 116.53802163260323, 64.01752649034772, 65.4591873713902, 45.517628124782014, 56.51078305925642, 73.19439452035087, 4.724806308746338, 0.41492068980421337, 0.17407028802803584, 0.12944654109222548, 0.3341999926737377, 0.14563006269080297, 0.1164265125989914, 0.12605765222438745, 0.11436835303902626, 0.1749671891863857, 0.06891076798949923, 0.1339420662926776, 0.2253798440630947, 0.1535532075379576, 0.19582057877310685, 0.12975922359951905], [0.10592825271721397, 0.09607977153999464, 0.10375947159315858, 0.0684870160850031, 0.046225876680442264, 0.09345465525984764, 0.13857051650328295, 0.009388870393325175, 0.09960085260016577, 0.01986623987821596, 0.09009486197360925, 0.03184315987995692, 0.11756346587623868, 0.08068856171199254, 0.08639584189014775, 0.004315568383650056, 0.08655393376414265, 0.15836619213223457, 0.12359444797039032, 0.17744426269616398, 0.6839168327195304, 7.959903206144061, 63.618581771850586, 54.543973854609895, 36.52287585394723, 65.87442561558315, 57.77264540536063, 33.15264170510428, 56.01304190499442, 31.890883581978933, 44.27986560549055, 27.89157169205802, 33.16822304044451, 55.54559142248971, 58.60784666878836, 62.13181318555559, 58.871468271527974, 65.45676939828056, 62.570640563964844, 58.60465744563511, 60.08950138092041, 59.556178501674104, 74.44918360028947, 52.53142465863909, 28.63345864840916, 1.2231957295111247, 4.681359222957066, 16.146642514637538, 31.35834584917341, 33.805647305079866, 61.39520686013358, 22.314238786697388, 14.298419083867755, 24.24017173903329, 18.434154510498047, 21.342887571879796, 21.485268320356095, 16.777650117874146, 15.897853578839984, 11.897015690803528, 13.15901005268097, 16.333328451429093, 12.869927644729614, 9.098939640181404, 9.850148473467145, 14.564421313149587, 12.226161411830358, 28.61303094455174, 16.872173411505564, 20.158620970589773, 28.565166541508265, 26.853205101830618, 12.826954773494176, 14.302362186568123, 1.3082338635410582, 2.342655722584043, 0.35316336367811474, 0.7843361614005906, 2.6871524027415683, 6.858257634299142, 7.5358138254710605, 18.216151305607386, 20.98045563697815, 19.67626486505781, 11.36883360998971, 9.747426305498395, 19.21612909861973, 26.068923711776733, 28.3103118283408, 19.355423109872, 19.12619161605835, 12.624728322029114, 9.881331988743373, 4.548584359032767, 8.259406174932208, 12.191694004195076, 11.948518344334193, 3.627387195825577, 2.0820159826959883, 5.598845396723066, 2.177171345267977, 1.1261717357805796, 0.15324345630194458, 0.4275445081293583, 4.397149673530033, 8.984334315572466, 19.883451461791992, 18.26110441344125, 19.320070675441197, 32.309241567339214, 20.48424482345581, 15.87761868749346, 16.876576832362584, 21.370320796966553, 16.804265192576818, 16.686465433665685, 12.951342293194362, 10.95900193282536, 13.316552639007568, 16.069402865001134, 16.469403709684098, 18.153072084699357, 19.083722489220754, 19.75925588607788, 22.128966808319092, 28.313035522188457, 23.935034649712698, 25.48734038216727, 22.52171720777239, 18.25680695261274, 33.720736844199045, 23.56434304373605, 19.545815910611832, 29.397772652762278, 18.351523058755056, 8.62850490638188, 2.9555932325976233, 5.224355731691633, 55.813805784497944, 43.959887163979666, 57.4549320765904, 50.92362887518746, 48.82996640886579, 54.014302253723145, 56.29907144818987, 52.60184465135847, 51.010001931871685, 52.41727270398821, 45.69855226789202, 19.358726978302002, 24.452982902526855, 8.48628396647317, 23.176060335976736, 62.02701350620815, 74.9411369051252, 76.53098896571568, 46.37081132616316, 30.10464068821498, 49.55153683253697, 36.19262450081961, 0.24627124518156052, 0.05938256212643214, 0.13196333604199545, 0.011378648042279695, 0.18951409789068357, 0.011982992890157869, 0.11417425131159169, 0.017137090609009777, 0.042003051311309846, 0.18079017315592083, 0.02861780473696334, 0.07035649541233267, 0.07133628640856061, 0.1310768843229328, 0.13846668707472937, 0.11528973574084894, 0.05914534628391266, 0.16077083881412232, 0.08228885941207409, 0.02303457772359252, 0.06188056165618556, 0.06307237448969058, 0.04630616094384875, 0.03763358434662223, 0.06583821214735508, 0.05156889211918626, 0.030893068361495222, 0.013200029414812369, 0.10755726601928473, 0.07355199501450572, 0.059866629008735926, 0.08367080454315458, 0.2118592331452029, 0.09613661920385701, 0.09616150108299085, 0.13497058967394487, 0.5020772644451686, 12.576420971325465, 82.60905075073242, 60.31439372471401, 45.740557602473665, 76.0037179674421, 51.074265820639475, 29.93748787471226, 40.08396659578596, 37.08722243990217, 40.723225184849326, 30.80287558691842, 43.75678784506661, 57.489002568381174, 68.21027101789201, 68.11770016806466, 67.11167744227818, 70.23569869995117, 68.99453503744942, 62.260459082467214, 65.0230142048427, 63.94851003374372, 70.9647523335048, 58.53965704781668, 25.592039312635148, 1.695429069655282, 14.622951201030187, 19.400075708116802, 31.547104086194718, 33.46784326008388, 62.30781800406319, 34.327731473105295, 18.27045668874468, 23.697843994413102, 17.729383093970164, 19.25789819444929, 20.588584184646606, 17.482638665607997, 15.43786893572126, 13.453990612711225, 11.223611916814532, 14.835196086338588, 15.45802913393293, 12.642863988876343, 10.447419098445348, 14.851468767438616, 15.850609302520752, 24.32668375968933, 14.921202625547137, 24.514599527631486, 25.722941637039185, 38.60866601126534, 14.468900084495544, 20.532800572259085, 12.292571425437927, 1.0072983716215407, 0.8253395440323013, 0.9951153567859105, 3.722537781511034, 17.777480261666433, 28.146865878786357, 32.09202003479004, 30.590080056871685, 21.432915381022863, 16.799146107264928, 24.611104794910975, 32.287288733891074, 37.35188627243042, 37.63942704881941, 28.296670777457102, 29.538209642682755, 22.089681693485804, 18.776725019727433, 11.527611238615853, 12.790488021714346, 15.764260564531599, 14.340008395058767, 4.879936567374638, 4.0504801613943915, 2.7735958099365234, 3.3606436806065694, 1.555627622774669, 0.7738035065787179, 0.48609222791024614, 4.976345428398677, 13.386092816080366, 32.28406129564558, 16.220258678708756, 26.55073438371931, 37.11021402903965, 20.52408926827567, 10.957010405404226, 18.696308306285314, 20.527566841670446, 20.580892528806412, 22.38828226498195, 16.60981638090951, 11.128290448869977, 9.977233631270272, 10.131121465138026, 10.966648425374713, 17.51292586326599, 18.01840557370867, 21.507789169039043, 22.976834637778147, 27.488501480647496, 25.219060012272426, 21.042850460324967, 19.271419388907297, 18.28915776525225, 29.46940163203648, 22.56652614048549, 22.40134140423366, 32.18879107066563, 19.772858721869333, 15.88694143295288, 10.40539118221828, 4.59402470929282, 50.765223843710764, 50.112103598458425, 57.67163596834455, 58.98197937011719, 53.45834214346749, 58.9105657849993, 61.65763337271554, 60.0922737121582, 53.80399417877197, 53.76233278002058, 50.3313262122018, 29.023169210978917, 29.73303018297468, 15.023745877402169, 24.621044192995342, 69.4819164276123, 73.7596652167184, 74.30919129507882, 55.7738744871957, 35.21136515481131, 56.930089473724365, 44.19871064594814, 0.6099164006965501, 0.04640042642131448, 0.10217322635331325, 0.05445838939132435, 0.1232866644859314, 0.01450748073070177, 0.16445966730160372, 0.08812682543482099, 0.06426718644797802, 0.06697898557675735, 0.07912948501429387, 0.06348507305873291, 0.08043408393859863, 0.08685229918254272, 0.1302714089729956, 0.16991827796612466, 0.1948069017380476, 0.31862620264291763, 0.249529488916908, 0.18171323862458977, 0.11590497701295785, 0.21716146862932614, 0.29472640795367105, 0.12401728385261127, 0.2715439333447388, 0.08103160866137062, 0.20850728372378008, 0.1061449157340186, 0.17448195522384985, 0.3869030017937933, 0.20171947724052838, 0.2559213430753776, 0.2799942727599825, 0.1824987650449787, 0.2840392914201532, 0.29194992408156395, 0.9082945212721825, 23.405823366982595, 99.08163152422223, 72.50919096810478, 60.82178592681885, 80.50277382986886, 74.69385051727295, 47.44482912336077, 71.53419889722551, 38.30475180489676, 58.146746839795796, 35.2312022617885, 45.060179574149, 61.23755918230329, 73.85195813860211, 76.98456736973354, 73.23991911751884, 73.09809248788017, 74.04630620138985, 64.93051283700126, 69.02054909297398, 67.13184111458915, 79.35021359579903, 60.93748732975551, 40.42038447516305, 2.6761887967586517, 7.752211127962385, 22.52708990233285, 42.033151694706504, 48.70464522497994, 72.47759750911167, 29.05901149341038, 18.49715382712228, 28.90272045135498, 24.027051380702428, 29.31792742865426, 27.400490386145457, 22.778001512799943, 21.268289974757604, 19.367294107164653, 19.616407871246338, 25.430667400360107, 20.351529019219534, 17.859957115990774, 15.787780216761998, 19.449631997517177, 15.149690662111555, 39.071843351636616, 22.766133989606583, 29.21614326749529, 39.35869973046439, 41.943860394614084, 20.91377898624965, 30.021852902003697, 25.555571692330496, 7.43069018636431, 2.6898645886353085, 1.0565336325338908, 4.986594889845167, 17.345839057649883, 26.033060584749492, 35.349102769579204, 37.781000069209504, 30.325332845960343, 27.312686000551494, 35.09759187698364, 42.83685677392142, 42.43096038273403, 44.73553889138358, 36.43142018999372, 36.660311222076416, 32.337548528398784, 29.906127180371964, 22.84384264264788, 25.25520280429295, 21.043552228382655, 14.650274991989136, 8.179316895348684, 12.129068153245107, 8.01199906212943, 4.503024586609431, 5.404280202729361, 1.2235993764230182, 1.4292696373803275, 6.1581145865576605, 22.14165595599583, 43.39995615822928, 25.49379699570792, 36.12864201409476, 41.38347775595528, 31.050530229296, 22.846559388296946, 24.768375532967703, 28.618716308048793, 23.264288561684744, 24.92583039828709, 21.44779668535505, 19.72155669757298, 22.01537765775408, 23.407758440290177, 22.342540536608013, 24.05213611466544, 25.910002776554652, 28.170017276491436, 30.408162321363175, 35.52071632657732, 28.689242260796682, 31.78715739931379, 27.819207940782817, 24.1359053339277, 42.72472674506051, 31.305539539882115, 23.70802136829921, 38.418549401419504, 22.35074462209429, 15.166451454162598, 5.652259239128657, 7.656087143080575, 60.56504304068429, 50.16490295955113, 60.24792030879429, 59.62163053240095, 55.7678781918117, 62.03191198621477, 66.6228369304112, 62.21547644478934, 59.903414726257324, 62.00032547542027, 54.566802161080496, 28.694302286420548, 35.70929043633597, 11.630845836230687, 31.507270063672745, 73.12944970812116, 76.18277304513114, 79.12057563236782, 64.03204822540283, 41.95585993358067, 63.079964365277974, 52.13403633662632, 0.5759651139378548, 0.16536116892738, 0.17482458826686653, 0.1768528108618089, 0.2655264948095594, 0.21260784726057733, 0.288910195763622, 0.1871170915131058, 0.10974657961300441, 0.28159428547535625, 0.20872636911060127, 0.10592355725488492, 0.15996988250740937, 0.302781025746039, 0.26642140107495443, 0.3283217895243849], [0.04712970907400761, 0.06170912299837385, 0.126842839377267, 0.0676176023802587, 0.02830344794451126, 0.07340623890714985, 0.023537974372240048, 0.05230002038713012, 0.12622538608099731, 0.07061494261558567, 0.04068746690505317, 0.0659950894436666, 0.023020487943930284, 0.012478482061331826, 0.00933948322199285, 0.059561057548437796, 0.060584254429808686, 0.12831808307341167, 0.10308078729680606, 0.14061583818069526, 0.10566596500575542, 0.1958163311438901, 32.14126191820417, 59.04123360770089, 43.401522977011545, 54.450815882001606, 91.24090208326066, 47.953683921269004, 45.23132412774222, 35.5776047025408, 36.9988100869315, 39.927715505872456, 22.078013931001934, 60.82771274021694, 44.64748437064034, 70.64970711299351, 64.66407026563371, 64.36797973087856, 57.35198061806815, 61.724766867501394, 51.644473212105886, 62.23801640101841, 57.72550882611956, 41.46707500730242, 2.005572770323072, 1.515950694680214, 11.65554060254778, 32.54711662020002, 32.472729206085205, 34.286747523716514, 16.290324313299998, 10.526440961020333, 23.768244879586355, 21.72155918393816, 21.115594625473022, 23.43536537034171, 20.150727816990443, 18.14318479810442, 14.28271962915148, 12.145044667380196, 13.874587655067444, 18.82515570095607, 11.468192849840436, 9.597693494388036, 13.559830784797668, 15.389808246067592, 9.924548046929495, 22.32716417312622, 22.868658133915492, 19.785299471446447, 31.267386981419154, 27.120776755469187, 14.205937692097255, 17.323912279946462, 2.204705753496715, 2.1048492831843237, 0.6151029052478927, 0.24175882445914404, 0.8545542220984186, 1.535862494792257, 1.8981586141245705, 5.565674696649824, 12.293733511652265, 21.30320988382612, 12.604654107775007, 10.90199978010995, 15.623563017163958, 28.255342892238072, 25.20211683000837, 16.067533799580165, 16.4922684941973, 9.999584249087743, 8.03728529385158, 5.1184104681015015, 9.188389011791774, 13.266845226287842, 9.37893033027649, 2.925952000277383, 4.7428781390190125, 4.992344089916774, 0.5940826503293855, 0.4152923641460282, 0.20121227231408867, 0.09901695286056825, 2.1386972154889787, 8.860514811107091, 23.7051100730896, 23.381730488368444, 15.057567971093313, 31.344914981297084, 19.514795678002493, 17.921938521521433, 17.075500283922466, 21.63218797956194, 25.50292866570609, 17.22774921144758, 14.041684882981436, 12.056667055402484, 16.26049222264971, 12.717610103743416, 12.067157966750008, 10.99298209803445, 19.990104573113577, 22.180037805012294, 30.698805468423025, 32.933036940438406, 32.48898799078805, 38.283799512045725, 33.22674076897757, 36.47185870579311, 23.65142481667655, 23.034200702394756, 20.69035792350769, 28.11395573616028, 24.123230082648142, 15.894092866352626, 8.483392647334508, 6.245370932987758, 16.085679020200455, 43.91207313537598, 43.35047803606306, 57.96689619336809, 54.621863160814556, 55.5266158921378, 55.510054860796245, 55.759088720594136, 52.770581654139924, 60.540918895176475, 46.787341935294016, 20.325490644999913, 28.7768486227308, 17.30782720020839, 30.348574570247106, 68.82021863119942, 51.521597794124055, 69.3682438986642, 49.331668036324636, 30.359042031424387, 55.00011614390782, 12.799045596803937, 0.4384685419499874, 0.40568949228950907, 0.10663576796650887, 0.08587720364864383, 0.07780401435281549, 0.030261783128870384, 0.04469609912484884, 0.01857424813455769, 0.025425253369446312, 0.051686753651925495, 0.05824452319315501, 0.05763758040432419, 0.0469178602631603, 0.07184245996177197, 0.07113507363413062, 0.26881828531622887, 0.10068229492753744, 0.05768030096909829, 0.07121474721602031, 0.10454691148230008, 0.09805706329643726, 0.07755317352712154, 0.006329554889816791, 0.0392617834066706, 0.048295069219810624, 0.08003706631383725, 0.062433255570275445, 0.03996045734467251, 0.04501825737367783, 0.12452417665294238, 0.0442620165246938, 0.006022996161066527, 0.01815043855458498, 0.08151703939906188, 0.025324187274756174, 0.003975813601365579, 0.06325746527207748, 0.7230939790606499, 47.556809765951975, 70.77788748059953, 45.77067109516689, 61.6685767854963, 87.7301024028233, 44.315266677311485, 32.68061930792672, 29.20836475917271, 37.31820140566145, 36.11129583631243, 31.122263431549072, 64.48040853227887, 52.20713138580322, 75.72301769256592, 69.08118602207729, 67.83094801221574, 64.26339544568742, 66.36535058702741, 57.395900181361604, 66.00653866359166, 58.98946952819824, 47.755333696092876, 0.5520712360739708, 5.128572642803192, 19.923761435917445, 27.74236954961504, 40.79178306034633, 37.55192838396345, 29.498090744018555, 16.40954324177333, 25.594488552638463, 19.536237818854197, 17.442782061440603, 19.876461574009486, 20.458640711648123, 19.372802291597637, 17.58650381224496, 11.844275389398847, 10.809679065431867, 12.544307265962873, 14.063567365918841, 11.171617678233556, 14.059170893260411, 14.894903693880353, 14.348369683538165, 28.37489012309483, 18.065794025148662, 22.095752682004655, 34.895451409476145, 36.05303519112723, 16.179481438228063, 24.41786844389779, 11.141087293624878, 1.2662479622023446, 0.5393332881586892, 0.8844926527568272, 0.686597751719611, 5.25041538476944, 8.707994035312108, 17.75012172971453, 24.46228654044015, 25.423943281173706, 15.41060767854963, 21.533009392874582, 29.970349379948207, 38.582721437726704, 35.286249365125386, 25.980441876820155, 26.984051840645925, 20.22379854747227, 16.181921992983135, 10.135020273072378, 11.506595543452672, 15.132221153804235, 15.123063428061348, 6.838113503796714, 4.809089260441916, 6.805304110050201, 1.7393199716295515, 0.06976894515433482, 0.1037875290161797, 0.22622004683528626, 3.876461224896567, 15.005126442228045, 34.15435307366507, 18.5444050516401, 22.68688804762704, 36.83023984091622, 24.70788104193551, 12.377349002020699, 12.89271078790937, 21.869600977216447, 27.497987508773804, 23.004241807120188, 17.269193478993007, 15.081369025366646, 12.487488371985298, 6.661903713430677, 5.73043429000037, 10.548410296440125, 17.33299878665379, 20.934910195214407, 25.764731577464513, 29.921190874917166, 28.341505765914917, 32.00288854326521, 29.359620094299316, 32.43221773420061, 27.120458875383648, 23.591583456311906, 23.592483248029435, 29.597967624664307, 23.250836849212646, 18.362292766571045, 16.26977849006653, 15.071921212332589, 14.068376387868609, 51.41998733792986, 44.274800368717735, 55.84883165359497, 58.23708036967686, 63.92433030264718, 57.98658043997628, 62.5248658316476, 55.894126960209434, 61.92107432229178, 50.32739005770002, 28.013118267059326, 30.55151755469186, 18.71394109725952, 43.836730343954905, 82.42005974905831, 57.22855281829834, 71.95014585767473, 54.34650952475411, 32.738070487976074, 69.08800915309361, 16.494636092867168, 0.3239970515881266, 0.27575234323740005, 0.15698640474251338, 0.09357069831873689, 0.18371307131435188, 0.053812949918210506, 0.030239238802875792, 0.04991753805162651, 0.09385632084948675, 0.09358416045350687, 0.06762073721204485, 0.02557340300908046, 0.08231144784284489, 0.048667520484221835, 0.08837067734982286, 0.14801070280373096, 0.18855912770543778, 0.4027267912668841, 0.27916930988430977, 0.09760925732553005, 0.15415500024599688, 0.16706220193633012, 0.16438558484826768, 0.2612241213875157, 0.14861630887857505, 0.16557942650147847, 0.18632666606988224, 0.14538006324853214, 0.2356818648321288, 0.20822194617773804, 0.08640038128942251, 0.1257379265236003, 0.1300385764666966, 0.3446057614471231, 0.14802997319826058, 0.14999046442764147, 0.14687811929200376, 1.243439957499504, 73.71828174591064, 83.27235358101981, 62.049226897103445, 73.90903759002686, 108.98638589041573, 64.3056196485247, 61.53446960449219, 42.055740288325715, 46.36117764881679, 51.84963962009975, 27.662136963435582, 75.18913895743233, 54.77483817509243, 82.56854275294712, 75.02773925236293, 77.66986819675991, 65.96938664572579, 70.0914124080113, 57.68671008518764, 72.31827531542096, 65.39167172568185, 53.88858502251761, 2.4123111963272095, 2.415005794593266, 15.746351582663399, 43.46098913465227, 45.056559562683105, 44.51706668308803, 23.72884511947632, 14.73263372693743, 32.67115586144583, 27.64425924846104, 27.490745748792374, 29.165869576590403, 26.617975575583323, 26.00771008219038, 20.602386781147548, 19.00966511453901, 22.43138541494097, 28.47258526938302, 20.142978838511876, 19.038444553102764, 22.17970429147993, 21.439375468662806, 13.6607038634164, 30.917788369315012, 34.068313530513215, 28.398944786616735, 47.018630095890586, 42.7741562298366, 21.740993295397075, 33.70758390426636, 24.243234157562256, 5.079524440424783, 1.3705188184976578, 0.9375754786389214, 0.8583372448171888, 3.9099176696368625, 4.349246186869485, 13.057916368756976, 27.70142902646746, 34.28563928604126, 22.57492130143302, 32.01371383666992, 41.07762847627912, 46.25419276101248, 42.4324438231332, 31.86606114251273, 33.5292375428336, 29.933343274252756, 27.658975533076696, 20.852136305400304, 24.082185336521693, 19.332990850721085, 14.165680697986058, 9.928096839359828, 10.286213942936488, 6.474492992673602, 0.7401934415102005, 1.2731034457683563, 0.2491398469677993, 0.5317828761679786, 3.816770553588867, 20.405836139406475, 45.191830566951204, 28.672139269965037, 30.999398435865128, 41.18644074031285, 28.661447729383195, 25.05975866317749, 24.238570179258073, 28.668371609279088, 33.848198073250906, 25.509873390197754, 23.455372708184377, 24.12438522066389, 25.932758126940044, 22.126682588032313, 16.80407759121486, 17.60887701170785, 26.340989112854004, 27.387862035206386, 37.86419432503836, 40.27310003553118, 40.302150453839985, 46.49534388950893, 39.90496015548706, 43.45433970860073, 30.526094096047537, 29.176573276519775, 29.465823309762136, 35.84355395180838, 31.304476465497697, 20.717678240367345, 12.755288447652545, 11.496999212673732, 23.074840715953282, 60.35346344539097, 52.5713837487357, 65.04233714512416, 60.45801298958914, 63.529964447021484, 60.407833099365234, 67.07317747388566, 60.59385027204241, 69.72165707179478, 55.66705635615757, 29.42753526142665, 38.46237168993269, 21.702310936791555, 41.2494991166251, 78.27634171077183, 61.57185786111014, 78.77983597346714, 65.89617347717285, 41.334472111293245, 77.84685965946743, 20.892046758106776, 0.6455647306782859, 0.5082990505865642, 0.33726564102939194, 0.27967576842222897, 0.2881103115422385, 0.1609019317797252, 0.09899956879339047, 0.12475387432745524, 0.24303677731326648, 0.13670231960713863, 0.1507860603077071, 0.2948797568678856, 0.14138837744082722, 0.1546746359339782, 0.2541231981345585, 0.5248873861772674], [0.09739674015768937, 0.015359084587544203, 0.03817783389240503, 0.10991350601294211, 0.06117778258132083, 0.1427976539624589, 0.022610199870541692, 0.06635523547551461, 0.023758598337216035, 0.06575560050883464, 0.08840849889176232, 0.026159200950392654, 0.038737065491399596, 0.021127901106540645, 0.018123376881703734, 0.038874916665788205, 0.04443601325952581, 0.04506879805454186, 0.04007604578509927, 0.035642436905098815, 0.15549526975623199, 0.48857593749250683, 18.144129753112793, 69.60883917127336, 55.863231795174734, 62.44860240391323, 81.760237966265, 69.20095212118966, 42.325000354221885, 53.97589956011091, 35.25655276434762, 44.1862143107823, 19.792374474661692, 57.16451474598476, 65.47691917419434, 68.10197639465332, 63.77390875135149, 64.17150551932198, 66.2248649597168, 60.47442463466099, 58.367744718279155, 64.02893543243408, 52.45215266091483, 33.22321803229195, 0.6334311131920133, 6.8806482042585095, 34.5657593863351, 28.102228913988384, 24.75721151488168, 24.42732494218009, 28.534547567367554, 29.450085639953613, 24.126422779900686, 23.451568569455826, 20.540931701660156, 22.6538702079228, 23.467202016285487, 19.08666331427438, 17.701739685876028, 14.562942215374537, 9.577601041112628, 12.270781006131854, 13.591516307422093, 11.724856700216021, 11.73819637298584, 19.30767856325422, 14.288187861442566, 10.726582952908107, 18.695669072014944, 21.563694374901907, 27.63550799233573, 32.68007040023804, 15.654967137745448, 25.74115112849644, 2.195219073976789, 0.6333893154348645, 0.7108738890716008, 0.09670892956533603, 0.5401411790932927, 0.21069014444947243, 0.8467118772012847, 2.157359859773091, 6.296288200787135, 12.383746555873326, 12.252758247511727, 9.795590349606105, 14.518980962889534, 21.73557891164507, 20.08338761329651, 10.652013148580279, 16.53257152012416, 11.413741554532733, 8.108262010983058, 6.88918536901474, 9.002668006079537, 10.897103037152972, 5.910406095641, 1.9538297525474002, 0.8273345455527306, 4.202640499387469, 0.40363676100969315, 0.303938090801239, 0.06111063475587538, 0.1321856512555054, 3.1690801084041595, 10.868252379553658, 29.88164520263672, 26.52161274637495, 15.274780818394252, 32.72117594310215, 21.023020301546367, 16.075673614229473, 20.825370107378276, 17.192250864846365, 21.320175647735596, 24.186649765287125, 20.739261082240514, 13.621233752795629, 14.020629235676356, 7.6841500486646375, 7.787902287074497, 10.334433572632925, 16.377466882978165, 23.141819613320486, 28.49410731451852, 26.96498077256339, 33.72701454162598, 30.225091184888566, 29.690138953072683, 28.86428475379944, 31.30986131940569, 31.643225465502056, 22.16114912714277, 22.631061008998326, 36.732881682259695, 19.085652351379395, 21.415574414389475, 12.512761575835091, 3.8914285131863187, 22.15068687711443, 27.274601187024796, 21.644543613706315, 34.09418167386736, 44.5718879699707, 53.069566113608225, 56.30810758045742, 57.141811507088796, 68.11571993146623, 44.16862147194998, 23.18656948634556, 33.90740367344448, 25.214270966393606, 18.18933473314558, 46.73078012466431, 45.530885287693565, 55.236181191035676, 49.11308465685163, 38.57745122909546, 45.4789023399353, 3.248553386756352, 0.15163471762623104, 0.21491618268191814, 0.028911471300359284, 0.27870543620416094, 0.020252278806375604, 0.08264411320643765, 0.029018408419298272, 0.12299441945339952, 0.03644541185349226, 0.04842956503853202, 0.04024282630000796, 0.12189025298825332, 0.03390956703307373, 0.08258408321333782, 0.11739327572286129, 0.2053535208106041, 0.09135980731142418, 0.10720655162419591, 0.10408372990787029, 0.07891302555799484, 0.13374952519578592, 0.07628401448684079, 0.010126689016552908, 0.028966839757880995, 0.07698772994003125, 0.04991285276732274, 0.05931274765836341, 0.028245229639911225, 0.0667624854083572, 0.044302026342068396, 0.05713127114410911, 0.030261009598949125, 0.05269097869417497, 0.12651897461286613, 0.041382144271795235, 0.09639103590909924, 0.1318013154502426, 0.5159511342644691, 28.018213033676147, 85.7991771697998, 57.99549845286778, 67.2931296484811, 90.71402713230678, 61.52934878213065, 39.11071504865374, 37.61554261616298, 33.45024694715227, 39.613149711063926, 28.41402758870806, 64.73826313018799, 68.97340556553432, 74.60897827148438, 68.73915399823869, 67.17988095964704, 68.47580337524414, 66.00698334830147, 63.75428703853062, 67.54101358141217, 56.91102014269148, 37.145983355385916, 1.281448232276099, 12.855514475277491, 29.408580575670513, 36.040889739990234, 31.991427489689418, 27.201832703181676, 30.667615004948207, 26.596866948263987, 22.4862379687173, 21.062545129231044, 18.787590265274048, 21.463708060128347, 24.21421848024641, 20.608127730233328, 20.165322508130753, 16.129272018160137, 11.013844932828631, 9.408738102231707, 12.579494680677142, 14.213419164930071, 12.360008903912135, 18.765548842293875, 17.89405366352626, 16.468337161200388, 25.023893799100602, 21.643852267946514, 33.57744761875698, 43.34882436479841, 18.475235734667095, 31.13832071849278, 10.718223401478358, 2.506037184170314, 0.5980417664561952, 0.48372224079711096, 0.2331078015267849, 0.8100348338484764, 5.038248666695186, 7.532215527125767, 19.313982316425868, 26.26443907192775, 20.382340805871145, 19.515038864953176, 32.91788291931152, 33.76479537146432, 29.920617648533412, 20.277164186750138, 26.917755603790283, 19.562149388449534, 16.16433957644871, 9.522534830229622, 10.85158017703465, 12.765639526503426, 9.063352704048157, 3.1403605980532507, 7.3841016462871005, 7.1187434281621655, 2.2618551211697713, 0.529969504901341, 0.11051787715405226, 0.18475642747112683, 3.1136528083256314, 14.987132344927106, 40.8193986756461, 24.48112484386989, 22.227297714778356, 42.8842955998012, 23.364566700799124, 16.410786969321116, 14.00373295375279, 19.554666178567068, 20.448216676712036, 26.94986844062805, 21.353902203696116, 16.866767713001796, 12.059775505747114, 5.3241409829684665, 5.070436196667807, 8.855773534093585, 15.20281137738909, 18.341807740075247, 25.770277976989746, 26.816360541752406, 28.262199027197703, 30.03465495790754, 26.76429942675999, 28.23145498548235, 28.645737852369034, 27.164550406592234, 19.746193272726877, 25.34881588390895, 30.22365985597883, 20.460836342402867, 28.97270965576172, 32.776976925986155, 7.662563732692173, 21.31996546472822, 33.76646988732474, 22.353407519204275, 32.66999551228115, 44.24970347540719, 57.760020528520855, 64.926100730896, 57.296728542872835, 69.02853257315499, 48.616566385541645, 30.872176919664653, 32.48947089059012, 21.97587193761553, 27.99715825489589, 54.95280933380127, 53.211622033800396, 59.8606207711356, 53.73138550349644, 43.05188614981515, 61.04278727940151, 5.267571355615344, 0.0669473862009389, 0.1261899665530239, 0.014289833838120103, 0.30792437547019547, 0.05003003576504333, 0.06328926820840154, 0.04297167362113084, 0.09357417920338255, 0.09355675442410366, 0.045087186353547234, 0.027525068194206272, 0.032635003461369445, 0.03809241311890738, 0.012787146793146218, 0.07484029552766255, 0.08181970672948019, 0.16245247929223947, 0.2938761221511023, 0.1434738819620439, 0.1864987832627126, 0.1974813203726496, 0.18356741698724882, 0.1166269654142005, 0.19752747432461806, 0.17519935672836645, 0.17458482113267693, 0.19005888008645602, 0.13459006723548683, 0.17486395686864853, 0.10587496057684932, 0.21998065949550696, 0.12378332497818129, 0.2351557830614703, 0.23621986167771475, 0.2948548410620008, 0.22891385800072125, 0.3067359892385346, 0.7255128749779293, 41.20408916473389, 106.17061451503209, 73.77149105072021, 84.12479332515171, 95.91922841753278, 85.75200584956578, 60.886758531842915, 66.9676273890904, 45.3172733443124, 57.92556830814907, 26.133788619722637, 71.67750549316406, 74.09983512333461, 83.96483189719063, 74.28405966077531, 75.10636506761823, 71.24056802477155, 69.17168630872453, 65.72761017935616, 75.78553758348737, 58.97794246673584, 42.53272369929722, 1.2002584231751305, 11.437284656933375, 46.179909569876536, 40.30694471086775, 34.74990054539272, 34.408705779484336, 37.86272478103638, 37.174728052956716, 32.21216133662632, 31.42621237891061, 27.107622078486852, 29.079560790743145, 31.122899191720144, 26.51427718571254, 24.117690631321498, 24.215048789978027, 17.75750940186637, 20.338709592819214, 23.604649543762207, 20.30038854054042, 19.456668785640172, 24.477994680404663, 21.317330360412598, 13.595336948122297, 26.070565223693848, 32.476425647735596, 42.87590912410191, 53.658696923937114, 24.12296083995274, 37.78735072272164, 23.177344015666417, 4.748321618352618, 1.5239861777850559, 0.3817211112805775, 1.3565069075141634, 5.294745760304587, 4.3914230551038465, 8.345064435686384, 20.657803876059397, 29.24076768330165, 30.678739070892334, 32.08150393622262, 46.54797649383545, 38.7437424659729, 37.14831795011248, 28.778903552464076, 35.34856081008911, 30.39964382989066, 28.083272491182598, 21.796648366110666, 20.532001529421123, 13.732780132974897, 10.34275664602007, 4.58323415688106, 9.110295602253505, 5.0192001802580695, 1.4979962238243647, 1.1957772693463733, 0.22752990440598556, 0.48984300664493013, 3.433362875665937, 25.895357710974558, 49.73968710218157, 28.40186129297529, 32.94700281960623, 51.0013826915196, 30.639850003378733, 21.103734050478252, 30.06560570853097, 23.594930750983103, 28.62326042992728, 32.05521542685372, 29.350590910230363, 21.26023527554103, 25.683957031794957, 14.181056192943029, 13.573605588504247, 15.440101044518606, 21.76211929321289, 31.568765095302037, 34.5221768106733, 33.159902572631836, 38.94974613189697, 35.143675804138184, 35.31469529015677, 32.996595587049214, 38.22818265642439, 39.968789781842915, 27.57964621271406, 31.923540115356445, 45.49510901314871, 26.9884135723114, 27.703522171292985, 23.601408209119523, 9.762543848582677, 31.173555033547537, 42.3200740814209, 31.391467911856516, 40.589065892355784, 55.93700081961495, 60.6216847555978, 70.95858233315604, 60.92648833138602, 78.99878760746547, 52.63558510371617, 32.35134417670113, 42.89815378189087, 34.4619220324925, 25.468705313546316, 62.154700551714214, 63.02050168173653, 66.41926165989467, 61.774647985185894, 51.14339344842093, 72.01736967904228, 7.241537204810551, 0.38396605796047617, 0.3422453281070505, 0.12013447577399866, 0.44663354381918907, 0.16273878035800798, 0.11838211837623801, 0.1828689601804529, 0.3365058446569102, 0.14376466135893548, 0.11401927391333239, 0.18091271658028873, 0.1479499332074608, 0.07962827610650233, 0.18261429241725377, 0.14665583121989453, 0.3873384855687618], [0.08512781600334815, 0.1547149544847863, 0.12845178161348614, 0.08815783448517323, 0.26011908639754566, 0.1126343703695706, 0.06704082725835697, 0.031420072939779074, 0.07310398548309292, 0.09656905635659184, 0.06715419010392257, 0.026539855703179325, 0.05763872034315552, 0.08733384869992733, 0.07213015202432871, 0.195181615916746, 0.0964832759595343, 0.030488902370312383, 0.1413638958973544, 0.11498818120786122, 0.036992205905594995, 0.08351985764290605, 3.9156560131481717, 68.93455123901367, 63.62105533054897, 56.485849448612754, 68.90580654144287, 89.71937860761369, 50.8395209312439, 53.263448647090364, 40.113760471343994, 48.69030066898891, 24.86035578591483, 53.11907202856881, 79.53496619633266, 62.98746299743652, 67.46920394897461, 63.075017247881206, 64.19984722137451, 60.771995135716026, 68.26438358851841, 55.04638072422573, 60.909277643476216, 26.498174735477992, 0.805411730493818, 24.88673288481576, 29.41870062691825, 26.652280569076538, 36.16251795632498, 37.85129846845354, 33.597802366529194, 27.574362107685634, 25.99654606410435, 19.97314054625375, 22.155272688184464, 19.073010104043142, 24.2947724206107, 22.193986313683645, 20.775190217154368, 13.595732995441981, 10.194216319492885, 7.749716724668231, 13.887516515595571, 9.815710595675878, 16.979703732899257, 15.989978006907872, 17.25394218308585, 16.913473503930227, 14.384055631501333, 24.736629213605607, 29.501286915370397, 35.49128723144531, 20.002494948250906, 31.03270809991019, 6.370156671319689, 1.439799849476133, 0.2421134268598897, 0.06157919711300305, 0.6044387774808067, 3.657591232231685, 10.608468788010732, 1.3522441876786095, 7.082080389772143, 6.700925665242331, 14.803741591317312, 14.077957953725543, 10.048984204019819, 16.30182010786874, 17.829551798956736, 10.943652493613106, 14.811843190874372, 13.654192532811846, 8.084185634340558, 7.117681222302573, 9.321585978780474, 9.5150203534535, 0.8301746760095868, 0.8276131791727883, 0.7066431418061256, 0.5077310353517532, 0.3465706360127245, 0.14998312267873967, 0.5116294090236936, 0.28220928247485844, 4.157266157014029, 15.955565316336495, 34.980723176683696, 25.56397727557591, 14.78887244633266, 33.59655169078282, 27.1450902393886, 8.946759326117379, 14.75795122555324, 16.89284951346261, 22.31615822655814, 22.971715552466257, 17.636334555489675, 17.282591342926025, 12.907575590269905, 5.512254774570465, 5.7270387922014505, 11.552315558706011, 16.990888595581055, 22.951838493347168, 20.58998077256339, 24.22175553866795, 31.19831493922642, 33.69057124001639, 37.49310146059309, 33.566664014543804, 32.9936842918396, 30.958549976348877, 32.45700543267386, 19.319834436689103, 40.04018599646432, 35.91601324081421, 20.386198793138774, 10.936450685773577, 8.61768569265093, 8.123407346861702, 22.069497176579066, 14.203352093696594, 16.06625533103943, 16.926694188799175, 31.499814646584646, 54.72337981632778, 58.76595292772566, 67.86581407274518, 35.32095909118652, 24.074566636766704, 36.660248688289094, 26.641884326934814, 31.252170426504954, 45.99207891736712, 54.54043027332851, 59.477684702192036, 44.818958963666645, 44.08284248624529, 28.84923495565142, 0.3101344997329371, 0.02128186579128461, 0.051694835003997595, 0.06839051483465092, 0.09585016886038439, 0.013717302952760031, 0.03318531232486878, 0.07614074860300336, 0.07365729007869959, 0.0400906885708017, 0.07553105774734702, 0.1766176034829446, 0.02653104662229972, 0.043944370533738814, 0.1131417720711657, 0.163461691566876, 0.11580059118568897, 0.18071043172052928, 0.17130049451121263, 0.13573297805019788, 0.0743633396923542, 0.31935744626181467, 0.024868820727403675, 0.05554864928126335, 0.07975883981479065, 0.08295121137052774, 0.042341813312045166, 0.057146511040627956, 0.052768426681203504, 0.08955993210630757, 0.02057600956011031, 0.08830046933144331, 0.04037413978949189, 0.16096817036824568, 0.02878910768777132, 0.12039306546960558, 0.033661073938544304, 0.06053950504532882, 0.05578047416305967, 6.26420749936785, 84.42990262167794, 71.95600318908691, 67.58064610617501, 83.95937756129673, 81.96312536512102, 47.18603999274117, 36.20668765476772, 30.86384950365339, 41.542344842638286, 31.201855046408518, 59.53115109034947, 79.12562697274345, 74.80362510681152, 70.19735159192766, 68.2554759979248, 68.62052740369523, 67.03644929613385, 68.1205836704799, 59.7834540775844, 68.56802681514195, 26.006751230784825, 2.419414643730436, 32.560196604047505, 34.59390306472778, 31.16019712175642, 32.24993174416678, 36.37128005708967, 28.991985695702688, 24.699195793696813, 23.896513836724417, 20.532692875180924, 19.16213117327009, 19.716917037963867, 22.81495898110526, 20.730940614427837, 20.521355152130127, 16.741917269570486, 12.276239684649877, 9.128274066107613, 9.606283204896108, 12.277641483715602, 18.86912911278861, 18.078712463378906, 19.550785609654017, 17.424847023827688, 18.478741100856237, 25.0875723021371, 34.20370960235596, 44.29658644539969, 23.96995803288051, 35.33379936218262, 17.684523786817277, 2.112431070634297, 0.04514645638742617, 0.17379005306533404, 0.1847415268421173, 1.5403060849223817, 1.2938514181545802, 5.2625912342752725, 8.334180082593646, 14.327264530318123, 23.231692825044902, 20.88911461830139, 22.668223449162074, 34.40404006413051, 25.639026505606516, 20.46562191418239, 24.543740272521973, 20.347969804491314, 11.536257403237478, 9.584175774029323, 8.654723933764867, 10.798619270324707, 3.9412014995302473, 1.592654247369085, 3.3745072909763882, 1.9195760020187922, 1.085114830306598, 0.1912660210260323, 0.12388704584113189, 0.23637549046959194, 2.5568862727710178, 16.479377848761423, 41.12096439089094, 30.68825462886265, 17.777926683425903, 46.3162818636213, 28.240103755678447, 12.672493713242666, 13.348945140838623, 19.969115802219935, 20.29620919908796, 23.42000116620745, 17.92110300064087, 16.931368589401245, 9.911150182996478, 6.648489781788417, 7.284504430634635, 13.732391902378627, 14.553115725517273, 18.684494631631033, 17.388758080346243, 18.387478249413626, 24.37754283632551, 27.729161024093628, 28.78076045853751, 26.71499674660819, 25.894582986831665, 30.7870580128261, 30.327552795410156, 19.513265337262833, 39.593222277505056, 30.32400574002947, 19.772756235940115, 13.324638605117798, 17.619210720062256, 10.841643384524755, 23.89089448111398, 21.144735370363506, 20.144806214741298, 15.947755541120257, 31.557106018066406, 56.93041256495884, 66.47402736118862, 69.60377393450055, 45.151364258357454, 28.219347749437603, 33.721747807094026, 21.20988862855094, 30.5496415410723, 47.98616674968174, 59.43679455348423, 65.12109497615269, 54.683827195848735, 50.6501338822501, 40.10364042009626, 0.46058750791209085, 0.08358471201998846, 0.1847149282693863, 0.035730843232678514, 0.10318542418203183, 0.023201519390568137, 0.008004765824547835, 0.05018843297979661, 0.021246436085285883, 0.038851853260504346, 0.06933170397366796, 0.10829746630042791, 0.0631167913920113, 0.08842398306088788, 0.09697372107101337, 0.2137810614492212, 0.09102541168353387, 0.3065137283078262, 0.3829049106155123, 0.15984572416969708, 0.19734193570911884, 0.3442067014319556, 0.1873697101005486, 0.14783446011798723, 0.264422138354608, 0.1977914787296738, 0.1784840633294412, 0.2565006762742996, 0.16247774793633393, 0.10373633354902267, 0.14132781140506268, 0.23083476349711418, 0.2642274802284581, 0.3619125027741705, 0.17397010911788258, 0.45979677034275873, 0.22634656647486345, 0.25678916222282816, 0.2762193110372339, 9.632788845470973, 106.24470315660749, 82.75219753810337, 79.50162873949323, 90.85902214050293, 102.67455891200474, 66.93810449327741, 69.52263981955392, 50.549173082624165, 58.47144658224923, 32.00636264256069, 64.85843222481864, 90.43974004473004, 80.01320375714982, 80.66179725102016, 72.08057744162423, 74.82350390298026, 71.85979843139648, 73.33574867248535, 60.65177740369524, 72.36571761540004, 36.50451871326992, 1.558159481201853, 32.734735352652415, 37.85812507356916, 35.19406066622053, 43.949468340192524, 49.72171211242676, 41.363730975559776, 34.974952697753906, 31.55520221165248, 26.620284114565166, 28.372359241758073, 25.675101552690776, 30.312040942055837, 27.181000266756328, 27.49138150896345, 20.386928353990825, 18.266206128256663, 17.31323116166251, 24.83194807597569, 18.299439362117223, 24.982916797910416, 22.31614085606166, 25.44153959410531, 21.25584053993225, 18.328918831689016, 34.51990474973406, 46.180646078927175, 54.44115441186087, 31.31755644934518, 41.51762662615095, 30.990265028817312, 5.181932202407292, 0.9206494497401374, 0.3872120609240872, 0.8738184826714652, 8.708783524377004, 13.074268954140798, 8.646822094917297, 12.461711423737661, 14.623675550733294, 30.421388217381068, 32.22069372449602, 37.21436752591814, 42.90669311795916, 33.239556721278596, 30.529074873243058, 31.87355477469308, 31.61443213054112, 21.50904679298401, 23.301061902727398, 15.559479781559535, 9.167748519352504, 4.595497293131692, 2.4895417264529636, 3.723454075200217, 0.9215953818389347, 0.5137524093900407, 0.5310843107955796, 0.6023558921047619, 0.5146981243576322, 8.056378943579537, 35.48580857685634, 45.24716602052961, 33.02200862339565, 28.886451244354248, 53.38153328214373, 41.15709154946463, 14.955043826784406, 23.027693714414323, 25.814642224993023, 27.827749013900757, 29.90132597514561, 23.445528847830637, 26.23524968964713, 22.977119513920375, 12.583214572497777, 13.4325076511928, 16.642617089407786, 23.764164549963816, 30.122382913316997, 26.17188385554722, 31.17017820903233, 35.87895849772862, 37.71558625357491, 40.80769790921892, 37.15181289400373, 38.935057640075684, 40.32067435128348, 41.172839641571045, 27.922901119504655, 51.85586520603725, 45.73742743900844, 25.850510563169205, 12.69070407322475, 15.141312871660505, 17.958699703216553, 35.35128797803606, 27.2359778881073, 30.22381271634783, 22.77630615234375, 38.80527918679373, 64.1092427117484, 71.62495626722063, 78.45894731794084, 46.828919955662315, 32.24423769542149, 47.20246206011091, 34.02814599445888, 43.06062698364258, 59.66736357552664, 67.76052107129777, 74.60824176243374, 57.888992990766255, 60.62538119724819, 51.077764238630024, 0.5370944482939584, 0.17372602650097438, 0.3938043000442641, 0.19177708003137792, 0.3490132535142558, 0.09623153946761574, 0.11378138632114444, 0.19921675510704517, 0.11140783689916134, 0.1434613833470004, 0.2012699342199734, 0.24577366188168526, 0.09537139455122606, 0.26648488481129917, 0.17327660561672278, 0.38843871653079987, 0.2880712279251644], [0.04687728047637003, 0.18633208077933106, 0.31558186028684887, 0.07289261503943376, 0.10023302332098995, 0.18217699016843522, 0.017382233436884623, 0.12021378294697829, 0.055140364582517316, 0.09953471579189811, 0.06044610470001187, 0.019942651403003504, 0.08127512130886316, 0.042863915474819284, 0.05996242458266871, 0.2470363884099892, 0.14756521742258752, 0.010614486145121711, 0.06528480577149562, 0.1253856040005173, 0.01944216906226107, 0.026848819838570695, 0.0731709161773324, 42.815793309892925, 75.63881942204067, 62.330191203526084, 58.963636125837056, 92.29610415867397, 66.96775940486363, 48.484060764312744, 46.91283335004534, 47.82186964579991, 32.021603516169954, 44.57153361184256, 88.31157629830497, 65.2341421672276, 70.27268396105084, 69.2133685520717, 68.40053353990827, 63.37763908931187, 66.02668843950543, 53.01214967455183, 41.1954699243818, 12.942714367594037, 8.08478057384491, 22.614819594791957, 28.919279745646886, 36.32172203063965, 36.17889486040388, 31.69123751776559, 35.65135983058384, 29.64523274557931, 24.85303933279855, 18.6047032560621, 16.09724603380476, 19.80948441369193, 26.480877195085796, 27.62397571972438, 25.441105331693375, 11.86778722490583, 6.497764681066785, 6.024836412497929, 10.452803083828517, 14.255334172930036, 14.703578097479683, 18.78522961480277, 24.14122244289943, 23.40336196763175, 27.958757298333303, 23.67529535293579, 34.74809748785836, 49.007815974099294, 22.043799264090403, 38.26188836778913, 18.55952606882368, 1.8929541962487357, 0.962039760180882, 0.6977668181061745, 0.3705050359879221, 2.2965188154152463, 5.043470672198704, 1.0054835890020644, 3.4894018343516757, 5.923463497843061, 11.832360965864998, 11.595664501190186, 6.870600240571158, 13.210263439587184, 16.40202181679862, 10.610939741134644, 12.13081909929003, 11.905535919325692, 6.048888470445361, 7.452074136052813, 9.118333799498421, 4.883559184415, 0.4907148427196911, 0.016150923079944084, 0.7670442664197513, 0.49691497002329144, 0.17575770962451184, 0.034704399561243396, 0.5509246204580579, 0.4635727362973349, 3.819096028804779, 23.788436344691686, 42.33861187526158, 31.15392984662737, 18.139172213418142, 34.08667414528983, 29.864260809762136, 9.621042915752955, 11.240254589489528, 16.594005755015782, 17.680799552372523, 21.955461604254587, 19.98240770612444, 17.067233664648874, 12.09217061315264, 5.454774498939514, 5.575231075286865, 10.11833677973066, 23.03252444948469, 25.10947128704616, 32.04237515585763, 41.467276505061555, 52.51047236578805, 64.44650132315499, 67.57537937164307, 61.19914954049246, 53.04802322387695, 35.32201869147164, 30.037969248635427, 29.788841588156565, 30.435725825173513, 48.518833024161204, 41.97286912373134, 28.913639545440674, 28.647683347974503, 5.417302863938468, 6.66711790221078, 11.220599004200526, 15.730639968599592, 8.514621325901576, 9.65780062334878, 23.176888908658707, 44.19582714353289, 65.2668820789882, 29.94885860170637, 29.544188567570277, 35.11177315030779, 26.790344749178203, 39.51169906343733, 57.08711528778076, 71.13559464045933, 43.84060396466936, 32.32599714824131, 53.39973061425345, 7.457992264202662, 0.08394400988306318, 0.05402644417647805, 0.10785179092947926, 0.06362025759049825, 0.07837891671806574, 0.037317156326025724, 0.032668994673128636, 0.02061397529074124, 0.10623319313994475, 0.01947448598886175, 0.13777102583221026, 0.10622129842106785, 0.039791366418025324, 0.07468573203576462, 0.0824215401496206, 0.1890417153814009, 0.16131871512957982, 0.0749923280839409, 0.17232862434216908, 0.31971147869314465, 0.20370432787707873, 0.07795650831290654, 0.07870175689458847, 0.06841147478137698, 0.12897528495107377, 0.028924963969205107, 0.07397605904511043, 0.05057498420189534, 0.012253389095089265, 0.13620158790477685, 0.058159129561058114, 0.07055078034422227, 0.13040193196918282, 0.12956939664270195, 0.018777884975341812, 0.05619193101301789, 0.12365889522646155, 0.10539386567792722, 0.0358091665298811, 0.3699199759534427, 58.34297439030239, 85.09303174700055, 64.79145853860038, 73.3002711704799, 98.69860512869698, 61.645626885550364, 43.15163796288626, 28.64725603376116, 42.48711919784546, 33.878544330596924, 57.683145659310476, 84.13214451926095, 74.23442867824009, 72.63339696611676, 73.81493813650948, 69.32540825435093, 67.60678522927421, 70.45292718069894, 60.62421389988491, 39.9113837650844, 13.884380272456578, 16.438869850976126, 31.452994210379465, 30.04957274028233, 37.18914903913225, 35.73898008891514, 31.759722437177384, 28.827794551849365, 26.840324878692627, 25.00604040282113, 18.46315802846636, 15.950076239449636, 19.910749197006226, 22.267750126974924, 25.11014699935913, 22.235621656690324, 13.938739504132952, 11.12676271370479, 8.904531649180822, 8.520427414349147, 12.775038702147347, 16.87376802308219, 20.20719235283988, 21.089947087424143, 24.981857197625295, 25.84726401737758, 27.712954350880214, 34.16607468468802, 55.499378953661235, 24.707757711410522, 41.13347462245396, 28.95301672390529, 4.482118325574057, 0.9334958004099982, 0.39498174829142435, 0.39020727734480587, 2.0715235514300208, 6.326151992593493, 2.5745811632701328, 6.086411348411015, 11.599490353039332, 22.22146817616054, 23.259006193705968, 20.44650047166007, 27.746832030160085, 21.033873387745448, 17.303620065961564, 22.454700095312937, 16.974768774850027, 11.66571797643389, 8.713143518992833, 9.700744833265032, 6.926326096057892, 1.2719880427633012, 0.36966365256479805, 2.329912943499429, 1.1940261061702455, 1.029673850962094, 0.24919885237302097, 0.31009528040885925, 3.129498826605933, 7.097316486494882, 24.936539309365408, 45.85607140404837, 35.6736044883728, 19.69976888384138, 45.18066481181553, 32.435973235539024, 14.754515341350011, 15.320195981434413, 15.85360050201416, 17.302753278187343, 19.39146167891366, 17.491579260144913, 13.157823647771563, 11.861203806740896, 8.636156610080175, 10.480747001511709, 12.958278332437787, 20.607394695281982, 19.41709532056536, 19.753320387431554, 29.005044834954397, 39.691605295453755, 46.132932799203054, 50.1298006602696, 45.081177030290874, 42.770421573093955, 32.74288558959961, 26.65433723585946, 29.431415830339702, 34.1047603062221, 42.477082524980815, 28.78636418070112, 14.809576341084071, 34.24749020167759, 6.245679259300232, 5.708397643906729, 12.989563465118408, 17.192198753356934, 13.46493055139269, 11.605555261884417, 25.20351689202445, 50.25426721572876, 66.16572189331055, 38.523630482809885, 30.620016370500835, 29.39519487108503, 20.269427367619105, 41.199284485408235, 54.53341259275164, 75.88158253261021, 62.02790982382638, 39.35383251735142, 63.95653520311628, 14.668915271759033, 0.12736083301050322, 0.34994670056871, 0.058899798031364164, 0.06728626694530249, 0.06130357618842806, 0.06809267867356539, 0.014518951365192021, 0.0219645330881966, 0.05347556534356304, 0.16292691097727843, 0.09499000358794417, 0.029154393622385602, 0.030315099017960683, 0.10958655391420637, 0.03689552823613797, 0.05354846714596663, 0.15081997348793916, 0.33701811145458904, 0.3373191367302622, 0.39249193189399584, 0.29346077729548725, 0.244265577090638, 0.2034070481147085, 0.12099986576608249, 0.16726279045854295, 0.1799418551049062, 0.08900645109159605, 0.13859632797539234, 0.12830930283027037, 0.1756190713495016, 0.16881329725895608, 0.1662539853049176, 0.3142770917287895, 0.1974476378943239, 0.10241283063909837, 0.20477862523070403, 0.2255182380654982, 0.23864649289420672, 0.17329202193234647, 0.5796262174844742, 72.35289818899972, 98.93660872323173, 74.25491196768624, 83.7549546105521, 113.28641755240304, 84.7153137751988, 67.07240622384208, 58.47199548993792, 59.19729709625244, 43.4611941065107, 55.932863167354036, 101.51699597494942, 77.4161686216082, 83.50704983302525, 77.12449714115688, 79.11052853720528, 65.40703419276646, 77.85287679944719, 64.90130261012486, 52.30745642525809, 17.781039476394653, 14.27053769997188, 30.66973420551845, 35.52254717690604, 47.4091397012983, 45.50024373190743, 41.91824933460781, 41.88428653989519, 37.262049538748606, 30.790733609880718, 23.964387314660208, 21.329812799181255, 27.569656440189906, 33.30533879143851, 36.49946389879499, 32.00240216936384, 17.452735355922155, 14.739206722804479, 14.364643233163015, 20.229582922799246, 23.441493681498937, 21.934511048453196, 27.548249040331157, 33.548126220703125, 32.949570178985596, 35.92218671526228, 32.56709963934762, 48.07163654054914, 68.75955390930176, 30.669261728014263, 46.323921407972065, 39.373283999306814, 8.804545334407262, 1.7570734875542777, 0.826029261308057, 0.7958224564790726, 5.475497501237052, 9.244018026760646, 3.264910097633089, 8.828953487532479, 14.575005156653267, 26.197692939213344, 30.118978296007427, 35.38744292940412, 37.53779922212873, 31.30874613353184, 26.60057554926191, 32.70213787896292, 29.243824890681676, 22.44874722617013, 19.448395218167985, 13.933008977345057, 6.487054032938821, 1.3568816759756632, 0.4472760893404484, 2.0314087782587325, 1.7813614585569926, 1.0784371771982737, 0.24575469004256384, 0.5535106531211308, 4.816301490579333, 14.529586519513812, 36.384120328085764, 49.118632793426514, 38.39056553159441, 29.51093101501465, 50.15309797014509, 43.62807246616909, 15.689715078898839, 19.875726802008494, 25.641956908362253, 24.529032673154557, 29.62491273880005, 25.015637602124894, 26.312965290887014, 22.645895412990026, 12.66110908985138, 11.840364422116961, 15.631082705089025, 35.76270818710327, 35.81055348260062, 38.11332198551723, 47.012421880449565, 54.65560361317226, 65.59033461979458, 70.94466509137834, 66.48591572897774, 62.16422653198242, 41.58624356133597, 39.20136819566999, 38.51373972211565, 38.461444105420796, 55.37461709976196, 52.720624106270925, 36.81874752044678, 37.49828829084124, 7.916397060666766, 9.124084302357264, 22.58446638924735, 25.944141013281687, 21.49872350692749, 19.788389682769775, 34.085756983075825, 58.948662757873535, 75.72797175816127, 42.35572528839111, 37.17190361022949, 48.19819450378418, 34.38692317690168, 59.17540332249233, 67.18195847102574, 83.85131222861153, 58.344273703438894, 45.5830523627145, 78.51267773764474, 16.117996828896658, 0.2975272105208465, 0.6758319522653307, 0.23206554459674017, 0.2781728133559227, 0.34472778918487684, 0.14776763798935072, 0.2608528270253113, 0.1104932531182255, 0.13497516299997056, 0.1888613879148449, 0.372180447514568, 0.2949557527899742, 0.10807491359966141, 0.1750666895615203, 0.13013460274253572, 0.22923124954104424, 0.2515921268079962], [0.052185344576303444, 0.19719971476921014, 0.06110724208078214, 0.053675217487450154, 0.11255080199667386, 0.15107454625623568, 0.019436538917943835, 0.030298692041209767, 0.050163897153522284, 0.13245432398148946, 0.0029126372246537358, 0.11750498972833157, 0.031389827241322825, 0.02617551462857851, 0.016464711599318043, 0.1769086950059448, 0.017561573634988496, 0.037678493186831474, 0.10217110932405506, 0.04417746766869511, 0.05311176200796451, 0.026852205728313754, 0.17104022204875946, 8.1973101241248, 76.52836949484688, 76.884763445173, 62.3071231842041, 72.55777972085136, 86.71955639975411, 49.10610866546631, 40.446659088134766, 46.75174283981323, 40.2132899420602, 35.28394603729248, 82.80298886980329, 68.4181819643293, 69.95052378518241, 65.27730437687465, 63.79794257027762, 51.56780331475394, 36.58274153300694, 20.142370871135167, 10.692653162138802, 0.8756376079150608, 11.770019122532435, 47.46503448486328, 33.994231837136404, 35.662963322230745, 30.24439675467355, 33.77070481436593, 32.247364384787424, 33.515883105141775, 30.41556215286255, 29.06094135556902, 29.126070295061382, 30.36016069139753, 37.4518951688494, 33.32764250891549, 25.55250927380153, 17.60608904702323, 6.223487147263118, 6.876877503735678, 6.165503995759146, 13.357401098523821, 20.74154356547764, 19.14419092450823, 28.56651622908456, 25.899300813674927, 31.989815507616314, 27.210613489151, 43.39227492468697, 44.99679115840367, 19.771427392959595, 39.648873874119346, 30.58924627304077, 7.790294204439435, 0.26641353006873814, 0.4843185373714992, 0.5068609906094415, 1.534146398305893, 4.238903147833688, 3.880509853363037, 10.393965738160269, 5.212939407144274, 8.3069292477199, 12.309661388397217, 5.9064421483448575, 13.096917475972857, 6.1258128455707, 10.079928874969482, 9.934858305113655, 8.950407998902456, 7.563077688217163, 9.000232662473406, 7.365750585283552, 2.5964551780905043, 0.4966001297746386, 0.06341743668807404, 0.39343368421707836, 0.5185726678797177, 0.3407966558422361, 0.04570985419143524, 1.114325491445405, 0.5176416092685291, 5.904000290802546, 22.313479696001323, 43.21395288194929, 30.960106372833252, 19.083354234695435, 26.234966550554546, 30.83109222139631, 10.543130534035818, 8.71049017565591, 20.362804208483013, 21.014915227890015, 26.40570637157985, 24.73619668824332, 15.735710416521345, 9.861464483397347, 9.323562741279602, 10.268516881125313, 26.176217794418335, 33.90279006958008, 38.95997040612357, 47.473664147513254, 48.65682077407837, 56.69030366625105, 64.76479135240827, 73.84694153921944, 69.88263988494873, 59.353395325796946, 48.9104300226484, 48.23998097011021, 24.994101660592214, 25.713228055409022, 52.08531904220581, 34.19278703417097, 37.179880142211914, 34.80045216424124, 25.376494032996042, 0.18356950687510626, 2.672724251236234, 4.344640399728503, 5.056278807776315, 10.368540542466299, 9.981343490736824, 22.535862003053936, 58.69678361075265, 33.78735269818987, 30.13716867991856, 36.00759744644165, 27.955581971577235, 37.24029472896031, 67.60272053309849, 57.085548468998496, 32.37366526467459, 56.68623897007534, 28.181332417896815, 0.37000137301427977, 0.06098632714045899, 0.12243621583495821, 0.24603959332619393, 0.17496215445654734, 0.16575440711208753, 0.1339782186384712, 0.02199333350706313, 0.04205126461705991, 0.0280779164750129, 0.03160134696268609, 0.08466173029903855, 0.07767492306551763, 0.029202800310615982, 0.08178835841161863, 0.04113866215837853, 0.09964033655290093, 0.09039061503218752, 0.07091315875628165, 0.28569355979561806, 0.11362431224967752, 0.05164366667824132, 0.13940808655960218, 0.16017021318631514, 0.0777774022093841, 0.08808621511395488, 0.024097455332853963, 0.11709795014134475, 0.022501396780301417, 0.04719093328874026, 0.02522792011898543, 0.06953269283154181, 0.04249131493270397, 0.20090433955192566, 0.038767965976148844, 0.031699883818094216, 0.24272679537534714, 0.05944386776536703, 0.07032290114355938, 0.11217156877475125, 0.30583123064466883, 16.10829540661403, 94.33913162776402, 80.87987341199602, 72.19881493704659, 87.50002670288086, 77.59995542253766, 45.68106017793928, 26.08676494870867, 38.80944463184902, 39.16434471947806, 47.414375168936594, 88.65551212855748, 72.66890226091657, 77.26193250928605, 72.26813016619, 71.11830752236503, 55.17071178981236, 36.24442679541451, 20.201248168945312, 8.882161923817225, 11.342107364109584, 22.67789360455104, 45.15137120655605, 35.6603855405535, 33.83486795425415, 32.682186126708984, 32.62948056629726, 31.7605562210083, 28.42761652810233, 24.30703251702445, 27.1919367313385, 26.385136229651316, 26.06223954473223, 28.96241589954921, 28.712522200175695, 21.64049802507673, 17.40001937321254, 10.335329021726336, 10.981950095721654, 7.801358342170715, 12.607973609651838, 22.105238710130962, 22.322673899786814, 25.73465803691319, 25.649255990982056, 29.939951011112758, 28.740288938794816, 40.30564192363194, 53.090170996529714, 24.44526171684265, 41.428901604243684, 36.41400105612618, 10.411019223076956, 0.291360005736351, 0.2311941156429904, 0.455880700477532, 3.3500101140567233, 9.622342228889465, 2.6979457778590064, 3.83048586334501, 9.89781311580113, 12.020170773778643, 14.689622640609741, 16.96455839702061, 27.314921583448136, 10.14466871534075, 13.634907807622637, 20.5027756690979, 16.35090218271528, 9.692951560020447, 9.742105722427368, 9.814105561801366, 3.7209570663315907, 0.3999626024493149, 0.332138576145683, 1.0528511958462852, 0.5230935567191669, 0.274331409484148, 0.05588918565107243, 0.5847979028310094, 1.4205473682710101, 6.356733620166779, 29.04752959523882, 46.48566852297102, 31.609047276633127, 17.72626508985247, 34.48362820489066, 35.145579610552105, 14.41333360331399, 14.685940095356532, 19.000962495803833, 18.456072602953228, 23.389107738222393, 22.436605249132427, 12.871467539242335, 13.981910399028234, 14.464559197425842, 16.953866856438772, 22.715023040771484, 30.386188643319265, 33.543547357831685, 35.34480530875069, 38.39153133119856, 46.10686315808977, 56.1932156426566, 61.95550959450858, 58.45503493717739, 51.10379913875035, 42.17272015980312, 44.548813002450125, 29.14921474456787, 29.810398374285015, 45.18475382668631, 28.275032349995204, 35.25152226856777, 37.53660413197109, 33.59086806433541, 1.1666066689150674, 2.7701523261410848, 6.505083305495126, 8.483193755149841, 15.910514933722359, 20.59064953667777, 29.199630873543875, 62.11694404057094, 40.430226598467144, 30.81692831856864, 25.088454723358154, 28.61172468321664, 39.20560312271118, 68.5624474116734, 72.26911681038993, 40.645207336970735, 56.43305703571865, 41.77437993458339, 0.16576166743678705, 0.42213338134544237, 0.07892587701124804, 0.23075865900942258, 0.1796621358288186, 0.2877857003893171, 0.05187260100085821, 0.06855357358498232, 0.044063863943197897, 0.029889565959040607, 0.04254574701189995, 0.05759807609553848, 0.10263038253677742, 0.13457714792873177, 0.053691122348287275, 0.07341972818332058, 0.10038207710853644, 0.09024456036942345, 0.14217584447136947, 0.38229379483631676, 0.22300950411174977, 0.1876121370920113, 0.20290544788752282, 0.19274904073349067, 0.1639306949717658, 0.13192643730768136, 0.20288467114525183, 0.1867946788136448, 0.16472242320222513, 0.3088474545095648, 0.20060403352337225, 0.18489050599081175, 0.15103909958686146, 0.27113401676927296, 0.1734724308231047, 0.12553633376955986, 0.29284987864749773, 0.14994728245905467, 0.1597873701580933, 0.2755635476538113, 0.4009281577808516, 20.981160879135132, 112.22168949672154, 87.19131823948452, 83.39599677494594, 92.53439957754952, 102.44469165802002, 64.88238266536167, 54.28387498855591, 57.58956037248884, 49.78894288199288, 43.707372256687705, 99.08014460972377, 77.13794885362897, 83.54700197492326, 78.70487880706787, 75.14037649972099, 58.91454015459333, 48.04996510914394, 22.742147071020945, 16.388337339673722, 9.614057370594569, 20.311769689832413, 56.30810758045742, 41.625671114240376, 47.55849470411028, 37.488105705806184, 43.046577726091655, 36.309472356523784, 38.87883629117693, 35.665631430489675, 36.76505878993443, 35.947558062417166, 38.38661895479475, 43.50508935110909, 41.82687357493809, 34.30687298093523, 25.226826361247472, 12.27661575589861, 14.106421249253408, 13.993379269327436, 22.489326442990983, 28.79987668991089, 27.751061746052333, 36.773914269038606, 34.492438520704, 41.71154390062605, 38.00093487330845, 53.724287918635774, 61.102124895368306, 26.55669767516, 44.49170575823103, 45.14752537863595, 14.131980197770254, 0.26353361031838823, 0.749468635235514, 0.6237360962799617, 3.281225553580693, 9.021853719438825, 9.950426612581525, 14.19969734123775, 11.240473457745143, 13.839582630566188, 29.494748660496303, 32.517937660217285, 42.45660270963396, 17.546614204134258, 19.732368094580515, 29.729913915906632, 28.805586372103008, 24.509480442319596, 20.046450989586965, 11.891068032809667, 5.518271480287824, 0.46896328989948544, 0.3952193169721535, 1.647066893322127, 0.6983940015946115, 0.6614852249622345, 0.14444753900170326, 1.9508240052631922, 2.292811951466969, 9.364248786653791, 34.6752803666251, 51.487169470105854, 38.31596967152187, 29.41202688217163, 39.61665160315377, 46.32555423464094, 13.82394049848829, 16.203690699168614, 31.795582090105327, 29.393221582685197, 34.22450903483799, 33.345561913081575, 23.697319405419485, 17.81629637309483, 16.803235122135707, 18.63682130404881, 33.859516688755576, 43.76598031180245, 47.069695881434846, 51.36886249269758, 48.06177704674857, 58.2138386453901, 64.6879859651838, 76.62579713548932, 74.07104873657227, 63.360518727983745, 56.06963498251778, 60.934701102120535, 32.08140318734305, 31.966327122279576, 60.009506770542686, 48.7286581993103, 49.39705753326416, 45.02652597427368, 33.45165395736694, 1.04842942740236, 3.5153518361704688, 8.698480214391436, 14.802188668932233, 22.05293267113822, 30.037892818450928, 39.38924401147025, 72.70135034833635, 43.39527307237898, 38.344783851078574, 43.732635906764436, 41.57032871246338, 50.80607925142561, 78.52041108267647, 74.80783571515764, 45.990706648145405, 74.09751442500523, 49.26325607299805, 0.3275007892932211, 0.6679065003991127, 0.29876909245337757, 0.6587775988238198, 0.43068387252943857, 0.3380568671439375, 0.3353669371988092, 0.20452352320509298, 0.15008501149713993, 0.12596598214336804, 0.08036595223737614, 0.1791065920676504, 0.1083357763875808, 0.1604655116264309, 0.24539658640112194, 0.13271448787833962, 0.2324665045099599, 0.20122323743999004], [0.11688046609716755, 0.23455609381198883, 0.1353335923382214, 0.11125021999967949, 0.031161571453724588, 0.119434281917555, 0.07791137894881622, 0.0761820035321372, 0.06078117207757064, 0.05436217991103019, 0.10896329914352723, 0.05986495981259005, 0.0217840529512614, 0.034682937498603544, 0.03208145120048097, 0.05555948887818626, 0.054457646395478926, 0.0948902317988021, 0.10154832274253879, 0.06383096306983914, 0.1599751750805548, 0.058202460807349, 0.14198411761650018, 0.28298756214124815, 34.71792146137783, 77.11562429155622, 74.37567860739571, 72.23915617806571, 92.4141332081386, 65.32197434561593, 32.80048268181937, 40.40141589300973, 39.206600189208984, 39.08506229945591, 76.60923263004848, 69.45538125719342, 61.14411285945347, 52.83504009246826, 43.64136784417288, 20.615079402923584, 10.4021863256182, 7.1158603600093295, 3.4509526746613637, 4.504732540675572, 28.66300412586757, 51.19356639044625, 33.48689522062029, 31.20805631365095, 28.3378301688603, 28.94845870562962, 32.670283862522666, 46.907170568193706, 46.186340127672466, 46.1819349697658, 50.95853315080915, 53.69142293930054, 51.853843280247276, 47.731254713875906, 35.03141723360334, 27.55608834539141, 13.949817538261414, 6.50724332673209, 7.306260108947754, 13.051861882209778, 21.494613647460938, 23.501298563820974, 27.592347519738333, 33.2362493787493, 31.966486930847168, 29.701919623783656, 36.77636350904192, 30.125731945037842, 16.298457179750713, 39.40186194011143, 30.138384614671978, 14.537620374134608, 1.6171109293188368, 0.5174510766352926, 0.7670552315456527, 2.269472518137523, 6.688208724771227, 8.01010741506304, 7.917107513972691, 2.134968204157693, 7.045741311141422, 15.14249232837132, 9.922289882387433, 6.558383371148791, 2.5183209478855133, 7.749856557164874, 14.27448775087084, 9.990529009274074, 7.818349293300083, 11.465036630630493, 7.509675570896693, 0.4605926647782326, 0.11896434213433947, 0.14485877193510532, 0.23765284621289798, 0.8124429817710603, 2.2066466893468584, 0.9764901676348278, 0.991992250084877, 0.8145994203431266, 3.0368545864309584, 12.340841429574148, 34.99121495655605, 34.50098133087158, 21.061013051441737, 26.83594056538173, 22.730500153132848, 20.355991499764578, 16.09032736505781, 19.796406166894094, 21.247502701623098, 23.231661558151245, 18.428833927427018, 11.20379912853241, 7.422148244721549, 11.779999341283526, 23.297290767942155, 41.3114457811628, 38.325294154030935, 46.65990155083792, 48.62379251207624, 52.40331377301897, 62.58138247898647, 62.86554990495954, 62.80610111781529, 61.53852735246931, 55.53943184443882, 54.78427035467965, 47.067055565970286, 26.857724905014038, 25.64709857531956, 45.56812763214111, 19.598618745803833, 19.512448923928396, 26.051574059895106, 31.72184780665806, 5.105505057743617, 0.6019544707877296, 1.41586525951113, 3.5396822563239505, 6.515614168984549, 14.362391148294721, 21.731031315667288, 40.73498501096453, 30.162915229797363, 31.24438844408308, 36.51410027912685, 28.43046007837568, 54.62057079587664, 72.65177495138985, 38.105494839804514, 47.4392740385873, 51.434370109013145, 1.971806913614273, 0.15199910450194562, 0.12481377539890152, 0.06387966831347772, 0.033870320567595105, 0.11014932407332317, 0.07328710172857557, 0.075655568923269, 0.02377240652484553, 0.07172685795064483, 0.034081887786409686, 0.05418147925021393, 0.06715830881148577, 0.01467206618482513, 0.08361082883285624, 0.05699493310281208, 0.1105027933205877, 0.09771916642785072, 0.10190473683178425, 0.11994272177772862, 0.0808167437623654, 0.31990114280155724, 0.08119191934487649, 0.01905746684808816, 0.08925487633262362, 0.07512507667498929, 0.030815647515867437, 0.03985429714832987, 0.011494723331582333, 0.06370404309460095, 0.016262693064553396, 0.03176010719367436, 0.07180531016950097, 0.021860825795946375, 0.051632915290870836, 0.014108508925086685, 0.03843305805431945, 0.007489889211553548, 0.0739744102050151, 0.13804885878094605, 0.08923199613179479, 0.027235257406053797, 0.8455196097493172, 60.73721245356968, 83.14841161455426, 75.32411466326032, 84.97114644731793, 89.35271521977016, 61.07647909436907, 31.340249265943253, 31.22424909046718, 38.6875593321664, 49.04594421386719, 85.73726872035435, 74.00099005017961, 68.59331825801304, 62.36782264709473, 46.76226936067854, 21.589004925319127, 11.005570496831622, 9.960664783205305, 9.52404693194798, 12.019044297082083, 30.972852843148367, 50.542916229793, 29.33745186669486, 29.249751704079763, 26.506611585617065, 30.77629177910941, 27.178118501390728, 39.114682470049175, 34.88539736611502, 34.23056091581072, 39.84089081627982, 40.107079778398784, 38.97992563247681, 36.279014928000315, 27.827981778553553, 26.06394706453596, 17.463388681411743, 12.943111283438546, 9.75506237574986, 10.64664305959429, 19.7510552746909, 24.228215626307897, 24.48656702041626, 31.41833312170846, 32.004840987069265, 31.62829031263079, 37.22789914267403, 40.976990767887656, 17.787808758871897, 45.081468854631694, 34.36753075463431, 15.085431984492711, 2.456512595926012, 0.35032250040343826, 0.6530006602406502, 1.153201965349061, 4.593567430973053, 4.9528014574732095, 10.078365530286517, 5.854526945522853, 11.046008144106183, 13.377479655402047, 14.40087114061628, 18.866400207792008, 1.9337620522294725, 10.116208893912178, 24.42962827001299, 17.404858793531144, 12.53550216129848, 11.755621586527143, 8.884949888501849, 1.6040048897266388, 0.24669606238603592, 0.38696520988430294, 0.37948284138526234, 2.2341999879905154, 2.457910486630031, 0.7476603665522167, 0.8976896160415241, 1.5093195076499666, 3.32962019102914, 20.746476786477224, 45.690402030944824, 35.626589502607075, 18.594114201409475, 31.473797116960796, 27.17665590558733, 23.3372220652444, 19.001000710896083, 19.423899344035558, 18.97074999128069, 21.877334322248185, 15.334021159580775, 10.631943276950292, 12.837932927267891, 17.030760833195277, 24.922543900353567, 33.849038805280415, 35.14788293838501, 40.453020163944785, 46.4599323953901, 49.370605741228374, 59.4496556690761, 57.76246976852417, 60.66112273080008, 58.85193688528878, 51.39149624960763, 48.970882824489046, 43.74456248964582, 25.05614733695984, 27.238560880933488, 46.08144664764404, 24.27584900174822, 25.753439017704554, 33.263472420828684, 43.55513027736119, 7.796674387795584, 0.5776640027761459, 1.391485333442688, 4.264483375208719, 8.375608716692243, 16.112634556634085, 29.3396474974496, 46.29025043760027, 41.84298644747053, 27.357117993491038, 26.482270308903285, 31.25267764500209, 52.76098271778652, 81.80032907213483, 47.34910726547241, 49.942949703761506, 65.666257585798, 5.2757632817540845, 0.2984525965792792, 0.14452014224869864, 0.13816714100539684, 0.11317210258649928, 0.12474611188684191, 0.13583489400999887, 0.06616684701293707, 0.05051928326221449, 0.042376045403735976, 0.040754953998007944, 0.040477677447987456, 0.036352255780782015, 0.02843865452866469, 0.04735765612817236, 0.028412788773753812, 0.028249266923272183, 0.011518015742434986, 0.05939941693629537, 0.25798978922622545, 0.2773350668804986, 0.3249816601829869, 0.18589355716747896, 0.10048488873456206, 0.17663973729525292, 0.3245787189475128, 0.14563591166266374, 0.18533620850316115, 0.12238447075443608, 0.14924858137965202, 0.1273650670690196, 0.14447375759482384, 0.1630351644541536, 0.15404673319842133, 0.1989067324570247, 0.19240787332611425, 0.11918559883322034, 0.1881471076714141, 0.16528026041175636, 0.3115912058523723, 0.17889127933553287, 0.1963017958083323, 1.1652670779398508, 78.49065889630998, 93.21233531406948, 88.50442355019706, 94.89386885506767, 103.93379483904157, 83.09060955047607, 42.50093221664429, 52.65449810028076, 47.8612242426191, 49.805635929107666, 92.47014958517892, 84.31355503627232, 72.23368794577462, 72.68946198054722, 56.39675269808088, 28.894922835486277, 16.219067062650407, 15.646113395690918, 11.857183405331202, 9.355566143989563, 34.62293611254011, 59.64181504930769, 43.84038162231445, 44.89488887786865, 35.55426222937447, 39.54495661599295, 38.85356569290161, 54.18094784872872, 51.08986105237688, 50.238852637154714, 55.387266295296804, 61.172774178641184, 60.04929910387312, 57.45426504952567, 43.10532474517822, 38.98063434873308, 21.9083753994533, 13.891368423189435, 12.670621173722402, 20.734402554375784, 29.645184108189174, 34.44198765073504, 36.46360771996634, 44.31684739249093, 41.18405750819615, 40.500184535980225, 44.68345866884504, 43.589610712868826, 19.187314919063024, 47.35822677612305, 40.099971771240234, 20.079399347305298, 1.9701669216156006, 1.276144259742328, 2.102924849305834, 7.6297699723924906, 11.367519531931196, 13.732582109315054, 16.449476276125225, 4.560211735112326, 10.094867501940046, 22.1852993283953, 25.193433318819316, 30.8827486038208, 5.538878534521375, 15.11202621459961, 37.02399035862514, 30.582471779414586, 28.388600655964442, 21.73018537248884, 10.025387253080096, 2.493955569607871, 0.16373249489281858, 0.7735204760517392, 1.3874536412102836, 3.3993390670844486, 7.59042579787118, 2.152422513280596, 3.549687445163727, 1.163730874657631, 6.42164933681488, 27.627840655190603, 47.42044789450509, 43.012260573250906, 26.427393436431885, 39.85709054129464, 33.17570972442627, 27.599269662584575, 25.145737409591675, 27.959971496037074, 28.968361820493424, 29.476308141435894, 24.970795665468486, 17.44967293739319, 18.044275454112462, 18.51839620726449, 34.42080954142979, 46.76035860606602, 46.30446645191738, 49.77062743050711, 49.736407552446636, 50.58922944750105, 63.32102516719273, 60.46391201019287, 67.98588589259556, 64.31696605682373, 59.713569096156526, 59.54062843322754, 54.621286460331504, 32.584959983825684, 33.07978984287807, 57.06443289348057, 30.103793007986887, 29.454428264072963, 36.598944732121055, 42.53177874428885, 8.830049565860204, 1.5755176012005125, 3.24545470731599, 6.370791128703526, 12.839071563311986, 23.370175634111675, 37.569847788129536, 56.159221581050325, 42.284332547869, 39.93353809629168, 46.59154517310006, 45.13791254588536, 68.41249138968331, 93.28871686117989, 51.85142878123692, 63.09587574005127, 75.12255437033517, 4.082043656281062, 0.47370076711688724, 0.24645786945308956, 0.24878033197351865, 0.32413696550897186, 0.333227380578007, 0.2179108155625207, 0.17151854852480547, 0.12979632589433873, 0.15370062605610915, 0.13847602371658596, 0.11940313716019903, 0.1584875684763704, 0.09830428753048182, 0.2577299645968846, 0.23350308888724872, 0.11379857361316681, 0.16609907576016017, 0.19043058156967163], [0.17517167249960558, 0.21999683577035153, 0.10423095165086643, 0.16892201213964395, 0.026342106850019524, 0.048804045122648985, 0.08107026480138302, 0.17834049889019557, 0.025781155164752687, 0.02772504773123988, 0.06978077201970986, 0.03074444883636066, 0.01686034331630383, 0.0274662917945534, 0.006807716821120786, 0.06942802880491529, 0.10157606803945132, 0.027477343433669636, 0.08890929844762598, 0.060216664868806086, 0.1852480260921376, 0.11124585701950959, 0.12329849813665662, 0.10167600946234805, 8.68617582321167, 81.50778211866105, 66.67585168566022, 53.77242156437465, 82.29939038412911, 80.91180733272007, 33.78060252325875, 35.367779527391704, 43.304699829646516, 38.564635276794434, 76.69006102425712, 63.72468771253313, 47.368027210235596, 24.26822509084429, 9.762711473873683, 4.811320500714438, 6.432324809687478, 10.764737248420715, 2.885346293449402, 33.294367585863384, 36.99652760369437, 34.94938332693917, 51.22145298549107, 26.878437485013688, 40.74541425704956, 30.698888846806117, 56.267887932913645, 57.11769083568028, 64.73735291617257, 64.92474583217076, 62.01034477778843, 62.36712782723563, 65.99393463134766, 61.01948996952602, 49.83219541822161, 35.47387504577637, 27.27591265950884, 15.580206257956368, 8.608634795461382, 13.693831137248448, 23.90128377505711, 27.196929012026104, 27.52714388711112, 30.88099765777588, 26.494509560721262, 27.882987192698888, 26.97971269062587, 24.44882787976946, 17.993009907858713, 35.55757999420166, 21.24352833202907, 11.859632645334516, 1.0330499155180795, 0.35445217309253557, 0.31547267043164795, 1.438262777669089, 0.9227237041507448, 2.6181811094284058, 7.100469665867942, 3.332244873046875, 7.432214447430201, 13.247796739850726, 12.489646656172615, 4.562719600541251, 2.571020211492266, 8.165499533925738, 16.353419167654856, 10.922735810279846, 7.798463548932757, 13.068198834146772, 7.717673369816371, 1.115936930690493, 0.2712910297725882, 0.05603019540597286, 0.6418479329773358, 1.9835341700485773, 1.677474381668227, 0.4095887073448726, 0.4620771365506308, 0.26946311071515083, 2.3083392211369107, 7.54531809261867, 32.042614868709016, 33.152422836848665, 15.509923492159162, 21.790028469903127, 20.508066722324916, 24.832754067012242, 23.534609964915685, 22.974677222115652, 19.100519759314402, 20.327217272349767, 14.376481226512364, 10.366923349244253, 11.049993804522924, 23.78615733555385, 44.43412603650774, 54.626900604793, 49.93422624043056, 46.5772978918893, 44.20613479614258, 53.310442788260325, 58.248353821890696, 59.87838731493269, 52.123464652470176, 58.674076897757395, 60.01445388793945, 62.20210811070034, 60.87293856484549, 59.38999148777553, 32.8013789994376, 45.197020871298655, 31.99952561514718, 35.533410685403005, 24.2281722000667, 27.700081075940812, 15.222728388650076, 0.41408853445734295, 1.3024275579622813, 1.53183471092156, 3.364857328789575, 6.398196126733508, 21.77693111555917, 26.74374144417899, 23.335952281951904, 38.60827691214425, 37.59150879723685, 38.134076254708425, 67.90471703665597, 60.326136180332725, 42.252662658691406, 55.05064344406128, 22.83275158064706, 0.4123327572430883, 0.2651790034558092, 0.1851160917431116, 0.08769832378519432, 0.13028739525803498, 0.05484308821282216, 0.07995403398360525, 0.0381619833143694, 0.035094418097287416, 0.04619378536673529, 0.03090541430615953, 0.08426782715001277, 0.04236651537939906, 0.07829209816242967, 0.09051330773425953, 0.01657198628942881, 0.03227223828434944, 0.053176270332187414, 0.13726334593125752, 0.09614546730050019, 0.27624300548008507, 0.225111184907811, 0.07636881779347147, 0.04336020955815911, 0.03839361820636051, 0.013888488856277295, 0.09003148680286747, 0.0272998166204031, 0.05368799090917621, 0.027093580990497555, 0.0759781716125352, 0.05468808028048702, 0.0605637151747942, 0.0755621889340026, 0.10432579049042293, 0.020502005138301423, 0.05230374215170741, 0.03517945210582443, 0.042166910732963254, 0.37913065456918305, 0.07661281220082726, 0.3578764950590474, 0.11644521302410535, 20.699668509619578, 101.46704537527901, 72.06240790230888, 71.10858699253627, 92.2542690549578, 74.10811737605503, 34.76729188646589, 25.900645290102275, 36.78161982127598, 48.80447346823556, 87.58120945521763, 68.22453566959926, 49.694190297807964, 24.45149598802839, 11.671619602612086, 6.967811184270041, 11.001547489847455, 9.05021105493818, 4.629620330674308, 24.972048078264507, 33.318071365356445, 37.01705258233206, 43.402610370091026, 26.648439952305385, 32.838537965502056, 27.243021624428884, 46.41891370500837, 46.61176790509905, 52.10181753976004, 54.661686761038645, 50.26162535803658, 53.95073318481445, 52.47378935132708, 47.51526301247733, 40.541686126164024, 32.103661741529194, 25.69436890738351, 18.943339347839355, 12.488147582326617, 12.476060322352819, 19.248511178152903, 26.473560741969518, 27.320561783654348, 27.53572838647025, 26.10334508759635, 29.807448863983154, 29.366790635245188, 33.3335554259164, 20.284353835242136, 42.19404418127877, 29.19219630105155, 18.54741883277893, 1.8255566699164254, 0.35694239661097527, 1.0707556179591586, 3.480782159737178, 1.8702398836612701, 8.692608986582075, 7.044236157621656, 6.813376179763249, 10.46708163193294, 15.751566205705915, 13.106726595333644, 10.894505279404775, 3.0360928901604245, 9.240602118628365, 28.642941202436173, 20.004391806466238, 16.613663945879253, 14.993960687092372, 9.165091701916285, 1.3625063513006483, 0.29033172662769047, 0.23957502735512598, 0.989880866238049, 1.632252031138965, 1.11773282289505, 0.8660830206104687, 0.7942967297775405, 0.3489847279020718, 0.924733036330768, 12.485848597117833, 40.25289467402867, 34.04753146852766, 15.596591847283499, 24.3554527759552, 25.636261122567312, 23.89512072290693, 24.373625789369854, 19.542532886777604, 21.86086709158761, 18.299085003989084, 12.221721512930733, 11.281116076878138, 15.548501627785818, 26.702894721712383, 40.9156277520316, 47.5066750390189, 47.70156158719744, 45.46571813310896, 46.97460283551897, 54.02274431501116, 58.71994195665632, 55.307348115103586, 53.598355293273926, 56.96968378339495, 57.33790009362357, 59.01843656812395, 57.635286467415945, 52.49099309103829, 32.07632752827236, 48.32924100330898, 37.47829137529646, 42.46566316059658, 31.197168486458914, 27.170067276273453, 19.191671439579554, 0.7509558211479868, 1.6187562410320555, 2.306129042591367, 4.906521677970886, 8.190064021519252, 25.46756407192775, 30.400338649749756, 33.31867585863386, 25.431714841297694, 29.798315456935338, 38.95941802433559, 68.90189470563615, 73.96426882062639, 41.183661460876465, 64.77947984422956, 33.40805401120867, 0.4174915504242693, 0.20838612451085023, 0.2297601540173803, 0.07085508294403553, 0.08123698085546494, 0.24346865128193582, 0.12584618000047548, 0.13873383988227161, 0.05475719925016165, 0.04341355937400034, 0.0693400703104479, 0.12664360792509147, 0.03898559929803014, 0.03836808832628386, 0.08445679236735616, 0.03211081480341298, 0.07435186566518885, 0.012882743895586048, 0.09194821930889573, 0.23967257354940685, 0.32840524933167864, 0.3380882968860013, 0.15420279625271047, 0.1353877665741103, 0.11664376594126225, 0.1461711943681751, 0.28304198064974373, 0.151200780911105, 0.1384392064064741, 0.1873099583068064, 0.1572087470974241, 0.17715410755148955, 0.17645634285041265, 0.23850989022425242, 0.1847764171127762, 0.15281450003385544, 0.07627615705132484, 0.3625670719359602, 0.17625141170408043, 0.4560690075159073, 0.21411112802369253, 0.7315008650932993, 0.2980885761124747, 27.633414847510203, 119.9949449811663, 78.19652775355748, 75.21611881256104, 98.25448322296143, 97.41319533756801, 43.75745139803205, 44.68778044836861, 56.91863189424787, 50.3911953653608, 93.78921645028251, 75.95779037475586, 54.54964011056082, 31.871772561754497, 14.507074356079102, 14.128038832119532, 13.841848611831665, 22.578775814601354, 4.580914327076503, 39.52152034214565, 46.76063653400966, 42.63547018596104, 61.19611317770821, 33.376262528555735, 49.52501555851528, 38.68429020472935, 69.27603435516357, 66.85988167354039, 70.72884014674595, 68.74941648755754, 64.22394357408795, 68.64678464617047, 69.59500530787876, 69.55944442749023, 55.31613063812256, 44.10748774664742, 35.24492842810494, 23.057784625462123, 13.07876878125327, 19.1754960332598, 31.67303671155657, 35.88100126811436, 35.651054109845845, 42.219655241285054, 33.32100697926113, 37.8092931338719, 31.413042068481445, 38.17609895978655, 22.09998413494655, 45.0578727722168, 35.63881138392857, 25.45790433883667, 0.9886542920555387, 1.2302435913256236, 1.6204397678375244, 4.032289343220847, 0.8241730609110424, 11.634784596306936, 21.12859296798706, 11.256306665284292, 14.85854377065386, 22.810995033809117, 23.645583118711198, 23.8092531476702, 5.96368488243648, 12.931128246443611, 36.47174753461565, 30.08995567049299, 29.530250481196813, 23.96667500904628, 9.472524302346365, 2.4595415762492587, 0.2276395828063999, 0.2886587849685124, 2.5763464399746487, 5.631681714739118, 3.346337773970195, 2.511989401919501, 1.2739492803812027, 0.46449315547943115, 3.192093844924654, 21.8564167703901, 45.50497892924717, 38.00338411331177, 23.426101684570312, 33.719767570495605, 33.722640650612966, 30.49959019252232, 35.33069699151175, 29.633118561335973, 28.992301838738577, 26.57709584917341, 22.22717785835266, 17.606123788016184, 18.589785473687307, 31.660804407937185, 53.78048494883946, 56.759983675820486, 56.32252509253365, 45.665517057691304, 44.59783601760864, 53.68426282065255, 59.583081926618306, 59.337247712271555, 54.68786062513079, 60.08063547951834, 61.7422068459647, 65.42083331516811, 66.3541361945016, 65.47535582951137, 41.18982451302664, 54.41901050295149, 44.43381684167044, 46.000857966286794, 35.15961497170584, 37.96302897589547, 22.149015835353307, 1.2274722371782576, 3.037718117237091, 3.0537671531949724, 8.234964149338857, 10.160240496907916, 34.32298237936837, 38.52683012826102, 33.75818763460432, 45.36786665235247, 51.49563237598964, 53.50369998386928, 82.26445484161377, 84.22102587563651, 52.24540206364223, 80.47766304016113, 34.434560026441304, 0.43116156118256704, 0.3366103661911828, 0.3869359514542988, 0.38296980570469585, 0.2223011814057827, 0.25416695007256096, 0.29306529994521824, 0.5441089261855397, 0.1069715545911874, 0.2237201202660799, 0.12798319890030793, 0.22079441297267163, 0.10353106313518115, 0.18730090664965765, 0.20526394061744213, 0.12794437312654086, 0.20677825435996056, 0.10617048293352127, 0.19569450696664198], [0.17069287997271332, 0.08247439802757331, 0.011704319406167736, 0.05441330413201025, 0.04372672024848206, 0.0733182125591806, 0.038352115611944876, 0.06243736749248845, 0.0864592238462397, 0.025184658422533954, 0.1822006981819868, 0.05010954989120364, 0.06410302168556622, 0.012346238978872342, 0.045148994108395915, 0.00741321814712137, 0.11147878452071122, 0.030693066772073507, 0.07908998070550816, 0.10742329606520278, 0.07311659944908959, 0.23650139942765236, 0.04060107582647886, 0.11539417585091931, 0.5397316153560365, 47.92370591844831, 75.68486513410295, 44.40835516793387, 72.46862738473075, 88.45283317565918, 50.59176901408604, 33.37481035505022, 37.27391011374337, 38.434610162462505, 64.57528618403843, 36.147360461098806, 14.868992124285016, 7.166943950312478, 4.805882232529776, 5.68746098450252, 0.7227845670921462, 0.9540877640247345, 19.71077135631016, 74.72322750091553, 56.936176095690044, 44.77755464826311, 44.48733186721802, 27.678955078125, 45.45554597037179, 56.491904803684776, 55.50912380218506, 63.24815246037075, 62.75632422310965, 51.67682749884469, 56.25063208171299, 58.84768458775112, 62.565220969063894, 58.23894248689924, 54.95495980126517, 48.295563084738596, 45.011656829289024, 32.88127980913435, 22.883150339126587, 16.714815820966447, 21.834979840687343, 26.54369238444737, 27.680501052311488, 26.76526348931449, 30.615475722721644, 25.726978540420532, 28.01933343069894, 22.03440703664507, 16.774278504507883, 30.141969885144913, 17.280183792114258, 4.721146779400962, 0.5944985651544162, 0.3336890558046954, 0.21596811552132877, 0.13554735801049642, 0.17737938117768082, 0.4207925961485931, 1.9928187004157474, 2.8576288436140334, 9.255794354847499, 16.746416228158132, 11.393143619809832, 9.353661469050817, 1.2349115865571159, 5.150984925883157, 20.04837911469596, 11.947872161865234, 15.673088039670672, 20.385674204145158, 8.762967314038958, 1.3770350345543452, 1.086838960647583, 1.863220031772341, 0.43198752829006737, 2.8546250505106787, 1.1700611178364073, 0.09268261811562947, 0.1530744196580989, 0.26765402778983116, 0.9311679367508207, 8.399615611348834, 36.747931480407715, 31.410637991768972, 16.150080135890416, 21.937622104372295, 19.79058357647487, 24.878857101712907, 24.395762750080653, 19.95512386730739, 15.631079230989728, 23.930110113961355, 15.402360166822161, 14.983957018171038, 21.89909086908613, 43.26808282307216, 52.142690317971365, 51.60144649233137, 48.3150805745806, 51.62065826143537, 52.24887268883841, 60.61325659070696, 63.217483111790244, 60.39989825657436, 55.97066136768886, 60.397980553763254, 56.56890821456909, 63.20376736777169, 66.33309704916817, 60.58023180280413, 36.90070499692644, 39.70871523448399, 47.523580006190706, 39.089627265930176, 32.74249301637922, 48.206653935568674, 21.234509570258005, 0.48128488872732433, 0.8288091921380588, 0.5069854067904609, 1.9424518602234977, 4.270811012813023, 16.61013947214399, 22.789036989212036, 26.87082573345729, 40.14268582207816, 32.299236161368235, 44.701562200273784, 69.42523302350725, 51.511779989515034, 52.11976473672049, 39.6022584097726, 0.7029589680688721, 0.07382715453526803, 0.15296540622200283, 0.0583495061312403, 0.0935385696856039, 0.05752893337713821, 0.05120300568108048, 0.04725882750270622, 0.10288600024900266, 0.07233703056616442, 0.05350429451625262, 0.09065552867416825, 0.10497446996825081, 0.01941505989192852, 0.04384807962924242, 0.05086598412266799, 0.19198346324265003, 0.06162502536816256, 0.14472643046506814, 0.11947375908493996, 0.09843280884836401, 0.06747802772692271, 0.16187062194304808, 0.10260797052511147, 0.08039682558072464, 0.05468512186780572, 0.06855641664671046, 0.04781487677246332, 0.02902068829696093, 0.06464787173484053, 0.001011544738763145, 0.013983202166855335, 0.03950685329203095, 0.02119332884571382, 0.08327480472092118, 0.01612525579652616, 0.08769868340875421, 0.07692934200167656, 0.057659768499433994, 0.07390838874770062, 0.0499964143548693, 0.2245180367359093, 0.05162044720990317, 0.058902980360601626, 1.4111128002405167, 67.22668402535575, 81.569002696446, 50.62043033327375, 88.56411552429199, 86.39803545815604, 44.75400372913906, 30.335310459136963, 28.831061942236765, 45.60793038776943, 77.2386838368007, 37.66968297958374, 17.413861921855382, 10.782257131167821, 7.603768944740295, 6.506575431142535, 1.6069332297359193, 1.3407470903226306, 22.886254446847097, 73.11085632869175, 51.43065629686628, 32.420162609645296, 45.64122615541731, 25.619350944246563, 39.85969958986555, 45.40799944741385, 45.936347416469026, 56.38885607038225, 57.92933770588466, 46.65783446175711, 52.6254893711635, 54.11827162333897, 58.38185650961739, 56.628235408238, 51.092282499585835, 44.28314862932478, 40.613572188786094, 28.905261754989624, 22.41831932749067, 17.06989656175886, 18.060667991638184, 16.419857842581614, 22.92642719405038, 28.328140905925206, 27.97849018233163, 28.2646586894989, 31.61745807102748, 29.021046536309377, 18.532917942319596, 34.45455346788679, 25.03417365891593, 11.12469128199986, 1.174964808991977, 0.3689921743103436, 0.27560605108737946, 1.341012207525117, 0.4567714812500136, 0.4584305265120098, 4.6846752507346014, 7.872213465826852, 15.816455432346888, 19.199378728866577, 17.269622530255997, 13.364771400179182, 2.7815981805324554, 6.585378425461905, 32.27125923974173, 20.798956530434744, 25.76471073286874, 24.965699161802018, 9.248761909348623, 1.5549418138606208, 1.4915254967553275, 1.0184490361383982, 0.7152398547955922, 3.7194623351097107, 3.0202184276921407, 0.44336145796946114, 0.14636119774409703, 0.47442793952567236, 0.45261529141238754, 13.342630096844264, 43.43010091781616, 34.15766389029366, 18.01967535700117, 27.20663217135838, 23.990213768822805, 26.12753871509007, 21.015354701450892, 20.342617954526627, 14.0202123437609, 13.386416775839669, 13.321211406162806, 15.150498390197754, 26.075606141771587, 40.00536857332502, 47.99193375451224, 48.70589937482561, 45.04527221407209, 55.23252643857683, 58.09254046848842, 61.44781861986433, 60.51598875863211, 60.25902353014265, 57.629884243011475, 59.2286126273019, 58.245824677603586, 61.78395857129778, 60.9623966217041, 54.37700169427054, 36.241435595921104, 42.44369295665196, 51.24009500231062, 44.542709009987966, 42.23055696487427, 48.768645082201274, 25.273983785084315, 0.7962050959467888, 1.3351043931075504, 1.1845324784517288, 2.6105925909110477, 5.5857745323862344, 18.310143062046595, 31.045100212097168, 32.12254694529942, 26.159010580607823, 34.053433963230674, 45.80410235268729, 76.28703771318708, 58.25451339994158, 55.92890269415719, 58.92972196851458, 4.2320583036967685, 0.07417758394564901, 0.08426218173865761, 0.17988685305629457, 0.056298077638660154, 0.19588790301765713, 0.12037208516682897, 0.10149197040924005, 0.1798089843775545, 0.07957910945905106, 0.037792141017104895, 0.02192202117294073, 0.06755525858274528, 0.0213137501518109, 0.04418159994695868, 0.03788014022367341, 0.07416898690696273, 0.044954641323004446, 0.05864770870123591, 0.037661095548953326, 0.2741783862667424, 0.23389305653316633, 0.20359340097223008, 0.23152999047722134, 0.15591444154935225, 0.12081500568560191, 0.17514230550399848, 0.1338938224528517, 0.2715780500854765, 0.06823673165802445, 0.4020450535629477, 0.17142090733562196, 0.2328035192830222, 0.08117224182933569, 0.13401815720966884, 0.076989358424076, 0.2176353032035487, 0.1068064873772008, 0.12751970519976957, 0.21749296012733663, 0.298215353595359, 0.33313243995819775, 0.14107330649026803, 0.2036335973867348, 1.3892221748828888, 81.37489087241036, 91.21336637224469, 63.98803833552769, 94.42735290527344, 106.71996688842773, 67.54935836791992, 44.259253774370464, 47.20858342306954, 49.52172211238316, 80.95541422707694, 47.58290025166103, 21.564634118761333, 16.670194489615305, 11.436508195740835, 11.809594324656896, 5.496920100280216, 2.305866313832147, 28.134685686656407, 91.15618964603969, 63.56678295135498, 54.84394148417881, 55.22128772735596, 35.679326329912456, 52.75519834245954, 66.57038497924805, 61.89227403913225, 70.13113525935582, 66.55154146466936, 54.85730981826782, 56.036846433367046, 60.67515114375523, 65.89201150621686, 66.5952456338065, 62.17530196053641, 54.44668517793928, 54.13726799828665, 44.0422545841762, 28.00874263899667, 22.264342035566056, 27.628130742481776, 40.14498567581177, 35.2391996383667, 38.9374999318804, 37.25860323224749, 36.33361734662737, 35.129140172685894, 37.64494044440133, 21.053052152906144, 39.826330866132466, 35.535126890454976, 15.83437831061227, 1.718856223991939, 0.4355535012270723, 0.3210359519081456, 2.2453557550907135, 1.341653938804354, 0.7263426961643356, 4.997875724520002, 9.378490856715612, 23.187681198120117, 29.97116926738194, 24.850498029163905, 22.89492232458932, 2.7123483078820363, 8.864342400005885, 43.24871471949986, 28.24118767465864, 39.47617292404175, 30.489706380026682, 10.354893411908831, 2.226710698434285, 3.469526078019823, 4.410573158945356, 4.205786296299525, 7.435060603278024, 2.7703675031661987, 0.5334147257464272, 0.18413689785770007, 1.4038651777165276, 2.9271790087223053, 26.453440495899745, 46.41902835028512, 39.097489152635845, 23.749505587986537, 36.29179613930838, 31.748615741729736, 36.55962140219552, 34.93731778008597, 25.353396483830043, 24.29541860307966, 32.813222203935894, 23.13722859110151, 20.916712863104685, 29.440559659685405, 49.11332784380232, 58.25399923324585, 55.437578201293945, 49.211648327963694, 53.189849853515625, 54.35639681134905, 62.53358582087925, 64.16798278263637, 59.7520204271589, 58.284289905003135, 62.64078262874058, 59.601175035749165, 66.87968403952462, 68.46260179792131, 62.81689861842564, 42.55970702852522, 52.0784854888916, 59.846543720790315, 47.11494949885777, 45.06374747412545, 57.97513675689697, 29.135379144123622, 1.1807513556310107, 2.375354162284306, 2.2139132022857666, 5.030635178089142, 6.527483429227557, 24.42790511676243, 34.67322022574288, 36.27648230961391, 47.80692407063076, 48.805168288094656, 57.80557639258248, 87.5809245790754, 69.35511180332729, 66.9455668585641, 68.77184527260917, 3.6735269257000516, 0.16444187611341476, 0.2218711394816637, 0.32995548471808434, 0.12601658728505882, 0.307378209062985, 0.3716282014335905, 0.2464877249939101, 0.20153365364032133, 0.2056849580258131, 0.18085935658642224, 0.18695876215185436, 0.25582119130662506, 0.110333356341081, 0.17903918639889785, 0.12698086697076047, 0.24370434720601353, 0.1538570826607091, 0.19085108329142841, 0.23003810910241945], [0.03924499645030924, 0.1383819244801998, 0.04391394163082753, 0.034819278932575665, 0.014443601747708661, 0.003802725679374167, 0.019381806587002108, 0.02489277470989951, 0.02308746104660843, 0.027888762964201824, 0.10902552759008748, 0.08569683546998672, 0.008998841679255878, 0.04695278785324522, 0.045110348146408796, 0.0922797718750579, 0.0321324906045837, 0.02145930948401136, 0.018085333119545664, 0.08605147858283349, 0.14760223829320498, 0.009991602024196513, 0.028717054054141045, 0.061814404491867335, 0.08146307550902877, 6.322770825454167, 87.8599294934954, 60.081538745335166, 52.986778327396934, 91.2657835824149, 63.37471389770508, 40.67796114512852, 41.28150251933506, 42.25095687593733, 41.90222331455776, 18.919711998530797, 7.139011323451996, 8.956027354512896, 1.7535788693598338, 0.9515407064131328, 0.297585591673851, 1.3758982441255023, 54.480029582977295, 46.013534954616, 47.721193722316194, 60.622692244393484, 46.372121061597554, 31.676406587873185, 53.25561802727835, 62.48446205684117, 65.61003971099854, 63.66979694366455, 63.550023896353586, 62.50485501970564, 58.893813678196494, 58.842501231602256, 55.50496530532837, 55.06067664282662, 56.70212255205427, 58.63327707563128, 53.0846471786499, 47.68340247017996, 32.19155297960554, 22.69939133099147, 22.146370308739797, 44.10118225642613, 53.90065404347011, 26.92721905027117, 24.63034609385899, 23.108285869870866, 28.613703182765416, 21.351110764912196, 15.408639601298741, 31.231016635894775, 22.411998203822545, 9.731399416923523, 2.02149760723114, 0.796046318752425, 0.28621500038674896, 4.087051570415497, 1.4415577437196458, 3.6170291687761034, 0.6661849213497979, 4.998284799712045, 17.486581768308366, 22.822812182562693, 13.346990091460091, 9.673203042575292, 2.7181398485388075, 2.1477107661111012, 21.498150280543737, 17.57105622972761, 19.838529620851787, 34.71470097133091, 7.34996862070901, 3.5181326355252946, 5.32203220469611, 2.4449288632188524, 1.8832948974200656, 1.9665953304086412, 0.31964324521166937, 0.15192789903708867, 0.2033753198172365, 0.15929532370397023, 0.4079363117260592, 10.499580093792506, 31.829617840903147, 29.575264385768346, 12.945225272859846, 15.684347595487322, 20.75782319477626, 21.51065877505711, 27.627001660210745, 20.25363063812256, 46.182866028376985, 51.087985038757324, 16.095741748809814, 24.475363050188335, 34.928278173719136, 50.612825529915945, 60.169030461992534, 61.641381536211284, 61.03047507149832, 50.85788154602051, 55.60155916213989, 65.6019172668457, 59.107498577662874, 54.407594612666536, 61.04146017347063, 62.00842012677874, 59.88796888078962, 67.12255832127163, 64.42708110809326, 64.31073352268764, 51.56529154096331, 46.95115613937378, 49.70401505061558, 40.313142504010884, 35.61838020597185, 40.328678676060264, 24.69316475731986, 0.8676224808607782, 0.10607237355517489, 0.6649734920689038, 0.34062327657427105, 1.6233858040400913, 10.105594652039663, 13.640335219247, 29.112656797681534, 33.56375271933419, 29.924605914524623, 57.93948554992676, 71.31633813040597, 48.49298919950213, 68.02748475755963, 15.477112361363002, 0.369277050452573, 0.15317731270832674, 0.06367452003593956, 0.00703342810239909, 0.1578394453972578, 0.08310055692813226, 0.07902308393801961, 0.028890982935471193, 0.12371273019484111, 0.04300036886706948, 0.15249599569610187, 0.09714389086834022, 0.0839623167578663, 0.09878511101539646, 0.043695935114685974, 0.044224839591022046, 0.1864601881908519, 0.016929938956829052, 0.034378363484782834, 0.027139821455680897, 0.07961867483598845, 0.09481233597866126, 0.037698845844715834, 0.0559195772345577, 0.1107737934216857, 0.05367624207532831, 0.12109690984444958, 0.014230736830670918, 0.0732531003387911, 0.019490789489022324, 0.02924657939001918, 0.09673653915524483, 0.052281825470605066, 0.009948237699323466, 0.02761420394693102, 0.006227440034438456, 0.04879138365920101, 0.0082936266636742, 0.03776501997240952, 0.1257341538688966, 0.09330541148249592, 0.10402118254985128, 0.11312867634530578, 0.02233827526548079, 0.12216866947710514, 14.17540557043893, 102.31876250675747, 64.62939875466483, 69.73294789450509, 95.63569327763149, 57.803686482565745, 32.15942450932094, 30.248947824750626, 47.0356114932469, 51.67685876573835, 23.15688157081604, 12.978980490139552, 12.557976109640938, 2.7783297044890265, 2.0050675060067857, 1.0058636771781104, 3.583967251437051, 56.95979997089931, 49.9066036769322, 51.825984477996826, 56.08359391348702, 43.7015357698713, 31.193103790283203, 46.38693809509277, 57.261452538626536, 58.66016660417829, 57.25378172738211, 60.73615632738386, 59.8737667628697, 54.93736696243286, 56.70495046888079, 56.22666079657418, 56.03053399494716, 55.50047329493931, 55.41930791309902, 50.137672969273154, 45.21703168324062, 31.579903057643346, 23.95297142437526, 21.443912642342703, 39.59455633163452, 52.89998837879726, 30.949357509613037, 24.437349455697195, 27.264611414500646, 31.228772367749894, 28.400172880717687, 18.034935338156565, 37.340915066855295, 31.38023614883423, 12.765679478645325, 0.7753790648920196, 0.6672914219754082, 0.44374453169958933, 2.3229825496673584, 0.47390975590263096, 3.1430886345250264, 1.3715483461107527, 5.509716510772705, 19.14037983758109, 27.119512183325632, 23.332415648869105, 14.773918185915266, 6.398758062294551, 1.430502182671002, 31.463628428322927, 25.824096986225673, 28.563250575746807, 38.322771957942415, 10.632910813604083, 5.671789756843022, 6.550524958542415, 1.97559455037117, 2.3419107454163686, 2.691290706396103, 2.166536475930895, 0.1234407869300672, 0.2825337307793753, 0.21346057578921318, 1.4047023270811354, 15.689218282699585, 40.175905159541536, 32.115504946027485, 14.51906260422298, 17.76765377180917, 21.851464441844396, 21.847274678094045, 23.636592149734497, 22.862321376800537, 41.36891780580793, 41.14744744982038, 14.740678003856114, 27.35441514423915, 36.05377517427717, 48.28945214407784, 54.14567879268101, 59.1509804044451, 64.24091802324567, 55.14271054949079, 57.95084932872227, 63.63471548897879, 57.536253792899, 56.87061636788504, 61.664338384355815, 63.16589273725237, 60.68535804748535, 66.53849969591413, 61.47741099766323, 61.109566416059224, 48.6411143711635, 50.53673928124564, 57.10877629688808, 46.59157991409302, 42.829960686819895, 47.37001439503261, 31.343362058912003, 1.3081897859062468, 0.8607126059276717, 0.9893157822745187, 0.6105562863605363, 2.6003129482269287, 10.43079205921718, 24.84930988720485, 27.233480010713848, 25.99861662728446, 34.480925355638774, 60.42735058920724, 79.69807515825543, 55.336613927568706, 72.43935462406704, 26.035605362483434, 0.4641858605401856, 0.06883513847632067, 0.03875197969110949, 0.040930111027721844, 0.10509588702448777, 0.15652667012597832, 0.06892687641084194, 0.07144332530775241, 0.11557750244225774, 0.1652045901864767, 0.2056478557309934, 0.10357702031199421, 0.07575836019324404, 0.11336907451706273, 0.04577129214469876, 0.05775488553834813, 0.06620582206440823, 0.04190340844382133, 0.03280144470876881, 0.04055056567969067, 0.15414463223091193, 0.299409276672772, 0.16712222514407976, 0.15693280047604016, 0.25306411353605135, 0.1362094317695924, 0.20688451294388088, 0.1153556757739612, 0.16599676625004836, 0.13876058773270675, 0.16725201532244682, 0.21660882899803774, 0.0829179495839136, 0.25922211738569395, 0.09082736766764096, 0.13280258886516094, 0.16341945954731532, 0.18022366426885128, 0.1743533049843141, 0.1706150927181755, 0.21579333847122534, 0.2091550403939826, 0.28421989030071665, 0.1661550413284983, 0.25627670543534414, 17.643750020435878, 118.50261088779995, 74.56295340401786, 76.18067468915666, 108.93180779048375, 83.34965229034424, 49.94243901116507, 51.98646354675293, 52.701210839407786, 56.701309612819124, 29.655265944344656, 18.94617942401341, 19.063009909221105, 8.136713147163391, 4.300105920859745, 2.1877024258886064, 3.942440450191498, 64.31112957000732, 57.79370192119053, 54.422651359013145, 70.90251731872559, 53.576513631003245, 38.869629928043906, 58.14901890073504, 68.22201347351074, 69.93035316467285, 66.94606712886265, 67.7210691996983, 66.72922774723598, 59.37678991045271, 58.918118476867676, 57.54000582013811, 60.42837197440011, 62.52528272356306, 62.39201627458845, 57.70465380804879, 53.345635414123535, 38.18852233886719, 31.41788148880005, 28.081254039491924, 54.6687148639134, 66.34397792816162, 39.221170561654226, 32.0922805922372, 34.04147611345564, 38.513930797576904, 34.959180286952424, 18.407624551228114, 45.5910393169948, 40.25982550212315, 24.4079099382673, 5.330266688551221, 3.9028843556131636, 0.6070459804364613, 13.715589421136038, 2.2748730054923465, 9.189525042261396, 2.8248956629208157, 8.257384249142238, 25.85812405177525, 34.07027987071446, 32.466100624629426, 23.495981454849243, 7.5007645062037875, 3.381608349936349, 38.18168183735439, 32.961250100817, 37.522492340632844, 42.43832894733974, 12.95059883594513, 11.1284076997212, 10.89624754020146, 4.661059192248753, 2.239659535033362, 4.767740530627115, 3.1421606157507216, 0.20668005677206175, 0.28571831275309834, 0.25403121592743055, 2.642873704433441, 24.958445242473058, 41.619883264814106, 40.77375248500279, 23.025135040283203, 31.59241328920637, 28.4046197278159, 29.868791035243444, 32.8940749168396, 28.83901068142482, 59.00742367335728, 60.03540965488979, 23.01309207507542, 32.06978232519967, 40.028488704136436, 58.06540775299072, 64.42658083779472, 61.9593380519322, 60.590751375470845, 50.15031521660941, 57.14148841585432, 65.4114601952689, 60.66849476950509, 59.217905453273225, 61.8576511655535, 62.43216296604702, 61.16471426827567, 70.73430143083844, 68.08511311667306, 67.40115329197475, 57.98720577784947, 57.962782859802246, 60.80756991250174, 51.78428486415318, 48.23734760284424, 50.50537511280605, 33.46996593475342, 1.9756903052330017, 1.5006747543811798, 2.0253625426973616, 1.2959991714784076, 3.3660135524613515, 16.136201109204972, 27.033712353025162, 34.97861092431204, 39.82645245960781, 48.98360845020839, 69.13677855900356, 93.55191462380546, 63.47756808144705, 86.41962351117814, 28.984889847891672, 0.36167941242456436, 0.35130499196904047, 0.11536634234445435, 0.14328870975545474, 0.3320704512298107, 0.27646665062223164, 0.3402923686163766, 0.18102829823536531, 0.17931218817830086, 0.2916779943874904, 0.3503936380147934, 0.14506187103688717, 0.1828889362514019, 0.1270343219595296, 0.15550562420061656, 0.13204079759972437, 0.27353763207793236, 0.1623097290950162, 0.04843614004286272, 0.14730235295636313], [0.015228749884824668, 0.04609878028609923, 0.09000550569700343, 0.06413624276007925, 0.036121387633361986, 0.09768447293234722, 0.08161356100546462, 0.05336938818384494, 0.11354908985751015, 0.1034536762163043, 0.058168764758322916, 0.07254975807986089, 0.048068967780896595, 0.06434481763946158, 0.06207063288560935, 0.03339443342494113, 0.016061744918780665, 0.023781817805554186, 0.05157167072008763, 0.07668747819427933, 0.09897316021046468, 0.03816923006836857, 0.02438586324985538, 0.13096635096839496, 0.04614933114498854, 0.1383088462586914, 43.30601303918021, 82.83054542541504, 43.45472533362252, 81.09767164502824, 68.41732733590263, 56.45308174405779, 39.170035294124055, 32.96251467296055, 39.20865338189261, 17.119167975017003, 8.578627262796674, 1.8488604937280928, 1.3038101409162794, 1.556369342974254, 0.9660367114203317, 5.393283375671931, 50.2216488974435, 49.69488164356777, 39.348736013684956, 56.18765013558524, 50.87232337679182, 34.76449523653303, 55.64938708714077, 60.30603504180908, 58.46861171722412, 60.05924892425537, 61.293033599853516, 57.21939509255545, 64.38302952902657, 66.36493369511196, 61.005190576825825, 55.39023665019444, 55.065825257982524, 58.00982563836234, 55.934930256434846, 47.456446511404856, 45.63483381271362, 34.57858576093401, 28.90563174656459, 14.605577230453491, 21.281594038009644, 23.07693907192775, 20.15742588043213, 18.197537081582205, 20.60695001057216, 20.948382752282278, 13.57445674283164, 30.69287518092564, 27.295770611081803, 15.67950643811907, 4.386544116905757, 0.28928406855889727, 0.0782246110694749, 0.963842817715236, 6.117252230644226, 5.310946788106646, 9.620926533426557, 9.379593014717102, 25.731343746185303, 27.346165895462036, 20.545467138290405, 6.434153488704136, 5.861312295709338, 0.9918148538896016, 5.1877578326634, 23.17005361829485, 24.492580686296733, 39.40068769454956, 8.667926379612513, 4.073724056993212, 12.267104540552412, 5.359073485646929, 4.818712515490396, 1.3464618750980921, 0.29269829392433167, 0.4043361949069159, 0.08373910587813173, 0.04245767995182957, 0.5920389028532165, 8.177482570920672, 38.083997113364084, 29.421667507716588, 23.35180285998753, 23.510574408939906, 23.9161251272474, 22.371684755597794, 18.188721554619924, 20.362135444368633, 55.60191699436733, 51.70954656600952, 21.82472082546779, 32.216889585767476, 46.95154871259417, 61.520746912275044, 59.24441283089774, 51.863053117479595, 48.481788703373496, 50.16619185038975, 64.66417448861259, 56.45873410361153, 58.32099028996059, 62.63845498221261, 66.32878221784318, 54.78762633459908, 62.41868346078055, 65.77214118412563, 65.4727224622454, 60.69312613351004, 54.33047308240618, 46.371047564915244, 52.075400488717214, 54.40547888619559, 57.06321695872715, 36.947577544621055, 25.50570968219212, 4.009388514927455, 0.31636725100023405, 0.39247103301542147, 0.812127978674003, 1.5801865735224314, 5.32421350479126, 7.887207678386143, 24.92476384980338, 28.460594415664673, 41.0040157863072, 66.18052155630929, 59.34008257729666, 55.079030309404644, 36.8701502936227, 0.9353900530508586, 0.21767156411494526, 0.07470878187034811, 0.10448634544653551, 0.08528037103159086, 0.06833317184022494, 0.04125681206850069, 0.017163025913760066, 0.07092200006757464, 0.008742365620232053, 0.04365608136036566, 0.028140144921573143, 0.06790483982435294, 0.10981840254472834, 0.0762279267821993, 0.008770819138070303, 0.043623277584889104, 0.13494038129491465, 0.17723718737917288, 0.04124135843345097, 0.015595335213999664, 0.030680778502885784, 0.03186946328995483, 0.09180804075939314, 0.03434086424697723, 0.029988547254885946, 0.016034228627436926, 0.051798118211861165, 0.009834725576053773, 0.08244623203894921, 0.06499606197965996, 0.058718079568019936, 0.038794340632323704, 0.03148810964609895, 0.04826021287590265, 0.04947431219209518, 0.007903731112102312, 0.07378712775451796, 0.019193265454045365, 0.030575463082641363, 0.07982537695871932, 0.09853415483874933, 0.15013059547969274, 0.037370231335184405, 0.052918087757591686, 0.0499781414068171, 0.31986241202269283, 65.69456454685756, 82.9547792162214, 49.72763197762625, 93.93468393598283, 71.43505505153111, 46.53084223611014, 24.631687096187047, 36.46022742135184, 53.92949601582119, 22.852830137525284, 9.584317343575613, 1.646747819014958, 2.4636822683470587, 3.5552475239549364, 1.7694942610604423, 8.39458337851933, 67.30489989689418, 57.041969367435996, 38.55441795076643, 59.2889438356672, 49.97492183957781, 32.8396566254752, 51.37820781980242, 59.213173730032786, 57.569042342049734, 61.464459555489675, 60.624735014779226, 59.822079113551546, 66.78404903411865, 66.14809431348527, 62.85708005087716, 58.10202475956508, 57.88535908290318, 58.144453934260774, 53.91908066613333, 45.86237689426967, 39.103117193494526, 31.625914028712682, 26.232918569019862, 22.907929352351598, 26.82447256360735, 22.03038924080985, 18.72871991566249, 19.497595412390574, 23.941868203026907, 25.57371517590114, 12.179649301937648, 31.778697967529297, 34.257644993918284, 20.529823269162858, 3.387279599905014, 0.15809908003679343, 0.015752490709668825, 0.5764521935156414, 6.490214594772883, 11.225419316973005, 8.830679246357509, 9.010334474699837, 32.51589141573225, 35.255986486162456, 25.89185929298401, 15.292562995638166, 8.226525562150137, 1.7785240965230125, 10.790658371789114, 33.25219896861485, 33.97314058031355, 44.81231648581368, 11.35666470868247, 3.951671132019588, 13.588625856808253, 7.766312497002738, 6.542442032269069, 3.5806112715176175, 0.5889257841876575, 0.47153705464942114, 0.23654132442814962, 0.08201352347220693, 0.5770030011023793, 11.155507411275591, 49.337806769779746, 34.87341519764492, 22.393682752336773, 23.632426704679215, 25.957597936902726, 24.156145436423166, 25.036367552621023, 25.740624802453176, 62.367169516427175, 59.475892066955566, 23.056014571871074, 33.50592633656093, 44.24655941554478, 57.438965116228374, 58.52445438929966, 54.81754527773176, 54.97605800628662, 52.36014461517334, 64.2382846559797, 54.17457982472011, 56.89219052450997, 63.696707316807334, 69.5384052821568, 57.21783869607108, 61.12224687848772, 67.18991415841239, 63.57512773786272, 59.82831164768764, 55.4619003704616, 49.69961336680821, 57.581837449754985, 57.38433837890625, 60.513813972473145, 47.08620132718767, 33.59804902757917, 4.657331917967115, 0.37057098959173473, 0.5797521535839353, 1.074180537036487, 1.6729677149227686, 6.460817635059357, 17.43118725504194, 23.788490193230764, 26.316406386239187, 44.11717006138393, 69.21585600716728, 69.20579501560756, 62.73606327601841, 61.88784108843122, 3.439221944127764, 0.2249100942696844, 0.07415778429380485, 0.05085406226239034, 0.06426014325448445, 0.1227142930563007, 0.0603776608726808, 0.2071585189551115, 0.1573849083589656, 0.08305392800165073, 0.0805533364681261, 0.13960053266159125, 0.11276789927589041, 0.016455578517967036, 0.052994585795594115, 0.06988321723682539, 0.035682059957512786, 0.10308203580124037, 0.10058223815368754, 0.06060486153832503, 0.03636939896802817, 0.10155169506158147, 0.13461570228849137, 0.2498246245086193, 0.20725375813032898, 0.18939010240137577, 0.15919484623840877, 0.11453044148428099, 0.09890425497932093, 0.34800196492246216, 0.19279880449175835, 0.1939062007835933, 0.1627906747162342, 0.11866095555680138, 0.14001823881907122, 0.20681013193513664, 0.08678682733859334, 0.24483410801206315, 0.17289172698344502, 0.22867058962583542, 0.17509704721825464, 0.22978759397353443, 0.264261786959001, 0.2829106162701334, 0.26168633944221903, 0.10645877210689442, 0.5908320333276476, 74.11965833391461, 102.07764611925397, 63.06409467969622, 101.85195473262242, 89.21604415348598, 71.27061203547886, 53.791640281677246, 39.62849828175136, 58.44375106266567, 29.456015927451, 15.931821584701538, 3.534056603908539, 3.6291049207959856, 5.474830039909907, 3.214202795709882, 10.051441260746547, 63.061912945338655, 60.947451046534944, 48.45858519417899, 68.70478125980922, 61.96384048461914, 40.37881340299334, 61.82955959865025, 64.8065778187343, 64.03586973462785, 64.87940883636475, 65.4213752746582, 58.57530130658831, 67.48890209197998, 67.88470622471401, 62.99521023886544, 56.34961264474051, 58.306003025599885, 63.268017360142295, 62.25284385681152, 53.53362587520054, 51.69484070369175, 40.942107336861746, 37.47544608797346, 20.314580236162456, 28.347436053412302, 32.0885910987854, 27.317775556019374, 24.882511854171753, 31.276117392948695, 33.115465368543354, 20.416366134371074, 37.275657585689, 37.60565185546875, 33.88195242200579, 6.9679088933127264, 1.1393515999828066, 0.1830729278070586, 1.445110987339701, 25.091265269688197, 18.070388521466935, 17.60252809524536, 12.282630290303912, 40.60039840425764, 41.568299838474815, 35.24271890095302, 25.29127437727792, 10.376325130462646, 2.961141369172505, 15.500772714614868, 39.88337557656424, 41.884904929569785, 46.54838643755232, 16.364404269627162, 7.284302498613085, 15.69265764100211, 11.039128558976309, 12.854157839502607, 3.3291941796030318, 6.167702232088361, 0.9336388898747308, 0.24857785712395394, 0.14685423485934734, 4.395618464265551, 14.032518471990313, 53.170255933489116, 40.715780190059114, 35.42449767248971, 37.25356231416975, 32.46400574275425, 32.40550538471767, 25.785070691789898, 33.23850059509277, 68.63717528751918, 59.66646725790841, 25.997002908161708, 39.45025961739676, 53.39783375603812, 66.36703899928501, 60.23321097237723, 50.713181836264475, 48.21076379503523, 52.05960028512137, 68.50345025743756, 55.29234348024641, 59.27367169516427, 64.55931227547782, 67.52375425611223, 55.632200717926025, 64.585909979684, 68.77768870762416, 65.45675550188336, 61.828586850847515, 57.890184606824604, 54.920288290296284, 64.54062162126813, 65.51081943511963, 67.51399898529053, 47.57203674316406, 33.103212220328196, 5.39839551278523, 0.6208617676581655, 1.785794843520437, 2.648611613682338, 2.8992826427732195, 9.226535490580968, 22.350027220589773, 32.19312327248709, 38.67846066611153, 59.596929686410085, 75.81344849722726, 80.35853617531913, 70.2285212108067, 67.49421051570347, 2.2994007979120528, 0.30338448765022413, 0.4420914032629558, 0.37182717504245894, 0.1426713378833873, 0.19965306669473648, 0.21265845240226813, 0.2064404253448759, 0.3936086105448859, 0.1378948041903121, 0.10591973031737975, 0.24619237227099283, 0.2127687143427985, 0.2380594243960721, 0.26903897204569405, 0.1578324157744646, 0.08251392269240958, 0.19426338161740983, 0.49968529279742924, 0.26913119852542877, 0.19791649202150957], [0.11371306463011674, 0.051733240086053095, 0.0149241012321519, 0.021601255617237518, 0.016587143065407872, 0.08547329889344317, 0.08444690611213446, 0.0009625395614420995, 0.040487098906721385, 0.05820216903729098, 0.03971506515517831, 0.047121600580534766, 0.027823477717382566, 0.059079155192843506, 0.041508372141314406, 0.05574505802776132, 0.06530485648129668, 0.03533203088279281, 0.02391022037980812, 0.027201154236016527, 0.05022181011736393, 0.06346322423113243, 0.21788539764072212, 0.004022149909620306, 0.08154573464500052, 0.045879508302147896, 9.597417303494044, 93.44154248918805, 57.46015017373221, 73.31031826564244, 80.60421752929688, 58.71350792476109, 44.07501534053257, 38.18881068910871, 39.75930159432547, 10.770615424428668, 2.804198282105582, 4.584755378110068, 1.2002136941467012, 1.3720822717462267, 1.3743239343166351, 13.199782950537545, 40.36282212393624, 36.18073960712978, 44.663757051740376, 58.01982062203543, 50.37203918184553, 47.87761851719448, 60.15735054016113, 62.39558070046561, 57.29267774309431, 59.01232215336391, 61.76465647561209, 63.46388707842146, 60.261094093322754, 64.24360002790178, 64.95085716247559, 64.56175804138184, 57.647504874638145, 57.29580790655953, 60.709037508283345, 61.19630772726876, 58.68584714617048, 48.13670989445278, 39.20876802716936, 26.668852022715978, 25.497705357415335, 30.134076731545584, 29.166050229753765, 24.993954011372157, 24.84934983934675, 23.64541288784572, 27.61089747292655, 36.48563003540039, 28.491579907281057, 9.977601885795593, 1.9483035462243217, 0.4844442020569529, 0.8620671246732984, 2.384906415428434, 1.1988811599356788, 5.313211466584887, 19.756070137023926, 22.69127757208688, 27.195075580051967, 33.52461699077061, 22.735806839806692, 11.732392021587916, 6.5691035730498175, 2.0089283159800937, 1.018772453069687, 13.171573264258248, 38.52406474522182, 39.939134870256694, 11.74039547783988, 3.179242500237056, 12.53760051727295, 9.93865202154432, 3.5597234666347504, 1.396054751106671, 1.4946162509066718, 1.453701674938202, 1.7224659217255456, 0.14411744528583117, 0.6550713862691606, 7.160798702921186, 28.32520181792123, 27.713560581207275, 18.865566423961095, 12.832250169345311, 26.412461757659912, 23.388600519725255, 18.00763933999198, 24.142558234078543, 22.17180940083095, 12.797831399100167, 23.67085197993687, 35.963337421417236, 51.34567287990025, 53.0549818447658, 54.84277071271624, 51.9895589692252, 53.55251802716936, 61.0678494317191, 66.3625921521868, 59.269058091299875, 59.29280703408377, 58.45184571402413, 62.445357595171245, 61.87700884682791, 67.16781888689313, 61.32924066271101, 62.234125409807476, 61.700892857142854, 59.42068862915039, 50.2638383592878, 55.958512442452566, 48.992981570107595, 55.13342775617327, 40.177423340933665, 40.69622448512486, 18.63751264980861, 0.2194997410156897, 0.4515478472624506, 0.2727147048073155, 1.8442125831331526, 3.307174686874662, 5.973878758294242, 21.836322580065044, 35.494288853236604, 46.01340988704136, 69.34824698311942, 49.68738453728812, 52.867887701307026, 16.26224316869463, 0.26734393728630884, 0.10858509050948278, 0.07038154013987098, 0.058664271741041114, 0.11269460392317601, 0.07350174271102462, 0.0202531337604991, 0.043806112238339016, 0.11195846806679453, 0.03926043990733368, 0.07625071198812552, 0.03931321296840906, 0.021407761178644638, 0.049900703597813845, 0.006039353519944208, 0.025772887215550457, 0.05368073397715177, 0.07846515851893596, 0.07366920515362706, 0.047011355603379865, 0.0363702844562275, 0.08905213006905147, 0.05845967307686806, 0.02109268513907279, 0.06050399052245276, 0.04989204549097589, 0.03643224827413048, 0.03330268531239458, 0.06651270309729235, 0.08274948290948357, 0.01997843225087438, 0.07375780147101198, 0.017729271868509904, 0.0495814325154892, 0.08890057248728615, 0.04376657061012728, 0.036651934164443185, 0.0035046696305341485, 0.07532303926667996, 0.009861647301087422, 0.08539189504725592, 0.0671756589519126, 0.07497594146324055, 0.0763397900653737, 0.08495472172009093, 0.19926681742072105, 0.26820969368730274, 18.66193209375654, 115.78477437155587, 57.88164527075631, 84.69535854884556, 81.50156348092216, 60.765797342572895, 35.49638720921108, 37.83862495422363, 53.81816502979824, 13.215726460729327, 3.7804319092205594, 5.885364353656769, 2.3732601489339555, 1.695903718471527, 1.5776030378682273, 16.836878299713135, 50.53755569458008, 44.62380143574306, 50.13560240609305, 58.318850244794575, 52.29580429622105, 43.479478291102815, 56.03601959773472, 62.79547732216971, 56.695455755506245, 61.86475222451346, 63.50928660801479, 63.951956340244834, 61.99597590310233, 64.65576022011894, 64.38693441663469, 65.38946219852993, 58.01367841448103, 57.15409939629691, 59.94982869284493, 61.44924994877407, 51.72212280545916, 46.72557244982038, 32.986690929957796, 24.328434705734253, 23.70225783756801, 28.556265899113246, 27.537616559437343, 28.48765938622611, 27.114766563688004, 25.32111689022609, 26.40054386002677, 39.35388115474156, 35.55320610318865, 17.72794829096113, 3.093160616500037, 0.6445984425289291, 0.7503384628466198, 2.633546833481107, 0.3844289274087974, 8.048413702419825, 23.165339265550884, 24.645274298531668, 31.227848257337296, 43.21769448689052, 28.776549850191387, 24.158448764256068, 8.26543026311057, 2.8685596627848486, 2.834763841969626, 17.759583439145768, 46.425973074776785, 46.47324514389038, 16.30294919013977, 4.355973780155182, 16.004002945763723, 12.940675071307592, 5.301994034222194, 0.9502697288990021, 3.069929314511163, 1.354144302862031, 1.2555950709751673, 0.08082570720996175, 0.5191328121083123, 8.86320550101144, 35.60401480538504, 32.701797417231965, 20.05774702344622, 19.552223886762345, 28.196910279137747, 22.853608335767472, 20.064825500760758, 21.715971095221384, 25.976997307368688, 21.887944221496582, 28.224374771118164, 35.18694918496268, 49.11159079415457, 53.8835232598441, 56.06100879396711, 53.361122948782786, 55.44716671534947, 58.130237919943674, 65.14100851331438, 59.44979463304792, 61.58892263684954, 59.96699769156319, 64.2604146684919, 62.23839855194092, 65.3706464767456, 62.161502838134766, 63.13882255554199, 63.14033031463623, 59.778277669634136, 53.01456069946289, 60.94126714978899, 55.526688848223, 61.995135171072825, 43.25360625130789, 41.756199972970144, 18.41536831855774, 0.2594919843333108, 0.5719518235751561, 0.631733527140958, 1.7301562747785022, 5.30148811851229, 11.276121190616063, 24.23270242554801, 35.58755104882376, 54.2755058833531, 75.96949808938163, 59.36989729745047, 64.4894689832415, 25.81304066521781, 0.3511401893837111, 0.2269696108996868, 0.14115364503647598, 0.030255543999373913, 0.03785257473854082, 0.0464959505812398, 0.04267869916345392, 0.05865298091833081, 0.09365833111639534, 0.04032141422586782, 0.14962472048188957, 0.08161828360919442, 0.004472780706627029, 0.026508006965741515, 0.0308639117117439, 0.028938005412263528, 0.06656558811664581, 0.036862361444426436, 0.06362111932997193, 0.10001133235969714, 0.020600994915834496, 0.21009852976671287, 0.20806973720235483, 0.09349698905966111, 0.12090830425066607, 0.13081733110759938, 0.0924687303070511, 0.1817382765667779, 0.18810486208115304, 0.1869631726294756, 0.11967759100454194, 0.19167751180274145, 0.12081037807677474, 0.1722976831453187, 0.19205966272524425, 0.13885892102760927, 0.13358244273279393, 0.20653794439775602, 0.15965538152626582, 0.16800886685294764, 0.09820920441831861, 0.21505685656198434, 0.16086710936256818, 0.4079473582761628, 0.18680394760199956, 0.47580878543002264, 0.34734297171235085, 23.15275260380336, 132.44667271205356, 77.62861674172538, 96.70254748208183, 101.47848211015973, 73.8072395324707, 55.74780832018171, 49.56970289775303, 55.05752910886492, 16.85481854847499, 5.656862420695169, 8.621177162442889, 5.482689755303519, 4.5580660445349555, 2.882878380162375, 22.32614799908229, 50.36991303307669, 46.87079674857003, 54.600956031254356, 69.93033926827567, 62.61730466570173, 55.32065391540527, 64.63481140136719, 69.5533925465175, 60.656780106680735, 61.80757549830845, 64.06972830636161, 64.23220498221261, 62.18019349234444, 64.70555101122174, 65.574937411717, 64.371335710798, 56.5538375718253, 57.762157099587576, 63.558938435145784, 66.893844468253, 64.2508886882237, 57.478479521615164, 47.66403089250837, 34.49177496773856, 33.32488407407488, 39.97191647120884, 37.36006082807268, 36.23139197485787, 34.12331199645996, 33.075120653424946, 40.315320764269146, 45.34644535609654, 42.44197327750069, 28.79887614931379, 4.070429742336273, 1.7994597788367952, 2.5898865248475755, 13.961198687553406, 8.169251561164856, 14.456028546605792, 34.11073228291103, 37.09060621261597, 31.166638101850236, 48.81198099681309, 37.933151721954346, 36.8533148084368, 13.696629524230957, 4.331089675426483, 5.650352827140263, 24.614226273127965, 53.97430842263358, 48.55121857779366, 21.339960643223353, 5.7041879040854315, 19.7682329586574, 21.382118838174, 10.03195938042232, 1.5371565967798233, 4.932436287403107, 7.099723168781825, 2.6649811353002275, 0.9082395870770726, 3.7721387999398366, 13.398585677146912, 38.66090256827218, 41.296312604631694, 24.594719205583843, 22.696354968207224, 34.32977424349104, 31.6983003616333, 26.909693956375122, 33.400188650403706, 29.620535373687744, 18.9842711857387, 30.175918783460343, 41.212044852120535, 53.166291986192974, 55.0737601007734, 52.46942935671125, 55.00760630198887, 54.41153424126761, 63.72629969460623, 66.36840084620884, 58.34059115818569, 60.15930298396519, 59.69564274379185, 62.491174016680034, 63.581082344055176, 66.09514904022217, 60.474667821611675, 61.97002438136509, 65.92136069706508, 64.44944735935756, 57.571196283612935, 70.33610711778913, 61.37769739968436, 69.82969461168561, 48.36571209771292, 51.62315613882882, 22.261399473462784, 0.5240192413330078, 0.9800703355244228, 1.2491346576384135, 3.5125174054077695, 7.280219563416072, 15.72031147139413, 32.39806038992745, 47.554141657693044, 61.56800855909075, 83.94115243639264, 66.96078341347831, 72.54864283970424, 32.0649220602853, 0.34754009970596855, 0.32185896060296465, 0.1966006090598447, 0.22112713940441608, 0.17803270183503628, 0.34194983967712944, 0.13985688319163664, 0.10352431849709579, 0.2636018709412643, 0.12533246113785676, 0.17117457198245184, 0.1918046421238354, 0.11819246783852577, 0.16661367671830313, 0.1703611984848976, 0.17045525700918265, 0.10465261366750513, 0.27007031813263893, 0.13023900214050496, 0.21415148728660174, 0.16143682093492576], [0.03951988455706409, 0.05373106091948492, 0.0352921262383461, 0.018771744233423045, 0.047528409465615234, 0.056935276303972514, 0.05440577917865344, 0.01687745257679905, 0.01084827453762825, 0.10592048349125044, 0.02493191260977515, 0.09174271140779768, 0.058703355358115265, 0.009880419820547104, 0.0215032683751945, 0.027519680626158203, 0.020030567489032234, 0.022918264947033355, 0.008317864782709097, 0.0059165276553747904, 0.09018927333610398, 0.057609950458364825, 0.028467916351343905, 0.07757865930242197, 0.0439491508129452, 0.10126669678304877, 0.6979846549885613, 31.648506096431188, 65.00162764957973, 56.796232427869526, 92.5906035559518, 63.46378285544259, 40.28558247429984, 35.794902665274485, 22.17136471612113, 5.709139364106314, 3.6173351066453114, 1.0925929376057215, 0.16268789023160934, 1.3585326331002372, 0.6148624324372837, 26.297184194837296, 58.39560004643032, 47.13152095249721, 41.935532978602815, 50.91905001231602, 60.068976402282715, 46.29623283658709, 61.627283641270225, 65.68848487309047, 65.5290584564209, 61.346902983529226, 61.422888483319966, 64.63627052307129, 69.26598031180245, 68.08175018855503, 68.01650660378593, 69.23407418387276, 62.52096789223807, 60.08606202261788, 56.076857634953086, 52.15545763288225, 53.800780636923655, 51.1773909841265, 45.51620026997158, 43.84597144808088, 29.390292916979107, 22.31794912474496, 33.819693088531494, 26.788854360580444, 23.546553918293544, 20.8062938281468, 18.13153961726597, 30.85668591090611, 23.26483573232378, 7.673224006380353, 1.1089064393724715, 0.2592089809477329, 0.2834903565900666, 2.6861025733607153, 0.5642043107322284, 3.2678016339029585, 12.436713542257037, 17.867864165987285, 37.7384215082441, 34.83272654669625, 28.084874050957815, 22.254960230418614, 4.274478358881814, 5.852092036179133, 0.5952510333486966, 6.568635438169752, 31.849055426461355, 41.57509170259748, 9.340424282210213, 2.502045444079808, 14.30228054523468, 13.616763455527169, 8.153147373880659, 2.3140415208680287, 0.26941013070089476, 2.0349682101181576, 0.8946235605648586, 0.2188545899199588, 1.0018100546939033, 4.93929329088756, 18.000446217400686, 27.335731438228063, 23.967746768678936, 19.591383934020996, 24.48272292954581, 23.22647820200239, 25.64154349054609, 23.257963963917323, 24.375875268663677, 16.816827535629272, 28.650120428630284, 43.737110546657014, 51.02942909513201, 54.67156362533569, 58.424254417419434, 60.56290299551827, 65.40595722198486, 66.40977042061942, 64.16195174625942, 58.98643316541399, 63.10035037994385, 67.38576998029436, 65.36074529375348, 63.72891221727644, 66.80642918178013, 63.80020073481968, 63.477561133248464, 60.0567684173584, 60.253006390162874, 54.43908037458147, 54.00823300225394, 47.49500553948538, 52.60826826095581, 53.90948172977993, 52.2909266608102, 21.264296497617448, 0.2665620749550206, 0.1636499986052513, 0.06267353839107923, 0.7456958719662258, 2.501169319663729, 3.761260526520865, 28.10337884085519, 36.18927894319807, 51.99224097388131, 64.1122304371425, 45.315751688820974, 44.38962629863194, 3.110415382044656, 0.7115868936691965, 0.053497855218925645, 0.11611834913492203, 0.057475858367979527, 0.04271527898630925, 0.0468423528862851, 0.08419008739292622, 0.05631084427503603, 0.07351397669741086, 0.031223959356014217, 0.16277027795357363, 0.16966822424105235, 0.0373742482624948, 0.04375560887690101, 0.019771053289462413, 0.030864013491996696, 0.03387176584718483, 0.048761450086853335, 0.06318038369395904, 0.09916685481688806, 0.005516884948260018, 0.03209635861484068, 0.09605533070862293, 0.012783046745296036, 0.053733568106378825, 0.04679906235209533, 0.043043622081833224, 0.03240223202322211, 0.04981752877522792, 0.025739067333883474, 0.01860815961845219, 0.008154575330471354, 0.11217760095106703, 0.08276647342635052, 0.027922418301126788, 0.028152534971013665, 0.0500993311538228, 0.043313573846327405, 0.09117226701761995, 0.036764961135174544, 0.01723041631547468, 0.0578281469643116, 0.08337478007056884, 0.06818481015839747, 0.061935536563396454, 0.06486007677657263, 0.07671136941228594, 1.3574993056910378, 58.676821436200825, 76.80547060285295, 67.98325947352818, 98.54913548060826, 67.623995917184, 40.050879274095806, 32.603636741638184, 37.859997613089426, 10.298165713037763, 5.22055767263685, 2.37112010376794, 0.4473827007625784, 1.1867916200842177, 0.9732872652156013, 29.83876439503261, 65.81138460976737, 49.63562045778547, 47.74234403882708, 61.22103636605399, 61.42461163657052, 45.68126514979771, 60.326309885297505, 64.68742316109794, 65.16216577802385, 64.53629289354596, 63.98628738948277, 65.74338259015764, 70.25685596466064, 68.86085864475795, 68.06799275534493, 69.25347355433873, 64.42156423841203, 62.97094712938581, 57.29790278843471, 54.01319749014718, 52.806976318359375, 49.97637748718262, 39.89784867422921, 37.27652958461216, 27.818789311817714, 23.195428439549037, 31.43957723890032, 30.88502413885934, 23.28206726482936, 26.287878819874354, 22.93163139479501, 34.78688580649239, 29.842995847974503, 12.436019590922765, 0.8217426570398467, 0.344618165067264, 0.4204231474016394, 3.201666942664555, 0.38305340121899334, 4.318074396678379, 18.628236804689678, 23.88244547162737, 42.05475017002651, 44.86619976588658, 34.93278408050537, 34.651468890053884, 7.208693938595908, 6.187822912420545, 1.9237816163471766, 8.161883865083967, 41.88916417530605, 45.175797598702566, 14.926709072930471, 3.4289166799613406, 17.71956876346043, 18.400905643190654, 6.800726984228406, 2.0588268041610718, 2.4902461000851224, 1.4006274257387434, 2.0440998801163266, 0.79638998316867, 0.7125923740012305, 5.730680951050349, 24.02485748699733, 32.502391065870015, 21.670512505940028, 19.281358786991664, 25.510729755674088, 23.974397931780132, 25.37036919593811, 22.316271134785243, 25.41784449986049, 18.91337350436619, 30.591386318206787, 42.95211696624756, 52.621247495923726, 57.554121085575645, 60.46642030988421, 62.52323995317732, 63.08731555938721, 63.16567039489746, 62.593743324279785, 60.186421803065706, 63.3007572719029, 68.08457115718296, 66.90070928846086, 64.52775355747768, 65.22064181736538, 63.816188539777485, 63.060002190726145, 61.14349446977888, 62.15320668901716, 58.52551746368408, 59.47997065952846, 51.80158935274397, 57.061393056597026, 57.65943840571812, 53.80250031607491, 23.74362220082964, 0.22752890017415794, 0.259935094841889, 0.09310177633804934, 0.6903693750500679, 3.742004462650844, 4.9931318419320245, 30.93484272275652, 43.64155544553484, 57.46276617050171, 76.36432947431291, 56.48305974687849, 60.792165756225586, 8.368849856512886, 0.2668206239385264, 0.026368486595207026, 0.15645631961524487, 0.023922015014769774, 0.16046338102647237, 0.077307550635721, 0.04257295287347265, 0.11828596996409552, 0.058464829943009784, 0.02812606531993619, 0.04894724315298455, 0.0866986992103713, 0.09735509167824473, 0.015816934573064958, 0.09410168589758021, 0.06508107563214642, 0.040201829214181216, 0.03518500591495207, 0.06396285670676402, 0.08994792521532093, 0.02165998112676399, 0.08106518257409334, 0.12766962072678975, 0.07788433932832309, 0.115601671859622, 0.12634087274117128, 0.11330016928591899, 0.15993837134114333, 0.10660258760409695, 0.08975630692605462, 0.1241744054215295, 0.06946916838309594, 0.18786186512027467, 0.19446835347584315, 0.09458968149764196, 0.11979299624051366, 0.12311905276562486, 0.2549992954092366, 0.14289692363568715, 0.09885430123124804, 0.1290134321898222, 0.25856404698320795, 0.23209618723818234, 0.13155363659773553, 0.11622440415833678, 0.153053683627929, 0.14283586905470916, 2.064324132033757, 73.95463861737932, 90.6858104978289, 81.7520946775164, 114.823331287929, 87.6574798311506, 52.37627485820225, 46.069023268563406, 36.32699223927089, 12.020480837140765, 8.437500664166041, 3.3857129982539584, 1.1348144263029099, 2.9093870605741228, 2.1288051520075117, 32.50410727092198, 72.06156717027936, 58.9049516405378, 52.95939895084926, 63.38672038487026, 70.0824978692191, 53.52682358877999, 67.02125358581543, 72.18204198564801, 70.02055467878068, 61.78429903302874, 63.32833467211042, 65.5383551461356, 69.18302576882499, 69.84634249550956, 69.1972348349435, 69.65567002977643, 65.1390630177089, 64.17504910060337, 58.538941383361816, 54.785871914454866, 56.490813936506, 58.389499528067454, 52.58162886755807, 54.0998797416687, 38.33372579302107, 30.413557597569056, 44.639462675367085, 38.695956230163574, 34.51771606717791, 30.53206259863717, 25.398490292685374, 38.31622675486973, 36.40525674819946, 21.25094379697527, 1.7553271012646812, 1.8902804425784518, 0.5617070304495948, 10.178003566605703, 0.7812529525586537, 14.121629987444196, 22.163574048451014, 30.02516371863229, 42.374454157693044, 48.246786730630056, 40.53237206595284, 44.176427773066926, 11.418544496808734, 9.397644434656415, 3.1354028412273953, 14.922019038881574, 45.497297695704866, 47.05671317236764, 18.711085387638636, 6.575080326625279, 20.47292447090149, 23.219469206673757, 15.481819765908376, 4.7928309100014825, 6.681644848414829, 4.618567483765738, 4.459927516324179, 0.7479071904506002, 3.389656969479152, 9.771097081048147, 33.44965982437134, 41.20065328053066, 33.76882880074637, 31.66019991465977, 32.45708533695766, 35.21030902862549, 36.7935985156468, 31.873829228537424, 30.405348300933838, 23.323567117963517, 36.56630556924002, 49.51324183600289, 54.89568471908569, 55.93186262675694, 59.27530452183315, 63.49131161825997, 64.83364800044468, 66.6254494530814, 64.2126874923706, 59.91793646131243, 64.97827475411552, 67.05045686449323, 65.88465336390904, 64.61524527413505, 65.65542534419468, 64.2032448904855, 63.29011957986014, 63.61596230098179, 64.99417223249162, 61.989500182015554, 65.57504858289445, 59.5796981539045, 63.71853160858154, 64.37639399937221, 63.25165435246059, 26.95460363796779, 0.3906783434961523, 0.4665628501347133, 0.441548900944846, 1.2166486808231898, 5.59841764824731, 8.411261660712105, 41.858776228768484, 50.9764039175851, 68.38338538578579, 83.90698119572231, 58.40973963056292, 71.98971584865025, 7.163060775824955, 0.7093736752867699, 0.15028876199253968, 0.2829518440578665, 0.14064907282590866, 0.21977263422948973, 0.1649710927158594, 0.27798445203474587, 0.18751479445823602, 0.15806489544255392, 0.15706424627985272, 0.34834036390696255, 0.31327332130500246, 0.2184195811195033, 0.10935457636203084, 0.12991753939007009, 0.1227615869471005, 0.09104910612638507, 0.1395033257348197, 0.13908240332135133, 0.2200550812163523, 0.12677043969077723], [0.10588885697403125, 0.05919717278863702, 0.1347263984914337, 0.009915066666768065, 0.04198315666456308, 0.036482388619333506, 0.03134338830464652, 0.0426611386771713, 0.025009630314473594, 0.017691263729440312, 0.054814236903829236, 0.0869130619934627, 0.033883606283260245, 0.08010135072150401, 0.0018306283205414989, 0.03772057932136314, 0.02145984043766345, 0.0588489757584674, 0.06986335651682955, 0.04795832586075578, 0.07379984350076743, 0.0375533713293927, 0.08335005425448928, 0.040729044138320854, 0.05629605560430458, 0.17697844840586185, 0.1938271378832204, 14.532983320099966, 68.73570769173759, 61.51131125858852, 89.07542651040214, 75.63005079541887, 45.69523450306484, 32.259138107299805, 14.532496946198599, 2.463614957673209, 1.854937344789505, 0.9945768713951111, 1.01908001942294, 2.349637359380722, 6.06634885924203, 30.529074873243058, 48.804952893938335, 38.03450856889997, 49.94861943381173, 55.498367990766255, 64.79856654575893, 59.561556407383506, 65.02614089420864, 65.02050590515137, 69.16869163513184, 64.77289990016392, 65.37192494528634, 64.40911306653703, 68.28266429901123, 65.27542836325509, 66.38932187216622, 70.1243816103254, 68.44094426291329, 62.30829742976597, 62.88483810424805, 62.063095501491, 55.81366334642683, 53.29352045059204, 48.22217621122088, 44.13100739887783, 33.30077035086495, 24.06235691479274, 29.651753629956925, 27.574122394834244, 26.153981821877615, 22.253624439239502, 22.767891883850098, 41.89777646745954, 24.528718267168315, 6.361647299357823, 0.7801976406148502, 0.0952455670173679, 0.13423823325761727, 2.8145026777471815, 1.5670402560915266, 0.8343997778637069, 3.802929307733263, 11.292926277433123, 18.453011921473912, 33.58370099748884, 24.90251919201442, 22.122155836650304, 4.236770050866263, 3.28144594175475, 1.5423810992922102, 3.7266767365591864, 26.954601900918142, 33.85238783700125, 8.583598698888506, 2.2831910848617554, 13.560776608330862, 13.40152997629983, 9.87530790056501, 5.664087678704943, 4.894444840294974, 0.21610192262700625, 0.22109884449413844, 0.34761859263692585, 0.3788109560097967, 0.1520147379487753, 1.9068021731717246, 22.5147533757346, 20.825832162584575, 26.236288445336477, 28.000112976346696, 23.995124408176967, 26.49399539402553, 25.486767155783518, 22.11600841794695, 23.504222018378123, 32.51424816676548, 46.82260751724243, 55.8111480985369, 56.399302686963765, 57.39007411684309, 61.50660037994385, 63.85366712297712, 66.20235279628209, 62.924352509634836, 60.706445830208914, 63.803855487278526, 69.34913635253906, 66.68694795880998, 66.09230027879987, 67.57965251377651, 63.978755542210166, 62.47645773206438, 59.94139357975551, 58.90253366742815, 54.29053136280605, 53.21244886943272, 49.71349934169224, 47.03428438731602, 51.41014174052647, 50.56707164219448, 15.157979863030569, 0.22404996970934526, 0.1748883705586195, 0.05601571886134999, 0.2490243874490261, 0.5945410685879844, 1.7595997005701065, 37.04343836648123, 28.606041056769236, 71.91901097978864, 49.420976706913535, 48.98863199778965, 32.23521893365042, 0.8333987487213952, 0.26828001705663546, 0.050300672849906344, 0.1075902088944401, 0.07143341869648014, 0.11120537562029702, 0.0630041342228651, 0.05998381200645651, 0.08351590178374733, 0.030039790219494274, 0.12434831394680909, 0.11293814371206931, 0.01799370883964002, 0.01733474955627961, 0.08969642621065889, 0.04324496038524168, 0.026035595618720566, 0.020343818269403915, 0.051972515282354186, 0.01650963570656521, 0.025907652751941766, 0.02714039821044675, 0.06408510157572371, 0.07287018945706741, 0.060604325495660305, 0.03290363208257726, 0.0437611864347543, 0.044070744288286993, 0.034879312318350585, 0.021589216709669148, 0.029479303330715214, 0.018393089462603842, 0.013239673671445676, 0.05766240121530635, 0.011603144745874618, 0.058052083876516135, 0.004812353980794016, 0.006869036878924817, 0.10165105972971235, 0.1563457998314074, 0.06806806820843901, 0.038349031670285125, 0.07892488635012082, 0.07570936317954745, 0.12361483116235052, 0.06592389754951, 0.03699123899319342, 0.034555247386119196, 0.26921093996082035, 25.338238988603862, 91.2502613067627, 68.00897475651333, 98.28238024030412, 81.258029120309, 48.05309527260916, 29.394861357552664, 28.811506237302506, 6.599343001842499, 1.5365019461938312, 2.5149990575654164, 1.9441737106868198, 4.942046080316816, 10.773622257368904, 41.155337129320415, 57.60541616167341, 47.081879547664094, 58.319225447518484, 62.62518392290388, 68.35169465201241, 57.88443497249058, 63.46025317055838, 67.04270962306431, 69.73147487640381, 68.5899692262922, 68.14989117213658, 64.129684312003, 67.70412254333496, 66.00360652378627, 66.52004528045654, 70.04279586247036, 67.6329243523734, 63.80258396693638, 63.48078509739467, 62.31311253138951, 55.556156158447266, 53.013980524880544, 45.9763308252607, 39.401507581983296, 28.010804516928538, 24.990544182913645, 28.162810257502965, 28.335502522332327, 27.18585879462106, 26.74779224395752, 17.07213388170515, 43.83785942622593, 32.92610263824463, 8.138756786073957, 0.6664252313120025, 0.243155086679118, 0.05378923851198383, 1.650107707296099, 1.422960238797324, 1.6545712734971727, 8.913659845079694, 17.73870931352888, 25.059407779148646, 42.922187600817, 33.55646405901228, 35.70361375808716, 6.810460107667105, 6.291186051709311, 2.89489637528147, 4.2792704445975165, 35.516887869153706, 41.32567916597639, 12.286746229444232, 3.413571149110794, 17.025358608790807, 16.691792964935303, 10.064068743160792, 7.081365593842097, 8.104271139417376, 0.85039393390928, 1.1433735213109424, 0.37088544986077715, 0.6847321061151368, 0.3818066066929272, 6.604732632637024, 29.732001849583217, 19.144157920564922, 27.265580688204082, 25.172885758536204, 24.412737199238368, 27.260975769587926, 23.65883333342416, 22.25583917754037, 21.935257979801722, 34.49573196683611, 45.48859160287039, 55.86783845084054, 59.612792423793245, 58.68253285544259, 61.948366846357075, 61.72631631578718, 65.82323128836495, 63.55221952710833, 61.26854119982038, 64.44501440865653, 69.19949299948556, 66.41837923867362, 67.48626177651542, 65.84577819279262, 66.32090990883964, 64.62133884429932, 63.83060605185372, 59.97202818734305, 57.65010697501046, 59.389505113874165, 54.76469380514962, 52.52900668552944, 59.37130083356585, 57.72362239020211, 17.693900380815776, 0.1398282897259508, 0.16108681900160654, 0.05656993269388165, 0.10602630781275885, 0.3990940504840442, 3.038345843553543, 49.87745598384312, 37.75846011298043, 75.4265102658953, 62.471726008823936, 55.89856685910906, 45.16790444510323, 1.0431308831487383, 0.19671118312648364, 0.10552159989518778, 0.13826673637543405, 0.06925373351467506, 0.0806373255327344, 0.03893101794113006, 0.06703811311828238, 0.052565035809363635, 0.1197983023843595, 0.09279260185680219, 0.04223771925483431, 0.05228965915739536, 0.02702973423791783, 0.07501410227268934, 0.014989401746009077, 0.04834415105038455, 0.039776981475629976, 0.09387528590325799, 0.10886093535061393, 0.026730557970170463, 0.031911501927035194, 0.26484228723815506, 0.14621171647948877, 0.3064270115324429, 0.13866890408098698, 0.22508861683309078, 0.15443694511694567, 0.2553148956171104, 0.0868925770212497, 0.11306562687137298, 0.07466948790741817, 0.17535151142094815, 0.28162992213453564, 0.08535291321043458, 0.23228845692106656, 0.1255093009344169, 0.13134373857506684, 0.17787703233105795, 0.21147368954760687, 0.18370304256677628, 0.14260020027203218, 0.23185671865940094, 0.1762644395764385, 0.32257060813052313, 0.10850721504539251, 0.15065084184919084, 0.28695566207170486, 0.34245811668889864, 33.003311020987375, 116.22531795501709, 82.6044510432652, 117.3751961844308, 96.41215447017125, 68.91756289345878, 42.209236417497905, 32.90167277199881, 9.324308804103307, 3.0851354471274783, 4.095090201922825, 3.8595714569091797, 6.0270033819334845, 16.909426178250992, 48.155747958592, 57.69772297995431, 47.72598450524466, 59.346509660993306, 66.07192816053117, 77.46400696890694, 63.73305334363665, 68.77890464237758, 69.3606286730085, 72.88360159737724, 68.52580956050328, 68.7104162488665, 65.12576416560582, 68.28192778996059, 65.8583961214338, 67.06449222564697, 70.35733386448452, 66.78452151162284, 64.0908647264753, 63.091025897434776, 63.40883650098528, 59.20436341421944, 59.58613913399832, 56.59301846367972, 53.78523056847708, 42.345108440944124, 31.570335388183594, 38.55120440891811, 37.35193838391985, 38.48263611112322, 33.753956181662424, 27.965559584753855, 53.18768201555525, 44.6233810697283, 16.643199001039775, 1.3223077654838562, 0.5002400087458747, 0.4598582184740475, 4.736480150903974, 2.788614341190883, 1.004036300948688, 14.838904687336512, 22.40073343685695, 31.75581407546997, 49.269891602652415, 38.42485836574009, 50.40184000560215, 9.301307661192757, 10.086276922907148, 5.793166535241263, 9.133256793022156, 40.49748168672834, 45.4661454473223, 17.00742530822754, 7.746774162564959, 20.524808406829834, 18.844343151365006, 21.675603798457555, 11.590149368558611, 13.60504184450422, 6.738009938171931, 1.112094359738486, 0.8654202818870544, 1.4314186934913908, 1.3814657053777148, 18.330426590783254, 35.33525153568813, 28.906265769686016, 39.61293779100691, 37.31236491884504, 29.75899907520839, 34.51465885979788, 34.91443736212594, 28.74435884611947, 30.24183634349278, 42.8926716532026, 51.41239643096924, 60.92805862426758, 57.61278472627912, 57.889420304979595, 62.02819469996861, 64.56689970833915, 67.71260629381452, 62.42918218885149, 60.58884062085833, 66.48351165226528, 71.21020439692906, 68.0985300881522, 68.80477973393032, 67.4861228125436, 64.28888838631767, 65.07027585165841, 65.30196353367397, 64.66007505144391, 61.30529717036656, 65.68023041316441, 63.239446367536274, 59.75412573133196, 65.70021343231201, 62.1034436907087, 19.800964185169764, 0.23474269094211714, 0.867940849491528, 0.18838051014712878, 0.3844945824572018, 0.6285276391676494, 6.404818194253104, 58.60421276092529, 39.19949565614973, 90.82107107979911, 65.45212800162179, 63.478804860796245, 54.961157594408306, 0.8377148285508156, 0.3040279559791088, 0.21820453980139323, 0.2478857785463333, 0.19287908875516482, 0.21934925551925386, 0.19861052477998392, 0.10382898072046892, 0.10705175743039165, 0.19459374674728938, 0.17051471024751663, 0.16527131732021058, 0.16707718398954186, 0.10975938356880631, 0.18971137516200542, 0.11508662306836673, 0.14568639466805117, 0.11845690650599343, 0.18550771501447472, 0.17405483100031102, 0.2478089683822223, 0.14321769428040299], [0.03668857166277511, 0.035771144820111136, 0.12032133074743406, 0.02804266658079411, 0.03776133891993335, 0.03780246492741363, 0.008325346479458469, 0.03724356581057821, 0.03849316268627133, 0.039706844703427384, 0.0186252247741712, 0.09349853611950364, 0.07700174168816634, 0.08072438157562699, 0.004205546898966921, 0.048781107246343575, 0.04278066601338131, 0.03414218580084188, 0.05055742371561272, 0.031477249693125486, 0.060930063016712666, 0.0812043161796672, 0.05208249902352691, 0.03136609887172069, 0.04752688954717346, 0.0065459380109262255, 0.10107205901294947, 3.2167147866317203, 52.54609925406319, 70.70877374921525, 79.76665387834821, 90.09486620766776, 51.96302727290562, 36.99585015433175, 9.751468420028687, 1.9739532555852617, 0.7742875463196209, 2.4469023687498908, 0.45947373339108055, 0.9130031743219921, 2.330333092382976, 30.99750852584839, 59.439566884722026, 52.22587415150234, 64.81820215497697, 73.54913479941231, 64.97714914594377, 61.15826633998326, 65.93108122689384, 69.27433204650879, 69.4343490600586, 69.79974092755998, 67.5306955065046, 71.01192365373883, 71.5485121863229, 69.16002723148891, 64.42254393441337, 71.47604247501918, 68.11140510014125, 66.76011943817139, 59.428845814296174, 55.6966278893607, 57.70868723733084, 55.586245332445415, 47.66732433864048, 45.637415068490164, 41.052399567195344, 29.130522353308542, 24.54956807409014, 29.668425832475933, 24.915312562670024, 30.14795228413173, 44.36633593695504, 41.50918803896223, 23.827033587864467, 4.219865952219282, 0.16086842572050436, 0.0944626054593495, 0.051468027888664176, 0.5166778181280408, 1.1224703001124519, 0.7756381567035402, 0.7119407632521221, 0.6705549582839012, 3.176256511892591, 15.949122599193029, 19.20936155319214, 13.956162112099783, 1.3255623451301028, 6.4673988819122314, 1.4911764583417346, 5.217891735689981, 31.404089314596995, 37.218102182660786, 13.383885025978088, 2.556651336806161, 19.455166237694876, 14.746933119637625, 11.029502698353358, 10.24890124797821, 3.6366259115082875, 0.06537138683987515, 0.4500841929444245, 0.1594879190836634, 0.17515289065028938, 0.44436647689768244, 2.023595746074404, 19.372975996562413, 18.3603663785117, 14.035243902887617, 28.104521819523402, 22.717303786958965, 25.363862207957677, 23.671883787427628, 27.748669828687394, 27.824670961924962, 37.78030177525112, 46.060351916721885, 54.57619265147618, 58.20940916878836, 60.49133655003139, 65.95715781620571, 66.06224237169538, 64.42389188494, 62.314731461661204, 62.13789980752127, 67.26083442143032, 67.65073258536202, 69.19826316833496, 69.78239822387695, 65.17049666813442, 63.459725107465474, 64.45850781032017, 61.76997879573277, 60.63856192997524, 61.01223605019705, 54.17846039363316, 46.92036172321865, 47.35581227711269, 48.31849908828735, 51.63145923614502, 11.42870363167354, 0.12336603951241289, 0.20496155827173165, 0.14368908612855844, 0.09151379404855625, 0.5446870380214283, 11.723999466214861, 31.184679099491664, 33.62650884900774, 79.08696024758476, 36.76729610988072, 62.3816773550851, 13.121788552829198, 0.5591376083237785, 0.08614975080958434, 0.24472888080137117, 0.16366766765713692, 0.07554736294384513, 0.0690121886187366, 0.04451631448630776, 0.026943076834348694, 0.03682107937389186, 0.13437212178749697, 0.05261419227878962, 0.1349646592778819, 0.04654463207615273, 0.025073638219120245, 0.07807989990604774, 0.12464640795120172, 0.06443475067083325, 0.022937838985983814, 0.08721878273146492, 0.09853736430938755, 0.012605428329801984, 0.03339276762147035, 0.03438558309738125, 0.04913402009489281, 0.0168607351702771, 0.022453917988709042, 0.03726373526400753, 0.0689137399728809, 0.03633048837738378, 0.030241220125130246, 0.035097108488636355, 0.054743628549788675, 0.015752578919221247, 0.05415402233068432, 0.01244777241455657, 0.10950419333364282, 0.06525085187916245, 0.052374411573899646, 0.06269659501101289, 0.03377409751660057, 0.06621630543044635, 0.05473991357056158, 0.08608279975929431, 0.10472987166472844, 0.0382146986999682, 0.07208986061492137, 0.02266470998126481, 0.11407058473144259, 0.03870272822678089, 10.93370875290462, 85.20712116786412, 79.82029397147042, 91.1969964163644, 94.26675919124058, 57.55083111354283, 37.781740052359446, 17.97256657055446, 2.7288884946278165, 1.9518123865127563, 2.7999409905501773, 1.3675741936479295, 1.0060981788805552, 3.1986564184938158, 32.28709765842983, 56.596214635031565, 57.376785687037874, 67.44986016409737, 71.78616142272949, 69.61783708844865, 64.51334299360002, 66.41677420479911, 69.78114754813058, 71.41414097377232, 71.15430613926479, 69.09618718283517, 70.98165035247803, 71.68306405203683, 67.01621614183698, 65.76433140890938, 72.24881417410714, 72.11139965057373, 67.21481650216239, 64.80371516091483, 55.67004755565098, 58.70415564945766, 55.1394761630467, 46.297594683510916, 41.05467162813459, 37.129682881491526, 24.360523223876953, 27.324874877929688, 28.18960772241865, 25.34192500795637, 22.87520854813712, 33.26270464488438, 47.82781730379377, 30.008074624197825, 4.920692963259561, 0.3511683078748839, 0.2328562821660723, 0.18982000861849102, 2.1832338656697954, 0.7627159186771938, 1.4688449480703898, 0.6131121920687812, 2.545322516134807, 6.961733681815011, 19.402656963893346, 25.486206088747295, 26.73162031173706, 3.116260988371713, 4.4603743723460605, 1.4319061530487878, 9.166801827294485, 42.48719910212925, 40.2491808618818, 19.21444068636213, 6.516099674361093, 21.89536316054208, 15.292783600943428, 11.825710671288626, 16.582112176077707, 7.851588606834412, 0.4183893065367426, 1.397062674164772, 0.18133830731468542, 0.1634906107293708, 0.5428529307246208, 1.36618064556803, 28.397518668855938, 17.977253130504064, 16.890243938991002, 23.781274488994054, 24.78837765966143, 24.693265506199428, 23.23315715789795, 25.76419656617301, 26.383147307804652, 38.83925935200283, 47.5404189654759, 57.15893186841692, 58.9782829284668, 60.394242422921316, 64.97849014827183, 65.66887705666679, 63.79801900046212, 63.884273937770296, 61.59869180406843, 66.33188806261334, 67.35404450552804, 70.37544087001255, 68.17412648882184, 65.95466341291154, 65.82410676138741, 66.68942846570695, 64.18656921386719, 62.44480868748256, 62.50336810520717, 60.15471717289516, 53.54725824083601, 51.88329321997506, 52.316930294036865, 53.97727877753121, 11.956303800855364, 0.03157399182340928, 0.09052760446710245, 0.10781215091368981, 0.042674203868955374, 0.24879278987646103, 10.736423339162554, 52.86025163105556, 36.26510116032192, 89.91117668151855, 48.358555453164236, 71.38873141152519, 24.74859401157924, 0.39318515041044777, 0.07525853772780725, 0.14436211144285543, 0.041936412387128384, 0.16020484561366694, 0.031838678156158755, 0.07664686787341322, 0.05264541506767273, 0.012525586810495173, 0.1267648892743247, 0.00912975228857249, 0.07023253384977579, 0.06671165635011025, 0.07315883146865026, 0.02812340885533818, 0.13058174374912465, 0.04463174007833004, 0.011448192792678518, 0.06135956211281674, 0.07301829329558782, 0.05927961479340281, 0.022152521215113144, 0.1446654573082924, 0.17650959427867616, 0.14886989098574432, 0.09468521922826767, 0.11575023031660489, 0.19869478525859968, 0.22534161540014402, 0.11702278203197888, 0.16610180347093514, 0.1752772932606084, 0.14687446877360344, 0.1359938204820667, 0.18260057243917668, 0.1948162926627057, 0.15176262147724628, 0.19420152636510984, 0.21486613393894263, 0.06464010929422719, 0.15652038689170564, 0.17469249106943607, 0.2172563685370343, 0.2301775887608528, 0.28187642033611027, 0.18677827183689388, 0.1249040069856814, 0.2757954980645861, 0.19881779008678027, 12.263214417866298, 101.93101828438895, 94.44766943795341, 110.32297611236572, 112.19767652239118, 76.38009493691581, 58.92550441196987, 23.57053562573024, 4.169112835611616, 3.2411090433597565, 6.090461713927133, 2.913980688367571, 1.505075352532523, 5.20590956721987, 40.478026730673655, 72.32733576638358, 61.99196679251534, 76.28974056243896, 82.57848562513078, 75.62236608777727, 65.64321735927037, 72.09230600084577, 74.42070293426514, 74.92129979814801, 72.40976919446672, 68.6175605228969, 70.82723358699253, 72.1858218056815, 68.65387875693185, 65.8752246584211, 71.81354427337646, 69.83733068193708, 66.59787900107247, 63.97835949489048, 55.57910605839321, 61.52955722808838, 58.627127919878276, 54.57818331037249, 53.886351176670615, 50.097213608878, 39.536333901541575, 32.90020670209612, 41.536306858062744, 32.78058304105486, 41.67277990068708, 50.98736817496163, 57.4845244543893, 38.82160745348249, 10.46031061240605, 0.19828072961952004, 0.3814225558723722, 0.2731673148061548, 2.1031157076358795, 5.003290108272007, 3.089593150785991, 0.667419855083738, 13.931024398122515, 12.059853672981262, 32.00005367824009, 34.01011541911534, 42.89926896776472, 5.374771637575967, 12.967274512563433, 8.401788660458156, 9.056368027414594, 47.770828178950715, 44.44101170131138, 22.28466899054391, 10.90708499295371, 26.84043083872114, 19.976857832499913, 18.652272360665457, 18.673573800495692, 11.740073255130223, 2.510976267712457, 1.5260577180555888, 0.40158212983182495, 0.22616634757391044, 0.739244740988527, 8.547306520598275, 36.43300437927246, 26.166684865951538, 18.535337652478898, 38.46718331745693, 30.404479776109966, 33.34835508891514, 28.394079310553415, 34.84809248788016, 35.11988517216274, 45.24274001802717, 52.42205653871809, 57.3328800201416, 59.76202583312988, 63.880132811410085, 67.24152537754604, 66.26729760851178, 63.43945026397705, 63.49808611188616, 62.88363606589181, 68.17146532876151, 66.60931573595319, 72.05076272147042, 69.91631085532052, 65.80778544289726, 64.8794505255563, 67.17239080156598, 65.48668139321464, 65.73970699310303, 67.02339363098145, 68.0901575088501, 60.3487525667463, 61.64391762869698, 60.85939652579171, 61.991542952401296, 13.409014054707118, 0.15945886421416486, 0.3534319821212973, 0.42052319060478893, 0.3673786994601999, 0.6559602128607886, 18.36345485278538, 55.017358098711284, 45.30517305646624, 102.52221270969936, 51.104139600481304, 82.7207360948835, 22.07741986002241, 0.5490179913384574, 0.1379537553127323, 0.35422575952751295, 0.1721978842147759, 0.14488560120974267, 0.19223099281745298, 0.1708099136927298, 0.17143001327557222, 0.08916322660765477, 0.1619281345712287, 0.12353016356272356, 0.2795610417212759, 0.21261174205158437, 0.18296213660921368, 0.20250744638698442, 0.2283059720482145, 0.186257306220276, 0.11679277223135744, 0.23547857574054173, 0.2013559860310384, 0.19815733124102863, 0.1619077649499689], [0.05839291201638324, 0.07246602685855967, 0.005561906594916114, 0.02636673767119646, 0.04091625873531614, 0.030184270681015084, 0.02154850121587515, 0.08018441019313675, 0.003969607974535653, 0.03433505937989269, 0.06582892978829996, 0.05364291922056249, 0.05715122685900756, 0.04990190799747195, 0.03140656330755778, 0.015350555402359791, 0.01355962413695774, 0.06633573437907866, 0.0474158744327724, 0.0028688530562379, 0.02372386073693633, 0.04931392686973725, 0.03157187140147601, 0.08099235541054181, 0.04588695861665266, 0.08594393078237772, 0.1154709453029292, 0.6856720671057701, 41.10114812850952, 85.58630520956856, 72.09161118098667, 99.61532265799386, 60.868561199733186, 47.195493016924175, 11.20054476601737, 3.633977562189102, 2.5631010021482195, 0.9518872478178569, 0.2862304167023727, 0.18084121256002358, 0.5405126905867031, 44.109266485486714, 81.59822681971959, 74.86900070735386, 71.80424758366176, 70.13823631831578, 68.13203430175781, 69.95889636448452, 68.95172718593052, 70.25246470315116, 71.25157397133964, 76.19298689705985, 69.34336934770856, 68.84020165034703, 67.74449157714844, 71.2658108302525, 66.73124272482735, 69.12050587790353, 68.1195205960955, 73.6864242553711, 68.12441212790353, 66.08377483912876, 59.87394046783447, 53.69151326588222, 46.491084643772666, 45.75898422513689, 36.25290707179478, 32.184361594063894, 24.60364764077323, 29.548840386526926, 25.531682048525127, 33.25258111953735, 21.63188920702253, 26.349372114453995, 27.071124928338186, 4.734424352645874, 0.31994321197271347, 0.2663990637021405, 0.007867370964959264, 0.2969346323183605, 0.9089073741010257, 0.23916250520518847, 0.7027456366590091, 1.3697235754558017, 3.061940623181207, 5.002109783036368, 11.761247021811348, 4.125264925616128, 3.8771669013159613, 10.44035712310246, 1.3882662547486169, 19.19890625136239, 31.379690715244838, 31.730821405138286, 28.378491027014597, 12.122680153165545, 19.775877714157104, 15.766994680677142, 11.762703537940979, 6.542536701474871, 0.3645840037081923, 2.298864918095725, 0.5587400410856519, 0.09758933553738253, 0.03635450512436884, 0.0260248086082616, 1.4510292240551539, 17.502738067081996, 19.68898527962821, 17.64149706704276, 25.34721085003444, 25.328685215541295, 28.569430998393468, 21.159922395433696, 30.86870629446847, 30.808767659323557, 38.87584161758423, 45.90675851276943, 53.64790637152535, 60.00829083578927, 62.32969788142613, 66.06644603184291, 63.50496482849121, 62.801313808986116, 62.37545871734619, 64.43060384477887, 68.8762697492327, 68.57809475490025, 69.92763641902378, 69.59664508274624, 67.04557922908238, 65.05985355377197, 61.895713397434776, 62.322457858494346, 60.36807550702776, 56.85633781978062, 51.679631096976145, 46.08110966001238, 45.84919616154262, 57.160220759255544, 50.786697251456125, 6.025138659136636, 0.10299221133547169, 0.04161820321210793, 0.3437578912292208, 0.06162056739309004, 0.622684964111873, 33.00664268221174, 28.945050614220754, 60.20004027230399, 56.77962275913784, 37.9643942969186, 57.97803068161011, 1.0962460615805216, 0.1802512127906084, 0.06222468747624329, 0.08105178829282522, 0.02427301778724151, 0.143228537270001, 0.019869769956650477, 0.17627258199666226, 0.049754896600331576, 0.12785286589392594, 0.1326667054423264, 0.12688729699168885, 0.08291018035795007, 0.12893408430474146, 0.049182521778025796, 0.0695651335907834, 0.09011454627450023, 0.038387365506163666, 0.05243420068706785, 0.06103936143751655, 0.051544186659157276, 0.0385729991165655, 0.05018084356561303, 0.030226285569369793, 0.04588187299668789, 0.0481169096726392, 0.041703464529876194, 0.028409094150577272, 0.06265709748757736, 0.030486792126404386, 0.06310841826988117, 0.035381614829280546, 0.021185920939647725, 0.07723692871098008, 0.09578194894960948, 0.03925097095114844, 0.015665929997339845, 0.033357918062912564, 0.0471758019578244, 0.012774889058034335, 0.10146348550915718, 0.04467240807467273, 0.09757141542754003, 0.08109432565314428, 0.06465895221169506, 0.020172922439607124, 0.1014601606875658, 0.04274935501494578, 0.01768186771576958, 0.12071687595120498, 1.0025158396789005, 60.777852467128206, 94.39992836543492, 87.61310168675014, 105.2047871180943, 67.31481497628349, 51.322927951812744, 15.360017844608851, 3.5440971851348877, 3.10882511309215, 1.4175721279212405, 0.3368565929787499, 0.44389399939349716, 0.9807677609579903, 48.71255922317505, 83.38961832863944, 79.6214712687901, 75.32594203948975, 76.21336596352714, 72.06959233965192, 71.44515078408378, 69.91874967302594, 73.2419410433088, 72.25000926426479, 75.97706467764718, 68.35913617270333, 70.96249416896275, 68.5796650477818, 72.01854392460415, 67.4753531047276, 68.19423457554409, 69.10159982953752, 72.86812101091657, 69.12047808510917, 67.53752558571952, 62.632639339991975, 55.76135035923549, 48.39531489780971, 43.19178465434483, 32.87453658240182, 28.213478258677892, 24.295013870511735, 31.32112087522234, 27.6465973172869, 27.944452694484166, 31.198304516928538, 31.344953196389334, 31.424492699759348, 6.15844202041626, 0.6462504310267312, 0.1196346397378615, 0.07069728284009866, 1.1713898522513253, 3.2623981067112515, 1.5090134612151553, 0.5199660531112126, 0.10723763531340019, 1.5698248552424567, 4.157211005687714, 13.133350355284554, 7.628036396844046, 3.400674424001149, 1.8969515817505973, 1.0746393352746964, 28.68732108388628, 39.02127088819231, 40.75525985445295, 33.69665091378348, 17.446613992963517, 21.16928161893572, 18.99203406061445, 14.212966663496834, 11.189744659832545, 6.9950359633990695, 1.3815152112926756, 1.1231079058987754, 0.2768726316945893, 0.050974929705262184, 0.2335003747471741, 0.9958854126078742, 28.77172432626997, 21.591481958116802, 18.59783148765564, 23.159919670649938, 25.595379659107753, 24.82008923803057, 22.517480543681554, 29.948146411350795, 31.334517002105713, 41.58498593739101, 49.24885245731899, 55.48003169468471, 60.64530863080706, 62.11557524544852, 66.68482181004116, 63.775506837027415, 64.1266062600272, 62.191894258771626, 63.874636786324636, 67.12958295004708, 69.16788564409528, 68.53515488760812, 69.17024108341762, 67.31259850093296, 65.48842539106096, 65.15411976405552, 65.21805013929094, 63.59890447344099, 58.97396809714181, 59.07202107565743, 55.75792837142944, 58.226633753095356, 59.1253901890346, 54.13843182155064, 6.333973058632441, 0.11225171054580382, 0.06506350836051361, 0.183764924960477, 0.038157705151076825, 0.1432422436773777, 37.11243050439017, 43.483647210257395, 55.25808538709368, 81.02633449009487, 44.69713967187064, 73.87092672075543, 3.412335238286427, 0.1856107437717063, 0.12124234704034668, 0.04079993747706924, 0.2658885068127087, 0.10482587079916682, 0.0785386845735567, 0.11626370490661689, 0.10120970662683249, 0.02009026669631047, 0.21253318126712525, 0.02647617519167917, 0.0746829839689391, 0.15058596033070767, 0.05809470944638763, 0.055668702482112815, 0.01812942941407008, 0.05582166463136673, 0.023182600137910674, 0.05818036092179162, 0.04778608653162207, 0.017925460091126815, 0.02770232020079025, 0.09638826748622314, 0.1643811065171446, 0.10392724616186959, 0.1240461894444057, 0.17538234405219555, 0.1427593303046056, 0.1394564253943307, 0.17107999777155264, 0.13439884249653133, 0.14514364807733468, 0.2059288913650172, 0.23241276453648294, 0.12768799545509474, 0.09123815276793071, 0.1188370082527399, 0.24031834889735493, 0.07802753735865865, 0.20623286148267134, 0.17362246848642826, 0.23210199549794197, 0.17989761462169035, 0.15146298041301115, 0.2291015407868794, 0.19030556827783585, 0.13861029222607613, 0.2339216364281518, 0.15770021001143114, 1.688048128570829, 83.63975347791398, 111.35247680119106, 104.38103648594448, 125.6608396257673, 87.34986223493303, 71.6352812903268, 29.235803195408412, 7.419051953724452, 5.838552602699824, 2.2928264992577687, 0.48351710609027315, 0.38526596820780207, 1.065264261194638, 58.55793081011091, 92.86305631910051, 80.36443519592285, 81.61423546927315, 80.64337062835693, 76.4978391102382, 74.27697249821254, 71.92559787205288, 71.84435953412736, 74.3819945199149, 76.22412177494594, 67.88431017739433, 69.93503625052315, 67.62155015127999, 72.87717451368059, 66.65802260807583, 66.65978745051792, 68.35526602608817, 73.04562664031982, 67.85099356515067, 65.59596960885185, 60.2397700718471, 58.0073937688555, 54.15743167059762, 55.65394510541643, 45.329377106257844, 40.80588790348598, 30.86966167177473, 40.675247873578755, 33.84760052817208, 47.20361198697771, 32.258227893284385, 33.85544504438128, 38.31808887209211, 9.56100526877812, 0.7333800813981465, 0.3124001553016049, 0.08656369109771081, 0.9269548313958305, 2.890622364623206, 1.1549015598637717, 0.9468334104333604, 2.778595255953925, 6.988132493836539, 9.590786116463796, 19.239092894962855, 35.06553636278425, 4.9730619703020364, 22.85325571468898, 6.71355618749346, 29.249042987823486, 47.279614857264924, 44.892352785382954, 38.00418663024902, 20.824522427150182, 22.93356646810259, 18.531137466430664, 20.7856159891401, 14.338434628077916, 11.180826646941048, 7.26166135924203, 1.2783961274794169, 0.8285879354391779, 0.2335672511586121, 0.6981155851057598, 4.860199340752192, 37.3642749105181, 28.221897738320486, 25.504783834729874, 34.693481172834126, 31.153867312840053, 32.087778159550254, 27.23906809943063, 38.160323074885774, 39.92342151914324, 47.37698343821934, 52.95164476122175, 56.460655280521934, 63.724722453526084, 62.848297527858186, 66.44013404846191, 63.07422515324184, 64.18443611689976, 62.32814148494175, 66.47915513174874, 68.16676834651402, 68.52177265712193, 70.35515907832554, 69.70828178950718, 67.79719366346086, 66.3366197858538, 65.08856351034981, 68.0252126966204, 65.34117221832275, 62.963359696524485, 64.79455743517194, 59.364602770124165, 60.02736364092146, 66.57547106061662, 61.30671460287911, 7.869170154844012, 0.18833257843341145, 0.1750484233988183, 0.502218345446246, 0.1291223234896149, 0.8747525268367359, 48.73197596413748, 42.61740834372384, 71.1559111731393, 83.06187180110386, 52.95110280173165, 81.13403851645333, 1.995793832199914, 0.2861803951007979, 0.19295262838048594, 0.11600609230143683, 0.3831116466649941, 0.143244292853134, 0.1633877991033452, 0.24903605825134686, 0.2104678020945617, 0.2640735070620264, 0.3108507070158209, 0.21029130156551087, 0.20340191838996752, 0.2773836228464331, 0.1634682190737554, 0.2052664647677115, 0.18649615054684027, 0.1957827029483659, 0.15500691453261034, 0.1143216426883425, 0.13593767849462374, 0.11051058968795197, 0.15037813862519606], [0.022912456687273722, 0.024113019229844213, 0.018485918142167584, 0.0039046467281877995, 0.020372104697993824, 0.04063290590420365, 0.019236248951139193, 0.055935638158449104, 0.04437681786449892, 0.06572184339165688, 0.031209055334329605, 0.11432107271892683, 0.12458383345178195, 0.01578540474708591, 0.09076997039041348, 0.03199100248249514, 0.14996059531612055, 0.039212718539472134, 0.0718544903876526, 0.013509083456093711, 0.030636721224124943, 0.0762491242161819, 0.060597139809812815, 0.05043631200013416, 0.06466881132551602, 0.039459376196776114, 0.14916231243738107, 0.0484157195314765, 42.975890227726524, 93.14225578308105, 74.3045985358102, 87.95176383427211, 73.90542452675956, 45.64013876233782, 20.37159194265093, 1.435150527528354, 0.04075285732480032, 0.205214706116489, 0.27900241741112297, 0.9169323806251798, 0.7949594685009548, 41.31125817980085, 71.59407847268241, 62.81360517229353, 69.9014139175415, 62.29763194492885, 70.61599445343018, 68.66953304835728, 68.98396682739258, 72.6733421598162, 74.85149124690464, 76.52068478720528, 76.44697829655239, 72.29999460492814, 72.5828696659633, 68.06401143755231, 67.65465136936733, 70.42209107535226, 71.40494155883789, 68.1233490535191, 65.43405573708671, 61.401105880737305, 59.03112397875105, 52.6712258883885, 43.872523988996235, 40.39525284085955, 41.00472450256348, 35.22247532435826, 24.215031419481548, 23.589203698294504, 22.370993409837993, 18.866942167282104, 7.808295249938965, 24.37519781930106, 25.255237545285905, 6.238599479198456, 0.2591460128980023, 0.27876623294183184, 0.04056985303759575, 0.43771859790597645, 0.0283180873375386, 0.18800867295690946, 0.2828190954668181, 0.440227738980736, 0.6107929050922394, 1.1699064118521554, 3.4827563166618347, 9.38439335141863, 3.364293656178883, 1.1297807821205683, 0.9113563426903316, 21.54287930897304, 27.825661080224172, 23.931042909622192, 17.507912737982615, 11.51458944593157, 12.859672103609357, 11.008783170155116, 11.709793874195643, 9.645973920822144, 0.4471620683159147, 0.8079002712454114, 0.42660470998712946, 0.163392304575869, 0.10584527466978345, 0.3809274152985641, 1.0599608314888818, 17.981255292892456, 16.447440453938075, 17.547691174915858, 18.367224250520977, 23.831417901175364, 25.26508140563965, 21.186448880604335, 33.95702770778111, 32.11539724894932, 32.34708145686558, 47.82526731491089, 54.772315979003906, 61.78985759190151, 63.59583336966378, 67.93795721871513, 64.52794810703823, 62.90184729439871, 65.02170794350761, 68.80975464412144, 67.00709315708706, 72.62949207850865, 71.64091627938407, 70.17384583609444, 65.18055765969413, 69.18311609540666, 66.52487427847726, 62.26634420667376, 59.823732784816194, 57.23397936139788, 48.362797328404014, 38.00715351104736, 37.62353304454258, 51.47658041545323, 30.153559480394634, 1.2283216544560023, 0.11579559716795172, 0.3095604862485613, 0.1042048144819481, 0.5782868436404637, 14.401962007795062, 41.70589848927089, 29.134800706590923, 78.7500559943063, 37.88954135349819, 68.75887993403843, 22.622280223029, 0.40621891245245934, 0.07214748859405518, 0.1709140281059912, 0.13699816087526934, 0.15763009020260402, 0.09284994485122816, 0.19643016106316022, 0.11685541458427906, 0.10765493434986897, 0.13594058262450354, 0.2174187691083976, 0.049614735014204464, 0.10345393405961138, 0.009991341636383107, 0.09369327566985573, 0.045015726438058276, 0.20375410520604678, 0.11245159339159727, 0.02947801411417978, 0.018112671295447007, 0.039336449400122674, 0.035106146575084755, 0.04157836642116308, 0.034176098981073925, 0.10357814668012516, 0.017742058860936334, 0.038334772256868224, 0.051910107024013996, 0.048802155402622054, 0.02867602643423847, 0.057377504717026434, 0.05990638437547854, 0.06487727763929538, 0.04251373712239521, 0.09046955579625708, 0.028721671484942948, 0.056574824931366105, 0.030021446025265113, 0.013608406563954694, 0.08697033713438682, 0.03181956382468343, 0.03658891861726131, 0.03160613063456757, 0.04322560178115964, 0.03444854096908655, 0.07793144322931767, 0.14914249921483652, 0.1270520452942167, 0.042164009995758533, 0.08109344355762005, 0.12237282709351607, 60.7664087840489, 105.32927799224854, 84.21209049224854, 103.16934013366699, 81.16216482434953, 56.98320497785296, 28.52020648547581, 1.9773958708558763, 0.4125235341489315, 0.22798573066081318, 0.4333635430250849, 0.9206699686391013, 1.4102334188563483, 43.95206696646554, 78.62848336356026, 68.02555315835136, 75.25231892721993, 70.96799714224679, 77.22144535609654, 71.70201873779297, 69.24006353105817, 74.88890729631696, 76.89745780399868, 75.47414711543492, 76.41387013026646, 71.5057738167899, 70.04034314836774, 69.45773669651577, 69.28989601135254, 70.23520537785122, 71.35748536246163, 69.5134334564209, 67.35713645390102, 64.96176583426339, 61.00306442805699, 54.304889815194265, 47.351261207035606, 45.193960189819336, 40.62851081575666, 34.0859306880406, 26.61064175197056, 26.104798998151505, 25.237790618624004, 24.582605021340505, 16.47625810759408, 28.582597834723337, 32.839799063546316, 8.310601370675222, 0.2690869037594114, 0.21405466033944062, 0.09503900738699095, 0.9454018643924168, 0.5105084148900849, 0.3375624322465488, 0.3669638160083975, 0.03542777895927429, 0.8210783441151891, 2.3127003014087677, 3.934847806181226, 7.681402904646737, 3.04220079098429, 3.691128884043012, 2.299505455153329, 24.565948452268326, 34.76710081100464, 27.694786548614502, 20.030741112572805, 13.24924978188106, 15.002805743898664, 15.123053005763463, 14.401712741170611, 12.70079893725259, 0.02621289512275585, 2.6675456719739095, 0.8107249853866441, 0.3899752183684281, 0.18973494746855327, 0.5259265761290277, 1.6721871282373155, 27.76145625114441, 20.134726115635463, 12.85423948083605, 18.986774274281093, 26.220429182052612, 24.708426475524902, 23.045069422040665, 35.53369556154524, 35.60700600487845, 35.449511187417166, 51.53769677025931, 56.15561894008091, 62.65884099687849, 64.2281472342355, 68.55473491123745, 64.48556409563336, 62.183625902448384, 65.52933638436454, 69.81399863106864, 66.07256044660295, 71.10980292728969, 71.28886495317731, 71.37206268310547, 65.41717161451066, 70.10883154187883, 65.14980493273053, 65.30559744153703, 61.58118234361921, 61.64378561292376, 52.74935143334525, 49.335406167166575, 46.10196467808315, 59.88984489440918, 33.82875006539481, 1.4487942925521304, 0.15207751600870065, 0.21005796694329806, 0.05525273676695568, 0.19148775269942625, 8.495684879166738, 59.83593382154192, 37.19469370160784, 82.07676315307617, 52.47003732408796, 67.67626026698521, 40.254555293491904, 0.4775685252887862, 0.1593106450246913, 0.18511392043105193, 0.03147972295326846, 0.08171827931489263, 0.07988174964806863, 0.11061576940119267, 0.11616317315825395, 0.06788271279739481, 0.14980518365544931, 0.19380268348114832, 0.06126716599932738, 0.18287209501223906, 0.0894910404458642, 0.08075475958841187, 0.04594804033903139, 0.0717451444693974, 0.10768270000283207, 0.01653219699593527, 0.04275686300492712, 0.08169843216559716, 0.019382398608805876, 0.04121816949918866, 0.08228054057274546, 0.16634082421660423, 0.16954331951481955, 0.07706956126328025, 0.2124027939779418, 0.10641316098294087, 0.14231497129159315, 0.3227136975952557, 0.11007879035813467, 0.1755451788859708, 0.05758443754166365, 0.16394030302762985, 0.1465188485703298, 0.14099313079246453, 0.10868617187121085, 0.13627367546515806, 0.2800297737121582, 0.14248575855578693, 0.1671863059912409, 0.08041098660656384, 0.2573590502142906, 0.27717604541352814, 0.19929131253489427, 0.19982261902519635, 0.21940000993864878, 0.14621809470866406, 0.2577667683362961, 0.15182679731931004, 73.62315395900181, 121.30758476257324, 101.17681217193604, 113.56569344656808, 101.14401667458671, 69.79471737997872, 44.031790597098215, 1.9137039056846072, 0.6571758219173977, 0.33350688272288864, 0.9316452997071403, 1.179374092391559, 1.442158545766558, 49.87748030253819, 88.93523270743233, 73.70528861454555, 80.04376193455288, 73.33160059792655, 80.45107228415353, 74.92049380711147, 71.9822951725551, 77.25635310581752, 80.23904800415039, 75.73054953983852, 79.1212774004255, 71.8049007143293, 69.55414295196533, 69.01241970062256, 69.86802087511334, 71.52855001177106, 71.22902011871338, 71.04034178597587, 69.03609916142055, 63.07822036743164, 61.18790735517229, 56.402019432612825, 52.07055412020002, 50.826569489070344, 53.45019885471889, 45.2613959312439, 33.975443908146445, 32.99586255209786, 30.88499982016427, 26.73345637321472, 13.12525222982679, 30.93802499771118, 38.081242152622764, 11.149780358586993, 0.3736828326114586, 0.4086709480200495, 0.1460544184914657, 0.6139869051320213, 0.2819780648819038, 0.29260891729167526, 0.48178054498774664, 0.8870804767523492, 0.6904917284846306, 1.1472534388303757, 4.3569969023977, 20.53185214315142, 5.228401320321219, 15.69821446282523, 5.542271426745823, 32.98716688156128, 47.70545257840838, 37.38661336898804, 28.48516845703125, 14.195983529090881, 14.868731566837855, 10.922474384307861, 15.517860071999685, 15.264195237840925, 0.2576466133551938, 2.298889671053205, 1.6631614182676588, 0.5961914286017418, 0.3250117871378149, 1.1781839962516512, 5.145223566464015, 34.86203057425362, 23.4929780960083, 27.104415484837123, 27.429872580936976, 32.22233697346279, 33.052882943834575, 26.00572463444301, 40.805151394435335, 42.635536193847656, 39.59506355013166, 55.229156562260215, 57.58001702172415, 65.2340726852417, 64.72932774680001, 69.66365350995744, 66.52281761169434, 65.05999946594238, 66.65674413953508, 70.25087356567383, 66.21121869768415, 73.14522211892265, 71.8373418535505, 72.33527060917446, 67.06756332942417, 71.31766523633684, 69.93654400961739, 68.07327338627407, 63.381863594055176, 68.89776052747453, 60.44424860818045, 53.34508303233555, 51.479293687003, 66.31357955932617, 36.1930969783238, 1.5917156977312905, 0.4011174961924553, 0.5496504945414407, 0.1634756965296609, 0.4526856147817203, 22.960584538323538, 61.31323896135603, 40.93162250518799, 95.051023210798, 55.31613063812256, 86.08227457318986, 33.8353647504534, 0.4804741750870432, 0.23191822107349122, 0.2711243544306074, 0.27582263946533203, 0.4413475388927119, 0.18050041156155722, 0.35337577228035244, 0.19924123665051802, 0.16400643305054732, 0.2935514567153794, 0.37468907290271347, 0.19854163990489074, 0.3705538090850626, 0.21082015175904545, 0.16725432234151022, 0.13925107355628694, 0.19720069185963698, 0.17693312226661614, 0.10922810421990496, 0.09962094402206795, 0.11795240214892797, 0.07559518609195948, 0.1174768033836569], [0.04368522104674152, 0.019525618691529547, 0.13731000199913979, 0.01385917020629027, 0.016924412289102162, 0.061011249731693945, 0.017792728463453904, 0.047610125437911065, 0.03872405118974192, 0.07174652868083545, 0.03722534375265241, 0.07078247291168996, 0.059999900071748664, 0.07440798051123108, 0.07257247543228523, 0.03414917131885886, 0.08873161048229251, 0.03583307810393827, 0.08093255611934833, 0.01898265496960708, 0.08871994646532194, 0.030291428323835135, 0.07548670191317797, 0.11691376859588282, 0.15815558843314648, 0.10248000560594456, 0.19766789036137716, 0.43085768605981556, 21.42698856762477, 98.56400462559291, 75.13790988922119, 75.88178403036935, 93.97155107770647, 44.66723462513515, 41.38597215924944, 2.915684082678386, 0.6511036391769136, 0.08463521315050976, 0.39311550557613373, 0.7219851985573769, 0.7768817214029176, 31.6057642527989, 74.11442634037563, 66.48791681017194, 61.865572111947195, 60.242382594517295, 68.90807165418352, 71.80058588300432, 66.09429441179547, 72.6761839730399, 77.68073517935616, 76.85626888275146, 76.77721922738212, 74.21565464564732, 73.70831108093262, 74.53957271575928, 72.29399136134556, 69.26134586334229, 72.93467780521938, 74.45490891592843, 73.48947061811174, 67.03286402566093, 55.46163633891514, 51.739562783922466, 43.87781156812395, 37.39958912985665, 36.15570177350725, 32.90847853251866, 20.94899766785758, 25.471281358173915, 23.620107548577444, 13.865733913012914, 12.51136759349278, 22.092716319220408, 22.839859587805613, 6.105365599904742, 0.44061330971973284, 0.09279481388096299, 0.33297569836888996, 0.03197459211306913, 0.15808522435171263, 0.06776086826409612, 0.06222692664180483, 0.12788095724369797, 0.41663920187524384, 1.2664178673710142, 0.6424351100410733, 0.1995355308588062, 1.1589447600500924, 1.250480871115412, 0.38399881763117655, 13.894187654767718, 17.853825330734253, 4.791202425956726, 6.775340872151511, 3.5937236079147885, 8.238253252846853, 4.9815748163631985, 8.223015853336879, 3.4564504367964606, 3.0786060946328297, 0.6957202479243279, 0.0942079716229013, 0.11435073826994215, 0.04301333227860076, 0.33407739496656824, 1.032478534749576, 20.9578184059688, 14.970027617045812, 15.672410590308052, 22.505967378616333, 24.41400350843157, 28.22166497366769, 22.189374446868896, 30.863682746887207, 27.7263765335083, 26.345147609710693, 43.168105193546836, 53.76618208203997, 64.9087302344186, 66.30823639460972, 65.37224456242153, 60.69978250776018, 61.09596879141671, 62.53248105730329, 66.6995380946568, 64.47906058175224, 72.06372111184257, 70.13102408817836, 66.51329163142613, 65.13982037135533, 69.91697093418666, 62.91609804970877, 62.667019026620046, 60.27865219116211, 54.629040649959016, 49.05506719861712, 45.01484257834298, 33.23377234595162, 39.46061590739659, 12.498201625687734, 0.10798388812690973, 0.12874266957598074, 0.09096015697079045, 0.5128509349056652, 5.2171131031853815, 47.95652573449271, 26.69791807447161, 64.3892342703683, 65.91240446908134, 49.62317623410906, 63.60516480037144, 1.9010935766356332, 0.12546751674796852, 0.0821605823667986, 0.07259496886815343, 0.031780045945197344, 0.07889657786914281, 0.09666755249989883, 0.11904706912381308, 0.07714806776493788, 0.09762525718126978, 0.09602643190217869, 0.12169965250151497, 0.029658728345696415, 0.05817460694483348, 0.008704750183304506, 0.09095740211861474, 0.06634019235415117, 0.00719654919313533, 0.2043666730501822, 0.04693031477342759, 0.04281727297763739, 0.08307780564895698, 0.036950224943991215, 0.03381192923656531, 0.02636594887423728, 0.039304385227816444, 0.062189471508775435, 0.029430163824664693, 0.05092327622696757, 0.02689791693618255, 0.03136495554021426, 0.0336139836082501, 0.07360114809125662, 0.01808683607461197, 0.03271295017163668, 0.10119104691381965, 0.07622754001723868, 0.039229705663664, 0.14097299187311105, 0.026791992530758892, 0.06687664892524481, 0.07164754399231502, 0.041270833994661055, 0.01844182693665581, 0.16097815840372018, 0.017591797281056643, 0.0466708599456719, 0.054203803052327464, 0.11739457851009709, 0.047823636659554074, 0.3586706524448735, 0.21797253510781697, 36.46008498328072, 113.46056720188686, 85.70614773886544, 92.13096632276262, 93.21164744240897, 56.05264663696289, 47.9545316014971, 0.7405194097331592, 0.5437240068401609, 0.22475738317838737, 0.549992747604847, 0.7493099666067532, 0.7929086099777902, 37.25917298453194, 84.23590891701835, 70.82223783220563, 71.27979755401611, 63.24148913792202, 75.41670635768345, 77.06276239667619, 69.97321660178048, 74.21459851946149, 79.57487664903913, 75.20527962275914, 75.25148514338902, 76.26000922066825, 75.22258063725063, 74.36069134303501, 71.93045466286796, 70.28879683358329, 72.35507297515869, 74.06004279000419, 73.35061781747001, 71.61389473506382, 60.81840215410505, 54.71856124060494, 46.29769195829119, 42.034430163247244, 38.471029145377024, 36.28504943847656, 22.02328470775059, 24.63554334640503, 27.31402005468096, 24.03148433140346, 19.154380457741873, 24.16171441759382, 30.553574221474783, 8.08024079459054, 0.6601944885083607, 0.0886067600388612, 0.08970840913908822, 0.3335354897592749, 0.5754939935037068, 0.3690771811774799, 0.23492136278322764, 0.26056157265390667, 0.9244049510785511, 0.8597663481320653, 0.67535236371415, 0.6991331705025264, 0.8195611940962928, 1.7204349849905287, 0.8285907581448555, 11.489343166351318, 18.529414313180105, 6.537949587617602, 10.042214053017751, 4.557954004832676, 10.054799846240453, 4.2225401401519775, 9.041831527437482, 6.000773932252612, 4.887866199016571, 0.6368677573544639, 0.24165476432868413, 0.19669959374836513, 0.05111906750659857, 0.3893526760595185, 2.650181472301483, 31.135242666516984, 15.111270598002843, 5.8736470852579385, 24.108748299734934, 20.975522415978567, 25.24420554297311, 20.877438170569285, 35.187505040849956, 31.089693750653947, 36.29907785143171, 47.58655500411987, 55.08742025920323, 64.75045027051652, 65.49012075151715, 65.55735152108329, 61.877432686941965, 61.56203310830252, 64.9689850125994, 66.80897917066301, 65.76815291813442, 70.0109453201294, 67.96597930363247, 67.05951036725725, 66.78203405652727, 70.23763724735805, 64.26221425192696, 65.17927919115338, 63.50416578565325, 59.138758523123606, 56.560438360486714, 47.98014266150338, 34.841717515672954, 44.21390288216727, 14.384888546807424, 0.1330279167741537, 0.3007868927504335, 0.02319987733582301, 0.06841836191181626, 3.4234512703759328, 54.70710366112845, 46.18269232341221, 53.36068868637085, 85.93848160334996, 50.514557157244, 80.23132855551583, 7.766998631613595, 0.29672672918864657, 0.11695814478610243, 0.016627213950934153, 0.11316336984080927, 0.23206079485160963, 0.05507592750447137, 0.026251446089840362, 0.02687645996255534, 0.026245719254282967, 0.09063388340707336, 0.06157162466219493, 0.02900209983012506, 0.07221520638891629, 0.06660697196743318, 0.032370890490710735, 0.038945277354546955, 0.08133595875863518, 0.08515020087361336, 0.0440304766276053, 0.03012927881042872, 0.04670360604567187, 0.015173985323469554, 0.077368496651096, 0.17838217451104096, 0.09944156650453806, 0.18253157899848052, 0.12349219274308, 0.1631477741258485, 0.14600187273962156, 0.1743837169238499, 0.08277711964079312, 0.24262593793017523, 0.33798632664339884, 0.14245825074613094, 0.21159070969692298, 0.19227557256817818, 0.21761306082563742, 0.19480839451508863, 0.17095851286181382, 0.15451125827218803, 0.17305179339434418, 0.1508216019719839, 0.0717531783240182, 0.4366769380867481, 0.19418364018201828, 0.3458737534071718, 0.37171657383441925, 0.2886283051754747, 0.27825852589947836, 0.5574748718312809, 0.9163069341863904, 37.01513140542166, 133.29749352591378, 96.26814610617501, 107.14070115770612, 113.6535951069423, 67.04751777648926, 63.45786299024309, 4.694376238754817, 1.2033511315073286, 0.26302487190280643, 1.960899761744908, 1.155459804194314, 1.0598611682653427, 43.60068266732352, 92.78141498565674, 76.96889223371232, 73.8714964730399, 71.37058966500419, 84.31179714202881, 79.73534529549735, 73.65669986179897, 77.66194030216762, 82.01474353245327, 77.6798597063337, 78.47399016789028, 77.38670825958252, 73.48022256578717, 75.18260765075684, 72.3150999886649, 68.30013901846749, 72.38134411403111, 72.67801134926933, 75.4014481135777, 69.89606380462646, 59.647985049656455, 54.194413457598, 51.455277238573345, 47.09172167096819, 48.184906073978965, 43.506388664245605, 29.407406330108643, 33.38749081747872, 34.29691621235439, 21.309421573366436, 22.632299525397165, 29.52868366241455, 35.3837708064488, 14.171794244221278, 0.8397703553949083, 0.9202298436846051, 0.39717838327799526, 0.24305241076009615, 0.35842521275792805, 0.25466458765523775, 0.43274832889437675, 0.24249058376465524, 1.1149368243558067, 2.359083435365132, 0.8490343668631145, 0.8776026996118682, 1.866312631538936, 6.760888619082315, 1.0104766296488898, 16.94528409412929, 24.026578903198242, 11.56828078201839, 14.520241192408971, 4.65462863445282, 10.108301843915667, 3.518705427646637, 14.924633298601423, 10.989684309278216, 8.90688795702798, 1.3785219490528107, 0.3982743801815169, 0.30039744079113007, 0.21610216689961298, 1.3689106362206596, 6.025753140449524, 38.854451588221956, 20.6215603351593, 24.368977444512502, 31.120321410042898, 27.523228577205114, 31.75991698673793, 26.288321767534526, 39.09374407359532, 35.97486795697893, 37.67736073902675, 51.48681858607701, 55.555023602076936, 65.65616880144391, 66.01713466644287, 67.68215928758893, 65.01819215502057, 62.91614668709891, 65.64888014112199, 67.44592748369489, 65.03898116520473, 72.51516641889299, 71.21027387891496, 68.83011286599296, 66.75212206159318, 71.85776260920933, 65.04917417253766, 67.3226455960955, 69.16229234422956, 62.56356034960066, 62.98154313223702, 59.601946285792756, 46.17956215994698, 50.506604943956646, 16.976853234427317, 0.14642158736075672, 0.3779451996088028, 0.14121844513075693, 0.8775491767695972, 13.195019960403442, 65.26798684256417, 41.19642877578735, 77.030168397086, 88.97328799111503, 65.11204842158726, 85.30484063284737, 4.62555867433548, 0.330767528287002, 0.231849661895207, 0.1789420744670289, 0.1447375855807747, 0.3534579293004104, 0.20811613542693003, 0.19633569541786397, 0.3423504467521395, 0.17076487253819192, 0.23749689172421182, 0.2500435199056353, 0.15884863053049358, 0.19386295096150466, 0.16284526964383467, 0.19603365233966283, 0.15430060029029846, 0.22422250759388718, 0.28741717444998877, 0.13138124799089773, 0.08943554306668894, 0.1254270217780556, 0.12202727634991918, 0.14372179151645728], [0.023595468340707675, 0.00580459991137364, 0.07111458187656743, 0.04194921634293028, 0.06943903464291777, 0.11848840410155909, 0.05087608411642058, 0.036525241498436244, 0.022887193132191896, 0.06366349384188652, 0.06445727803345237, 0.01922321429343096, 0.0162400249059179, 0.00032539427775191143, 0.09792047419718333, 0.021552238247490356, 0.02057597054434674, 0.08436095608132226, 0.06697826632963759, 0.15285659634641238, 0.022609780875167677, 0.14286937511393002, 0.11701808656964983, 0.07669121013688189, 0.11679625990135328, 0.08991032758993761, 0.09462514852306672, 0.09190926461347512, 1.6360485702753067, 81.84679167611259, 86.07336698259626, 77.19737679617745, 105.32032176426479, 65.80686828068325, 44.73362813677107, 27.69672335897173, 0.4009241408535412, 0.15867434202560357, 0.20901699922978878, 0.44488349344049183, 0.10535251575389079, 12.63689809186118, 48.05257763181414, 67.67376586369106, 59.5090697152274, 64.95885453905377, 67.56233065468925, 69.32472733088902, 67.34349019186837, 71.05398109980992, 74.98133223397392, 77.0680569240025, 80.64092486245292, 71.10876069750104, 73.56187779562813, 76.10957377297538, 72.44654600960868, 69.33147403172084, 73.7832612991333, 69.16345964159284, 68.99638325827462, 65.88979503086635, 58.3788548878261, 47.470388071877615, 42.031060286930625, 34.728896141052246, 30.712364877973283, 30.9788977759225, 22.736790009907313, 24.974167278834752, 22.93644823346819, 18.757985728127615, 18.263084650039673, 21.854874270302908, 23.87608960696629, 5.313144590173449, 0.10883742411221776, 0.16651926535580838, 0.27408615978700773, 0.6244461696062769, 0.47171081389699665, 1.1273437014647891, 0.3130231590143272, 0.12815432543201105, 0.9791780348334993, 1.8543495706149509, 2.628351100853511, 1.1065352580377033, 0.3917963792170797, 0.8619918344276292, 1.2367619786943709, 2.04913906114442, 4.32178212915148, 5.16927866424833, 0.9580687561205455, 1.592171998960631, 5.86188725914274, 3.7308178629193987, 2.6174285326685225, 2.2537298543112616, 0.4443957081862858, 0.871902191213199, 0.246097703065191, 0.26312610932758873, 0.07826774554061038, 0.3954403836812292, 4.09765191589083, 23.84056520462036, 26.233186074665614, 35.98292439324515, 14.587423324584961, 25.483869756971085, 21.71449634007045, 25.45304581097194, 27.599356515066965, 32.53012480054583, 18.619271891457693, 40.028575556618826, 51.25388370241438, 62.67769145965576, 70.19488498142788, 64.15661552974156, 65.7264984675816, 63.05638912745884, 67.35808835710797, 72.86466080801827, 70.76832675933838, 68.9801105771746, 72.1677495411464, 70.58541543143136, 64.29736518859863, 68.56565053122384, 66.3003432410104, 61.9056145804269, 56.130925042288645, 49.69142838886806, 45.887168066842214, 43.78429576328823, 36.52214976719448, 26.269754443849834, 1.5972411440951484, 0.24853247670190676, 0.15826598608068057, 0.4697039787258421, 4.835469399179731, 40.54972519193377, 23.762055771691458, 46.341576780591694, 87.7799070903233, 52.80945335115705, 68.05824443272182, 25.418052945818218, 0.4797667073351996, 0.1994661981506007, 0.09331136901995965, 0.018379722322736467, 0.09520729764231614, 0.08034734002181462, 0.06523036012159926, 0.03731232176401785, 0.05543023474248392, 0.03637494259913053, 0.1380868838833911, 0.007582408309515033, 0.0358864313124546, 0.0622242803552321, 0.028196543055985655, 0.07542664477867739, 0.039962336886674166, 0.013959749452104526, 0.02291688582460795, 0.06053751015237399, 0.062289426502372534, 0.047625989586647065, 0.049421247360961776, 0.03157481624345694, 0.09361353423446417, 0.027116252541808144, 0.03293913982010313, 0.09721275538738285, 0.020072546754298464, 0.01438744449322777, 0.04439476511574217, 0.015202648338994809, 0.03958089842594095, 0.035641290180917294, 0.042792662512511015, 0.03369521103533251, 0.031599630269088914, 0.04422088712453842, 0.05023135371240122, 0.030828400581542934, 0.02500996958198292, 0.0621679008805326, 0.06751977120126997, 0.060639704311532636, 0.03681284195876547, 0.08752966033560888, 0.11773122687424932, 0.052978867531887124, 0.2480665131339005, 0.03594942989626101, 0.10367535360689674, 0.02698974816926888, 6.822552144527435, 102.04492010389055, 91.07070595877511, 86.747773034232, 110.90454033442906, 64.03925350734166, 58.90963472638811, 19.091686861855642, 0.983635195663997, 0.08166481075542313, 0.7025089093617031, 0.3129189631768635, 0.8043772088629859, 14.846697092056274, 63.9918737411499, 72.7267599105835, 65.41009140014648, 74.2839276450021, 75.91620540618896, 72.98993682861328, 72.87087944575718, 74.32725661141532, 76.57552691868374, 76.33637687138149, 78.64797306060791, 73.6377660206386, 73.47911780221122, 71.95045157841274, 75.27887494223458, 71.24070004054478, 73.81973934173584, 73.8033138002668, 71.86523887089321, 68.37393583570207, 62.1302706854684, 51.778698512486045, 45.30479785374233, 41.09264005933489, 36.352384431021555, 34.599510260990684, 24.9550302028656, 25.629543951579503, 22.66508460044861, 22.919904572623118, 20.38646456173488, 26.393976075308665, 32.59818935394287, 6.759754325662341, 0.14271005509155138, 0.11881293383027826, 0.13075684649603708, 1.1697388951267516, 1.7712817937135696, 1.1789707711764743, 0.11919725606484072, 0.11748381943574973, 1.4035957178899219, 4.295725950172969, 5.875271660940988, 3.5316264714513506, 0.39635529315897394, 2.712853355067117, 2.8775847213608876, 2.447631278208324, 4.450586097581046, 7.799601316452026, 1.1654852948018481, 2.553319892713002, 3.630268309797559, 1.4362874265227998, 2.6866519153118134, 2.357139676809311, 1.4898430556058884, 1.022130821432386, 0.4977813778179032, 0.06860820243933372, 0.12694936937519483, 0.05483497632667422, 6.023753796304975, 32.91331795283726, 28.486439977373394, 40.35227475847517, 16.411309821265085, 23.225944927760533, 23.70155085836138, 22.78220690999712, 31.864848681858607, 37.19234868458339, 26.256188086100988, 46.479859828948975, 53.4480414390564, 63.25448226928711, 68.89805930001395, 65.68633787972587, 66.58335726601737, 64.68512330736432, 67.02202483585903, 71.80710329328264, 69.3147497177124, 68.95280415671212, 70.82612187521798, 70.07910020010812, 65.10691370282854, 69.13732051849365, 66.45520469120571, 63.75871998923165, 59.81378296443394, 55.955048765454976, 51.3431784766061, 44.88557481765747, 32.467677865709575, 28.69499363218035, 2.209709542138236, 0.015990916040859053, 0.1157193976853575, 0.5795654750296048, 5.100719051701682, 42.66712270464216, 48.53039830071585, 38.63860232489449, 88.9789160319737, 69.92548247746059, 67.6758086340768, 46.20215770176479, 0.3326653635927609, 0.0652819491390671, 0.021586360077240636, 0.04445691553077527, 0.07769508912627186, 0.029496758644069945, 0.031804703907775025, 0.0575222090951034, 0.06908812347267355, 0.0391691090938236, 0.06946571463985102, 0.027874842818294252, 0.04654124279373458, 0.037839153315871954, 0.004782836859314037, 0.0570702301338315, 0.06321762848113265, 0.06422620971820184, 0.03801884974486061, 0.1287144153778042, 0.021000168585617627, 0.018538882889385735, 0.015361615523163761, 0.062017571447151046, 0.1990880641554083, 0.08413608957614217, 0.18358205977295125, 0.11426740059895174, 0.20024804691118853, 0.18651638446109636, 0.13686633509184631, 0.11942327607955251, 0.10217482091060706, 0.16579100729099341, 0.09914421888866595, 0.12814713296081337, 0.1471677723207644, 0.08500629038150821, 0.18207906399454388, 0.15216155935611042, 0.08188086987606116, 0.13575336124215806, 0.20528331957757473, 0.22032730946583406, 0.4047630477164473, 0.28491997559155735, 0.2369275465607643, 0.1590213176927396, 0.4030096318040575, 0.10245291848800012, 0.28650649903076036, 0.20574662328830787, 4.630768086229052, 112.79266466413225, 109.2047677721296, 98.88849244798932, 129.07398932320731, 87.72830281938825, 68.18608433859688, 44.81249713897705, 0.7636816639985357, 0.5017159581184387, 1.3855097740888596, 1.1299899880375182, 0.8370181087936673, 16.141740560531616, 71.46384143829346, 82.70463711874825, 73.00436823708671, 74.81930024283272, 83.2454501560756, 77.60958562578473, 76.39435264042446, 75.58817400251115, 82.14143698556083, 77.95423017229352, 83.19006606510708, 73.1283449445452, 74.0138303211757, 74.32713849203927, 77.59750965663365, 69.85236658368791, 75.49227496555874, 71.32147284916469, 75.17092772892543, 69.90746579851422, 64.6976717540196, 50.24749272210257, 52.06823342187064, 43.706430775778635, 42.12621586663382, 39.68103013719831, 31.57690838405064, 32.006341797964915, 31.15904024669102, 24.82447702544076, 27.580445255552018, 32.56507771355765, 37.798123904636924, 12.349742940493993, 0.1857385119157178, 0.3277278542518616, 0.5224566566092628, 1.5299531604562486, 1.9945275230067117, 3.088410654238292, 0.6311340278812817, 0.43295463068144663, 2.8285297879150937, 5.060928021158491, 5.248807745320456, 3.784380223069872, 0.3159938667501722, 5.594661712646484, 4.761242227894919, 3.6599605679512024, 4.389088026114872, 10.440901688167028, 4.528069368430546, 3.004100344010762, 7.37789603642055, 5.992637591702597, 6.493149774415152, 3.009501482759203, 0.9797108748129436, 1.1365131522927965, 0.6972601424370493, 0.2269881891884974, 0.41369587981275147, 1.183596100125994, 8.105190907205854, 43.28293807165963, 32.49683598109654, 47.94750002452305, 20.567626680646622, 32.50744588034493, 27.827966145106725, 29.2361957686288, 31.88213232585362, 40.44689532688686, 26.545585768563406, 46.9110963003976, 55.76929562432425, 64.41540118626186, 71.64460577283586, 69.14433819907052, 70.64968626839774, 65.90931946890694, 69.4267338344029, 75.52021367209298, 71.2802700315203, 68.2599367414202, 74.31791128431047, 74.02460697719029, 65.3335986818586, 70.7626292364938, 69.56176512581962, 67.48777648380825, 61.514125279017854, 60.55722631726946, 58.50008705684117, 56.05293498720442, 43.757065773010254, 34.79155499594552, 2.4942196011543274, 0.19093781363751205, 0.22762785772127764, 1.4369853947843825, 10.933674880436488, 57.890966279166086, 36.23515095029558, 59.161062240600586, 106.4242307118007, 75.67804200308663, 84.82839570726667, 42.51348066329956, 0.49647989336933407, 0.23682264504688127, 0.20723946818283626, 0.19027363641985826, 0.175319158871259, 0.24367978423833847, 0.18304733346615518, 0.08252443319984845, 0.1902789425637041, 0.1827381250581571, 0.3000764665859086, 0.13346546329557896, 0.14902532978781632, 0.17214753691639217, 0.11571456651602473, 0.16692878838096345, 0.2024782286690814, 0.1933360006660223, 0.09949443795319114, 0.26558045191424234, 0.10525589236723525, 0.3188737322177206, 0.09354908697839294, 0.13568157223718508], [0.04831706053976502, 0.020687821953158294, 0.028034383364553963, 0.03905664530715772, 0.020270499167963862, 0.0646219245557274, 0.005731034840989325, 0.0690541627949902, 0.02366353727744094, 0.04735789361542889, 0.0719267340110881, 0.057197523303329945, 0.03968191193416715, 0.00910754977459354, 0.018644089744027172, 0.12172774385128703, 0.07195707809712205, 0.062726362342281, 0.03844768387664642, 0.12369560397097043, 0.05654020268203957, 0.012526954058557749, 0.04714426365015762, 0.11203888125185456, 0.16554877028933593, 0.195186528510281, 0.02820231738899435, 0.17272087186574936, 0.10121432745030948, 39.678546156202046, 104.26969855172294, 66.23473140171596, 95.86338574545724, 98.74274703434536, 45.37626355034964, 50.592005252838135, 12.07758721283504, 0.851986645587853, 0.048235351352819374, 0.20758970081806183, 0.08174474218061992, 1.9987016533102309, 26.104706934520177, 41.73543528148106, 66.26050227028983, 61.10661343165806, 61.6084748676845, 71.42971188681466, 65.16438920157296, 66.49562931060791, 74.87923540387834, 79.3015970502581, 74.71926702771867, 72.1082660130092, 71.00336347307477, 79.10226018088204, 75.565856388637, 70.24533585139683, 69.85766805921281, 69.63158757346017, 70.29491124834333, 72.21599783216203, 62.7078674861363, 47.98645857402256, 36.13393306732178, 26.24942054067339, 22.926529679979595, 35.83122089930943, 26.279386384146555, 21.282038722719463, 24.756732089178904, 27.97973390987941, 21.260415928704397, 20.987662655966624, 21.050778354917252, 2.814298574413572, 0.44999842611806734, 0.28873328811355997, 0.06455985895757164, 0.2903881264584405, 0.28291998005339075, 0.13213501897241386, 0.021431084123573134, 0.029521070553788116, 1.0685945110661643, 2.396369857447488, 6.871103984969003, 1.8899095824786594, 1.4540479992117201, 1.4090511394398553, 2.082318446465901, 0.13141478119151934, 3.39719381076949, 7.957153456551688, 0.6937471223728997, 1.5392458332436425, 2.311195582151413, 0.5888637389455522, 0.4571168284331049, 0.747778160231454, 0.4879909317408289, 0.6856030193822724, 0.5636612655861037, 0.31637221787657055, 0.5180601839508329, 0.9341272179569516, 6.865565402167184, 24.55191309111459, 25.2387182031359, 11.71635557923998, 15.596784659794398, 22.496071406773158, 22.560019152505056, 28.49429838997977, 31.522146156855992, 23.509872640882218, 14.156089578356061, 30.56398262296404, 49.63435588564192, 56.73594638279506, 67.75986099243164, 62.096432958330425, 63.321039063589915, 60.973159381321494, 68.31247207096645, 67.49146597726005, 68.88553864615304, 70.70982987540108, 70.21843937465123, 67.04112543378557, 67.85505131312779, 64.83778912680489, 59.83521120888846, 63.45122051239014, 56.81473895481655, 48.52930743353707, 48.575189862932476, 42.07403836931501, 38.53810010637556, 10.79661818913051, 0.8622965780752045, 0.3824100143143109, 0.8663462921977043, 4.932079757962908, 27.910062585558208, 24.085725443703787, 38.28561994007656, 89.24548367091587, 57.673480715070454, 50.15277835300991, 50.66791779654366, 1.7626851350069046, 0.2362102536218507, 0.06396358273923397, 0.14390198327600956, 0.07214066931711775, 0.08145328424870968, 0.12592495791614056, 0.0823288115539721, 0.033763257919677665, 0.12837015385074274, 0.02880599981706057, 0.03820693965202995, 0.09608498947428805, 0.05604401377162763, 0.04097996638821704, 0.08092406086091485, 0.09542818114693676, 0.05850534526897328, 0.06825473997741938, 0.1644685153982469, 0.05019230062940291, 0.04045070907367127, 0.02123997643190835, 0.02068218163081578, 0.026113499920549135, 0.04465706639790109, 0.05322138273290225, 0.03689999978191086, 0.07761819075260844, 0.03687905679856028, 0.061391711102000306, 0.0434805511363915, 0.07160955281662089, 0.02467378940699356, 0.02881140434848411, 0.07404443501893963, 0.04385601170361042, 0.07880196973149266, 0.03215606291113155, 0.11657292688531534, 0.05668515472539833, 0.03457409030358706, 0.08789329403745276, 0.03601141746288963, 0.06503234324710709, 0.07751290925911494, 0.07667615344481808, 0.01473918856520738, 0.03272905180762921, 0.05906896359686341, 0.09503133315593004, 0.04603030253201723, 0.15794358695191996, 0.19301392723407063, 64.00280325753349, 109.2451923915318, 77.86637020111084, 104.18634101322719, 85.89320019313267, 51.71866955075945, 55.21918242318289, 2.5544250905513763, 0.7826006316712925, 0.06846030216131892, 0.8529502195971352, 0.0777637975822602, 3.871839370046343, 30.868980748312815, 66.81081349509103, 80.2899921962193, 67.89958926609584, 74.45396396092006, 76.14358520507812, 69.69523307255336, 70.03813362121582, 77.11104542868478, 78.31774602617536, 75.33463423592704, 74.95999431610107, 72.0503875187465, 79.62297207968575, 77.50971221923828, 70.63024520874023, 71.38424287523542, 70.98608330317906, 71.25852911812919, 72.41911452157157, 65.9978256225586, 55.847626141139436, 47.56855916976929, 33.71686322348458, 29.61361149379185, 38.9165233203343, 25.32029700279236, 23.3730400289808, 27.975964512143815, 29.548162937164307, 26.03358691079276, 24.454652207238333, 28.25054689816066, 4.944147910390582, 0.2555923078741346, 0.21774180606007576, 0.17538952295269283, 0.46080127358436584, 0.6505633081708635, 1.0900335035153796, 0.16400502169770853, 0.1252902155475957, 1.3134785592556, 1.8259160220623016, 4.888434214251382, 5.159970249448504, 3.119911615337644, 3.792010647909982, 1.5942744804280145, 0.35969268903136253, 3.8229214463915144, 10.94984073298318, 1.4039913309471947, 1.5823510459491184, 3.457298985549382, 0.5208754528846059, 1.0080942660570145, 0.47622931429318016, 0.5312209948897362, 0.5469544849225453, 0.5763082898088864, 0.3936191142669746, 0.38043167761393953, 0.7234588680522782, 8.365397470338003, 31.729094777788433, 26.057493925094604, 18.511039802006312, 16.426974534988403, 20.6016172681536, 20.608629737581524, 30.13502516065325, 31.375004155295237, 31.056071417672293, 21.828905378069194, 41.26114777156285, 56.03570692879813, 58.22597367422921, 68.01811858585903, 64.51487159729004, 66.1879630770002, 62.28625079563686, 66.72235597882951, 68.22659928458077, 71.3261489868164, 68.72223513466972, 71.3060200554984, 66.77339049748012, 67.69119194575718, 66.17689459664481, 62.963651520865305, 66.76717185974121, 61.111907958984375, 51.9751101902553, 53.64185449055263, 37.40309797014509, 34.20945576259068, 12.280571017946516, 0.642675094306469, 0.3943661813225065, 2.0762535376208167, 8.602897320474897, 35.387050356183735, 46.39582484109061, 35.48436682564871, 69.8880386352539, 84.48379979814801, 56.61636093684605, 75.59505271911621, 6.960035281521933, 0.24731998890638351, 0.23446631005832128, 0.015914635134062598, 0.0660045685778771, 0.12557684231017316, 0.020412170494507467, 0.052852928039750884, 0.013946277139309262, 0.0390682516486517, 0.03183760607082929, 0.056516382710209916, 0.04817381501197815, 0.038873138904039345, 0.05083645088598132, 0.040009159195635996, 0.026908310396330695, 0.07484967288162027, 0.06326489523053169, 0.0770578904609595, 0.050530699613903246, 0.06655781889068228, 0.012250155875725406, 0.014462481984602553, 0.006918946946305888, 0.18589122300701483, 0.16473553249878542, 0.14147004591567175, 0.16334826765315874, 0.152985205873847, 0.12327183171042375, 0.1694788315466472, 0.1322137697466782, 0.0885857322386333, 0.17535537907055446, 0.17114766128361225, 0.14373070746660233, 0.24561982442225727, 0.11739912469472204, 0.19408720678516797, 0.16934857996446745, 0.22019954132182257, 0.17100427326347145, 0.1581925685916628, 0.12975918288741792, 0.12476756716413157, 0.1554439046553203, 0.14783726925296442, 0.22900266466396196, 0.22148491734904902, 0.31193723157048225, 0.18374041627560342, 0.2992998696863651, 0.330881196473326, 63.780162130083355, 134.18916974748885, 91.10202148982457, 115.09442915235246, 114.45795331682477, 64.92834499904087, 70.60161168234688, 20.17338589259556, 2.4509909493582587, 0.21738191108618463, 1.9864326545170374, 0.14478435021425995, 3.83367725781032, 35.68946722575596, 64.7635406766619, 77.52615165710449, 80.87999847957066, 74.86045442308698, 83.6816372190203, 71.51292351314, 71.96413258143834, 76.79795265197754, 81.5714693069458, 76.79660470145089, 77.45922660827637, 70.77428136553083, 79.57423741476876, 76.99107783181327, 71.0609918321882, 70.05765111105782, 69.86302512032645, 69.372239112854, 76.52365861620221, 68.07295376913888, 56.20491988318307, 46.28459807804653, 39.03031396865845, 32.49489743368966, 44.7294487953186, 33.25232056209019, 28.03564258984157, 34.88716568265642, 35.280065468379426, 31.67186941419329, 30.750423635755265, 35.57626370021275, 15.309499229703631, 1.2313512861728668, 0.7520610732691628, 0.2822325426552977, 1.0006866178342273, 1.0765615978411265, 1.0960869044065475, 0.46848826110363007, 0.2502146192959377, 1.707913788301604, 3.7825068150247847, 11.909926312310354, 14.50489522729601, 7.293023790631976, 5.945119730063847, 4.03964444569179, 1.6067038306168147, 7.23692490373339, 20.541173151561193, 4.300427275044577, 1.884208802665983, 9.445661698068891, 1.9558809910501753, 1.043373744402613, 0.9732088808502469, 0.7753330330763544, 1.0197614857128687, 1.1470788653407777, 1.7752476951905658, 1.2289908528327942, 2.089193037578038, 13.390451942171369, 41.0943979535784, 30.35963957650321, 14.854783058166504, 19.149869339806692, 28.340845687048777, 23.108897311346873, 33.59394611631121, 38.40454878125872, 33.47441973005022, 21.34269302231925, 39.73649065835135, 58.604428155081614, 61.24097769601004, 69.49313776833671, 68.59951605115617, 70.28207792554582, 66.2292423248291, 73.43917955671037, 70.65284769875663, 72.86022785731724, 71.01408454350063, 73.67017936706543, 67.73796027047294, 72.93246132986886, 68.10504055023193, 66.55024909973145, 69.63047586168561, 68.77367264883858, 57.17213691983904, 62.2124331338065, 52.96887281962803, 46.51369060788836, 13.78335085936955, 0.7703346184321812, 0.5127456805535725, 3.245682260819844, 13.933169654437474, 45.948284421648296, 35.748262882232666, 53.88395752225603, 100.70139557974679, 85.6857339314052, 64.42626816885812, 79.5172621863229, 3.6532386200768605, 0.27172816917300224, 0.2692265191248485, 0.16166123960699352, 0.1761927862784692, 0.18305893641497406, 0.2377381787768432, 0.16416617376463755, 0.12994762563279696, 0.1950991331998791, 0.09735363282795463, 0.2160413023084402, 0.09660666076732533, 0.12402257642575673, 0.12146226023989064, 0.12368938859019961, 0.31171288075191633, 0.18081291764974594, 0.20257434993982315, 0.26447080288614544, 0.11050190443971328, 0.13544822404427187, 0.2020411706928696, 0.11688023539526121, 0.1165996068822486], [0.026502875544662987, 0.011038243986799248, 0.0390796476442899, 0.005299197343577231, 0.03211844153702259, 0.04516609658354095, 0.06745511359934296, 0.047004546504467726, 0.051214500064296384, 0.09031819498964719, 0.07400721058781658, 0.014109032245219817, 0.025042361147435646, 0.04252455636326756, 0.058649852871894836, 0.04442067836810436, 0.034400439621614556, 0.079681351115661, 0.03460190345400146, 0.014118704761910652, 0.08064791067902531, 0.05918666228119816, 0.08105589342968804, 0.09257005594138588, 0.03867597359099558, 0.3114316144159862, 0.13264240031795843, 0.04888984587575708, 0.06209218994315181, 6.819213100842067, 112.79586083548409, 90.185060773577, 84.73316369737897, 106.57684094565255, 82.55546624319894, 38.035863467625205, 52.60502692631313, 6.414417999131339, 0.5242931523493358, 0.08880218490958214, 0.2725612201860973, 0.2600281627050468, 8.588125450270516, 33.70619426454817, 42.39128269468035, 70.6769162586757, 64.19343403407505, 61.63708060128348, 68.23553466796875, 71.97802897862026, 69.22973155975342, 72.88274696895054, 76.74766159057617, 78.00363186427525, 67.41416726793561, 73.59617410387311, 72.23119354248047, 78.81872504098075, 71.77432169233049, 70.98930726732526, 65.69318185533795, 67.52934755597795, 62.53536455971854, 48.1190128326416, 27.54820040294102, 18.963030542646134, 28.104818855013164, 35.80255263192313, 34.962081159864155, 21.045013087136404, 27.301019975117274, 27.416837760380336, 18.673839569091797, 17.314747606004985, 15.319021735872541, 1.6464128941297531, 0.4155671979699816, 0.041159791738859246, 0.03595769784546324, 0.17667863092252187, 0.03299213679773467, 0.1193685590156487, 0.4595208508627755, 0.13415315853697912, 0.2044195444988353, 0.31353659289223806, 0.2845939802271979, 3.4686953340257918, 1.5738933512142725, 0.7850360295602253, 0.9683224516255515, 0.18413801065513066, 0.7920175577913011, 6.6237112028258185, 0.999634291444506, 0.3738598759685244, 0.06606407609901258, 0.31825156988842146, 0.4620882102421352, 0.24828220584562846, 0.42089388785617693, 0.21017695484416826, 0.4004103812788214, 0.539121042404856, 0.33623035943933893, 0.3137031596686159, 10.305856500353132, 23.401194129671367, 11.023759143693106, 3.1375645995140076, 13.078386630330767, 17.072404861450195, 19.75380676133292, 19.95847463607788, 35.87010996682303, 22.241815975734166, 14.300795367785863, 28.702520268304006, 41.62584481920515, 53.779967308044434, 60.85296944209507, 62.495669501168386, 62.11072540283203, 61.33117921011788, 67.69557625906808, 67.63533537728446, 71.45109149387905, 69.10051591055733, 66.19753074645996, 66.60212435041154, 64.7410979952131, 58.52744211469378, 59.80456965310233, 60.0219509942191, 55.32638965334211, 51.85218960898263, 46.841979094914024, 39.89882142203194, 23.302991764886038, 3.777141502925328, 1.2927352551903044, 1.6698073702199119, 8.494597486087255, 23.496440035956248, 27.098257643835886, 35.69943789073399, 79.88878236498151, 69.85077544621059, 40.88566364560808, 65.91498919895717, 14.320902585983276, 0.28279564529657364, 0.1480213693742241, 0.06510994729718991, 0.11138338249708925, 0.03111367705943329, 0.018703188447813903, 0.08671514011387314, 0.0188851240423641, 0.11374558681356055, 0.01769988451685224, 0.06142958014139107, 0.11277983470686845, 0.06893571772213493, 0.05968939566186496, 0.013873045399252857, 0.07723550378744092, 0.0938211048820189, 0.057828791572579315, 0.08540923840233258, 0.08616518069590841, 0.06003376575452941, 0.03057269805244037, 0.02463868200512869, 0.05585307741005506, 0.050385228491255214, 0.055292936574135504, 0.0777394992432424, 0.0383831823377737, 0.010795508261903055, 0.05582384272877659, 0.021001142283369387, 0.04216476995497942, 0.05806807694690568, 0.09721673160259213, 0.01065012619697622, 0.0050712066087206555, 0.06281926735703434, 0.07841955418033258, 0.07321073261222669, 0.03681362566671201, 0.02775868949746447, 0.0101542672242171, 0.07252387196889945, 0.09658598580530711, 0.07306703246597733, 0.024558214537267174, 0.05827515904924699, 0.05608804390898772, 0.06429479603788682, 0.0435434581179704, 0.12940790530826363, 0.04273473937064409, 0.2001678440719843, 0.15898139269224235, 19.09815910884312, 119.4209542955671, 86.66897351401192, 97.34672886984688, 103.17794895172119, 63.60533850533621, 55.821952547345845, 43.22866569246565, 2.5902159128870283, 0.9966362523181098, 0.07764664851129055, 0.6266319751739502, 0.3804599589535168, 12.080038189888, 34.88864912305559, 61.69158921922956, 91.38272176470075, 74.77879224504743, 66.72009086608887, 74.20326600755963, 74.83273111070905, 77.24117824009487, 75.15116705213273, 78.16325977870396, 79.59720815931047, 74.52872657775879, 74.8552919115339, 77.66355923243931, 79.25755241939, 73.34742164611816, 71.11105360303605, 67.63894844055176, 67.0004437310355, 65.56058938162667, 52.23672028950283, 39.55744252886091, 26.58861075128828, 33.05826779774257, 38.75622837884085, 34.52003329140799, 24.097370624542236, 26.14287165233067, 28.905590057373047, 23.834006105150493, 24.147936139787944, 22.336292369025095, 0.5032552555203438, 0.488872158740248, 0.06533557376159088, 0.104745355833854, 0.14072705007025174, 0.026088767319119403, 0.32764026895165443, 0.9223809625421251, 0.09444273116865329, 0.17740945384970733, 0.3231717087328434, 0.07654073142579623, 1.080739853637559, 0.5310836594019617, 0.11154520631368671, 2.00875461101532, 0.33644507506064003, 0.9229462636368615, 8.89014366694859, 2.3537952048437933, 0.7552039931927408, 0.10993507664118495, 0.7205011610473905, 0.3433953635394573, 0.7864964540515627, 0.22742123023739882, 0.2846992617206914, 0.1470429218773331, 0.337935029395989, 0.44185508308666094, 0.503698040332113, 12.92593446799687, 30.352465561458043, 10.300803422927856, 7.368392637797764, 15.741319349833898, 25.131203515189036, 22.0797336101532, 18.76589104107448, 37.045661790030344, 35.30774014336722, 19.735496520996094, 35.56340953281948, 43.84327554702759, 56.637556416647776, 61.91473756517683, 63.135744503566194, 65.11174270084926, 62.75149522508894, 70.07910020010812, 71.50455788203648, 69.2047666822161, 70.34839153289795, 70.40778473445347, 68.83940260750907, 66.69095012119838, 65.04180908203125, 63.83049488067627, 63.82504054478237, 58.608201026916504, 55.72674833025251, 41.846849645887104, 38.295882429395405, 24.37094031061445, 4.173990036760058, 1.8041327680860246, 4.869325799601419, 15.682221446718488, 33.09092433112008, 44.719863755362375, 37.15119450432913, 55.975146429879324, 89.79766396113804, 53.12548174176897, 70.24384893689836, 33.54216119221279, 0.5187634176441601, 0.12269264778920583, 0.059820868607078276, 0.02181879903322884, 0.053162930333720784, 0.02698228937307639, 0.04207106087622898, 0.04285614964153085, 0.1867415223802839, 0.01986910159965711, 0.038098665819104226, 0.09729618805327586, 0.08562738062547785, 0.10041783590401922, 0.04490936607388513, 0.024588891105460267, 0.01805948093533516, 0.033610227916921885, 0.017476736401606883, 0.014393980481794902, 0.05661959806457162, 0.031309587082692554, 0.006632938498764166, 0.09316074103116989, 0.04482245591602155, 0.23076704570225307, 0.12593652015285833, 0.120386022276112, 0.11518606916069984, 0.13552860330258096, 0.09951528933431421, 0.23019433500511305, 0.16583010447876795, 0.20255045193646634, 0.22188101895153522, 0.14641119220427104, 0.14263601335031645, 0.19332067934530123, 0.2361718485397952, 0.16290241586310522, 0.18543102698666708, 0.11141142634940998, 0.1513145440923316, 0.16331865638494492, 0.12827418185770512, 0.21175081681992325, 0.11541959377271788, 0.10009381507656404, 0.3333961186664445, 0.13287924975156784, 0.34669513361794607, 0.1887979313199009, 0.30800954518573626, 0.2882791853376797, 13.290945053100586, 145.68272699628557, 109.50037888118199, 112.45980426243374, 117.75751386369977, 100.18167727334159, 56.20806394304548, 70.40925775255475, 8.398471764155797, 2.3713170417717526, 0.09912752014185701, 0.9437886880976813, 0.39297917432018686, 13.57823395729065, 50.00696693147932, 60.21189389910017, 86.94347599574498, 84.35750239236015, 73.102511542184, 79.87251663208008, 79.25121566227504, 78.4438419342041, 76.6721624646868, 79.75660678318569, 82.1691950389317, 72.67454419817243, 76.05541951315743, 77.23675918579102, 80.82509381430489, 72.20358140127999, 72.92902197156633, 70.04101712363106, 71.80456720079694, 70.21326991489956, 52.793906756809776, 36.92346034731184, 29.944394384111675, 39.543038913181846, 45.29199232373919, 45.07764039720808, 26.185042006628855, 33.41716309956142, 33.291855812072754, 26.40417776788984, 25.248787879943848, 31.931738989693777, 4.981798027242933, 1.2305807960884911, 0.286147906844105, 0.20347856570567402, 0.1673116178384849, 0.09653738234192133, 0.30063487376485554, 1.660127661057881, 0.24652800283261708, 0.8996051475405693, 0.7094469027859824, 0.21691165917686053, 9.152474641799927, 3.60043426496642, 5.014966121741703, 2.5746851691177914, 0.605922380728381, 3.2438933168138777, 19.490315437316895, 2.8625099531241824, 4.433459222316742, 0.2505359191979681, 1.5412650448935372, 1.559662789106369, 1.1226385767970766, 0.7651271607194627, 0.7420343884399959, 0.9448743441275188, 2.202446937561035, 2.671048649719783, 1.5005767196416855, 19.46165759222848, 37.5019326210022, 15.927697828837804, 8.32642502444131, 18.80265917096819, 28.494796923228673, 25.291201421192714, 23.37568208149501, 46.54130274908883, 34.70122841426304, 19.986838919775828, 39.001663071768625, 50.21117101396833, 63.361547061375205, 68.21084077017647, 70.13903536115373, 68.13078362601144, 66.84652723584855, 75.45512294769287, 71.81102207728794, 75.00389303479875, 71.80253137860979, 71.18431540897915, 70.27716554914201, 71.02199854169572, 65.54352460588727, 69.11387729644775, 68.66062545776367, 65.23850563594273, 62.297367913382395, 57.414208684648784, 45.77609069006783, 30.128587654658727, 5.043219234262194, 1.7682483622006007, 6.595933173383985, 21.514761686325073, 44.11651693071638, 38.61711502075195, 51.322372095925466, 92.29701437268938, 90.72504002707345, 58.369502612522666, 85.74938637869698, 28.49517560005188, 0.592723626111235, 0.39992045185395647, 0.14283732111964906, 0.1514138409069606, 0.2607054220778601, 0.1429643700165408, 0.16508617225502217, 0.07492021338215896, 0.36343024990388323, 0.06942524002598864, 0.18296324940664427, 0.2885417512484959, 0.17039351032248565, 0.1488911969853299, 0.16302134948117392, 0.13878022453614644, 0.2512794035886015, 0.14926247777683394, 0.1887117845139333, 0.16722500962870462, 0.14112544512110098, 0.17237226771456854, 0.1370982855026211, 0.19697714171239308, 0.20198873350662844], [0.0160296722647867, 0.05828255508095026, 0.04783367897783007, 0.05849417658256633, 0.01840639383798199, 0.10722789833588259, 0.05774070415645838, 0.053857661983264346, 0.036450059818370004, 0.07341528377894845, 0.01003933950726475, 0.040817867764937024, 0.06135327209319387, 0.02984716769840036, 0.015642730885052254, 0.08202758950314351, 0.0487245174257883, 0.026770021566855054, 0.06290648624833141, 0.09047335559236151, 0.0924729507948671, 0.022879145706870725, 0.044480308025543175, 0.04425730070631419, 0.13183232450059482, 0.09726754030478851, 0.38235706144145554, 0.10217175393232278, 0.2252621996615614, 0.07676812886659588, 44.20377935682024, 114.85584885733468, 60.33989361354283, 85.8754961831229, 110.498612676348, 61.53948620387486, 42.52047749928066, 53.178228991372244, 7.269113302230835, 0.4629100518567221, 0.4248748799519879, 0.0821777085906693, 2.436087280511856, 24.4639402117048, 63.7421624319894, 48.4330609866551, 61.14902523585728, 62.95792620522635, 65.62933485848563, 67.09656511034284, 67.79484517233712, 75.64134161812919, 72.40669809068952, 74.51632404327393, 66.91150678907121, 71.18557303292411, 74.1720130102975, 73.31438991001674, 69.58741787501744, 70.97716876438686, 65.95872810908726, 69.73353849138532, 57.67887946537563, 43.76203373500279, 21.68672612735203, 21.464692967278616, 16.953945023672922, 30.475045680999756, 31.72684703554426, 22.91182381766183, 33.82170806612287, 29.020217963627406, 24.522841828210012, 14.621622358049665, 5.68953936440604, 2.052925612245287, 0.05352007724078638, 0.27196476076330456, 0.12123850653214113, 0.012527356090556298, 0.1549017144633191, 0.023171640101021955, 0.18583005986043385, 0.21036960450666292, 0.37126097828149796, 0.7316012882760593, 0.4910546530570303, 0.3807829144809927, 0.12487898261419364, 0.2943044677376747, 0.503714379455362, 0.5168704677905355, 0.48841819167137146, 0.7825692562120301, 1.6969906772886003, 0.19974325756941522, 0.17670304461249284, 0.35785847316895214, 0.37140466485704693, 0.0773014302498528, 0.20813053394002573, 0.12903327255376748, 0.2570272465901715, 0.5422124479498182, 0.7452294198530061, 0.38523983103888376, 5.920279051576342, 21.711466925484793, 13.248620101383754, 10.292018294334412, 13.217435717582703, 15.591290371758596, 21.12783908843994, 35.051448890141074, 37.66031680788313, 14.087950331824166, 13.411397286823817, 17.63714575767517, 34.64837694168091, 47.59036609104702, 54.79370600836617, 56.45828594480242, 52.99888556344168, 59.43155561174665, 63.50383922031948, 65.67296954563686, 65.2667361668178, 60.72860363551548, 59.764443806239534, 63.34987408774239, 59.539808545793804, 58.687625885009766, 62.18652330126081, 55.75386020115444, 51.87823840550014, 57.35051454816546, 50.86332893371582, 32.3943326813834, 8.584267463002886, 3.7865002921649387, 3.9624695011547635, 6.8376748987606595, 20.719347545078822, 18.656123399734497, 34.77109602519444, 70.52231189182827, 81.72196728842599, 41.41117327553885, 64.57691901070731, 42.31239979607718, 0.23332512272255762, 0.14111897189702305, 0.026766812096216848, 0.029780335391738584, 0.010429562451983137, 0.08354817290923425, 0.026529587772009627, 0.07124389029507126, 0.054000605562967915, 0.09590768827391521, 0.021083487596895014, 0.07165459397115878, 0.013882877371673073, 0.0749601519533566, 0.18222819242094243, 0.062381042300590446, 0.022094423350478922, 0.13703128695487976, 0.07624504622071981, 0.016412815544754267, 0.006283799577171781, 0.07120000943541527, 0.018066081384729062, 0.06687691355390207, 0.021655190669532334, 0.09117785136082343, 0.05964096183223384, 0.025309703944783126, 0.022791550228638307, 0.05298376655472176, 0.13781176507472992, 0.0865642474964261, 0.03698094900963562, 0.03449062031826802, 0.015182991179504564, 0.009414759048792933, 0.025580824485846927, 0.028970354569277594, 0.023835835978388786, 0.12463010954005377, 0.05621806139658604, 0.1001760670915246, 0.06883531489542552, 0.05713254678994417, 0.05325595409210239, 0.031924604438245296, 0.05107503058388829, 0.039644626434892416, 0.03373388074604528, 0.036257165883268626, 0.07032258223210062, 0.047222770151815245, 0.06695124706519501, 0.04162879175107394, 0.17589824779757432, 0.23269522509404592, 83.80389772142682, 110.4550335747855, 79.17268712180001, 106.77114731924874, 94.75589847564697, 51.29442644119263, 63.03391865321568, 39.1543983731951, 4.459227051053729, 0.814929894038609, 0.15131512763244764, 0.19991237563746317, 2.066828957625798, 28.73917375292097, 62.98920004708426, 66.49642835344586, 80.78705937521798, 74.22893960135323, 71.71567194802421, 73.12984575544084, 73.15850707462856, 80.3154295512608, 75.69456481933594, 76.7357245853969, 72.61595003945487, 77.16468552180699, 75.14563628605434, 74.71172128404889, 72.77473027365548, 70.26108046940395, 64.2135351725987, 68.49726636069161, 59.78339154379708, 52.084078788757324, 30.65691477911813, 27.50280261039734, 25.88204322542463, 32.11166954040527, 33.4945000239781, 24.95166380064828, 32.08463409968785, 28.205305440085276, 31.266990934099468, 23.50280805996486, 14.538727743285042, 1.0724967930998122, 0.4271799176931381, 0.1109538155474833, 0.17170361216579164, 0.029596147060926472, 0.14298478034990175, 0.03255404066294432, 0.4055827451603753, 0.22450684090810163, 0.506814253117357, 0.26924041552203043, 1.1719051046030862, 0.5616980195045471, 0.06970324939382927, 0.03367519085960729, 0.6308823728135654, 0.8577378541231155, 0.3917564813579832, 0.574760687138353, 0.5822602904268673, 0.14540869742631912, 0.07205155731311866, 1.0103912970849445, 0.18236118528459752, 0.24508212613207953, 0.5578005686402321, 0.3576459288597107, 0.26613096094557215, 0.3923443369567394, 1.5613923477275031, 0.5982197597622871, 7.44602746622903, 28.18160339764186, 17.22013919694083, 13.759938035692487, 16.910082783017838, 21.59660104342869, 22.756262336458477, 27.41731892313276, 38.55834715706961, 24.908204555511475, 15.912293672561646, 21.81349948474339, 38.39099631990705, 49.15895666394915, 57.493650913238525, 63.12079892839704, 60.83968448638916, 63.44275065830776, 67.86407702309745, 66.85398960113525, 66.63812296731132, 63.84139660426548, 61.65437466757638, 64.12093652997697, 63.61745616367885, 61.62972245897566, 67.20961230141776, 61.071511132376536, 55.59983600888933, 49.75785664149693, 50.117658683231895, 32.963966846466064, 10.956666469573975, 8.963673847062246, 11.461519973618643, 19.805768864495413, 33.782898902893066, 37.25445168358939, 44.58515208108084, 49.043387276785715, 84.09558309827531, 61.97390842437744, 55.485718795231406, 66.14874744415283, 2.7736902620111192, 0.12256312902484622, 0.07061390445700713, 0.026541777653619647, 0.06455770121621233, 0.0347028389307005, 0.041471266453819614, 0.046957605451877625, 0.04399946418457797, 0.03655856435320207, 0.05833023573671069, 0.03388530940615705, 0.049050648497151475, 0.16512741361345562, 0.08323753279234682, 0.04101204413122364, 0.03700679101582084, 0.09149928696985755, 0.056424485319959264, 0.03656463724161897, 0.041218512159373076, 0.010102094666633223, 0.07115148739623171, 0.014039322101910199, 0.08037851192057133, 0.14801250770688057, 0.17112512035029276, 0.11615504430873053, 0.1682138251406806, 0.12004427132861954, 0.24228623615843908, 0.10391228446470839, 0.1317555686192853, 0.1982610656746796, 0.1675993302570922, 0.13351351714559964, 0.09271229723734514, 0.17186168368373597, 0.21386625830616268, 0.19051018729805946, 0.15284109860658646, 0.18904612585902214, 0.09201779628970794, 0.1345727238804102, 0.14595347962209157, 0.18194199992077692, 0.16966973058879375, 0.10900323771472488, 0.15327545601342404, 0.14018182004136698, 0.18643360318882124, 0.21634706375854357, 0.4104877662445818, 0.09675369930586644, 0.4247436241379806, 0.12015139843736376, 71.97950894492013, 140.3467467171805, 83.56915283203125, 113.23724515097481, 122.60589735848563, 79.24073083060128, 60.90380246298653, 70.01841463361467, 12.912398508616857, 1.343302724616868, 0.5085496199982507, 0.7805989533662796, 2.753231074128832, 40.31417431150164, 88.65913908822196, 68.61026491437639, 76.68628815242222, 77.99140998295375, 80.75565351758684, 79.0126701082502, 76.17600549970354, 82.89484405517578, 77.68280574253627, 81.09202970777238, 72.98843601771763, 76.48572840009416, 76.98688806806291, 76.16785526275635, 71.55582863943917, 72.6112391608102, 68.8991779599871, 73.04146466936383, 65.45672076089042, 55.64487075805664, 31.09971652712141, 31.66726275852748, 27.740014110292705, 41.47794198989868, 38.24062688010079, 25.5246331010546, 38.604031562805176, 32.05491665431431, 32.18238483156477, 23.78772415433611, 22.481808492115565, 3.4203625789710452, 0.5935117581060955, 0.2704218535551003, 0.18827184954924242, 0.08659409625189644, 0.23970449183668407, 0.1342501619032451, 0.5895618700555393, 0.5891241878271103, 1.8304536300046104, 1.9425945154258182, 3.1525095232895444, 0.6597104487674577, 0.48816762225968496, 0.5862930683153016, 2.8362635672092438, 1.854749743427549, 1.686525713120188, 1.0598365238734653, 1.7028763443231583, 0.745931513607502, 0.14804559307438986, 2.8644621797970364, 0.6765040276306016, 0.42802024260163307, 0.6632944707359586, 0.6853838254298482, 0.7088424637913704, 1.86261163013322, 2.552771202155522, 2.367353528738022, 11.983078684125628, 31.878453254699707, 22.799054554530553, 13.231225286211286, 22.665555340903147, 19.235264437539236, 24.601443324770244, 42.881078583853586, 51.30625227519444, 19.660770382199967, 22.5891911642892, 29.934079783303396, 44.55424649374825, 60.75904369354248, 62.84319755009243, 73.90684195927211, 66.919511113848, 70.66008077348981, 71.97716740199498, 68.98930999210903, 72.65718064989362, 67.43273980276925, 62.61576911381313, 67.59860025133405, 69.7359286717006, 67.05687005179269, 69.60395458766392, 67.9312105178833, 64.35352747780937, 63.70600400652204, 60.551243918282644, 42.30043152400425, 15.045144592012678, 9.347595691680908, 13.20868272440774, 28.125778096062795, 40.757406847817556, 34.00341388157436, 52.56628724506923, 83.90086678096226, 97.36450931004116, 64.81041322435651, 79.49214444841657, 66.42993409293038, 1.3404632998364312, 0.2761738220495837, 0.14744209045810358, 0.13814010817025388, 0.17802686643387589, 0.16399282163807324, 0.12356106404747282, 0.1174145545810461, 0.24041016825607844, 0.12974467580871923, 0.2072331170950617, 0.22616732466433728, 0.06851560276533876, 0.32889919568385395, 0.24596688151359558, 0.1698361345167671, 0.11138814581292016, 0.2439753540924617, 0.14058416416602476, 0.13125673681497574, 0.0856718382398997, 0.1707295344344207, 0.14499712522540772, 0.1427754930087498, 0.13805795115019592, 0.24714052996465138], [0.08819030917116574, 0.03635140082665852, 0.03468724958864706, 0.05109242143641625, 0.0008795288595138118, 0.03504434560558625, 0.013292471329415483, 0.05542398204228707, 0.027303996396117976, 0.012141819278310453, 0.06665056784238134, 0.03859714139252901, 0.03198984218761325, 0.03240446101075836, 0.017596874419333677, 0.03902866930833884, 0.07885259522923402, 0.009511766655902778, 0.09314884631229298, 0.034099190429385216, 0.05213718216067978, 0.023747599284563745, 0.07260872955833163, 0.03277606749907136, 0.013877128483727574, 0.22255924184407505, 0.19137119395392282, 0.36677597037383486, 0.16982450442654745, 0.03789412483040776, 2.4869632933820998, 84.58261707850865, 89.61768477303642, 74.21945531027657, 100.88232667105538, 102.41823291778564, 50.21703181947981, 37.219318117414204, 50.54717547552926, 7.979861906596592, 0.8967164882591793, 0.3615175411105156, 0.75393665262631, 8.348427363804408, 35.96612364905221, 67.21287795475551, 57.82340547016689, 57.229431765420095, 68.29795728410993, 66.55058261326381, 68.21815722329276, 64.56942190442766, 72.93083545139858, 71.82614135742188, 67.3081169128418, 58.78883334568569, 65.98486028398786, 73.12149402073452, 65.96366133008684, 59.200437682015554, 55.90433733803885, 56.36154270172119, 55.6580445425851, 43.754553999219624, 22.870485510144913, 16.656421422958374, 12.746845517839704, 27.69546226092747, 35.33909041540963, 24.884669269834244, 32.05728251593453, 23.85099618775504, 25.69224796976362, 10.621320349829537, 2.0528027159827094, 0.4343479073473385, 0.599366158246994, 0.08245757714446102, 0.10412009938486985, 0.027117991287793432, 0.18468332210821764, 0.32767560705542564, 0.07683662697672844, 0.049466817772814205, 0.06906186416745186, 0.2566171128834997, 0.38344933997307507, 0.24990613013505936, 0.39083769065993174, 0.03787364664354494, 0.12705823353358678, 0.08582472575030156, 0.2397595074559961, 0.04915580785434161, 0.1861941481807402, 0.010065356236217278, 0.27912289808903423, 0.19495584017464093, 1.3433385512658527, 0.15719884048615182, 0.11548964572804314, 0.035196839565677304, 0.3937827226306711, 0.14653136075607368, 0.7068641813738006, 0.5737550439579147, 11.769196629524231, 25.291025979178293, 15.55733973639352, 14.098630581583295, 14.238170385360718, 24.644014937537058, 24.09012712751116, 28.39081018311637, 21.022280318396433, 6.528987279960087, 11.260261058807373, 14.700135265077863, 29.984113761356898, 41.34315388543265, 43.887837818690706, 55.73338038580758, 56.06346150806972, 60.805867603846956, 53.26637731279646, 57.64725126538958, 57.91902310507638, 60.004643031529014, 62.588580812726704, 60.783341544015066, 58.51509516579764, 65.34550789424351, 62.700460706438335, 55.33544315610613, 56.484119347163606, 52.28056689671108, 36.71675491333008, 13.342293109212603, 8.831637229238238, 5.381750668798174, 7.7879917451313565, 11.346669725009374, 15.51718783378601, 40.62130205971854, 73.08243124825614, 86.46741322108677, 45.70813035964966, 56.437462193625315, 59.1042537689209, 5.730825560433524, 0.3274465064917292, 0.17091819431100572, 0.1289750135370663, 0.08958324656954833, 0.045428184127168994, 0.15720169033323014, 0.06357161341501133, 0.012359212568428899, 0.04454463314531105, 0.12130337447992393, 0.0856534635115947, 0.06862442621162959, 0.1659249093915735, 0.07803466197635446, 0.09907257237604686, 0.03825027768367103, 0.04124359081366232, 0.06817943616104977, 0.11985859700611659, 0.003839282601672624, 0.0958401740395597, 0.11019483341702394, 0.06438303273171186, 0.03533431076045547, 0.0359337218105793, 0.07415637972631625, 0.0650898694459881, 0.023802426610408083, 0.03824023875807013, 0.05312720885766404, 0.09360313229262829, 0.023185634885781577, 0.08884094961519752, 0.05659847526944109, 0.0270256833838565, 0.11237831160958324, 0.16512695220964296, 0.003946753642854414, 0.0672863619402051, 0.10611309244164399, 0.06064680178782769, 0.028451399112652456, 0.09908352393124785, 0.12432999350130558, 0.023881891542779546, 0.038403222869549475, 0.05546504019626549, 0.06093424279242754, 0.04764875443652272, 0.032413261609950235, 0.10688083445919411, 0.08086943200656346, 0.07094813723649297, 0.12411700135895185, 0.03300075079979641, 0.10343606144722019, 14.37252857003893, 114.97102914537702, 77.30028656550816, 88.01292882646833, 112.65716089521135, 81.47536182403564, 50.14922782352993, 61.20856434958321, 43.49100187846592, 7.0041050996099194, 1.0129232640777315, 0.1694315919386489, 0.6794842077153069, 9.446245346750532, 44.044387681143625, 62.66421890258789, 65.03767490386963, 75.62498555864606, 80.80697986057827, 75.21661908285958, 71.92502117156982, 67.73007406507219, 75.95126601627895, 76.29651505606515, 71.2571325302124, 69.19670677185059, 74.86409527914864, 74.82933344159807, 69.18377617427281, 64.92113276890346, 59.780521937779014, 63.30548899514334, 58.52252973828997, 45.18867608479091, 22.282296180725098, 23.317881754466466, 19.361857141767228, 34.63732235772269, 30.941033567701066, 24.14588815825326, 31.758826119559153, 27.642711537224905, 25.710441827774048, 17.58080628940037, 10.399915133203779, 1.623956207718168, 0.7828843678746904, 0.025013509838442718, 0.005097747081890702, 0.039070955610701015, 0.07635560671665839, 0.20765395808432782, 0.03987906028383544, 0.03611952844741089, 0.15544775873422623, 0.45512527387057033, 0.39074275004012243, 0.7464838411126817, 0.6489562115498951, 0.16574881598353386, 0.3863408219601427, 0.041397974493780305, 0.260945270636252, 0.12446320349616663, 0.162643378334386, 0.0475348555482924, 0.5045679765088218, 0.4067969157227448, 0.6236474524651254, 0.31314496962087496, 0.24134950499449456, 0.47676948245082584, 0.23597450341497148, 0.9381073415279388, 0.18196511082351208, 2.975019093070711, 14.329286456108093, 38.883033003125874, 22.68081705910819, 18.55702645438058, 19.13104145867484, 24.917148624147686, 21.385243790490286, 28.482712268829346, 33.299488408224924, 14.110082081386022, 14.901860577719551, 19.388277666909353, 34.66579260144915, 49.039767265319824, 52.938887868608745, 64.30846840994698, 61.85283606392996, 68.50704247610909, 59.25229903629848, 61.18703883034842, 61.478154454912456, 62.89159175327846, 63.11324623652867, 63.61359991346087, 60.92388275691441, 69.20589923858643, 65.66764722551618, 53.551826681409565, 51.02217517580305, 53.55466154643467, 38.96130098615374, 21.003961392811366, 21.262745312282018, 18.66066231046404, 26.251148905072892, 30.300395761217388, 30.978178637368337, 45.89476244790213, 51.753480025700156, 80.70787075587681, 73.35226454053605, 50.79034505571638, 76.55432101658413, 17.10270769255502, 0.08909585486565318, 0.10805233873959098, 0.06113172362425497, 0.04333624030862536, 0.04802870690556509, 0.03875140972169382, 0.0679725304778133, 0.028727354215724126, 0.05971080344170332, 0.164215638967497, 0.09089003716196332, 0.03274282267583268, 0.19427493028342724, 0.028949920487190996, 0.051425035909882615, 0.0782433861334409, 0.052159200622034926, 0.038397126232406924, 0.0641942507188235, 0.03126720917810287, 0.09465953667781182, 0.03361738646136863, 0.06938120988862854, 0.06794547050126962, 0.029394252358802726, 0.057944739636565955, 0.16807695105671883, 0.11374987515487842, 0.10056916956922837, 0.221091733447143, 0.11885171889194421, 0.18470594446573937, 0.15478432790509292, 0.10132213309407234, 0.15092650348586695, 0.17895134325538362, 0.23852850922516414, 0.1401200597839696, 0.16246092026787146, 0.10637040649141584, 0.16133615347955907, 0.10999876393803529, 0.28587206878832405, 0.16530954598316125, 0.09067358449101448, 0.11904563062957355, 0.11135954556188413, 0.10799111452485834, 0.2391693719795772, 0.09966046190155403, 0.22377186534660204, 0.177614547844444, 0.3633899449237755, 0.3158510486994471, 0.49462249875068665, 0.1410544432167496, 6.362544919763293, 124.84125791277204, 110.25264644622803, 98.96754905155727, 122.08639444623674, 118.09509904044015, 68.18010193961007, 54.48806170054844, 74.788651738848, 18.914292403629847, 1.8469925139631544, 0.3781511214162622, 1.652258174760001, 11.885832565171377, 54.501812185559956, 89.4437505177089, 78.53466183798653, 72.02960545676095, 83.49598135266984, 79.26164490836007, 79.50410229819161, 71.68809454781669, 81.68479442596436, 80.40523501804897, 72.79253155844552, 67.63047163827079, 75.76440811157227, 77.85835892813546, 71.22683838435582, 65.62099702017647, 66.04798466818673, 69.3253596169608, 67.29522105625698, 51.68955659866333, 32.5588938168117, 26.276478563036235, 23.33137689317976, 42.105836800166536, 45.346862248011995, 28.014551333018712, 38.67233235495431, 30.441736016954692, 32.72965621948242, 18.54580511365618, 20.80447687421526, 2.4771444031170438, 1.9699871369770594, 0.16514528622584684, 0.15601935663393565, 0.18917067774704524, 0.37534358778170174, 0.3996091942702021, 0.12229790325675692, 0.21510685102215835, 0.35559023916721344, 1.5272132903337479, 2.0274465680122375, 0.7563161392297063, 1.370102686541421, 0.21167773859841482, 0.5263180636933872, 0.14521162371550286, 0.9503227089132581, 0.22658797566379818, 0.4588806395019804, 0.07123738314424242, 1.3574343834604536, 1.0116227567195892, 1.7333250875983919, 0.4000441352171557, 0.5758391235555921, 0.46574752245630535, 1.184310027531215, 1.716738869036947, 1.2818642556667328, 9.656917333602905, 15.06390299115862, 39.9395934513637, 22.85404086112976, 16.44186626161848, 21.33917202268328, 28.99471460069929, 28.49556643622262, 37.623362813677105, 33.92687252589634, 13.400456479617528, 27.675753695624216, 28.572469098227366, 47.19959940229143, 57.16646718978882, 60.698677744184224, 69.6275715146746, 69.93828105926514, 74.6843592779977, 62.92723601205008, 66.07539531162807, 65.21311691829136, 63.91600636073521, 70.24124336242676, 69.37059238978794, 63.51626259940011, 76.00396115439278, 76.59143829345703, 63.24286488124302, 60.732112475803916, 67.44179330553327, 53.370666299547466, 26.117835555757793, 21.679698024477275, 22.46769322667803, 30.880431379590714, 31.923658234732493, 28.463036707469396, 62.681193351745605, 82.66237817491803, 102.77184758867536, 71.14925479888916, 70.88944775717599, 84.93360533033098, 10.314345461981636, 0.32753292471170425, 0.31320164086563246, 0.1354367160903556, 0.19231791315334185, 0.13163097601916107, 0.3058014836694513, 0.21662309180412972, 0.06999512801745109, 0.18254892235355719, 0.2372639099402087, 0.2614566960505077, 0.12378375924059323, 0.28192245215177536, 0.15239327906497888, 0.22160725721291133, 0.11198645085096359, 0.14066092004733427, 0.31984930272613254, 0.2943162199641977, 0.05714631426547255, 0.21709383225866727, 0.18697976959603174, 0.19329570925661496, 0.10392896285546677, 0.08813145304364817, 0.15774001287562506], [0.08906423513378416, 0.04783289526988353, 0.036628568811076026, 0.0837265665509871, 0.07379171465124403, 0.02115154974827809, 0.03944023811657514, 0.06230318719255073, 0.018302881624549627, 0.11341657196836812, 0.021821852440812757, 0.012850862079566079, 0.03714737668633461, 0.03142966742494276, 0.09182786076728787, 0.042785120595778735, 0.04962908263717379, 0.037834345895264826, 0.014320739411881991, 0.05937116273811885, 0.10015759736831699, 0.0529714477514582, 0.02325730345078877, 0.05891161132603884, 0.03760859050921031, 0.17201246773558004, 0.0391821098247809, 0.3650832969163145, 0.06188702130956309, 0.05014357163703867, 0.5216183673058237, 14.184439097132001, 94.36711202348981, 86.07975237710136, 69.4093633379255, 117.43125425066266, 87.32074233463833, 41.96105023792812, 28.570824112210953, 39.96719517026629, 7.767521483557565, 1.0009884302105223, 1.4319293860878264, 2.5304179787635803, 14.223921367100306, 46.565756934029714, 73.71792738778251, 61.80467809949602, 52.4180474281311, 54.91101591927664, 66.15436853681291, 71.03064210074288, 72.33782059805733, 71.861403465271, 74.07293864658901, 65.51609311785016, 55.118280683244976, 57.78746591295515, 64.6068240574428, 60.26624270847866, 61.83886323656355, 55.05954756055559, 53.98364332744053, 40.19064923695156, 30.215898718152726, 17.228046246937343, 11.769867999213082, 15.251077038901192, 35.058268547058105, 36.36656223024641, 26.76881228174482, 25.648726190839493, 28.792402165276663, 14.151305743626185, 0.9579376088721412, 0.3244178518652916, 0.2309200960610594, 0.04362307402438351, 0.18353947491518088, 0.11431302529360567, 0.05885723352964435, 0.09612887711929423, 0.07797153107821941, 0.1341320832392999, 0.007722750555590859, 0.39002979972532814, 0.28366696568472044, 0.08179258568478481, 0.2598643914929458, 0.27425202088696615, 0.022515483167288557, 0.13016778310494764, 0.13981796242296696, 0.26281067196811947, 0.06761577712105853, 0.030816685674445968, 0.04762497856946928, 0.7174789660743305, 1.1562119466917855, 0.36213837351117817, 0.09385577802147184, 0.07304056960025004, 0.1706646257745368, 0.08556573571903364, 0.5615569927862712, 2.075986249106271, 9.229934028216771, 24.4008366721017, 18.546122993741715, 7.221807360649109, 10.277824861662728, 23.109637294496807, 28.859167405537196, 19.94749821935381, 5.005437970161438, 5.112732487065451, 8.389961957931519, 11.322225962366376, 24.458652632577078, 40.083824157714844, 38.37971939359392, 41.88834081377302, 47.33294922964913, 51.274565015520366, 52.9838079724993, 53.18572262355259, 54.736161027635845, 56.23975815091814, 61.461193902151926, 62.370365687779014, 59.465900557381765, 59.51582336425781, 59.33950587681362, 59.38455104827881, 38.94863442012242, 21.37655333110264, 11.486552596092224, 13.182667800358363, 5.287361127989633, 3.839193258966718, 6.3994689498628885, 12.921896696090698, 43.860493183135986, 83.6746403830392, 81.2067792075021, 56.14611380440848, 57.94163949148995, 65.41669913700649, 12.80531026635851, 0.39834872047816006, 0.05733729473182133, 0.07966792290764195, 0.09842256296958242, 0.07120678800025157, 0.08798376989683934, 0.0990172310599259, 0.06862642110458442, 0.05480414708810193, 0.02691427302280707, 0.13787423100854668, 0.0849969537396516, 0.15757500672979013, 0.08245435410312243, 0.057421338079231124, 0.08307558683944599, 0.0064062916873289, 0.08040116141949381, 0.09550296249134199, 0.11315581774605171, 0.03488735295832157, 0.05891659177307572, 0.035891734063625336, 0.016855105025959865, 0.051696426168616326, 0.02604878125047045, 0.044716363573180776, 0.03928267549989479, 0.06775520249669041, 0.030855389311909676, 0.07936911644147975, 0.031026536199663366, 0.025111788850543753, 0.05437786764066134, 0.08276874651866299, 0.02849158026011927, 0.09884719696960279, 0.05059957091829606, 0.028049663973173926, 0.055773709168923755, 0.03268199201141085, 0.10240550246089697, 0.04654477796118174, 0.015512504747935703, 0.023054540223841156, 0.03542368060776165, 0.11281277079667364, 0.10035596708101885, 0.0008526332156699416, 0.12883845157921314, 0.12698519602417946, 0.06821843156857149, 0.01524712800580476, 0.13525284667100224, 0.14575384104890482, 0.02929327277732747, 0.22895060745733126, 0.8011201322078705, 48.67618192945208, 117.27957507542202, 83.20824255262102, 95.35955102103097, 110.88446698869977, 67.91770321982247, 42.66296420778547, 54.729188510349815, 41.640727860586985, 11.958087750843593, 4.03274575301579, 0.9300802179745266, 1.8645662452493394, 14.833516359329224, 54.65763943535941, 72.00708634512765, 64.15334987640381, 66.90619141714913, 71.63537856510708, 74.80759252820695, 74.25890023367745, 74.077559198652, 75.96186896732875, 75.07648086547852, 65.31236498696464, 61.94223158700125, 66.79640293121338, 69.30525153023856, 62.81675965445382, 62.93971497671944, 61.53200299399239, 60.329499108450754, 48.86656257084438, 32.278415884290425, 20.238436664853776, 14.494236690657479, 24.05867436953953, 31.19461849757603, 24.20151891027178, 20.121550594057354, 17.484136002404348, 21.18070272036961, 17.74092926297869, 6.08507946559361, 1.1277642846107483, 1.092169966016497, 0.08890535615916763, 0.2992434969970158, 0.08788851715092148, 0.081910372578672, 0.1411412414163351, 0.039453391517911635, 0.08805329938020025, 0.1417794714548758, 0.3914445180978094, 0.17173193421747002, 0.07515659462660551, 0.45954940361636026, 0.6560746410063335, 0.1775897948869637, 0.4653751967208726, 0.32817416744572775, 0.049397583452186415, 0.20797814854553767, 0.03629042088453259, 0.041459371734942706, 0.4263864659837314, 1.4515220033270972, 0.2132650219968387, 0.1769433817160981, 0.08448837817247425, 0.18792720804257051, 0.35854699622307507, 0.9950074425765446, 2.8865502859864915, 11.769652605056763, 35.672673429761616, 21.270723581314087, 13.255874889237539, 20.05287286213466, 23.21216664995466, 20.937486239842006, 25.158965042659215, 22.171649592263357, 10.066647393362862, 15.588007347924368, 22.67589599745614, 43.03194829395839, 51.42685215813773, 58.79603862762451, 63.85876015254429, 63.56706782749721, 64.29381465911865, 59.14474787030901, 59.715361731392996, 61.36879675728934, 60.230848584856304, 61.20489570072719, 64.9549982888358, 65.04363645826066, 61.664706638881135, 58.36372865949358, 54.421143599918906, 35.29302733285086, 27.53437348774501, 31.42369713102068, 36.661947522844585, 20.981051445007324, 19.386026450565883, 20.6405827658517, 26.303211757114955, 47.35246671949114, 64.03117970057896, 83.60229573931012, 84.36654199872697, 54.11844880240304, 75.33417565482003, 32.44327579225813, 0.7572279817291668, 0.02363584965600499, 0.05796506176037448, 0.03125863249546715, 0.04381369147449732, 0.04610503977164626, 0.07347269462687628, 0.027314910631892935, 0.10388486486460481, 0.10741397299404655, 0.12615168360727175, 0.1356380781424897, 0.06242262971188341, 0.04594088518725974, 0.032005757226475647, 0.07030202262103558, 0.06477251183241606, 0.027294617345822707, 0.01201195446109133, 0.05046186562893646, 0.10993808255131755, 0.08021271867411477, 0.06495815222816807, 0.06435232223676783, 0.04198421857186726, 0.08745027173842702, 0.03727065632119775, 0.17570011557212897, 0.15729249188942568, 0.17146794338311466, 0.17397633806935378, 0.16709200319434914, 0.09429193354610886, 0.14527510745184763, 0.19057557093245642, 0.09873863815196923, 0.17973570259554045, 0.09735858613359076, 0.08858001897377626, 0.1401120802121503, 0.1119438795638936, 0.21940850519708224, 0.14028240607253142, 0.19258745440414973, 0.11106202831225735, 0.09515612931655985, 0.16475299799016543, 0.12915815013859952, 0.1394636585776295, 0.2513430773147515, 0.1587435525975057, 0.12831657672567026, 0.29292370325752665, 0.20248498687786715, 0.5035307950207165, 0.0908782510086894, 0.5277143259133611, 0.44956334946411, 32.45345490319388, 140.52955382210868, 107.19810022626604, 98.47966044289726, 131.27237156459262, 103.37533337729317, 59.58856405530657, 45.081743308476035, 59.67798042297363, 25.4526914528438, 5.955821692943573, 2.0857156813144684, 3.1648495239870886, 20.842417512621196, 66.8813863481794, 94.87434441702706, 75.03661210196358, 69.6098119190761, 71.33063752310616, 77.34071813310895, 79.75423049926758, 79.28987543923515, 79.3980519430978, 82.62554577418736, 70.87978976113456, 63.006167548043386, 69.96348217555455, 71.91834395272392, 61.40380872998919, 66.5861712864467, 60.31777054922921, 68.67771802629743, 56.67268303462437, 44.42254686355591, 29.72272253036499, 23.97746729850769, 30.52093505859375, 49.50188153130667, 39.73982926777431, 26.77959588595799, 25.404759304864065, 37.814778736659456, 27.185947384153092, 13.526916299547468, 1.50522224179336, 1.4416753202676773, 0.33757684433034485, 0.5290952261005128, 0.4594761761171477, 0.09162098901080233, 0.2327586274061884, 0.25426729183111874, 0.23702156437294825, 0.2390464214341981, 1.8259724761758531, 0.5101021081209183, 0.2560061328113079, 0.4858454582946641, 0.9225019046238491, 0.2492483582879816, 1.3672872547592436, 0.45543552722249714, 0.5700027995875904, 0.23611574726445334, 0.1055616538173386, 0.14913529317293847, 1.5670488327741623, 2.217264405318669, 0.74643574655056, 0.5190019362739154, 0.26988228250827107, 0.17256930071328366, 0.49823301072631565, 2.120447120496205, 3.9016849228313992, 12.28562409537179, 44.49546473366873, 22.792695215770177, 12.844360010964529, 17.380277803965978, 31.614762169974192, 41.484247480119976, 31.10792234965733, 19.881797790527344, 19.548075812203543, 24.309955971581594, 28.765609911509923, 45.238591943468364, 53.64998388290405, 56.38016734804426, 64.0316104888916, 72.02392877851213, 70.95245402199882, 63.76253455025809, 61.358589853559224, 66.90457943507603, 68.04800973619733, 71.6205233165196, 73.62921278817313, 75.18873596191406, 73.75050054277692, 69.78788730076381, 67.00903170449394, 52.60409934180123, 40.3520941053118, 38.38078246797834, 36.08898169653756, 22.500447034835815, 18.998686960765294, 17.68627299581255, 25.11943847792489, 62.580236026218955, 93.75319004058838, 94.95276178632463, 84.77671500614711, 73.9863224029541, 86.44174657549176, 20.803597927093506, 0.3728806956538132, 0.11647854266422135, 0.18686284444161824, 0.1162225314016853, 0.11443338383521352, 0.12173941465360777, 0.232008194816964, 0.1718260877366577, 0.14647314245147364, 0.1527154610625335, 0.18071946980697767, 0.30311915331653183, 0.1555116767329829, 0.11351077977035727, 0.07795550408107893, 0.3268217657293592, 0.2083426168454545, 0.13721303934497492, 0.25669082892792566, 0.1655142328568867, 0.12193321782563414, 0.11559450652982507, 0.1169072546597038, 0.15337364003062248, 0.23918543968881878, 0.12251265959015914, 0.1074215793716056], [0.023549850431403944, 0.08061160227017743, 0.03045698069036007, 0.027901049537052, 0.03281049297324248, 0.04688430670648813, 0.06816950919372694, 0.07010375468858651, 0.0750887750514916, 0.06438785711569445, 0.03715231981394546, 0.09335869005216019, 0.010549168667889066, 0.024336452329797403, 0.04042458547545331, 0.06499878969043493, 0.04162247119737523, 0.019334314224709357, 0.08881686840738569, 0.01912947976961732, 0.08898138600800719, 0.047523469730679474, 0.05474787957168051, 0.018537758217592324, 0.10699727106839418, 0.03014119727803128, 0.16688496858945914, 0.044376576984567304, 0.2293140579547201, 0.0975289052086217, 0.17385975218244962, 0.2220985572785139, 36.4159882409232, 88.26391165597099, 88.27608489990234, 81.17893082754952, 122.43695885794503, 81.0594287599836, 39.16247912815639, 22.088842698505946, 27.574386426380702, 5.13653701543808, 4.310927740165165, 5.630269927637918, 8.525165217263357, 21.443657296044485, 51.43224048614502, 65.81558132171631, 65.63288538796562, 59.27859796796526, 57.91987425940377, 62.69703524453299, 67.34009252275739, 74.22048364366803, 72.13359219687325, 77.95757225581578, 70.57611179351807, 63.71480737413679, 61.09014620099749, 57.55733115332467, 56.837494305201936, 53.07925885064261, 47.99655083247593, 43.689570971897666, 27.246064935411724, 24.989788566316875, 19.98687539781843, 16.887874603271484, 25.905740056719097, 42.559130328042166, 50.115164279937744, 51.66220848900931, 36.031026772090364, 15.567590066364833, 3.158012930835996, 0.8527352054204259, 1.4305794813803263, 0.07142396670367036, 0.4167409549866404, 0.4006093820290906, 0.332685013966901, 0.04946127074903675, 0.510738519685609, 0.3595041648617813, 0.13964656447725637, 0.5473457010728973, 0.19461968035570212, 0.054987202265432904, 0.2219230066984892, 0.20658773529742444, 0.2930488793977669, 0.17047517879733018, 0.36388182852949413, 0.2740116837833609, 0.28979112420763287, 0.10278911223368985, 0.042998072026031356, 0.5733219757676125, 0.2808331863156387, 0.3378723870430674, 0.18585188154663357, 0.30475955243621555, 0.15948398358055524, 0.019679469721657888, 0.6672941361154828, 0.6273196297032493, 6.517666058880942, 27.214766774858745, 20.239282608032227, 23.20646217891148, 24.082452842167445, 19.518997601100377, 13.603918841906957, 1.7537673392466135, 5.466274636132376, 11.142996311187744, 7.655459199632917, 6.559093824454716, 13.042262077331543, 30.529060976845876, 27.891835723604473, 33.66946608679635, 39.0229697227478, 50.63993045261928, 52.15312998635428, 55.34925964900425, 48.391722679138184, 55.30506215776716, 55.88704674584525, 58.373602049691335, 58.55591583251953, 57.04259817940848, 50.46073988505772, 33.171179498944966, 20.555536815098353, 18.319406747817993, 14.86060391153608, 2.6191039170537675, 3.0896632841655185, 7.274446478911808, 19.72043456350054, 56.09945317677089, 84.8734964643206, 84.11774090358189, 45.494709491729736, 46.561942373003276, 64.883209500994, 22.96282533236912, 0.1531102191656828, 0.21002747357956, 0.06830691932035343, 0.043045610189437866, 0.004972153218529586, 0.018619328304859142, 0.049169856921902726, 0.032193501080785475, 0.050619916790830236, 0.06516116990574769, 0.12990228592285089, 0.07864384393074683, 0.08934117920164551, 0.03444974197606955, 0.03966919618791767, 0.12876918672450952, 0.07393456662872008, 0.03619054392246263, 0.06904823239892721, 0.036488634534180164, 0.13932552241853305, 0.01962579251267016, 0.09786025421427828, 0.014311777660623193, 0.14216953409569605, 0.004292502857944263, 0.08178368330534015, 0.15409746047641548, 0.03893012227490544, 0.0651454482493656, 0.02168483247182199, 0.023551156611314843, 0.04689883753391249, 0.05530470237135887, 0.056919527506189685, 0.004304389943302209, 0.11021569836884737, 0.02367579161987773, 0.06464002108467476, 0.08272717946342059, 0.10919757014406578, 0.031396164758397, 0.017829220076756816, 0.015489152965268918, 0.05058008339256048, 0.07431177103093692, 0.06769389685775552, 0.011414168502337165, 0.09264390769281558, 0.034904625067221265, 0.08348380029201508, 0.10669023397245578, 0.15209639285291943, 0.07303296322269098, 0.08279215597680636, 0.030415230430662632, 0.14175165151911123, 0.02954181676198329, 0.6335391902497837, 1.3701158229793822, 76.94022396632603, 100.87594822474888, 83.03664289202008, 109.90684849875313, 105.57545961652482, 62.37509741101946, 43.053619725363596, 49.93687002999442, 38.88819204057966, 19.795066901615687, 10.734860863004412, 8.717759728431702, 9.423551661627632, 20.24286093030657, 46.89980895178658, 63.96624183654785, 61.18583679199219, 61.5033277784075, 64.65346036638532, 72.63080528804234, 69.94424261365617, 78.82232420785087, 75.77640070234025, 77.50474425724575, 74.40994017464774, 75.5121259689331, 75.93194307599748, 73.80959497179303, 71.45207118988037, 67.4252496446882, 60.61673763820103, 46.24666786193848, 33.30876425334385, 26.985172237668717, 21.072052001953125, 20.96180146081107, 29.201913356781006, 29.849277019500732, 29.84719603402274, 27.547481264386857, 19.918953282492502, 18.069379295621598, 4.9583587135587415, 1.2383387855121066, 1.054889732173511, 0.023364949638822248, 0.38223207529102055, 0.42533693515828674, 0.3120917204235281, 0.1637709813990763, 0.7141280344554356, 0.22183063094105038, 0.1478259784302541, 0.4912949630192348, 0.4725561056818281, 0.06809359469584056, 0.2970037343246596, 0.2653126205716814, 1.6898937438215529, 1.3348072490521838, 0.3239485499049936, 0.36026173563940184, 0.2802342841667788, 0.18997532528425964, 0.05543929657765797, 0.8589580772178513, 0.9967068199600492, 0.4203731800828661, 0.33636253806097166, 0.24456972362739698, 0.2837304765624659, 0.11024775236312832, 0.30402277197156635, 0.15552371394421372, 8.181073921067373, 34.24054547718593, 31.368993963514054, 35.52315167018345, 32.83564056668963, 23.638872895921978, 22.480203458241053, 16.513298954282487, 11.457405771527972, 17.86480348450797, 22.45156298364912, 19.589058024542673, 26.845139980316162, 47.05284649985177, 43.86436332975115, 51.53469514846802, 53.69756862095424, 57.941378934042795, 60.63351058959961, 62.637829644339426, 57.647609097617014, 57.57323905399868, 60.263359206063406, 66.11104651859829, 61.39283752441406, 53.67936781474522, 45.243240288325715, 32.85737453188215, 34.13112524577549, 45.380133696964805, 39.19539621898106, 15.482990537370954, 15.613967554909841, 20.085885490689957, 30.32178579057966, 51.65513869694301, 64.68084321703229, 81.88800839015416, 69.83780315944126, 54.374118191855295, 74.55337183816093, 47.16824913024902, 0.6685196246419634, 0.08933077725980963, 0.038062075818223615, 0.06704043370804616, 0.05701421706804207, 0.03921853019190686, 0.08971501807016985, 0.02817659412643739, 0.014131250874405461, 0.049967637684728415, 0.07975222409835883, 0.08915235647665602, 0.06849361823073455, 0.058486739838761945, 0.03719515233699765, 0.09498846331345183, 0.013749121156122004, 0.024401135376787612, 0.04123140771740249, 0.006973111852338272, 0.02539482107385993, 0.08409843766795737, 0.017452648408444862, 0.050929169303604534, 0.11555193524275507, 0.059017354223345, 0.053894659105156145, 0.06391204121921744, 0.14242855805371488, 0.18470865860581398, 0.16721987990396364, 0.14473952619092806, 0.15169798423136982, 0.1373557759714978, 0.10116394622517483, 0.12521664878087385, 0.21205002362174646, 0.19548676668533257, 0.13800377691430704, 0.12145980394312314, 0.2957401935543333, 0.15402337802307947, 0.2142154188560588, 0.19427282682486943, 0.14807896342660698, 0.14221405956361974, 0.13946524634957314, 0.10950563861323254, 0.21986244512455805, 0.10929806118032762, 0.13088487248335565, 0.21612879261374474, 0.25175046973994797, 0.12942937415625366, 0.25407692204628674, 0.12778239324688911, 0.4306901693344116, 0.20674940305096762, 0.38210790338260786, 0.37023006645696505, 71.35304546356201, 127.33999688284737, 112.27318259647915, 112.10352843148368, 133.8128831045968, 98.0631228855678, 62.51440184456961, 40.034516266414094, 47.61694989885603, 35.35511643545968, 16.354301588875906, 11.20493950162615, 14.233337044715881, 27.67700958251953, 70.3781715120588, 88.4104700088501, 75.31262234279087, 70.31586701529366, 69.96696322304862, 72.37119279588971, 72.31339768001011, 81.9293988091605, 80.99819428580147, 84.48771858215332, 81.70569460732597, 77.63769803728376, 78.92350387573242, 74.40656335013253, 72.43816648210797, 67.60324164799282, 61.84372697557722, 51.84059306553432, 39.501936844417024, 37.682231426239014, 37.04451881136213, 29.17525311878749, 40.21753529139927, 52.641473702022004, 62.95044994354248, 62.13566248757498, 50.63882916314261, 32.41173791885376, 12.576317616871425, 1.0648635455540247, 2.436200188738959, 0.16968320629426412, 1.2326244349990572, 0.7071943293724741, 0.523933963051864, 0.19828222239656107, 0.7447816410234996, 0.4331607424787113, 0.33044419277991566, 2.183368052755083, 1.2271395921707153, 0.33778328182441847, 0.6830566131642887, 0.6174886886562619, 1.8446713813713618, 0.6813835629395076, 0.797817240868296, 0.661361134478024, 0.8626265089426721, 0.5256015307136944, 0.3106904099030154, 1.6659558968884605, 1.1872473784855433, 0.6620843985251018, 1.0059902646711893, 1.5369963539498193, 0.4257190317979881, 0.27576691816960064, 1.3606896145003182, 1.2095585869891303, 11.510108726365225, 39.16874640328543, 39.841599532536094, 45.62907028198242, 38.251754420144216, 42.37528446742466, 35.801555565425325, 18.896124601364136, 16.13738751411438, 26.808276312691824, 27.314921583448136, 24.14202148573739, 24.080679314477102, 45.22669662748064, 47.41118247168404, 50.18689053399222, 54.871838501521516, 57.85452992575509, 59.55398981911795, 65.75146334511894, 65.94638810838971, 67.88627651759556, 65.35895960671562, 74.79808739253453, 68.7977967943464, 66.24422264099121, 60.1493045261928, 48.75368561063494, 42.76228175844465, 44.651594230106895, 36.720809187207905, 14.826403141021729, 12.82200939314706, 19.767376593181066, 36.50767319543021, 76.89917400905064, 90.56647518702916, 94.59873022351945, 73.03193868909563, 69.79591941833496, 90.66138757978166, 35.000925064086914, 0.2473563312419823, 0.31817429832049776, 0.13963137886353902, 0.23050046286412648, 0.14517336791115149, 0.1631152315863541, 0.13819049618073873, 0.13892795518040657, 0.19227705177451881, 0.1773829638425793, 0.1894431502691337, 0.2006029478673424, 0.23647485513772282, 0.17177119425364903, 0.12448412951614175, 0.23590027168393135, 0.09597056132874318, 0.1286778694816998, 0.1560865044593811, 0.10256853406982762, 0.1661075438771929, 0.11738328768738679, 0.22870288789272308, 0.0992071937237467, 0.2194847453917776, 0.2691407251570906, 0.14751820851649555, 0.22339061009032385], [0.0975290069888745, 0.04057003963472588, 0.0955573335023863, 0.036994485783257654, 0.009980996521855039, 0.04390584670805505, 0.044973402816270075, 0.05606468873364585, 0.020183234475553036, 0.010886934918484517, 0.018710184143856168, 0.03178634614284549, 0.034293919801712036, 0.058684207099889, 0.04046599646764142, 0.032009499347103496, 0.024520988409806575, 0.04492762205856187, 0.028103658397282873, 0.08773221660937582, 0.0811860907290663, 0.040673614612647464, 0.13127026680324758, 0.05488939144249473, 0.042948423618716855, 0.052174091073019166, 0.07990417523043496, 0.10418665688484907, 0.17291311440723284, 0.10857331792690925, 0.42908380553126335, 0.24075801244803838, 0.8466442951134273, 48.27299533571516, 86.63274560655866, 70.19233499254499, 79.88503033774239, 121.68904086521694, 81.92983654567173, 47.605172702244346, 22.374912193843297, 15.870484624590192, 9.757633209228516, 14.787976128714424, 12.398349932261876, 13.514430386679512, 20.877358266285487, 42.0441437448774, 51.56367261069161, 64.30574471609933, 64.69201592036656, 54.50635978153774, 49.3718911579677, 56.45232439041138, 62.6809640611921, 66.04498999459403, 64.98356928144182, 61.507816314697266, 59.43664864131382, 57.89299862725394, 56.47978367124285, 59.61637074606759, 54.10995462962559, 45.7731967653547, 21.688360691070557, 17.23067614010402, 25.86438611575535, 33.44178751536778, 23.292114359991892, 26.04671205793108, 31.05857276916504, 55.63996532985142, 38.35259362629482, 15.358081034251622, 4.583867311477661, 1.6573205888271332, 1.1712388374975748, 0.2856438367494515, 0.16849346299256596, 0.04935719704787646, 0.2690749072602817, 0.1374062725475856, 0.12823859948132718, 0.18112939995314392, 0.3915753667908055, 0.2396905411567007, 0.030176945895488774, 0.05793747931186642, 0.048503118234553506, 0.4226378042783056, 0.6324874609708786, 0.10287654825619288, 0.10006925210888896, 0.05501164648947971, 0.13867776574833052, 0.07857341199581112, 0.028637261728623083, 0.09900672055248703, 0.2877068274787494, 0.1221851035952568, 0.2944440559617111, 0.3366888591221401, 0.1264011130801269, 0.013880199702855731, 0.22015361807176045, 0.09481662431997911, 4.048208100455148, 25.629839250019618, 22.071034465517315, 21.357199123927526, 25.752537488937378, 7.406431419508798, 12.426006368228368, 6.1342579466956, 6.946706031050001, 8.032464981079102, 4.067808534417834, 2.8115249403885434, 7.105085006781986, 20.252110719680786, 15.055205583572388, 22.328988075256348, 37.05231816428048, 46.32199675696236, 52.637822423662456, 49.461331844329834, 47.539744990212576, 55.790800298963276, 55.75269290379116, 50.892848355429514, 41.52624934060233, 31.41406692777361, 29.960823399680002, 22.995421069008962, 17.37521951539176, 7.940197246415274, 2.6418885801519667, 6.182386815547943, 11.80844439779009, 23.625256163733347, 57.776220253535676, 90.56955323900495, 93.95884977068219, 51.07439088821411, 50.681828090122764, 60.25393050057547, 26.712250471115112, 0.35174416697451044, 0.1775535475462675, 0.1106721760172929, 0.12150468224925653, 0.18765580760581152, 0.09838673632059779, 0.07806321472993918, 0.06226292970989432, 0.17655976515795502, 0.14309646721397126, 0.15497815821852, 0.07417235244065523, 0.19102822164339678, 0.02487226259628577, 0.07452463425163712, 0.03058590573657836, 0.07098408602178097, 0.051377887904111824, 0.08313681105417864, 0.04730455058493784, 0.0644541974844677, 0.15337928544197763, 0.0794630189027105, 0.010382003084357296, 0.13577298447489738, 0.04695809738976615, 0.06668674054422549, 0.2705142157418387, 0.0849246219066637, 0.0404494911033128, 0.01834435877390206, 0.11841509517814432, 0.0671999640762806, 0.06576218229851552, 0.0322113601224763, 0.007689588004723191, 0.03758870264781373, 0.08415573995028224, 0.01598700089380145, 0.07671398855745792, 0.057076018037540574, 0.04960365793002503, 0.06715289410203695, 0.006381488263806594, 0.04075446884546961, 0.07436786552092858, 0.06554236409387418, 0.10993048974445888, 0.06448186135717801, 0.02655384030991367, 0.05508282820561102, 0.08611233638865606, 0.04991672380960413, 0.09490566847047635, 0.029181077011993954, 0.09336069173046521, 0.03541412344202399, 0.10343977303377219, 0.1331985140485423, 0.18753976454692228, 0.270109727446522, 10.649597781045095, 90.98035853249687, 96.53596442086356, 83.74990327017647, 109.11274582999093, 99.54800156184605, 62.37180396488735, 44.1358676637922, 45.407130922589985, 32.93606982912336, 30.59762580054147, 29.867474351610454, 20.69533630779811, 23.325559513909475, 28.50161484309605, 39.58521447862898, 49.63197265352522, 63.12952586582729, 64.14990356990269, 61.10299342019217, 59.00570052010672, 62.751293727329795, 68.5809782573155, 73.96000262669155, 70.88407679966518, 74.08359023502895, 70.15070138658795, 72.12351036071777, 66.66608251844133, 68.65467779976981, 62.692143712724956, 66.00271020616803, 35.2213705607823, 27.332540478025162, 32.557518073490684, 29.43798882620675, 29.535107272011892, 26.25980462346758, 38.185739585331504, 64.66429955618722, 45.07253694534302, 29.26066037586757, 3.815230659076146, 1.0392071051256997, 1.0801271093743188, 0.24999482823269709, 0.23446310737303325, 0.07340917017843042, 0.3202055607523237, 0.046247257318879874, 0.13237310333975724, 0.19252589770725795, 0.16698970725493772, 0.5472144452588898, 0.15244264927293572, 0.03198729768129332, 0.13144460959093912, 0.21374865461673054, 0.9193786893572126, 0.4005530636225428, 0.14411378119673046, 0.07846275650496994, 0.2172362839004823, 0.05835927703550883, 0.042886198564831696, 0.11218638797955853, 0.8322219518678529, 0.24621717951127461, 0.3035588168672153, 0.16610962019434997, 0.2518409863114357, 0.030982835151787316, 0.6376388445496559, 0.5389592253736087, 6.852234414645603, 36.60238756452288, 36.67436395372663, 41.363696234566824, 41.90829604012625, 23.587951285498484, 19.39811631611415, 14.984495503561837, 13.027597904205322, 18.535080569131033, 16.528981038502284, 16.00037772314889, 15.386276824133736, 36.112619468144004, 34.00558171953474, 32.88085944311959, 48.255096776144846, 59.8512407030378, 64.55442074366978, 62.55784893035889, 55.90680742263794, 61.092466899326865, 58.73397036961147, 53.33777700151716, 42.520310742514475, 34.53104271207537, 35.241690567561555, 38.91215637751988, 40.006647041865754, 27.21544769832066, 17.562954630170548, 21.893874508993967, 30.252564362117223, 39.64037275314331, 55.46824754987444, 71.84900093078613, 87.1392136982509, 74.77888257162911, 56.13769258771624, 69.00319249289376, 51.03462634767805, 2.089573451450893, 0.04982361862702029, 0.17865448418472493, 0.029661364454243864, 0.041442184442920346, 0.040470959951302836, 0.15373025089502335, 0.026602650726480142, 0.03848908469080925, 0.047152429819107056, 0.06627489692930665, 0.11397473487470831, 0.12172224771763597, 0.007017301869512136, 0.11329605057835579, 0.06777060524161373, 0.09818922156201941, 0.12083728877561432, 0.05251062069354313, 0.08102594967931509, 0.04158569799203958, 0.07706388871052436, 0.059269199280866554, 0.04463632018970592, 0.16493469609745912, 0.10373655068022863, 0.15850651317409106, 0.03139651759660669, 0.023319016210734844, 0.12447959690221719, 0.1435748751142195, 0.19405311718583107, 0.08870094748479979, 0.10300819083516087, 0.11028904800436326, 0.22594992204436234, 0.14744152048868792, 0.2102892252483538, 0.08364871822829757, 0.12752710123147282, 0.16715117144797528, 0.14716665952333383, 0.13711096053676947, 0.3307361528277397, 0.12798037619463035, 0.12521398892360075, 0.1230360950742449, 0.19899036868342332, 0.18053247912653855, 0.1371928190014192, 0.11839878319629601, 0.1450100445321628, 0.13687141053378582, 0.14205696513610228, 0.12634345117424214, 0.14825013067041123, 0.15406938269734383, 0.26153041209493366, 0.2050072643905878, 0.33516394666263033, 0.3089936652353832, 3.5780708364077976, 99.46068355015346, 120.88063185555595, 91.67672089168003, 108.1529494694301, 132.82276480538505, 94.52900505065918, 67.92964717320034, 41.44273199353899, 33.133086000170024, 41.37876340321132, 38.375665119716096, 27.627706902367727, 29.193975039890834, 35.69165243421282, 62.341753005981445, 80.62045546940395, 81.51176343645368, 79.77537386757987, 72.88720076424735, 62.01276969909668, 65.32711601257324, 73.72997556413922, 81.54103619711739, 77.31129946027482, 79.74746990203857, 75.37164728982108, 76.72482286180768, 69.59772205352783, 67.96622249058315, 62.730011395045686, 59.19071020398821, 32.41834218161446, 32.557896750313894, 38.02481583186558, 42.8684641293117, 36.49175834655762, 38.180055958884104, 44.979114941188264, 72.8573304585048, 62.67831679752895, 40.81801945822579, 14.506943208830696, 2.091847683702196, 3.931545674800873, 0.3791314416698047, 0.32035017013549805, 0.1469269059598446, 0.6950468154890197, 0.15730543833758148, 0.2098419756761619, 0.2514285727271012, 1.444662937096187, 1.174511113337108, 0.3746486593570028, 0.1730276918304818, 0.419126602688006, 1.417797944375447, 2.0033662830080305, 0.18537982473415987, 0.3782169935958726, 0.20054494669394834, 0.6168163418769836, 0.10577518878770725, 0.12287446803280286, 0.2722956415797983, 1.674795959677015, 0.24071135638015612, 0.7075871197240693, 0.5507776226316179, 0.20511639996298722, 0.1283913105726242, 0.49451203324965065, 0.633953639439174, 10.717735290527344, 50.06612042018345, 48.29924215589251, 52.3655537877764, 52.22218118395124, 27.22336517061506, 29.684118338993617, 20.753746339253016, 21.803257840020315, 27.75238711493356, 18.252507754734584, 13.128148760114398, 17.603031839643204, 35.14265441894531, 30.468743664877756, 37.34334693636213, 47.382552419389995, 57.578946999141145, 63.645645005362375, 60.27245439801897, 60.7408880506243, 65.73863002232143, 71.06327778952462, 62.501978465488975, 55.82125425338745, 48.15757533482143, 46.61892802374703, 42.09072099413191, 41.652571065085276, 24.294944388525828, 13.571799056870596, 18.514359303883143, 31.734941686902726, 46.82787772587368, 77.77341025216239, 96.70383289882115, 105.5363621030535, 76.66305337633405, 76.59366866520473, 89.29889447348458, 42.53859492710659, 0.5343973530190331, 0.3988851431225027, 0.14232369725193295, 0.1536727382668427, 0.23907573414700373, 0.23112113241638454, 0.19704612158238888, 0.12800124793180398, 0.26855962776712006, 0.1968830424760069, 0.3657807223498821, 0.2700837259846074, 0.3610169179737568, 0.134852850277509, 0.34494185341256006, 0.1915240678936243, 0.17151503371340887, 0.27426135752882275, 0.17677796844925198, 0.14697517694107123, 0.1729823656912361, 0.1429845496479954, 0.07239718269556761, 0.10807427577674389, 0.3636525108345917, 0.12200324263955865, 0.1974807639739343, 0.21000856959394046, 0.18338852801493236], [0.09181269550962107, 0.03947315045765468, 0.02912380526374493, 0.023717270465567708, 0.0575388264177101, 0.053993755751954656, 0.06877917290798255, 0.016138913010114005, 0.10667518406574215, 0.14675611869565078, 0.03245309500821999, 0.01064797948181097, 0.07383119860397917, 0.06039908222321953, 0.09600446772362504, 0.05846963397094181, 0.02665212780370244, 0.027350710139476826, 0.03392076964623161, 0.0900727417320013, 0.060911688288407664, 0.11598036225352969, 0.035650966090283225, 0.013002776740384954, 0.11346641036548785, 0.0777933681383729, 0.09349454633359398, 0.07803710470242159, 0.08662040305456944, 0.15987388337297098, 0.4538171669202191, 0.4230362128998552, 0.15642970747181348, 3.1841296894209723, 73.57762936183384, 96.96408462524414, 72.00070789882115, 75.44375569479806, 126.02773230416435, 93.67101369585309, 58.91583251953125, 27.92981631415231, 14.779528856277466, 17.115669557026454, 9.332899383136205, 13.680322102137975, 11.272059100014822, 15.132419177464076, 30.11852318899972, 37.181554658072336, 48.421634674072266, 46.74036863871983, 40.65635224751064, 49.4439127104623, 42.59629276820591, 38.40566396713257, 40.55078479221889, 44.997715268816265, 48.790375573294504, 51.14305993488857, 42.41324942452567, 48.01797907693045, 38.08061334065029, 20.95353136743818, 6.914067302431379, 12.398545350347247, 16.110470192773, 22.6282365662711, 27.35586210659572, 33.2168083190918, 19.746393033436366, 19.762215818677628, 33.21239621298653, 15.35727504321507, 2.0225398370197842, 1.685316617999758, 0.44070868460195406, 0.0927660372108221, 0.04660987321819578, 0.27312969682472094, 0.09836861943559987, 0.0343960495000439, 0.1487817628575223, 0.18387598757232937, 0.21105681120284966, 0.04188776481896639, 0.17011426602091106, 0.055332956569535394, 0.13565151313585894, 0.1769492035465581, 1.1146192699670792, 0.9853492294039045, 0.08975652405726058, 0.025933036746989404, 0.04260931217244693, 0.08566468648080315, 0.1035523284226656, 0.07557758489357573, 0.2643071673810482, 0.052526932675391436, 0.009413912576357169, 0.19379950793726103, 0.4461318078849997, 0.0830413411770548, 0.6299777499267033, 2.1262128225394656, 2.3553364021437506, 25.571295465741837, 22.658266680581228, 14.710123300552368, 26.62428453990391, 19.361904042107717, 10.496880718639918, 6.957840085029602, 10.970157265663147, 2.6446897898401533, 2.9371305661542073, 6.423179677554539, 16.65479554448809, 12.79538823877062, 21.925586087363108, 28.601637635912212, 35.777271611349924, 41.803270544324604, 38.318717684064595, 43.16181359972273, 47.32620600291661, 44.5635119165693, 34.520543984004426, 29.555948393685476, 30.340504237583705, 24.304482528141566, 23.117111819131033, 23.062802961894445, 10.907294307436262, 6.870594160897391, 9.910974740982056, 21.241516828536987, 34.11727401188442, 64.43730190822056, 87.8443238394601, 76.6359623500279, 51.51519502912249, 53.000712939671104, 55.45076240812029, 20.97074726649693, 0.4092028923332691, 0.09221830338771854, 0.2655263048197542, 0.12512938917747565, 0.023489353945478797, 0.06272103584238461, 0.04284280285771404, 0.05672616198925035, 0.14712788803236826, 0.09979629782693726, 0.08002262708864041, 0.21422630255775793, 0.08701333589851856, 0.03513012260996869, 0.0843650544328349, 0.03018824350354927, 0.0393809171925698, 0.1324738657900265, 0.23254654450075968, 0.04120418489245432, 0.0789049102791718, 0.0827011169333543, 0.11185996513813734, 0.024240858620032668, 0.028179469418578913, 0.05280836185972605, 0.01238521996752492, 0.08491725980171136, 0.04216346377506852, 0.01308739005721041, 0.05973848767046418, 0.04929976923657315, 0.01136319779990507, 0.05474650214559265, 0.04480630338990262, 0.0178827208666397, 0.02639242700700249, 0.05010030824424965, 0.04122272925451398, 0.027015646154593145, 0.04587630222418478, 0.14260303654841014, 0.02198314360742058, 0.04228397498705557, 0.020787184924951622, 0.025966999121010303, 0.065849998300629, 0.09496493850435529, 0.044533179474196265, 0.09926672838628292, 0.028756748352731978, 0.027659977919289043, 0.03670377084719283, 0.01989538804627955, 0.012709713224986834, 0.042902588578207154, 0.0705357575789094, 0.09158333710261754, 0.0787326709500381, 0.16818504168518952, 0.22510754796011107, 0.22903078315513475, 0.2944354521376746, 20.55486978803362, 96.45460101536342, 81.77701091766357, 84.71243722098214, 108.15253257751465, 98.00130476270402, 68.16952678135463, 48.41939040592739, 44.01857164927891, 33.90931442805699, 38.3282401902335, 34.41054705211094, 33.207657541547505, 31.123260498046875, 34.14462906973702, 42.219964436122346, 40.8343894141061, 48.13649797439575, 44.28041451317923, 41.689247131347656, 53.999176025390625, 53.90258911677769, 49.38984530312674, 52.91115413393293, 55.0397104535784, 60.188179697309224, 63.28312274387905, 56.084094183785574, 59.29488454546247, 51.62434080668858, 32.792436667851035, 18.618854999542236, 26.607139859880718, 25.2108541897365, 31.275186334337505, 30.2220687185015, 32.50729996817452, 25.588257755552018, 26.423780373164586, 40.1662506375994, 25.44644328526088, 7.5597060748509, 1.5785648205450602, 0.40834677112954004, 0.10925667054419007, 0.2976609362023217, 0.18740462751260825, 0.17949969454535417, 0.10999673511832952, 0.1924965578530516, 0.2832860904080527, 0.5770690089889935, 0.2109456943081958, 0.14547418962631906, 0.03693667459966881, 0.05658384605443903, 0.005317056385268058, 1.156970060297421, 1.6733050282512392, 0.07438456426773753, 0.043262463196047714, 0.08087619700069938, 0.22658523438232286, 0.027354476008830324, 0.0943219315792833, 0.522164560854435, 0.046034349993403466, 0.06894487794488668, 0.07705802616796323, 0.5963914607252393, 0.10219504125416279, 0.7709312949861798, 3.6504940816334317, 3.7378433602196828, 41.742796897888184, 30.79408958980015, 24.556943586894445, 40.40564387185233, 27.04879515511649, 24.71819911684309, 12.783340062413897, 21.59090178353446, 18.743114846093313, 15.122615269252233, 17.737627131598337, 20.609675441469463, 19.893779958997452, 28.892999921526226, 45.65219041279384, 55.567106519426616, 56.91331304822649, 53.362543855394634, 61.76631709507534, 52.180860246930806, 47.543149607522146, 34.11557865142822, 30.579167910984584, 33.35383721760341, 34.368017128535676, 37.44415487561907, 39.97023153305054, 25.27560097830636, 21.997541631971085, 28.197620732443674, 36.99755246298653, 40.8243214743478, 50.71898705618722, 75.24693407331193, 80.95409406934465, 79.5124123437064, 61.35524082183838, 67.07681832994733, 48.20083829334804, 4.399224579334259, 0.046808130972619565, 0.1494889591953584, 0.051041975750454834, 0.05342645297891327, 0.01827043407995786, 0.031616597037230215, 0.04650457136865173, 0.07382532249071769, 0.027592073527297804, 0.04375391253935439, 0.1716304796614817, 0.0807375722963895, 0.029584211629948447, 0.082494435166674, 0.09774616533624274, 0.0714131033580218, 0.06904433760792017, 0.02946358167433313, 0.03730582818388939, 0.0810896030494145, 0.09495134066258158, 0.12416050902434758, 0.07766686885484628, 0.04735169180535844, 0.0899472331096019, 0.042399953585118055, 0.020798511370750408, 0.04569620206686003, 0.009899520581322057, 0.1698970262493406, 0.1340147102517741, 0.08920053246298007, 0.09665926758732114, 0.15677877302680696, 0.0765154492110014, 0.1749097579824073, 0.09910803261612143, 0.19217045392308915, 0.2295640573969909, 0.2941432206758431, 0.22961654886603355, 0.1745728382042476, 0.11508472317031451, 0.2233949527144432, 0.16721168320093835, 0.19863776117563248, 0.13072300116930688, 0.12612337512629374, 0.13762713569615567, 0.065229986927339, 0.17446573823690414, 0.21845767407545022, 0.10822524981839315, 0.10983288926737649, 0.20802971720695496, 0.08145688048430852, 0.2376953496464661, 0.16111453037176812, 0.34337747735636576, 0.47898367792367935, 0.47005491703748703, 0.2584840612752097, 9.845018097332545, 113.24422114236015, 114.28258773258754, 98.94643347603935, 100.93346541268485, 139.59748077392578, 108.09236812591553, 83.78451224735805, 54.725478172302246, 29.65102059500558, 42.18947574070522, 34.86130101340157, 32.58982719693865, 31.640804018293107, 40.98717335292271, 63.583208492824006, 74.99645151410783, 75.70411164419991, 61.94052233014788, 55.35572147369385, 64.19531004769462, 57.48337800162179, 53.866500173296245, 56.062672887529644, 58.8828980582101, 65.85423415047782, 69.56926223209926, 59.29919242858887, 64.83977631160191, 45.61619874409267, 24.98067774091448, 10.153713532856532, 19.148938281195505, 26.269071783338273, 32.32135227748326, 35.68305056435721, 45.72045298985073, 37.165389674050466, 33.502841336386545, 62.58687850407192, 35.75972046170916, 24.73884047780718, 2.656621801001685, 1.029412316424506, 0.14262749095048222, 0.3457644549863679, 1.0309116074017115, 0.47476785842861446, 0.18331506981381349, 0.6624484189919063, 0.6326839647122792, 0.766926038478102, 0.40795482216136797, 0.3771781564823219, 0.1063055656850338, 0.2263653754655804, 0.3137461787887982, 3.197384246758052, 1.8124389052391052, 0.11603862127023083, 0.17755970864423684, 0.208908650758011, 0.46235088471855434, 0.20634495546775206, 0.2819242977670261, 0.684129784149783, 0.09890043482716594, 0.12021366081067494, 0.2435650575373854, 0.7824015223554203, 0.17452950695795671, 0.8678307639701026, 5.037657201290131, 4.876989662647247, 47.5966020992824, 44.40512078148978, 28.538935354777745, 52.665476254054475, 43.69056109019688, 27.95993501799447, 17.67963399205889, 33.027244091033936, 13.386466281754629, 10.696749993732997, 22.26972688947405, 31.22149760382516, 34.416373116629465, 33.98156179700579, 43.795815876552034, 46.33123091288975, 50.516551290239605, 43.062982422964915, 58.80493232182094, 54.6305136680603, 58.0864052091326, 44.77312864576067, 41.81848015104021, 42.08890404020037, 35.67584875651768, 39.19040741239275, 37.62699324744088, 19.389736788613455, 17.362684965133667, 27.266193866729736, 44.05287837982178, 55.44124337605068, 75.81604712350028, 97.10014425005231, 89.31172779628209, 79.36950874328613, 77.31893553052629, 77.83879974910191, 39.05653647014073, 1.4384166151285172, 0.20913241803646088, 0.23226028414709227, 0.13074839194970472, 0.16523144660251482, 0.19419152475893497, 0.138480027073196, 0.19158008774476393, 0.2621745318174362, 0.30282171070575714, 0.17478703813893454, 0.3214162843567984, 0.17827746298696312, 0.17357778017010006, 0.2619500724332673, 0.18502993136644363, 0.21709559644971574, 0.2875233516097069, 0.2839834344174181, 0.11737226827868394, 0.17009599985820906, 0.19892783489610466, 0.28986171899097307, 0.16559477496360028, 0.13270095789006778, 0.10630222050739185, 0.09231683345777647, 0.24070736659424646, 0.21587404342634336, 0.07187329937836953], [0.07412689737975597, 0.06427734411720719, 0.046038709580898285, 0.024538681210417832, 0.030045754542308192, 0.04179259349725076, 0.05962135895554509, 0.018295482200171267, 0.03700606159067579, 0.0899714839511684, 0.08237145069454398, 0.07703034872455256, 0.04780073270999959, 0.06900811740862471, 0.06348264390336615, 0.11389413848519325, 0.09899321770561592, 0.1478359664657286, 0.1447266475962741, 0.01373043260537088, 0.03126591317621725, 0.06534231161432606, 0.1477880347520113, 0.07374537749482052, 0.045015404133924415, 0.04884030603404556, 0.006599343805906496, 0.05386305294398751, 0.1345131349350725, 0.06507870754493134, 0.46646877803972786, 0.22678757352488382, 0.3991632881973471, 0.1813569805983986, 6.470986323697226, 74.68238598959786, 88.35195228031704, 71.44253826141357, 68.30587128230503, 105.07630797794887, 103.09523064749581, 74.63105269840786, 35.600801263536724, 14.450436983789716, 11.344253488949366, 3.470850795507431, 7.533882226262774, 7.275688903672354, 7.991157940455845, 17.09644910267421, 20.88967742238726, 32.83089147295271, 41.803930623190745, 55.37749365397862, 48.66563803809029, 41.8903523172651, 41.60622658048357, 33.600967270987375, 38.15586233139038, 42.36296878542219, 34.935521670750205, 38.29592759268624, 34.32382311139788, 23.255789177758352, 21.26963792528425, 9.198811309678213, 8.394110032490321, 14.524867824145726, 20.309287445885793, 27.642065354755946, 39.371887411390034, 38.43079212733677, 23.825666529791697, 18.621206964765275, 8.617630107062203, 2.2403174425874437, 0.38399298223001616, 0.34294959317360607, 0.12388404671634946, 0.8015206307172775, 0.48278510251215523, 0.11564051120408944, 0.1709715678755726, 0.10773528646677732, 0.10228225336010967, 0.029178837846432413, 0.0336053526428129, 0.18355801249189035, 0.07806040559496198, 0.0577688565743821, 0.4132542349398136, 1.265690152134214, 0.020339065131598284, 0.005823866913228163, 0.09960815363696643, 0.035473912555192194, 0.19961681935404027, 0.14874521696141788, 0.12892830318638257, 0.052468093511249335, 0.08522165061107703, 0.24759370993290628, 0.2502009943127632, 0.08150377403944731, 0.5768269619771412, 1.5585161192076546, 1.2282378418104989, 14.28067946434021, 24.400782823562622, 22.458153350012644, 15.26096432549613, 19.338500772203716, 19.674347162246704, 12.73337643487113, 1.9949428950037276, 4.708656523908887, 12.796581591878619, 7.577554259981428, 11.432005763053894, 9.001771688461304, 15.835144349506923, 15.095248052052089, 21.132393632616314, 26.940693344388688, 19.83023520878383, 24.272484336580547, 28.429016590118408, 25.697846480778285, 20.208627155848912, 19.852384328842163, 16.710737228393555, 14.282152482441493, 14.566082801137652, 10.65828824043274, 11.581114973340716, 19.51514482498169, 30.315445559365408, 55.206682613917756, 78.82410989488874, 85.84345803941999, 69.71847479684013, 41.40702520098005, 52.2281288419451, 51.68278905323574, 19.068089042391094, 0.1829665470868349, 0.08434098001037325, 0.15980076443936142, 0.11181838451219456, 0.10292800835200719, 0.06415004416235856, 0.040175675081887414, 0.0773656400186675, 0.04845868776153241, 0.09195141520883356, 0.06683516329420464, 0.06986261691365923, 0.09818774235567876, 0.08004235888698272, 0.13901080430618354, 0.07668561900832824, 0.14786373211869172, 0.08942746849996702, 0.16275716865701334, 0.17931087182036468, 0.10897068160453013, 0.029585897789469788, 0.12116849528891699, 0.11376474864248719, 0.03433304073821221, 0.07499521864312035, 0.029434536982859884, 0.03862570432413902, 0.03743311456803765, 0.03622372767754963, 0.05413175281137228, 0.08071571668343884, 0.05582364934629627, 0.07604417271379914, 0.02376741759612092, 0.039066409426076074, 0.0875106817111373, 0.05448521527328661, 0.06087856220879725, 0.06400928207273994, 0.04966298903205565, 0.07256553401904446, 0.06741902232170105, 0.13069515409214155, 0.09214168999876295, 0.10939543095550366, 0.11964845471084118, 0.04773068414734943, 0.09975808952003717, 0.07240183744579554, 0.009948372558158423, 0.08319259341806173, 0.058839204854198864, 0.04149606690875121, 0.0782666327431798, 0.03151413146406412, 0.033325107502085824, 0.04799852227526052, 0.06246192367481334, 0.09886492030428988, 0.06452570150473289, 0.2565228236573083, 0.1114022321999073, 0.5206017589994839, 0.5211288992847715, 30.040102345602854, 98.56917408534459, 82.2492104939052, 84.06817245483398, 103.61056464059013, 97.82081140790666, 75.30181094578334, 55.70777974809919, 44.178529603140696, 34.49055903298514, 31.914385863712855, 22.868812731334142, 26.404936858585902, 30.431077480316162, 32.05483675003052, 41.779163769313264, 35.37062134061541, 41.39561973299299, 40.394221033368794, 49.85569075175694, 45.072363240378245, 41.9983412197658, 43.29742159162249, 41.074043205806184, 49.2183255468096, 56.02338777269636, 49.484306062970845, 50.48417615890503, 43.549530029296875, 25.274728979383195, 23.66232306616647, 21.44140781675066, 27.470901693616593, 31.491608824048722, 28.45651408604213, 38.597660064697266, 42.04948690959385, 35.198351178850444, 31.61218786239624, 23.052707229341777, 18.69937767301287, 2.004918553999492, 0.3825617347444807, 0.24059527260916574, 0.09030583886695759, 0.28139582755310194, 0.3337777539023331, 0.11258624188069787, 0.4753354394010135, 0.22632215278489248, 0.03196633434189217, 0.013554941397160292, 0.023060192420546497, 0.12314957327076367, 0.03115165127175195, 0.08898225453283105, 0.51067815721035, 2.126069515943527, 0.02369520620309881, 0.021071847328650098, 0.13066201444183076, 0.03040903540594237, 0.03310691438881414, 0.03524281709854092, 0.11999965086579323, 0.027845301099919846, 0.11419825788055148, 0.028570232646805898, 0.25189472628491266, 0.020359517873397896, 0.3465859709041459, 1.8392702426229204, 2.75077206322125, 22.20837082181658, 36.97863251822335, 24.270521470478602, 25.544873203550065, 24.513119561331614, 19.423638786588395, 20.486681904111588, 15.37743524142674, 13.433588964598519, 19.107692037309917, 16.53924352782113, 17.553902864456177, 22.011950458799088, 24.663294451577322, 28.540833950042725, 33.90746620723179, 39.16402857644217, 32.829199586595806, 27.97377061843872, 24.78305012839181, 22.812231813158306, 24.466601371765137, 32.09478889192854, 34.204838684626985, 27.433758360998972, 28.578512293951853, 25.57283275468009, 29.167495455060685, 31.040034975324357, 35.041210719517295, 45.342283385140554, 61.402752603803364, 74.33421870640346, 84.39153466905866, 66.63635117667062, 58.400046893528526, 65.69541222708565, 42.111186913081575, 3.3965146243572235, 0.14863001528595174, 0.2853022350796631, 0.07834476605057716, 0.04182596045679279, 0.07240478907312665, 0.0018998882982746831, 0.0456155887139695, 0.12265608832240105, 0.08928705246320792, 0.20116983673402242, 0.1131057757884264, 0.047918187121727636, 0.05818696306752307, 0.05884202755987644, 0.01574408366078777, 0.09183722455054522, 0.14649153075047902, 0.10007299083684172, 0.09839343346123185, 0.04687313802008118, 0.013924935516635222, 0.06700198791388955, 0.039684602325516086, 0.05624664129157152, 0.047872372437268496, 0.1035503199590104, 0.01449929250936423, 0.05752705383513655, 0.08758012977029596, 0.04839707678183913, 0.1916168372013739, 0.1649107030991997, 0.15995354338416032, 0.08755089848169259, 0.13391558985624993, 0.12391763419977256, 0.11013025723929916, 0.1695278896284955, 0.18928560800850391, 0.3660719767212868, 0.11826467753521033, 0.13801144436001778, 0.26031795144081116, 0.22865495617900575, 0.2326091868536813, 0.3015051899211747, 0.1326247855488743, 0.3258236407169274, 0.2008866976414408, 0.12933770407523426, 0.11045107538146631, 0.1629938009594168, 0.30446892231702805, 0.15773284754582814, 0.18421125172504357, 0.13341295825583593, 0.13994845827775343, 0.15100940689444542, 0.22883734639201844, 0.24523949197360448, 0.5989903041294643, 0.27590732063565937, 0.698461366551263, 0.2242032236286572, 14.359779494149343, 105.36970955984933, 106.95928369249616, 97.20780658721924, 94.72078227996826, 123.77391733442033, 113.83098956516811, 91.87470981052944, 69.5394822529384, 29.503972394125803, 26.68809332166399, 18.65442977632795, 17.397865431649343, 22.462902443749563, 25.53214236668178, 39.14844029290335, 46.19009215491158, 60.73469025748116, 62.61404596056257, 73.07445471627372, 62.191720553806846, 56.576731886182515, 53.92797088623047, 46.387643337249756, 48.304533209119526, 52.92517212459019, 44.89149120875767, 45.74118294034685, 40.46365090778896, 27.102817399161204, 25.836072206497192, 14.521408489772252, 18.111711195537023, 30.46359157562256, 33.72441591535296, 44.514513220105854, 57.62242882592337, 50.52924564906529, 37.48261662891933, 38.44421604701451, 37.38133273805891, 4.257428782326834, 0.6176656505891255, 0.7094726328338895, 0.12169205290930611, 2.0809904720102037, 1.8675051161221095, 1.395412802696228, 0.7912344740969794, 1.8558827340602875, 0.14985177186982973, 0.20336358116141387, 0.2683668966804232, 0.37564512874398914, 0.2516336260097367, 0.15856816486588546, 1.2491206526756287, 3.9186107345989774, 0.13285072413938387, 0.08755616391343729, 0.1773261704615184, 0.1372407235737358, 0.43217230694634573, 0.18931338723216737, 0.22951829699533327, 0.11055553584758725, 0.2958744892052242, 0.37029488012194633, 0.5501749206866536, 0.12836585193872452, 1.0359837923731123, 4.607582816055842, 2.5005229200635637, 20.210623025894165, 49.40469012941633, 46.50470658711025, 34.86795391355242, 34.85665266854422, 40.607047830309185, 32.110846178872244, 9.210398299353463, 8.310416374887739, 26.222041164125713, 24.677520888192312, 27.12401635306222, 33.61595106124878, 31.38533612659999, 30.239897796085902, 30.61529506955828, 33.842451913016184, 32.67706877844674, 34.733884947640554, 38.02967957087925, 35.104661669049946, 30.058417797088623, 36.163900647844585, 33.313054765973774, 26.58229831286839, 22.08430552482605, 21.01132127216884, 27.181964329310826, 37.03022289276123, 50.37073639460972, 71.10660675593785, 88.33665234701974, 91.37607233864921, 82.4024738584246, 65.21370751517159, 71.12312262398856, 73.74426106044224, 35.97063997813633, 1.0949926716940743, 0.14077276975980826, 0.2356517921601023, 0.1705569965498788, 0.14967329001852445, 0.07476128012474094, 0.1299450879118272, 0.12830951996147633, 0.20814733446708747, 0.2595423316316945, 0.3550606832972595, 0.21254470279174192, 0.26132297036903246, 0.1335750331303903, 0.18026932967560633, 0.17329263261386327, 0.3396429291793278, 0.25671723751085146, 0.3148690185376576, 0.42937970108219553, 0.13455426772790297, 0.06944520931158747, 0.13700145855545998, 0.21270618055547985, 0.1424024344554969, 0.18468640265720232, 0.1532847248017788, 0.1688514852098056, 0.16074155324271747, 0.11900676414370537, 0.27935794261949404], [0.03415518992447427, 0.12209970317780972, 0.04584535763465932, 0.028933011394526278, 0.08975215429174048, 0.016269693849608302, 0.060263300580637794, 0.1513571696622031, 0.05242911845977817, 0.03703067544847727, 0.16872887393193586, 0.08091169116752488, 0.1147254795900413, 0.0602970848392163, 0.019999192029769932, 0.05810283151056085, 0.032504083522196324, 0.20677256823650428, 0.005278828994570566, 0.038307780133826394, 0.05578356489006962, 0.03684793578992997, 0.08676345180720091, 0.1523399462125131, 0.0754445648885199, 0.06232055090367794, 0.15787969609456404, 0.08127449027129582, 0.11543787350612027, 0.13874069308596, 0.22486822865903378, 0.26661502782787594, 0.12157771975866385, 0.42675819460834774, 0.25815193195428165, 4.662550015108926, 82.09048584529332, 91.39656952449253, 71.57296984536308, 77.79299027579171, 101.56261784689767, 105.72276837485177, 83.18707833971295, 56.12859044756208, 18.366011789866857, 16.45449982370649, 8.162573473794119, 8.602960722787039, 3.6221536823681424, 1.4419675788709094, 4.906972876616886, 12.53316148689815, 20.634329387119838, 30.902964387621196, 40.16306488854544, 41.53439262935093, 38.73307350703648, 37.967253480638774, 31.756793771471294, 25.927701575415476, 19.07133732523237, 15.177137783595494, 18.530265467507498, 26.056969336100988, 29.537087508610316, 24.50437351635524, 9.361611945288521, 4.967914657933371, 8.0753344978605, 17.257081031799316, 27.64454586165292, 31.417721680232457, 31.57552569253104, 36.67442996161324, 7.432834574154445, 0.38171362025397165, 0.41540356246488436, 0.054889812134206295, 0.029383019211569, 0.15344133068408283, 0.4749475345015526, 0.33713346240775927, 0.09688711964658328, 0.03075540378423674, 0.03983115910419396, 0.06139033367591245, 0.017995357679735337, 0.029601449812097207, 0.05882570879267795, 0.054542693974716325, 0.10973400635910885, 1.236125892826489, 0.02896106881754739, 0.07864560133644513, 0.1521574067217963, 0.015512871156845773, 0.06169578299990722, 0.023363862286454866, 0.013699824738848423, 0.1492233398769583, 0.1196932787341731, 0.22092735155352525, 0.08942410975162472, 0.11272857817155973, 0.6080852246710232, 1.8387749663421085, 1.7771143721682685, 8.585093430110387, 16.054625783647808, 25.45977340425764, 34.84885678972517, 24.000252178737096, 8.176330038479396, 0.7440828585198948, 4.780027551310403, 12.48433996949877, 5.697529358523233, 5.087325530392783, 8.620215705462865, 8.094853724752154, 8.77045660359519, 16.24806363242013, 19.0733505657741, 16.401934964316233, 21.5367614201137, 24.470759868621826, 21.827090161187307, 22.519146374293737, 17.38181161880493, 13.050493955612183, 10.696115970611572, 10.171748450824193, 8.985941086496625, 21.458821739469254, 28.83265655381339, 45.57516963141305, 72.26714352199009, 86.55769116537911, 84.8760325568063, 60.68173108782087, 48.71456030436924, 54.37529591151646, 51.4696044240679, 15.04257549558367, 0.3012555975999151, 0.04436675858284746, 0.09779947783265795, 0.09788321583930935, 0.06118479184806347, 0.0683379622974566, 0.13311084732413292, 0.026917579184685434, 0.05575532765526857, 0.03082870252962623, 0.128380060462015, 0.08188081559325967, 0.04126389936677047, 0.2194267035062824, 0.08892031785632883, 0.1690038570335933, 0.07795300028686013, 0.03513059758448175, 0.048696290369012525, 0.11572686157056264, 0.0724539150084768, 0.026542671623506715, 0.06354408524930477, 0.07038334504302059, 0.045728032144584825, 0.0057747142605616576, 0.03174528120351689, 0.0850326514669827, 0.07378539749022041, 0.013526270748116076, 0.03717427042179874, 0.043349980642752986, 0.010709336010872253, 0.047342182137072086, 0.02210005688747125, 0.02471586875617504, 0.08742296070392643, 0.015702330008415238, 0.05337776130597506, 0.10869495889970235, 0.029936642718634436, 0.023896084799032127, 0.06799294081117425, 0.05830614774354866, 0.03407727374828287, 0.16010454456721032, 0.034517008545143266, 0.08627164284033434, 0.08506421013070004, 0.17359692842832633, 0.021199254152764167, 0.05565418183271374, 0.028034488537481854, 0.018668276124766896, 0.022700984463361756, 0.04629010341263243, 0.1676345326538597, 0.08471019127007041, 0.04697241108598454, 0.024381876856620823, 0.14922301418014935, 0.11681831228945937, 0.16476386812116417, 0.11984060225742203, 0.054706980873431475, 0.18622158813689435, 0.43873026647738045, 25.1551730632782, 91.2018323625837, 83.2166359765189, 73.54313155582973, 101.06582859584263, 106.43682779584611, 89.26850305284772, 68.6401560647147, 54.15548617499215, 35.60162462506975, 36.941678524017334, 26.402037722723826, 28.6230537210192, 25.221097571509226, 24.647374391555786, 30.29964188167027, 32.85101693017142, 39.566131251198904, 45.58926057815552, 43.08979899542672, 35.36120653152466, 31.52563762664795, 31.45800038746425, 33.33782509395054, 33.9576530456543, 28.80850808961051, 25.854295594351633, 29.38985170636858, 37.57010834557669, 41.8004287311009, 33.0896006992885, 20.72298492704119, 17.96457440512521, 24.85742712020874, 29.37202957698277, 36.530240944453645, 38.249242646353586, 31.511588369097026, 40.20092214856829, 24.392627375466482, 2.0221238136291504, 0.11858861015311309, 0.099446513024824, 0.04695548842261944, 0.3590087800153664, 0.20273696764239243, 0.48541684129408424, 0.20049569862229483, 0.019361703290737102, 0.06578424147197179, 0.05364875462172287, 0.035502224428845305, 0.03015708178281784, 0.27848130251680103, 0.034165245813450644, 0.7522723419325692, 1.9066362849303653, 0.04638254023822291, 0.027143548309270824, 0.012648744309054953, 0.06987780931272677, 0.03646774244095598, 0.048202988625104935, 0.028664962920759405, 0.02129703274528895, 0.13509142319006578, 0.021520294515149932, 0.13117337200258458, 0.13607869164219924, 0.6455608223165784, 2.190428291048322, 2.001867426293237, 13.722723484039307, 32.756413732256206, 43.47448253631592, 37.94937923976353, 32.751987729753765, 27.38817991529192, 19.826566559927805, 17.34432261330741, 18.15422374861581, 14.699211154665266, 10.516598837716238, 15.684191261019025, 16.288187742233276, 24.942850010735647, 27.05341223308018, 23.70656050954546, 16.900586332593644, 13.645583714757647, 13.51346024445125, 17.661745854786464, 31.367368085043772, 34.548892634255544, 29.959378174373082, 23.726276023047312, 21.650631972721644, 20.654463529586792, 35.185806206294465, 35.70147023882185, 38.17336136954171, 54.52910818372454, 69.68351146153041, 80.88600867135185, 73.62091663905552, 60.55612850189209, 57.374986103602815, 64.5363415309361, 31.084249837057932, 2.936156515564237, 0.1398815004421132, 0.12562870952699864, 0.04701965069398284, 0.03229421942627855, 0.09806518536061049, 0.07302887165652854, 0.047710175426410775, 0.04373231137703572, 0.03472581073375685, 0.13097167068294116, 0.10118696213300739, 0.1334114654787949, 0.03124372168843235, 0.08490667465542044, 0.04986346220331533, 0.027461643829675655, 0.05218869653929557, 0.05867326911538839, 0.02591681806370616, 0.03916035259940794, 0.01034473963747067, 0.03443022730893322, 0.02817227694738124, 0.042121041765702624, 0.034722343419811556, 0.05487784956182752, 0.02153508997123156, 0.10979765294385807, 0.10015816055238247, 0.05310444400778838, 0.02421897925835635, 0.11412987512137208, 0.27397797416363445, 0.08261989629162209, 0.09949074672268969, 0.24800055953008787, 0.15512929510857376, 0.2358766043824809, 0.25685769425971167, 0.07418832515499421, 0.24532154042805943, 0.1833867502531835, 0.26502744587404387, 0.2242850006691047, 0.21287578716874123, 0.16212841096733296, 0.17160787087466034, 0.37551286869815415, 0.20852918683418206, 0.07110287714749575, 0.16430038799132618, 0.23100762707846506, 0.13523569330573082, 0.1977498166795288, 0.23703806634460176, 0.20364357185150894, 0.15018649319452898, 0.2273281216621399, 0.12066528014838696, 0.2800676631075995, 0.3072653008358819, 0.44020211749843186, 0.3129031125988279, 0.20198912705693925, 0.24495670571923256, 0.19298475022826875, 11.37352190698896, 110.35431943620954, 106.87434891292027, 89.2088736125401, 102.95165307181222, 121.52467427934918, 120.17269379752022, 100.67829281943185, 84.34114633287702, 52.12230430330549, 39.5722074508667, 22.738580908094132, 18.953963143484934, 17.14456364086696, 19.355110440935405, 22.122122832706996, 26.7798946584974, 40.41447155816214, 50.48883145196097, 55.12951592036656, 53.8290250641959, 49.13888331821987, 50.436289174216135, 48.5005418913705, 38.30024242401123, 30.93605170931135, 26.887319019862584, 29.26587152481079, 37.753002302987234, 38.72495453698294, 28.854611124311173, 12.340900489262172, 6.768951569284711, 13.30316172327314, 27.30024872507368, 37.29200322287423, 42.88994795935494, 46.268043994903564, 58.01005492891584, 26.622867107391357, 5.011673544134412, 0.54432470032147, 0.26851400307246615, 0.10932443583650248, 0.7135601277862276, 1.659592649766377, 1.402993070227759, 0.3709135954933507, 0.29566213488578796, 0.19341636635363102, 0.20377037647579396, 0.12848460913768836, 0.182051488331386, 0.7257574189986501, 0.16493988010500157, 1.4365990098033632, 4.483553997107914, 0.13656925888998167, 0.21356455449547085, 0.2591674546045916, 0.19907870037215097, 0.16821222379803658, 0.08737785848123686, 0.1580753448818411, 0.20542307065001555, 0.2275147187922682, 0.18788256043834345, 0.1996837771896805, 0.5436253749898502, 1.8686884811946323, 5.987663550036294, 2.3484707134110585, 15.112811361040388, 28.375338281903947, 45.54625122887747, 57.76520388466971, 48.740091460091726, 31.712752614702495, 16.56110950878688, 23.325106143951416, 39.53887694222586, 24.60526830809457, 18.592809677124023, 30.754898275647843, 26.336577006748744, 28.22064879962376, 32.80348777770996, 27.785498755318777, 26.01495705332075, 31.978316238948278, 30.92105402265276, 28.779188428606304, 35.47325665610177, 30.478828975132533, 24.456712348120554, 18.83682346343994, 16.17096642085484, 20.553653853280203, 34.7583703994751, 43.794745853969026, 62.89336354391915, 82.7885296685355, 92.73258304595947, 91.7703548158918, 74.72902229854039, 67.80838721139091, 73.81985051291329, 69.83774062565395, 24.238313095910208, 1.2150825134345462, 0.20338177947061403, 0.21043525955506734, 0.1730170931134905, 0.07800420932471752, 0.13259292154439858, 0.11729468458465167, 0.12307245098054409, 0.1745589825191668, 0.1459247368787016, 0.23066844099334308, 0.18553075806370803, 0.25005367078951424, 0.36250554238046917, 0.1839013783527272, 0.22310468900416577, 0.1973435099103621, 0.14617949963680335, 0.2519042800579752, 0.17425798438489437, 0.1284966870610203, 0.05276295768895319, 0.14253199393195765, 0.14458283888442175, 0.12037374079227448, 0.26683587740574566, 0.14473800627248629, 0.2324729370219367, 0.26171494647860527, 0.21717924624681473, 0.14713898886527332, 0.1634328673992838], [0.056053367376859696, 0.032532429322600365, 0.030931059537189345, 0.030486306973866055, 0.05588742485269904, 0.02358529540444059, 0.06502121527280126, 0.10234963867281165, 0.05393627705052495, 0.13655566104820796, 0.06081670017114707, 0.02765328756400517, 0.01908502385153302, 0.041778751382870336, 0.03848859614559582, 0.06796376380537238, 0.07718240842223167, 0.15697155839630536, 0.013111468720515924, 0.03588347289977329, 0.04288087885028549, 0.08482706214168242, 0.01185753770239119, 0.095020707297538, 0.08654548600316048, 0.005692511439389948, 0.08531036227941513, 0.14214672174836906, 0.09389148253415312, 0.054371238353529146, 0.11215391329356603, 0.13214667620403425, 0.32406981768352644, 0.07903345195310456, 0.3436443858913013, 0.176582468939679, 4.338355754102979, 59.22124753679548, 99.28328214372907, 82.25369903019497, 69.81866782052177, 84.04758494240897, 114.20269039699009, 109.83326707567487, 71.25595133645194, 47.978287492479595, 31.6572573525565, 17.611807414463588, 11.921561070850917, 14.24093576839992, 7.1137837171554565, 3.7579340764454434, 7.955054232052394, 14.214735848563057, 21.117406368255615, 30.936152458190918, 40.11393765040806, 29.775775500706263, 28.890545470373972, 28.62441383089338, 32.19148697171892, 29.34321539742606, 28.334512404033116, 26.10495706966945, 25.35017078263419, 21.294005257742747, 19.71528594834464, 15.784031663622175, 4.7175767081124445, 3.993338176182338, 19.45228794642857, 30.979342460632324, 33.919260774339946, 17.540176698139735, 8.894094586372375, 0.9061411768198013, 0.1034636642517788, 0.4668147223336356, 0.1215298016156469, 0.6434399389794895, 0.25239795499614304, 0.13772400335541793, 0.05409857244896037, 0.15803276002407074, 0.040988984118614874, 0.007827541807533374, 0.07915775278317076, 0.1193452716938087, 0.31227267214230126, 0.1317370988960777, 0.5411454109208924, 0.9291436225175858, 0.16447973836745533, 0.06966415899140493, 0.05844372071857963, 0.0530841049206044, 0.13206508915339196, 0.04239739211542266, 0.2016857811915023, 0.13911177031695843, 0.072134019673935, 0.024000136447804313, 0.06752841573740755, 0.25728508989725796, 1.0898194121462959, 0.5035788895828384, 3.1165343565600256, 11.343254685401917, 26.35504010745457, 24.352385146277292, 24.66571068763733, 25.355053629193986, 25.72726341656276, 33.917561939784456, 12.713476794106619, 2.088984591620309, 5.36497163772583, 4.706119562898364, 9.096845626831055, 9.229086347988673, 12.230411972318377, 17.5727151121412, 24.903264386313303, 26.536579166139873, 27.8141896043505, 24.189807721546718, 24.226072107042583, 18.865990264075144, 13.637760043144226, 14.429441264697484, 21.72768575804574, 26.744988645826066, 40.692413398197715, 43.094169412340435, 58.638856479099815, 66.90822723933628, 69.14713832310268, 65.10067422049386, 44.787452357155935, 50.64822660173689, 61.192368098667686, 43.29885292053223, 10.86853117602212, 0.09885907133242913, 0.03291347423302276, 0.038450852635183504, 0.0178806106227317, 0.04013276452730809, 0.087986049774502, 0.02789110391001616, 0.015201985071014081, 0.04676307285470622, 0.05884689265596015, 0.07540662121027708, 0.008753496139044208, 0.04674657088305269, 0.07836711020874125, 0.1956013576792819, 0.12471565923520497, 0.015731861548764364, 0.04636044713801571, 0.13103162603718893, 0.08786466664501599, 0.010019537310914269, 0.08561435275311981, 0.028063020935016017, 0.06824713359986033, 0.09479827673307487, 0.011650265610244657, 0.03733922567750726, 0.02886399420510445, 0.09637047629803419, 0.023092041157984307, 0.04966093646362424, 0.050770833157002926, 0.03562923261363592, 0.008616218326746352, 0.14078499696084432, 0.0991331519825118, 0.03290272284565227, 0.07077807600476912, 0.02809673055474247, 0.02019578398072294, 0.03838340286165476, 0.0053158083049181315, 0.020086828220103468, 0.02377088999907885, 0.05516901911635484, 0.06986858802182333, 0.06301250055964504, 0.031538348378879685, 0.08194954440529857, 0.08481982895838362, 0.143824752420187, 0.05548857179071222, 0.05913273910326617, 0.04117869911715388, 0.0504404069589717, 0.0271882909084005, 0.025117546220176985, 0.06201461981981993, 0.030222421312438588, 0.04658780725938933, 0.05007776052557996, 0.13978706193821772, 0.029108768927731683, 0.18152204102703504, 0.1469882998083319, 0.07985438433076654, 0.08478793102715697, 0.2662845269909927, 0.3238041305116245, 24.360696928841726, 81.09667110443115, 88.33886882237026, 83.77742508479527, 96.59208502088273, 104.57052775791713, 97.43778501238141, 85.39634840829032, 64.96125861576625, 51.630861691066194, 52.875172887529644, 39.179967744009836, 40.130130427224294, 38.80700928824288, 36.42311014447893, 31.827481269836426, 32.2649051121303, 36.783645221165244, 39.16349703924996, 45.02160317557198, 45.09570918764387, 31.435533387320383, 26.28087850979396, 21.41419345991952, 20.054568222590856, 19.12706708908081, 22.264878783907207, 21.720935583114624, 29.538157531193324, 29.684333733149938, 25.64936195101057, 22.063928195408412, 19.684269189834595, 25.98249159540449, 37.25848511287144, 42.27507407324654, 48.629976408822195, 41.56498902184622, 15.361476966312953, 1.209619166595595, 0.032136653416923115, 0.08667667396366596, 0.041675631023411236, 0.4072979459805148, 0.980329807315554, 0.2723771743476391, 0.08000609797558614, 0.12784048941518578, 0.0670086850545236, 0.02226039980139051, 0.04948730953037739, 0.18099228159657546, 0.15589324411536964, 0.11533096352858202, 0.371113437627043, 0.3847561169947897, 0.13378284126520157, 0.03227146475442818, 0.13070354078497204, 0.07965972620461668, 0.11199284943618945, 0.001722458706353791, 0.16282499501747744, 0.11426125307168279, 0.05733480450830289, 0.104144920195852, 0.07215770733143602, 0.7038176134228706, 0.2052873500755855, 2.763498123203005, 3.953962734767369, 10.112451655524117, 25.617636476244243, 40.05974170139858, 46.11596529824393, 42.73617042813982, 35.11577878679548, 29.12753289086478, 20.24383020401001, 13.273300971303668, 13.116454073360988, 12.196029680115835, 19.082777534212383, 24.023447002683366, 21.277518919536046, 23.588215317044938, 22.008042097091675, 22.274955408913748, 30.8819808278765, 32.110728059496196, 36.99094820022583, 35.02718578066145, 27.860138041632517, 27.71909655843462, 28.729715517589025, 31.810878549303325, 46.04476015908377, 46.52640233721052, 50.99673087256295, 65.16154044015067, 72.99511323656354, 73.14084475381034, 62.81291730063302, 57.64475686209542, 66.87571661812919, 61.37644672393799, 22.794656344822474, 1.0290389593158449, 0.06573519017547369, 0.06287085637450218, 0.08903307002037764, 0.0379107692944152, 0.08409271083239998, 0.04159750450136406, 0.09141921305230685, 0.0698325103148818, 0.03312184215922441, 0.032816654071211815, 0.051869676514927826, 0.03350330097600818, 0.032560829405805895, 0.15757963433861732, 0.10851684345730714, 0.02937121270224452, 0.05077364229198013, 0.034755622169801166, 0.011606503494216927, 0.05689084922362651, 0.02840707720523434, 0.049061087758413384, 0.03020534258601921, 0.04873006784224084, 0.056120861255164654, 0.06025645416229963, 0.02564825051065002, 0.022182140965014696, 0.038250481244176626, 0.03423492118184056, 0.02888994138421757, 0.021517388688932573, 0.18404783335115227, 0.23296859328235897, 0.25620290796671596, 0.21574200051171438, 0.17077890464237758, 0.17182770265000208, 0.1201947975371565, 0.31663236820272034, 0.14808174542018346, 0.17582841297345503, 0.08230169729462691, 0.1308618565755231, 0.26406582604561535, 0.15461601050836699, 0.1577766401959317, 0.1452356574258634, 0.13695117911057814, 0.19365697487124375, 0.1215845729623522, 0.21048163063824177, 0.28040796199015205, 0.2337529526225158, 0.17590601023818764, 0.16947967293007032, 0.12756908897842678, 0.058411212105836184, 0.30653422006538933, 0.24087583326867648, 0.36608883153115, 0.24731988034078053, 0.25463893903153284, 0.18859058458890232, 0.3551166760069983, 0.17099108254270895, 0.4625677445105144, 0.17878812844199793, 9.147085445267813, 79.75434861864362, 114.31388241904122, 96.3193473815918, 95.39563996451241, 113.27063819340297, 131.73410715375627, 125.49048369271415, 93.49549525124687, 78.53473131997245, 69.15728964124406, 41.51574713843209, 39.07671751294817, 29.09911823272705, 24.88675546646118, 22.675268922533306, 20.321182761873516, 27.315301997320994, 34.16677645274571, 45.89337975638253, 52.06274087088448, 38.77574586868286, 37.355527128492085, 37.19792113985334, 36.308975560324534, 30.91123274394444, 27.518670558929443, 27.227966615131923, 27.791390827723912, 25.24043267113822, 28.418443168912614, 27.040434735161917, 11.248354451996939, 15.358570882252284, 35.41562829698835, 45.55336618423462, 52.74638455254691, 33.17077302932739, 18.27989407948085, 4.020872150148664, 0.23812619224190712, 0.6965793275407383, 0.4674113446048328, 1.3313897124358585, 2.529171211378915, 0.5593185329011509, 0.18521085594381603, 0.2213663908519915, 0.1468851896268981, 0.29155718801277025, 0.3005237297288009, 0.33711820894054, 0.7729500180908612, 0.21096172130533627, 0.6656674434031759, 5.081782170704432, 0.16311760645891937, 0.1480932126619986, 0.2432349638215133, 0.1920722291937896, 0.22554692652608666, 0.09355506487190723, 0.343841622450522, 0.2652483225933143, 0.1200747646923576, 0.11179435080183403, 0.15084928620074475, 0.9581046913351331, 1.8142280663762773, 2.667614068303789, 6.569339377539499, 12.995075123650686, 36.61960520063128, 40.59048679896763, 41.386805943080354, 45.32958207811628, 50.50861644744873, 70.29746123722622, 41.94068506785801, 31.745363984789165, 30.300565992082866, 34.187579359327046, 37.50944014957973, 45.482581411089214, 38.82135731833321, 40.47374664034162, 42.33886548451015, 43.122483321598594, 47.96002762658255, 40.18909284046718, 36.961178643362864, 29.16734606879098, 24.024169615336827, 27.328976052148, 34.61140557697841, 42.13299036026001, 57.70728022711617, 67.00510597229004, 86.3532543182373, 89.73685332706997, 85.46824836730957, 76.77036135537284, 63.33376816340855, 67.45190293448312, 76.79336684090751, 57.525737694331575, 14.813187667301722, 0.21163911638515337, 0.16344023628958634, 0.15653740454997334, 0.17444869343723568, 0.1057955516236169, 0.13884946224944933, 0.13494465606553213, 0.20257011588130677, 0.21283508863832268, 0.1900417674332857, 0.12248322474105017, 0.14092343167534896, 0.268686866653817, 0.245314537946667, 0.34212188901645796, 0.4513325073889324, 0.11494358788643565, 0.1498179943966014, 0.23838786248649868, 0.19215278487120355, 0.11887335058833871, 0.2276723017649991, 0.09268538653850555, 0.16461684315332345, 0.3075213799519198, 0.09450240153819323, 0.18402362322168692, 0.21344978708241666, 0.2868087456694671, 0.11666277849248477, 0.24675411784223147, 0.10233286528715066, 0.13240503519773483], [0.1512855842177357, 0.08627168355243546, 0.021676074281068783, 0.0963177609124354, 0.08879881259053946, 0.03930230551798429, 0.027784582393776094, 0.14527957221227034, 0.14124060608446598, 0.2952831323657717, 0.09112712408282928, 0.10614307011876788, 0.026627139055303166, 0.01597895346848028, 0.12342132654573236, 0.08051776087709836, 0.03130259817200048, 0.05458570630954845, 0.12542809386338505, 0.029031856983367885, 0.13535226562193461, 0.050573294649698904, 0.107485341307308, 0.10192079775567565, 0.020923794380256107, 0.016559686145878265, 0.045906181513730965, 0.06002037147326129, 0.0898673152551055, 0.03910622586097036, 0.05909684460077967, 0.08882350447986807, 0.06433529100779976, 0.3357279178287302, 0.07973334046878985, 0.1253469410751547, 0.2363096454313823, 2.854031196662358, 54.772048473358154, 90.49625669206891, 85.75626509530204, 70.8411647251674, 66.57791682652065, 93.55640316009521, 108.62050764901298, 93.14907196589878, 77.49072279248918, 54.725787367139546, 43.76211016518729, 31.819317136492046, 11.638065014566694, 13.737798469407217, 14.1748914037432, 13.730399506432668, 14.800979682377406, 14.043197853224617, 20.364143473761423, 23.888398340770177, 25.871587923594884, 30.783750670296804, 28.200195040021622, 32.26286234174456, 34.52475459235055, 35.693278312683105, 26.91715111051287, 23.460549116134644, 19.529843739100865, 19.869959797177994, 22.743658304214478, 18.90379888670785, 19.230629989079066, 28.64305932181222, 31.381038665771484, 28.646503891263688, 14.770883560180664, 2.0248963619981493, 0.5749128961137363, 0.03419771371409297, 0.8298119583300182, 1.321814117687089, 1.8675131499767303, 0.4617224527256829, 0.11182793828525714, 0.132486581536276, 0.23394155821629933, 0.13415077009371348, 0.39833276133452145, 0.43982284356440815, 0.40967865394694464, 0.048814559022762945, 0.27926661180598394, 0.7162526633058275, 0.10832082826111998, 0.033954486051308255, 0.08977065794169903, 0.04268571860822184, 0.04037151725164481, 0.018098549285371388, 0.02820268040522933, 0.17448788561991282, 0.34549990775329725, 0.19263116563005106, 0.23466056106345995, 0.22632192208298615, 0.4492000075323241, 0.6913709470203945, 4.413853577205113, 14.204810346875872, 16.80893611907959, 41.10883631025042, 41.50970220565796, 21.810753209250315, 24.19178969519479, 39.37241894858224, 24.21220350265503, 8.020243968282427, 7.496196934155055, 14.547768218176705, 20.492864063807897, 31.23822886603219, 29.860908303941997, 27.746293544769287, 28.12528477396284, 25.56692852292742, 20.281234094074794, 19.125950166157313, 17.800822734832764, 25.182540280478342, 31.63744456427438, 31.69073724746704, 39.67849751881191, 40.98071500233242, 49.68280914851597, 53.072592054094585, 49.350143296378, 49.68975387300764, 49.166373865945, 49.52301795142037, 51.35196099962507, 57.04898704801287, 23.84549147742135, 4.086940833500453, 0.07674224275563445, 0.08444041931735617, 0.11701767944863864, 0.11739894827561718, 0.04271853256172367, 0.1191163882613182, 0.1731180591242654, 0.1466294362076691, 0.06288697158119508, 0.07363442344857113, 0.057223728325750144, 0.12757869703429087, 0.1147837657481432, 0.03250688247914825, 0.10073925794235297, 0.023974774505144784, 0.08890912881387131, 0.030436465184071233, 0.047147605435124466, 0.061042326635548046, 0.0383658593387476, 0.08074204384216241, 0.03674559574574232, 0.049113898138914786, 0.013679208300475563, 0.024274346019540514, 0.030624144577554295, 0.04669520238946591, 0.04665449707369719, 0.009714763977431824, 0.02458117446596069, 0.10290808656385966, 0.07308730030698435, 0.1420316829213074, 0.14695070896829876, 0.06435997611177818, 0.03501513806570854, 0.08573025331965514, 0.050265202431806495, 0.026635228889063, 0.027058139410136, 0.07458392464156662, 0.08412954171321221, 0.09702387837959187, 0.016214754565485885, 0.07761797362140246, 0.017869845664660846, 0.020156045577355793, 0.06621019182992832, 0.06492563683007445, 0.12367167882621288, 0.09271231759339571, 0.08906540221401624, 0.06555596193564789, 0.08667429230575051, 0.057511752870466025, 0.18234099208244256, 0.09868993290833064, 0.04387978757066386, 0.018447467258998325, 0.02430410826179598, 0.05087298660406044, 0.047290657580431016, 0.05550225105668817, 0.07442440105868237, 0.10384926891752652, 0.05302758973890117, 0.10370132114206042, 0.20120057437036717, 0.14973723515868187, 0.4667812298451151, 14.4753897019795, 76.93684714181083, 89.14928586142403, 81.94757529667446, 88.11123194013322, 103.48739392416817, 103.12742859976632, 93.30830383300781, 81.50954001290458, 69.06604589734758, 58.31465353284563, 59.09373419625418, 49.20096547263009, 32.23737634931292, 38.697912148066926, 38.43145915440151, 35.49277067184448, 35.85964250564575, 36.572482517787385, 40.78364324569702, 39.74900088991438, 40.61854362487793, 38.890835830143516, 32.46142796107701, 31.95404965536935, 23.56846853664943, 27.03814356667655, 19.87662833077567, 15.937972477504186, 19.008548191615514, 21.29469312940325, 21.93182556969779, 25.793698617390223, 39.688989298684255, 49.38717719486782, 47.93533025469099, 29.39085224696568, 13.859503984451294, 3.443644255399704, 0.6047090515494347, 0.006061441955223147, 0.40749903661864145, 0.5570647109832082, 0.2626140596611159, 0.39069544257862227, 0.055456388874777725, 0.12087498818125043, 0.09293243435344525, 0.09832840266504458, 0.43319578202707426, 0.27110413408705164, 0.2652274779975414, 0.12461039131241185, 0.5128934926220349, 0.11023296708507196, 0.2474041815314974, 0.09943384477602583, 0.12763057782181672, 0.048763075178222995, 0.07025479658373765, 0.029421804273234944, 0.09025887067296676, 0.13690612438533986, 0.16656882555357047, 0.23075089656880923, 0.32890082416789873, 0.1482933262096984, 0.8684642985463142, 2.1296751967498233, 4.612814375332423, 15.492532151085989, 24.09519236428397, 30.919897147587367, 35.90751211983817, 40.351739747183665, 43.3313843863351, 48.321868964603965, 25.108906745910645, 12.620239785739354, 16.73048574583871, 16.19204204423087, 22.59137463569641, 28.005372762680054, 31.286946160452707, 31.148701327187673, 35.38058853149414, 45.57945319584438, 46.84399059840611, 41.83296367100307, 40.562732219696045, 42.447712489536826, 43.0521536554609, 43.4190810748509, 49.81535645893642, 47.85061434337071, 51.02547904423305, 63.33247579847063, 64.58970369611467, 62.78431851523263, 55.60505758013044, 52.72607149396624, 51.6469224521092, 63.690398352486746, 41.27144847597395, 11.750350509371076, 0.2602711868073259, 0.06137951782771519, 0.1139760919447456, 0.04268725888271417, 0.014805384745289172, 0.11193547251501254, 0.21439932898751327, 0.10765340764607702, 0.0518609539472631, 0.0414852307045034, 0.02455954276956618, 0.0725755084838186, 0.04218190635687538, 0.05336292513779231, 0.06925483274140529, 0.1490727322442191, 0.079895517123597, 0.014751168100961616, 0.04309548929865871, 0.07416597421147994, 0.06617698432611567, 0.08174231302525316, 0.045243602246046066, 0.07260174064763955, 0.05457715676831348, 0.07003320740269763, 0.07018382182078702, 0.009288184278245484, 0.06324110579277788, 0.07751222393874611, 0.03789790427046163, 0.027143672141911726, 0.10155697406402656, 0.04440562167604055, 0.21111565375966684, 0.23095836543611117, 0.08818245852099997, 0.19588593526610307, 0.2088005737002407, 0.12470854818820953, 0.17143318881945951, 0.2795540935226849, 0.16370951969708714, 0.4041640912847859, 0.2184119950979948, 0.1493884545883962, 0.16340951222394193, 0.10865746305457183, 0.21040467119642667, 0.1264978586030858, 0.22324108811361448, 0.263383328382458, 0.24880456924438477, 0.18247162364423275, 0.2661488471286637, 0.16589208186737128, 0.29227868786879946, 0.13413607302520955, 0.14756113264177526, 0.07134045261357512, 0.10183582481529031, 0.14345014680709156, 0.23336040654352733, 0.154752966016531, 0.1548523578260626, 0.1436382367142609, 0.152328953945211, 0.2912028298846313, 0.177072656207851, 0.21803976435746464, 0.3132508210837841, 5.108911846365247, 68.0270609174456, 106.52634143829346, 100.53919683183942, 93.95406941005162, 101.81316293988908, 120.31542369297573, 126.55333573477608, 111.28066022055489, 101.65595994676862, 89.34392574855259, 77.35945742470878, 67.19741126469204, 37.8020670073373, 33.8554276738848, 35.29147441046578, 27.575004816055298, 27.51691092763628, 28.283955574035645, 33.58824164526803, 39.352352551051546, 44.66683857781546, 46.11835200445992, 42.31394229616438, 44.03593519755772, 46.311880179813926, 45.71800722394671, 31.434855937957764, 33.53006090436663, 29.025953701564244, 30.670102460043772, 42.435716424669536, 33.88403688158308, 39.36478982652937, 54.438792024339946, 53.080867358616416, 48.73106575012207, 26.920465401240758, 10.339132291930062, 1.3954420068434306, 0.08386272817317929, 1.4083752099956786, 3.2016495721680776, 3.7006935136658803, 0.9563982571874345, 0.8113389781543187, 0.7023714110255241, 0.6812275541680199, 0.37592004399214474, 0.6515799707600048, 0.6590566667062896, 1.06324602663517, 0.6714876453791345, 1.9425595573016574, 1.3796319237777164, 0.15805884291018757, 0.24802376542772564, 0.24520903932196753, 0.17965335558567727, 0.1902855107826846, 0.19658511132001877, 0.2120753058365413, 0.358684277428048, 0.34247426582234247, 0.5755605442183358, 0.9902158996888569, 0.7311706628118242, 2.0340328088828494, 3.0550158747604916, 5.740139186382294, 20.90765414919172, 27.57478768484933, 52.47440774100167, 56.105737822396414, 36.67082732064383, 40.8439952986581, 62.401771545410156, 52.77044269016811, 34.89444044658116, 36.09947000231062, 50.80249745505196, 53.135904039655415, 56.35840559005737, 52.21282196044922, 43.38723748070853, 40.69687761579241, 48.13766527175903, 43.674486432756694, 42.14016090120588, 36.465455940791536, 44.32449388504028, 55.012317180633545, 54.98246771948678, 69.4438750403268, 64.96815122876848, 79.91298294067383, 92.11300522940499, 80.61010265350342, 71.60969802311489, 55.840309688023154, 58.57811532701765, 62.7439147404262, 68.49486228397915, 32.338062695094514, 5.674929474081312, 0.1205462243940149, 0.13173034068729195, 0.2707473060914448, 0.19917754935366766, 0.1261500958353281, 0.24225583778960363, 0.43090206225003513, 0.19186564242201193, 0.10097485887152807, 0.20874952072543757, 0.15183061068611486, 0.18384451711816446, 0.2005255270217146, 0.10919390605496508, 0.46432200180632727, 0.164649901379432, 0.18675278606159346, 0.1895527472453458, 0.25622869229742457, 0.1260997485369444, 0.1341888223375593, 0.20313514556203568, 0.15466084810239927, 0.17485315459115164, 0.18738024096403802, 0.21049758978188038, 0.10160643248153584, 0.15634225787861006, 0.06744275747665338, 0.13289606384932995, 0.12371492864830153, 0.15629823452660016, 0.160671311297587, 0.20403926633298397], [0.12857283226081304, 0.10306915720658642, 0.039289705122687986, 0.04832699768511312, 0.1392484815525157, 0.13529974701149122, 0.1650009618273803, 0.20553430968097278, 0.12337016500532627, 0.20023206062614918, 0.030263856053352356, 0.05698932161820786, 0.01438969383681459, 0.0622649449588997, 0.1671517142759902, 0.09944840613752604, 0.05215767052556787, 0.10254994221031666, 0.06758634227194957, 0.05803056753107479, 0.06018439374331917, 0.03171523567289114, 0.046597523880856376, 0.07930401100644044, 0.09611580853483506, 0.04842995519616774, 0.05466009071096778, 0.04965010704472661, 0.08239666505583695, 0.08877489423113209, 0.09282556508800813, 0.009871183262605752, 0.034442753065377474, 0.0387257678833391, 0.25338421921644894, 0.1470621379890612, 0.0707003226769822, 0.040406750182488134, 1.6257117135184151, 27.629079171589442, 82.33917576926095, 78.82672936575753, 75.27265630449567, 68.31669657570976, 71.4942398071289, 98.01312364850725, 93.09746074676514, 80.78772640228271, 60.26656927381243, 52.94728476660592, 54.47899777548653, 38.12623173849923, 38.881747586386545, 33.95286921092442, 27.86778106008257, 16.230036531175884, 10.34543604510171, 14.159263168062482, 15.60513813155038, 17.22769362585885, 17.319752046040126, 21.76100410733904, 30.92089421408517, 30.036885329655238, 26.550258432115825, 28.31913082940238, 28.995513643537247, 38.676139967782156, 51.82998316628592, 39.26458290645054, 30.932890278952463, 32.179285934993196, 33.43643740245274, 22.573427438735962, 9.332731757845197, 3.4716005495616367, 0.83652299536126, 0.3129805741565568, 0.1902825387993029, 1.3433840402535029, 0.24951825237699918, 1.0584139887775694, 2.0577737178121294, 1.1819364577531815, 1.4499481277806419, 0.08090683285679136, 0.6844344192317554, 0.8903075893010411, 0.31132570867027554, 0.033388245185571055, 0.262326360813209, 0.4849596172571182, 0.09522593021392822, 0.20022219472697803, 0.013179351908287831, 0.2733569789145674, 0.5326757739697183, 0.9660655898707253, 0.4632020933287484, 0.5111055257064956, 0.2638270631432533, 0.29517307398574694, 1.4512309389454978, 1.5868851797921317, 1.9162100340638841, 4.753424201692853, 8.297497936657496, 13.937954357692174, 17.318197386605398, 39.091093335832866, 43.949794905526296, 27.822218247822352, 25.710471357618058, 26.90534438405718, 31.64635215486799, 27.529890162604197, 25.987383127212524, 20.99566524369376, 26.37044252668108, 33.75538403647286, 33.60905497414725, 37.66842188153948, 28.685189723968506, 22.365643296922954, 23.236089297703334, 34.12329115186419, 34.808095182691304, 39.56266410010201, 41.888042041233604, 39.51561089924404, 43.97374882016863, 46.56539562770298, 39.370171206338064, 29.487307139805385, 34.34953492028372, 42.74795457295009, 53.253151416778564, 47.96439804349627, 31.229595729282924, 13.20050208909171, 0.9077786718096051, 0.12950182812554495, 0.07371474842407874, 0.13595173774021013, 0.061695633722203116, 0.0753064083733729, 0.06303760635533504, 0.13482908798115595, 0.0322409340712641, 0.03315641012574945, 0.06735274980642966, 0.09306259772607259, 0.033693687724215646, 0.057633787393569946, 0.08710742156420435, 0.14937709591218404, 0.14307429268956184, 0.23325260089976446, 0.06851412355899811, 0.06929829290934972, 0.031721529085189104, 0.06883386283048562, 0.16463996762675898, 0.017344590010387555, 0.14390290608363493, 0.12775481758373125, 0.19351092699382985, 0.07784545927175454, 0.10909558633076293, 0.13344740069338254, 0.13470161839255265, 0.10001366652016129, 0.1246366234762328, 0.18021216988563538, 0.24612701577799662, 0.2153153105505875, 0.07103553254689489, 0.025679892294907143, 0.027696028484829834, 0.06843594953949962, 0.03230730497411319, 0.0635443702340126, 0.11730258273226873, 0.04521210125780531, 0.06567387775118862, 0.11108117657048361, 0.04143531766853162, 0.02524484447868807, 0.020486298748957257, 0.07537610749048845, 0.14391138777136803, 0.16343395305531366, 0.23664362036756106, 0.13141748176089355, 0.11994501522609166, 0.018247177292193686, 0.032200537488928864, 0.07113615929016046, 0.10825330724141427, 0.1195530526872192, 0.05532832556803312, 0.049434472008475235, 0.013881233620590397, 0.05746239623320954, 0.08102029748260975, 0.018442446099860326, 0.060431149788200855, 0.02538517739490739, 0.05920249250318323, 0.0625289629346558, 0.148267623303192, 0.12539044874055044, 0.14528407768479415, 0.05442948040685483, 9.213269642421178, 54.51303700038365, 91.50863701956612, 84.25463431222099, 78.85275731767926, 93.42374120439801, 102.30769402640206, 106.81247520446777, 95.83411993299211, 86.33047117505754, 75.57274205344063, 72.29971667698452, 62.884115491594585, 46.64471626281738, 54.97054461070469, 47.568718978336875, 42.49002007075718, 31.154148714882986, 29.721159185682023, 31.445917470114573, 34.33613531930106, 37.232787200382774, 31.963516575949534, 33.923342841012136, 37.42587763922555, 28.656398126057216, 24.097018003463745, 25.971263306481497, 24.387506553104945, 25.703620433807373, 28.574166195733206, 34.80813339778355, 43.34633343560355, 47.77662297657558, 44.48776265553066, 35.14959566933768, 20.942697388785227, 7.538428953715733, 2.341721624135971, 0.3624452884708132, 0.3724471932010991, 1.730806365609169, 1.9353796797139304, 0.22954926533358438, 0.48068712651729584, 0.3571705472256456, 0.4468871530677591, 0.09567603641854865, 0.3263930401631764, 0.5556897819042206, 0.1258941659969943, 0.14125067554414272, 0.27817517465778757, 0.4210474267601967, 0.19772813070033277, 0.33238903699176653, 0.03252701800582664, 0.29609653300472666, 0.06524272981498923, 0.2897427853729044, 0.05778462572821549, 0.42057532923562185, 0.41568645728485926, 0.0904913367703557, 0.502441936305591, 0.6503793437566076, 1.3004518811191832, 2.850088093961988, 7.916133029120309, 18.689790896006993, 27.38640465055193, 46.19601549421038, 53.447989327566965, 35.37536001205444, 30.459137780325754, 48.96431677682059, 45.048867906842915, 32.020335469927105, 25.10518251146589, 37.26912975311279, 42.3973137310573, 48.66824361256191, 48.71412256785801, 43.82586683545794, 42.12248468399048, 41.101700510297505, 42.234816210610525, 50.47101974487305, 47.36655419213431, 53.7000595501491, 59.089398520333425, 50.62917116710118, 52.29779495511736, 55.37492282049996, 54.65785135541643, 46.97246626445225, 50.03018086297171, 50.653944969177246, 48.64951474325997, 54.14352832521711, 44.2753666469029, 23.155226162501744, 3.6281488920961107, 0.47427502487386974, 0.15142285185200827, 0.20695297712726252, 0.05041557936263936, 0.1766436727983611, 0.07451540617538349, 0.1276317991848503, 0.11025280066366706, 0.09090628807565995, 0.031470586479242356, 0.09066967612930707, 0.12167897075414658, 0.04417327092960477, 0.048454270498561006, 0.06278729478695563, 0.0676963192277721, 0.02757347488243665, 0.06648927328309842, 0.0380117251271648, 0.05753903676356588, 0.11730782102261271, 0.14291736111044884, 0.11004147093210902, 0.20569243548171862, 0.09654960954295737, 0.10896308201232127, 0.04293980622398002, 0.02355743645291243, 0.03373786713927984, 0.16526275420827524, 0.12472158963126795, 0.013540882151573896, 0.08989681117236614, 0.12417874804564885, 0.11453251780143806, 0.24819888174533844, 0.25650051342589514, 0.19530472931052956, 0.17813392568911823, 0.17567089785422596, 0.2431917004287243, 0.169657259115151, 0.3257757904274123, 0.3064611554145813, 0.3598673439451626, 0.1738702016217368, 0.1305960744087185, 0.12092139997652598, 0.1506751605442592, 0.171311351071511, 0.245269347514425, 0.3175619611782687, 0.22648000717163086, 0.23012395735297883, 0.21795247761266573, 0.22209387538688524, 0.1917216708617551, 0.20681174684848103, 0.21894948982766696, 0.17413740871208055, 0.09818350151181221, 0.1140299676252263, 0.12466821606670107, 0.13634873500892095, 0.1204541064798832, 0.11444301903247833, 0.12278135945754391, 0.15785670732813223, 0.15029087902179786, 0.26413674652576447, 0.18017076567879745, 0.2639620916119644, 0.13606831005641393, 2.446619663919721, 41.56650372913906, 103.73784869057792, 98.91450650351388, 91.87259060995919, 98.86611230032784, 107.50137519836426, 127.93890380859375, 119.66589219229562, 110.17272131783622, 95.28214114052909, 84.51287106105259, 78.94228485652378, 58.36055333273751, 65.06022875649589, 59.31897394997733, 51.28468854086739, 35.977657658713206, 28.3472067628588, 28.467181307928904, 27.161748545510427, 29.206638131822857, 24.208111013684952, 25.864262785230363, 30.70289100919451, 28.575578417096818, 30.200980935777935, 39.91988836015974, 45.21586091177804, 56.905023847307476, 78.03563526698521, 68.99541051047188, 59.662513732910156, 65.73177909851074, 62.68909345354353, 58.02122415815081, 31.507040773119243, 13.625631093978882, 5.583320949758802, 1.7311645235334123, 1.6580202941383635, 3.806809876646314, 2.177636657442365, 1.8632862567901611, 2.2549681535788944, 1.4367856340748923, 2.137066560132163, 0.41967808880976265, 1.3047051557472773, 1.515275199498449, 2.0207676121166775, 0.19576867084418023, 0.8425459978835923, 0.8394009609307561, 0.2472643218934536, 0.6105724626353809, 0.10598395365689482, 0.8238675573042461, 0.7064548347677503, 1.0022663559232439, 0.41587183305195397, 0.8175499620182174, 0.9824832060507366, 0.3121518114847796, 1.487540921994618, 4.073190782751356, 5.410857106958117, 6.003439000674656, 11.353820289884295, 21.867929935455322, 34.71419722693307, 54.72818796975272, 60.11977468218122, 44.62559059688023, 38.86237948281424, 45.79230431147984, 57.848148005349294, 57.05196782520839, 55.85126004900251, 57.129162311553955, 61.03091280800955, 63.78471320016043, 66.43536758422852, 66.37452915736607, 56.89252403804234, 53.347761562892366, 53.041749000549316, 60.79271466391427, 62.44904708862305, 69.83620507376534, 77.21928446633476, 71.82054110935756, 77.77035304478237, 78.75922761644635, 69.68657561710903, 54.578079087393625, 53.23917511531285, 54.37823499952044, 59.75804451533726, 58.52387074061802, 39.93587269101824, 15.52565768786839, 1.4429253446204322, 0.3551866193967206, 0.18580901170415537, 0.5190932399460247, 0.168594361149839, 0.2550005981964724, 0.13157070853880473, 0.2703550857092653, 0.1272227239928075, 0.1749973568533148, 0.11318769532122783, 0.1412605278726135, 0.16859142987855844, 0.1598750233118023, 0.25530127063393593, 0.2649944419307368, 0.2728826015123299, 0.2888682351580688, 0.22053986734577588, 0.18897527323237487, 0.17435859755745955, 0.20545159626219953, 0.28280020505189896, 0.23400857033474104, 0.42566282195704325, 0.24250057180012974, 0.3137750843805926, 0.1238808168896607, 0.15612956429166452, 0.23490589218480246, 0.2858318995152201, 0.2244046806756939, 0.18714945763349533, 0.3839549571275711, 0.3761019728013447, 0.17858782490449293], [0.34771136194467545, 0.07269127334335021, 0.038746507306184085, 0.03782303471650396, 0.10896388946899346, 0.07892669125327043, 0.22187303937971592, 0.2656684714768614, 0.21521648871047155, 0.13422996870109014, 0.1558986995369196, 0.051390403482530794, 0.03295158415234514, 0.012702811675678407, 0.18023230880498886, 0.18829620895641191, 0.15687939977007254, 0.12097581848502159, 0.12679859889405115, 0.07048937292503459, 0.05579620260479195, 0.01752593188679644, 0.0929740285500884, 0.10344349140567438, 0.04917676440839257, 0.12746539525687695, 0.0529505149461329, 0.06823360361158848, 0.06693500293684856, 0.03053278662264347, 0.07504701800644398, 0.04538444236719182, 0.09153427223541907, 0.12182591429778508, 0.21073080226778984, 0.15538043448967592, 0.13361377747995512, 0.38359981189881054, 0.10968589822628669, 0.3573687065924917, 16.407688072749547, 63.26243100847517, 91.12881374359131, 81.50880350385393, 66.70909186771938, 58.264869689941406, 72.1891986301967, 82.56483241489956, 90.7480524608067, 92.66813155582973, 70.75790446145194, 50.48826517377581, 50.24026312146868, 53.30266080583845, 51.818626335689, 45.17645072937012, 34.33667033059256, 33.55419199807303, 34.93593856266567, 39.36500869478498, 40.44605112075806, 45.67499440056937, 56.269996711185996, 63.479937417166575, 58.725861821855815, 60.44233785356794, 68.00939859662736, 61.315108026777, 54.29129566465105, 50.19940423965454, 62.171063559395925, 55.87016609736851, 35.85257271357945, 28.942158426557267, 16.94984037535531, 10.368530120168414, 6.881246617862156, 4.269960727010455, 0.6950675515191895, 0.5057892852595874, 0.3942399195262364, 0.10757151525467634, 0.2931120917201042, 0.5789565848452705, 0.7283514855163438, 0.28127542829939295, 0.7016352819544929, 0.16464870715779917, 0.20596656362925256, 0.09461397305130959, 0.4126632037971701, 0.23043133371642657, 0.13994818686374597, 0.4782153048685619, 0.18343257850834302, 0.08325899485498667, 0.6420983395406178, 0.6233843980090958, 1.2571762204170227, 0.8871279199208532, 1.4083038823945182, 0.5769047492316791, 3.8920026080948964, 5.701002589293888, 6.783481989588056, 14.368799124445234, 19.829827002116613, 20.826624257223948, 29.250470842633927, 35.39044107709612, 42.4963880947658, 40.94059262956892, 45.59150832039969, 59.79227134159633, 66.96443816593715, 66.6321336201259, 65.62162930624825, 63.80581487928118, 65.21715382167271, 61.43001038687569, 49.40442957196917, 47.694269452776226, 40.64113221849714, 31.47784791673933, 31.65529101235526, 42.737400259290425, 42.767173290252686, 39.84324278150286, 31.245243072509766, 27.437913383756364, 39.69488137108939, 36.51127583639962, 30.89163187571934, 26.87450306756156, 32.75690010615757, 46.43417542321341, 29.266792161124094, 14.261334810938154, 3.551080124718802, 0.63434827540602, 0.45221986834492, 0.08711727389267512, 0.1907911007957799, 0.15462894338582242, 0.03939331402736051, 0.07158814503678254, 0.08258172191147294, 0.03434047069666641, 0.15588915933455738, 0.032238009585333724, 0.040735534325774224, 0.04811805300414562, 0.055410930421203375, 0.14932051966232912, 0.19509783041264328, 0.21763024133230957, 0.22867295092770032, 0.17079251605485166, 0.01832692212026034, 0.07576137967407703, 0.044949162152728865, 0.14327047073415347, 0.04588647007143923, 0.06606537210089819, 0.11095364591372864, 0.3449591424848352, 0.19743360579013824, 0.14677034078964166, 0.17034110027764524, 0.10709337198308536, 0.04518937712003078, 0.10364543699792453, 0.085905736046178, 0.16726972508643353, 0.29207116471869604, 0.3927632101944515, 0.14538394446883882, 0.08839273652327911, 0.08078846920813833, 0.045996599697640965, 0.08579940960875579, 0.05076363390045507, 0.08031829193766628, 0.1421061453542539, 0.2276116135929312, 0.2012858119394098, 0.0987937691222344, 0.0660591906468783, 0.018146318150684237, 0.16472166324300425, 0.14799384799386772, 0.33496630298239843, 0.39255205009664806, 0.1266999670437404, 0.16408829151519708, 0.10316652698176247, 0.06343311084700481, 0.09430563995348555, 0.02773415536752769, 0.11048102591718946, 0.13654435665479728, 0.143374625859516, 0.015295058023184538, 0.06925804899739367, 0.07202534550534827, 0.1391198584543807, 0.07460499993924584, 0.01757544289076967, 0.08101433994514601, 0.12263183748083455, 0.08520527756107704, 0.14744773586945875, 0.12612702564469405, 0.25211079897625105, 0.19168101304343768, 3.6022538244724274, 41.681340081351145, 79.61383519853864, 94.62960106985909, 84.42390632629395, 82.02237960270473, 92.1276033946446, 103.75018869127545, 105.51819256373814, 101.72669955662319, 96.79382596697126, 79.60942309243339, 69.36597183772496, 68.13930211748395, 66.88115010942731, 66.33997576577323, 65.6035292489188, 48.23021180289132, 43.51364605767386, 36.224468094961985, 36.87029620579311, 30.91990062168666, 27.38843526159014, 30.662250995635986, 38.600178786686485, 40.560536588941304, 46.588112762996126, 49.377793652670725, 49.702312741960796, 60.242306164332796, 56.99564572743007, 51.39323329925537, 52.73543766566685, 48.92059176308768, 40.628813062395366, 25.122856991631643, 9.722419738769531, 6.776306237493243, 4.553914061614445, 0.666678460580962, 1.2230055225746972, 0.5782131818788392, 0.374428461172751, 0.7246632405689785, 0.3723087449158941, 0.3290064313582012, 0.19567674291985376, 0.9565740248986653, 1.8033111436026437, 0.7980042451194355, 0.10951445956847497, 0.55413354826825, 0.1413416535194431, 0.08145707047411374, 0.17317193480474607, 0.15560080909303256, 0.18146732396313123, 0.5589184143713543, 0.6409936302474567, 0.7147671601602009, 0.42634591673101696, 0.5723869002291134, 0.6806836947798729, 3.561758420297078, 4.333698723997388, 5.5822227001190186, 10.187266383852277, 13.841622795377459, 25.098819698606217, 32.52920069013323, 49.51079954419817, 54.62178325653076, 40.52513551712036, 43.77673612322126, 43.16038574491228, 52.33250815527779, 51.07961940765381, 53.37873663221087, 52.772787707192556, 54.24022987910679, 55.36058521270752, 53.36145993641445, 55.94536645071847, 52.92828491755894, 52.1113852092198, 51.26863472802298, 54.8573271887643, 57.54399061203003, 58.56323228563581, 52.61732176371983, 51.556818212781636, 55.20654364994594, 50.547971044267925, 45.30391195842198, 46.40283209936959, 40.89119093758719, 48.91763530458723, 41.89982271194458, 21.86801505088806, 6.188054374286106, 0.9912462958267757, 0.38369078987411087, 0.2846642221723284, 0.15244407419647488, 0.1224303940044982, 0.15313615277409554, 0.115812926952328, 0.12347982983504023, 0.1144645150218691, 0.14447149128786155, 0.1898964388029916, 0.11492005629198891, 0.07535029601837907, 0.001475616466320519, 0.006826944383127349, 0.10994718849126782, 0.057878914954406877, 0.08091491420886346, 0.16295266816658632, 0.045023200501288684, 0.044880877781127176, 0.040184903158141036, 0.06727132560419184, 0.06413000702325787, 0.04178337899169751, 0.08961995531405721, 0.06210066484553473, 0.04058536434812205, 0.12377811382923808, 0.041586356171007664, 0.051085476630500386, 0.03813045518472791, 0.07494073228112288, 0.08065595131899629, 0.16198023248996052, 0.08755870163440704, 0.12468492159886019, 0.39866323503000395, 0.2850950376263687, 0.17583285059247697, 0.21052846312522888, 0.2192468645849398, 0.1965013529573168, 0.30909498408436775, 0.25313400264297214, 0.3767505165721689, 0.25053458926933153, 0.1730820560561759, 0.11377094366720744, 0.10662820908640112, 0.22380980902484485, 0.1559292743248599, 0.3654736445418426, 0.2912584968975612, 0.12291984845485006, 0.23988704489810125, 0.16304587173674787, 0.11594233715108462, 0.1890565481569086, 0.4449417388864926, 0.29622165486216545, 0.2755577393940517, 0.23449890688061714, 0.15557661253426755, 0.13876089985881532, 0.13832437113991805, 0.19708649441599846, 0.1327088288962841, 0.12447423647556986, 0.1707647775432893, 0.20333417345370564, 0.12981620697038515, 0.12097752839326859, 0.14888510374086245, 0.30343271791934967, 0.1364517637661525, 1.0527696630784442, 24.86238465990339, 82.6545683997018, 112.4027178628104, 100.20169503348214, 91.24570328848702, 88.99671731676374, 107.85584449768066, 113.78869588034493, 124.95128958565849, 125.25719097682408, 105.84354891095842, 90.66290923527309, 86.5746934073312, 78.5014077595302, 76.41034044538225, 79.16515527452741, 59.16518252236502, 56.722425188337056, 49.72006886345999, 49.1060357093811, 44.01953050068447, 44.649322169167654, 51.611792360033306, 63.74187060764858, 67.13414791652134, 72.13720526014055, 91.68253653390067, 91.68553815569196, 90.82455212729317, 93.86794648851667, 100.55845723833356, 88.32641070229667, 64.51207842145647, 56.62946176528931, 34.144083636147634, 19.940310307911464, 16.15845618929182, 10.229215264320374, 5.244841192449842, 1.579635494521686, 0.5678967354553086, 0.5842128427965301, 2.398617599691663, 1.4641054081065314, 1.3477111394916261, 0.6684332607047898, 1.4526744272027696, 2.40212795989854, 2.638297881398882, 0.1857185358447688, 1.1769128016063144, 0.7525292081492287, 0.2676533763962132, 0.5681559901152338, 0.4068731830588409, 0.3532765161778246, 1.6426877911601747, 1.6181318802492959, 1.8463020367281777, 1.3073087760380335, 1.5525979910578047, 1.7563184137855257, 7.605948073523385, 8.362278597695486, 14.560778720038277, 17.384611742837087, 27.03536081314087, 32.024195194244385, 44.794046197618755, 53.56821053368704, 63.84697600773403, 68.22741222381592, 74.8997117451259, 75.78587804521833, 79.96373953138078, 79.96048777444022, 92.13762964521135, 94.51140526362828, 92.91723837171281, 86.61847400665283, 68.6818105152675, 72.33782754625592, 69.43383489336286, 64.43341091700962, 65.06509944370815, 72.40413420540946, 74.24823474884033, 76.21481813703264, 68.74685260227749, 68.741697038923, 66.98102351597377, 61.30184391566685, 52.23329482759748, 57.26799774169922, 49.70895174571446, 58.63916914803641, 37.020571844918386, 15.795621258871895, 3.080080198390143, 0.3658702075481415, 0.7866553940943309, 0.3461398748414857, 0.2584793386714799, 0.16600489509957178, 0.22193611599504948, 0.21109653264284134, 0.30586597163762363, 0.16898058328245366, 0.19369095590497765, 0.21155675580458982, 0.1589167011635644, 0.2088941301086119, 0.10995163289563996, 0.16275069543293544, 0.2727331609598228, 0.29419294372200966, 0.2899254469999245, 0.3157064664576735, 0.1878804298383849, 0.2033232083278043, 0.10116884524800948, 0.148076344281435, 0.08434714110834257, 0.26001301780343056, 0.21328636870852538, 0.4374462610908917, 0.2370636606855052, 0.2864329186933381, 0.25178200804761475, 0.22717642837337085, 0.22137445184801305, 0.1652734207787684, 0.2543321054961, 0.2927966815020357, 0.4460087487740176, 0.46823134060416904], [0.11699030734598637, 0.0774805499240756, 0.018420826277828643, 0.10865258438778774, 0.060738085103886466, 0.09160758794418403, 0.03426406426089151, 0.12433990011257784, 0.20367762073874474, 0.04184105786095772, 0.14882668187575682, 0.12010073901287147, 0.08281018465225186, 0.02791837423241564, 0.20547077166182653, 0.10662914546472685, 0.21665100673479692, 0.11027426272630692, 0.14423347477402004, 0.06287898522402559, 0.044519951434007714, 0.04538984689861536, 0.04708647621529443, 0.06822622115058558, 0.24685625093323843, 0.06591408593314034, 0.028103763570210764, 0.0822075777021902, 0.0713530597942216, 0.07876540347933769, 0.15190972786928925, 0.20504736581018992, 0.15635019673832826, 0.047627933589475493, 0.08594732345747096, 0.03613918221422604, 0.19168011737721308, 0.08457644523254462, 0.11845303885638714, 0.019793171834732805, 0.15353359787591866, 4.18596134866987, 39.631166390010286, 71.97750786372593, 77.4928697858538, 79.31773771558488, 70.32892268044608, 52.641911438533235, 63.82602718898228, 72.00837871006557, 75.65905257633754, 83.023038319179, 79.8728084564209, 80.00221865517753, 69.87617806025914, 55.657523427690776, 46.943356786455425, 44.56202152797154, 53.377791677202495, 62.47427599770682, 68.93592698233468, 71.30843802860805, 75.04271262032645, 79.66976124899728, 78.9379630770002, 77.21697071620396, 80.25991344451904, 71.41675349644252, 64.05517183031354, 62.217025893075125, 60.19487081255232, 57.23519877025059, 58.90656362261091, 44.49619776862008, 33.177523204258506, 28.884057589939662, 23.071681022644043, 19.331248589924403, 8.36005083152226, 3.046342351606914, 0.39532704119171413, 0.7105670283947672, 0.437090057347502, 0.4196121080645493, 0.4727197683283261, 0.14104969347161905, 0.14590751565992832, 0.39727782937032835, 0.2685321606695652, 0.5420236523662294, 0.21102182593728813, 0.2455388344824314, 0.5799863295895713, 0.5257502113069806, 0.1467965729534626, 0.361063899738448, 0.1823777143976518, 0.9332741094487054, 1.3548846117087772, 0.7189305424690247, 2.0172796164240157, 2.136705905199051, 1.3255911150148936, 4.595475145748683, 10.513261096818106, 15.769412653786794, 13.874163814953395, 18.873398780822754, 35.804849011557444, 37.21604898997715, 23.670026881354197, 25.064672776630946, 33.467766829899375, 43.37667621885027, 53.896092551095144, 72.70481055123466, 83.87158012390137, 91.5316355569022, 89.58618858882359, 75.87983853476388, 68.1905381338937, 61.513159479413716, 43.89849635532924, 39.88172885349819, 38.29382923671177, 40.67132908957345, 42.245269775390625, 30.44028036934989, 25.082441057477677, 27.976786136627197, 33.4870411327907, 32.78233051300049, 38.772987433842246, 27.6689635685512, 19.21620031765529, 12.667709009987966, 4.559824373040881, 0.083830043141331, 0.46385989231722696, 0.24618735111185483, 0.18796515172081335, 0.04950793020959411, 0.1035578991951687, 0.07571819770549025, 0.015455794487414616, 0.07857143067355667, 0.10327910272670643, 0.14639334673328058, 0.10784942962761436, 0.05140270871509399, 0.08207708863275391, 0.009866293569627618, 0.11784446079816137, 0.16554469907922403, 0.05671726978783097, 0.14610967838338443, 0.14005717315844127, 0.11656052326517445, 0.06525204610079527, 0.03672456455283931, 0.086089374763625, 0.10034506980861936, 0.06333551715527262, 0.10491088445165328, 0.16494353062340192, 0.2747896648943424, 0.16370976396969386, 0.0961806493412171, 0.05596614170021244, 0.0903367597077574, 0.05567043274641037, 0.018885023958448852, 0.0377664856080498, 0.13012947301779473, 0.27897006486143383, 0.1970013247004577, 0.13437237963080406, 0.04837055963331035, 0.015702782930540185, 0.0745938787502902, 0.12215340243918554, 0.06297121848911047, 0.1446088674877371, 0.04874419154865401, 0.3414907700249127, 0.09164583696318523, 0.0404007926450244, 0.060619626460330825, 0.06264902970620564, 0.05375538979257856, 0.25635712540575434, 0.2941793458802359, 0.36660242825746536, 0.2252382609461035, 0.23209350023950848, 0.0746926734490054, 0.06097463598208768, 0.048469127022794316, 0.16265255212783813, 0.06134403044623988, 0.17157945382807935, 0.13753295503556728, 0.23545577696391515, 0.06601397307323557, 0.0871466069615313, 0.09429107859198536, 0.1618943028151989, 0.10439386790884392, 0.1773978644715888, 0.07706290483474731, 0.13688808892454418, 0.02751302419762526, 0.21040577042315686, 0.1701757005814995, 0.07727404457650014, 0.13709025164800032, 1.5756469028336662, 21.35938606943403, 70.80130985804966, 92.27029854910714, 88.40574523380825, 77.65431118011475, 77.69182450430733, 81.30697223118374, 90.3112678527832, 93.88776275089809, 100.68972955431256, 103.08412742614746, 93.45894772665841, 85.5274817602975, 72.5306817463466, 69.79947689601353, 63.479207856314524, 57.34944799968174, 58.98739896501814, 60.826552391052246, 62.55277674538748, 63.195283617292134, 67.62932518550328, 69.95932715279716, 75.37041051047188, 74.15652547563825, 80.57105377742222, 82.83745888301304, 81.72653225490025, 84.80935069492885, 90.63186468396867, 85.50594234466553, 67.87099742889404, 48.54362767083304, 31.787946019853862, 22.129256895610265, 16.008019004549297, 9.642482451030187, 2.947694433586938, 1.1691501438617706, 0.4155179634690285, 0.4912012166210583, 1.1491328179836273, 0.6574263913290841, 0.527691798550742, 0.2874835894576141, 0.12094888064478125, 0.9903661544833864, 1.3485641394342696, 0.31819153310997145, 0.3169172986277512, 0.06348193822694675, 0.10083551492009844, 0.3504187709518841, 0.045196477989000935, 0.6165434079510825, 0.6194294073751995, 0.5843870905893189, 0.40939722476261003, 1.010696257863726, 1.988466739654541, 2.091267943382263, 4.159276791981288, 7.488008482115609, 10.313470857483999, 15.225646632058279, 24.987950767789567, 33.271980490003315, 46.74471473693848, 48.964667660849436, 47.962862491607666, 41.91288879939488, 51.21406705038888, 64.82924979073661, 73.60490798950195, 73.78519289834159, 80.33081981113979, 85.02104146139962, 87.65606934683663, 75.04431765420097, 67.54732949393136, 64.57429953983852, 62.25767285483224, 58.5294223512922, 56.245942047664094, 61.83456924983433, 69.48144395010812, 57.74355329786028, 53.30725703920637, 63.51485906328474, 55.929861545562744, 50.351555892399375, 46.57349027906145, 46.39864233561924, 33.22361407961164, 23.377514668873378, 7.263510882854462, 0.7709102875420025, 0.1951207106134721, 0.6152719961745399, 0.5553022027015686, 0.247251674000706, 0.2183309101632663, 0.1218251543385642, 0.09786561464092561, 0.1775851265660354, 0.08397309189396245, 0.10125864935772759, 0.12568348087370396, 0.11313789763620921, 0.1222859610404287, 0.2054247534168618, 0.030736075714230537, 0.025416330633951083, 0.04673045228368469, 0.08392429844077144, 0.17662713011460646, 0.08212822981710945, 0.02561903788175966, 0.050755532192332406, 0.09571239232484784, 0.060582510594810755, 0.12100537547043391, 0.16418087083314145, 0.13607722600655897, 0.15027468917625292, 0.07746552037341253, 0.04894612017752869, 0.06255368875073535, 0.020480536290311387, 0.03027148957231215, 0.00806661683600396, 0.03058831114321947, 0.046276444502707036, 0.08109224255063704, 0.024269815101953487, 0.26973460614681244, 0.16513874514826707, 0.12861453502305917, 0.16710375542087214, 0.17422777600586414, 0.42032134000744137, 0.19639244808682374, 0.24029970275504248, 0.3132119545979159, 0.19025545168135846, 0.1848361146237169, 0.1129065714776516, 0.14779749353017124, 0.21642299182713032, 0.37756006313221796, 0.28295830371124403, 0.41225933975407053, 0.18572294632239, 0.24504011124372482, 0.1686834120856864, 0.258525261921542, 0.18654936126300267, 0.26615660956927706, 0.19021368106561048, 0.5459294627819742, 0.27699180958526476, 0.2766641043126583, 0.18580109998583794, 0.18162595187979086, 0.12903274329645292, 0.3768581322261265, 0.26068949007562225, 0.2916616281228406, 0.26508316716977526, 0.12810115542794975, 0.12146205667938505, 0.27608905945505413, 0.20199435177658284, 0.09618594191436257, 0.16979858438883508, 0.2893198680664812, 8.75150191783905, 56.00109447751726, 96.9121537889753, 103.38148253304618, 94.07825456346784, 85.77721391405377, 78.93733079092843, 96.11357648032052, 100.5466730935233, 113.47342831747872, 127.28881645202637, 113.09510585239956, 114.67741216932023, 100.61197226388114, 94.35627978188651, 86.91134057726178, 76.14639922550747, 71.96755109514508, 71.64077036721366, 74.3119010925293, 75.44659750802177, 81.1485116141183, 83.85459177834647, 94.46192714146206, 100.62265859331403, 108.91174834115165, 114.59507601601737, 115.4690134865897, 113.13279288155692, 99.43926225389752, 87.25606155395508, 78.16724804469517, 63.071654319763184, 47.9416948046003, 46.1196026802063, 31.85062571934291, 22.65300168309893, 8.94667855330876, 3.9188052841595242, 1.6543540337256022, 0.8800948230283601, 1.8906156931604658, 0.8872670467410768, 0.9089245274662971, 0.5676927949701036, 0.14889464394322463, 1.2918450172458376, 2.6943400970527103, 0.8433634425912584, 0.5325157482709203, 0.9453925277505602, 1.4847328726734434, 0.5550351313182286, 0.07343595874096666, 1.0333837547472544, 2.0954472848347256, 1.7266678448234285, 2.862326042992728, 1.7122978844812937, 2.6985543966293335, 4.519977756908961, 6.3756236008235385, 8.766701970781599, 14.836594411305018, 21.809137753077916, 24.742816584450857, 35.86934913907732, 54.163914339882986, 56.44942699159895, 41.00110796519688, 40.51051998138428, 54.23880202429635, 69.06338473728725, 80.94845908028739, 86.06844765799386, 95.17119925362724, 100.28359345027378, 106.60350813184465, 91.35465104239327, 91.27725505828857, 87.53346838269914, 82.23186084202358, 78.61260672977993, 77.8095200402396, 78.96337958744594, 87.19464642660958, 67.70797879355294, 62.23069994790213, 73.16995075770787, 64.33095278058732, 54.94985982349941, 57.50958660670689, 50.35928923743111, 33.44559860229492, 15.757753576551165, 3.891156230654035, 0.2662193333464009, 0.6572753765753337, 0.8685311206749508, 0.46993837186268395, 0.3244264285479273, 0.3070504223661763, 0.2132856087493045, 0.09012146733169045, 0.24997154091085705, 0.16153742053679057, 0.31082117717180935, 0.26989702028887613, 0.14271046221256256, 0.19397148942308767, 0.23187783466918127, 0.22932857860411915, 0.1524237317166158, 0.2091482686144965, 0.15382707784218447, 0.3249567172357014, 0.1481109902794872, 0.14843819343617984, 0.09695565846881696, 0.1955891169075455, 0.14872205177588121, 0.22402049414813519, 0.1959861684590578, 0.25150541003261295, 0.26150218503815786, 0.3224920337753636, 0.3277981776211943, 0.22489420297954762, 0.31590674285377773, 0.1790255614157234, 0.09671916187341724, 0.18747196532785892, 0.2201795923922743, 0.2776401905076844, 0.16919183837515966], [0.09879255454455103, 0.03272905859297939, 0.12034624655331884, 0.03958225888865335, 0.12678367112364086, 0.17288646155170032, 0.02749806589313916, 0.031285739969462156, 0.07200057219181742, 0.12120357554938112, 0.18482354815517152, 0.1829265813742365, 0.25970566858138355, 0.08276702982506581, 0.05215018967698727, 0.1253483931400946, 0.040266537706234624, 0.17034743779471942, 0.2383481003344059, 0.1358813058052744, 0.022228383126535585, 0.056807114609650204, 0.02987668736438666, 0.052187559993139336, 0.07385275566152164, 0.08538557110088212, 0.10527547488787345, 0.018410517634557824, 0.07222913671284914, 0.20633194116609438, 0.34102374794227736, 0.2322477176785469, 0.04128555481189063, 0.029753652002130235, 0.0976825255368437, 0.21828569258962358, 0.08939657480056797, 0.05682862077706626, 0.14415811667484896, 0.13514608597116812, 0.07127105205186776, 0.4916466070072991, 0.7616722232529095, 15.926045894622803, 43.842191628047395, 75.72371251242501, 81.01682935442243, 65.23000798906598, 64.76390893118722, 56.02199118477957, 58.226710183279856, 65.29245839800153, 73.56061322348458, 79.11584390912736, 68.37939017159599, 53.304748739515034, 43.91507475716727, 49.41444540023804, 67.39740126473563, 67.06297751835415, 80.83232688903809, 77.37015765053886, 73.68824468340192, 75.2076975958688, 71.65577152797154, 72.63004793439592, 69.5026637486049, 66.72027846745083, 65.42261205400739, 74.64232962472099, 71.03614507402692, 83.61002213614327, 80.87261254446847, 58.69027314867292, 43.700059277670725, 36.7844512122018, 36.25657572065081, 19.66068352971758, 13.406094942774091, 8.74214790548597, 7.996305687086923, 2.74203730906759, 0.4958770828587668, 0.16502217283206327, 0.4359873565179961, 0.1845692332301821, 0.18385991986308778, 0.08146500933383193, 0.3675803600677422, 0.22126040368207864, 0.28675636276602745, 0.4373588114976883, 0.5183890834450722, 0.6960898052368845, 0.40543078045759884, 0.45715287221329554, 1.0835134876625878, 0.370423964623894, 1.8428370569433485, 3.0327169341700415, 0.308295018438782, 0.9774849542549678, 2.0174602695873807, 6.158399896962302, 12.580958145005361, 13.218620385442462, 22.130415507725306, 41.64136709485735, 58.54492378234863, 49.22499581745693, 26.2372316632952, 13.513604419572012, 10.790356993675232, 9.382978524480547, 24.638657876423427, 38.10656138828823, 47.05370807647705, 55.99293729237148, 61.2959657396589, 57.58633293424334, 48.42024850845337, 36.86526223591396, 26.744427578789846, 23.047965083803447, 26.904427221843175, 20.957847935812815, 22.931287458964757, 20.163145984922135, 21.21765845162528, 15.028560979025704, 24.326556955065044, 30.765980652400426, 18.460776533399308, 8.57212027481624, 2.105263786656516, 0.512027627655438, 0.169527726780091, 0.4250737449952534, 0.3218795337847301, 0.18599854010556424, 0.07654510119131633, 0.10226355293499571, 0.18573483425591672, 0.11869952348726136, 0.036201492084988525, 0.05417172870199595, 0.09718000250203268, 0.06998625956475735, 0.023452456907502243, 0.07748445150043283, 0.06450467370450497, 0.0016696484318734811, 0.12034970708191395, 0.05317624658346176, 0.12285522477967398, 0.17974946328571864, 0.02418141047071133, 0.07367987850947039, 0.0498989190507148, 0.08064297094408955, 0.08280546204852206, 0.03135947297726359, 0.06527557769524199, 0.07788740630660738, 0.08575199358165264, 0.10186935123056173, 0.062438995976533206, 0.1134967544515218, 0.02799414623794811, 0.1440567435430629, 0.092581339978746, 0.07261262434933867, 0.09642461660717215, 0.10780448346797909, 0.05858670161770923, 0.12811882447983536, 0.019829980663156936, 0.06067207043192216, 0.06250067480972835, 0.09144638837980372, 0.16764617631477968, 0.18756307901016303, 0.2120100986212492, 0.07664620969444513, 0.14646482361214502, 0.09510133082845382, 0.03134111181965896, 0.059164352049785, 0.07605115483914103, 0.03583636899877872, 0.26151076172079357, 0.2423131332865783, 0.21889375496123517, 0.23491729157311575, 0.18899191091103212, 0.10228080129516975, 0.051218313431101184, 0.058219084915305884, 0.002856439258071727, 0.023833852959796786, 0.07034563206668411, 0.07530157720404011, 0.1449445387614625, 0.14493932761251926, 0.19233379087277822, 0.24701741657086781, 0.27670777482645853, 0.15070973868880952, 0.0985654013763581, 0.03151341560961945, 0.10069826764187642, 0.14863598639411585, 0.07959563857210533, 0.12263350667698042, 0.11782044065850121, 0.12559865042567253, 0.04490254001159753, 1.499364693249975, 6.175203246729715, 39.295095920562744, 67.39575454166958, 81.22186374664307, 84.18097645895821, 73.36446557726178, 81.2388242994036, 86.68023654392788, 89.0443194253104, 89.46080834524972, 84.62381989615304, 88.94888591766357, 84.26659216199602, 71.27551746368408, 67.9943904876709, 64.87112658364433, 67.82849529811314, 67.16410160064697, 75.14651870727539, 78.77745968954903, 79.33358655657086, 79.65649713788713, 79.74624007088798, 85.24831008911133, 91.18327372414726, 92.53468445369175, 93.10450622013637, 94.01909760066441, 85.54057216644287, 77.14214556557792, 68.38009888785226, 56.4369341305324, 40.69283723831177, 35.85365315846035, 29.324090480804443, 24.598346165248326, 10.853606445448738, 4.871395928519113, 1.6822800380843026, 1.1099917697055, 0.35347003436514307, 0.35027456868972096, 0.851906632738454, 1.002726782645498, 0.10577041190117598, 0.12025593354233674, 0.6494433996932847, 0.5249283154095922, 0.28847395202943255, 0.4748263752886227, 0.28660518516387257, 0.8434996381402016, 0.5595560744404793, 0.08572329155036382, 0.5173628128000668, 1.8736718595027924, 1.2436454721859522, 0.8958912811108998, 2.053258474384035, 3.0307429943765913, 4.955488673278263, 6.82278881754194, 12.673469935144697, 21.4119804586683, 24.6339522089277, 36.11590249197823, 55.226783752441406, 59.02965096064976, 42.15069089617048, 33.01659597669329, 33.92220681054251, 43.148511273520334, 58.553852217538015, 66.64938599722726, 73.21759455544608, 76.51996912275041, 74.1544827052525, 74.05467878069196, 69.7536187853132, 66.90758800506592, 61.61267852783203, 55.44930328641619, 58.64022527422224, 58.02611568995884, 54.03996889931815, 49.64894710268293, 46.36937999725342, 37.50739043099539, 37.52593517303467, 36.07156951086861, 33.56748390197754, 15.478896311351232, 6.830795747893197, 1.2549735328980853, 0.3856695879782949, 0.32975490976657185, 0.3582491193498884, 0.25861765124968117, 0.10159506701997348, 0.23979758684124264, 0.2796603521066052, 0.19760484088744434, 0.02898088882544211, 0.04257914111284273, 0.05256974484239306, 0.13982268502669676, 0.05035809387585946, 0.040933334069060426, 0.08269631290542227, 0.08881129763488259, 0.04329590140176671, 0.05896852684340306, 0.07850965684545891, 0.01891779380717448, 0.05136104327227388, 0.09970911286239113, 0.024128230288624763, 0.06540681993854897, 0.12644048168190888, 0.07169942477984087, 0.07059610648346798, 0.07367416524461337, 0.04515740454995206, 0.029139150333191668, 0.0944316778331995, 0.05225489441571491, 0.09085431229323149, 0.0680509012724672, 0.0789383484848908, 0.050528752218399725, 0.04480255787659969, 0.0681507069883602, 0.08433775018368449, 0.01762142720898347, 0.19522240944206715, 0.1285502506153924, 0.152292313054204, 0.1449470764824322, 0.33534362273556845, 0.2942830260310854, 0.25685905132974896, 0.17854392368878635, 0.18302020563610963, 0.1987164169549942, 0.12915753945708275, 0.28565985017589157, 0.27790283784270287, 0.1653702070138284, 0.2590217324239867, 0.2973351308277675, 0.20816055232925074, 0.2174480411091021, 0.24211014275039944, 0.2492835335433483, 0.1326834245451859, 0.1502158466194357, 0.21363444360239164, 0.3600400989609105, 0.2400146366230079, 0.2831106755350317, 0.2402138002216816, 0.22272876703313418, 0.17191346947635922, 0.2845770168517317, 0.280770761093923, 0.22433423517005785, 0.19309315298284802, 0.1303948616342885, 0.187198420720441, 0.2297365138573306, 0.16371489369443484, 0.16554142854043416, 0.19654205148773535, 0.2292638463633401, 0.1396184866981847, 0.5907072371670178, 1.3085306818996156, 22.176768677575247, 56.35825620378767, 85.78499589647565, 99.65517057691301, 84.68829223087856, 92.8038020815168, 90.04752118246896, 93.55350576128278, 91.53982748304094, 100.06835910252163, 106.96243817465646, 106.70269366673061, 95.3343915939331, 94.03583581107003, 85.9529755456107, 89.36009420667375, 83.21143872397286, 93.72107546670097, 97.10713413783482, 97.45475946153913, 95.87111909048897, 93.00732176644462, 100.77840246473039, 101.70802974700928, 103.72203459058488, 100.55027226039341, 104.03548867361886, 87.01885005405971, 88.84243951525006, 87.09373773847307, 68.13716207231793, 56.464122431618826, 58.62589808872768, 50.56166246959141, 40.51883002689907, 21.66354172570365, 17.18640742983137, 10.403850419180733, 2.022560247353145, 0.5458087378314563, 0.6333623911653246, 1.2055717323507582, 1.411617847425597, 0.3849973497646195, 0.2688599202249731, 0.6203638315200806, 0.9972154498100281, 0.32890722953847473, 1.5294916480779648, 1.1463836112192698, 3.1525475212505887, 1.356114877121789, 0.5015230370419366, 1.9109361342021396, 4.344425005572183, 6.044594049453735, 4.3871108293533325, 4.743073122841971, 4.0507203085081915, 6.979125457150595, 12.650998592376709, 27.011460747037614, 29.781393119267054, 44.732339245932444, 61.41844163622175, 78.4675074986049, 67.63898318154472, 51.6074983733041, 37.35414791107178, 34.11621788569859, 40.18539292471749, 60.78844846997942, 68.50952993120465, 69.33208547319684, 69.32778453826904, 72.35857486724854, 77.16526222229004, 80.05423286982945, 75.79800959995815, 72.76059763772147, 66.10804489680699, 70.268417767116, 64.91578960418701, 57.45111404146467, 53.71501554761614, 52.40825046811785, 38.17829459054129, 41.124646936144146, 40.69676297051566, 28.635574374880107, 12.892478891781398, 3.689522547381265, 0.8153173103928566, 0.223697782893266, 0.379645581224135, 0.31467023491859436, 0.3021387516387871, 0.13967661000788212, 0.32204737620694296, 0.31417824274727274, 0.23698299644248827, 0.12422602836574827, 0.2226652425846883, 0.30313144837106976, 0.2969975732266903, 0.24879032000899315, 0.26436527712004526, 0.157118434086442, 0.22485317875232014, 0.22215265009020055, 0.21842382874872002, 0.20548310742846557, 0.22179745057863848, 0.12522468263549463, 0.20438863044338568, 0.19812942988106183, 0.24776920623012952, 0.165072520130447, 0.1291676496288606, 0.13517630792089871, 0.1500856221786567, 0.1762036292680672, 0.1783919318446091, 0.2765943237713405, 0.2440743116395814, 0.16796879257474626, 0.36741696883525166, 0.23826092215520994, 0.19709782595080988, 0.19073806649872235, 0.18145470321178436, 0.1788452746612685, 0.21647971735468932], [0.025344914823238338, 0.05125357689602034, 0.00478505524474063, 0.04021756104858858, 0.0563099520014865, 0.13476416575057165, 0.08131780116153614, 0.08120771564011063, 0.04956997884437442, 0.008121671471079546, 0.08200684668762342, 0.14530842352126325, 0.09496796477053847, 0.07714573360447373, 0.08939401672354766, 0.09429383344416108, 0.028047706399645125, 0.06676498241722584, 0.08384416345506907, 0.0600162459803479, 0.14341398089059762, 0.15634543342249735, 0.13573125457125051, 0.07272686250507832, 0.10447360934423548, 0.12747744603880815, 0.07490290395383324, 0.07033892814069986, 0.03078325086140207, 0.13229668672595704, 0.11385010156248297, 0.19031034516436712, 0.039790409683649025, 0.013023750257811375, 0.03363971704883235, 0.07543923838862351, 0.017902184643649628, 0.11072567171816315, 0.12596250804407255, 0.07335595946226801, 0.2634981907904148, 0.08683456906250545, 0.4485757824565683, 0.2015175859310797, 2.1081572771072388, 13.442190834454127, 27.817797456468853, 48.60073144095284, 70.3783243724278, 59.26078973497663, 66.87105437687465, 62.469599860055105, 57.42214352743966, 56.5766658782959, 46.229224409375874, 43.22835302352905, 30.910662991659983, 43.598751068115234, 48.83928394317627, 51.665936197553364, 49.62731736046927, 47.56675958633423, 39.041003772190635, 37.715047768184114, 43.566157068525044, 38.06250980922154, 34.28470822743007, 40.10774680546352, 44.203352042606895, 48.425577776772634, 55.78088869367327, 50.107455253601074, 52.44800111225673, 59.71126924242292, 57.522333077022004, 56.07451956612723, 53.38404505593436, 32.91509321757725, 28.30914626802717, 25.247564996991837, 19.871510982513428, 5.839502768857138, 0.6117095244782311, 1.1649633113827025, 0.26818200945854187, 0.3343630310680185, 0.09297840510095869, 0.21241085497396334, 0.13221214126263345, 0.5718025458710534, 0.18587523672197545, 0.3545569660408156, 0.2317755115883691, 0.49348706539188114, 0.4260106932904039, 1.0789065062999725, 0.6788682064839772, 1.448237459574427, 4.2025788341249735, 4.340069787842887, 1.7134283781051636, 4.045972517558506, 8.594593354633876, 22.33266540936061, 36.06384311403547, 39.29649945667812, 54.6974595614842, 62.943112645830425, 72.56241416931152, 66.08788122449602, 50.90430246080671, 26.698499986103602, 14.688679422651019, 13.525468468666077, 10.195056182997567, 11.021204812186104, 13.063647764069692, 20.95501480783735, 20.366809844970703, 22.961140394210815, 19.587869882583618, 14.94513395854405, 14.235712460109166, 9.462806378092084, 17.31017221723284, 13.812997954232351, 11.625015429088048, 15.706041608537946, 12.54837109361376, 10.341958471706935, 9.060887830598013, 4.384022355079651, 1.5124077647924423, 0.21689578145742416, 0.12595196360988276, 0.15005633660725184, 0.3987591527402401, 0.23019704914518765, 0.09135608893952199, 0.08620983508548566, 0.09330703996654068, 0.17469496093690395, 0.031411489471793175, 0.05286755046940275, 0.06915338497076716, 0.08771253230848483, 0.02524478849954903, 0.13086530353341783, 0.038794852926262786, 0.0794007701000997, 0.11199337190815381, 0.11179943302912371, 0.16023204129721436, 0.07712510613990681, 0.0952285493591002, 0.06760345492511988, 0.03436103030773146, 0.055166664599840126, 0.07844506709703378, 0.07216642650642566, 0.033559924723314385, 0.0618106589785644, 0.039225366432219744, 0.08982848948133842, 0.06339675494070564, 0.08045707949038063, 0.06489042086260659, 0.12177746689745358, 0.08261664610888277, 0.06956198518829686, 0.09958907323224203, 0.08410168106534652, 0.10139719942318541, 0.08002294600009918, 0.0931092741500054, 0.11387399956583977, 0.03282812809837716, 0.05187329310657723, 0.04099006977464471, 0.042544298339635134, 0.07054332324436732, 0.1636767600263868, 0.17717861623636313, 0.0706274276599288, 0.10425168089568615, 0.11831217498651572, 0.021354287530162504, 0.08075427782854863, 0.03508802629741175, 0.1093583625874349, 0.09904401962246213, 0.12678288402301924, 0.3369209180985178, 0.08703371909047876, 0.13922606275549956, 0.12263805286160537, 0.16983052981751307, 0.038252856116741896, 0.07075209489890508, 0.189681668898889, 0.10244932903775147, 0.16309513337910175, 0.12057640563164439, 0.22183129590536865, 0.1853810189557927, 0.16828469133802823, 0.3149874364691121, 0.22279029658862523, 0.1840002273342439, 0.005709090594401849, 0.023969532822125723, 0.044668917012001784, 0.03694342941577945, 0.0037120233589251128, 0.07355116720178298, 0.022309176291206052, 0.09777918285025017, 0.1606319019837039, 0.5916236394218036, 0.7219905182719231, 8.050526823316302, 33.28471653802054, 54.06588568006243, 65.76237201690674, 78.90309006827218, 74.42566394805908, 82.1248585837228, 86.28467559814453, 90.33322416033063, 88.67054108210972, 84.29826205117362, 82.09932395390102, 66.07460321698869, 59.40582643236433, 60.06859425136021, 59.68715899331229, 60.97209630693708, 58.954964773995535, 57.318125520433696, 60.695460728236604, 65.79436847141811, 68.84739303588867, 74.61063889094761, 79.89339596884591, 79.33775547572544, 80.93520191737584, 77.12589372907365, 76.75880650111607, 78.62013857705253, 60.35426943642752, 48.93411643164498, 45.24272264753069, 47.300820759364534, 33.04871055058071, 26.903534378324235, 18.976728916168213, 10.065254279545375, 6.4385586466108045, 1.4357246224369322, 0.6912431653056825, 0.05676434654742479, 0.12774222397378512, 0.39159941407186644, 0.15383565452482018, 0.6983518238578523, 0.9297850281000137, 0.17361146264842578, 0.288245828556163, 0.45592027263981955, 0.9767473595482963, 1.9280908022608076, 1.7098207431180137, 0.19184107945433684, 1.2777247577905655, 3.278429772172655, 4.211747416428157, 1.6295826200928007, 0.7369953159775052, 4.089628917830331, 11.65659499168396, 24.681269441332134, 25.913713114602224, 34.711480481284006, 48.232560294015066, 67.73078972952706, 66.29059491838727, 58.167136328560964, 43.75582551956177, 36.68111412865775, 35.12285900115967, 37.06171212877546, 45.72546264103481, 47.694380623953684, 51.62029695510864, 55.031515053340364, 54.13907452992031, 48.942655767713276, 43.70660448074341, 41.53134931836809, 39.65316438674927, 43.8273537499564, 37.128661496298655, 30.717975548335485, 30.049002987997874, 25.296426466533116, 18.366117749895366, 16.73809576034546, 12.232567650931221, 4.951837394918714, 1.6854267035211836, 0.38862246381384985, 0.3194172659090587, 0.3518945574760437, 0.25775577606899397, 0.06352458415286881, 0.0844167113038046, 0.08294240398598568, 0.14838655692126068, 0.16610314697027206, 0.09053363664341824, 0.05945059883275202, 0.12242172232695989, 0.06363661028444767, 0.17701525214527333, 0.05579875050378697, 0.12995131686329842, 0.03197533850158964, 0.12897162086197309, 0.10566876735538244, 0.05096891109964677, 0.07609187372561012, 0.04954848285498364, 0.07138421812227794, 0.0448572749405035, 0.04273896325113518, 0.09101544400410992, 0.04848024481907487, 0.010496669565327466, 0.034232013659285646, 0.08905838616192341, 0.06739406580371515, 0.012161322919252728, 0.05162667616137436, 0.14230122417211533, 0.0601040551971112, 0.09494412104998316, 0.11410717133964811, 0.07730571859117065, 0.11029834393411875, 0.05425225384533405, 0.00086521558737981, 0.07582587442759957, 0.13142813476068632, 0.1543567558484418, 0.13673669419118337, 0.12130782566964626, 0.17122785055211612, 0.2427019067108631, 0.47821877896785736, 0.315901694553239, 0.41662807390093803, 0.3394766338169575, 0.19251988588699273, 0.21896140490259441, 0.2127206197806767, 0.548973370875631, 0.4416171887091228, 0.2708007203681128, 0.48907338508537834, 0.21791688166558743, 0.23734796685831888, 0.2182420627879245, 0.4018171743622848, 0.3396392650902271, 0.29932261418019024, 0.37289760474647793, 0.3371425819184099, 0.3026742514755045, 0.28085291811398094, 0.4152697010764054, 0.4953859863536698, 0.3681565448641777, 0.5860012982572828, 0.32713245334369795, 0.271185286875282, 0.15815539844334126, 0.17396098960723194, 0.08440312024738107, 0.0926503741315433, 0.1321370681481702, 0.16656517503517015, 0.12809785774775914, 0.27808305674365585, 0.1631016880273819, 0.3113890838410173, 0.15342028252780437, 2.2496775346142903, 19.498688016619, 41.29563168116978, 69.6723804473877, 91.20041493007115, 85.95609528677804, 101.8334447315761, 102.42731421334403, 98.12689345223563, 97.98776272365025, 92.71006393432617, 99.32381098611015, 82.09539127349854, 81.17611680712018, 78.43870721544538, 77.66592161996024, 75.48242936815534, 73.91854967389787, 70.7904359272548, 71.57074642181396, 77.09805229731968, 74.91028690338135, 81.46382781437465, 82.70085729871477, 80.23238468170166, 76.76644257136753, 82.98764419555664, 79.19040502820695, 83.8779377256121, 86.27196734292167, 87.88572815486363, 83.71848351614815, 77.10117203848702, 60.32527460370745, 47.564834935324534, 39.21994073050362, 31.35260316303798, 14.764503376824514, 4.107223927974701, 1.7247689238616397, 0.2200608623347112, 0.30336269310542513, 0.4741222730704716, 0.27830094790884424, 0.9104660504630634, 1.5772671358925956, 0.3318519629538059, 0.46899520818676266, 1.4434971596513475, 2.215562096663884, 4.07172167301178, 3.328962500606264, 1.0594272315502167, 2.7400672776358466, 5.849068267004831, 6.09687967811312, 3.708880662918091, 5.151212045124598, 10.922480463981628, 27.237673248563492, 48.92669922964913, 55.29359415599278, 69.4690066746303, 76.35074574606759, 81.11119978768485, 79.90980761391776, 74.39971937452043, 58.15972260066441, 46.822086402348106, 43.1037266595023, 40.39601714270455, 47.686379773276194, 50.19643388475691, 54.94872726712908, 57.26460007258824, 56.96636254446847, 51.39868416104998, 49.157667773110525, 49.414699009486604, 47.379064423697336, 52.980236598423545, 45.92463622774397, 35.12768105098179, 32.14338459287371, 22.13844415119716, 18.515302521841868, 12.569369418280465, 6.646709305899484, 2.4315290451049805, 0.7530545571020671, 0.3097144051321915, 0.46598935233695166, 0.4792238793202809, 0.2511244261903422, 0.1310418447745698, 0.15907934600753443, 0.15348781033286027, 0.32636910144771847, 0.1551158329738038, 0.3003226933734757, 0.16847731385912212, 0.24091434691633495, 0.1476454609738929, 0.31914373487234116, 0.22625294221299036, 0.1874666049012116, 0.5113817708832877, 0.44884814641305376, 0.265652702323028, 0.22374105985675538, 0.23800036470804894, 0.2298582430396761, 0.16990100246454987, 0.16252352190869196, 0.19797304112996372, 0.1339539135141032, 0.2196101929460253, 0.16297303778784616, 0.15381915255316667, 0.12418568267353944, 0.1495054340256112, 0.20419057964214257, 0.14869273906307562, 0.20128695187824114, 0.28476298972964287, 0.18698403079594883, 0.2982128565864903, 0.1807501938726221, 0.42565210110374857, 0.3072742574981281, 0.11305301969072648, 0.17766735143959522], [0.0491569172590971, 0.0774803531489202, 0.052279912001852474, 0.08684584631451539, 0.05181944117482219, 0.07813264921839748, 0.14171003018106731, 0.16987767443060875, 0.10351184023810284, 0.19472326551164898, 0.11683934687503747, 0.19396578972893103, 0.2296650234077658, 0.10646947260413851, 0.23342223465442657, 0.06549640691706113, 0.0857664260214993, 0.10603735436286245, 0.06518309337220021, 0.09952852076717786, 0.13496054735566887, 0.07504390353070838, 0.03144047988046493, 0.07404857408255339, 0.029150298663548062, 0.07814066271696772, 0.16505185195377894, 0.18654682354203292, 0.15009308606386185, 0.09880991825567824, 0.23165744649512426, 0.16727428484175885, 0.16506501553314074, 0.14406696228044374, 0.014220049904127206, 0.07199681310781411, 0.059593925784741125, 0.019215015894068137, 0.09972003049084119, 0.08438752072730235, 0.1788832861930132, 0.08619498195392744, 0.2945040927401611, 0.3662320024200848, 0.4158538654446602, 0.18234703104410852, 0.7877370874796594, 4.476760830198016, 13.327623724937439, 35.38741513660976, 40.39212615149361, 36.029793466840474, 29.849134581429617, 39.3970433643886, 38.06406273160662, 26.89428285190037, 32.54056446892874, 31.372878006526403, 35.04480641228812, 35.97736236027309, 24.14639711380005, 23.538860525403702, 14.988645315170288, 12.096748607499258, 10.577390364238195, 10.266474979264395, 11.459781186921255, 17.100680555616105, 18.099447625023977, 21.348397493362427, 19.590339967182704, 24.137708391462052, 34.25618239811489, 47.923150062561035, 51.321117946079795, 53.91045100348336, 36.04185206549508, 23.362244265420095, 21.13222861289978, 28.170512335641043, 22.520270245415823, 11.455983127866473, 4.288753432886941, 2.468623088938849, 1.2929936413254057, 0.8489318266510963, 0.22296140954962798, 0.23299635893532208, 0.09969293658754655, 0.043787235394120216, 0.14401676425976412, 0.16155571384089334, 0.16632521791117533, 0.19659493650708879, 0.4837458538157599, 0.9827118452106203, 1.2307497241667338, 2.8120104457650865, 2.662818942751203, 1.4652063718863895, 7.574093188558306, 14.32458426271166, 24.608275141034806, 43.65526424135481, 63.47701917375837, 65.30721637180874, 57.414681162152974, 56.87853384017944, 62.24812602996826, 59.04031644548689, 40.3434088570731, 28.05067675454276, 18.54399163382394, 11.628816962242126, 10.935617770467486, 9.079799090112958, 9.081426705632891, 7.323086040360587, 1.2419516316481998, 2.049577449049268, 3.34805788738387, 12.171596339770726, 10.984873550278799, 10.137915934835162, 13.64624639919826, 9.13229707309178, 6.120411489691053, 4.378302250589643, 2.4085074918610707, 0.5771910910095487, 0.392171961920602, 0.15026597678661346, 0.0643140325056655, 0.14286991794194492, 0.1457475306732314, 0.05735298924680267, 0.055513233145965, 0.07593537640890904, 0.047513787035963366, 0.08121207183493034, 0.0297467411229653, 0.012825717268112515, 0.05079937573256237, 0.01419930369593203, 0.04254305322787591, 0.05570899389152016, 0.015450513788631983, 0.15169228453721317, 0.04582085234246083, 0.047518835336502106, 0.04719321655907801, 0.11329782834010464, 0.07214649793292795, 0.105442469141313, 0.05505220592021942, 0.006833506664926452, 0.005683955536889178, 0.02182649022766522, 0.05732060277036258, 0.08948209056896822, 0.05332113077331867, 0.08564568071493081, 0.05663555381553514, 0.03192413964175752, 0.07626234886369535, 0.028115444550556794, 0.016998469297375, 0.06436975380139691, 0.05791392736136913, 0.060975836989070685, 0.09056514780968428, 0.06458429300359317, 0.05439590310145702, 0.08632804945643459, 0.04188257741874882, 0.008968088775873184, 0.07511043388928686, 0.04833963539983545, 0.09907369874417782, 0.04784530567537461, 0.10627670759069067, 0.15957535510616644, 0.04231717909819313, 0.10974792311234133, 0.1550249092813049, 0.3313373348542622, 0.1450360867061785, 0.13539968164903776, 0.2794255518487522, 0.28530408069491386, 0.24226916421736988, 0.12210240374718394, 0.19800120033323765, 0.07439803997320787, 0.06601012577967984, 0.10190680636359112, 0.10052729038787739, 0.15930566457765444, 0.15398669641997131, 0.11975123919546604, 0.11968282929488591, 0.17830153740942478, 0.17732660472393036, 0.2599204113440854, 0.12663769109972886, 0.27956682283963474, 0.20435179956257343, 0.2492229810782841, 0.21413121266024454, 0.0317275069787034, 0.021065128135627935, 0.025372714402952364, 0.10409037955105305, 0.02888161575953875, 0.06999294313469104, 0.04211991200489657, 0.1528242437967232, 0.18680352691028798, 0.3559444887297494, 0.4936767837830952, 0.687322698533535, 0.821426731135164, 6.30625148330416, 20.07701437813895, 39.48593861716134, 54.112417766026084, 66.41591262817383, 62.86561243874686, 57.8091755594526, 63.24939618791853, 59.28249590737479, 52.67662811279297, 54.72111817768642, 50.625123841421946, 56.63669484002249, 53.91970252990723, 47.034378187997, 43.15327078955514, 42.057234151022776, 40.5669185093471, 46.19016511099679, 44.40597888401577, 41.37569924763271, 47.96089615140642, 49.67585400172642, 59.962370191301616, 65.68896429879325, 65.47906616755894, 63.40192999158587, 68.48032665252686, 69.87847791399274, 70.83447360992432, 65.8667687007359, 44.162732873644146, 35.95742450441633, 37.811613832201274, 27.354929310934885, 9.956896253994532, 1.2771054995911462, 1.2619465930121285, 1.3257778478520257, 0.35915167949029375, 0.0357698081061244, 0.3534095361828804, 0.3675074039825371, 0.4035054237714836, 0.3286905868777207, 0.1549010087868997, 0.19675615642751965, 0.31542639434337616, 1.4516314374549049, 3.205153201307569, 4.438666028635843, 4.367007519517626, 5.587971465928214, 4.305553308555058, 4.993235196386065, 8.261154515402657, 16.184861080987112, 35.377711977277485, 52.21194301332746, 51.25589868000576, 55.40209027699062, 63.27443054744175, 72.9588714327131, 73.8693494796753, 58.71974045889718, 48.14657981055123, 36.61532163619995, 27.751376152038574, 27.6245402608599, 28.112173523221696, 26.67503591946193, 32.6938591003418, 31.24359287534441, 30.27174833842686, 27.158258812768118, 24.52028489112854, 22.949818304606847, 20.79878282546997, 24.880887712751115, 18.84833836555481, 13.058038830757141, 13.243559207235064, 7.848712921142578, 5.017273357936314, 1.9356940857001712, 0.5191643504159791, 0.21007239259779453, 0.20575917618615286, 0.3964614160358906, 0.138125994641866, 0.0982453024813107, 0.024231739109382033, 0.052232607933027406, 0.1270193127649171, 0.1694192833134106, 0.07471526866512639, 0.014634241250210574, 0.021285580770511712, 0.02365361200645566, 0.074707431585661, 0.06545622407325677, 0.1475727084491934, 0.08025558851659298, 0.10756142543894903, 0.1801303792744875, 0.17297316475638322, 0.07576976636690752, 0.1110590427581753, 0.022132862359285355, 0.026820708132748092, 0.03403972362035087, 0.0181867995498968, 0.048641773472939215, 0.10015676955559424, 0.09618790966591664, 0.05764427075960806, 0.0112894469805594, 0.07829963668648686, 0.026520145957225134, 0.01879189841981445, 0.1016790425138814, 0.06564235979957239, 0.013026581445176686, 0.06580654491803475, 0.045641583390533924, 0.04083338925348861, 0.08463607488998345, 0.04125699866563082, 0.12719365555260861, 0.021568158375365392, 0.18922825822872774, 0.17129379058522837, 0.18055417867643492, 0.2019069700368813, 0.1878143133861678, 0.2885042961154665, 0.39447393268346786, 0.28423660940357615, 0.4719990555729185, 0.5041214461837495, 0.3115420527756214, 0.306137385645083, 0.5106791885835784, 0.45177700210894856, 0.5604810533779008, 0.3803784804684775, 0.3358081749507359, 0.35036845079490114, 0.3030336307627814, 0.18099138593035086, 0.30025611551744597, 0.28201120453221457, 0.3918857287083353, 0.45784953768764225, 0.16508030971246107, 0.2391362323292664, 0.27029510321361677, 0.4600157471639769, 0.25396439379879404, 0.5328515959637505, 0.3961293952805655, 0.3308100045791694, 0.30654496806008474, 0.18768904225102492, 0.15372402194355214, 0.1420499083719083, 0.22402398181813105, 0.14644920373601572, 0.17979755784784043, 0.12352928146719933, 0.1657908580132893, 0.2931648003203528, 0.2634373669113432, 0.4917635864445141, 0.45358079246112276, 0.2579498642257282, 2.330875051873071, 10.259964517184667, 24.555480991091045, 50.28023263386318, 64.4572501863752, 63.54409013475691, 58.24792998177664, 67.19865499223981, 63.740314211164204, 52.70295831135341, 64.05478273119245, 60.64812959943499, 66.34436007908413, 68.2583178111485, 59.44059521811349, 52.258541107177734, 55.325541973114014, 50.11759614944458, 55.64627776827131, 54.33234909602574, 42.814782346997944, 53.0096309525626, 50.40519598552159, 65.71873038155692, 68.70931843348912, 70.34722423553467, 75.71839714050293, 84.81372806004116, 81.65782151903424, 81.12192780630929, 73.12070887429374, 63.45920399257115, 49.63039888654436, 49.620195456913535, 37.51188938958304, 22.96631853921073, 10.182716182300023, 4.923414920057569, 3.4807257056236267, 0.8297874767865453, 0.9421097210475377, 1.1267899083239692, 0.3880961106291839, 0.3658289797604084, 1.0142510214022227, 0.5036136305757931, 0.2710075649831976, 0.6080365872808865, 2.0925086310931613, 3.3813584319182803, 5.7759028673172, 5.940213867596217, 6.507345378398895, 5.439504964011056, 11.781378558703832, 20.62246707507542, 33.62913179397583, 56.473116874694824, 76.70607662200928, 75.60844884599958, 67.815078326634, 66.5684255872454, 76.80194091796875, 77.08818585532052, 67.90167372567313, 61.242096355983186, 53.88626432418823, 44.890629632132395, 41.99445022855486, 44.181142125810894, 37.917063168116975, 46.34220906666347, 41.45504420144217, 31.196181842258998, 36.15156064714704, 37.684993335178916, 34.07107891355242, 30.150946957724436, 28.665609700339182, 18.860132932662964, 14.015891432762146, 9.632571714265005, 4.749599652630942, 2.537237201418195, 0.8403888536351067, 0.2238751519471407, 0.24848381217036927, 0.4623367711901665, 0.5573988216263908, 0.15815927966364793, 0.23732592804091318, 0.2844332759933812, 0.17814084674630845, 0.17508719488978386, 0.24445464408823422, 0.14340686984360218, 0.1793448935661997, 0.07645719019430024, 0.11218825395085982, 0.24321762046643666, 0.14579563880605356, 0.3007187678345612, 0.11630273424088955, 0.15078604673700674, 0.39635643309780527, 0.3593358610357557, 0.19225700785006794, 0.2504598689930779, 0.08081449781145368, 0.12260101842028753, 0.1797319706529379, 0.16013448153223309, 0.11874988435634545, 0.18535740593714373, 0.2941815714750971, 0.32597069282616886, 0.1498926875314542, 0.23726116865873337, 0.1437707274620022, 0.11321664841047355, 0.2612449659832886, 0.1545003881411893, 0.2155329981552703, 0.23074625538928167, 0.16766171476670674, 0.16676823342485086, 0.38021707055824144, 0.25947534665465355, 0.23248821763055666, 0.08184914157858916], [0.030991354158946445, 0.05816476818706308, 0.044571547236825736, 0.1455774355147566, 0.14159976824053697, 0.03520943656829851, 0.13058120092110975, 0.05198544476713453, 0.09127316517489296, 0.12902348807879857, 0.10235788287328822, 0.1744013452636344, 0.23027434785451206, 0.11575926840305328, 0.05243691821981754, 0.0905492225927966, 0.1220374543751989, 0.0919723751555596, 0.11434372221784932, 0.10656319186091423, 0.08933051263115235, 0.04659654000507934, 0.07354976941964456, 0.051553011007074795, 0.07724975302283253, 0.05231344520247408, 0.11095961702189275, 0.12558725103735924, 0.06693515221455268, 0.07589416219187634, 0.0560074814462236, 0.02025037381931075, 0.05236745998263359, 0.12558098137378693, 0.03491651300074799, 0.02866659819015435, 0.030771956646016667, 0.016893903658326184, 0.046953982074878046, 0.08557068902466979, 0.04346922977960535, 0.08508018284503903, 0.02052008979288595, 0.04203348699957132, 0.12465202622115612, 0.2537060076636927, 0.44573255788002697, 0.11551845632493496, 1.2309067100286484, 4.77818671294621, 8.466426014900208, 13.214105793407985, 12.691591705594744, 14.588434287479945, 12.424733110836574, 16.859220232282365, 23.27567665917533, 22.164895943232946, 21.953832251685007, 30.46867070879255, 21.066349267959595, 15.665319953645978, 10.020380207470485, 2.4646715181214467, 2.39857200213841, 3.936227023601532, 2.390830840383257, 5.634030640125275, 10.37569284439087, 10.82421817098345, 16.8444379397801, 20.870361430304392, 23.18391874858311, 29.247521332332067, 30.92773471559797, 45.844266414642334, 42.462334973471506, 24.45814367703029, 24.523064170564922, 35.60467835835048, 34.64740071977888, 18.503045899527415, 8.524535536766052, 4.231383894171033, 2.6781484058925082, 1.9360243422644479, 0.616352875317846, 0.3111824563571385, 0.4394657170133931, 0.42151664729629246, 0.5268107343997274, 0.0940893976283925, 0.11495766070272241, 0.15987952878432615, 0.1408538818359375, 0.4058179525392396, 0.9151701437575477, 1.7547639714820045, 1.2757866446460997, 7.407593505723136, 19.705212797437394, 35.28295244489397, 53.73621450151716, 64.00126770564488, 68.76523753574916, 69.64136368887765, 66.8462632043021, 68.55884824480329, 65.70768274579729, 42.31589821406773, 31.888191155024938, 19.682997669492448, 14.129883578845433, 13.161377651350838, 6.641354850360325, 5.428668814046042, 1.2597664871386118, 12.485713975770132, 5.148136164460864, 11.635776451655797, 31.095967973981583, 22.4788225037711, 13.802309019224984, 10.785223143441335, 8.967399818556649, 6.476999989577702, 3.0748868542058125, 0.8164976356284959, 0.15768601505884103, 0.04750851481886847, 0.13034618353205069, 0.15815469276692184, 0.05975710667137589, 0.033844244466828446, 0.07871571435992207, 0.05723960604518652, 0.05339515894385321, 0.03671705995553306, 0.105656234813588, 0.06575835536101035, 0.10169706440397672, 0.058662629686295986, 0.041060399929327626, 0.019807270096082772, 0.06113711119230304, 0.08730649695332561, 0.039238557152982266, 0.02987034645463739, 0.042888054358107705, 0.06575487447636467, 0.007493715300889952, 0.024953769919063364, 0.03456035675480962, 0.0448204237036407, 0.04867195810324379, 0.07743344602308103, 0.025788809039763043, 0.07691832259297371, 0.07860478066972323, 0.04875291072364364, 0.1055787257584078, 0.05423732268224869, 0.051211901275174956, 0.039814304294330735, 0.1140591853431293, 0.09165036957710981, 0.10017768879021917, 0.10691300380442824, 0.11463694434080805, 0.29563105798193384, 0.19329797556357725, 0.166006577866418, 0.06292612983712129, 0.07782062489007201, 0.013666142260522714, 0.05255730390282614, 0.08093316001551491, 0.05287731458832111, 0.07301080226898193, 0.056780139449983835, 0.07509122456290893, 0.13498801445322378, 0.1377438437193632, 0.1368472682578223, 0.176278539534126, 0.37285803258419037, 0.18217817081936769, 0.31756890937685966, 0.4203697331249714, 0.36195115212883266, 0.34028973590050426, 0.2662660708384854, 0.20920028510902608, 0.18205744586884975, 0.0941460756585002, 0.1392217201313802, 0.06209742144814559, 0.07939225448561565, 0.030465591299746717, 0.025677868564214026, 0.06894161419144698, 0.14130714322839463, 0.17785146513155528, 0.1961993370205164, 0.10575275641999074, 0.09253753375794206, 0.08720183971204928, 0.17157996951469354, 0.1122562363743782, 0.06360961137605564, 0.13329557169760975, 0.0885484738807593, 0.054336086846888065, 0.006062763402171965, 0.06893942930868693, 0.04078447366399424, 0.06723773812076875, 0.13263721631041595, 0.07065555293645177, 0.13369203970900603, 0.2153839918651751, 0.04153455341500895, 0.4852549699800355, 0.70052796708686, 4.1595156363078525, 13.337963512965612, 20.79908159800938, 29.057024308613368, 29.24989414215088, 33.9620304107666, 31.567799295697892, 27.680125849587576, 37.04367460523333, 38.1105010168893, 37.547189712524414, 41.72671529224941, 31.17107105255127, 31.301641600472585, 29.217275823865617, 27.5381498336792, 29.203789370400564, 27.119807481765747, 24.243173360824585, 27.14704442024231, 33.89395890917097, 38.88934891564505, 38.98776320048741, 40.50580562864031, 48.64423411233084, 58.029565470559255, 58.890874590192524, 71.7701666695731, 56.86682265145438, 39.94805983134678, 35.131335803440635, 44.87896360669817, 38.175595215388704, 18.432919468198502, 7.948069555418832, 3.9922199504716054, 3.080735283238547, 1.5573630439383643, 0.564534350165299, 0.11609138415328094, 0.6171822622418404, 0.7521179616451263, 0.3469572924077511, 0.3805434730436121, 0.18058901466429234, 0.39298783242702484, 0.14553495922258922, 0.7366214160408292, 1.637783665742193, 1.7904273377997535, 2.481156553540911, 6.091820086751666, 17.60796853474208, 32.335783685956685, 48.89633560180664, 67.5029513495309, 79.39703750610352, 78.96392154693604, 73.66734450204032, 73.72150571005685, 74.96639360700334, 66.21674946376255, 56.091931751796174, 42.786902700151714, 31.668291091918945, 25.14750746318272, 21.353388037000382, 23.883435589926584, 23.332637991224015, 27.802815403257096, 20.54252805028643, 16.448414938790457, 19.837139981133596, 19.570918015071324, 17.114675964627946, 16.63571058000837, 17.07884931564331, 11.589345114571707, 6.308867045811244, 2.983057073184422, 0.7338174379297665, 0.4772619903087616, 0.13218026368745736, 0.109854921299432, 0.13177767529019288, 0.22639529885990278, 0.11806930016194071, 0.06818856924240078, 0.1013093019968697, 0.056833489265825064, 0.08643023004489285, 0.048003268627715964, 0.04278696621102946, 0.05125180931229677, 0.06759778915771417, 0.038087015372834036, 0.019335745933598707, 0.13093251921236515, 0.052691725082695484, 0.03648360998236707, 0.11134366105709757, 0.07244858850858041, 0.08899047837725707, 0.1421826569629567, 0.05199758375861815, 0.04839278165517109, 0.07387565621840102, 0.03789712056251509, 0.014528837620413728, 0.014913991060374039, 0.051754216996154616, 0.0712870451222573, 0.11537785029837064, 0.20960615761578083, 0.10216935191835676, 0.03288816148415208, 0.046885768949453316, 0.09282721392810345, 0.17679373760308537, 0.06078831026596682, 0.04091493898470487, 0.10305112853114094, 0.08590467074619872, 0.13060937369508402, 0.06943767757288047, 0.039238689467310905, 0.21913382065083298, 0.11521703749895096, 0.13302969453590258, 0.16523669846355915, 0.14376288359718664, 0.2659492221261774, 0.20890559735042707, 0.31537528708577156, 0.24314518006784575, 0.2464409332190241, 0.37085399297731264, 0.5552986200366701, 0.3331489147884505, 0.4978989543659346, 0.46611583126442774, 0.5328878568751472, 0.589429854282311, 0.4518951486263956, 0.32547701788800104, 0.22494228397096905, 0.21584810981793062, 0.1964152604341507, 0.20665328178022588, 0.1375202935721193, 0.1601452702390296, 0.1424917432346514, 0.20264569111168385, 0.16284346474068506, 0.26705838260906084, 0.15960820977176937, 0.19787763910634176, 0.17622988857328892, 0.139156363638384, 0.25374104721205576, 0.1901249015437705, 0.29044238211853163, 0.24200076290539332, 0.28444269405944006, 0.151547390169331, 0.1058084030768701, 0.12516502583665506, 0.20470351140413964, 0.19261610215263708, 0.244952064539705, 0.16735307632812432, 0.14513809766088212, 0.2797175390379769, 0.4228212801473481, 0.4418776918734823, 0.30968612379261423, 1.656293015394892, 5.853246739932469, 11.801416294915335, 20.575179372514995, 24.2733667578016, 27.461603266852244, 26.303203071866715, 24.708271878106252, 39.90518249784197, 42.91509696415493, 40.1656357220241, 54.2295366014753, 46.81303289958409, 48.97892883845738, 52.62594100407192, 45.70916911533901, 47.24378299713135, 40.21733379364014, 36.934775488717214, 33.912416798727854, 42.564602034432546, 51.37080798830305, 54.9145073890686, 59.52184745243618, 63.61195319039481, 67.54885809762138, 68.31062385014125, 85.71802915845598, 79.4920402254377, 63.93647575378418, 57.157990387507844, 60.94311537061419, 52.79534503391811, 34.47451216833932, 20.498888151986257, 10.229510562760488, 6.576722707067217, 3.041124905858721, 0.786237253674439, 0.2601694608373301, 1.4271986399378096, 2.2841262689658572, 1.7784055428845542, 0.6964910094227109, 0.2669954959835325, 0.5698800118906158, 0.5590568355151585, 0.7470626043421882, 1.3116519429853983, 1.9193651676177979, 3.641347212450845, 13.938857623508998, 26.05131697654724, 46.25049631936209, 67.02114241463798, 79.29593426840646, 84.41306713649205, 84.79772635868618, 82.8386400767735, 86.48547158922467, 84.44147832053048, 72.42802906036377, 66.97453389848981, 55.30486413410732, 48.73993512562343, 41.98416689464024, 36.53110599517822, 38.73770100729806, 38.533653259277344, 47.52803727558681, 38.071837765829905, 39.13480792726789, 52.03495502471924, 43.695007937295095, 30.186431407928467, 21.89255087716239, 19.633113077708654, 13.588859489985875, 5.801394505160196, 1.654289871454239, 0.36497611552476883, 0.283801831305027, 0.30434114060231615, 0.28119631111621857, 0.2322116196155548, 0.23940083384513855, 0.2409862173455102, 0.22191677774701798, 0.1907581239938736, 0.20493595036012785, 0.26453727217657225, 0.19228475993233068, 0.32123785678829464, 0.18309934996068478, 0.2192518857440778, 0.0945885144174099, 0.11560040978448731, 0.22483169633362973, 0.07730717744146075, 0.13504399359226227, 0.1455327607691288, 0.13910366860883577, 0.17363899759948254, 0.2750966069953782, 0.18526085040399007, 0.154154932392495, 0.22608808534485952, 0.30843124112912584, 0.15321043878793716, 0.14926264062523842, 0.22834679271493638, 0.11378454150898115, 0.28695324648703846, 0.2137547071490969, 0.17737644990640028, 0.16253429704478808, 0.17097751184233598, 0.17947373379554066, 0.242569022412811, 0.30992103261607035, 0.1845842017126935, 0.3140314891934395, 0.296727109168257, 0.22567820948149475, 0.16309632760073456, 0.22805754680718693, 0.27519271469541956, 0.2342779758785452], [0.037497480399906635, 0.021291063333462392, 0.026770238698061024, 0.010047859362592655, 0.1312114649585315, 0.11975950375199318, 0.05318822951189109, 0.0884337607505066, 0.08200696882392679, 0.05865954913731132, 0.14618297373609884, 0.09385489592594759, 0.06663061212748289, 0.0839326037093997, 0.012425219606874245, 0.0592513063124248, 0.02914498234167695, 0.03477931661265237, 0.0109654108860663, 0.014467216462695172, 0.06364716828933784, 0.00943678429549826, 0.039644473764513216, 0.04202831317005413, 0.03487697137253625, 0.02906025367389832, 0.06385062022932939, 0.0472962385309594, 0.022487349409077848, 0.03605122371975865, 0.007453648656207536, 0.004597029374313674, 0.05385596225304263, 0.054829704109579325, 0.04482654069683381, 0.04761496339259403, 0.03566309829641666, 0.03325241943821311, 0.028374212361606102, 0.03438234987801739, 0.024979744239577224, 0.04655249968969396, 0.010615067988900202, 0.0567932589245694, 0.02373581313128982, 0.031125463212707212, 0.12575498489396914, 0.2298199465232236, 0.0646075192572815, 0.12422970602554934, 0.25356840076191084, 0.09240238993827786, 0.4546453867639814, 0.8832509336727006, 3.917683584349496, 7.111997161592756, 13.59184113570622, 13.42134884425572, 11.670716336795262, 12.774088535990034, 14.10276997089386, 17.99287268093654, 18.875349487577164, 15.781212432043892, 18.430074180875504, 12.097544176237923, 1.6101247327668327, 1.8101974597999027, 5.684377721377781, 7.210051442895617, 7.886334810938154, 9.586089134216309, 15.518970046724592, 17.77346420288086, 19.820439985820226, 36.58408600943429, 34.456829002925325, 27.654308080673218, 26.843114580426896, 32.579446588243755, 36.240831102643696, 31.171144008636475, 21.16900542804173, 12.383690970284597, 7.253417755876269, 6.94078312601362, 4.76352471113205, 2.8143810842718398, 2.1644491936479295, 1.8747874796390533, 1.534472529377256, 0.6194608371172632, 0.3817604663116591, 0.5618901806218284, 0.6667360003505434, 0.6703502035566739, 1.6926994046994617, 3.2484026976994107, 12.243944457599095, 31.114814962659562, 46.34041295732771, 60.57703563145229, 68.301285471235, 64.16281332288469, 64.25912925175258, 61.3540735244751, 60.90109266553606, 54.71860292979649, 49.21811015265328, 31.255067825317383, 22.679491690226964, 11.367503029959542, 4.064102973256793, 7.382624285561698, 4.251766869000026, 3.608053181852613, 7.637804695538112, 6.424927583762577, 9.568769880703517, 10.887348634856087, 12.429166061537606, 10.204100131988525, 8.49500742980412, 5.984626318727221, 2.8987191872937337, 0.4052187518349716, 0.11757364390151841, 0.11037780717015266, 0.10226192445095096, 0.12564397656491824, 0.14212563287998947, 0.16958876779036863, 0.04285846344594445, 0.044779484293290546, 0.13644162645297392, 0.05847421408231769, 0.06039065481828792, 0.06738092258040394, 0.05667536346507924, 0.05998518943254437, 0.08332821899758917, 0.032864789345434735, 0.004493707150686532, 0.013823244321559156, 0.10029599815607071, 0.034104669599660804, 0.03338444199679153, 0.07428731662886483, 0.018028290376865437, 0.026360827631184032, 0.10672913438507489, 0.011258705951539534, 0.015136577687891466, 0.06178905442357063, 0.014813998747350914, 0.05002874994118299, 0.04361302831343242, 0.05113565768780453, 0.16598904452153615, 0.13076553174427577, 0.048857472970017364, 0.07256269774266652, 0.07750750133501631, 0.028551226880933558, 0.03906232464526381, 0.019320668885484338, 0.06469344214669295, 0.12456600155149188, 0.06196645740419626, 0.10602040455809661, 0.08878826137099947, 0.06356588657945395, 0.01850416394881904, 0.06619000541312353, 0.054458450459476025, 0.11065273598900863, 0.03824966360947915, 0.06472186597862414, 0.025419709738343954, 0.016876351653731296, 0.13244365741099628, 0.20750240050256252, 0.06441529707184859, 0.15145224598901613, 0.12623469558145317, 0.08286913577467203, 0.16526134285543645, 0.2770612644297736, 0.21494275411324842, 0.2099452894181013, 0.26009550052029745, 0.15206827436174664, 0.14516826532781124, 0.1353402826935053, 0.30797190006290165, 0.17680208358381475, 0.11953038961759635, 0.06823611419115748, 0.043543661678475995, 0.06727118989718811, 0.10314339572297675, 0.03216646146029234, 0.03815502493775316, 0.05529459898493119, 0.08742633980831929, 0.0996562617697886, 0.027744559005701115, 0.03778305882588029, 0.031837497505226305, 0.02832921191916934, 0.022715323604643345, 0.09971224769417729, 0.043518647485013516, 0.03436518972739577, 0.035839653108268976, 0.04973608760961464, 0.04546274530834385, 0.0854753412838493, 0.07978914318872349, 0.040034302310752015, 0.09446622883634907, 0.05273360426404646, 0.061671891781900606, 0.16311136393674783, 0.3699755072593689, 1.005312163914953, 2.081556750195367, 4.051020818097251, 5.241840873445783, 8.339574490274702, 11.587183356285095, 16.45013288089207, 24.159155743462698, 23.23673721722194, 25.399023566927227, 34.00820466450283, 30.223291601453507, 22.785981518881663, 20.84379151889256, 22.436259576252528, 21.379558426993235, 16.349554232188634, 11.811069079807826, 17.434089865003312, 19.79623419897897, 25.550506455557688, 30.125123977661133, 34.90706532342093, 40.50386708123343, 43.886138984135215, 43.49354839324951, 63.39718437194824, 57.18024199349539, 43.071427958352224, 41.715546063014436, 50.39429078783308, 51.115176813943044, 37.62917150769915, 19.194765125002178, 10.091285705566406, 6.3810887932777405, 5.261362705911909, 2.441469745976584, 2.86308621934482, 2.8104746767452786, 1.5297715302024568, 1.278002251471792, 1.3174732306173869, 0.781665501849992, 1.161151898758752, 1.0712524141584123, 0.6165752176727567, 1.4738559020417077, 1.469778829387256, 6.51318837915148, 26.029322453907557, 43.62446982519967, 61.61955029623849, 79.42414937700543, 81.14257090432304, 86.12403324672154, 85.09460898808071, 78.53954642159599, 77.69566685812813, 70.47003364562988, 56.47309603009905, 48.55553688321795, 33.23265021187918, 23.962891714913503, 23.899452924728394, 19.9523115839277, 18.385027272360666, 14.498152869088308, 19.979428665978567, 14.190739376204354, 13.685423816953387, 23.90116912978036, 22.004053831100464, 16.485330717904226, 11.544564843177795, 7.518574476242065, 2.224312267133168, 0.6282522082328796, 0.07942597767604248, 0.12487413787416049, 0.10557483775275094, 0.20882548950612545, 0.2153562804950135, 0.09297636271055255, 0.10263091857944216, 0.1314365757363183, 0.06252092908003501, 0.04341692490769284, 0.14029048063925334, 0.13814455935997622, 0.018728755647316575, 0.058947974017688205, 0.0737806816718408, 0.017563441302627325, 0.07012632276330676, 0.024956451828724573, 0.022925798382077898, 0.04164951421054346, 0.06012544262089899, 0.09746844095310994, 0.08176912872919015, 0.010140298732689448, 0.05078035978866475, 0.04085905823324408, 0.052421681715973785, 0.02035660865450544, 0.011212401873698192, 0.014060106477700174, 0.03630165742444141, 0.11898388394287654, 0.050563194655946324, 0.048961953792188845, 0.02429569951657738, 0.02899698367608445, 0.09912031409995896, 0.0940048521650689, 0.013807169826967376, 0.06638437176921538, 0.10522989769067083, 0.07916202755378825, 0.18427179061940738, 0.15612906217575073, 0.18641825472669943, 0.0721765434635537, 0.10293652396649122, 0.03250129474326968, 0.0693204877898097, 0.13982778761003697, 0.10108951771897928, 0.15975390481097357, 0.0829725241554635, 0.2363448478281498, 0.20546211355498858, 0.3044352669801031, 0.20582195424607821, 0.31965763015406473, 0.32248931963528904, 0.38020336415086475, 0.4053771490497248, 0.23621399913515362, 0.4442958821143423, 0.456174587564809, 0.3886985954429422, 0.22615931795111724, 0.1813062804618052, 0.3379407562315464, 0.18937436038894312, 0.19689702029739106, 0.15122527602527822, 0.12898771571261541, 0.1345926592392581, 0.1287417739097561, 0.09790439291724137, 0.1473041714302131, 0.10331726353615522, 0.18896035903266498, 0.17629704996943474, 0.18248382370386804, 0.18367296989474977, 0.1646180780870574, 0.13561295877609933, 0.16135068769965852, 0.17452232805745943, 0.1302943163152252, 0.11588927571262632, 0.14917684665748052, 0.13682881210531506, 0.1880104100065572, 0.18463967873581819, 0.307256317032235, 0.1784153820148536, 0.1472024726016181, 0.14581425780696528, 0.27159903038825306, 0.2876755877264908, 0.33832323285085814, 0.5143837726541928, 0.7560947739652225, 1.3590619989803858, 2.0872449363980974, 4.436399178845542, 9.251483866146632, 14.797253710883004, 22.691463436399186, 26.58945322036743, 25.583939450127737, 33.95939704350063, 35.260975292750764, 37.331892830984934, 43.25603117261614, 52.244964327131, 52.459156445094514, 44.31382492610386, 30.827927316938126, 32.08137192044939, 37.40625245230538, 43.670835154397146, 42.873025621686665, 46.40145288194929, 58.04708882740566, 57.45620707103184, 58.825540678841726, 78.27969074249268, 75.13701357160295, 72.18270901271275, 64.9234117780413, 68.9706471306937, 64.4009141921997, 59.34763526916504, 44.1078143119812, 30.872861317225865, 17.96075984409877, 13.056580577577863, 7.35140255519322, 5.341955729893275, 6.433092151369367, 5.400066554546356, 4.466908284596034, 3.01300967165402, 0.8971112870744297, 1.3090200956378664, 1.802146126117025, 1.5802926421165466, 3.7942279917853217, 5.328744598797389, 18.100939750671387, 41.00605508259365, 57.768535545894075, 75.29367460523332, 87.83105972834996, 87.2569717679705, 90.23032133919853, 86.01150717054094, 84.45012187957764, 77.08170318603516, 75.36960451943534, 63.35457801818848, 63.56888130732945, 47.58863946369716, 35.789430958884104, 38.93299055099487, 40.256545952388215, 39.48370129721505, 37.76615176882063, 36.724564688546316, 35.00525031770979, 32.50359310422625, 27.588103907448904, 20.077413899557932, 14.710065977913992, 9.130491409982953, 4.323191744940622, 0.7291909147586141, 0.2544715851545334, 0.20261901111475059, 0.22322578036359378, 0.1472076294677598, 0.2642837172108037, 0.2916683591902256, 0.29334751623017447, 0.30031750936593327, 0.24435541512710707, 0.22318839308406624, 0.22047984413802624, 0.3291095958224365, 0.21963196034942353, 0.20444836866642746, 0.22298940590449742, 0.11361557950398751, 0.06325061885373932, 0.21451073086687497, 0.24313673909221376, 0.1757567868168865, 0.1626614409365824, 0.19992385644997868, 0.16007831240338938, 0.13899947277137212, 0.1536402635808502, 0.21251210596944603, 0.2070635376232011, 0.15631270089319774, 0.15643645210989884, 0.12470269921634879, 0.08926799241453409, 0.11934121405439717, 0.23086676320859364, 0.1931554696389607, 0.13159524436507905, 0.17392073890992574, 0.17691208768103803, 0.22674867989761488, 0.20793960775647843, 0.1743541056556361, 0.19926901587418147, 0.2672769251678671, 0.15315451393170015, 0.28456686596785274, 0.30553617647715975, 0.27947304930005756, 0.207543533295393, 0.3146975663091455, 0.10618511893387352, 0.16182951629161835], [0.08365561892943722, 0.01101076671121908, 0.04532934193100248, 0.08455199761582272, 0.03477976105308958, 0.032630365674516985, 0.08722463848867587, 0.13883346239370958, 0.11199439649603196, 0.024489107441955378, 0.05155766575730272, 0.03577589795791677, 0.11158277001231909, 0.028181045316159725, 0.08402134930448872, 0.024245584616437554, 0.14945944292204721, 0.020520552893036177, 0.014698540924915245, 0.031237784507019178, 0.07831706825111594, 0.02649773733823427, 0.10938730210598026, 0.01958411858816232, 0.024056734750047326, 0.07808397790150982, 0.07831570439572845, 0.03200318218607988, 0.045460177053298266, 0.02623672187993569, 0.07749236321875028, 0.006857056495001805, 0.0613889494644744, 0.024036831621612822, 0.035524612691785605, 0.04437086371971028, 0.022929282659398656, 0.04130207374691963, 0.058083011502666135, 0.12868780323437282, 0.1070426922025425, 0.14302917011082172, 0.0415625938746546, 0.017697394293333803, 0.013619439543357916, 0.11683945544064045, 0.02027533033729664, 0.07993607316166162, 0.1246586622936385, 0.07703105440097195, 0.1605736022549016, 0.20225660556129046, 0.26844688238842146, 0.1408383162426097, 0.09907799387084586, 0.7078711816242763, 1.618091385279383, 3.061880477837154, 6.186757232461657, 7.786770599228995, 11.234728166035243, 12.430223056248256, 17.520647048950195, 17.212888751711162, 13.503231627600533, 8.076857021876744, 5.1981479951313565, 6.175323103155408, 6.418194779327937, 5.903733219419207, 3.5177467933722903, 6.85185877765928, 8.932145527430944, 14.25678721496037, 17.81701898574829, 31.1095586504255, 30.68479790006365, 29.830106939588273, 28.418988602502004, 34.60909877504621, 33.51783554894583, 34.30485800334385, 33.578354358673096, 26.07978548322405, 20.305667434419902, 14.599412441253662, 10.537692700113569, 8.293655582836696, 7.487964187349592, 5.139719724655151, 3.6930062004498074, 3.4549483231135776, 4.9567645362445285, 6.015663053308215, 5.85341306243624, 4.607476421764918, 8.164115973881312, 18.78179199354989, 37.977397850581575, 54.276600224631174, 68.51148932320731, 69.33584444863456, 62.040986333574565, 59.977051734924316, 60.47384793417794, 48.33672421319144, 44.492473534175325, 34.54210077013288, 29.4465594291687, 28.606183494840348, 19.161451986857823, 8.853121059281484, 5.0129389848027905, 13.585046666009085, 14.880274261747088, 10.695336035319738, 3.936266541481018, 4.966916722910745, 8.826361809458051, 7.979728153773716, 4.624935073511941, 5.371314474514552, 3.4640789074557166, 0.7133364826440811, 0.21448206954768725, 0.05743148217775992, 0.031664471075470955, 0.039982407952525785, 0.02830111208770956, 0.028715591811175858, 0.08809312938579492, 0.01902452397293278, 0.06468038034758397, 0.007996478367463818, 0.09657033878777709, 0.16580379089074476, 0.013002297525028033, 0.01836364952448223, 0.05338808860895889, 0.024775800361697162, 0.07133612356015614, 0.03439745067485741, 0.035645619234336276, 0.07656041572668723, 0.053307709350649796, 0.0463810338904815, 0.033114931280059476, 0.04515890750501837, 0.0593044695311359, 0.058796966049287996, 0.02501567606148975, 0.01931329320983163, 0.031525659774030955, 0.0582991520475064, 0.016710605904726044, 0.07628838425236088, 0.06607934313693217, 0.047949895063149076, 0.06416691932827234, 0.055789254406200986, 0.06277678427951676, 0.05544893177492278, 0.049572927079030445, 0.019807823102122972, 0.05459489028102585, 0.04928338600854788, 0.10913990145283085, 0.039419454588953934, 0.16223203683538095, 0.1806161967771394, 0.12207530305853911, 0.08358119042324168, 0.0821924124445234, 0.1921760043395417, 0.12536497653595038, 0.058247373040233336, 0.03481489898903029, 0.07074516705636467, 0.10715275736791746, 0.15598678695304052, 0.09974034582929951, 0.10140249878168106, 0.12299724215907709, 0.12366828615111963, 0.029002337317381586, 0.08874885205711637, 0.03479684656485915, 0.04560114609609757, 0.1185200238334281, 0.030553101961101805, 0.08069417319659676, 0.007945469497436923, 0.07343018440795795, 0.019133031900439943, 0.01600936201534101, 0.06123508486364569, 0.05799555512411254, 0.05044964182057551, 0.09074211652789797, 0.002390208304859698, 0.05222614149429968, 0.024824802464406406, 0.053754745184310844, 0.028844869695603848, 0.11211818842483418, 0.08001968224665948, 0.09603684062936477, 0.014666088291310837, 0.028785090760460923, 0.04333294262843473, 0.04065131116658449, 0.029218498218272413, 0.03467989766172, 0.008173617567600948, 0.050782911080334864, 0.02092238133107977, 0.057212227157184055, 0.014115939731709659, 0.021203537405069386, 0.0021492615799486104, 0.030744038322674375, 0.061486855282315185, 0.033649783115834, 0.04117754900029727, 0.11824223159679345, 0.07875620254448482, 0.28926585667899674, 0.3023141665118081, 0.47937033431870596, 0.577242876802172, 0.653783092541354, 1.877261689731053, 5.392111301422119, 8.487791725567408, 12.055670857429504, 15.568538495472499, 20.447949171066284, 23.54966844831194, 26.32399903024946, 21.647786685398646, 21.40816937174116, 19.240420000893728, 12.36550145489829, 8.99275118964059, 13.004932011876788, 17.759708506720408, 21.868442365101405, 25.850597415651592, 31.838244029453822, 35.07155697686331, 42.536524363926475, 55.3627495765686, 51.780355657849995, 49.87668473379952, 49.168284620557515, 52.822557653699604, 53.49051577704293, 55.39976610456194, 43.78765174320766, 30.393004826137, 23.60420659610203, 16.358352388654435, 12.8457270690373, 10.082603062902178, 8.207753266607012, 5.791377374104091, 4.740356377192906, 5.365785879748208, 7.139772151197706, 7.582134859902518, 7.400379538536072, 5.360376707145146, 6.265711350100381, 15.030287606375557, 36.01074150630406, 56.98991346359253, 73.70737307412284, 83.53455775124687, 83.77752930777413, 80.77792249407086, 79.38619136810303, 71.89157949175153, 70.66914817265102, 63.35680838993618, 62.23661286490304, 45.356492451259065, 37.284884793417795, 24.647346598761423, 16.80056527682713, 17.934742314474924, 13.251944814409528, 11.017569167273384, 12.37916248185294, 16.692920310156687, 15.901282514844622, 17.41738292149135, 17.9304552759443, 12.160727620124817, 7.213830828666687, 2.958770513534546, 0.9102522847907883, 0.0512671543817435, 0.04018051303657038, 0.029737078784299747, 0.05745165502386434, 0.027361218950578144, 0.0715368070772716, 0.03688062421445336, 0.05663078710702913, 0.036330966744571924, 0.048893659242561886, 0.07979746881340231, 0.041530139544712644, 0.05205200565978885, 0.025173508395840014, 0.03751422664416688, 0.10608850233256817, 0.0527233448145645, 0.052787340844848325, 0.025645756894456487, 0.015052664958472763, 0.05736619353826557, 0.034876920482409854, 0.07430114517254488, 0.05128205840342811, 0.08941671371992145, 0.1190390759812934, 0.07345182967505284, 0.037007598472493033, 0.0266927618732942, 0.008228319364466836, 0.026522524222465496, 0.05619523547855871, 0.08681538009217807, 0.13277478250009672, 0.11157726030796766, 0.24178678010191235, 0.024733744761241332, 0.036995157532926114, 0.05614925455302, 0.02448996409241642, 0.05134888731741479, 0.024203252512961626, 0.09579583177609102, 0.10223162786236831, 0.3282590928886618, 0.3054559464965548, 0.25891949076737675, 0.09055422339588404, 0.2830667607486248, 0.13902833765106543, 0.10858675292027847, 0.08446619007736444, 0.15649859234690666, 0.17621416013155664, 0.14030082151293755, 0.14983468635806016, 0.14331817174596445, 0.15866738025631222, 0.2379493388746466, 0.17856964016599314, 0.20807916883911404, 0.1444997319153377, 0.1809339682970728, 0.22748928729976925, 0.22841304487415723, 0.20433750961508068, 0.2800002438681466, 0.1656595750578812, 0.12000450917652675, 0.07501260271029812, 0.14684282190033368, 0.1384949277022055, 0.10743535363248416, 0.2689528523811272, 0.10000257247260638, 0.17495085006313665, 0.1800628514694316, 0.16444847147379602, 0.1916878391057253, 0.17944457036043915, 0.15496020418192658, 0.19959198497235775, 0.16568978343691143, 0.15822318409170422, 0.13271925119417055, 0.17293532964374336, 0.11004358796136719, 0.0757153071463108, 0.16075582961950982, 0.18655242824128696, 0.23120111812438282, 0.16904747326459202, 0.33151052413242205, 0.1207569230880056, 0.08049929793924093, 0.1110999584197998, 0.24473406480891363, 0.10639440627502543, 0.20625529385038785, 0.21782214460628374, 0.14966323412954807, 0.3202999314027173, 0.41099221631884575, 0.6423698078308786, 0.385207858468805, 0.262179471552372, 0.4947896897792816, 2.420157015323639, 4.5247863445963175, 8.380327412060328, 10.767375826835632, 17.497950758252824, 21.227865355355398, 31.36475556237357, 36.17915889195034, 33.75042649677822, 31.954681941441127, 31.478330816541398, 41.379784788404194, 42.39489575794765, 46.03706155504499, 44.43549483163016, 52.18029049464634, 51.63567679268973, 51.20181737627302, 61.05684348515102, 77.17823450905937, 73.72825241088867, 73.14550699506486, 70.47194440024239, 75.49167047228131, 74.70831666673932, 73.08218111310686, 67.31052098955426, 53.887782505580354, 42.59621286392212, 31.82238824026925, 23.097988639559063, 16.89125316483634, 13.722046034676687, 8.865937880107335, 7.580310089247567, 7.529891354697091, 8.34950954573495, 10.494379367147173, 12.895404083388192, 7.596946682248797, 10.141180719648089, 21.80746671131679, 45.41353368759155, 67.07383060455322, 82.3720338003976, 88.66794245583671, 92.54047230311802, 90.93962124415806, 89.27065699441093, 78.21917888096401, 73.49818365914481, 66.50134072984967, 64.81814656938825, 64.88284124646867, 59.50655446733747, 43.419452803475515, 43.22591420582363, 48.84591599873134, 42.600239345005576, 40.621361119406565, 28.663306372506277, 26.082663774490356, 25.920390333448136, 18.857655899865286, 13.047012039593287, 9.692553775651113, 4.9759363532066345, 1.1469958126544952, 0.35856952358569416, 0.13077800321791852, 0.12158280877130372, 0.05781499017030001, 0.12044558408004896, 0.13966975680419377, 0.28867352274911745, 0.07285677481974874, 0.2450097400162901, 0.11955336481332779, 0.16286622280521051, 0.20437659323215485, 0.1512679151658501, 0.14628598892263003, 0.1257278434932232, 0.16299021829451832, 0.2054617471460785, 0.150196426947202, 0.13298816819276127, 0.16067017135875566, 0.1460307647607156, 0.19091459416917392, 0.1530480110751731, 0.2019742942814316, 0.11031401130769934, 0.1857970423464264, 0.17539098858833313, 0.2527667794908796, 0.10103610344231129, 0.13637401722371578, 0.11761807437453951, 0.12565623090735503, 0.14628323407045432, 0.13121967523225717, 0.12090295739471912, 0.12289696825402123, 0.33015513686197145, 0.20232699678412505, 0.18242807526673588, 0.14140133745968342, 0.12408653513661452, 0.1636522649122136, 0.25695963736091343, 0.17918752772467478, 0.3229527861944267, 0.3370192785348211, 0.29758743728910175, 0.25988113773720606, 0.31567101978829926, 0.46164797672203606, 0.37874291251812664, 0.21648985466786794], [0.06485645339957305, 0.04428022501191922, 0.021130616942952787, 0.007912781072913535, 0.060515444193567546, 0.04649761638471058, 0.07120770402252674, 0.014899840212560125, 0.04389621151079025, 0.04012998253373163, 0.01752167916856706, 0.07316701460097517, 0.045470819875065766, 0.01916859222442976, 0.04092030280402728, 0.07224001362919807, 0.11188464345676558, 0.04295006567346198, 0.02637212354290698, 0.03137700292947037, 0.06361963333828108, 0.05380895673962576, 0.024394568854144642, 0.10005388329071657, 0.07275852973439864, 0.027980970784223506, 0.05164892871731094, 0.04007448176188128, 0.027677044771345596, 0.026776247125651156, 0.053161233996174166, 0.054090043263775964, 0.012374238726416869, 0.05762905800448997, 0.038825661808784516, 0.03301860984148724, 0.14467839018574782, 0.060938069729932716, 0.011752687078634543, 0.03300289157778025, 0.061424674333206246, 0.035168327524193695, 0.009561307345783072, 0.048380713909864426, 0.056342769347663434, 0.08905791118741035, 0.048213577164070945, 0.08164313156157732, 0.017642533040738533, 0.09933553183717386, 0.08480693000767912, 0.11423731435622488, 0.009200799145868846, 0.13293870298990182, 0.11633351258933544, 0.14790278859436512, 0.058906963361161094, 0.05990917993975537, 0.07706299982964993, 0.25707273557782173, 0.9237105654818671, 3.0847189894744327, 7.574850542204721, 11.98895686013358, 16.79337910243443, 14.959358658109393, 15.206806591578893, 21.77196315356663, 16.3632230758667, 11.646923967770167, 9.658367770058767, 9.739308203969683, 12.222904443740845, 9.536862015724182, 13.014099291392736, 26.2587502343314, 24.21825017247881, 30.92598376955305, 32.26618010657174, 37.42579426084246, 38.301805768694194, 33.74299192428589, 34.44702162061419, 37.87903567722866, 34.53813682283674, 26.134281941822596, 21.58553777422224, 20.535673652376445, 18.818657398223877, 17.920899765832083, 16.422668388911656, 16.12604979106358, 17.457439286368235, 18.53962469100952, 20.091230392456055, 18.43128490447998, 29.620333875928605, 45.591581276484895, 61.59580135345459, 74.52515520368303, 74.04236657278878, 66.52802876063755, 65.68437848772321, 57.86055401393345, 52.09551899773734, 34.90899692262922, 32.08470358167376, 26.888977902276174, 20.379914147513254, 12.812438249588013, 12.628139019012451, 9.094169701848712, 13.190480181149074, 12.675213064466204, 8.412081548145839, 14.014491370746068, 11.076110345976693, 10.662914872169495, 6.021292396954127, 4.938172025339944, 2.622941493988037, 1.148019694856235, 0.12564403084771975, 0.07653716911694833, 0.11732213811150619, 0.023548925927441035, 0.18026688694953918, 0.05857721569814852, 0.03344589012808033, 0.006960707384028605, 0.06395134196749755, 0.02433070513818945, 0.05309845254357372, 0.04654889327606984, 0.13159228595239775, 0.048786423568214686, 0.026882975595071912, 0.04715981228010995, 0.030405093117484024, 0.037287355068006685, 0.03824681376240083, 0.044126740390700955, 0.03576567582786083, 0.06381214729377202, 0.03680270125291177, 0.053768329455384185, 0.021728983049147894, 0.09766825594540153, 0.023880230828321407, 0.05989825552595513, 0.03574155390794788, 0.03740590870646494, 0.013503652631438203, 0.04877374174871615, 0.05124741579805102, 0.033200345268206935, 0.007702002651058137, 0.045168529131582806, 0.026552469669175998, 0.06976308261177369, 0.04375371915687408, 0.0475382176893098, 0.010573388975379723, 0.036947738113147874, 0.04281136293762496, 0.028260199818760157, 0.07612166819827897, 0.028613428186093057, 0.012239779378952724, 0.08510541756238256, 0.02880574875910367, 0.06957979673253638, 0.03969270742631384, 0.16793245023914746, 0.1330913190862962, 0.10511211758213383, 0.02812755640063967, 0.12312598739351545, 0.05104202324790614, 0.09187926658030067, 0.04260278805824263, 0.09550490988684551, 0.00448288070037961, 0.05632950059537377, 0.06980747915804386, 0.04704365387026753, 0.04018164958272662, 0.15823235788515636, 0.05871157920254128, 0.05678271109770451, 0.03446124314463564, 0.06469695695808955, 0.048749229671167474, 0.026740210130810738, 0.07247197082532303, 0.02015892935118505, 0.07831777392753533, 0.018647797937904085, 0.02564748715875404, 0.0006100154922543359, 0.057217648651983054, 0.04090789918388639, 0.06449216151876108, 0.08594600709953479, 0.03919984333749328, 0.0283763480505773, 0.031100662757775614, 0.033889926836958954, 0.057381664136690755, 0.0778646550274321, 0.04021197670538511, 0.001546677848507118, 0.06413258545632873, 0.0760053333693317, 0.030018348512904983, 0.04874838828774435, 0.030865706436868225, 0.04869826829859188, 0.08709252093519483, 0.024056504048140984, 0.08970519966845002, 0.005479901397068585, 0.02113395872791963, 0.04654855400856052, 0.018792663468047976, 0.06786747968622617, 0.09122267538415534, 0.0971574072859117, 0.03082243286605392, 0.0873052484488913, 0.16609894005315645, 0.5039471441081592, 0.2983484821660178, 0.48044024833611076, 1.4413870785917555, 2.7407360417502264, 5.880107607160296, 8.277701650347028, 16.372856753213064, 20.12162181309291, 23.694036381585256, 20.538312230791362, 14.287173424448286, 16.020372901644024, 12.88093706539699, 12.650003262928553, 12.236966729164124, 22.01813088144575, 26.16656153542655, 29.119804756981985, 40.26260130746024, 44.3645259312221, 45.51373713357108, 49.39949287687029, 49.3237748827253, 58.3571070262364, 55.252019609723774, 54.639150278908865, 57.80283185413906, 54.440876483917236, 42.2734169278826, 31.50736039025443, 25.639478138514928, 24.193462474005564, 22.671327556882584, 23.899357386997767, 21.074942452566965, 24.10257829938616, 23.823946850640432, 24.21504705292838, 24.4832318850926, 21.293637003217423, 33.44843346732003, 47.77095324652535, 70.14845017024449, 84.41524192265102, 91.81182861328125, 83.65351091112409, 81.58332293374198, 78.95323521750313, 77.1467591694423, 61.72466959272112, 52.58470344543457, 46.580917903355186, 43.91833693640572, 36.7942099571228, 29.36603675569807, 21.57036464554923, 13.184421351977758, 16.420279945646012, 17.959483112607682, 16.074315241404943, 12.86173050744193, 11.450833644185748, 12.89456856250763, 8.95732753617423, 4.63474896975926, 3.1972474540982927, 0.9230273621422904, 0.21726376456873758, 0.16496288244213375, 0.04215633915737271, 0.15509787893721036, 0.08779546285846404, 0.03725747238578541, 0.06174186909837382, 0.11684269883802959, 0.055848931561091116, 0.04218913275482399, 0.007398113957606256, 0.033504773396998644, 0.02159831247159413, 0.029460711471204246, 0.02647585458388286, 0.03660788027835744, 0.044354015695197244, 0.0505094377190939, 0.022121174593589137, 0.0398222024419478, 0.043732528508241685, 0.06071554417056697, 0.07943574858031102, 0.030725514316665273, 0.008920783010710562, 0.024827686238235662, 0.002696913978849937, 0.026770372708727206, 0.11263412609696388, 0.04933920908453209, 0.026979140970589857, 0.0473630606595959, 0.036540233729673285, 0.058594267283167155, 0.2112219530556883, 0.0174145758085485, 0.19083254571471894, 0.06709583609231881, 0.020250747013571005, 0.07018133159726858, 0.05838164833507367, 0.020443159188809137, 0.09631567102457796, 0.15042149701288768, 0.07146881786840302, 0.13810809488807405, 0.2915957016604287, 0.1349380471344505, 0.10694868796105896, 0.05274572629215462, 0.08902399122182812, 0.05347797414287925, 0.07557172235101461, 0.18436290430171148, 0.14906947527612957, 0.13009235715227468, 0.10823823019329991, 0.09800369651722056, 0.19573899172246456, 0.13730285024004324, 0.1318979524075985, 0.19219823314675263, 0.1544901965452092, 0.09704272129705974, 0.26258786820939606, 0.10334884255592312, 0.1475222525852067, 0.16976160423031875, 0.13293600242052758, 0.20229119727654116, 0.13509024253913335, 0.12177885110889163, 0.06626832871032612, 0.14898068218358926, 0.15033193039042608, 0.18571112624236516, 0.18710812128015927, 0.11578890681266785, 0.19535610798214162, 0.12767283698277815, 0.10397168342024088, 0.1263665213648762, 0.13412102311849594, 0.117785211120333, 0.14726720484239714, 0.07653188332915306, 0.20120912391160214, 0.14192455581256322, 0.09844146016985178, 0.2083948776125908, 0.1342854592949152, 0.12192709743976593, 0.1476303839257785, 0.0957544818520546, 0.13022605569234916, 0.12086976346160684, 0.10632093450320618, 0.17349434750420706, 0.13943286665848323, 0.10563792793878488, 0.11772787491125719, 0.12249064791415419, 0.2817809097468853, 0.29955670876162394, 0.22801471767680986, 0.10914072248020343, 0.2621607168444565, 0.38875504955649376, 0.5219133400491306, 0.17714966993246758, 0.3024578259459564, 0.5545015313795635, 0.9767766722611019, 2.959706566163472, 4.852621027401515, 12.25506591796875, 19.419992719377788, 27.251977852412633, 29.272677285330637, 34.445253304072786, 44.46637610026768, 45.410309723445344, 50.25076184953962, 54.11092390332903, 50.60866355895996, 57.87213666098458, 51.55596358435494, 60.62832028525216, 62.54708617074149, 63.141045979091096, 70.82719189780099, 73.10385949271065, 77.00649588448661, 78.09946141924176, 80.64239093235561, 77.98642117636544, 73.7517442703247, 59.69004249572754, 46.384881428309846, 36.11456496374947, 33.39198630196707, 30.57348428453718, 29.1790155683245, 26.393427167619976, 25.27396467753819, 24.06866066796439, 27.405764068875992, 27.461030040468486, 27.243082421166555, 39.73308604104178, 54.94795601708548, 73.74968760354179, 86.4992846080235, 96.53013488224575, 95.07635634286063, 96.45288481031145, 90.08032362801688, 85.56885133470807, 65.88378483908517, 65.13941042763847, 60.07639707837786, 59.34864970615932, 49.428678785051616, 49.43151017597744, 51.35281215395246, 43.85965245110648, 41.26558767046247, 36.01176636559622, 34.288814612797324, 28.09466232572283, 21.628865003585815, 14.403605256761823, 11.194722175598145, 4.322693645954132, 1.648457184433937, 0.33025802991219927, 0.20139622315764427, 0.31460211000272204, 0.18288896339280264, 0.24428378897053854, 0.2147230173328093, 0.13573421298393182, 0.11629573175949709, 0.15171202990625585, 0.08266073731439454, 0.13648373633623123, 0.16527647418635233, 0.289726907653468, 0.17110293225518294, 0.11141633215759482, 0.16072967887989112, 0.1256695437644209, 0.1943982879498175, 0.08847705807004656, 0.16253900607781752, 0.1341464410402945, 0.11276898493192025, 0.08120069280266762, 0.1042974887947951, 0.14837879448064736, 0.21787037487540925, 0.10663600545376539, 0.18842640625579016, 0.07001380130116429, 0.2315336274249213, 0.16569830583674566, 0.13207473792135715, 0.20449803742979253, 0.13156894434775623, 0.08450954846505608, 0.22786476143768855, 0.10744399816862174, 0.18672253697046212, 0.12094675004482269, 0.17491757470582212, 0.13325381465256214, 0.1243011150509119, 0.16842118544237955, 0.16663792755986961, 0.20498722046613693, 0.20571588565196308, 0.15917780143874033, 0.49402864490236553, 0.21994282438286714, 0.2808968057589871, 0.2589119183165686, 0.30277722594993456, 0.16640117312116282, 0.18420021874564035], [0.03184289185862456, 0.005532552321840609, 0.026953276912016527, 0.04003051608534796, 0.04451919486746192, 0.010827910005381065, 0.010999966130059744, 0.0481621408169823, 0.08289637217032057, 0.12358403924320426, 0.12153087370097637, 0.09453514763819319, 0.022779864159279635, 0.024842383306739584, 0.06673484867704765, 0.1369017410491194, 0.06510348764381238, 0.038744057794766765, 0.01593990547449461, 0.04303985960515482, 0.010284618042143328, 0.04940643833417978, 0.044348326179065874, 0.03902026225945779, 0.0807553024164268, 0.029371019319764206, 0.03950614083026137, 0.02602995020736541, 0.028374427796474526, 0.01700549722383065, 0.020829011519838656, 0.0305548118693488, 0.022770897319008197, 0.025329274591058493, 0.046534328521894555, 0.037765990277486186, 0.03537344866033111, 0.03127766540274024, 0.04242064890318683, 0.03950797626748681, 0.028287692361378243, 0.03825067123398185, 0.11021305208227464, 0.01981666441341596, 0.01593294709787837, 0.02700396517424711, 0.02441270779153066, 0.07841567974537611, 0.07377190821404968, 0.012707954971119761, 0.02080154442228377, 0.02362737475362207, 0.014414791150816848, 0.034750044611947875, 0.004261655807827732, 0.10821105486580304, 0.1277499592729977, 0.09214705721076046, 0.15306842140853405, 0.15105261600443295, 0.20454738049634866, 0.32729535603097504, 0.379964465541499, 3.042111332927431, 7.677586606570652, 10.850153190749031, 11.012400576046534, 11.211899859564644, 21.877457652773174, 17.159111431666783, 21.90049093110221, 22.592001710619243, 14.211304306983948, 17.698321172169276, 16.280103513172694, 17.00874546595982, 18.079513243266515, 19.491366352353776, 26.545648302350724, 34.794598306928364, 39.60632310594831, 43.50872673307146, 43.43085132326399, 39.62025077002389, 42.29737779072353, 44.97582844325474, 42.28639963694981, 38.62795421055385, 31.225940976824077, 30.83326700755528, 29.963224002293178, 20.883738449641637, 30.647993292127335, 54.59634242738996, 56.117278780256, 49.43293455668858, 58.927019119262695, 70.93308244432721, 76.8343403679984, 76.80875015258789, 69.94704968588692, 63.879702023097444, 59.056186131068635, 48.24741901670183, 48.7922237941197, 31.749838624681743, 33.9778618812561, 25.095376866204397, 22.320542539869034, 19.615263155528478, 24.736596209662302, 28.34050175121852, 18.17043215887887, 19.446182216916764, 16.667451688221522, 13.651382855006627, 4.605576523712703, 4.670586475304194, 4.543385803699493, 1.3873085975646973, 0.3262397455317633, 0.04697165112676365, 0.058651528853390894, 0.03731112414970994, 0.06507093153361763, 0.03633784369698592, 0.010794850931103741, 0.056933071065161905, 0.03575473784336022, 0.044145108333655765, 0.0415985867647188, 0.03396285917343838, 0.023003402432160716, 0.06344109720417432, 0.12107917293906212, 0.044469122375760756, 0.07052343538297073, 0.01762387841673834, 0.057405087165534496, 0.04931005922013095, 0.010939432324708571, 0.0078982273449323, 0.042479460925928185, 0.045545723355774365, 0.05010028788819909, 0.07697464099952153, 0.018792553206107447, 0.013910525129176676, 0.03194443801684039, 0.07738427937562976, 0.05970090361578124, 0.008371877018362284, 0.019960045648206557, 0.045997532683291605, 0.010509067248286945, 0.0434160428121686, 0.052449332017983706, 0.0511591146433992, 0.040610924762274535, 0.06359731632151774, 0.0137591380293348, 0.023010387950177704, 0.08012726397386619, 0.022637063071929982, 0.09064402750560216, 0.0720210639493806, 0.028424390026235154, 0.04471381567418575, 0.020154298349682773, 0.06993818535868611, 0.057516543327697685, 0.16097659777317727, 0.021049208007752895, 0.08189050507332597, 0.08316827472299337, 0.05822605346994741, 0.01897292647377721, 0.11791519128850528, 0.05462692391925624, 0.14485624778483594, 0.04510614122929318, 0.03362169855141214, 0.03981429072363036, 0.047723718985382996, 0.03359829927129405, 0.07149330619722605, 0.032844677567481995, 0.02877428169761385, 0.03810329342793141, 0.03062556271574327, 0.020291431973289167, 0.08809799448187862, 0.05271684444908585, 0.043040745093354156, 0.04151593102142215, 0.01820127779085721, 0.009004050283692777, 0.021159212104976177, 0.03202374858249511, 0.040592984296381474, 0.019329759558396678, 0.078343341127038, 0.07149421543415103, 0.031611066976828237, 0.09004423647586789, 0.04633491047258888, 0.0700901500614626, 0.03611098229885101, 0.02054454928397068, 0.018866710298295532, 0.09963627212813922, 0.014567799101184522, 0.041881861564304144, 0.010221544819484864, 0.06626770445810896, 0.018854605233562843, 0.03716144610994628, 0.03262445563450456, 0.046203691978007555, 0.04122020171156951, 0.03504812165296503, 0.023099639053855623, 0.007496726300035204, 0.02348606813965099, 0.07967308655913387, 0.015265002314533507, 0.028830739203840494, 0.0724478896175112, 0.05592408949243171, 0.11947146563657693, 0.04245557649327176, 0.04035148350521922, 0.06799950903015477, 0.10104820172169379, 0.06564834447843687, 0.2523502946964332, 0.44043553354484694, 1.1052717715501785, 3.679229659693582, 8.916541610445295, 15.216921431677681, 16.168802056993755, 17.28195037160601, 25.52299506323678, 27.609943832669938, 24.86037836756025, 22.886956214904785, 24.14821754183088, 22.78639841079712, 24.072648933955602, 31.303847653525217, 40.75464841297695, 37.45864534378052, 48.335487433842246, 51.62330205099923, 58.06026608603341, 64.75438295091901, 61.89161396026611, 58.490609713963096, 57.29430014746529, 58.745309829711914, 59.73285729544503, 51.74397141592843, 44.61372307368687, 38.18736546380179, 37.88193655014038, 38.804657323019846, 29.164045674460276, 44.377230712345664, 65.49381719316754, 61.64600208827427, 58.10056216376168, 64.5952900477818, 76.71119744437081, 83.94106905800956, 89.44535555158342, 88.71524579184396, 83.19782720293317, 84.18276909419468, 77.5020066670009, 70.89971024649483, 51.26620633261544, 47.1415958404541, 38.732253619602744, 29.764370032719203, 25.94189327103751, 23.915405988693237, 21.8282105582101, 20.86181514603751, 26.367444378989084, 21.260263068335398, 19.204268523624965, 11.754020026751927, 10.635795184544154, 8.334886193275452, 3.7036026375634328, 1.4218411445617676, 0.24428419609154972, 0.11502404856894698, 0.09199971333146095, 0.0423562050397907, 0.05833563009010894, 0.04987568601167627, 0.08579612549926553, 0.03101899428293109, 0.036924111523798535, 0.053294165791677575, 0.046939312147774866, 0.021830558045102016, 0.0565608708587076, 0.06578139162489346, 0.02732928030725036, 0.005209400867378073, 0.08735417760908604, 0.018917390078838383, 0.02198496038493301, 0.08179500805480139, 0.050543120197419605, 0.03813750855624676, 0.0399499196958329, 0.02638246780926628, 0.13105400412210397, 0.04857500562710421, 0.049650622731340785, 0.06939359315271888, 0.14846712616937502, 0.13416322799665586, 0.03892581357753702, 0.03604348502787096, 0.028290306417537586, 0.057011570781469345, 0.03881999264870371, 0.01381180337297597, 0.09519302126552377, 0.026015580532007983, 0.13908305471496923, 0.08868887634681803, 0.021597681434026787, 0.006151542499927538, 0.0476748203592641, 0.12188536753611905, 0.08969929641378777, 0.061034360634429116, 0.097331560083798, 0.11594583839178085, 0.13305280543863773, 0.12462765324328627, 0.1404832795794521, 0.0308920743076929, 0.0752793958942805, 0.07185149804822036, 0.04940209571006043, 0.05897713066743953, 0.1790484009044511, 0.10500103461423091, 0.19083498844078609, 0.13397156899528845, 0.07453144674322434, 0.06170420361948865, 0.20546547908868107, 0.15900324151984283, 0.20756961618150982, 0.3682115062006882, 0.18654796348086425, 0.0833026517980865, 0.06815910725189106, 0.1906579179423196, 0.21652619700346673, 0.121414789929986, 0.1267177310905286, 0.14725826175085135, 0.11432067916861602, 0.13606552806283745, 0.18606657002653393, 0.1405303291976452, 0.09199079738131591, 0.12335892846541745, 0.18662014603614807, 0.1406681260892323, 0.10968690245811429, 0.17094032812331403, 0.11159511934965849, 0.1519100535660982, 0.15537696039038046, 0.10262426893625941, 0.07927578394966465, 0.19598094373941422, 0.08199818179543529, 0.12100310916347162, 0.09849995667380945, 0.10910928595278944, 0.08158901160848991, 0.14786982536315918, 0.16580239310860634, 0.17600371928087302, 0.08878311129020793, 0.1607678939721414, 0.14239013940095901, 0.07685034695480551, 0.17414891666599683, 0.20260900950857572, 0.15131866958524498, 0.0840260786935687, 0.19817695447376796, 0.1865529032158, 0.24666099569627217, 0.2043571735599211, 0.20410246508462088, 0.13465344240622862, 0.36835511135203497, 0.1474751215428114, 0.2822593040764332, 0.23472103210432188, 0.3592606522142887, 1.611171848007611, 5.401260341916766, 12.475046753883362, 18.075900179999216, 19.376186064311437, 26.577941792351858, 41.0711145401001, 42.78082650048392, 56.42461150033133, 62.15713936941964, 54.54500218800136, 56.67241900307791, 57.74285152980259, 60.25335380009243, 55.31264959062849, 56.53357662473406, 68.57677459716797, 77.47445705958775, 87.42953722817558, 87.7967425755092, 87.39272567204067, 82.18589850834438, 80.92848300933838, 76.717054775783, 67.82584108625139, 59.19426768166678, 51.94947133745466, 48.86437736238752, 51.017839499882285, 35.083094460623606, 49.033972467694966, 73.37868853977749, 70.12825175694057, 65.72272559574672, 72.50495951516288, 86.18118218013218, 92.42324229649135, 101.2367890221732, 98.82803617204938, 89.5177696772984, 91.32201535361153, 84.89103371756417, 83.68609796251569, 67.71526745387486, 68.14812632969448, 64.72208772386823, 55.797050203595845, 56.63368974413191, 55.313959326062886, 57.888211318424766, 41.49497549874442, 39.95213147572109, 31.454835483006068, 24.264591182981217, 12.800901634352547, 10.6585487978799, 7.606912136077881, 2.427088277680533, 0.6893710600478309, 0.11004188483847038, 0.1673897850726332, 0.16490579050566467, 0.1865211206355265, 0.14263017794915608, 0.14753317699900695, 0.1311570057379348, 0.10796167967574936, 0.08862077857234649, 0.09308877560709204, 0.08381789736449718, 0.167769425415567, 0.21925944462418556, 0.19817968218454293, 0.13635697242404732, 0.17787693733615534, 0.236617456057242, 0.1402997494276081, 0.13982611841389112, 0.1532251358564411, 0.11086237616837025, 0.18682100597236836, 0.1033070787255253, 0.14833872020244598, 0.214879609644413, 0.11294112926615135, 0.12837156520358153, 0.1726151289684432, 0.24905313019241604, 0.25827439395444735, 0.12503651130412305, 0.08895877722118582, 0.09317997071359839, 0.1118324708991817, 0.19071810399847372, 0.14614977980298655, 0.11684472087238516, 0.13591794669628143, 0.2376441609646593, 0.10875674629850046, 0.15757013484835625, 0.12479579422090735, 0.14182677891637596, 0.20922650370214665, 0.1795102118381432, 0.1953563251133476, 0.2195875977299043, 0.17367269364850862, 0.3232784558619772, 0.17056773097387382, 0.28009154754025595, 0.2719142777579171, 0.26040265975253923, 0.15054425756846154, 0.11078132516039269], [0.023035634541884065, 0.07362474753920521, 0.056489682357226095, 0.03406013395371182, 0.011827442129807813, 0.07180652474718434, 0.06292969214596919, 0.08775329869240522, 0.05460117690797363, 0.0745367935991713, 0.021088863290580254, 0.006567414068350834, 0.03052587913615363, 0.06487760333610432, 0.07979617959686688, 0.10346223254288946, 0.08927694907678024, 0.05747474557054894, 0.043262673541903496, 0.0393462270897414, 0.030494554567017725, 0.09811552587364401, 0.03604379376130445, 0.02695692403774176, 0.052670453009860854, 0.05521943766091551, 0.03505328530445695, 0.05433368483292205, 0.017022450421271578, 0.030626064831657068, 0.023517128080129623, 0.03575949776651604, 0.06491121117557798, 0.028434021830824868, 0.033611428923904896, 0.03774120339325496, 0.03667067190898316, 0.04218413195173655, 0.09160386957228184, 0.0739298847370914, 0.05479911235826356, 0.08829263225197792, 0.07418753805437259, 0.02279942632386727, 0.02929224818944931, 0.023466582310252955, 0.01750876155814954, 0.06423072197607585, 0.008309030256766294, 0.05878676088260753, 0.0457258336911244, 0.09218154036040817, 0.08824178962303059, 0.05549331135781748, 0.11270281419690166, 0.09619820304214954, 0.17072164985750402, 0.047442493361553977, 0.10726602521858045, 0.013093009175333594, 0.14338314825935022, 0.16681111683802946, 0.14721996523439884, 0.24140061225209916, 1.6001054303986686, 1.7792660338538033, 4.488275732312884, 5.337190134184701, 18.134395326886857, 18.06059329850333, 17.25941388947623, 30.743551867348806, 19.570598397936138, 25.132443768637522, 21.21423646381923, 18.4685845715659, 22.095742259706768, 21.486089944839478, 22.09973747389657, 35.73687131064278, 33.328285217285156, 33.7709584236145, 39.8487422806876, 38.81048338753836, 48.27620540346418, 45.26728105545044, 52.52853768212454, 53.287367820739746, 53.678721632276265, 56.9980011667524, 57.25107887813023, 55.755364486149375, 47.349350452423096, 82.13794204166958, 110.50795105525425, 68.4527839933123, 60.75271388462612, 79.31421497889927, 79.25496768951416, 73.27664729527065, 49.997409684317454, 40.329425607408794, 46.75780861718314, 42.81536252158028, 40.602451596941265, 35.69588736125401, 33.774390833718435, 27.620322704315186, 18.483615262167795, 27.74811049870082, 33.53254835946219, 23.583266462598527, 13.745915702411107, 15.58528539112636, 9.277760216167994, 4.568764533315386, 2.8373598626681735, 1.3536563004766191, 0.4723588962640081, 0.0825852027961186, 0.015551384804504258, 0.016767886134662797, 0.014316756411322525, 0.07541597142283406, 0.05587448858256851, 0.06136257480829954, 0.021562068523573022, 0.0767739439117057, 0.05115800184596862, 0.02328349320617105, 0.017468851824690188, 0.0729080042136567, 0.053657785922821076, 0.025800086291772977, 0.03953833392422114, 0.04566929476069553, 0.0824104461020657, 0.08957538913403239, 0.01141835845607732, 0.032859099829303365, 0.013314164093961673, 0.06629014361117568, 0.019482967676594853, 0.07600980491510459, 0.02229031132135008, 0.03399238223209977, 0.053265127885554514, 0.03581009951553174, 0.0711868390707033, 0.04102377260902098, 0.09657678487045424, 0.012537767362248684, 0.006343403365463018, 0.010148711718751915, 0.03920521054949079, 0.09292404766061477, 0.031330686129097424, 0.06374734719949109, 0.06884720961430243, 0.058538749547941346, 0.0829970192696367, 0.024401581513562372, 0.02136670981001641, 0.04005071607285312, 0.055494312196969986, 0.009372722956218889, 0.09863524977117777, 0.05377253297982471, 0.11579878628253937, 0.04686701424153788, 0.058461294775562625, 0.03791571581470115, 0.11055427377245255, 0.0424062062853149, 0.010448415547476282, 0.05151478912947433, 0.022920322604477406, 0.027036799483799508, 0.11057788679110152, 0.05085391977003642, 0.012606795577864562, 0.060748744889029434, 0.014603186398744583, 0.0817184964460986, 0.03825667966157198, 0.041572385134973695, 0.01824489062918084, 0.05943082632230861, 0.006820712038981063, 0.03570809873885342, 0.020862914522045424, 0.010630954190024307, 0.12409443328423159, 0.02808914622957153, 0.002099531960474061, 0.022421324559088265, 0.09524298179894686, 0.09060994469161544, 0.05175439002258437, 0.044119032232889106, 0.018891298711033802, 0.01428271600577448, 0.06832507691745247, 0.033168674646211524, 0.05274145830688732, 0.01700264398407723, 0.012943102130001145, 0.04788051825016737, 0.004522244637233338, 0.019487408688291907, 0.03841760441926973, 0.03646935396162527, 0.04494704512347068, 0.04781590475301657, 0.090437569655478, 0.024769021796860864, 0.0533037942035922, 0.011762434234177428, 0.07045452336647681, 0.033809503473873646, 0.07364635887954916, 0.06586340615259749, 0.06543728616088629, 0.014902087859809399, 0.04285372727151428, 0.04323802915002618, 0.034134345328701396, 0.04214530617796949, 0.024792648386210203, 0.03758239905749049, 0.03413450478443077, 0.12885295865791185, 0.15989281449999126, 0.03546831803396344, 0.029515554064086506, 0.011567834631672927, 0.10659840782838208, 0.13217237911054067, 0.23734612124306814, 1.2673858382872172, 4.481167725154331, 7.109808479036603, 12.132730722427368, 15.894565343856812, 28.23535987309047, 28.402943474905832, 36.152033124651226, 39.57186698913574, 28.60466878754752, 26.045141765049525, 25.533042158399308, 33.05223328726632, 34.982383796146934, 35.76439659936087, 46.57108620234898, 57.03794983455113, 59.94015680040632, 62.04636423928397, 64.01027257101876, 62.25567177363804, 66.68282072884696, 65.14722715105329, 66.53865255628313, 65.18712370736259, 66.93287249973842, 72.71177959442139, 78.15544305528913, 69.05880587441581, 59.537932532174246, 95.20760781424386, 115.42325265066964, 77.40136201041085, 78.46430437905448, 94.36456898280552, 88.75345393589565, 91.6415491104126, 76.93343557630266, 65.81121785300118, 71.39653423854283, 64.566545350211, 67.72578007834298, 49.19640050615583, 49.574181011744905, 36.47112914494106, 28.235149690083094, 30.618550300598145, 36.176490783691406, 31.87466996056693, 24.96711138316563, 22.85872742107936, 16.47453669139317, 11.531039306095668, 6.2499167919158936, 4.440842117582049, 1.5691266698496682, 0.4879547251122338, 0.04985883120181305, 0.056711312250367234, 0.043250062968581915, 0.08709091959255082, 0.04642839224210807, 0.0545275931778763, 0.05737162860376494, 0.03274976408907345, 0.0714758610618966, 0.028053182177245617, 0.049376402981579304, 0.0859246603878481, 0.07770301441528968, 0.050375667932842455, 0.05454475332849792, 0.04506393974380834, 0.11184794149760689, 0.06293272519750254, 0.05109552573412657, 0.027936134886528765, 0.045142371606613906, 0.03175206994637847, 0.06839806692940847, 0.019662185738395368, 0.010708576051651366, 0.05558171768539718, 0.055641201457806995, 0.003071479091886431, 0.06838046573102474, 0.05206649238243699, 0.05485638749918767, 0.0670323319999235, 0.016795670447338904, 0.04454233969694801, 0.0116410197224468, 0.027620707705084766, 0.012748578014517469, 0.10890903669808592, 0.15997445583343506, 0.12292864226869174, 0.09867794997990131, 0.024241767856957655, 0.05617109998794539, 0.05091881485921996, 0.0767075221187302, 0.07589963118412665, 0.12676364076989038, 0.0509682427426534, 0.09985304371054683, 0.05972565657326153, 0.12062714648033891, 0.05786155802862985, 0.08360313424574477, 0.03699826183063643, 0.03654690712158169, 0.019382646274087683, 0.11777067690023355, 0.19877638587994234, 0.1668824308684894, 0.0755268983276827, 0.07211546852652516, 0.13995366942669663, 0.127767289057374, 0.18982289917767048, 0.12910001325820172, 0.14189768582582474, 0.09806912086371865, 0.17261469470603125, 0.14410053619316646, 0.17127456090279988, 0.09150414528059107, 0.14387828883315834, 0.14984247594007424, 0.10642021096178464, 0.12450683329786573, 0.1670761661870139, 0.19965575369341032, 0.2380026445857116, 0.10673728359064885, 0.1423588182244982, 0.12574844381638936, 0.08065355609038047, 0.1259954712752785, 0.17420412227511406, 0.15760210741843494, 0.15490299010915415, 0.12408487951116902, 0.14419405188943657, 0.14843712135085038, 0.07909070673797812, 0.08920148919735636, 0.09635092091879674, 0.1510941559182746, 0.09652458517146961, 0.08986267407557794, 0.11163994337299041, 0.08089773370219128, 0.16128891387156077, 0.18689280854804174, 0.11058186979166099, 0.10467900867973055, 0.22027236170002393, 0.12408416026404925, 0.14780049265495368, 0.15022666246763297, 0.1376429862741913, 0.16304165124893188, 0.19735864124127797, 0.13606532450233186, 0.15629157131271704, 0.20326857268810272, 0.2715765844498362, 0.21405457891523838, 0.16849358512886933, 0.13755340608102934, 0.09555879235267639, 0.3020161810730185, 0.243747990578413, 0.23147299353565487, 0.45545664323227747, 2.0119312405586243, 3.1305165205683028, 8.063299349376134, 11.866012828690664, 26.396857840674265, 34.22786154065813, 45.76030090876988, 61.729637554713655, 57.92748948505947, 64.8661447252546, 62.12284306117466, 62.17074394226074, 62.19570881979806, 59.33301625932966, 63.42043999263218, 77.23249994005475, 73.92132200513566, 79.0119822365897, 76.77690655844552, 74.68825026920864, 83.91831370762416, 81.75067029680524, 86.32113974434989, 79.71345152173723, 84.00708389282227, 89.62720380510602, 93.59249210357666, 85.87592697143555, 72.38152476719448, 99.95389447893415, 111.88397925240653, 85.3949031829834, 83.22105503082275, 100.44948863983154, 92.9732894897461, 94.18128940037319, 76.28136798313686, 68.32376984187535, 81.30538804190499, 79.27383204868862, 82.90514128548759, 73.82806328364781, 77.40159824916294, 69.09795897347587, 53.673698084695, 62.92602007729666, 58.68830680847168, 42.217098304203574, 30.534866196768625, 26.30468303816659, 15.365993295397077, 8.190719757761274, 4.6380980014801025, 2.662473487002509, 0.6323264038988522, 0.22101007854299887, 0.15337499710065977, 0.22530448596392358, 0.14008337818086147, 0.19851426780223846, 0.11084354682160275, 0.19244752691260406, 0.15038511396518775, 0.18275075938020433, 0.1368380401815687, 0.10425232550395386, 0.13311159371265344, 0.1681323873677424, 0.14804574235209397, 0.21828722607876572, 0.15215672818677767, 0.15194190399987356, 0.2159227350992816, 0.2254844063094684, 0.15979236417583056, 0.2039998434484005, 0.09525441511401109, 0.13425461309296743, 0.1707236583211592, 0.10727993518646274, 0.10025205622826304, 0.10346710442432336, 0.26645397075584953, 0.16628728780363286, 0.18379312487585203, 0.1191918413553919, 0.22210767678916454, 0.10502240846731833, 0.17507651474859032, 0.12583967963499681, 0.16577712446451187, 0.13194553128310613, 0.11986619659832545, 0.2823444466505732, 0.2768193259835243, 0.15262046615992272, 0.2643017933837005, 0.15722553405378545, 0.19805266042905195, 0.1220144113259656, 0.1794170489800828, 0.1534783515547003, 0.17741670060370648, 0.13940867009971822, 0.18167932544435772, 0.15907683542796544, 0.2325095779129437, 0.17685228160449437, 0.21814640292099544, 0.129381320306233, 0.085398483622287, 0.08474181778728962], [0.02556813757733575, 0.052807673146682124, 0.06676298752427101, 0.05415962363726326, 0.06999166748885598, 0.07480123905198914, 0.021009432284959724, 0.037134565945182524, 0.020988606348899857, 0.05433519796601363, 0.049388599648539505, 0.10784441525382654, 0.015482879909021514, 0.03992617775553039, 0.07378712096916777, 0.04199434909969568, 0.007267450165402676, 0.07378551284117357, 0.014915246350158538, 0.10313652894858803, 0.022279268163921576, 0.038073353070233545, 0.09933901272181954, 0.037457558792084455, 0.09038777197045939, 0.049211630930325816, 0.05418770820168512, 0.07274319484297719, 0.05710222305996077, 0.015821996444304074, 0.02584036921949259, 0.0401860261335969, 0.055581059506429095, 0.053243377445531745, 0.0017685284775715055, 0.030342206491955688, 0.04019662145791309, 0.07995355222374201, 0.043029651045799255, 0.042185882572084665, 0.04456758459231683, 0.05283275180097137, 0.03397958506164806, 0.043099390875015936, 0.06733007316610642, 0.05356677741344486, 0.06754336386386837, 0.051977526263466904, 0.03928824966507299, 0.0441653218918613, 0.04461576057864087, 0.04056118814540761, 0.004000383778475225, 0.03467548718409879, 0.01904348054501627, 0.016220800312502042, 0.017565368342080286, 0.02088277693837881, 0.09533223629529987, 0.030100797303020954, 0.0315167031117848, 0.06075590343347617, 0.04349721595644951, 0.03134718131540077, 0.05081648838573268, 0.11932650341519288, 1.0496145295245307, 1.7906117907592227, 6.121700814792088, 12.926023926053729, 15.736558096749441, 27.328241280147008, 34.39039380209786, 36.61110060555594, 31.56519024712699, 19.261099576950073, 27.014267819268362, 30.516995429992676, 29.977005754198345, 38.57378952843802, 32.39780330657959, 45.67707191194807, 35.58671726499285, 37.824374198913574, 40.9332275390625, 48.21509599685669, 60.70140838623047, 51.34871619088309, 47.21526411601475, 51.491807392665315, 43.78545263835362, 52.6865953036717, 45.63045992170061, 68.29873548235211, 108.80974183763776, 67.12013339996338, 32.20337533950806, 41.83451311928885, 49.438128335135325, 49.353061539786204, 39.23132882799421, 49.84394482203892, 50.58725963320051, 43.635625158037456, 41.23782614299229, 44.46518448420933, 39.333488191877095, 35.19053445543562, 32.43477119718279, 36.35387829371861, 21.64097571372986, 11.705782158034188, 11.779052649225507, 5.569580452782767, 1.8025907022612435, 0.6493702807596752, 0.23318542593291827, 0.12246702132480485, 0.016293152501540523, 0.0743268887911524, 0.03449686962578978, 0.025110401246430616, 0.009296352991701236, 0.01998146190973265, 0.044281917956790755, 0.02716262871399522, 0.01599454620320882, 0.034857952035963535, 0.03383994594748531, 0.05147064703383616, 0.06565455985920769, 0.031729495086308034, 0.060635415970214775, 0.06820642828409161, 0.04634857277518936, 0.011548710970341094, 0.10522141600293772, 0.010433670981521053, 0.03432238773841943, 0.04548233461433223, 0.032798584683665206, 0.003132671076205692, 0.01964544627948531, 0.025909868168777654, 0.02119597513228655, 0.08370722151760544, 0.017735120840370655, 0.018455845470141088, 0.07752114667424134, 0.09064456354826689, 0.03340340026521257, 0.05090417207351752, 0.006836161857271301, 0.03854037176019379, 0.04482079350522586, 0.018430268092613136, 0.10081492138228246, 0.06532538895096097, 0.047784295199172835, 0.06720414385199547, 0.03701249749532767, 0.10400831074054752, 0.061339294271809716, 0.1429366043635777, 0.06477411317506007, 0.052001583722553084, 0.036660242825746536, 0.015004341390782168, 0.030019529163837433, 0.03910373563745192, 0.046942450372236114, 0.1431888158300093, 0.03724009510395782, 0.040035401537482224, 0.06493968250496046, 0.05775195426706757, 0.0282427326310426, 0.010793400562501379, 0.054497754600431235, 0.13565387443772384, 0.09033228137663432, 0.01109125538329993, 0.034503196964838674, 0.017030740422861915, 0.06169771682471037, 0.05292825221217104, 0.046413722315004895, 0.08336734332676445, 0.06513401493430138, 0.0596313402056694, 0.035122757112341266, 0.0348716754067157, 0.032658630050718784, 0.06807273652936731, 0.023065695339547734, 0.053582899405487945, 0.03452324428196464, 0.05852932469653232, 0.09738569360758577, 0.07606461697391101, 0.04496585072151252, 0.0113308265905029, 0.14333577294434818, 0.07744223305157252, 0.05245371535420418, 0.04425646610824125, 0.017266124220831052, 0.021190102411700145, 0.018001734212573086, 0.0715704895555973, 0.028582286821412187, 0.03750286118260451, 0.032443941570818424, 0.058451266027987, 0.05409886761169348, 0.06238570383616856, 0.017140345880761743, 0.03619688143953681, 0.01818806671404413, 0.03317555159862552, 0.03292155897776995, 0.014018642899048115, 0.01908132583568139, 0.04648189812100359, 0.02322549033643944, 0.06688755298299448, 0.051598605167652876, 0.08874630755079643, 0.020732669725215862, 0.03240756191579359, 0.057808550872973034, 0.023403266511325325, 0.035319518697048934, 0.017874895661537136, 0.05216243044872369, 0.02312929103417056, 0.037627477531454394, 0.03004126264048474, 0.047605955840221474, 0.2054987001631941, 0.4850602575710842, 1.0140335644994463, 2.725753120013646, 5.361576574189322, 14.941069262368337, 22.24185766492571, 29.593096937452042, 42.02105140686035, 40.43839073181152, 45.50817510059902, 40.35084342956543, 35.62038823536464, 41.84047467367989, 39.672025271824424, 42.804679666246685, 53.766598973955425, 52.35421085357666, 58.25624697549002, 54.039555481501985, 55.211303165980745, 62.4053498676845, 64.29718453543526, 76.29506983075822, 67.73128305162702, 67.64397198813302, 73.66046578543526, 68.51697145189557, 70.89348466055733, 57.99916362762451, 83.58596747262138, 119.59522901262555, 78.56230872017997, 45.04880884715489, 65.49234417506626, 68.14823750087193, 71.43565954480852, 52.61865234375, 55.176694188799175, 58.32458250863211, 56.69739082881382, 56.64795439583914, 51.317424978528706, 49.63769449506487, 44.45628036771502, 36.106977530888145, 42.20661347252982, 37.472896099090576, 25.969317810876028, 19.150277546473912, 13.032664009502955, 6.562475425856454, 2.6110298931598663, 1.2975818408387048, 0.5528167560696602, 0.12432567801858697, 0.005465788716849471, 0.009812366999020534, 0.01699122254337583, 0.011292988085187972, 0.04946909425780177, 0.05812311292226825, 0.014707721503717559, 0.03126450860872865, 0.031918093894741366, 0.055007236011858494, 0.09957663568535022, 0.025114894844591618, 0.05074221594259143, 0.055543451703020504, 0.02391415079390364, 0.0714072340301105, 0.019421857116477828, 0.04659957644928779, 0.025735265841441493, 0.03621213829943112, 0.02842345364790942, 0.002977143640496901, 0.028714835244630064, 0.013205306720919907, 0.050288608497274775, 0.06222663487174681, 0.09138638552810464, 0.029695304775876657, 0.06663154850580863, 0.03269228199496865, 0.06723980765257563, 0.0821603313088417, 0.04036772424089057, 0.008146244616779898, 0.016629646498976008, 0.09602811466902494, 0.043997808559132476, 0.015827638462984135, 0.11110873187759093, 0.09420100306825978, 0.08256621060094663, 0.09383765435112373, 0.07783660438976117, 0.10267371378306832, 0.03372552797996572, 0.024810570192390254, 0.06080162990838289, 0.06496269162744284, 0.02368843781628779, 0.024973857948290448, 0.033338484819978476, 0.13792436117572443, 0.18503749024655136, 0.03444482598985944, 0.02053441197079207, 0.04681848202432905, 0.09069525011415992, 0.07937812060117722, 0.13581670927149908, 0.15368115210107394, 0.23629496193357877, 0.15264037437736988, 0.16373225062021188, 0.11127755817558084, 0.15293612065059797, 0.15541216278714792, 0.20684443866567953, 0.1074668105159487, 0.15855664334126882, 0.21076217772705214, 0.16596393872584614, 0.1428843028843403, 0.1234280304717166, 0.1486661812024457, 0.15104850408221993, 0.1908147952386311, 0.17361128622932093, 0.1523583209408181, 0.1940439162509782, 0.13085964455136231, 0.18880299319114002, 0.1346830129623413, 0.09676889170493398, 0.30208691156336237, 0.16597232541867665, 0.21367069094308785, 0.12088370057088987, 0.11429215355643205, 0.13696264635239327, 0.17823719871895655, 0.1751401884747403, 0.1115143329703382, 0.16415035032800265, 0.11367081903985568, 0.1630832590162754, 0.09323189221322536, 0.15792237594723701, 0.126822171200599, 0.11544331535696983, 0.03956887139273541, 0.20770832231002195, 0.14496201782354287, 0.21008957310446671, 0.17918725631066731, 0.17314368060656957, 0.12215469165572099, 0.18911551285002912, 0.15301616064139775, 0.1848592526678528, 0.14434982995901788, 0.17417403603238718, 0.13427518627473287, 0.07487228166844163, 0.08107242254274231, 0.07330375976328339, 0.22788107341953687, 0.12994003961128847, 0.11448892871184008, 0.1044448869568961, 0.12844590550022467, 0.17387188438858303, 0.3204168565571308, 0.6192683503031731, 1.4305374664919717, 3.443617331130164, 8.591220872742788, 19.766254459108623, 28.101699113845825, 45.512965883527485, 61.20351300920759, 68.2548576082502, 71.18860244750977, 65.13617256709507, 72.0282644544329, 73.88612243107387, 73.01001017434257, 76.11210986546108, 76.2601968220302, 78.02482386997768, 72.82849543435233, 75.59377425057548, 77.88426876068115, 83.05996799468994, 87.10157530648368, 79.05009310586112, 70.43523706708635, 73.50009441375732, 63.31286103384835, 68.97736603873116, 62.67093781062535, 84.19849286760602, 122.28614125932965, 80.3262687410627, 48.14032643181937, 65.58442865099225, 72.28830773489815, 78.00891944340297, 67.68712030138288, 81.36623341696603, 80.02817017691476, 81.01974064963204, 85.53599330357143, 78.58318110874721, 80.386141368321, 69.70590550558907, 61.1710649217878, 58.17697497776577, 35.64445679528372, 21.601032257080078, 19.029896531786235, 8.67908431802477, 3.2543761943067824, 1.1749816366604395, 0.6628343697105135, 0.3461570010653564, 0.11217785200902394, 0.22295330784150533, 0.12447981403342315, 0.14116104106817925, 0.07135702243873052, 0.20644912416381495, 0.1469753940722772, 0.10038651472755841, 0.14451501252395765, 0.09430046273129326, 0.1441650648734399, 0.1000907684543303, 0.15778289628880365, 0.17573972844651767, 0.20690571037786348, 0.2012360617518425, 0.22285330535045692, 0.158857560051339, 0.2576546200684139, 0.07808439859322139, 0.09179497896028416, 0.17316869140735694, 0.054623694092567475, 0.08185085148683616, 0.0766493377408811, 0.15371301610554966, 0.12752429209649563, 0.20315784934375966, 0.08754425562386002, 0.14130932811115468, 0.17005980680031435, 0.16408929574702466, 0.21475455564047607, 0.11074647560183491, 0.17279131737138542, 0.1392048110387155, 0.12814568089587347, 0.1556073094585112, 0.19873000122606754, 0.2793774572866303, 0.16360111694250787, 0.1805144300950425, 0.15413995033928327, 0.2253147725548063, 0.1928658980344023, 0.17277177556284837, 0.11795575411192008, 0.12459255941212177, 0.13364128528961114, 0.1504273052726473, 0.160622701048851, 0.1639186849019357, 0.18543535604008607, 0.3435137814709118, 0.15350699930318765, 0.13281584743942532, 0.13805508773241723, 0.19949875426079544], [0.03413100354373455, 0.0660292740379061, 0.12327997413064752, 0.037420157941856554, 0.020193068144310797, 0.03207386178629739, 0.023740517075306604, 0.07047506940684148, 0.033609294931271246, 0.03778914528499756, 0.0846057308039495, 0.009916520428045519, 0.02172158023209444, 0.015414090028830936, 0.04546308457585318, 0.053668164115931304, 0.01952022942714393, 0.07898330821522645, 0.03628512152603694, 0.017777724357854043, 0.01723288109392992, 0.00875984553048121, 0.031127112052802528, 0.025763307997424687, 0.08103064514164414, 0.05421893438324332, 0.09303665733230965, 0.08383468432085854, 0.047658413382513184, 0.06520965123283011, 0.027099667449614832, 0.047658952817853005, 0.008846813363821378, 0.024214205764500157, 0.028571640606969595, 0.017355885922110507, 0.08972762525081635, 0.04396228725090623, 0.0451411705996309, 0.10360374780637877, 0.0556817133910954, 0.02884104275809867, 0.04942153913101979, 0.02957269349800689, 0.06781422147261244, 0.02170234715699085, 0.03592010700543012, 0.013014459417068532, 0.04918228089809418, 0.013739894776205932, 0.03588179352560213, 0.014501572387026889, 0.04325861590249198, 0.07066820082919938, 0.045568030194512436, 0.047531690182430406, 0.07319456990808249, 0.014750087533944418, 0.061807055957615376, 0.07850520565573658, 0.07803115395030805, 0.10382374921547514, 0.00941187357862613, 0.07227453070559672, 0.04850034302632723, 0.03405444443758045, 0.0260509406881673, 0.18767678790858813, 0.363540525415114, 1.2757337731974465, 4.266930878162384, 11.175048351287842, 22.111080408096313, 25.788400615964616, 26.01497789791652, 25.925113371440343, 27.796292781829834, 23.3034051827022, 31.65745885031564, 41.587678364345, 56.65637561253139, 42.188475200108115, 45.70103972298758, 55.82758406230381, 69.91444873809814, 72.84759603227887, 80.21271433149064, 72.83088561466762, 59.46328108651297, 45.81279454912458, 26.558306183133805, 23.953030484063284, 50.58331653050014, 25.204647711345128, 33.4901886667524, 43.595860617501394, 57.28992278235299, 67.26297446659633, 74.096618107387, 67.74900790623256, 51.80758564812796, 56.413212980542866, 48.69143322535923, 47.31298705509731, 45.559810638427734, 44.278222356523784, 44.684181281498496, 33.119213921683176, 23.406490394047328, 13.87778730051858, 5.787340036460331, 2.99058045233999, 2.308307085718427, 0.7610700641359601, 0.22991632563727243, 0.01495148181649191, 0.04592791499037828, 0.07544781507125922, 0.04555065630535994, 0.01804121646897069, 0.05297242144920996, 0.05775656830519438, 0.02986634649070246, 0.05249900417402387, 0.05258044533963714, 0.05832087195345333, 0.05883442796766758, 0.016645468239273344, 0.033106181570994, 0.030381402067307915, 0.06508882450205938, 0.017086510912382176, 0.04719569321189608, 0.055060049785034995, 0.11611845770052501, 0.01970406831242144, 0.026710183259897997, 0.057425850337105136, 0.02927223140639918, 0.11125866097531148, 0.025871573348662684, 0.006047170243359038, 0.0836119077035359, 0.08247623685747385, 0.02873033976980618, 0.035771626579974375, 0.062315679022244046, 0.02894763382417815, 0.03984691808000207, 0.015457545107762729, 0.039533597749790976, 0.041637097019702196, 0.0211499127825456, 0.05255809439612286, 0.042906612290867736, 0.031939600062157424, 0.05081373353355697, 0.024616775502051626, 0.07981811663401978, 0.06226048019847699, 0.04037255880289844, 0.04977976830144014, 0.028719011627669846, 0.028345646037321006, 0.016890470271131823, 0.08288104406424932, 0.07324410296444382, 0.03575139945106847, 0.03064993569361312, 0.04438366428283708, 0.06544734883521285, 0.044270901940763, 0.03230371891653963, 0.05450289789587259, 0.16943251474627427, 0.01061724778264761, 0.014371748281908887, 0.11406643209712845, 0.16417204987789902, 0.04678505399663534, 0.026247507194057107, 0.017200742282771637, 0.03951607119025929, 0.04808032984978386, 0.029162471581782614, 0.01581875474325248, 0.019121613852413635, 0.02633760477017079, 0.04211295362828033, 0.010241468303969927, 0.014901548424469573, 0.021882082601743083, 0.03175887225994042, 0.09165026779685702, 0.01901562328982566, 0.03391419124922582, 0.0068131306824008265, 0.020135603013581464, 0.08370108756103686, 0.0357652381727738, 0.08367207340363945, 0.023349548590236475, 0.013482064191651131, 0.05040294164791703, 0.08435046592993395, 0.031527943044368706, 0.062457737113748274, 0.025778647977858782, 0.03586127123396311, 0.08901828474232129, 0.020503594606582607, 0.022342244695339884, 0.06435536207365138, 0.04012491726981742, 0.016281278138714175, 0.04441800494013088, 0.042923897970467806, 0.02282641675057156, 0.03489754116162658, 0.02473279311587768, 0.07748339977115393, 0.00634705473203212, 0.055702975285904746, 0.037924143219632764, 0.10448844890509333, 0.038018503692001104, 0.04377625330484339, 0.05433731499527182, 0.0540659247365381, 0.038040298236800094, 0.04700309104685273, 0.03788671183532902, 0.02335289037520332, 0.02803409837984613, 0.007256474013307265, 0.033531378755079846, 0.05380403396806546, 0.07717554164784295, 0.04386403538020594, 0.030750324949622154, 0.017354829103818963, 0.0742944141051599, 0.42826082397784504, 0.6911532187036106, 2.011707378285272, 6.656300859791892, 12.896379436765399, 24.858445031302317, 37.294143268040244, 43.26665844236101, 44.60134138379778, 38.70465537479946, 48.15370866230556, 51.01861422402518, 53.56541735785348, 60.070553643362864, 60.553766114371165, 61.1576965876988, 59.56593377249581, 70.24240371159145, 74.41999421800885, 77.57811028616769, 83.95309638977051, 73.91955716269356, 66.63148743765694, 54.19074828284127, 40.01402255467006, 40.0451192174639, 62.895135334559846, 39.26885257448469, 54.43001297542027, 57.83583232334682, 59.38850457327706, 60.214541162763325, 68.45513943263462, 73.2809065410069, 63.837429182870046, 71.7689368384225, 67.27663462502616, 60.707210132053916, 61.13916574205671, 60.13916710444859, 55.44251837049212, 46.38985286440168, 37.66703224182129, 27.327108723776682, 16.204957008361816, 9.819543395723615, 6.27519303560257, 2.6302603355475833, 0.5943527072668076, 0.24630973168781825, 0.15308921172150544, 0.07317519094794989, 0.05834642558225563, 0.033813615396086655, 0.04204335289874247, 0.033694997296801636, 0.03816819190979004, 0.10391472040542535, 0.0520023267183985, 0.04571482785312193, 0.03984755929559469, 0.03145297510283334, 0.023987315528626953, 0.0620400852390698, 0.0555004766876144, 0.008057244571058877, 0.03901896286489708, 0.03440920629405549, 0.07382853874670607, 0.02636485982553235, 0.04475825293255704, 0.03386283293366432, 0.057616593316197395, 0.036086049529590776, 0.03829329001850315, 0.03561303259006568, 0.05685845596183624, 0.04966303652950695, 0.04196268865572555, 0.04366694131333913, 0.11485478122319494, 0.05737854287560497, 0.03643089120409318, 0.04582221619784832, 0.052306198448474915, 0.07806144375354052, 0.02964917796530894, 0.056743094830640724, 0.01234144767347191, 0.05046125155474458, 0.018246268055268695, 0.0440763625582414, 0.08440084036971841, 0.07440091017633677, 0.052391581902546544, 0.0063974677634957644, 0.03169449625004615, 0.08878045143293482, 0.05728035207305636, 0.06111258893672909, 0.08142904019249336, 0.04782043058159096, 0.06192759770367827, 0.04831357626244426, 0.030678410415670702, 0.04062544201899852, 0.013547379972546228, 0.0958075907879642, 0.08829658811113664, 0.02739339168848736, 0.10120885845805917, 0.20112548768520355, 0.21183600010616438, 0.10156384762376547, 0.13468274154833385, 0.09545700531452894, 0.12365622179848806, 0.23572849375861032, 0.09648993238806725, 0.1328201222100428, 0.15364928809659822, 0.0672294260667903, 0.05562306082408343, 0.10353225735681397, 0.11681619526020118, 0.15456064205084527, 0.12637554588062422, 0.18185968005231448, 0.09753556163715464, 0.10571445311818804, 0.12998860914792332, 0.06556257765207972, 0.2272633079971586, 0.08570232481828757, 0.16352028985108646, 0.10021154090229954, 0.19554023524480207, 0.133634513510125, 0.18033908307552338, 0.1303854707096304, 0.19242499954998493, 0.19752473304314272, 0.1426293229950326, 0.1581807349409376, 0.18257644373391355, 0.14266738880957874, 0.1699951152716364, 0.1292252301105431, 0.09139762206801347, 0.16324753234429018, 0.14991691123161996, 0.18926215783825942, 0.12752125225961208, 0.127272881301386, 0.10030409986419336, 0.09450265259615012, 0.1679441346121686, 0.15577850384371622, 0.22403437697461673, 0.13930887116917542, 0.16048220358788967, 0.1019472334800022, 0.15501374059489795, 0.20491426438093185, 0.11933689857167856, 0.14845853591603891, 0.1222497136997325, 0.10051576886326075, 0.13284089895231382, 0.17682237178087234, 0.21565331598477705, 0.1733258401176759, 0.13200073689222336, 0.13581619358488492, 0.3002698490662234, 0.20437712248946938, 0.17843051334576948, 0.3069555088877678, 0.6171881247844014, 2.4518158308097293, 8.090459857668195, 16.977622747421265, 32.64550311224801, 42.9839049748012, 50.02013724190848, 56.55436216081892, 68.76309054238456, 65.01143850599016, 76.60415349687848, 81.93367889949253, 90.82141154153007, 86.65040792737688, 84.60099506378174, 95.98254040309361, 101.76151697976249, 99.59808417728969, 102.97321333203996, 92.59430694580078, 83.0714533669608, 69.65947764260429, 49.04279667990548, 48.04595252445766, 68.92234325408936, 40.82050691332136, 62.03815146854946, 65.38557815551758, 76.84340776715959, 84.27702835627964, 91.59147344316754, 94.21546758924211, 91.00740786961147, 96.92203412737165, 89.30483518327985, 85.61828776768276, 83.2958732332502, 76.42353507450649, 69.59706197466168, 53.236757142203196, 37.7639422416687, 20.692999976021902, 11.007631506238665, 5.978188378470285, 3.061791236911501, 1.1742721604449409, 0.31759917203869137, 0.15903783323509352, 0.208606431260705, 0.2531034142843315, 0.13728413624422892, 0.09282259310462646, 0.13002439508480684, 0.1499780472368002, 0.1512460256261485, 0.15093178248831204, 0.17285496395613464, 0.11381911286818129, 0.11411904570247446, 0.18718113164816583, 0.10954827775380441, 0.14160869776138238, 0.1753058595848935, 0.07816603992666517, 0.12059891942356314, 0.15883520910782473, 0.23945088258811406, 0.13469583727419376, 0.14399520041687147, 0.10910553365413632, 0.10978304408490658, 0.17144063913396426, 0.08087251255554812, 0.19756525515445642, 0.1699889406029667, 0.13390991730349405, 0.10753077601215669, 0.14631599374115467, 0.19296016011919292, 0.10347182024270296, 0.1659738589078188, 0.1470730352614607, 0.14097799946154865, 0.2997539724622454, 0.08318224575902734, 0.1377210178013359, 0.15295336901077203, 0.30031748222453253, 0.2077360608215843, 0.0901254571176001, 0.16273227999252932, 0.1804060816232647, 0.07630390234823738, 0.11458038166165352, 0.05483097636273929, 0.12140762460018907, 0.20776358220194066, 0.1825783843440669, 0.17243379727005959, 0.19356029720178672, 0.13972603449864046, 0.09141975588032178, 0.1615540717861482, 0.13412936909922532, 0.11142023373395205, 0.2174842341669968, 0.2196039775652545, 0.15006956804011548], [0.08325928662504468, 0.09140164578067404, 0.057108397728630474, 0.03585329844749399, 0.052686395190124, 0.019692037886540805, 0.09454555636537926, 0.027545000160379068, 0.032739372325262854, 0.026215219105194722, 0.05256059140499149, 0.03403641915481005, 0.09316277663622584, 0.06197288313082286, 0.05789579690567084, 0.04695724582831774, 0.01724375461760376, 0.024244063001658236, 0.01666310166807047, 0.05970863212964364, 0.042153818399778435, 0.07397398272795336, 0.053900002568428, 0.041771060188433955, 0.06521324068307877, 0.020303330084841167, 0.008656621694431772, 0.04426443550203528, 0.025995728293699876, 0.04404882760718465, 0.05429299987320389, 0.02632729782323752, 0.027457694755867124, 0.04572020524314471, 0.026211899372615984, 0.039086181936519485, 0.005993884888344577, 0.05012499674090317, 0.03676118848047086, 0.03075179737061262, 0.061478868925145695, 0.01495871669612825, 0.06562199017831258, 0.03691231519249933, 0.0864777478522488, 0.01868562287251864, 0.015323929688228028, 0.005564571117117468, 0.046621075831353664, 0.04740592710939901, 0.039698651393077204, 0.05187024648434349, 0.014443605140383755, 0.04574050361822758, 0.04373524943366647, 0.010080681797782225, 0.058550420350262096, 0.0800829284957477, 0.06817058127905641, 0.08632727592651333, 0.062083233280905654, 0.05742337368428707, 0.07536472845822573, 0.03867462669898357, 0.034713732810424905, 0.117208171369774, 0.06097656302154064, 0.010836963358867382, 0.03266733565500804, 0.1832637997078044, 0.19359435965972288, 0.9696937437568391, 1.334673279098102, 6.630770138331822, 10.633809736796788, 13.945606929915291, 26.28423970086234, 27.568060091563634, 35.06749922888619, 43.16490207399641, 58.20183910642351, 61.280589376177105, 61.517925943647114, 61.198774337768555, 70.76012788500104, 69.02470411573137, 102.40217563084194, 106.99562277112688, 88.32668168204171, 79.91209357125419, 78.12803936004639, 67.45686394827706, 56.72319643838065, 64.0152335848127, 56.59217078345162, 73.42689514160156, 86.5351790019444, 92.09171594892229, 72.27939319610596, 52.119333948407856, 41.90808064596993, 28.3746451990945, 31.035928589957102, 36.291709286826, 24.79749890736171, 19.857107366834367, 11.510314566748482, 6.986334213188716, 2.2338942672525133, 0.6517274028488568, 0.22399401771170752, 0.18923618351774557, 0.0496256153232285, 0.0740496733092836, 0.08255723358264991, 0.1301435051219804, 0.01778962416574359, 0.05874143474336181, 0.02538227496136512, 0.03265568181606276, 0.04988102947494813, 0.016557592865345732, 0.013731635308691433, 0.04062213416078261, 0.024764053224186813, 0.033784360358757634, 0.030570285860449076, 0.02730843231880239, 0.08127512130886316, 0.05258010946480291, 0.05790985615125724, 0.07907755672931671, 0.05818468318986041, 0.09561785204069954, 0.04856476653367281, 0.04810659254768065, 0.023866695751036917, 0.040635599688227685, 0.044955893220113854, 0.02399687608703971, 0.039672721177339554, 0.023083622234740427, 0.06075670410479818, 0.007603974696914, 0.06991448413048472, 0.05661464475893548, 0.08109123153345925, 0.06074302483882223, 0.03373439982533455, 0.054074202863765616, 0.05948182501431022, 0.07904998106615883, 0.02462583564088813, 0.08526667140956436, 0.0891475999461753, 0.04327895498967596, 0.04766359060470547, 0.07636544547442879, 0.02283666771836579, 0.10004019723939044, 0.07864076338176217, 0.08624705273125853, 0.05494328747902598, 0.022141081114698733, 0.036154255869665315, 0.020696366405380622, 0.06499548522489411, 0.04296449472063354, 0.0306268010421523, 0.07822447536247117, 0.07298492972872087, 0.06454358768782445, 0.03584096268085497, 0.05377366952598095, 0.07038899723972593, 0.01464004272462002, 0.031753518618643284, 0.0996348268485495, 0.06235264561006001, 0.1174765048282487, 0.047350168494241576, 0.03450958876471434, 0.048290875873395374, 0.019356008685593094, 0.0764119726206575, 0.01642295455427042, 0.032711141875811985, 0.05247605272701808, 0.033988830101277144, 0.062033754507345815, 0.0229472587483802, 0.032335060449051004, 0.019112609692716172, 0.02650008676573634, 0.046551800798624754, 0.03568777322236981, 0.01565930919189538, 0.017723539943939874, 0.09236008327986513, 0.04657424334436655, 0.08356700225600175, 0.04456741835123726, 0.09124594234994479, 0.04936687634991748, 0.03778566779302699, 0.011354190247532512, 0.08476699822183166, 0.03997140211452331, 0.04312668155346598, 0.03713057615927287, 0.01846037299505302, 0.014655392883079392, 0.017932869693530456, 0.04899272535528455, 0.018737271261800612, 0.10723228167210307, 0.020361134483079826, 0.013552685268223286, 0.03870822775310703, 0.01655669041377093, 0.09215945404555116, 0.08949931178774152, 0.04685453258986984, 0.06215513763683183, 0.06470314519745962, 0.02802488557063043, 0.00738272478338331, 0.011937813484109938, 0.06357231909143073, 0.044569304678589106, 0.0015972765229110206, 0.06601674828146185, 0.01819714720893119, 0.060220016831798215, 0.05712899805179664, 0.040366367170853276, 0.025421887835753814, 0.01986781577579677, 0.03850683516689709, 0.02992112801543304, 0.057691008251692565, 0.027039074272449528, 0.12047511392406055, 0.07546711260718958, 0.17742925350155148, 0.5415985094649451, 0.9891698701041085, 3.992085329123906, 7.458806940487452, 14.584277527672903, 21.68031120300293, 26.366681814193726, 36.80447244644165, 33.87905502319336, 49.465087345668245, 61.80061340332031, 74.67539610181535, 73.4150276184082, 77.1287008013044, 80.87926197052002, 98.52576174054826, 89.62211772373745, 114.77024705069405, 115.74595478602818, 94.33068261827741, 84.82873616899762, 70.8257188796997, 62.46888419560024, 59.390165192740305, 56.70273746762957, 60.72854804992676, 74.42796380179269, 80.24214690072196, 94.39946283612932, 89.96264198848179, 81.5440308707101, 70.15087509155273, 54.177498068128315, 51.84117324011666, 53.629431111471995, 41.88541562216622, 36.018714564187185, 27.373819725854055, 17.7111006464277, 10.417963947568621, 4.653389683791569, 2.053962630884988, 0.8236269216452325, 0.6992433645895549, 0.13021587766706944, 0.09634254779666662, 0.0835877111447709, 0.08628131874970027, 0.03194460425791996, 0.0470779572081353, 0.04775398503988981, 0.028819984423794916, 0.047347467924867354, 0.014505982864648104, 0.04868742191631879, 0.05609088018536568, 0.024596148037484715, 0.01383371920590954, 0.0036231352714821696, 0.07999334151723556, 0.06381944833057267, 0.029463493464780704, 0.024252373359299133, 0.04176264635420271, 0.03802316522757922, 0.013497947000100144, 0.07265805226883718, 0.0369350223668984, 0.0068255750146428385, 0.02227494928852788, 0.04899756330996752, 0.041257310791739395, 0.05232646628948195, 0.047854153772017786, 0.005323928672753806, 0.032607577075915675, 0.018073501165157983, 0.030195273126342466, 0.021138927300593684, 0.03424633753352931, 0.04268018515514476, 0.0039408003462345475, 0.043541375015463145, 0.015139870279069458, 0.08619426270680768, 0.026227571835209216, 0.11880274223429815, 0.21140441112220287, 0.14693499409726687, 0.042815162733729394, 0.15419388030256542, 0.06373631422008787, 0.057024795428982804, 0.03248947127056973, 0.05524180217513016, 0.011428219266235828, 0.20556287600525788, 0.09426797447460038, 0.13706114249570028, 0.02365096571988293, 0.04722677350842527, 0.06331528324101653, 0.03896788274869323, 0.1081015800258943, 0.1274096875318459, 0.011330280369812889, 0.05765113753399678, 0.23968212732246943, 0.1521577731307064, 0.13869827107659408, 0.15104527425553116, 0.17416330160839216, 0.08149300568870135, 0.18249016122094222, 0.07109905699534075, 0.2791076717632157, 0.13908806230340684, 0.12494877672621182, 0.07782744416700942, 0.20028639771044254, 0.19755233584770135, 0.13230442202516965, 0.09122697729617357, 0.13868681740547928, 0.15121441946497985, 0.14999282572950634, 0.09541212700839553, 0.09881776212049381, 0.15937296168080398, 0.16057935623185976, 0.14064185321331024, 0.13870931762669766, 0.13364019963358129, 0.10815206981663193, 0.23465100729039737, 0.14014014442052158, 0.23727503791451454, 0.1516292757753815, 0.11792739134814058, 0.14728697735284055, 0.0860532292031816, 0.08027890297983374, 0.06711663997599057, 0.14628232483352932, 0.1906308579657759, 0.0957104992121458, 0.14104263670742512, 0.12959706730076245, 0.09173407365701028, 0.16572109104267188, 0.0659773661089795, 0.19745523748653276, 0.21841720624693803, 0.2312961130269936, 0.12624567427805491, 0.18276495433279447, 0.20205058875892842, 0.07771244605204888, 0.2122080951396908, 0.12472062611154147, 0.1359366471213954, 0.13449685009462492, 0.15204205576862606, 0.133265526166984, 0.27135329214589937, 0.16052849324686186, 0.1302330038909401, 0.12460356525012425, 0.12359193739082132, 0.11271430858011756, 0.09538297035864421, 0.20923970799360955, 0.21296703655804905, 0.3400571612375123, 0.23574613566909516, 0.21943532090101922, 0.25529820365565165, 0.4295793260846819, 1.614904767700604, 3.036807034696851, 8.13596100466592, 15.785836458206177, 22.009669712611608, 38.618504660470144, 44.364018712724956, 55.36208949770246, 68.91473497663225, 84.09393637520927, 90.43641185760498, 94.66384874071393, 100.15550340924943, 112.10665512084961, 108.34291321890694, 128.67292540413993, 130.39381354195731, 106.67900030953544, 98.7547743661063, 93.8759994506836, 85.76092038835797, 79.69562244415283, 81.84787559509277, 74.8764978136335, 94.11134883335659, 102.64401463099888, 110.93879495348249, 104.43343979971749, 95.35905769893101, 81.9140988758632, 58.90081746237618, 56.06590379987444, 53.474090235573904, 39.39311763218471, 30.13258981704712, 18.51747383390154, 10.643381748880659, 5.416007024901254, 1.993022586618151, 0.8666076096040862, 0.4297500183539731, 0.4335690848529339, 0.25570404902100563, 0.19514610139386995, 0.23129806720784732, 0.1659892073699406, 0.1652604064771107, 0.11888048877673489, 0.09116162758852754, 0.11300510154770953, 0.15206406744463102, 0.1472946990813528, 0.16076150217226573, 0.1384076816695077, 0.08147228322923183, 0.1212105644600732, 0.11150151544383594, 0.23419671452471189, 0.14067668920116766, 0.13597886557025568, 0.1914709521723645, 0.11254797250564609, 0.24928974892411912, 0.16904330705957754, 0.1391687672585249, 0.153734932786652, 0.19042766386909143, 0.0812696251752121, 0.09184145860906158, 0.11876644061080047, 0.09651402716657945, 0.17201507331005164, 0.098080886660942, 0.14377345517277718, 0.09343374959592309, 0.16670008136757783, 0.09517674999577658, 0.12550411692687444, 0.15811940894595214, 0.10023502499929496, 0.13408442293959005, 0.11709739374262945, 0.17653612499790533, 0.1492626949080399, 0.234037313078131, 0.3036320986492293, 0.18254924805036613, 0.15268252497272833, 0.22582386380859784, 0.16075644030102662, 0.2657774713422571, 0.08634815444903714, 0.1981192382850817, 0.1842538094414132, 0.3503533601760864, 0.1987361351826361, 0.18715196821306432, 0.11446284582572323, 0.1330145224928856, 0.18733760182346615, 0.1753895908061947, 0.2364632657596043, 0.2696367885385241, 0.2307816477758544, 0.10573919250496797], [0.05858881864696741, 0.04369503605578627, 0.03146159928292036, 0.05749181072626795, 0.02953901101968118, 0.03486637604822006, 0.01736186720829989, 0.08100291341543198, 0.062245674564370086, 0.037649892935795445, 0.03138381881373269, 0.14709675684571266, 0.022150190447324088, 0.025920002089281167, 0.007043220210886959, 0.015727447678468058, 0.09307485885385956, 0.026706916113783206, 0.1158476679452828, 0.06890999445957796, 0.028324228079457368, 0.052126756470118246, 0.008540179148050291, 0.12946191669574805, 0.052130532517497025, 0.033012971215482266, 0.027233204837622385, 0.03660328320360609, 0.0527988521914397, 0.010579153130363141, 0.03295921088595476, 0.021273284019636254, 0.039465571221496375, 0.0675130265631846, 0.01661998755298555, 0.030763508885034492, 0.021367113538352505, 0.033187870401889086, 0.005699488475719201, 0.010296495797644769, 0.049786906489836316, 0.048696741594799926, 0.03998776159382292, 0.038963370490819216, 0.026397561820756112, 0.0365094485958772, 0.01893433479459158, 0.03849164616050465, 0.050083066669425795, 0.009355136176704295, 0.04971874425453799, 0.07969243837786572, 0.022526103936667954, 0.02476469613611698, 0.05768258763211114, 0.030606692656874657, 0.05217497316854341, 0.042809235730341504, 0.019984057306178978, 0.021232716107208813, 0.024014519693862115, 0.016367441908057247, 0.08357811665960721, 0.028612885358078138, 0.016489164305052588, 0.09653445785599095, 0.04699889091508729, 0.02399751221361969, 0.07310990230845553, 0.05066579593611615, 0.024893465119280984, 0.04971680025170956, 0.010485714617451387, 0.0539266113191843, 0.05673525096582515, 0.2756980061531067, 1.480246507695743, 1.491648175886699, 3.6106548479625156, 8.416187933513097, 11.09834110736847, 16.733680180140905, 15.432360751288277, 25.042690413338796, 18.036040101732524, 16.509828329086304, 17.578542913709367, 58.353021485464915, 73.6963393347604, 82.9052733012608, 79.88946328844342, 81.66925130571637, 80.67499882834298, 92.14855916159493, 84.19811071668352, 91.16087968008858, 91.423417363848, 78.95874513898576, 41.00239338193621, 14.591298682349068, 7.626047474997384, 2.227476737328938, 3.852637154715402, 3.67818352154323, 1.4126500891787666, 0.5080846878034728, 0.2873883774237973, 0.1615826788225344, 0.050739284671310864, 0.031373925773160796, 0.05713818541594914, 0.09286079462617636, 0.05924303497054747, 0.02130712934636644, 0.044675183282899, 0.01612232961425824, 0.01356232725083828, 0.017527923387076174, 0.05313880502113274, 0.02578191682031112, 0.042042898280279975, 0.05931423365005425, 0.02395234044109072, 0.036015424212174754, 0.023687243594654968, 0.030813147114323716, 0.08898676679070507, 0.022132326316620623, 0.00568203825137711, 0.06522726600191422, 0.0613741913278188, 0.006620226145189787, 0.005559196695685387, 0.02816217016827847, 0.11270254956824438, 0.0009160782543144055, 0.013176905789545603, 0.04969924655077713, 0.041914600878953934, 0.017466432847348706, 0.07176304422318935, 0.07136610123728003, 0.04069532434056912, 0.015836761366309862, 0.006349624259330864, 0.030240894428321292, 0.08016440019543682, 0.060978944679456096, 0.030442263265805583, 0.04980792071936386, 0.03716019760551197, 0.07414061735783305, 0.07577603603047983, 0.005631514533888549, 0.03181187602292214, 0.03585988702252507, 0.04675565646695239, 0.06413939794791595, 0.06399587422077145, 0.0329662167600223, 0.04296117329171725, 0.09518258539693696, 0.04904244500877602, 0.03707207286996501, 0.09185932443610259, 0.06659914167331797, 0.008361515788627523, 0.04367482589025583, 0.014043539197051098, 0.06956697920603411, 0.09020707809499331, 0.05739727044211967, 0.018399311628724848, 0.03299224875601275, 0.028023469128779004, 0.007986743934452534, 0.09047809176679168, 0.020761353096791675, 0.031789552220808606, 0.04779367933848074, 0.014936643951971616, 0.09264076607567923, 0.07832327684653656, 0.04028266987630299, 0.030031254248959676, 0.048428638838231564, 0.02100746792608074, 0.08622175694576331, 0.007621732806520802, 0.014045618058714484, 0.014086477741199945, 0.0460739967945431, 0.04438703999455486, 0.05189141338425023, 0.062163300413106165, 0.03388858673029712, 0.049464408973498006, 0.040427744055965116, 0.04038818546437791, 0.08283992484211922, 0.052704539216522656, 0.04622925578483513, 0.07877763746572392, 0.03216036143047469, 0.03156340667711837, 0.03318043026540961, 0.0704768675246409, 0.04913941105561597, 0.02032773190044931, 0.029966874846390316, 0.10912135030542101, 0.02585986692325345, 0.03834737604483962, 0.027909573633223772, 0.03435363766870328, 0.03732387721538544, 0.07440713234245777, 0.02198723178090794, 0.1104883337393403, 0.07103880308568478, 0.027136510204789892, 0.01744451786258391, 0.05570561478712729, 0.045602167291300635, 0.02977750590071082, 0.013041586398945322, 0.03930548445454665, 0.06833520744528089, 0.06119794864207506, 0.021874693355390003, 0.0164186967470284, 0.04636669983821256, 0.03321781075958695, 0.03867348336747714, 0.05279635518257107, 0.024264992414308444, 0.04053730032007609, 0.06558881660125085, 0.033899826662881036, 0.09677689163280384, 0.0065561393608472174, 0.09469998415027346, 0.04242981251861368, 0.07370551356247493, 0.05320251267403364, 0.048146307202322144, 0.05063667321311576, 0.16085021384060383, 0.03560038469731808, 0.3179883525839874, 1.0419621744326182, 1.706298332129206, 5.715828308037349, 6.7153735756874084, 10.194010479109627, 18.835993153708323, 21.995346001216344, 31.828971658434185, 29.99063117163522, 41.24364178521292, 33.75992815835135, 26.87906108583723, 25.07546854019165, 68.51814569745744, 88.049149785723, 98.58921269008091, 91.26004437037876, 91.59091063908168, 91.4634598323277, 98.54061698913574, 92.34697886875698, 101.94270515441895, 103.45233331407819, 93.58090945652553, 60.055323192051475, 29.98896360397339, 15.295993668692452, 6.751954104219164, 8.900834339005606, 8.825338687215533, 4.878258577414921, 2.9758735043661932, 1.755728142602103, 0.743352863405432, 0.21737754132066453, 0.20250181454632962, 0.20710885019174644, 0.05096029370490994, 0.06271714105137757, 0.047328692860901356, 0.05187126767954656, 0.002754516088836161, 0.05208231581907187, 0.04525535786524415, 0.06214303257209914, 0.021068607323936055, 0.01374799563615982, 0.008345448927554702, 0.03040382086432406, 0.030042667207973342, 0.05292083921709231, 0.015849195520526597, 0.03092063045395272, 0.024334908662629978, 0.03371904118518744, 0.11232318742466824, 0.021945303405768106, 0.03076915768906474, 0.05414053305451359, 0.021511449811181853, 0.17039205825754575, 0.02012771674032722, 0.012927382169956607, 0.01647688282121505, 0.06524461614234106, 0.03405458692993436, 0.02359989069269172, 0.02326609387195536, 0.03642032980652792, 0.017773410571472983, 0.005958674009889364, 0.039459827422563515, 0.01659934312504317, 0.05029674752482346, 0.01151132708348866, 0.016780934363071407, 0.054455424193292856, 0.0986329223960638, 0.04383318917825818, 0.03318790772131511, 0.004409995013182717, 0.06478385693792786, 0.13028932229748794, 0.09837217495909759, 0.11293124301092965, 0.12189752688365323, 0.07634468230285815, 0.07103448081761599, 0.007268484931306115, 0.054115708850856335, 0.04600590580542173, 0.03284087437870247, 0.009570864511520734, 0.029564612145934786, 0.10232177802494594, 0.061960194525974135, 0.12242086737283639, 0.04241702552618725, 0.04694365816456931, 0.07836454534637076, 0.06808003756616797, 0.037239277469260354, 0.13652311850871357, 0.15733176549630506, 0.09793361063514437, 0.23513290286064148, 0.16674433542149408, 0.20246855275971548, 0.09194996992924384, 0.13171728567353316, 0.23580633529594966, 0.11341890612883226, 0.0711841317159789, 0.38472821563482285, 0.11107844885970865, 0.16317707326795372, 0.14312473498284817, 0.19202192260750703, 0.15280449842768057, 0.11146585164325577, 0.19261418868388447, 0.1391864363104105, 0.13394636820469583, 0.12374357639678887, 0.11325822903641633, 0.16643433991287435, 0.1777687652834824, 0.1704190368098872, 0.11894101410039834, 0.22854340502193995, 0.1545640482966389, 0.14812020478504045, 0.2636024137692792, 0.1150149969117982, 0.1758340855262109, 0.10902725106903485, 0.2280919621033328, 0.14224563858338765, 0.05489755082609398, 0.09224702577505793, 0.11667621348585401, 0.13066919334232807, 0.23152249945061548, 0.17123668507805892, 0.1910812830818551, 0.16817072459629603, 0.10571840219199657, 0.11911105497607163, 0.1677308710558074, 0.15245911053248815, 0.1530356617378337, 0.10589696546750409, 0.08851211797446012, 0.18108198392604077, 0.1774333654237645, 0.09593187804733004, 0.18627331964671612, 0.09223738379244294, 0.14407874164836748, 0.11749416030943394, 0.10124150956315653, 0.17536681917096886, 0.20785741002431937, 0.17370394697146757, 0.11966954357922077, 0.09767408456121172, 0.07455887312867812, 0.225578084854143, 0.10572829523256846, 0.11887402912335736, 0.15533257062946046, 0.13488953188061714, 0.10866352237228837, 0.154482366251094, 0.05533118898581181, 0.10237705148756504, 0.2603123331708567, 0.5159132448690278, 2.1508420152323584, 3.88217351266316, 5.549320808478764, 12.04196206160954, 16.680352755955287, 25.32208616392953, 24.964373792920792, 37.64267185756138, 31.181795597076416, 26.513459035328456, 28.52152838025774, 80.13160106113979, 110.7937513078962, 126.15195219857353, 116.60162544250488, 111.99392059871128, 111.49932697841099, 117.62089838300432, 113.63749613080705, 123.53574698311942, 117.4831850869315, 105.14533833095005, 62.023963247026714, 26.94758074624198, 11.587037444114685, 4.26512347800391, 5.226792812347412, 4.299659933362689, 1.9529603591987064, 1.064701891371182, 0.9266581216028759, 0.37237762979098726, 0.19573114785764897, 0.13312057751630033, 0.2233657349965402, 0.15885005545403275, 0.15064812770911626, 0.0932618427489485, 0.14495274903518812, 0.15138728304633073, 0.13232177895094666, 0.15176792762109212, 0.14125583241028444, 0.08850880672356912, 0.09452511889061757, 0.0677447123453021, 0.1497155220380851, 0.10955935144530875, 0.1330296266824007, 0.10620448432330575, 0.205859314384205, 0.08909172937273979, 0.10681270954332181, 0.20008663700095244, 0.08486945022429739, 0.09537616465240717, 0.14479789377323218, 0.19613579900137015, 0.31081439182162285, 0.08812213675784213, 0.12323572007673127, 0.11045668686607055, 0.2035007266593831, 0.15760179529232637, 0.10498330449419362, 0.13044508679636888, 0.1423724703490734, 0.09905280665095363, 0.07967389401580606, 0.09917288699320384, 0.13579555254961762, 0.14615427170481, 0.06957860251090356, 0.12733533366450242, 0.16137766625199998, 0.2271686252206564, 0.20709636514740332, 0.128365105550204, 0.1756994098957096, 0.17272619158029556, 0.23019718485219137, 0.22756051990602696, 0.16415794992021152, 0.2550558852297919, 0.1536165012844971, 0.2079976089298725, 0.1462129107011216, 0.1226047503628901, 0.24107108850564274, 0.17833232932857104, 0.16639913751610688, 0.1347961111792496, 0.23782361990639142, 0.15964993967541627, 0.22443974736545766, 0.1591043568083218, 0.12358399853110313, 0.09714583147849355, 0.13216325959989003, 0.10305264844958271], [0.03089399795447077, 0.024571898892255764, 0.04416967469400593, 0.006580887653399259, 0.031161167725388492, 0.02855994944859828, 0.037528350350580046, 0.046330771408975124, 0.06463370392365114, 0.01963427589674081, 0.037708087491669824, 0.06586142483034305, 0.044587618338742425, 0.03519361652433872, 0.045601529468383105, 0.03367981168308428, 0.06914009246975183, 0.02475610757911844, 0.03894173540174961, 0.03293872930641685, 0.030944816834692444, 0.02857615965019379, 0.08562593534588814, 0.09908515920064279, 0.011600258427539041, 0.058521460475666184, 0.016698395667065467, 0.03568654168131096, 0.034507668510611565, 0.013018724009660738, 0.0455368209763297, 0.0458995895460248, 0.022922468471473882, 0.028886209441615, 0.009764357253776064, 0.05698725887175117, 0.05333805682935885, 0.09199203231504985, 0.047703010096613846, 0.05354947477046933, 0.05704723458204951, 0.09698058106005192, 0.062239852733910084, 0.058025105324174674, 0.049586616523031674, 0.08016222209802695, 0.0921760577974575, 0.06337861091430698, 0.049738747466887744, 0.039824445000184436, 0.04403184048299279, 0.06239208206534386, 0.027708021591284444, 0.07785059578184571, 0.07687106941427503, 0.03584334773144551, 0.04492150506536875, 0.078084093252463, 0.050583489638354094, 0.033744160551577806, 0.009911305038258433, 0.04630635093365397, 0.04309757918651615, 0.08639072573610715, 0.09191552070634705, 0.034566131087818315, 0.06109728118670838, 0.10346344712057284, 0.04490256036764809, 0.031206616000937562, 0.026357492631567375, 0.05420072589601789, 0.07659054268151522, 0.02120441271524344, 0.010844071013187724, 0.0347461667843163, 0.09433215031666414, 0.05852721445262432, 0.04948777771954026, 0.0718868225812912, 0.008234365959651768, 0.05044480047321745, 0.017573648165645342, 0.20345383988959448, 0.2045994648443801, 0.20802299971027033, 0.03492540180949228, 0.4054223937647683, 5.152737174715314, 16.04285553523472, 36.36984872817993, 38.978018351963584, 32.354140826633994, 41.99375540869576, 44.18115602220808, 23.92082037244524, 15.36539922441755, 6.017701481069837, 1.1651017325265067, 0.42040303562368664, 0.09671268864933934, 0.037450990573103936, 0.03173271134229643, 0.07733539771288633, 0.0512807590088674, 0.05915026566279786, 0.03844843705051711, 0.04484787383782012, 0.02623392122664622, 0.05724921410105058, 0.023166559570069824, 0.005658971453418157, 0.019305861555039883, 0.0458899000659585, 0.05104322425488915, 0.01573401250477348, 0.02725903836211988, 0.009389129932969809, 0.022110209467687776, 0.06565818323620728, 0.028205184199448143, 0.015096123430079647, 0.04938386008143425, 0.03702060938147562, 0.01423798019199499, 0.055054645253611464, 0.01364760468381324, 0.059040553335632594, 0.028317055964310254, 0.03303169199664678, 0.03999724751338363, 0.02329138626477548, 0.009875514012362276, 0.01823224443277078, 0.012905192378509258, 0.03058712709961193, 0.042231018721525154, 0.04476138097899301, 0.03133682008566601, 0.1464462588940348, 0.08286802297724144, 0.05858642341835158, 0.030277124805642024, 0.06909455598465034, 0.05373189212488277, 0.003004242420761979, 0.024518985035164014, 0.02176951364214931, 0.0508902281788843, 0.03628663805180362, 0.05364503964249577, 0.05834027805498668, 0.012879413984982031, 0.037368056630449634, 0.01863120775669813, 0.0321652265265584, 0.036661755958838124, 0.18027099887175219, 0.13367937824555806, 0.033037683460861444, 0.02038292902787881, 0.0452631135205073, 0.04132599210632699, 0.052134257674749405, 0.022939876287377307, 0.057954320551029274, 0.053463280467050414, 0.07060077480439629, 0.03993413357862404, 0.06902973553431885, 0.053186183728809865, 0.048469832699213705, 0.06293142241026674, 0.022334541626540676, 0.015343837905675173, 0.03797034127637744, 0.038689130385007174, 0.0830833153533084, 0.035387599508145025, 0.03735232479604227, 0.03507812647148967, 0.044525260970528634, 0.0508348054385611, 0.09213739487209491, 0.02964355969535453, 0.023416983096727302, 0.027520080961819206, 0.06874454726598092, 0.01274653647228011, 0.029144392016210725, 0.05084177399320262, 0.06155333135809217, 0.03322833144505109, 0.023826202477461526, 0.06270119547843933, 0.04311952979436942, 0.04333314618894032, 0.05380290759993451, 0.050258993836385865, 0.020248607931924716, 0.02905709170071142, 0.055807829302336485, 0.025639811231355582, 0.07154224214277097, 0.08704490813293628, 0.04004057197432433, 0.10495074159864869, 0.012525262810023767, 0.011497569785985564, 0.030188755797488347, 0.018249430028455596, 0.09217628171401364, 0.07478880150509731, 0.07249569240957499, 0.049145670541163, 0.05720763347510781, 0.046619243786803315, 0.13463106432131358, 0.06926013209990092, 0.04914977228535073, 0.022326158326385275, 0.028119264702711786, 0.060840279263045104, 0.04083055976246085, 0.014819727279245853, 0.021047856026728238, 0.05058552524341004, 0.05704294624073165, 0.020022403016420345, 0.03825567203706928, 0.06307084100054842, 0.05012815871409007, 0.06387679811034884, 0.1363427367593561, 0.02898738579824567, 0.09366910625249147, 0.03276712101485048, 0.04457981179335287, 0.04324239891554628, 0.03278129221871495, 0.07590750897569315, 0.035200652932482104, 0.08904130743550402, 0.043920764300440035, 0.05553010491920369, 0.10084801353514194, 0.07302413548209838, 0.01776834700389632, 0.09453107642808131, 0.024378818360024264, 0.03948701971343585, 0.016592323680275252, 0.10452880138265234, 0.04415473674557038, 0.06535707653633185, 0.3573824129998684, 0.27333000036222593, 0.2431347577699593, 0.05126206536910363, 0.5356845068080085, 0.35413752283368793, 0.19945333312664712, 0.06679157420460667, 1.142661765217781, 8.402738826615469, 24.11994184766497, 47.207892077309744, 51.93052012579781, 46.0704094341823, 56.60961076191494, 56.57709666660854, 37.72032839911324, 27.655091490064347, 12.210831080164228, 2.9103941151074, 0.7231058127113751, 0.16005839061524185, 0.08816288278571197, 0.0008423640652576328, 0.11009133647062949, 0.08178955941860165, 0.024150906928947995, 0.09441442268767528, 0.08199133537709713, 0.023265552740277987, 0.05461658304557204, 0.019259619393518994, 0.0016292382788378745, 0.05148020080689873, 0.02270208708276706, 0.0195991888509265, 0.0013346375635592267, 0.011388201815342265, 0.012999671594505864, 0.01952686719596386, 0.051139840856194496, 0.047776420800281424, 0.009993305995262094, 0.008824109582097402, 0.029858797788619995, 0.017989184707403183, 0.022966826001980474, 0.007747857199449624, 0.022840676163988452, 0.09456091161285128, 0.03207293897867203, 0.010086310245761914, 0.025551472757277743, 0.05283598502033523, 0.05762185196259192, 0.016369279041620236, 0.03991279025961246, 0.03481165559164115, 0.06631636898964643, 0.04225621611944266, 0.03187623506944094, 0.10398585123143025, 0.04163169588095375, 0.026664729895336286, 0.029173908289521933, 0.07119848273162331, 0.029220459184476306, 0.04826200081567679, 0.020098061367337192, 0.027833894926256368, 0.00494721408800355, 0.012616601257052804, 0.02217574916513903, 0.02158892833228622, 0.04344635297145162, 0.02725831911500011, 0.04003951685237033, 0.05619364092126489, 0.0771780318713614, 0.08407460073275225, 0.023207487106057148, 0.06526597642472812, 0.06649285594799689, 0.0506988032720983, 0.030970913291509663, 0.0034775528266826378, 0.0289656319655478, 0.04171562048473528, 0.05623775248282722, 0.03579874762466975, 0.10705451906791755, 0.06943303639335291, 0.026299635646864772, 0.06034394446760416, 0.05123338369386537, 0.04580805177933403, 0.041042116803250143, 0.13072308259350912, 0.13253227408443177, 0.12293230635779244, 0.18731712363660336, 0.1691496470677001, 0.10799452755600214, 0.12734952861709253, 0.1511455210191863, 0.09379914748881545, 0.10448855068534613, 0.1378727110901049, 0.14926705110285962, 0.11380468721368484, 0.15063587336667947, 0.12712930329144, 0.22416146658360958, 0.09324309482638325, 0.10490179886775357, 0.18017358838447503, 0.10587591731122561, 0.16750292400164263, 0.2634138624582972, 0.15500641241669655, 0.19089536448674543, 0.13214412491236413, 0.17221517328705105, 0.16186184169990675, 0.1331574898213148, 0.16929751341896399, 0.10348682265196528, 0.1698858304215329, 0.10509423818439245, 0.11939675893102374, 0.10180715671075241, 0.0761185876492943, 0.1272458756076438, 0.15353992182229245, 0.19439720229378768, 0.17648790829948016, 0.18609166225152357, 0.11008298370454993, 0.27315759818468777, 0.21776514766471727, 0.14259452771927628, 0.15372155207608426, 0.1618585575904165, 0.17607539972024305, 0.18892522448939936, 0.1280936508306435, 0.1023235082892435, 0.13620650049831184, 0.1411256351109062, 0.09841186247233834, 0.16860262570636614, 0.17408457797552856, 0.12767176489744866, 0.13492982329002448, 0.308595528027841, 0.17685800844005176, 0.12989699334970542, 0.13633196162325995, 0.1626085287758282, 0.23122611535446985, 0.11944307573139668, 0.3032051644154957, 0.12594916804560594, 0.20578102501375334, 0.2041118831506797, 0.14277021400630474, 0.18676048064870493, 0.14312693343630858, 0.14735735500497477, 0.19547958778483526, 0.10907680448144674, 0.09823743826044457, 0.11307830869087152, 0.1276915238371917, 0.11810603604785033, 0.14532780248139585, 0.2644679530390671, 0.27202151343226433, 0.3192236120147364, 0.14243645620133194, 0.3907795809209347, 0.39554289675184656, 0.2575863323041371, 0.20680056459137372, 1.3689316979476382, 9.077239547457014, 25.822790724890574, 56.81508983884539, 66.46019349779401, 67.14093630654472, 78.8266737801688, 66.02519457680839, 46.144244466509136, 29.99789203916277, 9.337773544447762, 1.7337126668010439, 0.4167878824685301, 0.1409131179430655, 0.17949740109699114, 0.10510137637278863, 0.1767224371433258, 0.23176669063312666, 0.17415658411170754, 0.18675988353788853, 0.1893932100917612, 0.08371342332767588, 0.14578757781003202, 0.1175963883953435, 0.07937427330762148, 0.14921940437385015, 0.13909053217087472, 0.16513086057135037, 0.1859790797212294, 0.05860200258237975, 0.09506976537938629, 0.08422148999358926, 0.19862955090190682, 0.14416339567729405, 0.13350004144012928, 0.11469347987856184, 0.10762411528932196, 0.11366402011896883, 0.09118416173649685, 0.14683712220617703, 0.14296979829669, 0.17066643067768641, 0.14905978579606327, 0.08575594265546117, 0.08944517826395375, 0.16325756109186582, 0.12344233398990971, 0.12121593845742089, 0.1834007552159684, 0.10802586908851351, 0.11457477696239948, 0.09260977738137756, 0.22474337821560247, 0.1493809228496892, 0.11643432932240622, 0.15470825055880205, 0.1980557409780366, 0.13014285372836248, 0.12900942883321218, 0.10313181313020842, 0.09840196943176643, 0.10789744955088411, 0.08089273289910384, 0.11431725935212203, 0.07501313196761267, 0.06636228545435838, 0.29876409843564034, 0.16896106861531734, 0.10152116777109248, 0.18900359528405325, 0.3725767662482602, 0.2919377104512283, 0.21729619854262897, 0.10602512716182641, 0.12390919322414057, 0.09500905685126781, 0.14790196078164236, 0.099482461810112, 0.18262159345405443, 0.0997548121958971, 0.2096555142530373, 0.19559017542217458, 0.25666879011051996, 0.17120377612965448, 0.14748504172478402, 0.1664163858762809, 0.15035006084612437, 0.15755292720028333, 0.1189367121883801], [0.015548406035772391, 0.03633329411968589, 0.04289524682930537, 0.031589845794120004, 0.090907271951437, 0.007174431496033711, 0.03999492013826966, 0.032323599992586036, 0.03359504908855472, 0.05077108421495982, 0.11355046728359801, 0.03232475010944264, 0.02838785430815603, 0.04971113109162875, 0.035367341845163276, 0.038587719933795075, 0.04853798814916185, 0.11357157650802817, 0.03473861808223384, 0.05491662444546819, 0.08510954984064613, 0.08747768455318042, 0.08559116042618241, 0.014395089886550392, 0.05753185786306858, 0.05302289766924722, 0.04212902133752193, 0.03459501971623727, 0.0581323749252728, 0.030530299791800122, 0.051904661780489345, 0.03238603539232697, 0.03919959906488657, 0.019383484264835715, 0.046804226003587246, 0.03485049832878368, 0.01357655952285443, 0.008785973369543041, 0.03164046450651117, 0.07382398577673094, 0.06046746498239892, 0.03170669970235654, 0.026053895708173513, 0.054906683907444985, 0.10426498018205166, 0.07782356294670276, 0.03612233079703791, 0.015195818884032113, 0.056654912419617176, 0.032734154390969446, 0.020885129758555974, 0.030840824557734386, 0.045282567119491954, 0.07876372071249144, 0.04584895047758307, 0.02937227121687361, 0.0386617073922285, 0.04625888401642442, 0.025089928148580447, 0.0310183869940894, 0.009907188875201558, 0.02252407342062465, 0.009515276378286737, 0.023993880354932377, 0.04613610649747508, 0.028488608276737586, 0.03529852143089686, 0.02495426864230207, 0.031220692209899426, 0.04123866464942694, 0.024318213308496133, 0.021220777283555696, 0.042451532424560616, 0.023905774279098426, 0.0383862425307078, 0.03777089608567102, 0.08658581812466894, 0.04308223072439432, 0.009237935367439474, 0.021533276586394225, 0.004359069263695606, 0.06389452144503593, 0.017611430691821233, 0.013257626011701567, 0.03905836878610509, 0.06762899498322181, 0.060957299412361214, 0.08145251750413861, 0.22672225774398871, 0.14717865602246352, 0.018876113097316453, 0.19586832049701894, 0.5482060834765434, 0.5560565165110997, 0.1123801843662347, 0.21995099394449166, 0.14192151597567967, 0.11394041457346507, 0.1499576097620385, 0.0628651702510459, 0.03891090277050223, 0.08473971432873181, 0.03595637809485197, 0.038360346241721084, 0.03945797162928751, 0.03908002083855016, 0.05654950878982033, 0.04638597023274217, 0.014211642007077379, 0.0519175844799195, 0.05672391264566353, 0.0427154587980892, 0.0534674059599638, 0.061153823509812355, 0.016272435131083642, 0.0231416200154594, 0.05402724484780005, 0.05707033869943448, 0.01920690740059529, 0.03948887550671186, 0.032461919356137514, 0.06739825915013041, 0.03221932951627033, 0.050429418084344695, 0.008741223136894405, 0.04009635094553232, 0.0374711905606091, 0.03642895059393985, 0.015428536039377962, 0.06127681476729257, 0.023017495604498044, 0.023118819542495266, 0.040019975043833256, 0.03051873416240726, 0.015821865826312984, 0.06365956512412854, 0.0382641978295786, 0.03556023578026465, 0.04640074872544833, 0.0903233043583376, 0.04672694086496319, 0.029220998619816134, 0.022074376033352952, 0.017277964656906467, 0.01890874045368816, 0.05898042834763016, 0.07590188392038856, 0.03875022907076137, 0.03457992909742253, 0.06141964638871806, 0.06002951812531267, 0.036270108938749344, 0.029114146317754473, 0.03960745628657086, 0.021519587142392993, 0.022805712950815047, 0.017561285257605568, 0.06373623279588563, 0.031977411426071606, 0.06491906182574374, 0.046283643759254894, 0.018749795321907316, 0.04681236163846084, 0.0577594181522727, 0.012192625436000526, 0.031075132877698967, 0.010240746512343841, 0.012397665996104479, 0.015535754750349691, 0.014459146984985896, 0.00558187163967107, 0.017501918532486473, 0.035854105904166184, 0.029423924695168222, 0.02536620555578598, 0.06839664200586931, 0.009187444728533072, 0.01571520690673164, 0.02736534274715398, 0.023382662795484066, 0.025313308662069694, 0.04538650172097342, 0.017680670101461664, 0.03123560980228441, 0.019354673667943904, 0.027183008513280323, 0.04136925210644092, 0.029639820967401777, 0.01066684614800449, 0.06210367754101753, 0.09530954608427626, 0.028765257181865827, 0.02531103048074458, 0.094777323571699, 0.05372948332556656, 0.011452345426992645, 0.02832591423897871, 0.008271419908851385, 0.0557781535732959, 0.040584509393998554, 0.07959541465554919, 0.035465966910123825, 0.005267703564771051, 0.013580471277236938, 0.059720058659357686, 0.04797839014125722, 0.059305385553411076, 0.01667699806525239, 0.010964974079148045, 0.003087264997053093, 0.051750301849097013, 0.009145781830219286, 0.08263875277979033, 0.04833928256162575, 0.014346907114876168, 0.04993896958019052, 0.010109643368715686, 0.05207889600257788, 0.01886655593157879, 0.024049396393820643, 0.06918192415365151, 0.01750153855287603, 0.019729625333898833, 0.05311437436778631, 0.01813080853649548, 0.012377490605493742, 0.008095935485990984, 0.032267196769160886, 0.004438181357857372, 0.0848867664379733, 0.022309525736740658, 0.07317852934024163, 0.01100955976705466, 0.056555164379200766, 0.008192183982048715, 0.018233124831957475, 0.03043038211762905, 0.012967680364714136, 0.05215656112081238, 0.009685672636676048, 0.014316885332976068, 0.018399695001010383, 0.05773666687309742, 0.0222369343641081, 0.041439897779907496, 0.042136010248214006, 0.030333002164427723, 0.07317947250391756, 0.06831749768129416, 0.06708447063075644, 0.002066955918313137, 0.035252011248043606, 0.07748565250741583, 0.047199852631560395, 0.03904221286731107, 0.032366476620414426, 0.02931356436706015, 0.04868912843189069, 0.12223888428083488, 0.027105343395045826, 0.01720877274471734, 0.10560073064906256, 0.048264928694282255, 0.07751262427440711, 0.1611355242452451, 0.1587475152420146, 0.07080404353993279, 0.378942646086216, 1.267747578876359, 1.360250358070646, 0.48455597034522463, 0.710535327238696, 0.16477879589157446, 0.15186034409063204, 0.10913138583834682, 0.09797318958278213, 0.03999504227457302, 0.07464222437036888, 0.03750168053167207, 0.05729922891727515, 0.057733233485903056, 0.015714630151965787, 0.05988349060394934, 0.05734538286924362, 0.01609289985416191, 0.03383529119725738, 0.030058860446193388, 0.05227130139246583, 0.022140682475375276, 0.030493577476590872, 0.016241217431213175, 0.059131497384182045, 0.03929965244606137, 0.03851750852274043, 0.007002808361513806, 0.051006715678210766, 0.04598668630101851, 0.09680741892329284, 0.025452058895358017, 0.016881988583398715, 0.04601181245275906, 0.03167678987873452, 0.02620922085562987, 0.013445054347227727, 0.04828405659645796, 0.028245972635756646, 0.036012740606176, 0.0541869177083884, 0.033439484757504294, 0.01404351884100054, 0.014270308992958494, 0.007982587907463312, 0.05492829524778894, 0.025358234465654408, 0.04411022484834705, 0.022898092100928937, 0.0391264360265008, 0.03985973899917943, 0.021838108443522027, 0.047407657373696566, 0.020363865586529886, 0.018380823245804225, 0.03334401148770537, 0.02452678988421602, 0.02478403608048601, 0.007376188794816179, 0.011381760821677744, 0.03159052772181375, 0.004038946619922561, 0.027646777020501237, 0.03317964995013816, 0.03214719785111291, 0.018298403293426548, 0.050634250843099186, 0.027592938659446578, 0.1013695423358253, 0.02278175387930657, 0.03156724039997373, 0.0285545686659004, 0.03440896202144878, 0.027420870660405074, 0.011231299073967551, 0.028805565554648638, 0.011349095297711236, 0.025645646632515957, 0.03243983982663069, 0.04363669900755797, 0.0238504380519901, 0.06091396138072014, 0.021719500522262285, 0.012410661638049143, 0.03188955131918192, 0.08580406435898372, 0.08508092244820935, 0.09890074695327453, 0.10955437099827187, 0.09736626715000186, 0.12509527243673801, 0.14190911235553877, 0.11956970393657684, 0.08397066273859569, 0.1767304709979466, 0.1576414353081158, 0.11025719757058791, 0.12223123040582452, 0.25245981024844305, 0.1432402759258236, 0.12626760452985764, 0.10173990031970398, 0.21523672262472765, 0.07299886005265371, 0.15361884901566164, 0.14674093308193342, 0.2374620693070548, 0.14284391648003034, 0.16632867843977042, 0.16488763290856565, 0.13331520850104944, 0.07648382269378219, 0.07681426246251379, 0.1917837161038603, 0.22844197760735238, 0.11947652750781604, 0.14877611744616712, 0.0949377224647573, 0.08399419433304242, 0.11524725944868155, 0.08396801645202295, 0.19729736952909402, 0.13782464366938385, 0.12046515302998678, 0.18375375627407006, 0.0950463152091418, 0.09487904954169478, 0.08375447469630412, 0.1536699291318655, 0.1665479809577976, 0.17178541634763989, 0.08963390599404063, 0.13858769700995513, 0.10062207494463239, 0.14605645409652165, 0.11846304046256201, 0.12059886514076165, 0.06354285031557083, 0.17702217320246355, 0.17730525801224367, 0.24606695185814584, 0.1138637401163578, 0.09303691517561674, 0.10012197427983795, 0.16587414140147821, 0.1211898827127048, 0.08992889230804783, 0.1247467632804598, 0.08675342984497547, 0.13323111087083817, 0.07594799037490572, 0.11203754453786782, 0.1017831162150417, 0.11057442626250641, 0.1600483347262655, 0.1621510333248547, 0.16150122747889586, 0.17331632705671446, 0.1613431695316519, 0.12315899133682251, 0.13526178976254805, 0.20388945937156677, 0.1637525116758687, 0.12875624027635368, 0.11761997427259173, 0.04673057781266315, 0.156492091981428, 0.17196687018232687, 0.08727197309157678, 0.1570543668099812, 0.18324801698327065, 0.18015947485608713, 0.12327945844403335, 0.3507078540112291, 0.1938988318932908, 0.23681064854775155, 0.4064369393246514, 0.9692872741392681, 1.395378713096891, 0.4179986874972071, 0.5384323565023286, 0.20991214976779052, 0.36153268601213184, 0.24676407873630524, 0.17844918662948267, 0.22634993200855597, 0.11416015135390417, 0.1729444627250944, 0.2099387619112219, 0.1570441345019, 0.13797275429325445, 0.09535263305796043, 0.17724193712430342, 0.07908012837703739, 0.10045292973518372, 0.11529607325792313, 0.19474983694297926, 0.1072993345026459, 0.21329430756824358, 0.14675596941794666, 0.1346206148820264, 0.16463512288672583, 0.1041716748316373, 0.1331375137503658, 0.1558363421687058, 0.1342361026576587, 0.14700235905391829, 0.08442458231002092, 0.10312446459595646, 0.06259376302893672, 0.18137057844017232, 0.10605328636510031, 0.11985737564308302, 0.11219792986022574, 0.13527222563113483, 0.13015953211912087, 0.10205261675374848, 0.11458842908697468, 0.10080474335700274, 0.09645173765186753, 0.11705377751163074, 0.128421831077763, 0.12314683198928833, 0.22414271187569412, 0.16651315854064055, 0.10482590472591774, 0.13493994703250273, 0.16378281504980155, 0.10014400631189346, 0.13181126277361596, 0.0985870398581028, 0.18857119205806935, 0.138763071170875, 0.10740833436804158, 0.13122198225132056, 0.056284513723637374, 0.07934057725859539, 0.07944743973868233, 0.17583409909691128, 0.12811543180474214, 0.08546723957572665, 0.08400637403662715, 0.1778327782771417, 0.14640387759677, 0.23699917271733284, 0.13885691256395408, 0.17773633130959102, 0.12465707452169486, 0.16524258814752102, 0.11245357471385173, 0.1226108300366572, 0.08989439558769975, 0.08618965545403105, 0.10625668402229037, 0.10812688259673969, 0.05982488553438868, 0.07987689133733511, 0.11609093632016863, 0.0948506732072149, 0.1290436948516539, 0.10060604116214172], [0.038201148355645795, 0.03418624307960272, 0.06489876684333597, 0.017977395161454166, 0.07945315300353936, 0.023511241788842847, 0.06259559507348708, 0.050358141373310766, 0.04358012615037816, 0.045743485779634545, 0.016501240532046983, 0.046806509273925, 0.009384811905744885, 0.016479615621002655, 0.00660575384141079, 0.07847178102071796, 0.0598714126806174, 0.0466878301064883, 0.06125208216586283, 0.02186919722173895, 0.02538246155849525, 0.01929629760395203, 0.046699273599577804, 0.01522650902292558, 0.01711370320325451, 0.04382226137178285, 0.029132117317723374, 0.05147323225225721, 0.027978404225515466, 0.06594366327460323, 0.009473163102354323, 0.03289508254134229, 0.06000928421105657, 0.02694378251076809, 0.04818788443558982, 0.013730444479733706, 0.039617325578417094, 0.03171740698495081, 0.032833115330764225, 0.08987422952694551, 0.03935889194586447, 0.012523915069842977, 0.027072419179603457, 0.016554208671940223, 0.01888262533715793, 0.016266944086445228, 0.05533524323254824, 0.06915778866303818, 0.07923152989574841, 0.057188987332795344, 0.052443645894527435, 0.037357132216649394, 0.04810536779197199, 0.07517279125750065, 0.032366435908313305, 0.00768875764749412, 0.01790706331043371, 0.04029610486967223, 0.03418688768787043, 0.029708878868924718, 0.004792795632965863, 0.035302775845463784, 0.028687870262988975, 0.040853772445448806, 0.05853235774806567, 0.04884093028626271, 0.017093560891225934, 0.021471143134736588, 0.02820257523230144, 0.026256860799289176, 0.036776431769664795, 0.05851386088345732, 0.025381075650719658, 0.009997653708394085, 0.02918042561837605, 0.01687457219564489, 0.028035128056736927, 0.03523770772985049, 0.09390058847410337, 0.05461296984659774, 0.0306818743369409, 0.013035182724706829, 0.14423260624919618, 0.022167250514030457, 0.06437353324145079, 0.09023973598544087, 0.053790928064180274, 0.056054598917918544, 0.058333302714994976, 0.05536520055362156, 0.07296263306800808, 0.08185772504657507, 0.06323100919170038, 0.026769042780090655, 0.02976593009329268, 0.1483400229896818, 0.10694838262030057, 0.021041537169367075, 0.05002268723079136, 0.0756018018083913, 0.018660515380491103, 0.05327479700957026, 0.05422531600509371, 0.07416266974593912, 0.015990603914750472, 0.05832203224833522, 0.0392655017785728, 0.06357949799192802, 0.017190839064174464, 0.043304915739489455, 0.055965649762323925, 0.00503065311516236, 0.06014309131673404, 0.039134860038757324, 0.017707945512873784, 0.06801715094063963, 0.038267766923776696, 0.07404151053300925, 0.029363575790609633, 0.019446925592741797, 0.01676590141973325, 0.059918747283518314, 0.04211415463526334, 0.04037394979968667, 0.019108295906335115, 0.027526778102453266, 0.023262470494955778, 0.057822840820465765, 0.04474349818857653, 0.04177179639892919, 0.04690587394205587, 0.04541398917457887, 0.04076554253697395, 0.036197973880916834, 0.03344864498025604, 0.020622923471299664, 0.01945924269966781, 0.0573846496907728, 0.024180887998746972, 0.039170612048889906, 0.052128218713083437, 0.0320544760408146, 0.016200150795547024, 0.030817611874746423, 0.021432848314621618, 0.040210416074842215, 0.025147322033132826, 0.02480945909129722, 0.042646838551653285, 0.0825387095766408, 0.019709639084924544, 0.02111350089710738, 0.020348145626485348, 0.03530069274295654, 0.06731898590390172, 0.02480205288156867, 0.048344266401337724, 0.04278762099732246, 0.0414115316234529, 0.06814853567630053, 0.029976062210542814, 0.009941233521593469, 0.024185932906610624, 0.05081523988129837, 0.056320906949362586, 0.01022603502497077, 0.04937461843448026, 0.025285559972482066, 0.009970875323883124, 0.030665457182164704, 0.1282115802168846, 0.029934793710708618, 0.04408845744494881, 0.05135243944823742, 0.037373311884169064, 0.05956419916557414, 0.0387362105372761, 0.03845553452681218, 0.03478668889562998, 0.03553863461794598, 0.08851180584835154, 0.0385186789956476, 0.06423980077462536, 0.019145583101947392, 0.07361617764191968, 0.013507536396251192, 0.048718403825270276, 0.01153186209765928, 0.0057728856086864, 0.07416521425225905, 0.02833255031146109, 0.016547009415392364, 0.037651107513478825, 0.015462408507508891, 0.016751260330368365, 0.06425097624638251, 0.02797298951606665, 0.033884759792791944, 0.033784414641559124, 0.049717315938323736, 0.06618467212787696, 0.025962244286867123, 0.007482896060017603, 0.02621467797351735, 0.04154033792604293, 0.11108441996787276, 0.04711033011387501, 0.0238008880322533, 0.05293458972924522, 0.028771269002131054, 0.017438014104430164, 0.06950777702565704, 0.03267553575070841, 0.05545286388535585, 0.051651195024273226, 0.05732071812131575, 0.02027196480360414, 0.02226099860854447, 0.06118190807423421, 0.03379125766722219, 0.02717688982374966, 0.0408298778347671, 0.07581604245517935, 0.05476296001246997, 0.05368569067546299, 0.06824828032404184, 0.02949062468750136, 0.03512622103361147, 0.10598841841731753, 0.04957417219078966, 0.04775069075237427, 0.041144690942019224, 0.08030799177608319, 0.061808738724461625, 0.02453579574025103, 0.018187182922182337, 0.020158832659944892, 0.054911267411495955, 0.02271239911871297, 0.04785178229212761, 0.023301511703591262, 0.060522439889609814, 0.02919334153245602, 0.05697842434580837, 0.01990311316746686, 0.004734837292094848, 0.030034694421504225, 0.020525560481473804, 0.0627912235047136, 0.06396335203732763, 0.03308142861351371, 0.033067243838948865, 0.04813931489895497, 0.05926527734845877, 0.09721055693392243, 0.022306468936481645, 0.034875180040087016, 0.11062804409968001, 0.0574342031031847, 0.01507385221443006, 0.015393873077950307, 0.057794165930577686, 0.043890216653900485, 0.057629241208945, 0.018966809480584094, 0.02996087320415037, 0.07317064476332494, 0.011637359874189963, 0.04980758484452963, 0.027634003598775183, 0.04916659316846302, 0.09039131392325674, 0.03603339860481875, 0.022479327428819876, 0.02912101648481829, 0.009005102012971682, 0.03381882993770497, 0.049539064788924794, 0.013244347929555391, 0.06921842933765479, 0.08382202964276075, 0.035012831046645126, 0.029694348041500365, 0.057923338642077785, 0.022952602211652056, 0.007897368149964936, 0.07550071366131306, 0.055593463126569986, 0.027349909468154823, 0.012130156109508659, 0.05644337912755353, 0.03881661015163575, 0.02624813823162445, 0.040583053936383555, 0.049282246069716554, 0.0614323282082166, 0.017592418140598705, 0.04293930071539112, 0.036235239024141004, 0.035064725404871364, 0.026269216921978762, 0.0061794158703248414, 0.035846068656870296, 0.04008181333275778, 0.01600085148986961, 0.04660234487216387, 0.019703639139022146, 0.01168091334069946, 0.028919803710388284, 0.05330853716337255, 0.027660654757970145, 0.038210369646549225, 0.04098192056907075, 0.0488251238130033, 0.013741407061128743, 0.03517820360139012, 0.023603212121608, 0.033851182487394126, 0.03962459947381701, 0.03213468227269394, 0.027683918331084505, 0.025797918372388397, 0.08149395563772746, 0.08676989110452787, 0.09020601958036423, 0.046728192762072594, 0.03795221082067915, 0.019565801535333906, 0.03605439926364592, 0.011097870251562978, 0.029635461379906962, 0.020049800564135824, 0.0288913323810058, 0.05659961520827242, 0.011668634401368243, 0.08611549836184297, 0.013304075974571918, 0.033365066429334025, 0.028801935392298868, 0.0321195407637528, 0.039297131688467095, 0.05529228178784251, 0.010868272660965366, 0.03471593465656042, 0.04403599311730691, 0.03469896788841911, 0.11225692169474703, 0.02363932884431311, 0.022580035596287677, 0.026599434470491748, 0.048990353875394375, 0.035414710374815125, 0.09762902983597346, 0.08939105831086636, 0.16229092010429927, 0.10724925183291946, 0.15250438238893235, 0.14379880524107388, 0.16619869827159814, 0.12866812571883202, 0.2611425614782742, 0.05921727099588939, 0.07661556026765279, 0.16878135183027812, 0.05511271767318249, 0.07487127743661404, 0.1821156098906483, 0.14503244975847857, 0.15310736931860447, 0.08520498579101903, 0.12519275077751704, 0.0688246822516833, 0.11853007972240448, 0.12847265335065977, 0.14155050659818308, 0.1910266067300524, 0.14710800695632184, 0.1265339023832764, 0.10442784894257784, 0.13102446070739202, 0.05917140881397894, 0.16739251278340816, 0.18550513658140386, 0.09088169118123395, 0.1621855164745024, 0.07370444147714547, 0.12480798070984227, 0.0979813930711576, 0.1563240188573088, 0.18144869139151915, 0.0838912334293127, 0.1224285891013486, 0.12686073913105897, 0.0830269901614104, 0.17963709788663046, 0.09172317638461079, 0.07787114182221037, 0.15365862473845482, 0.1847284853990589, 0.13767637019710882, 0.1338230376797063, 0.11533648680363383, 0.14582146384886333, 0.10357290160443101, 0.14085419396204607, 0.18531693810863153, 0.15466536714562348, 0.12814607444618428, 0.1574544989104782, 0.11765443028083869, 0.10495762872908797, 0.11869481445423194, 0.10988534002431802, 0.12420609300690037, 0.08027321685637746, 0.14073830018086092, 0.17650077332343372, 0.1314858238079718, 0.15944120873297962, 0.1278484147042036, 0.10835426646683897, 0.12224397329347474, 0.10602385151599135, 0.15809138544968196, 0.1829711204128606, 0.13260476876582417, 0.101105225804661, 0.07084666232445411, 0.11832856839256627, 0.15002425547157014, 0.1655517422727176, 0.16380147476281437, 0.1503928221229996, 0.16496205462941102, 0.26249490891184124, 0.06230667486254658, 0.13026306299226625, 0.14073391684464046, 0.20220657038901532, 0.3574245364538261, 0.22922020299094065, 0.15042934087770327, 0.2487063987978867, 0.1493007064397846, 0.13786625143672737, 0.10190634495977845, 0.11224768004779305, 0.31344832905701225, 0.20138936995395593, 0.14110837318003178, 0.1750716564378568, 0.1165223488850253, 0.12542197347751685, 0.24968107364007405, 0.07376859017780849, 0.21799800731241703, 0.14490244244890554, 0.09538162685930729, 0.08587011974304914, 0.14828223894749368, 0.09697867437664952, 0.09324941877275705, 0.21098757348954678, 0.15358119032212666, 0.15066239051520824, 0.16201151295432023, 0.08637571654149465, 0.1012268192800028, 0.12476511086736407, 0.2304823324084282, 0.11996158505124704, 0.11392733241830554, 0.041862146729337316, 0.14100695933614457, 0.16985163225659303, 0.1330259625933, 0.10594873090407678, 0.08735302409955434, 0.06307807418384723, 0.1965496510799442, 0.14292709130261624, 0.08779604639858007, 0.13867901425276483, 0.1470254970980542, 0.14017392189374991, 0.13822826343987668, 0.11007980137531247, 0.09691531956195831, 0.09877170316342797, 0.1980060857853719, 0.1275369128478425, 0.1505999110106911, 0.07373995600002152, 0.144783332411732, 0.12112833958651338, 0.12617708795836993, 0.12596727135990346, 0.12106467943106379, 0.25054631435445374, 0.12854832357593945, 0.19797726161777973, 0.09872379859111138, 0.07872420961835555, 0.056621423323771784, 0.1574066486209631, 0.16867792952273572, 0.1449769998767546, 0.11118204758635589, 0.1340108018900667, 0.09298228632126536, 0.09452499675431422, 0.15794604324868747, 0.08633282634296588, 0.13083392807415553, 0.12190737921212401, 0.14405968838504382, 0.11863437055477075, 0.06497079333556549, 0.10505807905324868, 0.066676243607487, 0.09931921985532556, 0.10473926258938653, 0.30207575644765583, 0.11087730393878051, 0.13002294301986694, 0.14700598243091786, 0.2765244346644197, 0.13591813668608665], [0.02437900665349194, 0.13774472581488745, 0.059323102102747986, 0.05059843776481492, 0.041272798353540044, 0.03825808762173567, 0.01935101975686848, 0.04940515590299453, 0.04371604349996362, 0.10197058186999389, 0.03848505758547357, 0.031958297094596286, 0.0392846262880734, 0.039207334364099164, 0.060931277594396045, 0.06076247165245669, 0.041713798618210216, 0.05326768256989973, 0.027076156211218665, 0.028300828799339275, 0.050731729183878214, 0.043701678913618834, 0.054012910795531104, 0.04294721921905875, 0.012646207436253982, 0.027291531707825403, 0.04602352735985603, 0.05809679933424507, 0.03056125116667577, 0.02997850832928504, 0.03265570556478841, 0.022176794109067748, 0.017505387542769313, 0.036233878561428616, 0.012114786443167498, 0.019550478518275276, 0.01170015913833465, 0.07905289198138885, 0.03067563520744443, 0.031212390333946263, 0.021209903759881854, 0.0060465714362050805, 0.03672539236556206, 0.08141623623669147, 0.043347120617649386, 0.0261736113378512, 0.0483314251261098, 0.005930788765129234, 0.038199051682438166, 0.029958372802606652, 0.017758430214598775, 0.020315197662317326, 0.02272975943716509, 0.038519849468554766, 0.10494371197585549, 0.010089913266710937, 0.03394048787387354, 0.057021708094647953, 0.04561907299129026, 0.012554754486440547, 0.03611691948026419, 0.009987492646489824, 0.0026300331145258887, 0.03917682742966073, 0.01647984462657145, 0.026940472956214632, 0.00406514061614871, 0.024915583664551377, 0.03311469040012785, 0.034312043472060134, 0.04279851148437176, 0.03772116964682937, 0.017418414620416503, 0.017004269075446894, 0.019933357169585567, 0.10946451939110245, 0.06190389647547688, 0.07526772509195975, 0.017133631776752214, 0.027216417881261026, 0.06645167565771512, 0.03349910762959293, 0.1118559210694262, 0.02703135763294995, 0.04549014115972178, 0.011278093393359865, 0.04063895843657, 0.03398075892723032, 0.04017735106338348, 0.0728165309077927, 0.010916058489653682, 0.08952863128589732, 0.05881521185593946, 0.07567079524908747, 0.0748122041778905, 0.17207627716873372, 0.05849955736526421, 0.009827315973650132, 0.040346007727618725, 0.014694461233115621, 0.028532407712191343, 0.03949035471305251, 0.04993045057303139, 0.05802364647388458, 0.02092035420771156, 0.04547076898493937, 0.02946091503170984, 0.013437583676672407, 0.023852029216608832, 0.029581524631274596, 0.02988784248009324, 0.019771273813343475, 0.01792494610085019, 0.03005580703860947, 0.023596155357414057, 0.07502523703234536, 0.013532939051011843, 0.06423186191490718, 0.007891882194339164, 0.05135653101439987, 0.019491971836292317, 0.05796001345983573, 0.05682795920542308, 0.021271222969517112, 0.019791950471699238, 0.02931975939178041, 0.047172354999929667, 0.10748099189783845, 0.07951586999531303, 0.008716817928611167, 0.031803173811307976, 0.01994614925102464, 0.05000802069636328, 0.051637458082820685, 0.022876831902457134, 0.015904999936797788, 0.033098653224962096, 0.029825261195323298, 0.02856140151353819, 0.06340856145003013, 0.05032470656026687, 0.013034119121065097, 0.03260387566738895, 0.025944999319368174, 0.025508399354293942, 0.015512073878198862, 0.06803703880203621, 0.03737244675202029, 0.016296124484922205, 0.0561876596350755, 0.025386278317975144, 0.01180081132666341, 0.015017301409638353, 0.027274317274402295, 0.033282288549734015, 0.052693370530115705, 0.07272545115223952, 0.04690865254295724, 0.06728186325303145, 0.02826575532422534, 0.013843069418466516, 0.06606047307806355, 0.03543965671477573, 0.03718388865568808, 0.05018196654106889, 0.010429125645064881, 0.03598483585353408, 0.01680392143316567, 0.02426153527838843, 0.030461662581988742, 0.0145909032185695, 0.04077195808557527, 0.04958010258685265, 0.021464496884228926, 0.025579014493684684, 0.03050659177824855, 0.03489638765209487, 0.08616739272006921, 0.054076445422002246, 0.07745930499264173, 0.023600881353818944, 0.024573607104165212, 0.03694355155208281, 0.048276758952332396, 0.05125613158036556, 0.0452894203231803, 0.03507172788626381, 0.04407546349934169, 0.041852715092578104, 0.0929717690284763, 0.06723905447870493, 0.04412850797442453, 0.0054974160822374475, 0.04623212938063911, 0.061907608062028885, 0.04420928078304444, 0.01909945289870458, 0.01994572177396289, 0.0132576090483261, 0.006534122171745236, 0.024714169025953327, 0.01854592438654176, 0.07519132883421012, 0.059739620823945315, 0.034319388613637, 0.01922875453185822, 0.06031414320958512, 0.017826063192582557, 0.030410463722156625, 0.022014152657772814, 0.029858662081616263, 0.02034348069823214, 0.019451595610007644, 0.04828056214111192, 0.010421821215589131, 0.00846869039482304, 0.027315467030608227, 0.009906281334614115, 0.1411764845252037, 0.0368892857139664, 0.03407291416078806, 0.053270108332591395, 0.06650994145976645, 0.02334817625316126, 0.038228703662753105, 0.0295724865448262, 0.0031801528363887754, 0.03646109279777322, 0.012634883534961512, 0.05077034800446459, 0.08296872435935906, 0.06407415002052273, 0.042255605437925885, 0.03773113054090312, 0.013999445447033005, 0.06164179875382355, 0.07454393178756748, 0.03679211949929595, 0.04075312873880778, 0.025217262030180012, 0.03964805303673659, 0.03255556058138609, 0.03366912814921566, 0.03826614522508212, 0.030004469079098532, 0.034823865829301734, 0.08378528697150094, 0.029149538704327176, 0.0911042167405997, 0.02254863638829972, 0.0522990263333278, 0.0422181435195463, 0.07480193115770817, 0.0585335519696985, 0.02869055386898773, 0.04252725014729159, 0.05946698545345238, 0.01325433426869235, 0.03322237051491227, 0.009365890956749874, 0.036172274367085526, 0.06445649093283073, 0.03461920948965209, 0.04406603864793267, 0.10857304651290178, 0.03315723454579711, 0.0419339934097869, 0.060425144753285816, 0.05907345549868686, 0.020197085071621195, 0.017523110877456408, 0.06937653478235006, 0.06983013544231653, 0.009872183253589486, 0.02186421847103962, 0.01598976762033999, 0.06799697809453521, 0.037639412962432416, 0.008717068138399293, 0.024560616551233188, 0.026987412312467183, 0.037588041076170545, 0.019717123326180235, 0.029657914103674035, 0.0552624160689967, 0.0703072812674301, 0.002024881022017715, 0.027862590172195008, 0.010119745058805814, 0.01699751934834889, 0.07425250099705798, 0.024725973838940263, 0.02291883491644902, 0.008247073224213506, 0.0037548308609984815, 0.078374268753188, 0.06835268650736127, 0.035050544022981606, 0.02939934137144259, 0.04764772645596947, 0.008849464739406747, 0.0022325844079854763, 0.031717844640037844, 0.030280486946659427, 0.04773616671030011, 0.015497938297422869, 0.03250469420371311, 0.03914668011878218, 0.019482036387281756, 0.0293924576336784, 0.04124628799036145, 0.04016786514382277, 0.01896509787599955, 0.02600452210754156, 0.05816719734242984, 0.02993074624932238, 0.03476636677182146, 0.013620755053125322, 0.031970680358686616, 0.039917696067797284, 0.030202798079699278, 0.023436903188537275, 0.027050999525402273, 0.05380074307322502, 0.012057492642530372, 0.017472675369520272, 0.022538309085315893, 0.015036970443491424, 0.02861705156309264, 0.015158287415813123, 0.03870339658377426, 0.06676306894847325, 0.06028862350753375, 0.031187980036650385, 0.035714833198913505, 0.025285622736971294, 0.02464473114481994, 0.11485341058245727, 0.01906172126265509, 0.10269739465521914, 0.02649757618616734, 0.09088760122124638, 0.05270213380988155, 0.02906733757949301, 0.011978455187220658, 0.051234876470906396, 0.06596450787037611, 0.00852819113060832, 0.01626562263949641, 0.017899321225870932, 0.06417118731353964, 0.033907572140118906, 0.15347713019166673, 0.2049421521701983, 0.09605123914246048, 0.1526098945843322, 0.1134440458512732, 0.10876433910535914, 0.130648633731263, 0.09347793579633747, 0.0902882648099746, 0.25012608404670444, 0.1347598366971527, 0.09658466944737093, 0.15413306999419416, 0.32127509479011807, 0.13370187846677645, 0.06499523416693721, 0.1545013380902154, 0.09220348418291126, 0.10272138765347855, 0.1434412444276469, 0.15863881393202714, 0.0930736849882773, 0.12736976253134863, 0.11581555966820035, 0.09276331628539733, 0.12491362861224584, 0.2023947010082858, 0.23866435193589755, 0.11749099833624703, 0.1580286616725581, 0.28319766372442245, 0.0972646361749087, 0.09694548044353724, 0.16716840623744897, 0.1035644741994994, 0.16289330992315496, 0.07565984369388648, 0.25446382271392004, 0.12428822288555758, 0.07348040957003832, 0.16502525338104793, 0.10503570096833365, 0.24383837144289697, 0.23289381872330392, 0.20263452242527688, 0.1460639586938279, 0.10036277957260609, 0.10158526218895401, 0.15817496739327908, 0.11850163553442274, 0.11866660096815654, 0.14749496190675668, 0.06407631454723221, 0.11561153775879315, 0.18499392829835415, 0.14746666699647903, 0.13684373987572535, 0.19993423803576402, 0.24855340272188187, 0.11205544429165976, 0.30152978003025055, 0.11912149084465844, 0.12485459606562342, 0.1516394538006612, 0.17197655966239317, 0.07520135758178574, 0.08466785747025694, 0.11739755049347878, 0.18276856413909368, 0.07409512158483267, 0.21977392344602517, 0.13382777385413647, 0.14128057179706438, 0.13570081549031393, 0.11236980278044939, 0.19307415400232586, 0.24201129376888275, 0.07206470732178007, 0.09798580354877881, 0.10107503099633114, 0.22817591045583996, 0.22965913372380392, 0.1930170484951564, 0.1114770339003631, 0.07770969119987317, 0.1639554886413472, 0.15894153554524693, 0.2207569306982415, 0.18822117655404977, 0.25441887655428475, 0.11625814091946397, 0.21293279768100806, 0.14043253873075756, 0.12471612063901764, 0.1075131476723722, 0.23701206488268717, 0.2069397321236985, 0.06346671868647848, 0.1681982052645513, 0.07676996769649641, 0.16015926163111413, 0.12294822478932993, 0.06503087761146681, 0.12940706392484053, 0.055613211888287745, 0.15212425350078515, 0.08339619463575737, 0.13344145672661917, 0.11104929220995732, 0.19454110600054264, 0.16450991960508482, 0.2430093102157116, 0.08549313247203827, 0.14634432936353342, 0.12932209776980536, 0.16680011100002698, 0.09234384593686887, 0.10354670336736099, 0.07250543617244277, 0.11451411593173232, 0.09754630284649984, 0.11453482482050147, 0.1182733763541494, 0.12131480100963797, 0.19099725330514566, 0.0377398259671671, 0.11404777238411562, 0.15895697900227138, 0.12191602374826159, 0.0627036721312574, 0.06826775427907705, 0.10400921319212232, 0.10771469292896134, 0.17058808702443326, 0.24739582198006765, 0.06815614205385957, 0.08859740304095404, 0.11496154192302908, 0.1185503543487617, 0.1729320591049535, 0.12024775041001183, 0.055032172173793824, 0.1411908016140972, 0.10820386239460536, 0.08693706177707229, 0.0933537163904735, 0.13435651548206806, 0.10347143347774233, 0.0742836728958147, 0.07835350558161736, 0.13676420200083936, 0.07521711316491876, 0.08529840649238654, 0.09235707058438233, 0.10325557791760989, 0.12060479553682463, 0.12054455519786902, 0.11209963049207415, 0.2704084999859333, 0.06520861985960177, 0.11943531329078333, 0.22858552847589764, 0.10167358709233147, 0.26622856142265455, 0.14003852701612882, 0.16541481390595436, 0.10782542305865458, 0.1612105295062065, 0.1058352119954569, 0.0964595340192318, 0.12270654418638774, 0.15564023197761603, 0.13426707099590982, 0.181963034506355, 0.09629161695816688, 0.11933501224432673], [0.05081018140273435, 0.06536422151007823, 0.046634605819625516, 0.016522444751379744, 0.015745359306622828, 0.0036955714292292085, 0.01990238543865936, 0.05367774503039462, 0.011580736126883753, 0.04612287845728653, 0.011471089108714035, 0.02896889911166259, 0.07292463510696377, 0.012720338235210096, 0.04162864247336984, 0.04211065000189202, 0.061587556664432795, 0.028240680062611188, 0.030871857356812273, 0.05631715804338455, 0.04539687652140856, 0.06321878877601453, 0.025673510673056756, 0.017295818609584655, 0.039075030213488, 0.03941999063161867, 0.01926329535698252, 0.0900418683886528, 0.029426075651177337, 0.024667368769379597, 0.049315942118742635, 0.008709201373026838, 0.006215802734784249, 0.04492152202874422, 0.08275122674448149, 0.016352595561849217, 0.00928669234937323, 0.046327816388968907, 0.025655627882640277, 0.03623502528561013, 0.11957232308174882, 0.015864075793485557, 0.02567765482568315, 0.02692834583909384, 0.045946479708488495, 0.08095836080610752, 0.06771270584847246, 0.03885868610814214, 0.043086240866354535, 0.06768890284001827, 0.07253149191715888, 0.03164544834622315, 0.07064660984490599, 0.038904812918709855, 0.015865044402224675, 0.024399629029046212, 0.03907836860577975, 0.029569894541054964, 0.09527376014739275, 0.029874315884496485, 0.009157785114699175, 0.014380779583007097, 0.04586997827781098, 0.04497982854289668, 0.009294933157174714, 0.0904102111235261, 0.008718100359796413, 0.017755086733294383, 0.016852211074105332, 0.024886186134868434, 0.014441074204764195, 0.023368727382538573, 0.017666512468297566, 0.040125256537326744, 0.012454986089973577, 0.032256774471274445, 0.029289435661797012, 0.017435567985687937, 0.029980747494846582, 0.014215733573239828, 0.04186465730890632, 0.04636105103418231, 0.07452156727335282, 0.056166116148233414, 0.06002273956047637, 0.04354157518329365, 0.04495897376909852, 0.06077780654387815, 0.07698465617639677, 0.02122010723022478, 0.047781499634896, 0.07561157949801002, 0.17505041829177312, 0.017587252792769244, 0.021870871506897465, 0.04392929348562445, 0.036410586043660126, 0.049639959553522725, 0.029412196217370883, 0.03831208883119481, 0.03617742784055216, 0.04484805364960006, 0.0146965053198593, 0.04761073611942785, 0.02601119549944997, 0.04777288224015917, 0.07547136023640633, 0.02163229520166559, 0.06330800256026642, 0.037830267899802754, 0.022447792513828193, 0.040088703855872154, 0.04971837106027773, 0.07214684398578745, 0.016174919470878582, 0.03990760625206998, 0.01703166831949992, 0.03455672659245985, 0.042653369451207776, 0.027186808309384754, 0.021771764682073678, 0.028119475048567568, 0.026505409872957637, 0.026147771028003523, 0.03505016065069607, 0.026456407770248394, 0.039542839396744967, 0.0540241066233388, 0.00916422186751983, 0.012601613266659635, 0.04075234163818615, 0.09732097493750708, 0.024676427211878554, 0.03728061382259641, 0.027161651623568366, 0.04312455773885761, 0.06635734571942262, 0.0634128430059978, 0.03584992612845131, 0.04445633199065924, 0.08314314857125282, 0.036376822141132185, 0.06545707224203007, 0.004446526914502361, 0.022960936318018606, 0.028138597861730626, 0.0485672330084656, 0.014482045845527734, 0.05101025423833302, 0.028736253202493702, 0.013936289103834756, 0.02321229113398918, 0.03594628149377448, 0.06093025979186807, 0.026684215724734322, 0.014218305220960506, 0.08753139738525663, 0.06482304233525481, 0.0024651749741419083, 0.009487036598979362, 0.06068709998258522, 0.02888956818995731, 0.06614452999617372, 0.025915287967239107, 0.02912071792941008, 0.04845970556406038, 0.015574795958985175, 0.013564678374677896, 0.049739090127072165, 0.020132729417777488, 0.03296712599694729, 0.04918972442724875, 0.03052014551524605, 0.031486019758241515, 0.00961029333328562, 0.04296749723809106, 0.04746561444231442, 0.022890411084517837, 0.040165683653737815, 0.02938018972054124, 0.02145402199987854, 0.049962253509355445, 0.03295695136434265, 0.0481569228826889, 0.014374384390456336, 0.02183966737772737, 0.08024284562894277, 0.03746882247339402, 0.06386881175317935, 0.03370226101417627, 0.03279896805595074, 0.05819790783737387, 0.027494895438264524, 0.011557324972402836, 0.03987453445526106, 0.02533874863625637, 0.02845313785863774, 0.03822620326120939, 0.05407042681638684, 0.047581470904073546, 0.04915544144543154, 0.0372908088112516, 0.0735756012478045, 0.016450296122846857, 0.015733871708757112, 0.0385517609704818, 0.042820645296680074, 0.025573754150952612, 0.018384848654802357, 0.027356835614357675, 0.02090462576597929, 0.049005583593887944, 0.039564837502049546, 0.07988466734864882, 0.05278024336855326, 0.03136873837294323, 0.035860636803720675, 0.006394636152046067, 0.0291131285152265, 0.008222585743559259, 0.08843061234802008, 0.06141520198434591, 0.053882387799343893, 0.031975263862737587, 0.030305887905082533, 0.02395801299384662, 0.06889358748282705, 0.052521470468491316, 0.03433884899797184, 0.004814593570439943, 0.04567313187622598, 0.08596907729016882, 0.027336372694532787, 0.060861089932067056, 0.040686808726085086, 0.0522512337192893, 0.02871689459841166, 0.07728089778018848, 0.006870832452217915, 0.07257798513663666, 0.022348368473883187, 0.08140493862863098, 0.0050928162527270615, 0.10212040240211145, 0.033480865215616565, 0.04072974642206516, 0.0227776470461062, 0.036518137236790996, 0.03952325348343168, 0.028575243627918617, 0.008541989140212536, 0.04585364254723702, 0.017490972066298127, 0.01672067366806524, 0.0772674356454185, 0.01626535122548895, 0.03656121403244989, 0.05438244096668703, 0.04651813189099942, 0.025679247686639428, 0.08812947172139372, 0.03994427428447774, 0.016338619436802607, 0.0985449164041451, 0.029468477304492677, 0.02884410973638296, 0.013561755585085069, 0.06281058210879564, 0.011310349251808864, 0.03303797183824437, 0.025111028891322867, 0.03949156929073589, 0.057947731975998194, 0.057922124064394405, 0.061369170168680806, 0.052901348298681636, 0.01647293035473142, 0.09921336160706622, 0.017480078186573725, 0.030509445018001964, 0.06025532779416867, 0.07309893039720398, 0.014895718112321836, 0.028985458758792708, 0.05250981662954603, 0.04492799525282212, 0.02944391094414251, 0.005161860583549631, 0.02052058681978711, 0.028607043171567575, 0.011321763058991303, 0.056895992519067864, 0.035332692454435995, 0.03746091414775167, 0.038739850877651145, 0.049278490378388336, 0.02824670884625188, 0.006979546908821378, 0.0558565209752747, 0.04536228819883295, 0.042889306255217106, 0.030923412447529178, 0.042521944003445764, 0.0728790375537106, 0.01445941670265581, 0.024365139094048312, 0.0065997276022764185, 0.03228222292714885, 0.0801764102652669, 0.0755861344348107, 0.02323365311271378, 0.03109775184254561, 0.0675566495795335, 0.06352438059236322, 0.03780173210959349, 0.02412353312995817, 0.007668340528782989, 0.041742191916065555, 0.06597216853073665, 0.023629203405497328, 0.04824604506471327, 0.021907766848536472, 0.05774381863219397, 0.04006561330918755, 0.01935056853108108, 0.041901613718697, 0.025458801837105836, 0.03290686530194112, 0.02126679552852043, 0.08226248475589923, 0.04094245357971106, 0.017890761506610682, 0.048709725362381766, 0.06852820316063506, 0.05702531790094716, 0.036571493837982416, 0.039822982757219245, 0.04403775391568031, 0.04153602922867451, 0.11056922868426357, 0.052554895103509934, 0.034171797069055695, 0.02130772645718285, 0.021866535668128302, 0.005345319489216698, 0.0308795756926494, 0.03164459339209965, 0.01490157047685768, 0.011631967217129256, 0.0458185622867729, 0.004909819174957062, 0.023811050790495107, 0.18952248458351406, 0.15682065220815794, 0.2325192131102085, 0.09543627606970922, 0.08993108397615807, 0.10102523331131254, 0.13018413579889707, 0.17114865194473947, 0.10925819724798203, 0.23215432411858014, 0.18110483698546886, 0.19672635516950063, 0.15259951299854688, 0.11463967205158301, 0.09219525355313506, 0.08744789008051157, 0.12278833479753562, 0.15221580144550118, 0.13140226900577545, 0.12626198625990323, 0.12492524513176509, 0.13013578339346818, 0.141538496528353, 0.12261792751295225, 0.13593436724373273, 0.12827576962964876, 0.07522756938955613, 0.1373898112880332, 0.13803706584232195, 0.06139476450958422, 0.1124458054878882, 0.08826819820595638, 0.12751058568911894, 0.10115980716156107, 0.13327412999102048, 0.1487665908145053, 0.12270043737121991, 0.21891675729836735, 0.17787220116172517, 0.09922854043543339, 0.15170280183000223, 0.11178413884980337, 0.09745265822857618, 0.07881885846810681, 0.14458663868052618, 0.2561169782919543, 0.1369005875395877, 0.14008956642023154, 0.13062522427311965, 0.18721163858260426, 0.11388244054147176, 0.21766737076853002, 0.18356386146375112, 0.12937836189355167, 0.06534464577479021, 0.1418928817978927, 0.16233369495187486, 0.19600500459117548, 0.12265353703073092, 0.14233638585678168, 0.08476228918880224, 0.18174076000494616, 0.14352713339030743, 0.13814358226954937, 0.10624924049313579, 0.20408862297024044, 0.10871672630310059, 0.1797516481684787, 0.14340686984360218, 0.11893341450818948, 0.10319874382444791, 0.0859463531523943, 0.15100890477853163, 0.13670728648347513, 0.15715978401047842, 0.10458892637065478, 0.12012128505323615, 0.10704172189746584, 0.22249662663255418, 0.1295152495482138, 0.18288333155214787, 0.13684327847191266, 0.10426951279597622, 0.1123890799603292, 0.16123665310442448, 0.11035299992987088, 0.15690407130335057, 0.20595547636704786, 0.12758673088891165, 0.18117482108729227, 0.09525087316121374, 0.13160634519798414, 0.33410203935844557, 0.10186128344919, 0.12342144868203572, 0.06674207507499627, 0.13092795945703983, 0.16472277604043484, 0.07182920817285776, 0.16844506987503596, 0.20312958157488278, 0.14651593086974962, 0.09265807550400496, 0.17042466865054198, 0.1298003699630499, 0.2800104761762278, 0.17182967040155614, 0.18875097669661045, 0.16612008320433752, 0.12478807249239512, 0.09035212852592979, 0.10420932673982211, 0.09095140386904989, 0.16891779165182794, 0.15422254162175314, 0.19695465506187507, 0.16675276282642568, 0.10797297728380986, 0.14764980359801225, 0.1810197215527296, 0.1302148870059422, 0.06292289322508232, 0.12499711556094033, 0.10063755232840776, 0.13134312789355004, 0.17909963029835904, 0.13882599850850447, 0.11657447394515787, 0.11846793948539666, 0.10290524350213152, 0.13128284684249333, 0.16496058899377072, 0.11111915417547737, 0.15207428618201188, 0.06400541442313365, 0.08854436874389648, 0.09197845482932669, 0.18486614658364228, 0.09797597836170878, 0.1443006225994655, 0.15093476804239409, 0.13657634279557637, 0.1316804683634213, 0.08893731515854597, 0.08841105696878263, 0.12368698657623359, 0.11910342824246202, 0.14754237793385983, 0.08325858094862529, 0.15359192474612168, 0.0789907585297312, 0.07220537441649608, 0.10101075337401458, 0.16661659441888332, 0.21814724430441856, 0.14150925166904926, 0.19109053829950945, 0.19924647494086198, 0.16529537817197187, 0.17962168157100677, 0.13517351235662187, 0.1301578086401735, 0.145128014630505, 0.1445165460130998, 0.19009953790477344, 0.20734766737690993, 0.16838136900748524, 0.08731440867164306, 0.17912336545331137, 0.07692710283611502, 0.10476441588252783, 0.11564903360392366, 0.08822277707180806, 0.12131433960582529, 0.1062127353091325, 0.10212042275816202], [0.025211246817239692, 0.023076319501602223, 0.017135714879259467, 0.055664621093975644, 0.05963572354188987, 0.05355136788317135, 0.0184315912358995, 0.04473790027467268, 0.021903027281431214, 0.01680432685783931, 0.03398640773126057, 0.07859093855534281, 0.029543994859393154, 0.05807165961180415, 0.043761973535375934, 0.0368307484979076, 0.08729326552046196, 0.02047551004216075, 0.06339020707777568, 0.05384253065234848, 0.045865218354655166, 0.041232093037771325, 0.029777529649436474, 0.027268315632162348, 0.01496664877049625, 0.0531720600223967, 0.04552303653742586, 0.039048455389482636, 0.03928737435489893, 0.05954144788639886, 0.019636331857847314, 0.012296904394003962, 0.01496876749609198, 0.061202053778937886, 0.03553193747731192, 0.030430891018893038, 0.08313198667019606, 0.02356397413781711, 0.06951201786952359, 0.034655979302312644, 0.03037157348756279, 0.016472597872572284, 0.06142608568604503, 0.06433715019375086, 0.03060195648244449, 0.021875013963186314, 0.05473301965477211, 0.0546443656619106, 0.03181468176522425, 0.035784108231642416, 0.009443427153330828, 0.028121203616527573, 0.07723317641232695, 0.06814285633819443, 0.03343270619266799, 0.014083839936314948, 0.0566441067494452, 0.03587658576933401, 0.03303435863927007, 0.040220838372728655, 0.030484495285366262, 0.03107656119391322, 0.035985086911490986, 0.0407947873962777, 0.0174858152001564, 0.08137192789997373, 0.02569519665225276, 0.015798890630581548, 0.035314229516578574, 0.005595479659470064, 0.015470572980120778, 0.055641690003020425, 0.02687227340149028, 0.03864184667223266, 0.08901911934039422, 0.07671557632940156, 0.06963222713342734, 0.02356772813280778, 0.10237046969788414, 0.04186971918014543, 0.0298375087524099, 0.05421687163678663, 0.021116579749754498, 0.03593780319871647, 0.028539210025753294, 0.057554873770901134, 0.05379628849082759, 0.018728625029325485, 0.02266081010124513, 0.020808334861482893, 0.07123775633850268, 0.05246782888259206, 0.05275937841672983, 0.06386343775583164, 0.03824014037049242, 0.012546021740750542, 0.07530122436583042, 0.03955380112997123, 0.0353972991662366, 0.03770025719755462, 0.025728589056857994, 0.06593098824045487, 0.019897708636043326, 0.0482502485891538, 0.027761742905048386, 0.02431019811358835, 0.04050882559801851, 0.011304689421584564, 0.018495395580040555, 0.0522705142918442, 0.0551150212995708, 0.020058977750263045, 0.04912687172847135, 0.057072286094938, 0.022389675989480953, 0.06846475335104124, 0.03201289541487183, 0.029274277189480405, 0.05499206057616642, 0.04231715534946748, 0.024932623375207186, 0.07646144460886717, 0.05540696099134428, 0.028490552279566015, 0.0437256922679288, 0.00985837506595999, 0.07859971201313393, 0.018250893967758332, 0.0053664571273007566, 0.06349623495978968, 0.05275456760344761, 0.030707224405237606, 0.03414466923901013, 0.013647580935087587, 0.02769541271430041, 0.08379983476230077, 0.06894941055881125, 0.024358937283977866, 0.03665546254654016, 0.021351059399811283, 0.004471997846849263, 0.024362194252067378, 0.015298881568014622, 0.026450894673221877, 0.05682966232831989, 0.05380633420177868, 0.02933260745235852, 0.02047595617893551, 0.019408364447632005, 0.025272106319399815, 0.04903453329045858, 0.013544146753182369, 0.00849754679282861, 0.02088366581925324, 0.030730959560189928, 0.10981131185378347, 0.02711144681753857, 0.02474586509301194, 0.032821722727801116, 0.04029584363369005, 0.032122923260820765, 0.024161736347845623, 0.030916800123772452, 0.03584962757304311, 0.06392864497112376, 0.032819588735167465, 0.010993760079145432, 0.08139621945364134, 0.03820747569469469, 0.030583568183439117, 0.04587904689833522, 0.008638129070667284, 0.010004937781819274, 0.04094387171790004, 0.04754938976839185, 0.014731285328577672, 0.07575076738638536, 0.029018578053052937, 0.014853784648169364, 0.02854142544258918, 0.031343147424714904, 0.037654700356402566, 0.025184010421591144, 0.02056743627014969, 0.033744964615574906, 0.07522041763045959, 0.10404651226209742, 0.07496541738510132, 0.023218777928767458, 0.034408015465097766, 0.00993023022809731, 0.019556283385359814, 0.033045744456882985, 0.040739653033337424, 0.06661658680864743, 0.0323383275951658, 0.052607501923505745, 0.09773876251918928, 0.03371212352067232, 0.00745249429850706, 0.02298186403433127, 0.02945949350084577, 0.04289921286648937, 0.02602296299301088, 0.024626934867618338, 0.02725110628775188, 0.042490459978580475, 0.06001902797392436, 0.027947569897930537, 0.026974498094724755, 0.08622356184891292, 0.039672405658555884, 0.0701663156173059, 0.03641447404931698, 0.1094671046095235, 0.03059003801484193, 0.001320701090402768, 0.0212688430079392, 0.0307416668427842, 0.02030001544127507, 0.08044645363198859, 0.038350863714835474, 0.012574309865677995, 0.03502914981384363, 0.08856160353337016, 0.05327815915058766, 0.026225663455469266, 0.03286644836355533, 0.07910209934094123, 0.04824317486158439, 0.012023274121539933, 0.002855116326827556, 0.06696840721581664, 0.02709599657516394, 0.03050976392946073, 0.02984457230195403, 0.042698973789811134, 0.0010542854475456157, 0.04324215803561466, 0.011557542103608804, 0.0439490456400173, 0.03642361391601818, 0.021343698991196494, 0.027795471184487854, 0.02078455899442945, 0.07442479460899319, 0.046178511543465514, 0.02484504146767514, 0.013933851466780263, 0.06837463032986436, 0.04913416597992182, 0.042907131370157, 0.048788085979010375, 0.016539744001680186, 0.13444638065993786, 0.03619242346446429, 0.04022532348920192, 0.04050770262256265, 0.02131543291865715, 0.05433670092107994, 0.032474825092192204, 0.0524827193335763, 0.0279613187137459, 0.03035882381456239, 0.0304719763142722, 0.016720707594816173, 0.03266920841165951, 0.05588420181136046, 0.01682571428162711, 0.09174001762377364, 0.056704523507505655, 0.014245116684053625, 0.04591030361396926, 0.018614746497145722, 0.03851174097508192, 0.01577367796562612, 0.036132759880274534, 0.05176859176052468, 0.00946252282509314, 0.04599647756133761, 0.0751099114173225, 0.008302657116603638, 0.018166887939774563, 0.03735385489250932, 0.015007515238331897, 0.04559034042592559, 0.0390991249920002, 0.030383067870778695, 0.011518072569742799, 0.038999773894569705, 0.07811261886464697, 0.03282614338344761, 0.020058972661250403, 0.03838330786675215, 0.08477539170001235, 0.056332167237997055, 0.04556313795702798, 0.04587446678695934, 0.04224624504734363, 0.02981530369392463, 0.06097120259489332, 0.011971142276057174, 0.036881533451378345, 0.0003090372634427954, 0.023953683940427642, 0.04956606708999191, 0.0304193627089262, 0.019477960088157227, 0.03370531442176018, 0.05311063563983355, 0.022174882336652706, 0.01970128801518253, 0.00804088169908417, 0.03819133673927613, 0.035227865579405, 0.054843474977782795, 0.016475108452141285, 0.025312316304604923, 0.04087130918300577, 0.008012323008318032, 0.0184302850559886, 0.08861159120819398, 0.1049522343756897, 0.07811173676912274, 0.020976217995796884, 0.06947412847408227, 0.03932959958910942, 0.028973604752016918, 0.019879320337037956, 0.03841507348365017, 0.02749004221654364, 0.057379974584494314, 0.02116819590862308, 0.013728641272921647, 0.02636954002082348, 0.05698723851570061, 0.03340967671413507, 0.018938236370948807, 0.03352491570902722, 0.018239542076896344, 0.018007764692551324, 0.020550556015223265, 0.029056497982570102, 0.07548113792602505, 0.05968314635434321, 0.06374278744416577, 0.0662822929610099, 0.047883934673986266, 0.04775355077747788, 0.06821417036865439, 0.03644765780440398, 0.03216568114502089, 0.11302625826959099, 0.15416063208665165, 0.08546837951455798, 0.17641100314046654, 0.12098732643893786, 0.12609033047088555, 0.06621624436229467, 0.08652188655521188, 0.08371924515813589, 0.2154206463268825, 0.13597853987344674, 0.1530770252325705, 0.181482998122062, 0.1299262653504099, 0.07954016833433084, 0.1460151991673878, 0.14660336689225265, 0.09098665376326867, 0.1652283389121294, 0.19650906111512864, 0.1546388364263943, 0.14524537404733046, 0.2788778112402984, 0.12513284970607075, 0.07711518595793418, 0.18517462217382022, 0.12354771047830582, 0.09692804209355797, 0.12357652107519762, 0.1159613768437079, 0.13192267822367804, 0.1790417241198676, 0.11345270395811115, 0.1867422823395048, 0.1574255254651819, 0.10602018742689065, 0.1695514347936426, 0.21113351280135767, 0.20331141538918018, 0.2546621449291706, 0.11301529992903982, 0.17893566909645284, 0.251847255975008, 0.14091018667178495, 0.16426093796534197, 0.11538709194532462, 0.13260708935558796, 0.1730735200856413, 0.1426827237010002, 0.1552438996732235, 0.10995444881596736, 0.11380720457860402, 0.1688216296689851, 0.10706270220024244, 0.0982745744820152, 0.11394698279244558, 0.1130560730983104, 0.07759026225124087, 0.07595898942755801, 0.09431429806032351, 0.1733941821647542, 0.11112001591495105, 0.1131461893341371, 0.07259383571467229, 0.14854967673974379, 0.27526653930544853, 0.08819335579339947, 0.09427517373114824, 0.16911760664411954, 0.18034019587295397, 0.10460344023470368, 0.08329986980451004, 0.07353844467018332, 0.15523426447595867, 0.1276790387928486, 0.12658499607018062, 0.19039950466581754, 0.12830823074494088, 0.2109333449708564, 0.1286564413458109, 0.15167293271848134, 0.10884655040821858, 0.10999541197504316, 0.11937401443719864, 0.10468882708145039, 0.232397266796657, 0.12999190682811396, 0.18131377148841107, 0.1285233941993543, 0.14864784718624183, 0.19236106798052788, 0.18954346488629067, 0.096721591028784, 0.21422426695270197, 0.14894553406962327, 0.16360745445958205, 0.14840521663427353, 0.13403175505144255, 0.19091740330415113, 0.12010049474026475, 0.09083719964006118, 0.13786250592342444, 0.07291114583079304, 0.12448512017726898, 0.14001219985740526, 0.14074022722031387, 0.11944804260773317, 0.12465915083885193, 0.17721932833748205, 0.13980150116341455, 0.16855909089956964, 0.09270237027002232, 0.1385741670216833, 0.20161986829979078, 0.1444371845573187, 0.11730153778834002, 0.07719320391437837, 0.06197319525693144, 0.2799120071743216, 0.14972027178321565, 0.0798279961038913, 0.18949952295848302, 0.14023338870278426, 0.1415996461042336, 0.08856397162058524, 0.08633845818362065, 0.16342920331018312, 0.05459322787023016, 0.17976155477975095, 0.19920691634927476, 0.1599927627082382, 0.03950369810419423, 0.22830298649413244, 0.09199226980230638, 0.13213581964373589, 0.13902326220912592, 0.1276376210153103, 0.12215987566326346, 0.11410057597926684, 0.16545439963894232, 0.1042918705248407, 0.11704115676028387, 0.14169647305139474, 0.07893975983772959, 0.145617401227355, 0.17501438808228287, 0.24798962154558726, 0.15144584061844008, 0.06155846108283315, 0.1254699866154364, 0.1477924045175314, 0.13041603192687035, 0.11395143398216792, 0.13154831688318933, 0.11078946079526629, 0.13271933261837277, 0.1168135218322277, 0.1341854025210653, 0.09595432398574692, 0.18679752866072313, 0.07826428501201527, 0.15734192995088442, 0.10446449661893503, 0.13420620640473707, 0.0825648196041584, 0.14382900004940374, 0.08695663072701011, 0.2119240875222853, 0.12287478015891143, 0.10812133218028716, 0.22772938013076782, 0.10875743840421949, 0.07949608391416924, 0.12116404409919466, 0.16498764897031443, 0.09397160394915513], [0.044022032259298224, 0.0584194902330637, 0.004938848175308002, 0.05107355137754764, 0.04553274976621781, 0.02812250640376338, 0.02139245342862393, 0.010574634087138941, 0.016523784858041575, 0.0268621225176113, 0.027463572565466166, 0.04214222562898483, 0.015232987336016126, 0.03858537898798074, 0.06466276557849986, 0.06894202809780836, 0.009696503751911223, 0.05102771972971303, 0.04030197759025863, 0.05846033125583615, 0.036434494225042205, 0.032777014055422375, 0.02928137466577547, 0.0229656589217484, 0.04434442460270865, 0.028723042125680616, 0.05666367569938302, 0.052866997463362556, 0.07146875001490116, 0.06578105914273433, 0.04292135007147278, 0.08540984908384935, 0.08337016603244202, 0.09543173667043447, 0.021315529609897306, 0.15047732687422208, 0.020412139960431626, 0.023770075757056475, 0.024672832672617266, 0.006975232698355934, 0.019240795135764138, 0.09428999972130571, 0.019407867420730845, 0.03628255666366645, 0.009941393825491624, 0.04417542527828898, 0.026889983165477003, 0.02406356929402266, 0.03980774625337549, 0.045937224490834136, 0.039499392799500904, 0.036690916001264534, 0.04556347383186221, 0.02212803458262767, 0.047646060652498684, 0.032685086131095886, 0.06557966316384928, 0.017073969888900007, 0.04089227591508201, 0.012916818227885025, 0.06300362532160111, 0.06928533967584372, 0.036418334913573096, 0.04777682452861752, 0.029284373790557896, 0.028181386280006597, 0.040177045722625086, 0.024160012868898254, 0.04889645141416362, 0.02365370700135827, 0.025564634640301977, 0.0290261776452618, 0.03474404975505812, 0.03915431363774197, 0.025424283064369644, 0.035538739790873866, 0.005431463326593595, 0.014342077641880937, 0.02616546213227723, 0.021684513560363224, 0.02621365338563919, 0.010216770477459898, 0.038745448791555, 0.020513034725029553, 0.024951379779460173, 0.07126031762787274, 0.048984426872006485, 0.027892803640237877, 0.03675954981840082, 0.09396160234298025, 0.0150465462689421, 0.0933308769017458, 0.029659817394401346, 0.02500525037092822, 0.027568155167890445, 0.03780801873654127, 0.03953295314152326, 0.06209815426596573, 0.030285433466945375, 0.048263921069779565, 0.026882531154634695, 0.06605554691382817, 0.06096602537270103, 0.0496981066119458, 0.0008094770102096455, 0.05079874469499503, 0.054406776625130854, 0.030190516595861742, 0.0196830031927675, 0.036986909939774444, 0.07901145384779998, 0.02884303086570331, 0.00898226082790643, 0.049204872721540074, 0.028612166110958372, 0.005618744080753199, 0.02528749210094767, 0.049186687983040295, 0.05012598400935531, 0.0621233211298074, 0.024403895317975963, 0.02473252679088286, 0.034095434738057, 0.036891725047358444, 0.05060080585203, 0.08149252392883811, 0.06377190338181597, 0.036475993426782746, 0.04173310972484095, 0.08016345024641071, 0.029035266621836593, 0.043291687699300904, 0.027501758819978152, 0.03677621124578374, 0.03803031698667577, 0.0560914705108319, 0.02469483925960958, 0.025731445689286505, 0.17655889663313115, 0.04502484594870891, 0.01031304441858083, 0.042074606221701415, 0.03385175584948488, 0.04628221205036555, 0.007921218655870428, 0.07311165292880364, 0.04857893095218709, 0.039285793368305476, 0.02180348619419549, 0.05629442712025983, 0.076733930701656, 0.048005847060786824, 0.035238158955637894, 0.029527157012905394, 0.01980538716140602, 0.027416064936135496, 0.021252434334850738, 0.07443675039602177, 0.039838938508182764, 0.0543648329829531, 0.011888449213334491, 0.038155242068959136, 0.026464680808463266, 0.07489104316170726, 0.025973971068326916, 0.08246440320674862, 0.0368691060825118, 0.02972900082490274, 0.04471593609611903, 0.042702040768095424, 0.027274536101945808, 0.032790764567575285, 0.02737117645197681, 0.04054403817281127, 0.05099416956571596, 0.017056616355798075, 0.04377463499882391, 0.02274293658722724, 0.013327815370368106, 0.026975400546299558, 0.07740456757268735, 0.014784594432317784, 0.038549891606505425, 0.008970489093501652, 0.02108057159265237, 0.020931682349847894, 0.011346991839153426, 0.05010969238355756, 0.03669306695727365, 0.0353836470416614, 0.03714953442769391, 0.04984231226678405, 0.10815306047775916, 0.0375487064011395, 0.0020097210654057562, 0.033859341870993376, 0.018977647381169454, 0.04787060824622001, 0.019415261756096567, 0.08556828022535358, 0.06953177002391644, 0.05778427289000579, 0.011806734089207436, 0.019034583254584243, 0.031862267426082065, 0.036750749219208956, 0.042760934215039015, 0.025773960997217467, 0.021675684123433063, 0.03320916961612446, 0.009646739145474774, 0.02592435319508825, 0.01978939239467893, 0.01118219010199287, 0.04340821930340358, 0.00871091297761138, 0.027306581614539027, 0.03711117684308972, 0.03658682194405368, 0.018352487623425465, 0.0320175298090492, 0.025660793230469738, 0.040560641924717596, 0.031200756851051534, 0.07605817089123385, 0.03746516177696841, 0.037939674886209626, 0.024919721031827585, 0.0690286091661879, 0.04824516975453921, 0.025974323906536614, 0.008393868338316679, 0.033184090961835215, 0.04949528910219669, 0.023127601481974125, 0.027861840390999402, 0.061691175747130594, 0.024952127864318233, 0.02033151812585337, 0.040538993264947615, 0.02596686002133148, 0.050317283387162855, 0.0432828022832317, 0.02098939344952149, 0.053094873271350346, 0.0326458227022418, 0.055224865941064696, 0.057149347317005904, 0.03517178466011371, 0.03603426034429243, 0.012753829875561808, 0.017214701444442784, 0.07186903817845242, 0.028000660174127136, 0.023045134032145143, 0.04040854490761246, 0.06203245850546019, 0.0657487880172474, 0.05974056398762124, 0.01958719065545925, 0.055372504983097315, 0.01489807602151164, 0.07083579897880554, 0.04279890503468258, 0.004343151680326888, 0.014850922926728214, 0.03375803320003407, 0.02562444580585829, 0.0629241620855672, 0.03333552979997226, 0.006305243404183004, 0.062143656824316294, 0.04375619920236724, 0.01447762518988124, 0.0764870321644204, 0.0555511361121067, 0.05505375637273703, 0.034867044405213425, 0.04303783078544906, 0.02357012336142361, 0.019766486748786907, 0.039660409159426174, 0.059287757213626585, 0.058071428909897804, 0.04971444234251976, 0.03516774737675275, 0.028606381599924395, 0.05376128626189061, 0.03634786226653627, 0.0592015493395073, 0.008878791022912731, 0.03676059136965445, 0.03222593166200178, 0.07267044910362788, 0.017128094931000044, 0.01957682433671185, 0.03216721463416304, 0.036145631689578295, 0.024949691923601285, 0.01895417346219931, 0.04428039125299879, 0.03428507170506886, 0.03170185835499849, 0.055967851608459435, 0.05018961363072906, 0.08472537009843759, 0.05974287100668464, 0.04300276070301022, 0.0386803840686168, 0.010193504359839218, 0.03921903570049575, 0.040225927385368516, 0.09301501885056496, 0.019647978911442415, 0.031926640043301244, 0.050876172325972996, 0.03466525826869266, 0.027943379944190383, 0.05722243232386453, 0.038601300812193325, 0.02677238286871995, 0.04968086503712194, 0.041447358272437534, 0.01276761940347829, 0.007799519159431968, 0.043704450729170015, 0.047020651533135345, 0.011437510955147445, 0.09780249052814075, 0.02655754511111549, 0.04539844732997673, 0.017297569229932766, 0.019108899802501713, 0.0017275465527615908, 0.03127313618149076, 0.04750533927498119, 0.07244315344308104, 0.1264629547617265, 0.027003140754199455, 0.017658629587718418, 0.018890630354040434, 0.029843479860574007, 0.03209744766354561, 0.03931711454476629, 0.017105146876669357, 0.03641478617542556, 0.04928602890244552, 0.014370338625407644, 0.07325498666614294, 0.03296503610908985, 0.040229835747075934, 0.023220175710905875, 0.1775735236172165, 0.11585742527885096, 0.1430004680795329, 0.07858063839375973, 0.11447941565087863, 0.13061291564788136, 0.08153381957007305, 0.14658657993589128, 0.08732332462178809, 0.10235858854970761, 0.11521933094731399, 0.13054108593080724, 0.10201738043023006, 0.16393292056662695, 0.16196184419095516, 0.13738447800278664, 0.18523775307195528, 0.12442530053002493, 0.134076307660767, 0.12379822560719081, 0.10126032533922366, 0.14374479385358946, 0.09716712390737874, 0.16069497859903745, 0.150602163746953, 0.1302266392324652, 0.1322365685233048, 0.08563693439854042, 0.1394024547189474, 0.17256052047014236, 0.08078156850699868, 0.10261618079883711, 0.19380520763141768, 0.12103859654494695, 0.07670723034867219, 0.19178533101720469, 0.1397389266639948, 0.11238211819103786, 0.11261123232543468, 0.06122961587139538, 0.146219546773604, 0.2295026635485036, 0.10831803948219333, 0.08793046418577433, 0.1033066783898643, 0.10986911625202213, 0.11153567968202488, 0.11524236042584692, 0.2171967795916966, 0.16886534089488642, 0.14408632766987595, 0.149776535906962, 0.1532735289739711, 0.17759605097983563, 0.06652997859886714, 0.18355672327535494, 0.1319472547620535, 0.08180589175650052, 0.08540306373366288, 0.22661027232451098, 0.2157651792679514, 0.1674057442162718, 0.14791964340422833, 0.09629036166838237, 0.11110396177640983, 0.1294635451797928, 0.11168921180069447, 0.0743361304381064, 0.14357898703643254, 0.08620091913534061, 0.17257216413106236, 0.16217043942638806, 0.13100875940706047, 0.11006188126546995, 0.08048739643501383, 0.08113640839500086, 0.12037678062915802, 0.12877317651041917, 0.11366528219410352, 0.12294536137155124, 0.1318600901535579, 0.10422887533370938, 0.15878688384379658, 0.10188349868570055, 0.08773853377039943, 0.21077862541590417, 0.180956970634205, 0.0993946525933487, 0.16662519824291977, 0.21809039664055618, 0.09935613894569022, 0.1788192324872528, 0.1418153252452612, 0.08363022136368922, 0.0996994369530252, 0.21781959331461362, 0.10448586368667227, 0.144133702984878, 0.1859753206372261, 0.26175400295427864, 0.13734905847481318, 0.10814263139452253, 0.22418798373213836, 0.08987064007669687, 0.10094164458236524, 0.1326804661325046, 0.13916331183697495, 0.18011965842119285, 0.21562819661838667, 0.10852492480937924, 0.2212319459233965, 0.14170447976461478, 0.0748341954978449, 0.19413486708487782, 0.15673168269651278, 0.08606610101248537, 0.16726460893239292, 0.1229902125362839, 0.12898753929351056, 0.15209677283252987, 0.12373905735356466, 0.10287684681160109, 0.10433763771184854, 0.10201918533337967, 0.13250609620341233, 0.12782781438103744, 0.1704204888748271, 0.10248490462877921, 0.12089098803699017, 0.19718824752739497, 0.150202248777662, 0.20421111211180687, 0.22059801779687405, 0.08304096119744436, 0.06549462915531226, 0.27802228714738575, 0.24262004824621336, 0.09378457934196506, 0.24055648754749978, 0.1073748893769724, 0.14019961122955593, 0.1532040334173611, 0.12965285644999572, 0.0914297846278974, 0.16942319167511805, 0.19942415612084524, 0.16032311426741735, 0.13505052109914167, 0.07307285429643733, 0.13912616883005413, 0.1449070293456316, 0.1009921682998538, 0.18993312040609972, 0.0758641641587019, 0.14548915810883045, 0.13627257623842784, 0.06307257805019617, 0.15120456713650907, 0.12593113258481026, 0.11078986791627747, 0.19064198594008172, 0.2018542071538312, 0.1767609915030854, 0.19638796975570066, 0.14530576366399015, 0.14483651598649366, 0.11762509042663233, 0.08991607478154556, 0.10040120501071215, 0.2115600806261812, 0.11551419512501784, 0.0697631776066763, 0.1594454020793949, 0.19494707350219997, 0.19791137586746896, 0.11831980172012534], [0.04612242044614894, 0.045826300978660583, 0.023353714795250977, 0.0051094492664560676, 0.08773668136979852, 0.06643568258732557, 0.014573890649314438, 0.047512867621013095, 0.05434645825464811, 0.004584069355457489, 0.0308071319013834, 0.03721320476116879, 0.059741642858300886, 0.03481885824086411, 0.05437203563217606, 0.026831103289233785, 0.05355127288826874, 0.06214968900063208, 0.023203990954373564, 0.03460684997428741, 0.03913545036422355, 0.0627503078430891, 0.018022197132397975, 0.04899574483611754, 0.054795078467577696, 0.041749849183751006, 0.04770814660670502, 0.02678813675551542, 0.026778727171144316, 0.024151197002668465, 0.024766903071265136, 0.05886970500328711, 0.09144695834921938, 0.018931717345757142, 0.027238422771915793, 0.04088172469554203, 0.031920672327812226, 0.050473414294953854, 0.01656787097454071, 0.06105316283979586, 0.04044759459793568, 0.07105006676699434, 0.044123279862105846, 0.027142966465492333, 0.06433537243200199, 0.04764351275350366, 0.0029382235079538077, 0.062213179522327015, 0.03379740858716624, 0.014728812068434698, 0.06802854354360274, 0.0626855416755591, 0.04345540462860039, 0.05131209036335349, 0.011157218316969062, 0.012576621125585266, 0.011191493665267314, 0.03348914673551917, 0.06007519710276808, 0.02709751988628081, 0.04975063540041447, 0.023197517730295658, 0.07977952834750925, 0.05521781596222094, 0.053272316964077096, 0.0359041512544666, 0.02767927206254431, 0.03248341873820339, 0.033541180193424225, 0.04887834809986608, 0.018240614162225808, 0.009378453184451376, 0.01968575295593057, 0.09235057021890368, 0.0920075707669769, 0.04319770381386791, 0.009975532618617373, 0.09555294338081564, 0.027881919938538755, 0.08066999020853213, 0.07716456295124122, 0.012667223362119069, 0.005127470732466983, 0.03956872211503131, 0.04107965336048177, 0.05869707212384258, 0.030575853240277086, 0.03007697393851621, 0.016674955674846257, 0.08304358712796654, 0.06569755862333945, 0.03794667397492698, 0.05527929123491049, 0.08754322425063167, 0.0438586308487824, 0.07431036646344832, 0.04654722407992397, 0.04075551378939833, 0.030147901204015528, 0.008883938559197953, 0.03970582350822432, 0.024994181768436517, 0.03409340252567615, 0.08503363534275975, 0.009464946891447263, 0.04266961018687912, 0.03927227355805891, 0.012682056985795498, 0.028531165993107215, 0.019729679616700326, 0.04429679822974971, 0.05294446919911674, 0.056469682537551434, 0.005291086729682449, 0.025813316028299074, 0.05304749117099813, 0.021923946516056145, 0.08917558951569454, 0.012037628529859441, 0.028778831274913888, 0.02447687684824424, 0.029016688333026, 0.04561179231054016, 0.005574169843125024, 0.03791925098214831, 0.011187952560638743, 0.023339638586289117, 0.07350829057395458, 0.014960173850080796, 0.021096274589321444, 0.020168791857681105, 0.020269006390922835, 0.05698611893291984, 0.014771203543724758, 0.05126100346179945, 0.012969227424556655, 0.009355718020482786, 0.05784618242510727, 0.0338136459301625, 0.016157459068511213, 0.015524904975401503, 0.03570753216211285, 0.04175670578011444, 0.0376977567960109, 0.04219014037932668, 0.0391812616560076, 0.06560617352702788, 0.08419032488018274, 0.030272565050316707, 0.03625188009547336, 0.001021939789227742, 0.015320767715041126, 0.015483884140849113, 0.022897500079125166, 0.03638177205409322, 0.02306776656769216, 0.06481854364808116, 0.028730366911206926, 0.06524773061807666, 0.06021840191845383, 0.055349475504564385, 0.038584798840539794, 0.01799478940665722, 0.08172091203076498, 0.03352459001221827, 0.04040745246623244, 0.02743271109648049, 0.009848356496409645, 0.052738398113953214, 0.05709052511623927, 0.03140917227470449, 0.01652159827894398, 0.023636928526684642, 0.07573480824274675, 0.01927655393124691, 0.043214629869908094, 0.01216784872979458, 0.015144017824370946, 0.010190104051227016, 0.02787257481499442, 0.05350466092516269, 0.017533244797959924, 0.04994598902495844, 0.06015712342091969, 0.030390891379543712, 0.035897342155554464, 0.02552618206079517, 0.019444686427180256, 0.029132178385875056, 0.03198094320084367, 0.026850302437586442, 0.026205458378951465, 0.09408348758838006, 0.04087123454415372, 0.06610174157789775, 0.046962019322173934, 0.068703543394804, 0.010304424479337675, 0.03795844655750053, 0.007853925793564745, 0.05752214802695172, 0.07179240443344627, 0.02239032568676131, 0.0613089773271765, 0.0060246797760815495, 0.015405050246044993, 0.03696536984560745, 0.06007217762193509, 0.06327229126223496, 0.04734003118106297, 0.029217242928487912, 0.03421005287340709, 0.02481982371370707, 0.03456331856016602, 0.031517558065908294, 0.06530819487358842, 0.07544372350509677, 0.0836436834984592, 0.03266631106712988, 0.04176863442574229, 0.05014959363532918, 0.04169823641755751, 0.05950965852077518, 0.04608088731765747, 0.04619355466482895, 0.01213202886616013, 0.02345406842817153, 0.0161956453230232, 0.03253587967317019, 0.020553036060716425, 0.016705562693199942, 0.046562765924526114, 0.021638614059026753, 0.033550649149609466, 0.027440612636772648, 0.06180235370993614, 0.015252105060166546, 0.04693093902564474, 0.07293053157627583, 0.03683473489114216, 0.0776651453758989, 0.010527789725789001, 0.04738823091611266, 0.028771601484290192, 0.05105813506192394, 0.03011308896488377, 0.0203476163691708, 0.03863797562995127, 0.021975284475567083, 0.04583890815930707, 0.061887536996177266, 0.026152427474568998, 0.05108189057292683, 0.05193576243306909, 0.03169927992192762, 0.0715556296386889, 0.015053757399852787, 0.00873060236751501, 0.054403207530932765, 0.015187364337699754, 0.004686791499677513, 0.023230774427897165, 0.022906902878146087, 0.025988476450688074, 0.06051127798855305, 0.04594609294352787, 0.05690261162817478, 0.034176322897630076, 0.03539281065708824, 0.02778141193890146, 0.03739800377349768, 0.0278050860257021, 0.016051012191123197, 0.03869188862985798, 0.030011128900306563, 0.08715557719447783, 0.026683947703401958, 0.019382115320435593, 0.05453182723639267, 0.0614933760038444, 0.015416179916688373, 0.03446128046406167, 0.010898876286643957, 0.04371536835762007, 0.018048244395426342, 0.08396450842597655, 0.023356576516692127, 0.01190514796014343, 0.07580855821392365, 0.03814789014203208, 0.04366368095257452, 0.02420707605779171, 0.019560753234795163, 0.039197288653148074, 0.03851731514026012, 0.046634246196065626, 0.018618441120322262, 0.08023209084889718, 0.0153792676116739, 0.0382823723900531, 0.011437244630152625, 0.0069909679254383916, 0.02782881269896669, 0.03466305981523224, 0.0778023519420198, 0.07443473514701639, 0.051933672545211654, 0.014439226893175925, 0.04792972221704466, 0.022732090204954147, 0.020156786876863668, 0.021031355751412253, 0.028572027371930223, 0.008603985188528895, 0.04971014043050153, 0.01899918238632381, 0.03550806661535587, 0.036003882331507545, 0.016045499094096676, 0.016808901880202547, 0.048738512210547924, 0.04980556620284915, 0.05965926870703697, 0.05852946040353604, 0.049228597698467116, 0.02769052895850369, 0.03147556692627924, 0.05602252456758704, 0.02334401004814676, 0.032278884534857104, 0.045615809237850566, 0.027442627885778035, 0.020850882399827242, 0.02478586133968617, 0.039919830060430934, 0.011069664399006536, 0.030915466802460805, 0.027351831418595145, 0.020425154262089303, 0.06530090062213795, 0.03591743018478155, 0.02911439398303628, 0.006973418465349823, 0.004795689160736012, 0.019043356712375368, 0.04686884967876332, 0.036913109078471146, 0.03146717684077365, 0.004036594647914171, 0.03983752036999379, 0.06368053185620479, 0.060058661204363616, 0.09739059941577059, 0.10802941104131085, 0.10169299319386482, 0.13835540733167104, 0.24151178342955454, 0.14710560494235583, 0.125107024663261, 0.16122291955564702, 0.13630438596010208, 0.09229828909571682, 0.09901806565799884, 0.12361078709363937, 0.13883222745997564, 0.14296795268143925, 0.10947646839278084, 0.14821323193609715, 0.18367518191891058, 0.1975369873855795, 0.19802021288446017, 0.13157084424580845, 0.19976532352822168, 0.13413391528385027, 0.10875235617692981, 0.12109737124826227, 0.14096811999167713, 0.1377996735806976, 0.09014413718666349, 0.21450330769377096, 0.08351367618888617, 0.17081635977540696, 0.07466590524251972, 0.2071046975574323, 0.1282328319336687, 0.15986028553119727, 0.16953759267926216, 0.11073645363960948, 0.09947311159755502, 0.15349425641553743, 0.10250477213412523, 0.15672457164951734, 0.19981512799859047, 0.13952217543763773, 0.16989630700222083, 0.09017311741730996, 0.10112618575138704, 0.10797769310218946, 0.12895486104701245, 0.14515860298914568, 0.15678140574267932, 0.11070093233138323, 0.2510126850434712, 0.17598814011684485, 0.12786787508853845, 0.16949682629534177, 0.06393962366772549, 0.14305768215230533, 0.1471559250993388, 0.13358120779906, 0.11760653927922249, 0.14907068306846277, 0.09816644992679358, 0.13560442280556473, 0.16662297264805861, 0.09957353478031498, 0.19053772224911622, 0.10852970169591052, 0.1173115393945149, 0.06291757351053612, 0.13755005411803722, 0.14255700473274502, 0.09521009999194316, 0.1405813278896468, 0.12310782979641642, 0.18678992906851427, 0.23502129742077418, 0.12858242674597672, 0.14186769457800047, 0.18973097125334398, 0.0838484110842858, 0.15347239401723656, 0.13267206586897373, 0.08543344174644776, 0.18301837359155926, 0.12303723501307623, 0.1448111930595977, 0.11222835537046194, 0.15129861209009374, 0.1494111990822213, 0.09361375136567013, 0.11831619191382613, 0.1534247880003282, 0.17398502331759247, 0.12044976385576384, 0.18255505631012575, 0.08891665376722813, 0.18842898468886102, 0.1505148091486522, 0.11258810106664896, 0.1310539905514036, 0.1926104160291808, 0.15081850785229886, 0.09939081887049334, 0.12262263654598168, 0.26649243012070656, 0.08059090016675846, 0.12487837193267685, 0.13301578456802027, 0.11610441202563898, 0.14878244139254093, 0.1773325486906937, 0.15627122883285793, 0.10201278674815382, 0.2110665278243167, 0.08842143176921777, 0.08537265179412705, 0.14127027163548128, 0.11745887648846422, 0.14842075508620056, 0.08365308799381767, 0.1735359417008502, 0.11217178590595722, 0.16645910644105502, 0.11554939752178532, 0.08451551957322018, 0.1023380153679422, 0.11354704068175384, 0.1002876725313919, 0.125461857765913, 0.1192748804709741, 0.14265931424285683, 0.15972389999244893, 0.048821703996509314, 0.1683129591069051, 0.1550036304231201, 0.14082026721111365, 0.10673180781304836, 0.12098875136247703, 0.16338466427155904, 0.10666204084243093, 0.1242256076740367, 0.10049968758331877, 0.1244003711534398, 0.17214073799550533, 0.06758424559874193, 0.10992009458797318, 0.1071441060464297, 0.13996202897812637, 0.15058849805167743, 0.140180802238839, 0.11822752095758915, 0.07690310983785562, 0.07425699289888144, 0.10383849378143038, 0.09535483151142086, 0.10524608753621578, 0.12456453591585159, 0.18886528270585196, 0.10150652498539005, 0.09866264222988061, 0.09798897230731589, 0.1431453488767147, 0.1081483175179788, 0.084526355777468, 0.18198225061808312, 0.10610783379524946, 0.14306008416627133, 0.09447000149105277, 0.13444609567523003, 0.15454544286642755, 0.1658977544201272, 0.12897111874605927, 0.11753575450607709, 0.13062913263482706, 0.14609897110079015, 0.10334467635090862, 0.13341770800096647], [0.031450325423585515, 0.0702204762824944, 0.014725326094776392, 0.03342297600050058, 0.024494932665090476, 0.021222965558990836, 0.01689256864067699, 0.048529326649648805, 0.038647546366389306, 0.058975230769387314, 0.012199478639688874, 0.025687954987266233, 0.06516812488968883, 0.014522398323086756, 0.013554800601143922, 0.018023004589070166, 0.04135205463639327, 0.04039847205526062, 0.02689326897130481, 0.07116338211510863, 0.016920765163376927, 0.029165070370904038, 0.03004432622609394, 0.036101930641702244, 0.016620974821437682, 0.05431381393490093, 0.04938782611861825, 0.01647307793609798, 0.031294679668332846, 0.036498941481113434, 0.031912034577024836, 0.0243170258722135, 0.07870147869523082, 0.01405386989271002, 0.07193680347076484, 0.016269118791179996, 0.09469425731471606, 0.016456489451229572, 0.03873465669208339, 0.04301619230370436, 0.007375071756541729, 0.03932568444205182, 0.018503923068887422, 0.03740540659055114, 0.028001116488927176, 0.03472422296181321, 0.010454467231673854, 0.016747777749385153, 0.012739245613504733, 0.02296439345393862, 0.03280005371198058, 0.06326237108026232, 0.03628139297610947, 0.06484406335013253, 0.0912499049944537, 0.026386386348998973, 0.006322980309570474, 0.04634434550202318, 0.0641577523201704, 0.06676354392298631, 0.020776253725801195, 0.026968910358846188, 0.017522539211703197, 0.033803349161254506, 0.01999127522243985, 0.018116457520851066, 0.043077270633408, 0.04330836269738419, 0.045858891015606265, 0.040143465024552176, 0.06313809060624667, 0.02115375329075115, 0.023417393610413586, 0.010339531033033771, 0.036539762147835324, 0.009510869293340614, 0.04875508542837841, 0.06416306524936642, 0.060821368492075374, 0.024879441496783068, 0.019333771396694437, 0.05402575207075902, 0.028709247508751493, 0.11446579066770417, 0.03752593815858875, 0.07283602521887847, 0.03485221841505595, 0.06700081404830728, 0.10629899746605329, 0.033347142926816425, 0.026461741055494974, 0.03594821871125272, 0.023216859371002232, 0.08287816029042006, 0.036073907145432065, 0.009650030888483992, 0.02746106537857226, 0.08638727199286222, 0.050293789112142155, 0.06470247344779116, 0.02882399456575513, 0.048724819373871596, 0.05367410808269467, 0.03094681172764727, 0.006310477877767491, 0.030615211664033786, 0.023860765354973928, 0.01849556521379522, 0.058800840484244485, 0.03751796537211963, 0.10540139063128404, 0.049026777635195425, 0.050928063291524134, 0.01824584397088204, 0.0492515491454729, 0.05003953186262931, 0.04004918597638607, 0.04666989981862051, 0.013892420118541589, 0.0025642279402485913, 0.039601987294320545, 0.01530819446114557, 0.05257989911894713, 0.04048411674531443, 0.02360483382030257, 0.08409953010933739, 0.03060493864385145, 0.04821813352672117, 0.03000897794429745, 0.05710290838032961, 0.04866573932979788, 0.0481666123627552, 0.003706185413258416, 0.031884170536484034, 0.004059253476693162, 0.037816218832241635, 0.02467528896938477, 0.02995949238538742, 0.03204847100589957, 0.0377163825822728, 0.031786410603672266, 0.027416714633415853, 0.034828557898955684, 0.006056645984894463, 0.02217548114380666, 0.05408822139725089, 0.034061022834586244, 0.05100045619266374, 0.022395720040159564, 0.009526325472896653, 0.06156990796859775, 0.03651215595060161, 0.013875458439412926, 0.026779911214751855, 0.0942547091149858, 0.07978677510150842, 0.023830650274508765, 0.09151237591036729, 0.020880631071382334, 0.017358008040381328, 0.011620617870773588, 0.047905254244272194, 0.036756001080253294, 0.02036249833846731, 0.025138641873906766, 0.0024369016921679887, 0.07076662233365433, 0.04682866344228387, 0.07745883680347886, 0.017602273861744573, 0.050124413200787137, 0.04314635567633169, 0.0372643018407481, 0.0442678383551538, 0.030752106104046106, 0.04540059489331075, 0.05590115840147648, 0.009075148879284305, 0.032584418675729206, 0.025917511865762726, 0.006802185064381254, 0.03144468340490546, 0.013710509969054588, 0.02905720705166459, 0.020471661052267467, 0.07924959928329502, 0.04892614749925477, 0.023640467086806893, 0.003500245158128174, 0.023364410203482424, 0.05353988028530564, 0.04086760777447905, 0.050842255753065856, 0.0184166549838015, 0.00547253293085045, 0.03510909480974078, 0.030402772527720247, 0.03722194768488407, 0.0203053724752473, 0.06030260132891791, 0.06851364858448505, 0.08120632464332239, 0.04224653003205146, 0.04558000294491649, 0.041024532568241866, 0.006817433442587831, 0.02794652495400182, 0.042980711707579236, 0.040694343857467175, 0.04642727944467749, 0.08003691703613315, 0.04520013529275145, 0.05079566075333527, 0.004277154395822436, 0.04114290978759527, 0.02052801677824131, 0.027278035646304488, 0.06596028738256011, 0.003093941357552207, 0.051135108074439425, 0.02074487317752625, 0.041409194070313654, 0.03627612075901457, 0.03678313908832414, 0.01637978106737137, 0.054724870449198146, 0.017101521803332225, 0.04272289554189358, 0.03003776479246361, 0.03517319940562759, 0.12154502794146538, 0.013423763614680086, 0.006410640248629663, 0.018322637171617577, 0.06863590702414513, 0.05406023522040673, 0.03393588062109692, 0.03958123769345028, 0.08514365979603358, 0.05323694493355496, 0.07345912392650332, 0.02507830654004855, 0.05626232562852757, 0.013110880091387247, 0.03323520839746509, 0.01568863886807646, 0.03828423496867929, 0.009944295410865119, 0.02550149865315429, 0.01134781795553863, 0.032696807823543034, 0.044054452662489245, 0.036119179001876285, 0.04359675365101014, 0.05195012362673879, 0.036677433510443995, 0.023008077538439205, 0.02244524970384581, 0.0510891339342509, 0.04185098822095564, 0.04439615950520549, 0.038690646910773854, 0.011151449921141778, 0.023146858305803368, 0.08844684290566615, 0.03091634889798505, 0.016477247533787574, 0.03574286348053387, 0.05762837268412113, 0.03395260311663151, 0.09150438955319778, 0.027668281491579752, 0.03748318027438862, 0.047028977157814164, 0.02764502809649067, 0.02862779955778803, 0.01684294907110078, 0.045947002180452855, 0.0025978188163467814, 0.08492078818380833, 0.046825477720371315, 0.030943249418799366, 0.031763452371316295, 0.03998135283057179, 0.05365271048088159, 0.06620219868740865, 0.03392076964623161, 0.029081759841314385, 0.04178898369095155, 0.015124942508659192, 0.015888033168656484, 0.03303096257150173, 0.08261640862162624, 0.006484804550252322, 0.051907952675329785, 0.009188078310606735, 0.07950548162417752, 0.07558204965399844, 0.04219146352261305, 0.04971622010426862, 0.043805715295353105, 0.07919754207666431, 0.024815886514261365, 0.04803135319213782, 0.019079412366928797, 0.03217256149010999, 0.03572978132537433, 0.048359177208372524, 0.046827177450593026, 0.012804366315581968, 0.03519283960174237, 0.013195192308298178, 0.03029078371556742, 0.01473597570189408, 0.048478494198726754, 0.014405951535861408, 0.01026913387301777, 0.07138932070561818, 0.02471458462865225, 0.007630066064718578, 0.027804958800386106, 0.02232635679787823, 0.055927146292690716, 0.0580589302948543, 0.08298023909862552, 0.02189487298684461, 0.007385365980943399, 0.025260204815172722, 0.027169015424858247, 0.006619243965750294, 0.02095383482186922, 0.06598892834569726, 0.011029030329414775, 0.11155653106314795, 0.06669053355497973, 0.029832942211734395, 0.02271466881835035, 0.009127744673086064, 0.006849881411263985, 0.052724464397345266, 0.051857948037130494, 0.01836227040205683, 0.026412089255505374, 0.03903558018750378, 0.020485798329381005, 0.020661922271496484, 0.04534552159852215, 0.01356852482006486, 0.040239616829369745, 0.014571358017357332, 0.013390416163019836, 0.02526464921954487, 0.14276949475918496, 0.1072254895365664, 0.1517597037766661, 0.1723117423909051, 0.05432186475289719, 0.09222303277679852, 0.1591622494161129, 0.20937306726617472, 0.12998493148812226, 0.17389165689902647, 0.12569798795240267, 0.07582062256655522, 0.1587004791945219, 0.08413830838565316, 0.227963637560606, 0.08636682094740016, 0.12114869563707284, 0.09208558193807091, 0.11223136128059455, 0.11190489094172205, 0.0792056302140866, 0.11681003416223185, 0.12920859243188584, 0.15779349500579493, 0.08666671985494238, 0.14967381927583898, 0.12837849983147212, 0.10724659876099654, 0.14573189722640173, 0.14258178483162606, 0.21284707156675203, 0.12601312675646373, 0.14729932669017995, 0.10376752580382995, 0.19376216136983462, 0.088530960891928, 0.17177812888153962, 0.04702935713742461, 0.19044124814016478, 0.179003169760108, 0.07671123370528221, 0.1859315008457218, 0.10954896307417325, 0.149660248575466, 0.07953742705285549, 0.1124603125665869, 0.07379436772316694, 0.0964460311723607, 0.09161271088357482, 0.1339834433581148, 0.10726793190198285, 0.09018571781260626, 0.13777977893395082, 0.09924513740198952, 0.36809835370097843, 0.11517240346542426, 0.15279088701520646, 0.14580869381981237, 0.17628421208688191, 0.10305712678070579, 0.13931576508496488, 0.15623872700546468, 0.21696577912994794, 0.13625882911895001, 0.11734124565763132, 0.11633374329124178, 0.1884538462119443, 0.11826184125883238, 0.17181113282484667, 0.12917486924145902, 0.11250253780079739, 0.19207644968160562, 0.08208580102239336, 0.08898059212203537, 0.12613476094390663, 0.09653289722544806, 0.2019193193742207, 0.10209986993244716, 0.13925051715757164, 0.10540739566619907, 0.21908166844929966, 0.09101312341434614, 0.1532722126160349, 0.11380560323596, 0.12857127163027013, 0.17277372974370206, 0.17448690852948598, 0.1604678322161947, 0.2885171611394201, 0.08486085318561111, 0.151840476585286, 0.21365325259310858, 0.0690628412578787, 0.1710354315915278, 0.12071270974619047, 0.11437610190893922, 0.1373466293194464, 0.15283467966531003, 0.16023555610861095, 0.14164993911981583, 0.08898431727928774, 0.11404621175357274, 0.07847271061369351, 0.15434566858623708, 0.18263398350349494, 0.15841363530073846, 0.11297513744128601, 0.06529775221965142, 0.16641131043434143, 0.21162878908216953, 0.23091143795422145, 0.15328977310231753, 0.13831347386751855, 0.10562823845871858, 0.18408850474017008, 0.21089569984802178, 0.16893331653305463, 0.10070399447743382, 0.15814435189323767, 0.07511856273881026, 0.1799998969904014, 0.1866583746990987, 0.13731320468442781, 0.16782598809472152, 0.1533623763493129, 0.19318603085620062, 0.09693326002785138, 0.2039498354175261, 0.09322609073881592, 0.12149058229156903, 0.19712556446237223, 0.09357493237725326, 0.08327207022479602, 0.11472204620284693, 0.09529537827308689, 0.10103145547743354, 0.05365877319127321, 0.07847966559763465, 0.12380198469119412, 0.11296136318040745, 0.09333781152963638, 0.11896531922476632, 0.0983690536980118, 0.11638030436422143, 0.10816439201257058, 0.1761742622724601, 0.13820123060473374, 0.13159445726445743, 0.13329365822885716, 0.09794733061322144, 0.1395107896200248, 0.17947133178157465, 0.06270609450127397, 0.09733971607472215, 0.31414198183587616, 0.17526384469653877, 0.18473314014928682, 0.23156513859118733, 0.20800546636538847, 0.16026615803795202, 0.10286155941763095, 0.15607230950679096, 0.07737239144210305, 0.073803975779031, 0.15125353022345475, 0.07934505558971848, 0.19232141439403805, 0.11165331729820796, 0.25228957938296454, 0.07293950859457254, 0.14792481384107045, 0.1368682078484978, 0.1539595550192254, 0.11639958832945142, 0.21879605948925018, 0.09764393725033317], [0.04797674808651209, 0.017668953498027155, 0.016578966718433157, 0.038618640774594884, 0.019657395281163708, 0.07065230275371245, 0.04313393170014024, 0.04902395832219294, 0.019092313013970852, 0.01870237081311643, 0.021890912038673247, 0.026896909311679856, 0.023694369908688322, 0.07396816768284355, 0.03892878216824361, 0.024903259772275175, 0.039920562878251076, 0.02322442164378507, 0.059579934392656596, 0.020015066356531212, 0.05921819380351475, 0.016223831667697856, 0.01830019292953823, 0.03655445582366415, 0.01670767124077039, 0.023339748848229647, 0.02901699367378439, 0.02698084239714912, 0.01618808983559055, 0.0668273058586887, 0.015935157425701618, 0.035497155772256, 0.05510380172303744, 0.025843967151428972, 0.06219568010419607, 0.09867553439523492, 0.09177558642945119, 0.03028176598516958, 0.024175822734832764, 0.047314433447484455, 0.014753224062068122, 0.0786337609003697, 0.013187687710991927, 0.03200115675904921, 0.05501868289762309, 0.021415817085653543, 0.04651364677452615, 0.034121059613036256, 0.06805910476084266, 0.007365987868979573, 0.012464888460401977, 0.055581205391458104, 0.03591746411153248, 0.04646904666775039, 0.022333881751235043, 0.02077148532095764, 0.08495871150600058, 0.032540809230080674, 0.013124669619303728, 0.03633853919538004, 0.013078860023857226, 0.04330375205193247, 0.027667633490636945, 0.0898995388831411, 0.04610291934971299, 0.0630392280540296, 0.08424373237150055, 0.03293368100587811, 0.022188777037497078, 0.08223168605140277, 0.022410498532865728, 0.06564018848751273, 0.01037724655387657, 0.0019150904512831143, 0.024172387651300857, 0.024395927620519484, 0.018633574147575667, 0.01724574781422104, 0.02762759822819914, 0.01818059434715126, 0.04663268217284765, 0.06045223865658045, 0.03471983962559274, 0.1255916886563812, 0.036253556076969416, 0.017318780234615718, 0.036447352463645596, 0.01938011364213058, 0.041498041445655484, 0.04778245976194739, 0.026699128228106668, 0.017167399071955254, 0.03658729352589164, 0.013303103973157704, 0.038918716101241965, 0.05874790796743972, 0.05640457710251212, 0.039845408339585574, 0.024028098875922815, 0.049624712871653695, 0.08283744140395097, 0.020041161117010882, 0.03602169726842216, 0.0354774782567152, 0.033826487205390415, 0.05426112569070288, 0.01900629512965679, 0.03465219646958368, 0.007581080925384802, 0.05136136896908283, 0.10903481673449278, 0.0409179856069386, 0.01789990476598697, 0.0325280934838312, 0.009659420964973313, 0.018308662742908512, 0.04519818111189774, 0.04665985071499433, 0.021885697497054935, 0.03872764742534075, 0.03267750350226249, 0.026161740367699946, 0.02503199822136334, 0.010621801600791514, 0.01716380792536906, 0.06876790922667299, 0.01842831900077207, 0.06211776392800467, 0.03189722555024283, 0.019146270118653774, 0.04643842777503388, 0.04250614431553653, 0.06772242925528969, 0.03332990813734276, 0.015948870618428503, 0.03467406904590981, 0.027878299954214265, 0.014664444540228163, 0.042065049055963755, 0.06206793910158532, 0.03266260287325297, 0.021893068083695004, 0.024694625521078706, 0.029228588033999716, 0.026211661885359457, 0.033142632472195795, 0.023240730232958282, 0.03907259427277105, 0.011096480951112295, 0.036003828048706055, 0.02534901487108852, 0.07635355075555188, 0.022187165516827787, 0.007889753290718155, 0.00580575893400237, 0.028992237323629003, 0.01866743983035641, 0.03414525956447635, 0.040110145562461445, 0.031413362228444645, 0.0301618213499231, 0.05523659781153713, 0.03514932515099645, 0.020652212435379624, 0.012912227938483869, 0.03002282345135297, 0.04694090670506869, 0.02506095470328416, 0.011688263571288968, 0.006101112505088427, 0.008926137500176472, 0.08143070938863925, 0.04765881032549909, 0.01581763007145907, 0.02963646561173456, 0.012371762921767575, 0.03678393636697105, 0.0549034167613302, 0.019475893949025443, 0.018589235276782086, 0.020050046533080082, 0.04584868924160089, 0.06785133055278234, 0.0317419122771493, 0.017701329796441963, 0.01120985736737826, 0.048358505458704064, 0.0213242436958743, 0.017989006591960788, 0.03799635630899242, 0.05774057523480483, 0.04800104642552989, 0.01835530693642795, 0.012505254508661372, 0.016135728984538997, 0.022258094478664652, 0.0877880057586091, 0.024587303333516632, 0.03262823846723352, 0.0776153951883316, 0.007933378003404608, 0.04125689349270292, 0.012778462393076291, 0.024927055995379175, 0.027642636260549937, 0.030718135248337473, 0.03344465858702149, 0.03967342006840876, 0.0018647249172707753, 0.008800170018470712, 0.042251320489283116, 0.05005952150427869, 0.03314219820978386, 0.047758626219417365, 0.0677509887942246, 0.024231925706512163, 0.024860932757811885, 0.0681920772684472, 0.04579320204045091, 0.044477017130702734, 0.04653478653303214, 0.02974876994267106, 0.03342433646321297, 0.003147815553737538, 0.03186855744570494, 0.04961027703913195, 0.022778910817578435, 0.017925388844949857, 0.02236110796885831, 0.02238693131533052, 0.03215342001723392, 0.03878238484529512, 0.09321186864482504, 0.02232754253782332, 0.035746581852436066, 0.0042185883420253435, 0.01683531385580344, 0.0219839120483292, 0.029889342042484453, 0.026803734579256604, 0.05347853393426963, 0.04811403268416013, 0.0409380159606891, 0.01876975273314331, 0.017742957919836044, 0.026802202786452005, 0.05311996888901506, 0.03994812497070857, 0.07515149204326527, 0.01692909757340593, 0.030534482960190092, 0.031018400564789772, 0.03221301235524671, 0.007267942951459969, 0.012602378314893161, 0.052083598250257115, 0.020072748618466512, 0.04480466812050768, 0.07983607067061321, 0.06066204846969672, 0.036703533359936306, 0.03885267089520182, 0.05088463705033064, 0.007666036054225904, 0.05255254737234541, 0.022797791054472327, 0.0343998153693974, 0.07995133341423102, 0.02482412732206285, 0.028883620830518857, 0.013957690098322928, 0.040342570947749276, 0.03819784728278007, 0.007918952348908144, 0.034299697527395825, 0.01710117744681026, 0.030933831352740526, 0.0373465877824596, 0.05851559114775487, 0.056004685881946764, 0.0708445520805461, 0.04560819607494133, 0.04922563928578581, 0.0669890618217843, 0.006506375178495156, 0.04349218801196132, 0.020479742404339567, 0.07943120239568607, 0.08143167290836573, 0.06303933661963258, 0.03994091892881053, 0.02049858362546989, 0.011235844410423721, 0.04437078908085823, 0.023576391328658377, 0.07266082069171326, 0.022025870957544873, 0.04763232710372124, 0.06748087078865085, 0.013704726306189383, 0.03157109447887965, 0.03807676949405244, 0.036344659581248245, 0.04466454724648169, 0.04256900719233921, 0.010109719703905284, 0.05982458019363029, 0.020157044720170752, 0.05005180995379176, 0.02001407230272889, 0.09822189980851752, 0.0106833074075569, 0.01407299016136676, 0.020148349293906773, 0.03628493832158191, 0.03122687366391931, 0.009804220337952887, 0.019838735461235046, 0.03511152057243245, 0.047248150754187784, 0.00782524242198893, 0.03884769044816494, 0.009381359010668737, 0.012077996274456382, 0.009301239292004278, 0.035248472687921355, 0.025266968112971102, 0.06600896548479795, 0.02229173794122679, 0.015649032779037952, 0.017959492014987127, 0.037227769515344074, 0.030381320643105676, 0.02257575573665755, 0.011238122591748834, 0.03476523361834032, 0.04162485285529068, 0.013188527398077505, 0.03690598446077534, 0.024680875008925796, 0.010881923937371798, 0.060081636400095055, 0.04937684063666633, 0.10081733696694885, 0.04608325879754765, 0.03351634581174169, 0.04312036778511746, 0.06948195876819746, 0.02420077416380601, 0.04252654786354729, 0.03069443062746099, 0.021196816515709673, 0.21442911667483194, 0.11830986796745233, 0.08668613274182592, 0.08973936390663896, 0.10626378828393561, 0.18084799791021006, 0.14668709811355385, 0.10919377713331155, 0.20918591373733111, 0.07335967104882002, 0.13778809777327947, 0.10021391577486481, 0.14742879117173807, 0.23491376319101878, 0.09605766486908708, 0.11827265710702964, 0.15070611531180994, 0.09146415921194212, 0.1680420200739588, 0.132417995216591, 0.15515399378325256, 0.1374867603714977, 0.0839240202414138, 0.11587261089256831, 0.08327770885080099, 0.15050077704446657, 0.17586628879819596, 0.1697959652436631, 0.10976566680307899, 0.17170083017221519, 0.077007733152381, 0.11709508672356606, 0.11806259623595647, 0.1818417395864214, 0.1328077864434038, 0.14847244588392122, 0.19963522122374602, 0.23004709290606634, 0.24992499340857777, 0.10237774359328405, 0.0786187042083059, 0.1803860105574131, 0.12185289285012654, 0.081366370698171, 0.11740574719650404, 0.10614207267229046, 0.09916060550936631, 0.10058854174401079, 0.09719969358827386, 0.12893037950353964, 0.10346981177904777, 0.17532223942024366, 0.0942869938111731, 0.0862704621894019, 0.07427501478897673, 0.11162270858351674, 0.14110897029084818, 0.09059916277016912, 0.11650904959865979, 0.11161622178873845, 0.06143228749611548, 0.10016249639115163, 0.09912177973559924, 0.2026666985558612, 0.10897684948784964, 0.1938466118382556, 0.2749931439757347, 0.0825231032712119, 0.13607703601675375, 0.15672822216791765, 0.14374294823833875, 0.1401060005383832, 0.18274253553577832, 0.1030228336208633, 0.12116317557437079, 0.16650147416761943, 0.13620143862707274, 0.06493505489613328, 0.0864564079259123, 0.15687159661735806, 0.18234760101352418, 0.12663014579032147, 0.15447782006646904, 0.2345602735877037, 0.09460427000054292, 0.07372785772063903, 0.1237279022378581, 0.14935136586427689, 0.16012867327247346, 0.1784420484410865, 0.15094626242561, 0.14611946285835334, 0.12040458699422223, 0.166888456259455, 0.13114974541323526, 0.11066445428878069, 0.15877367955233368, 0.1266614126839808, 0.159989845007658, 0.15867614692875318, 0.07932670800281422, 0.06465119655643191, 0.18826372069971903, 0.08906683392290558, 0.11465421984238283, 0.17618750727602414, 0.11966232396662235, 0.13342966378799506, 0.06460255916629519, 0.11867956098701272, 0.10059397680951015, 0.1680140644311905, 0.21890432653682573, 0.18257640302181244, 0.12977738119661808, 0.11595687137118407, 0.09872710984200239, 0.12254532426595688, 0.06829431213970695, 0.12977394780942372, 0.1010256540030241, 0.2413569145968982, 0.09408202195273978, 0.14441114238330297, 0.07116030156612396, 0.11683359289807932, 0.06818621472588607, 0.09517194596784455, 0.1384300733251231, 0.05581872318206089, 0.2084843763815505, 0.15295649027185781, 0.13626116327941418, 0.10464372485876083, 0.17513568300221646, 0.10323113030088799, 0.1187139084296567, 0.1325336175837687, 0.11554791831544467, 0.15739174799195357, 0.12669015542737075, 0.06499952250825507, 0.09540675301104784, 0.10802597086876631, 0.15542466140219144, 0.14107787981629372, 0.06419714806335312, 0.13536047589566025, 0.14796920360199042, 0.21040556686265127, 0.11329206757779632, 0.1996560793902193, 0.11023434451115982, 0.10618838268731322, 0.07229957543313503, 0.07285705301910639, 0.0997642031205552, 0.10586995977376189, 0.100969980204744, 0.12307889706322125, 0.1559669194476945, 0.07565523644110986, 0.17684120791299002, 0.12995127615119728, 0.05770688597112894, 0.18638926771070274, 0.17428892558174475, 0.17846933911953652, 0.10608840055231537, 0.10026838856616191, 0.1305652553481715, 0.18247645481356553, 0.1324491671153477, 0.11910266828324113, 0.12445298475878579, 0.07419215887784958], [0.005296548088413796, 0.017708868320499147, 0.051436391193419695, 0.06903862434306315, 0.025177408275859695, 0.04077046191585915, 0.05195698022310223, 0.057760008477738926, 0.02374062903358468, 0.00284169681253843, 0.007582303984755916, 0.023109392994748693, 0.05024047661572695, 0.04172151016869715, 0.05043002537318638, 0.028087341326421926, 0.04213744195710335, 0.035667203433279476, 0.06436674110591412, 0.02735721898664321, 0.08472923774804388, 0.02594063973187336, 0.07939869378294263, 0.0074988416329558405, 0.0343930401972362, 0.08292852115950414, 0.019171898386308124, 0.013202298266280974, 0.012769383594526776, 0.027155068137549927, 0.03134881658479571, 0.015221442062673824, 0.028333274647593498, 0.016099334062476243, 0.041774429114801545, 0.023227966989257505, 0.045422107846076996, 0.048243042547255754, 0.058199875588927946, 0.06880182240690504, 0.04442361303206001, 0.06079524489385741, 0.03850133564057095, 0.022421327951763357, 0.016059156307684522, 0.028921350770230805, 0.055300346176539145, 0.03765484963410667, 0.03153914565752659, 0.03662105742841959, 0.07318062601344925, 0.026066689485950128, 0.007864370992008065, 0.03417270630598068, 0.05885352872844253, 0.013790979133253651, 0.03019741051165121, 0.047821638373924155, 0.04234146386651056, 0.034779289471251626, 0.03895753848233393, 0.0289585039551769, 0.0510435974491494, 0.022537060580881577, 0.017122286671240414, 0.0437506453932396, 0.02329977465394352, 0.029584191273897886, 0.029468514623918703, 0.060855661651917865, 0.01792186894454062, 0.058228048362902234, 0.011102137388661504, 0.05877325803573642, 0.03965064843318292, 0.022145744346614395, 0.06439437783722367, 0.03624182081382189, 0.009000018937513232, 0.03832513027425323, 0.060873154284698625, 0.05331567535176873, 0.04838306503370404, 0.04694257250853947, 0.025587558945907012, 0.04391196370124817, 0.025220503731231605, 0.021460059265206968, 0.06420367557023253, 0.0757626553199121, 0.030969284807464907, 0.025957849076283828, 0.06303307374141046, 0.039492105333400626, 0.049874457863292525, 0.013730157798688327, 0.03209508636168071, 0.05246855152238693, 0.020372847693839242, 0.052478084939398935, 0.036095060474638424, 0.04360366453017507, 0.03481893966506634, 0.02343362077538456, 0.03385826978566391, 0.028742672143770114, 0.008340430312923022, 0.024523107135402303, 0.058769207181675095, 0.024340442115707055, 0.032360169637416086, 0.03913352332477059, 0.029007412759321075, 0.05230171672467675, 0.06205883316163506, 0.03187012146892292, 0.02792474058722811, 0.033424088797931156, 0.029499635632549013, 0.03335712756961584, 0.014290430948936513, 0.02125685159782214, 0.04509471809225423, 0.0331143172058676, 0.06861767478819404, 0.003272288986149111, 0.03150616207027009, 0.05117516538926533, 0.07882286182471684, 0.0511222667992115, 0.0338312674845968, 0.027520301485700265, 0.028905856423079967, 0.04483880860997098, 0.04876210487314633, 0.048488729899483066, 0.05722686994288649, 0.047821014121706994, 0.06648997895951782, 0.04069546004757285, 0.009560988434324307, 0.04120275657624006, 0.01576716742212219, 0.05902090974684272, 0.042799546250275204, 0.024018137981849055, 0.021865475457161665, 0.0325772940580334, 0.006182158848137728, 0.03227874543517828, 0.016465951622064625, 0.018912206071295908, 0.04943123200376119, 0.03369417966210416, 0.025033843836614063, 0.08330843970179558, 0.0272429129774017, 0.05525046367464321, 0.07981702419263975, 0.06898299125688416, 0.03165257635659405, 0.023227310506626964, 0.05416832924155252, 0.018806193456319825, 0.02502343850210309, 0.0104735459400607, 0.04172392914603863, 0.06324937034930501, 0.04225590738600918, 0.04056239254506571, 0.03249524899625352, 0.008499656188567834, 0.025568785578278557, 0.05957363758768354, 0.04009960452094674, 0.07888405889804874, 0.017099097736978104, 0.019671351050159762, 0.051407845225185156, 0.007572048776117819, 0.055565605871379375, 0.052062665444931815, 0.07256233811910663, 0.0617029211883034, 0.05359086201393178, 0.052549042738974094, 0.048893954405294995, 0.046338262435581, 0.02551184461585113, 0.05412914723690067, 0.04116189519741705, 0.03946367471611925, 0.021944955656571046, 0.11637000420263835, 0.07511561789682933, 0.027194022832970535, 0.05624059554455536, 0.044923367643994946, 0.021576858890642012, 0.01448714333985533, 0.023295140259766152, 0.0517940334310489, 0.047374823064144166, 0.06691921342696462, 0.04140674116622124, 0.028987969338361706, 0.02643037577425795, 0.026491002878174186, 0.09738219236688954, 0.05147115932777524, 0.07399852533957788, 0.0068213002440253535, 0.04623554241178291, 0.01873483362474612, 0.0909254906166877, 0.04009748070633837, 0.012211910249399287, 0.06628242866801363, 0.09663523387696062, 0.08823832230908529, 0.047286321741661856, 0.039739434740373066, 0.03553414610879762, 0.015156377339735627, 0.053708031440951993, 0.04471594627414431, 0.023381236175607358, 0.014802772385467376, 0.010667603562719055, 0.02711967914365232, 0.0512382861093751, 0.04481608786487153, 0.05889755208045244, 0.040241228350039036, 0.021968426182866096, 0.01943825900421611, 0.007443809898437134, 0.06516689674130507, 0.049955515656620264, 0.03362425662843244, 0.022281088334109102, 0.05992587190121412, 0.038221629935183694, 0.03497510789228337, 0.008692221034185162, 0.0779675209362592, 0.023544101543458443, 0.02199044294788369, 0.011456862773879297, 0.03738804966477411, 0.04816517047584057, 0.03595525172672101, 0.015950907919821993, 0.03253683301487139, 0.0457205173692533, 0.0337613342728998, 0.03041135599570615, 0.005865154496859759, 0.06548879375415188, 0.0059179818407366315, 0.016938603849017193, 0.044713181243943315, 0.07431178460163729, 0.024119889396908026, 0.05078496704144137, 0.029950525545115982, 0.047738029288926294, 0.017170813799436604, 0.036199439516557116, 0.031023716886660883, 0.044257860497704575, 0.01589718321338296, 0.06108367655958448, 0.013964896988389748, 0.046309424697288444, 0.02098232989997736, 0.05803503907684769, 0.06685028105442013, 0.011787946302709835, 0.05005927383899689, 0.08415669668465853, 0.03282221466568964, 0.006949273644879992, 0.04621821262740663, 0.02680384653753468, 0.06339040385293108, 0.006099564597077135, 0.032936663167285066, 0.05272756530238049, 0.05025849172047206, 0.06901526238237109, 0.08006256565983806, 0.003967643615656665, 0.027615084346117716, 0.01755818604890789, 0.04487686085381678, 0.05073679784046752, 0.057763652210789065, 0.030785676624093736, 0.014136220295248287, 0.026343080547771285, 0.016939653881958554, 0.05247893650084734, 0.020981376558276157, 0.03833342197218111, 0.09117809563343014, 0.05191627151465841, 0.029170532577804158, 0.0310114082614226, 0.023511121348877038, 0.019845715890239393, 0.03618392142068062, 0.07845238848988499, 0.016164045947204744, 0.028855132537760904, 0.04123969262998019, 0.02801017153875104, 0.03281441829832537, 0.045048872873719246, 0.061152493581175804, 0.019393148299838816, 0.020086331193202307, 0.01746379504246371, 0.017559602490759323, 0.04615432855540088, 0.03061181559626545, 0.04283743564571653, 0.03739428200892039, 0.023670042731932232, 0.018243084029693688, 0.025691724249294827, 0.041878570669463704, 0.024926955911463926, 0.055431116838008165, 0.04440130280064685, 0.03597994361604963, 0.0663993673931275, 0.04156945725636823, 0.023556791844644716, 0.05606520102758493, 0.04391608240881136, 0.01868521575150745, 0.04007510940677353, 0.030184827079730372, 0.019201402785256505, 0.04976025363430381, 0.05405284597405365, 0.020824718089508157, 0.044572127384266684, 0.014516693539917469, 0.044842879820082865, 0.02960719700370516, 0.09707202722451516, 0.07937934196421079, 0.1552288361958095, 0.1969388180545398, 0.19136881908135756, 0.14659721936498368, 0.20056594056742533, 0.15382566648934567, 0.14657889891948017, 0.1694997168545212, 0.11471825997744288, 0.09489793995661394, 0.12237465913806643, 0.09458987148744719, 0.19679589143821172, 0.19476424902677536, 0.0857062263946448, 0.16087829161967548, 0.13555687107145786, 0.11848856694996357, 0.1769144218415022, 0.13381461027477468, 0.21730548090168408, 0.10103558775569711, 0.05626799478860838, 0.13731367965894087, 0.06296920324010508, 0.17208988858120783, 0.12063914297946862, 0.13506249045687063, 0.11367330926337413, 0.08578903480832066, 0.13557865204555647, 0.15639236090438707, 0.18640980018036707, 0.1364225596189499, 0.12771046853491239, 0.1477834071431841, 0.17451277428439685, 0.11879459981407438, 0.08862183030162539, 0.13975551005985054, 0.14469167590141296, 0.1721331248325961, 0.15906429610082082, 0.14428667191948208, 0.14498716433133396, 0.19275437401873724, 0.15964345288063797, 0.20739870678101266, 0.15828961267002992, 0.11027242389640637, 0.06833269686571189, 0.14042861679834978, 0.14950763247907162, 0.17502842018646853, 0.15213042816945485, 0.13877972242023262, 0.10076893027871847, 0.15783546918204852, 0.06884943520916359, 0.12329300200300557, 0.10696660807090146, 0.18501610282276357, 0.11265923189265387, 0.2053064304803099, 0.1450810192951134, 0.09719321357884578, 0.17356372092451366, 0.15522112803799765, 0.12369693389960698, 0.12955108976789884, 0.06611094251275063, 0.12424595015389578, 0.11555857131523745, 0.0625061234459281, 0.17082224945936883, 0.10273073786603552, 0.10099850581692797, 0.16349249705672264, 0.11225006849105869, 0.10943235683121852, 0.13196415028401784, 0.11237409112176724, 0.074202689741339, 0.172930294913905, 0.18595985003880092, 0.1506683344819716, 0.145102325294699, 0.09181948764515774, 0.14989808867020266, 0.10781430186969893, 0.1861115704689707, 0.16161087873790944, 0.16150927490421704, 0.12338737265339919, 0.1763762485768114, 0.16696776343243463, 0.15656234749725886, 0.12015894374677114, 0.1169890859829528, 0.11413355278117315, 0.10911157261580229, 0.17133381058062824, 0.18516335849251064, 0.1489727297531707, 0.15863011511308805, 0.19556538175259316, 0.1337346788495779, 0.14579289752457822, 0.13872455752321652, 0.10332399460354022, 0.10670647131545202, 0.1492627491908414, 0.112270892730781, 0.14828477666846343, 0.1338646047349487, 0.09968988317996264, 0.11274013362292733, 0.16455859770732267, 0.1306231343852622, 0.1791424729994365, 0.1356672958603927, 0.07648534261222396, 0.127196179702878, 0.09303798047559601, 0.14187332641865524, 0.09197888909173862, 0.12847908586263657, 0.19221215668533528, 0.114203916862607, 0.15399272181093693, 0.08865986218942062, 0.11763568914362363, 0.1303495354950428, 0.20468684658408165, 0.18454277036445482, 0.1430821501250778, 0.15116728842258453, 0.11322435656828539, 0.08532826203320708, 0.15043144433626107, 0.11868085020354815, 0.114826839151127, 0.13657871766814164, 0.08616705345255987, 0.06653136281030518, 0.10187070151524884, 0.07125659247062036, 0.1254179294088057, 0.1524541029440505, 0.08779489967439856, 0.12911142621721539, 0.1408595543886934, 0.08213095074253422, 0.158506146765181, 0.23908004962972232, 0.1821412178022521, 0.192080466608916, 0.11239762271621398, 0.10422789145793233, 0.1751920556915658, 0.1233033835887909, 0.20858064692999634, 0.05177145178562828, 0.10885842477104493, 0.12520083891493933, 0.0909586777644498, 0.12516269167619093, 0.11895979594971452, 0.07352532858827285, 0.09274872099714619, 0.18375913027141774, 0.12714732518153532, 0.14066739327141217, 0.13085831462272576], [0.030933122283646038, 0.043555634428880045, 0.08523195077266012, 0.019101703938628947, 0.018853511095845273, 0.057210076201174936, 0.03830018054161753, 0.01337785563165588, 0.06333625675844294, 0.03651958590905581, 0.029688071592577865, 0.003339229858413871, 0.04661092834014978, 0.02311352527301226, 0.028482358969215835, 0.03559296152421406, 0.019270628624196564, 0.044346477171140056, 0.023475912166759372, 0.039111643963094266, 0.11699819192290306, 0.043339375140411515, 0.06779716310224362, 0.015019498166761227, 0.0423322561463075, 0.0447499374859035, 0.0332852096429893, 0.02123737764278693, 0.0034989741772213684, 0.080849075956004, 0.04261362086981535, 0.05035831779241562, 0.07150917713131223, 0.06429221081946578, 0.02879700922806348, 0.01104671719284462, 0.07497955805488996, 0.00864642416127026, 0.013051504036411643, 0.038966020170067034, 0.048087468038180044, 0.030982848722487688, 0.019919191054733734, 0.026575941891808594, 0.06361681741795369, 0.04266491811722517, 0.023662114050239325, 0.01552662845434887, 0.009983883688359388, 0.02873571715982897, 0.01569079321676067, 0.009523660526610911, 0.031261940353683064, 0.04939203303573387, 0.0685083017285381, 0.07929360227925436, 0.02306155627593398, 0.02964715932362846, 0.02712218463420868, 0.008728500605294747, 0.05241490315113749, 0.045895464053111415, 0.035597127729228566, 0.0330511082762054, 0.03987023254324283, 0.006025046184991619, 0.010329631207111691, 0.02589769016153046, 0.03236843080126813, 0.020576825498470237, 0.0681727458057659, 0.023729326336511543, 0.014774262040321316, 0.04662975090156708, 0.05258324768926416, 0.027231605191315924, 0.028650957957974503, 0.02658689853602222, 0.029491988542888845, 0.045670360060674806, 0.04158780823594757, 0.006710215579784874, 0.01815250299737922, 0.07887934307966914, 0.01139999899481024, 0.042399933229067495, 0.03646027855575085, 0.038490346765943935, 0.07858441783381359, 0.016529148677363992, 0.019587587598445158, 0.029099517102752413, 0.08162396973265068, 0.012310291889921894, 0.03679179719516209, 0.04477636981755495, 0.041941877986703596, 0.013692874843919916, 0.03697333584672638, 0.012937637378594704, 0.11806832307151385, 0.040822620902742655, 0.05956183786370924, 0.08228974829294852, 0.030122564706419195, 0.03380425161282931, 0.015728156747562543, 0.025048788570399796, 0.02425706203627799, 0.03083296712221844, 0.02065574929916433, 0.01846756716258824, 0.05836910900792905, 0.0442879704891571, 0.03356279153376818, 0.04571550978081567, 0.08521968964487314, 0.007443743741272816, 0.02298862224311701, 0.06988621636160783, 0.02711409140777375, 0.046064975671470165, 0.058678507405732355, 0.051411526277661324, 0.05976421771837132, 0.04681008854614837, 0.09785575552710465, 0.052295257071299214, 0.047186828151877434, 0.03313591158283608, 0.02823449012690357, 0.05718807809587036, 0.09021098645670073, 0.02931769664532372, 0.033126676721232276, 0.02054039664965655, 0.0583537198337061, 0.06203699790473495, 0.038995641616306136, 0.015189600110586201, 0.02598604390264622, 0.043036650134516616, 0.015112584689632058, 0.011412752060485738, 0.012918523895288152, 0.057844560726412704, 0.009273414267227054, 0.010481350789112704, 0.042658003845385144, 0.039994434985731325, 0.0931219288281032, 0.02017527356344674, 0.08429023916167871, 0.05736264480011804, 0.06226190512201615, 0.025168471969664097, 0.04897477471136621, 0.005012604507750699, 0.060357759440583844, 0.032621476865772686, 0.05357597156294754, 0.02585552090645901, 0.022645159691040005, 0.05393414645056639, 0.023447836084025245, 0.08708966430276632, 0.02315544686280191, 0.0435919021256268, 0.01707357633858919, 0.0406550227531365, 0.02704374259337783, 0.03709797594430191, 0.02917500751625214, 0.002848299594396459, 0.04928819003647991, 0.015533610579690762, 0.03291421722886818, 0.030971174527491842, 0.07824936402695519, 0.0350247427288975, 0.018508179179791893, 0.062264374989484034, 0.06993026006966829, 0.03991836442479065, 0.09088373357164008, 0.004100780243918831, 0.013796284428930708, 0.027999613533860872, 0.016398444173059294, 0.022213246706607084, 0.050316343616162024, 0.03707420686259866, 0.034255284017750194, 0.0257052661119295, 0.021525157914896096, 0.04898157702492816, 0.03274473614458527, 0.048751774177487404, 0.012613926980910557, 0.053582373540848494, 0.0077695228225950685, 0.08043751732579299, 0.04974622153011816, 0.07483927772513457, 0.046240278586213074, 0.044564585467534404, 0.018563471302124004, 0.010366911617373782, 0.0442734600177833, 0.02817424469893532, 0.02408916363492608, 0.05156355883393969, 0.09893814780350242, 0.025625025953299234, 0.05714171379804611, 0.040724430100194046, 0.014923361628981573, 0.03881325479596853, 0.08172309691352503, 0.028947148671639816, 0.05419780480276261, 0.011806689136262451, 0.020964516659400294, 0.03635326001260962, 0.06615029075848204, 0.0751016265047448, 0.039965383508907895, 0.02668498077296785, 0.03078130346589855, 0.11200964317790099, 0.033814422852758846, 0.025153593393042684, 0.01851045566477946, 0.06796762466962848, 0.01682929864286312, 0.025843558334080235, 0.04456716050793018, 0.034891325780855756, 0.024949776740478616, 0.02863460187134998, 0.033063613676599095, 0.08560582356793539, 0.0438760047379349, 0.02244000293181411, 0.03299737169540354, 0.017910947923415473, 0.026046333435390676, 0.017444480543157885, 0.03085314336099795, 0.04349738898287926, 0.026592367528272525, 0.024956504415188516, 0.03262494417971798, 0.008247733947687914, 0.03185108516897474, 0.020673698246745125, 0.009609517258858042, 0.021846512099727988, 0.03667469222896865, 0.02078145300038159, 0.041391670903457065, 0.052336576461259804, 0.022554473485797644, 0.04526331029566271, 0.029832063508885245, 0.03551406825759581, 0.04024979824732457, 0.04656018070610506, 0.00915072750233646, 0.024509061460516283, 0.04515644781557577, 0.02762452107188957, 0.04267620893993548, 0.009384009538085332, 0.02040308151793267, 0.048414274251886776, 0.05671505776367017, 0.04334951245359012, 0.008505433914251626, 0.061978847453636784, 0.06534248803343091, 0.029604133418095962, 0.031052792112209966, 0.09233010560274124, 0.038003460570637665, 0.039404028095304966, 0.057390831144792695, 0.05399170318352325, 0.056732435045497756, 0.014175308153166302, 0.07118491881660052, 0.018784851833645786, 0.07049729142870222, 0.022910164935248237, 0.0280767595728061, 0.04628126210133944, 0.0015604195609090052, 0.029818167111703327, 0.04484070850802319, 0.06445022805460862, 0.056420671953154464, 0.041685900650918484, 0.04345693811774254, 0.03227337483050568, 0.014686162749837552, 0.005396746082364449, 0.041671295184642076, 0.07174987385847739, 0.05636384803801775, 0.025518334803304503, 0.01913476555741259, 0.03159197639407856, 0.04233357250424368, 0.05651997894580875, 0.034923257638833353, 0.018866689942244972, 0.11534329929522105, 0.049273944193763394, 0.028678292741200755, 0.04261309839785099, 0.06235622148960829, 0.036379566815282614, 0.03891720636082547, 0.013425736455246806, 0.019565801535333906, 0.013736288362581815, 0.05894082225859165, 0.05325677511947496, 0.03895622551707285, 0.03431872704199382, 0.03461784224158951, 0.02534809206346316, 0.06173958922071116, 0.006399342640569168, 0.0446835699757295, 0.02362449946148055, 0.0351596897734063, 0.030087111251694814, 0.03814865688660315, 0.028942897649747983, 0.044061336400253434, 0.025610456110111306, 0.017244665550866296, 0.10078910312482289, 0.04676017890285168, 0.03449564826275621, 0.02737545800794448, 0.062124372859086306, 0.019315038741167103, 0.01763698092794844, 0.03496092651039362, 0.07324318015681845, 0.12216777381088052, 0.11344553862831422, 0.240090795393501, 0.08349364583513566, 0.09228087788713829, 0.10481996075915438, 0.10536575397210461, 0.11640621083123343, 0.17314517338361057, 0.1838647917445217, 0.09065420553088188, 0.20059186060513767, 0.09970263963831322, 0.10094937988157783, 0.11241319509489195, 0.08351864985057286, 0.0975717818364501, 0.11544847222311155, 0.10716616521988596, 0.18549780840320246, 0.24147115275263786, 0.13598098259951386, 0.09838380504931722, 0.12087113410234451, 0.20661433387015546, 0.12969405709632806, 0.19428065711898462, 0.20054363033601216, 0.11315606201865844, 0.24130331033042499, 0.07714654106114592, 0.11362473972673927, 0.16765537724963256, 0.11875257135501929, 0.06713792561952557, 0.1991223166031497, 0.16238254947321756, 0.14570371088172707, 0.15463221392461232, 0.13893187711281435, 0.09985784773847886, 0.08203316706099681, 0.12680018666599477, 0.11983529611357621, 0.1491715269429343, 0.13954482493656023, 0.11130738657500062, 0.0825360022219164, 0.164005985217435, 0.14855074882507324, 0.12334154439823967, 0.10980766133538314, 0.11503037251532078, 0.1565018764563969, 0.3353838734328747, 0.11123232024588756, 0.09646412770130805, 0.14768136904707976, 0.061225870358092446, 0.19283613748848438, 0.17960676737129688, 0.15279034418719156, 0.07183265513075249, 0.10325535400105373, 0.10037106448518378, 0.19839584987078393, 0.10183052545679466, 0.1586225155208792, 0.15992049872875214, 0.16602658107876778, 0.20354849552469595, 0.11147785492773567, 0.09993565534906727, 0.13260022258119925, 0.16234061600906508, 0.08354434597172908, 0.15074234908180578, 0.10482958238571882, 0.16034189611673355, 0.11983320622571877, 0.2116426040551492, 0.16440146256770405, 0.13563928593482288, 0.14181402245802538, 0.08729019175682749, 0.17072981941912854, 0.07531149060066257, 0.16676541071917328, 0.12224794950868402, 0.11967214915369238, 0.1162227892449924, 0.09673347896231071, 0.2255639848964555, 0.12155828651572977, 0.09950357781989233, 0.18906553196055548, 0.13024825735815934, 0.13029796683362552, 0.14316707556801184, 0.19093531662864344, 0.23985903497253144, 0.10369046458176204, 0.11311523456658636, 0.15752358734607697, 0.16189040802419186, 0.11139423905738763, 0.10019798377262694, 0.16802874792899403, 0.1329994454447712, 0.16470487628664288, 0.09057585509227854, 0.16744372860661574, 0.157404789435012, 0.09517892130783626, 0.11271048164261238, 0.10413385328969785, 0.15142448033605302, 0.10450476767229182, 0.09893514867872, 0.14391974732279778, 0.10065155050584249, 0.17641477579517023, 0.1501757451998336, 0.1846335990620511, 0.16039744099336012, 0.12980951661510126, 0.12756455636450223, 0.08709831562425409, 0.08898687535630805, 0.12879279974315846, 0.09581351439867701, 0.17935515301568167, 0.13796761099781307, 0.10906748141029052, 0.13765103369951248, 0.1048247172896351, 0.1618120643709387, 0.1963753897164549, 0.11104693769344262, 0.10721416478710515, 0.20774465107492038, 0.1439608529742275, 0.11633320046322686, 0.06666019625429596, 0.15810699175511087, 0.1934618010584797, 0.08441147979881082, 0.08253220921116215, 0.09338121062942914, 0.13580593413540296, 0.12128851456301552, 0.09462048698748861, 0.12107736803591251, 0.13584007801754133, 0.16171630950910704, 0.09585864376276731, 0.10201489020671163, 0.15759490137653692, 0.15886653028428555, 0.12852931102471693, 0.16381041785436018, 0.12005758418568543, 0.16891317761370114, 0.29443477360265596, 0.10770868110869612, 0.127092662400433, 0.10194489253418786, 0.12448362740022795, 0.1432413887232542, 0.10321218560316733, 0.10569892823696136, 0.1310000063053199, 0.15125291954193795, 0.06686022159244333, 0.09226924779691867, 0.13290401627974852], [0.034251243341714144, 0.027769576591838683, 0.07989361722554479, 0.08379692384707076, 0.027268483569579463, 0.036850079960588894, 0.02446601859160832, 0.08081228578729288, 0.024151519306802323, 0.008327717111179871, 0.00619101373013109, 0.033631371068102975, 0.05627726696963821, 0.03185814532584377, 0.017619598557108214, 0.00821622193325311, 0.015052805754489132, 0.024647830353517617, 0.027219685027375817, 0.016608571201296787, 0.035851622465997934, 0.035108687688729594, 0.039336754740881066, 0.013522195297160318, 0.048159623452063115, 0.03285970033279487, 0.036113136647535224, 0.0474984080397657, 0.032639471614467244, 0.006608972641905504, 0.013474458662260855, 0.047913997167987485, 0.023310059548488686, 0.02496643307884889, 0.017676839771281396, 0.027717326002727662, 0.03979158354923129, 0.036396184137889316, 0.03696271338100944, 0.04860890184396079, 0.026272758874776106, 0.03355164659608688, 0.03462190666635122, 0.0631446045424257, 0.025024856640292064, 0.011916861170902848, 0.02604784656848226, 0.045142035731779676, 0.05399484819333468, 0.020543015794828534, 0.020247301752013818, 0.037780619492488246, 0.03545958189559834, 0.030464542963142906, 0.06226442927228553, 0.036777069592582326, 0.09279378929308482, 0.0026928062974807938, 0.0024167335109918243, 0.028238059221101657, 0.05245753889903426, 0.006299183662382087, 0.04133585122014795, 0.04198581312916108, 0.087773193339152, 0.03674753974857075, 0.005529010793127651, 0.029686582208211933, 0.02704588506769921, 0.03729393007233739, 0.023142439346494417, 0.0204802530019411, 0.03782431375501411, 0.036748465948871205, 0.034512889837580066, 0.04090470667662365, 0.05468077924368637, 0.022940795702327575, 0.04131267246391092, 0.038583153393119574, 0.04918245392452393, 0.012694676888973584, 0.045051492018891234, 0.04323504698861923, 0.02691290577474449, 0.045410342048853636, 0.06862177992505686, 0.041274053643324544, 0.022491510525079708, 0.04428589077932494, 0.025458320077242594, 0.026507509938840355, 0.05156845446409924, 0.02345569182320365, 0.0238796303248299, 0.00493830068236483, 0.03547445199053202, 0.06915256394339458, 0.0579315624865038, 0.04164841837648835, 0.01890733927887465, 0.037780599136437686, 0.014345304075894611, 0.030113221279212406, 0.014627187878691723, 0.024236035932387625, 0.020110688904034238, 0.021494689996221235, 0.05842377857438155, 0.052102699011032066, 0.023636004022721733, 0.0635519019727196, 0.06213139569652932, 0.0008687786913859391, 0.04330667653786285, 0.03542293421924114, 0.021106023441201875, 0.04894133311297212, 0.05901258412216391, 0.02627164438100798, 0.06884085852652788, 0.019243519453864013, 0.040986351402742524, 0.013341770291195383, 0.0029908735845570584, 0.03058988873713783, 0.047309198549815586, 0.024006933672353625, 0.061608903376119475, 0.039904098226023574, 0.02867233520373702, 0.0758464408240148, 0.03351700059803469, 0.018915642851165364, 0.05045113120494144, 0.03337032846840365, 0.01731735870375165, 0.017547994452927793, 0.021465562184208205, 0.020981956705717102, 0.02551571905080761, 0.03755908120157463, 0.033736242047910175, 0.025804179554272975, 0.03911824950150081, 0.03539390988381846, 0.008883690893916147, 0.039250957380448065, 0.042456919992608685, 0.05058325554377266, 0.025106964466561164, 0.03174175960677011, 0.0026395531728797194, 0.0381624888229583, 0.030486245905714374, 0.09008467037762914, 0.03283290498490844, 0.05154959119058081, 0.04068769421428442, 0.0460085283432688, 0.006200240534131548, 0.030353018947477852, 0.03361907262088997, 0.03324108111805149, 0.028426250908523798, 0.009370677173137665, 0.05654623146568026, 0.03330603727538671, 0.04645258880087307, 0.007256351028835135, 0.0543855724057981, 0.07097160776278802, 0.06888577075941221, 0.012999321300802487, 0.05357020401528903, 0.0373882566179548, 0.011152015649713576, 0.042805809128497324, 0.06928672388728176, 0.04601399055016892, 0.032037818006106784, 0.004921762239454048, 0.022460598165967634, 0.014722924080810376, 0.0694914786145091, 0.007555394982253867, 0.06383508177740232, 0.025094267380024706, 0.025596098309116702, 0.02296192358647074, 0.06310092045792512, 0.02595587623571711, 0.0705994109490088, 0.03196345056806292, 0.00429893409766789, 0.020649310001837354, 0.013677311795098441, 0.03962547817666616, 0.02796545608102211, 0.028613920123981576, 0.034657757064061503, 0.04202803157802139, 0.039969651494175196, 0.03144387255555817, 0.07423251814075879, 0.03998416875089918, 0.010215675491573555, 0.034469395742884705, 0.04938545124605298, 0.041687715732093365, 0.05357878069792475, 0.04819218634760805, 0.0067398891884035295, 0.04999442285458956, 0.06271771102079324, 0.022725486362885152, 0.01963399939372071, 0.06788667544190373, 0.07238733715244702, 0.039630594330706766, 0.049480734526046684, 0.026070390894476856, 0.0490818611080093, 0.011800085294193454, 0.007392913834857089, 0.05441552294152124, 0.04306533859510507, 0.04880076101315873, 0.042863206405724795, 0.021876806991973093, 0.005556990608706006, 0.01635387120768428, 0.05781651008874178, 0.013269321410916746, 0.01957584046093481, 0.012599085723715169, 0.02905631477811507, 0.058421057648956776, 0.05765289493969508, 0.06987869140825101, 0.06867353857627936, 0.015531040628307631, 0.038159971458039114, 0.09450966186289277, 0.03507573802822402, 0.020642582327127457, 0.04756720809798155, 0.034013579666082344, 0.03686643943988851, 0.02486205573326775, 0.012114068044216504, 0.0126516950882173, 0.02393841350983296, 0.03607604453074081, 0.03426299217556204, 0.06935671477445535, 0.027476576689098562, 0.010632839669207377, 0.08921533809708697, 0.04708159415583525, 0.012712512181938758, 0.024853845459542105, 0.03473110330690231, 0.021955754541392838, 0.008386177143880298, 0.057204878622932095, 0.015157919310565506, 0.01929941716870027, 0.0474840502387711, 0.09553412760474853, 0.01829386898316443, 0.05961776950529643, 0.045851091255566905, 0.030979320340390717, 0.0407761107198894, 0.02842467840361808, 0.059523778834513257, 0.024586166787360395, 0.06445985646652323, 0.0544098198546895, 0.03195715376308986, 0.04599933758644121, 0.012353631617900516, 0.026272424696279422, 0.06961402203887701, 0.0447123364678451, 0.03291305693398629, 0.05601608866293516, 0.06200766483587878, 0.007595649920403957, 0.03694409438009773, 0.06882555077650718, 0.014219133033683258, 0.06509748939424753, 0.04460194899833628, 0.028206191823950837, 0.023684034124016762, 0.0481996943375894, 0.04232838510402611, 0.024259255400725772, 0.010302846885419317, 0.03124638833105564, 0.044965586092855246, 0.04224387017477836, 0.03708705831585186, 0.04742482091699328, 0.021269655553624034, 0.09668466515306916, 0.011993721376971474, 0.03038791600348694, 0.037316654210111926, 0.003734522731974721, 0.054401931885097704, 0.02494591078720987, 0.01341046263197703, 0.04457977447392685, 0.012019258042398309, 0.00999144765747977, 0.029050672759435008, 0.00984779161600662, 0.03189161406563861, 0.010427299537695944, 0.02280836602273796, 0.05637172243690916, 0.011884599375272436, 0.011543382774107158, 0.020263559451060634, 0.04372649293925081, 0.0161324143409729, 0.02319820474700204, 0.019674721672864895, 0.03622909149687205, 2.6286792847583585e-05, 0.016023214307746718, 0.05064054086272206, 0.023126699030399323, 0.024936309516695992, 0.015975375892594457, 0.015937411858301078, 0.03257203880431397, 0.020221839725439037, 0.03567776143816965, 0.0435648455417582, 0.1022723467488374, 0.030651771130838563, 0.023332420670028244, 0.03297657798975706, 0.05665117029898933, 0.05603377128552113, 0.026863710289554935, 0.0034924303430930843, 0.0380062052447881, 0.14266166197402136, 0.19038934021123818, 0.2516677427504744, 0.17428801634481975, 0.14529538207820483, 0.15134876939867223, 0.13000010353113922, 0.13462579888956888, 0.23178229693855557, 0.08040527334170681, 0.1415306662342378, 0.12863536604813167, 0.11834584389414106, 0.08071207973573889, 0.14322118195039885, 0.143497318561588, 0.18713105576378958, 0.11982579662331513, 0.10168811452708074, 0.12386951249625001, 0.1324868800916842, 0.1358968171158007, 0.13739662377962045, 0.0549287668296269, 0.18654666069362844, 0.08932103349694184, 0.096420972874122, 0.08287205347525221, 0.14048887070800575, 0.11670647614768573, 0.1129432123686586, 0.16168470334793839, 0.10299674394939627, 0.08838920814118215, 0.12740664769496235, 0.13480698131024837, 0.08843937223511082, 0.09227734950504132, 0.14581417638276303, 0.08824852069041558, 0.09102613093065363, 0.10206735453435353, 0.15173770567136152, 0.24093692856175558, 0.20710240410906927, 0.07506046657051359, 0.13449413595455034, 0.12903620382504805, 0.11427714436181954, 0.14552107639610767, 0.15874452968793257, 0.1383516482476677, 0.16295270887868746, 0.0684226570384843, 0.09018296296043055, 0.1119161139109305, 0.1735816885318075, 0.09658886957913637, 0.06504169345966407, 0.11534469707735948, 0.1748837429497923, 0.22773809252040728, 0.13122275578124182, 0.20353032435689652, 0.26640185926641735, 0.0871701996241297, 0.08130931947380304, 0.22182879889650003, 0.11608689225145749, 0.1350042721522706, 0.08373166913432734, 0.13038110094411032, 0.10997393634170294, 0.09712300556046621, 0.12476393021643162, 0.13684258636619362, 0.14196757493274553, 0.11114018876105547, 0.10783440686230149, 0.20039527543953486, 0.20030099978404386, 0.09154485059635979, 0.2462220921048096, 0.11407143968556609, 0.07455763819494418, 0.1519635764083692, 0.12721705144005163, 0.16265179216861725, 0.12893542780407838, 0.13739399106374808, 0.1668645175439971, 0.09473589900881052, 0.17745146873806203, 0.17315433360636234, 0.11032721559916224, 0.17316023686102458, 0.13738522439130715, 0.10380983924759285, 0.11357112867491585, 0.111580001589443, 0.15754790604114532, 0.12684278509446553, 0.08281501582158463, 0.17919124609657697, 0.11842308832066399, 0.19087017726685318, 0.1341418270021677, 0.14117959221558912, 0.10091698661978755, 0.20189481068934712, 0.09105003571936063, 0.20343227604670183, 0.21172143625361578, 0.1250554152897426, 0.15018616749772004, 0.12177205218800477, 0.0790063716205103, 0.10470892528870276, 0.14177860293005193, 0.12499726483864443, 0.17787031483437332, 0.09352943660425288, 0.11311387071119887, 0.08679314449961696, 0.09079830601279225, 0.1614271585962602, 0.1816424945635455, 0.17030103957014425, 0.24174872785806656, 0.12004215429936137, 0.11415829216795308, 0.1501496894551175, 0.0938428994268179, 0.12378930965704577, 0.11857977562717029, 0.11724393016525678, 0.12825801915356091, 0.07681323787463562, 0.09380871483257838, 0.13612948677369527, 0.07885123137384653, 0.16398049944213458, 0.11132103191422564, 0.12605839861290796, 0.1114214618823358, 0.09035907672452075, 0.12177486132298197, 0.10206692705729178, 0.2009436267295054, 0.19244618341326714, 0.13329354966325418, 0.12367223522492818, 0.10044191032648087, 0.06873248969869954, 0.0881370102454509, 0.2141779094402279, 0.09184675796755723, 0.08958743313061339, 0.1267651335469314, 0.10173230072749512, 0.07525832738195147, 0.14147657342255116, 0.07154919034136192, 0.08097057443644319, 0.116466668301395, 0.11836823554975645, 0.147281535501991, 0.1591897572257689, 0.16964881813951901, 0.07843514012971095, 0.18087519359375748, 0.10299544116216046, 0.1984255425632, 0.13595213129052094, 0.07639825942793063, 0.13938922328608377], [0.04752520678032722, 0.011224744425687407, 0.012520045723899134, 0.007132317371932524, 0.02178906393237412, 0.018276335638282553, 0.045761290538523874, 0.013381274599981095, 0.03819701268470713, 0.021072269716699208, 0.01426578316438411, 0.020327379062239612, 0.04958124252568398, 0.010825876096662666, 0.04824043358010905, 0.03380514049370374, 0.02788998432723539, 0.04182531584852508, 0.01875227876007557, 0.013860949664376676, 0.022386909262942414, 0.05338133718552334, 0.03399386143844042, 0.020850068157804862, 0.06585799822849886, 0.026961763688762273, 0.06282590342951672, 0.014075127546675503, 0.04483152114387069, 0.030460817805890526, 0.025075200546000685, 0.02098157163709402, 0.0224732664147658, 0.07361138039933783, 0.03909637353249958, 0.1176034180181367, 0.03757492499426007, 0.06987094253833805, 0.016261941587020243, 0.042539585913930617, 0.04283983426700745, 0.033866782007472854, 0.0423511329905263, 0.0489711140149406, 0.12430424988269806, 0.02607542392797768, 0.020797096625236527, 0.04662336927971669, 0.05419999307819775, 0.029655077827296088, 0.04341813609270113, 0.013824929632911724, 0.03609414445236325, 0.007391983393712768, 0.009796935416358923, 0.05360042257234454, 0.03549089289403387, 0.10778156934039933, 0.06523635158581392, 0.04920654191768595, 0.019387645380837575, 0.021274546094770943, 0.028394539574427263, 0.03394589240529707, 0.03488872359905924, 0.04727114291329469, 0.017834074994815246, 0.015115914600236076, 0.039927762134798934, 0.029859150626829693, 0.09370262588241271, 0.040083485921578746, 0.13287323793130262, 0.014863148431426712, 0.026680775552189777, 0.09376298157232148, 0.0505963919817337, 0.03940497125898089, 0.06470545221652303, 0.009710568086510258, 0.009572901812914227, 0.00428205426682585, 0.0396784717616226, 0.018660980176978877, 0.044007491253848584, 0.026306229310908487, 0.011900269293359347, 0.04659304894240839, 0.05923610712800707, 0.014551210616316115, 0.052022757407810004, 0.02703579525197191, 0.07681027946195432, 0.015418488632089325, 0.023284877417609096, 0.040534019603260925, 0.005265290100526596, 0.01632308098487556, 0.04739986439900739, 0.01778411615772971, 0.06477185365344797, 0.024458726036495397, 0.0262430678786976, 0.025002283476559178, 0.03802949595930321, 0.05566472287422844, 0.09655598098678247, 0.022248790067221438, 0.04195139104766505, 0.02757838917230921, 0.03445538738742471, 0.05335684885670032, 0.06591763467128788, 0.03321960548471127, 0.03558615581797702, 0.01536063673639936, 0.018521824519016912, 0.06399193871766329, 0.024972305799435292, 0.10198054954941783, 0.01912457396143249, 0.038171811894114525, 0.03540515660175255, 0.029042157144950967, 0.007226719404570758, 0.05529237678274512, 0.020929305780945078, 0.02446021542086133, 0.04351930566398161, 0.02417910684432302, 0.011315143101715615, 0.0373332342132926, 0.04257485955687506, 0.021744662297091315, 0.04633341430287276, 0.02525072398462466, 0.025085726320477467, 0.036072071708206616, 0.02203282424514847, 0.06533557376159088, 0.014595856524205633, 0.006350391427986324, 0.05266578129625746, 0.02248978704613234, 0.031908404414675066, 0.08881071409476654, 0.03874904841982892, 0.025700831885582635, 0.05711886752396822, 0.04108530216451202, 0.02613266514215086, 0.01538275188899466, 0.023795162893033454, 0.04310714992295418, 0.07924823542790753, 0.033502680116466114, 0.04689798936513918, 0.048072329921914, 0.07520130329898425, 0.07070330823106424, 0.00664318140895505, 0.07359050866216421, 0.01617913317334439, 0.05875216916735683, 0.044046218640037944, 0.020922812200816612, 0.0258778905096863, 0.04366463090160063, 0.044543466065078974, 0.04473300464451313, 0.048944162603999884, 0.031827407689499, 0.013873757861022438, 0.020782464017559375, 0.03520136200157659, 0.06012481836868184, 0.053282304999551604, 0.0016314088487498729, 0.052643589808472564, 0.015437401099396604, 0.020944235247692893, 0.02600498520769179, 0.17140615598431655, 0.01771001674101821, 0.04936488824231284, 0.031652369403413365, 0.040049755945801735, 0.02252640588475125, 0.08259431552141905, 0.025941645660038506, 0.08070137245314461, 0.010292701090552976, 0.07441175316593476, 0.09052012022584677, 0.0598221646089639, 0.026229349596958076, 0.01978851369182978, 0.011957342570115412, 0.046810492274484465, 0.027725917952401296, 0.06346609443426132, 0.022087061245526587, 0.052543970689709694, 0.021760463681338087, 0.04385212030527847, 0.02794063527003995, 0.026961270054536204, 0.02068310443844114, 0.013231918864351298, 0.14197870290705136, 0.033238998015544245, 0.06535548197903804, 0.037495326051222425, 0.05134024278127721, 0.03682480453114424, 0.03410830315468567, 0.045565947092005184, 0.05501214521271842, 0.03655045246705413, 0.09249368003968682, 0.00363452236134825, 0.011534233577549458, 0.03791106106447322, 0.058987505467874665, 0.02709424086580319, 0.00748014884136085, 0.030424156558832953, 0.03576014576745885, 0.004550316479123596, 0.02655298705212772, 0.02356427099688777, 0.025675965273486714, 0.05629381983141814, 0.032533518371305296, 0.056767847788121016, 0.008521631393315536, 0.01701739533538265, 0.022962435880409818, 0.028904648630746772, 0.027648697274604013, 0.013900389512335616, 0.07766939300511565, 0.05109938659838267, 0.04279750046719398, 0.008275910962506064, 0.007237162058507758, 0.009755198727361858, 0.06034435837396553, 0.014312211923035128, 0.024721436136003052, 0.05171566263639501, 0.028651935048401356, 0.005449190478040171, 0.03979550548163908, 0.048585075086780956, 0.014867497840896249, 0.029493620419608693, 0.11512995431465761, 0.05753987814698901, 0.03170214673238141, 0.05118398295183267, 0.05877443190131869, 0.013396954696093286, 0.024113081994333437, 0.033904047150697024, 0.014496890495398214, 0.015838128614372442, 0.06595205675278391, 0.03670828649774194, 0.020901731814124754, 0.05607699057353394, 0.09169627925647156, 0.033699669010405026, 0.0026767710306947784, 0.021118272694626024, 0.03084423758887819, 0.02780075527594558, 0.03744624422064849, 0.023948482969509702, 0.09153241304946796, 0.023938038619235158, 0.01940757904334792, 0.06636902330709354, 0.04602674361584442, 0.06883131832416568, 0.033214082209659476, 0.07269168046436139, 0.0062486459501087666, 0.04369512426533869, 0.04901455382683447, 0.009683799880024577, 0.010747320401216192, 0.04640522366389632, 0.07475194348288433, 0.04655493563041091, 0.025961642087038075, 0.029980951055352176, 0.04602769695754562, 0.04353000955390079, 0.028403416508808732, 0.0123534636804834, 0.009376538867530013, 0.045569634929831536, 0.06829712127468415, 0.024897186883858273, 0.04890623588913253, 0.06549158931842872, 0.06795695131378514, 0.026183806326506392, 0.040400877461901734, 0.03819199152556913, 0.03963432966598442, 0.010848709648208959, 0.014997868166704263, 0.04064901093287127, 0.050814062623041015, 0.010345458036421664, 0.028510582633316517, 0.03712457451703293, 0.008643953445633607, 0.08787055632897786, 0.036603764963469336, 0.014385678605841739, 0.027835911871599298, 0.04767012828961015, 0.02983431624514716, 0.09583023350153651, 0.018251865969172547, 0.06443298647978477, 0.056447385876838646, 0.0861329027850713, 0.012423516483977437, 0.04231048535023417, 0.07286877131887845, 0.028087487211450934, 0.0899042139894196, 0.020906668156385422, 0.010409508349506982, 0.01135674917272159, 0.03585396680448737, 0.027193843021190593, 0.01730810009342219, 0.06341861733900649, 0.04389250670958843, 0.0044417186457264635, 0.025458562653511763, 0.01976192190444895, 0.058281815477779934, 0.009246036227393364, 0.016464404562222104, 0.05316077259236148, 0.019849176418834498, 0.1602782223905836, 0.05717768972473485, 0.1157768831721374, 0.0640090513708336, 0.07443426017250333, 0.12211338244378567, 0.25059058197907036, 0.06824551868651595, 0.16336612669484957, 0.1332226970366069, 0.11901812281991754, 0.12373432117913451, 0.21227681716637953, 0.11558181792497635, 0.1814650712268693, 0.08761060277798347, 0.1768671822335039, 0.21481368318200111, 0.11447932065597602, 0.08923858470682587, 0.10878272740436451, 0.17611008643039636, 0.08893020411155053, 0.08834696933627129, 0.14885433896311692, 0.07904313464782067, 0.12481506461543695, 0.12584152525024755, 0.17709830483155592, 0.13583573539342197, 0.11939206346869469, 0.14222752169838973, 0.13732623255678586, 0.23115497774311475, 0.08951858218227114, 0.27083440284643856, 0.09516457707754203, 0.2585839959127562, 0.14894173427351884, 0.12852903961070947, 0.1366709034357752, 0.11285831406712532, 0.11891721109194414, 0.16059661816273416, 0.1459962408989668, 0.12149282145713057, 0.18154220708778926, 0.15723518282175064, 0.17527339846960135, 0.1436376396034445, 0.10772531200200319, 0.08265875599214009, 0.0825065334460565, 0.1128372387694461, 0.32671130022832323, 0.18306954870266573, 0.21172020131988184, 0.13207884984357016, 0.15211275911756925, 0.09856269402163369, 0.158505346093859, 0.12666705809533596, 0.07359340600669384, 0.13258038221725396, 0.09194784611463547, 0.09908112191728183, 0.1587601631347622, 0.06799771769770555, 0.1067659720512373, 0.07902856650097029, 0.17774446015911444, 0.22739821432956628, 0.13878082164696284, 0.1754730777548892, 0.08993685152381659, 0.18956665721322807, 0.1756236853876284, 0.17047739082149097, 0.14425570358123097, 0.05671942413651517, 0.09370384724544627, 0.21862652072949068, 0.16281876606600626, 0.09953298552760056, 0.1716139776898282, 0.14344112229134354, 0.1287012653691428, 0.14305233529635838, 0.224117782499109, 0.10327270414148058, 0.17376068606972694, 0.19009229115077428, 0.12105370073446206, 0.06579735076853208, 0.09609172732702323, 0.16304276404636248, 0.11232996598950454, 0.1557410487106868, 0.13063390952135834, 0.1041730386870248, 0.15807282073157175, 0.15591035676853998, 0.16913258869733128, 0.2023321400795664, 0.13953590898641519, 0.11447814000504357, 0.18232641715024198, 0.133502687726702, 0.19994927437177726, 0.1646924183837005, 0.22234247704701765, 0.13046262014125073, 0.11445645402584757, 0.10550822596997023, 0.10705997448946748, 0.1041745450347662, 0.09753562270530633, 0.20893043173210962, 0.10483885117407356, 0.24800558068922587, 0.1647009543542351, 0.07863001538706677, 0.2577625885605812, 0.13029137147324427, 0.08262910401182515, 0.13455619476735592, 0.15817921502249582, 0.25078252596514566, 0.20667317642697267, 0.1125379234020199, 0.14161215828997747, 0.2079888829695327, 0.11549511472029345, 0.09831044184310095, 0.12432024973843779, 0.21593911493463175, 0.09376899339258671, 0.09833335597068071, 0.11448393469410283, 0.14250582962163857, 0.14522192387708596, 0.1666600342307772, 0.11862250976264477, 0.08814990241080523, 0.31069252693227356, 0.22801246494054794, 0.10109151939728431, 0.14299136213958263, 0.15210537665656634, 0.21070273805941853, 0.12356071120926312, 0.18149181907730444, 0.07940231037459203, 0.12081903618361269, 0.15823413564690522, 0.25475985397185597, 0.1764820593276194, 0.1598531880549022, 0.15095475768404348, 0.15993402871702397, 0.06567672081291676, 0.19588483603937284, 0.09124296358121292, 0.1266846592937197, 0.11093960023884263, 0.1438009086996317, 0.11137049033173493, 0.14919530280998775, 0.10430054220237903, 0.15706843962626799, 0.13828732312789985, 0.1771347557327577, 0.17640819400548935, 0.06324558412390095, 0.09235664989267077, 0.22580854248787674], [0.04408543796411582, 0.022837020556575487, 0.022171584656462073, 0.05816020843173776, 0.041706928451146395, 0.01602342295726495, 0.04265386817444648, 0.009673062063354467, 0.024934991462422267, 0.04587872459420136, 0.028563711925276687, 0.038193721789866686, 0.0168129680013018, 0.050933491571673324, 0.04391007737389632, 0.021224385393517356, 0.06981976064188139, 0.03871957964396902, 0.030834568464862447, 0.04745674938229578, 0.03127801145559975, 0.033467715206955156, 0.02200540464504489, 0.05640298933056848, 0.012512531796736377, 0.07490753156266042, 0.013959779986180365, 0.031698072129594426, 0.02291700796091131, 0.020966372452676296, 0.016615180132378424, 0.05338905891403556, 0.02200857170724443, 0.06023753660597971, 0.02077784319408238, 0.03634044587878244, 0.0020387604558241685, 0.04423076320173485, 0.022889598538833003, 0.04166763448821647, 0.04353771771171263, 0.04885992926678487, 0.03224919523511614, 0.05408215529418417, 0.00655741458259789, 0.04508412276793804, 0.04432744426386697, 0.0470215268433094, 0.027490043912881186, 0.007447197484517736, 0.032472470575677495, 0.04361523694491812, 0.04217087337747216, 0.03149012828777943, 0.02797910650925977, 0.06086530363453286, 0.06795708702078887, 0.026508076515580927, 0.020907423026593666, 0.01655161497183144, 0.037034560061459026, 0.04562290332147053, 0.03678470989689231, 0.07367185822554997, 0.04016484905566488, 0.029779538113091673, 0.0396354967462165, 0.017102938245183656, 0.12777342301394257, 0.01757274571407054, 0.03425367928243109, 0.029453708989811794, 0.029992126527109315, 0.049490990582853556, 0.022682619913082038, 0.03186178566621883, 0.0314914005409394, 0.009154117632923382, 0.011689510379385735, 0.01593517099640199, 0.09531005498554025, 0.036950109593038044, 0.08525818972183125, 0.061306514245058806, 0.00806630470989538, 0.05975914227643183, 0.017388163832947612, 0.006126266646398497, 0.037179844586976936, 0.07481434834854943, 0.03312092613694923, 0.03311375402180212, 0.05519024708441325, 0.047343525636409006, 0.040595043650163073, 0.012268549263743418, 0.05641228186764887, 0.03348669383142676, 0.015512589564813035, 0.010478841057712478, 0.06632026378065348, 0.040169256140611, 0.04406984522938728, 0.02710402025175946, 0.01790502092002758, 0.029694246261247566, 0.032188771691705496, 0.06414321810007095, 0.01037104135113103, 0.019159357362825955, 0.018856847791799476, 0.042276853762034855, 0.026518590415694883, 0.04292336871315326, 0.0686099191329309, 0.056212154749248705, 0.018717729453263537, 0.02194853492879442, 0.031903217014457495, 0.04191248045702066, 0.031406047620943615, 0.02019148037236716, 0.06393696381045239, 0.01825720095075667, 0.018466449276145016, 0.019946490214871507, 0.10800127897943769, 0.020949856910322393, 0.017895458665277277, 0.0867074251707111, 0.030555822886526585, 0.05767358347241368, 0.03593671415001154, 0.008875954746534782, 0.08313901629298925, 0.007554826709175748, 0.014785790350288153, 0.05292724798034344, 0.016663033814568604, 0.012845411747028785, 0.014387140848806925, 0.028670676185616424, 0.022204678505659103, 0.05633963451587728, 0.04296714439988136, 0.05877037426190717, 0.00720643629652581, 0.0853578190186194, 0.0228977341737066, 0.027831028115802577, 0.11952261360628263, 0.051630465779453516, 0.05127859787483301, 0.024554236625720347, 0.02742318107214357, 0.06304340782974448, 0.023970849180061902, 0.0236407147520887, 0.010685189494064875, 0.07169868517667055, 0.04853964038193226, 0.012285387110231178, 0.02064482488536409, 0.04308110774893846, 0.011029464591826712, 0.03295684279873967, 0.01689962879754603, 0.05118705332279205, 0.058135726888264926, 0.06229280560676541, 0.027325304092041085, 0.03838585576574717, 0.05225257382595113, 0.05191231904817479, 0.015582880703732371, 0.025174217464934503, 0.0312312977122409, 0.031210090100233043, 0.028021228266879916, 0.030237379616924694, 0.013420169075418795, 0.044864938993539126, 0.04762628814205527, 0.025558024012882794, 0.023357165145820806, 0.011529932513699999, 0.06056128601942744, 0.05723552804972444, 0.046152041892388036, 0.02945924922823906, 0.03103126898141844, 0.034246245931301794, 0.10128435904958419, 0.01580952836333641, 0.014857806664492403, 0.027555542898231318, 0.06311063707939216, 0.04416604792433126, 0.05562467234475272, 0.09842775376247508, 0.008972080258120383, 0.005919466984258699, 0.028526049839066606, 0.057504417906914435, 0.029958915630621568, 0.022890869095655422, 0.023555095507098094, 0.02911758649029902, 0.02288065375094967, 0.040292220256690464, 0.03860995891903128, 0.02415828769361334, 0.020421524099739533, 0.04133235676480191, 0.027183924535555497, 0.02396633183317525, 0.017014360587511743, 0.040558694529214075, 0.04262140027380415, 0.0483814297643091, 0.007375137913706047, 0.06276765119816576, 0.021018668842901076, 0.0399535837849336, 0.0346464119585497, 0.022691352658772042, 0.03662977321073413, 0.041513640965734205, 0.045128712696688514, 0.0037514602382933454, 0.017644739975886684, 0.01645834694084312, 0.08612290117889643, 0.041826995222696235, 0.04269022747342076, 0.044469817874154875, 0.022813315935699, 0.014969980377437813, 0.030471531873834983, 0.041235909797251225, 0.04576616920530796, 0.050956032504992824, 0.031102420163473914, 0.04539497662335634, 0.039356435649096966, 0.026300833261172687, 0.03350743664694684, 0.013443603130456592, 0.0323443495934563, 0.02510849286669067, 0.04071813329522099, 0.016919855926451937, 0.05839248453932149, 0.051462769242269654, 0.010209657734126916, 0.034186575561761856, 0.04970645598535027, 0.0032079592014529873, 0.010101895346971495, 0.0460498477332294, 0.01892497101133423, 0.05811319274029561, 0.03881147364154458, 0.00949222399919693, 0.05382340614284788, 0.07159716955253057, 0.05360804930595415, 0.055319284088909626, 0.03699483183611717, 0.02055868486474667, 0.039955765275018554, 0.007856953756085463, 0.04983929617862616, 0.08492759389004537, 0.023687262254367982, 0.07252191100269556, 0.037740039705697975, 0.049209683534822295, 0.008862396768693413, 0.055533864003207, 0.043991779775491784, 0.01384826869304691, 0.019422557703884583, 0.020187020700957094, 0.017594273933874707, 0.039899250093315325, 0.06842735928616353, 0.014440756989642978, 0.04870668552549822, 0.02226779074408114, 0.05544838555423277, 0.023515273983191167, 0.014018148416653275, 0.037067224737256765, 0.010620056917624814, 0.05738207804305213, 0.010029152152128518, 0.03848176669063313, 0.014616684156603046, 0.03902666763003383, 0.03192434320226312, 0.051804615184664726, 0.03301212643938405, 0.03632879203983715, 0.0182475708425045, 0.04154304528076734, 0.048601139403347454, 0.049582409605916054, 0.022715640819764564, 0.01762275374494493, 0.0201664339484913, 0.030779030373586074, 0.028342087121148194, 0.0167289789366935, 0.015840461078499044, 0.01659509040681379, 0.013207976756218289, 0.020991910814440677, 0.05400925688445568, 0.03383579331317118, 0.010850607001754855, 0.0134519575928737, 0.0030843373304898186, 0.033137713093310595, 0.02544127018856151, 0.06199203138904912, 0.0283584499931229, 0.015792074746319225, 0.016875995422846506, 0.03618913256962385, 0.04129957673805101, 0.030485923601580516, 0.018342165409454277, 0.06310853362083435, 0.031879271513649395, 0.0374436284681516, 0.024469207706195966, 0.01969910822143512, 0.05256598236571465, 0.08963382456983839, 0.01909848428996546, 0.012028442862044488, 0.019507038706381406, 0.11019010402794395, 0.043976288821016035, 0.03287923874865685, 0.021098849629717212, 0.011703618818760982, 0.07461021787353925, 0.013587645088721598, 0.015783182544899837, 0.05219256758157696, 0.09022319330168621, 0.12300307756023747, 0.10453307615326983, 0.1368960684963635, 0.10826689151248761, 0.21925118006765842, 0.17476717063358851, 0.07788351830095053, 0.09963108133524656, 0.07345537841320038, 0.14587144473833696, 0.07606978741075311, 0.1286259615527732, 0.14826378279498645, 0.22693032372210706, 0.0976312215040837, 0.19004206598869391, 0.10071738197335176, 0.07610732396798474, 0.12680773197540215, 0.17747725306877069, 0.17019737298999513, 0.09434675917561565, 0.18480537698737212, 0.1398900364126478, 0.1663688477128744, 0.09872345932360206, 0.0628271180072001, 0.11839058649327074, 0.08625331560948066, 0.15996794189725602, 0.09986070437090737, 0.16399708283799036, 0.13674270601144858, 0.10177761329604046, 0.18684039850320133, 0.14833197556436062, 0.15237320799912724, 0.08941207932574408, 0.13930816549275601, 0.16479696705937386, 0.1213736707078559, 0.10431900514023644, 0.1545731406658888, 0.05703868504081454, 0.09640350738274199, 0.12333585827478341, 0.22437874706728117, 0.07412051236523048, 0.09076123085937329, 0.1422571193959032, 0.1784449661416667, 0.09670215778584991, 0.09715422495667424, 0.08318589627742767, 0.1280298549681902, 0.2252752682460206, 0.2119835950434208, 0.12385386547871999, 0.10092204170567648, 0.12171915359795094, 0.09665003951106753, 0.24883952736854553, 0.1215977772538151, 0.10595202858426742, 0.09806528714086328, 0.12572272733918258, 0.15065800717898778, 0.2577175609767437, 0.07711429029170956, 0.13106665201485157, 0.10456360344375883, 0.15505039505660534, 0.0925186365576727, 0.10710215901157685, 0.12770920645977768, 0.09533373585769109, 0.161934512800404, 0.0957812364878399, 0.24974998565656797, 0.11857607082596847, 0.13670421950519085, 0.1121342968461769, 0.14757232846958296, 0.17998666555753776, 0.12446218569363866, 0.24100657339606965, 0.043713186867535114, 0.11355847399681807, 0.18319133216781275, 0.15145208314061165, 0.14401942411703722, 0.12559791760785238, 0.10189385313008513, 0.09467130247503519, 0.12021033598908357, 0.10197261068969965, 0.19121685437858105, 0.12500935633267674, 0.19417526705988816, 0.2285184892160552, 0.2681417316198349, 0.11509093855108533, 0.10510068426706962, 0.1893532443791628, 0.14173661518309796, 0.07142102864703961, 0.19248720764049462, 0.131178189601217, 0.12597411099289144, 0.15842538752726146, 0.2534973717161587, 0.07715688193483011, 0.11449256565954004, 0.11264166462102107, 0.09660812640296561, 0.10533253968294178, 0.08696638127522809, 0.1379814124000924, 0.21034534009439604, 0.12149879256529467, 0.1274636582072292, 0.11124544311314821, 0.149471697264484, 0.11928463780454227, 0.14245978423527308, 0.1825781672128609, 0.10118674500180141, 0.07406060450843402, 0.1591098393712725, 0.18682533502578735, 0.1639674851404769, 0.11031310885612454, 0.14444171717124327, 0.1196835349713053, 0.10366685156311307, 0.10143481740461928, 0.11134690445448671, 0.160074186910476, 0.11030973653708186, 0.1067133177337902, 0.18963404931128025, 0.10508992270167385, 0.18294969227697166, 0.13111420374895844, 0.15158458745905332, 0.07106324391705648, 0.1924027164599725, 0.09515910129994154, 0.1725072961832796, 0.18641773904008524, 0.08489986894918339, 0.10870930991534676, 0.08957043582839624, 0.11778603893305574, 0.11406795201557023, 0.19682255786444458, 0.11670957026737076, 0.1281643541795867, 0.11970968571092401, 0.07125865521707705, 0.1308429797313043, 0.11862909155232565, 0.15732869851802075, 0.10631363346640553, 0.155885943078569, 0.12311538867652416, 0.1961250781480755, 0.14080470161778585, 0.2114396813724722, 0.09446498033191476, 0.11210509948432446, 0.1915066973971469, 0.179371356431927, 0.07581452253673758, 0.11383300248001303], [0.03185856941023043, 0.03366532835311123, 0.03568296919443777, 0.04836519242131284, 0.06481609413666384, 0.07442560885101557, 0.01909752585925162, 0.05028827601511564, 0.013981691578270068, 0.012454227827090238, 0.00801066992737885, 0.01426404102572373, 0.06672908791473933, 0.04640931183738368, 0.043445165535168986, 0.07266402337700129, 0.04097793756851128, 0.04047380640570607, 0.06009810444499765, 0.032107971741684845, 0.11883516263748918, 0.006451738266540425, 0.03238882077857852, 0.024720038353864635, 0.018524282512121966, 0.0389660880235689, 0.028815936962408677, 0.029303827389542545, 0.005383952728672219, 0.0405801667698792, 0.0224623725350414, 0.02922303761754717, 0.023585809394717216, 0.0271765200221645, 0.022464404747422253, 0.03186590437378202, 0.035783188816692145, 0.03673654408859355, 0.024796712810971906, 0.01968539842138333, 0.031067136342504194, 0.045798749064228365, 0.038454014608370404, 0.017342165944033434, 0.07181862981191703, 0.015225431848583477, 0.04829122192625489, 0.04593524316857968, 0.03795799533171313, 0.07482135082994189, 0.026410493001874005, 0.05132419882076127, 0.033854588733187745, 0.03635391140622752, 0.04672678140923381, 0.0505021061482174, 0.045679499927375994, 0.017323845498529927, 0.05665761638166649, 0.005992820012449686, 0.014989751191543681, 0.02488326164893806, 0.021352940638150488, 0.021928263695112298, 0.023662439747048274, 0.043728732104812346, 0.014033419695416731, 0.053482649249157736, 0.03581424875717078, 0.003921921805678201, 0.07256869599223137, 0.08952834630118948, 0.03834632431556072, 0.10113923397979566, 0.045540033839643, 0.06463731372995035, 0.005852039687202445, 0.09346711316279002, 0.01992148280675922, 0.016247646550514867, 0.051213624754122326, 0.030279455573431084, 0.05051553435623646, 0.0310314386151731, 0.025078871420451572, 0.012762194516004195, 0.012249013392387756, 0.017205924593976567, 0.07201063486614398, 0.029411951944764172, 0.03891575090321047, 0.019148865515100102, 0.013283524845194603, 0.04179878852197102, 0.02686992906300085, 0.03364131499880126, 0.05952475592494011, 0.0246191215368786, 0.021405666201774563, 0.0420055347494781, 0.015752431337854693, 0.013211038645489939, 0.03447290037625602, 0.06108022281633956, 0.055023493710905313, 0.032727175658302646, 0.04125780272962792, 0.007632099125268204, 0.029763351660221815, 0.03711336851119995, 0.053350457056824646, 0.020659130099894743, 0.039326478328023634, 0.04039675536166344, 0.04715035350194999, 0.032022554360862286, 0.026042772822880318, 0.050407229989234886, 0.039566109755209515, 0.013857933576218784, 0.08920073602348566, 0.046838478451328616, 0.046227260891880305, 0.04741151145260249, 0.025650296293731247, 0.05398668541706034, 0.07546075473406486, 0.05198903761005827, 0.07275773584842682, 0.005902392498683184, 0.05429419409483671, 0.05393160194424646, 0.02033974536295448, 0.050557881726750305, 0.011467441134820027, 0.005871360123689685, 0.017388950933569243, 0.07275626342743635, 0.00897061886332397, 0.03570446179115346, 0.04435303521209529, 0.018547837855294347, 0.03823161118530801, 0.08917057514190674, 0.019822269112669995, 0.03282588893281562, 0.028864089200007062, 0.04323136593614306, 0.08499971537717751, 0.025804313564939157, 0.040152886483286104, 0.029289551012750183, 0.033320035452821424, 0.008003127162477799, 0.00978153182326683, 0.050906119469021044, 0.010533917745176171, 0.056739257715110264, 0.021448608986767273, 0.05593084091586726, 0.05383210835446205, 0.051722950102495294, 0.019941104343160987, 0.039471114852598736, 0.01967049270336117, 0.038554169769798, 0.013869888515078595, 0.05910979783428567, 0.03216470066191895, 0.016696278637807285, 0.03559131946946893, 0.03169872352321233, 0.07405280814106975, 0.03974984686023422, 0.01588958701384919, 0.02963016541408641, 0.026338315535602824, 0.041937406440930705, 0.016727649008056948, 0.057555436954966614, 0.03985186799296311, 0.011816298040295286, 0.04426546008991344, 0.05463738014389362, 0.06984920227634055, 0.08881515171378851, 0.025883493512602787, 0.05305726546794176, 0.0334549451779042, 0.037644162707562955, 0.053859884185450416, 0.02390954184478947, 0.09154195325183016, 0.016607558487781456, 0.026550449331157973, 0.06779753629650388, 0.05210105695628694, 0.030545329342463186, 0.03280804006915007, 0.017548862977751663, 0.014084938314876385, 0.04156357775043164, 0.06231333129107952, 0.02432923610987408, 0.02646266047044524, 0.015900669187041264, 0.011842527659609914, 0.05682120778198753, 0.03553871264947312, 0.1129703741254551, 0.04149533069825598, 0.026781303907877634, 0.026013921513887386, 0.05253918023247804, 0.055925144614385705, 0.01842990338004061, 0.024581988707983067, 0.017977625863360505, 0.006566178710532508, 0.04170466214418411, 0.043541361444762776, 0.0067300830851309, 0.03067476668262056, 0.0528940370838557, 0.05650807744158166, 0.022075570254985775, 0.0204907211009413, 0.049133375486625094, 0.02772962105726557, 0.02132149223637368, 0.026938474670584713, 0.012002454970830252, 0.087674988965903, 0.05941569499139275, 0.0054741860117896324, 0.08374183358890669, 0.018119241210765073, 0.0586582056379744, 0.01648203968735678, 0.039469873133514605, 0.07880106727991786, 0.046081287653318474, 0.0855301601280059, 0.018085066794550846, 0.03337879319276128, 0.0502069162737046, 0.034441426529416015, 0.03208046053935375, 0.057833073128546984, 0.03945847713787641, 0.09284019430301019, 0.017956489497529607, 0.01173295103944838, 0.02956446286823068, 0.06547552160918713, 0.018944305866690617, 0.04487456401277866, 0.0425318641854184, 0.029209846896784644, 0.03416696250704782, 0.023692274931818247, 0.0526587856002152, 0.013102435723080166, 0.03112031313191567, 0.0645039069599339, 0.03519017295911908, 0.05498064761715276, 0.04334283566900662, 0.022600378076146756, 0.029113454212035452, 0.060305301898292134, 0.1210445947945118, 0.02404045669494995, 0.03993050341627427, 0.029467812340174402, 0.04601743411538856, 0.0037441914319060743, 0.026043313954557692, 0.04750733416793602, 0.045565285520362, 0.034016724675893784, 0.021737201804561273, 0.029759287235460112, 0.012308045939010168, 0.05210001201235822, 0.06219047574060304, 0.011100459710827895, 0.09100349500243153, 0.015394690712647778, 0.05770894193223544, 0.01838101662828454, 0.0556467213401837, 0.043260390271565745, 0.0472086328747017, 0.06004944669881037, 0.0055217949972887126, 0.09256846816944224, 0.03537698043510318, 0.02508867285879595, 0.02545515980039324, 0.04541360240961824, 0.030032821664852754, 0.046393088065087795, 0.03291366761550307, 0.014315304346382618, 0.026987390260079076, 0.060634235319282324, 0.05018410053370254, 0.023765721258574297, 0.033202981376754384, 0.03511928301304579, 0.012181492372682052, 0.04377864174810903, 0.05030944291502237, 0.04474570682006223, 0.04876565361129386, 0.0236087099515966, 0.044863334258220026, 0.04601869958319834, 0.019646021337913613, 0.014943624380975962, 0.04986941634810396, 0.046518074215522835, 0.021362224693543146, 0.10585520842245646, 0.03574935027531215, 0.01792981967862163, 0.04195973702839442, 0.007350761543161103, 0.0022976361963498804, 0.02990989147552422, 0.06596927118620702, 0.030290624259838035, 0.0026290746838120477, 0.01427912655552583, 0.03366360826683896, 0.007006494078918227, 0.051982574564005644, 0.04572422556313021, 0.041024512212191305, 0.03922984476334282, 0.02176535761516009, 0.0319411674780505, 0.051865876718823395, 0.01698919542000762, 0.00983787652304662, 0.044202335977128575, 0.006728719229743416, 0.02925430451120649, 0.02388939105107316, 0.011113963405867773, 0.04230739462322422, 0.146249456597226, 0.07905221344637019, 0.11949787421950273, 0.1091853700844305, 0.11201238445937634, 0.13717402358140263, 0.07848854083567858, 0.14391682962221758, 0.1335135849991015, 0.16787235917789595, 0.11993726635617868, 0.09718759530889136, 0.12410850610051836, 0.09254749465201582, 0.10653866281999008, 0.11651598422655038, 0.07923024067921297, 0.0642331036339913, 0.1442828449819769, 0.1743848297212805, 0.3039105694208826, 0.07496702551309552, 0.10343425654407058, 0.16916608118585177, 0.05973603815904685, 0.0659238500520587, 0.10447614706520524, 0.07679630164057016, 0.10235953171338354, 0.07398642706019537, 0.09682903026363679, 0.10040296920176063, 0.05958256032317877, 0.2483558947486537, 0.07983238622546196, 0.2094416128737586, 0.09542958571442536, 0.10462456981518439, 0.11806692528937544, 0.08722581913960831, 0.0994522398603814, 0.14933977648615837, 0.08638327542160239, 0.10187105435345854, 0.12819741240569524, 0.0750996180410896, 0.1123995701117175, 0.12823489468012536, 0.10714970396033355, 0.19793534172432764, 0.11538272217980453, 0.11927716034863677, 0.0869267141180379, 0.1132509144289153, 0.16622509328382357, 0.1294761523604393, 0.21170972473919392, 0.1917977753494467, 0.141974360282932, 0.21315371511237963, 0.16900083076741013, 0.1226818183703082, 0.06872769924146788, 0.11607481432812554, 0.08596568461507559, 0.13107765785285405, 0.12475969615791525, 0.07973649565662656, 0.16220934662435735, 0.1292214167437383, 0.1695276317851884, 0.1633757890335151, 0.17090174662215368, 0.2507458579327379, 0.15417850469904287, 0.15323589742183685, 0.07448677199759654, 0.17165853029915265, 0.19287231697567872, 0.0633589673255171, 0.12389350549450942, 0.08535357138940267, 0.17823783654187406, 0.07553371760462012, 0.1121866051107645, 0.12700969113835267, 0.07562842073717288, 0.08740537986159325, 0.14215748331376485, 0.06699535862675735, 0.09451408591121435, 0.08725639392754861, 0.211195598755564, 0.08022905101201364, 0.11448998722646918, 0.16227802793894494, 0.14173090191824095, 0.14608445045139107, 0.10165489345256772, 0.19985455088317394, 0.08346324068095003, 0.13529768426503452, 0.13378125349325792, 0.1477278894079583, 0.11945481438721929, 0.08407173052962337, 0.14193733941231454, 0.07300780314419951, 0.1489577748413597, 0.14342527171330793, 0.1477953086474112, 0.12734815797635488, 0.0910540594320212, 0.16305917102311338, 0.08638317364134959, 0.12712987326085567, 0.11232433414884976, 0.12409017208431448, 0.12293223850429058, 0.12162879987486772, 0.2481075780732291, 0.15942389251930372, 0.131621585094503, 0.14932031610182353, 0.16148004361561366, 0.18213120262537683, 0.13456644064613751, 0.1556395534425974, 0.08936728244381291, 0.1091985675905432, 0.1202723133776869, 0.11363607804690089, 0.07249331753700972, 0.1122227031737566, 0.10547830257564783, 0.09352931446794953, 0.0621934545093349, 0.15812960054193223, 0.14583637804857322, 0.20796919188329152, 0.08582376223057508, 0.09035111072340182, 0.11794605106115341, 0.11654370916741234, 0.061024962924420834, 0.14622673924480165, 0.14475719524281366, 0.1598217176007373, 0.19485986818160328, 0.09896065481007099, 0.10626039560884237, 0.11983393904353891, 0.08822454804820673, 0.07649786836866822, 0.1257194568003927, 0.1452112030237913, 0.12322544705654893, 0.16227048262953758, 0.11555150098034314, 0.12083431679223265, 0.09725498740694352, 0.13853962958923408, 0.14240689921591962, 0.1478006419326578, 0.1506289251680885, 0.1837638664458479, 0.16629982713077748, 0.23438358306884766, 0.09282905954335417, 0.07066302360700709, 0.12211448167051588, 0.10359528647469622, 0.17272072258804524, 0.08077069159064974, 0.06760587050978627, 0.15707361006311008], [0.03659580914037568, 0.03964052129802959, 0.014951183261083705, 0.03719764256051608, 0.011982726565163051, 0.05905186451439347, 0.0325272385297077, 0.03724712472675102, 0.10356931215418236, 0.0639713451798473, 0.09928302679743085, 0.09649494676185505, 0.06888986911092486, 0.06505400887025253, 0.09196440915444068, 0.037039537115820816, 0.012478957884013653, 0.03249111671798995, 0.0448854850339038, 0.04879490525594779, 0.01577890438160726, 0.01766262955165335, 0.05723119221095528, 0.022866178902664354, 0.011846547979595405, 0.05306378618947097, 0.045597736457628865, 0.02072944159486464, 0.009303325787186623, 0.04546220587300403, 0.04063726209902337, 0.007964360760524869, 0.04422454442828894, 0.033248670532235076, 0.02299142289640648, 0.07490641197987966, 0.06257877419037478, 0.04015182118330683, 0.0409176836588553, 0.02641754298071776, 0.03492804131071482, 0.020331172072993856, 0.055108408975814066, 0.05607938240947468, 0.021760792770822133, 0.03559253065447722, 0.05481001302333815, 0.022220761481938616, 0.04284184951601284, 0.050066001513706784, 0.05140378080042345, 0.023499447153881192, 0.034499902677323134, 0.05629955345232572, 0.04082251572981477, 0.02442198675791068, 0.07362818771174975, 0.017665399670866982, 0.07119179237633944, 0.046103319685373984, 0.006032384541218302, 0.07042225902634007, 0.02530781252841864, 0.044380729618881426, 0.020650037730644857, 0.03091763472184539, 0.03362097251894219, 0.03014914631577475, 0.047491446270474365, 0.009507369748981935, 0.05963875659342323, 0.04462397085236652, 0.010733794653788209, 0.018850126902439764, 0.020235749693321328, 0.06590431502887181, 0.062168077299637456, 0.026770111472745026, 0.048146510762827735, 0.036205397054020844, 0.02798710304445454, 0.01186372254908617, 0.044016814325004816, 0.059291299166423936, 0.017244029424286315, 0.09428987758500235, 0.02501167609755482, 0.02502128415341888, 0.022831398893945982, 0.08451531601271459, 0.02588743410472359, 0.055113759224436114, 0.048320008774421046, 0.04336680491854038, 0.024929932983858243, 0.02006887079083494, 0.08579701438013997, 0.05574124805363161, 0.02510249292078827, 0.051178619132510254, 0.04569943867889898, 0.03062628535553813, 0.053096206592661996, 0.06182703881391457, 0.015180962359798806, 0.06212979435388531, 0.057529035157391, 0.022899700228923132, 0.019855424030018703, 0.007626240823550948, 0.021720704921920384, 0.024240017236609544, 0.07927664568913834, 0.01795624352858535, 0.03573224101481693, 0.019151299759479504, 0.03769274581489818, 0.015763540652447512, 0.06537189574113914, 0.05384521086567214, 0.1325195583381823, 0.014057947888172098, 0.04737235658935138, 0.021144883141719868, 0.015544780962435263, 0.013532066285344107, 0.07419650150196892, 0.027306657949728624, 0.14574398872043404, 0.05832877688642059, 0.040167688724717925, 0.08012260243828807, 0.016672920069790313, 0.018248424100290452, 0.0901833361546908, 0.034508004385445795, 0.03153317454936249, 0.0709136337307947, 0.06671390908637218, 0.02867732922147427, 0.04985950295148151, 0.013174064424155014, 0.0328569217318935, 0.0778283534039344, 0.04873331802498017, 0.04019573596971376, 0.029930406981813054, 0.06107915751636028, 0.014460938317435128, 0.03619989074234452, 0.08902903273701668, 0.0318588883216892, 0.06727068778127432, 0.020514932926744223, 0.04853601021958249, 0.01644900520997388, 0.0009308534603665716, 0.05199559225833841, 0.015337432535099131, 0.08805462252348661, 0.03551843123776572, 0.02354024746455252, 0.0585933919729931, 0.026883930633110658, 0.039280504187835116, 0.05116416972928813, 0.04457145563459822, 0.02818533026480249, 0.030887826678476164, 0.057927348784038, 0.024733597179874778, 0.06353428720363549, 0.013498337157735867, 0.06447737624070474, 0.028802736063620875, 0.04928994404950312, 0.020149061755676354, 0.014502754734296883, 0.036654739906745296, 0.03364713004391108, 0.01054320010423128, 0.03530666385112064, 0.06389825338763849, 0.0496177307463118, 0.05091006515015449, 0.022112614874328886, 0.026162218734888092, 0.018275065081460134, 0.03850285216633763, 0.06348183644669396, 0.04033997215862785, 0.024106461188888977, 0.050319356311644824, 0.04791105571868164, 0.03601634701980012, 0.034491454916340966, 0.0334843121735113, 0.02267784981190094, 0.021106610373993005, 0.026296339663011686, 0.02139724897486823, 0.06557575480214187, 0.00929198068167482, 0.03910927248320409, 0.024696613628683344, 0.009410977912401515, 0.023490643162014227, 0.025437860550092797, 0.01537902673174228, 0.02564940062750663, 0.020099101222253273, 0.051350729539990425, 0.029773020784237554, 0.025968619123367325, 0.050989843904972076, 0.06030864029058388, 0.03231537275548492, 0.02874070778489113, 0.015396149562937873, 0.04070946501035776, 0.030656548017369847, 0.020341290726459453, 0.025818411826289127, 0.0183964244622205, 0.040507963858544827, 0.1129102830642036, 0.004564197609267596, 0.03899186896160245, 0.049829912039318254, 0.08434725645929575, 0.030771003304315463, 0.020344598584675362, 0.014135743624397686, 0.03490271159846868, 0.048901550604828765, 0.0063681058569013006, 0.06610818087522473, 0.024134771366204535, 0.02985074357794864, 0.030919351415442567, 0.0025849342845114215, 0.03527597710490227, 0.02344839078640299, 0.04500006924250296, 0.038584184766347916, 0.036012231704912016, 0.003887748237632747, 0.04036300502983587, 0.04597943615434425, 0.024414256547710726, 0.03060662480337279, 0.03693949391267129, 0.02235539979301393, 0.03406258346512914, 0.04650691909981625, 0.05182307812252215, 0.017839569432128752, 0.03976509693477835, 0.053726368849830966, 0.04589864977502397, 0.027383096615916917, 0.05264927253925374, 0.02391389973594674, 0.033490144181996584, 0.06570118200033903, 0.09655129909515381, 0.03383679075964859, 0.02782641407767577, 0.03654902754351497, 0.04056070638554437, 0.04103151469358376, 0.05743350421211549, 0.06952971406280994, 0.035092691225664954, 0.019329128520829335, 0.06050050285245691, 0.030160986751850163, 0.020514335815927813, 0.09407490412039415, 0.0455739232711494, 0.02562707512905555, 0.024921653160293187, 0.03919599265126245, 0.08553229751331465, 0.022900965696732913, 0.04578618598835809, 0.009833106421865523, 0.020964238460042646, 0.012180929188616574, 0.020276777313223908, 0.05510645818763545, 0.042748547558273585, 0.03287151362746954, 0.041878981183149984, 0.06109877396374941, 0.021205701931778873, 0.029355772637895176, 0.0033005906817769365, 0.009513057568775756, 0.07522160506674222, 0.06896927806415729, 0.01173212577123195, 0.020410100962700586, 0.026011838411380137, 0.04643437013562236, 0.056029004577015123, 0.022015150104250227, 0.01896880267720137, 0.023498105350881815, 0.024784363473632505, 0.04565770198990192, 0.018199091211759617, 0.04013226580406938, 0.06456114138875689, 0.04097960337198206, 0.04480519737782223, 0.035297523984419446, 0.007241415624905909, 0.024178214570773498, 0.016677247426871742, 0.03040869953110814, 0.007434463926724025, 0.014905560262767332, 0.06828822568058968, 0.019003993199606026, 0.009355185370493149, 0.037897188416016955, 0.07517978695354291, 0.06693164418850626, 0.008684345787124974, 0.06427127801414047, 0.06302299071103334, 0.046384799759835005, 0.006939769065606275, 0.018180587561801076, 0.06320370494254998, 0.04018056731937187, 0.09708051569759846, 0.026014681473108273, 0.0412344645176615, 0.041859510620789867, 0.04238559578412345, 0.074515460458185, 0.011073213137154068, 0.06573626904615334, 0.07372709776141814, 0.07401925458439759, 0.03017091371917299, 0.01277305616531521, 0.03480278035359723, 0.03491385653614998, 0.042967147792556455, 0.11317472851702146, 0.16913134019289697, 0.13977237844041415, 0.12522925596152032, 0.22853447550109454, 0.14024216894592556, 0.1555809551583869, 0.208820997604302, 0.18169483675488404, 0.18286039706851753, 0.20829064106302603, 0.23165022688252584, 0.14653110291276658, 0.19289477648479597, 0.12482623330184392, 0.18357374093362264, 0.13870198944849627, 0.14183045657617704, 0.16742059056247982, 0.12829609853880747, 0.06733360833355359, 0.1038550975333367, 0.14051176447953495, 0.11239051166921854, 0.07154294781919036, 0.20198568009904452, 0.07849002004201923, 0.09462959971278906, 0.10045658703893423, 0.08912970019238335, 0.07889559399336576, 0.0585631700232625, 0.1535796704036849, 0.08095262718519994, 0.10996281515274729, 0.2439354019505637, 0.09278802174542632, 0.06020034610160759, 0.1863600364220994, 0.1314131391367742, 0.1717213490711791, 0.0872237156810505, 0.19792812211172922, 0.08891265719596829, 0.11898814514279366, 0.12263991204755646, 0.16135273687541485, 0.17394117638468742, 0.2350255586206913, 0.19589034574372427, 0.1103716121454324, 0.10250308936727898, 0.13540475709097727, 0.14856133397136415, 0.12803003138729505, 0.08960198092141322, 0.1653247723089797, 0.13076032059533255, 0.14470629154571465, 0.10038638580590487, 0.15338262383426937, 0.1877509517861264, 0.08623300027102232, 0.15927453339099884, 0.09706252773425408, 0.08325096778571606, 0.09734803491405078, 0.10312331108642475, 0.14784766440945013, 0.11412356474569865, 0.09756134596786328, 0.13536606702421392, 0.09429148571299655, 0.0798960735223123, 0.16131764304425034, 0.16938855924776622, 0.20000993540244444, 0.1272849320833172, 0.224631148523518, 0.09402330153222595, 0.15613621393484728, 0.08117950215403523, 0.19797666450696333, 0.13264542658414158, 0.08247860494468894, 0.19071306926863535, 0.07223925366997719, 0.11513549116040979, 0.15685841946729592, 0.271025044045278, 0.13508360646665096, 0.10473599883594684, 0.09129270698343005, 0.11819364848945822, 0.09158433454909495, 0.16127948223480157, 0.1585038804582187, 0.107314947593425, 0.07407097252351896, 0.11443898853446756, 0.1260035051298993, 0.1112010194254773, 0.15137858422739164, 0.09718356481088058, 0.0957873093762568, 0.12142857776156493, 0.13428586641592638, 0.11091941382203784, 0.061674721272928376, 0.09230298455804586, 0.12806733724262032, 0.14121153764426708, 0.11024064131613288, 0.11938394818987165, 0.1374834491206067, 0.13837327994406223, 0.16175069766385214, 0.18489513359963894, 0.15733931080571242, 0.14020392671227455, 0.2343832030892372, 0.11298572937292711, 0.1175466924905777, 0.09312531471784626, 0.17230182220893248, 0.06627331594271318, 0.20689040262784275, 0.10099118442407676, 0.18950302419917925, 0.16842624731361866, 0.12146395657743726, 0.13728546617286547, 0.1043898102694324, 0.11340561362781695, 0.21778911352157593, 0.1338778090264116, 0.18607605594609464, 0.17522459823106015, 0.19689716957509518, 0.12094255669840745, 0.13969692534634046, 0.12261224138949599, 0.12461428610341889, 0.20070603090737546, 0.0792754650382059, 0.1400305474443095, 0.1785072556563786, 0.13696466838674887, 0.09005835000425577, 0.09961419938398258, 0.16006189185593808, 0.10600397722529513, 0.2207425186144454, 0.10408237962318317, 0.15914957438196453, 0.16549528815916606, 0.15074973154280866, 0.06973348491426025, 0.08747125204120364, 0.15789428459746496, 0.2027876949203866, 0.2240668245192085, 0.13865796609648637, 0.10464370450271027, 0.12916570901870728, 0.17173584257917746, 0.21803525888494082, 0.08499357463525874, 0.14474305457302503, 0.15108453429171018, 0.12853421004755156, 0.11591488362423011, 0.0620487229898572, 0.09352821524121932, 0.15481464484972612, 0.11301745088504893], [0.0295378473321242, 0.018587338771404963, 0.028301317344552705, 0.03339427396921175, 0.05770217693809952, 0.05075341516307422, 0.04393365985846945, 0.04902711011735456, 0.01426883996464312, 0.002302914562668385, 0.01948431456860687, 0.03150011632325394, 0.044848158822527955, 0.04739159305713006, 0.05508164755467858, 0.11200553804103817, 0.021676757905100073, 0.04101036475705249, 0.011476351995952427, 0.039558157324790955, 0.01786991860717535, 0.04966032578210745, 0.04743636619033558, 0.03863571610833917, 0.021624956845438907, 0.018615553953817914, 0.03426165206890021, 0.038664665804909806, 0.024547032280159847, 0.04506555465715272, 0.04487322051344173, 0.04459548255960856, 0.00858644166562174, 0.04508292515363012, 0.049618426244705915, 0.045224701653101614, 0.045170099940150976, 0.04588473980714168, 0.01290482681776796, 0.04880076101315873, 0.11285455498312201, 0.05152663974357503, 0.00866529082746378, 0.07623908868325607, 0.09120305893676621, 0.043320403301290104, 0.013737187421481525, 0.03422909935138055, 0.042768079188785384, 0.06559467235846178, 0.0047851464228837615, 0.0689209663708295, 0.015262932782726628, 0.039501828740217855, 0.06217197887599468, 0.03413002984598279, 0.0699196138552257, 0.051183311202164204, 0.027224029347832714, 0.04059853132015892, 0.009388633754237421, 0.012857863712789757, 0.0296488454831498, 0.03573796106502414, 0.05964438843407801, 0.06435179297945329, 0.02400472334453038, 0.10382041760853358, 0.005289628303476742, 0.08514682176922049, 0.02464603053938065, 0.05026401499552386, 0.02443685006749417, 0.03483388439885207, 0.04621654682393585, 0.045574645910944254, 0.03456731852410095, 0.0206253407523036, 0.022690465474235158, 0.03450057781966669, 0.04988287848287395, 0.003449127934540489, 0.016911338615630354, 0.03192073339596391, 0.07349134755453893, 0.033711475519729514, 0.05892100903604712, 0.02731157393593873, 0.003295577368200091, 0.05212179637913193, 0.04213911793859942, 0.07158501699034657, 0.033376197796314955, 0.07732867343085152, 0.025670358877895132, 0.02797979352596615, 0.027704827387684157, 0.049361325933464935, 0.01137817561227296, 0.06035469924764974, 0.03486739045807293, 0.012087479649510766, 0.032274151753102026, 0.016686293995007873, 0.052690866735896895, 0.025119244254061153, 0.006397304491006902, 0.017743987596726844, 0.013763461993741137, 0.04577407074560012, 0.018840089673176408, 0.019409850439322845, 0.04678664516125407, 0.017416913361687745, 0.013627312245911785, 0.05460787404860769, 0.016786837617733648, 0.0221542514794107, 0.11236653902700969, 0.02975104303498353, 0.06105686764099768, 0.010793857725470193, 0.04077639231192214, 0.0211933135786759, 0.03165750252082944, 0.011997578000383717, 0.017703346741784896, 0.06379226621772562, 0.015814381585057293, 0.017117989848234823, 0.019879761384800076, 0.03111003671905824, 0.03807792639625924, 0.04339030258623617, 0.01855222288785236, 0.05504639766045979, 0.04002763909686889, 0.02742742870136031, 0.022350726383072988, 0.027317541651427746, 0.01913916924968362, 0.03983449749648571, 0.07543353869446687, 0.007417732949501702, 0.0015981243736210413, 0.0343643212025719, 0.02524678169616631, 0.0628717520407268, 0.05897320873503174, 0.027107024465554526, 0.05243824475577899, 0.048458087258040905, 0.025924894326765622, 0.060117591970733235, 0.019404003163799644, 0.039554191287606955, 0.06896482008908476, 0.03482322461370911, 0.028302386037207077, 0.03151743592960494, 0.010481685815778161, 0.047652744222432375, 0.014941761802349771, 0.0828341640798109, 0.040895468422344754, 0.02731316170788237, 0.003633317113521376, 0.07786126235233885, 0.06593621296009847, 0.058494373357721736, 0.022266823831679564, 0.028995209307010685, 0.040464853136135, 0.08647461980581284, 0.014024834531093282, 0.05275256931781769, 0.04722920266379203, 0.04208218545785972, 0.02104090782813728, 0.055092246271669865, 0.029477016667702367, 0.010936959064565599, 0.010500747560789543, 0.10047646132963044, 0.0492589791039271, 0.006433335972750294, 0.03813682323587792, 0.029257697186299732, 0.09969663460339818, 0.034426118779395304, 0.05292557539152248, 0.05263617342071874, 0.0647274028243763, 0.019230459351092577, 0.11354790242122752, 0.027518762907545482, 0.017353551761646355, 0.035835609039557834, 0.013552857446484268, 0.042801456326352696, 0.011008069534519953, 0.015264356009928244, 0.020011515922046134, 0.06257933737444026, 0.05517524806782603, 0.052490539449666224, 0.05599723556744201, 0.014155372794318413, 0.05233656628323453, 0.03087128738739661, 0.055346374599529166, 0.08646708806710583, 0.00833231333776244, 0.06359970476478338, 0.05040691447045122, 0.03842265271980848, 0.06328889501414128, 0.011856053407037897, 0.021427839029846445, 0.01100111285424126, 0.03275857147361551, 0.06633749857012715, 0.029839384901736463, 0.045019410883209536, 0.0602115894268666, 0.04253996250086597, 0.01207225417186107, 0.004466224362009338, 0.03491332049348524, 0.04391863030780639, 0.044743111423615894, 0.02731466805562377, 0.047522669059357474, 0.07765923533588648, 0.030108566528984478, 0.04738944888647113, 0.0055624914072853115, 0.01583024064478065, 0.03984217172754662, 0.05009035074285098, 0.04675173114186951, 0.007857488102412649, 0.03521676813917501, 0.09555807989090681, 0.020559648384473155, 0.02275121132177966, 0.027371111991150037, 0.11086749910776104, 0.026468723180836866, 0.04309643246233463, 0.031011635570653846, 0.012724347529001534, 0.02355350094980427, 0.05133216142920511, 0.0031114301735734834, 0.036890459579548666, 0.04535429844898837, 0.025595153449103236, 0.03736337473882096, 0.030010229841406857, 0.08761200056012187, 0.05458885131935988, 0.10717400908470154, 0.008732265626479472, 0.020824914864663566, 0.045860200588192256, 0.03384966256895235, 0.022924675406622033, 0.05961315546716962, 0.04408061018745814, 0.04221406891675932, 0.04980750342032739, 0.020252706283437352, 0.008825312285417957, 0.007823091465979815, 0.028071679041853974, 0.027704747659819465, 0.052688227234674354, 0.07875718642026186, 0.014505470570709025, 0.027874125267512033, 0.05376639223790594, 0.014782731853691595, 0.016901800109605705, 0.022166151287300245, 0.023878788941406777, 0.024369866786790744, 0.02268216529461954, 0.07996506696300847, 0.028005581249349883, 0.02417717980487006, 0.048828794687454186, 0.03274742653593421, 0.04045818992225187, 0.009926754432464284, 0.031831397475408654, 0.02440182408983154, 0.027741873703364815, 0.009037450321816971, 0.02929151876430426, 0.039810782697583945, 0.03707073276330318, 0.03553422074764967, 0.056216215781335316, 0.03326602406533701, 0.013242841581813991, 0.04527301673910447, 0.05227838869073561, 0.034372372020568163, 0.026922914166269556, 0.03500490915030241, 0.03721382222803576, 0.055474682178880484, 0.007294228549913636, 0.0451813330873847, 0.010322487929702868, 0.016457663316811835, 0.06119853896754129, 0.03753752075135708, 0.07252803138856377, 0.06122726135488067, 0.09027254993894271, 0.031062288209795952, 0.06632671664868083, 0.020698809131447757, 0.02995067821549518, 0.058446740199412615, 0.009269592418734516, 0.018390312558040023, 0.018496606765048842, 0.08943863718637399, 0.049274388634200604, 0.03383911134941237, 0.04239484082375254, 0.02593565928483648, 0.023644065018743277, 0.09380897946123566, 0.03211802423798612, 0.049733607564121485, 0.01566912928995277, 0.019791901277910386, 0.06365784843053136, 0.08977387419768743, 0.011500636764269854, 0.0369052041455039, 0.037486667944384475, 0.022713993676006794, 0.05629859332527433, 0.08893927612474986, 0.036613067678575, 0.018582812942830578, 0.061270911512630324, 0.09519641394061701, 0.15848573643182004, 0.11265497069273676, 0.1484902235014098, 0.1475001730556999, 0.1648825846080269, 0.09012893800224576, 0.2095351828528302, 0.08520913163998298, 0.09853205138019153, 0.17962644488683768, 0.10197135539991514, 0.13356271093445166, 0.13242046508405889, 0.08787643922758953, 0.13235993976039545, 0.1515979953110218, 0.11499799282423087, 0.20158811286091805, 0.15892020240426064, 0.10878546868583985, 0.12757588789931365, 0.1253591547054904, 0.12093843120549407, 0.08367269087050642, 0.12161311214523655, 0.16822778939136437, 0.16153864189982414, 0.12151304180068628, 0.212001359090209, 0.17506124771067075, 0.1937659883073398, 0.15325383788772992, 0.12632077453391893, 0.1519821004143783, 0.14800458241786274, 0.14478705078363419, 0.17939141392707825, 0.096092446574143, 0.1160228792577982, 0.2292285625423704, 0.09809877962938376, 0.06162925942667893, 0.29303091179047314, 0.11760229165000574, 0.1552531277494771, 0.11417353206447192, 0.12360796438796179, 0.23941972426005773, 0.14386192256850855, 0.07439635042101145, 0.14415917518947804, 0.20475303088980062, 0.09742620893354927, 0.12393933374966894, 0.21119878787015164, 0.16991066480321543, 0.13764861811484608, 0.12348019624395029, 0.12161170079239778, 0.08340123615094594, 0.07934090295540434, 0.13741897472313472, 0.13723327325923101, 0.09846426573182855, 0.16168779746762343, 0.10202667635998555, 0.2216999993792602, 0.1454151842210974, 0.18649047799408436, 0.11868611563529287, 0.2092549478901284, 0.1233893268342529, 0.13108478247054986, 0.19549746039722646, 0.20646858454814979, 0.10167511379612343, 0.11343960823225123, 0.11650915816426277, 0.12626548750059946, 0.10557422028588397, 0.05686498686139073, 0.13634693010577134, 0.1179890294692346, 0.3149700659726347, 0.1057941945535796, 0.1203136904431241, 0.0806978644270982, 0.14923275794301713, 0.1618937871285847, 0.13709224654095514, 0.1511158418974706, 0.15495736790554865, 0.1123275775462389, 0.23079424138580049, 0.1493346467614174, 0.11379725725523063, 0.08570294907050473, 0.07713960643325533, 0.12521073195551122, 0.09909858062331166, 0.15745044127106667, 0.11340080959988491, 0.1412728636392525, 0.1575921465243612, 0.10902212134429387, 0.13765636698475905, 0.10364825970360211, 0.08604452359889235, 0.0987057224182146, 0.1419117993542126, 0.17767408250698022, 0.11549928092530795, 0.10801459862185375, 0.10796118434518576, 0.12080632043736321, 0.21378373487719468, 0.08242299221456051, 0.16319995346878255, 0.11333265075726168, 0.12019597818808896, 0.16816182221685136, 0.21046130172908306, 0.10069435928016901, 0.22524344495364598, 0.07493325482521739, 0.0689707708411983, 0.1545198213841234, 0.07903174204485756, 0.10606712847948074, 0.20906175539961883, 0.17280100685145172, 0.11651609279215336, 0.11579943767615727, 0.07908560415463788, 0.10063748447490589, 0.18686108025056974, 0.09761803078332118, 0.14538612935159886, 0.05999805445649794, 0.07502809366477386, 0.15254224464297295, 0.1181703611676182, 0.1420694094683443, 0.1467480712703296, 0.13368582432823523, 0.08260914151157651, 0.18651882718716348, 0.08753732099596943, 0.08206300903111696, 0.11256758895303522, 0.08912288770079613, 0.07997132305588041, 0.10411210624235016, 0.1236280897366149, 0.08827348399375166, 0.17802252380975656, 0.15837888073708328, 0.08177391240107161, 0.09227193479559251, 0.18760615241314682, 0.2288677447608539, 0.09513624145516328, 0.13637127594224044, 0.1288022720920188, 0.09294458013027906, 0.15873261461300509, 0.17228400387934276, 0.1221617077078138, 0.12462245566504342, 0.056465160101652145, 0.11727298503475529, 0.20335664653352328, 0.26228320598602295, 0.10037307973418917, 0.1974899106259857], [0.014840483665466309, 0.03712254909000226, 0.007292448243658457, 0.03250994945743254, 0.03236820349203689, 0.12079627811908722, 0.04185463195400579, 0.03914567927962967, 0.04642126423173717, 0.08279327555958714, 0.01417970675642469, 0.010493549152410455, 0.09701404640717165, 0.023440144889588867, 0.05367740915556039, 0.05051321376647268, 0.06214583492172616, 0.059552243378545554, 0.03459856506170971, 0.0249360805111272, 0.03360203121389661, 0.05322867698435273, 0.05523875894557152, 0.012597919491651868, 0.0594958910452468, 0.008321694264720594, 0.014374767762741871, 0.01917302136176399, 0.013449558971582778, 0.026291028430153216, 0.013841039750591984, 0.05442294611462525, 0.027344957858856236, 0.013733905856497586, 0.034128781341548474, 0.054767672438174486, 0.02834640090752925, 0.01047223127846207, 0.016201738567490662, 0.01955632070478584, 0.03300351243732231, 0.015324609919584222, 0.0414485830281462, 0.0217639208172581, 0.06378529087773391, 0.012693314729923648, 0.047946923079767396, 0.050350976043513844, 0.06602632241057498, 0.029464270387377058, 0.02768997595246349, 0.058519268807555945, 0.027926611647542034, 0.016828143436993872, 0.148265913394945, 0.009764847495327038, 0.02698871509970299, 0.0349804140361292, 0.007319237654363471, 0.03874941822141409, 0.03726195750225868, 0.04796794070197003, 0.015464556070842912, 0.07144235500267573, 0.012379561833638166, 0.05588334346456187, 0.0691110918830548, 0.12799382475869997, 0.026451066003314087, 0.00994947857023882, 0.07841928955167532, 0.053315139309104, 0.02636520248571677, 0.047090357435601096, 0.04026183885123048, 0.025229996436142495, 0.04390345826478941, 0.045519497977303605, 0.00749614615259426, 0.08975465130060911, 0.04544792949621167, 0.008784859723943685, 0.035566742931093485, 0.08558307907411031, 0.007236665031606597, 0.03489369047539575, 0.0040241448025751326, 0.02672962668085737, 0.013933537644334137, 0.020480661819289838, 0.055193473518426926, 0.055508602144462724, 0.07105770028595414, 0.07950075223509755, 0.024226229405030608, 0.01120267592237464, 0.027162345425624932, 0.029983332713267634, 0.02432156866416335, 0.05037493172234722, 0.024675412802025676, 0.03634710909266557, 0.004276802405781511, 0.03421094175428152, 0.05160446431753891, 0.022702651963170086, 0.0245277534039425, 0.04793800034427217, 0.017519253405875394, 0.00823980272148869, 0.04244883185518639, 0.018287656995068704, 0.019093310460448265, 0.026653861460675086, 0.041251292186123986, 0.030403668193944862, 0.0406654145169471, 0.01812767031203423, 0.012657240415657205, 0.008728725370019674, 0.03224073390343359, 0.05539546660812838, 0.025954542914405465, 0.05575596547818609, 0.02704658735144351, 0.04415162566250988, 0.06127273677183049, 0.03925972066021391, 0.0598873786096062, 0.054391757252493074, 0.020201514208955423, 0.022368429361709526, 0.017994307646793977, 0.02877554377274854, 0.03880090545862913, 0.05477485473134688, 0.029868029257548705, 0.030467630297477757, 0.021651704695874026, 0.03249257217560496, 0.021294561181483523, 0.04727413186005183, 0.009674308023282459, 0.05201450302930815, 0.03215092300836529, 0.04746024723031691, 0.04067257306139384, 0.028189167380332947, 0.0653450528958014, 0.033853316480027776, 0.02346020408107766, 0.04105799452268651, 0.03152507284123983, 0.031900295921202214, 0.018081005762464235, 0.015887556497805884, 0.040789905336818526, 0.038273324125579426, 0.012264242262712546, 0.08495013482336487, 0.06893144973686763, 0.056396071666053364, 0.02356903431271868, 0.04296627587505749, 0.07172438129782677, 0.013860416166218264, 0.003982568841560611, 0.01769735018855759, 0.004829154083771365, 0.0519669852219522, 0.01634025470619755, 0.053581026648836474, 0.008500078576616943, 0.03330315689423254, 0.048002386532191715, 0.16085039025970868, 0.025671493727713823, 0.05530703992449811, 0.008399870828725398, 0.07170954852231912, 0.029363477403031926, 0.07038714483912502, 0.06043631343969277, 0.01613556274345943, 0.02637996231870992, 0.018826466386339495, 0.025578531037483896, 0.012079773188036467, 0.06235697466347899, 0.09649057021098477, 0.01814007223583758, 0.023032460694334338, 0.06503792080496039, 0.07716342301240989, 0.03935876302421093, 0.055215125570872, 0.03323300315865448, 0.006836828093842736, 0.014154589086371874, 0.04066767743123429, 0.018644688551181128, 0.07575680634805135, 0.014391688729769416, 0.04398916741566999, 0.029137494707746164, 0.0413685566080468, 0.018949352470891814, 0.04184215708768793, 0.051695265873734436, 0.006587447390692043, 0.05587184229599578, 0.01982466264494828, 0.010244124768567937, 0.06966902408748865, 0.0326744840214295, 0.05238410783931613, 0.013898334399397885, 0.020495031494647264, 0.026078343324895416, 0.009206244389393499, 0.02017053569267903, 0.017059634140293514, 0.0621091668893184, 0.0645244394295982, 0.06518471507089478, 0.03863283572718501, 0.05381617635222418, 0.049872849735298326, 0.017786815030766383, 0.03772755466135485, 0.12157492419438702, 0.032933016041559834, 0.043564872683158944, 0.02032125019468367, 0.029744430711226802, 0.021786828159487674, 0.05988224209951503, 0.02267180067220969, 0.03499614926321166, 0.09886105944003377, 0.09250715574515717, 0.05387642686920507, 0.09423792894397463, 0.06202697594250951, 0.01922197257434683, 0.043744019498782497, 0.03687492452029671, 0.00783562655228057, 0.01061178048673485, 0.028344953931601982, 0.032243661782039065, 0.02478623792662152, 0.0884581608697772, 0.04313593677112034, 0.026180440792813897, 0.02650754725826638, 0.027283614900495325, 0.006738797595192279, 0.022760877053120306, 0.05406291882640549, 0.030494018524352993, 0.05611324809225542, 0.022207837086170912, 0.013605879021010228, 0.025929550773331096, 0.020482738136446903, 0.022348329458119612, 0.05073122367528932, 0.030951785389333963, 0.06458654573985509, 0.022943185841930763, 0.021760736791683093, 0.0652492641072188, 0.027856573262917142, 0.02691805755187358, 0.019434773030557802, 0.03199443926236459, 0.02392244418816907, 0.005394983587653509, 0.04535848840272852, 0.010666259215213358, 0.016952279722318053, 0.0343197923419731, 0.05511892626860312, 0.009500699749748622, 0.014978869186182107, 0.023694473385278667, 0.027551207059462155, 0.010777912152531956, 0.021748813235067894, 0.026755468687042594, 0.009883575856552591, 0.017265650942655544, 0.05178454411881311, 0.05745830466704709, 0.02126838330046407, 0.03408311254211834, 0.029843259336692945, 0.04946500269163932, 0.0020828457241545296, 0.022808189603633115, 0.037609577777662447, 0.04288441062505756, 0.07063246917511735, 0.047663173305669, 0.04139118914359382, 0.00561805027869663, 0.06747413972126586, 0.06654471637947218, 0.005805455713665911, 0.010742951483864869, 0.0632672497470464, 0.041543873093490086, 0.059515113942325115, 0.039327082224190235, 0.037484252359718084, 0.06757360616964952, 0.07438096803213869, 0.018911364687872783, 0.05164505088967936, 0.01815505089637424, 0.021640100050717592, 0.018872245447710156, 0.05195473087951541, 0.06595606010939394, 0.009770609105804136, 0.048160709108092954, 0.023612562334164977, 0.024851207654657106, 0.00625917808585135, 0.028977136526788985, 0.052158969920128584, 0.06667801458388567, 0.025430267743234123, 0.024866133728729825, 0.03916184198377388, 0.02845200809783169, 0.03977826051414013, 0.04794331666614328, 0.04170390557763832, 0.020622843743434975, 0.0267909340161298, 0.018053251983863965, 0.06304711941629648, 0.05277240289641278, 0.037991080699222426, 0.062093635222741535, 0.012096648353950253, 0.0795617661039744, 0.055421949829906225, 0.002444143993281094, 0.06970605174345629, 0.14900800000344003, 0.12714937435729162, 0.08415289010320391, 0.11234388274273702, 0.10335244557687215, 0.2577117798583848, 0.09640787714826209, 0.13216521378074372, 0.11163003676171813, 0.17409836580710752, 0.08719418583703892, 0.10989598623876061, 0.22814923045890673, 0.16932949955974305, 0.1142509529100997, 0.1315713192203215, 0.3333301379212311, 0.19127488269337586, 0.13660271066640103, 0.1534069696707385, 0.13374580682388373, 0.10808287281543016, 0.13742367018546375, 0.09078524421368327, 0.12807720314179147, 0.12132309270756585, 0.16137206155274594, 0.12319432944059372, 0.08031808837716069, 0.0637109980785421, 0.09769277820097548, 0.0904957540333271, 0.12970290519297123, 0.12376645659761769, 0.13571951591542789, 0.0981895811855793, 0.17399795619504793, 0.1442224553653172, 0.08089668197291237, 0.0681330854339259, 0.1023297304553645, 0.08770964853465557, 0.11793243964867932, 0.13931177529905522, 0.18890461059553282, 0.08632041593747479, 0.16685258889836924, 0.170233498194388, 0.1328438845063959, 0.0971587100731475, 0.1118400569206902, 0.16007700961615356, 0.19333690990294727, 0.13585472080324376, 0.3052752933331898, 0.08094519044139556, 0.10043456857757908, 0.11913241525845868, 0.09800113844020025, 0.14869875088334084, 0.18257166684738227, 0.14666337652930192, 0.11064265295863152, 0.1566635306392397, 0.18575149907597474, 0.10583557161901679, 0.1171383365456547, 0.24376460111566953, 0.07735962141305208, 0.10593010511781488, 0.14350639736013754, 0.18035215165998253, 0.0853745381214789, 0.10526245380086557, 0.10926134565046855, 0.10508581077946083, 0.22862865616168293, 0.08224624741290297, 0.13841518626681396, 0.1469764390162059, 0.1013639240658709, 0.14377371301608427, 0.12999557091721467, 0.19553556692387375, 0.15207203344574996, 0.18348958902060986, 0.07671867723443679, 0.13081226923636027, 0.2004969199853284, 0.11248547264507838, 0.2099790261792285, 0.13388715923896857, 0.13720370270311832, 0.2576229731951441, 0.08256131836346217, 0.19820230454206467, 0.10803192840623004, 0.09132478811911174, 0.08215906244835683, 0.21972513677818434, 0.10110274236649275, 0.17443236788468702, 0.15367174760571548, 0.09199490251817874, 0.17007968787636074, 0.12094782213015215, 0.08432941098830529, 0.14396519559834683, 0.17852516898087092, 0.16091597745461123, 0.1547626554965973, 0.06100043388349669, 0.06301906199327537, 0.16611796617507935, 0.15961358376911708, 0.07437840995511838, 0.07039883599749633, 0.17679330334067345, 0.10491145442106894, 0.16005056032112666, 0.14310163765081338, 0.11196644085326365, 0.17934752628207207, 0.13131811709276267, 0.07157684742872204, 0.11126495778028454, 0.13256230604435715, 0.19151151499577931, 0.1851568038442305, 0.10165219966854368, 0.09583582463009016, 0.11506581918469497, 0.09297946361558777, 0.09584957174956799, 0.10182250517287425, 0.18170209707958357, 0.09349169648651566, 0.13237424327858857, 0.13897542549031122, 0.11836385221353599, 0.15589470975100994, 0.12921925900237902, 0.1167908316212041, 0.08252984112394707, 0.11178529235933508, 0.10255496336945466, 0.15227581108255045, 0.19499439453440054, 0.14094821177423, 0.1290115730038711, 0.14340693769710405, 0.15217735565134458, 0.20365315276597226, 0.11534959610019412, 0.07958921284547874, 0.11617003993264266, 0.11597258624221597, 0.15986214471714838, 0.10967643944812672, 0.16572151173438343, 0.2239285662238087, 0.11398099096758024, 0.11037108288811785, 0.13147290450121674, 0.2659970724156925, 0.11552030194018569, 0.10637658794543572, 0.1518510753022773, 0.10796018689870834, 0.1782041269221476, 0.13400052886988434, 0.15709296188184194, 0.1305007538092988, 0.08800413273274899, 0.09282563294151, 0.2817205472716263], [0.02454416546970606, 0.024989493091457655, 0.003888273678187813, 0.07708386478147336, 0.06208116374909878, 0.022682621609419584, 0.014214024513161607, 0.03878805061270084, 0.086120302389775, 0.019289237447082996, 0.023683097745691026, 0.03132128163373896, 0.04687436616846493, 0.05363893622000303, 0.04191739983590586, 0.07240174245089293, 0.04931157235322254, 0.01881856145337224, 0.02395510207861662, 0.01576680949489985, 0.02517847018316388, 0.022806447464972734, 0.02483720438820975, 0.0018261792512410985, 0.026889565866440535, 0.025433326239830682, 0.007510748226195574, 0.0064867761185658825, 0.03914597104968769, 0.003592663536047829, 0.014249908837622829, 0.06623032396393162, 0.020866724496175135, 0.055069237149187496, 0.08064200063901288, 0.017753383610397577, 0.032919716755194325, 0.0719521858596376, 0.05124281872329967, 0.05860127654990979, 0.04029795387759805, 0.005231644941626915, 0.06946791987866163, 0.01391399244312197, 0.035630124887185435, 0.025353225180879235, 0.1024530745510544, 0.027990037708410194, 0.06628595705011062, 0.03494255517476371, 0.03098814808098333, 0.033708578175199885, 0.022645848404083933, 0.07930214503513915, 0.012255992973223329, 0.06682325500462737, 0.030394670819597583, 0.07926614196704966, 0.03888439919267382, 0.01896825136749872, 0.021778397361880968, 0.015380979216258441, 0.05130044330975839, 0.05752387150589909, 0.049540791660547256, 0.06426150710987193, 0.030326213421566144, 0.030835850896047692, 0.028512350217040097, 0.04173079252775226, 0.0994448099019272, 0.06993747289691653, 0.024417493159749677, 0.05368511392069714, 0.008132710387664182, 0.023086667160636613, 0.043644363060593605, 0.005285186019526529, 0.02891936605530126, 0.044677995810551305, 0.03389167067195688, 0.011143078495349203, 0.018474671424233487, 0.04108784327815686, 0.03811306433219995, 0.005128876148124358, 0.006388535698144031, 0.06365815377128975, 0.02238185248071594, 0.011460726182641727, 0.008801421067411346, 0.022678630127172385, 0.023695730371400714, 0.034479811255420954, 0.01420090758308236, 0.011593339914855148, 0.015531344272728478, 0.046314330505473275, 0.029904788892183985, 0.05879043175705841, 0.017641376138531735, 0.007580393908678421, 0.025257105606475046, 0.03541931084224156, 0.039308317338249514, 0.03457509792808976, 0.007500856033792453, 0.06784751040062734, 0.07967446398522172, 0.02840490250049957, 0.007152575034914272, 0.04878594180835145, 0.029723504691251686, 0.02590024484587567, 0.08268238258148942, 0.05284802223156605, 0.04113226357315268, 0.0408642184920609, 0.014985807206747788, 0.04080061601208789, 0.041219689417630434, 0.022176388684394102, 0.02863766884963427, 0.020141657242285352, 0.03256222379526921, 0.03690485469996929, 0.03620024697322931, 0.015782069747469256, 0.030786701211971895, 0.03232042105602367, 0.0527894612667816, 0.039182788359799554, 0.0412608222104609, 0.06750246855829443, 0.03838953681822334, 0.0542504218007837, 0.030887579013194357, 0.026470709592103958, 0.05542848412213581, 0.04851896881258913, 0.045111915562301874, 0.054328429579202614, 0.00892497890163213, 0.033161658594118695, 0.01490289531648159, 0.026653724057333808, 0.10471877761717353, 0.04630204562896064, 0.008281206928326615, 0.06325547037912266, 0.026258613115974834, 0.01876456872560084, 0.024804561764800122, 0.022637283595811044, 0.019624007965571115, 0.076217545196414, 0.011257855238259902, 0.06378212890454701, 0.07212933099695615, 0.037653048123632155, 0.02213093701616994, 0.04460418477122273, 0.03408447639750583, 0.031469914729573896, 0.050110286101698875, 0.015679373472396816, 0.03934456467894571, 0.02700943247015987, 0.07840832442577396, 0.02994005914245333, 0.06452416801559073, 0.022549101184787493, 0.026609395364565507, 0.018513308904532875, 0.02411919559485146, 0.02967270616708057, 0.024387166037091186, 0.06142566499433347, 0.03193084356774177, 0.042872990880693705, 0.03952706345756139, 0.01141039330312716, 0.03875306195446423, 0.0228841295465827, 0.04191624293369906, 0.01938987776104893, 0.010081413767433592, 0.014246774005836673, 0.02273367458422269, 0.023902081352259432, 0.03218958254105278, 0.025769138309572424, 0.038537810290498395, 0.024764723277517726, 0.0579511925045933, 0.03914463772837605, 0.07614086395395653, 0.018670684924083095, 0.031894742112074576, 0.054616901957030804, 0.038519530557096004, 0.04330641530188067, 0.02302671011005129, 0.058768135096345625, 0.05031788728332945, 0.03140117234683462, 0.004622671212668398, 0.005802610955600227, 0.029145989966179644, 0.08394443736012493, 0.03326166447784219, 0.03866343765652605, 0.005781416066123971, 0.036106883947338374, 0.06473146046378783, 0.07366961905998842, 0.07416005738611732, 0.025664525173072304, 0.0318595872127584, 0.022145488199644854, 0.061359460332563946, 0.05709858611226082, 0.05278455885127187, 0.026804017867626886, 0.06169135895158563, 0.06081817259213754, 0.02200682956858405, 0.04910234947289739, 0.033975625809814246, 0.003514333241452862, 0.021874813795355812, 0.0512416007529412, 0.03851851614724312, 0.028352916540045823, 0.03166492569393345, 0.03613028662013156, 0.028119743069899932, 0.047152670699038675, 0.03602031644965921, 0.034577988487269194, 0.06711009211306061, 0.04521304102880614, 0.02909828895436866, 0.061496734752186706, 0.021536764256390076, 0.057976244017481804, 0.0061605623507473084, 0.10273636970669031, 0.024491875864831463, 0.03757897245564631, 0.021130813718108193, 0.09038659131952695, 0.029897124839148352, 0.007524210360965559, 0.013268898174698864, 0.03652429494208523, 0.05121209126498018, 0.03546788037887641, 0.027644570085353086, 0.016755295917391777, 0.021527271551479186, 0.014019423214319562, 0.05175909905561379, 0.02626918808424047, 0.029683128464967012, 0.02987600543669292, 0.00969424338213035, 0.051465106795408895, 0.041938244431678734, 0.049236845291618786, 0.048838226324213405, 0.05381613224744797, 0.011916765327831464, 0.06486895201461655, 0.03405099069433553, 0.04369481213923011, 0.022880324661465626, 0.02981244706149612, 0.044695712359888215, 0.021535037384767617, 0.023815155927357928, 0.0293409500404128, 0.01319294550921768, 0.07897667214274406, 0.0532782914649163, 0.012876405530343098, 0.030609193058418374, 0.03985479926424367, 0.017929214086117487, 0.04411131728972707, 0.031806593627801964, 0.06262152189654963, 0.03771355987659522, 0.02409709570929408, 0.06229254097810813, 0.019819653360173106, 0.05411835513742907, 0.028373610161777054, 0.08155786006578378, 0.034497700831187625, 0.01977820844123406, 0.03511484878669892, 0.04468133759551814, 0.020713585927816372, 0.030585780207599913, 0.01874444168061018, 0.030163907845105444, 0.033446032620434246, 0.014618955552577972, 0.04475597984024456, 0.04193397305373635, 0.08237366950405495, 0.02646613626607827, 0.05386937349768622, 0.011869627500085958, 0.07747410384139844, 0.014713175228929945, 0.045767220934586864, 0.021898855987404073, 0.057373182448957644, 0.02661800936662725, 0.03688282945326396, 0.03569950170016714, 0.011663333346535052, 0.04718551179394126, 0.0432943000591227, 0.04940217374158757, 0.04243562077837331, 0.009008648206612893, 0.03922318494213479, 0.017910756237272705, 0.11563804133662156, 0.05905077885836363, 0.07325253715472561, 0.006662837720276522, 0.025325011694803834, 0.01909527142665216, 0.046056480413036685, 0.04005127586424351, 0.00829478695855609, 0.025042898886437927, 0.014522303328184145, 0.047049200894044976, 0.03700484022764223, 0.029391243055995022, 0.033308904085840495, 0.03963992418721318, 0.007871762782867466, 0.03784383520750063, 0.011868182220496237, 0.02404556606364037, 0.05452388159132429, 0.10112401443932738, 0.16655334138444491, 0.1474836032305445, 0.17817193722086294, 0.15649032779037952, 0.08895770513585635, 0.09073451693568911, 0.09995354153215885, 0.130915121574487, 0.09510654197739703, 0.1560283675789833, 0.09206784503268343, 0.19184097088873386, 0.12218928337097168, 0.11918156833520957, 0.23503285965749196, 0.10307417158037424, 0.13126652128994465, 0.08738285928432431, 0.1593515606863158, 0.17363324362252439, 0.11961448724780764, 0.06169425629611526, 0.14342139049300126, 0.12174511434776442, 0.10835747593747717, 0.15016536361404828, 0.14313583581575326, 0.08121126437825815, 0.11717671448630945, 0.06740957711424146, 0.15327886225921766, 0.15175918809005193, 0.200629750000579, 0.11051766680819647, 0.10066485657755818, 0.1961382824395384, 0.13217741384037904, 0.1428440928991352, 0.20270445224429878, 0.10318767691829375, 0.16621178042675766, 0.13714619007493767, 0.06913971249014139, 0.16569233472858155, 0.12306709055389677, 0.17801790977162973, 0.08286797547979013, 0.14084063683237347, 0.10519008125577654, 0.10111005697399378, 0.12393598178667681, 0.12700281079326356, 0.09717684731419597, 0.06070160027593374, 0.20989002952618258, 0.19529558265847818, 0.11552262252994946, 0.1360948679170438, 0.13539136280970915, 0.1110893664881587, 0.10600565999214139, 0.18591626094920294, 0.14722137658723763, 0.18275063724390098, 0.13525151674236568, 0.1272316670843533, 0.09885535296052694, 0.13285784875707968, 0.10965039048876081, 0.1776274942925998, 0.1990857028535434, 0.08227703254669905, 0.08511902897485665, 0.14812741082693848, 0.1107275987576161, 0.1679545704807554, 0.07310328659202371, 0.10704725874321801, 0.20481173773961409, 0.1372715969170843, 0.2216239491743701, 0.12662494821207865, 0.15724989346095494, 0.14114601830286638, 0.10490706429949828, 0.09398355295083352, 0.1197091835950102, 0.11551817134022713, 0.1314102757189955, 0.20699328210737022, 0.0973620805889368, 0.10857916689877, 0.08953583732779537, 0.15912320651113987, 0.0898212766540902, 0.16121107233422144, 0.13601752849561827, 0.10956270340830088, 0.1175484973937273, 0.1507409784410681, 0.14446876357708657, 0.10590170164193426, 0.11607400008610316, 0.08679314449961696, 0.11039733540798936, 0.12945567417357648, 0.14144840064857686, 0.19073324890008994, 0.10968658354665552, 0.12652689990188393, 0.08458722036864076, 0.13787284679710865, 0.11192745223109211, 0.19242319464683533, 0.08529580091791493, 0.211583870063935, 0.07831801820014204, 0.11426225730351039, 0.11736333875783853, 0.13177904593093054, 0.09506721408771616, 0.13305812515318394, 0.0709444120792406, 0.07876636021371398, 0.10910518081592661, 0.14719582295843534, 0.14557174939130033, 0.06833374180964061, 0.07386926441852536, 0.13338730963213102, 0.10861170265291419, 0.10793439578264952, 0.16944894886442594, 0.18544409557112626, 0.11570809329194681, 0.12870786072952406, 0.10700352716126613, 0.17473920142011984, 0.1820556138242994, 0.13360225595533848, 0.08460977487266064, 0.0884328582989318, 0.12571355354573044, 0.12692278437316418, 0.1383382539663996, 0.2645450346171856, 0.1216814134802137, 0.11442517356148788, 0.12113371358386107, 0.09855830390006304, 0.10534676856228284, 0.14458529518118926, 0.1099822416103312, 0.11141687498560973, 0.11472469248941966, 0.18561716271298273, 0.1332675889134407, 0.1165489067456552, 0.18019676714071206, 0.15044901839324407, 0.1302164883485862, 0.10624643135815859, 0.09369496522205216, 0.18056552378194674, 0.09151473721223218, 0.0999737958024655, 0.2189641326133694, 0.11073823818670851, 0.1770246159285307, 0.15674352991793836, 0.08877766943935837, 0.1435519949133907, 0.07173119378941399, 0.09902170260569879, 0.08794502554727451], [0.026431030560550944, 0.014191952617173749, 0.025413010901372348, 0.019391501156081046, 0.08822332668517317, 0.02254053807285215, 0.04131253675690719, 0.03650749780769859, 0.03323584622038262, 0.03815592060397778, 0.033519365292574675, 0.017723058184076632, 0.04511546090777431, 0.04597404519362109, 0.06376849713602237, 0.05008476300697241, 0.04834413069433399, 0.046151458352271996, 0.024622266546690037, 0.032653934588389735, 0.03938468984727349, 0.058430428217564306, 0.031055611425212452, 0.02936523820140532, 0.03719563748953598, 0.038724902751190324, 0.03013126691803336, 0.05618289292656949, 0.011433295556344092, 0.03556726879573294, 0.030515158282858983, 0.02242261716829879, 0.037642161029257944, 0.004651180285561297, 0.034873663514320336, 0.0418230970390141, 0.03482839505055121, 0.11798670887947083, 0.022617400823427097, 0.025417719934401766, 0.04479322802009327, 0.05498312087729573, 0.029254508071712086, 0.0349901510136468, 0.0236468130855688, 0.048245305461542945, 0.007955974067694374, 0.0231596673506179, 0.03766179783269763, 0.03444004571065307, 0.022993592512128607, 0.04312840163973825, 0.04134614120370575, 0.01264480032425906, 0.05258517812139221, 0.03092591624174799, 0.04597378395763891, 0.008517710309076523, 0.013610090178969716, 0.022668158635497093, 0.014709300793973463, 0.05791698076895305, 0.015741157478519847, 0.05150751184139933, 0.06381378934851714, 0.04802356021744864, 0.10343768993126494, 0.03481252411646502, 0.006696269988814103, 0.013566853927581437, 0.03696302550711802, 0.034721027061875374, 0.01116560076895569, 0.07519293017685413, 0.008308784287822033, 0.03651327553338238, 0.06936440257621662, 0.014420602803251572, 0.046761291700282266, 0.030942177333469902, 0.010533355409279466, 0.021926652174443007, 0.08118765814495937, 0.005989856510755739, 0.044387840665876865, 0.03169514425098896, 0.055874895703579695, 0.02356017773438777, 0.01166529007189508, 0.02756957839509206, 0.028903345843510966, 0.02398333083172994, 0.0048211957161713925, 0.044201114614095004, 0.04835825779342225, 0.016353063751012087, 0.016507364310590283, 0.039202828891575336, 0.009897948924585112, 0.012437301771050053, 0.04918003833985754, 0.022210887101079737, 0.028398129024675915, 0.07243454283369438, 0.01915150840899774, 0.04317844020468848, 0.026423505607194135, 0.052829505010907135, 0.04839565525097506, 0.0176883595995605, 0.013816763463962291, 0.016546127319868122, 0.06232937864427056, 0.04772165284625121, 0.06782081683299371, 0.0194775733231966, 0.04115306745682444, 0.041481729463807175, 0.00815475853492639, 0.021021861350163817, 0.044755983232919655, 0.022150266782513688, 0.022037088837740675, 0.047130611525582414, 0.04786865067269121, 0.05132841930857726, 0.0843282031959721, 0.04018870973959565, 0.022513542557135224, 0.026799605693668127, 0.01761532378649073, 0.05694736779800483, 0.04673533773581896, 0.07980109897575208, 0.019255558361432383, 0.02159706735983491, 0.04701792382236038, 0.02781065001285502, 0.024301847043846334, 0.06178585173828261, 0.033429418690502644, 0.07949968693511826, 0.026228231710514853, 0.10716811940073967, 0.03513829217159322, 0.11475807641233716, 0.05674587682421718, 0.02195409552327224, 0.057123610483748574, 0.02106777442220066, 0.02446453090357993, 0.0737758097904069, 0.05167584620150072, 0.017181203866909658, 0.049174515064805746, 0.06914089314107384, 0.01632502498770399, 0.04698346442143832, 0.013430452273626412, 0.025603884498455694, 0.11197076312133245, 0.025194386918363825, 0.01362888135814241, 0.031174657001559223, 0.015321359736844897, 0.04802803176322153, 0.01067649491596967, 0.05689605697989464, 0.054608131891914775, 0.029262667455311333, 0.05624312648017492, 0.0191329029787864, 0.020892508826883774, 0.09026045844491039, 0.019431987644306252, 0.06642219331115484, 0.06221423125160592, 0.009877181512170603, 0.020190990130816187, 0.044711125282836814, 0.019876694406515787, 0.01955632070478584, 0.014972906559705734, 0.02167940079899771, 0.0348188107434128, 0.05087538861802646, 0.03447183507627674, 0.03403882456145116, 0.025584156092788492, 0.08655899563538176, 0.03191500316773142, 0.007663087819569877, 0.06993023292826754, 0.037093209235795906, 0.01737893745303154, 0.017166118337107555, 0.007690676205259348, 0.018004400855196372, 0.07855543081781693, 0.014296257868409157, 0.010086604560326253, 0.022825629649949924, 0.009735187033324369, 0.003945293096226773, 0.017435836007020304, 0.01725042292049953, 0.012169043799596173, 0.07146564910986594, 0.02209902721058045, 0.018329352971964648, 0.07898263646555798, 0.021213030109980276, 0.03870966624734657, 0.028672467518065656, 0.026721672554101263, 0.09450680523046426, 0.054683130367525985, 0.043794550001621246, 0.02571980033202895, 0.02041065736141588, 0.04849917594609516, 0.004183880003568317, 0.050106092755283625, 0.026031227549538016, 0.008979334645638508, 0.01884862394737346, 0.03685985425753253, 0.018883385296378816, 0.01508571979190622, 0.02427549274372203, 0.03906643996015191, 0.032838896449123106, 0.022429392340459993, 0.01713043248413929, 0.025958050940451876, 0.04203984487269606, 0.007806614091220711, 0.06019727233797312, 0.04578386539859431, 0.06497098332537071, 0.05567134537601045, 0.027875389038984264, 0.07471161814672606, 0.044144080353102515, 0.03206521725015981, 0.04845105084989752, 0.04132454343406217, 0.080024140221732, 0.02023474037248109, 0.029399052994059663, 0.009978165334489728, 0.027430680580437183, 0.04867891647986003, 0.044980720816446204, 0.023336817576949085, 0.004379307842879955, 0.035821108746209314, 0.0659820819273591, 0.07413138928157942, 0.04952840839645692, 0.06894890844289746, 0.014064923228163804, 0.02785933150776795, 0.023419953383771435, 0.015885617583990097, 0.008923308009148707, 0.028755896791283573, 0.03261333105287381, 0.03651689551770687, 0.04492013103195599, 0.05698322158839021, 0.055419418894286664, 0.07023933955601283, 0.03579254581459931, 0.00871526577975601, 0.12393490970134735, 0.02538808322112475, 0.02073205734736153, 0.06971134431660175, 0.07151952479034662, 0.049271582891898494, 0.03104915177183492, 0.01569037082871156, 0.044312295969575644, 0.06678636305566345, 0.03977399252887283, 0.01299047320415931, 0.02074027949545, 0.05374027881771326, 0.06699710246175528, 0.009444113321868437, 0.017054799578285644, 0.016515990187014853, 0.03566029255411454, 0.008587700348081333, 0.028868017917765037, 0.03135088950927768, 0.011399972701578267, 0.03402647861678686, 0.030295523282672678, 0.07233444534774337, 0.05309474095702171, 0.014725108963570424, 0.04315325977014644, 0.0563131173673485, 0.02970590688554304, 0.04765359917655587, 0.02040648946006383, 0.06349483717765127, 0.08157295068459851, 0.021847538383943692, 0.046581510454416275, 0.024949829326942563, 0.03614132299220987, 0.05607450713536569, 0.055134753097913096, 0.04331016760053379, 0.060659999293940406, 0.004818708461243659, 0.054594418699187894, 0.023936333800000802, 0.020455596735700965, 0.029008070938289165, 0.04409049983535494, 0.05366276636985796, 0.019118999796254293, 0.010144799964369407, 0.025732224308220402, 0.03768037612150822, 0.033756971292729886, 0.028308737124981623, 0.03614573686250618, 0.03251391888729163, 0.025064939400181174, 0.030890330472694974, 0.01757451329779412, 0.02936080058238336, 0.026386393134349158, 0.025293727837769047, 0.027772484114393592, 0.06280576451016323, 0.02180179494566151, 0.04434592416509986, 0.08530584323619093, 0.07822989685727016, 0.022879386586802344, 0.034902565713439665, 0.04805176013282367, 0.05452030571177602, 0.07974545231887273, 0.02234377818448203, 0.04997039932225432, 0.12213539411979062, 0.11026510928890534, 0.10456059074827603, 0.1578834280371666, 0.17566080125314848, 0.11972603840487343, 0.13376766922218458, 0.1087905169863786, 0.11049398593604565, 0.16183404890554293, 0.06813458499631711, 0.09680074213870934, 0.09764955552028758, 0.16854815291506903, 0.15004664712718555, 0.2149664078439985, 0.14504455482321127, 0.23900755494832993, 0.12057856337300368, 0.06973061471113137, 0.14401563789163316, 0.13836768881550857, 0.10269645827689342, 0.09246218922947134, 0.10572842415422201, 0.16565258614718914, 0.12478249493454184, 0.11368861701339483, 0.10546788706311158, 0.27993214609367506, 0.05374745432553547, 0.1805181484669447, 0.09472529350646905, 0.0674812507682613, 0.1698563684310232, 0.13370284198650292, 0.09692640003881284, 0.21322810969182424, 0.10310703303132739, 0.2570238267736775, 0.09280303094003882, 0.15682074720306055, 0.13656183571687766, 0.08819896049265351, 0.17727780448538916, 0.15947133568780764, 0.12352884720478739, 0.1818017874445234, 0.09404297904776675, 0.14279967599681445, 0.156964596627014, 0.14186542827103818, 0.09124769975564309, 0.08180566105459418, 0.1549041707600866, 0.1362282543310097, 0.16062424810869352, 0.11758930448974882, 0.09935525685016598, 0.07390496214585644, 0.08856167138687202, 0.09092219972184726, 0.16479966762874806, 0.15990681946277618, 0.12479131588978426, 0.12004021368920803, 0.2101804425141641, 0.23250990360975266, 0.10204056597181729, 0.13078280724585056, 0.11201244552752801, 0.09821522302393403, 0.12336109977747713, 0.15438739848988398, 0.08979233035019465, 0.0733323667996696, 0.10871218011847564, 0.14149857152785572, 0.06937608016388756, 0.08782658047441926, 0.10907605809292623, 0.14534792783004896, 0.2204060602400984, 0.16329407984656946, 0.21136079489120416, 0.2162034043243953, 0.102002859780831, 0.09744775920574154, 0.11827147645609719, 0.10583002798791442, 0.1334494770105396, 0.12253249995410442, 0.19681479542383126, 0.15686569336269582, 0.1222349623484271, 0.12465351899819714, 0.12171684657888752, 0.16813360873077596, 0.10523204864667994, 0.18661597983113357, 0.08895880436258656, 0.10121133511087724, 0.1692085981901203, 0.16699048078485898, 0.2718994585531098, 0.1148070530699832, 0.16960376341428074, 0.1077413254284433, 0.14625639122511658, 0.1607900820672512, 0.09294306021183729, 0.23738178504364832, 0.109562635554799, 0.17560312577656337, 0.10308086193565812, 0.10999773935015712, 0.12025651708245277, 0.1311567071825266, 0.06018127926758357, 0.18139572494796344, 0.06415205262601376, 0.08388669403003794, 0.09048208155270134, 0.10064293989645583, 0.10049193192805563, 0.18998819030821323, 0.11996462488813059, 0.1092746245807835, 0.15181256165461882, 0.10777567965643746, 0.0884855736845306, 0.1627134031483105, 0.21092683103467735, 0.17763092767979416, 0.2022366566317422, 0.12609132113201277, 0.1115965171317969, 0.0974692687658327, 0.24095581897667476, 0.22326148487627506, 0.16138306739074842, 0.21442514045962266, 0.13850566212620052, 0.15240085151578697, 0.08527062726872307, 0.2516324317881039, 0.29762532668454306, 0.1333147335265364, 0.1759600487670728, 0.07656631219599928, 0.10506307307098593, 0.20916901821536676, 0.1619985665061644, 0.1118012515029737, 0.10531259075339351, 0.18053060636988708, 0.1551608605576413, 0.14225520592715057, 0.1274303692792143, 0.08018941778157439, 0.14182258556996072, 0.12419959264142172, 0.10535425280353852, 0.10534095351717301, 0.12160274413015161, 0.13772037997841835, 0.20154573156365327, 0.15132696128317288, 0.13297808516238416, 0.16481413399534567, 0.17640002444386482, 0.08544604892709426, 0.17346879387540476, 0.19779944473079272, 0.06078337053103106, 0.08669442443975381], [0.03684307747919645, 0.02918561301859362, 0.03914782005761351, 0.05352202124361481, 0.037543946477983675, 0.005804376418901873, 0.03236609324812889, 0.1044993054653917, 0.04936522411714707, 0.012841719668358564, 0.02216921148023435, 0.06819661666772195, 0.02678805193863809, 0.004961034149995872, 0.0845454836796437, 0.046261910282607586, 0.03050332123945866, 0.05538505788094231, 0.15563123460326875, 0.04948325189096587, 0.017845964624679515, 0.023603697274146334, 0.026215337848822986, 0.02453431483757283, 0.044043803055371554, 0.047445947104798894, 0.05502142757177353, 0.030187151062169244, 0.021844910757083977, 0.014589500347418445, 0.05987097841820546, 0.028623015885906558, 0.05058845312201551, 0.018504416703113487, 0.03556296009836452, 0.026840797858312726, 0.09642094573272125, 0.07690550506647144, 0.03923194143655045, 0.05744241337691035, 0.034274069259741476, 0.08546066457139594, 0.00972110403901232, 0.023245323915034533, 0.005336612612674279, 0.01304957699695868, 0.013765616342425346, 0.0649228480511478, 0.049807123440716944, 0.03972361469641328, 0.01737947858470891, 0.0297612007042127, 0.024115310981869698, 0.0364295273487057, 0.03269517933949828, 0.07339855789073876, 0.012347011660624827, 0.05719184396522386, 0.0370916078931519, 0.12104070000350475, 0.008927357166872492, 0.042558947910687754, 0.04427022001306925, 0.04256067817498531, 0.046541758480348756, 0.013189764876317765, 0.016222233717728938, 0.05469283002561756, 0.023797602226425494, 0.030652955174446106, 0.02802483637684158, 0.013626358904210585, 0.047163724034492455, 0.025826369345720326, 0.10810181072780065, 0.014369441262845482, 0.008368525903538933, 0.033407552899526696, 0.025610193177791576, 0.013389752895039107, 0.05171410200585212, 0.03533958637022546, 0.006994451778674764, 0.019371396163478494, 0.012343029508234134, 0.021324350565139736, 0.04378175961651972, 0.03044237183140857, 0.04195284989795514, 0.04237924130367381, 0.013860791056816067, 0.010367907367513647, 0.05190388485789299, 0.051715621924293895, 0.07169907194163118, 0.040035744197666645, 0.06565936388713972, 0.0030715583956667353, 0.04240370249109609, 0.01698014376285885, 0.04928635459925447, 0.06618158479354211, 0.013668041310406156, 0.036583371593483856, 0.008594244818336197, 0.01727051434240171, 0.02615804404818586, 0.03645466367847153, 0.06622783374041319, 0.007231464060688657, 0.05095009532357965, 0.02875847861702953, 0.027295713179877827, 0.027109272112803798, 0.04795316220926387, 0.0388317957653531, 0.04530844305242811, 0.07110964214163167, 0.05139855268810477, 0.057614944476102076, 0.039188963028469255, 0.03876223914059145, 0.004091903309537364, 0.06688148687992777, 0.05470944734822426, 0.03817631736663835, 0.027374026299055134, 0.0229916383312749, 0.008536592242307961, 0.06469718087464571, 0.06882556434720755, 0.0452373088337481, 0.06916152739099093, 0.06351531536451407, 0.052205683663487434, 0.02599657985514828, 0.0019550911508434054, 0.027412585747827376, 0.03141626635832446, 0.05808713699557951, 0.058358252447630675, 0.02485137728841177, 0.07985096451427255, 0.0483035644782441, 0.03579592831166727, 0.04998971042888505, 0.04411886599180954, 0.031244115238743167, 0.027670378164787377, 0.013292548512773854, 0.03012515331751534, 0.016430662712082267, 0.041447097036455355, 0.035003606363066604, 0.021714957730312432, 0.024733481828921607, 0.025358931660386066, 0.013167454644904604, 0.07615522175495114, 0.03267029406768935, 0.04555602012468236, 0.05051770566829613, 0.05989781447819301, 0.043359198540981324, 0.045379176935447116, 0.018500778059075986, 0.0564351077856762, 0.026883219867678623, 0.049422017498207946, 0.025912529722388302, 0.015294813750577825, 0.011620962227295552, 0.015419156989082694, 0.06653776139553104, 0.0677403968625835, 0.044032804002719264, 0.01727141679397651, 0.025408624172476784, 0.046507502639932294, 0.036351136198001247, 0.040412181855312417, 0.015284469484218528, 0.019894456756966453, 0.027087375787752013, 0.029623675226633037, 0.023334072902798653, 0.029166244236486297, 0.05678370175883174, 0.05088624857099993, 0.03436851794166224, 0.05573509374101247, 0.006346270175916808, 0.01150686656390982, 0.029988306374954324, 0.09210283708359514, 0.036084475328347514, 0.009309692141999091, 0.011550749968072134, 0.019275296945124865, 0.0572536720761231, 0.04837164868201528, 0.05457597951005612, 0.022722840076312423, 0.008522443939000368, 0.030027291604450772, 0.019375090786655034, 0.02716098665925009, 0.016091742951955115, 0.04181806570185082, 0.01728100110111492, 0.023348681761750152, 0.002378336910624057, 0.06328292390597717, 0.0218656077714903, 0.026163453668622032, 0.07042705626892191, 0.02129243397420006, 0.020087313372641802, 0.01342425640073738, 0.047399274073541164, 0.01612436691565173, 0.02016870873714132, 0.041865905813340626, 0.05023917043581605, 0.04359668919018336, 0.041442720485585074, 0.043143767065235546, 0.06258591916412115, 0.014207270545219737, 0.04293999621378524, 0.04647515009024313, 0.05370628760595407, 0.0325811108175133, 0.014149180314104472, 0.015953421892066087, 0.050726996402123144, 0.03319539874792099, 0.00517839817829164, 0.04656651483050414, 0.05873900558799505, 0.05557470841865454, 0.03551438716905458, 0.08531764296016522, 0.01942511578090489, 0.07200833463243075, 0.03649639358211841, 0.013222298085955637, 0.03904238250106573, 0.02096699670489345, 0.028582982319806303, 0.06952201947569847, 0.0517806798618819, 0.020292000246367285, 0.08362763614526816, 0.04827386500047786, 0.008551586169882544, 0.009399007706503783, 0.027608684064554315, 0.006074507147007222, 0.06213045931820359, 0.0032290255933600876, 0.05931510217487812, 0.04399527423083782, 0.04531601211056113, 0.04871158454833286, 0.006879061809740961, 0.037642089783080986, 0.054419258276798894, 0.03515673475340009, 0.03162645615105118, 0.017130663186045628, 0.04575195050399218, 0.026890067982354333, 0.02740877407736012, 0.0660149162369115, 0.05120315156610949, 0.044828966459525485, 0.03787306310342891, 0.018293665422658836, 0.06337276872779642, 0.059613908641040325, 0.016206069317247187, 0.051359652275485654, 0.023034694770883237, 0.0339652577947293, 0.015828990444008793, 0.043358245199280124, 0.02985497085111482, 0.036590947436967065, 0.0061426880420185626, 0.039575833162026744, 0.039507331659219096, 0.0011904074178476418, 0.007820608875980335, 0.0287137122691742, 0.10484744142740965, 0.017931641545146704, 0.07307459134608507, 0.05809787820492472, 0.006329683811470334, 0.03317304780440671, 0.07467033607619149, 0.00950116284989885, 0.012550031882710755, 0.02233008704414325, 0.0029365892987698317, 0.013253438602467733, 0.018972605865980898, 0.008793508500925131, 0.014150919908258532, 0.014395279876355613, 0.013942737731018236, 0.029386415279337337, 0.009637038639214422, 0.024227620401818837, 0.07452856296939508, 0.02812832823422338, 0.01609106780961156, 0.040409108091677935, 0.006880577911423253, 0.062051579622285705, 0.0375099484808743, 0.045140054409525225, 0.029812983104160855, 0.02009719793152596, 0.07657044447426285, 0.07888430317065545, 0.029938566365412304, 0.07381541587944541, 0.05818918187703405, 0.044363891772393665, 0.01808888864304338, 0.014164743362925947, 0.015394651696884205, 0.04088186040254576, 0.009504538561616625, 0.018864335425730263, 0.07561331654765777, 0.005246833948019359, 0.033872790435062985, 0.035348068057958565, 0.04316219607634204, 0.05432717768209321, 0.06891992142690079, 0.02208569230112646, 0.02630525900583182, 0.03436425674174513, 0.004273960616306535, 0.013321302282357854, 0.08215191068926028, 0.02568352415359446, 0.028511312058461562, 0.1417369001678058, 0.08056339235710246, 0.1470973946686302, 0.12400268177900996, 0.11615994333156518, 0.09598451879407678, 0.1295787604259593, 0.1423914014760937, 0.17604569345712662, 0.10395999904721975, 0.1218914200684854, 0.1490580216050148, 0.10769644712230989, 0.08987066043274743, 0.17120600172451564, 0.10437748128814356, 0.06002812712852444, 0.17735361041767256, 0.24253637130771363, 0.11478653417101928, 0.11655120019401823, 0.05376093342368092, 0.1534683092364243, 0.14464538624244078, 0.10899160762450524, 0.12935333752206393, 0.10083821548947267, 0.124793052939432, 0.12285312132111617, 0.08522751315363816, 0.11449005507997104, 0.09973803881023612, 0.10329135028379303, 0.14819614642432757, 0.07834792123841387, 0.09534750333321945, 0.1809478918356555, 0.1142620537430048, 0.11993243518684592, 0.14730024949780532, 0.08323042174535138, 0.10185811469065291, 0.08119518309831619, 0.09402068917240415, 0.08692035624491316, 0.1259881973798786, 0.14842321138296807, 0.13245124343250478, 0.13975561862545355, 0.10501369607767888, 0.10652061378849403, 0.11617436898606164, 0.18826401925512723, 0.08739394654652902, 0.11737264825829438, 0.17801314645579883, 0.10646058379539422, 0.12936928309500217, 0.12241911675248827, 0.1683864580201251, 0.10066765214183501, 0.15247911374483789, 0.1391736934227603, 0.09878205082246236, 0.09046805623386588, 0.05979268904775381, 0.13736391839172157, 0.15888665563293866, 0.14976073961172784, 0.14133551956287452, 0.13748753390141896, 0.1338073770914759, 0.12787299124257906, 0.12766073191804544, 0.22526604016976698, 0.14854743757418223, 0.10356682871601411, 0.12462586191083704, 0.1179229130170175, 0.10748266109398433, 0.1010652668774128, 0.1281375249049493, 0.07522955071181059, 0.14474257959851197, 0.06579489447176456, 0.15581656965826238, 0.12959129975310393, 0.14079221657344274, 0.1538023248847042, 0.07858734910509416, 0.09871473336326224, 0.11455048540873186, 0.13312502870602266, 0.1866944320499897, 0.100216833475445, 0.14037472754716873, 0.17374320700764656, 0.06518347335181066, 0.13227338583341666, 0.08780117612332106, 0.12704831335161412, 0.20209615917078086, 0.09663676736610276, 0.12377288910959448, 0.11225994796093021, 0.10375643175627504, 0.11961326588477407, 0.19114642244364533, 0.11741751299372741, 0.08380994493407862, 0.14251754113606044, 0.11412220767566136, 0.07126001228711434, 0.08645774463989905, 0.10432018579116889, 0.10793073169354882, 0.09598853572138719, 0.14894725754857063, 0.10242072878671543, 0.15216883325151034, 0.056433014505143674, 0.13912114767091616, 0.07731229359550135, 0.09975403866597585, 0.10754423814692668, 0.19776673934289388, 0.12003283122820513, 0.09459354236189808, 0.1416353370462145, 0.1111868651849883, 0.16958699002861977, 0.08784922318799154, 0.1388643900198596, 0.15312214781131062, 0.09888195831860815, 0.0937201049444931, 0.09527850989252329, 0.09039813320019416, 0.15303617742444786, 0.16320441822920526, 0.08186615245150668, 0.08940856451434748, 0.2878741813557488, 0.151169161179236, 0.1286166656230177, 0.07638726716062852, 0.1593458338507584, 0.13333622951592716, 0.1189507714339665, 0.18140424734779767, 0.19271784169333323, 0.24806925441537583, 0.20533045061997005, 0.1716508221413408, 0.16352300399116107, 0.08563616765396935, 0.09585898303027664, 0.11040731665811368, 0.2206633064363684, 0.10337961411901883, 0.2043414315474885, 0.1767413139875446, 0.12775973017726625, 0.12236533606691019, 0.1242017639534814, 0.09813930174069745, 0.16148943454027176, 0.11232669545071465, 0.09546355996280909, 0.07402943260967731, 0.23297035747340747, 0.16039612463542394, 0.09683677234819957, 0.17024938948452473, 0.19431709444948606, 0.16737686576587812], [0.06147262640297413, 0.06523146613367967, 0.018818196740799716, 0.0959860658539193, 0.07763550018093415, 0.040834390092641115, 0.024781038652041128, 0.0070225677253412345, 0.004805877364041018, 0.03596611846504467, 0.03333978421453919, 0.04503802988412125, 0.04923288943246007, 0.056060047554118295, 0.044949094299227, 0.02312497385511441, 0.026636504534898058, 0.03874249377154878, 0.0960883821493813, 0.0607234083914331, 0.051864831774894676, 0.026990180735343268, 0.07805210711168391, 0.02942962438932487, 0.020928340564881052, 0.07593642135283776, 0.02061019415434982, 0.018710947495752146, 0.03950555729014533, 0.0157864157642637, 0.019191633577325513, 0.051193621541772566, 0.06759039991136108, 0.05520038779026695, 0.04920187698943274, 0.02684811925116394, 0.018984714323388677, 0.030102459713816643, 0.0676974727373038, 0.07413734003369297, 0.02865414707256215, 0.015801750655685152, 0.008471960933612925, 0.05188323025192533, 0.06100965517440012, 0.041613657027482986, 0.03167472713227783, 0.041146845290703435, 0.025288537044876387, 0.02020269994890051, 0.03790698985436133, 0.026346457955826606, 0.06003677845001221, 0.020962810143828392, 0.002137607316918937, 0.013142300503594535, 0.03561267635918089, 0.00856360896224422, 0.06569206927503858, 0.0010610535162933438, 0.03175970346533826, 0.024189237372151444, 0.0432214525395206, 0.027224426290818622, 0.009012019677486802, 0.03422722998740418, 0.06289563647338323, 0.030146075944815363, 0.07461820423070874, 0.030308727574135576, 0.023613968597991124, 0.04127513590667929, 0.022650194420878376, 0.00221819183207117, 0.03478552860074809, 0.024087083925093924, 0.030191737958895307, 0.022539849359808222, 0.014937190172661628, 0.04655426727341754, 0.07054494494306189, 0.04802075447514653, 0.02929020579904318, 0.02083972728412066, 0.016426857826965194, 0.017367115676669136, 0.02918685134500265, 0.02607508805314345, 0.008052727224172225, 0.025521461153402925, 0.05854000483772584, 0.05249211365090949, 0.03234587629724826, 0.05341762863099575, 0.06455168939594712, 0.033636531326919794, 0.041547577894691906, 0.014950408034824898, 0.01983023002477629, 0.013777276118552046, 0.02305851474271289, 0.04659441279779587, 0.055438936954098086, 0.03514826324369226, 0.06573299850736346, 0.03949345222541264, 0.051419763692787716, 0.07362794343914304, 0.03139359989602651, 0.04076273679467184, 0.04289479221084288, 0.05429528992889183, 0.028567783135388578, 0.015124216476189238, 0.010190603622634496, 0.026249941438436508, 0.03406189475208521, 0.026966974837705493, 0.03864063209454928, 0.059580796132130284, 0.012063844578473695, 0.045772214952324114, 0.04617528850212693, 0.05922242107668093, 0.07888935147119419, 0.03347198319222246, 0.007790620172662395, 0.02716478645535452, 0.01411243509833834, 0.012793468195013702, 0.06840879456805331, 0.024653735304517404, 0.020960036631939665, 0.04140411862837417, 0.04800588098753776, 0.061614888054983954, 0.0137165031296068, 0.07673454138317279, 0.049253907054662704, 0.015922166872769594, 0.04141542302178485, 0.12101684271224908, 0.03450346498617104, 0.025570395402610302, 0.03107273086373295, 0.04922188698713269, 0.007824705531155425, 0.01627267601101526, 0.019043714639597704, 0.05616225867665239, 0.028245828447065184, 0.028376261537362422, 0.044035484216042926, 0.032315104734152555, 0.014253469450133187, 0.07335610873997211, 0.055834695896399875, 0.0217841038413878, 0.03421191545203328, 0.016088904979239618, 0.04599270151395883, 0.03130974993109703, 0.04238882900348731, 0.030112057591655424, 0.04153439395927957, 0.029219977424613068, 0.09334722959569522, 0.028309147638667907, 0.04824544116854668, 0.01287662350971784, 0.006148538710216859, 0.019996656005137732, 0.015829219449577586, 0.02910917265606778, 0.03491999388539365, 0.024285887900207723, 0.021937802201136947, 0.1059270313541804, 0.041812552604824305, 0.00234301555818612, 0.0380064088052937, 0.019322779129392335, 0.047645558536584885, 0.008128227815697235, 0.046983888505824974, 0.027371132347200598, 0.03761153195851615, 0.03776389699695366, 0.07503029890358448, 0.024642295204102993, 0.01436308678239584, 0.026097286326278533, 0.018094159163800732, 0.01703582434648914, 0.042765290409858735, 0.04183111732293453, 0.0649320354153003, 0.04101318067737988, 0.07976851572415658, 0.04843084068436708, 0.025333679979667068, 0.011573751457035542, 0.036460760315614085, 0.04637100514290588, 0.10809757666928427, 0.04529312851705721, 0.007192410129521574, 0.07564444773431335, 0.022779401059129407, 0.05054311680474451, 0.10014168572212968, 0.09593392722308636, 0.045050274048532755, 0.02215928620924907, 0.07838758161025387, 0.03138907067477703, 0.07553478290459939, 0.06710546450423342, 0.030762684464986836, 0.042603201964604, 0.04426822851278952, 0.02911480449672256, 0.018811699767996157, 0.0667432082284774, 0.052014665877712626, 0.02609340171329677, 0.05731381063482591, 0.07805037684738636, 0.0520835541454809, 0.025692507957241366, 0.015389813742201244, 0.02572261285968125, 0.06725695423249688, 0.0322770796317075, 0.11340570183736937, 0.016037624695205262, 0.016494231265304343, 0.045143779566777606, 0.009631394924196814, 0.024490691821223924, 0.04734037723392248, 0.020697073778137565, 0.042414467449166944, 0.024119911449296132, 0.017718729130657654, 0.03177902474999428, 0.03545879479497671, 0.02224899362772703, 0.01851101715250739, 0.02693185386514025, 0.03116043151489326, 0.029356108512729406, 0.020717446792072484, 0.047830388082989624, 0.025616540872891034, 0.0215636359394661, 0.023531745420768857, 0.030716065716530596, 0.018293972459754775, 0.008948407867657287, 0.018081674119457603, 0.033739387057721615, 0.015824873432783142, 0.02789643040991255, 0.020482144418305585, 0.03448480188048311, 0.056502269181822024, 0.051134748450879536, 0.035044650946344645, 0.018970799266493747, 0.06738736187773091, 0.0429898142548544, 0.03660923395571964, 0.011756896540256483, 0.05651839117386511, 0.024552409670182636, 0.06152484645800931, 0.02353049861267209, 0.027248130911695104, 0.022549162252939174, 0.07346286265445606, 0.07062064230974231, 0.034275792738688846, 0.10110766174537794, 0.04259560576507023, 0.05957618209400347, 0.05121327530858772, 0.015250595319750053, 0.008476530866963523, 0.02523472243254738, 0.08644215869052069, 0.011384587768199188, 0.0517845984016146, 0.07012537959963083, 0.05456513312778302, 0.014768692964155759, 0.03616098354437521, 0.026828507892787457, 0.04592368093186191, 0.021923751437238286, 0.03930061257311276, 0.031013874736215388, 0.04724818128826363, 0.017162525494183813, 0.029668648527669053, 0.038382680221859894, 0.06883149474327054, 0.02788674771519644, 0.05300270446709224, 0.047279007134160826, 0.030855860893747637, 0.03325875695528729, 0.03437313197978905, 0.02253260599848415, 0.055757526108728986, 0.025529517060411826, 0.04732092024226274, 0.0073342697495328525, 0.06892636072422777, 0.009361153934150934, 0.031050407061619417, 0.005485473441824849, 0.013469441743966724, 0.047764444657202275, 0.02449635080327945, 0.03841685803074922, 0.05255767709708639, 0.05639146102060165, 0.044341914023139646, 0.027568672550842166, 0.04742384043389133, 0.0620794470555016, 0.09183271907802139, 0.015154445211270025, 0.023560891892494898, 0.029182101599872112, 0.048639154327767234, 0.0173283781124545, 0.02993196082700576, 0.015589074032115085, 0.02052334336830037, 0.09055666612195117, 0.06682481563517026, 0.04275437617408378, 0.022397492712895786, 0.04556053577523146, 0.055885545310697386, 0.010483487326252674, 0.04307370153920991, 0.03450287805337991, 0.013218650112061628, 0.05046742283073919, 0.17987491083996637, 0.1637979463807174, 0.11468041129410267, 0.13643938728741237, 0.1377576451216425, 0.18883294372686318, 0.12469507248273917, 0.0821962325966784, 0.13131585078580038, 0.11908753695232527, 0.10105304646172694, 0.1739743703177997, 0.11826709311987672, 0.16023357478635653, 0.10715125102017607, 0.12627814896404743, 0.06739967728831939, 0.11522816547325679, 0.29959655233791893, 0.19202336110174656, 0.23475713016731398, 0.10337834525853395, 0.17263669281133584, 0.09122961679739611, 0.10321657572473798, 0.18113766450967106, 0.15514738485217094, 0.1466462095933301, 0.1744599435478449, 0.1399513759783336, 0.10148412654442446, 0.1682172178157738, 0.14173791797033378, 0.16967454818742617, 0.18909693456121854, 0.25941197148391176, 0.10282230616680213, 0.10398773077343192, 0.1992269331323249, 0.1628345623612404, 0.10555409493723086, 0.14813274411218508, 0.11305388821555035, 0.18236527006540978, 0.16202649500753197, 0.07772430684417486, 0.12213740258344583, 0.15041691011616162, 0.07664517832121678, 0.0819620294496417, 0.16411795706621238, 0.156176518914955, 0.1336652918585709, 0.14661454914935998, 0.0910903135580676, 0.16437062993645668, 0.1954740916511842, 0.14063371079308645, 0.16297101575349057, 0.09721781725862197, 0.1437668733830963, 0.11247635313442775, 0.13889906315931252, 0.14059462717601232, 0.1158429996243545, 0.11127114601965461, 0.15054341618503841, 0.14014690262930735, 0.23816519443477902, 0.09077661324824605, 0.16305386487926754, 0.13360351803047316, 0.1316059652183737, 0.10390294103750161, 0.16550853316273006, 0.1152896136045456, 0.2190159455473934, 0.18321737434182847, 0.08487312788409845, 0.11643063809190478, 0.21114422008395195, 0.19321051239967346, 0.11038409040442534, 0.09965733385511807, 0.11878819444349834, 0.15536195119576796, 0.11273132623838526, 0.14716885797679424, 0.11223798378237657, 0.09543677140027285, 0.12108840101531573, 0.16412498668900558, 0.13032352046242782, 0.13057788967021874, 0.12049910692231995, 0.14176911701049122, 0.2179152260401419, 0.13526966076876434, 0.1446437170462949, 0.18105846590229444, 0.12146980554929801, 0.12103315469409738, 0.10526982947651829, 0.08285972449396338, 0.12682887512658322, 0.11608691939285823, 0.07428151515445539, 0.17629314160772733, 0.1612239916409765, 0.15644915428544792, 0.19260979177696363, 0.10885341718260731, 0.08021875763578074, 0.1421021284269435, 0.10696235365633454, 0.16522314133388655, 0.16202587075531483, 0.08931419386395387, 0.2069975161658866, 0.17053282713251455, 0.12615445203014783, 0.10157990176230669, 0.14916407662842954, 0.1288345975003072, 0.18285441238965305, 0.14227223715611867, 0.09501396944480282, 0.09617158411336796, 0.09778447542339563, 0.14684917298810823, 0.11440165553774152, 0.09048358111509255, 0.19674314212586197, 0.17358535262090818, 0.07494710372494799, 0.1163110937923193, 0.12692328648907797, 0.2044034225067922, 0.12561766297689506, 0.14941326182867798, 0.14655232748814992, 0.17319283368332045, 0.09955013210752181, 0.09473403303750924, 0.09925994303609643, 0.13153509902102606, 0.08795336474265371, 0.13020643245960983, 0.1663637315588338, 0.13849996243204388, 0.17344736573951586, 0.14485046666647705, 0.15522437143538678, 0.10964600036719016, 0.15870703384280205, 0.17239104956388474, 0.1454610667590584, 0.1240367985197476, 0.11945628002285957, 0.09911159492496933, 0.18731234675007208, 0.12243886212153093, 0.146611020767263, 0.1379482184669801, 0.14373446655060562, 0.22358928514378412, 0.11266259742634636, 0.17449981426554068, 0.19277528646801198, 0.14185865649155208, 0.06960459040211779, 0.14139996681894573, 0.08893124905547925, 0.10079624131321907, 0.12689980917743274, 0.1423025405300515]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.022092094279027412, 0.07020418465669666, 0.058064317862902365, 0.01336809914625649, 0.03544515284842678, 0.01014396027728383, 0.052242999696838, 0.01004336406809411, 0.01940512444291796, 0.02460170184661235, 0.03141176767115082, 0.017170396500400135, 0.026375339798895375, 0.035174274883632145, 0.04124726168811321, 0.05801488658679383, 0.010313450691423245, 0.025884149995233332, 0.05384255779374923, 0.03477962873876095, 0.028478677916739668, 0.05345412702964885, 0.012998926054154123, 0.02556867362000048, 0.09202136538390603, 0.01350901645076062, 0.02685155433469585, 0.029726055982921804, 0.036431837760444195, 0.0201907068424459, 0.09126150794327259, 0.06072538292833737, 0.08865115658513137, 0.01944071190830852, 0.017918062363086, 0.02434863881873233, 0.04344511464504259, 0.05246195616200566, 0.045609702422682724, 0.04952100557940347, 0.015400968857907822, 0.035582759750208685, 0.02714389605846788, 0.016466579266956875, 0.014636816290606345, 0.024781572998368313, 0.012961118082915033, 0.023156708937936595, 0.04865776654332876, 0.015151502065626639, 0.04596494943169611, 0.01702251488209835, 0.04023933184466191, 0.0958744129166007, 0.006625563247195844, 0.03992605561922703, 0.040253255383244584, 0.09562586553926979, 0.027345841650718024, 0.046379988946552785, 0.032125654364270825, 0.028557839204690287, 0.026284526368337016, 0.08538314873086554, 0.01392786593974701, 0.020366270993170992, 0.03798733179324439, 0.025067583990416357, 0.02496506243811122, 0.03772029094398022, 0.03373741591349244, 0.0361989441859935, 0.027085871136348163, 0.033899338117667606, 0.023099818865635564, 0.04910285158881119, 0.04525810932474477, 0.042370919071670086, 0.012601661612279713, 0.04303248053682702, 0.019981378789192865, 0.027912304736673832, 0.011181498844442623, 0.015479599192206348, 0.029909195977130106, 0.05526025154228721, 0.03847883541935256, 0.05970669151949031, 0.05584180694339531, 0.02418659278191626, 0.025213969439002018, 0.03934579622000456, 0.08637891244143248, 0.049546454035277875, 0.06676802225410938, 0.026184885197186043, 0.01559062787730779, 0.05566716220762048, 0.01863068019572113, 0.039290638108338626, 0.008696271888246494, 0.06909051870128938, 0.03943355115396636, 0.055734774829553704, 0.08540336907442127, 0.06818442339343683, 0.05047097835423691, 0.0631060501826661, 0.02233586985883968, 0.0465576497704855, 0.03226109334666814, 0.028457740022401725, 0.06232941257102149, 0.04103854092370186, 0.026569168415984938, 0.021707159666610614, 0.04694473703524896, 0.03629184580807175, 0.04401546064764261, 0.04993868798815778, 0.03631851562697973, 0.025704833545855114, 0.009583318173619253, 0.07818509318998881, 0.026296672145170823, 0.06096116027661732, 0.044759613395269425, 0.041404691990464926, 0.02675085125624069, 0.05593775858038238, 0.0497688438876399, 0.035011633432337215, 0.02325819742067584, 0.052284777097936184, 0.013442737150139042, 0.028480157123080323, 0.02015033909784896, 0.010275500227830239, 0.03226344107783266, 0.038938318977930715, 0.0481318170869989, 0.011498758070436972, 0.08053169120103121, 0.04704346388046231, 0.03894263785332441, 0.031122050181563412, 0.013884453269253885, 0.061194644176534245, 0.0029500158104513374, 0.08433780446648598, 0.05717125042740788, 0.0059098627451541165, 0.05741048151893275, 0.02680452846522842, 0.06294434850237199, 0.017699278924348097, 0.0013167447011385644, 0.02247739869302937, 0.04144779592752457, 0.028000373493081758, 0.045906463105763705, 0.05969475608851228, 0.06105029942201717, 0.034182643451328786, 0.018858647605936443, 0.04099391367552536, 0.05295987533671515, 0.09212725077356611, 0.04159169963427952, 0.01704362071385341, 0.020968516623335223, 0.011118706365648125, 0.04139766576034682, 0.04080784919538668, 0.020515796362555454, 0.01752600652564849, 0.02856497060773628, 0.06320290427122797, 0.005880587351774531, 0.007142659941954272, 0.03171448928437062, 0.029946060784693276, 0.022908682336232493, 0.024117813079750965, 0.03952280904299446, 0.022820403233968785, 0.022499559646738426, 0.024304476367043595, 0.039492234255054166, 0.05750402435660362, 0.04798513477934258, 0.044092375984681506, 0.03927834644647581, 0.02098106443216758, 0.020014973057966148, 0.03335775860718318, 0.04391108499839902, 0.014197245190319206, 0.0058446054879043785, 0.0493375466737364, 0.01828846275540335, 0.020417418962876712, 0.01185742489594434, 0.023009499069303274, 0.02519124699756503, 0.017093443843935217, 0.038156436290591955, 0.03115416524399604, 0.01478736285519387, 0.014664045900904706, 0.11119069212249347, 0.027584385725536516, 0.03014183170827372, 0.04108288997252073, 0.11449023149907589, 0.051559653864907365, 0.014558129977168781, 0.011951252718323042, 0.0560961388317602, 0.016395894577726722, 0.011698322004771658, 0.027009030438161323, 0.03052650678104588, 0.037400762018348487, 0.04832800530961581, 0.04276539897546172, 0.01021264074370265, 0.04839999448241932, 0.027692527244133607, 0.02482710948346981, 0.08899583201855421, 0.01800336778563048, 0.10393426221396242, 0.04111559196774449, 0.0528537728158491, 0.024375335779041052, 0.02001394677375044, 0.025610345848170773, 0.02595280247208263, 0.037841531581112316, 0.020219222276604602, 0.02262739055523915, 0.026969665229054432, 0.02673199985708509, 0.03587861119636467, 0.016928771876596978, 0.04198543654222574, 0.012479885780651654, 0.014614412760628121, 0.005825544166977384, 0.011961419717408717, 0.037140767755252976, 0.02716921898536384, 0.016843670014558092, 0.049750197745327435, 0.026415483626936163, 0.016422912145831754, 0.04795266009335007, 0.025717467867902348, 0.027066943402002965, 0.03923495073935815, 0.05508601053484848, 0.07386480644345284, 0.06310450990817376, 0.0515008486275162, 0.011545111342067165, 0.015400940020169531, 0.019529345545119474, 0.020411695519994413, 0.07028398037488971, 0.05242338823154569, 0.0315208693167993, 0.03539937887606876, 0.00859741696954838, 0.025885854814467684, 0.05629612685048154, 0.03472253340961678, 0.05044636788911053, 0.013662099039980342, 0.028124268898474317, 0.02443302991533918, 0.10405352831419025, 0.042826786038598845, 0.049699467074658187, 0.015483653438942773, 0.018299675546586514, 0.040827747234808545, 0.03625429568013974, 0.011388772632926702, 0.04430115442456944, 0.02892930998599955, 0.01997642548355673, 0.044340193936867375, 0.037275270359324555, 0.03683182397591216, 0.11345367426318781, 0.03135877747886947, 0.022191167177100266, 0.09936569950410298, 0.007175519696569869, 0.023803359596058726, 0.04542485930557762, 0.03199903294444084, 0.02620529044153435, 0.04398258901866419, 0.01500380365177989, 0.05236197402700782, 0.017523709684610367, 0.05539934443575995, 0.05871657322027853, 0.060890341576720984, 0.035153477785310576, 0.0550048238198672, 0.07155710884502955, 0.010899151941495282, 0.018149753234216144, 0.022579876140558293, 0.048160054321799955, 0.025289049338815466, 0.06019871083221265, 0.022619517852685282, 0.05973556996988399, 0.07790455967187881, 0.0342832430531936, 0.02425953190374587, 0.08959684441132204, 0.04863353266513773, 0.027217873338876025, 0.06395934189536742, 0.021082379888477068, 0.02047433448024094, 0.021556837018579245, 0.05969186552933284, 0.013312998710067143, 0.022114523254068832, 0.022095105278172662, 0.08219511301389762, 0.026603146057043756, 0.015126998469765698, 0.03820166064958487, 0.02693105997916843, 0.048067020385393074, 0.06025273579039744, 0.03168168890156916, 0.0032722985280478106, 0.03130290012008377, 0.03210209223574825, 0.01483035653031298, 0.02956988097035459, 0.07495652179100684, 0.01405750259956611, 0.05930079187133482, 0.13432003743946552, 0.14488143500472817, 0.12388473882206849, 0.10447147195892674, 0.11605061776936054, 0.08997837786695786, 0.09409158929650273, 0.08813448609518153, 0.13261553033121995, 0.1037428474852017, 0.06266683446509497, 0.1771613135933876, 0.09650458874447004, 0.18559269474021026, 0.09567190414028508, 0.1923227443226746, 0.12975593949002878, 0.1418497541121074, 0.10360750010503189, 0.1251747967409236, 0.12818338030150958, 0.13428668065794877, 0.04016577186329024, 0.10469646060041018, 0.2081860788166523, 0.10482038145086595, 0.107062322220632, 0.1320239563605615, 0.10640965974224464, 0.13266788609325886, 0.17877275283847535, 0.13504665344953537, 0.1992652839315789, 0.16876593551465444, 0.20100459988628114, 0.053671159848038635, 0.12623480414705618, 0.13102036235587938, 0.19244431065661566, 0.18223660625517368, 0.08831323257514409, 0.09837161856038229, 0.17581603649471486, 0.08846467480595623, 0.07262504832553011, 0.08354309068194457, 0.07813097323690142, 0.15726126570786747, 0.15278240532747336, 0.10238899370389325, 0.13779336320502417, 0.1155145208218268, 0.12182588715638433, 0.2323028961462634, 0.1490548596318279, 0.09500851402325289, 0.16355634720197745, 0.15765443603907311, 0.15624996354537352, 0.11533020356936113, 0.17093175144067832, 0.08650374931416341, 0.07813924457877874, 0.1735116501471826, 0.14318519245300973, 0.11857312598398753, 0.12254246084817819, 0.06932960051511015, 0.0722582730065499, 0.1267341516379799, 0.10078545260642256, 0.27119652341519085, 0.07120881003460713, 0.1430936445082937, 0.08952379333121435, 0.1492421217262745, 0.21379373648336955, 0.10106991484229054, 0.14694233584616864, 0.19672133401036263, 0.19227888381906919, 0.1234328073582479, 0.07680987234094314, 0.10860535835048982, 0.11686233564146928, 0.12543055016015256, 0.11896438284644059, 0.1762553472071886, 0.1822388589914356, 0.08067841082811356, 0.07762471825948783, 0.08991394418158702, 0.21061304930065358, 0.1585133663777794, 0.15039921392287525, 0.1452694891818932, 0.18315427058509418, 0.15123609187347548, 0.11083795569304909, 0.1155086447085653, 0.13003785721957684, 0.1278095617890358, 0.11863285063632897, 0.11071189745728459, 0.1789723914116621, 0.18320418362106594, 0.14479494893125125, 0.11816622210400445, 0.14095407431679113, 0.17243083885737828, 0.15167984020497116, 0.11230033436524016, 0.14785523686025823, 0.15764205956033298, 0.1591528042086533, 0.127319673076272, 0.1311787867120334, 0.16941084233777864, 0.1328750021223511, 0.16723095359546797, 0.2044938983661788, 0.12349535471626691, 0.20093405938574246, 0.13163780208144868, 0.09734899164842707, 0.15931396984628268, 0.12469256190317017, 0.11219836412263767, 0.10415577675615038, 0.10376255214214325, 0.1464307475835085, 0.12418735186968531, 0.15346684360078403, 0.19856456081782067, 0.1837645314101662, 0.11500361109418528, 0.10962929483503103, 0.1836812344512769, 0.0953523005758013, 0.08963024190493993, 0.11419751149203096, 0.15696268315826142, 0.1431946512311697, 0.16468050330877304, 0.08455476603869881, 0.13798091028417858, 0.22112807578274182, 0.14920522299196037, 0.10334065263824803, 0.17246974605534757, 0.13477556513888495, 0.11742185561784677, 0.10486411303281784, 0.10364752010043178, 0.17786789924970695, 0.08683366661093064, 0.13305946865252086, 0.05973079986870289, 0.10049404217196362, 0.10033211657511336, 0.14424582411135944, 0.12320620380342007, 0.12666133125977858, 0.13071097752877645, 0.14447130129805633, 0.16987149976193905, 0.14415561966598034, 0.21622456104627677, 0.08233116607048682, 0.1076765660462635, 0.056660204992762635, 0.09978470166346856, 0.1402557667876993, 0.22573739130582127, 0.12011353618332318, 0.15375192330351897], [0.022553452290594578, 0.048852556983807256, 0.04676728994984712, 0.058908279719097276, 0.027485781016626527, 0.025574164664638892, 0.037976709327527454, 0.01764842102836285, 0.054638774533356936, 0.0464766225112336, 0.029702290293893645, 0.07354679065091269, 0.056354280694254806, 0.03757613957194345, 0.047712892959160466, 0.026994574249589016, 0.0421513247835849, 0.04032516313184585, 0.0718974620103836, 0.05114016316032835, 0.031108452339789698, 0.024917719353522574, 0.018465775830139006, 0.02389988289879901, 0.08315300768507378, 0.01688794951353754, 0.01531988222684179, 0.01747955910728446, 0.03456041103761111, 0.019890334656728164, 0.05626160638140781, 0.040375547749655585, 0.00710867254695456, 0.021084320498630404, 0.028024471664269055, 0.0745225782905306, 0.15507661364972591, 0.04913362993725708, 0.007624167899068977, 0.04479171149432659, 0.06011506103511367, 0.08512356158878122, 0.02160362709712769, 0.023173029401472638, 0.043324908773813925, 0.03788362789366927, 0.0359132911211678, 0.017132188193500042, 0.046528957917221954, 0.019407041304345642, 0.04247842616002474, 0.04188707610592246, 0.02126080067163067, 0.03581703414342233, 0.05111745259325419, 0.03171094733157328, 0.0258692815966372, 0.05309112775804741, 0.035941026240055046, 0.03527497626574976, 0.005618534158981804, 0.054260911952172, 0.02978920723710741, 0.04156808661563056, 0.02804657833517662, 0.038873909041285515, 0.047453115827270916, 0.05424129550478288, 0.04010446622435536, 0.06516503755535398, 0.026657522157100693, 0.003348037879082507, 0.03557912619518382, 0.06952686421573162, 0.044922539831272194, 0.005003414599091879, 0.017629001356129135, 0.046998317552996535, 0.030050032705600773, 0.02559559280052781, 0.0866209798093353, 0.04031797744599836, 0.030382440225886445, 0.04624945916501539, 0.029419018886983395, 0.01361497478293521, 0.06874844884233815, 0.009421731844278318, 0.05121963996706264, 0.04541754469807659, 0.025620912334748676, 0.028684888101582016, 0.04765397237081613, 0.02257540968379804, 0.060595701315573285, 0.03967718933043735, 0.012929981807246804, 0.03226555132174066, 0.058871706681592126, 0.014154387222203826, 0.01655114338999348, 0.034362702896552424, 0.04706524146188583, 0.029349923666034426, 0.035661235717790465, 0.061571590735444, 0.04524447416354503, 0.09452447428234986, 0.03161709915314402, 0.01735554326192609, 0.04583669274247118, 0.04282587340899876, 0.05069292376616171, 0.0586874233558774, 0.05429821102214711, 0.051773782553417344, 0.05532763685498919, 0.03489161755091377, 0.07314494864216872, 0.05770091486296483, 0.045500359897102625, 0.03360674024692603, 0.020702418937746967, 0.008926540380343795, 0.026320519258401225, 0.0046688124421052635, 0.0280565544962883, 0.004704290917808456, 0.051057371710027964, 0.053743915765413215, 0.041834571066179445, 0.037857582326978445, 0.025226066022046974, 0.012819211813621223, 0.02779109463361757, 0.03824809280091098, 0.013905073100301837, 0.01709034972425018, 0.010817462262431425, 0.029419276730290482, 0.027989008031519394, 0.02014696677880628, 0.01733769609459809, 0.05753221070127828, 0.0283079211866217, 0.03870192416278379, 0.053695950124944956, 0.0714198819228581, 0.08881629843797002, 0.033700177911669016, 0.019351304741576314, 0.025623499249507273, 0.024076687072270682, 0.024838709039613605, 0.038916300516575575, 0.11715226008423738, 0.006415321292089564, 0.04396505567378231, 0.04294654407671519, 0.042272891117525954, 0.04809468425810337, 0.08102299805198397, 0.03233024624309369, 0.04485957856689181, 0.0352514582420034, 0.04600870815504875, 0.08200562532458987, 0.02896508913753288, 0.029227146147085086, 0.029920452873089483, 0.03712467968996082, 0.029528863528477292, 0.033303669188171625, 0.030833014619669745, 0.005462453293148428, 0.029731589435998882, 0.042969169826912026, 0.02254823435630117, 0.0971026291538562, 0.02153906618644084, 0.024624300455408435, 0.026142015354707837, 0.00664900875251208, 0.07458870831344809, 0.04703351316441383, 0.11018825162734304, 0.01581047322334988, 0.06100278161466122, 0.004398475184903613, 0.022192768519744277, 0.005697931661935789, 0.019962847997833575, 0.04442143154197505, 0.04210980183311871, 0.04306660745558994, 0.017944275867193937, 0.04574055111567889, 0.04538953137983169, 0.02307742042466998, 0.021190419626821364, 0.052450376961912425, 0.025804411952516863, 0.03283778704436762, 0.01983763793084238, 0.04345639868240271, 0.06540931016206741, 0.026836112574008957, 0.003903487281474684, 0.04145318688824773, 0.01950291490980557, 0.045988755832825384, 0.05841326806694269, 0.010721631065410162, 0.03558459858010922, 0.04658972751349211, 0.021525308888937746, 0.04158602368884853, 0.03961063861580832, 0.01579053616816444, 0.026679364199350988, 0.08891915756144694, 0.05197880869465215, 0.03065390173079712, 0.07186199498495885, 0.025756846647709608, 0.030285012775233815, 0.04481074779427477, 0.0320753138512373, 0.029064528444515805, 0.037914155184158256, 0.044742219150066376, 0.015468522108026912, 0.026174820826521943, 0.026500339520030787, 0.03772355469741991, 0.03809792960860899, 0.03183178763304438, 0.03175171032281859, 0.0491955733991095, 0.0025946286415481673, 0.04742291084091578, 0.029789665248245, 0.032762585008250814, 0.04867622948118618, 0.030757242614137273, 0.06796551442572049, 0.01744796990949128, 0.033694203410829814, 0.013363306992687285, 0.04890447848343423, 0.02598835770705981, 0.0029029653440894826, 0.05150679937962975, 0.0714610486424395, 0.023252984575395073, 0.021829489352447645, 0.02896063116246036, 0.03715081007352897, 0.01522008838531162, 0.046110563046698055, 0.0344762726952987, 0.03820243078683104, 0.03746948743771229, 0.015781014625515257, 0.059548056817480495, 0.04698825487866998, 0.0438015524830137, 0.022911898592220883, 0.09834679774940014, 0.05860700338546719, 0.04046954520578895, 0.02232077924002494, 0.03842934307509235, 0.019405860653413192, 0.08055221009999514, 0.021769316866993904, 0.0355429908127657, 0.035016664769500494, 0.03612719250044652, 0.031127559885914837, 0.04838030678885324, 0.0369129835494927, 0.0026020433329644477, 0.07745602766850165, 0.019994216671745692, 0.03243989750210728, 0.031926623079925776, 0.03633009482707296, 0.028462830731379132, 0.03479127918503114, 0.010245050120699619, 0.028583467472344637, 0.04018166654610208, 0.056466768229646344, 0.07284191490284034, 0.06661415765328066, 0.03474307944998145, 0.03105295156793935, 0.0921217817813158, 0.056042700806366544, 0.01782714036692466, 0.02522247487546078, 0.011186714234229709, 0.015794168026851754, 0.05620546439396484, 0.010706577766021448, 0.05364276994285839, 0.029532707429357936, 0.02123557952498751, 0.052034696231463125, 0.018259070314733044, 0.02187046777856137, 0.022530477094863142, 0.02197505546999829, 0.027843508071133068, 0.048148068000695536, 0.03389049680637462, 0.03476462972217372, 0.04019731356363211, 0.03513178162808929, 0.0905248699709773, 0.02423678232090814, 0.02193838743759053, 0.08494308484452111, 0.0017252353988754163, 0.038619054680956263, 0.026448614795559218, 0.022823882422276905, 0.060518809727260044, 0.014574268932587333, 0.036656945145555904, 0.06104953267744609, 0.010293494976524795, 0.04023749980011156, 0.04226459602692297, 0.015769013037372912, 0.003436721133766696, 0.02078129184831466, 0.030574245112282888, 0.046851889695972204, 0.07166880249444928, 0.023518166238708154, 0.042559097188391855, 0.033245359281344075, 0.08631904529673712, 0.06578807519482714, 0.018521130716960345, 0.03129842518163579, 0.04360690453488912, 0.03842151278097715, 0.009141332336834498, 0.027564160292968154, 0.09553763563079493, 0.08798784789230142, 0.20225290076008864, 0.14704590743141516, 0.09686136245727539, 0.13810417295566627, 0.1396878194063902, 0.1723044549248048, 0.11311862045632941, 0.20858018552618368, 0.06724422491554703, 0.20523301299129212, 0.14601171149739198, 0.06856818244393383, 0.0820828222536615, 0.08752486987837724, 0.12037325224706105, 0.10944312518196446, 0.21833390928804874, 0.14544197278363363, 0.14683339026357445, 0.12422198429703712, 0.06199378879474742, 0.13644702759172234, 0.22937461041978427, 0.11357078262205635, 0.1686845655952181, 0.11618416703173093, 0.15472662528710707, 0.13482321186789445, 0.1131947860121727, 0.16266426364226, 0.12161166008029665, 0.15781694517603942, 0.12851261906325817, 0.14893296760107788, 0.15929502514856203, 0.19593377198491777, 0.17574689377631458, 0.1416651111628328, 0.12209916034979479, 0.19874705959643635, 0.14013805453266415, 0.1167947535536119, 0.21637373018477643, 0.13396939768322877, 0.17407476635915892, 0.1153969985565969, 0.14067829054381165, 0.070203614687281, 0.14741033501923084, 0.10281160566955805, 0.07615524889635188, 0.09599448647350073, 0.15278206605996403, 0.09363171897296395, 0.11974285250263554, 0.10767117847821542, 0.16982796495514257, 0.16751346843583242, 0.13871285957949503, 0.11353782617620059, 0.13366985161389622, 0.10171995139015572, 0.12956248915621213, 0.21157479126538548, 0.14305895779814037, 0.1383631019187825, 0.09499516723943607, 0.13631484897008964, 0.18887280087385858, 0.10955401816006217, 0.13739822512226446, 0.17281635531357356, 0.09863002505153418, 0.09719024159546409, 0.0647101883909532, 0.15577661751636437, 0.17516025954059192, 0.05686032193313752, 0.2078900204173156, 0.1298787814698049, 0.1095884470269084, 0.08506114315241575, 0.13574538167033876, 0.10596040849174772, 0.08281959593296051, 0.13287758055542195, 0.1268449021237237, 0.1142718925007752, 0.0641158799241696, 0.11443311242120606, 0.15002916806510516, 0.11504467603351388, 0.1079295781840171, 0.13217889304671968, 0.08876134388680969, 0.12352389389915125, 0.21691064137433255, 0.1031042578231011, 0.10411560069769621, 0.1036827564239502, 0.08627777679690293, 0.11820210303579058, 0.0793029728478619, 0.14720400609076023, 0.1292277949729136, 0.20365488981562002, 0.1331413271171706, 0.0944313724924411, 0.07835095428994723, 0.09958285785147122, 0.12653976492583752, 0.1013004199734756, 0.1315214740378516, 0.12024814396032266, 0.11519354661660534, 0.09989093989133835, 0.1675518328057868, 0.18876329889254911, 0.09708353517843143, 0.07567800129098551, 0.19630727837128298, 0.0997276504391006, 0.09985611068883113, 0.058405173144170215, 0.0741867713098015, 0.11408268979617528, 0.11489416339567729, 0.12206269587789263, 0.18850792545293057, 0.09540298035634415, 0.07373259389506918, 0.10887759338532176, 0.09789424881871257, 0.05935498646327427, 0.13776544827435697, 0.10609502983944756, 0.14671566443783896, 0.11267662274518184, 0.07879410551062652, 0.09338967196111168, 0.08977843395301274, 0.17580466424780233, 0.28078946151903694, 0.1189550869166851, 0.04903479452644076, 0.18732195480593614, 0.18589917543743337, 0.11066533638430492, 0.15164429854069436, 0.07828385396195309, 0.12162559718957969, 0.15205026604235172, 0.17481099042509282, 0.19624961646539824, 0.11489314559314932, 0.07241101802459785, 0.22837458550930023, 0.14809570967086724, 0.14851830128048146, 0.16538274634097302, 0.09706890596342937, 0.16355157031544618, 0.13632632978260517, 0.14479866730315344, 0.14436425561351435, 0.12725241668522358, 0.09282876777329616, 0.16955613025597163, 0.11152876541018486, 0.20174470517252172, 0.08858351342912231, 0.07052357787532465, 0.11127931558127914, 0.11820451862045697], [0.016532168158196976, 0.01847204040469868, 0.04812663307945643, 0.030576867650129964, 0.06723066778587443, 0.022490468973826085, 0.04240197901214872, 0.040716603198753934, 0.01826437476224133, 0.04643036677901234, 0.020187778963840435, 0.03572133695706725, 0.012180483900010586, 0.020541294012218714, 0.025515576558453695, 0.0027551734196354766, 0.0023503490374423563, 0.03278121418718781, 0.008206629144426967, 0.014550106300573264, 0.03960957670850413, 0.058795805754406114, 0.01333803919676159, 0.045285335542368035, 0.05099059029349259, 0.0336216171272099, 0.022679544453110014, 0.05952336492815188, 0.08583523625774042, 0.04626616130449942, 0.048834616517914195, 0.07920331640967301, 0.04164230138329523, 0.051580495068005154, 0.007999392675368913, 0.07937320122229201, 0.04964916727372578, 0.12648472216512474, 0.008507017445351397, 0.054530958711568794, 0.019309544303853596, 0.05006434928093638, 0.017891577444970608, 0.034114213194698095, 0.02327502508913832, 0.04712165825601135, 0.06814220494457654, 0.037898738868534565, 0.013822861797442394, 0.00606035121018067, 0.004687486998071628, 0.03131440807400005, 0.03678364798958812, 0.016138105553441813, 0.008846348567333604, 0.06129732009555612, 0.07363784326506512, 0.024008385737293532, 0.0030165974832406, 0.02107250890029328, 0.04336103397820677, 0.031886494518922906, 0.024336140203688825, 0.05229751659291131, 0.09935158597571508, 0.06265943164804152, 0.006236684649983155, 0.03292234607839158, 0.018129816179030707, 0.003430923688158925, 0.017757051092173372, 0.023406703291194778, 0.014877182231949908, 0.03839053426470075, 0.029694463392453532, 0.03806380608252116, 0.015413384352411543, 0.03563169230307851, 0.03878354514017701, 0.03562740056908556, 0.004977764703133809, 0.03717070811295083, 0.0585295350423881, 0.10129523596593312, 0.024164903410045162, 0.04012707840385182, 0.028045221265139322, 0.09426591172814369, 0.01984872010403446, 0.023070976038330367, 0.03403581525864346, 0.039947666959570985, 0.02004196009199534, 0.024410746825326766, 0.007682323439179787, 0.017526607029139996, 0.009159065849546875, 0.031659700974289856, 0.01652982721238264, 0.013180328998714685, 0.06328122078308038, 0.03156392914908273, 0.009077744275730635, 0.06823925580829382, 0.051230849365570715, 0.07252498476633004, 0.014805897039228251, 0.023812847211956978, 0.03092500361214791, 0.020559577138296196, 0.05022077874413558, 0.07548622693866491, 0.05540801611329828, 0.03724134360839214, 0.038936076419694085, 0.0034160521089298917, 0.014663107826241424, 0.0187325079459697, 0.020295555769865, 0.04988412020195808, 0.024012110894545913, 0.04636947504643883, 0.029864948708564043, 0.009969614096917212, 0.06652465209897075, 0.028850016383720294, 0.03780220029875636, 0.028877106894339834, 0.010033351435725178, 0.04464714960860355, 0.0728859111134495, 0.014299009327909775, 0.047891921031155756, 0.0162068157057677, 0.060409687725561004, 0.011588278891784804, 0.06999611189322812, 0.012311888991722038, 0.04323088756895491, 0.07085019749190126, 0.032032579715762816, 0.0017729609015597297, 0.02761133374380214, 0.0320194364924516, 0.021131049509027174, 0.007482043650400425, 0.022960133950359056, 0.02532756807548659, 0.09525368908154112, 0.03068007282646639, 0.03410588078466909, 0.035424885007419755, 0.04892228663499866, 0.0032348251593897915, 0.052336729131639004, 0.04947531642392278, 0.048742271294551234, 0.04094769526273012, 0.03731717328940119, 0.01574366805808885, 0.0870441956711667, 0.031119251224611486, 0.013944059177967054, 0.05232160797874842, 0.014240199001505971, 0.00881824703953628, 0.026687718661768094, 0.05351045561422195, 0.03258580627984234, 0.05878041658018317, 0.04533652083149978, 0.025556979068954076, 0.028676484445376054, 0.019921691456277455, 0.03182065626606345, 0.014550962951034307, 0.06343281229159661, 0.012878827900359673, 0.001108184558688663, 0.03127480198496154, 0.015565503421904785, 0.01566323112430317, 0.0849476038877453, 0.0378790884943945, 0.0113325712736696, 0.09909334233296768, 0.06722236930259637, 0.041248595009424856, 0.013656910791594003, 0.05103536003402301, 0.05738779130790915, 0.03415562418688621, 0.0704714935272932, 0.0282716992909887, 0.019386512227356434, 0.04375966990898762, 0.015362131209777934, 0.03400163744975414, 0.010131872175926608, 0.0433946044982544, 0.041610393274043284, 0.02788212858805699, 0.018634914254237498, 0.03295500736151423, 0.01775109694738473, 0.04942659760958382, 0.030335862189531326, 0.08818650258971111, 0.005776035283426089, 0.06410004970218454, 0.012275284571972276, 0.04596367717853614, 0.03103818664593356, 0.005551266317654933, 0.033639452420175076, 0.03204944470365133, 0.008213932725733944, 0.021499568663005317, 0.05113756437120693, 0.036386586260050535, 0.02622403497142451, 0.046189042406954935, 0.0515221851611776, 0.032496131091777763, 0.013262540301574128, 0.04319063687164869, 0.01635302134257342, 0.04839993680694273, 0.005217232433746436, 0.005305066247404153, 0.014114704797975719, 0.021587169230250374, 0.043012643565556834, 0.024136362530823265, 0.02797345431255443, 0.01638764698457505, 0.04486400940056358, 0.0353664767130145, 0.010716698115824588, 0.0359811615864081, 0.0466553961325969, 0.043210928461381366, 0.010772582259960473, 0.015655656977157508, 0.010015160760043986, 0.032153582865638394, 0.025001525213675838, 0.04047849847536002, 0.03350492606737784, 0.040776429631348164, 0.03109507162922195, 0.050601460638323, 0.05682961483086858, 0.03902907303667494, 0.0036972024577802843, 0.014971284861011165, 0.04309090240193265, 0.07526324676083666, 0.008319649329808141, 0.03873787973342197, 0.061083690130284855, 0.0323244685174099, 0.02672039860460375, 0.03612386767885514, 0.02859290250177894, 0.02894339637298669, 0.0335223135272307, 0.031684881408831904, 0.04636757175571152, 0.04464258306792804, 0.08315006962844304, 0.02753477972666068, 0.04289058868640235, 0.0331590971244233, 0.042812679295561144, 0.028820493325058903, 0.02840351659272398, 0.061899845621415546, 0.03271500613274319, 0.03392980094732983, 0.06116095491285835, 0.07878183759748936, 0.025049501032169377, 0.009395462361031344, 0.031184723068560873, 0.0395127022638917, 0.024235710235578672, 0.02973427643467273, 0.05301257036626339, 0.07231442856469325, 0.03179298560800297, 0.01979851020899202, 0.014892774966678448, 0.006611482797390116, 0.030678770039230585, 0.026110733194010596, 0.021152163822469965, 0.06345540072236742, 0.05153745219909719, 0.047133346021707566, 0.06922398653945752, 0.012417126380439316, 0.0708690064826182, 0.0575909379071423, 0.03861918020993471, 0.03466471544067774, 0.03221614718703287, 0.0187843429323818, 0.02790340405356671, 0.037434491994125504, 0.03948847856372595, 0.010843847944800342, 0.021581995400733182, 0.03605168512357133, 0.07412009167351893, 0.04130417720547744, 0.062366976269653866, 0.050633477313177924, 0.049274466665727754, 0.04132932371326855, 0.13564026302524976, 0.018876370940623537, 0.007460981075252805, 0.018177425588614175, 0.04100338602438569, 0.03026688571221062, 0.032673242302345376, 0.028947966306337287, 0.00973207425392632, 0.026988954283297062, 0.05878632662019559, 0.05999888226922069, 0.04472513024562171, 0.0319399155809411, 0.012908251723274589, 0.03725967423192092, 0.002337879896263725, 0.03445750441668289, 0.010344856684761388, 0.02731612860225141, 0.051537072219486744, 0.012607374877136732, 0.06033861796770777, 0.014535331200542194, 0.03188743428992374, 0.009048044797964394, 0.055940859485417604, 0.06584093985813004, 0.05339216321174588, 0.046887790983808894, 0.05916980068598475, 0.008443708431773951, 0.11363056834254946, 0.053900124704731364, 0.1219555823398488, 0.1349231872175421, 0.19468272982963494, 0.18462237609284265, 0.21390167783413613, 0.14897662454417773, 0.1082817582147462, 0.19655544576900347, 0.13117531261273793, 0.11025412380695343, 0.06798023863562516, 0.08474687965852873, 0.10407487502587692, 0.09295889721917254, 0.17860758384423597, 0.07411065325140953, 0.07070446852594614, 0.1310827468654939, 0.10132369372461524, 0.17056061992687838, 0.06178075594029256, 0.11844849267176219, 0.18349831498094968, 0.10032972813184772, 0.13056457681315287, 0.14711340809507029, 0.23534324871642248, 0.1746439758156027, 0.05780376720109156, 0.16123936724449905, 0.1039906484740121, 0.20722240981246742, 0.07171608281454869, 0.12876066432467528, 0.17465012334287167, 0.17940209406827176, 0.1491464211472443, 0.16982933559588023, 0.15372332983783313, 0.13152838152434143, 0.13553464226424694, 0.11963149133537497, 0.11014171769576413, 0.11107188742607832, 0.16362985968589783, 0.11366695139024939, 0.12230728061071464, 0.08753753134182521, 0.13046918836023125, 0.13566690231008188, 0.10932127386331558, 0.12119905650615692, 0.1364669765212706, 0.14802078583410808, 0.1780820856136935, 0.1254793368279934, 0.1141406095453671, 0.09354874771088362, 0.18306612888617174, 0.15565570257604122, 0.10309315020484583, 0.07592850963452033, 0.14912982418068818, 0.09359758866152593, 0.07322826595710856, 0.1127511394609298, 0.11580764794988291, 0.19201137817331723, 0.09360934767339911, 0.21778463519045285, 0.10493527778557368, 0.08768876322678157, 0.09703122691384383, 0.13013251285467828, 0.106127246682133, 0.08011533532823835, 0.11033181606658868, 0.15570047231657164, 0.14274745594177926, 0.11868801553334508, 0.1725255623459816, 0.18228718425546372, 0.16117334578718456, 0.12676355934568814, 0.15418960553194794, 0.21049765763538225, 0.11979834309646062, 0.11633852017777306, 0.2278558047754424, 0.08053346896278006, 0.16016356354313238, 0.14114273419337614, 0.21288185327180795, 0.07779281852500779, 0.08919806938086237, 0.20784116589597293, 0.14997470884450845, 0.1251134028924363, 0.15630662121943065, 0.08541800507477351, 0.10437599529645272, 0.21890187024005822, 0.1880114006676844, 0.21754025401813643, 0.12147275039127894, 0.09867385841373887, 0.09916340785899333, 0.25230076164007187, 0.07626107321786028, 0.12324964361531393, 0.11917481012642384, 0.12564587646297046, 0.08570279300745044, 0.08065306075981685, 0.10220224729606084, 0.05725523270666599, 0.10919430639062609, 0.09072435248110976, 0.06941314174660615, 0.13572521560958453, 0.17860919875758036, 0.12420012189873628, 0.14106586974646362, 0.10004748470549073, 0.07817173962082181, 0.11660063825547695, 0.1451261147324528, 0.13160287109868868, 0.17080935729401453, 0.14944414874272688, 0.09021032149238245, 0.16911292475249085, 0.11945885845593043, 0.051766746145273955, 0.17936428609703267, 0.1012275724538735, 0.1156900306897504, 0.21414388769439288, 0.19881384101297173, 0.09896184224635363, 0.14173041337302753, 0.145691008706178, 0.1873111253870385, 0.12640008170689854, 0.12344673089683056, 0.1631344069859811, 0.2030768051211323, 0.11760724495564188, 0.11204042831169707, 0.10978497790970973, 0.15363341037716183, 0.06881652626075915, 0.12492228671908379, 0.09651581849902868, 0.12314461996512753, 0.08499907755425998, 0.08443520138306276, 0.113597367624087, 0.15813611447811127, 0.1501770479870694, 0.09814544248261622, 0.13749389855989388, 0.18868617660232953, 0.09168403169938497, 0.19067907466420106, 0.1477160964693342, 0.11608117898660046, 0.10782920249870845, 0.27842908246176584, 0.21351020384047711, 0.10436821928513901, 0.15055189787277154, 0.13279811053403787, 0.05763976528708424], [0.07391400701765503, 0.07202305205698524, 0.043619467610759396, 0.014664045900904706, 0.04351926834455558, 0.052170942670532634, 0.01992780844947057, 0.04663644125685096, 0.004222023425557251, 0.015204563504084945, 0.029389560289148773, 0.040285248309373856, 0.015358095622754522, 0.025905766424589922, 0.011887859736037041, 0.020019532813291465, 0.02974621525832585, 0.04163163820547717, 0.07153000815638474, 0.04819149763456412, 0.04352503928488918, 0.012247260227533323, 0.08214289295886244, 0.035757112715925486, 0.04223142584253635, 0.01792929720665727, 0.009146074448446078, 0.07856392607625041, 0.04512457024039967, 0.04513621050864458, 0.05926440203828471, 0.016208679980731437, 0.03776274348742195, 0.041985579034579654, 0.018015739175357988, 0.08917638340166636, 0.04462591824787004, 0.0269557756172227, 0.02057583992635565, 0.026043980615213513, 0.036767525997545035, 0.016469228946204697, 0.06766806502959558, 0.01543290919757315, 0.010090897142487978, 0.008923147705250552, 0.01743553066626191, 0.03701442453478064, 0.05903123704982655, 0.041690782710377655, 0.015334859191040908, 0.033908108182783635, 0.02077577875128814, 0.04069138883746096, 0.0225127266187753, 0.018103626423648427, 0.018858761260552064, 0.033867535181343555, 0.044639607691871266, 0.034484757775706906, 0.04545093201366918, 0.08618373862866845, 0.01739537326752075, 0.014227628292116736, 0.022450386213936975, 0.009241467990380312, 0.02496400222714458, 0.012701972836761602, 0.05290902252974255, 0.017888742864930203, 0.024574777577072382, 0.05576879657538874, 0.04831348466021674, 0.08168086489396435, 0.030698315240442753, 0.03187813836016825, 0.026818014348724058, 0.0350167122669518, 0.017142790303166424, 0.021848976878183227, 0.015657112434772507, 0.05022147084985461, 0.016434177523478866, 0.05426866760743516, 0.050999343395233154, 0.042965946785573444, 0.028983039781451225, 0.019648791457127248, 0.07206271242882524, 0.0251294121013156, 0.04422093801466482, 0.042706549633294344, 0.0036825232008205993, 0.022589248405503373, 0.0354545810925109, 0.04055735102987715, 0.040210623028022904, 0.042478151353342194, 0.034400660145495615, 0.018305293816540922, 0.020554956314819198, 0.0451768174368356, 0.021462217006566267, 0.04520729722987328, 0.06600253297282116, 0.04187903207327638, 0.03523761612762298, 0.01902890222014061, 0.04417391214519739, 0.012215857626870275, 0.03918524465656706, 0.03617336680846555, 0.012809746250111078, 0.02510026393325201, 0.06867505170937095, 0.042916434085262675, 0.02010079925613744, 0.03877578269956367, 0.022865999090884413, 0.031306818659816465, 0.04480018639670951, 0.024747666603486453, 0.01522185088002256, 0.003960133081169001, 0.058962542164538584, 0.056326196129832945, 0.002397631265921518, 0.026185114202754836, 0.019246905343607068, 0.01692643601979528, 0.03839779458940029, 0.05546156609697001, 0.07725313891257558, 0.03620295772062881, 0.010148757519865674, 0.019624213222414255, 0.03313934157735535, 0.050835388978677135, 0.016483993868210485, 0.05397305364853569, 0.025693595309608748, 0.05943949121449675, 0.039347414526024034, 0.021983465911554437, 0.050498224927910736, 0.029873796805207218, 0.01742430430437837, 0.07694498901920659, 0.08896212239882775, 0.016538247831964066, 0.05743566195347479, 0.024755232268944383, 0.01826938913602914, 0.04295918518411262, 0.02038735816521304, 0.01932398183271289, 0.01043649368719863, 0.06448035500943661, 0.058890481745558124, 0.019417768942990472, 0.008315340632439723, 0.019131515374673263, 0.027330298109778335, 0.028011525216113244, 0.0496786767616868, 0.052470804258648834, 0.020461274377469505, 0.009248177853545972, 0.04531178483739495, 0.03565643508253353, 0.0547065669670701, 0.053164355257259946, 0.03460482454725674, 0.032813695658530505, 0.05791093502193689, 0.046883560317967615, 0.04877775528335145, 0.020273571235260794, 0.028031197642641406, 0.009328873478807509, 0.04066780296021274, 0.02956313293959413, 0.03330024258632745, 0.0160907963956041, 0.041251512710005045, 0.03788031664277826, 0.018869680585339665, 0.013167262958761836, 0.04189223975741437, 0.05339532857760787, 0.04099638354299324, 0.03775372236434903, 0.01828440511599183, 0.015501894156581588, 0.0654456117855651, 0.025799719882862907, 0.005885424034204334, 0.03955700042258416, 0.016266423310818415, 0.045795936536576064, 0.03107453915955765, 0.030907300633511374, 0.034911417202757936, 0.053585932457021306, 0.02532036372992609, 0.05646505492872425, 0.04038269950875214, 0.01160711417573371, 0.01047987667178469, 0.05843760033271142, 0.03312535697062101, 0.020195398912099854, 0.029691596581999744, 0.01027650191515152, 0.04183256599519934, 0.01992161342475031, 0.04914324138579624, 0.04694659961387515, 0.02822995581664145, 0.024265684520027468, 0.004481314556739692, 0.012907905670415078, 0.05023754873712148, 0.052476911073816676, 0.07426322185035263, 0.0349648518354765, 0.010088401829956897, 0.04770838748663664, 0.02312150993384421, 0.07257998681494168, 0.030502676631190946, 0.01808592344501189, 0.02512292191386223, 0.024222214174057757, 0.003908396906418992, 0.002263278151596231, 0.06686307822487184, 0.04537558748519846, 0.04817231884226203, 0.0033035987123314825, 0.021235476048397164, 0.022520317729296427, 0.018874225073627064, 0.03546616029260414, 0.023652587418577502, 0.051371753947543244, 0.034977302953068695, 0.043353295286319087, 0.021146246997107352, 0.03510804308046188, 0.047004359907337596, 0.032985972307090244, 0.03833460262311356, 0.07737325996692691, 0.013422628764861395, 0.049917219140167744, 0.012097629685220974, 0.011270340282603033, 0.04048531096694725, 0.003944656121478016, 0.06147670439843621, 0.05448047570618136, 0.02876214949148042, 0.01478016359864601, 0.02914513161938105, 0.011494567268528044, 0.04244179544704301, 0.008138952061666973, 0.04945310458008732, 0.04241092888904469, 0.02589807692649109, 0.031241848931780884, 0.025999104005417654, 0.02217860919024263, 0.08812962099909782, 0.02338742950399007, 0.029730955005756447, 0.038508009032479355, 0.059366141578980854, 0.03474668925628066, 0.03396187190498624, 0.01191167885969792, 0.028192142756389718, 0.06506739636617047, 0.0383194237947464, 0.03420109281848584, 0.04738037008792162, 0.056666247347103696, 0.05846203437873295, 0.01987143576012126, 0.03219180813591395, 0.06484166133616652, 0.024662233955625976, 0.01441724575124681, 0.03415710339322686, 0.011232045462488063, 0.02793407722908471, 0.06509148435933249, 0.016487434040755033, 0.058958918787539005, 0.04791209048458508, 0.0478546491025814, 0.06313142060701336, 0.027599466166325977, 0.04652539560837405, 0.01803950995339879, 0.0277436887845397, 0.012969932252807277, 0.012899811595811375, 0.06506543539996658, 0.0288157266165529, 0.05925434614930834, 0.07926031335123948, 0.028534338144319396, 0.03026591201445886, 0.02980127837508917, 0.06318001049969878, 0.08060480334929057, 0.004884735431655177, 0.02936427468167884, 0.037784436251968145, 0.06540943908372096, 0.03882260161585041, 0.06399319400744778, 0.02125790502343859, 0.06894128170928784, 0.05276741905670081, 0.03141271083482674, 0.04579241493982928, 0.023805306991562247, 0.019867939608437673, 0.020942703454888294, 0.07326034030744008, 0.04259246754060898, 0.02967622776382736, 0.02899491075160248, 0.014569905952417424, 0.02173686253705195, 0.04830117264230337, 0.04112434167680996, 0.03126826090738177, 0.030243578034320047, 0.02114908496982285, 0.020785208691709807, 0.023698566647778665, 0.04192883315097008, 0.03652746030794723, 0.0206210727670363, 0.07039282417723111, 0.017490130682875003, 0.039634129498153925, 0.02638752119881766, 0.12046493589878082, 0.11430177518299647, 0.13909081715558255, 0.16449284766401562, 0.12778117188385554, 0.13189994730055332, 0.16915982509297983, 0.12155865292463984, 0.09981423150748014, 0.12998540646263532, 0.19883385779602186, 0.08389449039740221, 0.1582382611398186, 0.06201447054211583, 0.09190758184662887, 0.1310055431510721, 0.14789398120982306, 0.11387190967798233, 0.12602687387594155, 0.11040993580328566, 0.11159619143498795, 0.1576467143105609, 0.17065325352762425, 0.09535973731960569, 0.09416004669453416, 0.14506286169801438, 0.1352247553212302, 0.13629750561501297, 0.1482460323188986, 0.14932170031326158, 0.138016655508961, 0.1456740860428129, 0.13037692116839544, 0.12594303408903734, 0.09711821510323457, 0.17590708232351712, 0.10369270374732358, 0.17173893669886248, 0.20318205947322504, 0.07168218320501701, 0.0754210672208241, 0.11854303974126067, 0.12436921282538346, 0.14579221898955957, 0.11826041633529322, 0.08227252707417522, 0.10022689614977155, 0.10329669713973999, 0.1922763596687998, 0.10552966767655951, 0.06697256663548094, 0.1394448902990137, 0.10826461842017514, 0.10852540656924248, 0.13487463125160762, 0.09445372343595539, 0.0544715190439352, 0.06390762395624604, 0.1855383576559169, 0.20472690729158266, 0.0952415025926062, 0.1760279701224395, 0.1015604210219213, 0.07983438111841679, 0.14207920751401357, 0.08704241790941783, 0.06557295923786503, 0.0875855309090444, 0.1793107632547617, 0.1150863380836589, 0.11035810251321111, 0.09896115692598478, 0.1414302159100771, 0.13675838017037936, 0.14729901456407138, 0.11011207928614956, 0.1489085131990058, 0.18336708630834306, 0.10044945563588824, 0.08874405481453453, 0.1287425881517785, 0.09746506184871707, 0.10622838232666254, 0.1689053608902863, 0.20018836297094822, 0.11943736246653966, 0.08638579957187176, 0.09076787371720586, 0.2444557568856648, 0.03962691667090569, 0.11896835906164986, 0.150687414886696, 0.15151572972536087, 0.28961687641484396, 0.1600294985941478, 0.08046119141259364, 0.1098631587145584, 0.12420951282339436, 0.13112459890544415, 0.09476521850696631, 0.11685903796127864, 0.0904686465593321, 0.1181968240333455, 0.18871377940688813, 0.18545147803212914, 0.18723128895674432, 0.08800133716847215, 0.11923731677234173, 0.13306450338235923, 0.08932530826755933, 0.1518855991640261, 0.28142334893345833, 0.15786468689995153, 0.14487249191318238, 0.12670652169202054, 0.1165705384420497, 0.10163395386189222, 0.07132291926869325, 0.16145446284541062, 0.09430683417511837, 0.08123413100838661, 0.11316408230257885, 0.11082931115691151, 0.0880222971151982, 0.1333391879286085, 0.1893010786069291, 0.12561937288514205, 0.1224917471408844, 0.16674208268523216, 0.1826240633215223, 0.08219298241393906, 0.08802315885467188, 0.11381984568600144, 0.19651938841811248, 0.08797936620456831, 0.08520450403115579, 0.17042844130524568, 0.09530098297234092, 0.12882094537573202, 0.16508432663977146, 0.1280566571014268, 0.1573855597525835, 0.11002076204333987, 0.23646182726536477, 0.09970889573118516, 0.15338912419974804, 0.05814257330660309, 0.1785023837749447, 0.15127385913261346, 0.10887012271476643, 0.17811897077730723, 0.1975964813360146, 0.1441667340695858, 0.17167693216885838, 0.10374851325260741, 0.1481520552188158, 0.11124924969460283, 0.16230738136385167, 0.13712621400398867, 0.1622321182595832, 0.10705464120422091, 0.06416446303150483, 0.08550514932721853, 0.08251078786062342, 0.1107382992548602, 0.16051608962672098, 0.12467429574046816, 0.10322802939585277, 0.12093180870371205, 0.15256558624761446, 0.09299143297331673, 0.12141708337834903, 0.16578794031270913, 0.11645541819078581, 0.10490342056644814, 0.14610665211720125], [0.01695372669824532, 0.04640605826196926, 0.10259391127952508, 0.01540087047033012, 0.026742539202262248, 0.047508955866630585, 0.05183100001886487, 0.11392943587686334, 0.015326000916372453, 0.02092446104091193, 0.09269019056643758, 0.08183857000299863, 0.02996400125058634, 0.03054474919502224, 0.015230069635435939, 0.027707719643201147, 0.016426331962325742, 0.025651867102299417, 0.017761643077912073, 0.03046639197106872, 0.0822344816156796, 0.014116328193007835, 0.07554390920060021, 0.03926186143819775, 0.04400544207809227, 0.031996810742254765, 0.029297903778829744, 0.05643523331465466, 0.030749249471617595, 0.05046325662572469, 0.06063814368098974, 0.015198850239227926, 0.04844449280894228, 0.03304755614538278, 0.021976517712963477, 0.01929640447321747, 0.0790275554837925, 0.04172759323513933, 0.03992356539570859, 0.04111664369702339, 0.03288141006071653, 0.06900692997234208, 0.11130152403243951, 0.051957098966730494, 0.015355088016284364, 0.08533525094389915, 0.007255943059655172, 0.032516297152532, 0.010998168860429099, 0.05450549329231892, 0.034312867892107794, 0.07319125865719148, 0.06153756220425878, 0.03821116353252104, 0.02505119058436581, 0.016326064842620065, 0.0027205378116507617, 0.03758122519190822, 0.03601378894277981, 0.025918741710484028, 0.015827523112030964, 0.05568401362480862, 0.030734715251518146, 0.0690288602241448, 0.028644013152058636, 0.03704575928194182, 0.07202563727540628, 0.018564472141276513, 0.04106756865179964, 0.0414431072505457, 0.028360427922702262, 0.04416163405403495, 0.05308638479826706, 0.015703045862859914, 0.015527841335694705, 0.04204758356458374, 0.029558759781398943, 0.012817185538421785, 0.031392521025346856, 0.05185037558632238, 0.008174928836524487, 0.048894463306558986, 0.05934837074684245, 0.051148671989462206, 0.04366575726973159, 0.03497288908277239, 0.03465994194682155, 0.03435681999794074, 0.0389813516688134, 0.030242695938795805, 0.0478366747099374, 0.04425917685564075, 0.023609549638682177, 0.04816149281603949, 0.025897515438763157, 0.04275508863585336, 0.055548394830631356, 0.05998016827340637, 0.09585095596100603, 0.03580130909436515, 0.1027643864176103, 0.04550771860937987, 0.023890949985278503, 0.032288523124797006, 0.009103635475704712, 0.03507403829800231, 0.021713383529069166, 0.05991150052951915, 0.0959554435685277, 0.038773560497377596, 0.01196648328498538, 0.029229354778570787, 0.017672973818012645, 0.01931193613979433, 0.05849273808832679, 0.09572087401258093, 0.025702277165172354, 0.030808495756770884, 0.02831423665130777, 0.04642038892156311, 0.0051514773014267635, 0.05286147418831076, 0.02897199323134763, 0.07525464972215039, 0.09833287421081748, 0.06040902276124273, 0.019919577819694365, 0.05698080600372382, 0.0191851637459227, 0.04105693261538233, 0.030290844783719097, 0.02142686363575714, 0.02714178920723498, 0.018109365133568645, 0.07922039513609239, 0.051398430551801405, 0.04480707352714879, 0.034201968128659894, 0.0348647475641753, 0.024654870154336095, 0.021235973075298325, 0.04656150724206652, 0.023127467471307943, 0.04755472983898861, 0.039884661590414386, 0.04064045460628612, 0.016058231803721616, 0.013076319758381163, 0.05419282435572573, 0.054083458081419976, 0.02593262623330312, 0.0028042461323950973, 0.03196823763261948, 0.01103966636583209, 0.029817393581782068, 0.08054884456630264, 0.043425915496689935, 0.051249841560742686, 0.03455664516825761, 0.03341937976490174, 0.03798489245985236, 0.047454445755907466, 0.011193541992854859, 0.019238516954439025, 0.08742545092744486, 0.04120902284713728, 0.03417501671771918, 0.03153829748875328, 0.08695200990353312, 0.027483005808400254, 0.06745124594973666, 0.06782202462532691, 0.03241755673661828, 0.026406510001314536, 0.04516454613102334, 0.027598624782902852, 0.020344917496134127, 0.016979015698390346, 0.07837529334106616, 0.04203857940488628, 0.03264943929389119, 0.038868613075464964, 0.04903715582830565, 0.05513173361708011, 0.024172117933630943, 0.024282870115712285, 0.05393892672977277, 0.03262547004435744, 0.02312938942174826, 0.03643935592845082, 0.07030871976166964, 0.10623980885637657, 0.030894140446824685, 0.041273846690143855, 0.03394812817818352, 0.05470294698274561, 0.03300610104841845, 0.031985716694699864, 0.05500857272584524, 0.022824720413024937, 0.006114178969125662, 0.04580313579312392, 0.058773339459938664, 0.021090883628598282, 0.027161147811317017, 0.028622249141335487, 0.008389445138163865, 0.025483023840934038, 0.022584508838398114, 0.034933903853275945, 0.010891213929945869, 0.02841023917842124, 0.020620304326127683, 0.06427831442228385, 0.025580112024077346, 0.024907051086691872, 0.00788595519095127, 0.053912022816283364, 0.041091860205467255, 0.009800017661681133, 0.021432083266388093, 0.06756431702524424, 0.012020390347710677, 0.04728369241846459, 0.020372089430955902, 0.09100548989538636, 0.030440729776663438, 0.021222458354064395, 0.08281092425542218, 0.008383303548076322, 0.020128999171512466, 0.015511013667232223, 0.019592032002817308, 0.046036375420434136, 0.01362953444809786, 0.045304789141352685, 0.01969181905899729, 0.039275035195584805, 0.06393341507230486, 0.03266951035974281, 0.023505681194365025, 0.06780582799443177, 0.010986285167746246, 0.03560447287080543, 0.047829865611025264, 0.07830186906669821, 0.026845701970160007, 0.04235559096559882, 0.044791487577770434, 0.025153021727289473, 0.01392759198123323, 0.030031817433025156, 0.013403598402094628, 0.037503244554890056, 0.014976864115202, 0.061982721888593266, 0.04190460266545415, 0.03206216384257589, 0.01952111321900572, 0.03486522253868835, 0.06433258365307536, 0.03523282906306641, 0.04605362378060818, 0.015747781676639403, 0.003992039069999009, 0.006855833011546305, 0.040886939237160344, 0.024919917806982994, 0.09504911755876881, 0.07186689400779349, 0.05228931988988604, 0.027272318988772373, 0.027326571256188408, 0.012555073397899312, 0.08212714416107961, 0.06351553249572005, 0.046593354283166785, 0.03603096944945199, 0.028650499946836914, 0.05947396757879427, 0.01592171734331974, 0.008619400655983813, 0.017876698868349195, 0.05205593437754682, 0.02889237053958433, 0.05510551841663463, 0.041508799618376155, 0.030319431464054754, 0.05494661908596754, 0.0443858118461711, 0.07421234529465437, 0.04113866215837853, 0.025695846349533116, 0.02227111895834761, 0.12133306717233998, 0.02031827312228935, 0.042114453190671544, 0.053024047786103826, 0.020904189807229807, 0.03290288230138166, 0.051753446858908446, 0.01474578901460128, 0.0418552765622735, 0.044107955148709674, 0.019794321951589415, 0.009628093003162315, 0.020568031684628556, 0.09325868756111179, 0.006570194789674133, 0.01586921399991427, 0.009828321901815278, 0.006983462904047753, 0.006452175921627453, 0.0259067333369915, 0.045779451528298, 0.02711813717282244, 0.0019352185564847396, 0.05617729501266565, 0.034733878515128574, 0.010829052488718714, 0.021423194457643797, 0.013134323476281549, 0.012113941667069281, 0.02401580721406, 0.04145887640437909, 0.030472295225730965, 0.010641167838392513, 0.02525156027903514, 0.019676976105464355, 0.026202717097476125, 0.06441284077508108, 0.012266263448899346, 0.019861233986115882, 0.012050696266149836, 0.05087376691933189, 0.03220812351043735, 0.06731405295431614, 0.04963310634983437, 0.027682354307866523, 0.017250139632129242, 0.03211526260046022, 0.015042671833985617, 0.02864134990211044, 0.020681206236726472, 0.07444580883852073, 0.026118651697678224, 0.035420321859419346, 0.04728038456024868, 0.047722521371075084, 0.024105356873146126, 0.04289189147363816, 0.07935123025838818, 0.15143446837152752, 0.19451568807874406, 0.15202448171164307, 0.09304435191942112, 0.135675275432212, 0.14031261445156165, 0.12368713585393769, 0.20792861548917635, 0.10720936075917312, 0.1329008135944605, 0.19373630918562412, 0.17315457787896904, 0.10480161317225013, 0.0681865472080452, 0.12605120614171028, 0.28867897817066734, 0.06845291970031601, 0.10743063781410456, 0.10917622343237911, 0.1439513127718653, 0.096187631466559, 0.07789538587842669, 0.26992798862712725, 0.15518634633294173, 0.14300259867949144, 0.15479042114956038, 0.1700496966285365, 0.11444126841213022, 0.07041288845773254, 0.13598073832690716, 0.11592715153736727, 0.08702110512448208, 0.07816154802484171, 0.14489637634583882, 0.08805826625653676, 0.14982152277869837, 0.1496543317501034, 0.16799062783164637, 0.0923920762059944, 0.18752718450767653, 0.1216046033161027, 0.1337228859109538, 0.19402354662971838, 0.16195256183190004, 0.15773048624396324, 0.13035233105931962, 0.05956445022353104, 0.12015779023723942, 0.15029850575540746, 0.15086928941309452, 0.16287604799228056, 0.2080958608005728, 0.13727990218571254, 0.19550419146461145, 0.12439324653574399, 0.10234575745250497, 0.07682181455727134, 0.1220165283552238, 0.1012520200705954, 0.10124938056937285, 0.10797313334686415, 0.15012079743402346, 0.15006521184529575, 0.09992374705949, 0.09586066579712288, 0.1809765938669443, 0.09332079387136868, 0.112427932875497, 0.10651841533503362, 0.15833079974566186, 0.07240131497383118, 0.14429030886718205, 0.13947653717228345, 0.2895694603877408, 0.17144939223570482, 0.13669561568115438, 0.07462295397583928, 0.17643810382911138, 0.13407286070287228, 0.11548465171030589, 0.07128614267068249, 0.09180814253964595, 0.18345825427344867, 0.1127964248880744, 0.11658427199082715, 0.09989651066384145, 0.07208034755395991, 0.08732857648283243, 0.0851492237831865, 0.10083309933543205, 0.2946891428104469, 0.08615807643426315, 0.18785962595471314, 0.23786682901637896, 0.13740625897688524, 0.13573535292276315, 0.09859330273632493, 0.13412783561008318, 0.232006702039923, 0.12891038986189024, 0.2050099242478609, 0.14491830659764154, 0.12541754942919525, 0.10539173507796866, 0.08874144245471273, 0.14416935321475777, 0.0339526065093066, 0.16460262105933257, 0.1858301412846361, 0.116727225748556, 0.12921335574771675, 0.1226022397833211, 0.14145291969180107, 0.23487706801721028, 0.16809048104499066, 0.16031677675034317, 0.13515329201306614, 0.09677281363734178, 0.18072597017245634, 0.1632903479039669, 0.1381871985005481, 0.1750876155814954, 0.10488351234900099, 0.1893850133887359, 0.14663083398980753, 0.17285053990781307, 0.12031533249786922, 0.12750086906765187, 0.0802325861794608, 0.1346092562058142, 0.10632150447262184, 0.11966290750673839, 0.11054724414965936, 0.10492394625076226, 0.22463865312082426, 0.07758929873151438, 0.1301685566348689, 0.1540329996496439, 0.11169262483183827, 0.1020146527194551, 0.11272731609642506, 0.17506762593984604, 0.10086926525192601, 0.1151140494538205, 0.09067705859030996, 0.14114314131438732, 0.09420127448226724, 0.11239805697862591, 0.1397725955716201, 0.14414061047136784, 0.11554694122501782, 0.07927865415279355, 0.06542175449430943, 0.06766228391123669, 0.1480045145643609, 0.17721198658858026, 0.11104676127433777, 0.14555964432656765, 0.10062056859689099, 0.10524114780128002, 0.15038898161479405, 0.1501238237002066, 0.1353798277143921, 0.08433893083461694, 0.1143700358058725, 0.1604641138442925, 0.10213625298014709, 0.19571882566171034, 0.15327526602361882, 0.12804628908634186, 0.07222508585878781, 0.09482049196958542, 0.17735264689794608, 0.14689760681773933, 0.12495850691837923, 0.1400704045913049], [0.0037594007943490787, 0.019107076239639094, 0.04620455711015633, 0.041236116750431914, 0.03662986820563674, 0.0020147097820881754, 0.04556662901969893, 0.01011135836597532, 0.023092097137123346, 0.052581330827836475, 0.05823701859584876, 0.04650999286345073, 0.045835315316383324, 0.04492107080295682, 0.02290038894196706, 0.058848168301795206, 0.05509689423654761, 0.040773739239999225, 0.006102566266365881, 0.04114231267677886, 0.03216012394321816, 0.08186094808791365, 0.05197006237826177, 0.05235228454694152, 0.036357629778129716, 0.037475611216255596, 0.013627684592003269, 0.021901912787663083, 0.04059031426108309, 0.03860189453033464, 0.011996965622529387, 0.006478486116975546, 0.04654812313882368, 0.024893509224057198, 0.03486532771161624, 0.02382356976158917, 0.013256812617847962, 0.011267607482815427, 0.010042621920417463, 0.015412454759435994, 0.017437992052042058, 0.034963725467345545, 0.04485022835433483, 0.03793916937762073, 0.010853025130927563, 0.021490505131493722, 0.05724183164004769, 0.025159754491012012, 0.019605120943327035, 0.05137550624619637, 0.0068357424378128985, 0.03030072425359062, 0.021422940007011806, 0.02056433875778956, 0.029891184265060083, 0.009692057651201529, 0.029314948578498194, 0.017344715539366007, 0.045458026097289154, 0.03764472928430353, 0.00744370642184679, 0.044754229219896455, 0.028057477303913662, 0.05915012317044394, 0.016605911344023686, 0.10071476282817976, 0.051215114138488255, 0.04150867748207279, 0.019352414146331803, 0.015934996273634688, 0.0328124437614211, 0.062056560069322586, 0.07531284088534967, 0.030203873557703834, 0.05370576513398971, 0.01741555968432554, 0.02116105263121426, 0.00877834324325834, 0.06827026485864605, 0.05567298743075558, 0.04395721859431692, 0.04366388451308012, 0.04868010052346757, 0.013944231356228036, 0.027619544017527784, 0.07250343449413776, 0.05167680632855211, 0.019349455733650496, 0.046520598365792205, 0.07127658211226974, 0.03875672943624003, 0.018161975346239548, 0.017864726117945144, 0.027513178564342003, 0.02164263777168734, 0.009013308894022234, 0.04353474233565586, 0.024087781119825583, 0.0482320740286793, 0.024051613506994078, 0.023136687065873827, 0.07407189533114433, 0.030003943214459077, 0.07248455764991896, 0.04722339101135731, 0.04389955668843218, 0.03214677715940135, 0.016359053518889204, 0.03081837183396731, 0.012720864099849547, 0.012649545828545732, 0.05806815837110792, 0.047177946128483327, 0.004855487179676337, 0.018824176330651556, 0.01225200149097613, 0.05829499941319227, 0.03259201148258788, 0.024482352625844733, 0.024860023520886898, 0.005166256218217313, 0.02241455956495234, 0.022287909307384064, 0.013901201209851673, 0.03371435250820858, 0.07034927579973425, 0.018291712938142673, 0.017519748736439005, 0.005147585479010428, 0.06486920985792365, 0.0263956585300288, 0.06186393076287849, 0.042324578522571495, 0.05475889898038336, 0.017502880355875407, 0.052383853388684135, 0.008130323640736086, 0.044379593072725196, 0.015593701640942266, 0.021664978537176336, 0.022218729269557765, 0.04088803846389055, 0.0006409348487587911, 0.011825287781123604, 0.024676211777010133, 0.008212942064606717, 0.02302520376230989, 0.023091586539521813, 0.011386462221188205, 0.01496981583269579, 0.019155270885676146, 0.08968660102358886, 0.02656172319049282, 0.04359529140804495, 0.0521803471658911, 0.01844727387651801, 0.06302719762814896, 0.029638640316469327, 0.026945641696719185, 0.03246558005256312, 0.034173289846096716, 0.03931534356836762, 0.026012661135090247, 0.025617716434810842, 0.01882905839011073, 0.05201742072988834, 0.028160853810342293, 0.1074620404147676, 0.018306121629263674, 0.051007217794124565, 0.02185597427056304, 0.026451135553153496, 0.009600166198132294, 0.023275067497576987, 0.013807020549263273, 0.016902273387781212, 0.01852233681295599, 0.030854361331356422, 0.07021699539784874, 0.06857213151774236, 0.06413931652371373, 0.016323399896334325, 0.01956281598125185, 0.04455535399860569, 0.04697553234707032, 0.06639652433139936, 0.011558651508364295, 0.009593402052165141, 0.03260597912594676, 0.06134493289781468, 0.057215911602335315, 0.02715141253013696, 0.008688022598757275, 0.03699336959315198, 0.03013951111850994, 0.007651942033719803, 0.011726783156128866, 0.04180102090218237, 0.02748712112328836, 0.039034938971911154, 0.1166866629251412, 0.014472475109089698, 0.026212706829288175, 0.01460504558469568, 0.021773452537932565, 0.04418427337493215, 0.04516505503228732, 0.008433695799405021, 0.047589246915387254, 0.03602452675944992, 0.03372868995315262, 0.0023827017991737065, 0.04970883425059063, 0.060523186278130324, 0.03883696959487029, 0.0715684268091406, 0.028159098100981543, 0.028060908994770477, 0.05642329788367663, 0.0821534034663013, 0.10698100658399717, 0.006178294167122138, 0.06515363816704069, 0.02854363407407488, 0.07437161781958171, 0.03494936766635094, 0.027442390398521508, 0.06482435190784079, 0.039625824229525666, 0.049877806433609555, 0.013496511898535703, 0.037662327090012174, 0.03987043610374842, 0.006685714528430253, 0.019795979273372462, 0.04062130295538476, 0.005463566090579012, 0.04264355104948793, 0.03333697847223707, 0.09894873973514352, 0.04128283388646586, 0.026171733492187092, 0.01764780525783343, 0.04310654602678759, 0.025128234843058244, 0.022162641564916288, 0.0338405057388757, 0.02490187556083713, 0.033111165410705974, 0.04281442313055907, 0.04361242441726582, 0.032237765312727006, 0.0055567980743944645, 0.03308805111529572, 0.04426746176821845, 0.05888630196984325, 0.036347953868763785, 0.04826873866841197, 0.09104699588247708, 0.03745107878265636, 0.044473671953060796, 0.015705363059948598, 0.05792503497962441, 0.04187087947502732, 0.037035326806030104, 0.005781027604825795, 0.024983002904004285, 0.044730076765907664, 0.022971207641863396, 0.03392000290166054, 0.014092270733921655, 0.0748732587588685, 0.04259604002748217, 0.01603752630762756, 0.044642993581614325, 0.07637143693864346, 0.028160628197448592, 0.017152917438319752, 0.006786204292438924, 0.02440155267582408, 0.040311158169060946, 0.035278779454529285, 0.027619703473257165, 0.05259406693013651, 0.028463916387408972, 0.031797891416187794, 0.07595479608114276, 0.02815155279157417, 0.04542879141601069, 0.01730139277476285, 0.017835598305932114, 0.03659476080377187, 0.012586077359238905, 0.019892790953495672, 0.05850109085440636, 0.03480443258636764, 0.05416426142411573, 0.030067199641572576, 0.03478308926735606, 0.05408965649881533, 0.028247173642739654, 0.030604382245136157, 0.038220093053366454, 0.031756365073046515, 0.03428291057103446, 0.04161803697102836, 0.024485714766862135, 0.04742850875481963, 0.02366531334285225, 0.039656181886259995, 0.049688651226460934, 0.04577660507389477, 0.030175717747105018, 0.022758541196318607, 0.015071701258420944, 0.01439243002927729, 0.04158833410058703, 0.04250807135498949, 0.06033537457031863, 0.021701789061938013, 0.03068983355270965, 0.017396786316697086, 0.03324852803988116, 0.012254015043643969, 0.038958596996963024, 0.02052804731231715, 0.015539025289139577, 0.04766085950125541, 0.025733050424605608, 0.05144956834348185, 0.06052464512842042, 0.052789213601499796, 0.04741390668121832, 0.025694080462147082, 0.019728110504469702, 0.061148402015013356, 0.041520677373877594, 0.04558848802532468, 0.03715184144675732, 0.02530596012781773, 0.04866765958390065, 0.0133552536301847, 0.10921935790351459, 0.0452516700274178, 0.020744596674506153, 0.06616992756192173, 0.023152724241039584, 0.04700518772006035, 0.059990251303783486, 0.018899922891120826, 0.02300185876499329, 0.01802418184732752, 0.0973414531243699, 0.10021042810486895, 0.11086706484534911, 0.15781858723078454, 0.09641849622130394, 0.10844251673136439, 0.1016638840415648, 0.13269866444170475, 0.11865042469331197, 0.1227848878396409, 0.1297391525336674, 0.21035443246364594, 0.19975362558450016, 0.10798970317201954, 0.133097059492554, 0.10890489084912197, 0.0735249486086624, 0.13406887091696262, 0.17515572692666734, 0.20959224764789852, 0.13703074412686483, 0.14997464099100657, 0.11562395494963441, 0.13822761204625877, 0.25482046071972164, 0.1289850558553423, 0.12010856930698667, 0.09404527249612979, 0.1558312667267663, 0.08867070517901864, 0.17206467421991484, 0.1076670733413526, 0.08686512349439518, 0.07892013660499028, 0.11894538386591844, 0.10986507896866117, 0.10352743975818157, 0.24159499896424158, 0.13809243429984364, 0.17194474994071893, 0.09463981166481972, 0.12300139479339123, 0.10604990047535726, 0.15616123830633505, 0.131043744672622, 0.11710236061896596, 0.13676441913204535, 0.07873133423605136, 0.11069739037858588, 0.16858711439583982, 0.1270921602845192, 0.08918915343071733, 0.09004588531596319, 0.08978279693318264, 0.1199239534991128, 0.06874059819217239, 0.11569256841072015, 0.10016069148800202, 0.18717079077448162, 0.18766167014837265, 0.14937292970716953, 0.17850747278758458, 0.07423333238278117, 0.2525510867791516, 0.06777815733637128, 0.19180002808570862, 0.16499798984399863, 0.11394409223326615, 0.12149758477296148, 0.10102291272154876, 0.14708894012229784, 0.139964634552598, 0.21457422817392008, 0.09279163833707571, 0.20679905824363232, 0.15013520951781953, 0.06623618650649275, 0.08148409652390651, 0.11552890576422215, 0.1467150944684233, 0.13259126591895307, 0.12650813162326813, 0.2455895889018263, 0.09843578083174569, 0.11716485369418349, 0.1396080372588975, 0.1462759194629533, 0.1584181814853634, 0.11438127234578133, 0.17359732197863714, 0.074511131404766, 0.17545736288385733, 0.09567559537078653, 0.07463457728070871, 0.08598870052290813, 0.17338371915476664, 0.13285513461700507, 0.15686288422771863, 0.2567317310188498, 0.17538353827382835, 0.12387411296367645, 0.18589230866304465, 0.09774187699492488, 0.10811496073646204, 0.11783694263015475, 0.10057389217295817, 0.13578309464667523, 0.14652624460203306, 0.11886059412998812, 0.08065310147191797, 0.14879983903041907, 0.2682951076754502, 0.18209148118538515, 0.10881829621004206, 0.1120144539911832, 0.11052897798695735, 0.12179270679397242, 0.06944280729762145, 0.12799101562372275, 0.07106014301202127, 0.11225273513368197, 0.12776211862053188, 0.09931457189044782, 0.1960548497736454, 0.0550645145454577, 0.18259054369160108, 0.12570923806301185, 0.08759626533303942, 0.10843282725129809, 0.1589718796312809, 0.09027951170823403, 0.15108460214521202, 0.07126797828823328, 0.10254359790789229, 0.11121505831501313, 0.09954314998217992, 0.13905698539955275, 0.14814790258450167, 0.0922682232090405, 0.08036540940936122, 0.10565635016454117, 0.14308011452002184, 0.13924921437033586, 0.07844373038304703, 0.14919128588267735, 0.08329180880848851, 0.0759776219991701, 0.10042865853756666, 0.08090268700782742, 0.059748848900198936, 0.1347807084343263, 0.1506085962589298, 0.15048291800277575, 0.12201047582285744, 0.07252434015806232, 0.1457610335201025, 0.14339236276490347, 0.08800521838877882, 0.117350148037076, 0.17919345812073775, 0.04788001613425357, 0.2387643408562456, 0.10540979089481489, 0.19755388290754386, 0.15524847299924918, 0.1258448636425393, 0.21088215628904955, 0.20434642556522573, 0.18354220262595586, 0.208107110911182, 0.11162918859294482, 0.09819597977080516, 0.11367395387164184, 0.08627042147730078, 0.0831252352467605, 0.16589748300611973], [0.08136567859245197, 0.029494051289345537, 0.0836279686274273, 0.03079753402354462, 0.013111422071233392, 0.0295427667110094, 0.0082524599440928, 0.01701706794223615, 0.024961359333246946, 0.08970929123461246, 0.013972505910455115, 0.08192371257713862, 0.07470792013087443, 0.09496534562536649, 0.027076778767098273, 0.011027358588762581, 0.06987386702426843, 0.09143159631639719, 0.08028335416955606, 0.04119167609938553, 0.05439790817243712, 0.05432963397886072, 0.05422753820727978, 0.0286483489908278, 0.03968212906537311, 0.06034489441663027, 0.047827714655016146, 0.021006813139787743, 0.018399684822985103, 0.03995718341320753, 0.04326680242749197, 0.08182460575231484, 0.02046620563071753, 0.03474407350378377, 0.055005797517618964, 0.10220283083617687, 0.0024737815547268838, 0.032265527573015006, 0.01213023074836071, 0.020352739308561598, 0.022623049627457346, 0.03890989514599953, 0.059150991695267816, 0.05008960435433047, 0.0079860204464889, 0.0415571214897292, 0.027548606574003185, 0.011380367280383195, 0.03725563016320978, 0.05971007740923336, 0.03380165282370789, 0.03468281536230019, 0.013262751495598682, 0.02882888341056449, 0.03455324910048928, 0.023684339464775155, 0.030926737269120555, 0.014909081859514117, 0.06744962425104209, 0.039978031401655505, 0.03862909360655716, 0.028538429710481848, 0.03317162288086755, 0.030922537137355124, 0.054414525495043824, 0.018641592735158544, 0.025377472629770637, 0.019648263896150247, 0.011680592732903148, 0.05760118378592389, 0.04291846629764352, 0.027344567701220512, 0.014755565007882459, 0.04647626628034881, 0.008965956479577082, 0.0070273895648175055, 0.007141712537434484, 0.056276496832392046, 0.04238885275221296, 0.03134758843641196, 0.024967712117359042, 0.03255710764122861, 0.01481286559386977, 0.015359956505043166, 0.039828665488000424, 0.06939643621444702, 0.04016889990972621, 0.03116899123415351, 0.013176159401025091, 0.009396699839271605, 0.05618617364338466, 0.04770994811717953, 0.06374666866447244, 0.05713927785732916, 0.012929288005190236, 0.037303293855594735, 0.041779887929026566, 0.03587511334834354, 0.018791966273316314, 0.023732483220685805, 0.03652034926095179, 0.050052251001553874, 0.00310150787117891, 0.05254942950393472, 0.06177312920668295, 0.08127990498074464, 0.010415347991511226, 0.007123404814462576, 0.04706940088155014, 0.03150479142953243, 0.014754094283229538, 0.023356137165267552, 0.01232261663036687, 0.07153827271291188, 0.023931931804067323, 0.02934149626110281, 0.0575424905068108, 0.012944314163178205, 0.03295721938567502, 0.022681739513895342, 0.03402046340384653, 0.11739062943628856, 0.03584452159702778, 0.017512008348213773, 0.042408353848648925, 0.042547870826508315, 0.04006151495767491, 0.023876105335408022, 0.023806523265583173, 0.04130021116829344, 0.020199205493554473, 0.017858626088127494, 0.042434246744960546, 0.005982403651744659, 0.09224079682358674, 0.019572503764980605, 0.017891507895131196, 0.013507190343391682, 0.03751507820561528, 0.009258188789577355, 0.037154938959117444, 0.032482516286628585, 0.08847085625997611, 0.020027293557567254, 0.016775368679580942, 0.028698645399085114, 0.06991732719221286, 0.05103653050693018, 0.019995970684768896, 0.006127735674713871, 0.03462390834465623, 0.019550127376403128, 0.058944364211388996, 0.015455945461456264, 0.02630860248713621, 0.023791098468271748, 0.02391093793059034, 0.029388193041086197, 0.06136516681207078, 0.024737644641261016, 0.024561588552647402, 0.027863070235720704, 0.03307727258652449, 0.03610127924808434, 0.03989365217941148, 0.04421527903260929, 0.03638481189097677, 0.03595949935593775, 0.06715448187398058, 0.04841684250693236, 0.04021179350093007, 0.02609274523066623, 0.081265764310956, 0.04789675898583872, 0.02355661033652723, 0.0334574014746717, 0.04355247584836824, 0.026207380329391787, 0.011576795534762954, 0.049869535091732226, 0.045299123373946974, 0.02683821094355413, 0.014564158760809472, 0.02426867007410952, 0.057695669787270684, 0.01763616668592606, 0.011345901094110948, 0.043409749399870634, 0.08365118131041527, 0.023849128479404107, 0.03308120130428246, 0.03686393903834479, 0.0534230738745204, 0.041669514030218124, 0.04772032291761466, 0.04244622288803969, 0.08112635929137468, 0.03248779528907367, 0.03182257652016623, 0.024498571309127977, 0.07103145455143281, 0.048238903483642, 0.025397228176838586, 0.06331098132899829, 0.028777182434818575, 0.009218246825704617, 0.01673955051228404, 0.058347253394978385, 0.014180513364928109, 0.02567734439591212, 0.0777076691655176, 0.03594056822891746, 0.06576164625585079, 0.018571053930957402, 0.014531767195356744, 0.056284683357392035, 0.030836834771824733, 0.03784990131056734, 0.024667626612686684, 0.037073524934904914, 0.023233001719095876, 0.008717817071426128, 0.043340362408863645, 0.04643240238406828, 0.018754417841721858, 0.026829032061089362, 0.05869258700736931, 0.04747865249269775, 0.03872162203437515, 0.00527530867007694, 0.04726981637733323, 0.015928377164527774, 0.018003220204263926, 0.015972229186445475, 0.07462293361978871, 0.012280138641861933, 0.05004782695323229, 0.04936555659930621, 0.0420186881508146, 0.046498861496469805, 0.03805259668401309, 0.07946666263576065, 0.03896377082648022, 0.011667430849878915, 0.030551867027367865, 0.021374967581193362, 0.028783747261123996, 0.025345730761598264, 0.047239173735891066, 0.05574624885671905, 0.06803144088813237, 0.038715304873351536, 0.018414819546576058, 0.017413267932300056, 0.013013339834287763, 0.02922456432133913, 0.058555020817688534, 0.03875787955309663, 0.0473831419034728, 0.02707969137866582, 0.06613732395427567, 0.06662106513977051, 0.02102040928522391, 0.01338269273817007, 0.036016438622027636, 0.0659043693116733, 0.028190309015501822, 0.02655690219918532, 0.03803380126399653, 0.06089137973529952, 0.016407716354089122, 0.037136425131133625, 0.04238795369331326, 0.02243603010927992, 0.011538116494193673, 0.06335796987903969, 0.027052349810089384, 0.028818128630518913, 0.03516623763633626, 0.03699644674946155, 0.04874252913785832, 0.03837175241538456, 0.11616576516202518, 0.05796124839356967, 0.056231632096959014, 0.009283140218550605, 0.03247270806293402, 0.06357206124812365, 0.056831267063638995, 0.018033221630113463, 0.07206187104540211, 0.059180955801691325, 0.02118302189878055, 0.02647161204367876, 0.013366390086178268, 0.09119981553937707, 0.05677760512168918, 0.038804522050278525, 0.029729737035397972, 0.08175835359309401, 0.040228041021951606, 0.050801251881888936, 0.021828958398795555, 0.03448942270396011, 0.024628163016002094, 0.015099000418558717, 0.013813652380901788, 0.02976083768797772, 0.03381333380405392, 0.06189560477754899, 0.014834953605064323, 0.03657173132523894, 0.06008217244275978, 0.060026919336191246, 0.05728450470737048, 0.02552781393751502, 0.08579090756497212, 0.014417055761441588, 0.06372894532978535, 0.06692897754588298, 0.03174924724070089, 0.0424487300749336, 0.033528905494936874, 0.02260571305773088, 0.021752428130379746, 0.006350246391126088, 0.035413343126752546, 0.02344983776233026, 0.01218825058146779, 0.03556901263073087, 0.14917075341301306, 0.03790324094838329, 0.05375730665400624, 0.02343293884769082, 0.04856448494164007, 0.06459646592182772, 0.017034357014511312, 0.016695732417117273, 0.013904877173315202, 0.07276389694639615, 0.038752179858939986, 0.01602672233379313, 0.014692081271537712, 0.04680576967075467, 0.042780146934092045, 0.026295230258256197, 0.017360108106264045, 0.010210695892705448, 0.03325509286618658, 0.04172903512205396, 0.012240256897972097, 0.014916857870827829, 0.1829145848751068, 0.16251634300819465, 0.1889386051999671, 0.10930762852409057, 0.12185361209724631, 0.14856037045163767, 0.1482355421675103, 0.13317777801837238, 0.08082407194056682, 0.21227544652564184, 0.13439310209027358, 0.1885902996041945, 0.2233840554420437, 0.10718149332595722, 0.14732383537505353, 0.1605764249605792, 0.12151543024395194, 0.16370383357363089, 0.0999113434393491, 0.20659377425909042, 0.1724206879734993, 0.164364129570978, 0.1552224172545331, 0.08765183735106673, 0.20353743540389196, 0.15637304979775632, 0.18156891422612326, 0.0909665555560163, 0.07685044873505831, 0.1363552896572011, 0.11033388559839555, 0.15841554876949104, 0.08602860516735486, 0.0905463048922164, 0.12190300944660391, 0.17956825372363838, 0.13050592424614088, 0.1213237712425845, 0.11490564420819283, 0.09835260600915977, 0.09769400634935924, 0.12543055016015256, 0.16792968181627138, 0.13283324507730349, 0.09407364883060966, 0.16507413504379137, 0.1054032633879355, 0.14462261460721493, 0.14298552673842224, 0.14061760237174376, 0.1337168062371867, 0.10100822922374521, 0.10009561319436346, 0.0985840814454215, 0.10754157150430338, 0.07783953566104174, 0.06223119462707213, 0.06854480691254139, 0.13805678406996386, 0.15920916332730226, 0.08935447170266084, 0.13530022198600428, 0.12816108364079679, 0.11752012105924742, 0.14759432657488755, 0.10681596651141133, 0.1512920167297125, 0.09698906953313521, 0.11799350780035768, 0.129740265331098, 0.11832065667424883, 0.141640521053757, 0.10546426368611199, 0.15604645732258046, 0.12608813201742514, 0.056956697654511244, 0.06170353186982019, 0.13636473486466066, 0.13046698990677083, 0.1287581537451063, 0.15570273862353393, 0.10301768354007176, 0.16995015554130077, 0.062334101248000345, 0.235885886741536, 0.19768930492656572, 0.11306210527462618, 0.13770505865769728, 0.162591673965965, 0.10623602941632271, 0.10638882193182196, 0.15697135483579977, 0.10650897691292421, 0.18964440375566483, 0.07035030717296259, 0.2078236596924918, 0.10080747785312788, 0.10324014803128582, 0.08255374591265406, 0.1696863139846495, 0.0822089822696788, 0.2285234560923917, 0.12410888608012881, 0.1696892859680312, 0.1312521906303508, 0.13173552469483443, 0.17190555775804178, 0.16288569676024572, 0.11344132492584841, 0.11646308563649654, 0.12564095029873507, 0.10948946912373815, 0.11735103013260023, 0.1217701251485518, 0.18049501042280877, 0.1854797593717064, 0.13325275613793305, 0.11573397261755806, 0.14369067390050205, 0.177959447194423, 0.13376431725919247, 0.14165197472487176, 0.1265381635831935, 0.11184826040906565, 0.10883542243391275, 0.10900956844644887, 0.15660508163273335, 0.08989413095904247, 0.1671665741928986, 0.0826495618426374, 0.10707536366369043, 0.11662615117217813, 0.1090325979249818, 0.1354243667530162, 0.1869486112679754, 0.14163982894803795, 0.18331182641642435, 0.1426409123731511, 0.13930770408894333, 0.10364040226808616, 0.1467463613620826, 0.09037179247077022, 0.16660896768527372, 0.09095438942313194, 0.09377177538616316, 0.08972782202597175, 0.2239525049392666, 0.13229444756039552, 0.11665163694747857, 0.06964395221854959, 0.09882105980068445, 0.06197341238813741, 0.11289634595492057, 0.14201089260833605, 0.16940420626529626, 0.13532629130142076, 0.16346247866749763, 0.09687603916972876, 0.1289490663579532, 0.140691983380488, 0.06199107465467282, 0.07884213900459663, 0.13727747303034576, 0.11162880861333438, 0.0966860493645072, 0.08660700877330132, 0.12213297853512423, 0.14505494997969695, 0.11421665975025722, 0.16400678588875703, 0.10467805873070445, 0.14302815230829374, 0.12156203202903271, 0.0668727405635374, 0.10136844989444528, 0.11736635145332132], [0.035803395589547496, 0.036272073297628334, 0.01672975077027721, 0.021419425195615207, 0.02133269315319402, 0.09378221125474998, 0.03932060221476214, 0.04338867410219141, 0.056349507200398614, 0.02750288349177156, 0.02899478522262403, 0.010273306015213686, 0.017890641066644872, 0.07060557883232832, 0.03894720100132482, 0.028241188963875175, 0.013130159815773368, 0.05929112274731908, 0.039570320065000227, 0.03683104705331581, 0.02899348582806332, 0.07328519504517317, 0.04052450654229947, 0.035558956741754494, 0.06674876543028013, 0.02030242932960391, 0.03153069789654442, 0.037456954895917854, 0.03954189623306904, 0.06910934804805688, 0.03470923751592636, 0.04786225548014045, 0.033070721330919435, 0.0839026803150773, 0.02400960201131446, 0.04800172496054854, 0.025353949517011642, 0.011200805710229491, 0.03725103308845844, 0.018909512287271873, 0.02206301735714078, 0.025096587969788482, 0.059136471045868735, 0.061236190875726085, 0.02328215309950922, 0.022931557448048676, 0.028736619611403773, 0.009212572576611169, 0.03530298958399466, 0.06818677112460136, 0.053450296699468575, 0.026247349434665272, 0.028992206789553165, 0.029255176428705454, 0.06026481371372938, 0.08052644612533705, 0.034493412489869764, 0.03779352522854294, 0.0745417604755078, 0.03507950050490243, 0.047699081378855875, 0.012744617066346109, 0.040104232129773924, 0.014864839679960693, 0.024115974249850427, 0.07747862288462264, 0.03343239745923451, 0.031196013891271183, 0.04192946418853743, 0.010189668092477535, 0.008724987490235694, 0.01723229416113879, 0.08706602414271661, 0.029757377159382616, 0.018095102327476655, 0.03308151003771594, 0.07959873947714056, 0.03198130621707865, 0.03280949213408998, 0.04490346621189799, 0.06272216221051556, 0.03821345019553389, 0.01247869834436902, 0.019123255907158767, 0.032016512006521225, 0.021142947620579174, 0.025960955070331693, 0.014245700224169662, 0.023032827103244405, 0.01691260069076504, 0.01852695594009544, 0.010216654278337955, 0.010836493473366966, 0.07900460742946182, 0.02020320376115186, 0.023078275378793478, 0.07343621658427374, 0.017791003288168992, 0.021970336258943592, 0.024643346933381896, 0.010051731253042817, 0.022608632454648614, 0.0236481701556061, 0.03114610764064959, 0.05270714818366936, 0.052470960321703126, 0.02864307338105781, 0.03781711110579116, 0.038635258097201586, 0.0067212252345468316, 0.06222318112850189, 0.0026976160505520447, 0.035037495794573, 0.004428156851125615, 0.025984339083411863, 0.03963473000164543, 0.05581079789304307, 0.02277565554582647, 0.1283879450389317, 0.06668093228446585, 0.03240923111193946, 0.046141470316797495, 0.007762435524325285, 0.050141206942498684, 0.02028106226186667, 0.02297981146589986, 0.02599505484769387, 0.00830058504029044, 0.05251064104959369, 0.03041275717051966, 0.06138681886451585, 0.0329578300671918, 0.06416310596146754, 0.020251735978360687, 0.02697570588705795, 0.025308012696249143, 0.051440207952899594, 0.026526990679225752, 0.04671510382156287, 0.03400703180315239, 0.04972701559641531, 0.003947008093486407, 0.051969461874770265, 0.010601756828171867, 0.053752577264926264, 0.0035552221857610023, 0.02620710721904678, 0.07235377002507448, 0.05410952739683645, 0.03484665442790304, 0.004605075527381684, 0.029034581301467757, 0.020949826376246553, 0.02369848861625152, 0.05787611260477986, 0.01931401415328894, 0.07402998900839261, 0.026991622622257898, 0.050577657629868815, 0.021953020045267682, 0.0537226877973548, 0.038471113690840344, 0.00995135132689029, 0.008821689756587148, 0.049095730363790474, 0.060325467959046364, 0.07151437470955507, 0.03143544854330165, 0.03339400255520429, 0.06439464246588093, 0.035696014030171294, 0.04978437216154166, 0.042413799092173576, 0.054744341011558256, 0.02921194356999227, 0.022830465908295343, 0.015470952959731221, 0.03199082945606538, 0.04202068643644452, 0.06152156234851905, 0.003333067488191383, 0.06730713189712592, 0.03144524319629584, 0.01976309237735612, 0.07240358128079347, 0.012956057908013463, 0.050634657964110374, 0.03234985590513263, 0.011093631952202745, 0.0713564728253654, 0.03253520792350173, 0.00869971714980368, 0.05808500639562096, 0.08451336183186088, 0.029544768389314413, 0.008734367388699735, 0.026163563930562565, 0.008524175051466694, 0.03893222912613835, 0.0299486086836883, 0.03970358434266277, 0.02866427760039057, 0.038144483896238465, 0.04273710406518408, 0.025081575382500887, 0.058961795776018074, 0.021117670494796972, 0.024567861608894806, 0.03722596121951938, 0.04903068260422774, 0.0011868474414638642, 0.05262611074639218, 0.021516479452007582, 0.020235384980748807, 0.10885153764060565, 0.03958978044933506, 0.026406640619305626, 0.03402253632832851, 0.027954674159575785, 0.10199627120579992, 0.049202928718711646, 0.012215709197334945, 0.04325163038447499, 0.02122512669302523, 0.029572099779865572, 0.0497544826939702, 0.01652337604069284, 0.04940718811537538, 0.05824558849313429, 0.02925338170358113, 0.07130400171237332, 0.05958093183913401, 0.013862017508862274, 0.07157392972814185, 0.11565351193504673, 0.027358240181846277, 0.06564086023718119, 0.04283256715695773, 0.04903467917548759, 0.02693379786796868, 0.0017329930685394044, 0.03757443644904664, 0.09543849487922021, 0.04343202570453286, 0.03726923479033368, 0.04879124455952218, 0.01522840722464025, 0.013360348580005978, 0.006606574868783355, 0.007572220106210027, 0.016142945204462324, 0.020651087763586214, 0.020484604107748185, 0.03257284286831107, 0.027693066679473435, 0.032416796777397394, 0.02309448049137635, 0.003202310821507126, 0.011587884493305214, 0.013453072934810604, 0.07468272612563201, 0.018498021510562727, 0.03732119021671159, 0.044325975235551596, 0.014376190989943487, 0.058234521586980136, 0.030557234239365374, 0.03438017517328262, 0.009170692547091415, 0.04463840668488826, 0.04483610125524657, 0.03987671255267092, 0.09026666025498084, 0.06020804747406926, 0.01693252587158765, 0.010813913524283894, 0.03143218818253704, 0.002925632654556206, 0.032044701743870974, 0.017424809812967266, 0.06547798469130482, 0.04083224931465728, 0.06137144326099327, 0.005326796755460756, 0.047067853821707625, 0.0022396532585844398, 0.020225927898926393, 0.02361850969360343, 0.037387425412556956, 0.01245589617506734, 0.029360919326011623, 0.02978363646460431, 0.047830462721841674, 0.017126001650467515, 0.06115422384547336, 0.08017799803721053, 0.018296081007325223, 0.05708049636866365, 0.04716978335220899, 0.05271701069016542, 0.014315389163259949, 0.040789623744785786, 0.07556872322623219, 0.03925744417522635, 0.05540309673441308, 0.02292370510154537, 0.06539751043809311, 0.017582835529797843, 0.026593775488436222, 0.04442157742700406, 0.054999270010739565, 0.015746478889403597, 0.07369080970862082, 0.035390215260641913, 0.03348781341420753, 0.06544025814426796, 0.062033863072948794, 0.030996449956936494, 0.07552334280418498, 0.011782033718191087, 0.04046411692563977, 0.04241603486506002, 0.04220470513350197, 0.034768565225281885, 0.08887695946863719, 0.034226059514497004, 0.0441747128165194, 0.04109779399420534, 0.020013822941109538, 0.025045724984790598, 0.06243661431861775, 0.03440596968201654, 0.0973251818546227, 0.008884800298671638, 0.017850412421726754, 0.024847255188173482, 0.011501165173415626, 0.05797011684626341, 0.04988395396087851, 0.010559442536240178, 0.0430107504528548, 0.04474690443437014, 0.04224200081080198, 0.017029169614293745, 0.0020213182890854242, 0.040410326062036414, 0.0052970226388424635, 0.03386713484568255, 0.02896457345091871, 0.001839476841269061, 0.022676105976903012, 0.035605080159647126, 0.07309853684689317, 0.1301232169249228, 0.07358401508203574, 0.09472906616117273, 0.07339342816599778, 0.22386493320975984, 0.17032496471490177, 0.14257859571703843, 0.10607284174433776, 0.0820549548204456, 0.1197529626744134, 0.0761927447414824, 0.10375896947724478, 0.12963921789612087, 0.207141107746533, 0.1161315669970853, 0.08076957879321915, 0.13401913430009568, 0.07916491811296769, 0.1132759659418038, 0.1378366673099143, 0.07974009867757559, 0.18363649185214723, 0.16102686364735874, 0.19240140010203632, 0.1487659394208874, 0.11788602785340377, 0.1621756912874324, 0.08239766250231437, 0.1314372407006366, 0.13379159436694213, 0.05887811205216816, 0.1775934182639633, 0.17696646547743253, 0.12199814005621842, 0.07998624404094049, 0.1627893719289984, 0.10968841559120587, 0.18063143667365822, 0.11838872730731964, 0.1372516072754349, 0.08407244977674314, 0.10633236103292022, 0.2866284724857126, 0.16722811731909, 0.09998315280037266, 0.13667033346635954, 0.15033659871135438, 0.13443669117987156, 0.1581625094903367, 0.11177707530025925, 0.12118925846048764, 0.1664132917565959, 0.13845817824559553, 0.11462078163666384, 0.21660973823496274, 0.17275831342807837, 0.168188515784485, 0.23523818435413496, 0.16540551797619887, 0.11747248790093831, 0.09494562061237437, 0.1391496461416994, 0.12422992315675531, 0.07907900879425661, 0.32237331728850094, 0.19340052934629576, 0.11119582184723445, 0.09701374785176345, 0.1266753226518631, 0.058028905120279105, 0.10267704539000988, 0.15952088231486933, 0.10455738127763782, 0.08651726573173489, 0.06487075691776616, 0.14897898584604263, 0.09673721090491329, 0.09952870397163288, 0.17715500321771416, 0.14212589072329657, 0.14472401488040174, 0.12129911328000681, 0.048335007791008265, 0.14963135655437196, 0.08787388115056924, 0.13070303866905825, 0.10871762875467539, 0.13536715268024377, 0.16476378669696196, 0.1374987025878259, 0.07407745931829725, 0.130378251097032, 0.131971397038017, 0.145295097093497, 0.15179696891989025, 0.15075536338346346, 0.14790609984525613, 0.12441513607544558, 0.12294935115746089, 0.15757014841905662, 0.1279282375637974, 0.10530250093766622, 0.11289849691092968, 0.2077960026051317, 0.17945021577179432, 0.16861899197101593, 0.08217169677040406, 0.10013625065663032, 0.0467024864628911, 0.22569833483014787, 0.12582810382757867, 0.15786778101963655, 0.039584331813135316, 0.08395853731781244, 0.15426025459808962, 0.1266387767557587, 0.1524835785052606, 0.23847031806196484, 0.16540728216724737, 0.08284275433314697, 0.12415031742836748, 0.13793835256780895, 0.11143756351832833, 0.12413137273064681, 0.14845165557094983, 0.18019968484129223, 0.15582929897521222, 0.0907801009182419, 0.12060939600425107, 0.1104759844020009, 0.11950379104486533, 0.12612561429185526, 0.18687253392168454, 0.10930437834135123, 0.1651226095855236, 0.1469863456274782, 0.10224749879645449, 0.11398711135344845, 0.13598069761480602, 0.18196226097643375, 0.05698238020496709, 0.07686993626079389, 0.15817707085183688, 0.14989263324865273, 0.06089306928749595, 0.09172778363738741, 0.15126616454550199, 0.11703285149165563, 0.21115567375506672, 0.11945881774382931, 0.12880817534668104, 0.17287527929459298, 0.06596247226532016, 0.11885386306260314, 0.05421387929735439, 0.17988702947539942, 0.13831379956432752, 0.14464987814426422, 0.059849957403327735, 0.08876303343900613, 0.10069671379668371, 0.13209085991340025, 0.24963238196713583, 0.14679465948471002, 0.16419905557164124, 0.17686174038265431, 0.1250405010900327, 0.09415222318576914, 0.17424028819160803, 0.10285803782088415, 0.15681808734578745, 0.09342487435787916, 0.17266971032534326, 0.12819176699434007, 0.17572613060474396], [0.049679599569312165, 0.023657650986154164, 0.042834026007247825, 0.02268869280149894, 0.06128944230398961, 0.059601131826639175, 0.05002859727080379, 0.07216721360704728, 0.025764548020171266, 0.01879296880880637, 0.0152493671713663, 0.06293840453560863, 0.04022497743634241, 0.02485248669316726, 0.05189591207142387, 0.05030795692333153, 0.0038993596681393683, 0.043159179988184145, 0.080103460965412, 0.07378460360424859, 0.04405379109084606, 0.023810618224420717, 0.01036310673225671, 0.020082653533401232, 0.023001962241583636, 0.02730634921629514, 0.04147067612835339, 0.055673360625015836, 0.010893299576959439, 0.03489277106044548, 0.011333589076197572, 0.0378112146364791, 0.038159896819187064, 0.016540188442117403, 0.025550778955221176, 0.04735923711476581, 0.02710692098896418, 0.04346377435805542, 0.026699280898485864, 0.0332215494875397, 0.04734886231433068, 0.005590680296466286, 0.037658048926719596, 0.030657579390598193, 0.023775280120649507, 0.042545821650752, 0.06898611251796995, 0.029304278615329946, 0.02560540272055992, 0.07046723911272627, 0.06116496505481856, 0.004399899684358388, 0.030914869691644396, 0.017742330274943794, 0.04952055435361607, 0.03311422560364008, 0.07620567761893783, 0.003722829877265862, 0.048880353170846186, 0.013461614842526615, 0.02494900151421981, 0.03692184860951134, 0.04266779849837933, 0.07736235590917723, 0.015361593470775654, 0.0793571402984006, 0.06607379950582981, 0.029811361405466284, 0.06918963909681354, 0.010241220638688122, 0.03585869280089225, 0.031854993530682156, 0.022671164545629705, 0.03744843928143382, 0.037380969151854515, 0.03367136392210211, 0.037007228670907874, 0.04687675800440567, 0.02360089831719441, 0.04098958462210638, 0.0454074480969991, 0.054635090088205676, 0.012187284517234989, 0.03424882775704775, 0.03746517874034388, 0.038735321656401665, 0.046489433252385685, 0.054384049094681225, 0.015172670661870922, 0.041525522113910744, 0.00418117137659075, 0.04832842939400247, 0.0362543669263167, 0.04950222033741219, 0.023306001909077168, 0.07844050734170846, 0.07100737334362098, 0.01532336141514991, 0.01713870043334152, 0.03912184912977474, 0.06689145455935172, 0.06631332915276289, 0.047481902675437074, 0.023602391094235436, 0.023310156239728843, 0.006015146359069539, 0.03856273627440844, 0.010890421740311598, 0.003792014155936028, 0.0388002167455852, 0.03970831712441785, 0.0973568626546434, 0.023520215414464474, 0.009670766918653888, 0.042909024482859034, 0.007218307266677064, 0.060723157333476205, 0.08568203662122999, 0.055441366109464846, 0.04724735686821597, 0.013184665685652621, 0.057799628137477806, 0.003293251053297094, 0.04885264180068459, 0.03688856985952173, 0.07586425236825432, 0.012285951990634203, 0.03660755118887339, 0.04485423510361995, 0.07096475455909967, 0.03352062736770936, 0.03907117274190698, 0.024341285195467726, 0.020207061232732873, 0.006396164976259959, 0.014973714016377926, 0.027325505956209133, 0.025910034409857223, 0.06568822876683303, 0.045385948714933226, 0.03124312118494085, 0.053493573662957976, 0.07533150738371269, 0.022641444711812904, 0.05629691055842808, 0.015518787982208388, 0.01902398114491786, 0.04871370157759104, 0.04780439001375011, 0.018712614995560477, 0.037242816029382605, 0.05029661860316992, 0.027408210893294642, 0.057377504717026434, 0.0738846535927483, 0.07760203483381442, 0.01769248509247388, 0.05810050413544689, 0.07108029550207512, 0.027987650961482098, 0.040768592551882775, 0.04383320614163365, 0.035449112100260596, 0.027376986408073987, 0.05420064786449075, 0.010425903451895075, 0.005191247511122907, 0.012449904710852673, 0.03059359693101474, 0.022513875039294362, 0.05358586799619453, 0.020175753626972437, 0.03701255517080426, 0.016007104190066457, 0.08298557916922228, 0.04611412196287087, 0.028036585210689476, 0.022522758759026016, 0.03922356492174523, 0.07183102664670774, 0.05147185482616935, 0.035953728415604146, 0.03937180446726935, 0.010040462482720613, 0.018419682946322218, 0.045504909474402666, 0.000784198082068802, 0.023209339506658058, 0.03224724444693752, 0.026673628882105862, 0.03994758892804384, 0.03092320549434849, 0.03947677383465426, 0.018501726311764548, 0.03537598638130086, 0.093257276208273, 0.051771590885307105, 0.029603210610470602, 0.022494102528850948, 0.0448747913220099, 0.05214328558317252, 0.023268290629078234, 0.03952950618362852, 0.020967420789280107, 0.019681340781971812, 0.05697269072490079, 0.04314244731462427, 0.062294705504817624, 0.061456117645970414, 0.027967417047226002, 0.00309728886765827, 0.009993083775043488, 0.020880671783483455, 0.02782070929450648, 0.022336480540356467, 0.05552892087559615, 0.026782396349257657, 0.009205318189093044, 0.03555846819654107, 0.011396281471076821, 0.031433830237282176, 0.08749962159033332, 0.02368256339936384, 0.02012293815745839, 0.05735999172819512, 0.04806097463837691, 0.029921969398856163, 0.032735871084566624, 0.018815133155190518, 0.033884688546614986, 0.027159973945734755, 0.031196057996047393, 0.005599621691674526, 0.04003828531131148, 0.006460292048619262, 0.020474361621641686, 0.07619558101786034, 0.038582478250776014, 0.02094678484302546, 0.04145018097811511, 0.05175684292667678, 0.02871400403923222, 0.04288944874757102, 0.011311831002655839, 0.027215523911373954, 0.01618995071787919, 0.010127918013105435, 0.04072929858895285, 0.030092790589800904, 0.028492380931441273, 0.019835614200149263, 0.051409209080572636, 0.0161621850649161, 0.03246767333309565, 0.015608374960720539, 0.03476894859756742, 0.03216814761981368, 0.03758492320775986, 0.02917420005957995, 0.02208267790930612, 0.07910752083574023, 0.028561326874686137, 0.036920423685972176, 0.02123403755415763, 0.026243215460064154, 0.024528140168903128, 0.0406474401243031, 0.031007384548762014, 0.06594048773071595, 0.02235717246575015, 0.03347417825300779, 0.07032408857984201, 0.026025395541052734, 0.02467805060691067, 0.051708904427609274, 0.039222408019538434, 0.017059199877881577, 0.011889722314663231, 0.03359341721183487, 0.041977121095572195, 0.017539422859304717, 0.03669475990214518, 0.03508612300668444, 0.03365588993100183, 0.029614854271390607, 0.08527271037123033, 0.03156953724101186, 0.03791265222909195, 0.028161160847438232, 0.05059700605592557, 0.009821783368741828, 0.01653140819897609, 0.04349751790453281, 0.07474979252687522, 0.048356395214796066, 0.027544513311503187, 0.02141962366710816, 0.023024177478094186, 0.03594267847282546, 0.027846849856099913, 0.030603330515857254, 0.020624263577961495, 0.03847741388848849, 0.008259386090295655, 0.01493167198662247, 0.029077837908906595, 0.009336956527217158, 0.07404663347240005, 0.021612789016216993, 0.06828882957675628, 0.030810521183801547, 0.01562442401024912, 0.022313137239377414, 0.02734970590764923, 0.08548149559646845, 0.014939748249681932, 0.019191124676061527, 0.056529865201030455, 0.05362017811941249, 0.0503990909616862, 0.02089152834378183, 0.019856898147346716, 0.023144598784191266, 0.03702123363369277, 0.06434914669288055, 0.01605278656019696, 0.04506272855880005, 0.0513800117187202, 0.04901482184816684, 0.05868203578782933, 0.07859228205467973, 0.029623892357839004, 0.060610595159232616, 0.05003674647637776, 0.0751043406448194, 0.00699932493236182, 0.030919802641229968, 0.026931263539674025, 0.00480281505068498, 0.055993507017514536, 0.030026667352233614, 0.0263266820527081, 0.022039031144231558, 0.0191913384145924, 0.03263022657483816, 0.0431020710883396, 0.036775013631475825, 0.029605738153415065, 0.04710293747484684, 0.06625646113284997, 0.03299163468182087, 0.006804709214650626, 0.09381694546235458, 0.10283576830157212, 0.13375016301870346, 0.16109450001801762, 0.14230266266635486, 0.19706138862030848, 0.11859687470964023, 0.16358081517474993, 0.14517982756452902, 0.0867930766461151, 0.12057812911059175, 0.19159943956349576, 0.17042939125427178, 0.08079627914620297, 0.1410601564816066, 0.162256816934262, 0.1252099041427885, 0.14734252222946712, 0.15108901262283325, 0.2977413833141327, 0.18392641629491532, 0.11983558109828404, 0.14538515226117202, 0.0863256813692195, 0.14192826061376504, 0.11573176059339728, 0.1559826343187264, 0.1593341901898384, 0.11376721850995507, 0.1610317626701934, 0.09433084074407816, 0.17022422940603324, 0.1374627673732383, 0.05614047770255378, 0.1096228351816535, 0.0868859002366662, 0.14017860378537858, 0.15904498499419006, 0.09529806527176074, 0.08131134150815861, 0.08183911283101354, 0.078805912019951, 0.20207521958010538, 0.12581628374755383, 0.08938578609377146, 0.2720865713698523, 0.1920521038451365, 0.08984725097460405, 0.13983245593096527, 0.25895404177052633, 0.16473702527582645, 0.09370493968682629, 0.19544108770787716, 0.10247703362256289, 0.12212600319513253, 0.08575208179120507, 0.12821506788688047, 0.12266421717192445, 0.12414269069475786, 0.13901712825255735, 0.14815945125051908, 0.10738385282456875, 0.13706792784588678, 0.1998043664331947, 0.1275412826133626, 0.10084449193839516, 0.19426857919565269, 0.1076625000153269, 0.0745063205914838, 0.06973118468054704, 0.13465127109416894, 0.12590840166168554, 0.13258982742471354, 0.1924674894128527, 0.11969270876475743, 0.19318185108048574, 0.19306913284318789, 0.10174384260816233, 0.10008335206657648, 0.15747771837881633, 0.16686533178601945, 0.18270437472632953, 0.09124248182134968, 0.06224141336445298, 0.11620573087462358, 0.14453249158603804, 0.11106964826051678, 0.1611773491437946, 0.09318462546382632, 0.10242062700646264, 0.10919587380651917, 0.09815929138234683, 0.168983324563929, 0.13879779859312943, 0.15154806870434964, 0.2869019763810294, 0.12556731567851134, 0.11161816918424197, 0.15586861329419271, 0.11068470177373715, 0.12211965210735798, 0.13194114794688566, 0.1935971959361008, 0.21585722932858126, 0.08543821863297905, 0.16022589376994542, 0.12380065476255757, 0.12683286491249288, 0.0967738517959203, 0.18870227145297186, 0.11576225395713534, 0.18384689199072973, 0.13611546824020998, 0.1252767534128257, 0.12130595291299479, 0.08524046638714415, 0.1640376728028059, 0.2186537299837385, 0.09083253131913287, 0.08805659706039087, 0.11956684051879815, 0.07990855856665544, 0.0997269990454827, 0.10028674972376653, 0.206410339102149, 0.13854056596755981, 0.11504782443600041, 0.07771710080227681, 0.18058773901845726, 0.18892156040029867, 0.07339099222528082, 0.09447842211063419, 0.09582035403166499, 0.1660069985581296, 0.0651119082633938, 0.09138450598610298, 0.10730358213186264, 0.08872804138809443, 0.14159927969532354, 0.07338840700685978, 0.1450086874621255, 0.17318576334842614, 0.18128805501120432, 0.13552318859313214, 0.09377744793891907, 0.11550065156604562, 0.10700058231928519, 0.07113144347178084, 0.16030841719891342, 0.07735563162714243, 0.15810039639472961, 0.16965701484254428, 0.1194360868207046, 0.18090317637792655, 0.19590690199817928, 0.16042744581188473, 0.11064653417893819, 0.1792663327817406, 0.15803269217056887, 0.11550441065004893, 0.11103916846747909, 0.10388069187424012, 0.08397130734686341, 0.14101569886718476, 0.13799247252089636, 0.08467814406113965, 0.10394502377935819, 0.09153690495129142, 0.03329065488651395, 0.10423489393932478, 0.10574742313474417, 0.1223918396447386, 0.13934256721820149, 0.20372384254421505, 0.15365569346717425, 0.07207126197006021], [0.08907409424760512, 0.056061994949621816, 0.022701476401250278, 0.02789827941783837, 0.0272436915963356, 0.054195664024778774, 0.018387520386438285, 0.03437732193352921, 0.033055756241083145, 0.011861035550412322, 0.012069515434892049, 0.06556719847555671, 0.020550320224304284, 0.01248818087125463, 0.026875313238373826, 0.04733682171042476, 0.06361719739756413, 0.02618041874042579, 0.0529296771357102, 0.031096018185572963, 0.03616156708449125, 0.019124400935002735, 0.07136265427938529, 0.04324691117342029, 0.07199215157223599, 0.043687202368995974, 0.042193210750286064, 0.06252318181629692, 0.0033023968571797013, 0.05178239994815417, 0.03837957253147449, 0.07723580234284912, 0.02379855896080179, 0.012850541471769767, 0.00863615538193179, 0.015826783508860638, 0.05450632789039186, 0.040061467460223606, 0.030389524131481136, 0.02770658309704491, 0.06421500710504395, 0.012760542283233787, 0.006793126197797912, 0.024566552036308816, 0.06173959600606135, 0.006636385880743286, 0.006685638617325042, 0.00951440615712532, 0.0378913903342826, 0.04390205369730081, 0.11222276424190827, 0.031302856015307565, 0.025332205862339054, 0.08277673966118268, 0.03970058861055544, 0.014398109367383378, 0.024174913497907773, 0.01438501024884837, 0.062086490248995166, 0.03417272326935615, 0.05545875356931772, 0.04340760522921171, 0.030533461764987026, 0.05767882176275764, 0.011567872799267727, 0.056135062993104966, 0.033578123032514534, 0.029259278172893182, 0.0024671043460589965, 0.014074990991503, 0.046920228350375376, 0.03277180969182934, 0.04788358522845166, 0.057436666185302396, 0.03483460025329675, 0.017031303606927395, 0.013527987441713256, 0.030486381612718105, 0.041618763003498316, 0.019776176228853207, 0.006838723751051086, 0.02681452328605311, 0.04632500046864152, 0.02654101260538612, 0.02810907649940678, 0.03881924965285829, 0.02084970344523234, 0.013133920596114226, 0.032313476250107796, 0.023659993628306047, 0.01420674637691783, 0.007434325675213975, 0.04594921759728875, 0.030484905799052546, 0.0840565991987075, 0.04962989009384598, 0.06636016163975, 0.013868773173141693, 0.018488774774596095, 0.04768658276381237, 0.030085720254906585, 0.02216786119554724, 0.025903973395803144, 0.03621012983577592, 0.017974899848923087, 0.03588571545800992, 0.022677405371463726, 0.0053993033112159795, 0.051319862981992106, 0.03950000687369278, 0.04688871718410935, 0.03151856229773589, 0.03594986755134804, 0.053511473416749916, 0.07764575284506593, 0.002722303062910214, 0.015133169745760304, 0.06862938630261592, 0.039927969087979624, 0.021127880750490085, 0.0833709802744644, 0.08105750155768224, 0.027433158929592798, 0.04014970754672374, 0.021658544328862002, 0.008336352317460945, 0.021080764975132685, 0.012088365985878875, 0.022967319636206542, 0.01695622709978904, 0.023029407286750417, 0.0284442982436823, 0.035699661155896525, 0.025000619369425943, 0.01888560749856489, 0.022479222255891988, 0.025049005701605762, 0.05992109501468284, 0.03103618836030364, 0.0602287088653871, 0.01576651942117938, 0.06801120697387628, 0.023875179135107567, 0.04460542309763176, 0.03819133673927613, 0.05460329393723181, 0.06881140332136836, 0.010280378046445549, 0.01268283136388553, 0.03530413291550108, 0.018632544470684867, 0.05636451639501112, 0.0447406517341733, 0.08972571856741395, 0.03355241673333304, 0.014460441290533968, 0.07462199045611279, 0.05172735718744142, 0.04318508645519614, 0.033026738691010644, 0.0049895075998002926, 0.02459068752692214, 0.03214438193078552, 0.03670567074524505, 0.047891659795173576, 0.03543131412672145, 0.033148321988327165, 0.055052365375948806, 0.040950789382415156, 0.003603728745864438, 0.01717190454447908, 0.055377102057848654, 0.024437204602041414, 0.03430189598085625, 0.04571864800527692, 0.007086179535170751, 0.014906824034239565, 0.07810288867247955, 0.046076799144170115, 0.03814352037651198, 0.024082366410376768, 0.02354115161246487, 0.007370690116658807, 0.037568170178149424, 0.003869884955098054, 0.02868516630093966, 0.02557522996461817, 0.010214416809113962, 0.0345536867555763, 0.031468510162085295, 0.05702343835894551, 0.06305817953710045, 0.046909561779882224, 0.06358967601720776, 0.026152363013742224, 0.0172036735540522, 0.026059206941031983, 0.04615555331110954, 0.042746416958315034, 0.11467961062278066, 0.038591611332127025, 0.07401360917304244, 0.020245271235970513, 0.048447536038500924, 0.045914510531084876, 0.08188428969255515, 0.06322470560137715, 0.06283036818993942, 0.012513278185256889, 0.050573654273258786, 0.07491782493889332, 0.05781231674232653, 0.03686442079820803, 0.042574493147964985, 0.027758278983778188, 0.05920579696872404, 0.027833906800619194, 0.032574311896626434, 0.018192024269540395, 0.04095921678734677, 0.022647234311859523, 0.062121828352766376, 0.13312517798372678, 0.0061493546485767835, 0.009641511881324862, 0.027195547840424945, 0.050724529927330356, 0.03717571230871337, 0.05913972801395825, 0.09147765527346305, 0.03758038720116019, 0.04049509883459125, 0.016116894548758864, 0.03021877757938845, 0.026214879837685397, 0.02568499996726002, 0.048940182996115515, 0.0479862306133977, 0.029944900489811386, 0.06464733569217579, 0.010674684075638652, 0.07175658456981182, 0.010027275154633182, 0.062094809088323794, 0.04741088720038533, 0.033905994546200545, 0.019013738658811365, 0.03670501595895205, 0.06104126133556877, 0.07993675848203045, 0.043492211760686975, 0.04111504574705448, 0.041918621198939424, 0.05176193533199174, 0.043880846085292954, 0.047465139467801364, 0.03457639392997537, 0.018643636821902225, 0.0475859119157706, 0.01813842000306717, 0.06270198936441115, 0.03134375810623169, 0.04859159580831017, 0.044280289472745996, 0.0629015261573451, 0.00837839943622904, 0.02943457430228591, 0.02472869137168995, 0.03377536637708545, 0.049719222621726136, 0.03792427892663649, 0.006367378976262573, 0.056572558624403815, 0.04274043906480074, 0.03640490331287895, 0.014449544018134475, 0.0035640505624801983, 0.026004671385245662, 0.07832359575799533, 0.0409079432886626, 0.041006629421774826, 0.07293439244053193, 0.03362544406471508, 0.014546503279624241, 0.0346638333451535, 0.08178529143333435, 0.06959532839911324, 0.01368467474821955, 0.026635468072657074, 0.06156111415475607, 0.039563996118626425, 0.06214348040521145, 0.048644769205046554, 0.06478857954165765, 0.0286933799673404, 0.07849002682736941, 0.05298591411805578, 0.03969583208007472, 0.02420507607582424, 0.06273816206625529, 0.04644513509369322, 0.023836212565324137, 0.038943818504256864, 0.05338985619268247, 0.059841312867190154, 0.018831075335453664, 0.06839297113141843, 0.0471426690928638, 0.027540157116683464, 0.019902790863333002, 0.02452270171072866, 0.020129679402868663, 0.026979553180613687, 0.03159642079845071, 0.04470927966758609, 0.02214507938229612, 0.033722735808363984, 0.025584917748346925, 0.032117250708064864, 0.04761557068143572, 0.038815049521092854, 0.05958496233714478, 0.028332477368946587, 0.040350255356835465, 0.009683067062204438, 0.016109547710844448, 0.02018420647696725, 0.04477816454267927, 0.029665646010211537, 0.06748151539691857, 0.01328346208070538, 0.024734859255009463, 0.08861021378210612, 0.05053401425746935, 0.01056481059640646, 0.08117882361901657, 0.02358412493153342, 0.044914794354034324, 0.029488633187221627, 0.025663736376113126, 0.004801728970570756, 0.043586945427315574, 0.005320449484445686, 0.05837001824485404, 0.05474032747692295, 0.014001333470722395, 0.015030580339953303, 0.04075062833726406, 0.055167098862252066, 0.026212038472294807, 0.07918381531323705, 0.034458189737051725, 0.11821225391966955, 0.1321853527000972, 0.16834075190126896, 0.14110000005790166, 0.06233170601938452, 0.19056071101554803, 0.11035884890173163, 0.1888946361307587, 0.1041388948048864, 0.10892528082643237, 0.21513064045991215, 0.15100923047534057, 0.09623504749366216, 0.15941056609153748, 0.13848388115210192, 0.24283145261662348, 0.1243686428559678, 0.11485090000288826, 0.11491811568183558, 0.15568341394620283, 0.1165712441184691, 0.10852474839027439, 0.12014678439923696, 0.1346141823700496, 0.15955058857798576, 0.1195704774664981, 0.08552358512367521, 0.16195706730442389, 0.1251404492982796, 0.16556403732725553, 0.16853926410632475, 0.1787979807704687, 0.06510971659528357, 0.08789233051772628, 0.13542716231729302, 0.10229875533176319, 0.18589141299682005, 0.1258725614420005, 0.11642449056463582, 0.24274435586162976, 0.147097896784544, 0.10085617631141629, 0.10777830558695964, 0.08030099608004093, 0.11098217831126281, 0.2019812831921237, 0.2823912655668599, 0.20043449476361275, 0.14058150430875166, 0.07865423230188233, 0.2834065710859639, 0.12736232578754425, 0.09785893107099192, 0.2125246860086918, 0.10914314485022, 0.07909269484558276, 0.0968395679124764, 0.07813513265656573, 0.18746025381343706, 0.10190888946609837, 0.13508919759520463, 0.183536204376391, 0.2601051357175623, 0.1227572171815804, 0.08586184840117182, 0.15122687736792223, 0.07432524673640728, 0.1224805513130767, 0.12892937527171203, 0.16101437860301562, 0.11836041882634163, 0.11852938761668545, 0.13217624676014694, 0.18502549374742167, 0.09682838565536908, 0.0741548937346254, 0.1053502019494772, 0.2165588888206652, 0.16282017741884502, 0.10653974169066974, 0.09169016565595355, 0.1154945854629789, 0.15123871101864747, 0.12258732558361121, 0.13195645569690637, 0.08124865844313588, 0.09724497223006827, 0.10317097817148481, 0.1861317636711257, 0.07629788374262196, 0.14579312822648458, 0.11052325115139995, 0.16955968577946934, 0.09340593644550868, 0.140951523025121, 0.17250880253102097, 0.1779301751937185, 0.08697344482477222, 0.12537581952554838, 0.09319194685667753, 0.09815244496400867, 0.11780756206384727, 0.13617741848741258, 0.0764323558126177, 0.10627914353140763, 0.10196030206446137, 0.07063666930688278, 0.05040589666792324, 0.13903576082416944, 0.10509199223348073, 0.15262436095092977, 0.11541549542120524, 0.1334953052656991, 0.15819269072796616, 0.08568680672241108, 0.18885621747800282, 0.15950185619294643, 0.13188738083200796, 0.15226788579353265, 0.18066004371004446, 0.13557136457945618, 0.11412722883479935, 0.1030550640342491, 0.25032633330140797, 0.2193709143570491, 0.08098476938903332, 0.07243967255843536, 0.14643454737961292, 0.0960887824850423, 0.13735112122126988, 0.1749823069466012, 0.08531368031565632, 0.11472123196082455, 0.28286708146333694, 0.12056272636566844, 0.10306740658623831, 0.12011493396546159, 0.0820114335843495, 0.12103310041129589, 0.15731898189655372, 0.1401886868157557, 0.15559700929692813, 0.07763953067894493, 0.09362951373415333, 0.08593634476086923, 0.14450054615736008, 0.11049599439970084, 0.10054014862648078, 0.08674471066998583, 0.14383159205317497, 0.12920077570847102, 0.15477857392813477, 0.09585424685584647, 0.19384974667004176, 0.1845736029957022, 0.14387300983071327, 0.15545653897736753, 0.10577202681452036, 0.12786617875099182, 0.10064071430159466, 0.18965816444584302, 0.17277334976409162, 0.12303814425000123, 0.10434685221740178, 0.1708422526717186, 0.16981809905597142, 0.12993579198207172, 0.1375563373523099, 0.1535057643694537, 0.06173642724752426, 0.1172402525054557, 0.15496871301106044, 0.10523796547204256, 0.08210479321756534, 0.13371026515960693, 0.12146572076848575], [0.0730870763904282, 0.009017920387642724, 0.019996734036664878, 0.1005396329398666, 0.08417501713016204, 0.05046409122379763, 0.033255421955670626, 0.06014964596501418, 0.03447884773569448, 0.061444012581237724, 0.03309828003070184, 0.060630591586232185, 0.043534850901258845, 0.0401684045791626, 0.027331670446853553, 0.024888803583702872, 0.021574456876675998, 0.04390137176960707, 0.07318356407008, 0.014287533604406884, 0.026950201452044503, 0.021674150634290915, 0.04082779473225985, 0.0742460684850812, 0.028927399909922054, 0.02532976313627192, 0.041976279712149074, 0.045992372424474785, 0.041456454034362517, 0.05192340291770441, 0.027801939319553118, 0.037800602348787446, 0.03994920723406332, 0.02724167804366776, 0.07108077726193837, 0.05289327712463481, 0.019488297569166337, 0.02754428260959685, 0.03779146587476134, 0.028303145996427963, 0.015253565606794186, 0.05233633897400328, 0.024712798385215656, 0.032391093870890994, 0.16486995028597967, 0.028003364136176448, 0.014133822522126138, 0.025538789241441658, 0.03634362142266972, 0.02826280708956931, 0.08385115915111133, 0.021356565711487616, 0.030243859626352787, 0.017947503997545158, 0.005900423474875944, 0.036537913139909506, 0.05311809613236359, 0.03013028982760651, 0.028686815141034976, 0.057574497003640444, 0.019007530063390732, 0.029766992000596862, 0.041806418648255725, 0.022462255487750684, 0.056612029006438594, 0.040943135507404804, 0.11268042932663645, 0.06023201333092792, 0.08168368759964194, 0.0644396429083177, 0.01709339295380882, 0.005642231570423714, 0.04994678291093026, 0.03878482078601207, 0.02055391645990312, 0.03785120749047824, 0.0380188090327595, 0.01804028857233269, 0.06816589938742773, 0.03844506812414952, 0.03432871847014342, 0.09264489156859261, 0.0298611048076834, 0.03176044306850859, 0.03105290067781295, 0.021056576898055415, 0.017461569447602545, 0.01845117375653769, 0.03827009090621557, 0.02468041530145066, 0.014898622242201651, 0.04215838494045394, 0.027351900968434553, 0.015711257832923105, 0.02762896377992417, 0.011927488725632429, 0.050485750061592886, 0.027404271997511387, 0.04782341952834811, 0.036940162269664664, 0.0215295242877411, 0.034902267158031464, 0.02902160431923611, 0.026521949164037193, 0.01985268953389355, 0.05610800301656127, 0.04160837123968771, 0.07792141448174204, 0.06457247292356831, 0.052773346060088704, 0.08509659660714013, 0.02347744904857661, 0.036384567618370056, 0.0390051478919174, 0.03795616667983787, 0.018578146318239824, 0.021291090474863137, 0.04886083850370986, 0.030422273624156202, 0.0666908524664385, 0.04303195467218757, 0.02338920217672629, 0.08980830306453363, 0.005381214415787586, 0.03647118939885071, 0.03104625442730529, 0.0025708449289335734, 0.019001799835158244, 0.044050333954926045, 0.050873312300869396, 0.07946464060140507, 0.023627931152337363, 0.04760063951835036, 0.05870475992560387, 0.06903048192283937, 0.06506453973374196, 0.11896166870636599, 0.020146376453340054, 0.038762317172118595, 0.06348275246896914, 0.06432672789586441, 0.043186287462179146, 0.050878794863820076, 0.051617593970149755, 0.016647391886051213, 0.02916958262877805, 0.035741326598716636, 0.030145763818706785, 0.07805613760969468, 0.020273345622367094, 0.025937257234805396, 0.018568380502983928, 0.0644157991877624, 0.01630753744393587, 0.02709831207591508, 0.05702091420867613, 0.04765995704968061, 0.02975089375727943, 0.013190526531876197, 0.06330952247870819, 0.010000904739302183, 0.027697947042595063, 0.12998753706259386, 0.03153972580496754, 0.026594952746693577, 0.018257860826062303, 0.010842285617919905, 0.016246699994163852, 0.03403988986143044, 0.013725089142099023, 0.021124915552458594, 0.03181571653112769, 0.022715569573587606, 0.024781196411432962, 0.03854455832125885, 0.01659644238783845, 0.06650919507124595, 0.020352705381810665, 0.024191515553476553, 0.05846028375838484, 0.02992203046700784, 0.04048970787386809, 0.007195932574437133, 0.02767411180372749, 0.07602037649069514, 0.12553784011730126, 0.05653784816552486, 0.036550669598260095, 0.029464361989604573, 0.011354426886620266, 0.019242947788110802, 0.044872949099434276, 0.03792396001517773, 0.01420795077657593, 0.07353690439569098, 0.01995649860639657, 0.10685226813490901, 0.031762909543301375, 0.06423450820147991, 0.015681049453892877, 0.028122138298515762, 0.030467189249715636, 0.027373393565150242, 0.05994799892817225, 0.046975698588149886, 0.0413556542646672, 0.014611591751288091, 0.022651198652705977, 0.07248257632766451, 0.05770484358072281, 0.09727093297988176, 0.027309292361938527, 0.03543410969099828, 0.0184248635611896, 0.027910248775567328, 0.00649048134385209, 0.033671346958726645, 0.03539958922192454, 0.028615782702607766, 0.02403766621968576, 0.10246999042906932, 0.024029442375259738, 0.005559202208782413, 0.024270693804802637, 0.05158450520996537, 0.03798277543059417, 0.05334810593298503, 0.020575371737192785, 0.03358975651540926, 0.024984110612422228, 0.01918312644452921, 0.030426941945084503, 0.08783086881573711, 0.029542729391583374, 0.01978199297030057, 0.030618662014603615, 0.028175247234425375, 0.028860126555498158, 0.024479339930361936, 0.05218433355912566, 0.04345288387100611, 0.02924358026523675, 0.05950324636484895, 0.0100474098331428, 0.0545353725818651, 0.026660081930458546, 0.058481929025479724, 0.02313866329911564, 0.0530648752381759, 0.010096047223279518, 0.029828307817557027, 0.06661070391003575, 0.07139436900615692, 0.027623092755675316, 0.06300694335784231, 0.050988513976335526, 0.017138764894168292, 0.020101900179205195, 0.02340705443306693, 0.02736764637354229, 0.0231780929690493, 0.016326473659968803, 0.054501890271369896, 0.01620895818008908, 0.03183732108612146, 0.0461690765140312, 0.020904020173475146, 0.05818050341414554, 0.01993699242094798, 0.04417946256164994, 0.07093265306736742, 0.019793397447626506, 0.034903020331902165, 0.016048080919842635, 0.03793936615277614, 0.048984501510858536, 0.03930540642301951, 0.030401513845260655, 0.055991427307682376, 0.01560922312949385, 0.06770372883017574, 0.06410737109503575, 0.07254869277988162, 0.058285011377717764, 0.028657672061984028, 0.025411630082609396, 0.08137196861207485, 0.06169030722230673, 0.07280278378831488, 0.026228004401283603, 0.06728334924472229, 0.024113183774586235, 0.0090889316218506, 0.03945911156811884, 0.050164233028356514, 0.06696485169231892, 0.05839292558708361, 0.03283653514725821, 0.07560640227581773, 0.008095448637115104, 0.01652842264489404, 0.10266496068132774, 0.02220525865310005, 0.04165502391489489, 0.004002259927801788, 0.031085378756480556, 0.04701483648802553, 0.04435430407258017, 0.05361767093251858, 0.08470702251153332, 0.04435325573597636, 0.06871640841875758, 0.01995535018587751, 0.0577023872839553, 0.03628418514771121, 0.03972024577004569, 0.008228652694794749, 0.014150136200311993, 0.07010758162609168, 0.03505645067031894, 0.017441559449902604, 0.011198368073174996, 0.01879206974990666, 0.015385403264580029, 0.03376653863649283, 0.023340909143111536, 0.010769106464327445, 0.053562696025307686, 0.0561759650840291, 0.03496985603123903, 0.016814847543303455, 0.08385482324021203, 0.04254288020144616, 0.05354541034570762, 0.024310988606885076, 0.028462328615465333, 0.036413001628326516, 0.042346376460045576, 0.021027937631255815, 0.008109791171071785, 0.03621121888448085, 0.026777149577225958, 0.05887286697647401, 0.027214570569672754, 0.03267735083188329, 0.03912202215620449, 0.014250324440321751, 0.021367415486435806, 0.026829642742606144, 0.0518103996956987, 0.05318174271711281, 0.042680266579346995, 0.20949292369186878, 0.07086998357304505, 0.09234144392290286, 0.17163706145116261, 0.11998355601515089, 0.21039815726024763, 0.0993692007447992, 0.14804750654314244, 0.21335788629949093, 0.2769790531269142, 0.1639126052281686, 0.09249359861548458, 0.0791463398241571, 0.06223063822835684, 0.15214391744562558, 0.13674175606242248, 0.10707213383700166, 0.12940995448401996, 0.22287225004817757, 0.06560644494103533, 0.3054897646818842, 0.10103210008570127, 0.12941949468638214, 0.2050673554518393, 0.10144789277442864, 0.08814972599170037, 0.09770671531025853, 0.11045912280678749, 0.15507271885871887, 0.14224075313125337, 0.18760406252528938, 0.0810283516932811, 0.1553902868181467, 0.09501991341156618, 0.18150878245277063, 0.10899792478552886, 0.13491995739085333, 0.1418907783393349, 0.12604500433163984, 0.088326328301004, 0.14469129592180252, 0.21247906131403788, 0.10479790837104831, 0.1528159249573946, 0.2333085121853011, 0.12155357748270035, 0.09240714646875858, 0.1025867188083274, 0.09306808707437345, 0.09099953235792262, 0.2074920053460768, 0.10121719086808817, 0.0946428854284542, 0.14697011506983212, 0.08973193394818477, 0.1393714863806963, 0.17892116201775415, 0.14676154697579996, 0.11967703460582665, 0.1864234930170434, 0.14601072083626473, 0.11719036661088467, 0.13634759507008962, 0.16285770040537628, 0.13773023230688913, 0.13010762419019425, 0.18591702090842382, 0.14158570899495057, 0.17099063470959663, 0.21375248155423573, 0.08074494118669204, 0.08403168339282274, 0.10834326741418668, 0.09957623534968921, 0.14530836923846177, 0.17882099667830126, 0.19892984335975988, 0.11139582004398108, 0.09611462788390261, 0.1614869511021035, 0.1048668407435928, 0.13138727338186332, 0.12970545648464135, 0.14007932054144995, 0.09519773029855319, 0.13197981087224825, 0.09255793052060263, 0.14793257628168377, 0.13867768432412828, 0.15472543106547423, 0.12047789591763701, 0.15414818775440964, 0.09824464430234262, 0.1610192504844495, 0.25518961091126713, 0.07594915066978761, 0.08857398679746048, 0.09453415019171578, 0.13663696311414242, 0.12197080866566726, 0.1158481700611966, 0.11132593772241048, 0.14757188063647064, 0.07546656977917467, 0.14244071740124906, 0.12970154812293394, 0.10858653578907251, 0.19941255317202636, 0.13291078805923462, 0.12033800913819245, 0.238761518150568, 0.08887320038463388, 0.08940748564366784, 0.09178834288780179, 0.11603269087416784, 0.10592737062168972, 0.0670578313459243, 0.09503480046987534, 0.09770405545298542, 0.1190347604985748, 0.14227431347327574, 0.08877557276615075, 0.1618359623742955, 0.13748245845947946, 0.11581269625042166, 0.15333332147981438, 0.07560159146253552, 0.12387465579169137, 0.18361210530357702, 0.18337803786354406, 0.2912886238523892, 0.09880254258002553, 0.10822388596300568, 0.14159907613481792, 0.14183678052255086, 0.14425912339772495, 0.28910379537514275, 0.18759317882359028, 0.0922694852841752, 0.11976304570479052, 0.1413646558565753, 0.11662663971739155, 0.23690670196499142, 0.18944875496838773, 0.12141868472099304, 0.11047751789114305, 0.06401589100382157, 0.058413722685405185, 0.17797111799674376, 0.1151521016976663, 0.09843785036355257, 0.21665556649012224, 0.19607916846871376, 0.08396083076617547, 0.15016562145735535, 0.22314470899956568, 0.10103610344231129, 0.11863392272165843, 0.07371553552470037, 0.10910720285028219, 0.13617612927087716, 0.09348795097321272, 0.26364958552377565, 0.10356893895992211, 0.14130870385893754, 0.06730685369776827, 0.1234124241662877, 0.12358595271195684, 0.1025835500497903, 0.11658800393342972, 0.14925578742155007, 0.08728334533848933, 0.18569721627448285, 0.12168161704071931, 0.10385589820465871, 0.18038356783134596], [0.04799575385238443, 0.01622258316326354, 0.08273386303335428, 0.02751901905451502, 0.04598517316792693, 0.08356676476874522, 0.009804579113343996, 0.027029301671843444, 0.0018243145521929754, 0.028300798265263438, 0.04911217465996742, 0.03486696298101118, 0.025516921754128168, 0.07801642974040338, 0.024922285894198076, 0.02109486154014511, 0.029498288740536997, 0.056153227375554185, 0.12782679657850946, 0.024823257100901434, 0.03702351690403052, 0.021860303323982016, 0.015610149329794305, 0.008600828304354633, 0.010444371478765138, 0.03701962211302348, 0.009651643257322056, 0.020039055962115526, 0.09852792588727814, 0.039637929294258356, 0.0227313862248723, 0.01918407978623041, 0.04008409321042044, 0.03735704400709697, 0.012636895391291805, 0.0937098590657115, 0.06371116092694656, 0.021241224936342666, 0.03445449172120009, 0.011423841019027998, 0.033259798506540914, 0.06330288640622582, 0.026583692458059107, 0.03766939742490649, 0.02167079018961106, 0.04286283999681473, 0.02395720044816179, 0.0156484814693353, 0.027068665184612786, 0.0658907646845494, 0.05797086323478392, 0.04952815055314984, 0.05627130264682429, 0.008924806723371148, 0.031169133726507425, 0.06027309184095689, 0.054305814007031064, 0.012429774273186922, 0.03572145909337061, 0.034546955688191314, 0.033485075525407276, 0.025164984299668243, 0.04529688420838543, 0.045300751857991726, 0.0218412585423461, 0.061306717805564404, 0.015695870355037705, 0.02885486451642854, 0.07783589192799159, 0.05464444030076265, 0.07970748828457934, 0.05517099365325911, 0.06325300051165478, 0.07068821082689933, 0.016630442081285373, 0.05419944007215755, 0.0020673051518055475, 0.017503272209848677, 0.0526991991459259, 0.01933682310794081, 0.09462623417909656, 0.015421767652566944, 0.03616969593401466, 0.053075792866625955, 0.02419476064720324, 0.030427739223731414, 0.008662668289616704, 0.05113611230626702, 0.03041082334571651, 0.013155995884777179, 0.07779857250196592, 0.041435276956430504, 0.012509212912326413, 0.04650546703487635, 0.06767083345247166, 0.04909630711855633, 0.007714444438793829, 0.03137215140408703, 0.025591787915410738, 0.056287058229957304, 0.04503831147615399, 0.017891809843214493, 0.006754525188755776, 0.0666067141241261, 0.060170816257596016, 0.033034087225262604, 0.06453669377203498, 0.028697756518210684, 0.07123595822070326, 0.04183774321739163, 0.01861431393107133, 0.051815458174262724, 0.05713282498930182, 0.03842229648892369, 0.05941372723983867, 0.04224249953404069, 0.040991304708378654, 0.04687629660059299, 0.022798323704461967, 0.027362307999283075, 0.03707783702494843, 0.06316076046121971, 0.017197028999882083, 0.050631926860660315, 0.11175646140639271, 0.01155956753063947, 0.022102408011310866, 0.07842225474970681, 0.0518262129543083, 0.04450626877535667, 0.022191299491428902, 0.052725360063569884, 0.07723501524222748, 0.019009896454268267, 0.0667831264436245, 0.007585585549739855, 0.03583289829215833, 0.0706757257825562, 0.003127657762628847, 0.015967584614242827, 0.07181124735091414, 0.05031819940943803, 0.052104683725961616, 0.03161564030285392, 0.04604416160977312, 0.09846360076751028, 0.016336594009771943, 0.08710179650889975, 0.02226722756001566, 0.0277994134729462, 0.018023988464847207, 0.042580518538930585, 0.0438212808886809, 0.02051605250952499, 0.04166994150727987, 0.0323220597180937, 0.02389087195375136, 0.02546780090779066, 0.04168189050895827, 0.03389919901798878, 0.06034880277833768, 0.02865601304386343, 0.04231332162661212, 0.03512169520503708, 0.03565918993470924, 0.011129524758351701, 0.02945185319653579, 0.015074546016486627, 0.0066574641470132125, 0.02581185887434653, 0.020155606225931218, 0.034000036107110124, 0.007307733941291059, 0.05587764037773013, 0.02463733172044158, 0.03373524799410786, 0.06015803265784468, 0.019580452802724073, 0.04656013660132885, 0.021198648560260023, 0.049438566967312775, 0.004711460064364863, 0.02230455037871642, 0.019749894871243408, 0.01703384641690978, 0.024782740078600388, 0.03597587240593774, 0.05866220220923424, 0.01796366161267672, 0.01478687091730535, 0.023922978534496257, 0.019475395225786736, 0.07152557732271296, 0.018524884711951017, 0.05633441997425897, 0.04808956131871257, 0.030575985554605722, 0.00991667140208717, 0.023228326612817388, 0.02857024621750627, 0.014021853217855096, 0.009287641450230564, 0.0324648370567177, 0.027589880162850022, 0.036882222164422274, 0.05834060375179563, 0.08171250498188393, 0.029758489956813197, 0.06920751849455492, 0.05645812369350876, 0.0477343618071505, 0.0731263364266072, 0.05707080688859735, 0.06384279672056437, 0.06248053589037486, 0.015113305633089371, 0.02034078521787056, 0.04719499092815178, 0.017103123145976236, 0.012853941780381968, 0.007140553090721369, 0.045735231401132684, 0.013008508664954985, 0.07162783933537346, 0.0659491526229041, 0.04963725219879832, 0.04890550646398749, 0.006788562201628727, 0.03245512382792575, 0.010233870408098613, 0.03184835745819977, 0.04237349750474095, 0.008585635905287095, 0.029271094860242944, 0.023278487314070975, 0.023116139329171607, 0.090165768883058, 0.03939988224634102, 0.020378187764436007, 0.046426573768258095, 0.04562550889594214, 0.043108554490442784, 0.024709643197378943, 0.008324756153992243, 0.03916109559525337, 0.07771321958197014, 0.05318493861705065, 0.04144254406648023, 0.05061436976705279, 0.04934063400807125, 0.02657955339444535, 0.05130652298352548, 0.036723261765603504, 0.05028478155976959, 0.041471622684704404, 0.03281150399042027, 0.05196893601013081, 0.02381657067287181, 0.0594554300020848, 0.03213910971369062, 0.020035860062177693, 0.02801955058904631, 0.034799957647919655, 0.025564982389499034, 0.02405183233453759, 0.026801549696496556, 0.02781668388550835, 0.01900432737810271, 0.04005480085366538, 0.0513917605525681, 0.0427711325963693, 0.01234467580382313, 0.04219245079106518, 0.03173527281199183, 0.02772028441540897, 0.05839425551572016, 0.01486757756876094, 0.0223086504265666, 0.033348398216600926, 0.04038505741794195, 0.025070846047518507, 0.0064911378264826325, 0.07545514324946062, 0.004442115588712373, 0.01786227321385273, 0.10006948281079531, 0.0386338433516877, 0.044762178257639916, 0.036815888580999205, 0.031328833728496513, 0.011047618796250649, 0.02682171406091324, 0.10904962236859969, 0.04164528354470219, 0.02536337436842067, 0.054730064634765895, 0.1418047808110714, 0.006426363601349294, 0.06537069473415613, 0.022628837531166415, 0.03299138701653906, 0.11163520041321005, 0.004116637183220259, 0.04274796062548246, 0.07672263987894569, 0.029202905483543873, 0.03026382891195161, 0.031044778613639728, 0.04009078356570431, 0.06762491020240954, 0.048736439286065955, 0.025467280132163848, 0.0072385216730513745, 0.0411875234650714, 0.043535278378320594, 0.0346942079652633, 0.05982765395726476, 0.03125231194176844, 0.027430083469620774, 0.042424479233367104, 0.03029023070952722, 0.04362356935494712, 0.012978725218480187, 0.07139016887439148, 0.014887597744486161, 0.02099434505882008, 0.06685349731040852, 0.03011970468131559, 0.004933074690468077, 0.012349688481273395, 0.025507824295865636, 0.04600011111636247, 0.02651115197555295, 0.019824593095108867, 0.03409636772370764, 0.015436827737305845, 0.07013103179633617, 0.03735580907336303, 0.08486062926905495, 0.030426619640950645, 0.025931723781728318, 0.027663480856322815, 0.02464380664085703, 0.026125732210597823, 0.056401757789509635, 0.020955600709255253, 0.022334066652027623, 0.08893656877002545, 0.04864234683502998, 0.019647276627698114, 0.018506742381889905, 0.03656675087820206, 0.17316768717552933, 0.0937195485457778, 0.19346576370298862, 0.07270910524364028, 0.08073893615177699, 0.15126963864479745, 0.07015267027808086, 0.1243283785879612, 0.1022306304158909, 0.20404689306659357, 0.14372560488326208, 0.2153064895953451, 0.11479323809700352, 0.12184502184391022, 0.1422051571841751, 0.06164337295506682, 0.1151785102805921, 0.14946261846593448, 0.2459730426115649, 0.11500386893749237, 0.1325052955320903, 0.09670209671769824, 0.06930411473980971, 0.0920320183836988, 0.09503515330808503, 0.09247772089604821, 0.09388332654322896, 0.0856896090720381, 0.16835501470736094, 0.16703261780951703, 0.11353779903479985, 0.10469353611447982, 0.17236263251730374, 0.14905940581645283, 0.11839092576078006, 0.11516428818660122, 0.14113407608653816, 0.1817520779690572, 0.1288183398012604, 0.08788771647959948, 0.0810388961274709, 0.13725510851613112, 0.11841376524950777, 0.15534432285598346, 0.11372791097632476, 0.13822796488446848, 0.10869917260216815, 0.16276791665170873, 0.0856931306687849, 0.19644165544637612, 0.18359233279313358, 0.18865257554820605, 0.21186881405966623, 0.06752415453749043, 0.14958799816668034, 0.16144455623413834, 0.12047170767826693, 0.10054381950093166, 0.09518555738031864, 0.1774888831589903, 0.16682160698941775, 0.10366511451346533, 0.09005596834634032, 0.1476150761757578, 0.06315543396132332, 0.17149798891374043, 0.08975531626492739, 0.10197329601006848, 0.15588252326207502, 0.22245016055447714, 0.18128259958965437, 0.1211321936654193, 0.15251434328300612, 0.12942205954875263, 0.1464997681656054, 0.10469442499535424, 0.09467603864946536, 0.12004884465464524, 0.15959364841026918, 0.15953658361520084, 0.17562011629343033, 0.06030641469572272, 0.17501772647457464, 0.09287635343415396, 0.13736736534961633, 0.13546684304518358, 0.14882806608719484, 0.14272009740982736, 0.14696301759353705, 0.1234880265380655, 0.15846194699406624, 0.11488617025315762, 0.16174969343202455, 0.14619627302246435, 0.16489321046641894, 0.05451636003064258, 0.0853578665160707, 0.09002131556293794, 0.08733278339994804, 0.17740353702434472, 0.09517618681171111, 0.12161372282675334, 0.14031174592673779, 0.12098402875874724, 0.12769034318625927, 0.21374881746513502, 0.15842788453613008, 0.09866577706166677, 0.1933148575148412, 0.16769177386803286, 0.14085751878363745, 0.14050793754202978, 0.12137490564158984, 0.09822828482304301, 0.09052947043840374, 0.16693678152348312, 0.16293784896177904, 0.1640538897897516, 0.1099774172263486, 0.18190767961953366, 0.1990028672984668, 0.18136254458555154, 0.13271338865160942, 0.1268143273357834, 0.19940036668309144, 0.18628911594195025, 0.13633220589586667, 0.10692603846213647, 0.11649929226509162, 0.2071343223963465, 0.21270524417715414, 0.12892614544502326, 0.1021784171462059, 0.16815765601183685, 0.10373037601155893, 0.09166373671697718, 0.08598842910890069, 0.11897384162460055, 0.1147485226392746, 0.15460462469075406, 0.0976506479616676, 0.188528498634696, 0.09559993193085704, 0.10735868596072708, 0.12221163431448595, 0.16117760698710168, 0.06175379774400166, 0.18057439901999064, 0.09176244320613997, 0.11521859812949385, 0.15285580924579076, 0.12262644991278648, 0.1194478797593287, 0.07558740329529558, 0.13145562899964197, 0.12077465999339308, 0.08648520495210375, 0.09529197881264345, 0.0861725631569113, 0.12386887467333249, 0.17853921465575695, 0.13524520636669227, 0.21945453701274736, 0.12264073986027922, 0.07721415707575423, 0.110813501290977, 0.10613665117749146, 0.06357295691434826, 0.13765677410577024, 0.173609942729984, 0.08101240612034287, 0.14311371557414532, 0.1092789468488523, 0.09916734336210148, 0.12201264713491712, 0.08266323432326317], [0.07719106652906962, 0.011921773764437862, 0.15039751758532865, 0.017057729153228656, 0.03313830002610173, 0.016219972499779294, 0.009889983771634954, 0.01925712577732546, 0.04064296179318002, 0.03494301997125149, 0.043531068068529875, 0.07778556498565845, 0.10086210670747928, 0.023849942721426487, 0.042271914027099095, 0.032495181142751656, 0.0369676531159452, 0.0824332923761436, 0.01670606141643865, 0.04229143208691052, 0.05851776924516473, 0.07094092440924474, 0.022356587229296565, 0.11989314800926618, 0.06698407458939723, 0.025236878477569138, 0.06530913125191416, 0.004473771791838641, 0.0541017208514469, 0.05380977776699832, 0.0010200672446184658, 0.03601366002112627, 0.0050543386522414425, 0.046541958648179255, 0.021661446762404273, 0.0654098122779812, 0.04714303889444896, 0.07040272400315319, 0.0232569115968155, 0.04579419270157814, 0.08391323153461729, 0.03296627104282379, 0.018832617306283543, 0.0658459881586688, 0.07215143088251352, 0.0340419186811362, 0.015981545472251515, 0.04946589157251375, 0.04011974683297532, 0.02399909489655069, 0.11849867712174143, 0.0162883959710598, 0.04113330173173121, 0.06915816185729844, 0.035653680230357816, 0.03606373929817762, 0.038576666598341296, 0.08334071082728249, 0.04072677104600838, 0.04606223438999482, 0.04481666461963739, 0.015891302011108825, 0.03407912275620869, 0.0570132467629654, 0.020508271409198642, 0.010420561684960765, 0.037326659208961895, 0.05472352355718613, 0.03603265221629824, 0.0381287011717047, 0.021783257368952036, 0.056233823765069246, 0.044430601942752085, 0.0385716929366546, 0.03269965088527117, 0.033981013377862315, 0.04665252932214311, 0.03331247318003859, 0.014433871555541242, 0.03750419450391616, 0.057852662434535365, 0.028362214166138853, 0.027823279245889614, 0.034228946681001356, 0.04262827383354306, 0.044592785382909436, 0.0734461299808962, 0.09050381502934865, 0.04228067391418985, 0.03173560529415097, 0.05005337058433464, 0.03710418114704745, 0.02225025061384908, 0.02223633725329169, 0.05488903521160994, 0.027066074877179096, 0.04144673402022038, 0.04018627719155379, 0.047074550962341685, 0.043230534730745215, 0.04256002338869231, 0.027792782489476458, 0.022306172077410986, 0.11463471874594688, 0.017624538292043974, 0.06334642799837248, 0.05120070205469217, 0.04333360420007791, 0.02592450756180499, 0.05429310843880687, 0.03063933697662183, 0.03343751700595021, 0.019058123330718706, 0.023209704219230583, 0.007764302343795342, 0.023490826366469264, 0.038603906386664937, 0.06354410560535532, 0.11418383222605501, 0.06347511895000935, 0.017904379704434956, 0.04446800957833018, 0.019665963482111692, 0.08219022756176335, 0.01696376223117113, 0.03672370281336563, 0.05359493661671877, 0.06571694436882224, 0.0009700869912714032, 0.04377108286800129, 0.02957558405718633, 0.022721135257078067, 0.05013964970463088, 0.03912763703348381, 0.032644357066601515, 0.025064917347793068, 0.024071654038769857, 0.02638056282220142, 0.04269956072260227, 0.05212473104308758, 0.035290541859077554, 0.02599524992651173, 0.021648893864559274, 0.08791782307837691, 0.01710636993604047, 0.02349525041479085, 0.023683208007631556, 0.043425281066447496, 0.03125056132142033, 0.02861153507339103, 0.06746571910168443, 0.03761061932891607, 0.011140393193012901, 0.031246978656521866, 0.042300375178456306, 0.013072007668337651, 0.03161975222506693, 0.02684391911939851, 0.04289272946438619, 0.02576218162929373, 0.014832592303199428, 0.033542700111866, 0.026970219931432178, 0.010514788994831699, 0.03303453166569982, 0.045894866942295005, 0.03160627991227167, 0.029126855278653756, 0.10117859579622746, 0.08901655447802373, 0.0376977567960109, 0.03751819268135088, 0.006899445849869932, 0.034561941134078164, 0.017035787027063112, 0.04242559881614787, 0.041477515761341364, 0.03208271666829075, 0.0360095277428627, 0.0369632358529738, 0.020457941074190394, 0.025946978945285082, 0.04101389653182455, 0.030781829330538, 0.016255459881254604, 0.016427229324887906, 0.06513651872852019, 0.052178969739803245, 0.024867970862292817, 0.03053847953144993, 0.003804003445631159, 0.05781382309006793, 0.036259839311242104, 0.03991815407893487, 0.02730000830654587, 0.05877142599118607, 0.07865259024713721, 0.044684635275708776, 0.029846523090132644, 0.0240244415721723, 0.021573579870164394, 0.03291580160813672, 0.0168878714820104, 0.03165789267846516, 0.051079040725848505, 0.05464694409498146, 0.08372708902295146, 0.047113064610000165, 0.06308023871055671, 0.0872237156810505, 0.024007797108164856, 0.013213046260976365, 0.019445977340053235, 0.02265474569451596, 0.04214699912284102, 0.061302042699285915, 0.006460033781227789, 0.025048069323280027, 0.03209468602601971, 0.03283682691731623, 0.0456891860147672, 0.024639864352398684, 0.027888048806094697, 0.041884372143873146, 0.03991568421146699, 0.0601647976519806, 0.11386502933289323, 0.01900858009633209, 0.054897421904440434, 0.01314436664272632, 0.12010744293885571, 0.03590276025767837, 0.0253295477014035, 0.057415543390171866, 0.030988473777792284, 0.02230760717897543, 0.035084579339517016, 0.018756541656330228, 0.05361751826213939, 0.10802716509039913, 0.018450564771358455, 0.048466935354684076, 0.0018270685561999145, 0.03745900746434927, 0.015191087798614587, 0.029677839284496646, 0.0089218686667404, 0.04063439528856959, 0.024832999167431678, 0.025783436738752892, 0.04583550191351345, 0.005221451225224882, 0.02288574954893972, 0.019594406875382577, 0.01454631837883166, 0.02166562314544405, 0.03658540041318961, 0.013398111598300082, 0.02566383476369083, 0.02398512894952936, 0.035363749002239535, 0.04238618610958968, 0.035714799272162576, 0.006107717619410583, 0.037520187574305704, 0.060424466218267164, 0.04423330770805478, 0.028694798105529377, 0.02091800986922213, 0.04000401250751955, 0.01744950339863343, 0.03666498917820198, 0.03406831030068653, 0.018875841683308994, 0.10350552307707922, 0.018170713180942193, 0.08840049217854228, 0.04127175001693623, 0.05167264012353761, 0.03248267574235797, 0.032651970229510746, 0.07014207156108958, 0.024174126397286142, 0.06097745190241507, 0.016141613579488227, 0.06515037441360098, 0.07388717774301767, 0.028149412013590336, 0.06134412544114249, 0.02696083579212427, 0.028002853538574915, 0.02543399968583669, 0.04452529828995466, 0.034624332429042885, 0.03911454470029899, 0.047664662690034935, 0.05155680062515395, 0.041210559728954516, 0.06048267773751702, 0.14521473140588828, 0.04145343116085444, 0.029952757925327336, 0.018345685309863517, 0.01719751924143306, 0.03571930813736149, 0.06792246137878724, 0.08599485483552728, 0.013081088163224714, 0.06063156867665904, 0.014854817717735256, 0.03300500521436334, 0.019915033331406966, 0.0461869016289711, 0.018703617621213198, 0.017036986337708573, 0.04211654307852898, 0.015533232296417867, 0.01240133771872414, 0.03290307229118688, 0.05659313519884433, 0.014148911444603332, 0.027559880433338027, 0.09457750857940742, 0.02911032616559948, 0.03265701853004949, 0.02779299283533224, 0.057538412511348724, 0.02105829698432769, 0.01233848077910287, 0.04975898816649403, 0.01303984341211617, 0.036197580330606015, 0.08590864017605782, 0.06297917091952902, 0.011181993326837463, 0.014106807498527425, 0.03338647081649729, 0.05013093052964125, 0.028121960183073367, 0.06738176396382706, 0.03802773855360491, 0.026463486586830447, 0.06600445322692394, 0.022887238933305656, 0.0748411708378366, 0.05186084538166012, 0.04005164566582867, 0.04808499138536198, 0.009960220627752798, 0.02148250859629895, 0.010072800613540624, 0.10377622462276902, 0.11845314742199012, 0.07923376227595977, 0.26213816234043663, 0.16114734432526998, 0.1274568321449416, 0.11165039959762778, 0.10906699965042727, 0.09414698489542518, 0.15428413903074606, 0.13342370625053132, 0.18426119190241608, 0.17943513872367994, 0.17183359233396395, 0.07422575314662286, 0.11976193290735994, 0.14578590861388616, 0.1487111137913806, 0.17442259698041848, 0.08949144756687538, 0.10661292847778116, 0.14287306634443148, 0.11633207409509591, 0.0810868414118886, 0.20536046900919505, 0.0951766889276249, 0.17395663341241224, 0.13029428917382443, 0.0631235156740461, 0.17289738596550056, 0.17876918374427728, 0.12363947555422783, 0.15004659284438404, 0.19379930437675544, 0.21249708320413316, 0.15746485335486277, 0.15450509717421873, 0.2033888226641076, 0.19496000637965544, 0.08836822105305535, 0.11249200015195779, 0.12252314974154745, 0.10307217668741941, 0.09130827257675783, 0.15437134435134275, 0.20608937846762793, 0.11618264711328916, 0.13445425166615418, 0.1535038101886, 0.12469458393752575, 0.14565421853746685, 0.22152602300047874, 0.05671973626262375, 0.11515363518680845, 0.09097075568778173, 0.17134791053831577, 0.18195212366325514, 0.1575844655079501, 0.2198158297687769, 0.12285959454519407, 0.10976244376174041, 0.1461336985230446, 0.12274057950292315, 0.11342417834592716, 0.2463439027113574, 0.107715771799641, 0.17112305760383606, 0.12027711740561894, 0.173276103500809, 0.15796166312481674, 0.09703721159270831, 0.08778703545353242, 0.06120458471455744, 0.05373838570501123, 0.1504678680960621, 0.1394732937748943, 0.1522101288927453, 0.16625038906931877, 0.1652739228946822, 0.07910686265677214, 0.12994055529790266, 0.15555423444935254, 0.25896055570670534, 0.10497114514665944, 0.09613370150327682, 0.10425559604274375, 0.12432789004274777, 0.10749275769506182, 0.10440979991108179, 0.105066350395126, 0.1977304241486958, 0.11559660998838288, 0.09434644026415688, 0.06830945704132318, 0.08957817112760884, 0.09820175410381385, 0.09806369258356945, 0.1883476690522262, 0.07164503341274601, 0.2011838959796088, 0.07208717361624752, 0.1487668486578124, 0.17528762056359223, 0.09304660465568304, 0.12839029277009623, 0.10797820200345346, 0.17753681487270764, 0.2355738149157592, 0.11421148931341511, 0.08216609885650021, 0.18661876182471002, 0.17803834724639142, 0.17208564095199108, 0.13459796538310392, 0.0880342461168766, 0.11027480555432183, 0.10726586915552616, 0.1436962785997561, 0.13401756009885243, 0.1470526656402009, 0.1923299232231719, 0.14499400396432194, 0.18741537550730364, 0.16812313215008803, 0.27437806555203026, 0.1333109201597316, 0.14894257565694197, 0.13327433355152607, 0.15343597025743552, 0.15458018385938235, 0.21086953553770268, 0.16741742858929293, 0.12385982301618371, 0.11760724495564188, 0.09129284269043378, 0.09412951940404517, 0.10044639544295413, 0.1292880895946707, 0.07543940802237817, 0.14266406398798737, 0.12351229095033237, 0.11749500169285707, 0.10394364635327033, 0.09160411384488855, 0.12305370984332901, 0.08025168015488557, 0.1281171552836895, 0.17578969576529094, 0.10498479727123465, 0.1459095919770854, 0.15644296604607785, 0.29140495189598625, 0.12304596097341605, 0.13144223471837385, 0.09326081816107035, 0.0817021776789001, 0.13652564265898295, 0.18128611440105097, 0.11230511803712163, 0.11017793789505959, 0.11927147422518049, 0.13587156204240664, 0.09352351977889027, 0.10118911987436668, 0.1313954158020871, 0.10723555899624314, 0.15213249091591152, 0.2803760165614741, 0.1108303221740893, 0.2583005039819649, 0.17167075750018868, 0.07382568889962775, 0.11533362338585512, 0.11371859469051872, 0.10605984779873065, 0.10307755068476711, 0.15656868501433305], [0.007636545225977898, 0.029688383718686442, 0.07493915807987962, 0.017731980919571858, 0.030797021729605537, 0.02954022559736456, 0.025634096270161014, 0.05795100251478808, 0.03310032920645816, 0.06366202820624624, 0.05051238934642502, 0.03136715738634978, 0.025194943317079117, 0.021610760196511234, 0.04436972038820386, 0.031396694015711546, 0.03649665142542549, 0.03673699192170586, 0.003218583363507475, 0.02295539777592889, 0.0714967938672219, 0.07831244064228875, 0.0728793361091188, 0.04119635459833911, 0.05644256827820625, 0.0730818041733333, 0.0336544989342136, 0.017669604891645055, 0.0267078728481595, 0.04235592684043305, 0.008579699572042694, 0.04226923381377544, 0.02841867845771568, 0.10559591305043016, 0.013369617368360716, 0.021647687768563628, 0.02882462221064738, 0.0443960577249527, 0.027354323338451128, 0.04362239548936486, 0.048876217499907525, 0.017963203601539135, 0.03601641148062689, 0.0351317782354142, 0.014107986453122326, 0.04935677974883999, 0.07880269576396261, 0.01897391883124198, 0.06697939269776855, 0.03994046091767294, 0.03459273983857461, 0.02547903575136193, 0.01635629018502576, 0.04059021926618048, 0.054456095942961316, 0.06404538692108222, 0.02045333382141377, 0.042189512734434435, 0.048701175821146796, 0.031300891656428576, 0.027730360660435896, 0.03666281108079212, 0.040466556259031804, 0.012229476672863322, 0.03576417965814471, 0.01506776745165033, 0.026114992697590163, 0.05064031355349081, 0.023667164047115614, 0.02016852214001119, 0.04612226099041956, 0.038720153006059785, 0.016617946858916963, 0.07718823703804187, 0.036538825769509585, 0.02747117046133748, 0.03608070606631892, 0.05957871302962303, 0.02465806096526129, 0.04783576208033732, 0.060988484881818295, 0.07895664857434374, 0.011938023829965718, 0.014121064367438001, 0.05019936417894704, 0.06340737401374749, 0.006111334211059979, 0.08046607007937771, 0.013479223674429315, 0.028742736604596888, 0.01725418709351548, 0.03357454715296626, 0.0338806648339544, 0.02190087123640946, 0.03436507098376751, 0.01176426712689655, 0.010548764091384197, 0.05724922767175095, 0.047454330404954295, 0.03684942178162081, 0.0393443712964654, 0.023958747508004308, 0.0721184608659574, 0.010285872483759053, 0.04375309490465692, 0.09303530704762254, 0.024455911812505553, 0.010922944771924188, 0.03003676056063601, 0.06293803134134837, 0.04051225219986268, 0.037002081982791424, 0.05419352663947003, 0.01306911456465189, 0.009634681578193392, 0.01986465380260987, 0.02831710346176156, 0.02529018249229661, 0.012032792271514024, 0.09166784185384001, 0.03707271069288254, 0.06434080071215119, 0.03833929808544261, 0.03408541277583156, 0.08473942934402398, 0.048854724903191836, 0.03065405779385141, 0.07658373018992798, 0.021796422644651363, 0.0402493809482881, 0.010866911350084203, 0.03586261812597513, 0.025900402605267506, 0.07953455006437642, 0.040572299156337976, 0.00822824557378356, 0.03490637568756938, 0.0469241842095341, 0.005412924901715347, 0.012683554851849164, 0.0062357041668812075, 0.059079155192843506, 0.012443512062808233, 0.005862531534928296, 0.037438118763800175, 0.023771587193810513, 0.033363627935094495, 0.02344879790741418, 0.023028616793453693, 0.03452474384435585, 0.031245360350502387, 0.04108689332913075, 0.03379149854715381, 0.03457550165642585, 0.03516823931464127, 0.021220429534358636, 0.015042785488601242, 0.019005007609458904, 0.02337322267703712, 0.028398751580555524, 0.02316101424262992, 0.05410252830811909, 0.06373208694692169, 0.021152918692678213, 0.025779462219881158, 0.04599205351301602, 0.03865410101466945, 0.07011913707745926, 0.017460275142054473, 0.020177159890798584, 0.049670130613126924, 0.02019751424502049, 0.07075136208108493, 0.05815693110759769, 0.023555485664733818, 0.024136240394519906, 0.02400462665329022, 0.03950088557654193, 0.05250381837998118, 0.06892234379691736, 0.044983709763203344, 0.02109994037475969, 0.058847964741289616, 0.03484984014981559, 0.055709441724632464, 0.024800473591312766, 0.05244290289868202, 0.09729574700551373, 0.03784187424129673, 0.06653395481407642, 0.013672793600043016, 0.05576402986688273, 0.02238822901355369, 0.04017747998503702, 0.027539721157933985, 0.028630282995956283, 0.025129970196368437, 0.051301603604640277, 0.06460865241076265, 0.012142880337445863, 0.05113146094871419, 0.10739235486835241, 0.040020405913570097, 0.013133857831625002, 0.028621146521930183, 0.03391496817182217, 0.03163541281329734, 0.05000439053401351, 0.02576541654499514, 0.019801780747781907, 0.03597586562058755, 0.049544923938810825, 0.03493770704205547, 0.05369253709380116, 0.03341135948098131, 0.005212701092075024, 0.05340486877997007, 0.025367126667073796, 0.051462429974760325, 0.007830993006271976, 0.0875523437612823, 0.016404959805575863, 0.06355182054851737, 0.04519280372187495, 0.020108320816819156, 0.06769336760044098, 0.04878527005868299, 0.050711712400828085, 0.009500963530237121, 0.002290286813929145, 0.03410997574350663, 0.09610315385673728, 0.023896481742018034, 0.03313654601307852, 0.06618926580995321, 0.025450598348730376, 0.05220603310902204, 0.05929587927779981, 0.03547121537849307, 0.026583799327324544, 0.006086962081358901, 0.04807677771896124, 0.020034241756158214, 0.04980530157419188, 0.015055682742968202, 0.010699610907717474, 0.05596595171040722, 0.026018135216353194, 0.010252022916185004, 0.09273027162998915, 0.007314144400879741, 0.04495008156767913, 0.019582398501890044, 0.06059434424553599, 0.07658087355749947, 0.02983811604125159, 0.06479030980595521, 0.07747813433940921, 0.05568118074110576, 0.007188787600690765, 0.050840288001511774, 0.04162105984453644, 0.027921972164352025, 0.045457853070859394, 0.016802893452612416, 0.04617264900090439, 0.036338562944105694, 0.03618929541802832, 0.08938967409942832, 0.032514298866902075, 0.04245473510984864, 0.05538702902517148, 0.06909241181399141, 0.010746885290635484, 0.03201820495139275, 0.015516384271904826, 0.05733140504785946, 0.06259208704744067, 0.004675044786251549, 0.009901116834953427, 0.003233493534415694, 0.023255188117868135, 0.014480592084250279, 0.012844258237497082, 0.04256878327578306, 0.00802588861967836, 0.03206972272268363, 0.054070006124675274, 0.012491471766095077, 0.007022483756632677, 0.036492990728999884, 0.05262290806110416, 0.007385499991609582, 0.08646064876977887, 0.008942107670009136, 0.020819361055535928, 0.055196638884288926, 0.04925573570653796, 0.01705208034919841, 0.04859969751643283, 0.029390564520976374, 0.02087346574158541, 0.01687119309125202, 0.061982810098145685, 0.02849165489897132, 0.0593377041763493, 0.015926640114880035, 0.026024320063048174, 0.03772411109613521, 0.05148786146725927, 0.01861446999412562, 0.023911708067836504, 0.03885762080816286, 0.019951864212219204, 0.01192411216574588, 0.049550532030739954, 0.059957864827343395, 0.07631608205182211, 0.027825294494894997, 0.02388695171768112, 0.018593218277341554, 0.006656040071642825, 0.015706723522660986, 0.04353473215763058, 0.023789994152528898, 0.040447363896029334, 0.08040063216217927, 0.096597188418465, 0.035194013467324634, 0.020588028111628125, 0.029970725532621145, 0.06387168874165841, 0.02407893132684486, 0.03752931387030652, 0.012303139282656568, 0.050029394549450705, 0.02036947028578392, 0.019922252944005386, 0.07586850678282124, 0.024144840825881277, 0.033780838762010844, 0.10154341693435397, 0.017528266047260592, 0.021965854535145417, 0.010894005253378834, 0.05814765553389277, 0.04457851579146726, 0.009479948452540805, 0.006143534938538713, 0.03874441741832665, 0.04753592084827168, 0.022144989476406148, 0.09373714295881135, 0.09749812007482563, 0.23531152041895048, 0.11461535335651465, 0.2656460255384445, 0.10086297523230314, 0.23160620353051595, 0.16513130840446266, 0.16292834947151796, 0.11976884039384977, 0.10365792204226766, 0.13555924594402313, 0.08178345260343381, 0.0955670704799039, 0.16469419614544936, 0.1478165060813938, 0.18067745491862297, 0.1240312752446958, 0.1599527020007372, 0.0868514103016683, 0.15654999815991946, 0.20006201975047588, 0.13237098631049904, 0.08966019922601325, 0.16386909756277288, 0.16298449145896093, 0.12245389845754419, 0.11881053181631224, 0.13330968522599765, 0.10582219090844903, 0.15292553550430707, 0.11841358883040291, 0.08584409113973379, 0.13780350051820278, 0.07836265223366873, 0.15094422682055406, 0.10172833129763603, 0.11759656481444836, 0.11804944622729506, 0.19778603687882423, 0.11193123167114598, 0.1570357342383691, 0.14656782522797585, 0.07518052655671324, 0.24135050922632217, 0.13075930279280457, 0.16616334659712656, 0.10591817647218704, 0.08424962205546242, 0.13231952621468476, 0.14768177616809094, 0.18444495275616646, 0.04351264923544867, 0.12271129393151828, 0.1614422220736742, 0.14802275358566216, 0.07812862550573689, 0.14200345586453164, 0.1608281478817974, 0.10164963480617319, 0.10729776708675282, 0.10458928599421467, 0.11245702845709664, 0.11248031577893666, 0.09777863323688507, 0.06754403561353683, 0.10107214722250189, 0.1428652767624174, 0.0897209688222834, 0.08869144799453871, 0.08940855772899729, 0.11525726105485644, 0.08166671065347535, 0.20077988265880517, 0.11599432650421347, 0.11863852318908487, 0.07715249181325946, 0.1198871090476002, 0.10910678215857063, 0.12198196378137384, 0.21065669267305306, 0.2314795074718339, 0.134371103984969, 0.11153528613171407, 0.17008572683802672, 0.13894468785396644, 0.09443642757833004, 0.24839511407273157, 0.12420265961970602, 0.1058466588812215, 0.1387485098093748, 0.1198981555977038, 0.1779959388077259, 0.11658552049526147, 0.13934841619006225, 0.11015411453055483, 0.15631298587790557, 0.09181737740124975, 0.15161930131060736, 0.09795499127358198, 0.16420341176646097, 0.13865555051181996, 0.16236155559974058, 0.09546073047178132, 0.12620427007121698, 0.16885594997022832, 0.1323322012488331, 0.14892535443816865, 0.08949990211320774, 0.11282104892390114, 0.12187510808663708, 0.09280180279165506, 0.1298420862959964, 0.08785868196615151, 0.08584590961358377, 0.12026883927839142, 0.08761649246194533, 0.15384347124823503, 0.08538724708237819, 0.13078226441783564, 0.19671121026788438, 0.1410915862236704, 0.12933078301804407, 0.11578905609037195, 0.13508081090237412, 0.12876428770167486, 0.19230499384658678, 0.17805258291108267, 0.05575825214119894, 0.08620556710021836, 0.06168162197406803, 0.11418655993682997, 0.08421851122485739, 0.19681463257542678, 0.1563140715339354, 0.06350528661693845, 0.15162493315126213, 0.1399713113371815, 0.1240443709705557, 0.12349709176591464, 0.11769773438572884, 0.2038112785667181, 0.09684928453394345, 0.11288567938442741, 0.12269884959927627, 0.10701519117823668, 0.10804963138486658, 0.2158945216132062, 0.09838620706328324, 0.14549594345901692, 0.11785371601581573, 0.3043808756130082, 0.09154191253972904, 0.07397385380629982, 0.127969193937523, 0.08889033339385476, 0.11002038884907961, 0.09893436157809836, 0.09266892527895314, 0.20275389030575752, 0.1594531238079071, 0.08578742668032646, 0.11941493009882313, 0.08498178848198482, 0.08781224302947521, 0.1648407732801778, 0.0959501713514328, 0.1194226789687361, 0.18100023402699403, 0.1383665624473776, 0.14541510279689515, 0.1218743481274162, 0.19623871919299873, 0.14471357901181492, 0.08857013271855456, 0.09710406086274556], [0.05589834926649928, 0.07754022029361554, 0.022900792670303156, 0.004665582615416497, 0.016644660782601153, 0.012355037033557892, 0.04232362857354539, 0.017593829493437494, 0.038213833567819426, 0.11518955683069569, 0.01911790226586163, 0.019398415427921072, 0.014125750499910541, 0.09083764747317348, 0.09577941122863974, 0.009058950552051621, 0.025620179516928535, 0.06363298690744809, 0.026407933228516152, 0.03949267869549138, 0.036948073987982104, 0.04154486036194222, 0.01283902333982821, 0.016061700814004456, 0.04040341179019638, 0.0471682702191174, 0.062133200599678924, 0.0541781815700233, 0.061885514961821694, 0.0207149294271533, 0.061994094135505814, 0.023808187372716408, 0.0786500796675682, 0.04401518584096006, 0.004172788076435349, 0.05963809162910495, 0.06394917065543787, 0.053888416582984586, 0.02691178788830127, 0.07788058024431978, 0.021800794106509005, 0.014664446236565709, 0.028303425892123153, 0.024699641591204063, 0.04028063427124705, 0.029887530353984663, 0.021649993091289486, 0.043315687482910495, 0.03545544283198459, 0.02910663154242294, 0.07695239862161023, 0.039344255945512226, 0.055068022571504116, 0.024988349759951234, 0.03267178005938019, 0.03152651133547936, 0.04666290072990315, 0.037926535055573495, 0.004632879772023963, 0.021695539754416262, 0.012627463754532593, 0.096135017861213, 0.004423694211124841, 0.020086853665166667, 0.11312001823846783, 0.06843523029237986, 0.025718344874413948, 0.02995717179562364, 0.07245506173265831, 0.024656692020861164, 0.015444030386528798, 0.024053642326699834, 0.04184560404558267, 0.05319047885547791, 0.0136198118894494, 0.020587188424542546, 0.03160442751167076, 0.004067244498790907, 0.05379140303869333, 0.017004920469064797, 0.04924726758950523, 0.05469808867201209, 0.04920928319916129, 0.04768507302339588, 0.014156376177977239, 0.04473488079383969, 0.013871325312980583, 0.014607311891657966, 0.0304523971863091, 0.03608498762228659, 0.019439334482220665, 0.09457349843744721, 0.02432959064442132, 0.04160948742979339, 0.039209705843989334, 0.01572029252669641, 0.044928992699299536, 0.043631304654159715, 0.013466723363048263, 0.03261873897697244, 0.03896663424425891, 0.0450758548187358, 0.025660738947668245, 0.029380233825317452, 0.020483092670994144, 0.04160907691610711, 0.029966406657227447, 0.043503546688173494, 0.013767880953050085, 0.01418642170860299, 0.08020092573549066, 0.045852641708084514, 0.037923094883028946, 0.010206323582679033, 0.01195260215484138, 0.050223598057138066, 0.038630487996020486, 0.020550284601215805, 0.009858281767394925, 0.03767388254137976, 0.0339024525934032, 0.059292527314807685, 0.06343013207827296, 0.028422829395692264, 0.03958702898983445, 0.03803263757643955, 0.023253842922193662, 0.08090823063892977, 0.020651459261508923, 0.031411248591861556, 0.009975820996000298, 0.03464754850470594, 0.018617833831480572, 0.06642718054354191, 0.047207693103700876, 0.009825415227429142, 0.019626796744497757, 0.018900750703843575, 0.04533061757683754, 0.0401208596304059, 0.09706283986036267, 0.05840976682624646, 0.05793917564941304, 0.08213175819920641, 0.01618341642564961, 0.03643937628450138, 0.03734906782795276, 0.023386613565630147, 0.04208964255771466, 0.031253991315939596, 0.03790066251531243, 0.0511294965898352, 0.06732978818139859, 0.026323759263115268, 0.01830349230606641, 0.04233659877042685, 0.023103041906974146, 0.017192089264946323, 0.015348850583125438, 0.032151767784463506, 0.02571980542104159, 0.03083829701478992, 0.04260512561138187, 0.06145830252873046, 0.047291275047297986, 0.01566313443306301, 0.012012191100179084, 0.06148827342050416, 0.034360460338315794, 0.014177243674306996, 0.06486095887209688, 0.007762284550283636, 0.036906554430191, 0.007984868633294744, 0.02983732894062996, 0.08669787818299872, 0.06127167147185121, 0.08937350460993392, 0.005066313523067427, 0.01401024348368602, 0.055006509979388545, 0.02974311774596572, 0.09738826525530644, 0.038145359206412516, 0.06546275158013616, 0.04645189330247896, 0.04467042675241828, 0.01120935270695814, 0.03529994296176093, 0.056014643383345435, 0.029557901434600353, 0.02368529959182654, 0.054578289921794615, 0.024192850571125746, 0.021605333612699593, 0.030179520935884545, 0.020866083280582513, 0.026364586715187346, 0.06813199977789607, 0.022448362483243858, 0.031034196860023906, 0.00812449841760099, 0.0496791788776006, 0.03065815953803914, 0.02552646874184055, 0.06073773226567677, 0.023220367397048643, 0.010620771075731941, 0.059214014027799876, 0.016331727217350687, 0.03809710858123643, 0.01707050427129226, 0.05635630951396056, 0.02445319088708077, 0.03179449874109455, 0.026825194945558906, 0.042194225160138946, 0.04262544094984021, 0.0749282743781805, 0.01534431118385068, 0.09962368530354329, 0.0347872317236449, 0.006173022798196013, 0.04794062966746943, 0.01647370558099023, 0.06210516353270837, 0.053439304432166476, 0.011925140994467905, 0.043434237728693655, 0.018393695055107986, 0.022032666485756636, 0.0629609115421772, 0.019466771045699716, 0.015540777605825236, 0.028043669116284167, 0.017540403342406665, 0.026667030129049505, 0.05809620900877884, 0.006142303397479866, 0.018242076405190995, 0.027431990153023174, 0.03680523218853133, 0.0865036543192608, 0.03501428650426013, 0.03366415788020406, 0.07650200743228197, 0.029442469057227885, 0.040436554833182266, 0.04191169335639902, 0.03471857415778296, 0.010131764458492398, 0.018743435752445033, 0.04540012331147279, 0.05236609273457101, 0.004015828083668436, 0.05747781254883323, 0.04329687849219356, 0.0052562227522555205, 0.009675825397217912, 0.022145688367475356, 0.018612339394167066, 0.017226540184180652, 0.033669718474681885, 0.011771747127308376, 0.015194899469081844, 0.04721630371308752, 0.04296422330662608, 0.024814425967633724, 0.03996664558404258, 0.04995836889637368, 0.02350149124062487, 0.01000293271083917, 0.0419731041682618, 0.01676541965987001, 0.031248223768281083, 0.05082017622355904, 0.05458254094368645, 0.04679184613217201, 0.0025360852762657616, 0.07135503433112587, 0.01920514151320926, 0.01598599157296121, 0.048138056216495376, 0.07554460809166942, 0.0223654556819903, 0.026688230955707173, 0.04127349385193416, 0.027791941106053333, 0.035056308177965026, 0.06295551718877894, 0.021669256700468913, 0.025353040280086652, 0.027769144025764296, 0.034109314171863456, 0.03328207820387823, 0.0493776616640389, 0.04810573759355715, 0.04669250860544188, 0.024489048070141246, 0.03615221347925918, 0.04818614738594208, 0.036133882855730395, 0.06031727125602109, 0.040248634559767585, 0.028978093261165277, 0.028511427409414734, 0.020444891149444238, 0.0685584047543151, 0.024280334091080085, 0.039735353352235894, 0.03720282656805856, 0.033573224009679895, 0.02518788485654763, 0.05041799833998084, 0.027910627058840225, 0.027587155844750147, 0.03198763694880264, 0.07327616374407496, 0.03155187497447644, 0.08427801874599286, 0.07028009915458304, 0.014039290719665587, 0.06651667931250163, 0.02845454412246389, 0.01780479620876057, 0.02537392558796065, 0.07362423185259104, 0.026495365858344094, 0.018126984991665398, 0.029209341388195753, 0.006686413843583847, 0.02051890405294086, 0.034415309716548236, 0.07463843814496483, 0.06741700028734547, 0.01401461918638753, 0.02790613006800413, 0.01856947294436395, 0.04064980821151819, 0.01800824814875211, 0.09594251747642245, 0.04100276855751872, 0.07449977951390402, 0.017252999657232846, 0.03856733334915979, 0.04651620824422155, 0.019252825561644774, 0.018594768729859164, 0.04956256924197078, 0.04225844849965402, 0.031954887456127574, 0.11545801242547375, 0.23559115827083588, 0.21509830148092338, 0.15545174852013588, 0.07426053485167877, 0.11969663069716521, 0.0747482522523829, 0.17963335237332753, 0.11208495377962079, 0.1479863298258611, 0.14505136731479848, 0.08112163668764488, 0.0778884037530848, 0.15882879016654833, 0.15761620737612247, 0.15828346514276095, 0.14051864482462406, 0.07988156644361359, 0.0946957908038582, 0.08464158459433488, 0.08025704058153288, 0.13422520538525923, 0.15008233806916646, 0.10972769598343543, 0.10018906103713171, 0.12805980550391333, 0.11101319414696523, 0.11905732857329504, 0.113159285059997, 0.14906754823667662, 0.13610363458948477, 0.1394613515585661, 0.1040461254971368, 0.09983773596052613, 0.11089349378432546, 0.17462287337652274, 0.09743671944098813, 0.129344570849623, 0.1933957388890641, 0.15729456820658275, 0.1401678557906832, 0.12900215493781225, 0.14734390644090517, 0.1628166354660477, 0.167517308944038, 0.21101403635527405, 0.17373378894158772, 0.08488625753670931, 0.1389657495809453, 0.062343512528709004, 0.1646995022892952, 0.1421660871378013, 0.17094087095132895, 0.12385079850043569, 0.14197552736316407, 0.07638628328485148, 0.1289576973233904, 0.1236310074371951, 0.13310157853577817, 0.0939361776358315, 0.10575351637921163, 0.11002903338521719, 0.17853344710809843, 0.08066712000540324, 0.0940824087177004, 0.18056753224560193, 0.13020537394498075, 0.2095694760126727, 0.12631348706781864, 0.14042658119329385, 0.16674970941884176, 0.09509800600686244, 0.07562573373849903, 0.1332660282828978, 0.14847330083804472, 0.055492459796369076, 0.12228469896529402, 0.10637278136398111, 0.13940538599022798, 0.1591027011828763, 0.11526130512356758, 0.15942458462502274, 0.10352217432643686, 0.08201601369572536, 0.12738364535783017, 0.050031335159604035, 0.12987333961895534, 0.07604124822786876, 0.07907969411462545, 0.16608739138713904, 0.13603094991828713, 0.13214107150478022, 0.1404303674186979, 0.12097079732588359, 0.11696054680006844, 0.15244533627160958, 0.10305779853037425, 0.14323530904948711, 0.07601724165890898, 0.11747099512389728, 0.11450324580073357, 0.20594628900289536, 0.13696626972939285, 0.10699384446655001, 0.10957600948001657, 0.13884734522019113, 0.10566479792552334, 0.1848640159836837, 0.16650573536753654, 0.05634010609771524, 0.07804536247359854, 0.18548731825181416, 0.1311135252139398, 0.16289568479572022, 0.12107678449579648, 0.09793975137706314, 0.09455240956906762, 0.1568617850009884, 0.1051096273586154, 0.09569011602018561, 0.11327315680682659, 0.11229913335825716, 0.0905500232641186, 0.1689509448728391, 0.13354985948119844, 0.10927771191511836, 0.14431818308574812, 0.10100050749523298, 0.17989545688033104, 0.12414529626922947, 0.09804788950298514, 0.09599551106137888, 0.1333875810461385, 0.10357086599937507, 0.09613450217459883, 0.12999402385737213, 0.11848396648253713, 0.09907329162316662, 0.112731461945389, 0.11845493875443935, 0.13414299408239977, 0.17253310765538896, 0.13630735794348375, 0.23740694512213978, 0.1951794988874878, 0.1449430731258222, 0.08969458738075835, 0.1359728401792901, 0.08855002772595201, 0.11755551344582013, 0.12045705132186413, 0.13739300040262087, 0.15624944785875933, 0.17784796389085905, 0.09450935652213437, 0.08624729021851506, 0.13372983410954475, 0.1663304969136204, 0.15531340880053385, 0.08401388541928359, 0.09184914641082287, 0.09883268989090409, 0.10142824240028858, 0.12030900855149541, 0.10130999410258872, 0.29195062975798336, 0.2009869986878974, 0.09526309357689959, 0.08236788838569607, 0.12381153846425669, 0.09333712620926754, 0.13810669710593565, 0.08975716188017811, 0.11258789750614337, 0.14732633238392218, 0.16647647693753242, 0.21297975230429853], [0.04342733024220381, 0.02280594195638384, 0.020471952822325484, 0.07609587029686996, 0.03115530518282737, 0.011124725819432309, 0.0265161714383534, 0.026884325879759023, 0.019606140442192554, 0.05157122967232551, 0.051967704469071965, 0.03686657853956733, 0.0139686738839373, 0.02098627218843571, 0.06975660938769579, 0.016324865531974604, 0.012100845941209366, 0.026486889259623628, 0.037949876660215, 0.028641156519630125, 0.0025860163358239724, 0.05171156767755747, 0.04966939440263169, 0.008679812325031629, 0.023095888451540043, 0.00661642974176045, 0.00801078018931938, 0.04262028408369847, 0.01995106184455965, 0.022702131187543273, 0.04245096245514495, 0.02783069563364344, 0.06588132626244, 0.028936492279171944, 0.036217396945825646, 0.021516771222065603, 0.018957321864685843, 0.033654247876256704, 0.07781481663031237, 0.02359087805130652, 0.03642408549785614, 0.0590793587533491, 0.025881351038281406, 0.01974754374740379, 0.042756309998886924, 0.03426156725202288, 0.006617463235410729, 0.039463572935866456, 0.04529674171603151, 0.03265714066635285, 0.058276258275977204, 0.03140835464000702, 0.027819803450256586, 0.025169942694317018, 0.052293357173247, 0.026294563597600375, 0.03805345842348678, 0.048666970870856724, 0.050493716062711816, 0.016225358371489813, 0.02976586563246591, 0.01646975481084415, 0.041337025085730214, 0.06701046960162264, 0.033644504113388915, 0.03494345762633851, 0.011738985760270484, 0.004394932808021882, 0.07848886653248753, 0.028186812863818238, 0.00395023579975324, 0.03117664510916386, 0.02323128841817379, 0.03764430859259196, 0.05044787423685193, 0.021551318832540085, 0.03874867183289357, 0.01163926740576114, 0.030140135370727097, 0.0384836360546095, 0.01192915198459689, 0.12565859220921993, 0.0381688127693321, 0.0552302840431886, 0.02733084941948099, 0.027243808643626313, 0.006090974343741047, 0.0736296669180904, 0.06023154514176505, 0.1561605054885149, 0.04800290221880589, 0.014683808233322842, 0.0035505199380817688, 0.010147291884225394, 0.006564325885847211, 0.05825958667056901, 0.024074256220566373, 0.04799181156392608, 0.06139970424451998, 0.011695771561270314, 0.009577436971345117, 0.05454369142119374, 0.05891561468264886, 0.07822837693882839, 0.02459983926798616, 0.027146443957462907, 0.01205102026662124, 0.02272914027396057, 0.055194335257900615, 0.024427969740437608, 0.014682510535099676, 0.030022636854222844, 0.0512422521465591, 0.06163859606853553, 0.026732289930805564, 0.006578986059009496, 0.061809471542281766, 0.055536099776093445, 0.024517746708754982, 0.033272392116487026, 0.051652742084115744, 0.007231053547002375, 0.022526716314522282, 0.040909785511238236, 0.04734671475099666, 0.030316812318882773, 0.004397892492956349, 0.02575801033526659, 0.06055479243929897, 0.057874009146222045, 0.023695950895281773, 0.0489110229536891, 0.009443511970208159, 0.02252701317359294, 0.0018349923609223748, 0.012871545523272028, 0.03465408279693552, 0.0575739677463259, 0.01230596368467169, 0.022381764271163514, 0.02182224768746112, 0.0238365569218461, 0.05174384219571948, 0.019117669867617742, 0.03187894581684044, 0.009860379288771322, 0.028177963070837513, 0.039194204711488316, 0.036731814699513574, 0.018392414320260286, 0.02712326859390097, 0.008522630536130496, 0.026703562454453537, 0.08062751391636473, 0.02785130783117243, 0.01613845839165151, 0.051733694704515595, 0.01578340646145599, 0.05588816784854446, 0.028540919934000288, 0.03311849358890738, 0.07328997193170445, 0.0589005376345345, 0.04611080053395458, 0.0239074943653707, 0.04158571156273995, 0.029253734541790824, 0.03989806944238288, 0.08734436599271637, 0.03502980460013662, 0.011890544190204569, 0.020282414242891327, 0.01033744029700756, 0.0376931359725339, 0.04216724321512239, 0.008429249698695327, 0.04912577589441623, 0.030274946708232164, 0.04276081207873566, 0.03558579619441714, 0.04239391801612718, 0.023136620908709507, 0.05375318455376795, 0.044642053810613494, 0.0349378936391856, 0.030941919490162815, 0.0723150053194591, 0.015532546976049031, 0.016595578952027217, 0.01779844851366111, 0.0525721332856587, 0.03275714994275144, 0.023831045521157126, 0.06599414627999067, 0.04782759251871279, 0.01637027139908501, 0.024426755162754228, 0.009434917476028204, 0.030419128614344766, 0.02144166248451386, 0.043110332252191644, 0.034458203307752094, 0.013762836893355208, 0.055579074791499546, 0.056860613703195534, 0.026513844063239436, 0.053471904647137435, 0.04443467654553907, 0.044269154713089974, 0.074173071687775, 0.0025327341614424115, 0.01610838571962501, 0.019081556537587727, 0.009331072780436702, 0.05435069231316447, 0.03887151041999459, 0.03363440751231142, 0.03267888092835035, 0.045187399190451415, 0.017953797409843122, 0.021718918678483794, 0.030560145154595375, 0.0104552093793505, 0.06644605060241052, 0.04277662194467016, 0.07378481395010437, 0.02000341930293611, 0.019511876661064367, 0.032681883445807865, 0.03507225035822817, 0.02744325383433274, 0.018884786471192325, 0.021855911506073813, 0.03860297679368939, 0.03688852914742061, 0.10101186617144517, 0.04462247807532549, 0.0396703904095505, 0.04147929013041513, 0.12823465040751866, 0.03789814854306834, 0.07610205853624002, 0.02549058441737933, 0.04409997896956546, 0.034402549865522554, 0.030662386811205318, 0.050375182780304124, 0.015626961731218865, 0.07187523320317268, 0.02087119434561048, 0.010329948422232909, 0.04689761956355401, 0.06769039561705929, 0.030935653219265596, 0.003800447073964668, 0.015700409754312465, 0.057660949150366445, 0.06747971049376897, 0.024919936466696005, 0.06623703467526607, 0.021957121789455414, 0.024649794712396603, 0.07249379251152277, 0.0234978865233383, 0.033180253846304755, 0.028207050170749426, 0.026514347875490785, 0.02112951093087239, 0.013681194711742657, 0.031116370843457322, 0.03236094316733735, 0.018622249398114424, 0.06736033582793814, 0.04696932714432478, 0.050502000975289514, 0.01868128533741193, 0.026837836052956324, 0.045385141258261034, 0.08139978176248924, 0.016957575688138604, 0.030186679480331283, 0.02934901782178453, 0.06462317984551191, 0.01297904412993895, 0.039465893525630236, 0.050943686560328515, 0.03944931352244956, 0.04057883005589247, 0.028074881727141992, 0.044362673802035194, 0.059172874449619224, 0.03548345275755439, 0.0258107443805784, 0.04240832670724817, 0.06583517231047153, 0.010714478458144834, 0.09149281374577965, 0.042155368852296045, 0.03727240015619567, 0.04686918216092246, 0.028828713776809827, 0.014876023633405566, 0.024811920477077365, 0.03492891662088888, 0.020398430160379837, 0.023600133268960884, 0.013926632702350616, 0.040259430051914284, 0.0222565643821976, 0.017211011910278882, 0.05272971625838961, 0.03154026184763227, 0.04464771618534412, 0.06078666142587151, 0.030295116161661487, 0.0687084627736892, 0.023619846407590166, 0.03805201314389706, 0.044033703061618974, 0.03648462778489504, 0.05099222556288753, 0.027250414182032858, 0.06897862827671425, 0.04015928506851196, 0.018785659290317978, 0.02266189406093742, 0.029323549009859562, 0.03396373109093734, 0.02330051764978894, 0.07835844531655312, 0.07149650209716388, 0.014341207420719522, 0.07121887270893369, 0.038375257048755884, 0.03181720591549363, 0.02140502498618194, 0.02799303174417998, 0.02669639203564397, 0.015909535943397453, 0.040294690124158344, 0.02569889466810439, 0.016042898608637706, 0.02003970735573343, 0.031047424900212457, 0.0220374789953764, 0.0072458719036408836, 0.02144615608267486, 0.05151630565524101, 0.019632299663498998, 0.04240078139784081, 0.024591026794431464, 0.03763938242835658, 0.13498175836035184, 0.05133120808750391, 0.10694463032164744, 0.22041245203997406, 0.08470001324479069, 0.10506128852388688, 0.12713836851928914, 0.11501205206981727, 0.0761548417753407, 0.150648955521839, 0.27461346292069977, 0.10457226833594696, 0.12598380047295774, 0.06731304193713836, 0.1577970776706934, 0.10170545788215739, 0.07265014055051974, 0.16469845734536648, 0.09168016404977866, 0.12118402017014367, 0.10079993254372052, 0.08213650115898677, 0.20705109329095908, 0.1725699792483023, 0.17515001366181032, 0.05927742991064276, 0.08273955594216074, 0.13849795396838868, 0.10014591299529586, 0.16999664876077855, 0.12046475947967597, 0.10436950850167445, 0.14358812011778355, 0.17773852976305143, 0.08212109162871327, 0.06371553069246666, 0.10591890929000718, 0.06573656081621136, 0.09013442735054664, 0.11876087662364755, 0.13996122830680438, 0.23022557475737163, 0.08221398985811643, 0.15580227971076965, 0.140366259430136, 0.13229204554642948, 0.07687608378806285, 0.1338861957192421, 0.126885410664337, 0.1556678619235754, 0.1542208045721054, 0.22209729520337923, 0.13974797832114355, 0.08778509484337908, 0.1408467029354402, 0.1131423691819821, 0.08996738559965577, 0.10453755448439292, 0.09563394689134189, 0.16346422928784574, 0.12938616504626615, 0.13182040942566736, 0.1146801398800952, 0.1900910697877407, 0.09472504244851214, 0.22375577049595968, 0.10824726149439812, 0.08851363110755171, 0.18360375932284764, 0.11464109697512218, 0.09450215726558651, 0.12431541856910501, 0.13317199690001352, 0.11502839119306632, 0.11744124814867973, 0.1422299915658576, 0.14653098077646323, 0.09701945433127028, 0.0786244310438633, 0.10580204520374537, 0.1967944936560733, 0.18849400191434793, 0.12138441870255129, 0.17276416239993914, 0.10506928166640656, 0.12339774066848413, 0.117876976196255, 0.16047532324280056, 0.14070490268724306, 0.19773920439183712, 0.11700162531009742, 0.06718407278614384, 0.12989437420453342, 0.10964293338890586, 0.07575318297105176, 0.16652002531502927, 0.19767975115350314, 0.15859542840293475, 0.1435986781226737, 0.048988783066826205, 0.13145809886710985, 0.11269329435059003, 0.15301510212676867, 0.10995614515351397, 0.13149418335940155, 0.08230617562574999, 0.1319466576512371, 0.10263070823358637, 0.1726166217454842, 0.16523257297064575, 0.08541699405759573, 0.12318793764071805, 0.1732912076903241, 0.15603104100695678, 0.1632226843919073, 0.07471463762755905, 0.08946657925844193, 0.2486932895013264, 0.1513432596943208, 0.103904447385243, 0.2269197657172169, 0.12038147609148707, 0.17873423919081688, 0.16373591470931256, 0.10720285360834428, 0.11376341192850045, 0.10304145262177501, 0.1917085208530937, 0.1645583262933152, 0.12371344944196087, 0.12335370374577385, 0.15365234150418214, 0.10735367158693926, 0.09855936241469213, 0.1103860242292285, 0.10298706804003034, 0.18275176361203194, 0.22417632650051797, 0.2101814874580928, 0.08587404846080712, 0.17626386960702284, 0.10568375619394438, 0.11155185595686946, 0.1038726173075182, 0.10387997262712036, 0.11853453091212682, 0.1682476568967104, 0.1007184608440314, 0.16299139894545078, 0.10528745781630278, 0.15109598796282495, 0.17873495843793663, 0.08231710003955023, 0.17262502200901508, 0.12245194427669048, 0.05253820992740137, 0.12665882068020956, 0.11799951962062291, 0.1710094708417143, 0.0543889311541404, 0.10794939819191184, 0.1711228269019297, 0.08200232085904904, 0.2027074106569801, 0.11457248351403646, 0.12841051311365195, 0.10424020008317061, 0.11610836109944753, 0.17198319573487553, 0.10454732538866145, 0.06899891647377185, 0.0996736865490675, 0.1685995858694826, 0.1427843275346926, 0.11517076141067914, 0.15239565393754415], [0.027375074635658945, 0.017457925714552402, 0.049133524764329195, 0.010658213486229735, 0.049807184508868625, 0.016148261526333432, 0.02244712076415973, 0.020099471023838435, 0.059711970521935394, 0.06957875178860766, 0.02684680967857795, 0.017189768675182546, 0.033961315506270955, 0.04519899196124502, 0.01475165834251259, 0.03262443867112909, 0.048954303309853585, 0.002566104089575154, 0.06534462541873966, 0.018881632979693155, 0.01595562543453915, 0.011881389056465455, 0.06196334292846067, 0.05814554528998477, 0.015833502701882805, 0.02733565684008811, 0.04082770313003233, 0.006635257392190397, 0.037723917713654895, 0.04147627743493233, 0.021277986267315488, 0.02148405565614147, 0.022541715331109505, 0.04959869444636362, 0.02597160467744938, 0.05180044897965022, 0.025371102882283073, 0.10600908659398556, 0.034467974212020636, 0.04981381379600082, 0.027329714569662298, 0.04032837938783424, 0.011641296225466898, 0.07800559353615556, 0.04832399177498051, 0.008155539698366607, 0.04903050957779799, 0.04065644767667566, 0.04134459075118814, 0.030282437734838043, 0.030951530938701968, 0.024198263584237014, 0.014950309647247195, 0.045215890875884464, 0.005696654319763184, 0.06431813764252833, 0.05121554161555, 0.030094096769711802, 0.028996057475783994, 0.029620981442609003, 0.021015939435788562, 0.06750111148825713, 0.04809631274214812, 0.027602470380121043, 0.05088770402861493, 0.03839571487956813, 0.015100438912798251, 0.038663240881370645, 0.03876689049814429, 0.016765361984393427, 0.05279934752200331, 0.046176957698272805, 0.07188558086220707, 0.038078906879361184, 0.02970029540093882, 0.03394347682063069, 0.025018497070829784, 0.022200958437419364, 0.04373379058337637, 0.00657750854900639, 0.02813378195943577, 0.03778553208602326, 0.032358127247009955, 0.030204528343996832, 0.033120390094284496, 0.04530401900410652, 0.017015834704839757, 0.011004546241435622, 0.0327849834492164, 0.04714020261807101, 0.07791200320103339, 0.07461738320333616, 0.019112362027434365, 0.04857281056631889, 0.052191278365041525, 0.051443067978003194, 0.01726270610067461, 0.025787292513996363, 0.021577277886016027, 0.04718571196177176, 0.027760860809524144, 0.06054791209420987, 0.04407336004078388, 0.019643526025382534, 0.02955144178122282, 0.012623397633433342, 0.016132025879674723, 0.044922261631914547, 0.04932846448251179, 0.00941594478873802, 0.017859586215178882, 0.020142615672999194, 0.014889158375029053, 0.03619597220261182, 0.035372990649193525, 0.07671503350138664, 0.06338796112686396, 0.031183074228465557, 0.027541347945641195, 0.08740347317819085, 0.005965874962774771, 0.016848492702203136, 0.0874417493385928, 0.02844632027803787, 0.06864624789782933, 0.05246951164943831, 0.04453040426596999, 0.018094549321436455, 0.005189833613777799, 0.0038807058923079497, 0.06222353396671159, 0.038307423902941604, 0.0465218061581254, 0.026414443772020083, 0.0457198625829603, 0.06949471522654806, 0.06014780034976346, 0.01897570168200348, 0.041781686046825986, 0.014395571646413632, 0.03768048468711121, 0.060607894589858394, 0.015209326819915856, 0.018720657331869006, 0.024210507748648524, 0.045652636725987704, 0.07881327412490334, 0.028620206750929356, 0.030578628448503356, 0.02948438555800489, 0.027316639199852943, 0.0026946444912547512, 0.07948540377297572, 0.017261640800695335, 0.06883230219994273, 0.014951982236068164, 0.02229496437524046, 0.028304129872205, 0.03398973594552704, 0.05745596372123275, 0.03611549794940012, 0.02123047354897218, 0.010415839929399746, 0.029132660145738294, 0.02483225447524871, 0.023101484669106345, 0.029789638106844256, 0.02469242537128074, 0.03528286423534155, 0.05398981346349631, 0.029992391155766587, 0.023282171759222235, 0.05072482169738837, 0.022111167898401618, 0.03594271918492658, 0.06810676506055252, 0.10078117105045489, 0.016515908762812614, 0.04653774155303836, 0.009342491676631783, 0.06390927279634134, 0.02116583799943328, 0.040210436430892775, 0.03034874078418527, 0.046415306694273434, 0.032398934343031476, 0.028582354674914053, 0.020259825812120522, 0.0068749558247093645, 0.029897097697747604, 0.02387544376376484, 0.025992159199501787, 0.04635072373119848, 0.031041657352553945, 0.017556465962635617, 0.021673268538766673, 0.013120974996127188, 0.008296015955108618, 0.04210786800831556, 0.040614426002970765, 0.054014763196132014, 0.029865600102181946, 0.031161737694804157, 0.04986366576382092, 0.041071734856814146, 0.04686206093590174, 0.043331772155527554, 0.01766560662404767, 0.03147753467783332, 0.01533996855973133, 0.038271753317011256, 0.03601000950272594, 0.019346780609339476, 0.03038486259590302, 0.018346989793436866, 0.05408946650901011, 0.03423823582540665, 0.03287079777302487, 0.031315276598823924, 0.022538527912859405, 0.02456030951413725, 0.03192906580599291, 0.013077225602631058, 0.026697135031489388, 0.028207474255136082, 0.04689901056034224, 0.030147019108491283, 0.015562833386606403, 0.04136232765657561, 0.05623849547867264, 0.012157646955789199, 0.020983659828613912, 0.031040072973285402, 0.01393776067665645, 0.015586945128494074, 0.025938071476827775, 0.06647194349872214, 0.03155347292444535, 0.0519544832142336, 0.03417312360501715, 0.07287898327090911, 0.016462241731850163, 0.02124633769770818, 0.026878515923661844, 0.022500755564708794, 0.05863685214093753, 0.034010963913585456, 0.016815436172432134, 0.10116107602204595, 0.015059957513585687, 0.03443367765950305, 0.05461068657625999, 0.010978909492093538, 0.03620913238929851, 0.018582256544115286, 0.03693108347111514, 0.023683625306668024, 0.03256461902388504, 0.011821133450471928, 0.011224019241386225, 0.0430532267450222, 0.028200514182182293, 0.042252385789262395, 0.03737499125834022, 0.01998385035299829, 0.02210115611420146, 0.0058038899941103795, 0.045321179154728136, 0.04539994349969285, 0.010515192723167794, 0.019773611366482716, 0.03552224460457053, 0.05744708848318883, 0.07095431190516267, 0.0022044934822978185, 0.05355874016614897, 0.011234282931712056, 0.043936105977211676, 0.008963900518470576, 0.029459995616759573, 0.02231975974115942, 0.04690640998472061, 0.04744996403210929, 0.05081725513030376, 0.05470985107656036, 0.010277898849121161, 0.03397299648661699, 0.016913752503959194, 0.016121432251696075, 0.0060458738173890325, 0.021839589346200228, 0.03613097533317549, 0.02848460152745247, 0.029806160434548343, 0.06529549948338952, 0.015679302226219858, 0.03408872402672257, 0.02111816073634795, 0.11804319013442312, 0.028267975830073868, 0.09176757293088095, 0.013467632599973252, 0.02372214404333915, 0.02309564926794597, 0.027734565881213973, 0.01958358763451023, 0.03130746326808419, 0.0406217338251216, 0.04522896285301872, 0.025685905811509917, 0.03402281792036124, 0.052019955058182986, 0.027222375418724756, 0.03836775245144963, 0.026880814461037517, 0.03536706703848072, 0.008656324835361114, 0.03312038330893431, 0.02727359633094498, 0.032495442378733835, 0.10728247969278268, 0.02705831922191594, 0.07920915181083338, 0.06844478406544242, 0.022476272324898412, 0.04100188646199448, 0.06150068382599524, 0.018107723078823516, 0.03883518844044634, 0.03739483840763569, 0.10404058186603443, 0.06641529939536538, 0.020744930853002837, 0.023063213597717028, 0.022189726986523186, 0.09330210023160491, 0.04112702528280871, 0.029526447943810905, 0.0393543593319399, 0.04538266460544296, 0.054951911659113, 0.09997850483549492, 0.05223547474348119, 0.020982180622273257, 0.011315263541681426, 0.04306230554357171, 0.026132984053609625, 0.006279346691111901, 0.045023838324206214, 0.047243719920516014, 0.009842918038235178, 0.023284103887687837, 0.11182473559996911, 0.13259277226669447, 0.14070872962474823, 0.0926483588825379, 0.1825641079672745, 0.07709645839141947, 0.11843855891908918, 0.10491696412542037, 0.14209873575185025, 0.12829768631075109, 0.09905049284654004, 0.13493089537535394, 0.0867681201281292, 0.10761488721306835, 0.11846454681030341, 0.15889562586588518, 0.20348531034375938, 0.1202343696994441, 0.14214415688599857, 0.05167228728532791, 0.09838894155940839, 0.22398882013346466, 0.14246941943253788, 0.12016087078622409, 0.15918305329978466, 0.11070121731609106, 0.13686870996441158, 0.16387520437794073, 0.13281438180378505, 0.116500907178436, 0.05768872158867972, 0.13372858560511044, 0.10901821298258645, 0.1440397665968963, 0.08088281950248138, 0.1692654187125819, 0.08028255349823407, 0.17896979940789087, 0.12142783137304441, 0.1901837576712881, 0.08232555458588259, 0.11673147337777273, 0.06930017245135137, 0.10790295925523553, 0.1407609632504838, 0.07877056713082961, 0.11784265589501176, 0.08932172560266086, 0.1486763727984258, 0.14911197870969772, 0.11845333741179534, 0.17212769655244692, 0.16373818101627485, 0.21629959344863892, 0.062414317657904964, 0.08076849992253951, 0.1504027015928711, 0.06612145980553967, 0.08967841110591378, 0.1348563108061041, 0.15425998318408216, 0.11003161181828805, 0.1545041065130915, 0.12991715941045964, 0.13377813223217214, 0.13166468563888753, 0.1226457203073161, 0.24683594916548046, 0.17962510138750076, 0.11739927397242614, 0.13673293510718004, 0.122866759874991, 0.2172017464680331, 0.21612932187105927, 0.13748643467468874, 0.1172282967184271, 0.11596706296716418, 0.11704635433852673, 0.09195975440421275, 0.095918741609369, 0.1095701197960547, 0.11903841101697513, 0.10460831890148775, 0.10435030596064669, 0.17307299082832678, 0.17096822948328086, 0.11054680988724742, 0.2201805016291993, 0.08506650357906308, 0.10149317820157323, 0.12098226456769876, 0.21757202302770956, 0.1184753490878003, 0.1493482853152922, 0.18109750880726747, 0.1263398685093437, 0.10391547357929604, 0.11796500932957445, 0.09949960839003325, 0.21828343985336168, 0.2551443933376244, 0.15898038846041473, 0.09248740359076432, 0.10965402743646077, 0.10373205877840519, 0.10029352150325264, 0.13352263665625028, 0.13509359450212546, 0.14419783811484063, 0.10357818739222628, 0.11777309248489992, 0.1054566301671522, 0.16230161381619318, 0.1442195919475385, 0.13969312555023602, 0.17482454755476542, 0.14514907635748386, 0.18712682170527323, 0.11773448384233884, 0.1853970323822328, 0.10372052368308816, 0.07848331611603498, 0.24767274569187844, 0.09651839014674936, 0.22827334808451788, 0.23562581783958844, 0.1469408973519291, 0.055833427035915, 0.18019209881978376, 0.08837856192673955, 0.09623417896883828, 0.10924864347491946, 0.11681536744747843, 0.07861028358872447, 0.1109267080734883, 0.22295553343636648, 0.09253862619932209, 0.10838581155985594, 0.12761084602347442, 0.08131594197558505, 0.11518309717731816, 0.16177462280860969, 0.0797489807009697, 0.19873310891645296, 0.21080187202564307, 0.08008676900395326, 0.20462653839162417, 0.10516017143215452, 0.11259283045572893, 0.091796865287636, 0.12266070236052785, 0.1216754966548511, 0.1446334304554122, 0.10370282748980181, 0.11108968539961747, 0.10859019987817321, 0.08053251901375395, 0.23457205295562744, 0.10995825539742198, 0.16221503274781363, 0.09466146371726479, 0.09662482514977455, 0.08812258459095444, 0.1358122852231775, 0.10828400416565792, 0.16674288335655416, 0.1554907371423074, 0.1143853028437921, 0.11892614061278955, 0.09225543282393898, 0.15077688651425497, 0.07866812191371407, 0.1410040823476655, 0.07400686453495707, 0.24254595222217695, 0.10694426391273737], [0.0513841270336083, 0.01482220902107656, 0.023614626776959215, 0.04379490962518113, 0.0630530294563089, 0.012119850858912935, 0.05156732809596828, 0.06687532578195844, 0.02250393619760871, 0.009807509536455785, 0.03485153988003731, 0.019299459577138935, 0.016800377784030776, 0.006347026318378214, 0.024875295647819127, 0.0076344180186944345, 0.025635477088923966, 0.031053331547549794, 0.012771799179193164, 0.04660687070073826, 0.06580378328050886, 0.03184868994035891, 0.02163661746973438, 0.0752756775223783, 0.030410928518644402, 0.01722335276593055, 0.02579617962640311, 0.0727852029459817, 0.09251074519540582, 0.04325491110129016, 0.019407821619617086, 0.033832566879157505, 0.03587702681709613, 0.06909857291196074, 0.0359166532621852, 0.008404070112322058, 0.029273669900638715, 0.05636416355680142, 0.024568760667794516, 0.055980200945798836, 0.058527784422039986, 0.0434773891632046, 0.02568337826856545, 0.0527055739824261, 0.029636784523193325, 0.043891899420746734, 0.0020947875163983554, 0.03405224598412003, 0.034347496926784515, 0.09297484279211078, 0.02401589711994997, 0.005892526599512036, 0.018181535814489638, 0.021011009878878082, 0.03688013906191502, 0.02780533199464636, 0.0037586900289170444, 0.029973093619836227, 0.03466429474896618, 0.05372653169823544, 0.03919444898409503, 0.03761338096644197, 0.03717930515163711, 0.028683398717216084, 0.052475428474800925, 0.008442574430124035, 0.005575415803053017, 0.03624386659690312, 0.06526140988405262, 0.0697493219215955, 0.06307313444891147, 0.021516359012041773, 0.05395861442333885, 0.08451419642993382, 0.0670195280441216, 0.03129714275045054, 0.058738971661244116, 0.02385378662230713, 0.04184590938634106, 0.027329434673967104, 0.02851046049701316, 0.054484136402606964, 0.06486404620643173, 0.037550643618617735, 0.014422329674874033, 0.02416723587417177, 0.04851477885884898, 0.016815364926255176, 0.046333536439176114, 0.011875665613583155, 0.012842188705690205, 0.10015767879251923, 0.026434409664943814, 0.021902569270293628, 0.09069328914795603, 0.053361479858202596, 0.05648914631456137, 0.056472508635904105, 0.0656221733827676, 0.009301077291768576, 0.07909386871116501, 0.019807309111846343, 0.06910630142582314, 0.019989772267373543, 0.11065836782966341, 0.02130410647285836, 0.05419104998665197, 0.02849051496013999, 0.02786467157836471, 0.04620894383905189, 0.037262995660837205, 0.019287678512877653, 0.07948261499404907, 0.056713951751589775, 0.03345728612371853, 0.04282561217301658, 0.01103622280061245, 0.030829204645540034, 0.05243798691247191, 0.014077630492725542, 0.04925612586417368, 0.028475431126675436, 0.01884257989669485, 0.04310120934886592, 0.022372631189812506, 0.023957012154694115, 0.006756357657390514, 0.06481156152273927, 0.05010009450571878, 0.027747712497200285, 0.02403951353127403, 0.03385166085458227, 0.025130273840789284, 0.007087539149714368, 0.031548411053206236, 0.029926773426788192, 0.02512065221422485, 0.028252583263175826, 0.07107775778110538, 0.030322664683418613, 0.008583092247135937, 0.03952776913398078, 0.03660635357456548, 0.051025327893772295, 0.010423757584898599, 0.04487172434372561, 0.06139137861984117, 0.08033784053155354, 0.03284568179930959, 0.03235215274617076, 0.011196853243745863, 0.05810187477618456, 0.018612546347347752, 0.01604996555085693, 0.018039235146716237, 0.02890736616349646, 0.02471017754370613, 0.012475226789579859, 0.026756795223004053, 0.12978913342314108, 0.006243162538989314, 0.03705799326832805, 0.06542085882808481, 0.037994802463799715, 0.01966788203987692, 0.055664492172322104, 0.06505802579756294, 0.02986720823017614, 0.0691620973604066, 0.005768820335755923, 0.01777347842497485, 0.03692529556740608, 0.07369975958551679, 0.06442589578883988, 0.05249642234827791, 0.034991708251514604, 0.04097118614507573, 0.03936216587732945, 0.03409019984038813, 0.03082061778487904, 0.02387668887552406, 0.01967818389779755, 0.051316901176635704, 0.03585454695192831, 0.062820746563375, 0.06672768334725074, 0.031121585385075638, 0.06322533663894449, 0.04893403886152165, 0.004798965212622923, 0.06915516273251601, 0.024970365189281956, 0.034769016451069286, 0.04084995568596891, 0.010425823724030383, 0.006653970539835947, 0.05358004955840962, 0.02052807784639299, 0.05676322357196893, 0.04654460832742708, 0.02090538402886263, 0.028618544340133667, 0.05401047485481415, 0.024178418131279092, 0.020669304732499377, 0.03406528403450336, 0.04668875630678875, 0.038691084565860887, 0.038757024598973136, 0.025935033336281776, 0.01891885232180357, 0.018455850559153726, 0.01336558347767485, 0.06466357303517205, 0.07807452590870005, 0.03988151318792786, 0.04486626892217568, 0.040426956955343485, 0.0060843272450646115, 0.03758318615811212, 0.015895905871210352, 0.0355324972687023, 0.03772244529266443, 0.049422428011894226, 0.015204097011259623, 0.040430325881711075, 0.05740118558917727, 0.03330597959991012, 0.038949731936944385, 0.0659170714872224, 0.08206446109605686, 0.005522658009015555, 0.019347128358536532, 0.045496899368507523, 0.048665946282978566, 0.017613013374752233, 0.06582447859857764, 0.046918263991496394, 0.03291080419772437, 0.036224650485174995, 0.059961515345743725, 0.06775235264961209, 0.03628571524417826, 0.03795095892356975, 0.13174851185509137, 0.008123175274314625, 0.005351858870458922, 0.055457980039396455, 0.0328007458176996, 0.04407677646460278, 0.04039660608395934, 0.025889289897999594, 0.027152876469439695, 0.007450132996642164, 0.0457024920864829, 0.01728412914755089, 0.10374703404626676, 0.053115694118397574, 0.03843433030747941, 0.012079357585337545, 0.025727277787934457, 0.030548769515007734, 0.03780811373144388, 0.06033162905701569, 0.002437830649016957, 0.023893796439681734, 0.015912641937445317, 0.04761511267029813, 0.010629865141319377, 0.025546531326004436, 0.04551926727539726, 0.05781926494091749, 0.04184758197516203, 0.04123329743742943, 0.025445960561877916, 0.008941509711023952, 0.05138482253200241, 0.030007396957703998, 0.02175989031924733, 0.027835160394066145, 0.026665269330676113, 0.03659952751227787, 0.0060894387341769675, 0.022479997482150793, 0.04198794372911964, 0.041836033309144635, 0.021594762037109052, 0.02919081398951156, 0.046252614352852106, 0.027836056060290763, 0.033627740905753205, 0.044976490150604925, 0.07619976757892541, 0.016581241507083178, 0.019939290958323648, 0.008726163900324276, 0.02520402041929109, 0.055766462414924584, 0.029169409602348293, 0.0380408478501652, 0.008240488890026296, 0.03103337243997625, 0.00869007855986378, 0.04586204281076789, 0.03474297427705356, 0.020341792842373252, 0.0562959470387016, 0.04224056910191264, 0.0033302356646994925, 0.05534056294709444, 0.05093304034588592, 0.027285258651578, 0.0313785432039627, 0.02839798483598445, 0.04253540274554065, 0.005578054032022399, 0.02609438050006117, 0.06858675394739423, 0.12620061955281667, 0.015537313684555036, 0.028562745012875115, 0.0398088488727808, 0.047812169417738914, 0.0054737432676899645, 0.02029236326260226, 0.016960196529648135, 0.022876826813444495, 0.043127997911402156, 0.08175136468240193, 0.006619609526491591, 0.04270354711583682, 0.027277847352836813, 0.0036729316842476173, 0.03406360126765711, 0.023283795154254352, 0.07039931775735957, 0.05767606691058193, 0.06862718784915549, 0.04286237859300204, 0.01769920937450869, 0.006892863636104656, 0.06563326743032251, 0.061271488267396174, 0.020281898556277156, 0.03936507339988436, 0.061198179343981404, 0.03506805022646274, 0.038613517835204086, 0.04573871228577835, 0.04862766333722642, 0.04152874854792442, 0.05203886243647762, 0.11829093684043203, 0.08864555867122752, 0.12023584890578475, 0.22368551498012884, 0.13777369926018374, 0.06431346932160002, 0.11110702196934394, 0.13331060803362302, 0.14890537836721965, 0.13914979541940348, 0.08029492319162403, 0.11254400307578699, 0.18707746506801673, 0.1429255578134741, 0.10631279886833259, 0.1384554369641202, 0.17091576515563897, 0.07351200894585677, 0.11721069552004337, 0.17467638264809335, 0.1132613502975021, 0.07518633481647287, 0.1416867971420288, 0.179409815796784, 0.10335772457931723, 0.09808741416782141, 0.17586043982633523, 0.18739242745297296, 0.14625928178429604, 0.13342397766453878, 0.2303857361631734, 0.11501813174358436, 0.12207603587635926, 0.17767139550830635, 0.06330562768770115, 0.06941105185874871, 0.1477018879460437, 0.23005507247788565, 0.11360439046153001, 0.21736203001013824, 0.1458908644105707, 0.20381230993994645, 0.04612596579162138, 0.12187162041664124, 0.09348520969173738, 0.2097257019153663, 0.18513784557580948, 0.10452245708022799, 0.10716156475245953, 0.12397571679736887, 0.10375462006777525, 0.09106102798666273, 0.13239453147564614, 0.14004350746316568, 0.13788816811782972, 0.10638851659106356, 0.07369601407221385, 0.17613648144262178, 0.1586425051625286, 0.10757131847952094, 0.12890899207975182, 0.11948137224784919, 0.09880346538765089, 0.11840943619608879, 0.16970994057399885, 0.13390337622591428, 0.054729226644017866, 0.1255719025752374, 0.16907970367797784, 0.1065398638269731, 0.12882705219089985, 0.08515360711940698, 0.14649216857339653, 0.1293406624879156, 0.26153828310114996, 0.08398855570703745, 0.1819824677492891, 0.11261954437941313, 0.12904748107705796, 0.15806060710123607, 0.16912504338792392, 0.20682246770177568, 0.19769590028694697, 0.16321498980479582, 0.12884234637022018, 0.17499351634510926, 0.15611218022448675, 0.12937116942235402, 0.10201147717556783, 0.07646090856620244, 0.10175492308501687, 0.156269993899124, 0.12793164380959102, 0.13066278797175201, 0.21911969355174474, 0.10150116455874272, 0.10528881488634007, 0.22992093967539923, 0.13973066210746765, 0.12051459109144551, 0.1316742936947516, 0.12564628358398164, 0.09899441871259894, 0.10887294542044401, 0.15159585114036286, 0.09221268511776413, 0.14592294554625238, 0.06398201853569065, 0.09772109346730368, 0.15854512181665215, 0.11388425901532173, 0.05310497326510293, 0.13916667737066746, 0.20671022443899087, 0.15923200281602995, 0.18064203539064952, 0.16717984633786337, 0.0858073348977736, 0.1053446243916239, 0.11985014245978423, 0.20888496988586017, 0.10244888798998934, 0.12113127085779395, 0.08675759604998998, 0.07847348414361477, 0.10257293776209865, 0.10058181746197598, 0.07995485501097781, 0.2240635132683175, 0.054312701137470346, 0.1339456353868757, 0.16057337155299528, 0.09457964596471616, 0.15021628088184766, 0.08765283479754414, 0.11943067211125578, 0.13955729641020298, 0.09084654306726796, 0.17802564507084234, 0.11351873898612601, 0.08885649485247475, 0.15161774068006448, 0.22416237582053455, 0.11523151743624892, 0.12824375634746893, 0.09192371062402215, 0.11603521502443723, 0.11440523820263998, 0.12891083769500256, 0.13843132182955742, 0.05872025766542979, 0.10555452241429261, 0.15353411356253283, 0.08083709981292486, 0.18717433272727899, 0.09856395609676838, 0.09912137261458806, 0.09284196527940886, 0.10288783229355301, 0.14622729564351694, 0.11281794801886592, 0.13866495500717843, 0.12005637639335223, 0.08739864200885807, 0.14675522302942617, 0.1586776261350938, 0.13697201013565063, 0.11133061282868896, 0.22592586119260105, 0.24678752890654973, 0.13767985786710465, 0.1715625718768154, 0.13500815337257727, 0.11186924749719244, 0.11305740302694695, 0.10191727615892887], [0.017983479924233894, 0.03237878524565271, 0.04540758041132774, 0.03544654045253992, 0.017474113863759806, 0.04455722336258207, 0.021543739596381783, 0.0290144288114139, 0.047030100133270025, 0.01966433160539184, 0.02211592442888234, 0.04898614017292857, 0.03830867240737591, 0.010504455754666455, 0.0800994508234518, 0.02850594145378896, 0.031561449103589566, 0.061425834628088136, 0.05824691163642066, 0.00751610695650535, 0.08114368229040078, 0.028657278511673212, 0.045784679640616686, 0.08142649568617344, 0.04595974167542798, 0.04063967089833958, 0.015313463285565376, 0.05209690771464791, 0.04536556213029793, 0.012659470251362239, 0.028508485960108892, 0.049650697370192835, 0.09501130280217954, 0.06437732625220503, 0.048221624589392116, 0.06489100440272264, 0.07533793989568949, 0.06375012240771737, 0.013323707688998963, 0.030210007514272417, 0.0609802474666919, 0.022926822969956056, 0.01823662267997861, 0.02646698273851403, 0.03332774361063327, 0.008099578370872353, 0.03597395554451006, 0.06250657806439058, 0.04209351699267115, 0.02311700106864529, 0.010452321364677377, 0.0748077394174678, 0.03298770596406289, 0.027895604293527346, 0.04400083143264055, 0.06237622470195804, 0.08221692791474716, 0.02648688417061099, 0.05826745767678533, 0.02089688877042915, 0.05598842479022486, 0.014027066911304635, 0.12494508549571037, 0.03523101398189153, 0.055896669892328124, 0.019357874656894376, 0.0351090846317155, 0.020042921915384274, 0.011182430133755718, 0.08067603595554829, 0.06121927499771118, 0.05615486603762422, 0.03636113780417612, 0.035415477119386196, 0.023043412249535322, 0.1077595983764955, 0.01395998609119228, 0.06673818028398923, 0.027418059829090322, 0.0694874616871987, 0.06736853253096342, 0.049165422695555856, 0.029900218958833387, 0.02914895855688623, 0.040636033950639625, 0.08547843540353434, 0.01410755982422935, 0.01115651348871844, 0.01110058608797512, 0.040401216729411056, 0.006701180461927184, 0.024046091928279827, 0.03000333931829248, 0.05131825485399791, 0.05272127867543271, 0.0012155360080734162, 0.014761539508721657, 0.05094533879309893, 0.03331215426857982, 0.043022282155496736, 0.036320398561656475, 0.05797732967351164, 0.02710180144224848, 0.019377594580873847, 0.01766409688363118, 0.015426498737984469, 0.06418768928519317, 0.012862716086341866, 0.07030160192932401, 0.03358586172440222, 0.07474720052310399, 0.014302917689617192, 0.044966871916715584, 0.04020005823778255, 0.0468647445419005, 0.047336380662662644, 0.029019243017371212, 0.021656016785917536, 0.023809503730652586, 0.021836619059156095, 0.03413806709327868, 0.05596553101869566, 0.012569328570472342, 0.0036361126777982073, 0.005603354058361479, 0.04589460909898792, 0.03351252226691161, 0.04521577552493129, 0.01848760260535138, 0.04782051879114338, 0.0601268946858389, 0.043370991479605436, 0.04551361168601683, 0.024748362101880566, 0.04101678030565381, 0.06748831431780543, 0.07880861937467541, 0.00723409847289856, 0.027547342802530954, 0.12432075185435158, 0.018613101049725498, 0.0526666667844568, 0.08223562155451093, 0.10464888851025275, 0.08351871770407472, 0.03441800010789718, 0.014521784248894878, 0.022457882329555492, 0.04733924747311643, 0.04922551714948245, 0.008742014478359903, 0.05365163839555212, 0.05678253807127476, 0.0134852049606187, 0.04569125554657408, 0.05156467163137027, 0.03373535655971084, 0.02748861050765429, 0.05571456805669835, 0.010503649994331812, 0.06524564751556941, 0.06218457927129098, 0.025659354736230204, 0.024529307249135206, 0.037323235999792814, 0.038358439558318684, 0.027287255240870372, 0.04157497713874493, 0.016214718942397406, 0.04297419437872512, 0.02182396098838321, 0.032117891923657486, 0.024489053159153888, 0.03274823059993131, 0.03192975791171193, 0.02902919373341969, 0.012235547016773905, 0.048716290188687186, 0.05675277074000665, 0.02805927542171308, 0.027469477516465952, 0.05874878327761378, 0.011700182887060302, 0.02874065689476473, 0.049349817979548655, 0.014028371394877987, 0.042362708797944446, 0.12399006102766309, 0.031069280513163124, 0.010602488797823233, 0.047837254857378345, 0.01052176094214831, 0.05174637991668923, 0.08259360984499965, 0.021489317695211087, 0.014740070660731621, 0.04473081636907799, 0.04349689704499074, 0.037546528303729634, 0.03978919849864074, 0.013151224935427308, 0.07857281488499471, 0.009748483775183558, 0.0647030637732574, 0.009338426403701305, 0.033379844922040186, 0.020371565262653997, 0.07641742125685726, 0.07328496434326683, 0.0817011734470725, 0.0118462112565924, 0.03190534761441605, 0.07783707257892404, 0.05448933058817472, 0.06665145672325577, 0.011513337243481405, 0.02412788932477789, 0.03775231779686042, 0.015557520457410386, 0.015076971779178296, 0.019233466957562735, 0.024303685873746872, 0.0040462624996767515, 0.040976003743708134, 0.01546727869260524, 0.0266965022975845, 0.05669135653546878, 0.026024128376905407, 0.010478193904938442, 0.027075944169025336, 0.007575048749069018, 0.08634424608732973, 0.045980172364839485, 0.020406547135540416, 0.06247320092682328, 0.038026283095989905, 0.008549068804963358, 0.023150110184880238, 0.09455514406519276, 0.014259701794279473, 0.04364259886954512, 0.014829516843227404, 0.002807559715750228, 0.059663394199950356, 0.06724754295178823, 0.039964073936321905, 0.03724784736654588, 0.06625720073602029, 0.03623000751914723, 0.03258278340633426, 0.03510002958189164, 0.03628299771142857, 0.04899927321821451, 0.03174895207796778, 0.016805441351607442, 0.05910953999097858, 0.10549093689769506, 0.06909697835466691, 0.009269619560135263, 0.026119606735716974, 0.018270210163401704, 0.08693416443254266, 0.03511160538930978, 0.041505956556648016, 0.018531245977750847, 0.0379744260571897, 0.037161215408039946, 0.02411065962431686, 0.03325393935665488, 0.03290714689397386, 0.046703164997909746, 0.03173741698265076, 0.06892405370516436, 0.02890382081802402, 0.055134301872125695, 0.030629569465028386, 0.005510287891541208, 0.05741957388818264, 0.04805915277185185, 0.030627286194690635, 0.025451509281992912, 0.04124391311779618, 0.035687070938625505, 0.043242955314261575, 0.051301210054329464, 0.03289783060816782, 0.0763758881283658, 0.000816177437497702, 0.04126650494124208, 0.0701660577739988, 0.05290493435625519, 0.0581584306699889, 0.09807493590882846, 0.0136421526549384, 0.027260110447449342, 0.044315797210271866, 0.0478403896891645, 0.034010492331747494, 0.04692895770339029, 0.06674683839082718, 0.053047637056027136, 0.02148096662546907, 0.016988449031487107, 0.03890438544164811, 0.003911738691385835, 0.020390467551935996, 0.06560361545000758, 0.010196426301263273, 0.031122864423585788, 0.015910056719024266, 0.02319854571084891, 0.0408702438830265, 0.06423441999192749, 0.02212717623582908, 0.027303670699309026, 0.11057237030139991, 0.03073442687413522, 0.04186382610350847, 0.08446182031184435, 0.02873277571052313, 0.06115232394742114, 0.04713968014610665, 0.04491086224360125, 0.026824857374387126, 0.007489018990392131, 0.013636866018974354, 0.009093928184094173, 0.019273561591814672, 0.04223699322236436, 0.01992404766912971, 0.020362006400578787, 0.019377469051895396, 0.02766366914979049, 0.03982616508645671, 0.023045634451721395, 0.01986128487624228, 0.042460828354316096, 0.05305106705054641, 0.06017935222813061, 0.006942586258186826, 0.007551082044041583, 0.02915281942114234, 0.1131963941401669, 0.021461365445117866, 0.0046407821604848975, 0.029855503501104455, 0.033004140082214556, 0.05949170448418174, 0.020182932527469735, 0.0313914964374687, 0.05376681971496769, 0.011942324045646404, 0.09169306978583336, 0.10026766931904213, 0.27938057854771614, 0.1300269328057766, 0.1034269147951688, 0.1647225317678281, 0.10461187442498547, 0.29731857457331246, 0.0865263445302844, 0.06217762428734984, 0.07573405506887607, 0.18639473670295306, 0.07511346694082022, 0.05477463420746582, 0.1530382808830057, 0.10545365818377052, 0.1522466612181493, 0.11762188774134431, 0.14991821401885577, 0.09997875589345183, 0.24279044196009636, 0.06709301338664123, 0.13983042032590934, 0.12494950954403196, 0.08101066907069512, 0.17193466691034182, 0.12528362018721445, 0.1396685354411602, 0.1444257851690054, 0.08925720370773758, 0.07242106034287385, 0.17236332462302276, 0.16990778781473637, 0.16239017620682716, 0.09273738267698459, 0.11230196284928493, 0.17195407301187515, 0.14986796171537467, 0.0926023270668728, 0.08399126306176186, 0.11153559825782265, 0.08034662756004504, 0.1473576942724841, 0.08216019560183797, 0.12054566799529962, 0.15244419633277825, 0.10938509008181946, 0.23531116758074078, 0.09880311933479138, 0.0965821792238525, 0.0808477188859667, 0.11485514763210501, 0.09407728577830962, 0.11582595482468605, 0.09225647098251752, 0.18748302544866288, 0.1845316831022501, 0.11221050989947148, 0.1352228961352791, 0.15260389633476734, 0.14041682385972568, 0.11596984496074063, 0.254161603216614, 0.18436000017183168, 0.12271136178502015, 0.12156302269015994, 0.12771335909409182, 0.12632412649691105, 0.08328549843281507, 0.1429093408265284, 0.11862298473715782, 0.10168613320482628, 0.09937213880142995, 0.0739727138674685, 0.10273651219904423, 0.16020876754607472, 0.13336341162877424, 0.09693093265273742, 0.07900660232241664, 0.23963932533349308, 0.15796996839344501, 0.1723314741892474, 0.09603783807584218, 0.105894197044628, 0.16354778409004211, 0.2013549410871097, 0.09005691829536643, 0.09424174231077943, 0.09451473051948206, 0.08633892637278352, 0.1231227982789278, 0.1311227668608938, 0.1256428366260869, 0.09540081582963467, 0.12388372101954051, 0.15601384692958423, 0.20856193293418201, 0.08031274830656392, 0.14155248792043754, 0.1498294480677162, 0.09630841069987842, 0.09497164921568972, 0.12002641228692872, 0.12091021771941866, 0.0744269455650023, 0.08405596816114017, 0.1851515384124858, 0.12237224355340004, 0.1585200974451644, 0.16797952699874127, 0.18259407207369804, 0.10774159005710057, 0.14864784718624183, 0.15288171571280273, 0.10948026140353509, 0.1395911824490343, 0.17851869575679302, 0.12380859362227575, 0.07605469000658818, 0.11528892149882657, 0.10157079582235642, 0.09145045958991561, 0.12023521108286721, 0.21626041483666214, 0.14435779596013681, 0.09734538862747805, 0.11142699872808796, 0.21529549732804298, 0.09515383586819683, 0.09657374503357069, 0.10767557538513627, 0.10451272010271039, 0.1556809712201357, 0.1465063906673874, 0.12431862125439302, 0.18160622008144855, 0.2268616288368191, 0.07716106171054499, 0.16189884899982385, 0.20535554284495966, 0.1491421599473272, 0.09988580338124718, 0.20014204617057527, 0.18431767315736838, 0.1541213991918734, 0.11134375605200018, 0.08183132324899946, 0.10825802305979387, 0.14200114884546824, 0.12212426614548479, 0.08315834097032036, 0.12041768272008214, 0.14289741218090057, 0.10330010338553361, 0.10041214978056294, 0.08721129849020924, 0.11888314863400799, 0.18056827863412245, 0.11173064314893313, 0.13136948219367436, 0.14089255833200046, 0.15825400315225124, 0.17944172051336083, 0.06182248584393944, 0.06529044439750058, 0.10575758758932352, 0.14920609151678427, 0.09961373119481973, 0.16150012825216564, 0.13537688287241118, 0.11503353448850767, 0.12114417659384863, 0.12691116785364492, 0.12316222116351128, 0.09931328267391239, 0.08876538795552083], [0.0990269205399922, 0.03277857807864036, 0.031463516144348044, 0.021194436554131762, 0.028966985642910004, 0.04024919095848288, 0.02630345749535731, 0.009231400227041116, 0.01894754926407976, 0.008852618230905916, 0.03773248761094042, 0.020947495608457496, 0.044476043432950974, 0.025762858467974832, 0.05777007115206548, 0.04620029251756413, 0.02739290483961148, 0.060935057034449916, 0.04326448862307838, 0.05225102676610861, 0.03489371083144631, 0.0077399132507187975, 0.036328371348125596, 0.03993196226656437, 0.048987439567489285, 0.03894691940929208, 0.012963916191698184, 0.025034369701253514, 0.044084236957132816, 0.04657618056184479, 0.055458634825689454, 0.01621776895730623, 0.021468408638611436, 0.007866515162666994, 0.024970421168420995, 0.05400807962619832, 0.05677447707525321, 0.025853393699175546, 0.06135106006903308, 0.0240896555728146, 0.0415334236542029, 0.03326369669022305, 0.04165504766362054, 0.018436547934210727, 0.03447820991277695, 0.05617474711367062, 0.05190256849995681, 0.0061661695945076644, 0.019345425235639726, 0.019671854862411107, 0.021019683252753954, 0.009515423959653293, 0.0409625653576638, 0.07175831483410937, 0.0212844815437815, 0.02037681033834815, 0.05436713321666632, 0.024743025423958898, 0.054535280979637585, 0.055345716420561075, 0.02742797152937523, 0.020229814208245704, 0.037665791011282375, 0.0516570779228849, 0.03599654058260577, 0.024450079804020267, 0.021175834516595517, 0.044342154903071265, 0.03219418640115431, 0.043490250794483085, 0.07888669839927129, 0.03578950258504067, 0.02931469752054129, 0.03588178674025195, 0.027687126105385165, 0.10402191536767141, 0.03251328106437411, 0.027522214954452853, 0.01613666197018964, 0.007825533343878175, 0.07414037987057652, 0.02102499109293733, 0.0223468553407916, 0.041070761159062386, 0.03593359288892575, 0.056645389180630445, 0.02393004547671548, 0.025719927557344948, 0.05762409112815346, 0.0553062460385263, 0.06817713592733655, 0.015172911541802543, 0.053338711615651846, 0.04151999883885894, 0.03822726856118866, 0.062291692809334824, 0.048711537050881555, 0.042712422353880744, 0.024930209486878345, 0.04068854238305773, 0.024758584231936505, 0.03342454002371856, 0.05953001457133463, 0.023239741268168603, 0.034464734207306585, 0.025787546964628354, 0.01582347565064473, 0.018257082207128406, 0.021612246188202074, 0.056819816785199304, 0.014787284823666726, 0.009465923981874116, 0.026226662598284226, 0.07377882248588971, 0.043126104798700125, 0.033072614443621466, 0.026685430302417705, 0.03857901772218091, 0.018208251434511373, 0.02553454670123756, 0.036991215244467766, 0.020515815022268465, 0.01039054329573576, 0.018455536736707603, 0.034144370683601925, 0.07111255305686168, 0.02347014461910086, 0.03619252524471708, 0.09611838018255574, 0.03515267372131348, 0.02930669759267143, 0.027027578192896078, 0.0278907086633678, 0.06282696194414582, 0.011162901047750242, 0.034994385072163174, 0.024772860608728867, 0.04762083272050534, 0.040309567004442215, 0.02739999213788126, 0.07090224791318178, 0.0337545523153884, 0.014728706895506807, 0.017772350360506346, 0.09922018088400364, 0.03814924042671919, 0.030222658799695115, 0.05209487210959196, 0.051870555217776976, 0.07273142904575382, 0.023805982133905803, 0.010589479585178196, 0.053058507187025886, 0.06131085008382797, 0.06628820978637252, 0.0315121331784342, 0.0366019736310201, 0.03683731332421303, 0.09645384789577552, 0.038030517154506276, 0.028384819560285126, 0.058941310803805075, 0.04028798959084919, 0.07996566407382488, 0.027897326076137166, 0.015909183105187755, 0.013723682878272874, 0.016103408665263226, 0.040794895961880684, 0.028548526311559335, 0.03246718139520713, 0.01931335258164576, 0.05009585026917713, 0.024825570905315023, 0.030991079352263893, 0.08563046117446252, 0.030546370893716812, 0.0211120098164039, 0.04460136545822024, 0.00987972432215299, 0.02597406436689198, 0.029197246501488344, 0.06166041096938508, 0.028814291514988457, 0.041484891436994076, 0.016046557608725767, 0.0024984901953887728, 0.016006456189123646, 0.01726606484901692, 0.09731568914971181, 0.07046838583690779, 0.017034129705280066, 0.011852242584739412, 0.017422195756807923, 0.04286099098888891, 0.010842926833512527, 0.015608290143843209, 0.030662529303559234, 0.01871939356039677, 0.04499225251908813, 0.048375621504549465, 0.02778005656520171, 0.017073756150369133, 0.057556916161307266, 0.0435582196473011, 0.02699696269285466, 0.0463290750714285, 0.08319460866706711, 0.01070544630887785, 0.04143735666626266, 0.011718017331856703, 0.05471600878185459, 0.046160662679799964, 0.02682106605997043, 0.07715155543493372, 0.015298655955120921, 0.08263983843582016, 0.016956138890236616, 0.04201022681913205, 0.06006609116281782, 0.02902344654181174, 0.0205139643180051, 0.04680086386256984, 0.024632588760661225, 0.026268392501931106, 0.07299361497695957, 0.059035057201981544, 0.044632740917482545, 0.028895953204482794, 0.028514429926872253, 0.02111989608965814, 0.06319207485233035, 0.037015496620110104, 0.03704031064574208, 0.09027165427271809, 0.02670022745483688, 0.04060826490500143, 0.015243092418781348, 0.04844191098319633, 0.04281908805881228, 0.020102678798139095, 0.04086339407201324, 0.004704577598853835, 0.046824107079633644, 0.03588821246687855, 0.018473714689857194, 0.037413355628294606, 0.06235472871256726, 0.022859325698976005, 0.04749289155006409, 0.046416287177375386, 0.035474272178752084, 0.07972487235175711, 0.019346132608396665, 0.005773252017596471, 0.028574629553726742, 0.08738173970154353, 0.020184840907209685, 0.0077681572708700386, 0.054612247206802876, 0.012996113526501825, 0.04106100043281913, 0.12831056490540504, 0.021027686573298912, 0.03202908865309187, 0.03588097928357976, 0.048548502049275806, 0.019874299177899957, 0.041798669778342755, 0.06569309386291675, 0.018095336422058086, 0.015534838728074516, 0.0947695407750351, 0.007603574361252997, 0.08282235078513622, 0.0323581068909594, 0.012563129304908216, 0.020809464622288942, 0.044982926055256806, 0.018004068373037235, 0.034244756546935866, 0.02524874435870775, 0.03115153931347387, 0.030912976578942368, 0.042509370749550204, 0.02605789906478354, 0.04749678294839604, 0.009249661300730492, 0.034255959160093746, 0.01917260236638997, 0.038158753487680636, 0.03978753269516996, 0.015534222957545092, 0.04231390855940325, 0.031226225662976503, 0.017057690137465085, 0.053275719817195616, 0.0553714091490422, 0.011171850076477443, 0.02314622387556093, 0.022602607063683014, 0.029862037793334042, 0.05159006919711828, 0.039424153443958075, 0.06995844641434294, 0.08762690797448158, 0.0319598441544388, 0.02950693666934967, 0.025600846357909695, 0.05008137711722936, 0.05288683443463274, 0.023761868876005923, 0.018582538136148026, 0.04419152352160641, 0.01711875998548099, 0.050689680368772576, 0.07601000847561018, 0.07720088493078947, 0.03594152496329375, 0.039353945425578525, 0.036204318183341196, 0.04798273276537657, 0.04257204024387257, 0.05377939636153834, 0.05292428956766214, 0.032780155672558715, 0.04236845938222749, 0.040934097420956404, 0.028101168173764433, 0.023959412472322583, 0.029581846935408454, 0.027197586838155985, 0.03760812910539763, 0.014157269299695534, 0.05206832103431225, 0.018066381636474813, 0.03946991723829082, 0.03312821360304952, 0.03573989488982728, 0.09714020642318896, 0.10045043951166527, 0.024107263556548526, 0.024291423049622347, 0.04806699324399233, 0.01647646212950349, 0.02286671324899154, 0.024003937940246294, 0.025326733477413654, 0.0077601217199116945, 0.03136780199461749, 0.007313733887193459, 0.07924361460443054, 0.2130680297102247, 0.18773782891886576, 0.09585691349846975, 0.07895942378257002, 0.07616421912929841, 0.09593690599181823, 0.12461835731353078, 0.07035472443593399, 0.09073256954018559, 0.08325366835509028, 0.07574650618646826, 0.22712722101381846, 0.08871263864317111, 0.15504310759050505, 0.10548581395830427, 0.15322500014943735, 0.1598450592053788, 0.21675339766911098, 0.09324009570160083, 0.14056663082114287, 0.12639738113752433, 0.13476911905620778, 0.08789507179920163, 0.10283615506653275, 0.2696515806019306, 0.11793395956712109, 0.09714973305485078, 0.1526374023939882, 0.08286502385245902, 0.15770353483302252, 0.14384132224534238, 0.17900981940329075, 0.07615518104285002, 0.09781087043562106, 0.13895132392644882, 0.15748071750359877, 0.18731987848877907, 0.13292141391762666, 0.14942702251885617, 0.05372280314830797, 0.1380753487880741, 0.17059803434780665, 0.12504439588103974, 0.1327505045171295, 0.08273484690913133, 0.151392059932862, 0.13722947346312658, 0.06390567656074252, 0.10862374664949519, 0.11547849061233656, 0.14745439908334187, 0.133993675666196, 0.16748825407453946, 0.20347433164715767, 0.07924477489931242, 0.14938807460878575, 0.14996896843825067, 0.15451665941093648, 0.15496945939958096, 0.17404853419533797, 0.17423529417387076, 0.09309448887194906, 0.08391329260276896, 0.11665253261370317, 0.06623105678175177, 0.08309350016393832, 0.09141304516898734, 0.254515744213547, 0.13127194957009383, 0.17742820855762276, 0.1695243748170989, 0.19860166311264038, 0.09293864294886589, 0.11519573149936539, 0.13440230302512646, 0.12976488258157456, 0.21950487074043068, 0.10836101110492434, 0.13508189655840397, 0.09860509567494903, 0.1531816960445472, 0.09299443888344935, 0.07496739870735578, 0.10692793836018868, 0.13481315597891808, 0.17224554451448576, 0.20531499359224523, 0.07378594710358552, 0.1657333725265094, 0.1346404959580728, 0.16873066526438507, 0.07235921866127423, 0.16329372700835976, 0.19192892259785108, 0.15834241626518114, 0.1587659849652222, 0.1664016345249755, 0.13070134233151162, 0.1454740674900157, 0.10811154091996805, 0.10438276029058866, 0.11571337229439191, 0.12980889236288412, 0.11538094441805567, 0.082545739199434, 0.08135203325322696, 0.08772582480950014, 0.11701104337615625, 0.2368100785783359, 0.1299811452627182, 0.14969021268188953, 0.1297812895583255, 0.16262459648506983, 0.21710126900247165, 0.11445858462580613, 0.1028645381863628, 0.061286232833351405, 0.14095487498811313, 0.1158469622688634, 0.07443349342793226, 0.08985964780939476, 0.1831508507686002, 0.143350429300751, 0.07135031172739607, 0.07067880633154086, 0.24783524125814438, 0.10070233885198832, 0.10731707819338356, 0.21872672678104468, 0.1725229974836111, 0.08836590046329157, 0.10860197924609695, 0.09745710263294832, 0.1305966850902353, 0.0699950669492994, 0.10944202595523425, 0.13107522869748728, 0.14034616122288363, 0.24064703126038822, 0.16104761324822903, 0.11076886047210012, 0.24570776256067411, 0.08240182870732886, 0.1287222999547209, 0.19973199388810567, 0.14766680768557958, 0.1654753799417189, 0.1559210369097335, 0.1585523821413517, 0.1670652689146144, 0.11502578561859471, 0.16192725247570447, 0.14212031316544327, 0.08923557201134306, 0.18169181048870087, 0.08757490505065237, 0.09475459943392447, 0.1211682917284114, 0.23302849435380527, 0.1441366613975593, 0.1702957877090999, 0.1278320484395538, 0.18010298003043446, 0.20435857134205954, 0.10400087399674313, 0.08956472934888941, 0.1534164963024003, 0.1322696538908141, 0.10208068774746996, 0.14753202348947525, 0.11084001843950578, 0.1053615945524403, 0.09924543595739774, 0.09355757545147624, 0.13105251134506293, 0.17304708436131477], [0.02229372944150652, 0.015979343626116003, 0.057264494709670544, 0.06188052772943463, 0.02464083974648799, 0.016389787762558887, 0.06689750709171806, 0.01595754229596683, 0.02724213944748044, 0.042081829226974926, 0.027667041468833174, 0.04962459412802543, 0.024170866036521535, 0.013487757948626364, 0.03994495960484658, 0.014279537069212114, 0.03786561618159924, 0.05199719699365752, 0.013547174715703087, 0.02759749162942171, 0.050734012454215965, 0.029123265828405107, 0.03309347261009472, 0.0798466761729547, 0.05640272470191121, 0.008146738251005965, 0.00803459676847394, 0.025020710791328123, 0.0580142487638763, 0.004508802434429526, 0.04480069869064859, 0.03497370332479477, 0.04832783228318606, 0.038733655852930884, 0.03359923564961978, 0.039429300132074525, 0.019502987852320075, 0.06647790103618588, 0.02575267874635756, 0.07008222477244479, 0.027732520098132745, 0.04371480517355459, 0.05700927733310631, 0.07096007945282118, 0.040401067451706955, 0.04458936895909054, 0.0649538706722004, 0.018076079598228847, 0.0833658641204238, 0.03153010078572801, 0.03298763811056103, 0.034383377858570645, 0.04473530827090144, 0.030184850828456025, 0.018482148880138993, 0.04205319844186306, 0.029059965296515396, 0.061439805664122105, 0.03460332837754062, 0.04601858762492027, 0.08186527035598244, 0.05788393611354487, 0.012807417178659566, 0.044582322372921875, 0.04873051228267806, 0.0022783730112548384, 0.06394433270075492, 0.02331782877445221, 0.0668162050257836, 0.0052070628901544425, 0.02989196797300662, 0.04769835873906102, 0.09266002968485866, 0.0230446777173451, 0.07774922265005962, 0.09696570078709296, 0.017131543585232327, 0.0229128451485719, 0.036387505675000806, 0.04317061669592347, 0.040678252399499924, 0.0071755850055654135, 0.011630681393268918, 0.03763715683349541, 0.01719421647222979, 0.024019827534045492, 0.04998759679230196, 0.036956080701202154, 0.07076301252735512, 0.04596433535750423, 0.04210379679820367, 0.037547200053398094, 0.0901235436488475, 0.03235466671841485, 0.03399635844730905, 0.011940509812640292, 0.04957475233823061, 0.0467976238578558, 0.08380290852593524, 0.04015082373682942, 0.018081767418022667, 0.054314495862594674, 0.01802717418675976, 0.007928677452062922, 0.00836790504399687, 0.05986540086035218, 0.04619582436446633, 0.03970569119389568, 0.030190503025161367, 0.02331740129739046, 0.03306698938831687, 0.04973634206024664, 0.03411622165835329, 0.0681340421683022, 0.012963093467988074, 0.09031750288392816, 0.03319919175867524, 0.04106701225308435, 0.01710169143708689, 0.05196113625009145, 0.008689411899207957, 0.06743202983800854, 0.0393698231450149, 0.04286550324676292, 0.021335062936746647, 0.036049812366919856, 0.0158988693729043, 0.015535474854654499, 0.009255349120524312, 0.0113856488273346, 0.11391772436244146, 0.06137641692267997, 0.02413425059057772, 0.019492886162229946, 0.024926368978672793, 0.04040941343243633, 0.027530723783586706, 0.031909334007650614, 0.020461659446092587, 0.035314005600022416, 0.01852687621223075, 0.05127661655257855, 0.029029081775141612, 0.05953719347183194, 0.044355963090700765, 0.052599291649780104, 0.07738280016928911, 0.011091369037915553, 0.0544549017213285, 0.02882530413834112, 0.037924594445420165, 0.034386404124753814, 0.034050139132887125, 0.01923515650975917, 0.04909458363960896, 0.024626062950119376, 0.04840172813939197, 0.027469655631908348, 0.032425122402076206, 0.06483161223254033, 0.058865565939673355, 0.05384153999122126, 0.05331641495493906, 0.00808997031500829, 0.0399800398653107, 0.05137397954240441, 0.011567104358359106, 0.04609240544959903, 0.02911590033077768, 0.052649727157716236, 0.056993969583085606, 0.01256459578871727, 0.021249672697324837, 0.028966642982725586, 0.06907666301620857, 0.006704417073966137, 0.010897542965332312, 0.07587833875524146, 0.027753067834834968, 0.005704976551766906, 0.02631752352629389, 0.007300648339358824, 0.07227600991193738, 0.029895401360200982, 0.036126117022441964, 0.04426400463229843, 0.07066185652677502, 0.03426427121407219, 0.02843961974472872, 0.06236548349261284, 0.010357714923364776, 0.037692023175103326, 0.0630192451977304, 0.016395713069609234, 0.030860875267535448, 0.040500065710927756, 0.023112878968407, 0.054154483734497, 0.018717098415696194, 0.018848975089245608, 0.03487076616979071, 0.02099266568464892, 0.020303647299962382, 0.0435027935143028, 0.03725380490400961, 0.04371116483317954, 0.04004180690805827, 0.0807406867721251, 0.04348038150263684, 0.02559283116300191, 0.019666372299460427, 0.029107103124260902, 0.05843226704746485, 0.03215466173631804, 0.019891371118969152, 0.03370894458410995, 0.0687895409230675, 0.019045852024906447, 0.04370848122718079, 0.03188958524593285, 0.01044183290962662, 0.04978345953194158, 0.011609639174171855, 0.03882856254598924, 0.05242097943222948, 0.04035186009215457, 0.04164729879370757, 0.024100442583273565, 0.01822716390181865, 0.0173183612392417, 0.04872335034555622, 0.009697762434370816, 0.051787926615881066, 0.029881372648690428, 0.05314007048894252, 0.11533546900110585, 0.04070333783913936, 0.04284908269931163, 0.024423718718545775, 0.042386525377099, 0.037607158800320964, 0.01267378988476204, 0.018490174253072058, 0.06108147132077387, 0.03465956196721111, 0.03652891915823732, 0.06372891140303441, 0.06107624660113028, 0.07890824188611337, 0.0389974668755063, 0.027203172877697007, 0.026767360013244406, 0.044718958969627104, 0.03819146566092968, 0.04437991198418396, 0.05178093770518899, 0.03167281366352524, 0.027680724127484218, 0.025396938103118112, 0.05618145103965487, 0.01968473006438996, 0.021307282016745636, 0.054928105257983716, 0.02862949250265956, 0.018497702599103962, 0.05299206503799983, 0.04563141554327948, 0.024863453515406166, 0.038173494660960774, 0.04225286415645054, 0.051785863869424374, 0.03065916376986674, 0.051867824114326916, 0.014154775683502001, 0.0640442401969007, 0.04079963552898594, 0.012871554853128535, 0.06723189593425818, 0.04558673740497657, 0.0431354550112571, 0.025443821480231624, 0.027935697231441736, 0.014851134968921542, 0.02141500453996871, 0.022148022527939508, 0.025905718927138617, 0.034056103455701044, 0.01887273060024849, 0.05073505400546959, 0.02667414626505758, 0.025553632194974592, 0.01692556240595877, 0.024719319106744866, 0.04595855423914535, 0.046946050000510046, 0.05917325442922967, 0.02957390129034008, 0.04124628799036145, 0.04557347543803709, 0.04714993281023843, 0.011780362825707665, 0.048549903224089315, 0.062448461540043354, 0.027086346110861217, 0.015785917041024992, 0.030581390086029257, 0.0123832725720214, 0.10236149267958743, 0.04153290457491364, 0.0320605523219066, 0.008582176224860762, 0.014952762551339609, 0.06784318813255855, 0.020236304395699074, 0.008961702065010155, 0.03869346961645143, 0.04933843555461083, 0.04648569452443293, 0.05705829470285347, 0.014985892023625118, 0.04109124613127538, 0.015721898958353058, 0.02459707423778517, 0.08542382690523352, 0.03284142059939248, 0.033419356016176086, 0.057691422158053944, 0.015622910877157534, 0.021612756785803607, 0.018000847028036202, 0.02257833586606596, 0.019385357021487186, 0.014541315879406673, 0.02713839483580419, 0.02829096120383058, 0.042066043109766076, 0.02198205964772829, 0.02549731039575168, 0.029120551688330512, 0.025360714511147568, 0.041981389080839496, 0.02716865749763591, 0.052394445320325236, 0.042616063595882485, 0.04191386806113379, 0.06933340709656477, 0.021741289978048632, 0.043087699716644626, 0.04347943155361073, 0.05191196620996509, 0.044443511071481874, 0.04991335827591164, 0.09714061354420014, 0.1480198223143816, 0.1066283719348056, 0.14400575842176164, 0.07455976200955254, 0.08493808404143367, 0.2307527693254607, 0.11798394045659474, 0.11228367633053235, 0.22358021991593496, 0.1580052793558155, 0.16660839771585806, 0.19308521412312984, 0.14775383658707142, 0.08302950752632958, 0.056632710753807, 0.1410507248448474, 0.18195614059056553, 0.1502561108874423, 0.1512720270880631, 0.10416001760001693, 0.1167591033237321, 0.11896272722099509, 0.17792357983333723, 0.08387323868061815, 0.05581087253189512, 0.17109660830880913, 0.18799050178911003, 0.20385744608938694, 0.1411896888166666, 0.14918740466237068, 0.1644419032548155, 0.1203306538185903, 0.07018996934805598, 0.11839431843587331, 0.0786300493138177, 0.12258994472878319, 0.11685787088104657, 0.12110446872455732, 0.11766694246658257, 0.17496119093682083, 0.11412687599658966, 0.1608969241912876, 0.10530551363314901, 0.12709921704871313, 0.12300317255514008, 0.16733137677822793, 0.1456167905458382, 0.17026578289057526, 0.11548689087586743, 0.12444063542144639, 0.08638904975461108, 0.12043821518974644, 0.13215173807527336, 0.1213984236653362, 0.15173497796058655, 0.18392002449503966, 0.2170942122382777, 0.11077309453061648, 0.13863386453262397, 0.18376591562160424, 0.283077101622309, 0.10467131409261908, 0.11583271303347178, 0.14061106129416398, 0.11867186639990125, 0.15047668905130454, 0.11753589021308081, 0.12904647684523038, 0.0998934708269579, 0.1398609544017485, 0.18229297894452298, 0.15705913012581213, 0.15233736777944223, 0.15772439299949578, 0.16529178193637303, 0.09122346927012716, 0.2032715446714844, 0.13031904213130474, 0.14233511021094664, 0.2280580082109996, 0.08302192829017128, 0.10872446160231318, 0.214725772184985, 0.14155366857136997, 0.15900002526385443, 0.11290296845670257, 0.06688344106078148, 0.1743191068193742, 0.1430594056312527, 0.10714192116366965, 0.17861226573586464, 0.1906138810196093, 0.12265464982816152, 0.1393682158419064, 0.15692988277545997, 0.1282162078257118, 0.1247353774628469, 0.176504966669849, 0.1980178922946964, 0.11209626495838165, 0.17971359592463287, 0.12942347090159143, 0.1997064674007041, 0.10778237679707152, 0.11470757983624935, 0.20043997732656343, 0.1875925545713731, 0.13324476299541338, 0.06915645194905144, 0.14894101502639906, 0.10431726130523852, 0.1234504764101335, 0.08538563895438399, 0.07251828084034578, 0.26514955503599985, 0.12208592891693115, 0.11070262188357965, 0.17150191084614821, 0.1566757849816765, 0.07148417990122523, 0.12941463637564862, 0.18764239975384303, 0.09469032859695808, 0.0896832694166473, 0.13401889002748898, 0.09703994608883347, 0.11741939932107925, 0.11862184479832649, 0.07398196908512286, 0.1845063737460545, 0.14372061086552484, 0.11306575579302651, 0.10142551468951361, 0.10671415233186313, 0.08570428578449146, 0.114733364166958, 0.09390606425170388, 0.11859249137341976, 0.08536682996366705, 0.08216157981327601, 0.18484763614833355, 0.15676783504230635, 0.10923226363956928, 0.0729238208649414, 0.10528741710420166, 0.12850162679595606, 0.1716626693627664, 0.1752329577824899, 0.1343421441103731, 0.0893991125215377, 0.088568911355521, 0.09774584642478398, 0.08794903568923473, 0.1716015740696873, 0.09737633660967861, 0.10836707720799105, 0.10389665101787873, 0.12776104653520243, 0.11636643510844026, 0.07620725860553128, 0.11763316499335424, 0.16775493190756866, 0.12668756342359952, 0.0894653375393578, 0.16750255759273255, 0.17446056780006203, 0.09796895552426577, 0.15346581222755568, 0.18115506214754923, 0.2053945857499327, 0.15170546168727533, 0.1947989628783294, 0.10445659847131797, 0.14610319158860616, 0.10642889621002333], [0.08987666546766247, 0.026786642282136848, 0.031952699180692434, 0.019874582466270243, 0.013193225404912872, 0.056776641601962705, 0.01473139219784311, 0.05490959482267499, 0.021129376920206205, 0.013354801556228526, 0.07886649841176611, 0.02951838355511427, 0.01988457728709493, 0.049647610035857985, 0.05421609810686537, 0.020167268546564237, 0.03211359340431435, 0.03671602179695453, 0.021922234911471605, 0.031166317806180035, 0.010176885340894972, 0.043581354298761914, 0.052829786602939875, 0.026480249794466153, 0.03205949380727751, 0.031278907121824365, 0.03289489594421216, 0.02278931106307677, 0.02260280553517597, 0.010330707533285022, 0.03054563468322158, 0.009822282091980534, 0.06704942429704325, 0.04283133561589888, 0.03948355918484075, 0.044825451648128886, 0.04567113019792097, 0.030483799786972146, 0.019117015081324747, 0.026611011974247437, 0.013855715614876576, 0.026512856794787303, 0.0021581978861442102, 0.02414501385231103, 0.012932304093348128, 0.035295953175851276, 0.05421391322410532, 0.045240474199610095, 0.009590702330959695, 0.042246787875358544, 0.08280673769435712, 0.0815615648669856, 0.02513080818711647, 0.027141227719507048, 0.02169695110725505, 0.03200995735824108, 0.02048186452261039, 0.05368933780118823, 0.05981155910662242, 0.03640366159379482, 0.009993185555296285, 0.025494964360924702, 0.031941062305122614, 0.05428771408540862, 0.026172603713348508, 0.0320091940063451, 0.03680910662348781, 0.02316426781804434, 0.026177545144621815, 0.05113423276426537, 0.023746786738878915, 0.029717258776405027, 0.021950833466170088, 0.009781419864988752, 0.020488303819937364, 0.03353507337825639, 0.03908300978530731, 0.04755994777328201, 0.030701317757900273, 0.02609040937386453, 0.03778668898823006, 0.016949835299913372, 0.006616776218704347, 0.010088573160049106, 0.09032658846782786, 0.05621955417362707, 0.019769650418311357, 0.013060917861626616, 0.006933849271652954, 0.04579404003119894, 0.027122973431167857, 0.0031152836163528264, 0.012115336904701377, 0.030026772525161505, 0.05584221745708159, 0.0025014469117325333, 0.047956005270992, 0.03633300234962787, 0.025113605628056184, 0.019108458754739592, 0.022261370106467178, 0.02711497519963554, 0.009975881215983202, 0.012039331652756249, 0.0669372488877603, 0.035752603850726566, 0.04343854642606207, 0.05172788305208087, 0.04282356299726026, 0.056372292406324825, 0.014013444472636496, 0.010535354543078159, 0.005506728127199624, 0.02333569629783077, 0.04554584209940263, 0.031156054964022975, 0.009451967364709293, 0.02558995078184775, 0.05167522534195866, 0.09149847951318536, 0.0221948397478887, 0.024219313436853032, 0.0068331618843201014, 0.07808698381164245, 0.026291162440819398, 0.032443083224019835, 0.01259630373013871, 0.04211091463054929, 0.0061356787752759245, 0.02107944861719651, 0.06242995789008481, 0.033805347446884425, 0.025719759619927833, 0.008777132058250052, 0.04316992119752935, 0.031642825808376074, 0.05108053350288953, 0.010413344616868665, 0.026822803109618168, 0.03044251093108739, 0.04814681949626122, 0.05208910795460854, 0.01745440751048071, 0.022670611539589505, 0.029073318865682398, 0.01928716112992593, 0.04840223704065595, 0.02331571513786912, 0.02059622311831585, 0.034781810228845904, 0.07405939671610083, 0.047450778274131675, 0.054418352432549, 0.07303701407675232, 0.036291927232273986, 0.022373587924188802, 0.021895039227924178, 0.007860563562384673, 0.025515617270554816, 0.007965890856991922, 0.013648837921209633, 0.014080504936698292, 0.03227790065908006, 0.016528463356995156, 0.0451282682562513, 0.09372484790427343, 0.02608914390605475, 0.03756949671411088, 0.04137355741113424, 0.0551258642891688, 0.013702647444526, 0.04885482668344464, 0.056042032449373176, 0.02651136232140873, 0.07227970792778901, 0.019645297001781206, 0.10970746885452952, 0.06430224635239158, 0.02128537551366857, 0.02681476416598473, 0.014706567994185855, 0.0094412320925455, 0.020427637700257555, 0.01965513067053897, 0.018853494132469808, 0.031433677566902976, 0.05319567643372076, 0.021895758475043943, 0.00234165700385347, 0.05671832151710987, 0.043379486738038917, 0.05500057279797537, 0.04033613843577249, 0.015478143734591348, 0.024061474317152585, 0.04200566367113164, 0.012627705482632985, 0.028315703983285596, 0.006328940391540527, 0.014647335279732943, 0.02572594616296036, 0.02751687997286873, 0.049454397189297845, 0.05175469536334276, 0.07963443720447165, 0.05766505428722926, 0.022162929942299212, 0.025499644556215832, 0.030349158083221743, 0.045735831904624186, 0.023586306421618377, 0.04715639246361596, 0.036188976506569555, 0.0328159551801426, 0.02943695935287646, 0.01876879939144211, 0.02771591973890151, 0.0034750176502192126, 0.060559745744935105, 0.004751685740692275, 0.05562439075271998, 0.012477047807936157, 0.0493086309039167, 0.043615742453507016, 0.01954015969697918, 0.05835531439099993, 0.03741005455542888, 0.03355559566989541, 0.015477202267252972, 0.016882528018738543, 0.07257033804697649, 0.010505406551861336, 0.04551230211343084, 0.04760765217776809, 0.040491064943905385, 0.02219535204182778, 0.029643125432942594, 0.01674908901830869, 0.025592759916824952, 0.012045405389341925, 0.0420641228556633, 0.03564486266779048, 0.06737731277410473, 0.06797265261411667, 0.038808542370264015, 0.033057099740420065, 0.02637097003337528, 0.04598798569557922, 0.0038854212866031696, 0.03240517347252794, 0.04802598598014031, 0.03640116797760129, 0.012061435779157494, 0.027059021505660245, 0.0210400935861149, 0.023514773563614914, 0.013228075811639428, 0.041270016359963586, 0.017313757379140173, 0.02270765106991998, 0.10433366149663925, 0.09997350403240748, 0.02318029820785991, 0.013701490542319204, 0.0471200738767428, 0.02745413583969431, 0.047140711519334993, 0.03998984130365508, 0.05453966431585806, 0.010051187576859124, 0.04295635908575995, 0.02380222813891513, 0.03992899028318269, 0.021661877632141113, 0.034921367918806415, 0.027890903742185662, 0.02562766715085932, 0.035501064133963416, 0.012673817026162786, 0.02575636319150882, 0.06628001308334724, 0.06625815747039658, 0.029273669900638715, 0.08499592915177345, 0.0165531671206866, 0.01224961644038558, 0.035967003953244, 0.032176761621875424, 0.005900933224308703, 0.019313130361427153, 0.07817999739199877, 0.022946944925934076, 0.052509908231773546, 0.005969527177512646, 0.03015496814623475, 0.05465019767039588, 0.012030263032232012, 0.036582377539681535, 0.07016965400959764, 0.022947182413190603, 0.03226981930700796, 0.06456395052373409, 0.044873821016933234, 0.013135683938993939, 0.01774267802414085, 0.05093621249709811, 0.03967515033270631, 0.0324646843863385, 0.022078642322282706, 0.05545313190668821, 0.01734042041269796, 0.03623515759993877, 0.05257099334682737, 0.028492140051509653, 0.07274147814938, 0.045809324032494, 0.04172253814925041, 0.02929691651037761, 0.08016087859869003, 0.020512515645740286, 0.0434879810948457, 0.016899077487843375, 0.021538077221651162, 0.05435779996748481, 0.026518878793077807, 0.009258977586536534, 0.018386254918628504, 0.03957273904234171, 0.023094762083409087, 0.031465385508324416, 0.0414286510619734, 0.03253399334581835, 0.04945608674149428, 0.048158503869282346, 0.06112374405243567, 0.011220601121229785, 0.03165082573624594, 0.02489671530202031, 0.028324292540284138, 0.011218302583854114, 0.035145277689610205, 0.03769750234537891, 0.05084803347874965, 0.029214376118034124, 0.0464579967249717, 0.04783771286851593, 0.030841099364416938, 0.04522707652566688, 0.1192034443042108, 0.01520560505533857, 0.05958262139133044, 0.03369915671646595, 0.15327837371400424, 0.12569944001734257, 0.10254203049199921, 0.14167557417282037, 0.08602424218718495, 0.1437098357294287, 0.18909069203904696, 0.19412219205072948, 0.08464974058525902, 0.07206520943769387, 0.19125254532056196, 0.11903143567698342, 0.13506016986710684, 0.13911516299205168, 0.17153139997805866, 0.19543675865445817, 0.08883201330900192, 0.1112390716693231, 0.09109163670135395, 0.09532914896096502, 0.07959221875561134, 0.11134997821812119, 0.13653276727667876, 0.10575576911547355, 0.14140042822275842, 0.13535670324095658, 0.165302733491574, 0.1154056838048356, 0.16790389748556273, 0.12465662668858256, 0.12620945407875947, 0.10436893174690859, 0.09051022039992468, 0.153204793376582, 0.12048886104353837, 0.15456296264060906, 0.1020811220098819, 0.1443569002939122, 0.21299219663654054, 0.09387564552681786, 0.1325136415128197, 0.1802284818674837, 0.22070946038833686, 0.14490005400563988, 0.18711329171700136, 0.11552414244839124, 0.14412854611873627, 0.13726302023444856, 0.09597369616052934, 0.12096127069422177, 0.16644890127437456, 0.2049321098519223, 0.10951942644481148, 0.18380356074443885, 0.14482602583510534, 0.11824715776102883, 0.20280178130737372, 0.20871544469680103, 0.1064391488741551, 0.09243152623197862, 0.18074720831854002, 0.15842734170811518, 0.10913507028349809, 0.1507187360631568, 0.16269314209265368, 0.10277695967150585, 0.10357729172600166, 0.15784032749278204, 0.11408967870686736, 0.12314436212182045, 0.13787765082504067, 0.09293901614312615, 0.10503458138555288, 0.13957271272582666, 0.10136218023087297, 0.16637213182236466, 0.11864933903728213, 0.11112667912883417, 0.10564161916928631, 0.18998581543564796, 0.08710782868521554, 0.07342537359467574, 0.1347052146281515, 0.09043619222939014, 0.22571797163358756, 0.1814457465495382, 0.11319190223834344, 0.20531137021524565, 0.15413496989224637, 0.12411681136914662, 0.16187755657093866, 0.11580140542771135, 0.13155884774667875, 0.11987717529492718, 0.15824480221739837, 0.14432580981935772, 0.1325287457023348, 0.11078528101955142, 0.08018263921673809, 0.12627837966595376, 0.17221015212791307, 0.13652679616851465, 0.08358235750347376, 0.07973213946180684, 0.12858564300196512, 0.09840020524071795, 0.11236291565001011, 0.15438830772680895, 0.12187692656048707, 0.09737364961100475, 0.08130892592349223, 0.131210610004408, 0.09362299979797431, 0.10269042610057763, 0.1340180757854666, 0.09808444218443972, 0.18710897623428277, 0.10926412085869483, 0.15755497637603963, 0.19735177446688923, 0.11609373188444547, 0.08901690731623343, 0.1466372393603836, 0.1228966832693134, 0.1697493363171816, 0.11918713232236249, 0.1478536355176142, 0.12253897317818233, 0.115324449592403, 0.18088410954390252, 0.13101759393300327, 0.09215649563286986, 0.10044683649071626, 0.08234857727906533, 0.0977319228862013, 0.28764068388513153, 0.22194370201655797, 0.08690297217773539, 0.10816546409790005, 0.1617138260709388, 0.15446813058640274, 0.15717655739613942, 0.12690674380532332, 0.11278363450297288, 0.08460425159760884, 0.07265916506626777, 0.17409890863512242, 0.11952477134764194, 0.08849693236074277, 0.08397579246333667, 0.227391618969185, 0.12549932646964276, 0.1329780715916838, 0.12916024002645696, 0.11568160328481879, 0.11274117178150586, 0.12783381263060228, 0.08980966013457094, 0.11143378407827445, 0.08819480785833937, 0.0975539635068604, 0.05122083418869546, 0.10851104876824788, 0.04160483607224055, 0.14351200205939157, 0.16332907868283136, 0.13336942344903946, 0.15869843001876557, 0.09018719023359673, 0.22485836275986262, 0.07725807864751134, 0.10392038617283106, 0.2080756811691182, 0.16803741960653237, 0.16807814527835163, 0.10847511355366025], [0.03231106066544141, 0.0210449620748737, 0.012534138896236462, 0.022946035689009086, 0.05882078941379275, 0.04418919614649244, 0.03189662165407624, 0.011460028987910067, 0.02793174476495811, 0.025330999766343405, 0.013976581361410874, 0.013690638222864695, 0.021330872983006493, 0.02943634188600949, 0.03578676808891552, 0.033199541204209836, 0.04727458647851433, 0.01656445285438427, 0.06779113092592784, 0.03145112609490752, 0.051214106513985565, 0.039999286511114666, 0.033809937736285586, 0.012960094343205648, 0.048495386328016005, 0.01497514233259218, 0.034905449487268925, 0.09012502964053835, 0.01934332516975701, 0.0708369253469365, 0.04995329684710928, 0.06008215208670922, 0.056133919661598544, 0.04842163296416402, 0.009917371989493924, 0.04735541696261082, 0.009924104753216463, 0.021370647009462118, 0.027226221015942947, 0.05338324047625065, 0.019477885449305177, 0.023156067722343972, 0.03337758879310318, 0.08663663361221552, 0.031206215665276562, 0.019140953796782663, 0.014558287736560618, 0.039527362012969594, 0.02418297788660441, 0.06019385252147913, 0.12923349466707024, 0.033119026238897016, 0.02635177767037281, 0.037013644219509194, 0.13203592571829045, 0.025709666411525438, 0.023959105435226644, 0.025371055384831767, 0.05167351882638676, 0.013747461289832634, 0.02656880031073732, 0.03127737363268222, 0.06205108429172209, 0.030038595997861454, 0.027006161931369985, 0.05168637027963996, 0.05260443833789655, 0.0652454032429627, 0.02250020086233105, 0.07329567162586109, 0.036221247632056475, 0.05984240530857018, 0.08179120147334677, 0.036771478464028666, 0.0352554242791874, 0.01630458072759211, 0.016200517204457095, 0.03720090292128069, 0.008573441782833209, 0.04430237239492791, 0.07453345520687954, 0.017136725896437253, 0.09307140511061464, 0.057428544121129174, 0.08027874013142926, 0.01365275985361742, 0.024542314765442694, 0.01535729325509497, 0.04147838428616524, 0.028895247528063397, 0.040281584220273156, 0.042643788536744456, 0.06677955734942641, 0.04095467399539692, 0.039330264553427696, 0.0557782044634223, 0.022183414914512208, 0.06631056751523699, 0.10776104365608521, 0.0922047191166452, 0.02813018063482429, 0.016347816978980387, 0.053228741445179494, 0.012017176636228604, 0.024207474697115164, 0.03811323057327952, 0.018423752460096563, 0.04773980026532497, 0.023412794839324694, 0.03833209882889475, 0.02850609751684325, 0.0449506481444197, 0.06435089052787848, 0.008416920717406486, 0.048840431563024006, 0.011084355530329049, 0.060758773636605055, 0.05272851864408169, 0.006664680791020925, 0.08359940230314221, 0.04896823024111135, 0.04036794137209654, 0.04587174586153456, 0.043597798594938855, 0.053507134185305665, 0.020015366608276963, 0.02912956941872835, 0.03954060701653361, 0.03735359365652714, 0.032412067388317416, 0.03036724782681891, 0.03684194093304021, 0.08771491396640028, 0.05506038226719413, 0.021335526036896875, 0.033327204175293446, 0.010363762366718479, 0.04107969407258289, 0.015481560158410242, 0.0805388701015285, 0.030632303961153542, 0.02350008667313627, 0.0238761409584965, 0.013622277516073414, 0.0722222767238106, 0.038729299658111165, 0.007846600159869661, 0.016628338622727563, 0.07318032745804105, 0.016817653285605565, 0.011340547452813812, 0.02438995481601783, 0.009802404408609229, 0.0480822195698108, 0.016451883894790496, 0.035560836283756156, 0.025369343780247227, 0.07170927032296147, 0.0347495832081352, 0.025673525940094675, 0.013601274312739926, 0.04749579907261899, 0.0461087377874979, 0.03939318171303187, 0.0324367253508951, 0.012452814777913903, 0.041184052758451016, 0.07510798437786953, 0.03323241283318826, 0.024060695698218684, 0.02092023376774575, 0.025093174938644682, 0.031023157095270495, 0.060605594356145175, 0.01060908246186695, 0.01010454332988177, 0.023817262778590833, 0.019523976636784415, 0.02539482616287257, 0.017837661052388803, 0.05116022404815469, 0.025483251150165285, 0.007644531583147389, 0.017162440677306483, 0.04401588812470436, 0.10775091991360698, 0.060975090600550175, 0.03979115607216954, 0.03637993661686778, 0.022571168839931488, 0.03600628095279847, 0.045477517015699825, 0.039440004021993706, 0.0727706008723804, 0.04020828886755875, 0.04034364642575383, 0.028566517667578797, 0.03060620411166123, 0.013375563031461622, 0.0498746173190219, 0.03263082029297948, 0.012689695593767931, 0.02612487386379923, 0.04147855731259499, 0.050784302077123096, 0.08503785583057574, 0.14722578706485884, 0.07061579078435898, 0.018776256491297057, 0.05650438281840511, 0.03812685216377888, 0.04839544151244419, 0.004794278656065996, 0.033070755257670365, 0.04468194488435984, 0.047291105413543325, 0.030877780967525074, 0.014934018021449447, 0.031734529816146405, 0.011790025164373219, 0.04378125750060592, 0.08177429238068205, 0.05227588150384171, 0.04369820820699845, 0.07470519920544964, 0.04364472946950367, 0.013883572021898414, 0.03585417375766805, 0.036857492955667634, 0.046560835492398055, 0.041018544496702294, 0.004420801955607853, 0.04335386864840984, 0.027122182937871133, 0.02803526715641575, 0.053733479896826405, 0.03889788168349436, 0.01996952308607953, 0.03161080913352115, 0.023523316319499697, 0.012837592479107636, 0.02317206927442125, 0.03843471367976495, 0.02742155089176127, 0.030830249589468752, 0.052391039074531624, 0.0558567720332316, 0.05706612499696868, 0.08702905755490065, 0.03579020147610988, 0.03588433463924697, 0.056580623013100455, 0.05611306828047548, 0.043391001477305374, 0.029853752880756344, 0.03114950031574283, 0.0484261621854135, 0.05751275710229363, 0.005330815379108701, 0.020031308788540106, 0.07995896014784064, 0.04557016079447099, 0.1020978953955429, 0.00882373214699328, 0.056605576138411245, 0.034338947385549545, 0.039040401178811274, 0.028587067100618566, 0.07101443689316511, 0.11514788120985031, 0.0865951276251248, 0.04673617911924209, 0.017349906332258667, 0.03529180393421224, 0.008394861543950225, 0.05775618154023375, 0.05420081749824541, 0.028214972067092146, 0.023589224122198563, 0.07782667742243835, 0.02705266193619796, 0.04303184271390949, 0.018254561449534128, 0.04680273322654622, 0.048077164483921866, 0.014027941373309918, 0.07324182987213135, 0.024901829759723375, 0.061073301759149344, 0.05122375188927565, 0.03248052139367376, 0.056335193504180224, 0.012801470667389887, 0.004914817857622568, 0.026125901844352484, 0.04040051444566675, 0.05802532924073083, 0.040816775323557, 0.016213987820914814, 0.02886303068537797, 0.043748524971306324, 0.03376110017831836, 0.03597879349919302, 0.042087196438972435, 0.035545793162392716, 0.03365185604031597, 0.06012971739151648, 0.021145434451422522, 0.044704431534877846, 0.04398791891123567, 0.05099996425477522, 0.060954212078026364, 0.030400367121079137, 0.004011265359752412, 0.028348036176924194, 0.041775121220520565, 0.03313254265646849, 0.06241101319236415, 0.044380878896585534, 0.04151394969916769, 0.12125032661216599, 0.01969274695563529, 0.02980931562238506, 0.009479286880897624, 0.02811570748287652, 0.094318572830941, 0.01988002601345735, 0.022481422405689955, 0.053625592828861306, 0.06250512599945068, 0.028247078647837043, 0.019476514808567505, 0.0404461764597467, 0.026153363852894733, 0.04468352247827819, 0.018228437851316164, 0.09295420175684349, 0.039052529992269616, 0.04251996946654149, 0.067643956680383, 0.0627897714397737, 0.03409042714961937, 0.04881716459723456, 0.04207192940105285, 0.015699034024562155, 0.0714595897921494, 0.026587914642212645, 0.0038878534105606377, 0.01559040735342673, 0.06061264433498893, 0.02463830541819334, 0.025127625857879008, 0.10531167473111834, 0.10218622029892035, 0.12588226449276718, 0.09037984668144158, 0.13816040993801185, 0.07908600449029889, 0.10016534623822995, 0.09789173823914357, 0.1529133761567729, 0.2256047377096755, 0.1456925964781216, 0.1451539753803185, 0.20428965932556561, 0.12537121905812196, 0.08799691990550075, 0.1650937039937292, 0.3384956350283963, 0.13743325109992707, 0.15333480068615504, 0.13676455483904906, 0.1302408884678568, 0.12933850474655628, 0.10837099914039884, 0.13888781304870332, 0.20619303147707665, 0.09742594430489199, 0.17035267608506338, 0.13473299385181495, 0.15455739865345614, 0.19757286831736565, 0.179287815200431, 0.18172957774783882, 0.10049738734960556, 0.21586256261382783, 0.07465942523309163, 0.16238374369485037, 0.05177015917641776, 0.08751456971679415, 0.16933528067810194, 0.12563800545675413, 0.1702268078391041, 0.05774014775774308, 0.11888829192944936, 0.15147230348416738, 0.11063786250139986, 0.15201620358441556, 0.14176239951380662, 0.16697667938257965, 0.1752253853316818, 0.10325073317757674, 0.16551772052688257, 0.08525546879640647, 0.08367253480745213, 0.0990192327382309, 0.17639473187071936, 0.12261358488883291, 0.12430993600615434, 0.19515493591981276, 0.20906437454479082, 0.19978928938508034, 0.1623002431754555, 0.14638337226850645, 0.1291575665984835, 0.08173547339226518, 0.08152735991669552, 0.11691310363156454, 0.16054044903389045, 0.11271383360560451, 0.1217846322272505, 0.15638363494404725, 0.19198616381202424, 0.14491890370845795, 0.16908538980143412, 0.12110125246856894, 0.08293498759823185, 0.2198746180427926, 0.08661483228206635, 0.14059705633137906, 0.09542466633554016, 0.2229550720325538, 0.1396406612225941, 0.0879136093759111, 0.12072803106691156, 0.13357725872525147, 0.17974806550358022, 0.20887462901217596, 0.21930544929844992, 0.06845532849963222, 0.1380028405359813, 0.1205860408289092, 0.13800156489014626, 0.2027199092720236, 0.21300099045038223, 0.2524936284337725, 0.16897082594888552, 0.07856057411325829, 0.21411699056625366, 0.24137040387306893, 0.221333006929074, 0.20377733824508532, 0.10844516301793711, 0.1456502287515572, 0.12413556607706205, 0.1355205558772598, 0.1878721517111574, 0.0687142371066979, 0.12167917431465217, 0.12387000104146344, 0.11942571880561964, 0.14336842404944555, 0.15486994545374597, 0.11346956555332456, 0.0905364186369947, 0.12412602587469987, 0.06586061058832066, 0.1688094296093498, 0.12902629721377576, 0.0746023061552218, 0.06545469058411461, 0.15130349754222802, 0.1761640163936785, 0.12133409854556833, 0.09546721048120942, 0.14570889488926955, 0.23237484799964087, 0.1236292432461466, 0.1616569376949753, 0.19654381567878382, 0.1813203397073916, 0.15612006480140345, 0.07120425027928182, 0.20847099567098276, 0.20909980764346464, 0.1229417108531509, 0.11566682479211263, 0.12252367899886199, 0.07679413711386067, 0.12606268695422582, 0.09421376631196056, 0.17342550334121498, 0.09227291188601937, 0.13414231554738112, 0.1333507637360266, 0.15205832703837327, 0.2069737267281328, 0.12180137847151075, 0.07018444607300417, 0.111208904002394, 0.2101540339312383, 0.2282144512448992, 0.1653973212731736, 0.10695892705449037, 0.14010027370282582, 0.08856173245502369, 0.0771870156750083, 0.13658040043498787, 0.10893593382622514, 0.11969089029090745, 0.10493268578180245, 0.0868052224229489, 0.15274618512817792, 0.12096253276935645, 0.10181411169469357, 0.14383262342640332, 0.11108656413853168, 0.12019935729248182, 0.11667078520570483, 0.14346563097621712, 0.10140653606504202, 0.1421083573784147, 0.10391271194177014, 0.16131544459078992, 0.07753640014146056, 0.10896139924547502, 0.12587671407631465, 0.1516911174569811], [0.00783352563822908, 0.02147521773752357, 0.0297413705182927, 0.015445404419941562, 0.019162505765312483, 0.019385954132303596, 0.053634155940796645, 0.030374355481139252, 0.03185732090579612, 0.0634185087734035, 0.02268964614320014, 0.047510692916278324, 0.03650149616545864, 0.05898365138896874, 0.022020843013056686, 0.05270669695788196, 0.023149358707347086, 0.0733677591862423, 0.025076430390721986, 0.08702972251921892, 0.01308939852086561, 0.037903953410152874, 0.0571355934121779, 0.01603065274788865, 0.03492718974926642, 0.03012252738699317, 0.06192066307578768, 0.014257659403873342, 0.05284571860517774, 0.05984351132065058, 0.04265339319993343, 0.023516821043033685, 0.04960391916600721, 0.0546459703972297, 0.04369096823834947, 0.01752579617979271, 0.039610373987151046, 0.01540973044133612, 0.020683542093528167, 0.019359279224382978, 0.04224365982892258, 0.03752303063603384, 0.04033222668138998, 0.012177779089792498, 0.01633419029946838, 0.11462511069008283, 0.05217091892180698, 0.018417698231392672, 0.04453501491142171, 0.00565094014330368, 0.05065885791555047, 0.049890769845140834, 0.049845026406858645, 0.04176325025036931, 0.041423192247748375, 0.03069105152306812, 0.030058019062770263, 0.023030579455995133, 0.05843312878693853, 0.02603453880042902, 0.010853226146926838, 0.04757007830111044, 0.07761779720229761, 0.030122388287314346, 0.023603364791987196, 0.025667566706293395, 0.01959364691616169, 0.026901100961757556, 0.057205475733748505, 0.04576016417039292, 0.0508950966676431, 0.025250947901180813, 0.06286377925425768, 0.006728407103634838, 0.04616051000942077, 0.021095611321340715, 0.05038521492055484, 0.02969577635771462, 0.02556567788789315, 0.026284226116591265, 0.0821634932820286, 0.031354865724486966, 0.034409718587994576, 0.017145680862345865, 0.03767986722024424, 0.04868836168731962, 0.02457308802487595, 0.04707345852096166, 0.01419260655529797, 0.026465237207178558, 0.005757423067864562, 0.019606868171000054, 0.04927349975332618, 0.04410955988402877, 0.015642973461321423, 0.04677127295040658, 0.04323257372847625, 0.04437335394322872, 0.06430158817342349, 0.0168313172845436, 0.010654808936773666, 0.05422721590314593, 0.019168302150709287, 0.042577298890267096, 0.017109581103016223, 0.018796731285484772, 0.045624016118901115, 0.006562149908859283, 0.08007397183350154, 0.03427414729126862, 0.016098971046241264, 0.04049427780721869, 0.008781803771853447, 0.07968156146151678, 0.050796200188675096, 0.06448701822331973, 0.05690625875390001, 0.013389500988913434, 0.05947026956294264, 0.07164728614900794, 0.006790577026549727, 0.04837117370750223, 0.043669166908200295, 0.08894479261445147, 0.06184981044914041, 0.04019884705277426, 0.04873261234856077, 0.021747744542413523, 0.051550005096942186, 0.05500795865165336, 0.024390920032081858, 0.032765916615192375, 0.022482696355187466, 0.026080633380583355, 0.041939581145665476, 0.007150690403899976, 0.03284382600603359, 0.0028672432319061564, 0.030312025254326205, 0.01912870623969606, 0.00890238962269255, 0.020831145512472306, 0.030042304191738367, 0.026758269340332066, 0.0695757730198758, 0.019005489369322146, 0.028399704922256724, 0.05218899848737887, 0.039639181191367764, 0.029020335458751236, 0.03349516534113458, 0.04755885872457709, 0.0153150832879224, 0.0384466389327177, 0.027962037960865667, 0.050202383659780025, 0.027062263206711838, 0.04369078842656953, 0.04381668720660465, 0.02151425046447132, 0.01957142150162586, 0.06123148184269667, 0.029930267882134234, 0.015180848705183183, 0.05661101798926081, 0.05431195814162493, 0.02443424110034747, 0.02291717759466597, 0.03501392688070025, 0.06497223861515522, 0.021030997824189917, 0.005463425294562642, 0.05641275344948683, 0.02829580764020128, 0.014178320848649102, 0.06916612785841737, 0.02023356650689883, 0.047831395707492314, 0.03834254487550684, 0.03707877001059907, 0.01343152266261833, 0.10408204714102404, 0.06775051381971155, 0.04421029858557241, 0.046609754474567514, 0.006508885333979768, 0.044369374335344346, 0.03308234124311379, 0.040011160873941014, 0.09956944321415254, 0.027612575462886264, 0.04016832994031055, 0.017648303981072137, 0.06344708866838898, 0.056948243108178885, 0.015635741974360177, 0.016756149175177728, 0.05015841119789651, 0.043580136328403435, 0.04908988817727991, 0.03345818518261824, 0.03556857158296874, 0.03806653718597122, 0.044119103479066064, 0.03236303984054497, 0.02979774320764201, 0.026206934192617024, 0.05310312764985221, 0.009604945629169899, 0.015622369745480163, 0.027421079309923307, 0.04395690307553325, 0.016056007905197994, 0.03649672945695264, 0.06616023808185544, 0.005640778233230646, 0.03940659295767546, 0.009941610108528818, 0.08834224673254149, 0.02288593614606985, 0.006376210957699056, 0.049870963407946486, 0.021072074637881348, 0.043875641721699915, 0.08490630146116018, 0.01190974164221968, 0.023403330972152095, 0.029213897750845978, 0.026393639888348322, 0.019738895818591118, 0.015368333019848381, 0.04903133060517056, 0.035244937520474195, 0.04413293202274612, 0.016917548907388533, 0.029805943303342377, 0.03905473183840513, 0.007997668348252773, 0.024090602129165615, 0.0587859737819859, 0.08513236218797308, 0.036061836007450304, 0.05424744303205183, 0.06549564695784024, 0.022865001644407, 0.040888530401779075, 0.1495407721293824, 0.014259730632017766, 0.1043791233428887, 0.10676028592778103, 0.05461569755737271, 0.014160140350993191, 0.0692196778420891, 0.007588269155738609, 0.04478513648999589, 0.1252683802906956, 0.014661771112254687, 0.026576623819502335, 0.051762410306504796, 0.01719479153065809, 0.024249681271612644, 0.019199004163965583, 0.043491577330444536, 0.03150201282863106, 0.014266829804650374, 0.03609049054128783, 0.01883930596522987, 0.06463587523571082, 0.028335184723670994, 0.056781676331801076, 0.03227484385882105, 0.039650366841150184, 0.06394339632242918, 0.036982289116297445, 0.026080626595233167, 0.06493692765278475, 0.024605345579662492, 0.033086717793984075, 0.028963447082787752, 0.03409260185435414, 0.034475658621106825, 0.030613447472985302, 0.09220855283950057, 0.01696476646299873, 0.028311653129224266, 0.016910417504342537, 0.026311518491378853, 0.022850190921287452, 0.008342696619885308, 0.061625269640769274, 0.02229669294320047, 0.01999279174820653, 0.009210587861681623, 0.011336281163884061, 0.06464656894760472, 0.05491612232955439, 0.07872068802160875, 0.04390504942940814, 0.02200744194643838, 0.029751463726695095, 0.014462161376806242, 0.07006228262824671, 0.014233554447335857, 0.018974239439038292, 0.06649307307920285, 0.013060247808295702, 0.05718759633600712, 0.05732469433652503, 0.017250375423048223, 0.007493699185683259, 0.006990487437828311, 0.05278400584523167, 0.0438971886012171, 0.019959007489628026, 0.01125313772354275, 0.036559629653181346, 0.04215109747435365, 0.06026595365256071, 0.03847647751016276, 0.03583072019474847, 0.03549188694783619, 0.042613498733511994, 0.01349760009907186, 0.06120728528393166, 0.025275780586525798, 0.021737191626535993, 0.01690713339485228, 0.019894166683245982, 0.021665450119014298, 0.022879608807020953, 0.029779507579015832, 0.027541256343413676, 0.04573334168110575, 0.012768562567154211, 0.01151990206978683, 0.031206843310168812, 0.05582109805462616, 0.05333149539572852, 0.029205297319484607, 0.030245226874415363, 0.07878402926559959, 0.06994562888784067, 0.04436453638066139, 0.03266983266387667, 0.03368770643802626, 0.06766761719648327, 0.025346175202035477, 0.02242327873994197, 0.028284854388662746, 0.02888499486393162, 0.08451943472027779, 0.06714095188570873, 0.0962107220132436, 0.12071997007089001, 0.11554481062505927, 0.0762077064386436, 0.09202025937182562, 0.19554877121533665, 0.12315706429736954, 0.10132456903478929, 0.17599394837660448, 0.07614230923354626, 0.09763500772948776, 0.08370199679796185, 0.1380110779511077, 0.21059216399277958, 0.0842538018311773, 0.15441595124346869, 0.07051460764237813, 0.15687023954732077, 0.07695634769541876, 0.12289447124515261, 0.07507580146193504, 0.15233522360878332, 0.09720822955880846, 0.15086129627057485, 0.13383511560303823, 0.07154178073895828, 0.16438979176538332, 0.0893123143219522, 0.11002002244016953, 0.1832485869526863, 0.08875067731631653, 0.08966435186032738, 0.21126719777073177, 0.07974533018256937, 0.08984362081225429, 0.12089305078344685, 0.08025839086622, 0.11367789616010018, 0.12764104083180428, 0.0872949075752071, 0.11209306905844382, 0.16000669981752122, 0.23273395587291035, 0.10723275664661612, 0.11992223002016544, 0.179146747770054, 0.10161578269409281, 0.1355964703751462, 0.2094531072569745, 0.04483867629564234, 0.15357165011976445, 0.14486695506743022, 0.19832334161869117, 0.11100423069936888, 0.2451977484992572, 0.1109672233994518, 0.11760402869965349, 0.126344536830272, 0.12429020420781203, 0.14540899598172732, 0.1423934099397489, 0.08751255446778876, 0.14789001856531414, 0.08629346452653408, 0.10753486079296895, 0.16136322702680314, 0.17291293798812798, 0.1381008481340749, 0.11486831121146679, 0.11875972311411585, 0.21152368400778088, 0.11979693174362183, 0.2072296565664666, 0.16828888468444347, 0.1773684024810791, 0.15318464088652814, 0.1362625474908522, 0.13276642294866697, 0.10506009430225406, 0.1305286551692656, 0.15558737409966333, 0.09516303001769952, 0.1188288794032165, 0.11603434649961335, 0.08954391867986747, 0.11461664257305008, 0.09569810916270528, 0.22663890650229795, 0.1241888175053256, 0.2055767724024398, 0.12980760314634868, 0.11767660480524812, 0.23281844705343246, 0.1882818647261177, 0.17823658803743975, 0.1388059952961547, 0.15232580554272446, 0.11064447143248149, 0.12879069628460066, 0.12437194053615842, 0.12310369073280267, 0.13899218530527183, 0.1761293839663267, 0.13661396077701024, 0.1514858334724392, 0.19126159697771072, 0.13243676349520683, 0.12215790791170937, 0.1361478479312999, 0.1457619834691286, 0.1086398618561881, 0.10706018483532326, 0.08529214361416441, 0.1832955687173775, 0.10054723931742565, 0.14857714383729867, 0.14242843591741153, 0.10411300869392497, 0.22077791100101812, 0.14763669430145196, 0.23926982230373792, 0.1034163771463292, 0.14640492254069873, 0.20233675411769322, 0.14603883932743753, 0.2090315063084875, 0.13360328732856683, 0.08738942071795464, 0.1956202888063022, 0.10916050856134721, 0.14502793071525438, 0.15269452147185802, 0.06544563892696585, 0.11199767382017203, 0.12629570945033006, 0.13670340526316846, 0.20631767836000237, 0.08352083473333291, 0.20133248157799244, 0.1085439712873527, 0.08828540585402932, 0.1443348614765065, 0.07628542583967958, 0.1623018445180995, 0.13198663693453583, 0.1977628988346883, 0.08529191969760827, 0.1004814485620175, 0.14406238895441803, 0.10972165702176945, 0.08145871252885886, 0.10301512546305146, 0.10136891808360815, 0.12094725216073648, 0.07471609647784914, 0.20483357299651417, 0.09761450918657438, 0.07792021347475903, 0.14172639644571713, 0.132555059290358, 0.08837636347327914, 0.1580530075090272, 0.1376591082662344, 0.14777154635105813, 0.14815023674496583, 0.21137399918266706, 0.11974097974598408, 0.08080301699893815, 0.17279884911009244, 0.20461399906447955, 0.14065498965127127, 0.11478684629712786, 0.09648812069956746, 0.0716789330222777, 0.1411868253988879, 0.1470182774854558], [0.06728087937725441, 0.03527527482115796, 0.055083550845405886, 0.044105373322963715, 0.02768699888006917, 0.027867014220516597, 0.04457771512014525, 0.011808207358366676, 0.025806759683681384, 0.006464482850528189, 0.027261774554582577, 0.03965399700349995, 0.07704516114400965, 0.039625413715839386, 0.03960520015763385, 0.06372876212533031, 0.09215834124812058, 0.02376959569353078, 0.02328059755797897, 0.032458102596657615, 0.053231720213911364, 0.012433119450828858, 0.06013838228370462, 0.01126872028024601, 0.021636344359389374, 0.03548896585458091, 0.023954309888982346, 0.0216031215885388, 0.04548302672005125, 0.027502669753240686, 0.02191978200737919, 0.015406990856198328, 0.014292088270719563, 0.009569129158210541, 0.04881142758365188, 0.0328044641896018, 0.03868558503953474, 0.03659219594140138, 0.05882759512002979, 0.03723183733278087, 0.015211640624329448, 0.03608053643256426, 0.0629315445465701, 0.03173397681010621, 0.008636564199280525, 0.04079336925808873, 0.0490043995502804, 0.037665248183267455, 0.02073343307711184, 0.02540969625780625, 0.08451579098722764, 0.0530803865487022, 0.07508359782929931, 0.007108170006956373, 0.030952195903020244, 0.02204984359975372, 0.022225528190444623, 0.03378744090774229, 0.029954454262873957, 0.012853433727286756, 0.042817015134330304, 0.06917042298508541, 0.05195989792368241, 0.05962941316621644, 0.06353686563670635, 0.018531045809920346, 0.01910781075379678, 0.06488742852317435, 0.04291421866842678, 0.00313249635343839, 0.05625182529911399, 0.06307041352348668, 0.030998889290328537, 0.0698073095242892, 0.006816125566339386, 0.061328329145908356, 0.02006907944035317, 0.02931182731741241, 0.02171375502699188, 0.04141540266573429, 0.06346802147371428, 0.03620596702343651, 0.05019082481573735, 0.05572421003931335, 0.05491146757932646, 0.03767938885305609, 0.14070198498666286, 0.012401869520545006, 0.0449134983521487, 0.030380944056170325, 0.09001248103699513, 0.06416117892201458, 0.09665060269513301, 0.033899504358747175, 0.02540258181813572, 0.018373391591012478, 0.043116527276911905, 0.03914473611595375, 0.031221991604460136, 0.03031234077310988, 0.02765370486304164, 0.05161333955558283, 0.056712906807661057, 0.02873267393027033, 0.06239645183086395, 0.04148916281493647, 0.03822138226990189, 0.06099350604095629, 0.08305755137865033, 0.0537775609243129, 0.040312990213611295, 0.03314374187695129, 0.06909463062350239, 0.028817273676395416, 0.04638860294861453, 0.0322761228973312, 0.024978626353134, 0.012620837011906718, 0.07918963035834686, 0.05444545651386891, 0.029248123057186604, 0.03636868650625859, 0.013604445615783334, 0.03553504177502223, 0.07179174625447818, 0.02483035627353404, 0.027610913052090576, 0.057362258035157404, 0.01728529792412051, 0.03879076814545052, 0.03663441099758659, 0.05172958617497768, 0.034333895692335706, 0.027885860530659556, 0.014073654277516263, 0.01571804318310959, 0.01651730654495103, 0.0676898935011455, 0.07890273896711213, 0.06239156637872968, 0.028529520545686995, 0.05734108095722539, 0.005104199101749275, 0.04145648456843836, 0.05732837878167629, 0.07743217037724597, 0.03795671968587807, 0.021643550401287417, 0.019846787975568856, 0.028382027388683388, 0.022806140427876796, 0.05187355434255941, 0.03373264241963625, 0.03108267140175615, 0.024153670262811438, 0.04229341001648988, 0.023812558834574053, 0.05643611880285399, 0.04713432989748461, 0.022204766715211526, 0.00994785687154425, 0.007459024349892778, 0.057259670325687954, 0.01546389449919973, 0.014207273937894829, 0.02047002747921007, 0.04099825629964471, 0.08320858648845128, 0.09082922006824187, 0.04053986518244658, 0.026729587665093795, 0.04274038817467434, 0.008971465335759734, 0.0013775804545730352, 0.10269591544887849, 0.02988243455599461, 0.03614240525556462, 0.023880990787542293, 0.03396275060783539, 0.014101872852604305, 0.04173234298026987, 0.034234972071966956, 0.03130757183368717, 0.031844421955091615, 0.03300340387171932, 0.005333998980599323, 0.03308256176699485, 0.01545933135119932, 0.04480027460626193, 0.021273032961679355, 0.013337381865962275, 0.050320462323725224, 0.07102921538587127, 0.043834525892244916, 0.013571389934181102, 0.06783073022961617, 0.07895435512598072, 0.021947561231042658, 0.047807270394904275, 0.02043207362294197, 0.018635418066488843, 0.0495445337811751, 0.03659492704485144, 0.01623036595992744, 0.0057379787987364185, 0.08404743897595576, 0.005239856911690107, 0.02863952803558537, 0.018643906539572135, 0.014061249809206595, 0.03466971963644028, 0.017645871433030282, 0.06640073124851499, 0.01343813244186874, 0.03162543156317302, 0.015528813337108918, 0.052720050527048964, 0.024940943910873363, 0.018359130481258035, 0.052288207092455456, 0.05365227282579456, 0.020254577343751277, 0.055144065991044044, 0.04417826155466693, 0.02497253310866654, 0.038834584544279745, 0.025698692803936343, 0.02284929695140038, 0.03479877021163702, 0.04752693025927458, 0.054248793316738944, 0.059072458052209446, 0.019587731787136624, 0.0072206049558839625, 0.009311338437588086, 0.03424062766134739, 0.024055988361526812, 0.08201722827340875, 0.06075422066662993, 0.06573012830423457, 0.03144640688385282, 0.009039367183244653, 0.03123809663312776, 0.04763857641124299, 0.050505312226180515, 0.005272757378406823, 0.050294681385691674, 0.004552971671468445, 0.013677004758002502, 0.05385628794985158, 0.019666848970311027, 0.011557962795320367, 0.03927172055201871, 0.06577838571476084, 0.029730778586651598, 0.03465972820829068, 0.061477111519447396, 0.010456413779008602, 0.046716169121542146, 0.04564880978848253, 0.036019335966557264, 0.06227490585297346, 0.04215217295235821, 0.10835750986422811, 0.04531237855553627, 0.026038913654961755, 0.05247994412535003, 0.02768153667316905, 0.04435651948941605, 0.09364669424082551, 0.03205675252580217, 0.0203122748727245, 0.09706765745899507, 0.056941023495580466, 0.11045928565519196, 0.015306788197319423, 0.036338691865759234, 0.012077450901935143, 0.022864216240122914, 0.04696457739919424, 0.03754861819158707, 0.0320836462612663, 0.0675477132733379, 0.07619741984776088, 0.08448491085852895, 0.046808809507638216, 0.04401567438617349, 0.026621922817347304, 0.032724926314715824, 0.034632132189082246, 0.01184936729259789, 0.02810262023870434, 0.02799597319348582, 0.04544743416564805, 0.018633387550445538, 0.05861142064843859, 0.03039529507181474, 0.04442158081967916, 0.059628985689154694, 0.06394458375871181, 0.022189060325867364, 0.0367111668788961, 0.005428767846232014, 0.07017653435468674, 0.01328393366254334, 0.03073029120319656, 0.02288085561511772, 0.030032227946711437, 0.042302037589251995, 0.055291179168437204, 0.02159725226062749, 0.05588733325047152, 0.050925447539027245, 0.031141917686909437, 0.13200012621070656, 0.014118468122822898, 0.029577209148555994, 0.07603894799415555, 0.0362692777333515, 0.0043480990487816075, 0.01340367812995932, 0.022938787238672376, 0.014584691230473774, 0.042814460449985096, 0.04140326028157558, 0.03050885469253574, 0.03841180633753538, 0.022926646550851207, 0.06667460155274187, 0.01300387257444007, 0.07382788056773798, 0.017625949644882764, 0.04648322465696505, 0.031124876279916083, 0.05174740111189229, 0.0840123247887407, 0.009145819149645311, 0.052155936868595223, 0.039438562135079076, 0.022479439387097955, 0.028749504991407906, 0.016025684175214598, 0.04068249324336648, 0.03686011549351471, 0.054293976963630745, 0.0420893745363823, 0.06696177114333425, 0.04060880094766617, 0.001823830247823415, 0.029461023597312824, 0.046799561075334034, 0.04106968228838273, 0.11223692526774746, 0.10100647860339709, 0.14601221361330577, 0.07732068028833185, 0.0835971970643316, 0.13816900019134792, 0.15974602023405687, 0.08502755566899266, 0.05990584833281381, 0.0843332786379116, 0.0829997741218124, 0.08571940354470696, 0.12572544147925718, 0.09501503474478211, 0.1385515175227608, 0.12130872133587088, 0.18035084887274674, 0.10749262198805809, 0.18077695529375756, 0.1260753891297749, 0.19181150889822415, 0.10787016565778426, 0.1631743726985795, 0.16767884099057742, 0.16665170182074818, 0.11662302991109234, 0.13729592918285302, 0.09411472055528845, 0.1947845100824322, 0.1953324271099908, 0.11479599294917923, 0.16303493375224726, 0.09888160548039845, 0.1293008867651224, 0.15362870134413242, 0.13196861504444055, 0.1879103532327073, 0.10513750836253166, 0.08832586689719132, 0.07898136081972293, 0.12463869979338986, 0.13823103186275276, 0.09135433153382369, 0.13729674342487538, 0.11611843055912427, 0.09156034833618573, 0.16609317250549793, 0.19421131084007875, 0.06768520482416664, 0.1299526332212346, 0.0937968540404524, 0.0850311451192413, 0.17386524831610067, 0.13625356368720531, 0.09047773892858199, 0.12580682496939385, 0.17290641048124858, 0.12486041789608342, 0.1888399054961545, 0.14329508798463003, 0.10713687964848109, 0.1687973245446171, 0.09213898264403854, 0.1714279776705163, 0.10581049296472754, 0.1826664446187871, 0.0604646626327719, 0.1587294933519193, 0.08634995256683656, 0.09420943725854158, 0.1513840260782412, 0.20083029781069073, 0.11608069044138704, 0.16069375723600388, 0.11199906481696026, 0.1548920656953539, 0.11242086932595287, 0.3013364518327372, 0.12844975957913057, 0.14702100519623074, 0.13043805717357568, 0.21920148416289262, 0.15140816835420473, 0.2217893081584147, 0.14711524013962063, 0.24326555218015397, 0.2800994728292738, 0.2051474225840398, 0.13448811056358473, 0.1200672872364521, 0.3229263776115009, 0.18709482199379376, 0.30035368885312763, 0.18117684312164783, 0.18206382409802505, 0.13726650790444442, 0.2073381543159485, 0.16868323566658155, 0.21856835670769215, 0.07962012690092836, 0.10490842136953558, 0.14034872608525412, 0.09892532349164997, 0.1823760587722063, 0.14436179931674684, 0.14885112270712852, 0.12390699477068015, 0.17385929077863693, 0.2186091366623129, 0.14634214448077337, 0.12658971867391042, 0.09160823933780193, 0.12177174006189619, 0.13396795918898924, 0.14112404733896255, 0.21108738599078997, 0.09759331175259181, 0.1441208922437259, 0.1969072933175734, 0.2000265187983002, 0.06678493813212429, 0.16964421767209256, 0.11141331267676183, 0.11239366685705525, 0.17686764363731655, 0.14654456504753657, 0.09201604566935982, 0.07655468889112983, 0.05283005123159715, 0.1027679555118084, 0.09992990137210914, 0.16477399186364242, 0.15453265926667623, 0.1380205095878669, 0.04637805512174964, 0.07599431396062885, 0.12234457289533955, 0.14331570187849657, 0.3082609288394451, 0.16915781662932464, 0.1404070665261575, 0.11931863240897655, 0.08563756543610777, 0.07134719725166049, 0.15398326303277696, 0.17322099288659437, 0.11081748429153647, 0.11482747697404452, 0.08205553157521145, 0.10615261710648026, 0.10749955661594868, 0.12093383073806763, 0.1188260702682393, 0.09712500723877124, 0.10227722541562148, 0.08952215806181942, 0.09569142559277159, 0.13649175662015164, 0.25193492269941736, 0.15118212119809218, 0.09621628600039653, 0.13840006850659847, 0.1436549151050193, 0.20353006651358946, 0.11138640197792224, 0.14635951497725078, 0.18702588283589908, 0.17572131300611155, 0.13494661024638585, 0.19448914378881454, 0.19881162898881094, 0.1251949763723782, 0.08425047700958592, 0.11404885804014546, 0.17821103440863745, 0.1516751176012414], [0.040847692771681716, 0.08222762841199126, 0.03117538642670427, 0.03449456599940147, 0.05570950618545924, 0.042651154034371884, 0.03392329718917608, 0.015212158007281167, 0.045712595472910574, 0.038079341141773124, 0.058062899724713395, 0.013861819885538092, 0.028294969649453248, 0.021474079495029788, 0.0672786266409925, 0.0072679836635610885, 0.06605933313923222, 0.03514977976945894, 0.04661873149286423, 0.05720347405544349, 0.028031455485948494, 0.014164443959348967, 0.01857095893605479, 0.013560892149273838, 0.04865836365414517, 0.04396424821711012, 0.006338291452266276, 0.04768495088709252, 0.014556545597900237, 0.08043979041810546, 0.03622285576005067, 0.026670409233442376, 0.011490312853961118, 0.05633988218115909, 0.012259583271640753, 0.017634930055854574, 0.03422498742916754, 0.019856457099584595, 0.06953774113208055, 0.06298335748059408, 0.031210381870291064, 0.02894455666786858, 0.008836126437277665, 0.02549163784299578, 0.03419787995517254, 0.045396533861224136, 0.019207943862836276, 0.01980556358051087, 0.10346073298049824, 0.03689960962427514, 0.012052282341755927, 0.01566083250301225, 0.06647027430257627, 0.07500204470540796, 0.03448281716555357, 0.015259792861927832, 0.034491468487041335, 0.012276209075935185, 0.0308574350949909, 0.028196955266009485, 0.0327368888870946, 0.055000091038112126, 0.03924126111503158, 0.02715820975468627, 0.02318285628488021, 0.00462059786410204, 0.020870510721579194, 0.04234431032091379, 0.0640812949942691, 0.027725855187912072, 0.10264734591224364, 0.010443055120828961, 0.06137010654700654, 0.1411520844059331, 0.07292345445603132, 0.038250813726335764, 0.014184774564845222, 0.02946627206568207, 0.01524078709605549, 0.06938516574778728, 0.11161924126957144, 0.0381980304872351, 0.037144482734480073, 0.0938438018783927, 0.05423030663015587, 0.029534637861485993, 0.05099844094365835, 0.03246183453926018, 0.05971283904675927, 0.03541060184527721, 0.05092196665438158, 0.046820632980338166, 0.13667653527642998, 0.053303108883223364, 0.084244112351111, 0.03765595564618707, 0.09406786092690059, 0.038469783762203794, 0.05729020440152713, 0.025720863935670683, 0.015262261033058167, 0.06193558406084776, 0.06142011457788093, 0.06762610442404236, 0.03076207378347005, 0.06092247699520417, 0.034559247350054126, 0.040220777304576974, 0.03169033004503165, 0.046861433291009495, 0.11342851418469634, 0.05237954129864063, 0.08069599845579692, 0.038875876792839596, 0.01658593018406204, 0.013630152763133603, 0.020530741096341183, 0.07738885948700563, 0.019744469983769313, 0.039877211275909624, 0.043202168574290614, 0.044441567068653445, 0.02311617834493518, 0.02817399872999106, 0.026573682370196496, 0.029271393415651152, 0.017816188811723675, 0.026972866218004907, 0.10151263180055789, 0.028166448331571052, 0.011396425659768283, 0.05093602589996798, 0.02743903504285429, 0.017358245527637855, 0.04155913334605949, 0.021515449775116782, 0.06513360102794, 0.039834914795522175, 0.0411913911146777, 0.06483284716627427, 0.015230927982234528, 0.04454760852136782, 0.05315855039017541, 0.021195990399324467, 0.01835907619845654, 0.010629379988781043, 0.013867603548403298, 0.024076734569721987, 0.008221760475342827, 0.004767133438560579, 0.06698003052068607, 0.05174931458064488, 0.011946747245799218, 0.017267808684014847, 0.040668752909238846, 0.04811836852292929, 0.04742313475747194, 0.022891735924141746, 0.03851344070530363, 0.03725469039220895, 0.02994501244808946, 0.0197475149096655, 0.01660462043115071, 0.025176600819187503, 0.0799501934753997, 0.02354661381936499, 0.023687906862635697, 0.023246925257678543, 0.02374991139263979, 0.06659712642431259, 0.024365218821913004, 0.10743812205536024, 0.035067307230617316, 0.062220623051481586, 0.07889020642531769, 0.05446934773187552, 0.05033482351739492, 0.014287141750433614, 0.0532786409104509, 0.020589944973055805, 0.040518884879669974, 0.03105717884110553, 0.05660711641290358, 0.06104046744959695, 0.04799620507817183, 0.0271472005240087, 0.06586934333401066, 0.035781254991889, 0.038355711847543716, 0.03613474459520408, 0.02585057438617306, 0.04603588008987052, 0.08839369325765542, 0.02286396178949092, 0.07011533049600464, 0.031976926273533275, 0.04520111916852849, 0.03290439543447324, 0.04043392211730991, 0.049933144357055426, 0.06691297090479306, 0.013381900548535799, 0.012820774988670434, 0.02438616180526359, 0.033697969280183315, 0.08580394222268037, 0.025161176021876078, 0.039955636353365014, 0.028499247705829994, 0.02553221762978605, 0.036552559318287034, 0.012653552577830851, 0.08864651540560381, 0.026240099287991012, 0.011508503529642309, 0.05300893002588834, 0.012734933523461223, 0.02302500868349203, 0.013237989208261882, 0.019112005796549574, 0.02159405466435211, 0.04656846561868276, 0.07400471357894794, 0.07504210541290895, 0.049006747281444926, 0.014800292339974215, 0.025733627179371457, 0.05155564372294715, 0.016181430014382516, 0.012078601018791752, 0.059454873603369505, 0.09257382859608956, 0.004476743775220322, 0.014758016215637326, 0.07473547543798174, 0.030030446792287484, 0.02393387580689575, 0.028424099952514683, 0.0696512736114008, 0.06038312307958092, 0.04011514975822397, 0.03526000099788819, 0.039916668087244034, 0.07358844591570751, 0.024174290942028165, 0.07298263628035784, 0.09804667492530175, 0.023470192116552165, 0.061309601579393656, 0.031678917086017985, 0.08198667384151902, 0.042351238163454194, 0.04560157696583441, 0.05934665405324527, 0.02898165557001318, 0.049637323444975276, 0.15545499191752501, 0.13283203728497028, 0.06720524986407586, 0.03966624456058655, 0.03505823861009308, 0.1225458128111703, 0.04557805894208806, 0.08874380375657763, 0.028738885918366056, 0.03347915191469448, 0.0667945190465876, 0.09398543249283518, 0.06705578217016799, 0.031018590554594994, 0.09604186178850276, 0.03356002650356718, 0.10287835994469267, 0.0887290049078209, 0.07497039104678802, 0.04130199910806758, 0.02375973657970982, 0.03712563303166202, 0.04779706183554871, 0.01845015425767217, 0.013068883862745549, 0.03535927067111645, 0.045220121541725736, 0.04060658553083028, 0.03717368348900761, 0.009736082699548985, 0.06252071194882904, 0.02584558885012354, 0.10589197144976684, 0.028735544133399214, 0.053382517836455784, 0.04391391109675169, 0.02891900303906628, 0.11176194396934339, 0.036439600201057534, 0.01776766337986503, 0.08189319885735001, 0.08203565728451524, 0.009193882329522498, 0.07356806272374732, 0.03103687028799738, 0.04916827254263418, 0.013613079973895634, 0.014923234403665577, 0.04332894605717488, 0.02330600021273962, 0.011623756095234836, 0.06190617635313954, 0.05922097579709121, 0.004433202183073652, 0.00623601077989276, 0.04162955849564501, 0.06282708408044917, 0.07036523494337286, 0.011454194434918463, 0.027212568891367743, 0.050655628088861704, 0.031221652336950814, 0.059224490608487806, 0.018744127858164053, 0.04357186159385102, 0.029368990500058447, 0.04620193117963416, 0.015527072894786085, 0.0852118729214583, 0.028246795359466757, 0.04470773600041866, 0.02604706455687327, 0.00963202426542661, 0.014922104642859526, 0.035694124310144355, 0.06426156817802361, 0.03403447175930653, 0.03111806378832885, 0.07276112852352006, 0.03795475193432399, 0.04121228660057698, 0.04044463957792946, 0.022685332356819084, 0.02280087669246963, 0.03159952848883612, 0.024216726522094438, 0.042446331453642676, 0.04105461202561855, 0.017558420143489326, 0.02352205424436501, 0.040973608515092304, 0.06225622578391007, 0.030906957973326956, 0.05417518923059106, 0.0792813818635685, 0.04626897043947663, 0.11176336210753236, 0.13157582469284534, 0.10928780851619584, 0.12284986435302667, 0.1606219546603305, 0.11483422161212989, 0.13112601025828294, 0.1789007516843932, 0.1521830689162016, 0.14859101309307984, 0.1435019461704152, 0.12317945595298495, 0.13699091412127018, 0.11493108927139215, 0.11965895843292985, 0.08338128722139768, 0.208411732422454, 0.13905564190021583, 0.16787265773330415, 0.09026442787476949, 0.16311372523861273, 0.11307536384889058, 0.20999255616750034, 0.09022990401302065, 0.13377939430730684, 0.07891634359423604, 0.08654545886175972, 0.179447365924716, 0.06701152133090155, 0.17954891547560692, 0.046567251040999375, 0.10056024683373314, 0.09309650412095444, 0.10278141086122819, 0.12184565966682774, 0.08196898443358284, 0.1415537092834711, 0.14038083436233656, 0.21927711367607117, 0.2725250135575022, 0.14158680822168077, 0.11367749582443919, 0.09332802026931729, 0.10014700543667589, 0.12658076201166424, 0.17542365326413087, 0.12608722278050014, 0.2841532038790839, 0.17869033797511033, 0.11296371091157198, 0.12754842080175877, 0.14845605247787066, 0.14628237911633082, 0.15439870288329466, 0.20280638177480015, 0.1498653832823038, 0.10149167863918201, 0.12894438446632453, 0.12635312708360807, 0.14833779739482061, 0.18730291511331285, 0.09526533952781133, 0.11488475890031882, 0.09622246745441641, 0.16196329625589506, 0.12168073494519506, 0.10750141580189977, 0.1274561264685222, 0.11347944502319608, 0.1382342345480408, 0.1657097866492612, 0.10387719741889409, 0.20251900862370217, 0.18424867971667222, 0.13543910453362124, 0.16430136508175305, 0.09413898496755532, 0.10532058389591319, 0.08513514418154955, 0.16521437466144562, 0.24459054108176911, 0.22157121343272074, 0.133047757138099, 0.22835108105625423, 0.2612863023366247, 0.15371499742780412, 0.25815901585987633, 0.21341649815440178, 0.16808638269347803, 0.20616039394267968, 0.13693911475794657, 0.21330310138208525, 0.2485839639391218, 0.25677662289568354, 0.24328303124223435, 0.1520103139004537, 0.34544277510472704, 0.19865845649370126, 0.1781789804143565, 0.12075334042310715, 0.23683309448616846, 0.2697461412421295, 0.1469955737037318, 0.16660144951726708, 0.14244356724832738, 0.1589605209550687, 0.14803240235362733, 0.08264523278921843, 0.1510525888630322, 0.10161580983549356, 0.26102607058627264, 0.1292930564710072, 0.215403126552701, 0.07550914785159485, 0.1483424657157489, 0.09381976138268198, 0.10265453838344131, 0.22033002360590867, 0.12075760162302426, 0.14939019163804396, 0.15351933506982668, 0.13913842317249092, 0.054610829068613906, 0.13618425812040055, 0.16398011946252414, 0.12880015506276063, 0.06923532485961914, 0.1398151668586901, 0.11892433570963995, 0.11872450714664799, 0.10688200832477637, 0.15573760175279208, 0.1560875086912087, 0.06828016468456813, 0.07665596024266311, 0.14314790016838483, 0.14926549047231674, 0.1748125646263361, 0.10338667766856295, 0.15127506692494663, 0.10451993292995862, 0.12974745780229568, 0.14643051688160214, 0.11093182422752891, 0.14183859899640083, 0.1210011142705168, 0.10134375800511666, 0.11690354985850197, 0.13985123778028147, 0.13006816059350967, 0.16591629199683666, 0.14653658547571727, 0.10213587978588683, 0.11647466144391469, 0.10313732283455984, 0.19000967272690364, 0.16668315870421274, 0.06094790170235293, 0.1241817878825324, 0.12322520278394222, 0.09212585977677788, 0.1863579193928412, 0.23979859107307025, 0.052148347454411645, 0.14420205860265664, 0.0897832719076957, 0.1106227854532855, 0.08119354104357106, 0.06810170318931341, 0.13014999191675866, 0.23073078479085649, 0.3110765777528286, 0.1406969909689256, 0.10131136474332639, 0.1386519814176219, 0.1357799055320876], [0.027273643828396286, 0.029804151970893145, 0.018072288283812146, 0.029665802073265825, 0.03613270899014814, 0.044179733975657394, 0.01841008846115853, 0.02068368119320699, 0.0363464882331235, 0.013379778430264975, 0.022441495708855133, 0.03566556137853435, 0.025545348978734443, 0.06954760703125171, 0.023562747685770904, 0.02221395747203912, 0.06785242977951254, 0.023691226595214436, 0.03479919768869877, 0.03138979670724698, 0.0165585886154856, 0.08483763371727296, 0.034826264450592656, 0.05509962873267276, 0.09779495200408356, 0.025290630325408917, 0.044066198103662045, 0.010607669412690614, 0.01649419733855341, 0.023500644768189107, 0.03681623124118362, 0.002721363079867193, 0.04220513939591391, 0.035991271758185964, 0.03810492869732635, 0.012332473199681511, 0.050703800682510645, 0.027604341440434967, 0.024593578086101582, 0.023752751061692834, 0.049826692390654764, 0.03624290307717664, 0.052425091354442496, 0.007691350499434131, 0.02780849396783326, 0.016248508289988552, 0.027834905943434154, 0.04084045958838292, 0.04606642434373498, 0.10769727493503264, 0.06371034668492419, 0.01291115754949195, 0.007766955415718257, 0.07745930499264173, 0.008491127003383423, 0.03096858930907079, 0.009334075297894222, 0.006937555345107934, 0.04266186810231634, 0.06457644235342741, 0.04829862813598343, 0.05189765929909689, 0.048389636645359654, 0.02659236074292234, 0.10821104129510266, 0.040640973685575385, 0.049451988389981646, 0.06582491964633976, 0.018893471719431024, 0.03247204988396593, 0.002458742886249508, 0.08513451314398221, 0.07483686892581837, 0.04694267089611717, 0.12013682350516319, 0.007469996261144323, 0.02619132279817547, 0.026611028937622905, 0.20195704592125757, 0.12261515909007617, 0.32021329605153626, 0.24645974220974104, 0.21994696344648088, 0.18157541459160192, 0.06729916589600698, 0.1983968133905104, 0.1803361110921417, 0.15184310930115835, 0.10227012793932642, 0.12042765718485628, 0.1381532988910164, 0.055550956300326755, 0.26904953005058424, 0.37839941095028606, 0.3194439730473927, 0.20219978503882885, 0.26267955186111586, 0.14988012106290885, 0.07486254469092403, 0.021194439946806858, 0.0487403815745243, 0.13509907706507615, 0.05595102733267205, 0.005965794386741306, 0.06375160161405802, 0.0340909665849592, 0.004091208235227636, 0.01950580207630992, 0.020978172176650593, 0.13519753249628202, 0.031396205470498116, 0.045549394230225256, 0.027882091268630962, 0.019685205038903014, 0.043270249385386705, 0.01131984026038221, 0.053045133261808326, 0.010875749268702098, 0.03175263652311904, 0.019005531777760813, 0.11093489799116339, 0.05006154014595917, 0.037955572961696556, 0.0047436959908476895, 0.058219050988554955, 0.03889562894723245, 0.056630624258624654, 0.034153123785342486, 0.07351971710366861, 0.01906767880011882, 0.018581712019762824, 0.05146862839215568, 0.056826798910541196, 0.01607684401928314, 0.022108121276167885, 0.02479143550486437, 0.044761635429624996, 0.05121406240920935, 0.017833520292437503, 0.01492185697757772, 0.025803746988198588, 0.0416519026538091, 0.03129707828962377, 0.021547076292335987, 0.039597254512565475, 0.006871309547152902, 0.037692297981785874, 0.021893839917278717, 0.050564707789037905, 0.022064303181001117, 0.020999635935627987, 0.03848199399986437, 0.06478678142385823, 0.04447866597079805, 0.03781064466706344, 0.02130871542197253, 0.01905459155594664, 0.0185862666860755, 0.016404340642371347, 0.037503539717623165, 0.05148437718993851, 0.040455411321350505, 0.01218698256915169, 0.026520948324884688, 0.007660765533468553, 0.018750460286225592, 0.03288806648924947, 0.032728688791394234, 0.026401797575610023, 0.05805830604263714, 0.03360859604020204, 0.0754658505320549, 0.004960562992242298, 0.07106832614434616, 0.03034531757501619, 0.017728187908817614, 0.0230194514816893, 0.015296174213290215, 0.07455822173506021, 0.020531377222921168, 0.003804702760784754, 0.023345312835382562, 0.039047454550330124, 0.010874007978210492, 0.0314925540504711, 0.028695144158388888, 0.017183850153482387, 0.04343836661428213, 0.015004589056063975, 0.06538340369505541, 0.025051087107775465, 0.035308207518288066, 0.018275266945628182, 0.018051579395042996, 0.08583151110048805, 0.034206887507545095, 0.03703735223306077, 0.026189735026231835, 0.01303410979120859, 0.018125468465898718, 0.0418456379723336, 0.015112435411927956, 0.036689949088862965, 0.06437351288540022, 0.03720176126807928, 0.026076326379552484, 0.03727179626002908, 0.038110601250082254, 0.024214414414018393, 0.030269871266292672, 0.0968804903594511, 0.08053727554423468, 0.05550156234364424, 0.04246149331863437, 0.04867804456236107, 0.06440144817211799, 0.03686444115425859, 0.06935469952544995, 0.043224879141364775, 0.03563881013542414, 0.02401156128118081, 0.034520201052406004, 0.05824078446520226, 0.037933683421994956, 0.028326911685456122, 0.11574552128357546, 0.032431687228381634, 0.015683426022795693, 0.024837728556511656, 0.03981203120201826, 0.029144989127027135, 0.07328478113881179, 0.049808755317436795, 0.024063453943069493, 0.043770322908780405, 0.021545968583918045, 0.04277157364413142, 0.04035295592620969, 0.040863031055778265, 0.05315253517723509, 0.016854333192376152, 0.0396592963619956, 0.05663070907550199, 0.06783565639385156, 0.03096575303269284, 0.056131432830755196, 0.040539929643273354, 0.025474460728998696, 0.08648958828832422, 0.048103912334356985, 0.03826512063720396, 0.009070162495066012, 0.04259631822683981, 0.10625150680009808, 0.10446598261062588, 0.17085762827524117, 0.2000818465437208, 0.11903151710118566, 0.027439501535679613, 0.0348773445667965, 0.03904687440288918, 0.06260596308857203, 0.043513521152947626, 0.04787952758904014, 0.04176768786939127, 0.1340080334671906, 0.05521980746250067, 0.0364836473017931, 0.07489150456551995, 0.09500420532588448, 0.1910490390977689, 0.2618194951542786, 0.14892935779477867, 0.1234390770218202, 0.15074623030211243, 0.036272073297628334, 0.10970113133745533, 0.047757917150322876, 0.025586690421083143, 0.048648677566753964, 0.009656217431516519, 0.04990796731518848, 0.03869872147749577, 0.02661712048575282, 0.07348914231572833, 0.05275130385000791, 0.020304931427485177, 0.03188623667561582, 0.01946560396546764, 0.014224204234778881, 0.03181534333686743, 0.005066498423860009, 0.025066364323720336, 0.07837016361632518, 0.03586957650259137, 0.06585594905274254, 0.021958346545164074, 0.05010591294350369, 0.0352867556336735, 0.024973530555143952, 0.02853627536179764, 0.053995065324540646, 0.021472841168620756, 0.01940255788420992, 0.025482058624870012, 0.05035212955304554, 0.049100917764008045, 0.06215945311955043, 0.035255353033010445, 0.025150448383231248, 0.018157217119421278, 0.05043316359764763, 0.01880359127452331, 0.017037817543106418, 0.020250613002904823, 0.034704793111554215, 0.053158753950681, 0.06506018353892223, 0.07430938258767128, 0.022312448526333486, 0.016517764556088617, 0.04126874749947872, 0.04066672748220818, 0.06135342137089797, 0.02444393397308886, 0.0862525352942092, 0.021928043171231235, 0.01040995363811297, 0.02943536140290754, 0.08814638081405844, 0.034446084672319036, 0.04170461464673281, 0.021544421524075524, 0.011477072091240968, 0.08475676591375045, 0.11862812803259917, 0.10290100944361516, 0.07755165360867977, 0.05251297860273293, 0.03725629173485296, 0.01036956044845283, 0.014876135591683643, 0.011321061623415776, 0.018268915857853632, 0.03374924956421767, 0.041298168777887306, 0.03019892703741789, 0.03147278832537787, 0.02123636832194669, 0.04637931380420923, 0.007542244125423687, 0.024942714887272035, 0.11828649922141007, 0.07332966623029538, 0.1401787937751838, 0.08944603321807724, 0.11406347368444715, 0.11062068878007786, 0.1022732559857624, 0.13433826289006642, 0.11175602035863058, 0.09255316720477172, 0.11652434377798013, 0.10149783973715135, 0.06612745805510453, 0.13504651774253162, 0.08405202587268182, 0.07432735698031527, 0.16245889823351586, 0.11001208358045135, 0.25676077231764793, 0.1427533184843404, 0.2001073866018227, 0.14435491897165775, 0.12731560186616012, 0.09325713371591908, 0.23814671114087105, 0.09212807858628885, 0.10296713268118245, 0.13923117890954018, 0.1498225134398256, 0.09859054788414921, 0.15556646165038857, 0.08219412913812058, 0.11474259224321161, 0.10925327786909682, 0.18606690929404326, 0.14593594627720968, 0.1098424701818398, 0.13305967221302645, 0.16218356229364872, 0.11337206685649497, 0.0994965210556984, 0.2206607958567994, 0.12181389065725462, 0.1560042660151209, 0.18048393673130445, 0.15516297758689948, 0.16735680827072688, 0.18014241648571833, 0.1933118583900588, 0.2271980872111661, 0.14357419657920087, 0.08255401732666151, 0.11616271175444126, 0.12540876918605395, 0.13415383707199777, 0.11530817832265582, 0.2368129827082157, 0.09537949625934873, 0.19323781664882386, 0.1517295768218381, 0.15844311086194857, 0.12839561248464243, 0.11042482286159482, 0.18982421553560666, 0.26534614020160263, 0.1378601174801588, 0.09999148521040167, 0.17117495196206228, 0.06918687067393746, 0.0996858866087028, 0.15726524192307675, 0.24379125397120202, 0.18760239332914352, 0.11199493253869669, 0.23097375461033412, 0.1428533616874899, 0.0910961353885276, 0.30411236573542866, 0.29596164024301935, 0.28119973093271255, 0.5121245767389024, 0.39965631174189703, 0.41692736212696346, 0.23551942354866437, 0.08641260849045855, 0.2801968833165509, 0.23477892471211298, 0.20660564862191677, 0.11329416425100394, 0.26470785588026047, 0.1492685303092003, 0.15278407452361925, 0.22960026402558598, 0.5479607794966016, 0.44973599591425484, 0.43751544452139307, 0.4319997419204031, 0.3445848082857472, 0.27692658879927223, 0.17231004605335848, 0.27103180225406376, 0.2601866956268038, 0.14804093832416193, 0.1000342939847282, 0.19071669264563493, 0.09027116572750465, 0.10228914049054895, 0.10014224212084498, 0.13692882816706384, 0.1894153303333691, 0.07781630262200322, 0.12900157139769622, 0.16638543110873016, 0.10569013442311968, 0.09551334407712732, 0.05706987051027162, 0.23350447309868677, 0.17080136415149483, 0.07479142065026931, 0.14466381525354727, 0.19216700696519443, 0.0755085235993777, 0.11323695017823152, 0.0890267596447042, 0.13251303083130292, 0.13479649115886005, 0.1334888320416212, 0.11018829233944416, 0.14349996484816074, 0.10087754337915353, 0.11196895821818284, 0.20339794217475823, 0.14565581988011087, 0.10893904151661055, 0.051871118401842456, 0.11975665390491486, 0.10258294615362372, 0.1384773129331214, 0.09058037413550274, 0.11731846045170512, 0.1385031244052308, 0.12600316586238997, 0.15264546339000973, 0.14746741338499955, 0.14525751982416424, 0.10410181965146746, 0.07529578251498086, 0.09605132735201291, 0.10579390278352158, 0.18136823070900782, 0.11931264773011208, 0.15789047123066016, 0.0929084617112364, 0.13912133766072138, 0.11132262647151947, 0.08268895080046994, 0.10258027272565023, 0.08699575505618538, 0.14833843521773815, 0.18075009887771948, 0.1661192961037159, 0.15275291619556292, 0.15694626261081013, 0.11784066100205694, 0.07272969199610607, 0.10586524395538227, 0.10343449403132711, 0.08575672297073261, 0.14889286618147576, 0.10748106653669051, 0.08464025466569833, 0.18551127053797245, 0.14397363657397882, 0.20424199902585574, 0.09196933531867606, 0.09666519798338413], [0.02364153408312372, 0.05197682737239769, 0.04631540598347783, 0.060863926208445, 0.04125164502433368, 0.015056013528789793, 0.07411563369844641, 0.042265277954616716, 0.014359614379437906, 0.02411340769114239, 0.040482647716999054, 0.032748983773802004, 0.04470361390018037, 0.052352990223360915, 0.010525007732212543, 0.0634162017543401, 0.008876391553453036, 0.011409601961661662, 0.05418354199667062, 0.025619285547041466, 0.09727877005934715, 0.021742097434720824, 0.08043607883155346, 0.005557236153565879, 0.01930574620408671, 0.029093827586621046, 0.09916815760412387, 0.04298352762790663, 0.03439129296956318, 0.03553487214126757, 0.022280844061502388, 0.02507329046992319, 0.007516973784991673, 0.08020238458578076, 0.01111266655581338, 0.03092009441128799, 0.04125346689085875, 0.012415532671314265, 0.03869294375181198, 0.05430463674877371, 0.01827383693307638, 0.01116748879264508, 0.025611294100859334, 0.012580146115007145, 0.05101546538727624, 0.048496292172265906, 0.029923492709973028, 0.04760891764557787, 0.12313338342521872, 0.10418912675231695, 0.012766009579146547, 0.06688816366451127, 0.03262517488162432, 0.01753648989168661, 0.08087097906640597, 0.026101462709318315, 0.01709467199231897, 0.03687038851369705, 0.11572775723678724, 0.05744620638766459, 0.07485898916742631, 0.012072718968348843, 0.09143802882837397, 0.03748072058494602, 0.0485032709049327, 0.03305604801114116, 0.043690849494721205, 0.043667300936899016, 0.007903447823732026, 0.05245964575026717, 0.07830797588186604, 0.06614647060632706, 0.28675856121948784, 0.03161222727171012, 0.11802651174366474, 0.37181156873703003, 0.5601340234279633, 4.883336407797677, 8.0191114119121, 7.825538941792079, 15.136562040873937, 18.18154580252511, 24.158398389816284, 30.40594584601266, 34.85347386768886, 31.11591625213623, 19.87777999469212, 21.914357798440115, 34.39414235523769, 37.633583613804404, 36.15104300635201, 31.445847988128662, 22.66999176570347, 24.701681511742727, 14.37203437941415, 7.192705699375697, 13.198838864053998, 3.192930234330041, 0.9992492092507226, 0.2772729130727904, 0.23375778379184858, 0.33942900065864834, 0.037381885174129686, 0.0572126546342458, 0.05141475610435009, 0.04032953968271613, 0.02586240803689829, 0.03715025706748877, 0.040369875196899684, 0.08368631585368089, 0.016030997104410614, 0.020926240498998334, 0.040109863970428705, 0.007904524998074132, 0.0114148919903008, 0.034274330495723655, 0.03289098758250475, 0.03130697472287076, 0.06848818995058537, 0.06479077799511807, 0.09595350295837436, 0.025562415830790997, 0.060888665595224926, 0.061168900557926724, 0.02537982036093516, 0.04067874773006354, 0.03965667721682361, 0.00448657532355615, 0.011716130156336086, 0.036074935125985315, 0.05227992896522794, 0.033174771283354075, 0.08493153617850371, 0.01588581096647041, 0.03368084644898772, 0.003938430986766304, 0.028099529511694397, 0.010510563418003065, 0.02494626701809466, 0.0884154878024544, 0.02822747577114829, 0.011719923167090331, 0.07368918122457606, 0.0556669009716383, 0.04236672572525484, 0.05224443140572735, 0.04137191196371402, 0.01866305649413594, 0.0058293083399933365, 0.017127755663490722, 0.010829044855199754, 0.03595513298309275, 0.04882889646770699, 0.07156118005514145, 0.05341566087944167, 0.09328440403831856, 0.043724168956811936, 0.033713684151215215, 0.05323995762903776, 0.039628762286156416, 0.055316831184817214, 0.015303112233855894, 0.012647054756858518, 0.021827949077955315, 0.02659872031238462, 0.01619189980972026, 0.01299477766068386, 0.019226522151646868, 0.04758686865014689, 0.022764091612771153, 0.011162468481675854, 0.06191732468349593, 0.020230068658877696, 0.05174454447946378, 0.04828337806143931, 0.036228843831590245, 0.03834993412185993, 0.08074051713837044, 0.09900722266840083, 0.017357232814122523, 0.05784921547664063, 0.05209945561364293, 0.04484633356332779, 0.03224332929987993, 0.038600812266979895, 0.005377551174855658, 0.05346426434282746, 0.06893355319542543, 0.009902187223945345, 0.009065646844516908, 0.02105340813951833, 0.09980563446879387, 0.021472915807472806, 0.03670174202748707, 0.004703488974233291, 0.035142865497618914, 0.035861335694789886, 0.054579528248203654, 0.042076536653829474, 0.016831687086128762, 0.034900811700416465, 0.054407845317785225, 0.04616586025804281, 0.04807292024738022, 0.03826509349580322, 0.03674450669703739, 0.032762042180235894, 0.03445538060207452, 0.02685452631807753, 0.027660132286005785, 0.04715533394898687, 0.03271115205383726, 0.0376112096543823, 0.03069598786532879, 0.01910519669763744, 0.051147901852216036, 0.04503848110990865, 0.028850640635937452, 0.01761905912176839, 0.025692703036059226, 0.00419579168582069, 0.047633154916443994, 0.027656773537663475, 0.023620993131771684, 0.021268761583736966, 0.0068023127137816376, 0.008141165782165314, 0.06813649167971951, 0.03898638979132686, 0.03418147637109671, 0.07127894341413464, 0.02998081874102354, 0.03276430170184799, 0.047779521705316644, 0.06520155631005764, 0.04553698721740927, 0.05185111179681761, 0.01855253501396094, 0.1169329575662102, 0.06239264524940934, 0.0565394325447934, 0.057991775684058666, 0.034356477337756326, 0.018547486713422195, 0.04387391824275255, 0.055929612767483504, 0.11741108048175063, 0.15308622616742337, 0.1597830139632736, 0.049856198485940695, 0.06497471526797328, 1.0237291242395128, 1.7518518077475684, 12.140814082963125, 17.071902854102, 15.19075277873448, 26.061843497412546, 34.62516301018851, 43.47793231691633, 49.703143051692415, 58.27660519736153, 50.808931486947195, 35.67138801302229, 39.195170402526855, 54.59730475289481, 60.53420693533761, 58.89279924120222, 53.144127232687815, 43.6626432282584, 45.63091502870832, 32.59280102593558, 20.29922992842538, 28.600251470293315, 10.86436138834272, 4.399197220802307, 0.5283834700073514, 0.09177652959312711, 0.32445080152579714, 0.12155293965978281, 0.024384014241929566, 0.02098789727980537, 0.022064650930198174, 0.016056448952960115, 0.05633526135768209, 0.007218275884432452, 0.10355954803526402, 0.02033307875639626, 0.062235347261386256, 0.025381659190835695, 0.013703335309401155, 0.022667469922453165, 0.07612489802496773, 0.029932893812656403, 0.05084604537114501, 0.06998477357306651, 0.07631946794156517, 0.012164395834718431, 0.03191681146355612, 0.05519656424543687, 0.08696467136698109, 0.025416123680770397, 0.04832272630717073, 0.017580721893214753, 0.009261741768568754, 0.032766015002770085, 0.013642168770145093, 0.023644478925104653, 0.04970885121396609, 0.016740481801597134, 0.012818524796914841, 0.04347706346639565, 0.04786800606442349, 0.029165100904979875, 0.005403655265191836, 0.021775399933436086, 0.025390186679682562, 0.03976574493572116, 0.05434187814327223, 0.034822759817221334, 0.0191628484254969, 0.0647051672318152, 0.01815631127517138, 0.027487353521532247, 0.01298106786063207, 0.0017547604719376458, 0.016309403415237154, 0.015353283113134759, 0.0138263604936323, 0.02761621241058622, 0.09772900518562112, 0.03424744015293462, 0.033736937546304295, 0.0504884540236422, 0.038303359478179894, 0.052555929869413376, 0.017627790171120847, 0.08632313007754938, 0.024190183928502456, 0.024743978765660098, 0.05527343208502446, 0.02408946049399674, 0.02915279906509178, 0.05251928897840636, 0.024118177792323486, 0.03663687747237938, 0.0741825576073357, 0.016796354071370194, 0.03423057855772121, 0.02644884040845292, 0.02043207871195461, 0.01906870169165943, 0.04716297425329685, 0.09240614902228117, 0.1830688023141452, 0.17350101071809018, 0.18848705371575697, 0.12778753654233047, 0.10169658264411346, 0.22026457211800984, 0.10913226114852087, 0.22473491009856972, 0.06821935437619686, 0.13379352140639508, 0.18636512543473924, 0.08641748037189245, 0.20305783328201088, 0.08328667229839734, 0.28169839988861767, 0.08439732555832181, 0.11457951313682965, 0.07569361438176461, 0.1254220549017191, 0.1301130253289427, 0.09534143723015275, 0.17123716005257197, 0.08246147872081824, 0.06024703609624079, 0.1718538398189204, 0.19568736877824577, 0.15121527441910335, 0.11886546601142202, 0.10749057281230177, 0.0962674068287015, 0.18265583233109542, 0.13985935305910452, 0.14564524830452033, 0.18113819376698562, 0.17924024989562376, 0.07381298672407866, 0.11451870282845837, 0.10298794335020439, 0.19051002444965498, 0.0912771617461528, 0.09708664286881685, 0.11413355278117315, 0.13762609075222695, 0.0826007683894464, 0.13475507338132175, 0.11562132223376206, 0.14376662911048957, 0.2076843021703618, 0.23774984957916395, 0.09162822219410113, 0.13001386422131742, 0.13301617811833108, 0.15664781576820783, 0.260482699743339, 0.13355649555368082, 0.164355905726552, 0.12512747570872307, 0.21101027727127075, 0.12391363084316254, 0.12810458881514414, 0.1044597468738045, 0.26855072538767544, 0.18196621005024227, 0.14604463401649678, 0.12252021847026688, 0.12713675360594476, 0.13566722800689085, 0.09562456275203399, 0.21929232643118926, 0.20761901353086742, 0.19983116856643132, 0.3472005064998354, 0.11090344110769884, 0.19763194157608918, 0.7465009401951517, 1.4885711010013307, 11.01100138255528, 16.02736278942653, 13.75806028502328, 24.478587014334543, 32.91989094870431, 42.14574030467442, 49.04393965857369, 57.90911149978638, 50.82884502410889, 35.98943485532488, 39.955119201115195, 58.620756421770366, 64.80484076908657, 60.47136742728097, 54.25922277995518, 43.45357193265642, 44.012957504817415, 31.375243868146622, 18.296392577035085, 25.214538472039358, 8.873893567493983, 4.380994243281228, 0.4409865311213902, 0.27165407314896584, 0.5445294007658958, 0.23538944338049206, 0.20293926607285226, 0.07502863649278879, 0.16398652483310017, 0.13922786765864917, 0.19367445393332414, 0.2061293577509267, 0.19094113845910343, 0.08754443204296486, 0.10590788309595414, 0.12184727458017212, 0.12603230215609074, 0.09745031728276185, 0.16655065438577107, 0.1207119904990707, 0.12958494866532938, 0.16440276535493986, 0.1499163005501032, 0.14059863053262234, 0.1336241862071412, 0.19472825952938624, 0.1375331857374736, 0.10365663961108242, 0.1435111199638673, 0.12948576041630336, 0.12187523022294044, 0.05196215744529452, 0.1112914342167122, 0.12525525742343493, 0.13603559109781468, 0.14509496997509683, 0.14095179443912847, 0.10959984641522169, 0.16138215815382345, 0.10740464313754014, 0.10872041753360204, 0.1494812374668462, 0.17496686348957674, 0.10441605600395373, 0.10951599984296731, 0.12267571155514036, 0.11209530822400536, 0.18793887884489127, 0.10303391409771782, 0.11167907448751585, 0.07651835334088121, 0.12830529947366032, 0.12789675353893212, 0.09561547716813427, 0.09842476142304284, 0.1256676031542676, 0.202778249712927, 0.16871538465576513, 0.11800488004727022, 0.1277697453541415, 0.09863199280308825, 0.14887457287737302, 0.10726415246192898, 0.11721146904996463, 0.12142350231962544, 0.07039112783968449, 0.11925084676061358, 0.09638374844299895, 0.10887784444327865, 0.13937648039843353, 0.13125985807606153, 0.1426053707088743, 0.11383216788194009, 0.11260623830769743, 0.19254172114389284, 0.10010564194193908, 0.1293238891022546, 0.08812863712332078, 0.1099431783493076], [0.055676987394690514, 0.027859955759985105, 0.027682978560083678, 0.04364583548158407, 0.013598934215094362, 0.04890204593539238, 0.015230176504701376, 0.06068937986024788, 0.033502995635249784, 0.04568118269422224, 0.0424742837037359, 0.0411079550561096, 0.020389202084126215, 0.012672102877071925, 0.03451615019834467, 0.017799335698197995, 0.030279794840940406, 0.007598466688900122, 0.061030011224959574, 0.01586010636362646, 0.02107393043115735, 0.028860961153571094, 0.06803399217980248, 0.06424807890185288, 0.03049232897215656, 0.01371763034590653, 0.04475500274981771, 0.02372390653805009, 0.04359587494816099, 0.029630189162812064, 0.010248262984012919, 0.0669006012114031, 0.007927502738311887, 0.07006638776510954, 0.04342222426618848, 0.02247515783113028, 0.023292707711724297, 0.011020564756888365, 0.043736850776310475, 0.01835094395625804, 0.05105734456862722, 0.048438104401741705, 0.03589423107249396, 0.043553849881781, 0.04672579074810658, 0.06832699038620506, 0.008635068029564406, 0.028096186030390005, 0.03787620472056525, 0.045585424439715486, 0.006929762794503144, 0.030101319774985313, 0.007127837344471897, 0.05395152033971889, 0.06343492253550462, 0.054679466278425286, 0.024619014667613164, 0.03923413310466068, 0.02769014049720551, 0.05132169841921755, 0.025275349716788957, 0.027481796319729516, 0.060129656323364804, 0.04319222803626742, 0.055269313377461264, 0.07795108681810753, 0.10742158615695578, 0.13404147167290958, 0.17175868206790515, 1.1958716128553664, 2.9517992990357533, 9.076833946364266, 17.583609887531825, 15.985364403043475, 27.634863546916417, 42.90878799983433, 63.96786771501814, 92.45114626203264, 96.71294893537248, 95.59329536982945, 105.48334039960588, 107.434401512146, 111.97124862670898, 109.14116396222795, 114.76063769204276, 108.91366604396275, 108.51860536847795, 111.6815573828561, 110.29805987221854, 110.7973643711635, 110.53187370300293, 118.88748550415039, 116.91906084333147, 112.75208718436105, 100.75853756495884, 99.71140929630825, 105.48613357543945, 84.53524426051548, 60.36598409925188, 38.76892621176583, 23.727610077176774, 12.278147833687918, 3.0612861897264207, 0.21238215294267448, 0.04731068793418152, 0.022762108594179153, 0.0675866272566574, 0.03532048560945051, 0.09866285936108657, 0.10393521894833871, 0.047701215371489525, 0.0057565914383823314, 0.10052672041846172, 0.0138649784660499, 0.03848655375518969, 0.03482045279815793, 0.003030601385814537, 0.07351536769419909, 0.11766709174428668, 0.032244113007826466, 0.03759703505784273, 0.038887432244207175, 0.028875064503933703, 0.026033007007624422, 0.0529094500068043, 0.001881423027953133, 0.010663245671561785, 0.058056372217833996, 0.04489064868539572, 0.011426362624791051, 0.02829178562387824, 0.025858689664996097, 0.07193668811981167, 0.01971957623027265, 0.02709686170731272, 0.03741987295714872, 0.006636408357215779, 0.01928907968769116, 0.050345008328024826, 0.023381665349006653, 0.11609317548573017, 0.03900167379262192, 0.022080499811896255, 0.02702215839443462, 0.005721712193917483, 0.06090448224650962, 0.020340218641129986, 0.03784333987693701, 0.017786019448457018, 0.02259561645665339, 0.02863582323438355, 0.030213240733636276, 0.07298317232302257, 0.018658076047099063, 0.017392248613759875, 0.01184676680713892, 0.03190229081415704, 0.011744025579121496, 0.05857726998095002, 0.0634147496894002, 0.06653638396944318, 0.028897642756679227, 0.047669005314154286, 0.06368828751146793, 0.04361821571364999, 0.052052528131753206, 0.018445463884355764, 0.08569325959043843, 0.011085543814780456, 0.02770161791704595, 0.040561914177877564, 0.05138330939891083, 0.021325580409861038, 0.04946376097255519, 0.03627568988927773, 0.010608649047623788, 0.045179185524050675, 0.04195053270086646, 0.021252871989937763, 0.028722607863268683, 0.054218791890889406, 0.03956690364118133, 0.03314567570175443, 0.044043110949652534, 0.03071685620982732, 0.025389287620782852, 0.04964392898338182, 0.021815518316413676, 0.09337719370211874, 0.028257516212761402, 0.1075717866686838, 0.01851123258737581, 0.018958536442369223, 0.018675439758226275, 0.05130988512454288, 0.01766278900738273, 0.041378497146070004, 0.022561365705249564, 0.047802272984491925, 0.03772815516484635, 0.03552037863326924, 0.03372835747099348, 0.0365681893724416, 0.017864712547244768, 0.01934532854439957, 0.008883118379994162, 0.04935503591384206, 0.024317312553258877, 0.0313785940940891, 0.05129872661616121, 0.011375521692181272, 0.03859102439933589, 0.03192118462175131, 0.07452501423124756, 0.0245444691141269, 0.06008964989866529, 0.026961758599749634, 0.04157724005303212, 0.019850535185209343, 0.04614705466000097, 0.01049653725099883, 0.08426022755780391, 0.04953892229657088, 0.094483436484422, 0.011430788369450186, 0.006133827222843787, 0.04264846703569804, 0.0162652765866369, 0.02943254548258015, 0.024417072468038117, 0.11654677614569664, 0.03796048894790666, 0.007430616633168289, 0.04891791008412838, 0.06357286870479584, 0.06576818733343057, 0.05586440894486649, 0.06859370893133537, 0.10666623418884617, 0.07648144103586674, 0.03556585405021906, 0.0986700721883348, 0.2263109433863844, 0.06975261281643595, 0.6409671945231301, 3.729436908449445, 7.430307166916983, 19.10748185430254, 31.025165830339702, 27.396870374679565, 43.263684613364084, 67.3557676587786, 88.23206806182861, 113.76211207253593, 119.79492024012974, 116.25579275403703, 128.53041785103935, 126.55558695111955, 126.56077030726841, 120.22238731384277, 131.21925953456332, 126.97457722255162, 127.03847285679409, 131.02526582990373, 125.76832825796944, 126.75620923723493, 128.49930381774902, 132.78603662763322, 134.04250717163086, 129.42537362234933, 123.4329970223563, 123.12603950500488, 128.6211335318429, 114.16282163347516, 94.88282121930803, 66.67815848759243, 45.658964906420024, 25.1415684904371, 9.124351808003016, 1.9133964478969574, 0.5678470666919435, 0.013713640559996878, 0.045847030223480294, 0.038074832276574204, 0.012290682227882956, 0.07874417211860418, 0.08426298240997962, 0.1338045679564987, 0.11692264383392674, 0.01959673933950918, 0.027409298245662024, 0.024894443906045387, 0.02716390775250537, 0.07559094524809293, 0.07076949253678322, 0.0676281468144485, 0.03256710924740348, 0.0529116043554885, 0.05070139527586954, 0.07007972097822598, 0.023459301629502858, 0.05018294702417084, 0.02378448614451502, 0.0379661920347384, 0.03788795355441315, 0.02908683189057878, 0.04241352428549102, 0.031100968098534004, 0.06179617904126644, 0.046878908960414786, 0.012084283749572933, 0.02615279218714152, 0.0323553452534335, 0.05943410364644868, 0.024857385716001903, 0.08994394221476146, 0.019386853191203306, 0.034276277891227176, 0.034086003101297786, 0.06884153027619634, 0.04331648476155741, 0.014119975318733071, 0.036575229173260074, 0.06201063681926046, 0.02172656576814396, 0.0037856503456298795, 0.026279532350599766, 0.04204282024875283, 0.037590344702558856, 0.020964023025174226, 0.02579093455070896, 0.04015548187973244, 0.014473179089171546, 0.02007109808203365, 0.04299373957993729, 0.036494568322918246, 0.06161418237856456, 0.015207491382690412, 0.019795521262234876, 0.04425341948600752, 0.079389974607953, 0.03660821615319167, 0.02939967724627682, 0.06592368720365421, 0.052070505917072296, 0.022220401858378733, 0.03804254758038691, 0.01945683390035161, 0.05724633711257151, 0.03469797722729189, 0.06163185143045016, 0.07856590061315469, 0.1456494687923363, 0.10604354260223252, 0.08717051853558846, 0.12903784587979317, 0.143144996038505, 0.09739602769591979, 0.06640738767704793, 0.16589357464441232, 0.07781719828822783, 0.12429973083947386, 0.134730157575437, 0.1232548819056579, 0.22746343511555875, 0.07252954452165536, 0.21054439512746675, 0.088659875760121, 0.12893327006271907, 0.12126039607184273, 0.11836499215236732, 0.1154543754777738, 0.1014107633382082, 0.16266270301171712, 0.20029899132038864, 0.11868464999965259, 0.1080004715227655, 0.1510750348014491, 0.0760792326182127, 0.16422793402203492, 0.16337752608316286, 0.08608406861977917, 0.10579756687262229, 0.12471579494220869, 0.05080992355942726, 0.1341778300702572, 0.08401332223521811, 0.10199177930397646, 0.18003771853234085, 0.12862384452351502, 0.15948406500475748, 0.13949255059872354, 0.09644702183348791, 0.13216544448265008, 0.08611300135297434, 0.14890734611877374, 0.05562611423166735, 0.1519226607467447, 0.23300013159002575, 0.13079717861754553, 0.13681947546345846, 0.20619134871023043, 0.1537444322769131, 0.16474918462336063, 0.1135412867047957, 0.21986880978303297, 0.3061670240546976, 0.19329427076237543, 0.06833164513643299, 0.20851248130202293, 0.174613604588168, 0.233282565006188, 0.1769932404692684, 0.10604459433151142, 0.3003355583974293, 0.16229663336915628, 0.1702097358980349, 0.12321279916380133, 0.30470361400927815, 0.24076455352561815, 0.5696465415613992, 3.0251579454966953, 7.298982739448547, 18.229823623384746, 29.072213070733206, 27.1411349773407, 44.451340198516846, 70.4172898701259, 92.32098565782819, 125.77162170410156, 132.7855780465262, 127.93032973153251, 141.48356928144182, 142.1002913883754, 146.0832211630685, 140.09323474339075, 145.12573160443986, 142.22515051705497, 144.519376209804, 147.2762129647391, 142.26144790649414, 142.09241213117326, 144.86201967511857, 154.18675231933594, 152.636164528983, 148.13180024283272, 141.90717315673828, 141.31636783054896, 146.9290392739432, 125.66639818464006, 105.36518628256661, 67.40683691842216, 45.50655269622803, 23.184495449066162, 7.182827532291412, 1.3490493191140038, 0.25033737985151155, 0.13857836036809854, 0.2484195413334029, 0.13046312225716455, 0.20725351385772228, 0.18443909021360533, 0.22941836235778673, 0.37670312768646647, 0.2016550571258579, 0.11233384720981121, 0.09351805757199015, 0.12079869370375361, 0.15775518491864204, 0.23813118625964436, 0.21648643485137395, 0.2554539952959333, 0.11264022612678153, 0.11096389179251023, 0.1512971735958542, 0.2352770236986024, 0.078689841819661, 0.12745528508509907, 0.09022216871380806, 0.18777802533337049, 0.1285280218081815, 0.2016992433262723, 0.10718933040542261, 0.09258011861571244, 0.17512086379740918, 0.10687735357454844, 0.05414392912228193, 0.07438647095113993, 0.0826891747170261, 0.17140570815120423, 0.19304192358894007, 0.10523850151470729, 0.15743251437587397, 0.10123456814991576, 0.10874831210821867, 0.08822082289095436, 0.11740736210984842, 0.1264340898820332, 0.12064744824809687, 0.08812449127435684, 0.06697341480425426, 0.17287297227552959, 0.0695972079411149, 0.09093751425721816, 0.1756756611700569, 0.1665884487863098, 0.09389660547354392, 0.1264995685113328, 0.11030938369887215, 0.09835706398423229, 0.17468341227088655, 0.19836366016949925, 0.15037948212453298, 0.13141019429479325, 0.15406607144645282, 0.09261269508195774, 0.2298624770981925, 0.11835077005837645, 0.07560502484972988, 0.22891345087971005, 0.07429995773626225, 0.12272115983068943, 0.17143967561423779, 0.21614567456500872, 0.23231641256383487, 0.14427517753626617, 0.10648713487067393, 0.24824656918644905], [0.05051734604473625, 0.03499332316485899, 0.04060294519045523, 0.018571608633335148, 0.03027694160118699, 0.062121360163603506, 0.06282336570854698, 0.06593980919569731, 0.035049743351659605, 0.06549592515719788, 0.036497258714267185, 0.01073511949341212, 0.0186658893778388, 0.04890131651024733, 0.05213677843234368, 0.02696622166383479, 0.03557480053443994, 0.01887929203387882, 0.04277450152273689, 0.0499834577286882, 0.03433918487280607, 0.04955314099788666, 0.09200471413454839, 0.018533142483127967, 0.030723193726901497, 0.05672815688220518, 0.04267250753140875, 0.05748598889580794, 0.015593998500012925, 0.09176499449781009, 0.01454799944934036, 0.0091789333548929, 0.014538423623889685, 0.034195365982928445, 0.013790983374097517, 0.03970180658091392, 0.02709654618852905, 0.004379591979419014, 0.020911383974765028, 0.029548629253570522, 0.025117846471922736, 0.06151191358055387, 0.01026937984196203, 0.01591399561480752, 0.06240193439381463, 0.09672814567706414, 0.06770056685698883, 0.030961854849010706, 0.05078247681792293, 0.04823171779779451, 0.05464872864208051, 0.02026171044313482, 0.022228255901219587, 0.019518319351066436, 0.04484840988048485, 0.0939346645027399, 0.019258699978568723, 0.03918612675209131, 0.02434766003196793, 0.09884196546460901, 0.04461392514141543, 0.052760908513196876, 0.333292655646801, 0.08002788573503494, 0.2517031079956463, 1.9878288081714084, 5.416745271001544, 16.458342177527292, 42.61931562423706, 69.5741468157087, 74.76210962023053, 96.10544013977051, 95.41137068612235, 100.73191206795829, 89.89519582475934, 89.75042315891811, 91.75219222477504, 77.24510397229875, 90.31406102861676, 86.44877120426723, 81.81838049207414, 83.78187888009208, 77.95092282976422, 88.6894610268729, 73.63970456804547, 87.84536606924874, 86.51359094892229, 80.73807457515171, 84.24082824162075, 84.27639607020787, 81.32365485600063, 86.7298605782645, 91.02670996529716, 85.0890087400164, 93.62217480795724, 89.23292827606201, 86.42737075260708, 92.13932500566754, 106.862870488848, 111.40805544172014, 111.64125783102853, 103.71145248413086, 89.29121671404157, 60.569072995867046, 47.562416962214876, 23.189826454435075, 6.252570569515228, 0.4719734883734158, 0.09561796739165272, 0.36056987196207047, 0.08150713278778962, 0.073524643267904, 0.018868706887587905, 0.10191053830619369, 0.04215990146622062, 0.06066292377987078, 0.05441501743293234, 0.014901222727660621, 0.013956818180823964, 0.07297687551804952, 0.03654157044366002, 0.021661911558892046, 0.03627571703067847, 0.08903326679553304, 0.03321609067331467, 0.02531722211278975, 0.023843803675845265, 0.03998453855248434, 0.033864461417709074, 0.019624269201553295, 0.06997638009488583, 0.05771500124995198, 0.04887956267754946, 0.02554069592484406, 0.02829061515097107, 0.032334276741104465, 0.01895583756933255, 0.040688895221267424, 0.011143141259838427, 0.014383369890440787, 0.055053484958729575, 0.011998473666608334, 0.054061660143945894, 0.018181143960516368, 0.04605933026011501, 0.02629659411364368, 0.06806608688618455, 0.06696517060377769, 0.08159703189241034, 0.03166119035865579, 0.016585935273074677, 0.019429158153278486, 0.060659904299037795, 0.007445536770059594, 0.05950233034257378, 0.07064470994685378, 0.023856821370178034, 0.056427090894430876, 0.033067667923335514, 0.1429754572787455, 0.06721225234546832, 0.02635841883186783, 0.023715063530419554, 0.029807208771152154, 0.08507731264191014, 0.0335013807219054, 0.0732305594054716, 0.03209666734827416, 0.05179474250014339, 0.016522319222401296, 0.0810228827010308, 0.06103892717510462, 0.02573485193508012, 0.0589123305731586, 0.024715616001880596, 0.044716176976050646, 0.10038825177720614, 0.052513779274054935, 0.034971057038222036, 0.016314884281850288, 0.04704690066033176, 0.023051612345235686, 0.0660546241062028, 0.06102976695235286, 0.025083580453480993, 0.041692468869898996, 0.05360915531803455, 0.05398214262511049, 0.07978801003524236, 0.0213834577506142, 0.08342017406331641, 0.02261248992622963, 0.08471796728138413, 0.018916116129340868, 0.03716017046411123, 0.02467274955207748, 0.021225881563233476, 0.018733127109174217, 0.04809824995962637, 0.021795559208840132, 0.03849166651655521, 0.03270639552335654, 0.022332412722919668, 0.02099352403144751, 0.020311172253319194, 0.0434813552003886, 0.07795779074409179, 0.029576669713216167, 0.03050298197194934, 0.050523815876139064, 0.02918874445770468, 0.03359184979594179, 0.04325061597462211, 0.01118522315352623, 0.03283131382028971, 0.053689290303736925, 0.02108632556961051, 0.04567198175936937, 0.013943864099149193, 0.028473171605063335, 0.0593126526634608, 0.036359682346561124, 0.01392240627735321, 0.050053319694208245, 0.03174252974401627, 0.017207546292671135, 0.011214981154937829, 0.07883648002254111, 0.052556754289461036, 0.028701193298080137, 0.014093413217259305, 0.016988213240568126, 0.013668515436750437, 0.03072282053264124, 0.0316481319522219, 0.025910390640742013, 0.027324664572786008, 0.030183799099177122, 0.3394317147987229, 0.04455185615058456, 0.7450302019715309, 6.316631657736642, 12.100784642355782, 27.532525266919816, 61.10533496311733, 90.85364423479352, 99.04172801971436, 114.59652124132428, 113.93011951446533, 122.43365151541573, 107.30769416264125, 107.11875874655587, 101.0914535522461, 91.23213345663888, 102.68960871015275, 95.84956577845982, 101.63086305345807, 97.92360305786133, 93.07605334690639, 108.21348912375313, 88.62527356828961, 107.21950067792619, 101.39301926749093, 92.91467448643276, 102.76419067382812, 100.51015336172921, 96.28978974478585, 96.98799337659563, 104.7318023954119, 95.67248398917062, 103.69336632319859, 100.15150819505963, 99.23903601510185, 102.34106622423444, 118.61358751569475, 123.99331365312848, 128.46969059535434, 126.40439414978027, 114.87368488311768, 87.7315754209246, 73.80084718976701, 42.698493821280344, 15.515339612960815, 2.725424600499017, 0.1496405303478241, 0.22889084209288868, 0.006403492730376976, 0.1580428159130471, 0.06620469569627728, 0.07563992869108915, 0.010908748122996517, 0.0653503793956978, 0.04663818169917379, 0.036295106168836355, 0.0799399475966181, 0.02145812544040382, 0.010826596191951206, 0.01937652419188193, 0.029442407989076207, 0.037086230503129106, 0.05295464043904628, 0.05408389573650701, 0.09111035748251847, 0.05949778415794883, 0.014751822887254613, 0.07152352814695664, 0.043457660757537396, 0.02711610835311668, 0.06699128063129527, 0.054758841304906776, 0.029917674272188118, 0.054677440851394615, 0.08812516980937549, 0.015980391962719814, 0.010298717999830842, 0.0241779635128166, 0.011607971674363528, 0.04382985757131662, 0.09719271824828216, 0.02810085435131831, 0.030924392930631126, 0.027271073877013156, 0.053329263015517166, 0.017421802206497108, 0.046759544472609244, 0.04473396816423961, 0.04930506859506879, 0.08293857026313033, 0.030862334117825543, 0.06139115470328501, 0.08987444665815149, 0.02669462445192039, 0.029149151939366545, 0.061390211539609094, 0.0732637872653348, 0.0298378615906196, 0.08986513715769563, 0.04685744011242475, 0.05062920593523553, 0.018334124769483293, 0.0157093036520694, 0.026028879818373492, 0.0444543404903795, 0.03897901411567416, 0.005666106249139245, 0.02818605799360999, 0.04023147101647087, 0.012202562581348633, 0.0321345499583653, 0.04336259800142475, 0.0207436195840793, 0.043085809996617694, 0.11527531008635249, 0.19353323722524302, 0.08457100338169507, 0.10915339751435177, 0.1040306616840618, 0.11744339231933866, 0.14353428514940397, 0.12232887159500803, 0.17338069288858346, 0.11389951248254095, 0.16813170883272374, 0.13173490044261726, 0.2154340948909521, 0.06866094496633325, 0.1675432561231511, 0.0810885988175869, 0.1002065400992121, 0.10824675937848431, 0.1764288078993559, 0.09471759213400738, 0.13899998845798628, 0.12168253984834466, 0.13394832238554955, 0.12088104071361677, 0.15108829337571347, 0.11361644802881138, 0.0853339752980641, 0.16375445228602203, 0.12187212253255503, 0.20151048845478467, 0.08763262802468878, 0.154995040169784, 0.10650285652705602, 0.12770380532102926, 0.19096184734787258, 0.10624166804232768, 0.05755701115620988, 0.05223078606650233, 0.16500678365784033, 0.14329622792346136, 0.07301299393709217, 0.10314003697463445, 0.12897037235753878, 0.10938175168952771, 0.13467455841600895, 0.11946658018444266, 0.17066215590706893, 0.2062764505722693, 0.12589427456259727, 0.17036035710147449, 0.21631313700761112, 0.10579739723886762, 0.1484923269599676, 0.13315948471426964, 0.09522246289998293, 0.1900772683854614, 0.1348400938191584, 0.19737664956067288, 0.12458301920975957, 0.17221545827175888, 0.16722148124660763, 0.2175553717783519, 0.4795631468296051, 0.22184646794838564, 0.6916571259498596, 5.728608216558184, 11.869673660823278, 26.0983475957598, 65.4152191707066, 96.67654732295445, 106.37088939121791, 125.76399258204869, 130.348566872733, 132.9710532597133, 121.43723814828056, 119.70498275756836, 117.97627094813755, 104.07601056780133, 112.06821073804582, 110.38760825565883, 105.77359444754464, 105.49452699933732, 100.6373679297311, 112.65258203233991, 99.0528381892613, 112.1054322378976, 112.20730672563825, 105.7554110118321, 110.54215008871896, 109.39705221993583, 106.02584879738944, 110.53062997545514, 116.66307531084333, 110.89171395983014, 118.30052947998047, 114.52045236315045, 113.10345063890729, 117.78837776184082, 134.12120246887207, 142.48716708592005, 144.20164898463656, 139.66490609305245, 125.7039601462228, 93.45630741119385, 75.15062509264264, 40.989563533238, 12.73883250781468, 1.9694738388061523, 0.17824034712144307, 0.577710143157414, 0.2706399347100939, 0.2629882038703987, 0.19050310339246476, 0.18078530127448694, 0.1344778782555035, 0.19589368413601602, 0.14048470450299128, 0.15596269895987852, 0.1481526116175311, 0.17347433072115692, 0.11915032858295099, 0.08879879901983909, 0.1641916459692376, 0.22488616912492684, 0.0877912152292473, 0.12454473626400743, 0.25514591325606617, 0.11613831163517066, 0.20575069449841976, 0.17906384436147554, 0.16042158326932363, 0.18767121035073484, 0.18676107775952133, 0.09112840651401452, 0.1346839086285659, 0.18680618676756108, 0.1430188428078379, 0.0705138680392078, 0.12778814722384724, 0.1754042607332979, 0.16489953441279276, 0.07801875711551734, 0.2258218146328415, 0.10971502094928708, 0.10972937875028167, 0.07185244799724647, 0.22491160061742577, 0.10546424333006144, 0.1490917990782431, 0.1642461187605347, 0.16289126074739865, 0.15438942052423954, 0.20970089467508451, 0.14346740873796598, 0.11199030492986951, 0.12232579104602337, 0.09643396681972913, 0.13301856656159672, 0.12891117696251186, 0.2091620293046747, 0.148685112329466, 0.194082769166146, 0.182776326579707, 0.11190656013786793, 0.15640978568366595, 0.12494998451854501, 0.22069346053259714, 0.08967452310025692, 0.12504960702998297, 0.09068454961691584, 0.19656152544277056, 0.10422755219042301, 0.1483178213238716, 0.10558667818882636, 0.11341492312827281, 0.1440982563155038], [0.025267298898792694, 0.052844320823039324, 0.04229699268138834, 0.08166441041976213, 0.025171559303998947, 0.07921913306095771, 0.022255151333021264, 0.008956731795998556, 0.04240435388471399, 0.024257462371938994, 0.05002951668575406, 0.010579625560369874, 0.03395256918988057, 0.04700868896075657, 0.07780188375285693, 0.024063330110428587, 0.012303512476916825, 0.06506991373108965, 0.008862776748303856, 0.042985763400793076, 0.02697443533023553, 0.03851399031866874, 0.0642315565741488, 0.04328447147937758, 0.04632314467536552, 0.01498420416776623, 0.058212503125624995, 0.02910610567778349, 0.053922421365444145, 0.015264459486518587, 0.007329824496991932, 0.0372269043831953, 0.04792261117004922, 0.03625300307092922, 0.031372368535293, 0.08224482248936381, 0.029578047139304023, 0.02008621414591159, 0.047796081352446756, 0.030853849037417343, 0.0632371770750199, 0.04802594526803919, 0.05017307433964951, 0.01591161056421697, 0.0970771840906569, 0.007967526126386864, 0.0384009022797857, 0.04431952915287443, 0.03413176689563053, 0.024103299215702072, 0.045938791906727214, 0.06275330018252134, 0.01991722669585475, 0.02383464514943106, 0.1425153019704989, 0.05528861091339162, 0.02371721957544131, 0.059631733755980215, 0.02332538426188486, 0.0772232630157045, 0.07702230808458158, 1.2273264335734504, 7.198642935071673, 22.4165266922542, 46.52408511298043, 66.10102721623012, 79.53536919185093, 84.99487454550606, 85.16789163861955, 83.05296421051025, 76.93693052019391, 76.69743306296212, 71.22389234815324, 45.8512875693185, 78.69320583343506, 61.558350563049316, 69.99315793173653, 64.75220816476005, 81.26301097869873, 73.61318329402378, 65.19351605006626, 79.59690938677106, 68.52296079908098, 62.39029312133789, 76.92944731031145, 53.667580195835654, 69.28767258780343, 67.20878546578544, 62.35851900918143, 75.3872320992606, 72.47490855625698, 77.16163526262555, 69.78371143341064, 66.86093085152763, 77.95844078063965, 85.16652284349713, 82.15249156951904, 84.6001056943621, 77.86666202545166, 87.97357422964913, 80.59640775408063, 94.95154585157121, 88.99341692243303, 97.65928663526262, 100.23327459607805, 112.24773829323905, 95.74643366677421, 67.01104668208531, 38.559559617723735, 16.5730482510158, 5.199823813779013, 1.560583968247686, 0.2916560641356877, 0.20241542346775532, 0.050537379791161845, 0.07439922740949051, 0.07017059717327356, 0.027376044940735613, 0.0981932927721313, 0.014178744933035756, 0.029250718453632932, 0.026102485600858927, 0.024007751307051097, 0.007320826274475881, 0.045303367610488615, 0.08255151353244271, 0.026970352245760814, 0.019883250751133476, 0.04431646895994033, 0.06403366862131016, 0.0715102424312915, 0.052128625834094625, 0.0690473367327026, 0.04948097201330321, 0.0385326873511076, 0.020977028845144168, 0.053824505369578085, 0.03561365684228284, 0.02164224422137652, 0.013004488344969494, 0.038224829227796624, 0.04139232908242515, 0.03900009619870356, 0.030836604069918394, 0.029551770870706866, 0.041306850633450916, 0.021098639283861433, 0.05506152899137565, 0.017975215367706757, 0.047183445654809475, 0.08386497412409101, 0.029679627224270786, 0.06700820329466037, 0.03771716629021934, 0.021766451752877662, 0.031597743941737075, 0.04740704329950469, 0.054853313735553196, 0.021214131033048034, 0.025449451624548862, 0.03875966410019568, 0.06110642783875976, 0.037731100006827285, 0.02461963383081768, 0.023854763712733984, 0.05798670702746936, 0.034278167611254115, 0.05585595439853413, 0.044367352300988774, 0.0376673346784498, 0.06462761067918368, 0.019837878810774003, 0.0070719468390702134, 0.02078064893638449, 0.06628981112901654, 0.06336219715220587, 0.05499744814421449, 0.05292073065148933, 0.09833000400768858, 0.01190260939100491, 0.03553357274670686, 0.016307310134704624, 0.0417443767988256, 0.04493757277461035, 0.007489317545800337, 0.027794427936896682, 0.06934387010655232, 0.025241010755832707, 0.02736448948936803, 0.04564747307449579, 0.11542488634586334, 0.026565380494243333, 0.03739817340725234, 0.030552006127046685, 0.03465854077200804, 0.016129148891195655, 0.027267939045227, 0.021003705449402332, 0.04791650774755648, 0.04794245831934469, 0.04017672002581613, 0.04259760744337525, 0.03436995643590178, 0.024094481653134738, 0.04774496730949197, 0.01044691089607243, 0.0018306516451827648, 0.039786274012710364, 0.05845619897757258, 0.04550897050648928, 0.035184941454125304, 0.05826962898884501, 0.014466025633737445, 0.013911810104868241, 0.01372585419033255, 0.009038342595366495, 0.07463399374059268, 0.05570959439501166, 0.0709612804598042, 0.019439897666286145, 0.06121341924050024, 0.06042648146727255, 0.01424468751065433, 0.021815793123096228, 0.006615373771637678, 0.022530263356332268, 0.026262099089633142, 0.02283962782738464, 0.05528916731210692, 0.0024561409164951848, 0.04237278165029628, 0.009811672348795193, 0.026052558994186775, 0.08489151618310384, 0.05321938444727233, 0.21143611227827414, 0.045415722831551514, 4.0553373864718845, 15.630504267556326, 37.535631384168354, 65.36192648751395, 88.43061978476388, 99.84997027260917, 102.86179896763393, 99.5259827205113, 96.97060898372105, 87.27491896493095, 93.86898177010673, 85.65986578805106, 65.2021735055106, 93.39059134892055, 86.82897663116455, 97.4259591783796, 90.97759314945766, 116.02575874328613, 95.9575685773577, 98.35289055960519, 107.19800989968437, 97.56317220415387, 90.22719464983258, 100.87412084851945, 72.0001242501395, 97.6910399028233, 89.5432139805385, 94.77850791386196, 105.32604013170514, 105.2289251599993, 100.21837765829903, 93.45835712977818, 88.51278223310197, 101.07911355154855, 110.56527369362968, 107.25133732386998, 99.1600558417184, 95.53639657156808, 98.71655232565743, 92.99752480643136, 102.27902575901577, 98.5680067879813, 106.3680475779942, 114.49525124686105, 125.17617498125348, 121.72889573233468, 94.06461524963379, 63.424268450055806, 30.914717265537806, 13.74168859209333, 6.406293817928859, 1.533311203122139, 0.059240185123469145, 0.06440959059234176, 0.04541959048115781, 0.06808043111647878, 0.021627428409244333, 0.025651680505169288, 0.049862654746643136, 0.07149241053100143, 0.022116160219801322, 0.031538266954677444, 0.018180102409262742, 0.028821826646370546, 0.0261036781261542, 0.0855707297367709, 0.003859492767203067, 0.05862683017871209, 0.03092934623626726, 0.01911436709841447, 0.05052809064675655, 0.026770482970667735, 0.03226030285337141, 0.022454396355897188, 0.06529004406183958, 0.020809132140129805, 0.019768727610685995, 0.03793776820280722, 0.01642446090201182, 0.03139535390904971, 0.054805700933294635, 0.038158848482583246, 0.04625695697697146, 0.056225097804729424, 0.03842293431184121, 0.032816165525998385, 0.1335742324590683, 0.027952083852142096, 0.041170190288020034, 0.03719894874042698, 0.02762173398930047, 0.024481190634625297, 0.013018105694624995, 0.0438874007335731, 0.021040392141523104, 0.017647306534594724, 0.04897309533719506, 0.03497892804443836, 0.03199309576302767, 0.055776698115680895, 0.07603113127074071, 0.016054516824494516, 0.04388974167938743, 0.0014080951285515247, 0.06413021058376346, 0.08009829731392008, 0.04041579844696181, 0.025436913993741785, 0.029085186443158557, 0.07016552851668426, 0.03777168657896774, 0.0387211470598621, 0.03522498180557575, 0.056125190308583636, 0.02340339882565396, 0.12561535595783166, 0.11559473723173141, 0.15069873285080704, 0.15299380969788345, 0.09345782401838473, 0.15767298718648298, 0.11864389718643256, 0.09892165940254927, 0.13914720341563225, 0.06599690113216639, 0.16805719211697578, 0.09937485294150454, 0.09529744101954357, 0.15366064677281038, 0.23996225371956825, 0.13632068437125, 0.08811156518225159, 0.13380059174128942, 0.0928544435384018, 0.07525198986487729, 0.2181929639939751, 0.19823781906494073, 0.18604115210473537, 0.09601626744759933, 0.1380230744502374, 0.13440239802002907, 0.1809541072164263, 0.16295340098440647, 0.1617814488708973, 0.11582135435725961, 0.07843373556222234, 0.1091588054384504, 0.08643489158047096, 0.09476670449865715, 0.17097703686782292, 0.11563124241573469, 0.16827576181718282, 0.09967744563307081, 0.29992732458880966, 0.14129407464393548, 0.12273242351199899, 0.11555877487574305, 0.11515028322381632, 0.09544772974082402, 0.2044060416519642, 0.1486446037888527, 0.09685694519430399, 0.13018725705998285, 0.11472167979393687, 0.09971581678837538, 0.06716702120112521, 0.13623954515372003, 0.15795217720525606, 0.12003676673131329, 0.24806122056075505, 0.164021957931774, 0.1585165283509663, 0.24066711589694023, 0.10544371764574732, 0.28693720591919764, 0.10554741136729717, 3.4803036025592258, 15.133272068841116, 37.64800112588065, 70.27681119101388, 97.21805518014091, 114.9589809690203, 114.16737965175084, 112.04100159236363, 107.27025032043457, 97.22032724108014, 96.79987784794399, 90.88393838065011, 65.81644984654018, 101.69140270778111, 84.51549053192139, 95.18419238499233, 90.00337232862199, 108.63075624193463, 97.30916690826416, 86.79836981637138, 100.835738999503, 94.70521136692592, 84.68769468579973, 101.52952357700893, 79.8942505972726, 99.03319563184465, 96.88442352839878, 87.55912808009556, 101.46128531864711, 98.38219806126186, 104.76079027993339, 97.6595367704119, 93.33545739310128, 107.00217492239815, 115.09741687774658, 111.28915091923305, 108.846921648298, 104.03229945046562, 111.15978240966797, 103.86195741380963, 114.97721304212297, 113.15496458326066, 121.87287630353654, 130.94545882088798, 143.50184031895228, 132.2582792554583, 99.85421562194824, 62.514165605817524, 27.283972569874354, 12.132130571774074, 5.916751103741782, 0.8609382052506719, 0.4105004955615316, 0.11269041057676077, 0.17173909954726696, 0.2028472838657243, 0.09410804377070495, 0.1479183677583933, 0.09585923408823353, 0.13283661061099597, 0.11847112859998431, 0.0910268501777734, 0.07693346070923976, 0.16756928472646646, 0.12594645390553133, 0.20469302125275135, 0.06289474759250879, 0.12650970582451138, 0.13428988334323677, 0.1990789310740573, 0.10017483215779066, 0.12973486419234956, 0.18807839921542577, 0.1172595771827868, 0.17459209502807685, 0.08620602850403104, 0.10215762683323451, 0.13615988514253072, 0.14177393460912363, 0.13112485674875124, 0.14253130182623863, 0.18218695106250898, 0.1188876133944307, 0.18023931128638132, 0.12216917159301893, 0.0798329154827765, 0.22671643591352872, 0.11664163534130369, 0.1041413578870041, 0.16492093540728092, 0.11482044735125133, 0.10183165182492562, 0.08379490859806538, 0.14255346277994768, 0.10299827065318823, 0.11722410337201186, 0.23142970300146512, 0.13072925726217882, 0.15672349956418785, 0.11930929576711995, 0.1604892603520836, 0.12062231531100613, 0.14581936039030552, 0.14571110691343034, 0.1434814001300505, 0.15018147203539098, 0.1256295916225229, 0.074589251141463, 0.10724623235208647, 0.18824548167841776, 0.10038677257086549, 0.1780517686690603, 0.08260186083082642, 0.11200879500912768, 0.11386882912899766], [0.05193025951406785, 0.04205491513546024, 0.02132775681093335, 0.09268799889832735, 0.04817510083583849, 0.08692575059831142, 0.013688460125454834, 0.01652993238531053, 0.05703696834721735, 0.04976834516440119, 0.01880921463349036, 0.03414901525580457, 0.039925180309052975, 0.010976384493655391, 0.04429202812856861, 0.07311083868678127, 0.017226870970002243, 0.062024024315178394, 0.05202362593263388, 0.04315952604104366, 0.02345929484415267, 0.012568170820096774, 0.02728409835669611, 0.07225612205054079, 0.0365356061208461, 0.04199743643403053, 0.03307990190972175, 0.03324731006952269, 0.01785092132299074, 0.1621888412960938, 0.05416454980149865, 0.007727921840601734, 0.04191288757803185, 0.01791747034128223, 0.04087497327210648, 0.05361920102898564, 0.03796459408476949, 0.06916722708514758, 0.023620804838304008, 0.025526651946295584, 0.033897166805607934, 0.02070552493179483, 0.03589631078232612, 0.010725556390493043, 0.02904955656932933, 0.008907683044006782, 0.037835750462753434, 0.015606188381622945, 0.02036538889764675, 0.06885494491351501, 0.0427300167669143, 0.11348574182816915, 0.009544813007648503, 0.04684490417795522, 0.04542644029217107, 0.05543243319594434, 0.06007664916770799, 0.11038991223488535, 0.14914320489125593, 4.268617119107928, 21.521339893341064, 57.76538801193237, 74.86402579716274, 82.79043347494942, 86.80276107788086, 81.0190875189645, 79.23963301522392, 66.58518464224679, 70.16223539624895, 72.37144987923759, 61.2895108631679, 75.0699634552002, 75.53062207358224, 60.77435057503836, 60.502238273620605, 54.353749547685894, 48.04429885319301, 40.475205762045725, 36.30851003101894, 34.47011743273054, 41.71140146255493, 38.99871008736746, 49.43340008599417, 32.52303763798305, 32.3320802961077, 47.19813680648804, 26.83321339743478, 34.893599714551655, 25.710222959518433, 40.25306837899344, 28.557141372135707, 39.78728893824986, 25.57496758869716, 33.14764247621809, 35.53730167661394, 38.12077045440674, 50.693105016435894, 69.0351333618164, 51.110118525368826, 77.67903981889997, 74.43163939884731, 70.79186725616455, 92.61520712716239, 96.20778015681675, 74.04409667423793, 77.5893246786935, 80.55081367492676, 85.8697291782924, 93.05880096980503, 95.8013939176287, 86.73564842769078, 67.29836164202008, 51.028918402535574, 8.264146583420889, 0.1778050126241786, 0.2102486217128379, 0.10557580127247743, 0.12105382287076541, 0.008135053029816066, 0.0374674246912556, 0.07129556073674134, 0.025385677814483643, 0.022160010545381477, 0.07402381433972291, 0.012679671087036175, 0.0383362412851836, 0.028698903242392198, 0.008496064193812864, 0.10220451360302311, 0.039655340502836874, 0.042631686864686866, 0.012556326991346265, 0.006676003844144621, 0.032764834351837635, 0.02077859127894044, 0.024525190237909555, 0.010833636840938457, 0.019765255207728063, 0.04830392410180398, 0.02403347796228315, 0.03820155547665698, 0.0030489767502461162, 0.011317637566077923, 0.06599597832454102, 0.0423048467242292, 0.044749774637499025, 0.048238903483642, 0.0361463814707739, 0.027270040807447264, 0.028642676438071897, 0.05028364501361336, 0.027225754523117627, 0.03608329128473997, 0.02522696168827159, 0.04626711464620062, 0.029849810592297996, 0.02205054757983557, 0.04963100967662675, 0.046316518780908415, 0.026907197598900114, 0.11212573373424155, 0.028238111807565604, 0.06596297438123397, 0.02579380475383784, 0.04852234113163181, 0.04404637131041714, 0.031034196860023906, 0.024557225572477494, 0.0361032096802124, 0.0302857727344547, 0.05952086791928325, 0.07790189981460571, 0.06311638427100011, 0.026345679336892705, 0.048943976006869755, 0.018402273434081247, 0.03505266783758998, 0.04712855556447591, 0.04969445948622056, 0.014395939751661249, 0.023407324150736843, 0.09260248312992708, 0.025806746112981012, 0.03749786037951708, 0.06319637676434857, 0.06375630386173725, 0.017257347370364835, 0.03640756317015205, 0.027967084565066865, 0.0402337169673826, 0.03986777963915041, 0.02356988417782954, 0.03276186576113105, 0.057728205541414876, 0.03706711956432887, 0.02444601707559611, 0.006186589257725115, 0.04682810704356857, 0.013995493828718151, 0.16785649502915995, 0.024345219002238343, 0.027410889410280755, 0.02054093947767147, 0.04043893988377281, 0.012284350647990192, 0.021767313492351344, 0.04356487946850913, 0.07148929605526583, 0.015369064141330975, 0.02608683010164116, 0.04829032626003027, 0.02491164646510567, 0.036200277507305145, 0.03235773030402405, 0.02660426903249962, 0.02584816049784422, 0.01786177109793893, 0.0430666278116405, 0.0397125579682844, 0.07716795562633447, 0.02989522154842104, 0.0634582709254963, 0.035685761366039515, 0.0486959036040519, 0.05221326968499592, 0.06729297087128673, 0.08033723663538694, 0.04099681780540517, 0.02399571918483291, 0.05163349543831178, 0.14908106465424809, 0.16470262355038098, 0.07973049062171153, 0.13826904339449747, 0.44779951125383377, 8.955326454980032, 35.98854201180594, 76.076813016619, 90.92684350694928, 100.15990161895752, 97.23706545148576, 92.44517775944301, 88.49936526162284, 81.64446013314384, 85.42728178841728, 95.70403575897217, 84.49193613869804, 104.27119241441999, 111.28358541216168, 78.7648834500994, 85.84764780317033, 73.20558112008231, 66.2107184273856, 58.7657653263637, 60.95779691423689, 58.94409779139927, 57.88150978088379, 59.129197801862446, 66.8732430594308, 56.591232776641846, 52.19971070970808, 59.46558094024658, 40.314070088522776, 51.50222969055176, 44.73605305807931, 65.45616490500313, 50.58635984148298, 66.59389768327985, 56.96968378339495, 58.179511070251465, 64.875990322658, 65.10154274531773, 75.89504814147949, 103.13240350995744, 84.77658299037388, 110.33092485155377, 109.21524565560478, 96.97078268868583, 116.66017096383231, 121.61885016305106, 93.09357670375279, 91.03701414380754, 89.80240263257707, 98.17184829711914, 104.50110135759626, 115.0257740020752, 110.26241561344692, 92.40127209254673, 73.92755453927177, 19.725211450031825, 2.1214908702032904, 0.09796429398868765, 0.20156151428818703, 0.07703184150159359, 0.03150194836780429, 0.04508157486894301, 0.06322276499122381, 0.00869606323872826, 0.023172953066283038, 0.0412155401759914, 0.02807969762943685, 0.02856488579085895, 0.025669268132852655, 0.016317786715392555, 0.024874142138287425, 0.015603993320837617, 0.05170208515067186, 0.07745663156466824, 0.03700778506962316, 0.011586714020398046, 0.0411091085656413, 0.01133653985535992, 0.041881942988506386, 0.032246257178485394, 0.10214943013020925, 0.009536402566092355, 0.03538850195971983, 0.02549144276417792, 0.03070005907544068, 0.026806586122672473, 0.08048943204006978, 0.0543016783360924, 0.05976973420807293, 0.02636176740218486, 0.03906737633847764, 0.018439952483666793, 0.055259868170001676, 0.020228145012099828, 0.030554011198026792, 0.013969838419663054, 0.021020729893020222, 0.012633781763724983, 0.05534692082021918, 0.03440199685948236, 0.028868567531130145, 0.018294248962774873, 0.008547551431027907, 0.023100047871204357, 0.037829935417643616, 0.05412437374304448, 0.05450341018981167, 0.03741414272891624, 0.04677330855546253, 0.08239517227879592, 0.015032103651070168, 0.03095067598457847, 0.04064459366989987, 0.03035864739545754, 0.045531715000314374, 0.01937107216300709, 0.01627249619923532, 0.028700938847448145, 0.1317780688405037, 0.09605524928442069, 0.20591757340090616, 0.19044189953378268, 0.09250646363943815, 0.25491822404520853, 0.08983087792460408, 0.14032785434808048, 0.13051161036959716, 0.21047674518610748, 0.10094054535563503, 0.13594453169831208, 0.2237317774977003, 0.13401029977415288, 0.13099026254245213, 0.10017513071319886, 0.06236258614808321, 0.14851669993783745, 0.18522039614617825, 0.2031588400048869, 0.06868857491229262, 0.10804989601352386, 0.06494523292141301, 0.26246122643351555, 0.08069873973727226, 0.13675282975392683, 0.14780602950070584, 0.13007719867995807, 0.13457435236445495, 0.2067427398370845, 0.15960419284445898, 0.11912450354014124, 0.15794930021677697, 0.0937121118019734, 0.11243092521492924, 0.12733451942248003, 0.13460793984787806, 0.1740117168852261, 0.10377809737942048, 0.07954413776418992, 0.11482350075883524, 0.1375757163124425, 0.1458389021988426, 0.14280167088976928, 0.06753765738436154, 0.14530497656336852, 0.1097082830965519, 0.11305476352572441, 0.18963143016610826, 0.3434130054499422, 0.11798028993819441, 0.27131279717598644, 0.10658928153238126, 0.15372684464922973, 0.17322089789169176, 0.30509770714810913, 0.1501520914690835, 0.26807618513703346, 0.37948981672525406, 8.610300626073565, 37.16988863263811, 81.58105087280273, 102.88878577096122, 111.66060161590576, 110.88446698869977, 99.46538053240094, 98.77019936697823, 84.54514544350761, 90.85826478685651, 90.70264598301479, 82.43319879259381, 93.82996763501848, 98.62564209529332, 78.292815889631, 80.75418744768415, 73.30128560747418, 66.66368538992745, 59.01211370740618, 50.90090479169573, 50.716576031276155, 57.97162791660854, 57.64891883305141, 68.01251833779472, 48.1074093409947, 49.630982535226, 67.64493083953857, 42.354061194828574, 56.14163221631731, 40.44157995496477, 58.990011487688335, 43.39946631022862, 58.88644163949149, 44.041591031210764, 52.25069311686924, 56.16619062423706, 56.670553411756245, 71.21852833884103, 91.87974030630929, 72.40182045527867, 104.29323210035051, 103.45259039742606, 98.34641483851841, 116.61439623151506, 120.85638264247349, 95.11138221195766, 96.92534841809953, 98.28436047690255, 107.45541286468506, 119.28446388244629, 128.23456355503626, 118.7497444152832, 100.01234967367989, 76.35866669246128, 18.552473647253855, 1.4128450730017252, 0.22938717688832963, 0.31694994973284857, 0.1718617243958371, 0.10161906001823288, 0.15649954229593277, 0.2189921832510403, 0.09691922792366572, 0.14722848763423307, 0.18942263137016976, 0.12048635046396937, 0.1315897618021284, 0.17992622165807656, 0.11061030719429255, 0.15699636563658714, 0.09795981565756456, 0.08420944599700825, 0.12891247974974768, 0.09422419539519719, 0.07356049705828939, 0.10923188365995884, 0.07380130235105753, 0.14261978279267037, 0.14728277043572494, 0.2858977716948305, 0.14860968637679303, 0.11663859550442014, 0.12752712837287358, 0.12450866534241609, 0.11269866834793772, 0.21472331588821753, 0.10000044865799801, 0.1224994281572955, 0.05391947991613831, 0.16924582262124332, 0.12794338246541365, 0.10826949708695922, 0.1991174854338169, 0.11213299405894109, 0.0995956685926233, 0.09862369431981019, 0.11160826257296971, 0.23674162796565465, 0.1141348419977086, 0.11001576124025242, 0.09049222565123013, 0.1733908030603613, 0.0817487183958292, 0.07593430432357959, 0.1318474965436118, 0.1289353599505765, 0.08264423534274101, 0.18116994920585835, 0.1670719456991979, 0.09917035605758429, 0.28856167303664343, 0.1221899754766907, 0.14515009416001184, 0.1485906331134694, 0.14628246054053307, 0.09374377224594355, 0.09476415320698704], [0.0500548497906753, 0.00866092021377491, 0.06688848936132022, 0.02295892615802586, 0.04703725528504167, 0.058370452507265976, 0.018417635466903448, 0.026602062097351466, 0.008906268298492899, 0.029497002916676656, 0.041747806793344874, 0.053974468394049575, 0.026343843899667263, 0.01814459976074951, 0.022157074185088277, 0.026533312929262007, 0.03332683776638337, 0.044041580853185484, 0.024490177830947295, 0.01613950333558023, 0.027851448627188802, 0.007518586153829736, 0.054597614599125724, 0.15378355660608836, 0.02363410242833197, 0.05428135281960879, 0.03229475886161838, 0.01568333781324327, 0.02700733918962734, 0.02185116515361837, 0.012534418791931654, 0.033291676081717014, 0.010209401587157376, 0.048111528889941316, 0.013603908724949827, 0.03808999074889081, 0.03417749337053724, 0.04975978544514094, 0.05927576071449688, 0.01993570490075009, 0.052406397714678726, 0.0457914005299764, 0.03596431356189506, 0.011293073750234075, 0.043310035286205154, 0.013959057346385504, 0.025720741799367324, 0.016634387762418816, 0.016111476446634958, 0.05644107889384031, 0.01873447060851114, 0.021944977708959153, 0.02425017660217626, 0.08221427484282426, 0.16343149675854615, 0.02462302311323583, 0.17743332471166337, 4.918387898377009, 25.72082417351859, 62.89485740661621, 75.64513533455985, 77.26218959263393, 74.79725360870361, 81.87662724086216, 78.92249638693673, 81.43741076333183, 74.60159928458077, 49.824663570949006, 49.94066374642508, 50.02556031090872, 37.68744952338082, 31.039461748940603, 12.76532425199236, 46.587598596300396, 66.89278139386857, 25.745952333722794, 32.82694837025234, 36.668989522116526, 38.535685607365195, 27.28821791921343, 44.56096887588501, 42.7398807661874, 34.68225635801043, 51.84892742974417, 40.9228504044669, 28.92717116219657, 45.3482449395316, 42.35336290087019, 42.59757123674665, 40.13622399738857, 38.05082293919155, 34.79236446108137, 36.344664982386995, 28.47615143230983, 24.695752961294993, 31.150480066026958, 24.11445450782776, 18.044049637658254, 16.470195804323467, 19.327034507478984, 31.50689138684954, 37.87325825010027, 46.670254366738455, 41.989367621285574, 79.2594631740025, 74.82693631308419, 82.53818607330322, 69.1634110042027, 69.08144310542515, 73.90088040488106, 74.52880995614188, 85.17750099727085, 93.54345866612026, 85.48554243360246, 52.33172648293631, 11.307997788701739, 2.651477094207491, 0.33428046692694935, 0.05666510740827237, 0.022890311000602584, 0.053638515528291464, 0.03360286581196955, 0.08812510874122381, 0.012598717618467552, 0.027893185316185867, 0.06342625764331647, 0.011173772026917763, 0.0669003976508975, 0.00501849885664082, 0.03925286067117538, 0.03575977257319859, 0.04402169977713909, 0.01544993364119104, 0.0404217288430248, 0.05585528264886566, 0.022368987456762364, 0.04431906096371157, 0.0409982088021934, 0.009786941443703004, 0.05926707546625819, 0.019100686136100973, 0.042630706381584914, 0.011473830390189375, 0.017538264260760376, 0.05913776704775436, 0.043147281876632144, 0.013614163085419153, 0.0091144725281213, 0.04050043551251292, 0.04924136433484299, 0.06040049357605832, 0.043727911077439785, 0.025309624216918434, 0.03293124506516116, 0.04618610095764909, 0.050788210438830514, 0.00982329819817096, 0.05307091759251697, 0.039722987051521025, 0.061502794069903235, 0.057561570911535194, 0.007345329870336822, 0.052618843636342456, 0.04842976520636252, 0.027894040270309364, 0.03283677602718983, 0.0368445566855371, 0.03971660542967064, 0.05403539744604911, 0.005356958061124065, 0.03083443615053381, 0.05062251557995166, 0.01380862613275115, 0.05818503602807011, 0.05920698440500668, 0.0283441176371915, 0.03867518988304904, 0.010984883992932737, 0.039272751925247054, 0.063368059694767, 0.024278936308941672, 0.035806499887257814, 0.02771710038983396, 0.02104291120277984, 0.027803391384493028, 0.0305342793996845, 0.014072649197519889, 0.026031729665451815, 0.004614658562266933, 0.029966080960418497, 0.010557853916127766, 0.026177238107525876, 0.024591589978496944, 0.022345237034772123, 0.03823430157665696, 0.031396561701382907, 0.024790707776056867, 0.029363959162895168, 0.03696135970364724, 0.10595529912305729, 0.0417780151723751, 0.04348871051999075, 0.012740018295257219, 0.05418183208842363, 0.025133379834837148, 0.018967932456039956, 0.04339976814974632, 0.02242761797138623, 0.04880396030577166, 0.06713151346359934, 0.022875210203762566, 0.03621751229677882, 0.009817678231879004, 0.04204854029896004, 0.05036709464288183, 0.04536494466343096, 0.07791443914175034, 0.0676087135715144, 0.02674309560097754, 0.04795681612033929, 0.045196118365441046, 0.05323060741648078, 0.058425787038036754, 0.03378485568932124, 0.02253378156040396, 0.036020479298063686, 0.009684983075463345, 0.028680681184466397, 0.08461695377315794, 0.026293728999527435, 0.26991743062223705, 0.03212083337296333, 0.40536610249962124, 12.618502736091614, 41.63671180180141, 84.9919285093035, 88.80320303780692, 92.14714172908238, 83.3310797555106, 95.19814436776298, 93.64373506818498, 101.06528663635254, 104.11815139225551, 76.76715823582241, 80.20220170702252, 70.06276498522077, 55.3728974206107, 46.80363893508911, 27.373529638562882, 48.98748901912144, 77.15941183907645, 35.89395618438721, 36.53215864726475, 31.063985415867396, 41.56352642604283, 35.33352838243757, 32.13366058894566, 40.59225511550903, 32.386248452322825, 38.704179423195974, 35.67746073859078, 35.927422182900564, 45.54597330093384, 43.08122491836548, 37.66429117747715, 40.582909788404194, 38.2568405015128, 39.31000328063965, 39.58364765984671, 34.77689777101789, 33.29014308112008, 39.87150110517229, 35.00120299203055, 31.497483525957378, 24.636128732136317, 40.00216197967529, 62.804496083940776, 57.00696086883545, 75.9473055430821, 69.15412821088518, 111.43795354025704, 100.80808516911098, 120.38950538635254, 96.58633886064801, 85.43840585436139, 89.92268984658378, 85.77268368857247, 94.83898503439767, 103.67427267347063, 104.80095086778913, 77.0002772467477, 27.64331603050232, 9.318545273372106, 1.1287967434951236, 0.09154579376003572, 0.1014693955491696, 0.023345457024074028, 0.005613177125009575, 0.06529818648206336, 0.05618543404021433, 0.04743415755884988, 0.044375192773129256, 0.022282972965123396, 0.02357898842144225, 0.07118614696498428, 0.02943667097549353, 0.060252396522888114, 0.04971165017091802, 0.020129236658768992, 0.013197589233251554, 0.05815905492220606, 0.05344858339854649, 0.053035905185554705, 0.04472768492996693, 0.05403578081833465, 0.03548185480758548, 0.03809069303263511, 0.04207498959398695, 0.08456480157162462, 0.015659443202561567, 0.050966661756059954, 0.029876965563744307, 0.017498654779046774, 0.031704826945705075, 0.06736750794308526, 0.005363164112038378, 0.03195156941988638, 0.031593591307422945, 0.044595832005143166, 0.01890926292565252, 0.02697868295945227, 0.06141684403909104, 0.056870309968612025, 0.059948399263833246, 0.02474039949343673, 0.07010006345808506, 0.027123234667150036, 0.027891845209524035, 0.04961510481578963, 0.04348151126344289, 0.023840870708227158, 0.07838321184473378, 0.05050565827904003, 0.05850721124027457, 0.020290373458660076, 0.021462274682042853, 0.06756511091121606, 0.052489667532167265, 0.05673111529488649, 0.02004622807726264, 0.020169504319450686, 0.02819374409903373, 0.09317334142646619, 0.08158264016466481, 0.1761472022959164, 0.16655172647110053, 0.09274438515837703, 0.18448191934398242, 0.09166385206793036, 0.0974003838907395, 0.0891936860446419, 0.08937784723405327, 0.08935785759240389, 0.13602096188281262, 0.07036036306193896, 0.13612199574708939, 0.0928543960409505, 0.09240197603191648, 0.1319661316062723, 0.08140543395919458, 0.14148627647331782, 0.1627726528261389, 0.08121517273996558, 0.08217597832637173, 0.18719284316258772, 0.28048292653901236, 0.08773050670112882, 0.11241458609168019, 0.12109803621258054, 0.10220370614635092, 0.1285777719957488, 0.11529994090752942, 0.12449410398091589, 0.14337278024426528, 0.12596166666064942, 0.11901536796774183, 0.08007226192525455, 0.0801697266953332, 0.0945142148328679, 0.27250775162662777, 0.1165762652776071, 0.20583817123302392, 0.16235387458332948, 0.152198729504432, 0.07470876829964773, 0.10331952984311751, 0.12700431714100496, 0.14822087224040711, 0.0861275830705251, 0.15560521957065376, 0.08713499722736222, 0.24499722783054623, 0.10560280696621963, 0.08797165804675647, 0.15524661381329807, 0.17328596939998014, 0.3716958649456501, 0.16524773144296237, 0.2903841095311301, 10.65401770387377, 43.31685222898211, 90.84420163290841, 101.83670343671525, 99.41383184705461, 94.7916122164045, 97.01212447030204, 97.60434028080532, 99.32659721374512, 95.97693320683071, 68.9408324105399, 69.26878043583461, 67.20715958731515, 51.7015700340271, 43.33493838991438, 21.317193133490427, 60.40765939440046, 83.47793688092912, 42.81170082092285, 52.83429316111973, 54.37948567526681, 57.34628309522356, 41.416794368198936, 66.74244322095598, 60.20721776144845, 51.10663052967617, 72.22101443154472, 61.73584924425398, 47.688790798187256, 67.12747069767543, 65.23228005000523, 64.14350427900041, 58.67274284362793, 59.72417204720633, 49.988731384277344, 54.948636940547395, 41.567907265254426, 39.857827050345286, 47.07657807213919, 37.8006078856332, 26.93313717842102, 28.016656637191772, 35.18297828946795, 43.79954705919538, 57.674338817596436, 66.31399645124162, 59.8636988231114, 101.84435340336391, 100.70270878928048, 108.25488649095807, 92.61712482997349, 90.90143394470215, 91.21914727347237, 91.89841706412179, 104.50879996163505, 116.28786563873291, 117.84590884617397, 82.03406647273472, 27.068672214235576, 8.27412680217198, 0.8215643380369458, 0.3261155736233507, 0.14798666909337044, 0.12082717860383646, 0.1160360835492611, 0.23825117839234217, 0.15073647296854428, 0.16768696984010084, 0.10612119414976665, 0.09663558671517031, 0.10819859017751046, 0.15071520768105984, 0.11399921641818114, 0.3542298035962241, 0.22513418724494322, 0.13662651367485523, 0.11011332779058389, 0.14163651769714697, 0.12385344478700842, 0.12351796350308827, 0.13203296730560915, 0.15314889566174575, 0.10964049066283874, 0.1370651051402092, 0.1427542684333665, 0.19459958214844975, 0.08042453695088625, 0.16516926565340587, 0.10978265053459577, 0.08209789930177586, 0.10508889811379568, 0.12122760925974164, 0.1404300552925893, 0.19669582109366143, 0.13140723588211195, 0.08879787621221372, 0.09608570872140781, 0.12864447198808193, 0.1555112831826721, 0.09268688610089676, 0.12916903384029865, 0.1510201141770397, 0.21687280626169272, 0.15152225723224028, 0.06542531680315733, 0.151576607887234, 0.11485551404101507, 0.07246034752045359, 0.17907673652682984, 0.08776719508958714, 0.17485974995153292, 0.11200936497854334, 0.06928985193371773, 0.13761485421231814, 0.10742423244352851, 0.1504726992653949, 0.13557631788509233, 0.12389822809823922, 0.11123656787510429], [0.01686732204897063, 0.05307462239371879, 0.02505714472915445, 0.05935202126524278, 0.028140311162652712, 0.006114321037395192, 0.01874309478859816, 0.047957189314599545, 0.07184413594326802, 0.02209410274268261, 0.030309938759143864, 0.013960645966497915, 0.04066027800685593, 0.08058035573256866, 0.02936829500166433, 0.04670187917404941, 0.021241655806079507, 0.043012697848358324, 0.026593794148149233, 0.05447577006582703, 0.04547572907592569, 0.08474733427699123, 0.0073510889363076004, 0.016549318130793314, 0.05591048486530781, 0.031095200550875494, 0.058511750639549324, 0.01970270276069641, 0.030429445739303316, 0.025155449186318686, 0.012567883290882622, 0.038341845984437635, 0.04681567967470203, 0.03803103623379554, 0.009627572227535503, 0.008122450938182217, 0.03302841127983161, 0.056251906723316224, 0.02900793862396053, 0.09009400701948575, 0.09023989204849515, 0.0486077958318804, 0.03268776634441955, 0.03508793130250914, 0.0438049146240311, 0.02753129884201501, 0.034561418662113805, 0.09550585305052144, 0.056124030013701746, 0.053334630227514675, 0.07692917915327208, 0.042648779161806614, 0.03904551733285189, 0.064626348604049, 3.1328658802168707, 14.529044560023717, 34.697785581861226, 68.81871782030377, 89.17911447797502, 77.49815736498151, 73.77951622009277, 63.51266343252999, 75.32439259120396, 54.562789576394216, 48.733521938323975, 55.58936159951346, 33.77445336750576, 28.372004883629934, 21.27573323249817, 32.04305955341884, 30.400286538260325, 40.86723354884556, 61.74302673339844, 31.660481316702707, 40.020890848977224, 43.79632656914847, 34.64031703131539, 45.79466322490147, 52.35836240223476, 64.21813488006592, 95.80028915405273, 57.922229698726106, 53.2219157900129, 81.1095391682216, 54.55306209836687, 32.2393114226205, 39.5021105493818, 35.49401787349156, 61.859416007995605, 62.77437564304897, 59.17390251159668, 59.515851157052175, 79.9697983605521, 50.32658406666347, 65.9127310344151, 71.65253366742814, 52.86546972819737, 47.84292963572911, 82.20706272125244, 50.683176040649414, 30.611810547964915, 41.82806519099644, 27.851939167295182, 36.59148236683437, 31.122937406812394, 21.898269244602748, 24.353602818080358, 34.14524051121303, 56.23967824663435, 60.26322719029018, 59.82578945159912, 52.59125212260655, 71.57570048740932, 74.06441320691789, 86.65263135092599, 89.85653604779924, 64.17865521567208, 39.15357501166207, 6.678467784609113, 0.04047775208683951, 0.2530133862580572, 0.06994932690369231, 0.09543612679200512, 0.00724585324392787, 0.10297590613897357, 0.025161605195275376, 0.035323226890925846, 0.048887257264660935, 0.04515119595453143, 0.0386663248230304, 0.10940039104648999, 0.04153992062700646, 0.027065506604100977, 0.056214159820228815, 0.09567004495433398, 0.058203750023884435, 0.046491468857441626, 0.07524203575615372, 0.06795201836419956, 0.006978748357921306, 0.050363773213965554, 0.05074642625238214, 0.033205044123211076, 0.031449687600667985, 0.042862107178994586, 0.016204032015853694, 0.061891350362982066, 0.014074460037850907, 0.036566343757190874, 0.02492752418454204, 0.04822197064225163, 0.026736932806670666, 0.01620096673390695, 0.03197998646646738, 0.031297838248844655, 0.009994805557653308, 0.00995061596456383, 0.02612991877166288, 0.03598531082804714, 0.03678319337112563, 0.025691814155184796, 0.0411274832939463, 0.010058647221220391, 0.04124220660222428, 0.031082491589976207, 0.04749873373657465, 0.019624097871461084, 0.025318046532837406, 0.06891274931175367, 0.011412172761213566, 0.014601001515984535, 0.05421420160148825, 0.038751270622015, 0.046343229311917505, 0.04094479791820049, 0.0681183272972703, 0.010808627736488623, 0.03515546928559031, 0.0562455929549677, 0.08453324290790729, 0.027170455615435327, 0.021432062910337533, 0.008507088691528355, 0.048930849746934006, 0.01823295689454036, 0.020695050047444444, 0.011961227183097174, 0.05692666569458587, 0.04214677520628486, 0.021448624253805195, 0.05362441557060395, 0.0275100674812815, 0.03240688338077494, 0.08709336231861796, 0.020921402544315373, 0.0733962712277259, 0.017076706081362705, 0.09251657381121602, 0.023689830509413565, 0.05856789941234248, 0.04291307533692036, 0.011315051499488098, 0.02783127747742193, 0.017725689203611443, 0.035613453281777244, 0.02897069722946201, 0.037911329085805585, 0.07692074496299028, 0.042645206674933434, 0.055205368237303834, 0.01467515860817262, 0.03644106583669782, 0.003085907714973603, 0.01914623619190284, 0.05787587511752333, 0.036769364827445576, 0.004955813671196145, 0.014623189611094338, 0.020230144994067292, 0.023924961553088257, 0.032311002989964824, 0.08166078704276256, 0.03764218817065869, 0.06978042596685034, 0.01421407625145678, 0.04988691915891, 0.0937290344653385, 0.04268605448305607, 0.04598951918472137, 0.06563466521246092, 8.017677477427892, 26.477842569351196, 55.140685149601524, 89.53438976832798, 104.36112294878278, 90.5265508379255, 87.47509656633649, 81.82734366825649, 93.30626801082066, 82.4100821358817, 86.52351992470878, 74.7162584577288, 51.82782922472273, 29.604908875056676, 24.05349796158927, 23.878797667367117, 23.002780948366436, 21.325918333871023, 22.02821271760123, 13.479405386107308, 29.045535462243215, 20.88649341038295, 20.73976830073765, 30.981433868408203, 15.338309935161046, 26.21187768663679, 56.924447536468506, 30.557899475097656, 27.51817376273019, 37.588316099984304, 25.937366519655498, 14.413597634860448, 24.941783462251934, 20.441115617752075, 26.77267721721104, 20.60984914643424, 21.13886066845485, 27.733692986624582, 31.01107488359724, 20.03555621419634, 24.293485266821726, 38.05683660507202, 24.831741367067607, 15.75988667351859, 46.95376518794468, 30.101673807416642, 13.953691158975873, 31.251624992915563, 22.491932017462595, 25.89876753943307, 33.495507512773784, 32.69101728711809, 37.32048736299787, 55.87897293908255, 79.51070308685303, 93.45838492257255, 88.94630813598633, 71.52930736541748, 88.14183875492641, 82.92008686065674, 93.50656373160226, 108.16799231937954, 87.13292557852608, 60.29054055895124, 16.71211470876421, 0.45844523715121405, 0.14602427796593734, 0.12116104497441224, 0.0959349110988634, 0.05618379877081939, 0.040515800938010216, 0.04003775605399694, 0.0579516471230558, 0.029734038947416202, 0.021435043375406946, 0.0934255053954465, 0.057008517373885424, 0.04555749593834792, 0.060828085988759995, 0.03631500760093331, 0.0496812891215086, 0.014016999996134212, 0.10168348691825356, 0.12650054560175963, 0.07361796897436891, 0.025686382482360517, 0.059464678434388976, 0.040262195082115274, 0.01132566633168608, 0.05264667375013232, 0.024414100484656434, 0.03722930978983641, 0.0747396619990468, 0.04955652349495462, 0.014074588111335678, 0.022753847430327108, 0.0327220255775111, 0.026450528264311806, 0.008234873164578207, 0.022417645202949643, 0.023776109629709805, 0.05913328193128109, 0.02087568455109639, 0.016624050281409706, 0.014620797775153602, 0.03710249159485102, 0.03820261738396116, 0.019892020816249505, 0.061133596380906444, 0.04760899567710502, 0.026610742256577526, 0.014110268875291305, 0.003984955588488707, 0.05339210553626929, 0.010515607477697943, 0.04724897178156035, 0.031025759277067015, 0.04187328827434352, 0.06061872400875602, 0.01670689771084913, 0.028833168359207254, 0.02573529807185488, 0.08327060458915574, 0.18829595111310482, 0.1553517324583871, 0.18631412674273762, 0.15301544139427797, 0.08594165090471506, 0.08766299246677331, 0.1543970201164484, 0.15140394786638872, 0.08254795800894499, 0.11082701092319829, 0.1272681722683566, 0.1840284951031208, 0.15481700615159102, 0.18953194336167403, 0.1271497814783028, 0.1725364460476807, 0.29880011507443016, 0.08283754318420376, 0.11936508491635323, 0.12253477983176708, 0.20069037031914505, 0.17728453555277415, 0.08889391605875321, 0.11008221695997886, 0.12128615326115064, 0.13090080448559352, 0.07102700336171047, 0.13966632341699942, 0.07699488169912781, 0.1421358244759696, 0.18016582594386168, 0.21754414880914347, 0.1808855887502432, 0.05031586864164897, 0.10938910700912986, 0.09791106970182487, 0.1152804669524942, 0.12156637465315205, 0.1594436921711479, 0.21478880808821746, 0.11400137415954045, 0.11714027715580803, 0.12750950003308908, 0.13699689880013466, 0.1987175297524248, 0.1059771818774087, 0.19894954801670142, 0.07878530491143465, 0.1901820477630411, 0.16325506408299717, 0.12855966868145124, 0.09687043447047472, 0.1022273123796497, 6.6605779102870395, 25.063057320458547, 57.7539894921439, 97.91253457750592, 113.03102956499372, 96.36664376940045, 91.05552414485386, 82.11013535090855, 96.96737112317766, 73.37073285239083, 68.82706260681152, 69.79005513872418, 44.78814022881644, 37.00046375819615, 30.362085342407227, 46.667426449911936, 43.70194223948887, 54.703035490853445, 86.75933483668736, 47.66998897280012, 59.66781520843506, 58.48402976989746, 53.45570877620152, 68.88926982879639, 73.42460918426514, 85.85033675602504, 122.81423214503697, 85.03570910862514, 73.3423980985369, 113.990784236363, 79.05473450251988, 51.58784886768886, 59.891039984566824, 52.24247339793614, 89.02685165405273, 86.55029133387974, 84.60587964739118, 84.8446683883667, 108.47355324881417, 70.71517304011753, 90.43166623796735, 98.0654991694859, 71.99765069144112, 63.677947180611746, 113.00984450748989, 71.64864267621721, 45.05623647144863, 64.48683561597551, 42.566641330718994, 51.02870648247855, 44.75856869561331, 32.69524874005999, 33.527503967285156, 47.39397178377424, 76.4989925112043, 82.1414578301566, 83.20353862217495, 73.78347669328961, 91.38247162955147, 92.63585717337472, 106.88232544490269, 123.06681306021554, 97.76360688890729, 64.90848704746791, 14.191482833453588, 0.30581917986273766, 0.41325667766588076, 0.21708304355187075, 0.24816880907331193, 0.1404607386461326, 0.3519403450191021, 0.15855713188648224, 0.17049868325037615, 0.12921874331576483, 0.10141695836292845, 0.19587294810584613, 0.16849539003201894, 0.09815598691680602, 0.17511425486632756, 0.10809107630380563, 0.24379831073539598, 0.1378570640725749, 0.15618840684848173, 0.1519216022321156, 0.25627369273986134, 0.12295359878667764, 0.1821234266140631, 0.1635041135762419, 0.06971527981970992, 0.14187576914472239, 0.1167821463729654, 0.12468751360263143, 0.10989373350249869, 0.11961764922099453, 0.10447311401367188, 0.1644098221191338, 0.24889524866427692, 0.1578304073108094, 0.11511609862957682, 0.14901371326829704, 0.13815954141318798, 0.11983642248170716, 0.12194351798721723, 0.13782822633428232, 0.10148711209850651, 0.08998160769364663, 0.12941011733242444, 0.09272378483521086, 0.09136424493044615, 0.10362779508743968, 0.08302771619388036, 0.08971341672752585, 0.07090962358883449, 0.06607909886432545, 0.11463459660964352, 0.07373260746576957, 0.17687160628182547, 0.10966643784195185, 0.11639048238950116, 0.07939600678426878, 0.12261969170400075, 0.19979325202958925], [0.027885419482897435, 0.023726089724472592, 0.02611415640317968, 0.060423964102353366, 0.058829047184969695, 0.017369546528373445, 0.10433055380625383, 0.035918668511190584, 0.026730196650273035, 0.018501646583899856, 0.010412776343790548, 0.017922498285770416, 0.04212486531053271, 0.0482010005175003, 0.03787878315363612, 0.034178453497588634, 0.042672168263899427, 0.013444101005526525, 0.026773329425070966, 0.03773983953786748, 0.048377138030316146, 0.008181066185768162, 0.02089490575183715, 0.02977886636342321, 0.033176138531416655, 0.055365526250430515, 0.06562450754323176, 0.014369566791823931, 0.037323517591825554, 0.03346226657075541, 0.024134153899337565, 0.041636533835636716, 0.03625804797879287, 0.028317571650924425, 0.032823907610561164, 0.030255543999373913, 0.026217568532696793, 0.03245029265859297, 0.05537026242486068, 0.018394916418141553, 0.01221051755627351, 0.05673606860052262, 0.029592594930103848, 0.03630173884864364, 0.04758157607700143, 0.024072229097198163, 0.01864959775204105, 0.023046502976545265, 0.01996501930989325, 0.06454379803368024, 0.1384404684816088, 0.23966117416109356, 2.3100621572562625, 31.402637141091482, 62.74977902003697, 83.3632846559797, 80.01218932015556, 72.633681842259, 50.43131078992571, 56.7891070502145, 61.274648666381836, 54.16203137806484, 44.415768895830425, 31.33909239087786, 11.592959914888654, 29.382986886160715, 36.76070921761649, 49.132268633161274, 54.732026849474224, 58.424726894923616, 51.53572000776018, 62.304920605250764, 75.90364306313651, 62.4971216746739, 52.72682189941406, 75.86380904061454, 45.681185245513916, 42.01670183454241, 86.14562824794224, 96.12766742706299, 67.66551835196358, 61.573337827410015, 57.74441834858486, 52.02823611668178, 64.745940889631, 70.36530344826835, 62.07604694366455, 64.65278639112199, 72.41482748304094, 82.31586456298828, 81.37675993783134, 70.05545548030308, 71.84539481571743, 73.15881279536656, 78.20869404929024, 72.75210693904332, 84.56199482509068, 86.60390363420758, 89.07553768157959, 110.6745410646711, 101.16583401816231, 61.495372091020855, 73.21890081678117, 83.7843246459961, 69.95226083483014, 47.445718492780415, 51.67135231835501, 34.44079256057739, 25.423727887017385, 21.577067920139857, 23.485857929502213, 36.85238374982561, 61.092244556971956, 60.249045916966026, 74.98208958762032, 64.27929987226213, 73.93412753513881, 80.53490924835205, 72.99364716666085, 34.09502935409546, 11.722187723432269, 0.1537219863384962, 0.29227201108421597, 0.10194115380623511, 0.15324307632233414, 0.0763898388083492, 0.10473024485898869, 0.03342578174280269, 0.04686443580846701, 0.012480091037494796, 0.015865446434223225, 0.066205740640206, 0.02246698657316821, 0.012758414227781551, 0.014471369097009301, 0.08265473906482969, 0.04576633883906262, 0.006078869703092745, 0.02496520153779004, 0.05412322023351278, 0.08814961064074721, 0.03364313007997615, 0.024627192710925425, 0.0225404379889369, 0.06111351174435445, 0.08677035250834056, 0.03459251592201846, 0.01571345459004598, 0.025562673674098084, 0.024030202334480624, 0.01608627226336726, 0.050645490775683095, 0.007383248103516442, 0.025234624044969678, 0.04241665233192699, 0.01124866702593863, 0.05068871684904609, 0.04002489781539355, 0.03728654082598431, 0.08901256469211408, 0.04001451962228332, 0.0668471801493849, 0.04950871052486556, 0.035176707431674004, 0.027456247779939855, 0.0467206101332392, 0.020282125865508403, 0.07935710637164967, 0.021998894101540958, 0.025716302484007816, 0.02301542946536626, 0.030944223116551126, 0.031245903178517307, 0.026858307454468947, 0.10196322655039174, 0.015286822304395693, 0.048435990765158615, 0.040600858695272884, 0.047214295249432325, 0.03128660170893584, 0.07649367502225296, 0.019844664160960486, 0.08112929734800543, 0.08285034035465547, 0.0760102052507656, 0.1250588215355362, 0.019608123460784554, 0.039000404932137044, 0.04225207366315382, 0.022572325742138282, 0.05736623425036669, 0.057671948203018734, 0.01930551041316773, 0.018102915658216392, 0.02611840233605887, 0.059678464462714534, 0.09262969916952507, 0.030296072896037782, 0.015452924284285732, 0.036107094293194156, 0.01733595395593771, 0.012382828131584185, 0.08055241366050073, 0.023285460957725133, 0.007588694088294038, 0.017434046370908618, 0.029878556728363037, 0.054089259555829425, 0.009679349538471018, 0.022698221129498312, 0.012222181573244078, 0.04900297123406615, 0.036812655361635346, 0.003063999515558992, 0.014097978909766036, 0.011318114236928523, 0.017992952273094227, 0.1091407360509038, 0.018815240024455955, 0.04198392001645906, 0.05185241797672851, 0.07709668230797563, 0.02117451137330915, 0.05359118431806564, 0.02893648888649685, 0.1392987338559968, 0.085369666240045, 0.3169360804770674, 7.9246037517275125, 46.64494555337088, 79.27778557368687, 99.22117914472307, 93.64852932521275, 83.22253499712262, 72.0351779120309, 83.18232577187675, 80.19843578338623, 76.12366471971784, 72.27769088745117, 28.72014089993068, 14.112321138381958, 24.529451302119664, 24.354170833315166, 26.778041226523264, 26.816416127341135, 31.443360533033097, 25.166357925959996, 33.72141776766096, 50.234377997262136, 51.175289154052734, 37.66480881827218, 47.88967016765049, 40.10797957011631, 37.1197052683149, 61.41027750287737, 70.93488202776227, 59.59385163443429, 47.318316323416575, 47.79286091668265, 44.44664321626936, 51.01779086249215, 57.351852076394216, 47.090620381491526, 53.69287511280605, 57.068851947784424, 59.68285805838448, 61.74825872693743, 56.0782333782741, 54.69729280471802, 56.81677825110299, 62.830454553876606, 56.59447758538382, 59.55175249917166, 58.31930187770298, 77.64394446781704, 84.0582504272461, 52.02350091934204, 44.327658789498464, 48.184496130262104, 54.79563413347517, 38.059205940791536, 28.625662769590104, 20.643315144947596, 31.191780158451625, 35.1311343056815, 30.588964870997838, 36.95889268602644, 62.771909032549175, 90.43505695887974, 87.93979903629848, 92.47805663517543, 71.35927104949951, 83.49045058659145, 90.82881137302944, 91.3404072352818, 55.08032267434256, 24.115100690296718, 1.2454599291086197, 0.08743427866803748, 0.11721292111490454, 0.151908954339368, 0.02013433415309659, 0.09897484297731093, 0.07475678822291748, 0.02764289071118193, 0.05047497492549675, 0.075518613415105, 0.08525894289570195, 0.010022239576626037, 0.026646202496652092, 0.033855243519480736, 0.043993031672601185, 0.0418951879920704, 0.028478827194443772, 0.0356630779403661, 0.07192203176340886, 0.05949791307960238, 0.02085352359738733, 0.06504632785384144, 0.03235082281753421, 0.02754389075562358, 0.08808873247887407, 0.05550924675273044, 0.01166824933274516, 0.02700520689333124, 0.09368175414523908, 0.041994949603187184, 0.03645132528617978, 0.033384520028318675, 0.03048468188249639, 0.026736523989321928, 0.004548257973510772, 0.008659857458301952, 0.055611512158066034, 0.02132077468559146, 0.025971738688115562, 0.022435044537165334, 0.016363399535683647, 0.05452007840254477, 0.03175949651215758, 0.017021831258067062, 0.05402016433488045, 0.012001176780488874, 0.058491584578795094, 0.033469397973801406, 0.029062791394868066, 0.03289328103086778, 0.035668363728161366, 0.018204780727890984, 0.014263445611244865, 0.01987760025076568, 0.02128448324011905, 0.1669110921876771, 0.1797983313777617, 0.14580577611923218, 0.16835099778005055, 0.15554841261889252, 0.12155809652592454, 0.16416560379522188, 0.1281659419515303, 0.19756085824753555, 0.23009247332811356, 0.06737587427986519, 0.10706353679831539, 0.10748553129711322, 0.1595779335392373, 0.15811624697276525, 0.1340369933417865, 0.19503087257700308, 0.12009208090603352, 0.15833417885005474, 0.1489766923976796, 0.10840709041804075, 0.09071344163800989, 0.13558627877916607, 0.09776723384857178, 0.15471928353820527, 0.10729315983397619, 0.17385464959910937, 0.153179687580892, 0.11114133548523698, 0.11644039542547294, 0.17014941413487705, 0.10982285373445068, 0.1833077280649117, 0.13163173597838196, 0.06974156626633235, 0.1277215015143156, 0.1987042711781604, 0.1413194111415318, 0.17224455385335855, 0.11371936822043997, 0.09151609428226948, 0.2881707011588982, 0.1379173044115305, 0.15641973300703935, 0.22615885654730455, 0.2589854715125901, 0.11517532116600446, 0.12048040649720601, 0.16371236954416546, 0.2644740327128342, 0.2807042918034962, 0.4972410468118531, 6.730250537395477, 47.656075205121724, 85.06269591195243, 110.09390095302037, 101.52666786738804, 90.60652460370744, 68.47046715872628, 74.27087197984967, 81.78971222468785, 73.531083379473, 62.42859854016985, 42.179025650024414, 19.355888639177593, 43.474829946245464, 55.75339119774954, 76.24299308231899, 83.18264538901192, 83.08570412227085, 69.47560051509312, 86.91528715406145, 110.5843812397548, 91.28648226601737, 73.64324814932687, 104.37399101257324, 72.2873558316912, 58.99591050829206, 115.45411654881069, 130.0493496486119, 94.8248176574707, 88.21875531332833, 80.5296355656215, 72.88714517865861, 89.28556088038853, 99.79818534851074, 84.94323553357805, 88.77175549098423, 99.88107735770089, 111.77807480948312, 112.5332258769444, 101.70741135733468, 102.25462368556431, 103.63437611716134, 110.49584034511021, 103.95509106772286, 118.34195463997978, 117.88322067260742, 115.16684327806745, 139.1568399156843, 134.78871590750558, 82.85373156411308, 97.83437429155622, 112.1840511049543, 96.4646064213344, 64.66914939880371, 76.1495953968593, 48.59883805683681, 37.875947202954976, 30.66918182373047, 34.254292488098145, 51.43522473743984, 81.44116973876953, 85.14714431762695, 95.31028134482247, 78.36256885528564, 93.09809303283691, 103.59599426814488, 101.03522872924805, 56.85111624853951, 21.57515021732875, 0.6610315293073654, 0.5424355502639497, 0.11262275385005133, 0.31885090629969326, 0.12241797681365695, 0.2660978212952614, 0.12995215824672154, 0.22495714388787746, 0.10876066144555807, 0.23125010835272924, 0.1794956097645419, 0.1306300283010517, 0.15039316139050893, 0.09808662028184958, 0.14869307833058493, 0.2851699750338282, 0.13139874062367848, 0.1401407958141395, 0.1360148957797459, 0.24143776882972035, 0.10934935842773744, 0.12948335840233735, 0.11437283137014934, 0.12095852941274643, 0.2505036209310804, 0.14112247313771928, 0.1051675538931574, 0.061260401005191464, 0.15359263042254107, 0.20518717116543225, 0.14807626285723277, 0.1490001425679241, 0.17411592629339012, 0.10493613273969718, 0.09754358870642525, 0.13649196018065723, 0.2381680714232581, 0.16600756852754525, 0.21360077469476632, 0.07309993462903158, 0.13517283382160322, 0.14322895796171256, 0.09794412114258323, 0.12290455427552972, 0.14861626816647394, 0.13957432763917105, 0.13724968023598194, 0.11730668108378138, 0.19102438113519124, 0.08446106035262346, 0.09626616510961737, 0.10094415516193424, 0.07847817960594382, 0.19057318248919078, 0.12074366451374122], [0.05041106031941516, 0.04496268874832562, 0.03212538295026336, 0.03605629237634795, 0.06428808532655239, 0.03038708819076419, 0.0526491436176002, 0.023926233806248223, 0.03692725653360997, 0.008137789222278764, 0.03555623920900481, 0.039163334760814905, 0.04418187814631632, 0.055863075623554845, 0.04856042390955346, 0.018682141987872974, 0.07838153586323772, 0.06778709364256688, 0.009610384935513139, 0.016492277084450637, 0.011475588644056447, 0.04660128975020988, 0.00688677208797474, 0.0534040477525975, 0.045197444901402505, 0.02698411463227655, 0.02203028991685382, 0.016578077837558727, 0.0854635483452252, 0.02546120385107185, 0.01779366484177964, 0.014102977168347155, 0.026962006265031438, 0.031959175797445435, 0.014764046695615565, 0.030442103810076202, 0.030932555706905465, 0.057157957926392555, 0.02641968715137669, 0.05449679108070476, 0.05832619166799954, 0.014770743836249624, 0.07678725676877157, 0.01692617648015065, 0.025634627223813107, 0.028389302980420843, 0.06844356270240885, 0.2481753501508917, 0.04855095495336822, 0.04864436547671046, 1.2936688108103616, 27.278332369668142, 64.20639937264579, 79.09005219595772, 76.9823647907802, 65.51056235177177, 58.358795438494, 56.67625788279942, 48.2197721345084, 37.37586797986712, 47.82953003474644, 22.584984030042374, 20.476009471075876, 55.88198150907244, 102.94262736184257, 54.91578933170864, 58.925400188991, 46.26908622469221, 46.145283222198486, 52.59148488725935, 67.36125673566545, 55.31505019324166, 45.09755046027047, 42.26300157819475, 57.613135610307964, 53.05112212044852, 47.97452504294259, 53.30979313169207, 40.352552686418804, 40.447774274008616, 35.964185101645334, 44.30177327564785, 36.297743797302246, 31.279945850372314, 33.166263648441856, 32.81553942816598, 38.44245120457241, 35.922739097050254, 40.27173124040876, 39.18581812722342, 39.15684413909912, 40.07892220360892, 42.986569608960835, 38.831050055367605, 32.345035212380544, 44.026530810764854, 49.55359697341919, 60.012473651341026, 52.76421710423061, 40.167407512664795, 59.578176498413086, 55.885813440595356, 52.525716713496614, 46.97182355608259, 56.84844119208199, 72.56146921430314, 76.2898725782122, 66.58380195072719, 42.267187867845806, 52.82687248502459, 43.604976654052734, 20.85204597881862, 18.089968545096262, 20.245890344892228, 53.83435433251517, 73.18970448630196, 66.85982608795166, 62.76290416717529, 67.37750857216972, 79.71923242296491, 74.7257913861956, 40.468309674944194, 10.7571975844247, 0.7492799482175282, 0.21518964586513384, 0.07251285934554678, 0.03384618507698178, 0.07004447108400719, 0.018782290363950387, 0.030372414870985916, 0.020021178260711685, 0.035930905890251906, 0.03670680389872619, 0.034883519235466204, 0.03437345089124782, 0.053449686017951796, 0.019766949848937135, 0.040593472841594896, 0.056025683148098845, 0.07212146677609, 0.08238566600318466, 0.04440809493618352, 0.04986784553953579, 0.010543378219673676, 0.01639948063530028, 0.08473592810332775, 0.03532901479463492, 0.05107455900205033, 0.0616626094228455, 0.04286602232605219, 0.02062790052566145, 0.028759208042174578, 0.02908221785245197, 0.07146480094109263, 0.026412962869341885, 0.04318985655637724, 0.0633070661819407, 0.03999191422813705, 0.03143220175323742, 0.016776237204404812, 0.05888909753412008, 0.05755656332309757, 0.047969762568495104, 0.02287087945400604, 0.07321439670132739, 0.036774470803460906, 0.006185151187569967, 0.039081062389803786, 0.029176357800939252, 0.06154256300734622, 0.046894878282078674, 0.043501399124839475, 0.044806568018559895, 0.035546441163335524, 0.05817549582570791, 0.01828531944192946, 0.03567379540098565, 0.023659990235630955, 0.03151963099039026, 0.039416557244424305, 0.010963115741365721, 0.05720413223441158, 0.05016932882634657, 0.05566147269148912, 0.03205766176272716, 0.0262017518814121, 0.020633322020460452, 0.006169739536874528, 0.041127069387584925, 0.04760631546378136, 0.03642481831567628, 0.05763291208339589, 0.010186055741672004, 0.020689706584172587, 0.041026066057384014, 0.009398818564867335, 0.028376030835456083, 0.0018966109741346113, 0.06234961934387684, 0.02158417010546795, 0.0668646524261151, 0.01588718330354563, 0.005798754332187984, 0.03366393057097282, 0.027047715415912013, 0.00663080789880561, 0.01570820272900164, 0.008921511587686837, 0.04460212202476604, 0.03936022187450102, 0.036729697670255385, 0.05504287267103791, 0.027543054461213093, 0.04007661236183984, 0.04722609497340662, 0.0326343215336757, 0.07294104886906487, 0.022721840933497463, 0.020284219146040932, 0.00514270129912932, 0.05108497790726168, 0.06423656416258641, 0.0849570965926562, 0.37539214374763624, 0.047951282667262216, 0.021365427378831164, 4.068972357681819, 45.09600796018328, 83.68880081176758, 90.02789946964809, 90.79988602229527, 82.44002887180874, 78.73747280665806, 80.41029330662319, 66.61267171587262, 54.68905571528843, 69.41906302315849, 27.761466673442296, 23.513159138815745, 40.615142481667654, 57.81791639328003, 42.656742095947266, 41.00273731776646, 44.89954764502389, 43.726160185677664, 55.350145544324604, 69.13001796177456, 59.359850202287944, 49.263408933367046, 46.37955215999058, 61.26833275386265, 58.525288173130576, 50.28952932357788, 54.68675933565412, 45.65642186573574, 46.34379325594221, 38.024065426417756, 41.68192025593349, 33.73862150737217, 29.478083406175884, 29.570793219975062, 27.200703620910645, 35.53054107938494, 36.02606923239571, 39.0343473979405, 41.53418418339321, 40.619568484170095, 43.32438407625471, 46.811584200177876, 40.496248381478445, 34.45284421103341, 46.83871691567557, 48.48336941855294, 59.0605912889753, 50.3931165422712, 41.95270545142037, 58.93270969390869, 59.64376054491316, 59.933806146894185, 54.97600589479719, 61.49259281158447, 67.31521102360317, 64.57010282788957, 40.6609137398856, 26.93550477709089, 30.85601888384138, 25.16069688115801, 16.22880322592599, 21.66110290799822, 31.67831039428711, 69.33944361550468, 95.33507946559361, 85.84627900804792, 80.0023089817592, 79.29983915601457, 86.52044882093156, 91.22148186819894, 57.99811444963728, 23.026000091007777, 3.132250964641571, 0.20409994093435152, 0.07752203555511576, 0.07512940572840826, 0.023054435050913265, 0.05982044791536672, 0.02136614153693829, 0.09478762373328209, 0.0532438490273697, 0.06545949461204664, 0.035120609549007246, 0.04411350556516221, 0.015990753192454576, 0.02541587092647595, 0.06307423367564167, 0.023230592919779674, 0.08612363399671656, 0.03660521024305906, 0.0692902183426278, 0.010464732618337231, 0.013774518721870013, 0.017783088177176457, 0.028447017472769533, 0.021267248450645378, 0.0268188964442483, 0.03603302541055849, 0.08606148697435856, 0.04087265946769288, 0.05801300025944199, 0.049720745932843, 0.03828255898718323, 0.012693922866934111, 0.028462810375328575, 0.05815988273492881, 0.018684864609635303, 0.012276842658008848, 0.07066900150052138, 0.05118971657274025, 0.04028218811643975, 0.02269893528760544, 0.032438255447362146, 0.07448382037026541, 0.10267691646835633, 0.004906990532098072, 0.011044803724092032, 0.059499114086585383, 0.05967512607042279, 0.03655327517273171, 0.03508765649582658, 0.03774397520880614, 0.009337301731907895, 0.021500031763155545, 0.029259329063019583, 0.11891936883330345, 0.20754064273621353, 0.11339768833879914, 0.07033943025661366, 0.15637057993028844, 0.13351401926151343, 0.11379100116235868, 0.14321671718997614, 0.10565762581037623, 0.1063897515247975, 0.10763425260250058, 0.10372160255376782, 0.19084701208131655, 0.10196173377335072, 0.1052475803132568, 0.09428215585649014, 0.08717963126088892, 0.18132502159902028, 0.15956747052924974, 0.12116739606218678, 0.1869806381208556, 0.1421739174319165, 0.15508552959987096, 0.12133700267544814, 0.14118658112628119, 0.1387194956519774, 0.1162253405366625, 0.1359340279762234, 0.129202594182321, 0.12259060969310147, 0.11611142807773181, 0.11976626196077891, 0.07616252957710198, 0.13918539136648178, 0.11265340327684369, 0.20222476869821548, 0.08170978405645915, 0.1852233817002603, 0.14307144284248352, 0.16253676691225596, 0.13510219832616194, 0.10415690990963153, 0.2461993204695838, 0.10476355414305415, 0.1480027096612113, 0.14808330605072634, 0.2240327349198716, 0.5177883356809616, 0.1674540966217007, 0.17113586834498815, 2.8198473623820712, 47.588604722704204, 91.55438395908901, 98.61063398633684, 95.72633947644914, 81.93974467686245, 76.99248136792863, 77.11892468588692, 63.37921633039202, 51.28944458280291, 65.34763404301235, 33.442944390433176, 29.333536556788854, 77.00188228062221, 127.39296994890485, 79.60962459019252, 82.89426040649414, 64.47176497323173, 63.76882266998291, 76.77266120910645, 96.96423748561314, 80.24465520041329, 67.23984391348702, 64.2527299608503, 86.30397074563163, 76.13363538469586, 69.56514889853341, 80.03232519967216, 63.09017126900809, 64.31054592132568, 55.460027830941335, 63.04954515184675, 54.30797481536865, 48.14288336890084, 48.45430162974766, 44.86277777808053, 55.823512417929514, 53.307757309504915, 59.11341149466378, 61.740761620657786, 61.07903603145054, 60.54198891775948, 66.47841167449951, 60.77982575552804, 50.58882645198277, 66.76504571097237, 72.10886355808803, 84.00470066070557, 72.62589985983712, 63.36925261361258, 86.41984585353306, 80.56566892351422, 78.49937193734306, 69.83949851989746, 81.9499237877982, 101.33000605446952, 106.33465453556606, 96.85278143201555, 60.22197573525565, 71.73800345829555, 63.76493862697056, 31.991542134966167, 28.177795784814016, 31.61828143256051, 71.91252136230469, 95.57602214813232, 86.54978411538261, 80.87484291621617, 85.89372825622559, 99.44417463030133, 103.70464324951172, 59.698991775512695, 19.66139919417245, 2.2037933681692397, 0.47287034881966455, 0.2415744529238769, 0.1964111349412373, 0.09717211792511599, 0.18182911883507455, 0.09003770896898848, 0.14982723604355538, 0.13920369824128492, 0.14184972697070666, 0.08462614792266063, 0.1487038941787822, 0.150137991511396, 0.08984873018094472, 0.14169702945011003, 0.11914563312062196, 0.1601783556065389, 0.1833358329853841, 0.1741871317582471, 0.094633745561753, 0.0641559474170208, 0.07774913444050721, 0.18964148605508463, 0.16939302400818892, 0.14302789446498665, 0.13714270240494184, 0.17961300989346846, 0.14944250668798173, 0.11302899955106632, 0.17089087649115495, 0.2064281574317387, 0.12335492510880743, 0.1336480706397976, 0.13076493463345937, 0.05927947908639908, 0.12246191874146461, 0.1514273030417306, 0.18956226030630724, 0.12826276889869145, 0.13539281487464905, 0.13343837617763452, 0.14785687891500338, 0.27470495658261435, 0.1634109914302826, 0.09220355882176332, 0.1977539693138429, 0.11460248833256108, 0.18315157001571997, 0.13195485435426235, 0.12325683608651161, 0.08233708968119961, 0.09432158552642379, 0.060868397754217894], [0.040514579574976645, 0.07874442996191126, 0.015711624241833175, 0.026250998256728053, 0.01599018831205155, 0.004180718454465802, 0.04478995408862829, 0.0068365469258943835, 0.1164059801293271, 0.012651579737264131, 0.0420245133739497, 0.020707996495600258, 0.02124432584137789, 0.013672594280381287, 0.06652955790715558, 0.020516047420512353, 0.035530577014599524, 0.038530604248600345, 0.03410663395853979, 0.04064753172653062, 0.04916245071217418, 0.012515124648676386, 0.053695766920489926, 0.012970477625328516, 0.010026840892221247, 0.03769644383074982, 0.02742062638779836, 0.032041353173553944, 0.01018585727017905, 0.05605445642556463, 0.033851396225925, 0.04051020641678146, 0.0393111841487033, 0.0031542245290308657, 0.044162489008158445, 0.06301302981695958, 0.0620151355064341, 0.028955833919878517, 0.02055178925261966, 0.021128348939652954, 0.07254264024751526, 0.0603460343554616, 0.14760829082557134, 0.10758362710475922, 0.02715232515973704, 0.09846955151962382, 0.04408203171832221, 0.32165233311908586, 0.19378136391086237, 11.832690136773245, 55.11397974831717, 79.90860557556152, 72.42265115465436, 68.95484692709786, 58.82727772848946, 50.58029406411307, 46.60808188574654, 38.35254151480538, 34.48620251246861, 38.81136580875942, 26.356328998293193, 45.922728947230745, 50.23010832922799, 39.19279759270804, 88.84506593431745, 83.36734935215541, 54.429127080099924, 47.57265860693795, 50.8063919203622, 37.27797480991909, 25.10291392462594, 18.09378136907305, 9.796591758728027, 7.533701573099409, 5.60050254208701, 8.017022609710693, 9.910407594272069, 12.479845353535243, 20.41225106375558, 11.532933558736529, 5.484002096312387, 3.2827111652919223, 1.760478321995054, 1.0248298708881651, 0.6841435176985604, 0.7767198500888688, 0.853696553834847, 1.8840763526303428, 1.7065680090870177, 3.559859390769686, 4.167203383786338, 6.422514821801867, 5.895120927265712, 4.752542214734214, 5.821722762925284, 4.414260481085096, 4.089054822921753, 7.325214794703892, 15.67857711655753, 12.771719200270516, 11.92434208733695, 17.58190757887704, 22.87671457018171, 28.904573883329117, 33.68957069941929, 41.27895253045218, 43.95452315466744, 61.86013862064907, 71.01896912711007, 69.15796361650739, 64.72339398520333, 111.14557334354946, 72.16029412405831, 40.50203275680542, 21.328100068228586, 21.14814519882202, 56.18471104758126, 49.3239312171936, 60.030525071280344, 66.14075006757463, 66.57400499071393, 75.34551511492047, 72.35746315547398, 49.236738273075645, 17.10277370044163, 0.8689292850238937, 0.40183435486895697, 0.02477202092164329, 0.06101854398314442, 0.009698290843516588, 0.1173377444169351, 0.033797422157866616, 0.05767534766346216, 0.04359689614336405, 0.036740065685340335, 0.007159292531598891, 0.09601166019482271, 0.044378599018922875, 0.03316183501322355, 0.01748814427160791, 0.09492991931204285, 0.03901516646146774, 0.07479610932724816, 0.03963518122743283, 0.10231680436325924, 0.015676070703193545, 0.010951408467787718, 0.026481915597936938, 0.02295633076157953, 0.010049737208256764, 0.01689644986098366, 0.028522188974810497, 0.008267542929388583, 0.022530606016516685, 0.05940158146300486, 0.0056056517475683776, 0.011799216769369585, 0.07716297517929759, 0.05055160527782781, 0.030402036317225014, 0.08626867764230285, 0.0288996139009084, 0.01723151045319225, 0.03535326224352632, 0.0373772134605263, 0.016200534167832563, 0.013697689049877226, 0.011007896508090198, 0.055575149466416666, 0.016513966456321732, 0.062126842726554186, 0.0168488370587251, 0.024344771169126034, 0.04427251685410738, 0.050701069579060586, 0.0423537928477994, 0.057123888683106215, 0.11956506275704928, 0.02884582642998014, 0.02480387983710638, 0.08339137025177479, 0.07980181143752166, 0.03572160837107471, 0.05062559612893632, 0.05945391686899321, 0.01824905683419534, 0.016478356938543062, 0.044777370656707456, 0.032952842834804735, 0.01996353331820241, 0.03633357910439372, 0.04535766737535596, 0.037060802403305254, 0.02719375820431326, 0.018109511018597653, 0.05319920481581773, 0.015672740792589526, 0.036973722611687014, 0.03576912617843066, 0.01918831723742187, 0.023759792558848858, 0.10585114399769477, 0.022338680690154433, 0.027710767961772423, 0.0421009198097246, 0.02663717628456652, 0.018186568847990463, 0.0098527593405119, 0.04417082141818745, 0.0404971819370985, 0.008654242581022637, 0.1307660202894892, 0.0162081218856786, 0.050293809468192716, 0.03548191587573715, 0.01827983178996614, 0.04102884465828538, 0.027905441354960203, 0.07784893337105002, 0.01689285532172237, 0.02487713617405721, 0.04746747702094061, 0.04944724543020129, 0.45086673381073133, 1.0189693910734994, 21.644706896373204, 74.04949542454311, 92.56230354309082, 83.8913130078997, 82.1307715007237, 75.84189442225865, 78.02447646004813, 72.12042536054338, 57.15676403045654, 48.728623458317344, 24.435998031071254, 26.700382947921753, 30.536050864628383, 22.973037447248185, 36.483111313411165, 80.42252213614327, 81.71276787349156, 54.477080072675435, 52.56809377670288, 52.130694253104075, 39.19195686067854, 24.232726744243077, 16.61275373186384, 7.936835186822074, 6.191865461213248, 4.488434672355652, 6.396340089184897, 8.001996261732918, 10.722483515739441, 18.45475765636989, 10.97596161706107, 4.121333982263293, 2.0188116942133223, 0.8607718284640993, 0.5333550146647862, 0.06930805702826806, 0.6571922696062497, 0.06925307533570699, 0.9855283626488277, 1.206613962139402, 3.4860030795846666, 2.746309582676206, 5.034153137888227, 4.617012390068599, 3.887048976761954, 4.966492448534284, 2.193763860634395, 2.328816648040499, 4.506417913096292, 12.575062598500933, 11.210104618753705, 10.91521177973066, 14.114903262683324, 17.98495520864214, 25.05589372771127, 32.281733649117605, 44.34349373408726, 47.87150757653372, 60.96518284933907, 61.008157457624165, 52.64538206372942, 47.43759257452828, 70.76303918021065, 48.81842197690691, 25.79489197049822, 24.412591287067958, 39.919412408556255, 82.40796988351005, 75.4283445903233, 78.09470190320695, 82.79825714656285, 78.48986680167062, 86.90938118525914, 87.90030547550747, 69.11198738643101, 31.63130930491856, 3.3696950120585303, 0.2966592828077929, 0.037664050568959544, 0.06312352924474648, 0.02132468983264906, 0.1353286254618849, 0.029361760709434748, 0.05208133872864502, 0.026732987125537226, 0.007475242185007248, 0.049589636003864665, 0.024321144579776695, 0.028387927250670533, 0.042578445614448616, 0.04342257710439818, 0.02574646336558674, 0.04090594161035759, 0.04721327405422926, 0.07590239960700274, 0.024417006310873797, 0.001352946346742101, 0.05351468288738813, 0.049644349675093374, 0.016025207504363995, 0.03771412645333579, 0.030421262606978416, 0.03209340020215937, 0.045397412564073286, 0.07045238598116807, 0.07565208125327315, 0.010168670826325459, 0.02255493658594787, 0.04872972857473152, 0.016843318872685944, 0.01083552825730294, 0.020292003639042377, 0.029161145045821155, 0.016335387913776294, 0.11800436436065606, 0.030363329287086214, 0.05001662112772465, 0.016604700159015398, 0.03204943791830114, 0.010952238825016787, 0.05379219013931496, 0.018353795499673912, 0.04374685577516045, 0.05999894333737237, 0.047763040089713674, 0.031464449129998684, 0.0697601716965437, 0.10987788292446307, 0.1781611078019653, 0.16094873712531158, 0.129055704921484, 0.1314916592091322, 0.13471155214522565, 0.11177054100802966, 0.09159177129289933, 0.21925442346504756, 0.13269003347626754, 0.12232769094407558, 0.1002174373716116, 0.21341771951743535, 0.11316902882286481, 0.11155755565102611, 0.10131564629929406, 0.19406902204666818, 0.11029535159468651, 0.11409860822771277, 0.1640509720891714, 0.12673743574747018, 0.0782789345830679, 0.12702813372015953, 0.08423687238246202, 0.10226239264011383, 0.14391038353954042, 0.10268671451402561, 0.11366461722978524, 0.12000681619559016, 0.19854887308818953, 0.15191683891628469, 0.10497592203319073, 0.09381188359111547, 0.12458573334983417, 0.2139950306820018, 0.16656482219696045, 0.14138274560017244, 0.12904764392546245, 0.20671802759170532, 0.12921305719230855, 0.11424139913703714, 0.152530275285244, 0.25387642851897646, 0.13771601021289825, 0.09950524023068802, 0.1967307385057211, 0.15126642238880905, 0.5239372200199536, 0.8820896074175835, 20.5154196534838, 82.12011296408517, 101.26048237936837, 88.42570046016148, 86.24005426679338, 75.48452077593122, 68.0493437903268, 62.58937290736607, 50.33033609390259, 46.82510886873518, 53.755665983472554, 37.428604807172505, 65.84698023114885, 69.97348063332694, 53.97272770745413, 110.22333199637276, 104.31208951132638, 77.31484304155622, 71.21195534297398, 75.4548589161464, 58.58246489933559, 39.889562947409495, 28.95947160039629, 17.188295602798462, 14.181316750390188, 11.510782701628548, 14.927560227257864, 18.48211966242109, 21.02105917249407, 30.504176003592356, 18.99290953363691, 10.385849373681204, 6.105517157486506, 3.2242422912802016, 2.0224479905196597, 1.3415651321411133, 1.735975933926446, 1.3095719345978327, 4.1324532713208875, 4.229669426168714, 6.56205723115376, 8.63057199546269, 10.891723394393921, 10.62444703919547, 9.263142943382263, 11.491506661687579, 8.397658824920654, 7.284043678215571, 11.28031529699053, 21.192882912499563, 19.902703183037893, 21.684233461107524, 29.5710711479187, 36.706874574933735, 44.130190985543386, 51.863525594983784, 64.435425894601, 62.5462315423148, 96.61092158726284, 100.56707300458635, 100.27237905774797, 85.97154113224575, 132.9430937085833, 98.116610118321, 58.97139726366316, 36.02112211499895, 35.872250011989046, 72.59135341644287, 67.45700986044747, 78.22637721470424, 84.06744984218052, 82.22956793648856, 96.2728430884225, 101.17620767865861, 73.89789267948696, 30.23227562223162, 2.32372231568609, 0.5022863617965153, 0.19149839212851866, 0.20149201873157704, 0.08733078850699322, 0.2607572078704834, 0.14047011600009032, 0.20441474047090324, 0.12533326180917875, 0.11704311094113759, 0.1453961580991745, 0.20210540081773484, 0.148886433669499, 0.12253955671829836, 0.17541461517768248, 0.21638151976679051, 0.09646274348987, 0.10157084331980773, 0.11914671877665178, 0.141164488026074, 0.09284508654049464, 0.08399860481066362, 0.146181888080069, 0.1369423988674368, 0.19876118669552462, 0.13004191485898836, 0.10986103489995003, 0.11122739408165216, 0.15637695815946373, 0.19517013510423048, 0.06874499509909324, 0.10353655248348202, 0.1666996335344655, 0.15972630200641497, 0.10902616541300501, 0.1583816898720605, 0.118666872382164, 0.14325452516121523, 0.3234253722642149, 0.08585639976497207, 0.08112861881298677, 0.16604392443384441, 0.08651012075798852, 0.15665576819862637, 0.0970625684463552, 0.11143529042601585, 0.12100747892899172, 0.09565120882221631, 0.1519709045865706, 0.19907851038234575, 0.1311182478176696], [0.03519927550639425, 0.030194940644183328, 0.04078304534777999, 0.04103071062958666, 0.03774543745177133, 0.012850761147482055, 0.02289748820476234, 0.029951207472809722, 0.08339575358799525, 0.06589224389089005, 0.03025593076433454, 0.019376897386142185, 0.024987150449305773, 0.020971125590481927, 0.0134443147440574, 0.050784434391451735, 0.07335754044886146, 0.05037938291206956, 0.024088239130963172, 0.050409306306391954, 0.03535452092598591, 0.057154795953205655, 0.013051125753138746, 0.04035063533644591, 0.017416239915681735, 0.056563221982547214, 0.0319913722840803, 0.05860797369054385, 0.02325362409465015, 0.017003351356834173, 0.09246565654341664, 0.057783010814871104, 0.01784468049715672, 0.06290517667574541, 0.02254510291719011, 0.03977354808843561, 0.03061542540256466, 0.027305222848164182, 0.010472575634984034, 0.04446539721850838, 0.027111696179157922, 0.03771593474916049, 0.09923786350658961, 0.03561830480716058, 0.014427208341658115, 0.19571104965039662, 0.14014488059495175, 7.6966177225112915, 38.62724549429757, 74.0797061920166, 73.49204839978898, 69.52759388514927, 66.94842256818498, 51.49331515175955, 44.317427567073274, 22.63694265910557, 24.365890707288468, 25.777271338871547, 34.08350576673235, 61.36988067626953, 46.85017449515206, 54.44540670939854, 72.93931920187813, 55.567433084760395, 38.13138035365513, 36.562852314540315, 23.45441906792777, 16.05276366642543, 6.6903457301003595, 2.572785271065576, 1.326243485723223, 0.17166098659592016, 0.046643674440149746, 0.1792504143502031, 0.09915079389299665, 0.06366075256041118, 0.04386910403679524, 0.4583231551306588, 0.41693591166819843, 0.328384703291314, 0.20171445608139038, 0.10701857028262955, 0.05900756974837609, 0.1770445512873786, 0.134938793522971, 0.09266868100634643, 0.07559327940855708, 0.11490933543869428, 0.05726439971476793, 0.054385189033512554, 0.06147161538579634, 0.04991811141371727, 0.10600758703159434, 0.1263780700308936, 0.07916934216128928, 0.24319121188351087, 0.09794016528342452, 0.06337532001946654, 0.034261587608073435, 0.5366849931223052, 0.9347476703780038, 0.278357592012201, 0.47274761540549143, 0.64866639567273, 1.166316147361483, 7.4023606436593195, 15.89286650930132, 32.690468379429404, 46.773643561771934, 56.95198324748448, 49.16023513248989, 61.63942909240723, 76.79740374428886, 56.34223018373762, 42.669356550489155, 32.22374745777675, 18.802535840443202, 16.829645224979945, 35.02605669839041, 53.814117704119, 57.47055510112217, 55.60252843584333, 61.83508341653006, 68.4936671938215, 71.50219549451555, 43.64116634641375, 13.152266825948443, 0.6089818137032645, 0.11855442555887358, 0.10299057606607676, 0.035179944043712955, 0.05277139187923499, 0.05601343898368733, 0.02764745555551989, 0.08304847258010081, 0.07114432206643478, 0.01861546404792794, 0.107213031633624, 0.07646989236984934, 0.03157556941732764, 0.030045598479253904, 0.02553138472805066, 0.044615662191063166, 0.02527562452347151, 0.028452669669474875, 0.010428528534248471, 0.037358312867581844, 0.016949641917433058, 0.0250033759179392, 0.04557497839310339, 0.02411118888163141, 0.030111538512366157, 0.044750839937478304, 0.04873910253601415, 0.03534291119181684, 0.021650193259119987, 0.043635141769690175, 0.015101936778851917, 0.00890701892785728, 0.04712054545858076, 0.04495495684178812, 0.06519403814205102, 0.06333493361515657, 0.06458574506853308, 0.007792553997465542, 0.06209725181439093, 0.03157514872561608, 0.03664391388052276, 0.012757071576613401, 0.04672412833731089, 0.021401598384337764, 0.024939054190846424, 0.03993271544043507, 0.019333752736981426, 0.05119728223819818, 0.0678197176062635, 0.028194887430540154, 0.03173760697245598, 0.029809868628425256, 0.02971901957477842, 0.0276199121227754, 0.11534822545945644, 0.03935045775558267, 0.06642574883465256, 0.028864207943635325, 0.037894175720534155, 0.023320585322965468, 0.03189875903938498, 0.07960706510181938, 0.049303182267716954, 0.010009221882293267, 0.024522063887811134, 0.032824626857680936, 0.0307755528816155, 0.04712790417085801, 0.13724680324750288, 0.02453649802399533, 0.01454023361605193, 0.006509251318805451, 0.033002888185105154, 0.06737651888813291, 0.006680263771808573, 0.03606893687642046, 0.08251879457384348, 0.07797699328511953, 0.047038463077374866, 0.10760247680757727, 0.04618856403976679, 0.037109633175922294, 0.044188734742679765, 0.011606046331248112, 0.011535586406742888, 0.05539647762530616, 0.026653323721672808, 0.015238111971744468, 0.06379084807953664, 0.04217869010088699, 0.0192253516787397, 0.17686330101319722, 0.02694128719823701, 0.04505939355918339, 0.25269851886800354, 0.4047737957111427, 15.196491990770612, 53.81838389805385, 92.5116720199585, 82.84361498696464, 88.17753859928676, 86.02972534724644, 79.72405447278703, 67.13804585593087, 30.139833314078196, 29.85361269542149, 19.589608669281006, 12.957908340862819, 35.70073025567191, 24.947800602231705, 37.92640502112252, 65.95098086765834, 55.022544928959434, 41.42500713893345, 33.50288649967739, 21.76520081928798, 12.661740507398333, 5.040969320705958, 0.8750474995800427, 0.412483419158629, 0.058627834410539696, 0.052302890590259006, 0.3564336581953934, 0.036631096354020495, 0.3594734679375376, 0.044455375256282945, 0.3577620397721018, 0.23066157421895436, 0.30931252241134644, 0.15112315650497163, 0.18460249501679624, 0.07277748121746949, 0.2352770236986024, 0.14955264649220876, 0.27259631401726175, 0.20022569596767426, 0.11655765984739576, 0.14431465470365115, 0.1917446053453854, 0.05834916686373098, 0.21974442074341433, 0.048284423005368025, 0.12053432288978781, 0.10844772109495741, 0.23332178433026585, 0.06637613435408898, 0.062054463396114964, 0.05368004187143274, 0.05915992800146341, 0.35835111673389164, 0.37825694573777063, 0.32554785694394794, 0.5153383357184274, 0.20612278953194618, 5.787905880383082, 12.612469962665013, 28.085150241851807, 44.932714870997835, 52.55798414775303, 51.32397712979998, 63.7935791015625, 72.04234845297677, 51.71730770383562, 39.46545532771519, 22.428684302738734, 21.234299387250626, 24.268848691667827, 54.175781863076345, 81.91119452885219, 82.68509878431047, 75.14084202902657, 79.24968011038644, 79.95723601749965, 84.42134938921247, 65.41350991385323, 25.76426431110927, 1.2131156304052897, 0.06857103907636233, 0.05795333667525223, 0.08062889134245259, 0.09804282763174602, 0.010004530660808086, 0.022827261526669775, 0.0500232707709074, 0.023810950706579855, 0.05082982499152422, 0.06479527668229171, 0.08611771038600377, 0.08201326562889985, 0.04328331118449569, 0.006295089127628931, 0.05332084918128593, 0.09196890784161431, 0.04337990064440029, 0.03307830395975283, 0.08081326287771974, 0.025365079187655022, 0.033659747402582846, 0.03462105510490281, 0.056359854859433005, 0.007066715334076434, 0.06143276247062853, 0.02019879497986819, 0.06865778299314634, 0.024068006913044622, 0.019726451486349106, 0.013013948819466999, 0.019113451076139296, 0.025006274958806377, 0.02012506197206676, 0.07365889820669379, 0.05722976050206593, 0.027066721181784357, 0.03840396247271981, 0.04589837157566633, 0.023170233837195804, 0.04783996221210275, 0.05552625762564795, 0.06759609960551773, 0.01862734858877957, 0.034194446567978175, 0.057745202843632014, 0.05139423042003598, 0.057668277328567843, 0.03977749376956906, 0.1339610924146005, 0.10787091204630476, 0.12500177031116827, 0.1863477820796626, 0.1320928819477558, 0.17371711055082933, 0.08113400638103485, 0.12399907197271075, 0.1293830709265811, 0.14257460593112878, 0.092092061947499, 0.11494092802916255, 0.12235365169388907, 0.12488380021282605, 0.08730732476604836, 0.14256027527153492, 0.12591487488576344, 0.11174564555819545, 0.11511429372642722, 0.25505395819033894, 0.07891578719552074, 0.19450772207762512, 0.07424147480300494, 0.09732802491635084, 0.13952263684145041, 0.1615186793995755, 0.18771885707974434, 0.16914259030350617, 0.13321691591824802, 0.10609589157892124, 0.2307837919465133, 0.1572202957634415, 0.14172868989408016, 0.15474729346377508, 0.12278612277337483, 0.1337575183383056, 0.1633393924151148, 0.08842937062893595, 0.06173522624054125, 0.15462826485080378, 0.09323117975145578, 0.13244743006569998, 0.25861740697707447, 0.2343084013887814, 0.10316784333969865, 0.458522264446531, 0.26955031603574753, 13.389341967446462, 57.75151593344552, 97.83795261383057, 93.9719957624163, 90.3120391028268, 85.56760065896171, 67.95791244506836, 60.98898042951311, 32.860268456595286, 35.27658094678606, 38.683786460331504, 46.088700566973, 79.75120803288051, 64.04775810241699, 77.40449564797538, 102.70476273127964, 81.38354137965611, 59.877741132463726, 56.923280239105225, 36.864167894635884, 25.02279077257429, 10.394104702132088, 4.133862018585205, 3.0789758690765927, 0.698197606418814, 0.1650946946548564, 0.7413248036588941, 0.21229994163981505, 0.753860819552626, 0.6024683117866516, 1.3913520148822238, 0.902155842099871, 0.8938316830566951, 0.48527201477970394, 0.42633503302931786, 0.273191117814609, 0.5057776687400681, 0.31022227502294947, 0.3696400395461491, 0.2626986051244395, 0.3776585321341242, 0.2370100835604327, 0.2662271500698158, 0.3149142361113003, 0.4326304266495364, 0.23569543553250177, 0.31777043427739826, 0.20832317003182002, 0.4101450246359621, 0.3352615742811135, 0.2835427394935063, 0.18102437630295753, 0.5729735887476376, 1.4953309382711137, 1.5289477344070161, 1.2015487253665924, 2.166284820863179, 3.0594258095536913, 12.754307883126394, 27.73432353564671, 49.9717777797154, 68.8413758959089, 86.68503774915422, 70.23624065944126, 81.73559270586286, 94.79274477277482, 84.45357513427734, 62.74287945883614, 46.627172061375205, 29.851413590567454, 24.83089542388916, 50.43238776070731, 71.6152982711792, 77.76260580335344, 73.17950453077043, 78.00235339573452, 87.00466878073556, 94.65339865003313, 72.89379460471017, 24.18319477353777, 0.7854549842221397, 0.4557061269879341, 0.17411140725016594, 0.13279223442077637, 0.1891112652208124, 0.100380896457604, 0.08794322064412491, 0.16964803103889736, 0.11761420672493321, 0.11758494829492909, 0.2752387465110847, 0.14395956375769206, 0.11905689431088311, 0.1421581618487835, 0.14434395384575638, 0.10068870029811348, 0.131984859172787, 0.10823950583913497, 0.153186418648277, 0.16324404467429432, 0.1555421429553202, 0.1422061885574034, 0.1287800297141075, 0.1711871927337987, 0.07960214572293417, 0.06567521446517535, 0.11794216984084674, 0.09350327229393379, 0.12415163378630366, 0.13859289458819798, 0.12711577330316814, 0.11021286209246942, 0.21308260464242526, 0.1678390431084803, 0.23528923732893808, 0.15856816486588546, 0.11769567163927214, 0.10017024526106459, 0.1540477510009493, 0.20658255128988198, 0.14854792611939566, 0.12451682133334023, 0.24314235736216816, 0.2836009035153048, 0.09765158433999334, 0.11732966985021319, 0.12949494778045587, 0.18403791316917964, 0.12276328328464713], [0.04025122656353882, 0.03263119687991483, 0.012625681751939868, 0.00974443122478468, 0.07814151088574103, 0.06128409544804266, 0.028730991163424084, 0.025750999372186403, 0.09308098602507796, 0.03770636062004736, 0.0030995070410426706, 0.02731108708706285, 0.015300002847132938, 0.065742660846029, 0.004309979375518326, 0.019611056428402662, 0.05345417791977525, 0.02205069685753967, 0.05035421604822789, 0.03519941121339798, 0.017305513178663592, 0.030477414772446667, 0.03194944899795311, 0.03204856260812708, 0.03449471527710557, 0.014053975913806685, 0.03259136348164507, 0.04192628525197506, 0.045879264029541185, 0.03970142320862838, 0.015310796642942088, 0.11070864727454525, 0.10178053778197084, 0.05584920636777367, 0.06942702457308769, 0.027970002265647054, 0.04907181878973331, 0.03694036922284535, 0.056763691761131795, 0.07308407048029558, 0.11763104796409607, 0.013880707755950945, 0.2872128268437726, 0.056661344931593964, 0.6680046979870115, 7.742779816899981, 37.0597631590707, 66.72379425593785, 73.57453741346086, 70.01858833857945, 75.93857165745327, 53.39132329395839, 54.745885031563894, 26.14437767437526, 20.057865142822266, 54.72408158438546, 43.0309408051627, 57.71200500215803, 91.38205473763603, 50.56576190676008, 60.037111963544575, 57.93238796506609, 27.20117609841483, 16.639467818396433, 8.397149000849042, 2.1084981731006076, 0.33111526391335894, 0.09465162495949439, 0.09610180357205016, 0.047871419095567296, 0.018832849704527428, 0.036293721957398314, 0.1105906975322536, 0.17342767465327466, 0.11058009202991213, 0.07151409651019744, 0.07972245676709072, 0.026906449514042054, 0.07017894315400294, 0.07287559738116604, 0.15504515676626138, 0.10749868809112481, 0.06067419424653053, 0.11140856971698147, 0.07888105977326632, 0.041973423079720566, 0.11969414725899696, 0.099655257537961, 0.41764185950160027, 0.526640286403043, 0.0266166031028011, 0.23259765175836428, 0.005790675524622202, 0.04689076296719057, 0.04775467375293374, 0.08675203206283705, 0.06649439622248922, 0.15040540216224535, 0.06182871479541063, 0.07332836344305958, 0.022848749034372822, 0.0432962067425251, 0.04856330089803253, 0.09124861577791826, 0.028443923353084495, 0.018820853205397725, 0.03748975867139442, 0.3055385649204254, 2.6594510206154416, 7.038701048919132, 17.462516682488577, 32.64968245370047, 40.2266582761492, 37.29819059371948, 36.12795761653355, 56.50135782786778, 60.39037227630615, 49.26077209200178, 23.43163071359907, 16.907595327922277, 27.47488648550851, 43.55407067707607, 37.38765559877668, 57.309259619031636, 59.92273071834019, 73.98368208748954, 66.00101484571184, 33.92808151245117, 8.421510253633771, 0.3565375283360481, 0.19570374861359596, 0.12257923744618893, 0.06415606955332415, 0.11603031600160257, 0.015799301144267832, 0.016543620132974217, 0.03164397931790777, 0.06945591659418174, 0.03900756347658379, 0.11036012454756669, 0.06217232492885419, 0.0906169946704592, 0.02158545423299074, 0.04296485773686852, 0.054367048399788995, 0.03977047771747623, 0.04686636284791997, 0.04248931325439896, 0.04020191403105855, 0.09880561634366002, 0.08249355985649995, 0.025823036042441214, 0.07482759335211345, 0.044950546364166906, 0.043105898025844774, 0.03797220724767872, 0.056608514195041995, 0.05510185772020902, 0.03341697096558554, 0.049284682010433505, 0.03391323112217443, 0.018520754130024995, 0.03411337181127497, 0.01569761419003563, 0.1320351521883692, 0.012547024276240595, 0.040344586196754656, 0.03813616844958492, 0.02927937638014555, 0.01689251944688814, 0.018886007834225893, 0.034688029903918505, 0.02308088943495282, 0.019661229004019072, 0.027450403897091746, 0.06070898952228682, 0.03802454943901726, 0.03271641070023179, 0.022733060510030816, 0.03566612456259983, 0.0500204582432551, 0.021974475322557346, 0.05749003974986928, 0.012131246854551136, 0.09800445647644145, 0.02737119171901473, 0.05673146474042109, 0.02015171991661191, 0.020737663742953112, 0.03841985037018146, 0.019679764884391, 0.01759479470950152, 0.014722476247698069, 0.00570087183898847, 0.04431249613740614, 0.04897074082068034, 0.033339550119957755, 0.0414390937159104, 0.01556765946692654, 0.05002334201708436, 0.06924500076898507, 0.026609773647838404, 0.033291659118341546, 0.05715875859771456, 0.013825720974377223, 0.06660775228270463, 0.019967385700770786, 0.055464507546275854, 0.0032688449968450834, 0.02933573889146958, 0.02498459067594792, 0.04648712623332228, 0.0054939805746211535, 0.018652405190680708, 0.09747033406581197, 0.10193510127386876, 0.048510728004787645, 0.05027556705421635, 0.2768327881182943, 0.2091151832469872, 1.5606387938771928, 14.624066386904035, 53.82620062146868, 84.40983622414726, 88.02005073002407, 82.05627291543144, 95.83316802978516, 70.03261675153459, 79.47185570853097, 39.959819657461985, 28.837537663323538, 37.59892947333199, 20.41939033780779, 35.460881914411274, 57.331955909729004, 46.13889782769339, 55.2250953401838, 59.488426617213655, 26.494226421628678, 14.784006970269338, 5.615915383611407, 1.041001477411815, 0.05421249508591635, 0.0990056348964572, 0.1659498116267579, 0.11783711904925959, 0.05598012969962188, 0.10384723331247057, 0.10754173435270786, 0.3944230968398707, 0.07792222872376442, 0.13745239935815334, 0.16277183858411653, 0.04163008436028447, 0.0714240006304213, 0.15401106939784118, 0.13401321747473308, 0.35179418857608524, 0.18015739853893006, 0.17572632059454918, 0.044564174953848124, 0.19589577402387345, 0.2407584467104503, 0.21891003980168275, 0.45720894634723663, 0.3008827833192689, 0.06854591292462178, 0.17477367099906715, 0.08842627650925092, 0.06503136615668025, 0.14218387832599028, 0.05376937100663781, 0.0411917914503387, 0.09096437745860644, 0.20625437104276248, 0.061846546695700715, 0.0579403495149953, 0.1397492132548775, 0.13147154743117945, 0.06677831563034228, 0.06508507898875646, 0.05894983998898949, 0.2735196644706385, 0.33626211487821167, 0.9472885174410683, 4.578699588775635, 13.902265804154531, 32.12739331381661, 40.08702380316598, 40.7751282283238, 36.951565810612266, 48.44784675325666, 36.79704829624721, 33.56114714486258, 27.936547381537302, 32.49560614994594, 44.20259121486119, 65.342374256679, 61.350272859845845, 80.57304096221924, 75.06027071816581, 84.39131232670375, 83.3010287966047, 51.967164925166536, 18.243952785219463, 0.9140760196106774, 0.21008694038859435, 0.04876994873796191, 0.08089200008128371, 0.08816054183989763, 0.020148924352335076, 0.018329634563997388, 0.02937946029539619, 0.032384040499372144, 0.07716028139527355, 0.058821814001670907, 0.04296427758942757, 0.019492321281826923, 0.015042205341160297, 0.0792824403781976, 0.06906624071832214, 0.04911570982741458, 0.09201729417379413, 0.07417655257242066, 0.09187815378287009, 0.01832180087720709, 0.04534270567819476, 0.03730367383520518, 0.06266068015247583, 0.05095656854765756, 0.0057851878726588825, 0.04445605718397668, 0.02977403180141534, 0.009557315015367098, 0.07076434245599167, 0.038249728070305924, 0.026703119710353867, 0.01623863899814231, 0.022658935648256114, 0.017036102545846785, 0.07696612538503748, 0.005812098571498479, 0.03198703983798623, 0.08055356038468224, 0.0026352650436040547, 0.01239809686584132, 0.0068763934707801256, 0.028630856358047043, 0.04229069248374019, 0.019922266514705758, 0.03356372791209391, 0.0194559348414519, 0.12052809393831662, 0.17043403243379934, 0.0758779723463314, 0.09230314740645033, 0.10018453520855733, 0.08920912950166635, 0.10092584828713111, 0.11171892484916107, 0.2468645562018667, 0.12994438223540783, 0.11359997998390879, 0.0612845297104546, 0.050547574779817035, 0.12610557036740438, 0.09518593735992908, 0.08709712140262127, 0.10713846063507454, 0.15666876892958367, 0.11860473214515618, 0.13166870256619795, 0.07165255836610283, 0.10247608367353678, 0.12982690068227903, 0.1780484031353678, 0.19364959241024085, 0.10036978883934872, 0.08804619511855499, 0.13888370112649032, 0.16212762386671134, 0.1480418068489858, 0.10514485689678363, 0.2916951748941626, 0.16118808356778963, 0.11963818169065885, 0.1325770981077637, 0.1948243129466261, 0.22070513133491787, 0.10959971749356814, 0.16518765395241125, 0.18268252589872905, 0.23417011595198087, 0.09346301481127739, 0.32257771917751854, 0.3229941768305642, 1.1996923621211733, 13.924022350992475, 55.93802915300642, 94.11674063546317, 97.08676201956612, 87.7045955657959, 96.77002838679722, 69.64080088479179, 68.12470395224435, 35.06804118837629, 30.095309257507324, 77.94956793103898, 57.410248211451936, 76.424987248012, 122.05305698939732, 71.2421522140503, 87.13288388933454, 87.10684204101562, 41.553107602255686, 26.685788256781443, 12.40373044354575, 3.4770101564271108, 0.7336310307894434, 0.36622641129153116, 0.2436103836766311, 0.28822425114256994, 0.2538034181509699, 0.29986954054662157, 0.2778058616178376, 0.7250711215393884, 0.1875957708273615, 0.20698208627956255, 0.2789996489882469, 0.16428117187959806, 0.12044158072343894, 0.18637299644095556, 0.6167824694088527, 0.6156867167779377, 0.5472026116081646, 0.4694070518016815, 0.2357800081372261, 0.4578380840165274, 0.633242914719241, 0.4334240954901491, 1.3549443227904183, 2.4131590936865126, 0.4268626890012196, 0.7323220010314668, 0.3388444020279816, 0.6387937111513955, 0.3591649244938578, 0.3210094076182161, 0.2986492360276835, 0.4543215627116816, 0.3845245737050261, 0.23028596437403134, 0.13295581564307213, 0.21134840484176362, 0.2620319037565163, 0.17582765301423414, 0.17823943788451807, 0.17567228206566401, 0.41819174428071293, 0.9413798344986779, 4.138532945087977, 11.799670560019356, 29.0756003175463, 50.27766874858311, 60.869408879961284, 56.45149755477905, 54.6659494808742, 81.8364805494036, 84.90678528376988, 66.01635646820068, 35.107833521706716, 27.191518102373394, 37.163982663835796, 58.19634655543736, 53.707309995378765, 76.15712029593331, 75.40839631216866, 93.64263030460903, 93.60414423261369, 56.66554376057216, 15.644866194043841, 0.7069806722658021, 0.3615077430648463, 0.21037294289895467, 0.16706706024706364, 0.256565055676869, 0.08379217410194022, 0.1102037832939199, 0.13797084082450184, 0.12237525624888283, 0.17702103326363222, 0.15949607507458755, 0.20076899895710604, 0.1920582920845066, 0.1594229018581765, 0.1748445371964148, 0.13302946383399622, 0.13976108761770384, 0.1359932640833514, 0.14707584439643792, 0.12948315484183176, 0.16476354242435523, 0.2017237791525466, 0.09872664165283952, 0.1794344059058598, 0.14614831416734628, 0.09844608777867896, 0.16287503018975258, 0.0873703606692808, 0.15077628940343857, 0.12815471898232186, 0.11550337927682058, 0.11247288582048245, 0.09748809132725, 0.04468363782923136, 0.06904222736401217, 0.23341430936540875, 0.11086080875247717, 0.14394881576299667, 0.22035903776330606, 0.10003594282482352, 0.04705494808565293, 0.1054610474301236, 0.09879368091268198, 0.09710583183914423, 0.08891395998320409, 0.10464172996580601, 0.17059593088924885], [0.047854333583797724, 0.030502537531512122, 0.035729313136211464, 0.021388146427593062, 0.06390581905309643, 0.028224218803058778, 0.04854137743158, 0.01945613161660731, 0.09445289562323264, 0.02861281411190118, 0.04002032109669276, 0.04481056798249483, 0.05127351225486823, 0.020403005182743073, 0.0514271020490144, 0.033399339233125956, 0.029147655769650425, 0.008185699731776757, 0.016457064509657875, 0.01155954971909523, 0.044919225187706094, 0.049096015348498306, 0.03791940025985241, 0.005644271840407912, 0.04167426377534866, 0.0488316513198827, 0.017662134221089736, 0.022838511637278965, 0.037649852223694324, 0.02788647630118898, 0.015519793910373534, 0.06555294245481491, 0.011712816360938762, 0.06684243718960456, 0.05008864761995418, 0.019413512832086, 0.024002127948084047, 0.038866221239524226, 0.054418138694018126, 0.11660375951656274, 0.0413775946944952, 0.059752811544707844, 0.34558901297194616, 2.7890316673687527, 39.94324125562395, 73.73980031694684, 74.96451759338379, 72.7925454548427, 59.68289279937744, 63.23841108594622, 42.28619466509138, 54.59589774268014, 22.480385848454066, 44.19182498114449, 44.016292640141074, 35.44720091138567, 48.80189916065761, 59.5825469153268, 41.61526618685041, 35.182495389665874, 28.046469620295934, 7.590424929346357, 2.169774119343076, 0.03586934580068503, 0.2519787832030228, 0.06687491866094725, 0.06304808972137314, 0.04084589804655739, 0.1092572540843061, 0.054107159309621365, 0.03046922485477158, 0.057346414242471964, 0.021207929222977588, 0.011539689847268164, 0.04065819151167359, 0.051632223185151815, 0.13456850339259419, 0.34599640539714266, 0.09427128572549139, 0.18399889740560735, 0.06302484311163425, 0.08993791682379586, 0.03841851704886981, 0.15739009236650808, 0.13707170050059045, 0.24295763298869133, 0.24848658059324535, 0.1329888060156788, 0.1139225283903735, 0.09212803108883755, 0.026343757386452386, 0.04612507012539676, 0.09925844347370522, 0.06618454320622341, 0.04436896042898297, 0.14356761478952, 0.06233243205185447, 0.12535862544817583, 0.037620013646249256, 0.16139188834599086, 0.16600543792758668, 0.2273111447159733, 0.19007338716515473, 0.23580006563237735, 0.10922946128994226, 0.0672495582007936, 0.1299691487635885, 0.09734984660255057, 0.13038367937718118, 0.08795203481401716, 0.14094248493867262, 2.468263953924179, 11.833841800689697, 23.67202796254839, 45.92581394740513, 40.40550490788051, 46.17929812840053, 48.921616622379844, 55.94462994166783, 41.36358853748867, 31.618538515908376, 23.591322898864746, 25.15454077720642, 27.578440700258525, 47.466608251844136, 57.06523193631853, 63.44861493791853, 70.50749833243233, 69.59326825823102, 39.123447622571675, 6.228822060993739, 0.17934838123619556, 0.08063039769019399, 0.03483843397615211, 0.033534089502479346, 0.03973760608849781, 0.02731368417984673, 0.07009560548301254, 0.05822382787508624, 0.0609975161829165, 0.07642718537577561, 0.042913926898368766, 0.08009632277701582, 0.06476500044975962, 0.035912799183279276, 0.06743165664374828, 0.02194438568715538, 0.008123110813487853, 0.03498950979805418, 0.029442211213920797, 0.03429052712661879, 0.03405826798241053, 0.05415444980774607, 0.02754442679828831, 0.007415348747079926, 0.010611707544220346, 0.03895095329997795, 0.07121924590319395, 0.03345163392701319, 0.010655762278474867, 0.02443366264924407, 0.028230546142107675, 0.016282389239807214, 0.08998751094830887, 0.0941006341683013, 0.045228650726910145, 0.05670372283618365, 0.014807986927085688, 0.04162574512884021, 0.005053992599381932, 0.03169702718566571, 0.08492568042129278, 0.030705656989344528, 0.014146752855075257, 0.027252337828810726, 0.029623536126954213, 0.05226541170850396, 0.016140324362952794, 0.029082272135253464, 0.05761704793465989, 0.010807460656256547, 0.023891696373799017, 0.03760344721376896, 0.017037958339122788, 0.017900696955621243, 0.030283333401062658, 0.0392751403685127, 0.03712638959820781, 0.052564533693449836, 0.02198084507004491, 0.034251206022288115, 0.027776451847915138, 0.033600389159151485, 0.05794782018555062, 0.00788411805738828, 0.04889474829126682, 0.03904604319749134, 0.08088950985776526, 0.009456920670345426, 0.03494165272318891, 0.0012532188744184428, 0.07625688665679523, 0.0017202802908806397, 0.021498330336596285, 0.07137686280267579, 0.07401296456477471, 0.065505207516253, 0.06959509091185671, 0.03237443583618317, 0.055985049078507085, 0.03160830533930233, 0.0312523831879454, 0.012299457382011627, 0.03042066210348691, 0.04324047526876841, 0.10824612155556679, 0.03484389279037714, 0.05775926208921841, 0.1072018900886178, 7.5514906985419135, 58.07300213405064, 89.7290643964495, 92.14445972442627, 94.69363566807338, 84.08350712912423, 85.60685798100063, 70.91507966177804, 74.69707448141915, 26.07802758898054, 30.6062867300851, 22.69558024406433, 24.995904718126567, 34.324660369328086, 52.227611201150076, 44.62682042803083, 38.56509038380214, 25.87034593309675, 6.291985963072095, 0.9764121089662824, 0.1177260157253061, 0.22763803574655736, 0.01292542290009026, 0.0585913835093379, 0.08067047196839537, 0.17408886631684645, 0.07246760105980293, 0.017178700072690845, 0.09501586934285504, 0.025419582513027957, 0.008006731031595596, 0.14320728555321693, 0.09447820497942822, 0.11260302883705922, 0.4158263440643038, 0.23625574260950089, 0.3609594596283776, 0.1787214827324663, 0.08386200214070932, 0.2125233289386545, 0.2640723671231951, 0.1891515702009201, 0.184722812846303, 0.09514299287859883, 0.20573499319808825, 0.15995431691408157, 0.39264080247708727, 0.2346637366073472, 0.08814171249313013, 0.20419188242937836, 0.11883960025651114, 0.04609193726043616, 0.27638726202504976, 0.2774212136864662, 0.03119880606287292, 0.052108385134488344, 0.06799396539905242, 0.19452452260468686, 0.09142585591013942, 0.1060283909152661, 0.21467494991208824, 0.11995612962969712, 0.10305820565138545, 0.16912774395729813, 0.1747704411723784, 0.20860663482121058, 0.11287355396364417, 0.3389837459794113, 1.0625620633363724, 7.916774868965149, 19.78381950514657, 39.56512723650251, 37.66698013033186, 49.87707730701992, 39.69852917534964, 27.903765780585154, 18.548499277659825, 24.330322878701345, 37.07555641446795, 38.879510266440256, 44.9477334022522, 69.50316401890346, 78.30628844669887, 75.73521872929165, 82.8325742994036, 85.56243814740861, 57.99293109348842, 13.49242717879159, 0.12694627525550978, 0.120168945352946, 0.023378954601607153, 0.04214310772450907, 0.04296296462416649, 0.04763909209785717, 0.045956094549702745, 0.08517506239669663, 0.06568727881780692, 0.12770487740635872, 0.05608294811099768, 0.07131274124341351, 0.13730549652661594, 0.02889755115445171, 0.0756939740053245, 0.03898358744169984, 0.009307385122935687, 0.06312310176768474, 0.01468264454576586, 0.043697041126766374, 0.012743819787699198, 0.020490743153329407, 0.0055814441626093215, 0.02143252601048776, 0.01858283669155623, 0.029030364206326858, 0.047829567055617056, 0.05054923379793763, 0.0389436454778271, 0.018851277019296373, 0.020364137000537345, 0.0928645401394793, 0.06089319142379931, 0.11814972013235092, 0.01741123402358166, 0.03349911780761821, 0.028147189811404263, 0.006070651371763753, 0.04330093273892999, 0.04423898704616087, 0.017000448923291903, 0.02427123154380492, 0.022028223777722036, 0.04244682339153119, 0.025915252344150628, 0.1808112891657012, 0.14879658206232957, 0.08930943733347313, 0.1898673703627927, 0.08714126010558434, 0.13275449430303915, 0.11622307422970023, 0.1112870644511921, 0.21829302076782497, 0.1370102795107024, 0.07026481176061289, 0.12536219454237393, 0.11079849888171468, 0.16508553443210466, 0.1512805630585977, 0.17321954082165444, 0.05000694521835872, 0.07858618881021227, 0.08613900960023914, 0.07740523253700562, 0.21566289689924034, 0.1005361791966217, 0.15512055557753357, 0.11553183703550271, 0.12075392396322318, 0.19791905688388006, 0.13238530339939253, 0.1379886455833912, 0.18576392983751638, 0.1368569034550871, 0.09725800688777651, 0.1747980575476374, 0.12273215209799153, 0.130496940442494, 0.13939299594078744, 0.1652725793953453, 0.13226993887552194, 0.09811930531369788, 0.15075404702552728, 0.18413677572139672, 0.10883553099951573, 0.1710008941590786, 0.34919355383941103, 6.2145291822297235, 60.88509791237967, 100.98047692435128, 99.54931477137974, 91.57816764286586, 78.93285615103585, 82.13619109562465, 58.38478864942278, 72.6080846786499, 32.40103074482509, 61.299405097961426, 60.86307212284633, 55.273843901497976, 70.17112909044538, 77.1046391895839, 60.8147543498448, 53.63387795857021, 43.22496577671596, 13.169567840439932, 3.903911820479802, 0.20950604655912944, 0.4639210690345083, 0.23216094662036213, 0.15696752789829457, 0.3572820983827114, 0.42663103714585304, 0.46926439659936087, 0.19286815077066422, 0.2755145845668656, 0.2559926706765379, 0.1239604361887489, 0.46790515525000437, 0.31179194365228924, 0.5106298455170223, 0.9097559228539467, 0.4589464302573885, 0.5483637207320758, 0.4537185893527099, 0.21040567542825425, 0.4256378247269562, 0.464691124856472, 0.5633289462753704, 0.3559513012213366, 0.6830359856997217, 0.4173616516802992, 0.4965772767152105, 0.45165576147181646, 0.39643888867327143, 0.18883426008479937, 0.46391124384743826, 0.23703611216374806, 0.1884497750018324, 0.6096195823379925, 0.5235455153243882, 0.3900831325777939, 0.18110764612044605, 0.24874154691185268, 0.5044379691992487, 0.3734978368239743, 0.43864401110580986, 0.3397317629839693, 0.39967452362179756, 0.18789672824953282, 0.4383734384817736, 0.33822470956615036, 0.33354892475264414, 0.2437823787331581, 0.5192265585064888, 4.020403581006186, 17.63849891935076, 37.39665004185268, 68.20495564596993, 56.23428297042847, 73.1719309943063, 76.46795490809849, 76.01954596383231, 56.40683453423636, 45.01045479093279, 35.626259463174, 35.996949332101, 37.33970955439976, 62.98234912327358, 78.09962817600795, 78.36978803362165, 92.73425756181989, 94.54805006299699, 62.54721123831612, 12.06869351863861, 0.27478353093777386, 0.09350767598620482, 0.16828546486794949, 0.07275890971400908, 0.16245429776608944, 0.15247929016394274, 0.16903781092592648, 0.16093389077910356, 0.1943603985543762, 0.19038055996809686, 0.1871756219438144, 0.1881551415260349, 0.2212622221559286, 0.1272983942180872, 0.16675151432199137, 0.11118459887802601, 0.11824098309235913, 0.16026431242270128, 0.10284250615430729, 0.1084618414086955, 0.12252887657710484, 0.13042713275977544, 0.10034331918827125, 0.10290509422442742, 0.13904318399727345, 0.1737059825765235, 0.21186719914632185, 0.13659614244742052, 0.14148611362491334, 0.06155666296503373, 0.09411375703556196, 0.1700202210673264, 0.14925168907003744, 0.24402971831815584, 0.13680822535284928, 0.07643732268895422, 0.09589196661753313, 0.09828392469457217, 0.09567323406892163, 0.08534976480794804, 0.23396864533424377, 0.10861091555229255, 0.14878368989697524, 0.20013070106506348, 0.1265348523323025], [0.04726056115967887, 0.007074219931382686, 0.01907624869740435, 0.05872956716588565, 0.018998190028859035, 0.05469360016286373, 0.011153270091329302, 0.05622937596802201, 0.02547532755748502, 0.024311600984739404, 0.022577304492837617, 0.04069807919274483, 0.011055209906771779, 0.018273772472249608, 0.015374224400147796, 0.03990935008706791, 0.023777872124420743, 0.012505201922197427, 0.015708301116579344, 0.01648643150526498, 0.027393856484975134, 0.043022183767919026, 0.024398095539904067, 0.036766175712857924, 0.017444263411951915, 0.04943117093560951, 0.04648747907153197, 0.05491133526499782, 0.016978591614003693, 0.0029001602379139513, 0.02711309226495879, 0.021097981104893342, 0.005267244705464691, 0.08452731929719448, 0.03405500762164593, 0.0312590090824025, 0.03261681533019457, 0.023119447187387517, 0.056865930025066645, 0.11142281895237309, 0.06400925493133919, 2.1113771157605306, 20.174561875207083, 61.89822169712612, 89.3495259966169, 73.13086019243512, 73.42223984854562, 42.44948080607823, 46.44951704570225, 38.85155071531023, 21.930442878178187, 21.845640114375524, 47.55516651698521, 51.58378069741385, 54.21940265383039, 50.59406886781965, 59.57218715122768, 50.629744393484934, 29.44458266666957, 11.301053064210073, 0.7107135919587952, 0.2562750226684979, 0.06560350688440458, 0.06460266773189817, 0.1186920188899551, 0.0841623828081148, 0.030083263958139077, 0.01472589436785451, 0.06214316827910287, 0.042653515336236784, 0.03744164714589715, 0.10402772362743105, 0.03845493063064558, 0.14517931187791483, 0.06668501706527812, 0.2217520158737898, 0.16687422059476376, 0.03878682246431708, 0.03154773251818759, 0.08688040410301515, 0.040691802743822336, 0.17804501046027454, 0.15012539790144988, 0.10034969063209635, 0.11403565374868256, 0.15617668176335947, 0.12290527352264949, 0.11116989502417189, 0.06510368441896779, 0.2768283912113735, 0.09494040946343116, 0.04243319501568164, 0.09661840620849814, 0.08897467529667274, 0.1700739881822041, 0.10191543732902833, 0.036941923068038056, 0.07004934975079127, 0.011510790192655154, 0.09116822973425899, 0.018945004757759825, 0.06792446305709225, 0.02387986272307379, 0.13331922542835983, 0.025294915274051682, 0.009931193747823792, 0.08224636276385613, 0.02980983809434942, 0.058886274828442504, 0.01890919846482575, 0.010309543177884604, 0.10691149067133665, 0.45712106249162127, 0.027078980613233786, 5.808720512049539, 27.361429350716726, 45.0644075529916, 59.50908361162458, 59.671852111816406, 71.36752550942558, 61.6856415612357, 35.64729166030884, 33.91830539703369, 29.801185062953405, 32.057046277182444, 32.01613875797817, 49.580038343157085, 51.81950528281075, 59.8560905456543, 66.51101262228829, 62.16951411111014, 21.873156717845372, 0.4057823973042624, 0.13938021234103612, 0.018089355135868703, 0.08031396966959749, 0.009897734337885464, 0.03248142045257347, 0.06193077324756554, 0.04836222043793116, 0.02343014158707644, 0.03803822531231812, 0.04969575548810618, 0.07148667691009385, 0.07509387084948164, 0.07305528023945433, 0.011529298083457564, 0.051857330570263524, 0.026473184548584477, 0.056294579790639024, 0.025371638924947808, 0.019845140831811086, 0.050300411613924165, 0.017298975493758917, 0.04095429401578648, 0.03584424339767013, 0.03340909656669412, 0.029360396854047264, 0.017655231823612536, 0.03191459604672023, 0.027212833520025015, 0.01232025702483952, 0.04205703895006861, 0.041509505294795544, 0.03837069729343057, 0.1140766508345093, 0.05712210413600717, 0.023609223941873227, 0.008030539977231195, 0.029007880948483944, 0.05811149640274899, 0.054983500856906176, 0.06328313425183296, 0.012456921611114271, 0.030485390951590877, 0.013273228924455387, 0.05766499321907759, 0.031644155737012625, 0.020384438768295304, 0.03306910641757505, 0.012939515224258815, 0.011604919114948382, 0.01741309660220785, 0.024573661386966705, 0.05109928821080497, 0.07100578557167735, 0.06607610652489321, 0.02237219862373812, 0.008681799584467496, 0.04732751899531909, 0.039421588581587584, 0.02708483297776963, 0.05233942630833813, 0.01466009852343372, 0.02358820123065795, 0.024973176020596708, 0.03409409802407026, 0.018056821078062057, 0.002830941608408466, 0.013634756623235132, 0.001935185053818194, 0.012345930245438856, 0.040581350813486745, 0.05320201734347003, 0.019958257708432417, 0.02597477682866156, 0.0762361166998744, 0.04061459902940052, 0.019810309932966317, 0.07270344626158476, 0.07585746023271765, 0.06673769173877579, 0.03551463822701147, 0.008780032795454775, 0.06630829442292452, 0.08973607301179852, 0.0451965933399541, 5.7976133823394775, 35.366751194000244, 83.4311546598162, 100.38043049403599, 87.35030691964286, 83.86805738721574, 49.45084353855678, 62.78030245644705, 61.341525077819824, 28.824768611363, 18.623558929988317, 19.290158680507115, 29.55301625388009, 39.179623808179585, 46.730641160692485, 61.67969390324184, 51.25256701878139, 28.275053194590978, 9.182141712733678, 0.3026585094630718, 0.24196881747671536, 0.1389046542878662, 0.1010808256853904, 0.21282003873160907, 0.13565301948360034, 0.00782138664674546, 0.1167759717042957, 0.0938523853463786, 0.04388716324631657, 0.20406844333878585, 0.1969488603728158, 0.07298211380839348, 0.33272021636366844, 0.2029976879379579, 0.29071664597306934, 0.1532342146549906, 0.2126511785068682, 0.11978327961904661, 0.4330403432250023, 0.4834991384829794, 0.2402846392776285, 0.3674380034208298, 0.356317791555609, 0.25994519144296646, 0.1831033940293959, 0.5905138275453022, 0.3304490510906492, 0.8686836553471429, 0.6206055528351239, 0.5247379999075616, 0.3306862397917679, 0.7897468539220946, 0.33434761475239483, 0.9313849593911852, 0.31665134004184176, 0.14706984614687307, 0.09259346539952926, 0.17014038961912903, 0.17263331370694296, 0.07646628256355013, 0.11830243122364793, 0.04644815457452621, 0.18999155584190572, 0.044524290665451965, 0.06557468271681241, 0.025607102450781634, 0.010318381944671273, 0.06853509707642452, 0.059613270818122795, 0.0992916374068175, 0.14496961741575173, 0.5764067045279911, 0.09865559903638703, 3.272871647562299, 21.310639245169504, 40.07423564365932, 59.09977912902832, 54.157706124441965, 44.015316418239046, 33.699374607631135, 16.011036259787424, 17.981604439871653, 35.86236619949341, 51.926219190870015, 53.75099679401943, 78.82155295780727, 69.75047125135148, 72.89000783647809, 75.5659258706229, 79.11296040671212, 38.20988457543509, 1.8776916095188685, 0.19031335785984993, 0.05633946827479771, 0.064350327343813, 0.11078610883227416, 0.03254940966144204, 0.26154419992651257, 0.0839415875130466, 0.07085107280207531, 0.026025275101086924, 0.03193828709689634, 0.05905510112643242, 0.025368697475641966, 0.04929620014237506, 0.05394867388531566, 0.018258963445467607, 0.027577915894133703, 0.005881294724531472, 0.04122053419372865, 0.03696327656507492, 0.08914946591747658, 0.060118881187268665, 0.0174331252596208, 0.06053378499512162, 0.03637036248775465, 0.031307195246751816, 0.039209020523620505, 0.004813430306967348, 0.01056615324757461, 0.018688969746498123, 0.06853361108473369, 0.03821308378662382, 0.054994177605424605, 0.08370540304375546, 0.02276455471292138, 0.01165324607531407, 0.0029680648419473854, 0.02871294552460313, 0.01326496436792825, 0.048768147227487395, 0.05917750884379659, 0.0306975383178464, 0.02784149451846523, 0.060008938158197064, 0.14489145018160343, 0.06343602176223483, 0.08959524306867804, 0.1338721364736557, 0.10012692080012389, 0.11046233906277589, 0.13747325752462658, 0.1321224525038685, 0.09717675910464355, 0.09514700980590922, 0.13421297818422318, 0.1155642167265926, 0.07016962686819689, 0.1271415576338768, 0.16404688730835915, 0.13672576977738313, 0.1290652858359473, 0.079099398771567, 0.11305922150079693, 0.11468559530164514, 0.10803133129541363, 0.10242214013955422, 0.0744632404031498, 0.1344188457088811, 0.0946358490203108, 0.1485894796039377, 0.163353153105293, 0.2262415156832763, 0.0663346622937492, 0.07775257461305175, 0.119620431214571, 0.10101044803325619, 0.06923591518508536, 0.21495829256517546, 0.23389639492545808, 0.1523630978273494, 0.1647380023662533, 0.06499830114522151, 0.15491820286427224, 0.26072148978710175, 0.07940631373120205, 4.922675805432456, 35.503404889787944, 91.82229260035923, 112.66088512965611, 92.51652186257499, 92.84713799612862, 58.09556293487549, 62.53442655290876, 52.07652957098824, 34.099389348711284, 31.748518466949463, 64.76857117244175, 73.30075754438127, 78.54550102778843, 67.95983014787946, 82.34391444069999, 69.7914378302438, 43.695445673806326, 19.97117941720145, 1.87310015303748, 0.8822738432458469, 0.3264301967407976, 0.20043720890368733, 0.27558984767113415, 0.32511411021862713, 0.19861302178885254, 0.34451437635081156, 0.24861943774989673, 0.2324550508388451, 0.2897118984588555, 0.36172956973314285, 0.28440806163208826, 0.527117595076561, 0.20308112060385092, 0.5219948185341698, 0.31618871486612726, 0.24911080566900118, 0.24534037656017713, 0.4697064757347107, 0.5052954203316143, 0.5862199493816921, 0.49406528579337256, 0.560672671667167, 0.34827131618346485, 0.5121133401989937, 0.5853090839726585, 0.40217324239867075, 0.6410730459860393, 0.7508300478969301, 0.41234271813716206, 0.1596684365400246, 0.43045292635049137, 0.31517161801457405, 0.5923374039786202, 0.2804263638598578, 0.3654995917209557, 0.23614416431103433, 0.19798361270555428, 0.22329602230872425, 0.12166017533413001, 0.18778155371546745, 0.1203949653676578, 0.2531862769808088, 0.1434283929743937, 0.2086787223815918, 0.11808448577565805, 0.2804089662219797, 0.16377187706530094, 0.26824972725340296, 0.25346689192312105, 0.2941561671239989, 0.6892389357089996, 0.25774630372013363, 8.002169966697693, 39.80208165305001, 60.61404173714774, 83.30102184840611, 86.42812810625348, 106.0402524130685, 85.46086938040597, 49.00984484808785, 49.312028953007285, 39.662766797201975, 41.31761925561087, 43.57031903948103, 68.1833050591605, 67.65471390315464, 75.32562242235456, 84.82823589869908, 88.85615525926862, 39.26540626798357, 1.1969813704490662, 0.39517347514629364, 0.1634030118584633, 0.20182751358619758, 0.2916962334087917, 0.1717120260000229, 0.3035243744296687, 0.24477838671633176, 0.20614203278507504, 0.17127205032323087, 0.1491005521799837, 0.17655173130333424, 0.15223432545151028, 0.11478137730487756, 0.14079676275806768, 0.1332786897463458, 0.12784293214125292, 0.13152564024286612, 0.13920804086540425, 0.07678317198795931, 0.15520520960646017, 0.11486943757959775, 0.10073138693613665, 0.12440455092915467, 0.0897415555747492, 0.14038676475839956, 0.10167303747896637, 0.1273436796452318, 0.12193921607519899, 0.11110491172543593, 0.14438185681189808, 0.1415303676788296, 0.15938700735569, 0.18686342798173428, 0.13357389319155896, 0.10873796444918428, 0.07686208561062813, 0.11805302889219352, 0.24260881170630455, 0.12634406185575894, 0.14498833141156606, 0.10238528890269143, 0.22085981017776898, 0.12781501721058572], [0.0189500869850495, 0.025191800003605228, 0.04484481703756111, 0.022004373271816542, 0.014735746696325285, 0.017002413282170892, 0.05760608280875853, 0.024970687493415814, 0.05819601472467184, 0.05630514458087938, 0.07801409557993923, 0.02032234433240124, 0.02597268354812903, 0.007953319299433912, 0.039962411525526216, 0.09252482479704277, 0.04422485316172242, 0.0940130827948451, 0.023914389977497712, 0.03519657154434493, 0.07564228999295405, 0.023951650031709244, 0.018191720625119548, 0.07728312337504965, 0.021372823410534432, 0.061441135592758656, 0.09661960721548114, 0.025632705273372785, 0.06829294149896928, 0.022566848268200244, 0.06513067654200963, 0.04614451015368104, 0.16839441045054368, 0.036474917948778184, 0.08932851773819753, 0.05162300867959857, 0.031351588400346894, 0.030160311609506607, 0.14921750447579793, 0.4726042002439499, 12.7140873670578, 52.450558049338206, 71.15716184888566, 71.10570349012102, 63.122056552342, 64.35222121647426, 64.60020242418561, 102.60062313079834, 61.421248708452495, 27.517647436686925, 52.079552037375315, 58.81899547576904, 63.72963482992989, 51.84019701821463, 61.534483500889365, 56.561894008091514, 31.547329902648926, 9.973210624286107, 1.031250766345433, 0.09457986988127232, 0.021659901398899298, 0.064821339212358, 0.04776200871648533, 0.05989397396998746, 0.054536838217505386, 0.01778668610911284, 0.031026081581200873, 0.053383868121142895, 0.1820461686168398, 0.017225529167002866, 0.039963045955768654, 0.03145557728462985, 0.07934802757310015, 0.06150332332721778, 0.15346761713070528, 0.0751800990796515, 0.020253238933426992, 0.2501902463180678, 0.14408476703933307, 0.6141466594168118, 0.31822130722658976, 0.13169209845364094, 0.13211409295243876, 0.13927968059267315, 0.06658903150154011, 0.20272315266941274, 0.09498505028230803, 0.1883955736245428, 0.2720521560737065, 0.24202695435711316, 0.3626287100570542, 0.23637318345052855, 0.7139408130730901, 0.14654763202582086, 0.0711491396650672, 0.1512112303503922, 0.10011851375124284, 0.08324087118463856, 0.1881384224231754, 0.0746598866369043, 0.1943777554801532, 0.11560389745448317, 0.31738095517669407, 0.2879483588039875, 0.12233478842037064, 0.08330820221453905, 0.07916238039199795, 0.005475198725304965, 0.15852996334433556, 0.03442648858098047, 0.05456558096089533, 0.07201035666678633, 0.17138357433889592, 0.0256160557203527, 0.14945731232208864, 0.30395689979195595, 1.7859444469213486, 17.94615646771022, 40.270258222307476, 44.314804622105186, 55.402246611458914, 67.24184499468122, 108.47928551265171, 46.40108462742397, 23.073409387043544, 20.803900173732213, 23.92193729536874, 41.069217681884766, 50.884170055389404, 52.161137785230366, 65.26799379076276, 61.54064655303955, 42.65076664515904, 5.806002029350825, 0.020844214096931473, 0.08324171256806169, 0.052297011084322415, 0.02883007763219731, 0.09912851758833442, 0.04913713117795331, 0.04167816874438098, 0.007525986426376871, 0.059626047632523944, 0.06700106510626418, 0.047701290010341575, 0.036204749053078036, 0.03758176801992314, 0.024745919375813434, 0.06358127575367689, 0.028303916133674126, 0.039660134352743626, 0.0242450333067349, 0.04752494215166994, 0.06595179890947682, 0.04325319780036807, 0.04959705578429358, 0.04104111935677273, 0.02340369907739971, 0.03589196476553168, 0.0725466911015766, 0.07238511155758585, 0.03759896209729569, 0.03760540817997285, 0.06911971606314182, 0.01081876759417355, 0.029503893439791033, 0.08438877601708684, 0.013263475831731089, 0.030835705011018684, 0.0452664281640734, 0.04817782515393836, 0.037749454379081726, 0.04741847661456891, 0.07565698706145797, 0.09388561320624181, 0.07546315674803086, 0.019214286468923092, 0.022905313409864902, 0.012349704596480089, 0.02942547175501074, 0.051920790557882616, 0.043984183575958014, 0.02767822881495314, 0.02189809433184564, 0.06756993529519864, 0.02797837369143963, 0.08492652180471591, 0.06834442873618432, 0.07188359275460243, 0.04265235843402999, 0.03170316114223429, 0.0681741503732545, 0.05059555399098566, 0.056817180676651854, 0.04579869817410197, 0.06307922769337893, 0.05546911479905248, 0.02493244017075215, 0.030664744720395123, 0.06916174452219691, 0.04489835345053247, 0.0722801625462515, 0.023063037178612182, 0.025332692711214935, 0.03935888176783919, 0.03887279285117984, 0.012718995584041944, 0.0023337474059579627, 0.006137928118862743, 0.05450833635404706, 0.0904879712366632, 0.0287837947585753, 0.08757421294493334, 0.06068649608641863, 0.09189984654741627, 1.7105640918016434, 26.581542696271622, 74.00463785443986, 85.2140485218593, 82.45038863590786, 79.11994334629604, 85.60209846496582, 97.4902091707502, 103.65094757080078, 53.634162834712434, 19.487504890986852, 21.592274052756174, 29.01431894302368, 49.0352509362357, 47.2412052154541, 60.223879541669575, 56.07498162133353, 25.965284381593975, 6.700153112411499, 0.22144466665174278, 0.16334138730806963, 0.1192869855357068, 0.025662425107189586, 0.034720317992780886, 0.09498401890907969, 0.07327572948166303, 0.11742860025593213, 0.016565604667578424, 0.08202356579048292, 0.18173005272235188, 0.25134590002042906, 0.45458993688225746, 0.2157258242368698, 0.40115937537380625, 0.6075738263981683, 0.48501210872616085, 0.6563793846539089, 0.7449882413659776, 0.8548868671059608, 1.2960206674677985, 1.2679128157241004, 1.4558293436254774, 0.7899738645979336, 1.2346314873014177, 1.263325267604419, 1.5132356860807963, 2.3221420347690582, 0.8172814249992371, 1.5897605397871561, 1.4962666652032306, 2.2301672101020813, 2.0673049092292786, 1.906412422657013, 2.9301309074674333, 1.8002810776233673, 0.5105122689689908, 1.0947054071085793, 1.1242734662124088, 0.6251925038439887, 0.48441771204982487, 0.35701499985797064, 1.213961573583739, 0.8177064050521169, 1.2965537245784486, 1.793764318738665, 0.4400137018944536, 0.40025969222187996, 0.1988910718687943, 0.06169632582792214, 0.5211400272590774, 0.020292958677081124, 0.015524080555353845, 0.07127641926386527, 0.2976734755294663, 0.12429230766636984, 0.1669724860361644, 0.5044496400015694, 0.5141933485865593, 12.509034735815865, 36.20711496898106, 46.9900347845895, 53.27198103496006, 47.744623047964915, 68.43741457802909, 21.404360021863663, 15.633210590907506, 28.07178017071315, 37.44425562449864, 65.75283908843994, 68.62774658203125, 69.83511420658657, 78.69535282679966, 71.58092553274972, 62.23759256090437, 14.610585144587926, 0.013766640930303504, 0.08085151189672095, 0.09056060162505933, 0.021649801405146718, 0.10185550233083111, 0.07154085114598274, 0.04758858534374407, 0.02399625183482255, 0.03128628958282726, 0.003685461257451347, 0.066261156595179, 0.02841087700133877, 0.027761559700593352, 0.02826300386472472, 0.019616598363167474, 0.01126266605154212, 0.06071790547243186, 0.0055880446120032245, 0.03998019592836499, 0.008494870820348817, 0.0229076492666666, 0.04849046355645571, 0.04174311811636601, 0.015431348567030259, 0.05823400590036597, 0.02536545068557773, 0.026468071787218963, 0.05250331626406737, 0.027341712765129547, 0.05451654662777271, 0.050552511122077703, 0.02363217029986637, 0.035242823883891106, 0.007999993178860416, 0.023457177814894488, 0.005619528212784124, 0.018668296480817453, 0.061156368016132286, 0.007270216043772442, 0.029194362727659087, 0.012237069479721998, 0.03604305415813412, 0.15048371867409774, 0.11373481167746441, 0.09821290921952043, 0.05552714650652238, 0.11903683681573186, 0.13239388008202824, 0.22347124719194003, 0.1499180511704513, 0.1687825731933117, 0.13941142495189393, 0.22156883856015547, 0.1274643231715475, 0.1105377853714994, 0.14442810575876916, 0.09888021448361022, 0.21079710870981216, 0.1424320592944111, 0.14922461552279337, 0.09430709201842546, 0.16520928564880574, 0.1487800936613764, 0.08106883987784386, 0.12183166827474322, 0.11416317762008735, 0.13541977985629014, 0.1148737802037171, 0.19256671837397984, 0.20522653976721422, 0.12826758649732384, 0.14641529055578367, 0.12681626794593676, 0.16189472350691045, 0.22160642940018857, 0.257084243531738, 0.11362582538276911, 0.1293578701359885, 0.11518545847918306, 0.20115697171006883, 0.29366531489150866, 1.5730392656155994, 27.836637496948242, 83.14599364144462, 99.41270623888288, 90.5619866507394, 82.91438238961356, 85.10753958565849, 84.53281933920724, 116.4699570792062, 72.26510769980294, 39.70351798193795, 70.96785123007638, 76.72478812081474, 89.54281793321881, 70.1924739565168, 77.15893241337368, 76.74204049791608, 41.39388615744454, 13.896270377295357, 1.777471878698894, 0.313657209277153, 0.1641154464866434, 0.16030834934541158, 0.22519442758389882, 0.1312784363648721, 0.14802435492830618, 0.23964915052056313, 0.11582486916865621, 0.14405626856854983, 0.2774964767907347, 0.27137923932501246, 0.28341837759528843, 0.2181938732309001, 0.2762377400483404, 0.27746767976454323, 0.34642912074923515, 0.30940043340836254, 0.44991778901645113, 0.8357636332511902, 0.8326426435794149, 1.0852693191596439, 1.2532699214560645, 0.4299609341791698, 0.6651190242597035, 1.011083945631981, 1.1140172736985343, 1.446427345275879, 0.5922401291983468, 0.978432406272207, 1.2649935952254703, 1.2111996646438326, 1.1567088514566422, 0.977610673223223, 2.0099527410098483, 0.7088402381965092, 0.1468774407569851, 0.4922913781234196, 0.6730094637189592, 0.5039111546107701, 0.5959291883877346, 0.24924363568425179, 0.6298341719167573, 0.24534756903137478, 0.5718396210244724, 0.5678645457540239, 0.2917698680290154, 0.19089471309312753, 0.34329358328666004, 0.21732804897640431, 0.46813227449144634, 0.17915592156350613, 0.17822991125285625, 0.22161865660122462, 0.6300806158355304, 0.15126754875694, 0.18966972668256077, 0.590308638555663, 2.9210845700332095, 24.764705147062028, 54.527451038360596, 63.732740674700054, 80.3245803288051, 98.85398074558803, 133.3546633039202, 59.01014041900635, 32.86097369875227, 30.540216309683665, 31.48963553564889, 54.62839099339077, 67.65489455631801, 71.4403634752546, 82.63127108982631, 84.86228207179478, 66.26970863342285, 12.803412539618355, 0.13212653728468077, 0.27756948715874125, 0.21683769885982784, 0.16393875596778734, 0.2515723407268524, 0.13393055833876133, 0.19587142818740436, 0.08360595016607217, 0.16638334122087273, 0.13295067234763078, 0.13993509113788605, 0.09585599747619458, 0.11744203524930136, 0.10142322124115058, 0.23678936968956674, 0.07963911909610033, 0.12223775791270391, 0.09001550730317831, 0.1158900899546487, 0.15604037764881337, 0.20268739387392998, 0.05804775482309716, 0.112117272402559, 0.06370613298245839, 0.15301880692797049, 0.09821083290236336, 0.11812909266778401, 0.22552490127938135, 0.11565792241266795, 0.11666043076132025, 0.09335763832288128, 0.10214767272451095, 0.17563763606761182, 0.044081200512924364, 0.07858641272676842, 0.08550316800496408, 0.11235734487750701, 0.18085197412541934, 0.058123282556022914, 0.15184442565909453, 0.20050530667815888, 0.11076402251741715], [0.014639767917937465, 0.02014553506991693, 0.03448209113308361, 0.019843217185033218, 0.0533270849181073, 0.01748633597578321, 0.06119680870324373, 0.032308499195746014, 0.02251602938797857, 0.04430714249610901, 0.03243636233466012, 0.03460957429238728, 0.04242820439061948, 0.028318913453923802, 0.016710039327985475, 0.04006314344171967, 0.031963905186525414, 0.07570525125733443, 0.03449336838509355, 0.021041791619999067, 0.0345697510721428, 0.04318177859698023, 0.048962052179766555, 0.04972692738686289, 0.04765181462945683, 0.025223455358562723, 0.05139841019575085, 0.0334698017021375, 0.03266870290307062, 0.012542086237642382, 0.016329057182052305, 0.034062132239341736, 0.09327250931944166, 0.031162070176963295, 0.03673805382901004, 0.1238190159201622, 0.13743935791509493, 0.16947347111999989, 6.710883302348001, 42.21812663759504, 73.34816510336739, 80.47546740940639, 71.55735029493059, 70.8569996697562, 62.26581614358084, 46.62397936412266, 18.09402108192444, 45.1700827053615, 114.2761537006923, 90.74770505087716, 59.32661002022879, 55.735669817243306, 51.26211036954607, 50.250824383326936, 28.066671507699148, 5.062082724911826, 0.3929653050644057, 0.07286077139100858, 0.04885040602779814, 0.036869370711169074, 0.03495130827650428, 0.0192239725563143, 0.07361684939158814, 0.07718014890061957, 0.1162363870867661, 0.039589770271309783, 0.10295519725020442, 0.09053902421146631, 0.29283581940191133, 0.009097384471845413, 0.17784963308700494, 0.5803445960794176, 0.028966588699924092, 0.5025295487471989, 0.7743589824863842, 0.42272487389189856, 0.6022765306489808, 0.5857753189546722, 0.5487039653318269, 0.6166287947978292, 3.171518926109586, 5.618887475558689, 10.99500662939889, 3.522109393562589, 2.22738402230399, 1.6750505460160119, 1.1652295142412186, 1.0189702595983232, 1.4096053668430872, 2.046041250228882, 3.088563297476087, 2.7955657967499326, 5.542872880186353, 0.9254997266190392, 1.7586734188454491, 0.9969732399497713, 0.3590448780783585, 0.29748364857264925, 0.12360834436757223, 0.07578349313033478, 0.20465681462415627, 0.16083335903074059, 0.1450718862137624, 0.2943036806370531, 0.11808616854250431, 0.13965415049876484, 0.14604266626494272, 1.0042248794010706, 0.28387288749217987, 0.036223680180098326, 0.019723399775102735, 0.17416111672563211, 0.07302224236939635, 0.06786481304360287, 0.06031245365738869, 0.23498357087373734, 0.13803535593407495, 0.3546839877963066, 0.9388412450041089, 11.381245698247637, 33.7793344770159, 55.69496726989746, 35.848831108638215, 56.69623047964913, 70.8621552331107, 46.255481651851106, 37.745070934295654, 21.237280164446148, 35.76818684169224, 42.58246585300991, 55.296807697841096, 65.21545151301792, 69.44516045706612, 64.29127856663295, 21.46273010117667, 0.49405459208147867, 0.23651127889752388, 0.049013349427176375, 0.015221815256934081, 0.03844253718852997, 0.10895238830042736, 0.0509389266371727, 0.029232744060988938, 0.018858036924419657, 0.06644107694072382, 0.044353320196803124, 0.032018303338970454, 0.03752765485218593, 0.044736441424382586, 0.024191088076414805, 0.022343618728752648, 0.03492384796429958, 0.016984259077746953, 0.025426011632329652, 0.08494804493550744, 0.05096338103924479, 0.04086414046053376, 0.056913597110126696, 0.03196237509005836, 0.020567877317911813, 0.06904720102569886, 0.004968238495556372, 0.027772060030006936, 0.00910325549609427, 0.01619996250207935, 0.02960688148492149, 0.06128152380032199, 0.018152850746576275, 0.04483454062470368, 0.05048051516392401, 0.05691506613844207, 0.021714822023308704, 0.053398443053343465, 0.06261438370815345, 0.02762060083581933, 0.027386662317439914, 0.020494397064404826, 0.014296615795631493, 0.0404892023652792, 0.06531407777220011, 0.01494021134983216, 0.03384966256895235, 0.048273444308766296, 0.02303955647429185, 0.016496770682611635, 0.024669914972037077, 0.05811966596437352, 0.014682110199438674, 0.028851292029555355, 0.059432013758591244, 0.02947661972471646, 0.02357353299989232, 0.030840885625886064, 0.04122938568304692, 0.027577074510710578, 0.049739649918462546, 0.05328932783699461, 0.01204492278130991, 0.0251831792161933, 0.0477776862680912, 0.05101813202989953, 0.05998560333890574, 0.055953229178807566, 0.03535661420651844, 0.036415189903761656, 0.011546765271175121, 0.03402630898303219, 0.034590147834803374, 0.06328044725315911, 0.023613400324913006, 0.017413639430222765, 0.09433879317449671, 0.19655638214732918, 0.44918285416705267, 16.215056215013774, 64.90623583112443, 92.97096184321812, 91.34912722451347, 90.8937839780535, 97.36251517704555, 93.19814709254673, 69.37261431557792, 22.18575964655195, 54.402508531297954, 98.22889300755092, 56.23539468220302, 45.67141260419573, 56.67841182436262, 59.662673541477744, 49.27150705882481, 24.251151629856654, 2.0585417108876363, 0.2879358466182436, 0.12453367614320346, 0.04295775008254817, 0.07537827880254813, 0.012007861198591334, 0.2389185040124825, 0.1422691023243325, 0.030671893086816584, 0.2575992787522929, 0.24468165476407322, 0.26761019442762646, 0.17535878531634808, 1.145013730440821, 0.7410634319697107, 2.6900832397597174, 3.053843583379473, 2.2380145490169525, 3.696262300014496, 2.661191544362477, 3.4038358543600356, 3.2164516236100877, 3.6831640771457126, 2.989998540707997, 3.935718068054744, 9.183606914111547, 19.455720356532506, 20.726653575897217, 8.076187389237539, 5.772115230560303, 5.254868745803833, 3.090254532439368, 3.522545827286584, 4.3575080292565485, 5.543809149946485, 3.756178787776402, 5.382956615516117, 8.289570042065211, 3.5862868641104018, 4.290950800691332, 1.8435490301677158, 1.5392860025167465, 0.7717497167842728, 1.2588252233607429, 0.9307519133601869, 1.0706435782568795, 1.4495755306312015, 0.6729265738810811, 0.7312600665858814, 0.9189335703849792, 0.7606291249394417, 0.4766220503619739, 0.8911393646683011, 0.6050062498876027, 0.27060104108282496, 0.2427774140877383, 0.46286678846393314, 0.11930105835199356, 0.024380358634516597, 0.0865780556840556, 0.1614996532776526, 0.25022015614168985, 0.3966873953385012, 0.06243730642433677, 8.727058155196053, 35.11291265487671, 58.19349431991577, 41.49326624189104, 36.78466313225882, 26.78000930377415, 19.671573093959264, 22.28431463241577, 28.928717136383057, 52.00380277633667, 67.68035970415387, 75.65967791421073, 76.76781136648995, 76.46837180001395, 80.86184978485107, 35.42269808905465, 2.443423709699086, 0.2527413208569799, 0.06466626681919609, 0.08377833877290998, 0.10263758179332529, 0.1287505134407963, 0.03357366166476693, 0.04389209280322705, 0.06389441287943295, 0.03704244803105082, 0.024659010914287398, 0.02513822287853275, 0.06442189243222986, 0.07597212586551905, 0.05682506186089345, 0.014422331371211579, 0.03566621616482735, 0.06099765867527042, 0.04961950172271047, 0.027157665230333805, 0.020952306421739713, 0.0223311659148229, 0.004240748447565628, 0.021166587780628885, 0.02254386798345617, 0.05942879071725266, 0.009106679553432124, 0.036422467191836665, 0.049931566763137064, 0.014714857995776194, 0.030873014259019067, 0.02166009647771716, 0.006966695879652564, 0.038255862026874504, 0.06158451682754925, 0.028003167361021042, 0.046327609435788224, 0.08690754550376109, 0.07174808252602816, 0.07734388618596963, 0.03566612795527492, 0.1287488035325493, 0.11196684797427484, 0.0872812554506319, 0.0749698957162244, 0.15961726142891816, 0.12832461058029107, 0.20268299696700914, 0.08631529299808399, 0.100346257244902, 0.13497491872736386, 0.15170449816754886, 0.13747283683291503, 0.13248278174017156, 0.1344607656023332, 0.11060132339064564, 0.16544412661875996, 0.1098033662087151, 0.19860585645905562, 0.14309752572860035, 0.16756008379161358, 0.14342186546751431, 0.10467454391930785, 0.10946051603449242, 0.1861495277179139, 0.167577237156885, 0.09661482354359967, 0.12465450965932437, 0.09901407587208919, 0.10200063418596983, 0.17260852003736155, 0.10976768883743457, 0.09264289667563778, 0.2808506382363183, 0.11607570999435016, 0.09553849058491842, 0.19167776964604855, 0.25493160475577625, 0.32559817710093086, 14.957809209823608, 71.69672421046666, 105.37033489772251, 101.37148680005754, 92.00240380423409, 95.15510722569057, 84.9520319529942, 61.53196130480085, 26.244438682283672, 57.03785603387015, 129.16139766148157, 114.7495344706944, 79.94623007093156, 78.70957578931535, 71.8897590637207, 68.46356759752545, 40.16140079498291, 6.811896647725787, 0.9992949153695787, 0.2176072389951774, 0.17618012481502124, 0.25145693549088066, 0.29639872536063194, 0.4688878910882132, 0.2308770226580756, 0.17878624211464608, 0.4072322095079081, 0.3191627881356648, 0.2546534053981304, 0.23651828137891634, 0.6607981675437519, 0.22331169646765503, 1.1073709960494722, 2.164150421108518, 1.0969340418066298, 2.541469088622502, 1.4160705570663725, 2.3318041563034058, 2.129224432366235, 2.0953144005366733, 3.1417945325374603, 3.3989983882222856, 9.017650927816119, 16.677863563810075, 19.940822737557546, 10.65752741268703, 6.0820435370717725, 8.98586813041142, 3.79619129214968, 3.7615115301949635, 3.938810016427721, 6.648664355278015, 9.944987041609627, 9.634021282196045, 14.243430171694074, 7.173314145633152, 7.126581430435181, 2.42316905941282, 1.6891004549605506, 0.8644055734787668, 2.097358907972063, 1.0199830681085587, 0.9009051120706967, 0.5395268063460077, 0.38392491159694536, 0.6505650452205113, 0.44514950630920275, 0.9833056990589414, 0.3344903513789177, 1.987659445830754, 0.7156257512313979, 0.24240052859698022, 0.16771518332617624, 0.4270997148539339, 0.15788477153650352, 0.17376122889774187, 0.43393812647887636, 0.2834374037172113, 0.3913360610604286, 0.45493867674044197, 1.6157614588737488, 17.810883726392472, 47.310391902923584, 73.93330764770508, 54.821630818503245, 88.8351161139352, 101.00571278163365, 62.513915470668245, 52.817207540784565, 28.369074480874197, 45.310933113098145, 56.424111230032786, 72.05387551443917, 81.58310059138707, 86.3876895904541, 91.85163484300885, 36.15253686904907, 2.0799760350159238, 0.33696629852056503, 0.24489656037517957, 0.2945289271218436, 0.15670722829444067, 0.23393542425973074, 0.11749023837702614, 0.11932157725095749, 0.09459855673568589, 0.16036716476082802, 0.08706469421408006, 0.06952207375849996, 0.15042969371591294, 0.18887155236942427, 0.1535667646676302, 0.07795801466064793, 0.10949645124908004, 0.21482589681233677, 0.08667564259043761, 0.23041483174477304, 0.07279477707509484, 0.061829712241888046, 0.28765479741351946, 0.12463252512472016, 0.09172451988394771, 0.14378391818276473, 0.11219913086720876, 0.09278681395309311, 0.10157499595412187, 0.14115549065172672, 0.14987454350505555, 0.08977284960980926, 0.1411740282284362, 0.12813581499670232, 0.08593191392719746, 0.1948310440140111, 0.06848392196531806, 0.18749730182545526, 0.15580819653613226, 0.11919372768274375, 0.07407789358070918], [0.0016422064613185025, 0.05839680680739028, 0.031984563185168166, 0.036157886032015085, 0.054875780030020645, 0.0033788556673763587, 0.021069094172811935, 0.051532495500785966, 0.023171860624903014, 0.027093793032690883, 0.0448948759585619, 0.05354354776708143, 0.012330412149562367, 0.01913475537938731, 0.048031909590853114, 0.05560541891359857, 0.05411899635302169, 0.06606753662760768, 0.01055380136572889, 0.03338331902133567, 0.01044980569609574, 0.009134055048759495, 0.01265830741197403, 0.043035673044089756, 0.0166225218812802, 0.017321097431704402, 0.03134112199768424, 0.053542546927928925, 0.0812276035015072, 0.001861126349207812, 0.03564703058717506, 0.018421966216659973, 0.03710595551612122, 0.002413259835780731, 0.07943162987274782, 0.12828872964850493, 2.153570920228958, 30.96943780354091, 73.95884922572544, 88.90872532980782, 79.72490910121373, 61.87313870021275, 55.489029611860005, 41.4596334866115, 31.227990695408412, 28.392936331885203, 44.54020071029663, 25.040463515690394, 34.427931444985525, 59.981811250959126, 58.65987477983747, 51.01036671229771, 28.16007787840707, 4.142989345959254, 0.23844605364969798, 0.07225359111492123, 0.009234438367587115, 0.1149887376065765, 0.049757532708879025, 0.053993626830301115, 0.0741409362692918, 0.009427621528240187, 0.03006757962118302, 0.11040678061544895, 0.30349286326340263, 0.6243858614138195, 0.19932167019162858, 0.26917291485837525, 0.6377086522323745, 0.672570098723684, 1.2099023056881768, 0.226171680859157, 1.6508344454424722, 4.385838874748774, 1.2229091163192476, 2.7713869341782162, 0.8576988247888429, 1.8868043891021182, 2.0211756016526903, 2.6187039613723755, 3.5500096678733826, 15.674654858452932, 29.842033522469656, 5.225021021706717, 8.9545065675463, 4.921421655586787, 2.7551863406385695, 5.847641280719212, 1.6169748966182982, 6.02121900660651, 5.689317456313542, 3.9957079461642673, 8.45525678566524, 6.970869694437299, 5.609038404056004, 4.315682479313441, 3.3095746380942206, 1.3039498648473193, 1.3088147980826241, 1.5047875451190131, 4.561678673539843, 4.04141971043178, 7.889383333069937, 10.26679025377546, 3.577234664133617, 3.320628353527614, 0.18078695689993246, 0.6933766965355191, 0.9284383803606033, 0.055700725942317925, 0.08088459726423025, 0.019088628568819592, 0.1808754921491657, 0.019367754126765897, 0.07717413708035435, 0.03209144262863057, 0.08328658408884491, 0.11423009474362646, 0.011603702840927457, 0.1850067526102066, 3.1893021890095303, 13.460679990904671, 31.179144859313965, 73.10616629464286, 51.14278548104422, 65.76796531677246, 59.47499574933733, 44.664681162152974, 26.601947818483623, 25.890683310372488, 41.575470379420686, 37.25362484795706, 54.88686050687517, 59.465240478515625, 74.82115541185651, 37.552532877240864, 7.341321587562561, 0.04044359463400074, 0.17542387039533683, 0.06551516841032676, 0.14828005406473363, 0.03866633500105568, 0.045779549915875704, 0.14818762402449334, 0.08065459424895899, 0.03882724618805306, 0.026404968030484657, 0.07397753825145108, 0.0172842750325799, 0.023256828476275717, 0.021385050611570477, 0.02429880720696279, 0.03145917352022869, 0.025806055703599538, 0.04633175528475216, 0.07987254871321575, 0.02115347169871841, 0.02599796576292387, 0.034252688621303866, 0.009792495252830642, 0.016202831008870686, 0.04403678021792855, 0.04752081326608147, 0.08267096283712558, 0.023813910815598707, 0.02738644857890904, 0.044761235093964, 0.048074558909450255, 0.026635452805619155, 0.047947411624980826, 0.05230251061064856, 0.01619548925996891, 0.031124163818146502, 0.0329565238872809, 0.026120047783479095, 0.04986716700451715, 0.06918281303452593, 0.08226617598640067, 0.10503222686903817, 0.05857203169060605, 0.07459525617637805, 0.018529656509469663, 0.011263481989902045, 0.02436114421912602, 0.02233634652969028, 0.025523954769596457, 0.04132303708632078, 0.07780415005981922, 0.07641591490911585, 0.0629018247127533, 0.03698048760582294, 0.01870184325213943, 0.06763551570475101, 0.03157085020627294, 0.0815821923315525, 0.03619491368798273, 0.061967190222016404, 0.06168170339827027, 0.04347486162026014, 0.0486507674546114, 0.01911004143767059, 0.07273454352148942, 0.07052421569824219, 0.03356149892455765, 0.08948449936828443, 0.09488093586904661, 0.047150014234440665, 0.017850873825539435, 0.0404194184312863, 0.04329108041045921, 0.1007081742531487, 0.04574854086552348, 7.217015274933406, 53.95859507152012, 96.25706372942243, 104.88932500566754, 95.15703882489885, 83.7184418269566, 76.39899403708321, 67.9737890788487, 45.179681641714915, 23.78863784245082, 31.6541063444955, 17.42965865135193, 33.66947650909424, 58.53079114641462, 65.63110664912632, 50.903583322252544, 23.31966049330575, 1.576508370893342, 0.3375273384153843, 0.08977566553013665, 0.07138539877321039, 0.06078588789595025, 0.1394105021442686, 0.14250492038471357, 0.191999544522592, 0.1516690379274743, 0.2499124269400324, 0.3445131278463772, 0.4098320028611592, 0.9237662596361977, 0.6841425948909351, 0.6374358268720763, 1.536330195409911, 3.8845993024962286, 4.630394186292376, 5.843814126082829, 5.336973437241145, 8.825730391911097, 7.439419729369027, 5.5408917750631055, 6.624184114592416, 4.9268169317926676, 7.024176708289555, 8.969432166644506, 11.232358830315725, 24.073630367006572, 37.71224764415196, 10.142792701721191, 10.590198499815804, 9.780991315841675, 8.371412873268127, 8.718355536460876, 7.207319063799722, 11.69687717301505, 6.567181093352182, 5.173936997141157, 5.366010827677591, 3.3125215428216115, 3.1453400679997037, 0.2965777500399521, 1.0218024104833603, 0.8319539576768875, 0.18436255146350178, 0.44855477501239094, 0.45657704025506973, 1.5563471955912453, 1.797296717762947, 2.691287015165601, 2.437097809144429, 1.0923935025930405, 0.9058677543486867, 1.862270517008645, 2.749523341655731, 0.6130197484578405, 0.1614576383892979, 0.12911355681717396, 0.2121387624314853, 0.3406149170228413, 0.05831841565668583, 0.02661742752284876, 0.16030701941677503, 0.25163959711790085, 0.027626783986176764, 0.3973216898739338, 1.2449020104748862, 10.73558521270752, 32.94501910890852, 84.47787298474992, 55.5168536731175, 45.910569599696565, 34.88920497894287, 18.59833696910313, 24.352718659809657, 41.064749990190776, 62.752196993146626, 62.58213288443429, 75.0320679800851, 71.99116107395717, 88.118624823434, 56.718186787196565, 16.913431814738683, 0.08155948176447834, 0.27360022014805246, 0.19815852546266147, 0.18315813823470048, 0.10190280979233128, 0.021594684005581906, 0.029112819781793014, 0.03481033584102988, 0.033329975990844626, 0.04928006797230669, 0.0608790371833103, 0.02987789176404476, 0.03799058197598372, 0.009346348300044025, 0.05705305641250951, 0.03326127092753138, 0.04781778768769332, 0.04523979227191635, 0.03485407420833196, 0.017811079443033253, 0.025004234264737794, 0.08559426133121763, 0.049042492506227324, 0.02708712812247021, 0.04538690884198461, 0.03319186358047383, 0.09998649119266442, 0.020123016188985536, 0.018103017438469187, 0.07475794173244919, 0.029323983272271495, 0.006969747166814548, 0.002791713802642854, 0.03650051907503179, 0.022140612925535867, 0.0315764956176281, 0.04018846207431384, 0.007151221357552069, 0.08771688171795436, 0.07499683355646473, 0.2421018917645727, 0.18397585435637406, 0.15489566193095275, 0.15783838688262872, 0.0659353919327259, 0.14358908363751002, 0.10099469245012317, 0.12311143960271563, 0.10244014167359897, 0.17918064737958567, 0.11684816783027989, 0.20864620698349817, 0.10648400003888778, 0.11758345551788807, 0.16255279390939645, 0.2747332922049931, 0.1531755213758775, 0.24264781389917645, 0.12834588943847589, 0.1355619193719966, 0.12068805178361279, 0.18086682047162736, 0.1215749377650874, 0.08034558940146651, 0.13332945773644106, 0.13003921428961412, 0.20892102723675116, 0.2752658064876284, 0.1621709279716015, 0.163192001038364, 0.1124879289418459, 0.1765798633652074, 0.11269203227545534, 0.1813318340906075, 0.17106549069285393, 5.875994273594447, 60.30277633666992, 109.30867113385881, 111.9554831641061, 100.44370079040527, 83.42315033503941, 74.95856298719133, 54.83630541392735, 42.906939779009136, 37.86995785576956, 68.39703164781842, 36.788071223667686, 51.4308682169233, 80.02279921940395, 76.88364478519985, 64.84748881203788, 38.32751757758004, 6.882188967296055, 0.39963020171437946, 0.2521105275622436, 0.2556905597448349, 0.20677490239696844, 0.2390104862196105, 0.3258105585617678, 0.17543278634548187, 0.12805638568741934, 0.3053779149694102, 0.35827780781047686, 0.8035688293831689, 1.4163171095507485, 1.3459918946027756, 1.3990913310221262, 2.1918887155396596, 3.4832578897476196, 6.0069582632609775, 6.367774307727814, 7.88872412272862, 14.8886798449925, 6.909775487014225, 10.15191742352077, 8.845973099981036, 6.336599043437412, 7.359021254948207, 10.23846331664494, 9.75849391732897, 30.354654244014196, 45.76433086395264, 17.470189230782644, 22.40609049797058, 16.193685293197632, 12.120416777474539, 19.287961312702723, 11.898963791983467, 16.373648847852433, 22.654966286250524, 18.520645686558314, 20.073288406644547, 17.985782044274465, 13.389546939304896, 13.404995390347072, 10.116353069032941, 6.287200391292572, 5.4224614671298434, 4.770671367645264, 9.770397918564932, 11.631159373692103, 12.678337148257665, 17.62514100755964, 8.542676414762225, 6.492236520562853, 1.1323646434715815, 2.548923420054572, 3.282665567738669, 0.47972045838832855, 0.2205579706600734, 0.23628301971725055, 0.5328497503484998, 0.2929275030536311, 0.17809261647718294, 0.31198858310069355, 0.3741638053740774, 0.40953632444143295, 0.12574923091701098, 0.4386857274387564, 3.871672179017748, 20.679346765790665, 45.3509338923863, 96.7121776853289, 74.77244853973389, 97.4221168245588, 82.43087114606584, 59.205711364746094, 37.643668924059185, 33.9210638318743, 52.35432897295271, 54.97296258381435, 71.73853846958706, 74.79422419411796, 100.0417822429112, 63.5749887738909, 15.379460641316005, 0.17138738770570072, 0.2597239076026848, 0.2169139797666243, 0.38715723529458046, 0.25827352542962345, 0.16750466105129036, 0.2729363686272076, 0.25938211594309124, 0.1872498265334538, 0.11412269622087479, 0.16321997025183269, 0.17973559402993747, 0.157849894836545, 0.0987875469561134, 0.12199630801166807, 0.1173428198588746, 0.12717842922679015, 0.17777774908712932, 0.14705662828470978, 0.1353933848440647, 0.12231243747685637, 0.11674155640814986, 0.15804414584168366, 0.15752707501607283, 0.0817874763160944, 0.16430253216198512, 0.17322310991585255, 0.09635453751044613, 0.14507464106593812, 0.12416979138340269, 0.15935610687094076, 0.07298405441854681, 0.1412872350109475, 0.14261107040303095, 0.06785916763224772, 0.16008162365428039, 0.08844389806368522, 0.09104062443865196, 0.14280897192656994], [0.018365768250077963, 0.09096915434513773, 0.046892035220350535, 0.04536907694169453, 0.024345412384718657, 0.016133430447163324, 0.05087316641584039, 0.013469853953990554, 0.04496406278173838, 0.024860181280278733, 0.026908381642507653, 0.04182601813226938, 0.01348283008805343, 0.03108059169192399, 0.02141885692253709, 0.04839907506746905, 0.04195474979600736, 0.04403510423643248, 0.036442741818193874, 0.07201984258634703, 0.09408226622534649, 0.029746082943997214, 0.04550611726673586, 0.035183818478669436, 0.015505749931825059, 0.07762992940843105, 0.10464362307850804, 0.05124799594549196, 0.03562751252736364, 0.021725303693009273, 0.04415762051939964, 0.07397770788520575, 0.021983786519350748, 0.03318292048892804, 0.08089895506522485, 8.601647513253347, 68.99929455348423, 85.41199575151715, 76.54143905639648, 66.99832453046525, 63.08352184295654, 48.749617440359934, 61.42686980111258, 34.467960017068044, 38.63358572551182, 57.25558131081717, 46.720076424734934, 64.37485149928501, 64.54158047267369, 64.91628987448556, 34.083533559526714, 5.141376435756683, 0.09650124356682811, 0.14699983490364893, 0.1757332823638405, 0.10710639307009322, 0.02371908045772995, 0.0635201193924461, 0.027226439843486463, 0.043717007019690106, 0.06276353927595274, 0.21526095989559377, 0.11486181084598814, 0.3427750739668097, 0.27218229909028324, 0.772035570016929, 0.6976147176963943, 1.8382755645683833, 2.120797787393842, 6.883680658681052, 8.296918630599976, 1.9066080578735896, 4.449043597493853, 4.278606457369668, 5.8059950811522345, 4.484377358640943, 2.935149678162166, 7.037738289151873, 2.521213786942618, 2.8127189448901584, 9.836143510682241, 13.13278147152492, 11.685800875936236, 5.860874993460519, 4.870301587241037, 10.521208098956517, 5.768184287207467, 4.895440169743129, 7.021938519818442, 6.921231329441071, 1.8111732474395206, 4.213900055204119, 6.525640419551304, 1.646907519016947, 3.280936986207962, 3.143599761383874, 3.0307566736425673, 1.802299637879644, 1.47482821558203, 1.3002001174858637, 1.8883798931326186, 10.468691876956395, 3.1463827320507596, 2.2837052515574863, 2.2677382911954607, 0.5519352033734322, 0.5148393139243126, 0.5172839398894991, 1.3527919011456626, 0.6928503162094525, 0.2893926884446825, 0.2758043190198285, 0.12926316021808557, 0.024245623632201126, 0.1557161057634013, 0.09738981231514897, 0.0200823431036302, 0.02795924070025129, 0.10163514808352504, 0.08027934402759586, 0.21214955113828182, 0.18108135967382363, 2.68022027185985, 27.888478006635392, 53.06804098401751, 51.36117778505598, 46.80056435721261, 66.53059264591762, 50.28365114756993, 37.8132883480617, 21.42955592700413, 21.16522560800825, 37.64420393535069, 47.46028539112636, 47.67573513303484, 67.70497717176164, 69.27568694523403, 31.50539752415248, 0.9078703011785234, 0.22486372318650993, 0.16799304341631277, 0.04427713767758437, 0.06580063487802233, 0.02419542900419661, 0.0368175984892462, 0.0908074119527425, 0.006653278858201312, 0.0675998790455716, 0.03882870843101825, 0.054087498757456026, 0.03536704328975507, 0.027164813596755266, 0.02216999009916825, 0.03589329808684332, 0.004955837419921798, 0.040689611075712104, 0.06109686049499682, 0.024110288126394153, 0.03997199243998953, 0.033080916319574626, 0.06942366582474538, 0.0449219834325569, 0.08936701102980546, 0.015329500460731131, 0.023037235884528075, 0.01235173935336726, 0.016161869546132426, 0.0036882267117367257, 0.016906593959512453, 0.008836434322542377, 0.005540632825743939, 0.016376692036698972, 0.003443984215014747, 0.07674780674278736, 0.05826148656862123, 0.006618863562055464, 0.02392202858547015, 0.0844949260354042, 0.06284796260297298, 0.05565985438546964, 0.023981690473322357, 0.02294365912010627, 0.036219585221260786, 0.04256853221782616, 0.01779174798035196, 0.03910365421324968, 0.0467645893804729, 0.021763612083824616, 0.030789357676569904, 0.02494204313760357, 0.0023948049555266543, 0.0830626878887415, 0.042559748582009754, 0.019821171582277333, 0.03600162959524563, 0.08738534272249256, 0.09575951658189297, 0.01646439777687192, 0.034781470961336575, 0.0080420216379155, 0.040231053717434406, 0.018907765059598854, 0.09194163073386465, 0.035989198833703995, 0.0252942791474717, 0.04936890516962324, 0.05760399292090109, 0.02524975367954799, 0.010674096294678748, 0.07229447284979479, 0.019480655568518808, 22.130957467215403, 94.14234474727085, 97.92627811431885, 90.7284515925816, 89.01230907440186, 92.8320951461792, 78.54620974404472, 87.89908259255546, 31.93212808881487, 22.262530292783463, 39.59064449582781, 36.90539155687605, 63.06411552429199, 74.53085967472622, 70.9870491027832, 31.390404837472097, 2.547479497534888, 0.17339309650872434, 0.08719051496258803, 0.1605269733284201, 0.041798707097768784, 0.048799607503627024, 0.05640430908117976, 0.46770832581179483, 0.4467561143849577, 0.15979492903820106, 0.9482666935239519, 0.4731363888297762, 0.1088631134480238, 0.5227291019899505, 0.9523279156003679, 0.845747380384377, 1.821023404598236, 1.7529706848519189, 2.2120769236768996, 3.7266111629349843, 2.7377626470157077, 7.975735545158386, 8.217806441443306, 7.424266576766968, 9.955242582729884, 12.244723524366107, 16.84708867754255, 10.913579821586609, 8.746029342923846, 14.15617903641292, 12.453485625130789, 13.972294092178345, 10.992666823523384, 8.025292703083583, 14.744509935379028, 9.050964934485298, 6.876574822834559, 4.197975652558463, 3.4543761823858534, 1.467013446348054, 0.732020731483187, 0.14299983025661536, 0.7308573424816132, 2.0486557270799364, 1.3724385840552193, 2.129609623125621, 1.9440104280199324, 1.1980356510196413, 1.6800700766699654, 1.5314870838608061, 2.8154637004647936, 0.6054208619253976, 0.3922581358679703, 0.21112146201942647, 0.09900759586266109, 0.5926680405225072, 0.2048201515738453, 0.3652144441647189, 0.33818741728152546, 0.7242994915161813, 0.6735743848340852, 0.285703927810703, 0.18252408797187464, 0.24436241760849953, 0.2911898562950747, 0.122157894341009, 0.07182921495820795, 0.024016867425026636, 0.1198553264673267, 0.14819632284343243, 0.3264416232705116, 1.045103520154953, 20.850244658333914, 54.823697907584055, 63.352827072143555, 46.02261277607509, 51.76081384931292, 28.29461063657488, 13.165849685668945, 26.583126885550364, 36.41351120812552, 58.99164431435721, 78.85475145067487, 65.37213339124406, 74.36995329175676, 83.71902547563825, 48.4674128804888, 2.693946438176291, 0.2951442769595555, 0.24085998269064085, 0.01372647674621216, 0.021049886542771543, 0.02643018917712782, 0.08887965325266123, 0.007226542985465909, 0.03725175912092839, 0.011612768916945373, 0.08229315453874213, 0.056220968919140954, 0.048451858306569714, 0.03188265740339245, 0.040997299565268416, 0.0125476375022637, 0.09955132632915463, 0.02699027573024588, 0.009180364215613475, 0.023261853028088808, 0.0530294319614768, 0.014181403093971312, 0.11594342280711446, 0.010050319900204028, 0.03751623171514698, 0.01486574552421059, 0.02074922767600843, 0.06489078048616648, 0.0644200196755784, 0.010448775171036167, 0.06237883706177984, 0.01578559643322868, 0.013020405928338212, 0.02637716505809554, 0.003912164472110037, 0.02576992371385651, 0.07213705951081854, 0.06098016604248967, 0.10522071711186852, 0.21180138124951295, 0.15020015888980456, 0.15401319999779972, 0.1462876716894763, 0.05634838422494275, 0.09333331284246274, 0.2022290298981326, 0.11085532618952648, 0.09608901318694864, 0.07948289319340672, 0.08242555029158082, 0.056800963689706156, 0.1311344648046153, 0.13472710416785308, 0.18911621852644853, 0.10910849206681762, 0.09284514760864632, 0.09435699148369686, 0.2651732766202518, 0.209559080856187, 0.1181002277880907, 0.13636595622769423, 0.09351432562938758, 0.08985540696552821, 0.23475460601704462, 0.3630286385970456, 0.0988037164456078, 0.17834150312202318, 0.13376393727958202, 0.1567262951284647, 0.12604325371129171, 0.10373226912426096, 0.16417361050844193, 0.11032456252723932, 21.309548377990723, 105.78677518027169, 114.60674898965019, 95.22020489828927, 86.0856375013079, 83.85201399666923, 62.72772543770926, 76.05264023372105, 48.288597515651155, 53.11319037846157, 83.13211114065987, 63.054520062037874, 90.4499261038644, 85.12144293103898, 81.04627582005092, 47.347880908421104, 8.241391233035497, 0.39706018247774666, 0.3015056241835867, 0.318528520741633, 0.20861071960202285, 0.27617319779736654, 0.11685473604926042, 0.14159478779350007, 0.23518558431948933, 0.2665311337581703, 0.7557051862989153, 1.0610455104282923, 1.0562059815440858, 1.0326483313526427, 2.248257496527263, 2.3817362998213087, 6.850625906671796, 9.400562678064619, 14.95288119997297, 19.171436548233032, 9.91874282700675, 20.934088570731028, 19.059059858322144, 19.986168418611797, 15.92324229649135, 18.69442187036787, 21.939213241849625, 10.924003856522695, 13.477275763239179, 19.648715257644653, 25.20157834461757, 21.08741273198809, 16.144500732421875, 15.5030916758946, 20.38661047390529, 14.7512184211186, 18.803948061806814, 15.825250114713397, 14.282290577888489, 6.409598120621272, 10.836836968149457, 15.728809118270874, 10.695757269859314, 10.813166192599706, 9.779557381357465, 8.190359319959368, 8.180174129349844, 4.916008140359606, 10.268298012869698, 11.503965650285993, 18.580518313816615, 12.663965667997088, 10.095526712281362, 3.978060390268053, 1.800450548529625, 1.374998452407973, 1.0617606320551463, 3.953159349305289, 2.118542011295046, 2.263944140502385, 1.1303358780486243, 0.27837298118642395, 0.29346419711198124, 0.5537709391542843, 0.3651615727160658, 0.2287452556192875, 0.14870576693543366, 0.306124032075916, 0.24738040566444397, 0.35992998629808426, 0.4172964580357075, 4.323577804224832, 35.89016594205584, 65.08804934365409, 68.58924661363874, 65.51477990831647, 99.59581906454903, 71.73513385227749, 49.07440750939505, 29.668057577950613, 28.11766607420785, 49.03518492834908, 64.58624349321637, 60.56989288330078, 85.34069333757672, 92.47172682625907, 50.42061056409563, 2.050884796040399, 0.449948784496103, 0.4369633341474192, 0.27183936749185833, 0.16488035901316575, 0.14567519884024346, 0.15068584068545274, 0.2020755045648132, 0.14106646685728005, 0.10873776088867869, 0.11437600691403661, 0.12537011983139174, 0.14085694881422178, 0.1465428958513907, 0.12123427247362477, 0.12775492614933423, 0.173564969428948, 0.13753758264439447, 0.12140561613653388, 0.18779036110000952, 0.18401748926511832, 0.17919138180358068, 0.17707915657332965, 0.09251621418765613, 0.13818730706615107, 0.09532743226736784, 0.1005009835852044, 0.19030281342566013, 0.17911358097834246, 0.10166670674724237, 0.114512066755976, 0.13626048474439553, 0.08389151162867035, 0.09972601516970567, 0.12107578026396887, 0.20255400745996407, 0.19760817927973612, 0.07902615091630391], [0.06896240450441837, 0.06598789018711873, 0.022417738501514708, 0.017776798157553588, 0.07116113616419689, 0.03276962820174439, 0.04388871709150927, 0.042387814593634436, 0.03500631032511592, 0.07565228481377874, 0.03813985289473619, 0.010821861713858587, 0.040467438354556046, 0.014288325794041157, 0.03955737022416932, 0.03954400986965213, 0.011584798007139137, 0.030563846563122103, 0.016777657038931335, 0.0395065750926733, 0.03727125343201416, 0.03618265934554594, 0.02573759152021791, 0.023404426806207215, 0.012481714432526912, 0.04716221768675106, 0.06963693616645676, 0.04557141947693058, 0.0222043036150613, 0.08173829609794275, 0.02270009388614978, 0.01646875906070428, 0.16178653788353714, 0.20713896357587405, 19.17278449875968, 89.0211888722011, 82.21794360024589, 66.39608246939522, 73.27770342145647, 80.57927349635533, 42.0427645274571, 30.524037429264613, 27.50757254873003, 57.30209602628435, 61.75667994362967, 49.93814502443586, 62.38403974260603, 63.34576770237514, 53.577840736934114, 16.90382593018668, 0.48317512444087435, 0.2587412803300789, 0.07001241708972625, 0.02854007515790207, 0.03052219469100237, 0.12382293785256998, 0.09542208111711911, 0.08617190497794322, 0.11539123100893837, 0.1742448072348322, 0.6245179314698491, 0.8450933269092015, 0.3688954694994858, 0.6000832340547017, 1.42700799873897, 3.019081311566489, 3.353384332997458, 1.5245827457734515, 2.425678010497774, 5.225345849990845, 6.588792596544538, 7.036762935774667, 5.5141507642609735, 8.902601787022181, 10.610072084835597, 4.284625768661499, 6.746979628290449, 6.627656042575836, 7.5653897012983045, 7.2064991763659885, 9.7681371484484, 10.0593170438494, 16.323658296040126, 9.019130894115992, 9.63021193231855, 7.016164132526942, 8.756314413888113, 7.284221725804465, 4.519640335014888, 7.928673659052167, 1.8888745180198123, 2.012240218264716, 2.0931213753564015, 0.5820174834557942, 2.230609289237431, 1.211831407887595, 1.5844347455671854, 1.2306516894272395, 1.2079076298645564, 0.6178363699998174, 0.7083937621542385, 0.7606989869049617, 0.47956721803971697, 0.9586607643536159, 3.2969662632261003, 3.129779577255249, 3.480857938528061, 4.242336426462446, 4.162011342389243, 1.7784241076026643, 0.34116282047969954, 0.3392713362617152, 0.18511461253677094, 0.9499661794730595, 0.04526898284841861, 0.2289348111620971, 0.19607730928276265, 0.10167762437569243, 0.05136252926396472, 0.02423984251384224, 0.20275903360119887, 0.10198865804289069, 0.22980596870183945, 0.24758578464388847, 7.556621074676514, 44.815151350838796, 77.42812647138322, 60.478843688964844, 51.915619713919504, 69.22311687469482, 50.112909589494976, 33.654072352818076, 24.123417684010096, 18.78948712348938, 43.891662802015034, 55.79857880728585, 54.72672537394932, 72.4424535206386, 47.57003913606916, 5.943984133856637, 0.7771266454032489, 0.09337958214538437, 0.1033377552937184, 0.028965937306306193, 0.002707427878963894, 0.05168594280257821, 0.0330308777546244, 0.057204145805111954, 0.054213383966790776, 0.033491925336420536, 0.08031825122556516, 0.012853420156586384, 0.026114022392513495, 0.06496670176940304, 0.04069572128355503, 0.021445635307048048, 0.00919087726755866, 0.03444083620394979, 0.0645692159554788, 0.04692078135641558, 0.038092402940882106, 0.04109850984865001, 0.0443721088314695, 0.08708661089518241, 0.011772311159542628, 0.013319700939713843, 0.0687007817572781, 0.05250903292159949, 0.04755730487938438, 0.017681331673104848, 0.06853589774774653, 0.0396124028068568, 0.07543665995555264, 0.04837106174922415, 0.04824587203828352, 0.05167286064741867, 0.09980141398097787, 0.029924493549125533, 0.08368216321936675, 0.020271254038172107, 0.03223148886380451, 0.028661339543759823, 0.051272904966026545, 0.061986942376409254, 0.0366723580685045, 0.030259197910449336, 0.06431465675788266, 0.01657650533265301, 0.06554884410330228, 0.08159581052937678, 0.010441048353511308, 0.04224979717816625, 0.028658693257187094, 0.04173833105180945, 0.04751938155719212, 0.08607811786766563, 0.02821277191729418, 0.024645396109138216, 0.07637649202453238, 0.048082904890179634, 0.05969774164259434, 0.01968443999066949, 0.05982903138335262, 0.07132149434515409, 0.049309543533516784, 0.05225226169984255, 0.05815242563507386, 0.02141827847143369, 0.021837150012808185, 0.04096569340409977, 36.98918335778372, 110.20866434914726, 90.98880059378487, 86.04378155299595, 99.89195823669434, 101.3516149520874, 67.32919774736676, 44.10605641773769, 23.764463322503225, 37.06509937558855, 51.18956075395857, 49.16785035814558, 66.77594743456159, 71.86978299277169, 49.46447243009295, 11.424124768802098, 0.34003425389528275, 0.15584512241184711, 0.10246059950441122, 0.12707496620714664, 0.15334207458155497, 0.46799265912600924, 0.32251371975455967, 0.5371815179075513, 0.6283964376364435, 1.01356760093144, 0.6432593943817275, 0.38206141016313006, 0.7935557152543748, 1.4837652274540492, 2.4218033041272844, 4.9002517972673685, 6.170625686645508, 5.149847592626299, 4.513587585517338, 3.6506825515202115, 2.4078078951154436, 1.706724886383329, 1.326604466353144, 1.4317842338766371, 1.6649450425590788, 4.52137781892504, 6.476722061634064, 8.975458860397339, 13.159380044255938, 12.437883445194789, 16.370176485606603, 15.243430546351842, 12.223239694322858, 9.355759825025286, 13.43586710521153, 9.172649604933602, 11.191723159381322, 7.923589314733233, 3.2520956652505055, 0.43775795293705805, 0.32417463777320726, 0.44073107625756947, 0.7719335726329258, 1.0477146314723151, 2.6170138120651245, 2.6322227673871175, 2.9733072306428636, 2.2842246294021606, 2.831826273884092, 1.6607027330568858, 1.3449040672608783, 1.1719345258814948, 1.0435474493673869, 1.195184501154082, 3.779313249247415, 4.079042903014591, 4.464594968727656, 3.709954593862806, 3.1701032306466783, 1.7503143016781126, 0.11681107910616056, 0.21250432995813234, 0.4266103282570839, 0.7969739032643182, 0.44561392281736645, 0.5557157833661351, 0.5012792529804366, 0.4463289630200182, 0.06051745944257293, 0.019727567676454782, 0.17815812224788324, 0.12613647085215363, 0.11565509970699038, 0.36394607222505976, 3.3086320715291158, 39.494512694222585, 83.73829977852958, 65.4164628982544, 47.75271422522408, 40.40413958685738, 19.421788828713552, 24.68082823072161, 28.437043496540614, 35.84176826477051, 65.9824492590768, 75.53854301997593, 68.83943734850202, 83.67474460601807, 65.23193958827427, 12.39787745475769, 0.6566184461116791, 0.057413073522703986, 0.09424610529094934, 0.023993995705885545, 0.028009603265672922, 0.05750029919935124, 0.045882575280432186, 0.02911921836701887, 0.030581773458314792, 0.03234864811279944, 0.01261400755694402, 0.019915981584095528, 0.043463872745633125, 0.031062064293239797, 0.05365253406177674, 0.0630602626396077, 0.0367929473120187, 0.053618105194930515, 0.030718165782413313, 0.02086524528983448, 0.031153781871710504, 0.038164765307945867, 0.03699577160711799, 0.08938026960406985, 0.0516374512974705, 0.024731580234531845, 0.04985959455370903, 0.036111491200114997, 0.03375318846000092, 0.04512042439143572, 0.058955308981239796, 0.011514131977621998, 0.02326503875000136, 0.0663615662072386, 0.03203420480713248, 0.0499500263083194, 0.23399719808782848, 0.11745851007955414, 0.13634471808161053, 0.1111664752076779, 0.16000564130289213, 0.11010525322386197, 0.14687164606792585, 0.13160710515720503, 0.12438153502132211, 0.16529630097959722, 0.13680813035794667, 0.06138088168310268, 0.09845418270145144, 0.1686487660876342, 0.14435163486216748, 0.15034213555710657, 0.17935025399284704, 0.16824729048780032, 0.15783530633364404, 0.12958038891000406, 0.12863425325070107, 0.10488068285797324, 0.19346982134240015, 0.14525772338466986, 0.14322694949805737, 0.1630187574774027, 0.09470750910363027, 0.15075612334268435, 0.2484060249158314, 0.14588967018893786, 0.12711331700640066, 0.11013116647622415, 0.2619116130684103, 0.24940941536000796, 39.49531521115984, 127.1898741040911, 102.78673063005719, 85.45747865949357, 95.86273956298828, 96.07110214233398, 49.54156616755894, 39.487696511404856, 36.97560657773699, 79.45514529091972, 86.70875195094517, 73.33954238891602, 87.18974099840436, 80.67176791599819, 67.27461964743478, 24.58355345044817, 0.9884960034063884, 0.4572773426771164, 0.33785819209047724, 0.3316412371184145, 0.08708345570734569, 0.32967277988791466, 0.21816743750657352, 0.38012503406831194, 0.34529789430754526, 0.8415183158857482, 1.9715391908373152, 3.203699073621205, 2.05736768245697, 1.7274707960230964, 2.248003887278693, 4.832808239119394, 6.186208759035383, 4.849683242184775, 6.991623529366084, 8.750378046716962, 11.456854258264814, 14.610989877155848, 12.934950624193464, 18.55730264527457, 25.15212975229536, 17.931619099208287, 18.594221898487636, 15.319808619362966, 19.870230776923044, 23.018240690231323, 23.34593336922782, 25.978743042264664, 33.10991028376988, 17.914370196206228, 21.892929553985596, 14.153805358069283, 20.526396070207866, 17.975036655153545, 12.213903052466256, 14.611616952078682, 4.854247774396624, 3.931551320212228, 4.911678978375026, 2.8081574525151933, 2.970798496689115, 1.6645172940833228, 1.6399853761707033, 1.045957822884832, 1.6386274376085825, 0.926296489579337, 0.9248120720897401, 0.9822276426213128, 0.7757802147950444, 1.0213045286280769, 4.575595046792712, 4.243773835045951, 5.882754870823451, 7.940601978983198, 7.107690146991184, 5.069580265453883, 1.3215712564332145, 3.1273114468370165, 1.4681045306580407, 1.9977414991174425, 0.4018811737852437, 0.5255791119166783, 0.5351948759385518, 0.3558625488408974, 0.09107209489281688, 0.12782283393400057, 0.5060450658202171, 0.22375745326280594, 0.2570522709616593, 0.4903509851012911, 11.192598632403783, 57.422511781964985, 93.26067393166679, 73.24573475973946, 75.02933733803886, 98.08443301064628, 63.19608266013009, 44.738418919699534, 29.496489184243337, 24.839624098369054, 57.38378252301897, 72.96737602778843, 68.61753967830113, 94.02791486467633, 72.54477269308907, 11.361100264957972, 0.9773451217583248, 0.2654448263347149, 0.19993000397724764, 0.08875457889267377, 0.13969805171447142, 0.1762987191655806, 0.11885539655174528, 0.2297962520803724, 0.12821219089840138, 0.13611841308219091, 0.12786551378667355, 0.06611558369227818, 0.1320833010332925, 0.15127558261156082, 0.17944721664701188, 0.14696718379855156, 0.09648261099521603, 0.17512885693992886, 0.16080647547330174, 0.1021814298416887, 0.1629118203584637, 0.08703592432928936, 0.13817598910204001, 0.1751739252358675, 0.13242102148277418, 0.12358839543802397, 0.14936404089842523, 0.14079643706125872, 0.12597135614071572, 0.09866802979792867, 0.11983870235936982, 0.12463055737316608, 0.1897317176418645, 0.16354148728506906, 0.22280078674001352, 0.1401129351662738], [0.08287824849997248, 0.040808948422116895, 0.006507884070742875, 0.037345369812101126, 0.020814127854204605, 0.026131744030863047, 0.028370041067578962, 0.062148732266255786, 0.047492345329374075, 0.039521282339202504, 0.06778034900448152, 0.00932062927833093, 0.051911674439907074, 0.06711055351687328, 0.005218102230823466, 0.024285660590976477, 0.03672021853604487, 0.05297372084377067, 0.0328964328260294, 0.04771915923005768, 0.0869836499914527, 0.04317668279899018, 0.056208972420011244, 0.032290219462343624, 0.011490057555160351, 0.01735972982299115, 0.04765606225867357, 0.016364610720691935, 0.0490016413054296, 0.013408390555663832, 0.003413731519166114, 0.08240753518683569, 0.32891254925302094, 20.495992490223475, 96.09488582611084, 70.63670703342983, 82.71922138759068, 61.31397547040667, 55.69139589582171, 52.259107385362896, 31.128565447671072, 54.212860924857004, 70.67737483978271, 50.77588585444859, 41.254741532461985, 75.49826431274414, 80.35238701956612, 33.028143882751465, 1.3453568943909235, 0.44904519298246925, 0.029426333494484425, 0.19955847891313688, 0.08281196241400071, 0.06908078850912196, 0.03355701720075948, 0.07351118791848421, 0.1375415860010045, 0.27552245557308197, 3.0365933775901794, 1.7923487318413598, 0.4671371078916958, 2.110219589301518, 3.570974120071956, 6.547852507659367, 11.223168100629534, 17.82482181276594, 16.373683588845388, 13.351317950657435, 7.427479250090463, 6.193317200456347, 3.936539258275713, 2.2474923261574338, 4.844240197113582, 4.920194864273071, 4.460427786622729, 7.097515378679548, 7.88109586920057, 16.093679870877946, 13.226727196148463, 8.059007099696569, 11.890141316822596, 7.742415904998779, 15.001885107585363, 11.140521015439715, 5.648188463279179, 2.9812281770365576, 8.931045975003924, 3.9787869112832204, 2.2122779871736253, 1.7616693952253886, 1.5506736657449176, 1.8943963817187717, 6.506834251540048, 20.132096222468785, 33.83629233496529, 52.78573914936611, 59.00346320016043, 60.437467166355674, 57.57055704934256, 46.74172701154436, 31.347353799002512, 20.685072081429617, 20.275915248053415, 17.09648731776646, 12.316132766859871, 9.691871983664376, 8.20262897014618, 6.8299285258565625, 5.65596740586417, 3.848501673766545, 2.6040797403880527, 1.8403980221067155, 1.1235477051564624, 0.5999035579817635, 0.29795607179403305, 0.6453187753047261, 0.33677978281463894, 0.16923246905207634, 0.3593194676297051, 0.2494112066924572, 0.06034057893391166, 0.041070856153964996, 0.41818319473947796, 0.12669049469488008, 0.6196971844349588, 0.1286957963768925, 17.059951952525548, 79.37128748212541, 77.7487233025687, 50.239033290318076, 61.27693462371826, 61.81036172594343, 43.502469880240305, 33.78216239384243, 21.61375614574977, 42.581649439675466, 46.42571251732962, 45.93957485471453, 78.26837907518659, 53.2505076272147, 16.009021282196045, 0.21431535349360534, 0.08339132953967367, 0.0495419248140284, 0.010655871692246624, 0.04178056646404522, 0.05515580803954175, 0.03122875659859606, 0.0652085045086486, 0.07071905702884708, 0.05740554178399699, 0.06848830530153853, 0.0274047927731382, 0.05848051767264094, 0.040399438967662196, 0.021999718521588614, 0.03254308571506824, 0.04004426659750087, 0.010811167153795915, 0.034531295099960904, 0.02241724995630128, 0.01320298613115613, 0.026127029908820987, 0.032268299388566186, 0.06138048813279186, 0.047847188610051355, 0.03507107309997082, 0.04317292032231178, 0.01325368372324322, 0.0399027275852859, 0.0443320990140949, 0.0442873665929905, 0.00949826804987554, 0.04388563654252461, 0.04500122953738485, 0.03506303245999983, 0.0143321065697819, 0.02854197166327919, 0.0753448609528797, 0.053863249719142914, 0.060279246153576035, 0.08090501438294138, 0.03931161841111524, 0.04130122218547123, 0.0776263874556337, 0.05978503517274346, 0.09696492725717169, 0.057366716010229926, 0.0487270280053573, 0.007531833701900074, 0.05559388381828155, 0.040947719011455774, 0.024044570313500505, 0.042016184356595786, 0.027462303704981293, 0.030883986170270612, 0.023840260026710372, 0.024918877952066914, 0.06744126469961234, 0.15615656998540672, 0.02931717417335936, 0.11356078780123166, 0.09835707076958247, 0.05614545814959066, 0.05042721623820918, 0.08546519718532052, 0.056028227654418776, 0.031344195761318715, 0.11607599497905799, 41.86964668546404, 113.02800015040806, 80.75602872031075, 104.42714473179409, 87.33325604030064, 83.24087129320417, 70.78824724469865, 32.09984023230416, 25.95309203011649, 39.90049941199166, 40.2140577180045, 42.01755993706839, 79.24498312813895, 84.28838866097587, 27.668584891727992, 0.6174098700284958, 0.5253915648375238, 0.058405905961990356, 0.07376438326069287, 0.1853663083165884, 0.32017223111220766, 0.32870863590921673, 0.4830098333103316, 0.6379108556679317, 0.4137383832463196, 0.8503799289464951, 1.297465892774718, 1.4703966762338365, 3.9080546838896613, 5.378551891871861, 9.95126039641244, 15.238717930657522, 21.511186838150024, 19.897862025669642, 17.105214255196707, 10.446085912840706, 8.629867621830531, 4.948407590389252, 2.9153885671070645, 2.25305957027844, 1.657382254089628, 0.9163679480552673, 0.7392441438777106, 1.6613116775240218, 2.4585994439465657, 3.2630712134497504, 5.486231599535261, 5.974349933011191, 5.8638805236135205, 14.413252830505371, 20.404145990099224, 4.156745042119708, 4.002238384314945, 9.055686235427856, 4.5875203268868585, 1.4548782003777367, 1.5182602107524872, 2.747259531702314, 3.4457934200763702, 9.106764180319649, 26.046279532568796, 45.765821252550396, 66.02332551138741, 72.52532468523297, 75.92152077811105, 72.20687484741211, 62.434400285993306, 45.65552207401821, 36.05925382886614, 37.24093048913138, 37.0018047605242, 32.79956899370466, 27.95089020047869, 21.884496177945817, 17.266574008124216, 13.239326885768346, 6.462312800543649, 2.6569316472326006, 2.929883595023836, 1.402099249618394, 0.5225085509674889, 0.2545500780854906, 1.30534818981375, 0.7891773730516434, 0.6319675402981895, 0.5778763570955822, 0.41406163732920376, 0.08396750755075898, 0.04714433150365949, 0.23311002712164605, 0.08247386198490858, 0.40044525797877994, 0.45065085110919817, 9.536882860319954, 76.032851764134, 88.05379813058036, 57.86852012361799, 43.93940734863281, 35.31565761566162, 20.201868295669556, 17.911028112683976, 29.68022734778268, 68.76129790714809, 70.86658818381173, 65.02044337136405, 87.68140247889927, 69.76622281755719, 29.939283984048025, 0.26210323135767666, 0.1096830280231578, 0.010051904279472572, 0.05619248741173318, 0.07816203657005515, 0.0223768007875021, 0.031014950214219943, 0.023711843881756067, 0.08662114265773978, 0.05171211729092257, 0.021964377025142312, 0.04721360992906349, 0.05181400950199791, 0.025438851211220026, 0.04862211970612407, 0.015506214728312833, 0.04209212599588292, 0.027046416021351303, 0.05057742353528738, 0.0250035031432552, 0.07087956448750836, 0.005700278120847153, 0.02038982294366828, 0.0468090673509453, 0.011275519201132869, 0.12151386961340904, 0.04860122422022479, 0.03718772577121854, 0.07667294397417988, 0.029620353797716752, 0.016942308650219014, 0.026221115574506775, 0.035654107707419565, 0.022738982424406067, 0.007043632420910788, 0.1429983103381736, 0.15159886383584567, 0.11153751172657524, 0.13844667029167923, 0.1413318690444742, 0.1342155701879944, 0.16046810363020214, 0.1495230487946953, 0.1836476605385542, 0.09864438285252877, 0.1622505472706897, 0.1623640933207103, 0.20846187616033213, 0.11443631510649409, 0.19209088890680245, 0.08101613806294543, 0.07986917639417307, 0.14967312717011996, 0.09226059647543089, 0.12715218349226884, 0.1144458417381559, 0.1794512742864234, 0.14844453095325402, 0.4034353718161583, 0.1042280135942357, 0.18976621436221258, 0.15327895725412027, 0.1303960151438202, 0.23043961184365408, 0.1687414539711816, 0.0981311389644231, 0.2037856706551143, 0.2720632297652108, 47.58542939594814, 131.7659854888916, 85.63518578665597, 104.64276123046875, 82.8396475655692, 70.66759177616665, 60.683259691510884, 42.03506939751761, 70.15595422472272, 93.29066930498395, 71.62134320395333, 59.20289734431675, 92.60669558388847, 95.58339418683732, 44.3697509765625, 4.077528195721762, 0.8087869265249797, 0.19622607130025113, 0.5552602963788169, 0.12203992424266678, 0.2514726503619126, 0.2225505837372371, 0.24383242747613362, 0.3481428830751351, 0.5549173376389912, 5.090352773666382, 4.999148981911795, 2.6906104343278066, 5.153749006135123, 5.398867556027003, 8.337970324925013, 13.539715749876839, 21.328506537846156, 21.163320064544678, 16.61439003263201, 9.684272391455513, 10.400779315403529, 7.184196761676243, 6.406506606510707, 10.418865476335798, 12.60680023261479, 11.39233502319881, 21.035028525761195, 23.96916593824114, 34.24593380519322, 28.563622304371425, 20.18194259916033, 24.155705962862285, 22.00041471208845, 29.55981159210205, 25.36250036103385, 12.828466875212532, 11.114878688539777, 21.064872775759014, 11.977249145507812, 7.52656056199755, 4.269372735704694, 3.844704483236585, 3.2656040489673615, 8.270788192749023, 28.487914732524327, 50.35312271118164, 77.72287600381034, 84.36243561335972, 87.33185945238385, 82.13139683859688, 68.04162434169224, 52.24147285733904, 42.50269705908639, 45.542301177978516, 44.583105836595806, 37.23744249343872, 31.250113759722026, 26.115634713854107, 19.359560762132915, 14.440540143421718, 7.257833770343235, 3.44324169414384, 3.3645891717502048, 3.6650049601282393, 2.037791132926941, 1.61483257157462, 2.5154941167150224, 0.6202250846794674, 0.5094582055296216, 0.7060003248708588, 0.5138476214238575, 0.26314972234623774, 0.2021004067999976, 0.5518416198236602, 0.19702913106552192, 1.0892413003104073, 0.39993793091603685, 21.347362211772374, 94.48689896719796, 89.69818660191127, 67.99427236829484, 94.07726791926792, 84.3329405103411, 61.355880056108745, 43.248815468379426, 25.847323077065603, 55.601937838963096, 61.79843166896275, 61.28964982713972, 96.17112840924943, 78.98221615382603, 30.409399100712367, 0.325423712176936, 0.23356613836118154, 0.14882068362619194, 0.16109452715941838, 0.15408041567674705, 0.21020271203347615, 0.08166354868028845, 0.12028683402708598, 0.1356462069920131, 0.14779609574803285, 0.08639459338571344, 0.0983066081202456, 0.13261506892740726, 0.14608953946403094, 0.12512761141572679, 0.16264431471271174, 0.10071210975625686, 0.18806957826018333, 0.13249974511563778, 0.09721375961921044, 0.16096802109054156, 0.13898997328111104, 0.08000223711133003, 0.13126326432185514, 0.12546250915953092, 0.13185109277921064, 0.10604789201170206, 0.08260547063712563, 0.16158426659447805, 0.10821925835417849, 0.06374098254101616, 0.05316204145284636, 0.14569072372147016, 0.1770489617649998, 0.12494762321668011], [0.05262917772467647, 0.0703578864091209, 0.04928731472630586, 0.04526219071288194, 0.03907141701451369, 0.035447483616215844, 0.01654073127013232, 0.06355561355927161, 0.03032575880310365, 0.07185672276786395, 0.0673719048500061, 0.03215028179277267, 0.01338556972664914, 0.05519127167229142, 0.055923763795622757, 0.0118769989348948, 0.042991988959589174, 0.0312705577484199, 0.030813571198710372, 0.006363485457508692, 0.05559518999819245, 0.11241540033370256, 0.05017726768606475, 0.19841085906539643, 0.05999855657241174, 0.08047537957983357, 0.030939985665359666, 0.12068218924105167, 0.05421678003455911, 0.04563610761293343, 0.04364521122936692, 0.08803753701171704, 30.25670201437814, 92.07904938289097, 71.76965945107597, 90.49951539720807, 59.62742533002581, 37.051053592136924, 29.87076779774257, 29.98615653174264, 64.6231940133231, 93.37926578521729, 64.56988048553467, 59.57929515838623, 108.77193668910435, 70.17281750270298, 9.069086704935346, 0.5156800459538187, 0.0812216391786933, 0.13286037290734903, 0.09515458904206753, 0.1121966474290405, 0.022354417613574436, 0.02850705085854445, 0.3230488396116665, 0.7979403542620795, 1.2532910917486464, 1.1089974173477717, 4.496680881295886, 4.697350936276572, 5.797247299126216, 11.924757242202759, 17.537970645087107, 21.79357031413487, 30.465676035199845, 28.482529878616333, 25.858851875577653, 22.971774612154277, 19.953956569944108, 16.883085557392665, 15.218799182346888, 7.929498757634844, 2.725723590169634, 1.5151102883475167, 0.6284811730895723, 1.2574393834386552, 3.2466524030481065, 5.239062896796635, 10.76537821974073, 6.194367681230817, 12.185929604939052, 9.315481986318316, 6.570995220116206, 14.048217058181763, 4.993563064507075, 2.0028119470391954, 1.779221956218992, 1.1084637088435036, 1.5269423105887003, 2.4073968657425473, 7.387275235993521, 14.600751706532069, 36.31854322978428, 52.264638151441304, 57.14090476717268, 50.05687236785889, 50.58467837742397, 50.131826060158865, 55.9978392464774, 57.67410257884434, 53.49904816491263, 46.42758158275059, 39.31653806141445, 41.79853534698486, 49.78130333764212, 52.48157480784825, 57.413757051740376, 57.6559156690325, 54.4745682988848, 39.451454707554404, 20.04196071624756, 3.306372169937406, 2.906796468155725, 1.903198229415076, 1.0960810418639864, 0.7945842657770429, 0.830704639000552, 0.7535509190389088, 0.33046663871833254, 0.2545280935508864, 0.5695594719478062, 0.34960572315113886, 0.15421187505126, 0.13856645886387142, 0.3514777741261891, 0.10536336552883897, 0.7453904769250325, 3.105652826172965, 57.705491065979004, 82.79932716914585, 47.89692061288016, 42.03293630055019, 59.329959051949636, 75.88832228524345, 39.11460951396397, 15.184030396597725, 23.32004611832755, 31.02809797014509, 43.54793194362095, 63.728231293814524, 66.23612798963273, 34.464788164411274, 0.5102266328675407, 0.14255553909710475, 0.05658532526077969, 0.10351662390998431, 0.033740452357700894, 0.10916880704462528, 0.014396112778091004, 0.019284927053377032, 0.052276118991098235, 0.05990964134356805, 0.10056201102478163, 0.059838754790169854, 0.07975428005946533, 0.01806554534206433, 0.12351044533508164, 0.030158971502844776, 0.06987440306693316, 0.05755167108561311, 0.04671827258009996, 0.061890956812671254, 0.025583441934681365, 0.06362314814967768, 0.026938908932996646, 0.04912292604733791, 0.04485375334375671, 0.10972155524151665, 0.05534523126802274, 0.025474767766094635, 0.028607022815517018, 0.07398704452706234, 0.018389723928911344, 0.03356363630986639, 0.02732291734511299, 0.019138802840773548, 0.05409682182861226, 0.044922332878091505, 0.11247534890260015, 0.10434254352003336, 0.10400115219610077, 0.058048365504613945, 0.03691893430160625, 0.04144009455506291, 0.007804946591412383, 0.06869333822812353, 0.09618932101875544, 0.05988453554787806, 0.031341186458511014, 0.1043512559096728, 0.048794165652777464, 0.06009344290941954, 0.04667294644085424, 0.01134028791316918, 0.01044973190541246, 0.06795277153807026, 0.11882860798920904, 0.13232613514576638, 0.07047127639608723, 0.15821031906775065, 0.014212165327210511, 0.09258626614298139, 0.011178889029127146, 0.041826075807745965, 0.01768551823416991, 0.04145934120086687, 0.08667076392365353, 0.07129867521247693, 53.04825251443045, 104.99213055201939, 81.13745008196149, 113.1279638835362, 85.75484071459088, 59.28259318215506, 43.784532002040315, 19.414917060307094, 23.84042797769819, 65.70879445757184, 58.468854904174805, 65.85509572710309, 115.66422312600272, 65.64958885737828, 4.437269874981471, 0.6165149637631008, 0.11002818521644388, 0.07397693435528449, 0.22587904227631433, 0.18441458152873175, 0.10394680832645722, 0.20900876181466238, 1.35902030978884, 0.6999602232660566, 1.2384855662073408, 0.6518151238560677, 3.3519929562296187, 5.375749162265232, 9.43984431879861, 14.867380142211914, 22.820218767438615, 26.553756850106375, 33.80332660675049, 32.960235663822715, 31.137417452675955, 28.35696029663086, 25.672247580119542, 24.211783136640275, 19.620675802230835, 11.315480130059377, 5.38627872296742, 3.010524387870516, 0.7379614412784576, 1.3033829352685382, 1.1418486088514328, 1.4541812092065811, 0.8211699192013059, 1.281935800399099, 1.4438422897032328, 4.358152040413447, 8.651918598583766, 15.377449137823922, 7.916579450879778, 4.957553591047015, 3.1968401159558977, 0.8286984552230153, 1.0508772560528346, 3.672393935067313, 8.989720906530108, 19.040836470467703, 45.9462103843689, 64.97514111655099, 67.92595073154995, 62.856829915727886, 60.33685725075858, 61.98355252402169, 66.30042661939348, 70.40074620928083, 66.95297363826207, 59.66598783220564, 50.45433364595686, 50.981625488826204, 56.544332436152864, 65.27681800297329, 69.2161478315081, 71.35655430385044, 69.0154560634068, 57.32380567278181, 37.80861915860857, 14.617172036852155, 4.3675733634403775, 3.3593495786190033, 1.7070807644299097, 0.7283198929258755, 0.5884802852358136, 1.289670991046088, 1.0446409221206392, 0.5922001227736473, 1.0701177950416292, 0.32623160311153954, 0.08728515702698912, 0.06905811865414892, 0.26487789675593376, 0.08215823463563408, 0.736058340540954, 0.264089791902474, 49.61470290592739, 91.0692537852696, 55.040863854544504, 36.868454933166504, 54.100036076136995, 41.91235031400408, 7.00330171414784, 15.345284189496722, 39.064224651881624, 56.512408937726704, 66.81221008300781, 77.31587832314628, 79.53710624149868, 52.20080157688686, 1.8424112626484461, 0.16871291478829725, 0.09630556763815028, 0.1322614571877888, 0.05334755292694483, 0.09241653060806648, 0.10911579310361828, 0.02822366070800594, 0.059835721738636494, 0.02302256935009999, 0.003968140218473438, 0.04650323465466499, 0.028563328552991152, 0.06188953188913209, 0.13018512646002428, 0.0488412424123713, 0.08886417586888586, 0.07339603374046938, 0.0658259510195681, 0.026596983262736882, 0.012914702046795614, 0.052982144856027195, 0.025087955308013728, 0.02401735936291516, 0.051609210669994354, 0.0998909127499376, 0.132606872224382, 0.032104324615959606, 0.017389325824167048, 0.09661487104105097, 0.052688060993594785, 0.00932218142718609, 0.041275634629918, 0.00882886950525322, 0.15016136025743826, 0.13459092218961033, 0.19564065842756204, 0.1949041900890214, 0.08881753337170396, 0.18088349886238575, 0.11847992241382599, 0.15194737299212388, 0.16196943021246366, 0.1482471858284303, 0.27159276072468075, 0.10575821184154068, 0.06556492538324424, 0.21975915852401937, 0.15379776512937887, 0.10687774712485926, 0.08117508489106383, 0.12885978472019943, 0.10117791047585861, 0.12998041244489805, 0.18732888943382672, 0.19512205411280903, 0.15315934510103293, 0.24609618314674922, 0.15958879009953567, 0.23871464495147976, 0.11114637700042554, 0.21666712872684002, 0.15098800589995726, 0.167999747342297, 0.12712440426860536, 0.2192362387265478, 57.84868649074009, 125.0554986681257, 90.12796742575509, 115.09231689998082, 72.11388710566929, 46.866363797869, 37.842818192073274, 37.94497755595616, 83.30106353759766, 123.79636001586914, 88.3105549131121, 79.99464511871338, 124.01586750575474, 82.52130889892578, 12.166799477168492, 0.8681570036070687, 0.3241533860564232, 0.3884166505719934, 0.19418920416917118, 0.23327423259615898, 0.08758819755166769, 0.143139974879367, 0.8828821363193649, 2.052016918148313, 3.5006038503987447, 3.2565305701323917, 8.653097186769758, 6.434491344860621, 7.991480163165501, 12.701504179409572, 22.11415672302246, 25.26570848056248, 34.628084727696006, 33.771639347076416, 32.23522935594831, 30.102809837886266, 25.683428968702042, 23.283126865114482, 20.553203957421438, 11.981301682335989, 5.7513171008655, 5.252395621367863, 3.637840760605676, 5.603141554764338, 11.492753863334656, 14.529839260237557, 26.1015750340053, 18.29739659173148, 24.56306321280343, 23.59617621558053, 16.08433106967381, 23.7417722429548, 12.779700074877058, 7.808272668293544, 6.2658568280083795, 2.6264366550104956, 3.376338141305106, 3.699219192777361, 8.952501143727984, 20.555375269481114, 53.114698137555806, 72.44519805908203, 78.78622831617082, 68.23996761866978, 66.32307079860142, 68.01795877729143, 70.30225549425397, 71.69413253239223, 68.1745433807373, 61.324314389910015, 53.74189117976597, 56.82281623567854, 67.97161429268974, 73.88091823032924, 79.50862557547433, 81.0402934210641, 77.16489396776471, 64.67008740561349, 44.527006081172395, 19.583423035485403, 5.003182411193848, 3.463083795138768, 5.148291630404336, 3.671098530292511, 5.049080039773669, 3.5119743602616444, 1.4175851557935988, 0.42078811781747, 1.0256162115505763, 0.7175210895282882, 0.47517791071108406, 0.3165245625589575, 0.5197172750319753, 0.17746318025248392, 1.2520003552947725, 4.3154623082705905, 69.25402246202741, 93.08546120779855, 58.39541939326695, 63.83094651358468, 86.51129804338727, 112.01967757088798, 55.251453331538606, 21.4775037084307, 31.73341655731201, 42.85503326143537, 58.313354219709126, 82.80629621233258, 89.98978860037667, 59.311469895499094, 1.8496695246015276, 0.2468336692878178, 0.1782721025603158, 0.2081620722476925, 0.16522079360272202, 0.23390187748840877, 0.15116556494363717, 0.13824438543191978, 0.10888009717954056, 0.11535680214209215, 0.13957649895123073, 0.11733330679791314, 0.15533950525735105, 0.12952839955687523, 0.2131898674581732, 0.17436749993690423, 0.11817291245928832, 0.10072255241019384, 0.1356656402349472, 0.09638000292969601, 0.25924841740301674, 0.148253577628306, 0.15542521780090673, 0.14861298405698367, 0.1417255007794925, 0.2524551690689155, 0.19879315926560334, 0.11557710889194693, 0.14164966770580836, 0.15912977473012038, 0.2193526481943471, 0.16800581344536372, 0.17380982557577745, 0.08808938387249197], [0.05630058143287897, 0.062349103657262664, 0.04806982273502009, 0.0971430426995669, 0.053350192428167374, 0.059233861177095344, 0.026804899963151132, 0.08659261704555579, 0.14188681569482597, 0.09076412141855274, 0.08960582142961876, 0.04053818241560033, 0.06930394510605506, 0.1398590002208948, 0.0791031646409205, 0.022154427898515548, 0.1163380994860615, 0.056218611009951146, 0.017981376465676085, 0.004819789452345243, 0.06864111817308835, 0.05761452378439052, 0.04630766050623996, 0.06992183266473667, 0.013681913958862424, 0.07778625709137746, 0.08321028282599789, 0.12211887857743672, 0.1170029416680336, 0.02373575545581324, 0.5360004327126912, 39.43261466707502, 83.21549647194999, 80.0438175201416, 79.75646087101528, 54.72503348759243, 28.585896492004395, 31.638868944985525, 50.135032653808594, 69.45825086321149, 75.74884414672852, 59.22386005946568, 75.89359596797398, 109.99452086857387, 49.840449878147666, 1.3447312308209283, 0.2033690365829638, 0.2018428077655179, 0.2122018254761185, 0.15087098575064115, 0.03960896263431225, 0.0259326618563916, 0.31226908947740284, 0.477726759655135, 0.9174864994628089, 2.330934762954712, 3.514161522899355, 3.470142947775977, 6.7011779717036655, 13.583217552730016, 20.47748248917716, 31.107925823756627, 38.77348075594221, 39.42954008919852, 45.325722353799, 52.55110543114798, 52.679445607321604, 50.11927761350359, 48.27389860153198, 44.86649506432669, 33.49215153285435, 29.685636520385742, 21.48407323019845, 10.984553933143616, 4.676224938460758, 2.452238368136542, 0.2614896185696125, 0.5181239119597844, 0.41966712368386133, 2.597136970077242, 3.472111676420484, 2.1338821138654436, 0.8354973761098725, 7.777269806180682, 4.227945404393332, 1.4694372820002692, 2.4824541296277727, 3.0290378630161285, 2.2381270229816437, 9.474075487681798, 24.66880784715925, 48.937913622174946, 57.07858637401036, 64.8764419555664, 73.41167163848877, 80.33532919202531, 84.39313275473458, 85.01156411852155, 82.42251246316093, 82.58811582837785, 86.56602900368827, 84.25175080980573, 74.76073387690953, 53.82468591417585, 39.92520720618111, 41.855698176792686, 43.33366339547293, 46.145161628723145, 44.459750992911204, 47.69303614752633, 46.86032928739275, 35.30674655096871, 21.52260446548462, 5.580041400023869, 4.205523133277893, 2.5639493337699344, 1.9109228891985757, 1.9312782883644104, 0.6685497515967914, 0.9131330187831606, 0.4293035151703017, 0.23067688196897507, 0.727559010897364, 0.2720924610538142, 0.1545644961297512, 0.22714088670909405, 0.33528326026030947, 0.3584749086626938, 0.779760935476848, 36.56165027618408, 89.71377141135079, 67.00288254874093, 51.61160128457205, 85.63481058393205, 116.4097717830113, 78.92330237797329, 39.945113795144216, 21.570837123053415, 39.04645463398525, 45.873594760894775, 52.866727352142334, 64.38107708522251, 45.67431695120675, 1.2937296075480325, 0.3800813906959125, 0.1696752810052463, 0.1003513259014913, 0.07525000175727264, 0.0759044216413583, 0.02877808827906847, 0.0710907449413623, 0.08269385660865478, 0.035365540334688764, 0.011891641720597233, 0.02524214730198894, 0.02540110600447016, 0.10785023029893637, 0.06603662935750824, 0.039479494760079045, 0.037976146143461974, 0.005600033053529582, 0.12028454057872295, 0.1443361642637423, 0.17179571650922298, 0.07246246454971177, 0.02991163870319724, 0.0513021939301065, 0.05395552369632891, 0.1699765912656273, 0.03550663829914161, 0.10286396821694714, 0.05041369303528752, 0.061858427843877246, 0.06157748041940587, 0.11888844120715346, 0.054997136018105915, 0.058260638399847915, 0.09631229870553527, 0.03514084007058825, 0.10233583727053233, 0.0319474473196481, 0.03933620512751596, 0.04227794620341488, 0.06168813591024705, 0.1482149554150445, 0.09667223439152751, 0.024494676518120935, 0.056689704302698374, 0.025864918616467288, 0.05835001503250428, 0.036219629326037, 0.022343355796432922, 0.04799616775874581, 0.0634494838970048, 0.026823812430458407, 0.09267252151455198, 0.08920231701007911, 0.08338816756648676, 0.07428493497094937, 0.1218999017562185, 0.06888786743261985, 0.07322615571320057, 0.07194799929857254, 0.08600405577038016, 0.1276009122708014, 0.08289610754166331, 1.9315119215420313, 64.09351893833706, 94.07657309940883, 95.21452127184186, 98.00300707135881, 79.92785208565849, 53.38338150296892, 32.370889459337505, 18.922812632152013, 34.69699696132115, 56.23446362359183, 59.228744643075125, 84.6585122517177, 114.87087781088692, 42.506650584084646, 0.3929431305399963, 0.09863831674946205, 0.18220008750047, 0.07032356610787766, 0.3189801536500454, 0.07285568237836872, 0.2798762890909399, 0.640145787170955, 1.3986681423016956, 1.1083168195826667, 0.8367827385663986, 1.8485597670078278, 3.8403019309043884, 8.300841757229396, 16.807737554822648, 24.296448673520768, 36.4398900440761, 42.43042884554182, 49.47885520117623, 57.10040371758597, 60.26253931862967, 61.35355240958077, 57.50479582377842, 56.880156244550435, 51.902053356170654, 44.64412144252232, 40.148282596043174, 30.31518500191825, 18.63914200237819, 10.080811296190534, 6.26971264396395, 1.725669149841581, 0.44795684995395796, 0.37751321707453045, 0.9574072659015656, 1.6621951844011034, 0.8253402497087206, 2.1592436901160648, 4.559803528445108, 5.724170054708209, 2.6952939544405257, 4.855945740427289, 3.7117007630211964, 2.9878984476838792, 13.261590651103429, 30.095677512032644, 60.18087714059012, 72.55069950648716, 78.49124254499162, 86.38109574999127, 91.37658650534493, 97.33985015324184, 98.83625589098249, 96.10822636740548, 96.2759141921997, 97.90257086072648, 96.20828737531389, 88.79511533464704, 70.44209493909563, 53.64768055507115, 49.92688199451992, 50.02337857655117, 52.82641737801688, 53.294698170253206, 55.08090284892491, 56.970413344247, 50.31484161104475, 42.54868023736136, 18.391454356057302, 7.037442990711757, 5.321348675659724, 2.9447004113878523, 1.5416613093444278, 0.5443147122859955, 0.8162378381405557, 0.6205604981098856, 0.596584110387734, 0.6375324502587318, 0.3820704482495785, 0.29077676417572157, 0.15365087586854184, 0.39130590696419987, 0.16914364881813526, 0.28252794966101646, 25.967624187469482, 92.90513460976737, 70.64665685381208, 50.817377022334504, 88.50012956346784, 100.12758554731096, 41.07639169692993, 15.874677862439837, 27.11421070780073, 64.37633841378349, 75.05575438908168, 72.18445995875767, 72.57123143332345, 65.30024732862199, 3.6460003341947282, 0.4811470646943365, 0.20682393333741597, 0.14526368092213357, 0.04495343692334635, 0.021390748609389578, 0.04320890981970089, 0.04465903075678008, 0.0686660407643233, 0.047597335052809546, 0.028126289236492345, 0.031714981222259145, 0.052615043840238025, 0.09595565391438347, 0.05376086896285415, 0.04284178844786116, 0.053982268154088936, 0.008172445398356234, 0.09231489963297333, 0.07304844060646636, 0.16104787109153612, 0.05189599010295101, 0.13971801421472005, 0.05416146585983889, 0.08109709407602038, 0.08216996650610651, 0.15232904894011362, 0.11698132354233946, 0.04232013411819935, 0.10595861715929848, 0.04698204967592444, 0.1283462287059852, 0.07106616161763668, 0.09388632566801139, 0.24400713667273521, 0.2061969262680837, 0.14368931683046476, 0.12048755825630256, 0.13490630526627811, 0.09241142802472625, 0.14544810674020223, 0.23251071785177502, 0.2148571637059961, 0.09502915505852018, 0.21213127140487942, 0.09760882306311812, 0.1944922786206007, 0.16560329736343452, 0.16848698976848805, 0.2504030077585152, 0.20272019425673143, 0.10300844867846795, 0.18031720710652216, 0.18467769026756287, 0.18621260433324746, 0.14417687138276442, 0.18574565010411398, 0.1641081047377416, 0.13924253758575234, 0.13885584047862462, 0.16983857724283422, 0.19668391958943435, 0.15823904824044022, 1.5765996745654514, 67.3040383202689, 115.8851341520037, 101.18289879390171, 102.75939641680036, 66.55947630746024, 39.04373094013759, 43.591177531651084, 62.00892039707729, 98.64789022718156, 112.69522312709263, 77.2011913572039, 88.5604190826416, 124.3903476170131, 61.70815372467041, 2.047282806464604, 0.517869597034795, 0.2412390937762601, 0.3173857863460268, 0.3989786723894732, 0.12766993285289832, 0.18455948946731432, 0.4567169270345143, 2.2124562518937245, 2.403977700642177, 4.281613724572318, 7.842860800879342, 5.263461496148791, 8.40202750478472, 17.1896105493818, 26.190769059317454, 39.57054335730416, 45.27289867401123, 51.27216788700649, 60.439398765563965, 61.646467617579866, 63.48614910670689, 60.53019782475063, 58.47348240443638, 56.250010217939106, 46.583370617457796, 37.83989994866507, 27.876919678279332, 15.456394570214407, 7.142023801803589, 4.608061807496207, 1.1263058143002647, 1.282998223389898, 4.1521787728582105, 9.759060195514135, 10.578632354736328, 6.655907418046679, 5.279664261000497, 18.04621400151934, 10.175846150943212, 6.008163775716509, 7.6573777709688455, 6.091976855482374, 3.9887797236442566, 14.742996965135847, 32.63033866882324, 68.37809085845947, 82.63569014413017, 83.54967703138078, 88.390869140625, 93.08414105006626, 98.42378302982875, 101.60820497785295, 98.34430258614677, 96.3774412700108, 96.53734711238316, 92.51478481292725, 84.14136477879116, 68.63756438664028, 52.28421817507063, 53.08789546149117, 54.17680672236851, 58.2122996194022, 57.36367791039603, 61.31578895023891, 63.13732174464634, 57.74984836578369, 51.39179849624634, 27.081408262252808, 7.1801281571388245, 6.04503960268838, 6.876065867287772, 7.344386611665998, 5.551309730325427, 3.7664972969463895, 1.333571881055832, 0.4690069332718849, 1.1393115392753055, 0.46475186731134144, 0.5791128107479641, 0.4857172966003418, 0.5081186688372067, 0.5091482507331031, 1.4878389345748084, 46.870167936597554, 105.01327392033168, 77.83039242880685, 64.46112728118896, 104.9709871837071, 150.3664937700544, 106.41269670213971, 49.48712008340018, 26.640711818422588, 51.32295574460711, 61.58214814322335, 69.77904224395752, 84.94422912597656, 72.22027097429547, 3.353052773645946, 0.5101928689650127, 0.37904714047908783, 0.289811941662005, 0.2752326396959168, 0.2555601995970522, 0.18463342264294624, 0.17019184971494333, 0.18684969443295682, 0.1437237321266106, 0.16701429736401352, 0.1677700225263834, 0.13775862221206936, 0.12272130910839353, 0.16369677680943692, 0.07276332697698049, 0.19016961700149945, 0.1353001677032028, 0.19827303503240856, 0.2993084192276001, 0.3521943342472826, 0.15489009794379982, 0.24047015075172695, 0.18250020353921823, 0.19978797302714416, 0.3651729178215776, 0.3915782980620861, 0.23699982411095075, 0.1500920546906335, 0.218332972909723, 0.16686930800122873, 0.26937313697167803, 0.24511466867157392], [0.056517448010189195, 0.09115092030593328, 0.12442908675542899, 0.12404598588390009, 0.01463056867942214, 0.04033967360321965, 0.02596617130828755, 0.041846581136009524, 0.14947100515876496, 0.12756318572376454, 0.11101206777883427, 0.004281846465476389, 0.01348555610249085, 0.06179259637636798, 0.1521917405937399, 0.17666271249098436, 0.08570639602839947, 0.09125816276563065, 0.06922589322285992, 0.01418460747559688, 0.1537355434681688, 0.04343677884233849, 0.09697167189525706, 0.14562414586544037, 0.16333580975021633, 0.07678514652486358, 0.1353176874773843, 0.09246633507843528, 0.14555566811135837, 1.531827871288572, 59.03154781886509, 92.55222170693534, 80.073333467756, 79.09825107029506, 50.19329677309309, 40.036951610020225, 40.722547735486714, 53.77866799490792, 80.01863030024937, 63.920668601989746, 74.15533038548061, 100.51703207833427, 97.65600708552769, 24.705485650471278, 0.6414302811026573, 0.06295746458428246, 0.17227120670889104, 0.18130712184522832, 0.09134658266391073, 0.026283249026164412, 0.19923780326332363, 1.113692771111216, 0.5223296891365732, 0.5678777907575879, 3.7772092478615895, 1.5238184439284461, 2.4971083147185187, 7.710032956940787, 16.55726194381714, 28.749457086835587, 37.7876147542681, 56.373775005340576, 64.04267896924699, 80.589522089277, 75.96692030770438, 75.56448064531598, 71.50680215018136, 70.7109624317714, 69.19945131029401, 70.81271185193742, 78.64572879246303, 76.08840261186872, 69.11171640668596, 69.66485554831368, 62.92164271218436, 51.08083186830793, 32.91406488418579, 18.092784302575247, 6.964116045406886, 1.6099427768162318, 1.2118627833468574, 0.32470275514892166, 0.1998163629323244, 0.5307989461081368, 1.1140205306666238, 3.3144058074269975, 0.7886951789259911, 4.486057085650308, 5.208949838365827, 29.08532084737505, 44.05960423605782, 59.501016753060476, 66.95040280478341, 91.5860538482666, 94.60739462716239, 100.57261071886334, 99.69965989249093, 96.091383934021, 95.18877819606236, 90.0505644934518, 91.11557047707694, 90.44473579951695, 92.7777463368007, 87.65530504499162, 74.15499687194824, 56.825275897979736, 46.96495178767613, 44.204109396253315, 43.4083183152335, 41.16165999003819, 41.26242276600429, 39.43140568052019, 34.66830784933907, 26.44861670902797, 7.616055965423584, 6.664129742554255, 4.175973313195365, 3.0390439203807285, 1.6092829150812966, 0.3465709888509342, 1.1474196527685439, 0.2786599743579115, 0.14484767110220023, 0.08011658383267266, 0.4026302493044308, 0.09173729669834886, 0.32154349610209465, 0.3438558174031121, 0.10608706383832864, 0.21287475579551288, 12.91934757573264, 85.48364557538713, 98.43845067705426, 78.29897199358258, 79.58636202130998, 91.64501626150948, 89.04834243229458, 54.57044301714216, 24.904824256896973, 32.86896065303257, 44.370775835854666, 52.07244403021676, 67.83560330527169, 44.59514706475394, 1.9466220821653093, 0.7074507070439202, 0.010974658470201706, 0.07817812463534729, 0.08289139850863389, 0.09355425741523504, 0.0363956888073257, 0.032482947156365426, 0.09114374819078616, 0.04529678921348282, 0.012155967581618046, 0.02693046965370221, 0.05028822851766433, 0.06210902439696448, 0.04331184358202985, 0.0031356943737981574, 0.06046636575566871, 0.12581515737942287, 0.07125407510570117, 0.18980409018695354, 0.09871106248881135, 0.1536244401442153, 0.04248235487778272, 0.09001101540135485, 0.025701810672347034, 0.10032726504973002, 0.1810102356331689, 0.14281171320804528, 0.09384363902998821, 0.1243415285966226, 0.05352478966649089, 0.144328985363245, 0.021950904712347046, 0.030793520488909314, 0.08284318181020872, 0.08456271846911737, 0.0506681775940316, 0.06890001999480383, 0.07429577117519719, 0.05235327520806875, 0.11138736549764872, 0.12757572505090917, 0.10126470189009394, 0.08841696700879506, 0.026882010379007885, 0.024016387361500944, 0.09475539331989628, 0.06469912148479905, 0.060929852670856884, 0.09620796716106789, 0.05896746154342379, 0.043731388569410355, 0.00809778958292944, 0.042560427117028406, 0.13823708439511911, 0.26585520431399345, 0.09777889108019215, 0.179047342389822, 0.26114543846675325, 0.13600192219018936, 0.27468840032815933, 4.6505096554756165, 84.83573995317731, 102.83520821162632, 93.96918174198696, 100.73198849814278, 80.86230141775948, 52.043605531964985, 26.009676422391617, 21.364463465554373, 45.92234679630825, 63.171145575387136, 82.41149262019566, 111.07575784410749, 96.1113669531686, 18.671053341456822, 0.2597178822117192, 0.08282161796731607, 0.12388677442712442, 0.1580287702381611, 0.20580843782850675, 0.045083912422082255, 0.738884086055415, 1.831764885357448, 0.49643462151288986, 0.8004742754357201, 1.6550660069499696, 0.5203826736126627, 2.990182016577039, 9.96539216382163, 18.20727150780814, 33.001396792275564, 47.72552245003836, 65.29962199074882, 76.03697899409703, 84.91922950744629, 82.29058701651437, 80.53714656829834, 76.80415739331926, 80.09595680236816, 79.20530891418457, 83.9160555430821, 85.96503067016602, 82.97506100790841, 79.91110692705426, 79.80550125667027, 75.95788070133754, 64.59121840340751, 42.68779012135097, 27.049496923174175, 11.61626591001238, 2.8733141848019192, 1.8030171479497636, 0.6041876652411052, 0.549521844301905, 1.6595627942255564, 2.3942736727850775, 4.783969785485949, 2.0008825191429684, 5.931712312357766, 9.970973304339818, 38.95522478648594, 55.20606075014387, 74.92616353716168, 80.00590814862932, 99.5307422365461, 100.06943607330322, 104.95685454777309, 100.73218999590192, 99.11700480324882, 99.08343110765729, 97.04237692696708, 95.37655326298305, 95.04599966321672, 94.40004648481096, 96.54785973685128, 86.64633628300258, 74.44477844238281, 62.809179169791086, 58.30455085209438, 55.43212733949934, 53.847232818603516, 54.21534143175398, 52.15845578057425, 46.114384583064485, 39.766791752406526, 22.37233441216605, 11.98777653489794, 7.586235165596008, 6.342499801090785, 3.3780717168535506, 1.4415123632975986, 0.3897372968494892, 0.09799592729125704, 0.32928552638207165, 0.40390765933053835, 0.43600334280303543, 0.1345365715346166, 0.28930917435458725, 0.22230788533176693, 0.10696515600596156, 0.4355582781136036, 6.514359584876469, 79.22062274387905, 100.08323519570487, 76.51142283848354, 84.19194766453334, 94.83243983132499, 62.147592544555664, 15.4391074521201, 22.96143569265093, 55.94928176062447, 63.125002588544575, 69.85632705688477, 71.70232445853097, 63.468257495335166, 4.585130146571568, 0.5657259662236486, 0.07726535932826144, 0.05142552784777113, 0.1056864567633186, 0.05508650925808719, 0.06776188606662409, 0.047213155310600996, 0.11199053563177586, 0.05412205993863089, 0.02327085379511118, 0.031428161077201366, 0.0798964738579733, 0.09308218703206096, 0.09944763939295496, 0.028577279232974564, 0.08178765273519925, 0.10413738845714501, 0.05680622912145086, 0.1452936450285571, 0.0678792522687997, 0.13696470909884997, 0.11878600956073829, 0.09857430375580277, 0.03323952727285879, 0.03404627487595592, 0.011377761705911585, 0.13877107788409504, 0.18330073915421963, 0.10090935988617794, 0.03661915413769228, 0.08606147340365819, 0.24760937052113668, 0.2738747282751969, 0.17011218970375402, 0.21951067900019033, 0.09257889046732869, 0.149107622514878, 0.11966801009007863, 0.13765043658869608, 0.27624658814498354, 0.21275251092655317, 0.224505945241877, 0.08430116357547895, 0.052560252137482166, 0.1162190165902887, 0.29043328974928173, 0.30408340586083277, 0.21142412934984478, 0.19483173611973012, 0.19484245697302477, 0.09208301029035024, 0.22865064069628716, 0.13591999587203774, 0.2554281566824232, 0.3531452603638172, 0.19462409083332333, 0.2304890634758132, 0.21076581467475208, 0.18425260164908, 0.3432082507227148, 4.913090331213815, 96.77414172036308, 119.7653626033238, 99.75312628064836, 98.09149238041469, 62.42816080365862, 50.94528988429478, 50.9061541557312, 69.48887852260044, 116.66906465802873, 88.38160719190324, 90.29213251386369, 116.62501307896206, 115.59474114009312, 33.56577117102486, 1.2161997620548521, 0.18200070677059038, 0.4358420143170016, 0.2417901727770056, 0.2905548018004213, 0.1761063951998949, 0.6515698741589273, 2.4216157027653287, 2.657762825489044, 4.757953992911747, 8.371912275041852, 3.502580395766667, 3.7424361194883073, 10.83981340272086, 21.776380470820836, 36.61629785810198, 50.016996656145366, 67.60928658076695, 80.77657454354423, 91.27841540745327, 91.44137150900704, 92.47195611681256, 87.70887565612793, 90.5300110408238, 89.13744613102504, 90.4460003716605, 93.67868450709751, 93.15712492806571, 87.25431755610875, 88.08063207353864, 82.09760774884904, 67.93654673440116, 41.49961689540318, 24.241174016680034, 9.77666345664433, 2.8474740513733456, 2.3778496512344907, 2.8060376005513326, 2.1089317841189246, 4.67454651423863, 5.654098774705615, 9.600512725966317, 5.5188199537140985, 7.8387743915830335, 10.423068267958504, 42.081038679395405, 62.686904770987375, 80.47920554024833, 85.2219625200544, 103.18192332131522, 103.88505322592599, 106.07493087223598, 100.12308311462402, 96.75288023267473, 98.9169453212193, 97.56811237335205, 98.77462536948067, 98.13352898189, 97.6650675364903, 99.43976252419608, 87.22983210427421, 77.33712591443742, 66.40977736881801, 64.84171485900879, 60.54485157557896, 57.99323681422642, 55.55891111918858, 54.960504463740754, 49.35484722682408, 48.90352003914969, 35.19976166316441, 18.6482059274401, 6.967090308666229, 6.520572577204023, 7.18851854119982, 5.787624478340149, 4.661241148199354, 1.889404969555991, 0.551769532263279, 0.3831176177731582, 0.8085789691124643, 0.44790308283908026, 0.623353293963841, 0.6243940038340432, 0.2591875120997429, 0.5179831023727144, 16.94112386022295, 100.95162800380162, 106.3388442993164, 83.14447893415178, 84.96474715641567, 114.61645562308175, 125.08272171020508, 73.09112344469342, 29.28845317023141, 41.90142774581909, 57.97711699349539, 69.55119691576276, 84.09089306422642, 72.81179196493966, 4.332018996988024, 0.8488423685942377, 0.12036648046757494, 0.12925598131758825, 0.2193749448550599, 0.1650372770215784, 0.3069043473473617, 0.12372463169906821, 0.15325978185449327, 0.0876051609271339, 0.15161645146352903, 0.13335168654365198, 0.24020432787282125, 0.20845244452357292, 0.23885054194501468, 0.12572839989193849, 0.17276781291833945, 0.13983403013220855, 0.13183229735919408, 0.26646463732634273, 0.21167106181383133, 0.22655099550528185, 0.1398116520472935, 0.11193476683859314, 0.12779652034597738, 0.19533317349851131, 0.2765543444880417, 0.2164980920829943, 0.32505092503769056, 0.24982704009328568, 0.21271839418581553, 0.2227801049926451], [0.022398814159844602, 0.03288511825459344, 0.07731225288340024, 0.13883058540523052, 0.24557330406137876, 0.14668964940522397, 0.0584780274491225, 0.03149452519470027, 0.028967209559466158, 0.04381831569064941, 0.08092943485826254, 0.29930662789515083, 0.08979798933225018, 0.10802789790821926, 0.031225017870643308, 0.09903761425188609, 0.0873042984998652, 0.12617011261837824, 0.02235165936872363, 0.012176451705662268, 0.07154089185808386, 0.007171026946577642, 0.01568984496407211, 0.1431281819407429, 0.09295874115611825, 0.16040167505187647, 0.2729705939335482, 0.37297180933611734, 3.6480153117861067, 62.1555621283395, 88.94896234784807, 83.58812141418457, 63.83401761736189, 54.18226105826241, 30.264661175864084, 30.726494039808, 73.14037227630615, 63.488768577575684, 68.17931679316929, 86.25961344582694, 110.34588432312012, 57.669527190072195, 4.192539121423449, 0.08693885310952153, 0.03969848854467273, 0.0582548233547381, 0.1406875186200653, 0.09616336705429213, 0.06811870049153056, 0.7354308856385094, 2.0077080386025563, 1.6492947680609567, 1.2649877326829093, 2.0418345502444675, 2.3119861568723405, 4.307738517011915, 9.716208049229213, 22.368233237947734, 37.37803929192679, 60.02543898991176, 79.8087738582066, 87.72721195220947, 85.15513474600655, 72.88015529087612, 71.00701822553361, 72.04414108821324, 77.00570378984723, 75.02677345275879, 76.11345781598772, 74.09340109143938, 64.14237867082868, 70.88680744171143, 69.50296252114433, 62.76797635214669, 64.7188776561192, 69.1732566016061, 67.66159956795829, 69.06729657309396, 57.49220221383231, 31.24393333707537, 15.093931368419103, 3.4567607172897885, 0.7511926570108959, 0.5654252937861851, 0.5195650117737907, 2.0460712143353055, 4.425507009029388, 10.338035345077515, 27.347673654556274, 59.035376276288716, 61.14184774671282, 71.89602633884975, 86.59097998482841, 95.5844086238316, 98.24316460745675, 98.16395514351981, 98.4369637625558, 97.84548446110317, 94.65852642059326, 93.5424164363316, 90.7347605569022, 84.70915767124721, 80.36517170497349, 79.57192366463798, 82.28092207227434, 82.16230937412807, 74.64519923073905, 61.95792061941964, 52.12641416277204, 49.3496013368879, 47.24795886448452, 45.25154338564192, 39.573301792144775, 32.14668151310512, 23.026846034186228, 9.784216148512703, 8.044821483748299, 10.16319956098284, 7.8358222757066995, 4.184377159391131, 2.1172839530876706, 0.709298982151917, 0.1930737333106143, 0.3686092091458184, 0.24167047919971602, 0.04858551952721817, 0.03294658334925771, 0.16755652826811585, 0.14603271894156933, 0.03777480784005352, 0.41159936945353237, 4.0542261089597424, 47.870739800589426, 88.21027156284877, 75.33518314361572, 61.50783021109444, 77.54970605032784, 119.54189464024135, 73.45103318350655, 31.918697220938547, 35.6312552179609, 48.23460306440081, 60.62690980093819, 69.31458296094621, 54.171786648886545, 9.456346290452139, 0.21057340928486415, 0.09495876383568559, 0.018504138503755842, 0.052798560421381674, 0.018592499030221785, 0.0025381348761064665, 0.08074669859239034, 0.09646395806755338, 0.035318639994199784, 0.09045728109776974, 0.06660694482603244, 0.02816613281278738, 0.04573170641171081, 0.08501109440944024, 0.18510709436876432, 0.24428254046610423, 0.019842572576765503, 0.12562101493988717, 0.0857562819229705, 0.12632492716823304, 0.0753988791257143, 0.03648517061290996, 0.08671805781445333, 0.01522510445543698, 0.024147135970581855, 0.09669184405356646, 0.039285348927868266, 0.07862841404442276, 0.0696552973240614, 0.09398725775203534, 0.06002776750496455, 0.011764501221477985, 0.09750090206840209, 0.14440864537443432, 0.19030906951853208, 0.13408060957278523, 0.032221249770373106, 0.0695820969662496, 0.042070456980062385, 0.0946415758558682, 0.06977059399443013, 0.11028269691658871, 0.23562030813523702, 0.15089759789407253, 0.018493794237396548, 0.046410387315388234, 0.07518567663750478, 0.15334961989096232, 0.03532978832455618, 0.01839565602131188, 0.13170541131070682, 0.023190094557191645, 0.06675443119768586, 0.16010679730347224, 0.03587780713236757, 0.131651494918125, 0.2854890493409974, 0.5307233301656586, 11.139555215835571, 85.97043636866978, 97.95323712485177, 100.47722584860665, 95.11316095079694, 82.06853648594448, 50.46475594384329, 26.31725754056658, 23.893736294337682, 38.594856466565815, 72.29192079816545, 96.36797087533134, 115.42658083779472, 52.53928654534476, 1.695550120302609, 0.19291757526142256, 0.02413263567723334, 0.12733305378683976, 0.15347679092415742, 0.1578123854207141, 0.3433523715606758, 1.4449647494724818, 3.275973149708339, 1.5178516783884592, 0.6927420220204762, 1.5629310480185916, 2.847291661160333, 6.902830762522561, 15.368463379996163, 30.246123382023402, 49.40626389639718, 69.62689059121269, 83.19844559260777, 90.6497493471418, 83.90536921364921, 78.23231792449951, 79.48469597952706, 81.2045488357544, 82.41331999642509, 79.43084744044712, 79.12952491215297, 78.27714075360979, 70.68080724988664, 75.00991017477853, 75.0930870601109, 70.75943306514195, 70.50271102360317, 75.0902521950858, 75.93041447230748, 76.96065861838204, 67.24305398123605, 40.208533900124685, 21.065249715532573, 6.076430695397513, 2.0216487305504933, 0.7572139767663819, 1.4716253131628036, 7.037086027009146, 6.267909152167184, 13.554928830691747, 37.35223020826067, 68.2130433491298, 74.65419714791435, 80.85616615840367, 94.49220044272286, 98.72541822705949, 101.96104145050049, 102.54278632572719, 102.66991056714738, 101.53970268794468, 97.62379523686, 93.16690799168178, 93.53252914973667, 89.0985084261213, 85.8564372743879, 82.39918736049107, 82.25355311802456, 87.10677950722831, 83.64937673296247, 76.20418739318848, 69.91551876068115, 65.90688065120152, 61.99339117322649, 59.10267652784075, 53.071494238717214, 48.13910354886736, 40.71204553331648, 25.73345078740801, 21.122792959213257, 16.96924148287092, 14.55738799912589, 9.102804575647626, 4.251052507332393, 1.334325217774936, 0.14951316932482378, 0.4095072831426348, 0.2563583196273872, 0.18518323956855706, 0.0475265197455883, 0.29768919040049824, 0.3056477004928248, 0.11622078078133719, 0.493774872805391, 1.343838061605181, 38.18741062709263, 92.6137341090611, 79.91363607134137, 66.03167029789516, 85.29608590262276, 104.70440564836774, 31.152953624725342, 25.88188862800598, 56.42776945659092, 73.59452043260846, 77.38859816959926, 79.15439251491001, 72.31261253356934, 18.065439667020524, 0.12199932070715086, 0.03339466751952257, 0.027227567907954966, 0.05410314238231097, 0.04237571631425193, 0.04018585989251733, 0.01612491992169193, 0.12602240911551885, 0.04651097673922777, 0.04667633572327239, 0.08576846841190543, 0.028989777634186403, 0.09261871368757316, 0.06019387287752969, 0.0787166982356991, 0.044323447692607126, 0.002054788513175611, 0.11154939966010195, 0.12023643244590078, 0.12273471696036202, 0.06496153133256094, 0.035835269772048504, 0.04517851038170712, 0.06657470762729645, 0.0778197767212987, 0.06698530952313117, 0.037033416729952605, 0.05768999723451478, 0.11969353657748018, 0.056609243620187044, 0.1376759223639965, 0.11011928532804761, 0.26111026321138653, 0.29362509133560316, 0.3513167713369642, 0.1557915181453739, 0.174764022231102, 0.15397544630936214, 0.06983974349818059, 0.1313141408775534, 0.29963300323912073, 0.2948152417583125, 0.2861119173467159, 0.18976161389478616, 0.12759271556777613, 0.13417430168816022, 0.180904357028859, 0.20745284030480043, 0.1192286450948034, 0.08545384529445853, 0.14191394352487155, 0.10175982889320169, 0.08172129201037542, 0.2478268545653139, 0.17366228492132255, 0.1893854612218482, 0.24262895062565804, 0.5257621535233089, 12.26119075502668, 102.52204595293317, 110.66520268576485, 103.56102398463658, 83.9351978302002, 65.0433098929269, 35.49287836892264, 40.32117462158203, 96.76784665243966, 87.052903175354, 87.9519236428397, 101.6392981665475, 127.91701698303223, 71.45966557094029, 6.418886125087738, 0.46081261868987766, 0.16899154840835504, 0.26690891491515295, 0.5555343702435493, 0.1459419173853738, 0.2754203496234757, 1.7170839990888322, 6.326454673494611, 5.494386613368988, 5.4053515280996045, 4.81560753924506, 5.325958805424826, 8.08323894228254, 15.589744397572108, 29.11412113053458, 51.5585344178336, 73.51644352504185, 89.85081768035889, 97.35898549216134, 96.29946858542306, 90.76691681998116, 88.33780574798584, 88.24092701503209, 89.35500812530518, 85.53695215497697, 86.902724811009, 86.01144463675362, 79.64401122501918, 83.79867267608643, 84.3921947479248, 78.21844237191337, 76.67363548278809, 80.13098961966378, 81.49642181396484, 81.34439522879464, 67.44624710083008, 38.87330205099923, 18.81007637296404, 5.823502804551806, 2.7172917340482985, 1.6961560249328613, 2.773892628295081, 10.615512524332319, 7.465915816170829, 12.470639858927045, 39.39486510413033, 76.12336594717843, 78.76817689623151, 85.01501042502267, 96.62833377293178, 99.81787654331752, 99.56327370234898, 100.08668150220598, 102.62713050842285, 100.25976807730538, 96.67390700748989, 94.908675466265, 96.90766525268555, 91.84335953848702, 90.60519749777657, 89.03835092272077, 87.63166727338518, 93.16216237204415, 86.97028909410749, 78.10645825522286, 72.37626498086112, 68.86539581843785, 68.30587823050362, 62.27618980407715, 57.51122290747506, 50.846670627593994, 43.07478741237095, 34.15840039934431, 31.35324934550694, 21.705421992710658, 15.258405651365008, 9.241769415991646, 7.857205356870379, 4.785022871834891, 2.1981648930481503, 1.5304236837795802, 0.4592875433819634, 0.1607194465718099, 0.4004334243280547, 0.5326516181230545, 0.379812337990318, 0.3308057433792523, 0.6949203908443451, 4.723602099078042, 57.9241578238351, 104.1416015625, 86.38406263078961, 71.46825354439872, 94.21559265681675, 152.01560701642717, 91.9856378010341, 41.03847885131836, 45.34690741130284, 63.787923267909456, 78.05488177708217, 86.79368673052106, 80.29309804098946, 17.18515154293605, 0.16564936989120074, 0.21619455622775213, 0.15278798288532666, 0.18279320853097097, 0.07497884559312037, 0.12183204825435366, 0.18559069984725543, 0.2473204503101962, 0.1534765466515507, 0.1038160410576633, 0.18987220153212547, 0.17446978230561527, 0.16727515336658272, 0.17419568129948207, 0.18788232973643712, 0.286846255085298, 0.18986589115645203, 0.174691215423601, 0.2401064016989299, 0.24606608333332197, 0.296941091971738, 0.1107039111001151, 0.2146732128624405, 0.16238316015473434, 0.2997619520340647, 0.16647545913500444, 0.08879720446254526, 0.26937137278062956, 0.19763496784227236, 0.17563003647540296], [0.02828180098107883, 0.006638652611789959, 0.08194627386650868, 0.04425157726343189, 0.004526332386636308, 0.01621254423766264, 0.08257788140326738, 0.0529516175655382, 0.024060264828481844, 0.041113447797085555, 0.03167482891253062, 0.033499070310166905, 0.20835104425038609, 0.30791484883853365, 0.2618133883391108, 0.14925880011703285, 0.016574471423934613, 0.0407563823142222, 0.04348951458398785, 0.11182166862168483, 0.09616419486701488, 0.015796139171080928, 0.045184057405484576, 0.0839245223573276, 0.10960629928324904, 0.04809211600305779, 0.3595031334885529, 9.854881933757238, 73.27438913072858, 91.83033166612897, 74.62579986027309, 74.0354253223964, 34.835853236062185, 26.816822596958705, 44.011432375226704, 54.924095903124126, 56.82975401197161, 71.20967633383614, 91.61620208195278, 97.63589899880546, 36.05937194824219, 0.2987903984529631, 0.05362605083999889, 0.11783739046326705, 0.07426626847258636, 0.1305997520685196, 0.2592405735382012, 0.0867011487217886, 0.24414653490696633, 0.7882631963917187, 0.8237117656639644, 0.717571843947683, 1.1312806159257889, 5.8717124462127686, 11.38040930884225, 27.635978732790264, 50.308748040880474, 69.07657936641148, 79.93493230002267, 81.31635924748012, 88.5777062007359, 81.4086035319737, 67.78425611768449, 72.28768934522355, 77.7477366583688, 77.45555795942033, 76.07695892878941, 75.2174459184919, 69.9080286026001, 69.46893719264439, 61.56859915597098, 57.86158929552351, 53.42588363374983, 57.53903307233538, 62.90185424259731, 65.75861304146903, 64.79887921469552, 66.76209272657121, 66.80505343845913, 69.75672463008335, 63.612543787275044, 42.29869794845581, 19.789716788700648, 5.850128735814776, 6.692554822989872, 8.308940751211983, 16.986054386411393, 28.472368138177053, 66.5298352922712, 70.34972558702741, 70.75759179251534, 84.41217776707241, 105.38959530421666, 106.18867983136857, 96.30334568023682, 90.35723713466099, 82.75864546639579, 78.41210256304059, 77.14363248007638, 77.20142064775739, 73.76736382075718, 75.93845353807721, 75.90916688101632, 76.31694275992257, 74.67607702527727, 70.7138945715768, 70.53828580038888, 69.25497436523438, 67.27710015433175, 60.513119152614046, 55.83371932165963, 53.049009868076865, 45.9874062538147, 45.83922897066389, 38.75068719046456, 30.66858775275094, 15.560878106525966, 9.566885181835719, 11.75982437814985, 13.977420994213649, 10.06389330114637, 3.867623116288866, 1.8816648934568678, 0.5499228313565254, 0.14830279855855874, 0.27087451783674105, 0.3535013555416039, 0.4013366901448795, 0.11778825095721654, 0.09226928850901978, 0.223006382850664, 0.12051722380731787, 0.3619622529617378, 21.466268471309117, 85.92880276271275, 88.58776024409703, 66.70982837677002, 51.52965770448957, 53.88108096803938, 71.44015502929688, 27.65451305253165, 34.114793504987446, 42.8455559185573, 54.78977680206299, 55.44040959221976, 66.5720386505127, 33.540580477033345, 1.3348570806639535, 0.06061691232025623, 0.09410568246884005, 0.12541460458721432, 0.08586138021200895, 0.015086009865626693, 0.12072606331535748, 0.016865634193111743, 0.038703016604163816, 0.03298070687534554, 0.09194904033626829, 0.03911750989833048, 0.022040188046438352, 0.0691861446414675, 0.09001630797450032, 0.20073139454637254, 0.02669335389509797, 0.02945309830829501, 0.010251466517469712, 0.174448340599026, 0.13567003714186804, 0.22913886021290505, 0.18015693713511738, 0.08254396822303534, 0.06092429546905415, 0.10177311460886683, 0.11092180905065366, 0.0688602307013103, 0.06003994042319911, 0.014629640782784139, 0.020685638766735792, 0.08389221730508975, 0.0809444101261241, 0.05957751202264002, 0.019206037179433873, 0.0671521612842168, 0.04506413991163884, 0.017540232012314454, 0.030198747225637947, 0.030940799907382046, 0.04963028703683189, 0.09320747173790421, 0.21135300530919007, 0.2798212734716279, 0.16927072485642775, 0.027803019886570315, 0.039008995185473135, 0.0434401409833559, 0.01737153802865318, 0.06863615129675184, 0.021762472144993286, 0.009552115740786706, 0.12261325919202395, 0.10061402751931123, 0.04147951404697128, 0.26517414514507565, 19.47749079976763, 92.83406148638043, 99.3375267301287, 87.88638128553117, 95.49719483511788, 55.770424706595286, 35.67047432490757, 13.406906144959585, 23.007549149649485, 52.349361010960166, 79.87237071990967, 100.29748289925712, 104.3705724988665, 31.568421159471782, 0.19545735897762434, 0.07922667158501488, 0.21907480167491095, 0.10372451346899782, 0.1781017088464328, 0.3921109751931259, 0.9261668622493744, 0.9693270091499601, 1.1102674177714755, 0.7371619641780853, 1.4006797543593814, 2.8570595255919864, 8.890260917799813, 17.85202748434884, 38.51146766117641, 61.03945909227644, 78.62008299146379, 84.03478636060441, 82.87481934683663, 86.67925684792655, 79.05400494166783, 78.3491518838065, 81.34775120871407, 81.8740564073835, 80.74835096086774, 78.47779083251953, 76.40355900355748, 73.33006504603794, 73.9075437273298, 68.28779206957135, 65.85066972460065, 62.62230042048863, 68.05109473637172, 71.87406308310372, 73.32715375082833, 72.76078523908342, 74.00832734789167, 72.820143699646, 77.47061470576695, 73.31054060799735, 51.25850078037807, 28.064039877482823, 13.678878613880702, 8.708681906972613, 12.979356561388288, 22.66575857571193, 35.90332930428641, 75.25937829698834, 78.99365983690534, 82.0126451764788, 92.14318125588554, 107.10982336316789, 105.36816011156354, 96.82556533813477, 91.68640668051583, 86.54106412615094, 83.12368297576904, 80.71795954023088, 81.09897790636334, 79.09049688066754, 78.33295563289097, 79.46367073059082, 80.11637060982841, 79.28668621608189, 74.73349693843296, 73.72190175737653, 76.21506132398332, 76.0374653679984, 72.4745125089373, 69.02279336111886, 66.7211330958775, 59.882577078683035, 60.19047955104283, 52.59537935256958, 48.43999181474958, 35.39498519897461, 25.950489929744176, 23.05183870451791, 22.46554102216448, 18.93770956993103, 7.404110721179417, 3.1015659826142445, 1.2455767456974303, 0.3551769299166543, 0.19199209420808724, 0.7688651287129947, 0.2640023965920721, 0.2147316482982465, 0.19237879131521496, 0.12082712432103497, 0.16644493862986565, 0.5045336154954774, 14.298624055726187, 84.63162967136928, 94.11257866450718, 69.44051211220878, 56.53115865162441, 62.04789979117257, 29.495575496128627, 27.075684683663503, 52.477593490055625, 64.17058835710797, 76.28288269042969, 65.18967369624546, 79.81128215789795, 51.01639427457537, 3.515228722776685, 0.03799477532239897, 0.09415476769208908, 0.08129167077796799, 0.01912856035466705, 0.02229515606138323, 0.16643257572182588, 0.0849255718556898, 0.07183470430650882, 0.045665060702179155, 0.1107106828796012, 0.050730568888996325, 0.07006921047078711, 0.057895260863006115, 0.09245160408318043, 0.1479249359773738, 0.052208472442414076, 0.07713896182498761, 0.05046732783583658, 0.08997150430721895, 0.14519919295396122, 0.23206595171775135, 0.1694079517785992, 0.1425256971269846, 0.061104392233703814, 0.04848811582529119, 0.020204230045367564, 0.0734473784853305, 0.08247499513838973, 0.12011243695659296, 0.08462302666157484, 0.23679881489702634, 0.17682021403951304, 0.11592503450810909, 0.12493614240416459, 0.16572542009609087, 0.14353950986904757, 0.09855841246566602, 0.11510460424636092, 0.05707985854574612, 0.21645803137549333, 0.409066805349929, 0.6423794158867427, 0.39212031183498247, 0.19874601465250763, 0.09980723581143788, 0.10486872707094465, 0.18397134888385022, 0.22424579491572721, 0.22852926435215132, 0.16407932128225053, 0.10592920266624008, 0.25947645945208414, 0.15915363202137606, 0.27866627116288456, 0.4186450056731701, 22.28570600918361, 109.24695028577531, 110.94570841108049, 93.09231907980782, 94.89020715441022, 40.31331620897566, 32.28645495006016, 55.29616151537214, 72.75040463038853, 76.43554850987026, 93.81708567483085, 107.01391737801688, 113.80437796456474, 47.43936783926827, 1.1248028320925576, 0.23868012108973094, 0.30968943504350527, 0.5030812248587608, 0.21533406525850296, 0.4524901695549488, 0.3907464141292231, 1.0595933369227817, 3.7216605714389255, 3.8685090116092136, 2.387972959450313, 2.4344546709741866, 7.382613863263812, 14.413283228874207, 34.154314858572825, 57.71414852142334, 78.62132671901158, 91.95644841875348, 90.24280030386788, 92.2213693346296, 90.08534717559814, 89.48869146619523, 84.81147684369768, 87.46980898720878, 87.51380498068673, 88.62804589952741, 86.78684275490897, 86.0574278150286, 84.96119662693569, 78.65790898459298, 75.6265697479248, 69.62943363189697, 72.62663636888776, 76.07818875994, 76.56577859606061, 77.50971221923828, 79.8141587121146, 82.26232174464634, 83.02327455793107, 78.11052295139858, 52.40227154323033, 25.4934686933245, 12.908768943377904, 8.111155067171369, 15.522939205169678, 25.471826791763306, 35.18736260277884, 76.48164285932268, 81.76850632258824, 80.5427885055542, 90.84308992113385, 106.10152857644218, 106.48051112038749, 98.19595159803117, 94.634443964277, 89.54177570343018, 84.8555075781686, 84.27010100228446, 84.16623932974679, 81.96892016274589, 82.32175663539341, 83.0366359438215, 85.76648589542934, 87.49995027269635, 84.94368021828788, 86.30511025020054, 88.44405760083879, 87.34494291033063, 79.74197387695312, 73.45696694510323, 71.89223262241909, 66.67993027823312, 63.9844183240618, 56.7014068875994, 51.87497970036098, 42.566776820591514, 33.4177919115339, 31.218350069863455, 28.061149426868983, 20.183493784495763, 6.623792844159262, 4.674468781266894, 3.87669746364866, 1.4761576013905662, 0.6536459741847855, 0.6584408826061657, 0.4197937383183411, 0.41354434937238693, 0.23557701760104724, 0.610457600227424, 0.4172489605844021, 0.9417756646871567, 28.681062494005474, 100.50527572631836, 102.4784460067749, 78.93535055433, 59.44958618709019, 82.79232338496617, 95.99381732940674, 34.617356709071565, 40.9621250970023, 57.87336649213518, 72.62876946585519, 72.62721306937081, 94.18426322937012, 57.30515323366438, 5.0524212547710965, 0.16489994153380394, 0.24658014146345003, 0.2865321476544653, 0.20789588295987674, 0.13913792105657713, 0.2557417484266417, 0.17645263804921082, 0.20284670032560825, 0.09614396773810897, 0.1487843141491924, 0.1025796891855342, 0.2890490511698382, 0.16501656813280924, 0.15619314302291187, 0.30129869814429966, 0.09517048033220427, 0.10887633131018706, 0.08493895256625754, 0.19317054668707506, 0.22646719643047877, 0.307865777185985, 0.2696385255881718, 0.23500357408608707, 0.1686178927442857, 0.18063999978559359, 0.1989378093608788, 0.20942034758627415, 0.1312963632600648], [0.05342983886865633, 0.13490249189947331, 0.10230799697871719, 0.1611419567572219, 0.14760488457977772, 0.017102576925286224, 0.03225523419678211, 0.1149453656481845, 0.06195733789354563, 0.09732663391956262, 0.19237248093954154, 0.21333507395216397, 0.27842549979686737, 0.2510565998298781, 0.22213472319500788, 0.1698320090238537, 0.024392241479030678, 0.0741615230217576, 0.012171527237764426, 0.10057575135890927, 0.24096770691020147, 0.08772060687520675, 0.0886443644495947, 0.18014012303735527, 0.10533083656004497, 0.3827541944171701, 11.564577392169408, 81.54734516143799, 95.37498991830009, 73.64515195574079, 72.13813631875175, 48.28032568522862, 31.673387595585414, 52.03880780083792, 94.17849622453961, 66.54153605869838, 68.35957390921456, 93.62911605834961, 106.04691573551723, 38.91001980645316, 0.3643003760703972, 0.04201495960088713, 0.13271853194705077, 0.03966547442334039, 0.003082903501178537, 0.05502462347171136, 0.19855283573269844, 0.44284433286104885, 1.8136096767016818, 1.2088541047913688, 1.751378895980971, 8.541863475527082, 20.349897929600306, 36.03895814078194, 64.14734663282121, 82.16239275251115, 91.20101942334855, 89.39915697915214, 81.52401311056954, 87.15716784340995, 88.5802492414202, 76.46339688982282, 78.50576428004673, 80.1358255658831, 76.00262710026333, 75.45408766610282, 73.00220039912632, 69.54868166787284, 64.33309282575334, 60.377802985055105, 51.798507826668875, 48.646808419908794, 48.01673187528338, 50.903447832380024, 56.37003687449864, 63.564566476004465, 70.3957712990897, 72.24224812643868, 69.72158758980888, 61.98565782819475, 58.5860710144043, 57.19918973105294, 61.031204632350374, 48.873719215393066, 27.945630414145334, 29.14485822405134, 46.15423250198364, 68.6383147920881, 70.28636496407645, 63.16595527103969, 92.08208574567522, 114.07687936510358, 103.05691828046525, 87.96395097460065, 74.47588552747453, 74.5429356438773, 77.41728728158134, 75.21315887996128, 76.36216858455113, 75.56721128736223, 76.29748085566929, 77.55881513868059, 76.26976449148995, 73.87367820739746, 74.73842321123395, 72.16324016026088, 66.51894051688058, 58.564434323992046, 56.44690826960972, 55.28077820369175, 58.84597533089774, 54.7911490712847, 59.84339618682861, 57.74963991982596, 44.367749895368306, 41.35965238298689, 39.70280231748308, 33.25593362535749, 24.458155836377824, 15.29371292250497, 15.323597124644689, 13.57738367148808, 8.449854561260768, 4.179708404200418, 2.4975914316517964, 1.0082920725856508, 0.09815409380410399, 0.12137187937540667, 0.12636786486421311, 0.06990384470139231, 0.03656007070094347, 0.1989282148757151, 0.05924674655709948, 0.2831742406955787, 4.383646718093327, 50.488313811165945, 79.15454537527901, 64.1922528403146, 35.629632813589915, 62.12462180001395, 74.06055000850132, 25.6121369770595, 29.790731498173304, 36.55424002238682, 46.33036586216518, 56.65446833201817, 67.78725773947579, 56.89227042879377, 6.5475272451128275, 0.24402296010937008, 0.14601001515984535, 0.1482038138700383, 0.20191136694380216, 0.179368737286755, 0.16117259939866407, 0.052811530618263144, 0.1544997367475714, 0.1184279059192964, 0.343125333743436, 0.11157248342143637, 0.09313336892851762, 0.16458797827363014, 0.13875902710216387, 0.01670744902055178, 0.2686289740460259, 0.37102636801345007, 0.5113752569471086, 0.7957504774842943, 0.353956435407911, 0.03371152301718082, 0.08642130730939762, 0.1403381952217647, 0.05413652291255338, 0.06333062491778817, 0.05232607613184622, 0.071655984967947, 0.07674395266388144, 0.07181461966995682, 0.08277595256056104, 0.12320856510528497, 0.09902343965534653, 0.0503743922870074, 0.011447662687195199, 0.11361063298370157, 0.09005705400237016, 0.10480736036385808, 0.05597929510154894, 0.15281706489622593, 0.15839182718523911, 0.11425764326538358, 0.05932486629379647, 0.125905361824802, 0.10079689949218716, 0.03452934770445738, 0.025251205744487897, 0.07454896651740585, 0.12141381283955914, 0.03724820699010577, 0.011692267776067768, 0.20343512589378016, 0.15856542358441011, 0.09558918393616166, 23.516285828181676, 104.90077563694545, 102.93493570600236, 93.4170709337507, 91.10117380959647, 70.34005369458879, 29.271527358463832, 13.540950792176382, 50.33369207382202, 59.62258243560791, 77.50980949401855, 100.30612645830426, 112.94833210536412, 34.52272571836199, 0.40609053362693104, 0.009025519131682813, 0.0650192882333483, 0.14365684214447225, 0.050701931318534274, 0.16442764044872352, 1.1190858760050364, 2.7094009688922336, 2.4453398925917487, 0.6697527127606528, 3.0670937980924333, 12.127439669200353, 25.80733445712498, 44.97699226651873, 71.49881867000035, 88.22887189047677, 91.96437631334577, 91.455233165196, 85.80794579642159, 89.95668043409074, 88.22425828661237, 85.31271989004952, 88.5485863004412, 85.5823586327689, 81.41283498491559, 82.11852877480644, 79.10178770337785, 74.40957192012242, 72.0005828312465, 66.43559687478202, 59.22305406842913, 59.16598156520298, 58.89071478162493, 61.92593806130545, 63.83163438524519, 70.59596974509103, 77.59504304613385, 77.65590231759208, 78.0734612601144, 72.40514864240373, 64.19965962001255, 67.08396802629743, 74.65125111171177, 60.77584443773542, 40.86580916813442, 39.079524585178916, 57.13498142787388, 73.24228845323834, 70.57149818965367, 71.90299538203648, 97.74403381347656, 111.52017852238247, 100.92589882441929, 89.33153711046491, 77.81639180864606, 77.30024487631661, 79.96462195260185, 79.070937701634, 81.44394901820591, 80.25807217189244, 79.9433674131121, 77.51247760227749, 79.86565181187221, 77.90655858176095, 76.34524277278355, 75.56905950818742, 71.10947636195591, 65.01614938463483, 62.54780878339495, 62.50108214787075, 66.1030352456229, 60.9095903124128, 66.57763195037842, 70.39114379882812, 60.50640024457659, 56.74883181708199, 53.93952921458653, 49.38355023520333, 42.61854437419346, 32.25670623779297, 29.280723299298966, 28.212491614477976, 16.527751207351685, 7.231827965804508, 2.5802335228238786, 0.9761967148099626, 0.09006950511996235, 0.11762646106737, 0.3665766982095582, 0.025712480635515282, 0.09430088342300483, 0.09519294662667172, 0.07282354695988552, 0.3315322372530188, 1.2375673183373042, 45.08057253701346, 87.64365291595459, 67.85393265315464, 31.082700388772146, 59.18037823268345, 27.896329471043178, 26.095915726252965, 52.869746344430105, 62.15162944793701, 72.22687871115548, 73.69710363660539, 79.12898295266288, 77.20260184151786, 11.913064292498998, 0.33323422021099497, 0.2252317470099245, 0.03581047610246709, 0.23254958433764322, 0.05415933865255543, 0.2080777303448745, 0.03471656908680286, 0.2049160014305796, 0.13825395277568273, 0.3954388366213867, 0.08351122667746884, 0.06693910128836121, 0.11992871681494371, 0.0755102267222745, 0.0506778195766466, 0.23517760474767002, 0.22795810071485384, 0.2118279119687421, 0.44441142305731773, 0.2235903436584132, 0.07688858918845654, 0.045382786741746325, 0.07874620772366013, 0.10270913331104176, 0.1011461346809353, 0.11469584118042674, 0.04897639641006078, 0.15621746171798023, 0.19713708598698887, 0.19323284977248736, 0.1880321909806558, 0.2007136440702847, 0.10467968042939901, 0.17367075303835527, 0.4855635134237153, 0.30964210044060436, 0.22478041265692028, 0.21532357510711464, 0.41260547403778347, 0.36470660141536165, 0.626619815826416, 0.3499933566365923, 0.41973324013607843, 0.2284012655062335, 0.1728779934346676, 0.18277932570448943, 0.33522881461041315, 0.36585234850645065, 0.27866266135658535, 0.22196385450661182, 0.20817710858370575, 0.20999206762228692, 0.4402934754533427, 27.163515125002178, 120.2331987108503, 114.29844352177211, 91.82253578730992, 88.93450314658028, 55.511263847351074, 41.2176068850926, 65.07224914005825, 118.64307567051479, 94.34066717965263, 88.72903796604702, 110.02566964285714, 122.55578695024762, 52.182788372039795, 0.549394279718399, 0.18093179698501313, 0.24301384282963617, 0.2516693169517176, 0.17251727064805372, 0.2073662049536194, 0.30047881071056637, 1.9901130284581865, 5.98666604927608, 3.692019121987479, 3.9933872478348866, 11.91651667867388, 24.358122621263774, 43.35742276055472, 72.38907745906285, 93.87401226588658, 100.46679660252163, 99.04604285103935, 92.3233619417463, 95.88871887751988, 99.16464165278843, 97.52942480359758, 88.81527205875942, 90.59109960283551, 88.70510837009975, 90.39426408495221, 88.13383443014962, 85.06480121612549, 80.49808379581997, 76.6700849533081, 72.7610353742327, 69.2748670578003, 66.16955729893276, 71.06877381461007, 72.7202980858939, 76.29951667785645, 81.76197501591274, 88.32213756016323, 81.25290829794747, 80.12299919128418, 75.06990092141288, 72.28515325273786, 76.00790773119245, 60.84135205405099, 40.84766742161342, 38.52041694096157, 60.030594553266255, 76.8291014262608, 81.35313606262207, 72.2628425870623, 92.31523949759347, 102.67762306758335, 98.64708423614502, 90.52787794385637, 82.68297958374023, 82.09136131831578, 83.25302369253976, 79.39416095188686, 80.97045707702637, 80.7732880456107, 81.71021788460868, 83.35434232439313, 84.0401920591082, 83.14491667066301, 84.34917150224958, 80.9481394631522, 77.00049264090401, 74.43518992832729, 70.69396713801792, 72.72492558615548, 75.52914905548096, 70.13934108189174, 76.39806297847203, 75.76328250340053, 66.25848729269845, 63.22045694078718, 59.77085699353899, 54.660561152866904, 49.26449980054583, 38.64370925085885, 38.012232644217356, 34.552759306771414, 18.728765078953334, 7.936691011701312, 5.0136346731867105, 2.5195551216602325, 0.19449187149958952, 0.16295264102518559, 0.5049413336174828, 0.43433189392089844, 0.25179232177989824, 0.7288286856242588, 0.1400741229632071, 0.48497552211795536, 7.809411304337638, 63.63706398010254, 94.84862913404191, 84.21213912963867, 46.73429938725063, 87.99493299211774, 94.63347816467285, 33.971816948481965, 38.39224352155413, 49.00649929046631, 65.20115212031773, 74.76848806653703, 88.84473936898368, 93.43800585610526, 14.556287578174047, 0.48125454464129036, 0.43075913563370705, 0.21564020668821676, 0.28886362111994196, 0.2010974913303341, 0.3320408671029976, 0.2115920531962599, 0.21499585626380785, 0.21499409207275935, 0.4205979923052447, 0.2128583216773612, 0.12706495103027138, 0.3363742088632924, 0.18319635332695075, 0.17162087160561765, 0.23370445093938283, 0.369848159807069, 0.6540286136525018, 1.0273498956646239, 0.6267728390438216, 0.1720639956848962, 0.16843453901154654, 0.28810881876519745, 0.12200807380889143, 0.3648379386535713, 0.151741071205054, 0.21133910891200813], [0.06468388837363039, 0.1603960432112217, 0.17778905348054, 0.0111327757892598, 0.07656608149409294, 0.03528000081756285, 0.17670585374747003, 0.054372439360512156, 0.056034768731998544, 0.018472001388935105, 0.10575967747718096, 0.06365306475864989, 0.044428359384515455, 0.23109040835074016, 0.04777852765151432, 0.12921849904315813, 0.041642579582652876, 0.03637631663254329, 0.11985401010939054, 0.06935754937252828, 0.09066472960902111, 0.1285467900867973, 0.0663462584572179, 0.3734388585601534, 2.2207083233765195, 30.759953090122767, 85.9200688770839, 79.33392007010323, 69.41194111960274, 57.85963337762015, 38.84567601340157, 28.185760157448904, 55.59554549625942, 114.5539357321603, 64.4404216493879, 55.073329312460764, 106.29116576058524, 94.5319858278547, 24.87081629889352, 0.2723931334912777, 0.061626938836915154, 0.07735932285764388, 0.2180185126406806, 0.0325720727310649, 0.2261092827788421, 0.1315656059554645, 0.9652586217437471, 11.458732877458845, 4.001673408917018, 1.4091358206101825, 8.840953026499067, 26.00062813077654, 52.75802625928606, 78.63989925384521, 90.15064634595598, 88.33079501560756, 86.17099612099784, 83.82832063947404, 79.78729002816337, 79.0872242791312, 72.48742921011788, 79.61050701141357, 79.77986240386963, 72.52690887451172, 72.60930756160191, 68.95587526048932, 69.95645059858049, 69.42921434129987, 69.50654084341866, 61.3791287285941, 60.661574363708496, 55.81516763142177, 50.7433682850429, 52.10875531605312, 51.17837415422712, 58.89801039014544, 72.0032856804984, 65.59297493525914, 60.75655623844692, 59.86815956660679, 57.44529839924404, 61.046462876456125, 63.87872927529471, 66.86770534515381, 58.07108790533883, 66.86526652744838, 71.35640144348145, 74.6263209751674, 54.64969069617135, 59.435321535382954, 85.83649594443185, 79.88796247754777, 66.3817274911063, 62.48039736066546, 63.852930613926475, 69.11551012311662, 62.32620293753487, 62.98959609440395, 63.74380915505545, 66.28800324031285, 62.453521728515625, 58.20382629122053, 63.486461775643484, 62.943911688668386, 60.75605596814837, 58.34414168766567, 60.446979250226704, 51.86491176060268, 51.905305113111226, 47.058547496795654, 48.077090876443044, 54.46704339981079, 55.91249104908535, 53.14878599984305, 49.695152623312815, 49.64932230540684, 47.501286711011616, 44.877438477107454, 46.256381443568635, 43.721522263118196, 32.38871506282261, 19.99610607964652, 16.892453466142925, 12.430358546120779, 5.064049933637891, 1.6644004774945123, 1.3336835950613022, 0.16754939007971967, 0.7372639615620885, 0.043237957903849225, 0.0671212947262185, 0.09903287807745592, 0.04157347418367863, 0.022157898605135933, 0.4563854762486049, 0.5205426993114608, 24.481256859643118, 92.12996578216553, 113.47510283333915, 50.91064964021955, 67.6482937676566, 63.94962174551827, 22.24053577014378, 22.80819664682661, 22.96064359801156, 44.80847760609218, 55.84657001495361, 72.02523503984723, 53.65035561152867, 5.438031077384949, 0.1871540445302214, 0.14560939451413496, 0.060287795694811006, 0.09804922621697187, 0.009320844713199352, 0.08275555579790048, 0.15955426623778685, 0.03504539054951497, 0.12432027687983853, 0.07719897824738707, 0.08341172630233423, 0.04707355012318917, 0.05812896867947919, 0.12202040957553045, 0.36006631755403107, 0.16681981565696852, 0.21109978961093084, 0.31519080698490143, 0.07710058388433286, 0.0800422638920801, 0.11974430456757545, 0.059484003111720085, 0.10360365281147615, 0.041814177696193965, 0.12733470941228525, 0.05623219867369958, 0.05663312466016837, 0.1894029402839286, 0.08659459836781025, 0.02733395541352885, 0.05024743838501828, 0.16174521510090145, 0.08850751750703369, 0.10059610062411853, 0.031081673955278735, 0.018538209443379725, 0.06465108120547873, 0.011746562451922467, 0.014615751170952405, 0.08615186783884253, 0.09378187198724065, 0.06585451055850301, 0.061876381880470684, 0.05538239123831902, 0.07435422018170357, 0.07070051266678742, 0.038839052697377544, 0.05883712175169161, 0.08265241847506591, 0.30432064884475296, 7.6534042698996405, 50.26296983446394, 104.5974450792585, 93.54151317051479, 94.98123550415039, 87.17234270913261, 63.700438499450684, 28.616445984159196, 17.75509316580636, 94.3061832700457, 67.05898925236293, 62.90409851074219, 113.12209265572685, 99.15343420846122, 21.633860758372716, 0.5805632472038269, 0.0559164118686957, 0.12631183144237312, 0.23837233760527202, 0.23695571933473858, 0.532541098339217, 0.2928682533758027, 0.932755382997649, 6.669417755944388, 1.6489689626864024, 2.4146872631141116, 11.043438179152352, 29.49262945992606, 63.25354426247733, 87.27145876203264, 92.74042756216866, 91.14980425153459, 88.41743905203683, 84.52621160234723, 86.28220203944615, 82.34542914799282, 82.30955559866769, 83.78843103136334, 82.66943754468645, 78.61728286743164, 76.64942795889718, 74.9239192690168, 76.20471545628139, 76.90314143044608, 78.01845237186977, 72.41451481410435, 70.77041121891567, 67.68991347721645, 59.25375815800258, 61.23802471160889, 61.76847103663853, 68.52042470659528, 77.80577496119908, 74.03379249572754, 67.41197163718087, 67.52461583273751, 66.40055016108921, 74.58562537602016, 72.83545058114188, 77.1837374823434, 66.87798173086983, 71.33180482046944, 75.87200791495187, 77.5762551171439, 59.04156017303467, 62.331351552690776, 82.61950084141323, 78.34435762677873, 66.44257286616734, 63.58254146575928, 65.47355624607631, 71.52811227525983, 66.12406049455915, 67.70535932268415, 67.86095033373151, 68.37966809953961, 64.05298314775739, 61.87101255144392, 66.82901777539934, 67.14864185878209, 65.06250081743512, 64.95265674591064, 65.66887705666679, 58.89195156097412, 60.79272856031145, 53.46586356844221, 57.28150156566075, 62.05048452104841, 61.89727674211775, 61.23118768419538, 60.26950141361782, 63.97196020398821, 62.53723362513951, 59.7569397517613, 60.27664416176932, 60.76655469621931, 51.39585624422346, 40.7668251310076, 32.97865533828735, 25.321957622255596, 12.325897591454641, 3.5129160583019257, 0.8751370662025043, 0.29847295262983864, 0.3096368892916611, 0.2948903148727757, 0.1476848160049745, 0.1611930640148265, 0.17640744761696883, 0.09159930981695652, 0.4993198609777859, 0.631506299333913, 20.231966154915945, 96.03322056361607, 104.54583386012486, 49.84320831298828, 56.669299261910574, 25.721419981547765, 20.92241907119751, 34.544973850250244, 40.623574120657786, 70.07546629224504, 72.18534932817731, 76.8171157836914, 68.85214560372489, 11.383617639541626, 0.16198533507330076, 0.07910323927977256, 0.0341171750000545, 0.18559938509549412, 0.0397284730071468, 0.08556939980813436, 0.07020581314074141, 0.015372202365792223, 0.024161680368706584, 0.049102169661117454, 0.01687169011815318, 0.05474700765418155, 0.10798786434211902, 0.11152721835034234, 0.23593577263610704, 0.06423788730587278, 0.11680774071386882, 0.06624003380004849, 0.02746239530720881, 0.005298599808676434, 0.1062746923416853, 0.042392394705010314, 0.10955917502620391, 0.03599198761263064, 0.0266071646806917, 0.043929710784660916, 0.18879270660025732, 0.3687392164553915, 0.30434958157794817, 0.18645713478326797, 0.18664720601269177, 0.25551427634699003, 0.2865615417914731, 0.15028786632631505, 0.2288931491119521, 0.11954003838556153, 0.23796008686934197, 0.1364190855196544, 0.15198903504226888, 0.44956562934177263, 0.44968559433306965, 0.2518040197236197, 0.1392319660101618, 0.2540828931544508, 0.3250917185630117, 0.31793409692389624, 0.13913280490253652, 0.29803985729813576, 0.12143412817801748, 0.5483006441167423, 8.764267495700292, 59.141947746276855, 122.98592213221959, 98.99142306191581, 89.03401524680001, 74.0074588230678, 47.23170355388096, 36.68653719765799, 73.50277641841343, 136.73240498134066, 83.33267089298793, 73.59579890114921, 125.00790350777763, 114.84826837267194, 36.038471766880576, 0.9631427867071969, 0.19236258789896965, 0.3143582987998213, 0.5335544496774673, 0.23568821591990335, 0.46787133706467493, 0.41616037328328404, 2.7933078493390764, 18.161583627973283, 7.230218589305878, 3.266053076301302, 11.039252758026123, 31.032697677612305, 69.87970774514335, 95.46512195042202, 100.78297437940324, 99.1522113255092, 93.23119272504533, 92.75554684230259, 89.76691123417446, 91.11841229030064, 90.54836123330253, 86.36768572671073, 87.53338500431606, 83.49389689309257, 82.55128342764718, 79.74825504847935, 81.9532241821289, 82.37657792227608, 84.81317915235246, 81.0525986807687, 79.56715720040458, 76.04307951245988, 65.63506712232316, 70.86833218165806, 69.46831880296979, 75.76417882101876, 86.13230160304478, 78.4467671258109, 73.48464162009103, 72.25560256413051, 70.97741195133754, 81.83511870247978, 77.67619105747768, 79.0255103792463, 71.84634671892438, 75.53645856039864, 82.09346662248883, 83.91739654541016, 66.7887043271746, 65.3206958770752, 84.12133312225342, 82.15568079267229, 74.17932946341378, 74.5244117464338, 73.6928791318621, 80.3095235824585, 72.2067289352417, 73.42840984889439, 71.08436557224819, 77.4262226649693, 71.69815553937639, 68.49762071881975, 73.93840067727226, 73.55624975476945, 71.47058119092668, 72.7677195412772, 75.62908499581474, 65.47531414031982, 70.39973177228654, 65.47714151654924, 65.04896572657994, 72.75018923623222, 72.6535120010376, 71.80803435189384, 68.19513089316231, 69.73894418988908, 69.56553104945591, 65.94378253391811, 68.0670964377267, 67.82126222337995, 57.24624293191092, 45.841858863830566, 40.014727796827046, 32.27915934153965, 12.586970942361013, 3.2482372437204634, 4.294444007532937, 1.1436424383095332, 1.9356269921575273, 0.24655476425375256, 0.25369737669825554, 0.4027952147381646, 0.23834842603121484, 0.23098292840378626, 0.7629844014133725, 0.9973525681665966, 34.99694374629429, 104.03004128592355, 132.9236387525286, 61.49056393759591, 96.00788048335484, 82.4279042652675, 28.979638746806554, 29.416824613298687, 29.667303698403494, 59.95502594539097, 73.30697618212018, 86.74611241476876, 81.57433891296387, 14.978169168744769, 0.3314258972448962, 0.1958487651177815, 0.2417237577693803, 0.3613127592418875, 0.09086742158979177, 0.16672666636960848, 0.14332273150128977, 0.09656817426106759, 0.21172325472746575, 0.13305835585509027, 0.21706575447959559, 0.16646658389696053, 0.26200875214168, 0.1855308259172099, 0.3953918277152947, 0.24486879472221645, 0.5059759095311165, 0.48206259842429844, 0.24404404897774967, 0.18934731398309979, 0.18301350171012537, 0.12493661737867764, 0.26713372713753153, 0.1370066154216017, 0.16086542659572192, 0.1935424924428974], [0.06115846468933991, 0.10890786961785384, 0.04403678700327873, 0.20392934365996293, 0.011758332489989698, 0.03845243701445205, 0.029765173526746885, 0.06611829104700259, 0.04899428937850254, 0.08253642969897815, 0.062456990725227764, 0.15094638456191334, 0.09663355111011437, 0.05431740338514958, 0.08239641399788004, 0.08230397717228957, 0.07537762062358004, 0.06492762493767909, 0.046528886671044996, 0.10725058176155601, 0.03469039799113359, 0.029743504510926347, 1.138232288616044, 26.13906925065177, 71.62970188685826, 101.76095417567662, 81.59730270930699, 75.94087151118687, 50.8452809878758, 43.2977168900626, 27.183557203837804, 60.065870557512554, 82.50266688210624, 39.54197236469814, 76.87710653032575, 112.73437622615269, 84.89829458509172, 10.597689526421682, 0.3874053619801998, 0.08060211635061673, 0.06666490528732538, 0.056912212898688655, 0.07147308585367032, 0.06584718238030161, 0.14429556072822639, 0.35837204275386675, 3.803506442478725, 1.411878947700773, 0.5539318333779062, 6.547499886580876, 26.503722872052872, 57.247139249529155, 85.53789710998535, 90.14376068115234, 90.70021411350795, 83.69309479849679, 79.97578075953892, 76.26828452519008, 73.95374924795968, 65.62456839425224, 76.29945414406913, 74.40854358673096, 69.64328139168876, 75.354339327131, 75.03042820521763, 73.27793966020856, 74.9997171674456, 73.1960551398141, 67.26981844220842, 59.18463053022112, 57.347655364445274, 55.431866782052175, 59.37675516945975, 50.09062671661377, 52.010153429848806, 50.24640185492379, 51.34711115700858, 66.05980355398995, 61.60675866263253, 50.11982652119228, 59.23574842725481, 59.10270432063511, 58.34520476205008, 65.84005287715367, 69.19150951930455, 67.14484814235142, 72.72134726388114, 75.28328704833984, 65.09179442269462, 58.64023222242083, 44.32689448765346, 44.95550496237618, 48.33123166220528, 56.415818555014475, 58.60747146606445, 55.421541758946006, 53.01492895398821, 54.52321611131941, 55.25087315695626, 55.79913118907383, 61.23741327013288, 59.95948668888637, 59.860127449035645, 65.62201840536935, 64.65858813694545, 65.40612397875104, 52.792593547276084, 49.02804912839617, 48.60641854149954, 39.26217882973807, 48.69387204306466, 49.59254857472011, 53.00897434779576, 51.420077664511545, 49.30810669490269, 53.00045585632324, 52.40990761348179, 50.88404498781477, 47.81809677396502, 50.28441544941494, 50.983557088034495, 48.88957847867693, 31.00898347582136, 19.425454003470286, 12.016396164894104, 12.325308731624059, 2.662586829492024, 1.4645646406071526, 0.6139863623040063, 0.3373733109661511, 0.3244883380830288, 0.23631510085293225, 0.2043541744351387, 0.4399438127875328, 0.09024125590388264, 0.30549823279891697, 1.432058904852186, 10.447748269353594, 65.87997722625732, 93.99924659729004, 54.644809586661204, 58.3229774747576, 79.52723285130092, 42.10491616385323, 30.92084210259574, 34.36227791649954, 49.332036290849956, 60.61286054338728, 64.21718992505754, 55.761906215122764, 11.061345423970904, 0.1920877947871174, 0.0904754251241684, 0.02587620774284005, 0.03893844450690916, 0.044944388658872673, 0.0625644571014813, 0.0685802467965654, 0.034783248723085435, 0.08797647564538888, 0.07118301213319812, 0.012123715115844138, 0.029320210617567812, 0.04591036468212094, 0.015214948482545359, 0.09147709208939757, 0.04400946239807776, 0.05624711626608457, 0.11076924045171056, 0.06493026443890162, 0.10726090227918965, 0.0716535761686308, 0.07643072054322277, 0.06121790435697351, 0.07155765845839467, 0.17192561525319303, 0.07988635690084525, 0.1993347252053874, 0.09525334302868162, 0.047972249399338446, 0.013404432151998793, 0.0426964801736176, 0.04709370939859322, 0.01734014051700277, 0.11160727869719267, 0.1061716703698039, 0.09512709480311189, 0.1352781153150967, 0.058066563813814094, 0.06295565968113286, 0.07130195932196719, 0.08437082198049341, 0.0807737246421831, 0.08117164471851927, 0.058561290481260846, 0.11429584478693348, 0.04677572414012892, 0.03877523987154875, 3.1601495019027164, 43.12254932948521, 91.8160878590175, 116.17357472011021, 98.11290672847203, 105.6219013759068, 82.77491119929722, 58.73368549346924, 19.05936210496085, 24.936082465308054, 76.2957854952131, 51.335080351148335, 83.15456771850586, 116.49982043675014, 88.54688399178642, 8.192374297550746, 0.5503644219466618, 0.0714161160535046, 0.061996150096612315, 0.055574922157185416, 0.15299990294235094, 0.5890304957117353, 0.8699338968311037, 1.9746272308485848, 2.0463228694030215, 0.7513113192149571, 0.08750364530299391, 8.05906789643424, 32.68577139718192, 73.19827161516461, 93.6098278590611, 92.35884639195034, 94.46599183763776, 87.04432909829276, 84.37987559182304, 82.29910550798688, 78.65154443468366, 75.80685465676444, 81.82082625797817, 77.97374766213554, 76.21378980364118, 80.89168534960065, 82.96440247126988, 81.3415047781808, 80.98204667227608, 78.40340341840471, 74.18429742540631, 70.11842005593437, 65.9520161492484, 65.81898593902588, 71.23867116655622, 63.2737009865897, 61.45703887939453, 60.21373517172677, 59.4605712890625, 70.69613497597831, 68.69608906337193, 58.900511741638184, 67.29137870243618, 68.45541736057827, 68.08071490696499, 72.27164595467704, 76.68473870413644, 71.79524271828788, 75.01043128967285, 81.00935309273856, 73.84818526676723, 60.68158517565046, 49.206555298396516, 48.99321780885969, 52.62234878540039, 60.586575508117676, 63.78438663482666, 60.50775514330183, 59.413386072431294, 60.93406186785017, 63.33670725141253, 64.70014531271798, 70.18797847202846, 66.59615584782192, 68.11178725106376, 70.78614888872418, 68.60424777439663, 71.06070000784737, 62.777773312159944, 58.68684768676758, 61.04636560167585, 52.25790534700666, 58.10236522129604, 57.7533780506679, 61.22075148991176, 60.873723711286274, 60.435479981558665, 63.13807215009417, 62.80372483389718, 64.27205984933036, 59.2769581930978, 59.4272894178118, 59.85868222372872, 62.432684080941335, 51.544158594948904, 40.444581576756065, 29.597432613372803, 21.863736697605678, 7.364003113337925, 2.1726183210100447, 0.37403219672186033, 0.714436089353902, 0.7138143884284156, 0.3675923022840704, 0.21492507149066242, 0.5079228707722255, 0.21081652838204587, 0.3068683849913733, 1.2155625905309404, 8.337482213973999, 68.47594233921596, 92.97691644941057, 59.42055661337716, 49.46371507644653, 25.762200696127756, 21.840333427701676, 44.22105952671596, 49.69345031465803, 67.11947332109723, 80.92152786254883, 73.1091331754412, 72.02224036625454, 18.76489050047738, 0.028241696168801615, 0.04628668359613844, 0.01981121577721621, 0.0402810074655073, 0.07777635726545538, 0.03557593708059617, 0.023769529536366463, 0.022634596597137194, 0.038216805551201105, 0.0747789763180273, 0.024325280250715356, 0.019572481712592498, 0.018516721935676675, 0.039218777857188664, 0.052825281130416055, 0.018552964187360237, 0.07949195163590567, 0.11329816760761396, 0.016357816888817718, 0.07213524782231875, 0.15890091843903065, 0.08137996853994471, 0.04768733593768307, 0.05890415422618389, 0.09632105859262602, 0.29965379355209215, 0.3014057438288416, 0.13566019838409765, 0.3621235814477716, 0.10723409336060286, 0.09503632038831711, 0.14824535378387996, 0.11628122468079839, 0.270422097827707, 0.22656755175973686, 0.11968326355729784, 0.2637104094028473, 0.16889936264072145, 0.14464515554053442, 0.14048460950808866, 0.1560736530061279, 0.18402616094265664, 0.11603049242070743, 0.1523928583732673, 0.19557640116129602, 0.11411072686314583, 0.14421946981123515, 4.766824671200343, 51.65995379856655, 114.25412791115897, 133.41516821725028, 99.55559594290597, 101.87726702008928, 63.99897480010986, 53.02160964693342, 36.95940685272217, 71.71708938053676, 105.9125097819737, 58.3928416115897, 99.99460397447858, 128.58597564697266, 104.26669692993164, 15.145292452403478, 0.6074395850300789, 0.13026455576930726, 0.286275145730802, 0.2520821105156626, 0.27202420043093817, 0.31013675246919903, 0.6064489239028522, 1.610449018222945, 9.715153660093035, 4.740219584533146, 0.929269015789032, 7.565599884305682, 34.72330284118652, 83.19344983782086, 103.46916879926408, 98.84550394330705, 98.80692754473004, 95.11117376599992, 92.07232352665493, 86.7749891281128, 85.17264420645577, 81.84243515559605, 86.17460223606655, 83.35949788774762, 83.7877014705113, 85.02601637159074, 83.62802491869245, 81.24637004307338, 84.72490923745292, 82.1905746459961, 81.2722520828247, 74.84925392695835, 72.92001015799386, 71.04697036743164, 80.84589672088623, 71.3377663748605, 72.90787165505546, 68.57567678179059, 72.82458359854562, 79.87419809613908, 75.80707005092076, 64.7089625767299, 76.437438419887, 75.704347882952, 74.15563610621861, 76.07613209315709, 80.21147060394287, 81.88741779327393, 83.60902854374477, 89.35182585035051, 80.25136021205357, 62.54074246542794, 55.2825152533395, 56.599327428000315, 62.23157542092459, 67.10272816249302, 70.79432691846574, 67.35898467472622, 66.21117006029401, 65.48672308240617, 67.32277066367013, 67.44480882372174, 74.26917661939348, 69.38948454175676, 69.3102194922311, 76.26274681091309, 71.45083441053117, 71.46086760929653, 66.08984061649868, 62.86743981497628, 66.88156005314418, 58.250865595681326, 65.59529563358852, 68.81508391244071, 70.35292870657784, 70.10497529166085, 68.40167999267578, 72.62307889120919, 70.03506251743862, 73.47658865792411, 66.68145193372453, 66.46653025490897, 67.26248809269497, 70.75327001299176, 58.35539082118443, 46.212913513183594, 36.42754309517996, 26.986179726464407, 7.117461919784546, 3.312169138874326, 1.754345342516899, 1.5630273457084383, 0.6374431550502777, 0.4353413097560406, 0.2728078269532749, 0.6744203280125345, 0.3864764746810709, 0.5204003155231476, 1.6710741136755263, 18.855343886784144, 78.89525944846017, 112.75349766867501, 67.26159177507672, 91.79932185581752, 108.30740792410714, 56.95538786479405, 40.719108377184185, 43.243635586329866, 66.10996259961809, 78.3840387889317, 82.21911784580776, 85.9409065246582, 25.086648191724503, 0.28589549181716783, 0.16630657176886285, 0.21437597381217138, 0.10226096093122448, 0.17746605724096298, 0.1737624095486743, 0.14651200893734181, 0.2953301141304629, 0.21409838513604232, 0.16725641222936766, 0.056381686723658016, 0.07937524361269814, 0.10912094996976, 0.13200094045272895, 0.14728285185992718, 0.09283254721335002, 0.1807541972292321, 0.23406540442790302, 0.14929750375449657, 0.2341129018792084, 0.25714210899812834, 0.16186486796608993, 0.16241281213504927, 0.15009839220770768, 0.23110039638621466], [0.004965380590874702, 0.04513587463381035, 0.03316806396469474, 0.015866701724007726, 0.00805255165323615, 0.02593257703951427, 0.10207533410617284, 0.15676043901060308, 0.056216293812862465, 0.054517062314386876, 0.06571328706507172, 0.029848090506025722, 0.21753310225903988, 0.11936802975833416, 0.12460813857614994, 0.07416096662304231, 0.07558461451636893, 0.02764119267729776, 0.055024972917245965, 0.02816600558747138, 0.1684386780751603, 14.967526265553065, 51.32746859959194, 85.1517231804984, 87.02876513344901, 71.27638598850795, 57.87038571493966, 47.64123385293143, 37.97001886367798, 57.52048485619681, 88.04791995457241, 98.52499049050468, 47.08581222806658, 84.5685886655535, 105.35776560647147, 74.59749984741211, 5.713987035410745, 0.3735153158860547, 0.18045838310250215, 0.11023961672825472, 0.09870353753545455, 0.1611343300236123, 0.04859531418021236, 0.8783393715109143, 0.5275787274752344, 0.7152839324304036, 1.756543361714908, 0.7672458727444921, 4.1150654043470105, 27.5804591519492, 62.383872985839844, 80.01614284515381, 79.07129900796073, 83.74904169355119, 83.15901456560407, 79.5427690233503, 80.37721988133022, 77.09812872750419, 66.03148964473179, 75.71376269204276, 77.88985511234829, 76.69686331067766, 81.76644965580532, 77.98769964490617, 74.53151975359235, 71.34639603751046, 68.58381312234062, 66.46414702279228, 68.37146922520229, 71.102952003479, 69.82888862064907, 67.25519943237305, 66.61532592773438, 64.3541041782924, 59.77276079995291, 60.3487525667463, 51.673103264399934, 55.26064232417515, 67.10909966060093, 66.89532443455288, 48.88023315157209, 54.1426111630031, 57.166175365448, 55.973715100969585, 63.125850268772666, 80.05983311789376, 74.35841233389718, 59.029963629586355, 71.52631269182477, 59.77068328857422, 42.66391611099243, 39.16905559812273, 46.86698913574219, 51.14430366243635, 51.55234357288906, 47.37329394476754, 46.06015736716134, 54.64970111846924, 59.83318928309849, 64.13313061850411, 66.02515288761684, 63.61736583709717, 67.51959228515625, 66.30052389417375, 65.41395459856305, 60.17663179125105, 67.50455638340541, 56.99834510258266, 53.88737603596279, 55.0142730985369, 51.25685405731201, 48.74556316648211, 50.23850870132446, 51.23200382505144, 51.85523639406477, 48.06418112346104, 46.26101589202881, 48.60315636226109, 52.354061467306956, 54.03257949011666, 49.23124919618879, 48.09868935176304, 52.194648947034565, 42.80627080372402, 28.636515855789185, 13.721374664987836, 12.032871212278094, 7.14329879624503, 1.3270766181605202, 1.8106989243200846, 0.8660108244844845, 0.4789700529405049, 0.38062446298343794, 0.14968682000679628, 0.688808798789978, 0.28392356048737255, 0.0958308373977031, 0.42854955419898033, 7.880526985440936, 64.42086941855294, 93.06215694972447, 64.48072120121547, 70.30743885040283, 61.0968234198434, 38.06122439248221, 33.25980724607195, 36.18069444383894, 40.553616183144705, 63.34068856920515, 64.48980249677385, 70.52282605852399, 21.484200034822734, 0.5571996037449155, 0.013834928694580282, 0.12289536691137723, 0.03540274440976126, 0.16197742335498333, 0.045427922891186814, 0.04189956115026559, 0.03624532205451812, 0.02117837223756526, 0.06349123415670224, 0.09070784372410604, 0.006806074766375656, 0.017901136307045817, 0.023575792521504418, 0.08015468357396976, 0.0336408434169633, 0.0973049004429153, 0.0942616912403277, 0.027297808156747903, 0.11247295367398433, 0.08187304636729614, 0.044016827895705185, 0.05382877674752048, 0.022308513023225323, 0.046638907731643746, 0.027323129387306314, 0.01259952931598361, 0.032592143796916516, 0.052867163704442124, 0.060598110114889484, 0.05854757728853396, 0.052445403300225735, 0.10650441037224871, 0.022548519341009002, 0.05435614434203931, 0.03260381120656218, 0.035591960685061555, 0.04085527200784002, 0.07360364510012524, 0.04581220102097307, 0.05671000946313143, 0.04264194631416883, 0.022142022582037107, 0.039064689339803796, 0.745357310133321, 23.02470772606986, 69.09189319610596, 100.1055806023734, 100.75661291394914, 91.94221155984062, 90.29039546421596, 79.91467135293144, 37.362652506147114, 35.823133196149556, 51.05738169806344, 88.74273286546979, 56.88368592943464, 85.07334055219377, 112.82770442962646, 78.43104335239956, 4.292238823005131, 0.8883600852319172, 0.1825130685631718, 0.16666356261287416, 0.05728269301887069, 0.32719319579856737, 0.11850193408983094, 1.8543619470936912, 2.7012440008776526, 1.0510601890938622, 0.501921038542475, 0.8731235542467662, 6.335329260144915, 36.728594643729075, 74.67076860155377, 86.79959269932338, 86.05657318660191, 92.05707917894635, 87.83105972834996, 86.83329146248954, 86.77954714638847, 82.88981355939592, 75.67075334276471, 81.5846917288644, 81.27819279261998, 84.7643402644566, 88.29786055428642, 83.97275284358433, 77.02184445517403, 74.53285380772182, 70.21410369873047, 72.24358218056815, 71.50495392935616, 75.5072135925293, 75.62271349770683, 73.9744896207537, 71.87600857870919, 72.80202279772077, 68.34753962925502, 70.24414770943778, 64.82943739209855, 64.55621337890625, 70.09337874821254, 73.02455970219204, 58.20051200049264, 62.80564948490688, 67.6112459727696, 69.47002111162458, 71.43388080596924, 85.76843139103481, 79.29791450500488, 64.75978864942277, 74.22269317081997, 64.90709045955113, 48.547483921051025, 47.55166809899466, 54.84604678835188, 60.527620043073384, 61.069537843976704, 57.35558325903756, 55.18977417264666, 65.10443319593156, 65.73769896371024, 72.1742252622332, 72.84253079550606, 68.87873635973249, 69.39823232378278, 72.0134231022426, 71.64299379076276, 65.60212571280343, 73.98207010541643, 65.83318110874721, 64.4454243523734, 64.68956320626395, 64.55173873901367, 59.592274393354145, 60.53286593300955, 61.16935566493443, 62.13580839974539, 57.93347535814558, 55.13513353892735, 56.651077611105784, 58.45188740321568, 64.25362627846854, 58.670158113752095, 56.73836783000401, 64.45262268611363, 61.188595226832796, 51.405542033059255, 36.23026984078543, 25.410802500588552, 13.228614500590734, 2.733291046960013, 0.8382724214877401, 0.24251115694642067, 0.8257388483200754, 0.563495757324355, 0.14520671112196787, 0.4460800220923764, 0.23208408217344964, 0.0474976039757686, 0.44198620319366455, 6.725709021091461, 66.60056100572858, 94.10354600633893, 67.97581795283726, 63.04874610900879, 29.161540848868235, 19.163857800619944, 40.95486075537545, 52.96086154665266, 59.60029261452811, 80.04993193490165, 70.59985378810337, 81.884596824646, 33.98765536717006, 0.3708952750478472, 0.06442567865763392, 0.24718637179051126, 0.11121059355459043, 0.09759923536330462, 0.10736883684460606, 0.0555360217445663, 0.059384068474173546, 0.054131895303726196, 0.027483066876551936, 0.09064242616295815, 0.024629903458324925, 0.04794573225080967, 0.07518433313816786, 0.043665146588214805, 0.05723365529307297, 0.002434233989333734, 0.05898135115525552, 0.0243175279881273, 0.07907714960830552, 0.06502303374665123, 0.03845482885039278, 0.011711869804587747, 0.07120866075690303, 0.15357395713882788, 0.09948763903230429, 0.09251618704625539, 0.09958021156489849, 0.14114504121243954, 0.10195519948112113, 0.1820429523608514, 0.2870508198227201, 0.172699864421572, 0.10500628647527524, 0.19724414524223122, 0.1411532921982663, 0.30146675769771847, 0.16399396157690457, 0.190666046791843, 0.12149705551564693, 0.14106710468019756, 0.19195469335785934, 0.14771567577762262, 0.17671459327851022, 1.1242534901414598, 31.898384162357875, 87.80753312792096, 119.36281176975795, 106.15689182281494, 92.00814996446881, 80.054121698652, 58.185437883649556, 47.45309400558472, 69.82995169503349, 92.768602507455, 113.42204638889858, 66.98474775041852, 104.83036954062325, 118.97757584708077, 92.4142096383231, 8.161433100700378, 1.0340469820158822, 0.3806046226194927, 0.26436294295958107, 0.21190964829708847, 0.3895904890128544, 0.2382376076919692, 1.7381619023425239, 3.814368648188455, 5.350686575685229, 3.9201323900903975, 1.7948811330965586, 6.249239342553275, 44.313998631068635, 91.64503015790666, 99.43583679199219, 95.69596890040806, 98.38381699153355, 93.63233307429722, 89.21562726157052, 87.46923923492432, 87.76711545671735, 81.01414040156773, 85.58945274353027, 85.57183906010219, 87.37912109919957, 90.01355143955776, 86.94271864209855, 82.19968373434884, 85.38586357661656, 81.61764703478131, 83.76044368743896, 80.3701674597604, 83.64006614685059, 80.3237395967756, 82.04833112444196, 78.99990626743862, 76.95840740203857, 75.91061905452183, 75.20971257346017, 69.57404259272984, 75.6075108391898, 77.26295389447893, 81.14460672651018, 66.6971548625401, 69.84235422951835, 67.11498478480748, 72.35058443886894, 74.40325600760323, 90.24427332196916, 87.26028605869838, 79.82634585244315, 80.13526970999581, 67.2330972126552, 51.1632513999939, 51.16275807789394, 58.53402900695801, 64.22543048858643, 65.10358551570347, 61.74841158730643, 59.567636081150596, 66.83139405931745, 67.04108374459403, 73.25309290204729, 75.07623767852783, 71.81077889033726, 75.94494315556118, 78.13051986694336, 76.88734817504883, 71.3917816707066, 77.15640326908657, 69.93498761313302, 68.32228987557548, 71.17761039733887, 68.1601675578526, 64.37763772691999, 67.55066462925502, 69.39402171543666, 72.10062994275773, 65.01765714372907, 64.52723939078194, 66.73417486463273, 68.929840360369, 70.35306767054966, 63.661792618887766, 61.366288457598, 68.38374669211251, 66.25101103101457, 57.062754903520855, 42.92776353018624, 34.011710030691965, 14.415512732097081, 2.3895847243922095, 4.486699794019971, 3.307108678988048, 0.8188038947326797, 0.5799617394804955, 0.2994366352047239, 0.6612684737358774, 0.3843428891684328, 0.1877344769558736, 0.6844701915979385, 14.581088304519653, 77.46595246451241, 106.64357839311872, 78.43705354418073, 102.92477049146379, 86.93035084860665, 50.39701795578003, 47.29817696980068, 47.17594426018851, 56.43168824059622, 83.36010238102504, 81.97466632298061, 97.4547038759504, 44.52524471282959, 0.47790757566690445, 0.11206022117819105, 0.33451632569943157, 0.2922555905367647, 0.21285051852464676, 0.18129064701497555, 0.2149502315691539, 0.1614422627857753, 0.18144794500299863, 0.21600816265812942, 0.22496759332716465, 0.08786047329860074, 0.17966038520847047, 0.09859176246183259, 0.1588484812527895, 0.23349377938679286, 0.09992502270532505, 0.19903250570808137, 0.14065158340547765, 0.1249089195792164, 0.11982646158763341, 0.1253468460802521, 0.10333979089877435, 0.13713080090071472], [0.03044112671964935, 0.027924192670200552, 0.09023081324994564, 0.01689850921476526, 0.017294142628088593, 0.034835953930658956, 0.08854825674955334, 0.025572100221844654, 0.07917180524340697, 0.09692219312169723, 0.06555518840572663, 0.048327940848789046, 0.02662822980034564, 0.1382441140179123, 0.03103669047621744, 0.031195830686816146, 0.016721747449732254, 0.030376129850213016, 0.059564687710787566, 1.1034509092569351, 43.18913391658238, 93.27708557673863, 88.72694655827114, 82.13273089272636, 54.78631312506539, 51.72000707898821, 34.39547988346645, 48.79573263440813, 104.36079638344901, 80.21615368979317, 129.72802325657435, 67.59737736838204, 99.51520606449672, 101.82569054194859, 87.73671013968331, 6.95817186151232, 0.2939769795962742, 0.17456232091145857, 0.1126986751332879, 0.05612000630104116, 0.10381186128194843, 0.11563213808195931, 0.25601104540484293, 1.3833837338856287, 1.6636696138552256, 1.6801850476435252, 0.31742462569049423, 9.728330050195966, 49.41926050186157, 72.29259477342877, 68.35025637490409, 73.93637180328369, 78.3461502620152, 80.14615058898926, 76.62253843035016, 81.16267899104527, 79.0913793018886, 70.78987312316895, 72.65401921953473, 81.47642489842006, 77.46598025730678, 79.72706304277692, 74.40122713361467, 69.36372062138149, 60.92782238551548, 60.1444616317749, 59.23078741346087, 64.60835266113281, 61.03977176121303, 64.64213480268205, 66.67354488372803, 69.76286683763776, 73.70695618220738, 75.3711748123169, 72.11608968462262, 77.28750188010079, 74.29635102408272, 61.66299043382917, 60.79329136439732, 75.70593902042934, 68.37102454049247, 61.538881710597444, 76.12307412283761, 65.31064183371407, 68.19126769474575, 64.91340637207031, 96.82173688071114, 61.82456384386335, 47.413319042750764, 64.37474727630615, 42.58069406236921, 52.48976673398699, 54.7452666418893, 61.31368364606585, 66.52610410962785, 66.96617521558488, 69.34904602595738, 76.12326172419957, 73.30319636208671, 71.60102667127336, 71.75465134211949, 61.71038409641811, 49.90193101337978, 63.172173908778596, 65.75501387459892, 66.0566907610212, 66.72923469543457, 69.97040952954973, 60.41295392172677, 56.21364682061331, 63.553296497889924, 62.19912038530622, 58.292530468532014, 58.10942459106445, 61.945184571402415, 52.615904331207275, 42.714432988848, 43.19910110746111, 42.38412257603237, 51.131393909454346, 48.02088689804077, 45.736187185559956, 48.7747733933585, 48.772727148873464, 48.362415177481516, 37.590761865888325, 18.37104228564671, 11.230718186923436, 10.089206457138062, 1.7321433510099138, 1.5309290566614695, 0.3992965253336089, 0.26078855618834496, 0.3608668531690325, 0.0888860382671867, 0.31122531262891634, 0.3744820382978235, 0.04186902707442641, 1.1179093505655016, 4.849334529467991, 56.86705541610718, 90.53425639016288, 61.7485922404698, 53.73188924789429, 75.17781339372907, 39.64874880654471, 27.756194727761404, 34.19985335213797, 46.296093872615266, 52.52904837472098, 53.71290676934378, 62.92364379337856, 32.19705595288958, 1.2248650342226028, 0.030509899636464458, 0.011648679534638566, 0.03487107490322419, 0.06869238149374723, 0.10804482735693455, 0.015526409626805356, 0.024120162507253032, 0.1647118516266346, 0.013468667365876692, 0.026284787604319196, 0.028477578690009456, 0.19332462841910975, 0.05481297822136964, 0.031474030044462, 0.024086890542613607, 0.030428370261298757, 0.05563108450067895, 0.08114912414125033, 0.02272405126132071, 0.048788554168173244, 0.023748021672612855, 0.06497341248073749, 0.020361304116834487, 0.007850310050084122, 0.05123226750375969, 0.03212589185152735, 0.0660681812358754, 0.04457804760230439, 0.09171158022114209, 0.008219317749275692, 0.04087128543428012, 0.07839939490492855, 0.021963555997769748, 0.022025175459150757, 0.03907893178984523, 0.08792544981198651, 0.0820395927876234, 0.09607122878410987, 0.026580885019419447, 0.09228585154882499, 0.07170773683381931, 1.9532619544437952, 61.44268390110561, 112.97422109331403, 105.62704304286412, 103.6958954674857, 85.55324568067277, 84.50620773860386, 55.12235580171858, 42.08713572365897, 51.89767599105835, 56.49530247279576, 128.11467933654785, 75.26921694619315, 105.35679980686733, 108.02262905665806, 93.69010734558105, 5.625054436070578, 0.48670616639511927, 0.16354439141494886, 0.16161098730351242, 0.009252165943118078, 0.3215760115001883, 0.2657084236187594, 1.2330771535634995, 3.4615360839026312, 1.278809545295579, 1.2187903544732501, 0.764320681137698, 14.643128769738333, 67.06137248447963, 86.98490810394287, 80.63872228349958, 83.4383043561663, 86.1946964263916, 84.98996911730084, 85.45511627197266, 83.7385082244873, 83.5507401057652, 80.62645871298653, 84.20539242880685, 86.6333292552403, 84.08434091295514, 83.14832128797258, 77.74412359510148, 72.66592843191964, 69.08441693442208, 70.2802505493164, 69.52867085593087, 73.57937335968018, 70.36129433768136, 70.93874522617885, 69.84952477046421, 73.26425865718296, 79.05071149553571, 75.06915746416364, 76.79071957724435, 75.61500099727085, 77.77684961046491, 66.34581225258964, 67.8832540512085, 78.5416795185634, 75.47103432246617, 68.7957262311663, 74.00841767447335, 69.2648616518293, 72.61002322605678, 69.22711903708321, 100.03817612784249, 74.93079103742326, 56.05111108507429, 68.32330431256975, 50.728162152426584, 60.705000604902, 60.74566841125488, 65.94173281533378, 70.40083653586251, 73.82136522020612, 78.12023653302873, 81.14102145603725, 78.74415002550397, 76.63871383666992, 76.94818660191127, 62.1928322655814, 52.308165141514365, 67.17717811039516, 73.68918269021171, 72.66947201320103, 68.89077758789062, 69.81873035430908, 65.27386501857212, 61.527264322553364, 69.48656477246965, 68.55216407775879, 65.16542448316301, 68.13670349121094, 72.14129774911063, 64.6296488898141, 53.82132298605782, 52.095623220716206, 49.96991566249302, 57.10374232700893, 57.00133282797677, 56.74635478428432, 56.974207060677664, 60.376482827322825, 61.07632623400007, 56.396488666534424, 38.90325573512486, 26.188217333384923, 16.972201415470668, 5.054152659007481, 0.1277535690792969, 0.4930690878203937, 0.34288163110613823, 0.6377946361899376, 0.18556959740817547, 0.4491606525012425, 0.4709688765662057, 0.03311303138200726, 1.2182289617402213, 3.589744244303022, 59.24161270686558, 90.89452048710415, 66.38928018297467, 51.03700957979475, 28.027739013944352, 18.638930082321167, 37.92219788687569, 53.95456164223807, 64.34835106985909, 73.25950608934674, 62.80052171434675, 72.52255930219377, 45.95322459084647, 1.1389803056206023, 0.08627209745879684, 0.040601832393024645, 0.053032709285616875, 0.009176838378022825, 0.10727429656045777, 0.018712313047477176, 0.03007455835384982, 0.07882853437747274, 0.12799797739301408, 0.031145286613277028, 0.03970415431207844, 0.04888600536755153, 0.025112613270591413, 0.0779182185818042, 0.04258133278095296, 0.02509933603661401, 0.027118488314694593, 0.01623105297663382, 0.08102559684110539, 0.020223603916487524, 0.06096454616636038, 0.07816650133047785, 0.10370687834386315, 0.11519381803061281, 0.12810439882533892, 0.11790276052696363, 0.1333728025534323, 0.156294190457889, 0.2460783783878599, 0.13388931698032788, 0.2401820719242096, 0.16112911887466908, 0.15010376620505536, 0.1633671037852764, 0.1541252261293786, 0.22084557451307774, 0.13295729484941277, 0.23448482049363, 0.12162915271307741, 0.33085940192852703, 0.3053308789219175, 2.238344588450023, 73.03985963548932, 128.75862448556083, 112.56691769191197, 105.64641462053571, 80.56279236929757, 71.04750537872314, 41.825942516326904, 61.97958510262625, 119.2809203011649, 92.80191911969865, 142.59729603358676, 88.3645771571568, 121.06403650556291, 115.83164691925049, 107.05355685097831, 9.803163017545428, 0.972066553575652, 0.3320861118180411, 0.2463411885712828, 0.22976704793316977, 0.6698625811508724, 0.22231030091643333, 0.9136425171579633, 6.6786801389285495, 5.0152266791888644, 6.4630744968141824, 1.2346640569823129, 15.058882917676653, 73.66364806038993, 97.39051641736711, 88.31169441768101, 89.86652060917446, 92.8446296964373, 89.46039145333427, 89.8193006515503, 90.98918274470738, 90.40299102238247, 86.22679015568325, 83.88480254581997, 88.35160487038749, 87.11265073503766, 89.88353674752372, 84.1802955354963, 83.374269757952, 79.15111296517509, 76.18038286481584, 73.96422713143485, 76.19629423958915, 74.83870656149728, 77.49127170017788, 76.62686020987374, 81.46580110277448, 84.13816860743931, 82.35614327022007, 81.4332835333688, 79.73936830248151, 80.52067238943917, 71.02246407100132, 75.3399635042463, 81.13074507032121, 76.55738517216274, 74.60801247188023, 81.16622257232666, 72.85759449005127, 82.52779156821114, 80.44014971596854, 103.42497825622559, 81.15071419307164, 65.23403099605015, 78.30402333395821, 58.15655769620623, 63.560870034354075, 65.0159409386771, 70.71092769077846, 73.91479764665876, 77.5714191709246, 80.4414142881121, 87.90614196232387, 82.64491040366036, 83.64557606833321, 79.62311104365757, 77.27375139508928, 63.676196234566824, 73.79253714425224, 77.65447098868233, 79.10777010236467, 75.746933392116, 74.96709537506104, 69.8334744317191, 69.75600896562848, 73.21093123299735, 72.78049033028739, 72.76170240129743, 74.91202395302909, 73.92049516950334, 72.35881110600063, 63.078421865190776, 58.85372952052525, 58.77645165579659, 67.1032909665789, 66.04120322636196, 60.660921233040945, 61.9310519354684, 61.752920968191965, 67.17226573399135, 63.82259477887835, 46.6160340990339, 34.24280364172799, 21.814249890191213, 3.986653574875423, 3.8971273388181413, 1.6024888796465737, 0.858168533870152, 0.803694656917027, 0.27349233308008736, 0.7327866618122373, 0.4502531753054687, 0.13130602559873036, 1.5051911920309067, 8.972333908081055, 69.76474285125732, 105.26921776362828, 74.77842399052211, 75.54251738956997, 109.08427906036377, 51.62287473678589, 40.3400285584586, 45.40187461035592, 60.96280656542097, 73.39583669389997, 70.29750987461635, 86.74933637891496, 60.69126401628767, 3.0274868948119025, 0.2966207420187337, 0.09825197926589421, 0.11508783086069993, 0.11065339416797672, 0.21797793624656542, 0.17681659066251346, 0.25692818047744886, 0.2780516270015921, 0.1751362258302314, 0.137513806777341, 0.11870294330375535, 0.30385107547044754, 0.11404185555875301, 0.08924350408571106, 0.11680409019546849, 0.08261501083948783, 0.20253633840807847, 0.14155540562101773, 0.1566927619278431, 0.12462564477963106, 0.225976507046393, 0.1258712722254651], [0.10884660469102007, 0.0844216849654913, 0.02258762501047126, 0.03489123417862824, 0.03556777091164674, 0.1803863498249224, 0.09130815044045448, 0.08273628540337086, 0.05388797214254737, 0.12358492133872849, 0.10999254177191428, 0.026341155204655867, 0.05526180199480482, 0.04873388460172074, 0.1005177026880639, 0.055480280092784336, 0.052612950559705496, 0.14774793333240918, 0.07576728971408946, 41.56589923586164, 92.72884491511753, 74.58953026362828, 77.28897489820207, 61.95337649754116, 63.79925577981131, 40.77560417992728, 60.63214179447719, 178.4489029475621, 140.19875008719308, 97.40434333256313, 64.77130876268659, 89.55424771990094, 102.22974913460868, 94.04775891985211, 10.779008848326546, 0.4599705838731357, 0.24746951088309288, 0.08837545423635415, 0.12523146798568113, 0.11314671859145164, 0.07605285117668764, 0.13397508380668505, 0.7252498748047012, 2.5611711399895802, 2.6751962900161743, 0.7883369667189462, 12.141239660126821, 67.15996742248535, 84.89055429186139, 86.7604534966605, 79.86233057294572, 81.15493174961635, 76.1898741040911, 73.63961424146379, 74.57170118604387, 71.2954796382359, 67.78935609545026, 74.02663585117885, 77.59814889090401, 76.41987337384904, 71.9199698311942, 63.25055653708321, 63.03496783120291, 61.00141770499093, 63.60633904593331, 66.89966705867222, 72.25067629132951, 75.10514913286481, 72.75158582414899, 71.40487207685197, 62.79228809901646, 63.161591802324565, 67.24681295667375, 66.76889501299176, 70.60230650220598, 69.26642499651227, 72.95511940547398, 68.7307049887521, 69.70132664271763, 60.930080550057546, 67.9502763748169, 69.66292394910539, 73.81637641361782, 57.793017523629324, 58.15337889535086, 54.96748740332467, 78.39128576006208, 87.76398876735142, 57.29670075007847, 52.02986894335066, 59.553802217756, 65.14419078826904, 60.27398994990757, 68.69206605638776, 75.56345231192452, 77.27501596723283, 78.14859907967704, 79.66923318590436, 84.81576388222831, 77.45069422040666, 70.8116557257516, 47.31169121606009, 52.792211396353586, 61.77282060895647, 63.87264265332903, 66.77200085776192, 58.77051094600132, 54.116854190826416, 54.93512616838728, 50.504735878535676, 55.926088673727854, 58.540963309151785, 53.30627734320504, 56.46459838322231, 60.21800831386021, 61.78090831211635, 45.9225309235709, 44.01665047236851, 39.61468873705183, 35.42960459845406, 40.53053079332624, 41.88708666392735, 43.790319851466585, 54.5536561693464, 44.34870488303048, 42.46046243395124, 34.30606004170009, 20.4982784475599, 8.833071163722447, 12.348077978406634, 2.8256117616380965, 0.9597667221512113, 0.4596479811838695, 0.40311675891280174, 0.5175833095397268, 0.04835288040339947, 0.08215735932546002, 0.2388596071728638, 0.18374285900167056, 0.8800578564405441, 2.548615093742098, 53.06950010572161, 90.48844691685268, 80.35526357378278, 69.96787343706403, 64.24990204402378, 40.95332520348685, 24.578785249165126, 31.469072341918945, 28.081853321620397, 57.98214054107666, 59.205523763384136, 64.70682253156389, 45.72762700489589, 2.6428165989262715, 0.17944839729794435, 0.02523186749645642, 0.05308981818546142, 0.05778620671480894, 0.007298879059297698, 0.08395642707390444, 0.11653202479439122, 0.06465316430798598, 0.06425269293997969, 0.1748805266938039, 0.014491664079417075, 0.04873156061928187, 0.11372847416039024, 0.04874345873083387, 0.04945922835863062, 0.045417843253484795, 0.03365788821663175, 0.06401227441217218, 0.06366622155266148, 0.037938232999294996, 0.05584581369268043, 0.11369381459163767, 0.005004559202851462, 0.04750090165595923, 0.015136531886777707, 0.07835114427975245, 0.03694413848487394, 0.022115451150706837, 0.07288747174399239, 0.018949630670249462, 0.034522894836430035, 0.06929953462843384, 0.02759604634983199, 0.04048465618065425, 0.03661592091832842, 0.02135650464333594, 0.08676137549004384, 0.08571366992379938, 0.1323384302003043, 0.1743815184703895, 56.66700635637556, 108.18602984292167, 81.19746167319161, 93.9958906173706, 81.50208459581647, 77.06002480643136, 53.4372752053397, 35.61682380948748, 118.97237859453473, 129.5509831564767, 101.1955236707415, 76.37281322479248, 93.99140902927944, 109.37208039419991, 99.38284982953752, 10.502906543867928, 0.8588364837425095, 0.18424340071422712, 0.20351805644375937, 0.12742699017482145, 0.3822651063757283, 0.16589346607880934, 0.4351007012384278, 2.6888382094247, 1.3269267976284027, 0.6282789696540151, 1.0089683277266366, 18.55778901917594, 84.6160101209368, 92.61875070844377, 92.34485271998814, 88.7049902507237, 83.73543017251151, 81.36411421639579, 79.51082815442766, 78.2797463280814, 79.94577148982457, 78.33804171425956, 82.61866705758231, 84.71912138802665, 81.4077558517456, 75.09583159855434, 69.55245453970772, 70.83297974722726, 71.15932273864746, 73.95593098231724, 74.13682733263288, 75.08052471705845, 76.6536455154419, 76.57394272940499, 76.30087157658168, 72.78114346095494, 71.54247420174735, 74.81650706699916, 71.31804738725934, 74.15881838117326, 72.56952217647007, 73.58283356257847, 74.56443337031773, 73.50885609218052, 62.06568023136684, 68.50524289267403, 78.39948463439941, 80.4480289731707, 64.21024867466518, 69.38425254821777, 66.84053788866315, 81.06424386160714, 90.71973855154855, 66.22291251591274, 62.02433844975063, 66.42388916015625, 70.85548496246338, 64.50169781276158, 72.68499428885323, 77.71738692692348, 79.26110294886998, 81.17678383418492, 82.13548932756696, 85.11798967633928, 80.92187527247837, 75.8761351449149, 55.32932179314749, 61.62413610730852, 67.42156709943498, 67.65224729265485, 71.39554759434291, 65.30283205849784, 60.85429654802595, 62.13736479622977, 59.578510011945454, 61.46316024235317, 60.839295387268066, 60.00835336957659, 62.69058036804199, 60.98685428074428, 63.6520790372576, 57.88402155467442, 55.72875983374459, 50.91114296231951, 45.41358927318028, 49.68359776905605, 52.09733247756958, 50.84430129187447, 63.261562483651296, 59.935501507350374, 60.08496420724051, 53.38791520254952, 40.32154982430594, 23.319314820425852, 18.72653818130493, 5.721025994845799, 0.2446991881089551, 0.4415527821651527, 0.46042558231524056, 0.6831888460687229, 0.05158461716824344, 0.055322985497436354, 0.4821828891124044, 0.0414704182850463, 0.878031316612448, 2.3552441213812148, 55.29150969641549, 89.96095357622418, 85.55721310206822, 67.01824501582554, 32.08534629004342, 12.210090228489467, 23.950322423662456, 53.43868568965367, 49.54023906162807, 76.14782360621861, 68.6897314616612, 70.49664524623326, 61.66068363189697, 2.4331308220114027, 0.10991309889193092, 0.028138418049950684, 0.057734916252749305, 0.07845994058464255, 0.03142805590427347, 0.06444785318204335, 0.06176725309342146, 0.028419655548142533, 0.10386435275099107, 0.08704571558960847, 0.05388051165001733, 0.021336369116657546, 0.08501413424632379, 0.012909431526038264, 0.016485466289200952, 0.043918073909091096, 0.05041425621935299, 0.02107069212278085, 0.060139590076037815, 0.05937808379530907, 0.051140210657779656, 0.22492734262985842, 0.1883644424378872, 0.11301422784371035, 0.0940498865342566, 0.1764370860265834, 0.3173608433987413, 0.1666454185864755, 0.16050574875303678, 0.12051440110164029, 0.17759138265890734, 0.15698526480368205, 0.10062259063124657, 0.2649474873074463, 0.13850895980639116, 0.21984029774154934, 0.15445237500326975, 0.19754631045673574, 0.2175286239279168, 0.3404026712690081, 69.14968136378697, 124.5553812299456, 93.1096339906965, 97.11396421704973, 83.75595515114921, 76.36336367470878, 53.2875519480024, 79.02863012041364, 187.0454226902553, 142.02937807355607, 109.01997348240444, 84.56004932948521, 105.70641926356724, 116.6896174294608, 114.76426465170724, 15.691186359950475, 1.092670236315046, 0.4704919478722981, 0.39764963941914694, 0.2542451173067093, 0.578501314989158, 0.17971556367618696, 0.34141588690025465, 3.534868457487651, 9.112396563802447, 5.311004110745021, 2.1651846170425415, 20.973095757620676, 94.18315151759556, 99.26521682739258, 97.94897093091691, 92.50638444083077, 93.04469612666539, 90.24591309683663, 91.87179156712124, 89.7489709854126, 89.15290587288993, 81.43634074074882, 88.00813456944057, 88.25591427939278, 88.2293860571725, 82.52032225472587, 77.41947596413749, 75.25292342049735, 75.33280685969761, 77.85008362361363, 77.3937120437622, 79.85265173230852, 85.09758976527623, 80.72796494620187, 84.03682218279157, 76.54851927076066, 75.54774938310895, 79.25926862444196, 75.23801258632115, 78.35059710911342, 77.17075824737549, 77.85666356767926, 77.29601342337472, 74.96099485669816, 70.26152515411377, 72.72500896453857, 76.81420448848179, 83.6629604612078, 72.19318689618791, 76.25160884857178, 74.90372780391148, 91.94041892460415, 98.033461025783, 72.1619200025286, 71.37162494659424, 70.24587781088692, 76.19114562443325, 68.33069024767194, 74.96011243547711, 80.77161352975028, 83.38405282156808, 83.54106821332658, 88.51370634351457, 93.50172778538295, 81.66503374917167, 84.54916150229317, 61.434471130371094, 60.95583752223423, 70.45616504124233, 73.44145161764962, 81.1366718837193, 72.44141823904855, 67.79945877620152, 66.52443654196603, 64.13002477373395, 70.24524552481515, 70.03678567068917, 68.50375597817558, 73.64884839739118, 71.05272347586495, 69.02755982535226, 66.31836686815534, 62.889027867998394, 57.52450091498238, 55.42483867917742, 56.77797951017107, 57.08917542866298, 55.32681001935686, 65.35032299586705, 58.63011564527239, 61.462924003601074, 58.02825573512486, 47.25575474330357, 30.680566447121755, 26.14321732521057, 4.80857161964689, 4.7763562968799045, 1.6057749433176858, 1.069839215704373, 1.3077489009925296, 0.05519224197736808, 0.23488103066171917, 0.5935627839394978, 0.3956805036536285, 1.0376862095935004, 6.746202732835497, 67.15629877362932, 105.77058587755475, 96.76828438895089, 91.98244162968227, 90.84430585588727, 56.59013843536377, 35.67122820445469, 42.345924854278564, 43.792567593710764, 79.26031085423061, 76.33111708504813, 84.84099973951066, 81.10352897644043, 6.202999949455261, 0.2470972937132631, 0.13262223425720418, 0.08809274262083427, 0.23466180956789426, 0.1755173182381051, 0.13109648041427135, 0.2745329886674881, 0.21971684508025646, 0.3039725332387856, 0.25359038529651506, 0.1313003801873752, 0.13334285201770918, 0.15930862299033574, 0.11789290819849287, 0.12530791174088204, 0.12051417039973394, 0.17266002084527696, 0.12958334732268537, 0.12787479614572866, 0.13178002302135738, 0.123684272436159], [0.033063162450811694, 0.06520686923925366, 0.07797995848315102, 0.004307288136000612, 0.01880409169409956, 0.021217270953846828, 0.08693587434078966, 0.0643481221050024, 0.07784482823418719, 0.08302341428186212, 0.10159444276775632, 0.03899915303502764, 0.11806691171867506, 0.04500936856493354, 0.04423139763197728, 0.12379518577030726, 0.12729264024112905, 0.28179931161659105, 13.283631205558777, 85.63986192430768, 81.64796202523368, 78.29738085610526, 48.37107958112444, 52.94770860671997, 53.96542167663574, 57.45834711619786, 90.04020472935268, 152.64280700683594, 95.92956733703613, 59.748143332345144, 95.57946150643485, 103.05028969900948, 89.88426630837577, 10.5941789490836, 0.2577667140534946, 0.30349994716899736, 0.026527134867917215, 0.05978937101151262, 0.12378375924059323, 0.22870576488120214, 0.15659689850040845, 0.8105792903474399, 2.936251619032451, 3.7882390788623264, 2.1487404022897993, 10.999298879078456, 70.87248025621686, 82.06754984174455, 86.73070131029401, 83.3559126172747, 79.67547266823905, 72.0846004486084, 69.28385107857841, 65.01319640023368, 65.1978656223842, 68.36673055376325, 70.4401980808803, 71.4515083857945, 71.38575063432965, 65.70299965994698, 63.82792404719761, 63.35137489863804, 67.56356743403843, 73.19262272971017, 76.49022388458252, 67.64603560311454, 71.23147283281598, 74.28237819671631, 74.13249860491071, 77.96456214359829, 77.70318480900356, 79.25418949127197, 77.6103012902396, 69.63991846357072, 70.55099405561174, 73.15518583570207, 65.95097391945976, 71.02013642447335, 70.99706840515137, 59.88907364436558, 63.24406691959926, 64.96207850319999, 66.71023137228829, 61.6862530027117, 59.40128925868443, 71.1114079611642, 72.7076940536499, 73.58031831468854, 81.02041462489537, 68.53077057429722, 64.74141761234829, 63.713834626334055, 67.63413333892822, 80.33935914720807, 79.89493152073452, 78.76922607421875, 75.09397642953056, 79.94577843802315, 77.59728731427873, 84.26297909872872, 69.32875033787319, 68.84785161699567, 80.95865903581891, 74.94387449537004, 71.0955035345895, 71.27510057176862, 68.22953837258476, 60.002329281398225, 57.715103898729595, 61.130549975803916, 54.875045095171245, 51.344939844948904, 55.08372729165213, 57.13602018356323, 38.761300563812256, 51.98997238704136, 55.8663341658456, 46.45712532315935, 37.268924781254356, 25.647065571376256, 29.968105111803325, 35.458335399627686, 37.566655090876985, 43.8763871874128, 57.08844239371163, 54.21354879651751, 41.93660300118582, 32.97620609828404, 23.572467224938528, 7.7039359126772196, 10.380627802440099, 2.9067508706024716, 0.6051961311272213, 0.29210555287344114, 0.28845799288579393, 0.2325413604932172, 0.2172521073371172, 0.1819004328655345, 0.3367780457649912, 0.09473059286496469, 0.7510408822979245, 1.3233559663806642, 44.84545939309256, 75.38711397988456, 79.35680048806327, 61.596336364746094, 60.659121649605886, 61.59540530613491, 21.99323374884469, 32.09130784443447, 31.570547308240617, 39.8938638823373, 56.49767180851528, 64.42756748199463, 43.54005963461739, 2.9315450830118994, 0.05272027783628021, 0.030263635529471294, 0.0701464820387108, 0.047975112817117145, 0.014863840537145734, 0.05331338868875589, 0.0740897815142359, 0.07310820597090892, 0.07032685700271811, 0.07577419041522912, 0.1345490701496601, 0.051830094174614975, 0.048552746285817454, 0.0484512103056269, 0.01955342336025621, 0.01840424457831042, 0.0667472794385893, 0.04645311805818762, 0.08093113798115935, 0.036261824026171646, 0.03467450670099684, 0.09674641183976616, 0.10383092133062226, 0.03305459255352616, 0.016295976903555647, 0.02394905124258782, 0.043401953032506366, 0.0679350821301341, 0.04147885926067829, 0.04225542901882103, 0.01694129254402859, 0.026072628363700848, 0.07922170470867838, 0.013640775228850543, 0.11683201869683606, 0.10246323222028357, 0.14204462936946324, 0.35904639799680027, 22.400059461593628, 102.57122530255998, 94.62477902003697, 107.87022032056535, 75.60560008457729, 85.50086321149553, 80.35472161429269, 53.8232615334647, 76.15509142194475, 154.37189401899064, 101.32647636958531, 66.32173674447196, 95.60907472882951, 109.50645855494908, 95.77972943442208, 10.73247936793736, 0.41960127864565167, 0.19683918197240147, 0.0345707586966455, 0.004864915847844843, 0.43356843345931595, 0.3596240755702768, 0.6389784355248723, 2.092900335788727, 4.979213731629508, 1.0331145120518548, 1.5089547272239412, 17.054501090730938, 88.54772472381592, 90.09107943943569, 92.23379271371024, 87.55476461138043, 85.10492011478969, 78.01399162837437, 78.33750670296806, 75.27739497593471, 73.3749782017299, 74.71024131774902, 75.20949023110526, 77.33647973196847, 77.70998709542411, 74.02148723602295, 73.7184693472726, 74.11901909964425, 77.98476750510079, 76.74689034053257, 79.78890895843506, 74.06667831965855, 76.75813252585274, 79.01199613298688, 78.25086961473737, 79.5726740700858, 81.66190011160714, 80.88912841251918, 80.09299686976841, 74.30440398624965, 76.27037593296596, 74.50208718436105, 69.65881756373814, 72.13822664533342, 70.22233036586216, 64.44379152570451, 68.18440982273647, 65.68675477164132, 71.97802897862026, 65.04680483681815, 62.028132166181294, 75.29443195887974, 79.6024887902396, 78.41965525490897, 82.50341033935547, 73.88382952553886, 68.90162372589111, 64.72915404183524, 70.77840164729527, 82.91653633117676, 78.96420642307827, 79.6877362387521, 76.30811159951347, 78.91410296303886, 77.7868480682373, 80.93034512656075, 73.48388426644462, 78.6782533100673, 82.59958035605294, 78.50622286115373, 76.92625113895961, 74.49808502197266, 71.53371947152274, 67.08310644967216, 63.86105305807931, 63.34611511230469, 64.77162143162319, 60.25840514046805, 61.99901226588658, 62.067354747227256, 47.016778400966096, 57.10964134761265, 62.930668422154014, 58.88196005140032, 49.42252268110003, 40.7273975781032, 41.77974394389561, 43.27687924248831, 47.86917298180716, 52.4141286441258, 63.8916459764753, 68.08392497471401, 64.1778005872454, 55.03606264931815, 43.284042835235596, 22.3877055644989, 16.4536451952798, 5.344298575605665, 0.2607691229454109, 1.0009739909853255, 0.37619531207851, 0.3869699867708342, 0.14476543265794004, 0.12964934163859912, 0.6879010275006294, 0.061252523213624954, 0.7415513800723212, 0.7060301804116794, 46.90691001074654, 78.11095373971122, 84.04977362496513, 58.79198782784598, 36.96029274804251, 20.736351524080547, 21.417964594704763, 49.97447715486799, 54.1383866582598, 62.05188110896519, 69.1736387525286, 70.80321366446358, 58.81317983354841, 3.673467431749616, 0.042969017156532834, 0.05918514236275639, 0.05934104935399123, 0.03287537109905055, 0.06401874763625008, 0.039136335852422884, 0.02139632955991796, 0.05947976905320372, 0.02361550208713327, 0.05014227224247796, 0.10806159395724535, 0.0854443186627967, 0.03390580116372023, 0.032174271398356984, 0.026297455853117362, 0.08739554788917303, 0.03642817706401859, 0.02844591824603932, 0.043600360064634254, 0.03994920044871313, 0.09229746806834425, 0.17150124588182994, 0.2200204487890005, 0.10973967891186476, 0.09963865378605467, 0.09515263486121382, 0.183269024427448, 0.16334454928125652, 0.14813720887260778, 0.1725682286279542, 0.2101007825029748, 0.13019378456686223, 0.19497416062014444, 0.23510304731982096, 0.2138730843684503, 0.3326444375727858, 0.3961515426635742, 0.5611525859151567, 32.10195248467581, 121.18066896711076, 102.02777889796666, 105.37609495435441, 65.56242370605469, 71.68951892852783, 66.75854219709123, 75.84145668574742, 108.65308775220598, 156.4731821332659, 98.56797204698834, 76.28973361424038, 112.91100638253349, 119.0495730808803, 109.86961310250419, 16.7414847442082, 0.5545806757041386, 0.4035162531903812, 0.21237977807010922, 0.19308264926075935, 0.6853750316160065, 0.22991510427423886, 0.4748097104685647, 1.7511990027768272, 7.915996670722961, 7.733082737241473, 3.622937960284097, 19.23105035509382, 100.08564622061593, 96.16137313842773, 94.74318327222551, 94.48430728912354, 94.7760204587664, 87.29504094805036, 86.09849861689976, 82.47559670039585, 82.03125245230538, 82.20081629071916, 86.96824632372174, 85.63888222830636, 85.44106006622314, 80.7841272354126, 77.89370441436768, 74.85643836430141, 79.01847880227226, 79.8473641531808, 87.07720102582658, 79.19501863207135, 79.91036346980503, 83.31938593728202, 80.76355361938477, 85.62881428854806, 83.47770064217704, 85.75737680707658, 85.16330582754952, 78.65485872541154, 80.61845438820976, 79.33273887634277, 72.76686491285051, 74.0999115535191, 71.86891446794782, 65.86418397086007, 68.0404361997332, 67.75738743373326, 72.29654135022844, 67.62317602975028, 67.19372871943882, 83.29041194915771, 82.64891951424735, 84.85152626037598, 87.1330645424979, 79.57455008370536, 73.99502154758999, 68.09144292558942, 71.2768028804234, 84.57236153738839, 83.27636269160679, 83.76803806849888, 78.74073845999581, 85.85488087790353, 83.49728761400495, 87.68264620644706, 83.65567180088588, 76.23970658438546, 86.04596328735352, 83.1041168485369, 81.24368109021867, 79.37155846187046, 77.52070426940918, 70.42377253941127, 68.9154645374843, 68.87185069492885, 68.92886066436768, 66.13329465048653, 71.42964240482875, 70.231064251491, 56.37689822060721, 66.0763750076294, 69.05254554748535, 65.65422330583844, 57.15113598959786, 47.991252831050325, 52.18296207700457, 52.19616712842669, 55.029381956372944, 56.669188090733115, 63.43414878845215, 61.50749669756208, 64.33892236437116, 59.22333894457136, 50.48724726268223, 28.768720967429026, 21.685079404285975, 4.8429825731686185, 3.659736922809056, 1.4770347028970718, 0.3964144071297986, 0.3908334837428161, 0.5161613715546471, 0.37238731927105356, 0.6143797497664178, 0.21495823828237398, 1.003221298967089, 3.2858582649912154, 57.6502320425851, 88.89488451821464, 93.89187608446393, 80.92537021636963, 87.43079485212053, 84.74614988054547, 33.550130775996614, 43.91077034814017, 45.03791754586356, 56.677935872759136, 77.4438294001988, 81.55528695242745, 80.52536937168666, 9.846194079944066, 0.11170368495264224, 0.19885490595230035, 0.1448522037161248, 0.23724865647298948, 0.16831822453864984, 0.14133896652076924, 0.16080781897263868, 0.16558830173952238, 0.1853757942361491, 0.18008104977863176, 0.37378534568207605, 0.16947841085493565, 0.16868262498506478, 0.12613165325352124, 0.1420413316892726, 0.16110459661909513, 0.16778043125356945, 0.10481197440198489, 0.08362798898347787, 0.16382168153566973], [0.07563676671790225, 0.038452762711260996, 0.08418104252112762, 0.020659291251961674, 0.056182485805558305, 0.020483465865254402, 0.14582572504878044, 0.07913852310074226, 0.08639137034437486, 0.06932584821645703, 0.05756868874388082, 0.053978732986641784, 0.04185712217752423, 0.05920359851526363, 0.09801922139844724, 0.03107410150447062, 0.15447868859129293, 1.129169014947755, 53.75714594977242, 84.08833612714494, 67.59995515005929, 44.921396255493164, 42.39338452475411, 37.748475551605225, 35.295587744031636, 22.697378090449742, 23.53902554512024, 72.67081301552909, 73.18730735778809, 89.94582734789167, 99.92281518663678, 83.89676039559501, 5.938738243920462, 0.4354859191392149, 0.24136331996747426, 0.16150870493480138, 0.055334208466644795, 0.17299850125397953, 0.13688253850809165, 0.13192284107208252, 0.8122393126998628, 0.7301528060010501, 2.5161133749144415, 1.2228521193776811, 3.745050379208156, 64.37237099238804, 78.3222554070609, 89.57095118931362, 85.07411180223737, 80.89793872833252, 76.68733038221086, 73.45798138209751, 72.32218715122768, 77.1687502179827, 71.26895836421421, 63.536843163626536, 58.71627330780029, 67.44958918435233, 65.56772518157959, 66.09370381491524, 70.79407678331647, 73.63116523197719, 72.85721928732735, 68.41768864222935, 73.63834272112165, 77.41837120056152, 74.6387721470424, 77.27664879390171, 76.10680838993618, 74.69526100158691, 74.22115761893136, 73.61422552381242, 72.67744854518345, 70.85311562674386, 69.96920054299491, 72.48922184535435, 73.19394288744245, 75.37128598349435, 70.71495764596122, 66.93856307438442, 67.92454024723598, 67.72494629451207, 64.26907907213483, 65.49113518851144, 60.73328672136579, 51.42435428074428, 53.21692698342459, 60.59269687107631, 55.4775060244969, 54.696716104234966, 69.46924986158098, 62.93960380554199, 71.75054495675224, 76.9298711504255, 74.08996868133545, 74.37765189579555, 78.28700024741036, 76.70315837860107, 76.3345217023577, 74.999098777771, 75.78038896833147, 83.43025139399937, 74.5297966003418, 74.88794844491142, 74.34791360582624, 77.18357072557721, 73.7398350579398, 69.1368132999965, 64.4677072252546, 64.20730263846261, 63.199125971112935, 63.67926039014544, 55.51913963045393, 54.58004195349557, 47.51623228618077, 40.659246172223774, 51.20350578853062, 47.61711318152291, 40.35211494990757, 26.982471125466482, 20.25169382776533, 23.123113325663976, 28.87831837790353, 38.815684114183696, 50.060575757707866, 59.23231601715088, 58.88463510785784, 40.850231306893484, 33.994558402470176, 21.692197833742412, 8.555554032325745, 10.592533094542366, 2.0656275706631795, 0.6470642387866974, 0.35826491564512253, 0.09731211327016354, 0.5991363791482789, 0.337213828095368, 0.23507226897137506, 0.1854279057255813, 0.1700534557125398, 0.38689583646399633, 0.6269393786787987, 39.21959332057408, 76.26474789210728, 84.21344539097377, 56.22291571753365, 62.516138894217356, 65.55123710632324, 30.72458675929478, 22.05668122427804, 36.00383152280535, 44.54239286695208, 58.630025318690706, 57.06191764559065, 50.54512575694493, 2.337552922112601, 0.1497345074479069, 0.07385530695319176, 0.020624719892761538, 0.002260888224035235, 0.0868368014427168, 0.045621678565761874, 0.054186907530363114, 0.015974283451214433, 0.021364367167864527, 0.07052562705108098, 0.0536496910000486, 0.060170626267790794, 0.05359847517684102, 0.047995170312268395, 0.04526433827621596, 0.020889589429966042, 0.050512704865208695, 0.031141184869089296, 0.02430865105374583, 0.054984002972819974, 0.07706061817173447, 0.03842286645833935, 0.03955799447638648, 0.025989353457199674, 0.05300667050427624, 0.0302153374068439, 0.07539400045893022, 0.023180518731740967, 0.05784869300467627, 0.07939899233835084, 0.013463606342806347, 0.03492057064015951, 0.032002334017306566, 0.12193101937217371, 0.0818321035642709, 0.07464822940528393, 1.9253703653812408, 72.33705629621232, 94.57561356680733, 87.28846100398472, 58.24752351215908, 39.89937727791922, 42.48365552084786, 36.90398107256208, 27.378779002598353, 28.994214330400737, 75.60034724644252, 79.35407679421562, 89.36603491646903, 105.42016042981828, 89.22652898515973, 6.25245201587677, 0.7131620720028877, 0.07006858621856996, 0.24962453810232027, 0.03695792292377778, 0.37840478494763374, 0.07254329842648335, 0.3929741803024496, 1.0145655359540666, 3.4882681923253194, 2.3932713951383318, 1.0710310488939285, 5.809906916958945, 80.95955535343715, 87.85642760140556, 92.31810215541294, 87.82302066258022, 83.97344766344342, 85.2497136252267, 81.62143380301339, 80.5572407586234, 81.70140756879533, 76.2715710231236, 68.16941561017717, 69.86358097621373, 78.56527560097831, 74.51656028202602, 73.64293548039028, 77.98631000518799, 78.7289890561785, 75.6553978238787, 74.53790514809745, 77.81120845249721, 80.99713121141706, 80.22194848741803, 79.81111540113176, 79.16310555594308, 77.70628370557512, 77.83152498517717, 77.20870235988072, 78.02709593091691, 73.92547007969448, 76.13809612819126, 77.31142452784947, 78.53958811078752, 77.96956484658378, 72.49177183423723, 68.50420761108398, 68.8876370021275, 69.69846398489815, 67.2565334865025, 68.07910292489188, 63.25199481419155, 55.12669147763933, 61.02999564579555, 64.81255326952252, 61.48768738337925, 58.593582017081125, 69.77299731118339, 65.20681490216936, 73.16668510437012, 78.37318570273263, 76.70363780430385, 75.81666551317487, 79.23657580784389, 76.1217817578997, 77.41145079476493, 77.88464396340507, 82.7055195399693, 81.59298092978341, 73.45347894941057, 75.87715653010777, 75.71215765816825, 77.90254947117397, 74.48157610212053, 74.19926384517125, 69.61293166024345, 68.11665099007743, 66.13612951551164, 67.459073475429, 61.68123640332903, 59.95037760053362, 55.053099632263184, 47.453281606946675, 53.326673780168804, 54.35098416464669, 56.702820846012656, 46.38071598325457, 40.06974015917097, 40.266707692827495, 41.325213636670796, 49.62666770390102, 58.72056034633091, 61.21858365195138, 75.97124903542655, 64.03662014007568, 56.253505161830354, 40.967902524130686, 21.39607082094465, 16.63458844593593, 3.694933457033975, 0.3168687969446182, 0.7225882261991501, 0.1824250625712531, 0.5515553866113935, 0.3943435182528836, 0.06847073802990572, 0.5806774582181657, 0.140334531132664, 0.3050224169024399, 0.7005925093378339, 43.099126952035085, 80.23555306025914, 84.89045006888253, 55.69121176855904, 56.17314577102661, 16.65231851169041, 20.400781324931554, 38.77607590811593, 46.76716089248657, 61.13499682290213, 70.8866754259382, 63.17772551945278, 66.29200540270124, 5.278980731964111, 0.16049049528581755, 0.05210158960627658, 0.11289325862058572, 0.03982986310230834, 0.07824409859521048, 0.04038030428013631, 0.037281499310795746, 0.09647277223744563, 0.08108364551195077, 0.033670824486762285, 0.024925836328683153, 0.08383779879659414, 0.015313509086679136, 0.06618111660437924, 0.01276016399996089, 0.026352809043601155, 0.07008993293025664, 0.06127038225531578, 0.07006870156952313, 0.11372452508658171, 0.20021561293729714, 0.20256225844579084, 0.18539559388799326, 0.10184512753039598, 0.18531668026532444, 0.2322757818869182, 0.2627676528479372, 0.18445837417883532, 0.1355635885681425, 0.15475540874259813, 0.07558540161699057, 0.13882967616830552, 0.2244000802082675, 0.2896994948387146, 0.24713759869337082, 0.3751636674361569, 3.104150712490082, 88.74328872135708, 107.79317869458879, 89.3718227658953, 62.048705782209126, 62.28796700068882, 49.345790249960764, 46.46574108941214, 27.570302622658865, 30.64313302721296, 82.35378088269914, 93.52171775272915, 108.65534591674805, 115.4799221583775, 100.87878308977399, 13.303645491600037, 0.7077802036489759, 0.21301544324627944, 0.44677237208400455, 0.13396356228206838, 0.9691284426621029, 0.2104234801871436, 0.34456925626311985, 1.2703887628657478, 3.020084023475647, 6.811158835887909, 3.422455072402954, 6.024513321263449, 89.22380529131208, 93.464645249503, 97.57261480603898, 92.22415556226457, 88.09802341461182, 91.45020266941616, 85.84420149666923, 83.55342211042131, 87.03751986367362, 84.68729169028146, 82.51774447304862, 76.58072417122978, 82.96964141300747, 78.70117541721889, 79.28264931270054, 80.97533471243722, 84.24072401864188, 81.39720848628453, 79.41160093035016, 81.2374346596854, 84.88635063171387, 82.06162302834647, 86.17129489353725, 83.6159281049456, 84.01767294747489, 81.71533870697021, 82.3561293738229, 83.57883862086705, 78.17709364209855, 80.3004492350987, 82.37573719024658, 81.1455169405256, 81.28774656568254, 76.60800974709647, 71.74676513671875, 71.15362521580288, 71.29629952566964, 68.31814180101667, 70.77555288587297, 71.28017275674003, 64.21813488006592, 66.24903774261475, 72.43271909441266, 66.46754469190324, 67.28026853288922, 75.58044760567802, 66.45799786703927, 76.1152435030256, 84.18143504006522, 78.63040106637138, 78.00345815931047, 84.88997064317975, 81.54491329193115, 81.53126008169991, 84.4536098752703, 83.31544630868095, 84.86192076546806, 81.4653216770717, 80.5117439542498, 82.34418542044503, 84.54263019561768, 80.84113720485142, 77.41657161712646, 74.05268464769635, 72.78413118634904, 71.8314984185355, 72.2044151851109, 66.7665604182652, 66.63150133405412, 61.397110666547505, 60.440941265651155, 67.88141277858189, 62.66183567047119, 56.68638835634504, 49.75793307168143, 48.659930092947825, 48.87234694617135, 53.8973571232387, 59.14865970611572, 61.25373458862305, 62.29515838623047, 69.24202292306083, 61.57356711796352, 58.672874859401155, 48.695112296513145, 27.450347185134888, 20.279467514583043, 4.657780511038644, 3.2004929142338887, 0.9391324179513114, 0.33179751730390955, 1.520680029477392, 1.6258383010114943, 0.4332594286118235, 0.815445037824767, 0.3118888113115515, 0.83212397141116, 3.80026467357363, 57.5005122593471, 92.19019971575055, 98.46785545349121, 68.94863523755754, 87.20258821759904, 89.26458426884243, 44.774170875549316, 31.39872530528477, 46.470761162894114, 61.67604609898159, 80.813796043396, 72.99319553375244, 88.19899463653564, 13.215413791792733, 0.2916294112801552, 0.15877906712038176, 0.29430202501160757, 0.19370044182453836, 0.11656169034540653, 0.20275941358080932, 0.21331264158444746, 0.2308205414031233, 0.20157809768404278, 0.2411820696932929, 0.14107887047742093, 0.11087089178285428, 0.07940662585731063, 0.10209891998342105, 0.10898100212216377, 0.15566995181143284, 0.18383746035397053, 0.13525039037423475, 0.20084491345499242], [0.04676501685753465, 0.025312545310173715, 0.030762256987925087, 0.029239061222012554, 0.10144772314067398, 0.012209983209946325, 0.04008244097765003, 0.034866236948541234, 0.014851245230862072, 0.04941738310403057, 0.08364347993795361, 0.08159140005175557, 0.0830767946317792, 0.051562330685555935, 0.09602766005056244, 0.11782422688390527, 0.22489409441394465, 15.609958444322858, 80.56794098445347, 69.11494731903076, 69.81019101824079, 87.91035951886857, 92.63358511243547, 113.28128283364433, 103.34421934400285, 59.847669328962056, 56.76367316927229, 60.30835574013846, 85.99670055934361, 100.89682061331612, 75.68464279174805, 4.158957174846104, 0.17953649828476564, 0.1682766710541078, 0.07557376474142075, 0.19148647705359118, 0.07714736887386867, 0.20390533709100314, 0.4416540467313358, 1.254688982452665, 1.0235364202942168, 3.458347512142999, 2.6453833069120134, 0.1735333361263786, 35.22990642275129, 83.43548338753837, 85.39265891483852, 92.3683167866298, 86.65903759002686, 82.41181918552944, 80.93132482256208, 81.83151953560966, 80.3291939326695, 77.85373142787388, 71.57458877563477, 63.172173908778596, 71.34563173566545, 74.56134837014335, 78.95934963226318, 69.5600072315761, 70.94311564309257, 74.01456683022636, 68.57680933816093, 74.15205083574567, 74.46456691196987, 73.93064648764474, 74.9089389528547, 72.87213706970215, 74.05432442256382, 72.95468861716134, 76.52335289546421, 74.5370922088623, 74.52113219669887, 73.98727430616105, 72.2750575201852, 72.61478969029018, 73.85152735028947, 75.06664916447231, 75.73034804207938, 67.53526047297886, 65.58863925933838, 68.31106158665249, 70.23169653756278, 58.745893478393555, 38.55016565322876, 26.03985939707075, 51.56369692938668, 49.340592997414724, 37.59626483917236, 45.48941149030413, 57.24756308964321, 63.902290616716655, 69.31843226296562, 73.38332298823765, 74.85288088662284, 72.93271841321672, 70.68611567361015, 73.32473577771867, 75.16345841544015, 77.58383560180664, 81.81676156180245, 74.6211793082101, 71.76364231109619, 70.82318278721401, 69.8331687109811, 68.39936624254499, 70.66950253077916, 76.7869953427996, 73.06813880375454, 63.905771664210725, 60.66840444292341, 57.485889775412424, 59.7249641418457, 55.45049490247454, 54.023477349962505, 45.87039164134434, 41.97124324526106, 46.43006208964756, 49.780004024505615, 36.879568576812744, 26.27717511994498, 28.403813736779348, 21.199499334607804, 28.437330109732493, 40.72394779750279, 47.20881271362305, 58.77543027060372, 56.88297373907906, 41.42928375516619, 33.673384870801655, 15.23070318358285, 13.50525963306427, 9.057338169642858, 1.795273272054536, 0.6732621501599039, 0.6001848514590944, 0.028262847801670432, 0.4064809355352606, 0.6560923914824213, 0.15632701798209123, 0.4009921843452113, 0.04848703695461154, 0.8783475139311382, 1.6061505803040095, 37.77971812656948, 74.01046739305768, 85.81565134865897, 54.40546498979841, 61.43711839403425, 58.7803704398019, 38.308385712759836, 36.957791396549766, 32.79628596987043, 41.94757768086025, 57.70876714161464, 51.05255617414202, 45.88238770621163, 4.468997086797442, 0.09750624892434903, 0.15246642513998918, 0.0770312308200768, 0.021876540666978275, 0.04568585780050073, 0.016884092041956525, 0.06499415529625756, 0.0771384189969727, 0.028283729716869335, 0.04718079597556165, 0.07691995786236865, 0.06150307905461107, 0.04620856385944145, 0.060756059496530464, 0.050307685509324074, 0.03800496691837907, 0.06583811715245247, 0.06381829482104097, 0.09390126700912203, 0.03645151188330991, 0.010975040994318468, 0.012560937636797982, 0.03602600596579058, 0.01856006675266794, 0.05511724689443197, 0.032896256406924555, 0.030240826574819427, 0.014426210895180702, 0.07642027788928576, 0.0452075889999313, 0.12453007990760462, 0.0579037018386381, 0.07225840871355363, 0.1026716103245105, 0.31919560208916664, 23.224960020610265, 92.82151998792375, 80.84474331992013, 83.40455000741142, 93.23377050672258, 101.21398503439767, 103.5401863370623, 69.16851793016706, 18.874597345079692, 41.481204169137136, 61.68717016492571, 91.17652702331543, 107.63419001443046, 83.36893354143415, 4.31083003112248, 0.6015649916870254, 0.17371058304394993, 0.019915240284587656, 0.04014767872701798, 0.01869015209376812, 0.2599916575210435, 0.4660338099513735, 2.5480470785072873, 3.2124924532004764, 4.1962946227618625, 1.4203996104853494, 0.13634612943444932, 42.996130330221995, 95.37353079659599, 90.94595105307442, 97.89342703138078, 87.64503560747418, 90.06732354845319, 85.23376056126186, 86.0726513181414, 84.88888672419957, 82.65645830971854, 74.7107902254377, 74.72078173501151, 80.7622126170567, 77.6945412499564, 83.73973110743931, 78.00301347460065, 74.93794768197196, 80.08340835571289, 74.83334255218506, 77.42843914031982, 76.52235930306571, 78.16221060071672, 78.27448654174805, 78.0282632282802, 79.11778245653424, 78.27427114759172, 79.63279683249337, 78.82680579594204, 76.87267357962472, 76.38185283115932, 76.63899176461356, 77.83895260947091, 76.7557076045445, 79.87684535980225, 79.21679428645542, 71.11688314165387, 67.72976834433419, 67.21606022971017, 71.04259300231934, 63.28318527766636, 40.57155295780727, 28.80568712098258, 59.00592981066023, 54.491820675986155, 39.88697474343436, 50.96161467688424, 59.090128081185476, 65.07871791294643, 71.00961685180664, 75.02135385785783, 75.52955899919782, 75.0814071382795, 71.04442037854875, 73.75690678187779, 74.16881683894566, 77.9042170388358, 81.33329200744629, 74.12022113800049, 75.27888883863176, 73.54975318908691, 74.33086967468262, 72.2073403767177, 72.7169907433646, 75.11835765838623, 75.72786058698381, 68.40852396828788, 66.89260768890381, 62.48609488351004, 64.93098531450543, 59.65311976841518, 57.9504393850054, 54.1209397315979, 50.43776914051601, 52.73850529534476, 54.22103548049927, 56.393702438899446, 46.34446028300694, 49.405645506722585, 41.62000485828945, 39.36810411725725, 49.57827697481428, 56.474885191236226, 66.47984995160783, 75.42403670719692, 64.94479833330426, 55.163214683532715, 35.780787399836946, 24.01252269744873, 15.166899612971715, 3.578154866184507, 1.1564172442470277, 0.5251682996749878, 0.02952725879315819, 0.2349420716719968, 0.5799070766993931, 0.03421792387962341, 0.8834493373121534, 0.1448124958468335, 0.5553842240146228, 1.5160176796572549, 44.81283065250942, 79.32232352665493, 88.70672035217285, 54.6859325000218, 57.149468421936035, 21.434895617621287, 28.752418756484985, 52.93396159580776, 49.70141642434256, 58.497273036411826, 66.92024762289864, 58.02723434993199, 61.55562686920166, 6.281868083136422, 0.11335466921861682, 0.08869480674288102, 0.13841868750751019, 0.041281327538724454, 0.06667420121708087, 0.020728259247594645, 0.035949090628751686, 0.003243751499602305, 0.07831738037722451, 0.0370725274884275, 0.0838912334293127, 0.09035417091633592, 0.05217539046757987, 0.0367842111736536, 0.018453477382926003, 0.03298129041546157, 0.02002913917281798, 0.04657599735738976, 0.1603411225868123, 0.15088412218860217, 0.11169926090432064, 0.15302428949092114, 0.17883474379777908, 0.166510919375079, 0.16718637384474277, 0.14275535408939632, 0.10266924223729543, 0.12022510091108934, 0.15439885216099875, 0.17402156921369688, 0.24164751757468494, 0.2770739123225212, 0.16857746562787465, 0.316008848803384, 0.4030529223382473, 32.458957876477925, 109.71830912998745, 87.42518765585763, 93.87470013754708, 110.78792871747697, 113.60315813337053, 130.08596665518624, 119.82834107535226, 76.63284955705915, 77.08772032601493, 84.42795712607247, 103.12325273241315, 119.21731649126325, 89.853041103908, 6.499351041657584, 0.9293418633086341, 0.29570490973336355, 0.10397755274815218, 0.46620930624859674, 0.17531265850578034, 0.7276386437671525, 0.468839525112084, 3.27588911993163, 2.891417281968253, 10.90065964630672, 7.695563333375113, 0.3655613384076527, 47.26613187789917, 100.40881388528007, 94.81133815220424, 102.28359072549003, 92.2961597442627, 94.00121293749127, 90.00966044834682, 93.96933460235596, 89.3573774610247, 89.30608585902623, 81.24117279052734, 77.64220741816929, 83.21334253038678, 86.62317793709892, 89.96681090763637, 84.97247355324882, 83.59242929731096, 83.84214755467006, 78.17396000453404, 80.19274520874023, 81.44592230660575, 83.55868884495327, 81.82043021065849, 82.65008681161063, 82.37691143580845, 81.7464041028704, 83.9032291684832, 82.22170952388218, 80.90440055302211, 82.74858447483608, 79.17390305655343, 82.60596575055803, 80.07443823133195, 81.49255166734967, 80.56698213304792, 72.75829778398786, 67.0352681023734, 68.2158921105521, 72.49736513410295, 68.25507300240653, 51.171002115522114, 38.366403170994346, 59.56199414389474, 59.72422068459647, 53.117731026240754, 58.67573751722063, 65.89354010990688, 64.31846686771938, 73.87517207009452, 76.58399677276611, 79.27570806230817, 76.9014321735927, 72.9466495513916, 76.51945495605469, 78.47803401947021, 82.30825628553117, 87.400924546378, 81.42801679883684, 81.42062391553605, 79.40871742793492, 77.98065417153495, 75.88717583247593, 76.65577861240932, 80.54906967708042, 80.16907269614083, 72.33989810943604, 72.33349187033517, 70.01702499389648, 70.81637355259487, 65.64109815870012, 67.4827390398298, 59.92191777910505, 62.36199310847691, 66.48715250832694, 61.3125649860927, 55.34041806629726, 49.17089019502912, 54.40410661697388, 46.70041649682181, 52.99029064178467, 63.57917158944266, 63.75960241045271, 62.7382241657802, 67.62589277539934, 61.70974486214774, 58.44463348388672, 40.312388624463765, 30.355998720441544, 15.504490000861031, 5.491206509726388, 5.321130241666522, 1.1098551941769463, 0.19105700509888784, 1.043728536793164, 1.921869776078633, 0.20902503308440956, 1.0847248626606805, 0.19812166744044848, 1.0599417239427567, 4.287435446466718, 63.67812088557652, 85.1056774684361, 103.06898730141776, 65.07217270987374, 90.47344575609479, 86.95239748273576, 52.636071477617534, 51.00002431869507, 46.84000580651419, 57.22340420314244, 77.77575179508754, 69.09640952519008, 84.11820643288749, 12.327276808874947, 0.16610355409128325, 0.24238652363419533, 0.19760071539453097, 0.16825566360993044, 0.15823485489402497, 0.09997057276112692, 0.1813025213778019, 0.11183551752141543, 0.16265701688826084, 0.19746624332453522, 0.1697308530232736, 0.18176936704133237, 0.13285826944879123, 0.1321343540080956, 0.1521606094070843, 0.13202113365488394, 0.1451469457575253, 0.0976901115583522], [0.034265051529343636, 0.018391505083335296, 0.037160200998187065, 0.03082475684849279, 0.03302736633590289, 0.04049347713589668, 0.03050235432705709, 0.053659112458782535, 0.05361737576978547, 0.05053035356104374, 0.03812469442241958, 0.08025936117129666, 0.06891347534422364, 0.05513923821438636, 0.018805801602346555, 0.06301182880997658, 0.24060072803071567, 33.87202344621931, 80.4627799987793, 65.80603449685233, 63.610681670052664, 46.070753370012554, 23.192369495119365, 27.075736795152935, 66.2647476196289, 95.06581592559814, 81.73022174835205, 100.11480781010219, 105.500460760934, 70.10696247645787, 4.011879009859903, 0.12197175861469337, 0.08710650554192917, 0.21725788845547608, 0.0665801562634962, 0.008952670763911945, 0.1332757313336645, 0.13333529313760145, 0.5237900050623077, 1.1212759699140276, 2.096938976219722, 2.610190898180008, 0.7122719969068254, 3.163933664560318, 76.36567047664097, 82.4020917075021, 89.45166451590401, 91.01947689056396, 90.2114291872297, 85.16867678506034, 82.78518063681466, 79.90862642015729, 81.14537797655377, 76.46707248687744, 72.037095614842, 75.0130090713501, 76.30415112631661, 73.97883224487305, 73.55503382001604, 79.78105054582868, 67.95784991128104, 75.29065213884626, 75.73498943873814, 69.51918656485421, 70.60849734715053, 71.58639376504081, 73.09979479653495, 72.9990598133632, 75.79030404772077, 73.40348666054862, 75.17529119764055, 75.67679827553886, 72.92815344674247, 72.50078364780971, 74.63003826141357, 74.24002197810582, 79.63448524475098, 76.94937474387032, 81.13931914738247, 75.35060119628906, 70.63836070469448, 65.89484637124198, 69.72922366006034, 59.80579948425293, 35.505524090358186, 27.277078219822474, 69.05522755214146, 48.21925449371338, 17.70312237739563, 24.659558057785034, 44.944867270333425, 63.774381228855674, 70.05208560398647, 68.94634233202252, 65.33374459402901, 69.18590232304165, 71.22267641339982, 73.83724880218506, 76.7878360748291, 73.85633550371442, 68.53220190320695, 71.1788888658796, 75.08660439082554, 72.55598708561489, 71.82216698782784, 69.3693903514317, 67.44027165004185, 63.40256922585623, 73.79289845057896, 75.31178855895996, 68.27124146052769, 61.76712308611189, 57.96846996034895, 57.64361735752651, 52.054479462759836, 60.396549224853516, 53.76721041543143, 48.30628762926374, 48.243698256356375, 47.46723706381661, 35.39984893798828, 33.078153542109895, 31.772590500967844, 25.74939169202532, 32.18608127321516, 39.30163417543684, 53.92874561037336, 65.77058478764125, 53.88065365382603, 41.91822154181344, 32.75437791006905, 14.090626256806509, 14.68772578239441, 7.570084946496146, 1.3631576363529478, 1.242083104593413, 1.0613183357885905, 0.14550186028437956, 0.08948268767978464, 0.6039714568427631, 0.3557058615343911, 0.1317000508840595, 0.03643025677385075, 0.8982617567692484, 1.8233034993921007, 47.66429492405483, 73.27694606781006, 82.21814509800502, 47.458006381988525, 52.98977647508894, 67.96752875191825, 27.677145072392054, 31.652542999812535, 40.78906978879656, 45.47089801515852, 56.66699940817696, 55.737973145076204, 42.88624109540667, 4.493633661951337, 0.12765432654746942, 0.08525295143148728, 0.04429264559543558, 0.0082022330856749, 0.021505112294107676, 0.025592486806479946, 0.055465328573648415, 0.2084520509732621, 0.02545256440394691, 0.03994771445702229, 0.03741994081065059, 0.07102828579289572, 0.05279094386579735, 0.04583560708644135, 0.0365583981121225, 0.05488074351368206, 0.04198330594226718, 0.0565302960707673, 0.03278760937973857, 0.012516409624367952, 0.04424314985850027, 0.062246420952890597, 0.05737905177686896, 0.07655941149485962, 0.02718267433478364, 0.12470261779214654, 0.041190505626478364, 0.04188696414764438, 0.01553690995621894, 0.033117360435426235, 0.06657271273434162, 0.024468815852222697, 0.21372797286936215, 0.2166673322873456, 46.993171896253315, 88.31142343793596, 83.07308619362968, 82.3641892841884, 68.5477797644479, 53.39204938071114, 39.779336724962505, 50.31985821042742, 78.93907478877476, 85.24209145137242, 107.99250166756767, 112.63772678375244, 78.87977886199951, 4.127494863101414, 0.4980394382561956, 0.09772597891943795, 0.65265753865242, 0.11814722312348229, 0.13917526762400353, 0.07378194374697548, 0.23916980624198914, 1.057274158511843, 2.4036355018615723, 4.184104876858847, 0.9988641270569393, 0.9196555316448212, 4.3366920948028564, 87.12733922685895, 91.21844550541469, 94.690856388637, 93.06210831233433, 93.43429551805768, 88.4841000693185, 90.07370894295829, 86.89579745701381, 86.95811585017613, 83.11798545292446, 80.24821267809186, 79.2840667452131, 80.94240025111607, 79.77572127750942, 77.15071964263916, 81.99000794546944, 76.29998915536063, 75.77574062347412, 80.60516248430524, 75.4391837801252, 77.87619495391846, 77.03139128003801, 77.75936099461147, 77.22003487178257, 80.3648590360369, 80.0102229799543, 78.83355944497245, 80.43627262115479, 75.8441595349993, 78.00440311431885, 78.74072456359863, 77.1577651160104, 83.9403325489589, 78.06401865822929, 82.17873491559709, 78.94831589290074, 71.02841172899518, 68.1175889968872, 71.59387697492326, 63.81724466596331, 45.5034225327628, 35.98555081231253, 72.77293069022042, 51.93796859468733, 24.433185747691564, 25.036308492933, 46.21615137372698, 64.31101145063127, 73.30050046103341, 71.30822958265031, 67.14461190359933, 71.27703217097691, 74.24527481624058, 73.6862574986049, 76.7388721193586, 75.67767374856132, 73.07674762180874, 74.87001514434814, 76.60227053506034, 74.3306473323277, 75.44299139295305, 74.56248787471226, 74.14805562155587, 69.36422783987862, 75.54884025028774, 77.63664191109794, 71.64622470310756, 68.61470481327602, 64.70218808310372, 64.15599714006696, 58.58196462903704, 62.45705141339983, 59.307224546160015, 55.83617550986153, 54.757349559238975, 55.08584301812308, 54.83072601045881, 49.508291244506836, 51.74611146109444, 44.697636468069895, 47.19940137863159, 50.20624821526663, 58.90181105477469, 69.57482079097203, 76.77365480150495, 63.73492240905762, 54.536198820386616, 33.9495062828064, 23.02812797682626, 11.132611359868731, 1.5005894218172346, 2.018424332141876, 1.6409306568758828, 0.17388625576027802, 0.005245986203330436, 0.15428232055689606, 0.1992593535355159, 0.5714260946427072, 0.053197895243231735, 0.8162425607442856, 2.025477622236524, 55.788295473371235, 79.02514212472099, 85.78886604309082, 53.65719958714077, 51.99256753921509, 25.313324485506328, 29.27186782019479, 48.84267118998936, 55.09708867754255, 63.00978061131069, 68.97870704105922, 63.81138733455113, 56.97183772495815, 4.053521301065173, 0.21236320824495383, 0.12140012000288282, 0.14817933232656547, 0.05157964011388166, 0.055092527863702605, 0.10165746510028839, 0.005491874571557024, 0.038563136610069444, 0.018174855637231042, 0.08425974579794065, 0.0517630108099963, 0.07862968290490763, 0.05574715470096894, 0.03507616889796086, 0.04284056708482759, 0.019292932070259537, 0.050942251458764076, 0.10995697975158691, 0.06124162594122546, 0.12994879271302903, 0.11919482690947396, 0.1819458675703832, 0.17084728740155697, 0.1464902822460447, 0.09622524944799286, 0.17080599176032202, 0.15711966902017593, 0.1765461266040802, 0.08243551118565456, 0.14549225222851547, 0.21866270021668502, 0.07437560760549136, 0.35764649882912636, 0.6150469396795545, 61.03043338230678, 104.90538229261125, 87.45911570957729, 78.90664059775216, 59.975002016339985, 31.225187097276958, 35.71524156842913, 85.46974917820522, 123.02647181919643, 98.60046877179826, 116.05781773158482, 123.60692432948521, 90.07156194959367, 6.3477726152965, 0.7337034440466336, 0.14099950902163982, 0.5849032114659036, 0.21993869888995374, 0.43042556781853947, 0.22663182259670325, 0.4030948829438005, 1.2688219440834863, 3.284371567623956, 5.652334366525922, 9.850838082177297, 1.9560416681425912, 4.591362246445247, 94.37183679853166, 91.57581220354352, 98.47160053253174, 97.44193308694022, 99.70588547842843, 93.86170700618199, 95.42413452693394, 89.24328109196254, 90.40484619140625, 86.2178339276995, 82.88677024841309, 81.09329427991594, 88.90138108389718, 85.36947277614048, 84.45036506652832, 85.8098634992327, 81.34941182817731, 82.81669071742466, 86.1166890008109, 78.39330768585205, 80.40983472551618, 77.78695229121617, 81.7976609638759, 78.05851568494523, 87.18119471413749, 81.97153963361467, 82.51131738935197, 84.73051643371582, 81.38165841783795, 81.57295622144426, 81.94840213230678, 79.07550961630685, 87.4472690309797, 81.71330288478306, 87.86905942644391, 82.15613242558071, 73.04787785666329, 65.94793060847691, 74.0353558404105, 63.19624246869768, 45.50484691347395, 35.993409224918906, 75.88649490901402, 57.8938741002764, 27.940764938082012, 39.51274824142456, 51.67962414877755, 65.80042035239083, 76.29348564147949, 74.28995868137905, 69.70856666564941, 73.27342333112443, 76.05776800428117, 77.75946521759033, 82.07836818695068, 80.0527320589338, 75.39782115391323, 77.99988678523472, 80.23820727212089, 78.76243073599679, 81.05074351174491, 77.14174257005963, 78.12153584616524, 71.60232598440987, 84.04738344464982, 83.28369998931885, 74.61532197679792, 70.93715408870152, 68.23785536629813, 66.94947869437081, 61.94017492021833, 67.19577843802315, 65.1193996156965, 63.50841113499233, 65.17074680328369, 63.91856329781668, 54.929095132010325, 48.527417523520334, 52.3166697365897, 54.349017824445454, 62.28885637010847, 62.695951325552805, 66.59780951908657, 65.10603128160749, 66.15718255724225, 62.118736675807405, 56.870456559317454, 39.33323458262852, 31.096718379429408, 11.614945752280098, 6.335337945393153, 6.6119014365332465, 3.021611758640834, 0.6787521498543876, 0.17614319893930638, 1.176054373383522, 0.5441006751997131, 0.6278521439858845, 0.13665320724248886, 1.7485701952661787, 8.927753397396632, 77.74308136531285, 80.16461195264543, 102.49599020821708, 59.27783366612026, 80.48550060817173, 94.28275394439697, 39.45077725819179, 41.745360783168245, 54.87941551208496, 60.9033716746739, 81.13732501438686, 74.55036326817104, 76.76521274021694, 6.75097918510437, 0.4093977947320257, 0.2912081224577767, 0.1903600682105337, 0.11022350152156182, 0.11215461896998541, 0.144367444728102, 0.11070629954338074, 0.2873734767947878, 0.08466708394033567, 0.18157785731766904, 0.16117019738469804, 0.10698314396930592, 0.11279485747218132, 0.1987956834158727, 0.07638915348798037, 0.19306594372860023, 0.1908792017826012], [0.0764036469959787, 0.04430724088368671, 0.060293237545660565, 0.0486202469494726, 0.00939368290294494, 0.022308569002364362, 0.10232637170702219, 0.01383240454431091, 0.016902731398918798, 0.03689326532185078, 0.0398007132379072, 0.05149751023522445, 0.06590748378740889, 0.0789182163508875, 0.09129600466362067, 0.10234726380024638, 1.431723871401378, 58.82856314522879, 72.5365321295602, 56.881862027304514, 65.59216894422258, 46.166075706481934, 38.89044325692313, 53.53390727724348, 48.53091246741158, 53.75994954790388, 96.26622145516532, 93.28893225533622, 81.03351197923932, 8.135825514793396, 0.1786541042051145, 0.17836350122732775, 0.026888916169160178, 0.1968729187335287, 0.07729314533727509, 0.040185198320874145, 0.09544886289430515, 0.09497098425137145, 0.3855904707951205, 1.2149674338953835, 5.583053009850638, 0.30656684402908596, 0.23741834451045307, 27.396524701799663, 85.33667033059257, 89.82652677808488, 91.67339965275356, 88.76635674067906, 85.37863745008195, 87.56998116629464, 86.859680720738, 90.31436674935478, 80.95890917096818, 78.76122869764055, 78.94101333618164, 74.87512901851109, 74.53554970877511, 73.72456291743687, 72.98136275155204, 72.60759135654995, 75.49907725197929, 69.00648593902588, 75.86378124782017, 71.70527049473354, 74.16703810010637, 72.88515799386161, 70.66361045837402, 73.84929697854179, 74.25229944501604, 75.01602458953857, 74.87048762185233, 75.41585172925676, 75.31674262455532, 74.81108747209821, 75.04126739501953, 77.2342369897025, 78.46283830915178, 73.62471035548619, 74.71874591282436, 70.24951866694859, 65.66911329541887, 66.75501251220703, 66.72453076498849, 64.78370434897286, 63.85964257376534, 68.29925659724644, 66.79649325779506, 42.974552699497764, 52.926301206861226, 16.221403394426616, 40.83929136821202, 61.24896812438965, 71.88256072998047, 68.73992524828229, 66.85196767534528, 71.44585950034005, 72.90605817522321, 71.54924869537354, 70.14464950561523, 68.23128237043107, 74.58660507202148, 74.2941484451294, 77.2731260572161, 75.15302916935512, 75.5152040209089, 74.07483550480434, 74.69838074275425, 70.89067758832658, 65.77440629686627, 67.80958230154855, 73.03670515332902, 66.15996183667863, 66.0122709274292, 61.89602606637137, 58.774499211992534, 56.445824350629536, 59.15894998822893, 59.740409987313406, 52.4523263658796, 45.89379664829799, 45.75126130240304, 40.53015559060233, 40.87882661819458, 35.575944083077566, 31.821648257119314, 34.00732224328177, 39.587517806461875, 55.16180419921875, 71.88582638331822, 55.10700028283255, 41.78331879207066, 29.739495481763566, 13.749911785125732, 15.005649294172015, 5.435836315155029, 0.30416767991014887, 0.29633562160389765, 0.13494293258658477, 0.05270724657124706, 0.004401289408893457, 1.0376389835562025, 0.2614229592893805, 0.25794869714549606, 0.07990105396934918, 1.5235823137419564, 5.762411202703204, 57.987931864602224, 65.67087813786098, 84.63249819619315, 57.473122460501536, 64.26634843008858, 63.74557399749756, 27.773066690989904, 25.853755371911184, 26.921690021242412, 40.30827876499721, 56.23915018354143, 45.863346167973106, 44.871205942971365, 3.330827440534319, 0.2717651357608182, 0.08526165025042635, 0.07764645852148533, 0.09382096917501517, 0.02510611290511276, 0.06229886492448194, 0.09931601717003755, 0.07545301264950208, 0.03342978509941271, 0.061921565527362485, 0.09890686055379254, 0.04538652886237417, 0.09342011104204825, 0.04990110732614994, 0.021503444794299345, 0.05492322998387473, 0.06827839370816946, 0.05022521636315754, 0.04499521432444453, 0.016915784716340046, 0.04506026208400726, 0.05064598610624671, 0.05554645761315312, 0.028971416476581777, 0.06266442566577878, 0.03608150673764093, 0.06362171644078833, 0.022950929622831087, 0.03939232675890837, 0.08522927734468665, 0.12504054180213384, 0.13479699327477387, 2.4320416918822696, 70.73951257978166, 84.7945510319301, 68.59770257132394, 64.7668480191912, 57.771881103515625, 48.719552585056846, 18.280554158346995, 36.26646648134504, 66.41399492536272, 104.99698039463588, 99.5707916532244, 89.9976887021746, 10.672124709401812, 0.30870702490210533, 0.15752916490393026, 0.09401866035269839, 0.08384869606899363, 0.5932903385588101, 0.031088411808013916, 0.15135057430182183, 0.09028830552207572, 0.8873904858316694, 0.9858898861067635, 3.8298943979399542, 0.9015348468508039, 0.5429358748453004, 32.023879051208496, 89.2579070499965, 87.50165952954973, 93.81177030290876, 92.0878596987043, 91.82204246520996, 91.52024051121303, 92.41352871486119, 88.7263490131923, 84.32161494663784, 82.34977872031075, 81.27574702671596, 78.53662817818778, 78.63649463653564, 75.90384456089565, 78.39894962310791, 77.01233237130302, 80.19678211212158, 74.40356867653983, 78.87365055084229, 77.89895725250244, 76.94628974369594, 75.55956132071358, 74.74493367331368, 77.54993534088135, 78.14312389918736, 78.55586774008614, 80.3789291381836, 77.06019851139614, 79.04522241864885, 77.7539483479091, 81.14454419272286, 80.96985258374895, 78.62896278926304, 73.90340260096959, 74.16026360648019, 70.32155758993966, 66.85752623421806, 66.72325924464634, 69.13066414424351, 66.33418791634696, 67.36179869515556, 70.80845260620117, 68.90184606824602, 52.1531925201416, 60.29521669660296, 26.9216240133558, 44.32664782660348, 62.37579223087856, 72.25101675306047, 73.82313006264823, 71.49005699157715, 74.43959508623395, 74.79243850708008, 73.31979560852051, 69.78917966570172, 70.94317817687988, 74.54833439418248, 74.31605611528668, 75.30440957205636, 74.18233108520508, 74.12511961800712, 75.54249654497418, 76.2535890851702, 76.50566278185163, 72.76373822348458, 68.93446786063058, 73.94038786206926, 70.04800701141357, 70.84164415087018, 69.03787095206124, 65.15287603650773, 60.80738925933838, 61.170543806893484, 64.61801760537284, 57.895698002406526, 53.305308069501606, 54.34527274540493, 57.04838950293404, 53.85507386071341, 52.401910236903596, 47.53314420155117, 47.2722601890564, 50.30180331638881, 57.57747745513916, 69.38428728921073, 78.84098012106759, 63.35416807447161, 52.988779408591135, 33.882695879255024, 24.590513808386667, 7.276240851197924, 0.5916422584227153, 0.3345181170318808, 0.03702748294121452, 0.17111130537731306, 0.05127830271209989, 0.7413524336048535, 0.3435275693024908, 0.4909642179097448, 0.06337702314236335, 1.4778186551162174, 9.885906508990697, 67.08290495191301, 71.45159176417759, 86.91318184988839, 64.77182987758091, 52.207124437604634, 24.576231786182948, 31.072066170828684, 40.77532277788435, 41.72221633366176, 57.617874281747, 64.44088023049491, 53.459127289908274, 57.29615879058838, 4.021168751376016, 0.20142157322594098, 0.08715345337986946, 0.02204309556899326, 0.06946499539273125, 0.08949804292725665, 0.036719506074275286, 0.06662733480334282, 0.052814390643366745, 0.03818003573854055, 0.06002976239791938, 0.05274240147056324, 0.010089089694832052, 0.05906264643583979, 0.10862147355718271, 0.0623759940000517, 0.06427592597901821, 0.1621995892907892, 0.19023236792002404, 0.17542034201323986, 0.09507177384304148, 0.2030259964189359, 0.132523330992886, 0.146839958482555, 0.12604915696595395, 0.10651967062481812, 0.12248977938933031, 0.17727149410971574, 0.08540769812784024, 0.2718613791678633, 0.161364095551627, 0.36037510527031763, 0.3463106213935784, 3.967514327594212, 87.84879153115409, 95.7027017048427, 74.49771676744733, 80.99897943224225, 61.2604534966605, 58.113266944885254, 72.90710735321045, 71.97622244698661, 72.34028720855713, 113.20108672550747, 107.04314150129045, 100.41087750026158, 13.980636273111616, 0.6585443456258092, 0.4585145020059177, 0.38752217856901033, 0.35428699052759577, 0.849141466830458, 0.12605299747415952, 0.31053510680794716, 0.28219693313751903, 1.4597912281751633, 7.730663027082171, 15.002807480948311, 7.734915324619838, 1.510104762656348, 39.1096693447658, 99.63041414533342, 95.91174520765031, 101.1193436213902, 98.93166855403355, 96.89049625396729, 95.33395385742188, 93.73454107557023, 94.1114808491298, 89.4105589730399, 88.55072634560722, 87.60415240696499, 84.31032412392753, 83.23659815107072, 82.04311997549874, 81.97810568128313, 84.96230139051164, 83.57247407095772, 81.11373588017055, 85.39887060437883, 80.0731736591884, 82.27240358080182, 79.86499868120465, 77.58648286546979, 81.58647046770368, 82.50049209594727, 84.50554071153913, 83.65203789302281, 80.0008498600551, 80.91633755820138, 80.37111936296735, 84.13674422672817, 83.29830510275704, 83.82094165257045, 78.7298367364066, 75.5496323449271, 69.75926072256905, 67.9960719517299, 67.19010175977434, 68.20134258270264, 68.18324252537319, 64.27585356576103, 70.41197449820382, 76.23266805921281, 53.32365131378174, 55.00427464076451, 26.785873583384923, 46.3646309035165, 62.80690710885184, 74.51709529331752, 74.32324055262974, 73.01227528708321, 79.19093309129987, 77.18900421687535, 76.12009334564209, 75.86684540339878, 74.95660359518868, 78.14334624154228, 79.5406220299857, 80.12058121817452, 79.51928411211286, 79.07750374930245, 81.42361164093018, 82.19239507402692, 77.25379616873605, 75.86367007664272, 78.11486557551792, 80.12435409000942, 74.94770295279366, 75.37948485783168, 72.54596083504813, 67.45807293483189, 63.98713506971087, 67.28541714804513, 69.84516824994768, 62.135794503348215, 64.38798359462193, 61.71720722743443, 56.916102749960764, 53.785327843257356, 54.516191482543945, 54.76273093904768, 60.29919801439558, 57.811840193612234, 67.3957336970738, 66.36896365029472, 66.6128454208374, 61.251399993896484, 55.41974564961025, 37.55664621080671, 30.195821898324148, 7.570414985929217, 2.4055084756442477, 1.0385156508002962, 0.19133542158773967, 0.31711114251187866, 0.15805372675614698, 2.6158641023295264, 0.5030028404934066, 0.3914497563881533, 0.12491524352559022, 2.6728228288037434, 21.442165170397075, 85.09187834603446, 75.45925712585449, 104.69041892460415, 71.7980706351144, 98.99985817500523, 88.90991347176688, 39.10366610118321, 36.28211382457188, 40.92696026393345, 56.47276251656668, 77.88344887324742, 63.774812017168315, 76.8939767565046, 8.040195720536367, 0.21010574937931129, 0.1845320223697594, 0.11551275663077831, 0.10287397660847221, 0.1890822374927146, 0.139198134254132, 0.17341607170445578, 0.1572284246129649, 0.2083055688334363, 0.18087470504854405, 0.16809839276330812, 0.11435478233865329, 0.16544764143015656, 0.17385179975203105, 0.15237594928060258, 0.0938068013638258], [0.03662935591169766, 0.028776279983243773, 0.028685400395521095, 0.03952980473903673, 0.006859422885879342, 0.023480020696297288, 0.03692822005333645, 0.005398927148365016, 0.027834363115419234, 0.04389737859102232, 0.03822998948661344, 0.0494858472874122, 0.12650122413677828, 0.033783834494118176, 0.04694026888215116, 0.05330672547487276, 9.969002621514456, 65.12543065207345, 66.12834753308977, 73.53639875139508, 79.90046923501151, 54.44907883235386, 57.9586625780378, 64.87165464673723, 48.49273211615426, 92.46346541813442, 96.68037578037807, 91.6297163282122, 18.45906032834734, 0.27153779938817024, 0.12434378133288451, 0.2653524912893772, 0.08856069429644517, 0.9876853440489087, 1.0434776416846683, 0.14427113346755505, 0.11541910522750445, 0.49727562495640343, 0.7659294605255127, 3.291637646300452, 3.5453383071081976, 1.2326354001249586, 2.6262253863470892, 58.89092322758266, 72.52494253431047, 77.76429421561105, 72.18803133283342, 69.34497438158307, 87.84376798357282, 89.5250791822161, 87.9650696345738, 79.28508118220738, 80.16584873199463, 75.20534910474504, 73.24436596461705, 72.7749526160104, 72.58724008287702, 72.39986106327602, 74.68956347874233, 70.68041815076555, 76.25987025669643, 67.88190610068185, 71.15496621813092, 78.56337179456438, 68.93758760179792, 69.10546997615269, 76.23586423056466, 77.98687280927385, 74.82971559252057, 76.09305095672607, 73.89462702614921, 74.8824246270316, 76.86744158608573, 74.38327298845563, 79.30869116101945, 75.66884953635079, 74.09209483010429, 71.41525268554688, 67.82609816959926, 69.08654308319092, 69.76316561017717, 68.19351891108921, 72.5533606665475, 67.66440664018903, 64.02198723384312, 54.75872530255999, 49.42518384116036, 58.30169514247349, 70.00178064618791, 62.87747301374163, 53.53926086425781, 61.30893802642822, 69.70951162065778, 73.33209392002651, 69.89523002079555, 64.2510415485927, 66.39214284079415, 70.18286459786552, 68.43366949898856, 68.0233575275966, 68.59183134351457, 71.02281842912946, 68.00159576960972, 70.05653939928327, 71.43249811444963, 72.41583497183663, 69.82088429587228, 72.47970976148332, 75.3201402936663, 65.02526542118618, 64.93027659824916, 70.13442175728935, 64.81812572479248, 65.41866547720772, 62.49228572845459, 61.17377471923828, 55.80152831758772, 61.970052174159456, 61.03704111916678, 54.214542388916016, 45.78855228424072, 46.246382985796245, 40.399512086595806, 44.89516333171299, 38.91031857899257, 33.02958563395909, 34.35983909879412, 38.00793865748814, 48.58995131083897, 81.25283881596157, 59.76526369367327, 43.76714413506644, 26.7012288911002, 19.491312503814697, 15.92610842841012, 1.9704131484031677, 0.1579894559191806, 0.2642487862280437, 0.04043946235573717, 0.15529633685946465, 0.198167387130005, 0.6761076003313065, 0.1267758679709264, 0.2604407662791865, 0.12236296119434492, 3.8744080322129384, 13.049067837851387, 57.0681779725211, 61.58775533948626, 74.41423416137695, 56.21654421942574, 55.313201972416465, 63.90350655147007, 27.868792022977555, 33.855674334934776, 33.611917631966726, 46.99228947503226, 63.030201366969514, 57.5567752974374, 49.699679374694824, 6.6020554048674445, 0.10080326415066208, 0.04507048760673829, 0.05182227745120015, 0.019056415118809258, 0.030274800823203156, 0.07320232556334563, 0.10547246038913727, 0.16283121039824827, 0.08499837866319077, 0.08516707603952714, 0.09073508690510478, 0.08869081017162118, 0.0694255114399961, 0.016671456130487577, 0.0074001147877424955, 0.029430740579430546, 0.06541387670274292, 0.04141070041805506, 0.04015894240832754, 0.02145641722849437, 0.015938831692827598, 0.058950742440564294, 0.05883701318608863, 0.0665616797549384, 0.039546296532664976, 0.03988373199743884, 0.03458915038832596, 0.040674683305301836, 0.029905341898224184, 0.07790538748460156, 0.14674381007041248, 12.765461478914533, 80.77474021911621, 74.19429588317871, 77.53972148895264, 87.03756155286516, 60.24140289851597, 24.77831666810172, 56.96456296103341, 60.3063268661499, 101.01690632956368, 103.81243065425328, 100.96523257664272, 22.714267424174718, 0.6558043669377054, 0.07005373987236194, 0.27979760617017746, 0.0592886053823999, 0.9997507823365075, 0.3492991610297135, 0.21179489445473465, 0.13747283683291503, 0.5491886021835464, 0.103102106867092, 2.974601984024048, 2.4937998865331923, 1.1821137453828539, 3.239115996020181, 72.07451861245292, 76.60069329398019, 81.88324192592076, 81.0191570009504, 76.92581340244838, 91.89745821271623, 93.172424861363, 88.50752244676862, 82.76575347355434, 82.47689601353237, 81.033602305821, 81.29390961783272, 77.10999625069755, 75.54227420261928, 75.67863259996686, 78.6737369809832, 74.02888706752232, 80.77446229117257, 74.5626129422869, 73.05908530099052, 82.03772122519356, 75.4328053338187, 74.48182623726981, 80.28969342367989, 78.56640120915004, 78.94637734549386, 80.68168994358608, 78.53552341461182, 77.78590311322893, 79.06378105708531, 77.6082376752581, 78.15068353925432, 77.75847857339042, 77.09845529283795, 71.49189826420375, 70.46430138179234, 70.90706838880266, 73.09826619284493, 72.54768398829869, 73.29569230760846, 70.40583229064941, 65.28993620191301, 57.49578401020595, 54.23986162458147, 62.60804966517857, 66.28063814980644, 64.01910373142788, 57.424113341740195, 60.77649062020438, 69.2316701071603, 73.63429192134312, 72.7733267375401, 67.4692803791591, 71.08708926609584, 70.80702822549003, 70.13264996664864, 69.5769121987479, 70.68064049312046, 72.56670120784214, 70.82305077144078, 70.25607081821987, 72.74139976501465, 73.4621364048549, 72.25500501905168, 73.57055609566825, 77.60768181937081, 72.38071877615792, 66.65832138061523, 71.65559087480817, 68.33131558554513, 70.68816539219448, 68.70788015638078, 63.30268887111119, 61.016293798174175, 61.86466884613037, 63.617046219961985, 61.61564540863037, 55.111162253788535, 55.59841857637678, 54.37348590578352, 55.7402834211077, 56.52490874699184, 52.81325054168701, 48.62704079491751, 53.20710570471627, 49.057620661599294, 72.07976450238908, 83.14299896785191, 68.61460753849575, 53.671012605939595, 37.85422018596104, 21.42949513026646, 3.952974787780217, 0.07333617338112422, 0.2915005167680127, 0.06750914534287793, 0.16415828918772085, 0.15512689309460775, 0.5409561267920903, 0.04727461701259017, 0.35994770963277134, 0.33073533858571735, 3.173592529126576, 14.884656838008336, 66.42921148027692, 67.95884350367955, 79.29072311946324, 66.63300909314836, 38.278835024152485, 26.09681030682155, 35.07792847497122, 46.53677599770682, 46.243141651153564, 61.79553427015032, 72.35778277260917, 64.5048383985247, 65.326066834586, 7.068072387150355, 0.11824711704892771, 0.051629040855914354, 0.042167562126581154, 0.016943759018821374, 0.05165592102067811, 0.03888930160818355, 0.06231242883950472, 0.04068763314613274, 0.05993293545075825, 0.040079519884394746, 0.04319953585841826, 0.04136763719309654, 0.06162655207195452, 0.046487448537456136, 0.015012300606550915, 0.08543202360825879, 0.14757388910012587, 0.1178930439054966, 0.10571591196847813, 0.11306773032993078, 0.12826213107577392, 0.10754177506480898, 0.25459760267819675, 0.18959668917315348, 0.17838630000395433, 0.145599135064653, 0.16877536715141364, 0.18611602165869304, 0.12007703099931989, 0.3076257657791887, 0.3023859555167811, 18.125928946903773, 99.46392141069684, 84.94543811253139, 97.49399593898228, 102.09785842895508, 71.29526424407959, 81.35431725638253, 96.472291128976, 68.79620565686906, 115.71633461543492, 111.93935639517647, 112.04003579275948, 33.07478713989258, 1.2582206215177263, 0.34159255027770996, 0.6493986706648553, 0.22497090457805566, 2.7935933768749237, 1.9361246568816048, 0.6312678349869592, 0.33643353996532305, 1.507292696407863, 1.5901521359171187, 11.545211025646754, 14.400208456175667, 5.426104494503566, 3.595184249537332, 78.5624337877546, 83.39311327253068, 92.56452696663993, 86.84943212781633, 85.42512089865548, 95.00773593357631, 98.26693439483643, 92.53072398049491, 89.19270515441895, 88.12268951960972, 86.38129029955182, 84.5478413445609, 80.76699992588588, 79.61227880205426, 81.31985419137138, 83.6326732635498, 78.08954633985246, 86.66281046186174, 78.55941826956612, 79.58599376678467, 87.91067218780518, 80.28976290566581, 77.93604673658098, 83.99511909484863, 83.49259063175747, 83.08655180249895, 84.07220935821533, 83.49975422450474, 79.57225022997174, 84.01742976052421, 78.95551422664097, 82.45228549412319, 79.29161943708147, 77.44416291373116, 73.10642337799072, 71.35865265982491, 70.73635114942277, 72.1327931540353, 73.37777832576207, 74.42722729274205, 67.9969960621425, 65.94225393022809, 62.14741883959089, 59.347822870527, 61.91238907405308, 71.85053648267473, 62.83246258326939, 56.10187462397984, 61.15850952693394, 73.21487086159843, 77.09402929033551, 76.3187562397548, 71.64529364449638, 74.38756002698625, 73.51123237609863, 73.96290697370256, 71.99409321376255, 75.54538699558803, 75.2937788282122, 72.33820274897984, 72.72231306348527, 76.67574773515973, 77.57991681780133, 77.70852797372001, 77.83843844277519, 81.20525755201066, 74.74129281725202, 72.64718914031982, 77.1191053390503, 73.5196257999965, 77.18990053449357, 72.11947345733643, 67.83364391326904, 67.26398890359062, 68.72905826568604, 69.17446558816093, 65.81389985765729, 60.90505313873291, 60.973235811506, 56.311536516462056, 56.60338517597744, 58.883009229387554, 59.237749508449006, 60.27571310315813, 59.852324622017996, 58.16409649167742, 68.77599334716797, 71.72533689226422, 67.348235811506, 57.226471832820344, 45.16953379767281, 27.929272617612565, 3.321670583316258, 0.28444757951157434, 0.6158803978136608, 0.22872158831783704, 0.26180074044636314, 0.4141928388604096, 0.8210938147136143, 0.13243845983275346, 0.40827647490160807, 0.5455656051635742, 7.425143786839076, 27.12596705981663, 82.92224080221993, 75.80543722425188, 93.75856794629777, 72.85129247392926, 88.47647789546421, 83.60321984972272, 42.29915305546352, 47.30346802302769, 47.256463459559846, 61.595641544886995, 85.52054050990513, 73.44304970332554, 84.06281539372036, 11.432172519820076, 0.15691496857575007, 0.11458689559783254, 0.1468725824462516, 0.1010314758334841, 0.12327237453843866, 0.16534263135067054, 0.109255795234016, 0.2177037266748292, 0.13529684288161142, 0.1797033907579524, 0.14806863612362317, 0.20180285562361988, 0.2564796416887215, 0.14563108049333096, 0.087553605836417], [0.08828973490744829, 0.01080177622913782, 0.081889887606459, 0.025091900989147167, 0.020392688057784523, 0.048732904118618796, 0.049098688776471784, 0.014821876538917422, 0.09284795674362353, 0.04626938773851309, 0.04129630619926112, 0.0061250122047827715, 0.04275508863585336, 0.03830760032204645, 0.11718230561486312, 0.1342363605009658, 22.484481811523438, 70.33506488800049, 65.9425527027675, 59.49314444405692, 40.66873741149902, 49.50530351911272, 69.18611771719796, 38.72579526901245, 73.44537734985352, 83.58206953321184, 95.0580061503819, 31.19513613837106, 0.5028851010969707, 0.1693046244659594, 0.08713799635214464, 0.05864199543637889, 0.07288610110325472, 0.10381007673484938, 0.603557496198586, 0.016994840831362774, 0.23227363771625928, 0.15038225054740906, 0.780479585485799, 0.8285698049834797, 1.0970346821205956, 1.4745672238724572, 26.394071613039287, 87.80897835322789, 70.17459624154228, 75.07035255432129, 80.43812779017857, 82.5346702848162, 83.56222547803605, 80.18320533207485, 78.85110364641461, 77.22474575042725, 75.00112070356096, 71.5485052381243, 72.2681440625872, 68.59014987945557, 72.97738838195801, 75.51392555236816, 78.20663043430874, 73.72614710671562, 76.90166841234479, 75.24022211347307, 69.01881899152482, 74.13369369506836, 72.2690542766026, 71.90829685756138, 69.72683347974504, 72.8971505846296, 76.69486917768205, 77.6417488370623, 74.04208864484514, 71.61424909319196, 72.29475566319057, 75.27305235181535, 73.42344188690186, 75.99645709991455, 74.55688762664795, 74.52156298501151, 72.89186995370048, 72.14235387529645, 72.83531856536865, 73.70189789363316, 76.0349223273141, 74.54176139831543, 72.46978078569684, 61.15930162157331, 51.161132199423655, 63.085015705653596, 63.96314293997628, 52.155280453818186, 64.03924655914307, 59.23121125357491, 66.34882777077812, 66.62109293256486, 66.16077477591378, 65.47407736097063, 65.90289238521031, 65.45041874476841, 67.89811624799455, 68.59175491333008, 71.74893992287772, 71.49168981824602, 74.39962904793876, 75.89569432394845, 74.76868956429618, 75.89804976327079, 73.65216268811906, 70.51532895224435, 71.97006634303501, 74.60467733655656, 64.46943732670375, 67.21142578125, 70.25702272142682, 67.66044616699219, 65.34196431296212, 56.458188670022146, 56.63925525120327, 55.88603230885097, 57.550615719386506, 60.94886153084891, 59.15181418827602, 51.98369468961443, 50.09100539343697, 49.488294328962056, 51.15878023420061, 49.568761416843955, 36.810694558279856, 38.77840008054461, 38.217968804495676, 49.52408797400338, 80.1282937186105, 64.26154027666364, 44.81996645246233, 27.83297232219151, 19.733281782695226, 14.978542634419032, 0.5206960482256753, 0.3230481067938464, 0.2954637041049344, 0.06377380327986819, 0.13922834263316222, 0.35713292924421175, 0.7237744139773505, 0.06782716792076826, 0.17619985661336354, 0.919883519411087, 1.735969854252679, 12.78428588594709, 64.41665186200822, 65.52965600149972, 67.9785485948835, 46.44149882452828, 65.90181541442871, 40.112878050122944, 25.28601632799421, 30.40206527709961, 20.271173102515085, 35.29106099264962, 57.82925932747977, 54.76701102937971, 61.27258505140032, 3.4828149420874457, 0.12771889593984398, 0.011062062262291355, 0.08986472325133425, 0.02051834935056312, 0.06340183038264513, 0.04070665926805564, 0.16866864716368063, 0.08395402505993843, 0.06418329916362252, 0.04970781644806266, 0.04695226538128086, 0.06070409049945218, 0.06570772986326899, 0.022888533238853728, 0.10343592574021646, 0.03365412913262844, 0.02334143840042608, 0.02474031298022185, 0.0663624279467123, 0.08755034886832748, 0.07723692871098008, 0.03345747611352375, 0.031351004860230854, 0.04925086382510407, 0.017523193997996192, 0.07201918440737895, 0.0749603012310607, 0.07523645819830042, 0.07213268295994826, 0.24007296349321092, 29.561948163168772, 82.6318130493164, 77.09723240988595, 79.63715335300991, 57.968098231724326, 57.35276229040963, 55.00050524302891, 43.696286405835835, 81.81947135925293, 93.10235227857316, 103.74909782409668, 36.81630522864205, 0.7223802145038332, 0.05804642489446061, 0.1564759835600853, 0.032322097037519724, 0.015130319898681981, 0.06995538622140884, 0.7248481820736612, 0.08969960853989635, 0.25503639770405634, 0.12165158508079392, 0.15617027639278344, 0.941205478140286, 0.4754360797149794, 1.0601625463792255, 31.838935375213623, 93.92023863111223, 72.24363081795829, 79.33805424826485, 82.43193422045026, 87.27277891976493, 85.10776192801339, 85.77954850878034, 82.45983123779297, 80.8183957508632, 75.23608098711286, 74.26067202431815, 75.34191594805036, 74.40409673963273, 75.90484510149274, 77.58275168282645, 80.05799184526715, 79.62918376922607, 78.64408901759556, 80.46093872615269, 74.32417161124093, 75.35406139918736, 75.80912671770368, 77.22119522094727, 74.98592499324253, 77.58124392373222, 80.37863731384277, 81.6541667665754, 75.3633372443063, 74.4961186817714, 76.81068869999477, 76.28892762320382, 75.83736419677734, 76.10580784933907, 76.40667179652623, 74.3049042565482, 76.09326635088239, 74.50560992104667, 73.33011368342808, 76.76059913635254, 80.19808837345668, 74.13907160077775, 73.11232934679303, 65.04750660487584, 55.95814766202654, 66.2505246571132, 67.48778343200684, 54.745370864868164, 66.83251271929059, 60.47984422956194, 65.9705330984933, 68.0511086327689, 66.79857771737235, 68.24369185311454, 69.45830644880022, 68.16765771593366, 70.73975576673234, 69.62437534332275, 72.96185915810722, 72.82454885755266, 74.05860451289585, 75.84618146078927, 74.39885084969657, 73.79763712201799, 73.77697317940849, 74.09188638414655, 73.43432971409389, 73.63978099822998, 71.72993659973145, 70.8982789175851, 71.84912599836076, 70.69080570765904, 67.98430170331682, 64.3407288960048, 61.875709533691406, 58.14861937931606, 61.94721344539097, 63.657436098371235, 62.346040044512065, 57.54358066831316, 55.42757626942226, 54.38973426818848, 56.30370242255074, 62.85187585013253, 57.09504318237305, 51.79104198728289, 52.13255637032645, 49.5251475742885, 71.13782501220703, 85.96013219015938, 70.08112907409668, 57.47409520830427, 36.989614146096365, 20.91339683532715, 2.068217077425548, 0.13681188944194997, 0.44532375410199165, 0.11615049812410559, 0.09767821005412511, 0.13375503490013735, 0.6026328429579735, 0.051915172287928205, 0.2234043843512024, 0.2537548893264362, 2.2585362706865584, 16.053375107901438, 73.31624507904053, 69.23982729230607, 74.68444265638078, 56.105842045375276, 39.662071977342876, 23.8264707837786, 35.70443017142159, 42.54320158277239, 36.71662637165615, 51.40009811946324, 70.09536593300956, 63.04468836103167, 74.95111451830182, 3.1015536061355045, 0.16824422350951604, 0.04332063061052135, 0.0831646988434451, 0.03296213197921004, 0.04332081720765148, 0.00835255064469363, 0.013187649543397129, 0.04413389214979751, 0.028674984882984842, 0.033147758804261684, 0.042947378674788136, 0.00925709804453488, 0.026883352182007263, 0.0438582780105727, 0.13655551177050385, 0.27187937391655786, 0.20856206864118576, 0.16308936583144323, 0.17860765169773782, 0.24521283911807196, 0.15971577114292554, 0.0816854585760406, 0.3158996860895838, 0.24796272441744804, 0.09766913125557558, 0.21130336368722574, 0.1587803563369172, 0.14495810946183546, 0.31336446212870733, 0.3315889627805778, 40.0040796824864, 97.29301234654018, 88.43487903050014, 81.86036845615932, 52.964384283338276, 72.42286654881069, 98.41350664411272, 56.33397224971226, 95.49137919289726, 102.11642401559013, 109.16491985321045, 56.08609873907906, 1.2512972844498498, 0.30736452979700907, 0.3528538702854088, 0.16074376526687825, 0.6274122904453958, 0.4425685762294701, 1.8663204482623508, 0.568598992058209, 0.7601866658244814, 0.47338321272815975, 2.777007592575891, 2.4759936077254157, 3.9218229736600603, 3.0640737201486314, 37.166126183101106, 97.89617851802281, 77.66865226200649, 85.1387995311192, 88.88984707423619, 90.19904054914201, 89.79701777866909, 92.46959372929165, 87.78685528891427, 86.07931464059013, 81.65282576424735, 80.81191308157784, 80.37780353001186, 79.44651562826974, 80.61869062696184, 81.7330288205828, 84.09146281651088, 83.74560233524868, 84.77122592926025, 85.24216788155692, 79.3047376360212, 82.10932935987199, 80.40071174076625, 81.80948679787772, 77.04596860068185, 79.1514812197004, 82.81372383662632, 85.53333214351109, 78.33492197309221, 76.73136111668178, 74.51881149836949, 79.09072617122105, 77.82272161756242, 77.07131562914167, 81.45777593340192, 78.14496517181396, 78.1772187096732, 77.61672837393624, 75.66540322984967, 77.80166162763322, 81.53863906860352, 76.97267205374581, 73.48260579790387, 65.37683037349156, 54.150949001312256, 71.47365924290249, 75.7557020187378, 57.82610831941877, 64.62919725690568, 59.53848838806152, 66.55477237701416, 69.12780148642403, 67.79415730067662, 70.66835607801164, 69.73251015799386, 70.61058180672782, 71.84973743983677, 72.30232919965471, 76.03464439937046, 76.5139867237636, 76.9520845413208, 80.63999380384172, 79.2120556150164, 77.12066868373326, 78.02039786747524, 77.30196108136857, 78.87036405290876, 77.47828551701137, 72.94646195002964, 77.54509244646344, 73.6626683643886, 75.13779176984514, 73.48698316301618, 69.81600666046143, 64.28467082977295, 63.74545587812151, 66.54003524780273, 68.57348809923444, 69.72745881761823, 65.04493577139718, 62.54698889596121, 60.17841747828892, 59.556901114327566, 65.16816902160645, 61.04856818062918, 61.28481388092041, 58.01440102713448, 59.23144054412842, 67.63878168378557, 75.50932584490094, 70.26424189976284, 59.894507135663716, 43.73523105893816, 26.693655354636057, 1.476298736674445, 0.5336214889373098, 0.5748167612722942, 0.14759390588317597, 0.1811791637114116, 0.960536886538778, 1.311234399676323, 0.19704054402453558, 0.42347907913582666, 2.2237868096147264, 3.640215741736548, 30.265022482190812, 84.6190047945295, 80.86694976261684, 83.4274651663644, 71.03975118909563, 101.272294316973, 55.214950970241, 36.51317616871425, 41.301725251334055, 34.266733237675254, 53.263670989445274, 81.21005875723702, 71.762864112854, 91.57342202322823, 5.730655329568045, 0.28126117906400133, 0.16575731124196733, 0.25057739125830786, 0.16210808205817426, 0.16986647860280105, 0.10209499126566307, 0.26374319621494835, 0.30496210870998247, 0.14058347206030572, 0.11259737664035388, 0.15935066502009118, 0.12106785497495107, 0.24572830860103878, 0.12247509589152676], [0.09248719324490853, 0.035454028086470704, 0.03292285158698048, 0.01711011036033077, 0.09795649762132339, 0.06396139107112374, 0.044613039653216086, 0.08107523167771952, 0.02349613929566528, 0.011311189787063216, 0.06999022899461643, 0.0355802932754159, 0.03340068273246288, 0.05705024049218212, 0.053490801847406795, 0.14740243687161378, 28.99076107570103, 62.673939432416645, 58.770177432468955, 48.099960872105186, 41.20121261051723, 35.6316408429827, 16.892687967845372, 59.307731764657156, 78.05119228363037, 90.3619132723127, 59.34029797145298, 1.6970276981592178, 0.5158146130187171, 0.12027011492422648, 0.10922628574605499, 0.13057627475687436, 0.11600453167089395, 0.06002221708851201, 0.38105535986168043, 0.22031696859214986, 0.3927937171288899, 1.4644037463835307, 0.746151684650353, 0.3311100799058165, 1.2641916211162294, 1.47673191343035, 50.84034081867763, 62.597078459603445, 73.25576101030622, 66.52187960488456, 76.3362934929984, 80.44383226122174, 83.83409459250313, 79.59357425144741, 79.56840092795235, 74.51785264696393, 71.07488128117153, 71.43124049050468, 70.5846163885934, 71.46115248543876, 73.27931540352958, 76.89489391871861, 78.24148954663957, 76.84322711399624, 77.6671028137207, 81.09136962890625, 70.29940673283168, 68.1410322189331, 71.81593445369175, 71.66550595419747, 71.74183191571916, 71.47189440046037, 70.9134885243007, 74.77132987976074, 72.44790785653251, 74.645233971732, 76.13571289607457, 76.29661233084542, 74.09984901973179, 71.25620147160122, 72.67990820748466, 71.60154778616769, 68.96367113930839, 68.54784229823521, 68.61903354099819, 73.46441541399274, 74.47585078648159, 74.69353090013776, 74.74234199523926, 75.15906020573208, 68.01096888950893, 58.98102746691023, 44.91276659284319, 57.509961809430806, 71.94328798566545, 63.95280402047293, 65.70978110177177, 69.79789270673479, 66.38540308816093, 66.3556717463902, 69.14572783878872, 66.02546555655343, 66.80849974496024, 67.46149144853864, 68.78964655739921, 66.83972494942802, 63.651620456150596, 66.46498775482178, 68.75655228751046, 69.97869873046875, 67.37078271593366, 70.66253348759243, 69.03688430786133, 68.82788249424526, 73.56814507075718, 62.52723516736712, 66.89326081957135, 68.99042865208217, 64.02824061257499, 65.34761319841657, 58.501164027622764, 58.84438419342041, 54.86410168239048, 58.64315741402762, 56.06615046092442, 52.31016274860927, 45.725080490112305, 44.11495706013271, 46.02473892484392, 56.27703176225935, 53.99617092950003, 38.62489005497524, 40.03653819220406, 40.74758209500994, 51.27097627094814, 89.00038596561977, 64.95248998914445, 45.0700877053397, 29.187916210719518, 22.88311559813363, 9.969119003840856, 0.49518758271421703, 0.48425622071538654, 0.19229173527232238, 0.15859451916600975, 0.2744511844856398, 0.24972922248499735, 0.16910566442779132, 0.06325841522110359, 0.18524818894054207, 0.584333242050239, 0.12387367870126452, 25.001984391893657, 57.9256134714399, 64.75097138541085, 60.48028196607317, 40.971074376787456, 65.83296571459088, 40.202033860342844, 27.788564647947037, 28.835654701505387, 48.36907155173165, 45.017045157296316, 54.427765233176096, 61.13204383850098, 41.9319338117327, 0.4003022770796503, 0.02016501920297742, 0.0533495274638491, 0.05377046005534274, 0.03934538570631828, 0.022221504477784038, 0.06985469162464142, 0.102377268618771, 0.05583433288016489, 0.03612233079703791, 0.10870078073016234, 0.021396092072661434, 0.08330574591777154, 0.12216995869364057, 0.044985358603298664, 0.03730463056958147, 0.05989222334963935, 0.021269353605540733, 0.02737624171589102, 0.08912221595112767, 0.050881183307085714, 0.08168989619506256, 0.04530571194897805, 0.04642111834670816, 0.054463617503643036, 0.027940606432301656, 0.043400623103869815, 0.030996107296752076, 0.04728700366935559, 0.11560967857284205, 37.41082436697823, 72.1358642578125, 72.42044162750244, 62.14360427856445, 48.811126368386404, 46.34991461890084, 23.538676398141043, 66.45592730385917, 89.12304251534599, 99.59658336639404, 71.16430459703717, 0.8147140113370759, 0.3656801091773169, 0.09599912086767809, 0.17635798241410935, 0.07042606560779469, 0.14684755807476385, 0.2427181372685092, 0.23801119412694657, 0.24553012209279196, 0.3158918965075697, 3.2245035001209805, 0.9719783983060292, 0.25980185770562714, 1.3567079710108894, 2.41604802438191, 60.837697301592144, 68.92986815316337, 78.5581328528268, 71.25495774405343, 79.1557126726423, 82.0902635029384, 89.28057902199882, 84.47470460619245, 82.38822310311454, 77.91238117218018, 77.00994913918632, 73.95045580182756, 75.30531978607178, 75.35817473275321, 76.1397567476545, 79.95884799957275, 80.48020608084542, 78.17292472294399, 78.31942749023438, 83.03735855647496, 73.1212716783796, 71.33892672402519, 77.57540048871721, 78.28186552865165, 75.37525340488979, 71.79605565752301, 70.82446125575474, 74.76984296526227, 78.03282819475446, 79.14038494655064, 80.40585340772355, 77.19282572610038, 78.48120934622628, 74.82909025464738, 75.3624826158796, 71.48913982936314, 71.83446529933384, 69.7749775477818, 72.37231840406145, 76.0366941179548, 75.49085753304618, 75.30771691458565, 75.03172057015556, 79.28094005584717, 72.3768138885498, 67.15735489981515, 57.96014601843697, 67.09591892787388, 74.46309389386857, 65.4113768168858, 68.18416663578579, 70.17540223257882, 68.95823069981166, 68.22456346239362, 72.88040542602539, 70.6819953918457, 69.58547237941197, 70.88480636051723, 69.65330069405692, 68.08895547049386, 67.59084606170654, 66.22919368743896, 68.31906591142926, 69.4647057397025, 68.21135493687221, 69.5620777947562, 71.42708546774728, 71.96714115142822, 75.13440799713135, 66.2386223929269, 65.84090750558036, 71.6127621786935, 68.32815415518624, 69.99023968832833, 66.05320276532854, 63.398747716631206, 57.906707423073904, 61.401626995631624, 60.215784890311106, 58.731802531651084, 55.38176679611206, 51.41981710706438, 48.85207557678223, 55.474500928606304, 62.33667387281145, 60.89479759761265, 52.137423583439414, 52.341248989105225, 50.87722533089774, 77.08455889565604, 89.52673980167934, 69.57450812203544, 55.17620086669922, 35.87703384671892, 13.053057840892247, 0.7252555744988578, 0.20693438526775154, 0.20073072958205426, 0.19750557121421608, 0.08796110682721649, 0.013637926229940993, 0.38251497011099544, 0.04630677162536553, 0.2672182454594544, 0.4364870297057288, 0.22046255506575108, 29.067602940968104, 68.45015757424491, 70.85640907287598, 70.60669776371547, 46.86365400041853, 25.463304826191493, 22.252246958868845, 33.524106298174175, 42.2536666733878, 56.71295479365757, 59.21122823442732, 63.85591833932059, 68.11904117039272, 50.43640381949288, 0.48057085275650024, 0.039905777600194724, 0.028586595518780605, 0.039403522586716075, 0.036873614947710714, 0.020501738813306605, 0.0411612709451999, 0.06478254057999168, 0.02714076292301927, 0.020695336728489826, 0.07678830849805049, 0.0408928357064724, 0.03672500220792634, 0.06364973993705851, 0.20177713914641313, 0.1698745803109237, 0.10536099744162389, 0.12298098446003028, 0.15112315650497163, 0.1469419151544571, 0.13464444503188133, 0.11692655219563416, 0.1302040033042431, 0.11630945173757416, 0.22678679999496254, 0.1246941089630127, 0.22454107978514262, 0.13081540406814643, 0.16987971003566468, 0.392863361963204, 50.23012917382376, 85.82813031332833, 80.73102910178048, 65.49705505371094, 57.22526979446411, 50.19843149185181, 26.332680804388865, 82.66266999925885, 102.36948435647147, 105.20398112705776, 85.56272302355084, 6.040077720369611, 1.3886452572686332, 0.4130486931119646, 0.591173743563039, 0.5220425873994827, 0.30650897856269566, 0.2887141534260341, 1.5596519325460707, 0.8588215016892978, 0.8622323072382382, 4.614995241165161, 1.3501490886722292, 1.3476549025092806, 5.684644358498709, 3.094991249697549, 72.11403996603829, 76.82909447806222, 82.13744871956962, 79.32231657845634, 85.75941957746232, 86.03638866969517, 91.30498531886509, 90.49356773921421, 88.07393401009696, 82.6920747756958, 80.47286183493478, 78.24579048156738, 79.59713867732457, 79.89896147591728, 82.56408895765031, 84.63610431126186, 85.44667421068463, 82.87374932425362, 83.51491519383022, 87.7779963357108, 81.36361394609723, 77.6312084197998, 81.54086944035122, 84.50897312164307, 77.86989988599504, 74.58235277448381, 73.69015543801444, 76.33251367296491, 78.47924300602504, 82.68502930232457, 83.4106227329799, 80.17252595084054, 81.42409106663295, 77.72008282797677, 78.61448969159807, 74.51218291691372, 74.86944539206368, 72.24228286743164, 75.55107757023403, 77.9316554750715, 79.78996508462089, 78.89041655404228, 78.95944690704346, 82.61502620152065, 73.05122688838414, 67.54282011304582, 59.02518326895577, 63.782976150512695, 74.9470637185233, 65.50519139426095, 68.53651673453194, 71.68971347808838, 71.60927418300084, 73.22612694331578, 76.50127152034214, 71.3415948322841, 72.26800509861538, 71.47228349958147, 73.97683811187744, 69.65957491738456, 68.37964725494385, 69.78078624180385, 72.6651224408831, 73.97084181649345, 73.30110495431083, 74.70829582214355, 74.3354902267456, 75.11461952754429, 78.87826415470668, 70.21311010633195, 74.40406894683838, 75.73683765956334, 72.02231679643903, 75.99345547812325, 71.46669019971574, 68.06607505253383, 64.70503684452602, 68.2650784083775, 67.64229052407401, 65.34803703853062, 63.65836715698242, 60.34058148520333, 56.443823269435335, 65.00251007080078, 66.45111915043422, 62.41820403507778, 59.130886214120046, 60.12568065098354, 56.81403718675886, 74.68756934574672, 80.71816798618862, 72.15163666861397, 60.47936480385916, 45.170635087149485, 15.93256504195077, 0.7678997090884617, 0.6651673902358327, 0.3050161472388676, 0.350311209580728, 0.340541770947831, 0.3755302391946316, 0.36898310908249443, 0.1262720421488796, 1.6910821029118128, 0.8787499666213989, 0.7790929856044906, 38.35994829450335, 78.0154229572841, 83.84786592211042, 77.42718846457345, 64.54084396362305, 95.76170580727714, 54.24938760484968, 42.12532649721418, 42.03688287734985, 59.80857876368931, 60.77767876216343, 75.50612967354911, 78.82402651650565, 63.7990334374564, 0.4313136344509465, 0.19727778700845583, 0.1653240259204592, 0.13539803959429264, 0.1487281857324498, 0.10466387734881469, 0.20003231348735945, 0.2656462426696505, 0.27812002333147184, 0.1903785379337413, 0.2394199956740652, 0.1444346604070493, 0.17095639583255562, 0.13309857941099576], [0.018764265081179992, 0.020619775068813136, 0.07007889316550323, 0.03734518660764609, 0.06261840742081404, 0.016428435420883552, 0.07347872680319206, 0.0523245799621301, 0.01035800838976034, 0.0374026619164007, 0.04356052327368941, 0.02549373112352831, 0.029513308113174777, 0.11972333783549921, 0.08049335397247757, 2.4294243923255374, 47.83564444950649, 67.34921550750732, 56.89813470840454, 61.55631474086216, 52.809797286987305, 50.250265053340364, 38.9088316644941, 49.84346539633614, 75.92711407797677, 59.67181737082345, 6.460965718541827, 1.3292478216545922, 0.24135422759822436, 0.11265464499592781, 0.07174553801970822, 0.21673386943127426, 0.1546684612653085, 0.2278330059988158, 0.209893028650965, 0.07899572540606771, 0.2888600384550435, 3.374133608170918, 0.650029871080603, 0.5848060995340347, 0.3068148892905031, 23.352933679308208, 60.19837270464216, 61.00839369637625, 57.4729904447283, 60.28267519814627, 74.89758559635708, 81.71121842520577, 79.20494760785783, 76.95617008209229, 75.47070775713239, 74.68599210466657, 72.74358149937221, 71.81210599626813, 72.93100220816476, 75.76822962079729, 73.41162300109863, 75.7775193623134, 74.83933189937046, 76.3266771861485, 76.3720280783517, 75.66366618020194, 65.94043350219727, 66.81654575892857, 76.69627271379743, 70.8510937009539, 71.62239933013916, 66.98863874162946, 71.63780348641532, 74.11595494406563, 77.51933547428676, 71.91247967311314, 72.40275846208844, 69.03707885742188, 70.74584238869804, 72.36675984518868, 72.63981015341622, 73.70136288234166, 70.13002354758126, 69.76236656733921, 71.06325694492885, 69.49825859069824, 67.77127688271659, 71.20975276402065, 70.36947236742292, 73.42078072684151, 72.57701928274972, 72.17086928231376, 72.2591391972133, 72.3705883026123, 65.13430350167411, 61.215151241847444, 65.6036126273019, 65.55735846928188, 67.42135865347726, 68.13429941449846, 64.39901733398438, 66.18038954053605, 63.72674437931606, 65.38573101588658, 67.13093784877232, 67.98405851636613, 69.19727652413505, 69.28576183319092, 67.15732710702079, 67.28172765459333, 69.04484694344657, 64.89286054883684, 63.62513392312186, 67.00263936179024, 71.48085757664272, 71.14351558685303, 63.4397976739066, 67.57584490094865, 67.98599011557442, 67.47799342019218, 60.67098222460066, 56.782596588134766, 55.005928312029155, 54.1732805115836, 51.03935807091849, 54.10606363841465, 52.72091245651245, 42.96464456830706, 41.313189779009136, 42.74126345770699, 46.71409402574812, 52.645034653799875, 42.3346757207598, 40.789375509534565, 39.35726145335606, 57.20593990598406, 93.57191848754883, 64.93705109187535, 43.96758924211775, 29.255014964512416, 18.377326931272233, 3.9441705516406467, 0.45360057854226654, 0.2340114473232201, 0.32362013895596775, 0.08034736037786518, 0.043154274179999313, 0.2753616156322615, 0.06458102925015347, 0.47955657861062456, 0.5170713141560555, 0.12057066522538662, 1.1713174389941352, 25.746690579823085, 43.18563549859183, 66.89839553833008, 56.989051886967246, 54.09794814246041, 70.02083260672433, 42.16001885277884, 32.406769956861226, 51.357780115945, 39.956199645996094, 48.51008176803589, 55.23595537458147, 66.70495768955776, 15.708334514072963, 0.8622117883392743, 0.3307810718459742, 0.16003456046538694, 0.07697983857776437, 0.009065780007014317, 0.04345963529444166, 0.05320682476407715, 0.08465456496924162, 0.11332976698343243, 0.018039788152756434, 0.0445612267191921, 0.08665735607168504, 0.07996956565018211, 0.05501522236902799, 0.012210477692341166, 0.05725300032645464, 0.013545279906663512, 0.016501891925664883, 0.023224448785185814, 0.018724984688950435, 0.04725469183176756, 0.05811921813126121, 0.07714311445930175, 0.020028379213597094, 0.03450716978737286, 0.02943351578765682, 0.08961854396121842, 0.11738283985427447, 2.6971552031380788, 55.90393781661987, 76.55176407950265, 71.79124055589948, 71.7908375603812, 57.277530670166016, 41.91157558986119, 24.403951202120098, 57.11447729383196, 85.11382075718471, 72.03936767578125, 6.926021243844714, 1.8145229305539812, 0.829536038850035, 0.16213188506662846, 0.15947227206613335, 0.09572075187627758, 0.18428842829806463, 0.09705025982111692, 0.06839171584163393, 0.2672464996576309, 0.31799858489206856, 7.428137591906956, 0.5701000743678638, 0.46721646934747696, 0.39003859353916986, 27.479831865855626, 71.03114931924003, 67.28403445652553, 67.0426331928798, 66.90376649584088, 80.38856628962925, 83.02692931038993, 83.29836763654436, 80.18506050109863, 79.14180932726178, 75.9921909059797, 77.41575867789132, 75.1253753389631, 74.86768054962158, 78.41588238307408, 79.34861551012311, 79.44088758741105, 76.1552790233067, 77.7902248927525, 78.00338867732457, 78.28315789358956, 72.0935914175851, 70.92465427943638, 78.64763259887695, 69.5345768247332, 74.40085193089077, 74.25480079650879, 75.7339402607509, 77.19963496071952, 80.33990805489677, 75.85733331952775, 75.35720893314907, 73.06752736227853, 72.28583417619977, 76.22402450016567, 76.44717284611293, 75.50941617148263, 73.40566839490617, 73.93999876294816, 73.24852098737443, 72.1121153150286, 70.55079950605119, 73.7131678717477, 72.21273912702287, 73.7485203061785, 74.9803386415754, 73.89212567465646, 75.0478959764753, 71.01603698730469, 66.50314031328473, 62.43656117575509, 68.02793639046806, 65.97340965270996, 67.49253599984306, 69.75600201742989, 69.76393686022077, 69.3191270828247, 70.04797227042062, 70.81392778669084, 70.21482631138393, 68.03348105294364, 69.68969535827637, 71.46021447862897, 68.3836772101266, 67.37632737840924, 69.73979187011719, 66.63102885654995, 64.32176031385148, 65.66639654976981, 71.92720290592739, 75.46079962594169, 69.02835886819022, 70.92751693725586, 71.36172376360211, 69.12125628335136, 69.23668670654297, 64.17419447217668, 62.657388823372976, 59.73146070752825, 60.37429414476667, 60.81635243552071, 61.242568833487375, 56.4665265083313, 53.63983603886196, 47.684809480394634, 46.771930830819265, 55.510885170527864, 63.835567065647666, 53.00921058654785, 53.46738174983433, 52.43835701261248, 81.03711114610944, 88.3226934160505, 71.59741360800606, 50.28431122643607, 30.23829276221139, 5.084627023765019, 0.4147627539932728, 0.14708762376436166, 0.1605127512344292, 0.04488283535465598, 0.021031432086601853, 0.1691378948411771, 0.4285810925066471, 0.9020533561706543, 0.5063586032816342, 0.10555997105049235, 0.9356766662427357, 31.695559297289165, 54.07217379978725, 74.62627928597587, 64.22820281982422, 56.033528668539866, 28.593711478369578, 23.672924280166626, 43.543089049203054, 75.06835842132568, 53.24080794198172, 63.03881713322231, 64.45972374507359, 77.20891775403703, 19.71021028927394, 0.8442809847848756, 0.30198613554239273, 0.14676838660878794, 0.07365147503358976, 0.14850451344890253, 0.04560762610552566, 0.07956604087459189, 0.10671172996184655, 0.040946453543646, 0.061810781114867756, 0.09911456012300082, 0.05090352746524981, 0.02888047582070742, 0.12855630314775876, 0.17953814033951077, 0.11659656704536506, 0.08805309581969466, 0.19290738366544247, 0.06561272817530803, 0.12910492585173675, 0.1396558332656111, 0.12348576023110322, 0.12603496201336384, 0.1585248200488942, 0.08570292871445417, 0.17328881924705847, 0.3067201929433005, 0.21694796080035822, 4.407962807587214, 69.46118995121547, 91.40301745278495, 79.4293327331543, 83.5331472669329, 72.61128085000175, 72.98451723371232, 53.90087638582502, 73.69720091138566, 95.34317411695207, 83.27915586744035, 14.147532871791295, 3.2054335176944733, 1.3695792917694365, 0.20541940656091484, 0.5292078629136086, 0.20679173006543092, 0.8722821165408406, 0.46200135775974815, 0.4100669116846153, 0.6335869591150964, 0.9721166023186275, 15.440978254590716, 1.9085405256067003, 0.6833554942693029, 1.396361123238291, 31.918919563293457, 81.35918794359479, 67.60162271772111, 74.76927321297782, 75.03625079563686, 87.07877131870815, 89.93783691951207, 86.56150572640556, 83.77248491559709, 85.83526611328125, 82.12871483394078, 82.59552955627441, 80.93828691755022, 81.71294852665493, 84.73882647923061, 83.0902065549578, 81.9287943158831, 81.38502829415458, 82.5928544998169, 83.26408522469657, 83.44571113586426, 76.87315995352608, 76.45223113468715, 84.91904885428292, 74.1534126826695, 78.62139620099748, 75.55251584734235, 76.69616849081856, 80.2621021270752, 83.40666225978306, 79.55894442967006, 78.77017102922711, 74.82717950003487, 74.46559524536133, 77.50858661106655, 78.04295172010148, 76.45594842093331, 76.02894687652588, 76.42664091927665, 76.69964953831264, 74.62397248404366, 73.06730501992362, 76.31224577767509, 75.37655966622489, 75.9194780077253, 78.09056077684674, 76.91971288408551, 77.82917649405343, 74.6616108758109, 67.66198171888078, 63.814583505902974, 70.26279667445591, 68.89633614676339, 69.47453049251011, 72.09029797145298, 73.20715836116246, 70.33463409968785, 72.41249288831438, 72.99557181767055, 73.10050351279122, 70.51389762333461, 72.89025797162736, 72.52264962877545, 71.55439036233085, 69.99484634399414, 72.28040068490165, 67.22206347329276, 67.28092166355678, 70.32209954942975, 77.93553951808384, 78.38115528651646, 73.80495357513428, 74.08737700326103, 75.08442265646798, 74.76035867418561, 73.51749270302909, 69.98625142233712, 66.90792846679688, 65.2491433279855, 64.89124856676374, 63.28389399392264, 65.98839691707066, 61.262121064322336, 57.65629781995501, 54.563508714948384, 56.981898716517854, 62.3570807320731, 64.42467008318219, 57.60298081806728, 58.356829098292756, 57.62575353894915, 81.07256085532052, 81.26554012298584, 74.64265619005475, 58.09624038423811, 37.16172797339303, 5.2830332687922885, 0.7281211635896138, 0.28395553305745125, 0.5495610364845821, 0.1033185798940914, 0.154444816123162, 0.49842473758118494, 1.148005147065435, 1.3697186900036675, 1.7961319174085344, 0.12432554231158324, 1.8956272985254015, 41.5004472051348, 64.56567682538713, 89.70398834773472, 76.54913071223667, 85.90349742344448, 105.54185812813895, 62.40208421434675, 47.410946232931956, 64.32724939073834, 55.12394346509661, 67.85477338518415, 74.41144793374198, 87.80492060525077, 23.044685534068517, 0.9603420112814222, 0.44555974858147757, 0.3204222305544785, 0.28781172899263247, 0.24734764599374362, 0.138601118432624, 0.25284714517848833, 0.20095650532415935, 0.24583174447928155, 0.16552681289613247, 0.17529030756226607, 0.23778391203710011, 0.12923829869500228], [0.05488360353878566, 0.04878070351800748, 0.09752369405967848, 0.025618276226201227, 0.046579081299049516, 0.053030836528965404, 0.02651074485454176, 0.03225681518337556, 0.09801724007619278, 0.021767131984233856, 0.008887394846949195, 0.04782099376565643, 0.02972155051039798, 0.08162554393389396, 0.2244243581912347, 8.55366325378418, 66.688323702131, 62.66168281010219, 59.69271060398647, 53.64238255364554, 43.85736649377005, 47.45309400558472, 45.64221279961722, 73.03782381330217, 65.52431978498186, 14.080445408821106, 1.0991595281021935, 0.4630078694650105, 0.38045974182231085, 0.12431531000350203, 0.19290496808077606, 0.14651770863149846, 0.2635722868144512, 0.07203641241150242, 0.32821045549852507, 1.0451274045876093, 0.7080588915518352, 2.2162992571081435, 0.1437134998185294, 0.6434688717126846, 3.121524465935571, 54.14322260447911, 79.18618052346366, 65.63784640175956, 45.17763539722988, 60.18878419058663, 70.05856827327183, 74.06125872475761, 76.0284674508231, 73.49259035927909, 74.42252336229596, 72.53813716343471, 72.21519878932408, 73.17281341552734, 71.91252136230469, 74.81115695408413, 75.01727526528495, 73.01399149213518, 71.63061210087368, 78.45228399549211, 72.34769398825509, 77.72021484375, 68.31800978524345, 65.9674619947161, 68.69873632703508, 68.43430873325893, 72.31016676766532, 71.31766523633684, 73.44233403887067, 72.61695058005196, 73.02867303575788, 72.75032125200543, 72.60108089447021, 70.53547177995954, 72.62048026493618, 73.26040240696499, 74.2935300554548, 70.74158314296177, 74.44029685429165, 71.34057344709123, 68.76539039611816, 65.77068901062012, 69.3063771384103, 69.94222068786621, 69.3086005619594, 68.09018530164445, 73.42296940939767, 69.07842758723667, 63.77132402147566, 66.87684222630092, 63.97093881879534, 61.94422571999686, 59.77720069885254, 58.056020736694336, 58.71251433236258, 62.76616287231445, 63.547911643981934, 62.449971199035645, 63.39887278420584, 61.83514595031738, 63.61559404645647, 66.22882543291364, 65.54400403159005, 67.40657983507428, 65.38399396623883, 67.8267582484654, 66.59490517207554, 68.69216333116803, 66.83777945382255, 62.6206328528268, 65.27193341936383, 67.96292904445103, 62.54575906481062, 68.86784158434186, 70.15325137547084, 67.72257001059396, 66.29190117972237, 59.977294921875, 57.74674252101353, 55.53137193407331, 57.01879365103585, 57.48691463470459, 61.80327456338065, 62.84938839503697, 55.92915630340576, 50.641518115997314, 47.30693517412458, 42.12721640723092, 46.62850611550467, 42.20840263366699, 50.90755769184658, 49.75416367394583, 58.65750544411795, 84.95671503884452, 65.90229484013149, 43.8013779095241, 25.950311013630458, 10.53502024923052, 0.9900523998907634, 0.3554295892161982, 0.030205471507672752, 0.06653309307460274, 0.039577668599252186, 0.09689712125275816, 0.6929329889161246, 0.48105369827577044, 0.5516669377684593, 0.21489444241992064, 0.14137218759528228, 3.2764918761593953, 15.254834277289254, 41.05540466308594, 62.60006618499756, 46.190609795706614, 45.749503408159526, 52.728736128125874, 36.248762471335276, 18.62693749155317, 25.682388475963048, 37.50478833062308, 42.34287459509713, 58.79359980991909, 42.1921056338719, 0.21142936764018877, 0.08325465901621751, 0.05973622814885207, 0.049456290301999876, 0.053492542289729626, 0.03644329482423408, 0.04439704499340483, 0.025927910414923514, 0.04980059254116245, 0.16382846688585623, 0.048862280390624485, 0.05027324307177748, 0.16252961515315942, 0.13778357873005526, 0.05105726653710008, 0.09663826014314379, 0.02918635940711413, 0.065114825963974, 0.05557501715208803, 0.08159965103758232, 0.013810721109621227, 0.018815984716638923, 0.034325305438999615, 0.09288931345301014, 0.05032356662143554, 0.04231597809121013, 0.07228054931121213, 0.21533561231834547, 10.886038030896868, 77.92432512555803, 72.76070186070034, 75.83797563825334, 63.61275223323277, 58.97640691484724, 35.676658221653526, 41.724693366459434, 89.830125944955, 78.74076625279018, 18.037725039890834, 1.497794074671609, 0.5144751306091035, 0.9949011568512235, 0.11809557303786278, 0.1914235632866621, 0.15420090992535862, 0.1644507377807583, 0.008568156843206711, 0.5522492293800626, 1.4286974966526031, 0.5694069915584156, 3.050409436225891, 0.2276617166187082, 0.46559086229119984, 4.352349426065173, 63.627037729535786, 83.88795007978166, 71.56781428200858, 56.37139524732317, 70.97547340393066, 76.40900639125279, 76.57913303375244, 77.26269681113106, 77.1577651160104, 77.00613457815987, 77.9257425580706, 74.51416315351213, 77.46618175506592, 76.66900798252651, 77.87710516793388, 76.7837574822562, 77.27053437914167, 74.30296570914132, 78.92483792986188, 76.16913373129708, 76.26160730634416, 72.03677599770683, 69.23529706682477, 68.60144070216587, 71.69669641767229, 76.09500340053013, 75.02062429700578, 77.95402867453438, 77.47294930049351, 74.88065283639091, 76.71595001220703, 76.7335706438337, 75.63952813829694, 76.66305337633405, 76.59589208875383, 75.7645331791469, 76.15929508209229, 74.8588285446167, 73.19188622065953, 74.44334711347307, 70.30867562975202, 72.99643339429582, 71.37560626438686, 71.8139750616891, 69.85874502999442, 73.17911543164934, 71.26676273345947, 66.88574286869594, 69.92134829929897, 64.00009346008301, 62.66033485957554, 60.093114444187705, 59.53900950295584, 59.52965027945382, 62.938895089285715, 65.3261502129691, 65.0632095336914, 65.9030521937779, 67.14620304107666, 66.71975040435791, 68.84545448848179, 67.10065065111432, 68.05935614449638, 68.89629445757184, 68.74923583439418, 66.18537834712437, 69.04363795689174, 67.65351881299699, 64.80086639949253, 62.84332956586565, 66.8930732182094, 64.19545595986503, 71.54313428061349, 72.66014058249337, 69.2497979572841, 68.54434040614537, 67.19007396697998, 62.89189052581787, 61.68578747340611, 63.79716437203543, 65.11643968309674, 65.63383034297398, 66.49708148411342, 64.00797966548375, 58.38237067631313, 51.697981289454866, 46.41339683532715, 49.637791769845144, 58.70891516549246, 60.81096063341413, 68.95385333469936, 56.255120618002756, 76.60561956678117, 85.25443145206997, 67.94849068777901, 44.011508805411204, 19.03459872518267, 1.1877526428018297, 1.9565538806574685, 0.08137745796037571, 0.07746414294732468, 0.04597453373883452, 0.14641309210232326, 0.9880256972142628, 0.5178288849336761, 1.0335843839815684, 0.23664041768227304, 0.15486577924873146, 3.1146854843412126, 23.91478759901864, 54.70150688716343, 70.73045907701764, 53.71490437643868, 47.0412152154105, 28.262593337467738, 20.857561111450195, 24.154740163258143, 27.28390656198774, 46.22990880693708, 62.66025842939104, 67.15261622837612, 51.67789057322911, 0.20417994021305017, 0.07797763789338724, 0.061991061083972454, 0.007120487962051162, 0.04494014102965593, 0.01189076216957931, 0.06077492277004889, 0.11186854860612325, 0.041360800952783654, 0.045676850248128176, 0.03736202445413385, 0.06816938027207341, 0.025184989208355546, 0.2895644935114043, 0.10852794429021222, 0.21116710028478078, 0.07596652116626501, 0.15795342570969037, 0.13243314011820725, 0.11967282768871103, 0.13111530297568866, 0.11858818946140152, 0.08634274652493851, 0.22457822279206344, 0.14358943647571973, 0.20069919127438748, 0.15774637753409998, 0.4589439875313214, 15.804388148444039, 92.6890595299857, 83.28532586778913, 81.3125307900565, 70.54674175807408, 60.14629595620291, 64.66329206739152, 64.32305267878941, 101.96907356807164, 93.28847367422921, 25.13291277204241, 2.313685642821448, 1.7143152505159378, 1.8801890526499068, 0.2816362189395087, 0.6315120533108711, 0.6043694040605, 0.3869220550571169, 0.1384593860379287, 0.6877690660102027, 3.343788219349725, 3.0896157324314117, 8.176033871514456, 0.33252178558281487, 1.3586183999265944, 5.6140715054103305, 74.82450444357735, 88.78483200073242, 82.04926913125175, 67.0211215700422, 79.77133001599992, 82.57189178466797, 82.10530635288784, 83.08991473061698, 81.92729350498745, 78.96547099522182, 81.94040475572858, 79.42077950068882, 82.26344735281808, 82.3678092956543, 83.86351326533726, 81.43301950182233, 81.14724009377616, 78.39785875592912, 82.16591548919678, 79.46392086574009, 83.16818618774414, 79.13725130898612, 77.01904433114188, 70.35001046316964, 74.1751605442592, 79.57719734736851, 81.01804528917584, 82.47403335571289, 78.21705273219517, 76.73093032836914, 78.10832732064384, 79.05066980634416, 76.19484901428223, 79.92466981070382, 78.83501161847795, 78.3254029410226, 79.62621688842773, 79.86362988608224, 78.32720252445766, 77.49931076594761, 73.33589458465576, 77.99081243787492, 73.82055228097099, 74.66195828574044, 72.12719290597099, 76.60561956678117, 76.11948190416608, 71.3507386616298, 70.41356563568115, 64.67540277753557, 63.851825850350515, 62.088664872305735, 61.827627999441965, 61.49314866747175, 67.12945093427385, 68.74504607064384, 67.48199558258057, 67.67043072836739, 68.1004477909633, 68.66412040165493, 73.51675619397844, 68.50578485216413, 73.06390040261405, 69.75873265947614, 73.42121151515416, 71.00511441911969, 73.8489773614066, 69.80290930611747, 66.02345752716064, 67.82463209969657, 71.46082592010498, 68.55453341347831, 76.36318302154541, 75.88225650787354, 71.54399585723877, 74.46599129268101, 71.79479108537946, 68.73974459511894, 66.5466638292585, 68.0388103212629, 66.84071159362793, 67.82447229112897, 69.60991614205497, 69.01324653625488, 62.814675194876536, 59.12532070704869, 57.54900026321411, 58.10187884739467, 63.2571017401559, 64.28438595363072, 66.42356954302106, 61.520489828927175, 77.6131569998605, 83.17231341770717, 72.71357222965786, 50.42316402707781, 24.112102542604717, 1.2549844980239868, 2.376028137547629, 0.11527830921113491, 0.19145245530775615, 0.11629410327545234, 0.21208256616124085, 1.5939677825995853, 1.9078326778752464, 2.185642285006387, 0.5929459141833442, 0.14700203335710935, 4.40574893781117, 37.748364380427766, 66.0209631238665, 84.42519174303327, 61.37713459559849, 72.04958847590855, 78.24012769971574, 52.693071024758474, 29.29244143622262, 38.310372897556846, 53.0940272467477, 58.8832037789481, 79.02655955723354, 60.50455897194998, 0.4554221193705286, 0.22728651389479637, 0.19762162784380571, 0.16499034953968866, 0.1474734523466655, 0.10254273616841861, 0.16766681735004696, 0.20081631998930657, 0.19022805243730545, 0.27249124965497423, 0.23402531657900127, 0.18106210284999438, 0.20042042194732598], [0.036216830369085073, 0.14667062328330108, 0.08124981195266757, 0.013074150990827807, 0.04232970824731248, 0.07324429295424904, 0.07016265831355538, 0.06260618700512818, 0.017250711297882453, 0.025966471560033302, 0.011460070548179959, 0.04159344007660236, 0.027673485855172788, 0.03762460393565042, 0.10740493490759816, 16.068402324404033, 62.67480100904192, 59.858223642621724, 58.797928537641255, 61.14467566353934, 43.45078223092215, 49.914958885737825, 54.89592443193708, 69.94335324423653, 20.307995080947876, 1.047221092241151, 0.09072952291795186, 0.45874330401420593, 0.4145907589367458, 0.27001451541270527, 0.2373727469571999, 0.109964769333601, 0.2153225573045867, 0.10970132811261074, 0.8515102054391588, 0.5726621140326772, 0.614662834576198, 0.5060910433530807, 0.08505560630666358, 0.229982496372291, 24.740356922149658, 52.3673985345023, 51.166079316820415, 46.66116959708077, 56.54946368081229, 65.06357084001813, 74.04827948978969, 70.37601062229702, 69.54124709538051, 72.5239280973162, 71.7919145311628, 74.03254876817975, 70.03771672930036, 72.89413506644112, 70.67082268851144, 72.76914392198834, 71.7678668158395, 70.28894969395229, 73.96373380933488, 72.25747162955147, 73.08508546011788, 72.62048721313477, 61.6322238104684, 70.15829576764787, 69.78041798727853, 71.35277448381696, 70.67497076307023, 67.64379133496965, 69.38143157958984, 73.80167402539934, 75.69940076555524, 74.85249873570034, 74.04875196729387, 72.35419750213623, 68.99456977844238, 67.35410703931535, 68.11565739767892, 67.49548203604562, 65.06639180864606, 68.08498110089982, 68.33623491014752, 70.13438701629639, 67.82411793300084, 72.84875638144356, 69.82278115408761, 69.16128485543388, 68.37217099325997, 66.31430217197963, 71.19038118634904, 63.488872800554546, 63.44787842886788, 59.62222807747977, 59.17221409933907, 59.90831320626395, 58.32534681047712, 58.35898303985596, 58.49662685394287, 59.79470321110317, 61.19633552006313, 60.764887128557476, 58.81021990094866, 66.11732074192592, 66.41603074754987, 68.07369027818952, 65.50608771187919, 67.10702909742082, 66.4808713368007, 64.65973458971295, 66.15488270350865, 67.84479577200753, 62.20975112915039, 64.50576945713588, 56.000521251133506, 59.31884888240269, 71.66804204668317, 67.17340523856026, 65.14434364863804, 63.66500268663679, 60.15653760092599, 57.97095741544451, 58.892708914620535, 61.22566386631557, 65.03978715624127, 64.92395373753139, 63.891083172389436, 59.04788998195103, 55.4966413634164, 47.968744141714915, 38.81686183384487, 35.07555219105312, 42.575010435921804, 83.26623221806118, 58.527122497558594, 66.80281611851284, 76.78329890114921, 63.119298117501394, 34.31037139892578, 20.54000759124756, 3.6427507485662187, 0.24994122396622384, 0.07505944876798562, 0.07626761429544006, 0.0349775540110256, 1.0202566534280777, 0.6021162335361753, 0.4274998605251312, 0.22649224794336728, 0.051552790483193736, 0.20488917215594224, 0.007854896098641413, 3.6988457271030972, 10.16919151374272, 49.836617946624756, 63.223479407174246, 51.95628752027239, 36.181899956294465, 71.72480882917131, 55.317363943372456, 125.96216910226005, 60.66631303514753, 29.44263369696481, 51.754775864737375, 56.08531011853899, 4.095320795263563, 0.19980725699237414, 0.03776033468810575, 0.11128002804304872, 0.11916197224387101, 0.04214113997295499, 0.04305110971576401, 0.051341857694621594, 0.13634300817336353, 0.11717686376401357, 0.2638986078756196, 0.05640935059636831, 0.14763514724160942, 0.0247642092872411, 0.04733659440119352, 0.036815983575901816, 0.04688854755035468, 0.04155924191166248, 0.02524751960299909, 0.05939970870635339, 0.10958569217473269, 0.03487934963777661, 0.04153774592227169, 0.05679169829402651, 0.07941890055579798, 0.05408386859510626, 0.17942498783980096, 0.12205173075199127, 22.848081043788365, 74.40925230298723, 72.71089717320034, 70.29805878230503, 70.43682820456368, 46.37051255362374, 27.63170211655753, 61.85353783198765, 82.50603675842285, 26.22614754949297, 1.1579766805682863, 0.15309633633920125, 0.5170732140541077, 0.7209275524531091, 0.05306044440450413, 0.18522088469139167, 0.03995441499033144, 0.05401583528146148, 0.2168950079275029, 1.7118327894381113, 2.035405078104564, 1.3918304634945733, 2.611721238919667, 0.06048826886607068, 0.569129715008395, 36.02770553316389, 64.69631685529436, 62.14402117047991, 59.75296538216727, 70.00260053362165, 73.22855186462402, 80.88787773677281, 75.84987095424107, 73.4094968523298, 74.39699568067277, 72.59052658081055, 76.50670501164028, 71.9441773550851, 75.2631025314331, 73.93864386422294, 77.16213553292411, 74.97903932843889, 72.47229603358677, 78.22923292432512, 76.84635380336216, 75.24438408442906, 75.31494998931885, 63.05200481414795, 71.46509906223842, 74.7334760938372, 75.6879779270717, 76.39476258414132, 74.33333628518241, 76.3399829864502, 76.15610585893903, 75.70286096845354, 77.35454504830497, 77.9402573449271, 78.60552651541573, 71.37548119681222, 70.54767976488385, 69.08454200199672, 72.6193824495588, 69.73196125030518, 70.2171470097133, 69.9292345046997, 71.99560097285679, 71.64468915121896, 73.42107255118233, 71.3861744744437, 73.33789566584996, 68.87063476017543, 67.97269821166992, 70.32576819828579, 64.88194492885044, 61.77502318790981, 59.92432880401611, 59.88853168487549, 61.525033950805664, 62.80059814453125, 59.20089626312256, 59.61704472133091, 60.65602970123291, 63.89529378073556, 63.750090326581685, 62.12368379320417, 66.49124499729702, 66.95880317687988, 68.23008033207485, 65.78987298692975, 68.26097897120884, 65.89925152914864, 68.41917555672782, 67.46909972599575, 68.67534174237932, 66.70221315111432, 66.21576976776123, 60.6045366014753, 60.95398235321045, 70.54042584555489, 69.14497743334088, 67.2581593649728, 66.60525798797607, 65.56106185913086, 64.20782375335693, 63.30981077466692, 65.10653850010463, 69.23901435307094, 67.8560379573277, 66.55785042898995, 63.693226269313264, 59.99720845903669, 50.86625065122332, 47.78119141714913, 40.906751428331646, 54.17585481916155, 84.7200732912336, 69.11163302830288, 67.6996270588466, 74.19805485861642, 85.2008330481393, 56.65514925548008, 34.736038889203755, 7.03970593214035, 0.4308126041931765, 0.6697788227881704, 0.03076248090448124, 0.03134267584287694, 0.8300245840634618, 0.8731090064559663, 0.7505760586687497, 0.3631024089242731, 0.06143727472850254, 0.15611447367284978, 0.01939512792575572, 4.558157239641462, 20.877796002796718, 62.592902592250276, 69.25434902736119, 56.36498206002371, 38.28745426450457, 29.93555280140468, 38.13157837731497, 113.25509507315499, 62.91823809487479, 40.21991852351597, 56.19853796277727, 70.31723581041608, 5.285947169576373, 0.2204330659338406, 0.10019581246056727, 0.08985981744314943, 0.10253994738949196, 0.043545453010925224, 0.028149539238906333, 0.04096845164895058, 0.022530175146779845, 0.0331799281494958, 0.051351645562265597, 0.051436170669538636, 0.12154060389314379, 0.13281611885343278, 0.2866720887167113, 0.135641145120774, 0.19220634842557566, 0.09203314475182976, 0.13944706161107334, 0.14602817275694438, 0.177999616467527, 0.142288332006761, 0.16786963146712097, 0.14846107363700867, 0.16955005058220454, 0.08877964397626263, 0.3067139504211289, 0.133640443906188, 32.24876792090279, 86.4638557434082, 79.6018773487636, 81.8727640424456, 80.44157409667969, 63.833885601588655, 72.59227752685547, 78.03946372440883, 96.8914134161813, 34.14022738592965, 1.5020635255745478, 0.1542360173272235, 1.1009380498102732, 2.1919026119368414, 1.7711406584296907, 0.959829147372927, 0.4298471302858421, 0.3140942401119641, 0.753893063536712, 3.943959500108446, 4.57824752160481, 3.1458025574684143, 6.703380984919412, 0.44693101357136455, 0.5288345600877489, 46.195602076394216, 74.61874743870327, 67.78731332506452, 66.34644453866142, 76.77371733529228, 78.12027127402169, 84.207428250994, 82.56976563589913, 79.8305356161935, 81.8129608971732, 79.30955968584333, 84.38147367749895, 80.42362689971924, 84.92273139953613, 80.52982316698346, 82.40822001865932, 78.54996177128383, 79.43029158455985, 81.81544140407017, 80.82456575121198, 80.17282472337995, 78.68279048374721, 67.29917458125523, 76.92090102604458, 77.50647435869489, 78.44218131474086, 80.1596370424543, 74.9900244304112, 78.32795292990548, 79.28610951559884, 79.4174860545567, 80.8270184653146, 80.2600246156965, 82.61596420833042, 74.98581382206508, 72.30448314121791, 73.04006808144706, 72.92102459498814, 72.92208072117397, 73.26737145015171, 73.63293007441929, 76.34647260393415, 72.31227207183838, 78.1497802734375, 76.22240556989397, 77.6873220716204, 74.02766418457031, 69.97027751377651, 72.36256313323975, 68.2513209751674, 64.66196496146065, 60.334154401506694, 61.36669840131487, 63.48264026641846, 63.194290024893625, 61.92741107940674, 62.0347329548427, 63.25159876687186, 65.29387583051408, 65.01729583740234, 64.7553070613316, 69.61922672816685, 70.32972172328404, 73.2969638279506, 67.70920167650495, 71.33063752310616, 70.37934575762067, 70.45865944453648, 73.77632699693952, 72.35797732216972, 69.20082010541643, 68.34697682516915, 60.162874358040945, 65.28947762080601, 79.40748759678432, 73.83720016479492, 72.74498503548759, 71.91332040514264, 70.31729834420341, 68.46640246255058, 65.0532180241176, 69.9236203602382, 73.86194269997733, 68.89053440093994, 67.88688101087297, 68.60506766183036, 64.50845146179199, 61.123414175851, 56.335528646196636, 53.09556974683489, 56.08381278174264, 78.27011612483433, 69.9240094593593, 69.54363032749721, 77.76282814570835, 84.83002853393555, 63.204872131347656, 40.565622670309885, 7.4421208415712625, 1.3928086395774568, 1.5536935265575136, 0.1481804315532957, 0.08552024673138346, 2.1420792511531284, 3.66509268113545, 1.7205634180988585, 0.961238871727671, 0.23149633514029638, 0.4209617684994425, 0.09564485773444176, 6.79317125252315, 38.08831541878836, 77.9696204321725, 84.5607441493443, 67.21281542096818, 60.35893167768206, 106.32405158451625, 83.87381744384766, 146.86950710841586, 70.06966454642159, 45.39219229561942, 69.2788553237915, 82.97342123304094, 6.999727734497615, 0.39360437648636953, 0.30220530235341614, 0.27315027000648634, 0.3010199288172381, 0.12449376471340656, 0.11806513395692621, 0.21320267819932529, 0.2211104610136577, 0.4061548044638974, 0.22927831272993768, 0.1523910127580166, 0.3017762782318251], [0.1165286728313991, 0.09278259346527712, 0.05234117014333606, 0.045533004216849804, 0.054614754393696785, 0.05872160116476672, 0.06945863751960651, 0.07514648445482765, 0.045702980631696324, 0.049193778673985174, 0.07589102057474, 0.026704319020999328, 0.0860220098069736, 0.09809832501092128, 0.20407548653227942, 25.812934705189296, 72.2974168232509, 52.226040908268516, 75.03211661747524, 68.96263585771833, 47.04238598687308, 51.30157961164202, 67.47372722625732, 50.21825817653111, 2.4884810405118123, 0.13903733502541268, 0.026943809652168835, 0.1881711142403739, 0.5623180376631873, 0.34713818984372274, 0.2004245745816401, 0.1452886238694191, 0.06477310215788228, 0.3392966591886112, 1.928542000906808, 1.6718529633113315, 0.9482825441019875, 0.7716836003320557, 0.07120655729834523, 11.647206238337926, 55.02481004170009, 52.220878396715435, 56.22636897223336, 67.86288888113839, 65.03003188541958, 75.67497784750802, 73.86224147251674, 69.98262446267265, 67.2134963444301, 70.20245851789201, 69.13601425715855, 69.97509956359863, 61.64571721213204, 61.70935576302664, 67.93093258993966, 66.4631186894008, 67.63110392434257, 68.90306895119804, 71.72072328839982, 67.0674660546439, 70.60993562425885, 63.66196632385254, 59.91889531271798, 74.3557025364467, 73.5614400591169, 71.83107457842145, 75.93009485517229, 77.61968830653599, 73.71068736485073, 70.65420259748186, 70.42239679609025, 71.14610031672886, 69.90970311846051, 68.96713829040527, 68.80375140053886, 68.6037266595023, 67.97965335845947, 69.07578032357353, 64.5337220600673, 65.51064573015485, 65.57756383078438, 67.22910894666398, 66.98128754752022, 68.55356066567558, 63.15325396401541, 66.09959588732038, 63.2557954788208, 67.09170831952775, 63.09805052621024, 59.425149372645784, 57.58361618859427, 57.637284074510845, 57.21070637021746, 63.96799973079136, 67.21322536468506, 66.79790374210903, 63.69111401694161, 67.49077115740094, 65.14531639644078, 65.34371525900704, 55.58012396948678, 55.83071075166975, 60.48174108777727, 63.72220720563616, 64.62015765053886, 64.43170860835484, 63.513629232134136, 64.25771876743862, 62.3892856325422, 58.12761844907488, 66.0703717640468, 67.26179327283586, 66.27226557050432, 57.14622361319405, 58.68908500671387, 64.91869395119804, 66.61226177215576, 62.425103596278596, 60.634844643729075, 60.7991486958095, 57.28030300140381, 60.99745723179409, 57.64604227883475, 59.160631452287944, 60.00689424787249, 56.01181902204241, 56.56423555101667, 53.50257090159825, 41.8866628238133, 45.968451568058555, 32.77546916689192, 59.06560788835798, 77.50930922372001, 70.44485337393624, 73.60252475738525, 73.21421773093087, 53.22225972584316, 25.76158925465175, 12.702502114432198, 0.8029013137732233, 0.5843405702284404, 0.5207178156290735, 0.14572465047240257, 0.42213856535298483, 0.18535839659827097, 0.5834513636572021, 0.3120727485844067, 0.059029092879167626, 0.21731436971042836, 0.03686726385993617, 0.8427364219512258, 1.298575107540403, 22.598604236330303, 50.905702522822786, 55.402152810777935, 28.108346802847727, 43.36784158434187, 34.42944962637765, 52.14079693385533, 43.27821329661778, 51.25372041974749, 51.05844477244786, 70.02445261819022, 12.966356481824603, 0.5418902252401624, 0.14099119018231118, 0.11207301156329257, 0.06686415709555149, 0.008788783352689018, 0.04827817709052137, 0.04586568654381803, 0.050943706916379075, 0.08647862994777304, 0.08672809334737913, 0.05987307509141309, 0.061401027387806346, 0.07162956281432084, 0.021518722010244216, 0.055137389206460545, 0.08736820971327168, 0.07427436339535884, 0.01848383334332279, 0.03330400167033076, 0.036575568440769396, 0.022766624244728258, 0.05167135429967727, 0.035248828918806145, 0.08453430820788656, 0.02269572751330478, 0.048286702883030684, 0.1100120564390506, 32.40746477672032, 79.92856080191476, 63.609653336661204, 69.85597964695522, 82.84488650730678, 35.73900440761021, 46.7070346559797, 87.47151129586356, 63.427895409720286, 2.593009088720594, 0.08404473840658154, 0.11003486200102738, 0.11133448726364545, 0.8896257973143032, 0.6497736019747598, 0.3587801137140819, 0.4819183690207345, 0.025137089725051607, 0.7560061301503862, 2.4427238958222524, 2.7296336889266968, 1.6215881747858865, 0.7899239244205611, 0.2351049743592739, 19.002166271209717, 67.95261096954346, 63.117644446236746, 66.89977822984967, 77.25194794791085, 71.81431552342006, 81.63865143912179, 79.99972425188336, 74.07743413107735, 71.8728471483503, 74.29851191384452, 71.48665237426758, 73.23490251813615, 71.67135633741105, 67.54678753444126, 70.293778691973, 70.39309624263218, 70.20605073656354, 73.01216411590576, 75.52486201695034, 71.57007244655064, 69.310288974217, 63.830849238804404, 63.26243100847517, 76.01327868870327, 74.04500688825334, 76.66937623705182, 79.1641616821289, 82.01534802573067, 75.86072404044015, 76.97140053340367, 71.81907503945487, 72.04813630240304, 72.39857564653668, 72.16055815560478, 72.01787689753941, 72.503785269601, 72.57294069017682, 70.73276587894985, 69.05970914023263, 70.17747279575893, 66.89825657435826, 72.28948198046002, 70.18298966544015, 70.24437699999127, 67.62232834952218, 67.45750318254743, 64.66541126796177, 68.86574322836739, 62.78243555341448, 62.82821028573172, 59.65744849613735, 58.873511041913716, 58.60672800881522, 68.87111418587821, 68.69676303863525, 70.92639827728271, 66.51489666530064, 70.77927017211914, 66.17055783952985, 67.74101747785295, 59.10102980477469, 59.08652196611677, 61.79175445011684, 65.03921045575822, 66.08155836377824, 66.42330551147461, 65.00092588152204, 67.86976759774345, 63.24200330461775, 61.18464170183454, 65.88980197906494, 70.78695487976074, 66.37605776105607, 62.68345151628767, 59.21957302093506, 64.56128556387765, 68.65141214643205, 65.27195426395961, 64.52426556178501, 65.00169018336705, 60.114938735961914, 65.51826095581055, 61.938555989946636, 63.98702389853341, 61.97834137507847, 61.240852628435405, 58.7990471976144, 56.208529472351074, 43.2270050730024, 58.656866209847585, 44.20427615301949, 56.71091202327183, 72.367892401559, 72.81543976919991, 73.51711055210659, 76.04123823983329, 75.52377809797014, 46.75336871828352, 18.944154024124146, 1.8761545377118247, 0.2665352321096829, 0.22468887828290462, 0.11267976436231818, 1.9401279049260276, 0.2506925250802721, 0.8783843176705497, 0.3010517385389124, 0.01416541256808809, 0.09375818432973963, 0.29883862872208866, 0.43286604114941185, 2.169848378215517, 34.69239725385393, 62.977214404514854, 64.42243971143449, 36.01621668679373, 46.29965829849243, 27.336565222058976, 73.6526004246303, 43.642750535692485, 47.39651135035923, 58.11347886494228, 77.33168547494071, 16.029869352068218, 0.7270082033106259, 0.1897444198174136, 0.07132434419223241, 0.05848487386746066, 0.050005727248000245, 0.023135182414469973, 0.14581694480563911, 0.05252161296084523, 0.07958384563348123, 0.047730735037475824, 0.0311890758707055, 0.05043085997125932, 0.296026101069791, 0.13856852161032812, 0.14076564514211246, 0.1376919900732381, 0.19856804848781653, 0.18153709093374865, 0.14482051613075392, 0.1607847080699035, 0.10814275353082589, 0.25972032493778635, 0.11406009458005428, 0.12481657096317836, 0.1579365437584264, 0.1837318395929677, 0.24448268115520477, 41.500256129673545, 93.3129938670567, 68.24729101998466, 89.95397758483887, 86.04519203730992, 70.72740186963762, 75.49309485299247, 94.5405112675258, 78.759046963283, 3.0722089750426154, 0.15537302488727228, 0.347211553049939, 0.28813319174306734, 2.919739659343447, 1.0139392209904534, 0.7946161840643201, 0.7021837010979652, 0.16817411727138928, 1.9738027836595262, 4.890362339360373, 4.464076459407806, 3.400191089936665, 2.63779239995139, 0.3107243095125471, 24.82885786465236, 77.7337429864066, 72.30601174490792, 74.02154976981026, 80.2053006035941, 78.34927000318254, 89.29368332454136, 83.9663188116891, 79.63080269949776, 77.63971301487514, 79.63818863459996, 76.97563893454415, 81.2645743233817, 76.74841894422258, 76.65256159646171, 77.86338942391532, 74.54037870679582, 74.60559449877057, 76.11135251181466, 80.39438888004848, 77.4538209097726, 75.5836159842355, 69.58445794241769, 69.24694919586182, 81.03708335331508, 79.5240227835519, 79.39739186423165, 80.4549424307687, 85.80481215885708, 78.81662668500627, 79.22204712459019, 75.4245022365025, 75.47802421024868, 75.16627938406808, 75.59671333857945, 76.83531311580113, 75.58993884495327, 74.17122091565813, 74.96453843797956, 71.12181636265346, 73.48949841090611, 69.50515120370048, 74.64671393803188, 72.07657527923584, 73.86320032392229, 68.85806546892438, 67.56951509203229, 65.83466802324567, 70.2267633165632, 64.8792976651873, 62.04629475729806, 60.615695408412385, 58.719413893563406, 58.436886242457796, 70.1336088180542, 72.42575699942452, 74.26126956939697, 68.04030418395996, 73.35114588056291, 70.0360700062343, 69.43839985983712, 59.978052275521414, 60.928364345005576, 63.999523707798545, 68.49206910814557, 66.09261989593506, 69.71254103524345, 68.75703866141183, 70.84813376835415, 66.87771769932338, 63.61271054404122, 71.94736657823834, 74.83810206821987, 69.21150643484933, 64.90105942317417, 64.43695449829102, 70.87011092049735, 71.76610892159599, 69.02008356366838, 70.30632713862828, 69.75500842503139, 62.38411617279053, 71.58252361842564, 67.93882574353898, 68.32194941384452, 66.44850662776402, 62.6917268208095, 61.4879583631243, 63.48304326193673, 53.37384162630354, 67.33007322038922, 48.28719745363508, 66.3683591570173, 78.10132353646415, 73.11434432438442, 74.33863081250871, 77.86807945796421, 77.32152720860073, 51.80275665010725, 22.736699683325632, 1.466719450695174, 1.1193483876330512, 0.6460633724927902, 0.39502883862171856, 2.5980769310678755, 0.870707209621157, 1.9201670331614358, 0.9159607184784753, 0.21903232538274356, 0.34608496778777664, 0.42818767790283474, 0.9250663327319282, 6.085166752338409, 51.789110388074604, 73.42779840741838, 77.10077599116734, 44.63949394226074, 68.00037288665771, 53.551218714032856, 66.84069074903215, 56.545079367501394, 73.10729885101318, 67.22554452078683, 92.96666090829032, 19.1346823147365, 0.816320076584816, 0.3337888004524367, 0.15376588755420276, 0.19859930181077548, 0.12284519603209836, 0.11965950126094477, 0.29131199259843144, 0.13256267245326722, 0.24144905965243066, 0.14579179829784802, 0.15724210387894086, 0.16508549372000353], [0.07157960906624794, 0.08512277448815958, 0.06605619152209588, 0.019901377814156667, 0.07000715165798153, 0.06939429882913828, 0.02499449050187, 0.03932545713282057, 0.05050644198698657, 0.058694337627717426, 0.029169026230062758, 0.051064241877091784, 0.02328393086125808, 0.01997694625918354, 0.030634916320975338, 21.830783128738403, 65.37526008061, 59.466560636247905, 66.4554409299578, 33.98172855377197, 33.14484582628523, 44.27304942267281, 79.24014023372105, 13.771040388516017, 0.23558228303279194, 0.17856020852923393, 0.02991162852517196, 0.029082862460719686, 0.7078104934522084, 0.4007560270173209, 0.314528936786311, 0.23754333066088812, 0.19221610575914383, 1.325735941529274, 1.5003148594072886, 0.8346016556024551, 0.742922129375594, 0.1450680321348565, 3.1681255996227264, 50.5084844316755, 46.049384185246055, 56.292609623500276, 66.2197927747454, 74.98994105202812, 68.84935937608991, 70.13376862662179, 71.42102663857597, 68.37488079071045, 67.58106994628906, 69.88218825204032, 74.52669075557164, 73.92986828940255, 73.55030904497418, 62.773771149771555, 63.43264102935791, 63.786894934517996, 65.96216746738979, 69.17845385415214, 68.91055910927909, 68.00864819117955, 60.007450103759766, 61.12763868059431, 65.75748743329729, 73.16018853868756, 74.7142643247332, 76.74115112849644, 77.63402244022915, 72.99029118674142, 69.99014936174665, 68.62067331586564, 67.30150917598179, 68.06420598711286, 71.7235859462193, 70.65618978227887, 66.60109601702008, 66.45425973619733, 67.49621854509626, 64.27811173030308, 70.67363670894078, 63.02907575879778, 64.9336325781686, 68.42451177324567, 65.68634482792446, 62.67678124564034, 68.46636077335903, 63.1575687953404, 61.71636649540493, 61.44465718950544, 60.91352994101388, 59.04023306710379, 62.59926019396101, 61.50731604439871, 63.14526353563581, 65.30744566236223, 62.09921223776681, 61.58792904445103, 63.85201345171247, 64.45758369990757, 63.59604181562151, 64.05343478066581, 59.57748862675258, 57.11404650551932, 61.78147111620222, 60.229055949619834, 62.53819942474365, 65.74530724116734, 65.54484476361955, 64.870911189488, 66.09762954711914, 66.43886947631836, 60.830325262887136, 62.895677294049946, 62.81922626495361, 63.192830903189524, 56.07703481401716, 56.115875244140625, 62.020919936043875, 66.43902233668736, 61.615263257707866, 58.45539624350411, 58.460093225751606, 60.006129946027485, 57.322978837149485, 55.01878942762102, 54.4967816897801, 55.51841006960188, 52.31410585130964, 55.43915891647339, 42.7073631967817, 44.430888175964355, 40.745014735630576, 29.027195692062378, 53.542630740574424, 63.9267760685512, 74.80836377825055, 73.55992535182408, 68.20592144557408, 35.88436419623238, 21.231016363416398, 4.302271153245654, 0.37251054123044014, 0.2732829643147332, 0.7667199266808373, 2.607143895966666, 0.0212127179838717, 0.42272728947656496, 0.20655896541263374, 0.1317514566970723, 0.015733335666092377, 0.012070249100880963, 0.0615963911903756, 1.4138058785881316, 1.8728604401860918, 40.50479466574532, 59.45684705461775, 24.592362029211863, 17.13394331932068, 38.601662227085654, 14.902546712330409, 54.23073863983154, 61.65579210008894, 39.49351562772478, 64.92289761134556, 12.049008403505598, 0.24450263008475304, 0.06560316083154508, 0.02846414369664022, 0.029695386200078895, 0.03622038589258279, 0.03473178862727114, 0.06286461385233061, 0.1331012664096696, 0.10298712232283183, 0.05547421059704252, 0.064339993255479, 0.06320035976490804, 0.042534591896193366, 0.07304012855248791, 0.05892938215817724, 0.08246247616729566, 0.05518787560452308, 0.04625187474968178, 0.03893787793016859, 0.051579545118979046, 0.0177810848025339, 0.07716317873980318, 0.03188561920874885, 0.04912610498390027, 0.025853992506329502, 0.04838140940825854, 0.033180871313171725, 26.239741700036184, 76.61069175175258, 63.84458582741873, 86.85333006722587, 52.35006625311715, 27.839425461632864, 50.963817255837576, 90.36028044564384, 17.29713565962655, 0.30049021009887966, 0.07975471432187728, 0.07320868343647037, 0.08468176743813924, 1.0919665140765054, 0.37026779300400187, 0.6540826793227876, 0.719361982175282, 0.5877215745193618, 2.6304679129804884, 3.237912872007915, 1.255977439028876, 0.5264681556395122, 0.2538655719586781, 5.3516588892255506, 62.52575520106724, 58.772998401096885, 67.39441353934151, 73.56772123064313, 79.64947250911167, 75.31988321031842, 76.83731419699532, 76.42345864432198, 74.23438004084996, 73.60426875523159, 71.89586653028215, 76.79067093985421, 75.30142879486084, 75.09710311889648, 71.66296986171177, 67.6590495790754, 67.05612659454346, 70.47550187792096, 72.59173556736538, 72.920975957598, 71.78343078068325, 62.75527504512242, 63.093770435878206, 72.36715589250836, 77.20631217956543, 76.32088238852364, 79.35671016148159, 79.21250029972622, 76.66842433384487, 73.80317483629499, 72.47476959228516, 73.70454515729631, 72.07633209228516, 75.62658364432198, 74.19096074785504, 69.87262753077916, 70.70214516775948, 69.84367438725063, 67.9559600012643, 72.61993830544608, 69.61613477979387, 68.68831402914864, 72.47218486240932, 67.80048016139439, 66.59953267233712, 67.09415408543178, 62.41281223297119, 62.24352632250105, 61.78338187081473, 60.63375377655029, 59.54197638375418, 63.52401678902762, 63.26793398175921, 64.90547847747803, 67.50344467163086, 66.58027226584298, 66.8683167866298, 66.71326078687395, 65.9087358202253, 63.54910673413958, 68.19351891108921, 66.01692622048515, 62.771242005484446, 64.78439222063336, 62.704191889081685, 66.17058563232422, 65.79422950744629, 67.19147055489677, 67.10615362439836, 67.67146600995744, 66.11996105739048, 60.03483990260533, 64.87995079585484, 67.37247112819126, 65.83288928440639, 62.13685757773263, 57.76242113113403, 61.60577201843262, 70.04839611053467, 65.48606995173863, 65.91947078704834, 63.11218316214425, 64.85772350856236, 62.09477233886719, 61.87382657187325, 59.105177879333496, 60.15527302878243, 56.94363151277815, 58.80675274985177, 47.99447332109724, 45.914557865687776, 47.166748319353374, 38.84230266298567, 54.79850026539394, 62.57198851449149, 72.52904891967773, 74.78267628805978, 76.40740135737828, 62.468682697841096, 32.225498403821675, 8.176906738962446, 0.2731446788779327, 0.0752925459029419, 0.6972330553191048, 2.4358143465859547, 0.6068459483129638, 0.7957333241190229, 0.13098213369292871, 0.374194719429527, 0.05242545776335256, 0.08840130642056465, 0.03185152282406177, 1.0413408534867423, 2.171594547373908, 51.795179639543804, 69.22951616559709, 29.708131313323975, 23.83171841076442, 29.69024317605155, 19.821214709963115, 58.44781575884138, 57.9904123714992, 50.38457720620291, 70.53445734296525, 15.264344624110631, 0.42770241679889814, 0.17168025699044975, 0.035108019331736226, 0.050084807111748626, 0.02004695919874523, 0.0438944269636912, 0.0581198763102293, 0.05233184028682964, 0.01999943290970155, 0.00820352993572929, 0.047634915714817386, 0.020713636817942773, 0.1983533464372158, 0.19429529990468705, 0.1482001090688365, 0.26293731374400003, 0.13377440028956958, 0.13651874874319347, 0.0979936813403453, 0.1561343954609973, 0.10994287300854921, 0.1485965092267309, 0.15580271397318157, 0.12302027163761002, 0.08159530841346298, 0.15167587756046227, 0.09103531150945596, 31.09463391985212, 87.60924543653215, 75.21973882402692, 87.06676483154297, 48.318756171635215, 48.441784449986045, 62.74970953805106, 104.21999113900321, 21.13328300203596, 0.44274749234318733, 0.22767892426678113, 0.4113846266908305, 0.13510480390063354, 2.6041804892676215, 0.972333082130977, 1.1915685066155024, 2.434484417949404, 2.554748833179474, 5.943988476480756, 5.592967654977526, 4.533178465706961, 2.5481191660676683, 0.39082569416080204, 7.57696887425014, 73.99977411542619, 69.47867161887032, 75.21975272042411, 81.01942103249687, 87.26640742165702, 79.57193061283657, 81.94818673815045, 82.6427286693028, 81.62935474940709, 76.84920256478446, 77.10220037187848, 81.38598714556012, 81.5135908126831, 81.95662185123989, 77.23119367871965, 77.17913777487618, 70.41326686314174, 74.53265230996269, 76.2983146395002, 76.43114335196358, 75.82645552498954, 67.11278915405273, 66.58970097133091, 76.36004243578229, 81.68216105869838, 79.54081657954625, 83.47543552943638, 85.09910447256905, 80.58711801256452, 77.115797996521, 75.09784657614571, 74.84626620156425, 74.97289712088448, 77.89680331093925, 78.17334161485944, 72.0333366394043, 74.6019536427089, 73.27526460375104, 72.62619168417794, 76.99816499437604, 71.79504816872733, 70.57967621939522, 73.65139143807548, 69.5474031993321, 68.40805149078369, 71.43432549067906, 63.62833704267229, 63.758886745997835, 64.59354604993547, 61.78224931444441, 60.876586369105745, 64.73462227412632, 62.779162951878135, 65.73752525874546, 69.50526932307652, 69.34366117204938, 69.54575647626604, 70.3254485811506, 69.7617620740618, 67.9363660812378, 71.25117097582135, 68.75029196058, 65.46207782200405, 67.49400206974575, 64.72335924421037, 67.0437240600586, 70.25164481571743, 70.23412145887102, 70.67602688925606, 71.9696216583252, 71.26991721561977, 64.11872700282505, 68.71118055071149, 71.26157242911202, 70.05948543548584, 64.65400927407401, 63.44176401410784, 67.1252750669207, 75.0213052204677, 70.09333011082241, 68.45379843030656, 66.36838000161308, 67.73596613747733, 66.55023520333427, 66.31451061793736, 63.866583824157715, 66.43050384521484, 62.4017368044172, 64.86856269836426, 55.987066064562114, 58.0241493497576, 54.32471997397286, 46.53863116673061, 61.39804867335728, 69.02911622183663, 76.76983329227993, 75.90774250030518, 79.1539408820016, 65.09175273350307, 40.24694354193551, 8.288423589297704, 0.6772772861378533, 0.2179311444716794, 1.3439273025308336, 5.369895739214761, 0.6970010506255286, 1.6320553102663584, 0.397560425634895, 0.6235632055572101, 0.11661222763359547, 0.21210947686008044, 0.18427636394543306, 2.5388461436544145, 6.870790013245173, 70.9381685256958, 76.61741065979004, 42.87023591995239, 32.863586221422466, 56.93961197989327, 23.980392490114482, 67.97189222063336, 77.36411271776471, 53.49335759026663, 85.65830939156669, 18.116255317415508, 0.4696032298462731, 0.32839726975985933, 0.10573746902602059, 0.14839334227144718, 0.113804402228977, 0.18865850594426903, 0.11375561556113617, 0.19284780829080514, 0.1748274245432445, 0.12335054177258696, 0.20999030343123845, 0.17263616355402128], [0.030993650999984572, 0.05681417476651924, 0.05954537660415683, 0.016581373821411814, 0.028367308267791356, 0.06923907715827227, 0.03073889502723302, 0.05386743628020797, 0.015930134570226073, 0.031072405166924, 0.03743382702980723, 0.054693959786423614, 0.0506517638319305, 0.04210901812517217, 0.04896349745935627, 10.588742852210999, 60.78043024880545, 59.245559283665244, 29.840167931147985, 36.278472968510215, 42.89646536963326, 63.556249482291086, 65.77328068869454, 2.270122391836984, 0.07465552365673439, 0.08425169837261949, 0.2923465413706643, 0.12043499893375806, 0.6863246006625039, 0.29438819895897594, 0.18720903300813266, 0.10640479464616094, 0.433908678059067, 0.370629506451743, 2.259112536907196, 0.735063119658402, 0.16897572497172014, 1.3209882591451918, 30.77965123312814, 47.381093297685894, 60.1711357661656, 65.45789500645229, 73.1374957220895, 72.8933916091919, 73.57802540915353, 71.60923249380929, 74.21815599714006, 66.8884665625436, 69.67802238464355, 69.88424491882324, 73.74169022696358, 70.04826409476144, 72.51827226366315, 69.79374463217599, 60.957991463797434, 67.84268351963588, 67.20913287571499, 68.31658540453229, 65.62756306784493, 61.6612742287772, 59.53125531332833, 64.66311141422817, 70.10757391793388, 71.34172684805733, 75.15236214229039, 76.36225196293422, 75.65135397229875, 72.8172254562378, 73.92092595781598, 69.90719481876918, 67.04452310289655, 69.1548021861485, 69.0078477859497, 66.42419488089425, 69.36692374093192, 65.20606449672154, 62.72480719430106, 67.01117174965995, 62.92393561771938, 64.40980093819755, 69.77290003640312, 69.95221219744, 63.486934253147666, 66.1818972996303, 62.49396024431501, 57.849923270089285, 62.28981522151402, 60.87798990522112, 58.959467206682476, 59.97589833395821, 61.8948518208095, 60.546956879752024, 64.2601158959525, 60.57652841295515, 61.892815998622346, 61.88702120099749, 62.458503586905344, 62.33918217250279, 65.11518205915178, 62.511858803885325, 61.13728972843715, 55.00855473109654, 57.97996228081839, 60.36141218457903, 61.04138374328613, 61.73372309548514, 61.314823150634766, 63.626572200230186, 62.88837473733084, 63.16212681361607, 67.28506278991699, 64.05266353062221, 61.05855969020298, 58.72391632625035, 62.9098516191755, 57.020353521619526, 61.30793053763253, 62.208055768694194, 67.87811933244977, 65.60380022866386, 63.676376887730186, 60.18437903267996, 57.99598135266985, 51.02962017059326, 51.62738411767142, 47.65554019383022, 48.08314970561436, 50.91479076657976, 57.905661719185964, 45.071994985852925, 43.106398241860525, 35.21295281818935, 36.83006613595145, 49.64003951208932, 60.822925431387766, 77.01751572745187, 73.96624210902623, 53.164485454559326, 23.765472548348562, 13.116316846438817, 0.8595004166875566, 0.3006543070077896, 1.226820952125958, 0.8165072436843599, 0.5181196236184665, 0.40432995238474434, 0.22589912691286632, 0.20445959163563593, 0.07644821317600352, 0.19773250046585286, 0.08710254968277045, 0.3346624821424484, 0.176071613494839, 10.400223459516253, 56.06583431788853, 41.37818322862898, 57.41355902808053, 26.16066598892212, 28.91956983293806, 26.311351571764263, 49.98739038194929, 45.56885371889387, 48.0431558745248, 2.5479899730001176, 0.15808514292751039, 0.029702846692608934, 0.06021426964019026, 0.025576473380039846, 0.01738343614020518, 0.07441265561750957, 0.026205353206023574, 0.03451844025403261, 0.10949129438293831, 0.1180210563221148, 0.09455993452242442, 0.11538105298365865, 0.04203703573771885, 0.05112841771915555, 0.08259059036416666, 0.024035001273400018, 0.007004374929238111, 0.07695716193744115, 0.03244456582303558, 0.06070389372429677, 0.03471434688461678, 0.04778215102851391, 0.0460347876484905, 0.058242250100842545, 0.06475186401179858, 0.04076421939368759, 0.05212858172931841, 12.901369980403356, 71.49011257716587, 66.87486893790108, 50.816487652914866, 36.71876641682216, 32.5294508252825, 80.05379513331822, 78.26615565163749, 3.6750833221844266, 0.11928610344018255, 0.23164137878588267, 0.14957072266510554, 0.01667392430161791, 0.7062984460166523, 1.196067682334355, 0.7675710810082299, 0.11445391630487782, 0.07376166912061827, 1.3408669467483247, 3.38468661904335, 3.3205773276942114, 0.14489292938794407, 2.1001902988978793, 40.63119282041277, 58.64651339394705, 67.96935612814767, 73.54037312098912, 79.26616818564278, 77.42886298043388, 78.266690662929, 77.7318113871983, 78.24166325160435, 72.04717050279889, 75.5175038746425, 74.63609709058488, 77.57145391191754, 74.10879829951695, 74.75342437199184, 73.20822143554688, 69.3283612387521, 71.12941769191197, 71.06858621324811, 71.93088545118059, 67.07086372375488, 63.26154163905552, 63.99725859505789, 69.98006752559117, 74.09074687957764, 73.68675776890346, 76.19008255004883, 77.71913092476981, 77.4389100755964, 75.21540314810616, 76.05592673165458, 73.72964899880546, 71.82430008479527, 72.9804664339338, 69.32822227478027, 68.62368883405412, 72.35770634242466, 68.55094814300537, 68.40623801095145, 70.1732621874128, 67.52530370439801, 68.27319390433175, 73.8126938683646, 71.17400428227016, 67.41599464416504, 70.59134919302804, 62.623884609767366, 59.16794095720564, 64.52948365892682, 60.453093664986746, 58.735123770577566, 59.17676516941616, 62.092667034694124, 62.97333036150251, 65.32735225132534, 61.586525508335654, 64.13896015712193, 65.70088045937675, 65.69763565063477, 64.60287748064313, 66.97644465310233, 63.90915543692452, 64.81788948604039, 62.146459988185335, 61.309771810259136, 61.764281272888184, 62.68220084054129, 64.90827165331159, 63.075788497924805, 63.93314756665911, 64.75528621673584, 64.44210311344692, 68.86270686558315, 65.17333153315953, 65.2446756362915, 63.57550294058663, 66.05811514173234, 63.183527265276226, 61.09074374607631, 61.134357588631765, 69.71648761204311, 72.37691116333008, 68.07351657322475, 64.6079774584089, 63.93575314113072, 59.18426922389439, 57.373502663203645, 54.68936838422503, 57.04195894513811, 56.772896902901785, 59.13554150717599, 49.593629019601, 45.0060635294233, 43.574748516082764, 47.29467160361153, 56.584295000348774, 62.74280997685024, 69.76499993460519, 75.04097557067871, 71.25708389282227, 45.2274991444179, 20.435174907956803, 1.0006578479494368, 0.0910358882642218, 1.4030854595558984, 2.124200667653765, 0.5941785137568201, 1.2830030002764292, 0.11150566129279987, 0.20753697864711285, 0.42509982788137024, 0.13888512605002948, 0.07686512544751167, 0.3388089010758059, 0.3800898316715445, 14.214952111244202, 65.51088196890694, 47.18929869788033, 61.5181621823992, 29.42005205154419, 35.04245792116438, 35.19296979904175, 54.37722751072475, 49.665396962847026, 57.395952292851035, 3.689875602722168, 0.23801200836896896, 0.05657838724021401, 0.028405652281695178, 0.029361926950514317, 0.026789124023967555, 0.054961818270385265, 0.019898622961980954, 0.04818219491945846, 0.024565785291737745, 0.010116089451392847, 0.009811584139242768, 0.06190161659781422, 0.14099218084343842, 0.16078696080616542, 0.2522242771727698, 0.09644149855843612, 0.09620654902287892, 0.12997469918004104, 0.08982832663293396, 0.19855272716709546, 0.11093681824526616, 0.14352642771388802, 0.18717148288020066, 0.20175026915967464, 0.1944613509944507, 0.1811151507177523, 0.21944524108299188, 17.085040160587855, 82.51713303157261, 77.07420607975551, 44.07916341509138, 48.675897053309846, 63.714862959725515, 88.2487576348441, 89.39730181012834, 4.185253066676004, 0.26434956224901335, 0.22331348780010427, 0.5240156043853078, 0.21536013457391942, 2.2174546122550964, 2.738897157566888, 1.2498440252883094, 0.20329777683530534, 0.697395306612764, 4.276268822806222, 6.644675220761981, 4.4645984428269525, 0.7616585439869336, 2.591311339821134, 50.436587946755544, 67.39353111812046, 75.94586726597377, 80.62609045846122, 86.04861055101667, 85.46251610347203, 82.54125717708042, 85.1475751059396, 83.42943150656563, 76.66173321860177, 78.63811356680733, 78.66175133841378, 82.13932473318917, 79.20435006277901, 80.40392180851528, 78.41043499537876, 74.73561613900321, 83.2775021961757, 74.16234806605748, 75.51929650987897, 72.2118775503976, 68.71545369284493, 67.96789700644356, 70.8739115851266, 80.53467995779855, 77.8175104686192, 81.16594464438302, 83.21778242928642, 81.11862741197858, 78.30127879551479, 79.77658285413469, 77.29789638519287, 76.13232217516217, 76.03315748487199, 74.80424349648612, 70.71610409872872, 76.2196123940604, 73.26002025604248, 70.67805576324463, 72.87580571855817, 69.96125180380685, 70.11264610290527, 76.86921337672642, 73.60927145821708, 70.05787345341274, 72.17415578024728, 63.409802300589426, 61.673384938921245, 65.74252796173096, 63.2044552394322, 63.58437579018729, 61.760140146527974, 64.4141366141183, 66.0596923828125, 69.40223448617118, 65.42188249315534, 68.01073959895542, 69.25232710157121, 69.18157359531948, 67.65166364397321, 71.07215063912528, 67.35093866075788, 68.18564660208565, 63.344989504132954, 63.711889130728586, 65.45016860961914, 64.95827089037213, 67.81845515114921, 66.00782408033098, 68.29291984013149, 69.13377693721226, 67.84872150421143, 72.81778826032365, 66.7514202935355, 67.28504194532121, 67.31919928959438, 70.0217011315482, 66.34686837877545, 64.65614931924003, 63.854869161333355, 73.51658943721226, 73.69753442491803, 72.31372424534389, 67.22198009490967, 65.47732216971261, 62.35679585593087, 62.347360202244346, 58.51344149453299, 62.45127746037075, 63.17432090214321, 66.53418486458915, 57.24568360192435, 56.94246074131557, 51.57823950903756, 53.17621053968157, 59.99201815468924, 68.84379386901855, 75.59748458862305, 78.39596189771379, 72.7170741217477, 49.56080572945731, 23.82592535018921, 1.008617986525808, 0.5126903663788522, 1.7246162806238448, 2.588401130267552, 1.8113822362252643, 1.9658835743154799, 0.7218547027025903, 0.3255423472395965, 0.7670195677450725, 0.3921255501253264, 0.3715407246989863, 0.6721838223082679, 1.6131452449730463, 22.26404847417559, 76.72814410073417, 64.19084235600063, 75.36381667000907, 42.21404457092285, 47.34982292992728, 39.39129025595528, 70.46753229413713, 61.294027192252024, 72.76165376390729, 5.956736249583108, 0.23916918198977197, 0.11461234066103186, 0.16598228631275042, 0.12675872817635536, 0.09263273222105843, 0.1840172042804105, 0.17010499723255634, 0.13382272555359773, 0.20056030872677053, 0.16761021395879133, 0.2398715200168746, 0.20053858203547342], [0.026824282315958823, 0.036263130206082544, 0.035940069505678754, 0.03253872952024851, 0.06548379295106445, 0.09593768630708967, 0.057679561365927966, 0.021466566416035806, 0.03386902117303439, 0.014606731744217021, 0.028793986354555403, 0.05062817456200719, 0.09691960111792598, 0.15805722799684319, 0.40745512183223453, 13.897766845566885, 57.66142906461443, 51.51483719689505, 46.81036131722586, 45.27836690630232, 38.77676377977644, 58.835282053266255, 25.868713106427872, 0.1801950300910643, 0.06912842845278126, 0.06485997499631983, 0.04624435318900006, 0.16005820062543663, 0.10021242299782378, 0.3473946489393711, 0.2809271498450211, 0.18094885535538197, 0.26555187201925684, 0.11862183122762612, 2.131860622337886, 1.5023386308125086, 1.204844777073179, 9.76789743559701, 39.22548886707851, 52.31401899882725, 63.578045981270925, 69.36420699528286, 70.4532606942313, 77.84936101096017, 75.19601072583879, 79.19696412767682, 72.18909440721784, 70.88391004289899, 66.98073863983154, 68.18883582523891, 70.20053386688232, 75.77848516191754, 72.76229994637626, 70.26194899422782, 68.7709767477853, 61.84093379974365, 66.20085198538644, 67.46077578408378, 59.8969737461635, 57.39621632439749, 63.44861493791853, 70.53040654318673, 67.0733094896589, 74.06365585327148, 74.86815302712577, 72.57951368604387, 71.4654186793736, 73.73102474212646, 70.86789444514683, 70.6090532030378, 68.58447320120675, 65.6933903012957, 63.11606025695801, 67.66331577301025, 65.77235657828194, 65.08682646070207, 66.3404621396746, 64.64934703281948, 67.42107377733502, 68.11335059574672, 66.40841552189418, 65.39728587014335, 66.5546681540353, 64.66858659471784, 61.97149739946638, 64.90253244127545, 64.7847535269601, 62.99614824567522, 60.94797216142927, 58.595200947352815, 57.12734188352312, 58.7456294468471, 61.86127812521798, 58.006591251918245, 60.893352372305735, 60.777956690107075, 60.735336439950125, 61.463361740112305, 61.770208086286274, 62.40215369633266, 61.98881925855364, 62.7197836467198, 58.45131070273263, 60.40151023864746, 61.65212345123291, 64.15808854784284, 64.32069029126848, 63.84555857522147, 62.47950799124581, 63.482945987156455, 60.945102555411204, 63.64679145812988, 63.206894057137625, 63.78590134211949, 61.40781089237758, 59.79357760293143, 59.887927191598074, 62.42805658067976, 64.95296246664864, 66.76729692731584, 66.56287397657121, 65.82820619855607, 63.277022225516184, 56.78530638558524, 50.71629810333252, 48.29536853517805, 46.013607910701204, 44.45914997373308, 45.33596747262137, 52.92320578438895, 41.53814813068935, 38.910429750170024, 43.923999718257356, 54.46054336002895, 55.20564385822841, 57.31655870165144, 71.92725154331752, 62.99457795279366, 35.20027582986014, 19.0696610723223, 6.571060359477997, 0.14542347591902527, 1.235163458756038, 1.5103913758482252, 0.523981297654765, 0.637100087744849, 0.20421200777803147, 0.08477494386690003, 0.14764689946813242, 0.24192881105201586, 0.498444496520928, 0.15642090008727141, 0.1655214796108859, 0.7415144677673067, 38.78230496815273, 60.14822060721261, 85.78373827253068, 36.69852978842599, 21.312204326902116, 38.1551570892334, 38.940442493983674, 54.84473705291748, 25.180153574262345, 0.1817502323538065, 0.02618424398159342, 0.028536763907011067, 0.014429042082546013, 0.009074283747135528, 0.02118755620904267, 0.02504176234028169, 0.01290572842117399, 0.05480414369542684, 0.05151873481060777, 0.0991143701331956, 0.08338788936712913, 0.09734610108924763, 0.02594443443896515, 0.0764836666307279, 0.005022390679057155, 0.010995447086835546, 0.03302095757265176, 0.08128334515328918, 0.0456969179213047, 0.013461003312841058, 0.023105647481445755, 0.03217181510158947, 0.07073498224573475, 0.08196026525859322, 0.11620578515742506, 0.25083670020103455, 0.372791943273374, 17.06961168561663, 68.02417741503034, 60.93984971727644, 58.969173840114046, 25.43656120981489, 39.44246026447841, 79.5407054083688, 31.449735505240305, 0.10099780692585877, 0.0555488731978195, 0.08032918921006577, 0.017485194340614334, 0.08828754323933806, 0.10750464562858854, 0.13987282876457485, 0.9155307986906597, 0.15954400678830488, 0.9416551568678447, 1.1606253555842807, 4.146228075027466, 0.585445876632418, 1.6645602860621043, 17.20134084565299, 53.42497341973441, 62.343364988054546, 72.0641588483538, 76.83040073939732, 77.41296550205776, 84.97314752851213, 80.97525133405412, 83.36019270760673, 79.26375021253313, 77.116256577628, 70.99524797712053, 73.55328287397111, 72.59565435137067, 76.92037991115025, 74.05568626948765, 74.77642290932792, 70.93026842389787, 70.65342439923967, 69.45436682019914, 70.75440951756069, 62.10479858943394, 63.221943855285645, 70.09244768960136, 76.07178946903774, 73.72780077798026, 76.26964637211391, 74.8910334450858, 74.94630636487688, 71.8513355255127, 76.84875093187604, 71.39631189618791, 75.25943388257707, 72.20813941955566, 70.45128045763288, 69.384690284729, 70.94794464111328, 66.40918677193778, 69.30446638379777, 68.38347571236747, 68.13784299577985, 69.88183389391217, 72.00625256129673, 68.17555781773159, 67.90774645124162, 67.08311339787075, 66.84884098597935, 62.024908202035085, 68.17587048666817, 67.16841643197196, 66.57382433755058, 61.19641889844622, 62.632486479622976, 59.10517093113491, 61.62455994742257, 63.0247539792742, 61.534455708095, 63.49647412981306, 63.60483823503767, 63.246554374694824, 64.3451896395002, 62.972663334437776, 64.37988894326347, 64.4972926548549, 66.92937755584717, 62.43442807878767, 65.0101044518607, 63.89181968144008, 65.3764065333775, 67.12840870448521, 65.14257185799735, 63.93026406424386, 66.48608248574394, 62.56407451629639, 64.77707576751709, 65.19259888785226, 67.80819266183036, 65.22213568006242, 63.00340911320278, 63.590066364833284, 64.47559343065534, 62.80271734510149, 65.2726560320173, 69.35445172446114, 68.82351902553013, 66.43340819222587, 64.35969747815813, 58.56378814152309, 57.789227281297954, 54.46959686279297, 53.86706297738211, 49.82655348096575, 50.834219455718994, 45.43671982628958, 43.515855584825786, 53.43823753084455, 61.381477219717844, 61.332367352076936, 60.728673117501394, 68.17220878601074, 69.99085112980434, 59.170553479875835, 30.313906533377512, 9.552119391305105, 0.104606290081782, 0.5518443339637348, 1.4667540831225259, 0.6638687284929412, 0.8238913331712995, 0.20093244447239808, 0.055074204025524, 0.26567015424370766, 0.08768686332872935, 0.6256996137755257, 0.29513027199677055, 0.23825611812727793, 0.5414053169744355, 44.52084650312151, 69.63323429652623, 93.63483442578996, 39.38673223767962, 23.35769145829337, 34.41889531271798, 45.925619397844585, 59.62339537484305, 30.723294394356863, 0.20820268935390882, 0.021551089826971292, 0.023835021736366407, 0.025099607450621467, 0.029771304090640376, 0.034046637892190895, 0.020851920558405772, 0.013450803235173225, 0.026327640483421937, 0.0521106175146997, 0.019522767148113677, 0.0476680417944278, 0.039137479183929305, 0.1215352706078972, 0.14800716085093363, 0.11359946429729462, 0.22192318311759404, 0.14560511974351747, 0.15907148857201847, 0.14951299290571893, 0.27472091572625296, 0.17824721389583179, 0.16196587468896592, 0.218307975679636, 0.1611401518540723, 0.19849304322685513, 0.36410677645887646, 0.6215182638594082, 22.128426585878643, 78.00516046796525, 66.79777867453438, 58.918201855250764, 67.80956840515137, 61.53493513379778, 86.71845163617814, 38.35716206686837, 0.3534464213464941, 0.18600590899586678, 0.2625898766730513, 0.45188917751823154, 0.5072944387793541, 0.41015465983322685, 1.4142781389611108, 1.534873353583472, 1.369495913386345, 1.7058000160115105, 5.41409627028874, 7.922732949256897, 3.0334334671497345, 1.49067998783929, 26.42596905572074, 65.2978710447039, 69.20874105181012, 79.66524491991315, 79.52415479932512, 83.27484103611538, 88.13810062408447, 85.3115873336792, 88.76922634669712, 82.74398476736886, 81.83999633789062, 74.60736628941127, 76.6645541872297, 78.16093908037458, 82.73283290863037, 79.618330683027, 79.49092851366315, 75.3753228868757, 74.34698949541364, 77.47859818594796, 76.62908363342285, 63.588746207101, 68.87731197902134, 72.10452788216728, 78.6713537488665, 76.80936159406389, 79.40174838474819, 80.56789929526192, 78.46433912004743, 76.25363077436174, 81.26572077614921, 76.26667254311698, 78.16665049961635, 76.44513007572719, 75.33714253561837, 70.74569647652763, 73.3362489427839, 70.60308470044816, 73.24404634748186, 72.88421303885323, 71.60367393493652, 71.60798181806291, 73.1462574005127, 71.53396265847343, 70.32035555158342, 70.50002207074846, 68.95483303070068, 63.261527742658345, 69.42894336155483, 69.71796063014439, 68.34161281585693, 65.59282902308873, 64.04804992675781, 60.48339475904192, 63.875922203063965, 64.14390032632011, 61.904245785304475, 67.63791315896171, 67.13689245496477, 66.73748220716203, 68.00169999258858, 67.27763516562325, 68.33209378378731, 69.56650379725865, 71.20620223454067, 63.928103174482075, 67.64723069327218, 67.77967030661446, 68.5996480669294, 69.68039172036308, 67.91179725102016, 67.2584650857108, 69.7396320615496, 67.69220638275146, 67.53147370474679, 69.26377773284912, 70.66648006439209, 67.27546732766288, 67.6854110445295, 67.69757734026227, 67.76379367283413, 66.81178624289376, 68.36995451790946, 74.731780733381, 70.03163010733468, 68.96513720921108, 64.25930295671735, 62.20019735608782, 60.830804688589915, 60.09930528913225, 59.392110688345774, 56.428912435259136, 61.5718161719186, 56.24658128193447, 56.41108683177403, 60.31626973833357, 63.0225305557251, 63.70731026785714, 64.88053444453648, 70.73363440377372, 73.3836703981672, 62.18382740020752, 35.30572516577584, 10.52889541217259, 0.4362332033259528, 1.690287402697972, 3.058405727148056, 0.836052417755127, 1.8139773883989878, 0.29816240072250366, 0.3283339760133198, 0.5057788086788995, 0.6301456466317177, 1.3997498899698257, 0.6288855799606868, 0.5878082098705428, 1.1306093548025404, 56.400588103703086, 76.78987189701625, 99.08024883270264, 48.88364124298096, 36.74065671648298, 56.49773781640189, 57.09762096405029, 74.61565549033028, 42.994681630815776, 0.5079957182918275, 0.14167659197534832, 0.15104964402105125, 0.15189070174736635, 0.0897682084302817, 0.18167433142662048, 0.06976688919322831, 0.14895854837128095, 0.19648038622524056, 0.20505579321512155, 0.2377141857785838, 0.1603804776178939, 0.11728149386388914], [0.08576286371265139, 0.045924518922609944, 0.11159718888146536, 0.038126896268555095, 0.019443546488348926, 0.06539679797632353, 0.01818709640896746, 0.08174626888441187, 0.05557475591610585, 0.04897489006231938, 0.03624950861558318, 0.024856374698824117, 0.08336288535169192, 0.022996830820505108, 0.03697816362338407, 28.195489372525895, 70.45934731619698, 41.985810143607004, 43.04691471372332, 48.158735683986116, 52.738050188337056, 30.67577566419329, 8.870369962283544, 0.12157675623893738, 0.10256681059088026, 0.2973123863339424, 0.07939735028360571, 0.2583028924252306, 0.1293574223028762, 0.09735000945095505, 0.460596356008734, 0.01786104167279388, 0.21190739556082658, 1.3589736265795571, 1.2851509707314628, 0.5376986701573644, 3.0014367955071584, 25.218170642852783, 41.4944509097508, 50.98868138449532, 66.6385954448155, 70.76057256971086, 75.10237680162702, 73.5817426953997, 75.89329719543457, 77.53526074545724, 72.62910992758614, 66.96311106000627, 67.3286349432809, 68.45579951150077, 69.75079781668526, 69.23763860974992, 68.37024634225028, 72.06858485085624, 72.01458345140729, 69.96239825657436, 62.05475071498326, 59.52261870247977, 62.746707916259766, 62.097384861537385, 71.09493378230503, 71.6053831917899, 70.23023046766008, 68.24766622270856, 69.49757766723633, 71.05867113385881, 75.76765986851284, 74.8469957624163, 68.53227833339146, 69.22948837280273, 62.956619943891255, 63.49650192260742, 66.21791676112584, 63.05232443128313, 67.12302385057721, 69.0424359185355, 65.81303133283342, 69.00442232404436, 67.37750162397111, 68.14991896493095, 66.73063128335136, 64.53127629416329, 67.3147941316877, 67.36173616136823, 61.902196066720144, 62.04801096235003, 67.65488065992082, 67.43380287715367, 62.5810489654541, 67.46595219203404, 64.4189795085362, 63.35765607016427, 61.7090083530971, 62.170111656188965, 60.48481913975307, 59.84234700884138, 62.40938677106585, 60.14813722882952, 60.42252853938511, 60.69225066048758, 58.19389731543404, 59.00821576799665, 58.730836732046946, 58.661855016435894, 59.042630195617676, 58.92708165305001, 61.501083510262625, 63.61568437303816, 62.94040979657854, 60.790004866463796, 62.64857850755964, 59.74807385035923, 62.51309558323452, 62.918140820094514, 62.27458477020264, 63.10930660792759, 58.316467012677876, 62.624502999441965, 66.59118093763078, 60.42678778512137, 62.647181919642854, 64.61625276293073, 64.44122764042446, 64.2249093736921, 58.75368240901402, 54.8823059626988, 47.68619564601353, 45.675557204655235, 45.418508597782676, 42.46591329574585, 42.45287152699062, 34.57439252308437, 37.906703404017854, 52.31624242237636, 65.30295017787388, 59.09189292362758, 57.48316955566406, 69.84110355377197, 44.092444896698, 20.175206320626394, 11.667213576180593, 0.45920611917972565, 0.25050587366734234, 0.4203486985393933, 0.33914515588964733, 0.5885999245303017, 0.5514943184597152, 0.2382661604455539, 0.12950804350631578, 0.3231907348547663, 0.7425055631569454, 0.39608322775789667, 0.33084200429064886, 0.5094269386359623, 10.263990129743304, 64.15595545087541, 84.87354510171073, 47.369816371372764, 37.160647528512136, 47.55569110597883, 44.28064032963344, 47.49619715554373, 7.7203414780753, 0.08841964043676853, 0.0771916297131351, 0.0525793596836073, 0.026604211357023035, 0.027483989684177295, 0.018297821449648057, 0.008125088743067213, 0.05075607502034732, 0.043741586950740645, 0.048896644796643934, 0.08224739413708448, 0.0396200329331415, 0.07078630663454533, 0.018049218093178103, 0.04829586649845753, 0.04951344669929572, 0.07644167209842376, 0.058822180410580974, 0.02907628406371389, 0.07779385668358632, 0.0678552592705403, 0.060555029926555495, 0.017560138533424054, 0.02297261051301445, 0.07744044850447349, 0.03660605162648218, 0.04761039006656834, 0.031331887136080434, 35.56721019744873, 71.56711251395089, 54.77733257838658, 45.99960381644112, 26.55091677393232, 69.50031525748116, 47.88873910903931, 9.428218245506287, 0.09318318018423659, 0.11652192819331374, 0.21051285681979998, 0.1122603075844901, 0.37368945511324064, 0.09253321148987327, 0.3268060508583273, 0.611189603805542, 0.10712697982255902, 0.03907818879399981, 1.7282672332865852, 1.2199109686272485, 0.4678614033120019, 6.447942623070308, 41.34100341796875, 53.94627244131905, 62.31928947993687, 73.83918734959194, 77.21122455596924, 79.76598685128349, 79.3609972000122, 80.88935075487409, 80.3064455304827, 76.31305176871163, 72.45134721483502, 72.85276549203056, 72.07912526811872, 72.7178384235927, 74.10264219556535, 72.73336069924491, 73.07290526798793, 75.08813994271415, 77.11960560934884, 69.13249152047294, 63.80560643332345, 66.26385130201066, 67.26839406149728, 73.98873342786516, 76.5073025567191, 73.19697230202812, 71.51221479688371, 72.62246050153459, 75.38236836024693, 78.33576270512172, 75.29670401981899, 70.58874361855644, 70.2721836907523, 65.91193893977574, 68.08227130344936, 70.40331704275948, 65.78421020507812, 71.45763669695172, 70.25069291251046, 70.4853822163173, 73.08632918766567, 70.46420410701207, 71.0473108291626, 67.82671655927385, 67.07729775565011, 68.43581649235317, 70.14787346976144, 65.76834746769497, 65.10109111240932, 71.1300847189767, 68.17671121869768, 65.42928232465471, 69.83697632380894, 67.06543023245675, 65.49586691175188, 63.61037594931466, 65.44867474692208, 61.64450822557722, 63.1047694342477, 63.98580796377999, 62.784436634608674, 61.13346127101353, 61.267915861947195, 60.06182670593262, 60.861057145254954, 59.63115651266915, 61.04858207702637, 61.17763096945626, 60.69192409515381, 61.891058104378835, 63.508355549403596, 64.65564210074288, 63.46271283285958, 62.87231050218855, 61.61303983415876, 62.70424747467041, 65.51273713793073, 64.93364647456578, 66.20358262743268, 61.843699182782856, 65.4654963357108, 69.20842838287354, 61.90132059369768, 63.179907253810335, 68.15314987727574, 65.68822084154401, 64.69969367980957, 62.98198086874825, 62.24337346213204, 56.581911768232075, 55.63969782420567, 51.8302333014352, 48.438904421670095, 45.940592765808105, 40.17102057593209, 41.08608443396432, 59.68740912846157, 70.81212125505719, 66.71205874851772, 59.415734563555034, 68.49805150713239, 58.584167207990376, 43.687014034816194, 16.75381084850856, 1.457728264587266, 0.09020138518618685, 0.18885608177099908, 0.4707110875419208, 1.2790803079094206, 0.8037983370678765, 0.20081804346825394, 0.1963002351777894, 0.5160526431032589, 0.9525860846042633, 0.33586688180054936, 0.07607943617871829, 1.1410870211465018, 11.65236701284136, 70.6447252546038, 88.67274366106305, 55.05356168746948, 32.43969399588448, 48.70179646355765, 48.85499382019043, 57.533755915505544, 9.22071463721139, 0.07943265446062599, 0.020866537899045006, 0.022271899273619056, 0.03349180320011718, 0.013395736725734813, 0.021993626973458698, 0.06914529683334486, 0.034097945317626, 0.028824096346007924, 0.01765285525470972, 0.06504715566656419, 0.051738251067165814, 0.056803799966084104, 0.157333801101361, 0.13060119056275912, 0.16826092904167517, 0.14238875518952096, 0.08220162016472646, 0.09346289267497403, 0.20954997491623673, 0.14747212241802896, 0.13617773061352118, 0.1312408862369401, 0.09427311098469154, 0.13532166369259357, 0.10363706387579441, 0.07233608061713831, 0.1252335307321378, 43.306947571890696, 87.9928207397461, 54.81409897123064, 56.62284360613142, 73.50363799503872, 76.82367488316127, 66.24304144723075, 10.960106696401324, 0.1370216788990157, 0.23102616465517453, 0.7665091465626444, 0.4831055338893618, 0.8389502508299691, 0.3067253226680415, 0.6929544849055154, 1.7159554596458162, 0.15708030041839394, 0.2693937101534435, 4.316525382655008, 3.8653219597680226, 0.9490317553281784, 10.125937240464346, 54.45360558373587, 62.00321592603411, 74.2874503816877, 78.55340112958635, 82.30098152160645, 84.80579321725028, 82.2319164276123, 84.86415113721574, 84.13385377611432, 82.85666370391846, 75.92323698316301, 77.55686964307512, 75.12081732068742, 77.41054058074951, 76.70788315364292, 76.97759137834821, 76.38391644614083, 82.20168481554303, 80.53478418077741, 72.90004103524345, 69.96836675916398, 73.0909149987357, 72.35725470951625, 78.591644014631, 79.55628326960972, 77.43011365618024, 75.86964552743095, 75.44351250784737, 76.53822204044887, 81.53093351636613, 81.6245813369751, 74.38485717773438, 75.08968939099992, 70.00235734667096, 69.4913729258946, 73.70066111428397, 69.08374990735734, 74.3646935054234, 75.17092772892543, 74.83118861062187, 76.23801122392926, 73.75421782902309, 71.88200487409318, 73.21102850777763, 71.92576462881905, 71.01812144688198, 70.70140171051025, 67.5152496610369, 67.92718751089913, 75.4042134966169, 72.07717282431466, 70.30987766810826, 74.73843015943254, 69.45174734933036, 69.03810719081334, 69.09683336530412, 67.36820493425641, 64.28373282296317, 66.7902398790632, 67.31301539284843, 67.36140264783586, 62.769095012119834, 65.60302203042167, 65.83527946472168, 65.36316326686314, 63.23906421661377, 63.17523111615862, 64.67704950060163, 64.37667192731584, 67.65855625697544, 69.06091812678746, 67.81455026354108, 66.95726067679269, 68.34760911124093, 64.25728103092739, 66.54052856990269, 69.18104553222656, 67.91623714991978, 68.13532774788993, 64.33394745418003, 70.9403988974435, 73.67743328639439, 66.70731312888009, 66.27578830718994, 70.62030233655656, 67.68893378121513, 69.20842838287354, 64.95900739942277, 65.1014107295445, 59.279904229300364, 62.151031902858186, 58.78936835697719, 56.25350863592965, 53.845627784729004, 51.99359587260655, 54.35209935052054, 65.7880664552961, 67.90506444658551, 67.51697281428746, 61.96977424621582, 75.97411864144462, 59.91241264343262, 48.01784358705793, 20.03753818784441, 1.27082074540002, 0.4080368977572237, 0.7716258434312684, 1.2840101633753096, 1.4554638032402312, 1.8865418774741036, 0.8242538880024637, 0.27429881266185213, 0.6679267478840691, 1.9058561325073242, 1.9683087127549308, 0.647928420986448, 1.3849227598735263, 13.64542477471488, 81.0136331830706, 90.34732205527169, 66.05286925179618, 58.8555360521589, 67.79676287514823, 60.00333677019392, 71.69254834311349, 13.433426550456456, 0.14288040809333324, 0.23474613790001186, 0.10790253177817379, 0.1359347743647439, 0.14554855706436293, 0.11867295205593109, 0.18977773588682922, 0.17409331750656876, 0.13472335865455015, 0.11604725223566804, 0.19894501540277684, 0.18541810767991201, 0.14400266430207662], [0.06007236761174031, 0.023260031161563735, 0.062443691438862255, 0.05307573519114937, 0.02132096467539668, 0.0954514548980764, 0.025852514996326396, 0.004850691633432039, 0.08156206698289939, 0.034503312315791845, 0.06544548964926175, 0.04309085151180625, 0.019487240750874792, 0.028973608144692013, 0.2588357324046748, 40.45528875078474, 58.42116246904646, 43.183693477085654, 55.184319836752756, 41.86160067149571, 55.53128855569022, 4.163879539285388, 2.0103746269430434, 0.11291352646159274, 0.029336892401001284, 0.15497933886945248, 0.1547004881181887, 0.06893841150615897, 0.45851862749883104, 0.1840704692793744, 0.16683620906301908, 0.13143321020262583, 0.13544071944696562, 1.0256689744336265, 0.21613499442381517, 1.767584917800767, 18.044044426509313, 36.0553628376552, 48.924225670950754, 56.06860317502703, 65.88717555999756, 66.06675175258091, 70.84065055847168, 71.97116415841239, 75.52729388645717, 76.24219403948102, 72.57997226715088, 69.51748425619942, 65.59370449611119, 65.68111283438546, 66.67494147164481, 69.44246455601284, 70.80494376591274, 71.13499709538051, 72.8456505366734, 68.50877257755825, 66.11552115849086, 60.02941335950579, 60.188151904514854, 64.7707668031965, 71.84184428623745, 73.07412815093994, 69.79331384386334, 68.23039994921002, 70.00012002672467, 73.1995917728969, 67.29668017796108, 68.52031353541783, 67.93630354745048, 64.58331830160958, 67.16069003513881, 69.37606062207902, 60.56659943716866, 64.65268216814313, 68.30899797167096, 68.39293221064976, 70.79476465497697, 66.86906719207764, 68.45524365561349, 64.35790484292167, 65.41330146789551, 65.32437842232841, 69.00127479008266, 65.04233019692558, 64.54965427943638, 64.6494721003941, 64.10759598868233, 58.52523258754185, 62.89229352133614, 63.090004512241904, 63.44970580509731, 63.3735466003418, 62.97067614964077, 57.69404738289969, 56.79086147035871, 57.37109858649117, 57.52534164701189, 60.200373785836355, 57.79092958995274, 58.433703967503135, 60.24279948643276, 58.95003155299595, 59.6336578641619, 55.52886710848127, 54.763165201459614, 56.89767960139683, 59.62684168134417, 59.23751326969692, 61.17679718562535, 61.43125411442348, 58.65482343946184, 60.87384877886091, 60.229118483407156, 62.05747440883091, 60.665020670209614, 62.32184641701834, 63.477192878723145, 59.31060831887381, 64.06222425188336, 64.6352630342756, 61.376495361328125, 64.68539428710938, 64.01829774039132, 62.24941839490618, 58.91851452418736, 56.06089762278965, 52.57363843917847, 46.47656985691616, 41.314544677734375, 46.41594335011074, 48.00243248258318, 43.3802614893232, 31.99488421848842, 36.70140634264265, 52.93217243467058, 65.53323432377407, 56.285793440682546, 59.79928207397461, 56.84319877624512, 24.351638214928762, 17.5867417880467, 4.597680764538901, 0.10423902621758835, 0.7289640126483781, 0.21020736678370408, 0.9319891269717897, 0.39376269227692057, 0.45781821651118143, 0.10167128685861826, 0.6573724885072026, 0.48377239810568945, 0.1439659691282681, 0.24251536386353628, 0.34955125035984175, 0.186559634283185, 38.42634528023856, 80.31595761435372, 37.282053402491975, 32.677565574645996, 43.53057186944144, 36.692860058375764, 36.26584114347185, 1.462971983211381, 0.08169003190206629, 0.03351407950477941, 0.014513368718326092, 0.09150872539196696, 0.005394559079182467, 0.029721224813589027, 0.06664729730359145, 0.025136509577610662, 0.020654273485498767, 0.027411537411223565, 0.10274675129247562, 0.0910286075834717, 0.03130348366019981, 0.05107318496863757, 0.047825933500592194, 0.02948398861501898, 0.011953348543361893, 0.04175243779484715, 0.07408778662128107, 0.031605750654957125, 0.047515971918723414, 0.026757224396403347, 0.03194990700909069, 0.051329321760152063, 0.09830379898526839, 0.04941160537834678, 0.016692750255710313, 0.3208305186458996, 48.788635049547466, 64.94445092337472, 59.61847605024065, 42.7351073537554, 40.16139384678432, 74.46439320700509, 8.596837622778756, 2.5159772336483, 0.2762450953679425, 0.47900636813470293, 0.3106207922101021, 0.31915768555232454, 0.09862109553068876, 0.5603280844432967, 0.08382521197199821, 1.036472337586539, 0.1299471099461828, 0.25015268261943546, 2.0467784106731415, 0.299831786858184, 2.7706704011985233, 30.57127128328596, 52.81315326690674, 58.4208984375, 65.88989925384521, 74.3241855076381, 73.83519908360073, 77.38297707693917, 77.64224215916225, 79.12672478812081, 79.42769295828683, 75.92320919036865, 71.29599380493164, 70.40781252724784, 69.93337563105992, 72.03785296848842, 74.3864413670131, 72.52466460636684, 73.68384647369385, 75.98898083823067, 70.44828578404018, 68.08833013262067, 67.4390835080828, 67.36220169067383, 68.0584945678711, 74.74847725459507, 74.16928236825126, 73.95330456324986, 72.69176878247941, 75.21525028773716, 75.16533442905971, 69.68287917545864, 71.39875071389335, 68.72810636247907, 69.06270381382534, 72.5300772530692, 70.89943231855119, 65.76978574480329, 69.37243366241455, 69.60063334873745, 71.92759895324707, 73.29276711600167, 71.57189982278007, 69.7892005102975, 65.05105713435582, 66.19621753692627, 70.23063346317836, 70.40209415980748, 65.38391753605434, 66.95981761387416, 66.82894134521484, 64.41340010506767, 60.16445854731968, 64.30265276772636, 64.22127546582902, 63.207706996372764, 65.74655096871513, 66.03626305716378, 60.40481063297817, 60.03891849517822, 57.717685154506135, 60.70546613420759, 62.01111602783203, 58.70100116729736, 59.81637464250837, 62.92128140585763, 61.13558741978237, 61.515403747558594, 58.75521101270403, 57.05302047729492, 60.38630758013044, 62.30588640485491, 61.77740642002651, 61.86951174054827, 63.76344476427351, 62.259687832423616, 62.29603385925293, 61.66171196528843, 63.31878089904785, 63.00428458622524, 64.91836738586426, 65.98111520494733, 66.41842092786516, 65.23618493761334, 66.66954272133964, 64.25424466814313, 64.48158277784074, 66.73684992109025, 65.08914715903146, 64.07553700038365, 60.884674072265625, 60.34361089978899, 54.82402447291783, 51.39340353012085, 51.18454415457589, 50.50451353618077, 49.08177259990147, 39.650833266122, 41.49784510476248, 56.213737147195, 69.6013629095895, 62.923622948782786, 57.07586962836129, 62.98351642063686, 46.723154476710725, 27.066905634743826, 7.238687140601022, 0.2060964216611215, 0.9206841907330922, 2.1055847065789357, 2.8082312771252225, 0.09838303830474615, 0.44661853462457657, 0.8817252069711685, 1.7120849873338426, 0.4663439818790981, 0.36340590406741413, 0.15069535374641418, 0.28786017639296396, 0.03785004380292126, 40.92932265145438, 84.57076345171247, 44.5860310282026, 34.898407867976594, 50.467132227761404, 43.174459321158274, 49.218124049050466, 1.7630209284169334, 0.10801657315875803, 0.038364312278905084, 0.03581671862463866, 0.04483549396640488, 0.042254329792090824, 0.08571983102176871, 0.05116456327959895, 0.030005683656781912, 0.07413854104067598, 0.039361816431794844, 0.06450894168977227, 0.003587654251272657, 0.045789164757089953, 0.20127874160451548, 0.14814988390675612, 0.13931974130017416, 0.12077371004436697, 0.15773856081068516, 0.3089356912033898, 0.09529434011450835, 0.08203241388712611, 0.12132951164884226, 0.09364497754722834, 0.1735591340277876, 0.1876950812126909, 0.13568831687527044, 0.23433293721505574, 0.6722468989236015, 58.84131308964321, 73.63279805864606, 59.54924419948033, 73.04454966953823, 60.60849707467215, 84.88366862705776, 21.098456893648418, 3.2796715455395833, 0.28783908752458437, 0.6610201299190521, 0.5130093321204185, 0.6889572079692567, 0.30883833499891417, 1.9437631155763353, 0.40095367069755283, 3.0573938957282474, 0.47296914351837976, 0.7233581191727093, 4.117648831435612, 0.7173143263374056, 3.38017007282802, 40.11982972281319, 60.06449481419155, 69.62317330496651, 77.06624344417027, 81.51272228785923, 79.10872895377022, 81.4326651436942, 84.02600383758545, 83.25642830984933, 84.60462202344621, 80.83674594334194, 77.35512869698661, 73.92311464037213, 76.17223957606724, 75.76555456433977, 78.97880458831787, 79.34125736781529, 77.87427030290876, 79.28488663264683, 74.63139316013881, 69.69947147369385, 70.16090829031808, 72.41907283238002, 72.70732579912458, 77.59944125584194, 78.92610945020402, 78.63847487313407, 74.18298421587262, 78.6998622076852, 80.13655512673515, 72.42873082842145, 74.69089753287179, 73.82500607626778, 73.43146010807583, 73.73542295183454, 76.1303905759539, 68.99652917044503, 70.12547942570278, 72.48606736319405, 73.29534489767892, 76.59609358651298, 72.70180198124477, 72.97043323516846, 70.5205887385777, 68.30940096718925, 71.84663159506661, 72.83656924111503, 70.81671401432583, 69.28228773389543, 67.81618309020996, 69.98912102835519, 63.997758865356445, 66.58777632032121, 69.09856346675328, 67.18520327976772, 67.68028327396938, 66.99835232325962, 61.985720361982075, 62.69923087528774, 59.78936004638672, 62.57815851484026, 65.72116225106376, 63.108681270054404, 63.35503659929548, 66.13538605826241, 66.18917206355503, 65.55458613804409, 60.522672925676616, 60.544469424656455, 62.27555056980678, 63.57858099256243, 65.1917234148298, 67.32857935769218, 68.58617550986153, 66.07781328473772, 64.46398993900844, 64.73406641823905, 66.35988930293492, 65.45005743844169, 68.75971371786935, 69.55976404462541, 68.08684321812221, 70.18820776258195, 69.50007207053048, 66.79241466522217, 69.31642423357282, 70.6192740031651, 67.31049319675991, 65.09221826280866, 65.52044269016811, 60.654250962393625, 58.77704225267683, 56.73270157405308, 59.84997613089425, 60.80540902273995, 58.145381518772666, 50.07069928305489, 54.92612477711269, 61.93611022404262, 67.63121509552002, 64.35505608149937, 63.980270249503, 68.80890001569475, 48.66567972728184, 30.43775122506278, 7.096484439713614, 0.4882007890513965, 1.5302574698414122, 2.4394426090376715, 4.3537329861095975, 1.0912285936730248, 1.2263291499444415, 1.250801248209817, 3.3206164113112857, 2.031043780701501, 0.5341388583183289, 1.2242607580763953, 0.31520318346364157, 0.3404776086764676, 50.678743089948384, 86.86995710645402, 50.41850873402187, 50.892462730407715, 59.32588045937674, 53.50288357053484, 61.782958030700684, 4.036850835595812, 0.1816242148301431, 0.10816304172788348, 0.09741275358412947, 0.14483063987323216, 0.0854248379224113, 0.13606586733034678, 0.09489960915275983, 0.09538867005280086, 0.20453645608254842, 0.2363543744598116, 0.1427562768970217, 0.14085194122578415, 0.17429201970142977], [0.04043399675616196, 0.047279994402612956, 0.05239799405847277, 0.05415532511792012, 0.09195156448653766, 0.09140619875064918, 0.0845869964520846, 0.01876244830366756, 0.034538684346313984, 0.04959209230063217, 0.043621313226010115, 0.0450232446060649, 0.04116845323837229, 0.06947411490338189, 2.1676618669714247, 55.80008309228079, 51.05835444586617, 48.87881224496024, 36.80922848837716, 52.325205598558696, 43.726514543805806, 0.8212664340223584, 0.6318366644637925, 0.27555263681071146, 0.5623904509203774, 0.4007055711533342, 0.09980441989111048, 0.2810654895646231, 0.3380777117397104, 0.08203858177044562, 0.829789865229811, 0.3152890588556017, 0.3346429946167128, 0.5708070535744939, 0.5130370163491794, 7.5978855575834, 32.05113683428083, 43.72168901988438, 51.79091691970825, 66.11235277993339, 65.88596657344273, 71.4342143195016, 70.4667054585048, 67.42142118726457, 75.4684009552002, 72.74433885301862, 69.22433975764683, 65.91175828661237, 67.72351496560233, 67.82261712210519, 69.00490174974713, 68.28069795880998, 66.50619057246617, 69.26097066061837, 68.98123618534633, 67.85981777736119, 71.45914445604596, 71.88256767817906, 62.27100644792829, 61.491738183157786, 67.34434482029506, 72.73791871752057, 71.35498401096889, 69.82990305764335, 70.12010846819196, 65.3913937977382, 68.78860432761056, 66.11096314021519, 67.10970415387834, 71.23263318198067, 68.60022476741246, 62.08670548030308, 66.19498075757707, 69.30156898498535, 68.08709335327148, 71.40228039877755, 70.03550720214844, 70.12722342354911, 63.03601700919015, 63.83738054547991, 70.77963842664445, 64.76193564278739, 59.663403102329795, 60.586874280657085, 63.121896743774414, 58.8546119417463, 54.12375027792794, 58.47974273136684, 62.74060044969831, 62.73104667663574, 59.85926587241036, 58.745886530194966, 63.831752504621235, 60.7750176021031, 59.16471004486084, 59.17962782723563, 58.60945865086147, 58.197527749197825, 57.658225945064, 56.89267689841134, 57.18909747259957, 56.88119847433907, 55.371264593941824, 56.39706884111677, 53.0117883682251, 52.86333315713065, 56.97992890221732, 62.01078946249825, 57.86324644088745, 57.62025056566511, 59.968380383082796, 62.22011089324951, 59.35579245431082, 60.17486000061035, 60.72510869162423, 63.351833479745046, 60.512848172869, 61.360194887433735, 61.374153818402974, 64.17035906655448, 65.38789885384696, 59.46325329371861, 61.82762105124337, 63.90623719351632, 61.25918197631836, 56.645880358559744, 57.17294291087559, 52.87834126608712, 46.43563454491751, 36.76604890823364, 41.69601467677525, 44.44339145932879, 45.54074478149414, 36.496156556265696, 40.93754931858608, 56.237187317439485, 55.196854387010845, 50.6415250641959, 54.633532660348074, 40.96688461303711, 11.239177618707929, 14.300766706466675, 1.4895334265061786, 0.3441799400108201, 1.244561331612723, 0.5804441507373537, 0.024541546324534074, 0.6270167316709245, 2.0897425966603413, 0.5897113106080464, 0.30952294969132965, 0.299023298812764, 0.644966045660632, 0.30734338664582794, 0.4149995084319796, 11.154342719486781, 67.27727385929653, 26.78847220965794, 36.914813314165386, 30.334268229348318, 41.82109267371041, 41.40271036965506, 0.8702447201524461, 0.07132941963417189, 0.08371476004166262, 0.029378500168344805, 0.051012513759945116, 0.0263930495628821, 0.039069679964865954, 0.006329458198576633, 0.04206754945750747, 0.029309574581150497, 0.027548296144232154, 0.1053008520975709, 0.03140767949766346, 0.03640113405085035, 0.023427133980606283, 0.04914668834369097, 0.0073755306158480895, 0.02841974375769496, 0.032609877309628894, 0.086185468892966, 0.10011765879711934, 0.019709025010732666, 0.03927566623315215, 0.04808226028191192, 0.031015520183635608, 0.02292064151593617, 0.11488196333604199, 0.07907220308801957, 2.8747809060982297, 64.82099533081055, 61.57451902117048, 56.8040908404759, 31.903449399130686, 57.7871150289263, 58.042676721300396, 0.9088178617613656, 0.21326891678784574, 0.2555894580270563, 0.3395832452390875, 0.7568760120442936, 0.32427603804639404, 0.20492721082908766, 0.8175117469259671, 0.24328069708177022, 1.3538435761417662, 0.5107230490871838, 0.5568759153996194, 0.9359712047236306, 0.6030677567635263, 13.62440734250205, 49.71152605329241, 56.33129719325474, 61.87462561471121, 72.32392420087541, 70.04902839660645, 77.58774743761334, 75.32465662275041, 73.38902745928083, 76.22526822771344, 79.06413541521344, 74.00767421722412, 70.46230724879673, 68.83772809164864, 72.97176728929792, 73.42610999516079, 72.15260246821812, 70.27554661887032, 71.2116287776402, 69.8878093447004, 70.72827039446149, 72.30349649701799, 75.12033789498466, 69.52790655408586, 68.19185829162598, 68.49926049368722, 73.44127096448625, 75.39354801177979, 72.05302088601249, 73.18110956464494, 69.44958645956856, 72.40359224591936, 69.69446877070835, 70.05439240591866, 74.93534905569894, 69.5578532900129, 67.12353106907436, 69.9924909046718, 72.13887282780239, 70.67076015472412, 74.0885512488229, 71.87864889417375, 70.4369671685355, 66.1315506526402, 67.82100514003209, 71.08081504276821, 65.8597718647548, 62.43076637813023, 64.61987277439663, 64.96872792925153, 60.88882909502302, 56.864422048841206, 62.61653341565813, 63.93436350141253, 64.36190005711147, 62.21528884342739, 60.91798373631069, 63.439075061253135, 61.62890257154192, 60.73004886082241, 62.39806815556118, 59.7213510785784, 62.212335859026226, 59.91383007594517, 60.07225595201765, 57.61931255885533, 59.13889748709542, 55.72393430982317, 58.256121907915386, 56.479891368321006, 55.999816008976524, 58.894244466509136, 64.53797435760498, 61.09391212463379, 61.24705736977713, 61.99248095921108, 63.76827376229422, 60.95067501068115, 62.006988797869, 63.51360838753836, 66.65914821624756, 63.25576073782784, 63.54484054020473, 63.50376279013497, 65.57053920200893, 69.25712135859898, 60.81646360669817, 64.38828236716134, 67.40084062303815, 65.99808270590646, 62.63476548876081, 64.19659546443394, 60.322801045009065, 53.87903472355434, 50.023778097970144, 44.82325989859444, 48.218340805598665, 48.91900757380894, 43.63972112110683, 45.65057495662144, 60.37947750091553, 65.14863763536725, 56.70010757446289, 55.815219742911204, 53.60481711796352, 28.500081028257096, 20.43566128185817, 2.52320379444531, 0.8374661590371812, 2.340203659875052, 0.636235416999885, 1.350122707230704, 0.8026787542871067, 4.644101679325104, 1.3054253799574715, 0.08855180548770086, 0.0640516294432538, 1.3377139845064707, 0.20190502942672797, 0.6886562641177858, 12.374752981322152, 71.42894758496965, 31.263867718832834, 33.92195667539324, 39.05582775388445, 47.790953636169434, 52.394833496638704, 2.6424350993973866, 0.05034687429932611, 0.0566090129182807, 0.020713967603764365, 0.03612605256161519, 0.0183273682570351, 0.052754621886249096, 0.020238479100433842, 0.030446877303932394, 0.035270657390356064, 0.004865992598102561, 0.04474024122048702, 0.10824745148420334, 0.045650940388441086, 0.16956149068261894, 0.2692278219120843, 0.09412762629134314, 0.1387309900351933, 0.2161892500839063, 0.2207809236965009, 0.1707220162664141, 0.12168449402919837, 0.10899542777666024, 0.17845427564212255, 0.1307293251156807, 0.08167545696986572, 0.2595221112881388, 0.23649683967232704, 4.242908784321376, 75.8007332938058, 65.63645676204136, 62.09919834136963, 53.89486966814314, 69.38189710889543, 72.30328110286167, 2.0968175998755862, 1.0904606005975177, 0.3534890333456652, 1.6788021389927184, 1.4522701288972582, 0.9603258350065776, 0.6475118004849979, 1.3025849780866077, 0.32066916301846504, 2.5591068736144473, 0.7700207552739552, 1.991391496998923, 3.3130628509180884, 1.1285715784345354, 22.59673343385969, 57.28133480889456, 66.62023830413818, 74.52635029384068, 82.34445640019008, 81.21050344194684, 84.1031357901437, 83.01055935450962, 78.30999183654785, 81.36413506099156, 81.07417283739362, 80.03798798152378, 74.42146028791154, 76.21637453351701, 77.61294855390275, 77.78872408185686, 76.62586661747524, 73.82446411677769, 77.2177836554391, 74.63921683175224, 74.4975083214896, 78.21680954524449, 78.67953177860805, 74.37259360722133, 73.65327439989362, 73.61822768620083, 77.69635472978864, 80.02712794712612, 77.02360234941754, 77.657806124006, 71.9569342476981, 75.51532214028495, 72.67931761060441, 73.69445637294224, 78.22650228227887, 72.22476645878383, 68.25572613307408, 72.88608210427421, 77.05215944562639, 71.64732946668352, 77.46850940159389, 73.23398535592216, 76.98003714425224, 70.46554510934013, 69.33269691467285, 74.47386360168457, 70.6586285999843, 65.9673855645316, 68.1433390208653, 68.15485218593052, 64.43703787667411, 57.78890071596418, 63.52030645098005, 66.92978055136544, 67.7757237298148, 66.1734343937465, 65.33919892992292, 70.9050395148141, 65.28424562726701, 63.35581479753767, 64.85225527627128, 63.50113637106759, 64.46637317112514, 63.94197872706822, 63.285075187683105, 62.894954681396484, 64.6615411213466, 60.328067779541016, 60.99745028359549, 58.591358593532014, 58.767828941345215, 63.27911363329206, 67.65540872301374, 63.959126881190706, 65.12069892883301, 68.22835717882428, 69.06577491760254, 63.6117308480399, 66.51511900765556, 67.03769997188023, 71.52596528189522, 65.23106411525181, 67.1449454171317, 69.61735071454729, 69.34043720790318, 72.89197417667934, 65.33670452662876, 67.46377045767647, 71.45109149387905, 67.80963788713727, 67.12556689126151, 66.51767594473702, 62.53025068555559, 57.83779518944876, 54.614265305655344, 55.20226008551461, 61.023499080113, 59.81616619655064, 54.15752894537789, 55.7207589830671, 61.32565539223807, 64.3817719050816, 58.98796871730259, 61.69054004124233, 56.164366722106934, 31.32271201269967, 24.78335758617946, 2.6664836832455228, 1.91896282349314, 3.534709300313677, 2.3254875923906053, 1.61175180545875, 1.7916976639202662, 6.854972004890442, 1.9013845324516296, 0.6227919012308121, 0.9932406459535871, 2.2620483679430823, 0.7003106730324882, 1.1175762712955475, 16.23274632862636, 80.93013668060303, 39.10480907985142, 50.298930236271445, 44.20808029174805, 57.67623220171247, 63.26812853131975, 4.057513909680503, 0.15805691587073462, 0.35609311504023416, 0.23036646576864378, 0.15484671241470746, 0.11910616952393736, 0.17239299017403806, 0.10836965564106192, 0.15420941875449248, 0.09416795841285161, 0.0833955296714391, 0.23955665262682097, 0.2000891747219222, 0.37837571650743484], [0.05837106318878276, 0.0515384496455746, 0.03561671703521695, 0.06969552087996687, 0.025787713205707923, 0.05582889102931533, 0.031184210774621794, 0.1019540052594883, 0.03151009418070316, 0.05186534067615867, 0.025725299858355095, 0.08227324632129498, 0.15581538900732994, 0.24123344836490496, 12.95389141355242, 66.9707749230521, 45.5788243838719, 63.114100864955354, 44.6482834134783, 75.6315724509103, 14.549254264150347, 0.3991986805839198, 0.05500919019271221, 0.5690673983522824, 0.0741858688582267, 0.16564369733844483, 0.26327305287122726, 0.24029237457684108, 0.4591609016060829, 0.9265720290797097, 0.6782313606568745, 0.23240348217742784, 0.5691627732345036, 0.9710268207958767, 0.5012045055627823, 36.21321896144322, 40.49438279015677, 52.72564417975289, 58.99056734357561, 65.61419473375592, 64.83629526410783, 67.56449849264962, 66.91460568564278, 70.66551426478794, 71.90521880558559, 74.20071601867676, 72.54372351510185, 69.5982779094151, 69.55983352661133, 68.531708581107, 65.9496259689331, 69.04525688716343, 68.31910760062081, 63.848205838884624, 61.274982179914204, 68.23263726915631, 69.35587610517229, 70.10926233019147, 67.60914761679513, 58.19383825574602, 59.36525590079171, 70.0026422228132, 71.19939994812012, 68.61961024148124, 65.85818767547607, 67.99048560006278, 65.94007219587053, 66.22050843920026, 71.0601441519601, 68.32554858071464, 67.41150610787528, 70.84800175258091, 67.9053840637207, 65.85836832863944, 68.9678817476545, 69.62053993770054, 69.76457609449113, 63.77374199458531, 67.65034348624093, 63.78879874093192, 56.955565043858115, 59.614216804504395, 65.51248700278146, 67.68588352203369, 64.03120054517473, 55.44065277917044, 62.80654580252511, 62.56055872780936, 65.38500840323312, 64.88352216993059, 65.07402093069894, 56.673572404044016, 51.58230767931257, 54.183619431086946, 54.92297376905169, 56.512606961386545, 60.86588614327567, 58.52882480621338, 59.92999158586775, 59.3228371483939, 59.317771911621094, 57.391390800476074, 57.48853356497628, 53.96869427817208, 56.30318478175572, 52.82307876859392, 53.89600222451346, 55.77470827102661, 60.71134431021554, 59.70547444479806, 57.56455727985927, 56.32457481111799, 58.255538259233745, 62.07831900460379, 60.38788482121059, 57.266580309186665, 59.07307720184326, 61.184857095990864, 59.3757198878697, 62.23107515062605, 65.66165093013218, 62.919162205287385, 60.23610142299107, 60.6652638571603, 62.91960688999721, 62.385255677359446, 60.80926527295794, 58.87792314801897, 51.40513556344168, 44.69772332055228, 35.484804562159944, 41.82500103541783, 42.78235510417393, 39.87804283414568, 37.84582676206316, 55.88773461750576, 56.34824384961809, 51.852675982883994, 48.62283713476998, 48.33935758045742, 15.807068416050502, 12.358151129313878, 7.683032257216317, 1.1758774114506585, 0.2582276293209621, 0.2295325462307249, 0.7061054706573486, 1.4676716795989444, 1.32144738308021, 0.9085498675704002, 0.3116415802921568, 0.0973600246278303, 1.2016374234642302, 0.3723095862993172, 0.1357553561351129, 0.080716340935656, 55.33195516041347, 36.121488843645366, 30.372188023158483, 32.740214007241384, 31.722556522914342, 48.0230964251927, 4.878934723990304, 0.18340741842985153, 0.2038000284561089, 0.1155009094093527, 0.1615500005760363, 0.009032712451049259, 0.019084414866353785, 0.01875102686296616, 0.015847192145884037, 0.04339639922337873, 0.09669422571148191, 0.07310593287859644, 0.03611824940890074, 0.028831125968801122, 0.006687092802686883, 0.08264055089758975, 0.03919118523065533, 0.0498689481589411, 0.10828169036124434, 0.06143255212477275, 0.030976117655102695, 0.06766864178436142, 0.09437352738210134, 0.04958303046545812, 0.0723053633368441, 0.05269028998113104, 0.11391890501337391, 0.3396414635436875, 17.282683406557354, 73.709561756679, 53.95622226170131, 61.17326750074114, 32.30357183728899, 87.36299433026994, 20.25234001023429, 0.42922124958464075, 0.01188842800911516, 0.16136946954897471, 0.22491616037275108, 0.2963344545236656, 0.42310080943363054, 0.23528408046279634, 0.26934702694416046, 0.8425765048180307, 0.454926707382713, 2.123723630394254, 1.6508104524442127, 0.8790739263807024, 1.6033582729952676, 51.01438971928188, 52.6084280695234, 63.70139735085623, 63.521439007350374, 69.61059706551688, 68.77970368521554, 73.735534123012, 70.5513275691441, 74.15434374128068, 75.29670401981899, 79.12338270459855, 77.4588097163609, 71.65612588609967, 72.74992520468575, 71.80309418269566, 71.42385455540249, 73.85872568402971, 72.1501567023141, 66.98129449571881, 65.2833423614502, 69.71563298361642, 70.32149505615234, 73.07766478402274, 72.39804063524518, 67.0530902317592, 67.74671500069755, 71.69384070805141, 74.59499849591936, 71.93139961787632, 69.0884677342006, 71.74131774902344, 68.10126767839704, 70.72653334481376, 72.68183285849435, 69.90572180066789, 70.77185644422258, 73.79506628853935, 68.71582194737026, 70.08235890524728, 71.7386496407645, 71.21075330461774, 68.54291602543422, 64.27357455662319, 70.94313648768834, 65.97583457401821, 58.65699822562081, 62.27473068237305, 68.91256713867188, 72.27641241891044, 65.169127873012, 59.07978916168213, 68.15613760266984, 63.42773560115269, 66.4059419631958, 62.7215484891619, 68.05301243918282, 62.29164259774344, 53.481622082846506, 54.59388971328735, 56.062363692692344, 57.53162281853812, 64.25216020856584, 61.0901323046003, 62.38891042981829, 61.51024123600551, 61.559309414454866, 58.17780876159668, 62.25326074872698, 55.98397759028843, 57.11420978818621, 55.57673672267369, 57.65734004974365, 58.15469210488455, 61.805775914873394, 61.990820339747835, 60.493566921779085, 59.19941629682268, 62.45127051217215, 64.87226608821324, 61.79429054260254, 62.01045594896589, 62.28339508601597, 64.39309746878487, 63.36113016945975, 65.34642505645752, 65.66691071646554, 66.65840475899833, 62.587295395987375, 63.42422676086426, 63.963295800345286, 67.30700520106724, 63.02258614131382, 64.12989970615932, 57.771478107997346, 55.379182066236226, 48.095983028411865, 49.25391074589321, 47.014231886182515, 41.516567025865825, 44.54647145952497, 59.44632053375244, 63.128858838762554, 61.945108141217915, 51.52542972564697, 55.355005809238975, 35.14468329293387, 25.613561357770646, 12.177069783210754, 1.7418797314167023, 0.9823186205966132, 0.08594840232815061, 0.5154852249792644, 2.0535329282283783, 1.2625291560377394, 0.20872790259974344, 0.4093865310507161, 0.10272524851773467, 1.9924786729472024, 0.4650334322026798, 0.15241652567471775, 0.27042627760342186, 57.38581487110683, 35.845273630959646, 25.50085810252598, 38.22128309522356, 36.17742184230259, 58.85199247087751, 5.522491208144596, 0.15765316039323807, 0.18944297385002884, 0.03138237353414297, 0.06697749279971633, 0.019239231112546155, 0.04037241631054452, 0.06982594888125147, 0.010994592980880822, 0.021286242342154895, 0.033367217385343144, 0.05442098854109645, 0.052310337512088675, 0.02057659818923899, 0.1983308055038963, 0.12330056088311331, 0.11102101765573025, 0.2631585975842816, 0.14944570937326976, 0.16058489307761192, 0.1674611805272954, 0.24085441870348795, 0.17646605947187968, 0.159426959497588, 0.18406204187444278, 0.14216259946780546, 0.3576828140233244, 0.4820761691246714, 21.113902739116124, 87.4303571156093, 56.168559959956575, 76.83331203460693, 58.100919995989116, 102.2166656766619, 23.26429377283369, 0.6538892697010721, 0.17896306834050588, 1.610510140657425, 0.48938382842711037, 1.8591310169015611, 0.682105687047754, 0.9035707776035581, 1.5872477889060974, 1.9213052349431174, 1.204998831663813, 4.5451580286026, 4.75192208800997, 1.9724320343562534, 3.3157693914004733, 61.84875052315848, 57.08401986530849, 73.29237106868199, 69.70195892878941, 77.44494111197335, 78.01113591875348, 82.0926467350551, 76.63212694440568, 80.8597514288766, 78.8501170022147, 83.05565316336495, 82.41831575121198, 77.25820132664272, 78.74722112928117, 77.58184841700962, 75.32756791796002, 77.3640501839774, 76.56768240247453, 70.71003137316022, 69.02103546687535, 74.54886940547398, 74.55213505881173, 78.88446194784981, 73.58388274056571, 70.88753700256348, 71.95340456281389, 78.80045127868652, 75.24347387041364, 76.81482287815639, 72.28954451424735, 73.04809325081962, 71.06932967049735, 73.8016253880092, 77.14047799791608, 73.06822218213762, 72.59444536481584, 76.40692887987409, 73.263306753976, 73.60501221248082, 73.92508792877197, 76.00674043382917, 77.13901887621198, 69.4557078225272, 73.301271711077, 70.00176674979073, 63.530110359191895, 63.75992202758789, 71.45671258653913, 74.920382635934, 67.19257531847272, 61.35881219591413, 67.43888895852226, 66.14473138536725, 68.97478130885533, 67.27631500789097, 68.30150086539132, 61.73404271262032, 55.795059544699534, 58.69012723650251, 58.20195027760097, 63.107875279017854, 66.50300134931291, 63.17989335741316, 65.69120161873954, 64.33309977395194, 61.75260135105678, 60.14656693594796, 63.644991874694824, 60.562263761247905, 59.77870150974819, 58.07571540560041, 59.89377062661307, 61.17949308667864, 67.53388472965786, 64.41950062343052, 64.01705401284354, 63.66325868879046, 63.85089479173933, 67.43127373286656, 65.6078440802438, 64.12575857979911, 65.04650606427873, 68.01592295510429, 66.88203947884696, 68.1796155657087, 70.30743190220424, 66.51188809531075, 65.25916263035366, 66.3140172958374, 66.57137857164655, 69.80174895695278, 65.2916385105678, 66.83556297847203, 61.500235830034526, 58.12849392209734, 51.39389337812151, 54.23890624727522, 54.90133360454014, 55.756618635995046, 55.23625414712088, 64.4136016028268, 61.23276492527553, 59.39864894321987, 54.100689206804546, 60.81691523960659, 37.705323764256065, 29.282984937940324, 13.992710505213056, 1.9676041219915663, 1.4864209592342377, 0.30684659044657436, 1.6087162026337214, 4.025928267410823, 4.448799107755933, 2.738463329417365, 1.3593808561563492, 0.28135465404817034, 4.682920396327972, 0.732651660484927, 0.3797156331794602, 1.2370787731238773, 66.38212353842599, 49.69901582172939, 45.87132964815412, 46.75801011494228, 43.07389804295131, 68.81340939658028, 7.534788966178894, 0.3134362782750811, 0.30796058209879057, 0.15580183187765734, 0.23963582409279688, 0.14239623264542647, 0.15861079043575696, 0.20702640818698065, 0.10381871448563677, 0.10883349539445979, 0.12383380798356873, 0.1611596258091075, 0.14679623368595326, 0.16881142450230463], [0.039075444119849374, 0.06913517987621681, 0.035041027569345067, 0.04006730964673417, 0.027078648131074648, 0.07551304264260189, 0.07856580561825208, 0.021948000582467233, 0.02287603632014777, 0.0718986698027168, 0.035669205111584494, 0.015210271679929324, 0.04208217867250953, 0.08478678430297545, 33.904193605695454, 59.912822587149485, 40.07107073920113, 38.0242669241769, 42.4669520514352, 66.39445659092495, 2.714200437068939, 0.11039002080048833, 0.039198706791337044, 0.09649371182812111, 0.1398137690765517, 0.12165229075721332, 0.2721824619386877, 0.26865155569144655, 0.044587336746709685, 0.7051703408360481, 1.0213730335235596, 0.9420348107814789, 0.43232231746826855, 0.4623462163976261, 22.568905898502894, 47.329506397247314, 60.40096133095877, 67.35466984340123, 68.80095822470528, 66.41308471134731, 66.95936598096574, 69.8493024281093, 69.1581095286778, 64.81681251525879, 72.52824987683977, 70.8616897038051, 72.1380181993757, 68.30988734109062, 71.85533768790108, 68.6842006955828, 68.09714739663261, 61.24834278651646, 57.24622208731515, 56.05498817988804, 58.57241085597447, 57.722719124385286, 60.501800537109375, 60.97866235460554, 64.99916798727853, 69.98017869676862, 66.69152682168144, 64.77287905556815, 66.54311329977853, 65.43164471217564, 66.228394644601, 65.95875590188163, 69.71650150844029, 69.23664501735142, 71.09154306139264, 69.63968917301723, 70.97434779575893, 67.17058426993233, 68.37351199558803, 70.26893193381173, 66.61695875440324, 62.71161256517683, 62.50885023389544, 69.61293860844204, 61.22883224487305, 56.30076333454677, 63.02305167061942, 71.034241267613, 69.94187327793666, 64.92466245378766, 50.96575927734375, 60.96265370505196, 63.319982937404085, 60.510881832667756, 62.062991278512136, 57.47618661608015, 68.03360612051827, 68.52621950422014, 61.35197516850063, 52.160835538591655, 47.9028821672712, 52.95621320179531, 57.84106431688581, 58.68827206747872, 62.09132603236607, 62.54963615962437, 60.64792810167585, 62.59417411259243, 60.18190547398159, 57.822199957711355, 53.89863211768014, 54.77778768539429, 54.97271939686367, 53.22108200618199, 52.76795523507254, 56.47431196485247, 58.69449765341622, 57.34383385522025, 56.47200516292027, 60.78379317692348, 58.81409004756382, 59.7475596836635, 58.58086681365967, 57.778853620801655, 60.864211627415244, 59.06126526423863, 62.374791690281455, 62.58175768171038, 61.67631707872663, 57.05927733012608, 59.91973604474749, 63.53095803941999, 61.40914494650704, 61.23842770712716, 56.858641147613525, 52.43591819490705, 42.89471442358834, 42.80961636134556, 47.69458212171282, 31.745940685272217, 37.482234477996826, 49.23306615012032, 54.228921685900005, 51.67332213265555, 43.69390664781843, 43.767272676740376, 32.16829735892159, 8.991788864135742, 12.58503326347896, 5.271602179322924, 0.19277676567435265, 0.4133759912635599, 0.22315572840826853, 0.11708649647022996, 0.4504729392273085, 0.2495036774447986, 0.459681365106787, 0.8810145908168384, 0.4712853452989033, 0.4138331338763237, 0.33261868038347786, 0.7818558173520225, 23.008730343409947, 49.20825413295201, 18.68215482575553, 45.201763016836985, 31.20412015914917, 48.05969953536987, 5.489974941526141, 0.262005766587598, 0.2246692550501653, 0.034430071245878935, 0.028836778165506463, 0.1145222040691546, 0.05136559284957392, 0.1045038720060672, 0.02178181378569986, 0.003365745946731684, 0.030436967299985032, 0.013755752139591744, 0.08862574544868299, 0.03679385654894369, 0.10822549409099988, 0.010777000371100647, 0.05710807203182152, 0.035370483462299616, 0.003990990309310811, 0.05728878626333816, 0.055228190762656074, 0.0416852390792753, 0.08101423816489321, 0.03725865642939295, 0.03157211567408272, 0.1164584851690701, 0.08236290793865919, 0.036648395604320934, 41.83292198181152, 63.66734422956194, 54.2956417628697, 40.616334097726, 41.25190666743687, 80.08196313040597, 3.476553746632167, 0.21445746586791106, 0.05407991273594754, 0.1940854697355202, 0.1248271425387689, 0.13434407114982605, 0.3321425387901919, 0.22641845047473907, 0.1290432470185416, 3.2780880076544623, 2.841538769858224, 0.8006105795502663, 0.7129053143518311, 0.6013288072177342, 33.21450499125889, 61.13997173309326, 70.7387204851423, 77.39337853022984, 76.33835015978131, 73.09907218388149, 71.29719584328788, 72.88095433371407, 76.37009647914341, 70.46702507564, 72.18392494746617, 73.84238352094377, 75.62276908329555, 70.95302377428327, 73.7690452848162, 71.17378193991524, 73.83289922986711, 65.79878752572196, 62.60005923679897, 60.33497428894043, 62.39733164651053, 60.43858582632882, 63.168185642787385, 60.84135205405099, 65.5548015322004, 71.6307441166469, 72.85528073992047, 70.22269862038749, 68.82749339512416, 70.31149659837995, 69.52093056270054, 71.50464126041958, 75.02411229269845, 71.91824667794364, 74.79758712223598, 70.17328998020717, 72.61411571502686, 70.96159785134452, 70.73922770363944, 71.37409850529262, 71.46688474927629, 63.2192896434239, 65.4234597342355, 71.30381747654506, 62.197987828935894, 60.53854955945696, 68.54312447139195, 71.47184576307023, 70.8846048627581, 65.57039328983852, 53.3863205909729, 63.461156436375205, 66.58883939470563, 63.625946862357004, 64.1770293372018, 61.84092685154506, 65.30283900669643, 68.86523600987026, 62.16982678004673, 54.841843128204346, 49.21180813653128, 53.5271258354187, 60.71126093183245, 61.54171657562256, 63.74710954938616, 65.67428275517055, 60.65228462219238, 61.78309004647391, 60.24209771837507, 62.2093620300293, 58.086144651685444, 57.99760028294155, 57.06044462748936, 55.61225243977138, 55.24827800478254, 57.31468268803188, 62.072475569588796, 60.6631863457816, 60.09434427533831, 61.4848872593471, 62.55251966203962, 64.41887528555733, 62.90506431034633, 61.235141209193635, 63.288111550467356, 63.25880404881069, 65.09225300380162, 64.5849997656686, 64.19817270551408, 60.25708498273577, 62.94353648594448, 64.88163225991386, 64.32002326420375, 65.2980933870588, 63.18995434897286, 59.79327883039202, 55.02263872964041, 48.29694925035749, 49.51262692042759, 41.06155381883894, 40.09256499154227, 51.341663769313264, 60.09444155011858, 63.601114000592915, 56.782474994659424, 52.89533308574131, 46.117584228515625, 27.23019872392927, 24.96600488254002, 9.009043846811567, 0.08326153936130659, 0.9796020920787538, 0.22594624438456126, 0.15633673460355826, 0.7639120402080672, 0.4745423676712172, 0.62172063014337, 1.0844903609582355, 0.6007002123764583, 0.44381811203701155, 0.08923703086163316, 0.6624086839812142, 24.9639082636152, 55.492125034332275, 16.411610330854142, 42.179293155670166, 37.93822390692574, 57.767420360020225, 7.920535581452506, 0.15372803887086256, 0.15200237504073552, 0.031252987084112, 0.06544356260980878, 0.07619873620569706, 0.06256926112941333, 0.005256055238922792, 0.06364879677338259, 0.058980285855276246, 0.0734916664659977, 0.02624736979071583, 0.048263357885714085, 0.04835974717778819, 0.15109544513481005, 0.14483013775731834, 0.10586413794330188, 0.11305440390216452, 0.1212981633309807, 0.19965865782329015, 0.17028774028377874, 0.14571953431836196, 0.13357807296727384, 0.1599310160215412, 0.10261732073766844, 0.13489989989570209, 0.19948605208524636, 0.20409094356000423, 47.73452731541225, 77.18789945329938, 50.900772775922505, 49.61110026495797, 60.199387141636436, 83.14233194078717, 4.511644261223929, 0.5112796649336815, 0.21005304077906267, 0.3211205516542707, 1.0688870953662055, 0.462162903376988, 0.8991181765283857, 0.45203715243509834, 0.3747752197086811, 5.8885970030512125, 5.120470174721309, 1.262202916400773, 2.7719054434980666, 0.8328142315149307, 46.638587951660156, 65.14813041687012, 73.12778214045933, 80.99750641414097, 83.31318814413888, 79.67807129451207, 77.74686118534633, 80.59728322710309, 82.61430358886719, 74.6261820111956, 74.40326295580182, 80.79500116620744, 81.586991582598, 77.8481033870152, 79.87039743150983, 76.7154358455113, 78.09825938088554, 73.35678086962018, 67.32883644104004, 65.32171726226807, 69.75420243399483, 66.46268095288957, 71.97913374219621, 71.98201724461147, 71.72016743251255, 77.08745629446847, 76.60086005074638, 74.53891263689313, 73.53653076716832, 73.96242059980119, 72.73837729862758, 73.10645811898368, 76.64552307128906, 75.42867810385567, 78.70995794023786, 73.04805850982666, 75.63526889256069, 74.43789972577775, 74.70210497719901, 72.68098517826625, 75.90855543954032, 69.21538352966309, 68.2328040259225, 75.67110770089286, 67.69723687853131, 62.4690648487636, 68.30853939056396, 77.09543977464948, 74.3419520514352, 69.42583056858608, 56.41092354910714, 63.884378160749165, 70.65846184321812, 64.41876411437988, 68.90141527993339, 62.17617743355887, 71.31075177873883, 74.31192888532365, 66.17140551975795, 55.89273732049124, 52.31565877369472, 57.990058013371055, 63.33039133889334, 63.7899660382952, 66.79809134347099, 67.87818881443569, 65.38173580169678, 64.94338090079171, 64.39404937199184, 63.25194617680141, 59.065892764500205, 61.438820702689036, 60.47194412776402, 57.452156271253315, 58.216795103890554, 63.0053129196167, 64.585604258946, 64.09246976034981, 63.41637529645647, 64.12535558428083, 64.91274629320417, 65.00139141082764, 65.57906464168003, 63.58366707393101, 66.3361542565482, 66.9150503703526, 70.10569095611572, 68.20074503762382, 67.35185582297188, 61.763252939496724, 67.7999382019043, 68.07629585266113, 67.14926024845668, 67.91221414293561, 66.03508186340332, 63.68861961364746, 54.46907574789864, 52.41770349230085, 61.52229636056082, 50.52400670732771, 50.22947951725551, 63.94713429042271, 64.52303573063442, 61.333215032305034, 55.56301403045654, 55.618540559496196, 52.47379282542637, 30.430327074868337, 32.45502519607544, 10.396076253482274, 0.2891184245901448, 1.4608660276447023, 0.3321589593376432, 0.9300006393875394, 1.066886882696833, 1.2219492878232683, 1.1807198716061456, 1.490512796810695, 1.1839442700147629, 1.0566613056829997, 1.3811419627496173, 1.0091353016240256, 34.064575399671284, 65.49696472712925, 30.197871616908483, 60.18577562059675, 42.527265889304026, 71.99847752707345, 10.589954444340297, 0.3025689428406102, 0.41631127947143143, 0.09288006502070598, 0.11471318453550339, 0.22549070311444147, 0.14952976629137993, 0.17513961850532464, 0.08319726173899003, 0.15846158058515616, 0.17073694403682435, 0.12417540965335709, 0.15157112532428332, 0.1577163455741746], [0.014320352646921362, 0.06687312054314784, 0.058809274674526284, 0.012978597144995416, 0.04057128813916019, 0.08569836895912886, 0.0705361579145704, 0.05038253470723118, 0.03618985181674361, 0.04291911429858633, 0.012504464015364647, 0.05699038691818714, 0.051919776148029735, 0.21623906812497548, 49.7544971874782, 45.21208803994315, 33.61695160184588, 29.38707937513079, 46.49082408632551, 48.38037279673985, 0.15363567668412412, 0.11422094809157507, 0.24958518307123864, 0.27431428326027735, 0.2430259750357696, 0.6308067025882858, 0.6958784822906766, 0.5388482170445579, 1.239853492804936, 0.6207946741155216, 0.5963815812553678, 0.357284921088389, 0.7359444552234241, 13.143927250589643, 53.66768094471523, 61.005774225507466, 72.6572709764753, 72.59234006064278, 73.03082697732108, 71.46338980538505, 69.39771120888847, 71.11981528145927, 70.43342358725411, 70.45448357718331, 67.20439420427594, 67.83827141353062, 64.18250451769147, 65.28919969286237, 64.9579929624285, 66.0351791381836, 64.84320177350725, 60.4530519757952, 58.812471117292134, 54.55869013922555, 52.76539829799107, 55.1300995690482, 57.77243348530361, 58.73514461517334, 57.765269892556326, 54.904168469565256, 59.84527220044817, 65.93650082179478, 63.44455024174282, 70.1783343723842, 68.5084251676287, 70.93666076660156, 66.41456467764718, 67.03669248308454, 67.95730100359235, 67.99824673788888, 69.31437451498849, 67.3468461717878, 69.46536581856864, 65.20293085915702, 62.08980437687465, 59.603085790361675, 71.52954360416958, 57.1093738419669, 59.73431641714913, 69.87927000863212, 70.35057326725551, 64.73076602390834, 70.49403272356305, 52.13338668005807, 59.04345703125, 65.23006357465471, 61.59119469778878, 65.6942240851266, 58.6523220879691, 60.96426568712507, 59.59711033957345, 60.156718254089355, 58.00152948924473, 60.28395366668701, 51.846992356436594, 46.49378054482596, 51.71038382393973, 58.332955087934224, 55.763382707323345, 62.810214451381135, 63.18618147713797, 68.38157885415214, 63.48727471487862, 62.41339588165283, 61.707222666059224, 58.09520162854876, 56.17954158782959, 56.00883477074759, 54.41516120093209, 52.548357418605256, 54.7610251562936, 56.76916919435774, 57.79920836857387, 57.68209300722395, 59.654426029750276, 60.15234088897705, 58.295268058776855, 60.016725948878694, 58.276806695120676, 59.640216963631765, 60.59729657854353, 60.009840284075054, 62.16371236528669, 61.039403506687705, 59.625389507838655, 61.354483468191965, 61.58173125130789, 62.49062510899135, 59.79668344770159, 56.436777796064106, 50.513421126774375, 41.70594712666103, 41.28271150588989, 48.98873274666922, 32.387585980551584, 33.39609268733433, 51.08615071432931, 52.21084519795009, 47.25074509211949, 37.774468762534006, 33.78301007407052, 18.68134014947074, 6.289736483778272, 13.197477885654994, 2.083373704126903, 0.3448140988392489, 0.19911885607455457, 0.054757901533905945, 0.26534934288689066, 0.7290496166263307, 0.23503155687025615, 0.23932016960212163, 0.31164730712771416, 0.17285731168729918, 0.22893855667540006, 0.3719754213733332, 3.6912921667099, 49.94291148866926, 25.27024391719273, 32.93122346060616, 24.358400549207413, 49.943575041634695, 9.73682769707271, 0.15309051450874123, 0.13984450671289647, 0.031884808359401565, 0.10089122264512948, 0.03603349359972136, 0.052067377870636325, 0.06326530235154287, 0.019898046207215105, 0.013326457452162035, 0.0703584428078362, 0.044062238851828237, 0.04201877296769193, 0.010899731240767454, 0.029479021738682474, 0.0358606266256954, 0.025884428194590976, 0.01938326713362975, 0.021749259371842657, 0.061784867862505574, 0.014267791628039308, 0.020959227478929927, 0.024068278327052082, 0.07292172419173376, 0.02525477483868599, 0.03618532938084432, 0.03849951716672097, 0.41254223457404543, 59.85938399178641, 55.40273298536028, 55.63377101080758, 22.413255827767507, 49.27975804465157, 57.69326571055821, 0.16351644934288093, 0.09113457439733402, 0.24875232204794884, 0.4672583213874272, 0.17333886799003395, 1.655082943184035, 0.489443050963538, 1.8984947332314082, 3.2244162133761813, 0.5043378717132977, 1.0054273520197188, 0.3610228890819209, 0.8905577787331173, 19.034385068076, 70.68487194606236, 72.19636222294399, 82.56330381120954, 77.1109481539045, 78.47211415427071, 76.9463939666748, 74.17364583696637, 73.49218041556222, 76.65231840951103, 71.65461117880685, 69.01276016235352, 72.81862204415458, 66.97567340305874, 69.38102163587297, 67.41484819139752, 68.62566212245396, 67.32142966134208, 63.48129231589181, 61.765267917088096, 62.188058853149414, 62.73126901899065, 61.33849566323416, 64.85653536660331, 70.02436229160854, 66.78428527287075, 60.84795979091099, 64.57168701716832, 71.9838307244437, 70.08850111280168, 73.46516581944057, 72.12695666721889, 74.63951560429165, 70.56841318947929, 72.3928781236921, 72.79337229047502, 69.89907932281494, 71.64828136989048, 70.49008614676339, 71.09378038133893, 66.33216599055699, 62.48279448917934, 63.73752103533064, 70.23218985966274, 58.31502178737095, 65.72292709350586, 71.90045234135219, 70.65115233830043, 67.32037353515625, 71.58100891113281, 53.70216832842146, 65.47451509748186, 66.75508894239152, 65.0260088784354, 65.91517680031913, 59.631531715393066, 62.48195375714983, 61.23787185123989, 60.034881591796875, 57.559165477752686, 61.928856304713655, 57.05884306771414, 48.5529591015407, 51.263597284044536, 57.29586001804897, 56.51587956292288, 62.405426297869, 64.1731036049979, 68.3316490990775, 65.00849941798619, 63.81370803288051, 63.12985937935965, 62.19224861689976, 59.90918867928641, 58.93158408573696, 58.79162652151925, 57.196219376155305, 55.78607552392142, 56.42539317267281, 62.202420779636924, 58.99791158948626, 63.269657135009766, 63.02472618647984, 62.0989898954119, 63.35646792820522, 61.38878672463553, 61.35742950439453, 63.54990577697754, 64.7150491986956, 64.17040770394462, 63.36679295131138, 62.3164963041033, 64.30787086486816, 63.811137199401855, 65.50726195744106, 65.00683879852295, 61.26953479221889, 59.09128148215157, 52.942316804613384, 45.4767553465707, 49.78195994240897, 35.027286529541016, 40.05064998354231, 56.906660148075645, 62.69955744062151, 63.5712228502546, 53.97535065242222, 50.344062260219026, 39.721899441310335, 20.574161461421422, 22.480667250497, 3.313662133046559, 0.050852393066244464, 0.16062708438507148, 0.18539579744849885, 0.8035532502191407, 1.273084772484643, 0.11547930485435895, 0.5299920865467617, 0.37005039038402693, 0.2623448169657162, 0.3873475236552102, 0.46188074137483326, 4.555598999772753, 59.48696749550955, 21.686364821025304, 35.147587639944895, 32.21846335274832, 59.58343628474644, 13.194033316203527, 0.18188061964298996, 0.19831049016543797, 0.02775035030208528, 0.11881832139832632, 0.018375640934599296, 0.00046876734891806597, 0.03110193501093558, 0.06192509390945945, 0.04951748737533178, 0.03984192066958972, 0.11481143640620367, 0.07786933013371058, 0.030281413146959882, 0.08330416493117809, 0.16817156597971916, 0.13641808128782681, 0.08773574499147278, 0.0906301446791206, 0.1520141408379589, 0.10996461327054671, 0.13050804127539906, 0.10382349137216806, 0.14344800263643265, 0.10348215433103697, 0.06405420787632465, 0.14449830699179853, 0.9095975256391934, 70.34272180284772, 60.7895393371582, 44.47517251968384, 41.502649784088135, 63.977435384477886, 62.141693523951936, 0.18552979454398155, 0.2796779397342886, 0.32104827410408426, 0.5575029360396522, 0.5418334454298019, 2.7490932047367096, 2.3592256563050404, 3.541121401957103, 5.761729410716465, 2.571522435971669, 1.9986510617392403, 1.0818322407347816, 1.9229150457041604, 25.70465918949672, 77.53193950653076, 72.47167764391217, 86.6664652143206, 82.97772911616734, 83.24251801627022, 78.72908633095878, 80.01043142591203, 79.21684987204415, 80.08283165522984, 73.98822620936802, 74.13692460741315, 77.27191707066127, 73.7723387309483, 74.47935962677002, 74.71868337903703, 75.23467050279889, 75.03295040130615, 70.17885548727853, 69.3481080191476, 70.36007145472935, 71.06308323996407, 69.44988523210797, 72.59136731284005, 74.98754392351422, 73.74186393192836, 69.24268300192696, 71.544127873012, 76.71651281629289, 72.45008959089006, 77.74179594857353, 74.98951721191406, 77.73030362810407, 71.53510216304234, 73.97737312316895, 74.22863388061523, 75.29851055145264, 73.26088878086635, 72.81457819257463, 74.73503943852016, 69.60610158102853, 68.35999774932861, 64.5623277936663, 75.38172912597656, 64.28635229383195, 66.36380113874162, 75.15645463126046, 75.63150296892438, 68.53483527047294, 76.02308954511369, 55.88837732587542, 63.84558636801583, 69.79639884403774, 67.82884270804269, 68.94887147630963, 63.17446681431362, 65.34126254490444, 63.70416273389544, 64.29277242933, 60.25575787680489, 63.74233613695417, 56.913351263318745, 50.69647489275251, 54.93836055483137, 61.24636254991804, 59.230377469744, 66.89611652919224, 68.7769660949707, 72.72257014683315, 66.9932176045009, 70.07764107840401, 65.49472740718296, 64.0958604812622, 61.54309926714216, 59.81876482282366, 61.18783787318638, 59.86256626674107, 60.59835270472935, 61.54397474016462, 62.73252664293562, 63.14021219526018, 65.29284054892403, 65.49058628082275, 62.66132150377546, 65.4348200389317, 65.01316860743931, 65.95995099203927, 67.30037661961147, 65.96379334586007, 68.79953384399414, 67.08751855577741, 62.947253772190635, 66.15149198259626, 65.54539367130825, 68.50247750963483, 66.41658660343715, 63.938108580453054, 62.164761543273926, 53.130449703761506, 54.799525124686106, 60.098784174237935, 50.21613550186157, 55.17279972348894, 63.64372035435268, 63.071911403111045, 58.669574465070454, 51.24241917473929, 52.12916217531477, 44.9887694631304, 25.062709910529, 29.670218467712402, 2.356115686041968, 0.47326281347445076, 0.40219150856137276, 0.3689000563962119, 1.691877345953669, 2.3460937780993323, 0.8387391992977687, 1.4599096732480186, 0.9153808695929391, 0.7538070795791489, 1.118841820529529, 0.8442170939275196, 8.182550413267952, 67.3081169128418, 41.1746426991054, 46.937725271497456, 33.185155800410676, 74.52758012499127, 15.732889447893415, 0.2646240975175585, 0.42978766347680775, 0.08130081743001938, 0.19797977219734872, 0.12547028517084463, 0.09382493181952409, 0.10329411870666913, 0.1510260717145034, 0.10385367939514772, 0.13877936958202294, 0.17323103520487035, 0.1374716018991811, 0.14351268059441022], [0.02188339047799153, 0.0987576846299427, 0.06119377565171037, 0.010208018223888107, 0.01949482168337064, 0.02971960311489446, 0.018253521594618047, 0.05012612650170922, 0.02076547858970506, 0.03348553692921996, 0.07327408742691789, 0.059926007608217854, 0.28356038140399115, 7.448237861905779, 66.24488966805595, 33.50954287392752, 41.24201590674264, 28.212804283414567, 69.20613547733852, 21.61540981701442, 0.2494402208498546, 0.23176780343055725, 0.3683604582079819, 0.1411865132727793, 0.09040899654584271, 0.5742180762546403, 0.8326358582292284, 1.596174812742642, 2.8506947585514615, 0.28032900765538216, 0.7629488461783954, 0.7601637041994503, 12.576283744403295, 54.23566491263253, 68.38495567866734, 72.54622486659459, 77.80212020874023, 78.32166481018066, 76.03409549168178, 74.74806036267961, 72.64971828460693, 75.26999514443534, 76.20434025355748, 75.38894135611397, 69.75704424721854, 67.53251593453544, 65.66378402709961, 63.20938846043178, 60.40860434940883, 57.568288462502615, 57.788713114602224, 57.04529408046177, 49.649277142116, 49.986459323338096, 51.707132066999165, 50.4558344568525, 54.44529206412179, 61.30535275595528, 62.295422417776926, 63.55588122776577, 60.06650979178292, 67.28064373561314, 64.29443999699184, 65.5913837977818, 70.67690931047711, 69.06863062722343, 67.91319383893693, 71.17836080278668, 67.96519415719169, 68.75341864994594, 67.60757732391357, 67.52612359183175, 62.86668940952846, 60.836481366838726, 65.47721794673375, 71.64823968069894, 56.26438256672451, 63.03669793265206, 70.26384585244315, 66.80601228986467, 65.40904222215924, 71.19394561222622, 54.105455671037944, 56.40702908379691, 70.82578836168561, 56.45869588851929, 61.70094149453299, 61.179583413260325, 60.332938466753276, 57.18366398130144, 63.63721684047154, 59.01779038565499, 61.26305907113211, 64.28998620169503, 65.9580888748169, 57.52896513257708, 49.64207533427647, 50.95383964266096, 59.27688871111189, 55.43693549292428, 59.51455184391567, 60.58951459612165, 65.26378318241665, 62.70787443433489, 63.77973134177071, 58.92289883749825, 58.20769991193499, 60.00245434897286, 56.30146510260445, 56.50454705102103, 54.23788138798305, 52.38268109730312, 57.08064998899187, 55.581829752240864, 59.27258082798549, 56.36482572555542, 61.99179308755057, 58.570694650922505, 58.70544801439558, 59.31757736206055, 59.82648427145821, 58.607652119227815, 58.319440841674805, 62.324396405901226, 60.941989762442454, 59.351317814418245, 64.14674908774239, 56.9073098046439, 62.001291275024414, 55.35993903023856, 54.34326124191284, 45.85693645477295, 45.27261727196829, 41.36504071099417, 32.49535948889596, 30.834764344351633, 50.44648912974766, 49.02750369480678, 44.4562907900129, 39.30311066763741, 32.865910393851145, 20.95154765674046, 8.38601451260703, 5.104183597224099, 8.483791300228663, 1.0644258090427943, 0.3171681123120444, 0.3063632563820907, 0.2899954446724483, 0.9831791115658624, 0.5013094342180661, 0.31581986322999, 0.41297649698598043, 0.2673073506781033, 0.2297444934291499, 0.2309908808342048, 0.13037875321294579, 37.44745874404907, 26.431213208607264, 42.85842398234776, 32.134247711726594, 45.98820529665266, 15.77186015674046, 0.23581993313772337, 0.2973465302160808, 0.11520224543554441, 0.04520640156364866, 0.03947482983182583, 0.011092423311700779, 0.07979107022817646, 0.015980717659528767, 0.030382355409009115, 0.0693411695371781, 0.043677160050719976, 0.01607504250880863, 0.07070353893297059, 0.033069635674889596, 0.07248963987720863, 0.02415751925270472, 0.02364728636374431, 0.013342621852643788, 0.021489112438367944, 0.05382739592875753, 0.009451375342905521, 0.03326310636475682, 0.013672937788734478, 0.12207002405609403, 0.054529299693448205, 0.41079592970865114, 9.773961475917272, 71.25089999607631, 44.032655647822786, 47.18726634979248, 26.870301144463674, 81.28437668936593, 26.29410093171256, 0.25450021933232037, 0.06429425320987191, 0.28937941629971775, 0.23256814905575343, 0.6018754893115589, 0.5621907444936889, 2.3366216463702063, 2.331395081111363, 3.985461958817073, 0.1207862493715116, 0.733270104442324, 1.091868370771408, 17.012980393001012, 65.79693235669816, 77.19447939736503, 81.8391695022583, 84.12816320146833, 84.17166587284633, 79.17814145769391, 78.56818689618791, 75.49763897487095, 77.80893639155796, 78.93349538530622, 75.44975893838065, 74.19102328164237, 71.53792313167027, 69.85739013126918, 65.39044884272984, 64.95636708395821, 62.95443820953369, 65.08325508662632, 59.28439276559012, 58.672728947230745, 57.56374086652483, 59.05542877742222, 58.198854855128694, 60.498917034694124, 65.50026512145996, 69.46082169669015, 72.80550384521484, 68.94804464067731, 73.186612537929, 72.03150926317487, 68.9098573412214, 71.2123235974993, 71.28300067356655, 72.62767165047782, 72.67939404078892, 69.26561900547573, 70.86282226017543, 69.38817133222307, 68.08076354435512, 65.28127179827008, 62.87809140341622, 69.27413054874965, 71.42386150360107, 58.08128438677107, 66.01416778564453, 72.92487389700753, 67.61571366446358, 68.39815030779157, 71.63094561440604, 52.65404299327305, 61.99126502445766, 70.6644789831979, 59.74067401885986, 62.710674558367046, 60.57593781607491, 65.8158870424543, 61.339107104710166, 65.27831881386894, 61.12217739650181, 60.84253324781145, 65.44216428484235, 66.87104048047746, 59.129802295139854, 53.78320516858782, 53.684276717049734, 57.854658467429026, 56.30686732700893, 58.185556003025596, 60.007887840270996, 63.12122276851109, 61.248870849609375, 64.43146542140416, 59.042129925319124, 59.80561188289097, 61.25064958844866, 60.41227994646345, 59.27873693193708, 56.18713596888951, 55.245397976466585, 58.16561119897025, 58.894862856183735, 63.25641386849539, 60.577716554914204, 64.34076363699776, 62.152616092136924, 63.57096576690674, 60.891552788870676, 62.93209975106375, 61.94996493203299, 62.8102422441755, 65.89371381487165, 62.372262545994346, 60.17791025979178, 66.1111090523856, 60.318069321768625, 64.59164224352155, 59.85753577096121, 58.96178790501186, 56.098296301705496, 52.58823313031878, 46.13057041168213, 37.95542417253767, 38.50972713742937, 54.8231976372855, 55.81768635341099, 60.92386886051723, 59.74001393999372, 56.38245677947998, 46.61639540536063, 30.474198000771658, 18.39765909739903, 14.145540475845337, 1.526331086243902, 0.7616740688681602, 0.15800473652780056, 0.27221473306417465, 2.150970991168703, 0.04838351286681635, 0.21549396882099764, 0.7402762227824756, 0.3243282309600285, 0.5017073271530015, 0.09581139736941882, 0.1670716471437897, 43.03085395268032, 30.733247688838414, 38.5906389100211, 38.63499273572649, 51.96492065702166, 21.297217062541417, 0.4286199047097138, 0.27825904158609255, 0.11153925556157317, 0.10165836076651301, 0.030658950031335865, 0.04104800648721201, 0.031624118597911935, 0.01762853147062872, 0.03772920010877507, 0.029329964558460882, 0.030109441839158535, 0.03579906653612852, 0.03213670430704951, 0.16621848435274192, 0.19375762875591004, 0.18636380907680306, 0.14917121481682571, 0.11009635762976748, 0.16475503359522137, 0.09974868502467871, 0.11901479799832616, 0.10151710334633078, 0.1497529907418149, 0.16996019785957678, 0.1201611150588308, 0.44894547547612873, 11.835440754890442, 87.39375400543213, 43.55876071112496, 51.898752961839946, 43.48550932747977, 87.56602764129639, 30.507194995880127, 0.3745432692979063, 0.9780492782592773, 0.6121003606489727, 0.4422138381217207, 0.6729844393474715, 1.1629400828054972, 4.320015983922141, 6.317687349660056, 6.787164534841265, 0.8860087171196938, 0.8975165081875665, 1.9884020345551627, 22.527708292007446, 78.3773546218872, 82.97995948791504, 86.33697468893868, 87.70183713095528, 87.04620511191231, 82.61277498517717, 83.28048992156982, 76.94425392150879, 83.39568410600934, 82.74813284192766, 80.2275834764753, 78.8910071509225, 75.93563256944928, 74.28792980739048, 72.12342003413609, 71.00428758348737, 72.01503508431571, 72.43471322740827, 69.89668914249965, 66.01645374298096, 61.33560521262032, 61.913431303841726, 60.841755049569265, 65.74853120531354, 69.00060081481934, 70.75673716408866, 71.65914835248674, 71.04895060403007, 78.2753689629691, 74.32240676879883, 74.4601617540632, 74.95131601606096, 73.89582211630685, 75.8280258178711, 76.23295988355363, 72.38170542035783, 75.77676200866699, 72.85490553719657, 71.72016743251255, 68.7023354939052, 67.17436408996582, 72.29391493116105, 76.21367168426514, 63.023538044520784, 68.3394866670881, 76.28650270189557, 71.3671989440918, 71.74620233263288, 75.9977981022426, 57.91881118501936, 61.48851421901158, 75.98266492571149, 61.0154252733503, 65.09064102172852, 62.700759478977744, 66.49159935542515, 61.63170269557408, 66.66781261989048, 61.71886089869908, 63.193449292864116, 67.77146448407854, 69.27219200134277, 61.97727830069405, 54.53228351048061, 57.54085350036621, 61.33355549403599, 59.20396041870117, 63.83799198695591, 65.00569929395402, 68.67527226039341, 65.18847860608781, 67.90279238564628, 62.07578986031668, 63.44246578216553, 64.64161368778774, 58.89287567138672, 61.04989528656006, 59.28458036695208, 57.71661860602242, 62.372665541512625, 62.223904609680176, 65.48233876909528, 61.25150421687535, 68.83679703303746, 65.2751851763044, 66.65061582837785, 64.74266133989606, 65.98123332432338, 66.61679894583565, 64.9289355959211, 69.71627221788678, 64.6278909955706, 62.02361583709717, 67.297208241054, 62.54854529244559, 67.5147841317313, 62.55607713971819, 64.30939946855817, 60.709301539829795, 58.53196539197649, 55.46361310141427, 49.74164302008492, 52.82638611112322, 65.8257395880563, 60.23587213243757, 59.90839658464704, 54.25018317358834, 52.730879647391184, 46.610982758658274, 35.86741406576974, 25.61158459527152, 19.037444012505667, 1.5723984028611864, 1.2442451885768344, 0.6834528233323778, 0.3571573293634823, 3.3642689032214026, 1.2337630710431506, 1.4344233551195689, 0.8707369565963745, 1.4329237384455544, 0.6004976289612907, 0.4902205435293061, 0.34872300337467876, 53.71192012514387, 38.238820348467144, 60.51591232844761, 43.27609062194824, 63.399657930646626, 25.221556152616227, 0.4693750792316028, 0.46311192959547043, 0.21578147767909936, 0.14518703360642704, 0.11897793997611318, 0.19844645501247474, 0.17455447704664298, 0.0853961223204221, 0.15977762639522552, 0.1147493233105966, 0.14593752047845296, 0.171909968235663, 0.19123928674629756], [0.0860427865492446, 0.029702415822872093, 0.03420908935368061, 0.02640234209996249, 0.006802546384278685, 0.05326689886195319, 0.029803700745105743, 0.0159952586649784, 0.05396752019545861, 0.10486270167997905, 0.014438322745263577, 0.01393658172206155, 0.2503553203174046, 13.765011957713536, 59.85820974622454, 33.30748231070382, 49.40025717871529, 23.940848554883683, 69.40723024095807, 7.204996194158282, 0.3737849114196641, 0.15679078309663705, 0.514275749879224, 0.010857765546201594, 0.6284369326063565, 0.3714797651129109, 1.0513697096279688, 0.19350695077862057, 0.20453125850430556, 2.612740235669272, 0.36417392428432194, 9.255755271230425, 53.179740224565776, 69.75838524954659, 74.53046362740653, 78.91096932547433, 76.91094425746373, 77.40725408281598, 74.07928930010114, 71.7880026953561, 72.31571143014091, 73.11318397521973, 71.05478014264787, 69.9928869519915, 72.43280942099435, 67.15265096936906, 64.88161836351667, 63.13457720620291, 57.68769325528826, 61.009477615356445, 61.41119466509138, 53.37459550585066, 57.871688502175466, 63.25426687513079, 61.92743192400251, 62.21119635445731, 62.15192822047642, 64.85490948813302, 71.62801347460065, 71.87131159646171, 70.9231812613351, 64.566545350211, 67.66822814941406, 65.92402185712541, 65.57756383078438, 64.48994840894426, 66.83700820377895, 68.15907669067383, 65.5743329184396, 65.94101020268032, 62.225738934108186, 63.61384310041155, 59.22531223297119, 70.27314254215786, 65.6497278213501, 55.85293109076363, 65.01327283041817, 68.40141596112932, 64.4716329574585, 66.94507353646415, 71.00374562399728, 51.63941839763096, 51.74179662976946, 66.25750064849854, 62.664462089538574, 66.73521709442139, 62.69604165213448, 61.661774499075754, 63.33854852403913, 63.74560873849051, 61.17302431379046, 60.749573298863, 57.92767013822283, 56.78646673474993, 60.06624576023647, 62.404015813555034, 61.15145015716553, 54.8741591998509, 51.445511545453755, 58.18868964059012, 57.99128437042236, 53.857787132263184, 55.31796496255057, 60.26883438655308, 64.35891233171735, 60.82207080296108, 58.64904253823416, 59.76342936924526, 62.223765645708355, 59.995520046779085, 60.55976240975516, 56.449319294520784, 51.586990765162874, 55.02741214207241, 58.045421259743826, 56.88129922321865, 58.293260029384065, 58.41716725485665, 56.05553361347744, 57.620306151253835, 57.6508469581604, 59.12636988503592, 60.775219099862234, 59.82166916983468, 62.63547420501709, 51.857119355882915, 56.005537850516184, 58.467868259974885, 59.293272563389365, 60.76238577706473, 58.628566196986604, 56.2433295249939, 52.07480294363839, 45.63297169549124, 43.446137360164094, 30.099453857966832, 40.819370882851736, 47.09098168781826, 40.12121588843209, 42.66081026622227, 40.063921042851035, 24.466674327850342, 9.78169482094901, 2.2060793255056654, 4.0796508703913, 3.982804707118443, 0.3100524241370814, 0.28546562631215366, 0.04407588079837816, 0.22690742995057786, 0.458255084497588, 0.2597521889422621, 1.010668899331774, 0.07928240645144667, 0.6144840813108853, 0.11030236086142914, 0.8209541450653757, 13.39490486894335, 40.11595262799944, 33.86230986458914, 24.82850350652422, 43.632984842572895, 17.365747383662633, 0.4860896223357746, 0.16663973246301922, 0.06927498523145914, 0.14082363274480614, 0.06591879496616976, 0.13693965758596147, 0.08742927107959986, 0.07562071257936102, 0.018522304582542608, 0.08119812794029713, 0.05203189388183611, 0.07042242187474455, 0.0567734796287758, 0.07772892766765185, 0.012446108307423336, 0.0037461184713590357, 0.09144887181797198, 0.03807780086728079, 0.04576254922098347, 0.07024074412350144, 0.030893353346203054, 0.030458327582372085, 0.05554688848288996, 0.04535464450184788, 0.03406122300241675, 0.27315816815410343, 18.104618821825298, 68.92919417790004, 38.7133823122297, 45.79696307863508, 24.694354636328562, 79.20119558061872, 9.290946160043989, 0.28348576969334055, 0.0704197348760707, 1.363729559949466, 0.1913668784712042, 0.5390939552869115, 0.9579174156699861, 2.218413680791855, 0.16549207190317766, 0.33035584752048763, 3.2505753125463213, 0.46143773943185806, 11.30076731954302, 65.10572556086949, 78.5433748790196, 80.33976909092495, 84.60145364488874, 80.63741602216447, 80.01709474836076, 79.5580689566476, 75.70398657662528, 74.67611871446881, 77.58165386744908, 74.65509346553257, 70.82604544503349, 74.1879243850708, 69.8122615814209, 68.32994679042271, 66.70094857897077, 65.61120006016323, 67.2577702658517, 66.49738720485142, 59.45157337188721, 63.94723156520298, 68.1046792439052, 66.94706766945976, 66.98231588091168, 66.33336802891323, 69.72335938044957, 72.80965886797223, 71.99548285348075, 73.84571170806885, 72.62564277648926, 72.6102316720145, 74.14237199510846, 70.57566016060966, 68.52740069798061, 69.64172499520438, 71.62663078308105, 68.80521052224296, 67.19826589311872, 67.403578213283, 66.82818399156842, 62.50093623570034, 72.45575932094029, 64.6820730481829, 57.253913743155344, 66.8564840044294, 68.83344800131661, 66.96554987771171, 70.64241845267159, 69.77232333592006, 51.16810819080898, 57.041086946214946, 67.23430619921002, 63.99522277287075, 69.08463232857841, 62.73302691323416, 63.85395894731794, 65.3742595400129, 63.82517950875418, 62.746089526585166, 60.2807366507394, 60.1157169342041, 57.59884316580636, 62.03877680642264, 63.977546555655344, 65.34233951568604, 60.04398373195103, 52.16735642296927, 58.31065831865583, 59.87365559169224, 56.10614081791469, 55.25885663713728, 58.337235178266255, 65.3438194819859, 61.587942940848215, 61.78018569946289, 61.606188910348074, 63.18167209625244, 61.42773832593645, 63.45076887948172, 60.63249615260533, 57.2361159324646, 56.46459490912301, 60.484304973057334, 61.69508416312081, 62.41047069004604, 61.16752134050642, 59.07667636871338, 62.67694105420794, 61.44283676147461, 62.3998955317906, 63.77573612758091, 63.042583056858604, 63.927450043814524, 54.47817093985421, 55.93263040270124, 63.26466832842146, 62.89940847669329, 62.44318280901228, 62.65995270865304, 59.37322548457554, 57.585276808057515, 51.94149827957153, 47.24961600984846, 37.493045875004356, 44.93296848024641, 51.23466845921108, 54.06033754348755, 61.989131927490234, 60.92897578648159, 52.50798143659319, 40.587874276297434, 23.17970814023699, 17.15888214111328, 6.374684725488935, 0.23588205980403082, 0.4827275627425739, 0.09856681951454707, 0.5735216279114995, 1.2609507207359587, 1.0291217948709215, 1.1291604382651192, 0.33938836998173166, 1.0064835867711475, 0.1823132535708802, 0.78451078917299, 15.96908129964556, 42.05991268157959, 34.250443186078755, 33.941651344299316, 49.222786290305, 22.38741374015808, 0.4546041318348476, 0.14901816445801938, 0.08127411707703557, 0.16187417746654578, 0.08235415483691863, 0.17462311764912947, 0.03425258344837597, 0.04602867404797247, 0.026086182100698352, 0.07660367233412606, 0.026959834952971766, 0.13205254982624734, 0.04873974375160677, 0.16818928931440624, 0.06978187124644007, 0.12592527004224913, 0.2053911659334387, 0.12150992053960051, 0.18273423026715005, 0.16941926974271024, 0.1712117557014738, 0.1123450498229691, 0.2378884878541742, 0.0821815219574741, 0.12141736836305686, 0.29007925731795176, 22.32054775101798, 81.4982908793858, 42.70560877663748, 65.41069589342389, 36.583474567958284, 86.0462898526873, 11.286854420389448, 0.4515306938971792, 0.4062869016613279, 1.8632723603929793, 0.34636506704347475, 1.9668417743274142, 1.9091864909444536, 4.2675609929221014, 1.09755297430924, 0.8748630466205733, 5.202877547059741, 0.5520833411387035, 15.344368764332362, 80.2463436126709, 86.47381251198905, 84.99589593069894, 86.91485636574882, 82.83685438973563, 86.12757682800293, 82.10811342511857, 80.31462356022426, 78.4900405066354, 79.75020054408482, 79.01379571642194, 74.87168966020856, 79.3937440599714, 73.63173498426164, 73.18196419307164, 72.92503370557512, 71.3696516581944, 73.9910888671875, 72.55868993486676, 64.45934854234967, 69.77476910182408, 71.87455640520368, 70.97518157958984, 69.2743250983102, 69.08407647269112, 74.202223777771, 77.94911629813058, 77.55425712040493, 75.76992498125348, 72.82077598571777, 74.81472137996128, 76.55926813398088, 75.15110451834542, 72.09764916556222, 74.15697710854667, 75.09544249943325, 71.8520928791591, 70.67298357827323, 68.55958475385393, 71.81464903695243, 64.72131647382463, 73.87501226152692, 71.6272144317627, 59.73237786974226, 67.90017986297607, 74.23260825020927, 68.7077967779977, 71.60473006112235, 76.0413007736206, 57.138698714120046, 57.2680081639971, 71.05720506395612, 66.2263935634068, 71.29374258858817, 67.29718044825962, 65.3294506072998, 68.61936705453056, 67.9831691469465, 66.45941529955182, 64.25668348584855, 64.49440220424107, 62.002090317862375, 64.61982413700649, 67.2151847566877, 66.45630250658307, 60.63936792101179, 55.805857045309885, 61.25895963396345, 62.68700204576765, 58.325159209115164, 59.75888524736677, 63.32893916538784, 70.288240977696, 64.3948414666312, 62.983439990452354, 64.1400649206979, 66.28741264343262, 62.62236990247454, 65.7309661592756, 61.91509887150356, 59.06671265193394, 61.55179146357945, 63.527032307216096, 63.46259471348354, 65.73205007825578, 61.79140704018729, 61.891718183244976, 64.43163912636894, 61.872228486197336, 64.70698928833008, 68.67724554879325, 67.81567587171281, 67.67509296962193, 55.80363709586007, 57.3241148676191, 64.42979090554374, 65.81726973397392, 66.82110377720424, 63.66343239375523, 62.6980288369315, 61.33300658634731, 58.84533609662737, 57.215420722961426, 49.72234092439924, 59.91861738477434, 61.546309334891184, 58.0462863104684, 57.489752973829, 55.69110754558018, 47.82059465135847, 39.315009457724436, 28.66269145693098, 26.570767777306692, 7.217313178947993, 0.4167597639773573, 0.7776971576469285, 0.33894297959549086, 1.5517828805106026, 1.598225182720593, 1.932970391852515, 2.1110653153487613, 0.42304492528949467, 1.1279083511659076, 0.5221157063330922, 0.7139985699738775, 21.10968518257141, 55.2290175982884, 53.345190729413716, 35.67231559753418, 57.261459486825125, 27.853688376290457, 0.6365962347814015, 0.5154696458152362, 0.1624004085149084, 0.3134814144245216, 0.18355797177978925, 0.28796811774373055, 0.13288633365716251, 0.20163202764732496, 0.15453166860554898, 0.2826866725725787, 0.20196357342813695, 0.2096187240843262, 0.22279026944722446], [0.09049147247735943, 0.033370956113295894, 0.031246289943477938, 0.013218269284282411, 0.030260436236858368, 0.04611837977011289, 0.04523251159116626, 0.018117812894550816, 0.024481289022203003, 0.03586611258132117, 0.03295148576476744, 0.034666455883000574, 0.14032695868185588, 29.535367829459055, 51.446428707667756, 35.42046076910836, 44.41024507795061, 36.98988512584141, 65.93052537100655, 1.1973208550895964, 0.08428376593760081, 0.07264526188373566, 0.4583200067281723, 0.22487527185252734, 0.37106192324842724, 0.7937322429248265, 1.3403250958238329, 0.3788531337465559, 0.5403778521077973, 0.4207657261618546, 4.562069509710584, 42.96589176995413, 73.59782082693917, 70.60772609710693, 78.15670067923409, 77.43196187700543, 78.24872262137276, 77.94712911333356, 72.35382229941231, 75.77147442953927, 75.41310024261475, 74.21978882380894, 71.22439956665039, 67.63889285496303, 66.04762336186, 67.43610967908586, 64.18941102709088, 59.63828536442348, 58.697297777448384, 62.86918381282261, 63.00711945125035, 65.2787287575858, 62.91148444584438, 63.691683769226074, 65.54323278154645, 60.910743713378906, 64.8889695576259, 66.65320750645229, 67.32673808506557, 65.67910480499268, 70.87393242972237, 70.36121790749687, 69.297532081604, 68.09472247532436, 64.2567390714373, 66.34595121656145, 67.49928270067487, 65.19906071254185, 63.31061676570347, 58.94022764478411, 62.24665996006557, 63.42533847263881, 67.3920372554234, 63.65043926239014, 54.477559498378206, 64.22992597307477, 69.1875420979091, 63.09732791355678, 66.94882556370327, 68.22256238119942, 52.03356191090175, 55.229191303253174, 67.4640622820173, 64.88594014304024, 64.21389647892543, 58.66274438585554, 55.754937171936035, 55.61642483302525, 57.09267732075283, 56.85193613597325, 57.89881426947457, 54.91295794078282, 58.619477953229634, 56.85948882784162, 54.98986060278756, 60.10004874638149, 57.808418205806184, 64.06161975860596, 57.03625099999564, 52.55461079733712, 58.06777014051165, 60.279402596609934, 55.60280288968767, 53.44014828545706, 54.41972616740635, 62.626663889203755, 61.2447783606393, 58.95618070874895, 55.52237401689802, 59.76071957179478, 60.45109953199114, 60.67326123373849, 59.66322939736502, 53.98123925072806, 52.58110427856445, 57.87886599131993, 58.37130914415632, 59.193690981183735, 57.22374813897269, 57.316496167864116, 58.86701447623116, 56.50301149913243, 58.39588492257254, 60.392783301217214, 60.51222283499581, 58.47371169498989, 49.68523406982422, 57.21717514310564, 59.71088709150042, 57.20932020459856, 58.53398731776646, 60.47313921792166, 58.190548283713206, 51.59360892432076, 45.547494956425254, 40.57185867854527, 29.810374055589946, 43.74078961781093, 39.60065337589809, 42.0148605619158, 37.849328654153005, 35.062708445957725, 16.921693222863333, 4.916929645197732, 2.0784608934606825, 5.754290929862431, 1.0586063670260566, 0.18937483536345617, 0.34263307015810696, 0.18472117079155786, 0.499566413462162, 0.01095342286862433, 0.10949475491153342, 0.08430815927152123, 0.5091288174901689, 0.13108627524759087, 0.2990779344524656, 3.1850446803229193, 44.36582177025931, 26.646350281579153, 23.02526879310608, 41.93850333350045, 25.679353850228445, 0.3312037991625922, 0.20219457388988563, 0.10894712965403285, 0.13137052713760308, 0.013470416289887257, 0.12510402553847857, 0.07810234584446464, 0.027819282674629773, 0.04041665340108531, 0.12265330632882458, 0.04109200948317136, 0.03843236594860043, 0.08038953811462436, 0.014234175306877919, 0.05215477318103824, 0.08943995354431016, 0.06633150710591249, 0.012055881121861083, 0.054759136467639885, 0.08607046399265528, 0.03992058662697673, 0.022195396146603992, 0.01661183325839894, 0.040948804667485614, 0.04580248100683093, 0.04385913635737129, 35.39916106632778, 58.37387302943638, 47.674734592437744, 35.50787952968052, 38.941411767687114, 73.32881437029157, 1.8401789367198944, 0.047430218663066626, 0.11347644589841366, 0.49448966873543604, 0.8523136994668415, 0.2714388689824513, 1.6211861563580376, 1.8986658326217105, 0.19510819842772825, 0.701773920229503, 0.7735066882201603, 5.810745911938803, 54.065579959324424, 83.93633038657052, 77.56026036398751, 85.11143057686942, 81.77571855272565, 80.70308344704765, 79.34246635437012, 75.2445855821882, 78.37052454267229, 77.23001943315778, 77.81046499524797, 74.92295346941266, 70.80914742606026, 72.36241722106934, 71.12944548470634, 68.17756584712437, 65.555267061506, 63.20632430485317, 67.69607652936662, 65.73268931252616, 70.47969858986991, 66.21295574733189, 67.0038344519479, 65.10882445744106, 65.21041406903947, 67.98544815608433, 68.50090721675328, 69.6243336541312, 70.23791517530168, 73.3891247340611, 71.97036511557442, 72.54425157819475, 73.0397276197161, 68.98491873059953, 69.79398781912667, 69.31785556248256, 67.41112395695278, 66.15967001233781, 64.21998310089111, 66.9333519254412, 68.4732255935669, 69.87617806025914, 62.44581617627825, 59.20001384190151, 69.31065028054374, 69.64889553615025, 65.18473352704729, 70.5027596609933, 65.62000342777797, 51.99429416656494, 58.59369318825858, 69.65556580679757, 66.64847578321184, 64.53781454903739, 59.3921662739345, 57.895774432591026, 58.44305624280657, 60.46423857552664, 59.218822615487234, 59.333989007132395, 56.76430198124477, 61.14411980765206, 58.82979992457798, 57.21055350984846, 59.42178644452776, 61.11545154026577, 64.87486471448625, 60.10920647212437, 52.82847057070051, 56.18479790006365, 62.26321056910923, 56.62544223240444, 56.20041397639683, 53.79641022000994, 62.412582942417686, 62.284041268484934, 60.9969847542899, 58.26903860909598, 62.427813393729075, 62.91001837594168, 62.31689929962158, 64.27309513092041, 57.269085134778706, 56.75554725102016, 61.172885349818635, 61.50532191140311, 62.312244006565635, 59.696094376700266, 63.66665635790144, 62.238447189331055, 60.16153335571289, 63.65529605320522, 62.75669247763497, 62.90658596583775, 61.35125950404576, 51.53497655051095, 59.23420592716762, 62.52870123726981, 60.37010438101632, 59.020701680864605, 63.617192132132395, 60.042066029139924, 54.576988220214844, 51.35057830810547, 48.21672534942627, 35.959640979766846, 48.77080249786377, 51.29310628346035, 59.14034966060093, 56.6947991507394, 60.533373151506694, 48.45939813341413, 37.099093437194824, 17.25794608252389, 9.482259597097125, 1.9237160427229745, 0.09484932970787797, 0.29710250188197407, 0.7035007104277611, 1.8370077354567391, 0.367939223668405, 0.3594695324344294, 0.06483911682984658, 0.46736721268721987, 0.020062531577423215, 0.27950920164585114, 2.926946895463126, 52.9372341973441, 24.95904278755188, 24.34854452950614, 50.18239157540457, 31.050714356558665, 0.23446796568376677, 0.14446332172623702, 0.04864307286749993, 0.022129900553928952, 0.03404487370114241, 0.11357860613082137, 0.05377341168267386, 0.07333307926143919, 0.04956948012113571, 0.1322668990386384, 0.02324676071293652, 0.06807165765868765, 0.007720937170753521, 0.14894329490406172, 0.15417245216667652, 0.14550324449581759, 0.11749968358448573, 0.09655932616442442, 0.22356613352894783, 0.10459963365324906, 0.15000161954334804, 0.0987924188375473, 0.07723278964736632, 0.19636772227074417, 0.15488686811711105, 0.188152888789773, 40.96213551930019, 68.59575707571847, 48.61447845186506, 63.37071868351528, 52.13302537373134, 81.88148403167725, 2.582327101911817, 0.14377065960850033, 0.3722753609929766, 1.4752552040985651, 1.7327527297394616, 0.6603582054376602, 3.323968265737806, 4.409615610327039, 1.239852949976921, 1.0527305794613702, 1.5232324068035399, 8.185548560959951, 68.12248052869523, 92.9429953438895, 83.6988479069301, 87.98150212424142, 85.64666421072823, 86.1697176524571, 83.54284695216587, 79.0203617640904, 80.52639770507812, 80.74266038622174, 79.17582770756313, 77.9182801927839, 73.95310306549072, 76.29730020250592, 77.42165769849504, 74.80249949863979, 72.13671888623918, 66.72493376050676, 73.05376298086983, 70.65049225943429, 72.72712121691022, 71.57110772814069, 70.96280683789934, 70.66703592027936, 68.77751500265938, 72.04739284515381, 70.70610564095634, 72.39646339416504, 73.623626436506, 78.34767191750663, 77.67748342241559, 74.71427822113037, 75.2438143321446, 71.13783196040562, 72.86827387128557, 73.52660179138184, 71.56167207445417, 70.45066901615688, 66.11270713806152, 71.21012101854596, 69.32146862574986, 71.12105900900704, 70.8692979812622, 61.0642363684518, 71.33051940373012, 74.96608788626534, 68.44694750649589, 72.40744154793876, 74.08443096705845, 57.56899717875889, 59.861663000924246, 73.25927679879325, 69.4425687789917, 69.86369909558977, 62.280608858381, 61.693777901785715, 61.500680514744346, 63.33761746542794, 60.77981185913086, 61.55247238704136, 57.82966232299805, 62.69680595397949, 61.73279898507254, 59.22886276245117, 63.40118653433663, 62.38963999067034, 68.23393658229283, 60.24147932870047, 57.83372007097517, 60.82899815695626, 63.92119666508266, 58.1851669039045, 58.615746770586284, 57.82046638216291, 68.43532317025321, 65.14931855882917, 64.7483241217477, 60.58619335719517, 64.73373290470668, 64.73047419956752, 67.71048709324428, 65.94561685834611, 59.04411016191755, 58.53903865814209, 64.86299719129289, 64.03618935176304, 66.27176530020577, 62.415841647556846, 65.6102273123605, 64.3793956211635, 62.68013027736119, 66.22374629974365, 66.16695867265973, 66.1437794821603, 63.180998120989116, 54.263548033578054, 64.03666877746582, 63.94422994341169, 62.80175849369594, 61.64830194200788, 66.72732394082206, 63.532125336783274, 61.685975074768066, 60.36385795048305, 56.23585673740932, 49.80526420048305, 63.60538714272635, 57.511441775730674, 62.85867813655308, 54.81184080668858, 55.07891913822719, 42.46237666266305, 37.60798645019531, 24.26352984564645, 18.229285137993948, 1.5701987551791328, 0.4506488155041422, 0.7836888932756015, 1.5134737704481398, 4.319842278957367, 0.9403728885310036, 1.266565190894263, 0.42326846186603817, 0.918280765414238, 0.39696174061724115, 0.43075104749628473, 6.99436719928469, 62.9353723526001, 39.93193653651646, 33.573226588112966, 56.278237274714876, 36.940837791987825, 0.36683095885174616, 0.29219034260937143, 0.17223763279616833, 0.2535001944218363, 0.08404954243451357, 0.31547432605709347, 0.1210970998342548, 0.19645332624869688, 0.12384302248912198, 0.199125166450228, 0.1780746488698891, 0.1880410255065986, 0.12434350991887705], [0.0876167570906026, 0.04921534590955291, 0.034984468282865624, 0.030536335360791002, 0.010055596358142793, 0.04149663009281669, 0.05593804017241512, 0.03461150133184024, 0.04465183150023222, 0.052764518319496086, 0.052630999591201544, 0.03252285858616233, 0.1076233960422022, 46.34816367285592, 44.54862540108817, 27.092417682920182, 29.260882718222483, 43.21844489233834, 41.923828738076345, 0.2822677179106644, 0.11777520951415811, 0.1821570819509881, 0.2547715790569782, 0.2670846554849829, 0.6554375780480248, 1.259946271777153, 0.39028715448720114, 0.29871383256145884, 0.25297378695436884, 1.3828647903033664, 18.385150602885656, 66.2194106238229, 67.31728853498186, 78.03334930964878, 78.3650563103812, 76.80386556897844, 73.80828176225934, 74.04851572854179, 71.10749612535749, 73.89722565242222, 75.51655197143555, 74.55351080213273, 69.33525385175432, 61.321861675807405, 68.21459974561418, 64.79957403455461, 62.627511569431846, 61.60352080208914, 61.876119477408274, 65.32353769029889, 65.50510106767926, 65.32472583225795, 61.85642828260149, 62.880481583731516, 62.538081305367605, 63.60761056627546, 66.15193666730607, 64.23102378845215, 65.78289004734584, 72.69666726248605, 68.35561343601772, 67.85634367806571, 66.1393951688494, 69.10674844469342, 68.93416213989258, 65.55847712925502, 63.909801619393484, 58.51647785731724, 62.60140718732561, 63.32529136112758, 67.94593375069755, 67.44805363246373, 60.61582047598702, 55.69587400981358, 67.5207039969308, 65.95604610443115, 67.42660454341343, 66.2180974142892, 64.06676142556327, 48.15091896057129, 57.677750383104595, 69.46483775547573, 63.498503003801616, 59.83762223379952, 54.12358352116176, 59.63049643380301, 58.347455978393555, 59.97858728681292, 62.34422656467983, 62.573899269104004, 59.69813714708601, 59.91002941131592, 57.951078619275776, 61.20791121891567, 60.67799990517752, 57.31255306516375, 59.99816731044224, 60.30899497440883, 64.807126726423, 58.50408921922956, 47.11187492098127, 60.37436362675258, 62.87631961277553, 59.958562578473774, 56.879645551954, 51.95471027919224, 56.684342111860005, 60.01259871891567, 57.706752164023264, 55.65781872613089, 57.45984097889492, 58.361553873334614, 56.95983471189226, 59.312929017203196, 56.709362574986045, 53.83157157897949, 52.60895265851702, 58.101038115365164, 57.61640126364571, 57.03124829701015, 56.6210891859872, 58.34458637237549, 59.08879402705601, 58.17032902581351, 58.67274979182652, 61.050089836120605, 53.29092182431902, 52.21616404397147, 58.91060052599226, 58.89225033351353, 59.76046943664551, 59.04932825905936, 55.79658120019095, 54.8006819997515, 50.539223262241904, 50.34278726577759, 36.22701808384487, 38.026827335357666, 46.04438495635986, 41.68055146081107, 41.21569960457938, 34.84954118728638, 27.06056192943028, 13.191257510866437, 7.046413549355098, 2.962370766060693, 2.2828482346875325, 0.33951810587729725, 0.048074056793536456, 0.2507893113153321, 0.10537185400192227, 0.44494084322026795, 0.22928732367498533, 0.31637683191469734, 0.06900051781641585, 0.20086683013609477, 0.058993809058197906, 0.08184260050100939, 30.56836346217564, 41.14802415030343, 29.805847304207937, 36.92492641721453, 34.35697644097464, 0.0710613304483039, 0.05414295542453017, 0.024033058966909136, 0.09012270226542439, 0.04898083402908274, 0.08570461148130042, 0.014763035678437777, 0.03534541837871075, 0.06886540792350258, 0.06077355212931122, 0.06758564338088036, 0.07296253807310547, 0.029915496174778258, 0.017184915453461663, 0.05139204214460083, 0.027032263477199843, 0.05766504750187908, 0.019528344705966965, 0.036246058265013356, 0.06805573922715016, 0.018424827938101122, 0.0966538664485727, 0.037574161642364094, 0.09303341393492051, 0.056917223879801374, 0.39773926032441004, 56.32806280681065, 50.52779694965908, 42.35870259148734, 32.64372784750802, 47.00181892939976, 49.46820361273629, 0.16347542511565344, 0.06128839736006089, 0.21286163292825222, 0.3862708242876189, 0.7679072543978691, 0.6008147490876061, 1.621738646711622, 0.47225641033479143, 0.32335551029869486, 0.16055883733289583, 1.9325602310044425, 22.826070887701853, 75.2701063156128, 73.37970297677177, 86.13795743669782, 81.88365881783622, 80.69046551840646, 76.74297850472587, 74.38556589399064, 72.09937231881278, 77.1473845073155, 78.87190655299595, 77.0064264025007, 70.72724900926862, 63.936767578125, 71.21599224635533, 70.62632642473493, 68.6888837814331, 66.71089839935303, 65.39750821249825, 69.44798142569405, 69.72780622754777, 68.14231763567243, 64.7725316456386, 65.40504005977085, 64.08796037946428, 67.20436641148159, 68.28674289158413, 69.62616797855922, 69.89645985194615, 74.93624537331718, 70.14694935934884, 71.99416964394706, 71.7726263318743, 73.169846534729, 71.55017975398472, 68.29757513318742, 67.28924560546875, 62.74438026973179, 65.93365206037248, 67.67090320587158, 71.69518865857805, 68.80823993682861, 59.11600317273821, 63.327771868024556, 71.60363919394356, 67.89680998665946, 69.63168484824044, 69.05809715815953, 64.12471635001046, 51.846759591783794, 63.974503244672505, 69.41264288766044, 64.10404545920235, 60.63893713269915, 57.90240996224539, 62.41347926003592, 62.24645151410784, 63.04478563581194, 65.79313169206891, 63.016027041843955, 64.10113416399274, 62.959559031895225, 57.96569415501186, 61.645376750401084, 63.04699516296387, 59.70219489506313, 62.8645841053554, 62.82436793191092, 63.93457889556885, 61.69932951245989, 49.40627779279436, 57.07935414995466, 65.58338642120361, 59.878880637032644, 59.45093413761684, 54.509416988917756, 55.71216058731079, 60.41391972133091, 61.08424023219517, 58.56804738725935, 59.86083616529192, 59.70191696711949, 59.610443932669504, 61.901237215314595, 61.52119854518345, 56.88544382367815, 56.16518660954067, 61.12973703656878, 61.03583908081055, 60.98203223092215, 61.17817987714495, 61.42057473318917, 62.54854529244559, 61.175331115722656, 61.732152802603586, 62.98695577893938, 56.13300602776663, 53.680392674037385, 61.01430661337716, 61.8409754889352, 61.12308761051723, 60.850148473467144, 59.48975372314453, 58.74038355691092, 55.287108012608115, 53.45014326913016, 43.33209310259138, 43.64093705586025, 49.017967292240684, 56.19137784412929, 58.79217542920794, 58.64121886662075, 53.80703401565552, 45.85690518787929, 27.52378269604274, 11.798116769109454, 3.792750631059919, 0.34958992685590473, 0.11304099605019603, 1.1354844932045256, 0.17060070777578012, 0.8711795785597393, 0.21043088978954724, 0.43623936442392214, 0.08466483120407377, 0.2637843968612807, 0.06864011394126074, 0.22595590672322682, 36.939441204071045, 38.700545515332905, 29.709406307765416, 45.53254590715681, 39.76660762514387, 0.07626850996166468, 0.0690984914877585, 0.01497208044332053, 0.09226796536573342, 0.033067393116652966, 0.025725878309458494, 0.0639472029038838, 0.08919658338917152, 0.012746477948634751, 0.04803470515512994, 0.044643726399434466, 0.02887986853186573, 0.02091059008879321, 0.22007676719554833, 0.1453762770231281, 0.09876622738582747, 0.1693196472312723, 0.12221209571829864, 0.1618356502481869, 0.24207157481993946, 0.14700492391628878, 0.1601411990289177, 0.19905382527836732, 0.15623521219406808, 0.13734350805836065, 0.8517405816486904, 63.02249581473214, 59.479248046875, 36.70896250861031, 43.762408937726704, 56.77548163277762, 57.17162275314331, 0.3086313818182264, 0.25936583110264366, 0.4018822865826743, 0.8429933967334884, 1.756282804267747, 1.0549812529768263, 3.2391707130840848, 1.5781047195196152, 1.0273086407354899, 0.32185915059276987, 3.4213101395538876, 29.494901520865305, 87.14520999363491, 79.91724913460868, 90.60635089874268, 84.03113160814557, 84.51107842581612, 78.80744811466762, 79.34041663578579, 75.52955899919782, 79.70476627349854, 78.91003826686314, 79.95467908041817, 76.48861885070801, 66.06951018742153, 75.67519324166435, 74.64243384769985, 73.48831721714565, 70.3697919845581, 70.26893888201032, 72.73923192705426, 71.92602171216691, 72.72955308641706, 71.14360591343471, 71.63018131256104, 67.8915502003261, 70.80540234701974, 71.93005861554826, 73.90299960545131, 74.12361185891288, 79.21605777740479, 73.31459140777588, 74.89303452627999, 72.57301017216274, 76.96702316829136, 75.07543863568986, 70.93782806396484, 73.90656403132847, 63.96534551892962, 71.55999061039516, 68.51857648577008, 73.4630605152675, 72.66563660757882, 66.73559924534389, 64.40610449654716, 72.92356763567243, 69.7673692703247, 74.00342886788505, 71.2329180581229, 70.35208797454834, 53.36177607945034, 62.28816155024937, 74.5681437083653, 66.8911555153983, 64.72431809561593, 60.45893710000174, 66.54065363747733, 64.31395053863525, 64.28943729400635, 69.05037076132638, 64.01088401249477, 66.21455383300781, 65.07273551395961, 60.375711577279226, 63.5485508782523, 65.5952261516026, 62.133862904139924, 63.7105689729963, 67.16072477613176, 69.91251019069126, 62.342642375401084, 52.48897116524832, 63.93885898590088, 66.57025296347481, 63.750500270298545, 62.22608634403774, 56.096159730638774, 61.61679880959647, 64.54470716203961, 63.01273359571184, 59.123896326337544, 63.46018368857247, 62.662516593933105, 62.06513827187674, 63.22862107413155, 62.81052712031773, 60.45963886805943, 59.7524025780814, 63.58956609453474, 64.8712238584246, 63.03602395738874, 62.485386167253765, 62.38356031690325, 66.38868958609444, 65.06743403843471, 65.25994777679443, 67.13344614846366, 57.30308961868286, 56.49271079472133, 64.2594210760934, 66.20294339316231, 64.70489093235561, 63.22175625392369, 62.14320823124477, 61.90132754189627, 61.37254878452846, 61.86227866581508, 52.37205730165754, 59.50192696707589, 60.88619572775704, 63.044215883527485, 62.269283294677734, 57.416404315403526, 49.04042387008667, 40.523301192692344, 29.96942526953561, 22.973423072269984, 4.361056387424469, 0.5184800614203725, 0.2118341273495129, 2.8061726561614444, 1.4089515847819192, 1.4193634603704726, 0.7391493661063058, 1.1153199523687363, 0.28652001544833183, 0.36610606632062365, 0.2195518117930208, 0.48165542313030785, 44.7421362059457, 58.4690911429269, 46.10904141834804, 48.77317878178188, 49.39278439113072, 0.1199839495654617, 0.13601271089698586, 0.12305259704589844, 0.19393636845052242, 0.11073017719068698, 0.14311528977538857, 0.15769931434520654, 0.15757069124707154, 0.08550244875784431, 0.24374204661164964, 0.1231556800859315, 0.1557762511074543, 0.14217042976192065], [0.01902265121628131, 0.024557642871513963, 0.044069994507091384, 0.04871518417660679, 0.07391033614320414, 0.035948954921747954, 0.05017182583521519, 0.017583358001762202, 0.0415087758696505, 0.06055777120803084, 0.020835574649806534, 0.10947414101766688, 1.144765766603606, 52.58662462234497, 39.288175514766145, 38.59273726599557, 29.864253861563547, 55.64826842716762, 18.53130943434579, 0.301742107208286, 0.38866062462329865, 0.13341636450162955, 0.2845414344753538, 0.14893566817045212, 0.16732579922037466, 0.1734643562563828, 0.16314188444188663, 0.2991198407752173, 0.5640012387718473, 4.621341552053179, 42.13458497183663, 67.59774562290737, 74.5802196775164, 76.36184896741594, 74.2705523627145, 72.02487373352051, 76.69933686937604, 70.4886965070452, 72.68437589917863, 73.03683022090367, 74.89682129451207, 74.38355786459786, 60.56125627245222, 67.88197558266776, 61.75817380632673, 65.91106346675328, 63.68971048082624, 62.5353993007115, 61.8054632459368, 64.696441922869, 65.32683113643101, 63.14901556287493, 63.36080360412598, 62.291663442339214, 66.33886405399868, 63.576364517211914, 63.017708505902974, 64.17514637538365, 68.44074971335274, 65.40292780739921, 64.36931378500802, 68.66717760903495, 69.3686329977853, 68.07082067217145, 65.85638114384243, 62.66269029889788, 61.78420870644705, 63.878381865365164, 67.236786706107, 70.61186027526855, 65.62649304526192, 56.40396840231759, 58.35413319723946, 69.87147412981305, 64.83605902535575, 64.97381401062012, 68.08584267752511, 63.848421233040945, 48.52985634122576, 60.82837281908308, 68.87416444505963, 63.84297384534563, 59.81258092607771, 56.49779340199062, 58.94633511134556, 61.412424496241975, 62.71805354527065, 62.65358121054513, 58.171339988708496, 57.43993091583252, 61.24151965550014, 58.55390780312674, 60.931588309151785, 57.42515557152884, 59.685741560799734, 56.134836878095356, 62.574767793927876, 61.80603299822126, 57.03804363523211, 62.35227952684675, 60.79978098188128, 45.60488707678658, 59.710678645542686, 60.498284748622346, 59.25004087175642, 59.704376629420686, 55.05690377099173, 53.07500655310494, 54.51284939902169, 60.59173801967076, 60.263004847935264, 61.43735463278634, 57.570081097739084, 58.090570654187886, 60.86979797908238, 59.21004704066685, 52.844621658325195, 55.5463661466326, 57.23855127607073, 57.6430788721357, 57.92903893334525, 57.722350869859966, 56.806321212223594, 57.395816802978516, 57.71044165747506, 56.13488898958479, 58.045497689928325, 52.196260929107666, 56.04847076960972, 56.866864340645925, 57.091576031276155, 54.541986669812886, 55.13290316717965, 54.48146786008562, 54.67972081048148, 52.7585369518825, 51.85809905188424, 37.289470604487825, 46.02821997233799, 42.39248125893729, 45.97035537447248, 41.0464380128043, 35.33531754357474, 23.94560980796814, 11.946896808488027, 7.804826361792428, 2.910045402390616, 0.7689367277281625, 0.1435807105153799, 0.28314278381211416, 0.3753773516842297, 0.5899761563965252, 0.39763446737612995, 0.6587591969541141, 0.03242562451799001, 0.29657753290874617, 0.03539780806750059, 0.3213894957942622, 14.992598840168544, 43.125957420894075, 29.086594104766846, 32.78515842982701, 39.567666803087505, 0.21931281818875245, 0.09728459867515735, 0.02788288515460278, 0.03435589040496519, 0.03791472515357392, 0.03450295269223196, 0.012554485616939408, 0.03911015457872834, 0.03129138538081731, 0.011437893479264208, 0.0368321564580713, 0.021301835076883435, 0.01790854930212455, 0.03931291441300085, 0.03951208818969982, 0.03528512375695365, 0.03984431929088064, 0.04144635743328503, 0.01602047641894647, 0.03092328691855073, 0.009910695204910423, 0.02227301207104964, 0.03026037516870669, 0.07338065135159663, 0.04038973930957062, 2.050841586930411, 62.224863461085725, 43.846985885075156, 40.47147110530308, 28.974147932870046, 60.2129430770874, 24.066624845777238, 0.22956831859690802, 0.07723023157034602, 0.35686349655900684, 0.045640684331634214, 0.25752249572958263, 0.17689566713358673, 0.5168326326778957, 0.3128293151301997, 0.5428495651909283, 1.13610320857593, 4.8905477694102695, 53.434127671378, 79.94261005946568, 81.33244432721818, 80.99051652635846, 77.91709899902344, 75.98447145734514, 77.75599806649345, 74.55688762664795, 76.12019062042236, 77.35045950753349, 76.71923651014055, 76.3940121786935, 64.55173179081508, 70.27255889347622, 63.89081219264439, 69.67669527871269, 68.54405553000313, 65.200332232884, 65.47999722617013, 66.99682371956962, 67.79899324689592, 66.60427829197475, 66.06572341918945, 65.63799231392997, 69.1997709274292, 67.80340535300118, 64.31165763310024, 69.0040054321289, 70.96509974343437, 70.24359880174909, 68.51328195844377, 72.05205508640834, 71.56705692836216, 72.16397666931152, 68.57778903416225, 64.86754131317139, 63.949892725263325, 67.55151230948312, 69.97512735639299, 71.18751158033098, 66.49537222726005, 58.231598240988596, 62.7874174118042, 72.84866605486188, 65.42535659245083, 67.79379599434989, 70.09992395128522, 64.87760925292969, 50.699539048331125, 66.09944302695138, 67.72168064117432, 65.78675324576241, 59.19191919054304, 59.94540269034249, 60.78509249005999, 62.79923629760742, 65.03804315839494, 64.00167764936174, 60.43139444078718, 59.063099588666645, 60.36972223009382, 60.98105253492083, 62.48030008588518, 60.09513636997768, 60.5946284702846, 59.376296588352744, 62.42665304456438, 62.91997514452253, 59.48404925210135, 61.07823004041399, 65.82997104099819, 49.74910885947091, 55.471749441964285, 62.195667130606516, 59.97871930258614, 63.71223654065813, 59.269134521484375, 54.12371206283569, 54.83171612875802, 61.71364280155727, 62.466785839625764, 64.72878578730992, 61.227852548871724, 61.59392533983503, 63.10210132598877, 63.72907897404262, 57.587555817195344, 58.00675800868443, 60.29611301422119, 60.60783004760742, 62.20107977730887, 59.77733966282436, 59.89366640363421, 60.910305976867676, 61.26903452192034, 59.85286658150809, 59.722282137189595, 54.52108301435198, 57.359422138759065, 59.58284568786621, 60.19418294089181, 57.093577112470356, 56.96827677318028, 58.57136862618582, 58.29250962393624, 57.69921336855207, 57.56608588354928, 44.50249631064278, 49.98429495947701, 51.13944339752197, 57.5149575642177, 55.00837060383388, 59.054358754839214, 52.231710638318745, 41.09505803244454, 19.423631838389806, 3.596105537244252, 1.450781368783542, 0.09118316429001944, 0.25171505021197454, 0.8466204649635724, 1.2658898042781013, 0.6128843128681183, 1.2365091294050217, 0.06009916974497693, 0.27549319714307785, 0.036509828575487645, 0.46512641864163534, 19.389236518314906, 46.31900903156826, 30.35963957650321, 43.61501680101667, 45.509533473423545, 0.5160339698195457, 0.1369163974055222, 0.046609832506094656, 0.02248847408087126, 0.10288080267075982, 0.04001367484618511, 0.06013689629201378, 0.030828220769762993, 0.01964226734292294, 0.04699772044218012, 0.04412451818851488, 0.018339371541514993, 0.01743057736062578, 0.11557709532124655, 0.10812762898526021, 0.12102896134768214, 0.13771344535052776, 0.24303338463817323, 0.1532021878021104, 0.19020732997783593, 0.10973136685788631, 0.1152716324265514, 0.17043491452932358, 0.1315064105604376, 0.23557495485459054, 2.952548618827547, 72.40437044416154, 53.03913300377982, 48.96196133749825, 44.980393409729004, 74.6529186793736, 30.01668691635132, 0.2835037644420351, 0.6102927976420948, 0.4188565457505839, 0.3587265908718109, 0.5591465107032231, 0.6753598547407559, 1.364438276205744, 1.1257990300655365, 0.8605962778840746, 2.0812191111700873, 5.756134373801095, 67.3802739552089, 91.3384895324707, 88.28425598144531, 86.54781082698277, 80.50107846941266, 79.2923698425293, 80.96354361942836, 76.48415115901402, 79.25195217132568, 80.56647491455078, 80.72921562194824, 80.96594074794224, 69.20735836029053, 70.82345376695905, 70.28391919817243, 75.17658356257847, 71.94974286215646, 70.83361203329903, 70.11747510092599, 70.71899454934257, 72.63707951136998, 71.1620533806937, 69.2911536352975, 70.98914745875767, 74.39270864214215, 72.07469926561627, 68.85621724809918, 71.23043060302734, 74.36424882071358, 73.81567464556012, 72.1264841897147, 73.32256099155971, 73.95545155661446, 75.43800258636475, 73.08068030221122, 69.93380641937256, 66.70044136047363, 69.69906847817558, 73.07863753182548, 74.47717789241246, 72.21597003936768, 61.79568018232073, 64.40394360678536, 75.3997666495187, 67.35688631875175, 70.18055779593331, 75.96840722220284, 70.30233887263707, 53.16522543770926, 66.22814450945172, 72.83656924111503, 69.28422628130231, 65.78851114000592, 62.67422430855887, 62.83795860835484, 67.26081357683454, 66.93292113712856, 68.13030420030866, 63.05055264064244, 62.777537073407856, 63.881675311497276, 62.10334641592843, 65.34583445957729, 60.705605098179404, 63.99907207489014, 59.96612916673933, 66.03054468972343, 66.00708062308175, 61.76179381779262, 64.63440145765031, 67.67892837524414, 51.27874435697283, 62.79520634242466, 64.21583502633231, 63.70181424277169, 64.97059004647392, 61.72984600067139, 56.737464564187185, 59.08470153808594, 64.2770208631243, 64.06571224757603, 66.07443646022251, 63.820809091840474, 64.63297012874058, 65.90307998657227, 65.41342653547014, 59.501975604466026, 62.70141955784389, 64.84772505078996, 64.28708880288261, 66.41880307878766, 62.57625470842634, 63.823803765433176, 65.21699401310512, 66.79313727787563, 62.50535529000418, 63.81985024043492, 56.73259735107422, 61.03483854021345, 62.29509585244315, 64.247894014631, 60.55407183510916, 61.62386512756348, 63.153309549604145, 62.97478253500802, 63.58425072261265, 62.346109526497976, 54.93126991816929, 63.726362228393555, 58.83759580339704, 63.47565037863595, 55.41538565499442, 56.16291454860142, 48.73914997918265, 38.279922417231965, 27.009582996368408, 7.062480390071869, 2.2705390666212355, 0.24304155419979775, 0.5121060663035938, 1.2806904443672724, 2.781728459256036, 2.01857219849314, 1.8587197703974587, 0.2131944950670004, 0.5935894910778318, 0.2127416950783559, 0.5644058627741677, 26.60564773423331, 61.010658809116904, 41.06700120653425, 45.47516073499407, 53.499492849622456, 0.47754029823201044, 0.19581630400248937, 0.09446695486881904, 0.12850218319467135, 0.17366879885750158, 0.1566984751927001, 0.15255224624914782, 0.1526617889425584, 0.12606613391212054, 0.07412551995366812, 0.16498703828879765, 0.1104779928656561, 0.09775675726788384], [0.022185094288683364, 0.04611301255811538, 0.02678955319736685, 0.007120077448364879, 0.028452610297660743, 0.03231205471924373, 0.023558464433465685, 0.028641733274395977, 0.012437242399235921, 0.10493461282125541, 0.09506415389478207, 0.14377375372818538, 3.661946449960981, 56.309802940913606, 36.84215947559902, 50.80919899259295, 32.9032986504691, 48.073172092437744, 5.812615845884595, 0.15829866432717868, 0.12921809192214692, 0.22733942605555058, 0.091983923821577, 0.23411819445235388, 0.4772741496562958, 0.3451380043157509, 0.276367150247097, 0.09207972618085997, 0.3201194682291576, 13.292147091456822, 54.839303561619346, 64.75787094661167, 74.1916138785226, 73.10549926757812, 75.05621991838727, 80.8565205165318, 79.70776094709123, 76.4656481061663, 71.37529359545026, 73.77605601719448, 75.7924301964896, 73.76971926007951, 71.93051719665527, 72.83931377955845, 66.71543557303292, 62.65916756221226, 67.1878296988351, 63.221721512930735, 62.507356371198384, 63.137127195085796, 61.6981691632952, 63.043528011866975, 62.23616818019322, 64.34275082179478, 66.49175916399274, 64.29865755353654, 65.59810965401786, 64.53654302869523, 65.70446572984967, 65.64426653725761, 67.07649871281215, 68.01113564627511, 65.39528478894914, 60.26026725769043, 59.35829380580357, 62.16588715144566, 66.91832297188895, 66.86899076189313, 66.32443264552525, 61.55222225189209, 56.26525803974697, 58.15085669926235, 68.11303792681012, 63.699382373264854, 64.38712896619523, 65.75554193769182, 63.0454318182809, 49.48254816872733, 58.0393693787711, 64.96426023755754, 62.577151026044575, 58.03386640548706, 50.97904075895037, 66.24374321528843, 62.12569877079555, 61.74605614798409, 60.06396675109863, 61.228290285382954, 58.190180029187886, 58.70526736123221, 61.17899281638009, 61.65609087262835, 61.20881448473249, 58.302924973624094, 55.68011896950858, 52.359599181583945, 58.35740579877581, 58.21042013168335, 61.22667135511126, 58.527775628226145, 60.554134368896484, 60.77462155478341, 46.9611302784511, 55.95282186780657, 61.530272892543245, 59.53798116956438, 60.18187768118722, 58.677842821393696, 53.403229032244, 52.491194588797434, 59.18756267002651, 62.13124343327114, 60.051918574741904, 56.98157909938267, 59.1050250189645, 57.748368399483816, 61.61941133226667, 55.95114387784685, 55.02305909565517, 57.17998491014753, 55.17983477456229, 59.104962485177175, 58.395940508161274, 58.49593898228237, 57.14083181108747, 56.46428918838501, 56.19824613843645, 54.17388847896031, 52.300859110695974, 54.906166076660156, 54.89497947692871, 54.35788719994681, 52.42826475415911, 53.64834063393729, 54.56557232992989, 57.3945244380406, 59.43673201969692, 50.46945640019008, 43.566921370370046, 53.62821170261928, 43.64176041739327, 49.88038812364851, 43.76375341415405, 35.51658909661429, 25.106063195637294, 15.200063364846365, 3.7580148492540633, 0.7242541653769357, 0.29009399509855677, 0.09456367325037718, 0.726249058331762, 0.30136761016079355, 0.34622056622590336, 0.6681719975812095, 0.019135042060432688, 0.1609822024724313, 0.07484968645232064, 0.35693542127098354, 5.704491019248962, 43.254704066685264, 27.783895458493912, 30.01757628577096, 45.02054010118757, 0.9431636759213039, 0.1298536349620138, 0.055315782848213396, 0.012317976299008089, 0.04632731427305511, 0.010525432664767971, 0.018244447885081172, 0.0030864967681866673, 0.051494290586560965, 0.022878431548763598, 0.053845611201333146, 0.0747269666088479, 0.08488450013101101, 0.019440520222165754, 0.06178040988743305, 0.0501413494348526, 0.06840711180120707, 0.006846525631512382, 0.050842554308474064, 0.02900492592847773, 0.05564397666603327, 0.02875084849074483, 0.0462145655016814, 0.07144930320126669, 0.2182509923087699, 5.9484626821109226, 66.30908407483781, 43.29646621431623, 49.539005756378174, 26.620496034622192, 58.58049161093575, 7.914746863501413, 0.22380881836371763, 0.14460323564708233, 0.2122456995504243, 0.0718298392104251, 0.4929613364594323, 1.83891219326428, 1.0710725209542682, 0.10611505340784788, 0.19469081796705723, 0.17669525503047875, 15.894803319658552, 66.5372212273734, 71.88095569610596, 79.30188887459892, 78.63601521083287, 78.5179305757795, 83.76928179604667, 82.57333006177629, 79.09193515777588, 71.4104653767177, 76.63528837476457, 77.54219504765102, 74.50892421177456, 74.0470427104405, 75.46034799303327, 72.02850764138358, 66.65544482639858, 70.71022592272077, 68.01073265075684, 66.71851362500871, 65.70586926596505, 63.371059145246235, 63.97666413443429, 65.8353350503104, 67.71525355747768, 67.07351098741803, 66.5358385358538, 68.43203667231968, 67.97795799800328, 68.07179341997418, 69.01994459969657, 69.69571249825614, 70.38554355076381, 69.94055312020438, 64.6369514465332, 63.722804750714985, 66.18606621878487, 68.36674445016044, 69.7815158026559, 68.83841596330915, 63.970334325517925, 59.99330357142857, 64.36781297411237, 70.07447964804513, 64.32034982953752, 67.4603727885655, 68.37695135389055, 63.007890701293945, 51.86300448008946, 63.565309933253694, 66.5371378489903, 65.43461854117257, 57.457495961870464, 56.2370240347726, 65.27424716949463, 62.50220775604248, 64.23957702091762, 63.41675744737898, 62.93924249921526, 61.490188734872, 61.157397815159385, 63.4597806930542, 63.582583154950825, 63.29296834128243, 62.70583166394915, 57.85615233012608, 55.40020036697388, 58.69610963548933, 59.41326795305525, 62.32354872567313, 61.412202153887065, 58.89614132472447, 63.709005628313335, 49.74144499642508, 53.57233081545149, 64.13322789328438, 60.154967308044434, 61.54526015690395, 59.32001617976597, 55.83255549839565, 54.18359511239188, 61.216262953622, 63.50663934435163, 61.416968618120464, 60.149144717625205, 61.67177990504673, 59.907486370631624, 64.6081303187779, 60.2691262108939, 59.01130076817104, 59.05879865373884, 59.003226961408345, 63.40586962018694, 60.99366351536342, 61.7111553464617, 60.64713600703648, 60.4311512538365, 57.746454170772004, 57.96024676731655, 54.16164575304304, 56.573275157383506, 56.66300071988787, 55.913602760859895, 56.40553174700056, 58.43539932795933, 58.64021832602364, 62.04258441925049, 62.29119096483503, 57.24852194104876, 50.23841142654419, 55.45927047729492, 54.694655963352744, 57.57704666682652, 62.28618131365095, 56.08369813646589, 51.15834597178868, 32.89452654974801, 5.739479107516153, 2.1943759535040175, 0.05792725378913539, 0.5241795384458133, 1.753450979079519, 0.9131221622228622, 0.5509905197790691, 0.3757706034396376, 0.026586620336664573, 0.1611353206847395, 0.05425324111378618, 0.47558834297316416, 8.008582285472325, 50.31745065961565, 26.215706144060405, 35.12443276814052, 54.449422768184114, 1.8119847753218241, 0.1311527309673173, 0.09818770842892782, 0.06190417467483452, 0.0673192912446601, 0.08729277018989835, 0.06837051162230116, 0.03348346061206289, 0.04851211221622569, 0.053520121345562596, 0.07470448674368006, 0.03762259886467031, 0.1369876300117799, 0.10073896617229496, 0.17242980748414993, 0.15988544560968876, 0.13428650423884392, 0.08993153859462057, 0.15044858413083212, 0.11347460706851312, 0.14951740338334016, 0.11275894939899445, 0.14571155474654265, 0.18144551584763186, 0.2531535987343107, 7.430873445102146, 80.35690334865025, 47.36612687792097, 69.34717696053642, 48.69930900846209, 67.05888502938407, 12.14894347531455, 0.4100048121597086, 0.4586509146860668, 0.6394157920564923, 0.21717360083545956, 0.9792784580162593, 3.50627292905535, 1.861616734947477, 0.5470514340060098, 0.4269722316946302, 0.6887808431472097, 19.817936897277832, 77.5221494947161, 79.97385610852922, 84.63179642813546, 82.5978363582066, 81.72551781790597, 86.61602129255022, 86.45182146344865, 83.41381890433175, 75.50077956063407, 79.16249411446708, 82.98005676269531, 76.68459974016461, 79.21352168491909, 80.90739522661481, 75.93626485552106, 74.07798303876604, 75.72054413386753, 71.92544501168388, 70.5029958997454, 69.43399470193046, 67.36236844744, 68.58287511553083, 71.56645243508476, 71.3835758481707, 73.32847390856061, 71.64871910640171, 71.5140769141061, 71.48591586521694, 71.67795017787388, 72.46516718183244, 74.41423416137695, 74.09583296094621, 72.3566015788487, 66.2253999710083, 66.3779546192714, 69.10701247623989, 72.51079600197929, 73.66096605573381, 70.17514514923096, 68.03804601941789, 63.15052332196917, 64.58738994598389, 73.51280961717877, 67.98360688345772, 68.69137818472726, 71.94355201721191, 69.26674461364746, 56.685377393450054, 63.80514785221645, 70.32853358132499, 69.47377313886369, 62.988769258771626, 56.14882707595825, 70.18128040858677, 65.1578231539045, 67.39770003727504, 65.27883992876325, 66.87360436575753, 61.99746281760079, 63.65368407113211, 65.26200444357735, 63.57051413399832, 65.9222639628819, 64.57411193847656, 59.3101566859654, 55.630922249385286, 65.1665848323277, 63.054804938180105, 62.701051303318565, 63.914588928222656, 63.64115646907261, 64.4574169431414, 52.683347020830425, 58.29064750671387, 64.33302334376744, 64.19658851623535, 64.50354603358677, 62.77284703935896, 56.87861027036394, 57.70244080679757, 64.1647310256958, 67.93722070966447, 64.76865455082485, 62.05173519679478, 63.45254067012242, 62.80297442844936, 69.07477978297642, 62.13805961608887, 63.07507978166853, 63.8420775277274, 61.630868911743164, 67.2895096370152, 65.27470575060163, 65.16978100367955, 64.92013222830636, 63.84320313589913, 61.98000199454171, 59.44001851763044, 57.991423334394185, 59.70621790204729, 61.81618431636265, 59.20125756944929, 61.1509290422712, 61.314017159598215, 63.64819499424526, 65.09076608930314, 69.55539362771171, 61.92549337659563, 58.86943244934082, 65.79614721025739, 61.71562303815569, 63.09118570600237, 63.46941784449986, 55.05666405814034, 47.82882826668875, 37.107900278908865, 14.374771101134163, 3.034934712307794, 0.7334956494825227, 0.8465973947729383, 3.3980508276394437, 1.5636220680815833, 1.2732221079724175, 1.0457544795104434, 0.13104046056313173, 0.39896344606365475, 0.1810677211199488, 0.776508744273867, 13.911860397883824, 60.3212377003261, 40.46648229871477, 41.65643078940255, 62.02495683942522, 1.8115832997219903, 0.2847007273563317, 0.16615627626223223, 0.1446350725101573, 0.144742253901703, 0.15741666379783834, 0.1698749874319349, 0.1498566980340651, 0.1290702120001827, 0.12959763727017812, 0.17040511327130453, 0.17915586728070462, 0.22882515990308352], [0.015895493661186526, 0.059977467704032145, 0.09006387327930757, 0.045763163295175345, 0.08224672917276621, 0.014716060699096747, 0.07473008108458348, 0.06376004258969001, 0.09663491496550185, 0.04978835176942604, 0.14373785922569887, 0.36657943949103355, 12.00755284513746, 48.54457957404, 38.162390163966585, 35.69899320602417, 26.199188538960048, 40.08695084708077, 1.2193630380289895, 0.038710551735545905, 0.11435817501374654, 0.05251468851097992, 0.17746532442314283, 0.05946356563695839, 0.7043036616274289, 0.8530173674225807, 0.36374207745705334, 0.044493614097258875, 1.1613505738122123, 20.77450234549386, 57.45887517929077, 67.74189989907401, 72.23582104274205, 72.13671193804059, 79.10254505702427, 77.5417434147426, 79.44096401759556, 79.25297355651855, 73.63165855407715, 77.11314378465924, 76.50958156585693, 76.78043624332973, 77.16687420436314, 69.90807723999023, 69.59046813419887, 69.56909547533307, 68.1517949785505, 67.97944491250175, 64.18573543003627, 64.1633552823748, 58.225063460213796, 64.04957158224923, 63.99766159057617, 67.73725155421666, 63.854646818978445, 66.06831509726388, 64.29366874694824, 63.17145129612514, 64.88501603262765, 64.19944422585624, 66.36321054186139, 62.0146735055106, 60.05958243778774, 62.35195296151297, 64.87272466932023, 67.16771466391427, 65.1903407233102, 69.11826160975865, 59.76550688062395, 58.1642632484436, 61.97477000100272, 67.51181030273438, 59.061904498508994, 64.28444153921944, 65.96428666796002, 58.28914669581822, 50.6166991506304, 59.02489839281355, 69.17866230010986, 61.91011701311384, 58.310359546116416, 54.12911081314087, 57.38689531598772, 58.501754624503, 62.0248178754534, 62.2106682913644, 61.76902689252581, 61.23152814592634, 62.33784811837332, 61.50092370169503, 59.35952363695417, 59.26233918326241, 58.42346927097866, 57.19354779379708, 56.740056242261616, 49.50398336138044, 55.59183863231114, 56.09648977007185, 59.58090714045933, 60.459020478384836, 58.6895991734096, 61.87437547956194, 61.0918276650565, 47.24574933733259, 52.57041447503226, 59.45848682948521, 60.10463455745152, 57.231592655181885, 61.34533963884626, 52.983675956726074, 53.411448751177105, 54.86283711024693, 57.87237637383597, 59.06053570338658, 58.31835692269461, 57.14069284711565, 55.170329638889854, 59.51437813895089, 55.918824332101, 54.60931124005999, 56.16824729101998, 57.11308765411377, 57.53897053854806, 56.081026554107666, 57.27622440883091, 56.92969342640468, 55.795789105551584, 56.514896392822266, 52.46402365820748, 50.49267380578177, 53.0188546861921, 54.59263208934239, 52.518976960863384, 55.7146897315979, 55.698288508823936, 61.762926374162944, 59.06865119934082, 60.990439551217214, 44.84675175803048, 51.553490025656565, 52.83299732208252, 48.10351487568447, 54.401862348829, 43.271230357033865, 39.02584975106375, 23.469124930245535, 8.128621969904218, 0.5959710947104863, 0.5229902022651264, 0.09661609918943473, 0.22193889798862593, 0.19500949872391565, 0.4281933775969914, 0.31305757431047304, 0.07073912130934851, 0.19532451539167336, 0.08468336878078324, 0.21805029522095407, 3.3941387747015273, 35.80576964787075, 39.617089339665, 17.020001547677175, 48.20398930140904, 3.2802200189658572, 0.15529343272958482, 0.08203229175082274, 0.046249506662466695, 0.05675394121291382, 0.03583771249811564, 0.05605705860736115, 0.025792115201641406, 0.05432396821145501, 0.035671803900705915, 0.07648815853255135, 0.0403866350118603, 0.07023585188601698, 0.014436909696087241, 0.11541704248104777, 0.03339292707719973, 0.029106061573007276, 0.07305663052414145, 0.04263264699173825, 0.025215648813173175, 0.07794578067426171, 0.028273422769936066, 0.12011635888900075, 0.16432586019592627, 0.3969167673162052, 17.568706001554215, 56.295618193490164, 47.543705463409424, 37.891500745500835, 22.774219955716813, 51.630649771009175, 1.47234488597938, 0.04474104189180902, 0.07704931377832379, 0.04462720746440547, 0.19544681454343454, 0.5129522808960506, 1.2011317248855318, 1.6758336297103336, 0.3868140051407473, 0.23871469923428126, 1.3011393185172762, 24.33628269604274, 69.47475283486503, 75.81239931924003, 78.76702349526542, 76.7394905090332, 81.89751352582658, 80.24113941192627, 83.4638181413923, 79.13675103868756, 74.91078717367989, 78.98771217891148, 78.22154126848493, 78.42959812709263, 76.68535709381104, 71.51463276999337, 71.77079200744629, 72.66774191175188, 71.406094959804, 69.37344809940883, 69.20143154689244, 68.22901030949184, 63.077511651175364, 67.2610011781965, 66.2719737461635, 69.70016629355294, 66.31023747580392, 68.9393663406372, 66.09657342093331, 65.96585696084159, 69.30912862505231, 69.48063795907157, 70.59039728982108, 63.62358447483608, 62.70116247449602, 67.2651423045567, 69.4325703212193, 70.05582373482841, 67.7904052734375, 68.35997690473283, 60.6326698575701, 62.47688157217843, 64.62426403590611, 69.16666276114327, 60.644120488848, 66.80490752628872, 67.85838644845145, 60.11983026776995, 55.42392151696341, 62.74867425646101, 69.13799449375698, 62.362590653555735, 59.26085226876395, 56.8485176222665, 59.078267506190706, 60.02142293112618, 65.87423801422119, 63.22625868661063, 63.61252294267927, 63.38480963025774, 62.78098337990897, 61.887952259608674, 61.26987525394985, 62.133418219430105, 60.42833028520857, 60.68209934234619, 56.422266483306885, 50.85059288569859, 54.448071343558176, 57.68800939832415, 58.567769459315706, 61.72364820752825, 60.47094358716692, 62.01998887743269, 61.95196601322719, 50.934617451259065, 51.06518452508109, 60.92555032457624, 62.510066168648855, 59.11930356706892, 63.00750160217285, 57.61363935470581, 53.75596128191267, 56.27176850182669, 60.42963654654366, 61.998025621686665, 59.56984560830252, 58.958008084978374, 56.298661504473, 62.50375720432827, 60.64256409236363, 56.90917192186628, 60.7187510899135, 58.008460317339214, 60.525570324489046, 60.51771886008126, 59.81190695081438, 58.80868434906006, 59.16786452702114, 59.1117856161935, 54.67483275277274, 54.17730351856777, 56.22136974334717, 57.83431761605399, 54.633713313511436, 55.50643137523106, 57.81451177597046, 62.875729015895296, 62.83085060119629, 61.85958971296038, 53.09051840645926, 52.644958223615376, 59.26110240391323, 54.42838709694998, 64.18705558776855, 58.96084295000349, 61.72496836526053, 44.89725821358817, 16.476129565920147, 1.9217447085039956, 0.29621728509664536, 0.2896082725908075, 0.22978599263089045, 1.0418686994484492, 0.5256741611020905, 0.2171334722744567, 0.03283597196319273, 0.056037930705185444, 0.056643553743405003, 0.3873833231627941, 6.02767779145922, 43.672026770455496, 36.77500861031668, 19.657143422535487, 55.15540143421718, 5.003713079861232, 0.2901906184852123, 0.17866962908634118, 0.01601458334230951, 0.045097065823418755, 0.06503577663430146, 0.05724850842463119, 0.0706581992230245, 0.025258532226351754, 0.06524849736264773, 0.06595790572464466, 0.05922993924468756, 0.06784569192677736, 0.1074066651718957, 0.2379920594394207, 0.1364299827920539, 0.1391487369047744, 0.14383163276527608, 0.16044035154793942, 0.16702508607081004, 0.16906257745410713, 0.24339851790240832, 0.14990386978856154, 0.38681807635085924, 0.5866932954107011, 19.74219458443778, 68.84842831747872, 50.449254512786865, 49.962800707135884, 38.23524897439139, 58.94120734078543, 3.637687465974263, 0.17956073555563176, 0.34736886460866245, 0.1644222257392747, 0.3674254098108837, 1.0785145844732011, 3.5847033262252808, 2.5066299523626054, 0.7494599499872753, 0.41093709213393076, 1.9419029525348117, 30.634982790265763, 82.78616728101457, 86.04952771323067, 85.43302100045341, 80.9579016821725, 84.83850533621651, 83.11774921417236, 87.20885549272809, 84.04037271227155, 80.81183665139335, 83.0334119796753, 81.62229537963867, 83.22080489567348, 82.05564757755825, 75.44791071755546, 77.94768496922084, 79.02466269901821, 74.93864250183105, 72.42130320412772, 70.74379267011369, 71.14619759150914, 65.9955952508109, 71.92352730887276, 69.2795501436506, 76.14282090323312, 71.06493840898786, 74.08045659746442, 70.99076638902936, 68.79507310049874, 72.84220423017229, 72.00029795510429, 74.16669763837541, 68.42305959974016, 65.5314416885376, 69.1309003829956, 72.89000783647809, 75.24848352159772, 71.98634597233364, 73.55497128622872, 66.02981512887138, 63.70628888266427, 66.14627388545445, 74.1755426951817, 64.42305810110909, 68.72289521353585, 72.5700432913644, 64.72084399632045, 58.647743225097656, 63.520257813589915, 73.34653922489711, 67.68460505349296, 63.52023696899414, 61.54541301727295, 62.16248948233468, 63.40693269457136, 68.74017538343156, 67.98030648912702, 66.31360735212053, 66.82833685193742, 67.40536390032086, 66.95113236563546, 63.53864969526018, 64.90391513279506, 61.122531754629954, 60.96970612662179, 60.48537499564034, 52.37669175011771, 58.83285713195801, 60.0396272114345, 63.68352658408028, 63.48560019901821, 60.34771728515625, 66.62050928388322, 63.0302916935512, 52.31018359320504, 57.052440302712576, 63.42567893436977, 67.0264230455671, 62.74841717311314, 66.49342673165458, 57.07482392447335, 56.8695776121957, 62.001583099365234, 62.71980449131557, 63.2159823008946, 62.109175954546245, 61.670640400477815, 57.70840236118862, 65.2859479359218, 61.91646071842739, 59.791465350559776, 64.5226605279105, 62.65469987051827, 63.249806131635395, 62.61045374189104, 64.44451413835797, 62.338647161211284, 61.46631472451346, 62.52537305014474, 59.05293437412807, 58.295775277274, 62.27263927459717, 63.105895042419434, 59.75907979692732, 60.45356614249093, 60.848202977861675, 66.69394479479108, 66.69804423195976, 67.31717041560582, 58.226633753095356, 62.89296054840088, 66.61741733551025, 58.398761476789204, 67.76823357173375, 61.745048659188406, 60.00690119607108, 46.54652779442923, 26.699128798076085, 2.5964126203741347, 0.80865849341665, 0.5625444512282098, 0.8590941642011914, 2.049161425658635, 1.2928161365645272, 0.7145394438079425, 0.14663007403058664, 0.29494353915963856, 0.24425083931003297, 0.4096385660980429, 10.409575734819684, 52.390504768916536, 56.34992183957781, 27.340223448617117, 63.33326094491141, 5.819564044475555, 0.7048909472567695, 0.3437808799956526, 0.11865621938237123, 0.12681546727461473, 0.08649459587676184, 0.09867263026535511, 0.15953272953629494, 0.09244644043168851, 0.1271109421338354, 0.13348769210278988, 0.11816565213458878, 0.30774643644690514], [0.02917546552738973, 0.027688547636249235, 0.08695900559957538, 0.06632685914103474, 0.07885853241064719, 0.056313833221793175, 0.059977298070277484, 0.053599085858357806, 0.10746881219425372, 0.049435483025653024, 0.044612910731562545, 0.1905539392360619, 22.204085520335607, 53.513965947287424, 29.35464518410819, 39.99496364593506, 31.497424466269358, 31.311087676456996, 0.11223284727228539, 0.16644202092928545, 0.08131522272846528, 0.0635348300316504, 0.11029153144253151, 0.14347090997866221, 0.7775595507451466, 0.0939504811540246, 0.27310969361237114, 0.11584872645991189, 2.1661478110722134, 23.348954098565237, 51.95662798200335, 66.95748996734619, 69.36803545270647, 76.0466856275286, 80.20849677494594, 81.39490863255092, 75.3287421635219, 78.70733152117047, 72.05798884800502, 76.57436656951904, 73.74670682634626, 76.99596241542271, 68.7400711604527, 69.81997408185686, 67.94843510219029, 67.83210836138043, 67.67679527827671, 70.3478148324149, 67.74586732046944, 63.275229590279714, 64.79403632027763, 65.5031555720738, 66.21975803375244, 62.32129750932966, 64.00892462049211, 65.03105327061245, 64.73039776938302, 66.4637370790754, 62.77054023742676, 65.30519444601876, 59.738360268729075, 61.341594559805735, 61.15165860312325, 63.82941790989467, 67.06401974814278, 64.14545672280448, 65.79453522818429, 57.52074888774327, 58.41779259272984, 66.31559453691754, 68.34039688110352, 64.92423861367362, 63.458078384399414, 62.637551716395784, 53.57117741448538, 51.58539962768555, 63.01925795418875, 65.40210791996547, 61.181640080043245, 57.637054783957346, 51.23238945007324, 51.515535490853445, 46.894375460488455, 52.249921866825645, 59.77462291717529, 59.71479197910854, 58.64388697487967, 59.14585958208357, 60.4824914932251, 58.413477761404856, 57.65080526896885, 57.70869418552944, 61.30322660718645, 58.65865189688546, 43.32025684629168, 48.83469465800694, 50.15847934995379, 54.640640667506624, 55.88430568150112, 55.785311222076416, 60.25462532043457, 59.11183425358364, 57.372644560677664, 62.02859074728829, 48.08553293773106, 51.299672331128804, 57.761135714394705, 57.59691504069737, 57.15819188526699, 61.33593872615269, 55.995831217084614, 52.42467948368618, 52.250071253095356, 59.428692953927175, 57.11187866755894, 57.71154989515032, 56.52844885417393, 54.95556429454258, 59.10914530072893, 56.378739493233816, 55.4186304637364, 57.73203318459647, 56.357498850141255, 58.20864486694336, 56.74634436198643, 54.638705594199045, 55.548068455287385, 55.892765113285606, 53.21532889774868, 51.98436519077846, 51.92960296358381, 50.62203189304897, 49.87488167626517, 53.75224052156721, 57.84638316290719, 60.26777826036726, 62.23347922733852, 58.85561943054199, 55.39456537791661, 47.725404330662315, 56.95697900227138, 54.96766805648804, 58.58328478676932, 51.76094586508614, 49.81571429116385, 28.711519922528947, 11.233438406671796, 0.8208138783063207, 0.34221834955470903, 0.0529759634020073, 0.16633122973144054, 0.6601459054010255, 0.16427118384412356, 0.228629931807518, 0.057427458465099335, 0.09617301582225732, 0.16859603034598486, 0.5643361636570522, 1.9846146149294717, 24.773885454450333, 54.36608954838344, 26.098444870540074, 47.1969312940325, 9.039740119661603, 0.59013460789408, 0.1553288386868579, 0.18869430545185292, 0.13212043046951294, 0.07305314285414559, 0.1139035022684506, 0.045026871375739574, 0.09450556351138012, 0.022098703210109046, 0.1091730139617409, 0.020641885132395794, 0.049613333839390955, 0.013759963297551232, 0.055134658103010485, 0.03932757076940366, 0.06412210209029061, 0.01976840869922723, 0.023792967832248126, 0.03169435715036733, 0.07769179823143141, 0.11422562998320375, 0.07026739019368376, 0.11877940062965665, 0.24500249326229095, 29.868686812264578, 58.90308952331543, 48.510859966278076, 43.14066675731114, 32.176715101514546, 40.247610569000244, 0.24458068875329836, 0.11217377401356186, 0.15887792967259884, 0.04327244444617203, 0.650984488427639, 0.13506884154464516, 1.6224762414182936, 0.15055573838097708, 0.23487039123262676, 0.44034249282308985, 2.4167988640921454, 29.427934782845632, 67.27810764312744, 74.7882695879255, 75.10071618216378, 79.47436400822231, 80.60340459006173, 84.2016612461635, 75.72979913439069, 80.56644712175641, 74.93610640934536, 78.70342663356236, 76.04775565011161, 78.39147336142403, 70.21697330474854, 73.02935395921979, 71.85367012023926, 71.22182178497314, 71.16111537388393, 73.41569464547294, 68.85423006330217, 67.19086606161935, 69.07521751948765, 66.7003093447004, 67.82624408176967, 67.52335820879254, 66.95522485460553, 68.58260413578579, 70.06300817217145, 68.94824613843645, 65.21358244759696, 67.05561937604631, 63.609840938023154, 64.79426561083112, 66.26453222547258, 68.61116818019322, 69.53630692618233, 67.03379508427211, 68.19528375353131, 58.41319983346121, 63.11594908578055, 69.6092838559832, 68.95921734401158, 67.76831000191825, 67.70818723951066, 63.98735046386719, 56.98486907141549, 55.729656151362825, 67.84148842947823, 65.61371530805314, 64.02681623186383, 59.86659622192383, 54.18525573185512, 52.68683501652309, 47.51082311357771, 52.64545849391392, 62.437193461826865, 61.97471441541399, 61.873632022312705, 60.893873487200054, 62.116721698216026, 60.40007890973772, 59.382292883736746, 59.95305265699114, 64.1261476789202, 58.36625780378069, 45.86609418051583, 47.92452233178275, 51.646050453186035, 55.68293298993792, 57.47813905988421, 57.2088303565979, 60.59857504708426, 62.06192125592913, 56.726566314697266, 63.960884775434224, 51.42597321101597, 52.811100074223106, 58.1036992754255, 62.27708612169538, 59.004915373665945, 63.16432244437081, 60.65587684086391, 56.27366883414132, 54.48959377833775, 62.23541777474539, 60.909249850681846, 60.05811636788504, 57.78140708378383, 56.42742552076067, 61.661996841430664, 58.518152373177664, 58.315195492335725, 58.00243970326015, 60.092676707676475, 60.29128401620047, 59.754077093941824, 57.76912266867501, 56.0011431149074, 57.72684288024902, 55.902558599199565, 53.81437826156616, 56.34906721115112, 53.7045897756304, 53.38419096810477, 57.02648878097534, 59.745106969560894, 60.45673452104841, 63.906132970537456, 62.434560094560894, 61.05352224622454, 52.97465372085571, 58.77228273664202, 58.48297364371163, 62.70336505344936, 61.229832785470144, 63.47080748421805, 47.41940566471645, 25.713118621281215, 2.114793675286429, 0.16702720310006822, 0.029053702418293272, 0.5345463050263268, 1.8914134332111903, 0.5261644976479667, 0.17226824829620974, 0.017966287543198893, 0.007139727822504938, 0.09609898765172277, 0.5918945106012481, 2.085564775126321, 34.15165717261178, 51.54591996329171, 30.836935656411306, 57.69675718035017, 11.07949846131461, 0.5989476921302932, 0.1450159749282258, 0.10947738441505603, 0.1166276710906199, 0.0533478684457285, 0.06859493707971913, 0.03959428592185889, 0.10777742349143539, 0.06153174037379878, 0.05082444081615124, 0.04086526682866471, 0.07805157106901918, 0.0759185351697462, 0.17374381768916333, 0.10623332884694849, 0.20941361651888915, 0.17612262575754098, 0.12695175781846046, 0.15377592987247876, 0.16227088975054876, 0.17888773738273553, 0.3026309066585132, 0.19547679222055844, 0.3500418583197253, 32.54465000970023, 73.5816593170166, 40.83895090648106, 55.44747243608747, 49.42949519838606, 45.345559460776194, 0.5673219348703111, 0.34312047543270247, 0.2461026699415275, 0.16343977488577366, 0.8003055102058819, 0.5222957081028393, 3.455700682742255, 0.4520707263478211, 0.6618225925735065, 0.973489197237151, 3.6876143983432224, 38.276038374219624, 81.60243742806571, 82.24525696890694, 80.59159960065568, 81.79993997301374, 86.73814283098493, 86.53183691842216, 82.2915597643171, 84.94256850651333, 80.8250868661063, 81.89802074432373, 78.35607228960309, 81.07707718440464, 74.09677791595459, 78.36721720014299, 74.94031701769147, 76.36605957576207, 75.46318285805839, 77.28067180088588, 74.16765648978097, 71.20991952078683, 72.38954298836845, 72.1061190196446, 71.50590583256313, 70.36913190569196, 70.32314872741699, 74.81561769757951, 72.75827693939209, 74.46323980603898, 68.11184283665249, 71.57113552093506, 67.19018513815743, 68.1479526247297, 67.89029257638114, 71.59544031960624, 73.21486391339982, 69.82513659340995, 72.19604955400739, 63.233033180236816, 61.770249775477815, 72.9503390448434, 73.34448950631278, 71.43638215746198, 71.30953584398542, 67.57674816676548, 61.30144092014858, 56.536300318581716, 68.59380463191441, 70.87313338688442, 66.42925316946847, 64.34801060812813, 56.620456899915425, 57.06223031452724, 51.330911431993755, 57.64576782499041, 65.54843003409249, 63.404980250767295, 63.30566964830671, 63.22660609654018, 64.124758039202, 62.042417662484304, 59.42683778490339, 59.700318881443565, 66.33828735351562, 63.98909446171352, 48.69137416567121, 52.75044577462332, 56.707031454358784, 59.7400278363909, 59.200062479291645, 59.7851494380406, 66.7061458315168, 63.00343690599714, 61.12529018947056, 67.89214079720634, 51.445570605141775, 57.31528718130929, 63.149293490818565, 63.03940078190395, 62.100164140973774, 66.40859617505754, 63.039609227861675, 58.79762976510184, 57.60277584620884, 66.43932805742536, 62.28973879132952, 62.86339596339634, 59.996652603149414, 59.89459746224539, 64.40884208679199, 61.2466265814645, 60.05591378893171, 61.819311005728586, 61.36420399802071, 64.20243889944894, 63.42984785352434, 60.1168703351702, 60.549513816833496, 62.35047994341169, 59.72358839852469, 58.189509528023855, 62.199808256966726, 58.042530809129985, 57.86381619317191, 59.739166259765625, 65.13952159881592, 63.95112950461251, 69.00381783076695, 65.5732420512608, 65.50458690098354, 60.97910009111677, 67.68538325173515, 64.80765478951591, 65.29520988464355, 63.13426453726632, 64.52500207083565, 49.859126635960166, 37.35043409892491, 3.588083190577371, 1.2761487109320504, 0.3292438100491251, 0.9517283077750887, 2.7405234702995847, 1.4374869678701674, 0.5644210619585854, 0.25191863785896984, 0.12059217478547778, 0.5282517256481307, 0.6089227540152413, 5.475850556577955, 40.41633367538452, 69.87746347699846, 38.59401226043701, 62.32636969430106, 13.315489564623151, 1.0898470963750566, 0.3431258222886494, 0.48472115291016443, 0.3127641757684094, 0.16993791476956435, 0.21133100720388548, 0.20701595874769346, 0.18228010034986905, 0.17423946037888527, 0.19723035741065228, 0.14489059522747993, 0.20945176375763758], [0.051234367569642406, 0.0026926661375910044, 0.0255215476666178, 0.06336071794586522, 0.06124172093612807, 0.05153620708733797, 0.08885451353022031, 0.06118327871497188, 0.021197247385446514, 0.07317173720470496, 0.05419340789584177, 0.06765963762466397, 31.392913137163433, 46.75503281184605, 30.117474011012487, 24.09104081562587, 37.6358973639352, 22.182342869894846, 0.09214908603046622, 0.10855366755276918, 0.07353236499641623, 0.034625767530607324, 0.32866173556872774, 0.3476078175008297, 0.5566308828336852, 0.7197954303451947, 0.21166353007512434, 0.10333181132695504, 5.377778470516205, 29.628251348223003, 50.67202418191092, 66.73325075422014, 69.33077226366315, 76.0633682523455, 77.09191703796387, 77.55362483433315, 75.01989473615373, 78.03674697875977, 72.75607436043876, 77.21594933101109, 74.50144100189209, 74.49596582140241, 71.37341758183071, 68.82798671722412, 68.85991368974958, 67.41889899117606, 67.0595451082502, 69.72807720729283, 64.3429592677525, 64.11366176605225, 62.97333036150251, 61.14937959398542, 65.31936182294572, 66.43563161577497, 63.406557491847444, 66.53102343423026, 66.94182177952358, 62.49060426439558, 66.63304383414132, 60.11273615700858, 60.77548313140869, 65.67313630240304, 65.21618802206856, 61.41910866328648, 66.07668767656598, 68.15254538399833, 57.18098545074463, 61.19088813236782, 67.1244968686785, 64.87677546909877, 63.44805908203125, 67.45986557006836, 61.06479222433907, 53.01938622338431, 53.55621446881975, 63.13894762311663, 63.49973283495222, 60.582656724112375, 60.01387023925781, 48.7303466115679, 46.50888245446341, 44.66083880833217, 46.506537437438965, 42.46600709642683, 51.73065519332886, 64.82576179504395, 61.56544467381069, 62.26967934199742, 59.70991434369768, 62.7004884992327, 61.265386717660085, 64.66473729269845, 57.0388947895595, 44.93064430781773, 43.33739110401699, 44.07496670314244, 44.55993012019566, 46.703911440713064, 51.45843172073364, 57.24474559511457, 57.158865860530305, 56.36865070887974, 57.86413581030709, 57.189635957990376, 60.73578807285854, 50.97608082635062, 47.32423618861607, 60.05815805707659, 57.84014368057251, 58.706372124808176, 57.52548408508301, 59.065517561776296, 54.63117722102574, 52.83221217564174, 55.41210263116019, 59.846786907741, 58.33088452475411, 54.43077032906668, 54.40773357663836, 58.9141024180821, 53.91658973693848, 57.865546294621055, 55.94840628760201, 57.001899106161936, 55.7221416745867, 54.4581948689052, 55.313427788870676, 56.340055397578645, 55.311145305633545, 51.70098985944475, 49.79886143548148, 48.975624970027376, 50.48391212735857, 53.05026749202183, 56.09673295702253, 58.40426445007324, 59.75743307386126, 58.39961610521589, 57.14697054454258, 53.81176226479666, 56.01089491162981, 57.852143219539094, 59.13005937848772, 59.003560474940706, 52.04900080817086, 40.10205275671822, 19.0162068435124, 4.974958394254957, 0.2218238455908639, 0.06751631745802504, 0.1403898045952831, 0.40041222689407213, 0.19010611969445432, 0.12253817250686032, 0.058268421196511815, 0.14733462408185005, 0.038038669752755334, 0.6330585703253746, 1.1963525584765842, 10.937904596328735, 50.49451855250767, 25.746657575879777, 39.34796476364136, 16.57663699558803, 0.38367781628455433, 0.18572072072752885, 0.05460757549319949, 0.14228553644248418, 0.03903519342254315, 0.06562315725854465, 0.016899998599131192, 0.07862359644579035, 0.012261851274940585, 0.013505592393422765, 0.044826791754790714, 0.05404756697160857, 0.04050563648343086, 0.012769621081783302, 0.03635986215834107, 0.028857582049178224, 0.057130925091249604, 0.0652591028649892, 0.1467201563396624, 0.03303051473838942, 0.04061748619590487, 0.022152894409373403, 0.037700959481298923, 0.09276395410831485, 41.48702675955636, 53.41734082358224, 43.729839256831575, 24.99734820638384, 40.80236169270107, 26.529062952314103, 0.1100778268384082, 0.20485369834516728, 0.17317064558821066, 0.0545100734036948, 0.7636368264045034, 0.3424713345510619, 1.071796110698155, 0.6210157136831964, 0.2382199386400836, 0.25094209026013103, 6.0262890202658514, 37.07263469696045, 66.19063118525914, 78.42583220345634, 75.20540469033378, 80.45784677777971, 81.52454117366246, 80.02503653935024, 77.53642109462193, 80.65041610172817, 77.20217105320522, 79.01224626813615, 76.27214077540806, 75.7414860044207, 71.25438799176897, 71.26004382542202, 69.35280500139508, 70.96065289633614, 69.10533796037946, 72.32461207253593, 67.58436339242118, 70.14618505750383, 65.05539975847516, 65.21174812316895, 68.03482900347028, 68.11132866995675, 65.73129272460938, 66.14345986502511, 69.78646292005266, 66.0880549294608, 69.23488712310791, 62.48759569440569, 64.98102624075753, 68.07172393798828, 69.14523451668876, 65.34777300698417, 69.06027889251709, 68.06464372362409, 60.874897956848145, 66.69356264386857, 68.67074203491211, 65.51503699166435, 65.9746811730521, 68.83003643580845, 62.24341515132359, 54.63029827390398, 58.60963930402483, 66.48227487291608, 65.30233178819928, 64.64428179604667, 60.269959994724815, 51.27080604008266, 49.41517843518938, 47.06791019439697, 51.12269476481846, 44.664563042776926, 53.11624411174229, 66.99489906855992, 65.4870913369315, 64.0442145211356, 61.950729233878, 63.771629742213655, 61.83839075905936, 64.26696681976318, 57.33720179966518, 46.71369797842843, 46.27272360665457, 46.768901416233604, 47.79565756661551, 48.019045625414165, 51.30827072688511, 55.76334796633039, 58.33367075238909, 57.98934234891619, 59.839505195617676, 59.337108748299734, 61.777135440281455, 54.28593512943813, 49.569869654519216, 59.07382065909249, 60.524326596941265, 61.245619092668804, 59.464580399649485, 62.33513832092285, 56.99113287244524, 54.304445130484446, 57.27293791089739, 61.307138442993164, 60.894519669669016, 59.314026832580566, 55.51690231050764, 61.01052679334368, 57.88789864948818, 58.92644936697823, 59.56077126094273, 59.03429930550711, 58.86379051208496, 58.15729420525687, 57.989939893995015, 58.52251584189278, 57.49688182558332, 54.76470422744751, 54.06189046587263, 52.905932562691824, 53.2090060370309, 55.92802722113473, 57.38439049039568, 60.865636008126394, 63.13245800563267, 63.12933826446533, 61.0006742477417, 56.51782505852835, 59.480151312691824, 62.941174098423545, 60.62136513846261, 63.59431171417236, 60.8895378112793, 56.61950152260916, 34.20150702340262, 7.170117974281311, 0.396077962326152, 0.05470628537503736, 0.5659517826778548, 0.8706577037061963, 0.3352663783090455, 0.3772926389106682, 0.02906487789005041, 0.10052610973694495, 0.04006766587761896, 1.0346046835184097, 2.1293475457600186, 12.287288188934326, 56.55578306743077, 24.977368661335536, 46.81515210015433, 20.631124530519756, 0.37359717435070444, 0.15524847299924918, 0.04906505040292229, 0.05237725802830287, 0.03838628663548401, 0.03953214568485107, 0.0667850331270269, 0.08940425581697907, 0.015632138953411152, 0.024887093675455878, 0.039538252500018904, 0.07719940572444882, 0.26127897415842327, 0.13139047606715135, 0.1504046693444252, 0.19869003551346914, 0.14684143768889563, 0.13764913380146027, 0.296146174626691, 0.1515218908233302, 0.07484868900584322, 0.17105881390827044, 0.17792351197983536, 0.16071320404963835, 46.3321133341108, 60.5556560243879, 42.42200068065098, 35.84842116492135, 54.47783047812325, 32.946301051548545, 0.2834378922624247, 0.8221312133329255, 0.22719635016151837, 0.19075900608939783, 1.2592169280563081, 1.5487060227564402, 1.1988165634019035, 1.038556580032621, 0.5350866903151784, 0.9202765268938882, 8.454859001295906, 46.699839796338765, 85.51100063323975, 87.71682439531598, 80.72857638767788, 83.22433458055768, 85.64253003256661, 81.75274780818394, 80.42076424189976, 83.98075022016252, 74.90213666643415, 80.51197324480329, 78.27270780290876, 80.81652668544224, 75.88277067456926, 75.88937146323067, 73.81609153747559, 75.32590729849679, 70.30660506657192, 77.87561130523682, 69.76064341408866, 74.07887935638428, 68.00242260524205, 69.12217344556535, 69.78124482291085, 73.4372479575021, 67.41732175009591, 71.13195378439767, 75.13424818856376, 70.06288310459682, 74.03516129084996, 65.2817164829799, 65.53392219543457, 72.71995067596436, 71.05451611110142, 69.10397611345563, 71.7964517048427, 75.27915287017822, 64.33132103511265, 68.7962542942592, 72.24741758619035, 69.70763560703823, 68.36666801997593, 72.9134441103254, 67.703017779759, 58.18332215717861, 57.62271022796631, 69.04147011893136, 68.07095963614327, 66.3873416355678, 64.92810181209019, 55.72718954086304, 50.0871456691197, 49.5077805519104, 53.395387990134104, 46.547656876700266, 59.40079593658447, 70.45730454581124, 66.5402923311506, 67.81206280844552, 64.18975148882184, 66.45118863242013, 65.94065584455217, 68.3670710154942, 61.18653161185128, 50.08259807314192, 48.671797616141184, 48.438827991485596, 48.58283288138253, 51.19880185808454, 57.41616460255214, 60.040738923209055, 61.07590239388602, 60.56952462877546, 60.59682410103934, 63.00944709777832, 64.63234479086739, 54.84490033558437, 52.236529214041575, 64.70446709224156, 63.414026805332725, 63.48490537915911, 61.809548786708284, 65.16853032793317, 59.597881589617046, 58.02989898409162, 60.67725644792829, 65.66645908355713, 64.35445158822196, 62.33144882747105, 58.79414871760777, 64.84762777600969, 61.169730867658345, 62.06476306915283, 63.2509525844029, 63.103143555777415, 63.4812228339059, 60.875328745160786, 61.338231631687705, 60.83584908076695, 58.80848979949951, 59.77225358145577, 59.00163582393101, 57.638819626399446, 58.43590654645647, 61.30205930982317, 60.798245429992676, 65.312851360866, 66.22530269622803, 64.20227214268276, 65.5662591116769, 62.14939907618931, 65.88994094303676, 68.38427475520542, 64.2127708707537, 67.300265448434, 63.696547508239746, 59.54213619232178, 47.127484049115864, 10.731487512588501, 1.2655119959797179, 0.32981274809156147, 1.6183682275669915, 2.13964911869594, 1.3400801718235016, 0.6611402577587536, 0.21525523306003638, 0.16512626010392392, 0.35839177455220905, 1.2263341439621789, 6.277400825704847, 19.48260293688093, 65.94253185817173, 36.34272990907942, 52.41083172389439, 24.190146446228027, 0.535707739847047, 0.2802575443472181, 0.14912310668400355, 0.20624644575374468, 0.127299805570926, 0.14278450395379746, 0.12935378535517625, 0.18957228905388288, 0.10412729185606752, 0.07711800866361175, 0.1353518720716238, 0.20149718916841916], [0.020678654945056354, 0.027914260613865087, 0.024065014573612382, 0.025262720483754362, 0.08088324697954313, 0.03507547679224184, 0.017066885983305316, 0.0679433670427118, 0.043164235074073076, 0.020071037013881972, 0.03688079384820802, 0.831242418714932, 46.355837958199636, 38.120562008449006, 39.91282204219273, 40.1727819442749, 37.7964528628758, 11.530876891953604, 0.2261696316834007, 0.21519450417586736, 0.09716141064252172, 0.06923585411693368, 0.15381372427301748, 0.7343957126140594, 0.11863576833690916, 0.47981990448066164, 0.29308253473469187, 0.288051821823631, 13.955686160496303, 35.04394483566284, 49.796811716897146, 64.84196499415806, 67.7131621497018, 76.27922793797084, 77.47991139548165, 77.25328200204032, 76.01443903786796, 75.90963935852051, 75.54820101601737, 72.74907057625907, 72.43212849753243, 70.39256123134068, 66.58153683798653, 63.264862877982004, 65.66726507459367, 64.51417677743095, 66.69338893890381, 70.37153598240444, 69.04571546827043, 66.5224563053676, 61.29966218130929, 64.00779206412179, 66.20619515010289, 66.90243938991001, 65.67275415148053, 65.27628299168178, 61.76099477495466, 64.44415978022984, 59.20106996808733, 64.91781152997697, 65.93032387324742, 63.52701146262032, 62.530723163059776, 63.7266332081386, 63.81702927180699, 54.807310581207275, 61.10659258706229, 67.22804587227958, 56.92999219894409, 64.62061623164585, 62.57223170144217, 56.57015889031546, 52.7977352142334, 59.408223560878206, 65.28791427612305, 63.08174310411726, 59.61962945120675, 58.391702107020784, 45.00928054537092, 47.53407178606306, 49.63588796343122, 49.1871246610369, 46.51818609237671, 46.76597275052752, 44.16393838609968, 52.03504535130092, 62.15695871625628, 59.969658851623535, 61.8170736857823, 60.23775509425572, 59.86866678510393, 58.12365450177874, 46.45087194442749, 42.88233968189785, 44.61116961070469, 46.638525417872835, 49.110041345868794, 47.44744859422956, 44.92187220709664, 44.53133133479527, 54.24154308864048, 58.05272034236363, 56.61730241775513, 61.00187628609793, 55.577737263270784, 59.97362627301897, 53.646513257707866, 52.04006542478289, 52.3706259727478, 59.39382689339774, 58.65429537636893, 58.17384481430054, 60.05492714473179, 55.88702242715018, 50.56648104531424, 55.39580910546439, 57.789671966007774, 59.05030100686209, 53.59767089571272, 55.85254546574184, 55.403361797332764, 54.016970361982075, 57.77568524224417, 56.485644476754324, 53.70526375089373, 55.38960436412266, 55.21513162340437, 56.78839485985892, 56.06842252186367, 53.77610410962786, 47.31757634026663, 47.78073631014143, 50.72472974232265, 55.568339824676514, 56.86354310171944, 58.18916211809431, 58.09910304205758, 58.09053243909563, 58.526809828622, 56.193024567195344, 52.98495442526681, 57.60322053091866, 61.26855509621756, 62.064200265066965, 58.24600880486624, 48.3734176499503, 23.924575873783656, 7.671328016689845, 0.9055365749767849, 0.09046984078096491, 0.12036192071224962, 0.1340225405458893, 0.16423987623836311, 0.1347925556557519, 0.13965351267584733, 0.15993792350803102, 0.04171215656346508, 0.7437211722135544, 0.9290923795529774, 2.0987007788249423, 39.329843861716135, 34.795789922986714, 32.17695828846523, 31.655509880610875, 0.2638493462332657, 0.13441047258675098, 0.07304276126836028, 0.11239275083478008, 0.021537573409399817, 0.11007307709327765, 0.021232595667243004, 0.04962786127414022, 0.01559530637626137, 0.030152752729398862, 0.05720664281398058, 0.050378850262079916, 0.041529240485812934, 0.024545089973668967, 0.019029071853895272, 0.049074200447648764, 0.039777242711612155, 0.01700506465775626, 0.028293098589139323, 0.09059602115303278, 0.004079723181868238, 0.020133881230971644, 0.07452776908342328, 1.1998935341835022, 54.81865698950631, 49.086726665496826, 42.81247901916504, 24.63640144893101, 49.1228677204677, 12.077178137642996, 0.20028106442519597, 0.008869842842354305, 0.08464182886694159, 0.12313073713864599, 0.32680442237428253, 0.5461844291005815, 0.1731384830283267, 0.6488822783742632, 0.2167633721338851, 0.20822385964649065, 14.842925957271031, 46.95972326823643, 66.75854219709123, 75.62936292375836, 74.04500688825334, 78.69506100245884, 80.28628185817173, 80.0583462033953, 76.20393030984062, 78.67881611415318, 77.23303495134626, 77.3626605442592, 73.78077384403774, 71.80399744851249, 68.910322870527, 66.13658114842006, 68.49948978424072, 69.16491181509835, 70.11209024701799, 72.40935230255127, 70.98110839298793, 70.05510112217495, 66.51871817452567, 67.53066771371024, 68.22698143550328, 68.66774041312081, 65.60989379882812, 70.02227783203125, 66.0235617501395, 68.11969430106026, 64.66582121167863, 67.6712645121983, 67.0175849369594, 65.99249635423932, 67.91229057312012, 68.37497111729213, 64.54674298422677, 57.643707684108186, 67.16403906685966, 68.38178730010986, 61.151533535548616, 67.79674897875104, 64.15325954982212, 58.4197450365339, 55.532289096287315, 63.25323159354073, 66.8125991821289, 63.598626545497346, 62.86311108725411, 58.210750171116416, 47.57035180500576, 52.622505119868684, 51.89688042231968, 52.165466512952534, 48.54713303702218, 49.37886367525373, 45.03902578353882, 52.57083484104702, 62.03015409197126, 62.664309229169575, 65.22290693010602, 61.26319803510393, 62.485566820417134, 59.260233879089355, 46.521080017089844, 46.60626493181501, 47.93115438733782, 48.607217584337505, 51.98658166612898, 50.95800856181553, 46.098375933510916, 46.18041678837368, 54.41130147661482, 59.97420992170061, 57.987872804914204, 61.61389446258545, 58.53000599997384, 60.63311454227993, 58.39031246730259, 54.31596524374825, 53.70058066504342, 61.65854358673096, 62.04470361982073, 58.381071363176616, 62.04837921687535, 58.3742412839617, 52.594413552965435, 56.82401827403477, 59.33596229553223, 60.47819750649588, 57.02691956928798, 57.73733466012137, 60.33563436780657, 57.808779512132915, 59.30383382524763, 58.32531901768276, 57.614473138536724, 56.45145239148821, 58.39157703944615, 57.70067596435547, 57.879439217703684, 56.69401747839791, 51.60189117704119, 50.96778467723301, 52.199175698416575, 57.682645389011924, 59.3494348526001, 60.195252963474815, 63.5454797744751, 62.94189671107701, 62.08245318276541, 60.6186831338065, 57.90798936571394, 63.053484780447825, 61.23364039829799, 64.19319779532296, 62.91447217123849, 60.44892474583217, 41.23248645237514, 12.003730467387609, 1.8815687043326241, 0.052155600993760994, 0.06832450016268662, 0.20226841207061494, 0.7522852612393243, 0.06672268254416329, 0.1296351873981101, 0.0743186106639249, 0.03482763848400541, 0.8895622864365578, 1.1745338035481316, 1.7086936150278365, 46.584496225629536, 32.33601992470877, 37.44291809626988, 37.57274866104126, 0.16591663126434597, 0.10820616941366877, 0.054454012840454064, 0.100904413365892, 0.08691157600177185, 0.059014042972454, 0.034361508674919605, 0.10704808655594077, 0.03305589534076197, 0.02786173521807151, 0.015548529868413295, 0.08150536181139094, 0.10001132557434694, 0.05203060466530068, 0.09719065550182547, 0.15188694266336306, 0.2515084227280957, 0.07714812204773937, 0.10806589586926357, 0.15484105343265192, 0.09893546759017877, 0.0731076088600925, 0.1130923747218081, 0.9993927329778671, 70.27562999725342, 49.16567209788731, 52.97502892357962, 55.021707671029226, 57.33322395597185, 17.63657774244036, 0.3607626844729696, 0.41480403606380734, 0.3682037166186741, 0.4572030838046755, 0.7612373637301582, 1.2310122357947486, 0.2690598437828677, 1.4804609247616358, 0.449746771050351, 0.41017987419451984, 18.241564341953822, 59.074272292000906, 80.25261088779995, 81.29801600319999, 80.2912984575544, 85.20225742885044, 86.60193034580776, 79.03758634839738, 76.9999645778111, 80.44362381526402, 79.32419954027448, 82.10767568860734, 76.40465681893485, 75.78594752720424, 69.76750128609794, 70.5628685270037, 71.79570129939488, 74.46677643912179, 73.03901890345982, 77.29119832175118, 74.35395853860038, 72.7599584034511, 68.65367725917271, 71.49346855708531, 70.95355183737618, 73.7034056527274, 69.3133739743914, 73.98274408067975, 69.93732220785958, 73.77975940704346, 67.37195696149553, 72.23682158333915, 71.56430544172014, 69.40877274104527, 69.61555807931083, 71.09148747580392, 69.8427711214338, 61.48071139199393, 67.40991497039795, 73.44106251852853, 62.42866802215576, 69.69330147334507, 68.71898337772915, 62.3507787159511, 59.00485283987862, 65.16192953927177, 71.40200941903251, 68.43075820377895, 64.42765780857631, 64.14580413273403, 50.00010558537075, 52.7316335269383, 52.511167185647146, 53.66802140644619, 52.388607910701204, 51.93435900551932, 48.32866082872663, 56.86875425066267, 66.19801017216274, 65.41816520690918, 67.33322075435093, 63.2809271131243, 66.0077407019479, 61.95819854736328, 48.811831610543386, 45.92559855324881, 50.732278960091726, 51.48704440253121, 52.933562074388774, 52.181013107299805, 47.32145690917969, 48.951858656747, 59.28606728145054, 62.19365215301514, 62.10416630336216, 65.22901439666748, 60.15555790492466, 64.7640687397548, 59.23050948551723, 58.463435309273855, 57.1823855127607, 64.0184575489589, 63.878270694187705, 62.79178088051932, 65.46145943232945, 62.7944906779698, 54.495815890175955, 61.18716389792306, 62.02710383278983, 63.8503806250436, 58.70470455714634, 61.19029753548758, 62.12039729527065, 62.21382277352469, 62.75911739894322, 63.055576188223704, 60.321105684552876, 61.63444723401751, 60.739623478480745, 60.41924898965018, 61.79388754708426, 61.17502539498465, 57.76501628330776, 56.8273777280535, 58.19393900462559, 63.78729098183768, 63.836338315691265, 63.63822432926723, 65.52803012302944, 66.00990853990827, 65.36214882986886, 66.28444576263428, 61.55065195901053, 67.48155784606934, 65.60283442905971, 67.16597761426652, 66.43804958888462, 64.30809320722307, 52.974535601479666, 19.005741119384766, 2.4415631123951504, 0.19994289614260197, 0.48014011872666224, 0.39274505259735243, 1.529656124966485, 0.4269042696271624, 0.31368980609944885, 0.23785238979118212, 0.17720498410718782, 1.961867949792317, 2.6200883899416243, 5.03686032976423, 57.638774463108604, 47.10960633414132, 44.212270055498394, 41.43131957735334, 0.27836253174713677, 0.19163648757551396, 0.1450999097100326, 0.19729792592780931, 0.1919454788523061, 0.08639701575573001, 0.1355286440146821, 0.16761211385684355, 0.13455641189856188, 0.11016258264758758, 0.1255685913243464, 0.12499693914183549], [0.05560497447316136, 0.022676260343619754, 0.0328837306504803, 0.041436454214687855, 0.053834551080529175, 0.0772500651489411, 0.03870820739705648, 0.06846305022814445, 0.008882563677616417, 0.12162289662020546, 0.1418652789933341, 5.1772278376988, 50.07855422156197, 26.807838576180593, 40.62895550046648, 34.525327818734304, 33.58513580049787, 5.5920604807989935, 0.12824727115886553, 0.14054707544190542, 0.02857782206098948, 0.030917963811329434, 0.051335968010659726, 0.07932105580610888, 0.39466405819569317, 0.2627376344587122, 0.10881459140884024, 1.545755318232945, 24.966793503080094, 41.94149800709316, 52.35028164727347, 67.03382982526506, 67.90229211534772, 71.85051563807896, 75.76986244746617, 74.44381959097726, 74.35246467590332, 75.2706413269043, 72.81827463422502, 70.40692315782819, 71.27775478363037, 64.66302108764648, 63.292252676827566, 60.3804155077253, 63.923927307128906, 66.31087671007428, 66.31444113595145, 66.97603470938546, 68.1316590990339, 67.61221872057233, 64.88901819501604, 61.26708902631487, 61.16747270311628, 65.0396203994751, 65.64898436410087, 62.782637051173616, 61.88178225925991, 63.36928040640694, 64.09735434395927, 63.32764680044991, 62.716177531651084, 64.81877190726144, 61.413702964782715, 60.65318788800921, 56.527552536555696, 61.10794053758894, 65.89932101113456, 61.48818070547921, 64.26998233795166, 62.79526192801339, 55.134779180799214, 55.673705782209126, 60.03955772944859, 64.69827624729702, 60.94155202593122, 63.071320806230815, 54.75317716598511, 42.97865561076573, 51.15323557172503, 56.028484276362825, 48.462323325020925, 45.559699467250276, 42.79653637749808, 42.35736506325858, 43.52326931272234, 43.38133846010481, 51.27574620928083, 53.74629633767264, 58.067561694553916, 56.80478566033499, 56.23613813945225, 50.9804026058742, 43.326722145080566, 46.30317408697945, 44.372860295431956, 44.79829849515642, 47.729281425476074, 52.011216504233225, 53.752389907836914, 49.70443541663033, 43.76995815549578, 53.05121939522879, 59.70692661830357, 56.78650842394148, 58.44012410300118, 57.416122913360596, 59.76261643001011, 54.8554025377546, 51.4646885735648, 52.28195653642927, 57.20035702841622, 56.962520190647666, 58.91591589791434, 57.87605544498989, 53.6885290145874, 53.5603278023856, 56.60685927527291, 55.67861121041434, 57.39263800212315, 53.24917704718453, 56.334145954677034, 56.30311182567051, 53.73281683240618, 56.736735003335134, 53.732580593654085, 52.95881182806832, 53.914154393332346, 54.50897230420794, 54.002528531210764, 50.23548970903669, 46.23683616093227, 49.74163259778704, 52.247427463531494, 53.6112094606672, 55.03109121322632, 57.127439158303396, 59.39845439365932, 60.691465514046804, 60.04410879952567, 57.229671478271484, 54.82460464750017, 55.667546204158235, 65.52483395167759, 62.904737745012554, 60.313323702131, 55.63668925421578, 30.307069505964005, 12.22695003237043, 2.3749500811100006, 0.06936447721506868, 0.1254506212260042, 0.10924158671072551, 0.11424263407077108, 0.026473533994119083, 0.19631433513547691, 0.09988269569086176, 0.08482964736010347, 0.6166412255593708, 0.46796112081834246, 0.28512304755193846, 27.267884016036987, 39.04269913264683, 26.12802335194179, 43.671227727617534, 0.4239816835948399, 0.07427773571440152, 0.028072986918102418, 0.036267452474151335, 0.028751489706337452, 0.038357672813747606, 0.10848347310509, 0.08638856120939765, 0.07513613679579326, 0.07724054530262947, 0.12297643827540533, 0.055157314387283156, 0.01887250498735479, 0.04473488079383969, 0.02453970579829599, 0.014693358613710319, 0.029062635331813778, 0.06907394887613398, 0.06334362564874546, 0.07692212917442832, 0.03815522510558367, 0.11295153120798723, 0.19395365752279758, 8.317949090685163, 61.36801161084856, 31.407761437552317, 32.77890852519444, 37.29500137056623, 42.818968636649, 6.726028203964233, 0.2322640839431967, 0.17159678361245564, 0.05334531715405839, 0.09647602920553514, 0.04306350315787962, 0.03961824838604246, 0.25485142905797276, 0.5238223576119968, 0.10162279874618564, 1.51747256730284, 27.54003279549735, 52.37951619284493, 66.58486502511161, 74.90324143001011, 76.17210061209542, 81.00862353188651, 80.40123980385917, 76.30363001142229, 72.81423773084367, 77.75388581412179, 75.54257297515869, 72.62812328338623, 71.83843272072929, 67.42370019640241, 64.18737520490373, 62.74841717311314, 66.24060957772392, 69.98433371952602, 69.01558807918003, 68.97202287401471, 70.98736871991838, 67.60877936226981, 67.76496097019741, 65.92220837729317, 64.45542975834438, 66.52703516823905, 68.38287816728864, 65.81326062338692, 65.90007836478097, 66.08747128077916, 69.52057620457241, 67.52269118172782, 65.73194585527692, 66.14530113765171, 64.87407956804547, 63.2480343409947, 60.459284509931294, 64.95096833365304, 67.35519790649414, 64.4708617074149, 68.1222790309361, 64.1037814276559, 58.26326813016619, 57.912411894117085, 63.494077001299175, 66.05140318189348, 65.36044652121407, 66.7652541569301, 54.46827323096139, 47.73228652136666, 55.891479696546284, 57.83061075210571, 50.26472772870745, 47.60670478003365, 46.37545619692121, 43.66257722037179, 45.685222148895264, 44.84348610469273, 52.13081932067871, 53.692044803074424, 57.85344253267561, 56.800321442740305, 54.40847355978829, 51.115760462624685, 45.724396092551096, 47.12191159384591, 46.57850340434483, 47.28429446901594, 50.27784940174648, 52.6530042375837, 55.42899022783552, 54.60272087369646, 48.19591202054705, 50.585668495723176, 62.63127054486956, 56.36714989798409, 61.026695251464844, 59.322864941188264, 60.3661994934082, 58.26754127229963, 55.466784954071045, 53.59098672866821, 58.44835077013288, 60.59574018205915, 59.385516847882954, 61.6293819972447, 57.956189019339426, 55.98534985951015, 59.23909745897566, 57.63018648965018, 61.01408427102225, 57.13986948558262, 58.79524653298514, 58.76857239859444, 57.72613416399275, 59.84641865321568, 54.5448944909232, 55.657547746385845, 57.78798702784947, 57.34272909164429, 56.61010408401489, 54.1795060975211, 51.657473291669575, 52.11582510811942, 54.508857658931184, 55.39521156038557, 58.42507430485317, 59.816805430821006, 62.767330169677734, 63.97354439326695, 64.0355223246983, 59.75817653111049, 58.28995268685477, 61.60119315556118, 64.59056527273995, 64.96778992244175, 60.85510948726109, 64.65669127873012, 45.44392858232771, 17.364109345844813, 3.257925420999527, 0.09362259267696313, 0.10121166759303638, 0.11056593778942313, 0.5407827475241253, 0.04804363128330026, 0.08998677813048873, 0.13500777339296682, 0.053320323316646476, 0.7079260615365845, 0.4287409282156399, 0.15743794265602315, 32.757028647831504, 41.481433459690635, 28.54525474139622, 52.00985813140869, 0.7164239798273359, 0.01843030201936407, 0.05153910103919251, 0.04456461260893515, 0.03445733478292823, 0.0066198979038745165, 0.0017834306968974748, 0.052055802063218186, 0.056136430241167545, 0.14869055418031557, 0.07404345114316259, 0.017597322252445986, 0.20292257411139353, 0.15611095886145318, 0.09756478614040784, 0.06972813127296311, 0.08399657599095788, 0.1668504040156092, 0.14237209036946297, 0.19386692717671394, 0.08831927832216024, 0.17639946804514953, 0.2824293449521065, 9.404490147318159, 76.39446381160191, 35.135376180921284, 59.049960545131135, 51.128340176173616, 48.61618423461914, 11.74777967589242, 0.6307066593851361, 0.5085010911737169, 0.15076459145971707, 0.3068363852798939, 0.2867044141249997, 0.5620917326637677, 1.2891396709850855, 0.9547983258962631, 0.2095502463302442, 2.144869387149811, 31.174652848924907, 64.64927755083356, 78.81878757476807, 82.19085257393974, 83.91061510358537, 85.19266196659633, 84.05682604653495, 79.61770534515381, 73.38039084843227, 80.22794478280204, 77.4549812589373, 75.57466670445034, 74.98653643471854, 70.43091528756278, 68.14008031572614, 66.58674798692975, 68.80489090510777, 73.79776218959263, 72.85050732748849, 72.40911606379917, 73.81063720158168, 73.39678164890834, 70.53393622807094, 69.48348672049386, 68.03039605276925, 71.91280623844692, 70.54722118377686, 70.81797163827079, 68.82838971274239, 69.28551864624023, 72.2153377532959, 70.32409368242536, 70.44631944383893, 69.95693002428327, 70.5286625453404, 66.93353257860456, 63.793342862810405, 67.66379519871303, 70.42915739331926, 65.20610618591309, 71.42511217934745, 68.97248145512172, 63.03193146841866, 62.603220667157856, 63.91249057224819, 69.3821541922433, 68.17428629738944, 67.07821491786412, 60.7462729045323, 48.98768704278128, 56.27773700441633, 61.94489969526018, 54.25556802749634, 49.15674366269793, 47.680060386657715, 44.62637921742031, 47.554864270346506, 46.919218744550435, 56.473836013248985, 58.0833306312561, 61.6778804234096, 60.87566920689174, 59.289895738874165, 55.44518300465175, 46.492800848824636, 51.14878177642822, 47.980062757219585, 51.59486654826573, 53.99630989347185, 56.84878512791225, 56.50824696677071, 53.73822600500924, 49.18383468900408, 57.324677671704976, 64.03420911516461, 60.416365487234934, 64.37795734405518, 61.549609729221885, 63.04102666037423, 59.55728326525007, 56.67830065318516, 56.199722630637034, 62.58153533935547, 62.20133686065674, 62.39879076821463, 63.12071555001395, 59.913698060171946, 59.91354519980294, 62.0783120564052, 60.31149632590157, 64.56644112723214, 59.752784729003906, 61.659870692661826, 62.11240686689104, 60.79376384190151, 64.10736669812883, 59.42141124180385, 60.720279693603516, 59.51965182168143, 59.50187138148716, 60.18708883013044, 58.3077609198434, 57.978214808872764, 58.70560087476458, 58.66120188576834, 60.08265045710972, 59.561021396092, 63.617859159197124, 64.26770332881382, 69.54335239955357, 66.19283376421247, 65.18206541878837, 63.06383064814976, 66.419935635158, 68.84858812604631, 69.54843153272355, 65.90344129289899, 68.62213243756975, 56.483605180467876, 26.44604066440037, 4.118823945522308, 0.19550093449652195, 0.4624620016132082, 0.35110072578702656, 1.2622187669788087, 0.2537028321198055, 0.3155691852527005, 0.25277432480028694, 0.21799150694693836, 1.5612301507166453, 1.4120945589882987, 0.5368547897253717, 42.05904763085501, 52.820327281951904, 39.12157508305141, 59.952045168195454, 0.7447700245039803, 0.16609618520098074, 0.08194510000092642, 0.10329018320356097, 0.1883358082601002, 0.14847442720617565, 0.15621360763907433, 0.15934567100235394, 0.12288881226309709, 0.15975763675357613, 0.1766053762819086, 0.10572724350328956], [0.028706163567091738, 0.02465463605975466, 0.039914069298122606, 0.08069175761193037, 0.033991696911730936, 0.03892770329756396, 0.0090068619631763, 0.06946800808821406, 0.024936087296477387, 0.1020405591864671, 0.1404115312865802, 22.522957461220876, 46.97108357293265, 31.176702567509242, 38.33914886202131, 33.28212138584682, 36.569446155003135, 3.360479529414858, 0.3127932170672076, 0.19483804649540357, 0.04731371420036469, 0.05654482011284147, 0.07942503451236657, 0.021162124716543725, 0.13794397083776339, 0.337809826114348, 0.12365846096404962, 4.942061713763645, 37.25984695979527, 53.94727645601545, 57.50502164023263, 62.55348546164376, 65.76783330099923, 73.31243746621269, 78.18987832750592, 72.51499966212681, 71.46992111206055, 74.59328923906598, 73.95938423701695, 68.58631447383335, 68.69121837615967, 63.89015211377825, 58.28254590715681, 60.38324342455183, 61.68218830653599, 64.76732049669538, 65.33081245422363, 69.06178665161133, 67.28240162985665, 63.98123604910714, 61.69655023302351, 63.5478630065918, 63.05294976915632, 63.43553842817034, 63.60048171452114, 62.48186343056815, 62.31928947993687, 64.00090639931815, 63.970633098057334, 62.05928788866316, 63.19754178183419, 62.75094631740025, 57.66664368765694, 58.07183831078665, 62.87424210139683, 64.91829095567975, 62.576935631888254, 62.35584395272391, 59.51405157361712, 55.44396012169974, 55.45343746457781, 59.935279164995464, 62.330948557172505, 61.37777382986886, 64.53664725167411, 52.34659562792097, 44.545074871608186, 54.938047885894775, 56.129629203251426, 51.13733809334891, 46.61847986493792, 47.39505917685372, 44.02173655373709, 43.99171686172485, 45.556551933288574, 45.23668466295515, 41.08592809949602, 45.14305421284267, 48.99240834372384, 47.56657893317086, 43.087506089891704, 42.7245044027056, 44.09806598935808, 44.5011796270098, 43.48724985122681, 45.28417560032436, 46.49155364717756, 45.7899523462568, 49.02415118898664, 53.91752774374825, 56.9354430607387, 44.28269004821777, 49.08256469454084, 57.6493878364563, 54.2011010987418, 57.9083228792463, 55.752133573804585, 57.50816570009504, 56.822899614061626, 53.22305529458182, 50.63181843076433, 55.936955656324116, 57.86326033728463, 57.6018899508885, 56.43459258760725, 51.231903076171875, 55.50241879054478, 57.09643977028983, 57.315252440316335, 54.973164081573486, 53.79778943743025, 55.7509697505406, 57.10540294647217, 54.38446058545794, 53.91870893750872, 51.954060622623985, 54.71353074482509, 53.86651406969343, 51.88168123790196, 47.353585379464285, 45.233234882354736, 47.581823280879426, 50.23573637008667, 54.73191220419747, 54.467432498931885, 54.73638684409005, 59.75027642931257, 60.454594475882395, 60.75079618181501, 57.26325907026018, 56.134277548108784, 59.763304301670615, 61.129257610866, 65.02405643463135, 61.061484881809776, 59.10566425323486, 33.41562407357352, 14.579709087099348, 4.476498101438795, 0.16861505646790775, 0.11546160866107259, 0.08230242332709686, 0.1355229036084243, 0.040551440989864726, 0.14993318250136717, 0.13183948983039173, 0.15005820936390332, 0.1879734977015427, 0.23841744661331177, 0.14495194836386613, 12.32394254207611, 46.37220096588135, 23.121784482683452, 42.98778554371425, 4.648692267281668, 0.2203812122877155, 0.16721819713711739, 0.048904583656362126, 0.14049386472574302, 0.03228414996660181, 0.16266179377479212, 0.014768886346636074, 0.07551588570433003, 0.04729688653190221, 0.10538189632019826, 0.01751406261298273, 0.010987945034035614, 0.010805546339335186, 0.03705493986074414, 0.08298683445900679, 0.03275306176926408, 0.10311479547194072, 0.019552407254065787, 0.06671055033802986, 0.03584638756832906, 0.11634911889476435, 0.049924347150538645, 34.311736719948904, 55.999645778111045, 43.11428097316197, 41.89382641656058, 37.34100191933768, 38.040692465645925, 6.293840263571058, 1.6559039162737983, 0.15201536220099243, 0.09763008156525237, 0.05394283848415528, 0.06813299722437348, 0.18993865725185188, 0.35422660091093605, 0.9425181448459625, 0.1321588084101677, 5.137149325438908, 38.15841579437256, 62.067528452192036, 71.46352876935686, 73.03129250662667, 72.6288389478411, 78.45988532475063, 79.13299206324986, 75.47220161982945, 71.55102048601422, 75.99535233633858, 74.51812362670898, 71.95597539629254, 71.38540322440011, 65.89024666377476, 60.95445483071463, 61.80740874154227, 63.265015738351, 66.75361592429024, 68.72015762329102, 69.8899702344622, 72.74902193886894, 67.18803814479283, 65.71920980725969, 67.0454889025007, 65.4757171358381, 66.25169195447648, 65.96097932543073, 65.09376771109444, 66.11466653006417, 68.64251845223563, 67.90710026877267, 65.67066274370465, 64.95050975254604, 65.63891642434257, 63.455368586948936, 62.02738176073347, 67.3161837714059, 66.15392385210309, 66.29799474988664, 66.46485573904855, 60.249337741306846, 57.49471051352364, 59.59727709633963, 63.183965001787456, 63.59292207445417, 63.858933857509065, 66.7094531740461, 51.275166034698486, 48.833020142146516, 57.545932633536204, 55.266544818878174, 53.3272956439427, 49.26419060570853, 48.424222878047395, 45.89934825897217, 46.51295757293701, 46.86924730028425, 45.47809287479946, 44.10230091639927, 47.74123927525112, 50.37358168193272, 48.72815098081316, 46.159551348005024, 45.83092587334769, 44.94994987760271, 45.77616364615304, 44.73391648701259, 46.29481887817383, 49.259104524339946, 47.70727300643921, 50.41943979263306, 55.4539064679827, 57.64501394544329, 48.315730231148855, 48.64314324515206, 59.89116505214146, 56.7080146244594, 59.50806222643171, 57.595695631844656, 57.78761529922485, 59.8839111328125, 54.853880882263184, 53.55823639460972, 56.10629367828369, 60.46180670601981, 57.97482756205967, 58.94389629364014, 55.19842120579311, 56.3118074962071, 58.845495905194966, 59.55929824284145, 57.85517610822405, 55.40841313770839, 57.465660095214844, 58.97867202758789, 57.5600756917681, 57.04968881607056, 54.72737850461687, 56.21633229936872, 54.232566016060964, 53.96495614733015, 51.14072534016201, 50.417233739580425, 49.425684111458914, 54.19056762967791, 57.0420492717198, 58.73804896218436, 57.95250299998692, 63.01010717664446, 65.27631078447614, 62.13507189069475, 61.80502550942557, 59.1266964503697, 64.54613154275077, 62.62345382145473, 65.66247081756592, 63.475400243486675, 65.16199902125767, 47.90975046157837, 20.115180832999094, 5.495142229965754, 0.21134358724313124, 0.037714659103325436, 0.11839441343077592, 0.15084237871425493, 0.16331831711743558, 0.08693199312048298, 0.12974122885082448, 0.15172283218375274, 0.3016010804900101, 0.2616070865520409, 0.22774452503238404, 14.110246232577733, 49.05395548684256, 26.13900671686445, 54.12682832990374, 7.3391876220703125, 0.16316621670765535, 0.14677536194877966, 0.051661447688405, 0.048390668018588, 0.056289083656987975, 0.09962792614740984, 0.03474833131102579, 0.046956536759223254, 0.0806169898382255, 0.05395780696666666, 0.020178932563534806, 0.10419203766754695, 0.11028588603117637, 0.18952785858086177, 0.19817544812602655, 0.16645024477371148, 0.19861099975449698, 0.12552967055567674, 0.1482853466378791, 0.1076385070170675, 0.168985726577895, 0.2890012823045254, 42.763984067099436, 65.75110898699079, 44.22578082765852, 56.64349365234375, 47.24443960189819, 51.266136850629536, 10.297840884753636, 2.759170264005661, 0.3733989878424576, 0.2577277390020234, 0.10261830461344548, 0.29408068688852446, 0.3847846154655729, 0.9588022253343037, 1.5796475453036172, 0.4380393278385912, 8.102249213627406, 41.81972735268729, 74.78208569117955, 81.48722239903041, 81.55170863015312, 79.10057176862443, 79.95066302163261, 82.7540179661342, 76.53164209638322, 71.97127532958984, 79.81035804748535, 78.65298965999058, 75.21326310294015, 74.91066905430385, 69.64556040082658, 64.43513407026018, 66.93446363721574, 67.44940853118896, 69.6334844316755, 71.88854312896729, 74.61919907161167, 74.82145418439592, 68.00534779684884, 68.31356988634381, 71.3845624923706, 70.56354250226701, 69.55526856013707, 69.88507175445557, 70.0296915599278, 68.57614925929478, 72.96745940617153, 70.91375950404576, 70.71821635110038, 69.81196975708008, 69.85663972582135, 66.85447597503662, 62.858844893319265, 69.9564436503819, 70.79937825884137, 69.44196428571428, 70.64539922986711, 66.47527108873639, 62.275293486458914, 61.15144320896694, 65.65327835083008, 66.95484270368303, 65.73696245465959, 70.4258222579956, 57.94771221705845, 50.97616420473371, 58.76079041617257, 61.519176619393484, 56.01075594765799, 52.13948025022234, 52.09586640766689, 50.156506061553955, 49.56443268912179, 51.225222383226665, 49.82206147057669, 46.27101782390049, 50.64421054295131, 53.58644608088902, 53.90521206174578, 48.77944605691092, 46.78628233500889, 47.34171438217163, 48.67475060054234, 47.343194348471506, 49.386934007917134, 53.66265739713396, 51.46632834843227, 53.23745196206229, 58.04775932856968, 60.79820374080113, 48.15289224897112, 54.23090539659773, 61.224559102739605, 57.79359075001308, 61.53485175541469, 59.55999306270054, 60.20028345925467, 62.265253339494976, 58.52017429896763, 55.94055829729353, 60.127389907836914, 62.35217530386788, 62.44680976867676, 60.735260009765625, 56.56783471788679, 61.581432478768484, 61.12852805001395, 66.09148039136613, 59.413823808942524, 60.351545742579866, 60.73721245356968, 61.17218358176095, 59.017283167157856, 58.93396036965506, 56.859033720833914, 59.25958769662039, 57.58151088442121, 57.75949593952724, 56.064038208552766, 56.40524339675903, 57.38769783292498, 58.36827972957066, 61.06693226950509, 58.77584021432059, 62.457655906677246, 66.29240839821952, 69.64398315974644, 64.15558024815151, 66.91015189034599, 61.50303595406668, 69.34791346958706, 64.37203053065709, 69.3693903514317, 66.49562236240932, 69.97024277278355, 58.80146517072405, 30.248958247048513, 6.442212096282414, 0.29694804017032894, 0.2995400168001652, 0.16494385632021086, 0.33509256477866856, 0.3718160470681531, 0.2910804764500686, 0.23599732933299883, 0.22651158619139874, 0.44184479649577824, 0.7727094367146492, 0.26871536512460026, 20.092029435294016, 64.61275087084088, 34.16500813620431, 61.854545320783345, 8.910163164138794, 0.527240979884352, 0.33780152084571974, 0.1585635779691594, 0.17822001821228436, 0.1718475701553481, 0.2618295374725546, 0.10537755369607892, 0.20550296136311122, 0.1285093349537679, 0.13527128925280912, 0.09075171779841185], [0.09467112605593034, 0.09628690792513744, 0.0014898566899189192, 0.043832927942276, 0.05961406470409461, 0.10712877794035844, 0.2758491566138608, 0.3881677910685539, 0.07416157730455909, 0.16279227605887822, 12.252108590943472, 48.50409589494978, 25.89144934926714, 19.702885150909424, 24.45141782079424, 55.40269477026803, 12.41558928149087, 1.346121521932738, 0.6465751507452556, 0.35755799072129385, 0.1133945874337639, 0.1427198802786214, 0.15170148547206605, 0.07090646840099778, 0.8876749819942883, 0.40830122785908834, 0.47661629638501574, 13.65468498638698, 51.26973601749965, 67.02239309038434, 57.113914489746094, 67.03560856410435, 70.98741040910993, 77.96840449741909, 77.38444314684186, 73.70222445896694, 70.90096092224121, 71.3657398223877, 71.60258306775773, 72.50721073150635, 66.56269332340786, 67.90788541521344, 62.34657505580357, 58.486760411943706, 58.096289021628245, 61.85662283216204, 65.10874107905796, 65.06978947775704, 67.80956145695278, 67.0756162915911, 62.869100434439524, 63.838130950927734, 60.133504322596956, 64.86410195486886, 61.77517604827881, 62.38025297437395, 63.63804367610386, 62.04225090571812, 61.717554637363975, 63.62017985752651, 61.778337478637695, 61.579931667872835, 59.82443455287388, 63.046126638139995, 62.509517260960166, 63.62252834865025, 62.12999275752476, 59.455096108572825, 51.67468050548008, 58.5608560017177, 61.69834981645857, 62.574371746608186, 59.84215940747942, 64.67109489440918, 50.56929506574358, 47.354839529309956, 58.65048081534249, 54.44214105606079, 49.90247644696917, 52.8873530796596, 47.7775297164917, 43.77614205224173, 43.43057686941964, 42.40874351773943, 42.07690797533308, 45.645912715366904, 49.57307972226824, 53.3361302784511, 56.41644041878836, 53.98624195371355, 49.208459104810444, 45.821868896484375, 42.43204777581351, 41.86052022661482, 42.1772712298802, 44.9755539894104, 44.06957490103585, 46.22536815915789, 49.876927920750205, 51.19488654817854, 51.5390898840768, 56.553201811654226, 43.96734258106777, 47.199199880872456, 58.37211513519287, 57.0189117704119, 56.09344645908901, 53.93518659046718, 56.929102829524446, 55.44101755959647, 53.08451863697597, 50.069160257067, 53.78425782067435, 56.822392395564485, 58.267468316214426, 57.36375781467983, 49.448109422411235, 53.72185604912894, 54.240309783390586, 55.24720450810024, 52.80868904931204, 50.3660637310573, 54.68356663840157, 54.95534890038626, 53.79123381205967, 53.431591578892295, 51.30106544494629, 51.703494685036794, 49.80905096871512, 46.38949850627354, 45.461820193699424, 49.60817507335118, 52.37844269616263, 53.68696914400373, 55.254753725869314, 56.17919765199934, 57.6380101612636, 60.673893519810264, 57.565543924059185, 58.313618251255576, 56.424024377550396, 59.28845746176583, 59.342708996364046, 63.06177398136684, 59.61208370753697, 60.92303507668631, 37.16516733169556, 20.0128755569458, 5.801470066819872, 0.11538200293268476, 0.11023381525384528, 0.11484969221055508, 0.10585068937923227, 0.13142483708049568, 0.13838155807128974, 0.164141339382955, 0.12754445815724985, 0.12843412613230093, 0.07972112005310399, 0.3360320915068899, 7.075034916400909, 44.270968437194824, 32.231578077588765, 24.686543124062673, 22.374264274324688, 0.7563784016030175, 0.16359283881528036, 0.011602635844610631, 0.10656498319336347, 0.04240353625001652, 0.11065444589725562, 0.02189987039725695, 0.05318763240107468, 0.0039177763807986465, 0.2781980005758149, 0.11072143765964679, 0.02666320658421942, 0.020261003070377877, 0.04996894386463931, 0.08895129297993012, 0.07009239601237433, 0.10866180567869119, 0.1401130844439779, 0.13969877096159117, 0.06175425236246415, 0.1454692091792822, 18.606858934674943, 62.26501710074288, 37.66046966825213, 30.291675771985734, 20.115932975496563, 52.95567124230521, 16.224333797182354, 3.322736914668764, 2.2482663989067078, 1.17767818910735, 0.08648589027247258, 0.2174056190997362, 0.12902294525078364, 0.12395954052252428, 1.8569451570510864, 0.7851982808538845, 0.9399010624204363, 15.025370018822805, 57.11823974336897, 75.65131228310722, 70.43708528791154, 73.1215079171317, 77.34853485652378, 78.82579830714634, 78.04438304901123, 74.44866248539516, 71.4885561806815, 72.42637538909912, 73.30817127227783, 73.73417922428676, 70.63301059177944, 70.19875512804303, 64.39044325692313, 60.453309059143066, 60.287087304251536, 63.92366327558245, 66.62232276371547, 67.8247571672712, 68.46182359967912, 70.49527645111084, 66.17601912362235, 68.27545206887382, 64.50530392783028, 67.79242719922746, 64.79876109531948, 63.715377126421245, 66.06343746185303, 65.6565717969622, 64.76765401022774, 66.9249654497419, 65.7268180847168, 64.77184377397809, 62.01562540871756, 64.63922350747245, 64.39828777313232, 66.19674560001918, 64.12195791516984, 60.448514802115305, 55.36059216090611, 62.24223395756313, 64.3377411706107, 63.83595616476876, 64.44429179600307, 64.527816091265, 51.2608596937997, 51.80151639665876, 63.47318376813616, 55.71311943871634, 53.74219342640468, 54.55668905803135, 49.186523641858784, 45.56589726039341, 44.168760435921804, 43.850261960710796, 44.56622518811907, 48.747585092272075, 51.82759646006993, 57.61790554864066, 61.88057327270508, 58.40899617331368, 53.62718684332711, 48.61939082826887, 43.82111079352242, 42.3041661807469, 44.643972056252615, 46.4088978767395, 45.5224814414978, 47.13608939307076, 51.16849728993007, 51.0342824118478, 52.09122501100813, 58.175119808741975, 47.322252477918354, 46.91124221256801, 58.231598240988596, 58.084841864449636, 58.62001991271973, 55.47798545019967, 58.81820338112967, 58.64674963269915, 57.54794066292899, 53.8960473878043, 57.51553773880005, 59.58524281638009, 59.97272300720215, 60.00048106057303, 53.87500824247088, 56.0734669140407, 58.90809222630092, 57.26698677880423, 56.49723754610334, 55.203962394169395, 55.98972027642386, 59.02694116319929, 56.232736996241975, 54.71549708502633, 54.91877358300345, 52.49728468486241, 53.03282751355852, 51.50435931341988, 50.034249033246724, 53.36870343344552, 54.78304399762835, 55.55841779708862, 56.03124965940203, 59.26145676204136, 60.245307786124094, 63.85210377829415, 61.469802720206125, 61.00159140995571, 59.90602030072893, 63.74239867074149, 61.70391532352993, 65.62823704310826, 59.54718753269741, 65.29211098807198, 49.04103531156267, 25.354138204029628, 6.919840821198054, 0.040784361705716164, 0.19734253281993525, 0.042891267221421, 0.09926807867097003, 0.3094008948121752, 0.022535482986963222, 0.11249062272586993, 0.08155530877411366, 0.3122081027499267, 0.11744685284793377, 0.35327931174210137, 8.698514086859566, 51.422975063323975, 35.95175477436611, 34.101904596601216, 32.83034603936331, 0.9392630223717008, 0.1975409636007888, 0.0254338690678456, 0.10101766086050443, 0.04384254278349025, 0.10798050902251687, 0.017756934044882655, 0.02472527325153351, 0.017571899241634777, 0.03572887208844934, 0.020851929040093507, 0.17149428411253861, 0.22211218226168836, 0.12929163154746803, 0.20742145127483777, 0.16580924631229468, 0.2342283342565809, 1.160903934921537, 0.9603840261697769, 0.2771564764635903, 0.2700944739793028, 20.624652283532278, 77.53385026114327, 39.60054915291922, 28.682000500815256, 35.98443215233939, 71.36515617370605, 21.586369821003505, 8.18339114529746, 4.664762582097735, 1.1811620593070984, 0.19831476493605546, 0.40418716147542, 0.31195454778415815, 0.501820615359715, 2.4777662668909346, 1.3043410267148698, 1.2067520575863975, 20.217041424342565, 66.68944931030273, 85.45150320870536, 80.77254458836147, 81.69910076686314, 78.39385659354073, 81.16128935132707, 80.36055810110909, 76.71339307512555, 72.72917788369315, 73.18640409197126, 76.69739832196916, 76.61129624502999, 73.72656399863106, 74.37090519496373, 67.10938453674316, 63.84689957754952, 64.58663954053605, 67.65374115535191, 71.70984240940639, 70.84127589634487, 72.39394119807652, 73.94495977674211, 69.23638793400356, 71.24692562648228, 68.3305721282959, 72.02082293374198, 67.51068469456264, 66.73042283739362, 69.92266150883266, 67.08624703543526, 66.83273506164551, 72.36893463134766, 71.34609031677246, 68.58602959769112, 65.15722560882568, 67.25345543452671, 65.68888786860875, 67.74700682503837, 66.83623695373535, 66.20873819078717, 55.98733704430716, 63.73938315255301, 66.6726416179112, 67.20687471117292, 66.17691544124058, 68.87260804857526, 56.50437682015555, 51.9695794241769, 65.32386425563267, 58.91674273354666, 55.77011898585728, 56.98288883481707, 51.6928048815046, 49.611756869724815, 47.74214254106794, 46.03776332310268, 46.59707941327776, 50.35547467640468, 53.8232615334647, 58.46912588391985, 62.351612499782014, 58.84106295449393, 54.503611768995015, 50.53721175874983, 45.81329481942313, 46.251288414001465, 46.9343067577907, 48.921154567173545, 48.981051513126914, 49.76171636581421, 53.999919482639854, 54.64631734575544, 54.540399006434846, 60.51790646144322, 49.37178693498884, 50.778317723955425, 61.616465296064106, 60.57260268075125, 60.41264125279018, 58.55212211608887, 61.566737038748606, 59.25486292157854, 57.30884272711617, 55.33535630362374, 60.142147881644114, 63.30172307150704, 64.07163211277553, 63.27759892599923, 55.54347917011806, 61.96208953857422, 59.56746237618582, 62.109940256391255, 57.84212391717093, 55.9917699950082, 60.5025509425572, 60.59879738943917, 59.91619941166469, 56.814016342163086, 57.079340253557476, 57.0146837915693, 59.14141968318394, 57.12719249725342, 55.209580012730186, 60.7112192426409, 58.269361700330464, 59.06469072614397, 60.19937324523926, 62.95441041673933, 63.93308503287179, 68.46353285653251, 65.11448723929269, 65.89492974962506, 62.494363239833284, 66.07178224836076, 66.75160789489746, 70.87457861219133, 65.37230014801025, 66.41198689596993, 59.89544514247349, 35.66434948784964, 7.554081508091517, 0.35214930666344507, 0.4906194135546684, 0.15220357424446515, 0.4701633740748678, 0.828961943941457, 0.23604971223643847, 0.3056912895824228, 0.29826461523771286, 0.47895365953445435, 0.25235056611044065, 0.3983192449169499, 12.146554163524083, 64.69520514351981, 43.14910881859915, 41.39306627001081, 41.22962032045637, 1.1403361814362662, 0.25583155932171003, 0.09820516034960747, 0.23072079675538198, 0.13814826416117804, 0.27245775716645376, 0.08373850198196513, 0.18474075331219605, 0.0834705349324005, 0.1666440615164382, 0.18912723793515138], [4.004453122615814, 0.5348445347377232, 0.013764785985196275, 0.07376572676002979, 0.09182212714638029, 0.508113620536668, 3.0401819050312042, 3.8235602463994707, 0.1281417046806642, 6.221562930515834, 54.12779760360718, 47.68442732947213, 22.03642896243504, 24.84895726612636, 52.05601848874773, 42.95345449447632, 0.4874519035220146, 0.5018602960876056, 0.43759879576308386, 1.2645325171095985, 0.09490353787051779, 0.06480719854256936, 0.08652363039020981, 0.14482842784907135, 1.8259303527218955, 4.612701032842908, 4.606041618755885, 39.205561433519634, 75.31304618290493, 59.72699301583426, 64.17830085754395, 74.02942207881382, 74.06845705849784, 76.49157183510917, 75.77883257184709, 74.79909488133022, 73.61045265197754, 75.1986163003104, 72.08222416469029, 68.8364565713065, 71.19188894544328, 67.51335280282157, 64.04695211138043, 58.87111391339983, 55.63174908501761, 55.858798844473704, 60.26210158211844, 65.65813514164516, 65.90771443503243, 64.74111189161027, 69.07099301474435, 66.11511121477399, 61.85917282104492, 60.26577023097447, 61.74593802860805, 64.19645650046212, 58.71383449009487, 62.42607634408133, 63.021953855242046, 59.880159105573384, 57.888906138283865, 58.55328246525356, 63.03731632232666, 63.14354733058384, 64.73953465053013, 60.94090584346226, 55.059651783534456, 54.24499634334019, 58.897614342825754, 61.02681337084089, 62.7362300327846, 60.868741852896555, 62.88949339730399, 48.94580677577427, 47.61416367122105, 60.765943254743306, 55.03716046469552, 52.75064032418387, 53.5711669921875, 46.933796065194265, 43.860861437661306, 42.940975529806956, 43.735894611903596, 42.495912143162315, 45.02095004490444, 49.074129581451416, 56.028254985809326, 58.88852609906878, 61.713990211486816, 59.4162209374564, 55.61407634190151, 49.17717136655535, 42.90522704805647, 43.14304998942784, 41.91748850686209, 41.937846728733604, 40.74056788853237, 43.37931653431484, 46.99615962164742, 52.46254021780831, 55.48343978609358, 52.94521767752511, 57.04087850025722, 44.81780556270054, 46.00648600714547, 56.771472522190635, 56.5348516191755, 58.73791694641113, 55.9659400667463, 57.580149037497385, 54.59442472457886, 58.43799100603376, 51.73935433796474, 57.168145179748535, 55.461434841156006, 55.587909426007954, 55.11876705714634, 50.29385805130005, 56.06776244299752, 51.18723310743059, 54.250558376312256, 52.345838274274556, 51.89398997170584, 55.96856648581368, 53.398354870932444, 55.4093268258231, 51.617760862622944, 50.65566117422921, 47.003264154706685, 45.405421665736604, 46.59639501571655, 48.514709268297466, 51.071014063698904, 53.70642410005842, 52.08570466722761, 54.19153342928205, 56.60962813241141, 58.99329798562186, 57.680237838200156, 58.24286821910313, 58.138822419302805, 60.008040700639995, 58.46504034314837, 62.24007306780134, 63.06598458971296, 60.201568875994, 39.20961570739746, 23.293239968163626, 7.726251789501735, 0.056036342933241806, 0.034670065689299784, 0.06796001150671925, 0.29753280164940016, 0.12439066810267312, 0.15278355883700506, 0.3395775726863316, 0.10096398195517914, 0.18115177803805896, 0.19270451526556695, 0.5424016235130174, 7.604614019393921, 29.37301274708339, 39.60091393334525, 19.686753170830862, 30.516672338758195, 22.599161829267228, 1.2252761721611023, 0.20361429985080445, 0.15470780272568974, 0.22032353681113037, 0.019418164189638834, 0.07333420562957015, 1.5718838019030434, 5.06271414245878, 5.879978631223951, 6.313245279448373, 1.8876029976776667, 0.15989263808088644, 0.06699411012232304, 0.04566144071785467, 0.06717989301042897, 0.3194976587380682, 1.5177496267216546, 1.0068856051989963, 0.6837936650429453, 9.157784802573067, 67.1008243560791, 54.81074299131121, 35.21124356133597, 23.993350880486624, 42.03867898668562, 47.80772658756801, 1.6302114320652825, 0.6222514073763574, 1.5325247538941247, 1.9298026646886552, 0.016897065631513084, 0.07519828381815127, 0.058708742926163335, 0.0884814549769674, 2.1044714748859406, 6.192258902958461, 6.604856397424426, 40.67214897700718, 79.02485724857875, 74.01967375619071, 69.3796250479562, 80.07926028115409, 76.31258623940604, 78.59464563642229, 76.76276002611432, 77.08086940220424, 76.7519416809082, 74.44789818355015, 73.64642347608293, 69.57941355024064, 72.2184088570731, 68.35106931413922, 66.55387605939592, 61.59284142085484, 59.27338681902204, 57.12684856142317, 62.38986233302525, 68.21957465580532, 68.00778661455426, 65.90039103371757, 70.17873736790249, 67.83768776484898, 67.06038584027971, 63.742878096444265, 64.14954226357597, 68.18891920362199, 61.89478928702218, 66.77515533992222, 65.71581908634731, 64.07273687635148, 62.067764690944124, 62.87121268681118, 67.5146312713623, 65.00587994711739, 66.81553132193429, 62.234785488673616, 58.30180631365095, 56.958729948316304, 61.25552722385952, 64.50764547075543, 65.37091745649064, 63.58124910082136, 65.25823851994106, 49.7307517187936, 52.6649933542524, 62.11752074105399, 57.25151661464146, 55.774864605494905, 55.02855512074062, 49.59253467832293, 46.314565658569336, 44.70706169945853, 45.73449877330235, 44.89460052762713, 47.48041084834507, 52.13413708550589, 55.18677602495466, 61.175782748631065, 61.511630875723704, 60.77948529379708, 57.537469727652415, 51.523133346012656, 45.07226249149868, 44.00710712160383, 43.047494888305664, 44.97820472717285, 41.745499747140066, 44.3337071963719, 49.473887239183696, 54.15216146196638, 55.396528244018555, 53.85725212097168, 57.990051065172466, 48.63084145954677, 44.92237942559378, 56.98015819277082, 56.61068425859724, 59.85039302280971, 58.67464665004185, 57.55271060126168, 56.4247921534947, 61.37253488813128, 55.98056255068098, 58.5197365624564, 57.98610101427351, 57.947079930986675, 58.85522338322231, 51.722626549857004, 58.25713981900896, 55.517927169799805, 55.81163099833897, 55.73539536339896, 53.81487505776541, 57.89897060394287, 55.46201848983765, 57.37025785446167, 54.579194273267476, 52.41347203935896, 50.87822239739554, 48.097226755959646, 50.91421059199742, 53.91748258045742, 54.78524310248238, 56.18695878982544, 54.9003712790353, 57.20695086887905, 60.441163608006065, 61.96196447099958, 60.9906063079834, 61.56825174604143, 60.516593251909526, 63.299833161490305, 60.945609773908345, 63.9516784123012, 65.27294090815953, 62.98160566602434, 50.30536079406738, 27.388977221080236, 8.374172176633563, 0.06010752929640668, 0.09597814735025167, 0.04449722729623318, 0.3574085501687867, 0.028178634820505977, 0.018419460726103613, 0.25027929725391523, 0.06743046920746565, 0.18384511422898087, 0.20736644922622613, 0.6464942693710327, 8.362133554049901, 35.826999868665425, 41.48848588126046, 23.725786175046647, 41.40292228971209, 32.12333903993879, 1.1627462932041712, 0.15684395310069832, 0.05899433831551245, 0.11567202237035547, 0.014312206834022487, 0.033423959876277616, 1.0375040365116937, 2.509853699377605, 3.68867095879146, 3.5358281774180274, 5.484197948660169, 0.6161663596119199, 0.16254007816314697, 0.1916737798601389, 0.6462637845958982, 1.9808295837470462, 5.0481094632829935, 6.559070374284472, 1.0082799132381166, 10.04398671218327, 79.9220781326294, 69.03093664986747, 37.379182270595, 35.90000111716134, 71.06819711412702, 56.5106406211853, 2.8352919050625394, 1.377924295408385, 3.849155238696507, 3.3001711198261807, 0.28592439740896225, 0.20043627252536161, 0.30591767600604464, 0.186049579509667, 3.032755366393498, 6.625253268650599, 10.68676369530814, 48.86701767785208, 84.7681965146746, 79.54689625331334, 74.9860292162214, 82.09817055293492, 80.29807295118059, 80.42584337506975, 80.4439503805978, 79.3278751373291, 79.19708919525146, 78.20529638017926, 76.55278546469552, 73.22043636866978, 75.66334656306675, 71.22704683031354, 70.89308166503906, 65.45546313694545, 63.24848597390311, 59.940705708095, 66.30246244158063, 71.0335464477539, 71.34395721980503, 69.6670720236642, 74.27525629316057, 72.50605038234166, 69.6096590587071, 68.9251433781215, 67.40523883274624, 71.1234769821167, 65.19441236768449, 69.13781384059361, 70.96498162405831, 66.176602772304, 64.94798755645752, 65.00263513837541, 71.0436977658953, 69.96017483302525, 70.36547020503453, 65.8399486541748, 60.27426092965262, 60.142550877162385, 64.3114561353411, 66.44872202192033, 68.78346960885185, 66.11135918753487, 68.51565129416329, 53.19818074362618, 52.80568047932216, 66.55018656594413, 61.244479588099885, 57.45207289287022, 58.818668910435264, 52.0810215813773, 48.896689959934776, 48.24126638684954, 48.274159158979145, 47.63311835697719, 50.28446061270577, 53.183308124542236, 58.802139145987375, 63.49488994053432, 65.73022270202637, 63.52455874851772, 60.25158895765032, 53.92846768242972, 46.85495832988194, 46.84334789003645, 45.74801301956177, 46.2114509173802, 44.739259651729036, 46.78417355673653, 51.554963043757844, 56.973015444619314, 57.82417324611119, 55.31442832946777, 61.34112903050014, 48.393626485552105, 50.055687699999126, 60.119955335344585, 59.6885347366333, 63.129227093287874, 61.10717623574393, 61.426598821367534, 57.730598381587434, 62.809415408543174, 57.983780315944124, 63.40539019448416, 60.01919255937849, 61.50316102164132, 61.89075238364083, 54.6128374508449, 63.81716823577881, 57.085454668317524, 59.60640008108956, 57.02085031781878, 57.09697478158133, 61.407623291015625, 59.25966412680489, 62.80170290810721, 57.98138666152954, 58.822511264256065, 57.675391469682964, 55.84108093806675, 56.980682781764436, 58.06183985301426, 58.21511363983154, 58.98664855957031, 58.76265253339495, 60.792026792253765, 64.34075668879917, 65.93291555132184, 64.02936622074672, 67.05979524339948, 64.14275387355259, 65.95223154340471, 65.96390451703752, 67.51444367000035, 68.17238249097551, 66.99678203037807, 59.696615491594585, 35.43078579221453, 9.802571552140371, 0.23222505460892404, 0.241061127611569, 0.10190669101263795, 0.6333192906209401, 0.2611505410500935, 0.38268517383507317, 0.3094389741974217, 0.676922330898898, 0.2234048864671162, 0.5186720054064478, 0.47524549279894146, 11.055443797792707, 44.81735740389143, 52.42925834655762, 32.38653680256435, 52.87342194148472, 37.43694959368025, 1.3220237578664507, 0.2526590824127197, 0.17209766459252152, 0.2975208865744727, 0.08959447632410697, 0.09070304648152419, 2.2409321410315375, 5.152075358799525, 7.336851290294102, 6.672545313835144], [16.94345498085022, 12.530366574014936, 1.9185207443577903, 0.5224009624549321, 2.020998856851033, 1.6407052746840884, 3.940962220941271, 6.134511990206582, 2.457444957324437, 29.67572144099644, 56.49112660544259, 35.69657175881522, 20.341452394212993, 29.189111300877162, 59.40476335797991, 13.880432827132088, 0.04116070097578423, 0.03214085694136364, 0.5190769008227757, 0.22683334749724182, 0.1151676130081926, 0.050277300711188994, 0.13481648080050945, 0.07064768871558563, 1.0902274016823088, 4.724864499909537, 19.80807740347726, 58.98475864955357, 64.0741195678711, 59.61241027287075, 76.27565656389508, 70.20928164890834, 74.59636729104179, 74.69848496573312, 73.18409034184047, 74.31896046229771, 72.69705636160714, 70.47160393851144, 71.47750159672329, 71.35346235547746, 70.98507581438336, 69.20337009429932, 66.26668616703579, 60.35199042728969, 55.54375014986311, 55.963546412331716, 58.2230623790196, 59.720051765441895, 62.84503187452044, 64.39056137629917, 63.91220569610596, 64.59374754769462, 63.52735192435128, 63.549877984183176, 59.724665369306294, 63.51485211508614, 63.327924728393555, 60.45572703225272, 60.29328509739467, 55.78727061407906, 59.356522015162874, 62.76606559753418, 60.705917767116, 60.49397686549595, 62.942528997148784, 57.4605392728533, 55.61453144890921, 60.94280964987618, 61.291428565979004, 60.97627912248884, 59.718585695539204, 64.7686892918178, 50.94967072350638, 48.517922810145784, 61.968738964625764, 53.86371047156197, 55.77800519125802, 59.43079825810024, 49.114818232400076, 44.74907398223877, 42.222743715558735, 40.14698328290667, 42.413815702710835, 40.85831206185477, 43.881782463618684, 48.30709709439959, 54.55417728424072, 56.03154843194144, 55.12713616234915, 57.82972833088466, 53.48132678440639, 50.42480032784598, 44.58676058905465, 43.051851408822195, 41.39930575234549, 42.93990203312465, 42.05276645932879, 42.356513908931184, 43.6279057094029, 49.33374902180263, 51.49972833905901, 56.79942512512207, 55.95422887802124, 51.87180437360491, 42.97177342006138, 46.026865073612754, 50.5069488797869, 54.69073370524815, 57.34714467184884, 55.077119554792134, 57.046301569257466, 57.23995133808681, 56.454492228371755, 51.50731577192034, 53.458151068006245, 53.924416882651194, 55.677631514413015, 53.8028998374939, 52.184278760637554, 53.06664787020002, 52.19256101335798, 54.57899277550833, 51.9166202545166, 54.438354287828716, 51.84323338099888, 53.80878496170044, 52.33059740066528, 50.33284091949463, 46.554987226213726, 45.12494025911604, 46.03111042295183, 51.74231774466378, 51.14352199009487, 51.679123878479004, 52.50923211233956, 54.05547033037458, 53.883203642708914, 58.01702397210257, 58.96064840044294, 56.68101739883423, 57.444721698760986, 57.588816915239605, 59.93004022325788, 58.777535574776785, 58.917319434029714, 57.946617875780376, 42.740950788770405, 28.950553587504796, 7.283508232661656, 0.305279120270695, 0.3945700132421085, 0.5198149840746606, 0.2268561055617673, 0.14083372934588365, 0.16813869774341583, 0.13642512448132038, 0.31286462609257015, 0.2824889203267438, 0.38916545467717306, 1.2249158429247993, 7.676869205066136, 35.40746068954468, 42.62004518508911, 40.56048100335257, 16.462226220539637, 44.074303150177, 17.136922359466553, 0.09325899968722037, 0.14363966163780006, 0.18009687321526663, 0.07255099301359483, 9.352539334978376, 12.495763676507131, 10.991676705224172, 6.4627713816506525, 11.696369954517909, 18.85650944709778, 9.34681054524013, 1.0075132229498454, 0.167826951614448, 0.1882732066192797, 0.7259539227400507, 4.630427190235682, 6.727047852107456, 0.35206204706004685, 45.03214706693377, 64.47585051400321, 50.66614253180367, 33.685731819697786, 25.484387397766113, 60.12902968270438, 17.506276437214442, 0.18736643956175872, 0.031688138376921415, 0.7542004670415605, 0.32372843314494404, 0.17164551599749497, 0.06953392097992556, 0.15082122199237347, 0.05032246739470533, 0.9508503377437592, 15.731730835778372, 21.742673022406443, 59.60401684897286, 74.57680116380963, 66.24657808031354, 79.06859615870884, 74.69747747693742, 78.01330375671387, 77.14669663565499, 76.42560563768659, 76.16490922655377, 75.34743976593018, 72.33943258013043, 70.39238057817731, 72.42527062552315, 71.24756486075265, 70.6508674621582, 69.02940109797886, 64.49024718148368, 57.712877001081196, 58.58489676884243, 61.50557899475098, 64.3689385822841, 65.49197592054094, 67.12063367026192, 66.33791215079171, 67.04077107565743, 65.05446869986397, 66.74319362640381, 63.36224882943289, 64.92938722882951, 66.56587559836251, 64.57074206215995, 63.8604416166033, 59.41692270551409, 63.52562877110073, 65.67021111079625, 62.60768835885184, 64.83553791046143, 64.91538660866874, 58.20897143227713, 58.019188335963655, 64.5254259109497, 64.32938943590436, 64.46983337402344, 61.89195442199707, 66.17891652243478, 51.17310741969517, 53.24352816173008, 65.11049897330147, 57.9401421546936, 60.1383124760219, 59.75699533735003, 51.33012628555298, 47.24423115594046, 45.32637548446655, 43.73359823226929, 44.1625383240836, 43.30342483520508, 47.10562154224941, 51.98941305705479, 56.13864796502249, 60.51466165270124, 58.733657700674875, 58.76664774758475, 54.8139773777553, 53.29265539986746, 47.586530685424805, 44.729407106127056, 43.6236812046596, 45.1875296320234, 43.271230357033865, 43.14311599731445, 45.10919564110892, 49.37769637789045, 52.32910353796822, 57.85132680620466, 57.9692759513855, 55.724854946136475, 45.85391051428658, 48.19846895762852, 51.34113918031965, 55.09694971357073, 58.50864723750523, 57.989769663129536, 57.90436588014875, 57.91917943954468, 59.39812782832554, 54.797895772116526, 56.96741172245571, 56.566681316920686, 59.64980547768729, 56.68146555764334, 52.375086716243196, 55.97678273064749, 55.34617812292916, 57.72794764382498, 53.234259264809744, 55.72640092032296, 54.530914715358186, 57.08935260772705, 55.26415811266218, 54.358397892543245, 50.76753411974226, 48.715300287519185, 51.14815296445574, 54.480304036821636, 53.66789286477225, 54.17273507799421, 55.660507678985596, 56.97941126142229, 57.20500189917428, 61.980196544102256, 61.62722110748291, 59.00349794115339, 61.85996491568429, 62.52084977286202, 62.944432803562705, 62.080875941685264, 60.47112424033028, 63.96110016959054, 49.035539286477224, 30.299815586635045, 7.292204771723066, 0.12005501932331494, 0.6490032204559871, 0.37284093350172043, 0.08063767837094409, 0.20279435813426971, 0.16204123278813704, 0.11336016535226788, 0.30668243925486294, 0.29598061208214077, 0.44388525986245697, 1.0235659501382282, 8.389190707887922, 44.67610052653721, 43.16570111683437, 47.93726532799857, 25.05071210861206, 56.20061200005667, 18.136082002094813, 0.01613087915549321, 0.06194753306252616, 0.0874695624890072, 0.3447100929915905, 5.472591851438795, 13.236100316047668, 17.65257249559675, 18.903147493089946, 18.687916619437082, 29.769595078059606, 15.983420644487653, 3.4075309932231903, 1.3696103415318897, 5.648953199386597, 4.267676940986088, 8.1896037033626, 13.042531320026942, 4.045903469835009, 53.8335657119751, 77.29943888528007, 58.33465044839041, 30.151499339512416, 43.540542534419465, 77.09438364846366, 22.127274921962194, 0.5018550306558609, 0.11183426901698112, 1.6553861669131686, 1.1809164839131492, 0.52363763323852, 0.10349201344485794, 0.5160575828381947, 0.1735982447862625, 1.5622297142233168, 27.93567885671343, 27.283142260142736, 64.85203293391636, 77.15149089268276, 72.75685255868095, 83.84944316319057, 77.65079539162772, 80.03822422027588, 80.27452550615583, 75.19332177298409, 78.37953635624477, 79.00133759634835, 73.78538049970354, 73.49384798322404, 74.84587710244315, 74.21277114323208, 75.7758378982544, 72.3619864327567, 69.13126863752092, 61.491661752973286, 63.12437725067139, 65.16989912305559, 66.69211741856166, 67.51019832066127, 70.12901605878557, 70.74469593593052, 70.9941223689488, 69.05518586294991, 70.15806647709438, 67.55654975346157, 70.05314173017229, 70.36688763754708, 69.3471908569336, 65.3502813066755, 63.99237401144845, 67.96019840240479, 70.65368148258754, 64.43548148018974, 67.9010066986084, 69.6670789718628, 62.79078033992222, 58.80113165719168, 67.04619067055839, 66.95731626238141, 65.88718250819615, 63.30051408495222, 73.14996773856026, 56.00733395985195, 54.48696041107178, 67.53904029301235, 61.07032993861607, 61.559635979788645, 64.96903364998954, 54.88901792253767, 49.79415055683681, 47.35724360602242, 47.252784388405935, 47.056935514722554, 45.67463309424264, 48.05474894387381, 53.75680201394217, 58.9328556060791, 61.09312697819301, 58.86870288848877, 63.42490073612758, 58.021189417157856, 56.82521683829171, 49.81048229762486, 48.841562952314106, 45.284074851444785, 47.80454083851406, 44.02211175646101, 45.27498313358852, 46.93828460148403, 52.88979537146432, 55.7438200541905, 60.08429023197719, 58.849796840122764, 55.86373553957258, 46.21412944793701, 51.351870673043386, 55.1882768358503, 59.49998147147042, 61.93208721705845, 60.18239879608154, 60.56221512385777, 61.700455120631624, 61.74317959376744, 55.269487380981445, 58.25944662094116, 58.45957905905587, 61.04400321415493, 60.495206696646555, 56.07027074268886, 60.70393058231899, 59.32016209193638, 60.03959247044155, 56.225191252572195, 58.99417345864432, 58.28771536690848, 60.50182832990374, 58.44448062351772, 58.71785054888044, 57.10452052525112, 54.8396509715489, 57.93830435616629, 60.23733125414167, 57.96108055114746, 56.47965860366821, 60.23275933946882, 59.70012433188302, 60.00451101575579, 64.72582585471017, 66.07887635912213, 62.76801804133824, 65.32301657540458, 65.76950086866105, 65.52899592263358, 67.3094231741769, 63.68955067225865, 64.26725169590541, 57.128422328404014, 36.10207210268293, 8.147684352738516, 0.3681098073720932, 1.2230865125145232, 0.9475635141134262, 0.7466085287077087, 0.29359754281384604, 0.3571157758789403, 0.14335991522031172, 0.5694850502269608, 0.2502412721514702, 0.8256792458040374, 0.9097610797200884, 9.666531034878322, 54.97620391845703, 52.483315331595286, 56.54420736857823, 28.831836666379655, 68.89347348894391, 23.313608612333024, 0.20635915042034217, 0.1646906677633524, 0.15229543431528977, 0.816884346306324, 9.762709736824036, 22.05604199000767, 25.095625264304026, 30.30224745614188, 27.808403491973877], [14.106485520090375, 23.044376339231217, 9.823000124522618, 5.869181130613599, 4.878258577414921, 1.1956707664898463, 4.4215899620737344, 3.2801242641040256, 5.234749802521296, 42.46621554238455, 45.86852257592337, 23.287354843957083, 14.194253427641732, 45.3000487600054, 50.75139345441546, 4.4168934140886575, 0.025249395752325654, 0.026757673925853202, 0.0931676145909088, 0.7367935468043599, 0.22173813304730824, 0.08964994656188147, 0.09747671229498726, 0.13292975989835604, 0.3557216306882245, 0.541352391242981, 20.965416261128016, 63.54174859183175, 54.54188592093331, 77.98118223462785, 68.60135037558419, 74.81620134626115, 70.06010382516044, 76.41617693219865, 73.2689903804234, 72.8852344240461, 69.78601823534284, 71.75229590279716, 67.9976978302002, 71.18576063428605, 69.09098298209054, 67.22824042184013, 63.168810980660574, 60.0580746786935, 54.25869819096157, 52.669464520045686, 54.81046506336757, 61.70522853306362, 59.37121050698416, 61.23007597242083, 61.46707207815987, 61.442009925842285, 63.02955518450056, 61.792178290230886, 64.65336309160504, 58.41463811056954, 62.43656117575509, 60.55245290483747, 58.23468324116298, 58.99784210750035, 59.515566280909944, 60.11722469329834, 59.868694577898296, 62.439312662397114, 57.48818962914603, 51.88285895756313, 59.36540181296212, 60.412550926208496, 62.38622842516218, 60.84244292122977, 61.972213063921245, 51.810375349862234, 45.72141184125628, 61.43042727879116, 56.593452726091655, 58.2439660344805, 56.91079085213797, 50.4854268346514, 46.207101345062256, 41.800963742392405, 40.561085496629985, 42.84877640860421, 40.16922099249703, 42.9078152520316, 47.35110834666661, 46.801582268306184, 49.14002629688808, 53.00956494467599, 56.07213633401053, 54.59909391403198, 48.84616960797991, 44.868537834712434, 40.860135963984895, 42.08236231122698, 41.346631458827424, 40.913199356624055, 38.74085896355765, 42.44409247807094, 41.518720967429026, 44.50297226224627, 49.058058398110525, 50.06984118052891, 57.59464297975813, 57.77108900887625, 51.47618089403425, 44.5280761037554, 51.40661205564226, 45.74347237178257, 53.6575539452689, 54.681916441236226, 53.16925539289202, 54.75554650170462, 56.477181570870535, 57.54567207608904, 53.68989086151123, 56.5896520614624, 56.24287789208548, 55.010694776262554, 50.33941738946097, 51.61131293433053, 51.95404325212751, 53.25139004843575, 51.81618751798357, 51.54072618484497, 49.724651200430735, 52.480723653520855, 48.89777387891497, 47.89923088891165, 44.90392501013619, 44.67506177084786, 44.361986364637104, 50.29620654242379, 52.719602721078054, 49.796314920697895, 50.261757373809814, 52.32360403878348, 53.31793989453997, 56.012621538979666, 55.113649708884104, 52.59217970711844, 58.99256842476981, 58.193275451660156, 59.168503761291504, 57.813976764678955, 63.425442695617676, 57.051769801548545, 49.03696714128767, 27.65667220524379, 7.188400856086186, 0.5675884091428348, 0.2845158129930496, 0.018095387312184488, 0.03438375783818109, 0.06511751296264784, 0.039781598906431875, 0.1696765837924821, 0.15826746528702124, 0.10066919920167752, 0.1375298337744815, 0.8075452074408531, 4.89649977002825, 46.42279774802071, 34.63741268430437, 51.64452879769461, 13.991522363254003, 45.75636822836739, 51.26039069039481, 1.1063499365534102, 0.22534770864461148, 0.09833399379359824, 3.827043899468013, 26.323047127042496, 25.157794271196636, 16.832910878317698, 20.128523111343384, 12.08689432484763, 30.957684925624303, 28.06351007734026, 9.446625760623387, 3.556051560810634, 5.426206111907959, 1.5228737060512816, 6.931837754590171, 11.323649474552699, 6.673222328935351, 57.02402911867414, 57.75715787070138, 38.473756313323975, 17.117062670843943, 32.037973472050254, 63.14761897495815, 5.30709661756243, 0.042586618568748236, 0.17496235801705293, 0.21410645970276423, 1.20551940373012, 0.1489542464592627, 0.13636582052069052, 0.035996136854269674, 0.3379813054842608, 0.4781234583684376, 2.297482877969742, 21.2130674294063, 67.83358832768032, 65.21046270642961, 79.40026147024972, 73.73761163439069, 76.61602796827043, 73.97200216565813, 77.84159292493547, 74.18605531964982, 73.43584442138672, 70.14881842476981, 72.40760830470494, 66.84945937565395, 75.13463728768485, 70.7789088657924, 69.56425952911377, 65.19145243508476, 62.9369079044887, 57.662881238119944, 57.21947847093855, 58.47519860948835, 63.437087876456125, 61.01841299874442, 65.05650452205113, 63.89400141579764, 64.36157349177769, 64.41851397923061, 63.48878247397286, 64.43575245993478, 62.02133682795933, 62.74875068664551, 62.91528511047363, 58.77722985403878, 62.31701741899763, 62.80744906834194, 63.497370447431294, 63.876429421561106, 65.96656567709786, 58.73550592150007, 56.59268495014736, 65.65138844081334, 62.17276586805071, 62.53088991982596, 62.58432156699044, 63.66661466870989, 52.14828709193638, 50.029711859566824, 64.25261878967285, 57.971030371529714, 62.758499009268625, 57.589470045907156, 49.734347411564414, 48.705430371420725, 44.39612981251308, 43.0745199067252, 44.735219274248394, 44.02931009020124, 45.42160749435425, 48.34196662902832, 47.02120787756783, 49.83409227643694, 54.615602833884104, 59.70243113381522, 55.87844140189034, 51.87498664855957, 46.900000027247835, 42.981577328273225, 45.103911536080496, 44.69076122556414, 43.304800578526084, 42.24697208404541, 43.52413088934762, 44.171498026166645, 48.198396001543315, 49.96400274549212, 50.77585111345564, 55.94944851739066, 59.67263725825718, 55.958745207105366, 47.272343567439485, 51.596006052834646, 49.66476815087454, 51.82602964128767, 57.52912146704537, 56.234960419791086, 57.36580058506557, 55.46127503258841, 57.7149475642613, 55.84917558942522, 57.769994667598176, 57.84883935110909, 58.70482267652239, 54.702486583164756, 53.60440717424665, 55.380783626011436, 57.233239378247944, 52.17393636703491, 54.11956746237618, 52.2642560005188, 54.805663858141216, 51.775877543858115, 53.45184210368565, 48.12004811423165, 49.384446552821565, 49.27578714915684, 53.038059507097515, 55.575166429792134, 52.5920581136431, 52.94097580228533, 54.246757711683, 56.54473195757185, 58.3926887512207, 57.12837716511318, 58.19942808151245, 61.3124885559082, 60.903795514787944, 59.8761499949864, 60.36346885136196, 66.49055017743791, 59.483187675476074, 53.67310053961617, 27.389628614698136, 6.824387337480273, 0.8736834813441549, 0.7270316534808704, 0.02706349814044578, 0.01668966461771301, 0.06560110487043858, 0.07273054016487938, 0.12525947791125092, 0.12582498256649288, 0.09419965956892286, 0.11957541720143386, 0.8893116627420697, 6.120277736868177, 52.762341090611045, 39.15929685320173, 57.90583542415074, 22.590202127184185, 52.560808590480256, 57.65131943566458, 1.3250698915549686, 0.20778567530214787, 0.03957507320280586, 3.8415504353387013, 28.576811722346715, 35.834827014378135, 30.388596194131033, 28.826278107506887, 30.087183339255198, 41.9725911957877, 38.37544277736119, 21.123336655753, 11.395047426223755, 16.829730340412684, 5.770468073231833, 14.101834569658552, 13.62846509047917, 7.843872632299151, 68.82330363137382, 73.97432286398751, 42.68982246943882, 22.572525909968785, 59.831528663635254, 70.98283154623849, 9.345135160854884, 0.235748931233372, 0.23055420283760342, 0.6530779046671731, 1.965667528765542, 0.4433282640363489, 0.4118627224649702, 0.20885028317570686, 0.6596309244632721, 0.6214384138584137, 1.8376684657164981, 24.862655639648438, 76.40626185280937, 70.13331004551479, 84.82538018907819, 75.90784672328404, 82.34216349465507, 74.73751299721854, 81.81620570591518, 76.79941872188023, 76.38921097346714, 74.15681035178048, 76.95695522853306, 71.97132396697998, 78.31494590214321, 74.30962903159005, 72.27516174316406, 67.53875541687012, 66.59805965423584, 59.403498785836355, 61.046240534101216, 60.24535642351423, 69.17342335837228, 63.144269943237305, 68.18891920362199, 67.41885730198452, 66.68169512067522, 68.25943647112165, 68.1368077141898, 68.97510092599052, 67.3103472845895, 66.38160242353166, 68.40407712118966, 63.554248401096885, 67.91793251037598, 66.97525651114327, 68.74857575552804, 66.59815692901611, 71.57919543130058, 64.04692431858608, 58.216141973223, 66.04249559129987, 66.76796395438058, 66.16502012525285, 64.70176424298967, 67.04515538896833, 56.62702294758388, 50.65774910790579, 66.36655957358224, 61.03101008278983, 64.4604880469186, 62.7617438180106, 54.21888153893607, 51.06417008808681, 46.43388359887259, 44.68626921517508, 48.273686681474956, 45.8990911756243, 47.94394602094378, 50.77166134970528, 51.183494976588655, 53.6905266216823, 58.16817855834961, 61.218250138419016, 59.29171616690499, 53.732580593654085, 48.6747019631522, 44.309034143175396, 47.606854166303364, 47.73180014746529, 44.38438388279506, 42.165202208927695, 44.19555616378784, 43.81354767935616, 49.42243235451834, 52.63476174218314, 53.88141795567104, 59.84241649082729, 61.00610773903983, 56.74894993645804, 49.089631012507844, 54.5240672656468, 51.04069907324654, 58.762193952287944, 59.20587812151228, 58.661924498421804, 57.82340547016689, 58.37308093479702, 59.85769557952881, 57.76987654822213, 63.701612745012554, 60.71791730608259, 61.16124711717878, 58.16524294444493, 60.176895822797505, 56.348744119916645, 59.043693270002095, 55.70722736631121, 57.377782753535676, 57.20254223687308, 59.75098514556885, 56.047136715480256, 57.46292250497, 57.23850263868059, 54.30903441565377, 56.87446914400373, 61.10511262076241, 59.852435793195454, 55.85880579267229, 57.78663560322353, 56.676462854657856, 60.13549845559256, 62.07668617793492, 60.761114256722585, 60.85381017412458, 65.44135134560722, 64.20379379817417, 64.06237711225236, 64.56483609335763, 67.72279930114746, 65.16964203970772, 56.48222943714687, 28.78953603335789, 8.843454377991812, 1.5850044978516442, 1.3905670855726515, 0.07096447635974203, 0.14537988682942732, 0.15791522418814047, 0.13043891212769917, 0.32473090078149525, 0.3491023858743054, 0.16922959206359728, 0.4292351188404219, 0.8554380546723093, 7.592491149902344, 60.45446246010916, 48.73502622331892, 59.92163985116141, 26.64978963988168, 62.84322534288679, 69.25139604296002, 2.352503491299493, 0.5656517073512077, 0.11444677811648164, 7.546308210917881, 36.657584054129465, 47.3042288507734, 42.74162476403372, 44.156239782060894, 39.40233441761562], [9.051270655223302, 7.292764101709638, 9.82750255720956, 13.016473838261195, 7.229221522808075, 5.667062810489109, 7.462174211229597, 7.689473237310137, 3.959999850818089, 25.583784852709087, 31.190473897116526, 23.57530903816223, 40.86583696092878, 54.36255291530064, 33.85758508954729, 0.9591937128986631, 0.14134306487228188, 0.06876179562615496, 0.08648179870631013, 0.2869276250047343, 0.04776366773460593, 0.04994713235646486, 0.05765659295554672, 0.1300719061068126, 0.10621283030403511, 0.8752248957753181, 30.993596690041677, 57.30652550288609, 72.49982479640416, 71.73967102595738, 72.75124536241803, 69.51291234152657, 71.61982154846191, 70.26412378038678, 74.11341885157994, 68.1711735044207, 66.33951718466622, 64.71185302734375, 67.51334585462297, 69.02635083879743, 67.44350951058524, 67.15235914502824, 65.57664666857038, 61.62825638907296, 54.26170328685215, 54.361802509852815, 55.681029183524, 59.47630895887102, 58.16435704912458, 57.872647353581016, 57.23829419272286, 58.48894214630127, 62.853501728602815, 59.84088788713728, 61.013771602085654, 58.11973571777344, 61.16327599116734, 57.219398566654746, 57.902319635663716, 56.96179410389492, 57.322471618652344, 60.77826935904366, 61.36004202706473, 56.95087153570992, 55.66876213891165, 63.48391873495919, 60.20607130868094, 57.882597173963276, 60.25236715589251, 59.659810883658274, 52.46290152413504, 45.5605263028826, 59.42427389962332, 58.37560313088553, 59.41645022800991, 59.324581146240234, 48.40581362588065, 50.15994194575718, 45.187606062207905, 42.24361263002668, 42.31445298876081, 41.94018827165876, 42.94703088487898, 43.75871249607631, 42.334050382886616, 43.70957830974034, 50.467219080243794, 53.48483909879412, 56.13582352229527, 54.0041127204895, 53.738927773066926, 48.526003565107075, 43.24701935904366, 44.266535486493794, 44.19286026273455, 40.87211118425642, 41.172454016549246, 42.36901371819632, 42.37162276676723, 44.27270548684256, 48.59520762307303, 51.641214506966726, 51.59116315841675, 51.996027742113384, 58.336915561131065, 51.531467710222515, 48.977778911590576, 54.290003299713135, 47.662867069244385, 51.85185262135097, 52.410664967128206, 58.33815928867885, 52.9639778137207, 51.746344225747244, 53.50547872270857, 53.91282033920288, 50.97599049976894, 54.56252901894705, 52.30393716267177, 51.697140557425364, 51.9974000113351, 52.92361225400652, 47.535395417894634, 50.87757274082729, 48.95402302060808, 47.96735102789742, 46.77225739615304, 48.56503159659249, 44.624850613730295, 44.51497180121285, 45.47697421482631, 46.571089676448274, 53.29789434160505, 49.8830110686166, 50.791147572653635, 47.71136549540928, 48.231837681361604, 47.996047088078086, 49.6912442616054, 53.19660350254604, 57.67339038848877, 56.801426206316265, 58.32404749734061, 55.45970473970686, 57.89493370056152, 54.25587722233364, 35.02006735120501, 11.518495202064514, 5.01920712845666, 0.2300792554659503, 0.6386687521423612, 0.05527729634195566, 0.019223339822409407, 0.14106873316424234, 0.06519794650375843, 0.1377386868532215, 0.11214737900133644, 0.08217626331107956, 0.07253744945462261, 0.3419526352414063, 3.1107577979564667, 60.14790793827602, 24.044470514569962, 32.00434071677071, 18.340126276016235, 30.626644951956614, 61.68508570534842, 9.287454690252032, 0.34537671293531147, 0.6101668072598321, 16.385261024747575, 27.338627099990845, 40.61626461574009, 45.99251665387835, 42.780103887830464, 18.06276634761265, 30.24475806100028, 26.520384652273997, 24.322139637810842, 8.140823006629944, 9.796225241252355, 3.7423744542258124, 9.928791659218923, 12.255890148026602, 7.335869857243129, 33.86166020802089, 49.76246329716274, 36.609467778887065, 28.973663296018326, 54.63515159061977, 45.766206877572195, 1.4588686376810074, 0.10742387960531882, 0.08403029239603452, 0.07080674410930701, 0.7107248827815056, 0.161479473646198, 0.08610635849514178, 0.22123191878199577, 0.18907941478703702, 0.059343152812549045, 0.8967894986271858, 32.62962300436837, 65.97013010297502, 77.06937708173479, 76.97217873164585, 78.64408206939697, 76.35024547576904, 74.98254816872733, 73.06742313929966, 75.585985319955, 70.4081460407802, 67.6348351069859, 65.78019414629254, 70.18012700762067, 69.70546776907784, 69.46963896070207, 68.52719225202287, 68.84065328325543, 64.56367574419293, 58.71575219290597, 57.182388986860005, 60.56821141924177, 59.92974839891706, 59.74644102369036, 60.41897106170654, 58.72716113499233, 60.87795516422817, 64.82492801121303, 64.16093730926514, 62.217088426862446, 61.85851274217878, 61.14533574240548, 59.34424454825265, 61.42270088195801, 62.839869362967356, 62.54190281459263, 63.35962241036551, 63.84985951014927, 59.49053886958531, 57.98968628474644, 65.6584894997733, 61.47338104248047, 61.587366240365164, 62.11890343257359, 62.098336764744346, 54.066372053963796, 50.11531366620745, 61.51215893881661, 60.30637550354004, 62.105479512895855, 60.540627070835654, 51.48280600139073, 53.16864742551531, 47.39333254950387, 45.068555627550396, 44.41296182359968, 46.85747010367257, 46.58078588758196, 46.631702286856516, 45.309467043195454, 47.10152905327933, 52.19901588984898, 58.42836775098528, 57.78079216820853, 58.03109754834856, 56.363151209695, 51.86262927736555, 45.33229534966605, 47.54316350391933, 47.636318002428325, 43.30891738619123, 42.24961587360927, 44.444958278111045, 43.55670057024275, 45.17683982849121, 48.26056500843593, 54.953841141292024, 55.644283635275706, 54.904554094587056, 58.34999901907784, 54.43939651761736, 48.25038589750017, 55.37393617630005, 49.99411971228463, 52.583445821489605, 54.51651109967913, 60.47293772016253, 54.44054644448416, 53.75319242477417, 53.40924269812447, 55.49054779325213, 52.03627518245152, 55.9742431640625, 55.229090554373606, 53.48786503928048, 53.879851136888774, 55.02971199580601, 49.84798172542027, 52.41966635840279, 52.9599096434457, 53.200310366494314, 49.81963654926845, 52.17226879937308, 47.78159441266741, 49.68846150806972, 51.83742816107613, 50.755628381456646, 55.656595843178884, 52.20024919509888, 52.8671372958592, 50.7242294720241, 51.751454625810894, 52.87590592248099, 53.38831124986921, 55.48201193128313, 60.86740779876709, 57.79891307013375, 61.97062192644392, 56.85734183447701, 60.15908758980887, 58.38295432499477, 39.802095549447195, 17.459508112498693, 8.003054124968392, 1.3446021463189806, 0.5086896153432983, 0.258089723863772, 0.1392090315265315, 0.11908368287341935, 0.061767300590872765, 0.15255128272942134, 0.04416947113350034, 0.10511846866990839, 0.032688373633261235, 0.47364442156893866, 4.487212223666055, 65.61737700871059, 31.045041152409144, 36.795411995479036, 22.869583981377737, 38.00056661878313, 72.8220614024571, 9.756828955241613, 0.38797484285065104, 0.40776344814470833, 18.67331498009818, 39.03981910433088, 50.73266111101423, 49.18877485820225, 50.64303282329014, 35.532236439841135, 42.03576421737671, 30.793134212493896, 46.20395728519985, 34.762045996529714, 16.442991869790212, 13.878335339682442, 18.927553040640696, 24.82942066873823, 5.2625056845801215, 61.91282681056431, 64.02582263946533, 38.02588585444859, 55.269358839307515, 72.94023636409214, 50.60405690329415, 3.036166931901659, 0.2815086543560028, 0.3922451079956123, 0.18498905641692026, 1.4071654634816306, 0.41311931503670557, 0.155393245230828, 0.3706084175833634, 0.4802202401416642, 0.12108890313122954, 1.1141486380781447, 40.61820663724627, 74.11209174564907, 86.88637569972447, 84.42464283534459, 85.59542124611991, 82.48542145320347, 80.22771549224854, 76.35928508213588, 76.08878476279122, 74.60328769683838, 71.44934749603271, 69.33032063075474, 72.68443148476737, 72.02872998373849, 74.08991309574672, 71.73280620574951, 70.60706601824079, 65.9580819266183, 62.48044599805559, 60.10001400538853, 62.715739795139854, 62.80255058833531, 64.27399144853864, 62.850750241960796, 60.64724023001534, 63.143206868852886, 68.49631445748466, 67.70162119184221, 64.38278634207589, 65.74036012377057, 66.16411685943604, 63.775618008204866, 64.90243516649518, 67.57156481061662, 65.43569551195417, 66.4509037562779, 68.96793038504464, 65.07226998465401, 61.87955188751221, 68.7765839440482, 63.59226199558803, 63.501504625592915, 65.53335244315011, 65.60917813437325, 58.6503974369594, 52.145657198769705, 64.61156967708042, 64.95881979806083, 64.25586359841483, 67.43775640215192, 54.97136797223772, 55.838433674403596, 50.32216501235962, 46.18192802156721, 47.80598953792027, 49.04934188297817, 48.71922254562378, 48.42492464610508, 45.170162609645296, 48.231375626155305, 54.89679643086025, 59.56574617113386, 61.799765723092214, 60.95250933510916, 58.896266392299104, 52.394826548440115, 47.67698580878121, 50.59775488717215, 51.434217248644146, 45.32274157660348, 44.11348751613072, 45.267020498003276, 44.9466529573713, 48.21133702141898, 51.498627049582346, 55.86824492045811, 55.67222581590925, 57.22416155678885, 62.825563022068565, 54.688551970890586, 54.29500600269863, 58.535432543073384, 51.631917817252024, 56.37495272500174, 55.74288204738072, 62.60808440617153, 56.790065901620046, 57.804294449942454, 57.62231765474592, 60.34101922171456, 54.64483043125698, 60.453823225838796, 59.264555658612935, 57.48679304122925, 56.694114753178184, 59.484980310712544, 53.359191349574495, 57.228240149361746, 55.30012893676758, 57.3018285206386, 54.525401319776265, 58.76727308545794, 55.75985649653843, 53.403826577322825, 57.30262408937727, 60.031331062316895, 61.222544125148225, 57.624471596309114, 56.77039555140904, 53.54690040860857, 55.26241064071655, 57.80665683746338, 57.82068525041853, 59.27039214542934, 62.4659937449864, 61.43689605167934, 64.25497422899518, 61.12107958112444, 64.18766702924455, 59.313630785260884, 44.884001050676616, 23.40471339225769, 9.190148643084935, 1.385593043906348, 0.983508608170918, 0.28324155136942863, 0.27512315128530773, 0.35279261214392527, 0.22180430378232682, 0.27495783301336424, 0.2624162259910788, 0.25926396942564417, 0.20183746090957097, 0.6724372687084335, 5.5356311202049255, 74.4403385434832, 37.8284249986921, 40.46133368355887, 32.08807693208967, 43.88514191763741, 83.19620132446289, 13.367183293615069, 0.470933592745236, 1.0669697182519096, 26.272823810577393, 51.473269598824636, 66.53712395259312, 74.8079468863351, 86.56682109832764, 55.733901500701904], [9.288422226905823, 9.418513349124364, 38.372816358293804, 15.438219819750104, 28.950767244611466, 34.531032289777485, 34.673901149204795, 13.462563821247645, 1.9880511505263192, 18.234107187816075, 21.139428683689662, 18.554294075284684, 43.29758140019008, 60.81761005946568, 34.33769171578543, 0.1699097284248897, 0.09925620430814368, 0.10754197183996439, 0.02099856045762343, 0.12520068963723524, 0.29994979766862734, 0.01572222465516201, 0.05235300040138619, 0.09329269573624645, 0.06255911024553434, 2.629128864833287, 46.43097925186157, 65.56447342463902, 63.51792321886335, 65.32121004377092, 68.36497265951974, 68.40060997009277, 68.14896706172398, 70.67514446803501, 71.93663161141532, 68.20972905840192, 62.77006081172398, 60.318652970450266, 65.45135675157819, 68.08422374725342, 68.52369730813163, 67.46793242863247, 65.96266078948975, 61.869928632463726, 58.49780109950474, 50.806530884334016, 53.74520547049386, 58.05438791002546, 60.58312920161656, 61.29588236127581, 63.315028871808735, 60.54364258902413, 60.22683947426932, 61.1064327784947, 60.51263277871268, 60.02384090423584, 55.16552495956421, 59.449752943856375, 58.5299643107823, 54.912193638937815, 60.138493129185264, 58.2684132712228, 60.18469864981515, 55.09084572110857, 61.29061562674386, 61.173795563834055, 56.28670365469796, 60.80518668038504, 57.004890305655344, 54.48850638525826, 47.470586095537456, 53.97963421685355, 59.739534514290945, 58.048558371407644, 58.23038925443377, 50.30686160496303, 54.32465049198696, 46.073643820626394, 43.2170170375279, 42.85192046846662, 43.69171101706368, 44.57126610619681, 44.57967342649187, 46.621967860630576, 46.470615250723704, 49.891762324741904, 55.107535294124055, 57.65212195260184, 56.86822618756975, 56.82943786893572, 56.200149944850374, 54.75762401308332, 52.58124671663557, 46.02463470186506, 45.965366567884175, 41.81818832669939, 41.194868905203684, 40.877381392887656, 41.954143728528706, 41.93924331665039, 45.24070766993931, 52.530907017844065, 56.361125809805735, 57.09708595275879, 53.03818110057286, 58.18786627905709, 48.88074037006923, 51.11871344702584, 56.366458552224294, 49.03296497889927, 50.677680015563965, 52.57597998210362, 54.77046080998012, 49.94374874659947, 46.373125076293945, 49.362469400678364, 49.33350930895124, 50.18774863651821, 53.477262088230674, 51.3404096194676, 50.922037737710134, 51.13407938820975, 50.50449963978359, 45.95017433166504, 50.070469992501394, 45.48752505438668, 44.89296770095825, 45.46595089776175, 42.36552572250366, 44.84094653810774, 48.67454562868391, 44.180756500789094, 48.23134783336094, 53.57186181204659, 50.59574338368007, 47.53540236609322, 46.76333590916225, 47.805009841918945, 49.62476737158639, 53.98713479723249, 54.96112980161394, 58.034974643162315, 54.80178676332746, 59.67582648141043, 57.472900118146626, 36.54904971803938, 10.658315164702278, 6.255808864321027, 2.550420322588512, 0.045435553017471514, 0.05164635706959026, 0.16404903147901806, 0.01858895707742444, 0.11649246620280401, 0.10225092539829866, 0.0787977831704276, 0.08880410516368491, 0.029373377228954008, 0.06979260567043509, 0.33318053452031954, 3.3494614234992435, 61.91179847717285, 30.33139862333025, 28.765771457127162, 53.50380768094744, 41.78132813317435, 50.010802337101524, 16.755537475858414, 0.282369145325252, 3.456240688051496, 24.637136220932007, 26.820816074098857, 34.8951005254473, 42.445464747292654, 37.3967855317252, 11.545098985944476, 26.947097846439906, 21.676877055849346, 29.454136439732142, 21.517078910555156, 14.699033975601196, 9.31333759852818, 16.05927586555481, 18.691243069512502, 4.948639052254813, 23.75869631767273, 37.57631656101772, 29.74643325805664, 39.237255641392295, 70.49599211556571, 40.41910948072161, 0.49772834352084566, 0.10997629085821764, 0.22201645454125746, 0.10953550772475344, 0.1734043601900339, 0.5958946645259857, 0.01831891031802765, 0.1039013396948576, 0.11341597485755171, 0.030409788579813073, 2.8812989677701677, 48.29242944717407, 73.85985129220145, 75.51124354771206, 71.94155788421631, 74.70940058571952, 74.12752369471959, 73.98148645673479, 73.97997869764055, 72.7628835950579, 69.14576257978166, 64.26179736001151, 62.727523939950125, 67.16255910055978, 69.67326286860875, 69.61746883392334, 70.44815376826695, 66.7547276360648, 64.25262573787144, 61.02761936187744, 53.90575402123587, 57.6070350919451, 59.464177404131206, 62.191275869097026, 62.778641836983816, 63.941798073904856, 61.79385280609131, 61.74869646344866, 62.24001748221261, 63.808100836617605, 62.686724117824006, 58.629518100193565, 63.668323925563264, 58.61224487849644, 56.859530517033164, 63.5295683997018, 59.43471704210554, 61.418212345668245, 59.35809925624302, 64.16221577780587, 59.7601706641061, 57.80593075071062, 63.28817408425467, 57.630818775721956, 56.04549694061279, 49.9390413420541, 58.13553244726998, 62.661898204258506, 61.718826157706125, 59.34260477338518, 53.85504954201834, 57.833251067570274, 49.041980266571045, 44.3516127041408, 45.58331292016165, 47.539074489048545, 47.52692208971296, 46.65903997421265, 50.33039167949131, 50.52731057575771, 52.53683730534145, 57.84689038140433, 59.25453635624477, 60.21830013820103, 57.518775599343435, 58.3142157963344, 56.524474484579905, 55.97953769138881, 49.290180342538015, 49.683952127184185, 45.292600291115896, 42.334151131766184, 42.444717815944124, 43.75227151598249, 43.38214445114136, 46.74912336894444, 52.18026270185198, 56.72618416377476, 59.88608591897147, 56.04601458140782, 58.18464231491089, 52.47041252681187, 49.28043549401419, 57.45274339403425, 51.54129246303013, 51.5896623475211, 54.75509139469692, 56.12541512080601, 52.6699925831386, 47.64703212465559, 53.88954734802246, 48.55802433831351, 51.096020630427766, 54.17915521349226, 56.219257490975515, 50.4733612877982, 54.77129806791033, 52.60451970781599, 49.219082900456016, 53.594144684927805, 50.952470847538535, 48.175654547555105, 48.357158865247456, 47.445708070482524, 52.841953550066265, 53.93235519954136, 49.16446311133248, 50.97356905255999, 56.58390242712838, 52.06095518384661, 51.277479784829275, 49.77848931721279, 51.43237597601754, 54.10033484867641, 58.91488756452288, 57.50849573952811, 60.451926367623464, 57.98497193200247, 58.00992291314261, 67.75031416756767, 41.36785473142351, 17.095495462417603, 10.689912966319493, 5.255953099046435, 0.3591070590274674, 0.20323915140969412, 0.024176440201699734, 0.04673669819853135, 0.06656091979571752, 0.10063614776091916, 0.051868896199656386, 0.048743434982108216, 0.007797732067826603, 0.14786954037845135, 0.36248838901519775, 5.173500997679574, 69.18889004843575, 35.84606919969831, 28.372119528906687, 51.88284158706665, 45.468365396772114, 61.47454139164516, 21.438241175242833, 0.4748865206326757, 2.1862930272306715, 37.06817395346505, 39.424169131687705, 59.931874547685894, 70.82088293348039, 69.61375154767717, 43.12164258956909, 47.92927142551967, 49.59830168315342, 74.10483782632011, 104.67725903647286, 59.79856640951974, 59.956366947719026, 52.139730385371614, 37.395614760262625, 1.5953037909099033, 58.069243158612935, 48.07640300478254, 34.061813490731375, 59.52286883762905, 75.64669173104423, 51.476757594517295, 1.0341329659734453, 0.2688274048268795, 0.3120550252497196, 0.20720290871603148, 0.3703516327909061, 1.069483446223395, 0.12312844369028296, 0.36762191355228424, 0.3856854114149298, 0.32849598303437233, 3.7879854696137563, 57.22991466522217, 82.50136062077114, 81.61493028913225, 79.88580158778599, 79.93764904567173, 79.27763966151646, 77.33820288521903, 76.75105231148856, 77.7301994051252, 74.18620818001884, 68.20840195247105, 66.33726596832275, 70.78303609575543, 72.31455108097622, 73.4381651197161, 70.75465965270996, 72.57822132110596, 67.63782978057861, 64.91601889474052, 57.624457699911936, 61.05143778664725, 62.962220191955566, 63.97571917942592, 65.83659267425537, 67.31819180079869, 64.20913696289062, 66.6684935433524, 65.94076006753104, 68.40039457593645, 68.69488702501569, 63.19151074545724, 67.42087227957589, 63.4176607131958, 61.07135132380894, 65.1350816999163, 62.8598940713065, 65.91856057303292, 61.31211335318429, 65.88173512050084, 66.43781335013253, 60.677583013262065, 68.34385013580322, 61.52655560629708, 58.0674262046814, 54.32032176426479, 60.1733591897147, 66.02570874350411, 66.19052001408168, 63.260033879961284, 56.38729967389788, 61.3743622643607, 51.58188731329781, 48.847177096775596, 49.034107957567485, 48.65792901175362, 50.422448362622944, 50.45307602201189, 51.634492124829976, 50.19659716742379, 53.567970820835654, 60.23341247013637, 62.893168994358604, 63.87440749577114, 60.22182982308524, 59.707239287240164, 58.81321457454136, 58.09908219746181, 51.488625117710654, 50.66093833105904, 47.25888838086809, 45.4441613469805, 45.77485738481794, 44.96906784602574, 45.054603644779746, 49.932228633335654, 56.408717496054514, 60.97946834564209, 62.16112763541085, 57.9608929497855, 61.09487097603934, 51.6469988822937, 55.597393717084614, 58.67952428545271, 53.84272691181728, 55.58621406555176, 57.718268803187776, 58.81135245731899, 53.89908375058855, 49.99797248840332, 57.20419243403843, 52.27227422169277, 54.77411903653826, 57.286646706717356, 57.51976571764265, 55.17061798913138, 58.909009388514924, 55.008228165762766, 53.6335757119315, 56.98998294557844, 55.881071295057026, 52.32395492281233, 57.30246775490897, 52.27542870385306, 56.64108610153198, 57.53191811697823, 55.348960876464844, 57.05845396859305, 60.589834213256836, 57.51669808796474, 55.29240948813302, 51.591597420828684, 54.82017517089844, 56.19060659408569, 64.23299707685197, 61.302531787327354, 62.79337896619524, 62.284006527491975, 60.58466475350516, 68.86800139290946, 47.11299010685512, 32.262098039899556, 14.129986933299474, 5.969310751983097, 0.3716277400297778, 0.21058927343360015, 0.23913403387580598, 0.12737707713884966, 0.21044612968606607, 0.2817098264183317, 0.12925313147050993, 0.2680371558027608, 0.1427045182457992, 0.3991360110895974, 0.5802664831280708, 7.528696264539446, 75.87430082048688, 45.6485321862357, 39.97845820018223, 66.86658668518066, 54.254716873168945, 73.13300023760114, 28.355563708714076, 0.7647799136383193, 4.223751732281276, 47.797669070107595, 48.527108328683035, 72.48279476165771, 83.63539000919887, 85.49648584638322, 55.97419452667236], [17.689168657575333, 43.308309418814524, 43.0393203326634, 42.88223545891898, 33.8837103162493, 37.94527632849557, 13.846372757639203, 10.100148132869176, 4.946133358137948, 7.722360798290797, 19.070988178253174, 25.71902459008353, 55.53692354474749, 71.30044065202985, 29.85030882699149, 0.549721496445792, 0.05668226755889399, 0.06798103252159697, 0.06463054873581443, 0.009531224495731294, 0.2553222509367125, 0.1747778779161828, 0.1589814741164446, 0.04835876330201115, 0.07019013219646045, 5.838974271501813, 68.67445237295968, 65.58815288543701, 60.800913538251606, 59.64638696398054, 62.44942923954555, 63.252717426845, 67.00541169302804, 70.02027675083706, 67.47371332986015, 67.16303157806396, 60.6839336667742, 58.404959269932334, 62.920371191842214, 66.15919058663505, 66.16887637547084, 65.68017482757568, 66.98443508148193, 63.03196620941162, 61.47898129054478, 53.706684657505576, 53.68973452704293, 54.78686898095267, 60.06994220188686, 61.62260055541992, 63.321921484810964, 61.57386589050293, 60.196461950029644, 60.78163923536028, 59.27187211172921, 60.18146078927176, 58.326625279017854, 56.630754130227224, 50.77630969456264, 53.59862974711827, 55.501161166599815, 58.67226341792515, 57.0323600087847, 62.11119788033621, 58.934273038591655, 58.850519452776226, 59.3040075302124, 57.128724575042725, 55.36088745934622, 52.97724192483084, 52.18991722379412, 59.834349632263184, 59.37901333400181, 58.72360365731375, 55.41206094196865, 58.448454993111746, 50.274569852011545, 44.3118759563991, 42.296773297446116, 43.52336311340332, 45.39257097244263, 45.789420809064595, 48.74419437135969, 47.019703592572895, 47.14092533929007, 52.431193419865195, 52.861676011766704, 55.77788707188198, 57.04950468880789, 57.262814385550364, 53.603285040174214, 52.17083747046334, 46.20304012298584, 44.26503814969744, 49.05623797007969, 50.280701637268066, 44.086472920009065, 43.40199198041643, 41.27100031716483, 42.6833849634443, 42.30978379930769, 43.7418909072876, 49.536761488233296, 55.55415507725307, 58.6552403313773, 53.432776246752056, 57.37387439182827, 46.724287033081055, 49.59972953796387, 57.805906432015554, 52.28492341722761, 49.50133262361799, 51.07310199737549, 54.07509551729475, 47.7075891494751, 50.31482771464756, 48.707803181239534, 45.22930915015084, 43.25544057573591, 52.11427565983364, 50.88135256086077, 49.70445278712681, 50.6689669745309, 50.290818214416504, 44.072058882032124, 45.14768171310425, 43.30398416519165, 41.646119662693565, 42.61784608023507, 49.953719411577495, 47.617735045296804, 51.695417404174805, 46.46558475494385, 53.12869528361729, 46.40220676149641, 49.138261454445974, 48.65281513759068, 50.2599265234811, 52.70213147572109, 54.1798882484436, 54.120873723711284, 54.946938105991904, 51.49664681298392, 42.4905481338501, 27.89401224681309, 9.539073279925756, 8.261384674480983, 2.377259271485465, 0.964498336826052, 0.275938017559903, 0.0906631350517273, 0.06544156771685396, 0.01682865064192031, 0.0565650845611734, 0.12994982408625738, 0.062377900683454106, 0.3036289502467428, 0.10406101255544595, 0.1381347341729062, 0.597429347889764, 7.3695529869624545, 57.96162945883614, 37.64316170556204, 27.121994427272252, 89.07656601497105, 59.975523131234304, 47.12954418999808, 30.591497489384242, 0.5538615914327758, 5.906744829245976, 9.191746728760855, 16.178102220807755, 16.43293956347874, 14.088778904506139, 14.098242350987025, 8.118465440613882, 20.56719936643328, 45.09354134968349, 60.41512175968715, 73.22878810337612, 45.54909651620047, 42.83656842367989, 37.33278567450387, 16.63152081625802, 6.612772132669177, 23.376116343906947, 30.849772453308105, 26.555818728038243, 55.2174141066415, 80.0283647264753, 36.78908218656267, 0.7419215344956943, 0.3644065260887146, 0.10872066859155893, 0.016066165574427162, 0.07574111861842019, 0.30543103069067, 0.13852231337555818, 0.26527321125779835, 0.1377278302929231, 0.15021799079009465, 5.661631924765451, 69.39240278516496, 74.5256346293858, 70.80940450940813, 67.96530532836914, 70.69884477342877, 70.1706496647426, 72.93898568834577, 72.84612301417759, 69.09834807259696, 68.08553000858852, 63.074982506888254, 59.684754916599815, 63.36017826625279, 68.02847834995815, 66.99556609562465, 67.771728515625, 68.6513009752546, 65.9379529953003, 64.65723323822021, 56.76192569732666, 57.171574115753174, 58.61810915810721, 60.689485277448384, 64.46961797986711, 66.15618201664516, 63.23814705439976, 61.62273257119315, 61.717804772513254, 62.91046306065151, 61.680597169058665, 60.89810494014195, 55.98570074353899, 53.860677582877024, 55.0287184034075, 58.534668241228374, 60.93804318564278, 58.07005262374878, 65.7205924987793, 61.53058556147984, 60.85980646950858, 62.22283458709717, 58.63641766139439, 57.84684869221279, 56.426862716674805, 56.48842723029, 61.224767548697336, 60.86227308000837, 60.021985735212056, 59.83354364122663, 60.136137689862935, 51.00308152607509, 47.88575833184378, 44.12873533793858, 46.588421957833425, 48.95155988420759, 48.51200641904558, 51.97939028058733, 51.0347444670541, 49.419732979365754, 52.95142936706543, 56.10046066556658, 59.54131630488804, 59.911321776253835, 58.682498114449636, 56.597552163260325, 53.500020912715364, 49.76339088167463, 48.4765636580331, 52.62991884776524, 54.51817866734096, 49.23716558728899, 45.28228916440691, 42.14078276497977, 43.31214482443673, 44.9162962777274, 45.23416594096592, 51.64493874141148, 54.09075675691877, 58.106631415230886, 56.777340275900706, 57.78108399254935, 49.057981967926025, 51.04857833044869, 59.14164202553885, 53.43964801515852, 51.27831704275948, 53.72996807098389, 56.07455430712019, 50.32708781106131, 53.335643904549734, 51.96520553316389, 44.95223930903843, 43.42795739855085, 54.85293245315552, 53.25359262738909, 54.253893511635916, 52.930063656398225, 53.68096937452044, 47.53787592479161, 49.25589445659092, 46.513200759887695, 47.412790979657856, 48.508303029196604, 53.259307520730154, 54.2703537940979, 55.59844289507185, 49.90933779307774, 56.17805119923183, 49.547882080078125, 52.9487612588065, 50.40393488747733, 56.88931049619402, 55.4211630821228, 57.7945739201137, 55.03175129209246, 59.2961699622018, 56.30021442685808, 48.26789535794939, 28.321371623447963, 13.761930431638445, 11.015298843383789, 5.95116205726351, 1.8100294002464838, 0.5267129710742405, 0.13634253319885048, 0.06153823395392724, 0.020791605580598116, 0.05122836592740246, 0.14431458685014928, 0.09397429773317915, 0.2790533075375216, 0.09551048065934863, 0.37584803785596577, 0.9014265526618276, 10.125404834747314, 66.14566939217704, 43.79125785827637, 27.62504574230739, 92.22025067465646, 62.77136012486049, 60.89297716958182, 34.222289085388184, 0.3665418215095997, 7.363401225634983, 37.01428025109427, 27.509806394577026, 39.35574674606323, 45.071814332689556, 46.20079585484096, 21.96099931853158, 41.16512714113508, 98.11524827139718, 83.21101488385881, 133.94060489109583, 82.05148560660226, 64.1543504170009, 39.42153923852103, 21.42893406323024, 6.674162941319602, 58.693775040762766, 36.36450556346348, 44.93296848024641, 68.97938101632255, 87.00722571781704, 45.857120582035606, 1.1660963020154407, 0.4658840979848589, 0.44549545060311047, 0.31311476124184473, 0.21589492873421737, 1.0361416467598505, 0.6312926965100425, 0.7579686705555234, 0.4754408566015107, 0.18552949598857335, 8.568930183138166, 75.9619037083217, 81.41646889277867, 80.186158316476, 76.92680699484688, 77.10574395315987, 73.75209862845284, 79.13993331364223, 77.74197660173688, 72.51943956102643, 71.80316366468156, 67.14723137446812, 62.42066369737898, 66.59778867449079, 70.15361962999616, 70.9307895387922, 70.6211222239903, 73.26289681025914, 69.89604990822929, 68.90365954807827, 59.38696902138846, 60.352831159319194, 61.25738934108189, 62.99022143227713, 67.8668076651437, 68.47707489558628, 67.59420898982457, 63.090511730739046, 65.99108586992536, 64.76981489998954, 66.12718718392509, 63.00702217647007, 59.649006434849326, 58.375901903424946, 56.77051019668579, 60.74927452632359, 65.49187864576066, 61.98274653298514, 68.69502598898751, 64.67857810429165, 63.3158209664481, 64.2979210444859, 63.808545521327424, 61.41404342651367, 59.71945422036307, 59.63321317945208, 65.6421890258789, 64.61446707589286, 65.069977079119, 60.753637995038716, 65.16987827845982, 52.992534909929546, 51.69940219606672, 44.52263566425869, 50.264741625104634, 51.71144689832415, 51.66820478439331, 53.32912302017212, 53.694070202963694, 50.708755833762034, 56.77176087243216, 57.48669229234968, 62.05946854182652, 60.94592939104353, 63.940596035548616, 57.830270290374756, 55.323561736515586, 52.88803400312151, 50.200547218322754, 53.94304152897426, 54.479713439941406, 49.54607902254377, 47.45420571735927, 44.56550257546561, 44.66586235591343, 45.65418107169015, 48.87378869737898, 53.309532574244905, 58.12361281258719, 62.16102341243199, 58.00005647114345, 61.77799006870815, 51.463080065590994, 53.74504566192627, 61.864363125392366, 54.67018093381609, 53.80242388589041, 55.20830501828875, 58.68864727020264, 52.36236456462315, 56.588196413857595, 52.87088932309832, 48.6214405468532, 44.84627233232771, 56.38278681891305, 57.489919730595176, 57.44705629348755, 57.61973639896938, 57.59922184262957, 52.57541370391846, 54.93284715924944, 54.593566622052876, 54.698790141514365, 52.56980650765555, 57.48079674584525, 57.33036477225167, 60.899432046072825, 56.07849393572126, 64.05599866594586, 53.127149309430806, 57.21047707966396, 54.851608821323936, 60.09810325077602, 59.91529614584786, 61.02678557804653, 59.63440826960972, 63.43799114227295, 61.41418239048549, 59.358488355364116, 42.991749491010395, 30.277671677725657, 14.787322998046875, 7.640674301556178, 2.431256111179079, 0.3914004676043987, 0.1989564283617905, 0.1337178104690143, 0.08272519814116613, 0.11977462151220866, 0.30423884466290474, 0.09661588205822877, 0.5491021839635712, 0.18961994935359272, 0.6653497804488454, 1.1163730387176787, 12.660440325737, 74.81431838444301, 53.570201192583355, 41.472234044756206, 93.25025163378034, 67.27286175319126, 71.34254673549107, 40.188602992466514, 0.5787328311375209, 12.57969878401075, 46.28983701978411, 36.77434505735125, 51.9872591154916, 40.95408603123256, 38.60460131508963, 21.490965843200684], [26.341135025024414, 50.48070900780814, 54.34772545950753, 34.89750460215977, 20.312634740556987, 37.32532330921718, 15.263347557612828, 11.047360437256948, 8.628325121743337, 14.6881548336574, 27.71182700565883, 37.32985006059919, 73.74133586883545, 58.8172584261213, 36.66645342963082, 0.8961147091218403, 0.1626680770090648, 0.1413812121110303, 0.08904797743473734, 0.06668419603790555, 0.029198369476944208, 0.06451179153685059, 0.407610289220299, 0.11470416001975536, 0.11041283993316547, 11.461868252073016, 76.37691961015973, 63.6955052784511, 62.077540806361604, 54.028327192579, 60.57802922385079, 60.746905190604075, 63.6099590573992, 66.0056631905692, 67.12829753330776, 64.61326503753662, 60.37572547367641, 56.480165822165354, 57.1080641065325, 65.0577621459961, 67.38976519448417, 65.80934878758022, 66.65449292319161, 64.12494564056396, 60.44602039882115, 56.22752237319946, 49.65114620753697, 54.269002369471956, 58.10963303702218, 57.83758674349104, 60.44285202026367, 59.48275688716343, 59.648610387529644, 60.69309834071568, 59.9261839730399, 59.26730019705636, 58.5826872416905, 51.541837896619526, 53.27415234701974, 56.404996735709055, 54.74977254867554, 57.20551259177071, 58.67256219046456, 56.77785791669573, 58.089007309504915, 55.32019533429827, 57.444367340632844, 54.78859908240182, 53.993190152304514, 49.53511129106794, 56.538992745535715, 60.12312371390206, 60.04130867549351, 58.36538233075823, 56.45026077542986, 52.16168321881975, 47.87639910834176, 44.103145122528076, 43.85585526057652, 45.82405757904053, 50.74378170285906, 55.56517144611904, 52.62338754108974, 48.687868799482075, 46.84756197248186, 46.02252244949341, 54.981557505471365, 54.38741704395839, 57.11370256968907, 54.62829719270979, 53.97125816345215, 49.85497508730207, 46.2533346584865, 48.01577302387783, 51.88458558491298, 54.343931743076865, 54.93811389378139, 50.44352919714791, 40.92566442489624, 39.71087612424578, 46.5864451953343, 45.11662326540266, 49.37286043167114, 56.07409225191389, 52.87142433438982, 56.56328017371041, 54.719662530081614, 56.888421126774375, 47.7170386995588, 52.06992878232683, 58.25074052810669, 52.52573408399309, 52.72493893759591, 55.48538180759975, 54.44402401787894, 51.700871740068706, 50.493726457868306, 49.49215405327933, 43.94315242767334, 50.17314004898071, 49.90240001678467, 50.27818291527884, 47.314064025878906, 47.82609762464251, 45.3274941444397, 42.877913679395405, 38.11728940691267, 41.07586363383702, 47.32484415599278, 52.30168942042759, 49.023362568446565, 50.516200406210764, 45.120083468300955, 50.64638532911028, 49.98064368111746, 49.93953119005476, 47.03446156638009, 51.61576672962734, 52.35880013874599, 54.31450612204415, 50.13743325642177, 50.578643866947715, 24.74327516555786, 20.63527955327715, 16.75667003222874, 11.603125997952052, 2.807805699961526, 0.7940738988774163, 0.21724864680852207, 0.3035282827913761, 0.1580554095229932, 0.1542044925902571, 0.15778315413211072, 0.22277000839156763, 0.13282308062272413, 0.07075884632234063, 0.14374464457588537, 0.08176986154701028, 0.1845095900020429, 0.361419859209231, 8.292930364608765, 56.26575831004551, 41.93429272515433, 24.425316912787302, 35.67274291174752, 38.68641635349819, 56.710185936519075, 19.81974516596113, 0.6895646325179509, 2.6058578278337206, 6.686690977641514, 8.973699229104177, 1.6225376895495822, 2.3194272433008467, 4.264802558081491, 2.185080783707755, 22.62352568762643, 62.45486967904227, 69.20315470014299, 87.14693314688546, 48.8936779158456, 49.71856457846505, 27.405086619513376, 11.238193580082484, 9.551114508083888, 33.456055641174316, 36.98160982131958, 35.03438411440168, 80.8297004699707, 65.18233639853341, 42.14546932492937, 1.123585160289492, 0.05962901283055544, 0.24616202818495886, 0.01854094902851752, 0.08087414782494307, 0.1257443047527756, 0.2704086628343378, 0.569771446287632, 0.23244815692305565, 0.14573932039950574, 12.509840726852417, 79.15545558929443, 74.9075562613351, 70.91469751085553, 64.44652911594936, 67.03123119899205, 67.1640738078526, 69.40411744798932, 70.48785577501569, 68.24032197679792, 64.88914326259068, 62.164622579302105, 57.459358079092844, 59.117344175066265, 66.57363673618862, 67.08577455793107, 65.43841920580182, 66.77557223183769, 64.95494270324707, 64.61837891169957, 58.451859610421316, 52.61022070475987, 55.94446665900094, 58.78809683663504, 61.20515973227364, 62.43115547725132, 61.101833071027485, 62.827022143772666, 62.86445903778076, 61.09291158403669, 62.21172441755022, 59.948237555367605, 55.13138845988682, 55.02824592590332, 57.95288167681013, 57.57595579964774, 60.28594085148403, 61.77128505706787, 60.87883758544922, 60.40804154532296, 58.01581498554775, 59.16546739850725, 57.92465462003435, 56.482910360608784, 54.24185228347778, 61.63205010550362, 61.904023442949565, 62.11292103358677, 61.30158683231899, 58.705857958112446, 52.60537781034197, 49.78965507234846, 46.19519213267735, 45.76116248539516, 49.366867610386436, 54.21343067714146, 58.671693665640696, 55.291447162628174, 52.69621508462088, 50.58260086604527, 50.857638359069824, 56.80261434827532, 58.29165499550955, 59.17251982007708, 57.514120306287495, 54.877883434295654, 52.78995670591082, 50.039838859013145, 49.977822712489534, 52.257127148764475, 57.80099752971104, 58.247752802712576, 54.336684771946494, 45.30900846208845, 40.949635710035054, 47.540550981249126, 49.254754952022004, 51.1255886895316, 57.15418277468, 54.63119806562151, 56.39230932508196, 55.929545402526855, 56.30721126283918, 51.084347656794954, 52.89453056880406, 59.28328105381557, 55.779787404196604, 54.31835542406355, 54.52053410666329, 56.073015281132285, 54.46490682874407, 54.58449922289167, 51.39246899741036, 49.747528144291465, 51.647113527570454, 51.33756085804531, 54.01916251863752, 51.09347064154488, 52.50815861565726, 49.26631328037807, 44.97357027871268, 44.350949151175364, 46.5643117087228, 53.97291530881609, 55.484843322208945, 53.97732046672276, 54.66739470618111, 51.01454952784947, 52.22164617265974, 53.12377595901489, 50.869696957724436, 49.60459327697754, 54.168889250074116, 55.10475948878697, 57.707224641527446, 53.73575939450945, 54.37814814703805, 28.47915826525007, 22.09122940472194, 15.638182026999337, 11.403069121497017, 6.736553422042301, 3.1214858165809085, 0.8205334533538137, 0.15691586424197468, 0.3262321187981537, 0.04334418934636882, 0.1288343532277005, 0.19728168179946287, 0.0973683570378593, 0.16173203795083932, 0.2753638955099242, 0.15269315083112034, 0.07565005921891757, 0.5043115988373756, 10.368260008948189, 65.37188325609479, 47.826816763196675, 29.66663667133876, 46.97867100579398, 42.59140123639788, 65.50376006535122, 24.632673740386963, 0.587806798517704, 11.470040202140808, 18.036241599491664, 14.853581019810267, 14.795447179249354, 11.355843084199087, 14.01125351020268, 7.653294835771833, 40.128629616328645, 94.56827626909528, 98.17259870256696, 143.3150588444301, 71.86282784598214, 62.358053479875835, 33.74255766187395, 19.697512456348964, 16.666473729269846, 61.835764339991975, 52.658851146698, 55.62790673119681, 88.96983473641532, 76.43943255288261, 49.31979703903198, 1.7745643832853861, 0.3582906999758312, 0.5875710483108247, 0.20017475155847414, 0.3690916746854782, 0.2434750837939126, 0.6710495831710952, 0.666498133114406, 0.45437237141387804, 0.20596456873629773, 14.445063420704432, 85.86276013510567, 79.26314571925572, 77.19051892416817, 71.14623928070068, 74.40952328273228, 73.84802545819963, 75.22945240565709, 76.66150392804826, 74.01615101950509, 69.72383185795375, 67.6821106501988, 60.95146015712193, 62.86392402648926, 68.60954230172294, 72.83048956734794, 69.06030668531145, 70.17369992392403, 69.44543838500977, 67.32382678985596, 62.326411383492605, 54.765145438058035, 61.043871198381694, 62.110197339739116, 62.63174302237374, 66.2661303111485, 64.5659408569336, 64.37443460736955, 67.68876007625035, 62.78469371795654, 64.56281416756767, 63.88884585244315, 62.93770694732666, 58.46796553475516, 63.278335435049875, 60.398418290274485, 64.34351512363979, 63.874351910182405, 62.97457408905029, 61.79773684910366, 62.361617905753, 63.84509999411446, 61.48033618927002, 58.3624849319458, 55.442525318690706, 63.923058782305034, 65.92252104622978, 63.82430403573172, 63.65162740434919, 61.18019485473633, 58.408655711582725, 52.818482535226, 49.257346630096436, 48.60550137928554, 52.91854701723371, 55.263425077710835, 60.72561591012137, 56.89973626817976, 53.86320325306484, 53.41069834572928, 52.366863523210796, 59.80440289633614, 61.59291785103934, 62.02457468850272, 60.502460615975515, 56.256148951394216, 54.075501986912315, 50.70256151471819, 51.770937374659944, 55.56938205446516, 60.165771756853374, 59.42607348305838, 54.06940841674805, 44.65832356044224, 42.355238914489746, 49.79063476834978, 51.497425011226106, 53.12911217553275, 60.465621267046245, 55.13304907935006, 60.387294224330354, 57.88337189810616, 61.05099310193743, 50.95340538024902, 55.65738098961966, 61.09089660644531, 58.120211669376914, 57.75632061277117, 60.70181138174874, 60.26909841809954, 57.16567856924874, 56.4779771396092, 54.33957869665963, 47.08606583731515, 56.092258317129954, 54.70930624008179, 57.98492676871163, 53.06907973970686, 56.81391906738281, 52.91941554205758, 53.70716755730765, 50.07555259977068, 52.18336854662214, 58.729454040527344, 60.46840054648263, 56.42918341500418, 58.383676937648225, 57.340926034109934, 59.59285109383719, 57.29457460130964, 55.900321279253276, 52.166922160557334, 58.78472696031843, 59.18651349203927, 62.449206897190635, 58.86039284297398, 62.351751463753835, 40.601534434727256, 41.613004548209055, 26.474653346197947, 17.5837436403547, 9.088020546095711, 5.068159358842032, 1.3564053986753737, 0.7336563265749386, 0.45824466219970156, 0.5636604513440813, 0.20544455306870596, 0.41432591314826694, 0.2138187608548573, 0.23596508534891264, 0.734518283179828, 0.30324470943638254, 0.4510149801416056, 0.6005122853176934, 13.926062515803746, 72.19526440756661, 56.575599329812185, 36.53999274117606, 48.464723927634104, 48.97864743641445, 76.79912689753941, 32.23563929966518, 0.6309741650308881, 19.566498960767472, 32.90676927566528, 32.61410420281546, 17.613683428083146, 7.9468362501689365, 5.9574271610804965, 4.724467149802616], [40.024674143110005, 55.62978969301496, 62.52812453678676, 15.769966772624425, 15.052837984902517, 34.27602992738996, 16.802350963865006, 8.77773310456957, 9.367902670587812, 28.613103900636943, 22.727519375937327, 38.18614605494908, 97.8529051371983, 56.24664381572178, 37.54998288835798, 2.558763154915401, 0.3720968248588698, 0.23613032219665392, 0.06862775781857115, 0.10133850614407233, 0.04193375252985528, 0.041816216693925004, 0.03035448119044304, 0.10596359760633536, 0.05500745314306446, 11.057564735412598, 59.935265268598286, 66.63515608651298, 62.77459103720528, 55.44524553843907, 56.343546867370605, 57.74773958751133, 60.322655132838655, 64.01234313419887, 62.921684401375906, 62.628345353262766, 60.03090722220284, 56.676330838884624, 51.88108369282314, 62.64893981388637, 65.14836665562221, 67.64407621111188, 62.85867118835449, 65.29572405133928, 60.7025339944022, 62.15507575443813, 52.46840449741909, 49.93088068280901, 53.979950359889436, 54.1103333064488, 56.42184959139143, 57.206638199942454, 59.097778047834126, 59.04740360804966, 59.219913482666016, 58.45462499346052, 51.592994008745464, 47.61713750021798, 51.14298003060477, 56.105730874197825, 56.070632049015586, 59.87662247249058, 56.537123680114746, 58.49586950029646, 56.231201444353374, 56.675653389522004, 56.4513829095023, 56.88427652631487, 52.32700865609305, 54.124254022325786, 58.981548581804546, 58.033209800720215, 55.85148239135742, 56.83384650094168, 54.36457136699131, 53.27891533715384, 45.074267046792166, 43.11316926138741, 44.849649156842915, 52.93078974315098, 57.53596544265747, 58.745087487357004, 52.86629656382969, 49.17214781897408, 47.47357382093157, 45.551184449877056, 48.91645411082676, 51.366524423871724, 55.329231466565815, 51.226570333753315, 51.38205017362322, 49.47735439028059, 45.22792298453194, 45.11779751096453, 45.49520976202828, 54.077648980276926, 52.91556624003819, 55.33194126401629, 51.3056686265128, 43.484949997493196, 41.58094208581107, 47.75190128598894, 47.0718081338065, 52.24446405683245, 56.481093406677246, 52.44722638811384, 54.62105022157942, 55.74361855643136, 52.721874782017295, 47.12644181932722, 53.39481823784964, 53.3921605518886, 52.5368720463344, 50.187616620744976, 52.277061530521934, 52.187537465776714, 52.60168136869158, 49.502972398485454, 47.67928218841553, 49.35130017144339, 49.16313253130232, 48.38453129359654, 47.36999355043684, 45.36033827917916, 41.885658809116904, 36.923561096191406, 38.88073662349156, 44.3998783656529, 49.564099175589426, 49.9922263281686, 49.60726833343506, 51.9367596081325, 46.32234069279262, 51.474561963762554, 49.302065236227854, 48.538145542144775, 48.79225158691406, 54.34315701893398, 48.99138695853097, 53.18086930683681, 45.65299640383039, 23.9587436403547, 23.514864921569824, 16.80452922412327, 9.656068784849984, 11.489036577088491, 5.165778943470546, 2.5202786028385162, 0.6873148275273187, 0.1284349946571248, 0.05087316980851548, 0.22756311190979822, 0.22367635475737707, 0.16170446228768143, 0.04565698613545724, 0.249664517385619, 0.24488806511674607, 0.03175741680232542, 0.20610710180231503, 0.43683756089636255, 11.863678233964102, 55.97996153150286, 47.82767833982195, 28.696930442537578, 28.270020961761475, 38.59584658486502, 46.335754190172466, 11.882368888173785, 0.21236837868179592, 5.804994106292725, 5.8449592760631015, 4.97369121653693, 0.8043879025748798, 0.37107628104942186, 0.6840702901993478, 1.8660027853080203, 42.050956453595845, 63.49208981650216, 78.71367522648403, 84.89429937090192, 41.04346765790667, 53.02416658401489, 20.81131911277771, 11.913839885166713, 8.56086071899959, 47.353439467293875, 35.86143166678292, 42.40012427738735, 102.55550847734723, 62.22459248134068, 45.19223703656878, 2.892071498291833, 0.17708351276814938, 0.27358325677258627, 0.10249975776033741, 0.07403788037065949, 0.0622150929910796, 0.08250453855310168, 0.11371575841414076, 0.05298218896080341, 0.03924048419243523, 12.546182411057607, 74.26981585366386, 72.85190391540527, 71.31234291621617, 64.75687735421317, 65.35568700517926, 64.83068806784493, 65.98071915762765, 68.58896868569511, 66.81904016222272, 63.742655754089355, 62.441063608442036, 55.00644595282418, 52.23282235009329, 65.49899360111782, 66.14571802956718, 67.80542033059257, 63.103588240487234, 66.83997508457729, 66.13430908748082, 65.38172885349819, 56.754873275756836, 52.736976691654746, 54.79979957853045, 58.63736956460135, 54.857570375714985, 59.373288018362864, 61.10163157326834, 62.92481803894043, 60.83720397949219, 60.51122229439871, 56.55133622033255, 50.68583025251116, 52.48194653647286, 59.482451166425435, 56.6842691557748, 60.86189092908587, 60.20855876377651, 62.71095943450928, 59.9625369480678, 58.0984012739999, 60.42994226728167, 59.038718359810964, 54.878321170806885, 57.171251024518696, 61.33519526890346, 59.854054723467144, 55.45608820234026, 60.32039696829659, 58.15652642931257, 55.757775511060444, 48.59658684049334, 45.080655915396555, 48.22021681921822, 57.60700382505144, 58.78978524889265, 60.50740078517369, 55.09966993331909, 49.878515584128245, 49.127060958317344, 48.43196317127773, 52.22639874049595, 54.31406838553292, 56.38878311429705, 54.409602642059326, 54.0493038041251, 52.33444322858538, 47.23533746174404, 44.34649535587856, 46.31054612568447, 55.162450381687705, 55.57923807416643, 56.360302448272705, 52.84356900623867, 46.825953074863975, 42.26405075618199, 48.402589661734446, 50.1706143787929, 53.71812834058489, 58.55581855773926, 54.66237115859985, 54.92097616195679, 56.46429961068289, 55.74348306655884, 49.77132225036621, 55.176850523267476, 56.44441039221627, 55.25627885546003, 53.12119817733765, 54.34770461491176, 53.92839125224522, 52.01096289498465, 51.84017269951956, 50.072828905923025, 53.819089140210835, 51.12147535596575, 52.739266123090474, 49.69838006155831, 50.92259359359741, 45.48207766669137, 42.634789262499126, 47.16408715929304, 49.541639123644146, 53.64790984562465, 53.27907167162214, 51.62170049122402, 54.98354121616909, 50.75075422014509, 53.06600863592965, 52.250592367989675, 52.11424786703927, 52.29083286012922, 55.39842510223389, 55.17404692513602, 55.509488582611084, 52.93288115092686, 28.35833603995187, 19.85622147151402, 21.863625526428223, 13.660055075372968, 15.866378239222936, 8.334132313728333, 2.8189282459872107, 0.7865791810410363, 0.2619823164173535, 0.23709498186196598, 0.1808489885713373, 0.24546359851956367, 0.2648435900253909, 0.03959479143044778, 0.18163794837892056, 0.3222470283508301, 0.04803982809452074, 0.20432437317711966, 0.4453841708600521, 14.925873552049909, 62.31276512145996, 54.83236925942557, 33.78816563742501, 30.67459794453212, 45.22983373914446, 58.27770301273891, 13.615436349596296, 0.45633016207388466, 11.578162857464381, 15.69675534112113, 7.960566759109497, 1.9990610054561069, 1.1366178095340729, 1.9381628675120217, 0.6695741223437446, 64.06402383531842, 88.58095795767647, 136.08536093575614, 119.97978401184082, 62.71102891649519, 67.75503894260952, 37.99103021621704, 14.990420579910278, 28.511780057634624, 71.60313892364502, 43.03004101344517, 59.189959798540386, 107.64815589359829, 73.4418476649693, 51.881413732256206, 3.7366721544946944, 0.6819654745715005, 0.8516046032309532, 0.21182492641466005, 0.4212107094270842, 0.13247690562691006, 0.2956761127071721, 0.1769653255386012, 0.170799586389746, 0.2489299082330295, 15.196865456444876, 80.5889731815883, 77.85609381539481, 77.42379079546247, 70.42609323774064, 72.30654675619942, 70.42852510724748, 70.55943611689976, 74.64011314937046, 72.68041542598179, 69.40606294359479, 66.78753702981132, 59.88855947766985, 55.1459310395377, 70.28499616895402, 69.1870835168021, 71.5231443132673, 65.72318417685372, 72.30993052891323, 70.32048756735665, 71.5234500340053, 56.80103710719517, 56.36150448662894, 57.611756392887656, 60.54478209359305, 61.279484612601145, 63.29266956874302, 64.07070800236293, 66.01823943001884, 66.58157852717808, 64.45946666172573, 58.92112009865897, 50.75159842627389, 55.76252807889666, 64.4474879673549, 61.077382360185894, 66.59767055511475, 62.382809911455425, 65.65384115491594, 61.80276039668492, 60.89890398297991, 61.63712229047503, 61.66070447649275, 58.31327778952462, 59.56105613708496, 65.8221195765904, 62.7382241657802, 58.63788373129708, 63.43734495980399, 60.17424161093575, 59.57503591264997, 51.40402037756783, 48.04762009211949, 51.10063770839146, 58.94645323072161, 60.80644430433001, 64.47676767621721, 58.40536226545061, 54.099532331739155, 51.719864640917095, 51.071514333997456, 55.16707093375069, 55.2737466267177, 59.40182426997593, 57.574437618255615, 58.474489893232075, 54.973393372126985, 49.614921774183, 49.98670251028878, 48.59872688565935, 59.2669597353254, 56.91319145475115, 60.70748111179897, 53.80292763028826, 47.256102153233115, 46.32936879566738, 52.163194452013286, 50.3656815801348, 56.75324739728655, 58.796761240277974, 57.69072266987392, 57.22631549835205, 58.06238528660366, 57.30561181477138, 52.39719588415963, 57.278027466365266, 56.70790345328194, 56.94940199170794, 56.62050206320626, 56.37305586678641, 57.28727551868984, 53.89470985957554, 54.664799554007395, 53.64673907416207, 55.67143719536917, 55.05333239691598, 55.488557134355815, 54.14017234529768, 54.24161604472569, 54.2678211757115, 51.26590061187744, 50.6301543372018, 55.46864707129342, 55.85649899074009, 55.33073575156075, 55.03287690026419, 59.517386708940776, 53.90282188143049, 57.81300401687622, 55.98036800112043, 55.25952366420201, 55.25452790941511, 62.97116947174072, 59.51403072902134, 59.599305970328196, 59.35846056256975, 42.239259583609446, 31.55063029697963, 23.79850081035069, 17.00690766743251, 19.066273825509207, 14.627715928213936, 5.892132767609187, 1.4857974669763019, 1.4373333475419452, 0.5159605794719287, 0.4478927691067968, 0.6387869800840105, 1.408512111221041, 0.10546058602631092, 0.5686506150024278, 0.3753713534346649, 0.20573778876236506, 0.35813637397118975, 0.8536913969687053, 20.994610854557582, 71.71854155404228, 63.952755383082796, 42.820330483572825, 44.26972123554775, 48.73690223693848, 73.65732519967216, 19.092293092182704, 0.45460003348333494, 24.622972318104335, 35.36150530406407, 19.405384131840297, 2.3330626487731934, 0.7593371399811336, 0.580555647611618, 1.9686661107199532], [48.19250740323748, 62.76284163338797, 30.5933735030038, 31.09260504586356, 21.30826817240034, 26.67512798309326, 16.18675967625209, 8.805915866579328, 11.485189880643572, 33.237909998212544, 24.126655544553483, 47.28125810623169, 100.59566484178815, 50.99751949310303, 38.14013160978045, 5.667351160730634, 0.6478092702371734, 0.32953737143959316, 0.19623535365930625, 0.024070034036412835, 0.022685642786590115, 0.06541259427155767, 0.031754984254283566, 0.05521292033206139, 0.020863482795123543, 10.512194548334394, 41.932712009974885, 66.11470821925572, 64.97965744563511, 58.05668428965977, 59.49901567186628, 55.90866953986031, 58.00153643744332, 56.847079345158164, 58.63452775137765, 58.18153994424002, 61.122191292899, 57.88419525963919, 52.64100469861712, 57.03717163630894, 64.48690509796143, 66.03036403656006, 64.04584039960588, 62.17178617204939, 63.40902410234724, 61.89053698948452, 58.65597684042794, 53.505596842084614, 48.85914189474923, 50.94904885973249, 51.64140905652727, 55.50506605420794, 58.55440807342529, 58.73123277936663, 59.10357979365757, 53.53610290799822, 48.80292401994978, 49.58521127700806, 54.770318371909006, 59.53849533626011, 56.313388211386545, 55.31819077900478, 58.0067024230957, 54.53103630883353, 56.89311810902187, 58.30060427529471, 58.59235218593052, 51.49273150307791, 51.233299664088655, 56.518360069819856, 58.094548497881206, 57.48072031566075, 56.0248191016061, 56.22078262056623, 57.60935926437378, 47.578297070094514, 44.154148374285015, 41.018238748822895, 50.39214726856777, 56.112984793526785, 55.26827144622803, 54.98828683580671, 46.21846859795706, 45.660132203783306, 43.81132425580706, 45.30269602366856, 52.06026383808681, 51.449267046792166, 51.53004680361067, 50.92325367246355, 51.168677943093435, 49.27447393962315, 43.30184064592634, 39.72586686270577, 42.79945462090628, 52.39974239894322, 58.682067326136995, 53.085171767643516, 51.334614821842735, 47.20787818091256, 42.61628968375069, 44.45050641468593, 49.97165618624006, 49.03364242826189, 51.36137580871582, 55.90359040669033, 53.47946466718401, 54.53480223246983, 54.31651415143694, 49.842610767909456, 50.426210812159944, 54.23097487858364, 55.16518449783325, 54.835495948791504, 50.09666470118931, 53.357263224465505, 51.120443548474995, 47.68911388942173, 50.93695552008492, 48.88102872031075, 47.24646847588675, 47.91712597438267, 44.527322224208284, 40.02259315763201, 36.78309283937727, 37.7863883972168, 44.21069976261684, 50.28904642377581, 52.08221319743565, 48.79639271327427, 50.6502172606332, 47.1174612726484, 48.629333700452534, 52.47812850134713, 50.70928737095424, 48.91069058009556, 50.00140142440796, 51.688069684164866, 51.905440602983745, 52.9675144468035, 25.570543323244365, 23.691795587539673, 24.720627512250626, 10.790921534810748, 1.242606173668589, 15.531652246202741, 14.019816296441213, 4.316361231463296, 0.9296704913888658, 1.0707167514732905, 0.03733948012813926, 0.24307523667812347, 0.3566109729664666, 0.2520597460014479, 0.02702965959906578, 0.13634532876312733, 0.1210503623421703, 0.004305825893035424, 0.14773695463580744, 0.24877862206527165, 15.248928308486938, 53.49877718516758, 51.18116733006069, 30.723037311008998, 36.459171295166016, 42.21861301149641, 32.238574913569856, 10.049279502459935, 0.19358306883701257, 9.842993565968104, 7.752200705664499, 2.8897657820156644, 0.4039491313908781, 0.25601422094873016, 0.652908162346908, 6.233982835497175, 57.99099602018084, 62.46711240495954, 82.25232328687395, 69.01915250505719, 34.47864982060024, 44.4419184412275, 20.68759948866708, 10.806858096803937, 14.109310831342425, 53.22656413487026, 33.234161445072715, 55.71362665721348, 111.52570928846086, 57.57662630081177, 47.24962643214634, 6.852276538099561, 0.4890603572130203, 0.23596758235778126, 0.06582059059292078, 0.2047092110982963, 0.044184018924300156, 0.08290215328867946, 0.06707098135458571, 0.14761741033622197, 0.014816371923578637, 15.436505351747785, 59.014538628714426, 73.45980875832694, 71.23851135798863, 64.69103622436523, 65.51887934548515, 64.71666812896729, 64.42042473384312, 63.907418387276785, 62.44118867601667, 62.487401144845144, 62.42171287536621, 58.94110311780657, 53.81584433146885, 56.79621853147234, 66.03895201001848, 65.73748356955392, 65.44497830527169, 64.16446004595075, 65.57414531707764, 64.13757051740373, 61.56936345781599, 54.92305367333548, 50.59376662118094, 51.95742702484131, 53.93575634275164, 58.41138635362898, 61.144244875226704, 61.53317723955427, 62.18445273808071, 56.19439683641706, 49.39145381110055, 52.3991448538644, 56.3148820740836, 60.36528927939278, 58.71584251948765, 58.835358483450754, 60.8016847882952, 58.16409649167742, 60.150937352861675, 60.60944897787911, 61.111727305821006, 53.05500616346087, 53.478387696402415, 60.533845629010884, 59.28697749546596, 59.369334493364605, 57.375663552965435, 60.440197808401926, 59.054205894470215, 48.71954563685826, 45.95646939958845, 44.13188982009888, 53.37062461035592, 57.361576080322266, 55.57354749952044, 55.766040393284385, 48.27472196306501, 46.513707978384836, 45.53555447714669, 47.997874464307515, 54.02090651648385, 54.86508137839181, 52.05009862354824, 54.78419392449515, 52.004765101841514, 51.59640210015433, 43.209780488695415, 41.83219242095947, 44.169215542929514, 51.927650519779746, 60.07035909380232, 55.38226359231131, 54.84774909700666, 50.70481620516096, 46.272091320582796, 45.582347120557515, 51.11983905519758, 51.56355449131557, 51.08970124380929, 58.31070695604597, 53.84559651783535, 56.268273557935444, 57.44516290937151, 52.75228704724993, 50.39728546142578, 53.81612573351179, 58.02464614595686, 57.31842776707241, 52.95337833677019, 54.00622844696045, 52.296297618321006, 51.04568440573556, 53.74415976660592, 51.423944337027415, 51.88120181219918, 50.70729323795864, 48.9913626398359, 44.31180994851248, 41.269113881247385, 46.73394155502319, 49.327978542872835, 53.998522894723074, 53.74532011577061, 51.878016063145225, 52.84200913565499, 50.6066346849714, 51.53269059317452, 55.22382034574236, 53.604827540261404, 51.75078412464687, 54.014969280787874, 54.91165862764631, 55.71914005279541, 56.0799217905317, 30.553205966949463, 26.594947508403234, 28.99701271738325, 15.367188385554723, 7.452577880450657, 17.890110560825892, 14.961225986480713, 4.357486316135951, 0.6063817760774067, 1.472023640360151, 0.03892854807366218, 0.18689341922955854, 0.22318679174142225, 0.2290576531418732, 0.07370575783508164, 0.04775538282202823, 0.059497438105089326, 0.05697305713381086, 0.06301066851509468, 0.3403740370912211, 19.085589817592076, 60.56013066428048, 56.69221789496285, 37.20638057163784, 38.12615530831473, 47.70826659883772, 41.69755022866385, 11.439564534596034, 0.32025984355381554, 14.398747597421918, 18.72722257886614, 6.043718576431274, 0.5642173928873879, 0.15262653226298944, 0.21524348083351338, 3.643323540687561, 76.11790466308594, 92.56290108816964, 131.99281638009208, 93.95736285618374, 50.927148137773784, 52.36921201433454, 43.574012007032124, 13.5886675459998, 44.10072020121983, 71.04253741673061, 41.81736843926566, 66.89492143903459, 111.6647288458688, 65.01050049918038, 54.786952359335764, 7.76363570349557, 0.737755438046796, 0.650256773190839, 0.48099317295210703, 0.5548438930085727, 0.14296724700501987, 0.25083043053746223, 0.1721630889390196, 0.2001300768128463, 0.1581969383571829, 16.070267915725708, 67.57910360608781, 75.148207119533, 72.658737046378, 69.6348601749965, 70.94811139787946, 70.1854145867484, 70.49588789258684, 69.14843068804059, 67.22854614257812, 68.50879342215401, 67.69589587620327, 65.50587926592145, 57.52307653427124, 61.67398943219866, 69.92629541669572, 71.64209052494594, 70.80993257250104, 66.39408138820103, 69.65366200038365, 69.65655939919608, 65.73705278124127, 57.09214578356062, 54.79381717954363, 54.85072292600359, 55.63873897280012, 61.797521454947336, 65.56753758021763, 63.859732900347026, 64.57379926953996, 59.19855472019741, 49.773392813546316, 55.16229057312012, 60.27469866616385, 62.664934567042756, 61.60600825718471, 61.72672625950405, 61.96329157693045, 63.747088704790386, 60.06425857543945, 63.29141889299665, 64.59815270560128, 57.69883121762957, 55.125604084559846, 63.97598321097237, 61.9991512298584, 63.04939923967634, 61.208182198660715, 62.51344299316406, 63.94459819793701, 53.894240856170654, 48.22828367778233, 46.310570444379536, 55.98711122785296, 63.49166597638811, 59.595943042210166, 60.0281765801566, 50.40966020311628, 49.266813550676616, 49.30068949290684, 50.48924139567784, 56.391360895974294, 56.47170639038086, 53.720122473580496, 56.514885970524375, 54.78865466799055, 53.518843582698274, 46.467460768563406, 43.97142117364066, 44.83499193191528, 54.17024762289864, 62.548663411821636, 56.82400090353829, 55.40224313735962, 51.2593970979963, 46.481558663504465, 47.296071665627615, 52.741322789873394, 53.434996196201865, 54.77559552873884, 60.55531556265694, 55.726852553231375, 58.765452657427105, 57.32681771687099, 53.097424915858674, 53.54000779560634, 55.91778905051095, 60.26535333905901, 60.99143314361572, 53.294277804238455, 58.379105022975374, 55.02346903937203, 54.288433006831575, 54.79146868841988, 53.84072930472237, 54.221487113407676, 54.740159715924946, 51.2045966557094, 51.43167420795986, 48.189297335488455, 51.231764112200054, 52.293931756700786, 56.79918541227068, 57.306059973580496, 57.35078205381121, 58.44445283072335, 55.60051345825195, 55.54263843808855, 62.03244699750628, 57.27049561909267, 58.319079535348074, 57.34797150748116, 60.30739688873291, 59.523250988551546, 62.48346151624407, 39.899842807224815, 38.386573791503906, 34.594608306884766, 17.594032185418264, 10.437099286488124, 22.472833156585693, 25.353978395462036, 12.919173002243042, 4.071428111621311, 2.4765318759850095, 0.1504716407507658, 0.3946846313774586, 0.8906988054513931, 0.4944680098976408, 0.11060441751033068, 0.37075305410793846, 0.2223253643938473, 0.18382811014141354, 0.29720919472830637, 0.4845529847911426, 25.030711718967982, 70.39326299939836, 66.69393784659249, 43.65214102608817, 55.874612944466726, 54.065263816288535, 58.77438109261649, 14.031469294003077, 0.606764632676329, 27.569117954799108, 38.8642554964338, 14.446794390678406, 1.3875211690153395, 0.36493619052427156, 0.5130144347037587, 9.282253095081874], [55.78734704426357, 55.02307994025094, 11.77742850780487, 38.385826860155376, 23.19703347342355, 18.07174689429147, 8.93996833051954, 4.2964242441313605, 15.819481372833252, 27.072217532566615, 27.689373901912145, 32.542694091796875, 80.42522498539516, 47.55635118484497, 35.99978419712612, 12.550999249730792, 0.7261557461959975, 0.23449502566031047, 0.17963690789682524, 0.10493886723582234, 0.04548399363245283, 0.05005386591489826, 0.0560756572522223, 0.14441445363419397, 0.08811277975993496, 8.037618807383947, 38.272616386413574, 61.62985447474888, 68.3633120400565, 61.05751051221575, 59.06765065874372, 54.56692722865513, 55.852764333997456, 54.894083159310476, 56.58994388580322, 55.08046858651297, 59.233316557747976, 60.58663804190499, 55.27630703789847, 53.60663059779576, 60.25282573699951, 65.4327564239502, 62.420344080243794, 63.28267805916922, 58.85243715558733, 62.76667703901018, 60.133942059108186, 58.08842018672398, 47.02028029305594, 50.54159607206072, 48.62484516416277, 54.04364102227347, 59.18658297402518, 60.78728812081473, 60.01373127528599, 54.65461349487305, 49.94420385360718, 52.43391016551426, 51.34120866230556, 54.29603781018938, 57.99967432022095, 58.70177936553955, 56.59889316558838, 56.90344313212803, 57.37059831619263, 57.33182041985648, 50.13762085778372, 50.287448338099885, 54.09052051816668, 57.89589950016567, 56.01754086358206, 55.89893511363438, 60.30465929848807, 55.586828981127056, 47.80191094534737, 45.40211084910801, 46.70499883379255, 44.56946652276175, 52.72664124625069, 50.530426842825754, 52.5152770451137, 50.08719778060913, 42.94126040594918, 38.690408093588694, 39.14659207207816, 40.914630685533794, 46.66488340922764, 48.19008943012783, 51.04679959160941, 49.89605631147112, 51.15152978897095, 46.148951871054514, 40.22641508919852, 39.34430306298392, 39.74195889064244, 46.04251936503819, 53.66279983520508, 54.694246019635884, 53.2638829095023, 50.65827022280012, 43.7496520451137, 46.935946532658164, 44.705328123910085, 50.97967651912144, 50.30919967378889, 48.50198016847883, 55.6613484110151, 51.758632114955354, 52.98677485329764, 51.03626264844622, 47.52009201049805, 52.46353381020682, 53.534657682691304, 51.83277981621878, 54.35799837112427, 50.273392132350374, 51.35575124195644, 47.71759108134678, 49.73524720328194, 48.266012396131245, 49.1559203011649, 45.14090721947806, 44.22668409347534, 38.39915350505284, 35.998571736471995, 42.772658893040244, 48.52250862121582, 53.003374099731445, 46.509066581726074, 49.71223824364798, 45.598185539245605, 48.293711389814106, 49.82237066541399, 52.94167757034302, 52.233895846775596, 50.92424726486206, 54.92570441109793, 53.34046248027256, 54.04248762130737, 32.803070885794504, 22.01647547313145, 29.834592001778738, 15.480378014700753, 4.007314911910465, 6.63953572511673, 17.869854824883596, 20.300638675689697, 14.924232040132795, 5.678218577589307, 0.7477317484361785, 0.5162571806992803, 0.042061737805072746, 0.2671760677226952, 0.023882244380989244, 0.09703957289457321, 0.04612602685977306, 0.20164528622158936, 0.04466417744489653, 0.43901829102209633, 0.28019726329616135, 19.208718844822474, 47.929538931165425, 56.32924052647182, 31.304545947483607, 35.512159620012554, 47.80802536010742, 37.01037188938686, 7.142844557762146, 0.29614655460630146, 10.719626937593732, 6.887962051800319, 2.434437951871327, 1.749462278825896, 0.11206075043550559, 0.293534411915711, 12.560957755361285, 62.529618399483816, 64.97128486633301, 64.01781136648995, 56.402620451790945, 35.809882981436594, 30.739977019173757, 20.60140187399728, 8.98083416053227, 28.845521143504552, 45.8836453301566, 35.292311668395996, 42.59187371390206, 94.89188861846924, 53.05675710950579, 48.89186443601336, 16.682166235787527, 0.8196923413446972, 0.445972596428224, 0.1364397265549217, 0.14187986749623502, 0.06981360632926226, 0.07932401421879019, 0.02814957995100745, 0.11934916648481574, 0.04678922698700002, 10.484503371374947, 52.19190788269043, 69.93409129551479, 74.65892887115479, 64.79100690569196, 65.51159763336182, 58.50032329559326, 63.58066545213972, 58.41089997972761, 63.288813318525044, 58.76187433515276, 61.31715774536133, 60.782542501177105, 56.81197704587664, 55.30086891991751, 60.90729740687779, 66.4693442753383, 64.29491247449602, 66.15659196036202, 59.88238252912249, 65.736649785723, 64.10606738499233, 60.281007630484446, 50.20150259562901, 52.37107760565621, 51.31657035010201, 56.81859867913382, 60.14237717219761, 62.268331391470774, 61.536046845572336, 55.50653212411063, 51.36980744770595, 54.93814863477434, 52.17769186837332, 56.343383584703716, 59.80110945020403, 60.317596844264436, 56.890516008649556, 60.20069340297154, 61.276733125959126, 59.90797969273159, 53.32741028921944, 53.16673667090279, 57.23432329722813, 61.94294030325753, 56.125349112919395, 58.6184982572283, 60.82411357334682, 55.727988583701, 49.156493527548655, 51.287985461098806, 46.87253032411848, 47.89568383353097, 54.96128961018154, 54.604798385075156, 54.777982234954834, 53.11757469177246, 44.612493242536274, 42.63313211713518, 40.721800804138184, 43.44345882960728, 46.91473020826067, 50.58297954286848, 52.60506166730608, 51.32493945530483, 50.5622113772801, 46.75023855481829, 40.29901681627546, 41.17193637575422, 41.50645739691598, 47.095206192561555, 54.298278604234966, 56.013941696711946, 53.565313134874614, 52.75677905763899, 45.19918523515974, 47.62377650397164, 47.79230158669608, 50.98718057359968, 53.84328971590315, 50.80044773646763, 55.75277280807495, 53.86165033067976, 53.65037645612444, 54.25480372565133, 49.44348887034825, 54.210105964115684, 52.63900361742292, 53.48920256750924, 56.23203870228359, 53.80221196583339, 54.17614664350237, 51.18108742577689, 51.156963280269075, 52.44015312194824, 50.83200992856707, 48.90423222950527, 46.95196907860892, 42.91702161516462, 43.43234518596104, 49.01423263549805, 54.19900621686663, 55.48985992159162, 50.25589656829834, 50.99520921707153, 48.23364073889596, 52.70904493331909, 52.915392535073416, 53.86773000444685, 54.79939658301217, 53.07708406448364, 59.060577392578125, 55.38879837308611, 56.4393937928336, 34.3167394229344, 23.79089253289359, 37.68713685444423, 21.38194339615958, 8.082263588905334, 8.51746574469975, 21.61337399482727, 24.093066215515137, 12.874847837856837, 3.955999859741756, 0.28660257958940094, 0.43799636300121036, 0.0830709185185177, 0.2787657715380192, 0.19643169455230236, 0.09201958762215716, 0.13307161442935467, 0.09797042115990605, 0.025815427968544618, 0.30195500435573713, 0.3613989060478551, 24.593020371028356, 56.668698242732454, 65.72496291569301, 36.21657146726336, 46.05006510870797, 52.89610086168562, 49.74666656766619, 8.15258891241891, 0.5007591151765415, 18.790374755859375, 19.03250731740679, 7.187515829290662, 3.561364544289453, 0.2254281693271228, 0.12294044877801623, 12.341515404837471, 82.30012689317975, 96.89937605176652, 121.34061649867466, 79.27927943638393, 47.49880620411464, 35.894915035792756, 33.26763439178467, 7.424620934895106, 59.94423539297921, 59.231343269348145, 49.499390602111816, 47.373061180114746, 96.10166031973702, 59.50258009774344, 58.47450378962925, 18.974559341158184, 0.9989669386829648, 0.6288200606192861, 0.24272752819316729, 0.2613306242440428, 0.23427670023271016, 0.14445508431111062, 0.12802263535559177, 0.36855332500168253, 0.2457441591790744, 13.032038671629769, 57.44489540372576, 71.66464437757219, 76.16809844970703, 67.64150537763322, 68.42472021920341, 64.28619943346295, 68.04716205596924, 63.94673824310303, 68.34134878431047, 65.31655475071499, 63.245414870125906, 67.13614204951695, 61.28780855451311, 58.54138020106724, 65.63846479143415, 71.40414251599992, 69.7281744820731, 69.65449578421456, 64.29926899501255, 68.70937401907784, 67.95791939326695, 64.72151797158378, 53.409072467258994, 57.9535938671657, 54.49260582242693, 60.86736610957554, 62.56105899810791, 64.8646856035505, 65.27801309313092, 57.65646457672119, 52.010031836373464, 56.5731327193124, 54.63261897223336, 61.53180149623326, 64.41987582615444, 63.90160969325474, 61.035915510995046, 62.917043004717144, 63.868744713919504, 62.65597833905901, 56.04562895638602, 54.97628729684012, 61.35658877236502, 65.923417363848, 59.62609127589634, 60.62966128758022, 63.017819677080425, 60.48373522077288, 53.13349648884365, 51.99824769156319, 50.25494466509138, 49.70032903126308, 56.99424566541399, 58.47821412767683, 56.169101919446675, 55.7049240384783, 46.890602588653564, 45.210861682891846, 43.18213708060128, 46.237371172223774, 47.981848444257466, 53.4940767288208, 54.90460273197719, 52.67650304521833, 54.28799179622105, 49.51522554670061, 41.69996125357491, 44.16549825668335, 44.0116651398795, 49.59082889556885, 57.938658714294434, 60.5289888381958, 55.20743996756417, 55.21752527781895, 46.567994253976, 49.22511393683297, 48.230406352451865, 54.24312380381993, 53.67591108594622, 52.63009950092861, 59.94720227377755, 54.80261012486049, 55.47966691425869, 53.843588488442556, 49.72076368331909, 57.00350066593715, 55.743052278246196, 55.842446259089876, 59.3885532106672, 57.16915266854422, 56.76715421676636, 53.69004372188023, 53.923669951302664, 55.83346223831177, 54.47658327647618, 53.921356201171875, 54.40594441550118, 48.35000569479806, 48.176401478903635, 53.066435950142996, 56.12167698996407, 59.993755204336985, 53.80887181418282, 57.23067201886858, 52.81204155513218, 58.07460716792515, 57.75872121538435, 61.14270237513951, 59.76921027047293, 57.58135454995291, 61.58602523803711, 62.251843316214426, 61.23002733503069, 41.81645475115095, 30.572518484933035, 43.78234331948416, 25.98259060723441, 10.404618195125035, 23.26688892500741, 27.726432119097026, 32.80870934895107, 25.664734840393066, 9.64353162901742, 4.850388050079346, 0.5048816768186433, 0.11920170725456306, 0.23826531906213078, 0.398432261709656, 0.175516259723476, 0.11326244273888213, 0.19204982396747383, 0.07689452636986971, 0.48867006387029377, 0.34502121486834114, 30.11958278928484, 65.20775985717773, 72.77075590406145, 45.48253624779837, 52.56537703105381, 58.82321998051235, 63.11195387159075, 10.589417695999146, 0.7670384581599916, 28.977846111570084, 46.984559604099815, 17.29473853111267, 4.353633105754852, 0.25890260881611277, 0.5695797737155641, 21.20174186570304], [66.69757870265416, 30.540977137429373, 29.998798779078893, 25.819122076034546, 22.79728971208845, 14.067604269300189, 4.102671120847974, 1.737340277859143, 17.490747213363647, 26.952256883893693, 23.5124226297651, 26.37245055607387, 65.84502778734479, 42.3128479548863, 29.601142951420375, 19.1399872643607, 0.44532540972743717, 0.21484032246683324, 0.11915863385157925, 0.07548303782407727, 0.08051306541476931, 0.13037407132131712, 0.03555139786164675, 0.08083173938627754, 0.07857894884156329, 3.190299255507333, 27.008634567260742, 58.441270555768696, 65.64001423971993, 63.763861656188965, 57.67216750553676, 51.84802416392735, 52.577814306531636, 53.12641627447945, 54.15046957560948, 54.370942865099224, 57.975654397692, 58.80516856057303, 62.25314957754952, 57.85388721738543, 53.12813942773001, 62.64436789921352, 61.79172665732247, 63.98319544110979, 62.174391746520996, 63.21240397862026, 61.08445562635149, 58.597570283072336, 52.34634549277169, 46.964701652526855, 47.80363757269723, 51.56701469421387, 58.41182409014021, 57.48695979799543, 58.45384679521833, 58.68390165056501, 53.9542350769043, 52.705574308122905, 52.91095611027309, 52.71074724197388, 51.95052398954119, 55.544896602630615, 56.815781184605186, 55.52937432697841, 53.21006563731602, 52.152122497558594, 53.89298323222569, 54.28042868205479, 55.588097027369905, 57.40552691050938, 52.81094026565552, 56.59951155526297, 50.889402048928396, 50.205702781677246, 51.57617589405605, 46.98460824148995, 42.37596191678728, 46.20758771896362, 52.89743838991438, 54.31556919642857, 52.98013584954398, 48.91718367167881, 38.743367263248985, 36.35148116520473, 37.983873571668354, 42.63626228060041, 41.04385328292847, 44.118406840733115, 44.01793588910784, 45.55451611110142, 42.07483046395438, 43.34025723593575, 38.57943146569388, 36.628589221409385, 37.088632924216135, 39.3925860949925, 49.96213020597185, 53.5146746635437, 47.938283239092144, 49.71873828342983, 47.09006799970354, 44.721937792641775, 52.236873149871826, 45.474212305886404, 52.99312203271048, 53.001751695360454, 51.455294609069824, 54.52556807654244, 52.05815158571516, 53.686430658612935, 52.814237185886924, 48.11736263547625, 53.21641281672886, 51.33754696164812, 52.59518827710833, 51.142531871795654, 49.97657551084246, 47.64757408414568, 48.78765882764544, 46.8310843195234, 43.547000885009766, 44.848217827933176, 41.60494463784354, 35.711798736027305, 45.39386681147984, 49.23705441611153, 48.11292273657662, 46.36932788576399, 45.73835154942104, 47.249379771096365, 47.19194596154349, 49.0171091897147, 48.50239706039429, 53.35001972743443, 52.599586486816406, 56.32795510973249, 49.91746718542916, 45.4868163381304, 37.53387001582554, 32.3526782308306, 34.54071113041469, 28.9445937701634, 12.652497666222708, 5.009148742471423, 16.743286064692906, 34.320845808301655, 27.815996135984147, 20.937038081032888, 15.54796314239502, 8.05983567237854, 3.249319859913417, 0.07815972276564155, 0.03931170662066766, 0.12737246310072287, 0.034914860767977576, 0.07401493910167899, 0.03688007460108825, 0.036939117325735946, 0.1767896528222731, 0.22918141792927468, 22.50128776686532, 51.71945469720023, 56.356296811785015, 36.339915888650076, 25.619343996047974, 28.954387256077357, 62.355378423418315, 5.115318085466113, 0.3316105944769723, 13.967188903263636, 4.087459342820304, 3.8314564398356845, 3.1696544204439436, 0.47504035809210365, 0.23955781970705303, 19.92572603906904, 73.13827392033168, 64.07912921905518, 50.30364111491612, 38.93764236995152, 33.877342292240684, 23.822428669248307, 12.566517182758876, 5.229229024478367, 28.086143834250315, 43.19325072424752, 30.375050680977957, 37.47193724768502, 68.58279868534633, 48.690526485443115, 40.78138855525425, 26.151485681533813, 0.5763213719640459, 0.27787051243441446, 0.1464898344129324, 0.0402774926541107, 0.1619289352425507, 0.06959965066718203, 0.059882248884865215, 0.114521199837327, 0.2863104295517717, 3.879788977759225, 36.43291057859148, 71.10431385040283, 69.37713759286063, 68.13213852473667, 62.54012407575335, 56.76816170556204, 58.52772004263741, 60.28296702248709, 60.40026651109968, 58.8334755216326, 59.33170304979597, 61.77468967437744, 61.893510818481445, 59.384155000959126, 54.133172035217285, 64.18208762577602, 61.83403423854283, 66.08529649462018, 62.582973616463796, 64.12190232958112, 62.193360328674316, 63.475170952933176, 56.44332299913679, 49.34725284576416, 50.56147139413016, 53.822108132498606, 61.92996106828962, 59.284927776881624, 59.850017820085796, 60.073339870997835, 55.95198460987636, 54.618732997349326, 56.47340522493635, 55.56632137298584, 53.993266582489014, 57.10168218612671, 59.35637610299246, 56.10363251822335, 56.27317898614066, 53.47834948131016, 57.80436740602766, 57.13804905755179, 58.454791750226704, 59.04689638955252, 57.08094181333269, 58.60359437125069, 52.30701521464756, 54.22174767085484, 55.576007161821636, 49.85371398925781, 45.644147872924805, 49.107956886291504, 55.371000562395366, 54.42624010358538, 55.43942642211914, 48.91895546231951, 41.23705836704799, 40.08480385371617, 40.52365207672119, 42.29467494147164, 40.91431106839861, 45.22638048444475, 44.8564966065543, 47.71070889064244, 43.17760338102068, 42.18236773354666, 40.10019758769444, 38.913542543138774, 38.46057210649763, 40.43251255580357, 52.245259625571116, 55.441583837781636, 52.30553524834769, 52.30330140250069, 48.51387895856585, 45.94610963548933, 52.31548159463065, 48.8883764403207, 53.698916571480886, 54.46101931163243, 53.05558981214251, 54.646174907684326, 52.77447959354946, 53.80179507391793, 53.940331731523784, 51.24845368521554, 54.411033970969065, 53.47761297225952, 54.665751457214355, 53.95451995304653, 51.1042195047651, 50.131878171648296, 51.02264417920794, 48.91989346912929, 47.31868805204119, 49.72415093013218, 44.62449972970145, 41.83026082175118, 50.246252468654085, 52.19840792247227, 51.0003091948373, 50.20843342372349, 46.64286804199219, 49.060459000723704, 50.77815791538784, 51.008612292153494, 51.985841682979036, 54.512109415871755, 55.26336601802281, 56.092154094151084, 52.7712973185948, 47.721829482487266, 37.718497548784526, 34.60990129198347, 37.214763573237825, 36.01700183323452, 18.36056787627084, 9.280799184526716, 25.482280356543406, 36.901816708701, 36.883084365299766, 22.76635112081255, 12.28524020739964, 5.846147418022156, 1.3347426525184085, 0.15369123513145105, 0.07285195722111634, 0.10473632453275578, 0.01150164523694132, 0.07025092214878116, 0.06648907650794302, 0.11990452025617872, 0.059190570642905574, 0.27743348159960335, 27.894026143210276, 60.833333832877024, 63.62197249276297, 40.59205709184919, 34.37002168382917, 39.14022404806954, 71.59315436226981, 7.366924830845424, 0.5275217848164695, 15.524162088121686, 20.299806628908428, 13.776426110948835, 8.261703423091344, 0.43000281336052076, 0.4946375350866999, 19.97980386870248, 94.62041555132184, 94.80323655264718, 91.07758467538017, 53.047227655138286, 49.044954095567974, 31.07825701577323, 20.40468794958932, 6.540704982621329, 58.244285651615684, 58.67720358712332, 41.9048810005188, 39.20286553246634, 79.67770998818534, 56.832769530160085, 48.24559511457171, 34.92525918143136, 0.9089126938155719, 0.44681281277111595, 0.355942181710686, 0.12671565477337154, 0.300252695700952, 0.5024960562586784, 0.17580057946699007, 0.16620815704975808, 0.37892633410436766, 8.289577858788626, 45.32611492701939, 69.4461054120745, 70.48340892791748, 69.51000799451555, 65.31390053885323, 60.02431338174002, 62.80396802084786, 65.57731369563511, 67.52629034859794, 63.94509846823556, 65.08144855499268, 67.39492770603725, 68.26511314937046, 63.644547189985005, 57.03403799874442, 68.07917935507638, 65.16431971958706, 67.85789312635148, 66.22990240369523, 68.59093502589634, 65.0063315800258, 66.09456539154053, 59.82850619724819, 51.35948589869908, 54.011036600385395, 56.574946199144634, 65.34012304033551, 64.70915017809186, 62.032926423209055, 63.56287806374686, 57.107216426304404, 56.4294821875436, 57.51671545846121, 58.99365929194859, 60.85987595149449, 60.84950229099819, 60.855630602155415, 60.49530397142683, 60.17911229814802, 59.25629425048828, 60.762767927987234, 62.091847147260395, 62.128443309238975, 61.439188957214355, 58.18242236546108, 63.45213072640555, 56.520024163382395, 52.98022617612566, 56.29581274305071, 53.11332586833409, 47.42982448850359, 50.51770469120571, 56.14814267839704, 59.47116034371512, 57.408987113407676, 53.96242700304304, 43.03825725827898, 41.200194699423655, 41.890640667506624, 44.2251763343811, 44.0067458152771, 48.90078592300415, 46.11411707741873, 49.08506257193429, 43.53595324925014, 46.754497800554546, 41.33004263469151, 40.83224589484078, 40.99736983435494, 41.84987211227417, 53.028585638318745, 57.25613021850586, 53.294354234422954, 52.831750120435444, 51.695347922188894, 48.65147066116333, 53.787721497671946, 50.531309264046804, 56.68446717943464, 57.06976216179984, 55.50630978175572, 57.1804643358503, 53.56742886134556, 57.06899438585554, 57.15993240901402, 54.58996050698416, 55.95003911427089, 56.15056759970528, 58.015432834625244, 56.06981563568115, 55.075448513031006, 54.55809954234532, 53.179962566920686, 52.52917691639492, 51.07326528004238, 54.77244452067784, 50.550732953207834, 48.302000590733115, 54.32512991768973, 56.212653228214805, 53.05240406308855, 54.29616982596261, 51.38904006140572, 53.522018909454346, 55.67138508387974, 57.87015642438616, 57.759353501456125, 60.06844139099121, 62.181214877537315, 59.98541736602783, 58.527921540396555, 52.249775954655235, 44.656913076128276, 39.38347353254046, 43.656608717782156, 47.3959242275783, 33.62359755379813, 39.50584520612444, 36.884439264025005, 46.80469158717564, 42.713269165584016, 33.139322008405415, 28.71235544340951, 11.827653561319623, 4.0667815038136075, 0.19686721903937204, 0.12912376198385442, 0.21727923516716274, 0.15675311083240168, 0.15927352915917123, 0.19919445844633238, 0.12912634041692528, 0.34267456935984747, 0.2882062021110739, 34.804527282714844, 71.69720363616943, 70.04827104296002, 51.179715156555176, 39.344431604657856, 41.58976282392229, 81.91827474321637, 9.298974803515843, 1.2690935752221515, 21.41462424823216, 42.252721718379426, 23.76065570967538, 11.367810487747192, 0.5263424909540585, 0.6269761281354087, 31.999820913587296], [68.33385862622941, 22.74099714415414, 30.87161758967808, 6.918096389089312, 18.567764895302908, 9.424994281360082, 3.561436631849834, 7.30917227268219, 18.297512974057877, 28.8983986718314, 18.315545286451066, 21.79754294667925, 61.689171246119905, 40.702300684792654, 27.390629155295237, 23.263631956917898, 0.23162764523710522, 0.13566892434443745, 0.014601030353722828, 0.10689644754997321, 0.12395403081817286, 0.1201344079204968, 0.08153476273374897, 0.06690319321517434, 0.20257299286978586, 0.8913180636508125, 9.456290704863411, 47.43285737718855, 68.07161276681083, 62.628275871276855, 63.59054579053606, 51.99759108679635, 52.23632076808384, 48.168529169900076, 51.128065722329275, 52.07476820264544, 53.95066717692784, 58.8054256439209, 61.852203777858186, 62.62947790963309, 54.786712646484375, 53.74605662482125, 59.089106695992605, 63.70062610081264, 62.605027198791504, 65.06403636932373, 60.309099197387695, 61.061484881809776, 55.22832972662789, 48.91074616568429, 48.41096224103655, 48.69177368709019, 53.16300548825945, 58.07406868253435, 58.969208581107004, 60.89831338609968, 55.49266699382237, 54.979250703539165, 54.83617687225342, 54.928938797542024, 53.23309196744646, 50.92043965203421, 55.695064544677734, 55.796518666403635, 52.93644210270473, 55.44333478382656, 51.33320781162807, 54.35560471670968, 56.07100030354091, 55.964154379708425, 52.60324123927525, 50.93776151112148, 53.54642098290579, 55.56798546654837, 49.953479698726106, 46.24070283344814, 47.7328701700483, 48.576416219983784, 55.21043464115688, 54.56960228511265, 54.13923781258719, 42.651579584394185, 37.1838128226144, 38.79102495738438, 40.027707031794954, 38.28145102092198, 38.94940219606672, 39.110916546412874, 41.09311253683907, 40.16595881325858, 41.314638478415354, 36.90593351636614, 40.51689147949219, 36.52761799948556, 37.37979023797171, 37.861710344042095, 45.241767270224436, 55.54176296506609, 52.80759818213326, 51.31776544025966, 49.95965664727347, 41.63777835028512, 46.14426531110491, 54.197442872183665, 47.62889385223389, 52.49707623890468, 54.402473790305, 52.80039984839303, 52.6386388369969, 48.82828494480678, 51.901865754808696, 48.19652346202305, 49.76807744162423, 50.277074677603586, 49.7425080708095, 50.64061485018049, 47.44092423575265, 44.79121133259365, 47.335106645311626, 46.545666217803955, 43.92937414986746, 41.716977391924175, 33.49736615589687, 41.45194183077131, 48.6016902923584, 48.701348304748535, 46.63908474785941, 45.39687190737043, 45.32423543930054, 47.251446860177175, 49.674922943115234, 48.794808523995535, 48.462305954524446, 55.64652790342058, 52.99281631197248, 45.71853528703962, 47.49903549466814, 52.04902860096523, 48.30916765757969, 41.65721246174404, 43.94437183652605, 43.83971112115042, 41.87235995701381, 30.13102994646345, 32.520974023001536, 42.24560328892299, 28.254861729485647, 24.203337601252965, 20.066446168082102, 16.367331198283605, 6.607759875910623, 0.376706601785762, 0.06385194337261574, 0.22723280106272015, 0.04018086926745517, 0.11789695226720401, 0.1950222280408655, 0.13562424959880964, 0.13303306006959506, 0.31581568345427513, 30.22919409615653, 52.584637437547954, 58.268976075308665, 35.76656791142055, 31.483420372009277, 33.33318369729178, 71.65985706874302, 5.447163615907941, 0.27299111283251215, 11.666138342448644, 8.038648009300232, 7.744894674846104, 7.500803589820862, 0.4589606523513794, 0.6791626363992691, 31.550512177603586, 83.15873663766044, 66.73683602469308, 49.186891896384104, 23.42436637197222, 30.546799727848597, 17.772844076156616, 2.5806658310549597, 7.4929199899945935, 25.760760681969778, 42.415229661124094, 27.420247588838848, 28.381657668522426, 78.85106890542167, 46.509042263031006, 39.547979082380024, 34.0342812538147, 0.26639876514673233, 0.023016742430627346, 0.05305651568674615, 0.026005967387131283, 0.06510534004441329, 0.037855278700590134, 0.07854618917086295, 0.10205681010016374, 0.16480318244014466, 1.100871933358056, 15.228693417140416, 63.272992270333425, 71.14011791774205, 67.93080752236503, 64.35407638549805, 57.97672094617571, 56.424614974430625, 54.368097577776226, 58.11536182676043, 57.81191314969744, 60.088570322309224, 64.37790870666504, 63.381140981401714, 62.85990101950509, 53.169071265629356, 56.11017424719674, 62.32775238582066, 64.61551625388009, 62.81843417031424, 63.28279617854527, 62.80923475537981, 61.64227785382952, 56.91521338054112, 50.96192734582083, 51.622065271650044, 51.57310479027884, 58.62728772844587, 59.633400780814036, 60.82152189527239, 61.99027143205915, 56.462500027247835, 56.97191415514265, 57.81685331889561, 57.94315767288208, 56.059080668858115, 53.37620401382446, 57.22603062220982, 56.52491569519043, 54.45744793755667, 57.10540294647217, 53.06048829214913, 57.01135213034493, 57.95312833786011, 57.559078625270296, 56.03853831972395, 52.78400557381766, 55.70844330106463, 56.17513642992292, 48.80139889035906, 50.19492612566267, 49.755160740443635, 51.74112612860543, 55.90334721973964, 55.33130202974592, 53.913362298692974, 43.47609451838902, 40.21977261134556, 40.75207757949829, 42.482519490378245, 40.27542768205915, 40.115167481558665, 39.63519981929234, 40.574891567230225, 39.81338289805821, 40.931518282209126, 37.93613249914986, 41.21212823050362, 38.83449983596802, 39.84226655960083, 38.87258986064366, 45.04851702281407, 55.75423540387835, 55.58327497754778, 53.66537414278303, 53.09269666671753, 46.17943361827305, 46.96446541377476, 55.942347458430696, 51.70107671192714, 52.45699208123343, 56.393059730529785, 54.261713709150044, 53.9349364553179, 50.16590697424752, 51.99465199879238, 50.464356422424316, 49.86386183329991, 53.56938130514962, 51.431326798030305, 53.167587825230186, 50.94779470988682, 44.96300206865583, 47.84365572248186, 46.64034584590367, 46.90180308478219, 44.482113770076204, 39.72562714985439, 46.15200213023594, 53.588895320892334, 51.8741910798209, 49.10360731397356, 47.99031482424055, 47.81192677361624, 49.713923181806294, 53.861313343048096, 51.05477959769112, 50.1660806792123, 55.12491968699864, 54.06167507171631, 47.74737106050764, 46.37573759896414, 51.33368376323155, 48.88994325910296, 44.7794098172869, 49.84705066680908, 50.195051193237305, 47.638840198516846, 35.05813305718558, 34.41620288576399, 48.1001866885594, 38.9781607900347, 31.616964748927526, 24.121506929397583, 16.71529872076852, 5.20816946881158, 0.17580665914075716, 0.030056468610252653, 0.047031240072101355, 0.08578385758612837, 0.07445247205240385, 0.19576506103788102, 0.17676655549023831, 0.0885679003383432, 0.265812945153032, 35.228718280792236, 62.76642690386091, 65.5604156766619, 43.73753091267177, 37.02779797145298, 41.74190752846854, 75.99635287693569, 7.585240704672677, 0.5075301347034318, 16.08019862856184, 19.009910038539342, 19.13805740220206, 14.076596975326538, 0.7736074370997292, 0.3407125989241259, 27.45118270601545, 104.03582913534981, 81.06554317474365, 62.43567875453404, 40.33864934103829, 39.32274975095476, 25.680132048470632, 10.127034187316895, 17.031195095607213, 57.06015975134713, 55.01328992843628, 34.45450483049665, 34.499327659606934, 72.10021999904087, 59.538919176374165, 48.68102829796927, 48.75860840933663, 0.43408528715372086, 0.18800540241811955, 0.3264332094362804, 0.1292197068354913, 0.33335548798952785, 0.1325120265994753, 0.2574375160038471, 0.2824378673519407, 0.392873078584671, 0.7867675966450146, 26.72427432877677, 67.22517626626151, 70.6203509739467, 70.05171040126255, 67.53366238730294, 62.929014750889365, 58.77620846884591, 59.50308731624058, 64.63370663779122, 63.06682532174246, 65.96496064322335, 71.25217151641846, 69.35302039555141, 70.20860767364502, 59.33122362409319, 61.3516069139753, 64.85425635746547, 69.54142774854387, 66.08800629207066, 68.44888605390275, 65.39443016052246, 65.95498303004673, 61.80879143306187, 54.71595219203404, 54.98029293332781, 53.93145193372454, 60.4459022794451, 62.00958047594343, 63.173167501177105, 66.81212670462472, 57.79020002910069, 59.227896962847026, 59.96567753383091, 61.11921746390206, 57.30245385851179, 56.377210889543804, 60.22812489100865, 61.49220371246338, 59.79411261422293, 61.7841739654541, 55.914151668548584, 60.33640561785017, 60.20647430419922, 60.00355911254883, 58.913178307669504, 57.28823784419468, 57.68964917319161, 62.068410873413086, 53.52091761997768, 51.9520525932312, 51.12462636402675, 54.83594410760062, 59.21561254773821, 59.26508372170584, 58.91140651702881, 46.75561646052769, 41.65765714645386, 43.65290185383388, 42.96333483287266, 41.601203032902305, 39.868013109479634, 40.690638133457725, 42.23599393027169, 40.74349308013916, 43.26401465279715, 40.136501925332205, 42.71153906413487, 40.88796002524239, 41.02362707683018, 40.742707933698384, 48.300388608660015, 59.65828922816685, 55.325969287327354, 54.32052673612322, 53.25470781326294, 47.41839470182146, 50.89007602419172, 59.92721230643136, 51.842472553253174, 57.17443329947335, 56.87132508414132, 58.609660148620605, 54.203744888305664, 50.77680996486119, 55.15005826950073, 54.48621695382254, 53.510748931339805, 54.10654306411743, 53.95429413659232, 57.158292634146555, 52.572314807346885, 51.05666603360857, 52.420312540871755, 50.37189326967512, 52.53579160145351, 52.49373762948172, 44.53655638013567, 49.79628365380423, 56.14457825251988, 54.328221866062705, 51.133537428719656, 51.97621842793056, 52.37333924429757, 53.14712885447911, 57.90226752417428, 56.954425539289204, 54.58709437506539, 63.874866076878135, 59.90995992933001, 53.79317930766514, 53.85425049918038, 57.8140149797712, 58.286513328552246, 54.02483572278704, 61.962221554347444, 59.44020611899239, 63.76441751207624, 51.92084475925991, 50.500361987522666, 53.10413687569754, 47.31114925657, 42.021061829158235, 31.82394811085292, 25.586392164230347, 8.558534809521266, 0.8428528585604259, 0.11664082109928131, 0.2296278668301446, 0.12343796422438962, 0.23119748117668287, 0.21405314042099885, 0.27748847007751465, 0.2439843107547079, 0.32175514474511147, 41.23155191966465, 72.86450099945068, 71.51205498831612, 53.51058564867292, 45.92257956096104, 47.75224869591849, 88.9238862991333, 10.065992525645665, 1.1354400898729051, 23.014948981148855, 38.41818809509277, 29.816318239484513, 20.099267721176147, 0.9254465294735772, 0.7572119140199253, 39.86062717437744], [70.48290170942033, 24.06239686693464, 5.713683920247214, 12.604304092270986, 19.340762410845073, 2.755349189043045, 0.8255323565432003, 2.8166920116969516, 10.863368664469037, 27.444423845836095, 36.0536014693124, 35.13724177224295, 26.76100250652858, 40.525524616241455, 26.22883997644697, 22.300797496523174, 0.5980082196848733, 0.08164275836731706, 0.03966699094910707, 0.0750116595466222, 0.0485451433009335, 0.07820678595453501, 0.04952657635190657, 0.019074409867503812, 0.13789283643875802, 0.3956445955804416, 4.901822524411338, 26.076571941375732, 65.30596569606236, 66.67875603267125, 66.8482642854963, 57.100330761500764, 49.866998944963726, 47.228618553706575, 45.808097566877095, 50.000960213797434, 53.502748080662315, 55.028770514896934, 58.80862876347133, 60.8169013432094, 59.488058362688335, 52.4452600479126, 57.5283328465053, 64.8715990611485, 61.66658265250069, 63.92080061776297, 57.67148658207485, 60.004198346819194, 59.995082310267854, 49.88127401896885, 44.59117269515991, 45.891746929713655, 53.2478221484593, 55.08540875571114, 56.69155086789812, 58.60092626299177, 57.78126811981201, 56.579611914498464, 56.33799178259713, 53.22620977674212, 56.82282318387713, 55.8817800113133, 52.4152056149074, 53.33694669178554, 58.77773707253592, 52.02343838555472, 52.44378355571202, 53.0784215927124, 54.58106681278774, 57.40646144321987, 52.85807684489659, 56.93115949630737, 54.39719663347517, 46.328069482530864, 51.72383206231253, 49.8936140196664, 49.013252939496724, 53.088242871420725, 55.55926547731672, 55.09172466823033, 48.82616574423653, 38.26330927440098, 38.54218217304775, 40.57996375220162, 41.83734451021467, 38.6807987349374, 37.51056923185076, 33.883991718292236, 35.053672313690186, 32.58002328872681, 35.926661355154856, 34.60282107761928, 38.37957000732422, 40.089431353977744, 36.40913036891392, 37.74502924510411, 44.11287260055542, 48.58775568008423, 52.723135880061555, 54.855399063655305, 54.01488937650408, 47.09131867544991, 43.612598827907014, 51.701135771615164, 54.8656268119812, 49.14063426426479, 52.92756230490548, 53.75629826954433, 52.89117806298392, 54.92950854982649, 51.402130467551096, 51.40557329995291, 50.39993619918823, 53.3551926612854, 47.1256115095956, 46.57808303833008, 45.09048761640276, 40.23397472926548, 44.81334481920515, 37.73528439658028, 32.27952412196568, 31.17724452699934, 34.23648772920881, 48.02603898729597, 47.36280216489519, 47.63657855987549, 45.24700273786272, 43.58607407978603, 43.10199655805315, 48.701115540095735, 52.084447043282644, 50.58678020749773, 47.36665146691458, 52.132382665361675, 47.25936780657087, 44.76836218152727, 52.33229276112148, 50.69825710569109, 47.677162987845286, 46.359138352530344, 52.45896189553397, 55.37100403649466, 51.37933342797415, 50.22432047980172, 53.301893029894146, 54.91925648280552, 36.44663674490792, 28.138185841696604, 20.626790591648646, 11.713658809661865, 3.777133686201913, 0.7218760358435767, 0.37237773835659027, 0.35768978936331614, 0.0598658894055656, 0.3063557653554848, 0.018807553919032216, 0.4213487505912781, 0.26628189427512033, 0.4157977913107191, 24.531725100108556, 54.982585838862825, 52.351778984069824, 39.83495010648455, 35.828834193093435, 34.1274322782244, 65.31888934544155, 5.026687298502241, 0.17129674899790967, 3.3279198365552083, 9.018083453178406, 9.86016343321119, 7.622194698878697, 0.7194094253437859, 0.3114377483725548, 43.33748837879726, 87.88134384155273, 51.18062884466988, 27.607114178793772, 16.62322119304112, 27.78953218460083, 11.762249299458094, 2.2017367013863156, 12.311594724655151, 25.186809948512487, 40.903603894369944, 34.21872465951102, 34.36367450441633, 47.871260915483745, 46.05071129117693, 36.66065515790667, 39.87782049179077, 0.9225515191044126, 0.11004909088036843, 0.08143937428082738, 0.0859046368194478, 0.04373923582690103, 0.056165386723088365, 0.0217206472464438, 0.09076568204909563, 0.15624468454292842, 0.3804691598883697, 2.4259650579520633, 40.32589592252459, 72.71344716208321, 68.85594626835415, 70.85369232722691, 62.30126585279192, 55.24033621379307, 51.80935743876866, 51.49517379488264, 56.78834622246878, 61.07705579485212, 62.68662684304373, 64.20535019465855, 65.07631383623395, 60.5278354372297, 52.838489873068674, 59.66748864310128, 64.51854024614606, 64.51885291508266, 65.42871952056885, 59.32232298169817, 61.02913406917027, 61.40715776171003, 52.91181421279907, 46.69132130486624, 48.911381925855366, 54.73046350479126, 57.02156598227364, 60.08122607639858, 60.15416826520647, 63.34522574288504, 57.844142368861604, 56.445737498147146, 54.521558965955464, 58.2745554787772, 57.83273342677525, 54.69255413327898, 55.649453095027376, 59.16294520241873, 54.321266719273154, 54.0507663999285, 56.355174677712576, 58.121035030909944, 57.904178278786794, 55.05583027430943, 58.249587127140586, 55.475866249629426, 50.87474829810006, 53.44289282390049, 52.60422093527657, 51.3137389591762, 55.779856886182515, 56.678415298461914, 58.14802530833653, 48.93153517586844, 41.197151388440815, 39.726308073316304, 43.907490798405235, 44.68134989057268, 39.45197582244873, 36.62123107910156, 35.1826308795384, 34.270662443978445, 33.42418425423758, 35.60377161843436, 36.57015139716012, 39.48346158436367, 41.28484460285732, 38.13475022997175, 38.71281255994524, 46.2908479826791, 52.79681805201939, 53.25859185627529, 57.462814807891846, 54.889931610652376, 51.639421871730256, 45.14892891475132, 51.71507385798863, 57.54528645106724, 51.772267954690115, 55.27704702104841, 56.501576696123394, 56.187066486903596, 53.881688935416086, 51.92923470905849, 53.92842599323818, 53.64159393310547, 53.177819047655376, 50.40265989303589, 49.40131677900042, 46.66742992401123, 45.771841866629465, 45.94815240587507, 42.11363615308489, 39.67233099256243, 39.523170539310996, 41.11846303939819, 47.40025642939976, 50.76306642804827, 51.09572533198765, 47.2987710407802, 47.95498323440552, 47.59705720629011, 51.67953034809658, 54.53966249738421, 54.451132025037495, 47.46434661320278, 51.40978043419974, 50.13079077856881, 47.3818541254316, 54.11704874038696, 56.582776818956646, 53.514223030635286, 51.09020151410784, 57.46047673906599, 61.584135328020366, 59.079914229256765, 58.186903953552246, 61.417614800589426, 61.942440032958984, 45.794228962489534, 34.16645336151123, 26.210755552564347, 19.65712778908866, 5.108909675053187, 0.6219444924167224, 0.27862490766814774, 0.15839950820165022, 0.06956803772066321, 0.1877126009868724, 0.3039991860943181, 1.0652725121804645, 0.21797390574855463, 0.3314459818814482, 33.69895076751709, 62.37386063167027, 61.838668687003, 48.36422518321446, 40.3147405896868, 40.687236990247456, 77.27392510005406, 8.050798671586172, 0.37824261507817675, 5.590743362903595, 15.275588546480451, 19.592646769114904, 16.414538996560232, 0.670640127999442, 0.5530157025371278, 36.76242194856916, 110.4350505556379, 65.59443405696324, 30.461996964045934, 31.54612786429269, 39.87504121235439, 14.7787732396807, 6.616088160446711, 15.391220467431204, 55.2514602797372, 51.16473831449236, 53.38825913837978, 49.579506805964876, 33.57252829415457, 58.70164040156773, 46.36950853892735, 57.981612477983745, 1.1220331064292361, 0.15531164460948535, 0.1539351006171533, 0.1523365806788206, 0.18135750985571317, 0.19148047880402633, 0.15577052427189692, 0.14811582144881996, 0.2743784455316407, 0.7635503539017269, 11.644380927085876, 55.16196748188564, 72.53503131866455, 72.68853787013462, 75.61014420645577, 63.99581336975098, 58.50727844238281, 57.27481739861624, 57.45981666019985, 62.58339745657784, 66.97236606052944, 68.05167143685478, 72.0088928767613, 72.29958466121128, 64.48017924172538, 57.0284412247794, 62.99743366241455, 69.05490098680768, 68.55933461870465, 69.81646524156842, 62.885136876787456, 65.61403492518834, 65.45528248378209, 56.09365490504673, 47.46983569008963, 49.9531044960022, 58.267322404044016, 59.936960629054475, 62.53642763410296, 62.52147511073521, 61.721730504717144, 60.793270519801546, 59.5690952028547, 57.03965561730521, 60.555009841918945, 62.64403438568115, 58.49780804770333, 59.63928590502058, 62.78049005780901, 58.902491978236604, 55.92268753051758, 58.889735085623606, 59.55827685764858, 62.5407007762364, 57.28988804136004, 61.39120469774519, 59.39964253561837, 54.204995564052034, 56.47082049506051, 56.11383942195347, 53.18253340039934, 58.44792693001883, 59.35069247654506, 61.087450299944194, 52.885609081813264, 44.35999917984009, 41.962144579206196, 46.18871293749128, 44.21983664376395, 41.1365943636213, 37.63792971202305, 36.69770295279366, 34.27194438661848, 32.5983943258013, 36.24879721232823, 36.925232137952534, 40.33075966153826, 44.832643440791536, 40.49228096008301, 43.2524528503418, 47.21398217337472, 53.96172176088606, 56.39000252314976, 59.67918940952846, 58.334414209638325, 53.06805488041469, 46.60964870452881, 55.08433525902884, 59.98484761374337, 52.588841097695486, 57.53259556634085, 59.06100818089077, 58.47594901493618, 58.50631264277867, 53.247210706983296, 56.74511800493513, 54.68779809134347, 58.95911284855434, 54.40803582327706, 51.71599449430193, 52.350476196834016, 45.79076875959124, 49.41665145329067, 48.13808911187308, 45.304485184805735, 41.6459424836295, 41.21980946404593, 52.38465438570295, 54.09421348571777, 54.97573838915144, 51.74959945678711, 51.45464495250157, 52.41100542885916, 57.67552695955549, 61.798049518040244, 59.4823955808367, 53.44294840948922, 58.30848353249686, 59.77410875047956, 54.08945049558367, 64.8603846686227, 64.48951067243303, 64.54593699319022, 60.39933545248849, 61.30767345428467, 66.23787198747907, 58.437428201947895, 60.81386498042515, 61.94177300589425, 61.866961751665386, 50.045327935900005, 47.02026987075806, 31.524056911468506, 24.75834580830165, 8.887591072491237, 1.5727476584059852, 0.5707225895353726, 0.48395462547029766, 0.10438320812370096, 0.3311431109905243, 0.23865566668765886, 0.5983412989548275, 0.5401625665170806, 0.3152592304561819, 49.61098909378052, 66.53551197052002, 73.24577644893101, 53.25989811761038, 53.27397516795567, 47.293104784829275, 89.06528908865792, 12.487313798495702, 1.1188699390207018, 12.815226214272634, 34.58711120060512, 30.03142751966204, 24.41892978123256, 1.2914405018091202, 0.6016209572553635, 54.07939992632185], [51.83840090887887, 27.154348714011057, 2.934383205005101, 15.75805582318987, 23.743479762758525, 1.1405425646475382, 0.26096397106136593, 1.2187293406043733, 9.858845012528555, 33.39590161187308, 46.76128966467721, 42.25299269812447, 26.885550703321183, 26.301092556544713, 30.587220873151505, 21.853369985307964, 1.3904322470937456, 0.19691367154674871, 0.10237669864935534, 0.033329633330660205, 0.09911242273769208, 0.018897307138623934, 0.07234883029013872, 0.06994074343570642, 0.25169586124164717, 0.5317170854125703, 3.7300926446914673, 20.922148091452463, 67.9949949809483, 72.05256925310407, 68.37439441680908, 61.94861003330776, 52.86131817953927, 47.36331285749163, 46.72630895887102, 47.57920033591134, 51.40829004560198, 51.6354718208313, 53.0491384097508, 55.51886517660958, 59.477101053510395, 54.13102504185268, 52.777244976588655, 59.48533466884068, 63.43124444144112, 63.67117268698556, 58.107034410749165, 59.86273997170584, 60.226964541843955, 53.81852633612496, 45.787471839359824, 44.62943989889962, 51.22839076178414, 54.38676738739014, 55.528724670410156, 58.3454965863909, 58.313145773751394, 55.98162909916469, 55.779686655317036, 56.361931800842285, 55.49297271456037, 58.35292421068464, 55.93164028440203, 52.76615912573678, 53.701678480420796, 53.389746052878245, 55.16375316892351, 54.863038608006065, 55.38259710584368, 55.06257002694266, 57.02498797007969, 53.67471252168928, 50.70965215138027, 54.15501717158726, 51.135250159672324, 48.08780499867031, 54.74967179979597, 54.20358855383736, 53.43355097089495, 53.46752418790545, 45.26583235604422, 36.80435085296631, 38.98505687713623, 42.57037946156093, 48.17540093830654, 35.31725222723824, 34.13940749849592, 33.511304242270334, 32.463818141392295, 32.859392983572825, 36.119428702763145, 33.429701123918804, 41.82899972370693, 43.13184601919991, 40.32708753858294, 34.3113545690264, 48.14435986110142, 55.7565769468035, 48.774957520621165, 52.69899436405727, 53.73577676500593, 52.181801727839876, 46.63759783336094, 48.489445618220735, 53.37390763419015, 53.69925355911255, 46.55012001310076, 54.6262092590332, 56.85799843924386, 52.614994117191856, 51.193486486162456, 51.280821868351524, 50.046133926936555, 49.51967239379883, 46.52359526497977, 46.16082286834717, 46.74053192138672, 45.316859926496235, 38.53281600134713, 34.22369262150356, 41.500214440482004, 47.050393785749165, 48.14390127999442, 45.01214667728969, 46.1581825528826, 46.96975646700178, 44.493665150233674, 42.48579209191458, 45.46717725481306, 46.57548441205706, 51.909540040152415, 52.45411205291748, 48.457442215510774, 46.51154708862305, 47.85359164646694, 48.797698974609375, 42.17579473767962, 35.32923092160906, 42.45184319359915, 48.27955443518502, 60.59052903311593, 56.02463844844273, 57.01481580734253, 48.7864533151899, 52.23524032320295, 57.079434054238455, 57.657291412353516, 37.82055268968855, 31.104482991354807, 13.39119713647025, 5.558673083782196, 1.4982528729098183, 0.09346272304121937, 0.19089702011219092, 0.07106179185211658, 0.10632953154189245, 0.4660633940781866, 2.154284413371767, 0.2803149755511965, 1.942550654922213, 45.38626548222133, 48.01516853060041, 62.223904609680176, 38.515671321323936, 43.34760843004499, 38.41482169287545, 57.42955378123692, 5.571007004805973, 0.5046211193714822, 0.8436420219285148, 8.276011501039777, 10.537557210241046, 8.763558779444013, 0.409821661987475, 0.3176226222089359, 39.955727168491904, 85.54356684003557, 43.389019693647114, 0.5588340046150344, 19.828366143362864, 26.619241884776525, 5.177096690450396, 0.9270211649792535, 4.529519370623997, 21.918123722076416, 46.603172983442036, 53.441669940948486, 35.38797794069563, 16.487647942134313, 32.053103174482075, 41.712655612400596, 42.521853242601665, 2.6705666184425354, 0.15616252752287046, 0.1315448699252946, 0.09356705458568675, 0.0425817670433649, 0.033149516209959984, 0.10007987118193082, 0.06281564398003475, 0.04549122681575162, 0.7831945940852165, 2.7091473596436635, 30.538715498788015, 73.10098988669259, 69.52346665518624, 72.76701777321952, 65.30811268942696, 59.44548674992153, 51.99243899754116, 52.46983582632882, 54.478306429726736, 58.711659703935894, 59.90591607775007, 61.221439361572266, 63.49922561645508, 62.81922626495361, 55.487184865134104, 54.845598629542756, 60.680258069719585, 62.17940834590367, 64.99124009268624, 58.72896071842739, 59.57765538351876, 61.52771595546177, 55.74444886616298, 48.5636419568743, 46.26338175364903, 52.99834360395159, 58.04548379353115, 56.778702122824534, 60.353157724652974, 59.52286188943045, 58.37289333343506, 57.128818375723704, 57.59402111598423, 58.15027305058071, 57.129273482731406, 56.23989711488996, 56.65250894001552, 55.227315289633616, 55.4714298248291, 57.10961355481829, 55.293344020843506, 57.841397830418174, 56.325599670410156, 59.186666352408274, 52.45660298211234, 53.620315074920654, 57.0404303414481, 52.59529250008719, 50.66280044828142, 55.35289703096662, 56.14642994744437, 56.36310952050345, 54.2878806250436, 45.04538685934884, 39.8320666040693, 42.177542209625244, 46.74970006942749, 50.87141663687569, 35.88840804781233, 36.990281173161094, 33.20012222017561, 33.94040066855294, 33.68191378457205, 35.82492930548531, 34.08831739425659, 42.78373779569353, 46.870956557137625, 42.69507530757359, 36.827637740543906, 49.59652641841343, 51.768776484898154, 50.300500529153005, 56.76315900257656, 55.471947465624126, 54.193968772888184, 50.64174393245152, 50.77451011112758, 56.40596253531319, 56.87522649765015, 49.569800172533306, 54.42285980497088, 56.58497244971139, 53.12933799198696, 54.12133577891758, 52.77646330424717, 51.28840582711356, 49.981717177799766, 47.90620340619768, 48.04367698941912, 48.231462478637695, 45.48018775667463, 43.353271211896626, 43.12911190305437, 47.50265203203474, 52.351615701402935, 53.70334952218192, 49.61757598604475, 49.24735164642334, 50.67251402991158, 49.83582585198538, 45.889183044433594, 48.56778308323452, 49.66132531847273, 53.158714975629536, 54.85643434524536, 49.84169707979475, 49.418395451136995, 49.12927048546927, 51.292967319488525, 46.679756028311594, 44.36547783442906, 51.82751308168684, 55.32971784046718, 65.90214892796108, 61.627353123256135, 61.53652627127511, 55.458784103393555, 59.74935926709856, 60.898848397391184, 60.725039209638325, 48.6532632963998, 32.43014717102051, 15.675660610198975, 6.7348359142030985, 1.5534550079277583, 0.2970470520002501, 0.09245875584227697, 0.07659885473549366, 0.08975473272481135, 0.05367789091542363, 2.7330565452575684, 0.4439362585544586, 3.2392358524458746, 55.25856133869716, 56.54378700256348, 69.27507550375802, 45.19699307850429, 48.89495985848563, 41.290542125701904, 71.37883717673165, 8.004919716290065, 0.4295041172632149, 3.3395074776240756, 9.690042870385305, 17.987788336617605, 16.258107253483363, 0.2228055636265448, 0.12365160776036126, 46.190943309238975, 95.00581128256661, 60.54103006635393, 12.29284587928227, 30.205379145486013, 45.61058807373047, 7.609980634280613, 1.7512479658637727, 4.058792812483651, 50.193790095193044, 59.75281946999686, 61.5552864074707, 57.131152970450266, 41.340583051954, 43.23390116010393, 53.05899790355137, 62.40746212005615, 4.699292957782745, 0.3392828442156315, 0.2705804136182581, 0.1721642967313528, 0.3629574195614883, 0.2501718173069613, 0.21775817232472555, 0.2823936811515263, 0.4369543774851731, 2.7244794283594405, 10.631170289857046, 43.702220167432515, 78.83278124673026, 72.93953459603446, 78.43928391592843, 67.9528888974871, 64.8412423815046, 55.35515866960798, 61.19901752471924, 58.11677925927298, 65.47243758610317, 64.60406562260219, 70.35435308728898, 69.12696075439453, 66.8877786908831, 60.630745206560405, 58.19569342476981, 65.36325359344482, 67.89287035805839, 68.22125611986432, 60.784265654427664, 63.168991633823936, 64.81032289777482, 58.57657977512905, 51.56715018408639, 48.88304369790213, 56.69130073274885, 60.14667810712542, 60.30019160679409, 64.83430807931083, 62.6069518498012, 61.85904080527169, 59.687054770333425, 63.0863219669887, 59.39947577885219, 63.10508210318429, 59.944242341177805, 61.261843136378694, 60.58711051940918, 59.39417430332729, 62.60932118552071, 59.74423844473702, 61.882748058864046, 60.45246137891497, 62.30606010981968, 58.69260079520089, 56.005075795309885, 62.92143426622663, 56.23884098870413, 52.58894879477364, 59.61193779536656, 59.184832027980256, 57.67001008987427, 54.99529756818499, 49.13818155016218, 42.921972206660676, 43.12797587258475, 48.51959385190691, 53.84920263290405, 36.51065744672503, 35.478203773498535, 33.525228432246614, 33.53619268962315, 33.91135719844273, 36.48234701156616, 34.56959131785801, 44.81769439152309, 49.11281367710659, 44.35444756916591, 38.36238363810948, 53.709839139665874, 55.24686752046858, 49.27652713230678, 58.02060924257551, 57.3361039842878, 55.21636840275356, 50.866205487932476, 52.53325203486851, 56.047108922685894, 57.48234966823033, 49.62891892024449, 57.70365674155099, 59.38890062059675, 55.52114765984671, 56.360618591308594, 55.27365630013602, 54.04966858455113, 52.779100145612446, 53.09186635698591, 49.3983325277056, 47.98531559535435, 48.884582723890034, 50.672208309173584, 43.658932890210835, 49.27909796578543, 53.99509743281773, 56.42784588677542, 52.70938539505005, 52.021875040871755, 53.66756629943848, 53.49682126726423, 49.32964263643537, 52.02875028337751, 52.23424325670515, 60.216340746198384, 59.79213237762451, 55.272297927311485, 57.10543073926653, 58.42537307739258, 57.96789673396519, 54.18564830507551, 55.52486147199358, 62.02658271789551, 61.72400256565639, 68.24810395921979, 64.96418380737305, 64.26022011893136, 57.67472096851894, 59.81695829119001, 64.21506377628872, 62.15822328839983, 57.549594334193635, 41.957374640873496, 26.78026638712202, 14.55093138558524, 4.996489558901105, 0.3437415792473725, 0.6442858821579388, 0.20846169974122727, 0.285292952720608, 0.6697797998785973, 5.230106668812888, 0.5904841891356877, 3.99567494222096, 71.01314653669084, 61.322806630815776, 80.77571296691895, 50.277432509831016, 64.2405984061105, 54.87816136223929, 82.40521144866943, 13.05626356601715, 1.1493648226772035, 14.385145630155291, 26.387502091271536, 30.46205254963466, 26.500898429325648, 0.7613335528544017, 0.2773478776216507, 56.38930422919137], [56.59466866084507, 28.303876059395925, 6.390196578843253, 22.989945888519287, 24.477867875780376, 2.0686806525502885, 0.27521898757134167, 0.3122759833931923, 8.245714749608721, 37.9743059022086, 22.396625314440044, 59.35090092250279, 92.44896452767509, 26.770922797066824, 36.55668926239014, 16.357245888028825, 1.2797555859599794, 0.12837864910917623, 0.05739944175417934, 0.07881205276186977, 0.03694542770140937, 0.03624243488801377, 0.03442586093608822, 0.11497530261320726, 0.06010938848235777, 0.7463550823075431, 1.4417404596294676, 34.08473907198225, 72.9037652696882, 67.08955437796456, 69.25600964682442, 65.46231406075614, 59.67463139125279, 47.599572454180034, 45.356106826237266, 47.58454697472708, 51.11131361552647, 49.904078006744385, 47.70706108638218, 49.83599608285086, 55.63860348292759, 53.81846032823835, 51.27546828133719, 56.64211790902274, 60.20974690573556, 61.832067898341585, 60.204153605869834, 57.892397608075825, 58.342626980372835, 56.23240000861031, 47.56359815597534, 45.910819734845845, 47.68010902404785, 54.47704185758318, 53.89679084505354, 58.78335121699742, 54.8021411214556, 57.27014820916312, 51.65757404054914, 52.26713602883475, 54.60146672385079, 54.59475128991263, 52.484222071511404, 55.37901183537075, 53.57356759480068, 50.70862034388951, 52.49378279277256, 53.304644516536165, 54.01001174109322, 56.755609784807476, 52.94863966533116, 49.278045313698904, 52.48201254435948, 48.25947414125715, 51.238059180123464, 48.361213139125276, 54.25641223362514, 54.842760290418354, 56.22619179316929, 54.061886991773335, 41.055442878178184, 36.86404282706124, 41.01499046598162, 48.469372272491455, 51.6836575780596, 45.12185525894165, 38.822878973824636, 33.91072491237095, 33.238191400255474, 34.76556525911604, 35.69048513684954, 37.03618792125157, 49.51959596361433, 47.00820779800415, 40.544416768210276, 35.974312101091655, 38.553556374141145, 41.510358810424805, 51.580973625183105, 55.05411754335676, 53.13073805400303, 51.85840129852295, 48.03458179746355, 49.24007340839931, 50.94064848763602, 54.86505705969674, 52.26457561765398, 49.47381428309849, 54.585649149758474, 53.17473404748099, 49.16956308909825, 48.36054611206055, 49.33490937096732, 49.26869303839547, 48.20378085545131, 47.97216612952096, 45.09519154684884, 36.09808383669172, 41.440248012542725, 47.54253816604614, 48.67612634386335, 46.94530575616019, 45.4330199105399, 46.63989421299526, 46.871411664145334, 48.8939836365836, 45.48386682782854, 43.90094559533255, 45.34201240539551, 53.28070797239031, 53.86510705947876, 58.552420888628276, 51.538791111537385, 46.89068596703665, 50.66419356209891, 40.40350035258702, 26.163834367479595, 28.341953924724034, 46.328000000544954, 52.34198897225516, 59.23098891122, 58.164846897125244, 56.41192756380354, 50.22283009120396, 50.8914726121085, 53.48595428466797, 63.918146405901226, 53.21376207896641, 44.095383984701975, 29.397393975939067, 11.655269622802734, 4.20492558819907, 0.8496658386928695, 0.598260688994612, 0.07812561959560428, 0.2174771638321025, 0.46817830630711144, 3.062011625085558, 0.2736069512154375, 2.439368567296437, 39.74241399765015, 55.02035624640328, 59.815853527614046, 44.22547163282122, 42.58756930487496, 36.44546249934605, 56.909335204533164, 13.218338983399526, 0.4014305722500597, 0.13960509241691657, 4.666518305029188, 9.839697514261518, 5.794553569384983, 0.2656402444200856, 0.07082670660955565, 27.579682690756663, 82.78073378971645, 40.28633287974766, 6.19973429611751, 27.25785776547023, 29.216629641396658, 3.238628319331578, 0.4330973673079695, 0.289788437208959, 16.005345685141428, 49.43935121808733, 32.37973799024309, 53.210086481911794, 75.39544486999512, 31.93482051576887, 50.12900856563023, 37.49112122399466, 4.207182015691485, 0.19723039812275342, 0.10374874395451375, 0.09278474442128624, 0.04503670674083488, 0.015650608676618764, 0.08387871445821864, 0.20066276751458645, 0.1187441846621888, 2.00555995958192, 5.721246600151062, 42.566179275512695, 73.17454351697648, 68.65951374598912, 71.0911192212786, 68.40177031925747, 63.28570747375488, 50.68267577035086, 52.148624079568044, 53.3030811718532, 58.156349250248496, 59.153078760419575, 57.26601750510079, 60.29440375736782, 62.698591641017366, 56.2228045463562, 51.508118288857595, 58.927165031433105, 62.26463494982038, 62.205380712236675, 60.50841522216797, 59.27124677385603, 60.56932313101632, 58.274343558720176, 48.21435601370675, 47.189319542476106, 50.35794128690447, 56.20284237180437, 55.51564816066197, 59.138550077165874, 57.898091656821116, 56.641464778355186, 53.88333913258144, 54.30914558683123, 54.707607405526296, 57.59242303030831, 53.96441766193935, 57.26231064115252, 54.20104898725237, 54.32803773880005, 53.73335879189627, 55.14387437275478, 55.06652702604021, 58.29316275460379, 53.38338497706822, 52.02925750187465, 53.77495765686035, 51.86923701422555, 53.67764466149466, 51.88300486973354, 56.579236711774556, 56.31629950659615, 57.86996534892491, 52.95342697416033, 43.31173835481916, 38.599716731480186, 42.81072807312012, 50.34087651116507, 53.480083056858604, 47.77554600579398, 40.688720430646626, 34.86625855309622, 32.69994919640677, 36.66496304103306, 36.21197523389544, 39.00224324635097, 52.27930927276611, 50.5963374546596, 41.321569306509836, 37.31891359601702, 39.684083870479036, 39.99772902897426, 49.12745353153774, 55.300229685647146, 56.488962241581504, 54.9147401537214, 51.21458469118391, 50.699966362544465, 51.605181149074006, 56.102986335754395, 52.98331117630005, 51.08186367579869, 53.609750338963096, 52.71933174133301, 50.43210288456508, 51.28138814653669, 51.405309268406455, 50.50577810832432, 48.766571044921875, 50.607475417000906, 42.53017718451363, 41.55222865513393, 46.57742643356323, 51.01965645381382, 51.029123374394004, 50.79094607489449, 49.47847305025373, 51.51344060897827, 49.318556785583496, 53.690776756831575, 47.57201937266758, 46.83877944946289, 45.90691832133702, 52.68693576540266, 53.36803988048008, 56.85014697483608, 53.641976084027974, 48.298238141196116, 50.37331417628697, 44.159192766462056, 34.85322720663888, 41.55791922977993, 54.12314231055123, 58.21947710854666, 61.8366676058088, 63.64811161586216, 59.26973206656319, 57.0508839062282, 55.5767263003758, 60.72535882677351, 67.23059586116246, 60.361252376011436, 51.405163356236045, 32.48729610443115, 11.370643615722656, 2.533097594976425, 0.4517537419285093, 0.47578066693884985, 0.1783839522727898, 0.17194082800831112, 0.6137340015598706, 0.2866848994578634, 0.36340565979480743, 4.380551295621054, 52.570935589926584, 62.66209970201765, 68.70655305044991, 50.41683421816145, 49.22314759663173, 43.44015148707798, 68.1282683781215, 15.09531579698835, 0.2768026068806648, 2.1991867125034332, 8.963669504438128, 15.290716511862618, 11.550705313682556, 0.07337749616375991, 0.13454468681343965, 41.73427145821707, 101.62983472006661, 55.99746404375349, 17.782220670155116, 41.9324757712228, 55.182836396353586, 11.89317420550755, 0.44541587201612337, 0.39294383621641565, 39.581156730651855, 63.017444474356516, 34.764533451625276, 77.7634882245745, 99.55556120191301, 44.88790593828474, 59.77242728642055, 58.96426146371024, 9.961611475263323, 0.48624709674290245, 0.24473517760634422, 0.2653099335730076, 0.16448462381958961, 0.19600853297327245, 0.1099744588136673, 0.27220137949500767, 0.2859872840344906, 3.130829623767308, 12.550678764070783, 53.13331583568028, 77.28812026977539, 73.93878977639335, 74.06796373639787, 74.43158381325858, 69.88086114610944, 56.50801420211792, 56.983066013881135, 61.31988838740757, 66.25451292310441, 69.6115003313337, 65.42894881112235, 69.10313538142613, 70.06072916303361, 60.24788556780134, 55.530659743717735, 61.10471657344273, 65.46842847551618, 64.93322263445172, 63.57085459572928, 61.8038512638637, 64.41622802189418, 59.49540955679757, 51.32069410596575, 50.97997529166085, 53.29298196520124, 60.473778452192036, 58.266488620213096, 63.51546355656215, 59.73545592171805, 60.34841905321394, 56.35663727351597, 57.80736207962036, 59.15068858010428, 59.2233042035784, 59.10534463609968, 60.387731960841585, 60.97506318773542, 58.20913471494402, 58.91492230551583, 57.23877361842564, 57.69438437053135, 62.62935979025704, 57.52006796428135, 53.77880695887974, 60.57721628461565, 54.82440662384033, 56.14744438443865, 53.463209356580464, 58.9401581627982, 60.28307819366455, 60.100403104509624, 58.200178486960276, 46.66542189461844, 39.60703182220459, 44.74122946602957, 53.20966958999634, 55.758873326437815, 46.83167839050293, 38.152468136378694, 34.666664600372314, 33.55433791024344, 35.97476373400007, 36.83615623201643, 36.48718990598406, 53.48574583871024, 52.38225725718907, 42.75304760251726, 38.805855887276785, 41.112709930964876, 43.107315404074534, 51.02434996196202, 57.72842359542847, 58.04280873707363, 56.32323380878994, 52.47266026905605, 52.90114177976336, 53.107089860098704, 60.01783071245466, 55.746345724378315, 54.85514892850603, 57.7655929837908, 53.6474095753261, 51.34064238412039, 52.48536505017962, 53.40434421811785, 54.69564608165196, 51.71806158338274, 52.89633362633841, 50.28329331534249, 46.696049554007395, 51.02277272088187, 54.99981737136841, 56.40393018722534, 55.9253591128758, 52.36081164223807, 54.24372134889875, 53.345875126974924, 58.30103506360735, 49.299657685416086, 50.38175623757498, 51.0961456980024, 57.766544886997764, 58.119089535304475, 60.70099149431501, 59.197978019714355, 56.57602664402553, 58.68930040087019, 53.19897631236485, 44.49433217729841, 57.51095887592861, 64.0879464830671, 64.82166930607387, 66.37523092542375, 68.01926503862653, 58.97754641941616, 57.98727525983538, 56.8744934626988, 61.44044658115932, 67.36066613878522, 65.98845945085797, 55.5907929284232, 41.34461300713675, 27.224414348602295, 13.323477387428284, 5.539585079465594, 0.8462740321244512, 0.27434880712202614, 0.34374516191227095, 1.7056022094828742, 5.788968954767499, 0.45356966448681696, 7.120073139667511, 68.06715202331543, 66.48206642695835, 79.26365988595145, 56.38367618833269, 59.92341859000069, 53.8994311605181, 76.47281169891357, 18.316919292722428, 0.5666604446513313, 11.2124148947852, 21.51087416921343, 26.16522053309849, 19.910754408155167, 0.2855862426970686, 0.2566516638866493, 41.942161560058594], [55.69010353088379, 41.04441956111363, 7.494579740933009, 31.497500896453857, 28.561214753559657, 1.7815949831690108, 2.547745700393404, 1.1078377195766993, 8.373060464859009, 49.06076124736241, 44.466028690338135, 33.53995861325945, 48.51453903743199, 32.062114988054546, 37.184743881225586, 17.815625871930802, 2.497761662517275, 0.08956700244120189, 0.024290059194234864, 0.07699034229985305, 0.03945470109049763, 0.050169159192591906, 0.08982680671449218, 0.032101308527801714, 0.045006983514342985, 1.4651748878615243, 8.203530498913356, 54.01605667386736, 77.22664260864258, 68.32161590031215, 69.92830344608852, 63.09620925358364, 59.51814406258719, 48.716363361903596, 43.152944224221365, 46.85358258656093, 50.87027365820748, 49.92238303593227, 47.72993803024292, 50.18717541013445, 53.43706675938198, 56.964545590536936, 47.77090808323452, 53.80210426875523, 59.84677301134382, 61.86750371115548, 59.144004413059776, 60.874891008649556, 58.316696303231375, 57.069282736097065, 47.886216912950786, 45.49408067975725, 47.431259291512625, 52.62140730449131, 56.245438303266255, 55.49921914509365, 55.15155560629708, 49.67881393432617, 49.252149377550396, 51.79639557429722, 51.94825192860195, 52.67510298320225, 53.52801520483834, 51.564423016139436, 53.484724453517366, 49.68580729620797, 52.073976108006065, 53.108684471675325, 52.84787341526577, 54.57767261777605, 48.59190375464303, 50.704948220934185, 50.55735806056431, 51.00278622763497, 50.25703607286726, 49.846762316567556, 51.292845726013184, 56.35690825326102, 46.45906387056623, 42.91483988080706, 41.74906069891793, 36.698349135262625, 42.555777822222026, 48.18621233531407, 51.85222087587629, 50.96892070770264, 48.36946759905134, 43.2911890574864, 36.44444806235177, 38.99968630926949, 46.43868827819824, 47.36426476069859, 52.483596733638215, 47.22249024254935, 45.16058104378836, 36.12155832563128, 40.42783989225115, 41.036759172167095, 38.24053307941982, 50.88379832676479, 53.43989815030779, 52.589911120278494, 48.718541622161865, 51.1263564654759, 50.15354265485491, 50.9775573185512, 50.396938051496235, 51.600918429238455, 50.113090242658345, 54.17449644633702, 47.89568383353097, 50.28400897979736, 48.554522446223665, 48.127333300454275, 51.3249568258013, 44.78622252600533, 35.432488100869314, 43.476890087127686, 51.937478746686665, 45.84650373458862, 47.06355019978115, 44.53213037763323, 45.773033482687815, 43.60754748753139, 47.5225829396929, 46.41606146948678, 42.85059336253575, 42.94312947137015, 45.94829484394619, 53.58367027555193, 54.45907729012625, 58.538357734680176, 54.75101280212402, 44.39443097795759, 44.965482575552805, 29.753485679626465, 21.36667125565665, 29.518421173095703, 39.7495185307094, 49.78336695262364, 59.55563654218401, 57.02607536315918, 52.64033072335379, 48.72084147589547, 49.625840868268696, 50.284481457301546, 58.058251108442036, 65.50464943477085, 59.61786460876465, 40.317988872528076, 34.917737756456646, 19.275256531579153, 5.918082118034363, 0.4242212064564228, 0.3133942633867264, 0.02282723268893148, 0.04700916054259453, 0.888017940734114, 0.21632271792207444, 2.3810136871678487, 47.23741497312273, 56.628808634621755, 62.21439252580915, 43.069569315229145, 44.09358787536621, 30.0953266280038, 39.8964729309082, 8.140821269580297, 0.3658020554908684, 6.406835343156542, 4.229272510324206, 8.22764595917293, 5.553397664002009, 0.02415390944640551, 0.419866178716932, 23.867093426840647, 76.7821455001831, 49.54265356063843, 9.826961466244288, 33.17882251739502, 35.59151152202061, 2.371386306626456, 3.3758676179817746, 1.0390925684145518, 12.280344332967486, 50.27355541501726, 41.91134629930769, 41.38565254211426, 59.46389947618757, 37.05569151469639, 47.02017607007708, 39.48832879747663, 3.536967681986945, 0.059928382480783124, 0.043509928310023885, 0.037740212732127736, 0.04727801986570869, 0.05153234622308186, 0.04351430146821907, 0.06214316149375268, 0.049346757786614556, 1.8802277020045688, 12.723047069140843, 56.498731408800396, 76.88002477373395, 71.6500323159354, 72.92390809740338, 68.7371529170445, 66.08742959158761, 55.44326877593994, 48.66254956381661, 55.03101825714111, 60.37294619424002, 58.762263434273855, 55.9906131199428, 59.37285028185163, 59.299817766462056, 61.2900458744594, 52.1123058455331, 56.43921313967024, 60.52994768960135, 61.907247407095774, 62.53812994275774, 60.965321813310894, 59.826254980904714, 59.13242871420724, 50.88371842248099, 47.36592190606253, 52.28003535951887, 56.371655804770334, 58.038156918116975, 58.103414399283274, 56.21102040154593, 52.85934836523873, 50.864944389888215, 52.70659916741507, 53.966734886169434, 52.12117174693516, 54.45048584256853, 54.5292957850865, 55.244790009089876, 52.927336488451274, 54.94688946860177, 54.97168411527361, 54.407010963984895, 53.86160169328962, 51.5242554800851, 53.72937052590506, 53.13467768260411, 54.62904759815761, 52.03341947283064, 53.300854274204795, 53.2807149205889, 55.11210373469761, 45.644206932612825, 45.256087507520405, 45.19854252679007, 38.80966697420393, 45.508154256003245, 50.74303477151053, 53.22956575666155, 53.29963139125279, 49.57746750967843, 46.577169350215364, 38.10342427662441, 41.38505499703543, 48.93981395448957, 50.47647755486624, 53.49790518624442, 49.50580726351057, 48.502119132450645, 39.05190896987915, 42.7957512310573, 43.41458906446184, 37.902562277657644, 49.673859868730815, 54.885731424604145, 55.73277241843087, 50.17175040926252, 52.34944091524397, 52.17959220068795, 51.549175194331575, 51.31670583997454, 53.04016481127058, 49.84660598209926, 53.27488885607038, 50.48057699203491, 50.04906954084124, 50.18005003247942, 50.885326930454795, 50.81105068751744, 45.60989325387137, 42.328568254198345, 49.4694299697876, 51.90118483134678, 49.948720182691304, 51.83892202377319, 49.79036031450544, 50.57934216090611, 47.046971797943115, 49.65916442871094, 50.758921827588765, 46.49100126538958, 45.64635740007673, 45.86145625795637, 54.37183918271746, 55.2631402015686, 59.884731020246235, 53.28183705466134, 48.76661273411342, 50.08071511132376, 37.155047280447825, 30.538246495383127, 40.82571111406599, 49.44503484453474, 57.47651318141392, 63.46720831734793, 61.108030864170615, 57.96918909890311, 54.61926800864083, 53.47719955444336, 54.217748982565745, 63.776535170418875, 67.40490531921387, 60.13201740809849, 47.512990951538086, 37.59131077357701, 12.625769683292933, 3.4751964594636644, 1.0033457151481082, 0.26554158542837414, 0.16456220751362188, 0.16216908235635075, 1.733263639467103, 0.25691387695925577, 3.2612277695110867, 57.526783398219514, 62.57614353724888, 71.59478718893868, 50.19398464475359, 51.74045215334211, 36.37595966884068, 49.395782538822715, 8.936264072145734, 0.4552229829132557, 7.601339680807931, 6.01752690758024, 12.479601298059736, 8.904767019408089, 0.06582221907696553, 0.37124998601419584, 34.71781029020037, 96.89474855150495, 71.85943712506975, 27.273710080555507, 49.776220730372835, 67.40167440686906, 25.067358255386353, 5.49970372234072, 3.3573087624141147, 31.84586272920881, 67.91034507751465, 58.86489527566092, 48.394804205213276, 59.1405303137643, 52.60554109300886, 54.72496747970581, 64.33224514552525, 12.19126842703138, 0.2044085386608328, 0.16647881109799656, 0.1929567131612982, 0.11563724066529955, 0.17786617577075958, 0.1402562146208116, 0.195291864286576, 0.21930069955331938, 3.680549383163452, 18.153044291904994, 64.05121830531529, 79.62558460235596, 74.64137077331543, 77.28696686880929, 73.54919038500104, 71.49842262268066, 58.866819926670615, 54.60006318773542, 60.62303965432303, 70.31524862561906, 70.19147341591972, 65.7069045475551, 66.82914979117257, 69.56453745705741, 66.98026616232735, 56.15492412022182, 59.95064858027867, 64.95716612679618, 66.34202548435756, 63.99909291948591, 64.08290209089006, 64.98771735600063, 60.015329360961914, 51.66431379318237, 49.91939183643886, 54.514322417122976, 57.250714097704204, 61.653540883745464, 60.137749671936035, 59.201604979378835, 54.909285817827495, 55.08163588387625, 55.950348309108186, 55.25154365812029, 57.10013968603951, 57.86825609207153, 58.176533767155235, 58.59604862758091, 56.37862137385777, 57.4940539087568, 59.24312046595982, 57.193947315216064, 56.98221833365304, 54.17009128843035, 55.51751722608294, 56.69421202795846, 56.07922697067261, 55.83685295922415, 55.0756812776838, 54.38604130063738, 58.70849827357701, 49.42996072769165, 48.64850378036499, 47.20065900257656, 42.1436836378915, 47.65638787405831, 54.063422543661936, 57.852949210575645, 56.5402329989842, 49.198776790073936, 44.11715269088745, 37.42096873692104, 41.06575400488717, 47.54769720349993, 51.99045181274414, 57.7036463192531, 52.33331067221505, 49.07749250956944, 40.87232310431344, 43.69156163079398, 44.506637437003, 38.505328927721294, 51.13334287915911, 57.66101912089756, 58.86605562482561, 52.37153966086251, 53.38362121582031, 55.27320466722761, 54.2386873790196, 53.45990548815046, 56.533451557159424, 52.05089766638619, 57.98170975276402, 50.69824668339321, 56.35655389513288, 52.5381817817688, 52.7508487701416, 54.86494588851929, 53.30294220788138, 46.715952668871196, 51.291817392621724, 58.32911968231201, 54.289822646549766, 53.31684902736119, 53.46300785882132, 52.82170649937221, 51.050829546792166, 53.37568984712873, 54.98489958899361, 50.51820843560355, 48.59002774102347, 50.601326261247905, 56.60721015930176, 58.73554761069161, 64.79297324589321, 60.024890082223074, 58.33161408560616, 60.50511482783726, 44.41407353537423, 44.70893423897879, 52.664249897003174, 59.05918080466134, 60.82726110730852, 69.47647598811558, 64.46697766440255, 61.01448726654053, 55.81929833548409, 55.744466236659456, 55.04482085364205, 66.3105570929391, 67.53296061924526, 70.18194743565151, 53.85830477305821, 60.69260501861572, 43.54814733777727, 13.521581820079259, 2.479098149708339, 1.6534763893910815, 0.272395983338356, 0.13567074281828745, 2.2833354771137238, 0.3207923306950501, 4.68964364698955, 68.08495330810547, 67.1289506639753, 80.76281016213554, 56.0501001221793, 59.79938629695347, 45.8591251373291, 61.833818844386506, 11.202333058629717, 0.600725128182343, 22.692886080060685, 17.030521120343888, 20.99777054786682, 14.607673849378314, 0.1856097531105791, 0.49666906893253326, 34.009941714150564], [64.78863756997245, 58.152677127293174, 16.631279366356985, 45.154914787837434, 44.67804602214268, 13.16123000213078, 5.4626311744962415, 1.4077866758619035, 7.554478423936026, 59.67820971352713, 45.302185331072124, 37.21384988512312, 39.14889539991106, 35.83035237448556, 35.86870643070766, 22.10195221219744, 3.426863921540124, 0.04590131302497216, 0.06055055159543242, 0.08330153900065593, 0.08560006280562707, 0.04146130555974586, 0.09482389143002884, 0.02046489266545645, 0.052947213873267174, 2.7075321206024716, 14.229558961732046, 68.57803222111293, 66.83768912724086, 67.86659921918596, 64.69956861223493, 62.69477013179234, 57.931363105773926, 48.972675459725515, 41.94953012466431, 46.70594726290022, 50.79822431291853, 52.272861344473704, 47.95634160723005, 50.62716313770839, 50.78832312992641, 55.305176803043906, 49.65741695676531, 51.81298439843314, 54.762925488608225, 60.88589000701904, 60.010778290884836, 61.450319971357075, 54.564005511147634, 57.96792800085885, 47.41068567548479, 42.06270238331386, 47.03755004065377, 52.16838823046003, 52.95241948536464, 54.5909332547869, 51.77587406975882, 49.78904710497175, 47.84080696105957, 47.607121671949116, 50.62202147075108, 52.786951610020225, 52.60722255706787, 53.4607948575701, 51.89599800109863, 50.761426653180806, 50.641664028167725, 49.96778951372419, 53.69688422339303, 49.00806610924857, 50.0646265574864, 53.147608280181885, 50.610880034310476, 49.52932691574097, 51.851869991847444, 51.61140326091221, 51.12521001270839, 44.644795417785645, 40.827892848423545, 44.485226563044954, 39.93386813572475, 37.31204182761056, 43.61247028623308, 48.254683358328684, 44.798069204602925, 47.68896450315203, 47.739922591618125, 49.72399459566389, 46.51401717322213, 48.081482137952534, 50.01217808042254, 47.52029698235648, 47.25816576821463, 44.70875358581543, 46.429318632398335, 37.644912651606965, 39.81029094968523, 43.05550963538033, 36.93083586011614, 42.761427130017964, 50.10400547300066, 51.982815742492676, 53.22620282854353, 47.432047912052695, 49.709754262651714, 49.556841782161165, 50.90881184169224, 51.83872400011335, 51.44953455243792, 49.39687688010079, 49.2102621623448, 45.405967099326, 51.55211080823626, 48.625088351113455, 42.77430214200701, 39.54674577713013, 46.602408681597026, 50.015759876796174, 47.991322313036235, 48.42169720785958, 45.119267054966514, 42.974451950618196, 41.35483728136335, 42.563306195395334, 43.029307978493826, 42.0961058480399, 40.70750141143799, 40.67197527204241, 46.763554777417866, 53.50601373400007, 57.91334990092686, 58.195728165762766, 50.124123982020784, 31.26547622680664, 25.36977165085929, 21.335307087217057, 17.062534945351736, 25.126054900033132, 39.14652606419155, 43.620068141392295, 47.68489285877773, 51.732333183288574, 50.00025149754116, 49.049157755715505, 47.28536449159895, 49.87329748698643, 54.375205584934776, 59.82025868552071, 65.41498988015312, 63.64816720145089, 47.06976188932146, 33.59398085730416, 20.967413868222916, 4.662387600966862, 1.1894838299070085, 1.5896325409412384, 0.6285022348165512, 0.502040677836963, 0.5760018091116632, 8.94319576876504, 65.78236893245152, 53.98077024732317, 65.99922915867397, 42.62133060182844, 44.712832178388325, 37.88493469783238, 23.399712426321848, 4.856086875711169, 1.9732669038431985, 4.728799785886492, 5.010509720870426, 4.397284729140146, 1.7320443391799927, 0.2681773139962128, 0.32440023709620747, 17.20587280818394, 75.74134704044887, 54.4108498437064, 17.36654990059989, 41.74560744421822, 48.07640300478254, 10.169857672282628, 10.161685722214834, 0.9923140385321209, 15.355081149509974, 60.02076980045864, 50.51453283854893, 34.502235480717246, 39.29260151726859, 44.66188103812081, 44.005119936806814, 43.48980678830828, 5.603237092494965, 0.0385960930559252, 0.10289297558899436, 0.03982323381517615, 0.031069168554885045, 0.03698459274268576, 0.10268296900072268, 0.023293532131771957, 0.11285162371184145, 2.8552955516747067, 17.952734674726212, 69.46959727151054, 69.37614400046212, 70.4081390925816, 72.50535556248256, 70.0939554486956, 64.48988587515694, 55.78518615450178, 46.84371267046247, 53.440346309116904, 59.25458499363491, 60.0121887751988, 56.59438725880214, 58.984814235142295, 58.872197832380024, 60.41968672616141, 52.53156362261091, 55.238838876996724, 58.552684920174734, 61.755199977329795, 62.87976591927664, 62.24146270751953, 60.1797445842198, 58.64310877663748, 49.12417050770351, 44.72692312513079, 49.461592401777, 52.50815861565726, 56.687069279806956, 56.059605257851736, 54.56841761725289, 50.299642426627024, 48.639863695417134, 48.81700454439436, 52.854852880750386, 54.266883168901714, 52.91718864440918, 55.419568470546174, 54.75494200842721, 52.54129804883684, 51.00432872772217, 52.05068227222988, 51.93034642083304, 51.45389802115304, 52.728753498622346, 53.076271125248496, 52.47883721760341, 51.503522055489675, 55.21573611668178, 53.623695373535156, 54.071437290736604, 46.79506833212716, 43.915731361934114, 44.04504081181118, 42.76888254710606, 38.8963804926191, 43.78584173747471, 49.23378528867449, 44.09579740251814, 49.94481182098389, 49.71549694878714, 52.80976602009365, 48.11408308574131, 47.35896328517369, 48.838026319231304, 48.93107312066214, 48.20891210011074, 47.69508586611067, 47.958043915884836, 39.40390471049717, 40.165170192718506, 44.35689333506993, 38.540462493896484, 42.744807038988384, 49.51090724127633, 53.25068480627877, 53.029169287000386, 48.81506599698748, 52.160724367414204, 51.59653064182827, 54.39474739347185, 53.16798039845058, 50.96171889986311, 51.29292563029698, 50.446152142116, 46.80238478524344, 53.1653470311846, 48.885378292628694, 44.60069867542812, 44.221677916390554, 50.90815871102469, 50.82490192140852, 49.77990327562605, 49.63629790714809, 48.931462219783235, 47.216177804129465, 48.394380365099224, 45.41112961087908, 47.02401842389788, 44.81043699809483, 44.831993784223286, 42.812920229775564, 49.723845209394185, 53.73883049828665, 56.983965805598665, 59.858119419642854, 53.952466760362896, 45.05075086866106, 40.02976369857788, 31.7105222429548, 25.90609441484724, 38.41483211517334, 46.59654440198626, 49.67012173788888, 52.321585587092805, 57.7301641191755, 53.42514017650059, 53.4420416695731, 50.83705084664481, 55.18903071539742, 57.19012233189174, 64.241591998509, 69.91157913208008, 64.03077670506069, 59.40743841443743, 40.62121868133545, 14.351578882762364, 2.390069361243929, 1.2713167816400528, 1.9834471004349845, 1.86437668970653, 0.4829004534653255, 0.5906254329851696, 9.935770256178719, 73.73556886400495, 60.63567842755999, 72.347763470241, 50.25386422021048, 49.73035567147391, 45.814007009778706, 33.73704774039132, 8.872649839946202, 5.875673787934439, 5.863853599343981, 4.9032078215054105, 6.902441663401468, 3.087341283048902, 0.16733764644180024, 0.45600299962929314, 24.23003258023943, 95.08299882071358, 83.2982564653669, 52.27105828693935, 61.985650879996165, 89.87116200583321, 42.02549130575997, 13.070436154093061, 4.249599465302058, 34.39016451154436, 75.14275973183769, 59.43778814588274, 52.60198014123099, 51.126196656908306, 57.19198097501482, 54.91804749625069, 62.68261078425816, 16.229869774409703, 0.19084699851061615, 0.2002511274601732, 0.15873071471495287, 0.1611697766929865, 0.12111627523388181, 0.16533195120947702, 0.1275709481643779, 0.48139193441186634, 4.315977777753558, 23.850624459130422, 75.79849597385952, 71.19924708775112, 74.12910093579973, 74.58249173845563, 75.60305704389299, 67.49775409698486, 61.867663519723074, 49.35216869626726, 59.85859189714704, 66.44258676256452, 67.78429780687604, 63.938178062438965, 66.80181557791573, 65.52172115870884, 67.3867496762957, 59.43901102883475, 58.29952730451311, 62.328871045793804, 65.65131895882743, 63.86641011919294, 66.10033934456962, 60.75674383980887, 59.165203366960796, 50.24679095404488, 46.373580183301655, 50.646166460854666, 53.251737458365305, 57.609783104487825, 58.52091775621687, 57.83281333105904, 54.96568781988961, 50.93447501318795, 51.50914314814976, 54.417471476963584, 57.43170772280012, 57.92970943450928, 58.80637754712786, 57.20175361633301, 57.2060614994594, 56.61951541900635, 55.1379406111581, 57.93020275660923, 53.74166536331177, 58.94705772399902, 55.718473025730674, 54.81565189361572, 54.15845305579049, 57.97227757317679, 57.32912104470389, 57.78331436429705, 50.490610190800254, 41.46302420752389, 46.7873523575919, 44.69270672116961, 40.271724292210166, 47.15839658464704, 53.11861344746181, 48.39234454291207, 51.32630477632795, 54.756415026528494, 55.20572376251221, 49.07293449129377, 50.1306483404977, 54.65363032477242, 51.18304334368025, 50.99381957735334, 49.63775702885219, 50.855102266584126, 42.6692419052124, 44.845129353659495, 46.21984086717878, 38.03589473451887, 44.824350765773225, 48.67728321892874, 54.98102944237845, 56.61772625786917, 50.588944571358816, 53.42940289633614, 54.49858474731445, 57.53068828582764, 55.57561458860125, 52.03978749683925, 51.98177351270403, 52.615852219717844, 48.67488956451416, 55.190715653555735, 52.40290035520281, 51.71965272086007, 47.78342178889683, 53.33499772208077, 55.299851008823936, 53.74956546510969, 53.46870885576521, 53.36162321908133, 52.05048772266933, 51.22291905539376, 51.25442566190447, 51.189567702157156, 49.96916873114449, 47.18351779665266, 46.52658993857247, 53.43384974343436, 57.03718900680542, 59.560347420828684, 64.74093818664551, 61.57141317640032, 52.113122258867534, 48.179368359701975, 39.258034229278564, 38.913973331451416, 52.25904485157558, 54.37023762294224, 53.86485692432949, 56.10991716384888, 58.63381903512137, 54.561313084193635, 54.94869947433472, 55.04672466005598, 55.28394658224923, 60.537361417497905, 62.295950480869834, 71.72995049612862, 65.27360793522426, 61.98265620640346, 51.97286592211042, 38.43970666612898, 12.444998400551931, 3.73390850850514, 2.7197946054594855, 1.7208276667765208, 2.02979245356151, 0.9736524799040386, 13.522358281271798, 80.88324328831264, 66.81455162593296, 78.92876366206578, 57.593850885118755, 58.884398869105745, 56.76827982493809, 48.02622658865792, 14.298815999712263, 15.13415970121111, 18.83069167818342, 14.09032574721745, 10.832925132342748, 5.576262014252799, 0.4894417481763022, 0.7277892785412925, 23.969824280057633], [67.45760740552629, 60.03877258300781, 26.379779168537684, 42.12114020756313, 60.43966974530901, 34.93587255477905, 9.634191513061523, 3.0850759531770433, 6.468386394636972, 47.68616785321917, 43.198805809020996, 51.54713242394583, 69.4793803351266, 42.811144965035574, 32.24810436793736, 34.38896247318813, 3.886923909187317, 0.09075464906969241, 0.034187243918755224, 0.07643875439784356, 0.052432887721806765, 0.029740267898887396, 0.085524996476514, 0.13975191382425173, 1.9801284670829773, 6.238778395312173, 30.01397364480155, 69.7187249319894, 66.22676876613072, 71.70033032553536, 62.47643688746861, 62.72549506596157, 54.20866073880877, 49.134919370923726, 41.40209892817906, 46.52292128971645, 49.874357087271555, 53.49802677971976, 49.67428023474557, 50.39489528111049, 52.18692602430071, 52.01193911688668, 49.34669351577759, 48.50890752247402, 54.12921503611973, 57.482964583805625, 60.705917767116, 58.2890077318464, 54.663385595594136, 57.602365902491975, 46.54573917388916, 42.277794292994905, 47.016135692596436, 51.295187268938335, 52.89257117680141, 53.3231440952846, 49.329333441598074, 45.53867074421474, 46.501538208552766, 49.71233204432896, 49.946225779397146, 52.29155894688198, 51.7087926864624, 52.23625823429653, 55.44315413066319, 51.53581380844116, 46.90116385051182, 48.838686398097444, 50.775069441114155, 49.268022537231445, 53.874150139944895, 50.19189671107701, 48.093384402138845, 50.10800763538906, 49.66076946258545, 50.01691327776228, 51.307930265154155, 49.84140525545393, 50.229747022901265, 40.29853739057268, 41.386892795562744, 38.37295879636492, 40.978356088910786, 43.500642504010884, 42.528405393872944, 44.49620819091797, 44.05311461857387, 40.032355376652305, 45.62522097996303, 42.56968116760254, 41.48836776188442, 44.81765965053013, 41.091090611049104, 41.800133432660786, 44.49361651284354, 36.98232201167515, 39.20471027919224, 40.798644406454905, 41.2842435836792, 39.822863715035574, 45.451668875558035, 51.12066241673061, 48.02997166769845, 50.19849055153983, 49.25551577976772, 47.67917449133736, 50.32399933678763, 49.77898958751133, 50.94809695652553, 49.65011440004621, 47.65253509793963, 48.03111812046596, 43.81839404787336, 41.996357509068076, 41.7859000478472, 46.17498329707554, 48.029113565172466, 46.624309403555735, 49.52147545133318, 44.42392955507551, 43.75557885851179, 41.24023716790335, 41.12321560723441, 40.440912927900044, 40.114771434238975, 36.90690279006958, 38.95857381820679, 39.75330529894148, 47.73647281101772, 55.44628776822771, 55.795573711395264, 46.33010530471802, 37.8868385042463, 17.272467817578995, 11.600258128983633, 13.524967329842703, 14.094409550939288, 22.183200972420828, 34.23919057846069, 42.05583756310599, 44.74276154381888, 45.16379458563668, 48.26658909661429, 46.482156208583284, 49.7266001701355, 49.79577643530709, 51.900114808763774, 57.66308273587908, 63.68964794703892, 61.979612895420615, 62.837569509233745, 39.310823168073384, 29.390508311135427, 26.0432414327349, 8.166970814977374, 8.22954455443791, 5.3719254817281445, 1.3116785415581294, 0.6027319090706962, 16.538487911224365, 65.8095155443464, 54.90433522633144, 66.45740727015904, 41.69110924857003, 46.8625214440482, 39.855690479278564, 43.56107446125576, 5.394729469503675, 12.521863715989248, 4.830045027392251, 6.9967886464936395, 1.4520683054413115, 0.4047317536813872, 0.1080598094101463, 0.28991860736693653, 8.220056789261953, 75.56980296543666, 60.97113050733294, 26.01866044316973, 50.193275928497314, 62.42680590493338, 28.91582475389753, 11.668277519089834, 1.6834447298731123, 11.35446560382843, 54.02711125782558, 45.367915289742605, 54.878029346466064, 73.5583689553397, 52.82153279440743, 42.122463839394705, 52.15390471049717, 10.767163038253784, 0.1609666368791035, 0.11775432420628411, 0.05882114903735263, 0.028932393927659308, 0.03744141644399081, 0.06839262507855892, 0.13237615674734116, 3.36018813933645, 8.434632795197622, 33.88463790076119, 72.69147000994, 70.34182548522949, 74.2410364151001, 68.1592573438372, 68.82639557974679, 61.861250332423616, 55.844245842524934, 48.31621660505022, 51.958580425807405, 57.57568481990269, 59.17940548488072, 56.491390636989046, 57.376469544001985, 58.62147903442383, 58.102591037750244, 53.947724614824565, 52.617061206272666, 55.321796894073486, 59.631538663591655, 62.75815854753767, 61.07548550197056, 57.74901110785348, 59.792306082589285, 48.626780237470356, 44.43793017523629, 49.42217527117048, 53.0153215272086, 54.59471307482038, 54.974953242710654, 50.16347163064139, 47.10895667757307, 48.24196120670864, 50.11197853088379, 50.37301887784685, 52.98463828223092, 53.67328814097813, 54.0994176864624, 54.663677419934956, 53.185785157339915, 50.11369126183646, 49.84497315543038, 52.323148931775776, 54.54277529035296, 55.89845221383231, 51.772552830832346, 50.8169983455113, 53.84512056623186, 52.8233254296439, 52.47236844471523, 54.59709630693708, 51.518210547310964, 51.44169003622872, 41.779413904462544, 43.48612076895577, 39.83136831011091, 42.852615288325715, 46.69249207632882, 45.35539810998099, 45.50175149100167, 47.47835070746285, 43.07582269396101, 49.75193330219814, 44.95615461894444, 43.58729001453945, 47.316325664520264, 43.70832763399397, 44.569720132010325, 46.773431641714915, 39.11695105688912, 40.190388679504395, 42.47113834108625, 41.80604634966169, 39.46584095273699, 45.743277822222026, 53.818039962223594, 50.070608956473215, 51.24495874132429, 50.352594648088726, 50.94780513218471, 53.31588670185634, 52.730348110198975, 53.09931135177612, 50.91885198865618, 50.44027049200875, 49.16119745799473, 42.842095715659006, 44.21613672801426, 47.38014486857823, 49.89980833871024, 50.65557084764753, 50.43178326742989, 52.01832798549107, 48.326413086482454, 46.576887948172434, 44.232628277369905, 47.18092611857823, 44.60820967810494, 43.90442664282662, 43.261513301304404, 41.23843758446829, 42.56001622336251, 49.94576025009155, 55.02300698416573, 57.37587199892317, 53.48766701562064, 44.152536392211914, 34.94179936817714, 28.79503205844334, 23.487541130610875, 24.903346027646744, 36.02542999812535, 45.623438767024446, 48.404611587524414, 51.16244888305664, 48.99358606338501, 52.28243943623134, 50.69429663249424, 54.32243054253714, 52.29491492680141, 57.51047250202724, 61.28580747331892, 67.91182504381452, 67.33554145268032, 69.50800691332135, 48.283257825034006, 35.47616100311279, 23.54103183746338, 9.30392278943743, 9.98087101323264, 3.779043572289603, 0.9068376251629421, 0.37359958993537085, 18.804210356303624, 73.85225691114152, 59.925093105861116, 74.28558131626674, 45.33868421827044, 53.22203043528965, 43.68117407390049, 57.50845752443586, 13.75758693899427, 24.27753046580723, 9.640685473169599, 9.963167871747698, 2.658139548131398, 0.0627173717532839, 0.16139547101088933, 0.284444946795702, 16.390585081917898, 89.89659241267613, 80.51156330108643, 70.90216990879604, 61.497018814086914, 90.02949060712541, 62.187176431928364, 15.565967661993843, 7.848589590617588, 23.67444246155875, 71.1987885066441, 57.59382656642369, 70.91182790483747, 85.3069042478289, 61.53572028023856, 52.61666863305228, 70.5946912765503, 28.412608419145855, 0.4327257201075554, 0.12543855687337263, 0.3286713164831911, 0.09592199857745852, 0.08785408149872508, 0.19653734245470592, 0.4130650593766144, 5.523152155535562, 15.309028489249092, 44.88940674918038, 73.97544152396065, 71.4236877986363, 79.28245476314, 72.55847454071045, 73.8287581035069, 65.92886475154332, 61.718020166669575, 52.204716886792866, 57.90176030567714, 62.28139400482178, 66.59585707528251, 63.3833018711635, 64.66379233769008, 65.28085490635463, 63.647444588797434, 57.49258089065552, 56.40531982694353, 59.36919552939278, 62.07411534445626, 64.81023257119315, 62.91528511047363, 59.52584266662598, 61.73574502127511, 51.06678261075701, 46.28943402426583, 51.74763311658587, 55.85925047738211, 58.20963845934187, 59.24799115317208, 53.44152750287737, 49.09770481927054, 50.8830166544233, 53.83265897205898, 55.003510338919504, 56.42241586957659, 57.27906969615391, 57.38433837890625, 59.01631736755371, 56.02307857785906, 53.371823174612864, 53.82559960229056, 56.632814271109446, 56.315736702510286, 60.80412360600063, 54.94727161952427, 53.18526404244559, 53.48641633987427, 55.448271478925435, 54.37893329347883, 55.52751915795462, 51.19488307407924, 53.11035551343645, 44.220719064985005, 46.08431625366211, 42.6773921421596, 45.12448515210833, 49.63968515396118, 47.12158155441284, 48.95702811649868, 48.95013550349644, 45.617890630449565, 51.13165099280221, 46.88683319091797, 44.57889175415039, 48.86828572409493, 45.99771738052368, 47.15790326254708, 49.18450519016811, 42.46396085194179, 42.700234345027376, 44.36779853275844, 43.66075331824166, 39.950627190726145, 49.55297858374459, 53.647482531411306, 51.46127005985805, 53.69296543938773, 52.623269421713694, 53.97625739233834, 53.833458014896934, 53.2221485546657, 53.65467391695295, 53.076500415802, 51.973845618111746, 50.38414989198957, 50.1424811226981, 50.35904952457973, 49.43587711879185, 53.28365748269217, 54.821752411978586, 54.722320216042654, 57.99145460128784, 53.307903221675325, 51.001709256853374, 47.48517383847918, 51.488687651497976, 48.49133552823748, 47.71912315913609, 46.109722341809956, 45.35442883627755, 45.96796172005789, 53.998224122183665, 57.679577759334016, 62.863354274204795, 60.105051449366975, 51.070715291159495, 42.57506602151053, 38.171961307525635, 32.48623997824532, 38.567734173366, 49.54480055400303, 51.485283034188406, 54.25502954210554, 53.88919646399361, 51.60160977499825, 54.08734866550991, 52.96657991409302, 54.09921618870327, 55.934423037937705, 59.16334819793701, 61.988430159432546, 69.2437391281128, 66.76285008021763, 70.83418873378209, 54.60403060913086, 48.904572691236226, 43.366191387176514, 13.64697596005031, 10.530532581465584, 8.255681940487452, 4.6020524842398505, 0.798865333199501, 23.842828580311366, 82.26526083265031, 66.50475229535783, 82.40021569388253, 56.54398155212402, 62.52608176640102, 49.91517775399344, 71.35165582384381, 24.908343519483292, 44.518046379089355, 30.646756512778147, 27.507470062800817, 3.2315624356269836, 0.8203215332967895, 0.3559739642909595, 0.4842991584113666, 14.729623419897896], [53.00637919562203, 56.30746834618704, 50.30552755083357, 36.104618617466514, 53.07381841114589, 37.281608717782156, 9.98659372329712, 1.3910759325538362, 4.468799063137599, 43.763350418635774, 42.3695695740836, 45.127552781786235, 65.70899595533098, 37.31095443453108, 31.69545160021101, 43.032281807490754, 6.759612321853638, 1.6884659975767136, 0.06724664050021342, 0.06691029747681958, 0.11701924007918153, 0.06924024423850433, 0.031056181394628117, 0.26001703473074095, 2.661496396575655, 17.340297869273595, 59.10294055938721, 71.22268336159843, 67.49088232857841, 67.0041401726859, 61.30107266562325, 59.95087092263358, 50.721394606998985, 45.75361326762608, 42.20904881613595, 43.20048379898071, 49.47296660287039, 52.2587947164263, 54.48830836159842, 53.409531048366, 51.33963489532471, 50.469327858516145, 50.578643866947715, 47.25355911254883, 49.39121062414986, 55.17801782063076, 58.94488293784005, 60.91405800410679, 56.48747532708304, 51.48926782608032, 42.983877182006836, 43.42101614815848, 45.10002749306815, 47.87539161954607, 48.96652977807181, 47.35775082451956, 45.09997190747942, 44.088317666734966, 45.51831947054182, 46.58086231776646, 49.43569646562849, 51.013826915196006, 53.71645382472447, 51.897964341299875, 52.73134865079607, 48.86034393310547, 46.011818749564036, 48.87459121431623, 49.76421076910836, 52.58735070909773, 52.70005396434239, 48.9523936680385, 52.58535657610212, 49.583845955984934, 54.613226549965994, 58.16909919466291, 52.01051126207624, 45.25219651630947, 45.63681752341134, 41.585923944200786, 45.09413194656372, 41.10553591591971, 39.71167516708374, 42.52738748277937, 45.25072349820818, 43.77328634262085, 45.61946439743042, 44.45159033366612, 49.93613352094378, 44.95143331800188, 45.63108178547451, 43.89820453098842, 42.2251512663705, 43.50442579814366, 41.30194411958967, 36.32710688454764, 41.35513257980347, 40.678944315229145, 41.53033140727452, 37.321619919368196, 39.66177320480347, 54.715917451041086, 52.04967825753348, 50.230605125427246, 51.53490012032645, 48.882095268794465, 47.51314728600638, 51.16562073571341, 49.15606621333531, 48.00535767418997, 46.978059564317974, 41.800724029541016, 36.435700280325754, 45.31482757840838, 48.74494825090681, 47.791005747658865, 45.22546679633004, 46.84147882461548, 43.042214257376536, 42.38118348802839, 40.49330929347447, 40.50762258257185, 41.815721716199604, 42.87317500795637, 45.14495801925659, 42.32127264567784, 42.403508050101145, 38.66990395954677, 46.0950859614781, 54.40166432516915, 48.52313048498971, 34.03179727281843, 24.133397034236364, 15.543486765452794, 9.229801143918719, 11.085015330995832, 12.570419464792524, 21.517817156655447, 34.688436780657085, 42.871677671160015, 44.29699291501726, 46.88171236855643, 46.63022232055664, 45.62868813105992, 47.07787391117641, 49.83095169067383, 51.257594040461946, 55.805606910160606, 59.16554382869175, 61.35726274762835, 53.82866723196847, 47.77340596062796, 30.322602203914098, 35.613089152744834, 21.87588041169303, 10.954090424946376, 5.695781018052783, 0.8949329182505608, 0.36296371636646135, 29.207499708448136, 66.71415710449219, 57.390456267765586, 58.26774624415806, 43.5990046773638, 42.3291449546814, 49.867179598127095, 51.14999771118164, 10.712902818407331, 24.88987868172782, 14.828808954783849, 10.509492567607335, 1.1920899472066333, 1.3108225017786026, 0.09785370635134832, 0.9462074211665562, 1.7928992680140903, 70.16147804260254, 68.86310986110142, 39.0217398915972, 54.68830183574131, 70.97422967638288, 40.37901142665318, 14.534720369747706, 1.1567480436393192, 6.186382464000157, 53.28251797812325, 47.71445744378226, 54.170765263693674, 74.45791053771973, 46.21653699874878, 42.47461591448103, 55.206932749067036, 24.289210387638636, 2.3839063090937476, 0.18339749824787888, 0.12413677386939526, 0.05048870847427419, 0.03326373061697398, 0.03777353558689356, 0.5075876744730132, 4.6255404353141785, 25.040406193052018, 61.22921439579555, 70.67303221566337, 74.14858368464878, 71.86815711430141, 68.62304959978376, 68.24103764125279, 59.217905453273225, 52.264304637908936, 49.482419627053396, 49.21724162782942, 58.04104042053223, 61.515070234026226, 59.16424451555525, 60.556621823992046, 59.97874014718192, 58.303070885794504, 54.70219128472464, 51.38312714440482, 53.70878301348005, 57.446965966905864, 59.63788931710379, 61.141027859279085, 57.17536783218384, 52.463985443115234, 45.69650254930769, 46.45565925325666, 46.2898404938834, 48.83736971446446, 51.61828197751726, 49.32050575528826, 47.1247673034668, 45.35971641540527, 46.6111147744315, 47.70337854112898, 51.05353587014334, 52.59616449901036, 55.03251211983817, 52.920537676130024, 55.34936039788382, 52.75972509384155, 49.033704962049214, 49.854856967926025, 52.29551942007882, 55.40189225333077, 53.745254107883994, 51.571350370134624, 54.44191523960659, 51.975603512355256, 58.38295432499477, 56.485842500414165, 50.46877895082746, 46.81209489277431, 47.566860335213796, 44.575327328273225, 45.7725818497794, 42.38720062800816, 40.96881968634469, 43.1568386895316, 46.25986596516201, 47.08990471703665, 49.884431975228445, 44.73783874511719, 51.849795954568044, 48.2184693472726, 47.338528633117676, 45.92221130643572, 44.16869442803519, 45.47651563371931, 41.96860292979649, 38.69195754187447, 43.17054748535156, 41.474308082035606, 41.58542367390224, 39.11267096655709, 41.50092315673828, 58.01742696762085, 56.39316395350865, 51.94753279004778, 52.524372237069265, 52.329742772238596, 48.92786652701241, 51.77099296024868, 50.97241217749459, 49.3558269228254, 47.89892169407436, 43.79724720546177, 42.41137341090611, 49.22185523169381, 50.637658391680034, 50.2775992665972, 46.782092571258545, 49.01862737110683, 46.05925062724522, 45.96548816135952, 44.304448332105366, 46.15803664071219, 47.823401723589214, 47.441865716661724, 47.99838168280465, 48.31374652045113, 45.40677656446184, 43.67348936625889, 45.93232788358416, 54.51003885269165, 54.72990070070539, 43.29208190100533, 34.59052276611328, 28.21814397403172, 21.02058843203953, 19.66299727984837, 23.73056479862758, 33.88750750677926, 45.54827662876674, 47.00527913229806, 49.08625766209194, 49.83187232698713, 50.04474776131766, 49.58039617538452, 51.47400263377598, 53.23478732790266, 56.89198555265154, 59.38840729849679, 65.00098841530937, 67.63603019714355, 64.85856424059186, 59.08202648162842, 40.30339765548706, 46.26345470973423, 25.72617949758257, 11.142806104251317, 5.978223987988063, 0.9978760715041841, 0.17952983507088252, 32.55533286503383, 75.01544094085693, 63.334949357169016, 69.10003648485456, 47.29164566312517, 51.75119406836373, 46.989260060446604, 62.67205647059849, 18.195108686174663, 42.61350693021502, 31.108165536608013, 7.2159170252936224, 1.5432817595345634, 0.5417236313223839, 0.15517969668975898, 0.4029858559370041, 6.643626042774745, 67.3217145374843, 78.01710442134312, 78.4838010243007, 66.09211962563651, 75.89176164354596, 54.90390791211809, 23.953228507723125, 15.22688341140747, 16.597898483276367, 71.53854152134487, 60.15748255593436, 59.13563878195626, 80.39118576049805, 53.06383384977068, 52.99797534942627, 70.2684941973005, 51.95186499186924, 4.038375530924116, 0.2570371532014438, 0.16502814394022736, 0.20370702844645294, 0.24140101937311037, 0.14306028772677692, 0.7115643663065774, 6.578150127615247, 36.460310799734934, 64.9711389541626, 74.25188255310059, 72.96825844900948, 75.03617436545235, 71.82630811418805, 71.36715030670166, 61.93463025774275, 54.93161037990025, 51.406038829258506, 52.499598434993196, 62.27113846370152, 66.27252265385219, 65.46785872323173, 68.45793260846818, 66.18054240090507, 62.27348000662667, 60.49156584058489, 55.45209298815046, 55.45452833175659, 61.658439363752095, 62.71515614645821, 62.69893905094692, 58.88760198865618, 56.29876225335257, 48.78710991995675, 49.568549496786936, 51.73462608882359, 52.033356939043315, 55.2932710647583, 53.17158998761858, 50.68840108598982, 49.74938678741455, 50.92081138065883, 50.79603215626308, 53.05417585372925, 57.928823539188926, 59.67773723602295, 56.833902086530415, 60.025327818734304, 56.23250423158918, 50.52512189320156, 53.21445689882551, 55.42591912405831, 60.359779357910156, 58.67879472460066, 53.84290756498064, 57.31224039622715, 55.339452266693115, 59.779847962515696, 61.24621663774763, 53.79955775397164, 50.67990343911307, 50.91341502325875, 46.43148994445801, 49.62917252949306, 44.88813175473894, 43.73630802971976, 46.75065892083304, 50.81265919549124, 49.81704139709473, 51.28757899148123, 47.958273206438335, 54.30506699425833, 48.49512577056885, 51.23219837461199, 48.15610926491873, 46.139526639665874, 46.74117462975638, 45.08863244737898, 40.37810468673706, 45.07149818965367, 45.12743466241019, 44.474338735852925, 38.47153983797346, 41.674728870391846, 55.71721192768642, 56.58354459490095, 54.65877546582903, 54.99616609300886, 52.272236006600515, 50.56535543714251, 53.863112926483154, 52.27544954844883, 51.75420263835362, 51.89445202691214, 49.69019160951887, 44.507078647613525, 52.52913522720337, 55.020762716020855, 54.87528828212193, 49.24915470395769, 51.25366136005947, 49.58303301674979, 50.04749577386038, 48.61592020307268, 50.201106548309326, 52.15207386016846, 51.3061306817191, 50.339542457035606, 50.36825936181204, 47.921381746019634, 46.38220637185233, 50.487028394426616, 56.34118447984968, 59.61188220977783, 52.96154247011457, 43.83289493833269, 39.140759059361045, 32.01899446759905, 31.461401530674525, 38.973877225603374, 47.14987114497593, 52.116502557482036, 52.1894655908857, 51.6398491859436, 51.927376065935405, 52.49994237082345, 50.70743220193045, 52.470787729535786, 54.52281311580113, 59.95749255589077, 61.36318956102644, 65.43072754996163, 68.45113032204765, 62.31459249768938, 60.9959077835083, 43.67736646107265, 48.29022339412144, 31.579211711883545, 11.939728873116628, 9.682591795921326, 1.9044916800090244, 0.28157018391149385, 34.869253226688926, 82.3665794645037, 65.63422639029366, 77.51360321044922, 53.86400924410139, 62.43065520695278, 52.85034349986485, 75.39019203186035, 35.070486954280305, 62.161947522844585, 69.09683336530412, 35.24028008324759, 4.325614060674395, 2.3089489255632674, 0.32555059822542326, 1.9193764584405082, 10.586442129952566], [27.86689169066293, 52.587218693324495, 50.1454757962908, 40.235948017665315, 40.92184638977051, 30.676077910831996, 6.742944027696337, 2.83570054599217, 2.8040343480450765, 32.19482210704258, 46.38578816822597, 23.521620307649883, 49.76517309461321, 42.1139349256243, 40.97008078438895, 45.920884200504844, 15.047937767846243, 5.935965478420258, 0.1989053753869874, 0.14588566683232784, 0.02842632894005094, 0.03372113446571997, 0.049774390911417346, 0.1932134029588529, 1.705757458295141, 13.792317509651184, 62.041021074567524, 68.63238103049142, 67.32960769108364, 62.53300217219761, 61.91352163042341, 57.7599058832441, 49.68416057314192, 46.82550491605486, 46.13674736022949, 44.792107650211875, 50.465211050851, 52.65517554964338, 54.74053839274815, 53.74891580854143, 53.076604638780864, 54.218700885772705, 52.261653900146484, 47.63451147079468, 50.46558277947562, 51.44633143288748, 55.08127805164882, 56.50975472586495, 53.38598707744053, 48.85307264328003, 40.96554013660976, 42.6221296446664, 43.1848121370588, 46.64312859943935, 45.95339829581124, 45.37158741269793, 43.60460492542812, 43.498926298958914, 45.53252158846174, 46.49148416519165, 48.923016684395925, 49.85837970461164, 53.61802911758423, 51.582206930433, 52.37622274671282, 48.44393144335066, 43.276521410260884, 47.76049620764596, 47.531167439052034, 51.728664534432546, 51.17471940176827, 51.63619443348476, 51.2106693812779, 50.394579138074604, 51.610479150499614, 47.96758379255022, 41.58605595997402, 44.4911846433367, 49.873901980263845, 45.06931298119681, 42.67064544132778, 41.34246253967285, 40.406859806605745, 40.0269809450422, 40.9555937903268, 45.800148827689036, 42.51217440196446, 46.68713501521519, 48.71810041155134, 48.330641065325054, 44.287922041756765, 42.85088171277727, 46.289079666137695, 41.6777617590768, 40.736972195761545, 40.07192884172712, 42.91490241459438, 40.14900173459734, 45.7702750478472, 45.61485079356602, 41.352412360055105, 39.69611120223999, 47.389240060533794, 51.43823330742972, 54.027472564152305, 53.87753391265869, 47.65920884268624, 48.804945945739746, 47.65651641573225, 46.80578940255301, 41.65195962360927, 41.65381131853376, 45.809855461120605, 49.95117637089321, 46.546618121010916, 45.97812346049717, 45.747769832611084, 42.98495762688773, 44.1380216053554, 40.41179302760533, 37.83217702593122, 41.7296404838562, 42.626065799168174, 47.5386506489345, 49.156191280909944, 49.28522975104195, 47.64832101549421, 49.49028498785836, 46.90466921670096, 47.55364138739449, 43.28597443444388, 29.9886474609375, 24.451080833162578, 17.494092770985194, 9.786270209721156, 12.390703439712524, 14.33015411240714, 25.394029549189977, 31.43520334788731, 40.543225152151926, 43.62908690316336, 45.89398077556065, 46.644469601767405, 50.85107231140137, 51.44311441693987, 57.141380718776155, 54.90509952817644, 58.344773973737446, 55.03955411911011, 59.4211402620588, 55.627621855054585, 55.29722458975655, 36.95663104738508, 39.80813353402274, 28.72674342564174, 14.368515985352651, 7.5952304771968295, 0.14700216906411306, 0.10841038809823138, 40.725823811122346, 66.35663059779576, 51.98052283695766, 54.12027965273176, 43.56231818880354, 34.222709451402935, 62.413868359157014, 38.15319422313145, 25.085564272744314, 34.28387444359915, 33.909981455121724, 21.436644826616558, 12.110098702566964, 1.1015796725239073, 1.417850164430482, 1.971540059362139, 3.0026507760797227, 46.75907318932669, 64.60865143367222, 52.36888197490147, 50.4270133290972, 59.19461509159633, 41.194476331983296, 11.565610068184988, 5.109751709869929, 5.205007604190281, 40.07514933177403, 53.815802642277305, 39.47826780591692, 59.01104368482317, 49.79982376098633, 50.213429178510395, 58.9283184323992, 32.63752310616629, 15.057875428880964, 0.3084622908915792, 0.051260012800672224, 0.07512580270745925, 0.06225903491888728, 0.1333787872322968, 0.13045758541141236, 2.9475302823952267, 23.425822019577026, 69.50434521266392, 70.7287289755685, 72.80073043278286, 67.99637767246791, 69.72149726322719, 63.10327557155064, 56.629416601998464, 51.60850238800049, 50.88965565817696, 50.14726843152727, 57.85810824802944, 60.24717685154506, 61.252852167402, 60.021006039210725, 58.878861154828755, 60.266617911202566, 57.768236773354666, 52.339532784053254, 53.70536797387259, 54.93101978302002, 55.35622869219099, 58.87312889099121, 55.56477887289864, 50.73732335226876, 41.48255559376308, 45.17867415291922, 45.48898070199149, 46.95733308792114, 47.98657669339861, 49.31099019731794, 44.84678302492414, 47.71813998903547, 48.81539256232125, 48.21047197069441, 49.54839277267456, 51.75616897855486, 54.48058196476528, 52.86156484058925, 55.00878054755074, 50.955746923174175, 45.22885056904384, 50.99734231403896, 48.893893310001914, 52.14592817851475, 52.54464013235909, 51.69193288258144, 52.0385159764971, 51.77889306204659, 53.940307412828716, 49.63179547446114, 42.0961058480399, 45.63381242752075, 52.295227595738, 45.6728196144104, 41.59979602268764, 42.7471034186227, 42.02813162122454, 41.94066422326224, 42.91765737533569, 46.69111285890852, 45.3923590523856, 47.80923087256295, 51.181386198316304, 50.663342407771516, 44.533839634486604, 45.32054941994803, 49.05447312763759, 41.906576360974995, 41.438215664454866, 41.556390626089915, 43.04089409964425, 42.29976797103882, 47.543816634586875, 46.389578410557334, 40.68785885402134, 40.8307728767395, 46.80067900248936, 49.70526920046125, 53.66115311213902, 54.950259344918386, 50.77420439038958, 49.52662059238979, 49.457430430821006, 48.9468594278608, 44.64432988848005, 45.38028655733381, 49.44832134246826, 49.88081891196114, 48.47494125366211, 48.399254526410786, 46.96799162455967, 43.44225331715175, 45.49881935119629, 44.10931512287685, 42.37894269398281, 44.64680692127773, 47.86965240750994, 50.64978299822126, 53.08316026415144, 51.661989620753694, 50.90387167249407, 52.848331996372764, 47.416716711861746, 48.323672022138325, 49.246712412152974, 37.78962278366089, 33.453856536320274, 27.82799220085144, 19.78573547090803, 21.953879152025493, 23.633772918156215, 34.32321514402117, 42.758845874241416, 45.310203552246094, 47.56675263813564, 48.34868901116507, 50.295226846422466, 53.59132024220058, 54.26075485774449, 57.37152590070452, 59.183407647269114, 60.689304624285015, 61.07857745034354, 62.91866888318743, 66.24398640223912, 62.6938807623727, 47.82726839610508, 49.02674981525966, 37.60679483413696, 16.405289207186016, 8.489332488604955, 0.7364984112126487, 0.16305775967027458, 44.8748641695295, 72.44051497323173, 60.15904590061733, 61.9455806187221, 50.199345179966514, 47.151021071842735, 55.92210040773664, 47.65352521623884, 37.92193385532924, 53.34323481151036, 52.04140642711094, 17.27663152558463, 3.926199904509953, 0.14663014188408852, 0.1779329436165946, 1.439478603856904, 2.5239114250455583, 38.11501734597342, 67.24572208949498, 65.29566846575055, 68.77058070046562, 57.827584811619346, 49.18215322494507, 22.946354627609253, 12.228475161961146, 15.337642908096313, 56.09633690970284, 72.4396881375994, 37.75199481419155, 66.2696669442313, 57.7697480065482, 62.71614279065813, 70.06229250771659, 57.2306581224714, 25.497727939060756, 0.39235918330294745, 0.2344519251159259, 0.17510746951614106, 0.18250702960150583, 0.16361776819186552, 1.214282927768571, 6.151371794087546, 36.37500776563372, 72.84241267613002, 72.95134653363908, 75.3585707800729, 68.26060376848493, 73.03174413953508, 65.44315787724086, 60.22012056623186, 54.533836432865684, 55.68418366568429, 54.14316007069179, 64.4604741505214, 62.77378504616873, 65.10443319593156, 66.05101408277238, 64.90515886034284, 65.50302355630058, 60.55409267970494, 55.43975993565151, 57.833674907684326, 57.663523946489605, 58.18939140864781, 59.96732425689697, 57.336253370557515, 54.51747342518398, 44.97972638266427, 48.65506287983486, 49.19503171103341, 51.09928628376552, 51.075954232897075, 52.58608266285488, 49.08570180620466, 50.99863467897688, 50.340605531420024, 52.84125525610787, 51.817827292851035, 54.47975165503365, 58.103747912815635, 56.28264243262154, 56.372163023267476, 53.28192390714373, 47.797238281794954, 55.116144112178254, 51.08961091722761, 57.46982206617083, 54.365363461630686, 55.09373617172241, 56.18678855895996, 56.13581657409668, 56.51938492911202, 54.42373527799334, 45.19390460423061, 47.42798668997628, 53.04704005377633, 48.726525102342876, 46.95638118471418, 46.276051793779644, 44.471833910260884, 45.20487233570644, 47.29349735804966, 50.046203408922466, 47.082386766161235, 52.309297697884695, 53.92201975413731, 54.17398575374058, 48.0759722164699, 47.28329392841884, 51.34197643824986, 45.33973339625767, 43.97325202396938, 43.424855027879985, 46.38629886082241, 44.60746969495501, 50.06057923180716, 47.88502182279314, 41.66832957948957, 42.6029109273638, 50.8807897567749, 53.65861701965332, 57.994192191532676, 57.85127469471523, 52.386433124542236, 52.523951871054514, 50.225487777165, 52.25447293690273, 50.90420171192714, 46.973970549447195, 50.81656060900007, 54.37905141285488, 52.04973036902291, 52.033297879355295, 51.19343784877232, 47.44759103230068, 51.6575288772583, 50.98011078153338, 46.503261361803325, 48.04452466964722, 51.16026714869908, 54.95090900148664, 56.558722155434744, 55.12777887071882, 53.22840193339756, 55.52813407352993, 50.019070693424766, 52.20935133525303, 55.04616185597011, 48.45875195094517, 44.37924916403634, 40.192883082798545, 32.248163427625386, 34.7306991985866, 37.44617680140904, 46.30507789339338, 48.537176268441335, 50.19763592311314, 48.53921556472778, 51.343637057713096, 52.91062607084002, 54.83163969857352, 55.32366248539516, 59.84197875431606, 60.90378161839077, 61.56070600237165, 61.669097900390625, 63.093478611537385, 66.31710924421037, 65.60971314566476, 55.45824909210205, 53.11841194970267, 41.533263547079905, 17.205167566026958, 12.822939583233424, 1.6528355266366686, 0.2669705258948462, 49.68043981279646, 79.06084891727993, 65.29951776776994, 71.1144026347569, 58.57965782710484, 56.13159554345267, 62.07633876800537, 53.90087291172573, 63.301743916102815, 73.28677776881626, 73.05568068368095, 37.63837787083217, 17.533775670187815, 3.1415172559874396, 1.2912316215889794, 8.044591324669973, 17.662093264716013], [7.22495185477393, 35.38187394823347, 42.580857345036094, 43.075176511492046, 41.07183367865426, 24.2847809110369, 4.2015635286058695, 4.45285381589617, 3.027859057698931, 24.415205546787806, 44.608095032828196, 18.1603034223829, 42.05193614959717, 43.574894428253174, 47.24072578975132, 53.417458942958284, 21.173464434487478, 1.2140574370111739, 0.04364854622898357, 0.0228902787701892, 0.03679644516003983, 0.03162769108478512, 0.08420973098171608, 0.33425180560776163, 2.6700900154454366, 30.17770447049822, 68.5730573109218, 66.39818777356828, 70.56381348201207, 63.55476256779262, 61.23651695251465, 55.36218329838344, 51.865342548915315, 48.607432978493826, 46.994516372680664, 43.61847005571638, 48.70440203802926, 52.95343739645821, 53.89692633492606, 55.973867961338584, 55.9795481136867, 52.55997828074864, 53.27306147984096, 52.820327281951904, 48.2227702822004, 49.65146235057286, 50.89382805143084, 53.03156294141497, 48.408530371529714, 45.342113154275076, 39.46956518718174, 42.14947496141706, 42.024313586098806, 44.140050479343955, 46.7966559955052, 44.8318305015564, 43.96896845953805, 47.18086358479091, 43.920338017599924, 46.597871507917134, 46.38021918705532, 50.45719630377633, 51.9043219430106, 51.42004639761788, 51.558892250061035, 49.68772847311837, 44.46668529510498, 46.649399348667686, 46.998410837990896, 47.51303611482893, 46.77177102225167, 50.91870607648577, 50.34621620178223, 48.11570201601301, 40.99289519446236, 40.719778878348215, 45.452860491616384, 46.09040982382638, 47.4378843988691, 42.446333272116526, 40.64383506774902, 38.303271838596885, 39.486973898751394, 40.20695318494524, 38.38697331292288, 41.58759846006121, 41.78387117385864, 42.413600308554514, 50.08078806740897, 46.75863545281546, 42.73854323795864, 42.99075589861189, 42.41017484664917, 39.56318521499634, 37.29606097085135, 38.58480589730399, 39.90829529081072, 38.654881954193115, 44.563991342272075, 45.480191230773926, 38.52073655809675, 31.94265113558088, 41.66355616705758, 39.3430940764291, 45.36689737864903, 49.776179041181294, 50.88595921652657, 49.21699844087873, 46.289722374507356, 44.45337949480329, 41.664066859654014, 41.25235135214669, 49.1517652784075, 45.93499946594238, 50.021540778023855, 44.429026058741975, 43.68223367418562, 41.618781975337434, 41.0653475352696, 37.713206495557515, 38.052844864981516, 42.60013859612601, 45.08729144505092, 48.732646465301514, 52.32248885290963, 53.96892009462629, 52.21756758008684, 52.54727349962507, 52.3850747517177, 48.38247810091291, 42.46011849812099, 33.79653474262783, 31.255693163190568, 21.347270148141043, 17.135704687663488, 21.249465567725046, 22.827198232923234, 33.05723599025181, 36.14225353513445, 41.94433287211827, 43.13325302941458, 47.272430419921875, 49.54076712472098, 51.24839115142822, 55.03572218758719, 58.21010051454817, 57.95527185712542, 57.877955777304514, 59.2852543422154, 60.0793639591762, 55.65238176073347, 60.33835111345564, 45.88320411954607, 48.257771832602366, 43.0198757989066, 20.035953998565674, 8.654880268233162, 0.7984043636492321, 0.5936185866594315, 48.61600010735648, 65.55198751177106, 52.444982119968955, 55.41485064370291, 41.77473776681082, 31.136555876050675, 58.500385829380576, 26.318958112171718, 25.338475227355957, 18.555485691343033, 28.78880647250584, 23.12965852873666, 6.534107233796801, 2.3513911281313216, 0.3694165843938078, 2.7113907592637196, 2.1998259467738013, 18.194130727222987, 50.42095797402518, 55.070497921534944, 50.39802891867501, 48.84269898278372, 35.496074540274485, 10.508714369365148, 6.595667839050293, 4.197891839912959, 31.952486310686382, 50.38740164893014, 27.933207035064697, 50.968927655901226, 48.73214272090367, 55.05773755482265, 64.38050733293805, 36.756745270320344, 10.090165308543614, 0.12512446301324026, 0.030722287882651602, 0.012558170910259443, 0.026727480813860893, 0.11760165382708822, 0.557964122721127, 2.6374997070857455, 41.390273094177246, 72.40362003871373, 67.63507829393659, 75.2066136768886, 68.38927050999233, 66.95671871730259, 59.81754888807024, 57.60116733823504, 51.73622070040022, 53.69097825459072, 48.703036717006135, 56.24935013907296, 60.15178503308977, 61.31020259857178, 61.59983825683594, 61.967668942042756, 60.15088176727295, 58.94521645137242, 57.96387372698103, 51.718468053000315, 52.86855125427246, 52.749222891671316, 55.06053767885481, 50.2786032812936, 46.182403973170686, 41.206514086042134, 44.430895124162944, 43.4329149382455, 46.14246572766985, 48.61458267484392, 48.036075660160606, 45.53083317620413, 48.88658727918352, 47.26051425933838, 49.53536490031651, 48.52191802433559, 51.946723324911936, 54.49764674050467, 54.91645635877337, 54.465803146362305, 52.71616336277553, 45.638815130506245, 50.417105197906494, 49.4416823387146, 49.872786794389995, 49.33549649374825, 53.67835685185024, 52.76910168784005, 49.72794117246355, 42.92874322618757, 42.74972983769008, 46.5110433442252, 45.64988361086164, 50.21819216864449, 44.65934494563511, 41.64423322677612, 40.57073654447283, 40.79250219890049, 42.233384881700786, 41.07837540762765, 43.804195404052734, 43.28124965940203, 46.485706738063264, 50.331489494868684, 49.32582460130964, 45.72117560250418, 44.19060557229178, 43.73394216809954, 40.443605354854036, 39.91247115816389, 38.75060381208147, 39.6536750793457, 40.09613636561802, 44.39757851191929, 45.974308899470735, 40.525910241263254, 34.60946702957153, 40.06873614447457, 40.98120485033308, 45.50709465571812, 49.268467221941265, 51.41863243920462, 51.46297584261213, 47.005150590624126, 45.35528346470424, 46.74598625728062, 42.65782254082816, 49.718845980507986, 48.95876864024571, 50.18739080429077, 46.052121775490896, 47.21546561377389, 44.94787584032331, 43.51458753858294, 42.670530796051025, 41.88365077972412, 45.53339358738491, 49.2865047454834, 52.551855836595806, 52.92306334631783, 54.80136987141201, 53.17341388974871, 54.50089849744524, 53.250201906476704, 49.88647127151489, 47.87501294272286, 42.05907194955008, 40.37073264803205, 30.684433119637625, 27.74875147002084, 29.30596263068063, 32.00943374633789, 40.67943416322981, 44.1053581237793, 45.48233822413853, 47.594402994428364, 51.229561533246724, 52.269870144980295, 54.29647902079991, 58.03615583692278, 62.86993421827044, 61.748168400355745, 63.617921692984446, 65.68542071751186, 64.13007341112409, 63.04432705470494, 65.30284595489502, 55.572317668369834, 53.11205087389265, 50.656609603336875, 23.896956784384592, 9.043685827936445, 1.0934127164738519, 0.5260792736496244, 57.52052654538836, 69.83433600834438, 60.61479909079415, 59.751985686165945, 50.055051939828054, 38.57656185967581, 58.35190282549177, 41.591367857796804, 46.575738021305625, 42.4870879309518, 44.82212039402553, 28.39196879523141, 10.944129313741412, 1.1998776836054665, 0.29020462344799725, 2.276645664657865, 4.894097430365426, 11.18383000578199, 44.76776116234915, 53.2082382610866, 60.1367004939488, 50.230629444122314, 38.41835137775966, 18.872016089303152, 9.801734294210162, 12.933389016560145, 51.35438592093331, 67.77647413526262, 32.80523524965559, 57.20900058746338, 60.10297393798828, 63.909134592328755, 77.04262651715959, 54.790690490177695, 28.677004746028356, 0.4208993432777268, 0.1284713369927236, 0.12620969835136617, 0.17747638454394682, 0.31028247464980396, 1.9573605230876376, 14.210793614387512, 57.987761633736746, 75.11920533861432, 69.5156499317714, 76.51695360456193, 72.0025908606393, 66.12597124917167, 61.96823869432722, 60.156495911734446, 54.32309062140328, 56.28511946541922, 52.88570983069283, 58.13389614650181, 62.97308022635323, 63.10832691192627, 66.32600988660539, 66.80795778547014, 61.96462563105992, 63.065463474818635, 62.0520270211356, 53.875838552202495, 54.6805476461138, 55.44313676016671, 58.74140494210379, 52.77850954873221, 49.568754468645366, 41.96684850965227, 48.49542801720755, 47.92412281036377, 50.255497046879356, 52.317573002406526, 50.32006665638515, 49.58726099559239, 53.61116777147566, 49.30296850204468, 52.25413942337036, 51.12449434825352, 58.20590727669852, 58.08816657747541, 57.94761494227818, 57.64024748120989, 54.99463401521955, 48.37521375928606, 53.20297152655465, 53.02047709056309, 53.247089113507954, 50.16267606190273, 56.08486195972988, 56.700927461896626, 53.10083300726754, 47.35447474888393, 45.8808000428336, 47.74124274935041, 50.107222488948274, 53.79982525961739, 47.09421260016305, 44.34860413415091, 42.548676763262065, 42.8021366255624, 43.93010023662022, 42.262480463300435, 46.08259310041155, 46.85158150536673, 49.38861894607544, 53.428548267909456, 52.50077268055507, 48.22140843527657, 45.906831468854634, 45.211959498269216, 41.94030291693551, 41.52534260068621, 40.32786921092442, 42.433263710566926, 41.831115450177876, 46.6385532106672, 50.444717339106965, 41.936641216278076, 35.62199674333845, 42.26456492287772, 42.18192999703543, 47.85801417487008, 54.16518586022513, 54.50362566539219, 53.33691542489188, 51.319703987666536, 47.42519351414272, 50.250970295497346, 45.72069270270211, 52.50350332260132, 52.89425611495972, 54.302252973829, 49.371043477739605, 51.09438780375889, 48.88162973948887, 46.81726087842669, 46.08429193496704, 44.94819893155779, 50.28371368135725, 51.439911297389436, 53.72178656714303, 57.28254379544939, 57.64704976763044, 56.560858726501465, 55.0263351712908, 56.44306591578892, 53.19005829947335, 52.13029473168509, 52.40881674630301, 50.228305271693635, 41.05252810886928, 40.24205201012747, 46.5350980077471, 48.873323168073384, 51.001504284994944, 49.1328627041408, 47.642765930720735, 48.11406224114554, 52.96301896231515, 53.534629889896934, 55.1476993560791, 60.73668439047677, 62.901833398001536, 64.40080302102226, 64.38776125226701, 66.500333241054, 65.41911711011613, 64.49142142704555, 65.90638038090297, 60.078898429870605, 60.42820521763393, 57.85516916002546, 26.923847436904907, 15.963580063411168, 1.7758052881274904, 0.731783461357866, 62.36803109305245, 73.99598734719413, 67.5718218939645, 67.98159190586635, 59.39220101492745, 48.39101396288191, 64.13523592267717, 48.18114709854126, 62.11168425423758, 53.52861622401646, 43.127107347760884, 31.312616280147008, 25.00386561666216, 5.5015367439814975, 3.2442939238888875, 8.954546519688197, 18.13363971029009], [0.25759797596505707, 10.236687183380127, 26.971624987465994, 29.117996488298687, 22.556638853890554, 10.908414704459053, 2.503319569996425, 2.375728279352188, 1.2981333541018623, 26.36457129887172, 38.45192507335118, 25.83886538233076, 36.27513435908726, 39.24850824901036, 49.014632156917024, 56.920160497937886, 28.050734077181133, 6.9529172863279065, 0.06968210624264819, 0.052817532260503085, 0.03502517359863434, 0.05595616384276322, 0.34616671768682344, 1.6142845324107578, 5.741248292582376, 52.31377233777727, 66.6015407017299, 66.55657196044922, 65.14473969595772, 64.60679626464844, 61.22132819039481, 59.67019149235317, 55.85005106244768, 49.66507734571184, 46.81856019156319, 46.351248673030305, 45.88639334269932, 50.633656229291645, 53.46880265644619, 55.188315050942556, 54.25700977870396, 55.85073546000889, 55.399116447993684, 53.53254543031965, 53.844495228358674, 47.18521315710885, 47.63617556435721, 48.43053879056658, 46.02303661618914, 41.023039954049246, 42.559446471078054, 42.599329130990164, 40.4751467023577, 41.94749430247715, 43.085654394967214, 42.83006490979876, 42.60633986336844, 42.1331466947283, 44.82689380645752, 48.32553761345999, 48.51952089582171, 51.21163170678275, 52.96084417615618, 53.019101347242085, 54.8110591343471, 50.58225693021502, 45.972894941057476, 48.141927991594585, 47.495933123997276, 44.607563495635986, 46.59807995387486, 50.70702920641218, 50.62243488856724, 46.39833314078194, 43.27747678756714, 38.623847825186594, 42.9248035975865, 42.56309427533831, 41.447356019701274, 42.13673891339983, 38.48044742856707, 37.968215806143625, 37.573936803000315, 41.281016145433696, 39.49954319000244, 38.17951052529471, 40.839162826538086, 44.27592250279018, 46.271507671901155, 46.161590644291465, 42.432113783700125, 41.823628766196116, 38.72965499332973, 40.144641739981516, 39.8124657358442, 38.09477376937866, 39.84064415522984, 38.60334021704537, 41.25831985473633, 43.63122694832938, 42.29544619151524, 39.381423813956125, 39.38761118480137, 42.92172901970999, 40.0849323953901, 43.882949760981965, 47.658236094883506, 47.595052650996614, 43.57892438343593, 41.17192595345633, 45.755291257585796, 42.164021015167236, 43.60291303907122, 51.0511074747358, 45.92480993270874, 46.71063034875052, 42.914374351501465, 41.86406033379691, 40.30784797668457, 37.342690331595286, 36.84867341177804, 42.35314750671387, 44.708663259233745, 50.03300877979824, 50.968927655901226, 56.303799697331016, 54.20261928013393, 54.79507827758789, 53.39443956102644, 49.43778092520577, 46.59156949179513, 40.332802431924, 42.838903018406455, 35.828524998256135, 27.11897369793483, 35.04859318052019, 37.55380439758301, 41.75281272615705, 41.38788638796125, 44.45864275523594, 45.9310633114406, 47.973038128444124, 52.099632331303184, 53.961520263126914, 58.999752862112864, 58.201866899217876, 61.19191646575928, 58.018656798771445, 60.43433352879116, 59.815964698791504, 61.527778489249094, 56.19787440981184, 59.40021923610142, 51.5472366469247, 54.77676282610212, 34.910407406943186, 9.255810856819153, 0.6654123142361641, 2.8704858337129866, 55.54569911956787, 58.450463022504536, 49.23765196119036, 50.21094867161342, 41.99714960370745, 22.22990676334926, 42.728068828582764, 28.016552414212907, 29.782046249934606, 42.35944604873657, 45.907019070216585, 17.68321578843253, 4.36063688993454, 6.3812538129942755, 1.9291784124714988, 6.906155909810748, 2.808037813220705, 2.2682882845401764, 23.216102804456437, 40.21072605678013, 42.33112171718052, 35.70612553187779, 24.151458876473562, 5.500365972518921, 3.2216844856739044, 3.4469659285885945, 29.433389118739537, 49.46575437273298, 29.174950872148784, 43.86595446722848, 45.34223127365112, 56.97056967871529, 66.0299471446446, 44.94844906670706, 17.927762848990305, 0.1266005073807069, 0.059682209976017475, 0.03028618324814098, 0.028602381635989462, 0.3651653453707695, 1.471948730094092, 6.312825781958444, 58.8931188583374, 69.06460762023926, 71.55241707393101, 69.64132894788469, 70.92810753413609, 64.54793807438442, 64.33378069741386, 59.28359372275216, 54.863278320857454, 51.50744431359427, 50.628973143441335, 51.44400378635952, 56.309743881225586, 58.09984302520752, 59.30862808227539, 60.36798518044608, 61.56965528215681, 58.20673411233084, 57.63983406339373, 56.8107784816197, 50.54017516544887, 49.39105428968157, 50.37990801674979, 46.79827492577689, 45.86853299822126, 43.84814970833914, 44.25804131371634, 42.89646884373256, 44.26001460211617, 44.95163481576102, 45.243841307503835, 46.045896189553396, 45.58385140555245, 46.721028327941895, 50.47783245359148, 52.36594983509609, 51.03106539590018, 54.96586847305298, 55.01921674183437, 54.63345970426287, 52.475957189287456, 48.63954060418265, 50.58303165435791, 47.24111141477312, 46.56852231706892, 50.332983357565745, 53.19504363196236, 54.64839138303484, 47.657430103846956, 45.21892854145595, 40.84927592958723, 43.95914718082973, 43.97567694527762, 43.989934648786274, 44.116350173950195, 41.80387503760201, 40.69973332541329, 39.56389045715332, 42.98778206961495, 40.921738692692344, 39.20656197411673, 43.455038002559114, 46.86629778998238, 49.92930344172886, 49.254216466631206, 42.79589366912842, 42.81886441367013, 39.78022609438215, 40.861980710710796, 40.49125610079084, 40.08097539629255, 40.07465600967407, 40.74060957772391, 42.40820503234863, 44.683701855795725, 46.13783475330898, 42.06435605457851, 40.26249361038208, 44.329819679260254, 42.53877905436924, 45.20854445866176, 48.61558321544102, 48.221985135759624, 46.08727618626186, 43.81981495448521, 45.45834262030465, 45.116550309317454, 45.624571323394775, 51.477924891880576, 48.07781001499721, 48.90906817572457, 45.75817823410034, 45.49886451448713, 42.820003918239046, 40.841973372868125, 42.387429918561665, 43.83494813101632, 46.55798537390572, 51.59072194780622, 52.382298946380615, 56.12226063864571, 52.87637145178658, 54.84098849977766, 54.49177203859602, 53.03049291883196, 51.93119757516043, 47.047864641462056, 50.20731128965105, 41.94513886315482, 37.47251394816807, 42.7836856842041, 45.56218344824654, 48.43411711284092, 47.739734990256174, 48.48787532533918, 48.69416734150478, 50.71350145339966, 55.81733546938215, 57.858208996909006, 63.550406047276084, 61.198558943612234, 64.84519590650285, 61.45938737051827, 65.26130267551967, 64.91890239715576, 68.11034202575684, 61.892815998622346, 67.5968770980835, 59.10003621237618, 60.90138448987688, 42.277578898838584, 11.610681295394897, 0.8362713945763451, 3.6929606028965543, 63.292481967381065, 63.650890895298545, 56.94595568520682, 57.471295084272114, 48.27957875388009, 28.947461639131816, 51.17480625425066, 34.102133887154714, 37.50735569000244, 38.377697467803955, 43.47762312207903, 24.324067762919835, 8.38957633290972, 7.710329992430551, 5.566592293126242, 3.434795073100499, 4.992080926895142, 0.6758356434958321, 12.945858427456447, 33.70342888150896, 36.77701316561018, 33.26643582752773, 18.53368398121425, 13.170274819646563, 5.867685530866895, 12.260202373777117, 47.72721086229597, 65.39248466491699, 42.723104340689524, 49.83434588568551, 54.42501374653408, 65.23687280927385, 76.23850454602922, 60.41868618556431, 33.80422987256731, 0.3892389807317938, 0.3769389050347464, 0.04300105418743832, 0.09951134026050568, 0.448946723980563, 2.039474768298013, 27.611338683537074, 65.8789141518729, 73.76478603907994, 74.44333321707589, 70.80076095036098, 70.39572266169957, 66.68730926513672, 64.93463311876569, 61.70789664132254, 56.3561543737139, 53.80927133560181, 52.351299558367046, 54.589352539607454, 57.54625572477068, 61.04462160382952, 63.560835293361116, 62.51017733982631, 64.85410349709647, 62.36946242196219, 59.75514016832624, 60.5562744140625, 52.798760073525564, 51.58139746529715, 53.51881231580462, 49.463854040418354, 47.0935594694955, 46.14669023241316, 48.54800156184605, 45.774669783455984, 48.61392259597778, 47.58172948019845, 48.34521838596889, 51.02499614443098, 47.74621418544224, 50.76887164797102, 53.080895151410786, 54.82844352722168, 56.07273735318865, 59.944978850228445, 58.10371664592198, 59.392881938389365, 54.29573556355068, 51.41935157775879, 57.5970470564706, 53.545583724975586, 50.167755195072715, 52.77639034816197, 57.609244619097026, 58.059519154684885, 52.35808794839041, 50.71512038367135, 45.15577636446272, 47.24754892076765, 48.37419932229178, 47.70329168864659, 48.103073665073936, 43.641360895974294, 42.11280236925398, 42.03817524228777, 48.59903260639736, 44.162329878125874, 42.88222851072039, 45.07706022262573, 50.288031986781526, 52.17045879364014, 53.232716764722554, 44.887791293007986, 46.12245144162859, 42.85529381888253, 44.31158413205828, 42.83244466781616, 42.66348532267979, 43.95659719194685, 43.95506164005825, 44.59577240262713, 49.643315587724956, 45.88140801021031, 42.87271295275007, 41.467842783246724, 46.820245129721506, 42.601601191929404, 47.0811048235212, 51.692235129220144, 51.31748056411743, 49.01469121660505, 45.8846423966544, 47.663620948791504, 50.50189406531197, 48.189606530325754, 55.60548489434378, 51.10299662181309, 52.84061254773821, 49.69527769088745, 48.1661250931876, 45.74808944974627, 44.45219135284424, 44.58264030729021, 46.69559097290039, 48.90655640193394, 54.11876841953823, 55.572526114327566, 59.01122433798653, 56.443892751421245, 57.24635757718767, 58.63352026258196, 57.64528145108904, 57.302783897944856, 51.97594049998692, 56.92702531814575, 49.44094582966396, 45.81052943638393, 54.5862466948373, 55.880616188049316, 53.27910641261509, 50.82881028311593, 50.13393483843122, 51.31221035548619, 52.003285135541645, 59.125174794878276, 57.77221809114729, 62.22883088248116, 61.40511499132429, 66.54863016945976, 63.393800599234446, 65.06796210152763, 63.97013282775879, 67.78608349391392, 61.71517835344587, 64.09588827405656, 57.016201972961426, 65.27170412881034, 45.10424852371216, 17.385612283434185, 1.2363180539437701, 3.8497718913214545, 70.11034624917167, 67.80269663674491, 65.38814204079765, 64.80277715410504, 57.20241369519915, 37.540894644601, 56.16856343405587, 46.16784054892403, 55.91496460778372, 69.3636372429984, 70.71802874973842, 43.69668592725481, 20.192654984337942, 18.99393265587943, 19.02090208871024, 20.95489842551095, 16.7416376045772], [0.08155005012771913, 0.5472608027713639, 10.050425955227443, 12.81301234449659, 11.509684886251177, 2.8611476719379425, 1.3766002293143953, 1.4790082084281104, 1.7856326465095793, 20.332890476499283, 40.79250567299979, 24.521059615271433, 42.029740129198345, 45.39375911440168, 49.00797230856759, 65.5638758795602, 37.28433588572911, 20.97014103616987, 0.18965996934899262, 0.10719344911298581, 0.17217693105340004, 0.0973520857681121, 0.46395874129874365, 6.792495105947767, 23.206354481833323, 65.44372068132672, 68.11557401929582, 69.5561718259539, 64.69307204655239, 64.82738767351422, 62.74771540505545, 63.12577383858817, 58.7602276120867, 54.563029289245605, 46.987502166203086, 46.23456757409232, 45.049896240234375, 49.95079769407, 53.70648315974644, 56.21670402799334, 55.39546169553484, 58.02174874714443, 55.60294532775879, 55.456855978284565, 55.53963334219796, 54.61169099807739, 49.36901807785034, 45.943834100450786, 44.81811128343855, 42.940895625523154, 42.59795686176845, 42.50324944087437, 42.29146139962332, 43.677435943058555, 41.819015162331716, 42.25763756888253, 45.0472593988691, 46.98640087672642, 45.042468615940635, 49.22411339623587, 48.94973945617676, 48.713712624141145, 50.082160336630686, 51.96678277424404, 51.07073613575527, 52.576681750161306, 48.14223371233259, 47.599502972194124, 43.98017242976597, 43.88905722754342, 47.12349925722395, 47.95871441704886, 49.76104933874947, 43.84269189834595, 41.06737640925816, 42.24718400410244, 41.783099923815044, 42.06132663999285, 39.04478359222412, 39.84134592328753, 41.03215946469988, 42.64137962886265, 37.79435798100063, 38.972015108381, 37.676634652274, 39.46669905526297, 42.095994676862446, 40.19644056047712, 41.83887311390468, 43.33786358152117, 42.78961249760219, 40.1687832559858, 38.58231496810913, 38.048915658678325, 40.78906284059797, 41.30364295414516, 39.90314320155552, 39.46103279931204, 38.76297507967268, 40.69010659626552, 40.25777578353882, 41.792671067374094, 38.15081099101475, 37.82801505497524, 41.688663482666016, 44.77010270527431, 46.79230294908796, 41.95008250645229, 44.09493235179356, 43.90119225638253, 42.29118694577898, 44.469054630824495, 46.765944957733154, 45.878962244306294, 48.4592661176409, 45.30753544398716, 44.14359406062535, 44.39582756587437, 42.63245466777256, 40.833826610020225, 42.48944337027413, 40.04174239294869, 43.6820182800293, 48.60949659347534, 53.497422286442344, 53.111439432416645, 54.33396455219814, 54.16211128234863, 54.42743866784232, 51.6936490876334, 50.130120277404785, 49.16058949061802, 48.91866363797869, 35.810671601976665, 38.068509578704834, 43.01298666000366, 47.15699304853167, 50.12595483234951, 45.2074362209865, 44.985135555267334, 44.32951743262154, 46.82061685834612, 50.09928069795881, 55.32556976590838, 57.82981865746634, 60.01913002559117, 55.65811749867031, 57.52357333047049, 54.95499454225813, 59.20268195016043, 54.95343814577375, 58.040970938546316, 56.60424675260271, 56.50201790673392, 54.652827807835166, 60.40634618486677, 21.30774184635707, 0.4976661897131375, 6.798062350068774, 63.167963300432476, 55.833219051361084, 44.30774177823748, 44.47410249710083, 44.10981886727469, 30.171253068106516, 27.781249931880406, 33.776662894657676, 35.41729933874947, 45.90356581551688, 29.39586537224906, 5.364925605910165, 3.0305597356387546, 4.48498489175524, 4.100041227681296, 13.405292425836835, 0.4428175171571118, 0.20994186960160732, 3.9378116471426825, 20.131510836737498, 24.16822487967355, 22.009718350001744, 13.078900797026497, 4.040827376501901, 1.8784604711191994, 1.0929658604519707, 27.792948961257935, 50.736145632607595, 21.24165231840951, 45.66819558824812, 52.817085947309224, 58.45289489201137, 72.81788553510393, 52.96745538711548, 35.31979874202183, 0.3290481748325484, 0.036725134522254975, 0.5289055619921003, 0.03596709894814661, 0.5452878400683403, 6.814256429672241, 28.767881972449167, 72.43074580601284, 72.23840577261788, 74.21799618857247, 69.25428649357387, 70.29651628221784, 67.9241441999163, 65.54109968457902, 63.454673767089844, 57.98389148712158, 51.27447816303798, 50.89875432423183, 51.388828141348704, 56.35395179476057, 59.37232916695731, 58.981958525521414, 61.46791281018938, 63.53652354649135, 60.900606291634695, 60.60288987840925, 60.48981489453997, 56.49373912811279, 50.208301407950266, 47.61803729193551, 47.97158248083932, 44.589400904519216, 44.48445878710066, 43.42406293324062, 46.90493324824742, 45.80106946400234, 43.0780530657087, 46.42824860981533, 49.123263767787385, 48.77437039784023, 48.29971463339669, 52.79188483101981, 53.29889835630144, 51.77733666556222, 52.21378428595406, 53.65087325232369, 53.78359774180821, 54.24325234549386, 52.64855739048549, 49.513554504939485, 47.4311203275408, 47.50673062460763, 48.75365086964199, 52.36601931708199, 49.4339212008885, 45.88795321328299, 43.72349207741873, 44.52991042818342, 45.25164760862078, 44.98428440093994, 40.24665519169399, 41.649096965789795, 43.60471262250628, 43.47593123572213, 40.26518256323678, 42.23242255619594, 41.35059540612357, 41.380976404462544, 43.78908307211739, 44.67379719870431, 43.61909886768886, 44.792416845049175, 42.69804913657052, 43.40130410875593, 40.394787311553955, 39.46800879069737, 41.00920261655535, 42.24704156603132, 41.68946599960327, 41.271549224853516, 41.14574861526489, 42.50081409726824, 42.89202547073364, 42.12249163218907, 40.81497267314366, 37.061295236860005, 44.02648217337472, 45.245109353746685, 48.60709946496146, 42.78608628681728, 45.90929460525513, 47.88812419346401, 44.77248593739101, 45.981274468558176, 48.8171261378697, 48.384142194475444, 51.426584652491975, 49.454866545540945, 48.51786722455706, 46.26897505351475, 46.00670140130179, 44.42748008455549, 45.544889381953645, 42.924233845302034, 45.28681591578892, 49.818146160670686, 53.12332780020577, 54.4085430417742, 55.101757866995676, 55.29345866612026, 57.45321239743914, 56.42985739026751, 56.80243716921125, 54.85093832015991, 55.48999193736485, 42.85700307573591, 46.24096686499459, 52.355381625039236, 55.2869690486363, 56.8203843661717, 50.20368085588728, 47.604384081704275, 47.02942759650094, 49.13154602050781, 54.48062365395682, 58.50169209071568, 60.0846654347011, 63.668719972882954, 61.04368359701974, 63.68663937704903, 63.702641078404014, 64.91990293775285, 64.00434575762067, 63.692260469709126, 64.60826233455113, 64.58071272713798, 62.10731383732387, 64.70646122523716, 26.610287393842423, 0.606881069285529, 7.911967584065028, 74.08675166538784, 62.86873912811279, 53.19077048982893, 52.04302535738264, 51.907215867723735, 42.128432341984336, 34.76030894688198, 36.38167803628104, 42.71000351224627, 54.742393561771934, 44.626031807490754, 18.407657555171422, 8.269167525427681, 6.241486455713, 7.732155152729579, 5.815768156732831, 2.1830054436411177, 0.3618685065635613, 0.9279097744396755, 13.201827457972936, 15.546377216066633, 16.590719257082256, 9.19428368977138, 3.665942966938019, 3.150425063712256, 8.35134300163814, 41.97376544134957, 65.39491653442383, 38.03382764543806, 57.91702549798148, 62.18071460723877, 63.23390865325928, 83.74308708735875, 60.91549628121512, 53.14663553237915, 0.47309415681021555, 0.3646018627498831, 0.31176930772406714, 0.21547241854880536, 2.066640487739018, 8.489878790719168, 48.35288224901472, 76.26584570748466, 75.41346849714006, 74.64535209110805, 72.19479193006242, 72.07251753125871, 69.29444708142961, 66.62113462175641, 64.48082542419434, 60.58283737727574, 53.63486112867083, 52.51293550218855, 52.55948148454939, 57.98875870023455, 60.80192797524588, 62.55893284933907, 65.68041106632778, 65.62963363102504, 66.64926787785122, 63.69681848798479, 62.3834421975272, 58.892597743443076, 52.67791700363159, 51.60467045647757, 49.95400428771973, 48.73290007455008, 48.64727742331368, 47.46810211454119, 50.40921204430716, 49.30859306880406, 46.18667016710554, 49.13140705653599, 52.61732871191842, 52.47036041532244, 50.010579994746614, 55.84730999810355, 55.9231322152274, 53.40156146458217, 55.599012647356304, 57.05821425574166, 55.583816937037874, 57.35815061841692, 55.157597064971924, 54.293647629874094, 50.676050662994385, 50.48046234675816, 54.27943161555699, 55.22588048662458, 54.33191135951451, 49.06782756532942, 46.52838952200753, 48.920925276620046, 48.295570032937185, 47.61360781533377, 42.387864180973594, 46.43128497259957, 47.87077801568167, 47.67860126495361, 42.36155135290963, 44.67860535212925, 44.591936997004915, 44.58230331965855, 48.24487945011684, 47.53774043491909, 48.833020142146516, 48.07092087609427, 47.16578251974923, 45.82180636269705, 41.82285404205322, 40.05758775983538, 45.179518359048025, 44.82125881740025, 44.86560569490705, 43.13265895843506, 42.876927035195486, 45.31413275854928, 45.342637743268696, 45.22402157102312, 41.50572088786534, 38.97090687070574, 45.84749732698713, 48.35490070070539, 50.89899403708321, 47.19667073658535, 50.25587224960327, 50.680407183510916, 47.301508631025044, 46.96657419204712, 54.68045037133353, 49.54726716450283, 56.285730906895225, 52.29926102502005, 50.31766257967268, 48.74074806485857, 50.562266962868826, 47.54308359963553, 49.84152684892927, 46.256176471710205, 48.12494312013899, 50.86999225616455, 57.975953170231406, 57.32413918631417, 59.078746931893484, 59.13433946881975, 58.923725673130576, 59.852804047720774, 59.55612291608538, 57.67329658780779, 57.413173403058735, 46.02206039428711, 51.31138351985386, 54.612893036433626, 58.62598841530936, 58.761235100882395, 51.37674174989973, 48.53967761993408, 48.152398926871165, 49.131229877471924, 54.677980286734446, 58.88407230377197, 62.01756395612444, 63.85573768615723, 61.131175313677105, 62.699105807713096, 62.70360129220145, 65.44000339508057, 63.090879985264365, 64.90736143929618, 65.47574492863247, 65.7763101032802, 64.62728650229317, 65.13541521344865, 33.67560829435076, 0.7648018981729234, 9.061000738825117, 78.62866401672363, 66.25777857644218, 58.18273850849697, 57.16023465565273, 60.47817666190011, 44.36326135907854, 39.993733814784456, 51.81077139718192, 59.19200951712472, 69.91411522456578, 49.51910611561367, 30.252963883536204, 28.01909371784755, 24.345336198806763, 24.57108317102705, 51.16146918705532, 3.35258463876588], [0.1053745952833976, 0.024957630783319473, 0.5821501506226403, 2.7971334840570177, 2.207470702273505, 0.6155363534178052, 0.6632672750524112, 0.669013435287135, 1.5435188668114799, 23.011361973626272, 35.084862777165, 31.300133841378347, 38.746191705976216, 39.97865274974278, 41.93225342886788, 71.04372555868966, 50.90752295085362, 48.82162162235805, 3.619824081659317, 0.012564526238877858, 0.5250292271375656, 0.03893017655770693, 1.6235286763736179, 11.690860033035278, 53.13851656232561, 61.43873037610735, 63.905848094395225, 67.68292358943394, 66.34701429094586, 61.94025135040283, 65.62344973427909, 62.72527967180525, 63.19233758108956, 57.909795897347585, 51.82100261960711, 44.76837607792446, 44.659768785749165, 46.34103829520089, 53.03789275033133, 54.01221432004656, 54.569699559892925, 51.654360498700825, 56.791994026729036, 53.85744319643293, 55.533112457820344, 56.999463762555806, 54.5618029321943, 48.585129261016846, 47.15694441114153, 44.58584690093994, 43.92319025312151, 40.687737260546, 40.01818452562605, 38.475899832589285, 41.98063373565674, 44.45444604328701, 45.54990945543562, 44.083499091012136, 47.790484632764546, 48.852339608328684, 49.56306389399937, 50.81860337938581, 52.16943393434797, 50.77304056712559, 51.19364282063076, 50.97882883889334, 52.22174344744001, 48.9072790145874, 44.83171933037894, 45.135564054761616, 45.618707043784006, 45.694261755262104, 45.60378578730992, 43.882616247449604, 43.21866028649466, 41.56178937639509, 41.425413608551025, 39.863218852451865, 39.66064064843314, 36.9030430657523, 37.71749005998884, 39.97335474831717, 40.267881938389365, 37.98425572259085, 37.83402524675642, 39.3256402015686, 38.62593575886318, 39.51090349469866, 40.09518098831177, 39.95122820990426, 43.84286560331072, 40.01989030838013, 39.17824806485857, 37.60756608418056, 37.82148722239903, 40.38220412390572, 37.93778617041451, 36.640494959695, 37.83721794400896, 40.398911067417686, 42.46766424179077, 41.04653876168387, 38.231601170131135, 36.46684210641043, 36.535059520176475, 40.647892815726145, 45.229993547712056, 41.45397070475987, 39.92187554495675, 45.201832498822895, 49.129805496760774, 48.22668906620571, 48.085237639290945, 48.955867767333984, 49.33777897698538, 47.600816181727815, 47.967868668692454, 45.816654273441856, 45.6997195652553, 44.99188573019845, 44.02586725779942, 42.741763728005544, 42.99934387207031, 44.51830693653652, 49.10735934121268, 53.81941570554461, 55.78173984800066, 53.687219279153005, 52.39826938084194, 50.840795925685335, 52.15516580854143, 50.56953477859497, 46.847555024283274, 39.448258536202566, 43.183756010872976, 50.23660489491054, 53.20730025427682, 52.72214228766305, 48.316254820142476, 44.35719905580793, 43.85732480457851, 47.3515738759722, 50.45777300425938, 54.97373730795724, 57.21151236125401, 58.382287297930034, 61.5612062726702, 61.235648427690776, 61.49542072841099, 64.00805609566825, 61.369137219020296, 61.95728833334786, 61.601207051958355, 57.38346290588379, 57.90636348724365, 56.437066146305625, 13.96101542881557, 0.5824379580361503, 11.633117028645106, 60.95237731933594, 57.4696865762983, 43.97296019962856, 42.18807567868914, 44.74447774887085, 28.103368418557302, 22.647741896765574, 43.88806710924421, 44.1321052142552, 37.22509554454258, 14.525649496487208, 1.1817563474178314, 0.6036620448742593, 8.435367567198616, 9.533671924046107, 5.125052511692047, 0.1782939921000174, 0.11555942626936094, 0.3625527684177671, 3.734076568058559, 8.72356755392892, 9.730401481900897, 4.353180604321616, 2.181572377681732, 0.7283260811652456, 1.0404197829110282, 27.85405489376613, 42.22183002744402, 24.620153086526052, 45.500511237553184, 47.73034449986049, 50.51589468547276, 80.29812853676933, 59.75300012316023, 64.45229612077985, 6.55453667470387, 0.12104797389890466, 1.9644166358879633, 0.18883641782615865, 1.9947813493864877, 14.46614338670458, 60.22351128714425, 65.618287222726, 70.72428907666887, 73.00027574811662, 70.06644058227539, 67.38524191720145, 69.72947379520961, 67.45102746146065, 65.39468029567173, 60.81749194008963, 55.34643520627703, 47.862231731414795, 48.51860720770699, 53.6039069039481, 58.35757950374058, 58.97892911093575, 59.92639241899763, 58.09423235484532, 60.32211317334856, 58.543777329581125, 59.64059911455427, 59.87860270908901, 58.03200428826468, 51.560340949467246, 48.78742953709194, 47.38934080941336, 46.79693044934954, 43.946355547223774, 44.20072214944022, 41.2831631387983, 43.5802514893668, 48.04436486107962, 49.54123265402657, 47.48181438446045, 50.458130836486816, 52.71279696055821, 52.45228467668806, 54.48930542809622, 53.79391929081508, 53.61069876807076, 54.69664314814976, 54.392485754830496, 54.43430001395089, 51.941988127572195, 48.327736718314036, 48.37060015542166, 48.44123206819807, 47.45098522731236, 47.92352873938424, 45.215475286756245, 45.95595175879342, 44.44389172962734, 43.332655906677246, 42.52513974053519, 41.528743743896484, 41.13744551794869, 39.79627643312727, 41.016317571912495, 42.651551791599815, 40.70908907481602, 41.01893356868199, 40.04279851913452, 42.44830656051636, 44.09177439553397, 42.863162653786794, 42.582042012895855, 44.255088329315186, 42.53090327126639, 40.97830745152065, 38.43657650266375, 41.89853034700666, 42.291145256587434, 40.55520037242344, 39.57030017035348, 40.75939750671387, 42.36646025521414, 44.395403725760325, 44.25692612784249, 41.09932770047869, 37.503541128976, 35.5448647907802, 39.937300545828684, 46.02499253409249, 43.10309089933123, 45.41822024754116, 46.8392310823713, 50.62442902156285, 48.77363388878958, 50.117370332990376, 50.09269380569458, 51.96340594972883, 49.20614535467965, 49.13636112213135, 49.57646696908133, 48.25491264888218, 47.4061450277056, 46.53762020383562, 44.49554116385323, 43.643143108912874, 46.847600187574116, 50.188832555498394, 54.291306086948936, 58.402054922921316, 56.51841218130929, 54.48228079932076, 53.11823129653931, 55.59692471367972, 57.011769022260395, 51.528810024261475, 44.414483479091096, 50.20748152051653, 56.660193647657124, 61.10463319505964, 57.380989347185405, 53.195467472076416, 49.00336912700108, 47.33834103175572, 49.44042818886893, 53.9214117867606, 56.9503538949149, 60.73898424421038, 64.68113504137311, 65.5295100893293, 63.82916777474539, 66.05998420715332, 67.54601628439767, 67.63134016309465, 67.7946297781808, 68.47658157348633, 64.76786245618547, 64.46823528834751, 60.49403245108468, 16.413585356303624, 0.4701445922255516, 14.366043295179095, 68.50235939025879, 63.59948812212263, 51.96202673230852, 47.528860637119834, 53.148584502083914, 32.81657818385533, 18.468480348587036, 45.482564040592735, 48.41174391337803, 53.05449547086443, 31.253813675471715, 10.804506131580897, 10.490582176617213, 9.063072170530047, 12.019816415650503, 14.195176669529506, 0.4010879663484437, 0.2171956803649664, 0.18100809146250996, 1.091501201902117, 4.358766087463923, 5.78041615656444, 2.6150813443320136, 2.2086911967822482, 1.6786224629197801, 9.014492971556527, 47.12156418391636, 57.056445939200266, 49.09731224605015, 58.402569089617046, 55.878649847848074, 54.98953403745379, 87.64280523572648, 65.46989454541887, 76.97301946367536, 7.691102589879717, 0.1927594087485756, 1.9611609705856867, 0.20527182519435883, 2.755391312497003, 27.823566198349, 68.0167567389352, 69.1313589641026, 71.3666569846017, 74.22921058109829, 71.66891057150704, 68.12831701551164, 70.82721969059536, 66.12385204860142, 66.65636893681118, 63.26110390254429, 56.79258462360927, 48.67902374267578, 50.637734821864534, 52.71076808656965, 59.33186285836356, 59.760955810546875, 62.77032484327044, 60.126764569963726, 63.36832850319998, 62.24039963313511, 61.327496664864675, 62.68110302516392, 60.31563745226179, 54.17556994301932, 52.80769893101284, 49.10232189723423, 50.270178590502056, 49.070853505815776, 47.02820471354893, 44.2847432409014, 47.85967479433332, 50.663797514779226, 53.35522740227835, 49.41444192613874, 53.96250690732683, 54.75511571339199, 54.56353303364345, 57.037939412253245, 57.249942847660606, 54.51808834075928, 56.011520249503, 56.77522802352905, 56.23270572934832, 54.892325265066965, 53.26665871483939, 51.76676498140608, 53.50605542319161, 52.62315477643694, 50.34947490692139, 48.466474873679026, 48.80010652542114, 47.901353563581196, 46.776586123875205, 44.526217460632324, 44.57652241843087, 43.38137667519705, 41.79842070170811, 45.94931622913906, 45.231115681784495, 42.86611911228725, 43.71495968954903, 44.1806765965053, 44.20416150774275, 44.651896476745605, 44.35436766488211, 45.718778473990305, 47.752735069819856, 44.16357013157436, 44.28519139971052, 40.398938860212056, 44.855780942099436, 46.183227334703716, 43.681288719177246, 41.134791306086946, 43.07793147223336, 44.33763640267508, 47.79296861376081, 45.221381255558555, 43.8657877104623, 38.31595230102539, 37.76667635781424, 42.19016013826643, 50.72043922969273, 47.65643651144845, 48.7915289742606, 52.76509257725307, 53.09027521950858, 53.589694363730295, 52.959638663700645, 55.67473758969988, 56.14646816253662, 52.20885106495449, 52.855436529432026, 51.466852937425884, 50.97960703713553, 50.529155322483604, 48.02658789498465, 45.58821834836687, 46.19921513966152, 48.53314283915928, 52.90982007980347, 57.99589450018746, 62.02552659170968, 58.20554249627249, 56.1056683404105, 55.059530190059114, 56.02517345973423, 56.937937464032856, 52.08897726876395, 46.36285563877651, 52.319751262664795, 57.64710187911987, 63.17139571053641, 56.63085487910679, 54.70042644228254, 49.13079908915928, 47.76498474393572, 51.414974212646484, 55.09015090124947, 57.43405621392386, 60.44697230202811, 62.42413779667446, 65.21497208731515, 63.15900012425014, 64.57527923583984, 65.1003337587629, 66.11094229561942, 68.62495340619768, 67.34178788321358, 64.49128246307373, 67.604325566973, 67.82094260624477, 21.532245091029576, 0.5592320603983743, 14.703487770898, 73.53860827854702, 66.55448750087193, 58.711798667907715, 56.20144925798689, 60.61578573499407, 37.580787726810996, 33.13232864652361, 58.25579881668091, 59.595213481358115, 67.29432473863874, 39.3057405608041, 24.63688608578273, 32.62630523954119, 30.814468656267437, 62.631096839904785, 16.038327046803065, 0.4773579623017992], [0.05423971451818943, 0.05051514080592564, 0.06959679403475352, 0.058988733616258414, 0.5238470562866756, 0.2537315477217947, 0.20429709606937, 2.3267441306795393, 2.2173328016485487, 18.0578487600599, 30.9617600440979, 21.24094533920288, 30.223729337964738, 42.076140199388774, 41.15706723076956, 71.58146054404122, 53.82827813284737, 61.15467412131173, 22.738832780293055, 0.1584348055933203, 2.5190355266843523, 0.24762074276804924, 1.6256239925112044, 30.707122462136404, 64.5581727709089, 63.65335750579834, 65.97603607177734, 65.78024278368268, 65.28642041342599, 65.63931941986084, 63.01504734584263, 63.61831774030413, 63.651293890816824, 60.28883130209786, 57.66095658711025, 45.62150716781616, 47.66496889931815, 47.283380780901226, 50.003652640751426, 53.15358025687081, 54.9684601511274, 54.40864726475307, 52.004938806806294, 52.42191062654768, 55.92781182697841, 56.9002400125776, 58.03827851159232, 56.49114397593907, 49.942161083221436, 47.06711115155901, 45.24808318274361, 42.494498184749055, 42.433631965092246, 43.563961437770296, 42.74521698270525, 42.851090158735005, 46.33041449955532, 46.87329115186419, 48.46205581937517, 51.28682163783482, 52.340255396706716, 49.590853214263916, 51.9293771471296, 53.721383571624756, 52.38946253912789, 51.41078792299543, 52.03576448985508, 50.73689603805542, 45.79495504924229, 44.768226691654746, 44.61596734183175, 41.974380356924875, 46.385892391204834, 40.82182012285505, 39.91557700293404, 39.71097339902605, 41.39091232844761, 39.91355855124337, 39.76003462927682, 39.430505888802664, 38.29469428743635, 37.27793659482683, 38.94571965081351, 40.13739824295044, 38.89482062203543, 40.18935339791434, 39.952763761792866, 40.807520730154856, 39.30603585924421, 38.869056701660156, 40.6798996925354, 39.30075522831508, 40.057216031210764, 40.04766920634678, 41.566062518528526, 38.847892488752095, 38.920952796936035, 40.33332354681832, 40.08694042478289, 41.30115897314889, 41.46257604871477, 40.86783109392439, 41.3240567616054, 36.06671966825213, 33.54167481831142, 29.745575155530656, 36.13964101246425, 42.30357905796596, 40.92234318596976, 45.68468018940517, 47.3195982660566, 49.359478201184956, 46.30977487564087, 46.686332498277935, 50.54067196164812, 49.07738133839199, 48.89775998251778, 50.00763395854405, 47.492545877184185, 47.906120027814595, 46.01919078826904, 44.49005208696638, 43.279488291059224, 42.54359763009207, 44.4346193586077, 47.13971635273525, 51.910415513174875, 54.213246549878804, 54.96904379980904, 48.12323733738491, 44.80935307911464, 45.62077413286482, 44.36351496832711, 44.1159610748291, 50.19281734739031, 51.512259415217805, 54.27053792136056, 54.02456474304199, 47.95592818941389, 44.77236434391567, 44.1810622215271, 44.216188839503694, 48.29997866494315, 51.2912198475429, 56.12685339791434, 56.58761971337454, 60.41063322339739, 59.83070877620152, 61.95401573181152, 61.29023347582136, 60.37998471941267, 60.498069354466026, 63.67639078412737, 62.835665702819824, 58.88319683074951, 36.753170422145296, 4.230237875665937, 0.516295884336744, 12.253953337669373, 61.453620365687776, 57.72510930470058, 39.94455793925694, 41.81252554484776, 37.042448248182026, 22.823892627443584, 29.565366676875524, 42.44187947681972, 38.166395800454275, 30.672728879111155, 14.226717148508344, 5.03498648745673, 3.181368214743478, 13.687823551041738, 6.263136608260019, 0.06573105111185994, 0.08411768092108624, 0.02848793313439403, 0.14067864338202135, 0.22758205660751887, 0.2830690677676882, 2.593710639647075, 0.9923121929168701, 0.7050474445734705, 4.156168341636658, 0.1791395688695567, 22.15604567527771, 39.57813079016549, 19.0247357572828, 39.912835938589915, 46.53503547395979, 49.40456158774239, 79.01403890337262, 63.44045775277274, 72.99275084904262, 28.846695389066422, 0.19545073647584232, 5.250881348337446, 0.7093050075428826, 2.689274860279901, 38.134461879730225, 69.44282586233956, 70.72134304046631, 72.74822289603097, 70.69220229557583, 71.4728810446603, 70.32109206063407, 66.38123416900635, 66.69783578600202, 65.98242146628243, 63.928659030369346, 60.6916948046003, 48.808451311928884, 48.843105452401296, 52.388052054813926, 53.88049037115914, 56.59842068808419, 59.88501589638846, 59.220580509730745, 58.00871045248849, 58.324019704546245, 61.93545709337507, 58.97384302956717, 59.964822905404226, 58.70770617893764, 53.72316231046404, 50.034231662750244, 47.189569677625386, 44.6954026222229, 45.03559684753418, 45.753540311540874, 45.90028626578194, 45.50322103500366, 49.126984528132844, 50.614447934286936, 52.46920006615775, 55.14179686137608, 53.71332713535854, 52.98508991513933, 53.64824683325631, 57.25918047768729, 54.622815064021516, 52.742507457733154, 53.41712542942592, 55.34155409676688, 49.821345806121826, 46.92104264668056, 45.780732086726594, 44.76755966459002, 50.06744057791573, 43.11189079284668, 42.04472739355904, 42.61289201463972, 43.91369901384626, 43.04662636348179, 40.660093852451865, 43.593098708561485, 41.806237425122944, 39.999684946877615, 40.10550601141793, 43.05606549126761, 41.814728123801096, 40.75554820469448, 42.27400752476284, 44.679491247449604, 40.126288073403494, 41.937846728733604, 43.02253001076834, 41.83563872746059, 42.17476987838745, 42.50114413670131, 42.815741198403494, 41.83626406533377, 40.996223381587434, 42.15669413975307, 40.41470432281494, 43.78968409129551, 40.16051837376186, 43.14713553019932, 43.655938216618125, 38.42865208217076, 34.888221808842246, 30.56182173320225, 37.929180826459614, 45.46570771081107, 42.87928594861712, 47.94372020448957, 49.18662091663906, 51.594925607953755, 50.00468792234148, 50.60253177370344, 49.83926868438721, 52.45964976719448, 50.59523269108364, 52.83584955760411, 50.46739625930786, 51.18479428972517, 49.166526726314, 46.86383465358189, 45.81544181278774, 43.71122850690569, 43.98207623617989, 48.6182895387922, 54.77320882252285, 57.46439899717058, 58.537843567984446, 49.84858274459839, 46.58366938999721, 45.18264504841396, 48.25334235600063, 50.062649794987266, 55.51833711351667, 56.04784195763724, 60.258287021092, 58.008727822984966, 52.43970843723842, 47.317322731018066, 47.995790004730225, 47.115897927965435, 51.660412379673545, 53.972790241241455, 59.15808146340506, 61.171995980399, 63.90434728349958, 63.49636990683419, 67.67686476026262, 64.07106930868966, 67.82350649152482, 64.94167164393834, 70.21235275268555, 66.27653176443917, 66.54194600241524, 42.54789509092058, 5.701784261635371, 0.6451003955943244, 15.346263885498047, 69.40635476793561, 64.57478591373989, 46.853325503213064, 47.808636801583425, 43.44981295721871, 20.425666298185075, 25.08864058767046, 46.977323055267334, 45.33573123386928, 43.9156688281468, 18.55086166518075, 7.11612526008061, 10.904406462396894, 17.81828008379255, 14.983182294028145, 0.27179838397673195, 0.05034539170031037, 0.07860716232763869, 0.21401165478995868, 0.1258727785732065, 0.12767928306545528, 1.0661812062774385, 0.7593517420547349, 1.2333559500319617, 8.515962328229632, 7.922256997653416, 41.40857812336513, 52.81701646532331, 31.952371665409633, 51.98692907605852, 56.24719272341047, 57.848603112357004, 85.12231840406145, 68.74233627319336, 79.30501556396484, 31.347812380109513, 0.23893774726561137, 11.188674637249537, 0.6013492175510952, 4.190487231527056, 47.187672819410054, 70.20599515097481, 74.03234727042062, 72.05709253038678, 70.84441648210797, 70.8185066495623, 71.39012799944196, 64.63515881129673, 66.12428978511265, 67.73774487631661, 65.93789740971157, 62.053771018981934, 50.3749817439488, 51.39497034890311, 54.70579392569405, 56.20603854315621, 60.047152110508506, 63.58179106031145, 61.31628227233887, 59.54516560690743, 60.0331723349435, 65.13354614802769, 60.723552295139854, 61.71339961460659, 61.46464715685163, 54.861343247549875, 52.16887807846069, 51.40239797319685, 47.03643485477993, 47.47310829162598, 48.82581833430699, 47.545310497283936, 47.324156284332275, 50.80873346328735, 52.402605056762695, 55.476140703473774, 58.397844314575195, 58.19141680853707, 55.02406311035156, 56.270476136888774, 59.462134633745464, 58.21805967603411, 55.50588246754238, 55.65574468885149, 57.83066981179373, 52.83814246313912, 51.70503371102469, 52.6262640953064, 50.13173573357718, 53.25253650120327, 45.20846108027867, 45.27717529024397, 44.4266289302281, 46.173013482775005, 46.19008868081229, 43.50811529159546, 44.84969432013375, 43.749460969652446, 41.4287348474775, 43.6418194770813, 45.71283776419503, 43.50188970565796, 43.380674907139365, 45.09907558986119, 45.59327663694109, 43.25158779961722, 44.08671610695975, 47.147241251809255, 44.31266457693917, 43.558635643550325, 43.301441124507356, 45.2747677394322, 42.94128472464425, 43.5993138722011, 45.24204519816807, 42.08492272240775, 46.529150349753245, 43.381077902657644, 45.59494767870222, 47.21597283227103, 40.90220730645316, 36.13221686226981, 32.47206565311977, 41.666734967912944, 51.694045134953086, 46.50737816946847, 50.42081206185477, 53.83257211957659, 55.613301617758616, 51.88613155909947, 52.17682334354946, 54.33655623027256, 54.3874066216605, 54.921076910836355, 56.467603479112896, 52.24313695090157, 52.04334844861712, 49.5962415422712, 47.6430230140686, 46.10190909249442, 45.32213013512747, 45.97352722712925, 51.15509074074881, 57.55464220046997, 59.10571983882359, 58.68989099775042, 51.02929360525948, 47.16387871333531, 46.36085108348301, 48.991293157849995, 52.166314193180625, 55.84514216014317, 54.66554995945522, 59.20825440543038, 56.1470170702253, 52.78001035962786, 49.29207720075335, 49.99531132834298, 47.97277757099697, 52.94950124195644, 55.51589829581124, 59.369334493364605, 62.18837152208601, 65.29761396135602, 63.88692120143345, 66.81981141226632, 64.86563055855888, 68.40917709895542, 64.69938795907157, 69.82611628941127, 68.61396830422538, 69.23885454450334, 50.451099259512766, 7.1665114249501904, 0.666337673153196, 16.410757439477102, 76.27870682307652, 68.51837498801095, 55.46362699781145, 57.784863812582834, 49.617694105420796, 32.479552337101524, 46.64965990611485, 58.07975230898176, 52.9174040385655, 64.5005235671997, 33.9412066595895, 22.868270771844045, 35.57405069896153, 50.598282950265066, 19.52239179611206, 0.13003903787050927, 0.1779139039239713], [0.060024388400571685, 0.02813599059092147, 0.024403662919732075, 0.1198176813444921, 0.17507404488112244, 0.024575150771332637, 0.057997929996677806, 4.538532052721296, 3.1241639128753116, 15.920862538473946, 26.47644250733512, 23.65816456930978, 35.96211106436593, 56.49470840181623, 36.769627230507986, 65.0528289249965, 62.780809674944194, 64.69508702414376, 43.70548929486956, 0.03764637473172375, 1.6422601512500217, 2.5303845405578613, 3.277690440416336, 47.99303504398891, 70.67755549294608, 62.98739351545061, 65.78027752467564, 64.1404470716204, 65.12164388384137, 62.10754312787737, 68.78861127580915, 64.1707273210798, 62.3756046295166, 59.429596219744, 57.95677266802107, 50.139010497501914, 45.67698853356497, 44.636426312582834, 47.41912773677281, 49.533620902470176, 53.076271125248496, 56.13799830845424, 55.860619272504536, 52.80175474711827, 53.382474763052805, 58.68454088483538, 57.78882775987898, 57.03254761014666, 55.291137967790874, 50.720810958317344, 46.605528422764365, 44.4476055417742, 44.44157450539725, 43.732139110565186, 45.397507667541504, 46.57136413029262, 50.53689908981323, 48.467666489737375, 51.03061376299177, 50.061048235212056, 51.80067913872855, 49.448057310921804, 51.29876906531197, 51.80654341833932, 51.1756191934858, 49.97437988008772, 48.81314829417637, 50.548992429460796, 48.46417154584612, 42.562833717891145, 41.64442777633667, 38.634627955300466, 37.7836959702628, 36.901392868586946, 39.39378465924944, 41.50566530227661, 37.54972927910941, 37.84110198702131, 39.85802507400513, 41.39361865179879, 39.41419151851109, 41.381448881966726, 37.32785940170288, 35.8230185508728, 38.878117152622764, 40.987538133348735, 40.77034786769322, 41.46971532276699, 38.493892192840576, 38.5559778213501, 40.4345692225865, 41.96315206800188, 41.75657170159476, 39.09521361759731, 37.41093553815569, 38.70975187846592, 40.74363204411098, 40.69145107269287, 40.51805182865688, 41.055376870291575, 36.73595973423549, 40.99535485676357, 43.3512909752982, 37.33911895751953, 34.71528809411185, 30.953960691179546, 36.47726093019758, 41.72182723454067, 43.40133190155029, 45.628788879939485, 47.93279416220528, 49.62684488296509, 50.58140924998692, 49.13864707946777, 45.92040824890137, 50.74734960283552, 50.982355049678254, 54.08876262392317, 51.71738413402012, 50.03260925837925, 48.30317483629499, 47.88183954783848, 49.204189436776296, 45.22114849090576, 43.334910597120015, 41.52624934060233, 48.86920288630894, 52.14994076320103, 53.005250113351, 54.96736233575003, 47.30526065826416, 43.92057425635201, 54.509663649967735, 56.463024616241455, 56.11060503550938, 53.8169595173427, 57.189187799181255, 52.1476582799639, 45.849300384521484, 41.78517048699515, 43.39951842171805, 45.60204873766218, 49.39471251623971, 50.92233998434884, 55.449282441820415, 55.347022329057964, 59.986320631844656, 59.43282018389021, 63.19877856118338, 61.24340261731829, 60.96623202732631, 61.07732677459717, 64.15386404309953, 56.49184226989746, 64.9040332521711, 23.10033713068281, 1.8968708089419772, 0.15808998766754354, 15.658375229154315, 62.655047280447825, 52.80051449366978, 37.25278411592756, 40.136501925332205, 33.709546770368306, 27.96848825045994, 40.24739170074463, 40.56501817703247, 34.322249344417024, 31.20113938195365, 14.423979112080165, 13.043158394949776, 12.145206212997437, 8.902183158057076, 0.06977053971162864, 0.021764607833964483, 0.017689872732652084, 0.028024558177483932, 0.027027276244812777, 0.1057186396792531, 0.19570628633456572, 0.7060119956731796, 0.23895894469959394, 0.023305693175643682, 8.776102014950343, 2.9609696183885847, 21.089353016444615, 37.23216533660889, 25.77887463569641, 46.27487754821777, 65.12228311811174, 44.6804188319615, 72.09277847834996, 67.77712726593018, 72.0838291985648, 49.64307934897286, 0.10961028906915869, 1.0286394378968646, 1.3644302423511232, 5.200171657970973, 54.50056150981358, 74.60583073752267, 70.16169343675885, 71.05247334071568, 70.31116308484758, 67.42454092843192, 68.11745698111397, 71.28525188991001, 67.19777951921735, 65.40906306675502, 66.23817770821708, 63.13051945822579, 53.55854558944702, 49.93420886993408, 49.79842022487095, 52.683037825993125, 55.04702343259539, 57.83374438967024, 61.40156446184431, 58.83709553309849, 57.929115363529746, 57.75419098990304, 59.79348727634975, 58.77051094600132, 59.92744159698486, 56.69858939307076, 52.12308250154768, 49.42742463520595, 46.00049665996006, 45.775451455797466, 47.35659742355347, 46.70174707685198, 52.33766719273159, 52.52424716949463, 51.35692548751831, 53.0994051524571, 53.099585805620464, 56.25698273522513, 53.85418449129377, 53.36159195218767, 54.291650022779194, 52.53592014312744, 51.52058335712978, 50.33315706253052, 53.41611794063023, 51.31144257954189, 46.67878328050886, 44.534253052302766, 39.36692292349679, 40.413557870047434, 39.7081732749939, 43.53477552958897, 44.30113056727818, 40.41017409733364, 40.743291582380024, 42.51710762296404, 42.541422843933105, 39.859901087624685, 43.420119830540244, 39.58732673100063, 39.53620883396694, 41.35302380153111, 43.25754587990897, 41.534566334315706, 43.68669441768101, 42.861884185246055, 40.27118233272007, 43.80087069102696, 44.45439740589687, 43.41536031450544, 42.34433371680123, 39.98840454646519, 40.32375587735857, 41.75357355390276, 42.232269695826936, 42.05727584021432, 40.76599482127598, 38.76759563173567, 44.650395665849956, 44.18764911379133, 40.02254452024187, 37.05677890777588, 33.15054334912981, 38.28174979346139, 44.787622588021414, 46.09819180624825, 50.04378890991211, 50.156436579568044, 51.94658783503941, 51.34836530685425, 51.95945242473057, 48.374640532902305, 51.84940685544695, 52.368656158447266, 54.78291198185512, 52.70509140832083, 53.340472902570454, 51.174097537994385, 49.34414005279541, 50.79922137941633, 47.26039266586304, 45.386821338108604, 43.44178083964756, 49.326564584459575, 54.738707542419434, 55.03944642203194, 59.52147224971226, 50.83715854372297, 48.273179462977815, 59.559437206813264, 58.34798404148647, 62.09818390437535, 59.21136719839913, 61.81432914733887, 56.74063989094326, 50.768979345049175, 45.84084095273699, 46.72500269753592, 47.62305736541748, 53.01559945515224, 54.84889554977417, 61.10613400595528, 59.58449935913086, 65.74578666687012, 63.64859104156494, 68.48410647256034, 64.95856271471295, 68.14992591312954, 65.2459818976266, 70.16808577946254, 61.94469819750105, 70.77952030726841, 26.882052285330637, 2.2201995849609375, 0.11444664240947791, 19.319301162447246, 69.0950129372733, 58.87088462284633, 42.00865929467337, 45.60292421068464, 41.26774161202567, 22.91306233406067, 41.89200251443045, 41.708907059260774, 39.30044603347778, 43.54285281045096, 22.69864092554365, 13.944495218140737, 12.972562960215978, 15.40836341040475, 0.3531083752002035, 0.04766029631718993, 0.04129945460174765, 0.16204664749758585, 0.12504294381609984, 0.21908842665808542, 0.16800584058676446, 0.3256758829312665, 0.25940271626625744, 0.14165048194783075, 17.12912126949855, 9.48181664943695, 39.07805504117693, 52.6728378704616, 35.67786373410906, 55.85746479034424, 73.48913710457938, 53.303223609924316, 75.21810599735805, 75.28471837724958, 77.35931846073696, 55.83478239604405, 0.15096807054110936, 6.305324333054679, 4.8192562120301385, 5.87391676221575, 62.43148899078369, 73.35550240107945, 72.35054969787598, 70.2392909186227, 70.99238531930106, 69.22053214481899, 69.6394737788609, 70.42944226946149, 68.03970663888114, 67.03512219020298, 64.6364859172276, 64.05239949907575, 55.175724915095735, 51.11545821598598, 51.065886293138774, 55.10658686501639, 55.36456653050014, 58.969027927943635, 61.7864807673863, 60.65632152557373, 61.81281444004604, 62.96274825504848, 60.32159900665283, 63.393953459603445, 62.229185240609304, 59.094019072396414, 53.090883186885286, 51.053452491760254, 49.382459368024556, 50.00158207757132, 47.9832797731672, 50.81642859322684, 53.112158570970806, 53.425504956926616, 54.325925486428396, 56.957743304116384, 56.02920688901629, 59.76288740975516, 55.20226008551461, 56.19249997820173, 57.63206945146833, 55.07185629435948, 55.170263631003245, 53.02452094214303, 56.55080815723964, 54.36920234135219, 50.98172971180507, 46.4052848134722, 45.252602985927034, 44.36399091993059, 41.709216254098074, 44.83632946014404, 46.51047706604004, 44.67422103881836, 42.40143401282174, 44.76762914657593, 46.24412482125418, 43.96950694492885, 47.987386158534456, 42.20684276308332, 41.23391778128487, 43.77065644945417, 46.97986957005092, 43.77886922018868, 45.67736373628889, 43.15233278274536, 44.08882488523211, 45.55396720341274, 47.36738450186593, 45.454997062683105, 44.08686201913016, 40.95088638578142, 42.37464870725359, 44.26579202924456, 45.510426316942485, 44.73783874511719, 44.51925189154488, 41.64753014700753, 46.67497566768101, 46.82974679129464, 42.57263762610299, 40.100784710475374, 36.13239404133388, 41.06425666809082, 48.661479541233604, 51.12959085191999, 54.98159919466291, 52.95447962624686, 53.644394057137625, 56.705589703151155, 54.04115356717791, 52.82019179207938, 55.88167231423514, 54.727003301892964, 58.48013877868652, 57.17096962247576, 55.11321892057146, 53.302424567086355, 51.37014096123831, 54.189553192683626, 49.726200648716514, 47.080302306583945, 44.62719215665545, 52.840470109667095, 55.72985070092337, 56.27541978018624, 58.568283626011436, 50.41806752341134, 48.220543384552, 60.50566373552595, 58.72151919773647, 62.383240699768066, 59.210352761404856, 60.24484920501709, 57.04786491394043, 50.209552083696636, 47.50287437438965, 48.513465540749685, 49.86482415880476, 54.29305703299386, 56.89819029399327, 62.24565941946847, 59.714548792157856, 66.14278588976178, 64.49661173139299, 66.1898112978254, 63.76132556370327, 67.53148760114397, 66.94113390786308, 70.09369836534772, 63.47978455679757, 72.26417664119175, 32.58578681945801, 3.054638066462108, 0.3043159805238247, 20.447617394583567, 75.13647856031145, 64.09636075156075, 51.02490234375, 54.367437498910085, 49.04449551446097, 36.23705128261021, 56.46823229108538, 56.399490288325715, 49.729289122990195, 70.85568646022251, 26.421744550977433, 32.22456387111119, 32.64342212677002, 14.341356345585414, 0.18858027085661888, 0.0882241612832461, 0.15832994479153836], [0.0408191332327468, 0.0725996575451323, 0.07398454751819372, 0.024580640119633505, 0.0586710570912276, 0.10589492986244814, 0.046527892617242675, 10.610402992793492, 2.9935230144432614, 9.742440973009382, 29.52898243495396, 22.274597576686315, 32.66858155386788, 47.379008838108604, 36.12264919281006, 53.79525681904384, 60.21431882040841, 61.312815121241975, 51.31267588479178, 1.9249634615012576, 0.5438624279839652, 3.767721482685634, 9.897226861545018, 58.581728390284944, 66.88071237291608, 62.571258953639436, 66.65946088518415, 60.32574013301304, 63.88728945595877, 64.3332804271153, 65.0060258592878, 59.530609130859375, 63.33116953713553, 61.46946920667376, 58.57195227486746, 51.930641719273154, 47.239912850516184, 44.98179347174508, 46.67192540849958, 47.01949167251587, 49.65087522779192, 51.01666178022112, 54.65260893957955, 57.784999302455354, 52.46135902404785, 54.38232054029192, 56.351238523210796, 57.425975458962576, 53.93759414127895, 54.2764230455671, 47.65923663548061, 43.8019893510001, 42.67767701830183, 46.30453245980399, 50.624967506953645, 55.149544102805, 50.38355582101004, 51.90891817637852, 51.403534003666465, 50.30852917262486, 50.86722339902605, 51.35210691179548, 51.203596115112305, 50.936906882694785, 48.071525369371685, 45.097359384809224, 45.84289761951992, 48.19619689668928, 48.27249159131731, 44.718078068324495, 40.51903847285679, 34.626910482134136, 33.49221754074097, 36.94186612537929, 38.34100750514439, 41.70636054447719, 35.519545555114746, 36.51269326891218, 39.058582714625764, 41.247887134552, 39.734600748334614, 39.170483452933176, 39.028048855917795, 38.107930183410645, 38.507552351270405, 41.09598561695644, 40.327789306640625, 40.608739716666086, 38.38305452891758, 39.661272934504915, 40.70888410295759, 40.09376702989851, 37.40067304883684, 36.48572383608137, 39.00351129259382, 39.11839975629534, 38.60947895050049, 38.33341659818377, 39.23189858027867, 38.54224123273577, 38.13706398010254, 40.89339699063982, 41.79336241313389, 37.05331870487758, 33.13926642281668, 31.721722739083425, 34.236053466796875, 42.07647718702044, 44.85829618998936, 50.70619889668056, 46.33463553019932, 48.009877477373394, 48.57244185038975, 50.593547752925325, 47.83005462374006, 48.15111698423113, 49.97297634397234, 53.89201395852225, 50.041176387241904, 54.88635676247733, 51.4410959652492, 51.59156962803432, 50.23718506949288, 48.771594592503135, 42.67399794714791, 42.66079636982509, 43.063847473689485, 51.94542053767613, 51.317723751068115, 52.865080629076274, 52.49902868270874, 51.05591562816075, 54.99670457839966, 51.49794612612043, 53.50282451084682, 50.72721719741821, 53.056308950696675, 47.07405587605068, 45.11564356940133, 42.32478148596627, 45.00854056222098, 44.72332048416138, 52.67731598445347, 51.954679012298584, 58.104793616703574, 56.20471143722534, 61.29738317217146, 57.674133845738, 61.369394302368164, 58.40031092507498, 63.81100518362862, 58.37089920043945, 69.0704093660627, 57.65510272979736, 65.62354006086076, 14.052293913705007, 1.340069749525615, 0.0787751879543066, 19.124732494354248, 65.54497677939278, 53.335543155670166, 37.50554568426949, 38.35939243861607, 32.42076710292271, 31.125265053340367, 44.99908406393868, 28.90343611580985, 32.551792757851736, 36.23147535324097, 2.6074389772755757, 7.095335815634046, 0.9893824415547507, 0.041624656080135276, 0.11158971821091004, 0.07526198468570199, 0.0691395564270871, 0.0607321954199246, 0.14891371077724866, 0.058473359128194194, 0.03980858424412353, 0.12986677139997482, 0.17439572699368, 0.13415676834327833, 14.59162872178214, 6.487235988889422, 16.636952570506505, 37.25304119927542, 24.807226385389054, 43.95584678649902, 54.17433316367013, 44.12573024204799, 60.377809933253694, 67.61173234667096, 68.19884817940849, 58.77438109261649, 2.521716228553227, 0.5217879467776844, 1.9779237168175834, 12.181124925613403, 65.11469568525041, 72.58198029654366, 70.85499858856201, 72.17954758235386, 66.72249494280133, 67.37493773869106, 68.92539351327079, 68.98034681592668, 62.99641922542027, 64.7830651147025, 67.14398656572614, 61.86892114366804, 57.055646896362305, 50.07332917622158, 49.45875753675188, 50.41457952771868, 52.49316440309797, 53.64510972159249, 55.19882072721209, 58.084650788988384, 61.125019209725515, 57.43739482334682, 57.055653844560894, 59.092212540762766, 59.524244580950054, 56.755575043814524, 55.35532195227486, 50.61253717967442, 47.312347820826936, 45.55269568307059, 47.514919076647075, 53.56669930049351, 56.93132625307356, 55.233103139059885, 53.98514066423689, 54.320710863385884, 54.53343343734741, 54.907434122903005, 53.88024023600987, 54.38002068655831, 52.74320922579084, 50.71616956165859, 47.26283843176705, 48.78837101800101, 49.37288127626692, 52.46461772918701, 48.023325715746196, 46.03005429676601, 37.28774397713797, 34.28510774884905, 40.01038517270769, 39.493567739214214, 44.756984506334575, 38.5200069972447, 39.551279476710725, 41.155931200299946, 41.442881379808696, 42.183767795562744, 41.3013048853193, 40.943000180380686, 41.44554601396833, 41.39458792550223, 44.4267053604126, 43.942461081913535, 43.02338811329433, 40.76576900482178, 41.26241929190499, 43.773084844861714, 40.484380858285085, 41.54481840133667, 39.53648328781128, 40.46301862171718, 41.01357650756836, 39.830993107386995, 40.36842932019915, 40.1203647341047, 38.79418291364397, 39.797739028930664, 42.01400940758841, 44.532203333718435, 40.75824063164847, 36.073647022247314, 34.38527645383562, 37.18030398232596, 46.182053089141846, 49.419521059308735, 52.905171734946116, 48.6350485937936, 50.680372442517964, 51.111688818250386, 53.4542635508946, 51.95976856776646, 51.264497075762065, 49.206280844552175, 54.79260471888951, 52.0573490687779, 54.60126175199236, 54.097746644701274, 54.595425265175955, 51.64274658475603, 51.4078106198992, 45.78582164219448, 45.48432193483625, 45.397643157414024, 54.739711557115825, 55.267701693943565, 56.21464041301182, 55.404226848057334, 54.69923482622419, 58.94559860229492, 55.3486829485212, 57.88568564823696, 54.010185446058, 56.10862479891096, 51.77467203140259, 47.35282455171858, 46.90708371571132, 49.495763642447336, 49.8743188721793, 55.737948826381135, 56.33514996937343, 61.53009223937988, 60.494143622262136, 65.01956789834159, 63.65184279850551, 64.92666353498186, 62.77089459555489, 66.90450995309013, 61.25611087254116, 72.03059210096086, 63.55770165579659, 70.0040943963187, 18.521017415182932, 1.423348252262388, 0.12591404707304069, 21.23953311783927, 72.48300320761544, 60.166577747889924, 43.39019046510969, 43.490883759089876, 40.995796067374094, 31.44522612435477, 50.57539905820574, 31.839126450674875, 35.53268459865025, 55.987597601754324, 5.925822845527104, 12.135645491736275, 2.8228518068790436, 0.18979168656681264, 0.051194052411509414, 0.08936228842607566, 0.03139363721545253, 0.13425392098724842, 0.251107571380479, 0.1808746236243418, 0.12044391488390309, 0.16572356091013976, 0.2548178280038493, 0.282597865909338, 23.128322737557546, 9.061595678329468, 33.9687180519104, 60.04412269592285, 33.198979241507395, 53.625776359013145, 62.297805649893625, 54.5246022769383, 63.85016523088728, 76.17878477913993, 71.48347704751151, 63.68939781188965, 2.13164826801845, 3.1201016051428656, 5.305953204631805, 14.136663283620562, 65.63943059103829, 71.3478204182216, 71.4939271381923, 72.3728256225586, 67.24211597442627, 66.50500243050712, 69.64925684247697, 68.25191852024624, 63.161772455487935, 67.66199561527797, 68.21969277518136, 62.80883175986153, 55.66241495949881, 53.789812905447825, 50.86727898461478, 51.98330906459263, 54.26864801134382, 55.47979198183332, 58.10509933744158, 61.273328508649556, 64.38104234422956, 59.57354899815151, 60.91175815037319, 60.601333481924875, 61.00514888763428, 60.529662813459126, 57.99019350324358, 52.72901405606951, 50.44689907346453, 46.759882654462544, 51.463569913591655, 55.72778013774327, 61.33340263366699, 58.42155851636614, 59.21817643301827, 58.061283997126985, 57.10756731033325, 57.436119828905376, 57.21959311621529, 57.92405360085623, 56.9970041002546, 54.25333070755005, 50.238262040274485, 52.282654830387656, 54.21137053625924, 55.212803976876394, 51.022463526044575, 49.652542795453755, 41.57887847082955, 39.30071006502424, 44.3831992149353, 40.941009521484375, 47.218526295253206, 38.399650301252095, 42.2562826701573, 44.06827906199864, 45.30125774656023, 42.97991670880999, 43.304630347660606, 43.05296312059675, 43.50720507758004, 42.79439633233206, 46.5478583744594, 46.6761360168457, 47.800952093941824, 42.52818305151803, 45.06319161823818, 47.75891201836722, 45.744264466421946, 42.495536940438406, 41.75445250102452, 42.52143635068621, 44.35920013700213, 43.49469832011631, 42.962223121098106, 43.594377177102224, 43.68880319595337, 42.42400871004377, 45.38337850570679, 45.84077841894967, 42.68170002528599, 38.97956085205078, 39.81073563439505, 42.08700370788574, 49.379492487226216, 51.0445032119751, 55.86392314093453, 51.55677304949079, 52.32869359425136, 55.022916657584055, 54.81694425855364, 52.527210576193674, 53.82788903372628, 52.62353345326015, 57.394117968423025, 53.6818413734436, 57.25613021850586, 54.45213603973389, 55.59915508542742, 53.91546412876674, 52.92534930365426, 47.64134502410889, 46.959487029484336, 47.95359012058803, 57.889368193490164, 56.25019781930106, 55.817467485155376, 57.65549530301775, 56.013427530016216, 58.98352187020438, 57.345299925122944, 57.922333921704976, 54.93008525030953, 57.23115144457136, 52.37789031437465, 49.69734130586897, 47.83686038425991, 51.06749480111258, 51.18848030907767, 56.33923898424421, 57.73761606216431, 61.78104032788958, 63.92431640625, 64.6392513002668, 61.24710600716727, 65.97359725407192, 62.86090850830078, 67.01645238058907, 63.32882104601179, 73.25202287946428, 63.64007255009243, 75.4289699281965, 23.48815257208688, 2.065798887184688, 0.25352071332080023, 23.559644324438914, 80.5865899494716, 64.71318708147321, 53.54597977229527, 52.18043640681675, 46.73435149874006, 44.91608783176967, 61.740247453962056, 47.286184379032676, 50.422361510140554, 77.95459147862026, 14.048447217260088, 17.585789884839738, 0.9626531558377402, 0.10736686230770179, 0.13181840096201214, 0.25189733185938423, 0.16218132312808717], [0.06773710596774306, 0.11235420326037066, 0.03990876654695187, 0.08300993179104157, 0.12185962391751153, 0.20943089202046394, 0.9804272992270333, 6.15398735659463, 0.7369740914021219, 7.033560250486646, 22.93220635822841, 27.77839422225952, 35.563725675855366, 54.249675955091206, 30.460430145263672, 47.422282218933105, 61.99662903376988, 63.314125605991904, 54.42833151136126, 5.663671221051898, 0.5058374341045107, 1.9912127980164118, 22.564868995121547, 61.390780857631135, 66.16058717455182, 63.58334050859724, 68.91814654214042, 63.06668635777065, 68.01349108559745, 61.35728359222412, 62.839285714285715, 64.27055209023612, 64.22144222259521, 61.1838287625994, 59.587452343532014, 52.99959775379726, 47.45935780661446, 46.68918473379952, 46.2935334614345, 44.272708960941856, 46.278626101357595, 50.8638778414045, 50.50151538848877, 52.996616976601736, 57.65942798342024, 54.21748495101929, 51.5743658883231, 59.67246355329241, 54.49305050713675, 55.413037163870676, 48.13790845870972, 43.079713685171946, 43.981086117880686, 49.02466882978167, 53.120100361960276, 51.488875252859934, 53.019709314618794, 51.94423586981637, 50.071654660361155, 50.57815401894705, 50.80801085063389, 49.09163556780134, 49.14287853240967, 49.09333440235683, 44.368013926914756, 42.554645265851704, 42.704986912863596, 45.532969747270855, 48.507531779153005, 45.997804233006065, 39.50455978938511, 33.48011725289481, 30.340459074292863, 37.157329763684956, 39.43364300046648, 42.162339551108225, 41.75510215759277, 36.22709451402937, 38.11127921513149, 40.042638710566926, 40.87517533983503, 39.46566724777222, 37.589424337659565, 39.10149826322283, 40.11577544893537, 38.708938939230784, 36.9159562928336, 38.356807708740234, 37.84697321483067, 36.67191818782261, 38.169105597904746, 37.43149873188564, 37.86757809775216, 40.81807156971523, 41.02773693629673, 36.93238183430263, 39.63211134501866, 35.88933563232422, 37.335057735443115, 36.08606692722866, 39.19424629211426, 40.15075962884085, 43.38978746959141, 47.07221460342407, 31.511880193437847, 32.83386877604893, 35.52372489656721, 43.878318786621094, 49.312279088156565, 48.6130610193525, 46.40829685756138, 46.107137611934114, 47.79872519629342, 50.02986124583653, 52.64456565039498, 51.87494148526873, 49.063325132642476, 52.317145688193186, 55.014391217912944, 52.570900848933626, 53.98562356403896, 52.82315172467913, 51.47472524642944, 51.17161008289882, 46.4304963520595, 44.182583877018516, 43.06741189956665, 46.935477529253276, 52.742128780909944, 55.64114652361189, 52.27376808438982, 52.23796054295131, 55.3485300881522, 55.65394510541643, 51.298334802900044, 48.81649037769863, 48.54956143242972, 44.39450740814209, 44.18593985693795, 40.29595960889544, 44.34267037255423, 48.25462429864066, 54.898926053728374, 55.79559108189174, 59.254459926060264, 58.573696272713796, 62.576935631888254, 58.57719121660505, 61.33707128252302, 56.19802032198225, 58.878020422799246, 57.0111471584865, 65.19259888785226, 56.15567452566964, 62.13218144008091, 10.658065029553004, 1.1449783380542482, 0.011594417937366026, 23.02108771460397, 68.62489782060895, 51.8467561176845, 36.45294223512922, 34.69225481578282, 32.246224880218506, 30.004169736589702, 38.84958437510899, 25.83988503047398, 30.05332476752145, 53.89019005639212, 10.212343301091876, 0.6443253457546234, 0.12566878380520002, 0.04663679748773575, 0.12901647202670574, 0.047223387618682215, 0.037826770051781616, 0.07206562334405524, 0.08403498107301337, 0.020366683203194822, 0.06560887409640209, 0.009784022894954043, 0.10593978102718081, 0.3578526920505932, 11.14358343396868, 3.7762603844915117, 14.53323779787336, 33.55669682366507, 31.63738203048706, 44.96982519967215, 62.36944852556501, 37.6840831211635, 57.021687575748985, 69.35356930324009, 68.65136350904191, 59.97817039489746, 6.59195750100272, 0.23541908179010662, 2.005714557000569, 26.200319358280726, 68.55199037279401, 70.39126191820417, 71.05947017669678, 73.41061551230294, 68.78748566763741, 71.51748153141567, 67.15146282741001, 67.38662460872105, 68.76332678113664, 66.86473846435547, 64.32519272395542, 64.4830071585519, 57.65868105207171, 50.328831808907644, 49.87713289260864, 47.99502222878592, 48.03220551354544, 51.66159357343401, 53.92808205740792, 53.771042346954346, 57.96708032063076, 60.11368111201695, 58.59333883013044, 56.469180720193044, 61.729012216840474, 57.0129919052124, 56.20816469192505, 50.58857979093279, 47.11425815309797, 46.74462788445609, 51.26358686174665, 55.38238518578665, 54.56455789293562, 55.253183432987754, 54.052684102739605, 52.848780155181885, 52.11498090199062, 54.340475014277864, 52.27179479598999, 51.288972105298726, 48.87683548246111, 45.86263050351824, 45.728082111903596, 45.83062710080828, 48.01570701599121, 51.87657083783831, 48.685353551592144, 44.48180457523891, 35.80307722091675, 33.277955940791536, 40.343874386378694, 40.662914821079795, 45.53930303028652, 43.89238888876778, 40.195558139256065, 39.485695430210654, 41.75976092474801, 41.83350215639387, 41.012475218091694, 40.19713885443551, 40.455035141536165, 42.28358561652047, 41.31841482434954, 38.243854318346294, 40.25404807499477, 39.246003423418315, 39.56228542327881, 39.563355445861816, 41.540715490068706, 41.784267221178325, 43.83661569867815, 41.01964923313686, 40.3267297063555, 42.68817227227347, 39.30077607291085, 39.15956435884748, 38.61996030807495, 40.10659340449742, 40.5573855808803, 46.63052804129464, 49.09761449268886, 35.92255844388689, 34.49365792955671, 39.64663655417306, 47.906488282339915, 51.14966072354998, 50.89574228014265, 48.67321157455444, 48.54786259787423, 49.22719839641026, 53.13821431568691, 52.440566539764404, 53.558274609701975, 50.854952880314414, 53.37513746534075, 57.02870178222656, 55.81815883091518, 54.62919003622872, 55.33009304319109, 53.011159556252615, 53.56573697498867, 48.86901181084769, 46.510369368961875, 45.90482343946184, 49.45508541379656, 54.669319357190815, 58.9819724219186, 55.66172013963972, 56.73569277354649, 59.72284494127546, 58.64012105124337, 54.1342316355024, 51.61465154375349, 51.266873359680176, 47.86981916427612, 46.98343399592808, 45.64255673544747, 48.21304627827236, 54.238861083984375, 58.89063140324184, 61.04332229069301, 62.66235678536551, 64.46076597486223, 66.45795617784772, 63.27033111027309, 66.29751532418388, 60.164701734270366, 60.46006270817348, 61.119606563023154, 66.10983058384487, 60.793381690979004, 68.69901425497872, 15.768184559685842, 1.502161668879645, 0.0198218653843339, 25.994001286370413, 75.65496703556606, 55.572147437504356, 48.25755296434675, 41.40999902997698, 38.19914266041347, 33.27489178521292, 49.16630090985979, 26.598178420748027, 36.43568638392857, 70.96901852743966, 13.719103472573416, 1.8146181425877979, 0.3362995700112411, 0.08529060333967209, 0.10045647168798105, 0.036289026495069265, 0.0871583999001554, 0.10619199927896261, 0.19360581333083765, 0.08009537282798972, 0.22289815651518957, 0.1790687705257109, 0.4106435036020619, 1.5030789396592548, 12.786497150148664, 5.287332032408033, 35.58473008019583, 54.49556228092739, 39.94951547895159, 55.64145571844918, 70.69134071895054, 48.93550954546247, 60.2433831351144, 76.13039752415249, 72.06989806038993, 67.01304081508091, 6.2222924913678845, 0.8215578783835683, 2.2345958181789944, 26.93397617340088, 66.70401273454938, 70.70379883902413, 70.64613573891776, 74.25799696786063, 69.24205071585519, 73.138336454119, 67.70506055014474, 67.01736259460449, 66.54781723022461, 68.36682782854352, 66.64586326054165, 65.38180528368268, 57.69237286703927, 52.38846547263009, 52.02461610521589, 51.160548550742014, 48.87921176637922, 53.36320046016148, 56.9487419128418, 56.39790957314627, 58.996931893484934, 63.8420775277274, 60.39686189379011, 59.892568588256836, 62.549580574035645, 60.08460290091378, 57.99350779397147, 52.99079091208321, 48.19415065220424, 50.0396443094526, 53.63625771658761, 58.071445737566265, 57.43982669285366, 55.42724622998919, 58.21251848765782, 55.48313059125628, 56.176536491939, 56.54833459854126, 54.68609578268868, 53.96023137228829, 53.791390146527974, 48.840093408312114, 48.222579206739155, 48.541195801326204, 51.609443868909565, 54.09045103618077, 50.91204275403704, 47.42279291152954, 43.22438907623291, 39.32021018436977, 43.435788018362864, 44.27040910720825, 47.749750818525044, 44.9945364679609, 40.94448709487915, 41.83054222379412, 43.433439527239116, 45.63682794570923, 42.83367449896676, 41.973657744271414, 43.445289679935996, 44.694127627781455, 44.14075919560024, 41.80290923799787, 43.79795592171805, 41.03634575435093, 42.55792828968593, 43.390555245535715, 43.02436433519636, 43.47730697904314, 46.465487480163574, 44.22208438600813, 41.1149958883013, 45.48297051021031, 42.023285252707346, 42.46593414034162, 41.245146070207866, 43.20259257725307, 43.46557147162301, 49.31851857049124, 51.21700961249215, 38.86694097518921, 38.59880651746477, 44.286299637385774, 50.86415924344744, 54.31496817725045, 52.34142964226859, 51.87331560679844, 52.07090847832816, 52.46407924379621, 57.17627804619925, 55.73158427647182, 54.53251280103411, 53.432262080056326, 57.89079257420131, 59.73197487422398, 57.862099988119944, 57.018637316567556, 56.815517153058735, 57.02286182131086, 56.7077818598066, 50.341873577662874, 47.155388014657156, 47.1286860874721, 51.82608870097569, 55.99836383547102, 58.97824123927525, 57.40322010857718, 60.23957552228655, 60.04567909240723, 60.057108879089355, 55.44482864652361, 53.76666498184204, 52.23475742340088, 48.617584296635215, 50.33772897720337, 46.217930112566265, 48.7345780645098, 54.71059513092041, 59.63360227857317, 61.48210103171212, 63.29834624699184, 64.47130639212472, 66.64003372192383, 63.18567425864083, 63.972092219761436, 59.328722272600444, 60.21633379799979, 61.029328618730815, 68.13247203826904, 64.11968585423061, 70.82991559164864, 19.587194170270646, 1.8951291995389121, 0.09794303548655339, 29.330823285239084, 78.64374160766602, 61.83802945273263, 55.588347162519185, 47.7368723324367, 45.94675234385899, 45.45637280600411, 54.44010523387364, 43.76338168552944, 50.27689055034092, 85.95208617619106, 27.252075127192906, 1.2057104791913713, 0.40591080327119144, 0.2655087714748723, 0.1855352906776326, 0.1072451670521072, 0.16369128067578587], [0.04378801570939166, 0.03698659781366587, 0.09586623656962599, 0.02899064276633518, 0.04881439956703356, 0.038142309191503694, 0.45396305194922854, 1.6208446089710509, 0.5107728264161518, 6.762985672269549, 22.849864993776592, 28.160277639116558, 29.197449139186315, 57.65095812933785, 34.860088552747456, 47.6019800049918, 60.25887761797224, 64.51302337646484, 59.570415360586985, 9.88629560811179, 0.08454364484974317, 3.825914817196982, 29.058785676956177, 58.842098236083984, 64.04410334995815, 64.38635076795305, 63.52258546011788, 64.70306355612618, 61.34283133915493, 63.396663257053916, 62.98296056474958, 62.549691745213096, 62.301286697387695, 62.125101225716726, 61.756846700395855, 58.96476173400879, 48.686145646231516, 44.7105427469526, 45.06353555406843, 45.07949556623186, 46.01136711665562, 46.10277761731829, 46.77198641640799, 53.05589205878121, 51.38727174486433, 54.799764837537495, 51.949037075042725, 52.47481073651995, 57.088025501796174, 51.11369684764317, 49.94828939437866, 42.818836620875764, 45.008307797568186, 52.640216078077046, 53.37107624326433, 52.53360986709595, 52.60825783865792, 46.61917815889631, 49.215490681784495, 47.7210373878479, 52.409198897225515, 47.102237769535606, 46.791139125823975, 43.39351865223476, 39.668238503592356, 39.728305680411204, 39.933440821511404, 43.41442230769566, 45.64064598083496, 48.03819833483015, 40.99147081375122, 31.01028973715646, 29.86671699796404, 37.63748502731323, 35.417209012167795, 43.23318896974836, 44.44405501229422, 40.806944029671804, 37.64587845121111, 37.33658633913313, 37.6292861529759, 38.73342786516462, 38.471835136413574, 39.38562052590506, 39.578505992889404, 37.12749072483608, 36.28115497316633, 37.29416758673531, 36.27681234904698, 37.97470889772688, 38.36186599731445, 41.88017668042864, 39.02084009987967, 42.27114486694336, 37.67288957323347, 36.8038957459586, 37.884521280016216, 37.170586926596506, 35.41599655151367, 37.4202287537711, 35.985168661390034, 40.15038095201765, 38.54981129510062, 49.36377566201346, 31.209994861057826, 30.822941984449113, 38.51093264988491, 46.75819076810564, 48.66357789720808, 48.393334661211284, 43.72993653161185, 42.55048329489571, 43.6691814831325, 47.41136312484741, 49.975415161677766, 51.35033164705549, 54.49050399235317, 50.71266419546944, 50.28017357417515, 50.87227126530239, 50.04437950679234, 54.64926338195801, 52.50542449951172, 53.01748936516898, 50.02477863856724, 43.54287365504673, 42.14099815913609, 47.53521476473127, 52.3652480670384, 53.91628401620047, 55.897163322993684, 55.591501644679475, 55.444033077784944, 52.10366228648594, 44.378929546901155, 45.451161657060894, 43.26335457393101, 42.20506402424404, 44.05612318856375, 45.01371349607195, 50.237164224897114, 54.024585587637766, 55.80728490012032, 58.54911354609898, 59.874920163835796, 58.71123586382185, 60.71936253138951, 60.62929303305489, 62.78881399972098, 62.344351632254465, 61.62724890027727, 57.951033455984934, 63.632172448294504, 58.69214916229248, 50.93398516518729, 10.275497215134756, 1.1482751497200556, 0.04092556145042181, 29.29965714045933, 68.01689570290702, 49.24040692193167, 32.27991322108677, 31.47685432434082, 39.57219008037022, 37.76746497835432, 34.01002161843436, 26.88785055705479, 41.1287567956107, 64.78835964202881, 15.82207999910627, 0.22428915330341884, 0.1532490202890975, 0.011871648686272758, 0.0707399355513709, 0.07726689281740359, 0.028513846386756216, 0.03653522953391075, 0.039497547184250185, 0.046961422211357524, 0.07990030758082867, 0.09349029191902705, 0.07681758728410516, 0.31205369532108307, 5.21317868573325, 0.7685013796601976, 11.66338164465768, 36.2692666053772, 23.934371096747263, 30.386893885476248, 69.43312617710659, 39.1579384803772, 56.14928913116455, 65.32454517909459, 72.99866376604352, 62.63385527474539, 11.73824327332633, 0.12570683604904584, 4.459640034607478, 33.14902516773769, 66.76631723131452, 70.48689692361015, 70.09398324148995, 66.70562471662248, 70.06031227111816, 65.54483086722237, 67.65215001787458, 64.56415516989571, 66.24149199894497, 64.68431036812919, 65.55039637429374, 66.3448464529855, 63.202940532139365, 51.17581721714565, 48.26251745223999, 49.417822224753245, 48.98342432294573, 48.748769760131836, 48.74651159558977, 49.25100292478289, 57.60552385875157, 54.45972694669451, 58.103747912815635, 54.68389320373535, 55.42672511509487, 57.28942946025303, 52.51309878485543, 51.02422489438738, 45.29380232947213, 47.453281606946675, 53.65593501499721, 55.08376203264509, 54.035285813467844, 52.15537772859846, 50.990057127816335, 50.71173313685826, 52.90015513556344, 54.74886928285871, 52.19675077710833, 51.476469244275776, 44.166797569819856, 43.28676305498396, 42.69080216544015, 42.89085469927107, 44.37788731711251, 48.377753325871055, 50.860890116010395, 46.10931587219238, 34.5183379309518, 33.79414108821324, 39.337459087371826, 40.09685550417219, 44.354412828172954, 45.93966865539551, 43.050805704934255, 40.01320614133562, 40.28098624093192, 41.06828314917428, 41.23116282054356, 40.829737595149446, 42.45767273221697, 42.117266586848665, 39.862996510096956, 38.031437465122764, 39.33166776384626, 38.172753402165, 39.66888468606131, 41.13260262353079, 42.87311247416905, 39.96459654399327, 43.79299143382481, 39.50164154597691, 39.67553758621216, 40.67205170222691, 38.74539613723755, 38.7900105203901, 39.070519719805034, 38.676105226789204, 41.07613113948277, 43.187202317374094, 50.67532457624163, 34.57786314828055, 34.10848454066685, 42.6092928477696, 49.27049609592983, 51.46962526866368, 49.65621839250837, 44.77315296445574, 44.2994247845241, 45.167598724365234, 47.41555636269705, 51.39416088376726, 51.16383504867554, 53.91968863351004, 53.092950275966096, 51.94826929909842, 52.99792323793684, 50.92401450020926, 54.54432473863874, 55.108952726636616, 53.38924578257969, 53.82384170804705, 45.1786150932312, 44.381444794791086, 48.84189993994576, 56.758295263562886, 57.05446570260184, 57.54574155807495, 58.46383135659354, 57.565450123378206, 56.3185715675354, 48.900514943259104, 48.729672636304585, 47.276571546282085, 46.049693380083355, 46.569675718035015, 48.165819372449604, 54.31502028873989, 58.926581382751465, 61.270222663879395, 62.80408614022391, 62.983203751700266, 62.53642763410296, 64.71241583142961, 64.79503686087472, 64.60178661346436, 67.11920928955078, 65.31904915400914, 60.15024948120117, 64.92923436846051, 64.03889914921352, 56.486075265066965, 14.179683923721313, 1.5184430352279117, 0.0531240129577262, 33.29449265343802, 76.51420906611851, 55.08893149239676, 41.93727002825056, 37.017337458474294, 39.86848906108311, 43.95039939880371, 37.399533544267925, 27.401584727423533, 47.62513835089547, 76.93956388745988, 18.618285247257777, 0.2925636725766318, 0.1562764264111008, 0.05694883343364511, 0.036450263378875594, 0.016659995674022605, 0.01954512657331569, 0.05031542420121176, 0.09508615200008665, 0.1675464723791395, 0.1792518121323415, 0.1486251162631171, 0.12013115095240728, 0.4106284129832472, 4.229695047651019, 0.8924151190689632, 32.28886944907052, 53.958331039973665, 38.49571262087141, 48.49590744291033, 74.7598306110927, 52.010452202388215, 59.53144291469029, 73.48422472817558, 74.4264143535069, 72.01855087280273, 12.122051341193062, 0.12692441285720893, 4.911155257906232, 34.147985049656455, 67.63504355294364, 70.65938595363072, 72.22929668426514, 66.50522477286202, 68.98027733394078, 66.03400489262172, 67.85024315970284, 63.37365082332066, 65.66738319396973, 66.6309037889753, 67.04229273114885, 66.68013177599225, 63.51818030221121, 52.44445405687605, 49.89955472946167, 50.39233486992972, 50.37268883841378, 51.997941970825195, 52.053669997623985, 53.052664620535715, 58.65465668269566, 56.66124977384295, 58.32103892735073, 56.21476200648716, 58.82864652361189, 60.81651224408831, 55.30895662307739, 53.081569126674104, 47.17261954716274, 49.127714088984895, 57.46701151984078, 57.181221689496724, 56.478227274758474, 58.23454775129046, 52.720752647944856, 53.57586397443499, 54.863938399723594, 57.31017330714634, 52.579881395612446, 54.004064083099365, 48.70367595127651, 45.37897334780012, 45.33563395908901, 46.04095254625593, 49.41020005089896, 50.84283174787249, 54.967615944998606, 49.32349348068237, 41.44404520307268, 37.499931539808, 45.11296156474522, 43.35894441604614, 47.88916294915335, 48.66488068444388, 44.931523254939485, 43.43500634602138, 43.70500292096819, 44.10002538136074, 43.56223481042044, 44.31630890710013, 44.61605419431414, 44.19826596123831, 41.31376300539289, 40.93143490382603, 41.10856533050537, 41.92008018493652, 41.63475588389805, 44.907958439418245, 46.80265923908779, 42.19981813430786, 46.37702301570347, 42.06799691064017, 39.981901032584055, 42.397282464163645, 42.04067311968122, 41.37521287373134, 41.663691656930105, 40.245011942727224, 45.0002235685076, 46.275621005467, 53.50766740526472, 38.35399716241019, 39.98734494618007, 44.282512869153706, 53.88332176208496, 54.99854237692696, 54.10152646473476, 48.10355656487601, 48.26003347124372, 48.06579310553414, 52.61496632439749, 54.103187084198, 54.521413053785054, 56.31055334636143, 55.64676761627197, 56.29779645374843, 54.17729657036917, 52.04867424283709, 57.179390839168, 58.31946863446917, 56.00673641477312, 55.489321436200825, 46.79998765672956, 45.27724824632917, 51.67544480732509, 57.44795608520508, 56.99512113843645, 57.6606890814645, 59.17389556339809, 59.197387422834126, 58.38207885197231, 48.08883680616106, 49.68045023509434, 46.90976224626814, 46.94507646560669, 47.86347893306187, 49.929709911346436, 56.569057600838796, 59.40916156768799, 60.53741005488804, 63.75471782684326, 64.10955538068498, 64.498446055821, 63.819780758449006, 64.48774582999093, 66.39198303222656, 67.3585260936192, 63.932105336870464, 60.06650284358433, 64.2501938683646, 67.24650723593575, 60.79622350420271, 14.912081377846853, 1.7879830918141773, 0.14231094079358236, 35.87007869992937, 80.31825746808732, 60.072964668273926, 45.85109649385725, 41.49970374788557, 56.70815706253052, 57.894565446036204, 46.14969185420445, 46.221025535038535, 62.47704832894461, 85.51885904584611, 24.968275206429617, 0.3726174240665776, 0.2653295568057469, 0.11014079488813877, 0.1419389678963593, 0.25770157469170435, 0.13989812455007009], [0.06302254966327123, 0.06062053569725581, 0.028316577597122108, 0.12623887535716805, 0.02009043293739004, 0.04391467784132276, 0.04058854328468442, 0.24458611703344754, 0.14888399094343185, 6.934543643678937, 32.368137972695486, 49.387243202754426, 32.06274727412632, 61.12636716025216, 35.05702829360962, 40.506444862910676, 62.54598140716553, 62.443273135593955, 60.062889780317036, 9.714940871511187, 0.054740995833916326, 6.675599915640695, 35.561828817640034, 53.972328186035156, 63.9463005065918, 61.556669098990305, 63.05724375588553, 61.88429750714983, 64.27233777727399, 60.7793185370309, 63.83595616476876, 64.05548449925014, 63.01909119742257, 61.31305830819266, 58.9024989264352, 60.96356391906738, 52.61172846385411, 44.67023972102574, 44.5244699886867, 44.292295932769775, 45.31383746010916, 43.32166385650635, 46.01781504494803, 47.6216573034014, 49.01413188661848, 51.088328974587576, 55.35532890047346, 49.76520088740757, 52.650152002062114, 50.51423406600952, 46.56185204642159, 43.8009922845023, 44.5935628754752, 51.86264317376273, 52.05949258804321, 49.65631219318935, 49.75076947893415, 44.32320499420166, 46.24360718045916, 51.3542400087629, 51.998671531677246, 49.658903871263774, 44.43952131271362, 40.89869499206543, 41.86070782797677, 36.218523911067415, 38.611389705113, 39.15913009643555, 44.44695935930525, 48.18613590512957, 45.198657172066824, 32.29082536697388, 28.75523451396397, 43.2377678326198, 37.02684259414673, 39.181458132607595, 41.69796712057931, 40.66046558107649, 36.34799664361136, 38.25413417816162, 38.29718174253191, 37.33834423337664, 38.112793922424316, 40.19059017726353, 39.5489170891898, 41.264729567936485, 38.4117888041905, 37.97574765341622, 37.02718652997698, 35.46888623918806, 37.718608719961985, 40.51198952538626, 38.576186656951904, 37.85765607016427, 36.45783724103655, 36.75734976359776, 36.63989741461617, 37.71664237976074, 37.23422200339181, 37.845107623508994, 38.5841076033456, 39.66774518149239, 37.10646547589983, 44.65250791822161, 32.367811407361714, 31.16762822014945, 42.126452105385916, 46.997611795152935, 48.31694616590227, 43.246456554957796, 43.00622606277466, 40.32032346725464, 41.10699503762381, 41.41597448076521, 47.35613189424787, 50.86293288639614, 52.334130559648784, 54.648273263658794, 49.406520979745046, 46.72815717969622, 47.80177198137556, 46.5769157409668, 55.01532922472273, 51.97171252114432, 53.01800005776541, 45.28865024021694, 42.45041881288801, 44.321940422058105, 51.301207883017405, 54.202039105551584, 53.33971554892403, 53.67439637865339, 56.652835505349294, 51.16709722791399, 44.93400028773716, 45.30477006094796, 44.58167450768607, 43.39228534698486, 42.329690388270784, 45.19932419913155, 53.79696954999651, 56.59543991088867, 57.88252074377877, 58.04944426672799, 60.299246651785715, 58.23379734584263, 61.437952177865164, 59.089843205043245, 60.69894872392927, 60.93988445826939, 65.45948614392961, 62.83911200932094, 60.214138167245046, 57.03276647840227, 47.358834743499756, 15.213555029460363, 0.9683346109730857, 0.18909473610775812, 30.824807575770787, 65.24650301252092, 52.663040910448345, 27.096173184258596, 36.34411607469831, 44.187353815351216, 46.25219515391758, 28.602327244622366, 36.46598400388445, 51.89822837284633, 49.108224391937256, 1.9028356203011103, 0.12076976097055844, 0.08811834374708788, 0.054459498796079836, 0.03543499178652253, 0.020733241390969073, 0.018777201351310526, 0.08159739830132041, 0.07230432517826557, 0.07946941748793636, 0.08001094950096947, 0.05989310544516359, 0.07328706780182463, 0.0808319090200322, 1.4226544094937188, 0.36034139565059115, 12.511959058897835, 46.89839846747262, 53.226525919778005, 35.683186054229736, 73.45583438873291, 38.82550886699131, 47.22553355353219, 69.36538818904332, 69.96562916891915, 64.93165928976876, 11.666819265910558, 0.046443316619843245, 8.635907343455724, 39.500745228358674, 61.322111810956685, 69.75882993425641, 68.09098434448242, 67.63502270834786, 67.18769073486328, 68.61049420492989, 65.99304526192802, 65.85025978088379, 67.28871059417725, 63.394175801958355, 65.78234113965715, 63.64860493796212, 63.1264408656529, 56.360319818769185, 48.9797556740897, 46.219198158809114, 46.02289765221732, 48.13018206187657, 47.83876419067383, 49.24997806549072, 48.332982608250205, 53.43909215927124, 55.16419785363333, 58.654128619602744, 54.25577647345406, 54.4065454346793, 53.156352588108604, 49.42366565976824, 44.225211075374055, 47.84319019317627, 52.31817054748535, 55.58493559701102, 52.92868791307722, 52.91682733808245, 48.776989868709016, 50.62765645980835, 53.99141141346523, 51.724891662597656, 50.70497253962925, 46.941213267190115, 43.14119482040405, 44.41337871551514, 39.10214444569179, 39.97111048017229, 42.98791061128889, 46.863532406943186, 51.10277080535889, 48.01377541678292, 36.411159242902485, 32.60434545789446, 47.30587557383946, 40.495115825108115, 40.75818852015904, 43.24826308659145, 41.95382063729422, 39.19618483952114, 40.508974007197786, 42.55008724757603, 38.43985257829939, 39.71337400163923, 42.749069758823936, 42.80850117547171, 41.633602482931956, 40.880890233176096, 40.61863742555891, 39.92642661503383, 37.68455212456839, 40.63681043897356, 41.71467406409127, 39.62330102920532, 39.4756691796439, 39.54828480311802, 38.96221814836775, 40.182929788317, 39.625857966286794, 38.505888257707866, 38.043284143720356, 40.741196700504844, 41.14152063642229, 40.127226080213276, 45.036628655024934, 36.10279818943569, 35.84122283118111, 45.3307181085859, 49.38690274102347, 50.45796060562134, 46.270840644836426, 44.63217054094587, 43.13355527605329, 42.270137378147666, 42.26386662891933, 47.09902422768729, 53.00392648151943, 52.86056429999215, 55.88245051247733, 53.90810251235962, 49.052503313337056, 48.69694662094116, 49.24048335211617, 59.53190149579729, 55.21430826187134, 54.1851931980678, 47.24686104910714, 43.84846585137503, 46.36376585279192, 54.638625689915244, 55.71037490027291, 56.08029351915632, 58.514052936008994, 59.39633519308907, 55.53635031836373, 47.36145074026925, 47.00014441353934, 47.118781430380686, 46.074133668627056, 46.20436722891671, 48.902703625815256, 57.80497884750366, 61.34609004429409, 61.13838059561593, 62.18279906681606, 63.05650724683489, 61.80936118534633, 64.20174407958984, 62.667533193315776, 63.50554152897426, 64.89078303745815, 67.9753315789359, 66.8834638595581, 63.47332968030657, 62.9518187386649, 56.15384367534092, 16.746923446655273, 1.156882882118225, 0.13640200000788483, 33.483587878090994, 72.14997604915074, 60.467997550964355, 38.87233625139509, 38.86370658874512, 49.407427719661165, 52.74853154591152, 29.400885445731028, 39.55390589577811, 60.38165923527309, 59.6605543409075, 2.8065799943038394, 0.1939240326838834, 0.1871850128684725, 0.015505397093615361, 0.034801548812538385, 0.09421497410429375, 0.05155222051377807, 0.29611276356237276, 0.15539815782436303, 0.08662366002265896, 0.17362681111054762, 0.11834101272480828, 0.14803192737911428, 0.132665090528982, 1.1924772007124764, 0.21027235686779022, 29.900009291512625, 62.30731078556606, 63.38740825653076, 47.73152221952166, 78.19424179622105, 50.38050556182861, 51.36480474472046, 76.15155478886196, 73.77412441798619, 70.95354488917759, 13.863157868385315, 0.15138509816357068, 8.917987704277039, 39.60009057181222, 63.127496991838726, 73.69420623779297, 69.44757148197719, 67.49283477238247, 66.63695566994804, 69.33030673435756, 66.084059715271, 65.44064262935093, 67.05636978149414, 64.53182520185197, 67.0277293069022, 65.19089657919747, 64.42149475642613, 57.338362148829866, 49.03527178083147, 48.08984776905605, 48.85908283506121, 50.842897755759104, 47.55423893247332, 51.15234967640468, 51.1186717578343, 55.50797734941755, 55.269761834825786, 59.927802903311594, 56.57541172845023, 59.78913770403181, 53.90249531609671, 51.83162988935198, 48.37978914805821, 50.04307324545724, 55.11134985515049, 54.59837824957711, 55.07218633379255, 54.01746368408203, 50.50212335586548, 52.669738973890034, 56.42683492388044, 56.424701826913015, 54.77188866479056, 50.764897278376985, 47.1975496837071, 47.67191014971052, 41.8430871963501, 43.89328520638602, 44.69672277995518, 49.43465076174055, 54.501294544764924, 50.912202562604634, 41.28500093732561, 40.125037397657124, 48.05321339198521, 41.2204521724156, 45.94858666828701, 46.42010532106672, 46.48038094384329, 41.77557155064174, 42.82671935217721, 44.734979561397004, 41.78182145527431, 42.99341705867222, 45.0375770841326, 44.174541337149485, 45.29430259977068, 43.79681641714913, 43.93166010720389, 42.87151091439383, 41.31302997044155, 42.83657537187849, 47.25993755885533, 43.68696192332676, 43.64064870561872, 42.4989971433367, 39.11436285291399, 40.23719869341169, 42.96048954554966, 40.71550573621477, 41.54647207260132, 43.102753911699565, 43.74669211251395, 41.59918458121163, 50.84133093697684, 38.66479008538382, 39.41209316253662, 47.308738231658936, 53.93358850479126, 53.27520152500698, 48.41830996104649, 47.19784498214722, 44.794185161590576, 43.69559506007603, 45.25214440482003, 50.66573258808681, 55.56175988061087, 55.57146998814174, 57.21539293016706, 51.556978021349224, 52.01788330078125, 50.04015500204903, 50.99857561928885, 58.53862176622663, 55.6446727343968, 56.55162457057408, 49.167659282684326, 46.39642586026873, 48.5305928502764, 55.02340303148542, 57.12836674281529, 56.60357277733939, 60.31351825169155, 60.4120089667184, 56.05938638959612, 47.58293499265398, 50.055430616651265, 48.47591052736555, 45.572974000658306, 47.143468379974365, 49.58429758889334, 58.91968182155064, 61.141312735421316, 62.146314076014924, 63.05686160496303, 65.54513658796037, 62.910407475062776, 65.41486481257847, 63.943118231637136, 64.94650064195905, 68.27488231658936, 68.81714057922363, 66.06010232652936, 63.146347454616, 63.51240634918213, 59.97569683619908, 17.79709676333836, 1.7939537657158715, 0.3819337912968227, 35.884659494672505, 74.9405324118478, 65.02724565778459, 41.42497934613909, 47.36621720450265, 67.04866422925676, 62.602386883326936, 45.466478960854666, 55.68675102506365, 74.21964291163853, 65.49510955810547, 3.0329542585781644, 0.2836075802998883, 0.20261631054537638, 0.12841108308306762, 0.13927908348185675, 0.16910109110176563, 0.13593877772135393], [0.03215690768722977, 0.1200126651674509, 0.09097256737628154, 0.04270639017756496, 0.03625680286703365, 0.007638788632383304, 0.08759620426488773, 0.2374726544533457, 0.6250373093145234, 6.125190981796809, 35.32592010498047, 37.458454268319265, 45.501456192561555, 49.00014863695417, 42.13729476928711, 26.298261165618896, 56.84345585959298, 61.18998486655099, 64.79786477770124, 12.776087011609759, 0.02459589867586536, 10.32072911943708, 37.32245717729841, 55.62767744064331, 63.04432010650635, 61.429642132350374, 63.17391095842634, 62.102512632097515, 63.79551764896938, 60.25971140180315, 62.922789164951865, 59.46153014046805, 61.90897750854492, 60.09766551426479, 59.42517021724156, 59.290152822222026, 57.297628334590364, 46.714038440159385, 46.17348943437849, 42.939697061266216, 43.244990485055105, 42.35209485462734, 44.06973123550415, 42.74432066508702, 45.41697999409267, 49.440254483904155, 53.364405972617014, 52.72251401628767, 49.7130685533796, 50.877242701394216, 45.96383796419416, 41.193385464804514, 44.95393466949463, 51.478011744362966, 50.232293537684846, 54.23503262656075, 51.526649134499685, 46.96360731124878, 51.00134795052664, 50.02319097518921, 47.521127292088096, 47.0188489641462, 42.38638768877302, 40.045237336839946, 40.65721035003662, 38.31306185041155, 38.323956625802175, 39.58059740066528, 43.78406299863543, 49.03521966934204, 46.16436297552926, 34.184053148542134, 28.137317316872732, 47.12352705001831, 38.454384735652376, 37.876093115125386, 40.473482608795166, 39.778961522238596, 35.19821221487862, 37.92337213243757, 39.31310565131051, 38.30376863479614, 37.30556263242449, 37.38658905029297, 36.62574740818569, 38.38069214139666, 39.3463180405753, 37.755944865090505, 35.956142561776296, 38.71672092165266, 38.829146248953684, 39.54741627829415, 37.21369007655552, 37.377452169145855, 37.10400581359863, 38.19752025604248, 36.321822779519216, 35.68841804776873, 36.4641774722508, 38.131880623953684, 33.834346839359824, 37.84552798952375, 39.78013229370117, 40.592196055821006, 29.873630455562047, 33.46599503925869, 45.814149447849815, 48.046202659606934, 48.47452436174665, 42.74328885759626, 40.25252989360264, 40.052001408168245, 41.52707270213536, 42.96834448405674, 40.57786887032645, 48.174959727696006, 48.34477717535836, 50.05921738488333, 53.409468514578684, 50.04411200114659, 46.600015027182444, 56.86571788787842, 56.74416957582746, 51.21665178026472, 51.87264163153512, 44.54590170724051, 43.21576983588082, 44.912134306771414, 52.466274874550955, 54.04923432213919, 54.103294781276155, 54.89142199925014, 55.66618088313511, 51.11890452248709, 44.36654438291277, 43.75747571672712, 45.45539658410208, 44.07475478308541, 44.496169975825715, 46.541309697287424, 58.02331556592669, 59.252069745744976, 60.890350750514436, 58.25111920492989, 58.98420279366629, 57.90693323952811, 60.56838512420654, 57.53568056651524, 61.397409439086914, 58.80524499075753, 61.77660042898995, 62.61569963182722, 66.80767985752651, 60.343270438058035, 54.56206348964146, 19.874295473098755, 1.302849443895476, 0.4105275555380753, 29.481488023485454, 66.97244943891252, 44.371581826891216, 26.731802701950073, 47.715030670166016, 32.45926359721592, 48.61238704408918, 31.578482151031494, 35.43599346705845, 47.219957624162944, 20.700644731521606, 0.09911714534142188, 0.02118885051459074, 0.06564497215939419, 0.04778490248801453, 0.04217165369274361, 0.033907731595848284, 0.03525331064260431, 0.026629084754469137, 0.04775532175387655, 0.01437358371913433, 0.02852842810430697, 0.018760960615639175, 0.08361206376659018, 0.056608629545995166, 0.16799218846218927, 0.829572028347424, 9.909706694739205, 49.657284940992085, 43.462524686540874, 52.40384183611189, 59.42449624197823, 45.21099369866507, 32.855363028390066, 65.44042723519462, 65.17261586870465, 71.70927265712193, 15.315462521144322, 0.04856613038906029, 12.730921983718872, 41.78093555995396, 62.286535671779085, 69.9486894607544, 66.47884941101074, 67.08086912972587, 65.60427965436662, 66.3329163960048, 67.09821878160749, 66.28198610033307, 64.75489016941616, 64.80775901249477, 63.73010035923549, 62.71090384892055, 62.125796045575825, 60.458068575177876, 49.543192046029226, 49.33933537346976, 46.407581193106516, 46.359180041721885, 47.844444343021934, 46.82835715157645, 46.10614749363491, 47.06999465397426, 53.42683206285749, 55.620187282562256, 57.12785605021885, 51.08685943058559, 53.4315116746085, 46.73473364966256, 44.412742955344065, 47.30358614240374, 53.971067087990896, 52.72651617867606, 56.90921013695853, 52.898880141122, 52.707512855529785, 53.45659119742257, 51.43842090879168, 51.878161975315635, 49.23586974825178, 45.3522366796221, 42.87879957471575, 42.76094423021589, 41.16621453421456, 41.35555641991751, 41.64038045065743, 45.258769512176514, 51.33296809877668, 48.754564557756694, 36.49802909578596, 33.11120612280709, 45.757768290383474, 40.93819202695574, 41.834294251033235, 41.09704521724156, 41.358432974134175, 38.09300545283726, 39.93334354673113, 39.949373040880474, 39.680130345480784, 38.954137393406455, 39.11382784162249, 40.05105645315987, 40.782632282802034, 41.248008728027344, 41.529754706791465, 38.64261490958077, 40.592289856501985, 41.734170709337505, 42.501686096191406, 41.03562314169747, 37.68387467520577, 37.75711563655308, 37.88794674192156, 38.26121439252581, 37.292652879442485, 38.37999037333897, 40.269254207611084, 37.7009950365339, 39.66972541809082, 42.4442766053336, 41.87000799179077, 33.99641704559326, 36.06077895845686, 47.47766283580235, 50.13099922452654, 50.37671184539795, 45.352865491594585, 42.05771010262625, 41.08273540224348, 42.93826573235648, 44.51743493761335, 43.65118217468262, 47.12022318158831, 50.47101627077375, 51.62174218041556, 54.327777181352886, 53.46884781973702, 50.90189838409424, 59.16265337807791, 56.35441732406616, 53.18259246008736, 53.74078989028931, 46.27212953567505, 45.54887417384556, 46.79413727351597, 53.98146506718227, 57.276502336774556, 57.92261184964861, 57.84037297112601, 57.57417706080845, 53.130421910967144, 47.462592193058555, 47.129526819501606, 47.69223015648978, 47.43499742235456, 47.79748494284493, 51.09447465624128, 60.8583334514073, 61.435416085379465, 64.35262421199253, 61.45469733646938, 62.58361979893276, 60.70002569471087, 62.75607408796038, 60.76797907693045, 64.34310517992292, 63.077692304338726, 67.18638447352818, 67.06151839665004, 70.12507643018449, 64.83890778677804, 62.42740345001221, 24.43334903035845, 1.4200860730239322, 0.3524705794240747, 31.39548397064209, 75.09860392979213, 50.67500843320574, 30.365583760397776, 45.91789994921003, 38.64642947060721, 57.724536078316824, 26.508027281079972, 42.57669537408011, 57.58023936407906, 24.84039534841265, 0.0554753267871482, 0.01721342240593263, 0.05527008690738252, 0.06593362774167742, 0.10122409835457802, 0.055883557203092744, 0.005107093053603811, 0.19870812525706633, 0.29880122787186075, 0.23250558812703404, 0.14961651020816394, 0.07439265240515981, 0.19529060221144132, 0.10524918165590082, 0.3608548023871013, 1.6426642324243272, 30.00793218612671, 61.858762877328054, 48.03265367235456, 56.47922434125628, 64.85614626748222, 58.23038578033447, 38.00408240727016, 69.35377080099923, 70.11022812979562, 75.03786972590855, 16.469789334705897, 0.13555121208940232, 13.579527190753392, 43.0280190876552, 64.45822988237653, 69.76096303122384, 67.53260626111711, 67.86044311523438, 65.73573957170758, 67.8012444632394, 66.931045123509, 66.88960606711251, 65.38446644374302, 68.16997841426304, 64.74802534920829, 62.847206660679404, 64.31461756569999, 62.01001821245466, 50.37528051648821, 50.54906191144671, 46.578037875039236, 48.0754337310791, 48.30236884525844, 48.201331615448, 48.73278890337263, 49.82215179715838, 55.996473925454275, 58.29837390354702, 58.54078960418701, 54.24541670935494, 54.83187246322632, 49.5877925327846, 46.900430815560476, 48.68418972832816, 55.963355336870464, 55.29907281058175, 59.280411447797505, 56.605810097285676, 52.62478412900652, 54.63769115720476, 54.328583172389436, 54.68824277605329, 53.00242567062378, 49.21032122203282, 44.956366539001465, 47.00041886738369, 43.605414390563965, 45.90092550005232, 45.0658666746957, 48.35736036300659, 55.395020484924316, 51.777301924569265, 42.383844648088726, 38.63208491461617, 49.270277227674214, 42.92736053466797, 44.02207701546805, 44.023393699101035, 43.72803619929722, 39.13205296652657, 43.31492757797241, 42.56352506365095, 41.801443168095176, 43.62838166100638, 43.324644633701865, 42.97615425927298, 44.039061886923655, 44.917227336338584, 45.54517773219517, 40.30161544254848, 41.747136047908235, 43.90036889484951, 45.8848751613072, 43.281631810324534, 40.25012929098946, 41.37231200081961, 40.24177755628313, 39.51486049379621, 39.58415835244315, 42.13819456100464, 43.09309591565813, 39.83785792759487, 41.92197356905256, 44.14395884105137, 49.68040854590279, 39.15926906040737, 40.61911685126168, 51.24643523352486, 53.812398024967735, 53.75186531884329, 47.81309754507882, 44.86974334716797, 44.28423602240426, 46.125289780753, 47.37330436706543, 45.16843250819615, 49.953736782073975, 52.85111822400774, 54.761365618024556, 56.04784195763724, 53.740574496132986, 51.84247602735247, 59.620623043605256, 56.99507597514561, 55.203406538282124, 56.0535568509783, 48.56369754246303, 47.280875955309185, 48.65527132579258, 55.787041323525564, 58.39810834612165, 59.03912135532924, 59.14111396244594, 59.96616390773228, 55.18460818699428, 48.69012696402413, 47.30512169429234, 49.89643498829433, 48.52693114961897, 48.9541654586792, 50.88627883366176, 62.16844408852713, 63.530402183532715, 65.61608464377267, 62.853209904261995, 62.730087825230186, 61.552937916346956, 64.36285890851701, 62.582021713256836, 66.73337582179478, 65.09373297010148, 67.71486445835659, 69.86633941105434, 70.82690702165876, 63.99422918047224, 62.420163427080425, 24.477423191070557, 1.8589759852205003, 0.645446448453835, 35.82619735172817, 79.84701674325126, 56.58989872251238, 37.35006237030029, 61.39168412344796, 49.084041186741416, 66.79340825762067, 44.92830623899187, 56.93892758233206, 75.09385136195591, 29.64069904599871, 0.13050296583345958, 0.13565133671675408, 0.12133194080420903, 0.11505547831101076, 0.09395533267940794, 0.13485233459089482, 0.11215154520635094], [0.037162837106734514, 0.062294196603553634, 0.13882086878376348, 0.03322643833234906, 0.017105174018070102, 0.07263611523168427, 0.04268609519515719, 0.03446347552484699, 0.5176197875823293, 1.960057944059372, 40.498975549425396, 33.96682119369507, 18.89103157179696, 42.87859112875802, 47.73760536738804, 21.432010378156388, 50.37864691870553, 63.35070787157331, 62.58878231048584, 17.70807296889169, 0.16406550630927086, 14.20304376738412, 43.861184528895784, 62.101922035217285, 59.983541352408274, 60.46645505087716, 60.91248076302664, 60.26503372192383, 62.29387991768973, 60.964036396571565, 61.301572935921804, 60.9392591203962, 60.60001332419259, 59.41856248038155, 61.25603444235665, 58.180456025259836, 59.67483983721052, 50.400495529174805, 46.231590270996094, 45.4985032081604, 43.61471108027867, 45.038508142743794, 43.71601581573486, 43.353997298649375, 42.36316333498274, 50.26341451917376, 50.21278994424002, 51.36528764452253, 48.239890643528526, 48.98537676674979, 42.76646457399641, 42.93296773093087, 42.647334235055105, 52.206026622227256, 48.60180493763515, 55.80271298544747, 47.88204799379621, 52.33428342001778, 52.3345057623727, 50.2381717136928, 48.818234375544954, 45.21736172267369, 44.19750165939331, 41.37088067190987, 38.39136110033308, 40.87054436547415, 38.018336636679514, 38.23409557342529, 43.85699476514544, 48.625157833099365, 45.637536661965505, 33.662431035723, 29.202149595533097, 36.18297692707607, 35.56000491550991, 41.801033224378315, 37.857562269483296, 35.97550024305071, 36.56326225825718, 34.694964613233296, 37.86714383534023, 35.961843558720176, 34.50000163487026, 36.17570563725063, 35.96788501739502, 38.047602449144634, 35.91226121357509, 37.25269378934588, 34.655689920697895, 40.279843262263704, 39.81967101778303, 39.044932978493826, 39.10320404597691, 39.52799258913313, 36.626671518598286, 37.194759709494456, 35.930243151528494, 36.39878797531128, 34.799844196864534, 36.55194364275251, 37.191570486341206, 40.58365324565342, 39.125591141836985, 33.323987756456646, 23.851659740720475, 35.84026745387486, 48.724482331957134, 47.09762069157192, 47.06601333618164, 40.93033014025007, 38.46731185913086, 39.702479226248606, 40.3842260496957, 41.89533070155552, 41.57420580727713, 43.9816107068743, 46.22109154292515, 49.23626232147217, 48.65759897232056, 54.70956332342965, 52.70287840706961, 54.413340772901265, 51.770252977098735, 52.0694146156311, 50.11911085673741, 42.69826453072684, 40.54497609819685, 44.52988958358765, 50.236983571733745, 53.14971358435494, 53.050750391823904, 52.471951552799766, 53.070448534829275, 49.547975880759104, 42.56296573366438, 43.31292649677822, 42.440173694065635, 44.84026214054653, 45.79688317435128, 50.18194689069475, 58.74231515611921, 57.63262530735561, 58.16614621026175, 58.9905812399728, 60.55298096793038, 59.44029644557408, 57.514196736471995, 56.13206454685756, 57.756188596997944, 58.145287718091694, 62.73720972878592, 61.945809909275596, 62.72940690176827, 61.94838074275425, 63.14673655373709, 36.080730710710796, 2.1751435569354465, 0.14350362893726143, 26.65177161352975, 66.75754165649414, 42.841022218976704, 40.24720062528338, 48.47088697978428, 30.025712626320974, 35.01783350535801, 27.39519238471985, 36.554493631635395, 22.21697269167219, 2.3562029727867673, 0.3315249904990196, 0.18238692890320504, 0.08871388036225523, 0.05328370617436511, 0.06074621395340987, 0.09045195459787335, 0.08184059203735419, 0.02167689021942871, 0.037364358614598, 0.04275062387543065, 0.046963518884565146, 0.013537033161680614, 0.05057246005162597, 0.014343662021149482, 0.04576342792383262, 0.2906543021755559, 12.302743588175092, 55.90163448878697, 32.817425864083425, 25.718328033174785, 57.848516259874614, 50.05915832519531, 26.550545045307704, 56.241981574467246, 71.25333186558315, 68.62767710004533, 19.44801480429513, 0.24764427436249598, 17.40068292617798, 49.48514679500035, 69.28961113521031, 64.55866609300885, 67.5881154196603, 64.71779373713902, 63.570979663303916, 66.49173831939697, 65.8729942866734, 65.4707978112357, 65.72583838871547, 64.85507624489921, 64.11617006574357, 64.5303452355521, 60.34607751028878, 62.85467597416469, 54.188455377306255, 48.84542267663138, 48.44938577924456, 46.360656533922466, 47.25630712509155, 47.074333803994314, 48.622653007507324, 45.52177619934082, 50.917820181165425, 53.25494057791573, 53.47410065787179, 52.2293586730957, 51.30292756216866, 45.21386330468314, 45.58059270041329, 46.06281157902309, 54.411839962005615, 52.95056431634085, 56.35336814607893, 51.04894658497402, 55.24966417040144, 52.43271854945591, 52.91850880214146, 50.30906070981707, 47.336770738874165, 46.05026313236782, 43.78412553242275, 41.96735225405012, 40.61001123700823, 41.00529425484793, 40.610737323760986, 44.17493043627058, 51.892569065093994, 48.49963515145438, 38.472248554229736, 32.46062197004046, 37.099420002528596, 37.766096183231895, 44.57892302104405, 39.251826013837544, 40.26823282241821, 39.40784086499895, 37.49301808220999, 39.4825895854405, 37.97149188177926, 37.961371830531526, 38.2700594493321, 39.875826358795166, 38.19975757598877, 38.582096099853516, 39.260837827410015, 36.96625082833426, 43.21677385057722, 41.228567668369834, 39.00677694593157, 41.604180335998535, 41.708917481558665, 38.66662440981184, 39.892359597342356, 38.13767194747925, 37.42587763922555, 37.70021683829171, 37.57684462411063, 38.72193554469517, 40.94231578281948, 41.14047145843506, 36.51393699645996, 29.723281860351562, 40.62166684014456, 51.973991530282156, 51.39602647508894, 48.686083112444194, 44.559711251940044, 42.425665855407715, 41.06658778871809, 41.5172792162214, 42.9946677344186, 44.49109779085432, 46.011801379067556, 47.68201977866036, 52.09134660448347, 50.96311201368059, 53.78817660467965, 56.93833698545183, 54.25435904094151, 52.543333871024, 54.390727860586985, 51.23702737263271, 45.865677288600374, 43.35843372344971, 46.54605531692505, 52.59408003943307, 55.58489390781948, 55.75626080376761, 55.73164333615984, 55.71376214708601, 52.9288546698434, 44.95346566608974, 46.950172969273154, 45.6367758342198, 47.71002796718052, 49.0686092376709, 53.01356015886579, 62.09118706839425, 59.606643268040244, 63.25264794485909, 63.233915601457866, 63.20428153446743, 63.459905760628835, 60.8789279120309, 59.112251145499094, 61.30125331878662, 62.841189520699636, 65.92605767931256, 64.98873179299491, 66.64949022020612, 66.71765899658203, 68.13007490975517, 44.31273405892508, 2.763205430337361, 0.20116976888052054, 28.671572991779872, 70.56694711957658, 51.54284538541521, 38.295274462018696, 44.006370612553184, 39.98861994062151, 41.08988857269287, 26.854962996074132, 49.02400875091553, 30.40808936527797, 3.2386437356472015, 0.27059091734034674, 0.18002581702811377, 0.012538791950126844, 0.031827848737261126, 0.10002877749502659, 0.008403262655649866, 0.04244766477495432, 0.08546398260763713, 0.19511454951550278, 0.2830381808536393, 0.12460205890238285, 0.13747450602906092, 0.1886958796530962, 0.14947971754840442, 0.14914148141230854, 0.39715778295482906, 34.32616465432303, 67.40901170458112, 47.540283475603374, 29.089590515409196, 56.727834360940115, 64.17940562111991, 33.16080583844866, 63.410392897469656, 76.2833343233381, 73.18336078098842, 21.488273416246685, 0.3580706374985831, 18.00510151045663, 50.178750719342915, 69.74910245622907, 68.3969760622297, 70.06779548100063, 65.4080833707537, 65.49098232814244, 67.31771237509591, 66.37799630846295, 65.96063886369977, 67.26849828447614, 65.40217740195138, 64.45012828281948, 64.5281982421875, 61.38373538425991, 63.54254763466971, 55.17658996582031, 49.54932035718645, 48.60556043897356, 46.879172801971436, 49.36364017214094, 48.49517788205828, 49.858414445604595, 47.36807932172503, 54.87671613693237, 54.18084709984915, 57.05379172733852, 53.68865755626133, 54.63895225524902, 47.54443155016218, 47.743129185267854, 47.4505683353969, 56.99261631284441, 53.776065894535606, 62.74228886195591, 53.651144232068745, 52.98366206032889, 55.79251650401524, 56.96029329299927, 54.36458873748779, 51.080258641924175, 49.05460514341082, 46.51307569231306, 44.268859658922466, 43.0511531148638, 43.66478327342442, 44.894315651484895, 48.452700069972444, 56.212962423052105, 50.727081707545686, 42.34262445994786, 38.575731549944194, 41.022227014814106, 40.05336672919137, 47.34383010864258, 42.136304650987896, 41.681871618543354, 42.001210825783865, 39.601890155247276, 42.5766293661935, 40.497433049338206, 40.48015635354178, 41.54862254006522, 43.44202055249895, 40.40271520614624, 41.66004385266985, 41.72240740912301, 39.95635945456368, 45.97915874208723, 44.492011478969026, 44.32460158211844, 45.62979984283447, 45.83131149836949, 41.14211123330252, 42.13404301234654, 39.76894916806902, 39.007416180201936, 40.388877868652344, 40.201200076511924, 42.54591832842146, 43.17977121898106, 43.8301226070949, 41.045062269483296, 34.09088822773525, 43.40030009405953, 53.339719023023335, 53.491651807512554, 51.86404323577881, 47.3094538961138, 44.638562883649556, 43.4861033984593, 44.49175092152187, 45.232838835035054, 45.736468587602886, 50.25134202412197, 50.2293370791844, 52.32490682601929, 51.886815956660676, 54.961338247571675, 56.08520589556013, 56.923297609601704, 53.386556829724995, 55.98888301849365, 54.55706773485456, 46.97047560555594, 42.971724782671245, 48.33263519832066, 54.75224610737392, 56.313516753060476, 55.96945238113403, 56.239042486463276, 57.17061526434762, 53.999030113220215, 44.72420290538243, 47.79630722318377, 45.93128217969622, 49.50429950441633, 52.022027901240754, 54.72172267096383, 64.62143611907959, 61.56281130654471, 62.75486510140555, 65.95625455038888, 65.56038788386753, 64.73488630567277, 63.869258880615234, 60.61659172603062, 63.002290453229634, 65.13856969560895, 66.40200233459473, 66.58580303192139, 70.18411527361188, 66.39877837044853, 69.40073367527553, 44.51472166606358, 3.6301067641803195, 0.2481096951024873, 33.28663771493094, 77.00447395869664, 57.98305075509207, 53.71203129632132, 61.55454295022147, 44.79886129924229, 47.07498346056257, 45.7274671963283, 66.5931681224278, 53.536113330296104, 4.097245012010847, 0.4508526474237442, 0.36596791659082684, 0.17563330701419286, 0.1297251611415829, 0.17768857601497853, 0.20306285444114888, 0.13225491611020906], [0.05685126009796347, 0.02763699763454497, 0.016455357994085977, 0.015613060245024306, 0.03562231834179588, 0.05487172917595931, 0.05469758655609829, 0.04204412982133882, 0.058201972262135575, 3.491678672177451, 42.055524894169395, 55.300604888371055, 20.184582914624894, 33.18338748386928, 53.71068334579468, 21.66211908204215, 36.59637042454311, 58.11314882550921, 64.07476575034005, 14.659696749278478, 0.11373755974428994, 19.19016020638602, 46.84046786172049, 62.623703956604004, 63.393550464085166, 57.677785124097554, 58.251560415540425, 58.40891974312918, 58.517381123134065, 61.27098001752581, 61.05557196480887, 59.389581544058665, 59.66350037711007, 57.68577902657645, 60.44620105198452, 60.00314916883196, 59.049335207257954, 54.2534418787275, 45.65275321687971, 45.50250537054879, 42.71003130504063, 44.11059011731829, 43.19030816214425, 42.226745877947124, 40.50761216027396, 43.91070434025356, 49.953479698726106, 48.4639561516898, 49.14221497944423, 46.694864886147634, 44.09216349465506, 42.63766929081508, 44.426753997802734, 47.02301788330078, 52.15137904030936, 49.68614080974034, 51.90279681341988, 52.38690560204642, 52.40512030465262, 49.89370782034737, 47.109835624694824, 43.54431888035366, 42.15151078360421, 44.839049679892405, 40.60013089861189, 40.29980891091483, 39.02608946391514, 40.56182547977993, 42.99218027932303, 48.0655950818743, 49.10557018007551, 43.91326822553362, 25.421245643070765, 34.523441382816856, 37.57614285605294, 40.56470898219517, 41.36214331218174, 36.784899371010916, 35.942909717559814, 37.027912616729736, 35.900497913360596, 35.79333584649222, 36.72459248134068, 37.206463950020925, 37.461796351841514, 37.50160952976772, 40.411098207746235, 39.72687087740217, 36.206666810171946, 38.38461092540196, 38.77989394324166, 38.29042114530291, 35.96470969063895, 35.40113435472761, 35.850707122257774, 37.20093665804182, 38.37832627977644, 35.32242168698992, 34.40042005266462, 37.20457404000418, 37.914919648851665, 41.89016124180385, 38.374199049813406, 32.83371591567993, 23.265832798821585, 40.68092107772827, 51.38233504976545, 46.11962005070278, 44.55886704581124, 39.527860573359895, 38.53496299471174, 38.062565394810264, 39.1976717540196, 42.73606620516096, 43.879030976976665, 43.029908997671946, 44.521527426583425, 45.64283813749041, 49.62002522604806, 49.897550174168174, 55.83362552097866, 49.143931184496196, 50.127323627471924, 51.75662408556257, 48.14163964135306, 40.93171630586897, 39.08417987823486, 43.83876964024135, 50.531753948756624, 53.072744914463584, 52.8768196105957, 53.18535089492798, 51.6065707887922, 48.034609590257915, 41.00558260508946, 42.29145097732544, 43.021400928497314, 43.94389588492257, 45.25974573407854, 51.53136001314436, 56.34603779656546, 56.99041025979178, 57.73974915913173, 59.88811479296003, 58.04017536980765, 56.39592238834926, 54.57135323115757, 53.07360649108887, 57.08571522576468, 60.545449120657786, 59.49285956791469, 61.304241044180735, 62.22040271759033, 64.1587277821132, 64.15202277047294, 54.26904058456421, 6.62038996389934, 0.374555591493845, 29.04350311415536, 63.411608832223074, 37.516172954014365, 50.169530459812705, 41.18443618501936, 24.381711755480083, 49.739117349897114, 29.48772750582014, 39.05581733158657, 5.948112666606903, 0.3321354548845972, 0.027146642428955862, 0.09491839100207601, 0.032257802451827695, 0.07421250135770865, 0.05465860811195203, 0.04171303187363914, 0.025622927583754063, 0.014189641357266476, 0.09011994741324868, 0.04984730289184621, 0.033257518628878255, 0.043513595791799684, 0.023459664645737836, 0.013646910881756671, 0.05328842538541981, 0.07798078629587378, 13.563594102859497, 57.8733560698373, 53.88515608651297, 18.726781368255615, 46.92603145326887, 59.4325908933367, 23.00551332746233, 46.50246579306466, 62.24587481362479, 70.77919374193463, 14.279515641076223, 0.3680408410727978, 22.882469415664673, 51.815787996564595, 67.96249825613839, 68.50644493103027, 62.78422818865095, 62.52088451385498, 61.39268466404506, 63.84425231388637, 65.83435535430908, 63.90395123617989, 62.61965315682547, 62.87022604261126, 62.94873373849051, 64.37069647652763, 62.864521571568076, 61.953974042619976, 56.96517787660871, 48.28584950310843, 46.89474718911307, 45.82003109795706, 45.866055965423584, 46.26077617917742, 45.121268136160715, 42.96978276116507, 45.86816821779524, 51.41761800221035, 52.02509205681937, 49.72631876809256, 49.57797472817557, 45.66916833605085, 44.5905647277832, 47.84681715284075, 49.13894932610648, 54.45442199707031, 53.32261950629098, 54.86763136727469, 53.361696175166536, 55.46926893506731, 50.79093565259661, 48.947498662131174, 46.36838640485491, 44.901055404118125, 46.86431755338396, 43.561817918504985, 42.82784843444824, 42.59016098294939, 43.32687847954886, 45.61603198732649, 50.48812273570469, 50.8854797908238, 49.13645144871303, 29.804634843553814, 36.44198145185198, 40.842977387564524, 44.28922830309187, 43.21695102964129, 40.00978415352957, 36.745023659297395, 37.61378124782017, 37.676203863961355, 38.34741027014596, 37.01006269454956, 38.96176651545933, 38.47677183151245, 40.86206061499459, 43.5281434740339, 42.1046382359096, 38.654433795383994, 38.30845519474575, 39.616373675210134, 39.89789036342076, 39.30715104511806, 38.41321318490164, 37.195152282714844, 37.35185153143746, 39.785141944885254, 38.68110792977469, 37.042232854025706, 39.553871154785156, 40.54371500015259, 43.66259806496756, 40.2276588167463, 35.6893630027771, 28.308032819202968, 43.07529810496739, 53.918594292231965, 49.50256940296718, 47.14037643160139, 42.99009929384504, 39.260691915239605, 40.4711480140686, 40.44687100819179, 45.27495881489345, 47.94418225969587, 45.70751196997506, 48.32323775972639, 46.3208954674857, 51.37631096158709, 53.091796875, 54.53204379762922, 53.581099442073274, 52.15899774006435, 54.88804170063564, 49.3619760785784, 45.303891113826204, 42.87670816693987, 47.043525491442, 54.18990755081177, 55.59138699940273, 56.35159635543823, 57.091200828552246, 54.92816754749843, 48.692062037331716, 46.27015972137451, 46.057617800576345, 46.66025243486677, 47.93333612169538, 47.770786489759175, 53.65598017828805, 59.88928209032331, 60.67895180838448, 60.93816130501883, 64.13400609152657, 61.559358051845, 59.203731128147666, 58.929992948259624, 56.82984781265259, 58.131172452654155, 63.58120046343122, 64.62966278621128, 64.08775888170514, 67.76616995675224, 68.56524753570557, 66.0385490145002, 60.932463782174246, 8.8510148865836, 0.31219062368784634, 34.58048609324864, 66.48099640437535, 46.88616616385323, 55.7412804876055, 42.877517632075715, 37.44802502223423, 49.05691889354161, 32.92435169219971, 54.47209474018642, 8.772884130477905, 0.2063764123512166, 0.03279299694778664, 0.048872868929590495, 0.0901794277929834, 0.045726200100034475, 0.06796212175062724, 0.0581439710887415, 0.016005496062072258, 0.12122538366488048, 0.18799876634563717, 0.1362391108913081, 0.12745084746607713, 0.17928453109094075, 0.1559272115784032, 0.1689612450344222, 0.171498301039849, 0.15092863408582552, 36.16813904898507, 67.44188363211495, 73.34664344787598, 31.742383207593644, 43.95630536760603, 69.84623827253068, 30.277803693498882, 50.7218462399074, 69.10633850097656, 73.34087644304547, 17.262952259608678, 0.6845149206263679, 24.083675725119456, 53.30036095210484, 68.93250152042934, 70.16171428135463, 65.1770418712071, 63.0166871207101, 62.398221015930176, 63.44033963339669, 66.6973911012922, 63.97148772648403, 64.22650745936802, 62.85671179635184, 61.631091254098074, 64.15129320962089, 64.55252388545445, 64.18289361681256, 58.67978136880057, 49.247886657714844, 48.785539627075195, 47.36890615735735, 47.260423932756694, 47.081949029650005, 47.088355268750874, 46.222456863948274, 49.14596700668335, 54.63206659044538, 53.069566113608225, 53.48055553436279, 52.93389906202044, 48.57665940693447, 46.38856744766235, 49.555830819266184, 51.88287285396031, 55.53840351104736, 56.381286008017405, 54.06124775750296, 55.99667542321341, 58.14930377687727, 52.64608383178711, 51.15048061098371, 47.26832403455462, 47.79895796094622, 49.46846417018345, 46.00451966694423, 44.66817263194493, 45.54893670763288, 45.837585721697124, 49.447004658835276, 53.57321671077183, 52.989807741982595, 49.07333401271275, 36.72720847811018, 38.593661376408164, 44.14930200576782, 45.8280736378261, 45.32785545076643, 40.966273171561106, 41.36349473680769, 41.26997198377337, 39.80900205884661, 40.12092406409127, 40.90674448013306, 42.44690302440098, 41.969200474875315, 43.05068063735962, 47.60735443660191, 45.33486270904541, 40.255517618996755, 41.079129287174766, 43.774988651275635, 42.28639268875122, 41.05762113843645, 39.48976707458496, 40.275917530059814, 41.35400349753243, 42.866205964769634, 41.452091217041016, 39.229685579027446, 42.76642288480486, 42.94011395318167, 47.158441747937886, 44.01356894629342, 40.36105033329555, 33.66976138523647, 43.5790251323155, 56.50255291802542, 51.328861713409424, 50.74934720993042, 45.49995885576521, 42.12474979673113, 40.71916743687221, 41.24070617130825, 46.85964141573225, 48.28550904137747, 46.55052995681763, 50.04882982798985, 48.906844752175466, 52.25386496952602, 55.30927276611328, 58.40040125165667, 53.426866803850444, 56.11948135920933, 54.90503352028983, 53.058358669281006, 45.42715910502842, 42.963800362178254, 48.250886167798726, 55.47260059629168, 58.422816140311106, 56.37772158214024, 57.60615961892264, 57.00485903876168, 52.808956554957796, 48.467270442417686, 47.69364064080374, 48.044170311519075, 48.497380461011616, 50.31099578312465, 56.13857848303658, 60.87928921835763, 62.30214827401297, 62.174614088875906, 65.49430356706891, 62.29629789079939, 60.126180921282085, 60.47018623352051, 57.351233686719624, 61.15682111467634, 66.04678262983049, 66.97276905604771, 68.1743974685669, 67.9973087310791, 67.97258009229387, 68.10048948015485, 59.58636147635323, 8.709724136761256, 0.39909988588520456, 37.16770689828055, 75.5426424571446, 52.54007863998413, 69.21256950923375, 55.01392221450806, 35.94975021907261, 65.5936141695295, 47.84364182608468, 74.43059716905866, 15.968515021460396, 0.4731723240443638, 0.09377907642296382, 0.16710185552281992, 0.19234958716801234, 0.08823331472064767, 0.16312113484101637, 0.11074657059673752, 0.100886438973248], [0.04026077015857611, 0.014335981004738381, 0.037122840860060284, 0.013160522561520338, 0.0725226438205157, 0.1457102248179061, 0.05257385676460607, 0.09658010290669543, 0.11199998083923544, 3.0835367100579396, 48.93945264816284, 45.80195535932268, 42.33869177954537, 19.40060898235866, 51.92224482127598, 25.906050988606044, 27.30914068222046, 57.201579911368235, 63.592435700552805, 17.447008303233556, 0.4991789971079145, 28.12935468128749, 45.66869933264596, 59.74737903050014, 59.88231304713658, 60.10760838644845, 57.23682117462158, 59.3846344266619, 59.30236775534493, 60.52443776811872, 58.5931373323713, 60.54776981898716, 58.354126249040874, 58.35293115888323, 55.772919109889436, 57.364490849631174, 58.028460706983296, 56.973470551627024, 46.634307861328125, 45.244362422398154, 43.265074253082275, 43.93768766948155, 41.93300036021641, 43.99136945179531, 41.38209159033639, 43.28547069004604, 43.87948955808367, 46.57462978363037, 44.687054361615864, 45.89614861352103, 41.74534341267177, 43.15877723693848, 43.60025535311018, 51.05723231179373, 50.953217778887065, 53.76965618133545, 52.54921204703194, 50.574881417410715, 54.37715802873884, 48.42463629586356, 43.643976892743794, 43.537363733564106, 44.67350884846279, 43.24271495001656, 43.63044875008719, 42.200155121939524, 43.620161942073274, 41.94085529872349, 44.97095080784389, 47.22351162774222, 49.44103963034493, 50.775350843157085, 23.01143840381077, 33.96800238745553, 38.65760217394148, 37.672997270311626, 39.35505192620413, 38.35469198226929, 37.50421510423933, 35.38263130187988, 37.838298388889854, 34.57019581113543, 35.343492099217, 34.89429800851004, 34.14881535938808, 35.31255871909005, 35.31028665815081, 36.21157223837716, 35.98363658360073, 37.1638298034668, 36.55364942550659, 37.41587918145316, 35.75811195373535, 34.63135385513306, 35.61758811133248, 36.131153787885395, 35.89775684901646, 36.860575675964355, 35.48832035064697, 39.089856556483674, 36.89854758126395, 39.2770653452192, 38.21371650695801, 31.431788308279856, 24.64781560216631, 46.25607572283064, 46.56290122440883, 48.438671657017295, 42.70987149647304, 39.444065298352925, 39.011230741228374, 39.32488284792219, 39.70053025654384, 42.36592524392264, 44.33561795098441, 46.47829648426601, 43.95165702274868, 44.98122719355992, 44.22561754499163, 49.13369648797171, 46.60469463893345, 53.73306001935686, 51.96195725032261, 49.42458977018084, 45.79346466064453, 42.86110946110317, 40.050973074776785, 44.84486532211304, 49.98432970046997, 52.30798101425171, 52.14665426526751, 52.08604165485927, 49.639403751918245, 43.72693490982056, 40.89154876981463, 42.41580983570644, 42.868349484034944, 43.96520948410034, 44.37087658473423, 50.504030636378694, 57.10317257472447, 57.5191855430603, 54.740156241825645, 57.37050104141235, 56.35708890642439, 55.930754389081685, 52.04273353304182, 54.16917412621634, 54.1053375516619, 58.137842723301475, 57.262644154684885, 61.751274245125906, 61.50075694492885, 66.09180695669991, 66.12221922193254, 63.90582030160086, 13.265445164271764, 0.22460431924888066, 36.16590520313808, 56.26259340558733, 29.468248231070383, 32.37013905388968, 28.56477223123823, 25.337747403553553, 38.22777271270752, 35.974861008780344, 29.107270206723893, 0.8122719366635595, 0.07880315038242511, 0.01691178135973002, 0.10870815640581505, 0.041363701689988375, 0.03810658432277186, 0.013612001103215983, 0.05668058818472283, 0.02519848526987646, 0.04848789869408522, 0.0024753358240039752, 0.08602631171899182, 0.018450367996203046, 0.046783327125012875, 0.020618908240326812, 0.0407345945547734, 0.049614663768027506, 0.052376165586922846, 4.4586551274572095, 61.819978032793315, 52.81856591360909, 28.591698237827845, 26.124981778008596, 65.44611086164201, 24.331260885511124, 36.70769098826817, 61.86574581691197, 68.78090572357178, 19.14865861620222, 0.7282937286155564, 30.83953775678362, 52.035430976322715, 64.29695524488176, 65.79969079153878, 65.73648997715541, 61.865488733564106, 62.577630451747346, 63.31303473881313, 64.17335374014718, 62.45379965645926, 64.12770407540458, 61.97128895350865, 63.450567381722585, 59.602168628147666, 60.88821765354702, 61.17697089059012, 60.29297242845808, 49.30922882897513, 45.876766613551546, 45.12832055773054, 46.19516086578369, 45.47940261023385, 45.99667167663574, 44.27136448451451, 46.31511456625802, 47.56830208642142, 49.25123221533639, 47.798586232321604, 47.672351360321045, 44.57057476043701, 43.74509055273873, 46.618855067661826, 53.29519149235317, 53.83784580230713, 57.344716276441304, 53.76243005480085, 54.2187807900565, 56.04684141704014, 51.52811173030308, 47.712800298418315, 46.52178178514753, 48.16103206362043, 47.462147508348735, 46.270017283303396, 45.02308314187186, 45.096449170793804, 45.597806862422395, 47.17769520623343, 50.666771343776155, 51.558430194854736, 51.7048739024571, 26.154275383268082, 35.97777577808925, 40.56045321055821, 42.518834250313894, 43.635573046548025, 41.32591540472848, 39.18931654521397, 36.8839876311166, 38.39140626362392, 36.53276661464146, 38.146287713732036, 36.916011878422324, 36.47476652690342, 37.97113752365112, 39.57325315475464, 39.20724984577724, 38.07777847562517, 38.88184486116682, 38.75255625588553, 40.25581291743687, 38.39388677052089, 37.43856157575335, 37.98850802012852, 37.41237728936331, 36.228188855307444, 39.2718368257795, 38.142924785614014, 41.48709971564156, 40.10995633261544, 40.10713883808681, 41.08053977148873, 35.2013840675354, 29.870479447501047, 51.07005173819405, 49.1045001574925, 49.8372745513916, 46.2295891898019, 44.01792894090925, 41.178172383989605, 42.19216469355992, 40.73076745441982, 45.71287945338658, 47.19715016228812, 48.740973881312776, 47.72714485440935, 47.21578523090908, 46.89327417101179, 51.062235014779226, 47.51903241021292, 55.08689914430891, 54.12380238941738, 51.17283296585083, 48.863880566188264, 43.55040202822004, 41.77777412959507, 47.16513633728027, 52.65803473336356, 55.07976334435599, 54.76013926097325, 55.61704322269985, 50.93770245143345, 46.526113986968994, 42.328853130340576, 45.27055365698678, 46.8742013658796, 47.209111486162456, 45.58987896783011, 52.190480027879985, 58.2624135017395, 60.0595338003976, 59.36914689200265, 60.534721102033345, 57.49155603136335, 57.79970863887242, 54.91445875167847, 56.94876970563616, 58.164152077266145, 59.955421992710654, 61.06787027631487, 66.17786039624895, 65.43410437447685, 69.70425878252301, 67.31151458195278, 69.38703182765416, 16.873646429606847, 0.20171908369021757, 38.93973725182669, 63.2534122467041, 34.9721108845302, 36.44163056782314, 34.036612374441965, 37.77920743397304, 33.55728742054531, 47.14036948340279, 35.874779156276155, 0.6592258661985397, 0.06639373555247273, 0.044404281569378715, 0.02552312017152352, 0.07898351177573204, 0.045339489422206364, 0.058891811674194675, 0.049223189774368487, 0.06173882247614009, 0.07011543227625744, 0.05430900312161871, 0.2889293304511479, 0.13258486054837704, 0.10226959868201188, 0.23654010306511605, 0.12564618858907903, 0.2034948912582227, 0.23536319764597075, 12.901486362729754, 80.62277616773332, 55.778408186776296, 63.163099561418804, 27.131200790405273, 67.61354582650321, 35.31307635988508, 38.43644448689052, 66.08904157366071, 72.22887284415108, 21.09360705103193, 1.2278734956468855, 33.554344858442036, 56.54405798230852, 67.39389242444719, 66.63091073717389, 67.23117256164551, 63.57230676923479, 63.61875547681536, 65.58934102739606, 65.70157527923584, 63.52628190176827, 64.68979249681745, 63.08466829572405, 63.388276781354634, 58.52573980603899, 61.02283900124686, 61.368039403642925, 62.23728684016636, 49.958753381456646, 48.06873566763741, 48.64262907845633, 48.846249512263704, 45.746946471078054, 49.28884628840855, 46.392093658447266, 48.112610067640034, 50.70432983125959, 51.106352601732524, 49.80721664428711, 49.97310835974557, 46.82421255111694, 46.750502586364746, 49.88443544932774, 55.275712966918945, 56.35558462142944, 59.046847752162385, 54.703334263392854, 56.44692216600691, 59.95755508967808, 52.891021728515625, 48.27322810036795, 50.53942476000105, 50.10776792253767, 49.71166154316494, 49.42757402147566, 46.053733757564, 48.05720165797642, 48.38379825864519, 51.930506229400635, 54.16011020115444, 56.835642610277446, 53.89954233169556, 29.13484239578247, 39.79173231124878, 43.52351597377232, 44.81485257829939, 46.077847480773926, 44.05948264258248, 42.68880803244454, 41.64262471880232, 42.51696171079363, 40.66569757461548, 41.289194175175254, 41.061678886413574, 37.815918241228374, 40.53320237568447, 42.032175472804475, 42.116776738848, 40.99692167554583, 41.69506972176688, 41.60455901282174, 43.4509767804827, 42.07870755876814, 40.407891614096506, 40.88101877485003, 40.29017175946917, 38.83045598438808, 42.13821540560041, 41.493328775678364, 44.60788311277117, 42.03185932976859, 43.92835971287319, 43.26930570602417, 39.61416414805821, 33.03024571282523, 49.1056535584586, 52.17008706501552, 52.709225586482454, 48.065463066101074, 44.33176864896502, 43.287899085453574, 43.8996775490897, 43.44126319885254, 47.725268840789795, 49.5597357068743, 50.75137955801827, 49.28295421600342, 47.37808125359671, 48.01272971289498, 53.131658690316335, 49.1038088117327, 55.84457588195801, 56.77821922302246, 54.11280339104788, 50.638603346688406, 46.81429399762835, 43.052813734327046, 48.99762296676636, 54.056286743709016, 56.551287582942415, 56.155156884874614, 56.99323122841971, 53.386178152901785, 49.72613116673061, 44.7326797076634, 46.452410970415386, 46.49077544893537, 48.89005095618111, 48.39419623783657, 54.185033389500205, 61.19373689379011, 62.63360513959612, 60.269445828029085, 62.06705597468785, 59.42940861838204, 59.868993350437705, 57.28875548498971, 59.124556405203684, 59.40201881953648, 62.946809087480815, 64.53268677847726, 66.9275154386248, 66.9572537285941, 73.10986968449184, 69.76511110578264, 70.16784259251186, 17.707977431161062, 0.3688337228127888, 42.714571952819824, 67.0230462210519, 44.04825782775879, 44.47840690612793, 42.53985602515084, 36.33825526918684, 51.15808194024222, 56.04718882696969, 56.04298864092146, 1.4569283532244819, 0.18917616030999593, 0.08172432506190878, 0.1541496262486492, 0.1397786752453872, 0.11148324249578373, 0.13875138679785387, 0.1404925619385072, 0.1468274870089122], [0.06879949503179107, 0.16992788602198872, 0.01911348500289023, 0.05042922130918928, 0.008400054881349206, 0.012177131088849689, 0.0677188533757414, 0.01261842142724033, 0.0453381696715951, 0.21066989696451596, 37.36393097468785, 57.49060412815639, 54.81561367852347, 27.05978373118809, 25.273238590785436, 40.1046062197004, 21.652646950313024, 54.903352056230815, 66.57389381953648, 20.678556408200944, 0.8774286146674837, 35.08204180853707, 46.20372799464634, 57.88186066491263, 57.43491431644985, 62.78197002410889, 56.52252204077584, 63.003756523132324, 57.99976117270333, 62.105111258370535, 59.27504743848528, 60.09538650512695, 57.704129219055176, 56.36335618155343, 55.87507152557373, 56.34892477308001, 56.608877726963584, 57.54068674360003, 47.21357570375715, 43.5719553402492, 43.542050293513704, 44.22842114312308, 42.70601177215576, 40.56693587984358, 40.83833599090576, 41.33157123838152, 42.36137417384556, 46.463903290884836, 43.83254405430385, 41.81163270132882, 41.16144459588187, 42.704677718026296, 44.312900815691265, 51.18657650266375, 50.51768732070923, 54.54705538068499, 52.74694388253348, 55.26088898522513, 49.131341048649375, 49.995464188711985, 42.5451922416687, 45.898479734148296, 47.1356794493539, 46.094978264399934, 44.09638105119978, 46.14643662316458, 43.834242888859336, 42.82693474633353, 43.650879928043906, 47.917893750326975, 46.74758434295654, 46.94119242259434, 25.101890802383423, 30.393209797995432, 40.37985910688128, 38.89926399503435, 39.812695026397705, 37.15186153139387, 36.06153631210327, 34.83940029144287, 34.63824299403599, 35.060196672167095, 34.90474115099226, 35.026720251355854, 35.13257953098842, 35.08223983219692, 37.72039788109915, 39.519508838653564, 38.647628034864155, 37.15480409349714, 36.95205913271223, 36.87646968024117, 34.48273883547102, 35.0056220463344, 36.51160587583269, 36.23550878252302, 33.33680370875767, 33.72755650111607, 34.99226066044399, 35.25504847935268, 38.171224798474995, 38.930753231048584, 38.64703743798392, 28.083550419126237, 27.769491842814855, 51.89658164978027, 46.241359438214985, 46.66308382579258, 42.91951601845877, 40.403243269239155, 38.13748434611729, 40.33627653121948, 40.99390268325806, 44.692748410361155, 42.71254655293056, 46.90562459400722, 46.839734826769146, 43.79431506565639, 45.062809467315674, 48.35492501940046, 47.29034982408796, 48.84144830703735, 47.93333959579468, 48.02280112675258, 43.3150908606393, 40.17041260855538, 40.06686360495431, 44.328697545187815, 48.12952545710972, 50.25986746379307, 49.228911127362935, 51.08914886202131, 46.6596166746957, 41.972605092184885, 41.60957561220442, 43.126482009887695, 44.22021532058716, 43.5021641595023, 43.318950584956575, 49.42799438749041, 56.222540514809744, 55.2419308253697, 57.20661040714809, 59.488093103681294, 54.7304322378976, 54.428303718566895, 49.68273966653006, 50.3829721723284, 53.86670514515468, 57.29446690423148, 58.26092658724104, 61.8876256942749, 59.7395692552839, 64.72438757760185, 62.11938285827637, 67.92615917750767, 19.81581595965794, 0.22156005831701414, 40.0335122517177, 55.86782455444336, 32.508529799325125, 36.75835725239345, 27.03953841754368, 36.792691775730674, 35.49743986129761, 50.245901584625244, 15.321507453918457, 0.1759039203503302, 0.10611540624605757, 0.04805617739579507, 0.027536359016916583, 0.12379144025700432, 0.08177041794572558, 0.03719225159979292, 0.014545025769621134, 0.02572448561633272, 0.12746911362877913, 0.037838573168431006, 0.05584498927263277, 0.04000170548845615, 0.042711340090526004, 0.016744873619505336, 0.07060224044003657, 0.04787103911595685, 0.05413173584799681, 0.09006056881376676, 38.72779982430594, 65.66570172991071, 45.942170006888254, 27.942178896495275, 42.393440110342844, 38.91550888334002, 28.743274927139282, 58.432529721941265, 71.56268651144845, 23.255424397332327, 1.282597182052476, 37.80658333642142, 53.3936961037772, 62.518271991184776, 62.09211812700544, 66.45409992762974, 59.11332811628069, 64.94028200422014, 61.654339926583425, 65.82343973432268, 61.550818715776714, 65.23883220127651, 59.45505441938128, 60.479607990809846, 59.22616686139788, 59.34113870348249, 59.28599085126604, 58.91150379180908, 49.173961298806326, 46.326707635607036, 46.642437253679546, 47.11338268007551, 43.54172372817993, 44.017366136823384, 41.81130961009434, 43.70889738627842, 43.556672777448384, 49.22241108758109, 47.45076635905674, 45.067971978868755, 43.64569657189505, 44.682055132729666, 46.601901463099885, 52.35712562288557, 52.686320849827354, 55.688832010541645, 52.10821335656302, 56.571822983878, 51.549029282161165, 50.24458837509155, 47.28285619190761, 47.205029419490266, 51.281474999019075, 48.660718713487896, 48.92971474783761, 50.16801227842058, 46.89246817997524, 45.345903396606445, 47.08547871453421, 50.7110070501055, 50.421923773629324, 49.63438367843628, 29.45452206475394, 33.0351893561227, 41.54772622244698, 40.225574357169016, 43.17442110606602, 39.716128962380544, 38.037287848336355, 36.825758252825054, 35.49743986129761, 35.93319613592965, 37.108268533434185, 35.8958044052124, 37.7568689755031, 37.43477480752127, 41.10294771194458, 42.35198368344988, 39.53492341722761, 39.1659254346575, 39.96989107131958, 38.87123843601772, 37.43315240315029, 36.52586357934134, 37.044435432979036, 37.41041442326137, 34.99918106624058, 35.29265213012695, 38.696300165993826, 38.65286002840315, 41.27898727144514, 39.3517723764692, 41.68698896680559, 31.898728098188126, 34.975543294634136, 60.32516343252999, 47.504868507385254, 49.64415284565517, 45.17628397260393, 43.510821614946636, 40.884892395564485, 42.32248510633196, 42.15623903274536, 47.35000010899135, 47.0891751561846, 49.268116337912424, 49.381497042519705, 48.85918705804007, 47.59128672736031, 49.69866146360125, 48.59533616474697, 52.12028237751552, 48.902787004198345, 50.37157365253994, 45.56874254771641, 42.835286481039866, 43.2647442136492, 46.98814834867205, 50.53439426422119, 52.67574221747262, 52.59509795052664, 54.21063750130789, 49.120751993996755, 45.40430300576346, 43.3419109072004, 45.776344299316406, 46.069613865443635, 46.73974677494594, 46.776877948216026, 53.83985383169991, 56.971594538007466, 57.07598427363804, 60.152868952069966, 60.50737994057791, 56.08504956109183, 56.62290961401803, 53.36768899645124, 54.41957330703735, 57.037255014692036, 60.23698384421212, 61.65790435246059, 65.53322042737688, 62.542007037571494, 69.63982118879045, 64.68134348733085, 72.52344172341483, 24.352742978504725, 0.14040192323071615, 45.283637114933555, 63.26095104217529, 36.24698025839669, 42.72693279811314, 31.354812690189906, 44.627636841365266, 39.59216962541853, 62.889055660792756, 15.516710145132881, 0.47803242611033575, 0.22707572020590305, 0.13736667324389729, 0.07281288038939238, 0.0668684725782701, 0.07622642043445792, 0.07215064378189188, 0.030941834673285484, 0.03368189478559153, 0.25956865879041807, 0.23502042889595032, 0.12508224456437997, 0.1998596534665142, 0.11808751204184123, 0.06597668078861066, 0.16970452586455004, 0.09799442772886582, 0.12402534484863281, 0.4382910914719105, 64.11734431130546, 68.34614998953683, 74.97141715458461, 35.12686116354806, 37.59509059361049, 53.575071879795615, 32.935479232243125, 63.89373738425118, 76.40129389081682, 26.53554388454982, 1.362401802624975, 40.41439165387835, 57.01821000235421, 66.49086284637451, 64.89784240722656, 67.29718739645821, 60.97914872850691, 67.43260083879743, 62.375340597970144, 67.8017030443464, 62.4599210194179, 64.18713201795305, 61.23189640045166, 61.22278731209891, 58.990782737731934, 60.81943048749651, 61.705172947474885, 61.030683517456055, 51.079692363739014, 48.18990182876587, 48.817911284310476, 48.28332035882132, 47.30655302320208, 45.47867999758039, 44.132720129830496, 45.99636942999703, 45.63343027659825, 52.217320919036865, 50.71480424063546, 48.69114140101841, 46.03407382965088, 46.55053343091692, 50.3552280153547, 53.592334679194856, 55.45517451422555, 57.75721345629011, 54.71375308718, 60.16596630641392, 53.42455652781895, 54.48879473549979, 47.53571850912911, 50.682130336761475, 54.674103191920686, 50.45316982269287, 49.88075985227312, 52.09410503932408, 51.00194896970476, 46.882223061152864, 49.14750950677054, 53.91320596422468, 52.295449938092915, 51.73863172531128, 33.044798714774, 36.06272097996303, 44.42965834481375, 44.04470729827881, 43.180743966783794, 41.3880045073373, 40.96940333502633, 40.37671504701887, 38.09172698429653, 39.59454590933663, 41.00680896214077, 40.95953689302717, 40.56397942134312, 41.056346143995015, 42.27066544124058, 45.08741651262556, 41.998014654432026, 42.22174664906093, 43.185194287981304, 42.91797004427229, 40.30349145616804, 40.43191501072475, 41.68439728873116, 40.563239438193186, 37.437769481113975, 38.65633760179792, 39.987678459712434, 40.22047437940325, 43.3534379686628, 44.70260443006243, 42.76461635317121, 35.11329827989851, 35.960325377328054, 55.61472947256905, 49.97022485733032, 52.35750429970877, 49.759465149470735, 45.30979708262852, 43.059390204293386, 43.337457111903596, 45.67631803240095, 48.12672185897827, 47.6959821837289, 50.56273249217442, 50.537079742976594, 49.990249565669465, 50.05952310562134, 53.75408179419381, 49.72238608769008, 54.57685620444161, 50.93324518203735, 52.962237289973665, 49.335850851876394, 44.23682151521955, 46.26078312737601, 48.084647042410715, 51.954071044921875, 53.88425976889474, 53.718347208840505, 55.927169118608745, 52.42929308755057, 47.46531936100551, 45.26257017680577, 46.9450695174081, 48.279252188546316, 47.93971109390259, 48.27283552714756, 57.111968994140625, 59.90126773289272, 59.281446729387554, 62.42716026306152, 62.97956984383719, 58.15428563526699, 59.74713584354946, 55.27494519097464, 57.57627541678292, 59.03918388911656, 61.24668911525181, 64.02182742527553, 70.53655569893974, 65.50378090994698, 72.54439054216657, 68.02691500527519, 74.02729593004499, 23.715442044394358, 0.2966307843370097, 46.92471824373518, 69.71108191353935, 44.79144409724644, 52.192116328648154, 36.23736047744751, 51.246859073638916, 49.39403159277779, 74.45713928767613, 26.200414896011353, 0.6454771725194794, 0.35852612448590143, 0.24164168217352458, 0.1714544269655432, 0.15737691521644592, 0.254159893308367, 0.15130383680973733, 0.21085776974047932, 0.13598760510129587], [0.07398371292012078, 0.07528044083820921, 0.07012270617165736, 0.05079204755436097, 0.04879273394388812, 0.041739345461662324, 0.09141578645046268, 0.1215035015983241, 0.22708862594195775, 0.32104843695248875, 9.456145661217825, 52.665486676352366, 50.68032380512783, 28.829769577298844, 18.05426870073591, 45.985533714294434, 23.69291945866176, 47.105051789964946, 65.855623790196, 26.74683165550232, 1.4494734789643968, 34.90525531768799, 45.64628096989223, 56.09832409449986, 56.3546917779105, 64.16236168997628, 58.45139408111572, 61.6086277280535, 59.280599049159456, 63.17123590196882, 59.366694177900044, 59.25816331590925, 57.62985645021711, 58.103105204445974, 52.55919313430786, 57.29066276550293, 55.633673736027305, 54.284111227308, 44.71417318071638, 44.116579464503694, 44.47071525028774, 42.12159878867013, 41.47601386478969, 41.32199314662388, 40.9876388822283, 38.44050223486764, 39.31846966062273, 42.248844623565674, 40.383534703935894, 39.19694219316755, 40.80503674915859, 41.625000613076345, 44.0226537159511, 51.518641335623606, 51.78968708855765, 51.842121669224326, 50.67674200875418, 54.78586844035557, 48.62334087916783, 48.40346513475691, 45.2117406300136, 47.93999597004482, 47.65559230531965, 48.5662579536438, 46.72447810854231, 47.275466782706125, 44.892265932900564, 46.07396343776158, 43.67253746305193, 48.56159918648856, 45.84861251286098, 48.94221108300345, 29.21191528865269, 30.360619272504533, 37.57861294065203, 38.31643867492676, 42.17723648888724, 37.26853220803397, 38.115020820072715, 34.79638399396624, 34.402883189065115, 33.994937079293386, 33.73579011644636, 33.118262018476216, 36.15477418899536, 34.72249337605068, 36.495784827641074, 38.35161393029349, 38.58453491755894, 39.64441313062395, 37.643463952200754, 34.81788519450596, 37.1464523587908, 35.32220976693289, 35.25425638471331, 34.87110839571272, 35.694271905081614, 35.730287892477854, 36.70891734531948, 37.17831679752895, 39.762435231889995, 35.97560446602957, 41.462767124176025, 28.310141597475322, 30.31190892628261, 47.090061051504954, 48.632960660117014, 46.23117337908064, 42.05584103720528, 41.97669063295637, 41.334697927747456, 41.91883298328945, 41.96542065484183, 46.71999304635184, 45.447440896715435, 48.4583454813276, 48.22275638580322, 48.40401404244559, 47.47517885480608, 45.54367344720023, 43.941286836351665, 46.809336457933696, 44.683854716164724, 46.93510232652937, 40.985780239105225, 40.11425379344395, 40.33901064736502, 44.22259507860456, 46.11290461676461, 51.6377716745649, 48.22684192657471, 46.89024128232683, 43.011034216199604, 41.3767032623291, 40.527025427137104, 42.310777391706196, 41.89493465423584, 43.99687589917864, 45.03701428004673, 47.614768164498464, 51.76577486310686, 55.87965733664376, 52.7550767489842, 54.12832914079939, 52.64743178231375, 50.03292192731585, 48.971577644348145, 49.84363562720162, 53.3829402923584, 56.71651921953474, 56.694406577519004, 58.651231220790315, 59.83673286437988, 64.69559424264091, 62.37073394230434, 67.49993583134243, 26.319513968058995, 0.2696630614144461, 46.80097082683018, 43.05313682556152, 33.68310192653111, 31.06389856338501, 33.30048200062343, 41.27188968658447, 39.81391790934971, 52.777349199567524, 4.210634836128779, 0.3465491943061352, 0.05237615880157266, 0.021645480833415474, 0.0649468953322087, 0.047858978156000376, 0.03465782831023846, 0.052829939273319075, 0.009581397919516479, 0.029253659902938774, 0.023925845344950045, 0.04636089497112802, 0.08146823916052069, 0.06495598091610841, 0.011220075256590332, 0.055367826484143734, 0.09677271185708897, 0.11545042640396527, 0.15147541117455277, 0.3196147195994854, 6.828677415847778, 60.43938486916678, 52.71509681429182, 20.760788338524954, 27.505654845918926, 49.96414865766253, 25.37236159188407, 55.52662284033639, 70.81555366516113, 32.56015838895525, 2.2540021368435452, 37.113389355795725, 50.58974014009748, 62.36747523716518, 62.270756312779014, 66.43899454389299, 61.59810815538679, 66.63171672821045, 62.341607093811035, 66.21538066864014, 61.962575912475586, 62.82814775194441, 58.207456724984304, 61.53371919904436, 57.84638316290719, 59.71538257598877, 58.55255290440151, 57.34615107945034, 47.41765471867153, 46.6895877293178, 47.31859425136021, 45.474580560411724, 45.44472762516567, 44.30013002668108, 42.0761992590768, 42.08260202407837, 42.39358254841396, 43.86283820016043, 42.333081109183176, 43.34763274874006, 43.94970457894461, 43.989152976444785, 47.191626344408306, 54.110576493399485, 53.45690734045846, 52.41576494489397, 51.82428216934204, 55.32404811041695, 50.86883538109915, 49.80569846289498, 47.791380950382774, 51.0320520401001, 51.00992897578648, 51.02522543498448, 49.17349924360003, 50.696040630340576, 47.84224871226719, 48.779630184173584, 46.568466731480186, 50.55348791394915, 51.0239018031529, 51.01397977556501, 34.48315225328718, 31.968626976013184, 40.95250531605312, 41.00025681086949, 44.71612215042114, 42.3398243359157, 41.156546115875244, 35.76715503420149, 37.48260620662144, 35.70686204092843, 35.27381556374686, 35.60675239562988, 38.76834256308419, 36.31930405752999, 38.67498309271676, 39.513481276375906, 41.23388304029192, 40.76768670763288, 39.76200096947806, 36.794348921094624, 38.15470893042428, 36.06732068743025, 36.640456744602744, 34.92479017802647, 36.54804917744228, 37.692830903189524, 39.33540589468819, 36.53070994785854, 42.475022384098594, 37.86413526535034, 43.903443472726, 30.344978877476283, 41.9737480708531, 56.66139221191406, 48.749325616019114, 49.4578195299421, 44.169198172433035, 45.31480325971331, 43.314079897744314, 46.8406207220895, 43.5310617174421, 48.638567856379915, 48.301340511866975, 50.08274051121303, 50.701665197099956, 51.48182283129011, 47.904834611075266, 46.222227573394775, 46.762661933898926, 49.021048818315776, 47.58781610216413, 49.05146108354841, 42.22144092832293, 42.625339712415425, 42.922743456704275, 47.46435356140137, 48.938125542231965, 51.05874701908657, 51.99562127249581, 49.477350916181294, 44.070710931505474, 42.271620818546836, 44.793976715632844, 45.09526450293404, 43.68410273960659, 47.96224062783377, 47.07730415889195, 51.46892697470528, 55.062438011169434, 58.86131695338658, 56.11661522729056, 57.18999031611851, 54.25166661398751, 54.854019846235005, 54.06947789873396, 53.970448698316304, 56.35040473937988, 59.19872842516218, 59.6879997253418, 63.017076219831196, 62.20201083592006, 66.69496617998395, 65.1557456425258, 71.74876621791294, 29.30242599759783, 0.43696327986461775, 52.57155050550188, 47.40039886747088, 39.650742939540315, 36.11124719892229, 32.56241307939802, 39.853300298963276, 43.93714918409075, 59.01452473231724, 2.2999670760972157, 0.1860467025211879, 0.06886246308152165, 0.010194988655192512, 0.029521382679896693, 0.05715642443725041, 0.0434120767749846, 0.03563514943899853, 0.02129257985922907, 0.058574026583560874, 0.1963500939309597, 0.13007650657423905, 0.16103951154010637, 0.13098893261381558, 0.17989624398095266, 0.23704390174576215, 0.13475116501961434, 0.3305965917451041, 0.32276879463876995, 0.625227516250951, 16.605195828846522, 74.77633258274624, 60.2522212437221, 41.78936719894409, 26.58575851576669, 65.36397620609829, 31.76987722941807, 57.41829422542027, 75.15091691698346, 35.23755986349923, 3.412375624690737, 38.99655614580427, 56.42311416353498, 64.26591764177594, 65.98932797568185, 69.14007895333427, 62.80020209721157, 66.00744887760708, 62.53341906411307, 68.05346407209123, 63.24584565843855, 63.84903267451695, 59.165828704833984, 62.86861406053816, 58.197493008204866, 61.8529611315046, 58.93076419830322, 59.948682240077424, 48.17211444037301, 50.0882955959865, 49.48392391204834, 45.747512749263215, 46.672905104500906, 46.705002307891846, 45.268246855054585, 44.7326797076634, 44.79198258263724, 46.51969732557024, 44.69346407481602, 45.23712934766497, 47.75929764338902, 45.11248561314174, 48.73813206808907, 57.75453839983259, 56.91629729952131, 53.021741662706646, 54.60925218037197, 58.60483809879848, 53.22033854893276, 52.558303764888215, 48.97713967732021, 52.82851573399135, 53.221644810267854, 54.486074515751426, 52.81303514753069, 53.16290126528059, 51.027059759412495, 52.423046657017295, 48.08060319083077, 52.93775531223842, 54.499581813812256, 53.043986320495605, 38.012170110430034, 37.02611303329468, 42.587624890463694, 44.43809345790318, 47.88424709865025, 44.796623979296, 43.59211553846087, 39.662996087755474, 40.55787195478167, 38.87783922467913, 37.525855268750874, 39.80323852811541, 41.00745167051043, 39.23881551197597, 39.72945213317871, 44.44540296282087, 43.49447250366211, 44.37111977168492, 44.57534122467041, 41.30043983459473, 42.06078815460205, 41.87950617926461, 37.4399025780814, 40.120920589991975, 38.79670510973249, 39.777280058179585, 40.125621046338765, 39.99804169791085, 42.18035970415388, 41.77854190553938, 45.34037957872663, 35.94447653634207, 38.937083039964946, 53.62936857768467, 52.88022422790527, 51.07861539295742, 49.323965958186555, 46.403804847172324, 46.39631468909127, 48.27182109015328, 45.40331636156355, 50.654320171901155, 48.63749435969761, 53.072953360421316, 51.6852000781468, 52.93122053146362, 50.111443519592285, 48.62577969687325, 47.96405758176531, 51.672512667519705, 50.05143540246146, 53.17568942478725, 44.53183160509382, 43.87406301498413, 45.246148109436035, 49.29897676195417, 48.89533158711025, 55.07069941929409, 53.39430059705462, 51.30288587297712, 47.1775666645595, 44.555629185267854, 46.59868097305298, 47.05446890422276, 45.4279442514692, 50.31393487112862, 49.50768327713013, 54.7787778036935, 56.48805897576468, 63.53686400822231, 57.05766882215227, 59.29710796901158, 58.12031936645508, 58.48735795702253, 55.34141513279506, 57.1517265864781, 58.288757596697124, 63.858266830444336, 61.8424346106393, 67.4308637891497, 65.73368290492466, 70.72330243246896, 67.51937689099992, 74.52169500078473, 31.818049090249197, 0.7883074368749345, 55.98058686937605, 56.0085950578962, 44.82997533253261, 43.05317504065377, 44.66520227704729, 57.61941678183419, 50.949246883392334, 71.32567650931222, 5.3986704008919855, 0.4589801941599165, 0.2124488800764084, 0.06794779109103338, 0.15892796484487398, 0.1595362579183919, 0.1315279472619295, 0.12562751530536584, 0.1346053478441068, 0.1898833295064313], [0.0401819074260337, 0.10559751439307417, 0.11310994877879109, 0.015333342665274228, 0.01789525680110923, 0.06274188043815748, 0.015619031353188413, 0.05420198118580239, 0.03016500367916056, 0.03837628842198423, 0.09216942172497511, 33.857699734824045, 56.01730809892927, 38.92905439649309, 27.387717860085623, 42.35341501235962, 29.464405877249582, 32.11659928730556, 70.13375473022461, 32.18838807514736, 1.863500782421657, 30.80487319401332, 46.17812040873936, 55.339090960366384, 61.4938017981393, 61.31972163064139, 61.665658542088096, 61.21079472133091, 63.89286191122872, 63.52784524645124, 60.8551025390625, 59.34046472821917, 59.240132740565706, 59.46375356401716, 55.72139474323818, 58.16907140186855, 57.508186544690815, 50.73165709631783, 43.07077482768467, 44.13570785522461, 42.980274541037424, 40.716836316244944, 40.87705830165318, 40.53883389064244, 41.157532760075156, 37.950807094573975, 37.22785745348249, 38.36777196611677, 39.60808447429112, 37.5976197378976, 40.9405266216823, 40.477057456970215, 45.21371391841343, 51.10179805755615, 50.82104567119053, 50.11228425162179, 51.16808039801461, 53.225435052599224, 47.57550736836025, 47.151924337659565, 47.096991879599436, 46.73128386906215, 46.45546122959682, 47.75806086403983, 44.212374278477256, 48.848531995500835, 44.413910252707346, 45.8379921913147, 42.20436920438494, 47.60516227994646, 44.75709915161133, 49.98027890069144, 33.6267728805542, 30.018003599984304, 39.46579578944615, 35.374151025499614, 44.31005205426897, 37.870096819741384, 34.32630361829485, 36.46541077750069, 37.14855766296387, 35.89074959073748, 35.6965856552124, 35.191552366529194, 36.483163424900596, 36.65257787704468, 42.04396309171404, 38.50652749197823, 41.1828624180385, 39.968487535204204, 40.35712112699236, 35.63951662608555, 35.63941935130528, 32.622518471309114, 34.45890304020473, 34.24230684552874, 35.11370127541678, 33.589551380702424, 37.2611289024353, 34.20593997410366, 39.794601917266846, 36.08227321079799, 41.18792418071202, 26.411372627530778, 29.712970733642578, 44.338293007441926, 46.137615885053364, 46.141663210732595, 42.95539999008179, 41.05946241106306, 40.866816656930105, 41.569467135838096, 45.83618218558175, 45.84286287852696, 44.46604258673531, 47.25629670279366, 44.773354462214876, 47.920113699776785, 44.73183897563389, 47.764480999537874, 44.62388481412615, 43.284049783434185, 43.45818553652082, 43.213063512529644, 40.205268246786936, 39.46989870071411, 40.30360957554409, 43.223492758614675, 45.62502990450178, 48.25424909591675, 46.56230020523071, 43.977816990443635, 42.23833894729614, 40.329939774104524, 41.81188978467669, 42.12340184620449, 43.23923737662179, 44.05108227048601, 44.326157978602815, 46.93725279399327, 51.504352365221294, 52.10143886293684, 54.88122204371861, 51.19032505580357, 48.785779339926584, 49.81938988821847, 45.60949720655169, 47.09153754370553, 51.50495685849871, 54.24166120801653, 55.394975321633474, 57.223046370915, 58.787012917654856, 64.14890997750419, 61.777976172310964, 71.1413130078997, 24.474702971322195, 1.0231756567955017, 47.21292952128819, 40.29750905718122, 35.80486290795462, 23.64280731337411, 63.64631898062569, 59.747226170131135, 41.40265825816563, 45.67238882609776, 0.476237239582198, 0.056058154441416264, 0.03591493656858802, 0.046785905558083735, 0.06650802120566368, 0.03993077822295683, 0.035861054102757146, 0.051345623563975096, 0.020423882008929337, 0.1330515162221023, 0.032075646333396435, 0.03480700423408832, 0.03927337617746421, 0.03508432828156011, 0.042546357693416734, 0.01457592286169529, 0.027213540892781954, 0.05035881990832942, 0.048238981515169144, 0.07137974657650505, 0.14155320716755732, 33.653780528477256, 64.07243810381208, 29.134654794420513, 27.411503280912125, 50.1905973979405, 27.823793751852854, 41.54676737104143, 73.9054592677525, 38.788405486515586, 2.7922030857631137, 32.41509737287249, 51.250253268650596, 61.663761683872764, 65.0359239578247, 63.57393264770508, 64.62663337162563, 66.07296344212124, 65.38692610604423, 66.80102348327637, 64.61815656934465, 62.72903169904436, 61.218625341142925, 62.41229806627546, 57.90218414579119, 61.43211569104876, 59.91929830823626, 52.515308312007356, 45.34686919621059, 47.02707215717861, 43.616767747061594, 44.624249594552175, 43.87240934371948, 43.5778717313494, 43.901181834084646, 41.18561043058123, 39.39637981142317, 40.573981353214805, 41.638490540640696, 42.51004825319563, 43.40562241418021, 43.292481422424316, 47.95227691105434, 53.31669616699219, 51.022369725363596, 53.374515601566856, 53.46789591653006, 54.272406986781526, 50.417945929935996, 49.7073849269322, 49.29962294442313, 50.85292400632586, 51.3543963432312, 50.233217648097444, 47.0831858089992, 49.82117557525635, 47.971891675676616, 47.8865921156747, 46.42021649224417, 50.47606413705008, 46.92366211754935, 50.60556466238839, 37.98839337485177, 32.37598596300398, 40.52911683491298, 37.01567336491176, 46.04440232685634, 39.51653848375593, 34.321745600019185, 38.853336402348106, 38.11900561196463, 37.07620259693691, 36.80253389903477, 36.799501010349815, 37.77369403839111, 38.77383858816964, 44.78390530177525, 40.9758860043117, 40.6772836957659, 41.41039855139596, 41.91089814049857, 37.16783543995449, 35.58536236626761, 34.338476862226216, 36.38425234385899, 34.62965849467686, 37.62037508828299, 35.233637605394634, 38.52193512235369, 39.05530316489083, 41.88573523930141, 38.18917546953474, 44.12462200437273, 30.827427046639578, 43.467919962746755, 51.188254492623464, 48.17210749217442, 48.435784680502756, 48.119881357465474, 45.956782068525044, 43.39355686732701, 45.051337991442, 47.693043095724924, 48.48236540385655, 47.88519205365862, 49.160683291299, 48.16411011559622, 51.70826809746878, 47.53606939315796, 48.66667331968035, 46.03673846381051, 47.675095898764475, 44.93940598624093, 45.49655771255493, 43.384166376931326, 43.49323919841221, 41.19459097726004, 45.66462074007307, 47.96739966528756, 50.57442283630371, 50.66071598870413, 49.06566320146833, 44.828088896615164, 43.66499171938215, 44.45472397123064, 44.01040751593453, 46.08221789768764, 46.66201727730887, 47.411766120365684, 50.580307960510254, 53.81589991705758, 54.698859623500276, 57.99290330069405, 54.944933550698416, 52.15195574079241, 52.802519048963276, 50.0699280330113, 52.505264690944124, 53.51327460152762, 58.59555530548096, 57.42206709725516, 62.09382043566023, 62.806587491716655, 68.56107861655099, 65.48213032313755, 75.15402970995221, 24.668271098818096, 1.4825199799878257, 56.21322645459856, 44.705560888562886, 44.392822469983784, 26.935470036097936, 67.20518629891532, 58.59761197226388, 42.592116900852744, 53.829070227486746, 0.4415790007582733, 0.05673923057370952, 0.02704966620409063, 0.01452180290860789, 0.09298451870147671, 0.014818529664937938, 0.0457716721243092, 0.05078836989455989, 0.026352393440902233, 0.0067429141823335415, 0.1565410957804748, 0.11775113509169646, 0.2436040597302573, 0.09384823949741465, 0.11672179746840682, 0.2137186090861048, 0.1055420305845993, 0.14984885416924953, 0.18116855142371996, 0.1321684436074325, 0.1698138378560543, 58.199216161455425, 68.99753665924072, 54.88265684672764, 38.4829592023577, 56.81482580729893, 39.109648500170024, 43.24704367773873, 81.11988503592355, 40.93840047291347, 5.240784747259958, 34.869055203029085, 56.10131876809256, 65.29114518846784, 67.8543425968715, 64.52380003247941, 65.97228404453823, 66.86464813777378, 66.20850890023368, 67.62201568058559, 65.65780857631138, 62.29120486123221, 63.261493001665386, 62.36902468545096, 60.02684947422573, 62.396609033857075, 62.68743283408028, 55.649272441864014, 47.73906101499285, 48.79170615332467, 47.93535457338606, 46.22847400392805, 45.516558102199006, 44.88688107899257, 47.38287551062447, 43.010860511234824, 40.76456696646554, 42.1334593636649, 44.76691000802176, 43.24311447143555, 47.44821637017386, 45.386755330221995, 48.26047815595354, 54.43957369668143, 53.75483219964163, 54.435842514038086, 54.890772342681885, 56.48050628389631, 53.516255378723145, 50.3642954145159, 51.56827231815883, 51.97033677782331, 52.05658476693289, 51.53520236696516, 48.93346677507673, 52.9245537349156, 49.65586403438023, 50.18103667667934, 48.11684499468122, 52.875475134168354, 48.34110505240304, 54.01759222575596, 41.83210209437779, 36.84775972366333, 41.47144195011684, 39.1980539049421, 48.41756650379726, 44.022212505340576, 36.286327907017295, 41.39110687800816, 41.55651569366455, 40.10132319586617, 39.833275590624126, 40.87218761444092, 40.437053203582764, 41.98663003104073, 49.281880719321116, 44.40437037604195, 46.30631467274257, 44.912495613098145, 45.729291098458425, 39.054504122052876, 37.65002999986921, 36.77535949434553, 38.143261773245676, 36.70280293055943, 39.64598342350551, 38.50525944573538, 42.692490577697754, 40.167723655700684, 44.16373341424124, 40.63990238734654, 44.42989805766514, 35.885534967694966, 37.92624521255493, 50.8182281766619, 53.71078062057495, 50.60260125568935, 51.22402729306902, 46.66303171430315, 45.078297001974924, 45.725320202963694, 51.81373480388096, 49.895100934164866, 49.936150891440256, 50.14424249104091, 49.668919699532644, 52.53669834136963, 47.841744967869346, 51.57385866982596, 48.37204885482788, 48.87575156348092, 46.15891211373465, 48.124349049159456, 44.96626077379499, 45.344649246760774, 43.08819743565151, 47.21762997763497, 50.47041177749634, 52.6768330846514, 52.59418773651123, 49.55755049841744, 47.705407415117534, 46.61155251094273, 48.75358138765608, 45.94671760286604, 48.116664341517854, 49.974918365478516, 49.977728911808555, 51.93059655598232, 56.833370549338206, 57.46113681793213, 59.87504523141043, 57.7383108820234, 55.18043579374041, 56.10545294625418, 52.536906787327354, 54.63969223839896, 58.417994090488975, 62.008614676339285, 60.76107256753104, 65.25088732583183, 67.33399895259312, 71.82553686414445, 68.03630202157157, 77.91327054159981, 28.158766405923025, 1.766883366874286, 58.84591974530901, 55.304645265851704, 50.43350294658116, 34.64628553390503, 80.67406776973179, 82.06517355782645, 50.05757761001587, 63.63899557931082, 0.690087973007134, 0.13096834586134978, 0.14231924606221064, 0.14668062488947595, 0.1666309115077768, 0.08155680155115468, 0.16189001447388104, 0.09460509781326566, 0.09353232716343232, 0.19921619870832988], [0.0476891272701323, 0.14296267367899418, 0.0354147205528404, 0.01834776671603322, 0.02222229497108076, 0.10472857566284281, 0.03709944157994219, 0.17326052433678082, 0.08686226007661649, 0.16236885663654121, 0.22930474845426424, 8.670893260410853, 57.751773016793386, 45.14463145392281, 38.75521394184658, 42.145729882376536, 32.22185754776001, 23.31319866861616, 60.80563831329346, 49.38353981290545, 2.3287104708807806, 23.97326363836016, 45.2593913759504, 56.99614947182791, 65.07687664031982, 62.921753883361816, 64.07979624611991, 62.625607763017925, 62.19357572283064, 63.764368874686106, 59.703202383858816, 59.0833466393607, 61.22544847215925, 60.59065410069057, 54.77346590587071, 57.36441789354597, 55.931344985961914, 46.50036743709019, 41.39083589826311, 43.477042947496685, 40.06980616705758, 41.362643582480295, 42.02377162660871, 42.39925227846418, 40.791602407182964, 38.34596504483904, 35.296383312770296, 36.21195091520037, 37.62034729548863, 38.21898324148995, 39.48179054260254, 41.073598521096365, 48.21948725836617, 50.1158903666905, 51.86776399612427, 49.273640155792236, 51.59678077697754, 51.88798325402396, 49.33181742259434, 49.005526542663574, 46.69848837171282, 46.91304179600307, 49.645820413317, 48.4295973096575, 48.031507219587056, 49.68972955431257, 50.474987166268484, 48.89044352940151, 45.75653151103428, 47.01629202706473, 48.62930243355887, 50.49062756129673, 38.77130944388253, 31.38542992728097, 41.39374371937343, 32.0006616456168, 38.128743512289866, 39.87498910086495, 38.91233008248465, 34.463106700352256, 34.1337308202471, 34.18400798525129, 34.45055825369698, 35.65849910463606, 36.940229824611116, 40.25045585632324, 37.737250736781526, 37.96095493861607, 38.082805497305735, 40.17042303085327, 38.90981136049543, 41.02143144607544, 38.20652512141636, 38.48330661228725, 34.82615007672991, 38.08527905600411, 37.764682224818635, 38.72296040398734, 40.658533981868196, 36.83193867547171, 38.41845907483782, 38.7451286315918, 41.11548226220267, 23.540859869548253, 29.259771006447927, 37.62510681152344, 44.474165030888145, 45.480232919965474, 42.29324013846261, 43.0385525567191, 43.389429637363975, 42.24262251172747, 46.18798337663923, 47.33213629041399, 47.18299668175833, 47.951217310769216, 47.54004028865269, 47.561996596200125, 46.629791532244, 45.27888107299805, 45.28811870302473, 46.77638462611607, 43.791574001312256, 42.76683977672032, 39.047323158809114, 38.77497461863926, 40.502696309770855, 43.79422126497541, 46.13786254610334, 45.86440576825823, 45.58247913633074, 45.70745985848563, 39.83189637320382, 40.0305940083095, 41.95802777154105, 41.607053416115896, 42.21353040422712, 44.0012081010001, 42.01588889530727, 47.768865312848774, 45.57795933314732, 51.02120590209961, 50.315574645996094, 48.823622703552246, 46.66629389354161, 47.333126408713206, 44.768577575683594, 49.67749377659389, 46.06990916388375, 53.809722968510215, 50.64793130329677, 56.66680833271572, 55.42612757001604, 68.27527141571045, 58.7641533442906, 77.4704201562064, 16.70979401043483, 2.393143070595605, 56.75400822503226, 42.7468706539699, 30.01942103249686, 28.623335123062134, 78.77315180642265, 47.13912228175572, 43.73557499476841, 47.50415284293038, 0.23859552134360584, 0.0639634131054793, 0.0222003884680037, 0.02027630912406104, 0.059347420797816346, 0.07015860745949404, 0.026808297727257013, 0.07681995537132025, 0.06529956390815121, 0.055800104181149175, 0.05800284259021282, 0.12210684136620589, 0.08776468451001815, 0.008222867335591997, 0.039722535825733624, 0.0679622981697321, 0.09805022366344929, 0.04631409980356693, 0.04793975774997047, 0.08491563131766659, 0.17077692332012312, 7.096098814691816, 67.87976605551583, 42.71303292683193, 40.88586514336722, 50.959290504455566, 31.535570076533727, 29.06324815750122, 65.54118306296212, 54.32574135916573, 5.6578282202993115, 23.530018942696707, 49.96200513839722, 60.974062647138325, 66.88258838653564, 66.14630167824882, 65.79550797598702, 66.50472450256348, 65.01621886662075, 66.40068912506104, 61.11668137141636, 61.47721644810268, 62.83985546657017, 64.17488929203579, 59.090169770377024, 60.0902031489781, 55.78656537192208, 49.28570570264544, 44.02680179050991, 45.739452838897705, 43.9567882674081, 43.439460141318186, 44.945697580065044, 44.89279399599348, 42.426120962415425, 41.352926526750835, 39.277947766440256, 37.765137331826345, 42.06055538994925, 40.73387677328927, 42.42459235872541, 42.44944259098598, 49.658879552568706, 52.83257348196847, 55.64107704162598, 51.31216171809605, 55.26449162619454, 55.391699245997835, 51.42537914003645, 51.503633226667134, 48.4869373185294, 49.25824294771467, 53.111300468444824, 52.680842195238384, 51.58623341151646, 51.31843594142369, 51.64579684393746, 51.35994447980608, 47.76385566166469, 49.71312761306763, 50.131388323647634, 54.386798654283794, 42.285128116607666, 32.53571810041155, 40.43775149754116, 35.62845161982945, 39.2463230405535, 43.58327048165457, 42.47794757570539, 36.6610164642334, 35.643609115055625, 37.16792229243687, 35.88494437081473, 37.087833881378174, 38.494500160217285, 41.65213680267334, 40.059908458164756, 40.821761063167024, 39.32551165989467, 43.27601419176374, 40.68035132544381, 41.677421297345845, 39.59775250298636, 41.36177853175572, 38.53294801712036, 39.976919174194336, 39.31566258839199, 41.862507411411826, 41.587775639125276, 38.28875010354178, 39.80573640550886, 41.49464545931135, 40.27639348166329, 31.037762914385112, 45.052203042166575, 41.5048280443464, 49.43719727652413, 47.49304614748274, 46.78337451389858, 46.47488144465855, 47.264797823769705, 45.8336044039045, 48.67565734045846, 48.808013575417654, 50.49769040516445, 50.2747609274728, 51.368042605263845, 49.542247091020855, 48.688914503370015, 49.214451926095144, 48.60501847948347, 49.290162972041536, 46.23066963468279, 46.555748053959434, 41.796117373875205, 41.749314308166504, 42.355256284986226, 46.38416576385498, 48.26228468758719, 47.77102967670986, 47.175572531563894, 48.0692081451416, 40.61251258850098, 42.59786306108747, 43.57988323484148, 43.605414390563965, 44.2347092628479, 46.02981110981533, 45.02142947060721, 50.13209009170532, 49.88803461619786, 52.323207991463796, 53.396631717681885, 52.44803237915039, 49.302999768938335, 50.445686612810405, 47.1041658946446, 54.06838355745588, 48.97684090478079, 56.85668870380947, 54.306734561920166, 60.93282508850098, 58.20483725411551, 70.61065128871373, 63.728008951459614, 80.01747689928327, 16.35119574410575, 3.8736545869282315, 61.80653326851981, 49.68530355181013, 36.327548095158164, 28.945717641285487, 85.68861048562187, 54.34598840985979, 50.58927461079189, 49.222206115722656, 0.12407696779285159, 0.09838022238441876, 0.029105355896587883, 0.03672390976654632, 0.06678071764430829, 0.002956441112993551, 0.03752472358090537, 0.031717508765203614, 0.015660628942506652, 0.0234121146079685, 0.152498546987772, 0.22328881626682623, 0.14162030071020126, 0.12820654548704624, 0.1502436258430992, 0.1844741976154702, 0.20095962658524513, 0.21629359519907407, 0.21729956407632145, 0.31368416068809374, 0.8089502634746688, 14.700444459915161, 75.65015193394252, 59.56603799547468, 51.652998651777, 55.47399371010916, 44.517000675201416, 33.73686708722796, 72.05465371268136, 58.15139518465315, 8.490703889301844, 25.597304310117448, 55.73382159641811, 64.2439752306257, 72.4951764515468, 68.4763731275286, 70.19046592712402, 67.0149724142892, 67.96090017046247, 66.26899296896798, 62.70413630349295, 63.11858245304653, 63.542554582868306, 65.70204080854143, 60.6668758392334, 61.43501308986119, 58.60726302010672, 51.315726143973215, 46.794158118111746, 47.733259269169395, 46.45536395481655, 44.44404111589704, 47.64498240607125, 46.38208130427769, 45.44689198902675, 44.214545590536936, 41.50254903520857, 39.07560232707432, 44.9819324357169, 42.891844817570274, 44.87304374149868, 44.91312442507063, 52.20788526535034, 54.18586369923183, 57.614629473005024, 52.806205068315776, 55.44650316238403, 58.34116785866873, 55.16118928364345, 55.459128039223806, 51.62092924118042, 49.55562932150704, 55.957894052777974, 55.031198910304475, 53.873747144426616, 54.57103361402239, 54.56766721180507, 54.277465275355745, 51.37500122615269, 51.663921219961985, 55.61490665163313, 55.90855836868286, 46.13993310928345, 38.53900337219238, 42.77418054853167, 37.56461926868984, 43.944580282483784, 45.68564598900931, 44.9979202406747, 40.37795877456665, 38.44205168315342, 40.74833944865635, 38.63906785420009, 41.346099921635215, 43.654763971056255, 45.468045779636924, 42.97537953513009, 44.77176332473755, 42.772342750004356, 46.01385109765189, 42.769101415361675, 45.678749901907786, 42.7720821925572, 45.55956745147705, 40.29551492418562, 41.49267217091152, 43.739830766405376, 43.897864069257466, 46.765611444200786, 41.071274348667686, 42.49736431666783, 41.83939075469971, 40.957911014556885, 36.63902541569301, 39.333102566855295, 41.42077916009085, 51.31189768654959, 50.03276211874825, 48.81470469066075, 49.123805727277485, 48.747713633946006, 47.8046624319894, 52.080733231135774, 50.912244251796174, 50.3596852847508, 52.064116614205496, 52.6347895349775, 50.839312485286165, 50.45522648947579, 50.29493154798235, 49.89694568089077, 51.53026219776699, 48.666808809552876, 48.5956140926906, 42.914659227643696, 43.737933908190044, 45.04156535012381, 49.28699459348406, 51.73493875776018, 51.03768008095877, 50.15611348833357, 51.877220494406565, 44.2918929372515, 44.9379677091326, 45.41771650314331, 45.74416719164167, 47.07188803809029, 47.90421274730137, 47.6972120148795, 54.21473693847656, 52.16207231794085, 57.49521425792149, 55.525313104902, 56.20701476505825, 52.3220545904977, 52.75420822416033, 48.99711922236851, 57.229372705732075, 51.145662035260884, 61.05179909297398, 59.02844892229353, 61.480753081185476, 60.84015696389334, 74.0393510546003, 65.91371767861503, 84.59415108816964, 20.056520666394913, 3.784547414098467, 66.29117856706891, 57.44090713773455, 40.68294300351824, 41.07783692223685, 91.15696089608329, 60.73966516767229, 55.598877157483784, 62.88937527792794, 0.5186107201235635, 0.2071569176124675, 0.08254960006369011, 0.11856574352298464, 0.17533298741493905, 0.13182727620005608, 0.11929412372410297, 0.1825839076191187, 0.12030908997569766, 0.09600965173116752], [0.05508889091600265, 0.12216576534722533, 0.025862160371616483, 0.011131571389601698, 0.027356910253209726, 0.0167439372411796, 0.02604307816363871, 0.06882057711482048, 0.04081081100074308, 0.027083518316171, 0.08749647997319698, 1.5497796280043465, 49.02239676884243, 38.403464862278526, 34.262783186776296, 37.73018094471523, 34.97336850847517, 27.82467791012355, 50.35860136577061, 58.44197232382638, 6.957997722285135, 15.751041616712298, 42.58788892201015, 57.24940088817051, 67.0052796772548, 62.74094091142927, 63.602885791233604, 61.72364820752825, 61.5050995690482, 60.88900974818638, 60.675859860011506, 57.80752188818795, 60.545240674700054, 55.528533594948904, 57.77599443708147, 55.62933458600725, 50.43336745670864, 43.131001813071116, 41.38190051487514, 40.532771587371826, 42.07899938310896, 40.35522774287632, 39.97703034537179, 40.47520923614502, 40.66105270385742, 37.31028045926775, 38.02929047175816, 36.578065395355225, 37.93422521863665, 39.148461137499126, 40.22518873214722, 41.550439493996755, 49.80566372190203, 49.54389033998762, 54.91183580671038, 54.66643932887486, 49.742643560682026, 53.807614190237864, 46.13659797395979, 48.68626376560756, 46.52811506816319, 47.87588494164603, 49.24819237845284, 50.48221329280308, 49.29140669958932, 47.72390004566738, 47.10288742610386, 46.696633202689036, 46.95338303702218, 46.22685854775565, 48.089045252118794, 49.364748409816194, 42.00034924915859, 32.063640117645264, 39.35055296761649, 38.423187323978965, 38.8800904410226, 34.06316491535732, 37.47993809836251, 36.751919746398926, 37.17116362707955, 37.66967603138515, 38.52059759412493, 35.40973622458321, 34.62214749200003, 33.331707205091206, 35.38417032786778, 34.20392152241298, 32.52498313358852, 33.70543691090175, 37.95978764125279, 32.60907023293631, 36.81520741326468, 38.26318768092564, 38.992692947387695, 36.66056483132498, 33.100919314793174, 39.46279069355556, 33.228547300611226, 35.268187522888184, 38.934654644557405, 43.94570589065552, 42.06426225389753, 22.01664744104658, 28.52324284826006, 37.87273713520595, 47.44664607729231, 44.79268087659563, 44.40192461013794, 43.41466202054705, 45.484648500170024, 45.78208698545183, 45.63779721941267, 46.28192302158901, 48.63307530539376, 46.88084731783186, 47.78279645102364, 48.97603143964495, 48.55138880865914, 48.40336438587734, 46.398816040584016, 44.62754651478359, 44.21371875490461, 42.33648920059204, 40.715061051504954, 39.30892630985805, 40.97404473168509, 43.118627071380615, 43.79984930583409, 44.284732818603516, 43.40957593917847, 41.229154791150776, 37.926915713718955, 40.863481521606445, 40.98185798100063, 40.650491441999165, 39.88385847636631, 43.58422238486153, 44.231874397822786, 45.138298170907156, 46.524620124271934, 46.47882454735892, 46.972639969417024, 46.653637749808176, 46.0239120892116, 47.269119603293284, 45.21765354701451, 46.68704121453421, 47.76960529599871, 50.672399384634836, 53.2813263620649, 55.68814066478184, 56.94429159164429, 67.24880708966936, 61.51883615766253, 72.55648040771484, 9.295023015567235, 5.721011664186205, 63.201620374407085, 40.84318930762154, 28.588401317596436, 25.734661511012487, 63.93050725119454, 37.348443440028596, 41.836601052965435, 36.71233933312552, 0.02772200619801879, 0.10144893093300716, 0.09767870538468872, 0.029296180299882377, 0.0295176643079945, 0.03868207022813814, 0.14215685906154768, 0.049888391579900465, 0.0637289656858359, 0.05057699605822563, 0.10980746456022773, 0.07407994954181568, 0.10049113125673362, 0.03151915601587721, 0.023649973362418156, 0.05395279937822904, 0.022783183891858374, 0.030106368075524057, 0.04481657641008496, 0.02786577759044511, 0.03847458439746073, 1.2687059960194995, 55.85605778012957, 40.40230873652867, 33.88516248975481, 51.99425942557198, 38.17025899887085, 31.258274418967112, 56.764892578125, 63.60929897853306, 10.818549309458051, 15.483214616775513, 46.709845202309744, 59.83608668191092, 70.0772728238787, 66.31510121481759, 65.188645362854, 64.77016230991909, 64.06706714630127, 62.39354487827846, 62.972989899771555, 60.65669672829764, 62.821560859680176, 58.61835234505789, 60.54813807351248, 58.37896605900356, 53.03008297511509, 43.90723371505737, 44.6796441078186, 43.52115706035069, 44.13790348597935, 43.4688058580671, 42.65664482116699, 42.23027556283133, 44.38507522855486, 40.36132478713989, 40.589246545519146, 38.103625774383545, 41.313808168683735, 41.3386618750436, 40.87812485013689, 41.95164237703596, 51.921605587005615, 53.38520540509905, 54.33188704081944, 56.56403752735683, 53.63639668055943, 55.839875425611226, 48.743666308266775, 49.199103355407715, 48.422680377960205, 50.249802998134065, 50.89418935775757, 53.00549677440098, 50.95864084788731, 50.389159543173655, 49.126591954912456, 49.41023479189192, 50.009030546460835, 48.53922598702567, 50.60043689182827, 51.26359033584595, 45.84237650462559, 36.31881420952933, 39.29102427618844, 40.48727478299822, 40.60954918180193, 36.80445507594517, 39.272090435028076, 38.76406247275216, 38.0922863142831, 38.278157574789866, 39.825788906642366, 39.15988745008196, 36.36819853101458, 35.30260195050921, 38.30257701873779, 35.98827450616019, 35.77740362712315, 34.83383478437151, 37.842057364327566, 34.24023628234863, 37.12613582611084, 39.06924819946289, 40.01602710996355, 38.60728331974575, 35.274920327322825, 43.26103387560163, 36.328072684151785, 39.83032955442156, 39.395855222429546, 42.45036670139858, 41.80920083182198, 32.821431500571116, 37.70338521684919, 41.19725213732038, 49.37759215491158, 48.54308571134295, 46.583071844918386, 46.78799506596157, 48.44033922467913, 47.66921424865723, 48.34319993427822, 47.490642070770264, 50.456369468144004, 48.99015365328108, 50.446680205208914, 51.56456545421055, 51.94552823475429, 50.368596349443706, 47.93489599227905, 46.15530947276524, 45.951327732631135, 44.30146408081055, 43.355181966509136, 42.661654472351074, 43.293158871786936, 45.471092564719065, 46.75104801995413, 45.23914779935564, 46.18281044278826, 43.527000495365684, 41.00529772894723, 45.34591729300362, 44.34363269805908, 44.07310806001936, 42.6416471345084, 45.73809099197388, 46.99119860785348, 47.278579575674875, 47.74392475400652, 50.00463581085205, 50.180129936763215, 52.55492346627371, 49.64250264848982, 52.05587257657732, 46.939215660095215, 50.109282629830496, 50.86728940691267, 54.655846800122944, 56.1470240184239, 60.71356078556606, 60.65636321476528, 71.6215238571167, 65.3488221849714, 74.3068983895438, 8.798883421080452, 7.763362118176051, 68.51663099016461, 46.94299895422799, 31.679950169154576, 29.165897369384766, 67.92269202641079, 42.58386591502598, 49.283079283578054, 41.14550542831421, 0.022793412807264497, 0.06622665308948074, 0.09742823775325503, 0.06735285158668246, 0.05065188257555876, 0.017313652206212282, 0.026183478933359896, 0.04239137350980725, 0.04025184403040579, 0.06120243375854833, 0.16875532322696277, 0.24282388016581535, 0.1783469585435731, 0.09445238672196865, 0.13080378754862718, 0.17665921125028813, 0.1551309914461204, 0.21095674085829938, 0.11290040359433208, 0.14176766494555132, 0.21645982270794256, 3.6216236650943756, 68.71948364802769, 46.7137257712228, 42.555117743355886, 51.679262842450825, 46.61892107554844, 38.55791984285627, 60.91173035757882, 66.3745083127703, 11.541564958436147, 18.343815769468033, 51.14862544195992, 63.76640469687325, 74.22728593008858, 69.03154809134347, 66.38386058807373, 64.88710744040353, 65.21030289786202, 65.0751256942749, 63.29886041368757, 63.55612441471645, 66.58438559940883, 60.70982960292271, 62.72735023498535, 61.027417864118306, 55.25502470561436, 47.90578651428223, 46.78099128178188, 46.11293240955898, 46.00923401968819, 45.749235902513774, 45.14140401567732, 45.36636584145682, 45.741311482020784, 42.179188932691304, 44.253910609654014, 40.36624411174229, 43.02365561894008, 43.953077929360525, 45.16652522768293, 45.65239538465227, 55.61881848743984, 53.885649408612935, 57.46503823144095, 60.644217763628276, 56.52738925388881, 57.32668917519705, 49.88267755508423, 51.63175800868443, 51.26532391139439, 51.80424703870501, 54.04947056089129, 54.891199656895225, 52.48269346782139, 53.04844011579241, 54.82968725476946, 53.23717056001936, 53.305186476026265, 50.74779428754534, 55.08817761284964, 53.482441970280235, 47.449772766658235, 40.73522472381592, 41.280286584581646, 43.24790872846331, 42.457162039620535, 39.969970975603374, 44.939600535801475, 42.85790286745344, 41.46973269326346, 40.808128697531565, 45.56703329086304, 41.725012983594624, 38.62294108527047, 38.12900059563773, 42.6431861604963, 40.036138670785085, 40.6503073147365, 38.61275502613613, 42.90002632141113, 36.75800289426531, 41.55821452822004, 43.1417680467878, 43.52047961098807, 42.34907933643886, 40.14475638525826, 47.40900421142578, 39.81391790934971, 40.531097071511404, 42.16707822254726, 44.8716402053833, 43.84756258555821, 33.97338376726423, 34.58915049689156, 43.48023564474923, 51.112272466932026, 52.9855762890407, 49.791246209825786, 50.83516093662807, 49.745419366019114, 49.86495964867728, 49.16783993584769, 49.30380228587559, 53.35085698536464, 51.482138974326, 51.88698271342686, 55.06193079267229, 53.189259256635395, 53.38985027585711, 50.099120889391216, 47.41616433007376, 49.31476306915283, 45.231664589473176, 44.952816009521484, 43.891020093645366, 45.09434734072004, 47.85310179846627, 49.99570042746407, 50.42327172415597, 49.70178120476859, 46.35246113368443, 43.254176003592356, 46.92741414478847, 45.61277328218733, 45.001814705984934, 44.45405694416591, 48.80380991527012, 50.09434747695923, 50.59469073159354, 51.07297692980085, 52.73889439446585, 53.58727291652134, 54.86172539847237, 52.90149961199079, 54.86804478509085, 51.6009635925293, 53.832294191632954, 53.39995643070766, 58.449149812970845, 58.76001221793038, 62.43344838278634, 62.57191208430699, 75.80310262952531, 67.06586102076939, 79.17090143476213, 12.243890609060015, 7.78631375517164, 74.2334976196289, 53.984074115753174, 37.99226352146694, 38.27019493920462, 81.54931844983781, 45.552007811410085, 56.70733370099749, 48.8361850466047, 0.11059906386903354, 0.16068359278142452, 0.21058950413550648, 0.12106705430362906, 0.19969685934484005, 0.1812256569308894, 0.153664962255529, 0.27175227073686464, 0.15134598740509578, 0.1466892422842128], [0.09784926194697618, 0.028817032796463797, 0.0897693687251636, 0.044546068246875486, 0.07370129986000912, 0.05302622588351369, 0.09892029554716178, 0.061625289996819835, 0.03566926957241126, 0.026759814703837037, 0.06626093946397305, 0.11040252620088202, 36.82431650161743, 49.18931334359305, 36.591409410749165, 34.043345178876606, 36.835756710597444, 23.4478634425572, 36.175563199179514, 71.28951808384487, 15.883406536919729, 8.153777054377965, 36.22457231794085, 52.548194135938374, 63.44385542188372, 61.31198828560965, 63.93207059587751, 60.91899817330496, 59.13562488555908, 57.28091096878052, 62.34230886186872, 55.868696553366526, 56.7605881690979, 55.13235773359026, 56.586841515132356, 51.25506142207554, 44.86576550347464, 41.424381801060264, 40.441034521375386, 42.47638423102242, 40.854973452431814, 38.301437514168875, 39.717313630240305, 39.461317675454275, 40.91404356275286, 37.48374571119036, 36.986880029950825, 34.159168175288606, 38.06939547402518, 37.19828592027937, 38.074898447309224, 39.06399188722883, 47.97226687840053, 52.2359733581543, 50.66421788079398, 57.791072028023855, 54.1390780040196, 51.504560811179026, 47.78080579212734, 47.70538657052176, 45.884638922555105, 48.42470577784947, 51.30626269749233, 49.786681243351524, 49.957711151668, 49.9247419493539, 46.486662115369526, 46.85864782333374, 47.466375487191335, 46.292765685490195, 49.0374813079834, 51.38984605244228, 46.02529130663191, 34.16843012401036, 40.005910532815115, 34.587875502450125, 38.49605655670166, 37.9213467325483, 33.59182344164167, 35.212285791124614, 34.576463086264475, 36.2508920942034, 33.59235497883388, 33.8418995312282, 31.45389747619629, 30.41165726525443, 32.77568456104824, 31.17382253919329, 31.65193155833653, 35.241124289376394, 35.6195718220302, 43.2410751751491, 39.57155779429844, 32.472367899758474, 37.95469461168562, 37.089164461408345, 34.479785851069856, 36.03063767296927, 39.25778409412929, 40.734238079616, 38.56597280502319, 36.50076668603079, 33.80054037911551, 21.781641994203838, 31.402050018310547, 43.81523609161377, 46.52896622249058, 42.85615539550781, 43.683665003095356, 43.310129846845356, 46.92524283272879, 43.145596504211426, 43.341118812561035, 45.538149629320415, 45.8588993208749, 48.71318803514753, 48.35126331874302, 50.85403571810041, 49.81144462312971, 49.08571917670113, 48.45123052597046, 47.54207958493914, 45.3241868019104, 42.02267728533064, 42.18005050931658, 41.05080148151943, 40.896700859069824, 41.119870049612864, 41.64497668402535, 42.54761021477835, 39.03623730795724, 40.23577431270054, 41.6555483681815, 41.00720500946045, 39.9570369039263, 41.97819144385201, 40.33821160452706, 40.43959971836635, 40.918309756687705, 42.32190145765032, 42.11745418821062, 45.2196615764073, 45.10112183434622, 44.347589697156636, 44.54593644823347, 46.61394616535732, 44.627053192683626, 45.96794434956142, 45.25504527773176, 52.93367324556623, 53.375641209738596, 56.424694878714426, 57.36287886755807, 67.21940926143101, 68.30503749847412, 59.48253454480852, 2.957440584897995, 13.950518437794276, 63.65858255113874, 34.9153128351484, 28.646199907575333, 30.24067599432809, 39.46723754065377, 36.28797115598406, 54.668443884168354, 35.357086249760215, 0.04943667724728584, 0.03356055576088173, 0.03938082559034228, 0.011689855584076472, 0.09029320454491035, 0.032682687509804964, 0.04759943172601717, 0.022597060039905564, 0.02430213542122926, 0.042676001986754794, 0.046117372145610194, 0.02049359300040773, 0.04364001365112407, 0.0666078133508563, 0.02581639657728374, 0.007175474743624883, 0.03629331144371203, 0.009374771283806434, 0.036341351723032336, 0.05051967002717512, 0.0836684839533908, 0.09762708922582013, 39.982707023620605, 53.88420418330601, 35.00521905081612, 43.93654816491263, 40.82027414866856, 26.967212881360734, 39.40929651260376, 78.05896036965507, 19.474796635763987, 7.760168552398682, 37.37430810928345, 55.541985307421, 67.17290496826172, 64.43179198673793, 67.14434787205288, 64.41447707584926, 60.65855189732143, 59.81436661311558, 63.97705323355538, 59.54253918784005, 61.64384119851248, 60.135811124529155, 60.80036463056292, 52.03135238374983, 48.48380715506417, 44.17585802078247, 44.443766662052695, 45.0876909664699, 43.6860134942191, 41.285546370915, 43.43800449371338, 42.46219948359898, 43.66684341430664, 40.81852667672293, 39.056251593998496, 37.659455231257844, 39.679949692317415, 38.95646503993443, 40.90114075796944, 43.57113197871617, 50.63426767076765, 54.96704271861485, 51.96883944102696, 56.47393676212856, 57.501582281930105, 51.99817820957729, 50.527821268354145, 49.03881188801357, 48.380275521959575, 50.02945130211966, 53.53474453517369, 52.571296896253315, 52.75357246398926, 51.98605012893677, 49.81817742756435, 49.643280846732004, 50.63579627445766, 48.93635375159127, 51.97676733561924, 52.658993584769114, 46.91531733104161, 38.072226864951, 40.93023633956909, 36.157376289367676, 38.3347749710083, 41.43709700448172, 38.540375641414094, 38.09725775037493, 36.881986549922395, 38.17552573340279, 36.029765674046104, 34.286664145333425, 35.63521221705845, 33.308184078761506, 33.96519184112549, 33.28105483736311, 33.58000455583845, 35.36128990990775, 37.56148910522461, 43.463966437748496, 41.4441112109593, 37.125513962336946, 40.329279695238384, 39.63297292164394, 35.54969726290022, 37.59171029499599, 41.26542438779558, 39.8399840763637, 35.68335281099592, 37.13616902487618, 35.42848941258022, 30.54074089867728, 36.26593147005354, 47.29195138386318, 49.782807622637065, 46.160468510219026, 46.51792206083025, 45.84467288425991, 47.48045253753662, 44.80230065754482, 47.366859912872314, 48.52375929696219, 47.86513955252511, 50.4541460445949, 49.685967104775564, 52.764460291181294, 51.77969210488455, 51.953376225062776, 52.29066262926374, 50.77341576984951, 46.855392592293875, 42.072659151894705, 43.95189673560006, 43.8367338180542, 43.79182413646153, 44.42185204369681, 44.987751552036826, 44.10988140106201, 41.83045537131173, 43.19838196890694, 43.201539925166536, 42.6501065662929, 43.00608362470354, 44.32210023062569, 43.0162627356393, 42.83447354180472, 43.5963956287929, 46.92939438138689, 44.5175530569894, 48.1765786579677, 48.51561253411429, 47.772474902016775, 47.61968401500157, 48.59141043254307, 47.71895292827061, 49.338192394801546, 49.19522973469326, 56.41877153941563, 56.10249301365444, 60.343159266880576, 60.13534559522356, 70.61847496032715, 70.85405363355363, 60.174595969063894, 2.6096007355621884, 18.236412252698624, 70.26923765454973, 41.964645930698936, 32.23830393382481, 35.01927873066494, 47.974507672446116, 36.730884075164795, 60.80056612832205, 36.09984173093523, 0.03399852975936873, 0.013051031606404908, 0.042497628701052496, 0.06410026683339051, 0.09094263719660894, 0.027755649660580924, 0.013554068631492555, 0.01761067921428808, 0.03390825406781264, 0.002835343392299754, 0.1869493712271963, 0.12273380772343703, 0.20969682346497262, 0.09929753387612955, 0.10376683369811092, 0.09310339125139372, 0.08639006077178887, 0.15992788118975504, 0.0766889506152698, 0.13537468441895076, 0.1246101606105055, 0.1655037562761988, 48.63601439339774, 64.27613844190324, 46.0634890283857, 48.08224643979754, 49.24183477674212, 34.19352354322161, 44.63240677969796, 82.20402635846818, 21.48040805544172, 10.36349788733891, 41.780119146619526, 61.02129650115967, 71.63530213492257, 66.60206181662423, 68.88984652927944, 65.74493203844342, 62.08662905011858, 60.16308280399868, 65.48276955740792, 60.574645451136995, 64.28711659567696, 61.61429745810372, 62.88007858821324, 56.14028773988996, 50.792029993874685, 46.01471267427717, 47.74716261454991, 47.24153525488717, 44.47279623576573, 42.76623180934361, 46.94524322237287, 45.570625509534565, 45.36360045841762, 41.53894369942801, 41.1407459122794, 40.61870690754482, 42.15787533351353, 41.27655192783901, 43.89416067940848, 45.17797933306013, 53.818762574877056, 57.35552419934954, 52.65898316247122, 57.869996615818565, 58.18816157749721, 53.18788698741368, 53.155574389866416, 52.29579387392317, 49.09160082680838, 51.838717051914756, 55.49092647007534, 53.88821676799229, 54.32360826219831, 55.626558780670166, 51.45429406847273, 51.351811613355366, 53.384465421949116, 50.69170148032052, 55.560776710510254, 58.47860322679792, 49.84570966448103, 42.8171204158238, 43.14038535526821, 35.76166248321533, 43.23902545656477, 45.75592701775687, 40.12240750449044, 41.3824702671596, 40.59183474949428, 41.24065753391811, 38.25775418962751, 39.1597832271031, 39.33633695329939, 35.6709884916033, 37.76621430260794, 35.703481742313926, 36.09198679242815, 37.782476561410085, 39.64404140199934, 46.326450552259175, 44.44980812072754, 40.67615808759417, 42.083147457667756, 41.94374227523804, 38.25552381787981, 39.833171367645264, 44.79788507734026, 42.10330070768084, 37.734506198338096, 38.84636041096279, 41.4220472063337, 30.80293812070574, 35.407964433942524, 51.54877914701189, 52.00561278206961, 47.93165465763637, 48.398747307913645, 48.96292018890381, 49.98081391198294, 48.702515602111816, 50.59163005011422, 49.238753250667024, 50.16321107319423, 54.26979446411133, 53.347289085388184, 54.52680485589163, 53.93043054853167, 53.016982146671836, 53.3110785484314, 52.054715701511924, 50.44543995176043, 45.22087056296212, 46.35072408403669, 46.78873157501221, 46.50630119868687, 46.26561907359532, 48.56970773424421, 48.19180563517979, 43.89897230693272, 45.76531750815255, 46.54352617263794, 45.85365343093872, 46.27482196262905, 48.34910242898123, 45.73635046822684, 45.44410228729248, 46.27192803791591, 49.62224864959717, 47.8739846093314, 51.85388844353812, 52.10196345193045, 51.607015473502024, 52.19849477495466, 52.571484497615266, 51.052337305886404, 51.46171127046858, 51.35118280138288, 59.211304664611816, 59.17993354797363, 63.254162652151926, 63.07803276606968, 74.41508878980363, 71.30119800567627, 68.07651819501604, 4.416602458272662, 17.408661195210048, 75.17401272909981, 47.53071928024292, 36.62471907479422, 45.58287865774972, 54.901354449135916, 45.967878341674805, 69.59128802163261, 45.33475848606655, 0.13925414053457125, 0.08174671671752419, 0.10737007856369019, 0.19744655223829405, 0.26348809418933733, 0.13748562043266638, 0.1532149306897606, 0.13680361131472246, 0.14744101837277412, 0.10480598293777023], [0.0439420703000256, 0.05570740611957652, 0.03833919969786491, 0.02789897152355739, 0.08426992382322039, 0.02222236112824508, 0.056276361125388315, 0.03800189994009478, 0.01969751705681639, 0.13374073138194426, 0.15634524343269213, 0.055484639680279155, 24.15388900893075, 55.16696323667254, 32.039432593754356, 31.221518448420934, 27.523497819900513, 27.324015038354055, 37.6635616166251, 70.13845171247209, 27.17684871809823, 2.612028045313699, 27.362535851342336, 47.463262694222585, 68.4533884865897, 61.18154975346157, 64.34498814174107, 59.39270823342459, 59.45379679543631, 55.43410062789917, 57.11603716441563, 54.22296707970755, 56.78770351409912, 55.35098627635411, 53.88505186353411, 46.322007179260254, 42.173640796116416, 41.19041510990688, 40.87707914624895, 40.90275274004255, 41.742032596043174, 38.75647851399013, 39.61975049972534, 38.25615610395159, 40.37207017626081, 38.30577319008963, 39.620292459215435, 35.218056270054404, 35.51869787488665, 38.087453842163086, 40.322883878435405, 39.96313394818987, 47.41061271939959, 52.17557961600167, 50.90541417258126, 52.51295287268502, 54.505307129451204, 49.9546400478908, 49.1127233505249, 46.95500891549246, 48.06304161889212, 50.073207582746235, 50.86971780232021, 52.26556921005249, 50.213033131190706, 50.03607988357544, 46.99135146822248, 49.20963682447161, 48.0568334034511, 50.22719355991909, 48.6035280908857, 46.92657341275896, 47.591950280325754, 36.10775572913033, 40.38086659567696, 43.63901587894985, 39.83156633377075, 34.13039915902274, 35.58199943814959, 33.78964907782418, 34.61529309409005, 31.589849403926305, 33.13436794281006, 34.2763842855181, 31.96353394644601, 38.20069905689785, 36.723320960998535, 42.473333971840994, 49.5967035974775, 45.296519075121196, 50.32209553037371, 46.76804678780692, 48.60422985894339, 43.55348008019583, 43.43200125013079, 43.25822680337088, 39.51733752659389, 37.360971042088096, 36.73905863080706, 36.29791055406843, 35.86335631779262, 39.95188134057181, 34.24084077562605, 23.097332034792217, 36.4929986000061, 47.13604422977993, 46.31558704376221, 42.56273644311087, 43.80193029131208, 44.75098473685128, 46.1382794380188, 43.912816592625205, 48.38495165961129, 46.28343425478254, 47.241069725581575, 47.42491558619908, 47.79467439651489, 48.748776708330425, 49.680599621364046, 51.347865036555696, 52.02458483832223, 49.90225757871355, 47.15155955723354, 43.592636653355186, 42.739905084882466, 41.6721510887146, 41.197731563023154, 40.39022234507969, 39.02311216081892, 39.122916085379465, 38.475524629865376, 38.27431174686977, 38.892347063337056, 39.76958492824009, 40.35779857635498, 39.257818835122244, 40.93300519670759, 40.160299505506245, 40.469501291002544, 41.554375648498535, 40.5754474231175, 44.63822589601789, 44.21243333816528, 46.00484275817871, 43.93308448791504, 44.295759609767366, 46.23768384116036, 45.83975008555821, 48.70513159888131, 54.26728616441999, 57.188666684286936, 57.96483605248587, 60.01793493543352, 67.21560859680176, 67.10627174377441, 39.76897348676409, 2.0429562500544955, 26.8607108933585, 58.30826813834054, 32.30835567201887, 40.557406425476074, 34.00810391562325, 38.654875005994526, 38.271709646497456, 55.163669790540425, 20.203353473118373, 0.2761855742761067, 0.059426117289279184, 0.05028586382312434, 0.02357127856729286, 0.06272602986012187, 0.025085309021441, 0.0686341089063457, 0.038202603813260794, 0.04999100982344576, 0.08502249379775353, 0.025181333600942577, 0.06366794503160886, 0.00948175335569041, 0.07316930126398802, 0.05652142422539847, 0.037424185047192235, 0.05904279250119414, 0.07203686702996492, 0.06782140715845994, 0.0648242976250393, 0.14993880077132157, 0.03669165221175977, 26.83120710509164, 61.83270713261196, 33.894605091639924, 39.03106437410627, 33.64024543762207, 30.581096036093577, 42.011949266706196, 74.75234740121024, 31.662781170436315, 2.9866868555545807, 27.179626260484966, 54.68483121054513, 72.53986726488385, 65.08506856645856, 65.75347137451172, 62.00719724382673, 59.80502128601074, 57.98723357064383, 59.61452252524239, 57.568441322871614, 61.18846321105957, 58.01016957419259, 56.01076636995588, 49.92519358226231, 44.28336749758039, 44.14964246749878, 44.01735918862479, 44.49176829201834, 44.29946647371565, 42.28609044211251, 42.35260207312447, 40.3634683064052, 42.412846429007395, 40.78338268824986, 41.426744188581196, 38.154295512608115, 39.74291774204799, 40.5229537827628, 43.16626739501953, 43.00379071916853, 50.96386589322771, 53.1794935635158, 53.51440715789795, 52.59488950456892, 54.32610961369106, 52.688975061689106, 50.4698281288147, 48.30098615373884, 50.408882004874094, 51.45816421508789, 52.63997983932495, 52.308189460209434, 51.445073808942524, 50.61920745032174, 49.91744981493269, 51.19118663242885, 52.55046967097691, 51.84502601623535, 49.65428679330008, 49.57043940680367, 49.05812440599714, 39.94046197618757, 43.78599459784371, 45.04323639188494, 40.960784094674246, 36.21569946834019, 38.14445686340332, 38.12594338825771, 36.11549949645996, 34.04600633893694, 36.15829692568098, 38.145714487348286, 35.27503497259957, 39.22807707105364, 37.99739824022566, 40.33520303453718, 48.95662859507969, 43.518718242645264, 49.98860631670271, 47.94602353232247, 46.10931934629168, 41.6161208152771, 44.58494016102382, 44.53826911108834, 39.60032681056431, 37.27899619511196, 36.903185503823416, 36.85449252809797, 35.48262977600098, 39.229685579027446, 39.876965863364084, 29.059793165751866, 39.41313191822597, 50.366039412362234, 46.62671348026821, 47.215816497802734, 47.48825536455427, 45.80809409277779, 46.61625991548811, 46.39533151899065, 51.014504364558626, 48.89139543260847, 48.829924719674246, 49.69636508396694, 51.20175831658499, 52.22643000738961, 53.353782176971436, 51.70168815340315, 54.041938713618684, 51.8357640675136, 49.81270572117397, 43.470466477530344, 44.18265683310372, 44.219423225947786, 44.01492037091936, 43.45885256358555, 43.61124045508248, 40.79525715964181, 42.89889029094151, 40.932459763118196, 43.08797856739589, 41.55112736565726, 42.597675459725515, 43.22650480270386, 45.35283422470093, 44.08384997504098, 43.08584894452776, 44.08185236794608, 43.87964589255196, 45.717552116939, 47.32037646429879, 47.35433578491211, 46.86344902856009, 48.546584129333496, 48.40453168324062, 47.841453143528526, 53.613505840301514, 58.70570509774344, 58.22341673714774, 60.84973158155169, 65.38718318939209, 67.85070868900844, 71.0796616418021, 38.814756529671804, 1.8366205905164992, 31.191401481628418, 65.39229706355503, 36.99834108352661, 43.619133608681814, 42.37583684921265, 50.44425528390067, 41.014514514378135, 57.04102093832833, 23.717771427971975, 0.19726044365337916, 0.07606303598731756, 0.03829313734812396, 0.0052781178050541454, 0.07324364156063114, 0.07602347061038017, 0.013272558022955698, 0.08227914957595722, 0.03285987335922463, 0.0285667687255357, 0.09015742968767881, 0.12071684880980424, 0.07512569414185626, 0.1681122484483889, 0.17407511919736862, 0.15947662826095307, 0.17898427934518882, 0.07328840451581137, 0.17507640618298734, 0.15364303200372628, 0.20871046424976417, 0.19740699364670686, 36.211474963596885, 72.36225741250175, 42.71514170510428, 44.93825258527483, 39.50863490785871, 36.69733817236764, 49.58759798322405, 79.37488664899553, 31.926461832863943, 4.722535116331918, 32.044664587293354, 60.51983111245291, 74.58185945238385, 66.01443876538957, 69.31556265694755, 61.639839036124094, 62.84184265136719, 59.91052968161446, 61.77480779375349, 61.392344202314106, 65.20997633252824, 59.88093730381557, 58.37104511260986, 52.9406909261431, 47.74743706839425, 46.772240025656565, 45.561884675707134, 47.60112190246582, 49.61660671234131, 43.424983569553916, 44.009563309805735, 42.06947340284075, 45.43770299639021, 42.19566658564976, 45.27705717086792, 40.03447805132185, 42.93190465654646, 41.29228612354824, 46.32055153165545, 44.67585733958653, 52.90718323843819, 56.890884263174875, 53.81504528863089, 53.765424728393555, 56.945087160382954, 56.66073908124651, 52.25089808872768, 51.97199739728655, 52.88861417770386, 55.036611557006836, 53.705142157418386, 55.19150079999651, 55.483516216278076, 53.6241956438337, 52.621511527470176, 54.718008858816965, 53.86729921613421, 55.68349926812308, 53.524693965911865, 54.525238037109375, 51.590704577309744, 45.50691400255476, 46.59175361905779, 43.12315729686192, 37.946467944553916, 38.36468696594238, 42.38061720984322, 42.16194002968924, 40.15875700541905, 38.04002891268049, 39.14443813051496, 40.42912878308977, 37.31412628718785, 42.640069893428254, 42.63863509041922, 41.82228776386806, 48.906570298331125, 44.15650033950806, 50.203104155404226, 49.71043866021292, 51.45976230076381, 43.29155036381313, 46.72905349731445, 46.803736209869385, 42.52073458262852, 38.81376641137259, 38.28543928691319, 36.63381079265049, 37.70792933872768, 40.9488331930978, 41.54599264689854, 29.950105803353445, 39.26517697743007, 53.45068522862026, 49.74695144380842, 47.93846041815621, 49.565957818712505, 48.53492505209786, 52.08802189145769, 49.79905251094273, 54.628165176936555, 50.344979422433035, 51.00219215665545, 51.164665358407156, 52.77300657544817, 53.983921255384175, 54.48445211138044, 55.477436542510986, 56.21077374049595, 54.63088539668492, 50.77552802222115, 45.49080807822091, 45.11384746006557, 46.58337409155709, 45.959550925663535, 45.99565029144287, 44.95554665156773, 45.25749799183437, 46.108384813581196, 42.30309615816389, 44.326296942574636, 44.670649664742605, 45.277807576315745, 44.78885241917202, 48.45651463099888, 47.026443345206125, 45.297728061676025, 47.351271629333496, 46.65088973726545, 48.974843297685894, 50.1946690423148, 50.51312582833426, 50.01517970221383, 50.84015669141497, 51.128760542188374, 49.72886528287615, 54.91266959054129, 61.94929790496826, 62.1851475579398, 63.15509523664202, 66.5832530430385, 72.35712269374302, 77.38421385628837, 47.595045702798025, 2.2197290616376057, 30.76897532599313, 72.88344178880963, 44.615811007363455, 52.28856079918997, 54.25709663118635, 46.29992927823748, 52.06415830339704, 70.2021736417498, 30.103522028241837, 0.256194249859878, 0.13078847979860647, 0.07702800777873822, 0.1247473196791751, 0.15483281601752552, 0.23094476759433746, 0.22421874850988388, 0.14604193344712257, 0.12756261575434888, 0.1599805626486029], [0.12140306484486375, 0.12365589610167912, 0.0981884276760476, 0.07037161995789834, 0.26408409220831736, 0.006726905420821692, 0.07834081697676863, 0.07556208036839962, 0.059736499562859535, 0.040577194786497524, 0.10400463986609663, 0.144927602527397, 17.79885118348258, 59.01627567836216, 37.11213173185076, 40.127076693943565, 31.877146993364605, 27.344010216849192, 30.76370164326259, 64.43168776375907, 36.54079873221261, 1.871857728276934, 14.524604661124092, 52.684229442051475, 64.37919412340436, 63.611779485430034, 59.72292831965855, 58.32961995261056, 55.632207666124614, 61.79168496813093, 55.263105460575645, 54.628995486668174, 54.772871834891184, 55.718841280256, 50.457349164145334, 42.00388935634068, 38.21598161969866, 42.15233414513724, 42.07308646610805, 38.175477096012656, 38.77882392065865, 39.872668402535574, 39.602327891758506, 39.892606258392334, 40.44741644178118, 39.174711431775776, 38.77496419634138, 38.23061800003052, 37.38989986692156, 39.58601699556623, 41.48392786298479, 39.69435330799648, 47.715030670166016, 51.8741910798209, 50.94607503073556, 51.02339111055647, 50.442566871643066, 51.64201354980469, 46.31396811349051, 43.0737486566816, 43.25384249005999, 49.561966078622, 50.97543464388166, 48.48431089946202, 47.92528315952846, 48.01521021979195, 46.87973213195801, 48.12619726998465, 49.90664536612374, 49.231475012642996, 45.82445362636021, 45.40086712156023, 49.16172899518694, 38.426258427756174, 42.97971173695156, 45.7924085344587, 44.32611976351057, 45.626826013837544, 36.64143296650478, 36.215053285871235, 32.9328875541687, 36.986372811453684, 33.236648900168284, 35.077306611197336, 33.47032724108015, 37.54733215059553, 25.799825191497803, 45.97256142752511, 75.60031945364815, 61.72997801644461, 47.699199199676514, 41.74973814828055, 40.12535006659371, 37.85965020315987, 36.81175763266427, 39.01696647916521, 38.02613598959786, 33.624677998679026, 35.33981302806309, 37.06338317053658, 36.580056054251536, 44.77609552655901, 37.44629144668579, 27.9640622479575, 47.478910037449424, 44.847120012555806, 43.507340567452566, 42.022948265075684, 46.44475405556815, 46.17719977242606, 45.297495297023225, 47.33119133540562, 46.54747969763619, 47.39226600102016, 47.3794778415135, 51.6132619040353, 49.75650521687099, 48.275392464229036, 51.975697313036235, 50.83719675881522, 48.27538551603045, 47.38394553320748, 46.26872491836548, 41.27209118434361, 42.33924763543265, 41.315736293792725, 42.81162786483765, 38.89282648903983, 38.94974265779768, 37.75442320959908, 39.110385009220664, 41.47590616771153, 42.41057436806815, 40.524180139814106, 42.19691726139614, 40.856380462646484, 38.78299631391253, 41.048320974622456, 45.05323484965733, 40.23068128313337, 42.35820232118879, 41.403641428266255, 43.1963391985212, 45.93768147059849, 44.939148902893066, 45.79700476782662, 45.07183517728533, 47.8675297328404, 55.98827505111694, 56.1315712247576, 57.39593144825527, 60.04995223454067, 62.7267735345023, 63.89750330788748, 56.530012198856895, 21.06642743519374, 0.8102248779364994, 38.76325648171561, 57.13882030759539, 27.89223003387451, 33.46732561928885, 28.935482944761002, 28.972760030201503, 27.652197565351212, 49.96505192347935, 19.18819907733372, 0.24018492177128792, 0.07426509460700409, 0.016779721481725574, 0.026524717586913278, 0.043956068477460315, 0.059496800282171795, 0.20836385499153817, 0.09484742980982576, 0.17191574935402187, 0.08139051297413451, 0.07080831831055028, 0.08879248185881547, 0.13631878447319778, 0.024253189297659055, 0.25694223972303526, 0.053841024304607084, 0.04743208124169281, 0.07793091397200312, 0.10044097394815513, 0.04868442279153636, 0.05656665536974158, 0.19904295514736856, 21.078369651521953, 69.49169949122837, 36.17509766987392, 46.45591286250523, 45.45097058159964, 29.02264288493565, 35.833979334150044, 69.2171414239066, 41.32699237551008, 2.8258566856384277, 14.385731884411403, 60.250873293195454, 68.1167552130563, 68.42753423963273, 62.927249908447266, 60.87010369982038, 57.82784536906651, 63.99858570098877, 61.09856741768973, 57.04134055546352, 56.58971112115042, 56.559656688145225, 53.477453163691926, 45.96909775052752, 40.772050176348, 43.29336036954607, 44.905172211783274, 42.80323791503906, 41.29560736247471, 42.18204116821289, 42.576545987810405, 43.79458604540144, 42.523774419512065, 41.143066610608784, 41.20160518373762, 39.57567112786429, 41.21750266211373, 43.59467942374093, 43.73402207238333, 42.0801215171814, 49.635863644736155, 54.187632015773225, 53.64495686122349, 53.49737712315151, 53.21131978716169, 53.0518273626055, 48.211507252284456, 45.341675417763845, 46.38059091567993, 51.37755816323416, 50.79244341169085, 49.463510104588096, 50.570952211107524, 50.46945987428938, 50.0319561277117, 51.57709305627005, 52.89610433578491, 53.14783409663609, 47.95711285727364, 48.24189519882202, 51.262961523873464, 41.817059244428364, 44.141321999686106, 49.160780566079275, 46.42125524793352, 45.9084712437221, 35.36998905454363, 37.107684884752544, 35.76333005087716, 38.01298999786377, 34.45425469534737, 36.29058020455496, 34.28782796859741, 39.49945286342076, 24.965261425290787, 42.62676061902727, 68.16104303087506, 59.92818505423409, 48.71555389676775, 40.60574851717268, 38.87339237758091, 36.358092376164024, 34.04931715556553, 37.567617416381836, 36.84027998788016, 32.71087523869106, 34.34034940174648, 38.02330459867205, 37.550594329833984, 46.289757115500315, 40.089750971112935, 31.095693520137242, 51.43356759207589, 46.83225161688668, 45.24744742257254, 44.08910976137434, 49.50568219593593, 48.73247970853533, 49.41729416166033, 50.70377744947161, 50.297043800354004, 49.58626740319388, 50.705128874097554, 51.82326078414917, 51.798191683632986, 51.91403899874006, 55.167553833552766, 53.99370084490095, 51.61649281638009, 49.87479829788208, 48.109754358019146, 43.227189200265066, 45.216732910701204, 43.45988089697701, 46.09582941872733, 39.81504699162075, 42.03240476335798, 40.65041501181466, 43.36054597582136, 44.960507665361675, 45.13463647024972, 42.05240167890276, 44.022073541368755, 43.287916455950054, 41.11828933443342, 41.60084867477417, 49.51899494443621, 43.30196223940168, 44.00031525748116, 41.932798862457275, 46.572986534663606, 46.92287697110857, 47.24183055332729, 47.935069697243826, 46.38469730104719, 52.12766136441912, 58.68010793413435, 59.060250827244346, 60.04292065756661, 60.22261496952602, 64.6834487915039, 66.9252711704799, 60.52866227286202, 20.268006461007253, 1.3085645543677467, 44.947618756975444, 63.08901786804199, 32.60686765398298, 38.37972981589181, 38.595276832580566, 33.59396696090698, 31.55272170475551, 57.761298997061594, 25.401085444859095, 0.25786974281072617, 0.14068342026855263, 0.02202266318324421, 0.03915668172495706, 0.03142682097053953, 0.09442500783396618, 0.23946241768343107, 0.09700912024293627, 0.16046695012067044, 0.04700861092922943, 0.185032455516713, 0.2303435041436127, 0.39267825761011665, 0.12054611582841192, 0.34647927805781364, 0.17348777928522655, 0.19989068965826715, 0.09436258939760071, 0.18198337698621408, 0.3118912268962179, 0.25952373977218357, 0.32240376994013786, 28.331571578979492, 78.98373780931745, 47.10682705470494, 55.13807610103062, 48.74207169669015, 36.55683517456055, 41.69896418707711, 75.79508440835136, 41.438611711774556, 3.667544960975647, 17.710820981434413, 64.37653991154262, 68.68998159681047, 68.300368309021, 64.46940953390938, 61.9670227595738, 60.153278895786826, 64.84423010689872, 65.18114825657436, 57.98008040019444, 59.14563723972866, 59.45387322562081, 55.9273567199707, 49.35359307697841, 43.438122613089426, 46.81073651994978, 47.55641024453299, 45.19196605682373, 42.800316197531565, 43.49839128766741, 43.61097294943673, 44.88481746401106, 44.71017101832798, 43.046449184417725, 42.85730184827532, 41.79682261603219, 43.41101769038609, 46.234609263283865, 45.510735511779785, 44.087442193712505, 52.679942403520855, 56.25784083775112, 55.124815464019775, 55.70679310389927, 56.710693155016216, 55.10639231545584, 50.939574990953716, 47.02342782701765, 46.270858015332905, 54.78957183020455, 55.899668148585725, 52.33547156197684, 52.70152350834438, 51.59493603025164, 51.267908641270225, 55.44864668164934, 54.27609995433262, 56.150835105351035, 49.87780686787197, 50.163561957223074, 52.6019731930324, 46.3236608505249, 48.798744678497314, 55.105648858206614, 49.739999771118164, 41.38211938313076, 34.13847296578543, 38.86237948281424, 37.75861644744873, 40.81382622037615, 36.78835262571062, 38.0426344871521, 34.733801569257466, 44.19749471119472, 28.041301897593907, 43.28451531273978, 67.64847442081997, 60.60047885349819, 52.031446184430806, 45.257133211408345, 40.39852891649519, 38.187157017844065, 36.29733732768467, 39.46187353134155, 39.17535066604614, 33.50769812720162, 37.49744755881173, 39.15956088474819, 37.79165513174874, 47.223671436309814, 43.941081864493235, 32.82997778483799, 55.4267007963998, 50.320747579847065, 47.00225666591099, 46.887600966862266, 53.34672628130232, 54.18907724108015, 54.19270420074463, 52.27285092217581, 53.199789251599995, 51.43172631944929, 52.25030401774815, 54.386267117091585, 53.93672909055437, 51.87394094467163, 57.91324915204729, 54.84339257649013, 52.36234719412667, 50.60790620531355, 50.487643310001914, 44.23535197121756, 47.54380621228899, 47.11248288835798, 49.23723159517561, 41.056499004364014, 43.86799723761422, 43.22228029796055, 45.12760489327567, 46.98423998696463, 47.322988986968994, 46.58055659702846, 45.25468397140503, 47.364928313664024, 43.02003560747419, 44.407563073294504, 52.57926648003714, 47.096244948250906, 48.05504076821463, 46.958906854902, 49.15223775591169, 52.06807361330305, 48.880253996167866, 51.11500310897827, 49.00211150305611, 53.92812722069876, 62.23224244798933, 60.38400077819824, 64.40777206420898, 63.53805215018136, 66.68566949026925, 68.77271379743303, 67.27662072862897, 24.478705133710587, 2.1936157771519254, 46.02366542816162, 72.50331279209682, 38.00569091524397, 45.749989782060894, 42.97811017717634, 29.74626997538975, 40.13105801173619, 69.44976016453334, 28.18993776185172, 0.47088115555899485, 0.2916543542274407, 0.1312125777559621, 0.2125667958919491, 0.0988557261547872, 0.12715287559798785, 0.3795479807470526, 0.20254765637218952, 0.21387422430728162, 0.18821885596428597], [0.09565199592283793, 0.17521158392940248, 0.04868728281663997, 0.07219198013522796, 0.2252368495932647, 0.17403839688215936, 0.0649588443338871, 0.051125058970813236, 0.18083092596914085, 0.05968079862317868, 0.11029871034302882, 0.21890360728970595, 15.628160987581525, 56.53281579698835, 50.07619878223964, 36.570269516536165, 26.0326315334865, 33.66649225779942, 34.2464097567967, 49.921726431165425, 49.45071152278355, 4.009400240012577, 9.887659192085266, 62.16246863773891, 63.92665794917515, 66.76272501264299, 59.63244192940848, 56.85583060128348, 58.721512249537874, 62.37849508013044, 51.72318240574428, 57.42516251972744, 49.9237414087568, 51.62877375738961, 46.407536029815674, 42.24772596359253, 37.995654242379324, 39.924894537244526, 38.250236238752095, 39.26814733232771, 38.473388058798655, 40.460902895246235, 38.471011774880544, 40.28395659582955, 38.714626039777485, 38.432706356048584, 36.524015358516145, 39.05157198224749, 37.34410081590925, 40.94378532682146, 44.33049018042428, 42.57338455745152, 43.41822992052351, 50.50152581078665, 49.98445129394531, 53.33232266562325, 52.14486163003104, 54.84296873637608, 47.50480597359793, 42.718980584825786, 46.04156746183123, 51.592660495213096, 48.84728479385376, 49.63535990033831, 52.16560895102364, 51.03474794115339, 47.92381361552647, 50.74107885360718, 53.734974248068674, 47.9957309450422, 45.14523247310093, 45.04705442701067, 47.67367499215262, 39.67852183750698, 38.66786118916103, 44.528260231018066, 36.546319075993125, 36.90109062194824, 39.8589630808149, 39.50821801594326, 39.03947516850063, 42.0752716745649, 34.967087336948936, 41.32633229664394, 37.26741007396153, 55.94351128169468, 43.387904507773264, 46.45553765978132, 52.31195190974644, 36.738669531685964, 36.564148153577534, 33.82752023424421, 38.88474225997925, 35.06179475784302, 39.13682637895857, 36.13559021268572, 34.800532068525044, 33.135187830243794, 36.13836254392351, 39.14271150316511, 40.44525555201939, 47.9507691519601, 35.288976533072336, 37.50701175417219, 50.86681692940848, 45.276032311575754, 46.21242019108364, 46.55342040743147, 47.68065793173653, 49.51145267486572, 48.17211444037301, 44.15407541819981, 48.13506317138672, 46.36406462533133, 47.83729812077114, 49.58023984091622, 48.035116808755056, 45.70769957133702, 46.69299929482596, 48.47753293173653, 50.38739470073155, 45.89555106844221, 39.62405490875244, 38.84951836722237, 42.20829841068813, 42.385866573878694, 38.89439330782209, 38.83817890712193, 38.116316659109934, 39.69697625296456, 39.84901326043265, 39.29365416935512, 40.438734667641775, 38.948092460632324, 41.44711978094918, 41.22870315824236, 37.90626219340733, 40.7677457673209, 43.84294203349522, 43.51709931237357, 41.786883217947825, 40.71812520708357, 43.81162650244576, 42.564480440957205, 45.081340312957764, 44.826212882995605, 46.7805118560791, 49.940444878169465, 59.660283361162456, 55.215986251831055, 62.67345305851528, 60.99986130850655, 65.1366936819894, 61.66399792262486, 40.877732276916504, 10.959027988570076, 2.971615344285965, 54.94991888318743, 48.185705116816926, 27.326144661222184, 24.627922909600393, 23.511297021593364, 28.20335647038051, 28.860305173056467, 50.35156284059797, 25.076370068958827, 0.07229339397911515, 0.12253074933375631, 0.24228667042085103, 0.11657528818718024, 0.12607100579355443, 0.37096017013703075, 0.6494870973484856, 0.17969720251858234, 0.38128964443291935, 0.12573392316699028, 0.11135957948863506, 0.08032254635223321, 0.16762054126177514, 0.07131416616695267, 0.26417094469070435, 0.2604398706129619, 0.016653072920494845, 0.011480471551684397, 0.290019084832498, 0.009358646747257029, 0.13154178937630995, 0.2685458670769419, 19.54886964389256, 67.67690644945417, 49.64006730488369, 38.7570343698774, 31.3899427822658, 38.94298553466797, 40.95922074999128, 53.320500305720735, 56.712263447897776, 5.51190128496715, 12.522242392812457, 68.38023090362549, 65.13526930127824, 69.96425342559814, 61.411465644836426, 59.5790867124285, 60.47581427437918, 66.11545167650495, 57.14594915934971, 60.74607835497175, 52.910341194697786, 54.19707809175764, 49.16478272846767, 47.715398924691335, 41.0759539604187, 42.39011539731707, 42.53766386849539, 42.904264722551616, 41.89987482343401, 43.61232784816197, 41.8567647252764, 42.99890960965838, 40.62191002709525, 38.81352322442191, 38.02696629932949, 41.28819016047886, 40.801448004586355, 44.19541025161743, 47.824989386967246, 44.88815259933472, 45.27274581364223, 53.3238319669451, 53.099293981279644, 55.22136068344116, 53.85468128749302, 55.574548040117534, 50.227954387664795, 44.30363539287022, 49.00376517432076, 54.01114777156285, 50.5470677784511, 51.626550333840505, 51.67636891773769, 53.93235172544207, 50.039616516658235, 52.402184690747944, 56.399705682482036, 53.088162967136924, 46.89761332103184, 44.94480126244681, 48.071525369371685, 42.12851224626814, 40.65095002310616, 47.89486394609724, 40.140823704855784, 39.760986532483784, 40.17576619556972, 39.873012338365825, 39.776515756334575, 42.349433694567, 37.005025250571116, 44.2265625, 39.42351600102016, 55.92899996893746, 48.11115789413452, 53.005309173039024, 55.15502970559256, 41.85666397639683, 34.72437981196812, 33.509598459516255, 33.80094337463379, 32.41250569479806, 37.349735804966514, 36.4684853553772, 34.516350746154785, 32.58450140271868, 34.95009551729475, 37.62342187336513, 42.30841153008597, 49.13258477619716, 38.351474966321675, 41.580709321158274, 52.77406964983259, 45.67078379222325, 48.51063414982387, 48.58742911475045, 51.67149823052542, 52.12656354904175, 52.470641817365376, 47.63250344140189, 51.32563427516392, 47.08373819078718, 51.26150240216936, 50.028554984501426, 50.4304735319955, 46.315243107931956, 47.668766089848106, 48.04997900554112, 52.9159449168614, 45.88135937282017, 40.339184352329795, 38.52604150772095, 45.15235785075596, 45.32164028712681, 42.597682407924104, 40.99403469903128, 40.13256924492972, 40.0591059412275, 41.34681211199079, 42.08232062203543, 43.82185425077166, 40.52578517368862, 42.26870257513863, 42.39123405729021, 41.092275278908865, 42.4157646724156, 47.60146236419678, 48.518131256103516, 45.02848884037563, 43.48352561678205, 46.08522299357823, 44.15412058149065, 48.958587987082346, 45.9900917325701, 47.08695520673479, 52.484788349696565, 63.09921087537493, 57.61249985013689, 65.14412825448173, 62.13121564047677, 66.36831051962716, 63.69608197893415, 46.17649800436837, 9.200445004871913, 4.867623925209045, 63.164628165108816, 53.99708809171404, 35.05894252232143, 34.39621639251709, 31.655648844582693, 32.53970289230347, 34.859734194619314, 59.19214848109654, 29.446430887494767, 0.07920360817973103, 0.17482454755476542, 0.2379879882293088, 0.10702307575515338, 0.008206305143955563, 0.20552482376141207, 0.4774301584277834, 0.18248077029628412, 0.22884649304406984, 0.10363660247198173, 0.2599252967962197, 0.315711541899613, 0.430669406162841, 0.16945601919932024, 0.3663496875337192, 0.33938106894493103, 0.16197571344673634, 0.14745988164629253, 0.41072091087698936, 0.2262766095144408, 0.2636439401124205, 0.4501442297228745, 26.305164200919016, 75.42577375684465, 67.55538245609829, 50.466385296412874, 38.58202314376831, 43.92247806276594, 47.30808162689209, 60.3688120160784, 57.68925312587193, 5.554230579308101, 14.071906072752816, 70.98120566776821, 64.06835951123918, 69.47421782357353, 62.562316622052876, 61.412563460213796, 59.33157798222133, 68.76648126329694, 62.30177307128906, 62.65617983681815, 54.87902293886457, 56.89104754584176, 52.86719635554722, 50.726095063345774, 43.32855994360787, 44.9103764125279, 45.179740701402935, 44.72694396972656, 43.90657711029053, 46.54645136424473, 43.27171325683594, 45.189311844961985, 42.84191506249564, 41.97139957972935, 39.49081972667149, 44.03722408839634, 42.88477502550398, 45.92835351399013, 49.175830364227295, 45.498489311763215, 46.91887133462088, 54.599927697862896, 54.48247882298061, 57.75800902502877, 55.500143255506245, 59.102947507585796, 52.921378408159526, 45.927033356257844, 51.24591759272984, 58.047015871320454, 53.24194744655064, 55.300632681165425, 57.79048490524292, 54.98483010700771, 53.14839342662266, 55.379935945783345, 59.96187686920166, 53.70981134687151, 47.794573647635325, 49.09544665472848, 49.86948987415859, 47.10649701527187, 43.816108090536936, 50.280427183423726, 46.23984473092215, 46.69759552819388, 45.26378958565848, 40.07090745653425, 38.76390961238316, 41.47493689400809, 38.15589707238333, 45.85219430923462, 41.174965790339876, 55.51553004128592, 54.124486786978586, 58.497273036411826, 63.9481417792184, 49.40472487040928, 40.9279990196228, 33.334382261548726, 35.94595650264195, 34.31360231127058, 38.84042664936611, 37.231203011104036, 37.37460688182286, 35.191260542188374, 37.012063775743755, 40.56728676387242, 44.417554582868306, 51.52598558153425, 40.84071922302246, 42.606423241751536, 56.27304002216884, 49.51870659419468, 52.44155318396432, 54.12981605529785, 54.91507019315447, 56.146641867501394, 55.57028879438128, 49.38437359673636, 55.33743381500244, 52.86676556723458, 52.30125515801566, 54.271291800907676, 51.95166002001081, 49.151734011513845, 51.4773725100926, 52.731317383902415, 56.48728772572109, 49.26752226693289, 41.96322154998779, 39.4750577381679, 47.05386093684605, 45.9742602620806, 43.998303753989084, 41.36475930895124, 42.224147251674104, 42.418669019426616, 44.06497866766793, 44.4022650718689, 46.56054925918579, 42.46690341404506, 45.89232363019671, 45.63696343558175, 44.380722182137625, 44.39452130453927, 51.17602218900408, 52.72449772698538, 49.209386689322336, 46.59188910893032, 49.09721497126988, 47.61240577697754, 51.6674404825483, 47.738216808864046, 48.41395691462925, 51.9770313671657, 64.31547914232526, 58.96888896397182, 67.33163656507219, 64.3773250579834, 69.62047045571464, 66.73012406485421, 54.101700169699534, 10.918024931635175, 5.0090023960386, 66.75032247815813, 64.61991446358817, 39.28133501325335, 35.78059632437569, 35.107249873025076, 37.03397492000035, 40.95184176308768, 66.43671553475517, 37.16439955575125, 0.37443994198526653, 0.3808074774486678, 0.49539613723754883, 0.22450870009405272, 0.2536634499473231, 0.28661213336246355, 0.6493985620992524, 0.30148716803107944, 0.44001381046005655, 0.19370777000273975], [0.03481010174644845, 0.01674166414886713, 0.20415298880210944, 0.025204739666410854, 0.06679775565862656, 0.10394157682146345, 0.23219837461199078, 0.0076938313930960634, 0.014524683289762055, 0.03460615447589329, 0.24229266867041588, 0.1155986048813377, 13.326591917446681, 57.585936886923655, 30.12436314991542, 40.246418952941895, 51.59502288273403, 21.61494255065918, 40.85031121117728, 45.93776484898159, 66.2038744517735, 12.27219409602029, 7.298001306397574, 60.64583669389997, 64.15751879555839, 67.38139261518205, 60.36503914424351, 63.771476881844656, 58.839096614292686, 58.157627718789236, 53.41995334625244, 54.75203766141619, 52.86018909726824, 45.57100418635777, 42.87940754209246, 39.58697932107108, 38.37794412885393, 42.01204306738717, 39.82190138953072, 39.90513038635254, 39.986188071114675, 41.07354293550764, 40.28858062199184, 40.706889969961985, 39.87857437133789, 40.13222183500017, 37.90770394461495, 40.18066814967564, 37.369906425476074, 37.71986634390694, 43.65099457332066, 45.531924043382915, 43.53981992176601, 49.019006047930034, 53.61442647661482, 50.94651971544538, 51.063193866184776, 53.38043546676636, 49.150705678122385, 48.25151150567191, 49.97511638913836, 51.09314407621111, 50.34662961959839, 49.67903627668108, 49.58096592766898, 50.39296020780291, 49.93721396582467, 49.30681085586548, 50.86630276271275, 48.493895939418245, 48.39432825360979, 44.080504417419434, 49.31830317633492, 40.67842320033482, 40.159920828683035, 42.48337411880493, 46.717700140816824, 38.280856949942454, 29.202681132725306, 32.88575792312622, 36.99363367898123, 36.40198414666312, 34.652045590536936, 37.9863714490618, 41.791899817330496, 56.301666600363596, 62.13746207101004, 37.418595927102224, 36.140037059783936, 34.357914447784424, 38.11682735170637, 32.12573964255196, 31.90316104888916, 32.843245370047434, 36.89342328480312, 39.11974423272269, 39.10600069590977, 36.62196411405291, 35.533949170793804, 41.75299685341971, 47.112621852329795, 48.50924103600638, 38.836462702069966, 43.80264942986624, 48.5041514805385, 43.87328134264265, 44.696375370025635, 44.439427512032644, 47.46003525597708, 46.969450746263774, 45.74117946624756, 44.81492900848389, 43.25886951174055, 43.055926527295796, 48.398368631090435, 47.1698819569179, 46.80470895767212, 45.93993616104126, 45.38966315133231, 40.41691384996687, 42.438561711992534, 37.705473150525776, 38.25034046173096, 40.95106356484549, 45.204986980983186, 40.02892991474697, 41.64565413338797, 39.47381748471941, 38.63192858014788, 39.18950762067522, 39.47868469783238, 37.05193601335798, 40.67284032276699, 37.21826546532767, 39.810662678309846, 38.26033197130476, 42.78997032982962, 44.57354858943394, 46.90665292739868, 43.66606174196516, 46.61946650913784, 45.00903735842024, 47.5082175391061, 42.47810391017369, 43.48403978347778, 44.815999031066895, 49.772458280835835, 55.79421533857073, 60.605481556483674, 61.30122552599226, 63.96208681379046, 60.11082540239607, 70.21518761771065, 56.602071966443745, 30.334685121263774, 5.385891795158386, 11.838933961732046, 59.1515223639352, 40.948444093976704, 25.953611407961162, 20.048005649021693, 27.53441343988691, 39.001808983939036, 39.3694485936846, 49.18002707617623, 18.081340619495936, 0.1569719383759158, 0.05886709264346531, 0.12101849833769457, 0.06241172565413373, 0.05413903009944728, 0.0634277029229062, 0.04813945399863379, 0.10372513093586479, 0.1777175087481737, 0.06122145988047123, 0.07618381522063698, 0.02880514825561217, 0.09464213903993368, 0.06290335141654525, 0.10817821377090045, 0.01748820873243468, 0.150064492598176, 0.048155457247048616, 0.08967206001813922, 0.05608467498262014, 0.37514328424419674, 0.19075456847037586, 16.253863641193934, 64.49642413003104, 38.842271396092, 46.889668055943076, 50.391355173928396, 31.5190646307809, 46.14731209618704, 53.77420377731323, 71.88782051631382, 16.99541882106236, 7.028873256274632, 63.33925029209682, 65.86014011928013, 70.20118004935128, 62.993278639657156, 64.86601965767997, 60.19163295200893, 63.82429013933454, 57.03700835364205, 59.24248123168945, 56.0075979913984, 49.38322714396885, 45.86914791379656, 44.55176598685128, 41.857935496738975, 46.171290329524446, 45.19704518999372, 44.11465828759329, 43.44519240515572, 44.70010655266898, 43.333545276096885, 43.20415244783674, 41.968366691044395, 42.429431779044016, 39.70703724452427, 44.0388708114624, 39.88867705208914, 38.277907439640586, 44.64253725324358, 48.33535194396973, 45.3532406943185, 50.738831111363, 55.11343778882708, 55.34253379276821, 54.03515379769461, 56.10235404968262, 51.258726596832275, 50.408485957554404, 50.464783736637656, 52.34901360103062, 50.84875856127058, 52.771095820835654, 49.24688264301845, 53.538611207689556, 53.7379480770656, 52.48228699820382, 52.270985330854145, 50.30203260694231, 50.22473042351859, 46.446623120989116, 50.535676206861226, 43.36233513695853, 40.67740528924124, 46.23133666174752, 48.510359695979524, 41.753292151859824, 32.38078022003174, 34.93738031387329, 36.5358099256243, 38.3851181438991, 34.81261845997402, 37.11030782972063, 40.151833125523154, 53.467343534742085, 63.52866513388497, 40.23690686907087, 35.48967177527291, 31.219743183680944, 35.47354848044259, 30.769506863185338, 27.894048724855693, 31.438458578927175, 34.70516109466553, 37.633885860443115, 38.32823671613421, 37.382434027535574, 36.69622646059309, 42.53974832807268, 48.74457999638149, 51.82574823924473, 42.013283320835654, 45.06557832445417, 50.47352457046509, 43.94116871697562, 45.9178478377206, 49.21855136326381, 50.240791184561594, 49.626216070992605, 50.07629605701992, 49.62405170713152, 46.409801142556326, 46.96786655698504, 51.62021705082485, 50.80765649250576, 49.208816937037874, 48.743152141571045, 48.20519133976528, 43.399935313633506, 42.207839829581125, 37.417609282902305, 37.94186128888811, 42.31388323647635, 48.02449648720877, 41.896327768053325, 43.883609839848106, 41.744537421635215, 42.1518269266401, 41.71144315174648, 40.95088985988072, 40.904847621917725, 40.49043273925781, 38.911930561065674, 41.919461795261924, 41.194260937826975, 46.0705622945513, 47.987035274505615, 48.64505052566528, 48.1221603666033, 50.96115262167794, 49.07895857947213, 51.60576132365635, 47.234552315303254, 45.048249517168315, 46.56364468165806, 51.828187056950156, 57.27935804639544, 60.44367190769741, 61.11691761016846, 64.47617013113839, 63.128636496407644, 71.08785356794084, 60.04009968893868, 31.69841500691005, 3.5274269367967332, 15.348603691373553, 66.2682773045131, 43.45614276613508, 32.9108304977417, 26.661485195159912, 33.94815138408116, 43.447315079825266, 46.64252063206264, 57.041496889931814, 27.365924835205078, 0.08893720659294299, 0.10266125588012592, 0.17661699280142784, 0.03568402770906687, 0.08723863666611058, 0.04958343080111912, 0.029882889174457108, 0.10380739652152572, 0.15861535019108228, 0.14156668287302765, 0.17753491497465543, 0.0871538876422814, 0.21814946989927972, 0.18392003806574003, 0.1333297970039504, 0.2679871070597853, 0.24983624102813856, 0.15530291864914553, 0.16965092159807682, 0.17127234887863907, 0.37015664896794725, 0.25642704165407587, 20.657260179519653, 78.43940898350307, 43.81623315811157, 55.29537289483206, 70.26463099888393, 29.914465018681117, 56.5573742049081, 60.470957483564106, 75.09096785954067, 16.86153050831386, 10.280777846063886, 65.88771751948765, 67.90780898502895, 71.72876235416958, 63.0193760735648, 64.87187004089355, 63.540761947631836, 67.74586037227085, 57.589417934417725, 62.20053781781878, 56.53199590955462, 51.332488673073904, 50.270779609680176, 47.84128638676235, 43.852815423692974, 48.83786998476301, 47.15358148302351, 47.45749568939209, 44.234764848436626, 45.80799681799752, 45.15687417984009, 46.03685310908726, 44.847349303109304, 45.06019694464547, 41.370592321668354, 47.451325689043315, 41.05549151556832, 41.15517732075283, 48.33471270969936, 50.90093605858939, 45.24422345842634, 52.607312883649556, 57.20551259177071, 56.086060523986816, 55.69914313725063, 58.06154455457415, 52.21232863834926, 52.953930718558176, 54.32804816109793, 57.13512734004429, 52.88981621606009, 54.025877952575684, 53.29750176838466, 57.57953759602138, 57.53615651811872, 55.793266909463064, 57.10688291277204, 54.47200093950544, 51.503820828029085, 49.35174485615322, 53.772369452885215, 46.55463286808559, 45.91142422812325, 49.77468170438494, 51.32072537285941, 42.7623998778207, 35.0507401738848, 38.372243131910054, 37.93611512865339, 41.35438217435564, 36.634804385049, 39.812385831560405, 42.21299191883632, 61.042710849217, 53.96190588814871, 38.065910952431814, 41.489024366651265, 34.11134025028774, 36.724651541028706, 31.056015832083567, 30.3333614894322, 32.78011751174927, 35.320847920009065, 39.85277918406895, 39.88862494059971, 38.123674801417756, 38.77047218595232, 44.25499105453491, 51.64156886509487, 53.994736126491, 46.06469801494053, 45.2178133555821, 54.599764415196006, 45.794958523341585, 50.54627915791103, 51.142198358263286, 54.39320836748396, 52.4311135155814, 54.34534222739083, 53.58798163277762, 50.952026162828716, 50.017020974840435, 54.20131996699742, 54.16534219469343, 52.31954281670706, 51.769224643707275, 52.15377269472395, 44.7095422063555, 46.63195937020438, 39.690986905779155, 38.66739913395473, 42.359053475516184, 50.574957847595215, 43.92685195377895, 46.744377749306814, 40.553505011967246, 44.60207094464983, 43.827444076538086, 43.47113003049578, 44.58782366343907, 45.04802022661482, 40.09800543103899, 44.295193331582205, 42.05333273751395, 47.206922803606304, 49.101439476013184, 52.612944398607524, 50.45544188363211, 50.980281012398855, 51.718843255724224, 55.530899456569124, 48.3673483984811, 50.871708461216514, 48.76907934461321, 55.78372703279768, 60.28953307015555, 65.49489416394914, 63.354070799691335, 69.40224838256836, 63.19195543016706, 74.21004050118583, 63.94544587816511, 40.21868174416678, 4.274506151676178, 15.834336621420723, 72.94142450605119, 55.83937862941197, 36.007979597364155, 28.311263731547765, 43.558774607522146, 60.664874758039204, 58.06675222941807, 65.41610159192766, 35.45720631735665, 0.29481103484119686, 0.20527987261968, 0.20364017917641572, 0.22188678649919374, 0.19966990793389933, 0.15475148681019033, 0.11377463489770889, 0.24228870602590696, 0.22689442921962055, 0.2468902591083731], [0.3482481917100293, 0.08478571221764598, 0.15015095153025218, 0.13543744890817574, 0.021259740460664034, 0.12010429453636919, 0.10063992041562285, 0.07014278402285916, 0.04786024023113506, 0.03559648651363594, 0.17729432002774306, 0.0546200164327664, 12.513765590531484, 65.72730445861816, 37.27237803595406, 30.01387984412057, 44.78645529065813, 21.7611118044172, 28.23336226599557, 43.09169932774135, 65.736191204616, 30.193313598632812, 1.3542734959295817, 51.701128823416575, 65.9167401450021, 60.677763666425435, 63.27058124542236, 60.72876344408308, 53.198580265045166, 57.99573816571917, 54.791611126491, 57.96534674508231, 47.513880320957725, 41.69358280726841, 41.747042247227256, 43.59728847231184, 41.81680563517979, 39.99636370795113, 41.67926951817104, 45.07742847715105, 42.01997791017805, 39.607712745666504, 39.45815971919468, 40.76393468039376, 40.6071138381958, 41.38718809400286, 39.55154698235648, 40.304901940482004, 38.48361233302525, 36.0303840637207, 41.296639169965474, 46.06619535173689, 44.670597553253174, 47.21589987618582, 52.78669800077166, 52.62285600389753, 55.28699336733137, 50.72704349245344, 49.47588832037789, 46.866120610918315, 48.561581815992085, 48.43265104293823, 49.786458900996614, 49.76148360116141, 49.72656890324184, 49.19362122671944, 46.555313791547505, 47.02734661102295, 43.58910696847098, 45.19687843322754, 45.90898193631853, 43.288347244262695, 45.672138690948486, 41.69373219353812, 38.50771910803658, 45.62677737644741, 41.02555867603847, 44.31645481927054, 31.140321799686976, 32.446635246276855, 30.958105291639054, 28.791870628084453, 29.636161872318812, 33.95239673342024, 33.60144322259085, 32.23919677734375, 43.71597065244402, 43.794933455330984, 39.562427861349924, 43.363971437726704, 42.221336705344065, 41.13084820338658, 33.60802664075579, 33.21263245173863, 32.54664414269583, 35.86647258486067, 37.60992499760219, 35.05308519090925, 34.175041334969656, 43.6226806640625, 48.52293940952846, 51.87983649117606, 36.668061937604634, 45.93827901567732, 49.10503169468471, 46.37802355630057, 48.1031813621521, 47.805635179792134, 46.34267112186977, 47.54112768173218, 44.38931710379464, 43.630375794001985, 44.10472583770752, 45.667677947453086, 47.706008434295654, 48.26015853881836, 49.43666573933193, 45.842192377362935, 43.11144610813686, 41.509382588522776, 34.69639594214303, 36.19893346514021, 37.07701553617205, 42.928461824144634, 43.15705408368792, 39.92897660391671, 41.078194754464285, 41.11279330934797, 38.4728877885001, 40.206852436065674, 39.409240927015034, 37.062608446393696, 38.90021242414202, 39.386697496686665, 39.60663577488491, 41.8775954246521, 47.028670242854524, 48.35747153418404, 48.814840180533274, 49.77157585961478, 52.40730551310948, 51.29922764641898, 49.62871047428676, 46.77248668670654, 45.045015130724224, 44.576244490487234, 47.26593385423933, 52.96702807290213, 60.15230614798409, 60.22405324663435, 64.571471623012, 60.54489326477051, 67.94013200487409, 48.33822154998779, 20.496157509940012, 1.3404092341661453, 21.466183355876378, 59.21166597093855, 36.235717228480745, 23.578234229769024, 25.236944675445557, 32.10374859401158, 33.47932168415615, 29.807087557656423, 55.3976469039917, 22.742251293999807, 0.10967030549155814, 0.11497828816728932, 0.10109933612069913, 0.054825850030673404, 0.008205883604075228, 0.06563498412391969, 0.07540959319365875, 0.06243839208036661, 0.04984908404627016, 0.08631708433053323, 0.175096260117633, 0.049393220472016504, 0.13383789759661469, 0.07007058111152478, 0.06764996850064822, 0.08784511805112873, 0.06623502621161086, 0.02989083481952548, 0.04082364209794572, 0.051354654865073304, 0.12452588656118938, 0.1274196891380208, 17.04267873082842, 74.30409826551164, 43.26609911237444, 37.159403800964355, 47.94691637584141, 28.780541590281896, 38.33872849600655, 47.351827485220774, 71.90622629438127, 35.3659382547651, 2.2497170524937764, 53.74349968773978, 68.15053040640694, 63.584570339747835, 64.7372486931937, 61.3447698865618, 55.617237772260395, 60.00681781768799, 57.59907245635986, 60.60285513741629, 49.19711964470999, 44.53824131829398, 45.49646738597325, 46.684275831495015, 46.452789647238596, 42.76320934295654, 44.64265884671892, 46.80890219552176, 44.53870684759957, 40.802201884133474, 41.97955676487514, 43.28195142745972, 43.19805540357317, 44.64007759094238, 42.61209644590105, 43.41782692500523, 40.900268759046284, 38.31641435623169, 45.22964266368321, 47.66750499180385, 45.67130838121687, 48.29849175044468, 52.99561991010393, 54.3293787411281, 58.73819487435477, 53.96324341637747, 51.13315527779715, 49.648700441632954, 50.09192255565098, 51.6088011605399, 52.740339619772776, 53.71791989462716, 52.16642536435808, 50.70779350825718, 48.07724026271275, 48.38181454794747, 49.03339924131121, 47.02114534378052, 47.68346152986799, 46.02772317613874, 48.65986408506121, 43.80663422175816, 41.35977745056152, 45.414958068302695, 42.98046561649868, 45.53987625667027, 32.61458362851824, 33.64855200903756, 31.50559902191162, 29.05859981264387, 31.095905440194265, 33.05731242043631, 32.939321586063926, 31.895101138523646, 38.1898181779044, 40.79013633728027, 36.215994766780305, 39.53724411555699, 39.59189864567348, 40.18627882003784, 32.158104351588655, 31.365405218941824, 29.874200207846506, 34.475867067064556, 37.54581049510411, 36.24124799455915, 34.15323093959263, 45.87970222745623, 47.52791220801217, 53.112801279340474, 39.0591698374067, 49.56288324083601, 49.72944893155779, 47.43728685379028, 51.762946946280344, 49.908681188310894, 49.87276247569493, 50.89225775854928, 47.90965666089739, 49.35312754767281, 46.69205433981759, 49.41145420074463, 50.4975722857884, 51.99382863725935, 51.90641335078648, 48.3293764931815, 46.83928319386074, 43.24567140851702, 35.18528161730085, 38.03714541026524, 38.16209486552647, 45.02459437506539, 45.67183991840908, 43.204027380262104, 44.7029379435948, 43.85886035646711, 40.09621626990182, 41.4684715952192, 40.26127072743007, 37.34076220648629, 39.68511915206909, 41.945326464516775, 42.86244698933193, 43.610893045152935, 50.35426568984985, 51.65804999215262, 50.77229363577706, 53.18404810769217, 56.137279169900076, 54.17324229649135, 51.853697368076865, 50.24821533475603, 47.990071637289866, 48.05452312741961, 50.02775246756417, 59.097562653677805, 62.8399110521589, 60.70917647225516, 65.22150339399064, 63.038282121930806, 70.84105355398995, 54.60643121174404, 18.303849731172832, 0.9585942136389869, 26.809118781770977, 65.50328758784703, 43.887622424534385, 32.97144658224923, 28.30837675503322, 38.16089630126953, 37.97241251809256, 36.65761184692383, 62.59371553148542, 36.33543430055891, 0.07723737654409238, 0.21170745843223163, 0.08133344817906618, 0.026292341395414302, 0.013613043502638382, 0.04505134274118713, 0.06751823771212782, 0.09775445703417063, 0.019752291796196784, 0.1611386997891324, 0.2729020890380655, 0.13487501123121806, 0.17080764738576754, 0.1633679044565984, 0.09413133787789515, 0.24848913188491548, 0.17525346311075346, 0.09734713246247598, 0.36259546184114044, 0.11325067015630857, 0.3274120640541826, 0.31950729393533295, 20.82566019466945, 84.46403217315674, 48.80530030386788, 39.07037728173392, 59.8037497656686, 29.29725306374686, 39.55986050197056, 54.742918150765554, 77.29929992130825, 36.32640164239066, 3.026730843952724, 58.76258305140904, 68.23990508488247, 64.7959818158831, 67.45784364427838, 63.630518777029856, 56.67937414986746, 62.554076058524, 57.40212229319981, 63.651210512433735, 52.05147436686924, 49.21530655452183, 48.51065846851894, 51.02201189313616, 48.61800466264997, 47.345191955566406, 45.2155829838344, 48.31405224118914, 47.034194060734336, 43.25491598674229, 46.50867053440639, 46.211183411734446, 46.47816794259207, 47.74334110532488, 43.846412658691406, 44.98695598329817, 41.793761934552876, 41.19191939490182, 46.455996240888325, 48.73325443267822, 47.65270185470581, 47.87292848314558, 55.22873272214617, 55.04141623633248, 58.712243352617534, 54.62658098765782, 52.89778579984392, 48.171794823237825, 52.60985245023455, 54.2924108505249, 55.36134604045323, 55.77893277576992, 58.70272432054792, 55.115115778786794, 52.60829605375017, 51.66033942358834, 50.65871490750994, 50.015537534441265, 49.51537145887102, 46.62583105904715, 51.94866534641811, 46.38166093826294, 44.64630317687988, 49.29430757250105, 47.22507497242519, 48.6433482170105, 32.173678738730295, 33.96417045593262, 32.480445180620464, 30.9629898752485, 32.34181819643293, 35.37350484303066, 33.513155937194824, 33.18293585096087, 40.75570453916277, 42.69126769474575, 37.13394560132708, 41.30491100038801, 41.63863297871181, 42.13998372214181, 33.00464507511684, 32.43688692365374, 32.77112306867327, 37.86851263046265, 39.427813461848665, 36.296447958265034, 37.32719932283674, 47.48374250956944, 51.86195182800293, 55.74121447971889, 42.190816743033274, 51.74633032935006, 53.752494130815776, 51.90906408854893, 55.04132243565151, 52.98743840626308, 54.56529440198626, 52.40098960059029, 51.1980688231332, 54.83802856717791, 48.60709946496146, 54.43391786302839, 55.008304595947266, 55.722343172345845, 56.30667625154768, 50.44223683220999, 48.04450729915074, 46.127659116472515, 35.815250464848106, 37.893724169049946, 41.28440339224679, 46.970770903996055, 46.83959238869803, 44.252138819013325, 47.6929076058524, 45.04816266468593, 41.524602617536274, 45.46969597680228, 44.35913412911551, 39.20611728940691, 42.47602987289429, 44.81915698732649, 44.32889209474836, 44.39514316831316, 53.067832538059776, 55.01234497342791, 51.936808245522634, 55.78571421759469, 59.61277157919747, 57.08465909957886, 56.52413402284895, 52.37627485820225, 50.5770457812718, 51.01530688149588, 53.945282323019846, 60.84083093915667, 64.41214942932129, 63.121236664908274, 69.99340111868722, 63.48592676435198, 74.88184097834996, 62.09472370147705, 23.687760421207972, 1.317953524844987, 27.55856364113944, 74.02285603114537, 50.04345539637974, 32.66330439703805, 35.68278653281075, 50.58167328153338, 47.454414163317, 43.6195261819022, 69.47377313886369, 44.33055966241019, 0.16523508355021477, 0.2572356382650988, 0.28468468678849085, 0.19725542249424116, 0.1377192536102874, 0.17569084678377422, 0.17779449533138955, 0.27453165873885155, 0.11725824725415025, 0.3029472939670086], [0.2792448715439865, 0.048098097289247174, 0.11669270188680717, 0.02365423456233527, 0.2087732558803899, 0.22064054837184294, 0.026634053327143192, 0.03115013474598527, 0.18052183969744615, 0.17942289795194352, 0.11020341009965964, 0.1398793427007539, 19.813448360988072, 64.55752658843994, 36.31875514984131, 38.34050028664725, 25.412654195513042, 26.222503219332012, 19.7025203704834, 36.67703206198556, 48.01657901491438, 50.60614831107003, 2.0858943802969794, 42.036910670144216, 67.99610669272286, 60.229820251464844, 60.04324722290039, 58.607728549412315, 58.75455788203648, 56.34278951372419, 57.11485597065517, 49.61327852521624, 43.049561977386475, 43.83931507383074, 40.57654176439558, 41.116614818573, 41.13638939176287, 41.49766097749983, 42.13293824877058, 42.670836516789024, 39.63336549486433, 40.80074276242937, 41.71001877103533, 40.70400299344744, 40.56951713562012, 40.343318530491416, 40.95310633523123, 39.88545308794294, 40.44082260131836, 38.042029993874685, 41.36000674111502, 46.05586685453142, 47.30720615386963, 47.05927358354841, 50.42979260853359, 52.295345715114046, 53.5751622063773, 50.677370820726665, 46.345571994781494, 47.14224897112165, 48.71441439219883, 49.062484400612966, 46.84239598682949, 45.88701868057251, 42.61812400817871, 46.329827376774375, 44.24258157185146, 47.0115498815264, 45.46520396641323, 46.193045139312744, 45.51001637322562, 42.600274085998535, 47.161200182778494, 40.368033272879465, 32.78643689836775, 42.84501395906721, 43.59702444076538, 40.745674814496724, 30.450449057987758, 34.968226841517854, 34.117760385785786, 34.73924200875418, 34.83427252088274, 37.8292726789202, 38.38595192773001, 44.18857322420393, 41.299811022622244, 46.819967201777864, 52.04584980010986, 46.987672397068565, 47.666844912937705, 42.12144245420183, 36.037992341177805, 34.53480168751308, 33.38286679131644, 34.300254821777344, 35.41438456944057, 38.770944663456504, 36.30903809411185, 40.13534157616751, 45.789643151419504, 47.80981799534389, 35.76854814801897, 45.04779788425991, 47.27851356778826, 45.287944998059956, 48.01641573224749, 46.655531133924214, 44.42610781533377, 46.908327443259104, 45.96804509844099, 43.90469414847237, 44.064770221710205, 44.67893191746303, 45.94588034493582, 47.574732644217356, 45.293441023145405, 47.2970861026219, 44.936008317129954, 36.61264310564314, 33.74510070255825, 36.609999316079275, 39.43058231898716, 45.30952262878418, 42.43673433576311, 40.206074237823486, 40.648191588265554, 38.639703614371165, 38.29697677067348, 42.21886314664568, 38.224639075142996, 37.00906910215105, 40.76924657821655, 40.85391385214669, 42.42977224077497, 42.422827516283306, 45.92932973589216, 50.24607876368931, 52.17968947546822, 49.889681339263916, 50.3404735156468, 52.06309870311192, 51.39980976922171, 51.681371620723176, 47.43759257452828, 44.637207984924316, 46.0998489516122, 53.82760068348476, 60.93401323046003, 61.25196279798235, 60.23529543195452, 64.77488708496094, 64.86338629041398, 41.96019213540213, 9.693077496119908, 0.16330045807574475, 34.63984455381121, 58.12766361236572, 34.758599690028596, 21.01747911317008, 33.906774861471995, 30.645179271697998, 34.43998309544155, 38.723901884896414, 53.158173016139436, 33.75077738080706, 0.1360174742128168, 0.10140384906636817, 0.06272576523146459, 0.06305054601814065, 0.037517605748559744, 0.0639536761279617, 0.050984921133411784, 0.06741823522107941, 0.14244324155151844, 0.2368643885212285, 0.1983306019433907, 0.04096545930951834, 0.048638947374586544, 0.03819887187065823, 0.13236433666731628, 0.14012795793158667, 0.055656054589365206, 0.05771943886897393, 0.15803020873240062, 0.27358939072915484, 0.10557249002158642, 0.08903129904397897, 23.456896100725444, 75.49285861424038, 40.127653394426616, 46.22372143609183, 35.67279849733625, 27.511157819202968, 33.80830846514021, 41.519394942692344, 53.57734741483416, 58.589955057416645, 3.6890635320118497, 43.14156654902867, 73.30328668866838, 61.393851961408345, 65.03729970114571, 59.32237161908831, 62.22623920440674, 57.947698320661274, 59.48207596370152, 51.54648624147688, 47.55831057684762, 46.722477027348106, 40.9031731060573, 43.65190478733608, 44.66979851041521, 42.837506430489675, 43.68618025098528, 44.80093881062099, 42.38050256456648, 42.274167333330425, 44.20539133889334, 43.63721282141549, 41.299553939274375, 42.18839529582432, 42.96039227076939, 42.17349140984671, 42.170399461473735, 40.08647836957659, 42.5485725402832, 48.09637212753296, 50.19152498245239, 48.27483660834176, 51.759080273764475, 53.71510240009853, 55.09322895322527, 52.09488671166556, 50.33196892057146, 51.82709618977138, 50.25020946775164, 50.58380290440151, 49.50120060784476, 48.32296677998134, 44.505379813058035, 46.42608772005354, 49.25803450175694, 48.609375, 47.478628635406494, 47.166793482644216, 46.31926611491612, 43.62639100211007, 46.467426027570454, 44.44474288395473, 33.50890016555786, 43.506096839904785, 43.883936405181885, 41.21807241439819, 31.354051862444194, 35.532733236040386, 34.77267674037388, 35.8433906691415, 34.89868579592024, 35.41202565601894, 36.81651367459978, 41.58663960865566, 40.18939856120518, 44.047670704977854, 50.04500137056623, 43.433335304260254, 44.412656102861675, 38.76096357618059, 32.492013931274414, 33.34084756033761, 31.132435594286235, 32.09584501811436, 33.049092701503206, 37.35105248859951, 38.71248599461147, 41.27353293555123, 47.02826377323696, 49.91856152670724, 36.40060840334211, 47.6374887738909, 49.26780366897583, 50.42779847553798, 53.46107278551374, 50.4114146232605, 49.47821944100516, 51.47438131059919, 49.23947933741978, 49.78212322507586, 50.03744867869786, 48.68985945837838, 50.10399505070278, 50.43379477092198, 48.025493553706575, 47.38346610750471, 46.48192344393049, 38.37795107705252, 37.168724809374126, 40.45146724155971, 43.47633423124041, 47.59866918836321, 45.43823453358242, 43.40366997037615, 44.10147755486624, 42.622140066964285, 39.8617319379534, 43.30425861903599, 39.30902705873762, 36.83090686798096, 41.78530250276838, 43.88948801585606, 42.46194240025112, 44.83863973617554, 50.08800377164568, 54.318987710135325, 55.60318504061018, 53.869724137442454, 54.976044109889436, 55.57778590066092, 53.96029043197632, 54.66063758305141, 52.31491184234619, 46.999164717538015, 47.565248353140696, 54.94661848885672, 61.06272166115897, 59.579010282244, 62.01470129830496, 63.176502636500764, 66.84413010733468, 44.6246143749782, 8.320671916007996, 0.4088668003678322, 42.159688813345774, 62.810395104544504, 40.93570457186018, 23.771965639931814, 30.848744119916642, 36.101901871817454, 39.28026499067034, 50.68043845040457, 60.033095904758994, 44.83092376164028, 0.1602822257471936, 0.08534278946795634, 0.06673558828021799, 0.023220591313604797, 0.06337425471948725, 0.04854585576270308, 0.009928619555596794, 0.0996662498052631, 0.05959814627255712, 0.11649722951863493, 0.24149625854832785, 0.07539688423275948, 0.27753846453768866, 0.10449307651392051, 0.2504577791052205, 0.21573684364557266, 0.13482401253921644, 0.18149796660457337, 0.2749104712690626, 0.2960498226540429, 0.29924336129001206, 0.2517966372626168, 31.31519753592355, 86.00388499668666, 50.31239584514073, 50.03606946127755, 38.29251255307879, 36.29751798084804, 29.838691438947404, 51.48830550057547, 58.98691953931536, 62.05128356388637, 4.122978534017291, 49.3172470501491, 71.74315902165004, 65.59699099404472, 64.79803848266602, 62.32474381583077, 64.50647122519356, 61.82557133265904, 60.888585908072336, 55.634180954524446, 47.37691395623343, 50.7525121143886, 44.12862416676113, 44.876934732709614, 45.307973180498394, 46.61274412700108, 43.7082268851144, 46.92589248929705, 43.742898396083284, 44.31457185745239, 44.85792098726545, 45.90305859701974, 44.71988112585885, 43.12064899717058, 44.0946752684457, 43.76654658998762, 42.39157451902117, 41.848760400499614, 44.34370218004499, 47.14037643160139, 48.23717737197876, 46.21039131709507, 51.64985806601388, 54.672602381025044, 57.18804829461234, 55.395155974796836, 53.49212775911604, 54.231023515973774, 52.08198390688215, 54.78945023672921, 55.29831198283604, 55.474341120038716, 50.443654264722554, 50.97393035888672, 51.27780982426235, 52.653341225215364, 50.3491587638855, 50.127299308776855, 50.25558737346104, 46.80427122116089, 48.16108417510986, 46.56449236188616, 36.025978905814036, 45.1736922945295, 44.55145331791469, 42.27356284005301, 33.80980232783726, 36.746823242732454, 37.17810140337263, 38.57996995108468, 36.29363741193499, 39.02337966646467, 38.81228991917202, 43.47461107798985, 42.42762872150966, 46.351696831839426, 52.18123197555542, 46.015942505427766, 48.30281352996826, 41.15999242237636, 34.26536444255284, 33.27882099151611, 32.231122970581055, 32.9144400869097, 33.01849283490862, 38.72267900194441, 42.21371453148978, 44.46042496817452, 49.75911773954119, 52.425568853105815, 40.462351594652446, 48.626735074179514, 51.21384470803397, 50.930469376700266, 57.58770520346505, 53.19588783809117, 53.57780252184187, 56.63399199077061, 56.39391088485718, 53.7015951020377, 57.23313862936837, 54.23316356113979, 55.17473479679653, 58.353820528302876, 52.94462708064488, 51.507972376687185, 49.68887145178658, 42.352963379451204, 37.29049893787929, 39.30566760471889, 43.12376873833792, 49.97618293762207, 45.825409003666465, 44.72976841245379, 46.68264995302473, 44.8467378616333, 40.0521125793457, 44.52289622170584, 40.11741174970354, 38.713364941733225, 44.58208792550223, 45.58280917576381, 45.26540156773159, 46.10289921079363, 52.758293764931814, 55.638905729566304, 56.251483236040386, 57.23356941768101, 56.73229510443551, 57.04214654650007, 55.52564314433506, 56.29462112699236, 55.42729139328003, 50.98347718375069, 50.8329861504691, 56.36701093401228, 62.829620770045686, 62.0931464603969, 63.34403760092599, 65.04950768607003, 69.38496821267265, 52.81989996773856, 10.857918671199254, 1.0536825912339347, 44.169128690447124, 70.99394866398403, 47.460792609623496, 26.24148222378322, 47.20419563565935, 42.60860497610909, 44.843423570905415, 55.725591455187114, 70.65423039027623, 54.4735677582877, 0.5787705034017563, 0.18234521257025854, 0.13206187289740356, 0.11981161524142538, 0.1410664939986808, 0.2128973781530346, 0.17983845993876457, 0.1274121981114149, 0.2197864084903683, 0.2544347271323204], [0.3694787924843175, 0.09983489289879799, 0.086058555703078, 0.04992046932290707, 0.05967586567359311, 0.12336495385638305, 0.10602493717202119, 0.07039135175624064, 0.314113157668284, 0.04711552429944277, 0.3616138388003622, 0.14730503995503696, 16.392681700842722, 58.17711394173758, 47.04241377966744, 28.058328458241053, 26.49244247164045, 34.95459794998169, 13.573657699993678, 37.35768454415457, 36.293748583112446, 68.85095746176583, 5.869556333337512, 27.514413050242833, 72.10044928959438, 54.25718000956944, 61.75715936933245, 54.51221711294991, 55.40954221997942, 53.94682829720633, 51.488017150333945, 44.29863616398403, 44.73131091254098, 41.163421358381, 42.455379826681956, 48.005093642643516, 47.71445049558367, 46.20936645780291, 47.14499003546578, 46.48115219388689, 45.35136120659964, 46.36543689455305, 45.459430013384136, 43.8132141658238, 42.180415289742605, 41.145706926073345, 42.554780755724224, 39.44762625013079, 40.670127051217214, 39.50413247517177, 39.095543657030376, 43.16230692182268, 48.0314724785941, 47.26283148356846, 48.2577475139073, 47.470078877040315, 50.82195241110665, 44.99616929462978, 44.97441101074219, 42.862426144736155, 45.7380701473781, 46.986574581691194, 45.762135233197895, 42.92009966714041, 41.732447556086946, 41.838814054216655, 46.78136648450579, 47.321908542088096, 46.99884857450213, 45.36894709723336, 47.579797880990164, 44.26304749080113, 44.44265842437744, 42.33392184121268, 36.97897645405361, 47.49838931219918, 42.464339528764995, 39.04055561338152, 32.785953998565674, 32.96250425066267, 33.3789827483041, 33.765893186841694, 36.36496761866978, 36.384412152426584, 38.17715161187308, 39.831663608551025, 45.10017687933785, 44.02759041104998, 47.80970335006714, 46.92441252299717, 42.66301284517561, 37.52799183981759, 33.577454566955566, 30.909499168395996, 32.60129867281233, 34.416397435324534, 37.21384988512312, 39.976061071668354, 37.072870935712544, 39.04170901434762, 42.4824013710022, 45.26590183803013, 35.51310110092163, 46.83425269808088, 46.7131073815482, 44.57531690597534, 45.167737688337056, 44.63900409426008, 44.52491814749581, 44.054229804447715, 43.43609373910086, 46.08010911941528, 44.41362885066441, 46.271441664014546, 41.5788437298366, 46.09187241962978, 46.154996803828645, 43.771893228803364, 39.05646003995623, 35.172927720206125, 34.17591333389282, 38.91255242483956, 42.39663280759539, 41.11839355741228, 38.96266630717686, 39.264457838875906, 38.275635378701345, 39.44714682442801, 40.12017365864345, 42.88224240711757, 39.78276913506644, 40.15683930260794, 39.25996930258614, 41.49947098323277, 41.041869572230745, 43.18611492429461, 50.529655592782156, 52.613656588963096, 54.897442613329204, 59.27094800131661, 64.21677303314209, 52.104232038770405, 54.62240512030465, 52.051133905138286, 51.850310121263774, 47.55915478297642, 47.90656818662371, 53.06094339915684, 60.76842376164028, 60.03318623134068, 63.606464113507954, 61.902918679373606, 68.96808324541364, 28.819338594164165, 3.876934136663164, 3.0059592042650496, 46.12696777071272, 55.80089603151594, 26.762213230133057, 23.889800139835902, 31.891415119171143, 26.51236990519932, 37.169051374707905, 37.31133311135428, 48.82326487132481, 39.56589501244681, 0.20530453058225767, 0.08107357605227403, 0.12374037371150085, 0.06087141723505088, 0.015377990269501294, 0.011461790634452232, 0.10932649179760899, 0.1389629675873688, 0.18342263118496963, 0.25709059461951256, 0.19192128229354108, 0.04857431352138519, 0.08008041113082852, 0.0905241710799081, 0.11112273684037582, 0.045473944528826644, 0.2953672707080841, 0.05857813850577388, 0.2713568205279963, 0.1546608345316989, 0.3625629193016461, 0.12446316278406552, 18.28584521157401, 67.87604876926967, 50.652030740465435, 26.946022612707957, 34.65533903666905, 35.92083876473563, 19.62728180204119, 45.50657006672451, 40.93617704936436, 78.39291163853237, 8.547470671789986, 28.0109851700919, 76.47453485216413, 58.841069902692524, 66.25324835096086, 56.96602555683681, 56.904012884412495, 55.19210876737322, 51.65745939527239, 47.543997287750244, 47.4774682862418, 43.14516224179949, 46.25757653372628, 50.85254185540335, 49.953462328229634, 49.658313274383545, 48.258595194135395, 48.13016816547939, 47.66444778442383, 48.514358384268625, 47.225154876708984, 47.11209378923689, 44.84821435383388, 41.62060587746756, 44.75049141475132, 41.16012096405029, 43.53342757906233, 42.56408439363752, 40.04226350784302, 46.075026512145996, 49.21248211179461, 48.20305824279785, 51.31785576684134, 51.94096326828003, 56.49462849753243, 49.086167335510254, 49.81319556917463, 46.1074572290693, 46.03552252905709, 46.39606802804129, 45.96559933253697, 44.74181658881051, 44.05994817188808, 43.31542784827096, 45.41917909894671, 47.36546679905483, 46.578347069876536, 43.472283431461875, 46.23529366084507, 43.76989562170846, 44.469853673662456, 43.38079302651541, 39.06356804711478, 47.417477539607454, 42.03026124409267, 38.14167063576834, 33.117007868630544, 33.40332923616682, 32.2039589881897, 34.57694598606655, 36.35465996606009, 36.33453450884138, 36.70833369663784, 39.176055908203125, 41.810559204646516, 42.642362798963276, 45.377632345472065, 44.04322385787964, 43.77848359516689, 37.958370208740234, 32.8221367427281, 29.87030574253627, 31.579656396593364, 34.37689692633492, 35.983806814466206, 38.91587713786534, 37.86452783857073, 40.76677301951817, 43.34077140263149, 47.107726846422466, 37.542874881199424, 49.71323183604649, 49.73422581808907, 47.45181206294468, 48.89043658120291, 51.54809822354998, 50.49880906513759, 48.392236845833914, 44.992184502737864, 47.194985798427034, 49.60996770858765, 49.758273533412385, 45.4991945539202, 46.710487910679404, 46.35862071173531, 44.04023265838623, 38.18078899383545, 35.53622123173305, 37.84229360307966, 44.14889901024954, 47.27750607899257, 44.12905842917306, 43.405570302690776, 41.226031575884136, 40.78548451832363, 41.92331109728132, 43.59937640598842, 44.12183230263846, 40.64089945384434, 40.90119981765747, 41.93767302376883, 42.88336106709072, 44.26643821171352, 47.934631960732595, 51.914059843335835, 55.0457831791469, 58.05047607421875, 59.74518339974539, 67.06896686553955, 55.29729407174246, 57.628366061619346, 56.266703265053884, 54.95617573601859, 48.78564385005406, 46.72736855915615, 54.31522178649902, 61.327197892325266, 60.4794898714338, 62.63814926147461, 61.10657869066511, 67.96737589154924, 32.93340172086443, 3.324717151267188, 4.174066466944558, 53.39858416148594, 60.01434966496059, 28.24687303815569, 23.06700141089303, 32.15802444730486, 30.116900784628733, 35.75624288831438, 37.200985295431956, 56.65469414847237, 47.666417598724365, 0.6889709958008358, 0.1434319213564907, 0.08117406030318566, 0.11091902705707721, 0.028051726719630615, 0.016902870498597622, 0.14131010164107594, 0.08972964728517191, 0.14236115238496236, 0.2888195163437298, 0.3720134464757783, 0.11055076574640614, 0.085425991431943, 0.12454192712903023, 0.21740367848958286, 0.2159744937505041, 0.3391872522022043, 0.15644266749066965, 0.48603289680821554, 0.24385063935603413, 0.7872588017157146, 0.2882166786917618, 23.736792121614727, 76.83783531188965, 63.316564423697336, 41.76662574495588, 39.76240049089704, 52.24643734523228, 19.20866847038269, 52.32482692173549, 48.3305333682469, 84.03889274597168, 8.842071686472211, 33.9656399999346, 75.66197081974575, 60.43110956464495, 68.48120212554932, 60.737928118024556, 58.05934892381941, 56.75041948046003, 55.125458172389436, 47.88693952560425, 48.73561334609985, 46.321989808763774, 45.99953086035592, 52.12411083493914, 49.25249678747994, 50.25879396711077, 47.39581653050014, 48.810897077832905, 48.33711331231253, 51.34045478275844, 47.91926601954869, 48.114173412323, 45.02820743833269, 44.39309344972883, 46.276868207114084, 42.744292872292654, 45.14219958441598, 43.858485153743196, 42.27992391586304, 46.766966342926025, 50.69733646937779, 47.52054016930716, 49.65893166405814, 54.02648939405169, 58.20262425286429, 50.019980907440186, 52.03102234431675, 49.270774023873464, 51.37957661492484, 52.275296688079834, 52.906405040196006, 49.302853856767925, 47.18922226769583, 45.876714502062114, 49.71835265840803, 48.28445986339024, 47.36272573471069, 45.620051520211355, 49.325852394104004, 47.318976402282715, 47.45911809376308, 44.60791090556553, 41.44906527655465, 49.18091991969517, 44.53692463466099, 41.96597303662981, 34.01747703552246, 34.22302212033953, 33.73602982929775, 35.7068828855242, 37.951251779283794, 37.840136187417166, 38.09610434940883, 39.59989949635097, 45.68387072426932, 45.897920404161724, 46.993178844451904, 47.58221238000052, 45.065845830099924, 39.814237526484895, 34.26266854149954, 32.423747880118235, 34.09651626859392, 37.81264911379133, 38.67813410077776, 41.7878212247576, 42.735152517046245, 43.080158369881765, 46.090357712336946, 46.79919556209019, 41.1809412411281, 51.93459871837071, 53.122115339551655, 50.5277031489781, 51.6688231740679, 54.27622849600655, 54.74931744166783, 51.767588342939106, 49.11721188681466, 54.18108333860125, 56.09757716315133, 56.14053092684065, 48.77880334854126, 53.176832403455464, 52.29065915516445, 47.90789876665388, 41.58049740110125, 37.298861094883506, 38.75786815370832, 43.8952967098781, 48.037903036390034, 46.66827760423933, 44.62778970173427, 41.695344175611226, 42.555649280548096, 44.311726570129395, 42.57624026707241, 45.507570607321604, 40.811161586216514, 41.96033457347325, 42.51388018471854, 43.358437197549, 46.79722922188895, 48.73205934252058, 54.631594112941194, 58.12633303233555, 60.513807024274556, 60.607996804373606, 65.0424552645002, 58.340500831604004, 59.332821709769114, 58.96458108084542, 57.751380443573, 51.59136118207659, 51.386135714394705, 56.5741297858102, 62.32497310638428, 62.471753801618306, 63.83520575932094, 62.02588094983782, 72.32925346919468, 39.953437737056184, 3.2887938788958957, 3.870459718363626, 54.944624355861116, 66.24747439793178, 35.88718169076102, 29.73990195138114, 41.58041054861886, 36.747921058109824, 48.856824670519146, 47.23146731512887, 63.23133087158203, 57.886178970336914, 0.8557058860148702, 0.2984458383704935, 0.18878311211509363, 0.23452099998082432, 0.14240383223763534, 0.1268884233598198, 0.23749121917145594, 0.18266560323536396, 0.1585292305265154, 0.4582991621323994], [0.2116473673709801, 0.12975599377283029, 0.1843868972999709, 0.06168381364217826, 0.023227023825581585, 0.03823140762480242, 0.03301068115979433, 0.024217554334817187, 0.10625573407326426, 0.04774558477635894, 0.22218052430876664, 0.09294595755636692, 17.798279694148473, 54.64731788635254, 42.50485100064959, 55.81239182608468, 40.7410751070295, 34.22472790309361, 26.24020549229213, 32.04004750932966, 33.38459341866629, 70.65611335209438, 20.837840386799403, 13.811271326882498, 72.0531598499843, 54.903216566358296, 61.002703121730256, 53.597316537584575, 57.26835904802595, 45.417042527879985, 46.640679359436035, 45.205542836870464, 45.453211375645225, 46.7552238873073, 52.97859682355608, 51.73485190527779, 53.80599178586687, 55.38638039997646, 52.73906462533133, 52.07821798324585, 50.797654560634065, 49.105709144047324, 48.34647600991385, 46.13170644215175, 43.427245208195274, 41.321704796382356, 41.50302498681204, 39.93330880573818, 39.380614348820274, 41.79695463180542, 39.69669485092163, 39.06259182521275, 45.061635221753804, 44.97441101074219, 45.36483723776681, 44.346102782658164, 47.52580690383911, 48.737885407039094, 45.59710162026541, 41.38965470450265, 45.39028154100691, 50.01362330572945, 47.993285179138184, 49.59725945336478, 51.17233616965157, 44.850830350603374, 45.48051084790911, 47.11095775876726, 48.025510924203054, 46.83314446040562, 43.8639429637364, 40.95105314254761, 45.06519269943237, 45.505176952907014, 35.54093211037772, 45.296466963631765, 45.675241061619346, 39.29792731148856, 31.121509552001953, 31.845306873321533, 35.664669104984824, 35.69633552006313, 36.479699747903005, 38.183828830718994, 40.21154594421387, 41.168903487069265, 36.50793375287737, 35.705521038600374, 31.288770062582834, 33.80860723767962, 30.8042756489345, 29.54124253136771, 30.85673107419695, 27.98958124433245, 25.934950283595494, 25.077441828591482, 27.697475501469203, 38.30642632075718, 38.28985139301845, 41.76513883045742, 44.36993162972586, 44.42669146401541, 33.28394528797695, 47.00174249921526, 43.79518011638096, 43.60830136707851, 46.43247658865792, 47.25135653359549, 46.28035272870745, 45.90850598471505, 43.26824263163975, 45.064414501190186, 43.17245823996407, 43.940550327301025, 44.07242018835885, 46.979028838021414, 44.73482322692871, 45.282935346875874, 40.971015317099436, 39.1080504144941, 39.41795744214739, 41.13277285439627, 40.63918672289167, 40.828716209956575, 38.45153250013079, 38.51194708687918, 38.58111987795149, 40.17188215255737, 40.37556512015206, 39.6165578024728, 39.705307143075125, 40.51394544328962, 41.22082390104021, 38.93284116472517, 41.250350270952495, 47.05454533440726, 48.964375836508616, 55.26589168821062, 56.19195107051304, 55.22276421955654, 60.06773962293352, 54.44759539195469, 54.036074434007915, 57.465614931924, 54.708489826747346, 51.28474760055542, 44.898321287972585, 52.587458406175884, 61.48861844199044, 61.34035778045654, 61.559205191476, 61.41453674861363, 64.86467170715332, 21.096223047801427, 1.835238116128104, 11.665680629866463, 46.60937425068447, 47.34866605486189, 26.46909131322588, 25.96186760493687, 26.604461329323904, 36.02925845554897, 45.8817206791469, 38.89403200149536, 44.9979966708592, 43.557454449789866, 0.7420293944222587, 0.10992281551339797, 0.2720810888069016, 0.13039461736168179, 0.04984301455052836, 0.027125595969014933, 0.10824354312249593, 0.04072042674358402, 0.07207700237631798, 0.20173064592693532, 0.28914806299975937, 0.04161998436653188, 0.11285147443413734, 0.05020615292180862, 0.07219996649239745, 0.022773241657497625, 0.06946443899401597, 0.018881872163287232, 0.12698069055165562, 0.08729574217328004, 0.24112675551857266, 0.17209233130727494, 24.47724253790719, 64.63347734723772, 46.55627611705235, 58.150175775800435, 44.044891425541465, 37.578644207545686, 21.853802510670253, 42.936017990112305, 35.69445603234427, 76.31436497824532, 25.199162108557566, 14.796645743506295, 74.07289000919887, 59.715153285435264, 66.11331163133893, 57.89158814293997, 60.36185686928885, 49.052475520542686, 49.67558649608067, 50.18789454868862, 49.17430523463658, 51.64718648365566, 56.247651304517476, 54.79394572121756, 57.95378841672625, 57.01082059315273, 54.500095980507986, 54.05692250388009, 54.13493340356009, 52.332775660923545, 52.05618177141462, 50.445763042994905, 46.42637954439436, 43.22242621013096, 44.25985131944929, 43.616607938494, 42.2330652645656, 44.5731212752206, 45.21344641276768, 41.87357589176723, 46.553795610155376, 47.4726288659232, 48.332322529384065, 49.42249836240496, 53.53878838675362, 51.95215334211077, 47.4766970361982, 42.9949699810573, 48.75957768304007, 50.87937579836164, 50.27382639476231, 51.20340503965105, 52.76247310638428, 49.488593101501465, 47.020738874162944, 48.381939615522114, 48.49676554543631, 47.66141836983817, 45.361158166612896, 42.19205699648176, 45.84975201742989, 47.58297668184553, 39.09476545878819, 48.4574248450143, 47.59461144038609, 39.53735876083374, 32.330708026885986, 31.959528309958323, 35.379247529166086, 35.53858361925398, 34.63250378199986, 37.25706768035889, 39.286622592381065, 39.38321992329189, 35.77575690405709, 36.5564842905317, 35.02556337629046, 38.19403920854841, 33.90877594266619, 32.53655535834176, 33.754317487989155, 29.284235613686697, 27.43575770514352, 27.512173993246897, 30.8441652570452, 40.070216110774446, 40.25289814812796, 42.977203437260215, 44.308221203940256, 46.91131516865322, 37.654963220868794, 49.18933418818882, 44.69920328685215, 47.01950209481375, 48.304915360042024, 49.82451071058001, 48.32962315423148, 47.58739226205008, 46.41141659872872, 48.64145483289446, 44.69843898500715, 46.19537625994001, 47.08569063459124, 48.38500724520002, 45.488945960998535, 46.01830836704799, 42.17235885347639, 42.08570439474923, 44.925676345825195, 44.783901827675955, 43.814082690647666, 44.11898701531546, 41.95467526572091, 42.31554038184029, 40.71735395703997, 43.27763312203543, 42.545633452279226, 42.77663326263428, 43.97505160740444, 43.23281029292515, 43.60256215504238, 42.50312784739903, 42.688863618033274, 49.89719929013933, 53.6208188193185, 57.34837102890015, 56.4038850239345, 55.57693127223423, 60.67442853110177, 55.196434020996094, 54.996214730399, 59.579538345336914, 57.16269779205322, 54.43043334143502, 45.56495925358364, 54.11249072211129, 63.30365467071533, 60.95985358101981, 61.31264836447579, 62.83283083779471, 65.98839691707066, 23.53508070537022, 1.6068461601223265, 14.524342366627284, 54.85427345548357, 49.76085131508963, 28.00854287828718, 23.087974548339844, 27.160398857934133, 32.86075135639736, 36.4594909123012, 43.186156613486155, 52.31614862169538, 53.18039682933262, 1.5553820473807198, 0.056746338228029866, 0.3623317288500922, 0.027206764024283205, 0.05444587381290538, 0.00801079800086362, 0.05193948759032147, 0.06347390437232596, 0.018456554539235573, 0.25933573128921644, 0.33112962171435356, 0.19130586460232735, 0.1636606923171452, 0.16358967684209347, 0.1944949384778738, 0.145463780899133, 0.16818825794117792, 0.1332324950822762, 0.30840912088751793, 0.17988118050353868, 0.34147187960999353, 0.2470073199697903, 28.954802410943167, 76.00655283246721, 54.27751391274588, 71.28922625950405, 56.73540094920567, 47.1408245904105, 32.85320561272757, 49.43274348122733, 42.17325169699532, 82.82244382585797, 25.211314507893153, 18.040153435298375, 79.46088450295585, 60.915586607796804, 67.75326020377022, 58.01703439440046, 61.98817307608468, 49.396168163844514, 51.428686482565745, 52.41969762529646, 54.03165190560477, 53.09330463409424, 59.39775262560163, 57.06516940253121, 59.83297388894217, 59.3142283303397, 56.730029991694856, 53.95748683384487, 54.97175012316023, 54.906405789511545, 54.43624898365566, 53.46385553904942, 48.56718553815569, 45.48120566776821, 45.148133346012656, 44.09093713760376, 43.493697779519216, 45.93239041737148, 47.088320527757915, 45.343707765851704, 48.76007795333862, 49.44008077893938, 52.23576143809727, 50.414155687604634, 57.16929510661534, 55.660240173339844, 48.389374188014436, 41.39551551001412, 48.30498136792864, 53.30893155506679, 53.11405542918614, 54.69785908290318, 56.18402317592076, 51.868267740522114, 50.38468490328108, 50.54122086933681, 49.884202684674946, 49.921702112470356, 46.853078842163086, 44.19626835414341, 48.47747039794922, 49.96437447411673, 41.9187912940979, 50.75344317299979, 48.236659731183735, 42.225109577178955, 35.15386186327253, 32.846691676548545, 35.99213423047747, 35.72892951965332, 36.056220940181184, 37.668863092150005, 41.5721560886928, 40.8617514201573, 38.692655835832866, 39.129662786211284, 34.87091384615217, 38.08401100976126, 36.14978538240705, 34.714975425175254, 36.93206569126674, 30.08791290010725, 26.777870995657786, 28.62937137058803, 31.995016234261648, 43.14480093547276, 44.453869342803955, 46.77266386577061, 46.87807846069336, 50.815157072884695, 41.452442101069856, 52.695026942661826, 45.802445207323345, 48.17290653501238, 50.77994360242571, 53.90184218542916, 50.897993496486116, 52.912502084459575, 49.904731137411936, 53.67150592803955, 48.55937228884016, 50.50614288875035, 50.12510020392281, 52.408702101026265, 47.26568371909005, 48.806120191301616, 44.31140695299421, 42.75135919025966, 45.65981606074742, 48.345614433288574, 45.157068729400635, 48.410281317574636, 44.51244960512434, 46.14813893181937, 44.60253299985613, 46.44614022118704, 43.093175819941926, 43.149094922201975, 44.27721834182739, 44.327179363795686, 44.30483743122646, 43.947057315281455, 44.80018840517317, 51.53400032860892, 54.49540594645909, 60.1260211127145, 59.00519330160958, 58.41634736742292, 61.72429438999721, 56.01814535685948, 57.812194551740376, 62.46317972455706, 59.20886584690639, 58.420745577131, 48.523474420819966, 58.16786936351231, 67.43564414978027, 65.91601753234863, 63.12947028023856, 65.21303353990827, 63.36911364964077, 28.865648337772914, 1.8799293637275696, 12.566286155155726, 58.83277375357491, 58.899809973580496, 37.037000860486714, 32.28010777064732, 35.04488631657192, 47.62867150987898, 59.451295443943565, 54.898033210209434, 58.87854848589216, 65.38927459716797, 2.7884056781019484, 0.2602967811482293, 0.48642563287700924, 0.25058081107480185, 0.15842545538076333, 0.10165663728756563, 0.18636285912777695, 0.1405893617442676, 0.10444857818739754, 0.22537379153072834], [0.03422602219507098, 0.04616201635716217, 0.04086382494175008, 0.027839682829965438, 0.058452650239425044, 0.03713321566049542, 0.12295343593827315, 0.06127907428890467, 0.20490276999771595, 0.024792346438126903, 0.11750543756144387, 0.07945637604487793, 20.257420880453928, 56.70043066569737, 38.23763568060738, 21.019558361598424, 45.184107644217356, 27.420713118144445, 21.431298187800817, 22.744961091450282, 27.89339906828744, 62.83202484675816, 38.696915081569124, 10.093377981867109, 58.17745787756783, 57.834189074380056, 59.30791241782052, 54.74210173743111, 51.08472980771746, 47.44742774963379, 46.11782046726772, 43.661667006356375, 47.431043897356304, 52.83111783436367, 54.7330447605678, 52.26523222242083, 53.847694873809814, 50.18997553416661, 52.10704605919974, 55.43221419198172, 53.33030421393258, 52.72023500714983, 50.2436329977853, 50.1627003805978, 45.59670557294573, 40.139555658612935, 41.78773784637451, 41.00893858500889, 40.70231458118984, 39.95941318784441, 41.760830947331016, 39.2281847681318, 40.42912878308977, 44.971614360809326, 43.63257489885603, 46.489173889160156, 42.866643701280864, 46.81979349681309, 47.651520660945344, 49.685307025909424, 51.50940023149763, 51.797986711774556, 50.54622704642159, 50.44088888168335, 47.26225478308541, 49.22612837382725, 46.27956410816738, 47.12118203299386, 45.35097210747855, 45.81596640178135, 43.900528703417095, 43.590107509068076, 45.84364455086844, 44.92935541697911, 35.650658062526155, 45.400175775800435, 46.28457375935146, 39.39443778991699, 35.91944912501744, 38.12397009985787, 33.979459966932026, 32.5204633304051, 33.84956339427403, 33.49277687072754, 30.38899224145072, 24.14843119893755, 15.69551682472229, 15.551079409463064, 9.170090062277657, 8.504887768200465, 8.227216907909938, 10.636374490601675, 13.01155972480774, 10.688197629792349, 8.777787821633474, 7.823706354413714, 13.199088130678449, 26.3729247706277, 37.35171604156494, 39.662259578704834, 45.67255210876465, 43.26355607169015, 32.90411158970424, 47.84160252979824, 43.95956407274519, 41.3408852985927, 42.35575655528477, 44.07132932118007, 42.61214855739048, 44.34683929170881, 42.06345626286098, 44.80689341681344, 45.75454085213797, 46.09881714412144, 46.90605885641915, 46.07766682761056, 46.69644560132708, 46.59321274076189, 46.38962009974888, 47.02138505663191, 43.060203143528526, 39.020843573978965, 39.9983092035566, 37.807910442352295, 39.64116832188198, 38.37419210161482, 38.16140004566738, 39.3240247453962, 40.41921022960118, 39.15912662233625, 38.644053186689106, 40.33312552315848, 39.6754264150347, 41.960470063345774, 45.85694687707083, 50.32214069366455, 52.69995321546282, 55.21870647157942, 52.51036466870989, 54.714586871010916, 50.2762200491769, 55.21970353807722, 54.81357090813773, 58.8536947795323, 54.58171646935599, 53.05502005985805, 43.7039224760873, 48.60493857519967, 61.228290285382954, 59.27589511871338, 62.05693939753941, 59.61961555480957, 59.73776967184884, 14.977620261056082, 0.6322641958083425, 22.53803505216326, 47.89997782026018, 41.791538511003765, 21.36577841213771, 29.470207623073033, 25.775325843266078, 52.26787601198469, 54.94721255983625, 45.01047910962786, 47.00138119288853, 41.317254475184846, 1.764639207295009, 0.09597335689302001, 0.10644736593323094, 0.05630985700658389, 0.22212141033794197, 0.04135163055200662, 0.0296552712097764, 0.1335606753293957, 0.11916140227445535, 0.026340323999258022, 0.19588704806353363, 0.08018531943006174, 0.02814850616934044, 0.0242969446283366, 0.04987294473020094, 0.05696188844740391, 0.07505598823939051, 0.07827248171504055, 0.1731344796717167, 0.08913462635661874, 0.11777363531291485, 0.08700557345790522, 26.620999779020035, 63.252161570957725, 47.01523242677961, 28.043395042419434, 51.58222777502877, 30.4893832887922, 25.513929401125225, 40.39734772273472, 30.658648354666575, 69.99313708714077, 43.7641008240836, 11.738096492631094, 57.46709142412458, 63.24664470127651, 59.94517339978899, 59.5096811567034, 54.02559307643345, 49.924401487622944, 47.86731086458479, 48.25718123572213, 52.381347043173655, 57.6310133252825, 57.013130869184224, 57.51717751366751, 55.418019022260395, 54.64170374189104, 55.61972522735596, 59.1120913369315, 56.533562728336875, 56.25035762786865, 52.49993889672415, 52.273194858006065, 48.97016021183559, 42.72624840055193, 44.72567244938442, 43.76622002465384, 43.2766603742327, 43.726580551692415, 44.23459461757115, 41.09184449059622, 43.59198004858834, 45.91587802342006, 46.87995794841221, 49.149812834603445, 47.42861550194876, 49.400302342006135, 49.33135189328875, 51.416124139513286, 55.347915172576904, 53.5332020350865, 52.14286054883684, 52.748486382620676, 50.633183751787456, 53.70360313143049, 48.97341891697475, 50.95807456970215, 47.99832262311663, 48.1599759374346, 48.01577302387783, 47.26425239018032, 48.789896147591726, 47.12287391935076, 37.911584513528005, 46.179437092372346, 44.79131555557251, 41.34599569865635, 37.58087110519409, 38.63777548926217, 32.21373162950788, 32.165591035570415, 33.5840345110212, 33.261610303606304, 33.93829536437988, 28.336442266191753, 23.410344907215663, 20.123732328414917, 14.532786164964948, 14.142901028905596, 14.909871850694929, 17.256883008139475, 18.577796357018606, 13.706703543663025, 13.48677134513855, 11.715322034699575, 17.895403351102555, 30.109528745923722, 40.128570556640625, 39.90441124779837, 46.68108660834176, 43.99772357940674, 35.93391180038452, 47.99392441340855, 44.705995150974815, 42.11343118122646, 44.71465260641915, 47.744407653808594, 44.133269037519185, 45.99047040939331, 45.11516761779785, 47.46085514341082, 50.44644744055611, 49.613174302237375, 48.98827069146292, 49.883702414376394, 47.51066330501011, 48.071507998875205, 47.964283398219514, 50.20470224108015, 45.98814276286534, 43.37407759257725, 43.30323723384312, 42.94864634105137, 41.852595806121826, 42.172845227377756, 42.00762748718262, 42.247566155024934, 41.901893275124685, 42.55255733217512, 40.90192590441023, 42.436307021549766, 44.16975055422102, 43.4861033984593, 46.69981895174299, 54.79755878448486, 54.6010776247297, 56.92371450151716, 55.184403215135845, 56.572417054857524, 55.9391964503697, 57.57595232554844, 55.07809577669416, 58.394592557634624, 57.58917127336775, 55.648577622004915, 46.58028909138271, 48.97688954217093, 60.6550361088344, 62.82166508265904, 64.09613146100725, 61.1361780166626, 61.110963003976, 18.161437715802872, 0.31485121377876824, 28.320671592439922, 50.5905704498291, 44.519665309361045, 27.031782490866526, 30.904572895595006, 29.830989360809326, 56.456059047154014, 51.984983580453054, 43.764243262154714, 53.167184829711914, 55.771008355276926, 4.21039034639086, 0.18116663795496735, 0.1798160954245499, 0.09230084717273712, 0.3518249126417296, 0.046476273065699, 0.093104056215712, 0.10965152364224195, 0.06897627376019955, 0.06641189314957176, 0.18182145138936384, 0.19792333165449755, 0.10960403976163693, 0.06817973471645798, 0.09962150042078324, 0.13152477171804222, 0.2170625382236072, 0.1742663982191256, 0.26603167770164354, 0.16488683223724365, 0.1644471822572606, 0.17853017656930856, 34.42350544248308, 76.43549292428153, 52.02326815468924, 30.294625282287598, 59.68444224766323, 36.98796394893101, 27.919579880578176, 36.886075564793174, 37.46543720790318, 73.60477597372872, 45.73186540603638, 13.753628202847072, 62.95463970729283, 61.941668782915386, 64.51009818485805, 59.238673618861604, 56.499169145311626, 52.72399050848824, 49.90619720731463, 48.92706053597586, 53.81554208483015, 60.74597413199288, 61.43111515045166, 56.21047844205584, 58.606998988560264, 57.22462708609444, 58.03120871952602, 61.13965906415667, 58.28052398136684, 58.08548109872, 55.43614339828491, 55.93959597178868, 53.04096038000924, 43.79974160875593, 47.99908692496163, 46.732857636043, 45.45934663500105, 45.1467159135001, 47.562837328229634, 44.41742604119437, 45.21884516307286, 49.84976393835885, 48.376443590436665, 52.700481278555735, 49.554878916059224, 51.953598567417686, 51.67787667683193, 52.25854805537632, 55.30414152145386, 54.58056654248919, 54.64659527369908, 53.5913793018886, 53.39649275371006, 56.08372940335955, 51.27298430034092, 52.174846581050325, 50.07596254348755, 52.36118337086269, 51.18355056217739, 51.133992535727366, 52.985965388161794, 50.06146860122681, 42.394235679081504, 49.82717534473964, 48.177874497004915, 43.65259613309588, 38.16905696051461, 39.83089583260672, 35.16007702691214, 34.55167886189052, 35.00332219260079, 33.63616337094988, 33.99181038992745, 27.059403317315237, 20.354471581322805, 22.102706091744558, 10.57041437285287, 11.331755416733877, 11.91188223021371, 15.234799146652222, 16.953995398112706, 13.108407190867833, 13.51416288103376, 9.62850614956447, 15.682541063853673, 32.5953996522086, 43.633804730006624, 42.54132209505354, 49.65299095426287, 47.053694180079866, 39.89638607842581, 49.8412697655814, 45.369037423815044, 42.94062117167881, 46.898370674678254, 50.69199677876064, 48.25701447895595, 50.32431547982352, 47.91739348002842, 52.47534574781145, 53.32734775543213, 53.90929412841797, 52.93403802599226, 55.71374477658953, 50.70936380113874, 51.89209311349051, 51.83433968680245, 54.79031528745379, 50.47079392841884, 47.14080374581473, 47.03808157784598, 45.40211084910801, 44.72347681862967, 45.39314072472708, 43.62776674543108, 44.69074385506766, 45.01699651990618, 44.736678395952495, 41.90689597811018, 44.03952741622925, 45.038859026772634, 45.708436080387656, 49.12770366668701, 57.46533005578177, 56.242179598127095, 59.300269399370464, 55.90849583489554, 60.42311913626534, 55.84605584825788, 57.3092109816415, 58.224625723702566, 63.108382497514995, 58.2247542653765, 58.32802881513323, 47.35716022763933, 52.759322098323274, 63.83547673906599, 65.52502850123814, 65.41251632145473, 62.99798257010323, 60.25035217830113, 22.933093990598405, 0.5694766363927296, 27.263544866016932, 58.904465266636436, 55.08001000540597, 31.81832354409354, 36.20721571786063, 35.697051184517996, 73.25079999651227, 76.40178026471818, 57.743410859789165, 61.58068902151925, 65.3612733568464, 4.82370696749006, 0.2817320009427411, 0.17810451798141003, 0.3176175467669964, 0.37652809279305594, 0.1275093371846846, 0.15917055468474114, 0.1834053285419941, 0.15530371932046755, 0.11285508424043655], [0.06364515982568264, 0.02069400849619082, 0.013357905853938843, 0.04599860476862107, 0.03054636750104172, 0.05492734869143792, 0.07885904131191117, 0.057953798079064915, 0.056633416430226395, 0.05106103919180376, 0.0936846039923174, 0.19441398925014905, 25.070347717830114, 51.920712743486675, 47.33350508553641, 35.52769231796265, 37.916086946214946, 34.111079692840576, 18.049806220190867, 9.350687640053884, 21.443141392299108, 51.809451239449636, 55.71933807645525, 8.940926313400269, 37.75910976954869, 68.74307973044259, 55.54663365227835, 60.85995238167899, 52.96981430053711, 48.97695902415684, 44.5645124571664, 48.515720231192454, 52.88579668317522, 55.74129090990339, 54.38573905399868, 52.80804981504168, 49.462936878204346, 56.14274740219116, 53.8646102632795, 52.467827796936035, 52.29695422308785, 53.69889920098441, 48.07214723314558, 49.8473459652492, 46.40037243706839, 42.04885809762137, 38.43958159855434, 41.14198269162859, 39.232051440647666, 40.99853365761893, 40.11499377659389, 39.01465967723301, 38.40435075759888, 40.225581305367605, 41.848694392613, 45.59421116965157, 41.985518319266184, 45.35797936575753, 48.07105984006609, 48.757448060171946, 48.16011837550572, 52.09838512965611, 50.23109149932861, 51.169202532087056, 48.58063725062779, 48.93258087975638, 46.63574266433716, 47.228052275521414, 45.92457021985735, 45.687219755990164, 44.2128780228751, 44.23222528185163, 42.210480145045686, 44.629307883126394, 34.73974575315203, 43.49502835954939, 41.53038351876395, 35.346584047589985, 39.669350215366904, 33.5126348223005, 16.70425455910819, 15.629800762448992, 18.548200505120413, 14.648775918143135, 12.86196414061955, 6.432649203709193, 9.549566796847753, 15.719380412782941, 5.109684833458491, 3.5680788925715854, 4.008157815252032, 4.219002204281943, 5.249250258718218, 4.224151253700256, 3.191890610115869, 4.455970951489039, 5.70385091645377, 16.931313003812516, 37.90767615182059, 36.70843097141811, 40.707247802189414, 40.58969470432827, 32.8554880959647, 49.45749296460833, 45.29739107404436, 43.46267407281058, 42.25622361046927, 41.17892278943743, 43.179305689675466, 46.32944175175258, 47.12855059759957, 44.47911214828491, 45.928020000457764, 46.315156255449565, 44.38941437857491, 45.11930874415806, 45.56387186050415, 47.111395495278494, 44.87308195659092, 44.1088878086635, 39.945506368364605, 37.7097567149571, 39.76291118349348, 40.03209829330444, 37.51491533006941, 38.240373270852224, 39.1059763772147, 40.358642782483784, 39.531789779663086, 39.90856279645647, 41.553611346653526, 38.02202613013131, 42.29295873641968, 43.07633686065674, 48.958216258457725, 52.29608917236328, 54.98759201594761, 53.60558836800711, 52.5806804384504, 56.56243249348232, 53.004711627960205, 57.2700856753758, 55.94502946308681, 56.89056812013899, 58.09298515319824, 52.36403213228498, 49.34215981619698, 45.037872382572715, 58.87894453321184, 59.81437356131417, 62.5097257069179, 56.344877447400776, 60.49073205675398, 9.701986823763166, 0.2509680102978434, 38.33685595648629, 48.81715045656477, 37.74985129492623, 19.399507692881993, 28.29846862384251, 21.508327654429845, 43.773057052067344, 57.567326136997764, 41.71356235231672, 39.984961714063374, 52.480963366372244, 11.434917058263506, 0.450965908489057, 0.1900050179766757, 0.1388544019843851, 0.14341479513261998, 0.022961926979145834, 0.05386232351884246, 0.060081127498831065, 0.055019059484558444, 0.03831100996051516, 0.15587989054620266, 0.054413029325327704, 0.07032417000404426, 0.06453186938805239, 0.054248457441904714, 0.04701657693034836, 0.17213597467967443, 0.06710735761693545, 0.1380197631993464, 0.052672922877328734, 0.06319649211530175, 0.1451214871236256, 35.06007160459246, 57.99695062637329, 52.48417690822056, 31.82427815028599, 45.58347967692784, 35.251536164964946, 18.76195662362235, 16.739676475524902, 27.38851863997323, 53.39151436941964, 61.46011693137032, 11.770628826958792, 38.606922013419016, 72.55024092538017, 58.00330127988543, 66.10771138327462, 55.63157885415213, 51.96130064555577, 46.41006517410278, 51.29015677315848, 53.23815720421927, 60.03234549931118, 55.948684215545654, 53.945125988551546, 53.254085949489046, 61.43155983516148, 56.621262890951975, 55.810203143528526, 55.196837016514365, 57.45046785899571, 50.19509635652815, 51.820641313280376, 48.08666549410139, 42.49966417040144, 40.659367765699116, 43.18723358426775, 41.98470538003104, 42.721888405936106, 41.41031864711216, 43.68150063923427, 38.877578667231965, 42.89822326387678, 42.71307461602347, 46.99829271861485, 44.565019675663535, 47.991040910993306, 51.86269528525216, 50.57252597808838, 50.15327514920916, 53.629406792776926, 51.84371280670166, 53.544416427612305, 51.78007425580706, 51.05235815048218, 49.17206791469029, 51.52081959588187, 51.64022091456822, 48.151860441480366, 48.31240899222237, 47.87354339872088, 47.02761064256941, 49.40112917763846, 37.61831842150007, 45.113986424037385, 43.64354957853045, 36.24531963893345, 39.851907185145784, 33.934095178331646, 20.68127315385001, 20.487870046070643, 24.7258369241442, 18.632504735674175, 18.463660035814556, 10.641103608267647, 10.934963771275111, 21.38583438737052, 7.458371809550694, 7.851111786706107, 8.273998260498047, 9.175196988242012, 9.28545013495854, 8.133179119655065, 5.407623589038849, 5.5493733542306085, 8.84888960633959, 21.339215448924474, 38.55949708393642, 39.84041486467634, 43.09576402391706, 41.01173870904105, 35.63387468882969, 50.64438077381679, 46.760045937129426, 46.75851385934012, 43.38989864076887, 46.301152161189485, 46.87002549852644, 50.39001417160034, 47.21532317570278, 48.88604531969343, 48.921557562691824, 48.26706504821777, 46.427216802324565, 49.369858809879844, 47.462894439697266, 49.15321397781372, 46.90257086072649, 46.496222836630686, 43.13072041102818, 39.86363921846662, 41.651532309395925, 43.02906479154314, 41.64107527051653, 40.934269768851145, 42.83488348552159, 43.89663423810686, 41.423690455300466, 42.56372308731079, 43.328511306217735, 42.62884507860456, 42.81186062949044, 43.29351322991507, 50.11221824373518, 53.42238174165998, 56.289906774248394, 57.32090827396938, 54.46284668786185, 58.590142658778596, 55.52714048113142, 60.23526069096157, 56.25410270690918, 60.0996526990618, 58.48257064819336, 56.14252158573696, 52.330788476126536, 48.05694457462856, 59.343035561697825, 61.35578972952706, 64.27664566040039, 58.320983341761995, 61.729776518685476, 8.87287391935076, 0.5073583839195115, 47.29888916015625, 48.42100238800049, 43.30930995941162, 25.618336507252284, 25.14166750226702, 14.6523003918784, 51.079761845724924, 67.22048623221261, 42.02252442496163, 47.310819217136924, 64.19294766017369, 20.939393520355225, 0.36666561343840187, 0.20382244725312504, 0.1495915265487773, 0.11552393888788563, 0.019952181427340423, 0.09026516069258962, 0.047367264184036424, 0.08959467309926238, 0.036366901959159544, 0.23538583357419285, 0.09730493436966624, 0.12004456988402776, 0.19206899936710084, 0.1567433127867324, 0.1346240889813219, 0.33924148072089466, 0.13166085870138236, 0.22560366562434606, 0.2256378230771848, 0.20087498612701893, 0.35384716412850786, 40.487809794289724, 65.61095687321254, 59.62771715436663, 43.45836271558489, 51.98451805114746, 47.01368645259312, 23.428821904318674, 14.234865648405892, 34.547058309827534, 61.643757820129395, 63.21655205317906, 14.332057050296239, 47.00104073115757, 76.18773405892509, 62.556209155491416, 67.52229513440813, 58.80725996834891, 52.90755844116211, 50.75943946838379, 53.19106578826904, 56.95946645736694, 61.02386038643973, 58.55299064091274, 57.99434852600098, 56.765993867601665, 62.40910884312221, 58.508556910923545, 58.964740889413015, 55.457505634852815, 61.21344198499407, 54.96535778045654, 52.55498252596174, 51.978688512529644, 45.070396900177, 43.32922349657331, 46.9730464390346, 44.273824146815706, 46.53716162272862, 45.64638866697039, 45.6213230405535, 42.176649366106304, 45.14217526572091, 45.90207890101841, 50.6001798084804, 47.84396144321987, 50.36305863516671, 54.15069886616298, 51.79096903119768, 51.152874265398296, 56.04253005981445, 52.81151001793997, 55.696454184395925, 53.78005068642752, 53.49152673993792, 52.51042372839791, 55.79690081732613, 55.38717596871512, 49.96400621959141, 51.056985650743755, 50.75360645566668, 50.60581479753767, 50.68807452065604, 42.46198756354195, 47.412856987544465, 46.11331108638218, 36.82590069089617, 43.25020163399832, 36.34705516270229, 19.699339832578385, 18.32477249417986, 24.346717153276714, 18.342386177607946, 17.162128686904907, 9.4812399489539, 15.853852374213082, 32.83875335965838, 18.397422858646937, 9.558997239385333, 8.921173453330994, 10.44627959387643, 9.632834877286639, 6.467902192047664, 5.842509167534964, 6.663156560489109, 8.519931486674718, 21.94261612210955, 43.03841011864798, 38.39382423673357, 44.66324635914394, 42.91367258344378, 38.49253034591675, 51.712756633758545, 48.423854623522075, 46.95378255844116, 46.095478534698486, 47.29497732434954, 49.70998007910592, 52.40653773716518, 51.61258445467268, 50.0357255254473, 52.865365505218506, 51.9950966835022, 47.24685410090855, 53.40964569364275, 51.936509472983225, 52.40464782714844, 50.11940962927682, 50.31610270908901, 46.632456166403635, 43.91421665464129, 44.470076016017366, 47.26571498598371, 43.29445471082415, 43.70177895682198, 46.56038250241961, 47.78909499304635, 45.50734479086739, 44.827515670231406, 46.607560770852224, 44.1625383240836, 47.40461294991629, 47.195340156555176, 54.21958678109305, 56.801273345947266, 60.66929381234305, 59.38689259120396, 58.60854843684605, 62.7672051021031, 58.863297189985005, 60.59596252441406, 58.70710168566023, 64.1279889515468, 59.855840410505024, 56.94224534715925, 55.16683122089931, 50.81321505137852, 62.05919756208147, 62.17489201681954, 67.53002847943986, 58.703342710222515, 63.89320237295968, 15.084726742335729, 0.5461290606430599, 47.52114813668387, 58.96553298405239, 51.05208717073713, 27.05771664210728, 34.87939412253243, 31.10126597540719, 57.32674823488508, 73.54212406703404, 53.05018063953945, 49.496670382363455, 75.59373950958252, 21.6694963318961, 0.45324738749435967, 0.2543250758733068, 0.1695070993155241, 0.23546636211020605, 0.19584765232035092, 0.1661592075335128, 0.19280873824443134, 0.1999507128660168, 0.07118687978280441], [0.012031099326642496, 0.02379546993012939, 0.07345360743680171, 0.021492868129696165, 0.1305706293455192, 0.04525850287505558, 0.2076481091124671, 0.08113352462117161, 0.1302088073321751, 0.1246921004993575, 0.29553880436079843, 0.08313739459429469, 32.43949597222464, 53.35898985181536, 48.06594944000244, 38.109448364802766, 41.097566332135884, 29.708780969892228, 26.773170539311, 28.103142602103098, 16.617080722536357, 41.09033325740269, 60.358764920915874, 13.860814588410513, 14.516458766801016, 72.09192384992326, 51.73375061580113, 63.1143718447004, 50.64043072291783, 51.77764586039952, 42.97621331896101, 56.061404841286794, 52.05991642815726, 57.3949795450483, 49.92677429744175, 50.34790461403983, 55.17769820349557, 55.85100643975394, 52.6422484261649, 51.67930800574166, 47.41387837273734, 52.115404742104666, 49.797034059252056, 50.73009375163487, 44.31730597359793, 41.80764096123831, 37.82045888900757, 42.57206439971924, 39.34703023093087, 40.618032932281494, 38.91281645638602, 41.753069809504915, 37.569399629320415, 40.470307282039094, 39.474119731358115, 42.652135440281455, 42.11984436852591, 43.4899457522801, 47.28572927202497, 52.169222014290945, 49.34707219260079, 51.9577431678772, 47.23638663973127, 49.04257781164986, 44.81640550068447, 50.479472228458945, 45.98961230686733, 47.17182397842407, 44.20992503847395, 45.2079747063773, 44.7143851007734, 44.076106207711355, 42.09589392798287, 47.09613377707345, 36.28460822786604, 39.43690865380423, 40.8510650907244, 34.82143919808524, 37.98797300883702, 21.125473226819718, 5.513260092054095, 5.838181742600032, 4.68404426745006, 7.377068332263401, 6.543112967695508, 12.289132935660225, 18.823137249265397, 14.568763068744115, 6.7750555617468695, 2.4133799161229814, 3.364235899278096, 3.146222923483167, 3.5085419501577104, 3.8551689045769826, 4.836357465812138, 4.908701241016388, 11.056919421468463, 20.681921073368617, 34.45547063010079, 35.4012177331107, 39.959305490766255, 37.81594950812203, 33.69644594192505, 48.74294716971261, 45.83140182495117, 45.50046954836164, 44.13963706152779, 46.9252358845302, 45.31309052876064, 47.54259375163487, 48.09379434585571, 43.02216523034232, 46.318133558545796, 47.781448500497, 47.66639675412859, 46.584510122026714, 47.08551345552717, 45.01769481386457, 45.62322684696743, 44.15848057610648, 38.2033497946603, 37.75699404307774, 38.65957546234131, 39.0996014050075, 41.01250648498535, 38.77135113307408, 41.155920778002056, 39.64308255059378, 39.67729895455496, 38.0032069342477, 39.642665658678325, 39.72665548324585, 42.02763482502529, 44.738092354365754, 49.74125392096383, 50.01384217398507, 53.8971278326852, 53.22090482711792, 54.26687274660383, 53.94300331388201, 53.25013242449079, 51.14965377535139, 60.77736609322684, 53.77418988091605, 61.31789425441197, 52.39686237062727, 53.86586441312517, 43.76302037920271, 57.12677213123867, 57.078628063201904, 66.38262380872453, 55.773666041237966, 56.01935434341431, 1.5146446504763194, 5.57232803106308, 46.45733029501778, 44.138970034463064, 26.289707933153423, 13.422741089548383, 30.017135075160436, 32.74105126517159, 20.554147175380162, 49.41114500590733, 30.704600266047887, 25.457171303885325, 57.506195885794504, 31.751672949109757, 0.1568071222198861, 0.02073745339709733, 0.08494041820189782, 0.14565774691956385, 0.04324484503428851, 0.014576046694336193, 0.059421014705938954, 0.031721698718943765, 0.021330671118838445, 0.049680983780750206, 0.015636500237243514, 0.1025895279433046, 0.005940680957532355, 0.0963990833344204, 0.029689516872167587, 0.041149874949561696, 0.05970193498900958, 0.17436049745551177, 0.035985602598105154, 0.2258399993713413, 0.10534213416810546, 39.76851143155779, 59.30240249633789, 56.15798480170113, 41.52186155319214, 47.01372814178467, 35.335814339774, 21.93080244745527, 26.605270794459752, 24.654378175735474, 43.86399507522583, 62.78213678087507, 18.086629935673304, 13.890921132905142, 75.0852494921003, 55.25925268445696, 66.27903311593192, 52.97869757243565, 55.6349834714617, 45.388127599443706, 60.00024482182094, 55.11271865027291, 59.817208426339285, 51.92472880227225, 55.811405181884766, 58.41522175925118, 55.19498184749058, 54.11984191622053, 54.38496085575649, 50.57502038138253, 54.62171377454485, 52.55057041985648, 53.20864125660488, 47.429647309439524, 42.35895620073591, 41.70167398452759, 43.12070458275931, 41.65452350888933, 41.88794476645333, 42.79036290305001, 44.668360233306885, 41.2538069997515, 41.13784851346697, 40.98373052052089, 43.884905678885325, 42.3012444632394, 44.559745992933, 50.0982905796596, 53.03696863991873, 51.22676835741316, 53.32619088036673, 49.389807088034495, 52.074639660971506, 49.58336305618286, 52.92543963023594, 49.23279169627598, 49.077541146959575, 48.438612597329275, 48.498450483594624, 47.126872607639854, 48.264150278908865, 47.628779206957134, 49.88120453698294, 40.89246245792934, 42.661553723471506, 43.054877349308555, 36.69464921951294, 40.532194886888774, 22.382138320377894, 7.004884600639343, 7.06169741494315, 8.847887328692845, 12.40099459035056, 8.585588489259992, 10.188332063811165, 26.313317911965505, 27.69005482537406, 15.758490085601807, 5.24692565202713, 5.140098835740771, 4.750100791454315, 3.7749267646244595, 5.518603256770542, 5.739506900310516, 5.458293327263423, 6.3852294853755405, 22.387535333633423, 39.001798561641145, 36.035178320748464, 41.721736907958984, 37.78768423625401, 37.71530832563128, 50.27282585416521, 44.75589711325509, 46.8449946131025, 45.65186037336077, 48.6039171900068, 48.30472428458077, 49.765836647578645, 49.033885615212576, 47.19465575899397, 48.381039823804585, 51.59235824857439, 50.1419426373073, 50.400419098990305, 48.944281646183555, 46.50284794398716, 48.329300062997, 46.01740162713187, 41.26328434262957, 41.25553362710135, 41.093116010938374, 41.89836706433977, 42.581958634512766, 41.63956751142229, 43.28666925430298, 41.94792856488909, 41.59166663033621, 41.30857270104544, 42.37068475995745, 42.51431792122977, 44.191272599356516, 47.20048529761178, 53.453537464141846, 52.14015422548567, 57.20157296316964, 55.24266038622175, 56.42557382583618, 56.21153456824166, 55.439704350062776, 54.475999627794536, 61.90817846570696, 55.91610063825335, 61.401390756879536, 55.71578754697527, 55.553171907152446, 46.3652458190918, 59.29443291255406, 60.46628829411098, 68.85585594177246, 57.350993973868235, 57.746506282261436, 1.3293794031654085, 7.77972252028329, 54.03097445624215, 45.847448689596995, 30.501865727560862, 19.194478511810303, 21.13348971094404, 19.691771507263184, 22.990800516945974, 53.115253993443076, 34.869263648986816, 34.86891276495797, 64.3471212387085, 46.2488773890904, 0.8760321895991052, 0.1201901834990297, 0.012410997512883373, 0.15079412130372866, 0.06287023890763521, 0.032935390914125104, 0.07201015989163093, 0.047326429946614165, 0.03761573887563177, 0.16255443596414157, 0.11782907162393842, 0.19088023315582955, 0.11036693703915391, 0.3090675984110151, 0.08126205950975418, 0.3420022768633706, 0.1647061790738787, 0.3272523640521935, 0.17201189776616438, 0.40488865811909946, 0.19582612918955938, 47.789060252053396, 68.72267287118095, 63.63454178401402, 46.57705470493862, 56.911617687770296, 43.66727072851998, 35.243629114968435, 34.02083648954119, 28.777208192007883, 52.79014083317348, 68.70416287013462, 19.400468281337194, 21.340919494628906, 83.17313330514091, 56.53372948510306, 70.0922600882394, 54.51785557610648, 58.71406378064837, 47.64352675846645, 61.66299738202776, 57.58411993299212, 62.589310373578755, 54.567239897591726, 58.791487557547434, 57.85586745398385, 58.091460023607524, 57.95638356889997, 54.975401401519775, 53.53443186623709, 58.19488395963396, 57.32656063352312, 57.01078585215977, 49.28764425005232, 46.141371386391775, 44.419680731637136, 47.08005911963326, 45.226630619594026, 44.96595852715628, 43.30095822470528, 47.33432844706944, 43.18466622488839, 42.08663545336042, 44.024380343300955, 46.55843005861555, 45.80462694168091, 46.2476475579398, 53.26909405844552, 56.159763540540425, 53.53875364576067, 57.05930164882115, 51.71439640862601, 53.895946638924734, 51.467506068093435, 53.46949052810669, 52.243630273001536, 53.5040717124939, 49.066375391823904, 50.53828872953142, 50.71553380148751, 48.236426966530935, 52.103912421635215, 51.30487305777413, 44.08634785243443, 44.7134644644601, 45.554957321711946, 38.747167927878245, 42.9376334462847, 25.307977846690587, 8.7087869984763, 7.53650256565639, 8.186420559883118, 12.271662558828082, 9.119277017457144, 19.10718481881278, 45.04307310921805, 40.92304842812674, 28.499207292284282, 16.06650025503976, 7.021207221916743, 6.258160395281656, 6.220178501946585, 6.389972499438694, 7.041651862008231, 10.213777235576085, 14.960937636239187, 24.25866436958313, 42.31909785951887, 37.52217272349766, 44.35243606567383, 39.87709787913731, 39.45028741019112, 50.14185231072562, 46.56244264330183, 49.102297578539165, 48.63178988865444, 51.69412851333618, 50.0720785004752, 53.5238219669887, 52.275150775909424, 48.88067436218262, 51.58916555132185, 55.69818081174578, 53.31843669073922, 53.987763609204976, 53.30424499511719, 51.244208335876465, 50.19226149150303, 50.892754554748535, 44.38697556086949, 44.9710237639291, 42.93320744378226, 44.30067893436977, 45.109174796513145, 44.23072794505528, 45.17472757611956, 45.61400311333792, 43.966703346797395, 42.84642791748047, 44.663770948137554, 44.91638660430908, 46.650643076215474, 50.087500027247835, 55.94990362439837, 54.622832434517996, 60.05171012878418, 58.384079933166504, 58.62916374206543, 58.857919284275596, 59.86082921709333, 56.51214490618025, 63.13593210492815, 59.43014512743269, 65.45362186431885, 57.06936264038086, 59.10656751905169, 47.992444447108674, 61.62836756025042, 61.7618077141898, 71.99219635554722, 57.907353605542866, 66.12086432320731, 4.9716245617185315, 6.39065819978714, 58.56002221788679, 52.31356041772025, 39.45074599129813, 20.66188246863229, 37.56160722460066, 48.17482076372419, 29.210237298692974, 54.75096069063459, 45.13469900403704, 34.61440372467041, 73.34917259216309, 51.28166260038103, 0.9969789939267295, 0.26550573163798874, 0.18449040103171552, 0.21876194274851254, 0.1473133045115641, 0.10850558656134776, 0.1513547540775367, 0.06868776745562043, 0.09269076053585325], [0.02533104387111962, 0.005897723753670496, 0.05043135530182293, 0.009026516578160226, 0.07138066259878022, 0.03528552409261465, 0.0052540306600609, 0.06336964746671063, 0.04661634983494878, 0.045543480797537735, 0.24934891717774527, 0.14031999691256455, 33.505054337637766, 55.60394934245518, 35.7042738369533, 26.062675544193812, 36.41979932785034, 28.88445016316005, 13.880337289401464, 26.56160831451416, 13.359332697732107, 27.777418000357493, 55.83203785760062, 29.45459154673985, 2.444629873548235, 56.12895175388881, 60.70766176496233, 61.38113675798689, 55.70590026038033, 51.63037531716483, 47.35937670298985, 57.708423205784385, 52.878563608442036, 58.276650360652376, 49.44920028959002, 57.2581000328064, 54.449158736637656, 53.47798817498343, 53.95161213193621, 52.83983434949602, 48.976163455418174, 49.48474727358137, 49.92276866095406, 50.635438442230225, 45.19139977863857, 41.72853224618094, 39.831733090536936, 40.515456676483154, 40.76409101486206, 42.15027747835432, 40.20585189546858, 40.903499671391074, 40.245081424713135, 42.16044616699219, 41.123344148908345, 42.1322295325143, 39.45167357581002, 43.568925925663535, 49.085944993155344, 49.460279192243306, 48.49452822549002, 50.0746944972447, 45.58587680544172, 49.385923045022146, 48.54134866169521, 47.060607637677876, 45.845141887664795, 45.99361099515642, 45.09958628245762, 45.04353516442435, 43.546469347817556, 44.87970706394741, 43.28131219318935, 47.15303952353341, 35.997671944754465, 36.35269709995815, 38.418087346213206, 36.362681661333355, 37.01355069024222, 17.650151048387798, 4.908765077590942, 7.270281902381352, 10.091397745268685, 5.05809098482132, 9.598268457821437, 20.084355149950298, 26.115695510591777, 21.00450161525181, 18.217329025268555, 13.989144342286245, 9.456720624651227, 7.600170646395002, 7.4380804640906195, 10.058164511408124, 4.421649021761758, 4.22201555115836, 8.782855663980756, 17.500976698739187, 27.816536358424596, 35.95441593442644, 39.00865990774972, 34.12483017785208, 33.83475678307669, 45.785845960889546, 45.042753492082866, 45.85434477669852, 42.04989685331072, 45.48972415924072, 44.09177786963326, 45.209315708705354, 46.206277983529226, 45.430772168295725, 45.26664529527937, 45.85548775536673, 45.989497661590576, 46.56177561623709, 44.881624766758506, 46.039437838963096, 45.86772700718471, 40.423549379621235, 41.15445123400007, 39.08224480492728, 39.10445819582258, 40.80009657996041, 39.84611586162022, 38.72446468898228, 39.993243966783794, 39.63313620431082, 39.78788300922939, 39.05965621130807, 40.54753303527832, 39.48252010345459, 41.669496876852854, 47.84290531703404, 54.1423783983503, 51.74798400061471, 54.832376207624165, 53.23620476041521, 55.576153073992046, 52.17338745934622, 57.474133423396516, 49.10691813060215, 59.24337754930769, 57.37650775909424, 58.00026144300188, 54.58146286010742, 54.50309412819998, 46.4336508342198, 54.48717927932739, 59.46394811357771, 63.03256375449044, 55.45622021811349, 39.53196348462786, 0.1919033553983484, 18.401831490652903, 51.80290603637695, 44.490785121917725, 16.500668866293772, 36.80139786856515, 110.49082374572754, 75.14542089189801, 25.194824695587158, 28.015286105019705, 36.5006103515625, 26.553586619240896, 46.79568672180176, 55.11850997379848, 5.83849093743733, 0.3954034713762147, 0.024151302175596356, 0.02440295385063759, 0.02854470955207944, 0.07068768156958477, 0.049179695679673126, 0.1181210588131632, 0.05981421217854534, 0.03476382226550153, 0.020843968127987215, 0.04264280805364251, 0.0020478468878926443, 0.07326973123209816, 0.02044848059969289, 0.03437008196488023, 0.04714851467204945, 0.05583416324641023, 0.055510529183915684, 0.0959698963644249, 0.36064714352999416, 42.54166603088379, 61.891537530081614, 42.38839224406651, 31.25181606837681, 42.886307103293284, 34.64303725106375, 12.132966961179461, 23.092216423579625, 17.9154680115836, 30.836292948041642, 60.89203916277204, 36.45895937510899, 2.8167180674416676, 51.66242388316563, 65.1526745387486, 63.398421151297434, 60.78242438180106, 54.419403076171875, 49.9936854498727, 59.385704449244905, 57.92278208051409, 58.25198425565447, 50.36197471618652, 60.776316915239605, 55.3965734073094, 56.895153931209016, 54.63170528411865, 53.920327867780415, 52.982793535505024, 55.189051559993196, 52.02873986107962, 52.53515584128243, 46.88982786451067, 42.74312904902867, 41.41151026317051, 42.67382424218314, 42.763178076062886, 43.92837013517107, 41.95346280506679, 44.528249808720176, 42.84114728655134, 43.7438885143825, 42.8268826348441, 44.180082525525776, 43.063496589660645, 47.270637784685405, 50.31960807527815, 51.20241839545113, 50.54546274457659, 52.26286288670131, 51.19393464497158, 52.048896585192, 50.62717356000628, 51.17197138922555, 47.9853572845459, 49.80380507877895, 48.69429240907942, 48.50012499945504, 46.14593635286604, 49.31112568719046, 45.256730215890066, 51.225059100559776, 39.3068904876709, 38.283997535705566, 40.20294754845755, 36.7378739629473, 38.11942250388009, 18.035119465419225, 4.503354626042502, 5.117657891341618, 9.517382740974426, 7.200689613819122, 7.738508411816188, 22.942540066582815, 32.364816733769004, 25.980196952819824, 23.647759641919816, 18.572819709777832, 4.369473261492593, 5.810941764286586, 5.2917784452438354, 5.72366544178554, 3.3711927831172943, 5.764661984784262, 11.316655244146075, 18.73198209490095, 33.19484853744507, 36.71957240785871, 38.550238609313965, 37.344215461185996, 37.699786049979075, 50.74163123539516, 46.43874386378697, 49.334951060158865, 46.131734234946116, 47.82189743859427, 44.703278405325754, 48.6034551348005, 49.20555475779942, 46.987665448869976, 48.46820150102888, 47.85403980527605, 47.668620177677695, 47.075035572052, 47.564046314784456, 47.07420873641968, 47.20081533704485, 44.56453330176217, 44.045117241995676, 43.020414284297395, 41.03697109222412, 43.31775549479893, 42.30298498698643, 41.70974431719099, 42.31197943006243, 42.34680380140032, 42.383716106414795, 41.46183259146554, 43.62912164415632, 42.23793247767857, 43.12630483082363, 49.795182364327566, 57.00024196079799, 54.34889970506941, 56.63910239083426, 54.84173543112618, 58.26169088908604, 54.861145223890034, 58.919841630118235, 53.290866238730295, 59.631573404584614, 59.97728797367641, 60.12015683310372, 57.25987877164568, 57.56016949244908, 50.08027737481253, 55.89340434755598, 61.197752952575684, 64.3744068145752, 60.778109550476074, 43.99913753782, 0.056439284168715985, 25.00832462310791, 57.22627033506121, 45.582767486572266, 19.39031001499721, 43.31386450358799, 114.19702761513847, 86.64051369258335, 33.225698539188926, 36.22716052191598, 39.97942052568708, 29.37897777557373, 59.31563186645508, 62.84094633374895, 15.473283903939382, 0.42202790986214367, 0.10166034887411765, 0.1031334823263543, 0.0110338504725535, 0.05315164290368557, 0.02382228902674147, 0.08713492937386036, 0.11259230119841439, 0.14969771727919579, 0.10453237726220063, 0.0905370225331613, 0.1411417978150504, 0.21524314156600408, 0.08076504617929459, 0.10110440477728844, 0.11880901189787046, 0.25937880469220026, 0.166912544252617, 0.291742780911071, 0.4822882520301001, 53.01497411727905, 68.81408337184361, 47.23510817119053, 32.777782917022705, 51.8911828994751, 39.88811772210257, 20.54504156112671, 33.92138344900948, 23.243119137627737, 40.61975261143276, 66.53203092302594, 36.441394329071045, 4.992820041520255, 64.08836337498256, 65.49686745234898, 69.24289839608329, 61.31766496385847, 57.719529901232036, 52.528975418635774, 63.04156167166573, 59.707670075552805, 60.74882984161377, 54.719544410705566, 62.013117109026226, 56.3213334764753, 61.41030529567173, 59.04708399091448, 59.13749395098005, 55.89311252321516, 56.55488327571324, 56.2844489642552, 56.761258670261924, 49.718852928706575, 46.107738631112234, 43.57826777866909, 45.80653074809483, 45.799863951546804, 46.60868637902396, 42.453132084437776, 47.08932106835501, 44.54594687053135, 46.30236462184361, 45.1457952771868, 46.99539531980242, 43.89539051055908, 50.57817138944353, 53.879423822675435, 54.04034062794277, 53.6433344568525, 55.50613260269165, 51.04829345430647, 54.855725628989084, 54.903171403067454, 53.676946367536274, 50.44402946744646, 52.465444564819336, 52.05424322400774, 50.79533733640398, 50.511673654828755, 50.68024737494332, 48.56817218235561, 54.33857468196324, 44.27983781269619, 41.947779178619385, 41.902706214359824, 37.06968171255929, 39.96780661174229, 21.8075726713453, 7.0840158973421365, 9.228326388767787, 14.727750880377632, 9.282067230769567, 13.918740851538521, 33.604740142822266, 39.077982085091726, 34.640699182237896, 33.58833197184971, 29.3750833102635, 19.954899787902832, 17.47076940536499, 14.058123452322823, 13.52249985081809, 6.982435405254364, 8.649458936282567, 14.909564392907278, 21.868006365639822, 36.19442408425467, 37.94802434103829, 41.946142877851216, 38.66018690381731, 40.82893507821219, 50.85398013251168, 47.42719112123762, 51.76727219990322, 45.659110818590435, 51.368567194257466, 47.563170841761995, 52.65898316247122, 50.865312644413535, 50.85276767185756, 50.773808343069895, 52.501193046569824, 50.030872208731516, 51.592729977199006, 51.414133480616975, 52.13835116795131, 51.33123104912894, 47.11887870516096, 47.237512247903005, 45.73895951679775, 44.116888659340994, 47.017532280513215, 45.61060197012765, 44.85893195016043, 43.77221284593855, 45.136755670819966, 43.5316801071167, 45.37536375863211, 46.022623198372976, 45.97169985089983, 46.534090518951416, 53.274537972041536, 57.68194014685494, 57.889104161943706, 59.52395970480782, 57.742611816951204, 61.481044905526296, 58.26292766843523, 60.857096672058105, 55.828014850616455, 63.55629811968122, 60.6598025730678, 65.46412754058838, 58.80176394326346, 59.90486689976284, 52.03359317779541, 60.05199500492641, 62.78483963012695, 69.06932544708252, 60.7968418938773, 52.987191745213096, 0.4912026822566986, 22.201994112559728, 61.798779078892295, 53.31291287285941, 28.64096096583775, 44.34348678588867, 113.74958447047642, 84.29276602608817, 36.43368182863508, 35.93224423272269, 51.572587149483816, 38.00308534077236, 61.2216408593314, 74.36035782950265, 14.610989877155848, 0.5409262169684682, 0.28956818474190577, 0.2061115258506366, 0.1405383494815656, 0.18510564230382442, 0.16068714830492223, 0.22376427932509355, 0.3652417484138693], [0.10412667438920055, 0.03769017416717751, 0.05381160302619849, 0.023177994581471597, 0.026404984993860126, 0.046030027725334675, 0.023327340139076114, 0.056977053705070696, 0.06680028659424611, 0.08989237355334417, 0.06908060530466692, 0.6712314848388944, 45.20105777468, 51.90474578312465, 42.60381071908133, 31.73950665337699, 31.951291220528738, 36.74055249350411, 13.681883709771292, 30.5684711592538, 9.329184702464513, 28.06855273246765, 45.98488405772618, 57.94811521257673, 4.9185585635049005, 19.177137545176915, 71.85939543587821, 51.96253047670637, 60.177847726004465, 49.57908296585083, 55.532504490443635, 53.94906561715262, 58.9291661126273, 51.26396901266915, 53.66250453676496, 58.42099571228027, 51.83590650558472, 53.17528642926897, 51.10174247196743, 48.48062835420881, 49.61966739382063, 48.862706320626394, 48.42187786102295, 48.495004177093506, 42.946256160736084, 40.64705555779593, 40.579849106924875, 41.84993117196219, 41.23928526469639, 40.60877445765904, 41.814887932368684, 44.061143262045725, 42.12580244881766, 42.07405226571219, 41.76833847590855, 42.477023465292795, 40.50124761036464, 44.00237887246268, 45.72428839547293, 47.98047270093645, 46.046650069100515, 47.99810375486101, 45.828685079302105, 44.31009374346052, 45.18783187866211, 46.46102326256888, 46.69595922742571, 44.2830548286438, 43.274888583592, 45.19686801092965, 43.73618991034371, 44.53534739358084, 42.71815027509417, 45.10150398526873, 35.29643889835903, 35.11397572926113, 35.27011912209647, 35.021814823150635, 31.141159057617188, 15.574065787451607, 4.491230888026101, 6.540826576096671, 8.871136001178197, 15.648097106388636, 32.83391741343907, 35.560491289411274, 30.118502344403947, 24.761779955455236, 18.385650873184204, 17.78682385172163, 19.5463022845132, 22.851994616644724, 20.040267092841013, 17.795627219336374, 12.038617372512817, 5.940447066511426, 5.578643075057438, 14.492373704910278, 26.79171701839992, 32.08517605917794, 38.38048716953823, 31.44254411969866, 34.15245621544974, 48.01275750568935, 45.3326427595956, 46.94287041255406, 43.83590350832258, 44.34287534441267, 43.76032100405012, 45.2462523324149, 43.67612273352486, 42.301306997026714, 45.05816807065691, 44.21752984183175, 44.49438081468855, 44.60513162612915, 43.40576137815203, 43.391958781651084, 42.79657806668963, 44.99508537564959, 40.15344510759626, 39.77191604886736, 41.49552093233381, 41.00134072984968, 39.09104469844273, 40.6252555847168, 40.55139970779419, 39.3805969783238, 41.138803890773225, 40.8814252444676, 39.377032552446636, 40.486447947365896, 40.28531149455479, 51.74452032361712, 53.95987006596157, 54.73493814468384, 53.62545674187796, 53.28977189745222, 51.767602239336284, 56.7834164755685, 54.212850502559114, 54.083068575177876, 53.602294921875, 59.17343003409249, 53.132944107055664, 58.141796248299734, 51.12500851494925, 52.35721942356655, 52.051595960344585, 61.3244047164917, 56.15420845576695, 67.00771849496024, 23.16658125604902, 0.108588700315782, 37.14718539374215, 46.81428010123116, 36.98881162915911, 13.151022229875837, 43.26051276070731, 75.4064438683646, 23.1234416280474, 21.524452686309814, 25.812236411230906, 33.918326241629465, 42.84537526539394, 29.668589115142822, 56.42643192836216, 29.991433688572474, 0.2881429897887366, 0.05732165449964149, 0.00916789613464581, 0.10222807912422077, 0.03854642429256013, 0.04667534166947007, 0.045020750989871364, 0.046808809507638216, 0.032249721099755595, 0.08178613960210766, 0.06589060183614492, 0.07304679855172123, 0.045322244454707415, 0.08714369604630129, 0.027744794796620096, 0.050777435302734375, 0.010804824547709098, 0.07526642230472394, 0.07603808625468186, 0.8310651853680611, 54.55869708742414, 57.876104082380024, 48.2850296156747, 28.855901752199443, 35.28026001793997, 42.90625538144793, 13.044084242412023, 22.23729964665004, 9.881185208048139, 33.236701011657715, 50.19826820918492, 63.43163354056222, 7.945740171841212, 15.318509306226458, 74.57646070207868, 56.18623965127127, 62.6409215927124, 52.67366123199463, 59.66905198778425, 55.8730148587908, 62.11433151790074, 52.331841128213064, 57.4314923286438, 59.82049492427281, 56.65948493140084, 54.32886110033308, 54.466685567583355, 52.62274483272007, 52.17401279721941, 51.117250851222444, 51.849187987191335, 50.65446260997227, 45.382357120513916, 42.77304104396275, 42.76821552004133, 44.52330616542271, 43.48021132605416, 43.25987005233765, 44.14712027141026, 45.12633337293352, 44.197282791137695, 43.600199767521445, 43.929308141980854, 44.25673852648054, 44.757095677512034, 45.3584692137582, 48.465606348855154, 50.20034572056362, 49.59157930101667, 49.98532329286848, 48.60247891289847, 48.19280617577689, 49.25466462544033, 49.496045044490266, 49.71801567077637, 48.64229556492397, 49.356226444244385, 48.4508171081543, 46.39049557277134, 49.09370960508074, 47.364031996045796, 50.11502879006522, 39.45645046234131, 37.39633042471749, 36.78034135273525, 36.51675796508789, 31.957343101501465, 19.04636549949646, 4.7059171966144016, 6.081879385880061, 5.744426224912916, 8.41544360773904, 26.33179838316781, 37.57865115574428, 34.939096518925254, 30.74681404658726, 26.7305520262037, 26.35577314240592, 25.968999930790492, 24.968224831989833, 21.949116161891393, 16.34520639692034, 10.421009864125933, 7.768628852707999, 9.057491030011859, 17.18110942840576, 30.09873124531337, 33.60047394888741, 37.51310532433646, 34.56041274751936, 37.87022188731602, 50.7352180480957, 47.118847438267295, 48.54843235015869, 46.24459729875837, 47.189500195639475, 47.128074645996094, 47.84371130807059, 47.78963695253645, 46.85007374627249, 47.8405568259103, 46.12518555777413, 48.55867052078247, 45.561842986515586, 45.42138862609863, 46.4580077443804, 45.471280166081016, 48.85024125235421, 43.646770068577354, 43.39201436723982, 43.33909688677107, 43.285217080797466, 42.62909868785313, 42.72187103543963, 42.75900220870972, 42.678333623068674, 43.89840950284685, 43.18114348820278, 41.25267096928188, 42.69475221633911, 41.58251585279192, 53.77036142349243, 55.68985686983381, 56.08928448813302, 55.17288310187203, 56.176286356789724, 55.74978508268084, 57.844666957855225, 57.77718257904053, 57.9092435155596, 54.298466205596924, 59.97971289498465, 54.93984399523054, 59.98708493368966, 53.51341009140015, 53.859023911612375, 53.94063745226179, 65.99916662488664, 58.55351175580706, 74.00170571463448, 23.60905817576817, 0.2908064568681376, 46.482809339250835, 47.35088947841099, 38.38364512579781, 12.878326279776436, 44.32720020839146, 95.37892954690116, 36.23478616986956, 33.729321343558176, 30.776597499847412, 42.59087317330496, 37.87481117248535, 41.972980294908794, 63.441006660461426, 47.05567789077759, 1.2076933213642664, 0.1193229750330959, 0.038257755139576535, 0.1146395770566804, 0.04471274698153138, 0.06598588172346354, 0.018767255724274685, 0.037942304209406884, 0.2579481543174812, 0.1453449558466673, 0.1654764520270484, 0.13227620853909425, 0.0829446092247963, 0.1849094099764313, 0.16465359260993345, 0.13193140418401786, 0.14244668850941317, 0.14280445288334573, 0.2615523152053356, 1.1543424470084054, 63.37553378513881, 66.41480091639927, 58.730002948216026, 42.82771989277431, 46.32909434182303, 53.356019496917725, 19.476743868419103, 39.61846160888672, 14.655581678662982, 40.634687764304026, 56.03198616845267, 68.41112954275948, 6.514846393040248, 24.147390706198557, 76.14991501399449, 56.93873998097011, 64.49137278965541, 55.66612877164568, 60.723253522600444, 58.51797866821289, 64.68228844233921, 56.21179859978812, 59.42532307761056, 62.38460949489048, 58.130137171064106, 56.144849232264924, 58.02650478907994, 54.79716273716518, 55.443442480904714, 52.83010687146868, 55.344409806387766, 54.795338835035054, 46.14910473142351, 46.2630934034075, 45.990602425166536, 48.33173540660313, 46.594338348933626, 45.464696747916086, 48.1628976549421, 48.50604139055525, 48.60727316992623, 46.684327942984446, 46.97532892227173, 45.16453456878662, 46.06382949011666, 49.25381694521223, 53.08332702091762, 52.73454829624721, 51.983295168195454, 52.76071521214077, 51.9357590675354, 48.7646290234157, 51.16871268408639, 50.70231832776751, 55.03887319564819, 51.736828667776926, 51.466321400233674, 52.57634823662894, 50.68873459952218, 50.641799518040244, 51.01491430827549, 51.04796688897269, 44.09389707020351, 39.8096204485212, 38.95562430790493, 38.78879805973598, 32.412700244358604, 23.367570059640066, 7.264716395309993, 10.97001222201756, 12.22139494759696, 19.853273698261805, 36.52110753740583, 38.646728243146626, 38.72880731310163, 36.64600140707833, 33.82534197398594, 33.66159725189209, 35.11739771706717, 37.36269072123936, 33.039573669433594, 27.45681769507272, 16.042372635432653, 9.129459602492195, 9.028761965887886, 18.01274974005563, 35.91547475542341, 34.95730079923357, 39.270332540784565, 35.14915445872715, 41.348312922886436, 51.332096099853516, 47.30884940283639, 51.45828233446394, 48.16409969329834, 50.458207266671316, 50.50815091814314, 51.154298646109446, 50.031254359654014, 50.86070251464844, 50.50338792800903, 49.02140317644392, 52.34546307155064, 49.94742086955479, 50.0207382610866, 50.412502016339985, 47.18537296567644, 51.55987889426095, 45.92437219619751, 46.04268959590367, 46.46498026166643, 45.42789213997977, 44.04921667916434, 45.18623379298619, 45.890871456691194, 45.03975534439087, 46.10294437408447, 46.88934843880789, 43.67977053778512, 47.59987817491804, 44.168836866106304, 57.26979037693569, 59.04136562347412, 59.75377137320382, 58.92656053815569, 57.15941824231829, 56.7323055267334, 61.92019190107073, 59.80133874075753, 60.270501954214915, 57.81849309376308, 63.26626641409737, 56.3796740259443, 62.60060119628906, 55.00371878487723, 55.932203088487896, 57.09072487694876, 66.86137553623745, 62.11834757668631, 72.98986039842877, 30.072341987064906, 0.2879148120326655, 44.58384581974575, 55.64741379874093, 45.931914465767996, 21.11813940320696, 48.99384314673287, 81.4974501473563, 26.462018047060283, 30.689314229147776, 35.18552133015224, 46.98481668744768, 56.71790885925293, 43.6037711415972, 72.94676072256905, 50.61954096385411, 1.2482978339706148, 0.21352802217006683, 0.10384467523545027, 0.1884636985404151, 0.07888694945722818, 0.21078494936227798, 0.12290482568953719, 0.10275349593056099], [0.038364186749926636, 0.0316647492748286, 0.028338416246697307, 0.013947349224638726, 0.051612152119300196, 0.009532656204620642, 0.049264960390116484, 0.10805426577904395, 0.034112228479768546, 0.20344337687960692, 0.08661532082727977, 1.6961966284683772, 50.366098472050254, 47.003813062395366, 36.573896476200645, 51.27842126573835, 48.925323486328125, 35.47305515834263, 15.328702313559395, 24.65132965360369, 18.743941681725637, 29.099837371281215, 55.00098466873169, 52.24518666948591, 32.91718462535313, 1.9212993724005563, 56.71169369561331, 58.94074875967843, 61.76140471867153, 52.76120853424072, 58.38321140834263, 54.863417284829275, 57.58257743290493, 54.34862872532436, 59.038572447640554, 57.0196031161717, 54.627727440425325, 51.39875711713518, 50.55695506504604, 50.288195269448416, 50.943160261426655, 50.46349137169974, 48.14455093656267, 46.90457541601998, 44.08766106196812, 41.073796544756206, 41.45884486607143, 41.12773888451712, 42.11538362503052, 42.903483050210134, 45.48512445177351, 43.6196095602853, 42.382670402526855, 41.49542713165283, 44.41890948159354, 42.41494825908116, 44.19646290370396, 43.774585655757356, 46.174444811684744, 45.64400890895298, 44.12772784914289, 47.46812295913696, 44.495947633470806, 46.01756490979876, 44.657666955675396, 46.085202148982454, 43.911944593702046, 44.60992588315691, 41.29360628128052, 43.72373873846871, 41.264448165893555, 43.79915101187569, 41.564030170440674, 45.25113691602434, 31.239100864955358, 33.004422732761924, 32.957734312329976, 34.12521580287388, 27.80913826397487, 16.024583509990148, 8.670049054282051, 5.649439139025552, 11.834184867995125, 40.07788692201887, 40.65367719105312, 35.60410165786743, 33.95914690835135, 28.452890600476945, 24.454304797308787, 19.765783718654088, 17.72908432143075, 17.462551423481532, 19.717492001397268, 28.940169504710607, 29.93477807726179, 18.479156255722046, 11.360034584999084, 10.646637848445348, 24.398496866226196, 32.754353591373985, 35.25455168315342, 31.74373115812029, 34.64764390672956, 44.118587493896484, 46.540538447243826, 45.74603625706264, 44.39889866965157, 43.641232354300364, 42.92165258952549, 43.58404867989676, 41.81132003239223, 42.57102911812918, 44.187635217394146, 43.27252967017037, 43.59869200842721, 46.011294160570415, 40.40139504841396, 41.021556513650076, 43.26810366766793, 43.28209039143154, 39.009542328970774, 42.08152505329677, 42.71820586068289, 42.791363443647114, 38.11198445728847, 41.863271713256836, 41.344550473349436, 40.296345233917236, 39.98356512614659, 41.951347078595845, 38.95506150381905, 42.274420942579, 40.49722807747977, 50.967239243643625, 53.637567452022004, 54.65800768988473, 48.5557279586792, 54.60405145372663, 51.9764963558742, 54.87166132245745, 53.66178887231009, 57.28250905445644, 53.88343293326241, 58.8862054007394, 53.793078558785574, 58.873517990112305, 49.98594863074166, 54.02425554820469, 48.8936779158456, 67.26148060389927, 49.763015678950715, 74.24717167445591, 10.80584626538413, 3.1450706081730977, 48.79779624938965, 41.53238112585885, 28.51067703110831, 10.121279341833931, 26.50395563670567, 12.392306736537389, 10.938925981521606, 25.94419833592006, 34.435570989336284, 26.19217954363142, 34.062053203582764, 34.89584398269653, 54.11262968608311, 51.63029541288103, 4.352566991533552, 0.3763300691332136, 0.04561389237642288, 0.08103960180389029, 0.01710022410510906, 0.11361205790724073, 0.03945067737783704, 0.02023482688569597, 0.007030862391859825, 0.07926347532442637, 0.10379431436636619, 0.0701934705887522, 0.03259752797228949, 0.1402499313865389, 0.12214051027383123, 0.1045409200180854, 0.07238737786454813, 0.12053965617503438, 0.00830868081123169, 2.754333883523941, 62.19616045270647, 54.03236757005964, 43.84825393131801, 53.549888134002686, 54.067973613739014, 42.44010421207973, 25.51284200804574, 23.455810444695608, 24.66833884375436, 32.92621728352138, 60.87187549046108, 57.408396516527446, 41.79670449665615, 2.1924100475651875, 51.78113385609218, 63.5085848399571, 62.64832142421177, 59.16792706080845, 59.05232988085066, 57.135849952697754, 60.73814351218087, 56.796246324266704, 62.00519616263253, 57.53291170937674, 55.134445667266846, 56.568696294512065, 53.994440828050884, 51.199507100241526, 51.48433460508074, 52.134595666612896, 49.87044872556414, 48.926258019038606, 45.936166763305664, 43.50367886679513, 44.15209518160139, 41.09481831959316, 41.37833261489868, 45.30219922746931, 47.79193680627005, 45.07511125292097, 45.521550382886616, 44.5024858883449, 47.32524715151106, 47.344556195395334, 47.690006732940674, 45.665388516017366, 47.74666929244995, 48.47463205882481, 47.08737904684884, 50.82205663408552, 48.812978063310894, 49.872289998190745, 50.30528783798218, 49.064506326402935, 47.84551436560494, 48.975941113063264, 47.02029071535383, 48.66187558855329, 45.021881103515625, 49.40641328266689, 45.82334886278425, 48.00841488157, 36.07330656051636, 35.843223912375315, 35.1600318636213, 36.85304035459246, 30.185708795275005, 19.424184220177786, 10.870569603783743, 5.631959642682757, 10.535604766436986, 36.11000347137451, 42.871104444776265, 39.33087566920689, 36.85281801223755, 32.17536020278931, 29.077424219676427, 24.84262572016035, 22.964239290782384, 25.179493495396205, 28.766740730830602, 31.505279404776438, 28.63671040534973, 16.78143514905657, 14.3800083058221, 12.836872458457947, 28.713083267211914, 34.65211854662214, 34.504500593457905, 35.17980643681118, 38.141868659428184, 46.673068387167795, 49.2831974029541, 46.888966287885395, 48.2183130128043, 45.97577844347273, 46.44876316615513, 47.8199519429888, 47.683388573782786, 47.19153949192592, 47.413037640707834, 46.80028642926897, 45.94376809256417, 48.46768733433315, 44.39061989103045, 44.385259355817524, 46.8406207220895, 45.1413380077907, 42.76315723146711, 43.92881481988089, 44.446389607020784, 43.543304443359375, 41.275568757738384, 42.411731243133545, 41.2759439604623, 42.008395263126914, 42.648584910801475, 44.582883494240896, 41.592020988464355, 43.21522787639073, 41.97845547539847, 51.55935777936663, 55.54302058901106, 56.79730939865112, 50.98568671090262, 55.62409217017037, 55.331767559051514, 57.317698206220356, 55.567929880959646, 60.877711977277485, 54.86380638395037, 59.84293760572161, 54.30761350904192, 59.87695598602295, 51.35495914731707, 56.96253408704485, 51.12490776606968, 68.88854721614292, 53.53436933244978, 77.29480443681989, 9.87363338470459, 5.308508838926043, 54.94490228380476, 44.72612408229283, 31.41675935472761, 10.790152021816798, 27.016597202845983, 16.569084303719656, 16.483895914895193, 40.273190362112864, 33.29982539585659, 30.17639126096453, 38.13996832711356, 38.3224002293178, 62.040840421404155, 62.55789756774902, 13.495531286512103, 0.57684802370412, 0.1009782108345202, 0.07592937137399401, 0.04850918433762022, 0.1698095766561372, 0.039414538602743826, 0.04822090534227235, 0.138335431260722, 0.12456594726869039, 0.21518822094159468, 0.08738980748291526, 0.09707490421299424, 0.18410236042525085, 0.18345925850527628, 0.22450253899608338, 0.14998775028756686, 0.2925835129405771, 0.12224778666027955, 3.2536529302597046, 75.37772001538957, 62.284444264003206, 53.22467075075422, 60.05371815817696, 65.14879744393485, 50.66211257662092, 22.228716884340557, 36.53459051677159, 27.896169662475586, 41.67334270477295, 65.08165005275181, 64.73438603537423, 37.93798419407436, 3.55557039805821, 64.07219491686139, 62.40036800929478, 68.3122010912214, 58.34430149623326, 63.76962866101946, 60.53877885001046, 62.949887139456614, 59.54605497632708, 63.86579867771694, 61.63847024100167, 61.02857821328299, 57.414663791656494, 56.57178824288504, 54.58360637937273, 56.12170825685774, 56.63973815100533, 53.40626539502825, 52.107310090746196, 50.12462772641863, 46.258868898664204, 47.233291217258994, 45.81321144104004, 44.72474833897182, 48.23613861628941, 51.941404478890554, 49.2439991406032, 46.91152708871024, 46.816830090114046, 51.43597861698696, 49.649430002485005, 50.58753061294556, 48.618630000523154, 50.163186754499165, 50.70958614349365, 49.80280106408255, 51.918694291796, 50.17345271791731, 50.831818853105815, 51.14033971514021, 51.55221503121512, 49.9530245917184, 50.37406458173479, 49.34240995134626, 53.594478198460166, 48.46204539707729, 51.463587284088135, 48.53121818814959, 49.7169143812997, 39.76139300210135, 37.79832540239607, 36.34794453212193, 37.98094490596226, 34.29425157819475, 22.335745198386057, 12.675781079701014, 7.523990597043719, 15.530908788953509, 41.131609031132285, 41.1874030658177, 39.81451198032924, 38.20470469338553, 36.799518380846294, 35.53296947479248, 32.80631569453648, 29.311152935028076, 29.28498601913452, 32.21644837515694, 37.88014391490391, 33.81737239020211, 23.689954314913066, 16.11909290722438, 17.24842357635498, 30.11760950088501, 38.862990924290244, 34.71076134272984, 39.42579501015799, 42.390000752040315, 47.97250311715262, 50.448747294289724, 47.5355725969587, 48.79264416013445, 48.02520520346505, 47.57278367451259, 49.69835574286324, 47.57320056642805, 48.434846673692974, 49.82222127914429, 51.36487422670637, 50.18332610811506, 51.183463709695, 47.21447549547468, 45.856682845524375, 50.12162957872663, 48.863581793648855, 45.400912284851074, 46.38582290921892, 48.311630793980186, 49.03223194394793, 44.840130124773296, 46.647881167275564, 46.701142583574565, 45.50083780288696, 45.434906346457346, 48.41804245540074, 44.300484384809224, 45.93671914509365, 45.83285052435738, 54.94757039206368, 60.7481906073434, 59.02957453046526, 51.581727504730225, 56.30934088570731, 56.61625671386719, 59.30917698996407, 58.992234911237446, 61.49865164075579, 56.824202401297434, 63.1409695489066, 57.92868110111782, 62.823763438633506, 55.31816298621041, 58.8580721446446, 53.6387243270874, 72.88057218279157, 56.548108782087056, 81.2578067779541, 14.465614455086843, 4.026035964488983, 59.60208524976458, 50.32228660583496, 39.405930110386436, 16.946347168513707, 30.534827981676372, 15.68602384839739, 15.963046789169312, 36.18122598103115, 44.39773484638759, 36.684268610818044, 48.15899971553257, 45.675182001931326, 68.31088093348912, 72.36279242379325, 16.949558973312378, 0.6814792635185378, 0.18370680165077957, 0.16966662289840834, 0.16213810044739926, 0.21255014464259148, 0.2806275359221867, 0.14216719993523189], [0.024032914778217673, 0.09644808034811701, 0.026913245042253817, 0.0741980214204107, 0.029158719283129488, 0.03099961532279849, 0.0288639704563788, 0.21452191312398228, 0.03915507020428777, 0.16034199111163616, 0.05715098937175103, 5.178271804537092, 61.33507020132882, 44.107286248888286, 41.11252580370222, 40.67514017650059, 38.57983446121216, 36.974849224090576, 16.993087700435094, 17.147752864020212, 20.795821155820573, 19.018468482153757, 51.71085630144392, 51.451744079589844, 60.91656630379813, 10.384183543069021, 11.22827328954424, 76.70528452736991, 51.13517025538853, 63.078678948538645, 53.43580913543701, 60.91618415287563, 54.1178651537214, 58.09852981567383, 57.71726131439209, 55.41665717533657, 52.08329711641584, 51.14585658482143, 45.826670101710725, 49.56982796532767, 46.70823669433594, 51.1196688243321, 47.738286290849956, 49.428334849221365, 42.716656412397114, 40.41489887237549, 39.479678290230886, 41.6262651852199, 41.0067846434457, 44.3315497807094, 43.940258502960205, 44.58406468800136, 43.57907376970564, 44.187729018075125, 42.34485135759626, 43.58530282974243, 45.40420920508248, 44.58136878694807, 43.27108791896275, 45.5615268434797, 44.92069101333618, 46.58672659737723, 43.8788503238133, 45.06050613948277, 44.760173729487825, 44.32461895261492, 42.95017841884068, 41.75785711833409, 40.94325726372855, 43.41207729067121, 40.99353095463344, 43.30452265058245, 40.84577056339809, 44.07167673110962, 30.653329508645193, 28.196410008839198, 34.95262118748256, 36.35516718455723, 29.58361612047468, 17.538641146251134, 9.34511865888323, 17.349905490875244, 32.65708923339844, 41.19840553828648, 36.98919030598232, 39.63863222939627, 34.737202712467735, 32.88594552448818, 31.11468642098563, 29.559509345463344, 26.881989751543315, 23.556698288236344, 25.348600489752634, 25.655643122536794, 33.15953084400722, 35.435291699000764, 25.4863189969744, 21.220158066068375, 26.951186861310685, 30.14103535243443, 33.37049204962594, 29.043020214353287, 31.274411610194615, 44.78918593270438, 44.99981015069144, 43.860010283333914, 44.15897042410714, 43.062416144779746, 43.28268446241106, 43.53319134031023, 43.899208545684814, 43.4760285105024, 43.29239109584263, 44.1835983140128, 43.55802420207432, 43.50560351780483, 41.98353113446917, 42.25880834034511, 43.05031933103289, 43.031597409929546, 41.760709353855674, 42.53172663279942, 38.8960782459804, 41.8147211756025, 38.984639985220774, 40.77129282270159, 40.9403737613133, 41.75791965212141, 39.90321615764073, 41.75349364961897, 41.148135321480886, 41.74492652075631, 39.45927143096924, 51.13018492289952, 52.37383256639753, 55.718834332057405, 51.10254846300398, 54.06978709357125, 55.428830419267925, 56.56036193030221, 53.16417973382132, 57.91580261502947, 52.19299527576992, 57.23915924344744, 54.07649557931082, 56.47618103027344, 49.82388537270682, 51.88614545549665, 49.54486656188965, 63.82968888963972, 53.03115994589669, 68.96887534005302, 3.820377537182399, 15.546493598393031, 49.85866110665457, 45.6703599521092, 23.602374008723668, 8.643846528870718, 19.83969518116542, 28.362716879163468, 29.187040737697057, 35.52916186196463, 36.961821351732524, 28.675542150224956, 29.161259446825298, 28.760796546936035, 45.547189235687256, 53.69909722464425, 25.5512638092041, 0.46428812933819635, 0.05605134194982903, 0.03616361626024757, 0.048797405657491515, 0.08059991111180612, 0.025065787568954483, 0.0568757416414363, 0.06982511428317853, 0.07148312817194633, 0.04873042407312563, 0.08980904945305415, 0.02617862231896392, 0.030299957509019544, 0.0756383002070444, 0.13646914783333028, 0.043291986254709106, 0.0648347402789763, 0.04211306219388332, 7.032931438514164, 71.31326702662876, 50.8461286681039, 46.24957915714809, 45.81730740410941, 46.33203342982701, 41.33815118244716, 27.619054658072336, 23.534973008292063, 23.270576681409562, 24.404967376164027, 53.245425019945415, 55.35086120877947, 65.94910485403878, 16.532290118081228, 7.375253983906337, 72.95211083548409, 56.12222589765276, 61.79125417981829, 56.95479031971523, 64.70348739624023, 56.268554959978374, 60.80827168055943, 58.39381435939244, 56.25971337727138, 54.85618073599679, 52.93966954095023, 49.316399369921, 52.17868198667254, 50.144107001168386, 52.454921518053325, 50.60692303521292, 49.656527587345664, 44.76679188864571, 42.73238018580845, 40.673531668526785, 42.3424368585859, 44.825914110456196, 45.6967248916626, 46.10621697562081, 46.62624100276402, 46.33823817116873, 47.2762519291469, 42.58140972682408, 45.086349964141846, 47.64391238348824, 49.640939303806846, 46.114249093191965, 46.95393541881016, 47.75223132542202, 50.078995432172505, 47.731751510075156, 50.464585712977815, 48.412063530513215, 48.48206663131714, 45.610841682979036, 45.284856523786274, 44.77409097126552, 47.26391192844936, 44.037182399204795, 48.934505530766074, 44.00272628239223, 49.5524331501552, 35.72174160821097, 31.876969814300537, 37.86873149871826, 35.79955448423113, 31.258878912244523, 21.175927570887975, 10.892168947628566, 15.590932539531163, 33.775103024074006, 42.15468611036028, 40.07127571105957, 38.551569189344136, 38.82605430058071, 38.441530568259104, 36.13549293790545, 34.177563531058176, 30.761676243373326, 27.421894311904907, 30.459651947021484, 29.742094108036586, 35.38241938182286, 33.10368817193167, 23.600291286196025, 20.819898400987896, 29.570160933903285, 32.00397246224539, 33.758020877838135, 32.081545625414165, 34.900158814021516, 47.02197912761143, 47.24803182056972, 47.238009044102256, 47.69030550548008, 47.20228140694754, 46.430621419634136, 45.34097364970616, 46.59930631092617, 44.62949548448835, 46.83405120032174, 44.93242999485561, 45.198716231754844, 45.63703291756766, 44.607365471976145, 46.07742016656058, 44.955543177468435, 46.24859946114676, 44.7688033921378, 43.99341222218105, 42.147505147116526, 43.51739461081368, 42.17896659033639, 44.16758271626064, 42.047440665108816, 43.166646071842735, 42.11108616420201, 44.6746483530317, 42.85481786727905, 44.283822604588096, 40.58879838671003, 50.66273096629551, 53.96458094460623, 58.296886989048545, 53.59506532124111, 54.90657949447632, 57.554586614881245, 58.80645397731236, 56.06522287641253, 59.17841189248221, 56.71859325681414, 59.59804834638323, 56.69189827782767, 59.473550524030415, 53.33491781779698, 55.85770102909633, 53.83334684371948, 65.92089516775948, 56.02128594262259, 69.72304671151298, 3.322226873465947, 21.027866670063563, 56.22499322891235, 49.41283341816494, 27.674655880246842, 10.78059824875423, 16.331568820135935, 25.597201824188232, 29.251280307769775, 43.12605469567435, 39.57299607140677, 30.12970631463187, 30.595093182155065, 27.563887698309763, 55.661355359213694, 59.22301932743618, 43.61864376068115, 0.5908758395484516, 0.07679711588259254, 0.04793138123516526, 0.051681983550744395, 0.12968748887734755, 0.0736838886514306, 0.06620727412934814, 0.27381271017449244, 0.1315492939736162, 0.21238839546484606, 0.1567552007202591, 0.11866251618734427, 0.14899624777691706, 0.1691970495241029, 0.19820727141840117, 0.13924852226461681, 0.20138691365718842, 0.13696522478546413, 7.996170197214399, 80.7632895878383, 58.71636363438198, 53.342529569353374, 47.57896409715925, 53.30771909441267, 53.67845760072981, 22.612877573285783, 25.438353845051356, 31.568400314876012, 32.03130667550223, 61.78770365033831, 59.38211917877197, 70.79441724504743, 12.373504042625427, 13.730670486177717, 79.44074167524064, 56.0580974987575, 67.92255306243896, 56.86108691351754, 68.68137277875627, 57.63615846633911, 63.611765589032856, 59.17984322139195, 60.79344422476632, 58.7253407069615, 55.95092500959124, 51.30420255661011, 56.95984860828945, 52.46265833718436, 56.90708746228899, 54.86139535903931, 54.63772242409842, 47.383608545575825, 46.52984864371163, 43.44885410581316, 47.384112289973665, 46.74072994504656, 47.637141363961355, 48.01038122177124, 49.032641887664795, 49.56867456436157, 48.72510072163173, 45.690436771937776, 47.62644113813128, 50.75593410219465, 49.81642648151943, 47.64751502445766, 49.4362280028207, 49.9559463092259, 52.4966002873012, 48.79180342810494, 52.3293571472168, 51.197961126055034, 51.2234332220895, 49.3181711605617, 47.95849902289254, 47.43818317140852, 51.28086355754307, 46.47364119121006, 51.90717765263149, 48.70693465641567, 50.824186256953645, 39.55296441486904, 35.355234554835725, 37.33589499337332, 36.585920333862305, 34.84830093383789, 26.30308321544102, 11.66339293548039, 19.0770400592259, 36.39760678155081, 40.58209337506975, 38.77865021569388, 38.32323401314871, 38.5994040625436, 39.51337705339704, 37.02316352299282, 38.12413338252476, 34.67972721372332, 33.620019231523784, 34.390438965388704, 31.66490731920515, 35.721352509089876, 36.02460663659232, 26.10793958391462, 26.015467745917185, 32.78052050726754, 35.57253251756941, 35.374811104365754, 35.08106558663504, 36.725266456604004, 48.77462748118809, 48.734018734523225, 48.17837129320417, 49.72053091866629, 50.52667828968593, 47.94088881356375, 48.70374195916312, 48.35770429883684, 49.004369667598176, 50.91596848624093, 47.24326535633632, 48.487284728458945, 48.76244381495884, 47.747426646096365, 49.81099646432059, 48.21242094039917, 50.5869573865618, 48.29945060185024, 46.94131054197039, 44.98936700820923, 47.04506451742989, 44.40699332101004, 46.06275599343436, 46.097417082105366, 46.46718978881836, 44.974358899252756, 47.21988466807774, 45.89781618118286, 47.70542825971331, 43.13810287203108, 56.206601347242085, 56.64049550465175, 60.79563985552107, 55.64521469388689, 58.59353337969099, 57.822484833853586, 62.088081223624094, 59.55071026938302, 60.90592166355678, 60.82186235700335, 60.53261579786028, 57.79183980396816, 61.55719716208321, 54.18414054598127, 57.63280596051897, 54.030140672411235, 67.94444683619908, 56.455263478415354, 73.62452275412423, 5.8969074828284125, 17.280446086611065, 61.90059798104422, 53.204659938812256, 34.8065561567034, 16.930275985172816, 25.22232219151088, 36.19735622406006, 39.73407963344029, 48.03805242265974, 50.67387935093471, 40.155522618974956, 41.9333929334368, 38.12260477883475, 63.76927430289132, 67.45632893698556, 49.516514437539236, 0.4774233730775969, 0.22320451507610933, 0.07686904737991945, 0.2553889373583453, 0.1613069764737572, 0.25114448368549347, 0.07792122449193682], [0.04137047007679939, 0.07495815706040178, 0.07180946958916527, 0.09569269445325647, 0.05942908927266087, 0.044820583159370084, 0.02263305292996977, 0.16412780939468316, 0.02690628157662494, 0.29513912009341375, 0.06799445394426584, 4.8557763780866345, 59.76895318712507, 47.216247286115376, 37.324989795684814, 19.21408806528364, 31.067879881177628, 46.95614494596209, 26.280237538473948, 30.903687000274658, 13.934076394353594, 14.984405176980154, 37.62067386082241, 57.54606812340872, 50.81971509116036, 55.93147700173514, 3.630128477300916, 25.88314972605024, 78.3078031539917, 53.012035029275076, 58.929840087890625, 55.58499813079834, 60.228166580200195, 58.34725448063442, 60.39962727682931, 51.97218499864851, 52.54472003664289, 46.860339709690635, 48.526146003178184, 47.66353062220982, 47.96578768321446, 47.811252798352925, 49.58726446969168, 45.51151371002197, 42.32839454923357, 39.576028960091726, 40.87602996826172, 41.0189266204834, 45.03695174625942, 44.5947197505406, 46.73473364966256, 45.941416127341135, 46.116469042641775, 44.140067849840435, 45.332646233694895, 45.73437370572771, 44.73440980911255, 45.390837396894185, 48.452599321092876, 45.73669440405709, 46.70973750523159, 46.80407319750105, 48.39157676696777, 46.46003661836897, 45.95631306512015, 44.52963597433907, 43.508473123822895, 43.29611880438668, 39.99864966528756, 40.725778647831504, 39.68332304273333, 40.13354894093105, 38.47245352608817, 39.92603751591274, 25.471232720783778, 24.311283077512467, 31.040326799665177, 28.122350897107804, 26.290548665182932, 25.107407672064646, 39.56237227576119, 49.93486894880022, 42.21399245943342, 35.82721526282174, 36.804896286555696, 38.654899324689595, 32.62980713163103, 33.3126482963562, 37.47660296303885, 36.670625822884695, 31.692324910845073, 28.18688576562064, 28.110799516950333, 31.62948887688773, 32.65886797223772, 34.7041848727635, 33.748647757938926, 29.517907006399973, 32.87074981416975, 32.20170429774693, 32.110682896205354, 36.15311009543282, 31.751454080854142, 35.71612746374947, 45.98339366912842, 44.8521956716265, 44.69800819669451, 43.06647736685616, 41.219882420131135, 41.57529667445591, 41.509733472551616, 39.854422433035715, 41.76800148827689, 41.45845576695034, 42.905859334128245, 39.73702219554356, 39.91632393428257, 41.033868721553254, 40.702404907771516, 41.6165828704834, 41.89967679977417, 40.665916442871094, 42.07538284574236, 39.94125754492623, 40.31523391178676, 41.21734632764544, 42.6626306942531, 41.725784233638215, 41.730696610042024, 41.754640102386475, 39.72757959365845, 41.871140548161094, 41.71812731879098, 43.541452748434885, 51.463886056627544, 53.050983156476704, 55.67192356927054, 47.81199278150286, 50.78967455455235, 53.49416010720389, 53.427297592163086, 59.410856928144185, 56.50835118974958, 57.22180264336722, 54.32181215286255, 54.61288956233433, 51.77460602351597, 51.80238144738333, 54.879676069532124, 60.96118763514927, 55.74598789215088, 49.1143388066973, 1.6371053478547504, 39.70302465983799, 38.619981152670725, 52.684309346335276, 20.050802298954554, 6.478898584842682, 25.672680105481827, 24.768405062811716, 32.25508383342198, 41.99817098890032, 37.01478746959141, 26.665065254483903, 44.11475556237357, 38.08034930910383, 51.44256203515189, 55.57984604154314, 49.56623574665615, 2.344848096370697, 0.11929811351001263, 0.0806160873866507, 0.011985152327854718, 0.016404320286320787, 0.14181584093187535, 0.10619086612548147, 0.03667605608435614, 0.0710643974265882, 0.09595446647810084, 0.1738434944834028, 0.01987977834817554, 0.029942145637635673, 0.04282391583546996, 0.05583062468628798, 0.10709775531930582, 0.14238237696034567, 0.05567174231899636, 5.650555627686637, 68.27765464782715, 52.448119231632774, 45.50194951466152, 27.872319970812114, 35.12774705886841, 47.92205919538225, 23.346372842788696, 39.391265937260215, 19.587954998016357, 17.760055916649954, 41.48268413543701, 60.66016387939453, 53.8835232598441, 64.8954313823155, 7.852267793246678, 14.95338841847011, 77.90632929120744, 59.194170406886506, 63.60446998051235, 54.14321913037981, 60.621733392987935, 58.59730625152588, 62.1346549987793, 53.416621685028076, 53.71007537841797, 49.61372320992606, 53.11041109902518, 48.00608376094273, 49.73240886415754, 48.999790804726736, 49.90312262943813, 47.747444016592844, 44.671876021793906, 40.91219186782837, 43.244219235011506, 41.104927948543, 46.03406688145229, 48.145377772195, 49.769491400037495, 46.81654521397182, 47.713606289454866, 46.055317946842735, 47.199265888759065, 47.65050274985177, 49.98282541547503, 48.42571326664516, 52.25311803817749, 47.99820450374058, 48.57569360733032, 48.78284025192261, 50.01175424030849, 48.05588150024414, 49.54177461351667, 46.729122979300364, 49.41703707831246, 46.218138558524, 47.53711857114519, 44.8885486466544, 45.380495003291536, 46.4371075630188, 45.622323581150596, 43.94951697758266, 30.89620726449149, 27.944758415222168, 33.39175353731428, 30.720595019204275, 27.60096502304077, 26.23571695600237, 35.57265411104475, 39.13482877186367, 39.188420227595735, 37.763087613242014, 37.63858979088919, 40.77029228210449, 34.621146951402935, 36.14416428974697, 43.63631302969796, 38.7703332219805, 33.361160618918284, 31.13668441772461, 33.178079060145784, 34.6069552557809, 32.938303674970356, 35.399928842272075, 35.87738125664847, 32.33172593797956, 34.10143559319632, 35.28820528302874, 31.99449164526803, 37.03648321969168, 35.950782026563374, 37.60421010426113, 46.547517912728445, 46.290014198848176, 45.35024602072579, 46.38786220550537, 44.587170532771516, 44.83865710667202, 44.58009031840733, 45.49670362472534, 45.92066880634853, 42.62145219530378, 44.27817719323294, 45.52235984802246, 44.32583141326904, 45.49648823056902, 45.51162140710013, 46.42988838468279, 45.222944600241526, 44.30052954810006, 43.60107176644461, 43.36970370156424, 44.09639842169625, 43.61793851852417, 44.14691877365112, 43.36509357179914, 45.038928508758545, 45.861015047345845, 43.86942161832537, 44.628203119550435, 42.0686674118042, 45.231407506125315, 54.89750862121582, 55.967628479003906, 55.5223844391959, 50.597028800419395, 52.53787953513009, 57.494515963963096, 56.28452886853899, 60.804623876299175, 59.42296763828823, 61.17157908848354, 56.52934169769287, 58.20723785672869, 54.44862025124686, 55.4273157119751, 58.27275936944144, 64.21979549952916, 59.683643204825266, 44.96095929827009, 2.250533248697008, 48.490321091243196, 44.00664159229824, 59.16837174551827, 20.860613107681274, 8.3769097668784, 17.58240611212594, 23.68312770979745, 28.574395486286708, 44.570946489061626, 44.66826295852661, 26.896150180271693, 52.77408702032906, 41.3295910017831, 63.75560024806431, 57.08468689237322, 62.80308559962681, 3.566899218729564, 0.24026401181306156, 0.12214076811713831, 0.01909309672191739, 0.059766789366092, 0.057108031319720406, 0.06523268749671322, 0.19200352073780128, 0.15654564196509974, 0.18926499411463737, 0.20482454848076614, 0.09208628761449031, 0.12537161260843277, 0.1687164974531957, 0.21321799952004636, 0.16729111251022133, 0.21081523916551045, 0.18689610622823238, 8.134586998394557, 79.7182388305664, 61.31718553815569, 50.54941974367414, 28.857115949903214, 43.154351234436035, 66.69705063956124, 35.96480349131993, 37.35672569274902, 22.925108773367747, 26.714116062436783, 50.94260787963867, 65.67199679783413, 61.13359328678676, 66.81536456516811, 5.795065130506243, 29.258582864488872, 81.96871866498674, 56.33387497493199, 67.07535226004464, 58.02548687798636, 63.680733408246724, 62.70575523376465, 66.4446712221418, 58.39136164528983, 58.475893429347444, 53.08811780384609, 54.94507251467024, 52.083700111934114, 52.729291984013145, 51.22903347015381, 55.347762312207905, 50.85627998624529, 47.31261532647269, 44.561615058353965, 45.75288370677403, 45.70728267942156, 50.68693849018642, 51.217669691358296, 54.18808364868164, 50.268267835889546, 50.07538931710379, 47.77389233452933, 49.74641643251692, 48.967155115945, 53.81798785073416, 50.529533999306814, 55.46369647979736, 50.53681223733084, 51.641916275024414, 49.360975537981304, 54.32956634249006, 50.50042104721069, 52.59995126724243, 49.36098248617989, 52.085965224674766, 50.384761333465576, 50.53856665747506, 48.373091084616526, 49.00100326538086, 49.36176068442208, 48.364266872406006, 49.414476667131694, 35.87318801879883, 31.928466388157435, 35.46803855895996, 34.904942648751394, 29.969227245875768, 27.942269223076956, 34.081278869083945, 39.28887728282383, 38.53038413184029, 37.47150298527309, 37.58207661764962, 42.38901063374111, 32.187637669699534, 35.72083139419556, 47.43031433650425, 42.216045652117046, 35.849793434143066, 32.933773449489046, 34.35083075932094, 35.66382837295532, 34.163111277988975, 35.92984710420881, 35.24525499343872, 34.00908708572388, 36.08845363344465, 37.77975286756243, 35.159875529153005, 40.98848308835711, 38.39584616252354, 42.47974715914045, 49.37063353402274, 47.35302604947771, 48.49587270191738, 48.06774207523891, 46.164713859558105, 47.03441292898995, 46.73749903270176, 47.32888453347342, 48.64156252997262, 47.07383353369576, 49.26669890539986, 47.46999897275652, 45.69246564592634, 47.63982336861746, 47.874450138636995, 49.03423997334072, 47.53318589074271, 47.02706868307931, 46.2716292653765, 45.74163457325527, 46.212590421949116, 46.484063489096506, 47.910097871507915, 46.84232650484358, 47.152737276894705, 47.57223129272461, 45.666830267224995, 48.48459577560425, 46.050947529929026, 47.24900804247175, 59.437294823782786, 57.48288467952183, 57.75464262281145, 50.862724440438406, 55.27074500492641, 58.77866118294852, 59.338491439819336, 64.89821066175188, 61.11559050423758, 62.075588362557546, 59.191606521606445, 61.12145478384835, 57.59612989425659, 57.525310380118235, 61.07984202248709, 69.00634002685547, 59.4196047101702, 53.504961081913535, 2.9329004159995486, 43.80935444150652, 50.877565792628694, 61.24141543252127, 29.401225907461985, 14.038967268807546, 33.74712610244751, 31.980775901249476, 40.60465070179531, 55.7096974509103, 51.74600376401629, 36.626456124441965, 61.999720982142854, 46.96009152276175, 68.3370339529855, 67.27887889317104, 72.80272456577846, 5.014162302017212, 0.2704681839261736, 0.1794008727052382, 0.12270662561058998, 0.1495152185005801, 0.17978629416653089, 0.12071564101747104], [0.01323198332517807, 0.049162722126181634, 0.12581799365580082, 0.18015522722687038, 0.04181641686175551, 0.059037696703204086, 0.059163992426225116, 0.06386710184493236, 0.12677276028054102, 0.3697953426412174, 0.22370241050209316, 6.310080374990191, 60.010118212018696, 47.24200425829206, 36.1253833089556, 30.97060510090419, 37.985040869031636, 39.17190088544573, 39.0448009627206, 29.157257284436906, 18.383415290287562, 6.888731564794268, 24.352741241455078, 58.89569664001465, 52.899620124271934, 53.701737540108816, 41.2619502885001, 1.1222744477646691, 28.178751162120275, 67.1236491884504, 55.50232151576451, 54.86079433986119, 59.55399676731655, 58.124595982687815, 55.712952681950156, 52.961844716753276, 50.91458579472133, 46.798549379621235, 46.45135831832886, 47.15067366191319, 47.28802217755999, 49.19380187988281, 47.10740375518799, 47.49809748785836, 41.54907417297363, 39.167582580021445, 43.07263347080776, 43.15367031097412, 45.60194798878261, 44.831170422690256, 47.00705787113735, 48.18093865258353, 46.28372260502407, 47.42894901548113, 47.33731269836426, 48.879816259656636, 45.96286869049072, 47.048215525490896, 46.65851191111973, 43.726212297167095, 45.98984507152012, 44.67993245806013, 44.88703741346087, 46.19106490271432, 46.880225454057964, 44.71826566968645, 43.11575051716396, 43.932240281786235, 40.90820707593645, 41.48689474378313, 41.12634924479893, 38.88703169141497, 36.70228181566511, 31.778715338025773, 20.120866196496145, 28.21634612764631, 30.864235128675187, 27.10073815073286, 26.312105451311382, 37.28557613917759, 60.95948532649449, 80.89134488786969, 63.90391649518694, 38.250423840114046, 36.220952306474956, 34.44543743133545, 36.67145960671561, 37.45976400375366, 42.70992013386318, 37.22378233500889, 37.76392487117222, 37.35999134608677, 33.637598173958914, 32.90403168542044, 34.159022263118196, 35.292558329445974, 37.87827484948294, 43.59610380445208, 28.906213658196585, 17.172247001102992, 12.781457100595746, 20.570861067090714, 31.949859891619, 31.964597020830425, 40.6641446522304, 42.85337264197213, 42.321734700884136, 42.39207131522042, 42.694265842437744, 41.42714023590088, 42.64228984287807, 40.32756349018642, 42.58506795338222, 41.1154579435076, 43.116104875292095, 43.690908500126426, 42.67987264905657, 40.458620412009104, 44.3633690561567, 41.25966085706438, 42.455977371760774, 40.67297581263951, 43.13496923446655, 40.3211225100926, 44.02166707175118, 40.06868403298514, 43.178378105163574, 43.77585717609951, 45.92104748317173, 43.43025377818516, 43.429468631744385, 40.265807901109966, 40.9460643359593, 41.456815992082866, 46.12581784384591, 52.02784354346139, 56.023735182625906, 55.18755769729614, 50.108705929347444, 50.80373770850045, 52.62901210784912, 55.23083455221993, 59.42081369672503, 56.63098342078072, 55.62869535173689, 52.69991500037057, 54.47624976294381, 49.67196301051548, 61.375029291425435, 48.688681738717214, 72.7158512387957, 19.028063944407872, 5.238560889448438, 43.22043555123465, 35.78585263660976, 63.335692814418245, 12.991064276014056, 7.755389928817749, 27.038378068378993, 19.746488571166992, 30.477182252066477, 39.659285749707905, 42.609268529074534, 28.29189910207476, 30.693118367876323, 21.86219940866743, 31.100873402186803, 56.04616744177682, 60.21771648951939, 7.332102196557181, 0.6921541392803192, 0.17920309331800255, 0.14698004882250512, 0.0791326334167804, 0.1436646995799882, 0.09790206554212741, 0.07380655421210186, 0.044095979005630524, 0.10533429708864007, 0.23082111137253897, 0.12392488095377173, 0.0984502879104444, 0.04694995157686727, 0.0855974911579064, 0.23436794962201798, 0.3001294194587639, 0.0797575573836054, 9.410608036177498, 71.14588492257255, 50.484137943812776, 45.57777173178536, 29.47479690824236, 41.61591236931937, 42.23530258451189, 32.63837078639439, 34.5931213923863, 34.74811485835484, 14.310240575245448, 24.7686482497624, 59.22183813367571, 59.76561805180141, 57.96153565815517, 52.426975863320486, 2.0475937383515492, 14.184811694281441, 62.29769447871617, 57.714134625026155, 58.076608249119346, 58.07866839000157, 61.40624059949602, 57.47465453829084, 55.932675565992085, 51.79904978615897, 52.8059584072658, 49.423978328704834, 52.35851526260376, 48.48207357951573, 50.44234452928816, 47.544650418417795, 47.257613386426655, 44.99433497020176, 41.763353143419536, 43.38512870243618, 44.81644024167742, 47.42112534386771, 50.03485005242484, 47.5391891343253, 50.85163858958653, 48.02660526548113, 48.23320995058332, 46.372652598789756, 47.765863691057476, 48.41470037187849, 50.98601675033569, 48.18146324157715, 48.44989994594029, 47.70947905949184, 46.421453271593364, 45.966016224452424, 45.9068557875497, 50.084025927952354, 47.44488818304879, 47.660327502659385, 47.58693020684378, 47.831319195883616, 47.71021556854248, 47.3109199660165, 43.847020626068115, 44.73183897563389, 38.82657194137573, 27.137143237250193, 33.30498095921108, 32.475463322230745, 28.74365881511143, 28.723825182233536, 40.48882075718471, 59.68940326145717, 69.92512811933244, 46.46760320663452, 38.26746082305908, 36.141221727643696, 35.07834536688668, 37.609522002083914, 40.24665171759469, 47.22538069316319, 39.70765910829817, 38.43297733579363, 37.03946052278791, 32.99294430868966, 34.573829718998496, 34.64972141810826, 35.269559792109895, 33.491272585732595, 40.34092835017613, 32.04260792051043, 19.23315565926688, 10.334552560533796, 19.98071755681719, 36.21205513817923, 37.071481295994346, 45.041301318577354, 44.779298646109446, 44.82817227499825, 44.934712478092735, 46.264166900089805, 45.77029241834368, 45.32612187521798, 43.02039343970162, 44.03882564817156, 44.449804646628245, 44.820775917598176, 47.48839085442679, 48.94927045277187, 44.81604419435774, 46.76230410167149, 46.903564453125, 47.324173654828755, 46.670393330710276, 47.07089097159249, 43.9779177393232, 45.56124544143677, 43.53591850825718, 44.76942525591169, 46.34639188221523, 50.213342326028005, 46.550922530038015, 47.943077496119905, 44.09277146203177, 41.58305433818272, 42.13508871623448, 50.28294243131365, 56.200417450496126, 57.53980432237898, 56.31166853223528, 53.01688139779227, 52.03975622994559, 57.10589279447283, 55.67037412098476, 62.48669242858887, 59.601918492998394, 61.62130124228341, 56.88252558026995, 59.15177249908447, 51.688969475882395, 63.28743062700544, 50.81325674057007, 76.38721684047154, 14.485764231000628, 7.379588791302272, 45.574026652744834, 36.28207213538033, 67.93080057416643, 13.310888120106288, 10.43236322062356, 27.190124988555908, 21.677049023764475, 30.596899713788712, 39.84999295643398, 50.1210355077471, 35.652940545763286, 44.29290737424578, 26.760719367436, 41.34406757354736, 56.81111894335066, 72.27261870247978, 12.437785301889692, 0.6579141223004886, 0.44886266706245287, 0.13392105884850025, 0.3039465589182717, 0.05555909872055054, 0.07927488828344004, 0.13359477849943296, 0.23418705218604632, 0.22671720944344997, 0.30719519459775513, 0.22199380504233496, 0.21377078842903885, 0.1883647817053965, 0.2778245891843523, 0.2438254521361419, 0.3459668755531311, 0.2630572515938963, 9.3761545249394, 82.56673622131348, 60.53356075286865, 48.6910753931318, 39.86536931991577, 51.7747345651899, 55.026825019291465, 52.194065298352925, 34.56287588391985, 26.78096989222935, 16.26741783959525, 36.20915079116821, 65.760787827628, 64.10648427690778, 63.58140890938895, 49.87702519553048, 1.6542578446013587, 32.47211429050991, 72.76554475511823, 58.768627984183176, 57.46298851285662, 63.666559083121165, 62.79183646610805, 61.97702816554478, 60.071366582598, 55.1537686075483, 53.57650668280465, 51.65373863492693, 52.25122117996216, 54.022508076259065, 54.63857705252511, 51.668493134634836, 52.785325731549946, 48.600693225860596, 44.53208868844168, 48.68704196384975, 48.423201492854524, 51.47165414265224, 51.96141529083252, 51.25438744681222, 52.85976178305489, 51.79194177900042, 50.12398501804897, 49.68553284236363, 51.2603177343096, 49.86808633804321, 54.406257084437776, 50.57278306143624, 48.88815757206508, 51.416579246520996, 49.641651494162424, 50.47761011123657, 51.57746825899397, 54.85100085394723, 50.28845930099487, 52.101786272866384, 51.56477737426758, 50.07224178314209, 51.600789887564524, 49.15098360606602, 47.15027066639492, 49.68954195295061, 41.72867815835135, 32.09434073311942, 35.56764793395996, 35.63105372020176, 30.618265424455913, 32.0302540234157, 43.19664491925921, 58.74535846710205, 60.813364710126606, 39.93271473475865, 36.4525705065046, 35.96897241047451, 33.016154766082764, 36.916466985430034, 39.26752546855381, 47.59701551709856, 37.700001444135395, 36.935814244406565, 37.11254514966692, 33.806324754442485, 34.394427231379915, 34.16026946476528, 37.94546740395682, 34.8120174407959, 40.864520277295796, 35.37111813681466, 22.81048607826233, 16.052407571247645, 25.566753080913, 40.31331968307495, 37.626774379185264, 43.87871135984148, 46.94867563247681, 45.549881662641255, 48.089757442474365, 48.40227351869856, 48.57191031319754, 48.39182342801775, 45.65176657267979, 48.0024915422712, 45.174227305821006, 48.48096186774117, 49.5874034336635, 51.61371006284441, 48.64991773877825, 50.52367319379534, 49.05650894982474, 49.34471327917916, 48.104650906154085, 51.59530428477696, 45.30557952608381, 47.62021555219378, 45.17401191166469, 46.87796034131731, 47.64559384754726, 52.99466800689697, 49.649541173662456, 49.740892614637104, 46.16608960287911, 44.83070836748396, 45.50590998785836, 54.30198894228254, 58.27411079406738, 60.21604197365897, 57.663996423993794, 55.45762028012957, 54.23003339767456, 58.008300508771626, 58.47136320386614, 63.3008337020874, 61.69742570604597, 60.87279265267508, 58.72196388244629, 60.25382627759661, 55.2383177621024, 66.54947090148926, 53.00375625065395, 79.15726906912667, 22.906263521739415, 6.068972238472529, 52.553064823150635, 43.19210079738072, 72.22994286673409, 21.147957597460064, 15.760583230427333, 34.1448027747018, 27.1707603590829, 37.850527218409944, 52.53207778930664, 56.44481338773455, 37.61803354535784, 46.83632673536028, 32.428583826337544, 47.116182804107666, 66.86768450055803, 81.52098369598389, 16.160568441663468, 1.289116763642856, 0.5331479800598962, 0.28155742745314327, 0.40741069135921343, 0.17995182956968034, 0.22262104281357356], [0.09429580798106534, 0.16572335734963417, 0.024518130081040517, 0.12959773226508073, 0.03610953023391111, 0.1389743669756821, 0.05681540630757809, 0.1092348692140409, 0.1497233116200992, 0.1316172017582825, 0.11434187660259859, 11.601975202560425, 67.95718288421631, 41.45593009676252, 41.85608032771519, 29.41344084058489, 33.8596556527274, 39.67646517072405, 24.002958502088273, 25.330335412706646, 17.336061205182755, 4.986157153333936, 6.2364524858338495, 31.381962776184082, 61.174094336373464, 47.50740459987095, 61.23726735796247, 19.85460775239127, 0.12107249615447861, 11.623055168560573, 43.57051011494228, 61.150588580540244, 53.87604699816023, 55.98540544509888, 52.54650572368077, 51.39696100779942, 50.6998656136649, 49.7349762235369, 47.3302116394043, 50.45971155166626, 46.5344865662711, 50.19602394104004, 48.80664478029524, 42.86963837487357, 41.149111543382915, 42.265447344098774, 42.03338098526001, 43.22385059084211, 48.037559100559776, 48.45525353295462, 46.540913649967735, 49.869614941733225, 49.366429873875205, 50.32111236027309, 47.2179183278765, 45.166688510349815, 46.159738949366975, 45.62181288855416, 46.79168108531407, 43.264997822897776, 43.84872988292149, 44.01030329295567, 43.036047731127056, 45.589208466666086, 45.088886056627544, 45.22389997754778, 43.692211287362234, 43.62554679598127, 42.45930903298514, 37.269105434417725, 36.34380340576172, 31.592017241886683, 32.95784200940813, 16.78186420031956, 13.139561176300049, 12.23819134916578, 14.046949011938912, 13.833965012005397, 20.1075656073434, 39.128762994493755, 47.78850787026541, 60.982344899858745, 84.71586268288749, 52.68222836085728, 31.229762486049108, 36.734090668814524, 31.704414776393346, 35.55534962245396, 33.96513972963606, 35.56504235948835, 32.09290940420968, 34.902910300663535, 35.16179323196411, 34.436439514160156, 34.431277002607075, 44.59856557846069, 57.3752292905535, 45.56416368484497, 31.031474794660294, 15.52171458516802, 7.527092099189758, 4.1294342790331156, 9.280547312327794, 19.489604984010967, 35.04281227929251, 39.59100580215454, 38.99370738438198, 40.004058837890625, 39.34042944226946, 40.65291288920811, 41.542970180511475, 43.00899144581386, 40.70844636644636, 41.366194111960276, 40.422208377293174, 43.539597579411094, 41.994676045009065, 41.073522090911865, 42.644992692129954, 40.90966967173985, 43.49717535291399, 40.234978743961875, 41.71647364752633, 44.76145567212786, 44.41940975189209, 44.80573654174805, 43.605671473911826, 46.52053805759975, 48.78152009419033, 46.63397087369646, 44.700533866882324, 42.619920117514475, 40.636265005384175, 39.45129837308611, 41.79241050992693, 48.66965062277657, 56.71899972643171, 56.54202216012137, 55.941704750061035, 48.22205809184483, 55.245338916778564, 51.6511504309518, 60.310120582580566, 56.94959306716919, 61.32224382672991, 52.01391240528652, 58.85734953199114, 51.414675440107075, 62.17343289511544, 54.589724268232075, 63.82733345031738, 2.339890990938459, 19.025993381227764, 45.74205493927002, 49.11177144731794, 46.40923833847046, 4.291108872209277, 8.59228047302791, 15.431969915117536, 29.88913188661848, 26.127868754523142, 35.41257456370762, 39.65110771996634, 28.91482768739973, 24.627537284578594, 26.89532334463937, 31.018318380628312, 48.36121661322457, 55.64700732912336, 15.209224564688546, 0.7398228528244155, 0.17151003969567163, 0.06038756069860288, 0.11411553089107786, 0.03029386087187699, 0.10005240408437592, 0.04582017720011728, 0.10028344525822572, 0.04349231014826468, 0.1069420383178762, 0.056436050949352126, 0.20239052123257092, 0.06255968021495001, 0.07017079394842897, 0.2242553758301905, 0.1205950246325561, 0.1374166269919702, 13.777913893972125, 77.08050114767892, 48.53975405011858, 42.10087578637259, 26.74040457180568, 41.17220735549927, 46.17675508771624, 17.009370803833008, 8.974225555147443, 17.40534690448216, 16.34991553851536, 10.401499322482518, 30.228582654680523, 64.93599496568952, 54.62726191111973, 67.6623569216047, 27.188672815050396, 0.11529428192547389, 4.309889853000641, 41.95401866095406, 64.45101070404053, 55.60705518722534, 58.23991176060268, 55.07876975195748, 52.17927605765206, 49.78350939069475, 53.13820736748831, 52.2234388078962, 51.77608946391514, 51.32113879067557, 53.055270195007324, 49.09019729069301, 44.77250330788748, 41.00472102846418, 43.15211044039045, 42.69227865764073, 42.58800704138619, 50.46330724443708, 49.91095324925014, 48.86875820159912, 50.668202672685894, 49.36400842666626, 49.72477279390608, 49.21341664450509, 43.199403354099815, 48.134288447243826, 49.16322980608259, 47.38149976730347, 47.89891821997506, 47.3568788255964, 46.188893590654644, 47.7091247013637, 47.72048500605992, 46.869209085192, 49.44082771028791, 47.413808890751426, 47.42595086778913, 47.047948019845144, 44.45569671903338, 43.53488670076643, 37.904921191079275, 35.52982541493007, 20.431721653257096, 14.958458866391863, 13.74176241670336, 11.97459145954677, 12.347280672618322, 24.19013602393014, 42.5671763420105, 53.36186988013131, 64.93707888466972, 80.87728868212018, 43.19267054966518, 39.34166969571795, 39.37560469763619, 35.21512760434832, 36.757631165640696, 37.269456318446565, 36.32762105124337, 33.03092316218785, 37.413475104740684, 36.78217567716326, 36.55783918925694, 34.595275333949495, 36.271166937691824, 47.325709206717356, 44.66115495136806, 34.53820283072335, 16.643813916615077, 7.233657079083579, 6.803509303501674, 12.265241554805211, 22.953332356044225, 38.04874890191214, 43.41257756096976, 40.674956049237935, 44.88006489617484, 45.31091226850237, 46.07085411889212, 43.017843450818745, 44.350528785160606, 42.19097307750157, 43.85388544627598, 45.05148042951311, 45.53584630148751, 45.71956362043108, 45.77824810573033, 45.92955902644566, 44.026746204921174, 45.41057028089251, 45.964397294180735, 45.82097952706473, 45.97524690628052, 46.87192235674177, 47.077276366097585, 47.44124385288784, 48.67475754874093, 50.247815813337056, 50.60466487067086, 49.78874485833304, 47.14633103779384, 41.701250144413535, 40.183572496686665, 47.10726826531546, 54.30412203924996, 57.20833356039864, 53.88200160435268, 58.69533143724714, 51.05839613505772, 58.059175218854634, 54.68550171170916, 59.14599854605538, 60.6116098676409, 63.95356832231794, 59.86018303462437, 64.00234467642647, 59.35247816358294, 63.579220226832796, 58.13988896778652, 54.712526730128694, 1.7899126282760074, 25.40793984276908, 49.209633350372314, 49.04720531191145, 49.01596621104649, 4.406369498797825, 15.639538662774221, 20.879856143678936, 25.730497803006852, 20.97238530431475, 35.90920748029436, 43.900153500693186, 34.43712738582066, 32.74625546591622, 26.294820070266724, 36.10871458053589, 53.0994086265564, 64.08313832964215, 20.249081305095128, 0.6167269381029266, 0.26852936510528835, 0.08063163262392793, 0.4016602427831718, 0.09368160486753498, 0.04616162959220154, 0.1541461928614548, 0.2217374409415892, 0.10918475261756352, 0.22955520930034773, 0.09705703838595323, 0.32170520456773893, 0.2029819187841245, 0.1577051497463669, 0.3447730881827218, 0.24801128038338252, 0.28531830278890474, 16.430637972695486, 88.6977710723877, 56.87861721856253, 57.24586078098842, 39.04355723517281, 47.068521635872976, 56.32577337537493, 34.52596010480608, 32.50668852669852, 23.492474351610454, 11.183920332363673, 17.374083484922135, 40.563107422419954, 71.01054096221924, 56.514465604509624, 72.52444226401192, 23.965266261781963, 0.1812748642904418, 16.49601009913853, 47.601545742579866, 64.40648664746965, 59.212117603846956, 59.84564740317208, 56.85105718885149, 53.15907628195626, 54.97819457735334, 56.1563207081386, 53.360900606427876, 53.97153261729649, 50.52835280554635, 56.54872369766235, 51.98081118719918, 47.29036372048514, 43.97367933818272, 46.72470045089722, 46.907907077244346, 44.72013473510742, 53.08132593972342, 52.651499952588765, 53.074461119515554, 53.10981355394636, 52.69683000019619, 52.68611587796892, 51.87955508913313, 47.44727141516549, 51.87732124328613, 52.18787445340838, 50.911000524248394, 49.394976547786165, 49.83923741749355, 50.40564761843, 51.79497466768537, 51.140346663338796, 50.17640222821917, 51.998841762542725, 48.457014901297434, 51.517731121608186, 49.92078842435564, 46.278848443712505, 46.89537600108555, 42.15314361027309, 43.863314151763916, 34.296832833971294, 28.460278272628784, 25.269272906439646, 19.862641607012065, 16.708708354404994, 28.200045653751918, 46.04167168481009, 57.71847030094692, 66.30689539228166, 70.30888407570976, 37.58095448357718, 39.585732119424, 35.91451242991856, 33.115045002528596, 34.654456615448, 34.057971136910574, 33.81296375819615, 30.790337562561035, 33.15033837727138, 36.67672981534685, 35.91656562260219, 36.49384280613491, 34.83032941818237, 47.68173837661743, 46.35572331292288, 36.3477395602635, 18.69471022060939, 12.540582162993294, 9.642933215413775, 18.57509003366743, 31.733774389539445, 41.056533745356965, 43.621923310416086, 44.40068783078875, 47.99958372116089, 46.27582597732544, 44.72694396972656, 45.197482926504954, 47.86717537471226, 45.273690768650596, 47.50304113115583, 45.49169397354126, 50.3995748928615, 47.99309062957764, 50.18624782562256, 49.10034166063581, 47.988723686763215, 49.76543017796108, 48.65866552080427, 46.80320119857788, 48.95122637067522, 49.869312695094514, 50.05003186634609, 48.09692103522164, 50.385959897722515, 51.26774188450405, 52.35928998674665, 49.94015652792794, 48.52092790603638, 43.10829510007586, 44.37483010973249, 52.46964822496687, 57.10665362221854, 57.83260488510132, 58.7270291192191, 61.80230876377651, 51.36725051062447, 58.577510833740234, 55.229465757097515, 61.04776218959263, 61.46235425131661, 67.37069933755058, 60.598297119140625, 66.34455462864467, 58.0495901788984, 69.01426792144775, 57.44813673836844, 68.6640578678676, 4.061967270714896, 21.312819242477417, 56.08743626730782, 56.56156744275774, 58.93703147343227, 11.81616645199912, 15.688596418925695, 22.444840601512364, 41.74458258492606, 32.18431295667376, 50.93059097017561, 52.40878895350865, 38.14286225182669, 34.32323946271624, 39.138334138052805, 42.01460000446865, 65.5878541128976, 74.0534142085484, 30.334306444440568, 1.0436831563711166, 0.5575440281203815, 0.1943791261208909, 0.3926594757608005, 0.1888277190072196, 0.19861422958118574], [0.24072666413017682, 0.14727743715047836, 0.042719462154699225, 0.22334919231278555, 0.2191305908241442, 0.2522153476519244, 0.05376810893150313, 0.15696093253791332, 0.16345050930976868, 0.08281737033809934, 0.1630447589393173, 11.002538476671491, 67.66445527757917, 40.50284569604056, 45.519472871507915, 30.609312670571462, 36.01069981711251, 39.76756647654942, 36.07431057521275, 64.34674603598458, 58.60844421386719, 10.7947621515819, 3.573493059192385, 5.860882810183933, 47.02382387433733, 52.73771667480469, 53.137071337018696, 42.31592948096139, 1.8120314585311073, 0.371208622519459, 17.966558115822927, 67.7496679850987, 54.64794322422573, 58.398942129952566, 53.67076941898891, 53.67556020191738, 50.62990767615182, 47.47712435041155, 48.48761476789202, 49.99074983596802, 49.684174469539094, 51.1218957219805, 46.495639187949045, 42.43501813071114, 41.54566608156477, 41.75891671861921, 40.98867416381836, 44.895997115543906, 47.18913541521345, 48.09284591674805, 48.40498331614903, 49.802359853472026, 49.39145033700125, 45.90438917704991, 47.571626799447195, 45.244758469717844, 46.20730979101998, 46.387650285448345, 44.238537720271516, 45.48862634386335, 46.91173900876726, 49.08285304478237, 46.384408950805664, 47.39544480187552, 44.870830740247456, 46.21090200969151, 40.78154836382185, 42.93168926239014, 39.229480607169016, 36.8490103994097, 31.518206528254918, 25.93170026370457, 13.312484468732562, 3.767429224082402, 2.505071601697377, 1.2984076993806022, 0.4491720790309565, 2.3996259570121765, 11.855369925498962, 31.674648693629674, 25.02064377920968, 30.01879916872297, 46.348584038870676, 58.54708467211042, 30.46512017931257, 36.46489661080496, 29.22381407873971, 31.330709389277867, 28.662945066179546, 31.181326593671525, 29.8366208757673, 30.60417100361415, 29.56825712748936, 33.567685399736675, 36.53504909787859, 65.66588238307408, 41.053678035736084, 31.07078422818865, 35.34489910943167, 13.876780680247716, 2.254957514149802, 0.5551601988928658, 0.30063153537256376, 3.8277256914547513, 13.187923244067601, 29.316225119999476, 36.56827538354056, 37.809171540396555, 41.35482338496617, 40.12491927828108, 41.41685690198626, 41.97060053689139, 42.21323510578701, 42.607364722660606, 44.19070979527065, 41.49358238492693, 44.50214542661394, 41.317786012377056, 42.13650614874703, 43.774078437260215, 42.68570566177368, 41.85243252345494, 44.67906740733555, 43.76380899974278, 43.56773083550589, 43.81405142375401, 45.12539884022304, 48.062607356480186, 48.97736201967512, 48.970455510275706, 46.65612867900303, 42.90743310110909, 42.188777446746826, 41.95867395401001, 39.048559938158306, 46.568494524274556, 54.53422900608608, 55.038855825151714, 55.80755935396467, 56.24089070728847, 53.34226206370762, 56.58269344057356, 54.258951800210134, 59.097277777535574, 58.1850140435355, 62.32839856828962, 55.085815225328716, 57.80777897153582, 54.50472348076956, 65.34298569815499, 26.024576834269933, 0.635230479495866, 47.1988559450422, 49.99685035433088, 57.52436542510986, 24.97080087661743, 1.6900139259440559, 8.706825000899178, 21.083002362932476, 52.839657170431956, 57.82576090948922, 37.831492628370015, 34.56121179035732, 28.003656557628087, 37.60947683879307, 30.915134157453263, 28.16976019314357, 39.568403312138145, 52.38624552318028, 12.194259626524788, 0.3371616080403328, 0.08822030720434018, 0.03970930100019489, 0.074509530062122, 0.19015802762338094, 0.026478567027619908, 0.06422363807048116, 0.12160368050847735, 0.07121621285166059, 0.08132383333785193, 0.3247244139867169, 0.2930745823042733, 0.17841289857668535, 0.45843074364321573, 0.200188172981143, 0.11475260742008686, 0.07808671918298517, 14.07574234689985, 76.16562489100865, 49.62607363292149, 51.63459634780884, 34.74518619264875, 45.758643763405935, 49.363171168736045, 36.78859233856201, 49.63224710736956, 53.77895981924874, 8.514263493674141, 8.264328105109078, 9.235179918152944, 47.49117360796247, 60.784738131931846, 59.232663427080425, 50.022516999925884, 3.36503472498485, 0.7299371947135244, 14.928772687911987, 70.56003366197858, 58.17192016329084, 60.021228381565635, 56.05239302771432, 54.779886041368755, 51.11401646477835, 51.24935000283377, 50.9550347328186, 50.48345354625157, 53.14447464261736, 52.923393385750906, 47.038644381931846, 45.652645519801546, 42.1200076511928, 42.649196352277485, 42.51257044928414, 46.432174342019216, 48.113381317683626, 49.36915009362357, 50.501432010105674, 50.10390819822039, 49.81370973587036, 47.482453618730815, 49.25250720977783, 47.17646190098354, 49.222049781254356, 50.64762558255877, 46.81206015178135, 47.90198237555367, 51.0610225541251, 51.99768836157662, 52.34728349958147, 48.72816487721035, 48.172996861594065, 50.09156819752285, 43.722953592027935, 47.09715516226632, 42.81346566336495, 43.82971961157662, 38.265911374773296, 33.31656360626221, 13.662130849702017, 1.9789761517729079, 1.3474966138601303, 1.1367987883942468, 1.0813252393688475, 2.1615578745092665, 10.9995151417596, 39.46011563709804, 30.409124646868023, 38.40053967067173, 61.839273180280415, 61.20889091491699, 35.06319829395839, 36.792702198028564, 31.96431561878749, 32.74122844423567, 34.015267508370535, 36.185408796582905, 35.627051557813374, 33.50737851006644, 33.092140265873496, 35.080186639513286, 35.991085052490234, 57.24404035295759, 44.9830893107823, 30.620735509055002, 38.22514629364014, 17.289148705346243, 3.144693451268332, 2.2338514924049377, 0.8877557005201067, 2.3339081576892307, 13.776760493006025, 31.811670643942698, 41.36285202843802, 43.83545534951346, 47.3334356035505, 43.66417530604771, 45.03732347488403, 44.8345924104963, 43.78144700186593, 47.86930499758039, 46.42134210041591, 44.09563759395054, 46.686933517456055, 47.325063024248394, 44.37480231693813, 46.90576703207833, 45.689133984701975, 47.18636655807495, 47.45385135923113, 46.23299380711147, 46.32241712297712, 46.14284440449306, 47.05815144947597, 49.276700837271555, 48.33503927503313, 50.825061729976106, 49.16366754259382, 47.53236600330898, 41.42568458829607, 42.563733509608674, 46.102767195020405, 51.71298592431204, 54.963523456028526, 56.18997778211321, 56.81937687737601, 59.720718792506624, 54.89486830575125, 62.12102958134243, 57.33819539206368, 61.77895586831229, 59.394667625427246, 69.95250402178083, 59.83737209865025, 65.16206850324357, 56.79502691541399, 66.15320123944963, 14.879723617008754, 1.8651644417217799, 51.65532629830496, 53.38268320901053, 61.96088055201939, 22.753133910042898, 3.198443195649556, 15.085619585854666, 20.991378205163137, 50.994448389325825, 39.82147754941668, 21.877343007496425, 43.30206993647984, 28.16903931753976, 43.67796400615147, 30.9844320161002, 28.969560384750366, 50.73465871810913, 63.44956684112549, 17.361856392451696, 0.4273708574473858, 0.3136670616056238, 0.03147042702351298, 0.258993179670402, 0.14184948269809994, 0.05258236559373992, 0.30636363636170116, 0.28557351338011877, 0.14120784641376563, 0.31557488494685715, 0.5554276502558163, 0.24639131873846054, 0.13967203668185643, 0.5384232912744794, 0.2611255438200065, 0.20122223320816243, 0.2095429724348443, 17.577498946871074, 91.57460321698869, 54.35139410836356, 63.10078116825649, 41.54232747214181, 50.74205507550921, 56.06523677280971, 43.02823795591082, 66.83987086159843, 74.37822164808, 15.843516928809029, 10.683447667530604, 15.155351706913539, 55.55078520093645, 62.43007850646973, 62.756629943847656, 52.24454396111624, 2.006890105349677, 0.5265610877956662, 24.29690030642918, 69.639557157244, 57.9030943598066, 62.90052713666643, 57.77507727486746, 56.34957095554897, 57.21615028381348, 53.872631958552766, 51.431549140385215, 51.5427759034293, 55.039147649492534, 55.56840583256313, 50.393359729221885, 48.004819188799175, 43.98651613507952, 44.90862546648298, 43.70502723966326, 48.942739146096365, 50.141174861363, 54.127974782671245, 52.62066037314278, 55.35938317435128, 52.209670952388215, 49.68095050539289, 51.99702480861119, 49.89032057353428, 52.707186290196006, 52.68139457702637, 50.37763942990984, 51.543026038578574, 55.676172392708914, 58.09574358803885, 54.6389730998448, 53.03974444525582, 52.93858214787075, 53.71817002977644, 45.05418675286429, 49.359433037894114, 48.77882766723633, 50.74211760929653, 41.826355934143066, 40.0305940083095, 30.20357608795166, 17.695656538009644, 8.830223270824977, 2.9210001059940884, 2.090294109923499, 6.854656296116965, 18.806230545043945, 44.789380482264924, 34.215181078229634, 45.4666874068124, 63.89764922005789, 55.92122840881348, 30.79521519797189, 35.53019366945539, 30.201429094587052, 32.878198283059255, 34.589883531842915, 33.99050760269165, 33.478150912693565, 34.69429758616856, 32.58414357049124, 33.60591091428484, 35.75963360922677, 51.821541104997905, 40.14786223002842, 32.95247105189732, 40.104620116097585, 18.354526417596, 5.76283243724278, 2.5449792316981723, 1.8253962099552155, 9.551868387631007, 28.08812059674944, 41.287026337214876, 45.79014342171805, 49.04771253040859, 50.36545923777989, 47.73839051382882, 47.744039399283274, 48.599654470171245, 46.2998354775565, 51.1081417628697, 47.9892760685512, 46.32720095770699, 49.72031899860927, 48.83045973096575, 45.834757804870605, 50.33878857748849, 48.34757382529122, 49.13205671310425, 48.134826932634624, 48.75455413545881, 47.32079683031355, 48.06715495245797, 49.97941384996687, 50.85217360087803, 52.71527051925659, 53.54479857853481, 52.38036387307303, 46.78953756604876, 43.467107023511616, 46.21785715648106, 50.829734393528526, 53.9033534186227, 57.1840044430324, 59.80176952907017, 60.72239194597517, 63.71616227286202, 57.2038380759103, 59.22140039716448, 57.72368492398943, 64.12188843318394, 61.8687960760934, 74.26015785762242, 61.3578394481114, 64.68044022151402, 60.02406324659075, 70.78734397888184, 29.426896027156285, 1.4409499934741428, 52.5522449357169, 62.03530270712716, 68.26690578460693, 34.396855626787456, 7.200640542166574, 15.59101939201355, 31.32921552658081, 65.92573806217739, 69.25236184256417, 50.4132593699864, 49.54524176461356, 37.09780107225691, 52.49426221847534, 43.27236638750349, 39.74578387396676, 56.04073742457798, 70.4353551864624, 26.914786985942296, 0.44888484158686226, 0.45581328123807907, 0.1910500569002969, 0.23686794404472622, 0.3230484867734568, 0.1238266426537718], [0.04013623523392847, 0.17249559823955807, 0.011321325403904276, 0.3351978191307613, 0.19324993528425694, 0.03960721201396414, 0.049052131096167226, 0.2583852394350937, 0.031304650740431886, 0.08782784254955393, 0.21254809546683515, 14.266592860221863, 65.57997485569545, 46.3731563431876, 38.40746355056763, 19.893538509096416, 34.94949797221592, 36.291577271052766, 19.199477740696498, 55.634566579546245, 75.4455761228289, 17.78790429660252, 6.313396402767726, 4.004505234105246, 23.831879956381663, 60.03379767281668, 49.66340977805001, 56.397930417742046, 14.085735593523298, 0.23405875478472027, 1.2756347613675254, 54.76714651925223, 60.509825706481934, 55.08055543899536, 57.871997697012766, 52.877684661320274, 50.06427567345755, 48.2465226990836, 48.97142825807844, 50.61906153815133, 48.708379881722585, 51.03750985009329, 46.55776650565011, 43.60187428338187, 42.1732690674918, 42.17867824009487, 43.05769484383719, 44.13881369999477, 46.42682770320347, 47.239304883139475, 50.2503206389291, 51.112407956804546, 49.664993967328755, 49.00650971276419, 49.44743892124721, 46.74902956826346, 47.709336621420725, 44.81460244315011, 47.78912625994001, 48.78260401317051, 52.605742590767996, 49.81620413916451, 51.58112301145281, 49.58084086009434, 49.56432499204363, 44.787872723170686, 41.65227576664516, 38.832512651171, 37.559144088200156, 31.003067084721156, 24.696822983878, 12.053820031029836, 2.676192705120359, 0.8150760776230267, 0.3645077092306954, 0.022223894617387226, 0.4671386278101376, 0.3827194262828146, 3.1347345113754272, 16.657774584633962, 12.341723850795201, 26.394882815224783, 30.115938459123882, 34.02938972200666, 26.2528338432312, 27.201949085508073, 21.69594464983259, 17.09971128191267, 12.776707138334002, 11.35380813053676, 12.2577930859157, 17.127528394971574, 24.91906806400844, 25.424066611698695, 38.71844754900251, 30.763618264879497, 24.230247974395752, 34.08641358784267, 22.252943515777588, 8.143048167228699, 1.1080771067312785, 0.4499562755227089, 0.20586025076253073, 0.45454998474035946, 1.2221210386071886, 12.525565368788582, 27.97846760068621, 35.74742909840175, 37.17256021499634, 39.16210739953177, 40.01487718309675, 42.66851929255894, 42.16176632472447, 44.65624604906355, 45.101611682346885, 44.448012011391775, 44.05471617834908, 46.57671076910836, 43.071573870522634, 45.356416021074565, 45.25440604346139, 46.465556962149485, 43.72669519696917, 44.44515630177089, 41.99167442321777, 44.069494996752056, 45.86546189444405, 45.6843501499721, 46.7343237059457, 46.51399980272566, 49.83958830152239, 51.087248529706685, 43.71149253845215, 39.99117687770298, 39.77664777210781, 44.75756120681763, 47.97750582013811, 52.869197436741416, 55.02047436577933, 55.91816425323486, 54.710966859545024, 56.85697357995169, 57.38280630111694, 57.22809076309204, 58.4232816696167, 57.710928031376426, 55.73059068407331, 58.466617584228516, 56.16204949787685, 51.97109760556902, 0.24383321457675525, 8.510142343384878, 55.27216591153826, 42.02889592306954, 58.931417328970774, 8.376695241246905, 2.8276627830096652, 13.654004062925067, 34.15739985874721, 47.356406348092214, 78.46338721684047, 55.697190693446565, 27.34533211163112, 34.01942947932652, 30.557760511125835, 26.173021623066493, 34.3917487008231, 45.85184689930507, 54.116055147988455, 9.609651344163076, 0.6137534890856061, 0.48159945756196976, 0.06550578427101884, 0.15183134350393498, 0.2793088438255446, 0.0750487143439906, 0.1092049933171698, 0.1145676930568048, 0.05800934974104166, 0.3714063476238932, 0.2926604045288903, 0.1529872143375022, 0.10082778640623603, 0.7205739542841911, 0.05421328218653798, 0.04712828415046845, 0.23359751382044383, 14.508293764931814, 77.22141756330217, 53.23515558242798, 42.38833665847778, 20.757607800619944, 43.03671475819179, 43.12720809664045, 30.564177172524587, 70.03603526524135, 78.66032000950405, 14.896708488464355, 6.20477043730872, 8.208581839288984, 24.278930527823313, 66.4157041822161, 53.1135447365897, 64.71856498718262, 19.547471318926128, 0.37069233879446983, 0.1307533723967416, 51.934192248753135, 63.53492546081543, 57.58972365515572, 58.50499248504639, 54.90076037815639, 51.12536634717669, 52.18256950378418, 51.225059100559776, 51.841117654527935, 52.748048646109446, 52.20021445410592, 48.14206000736782, 46.575738021305625, 41.895469665527344, 41.51291574750628, 45.68521172659737, 45.89056921005249, 48.37438692365374, 53.27732767377581, 54.624176910945344, 55.654865741729736, 52.84439236777169, 54.38171604701451, 53.13718250819615, 50.94108622414725, 51.651668071746826, 48.978445938655305, 50.95251253673008, 52.70929854256766, 55.62062154497419, 55.82900149481637, 54.56990800585066, 50.503089155469624, 52.3514142036438, 49.234080587114605, 48.682987689971924, 41.976155621664866, 42.44754573277065, 39.93902369907924, 31.068658079419816, 13.320864864758082, 1.3765118569135666, 0.7267785870603153, 0.8855203347546714, 0.18472157791256905, 0.363298234130655, 0.6477607956954411, 2.7725349068641663, 22.186607326780045, 18.575322798320226, 32.836522987910676, 42.73277970722744, 46.31332540512085, 34.15166759490967, 33.43655204772949, 27.340204341070994, 24.091459444590978, 21.866000073296682, 23.364587545394897, 22.78236150741577, 24.711521897997173, 29.85144485746111, 30.99513224193028, 41.99948419843401, 38.52779245376587, 31.121245520455496, 38.33266966683524, 29.91669191632952, 13.033504741532461, 0.40416181140712326, 0.5489330387541226, 0.17712362775845186, 0.3467768563755921, 1.4413742678506034, 9.779556512832642, 29.45661347252982, 42.73662206104824, 42.24830266407558, 44.35487488337925, 44.61390025275094, 46.73854126249041, 46.79048599515642, 48.208206857953755, 46.276138646262034, 48.34822695595877, 45.55089609963553, 48.35398006439209, 45.85588032858712, 46.77730178833008, 47.24242115020752, 48.70424917766026, 46.516886779240195, 44.200694356645855, 43.948353154318674, 47.196667262486045, 49.40428018569946, 47.88656432288033, 48.186323506491526, 46.7879672731672, 51.470379148210796, 57.650721890585764, 44.1192684173584, 41.36539159502302, 45.185066495622905, 46.659349169049946, 49.731210299900596, 54.817538329533164, 56.24905831473214, 60.20580727713448, 60.4900233404977, 56.4686005456107, 59.210283279418945, 58.58441039494106, 60.849182673863, 61.43180302211216, 61.4971091406686, 62.53990173339844, 59.987640789576936, 40.900181906563894, 0.372457995478596, 14.191523654120308, 57.76749331610543, 47.478680746895925, 62.37247099195208, 8.705322452953883, 5.220142952033451, 9.582166007586888, 28.499881267547607, 48.686065741947715, 67.31499562944684, 36.49591336931501, 35.16385337284633, 34.39320434842791, 35.41953318459647, 29.52064459664481, 34.09967769895281, 54.953636169433594, 63.851235253470286, 13.388735737119402, 0.9196482577494213, 0.46904938242265154, 0.23388019150921277, 0.30039355957082337, 0.13622416955019745, 0.027334364230877588, 0.28430207446217537, 0.6560340374708176, 0.1994591685278075, 0.8008383501853261, 0.4130928250295775, 0.1681863580431257, 0.16164783175502503, 0.9292133216347013, 0.22328679423247064, 0.44680268902863773, 0.4407048305230481, 20.548209939684185, 86.51915645599365, 61.06560516357422, 51.56675066266741, 26.982231412615093, 46.952396392822266, 49.280713421957834, 22.30925519125802, 57.50278432028634, 83.26524557386125, 27.328364610671997, 12.182162812777928, 10.606301818575178, 32.33033629826137, 70.71757711683, 57.35285609109061, 67.8749440056937, 19.09391549655369, 0.5857873154538018, 2.4178879942212785, 63.65064770834786, 65.2270758492606, 60.49130875723702, 60.18979862758091, 58.39426599230085, 53.797633102961946, 54.26516348975045, 52.08708388464791, 54.000728947775706, 55.741283961704795, 54.90307412828718, 49.255269118717735, 48.20215150288173, 46.063850334712434, 45.38568878173828, 45.489811011723106, 47.90922587258475, 49.38574586595808, 54.70055845805577, 57.21492740086147, 56.5928030695234, 54.261689390454976, 56.00942884172712, 53.736224923815044, 53.421964849744526, 54.01977048601423, 52.94035046441214, 55.82049689974104, 56.686725343976704, 62.468870299203054, 59.89548683166504, 57.748444829668315, 53.17008222852434, 55.95469093322754, 53.71275738307408, 49.2203231539045, 48.27548279081072, 46.71839843477522, 49.20829929624285, 38.73817001070295, 28.236355202538626, 9.291891983577184, 1.7250328468424934, 1.6524668378489358, 0.36865779225315365, 1.7752321703093392, 0.7520513023648943, 13.617794394493103, 32.359355449676514, 17.788559164319718, 43.51980563572475, 50.43824509211949, 47.34555326189314, 32.63292339869908, 35.352483068193706, 30.3431966645377, 25.441683769226074, 22.071560791560582, 23.38134138924735, 22.94129112788609, 22.71008460862296, 29.134891033172607, 29.766152245657786, 42.56712423052107, 33.68064226422991, 34.0259746823992, 34.39154372896467, 28.429093020302908, 23.57090561730521, 1.905623802116939, 1.0971014499664307, 0.2454706552837576, 0.6254904078585761, 6.573240791048322, 29.052091087613785, 40.42351811272757, 46.54230328968593, 47.199668884277344, 48.96924652372088, 47.89120919363839, 49.624895913260325, 49.01576123918806, 50.946537085941856, 49.180666310446604, 50.6171612058367, 47.14214127404349, 52.797200202941895, 47.84588262013027, 49.99379314695086, 50.34194653374808, 52.28773396355765, 47.72061007363455, 47.820143018450054, 44.69447503771101, 50.59285988126482, 49.56430762154715, 51.707423891339985, 48.65571253640311, 48.44350412913731, 49.69264084952218, 52.64987407411848, 46.227629797799246, 43.32079880578177, 47.310391902923584, 50.38587999343872, 49.71881471361433, 56.80992037909371, 60.929059164864675, 64.10676220485142, 58.47428839547293, 58.414728437151226, 56.84370599474226, 59.41387939453125, 61.64168030875069, 63.2986797605242, 59.796440260750906, 65.28722640446254, 58.74804047175816, 58.411393301827566, 0.29537031054496765, 10.535210456166949, 62.998413358415874, 55.099610873631065, 73.24016925266811, 15.45261996132987, 8.69517113481249, 19.837395327431814, 44.25067274911063, 54.79352535520281, 83.62657274518693, 66.37282684871128, 40.327549593789236, 45.623713220868794, 46.23414373397827, 38.108513832092285, 47.20685332162039, 61.147830145699636, 75.54773548671177, 24.29351132256644, 1.0596356775079454, 1.1709955419812883, 0.2656046077609062, 0.3801871878760201, 0.6125137241823333, 0.1846359060811145], [0.01833096449263394, 0.15221566573849746, 0.0326084184593388, 0.08587741399449961, 0.034077399277261326, 0.05106245054464255, 0.12692616347755703, 0.22958064079284668, 0.06236488638179643, 0.21051543525287084, 0.12013033671038491, 8.168888517788478, 62.15867492130825, 47.54690858295986, 28.988935436521256, 42.47062070029122, 40.23110164914812, 47.1841014453343, 26.440648862293788, 15.347052506038121, 35.053585461207796, 10.95746464388711, 4.615920220102582, 11.818240489278521, 29.74664170401437, 47.36563702992031, 56.98148529870169, 53.32535709653582, 44.00501571382795, 3.1688547262123654, 0.22483204917183944, 13.002326437405177, 61.89459473746163, 53.636101382119314, 58.80098574502127, 50.35139608383179, 51.0566417149135, 46.633852754320415, 50.95118890489851, 46.638285705021445, 50.56170415878296, 47.57798787525722, 46.681374958583284, 40.1644857951573, 39.046937533787315, 40.32178953715733, 44.8629549571446, 45.324568952832905, 45.84674344744001, 48.5056905065264, 51.330174922943115, 51.389095646994456, 52.08562476294381, 52.91339145387922, 52.05790145056588, 49.09341778073992, 47.439131600516184, 46.854339940207346, 48.49010222298758, 49.407135895320344, 52.15986973898751, 48.7850775718689, 51.424329962049214, 43.859110491616384, 45.22264582770211, 37.18431656701224, 33.73462629318237, 24.65471863746643, 30.817237513405935, 25.85862605912345, 12.371402212551661, 2.5017177930900028, 0.8718648989285741, 0.20975629027400697, 0.2922880787934576, 0.06297676890556302, 0.21326817039932522, 0.18902346278939927, 1.1832251314605986, 8.197337048394338, 15.577211584363665, 19.11386898585728, 18.52994932447161, 14.212026919637408, 15.869701215199061, 12.98040052822658, 6.962877094745636, 1.065803615110261, 4.83859304870878, 5.363796957901545, 4.899666411536081, 4.877744844981602, 9.484826956476484, 18.438389437539236, 23.9346855027335, 10.61878686291831, 19.00120047160557, 23.907139369419642, 21.6132367679051, 1.9637737103870936, 0.41112108368958744, 0.15754246419029577, 0.051729670991855006, 0.06861069266285215, 0.04602180388090866, 2.4012624749115536, 13.817989366395132, 30.305801459721156, 39.66923904418945, 41.29952614648001, 39.26802226475307, 41.972056184496196, 41.717741693769185, 43.270354884011404, 45.98845195770264, 44.675899028778076, 46.53251327787127, 46.3691646030971, 47.158601556505474, 47.17612491335188, 47.70190552302769, 48.800554684230256, 44.99686411448887, 43.02906826564244, 42.365838391440256, 45.35280295780727, 46.88616268975394, 47.24288667951311, 47.834491048540386, 49.00106232506888, 64.22958551134381, 56.547000544411794, 43.59770883832659, 40.889318398066926, 40.56486184256417, 41.47941153390067, 43.79209164210728, 50.033707073756624, 54.36693722861153, 55.48133100782122, 57.78046907697405, 52.37015349524361, 54.70049592426845, 55.171952043260845, 58.85511916024344, 58.81076186043875, 58.26113155909947, 55.903903075626914, 55.7582688331604, 3.598372821296964, 0.17879884929529258, 28.179143735340663, 44.467932496752056, 51.06672355106899, 42.11662040437971, 11.933518920625959, 4.919633362974439, 8.267964618546621, 19.898100001471384, 38.2694480078561, 65.00638716561454, 60.201395171029226, 34.07962172372, 26.515489646366664, 38.23759399141584, 24.651885509490967, 39.88460888181414, 50.62294210706438, 55.17807340621948, 7.203297793865204, 0.5543883517384529, 0.19752174748906068, 0.060785996461553235, 0.032621836489332576, 0.1814021710306406, 0.15684581228664943, 0.022920315819127218, 0.1546566276145833, 0.10788410955241748, 0.30261806877596037, 0.010648718236812522, 0.13025276283068316, 0.13854486787957804, 0.4392848467188222, 0.04600687611049839, 0.3438355156353542, 0.21359183160322054, 8.822085193225316, 74.70562076568604, 52.75854737418038, 36.784531116485596, 32.71721199580601, 43.6838560785566, 49.709858485630576, 25.904736042022705, 17.78074938910348, 36.066750935145784, 14.58112825666155, 5.597848764487675, 14.67748761177063, 38.0487072127206, 51.15154715946743, 62.819073404584614, 58.59932817731585, 48.87988574164254, 4.996529945305415, 0.5516414248517582, 10.570881639208112, 61.83683436257498, 58.872753688267295, 60.226158550807405, 53.913782664707725, 52.296631131853374, 52.38376154218401, 54.229633876255576, 51.23564468111311, 54.86316367558071, 50.63672385896955, 46.1253662109375, 44.14485168457031, 42.784099102020264, 43.444570541381836, 46.93911491121565, 45.27075515474592, 50.167088168007986, 51.224273954119, 53.20590366636004, 53.35721806117466, 54.55944749287197, 57.690330096653526, 54.467741693769185, 52.077398095812114, 51.574765409742085, 48.544454506465364, 51.32438359941755, 52.872338022504536, 57.975859369550435, 51.45531892776489, 50.804609707423616, 47.074969564165386, 49.688068934849326, 42.11411557878767, 34.20931679861886, 22.885035037994385, 33.04944705963135, 32.46277938570295, 16.79507098879133, 3.234063569988523, 0.6322658242923873, 0.7978354256067957, 0.47738971774067196, 0.0434940573759377, 0.23154955942715916, 0.17184273898601532, 2.397251627274922, 10.498324206897191, 22.532757895333425, 19.222323417663574, 24.574510369982036, 28.067249945231847, 24.970307554517472, 20.8932557446616, 15.681799343654088, 8.514984369277954, 5.224338361195155, 3.4815677404403687, 3.6815807563917975, 9.850852847099304, 19.592954226902553, 27.110212019511632, 32.71440839767456, 19.253765753337316, 19.137155873434885, 34.239166259765625, 33.82096460887364, 4.31102762051991, 0.419911369149174, 0.11940453494233744, 0.13925758749246597, 0.02547783644071647, 0.05110022119645562, 1.9450391956738062, 11.112914953913007, 35.883679798671174, 45.92815201623099, 44.434153829302105, 45.897965567452566, 44.68263183321272, 43.82563059670584, 48.74347175870623, 50.33715575081961, 46.05655125209263, 47.242855412619456, 46.1295142854963, 46.611410072871614, 47.893144266945974, 49.34364325659615, 50.88716125488281, 46.13493735449654, 44.04343230383736, 46.4379482950483, 49.003956249782014, 48.48288999285017, 46.47679219927107, 50.26441158567156, 51.055074896131245, 73.6343822479248, 57.93498659133911, 47.217609133039204, 41.4966847555978, 44.70208331516811, 42.82146998814174, 45.474135875701904, 50.047523566654746, 57.680050236838206, 59.18265724182129, 62.7082496370588, 57.01464557647705, 56.262100083487375, 57.286594595227925, 60.13399069649832, 59.76091412135533, 61.97715323311942, 59.778131757463726, 50.70396505083357, 0.5404871233872005, 0.41934253967234064, 35.10078804833548, 47.599846908024375, 56.939299310956685, 45.851502963474815, 16.702421971729823, 7.860286882945469, 8.269614815711975, 19.31325101852417, 37.91802896772112, 60.1576840536935, 50.885097639901296, 39.10954775129046, 27.444752148219518, 42.65996258599417, 25.204557384763444, 42.775472913469585, 58.603733335222515, 65.84880065917969, 11.202705655779157, 0.7500282909188951, 0.3737167865037918, 0.13845717401376792, 0.10506465405757938, 0.13581335730850697, 0.17263734420495375, 0.222376729494759, 0.4236455373466015, 0.1210135178906577, 0.3043945277375834, 0.08978370617010764, 0.30986083298921585, 0.4108462227242333, 0.8238070862633842, 0.3161423573536532, 0.8274586360369409, 0.487776731806142, 13.330271857125418, 83.8975316456386, 61.631487301417756, 43.57500212533133, 54.589946610586985, 52.52498367854527, 65.14466326577323, 35.071070602961946, 20.24067051070077, 44.81543275288173, 15.898357323237828, 10.731573496546064, 18.653771434511455, 41.030088901519775, 56.94301659720284, 66.03345598493303, 63.503783634730745, 51.8906444140843, 3.4444083401135037, 0.6280971765518188, 17.580512728009904, 69.84048516409737, 58.579303468976704, 63.410837582179475, 55.859219210488455, 54.772857938494, 53.40287814821516, 55.99200970785958, 51.85419763837542, 55.73862280164446, 52.76539829799107, 49.69600030354091, 46.165304456438335, 45.309734548841206, 44.58828224454607, 48.55166326250349, 46.67502777917044, 52.55552448545183, 51.11593416758946, 54.45602355684553, 53.88227258409773, 57.15179606846401, 57.43194743565151, 56.04881123134068, 55.29539721352713, 54.48841953277588, 51.307631492614746, 53.806294032505576, 56.240334851401194, 65.66219288962228, 55.82718106678554, 57.965527398245676, 50.36870404652187, 56.68605136871338, 46.368167536599294, 40.211639744894846, 30.6531697000776, 42.08830302102225, 39.67323078427996, 28.110314880098613, 11.506280268941607, 1.6735830647604806, 1.9989315952573503, 0.6822502421481269, 0.07029780213321958, 0.28434346509831293, 0.4229972649897848, 3.3165823306356157, 24.810247114726476, 26.234584399632045, 25.949023859841482, 35.33645357404436, 37.857996531895225, 28.798335926873342, 25.813570465360367, 25.119610445840017, 16.08114184652056, 11.99986379487174, 11.730228526251656, 11.453826580728803, 18.42529555729457, 23.77162344115121, 28.129813262394496, 31.244527408054896, 21.914611407688685, 25.76547850881304, 33.278563908168245, 35.08799988882882, 14.88085617337908, 0.3512270690074989, 0.15120084876460688, 0.23362498091799871, 0.10678039092038359, 0.19716274818139418, 6.494721370083945, 29.419523988451274, 44.90357065200806, 49.854770115443635, 49.0679943220956, 48.24320493425642, 50.28038202013288, 46.27937650680542, 49.974463258470806, 52.827522141592844, 50.64425570624215, 50.48669835499355, 51.81272036688668, 49.608199392046245, 51.67822061266218, 54.253730228969026, 55.117690086364746, 49.59756517410278, 46.85148770468575, 48.26051984514509, 50.707786560058594, 52.297360692705425, 49.342722620282856, 52.19102546146938, 49.48426784787859, 63.79985332489014, 62.58906718662807, 47.6001422064645, 43.73934439250401, 45.07258210863386, 45.44792379651751, 45.160310064043315, 55.75041389465332, 60.04802758353097, 62.83157321384975, 62.65995965685163, 56.56275905881609, 56.895796639578684, 55.33749982288906, 59.77203818729946, 59.312637192862375, 61.528153691973, 59.758864402770996, 64.52837194715227, 5.246174378054483, 0.24989752631102288, 34.330104282924104, 51.75066947937012, 64.74498898642403, 49.66638708114624, 17.886540923799785, 10.497446996825081, 16.171709878104075, 25.579780953271047, 42.69897672108242, 68.87662410736084, 64.76241506849016, 47.53751809256417, 34.6150985445295, 55.20028679711478, 34.832841191973, 55.083609172276084, 64.0539003099714, 79.70544719696045, 20.112052406583512, 0.6408301304493631, 1.0533413695437568, 0.20378805909837994, 0.19147735754294054, 0.3239486856119973, 0.3352665954402515], [0.09296589291521482, 0.033141041307577064, 0.050891720955925326, 0.12898789213172027, 0.031039638710873466, 0.02336908022074827, 0.249227052288396, 0.1961027000631605, 0.0412462133515094, 0.12017644995025226, 0.1455563059342759, 6.537913109574999, 66.95623929159981, 42.36507061549595, 32.53330707550049, 31.489409719194683, 42.32689373833792, 38.75866024834769, 47.570522035871235, 35.637925488608225, 34.64594854627337, 12.882487382207598, 2.4232784935406277, 9.733355334826879, 42.755218914576936, 46.82633522578648, 47.68123810631888, 53.41037178039551, 53.46817037037441, 14.871938160487584, 0.01791127022754933, 0.34714606084993904, 28.469877208982194, 64.29968588692802, 55.23712614604405, 54.622464179992676, 48.68572875431606, 50.820302213941304, 49.22794880185808, 53.023391859872, 50.842435700552805, 50.605853012629915, 46.11343962805611, 39.430756023951936, 44.17577811649868, 42.90963568006243, 41.874548639569966, 44.097749846322195, 47.3099159513201, 51.58594158717564, 50.391442026410786, 52.25582088742937, 51.22288431440081, 51.028053351810996, 53.30088554109846, 51.58079297201974, 48.07279688971383, 50.09782157625471, 49.571370465414866, 48.79587854657854, 46.1391201700483, 43.097858905792236, 40.50042077473232, 38.72148391178676, 41.81528745378767, 40.963914258139475, 28.183614901133947, 13.594960008348737, 21.318247522626603, 14.694870267595563, 4.456064317907606, 0.4503353051841259, 0.31149824655481745, 0.32488666528037613, 0.07790801341512374, 0.19357067878757203, 0.15597029855208738, 0.07052578989948545, 0.2836875931492874, 4.477331451007298, 4.8007926770618985, 10.14386967250279, 8.562622955867223, 6.121388580117907, 6.2094318100384305, 7.757627248764038, 5.4173367364065985, 2.449413491146905, 0.15302792643862112, 0.05052016196506364, 0.19870467829917157, 1.3604109265974589, 4.2495755808694025, 6.7157140374183655, 7.7627176727567395, 7.335658805710929, 9.079915472439357, 9.290900128228323, 7.694661804607936, 3.1322620383330753, 0.28603825558509144, 0.27202968299388885, 0.15973695500620774, 0.15965063178113528, 0.2347640512245042, 0.08355637639760971, 3.2793382491384233, 14.307537725993566, 30.65700510569981, 37.47444207327706, 34.46994372776577, 39.3505460194179, 39.88529675347464, 44.7728715624128, 42.63640819277082, 47.8637638092041, 43.88523571831839, 44.93101256234305, 49.98510095051357, 45.20825610842024, 47.18307311194283, 47.42561388015747, 45.963497502463206, 43.756002698625835, 42.53605883462088, 44.72154174532209, 45.491176332746235, 48.95702811649868, 46.66522734505789, 62.203254563467844, 53.740925380161826, 46.662329946245464, 48.24251011439732, 40.586571489061626, 46.73953138078962, 42.464641775403706, 41.61680521283831, 47.004070145743235, 51.46889223371233, 52.54576574053083, 54.76688596180507, 57.56287234170096, 55.017066274370464, 54.42104285103934, 56.72988060542515, 59.47499574933733, 53.649264744349885, 56.22768218176705, 7.673409002167838, 0.5791502115981919, 4.545943175043378, 39.85865388597761, 44.761563369206016, 57.42653131484985, 48.49381603513445, 35.32883834838867, 9.680180771010262, 4.736657329968043, 14.031399812017169, 29.74198293685913, 57.77700539997646, 31.40612166268485, 40.8571343421936, 21.363759960447037, 36.65405436924526, 24.974040474210465, 34.91219309398106, 52.4049083845956, 46.811142989567344, 4.577542279447828, 0.4379409131194864, 0.0747463455689805, 0.2546917019145829, 0.029921236581036022, 0.10425453752811466, 0.1066388145887426, 0.01710481269817267, 0.05447204490857465, 0.04591752661924277, 0.2319821390722479, 0.030694688470768075, 0.0556630401073822, 0.14046090149453708, 0.23168369222964558, 0.023430626739614775, 0.15180916897952557, 0.20357046648859978, 7.840805871146066, 78.10847323281425, 51.24425349916731, 32.67296586717878, 29.317427158355713, 45.536607129233225, 52.138035024915425, 42.16991308757237, 24.480784382138932, 35.18630647659302, 16.916247572217667, 5.775542429515293, 9.86793325628553, 46.85617773873465, 49.719530378069194, 51.97219542094639, 59.44226973397391, 61.72261987413679, 17.418531111308507, 0.06373913014041525, 0.14206681746457303, 27.161698171070643, 68.59814725603376, 57.81859384264265, 58.85163811274937, 51.82418142046247, 52.72739512579781, 50.651037148066926, 55.195054803575786, 55.48037563051496, 53.031990255628315, 46.76994712012154, 43.75227151598249, 45.73887266431536, 45.9415933064052, 45.63187388011387, 46.708261013031006, 51.58641406467983, 51.53284692764282, 52.54945175988333, 53.90735905511038, 52.14540358952114, 55.96923351287842, 56.222370283944265, 55.503829274858745, 52.07430614743914, 51.24936737333025, 52.11616904394967, 52.26176854542324, 48.576305048806326, 45.8250025340489, 45.1631692477635, 44.13777494430542, 47.863062041146414, 47.64300216947283, 31.920767784118652, 11.99565144947597, 26.470211710248673, 20.529050282069615, 7.722867148263114, 1.4998747344527925, 0.1317916666822774, 0.0944402138037341, 0.0752734180007662, 0.09124143687742096, 0.04981583922303148, 0.03154497766601188, 0.7180863906230245, 2.431720554828644, 10.55465498992375, 16.2323693888528, 19.36266313280378, 10.945214969771248, 13.560543843678065, 9.272170390401568, 4.449645050934382, 2.3064269466059546, 0.8008973013077463, 0.7275991801704679, 1.4662459961005618, 1.883398903267724, 4.580289857728141, 12.004890816552297, 17.879731689180645, 13.421420931816101, 18.316585779190063, 18.906955105917795, 15.121811015265328, 2.257148150886808, 0.17694967852107116, 0.16870785291705812, 0.0564802439351167, 0.04323687903316958, 0.35658787563443184, 0.016883082721116285, 1.6186304134981973, 13.715303676468984, 32.25911031450544, 38.62295150756836, 37.80937998635428, 42.85834755216326, 43.072060244424, 48.28974049431937, 45.19117396218436, 51.22064004625593, 46.15905107770647, 45.07792179925101, 50.97072376523699, 48.84555469240461, 47.54158973693848, 48.17603669847761, 48.493767397744314, 47.52606398718697, 45.926209994724815, 49.1931939125061, 47.24461678096226, 53.11471203395298, 49.6423602104187, 72.31850460597447, 60.853914397103445, 47.171490464891704, 48.78372267314366, 42.79721730095999, 48.296077251434326, 42.560328892299104, 42.8402544430324, 48.55388668605259, 54.93332658495222, 58.00038998467581, 57.62992593220302, 57.679602078029085, 61.04447569165911, 56.84188904081072, 56.614814962659565, 57.545102323804585, 54.61753095899309, 50.71856321607317, 4.017315975257328, 0.3409758705113615, 5.165152737072535, 46.176796776907786, 47.77866227286202, 61.00467641013009, 53.40281561442784, 42.39948851721627, 14.304692438670568, 6.726188446794238, 14.564213735716683, 29.402907371520996, 55.70804030554635, 33.89241293498448, 45.83764478138515, 22.31695032119751, 40.31210722242083, 23.225896290370397, 39.1681558064052, 60.94030829838344, 57.463627747126985, 6.337392440864018, 0.35228512223277775, 0.19581596473498003, 0.2577942082924502, 0.0723974337535245, 0.011312506993168166, 0.11206660619271652, 0.10907580703496933, 0.16306014811354025, 0.08926319517195225, 0.308423641536917, 0.07919829525053501, 0.18141977222902433, 0.3174057624169758, 0.2808274323386805, 0.1134210028020399, 0.1993125235395772, 0.22374378756753036, 10.939394984926496, 91.23402336665562, 58.06908335004534, 48.09209898539952, 38.89875330243792, 58.32668086460659, 56.08159630639212, 64.96608761378697, 39.49981416974749, 47.38417134966169, 18.83035295350211, 8.273478014128548, 18.19457541193281, 53.61478083474295, 57.62866483415876, 58.74858937944685, 61.09515585218157, 65.30932862418038, 18.16779705456325, 0.1798668634146452, 0.5613077261618206, 32.90977437155587, 71.02720969063895, 59.13205351148333, 61.50183391571045, 53.898802348545615, 55.48797695977347, 53.167441913059776, 58.878749983651296, 55.00954137529646, 56.140492711748394, 49.120512281145366, 44.166505745479036, 49.31443650381905, 46.644813537597656, 46.32846900394985, 47.44825805936541, 52.8431590625218, 55.32419402258736, 55.550965854099815, 56.00872359957014, 54.524181910923545, 55.4247796194894, 55.23870686122349, 56.12717648914882, 55.130276748112266, 54.67852919442313, 56.12078414644514, 55.01315096446446, 51.801596300942556, 49.99240003313337, 48.476928438459126, 45.7403039932251, 51.80186380658831, 52.70444869995117, 38.40676873070853, 28.3911315373012, 37.43632772990635, 28.879586424146378, 17.362261125019618, 5.370974447046008, 0.7526475446564811, 0.7761215993336269, 0.20132591335901193, 0.3820381499826908, 0.3184977152517864, 0.16458123363554478, 0.9257906824350357, 13.332851375852313, 22.213557652064733, 21.555172409330094, 35.48640612193516, 26.291759388787405, 21.63637774331229, 18.597852332251414, 9.864621571132115, 2.4141142538615634, 0.24588108754583768, 0.3222008336867605, 0.8060085156134197, 1.3799563177994318, 6.9348315596580505, 17.921632800783428, 23.54299991471427, 21.88031336239406, 20.27509536061968, 23.62768108504159, 24.608344623020717, 9.64706826210022, 0.4496244718985898, 0.29998407725776943, 0.22272280949567044, 0.24385978600808553, 0.4878112013850893, 0.16147190119538987, 5.969848803111485, 27.72184804507664, 39.48010560444423, 46.10496629987444, 41.95109346934727, 46.10851682935442, 45.88321106774466, 52.081980432782856, 48.32932785579136, 53.993395124162944, 51.8894111088344, 46.77677372523716, 53.965974058423726, 54.19366652624947, 49.65649632045201, 52.189236300332205, 50.68175860813686, 49.828471183776855, 49.19188070297241, 51.93732588631766, 51.01787076677595, 53.23741027287075, 53.74500049863543, 61.47557667323521, 63.261861256190706, 53.65864481244768, 48.122386183057515, 46.4298814364842, 53.244688510894775, 46.35789115088326, 45.06945194516863, 52.35255023411342, 56.57632194246565, 59.931499344961985, 58.583917072841096, 60.0646824155535, 59.42949199676514, 57.591054235185894, 56.25609336580549, 60.405415126255576, 53.20278739929199, 64.75510556357247, 11.766087310654775, 0.7739472474370683, 5.127680233546665, 47.84715066637312, 52.434153352464946, 66.930739402771, 56.80591474260603, 42.74054084505354, 16.51007499013628, 11.77604147366115, 19.02848083632333, 35.424007824489046, 63.868272236415315, 35.23311301640102, 55.46863317489624, 27.786742482866558, 55.00124522617885, 33.99985987799508, 51.77491174425398, 67.93043231964111, 78.8548834664481, 16.136845554624283, 0.6963277810386249, 0.62925101178033, 0.3312533050775528, 0.1735126950911113, 0.17240314105791704, 0.24535416439175606], [0.04628507546814425, 0.11494608489530427, 0.07966527662106923, 0.10212982725352049, 0.07351481129548379, 0.09237704665533134, 0.0653007309883833, 0.00914461220548089, 0.08472197063799415, 0.02401721347788615, 0.10185327673596994, 3.7384057300431386, 64.94147709437779, 41.606184891292024, 38.322994300297324, 31.813077654157365, 45.53984498977661, 30.634736129215785, 26.160801478794642, 34.87110144751412, 26.961808919906616, 21.687575544629777, 3.362351200410298, 3.0794789620808194, 32.43966620309012, 55.304412501198904, 54.851240566798616, 43.449722630637034, 47.96112196786063, 31.77945532117571, 0.3370993999498231, 0.04426887651373233, 9.879410811832972, 55.12107733317784, 53.77250494275774, 56.71153041294643, 50.663606439317974, 47.49295929500035, 47.13296617780413, 50.38788454873221, 50.69502966744559, 47.861495222364155, 42.54621015276228, 41.39302110671997, 45.79987089974539, 45.42282690320696, 45.16252653939383, 44.06145245688302, 45.821858474186485, 45.887734345027376, 48.980752740587505, 52.57414565767561, 51.68767016274588, 49.552016258239746, 51.31246396473476, 51.97722244262695, 47.898195607321604, 49.87098026275635, 51.233970165252686, 51.59129170009068, 47.07653290884835, 44.76216091428484, 45.03594078336443, 42.901707785470144, 39.2995879309518, 39.00822564533779, 33.14655160903931, 26.513512883867534, 25.602994884763444, 8.95981672831944, 1.2517813784735543, 0.12747185491025448, 0.2099564309631075, 0.07815781608223915, 0.05039099603891373, 0.02601929211855999, 0.1462245543620416, 0.05474905004458768, 0.0948699503870947, 1.163036271929741, 2.5757710422788347, 4.193624777453286, 8.928790416036334, 3.6467316320964267, 4.418045512267521, 2.4471227569239478, 1.2700147543634688, 0.46715968953711645, 0.2976054863205978, 0.14739939703473023, 0.17512749986989157, 0.6005357354879379, 2.13619173850332, 3.791851273604802, 7.489975690841675, 8.22695461341313, 4.323691580976758, 2.8229319282940457, 1.0303042914186205, 1.2852977514266968, 0.1974887435457536, 0.13559655179934843, 0.017746079180921828, 0.028876302830342735, 0.03471101867035031, 0.05040023090051753, 0.03773683362773486, 2.1793880377496992, 15.151102883475167, 26.40821119717189, 30.795256887163433, 39.236526080540244, 42.231178828648154, 42.64753573281424, 47.90245137895857, 41.997719355991904, 42.23166867664882, 49.871021951947895, 44.4529104913984, 45.685489654541016, 49.109207562037874, 47.055434703826904, 46.83097662244524, 42.31368521281651, 43.68388039725167, 47.388375009809224, 50.040287017822266, 46.58955798830305, 53.77602073124477, 50.863554750170024, 34.274212973458425, 52.355527537209646, 48.56925957543509, 47.44730963025774, 43.698575837271555, 40.169252259390696, 42.19632319041661, 45.26521396636963, 48.6161390713283, 50.062298910958425, 56.22881473813738, 51.81127861567906, 55.54985761642456, 55.56310435703823, 61.10933017730713, 52.789894172123496, 55.695345946720664, 7.863078321729388, 0.0580328745501382, 0.1205140482634306, 13.041612420763288, 64.06751183101109, 45.6753557068961, 59.924321855817524, 48.43731675829206, 55.909777777535574, 11.199724010058812, 4.512803307601383, 17.698934350694927, 38.50248711449759, 46.966956342969624, 20.396713154656545, 33.229249068668906, 21.17612212044852, 33.22013650621687, 28.090733119419642, 38.33593879427229, 53.62434503010341, 33.7532057762146, 2.437017253467015, 0.10052762287003653, 0.12943119263010366, 0.04627326556614467, 0.059874764643609524, 0.03486734635329672, 0.1291330172015088, 0.07086610235273838, 0.08364276069083385, 0.07890495777662311, 0.09138848898666245, 0.04260591610467859, 0.0247685281626348, 0.07792891229369811, 0.035810873045453, 0.05750637887311833, 0.16322273867470877, 0.12030917139989988, 5.604702728135245, 71.71020371573312, 48.46668331963675, 37.45614399228777, 34.13592297690255, 54.48502881186349, 39.65576648712158, 33.1190402167184, 34.272899763924734, 31.93923957007272, 22.673057658331736, 8.147629635674612, 4.071067239556994, 36.668826239449636, 57.15396390642439, 59.051308495657786, 44.54153823852539, 50.92997258050101, 36.14068671635219, 0.701907673052379, 0.06067658947514636, 8.710649984223501, 56.67726537159511, 57.330840723855154, 59.05928502764021, 54.01672370093209, 52.73750475474766, 51.037718296051025, 53.67317696980068, 53.613102844783235, 50.79524006162371, 44.577043533325195, 44.86440365655081, 48.94938162394932, 46.95030151094709, 47.19351972852434, 47.93907185963222, 48.3064717565264, 49.0862854548863, 51.1072176524571, 55.37246315819876, 53.416930879865376, 53.80941029957363, 54.9726116997855, 56.55213873726981, 51.13202272142683, 51.367080279758994, 52.14333997453962, 54.64841570172991, 50.8244502885001, 48.536901814596995, 44.63179186412266, 46.34613479886736, 42.17339413506644, 42.22905615397862, 37.555645670209614, 38.66728448867798, 34.28992632457188, 13.369735019547598, 3.0001012214592526, 0.5180987790226936, 0.15731329577309744, 0.20379673077591828, 0.09081410230802638, 0.03272507559241993, 0.171182727973376, 0.10190719312855176, 0.3693723981933934, 1.5763468252761024, 4.479561388492584, 5.621935129165649, 4.985570464815412, 6.813649330820356, 6.5829356993947705, 6.3156784517424445, 2.4977770788328986, 1.3833329251834323, 0.5420986169150898, 0.5105289880718503, 0.1530759667179414, 0.7467122631413596, 3.576317067657198, 5.725785076618195, 8.088937333651952, 5.985979914665222, 6.063503571919032, 7.636170131819589, 4.029360243252345, 2.665197180850165, 0.23306801223329135, 0.2607569364564759, 0.05585715201284204, 0.04698670442615237, 0.0370039479540927, 0.16394688481731073, 0.03828931719596897, 1.0591432239328111, 18.546307121004375, 30.314893177577428, 35.83338178907122, 40.27314172472273, 45.67242704119001, 45.90934671674456, 51.816541876111714, 45.60944856916155, 45.705031463078086, 49.06922762734549, 47.20836108071463, 47.99128409794399, 50.653086866651265, 47.600826604025706, 51.04933220999581, 46.46136025020054, 48.5255241394043, 49.751526832580566, 51.87203713825771, 47.76844147273472, 60.6000828061785, 65.30581283569336, 37.99579668045044, 53.408276898520334, 52.62734801428658, 49.85530512673514, 45.55757679258074, 43.64711053030831, 45.75025033950806, 47.22599213463919, 50.137176173073904, 51.454471247536794, 57.79860040119716, 53.106026785714285, 59.89001859937395, 57.395653520311626, 62.09582151685442, 53.7457891191755, 54.0210211617606, 3.8703216229166304, 0.1737591932926859, 0.12726448103785515, 18.17526810509818, 73.67779459272111, 49.813358851841514, 64.92449569702148, 50.48105294363839, 61.83335331508091, 12.13221481868199, 6.26298201084137, 23.061432429722377, 35.76449734824044, 49.61670051302229, 23.251222474234446, 38.745889459337505, 24.798799957547867, 38.006434372493196, 29.505313396453857, 44.06143856048584, 61.72139004298619, 50.925313813345774, 3.389744256223951, 0.11250802714909826, 0.20680587073521955, 0.10625732184520789, 0.06400839997721569, 0.056374518001185994, 0.1698071610714708, 0.16192890810114996, 0.23737556966287748, 0.1747793842639242, 0.2552504619317395, 0.14271418058446475, 0.10307114531419106, 0.17563443338232382, 0.19182586669921875, 0.13292924421174185, 0.28121851278202875, 0.2229331824928522, 7.52089604309627, 89.59829235076904, 57.373287269047324, 53.40895087378365, 41.809485707964214, 63.63398592812674, 46.02557618277413, 37.28325891494751, 37.99893726621355, 38.49506991250174, 31.828394957951136, 9.608154875891548, 8.20976390157427, 44.799028056008474, 61.822514125279014, 63.30828217097691, 50.84052494594029, 56.69351373400007, 38.19412606103079, 0.6553802554096494, 0.1274841906768935, 12.618599142347064, 62.587955474853516, 59.329681124006, 64.06348187582833, 56.48402207238333, 56.05788557870047, 51.74764701298305, 55.16995096206665, 56.49224526541573, 52.555955273764475, 46.93277815410069, 46.866488865443635, 49.94077491760254, 49.70239612034389, 50.78081212724958, 49.01701191493443, 51.307714870997835, 50.97648729596819, 55.0148880141122, 57.490315777914866, 53.50953647068569, 54.469961643218994, 58.21072585242135, 57.75596972874233, 53.37262569155012, 54.63430043629238, 54.49643427985055, 57.835318156651084, 55.0680000441415, 52.260205200740266, 47.12580605915615, 45.67185728890555, 42.92423731940133, 45.103696141924175, 43.30852828707014, 52.76849372046334, 40.734012263161794, 24.312017849513463, 10.100634506770543, 1.4949550841535841, 0.5253528069172586, 0.4214832362319742, 0.19268394208380155, 0.1946172240589346, 0.3321675903030804, 0.3028573473649365, 1.3356402729238783, 4.398223604474749, 18.168285165514263, 18.52839640208653, 19.615480286734446, 16.101034539086477, 11.718272413526263, 6.876991280487605, 2.2612141498497556, 1.4313705989292689, 0.9745332726410457, 1.2682343870401382, 0.20142636368317263, 1.4044325415577208, 4.176761933735438, 6.171617976256779, 14.802695887429373, 15.0774849823543, 11.7466618844441, 13.278778757367816, 9.479588883263723, 4.787222845213754, 0.5453555307218007, 0.33105009741016794, 0.11565763742796012, 0.23641234849180492, 0.18552782679242746, 0.2546032209481512, 0.1611085185515029, 8.500980275017874, 29.18497017451695, 33.396342822483604, 40.74279826028006, 44.68192311695644, 49.05212116241455, 49.010998249053955, 53.08796494347708, 48.50076770782471, 46.25138916288103, 52.854911940438406, 51.3768424987793, 50.26942123685564, 53.57952567509243, 55.08372381755284, 52.561649322509766, 49.92484269823347, 51.329744134630474, 51.228953565870015, 55.57118163790022, 50.29048817498343, 57.1862348147801, 58.67077650342669, 40.90125887734549, 54.897605895996094, 54.13914748600551, 53.15795414788382, 51.30118009022304, 46.21589429037911, 46.81394311359951, 49.17630978993007, 53.198278018406455, 53.51462950025286, 61.05890710013253, 54.84950699125017, 61.35927772521973, 57.39843279974801, 64.09175409589494, 53.78636659894671, 58.49978133610317, 12.697691355432783, 0.25501273040260586, 0.2089747672102281, 15.46984280858721, 73.62719086238316, 53.144658769880024, 69.58436066763741, 57.025616782052175, 64.07075663975307, 18.17969410760062, 9.728685276848928, 24.307588372911724, 44.91861350195748, 54.96368326459612, 24.334397997174943, 44.737279415130615, 30.16409294945853, 47.31642293930054, 39.05384751728603, 56.7007919720241, 70.04392147064209, 71.70363766806466, 8.223355446543012, 0.3481346863721098, 0.3274406710905688, 0.1628429761954716, 0.29079429752060343, 0.12835534821663583, 0.25157432204910685], [0.05968929388161216, 0.12192031208957944, 0.06295771564223937, 0.025618155786235417, 0.0516297227836081, 0.11078999005258083, 0.05353015009313822, 0.19284172861703805, 0.07979063596576452, 0.047901987098157406, 0.029023578856140375, 2.0886022235666, 47.10082033702305, 50.277286597660606, 35.19806282860892, 30.894987855638774, 30.797831194741384, 43.87533106122698, 23.403417553220475, 16.115361724581035, 43.90506935119629, 22.740432603018625, 20.39755736078535, 0.7585173611130033, 18.575176886149816, 51.49608400889805, 57.61937509264265, 50.106982776096885, 50.70146369934082, 45.797859396253315, 3.617249991212572, 0.060023099184036255, 3.0781533760683875, 46.27942514419556, 57.28066430773054, 52.88703693662371, 52.78646523611886, 46.792546136038645, 54.022810322897776, 50.21400587899344, 49.639619146074565, 42.79760640008109, 41.83676780973162, 48.57821232931954, 51.28844404220581, 47.448605469294954, 45.47378499167306, 43.852224826812744, 45.9663462638855, 46.237131459372385, 50.025174685886924, 51.99689279283796, 51.119078227451865, 50.50561135155814, 55.36477845055716, 51.55057178224836, 52.52602243423462, 50.076612200055806, 50.034582546779085, 49.77929878234863, 51.3777631350926, 43.925920895167756, 40.68775463104248, 39.9475873538426, 38.87760646002633, 33.14166007723127, 32.77556644167219, 47.6060585975647, 21.38341815131051, 5.012908152171543, 0.7203367927244732, 0.2504590004682541, 0.2127295628722225, 0.0256498688166695, 0.05275453706937177, 0.08910156134516001, 0.06780179071107081, 0.24088568559714726, 0.22076754298593315, 0.6049789999212537, 2.1335887696061815, 3.479523233004979, 3.4934309210096086, 1.5372487689767564, 2.1707549010004317, 0.6476849626217569, 0.16651861396219048, 0.347303318125861, 0.044607743687395535, 0.16082513518631458, 0.5476537016885621, 1.2238664478063583, 1.048356797013964, 2.35070846761976, 3.09064428295408, 5.041291977678027, 3.8993698699133734, 3.260215720960072, 1.5514545781271798, 0.39052857724683626, 0.04313533966030393, 0.08127853434000697, 0.08259180494185005, 0.07967155306999173, 0.012273630642864321, 0.07351014297455549, 0.04572521283158234, 0.067365424840578, 4.287277374948774, 22.69830220086234, 32.53028460911342, 37.20567880358015, 41.10556023461478, 42.05000107628958, 44.96455499104091, 46.971406664167134, 43.31912428992135, 40.77839388166155, 41.576818329947336, 46.44730404445103, 49.195320061274934, 47.70812068666731, 45.98795516150338, 43.40996503829956, 48.22943360464913, 48.566143308367046, 53.37576975141253, 49.285347870418, 53.32877213614327, 33.76355859211513, 42.21668488638741, 54.877636773245676, 50.613245895930696, 48.301649706704275, 40.81213433401925, 43.16122300284249, 43.37178816114153, 46.54006944383894, 43.37028735024588, 46.14513036182949, 51.655440943581716, 53.70158120564052, 51.218635490962434, 55.130012716565815, 55.43563617978777, 59.83232075827462, 29.430029664720806, 0.048637081403285265, 0.7148594409227371, 0.2324968214545931, 19.021028893334524, 36.01987143925258, 50.86839764458792, 53.19126033782959, 52.84608425412859, 53.02184935978481, 4.176312472139086, 8.198780536651611, 23.532831226076397, 46.11845622743879, 41.44016463415963, 25.822973115103586, 42.73884548459734, 21.475532157080515, 38.132002217429026, 32.88891240528652, 38.88537107195173, 51.87398610796247, 30.855084351130895, 1.3183221050671168, 0.09343975463083812, 0.028450310063947524, 0.052219824333276064, 0.026032350524993877, 0.03843173151835799, 0.030734213135604347, 0.02520515866178487, 0.14150725677609444, 0.017710625726197447, 0.05590218977470483, 0.005161878395093871, 0.05815507870699678, 0.10741813919906106, 0.16386369642402443, 0.21320908356990131, 0.039824271973754675, 0.057587219535240104, 3.261905001742499, 56.967793873378206, 60.75385338919503, 36.894225801740376, 29.620959213801793, 39.801108905247276, 47.944665159497944, 25.929794720241002, 21.983541011810303, 46.84037058694022, 23.940968411309377, 24.244748864855083, 2.7931057001863207, 15.57471718106951, 55.93498236792428, 59.80971826825823, 54.08451380048479, 53.69064474105835, 49.84882245744978, 5.221554304872241, 0.05967580460544143, 2.7736288138798306, 46.96302713666643, 62.07444885798863, 56.09878614970616, 55.271870613098145, 50.60593639101301, 56.30333069392613, 53.039612429482595, 51.35732500893729, 43.419077600751606, 45.02213818686349, 51.29915121623448, 54.51525000163487, 51.20196328844343, 50.525889669145855, 45.8092474937439, 48.118047033037456, 49.11202505656651, 54.18085752214704, 54.02013179234096, 56.09579842431204, 54.31712211881365, 58.76487595694405, 53.82021474838257, 55.57931797845023, 53.47407633917672, 54.969321727752686, 54.69468723024641, 53.13785648345947, 45.24209383555821, 44.46815136500767, 41.425114836011616, 41.24476739338466, 35.068815912519185, 38.279939787728445, 51.01477187020438, 26.282613822392054, 7.664723753929138, 1.4325483185904366, 0.29653255960771013, 0.11978645516293389, 0.04105496147115316, 0.11925372374909264, 0.06437297684273549, 0.0654812077326434, 0.27712127406682285, 0.2624603850500924, 0.4404605579163347, 2.8303816999707903, 6.445392199925013, 9.2493759563991, 7.507823007447379, 5.962319127150944, 2.672197708061763, 0.46498191782406395, 0.35250257913555416, 0.136685776923384, 0.2450527319950717, 0.4175240658223629, 1.3316987987075533, 3.108669864279883, 5.000385761260986, 7.973021405083792, 8.306818945067269, 4.787716167313712, 2.7771767377853394, 0.8202867923038346, 0.500164555651801, 0.13134126870759896, 0.052381648149873526, 0.0964125861812915, 0.12154855632356235, 0.03160855300458414, 0.2218064750943865, 0.14143786978508743, 0.1268109753727913, 3.4869376122951508, 26.903094904763357, 35.63269696916853, 39.083776882716585, 45.11421571459089, 45.33281993865967, 50.17838246481759, 47.07216944013323, 43.52149404798235, 44.17169604982649, 45.052116189684185, 48.63226236615862, 50.29595988137381, 49.154426438467844, 50.77783829825265, 44.662058217184885, 50.39752517427717, 50.5842684337071, 53.855393477848594, 50.60027708326067, 63.11697047097342, 45.202131271362305, 43.43303305762154, 56.265581130981445, 51.65755319595337, 51.798233372824534, 43.59668050493513, 45.39127165930611, 45.18573004858834, 49.30630016326904, 46.9679707799639, 50.028554984501426, 52.476203850337434, 55.07033116476876, 54.54268148967198, 56.493440355573384, 56.84476906912667, 60.07402079445975, 25.687540565218242, 0.1572492556380374, 1.2812531398875373, 0.6062102424246925, 22.509524856294902, 39.039700984954834, 53.68272726876395, 56.4692189352853, 56.741768973214285, 52.373467785971506, 3.2210947573184967, 13.845301866531372, 27.162448576518468, 41.28628635406494, 47.76079845428467, 27.639537947518484, 43.82376153128487, 24.288340125765117, 39.66724491119385, 33.93996640614101, 43.63925559180123, 61.19200679234096, 47.03465264184134, 1.949489516871316, 0.13872261691306317, 0.16730190121701785, 0.06722027262938873, 0.04148657759651542, 0.038937908464244435, 0.038670443530593596, 0.10338297965271132, 0.22856386963810238, 0.15677650671984467, 0.1721958757511207, 0.23335706815123558, 0.1993266234972647, 0.24328729244215147, 0.3819847085646221, 0.16037067957222462, 0.31792997143098284, 0.1860558356025389, 5.195669225284031, 72.6352868761335, 66.6144574029105, 48.13389239992414, 39.951784065791536, 46.197606631687705, 58.541109221322195, 30.315900666373118, 19.540139232363018, 54.54392521721976, 32.04869106837681, 31.178919042859757, 4.93030492748533, 26.133528062275477, 60.031073978969026, 66.97035108293805, 57.326307024274556, 62.189747265407014, 52.33645473207746, 5.507338055542537, 0.12127471316073622, 4.913618394306727, 53.9787483215332, 65.20125634329659, 58.05721582685198, 58.33302456992013, 53.52759483882359, 59.46130084991455, 53.110563959394185, 54.20214680262974, 47.19571188517979, 47.85175037384033, 52.316499505724224, 55.877142088753835, 50.22732557569231, 52.46663965497698, 48.660041264125276, 51.8260053225926, 53.37606504985264, 56.670372758592876, 55.790282658168245, 56.596874713897705, 56.443034648895264, 59.72943183353969, 57.316246032714844, 57.223935740334646, 55.498770986284526, 57.9572833606175, 56.956843512398855, 55.129856382097515, 50.21660450526646, 48.33135672977993, 43.09620176042829, 46.5989727973938, 38.205524580819265, 43.91887194769723, 55.71368571690151, 31.84297922679356, 19.192282881055558, 3.59062796831131, 0.9684436108384813, 0.5313749409147671, 0.13353335750954493, 0.34572585991450716, 0.19294399741504872, 0.27949891505496843, 0.5811350622347423, 0.9781013897487095, 1.833802878856659, 9.330372844423566, 12.975525498390198, 14.931289672851562, 12.748393229075841, 6.466283696038382, 2.183483132294246, 0.3866468955363546, 0.5920461767486164, 0.14371712319552898, 0.2848641185888222, 0.9841577219111579, 4.520531007221766, 4.540900085653577, 6.190172706331525, 9.300133415630885, 10.293154324804034, 8.511966245515005, 9.270587069647652, 6.57989455972399, 1.0035418931927, 0.5413408832890647, 0.2054128654833351, 0.20629535455788883, 0.1222621173198734, 0.3841637016407081, 0.19365389432225907, 0.20691598339804582, 0.18638626858592033, 18.93122168949672, 38.22360726765224, 39.43182952063424, 44.699481214795796, 48.21460614885603, 51.87851633344378, 51.617983204977854, 50.552945954459055, 45.26597826821463, 49.7435051373073, 48.27184888294765, 53.00157799039568, 53.19096851348877, 51.29241146360125, 50.662390504564556, 51.26031078611101, 52.444117069244385, 51.895879881722585, 59.19612285069057, 54.81286219188145, 58.58862795148577, 40.025195258004324, 45.33977855954851, 57.56219489233834, 57.195406436920166, 53.94712012154715, 45.409667015075684, 49.100762026650564, 47.39467355183193, 52.12757798603603, 47.905963693346294, 50.841695717402864, 54.313533374241416, 58.28492913927351, 56.15585517883301, 59.44240174974714, 58.31461879185268, 60.98787566593715, 34.136169637952534, 0.3960980198213032, 1.2068430355616977, 0.6992958560585976, 23.95627008165632, 46.721886430467876, 57.814789703914094, 61.474819319588796, 60.08727100917271, 61.588311195373535, 9.82275606904711, 13.156216876847402, 30.637835025787354, 52.56651653562273, 51.65059804916382, 33.341514587402344, 58.018510886601035, 27.415156296321324, 52.258739130837576, 42.23663316454206, 55.04755844388689, 70.13931328909737, 66.30308777945382, 4.3298919796943665, 0.3759356231561729, 0.1502319686114788, 0.2054211843226637, 0.08487849509609596, 0.1810802604470934, 0.0737836943673236], [0.0853182061442307, 0.18092227035335132, 0.05388713075912424, 0.025883101658629518, 0.0138404799592016, 0.1240248970155205, 0.08357489361826863, 0.2150713907820838, 0.014715058163606694, 0.0737043261261923, 0.05515266642240541, 0.7471494025417736, 43.267064911978586, 57.25793675013951, 35.275889601026265, 34.30200924192156, 30.552313123430523, 34.29289320537022, 37.21005964279175, 14.886842046465192, 24.872249364852905, 21.80243968963623, 13.106091703687396, 5.409265535218375, 7.959646122796195, 38.32703120367867, 54.76203611918858, 45.32458979742867, 50.49811771937779, 48.39950813565935, 8.19163691997528, 0.03444979625887104, 0.17004178491021904, 31.5986145564488, 58.410670689174104, 52.32964549745832, 53.52807079042707, 48.562919344220845, 53.753616264888215, 50.896159172058105, 47.32532358169556, 38.75498465129307, 46.6697610446385, 52.77404185703823, 53.117133481161936, 51.38552079881941, 50.451259068080354, 43.41926172801426, 45.26313992909023, 47.65344531195504, 50.697110652923584, 51.28073501586914, 52.85056931631905, 53.32838651112148, 52.93109546388899, 54.44452428817749, 56.08483069283621, 54.33377347673689, 53.60351780482701, 51.546131883348735, 45.65054368972778, 44.87113993508475, 44.27678060531616, 35.53706891196114, 36.483232906886506, 29.67778853007725, 32.889978953770225, 48.446474484034944, 13.632798160825457, 2.9578348951680318, 0.4288088360003063, 0.20598408340343408, 0.059137536345848014, 0.1320727158870016, 0.04588770500517317, 0.14327429767165864, 0.020786621740886142, 0.3839232831129006, 0.055972360473658354, 1.4798629454204013, 1.0789106317928858, 0.6040597206779889, 1.9051385138716017, 0.8945882224610874, 0.3851984946855477, 0.36040857061743736, 0.030291910083698373, 0.09680276417306491, 0.007645199940140758, 0.1894241648593119, 0.2562884305204664, 0.4945838493960244, 0.6764897512538093, 0.7763238570519856, 0.6674346200057438, 1.9933613112994601, 1.1725689832653319, 0.9023603254130909, 0.7964551768132618, 0.4843144661613873, 0.1719976756721735, 0.07220948633870908, 0.048887766165924926, 0.15176055873078959, 0.018268574894006764, 0.06160715275577136, 0.25924958448324886, 0.07685237577451126, 0.5989779819335256, 9.805944902556282, 28.81261794907706, 36.43450519016811, 37.854140281677246, 43.939452511923655, 44.231693744659424, 35.81317295346941, 36.722462858472554, 43.28379617418562, 45.840906960623606, 48.38977370943342, 46.831289291381836, 46.19726616995675, 44.716372285570415, 47.20738138471331, 45.06380653381348, 51.282788208552766, 49.06978348323277, 52.49134744916643, 43.94426761354719, 28.086512088775635, 49.64430570602417, 51.10011659349714, 51.89117595127651, 48.650223459516255, 42.600781304495676, 42.681446416037424, 42.87725360052926, 46.54745190484183, 43.994374547685894, 47.85883406230381, 48.06058195659092, 50.72352770396641, 53.086988721575054, 56.39596060344151, 50.58455678394863, 47.61125932421003, 7.988885879516602, 0.009036495283778225, 0.11488807015120983, 1.4662975647619791, 19.81643087523324, 42.773527417864116, 57.878667967660085, 49.70234053475516, 56.45956093924386, 22.755696058273315, 0.8066665317331041, 19.97264722415379, 26.00547102519444, 43.45714330673218, 32.405060700007844, 27.345330374581472, 39.053840569087434, 20.99201396533421, 36.32704087666103, 24.4240870816367, 39.984642096928184, 54.99987990515572, 34.145198822021484, 0.29472912209374563, 0.048194425513169596, 0.06275059282779694, 0.07076902434762035, 0.12145319501204149, 0.10795879590192012, 0.040749291623277326, 0.03353115823119879, 0.2215375445250954, 0.02497677904154573, 0.03855651071561234, 0.08718353283724614, 0.08094559077705656, 0.05605661755959902, 0.21786103823355266, 0.030644341172384362, 0.07619748091591255, 0.09914674982428551, 1.7165696152618952, 53.48121908732823, 65.11459146227155, 35.9396927016122, 32.137867723192485, 38.573949337005615, 35.997070925576345, 33.29849134172712, 18.075874124254497, 23.62081973893302, 26.67675907271249, 13.881863287517003, 7.491703186716352, 12.236456905092512, 40.012222971235005, 60.2280832018171, 49.7700229372297, 54.49288027627127, 55.092287472316194, 9.695161087172371, 0.1061853224943791, 0.27674596277730806, 31.315760340009415, 63.02937453133719, 55.661251136234824, 57.21996137074062, 51.05840655735561, 56.44512258257185, 53.71725286756243, 49.67921345574515, 41.665619782039094, 51.538002490997314, 56.01603657858712, 56.79611430849348, 52.38548469543457, 52.11849321637835, 47.21027183532715, 49.07590137209211, 49.03951365607125, 52.18311146327427, 54.35073055539812, 55.63423654011318, 56.820943696158274, 55.059266158512656, 55.558400426592144, 59.60384314400809, 58.23713942936489, 57.70383392061506, 52.979903084891184, 48.40284327098301, 46.09583984102522, 44.45703077316284, 37.95666790008545, 36.72580146789551, 31.74243184498378, 43.20916557312012, 47.411304065159385, 18.792525223323278, 2.0486292370728085, 0.5753729428563799, 0.21256283324744019, 0.07138099508093936, 0.04915260177637849, 0.03493985799806459, 0.0807281406596303, 0.025746787366058146, 0.12359317232455526, 0.31418703656111446, 0.8842145619647843, 4.406564916883196, 9.056682433400836, 10.688311406544276, 8.094482864652361, 2.4728137212140218, 1.1191041150263377, 0.07214891351759434, 0.24419215960162027, 0.011183038270766181, 0.14270394827638352, 0.5372708673988069, 1.8325621911457606, 3.096175483294896, 3.185707147632326, 3.0589984953403473, 6.052948823996952, 8.314698202269417, 6.716544347149985, 2.822322440998895, 0.8940354064106941, 0.10750582627952099, 0.02032591512293688, 0.0814699354980673, 0.04092627391219139, 0.04365331293748958, 0.05115769650521023, 0.07987821448062148, 0.07253768015652895, 0.6089851792369569, 12.69586397920336, 33.414884090423584, 41.654481819697786, 41.30827740260533, 47.76938642774309, 45.74880164010184, 37.36214181355068, 40.55012123925345, 43.448162760053364, 45.409340449741904, 52.05914865221296, 48.99063307898385, 47.499893597194124, 47.50791529246739, 48.95450939450945, 47.48264469419207, 53.26636341639927, 51.05899020603725, 52.11041940961565, 57.31867790222168, 33.82582139968872, 52.685560022081646, 52.25947911398751, 54.13538156236921, 52.76572833742414, 44.63192387989589, 44.66459430967058, 44.222536018916536, 47.00932993207659, 47.77081080845424, 50.59489222935268, 50.016729150499614, 52.45483813967024, 53.90479864392962, 57.484552247183665, 55.588604245867046, 49.43891000747681, 7.48652069909232, 0.03431572113186121, 0.2251675304557596, 2.284734453473772, 22.960579327174596, 46.3039105960301, 60.594677107674734, 52.94912256513323, 61.75998728615897, 21.326255321502686, 2.170930777277265, 23.635640246527537, 29.59121397563389, 44.22171613148281, 42.70340967178345, 29.526057243347168, 42.23907545634678, 22.502232721873693, 40.941523688180105, 26.156354631696427, 45.63939183098929, 66.61258138929094, 44.61204160962786, 0.689005791076592, 0.02356110223835068, 0.09309865507696356, 0.042596813557403426, 0.11117233096488885, 0.02399988708618496, 0.04364590333508594, 0.10802899713494948, 0.3200121782720089, 0.38980952011687414, 0.3211607209273747, 0.21984070486256055, 0.1766786037811211, 0.22009481622704438, 0.30796465330890244, 0.09257397787379366, 0.2015729815300022, 0.218535094921078, 2.6521886331694464, 71.05409227098737, 74.9207717350551, 47.16345834732056, 48.255096776144846, 42.734721728733604, 48.84226819447109, 49.389268602643696, 21.566009862082346, 33.00564561571394, 33.848892893110005, 22.375303030014038, 10.761068599564688, 14.214546510151454, 47.025189195360454, 65.06280653817313, 53.091578006744385, 60.47878115517752, 56.89637334006173, 10.654196619987488, 0.4914389210087912, 1.1764014576162611, 37.87796218054635, 65.23988137926374, 58.24916328702654, 60.64911624363491, 54.01542091369629, 58.72624397277832, 56.27749034336635, 52.696392263684956, 44.01210635049002, 52.79283326012747, 58.56836700439453, 59.20535700661795, 53.493239470890586, 54.067039081028526, 49.858105250767295, 51.34649624143328, 52.677197865077424, 55.200457027980256, 55.877270630427766, 58.42775630950928, 59.71047019958496, 56.98073489325387, 58.59535380772182, 61.9423497063773, 61.69019957951137, 58.117244788578574, 57.590894426618306, 55.28106655393328, 51.009710107530864, 44.31403684616089, 39.47445671898978, 39.21725525174822, 35.65648760114397, 40.50294297082083, 46.454589230673655, 29.398227759769984, 10.219393117087227, 1.5587117544242313, 0.6175308663930211, 0.1299111204487937, 0.20625618951661245, 0.17493950495762484, 0.2507576915834631, 0.09352197950439793, 0.9084661634904998, 1.13528853229114, 3.368881855692182, 8.41751069681985, 14.337298597608294, 15.851764440536499, 11.370611480304174, 3.385610295193536, 1.0451047143765857, 0.12793780490756035, 0.35033908379929407, 0.10363513683634144, 0.21734706152762684, 0.41266523940222605, 2.924407546009336, 3.6754316006387984, 3.1199090097631728, 2.901931426354817, 8.032290407589503, 10.908065557479858, 7.83585614817483, 3.823684011186872, 3.662247393812452, 0.8321092607719558, 0.1421301926353148, 0.16599736336086476, 0.2763342277279922, 0.08651397483689444, 0.18645344355276652, 0.47952547456536976, 0.1837886736861297, 1.9973732445921217, 29.7042681149074, 37.98321696690151, 45.49294464928763, 43.98830877031599, 50.77414533070156, 48.238139697483604, 42.46527058737618, 45.27803339276995, 46.29692070824759, 49.43726675851004, 53.07796648570469, 53.31618547439575, 50.18068926674979, 51.72661828994751, 52.28368663787842, 48.287353788103374, 58.279318468911306, 52.58020796094622, 54.85617726189749, 48.61825827189854, 33.44074528557913, 54.69526393072945, 54.97750323159354, 56.558406012398855, 53.33264228275844, 46.95346988950457, 46.53478881290981, 46.51264490400042, 52.3170553616115, 49.22372429711478, 53.452199935913086, 53.66900110244751, 55.971057415008545, 57.55440248761858, 60.9576301574707, 55.454778466905864, 55.27583803449358, 10.530310239110674, 0.1053657607574548, 0.5309520236083439, 2.2828467147690907, 23.524668829781668, 48.56861686706543, 66.26419871194022, 58.50311647142683, 64.52520356859479, 30.553101743970597, 4.290548239435468, 28.803998708724976, 35.26316397530692, 52.42183072226388, 43.989351000104634, 35.66244568143572, 55.97661597388131, 27.076092890330724, 49.54806273324149, 34.31279632023403, 60.53325503213065, 72.61925043378557, 63.51272596631731, 1.2949795233351844, 0.1805106574403388, 0.1847566988851343, 0.1059871224154319, 0.2115865299212081, 0.13818205520510674, 0.15833356816853794], [0.041664218064397573, 0.041867924455021105, 0.16280123272112437, 0.08247516477214438, 0.06883872792656932, 0.08344640622713737, 0.04038088442757726, 0.13324974344245025, 0.05854346536632095, 0.021678583164300238, 0.03701751186911549, 0.4345978796482086, 41.7626166343689, 54.15048347200666, 38.58438900538853, 34.141561440059114, 32.946704047066824, 37.05849511282784, 40.63920061928885, 20.498043945857457, 17.23501181602478, 23.73386345590864, 17.612509182521276, 3.6814965094838823, 25.41646354539054, 48.46281664712088, 53.598852089473176, 39.471555846078054, 49.39289208820888, 53.75277900695801, 13.411843708583287, 0.09772764811558382, 0.09196675010025501, 15.399943930762154, 55.85871546609061, 51.093001638139995, 55.19720179694039, 53.34634065628052, 54.11795200620379, 50.732800074986045, 46.492019176483154, 43.1642176764352, 53.839138167245046, 54.16915675571987, 57.74350813456944, 54.474335534232004, 53.54815803255354, 47.52768291745867, 45.113798822675435, 45.66224445615496, 47.29013442993164, 50.903027466365266, 52.92600243432181, 52.5420241355896, 53.46909448078701, 50.65172501972744, 52.825781617845806, 48.00094556808472, 51.222717557634624, 57.70765542984009, 57.96738256726946, 41.738193716321675, 35.61901944024222, 38.98269101551601, 31.802585874285015, 21.051455804279872, 34.810401984623496, 36.54778167179653, 5.690858219351087, 0.8958930181605476, 0.4928914744939123, 0.1903967091015407, 0.12045312938945633, 0.11684377092335906, 0.03495960336710725, 0.05394095894215362, 0.2306553859795843, 0.25187711151582853, 3.0750733699117387, 2.629107368843896, 2.709478050470352, 0.6998656083430562, 1.4084820385490144, 0.49741046343530926, 0.5300742164254189, 0.14237871287124498, 0.07397808786481619, 0.07994797466588871, 0.11270296347460576, 0.0022112094946870847, 0.03633757567565356, 0.030665782878973653, 0.2712453779365335, 0.11247423610516957, 0.18773763892906054, 0.46624263588871273, 0.40714239861283985, 0.8589266474757875, 1.8116640725306101, 1.1665178622518266, 2.1405697550092424, 0.13321540957050665, 0.010523687133432498, 0.002795908845395648, 0.05055289788703833, 0.022037886116387587, 0.02174388537449496, 0.048131433714713366, 0.046419781632721424, 0.4783367354954992, 24.780062402997697, 38.069374629429404, 35.20822804314749, 42.872337750026155, 32.60296624047415, 36.47152866636004, 43.10500512804304, 36.10779741832188, 42.03970384597778, 48.71886123929705, 47.087875843048096, 42.33395658220564, 39.273441859654014, 49.311539105006624, 45.30463457107544, 49.618816239493235, 49.74045835222517, 60.090508869716096, 29.678987094334193, 31.357956750052317, 52.70968764168875, 49.84363910130092, 52.58182341711861, 43.00586823054722, 43.8292019707816, 41.144737652369905, 43.628663063049316, 45.04281949996948, 47.72454275403704, 50.06286866324288, 50.700532640729634, 52.30573674610683, 53.228540897369385, 54.17931154796055, 50.588899408067974, 36.66117279870169, 6.533289951937539, 0.07967928836920432, 0.37323953211307526, 3.0801442520959035, 56.478665011269705, 55.80901847566877, 49.20360926219395, 49.88455009460449, 52.58081940242222, 19.46374031475612, 2.1119405712400163, 29.01777219772339, 36.17804023197719, 62.42739650181362, 31.012905733925955, 28.82340850148882, 32.15051691872733, 24.0212687424251, 36.19054351534162, 32.77362789426531, 40.66199765886579, 61.30560289110456, 28.54747816494533, 0.26039321454507963, 0.04092955802168165, 0.11329598951020411, 0.06371278262564115, 0.07932272500225476, 0.041062303220054934, 0.14447743525462492, 0.06623670219310693, 0.03741882122786982, 0.11664470231958798, 0.017579644718872647, 0.061531787871250083, 0.09854094018893582, 0.06025861868900912, 0.158017669405256, 0.026239705737680197, 0.04063703478979213, 0.06789633099521909, 0.3816821090877056, 52.541589873177664, 63.164926937648225, 41.055296966007774, 30.674389498574392, 41.11708034787859, 43.142577511923655, 34.07933684757778, 19.457950728280203, 20.180377517427715, 31.635189873831614, 23.909665039607457, 4.699491849967411, 28.516669852393015, 57.2246618270874, 56.16764279774257, 43.431045872824534, 54.21680055345808, 58.15414319719587, 15.733141320092336, 0.05484616876180683, 0.3038984372147492, 15.579534019742693, 60.05105004991804, 54.89539636884417, 57.95560884475708, 54.30246836798531, 56.149754660470144, 53.574060916900635, 48.86809812273298, 44.18632548195975, 56.32365070070539, 56.110962867736816, 57.02995245797293, 56.78274597440447, 55.741902351379395, 49.04633331298828, 45.1806891305106, 47.40695101874215, 49.90650987625122, 53.07863698686872, 55.27669961111886, 57.382799352918354, 55.4962557383946, 53.40147808619908, 54.49679211207798, 50.6210869380406, 53.614766938345774, 59.4426657812936, 56.32951845441546, 44.58447463171822, 38.80984762736729, 39.764279978615896, 31.951294694628032, 29.394590377807617, 47.4239046233041, 34.86354875564575, 10.600163085120064, 1.7436236206974303, 0.30193494686058586, 0.15879839179771288, 0.1466359230024474, 0.039804387505033186, 0.044842621976775784, 0.06903873290866613, 0.08917326892593078, 0.5481260706271444, 2.7910271031515936, 4.789951315947941, 6.171372617994036, 5.842795346464429, 6.761434052671705, 4.892171476568494, 1.2958004964249474, 0.4305320978164673, 0.08072741462716035, 0.10347641392477921, 0.12588975551937306, 0.05956721186105694, 0.15671262943318912, 0.8092193976044655, 0.919148747410093, 0.6639812024576324, 1.398586175271443, 3.3971175977161954, 3.0529164331299916, 3.511769388403211, 1.988192937203816, 1.6776722967624664, 1.4095178629670824, 0.08765299086059843, 0.012069468785609518, 0.0267705762692328, 0.025181710187877928, 0.04173250922134944, 0.06019545386412314, 0.04168948331581695, 0.08142820559442043, 3.187653077500207, 32.63216951915196, 42.516913073403494, 38.016484941755024, 44.426496914454866, 38.295118127550396, 42.19774409702846, 43.94978448322841, 36.95295197623116, 44.80589982441494, 50.132493087223594, 48.75999457495553, 45.52069575445992, 38.16712188720703, 50.82062183107649, 46.72338376726423, 53.97541318620954, 49.24826186043875, 65.263810975211, 39.06240769795009, 34.87335613795689, 55.9709392956325, 50.9294410433088, 56.086960315704346, 47.66067143848964, 44.72725316456386, 42.97211735589163, 46.193990094321116, 47.6362624168396, 50.381638118198936, 51.365829604012625, 54.866127082279746, 52.840178285326274, 54.91641466958182, 57.21868985039847, 53.43682704653059, 35.67932980401175, 5.176617699010031, 0.0679460268999849, 0.1879065398659025, 4.245813565594809, 55.27339921678816, 52.45198590414864, 56.10808283942086, 54.8770044871739, 59.12658527919224, 21.16028196471078, 3.2168122785431996, 31.664000579289027, 39.847800799778526, 69.43248694283622, 40.277856077466694, 27.990814549582346, 35.336026259831016, 24.43231722286769, 40.012719767434255, 35.56130075454712, 45.890093258449006, 69.57265295301164, 33.40266568320138, 0.4598364510706493, 0.06364068149455956, 0.13240507590983594, 0.027518047053100805, 0.0669630535745195, 0.01190141771387841, 0.0830354718491435, 0.10877474104719502, 0.12549627306205885, 0.2728007159062794, 0.1361778120377234, 0.20354401719357285, 0.2257156510438238, 0.07623633383108036, 0.2296058280127389, 0.14847062741007122, 0.2117882040994508, 0.17455539985426835, 1.4478383724178587, 64.99948065621513, 72.22277927398682, 52.05031749180385, 46.103726046425955, 42.665771280016216, 55.48979391370501, 53.43191467012678, 28.04318138531276, 26.483269112450735, 36.03807919366019, 27.94125999723162, 9.167680774416242, 35.197235992976594, 58.2863952091762, 60.9523286819458, 49.9946095602853, 58.677189690726145, 63.487198284694124, 17.012287310191564, 0.2664053605071136, 0.9058461497936929, 24.173271008900233, 65.76918819972447, 57.69683013643537, 64.18771566663469, 56.781790597098215, 58.913560458592, 55.793551785605295, 51.71367032187325, 47.59419454847063, 58.10887915747506, 59.03276375361851, 61.6237678527832, 58.83945792061942, 60.48522908346993, 53.161525521959575, 48.89089516230992, 49.46327386583601, 51.38696602412632, 56.70142078399658, 57.674123423440115, 60.093149185180664, 57.760176862989155, 56.80599117279053, 56.756287234170095, 55.63778012139456, 59.05294827052525, 60.33056913103376, 51.41875403267996, 48.55296604973929, 40.169714314596995, 47.272284507751465, 37.94424799510411, 30.36298860822405, 39.02815655299595, 41.56511756352016, 22.690726927348546, 2.4516881576606204, 1.925437024661473, 0.6321018902318818, 0.2748115951461451, 0.16350012379033224, 0.11226771040154354, 0.23734864539333753, 0.6459804283721107, 1.4782395639589854, 10.474846243858337, 10.11243428502764, 10.823235869407654, 8.14713110242571, 10.142180391720363, 6.563351333141327, 1.1412162142140525, 0.470372525709016, 0.1899686892117773, 0.17083793718899998, 0.20685249966170105, 0.11932510563305446, 0.25673805496522356, 0.4319876639970711, 0.5865149221249989, 0.5305799150041172, 1.1469820248229163, 5.0051174845014295, 4.37528760092599, 5.273396985871451, 3.694195645196097, 2.594713134425027, 3.6898582322256903, 0.4470774142869881, 0.20114680725548947, 0.1780416313558817, 0.12826708438141005, 0.09843529907188245, 0.11658820749393531, 0.2004331105521747, 0.3989338347954409, 13.409461344991412, 43.380994524274556, 44.58507912499564, 43.134114606039866, 47.37585088184902, 43.19922270093645, 45.57049696786063, 45.470175402505056, 37.527321338653564, 48.24985783440726, 54.183987685612266, 53.14148344312395, 47.137103830065044, 44.79402535302298, 54.136232716696604, 49.052673544202534, 56.03254549843924, 52.95691496985299, 63.03202179500035, 38.00570133754185, 36.77161094120571, 54.74501998083932, 55.10848372323172, 58.115479946136475, 47.47592578615461, 48.15728003638131, 45.5404668535505, 47.560120582580566, 49.28514289855957, 53.81722354888916, 56.19116244997297, 55.202016898563926, 54.12208271026611, 54.98132126671927, 60.14289133889334, 55.766203675951274, 43.58918687275478, 9.697989872523717, 0.14010537628616604, 1.5734133826834815, 4.439003450529916, 60.87663500649588, 60.98185157775879, 57.84348923819405, 59.222887311662944, 62.557557106018066, 27.172711065837316, 6.126141147954123, 36.267421858651296, 44.4969551222665, 73.17630141122001, 37.52356236321585, 38.682452406202046, 45.92112738745553, 32.16012280327933, 50.702179363795686, 44.81646108627319, 57.73281485693795, 79.4732106072562, 51.25120517185756, 0.7031893985612052, 0.19234110548027925, 0.36858687177300453, 0.148851285555533, 0.12728179725153105, 0.14809785384152616, 0.30949208991868155], [0.036844885775021145, 0.0316703234400068, 0.06687869810100112, 0.05215152639097401, 0.04127557695444141, 0.03070905984246305, 0.04373421806043812, 0.08766352850943804, 0.0405614425960396, 0.14106194781405584, 0.06555073043065411, 0.07271770906767674, 37.15072897502354, 57.04409899030413, 35.06333030973162, 34.50721039090838, 36.01130083629063, 30.461941378457205, 46.587021895817344, 21.209980692182267, 19.45125961303711, 20.83616934503828, 41.11328663144793, 4.37656216110502, 6.488025912216731, 46.87772410256522, 54.13924823488508, 47.905046531132285, 43.328083992004395, 57.21059519904, 13.765863980565753, 0.3568532371095249, 0.18520434200763702, 5.061460426875523, 47.86123813901629, 51.654933725084575, 53.974926812308176, 54.33792849949428, 52.41353109904698, 50.13791615622384, 44.983155318668906, 48.14183071681431, 56.5937306540353, 56.79523883547102, 56.47497204371861, 53.91785083498274, 51.52441528865269, 47.49346651349749, 47.27692243031093, 45.25352362224034, 47.37699386051723, 51.1577901159014, 57.44966186795916, 52.69680220740182, 54.525436060769216, 49.79990366527012, 51.8781862940107, 54.42108106613159, 45.98636749812535, 43.770468848092214, 62.998225757053916, 84.46589429037911, 54.53517048699515, 30.950563022068568, 23.1395423412323, 29.705046313149587, 37.06592621122088, 24.36245482308524, 1.2806358358689716, 0.7381366661616734, 0.49876856484583443, 0.08422612438776664, 0.1532686028097357, 0.022393631848639677, 0.0256389240468187, 0.2411714302642005, 0.36802898028067177, 5.137114584445953, 16.74767906325204, 11.277227691241674, 2.495570808649063, 0.9441274127789906, 1.6153677999973297, 0.785930013017995, 0.10476988487477813, 0.042849340542618714, 0.08462302666157484, 0.04965561335640294, 0.03320211285193052, 0.02485353672610862, 0.1373187279594796, 0.012554088673953499, 0.10152250448507921, 0.05806318470942123, 0.18987515994480678, 1.2060513751847404, 1.6910678808178221, 1.5208217075892856, 4.2054532170295715, 7.346960919243949, 6.240390811647687, 2.569549581834248, 0.11102926185620682, 0.011403586748721344, 0.040559016833347936, 0.025012476768876826, 0.0907342726630824, 0.01540976097541196, 0.11592280891324792, 0.6819599377257484, 12.421559521130153, 32.43207877022879, 38.94386795588902, 36.59463684899466, 43.08731501443045, 42.51625646863665, 38.95574590138027, 38.54926586151123, 43.79741048812866, 46.01819372177124, 48.249836989811485, 46.58077546528408, 39.25525494984218, 42.05562564304897, 44.86678688866751, 50.012956278664724, 50.43409354346139, 47.27709266117641, 26.39461530957903, 47.330673694610596, 48.91008608681815, 51.601946762629915, 47.945068155016216, 45.156759534563335, 40.74044976915632, 45.122834954942974, 47.21083811351231, 50.87800700323922, 47.81321219035557, 52.110669544764924, 50.877850668770925, 54.26553521837507, 53.45775154658726, 52.2271317754473, 48.95041343144008, 28.71240929194859, 1.1097661703824997, 0.2515592857130936, 0.5887251549533435, 9.598218083381653, 53.72502442768642, 50.64667020525251, 57.552929469517295, 40.92041853496006, 55.36532735824585, 12.46999888760703, 3.2088446489402225, 43.87788105010986, 30.020310401916504, 52.69967181341988, 29.049000876290457, 33.64324705941336, 31.68432753426688, 23.269805431365967, 32.46007306235177, 18.835426875523158, 37.419832706451416, 60.16666807447161, 20.38576626777649, 0.26850854765091625, 0.15373000662241662, 0.08137426206043788, 0.01493237427036677, 0.07704213487782649, 0.07974144896226269, 0.1007242351770401, 0.05150627690766539, 0.09105690249374934, 0.07344859984836408, 0.06221092000071492, 0.15605690676186765, 0.052041936200112104, 0.03444716693567378, 0.07233834013875041, 0.1024924838649375, 0.07185045310429164, 0.16313931957951613, 0.08594227515693222, 41.42330483027867, 66.53005068642753, 40.49882616315569, 28.285124608448573, 40.59468003681728, 37.439256395612446, 34.44001088823591, 17.522667237690516, 16.369535514286586, 26.54868640218462, 52.30726882389614, 9.291877218655177, 5.747030930859702, 50.17429344994681, 58.18795313153948, 53.04587275641305, 45.994549001966206, 62.21788052150181, 14.64717435836792, 0.32292898318597246, 0.34239764564803665, 5.2584422911916455, 52.42293895993914, 55.75977659225464, 58.53787136077881, 57.477124622889924, 56.65193223953247, 51.75061389378139, 46.25198323386056, 52.66448266165597, 61.6246155330113, 60.02773189544678, 58.81742518288748, 56.35526500429426, 54.47148677280971, 49.844924518040244, 47.92354610988072, 46.81619085584368, 49.219107219151084, 53.28743730272566, 56.033886500767295, 54.9330278124128, 56.836907182421, 52.059579440525596, 55.434163161686485, 57.49376903261457, 46.55263178689139, 48.49509102957589, 68.74188464028495, 78.05706351143974, 49.903855664389475, 33.10090889249529, 30.609951904841832, 43.903137751988, 44.02575608662197, 30.89474466868809, 4.009561351367405, 1.9643026420048304, 0.9686630219221115, 0.2503098041883537, 0.08087990858725139, 0.11307296862027474, 0.14654499930994852, 0.07654114533215761, 0.8068795374461583, 2.9620183621134077, 16.207453148705618, 13.887389710971288, 7.5801763364246915, 5.1431039316313605, 6.181490063667297, 2.748123062508447, 0.38181833177804947, 0.06980141305497714, 0.09066483138927392, 0.037347554694861174, 0.03647828008979559, 0.05876770083393369, 0.22581895121506282, 0.07913101850343601, 0.41965064885360853, 0.18274979586047785, 0.320129890527044, 1.7421327978372574, 4.147390161241804, 5.5857263292585095, 6.749959536961146, 6.760792647089277, 5.812127300671168, 0.9930401252848762, 0.056667648521917205, 0.019168405627299632, 0.07776993153882877, 0.051512438005634716, 0.07535596857113497, 0.01162445159362895, 0.01693805762832718, 0.636178040078708, 19.370545864105225, 36.182355063302175, 42.38266692842756, 40.926268918173655, 49.16857991899763, 43.09920685631888, 39.675534112112864, 43.20376682281494, 42.40555429458618, 49.03007452828543, 49.79060002735683, 50.50354078837803, 43.90201561791556, 43.46715566090175, 46.55812086377825, 50.9808611869812, 53.78321211678641, 52.442994935171946, 30.11006028311593, 49.524480547223774, 50.71720831734793, 54.40515579496111, 49.36452259336199, 49.12020308630807, 43.85660219192505, 47.39112997055054, 50.45673772266933, 52.9601354598999, 48.79578127179827, 54.77362224033901, 53.43507610048567, 56.824330942971365, 54.72107996259417, 54.03217649459839, 51.27122640609741, 28.260812861578806, 1.4425613241536277, 0.3706864219691072, 0.4482281282544136, 11.914684091295515, 57.23579978942871, 53.609632219587056, 63.62253529684884, 45.988406794411794, 57.67280673980713, 11.02517397063119, 4.948906123638153, 49.91679668426514, 32.822254862104145, 58.83211367470877, 35.587064674922395, 30.672913006373815, 32.765752111162456, 24.135318211146764, 35.983761651175364, 20.7025693825313, 43.45523255211966, 69.6557812009539, 25.846735954284668, 0.24423509729760035, 0.19571725146046706, 0.07318906698908124, 0.018593844225896255, 0.03589471961770739, 0.0973139385293637, 0.10677123748298202, 0.16416359533156666, 0.16486966530127184, 0.20523274157728466, 0.1055025669879147, 0.2607109860650131, 0.1787411602480071, 0.18340806982346944, 0.21411043591797352, 0.11874459178319999, 0.1945633212370532, 0.2663322144321033, 0.4113014925803457, 58.31868348802839, 79.62983689989362, 47.52465697697231, 46.52875082833426, 48.65730019978115, 48.37076691218785, 60.06516184125628, 26.462792771203176, 29.152265003749303, 31.31302969796317, 53.35351814542498, 11.056750927652631, 11.016949040549141, 53.595985957554404, 61.921741349356516, 61.006740025111604, 53.096097809927805, 67.04728153773716, 16.0892173903329, 0.35943327152303284, 0.7773741206952504, 9.84529515675136, 63.08391094207764, 60.86118221282959, 62.57361439296177, 60.11630753108433, 60.71180983952114, 54.72527667454311, 49.79281302860805, 53.691756452832905, 63.17200715201241, 63.453027044023784, 61.92341586521694, 60.0864372253418, 57.61868722098214, 53.13479927607945, 52.269140584128245, 48.00720589501517, 50.55461352212088, 57.050870009831016, 58.57360594613211, 57.96226521900722, 60.81552559988839, 55.36457347869873, 57.836047717503135, 56.58518089566912, 47.604231221335276, 54.19021674564907, 68.01344244820731, 72.33720220838273, 50.32931123461042, 40.75474568775722, 30.685048035212926, 34.901023864746094, 46.70247663770403, 39.24280030386788, 13.716466631208148, 2.2294174560478757, 2.0225109585693906, 0.7541733799236161, 0.30282480482544216, 0.21196000916617258, 0.1694594118744135, 0.3980376257428101, 1.3156037309340067, 12.757434572492327, 33.33086994716099, 28.79251159940447, 13.548167364937918, 7.775876692363194, 7.222752749919891, 2.9379337344850813, 0.306289296065058, 0.11865041112261158, 0.1869021180484976, 0.20499853843024798, 0.0978406716936401, 0.07878742194069283, 0.6007057492222104, 0.11208244320005178, 0.2749966180750302, 0.22048312824751648, 0.44612198269792963, 2.862520375422069, 5.796947223799569, 11.433444040162222, 16.52442649432591, 19.82312720162528, 12.39370766707829, 4.424199879169464, 0.21259870060852595, 0.15268237569502421, 0.18297152753387178, 0.1460899194436414, 0.21659757888742856, 0.15997326161180223, 0.23201050183602742, 4.140557910714831, 33.92591367449079, 40.46089594704764, 46.53390291758946, 44.750998633248464, 52.85046509334019, 45.839121273585725, 43.24308320454189, 44.293598720005576, 45.66165733337402, 52.478802476610454, 52.53623628616333, 52.64352689470564, 45.96260813304356, 46.875236647469656, 51.123761313302175, 53.736329146793906, 52.545612880161826, 53.17615147999355, 32.93990523474557, 51.89355223519461, 54.59038782119751, 56.03608907972063, 51.94573320661272, 52.40247998918806, 47.3052328654698, 48.85432679312569, 51.26364592143467, 55.376666818346294, 51.120672839028494, 56.621922969818115, 55.06835092817034, 57.73225900105068, 58.006379331861226, 57.63419212613787, 56.773883547101704, 34.761455399649485, 2.6336799349103654, 0.7306406455380576, 1.1790787939514433, 10.373508504458837, 62.42201164790562, 60.892657552446636, 63.73604106903076, 49.44576440538679, 63.106256348746165, 18.628792660576956, 6.944372304848262, 54.32579347065517, 39.59599460874285, 60.48060853140694, 33.96744653156826, 46.02146632330758, 45.17217411313738, 34.38757283346993, 47.89880357469831, 28.80963717188154, 53.25649350030081, 79.30368150983537, 38.00646216528756, 0.38275462867958204, 0.3893307186663151, 0.15889786503144673, 0.0843775055504271, 0.10115511169923203, 0.17443034585033143, 0.13701527352843965], [0.04237169260159135, 0.06157990278942244, 0.022459174938766018, 0.040591376168387275, 0.06200420430728367, 0.02003758354112506, 0.05066286466483559, 0.0540757159968572, 0.15093703434935637, 0.1680938194372824, 0.15318393521010876, 0.09108795904155288, 17.872505562646047, 55.28459276471819, 37.749351024627686, 33.66089200973511, 30.644029344831193, 30.252408027648926, 44.10688672746931, 13.909155811582293, 23.06024602481297, 23.549232448850358, 29.16222177233015, 12.855674283845083, 2.171991680349622, 40.57432876314436, 55.793457984924316, 52.006113052368164, 45.93351602554321, 55.44309507097517, 17.348673922674998, 0.18227210720734938, 0.11595669495207922, 1.320338059748922, 38.20071990149361, 52.55262361254011, 56.262245995657786, 55.81080068860735, 56.855966091156006, 48.645318031311035, 45.40237488065447, 51.79571465083531, 57.33361305509295, 56.51254095349993, 58.58435480935233, 55.94295195170811, 51.75395597730364, 48.17080470493862, 46.7802026612418, 44.28707088742937, 45.86628178187779, 49.960469586508616, 54.309100423540386, 55.25271095548357, 55.971502099718364, 49.73652219772339, 47.44161558151245, 48.024242877960205, 53.962774412972585, 46.35553223746163, 41.20516266141619, 46.85089363370623, 46.504067352839876, 39.71316902978079, 39.65546771458217, 34.67456817626953, 33.44326400756836, 18.665166480200632, 3.3032224646636417, 0.22064394104693616, 0.105785258247384, 0.03989438499723162, 0.0712327283940145, 0.26347018086484497, 0.3234015963971615, 0.4612544806940215, 1.2438964758600508, 18.237365892955236, 29.885814121791295, 18.015082597732544, 6.5336386646543225, 2.116484693118504, 0.8152765440089362, 0.40805793234280174, 0.18258994658078465, 0.014711602724024227, 0.14002510559345993, 0.14500473838831696, 0.06384631153196096, 0.045488013952438316, 0.03244097637278693, 0.12874953635036945, 0.14171708694526128, 0.014401050816689218, 0.21858960842447622, 0.7586218012230737, 1.158473368201937, 5.323869134698596, 11.53432754107884, 19.420878614698136, 18.80598909514291, 8.098994851112366, 1.678383510027613, 0.09204208105802536, 0.09521180990019015, 0.05389474731470857, 0.023738852968173366, 0.1366264865334545, 0.019050080994410173, 0.220316100067326, 1.5566773435899188, 26.814779826572963, 36.28931563241141, 36.5584089415414, 45.281014169965474, 41.497084277016775, 37.90130465371268, 41.60217925480434, 40.20841578074864, 45.82340792247227, 44.4447672026498, 50.5781957081386, 53.03041648864746, 50.83179106031145, 51.86117362976074, 50.553675515311106, 47.5950665473938, 39.05886064256941, 43.11883551733834, 49.138337884630474, 52.04624237333025, 49.88731895174299, 48.46729128701346, 44.63446692058018, 42.35809462411063, 50.018223013196675, 49.156646387917654, 51.84501906803676, 53.195363249097554, 52.300105231148855, 52.614636284964426, 55.030771596091135, 53.44639819008963, 50.98701729093279, 48.2084014075143, 16.473572628838674, 0.610261585031237, 0.21040277129837445, 0.4363130804683481, 23.864741461617605, 54.39032139096941, 40.84558296203613, 40.517377853393555, 42.29602289199829, 45.62042324883597, 2.899900381054197, 10.831582392965045, 41.0265348979405, 26.479478870119365, 29.466240201677593, 18.63458398410252, 38.9564094543457, 28.150833300181798, 29.024577958243235, 31.998417377471924, 27.171486445835658, 40.587728364127024, 60.29585593087332, 14.487034014293126, 0.12401196413806506, 0.04155174409970641, 0.06998313151832138, 0.027557929645159414, 0.04303599874089871, 0.042795878768499405, 0.07462758158466645, 0.10546607537461178, 0.08013199336294617, 0.058503872847982814, 0.04449894059715526, 0.05519774489636932, 0.03615918881925089, 0.04382738091849855, 0.022573284172852124, 0.033997030196977515, 0.0775091162483607, 0.2911747113934585, 0.10974879163716521, 23.444667271205358, 68.83121068137032, 39.98660496303013, 29.736914225987025, 35.20839479991368, 39.62347820826939, 34.227837221963064, 17.907937901360647, 21.215702533721924, 22.39615457398551, 37.67071826117379, 22.87776722226824, 3.6950902257646834, 45.741683210645405, 60.09914548056466, 56.071851457868306, 51.62554979324341, 58.663863045828684, 20.396694047110422, 0.5798657132046563, 0.18338212264435633, 1.2077895104885101, 43.12362282616751, 58.212834630693706, 58.14853947503226, 58.793398312159944, 59.659338406154085, 51.852102756500244, 47.16509117398943, 54.6842406136649, 59.84415354047503, 56.836754322052, 60.21234553200858, 58.768704414367676, 54.41941349846976, 49.469110352652415, 49.200586795806885, 47.16366679327828, 49.690299306597026, 53.364225319453645, 53.54572268894741, 55.52122756413051, 59.85674367632185, 52.58503348486764, 49.987883704049246, 49.282985482897075, 55.032571179526194, 46.55296877452305, 48.47636563437325, 53.50854982648577, 47.357247080121724, 44.44647993360247, 48.03018011365618, 41.68741280691964, 42.39106730052403, 24.964479752949305, 1.2187171812568391, 2.0622589971338, 0.6627015396952629, 0.5125115588307381, 0.08406731326665197, 0.1532398872077465, 0.0922291667333671, 0.11264574261648314, 0.7378702461719513, 17.524777753012522, 27.09465673991612, 20.485808168138774, 9.026667084012713, 5.1197497333799085, 3.2148897988455634, 0.9247882962226868, 0.1446148385959012, 0.170093923541052, 0.0994460584063615, 0.05577173802469458, 0.17966464640838758, 0.0327766985366387, 0.035302070169044394, 0.04589564386489136, 0.04982262457321797, 0.027149672087814127, 0.1432288358254092, 1.0273998358419962, 2.493767533983503, 6.332640741552625, 8.89354133605957, 14.642600706645421, 16.74273715700422, 9.29149419920785, 1.6265313838209425, 0.07706538148756538, 0.10706891758101326, 0.04387943133977907, 0.018170034645923545, 0.09200904318796736, 0.058849138606871874, 0.20353613261665615, 5.2789928913116455, 35.23618412017822, 37.068538733891074, 41.595613207135884, 44.35280084609985, 47.13211154937744, 40.35174669538225, 41.67383255277361, 41.995697430201936, 47.635716983250205, 45.69160059520176, 51.25549915858677, 52.30339520318167, 53.63553510393415, 52.332487310682026, 54.50525501796177, 51.786751474652974, 44.204793793814524, 45.575947829655235, 52.11410195486886, 52.816967827933176, 51.54231037412371, 51.65054246357509, 48.488254002162385, 46.77925770623343, 53.25806379318237, 52.014106954847065, 52.30553872244698, 55.33212191717965, 54.334972040993826, 55.451068128858296, 56.56622968401228, 56.71076263700213, 56.92957183292934, 50.302258423396516, 15.684952088764735, 0.5444632843136787, 0.17672070009367807, 0.7290274692433221, 30.61158820561, 58.714911460876465, 43.83278029305594, 42.72554315839495, 44.997690950121196, 44.996798106602256, 3.349667263882501, 12.969985178538732, 49.599778175354004, 32.17432492119925, 33.77228205544608, 24.354782274791173, 32.37936973571777, 30.903766904558452, 32.28462062563215, 34.46774809701102, 30.383520535060338, 46.10016162054879, 67.40928268432617, 16.908411741256714, 0.03544683900794812, 0.08599856642207929, 0.039939365083617825, 0.032833922787436416, 0.06602796446532011, 0.010145040844301028, 0.026067071161898117, 0.1642429567873478, 0.25977721331374987, 0.20605949578540667, 0.08423010738832609, 0.20989496926111834, 0.11551860560263906, 0.24042669736913272, 0.2103287431278399, 0.19575130034770283, 0.24729873718959944, 0.3495684308665139, 0.2785742075315544, 33.49673039572579, 82.02887616838727, 47.46138668060303, 45.75025381360735, 42.720481395721436, 44.93833943775722, 59.01940931592669, 20.67006744657244, 31.824472699846538, 34.476054668426514, 42.36624138695853, 19.781830583299907, 6.4405805724007745, 52.2396559034075, 63.677954128810335, 61.39340727669852, 55.55291829790388, 64.35395826612199, 21.041264533996582, 0.7413341945835522, 0.5410824971539634, 3.162832809346063, 55.5234648840768, 59.60702541896275, 60.87722560337612, 63.66769163949149, 62.78811223166329, 54.98715080533709, 50.09327050617763, 56.44773163114275, 64.09922340938023, 59.136750493730815, 61.836389677865164, 62.525887216840474, 56.8110842023577, 51.71209308079311, 51.37038762228829, 49.56568683896746, 50.15120806012835, 54.03813804898943, 58.95940467289516, 58.78733253479004, 62.93266255514962, 55.13131202970232, 54.51490953990391, 54.9791464805603, 52.19979408809117, 46.32613788332258, 58.0835633959089, 69.42594868796212, 51.034879956926616, 38.62163829803467, 39.999163831983296, 44.91832167761666, 47.3277450289045, 39.97022805895124, 7.8162613596235, 3.724755559648786, 1.4543638165507997, 0.4930010714701244, 0.15289311510111603, 0.3566458768078259, 0.3675581312605313, 1.5383231341838837, 8.49121023927416, 32.37693439211164, 35.551229340689524, 27.22034444127764, 14.213002273014613, 8.039446183613368, 3.4725237914494107, 0.6223855401788438, 0.26504576631954735, 0.30497991346887177, 0.13146165439060756, 0.19170408323407173, 0.2492863562490259, 0.1615249626338482, 0.11375539842993021, 0.2857032764170851, 0.21315300943596022, 0.07307267109198229, 0.3789828967835222, 1.6572513239724296, 3.4723835246903554, 8.476082273891993, 13.317588789122444, 24.014299699238368, 29.362277780260357, 19.162127699170792, 4.372130947453635, 0.17767663379865034, 0.18545515569193022, 0.36368779465556145, 0.220317009304251, 0.21939048330698693, 0.14667027044509137, 1.2186977480139052, 16.087864228657313, 44.972941466740195, 42.507199491773335, 47.643373898097444, 48.70111901419503, 49.53161634717669, 45.59822375433785, 43.809983253479004, 44.88514402934483, 52.319535868508474, 50.54711641584124, 52.46611854008266, 52.38152422223772, 55.0788322857448, 55.440322739737375, 55.82008000782558, 58.74605328696114, 51.08089440209525, 47.884226254054475, 53.173264503479004, 54.546701022556846, 54.50653696060181, 55.01088237762451, 52.880721024104524, 46.82705783843994, 55.51965727124895, 54.148392064230784, 57.08510031018938, 60.129946844918386, 57.57099478585379, 56.208505153656006, 60.07004642486572, 59.78731032780239, 59.8916722706386, 54.560500144958496, 20.85644245147705, 2.303378858736583, 0.5432804077863693, 0.5337453622903142, 29.057726076671056, 63.12523882729666, 48.24961117335728, 44.96022973741804, 48.48527322496687, 52.289995602199006, 5.800379633903503, 16.76440511431013, 55.8032306262425, 35.39449187687465, 41.171133858816965, 23.453894478934153, 50.64359562737601, 40.613144874572754, 40.33408784866333, 45.8608934538705, 39.7536735534668, 58.87995202200753, 82.53346129826137, 27.687421458108084, 0.40446601222668377, 0.3184250848633902, 0.10178665816783905, 0.14248947692768915, 0.14217224823577063, 0.09582294603543622, 0.15296460555068084], [0.01809321091111217, 0.02601392999557512, 0.0424447097549481, 0.040756212680467536, 0.03718565284673657, 0.02741731344056981, 0.024120508560112545, 0.15789866793368543, 0.04112906088786466, 0.02887068795306342, 0.19438140599855355, 0.07716957732502903, 15.306282213756017, 63.45654283251081, 34.78929335730416, 29.841043404170446, 29.081381218773977, 19.11485389300755, 45.258151122501914, 13.49386806147439, 18.57909219605582, 25.707806723458425, 40.322737966264995, 19.418220928737096, 0.18633540560092243, 22.160827772957937, 61.83126885550362, 49.909316948481965, 46.82057169505528, 55.495255197797505, 28.56758972576686, 1.2784347768340791, 0.33504400881273405, 0.1527995451220444, 21.929643835340226, 61.09910242898123, 56.45302963256836, 57.416122913360596, 56.25686461584908, 49.238378047943115, 46.69709178379604, 55.42004789624895, 58.72199862343924, 57.20473091942923, 55.38909019742693, 54.84969111851284, 53.851116861615864, 52.09218038831438, 46.617020743233816, 45.91965436935425, 49.84756135940552, 51.73250688825335, 54.645685059683665, 52.61948265348162, 55.69175372804914, 51.3586243220738, 49.7634916305542, 43.505805015563965, 40.750100816999165, 47.16775580814907, 49.37387139456612, 32.30667073386056, 31.501513481140137, 45.274910177503315, 43.062680176326204, 44.91992671149117, 43.66455398287092, 11.491064582552228, 2.8576114731175557, 0.7895951334919248, 0.126280863104122, 0.5792300615991864, 0.08463315718940326, 0.1430068463087082, 0.2164545708468982, 1.9591136404446192, 5.017987719603947, 25.648710557392665, 26.92539688519069, 24.4972186088562, 12.952982068061829, 6.1468919430460245, 1.9228138625621796, 0.25503607200724737, 0.03158569994515606, 0.07640803711754934, 0.22098783616508755, 0.4188130652265889, 0.10329095673348222, 0.06285546041492905, 0.023425580135413578, 0.0295189704879054, 0.10477494674601726, 0.08499210899961845, 0.09257520602217742, 0.7604842984250614, 3.73472318478993, 7.753793580191476, 17.33289803777422, 23.65754270553589, 24.1966621194567, 16.73070808819362, 1.999890229531697, 0.5946089220898492, 0.020390406483784318, 0.09624939850930657, 0.006597970620662506, 0.10231621403779302, 0.05087204683305962, 0.035028355927871804, 0.8146754162652152, 10.409876244408743, 33.31782123020717, 35.47751590183803, 39.618534564971924, 41.05556099755423, 39.66671684810093, 36.71775197982788, 40.93296003341675, 41.60561513900757, 47.027263232639854, 43.968513352530344, 49.10225588934762, 51.829986640385215, 52.86404882158552, 49.8438058580671, 45.82345308576311, 49.27255971091134, 49.90625279290335, 47.03354787826538, 50.187557561056956, 46.230322224753245, 46.30261475699288, 43.65282194955008, 49.48890577043806, 53.93035064424787, 54.45801421574184, 52.51122277123587, 52.87993587766375, 53.87276744842529, 55.4351532799857, 53.51483447211129, 56.953730719430105, 55.08377940314156, 37.58154508045742, 4.4794167791094095, 0.11771355782236372, 0.1380603260227612, 3.3364956506661008, 46.252778802599224, 51.71613693237305, 49.241772242954795, 38.59599944523403, 53.206167697906494, 31.068314143589564, 1.4036694339343478, 13.028927615710668, 38.173875536237446, 31.906228678567068, 40.41291863577706, 26.325093371527537, 40.22508798326765, 26.48022059031895, 33.31346818378994, 29.023763281958445, 23.58950768198286, 41.76943629128592, 48.32833773749215, 9.758453965187073, 0.0904031815007329, 0.25747619249991005, 0.06561590371919529, 0.06750583409198693, 0.06384757360709564, 0.16617775868092263, 0.029322934935667684, 0.07064465566405229, 0.05180658972156899, 0.050060671621135304, 0.016406732478312085, 0.026764569537980214, 0.03851780029279845, 0.05734315048903227, 0.06251293593751532, 0.034005030124847374, 0.03967183229646512, 0.23589975599731716, 0.10995614515351397, 19.603114230292185, 74.59944534301758, 38.91736057826451, 32.45368766784668, 35.413050515311106, 27.837495599474224, 38.568401200430735, 18.233646869659424, 22.582251650946482, 26.16247078350612, 37.46263360977173, 21.197538205555507, 1.5317393903221403, 18.498776231493267, 68.17617620740617, 53.16486760548183, 52.392665658678325, 59.78119591304234, 33.667749881744385, 1.4042995486940657, 0.30766911059617996, 0.2932982545878206, 26.11299613543919, 65.05405875614711, 60.313497407095774, 60.0015093939645, 58.400964055742534, 52.253628730773926, 48.73346287863595, 56.75354616982596, 60.94673538208008, 58.62487670353481, 59.16568974086216, 56.90829644884382, 56.87232909883772, 53.18568440846035, 49.18417515073504, 48.63738318852016, 51.18918207713536, 53.061780657087056, 56.809229033333914, 53.27429825919015, 58.40331254686628, 49.91139098576137, 52.41525077819824, 46.10687705448696, 44.1757607460022, 48.00479139600481, 51.567928382328574, 38.32664210455758, 42.23604951586042, 46.73326757975987, 48.9262684413365, 46.4217346736363, 48.2340715272086, 14.972589765276227, 2.011731479849134, 1.4747837036848068, 0.7066456930977958, 0.24675153940916061, 0.1130333353898355, 0.03656449135658996, 0.27676564029284884, 1.4607708156108856, 6.477377797876086, 30.36787666593279, 34.0394263948713, 21.856752020972117, 10.446296095848083, 6.563651408467974, 3.024237960577011, 0.4454056125666414, 0.1106501439852374, 0.047970658234719715, 0.028121369857607142, 0.06097655623619046, 0.14612337122006075, 0.08023195514189345, 0.08055311255156994, 0.03771021809162838, 0.015577654287751232, 0.04663830044280205, 0.1048123204548444, 0.9163781532219478, 4.086981654167175, 7.847702826772418, 11.242491040910993, 23.808240447725566, 30.435159546988352, 19.659394638878958, 5.306104762213571, 0.779618117426123, 0.08422767823295933, 0.028441078595018814, 0.05461361784754055, 0.07375006617179938, 0.03731602656521967, 0.12793209164270333, 2.3573746127741675, 17.76656985282898, 37.76544305256435, 39.19548307146345, 43.38534409659249, 42.89632293156215, 40.79653910228184, 39.46171719687325, 41.3642520904541, 45.225831576756065, 49.21114458356585, 46.88607931137085, 49.53938095910208, 51.68975114822388, 54.772552217756, 52.88521998269217, 49.116086278642925, 52.12552826745169, 51.75896562848772, 50.78268814086914, 50.813228947775706, 49.591923236846924, 47.14340932028634, 44.528805664607454, 52.438165937151226, 56.611177580697195, 56.14715950829642, 54.89123092378889, 56.11461067199707, 55.27918011801583, 57.29266732079642, 56.676949228559224, 58.708692823137554, 56.26097100121634, 35.66150072642735, 3.2952771995748793, 0.5659451601760728, 0.19429326429963112, 4.469350576400757, 52.80948461805071, 54.51712254115513, 53.790764808654785, 36.686189787728445, 55.80949790137154, 30.764879362923757, 1.7428447710616248, 16.628430604934692, 47.97760656901768, 34.0710893358503, 42.63118314743042, 24.179877008710587, 32.577733857291086, 32.29586281095232, 38.958750997270855, 34.59026568276541, 26.374965803963796, 47.98872021266392, 59.35846056256975, 11.834645186151777, 0.07110417314938136, 0.24578286281653813, 0.10284766302044902, 0.027473648810493093, 0.09063374091471944, 0.19366471017045633, 0.01626374988284494, 0.17583390910710606, 0.10318550560623407, 0.11721567596708025, 0.10019552069050924, 0.23537039011716843, 0.1439862573253257, 0.18301536089607648, 0.24461909383535385, 0.22893920806901796, 0.17313585031245435, 0.5504713590656007, 0.2955070489219257, 28.721791097096034, 88.68824509211949, 48.200720173971995, 41.066764967782156, 41.68908037458147, 29.62677833012172, 60.54740851266043, 18.227627992630005, 26.498688902173722, 36.57438632420131, 50.0046775000436, 27.52994053704398, 2.7836229290281023, 27.65503764152527, 72.91730036054338, 60.26414435250418, 57.6768992287772, 64.74476664406913, 36.13831738063267, 1.864481346947806, 0.8172274678945541, 0.7684450883950505, 33.56401327678135, 72.0565436226981, 62.08710847582136, 63.29541410718645, 61.865273339407786, 54.229453223092214, 51.58048030308315, 61.3602226802281, 65.63114833831787, 63.64479037693569, 59.72303254263741, 59.240674700055806, 58.580185890197754, 55.67788164956229, 50.877267020089285, 52.556549344744, 55.03076812199184, 56.584416593824116, 59.42072337014334, 57.07297222954886, 60.347842352730886, 52.91357210704258, 52.226899010794504, 48.45846707480294, 48.87037018367222, 51.03085000174386, 47.94016967500959, 40.114111355372835, 44.29114948000227, 48.47695970535278, 56.057767459324424, 49.99697194780622, 54.93023811067854, 24.87892484664917, 5.495269903114863, 3.9600710698536465, 2.469967348234994, 0.9493996841566903, 0.4555928387812206, 0.34792974165507723, 0.6232187811817441, 2.2757363191672733, 21.702432530266897, 39.48889854976109, 34.45668656485421, 29.499310152871267, 21.263101407459803, 11.82850558417184, 5.080456367560795, 0.6568151127014841, 0.3622763603925705, 0.1710849782185895, 0.20013587150190557, 0.49044082313776016, 0.3013975742672171, 0.2055798800928252, 0.18896664226693766, 0.12525176975343907, 0.09795172752014228, 0.30971033392207964, 0.31076141180736677, 1.8495624789169856, 6.141843208244868, 14.89316143308367, 21.037995406559535, 25.939279011317662, 33.54423175539289, 29.4975939478193, 11.950287529400416, 0.9383456430264882, 0.159325952774712, 0.0831617811428649, 0.1654191701007741, 0.22696119706545556, 0.13002043244029793, 0.20843697392514773, 6.197598593575614, 32.72520589828491, 44.530344690595356, 45.17900766645159, 48.413015433720176, 47.59535837173462, 45.07365560531616, 42.92396286555699, 44.20483200890677, 47.6456424849374, 52.292490005493164, 50.04980604989188, 50.58275372641427, 53.92228031158447, 54.97860452107021, 57.760732718876426, 52.627007552555625, 53.84644767216274, 52.46666744777134, 51.115767410823274, 53.814319201878135, 51.19007839475359, 50.03751468658447, 47.60129560743059, 54.4988557270595, 59.11729553767613, 57.30819307054792, 57.259538309914724, 56.06371511731829, 59.48698834010533, 60.53799370356968, 58.98828138623919, 61.63531575884138, 59.840971265520366, 42.965224742889404, 7.587358168193272, 0.8735184616276196, 0.22347614621477468, 3.7595152258872986, 55.67758982522147, 59.214021410260884, 58.07725443158831, 43.162807192121235, 61.774898120335166, 36.720354080200195, 4.585155768053872, 18.121923310416086, 53.59231383459908, 37.62792778015137, 51.660652092524934, 32.082799775259836, 52.40944903237479, 39.465931279318674, 46.59266035897391, 41.44258608136858, 36.38845600400652, 60.89275482722691, 71.58744294302804, 20.220645802361624, 0.524228392967156, 0.6030373041118894, 0.2491774106664317, 0.14909238261835916, 0.20611171584044183, 0.37410949543118477, 0.09084570168384484], [0.10883300684924636, 0.012519532581791282, 0.06836460836763893, 0.09225623349526099, 0.05317129667050072, 0.04564886746395912, 0.08593069934951407, 0.01971241090047572, 0.11401275997715336, 0.08419413824698754, 0.05726342262434108, 0.0880606072023511, 6.163970615182604, 55.18566083908081, 44.77068635395595, 21.182135786328995, 27.24110218456813, 23.12068666730608, 40.233196531023296, 26.53297652517046, 15.369337115968976, 31.056675910949707, 38.72736208779471, 58.09913083485195, 2.6649057907717566, 7.423186131886073, 41.77425834110805, 58.54834924425398, 49.254525661468506, 52.58985900878906, 33.73706858498709, 1.371446511575154, 0.26247238154922214, 0.15183717890509538, 9.254058173724584, 57.990676403045654, 57.99321249553135, 59.46507372174944, 54.04122304916382, 51.261898449489046, 47.81492492130825, 56.91649879728045, 55.24860457011631, 57.351852076394216, 56.54181718826294, 57.416578020368306, 51.56924506596157, 53.06646721703665, 46.92077166693551, 48.90932873317173, 46.96186678750174, 52.66606685093471, 53.82911886487688, 57.02535275050572, 52.55794940676008, 51.51231500080654, 48.584615094321116, 49.87015342712402, 45.35579763139997, 41.62248536518642, 41.61513417107718, 53.16298464366368, 47.647438594273154, 45.28673948560442, 44.852692467825754, 42.16368055343628, 20.73899531364441, 5.47589658839362, 3.6515367456844876, 1.7975358877863203, 0.8532500777925763, 0.3728187861187117, 0.019281495362520218, 0.5722308371748243, 0.21706651443881647, 3.887630454131535, 6.5860024605478555, 21.33693470273699, 30.689623423985072, 25.93140322821481, 13.222215209688459, 4.0756248235702515, 0.6878930479288101, 0.27789005424295155, 0.5203330048492977, 0.08008643652179412, 0.01970583589614502, 0.4488458122525896, 0.28642510196992327, 0.0442087990231812, 0.0628968035536153, 0.07238439231046609, 0.3038131860750062, 0.1807943122195346, 0.6597050204873085, 0.2291416014943804, 1.345673905951636, 8.030992831502642, 15.51588157245091, 21.851989030838013, 22.035940851484025, 16.265015499932424, 2.711808953966413, 1.4950513818434306, 0.14520706396017755, 0.03820019840661969, 0.050756122517798624, 0.126460389899356, 0.13793410493859223, 0.11306427658668586, 0.6220627746411732, 3.5439849283014024, 20.230609519141062, 32.94759341648647, 37.63918733596802, 37.23229735238211, 38.3519161769322, 36.71107128688267, 38.41233771187918, 39.46781424113682, 46.18583985737392, 45.62606866019112, 46.38600703648159, 43.089409896305625, 44.748486859457834, 45.49831908089774, 44.610537324632915, 45.02889878409249, 46.45298419679914, 48.50579820360456, 48.294461795261924, 45.63432659421648, 44.24530873979841, 42.52033853530884, 50.4664443561009, 51.028685637882774, 52.26178591591971, 55.49680117198399, 55.25999961580549, 51.89501483099801, 53.62129129682268, 56.54228619166783, 53.452036653246196, 49.602012021201, 20.016671010426112, 0.17022987481738838, 1.0860055025134767, 0.7705235225813729, 14.930322136197772, 48.15361138752529, 50.40524809701102, 52.024748120989116, 49.35242577961513, 55.5891045161656, 23.530894415719168, 1.3891886281115668, 20.9445994581495, 43.03909451620919, 47.1825658934457, 54.8131331716265, 38.18148033959525, 41.11754935128348, 25.92037296295166, 30.42469903400966, 27.636048214776174, 27.41600223949977, 43.5755684035165, 40.99686261585781, 3.5356433987617493, 0.04590744019619056, 0.1429307418210166, 0.019142916459324102, 0.10037531211440053, 0.04513261427304574, 0.07249361609241792, 0.06760849644030843, 0.10309530116085495, 0.026045225726972734, 0.03813298612034746, 0.045279778340565305, 0.05157008294814399, 0.024642459748845016, 0.0726338421393718, 0.06545296031981707, 0.022545832342335155, 0.08853845191853386, 0.055201985740235875, 0.11267378646880388, 8.137367146355764, 67.17764363970075, 49.89518778664725, 23.781717436654226, 28.961074897221156, 38.68653447287423, 38.45842163903372, 26.425225598471506, 22.957725354603358, 33.088770389556885, 42.74875708988735, 45.22512633459908, 4.700502812862396, 8.396942291940961, 47.939579078129356, 62.516805921282085, 58.23956087657383, 55.5940203666687, 38.81908178329468, 1.7991391846111842, 1.1018532578434264, 0.340792394642319, 10.861969470977783, 58.56683840070452, 61.846089363098145, 60.70715454646519, 58.28005845206124, 53.16628851209368, 51.24009847640991, 59.05149609701974, 58.673270906720845, 56.56145279748099, 58.69957678658621, 60.90945134844099, 54.777235303606304, 54.58429077693394, 49.05890955243792, 49.944596426827566, 50.01096909386771, 54.84784289768764, 56.372597285679404, 57.13070828574044, 55.94035332543509, 50.21655586787632, 50.8193016733442, 48.9900563785008, 47.19794225692749, 42.89411340441023, 46.624531745910645, 52.68724148614066, 48.485012667519705, 48.30177477427891, 48.23391171864101, 45.391587802342, 26.070667709623063, 8.225727387837, 5.244938901492527, 2.180064184325082, 1.1151839196681976, 0.8300743613924298, 0.1610561085066625, 0.24012385361960956, 0.24011435412934848, 2.833678185939789, 16.981263603482926, 35.95154980250767, 32.78824690410069, 26.551467418670654, 14.762128829956055, 6.761550869260516, 1.9824910717351096, 0.1009717376104423, 0.12988487471427235, 0.1584241661642279, 0.13162965966122492, 0.34238437350307194, 0.06748478593570845, 0.03868373942428401, 0.09100921505263873, 0.11671407573989459, 0.13520549849740096, 0.07582087362451212, 0.09918453065412385, 0.5307673535176686, 2.9813990592956543, 10.785265701157705, 16.892931154796056, 26.309468609946116, 30.218108245304652, 26.985259090151104, 9.086068102291652, 2.836735610451017, 0.7423838611160005, 0.05439989288736667, 0.09447949419596366, 0.051674400921911, 0.1312278447938817, 0.04122196250994291, 1.2729983542646681, 7.918674332754953, 28.837806906018937, 37.94268465042114, 41.51863064084734, 40.7582927431379, 41.49316201891218, 41.71942663192749, 41.684890610831125, 40.4418683052063, 47.77486508233206, 50.12674345288958, 49.292101519448416, 45.743250029427664, 45.36721699578421, 48.0704379762922, 47.98386689594814, 48.54708787373134, 49.7743238721575, 51.308298519679475, 48.946296623774934, 48.39662115914481, 44.99374784742083, 43.37628364562988, 52.58957065854754, 54.6402758870806, 55.02175978251866, 58.39402975354876, 56.337654794965474, 55.82038572856358, 55.89772960117885, 57.90536642074585, 53.9126501083374, 48.82727745601109, 17.429384197507584, 0.22119970193931035, 1.2593878103154046, 2.142836604799543, 20.999610083443777, 51.968158517565044, 52.989568029131206, 54.831705706460134, 48.83530262538365, 60.64205687386649, 25.175258568355016, 2.325179700340543, 25.7447190284729, 48.9697641645159, 44.95927088601248, 59.32847908564976, 31.014416967119487, 34.25647422245571, 33.5071040562221, 37.696503026144846, 30.040800639561244, 28.948724474225724, 54.15064328057425, 48.06124550955636, 5.429438327039991, 0.14533644701753343, 0.18603372893163136, 0.025691612291016748, 0.08225723968020507, 0.07021139748394489, 0.06617495550640992, 0.0703958368727139, 0.23710814544132777, 0.09267003807638373, 0.22957035420196398, 0.10487887116947345, 0.13925050358687127, 0.17673992977610656, 0.24792811913149698, 0.20111172699502536, 0.24286334376249993, 0.1767549254000187, 0.3887377062014171, 0.5491091321621622, 13.947884202003479, 81.23470401763916, 61.176074572971885, 31.807880401611328, 38.29735892159598, 32.962330545697895, 56.93268115179879, 36.55972215107509, 25.402120726449148, 41.10371548788888, 45.11099522454398, 62.062081064496724, 6.56638639313834, 12.384688905307225, 52.20103086744036, 65.94695091247559, 60.434423855372835, 62.40537071228027, 42.45498030526297, 2.491282033068793, 1.1902850440570285, 0.36452543256538256, 14.21026815686907, 66.03731223515102, 59.51879024505615, 65.64972087315151, 59.27266420636858, 56.225278105054585, 52.49619729178292, 62.0307377406529, 61.15099852425711, 61.05983815874372, 62.10208879198347, 63.55836868286133, 56.305387360709055, 57.91211659567696, 51.06470857347761, 51.51558412824358, 55.3967992237636, 57.97541468484061, 58.73227500915527, 60.30879347664969, 58.3969202041626, 53.69624151502337, 52.154766287122456, 49.425374916621614, 46.39648839405605, 45.781531129564556, 50.541370255606516, 54.668117318834575, 51.3964398929051, 54.06932156426566, 49.642002378191265, 49.36306694575718, 33.10247571127755, 15.228370325905935, 10.16376062801906, 4.912394642829895, 4.416577271052769, 1.5600408145359583, 0.43188968354037827, 0.917305194905826, 0.3195588354553495, 7.02282007251467, 29.137246472494944, 37.58220863342285, 34.26400259562901, 34.48112685339791, 23.13147895676749, 10.718953830855233, 2.596469074487686, 0.39532668835350443, 0.5575786605477333, 0.2439025065728596, 0.3021116102380412, 0.4455115725951535, 0.4579215166824204, 0.21428990843040602, 0.24181023027215684, 0.3908231428691319, 0.3042510040104389, 0.2928712660712855, 0.5786745314087186, 0.5656574613281659, 3.7803024990218024, 13.728798815182277, 20.478799172810145, 26.3119022165026, 28.62966319492885, 31.97862195968628, 19.655713830675396, 4.580327204295567, 1.1146757240806306, 0.1141507468585457, 0.28737719516669, 0.19444190418081625, 0.2094460776341813, 0.2556310386529991, 4.512724706104823, 16.167985643659318, 39.57178013665335, 43.70417955943516, 45.35781260899135, 45.760478087833945, 45.09284652982439, 42.720919132232666, 47.206822054726736, 43.590878759111675, 52.312111718314036, 51.0968405178615, 51.22528144291469, 47.59716142926897, 49.91023063659668, 51.76206105095999, 50.37900822503226, 49.4558983530317, 51.25424153464181, 54.2069410596575, 51.634061336517334, 50.590737206595286, 48.77648612431118, 44.68992049353463, 54.6326641355242, 55.892337799072266, 56.76062291009085, 59.74031271253313, 59.1064841406686, 57.942191873277935, 57.77591800689697, 59.2124719619751, 56.728768893650596, 51.633745193481445, 24.712312255586895, 0.6753110545022147, 2.9061958832400183, 1.8985713805471147, 17.91336270741054, 57.92359501974923, 58.31334727151053, 61.31710910797119, 56.183526379721506, 63.82595075879778, 30.72635507583618, 4.5502232653754096, 28.800316163471766, 56.12017617906843, 46.51123789378575, 68.46179580688477, 45.43973534447806, 58.027053696768625, 43.014497893197195, 44.44428082874843, 37.35163613728115, 40.544312545231406, 62.60312339237758, 64.84357002803257, 9.559169207300458, 0.3411739484540054, 0.41601744666695595, 0.13170125867639268, 0.22795478946396283, 0.2213337126054934, 0.15320548548230103, 0.14194537326693535], [0.08169220999947616, 0.046280783734151294, 0.1283844302275351, 0.06465965110276427, 0.050977871154568026, 0.028669912833720446, 0.049959481693804264, 0.037308586428740194, 0.17156069912016392, 0.030657433505569185, 0.06980254620845829, 0.04435437871143222, 3.6404480721269334, 55.186640535082134, 44.431058406829834, 35.82942131587437, 37.08122961861746, 14.485323888914925, 39.180419376918245, 34.206572260175435, 22.669152770723613, 32.37274810246059, 30.442597593579972, 59.920514242989675, 5.767932415008545, 11.100032125200544, 49.71652528217861, 49.49415166037423, 43.67443084716797, 55.43576124736241, 42.9111955506461, 7.776396938732692, 0.39680670893618036, 0.03315762131075774, 3.3236486486026218, 47.86109570094517, 59.62624413626534, 57.51000002452305, 57.0754770551409, 53.94209657396589, 51.960956709725515, 57.852212701525005, 58.730920110430034, 60.03622259412493, 54.46091856275286, 55.89352594103132, 53.39576319285801, 53.65523672103882, 47.484013489314485, 48.23388392584664, 49.516469274248394, 52.69641310828072, 53.17645025253296, 53.10612753459385, 53.18842199870518, 48.083514486040386, 49.42182438714163, 44.86270482199532, 45.95272084644863, 45.60621765681675, 45.9752573285784, 48.006455489567344, 48.5026923588344, 46.58409323011126, 42.899119581495015, 22.99781472342355, 10.485025354794093, 6.133652150630951, 4.172503122261592, 2.749284280197961, 2.4492028738771165, 1.8088409325906207, 0.9530921088797706, 0.5009319516164916, 2.304134258202144, 3.5264702567032407, 6.350772065775735, 14.18054028919765, 19.092291355133057, 16.746086188725062, 10.26966941356659, 2.3849633038043976, 0.5280206437621797, 0.34093836109553066, 0.40653367127691, 0.12267541299973216, 0.31236677137868746, 0.5220863936202866, 0.8802771046757698, 0.11403059187744345, 0.4424265724207674, 0.28351098405463354, 0.9003376396639007, 0.18121629314763205, 0.8058084834899221, 0.4102636868400233, 0.20367017042423996, 5.686396607330867, 11.834068485668727, 16.10842742238726, 14.34949094908578, 9.51641867841993, 1.4371762531144279, 2.144313531262534, 0.3186347521841526, 0.25325100922158783, 0.07599770663572208, 0.049774075392633677, 0.027169351299692477, 0.33362698342118946, 0.8603568907294954, 3.903462358883449, 10.797119327953883, 19.33106619971139, 34.37116813659668, 38.48198645455496, 37.144506863185335, 37.598606382097515, 37.33414057322911, 35.946081570216585, 43.973752294267925, 46.75894464765276, 47.71530512401036, 46.84217364447457, 47.08646535873413, 46.924311774117605, 45.74246835708618, 45.50055987494332, 46.823288440704346, 45.43437828336443, 45.17517226082938, 43.45950222015381, 42.291086196899414, 49.55479206357683, 50.776921136038645, 53.829841477530344, 56.55630070822579, 54.31099728175572, 54.32647092001778, 56.79652772630964, 57.64311361312866, 56.3332531111581, 55.47123180116926, 41.39635624204363, 3.8275411299296787, 0.018413192758868848, 0.09881602507084608, 5.606170100825174, 35.68335281099592, 48.386056423187256, 47.68402780805315, 46.93476186479841, 46.901768343789236, 54.13997779573713, 14.775622231619698, 2.4323843249252866, 29.407076290675572, 50.67051294871739, 61.64209720066616, 56.69947876249041, 42.643380710056846, 32.42637082508632, 18.788014105388097, 31.062178884233745, 25.94959361212594, 38.31973212105887, 47.423480783190044, 35.431647368839805, 1.939669975212642, 0.17163202672132424, 0.14795156169150556, 0.07250583650810377, 0.14795868630920136, 0.09422011739973511, 0.10748509703470127, 0.03648845472240022, 0.019190454622730613, 0.07878425318215575, 0.02145225441615496, 0.03985500282474926, 0.04570899245196155, 0.04409720376133919, 0.08052532654255629, 0.1353894221995558, 0.18200047606868403, 0.020716602015974264, 0.14695841712611063, 0.06025379430502653, 5.365129709243774, 66.72653879438127, 50.758758544921875, 35.282921178000315, 35.83943714414324, 15.335890225001744, 39.38217421940395, 31.46882220676967, 31.1118654523577, 32.35107667105538, 44.26970386505127, 59.84329891204834, 7.350034628595624, 11.179627214159284, 56.41705533436367, 53.528696128300254, 48.581578731536865, 62.65993881225586, 50.751546314784456, 11.929247515542166, 0.7408068914498601, 0.09043419055108513, 3.3343801413263594, 48.688372543879915, 61.30909088679722, 61.183800969805034, 60.13614463806152, 56.907837867736816, 56.03877108437674, 59.78748403276716, 59.9619255065918, 60.9136689049857, 57.52212463106428, 58.11717530659267, 55.10425574438912, 54.91531685420445, 50.84230368477957, 49.478723185403005, 50.99039758954729, 54.660192898341585, 55.873153822762625, 54.984173502240864, 54.1993362562997, 48.68098660877773, 52.213659218379426, 48.503922189985005, 47.3338976587568, 48.10162843976702, 47.304131575993125, 48.12632928575788, 48.00078228541783, 49.567750453948975, 46.18299804415022, 25.360129288264684, 15.719137225832258, 11.153001717158727, 10.612417101860046, 5.15186995267868, 3.4222051543848853, 1.2048410858426775, 0.7046361980693681, 0.5799408406019211, 2.1841282291071753, 2.1897795030048917, 13.314760872295924, 23.34647011756897, 31.441581794193812, 31.73929820741926, 15.233906303133283, 4.108822447913034, 1.7171694402183806, 0.23703855488981518, 0.17309688883168356, 0.06997962349227496, 0.36965673150760786, 0.35151145660451477, 0.06587418128869363, 0.11609681243343012, 0.1094277495784419, 0.3849580761577402, 0.3386151114744799, 0.4774641937443188, 0.6459492700440543, 0.3631363628166062, 1.58817863038608, 8.672870891434805, 17.804718937192643, 24.962478671755107, 23.674240963799612, 20.033237252916607, 10.602010437420436, 1.8183006878410066, 0.8188627915722984, 0.25920119136571884, 0.0856417180704219, 0.16325529478490353, 0.051115498412400484, 0.636412650346756, 0.47396762136902126, 7.584663135664804, 15.350354637418475, 25.73039358002799, 39.77773169108799, 41.124904019492014, 40.26256309236799, 40.43470818655831, 40.03645133972168, 38.20015362330845, 44.12275641305106, 48.18737268447876, 49.997600759778706, 49.21478543962751, 50.056587491716655, 49.4922582762582, 46.56737239020211, 48.727949483054026, 47.864451680864605, 46.61712844031197, 46.15568814958845, 45.86193915775844, 44.94523899895804, 50.38816942487444, 53.78635270254952, 56.56169251033238, 57.14391681126186, 56.73720400674002, 56.88243872778756, 57.597342354910715, 57.86375713348389, 57.72450481142317, 55.13005093165806, 38.95582233156477, 3.2664521634578705, 0.03123499233541744, 0.02686872466334275, 8.700410945074898, 39.86376428604126, 55.99073471341814, 51.03566510336739, 54.9643155506679, 49.47940410886492, 57.51191077913557, 13.274988515036446, 4.074845322540828, 34.39577865600586, 51.230145181928364, 57.1976055417742, 61.710300718035015, 34.46687957218715, 26.696960960115703, 24.49397553716387, 33.61797993523734, 24.200285605021886, 38.596923555646626, 59.90511008671352, 43.43447828292847, 2.89190257021359, 0.16453338334602968, 0.13721037948770182, 0.018691921373829246, 0.13203923696918146, 0.09477857207613331, 0.09203712096703903, 0.02677992987446487, 0.1315845370824848, 0.10494705715349742, 0.3462901839188167, 0.13787400030664035, 0.14052659725504263, 0.1496765198452132, 0.14710352862519877, 0.2652812179710184, 0.3180478736758232, 0.12998381869069167, 0.2858594480369772, 0.2680965411875929, 9.322159205164228, 82.1860374723162, 61.82156222207205, 46.78568131583077, 48.12234449386597, 19.77658816746303, 57.869329588753835, 48.760713713509695, 29.327731336866105, 43.64788178035191, 39.08233165740967, 66.16900839124406, 9.690748981067113, 17.485794884817942, 57.772489070892334, 61.01152038574219, 52.33985587528774, 64.89793968200684, 53.072129998888286, 12.264954941613333, 0.7440081653850419, 0.10987879216138806, 5.323965975216456, 56.01194061551775, 64.37580340249198, 66.38582692827497, 62.722903387887136, 61.83420099530901, 58.57032639639718, 63.91156646183559, 65.29399394989014, 65.0362296785627, 57.4610777582441, 59.704918588910786, 58.24510553904942, 58.06266321454729, 52.62153237206595, 52.392057691301616, 53.187567370278494, 56.0579376901899, 59.52644715990339, 58.363527161734446, 57.62322439466204, 51.47124419893537, 53.11564309256417, 50.020873750959126, 50.92331968035017, 49.756446157182964, 49.49045521872384, 54.808175631931846, 50.308734144483296, 53.83259643827166, 51.29145956039429, 32.629490988595144, 20.88693114689418, 17.311030319758824, 13.72131039415087, 8.227946468761989, 5.4420636381421765, 2.6207630165985654, 1.1998901686498096, 1.3100330127137048, 1.6965871389423097, 17.95626262256077, 22.342417206083024, 25.99625597681318, 32.65009587151663, 35.803202288491384, 16.714424984795706, 2.9998877814837863, 1.2799635976552963, 0.4666024222970009, 0.5409383763160024, 0.21542630530893803, 0.9684039843933923, 1.317654318043164, 0.6335309392639569, 0.3400263286062649, 0.5719446582453591, 1.1495106262820107, 1.74166097172669, 1.7121674971921104, 2.990324020385742, 1.419600676212992, 0.8898024878331593, 7.889937451907566, 21.264185326439993, 29.163840702601842, 25.990596669060842, 23.3442154271262, 19.994570527757915, 6.699645025389535, 0.7508425329412732, 0.48110825249126976, 0.36017496458121706, 0.3373799877507346, 0.10606235159294945, 0.6549452330384935, 2.920789271593094, 11.453950779778616, 21.414638144629343, 33.21135745729719, 48.609156131744385, 45.20071036475045, 44.23998294557844, 43.17040852137974, 43.79364456449236, 39.513317993709016, 49.49089295523507, 52.07934706551688, 53.16825137819563, 52.33942856107439, 53.44867025102888, 52.66734184537615, 49.423971380506245, 49.92729888643537, 49.89573669433594, 50.57069512775966, 50.03270305906023, 48.906962871551514, 46.93782949447632, 53.75050694601876, 55.565039430345806, 58.60865960802351, 58.843703269958496, 57.049549852098735, 57.665479864392964, 61.69767584119524, 62.1016024180821, 59.94668810708182, 56.3342501776559, 46.35536895479475, 8.585447788238525, 0.16693657796297753, 0.17515983884888037, 8.531194516590663, 43.40259994779314, 57.850868225097656, 53.936704771859304, 58.102959292275564, 55.6221466745649, 61.21731213160923, 18.751859154020035, 5.4587097849164685, 37.18306589126587, 57.89572926930019, 60.0596102305821, 64.45096206665039, 47.38460561207363, 47.69355378832136, 28.308435814721243, 40.9336131640843, 34.90903166362217, 54.02483919688633, 67.02090617588588, 58.98190293993269, 4.285232433250972, 0.5305843119110379, 0.3882053004843848, 0.1260693637388093, 0.3764065264591149, 0.15333729769502366, 0.14567285110907896, 0.20834822154470853], [0.0687546506524086, 0.0833323784172535, 0.09011002044592585, 0.0343460991446461, 0.04852261933098946, 0.0903869645137872, 0.052637082657643726, 0.0770640651296292, 0.014891728326412184, 0.021599793374272327, 0.016417446546256542, 0.06929024548402854, 1.5538696199655533, 34.56085395812988, 51.19380610329764, 29.50863810947963, 32.08166721888951, 53.56549726213728, 39.786239760262625, 41.478178228650776, 18.290422337395803, 44.94238676343645, 17.923034599849156, 54.736504963466096, 6.476531420435224, 2.0259314264569963, 42.613864762442454, 53.57973412105015, 38.63898794991629, 42.717573574611116, 59.998188155038015, 23.63332302229745, 0.9693453567368644, 1.1845531059162957, 0.2625512273183891, 18.52903389930725, 51.52803530011858, 60.39258875165667, 59.600375992911204, 56.152165685381206, 52.887436458042686, 57.47611713409424, 56.24139445168631, 55.90474728175572, 56.048884187425884, 56.200375761304585, 53.4492643220084, 49.635922704424175, 48.557423319135395, 46.01183612006051, 51.613977568490164, 54.22067417417254, 53.20396511895316, 56.406323841639924, 52.60629497255598, 49.92865031106131, 51.04812669754028, 50.96334477833339, 46.15712990079607, 46.73694665091378, 51.49533707754952, 51.55494914736067, 45.45177657263619, 36.730067661830354, 18.542978933879308, 12.838984710829598, 6.275588648659842, 9.619810479027883, 8.432297331946236, 8.216818928718567, 5.288557955196925, 2.169443428516388, 1.6907459838049752, 2.496098871741976, 4.73469967501504, 5.751859494618007, 10.115871906280518, 12.85363151345934, 13.530504175594874, 11.130261131695338, 4.7142884731292725, 1.0885195561817713, 0.3408935235014984, 0.3015571657036032, 0.3677706755697727, 0.303963305162532, 0.18807938987655298, 1.7628173679113388, 3.7665641733578274, 1.1806819822107042, 1.448831313422748, 4.2584918567112515, 4.215370033468519, 4.06614921774183, 4.180655964783259, 2.4069424101284573, 1.5344819745847156, 3.114942784820284, 6.705478472369058, 13.300489272390093, 15.57305829865592, 13.231732504708425, 6.762389429977961, 1.6191819267613548, 0.7616140320897102, 0.08061344788542815, 0.18027272235069955, 0.049623627215623856, 0.08217973062502486, 0.37721447167651995, 1.1865551642009189, 3.0142431940351213, 10.890156575611659, 15.244898353304182, 16.14946174621582, 27.330879858561925, 36.57230881282261, 35.78682885851179, 36.70424815586635, 35.01067338671003, 35.62386928285871, 48.32677786690848, 47.13622488294329, 42.66457618985857, 47.85982765470232, 47.50686264038086, 46.6994298526219, 42.409653731754844, 44.96643795285906, 45.60281998770577, 44.66777311052595, 43.255583013807026, 44.91637618201119, 47.52089105333601, 53.75406789779663, 52.461883613041465, 55.58495644160679, 51.78536878313337, 58.81655665806362, 51.36125768933977, 52.65832655770438, 52.09103046144758, 53.32047946112496, 14.621328796659197, 0.06344258998121534, 0.8146683052182198, 14.60614698273795, 31.494791099003383, 46.5067389351981, 53.27608394622803, 47.43564360482352, 50.51711409432547, 48.96458428246634, 47.97289569037301, 5.674268960952759, 8.851746184485298, 40.274673802512034, 54.47702101298741, 56.09303304127285, 58.34487124851772, 41.29865067345755, 28.50964174951826, 18.666191339492798, 35.797185148511616, 26.509510721479142, 33.550346170152935, 48.76822124208723, 22.991347687585012, 0.7678792444722993, 0.11443197248237473, 0.15218328604740755, 0.05635053178827677, 0.06116614570575101, 0.04799005076555269, 0.038700190505811145, 0.05714279266872576, 0.10742874470140253, 0.050369964846010716, 0.017515144876337478, 0.03125530767387577, 0.034301326011440585, 0.08445069233753852, 0.03307911480910011, 0.04681068226428969, 0.04399363896144288, 0.053983184176364114, 0.09423119787658964, 0.060673542852912626, 1.8958800392491477, 46.13069895335606, 60.59462152208601, 35.14313037054879, 34.05613681248256, 31.089249065944127, 36.33676140648978, 32.17838266917637, 28.65268083981105, 47.680223669324604, 32.83206919261387, 62.152678625924246, 8.681071502821785, 2.7842028864792416, 39.62418692452567, 61.749377386910574, 42.66906125204903, 47.88729388373238, 62.60090691702706, 30.38496576036726, 1.6406315586396625, 0.3200881470526968, 0.2869258336722851, 18.227318797792705, 54.77212837764195, 62.07843712397984, 61.8893974849156, 60.54535184587751, 54.94998141697475, 61.280915941510884, 59.30799579620361, 57.65211500440325, 56.58690404891968, 56.63173382622855, 56.31561163493565, 52.3812323978969, 50.947026933942524, 49.54196916307722, 54.089353220803396, 55.17028447559902, 55.333011286599294, 57.59917320523943, 53.956316062382285, 52.82789387021746, 52.30734525408064, 53.43718487875802, 49.04285226549421, 49.71079649244036, 50.47862802233015, 53.072661536080496, 50.73439816066197, 38.96025875636509, 23.17361978122166, 16.337341036115372, 12.78887951374054, 13.821502549307686, 10.969092454229083, 10.657885244914464, 6.429846039840153, 2.2539773838860646, 1.319957863007273, 2.2130316495895386, 4.3147436039788385, 6.6290760806628635, 13.067293831280299, 19.299903529030935, 24.035752262387955, 23.47236626488822, 8.926961302757263, 2.8879329775060927, 0.7251780586583274, 0.30222343280911446, 0.551481941980975, 0.32836898842028206, 0.6971952744892665, 1.1616429409810474, 1.323791314448629, 0.5609643331595829, 0.5439348955239568, 0.5288980166826929, 1.1405297539063861, 0.9776091533047813, 1.378286361694336, 2.1983676935945238, 0.8474427951233727, 5.062857014792306, 12.892524923597064, 19.498820032392228, 20.00741253580366, 14.679394892283849, 9.122665132795062, 1.8895309056554521, 1.0843098163604736, 1.0652316915137428, 0.0347468724607357, 0.10725957913590328, 0.14586837776005268, 0.5850863616381372, 1.1206601858139038, 5.907809640680041, 15.045479842594691, 19.482443128313335, 22.058076075145177, 33.021178313664024, 40.30176830291748, 38.38097701753889, 39.188368116106304, 36.82870428902762, 37.07055718558175, 50.281170640672954, 49.75449023927961, 45.94050243922642, 50.54551485606602, 49.117715631212505, 49.5639636857169, 45.141890389578684, 45.99406262806484, 46.82006100245884, 45.74330561501639, 45.54969753537859, 46.862722941807334, 49.8079149382455, 55.49753768103463, 55.26984521320888, 55.46685791015625, 54.66698476246425, 58.03455427714756, 52.23025846481323, 52.19349554606846, 52.500713620867046, 50.99179417746407, 13.39655680315835, 0.23096479794808797, 2.2110016899449483, 24.065165724073136, 37.89331769943237, 50.615253925323486, 58.0489752633231, 49.48180818557739, 54.4002468926566, 52.66209595543997, 52.58235495431082, 4.498530839170728, 15.277792862483434, 46.0467403956822, 56.91608885356358, 56.5100222315107, 67.1021306174142, 38.709126540592735, 27.59276614870344, 25.657772745404923, 40.4357921055385, 30.208519731249126, 38.23574924468994, 61.411764417375835, 24.388387237276348, 1.058308245880263, 0.011989251527536129, 0.017744157230481505, 0.10674432678414242, 0.06319127418100834, 0.002711354900384322, 0.09460079590124743, 0.07260358626289026, 0.18003146243946894, 0.10550781884895903, 0.16922594154519693, 0.13273371756076813, 0.10089909365134579, 0.2042494629110609, 0.24810703524521419, 0.1727579063070672, 0.1291271818003484, 0.1036731144413352, 0.13384180595832212, 0.1324033388601882, 3.893109542982919, 66.3375299998692, 68.85478591918945, 44.45852810995919, 44.395824091775076, 61.610767773219514, 53.93646158490862, 55.57783801215035, 22.23438835144043, 54.849920409066335, 28.653368711471558, 65.29998329707554, 12.293600627354213, 6.420248406273978, 49.97707578114101, 60.676485197884695, 46.12176356996809, 51.97647551127842, 69.74558666774205, 32.344152791159495, 1.8378669236387526, 2.111088982650212, 0.6497592170323644, 25.243500300816127, 56.11455161230904, 63.04505661555699, 65.05257878984723, 63.673583711896626, 57.79194055284773, 63.068791661943706, 62.00582150050572, 58.028082030160085, 59.19074494498116, 60.67218426295689, 60.446277482169016, 54.23357697895595, 53.114006791796, 50.9825495992388, 58.07124423980713, 58.6504738671439, 56.668281350817, 60.509749276297434, 57.85357802254813, 55.927676337105886, 56.425782271793906, 55.17589862006051, 51.50072193145752, 51.85206454140799, 58.286304882594514, 54.89960697719029, 55.75068487439837, 45.062208448137554, 28.56752892902919, 20.555995396205358, 18.90240577289036, 17.50721444402422, 15.478267499378749, 12.515720639910016, 5.597949079104832, 2.432090546403612, 2.584245238985334, 3.2498576939105988, 9.876551628112793, 18.328606162752422, 21.36338996887207, 26.59099050930568, 29.353325026375906, 24.922681127275737, 7.032758167811802, 3.123899447066443, 1.879090803010123, 0.4243828063564641, 1.1481605044433048, 1.2509189333234514, 1.5779204836913516, 4.022437231881278, 5.618949140821185, 2.6592519112995694, 3.465427509375981, 6.725415459700993, 7.103183805942535, 7.570929152624948, 7.0240247164453775, 5.061967645372663, 3.2309633706297194, 4.112726032733917, 10.288982800074987, 23.81418984276908, 29.2571793283735, 23.7728602205004, 18.965865407671245, 12.906967622893196, 0.9561353112970079, 1.515416334782328, 0.2502707205712795, 0.1449856986956937, 0.2055382180426802, 0.4466075152158737, 3.161275327205658, 9.758977685655866, 20.572771821703228, 24.75360539981297, 27.7626930304936, 40.76900339126587, 45.21433230808803, 42.522746086120605, 42.07179757526943, 39.87317909513201, 37.09586599894932, 50.99949625560215, 53.70687573296683, 49.86239923749651, 53.91368538992745, 54.82730402265276, 52.60805286679949, 47.89922046661377, 48.43601049695696, 51.65750455856323, 48.591455595833914, 49.43036024911063, 49.038120542253765, 53.906219550541465, 58.05711855207171, 58.01003408432007, 60.21188695090157, 55.69812870025635, 61.2417003086635, 54.11494691031319, 52.0800974709647, 52.00897223608834, 54.63342843736921, 20.300671679633005, 0.8040931469627789, 1.4935839005878992, 18.954510314123972, 35.709665639059885, 55.37875822612217, 62.9353723526001, 54.69232484272548, 58.73530442374093, 54.251260144369944, 55.78681550707136, 8.939056379454476, 12.539676291601998, 52.78426613126482, 61.801662581307546, 61.15163081032889, 65.64263371058873, 48.41966485977173, 41.92430121558053, 26.47946149962289, 48.567300183432444, 39.898970808301655, 48.9057434626988, 71.42816938672746, 47.74741622379848, 2.0385741080556596, 0.3262029417923519, 0.3078106258596693, 0.1681428775191307, 0.2841239725904805, 0.15439536449100288, 0.12797375369284833, 0.1956627515277692], [0.023414056914459382, 0.07498092191027743, 0.012113164744472929, 0.019178671862131784, 0.01516652652727706, 0.015406624447288257, 0.026201527964855944, 0.0034462537026099327, 0.04036066747669663, 0.009138098269301866, 0.07515536647822176, 0.019202669949403832, 0.4046929143369198, 40.99770334788731, 57.45911489214216, 36.884567805698936, 37.98220600400652, 132.62144769941057, 54.62080008643014, 43.123292786734446, 20.62986864362444, 39.2344138281686, 29.652907030923025, 44.27520336423601, 34.472987038748606, 0.054453324127410135, 15.606571197509766, 46.603846958705354, 60.70024108886719, 46.8585262298584, 42.06572137560163, 49.841975007738384, 12.554269245692662, 1.097900167107582, 0.24989500216075353, 5.840978392532893, 44.673453262874055, 57.36622095108032, 56.769037178584504, 56.11255747931344, 56.916839259011404, 55.1815961429051, 59.32302474975586, 56.250892639160156, 54.02592658996582, 55.089261531829834, 54.185710838862825, 51.318477630615234, 50.784946305411204, 48.299721581595286, 54.913291454315186, 55.62725360052926, 51.98197153636387, 52.313490935734336, 52.89432212284633, 51.61073623384748, 52.77991655894688, 48.38449307850429, 50.0202762058803, 47.59525762285505, 42.170493262154714, 30.618494715009415, 22.872460535594396, 17.882246937070573, 17.621890987668717, 11.825001086507525, 12.534962807382856, 12.675905278750829, 12.75727563244956, 11.654272556304932, 5.990038096904755, 1.8379618099757602, 1.959315138203757, 2.7786981761455536, 6.758098483085632, 10.496976256370544, 13.209803989955358, 13.041373576436724, 11.196115289415632, 7.03496378660202, 2.1889029443264008, 0.45211219840816086, 0.2554180057985442, 0.8643219779644693, 2.105711728334427, 2.9115073468003954, 1.2849768315042769, 2.889190818582262, 5.3398491229329785, 3.5774678630488257, 7.589878627232142, 10.749907187053136, 12.009443623679024, 13.282396163259234, 12.807481578418187, 9.848354969705854, 1.5223333750452315, 2.0189235167843953, 3.823063450200217, 7.893877949033465, 12.384725383349828, 14.775511060442243, 11.209731153079442, 7.987362486975534, 3.2486293826784407, 1.3324659232582365, 0.5273823865822383, 0.07584934495389462, 0.6301707795688084, 0.5347418859601021, 1.7768205936465944, 3.117820207561765, 7.899286253111703, 13.83472410270146, 18.105798278536113, 16.788143634796143, 19.924360718045914, 28.34849739074707, 31.16035693032401, 30.02481630870274, 44.64850575583321, 40.65963179724557, 42.85682242257254, 48.109222820826936, 45.499757358006065, 48.26769733428955, 47.089359283447266, 45.49502910886492, 43.297091552189414, 43.7114508492606, 41.280373437064036, 42.96144492285592, 48.08742979594639, 51.21102026530674, 54.09059694835118, 54.301415715898784, 52.36714145115444, 51.857049873897004, 49.645208971840994, 54.206916740962434, 59.56128542763846, 52.71843194961548, 31.715413774762833, 1.8278450156961168, 0.6134875033582959, 18.864875078201294, 47.24994952338082, 50.89786148071289, 49.339623723711284, 46.22625058037894, 48.29826940808977, 45.007793630872456, 60.19626045227051, 25.24438272203718, 0.7467240967920848, 13.996812547956194, 32.601253509521484, 57.6888918195452, 60.574346678597585, 41.54352603639875, 27.32414358002799, 20.35894101006644, 20.823744228907994, 28.3671133518219, 16.288281542914255, 41.34962613242013, 43.56393364497593, 4.625591678278787, 0.21880555897951126, 0.07950027047523431, 0.0511332115690623, 0.08436831818627459, 0.09752653712140662, 0.054929336799042563, 0.017852638016587923, 0.0400982203095087, 0.014310710664306368, 0.06432862100856644, 0.06958881446293422, 0.07569957191922835, 0.08164325369788067, 0.024685271915846636, 0.027643386041745543, 0.050800705661198924, 0.04282756296119519, 0.08989088077630315, 0.1285210464681898, 0.10704739445022174, 0.6774681444678987, 52.130239146096365, 67.67922714778355, 39.3048095021929, 44.46388169697353, 127.08677673339844, 61.06167943137032, 28.20688441821507, 27.386500188282557, 50.84427349908011, 35.246432713099885, 62.35066754477364, 35.6778359413147, 1.2695952568735396, 14.989506891795568, 48.81410714558193, 59.29229981558663, 52.004483699798584, 45.80938993181501, 56.35371903010777, 18.339533942086355, 1.7951142234461648, 0.12852693615215166, 4.864406474999019, 44.261174951280864, 60.89431817190987, 61.330539975847515, 59.73721381596157, 61.471345220293315, 57.71518380301339, 59.810392243521555, 57.63575199672154, 56.28446980885097, 57.09067971365792, 56.60749503544399, 54.31153924124581, 53.50496803011213, 52.385627133505686, 54.54638487952096, 56.930002621241975, 55.59073734283447, 55.25790473393032, 54.56219550541469, 53.384454999651226, 54.48093979699271, 51.943600109645296, 49.90962266921997, 49.56118788037981, 43.31027923311506, 37.498104163578574, 26.59474774769374, 21.72159739903041, 20.441344908305577, 17.609825440815516, 16.848030158451625, 17.129812615258352, 16.37762495449611, 13.802153553281512, 5.5059115035193305, 2.9952311856406073, 1.6823186874389648, 3.1270910586629594, 7.073487205164773, 9.721430488995143, 13.463555676596505, 19.398006881986344, 19.504805905478342, 13.798239980425153, 3.8839075224740163, 1.636667828474726, 1.1096732382263457, 1.0353042802640369, 1.115088164806366, 1.8260997150625502, 1.7640098524945123, 2.252552786043712, 4.965431979724339, 2.1199696489742825, 1.3216751537152698, 3.3627146780490875, 4.300927111080714, 2.265671853508268, 1.6302765714270728, 3.6799913559641158, 3.6316234256540025, 3.2661512196063995, 5.670096133436475, 12.600695371627808, 18.85629231589181, 18.429606914520264, 12.184624212128774, 6.494671864168985, 0.8428534013884408, 1.1138468257018497, 0.6164871166859354, 0.16000116297176906, 0.9299828346286501, 0.8875268985118184, 1.4524095271314894, 6.283177384308406, 11.750929815428597, 19.011049543108257, 22.923012154442922, 20.126412596021378, 26.914833886282786, 33.66986908231463, 33.55695390701294, 31.199075766972133, 44.30945450919015, 44.03443786076137, 43.84030171803066, 50.09550435202462, 47.66668857846941, 49.79821177891323, 47.457697187151226, 47.12888758523123, 45.97234255926949, 46.05083983285086, 43.98793009349278, 45.26817042487008, 49.48322214399065, 51.13922105516706, 57.13428313391549, 54.39468138558524, 53.409235749925884, 53.86535024642944, 50.627076285226, 54.281634194510325, 61.22685200827462, 52.85164976119995, 29.334662164960587, 1.4955012777021952, 1.4155618186507906, 29.525692462921143, 51.59946625573294, 53.18589285441807, 52.4999041557312, 49.46867956433977, 52.98568398611886, 50.60708631787981, 66.00771290915353, 21.008760860988072, 1.790897426860673, 19.981195245470317, 32.35450560706002, 61.41447421482631, 59.81478350503104, 52.86388553891863, 27.34086094583784, 24.879188878195627, 27.205221687044414, 36.17838069370815, 19.000981603349956, 47.87514843259539, 57.26526015145438, 8.36045035294124, 0.46688219585588997, 0.05104550073987671, 0.12662759449865135, 0.0268630758593125, 0.09057991273169007, 0.06417520424085003, 0.061713146711034436, 0.06749282657567944, 0.09615780306713921, 0.13633257230477674, 0.15448529752237455, 0.16263706795871258, 0.17041214289409773, 0.1773959238614355, 0.14658432719962938, 0.12121205723711423, 0.11577962445361273, 0.24215812874691828, 0.31368524634412354, 0.23879995037402424, 1.169268480369023, 67.5926456451416, 75.3657135282244, 52.81942401613508, 48.64673546382359, 149.87085097176688, 68.88803999764579, 56.11877611705235, 25.126800094332012, 48.560105323791504, 41.26439952850342, 59.20022228785923, 38.66366447721209, 2.7443165353366306, 21.18603025163923, 55.688435963221956, 66.52557604653495, 56.7490611076355, 50.09929459435599, 59.49480506352016, 16.973601477486746, 2.3244180040700093, 0.31027775204607416, 9.151885781969343, 52.36196851730347, 62.54493917737688, 63.719768387930735, 60.38079071044922, 62.79565102713448, 61.59389059884207, 63.367772647312705, 60.654980523245676, 59.2856364931379, 59.89012977055141, 59.82788780757359, 57.07667561939785, 55.96468939099993, 54.325890745435444, 58.81534767150879, 61.84032930646624, 58.8575301851545, 57.340026242392405, 58.904493059430806, 60.214138167245046, 57.89460366112845, 55.07354818071638, 55.2854334967477, 53.27306842803955, 48.26766954149519, 44.990100043160574, 34.25702313014439, 24.884221111025127, 25.21937789235796, 22.18469830921718, 21.610724994114467, 19.98464502607073, 19.599662712642125, 14.722524097987584, 7.0541664361953735, 5.88789610351835, 3.0634258006300246, 9.607357570103236, 16.12376730782645, 20.619133676801408, 21.933595623288834, 26.07378223964146, 24.310204369681223, 11.453815289906093, 2.111419890608106, 2.6282182165554593, 2.9061882836478095, 3.30660189475332, 6.643070621149881, 5.651928765433175, 4.882445301328387, 6.817866887365069, 10.52306066240583, 8.233260103634425, 11.261029703276497, 12.683322480746678, 16.106323855263845, 17.16675271306719, 17.696307931627544, 16.439140830721172, 9.976060254233223, 4.766655743122101, 4.5965977140835355, 11.563505632536751, 22.215147052492412, 28.295890842165264, 19.986521039690288, 18.136293922151836, 9.87941254888262, 1.2214113452604838, 0.42614868017179625, 0.18762596563569137, 0.9209689583097185, 0.667444010930402, 2.6772421002388, 10.376712492534093, 16.120374849864415, 25.150661945343018, 28.514938013894216, 27.421557324273245, 33.619873319353374, 41.02566984721592, 36.552860804966514, 33.44379901885986, 46.36025006430489, 48.77994632720947, 48.245466572897776, 53.94771071842739, 50.762625217437744, 53.15751641137259, 52.15817437853132, 49.93833262579781, 50.34857858930315, 48.81160231998989, 46.52659341267177, 47.458631719861714, 53.16422837121146, 54.25094052723476, 58.83100891113281, 55.99857228142874, 55.92017575672695, 53.976041998182026, 52.34866271700178, 52.25206191199166, 59.821203640529085, 52.5182717187064, 37.7446470941816, 2.9754670347486223, 0.6847352545176233, 24.60729718208313, 56.079678603581016, 60.74914945874895, 58.338263511657715, 53.61150128500802, 56.9716431753976, 52.12720625741141, 68.21953296661377, 31.687283992767334, 2.233467170170375, 19.46709976877485, 41.300842830113, 61.23375851767403, 65.96238980974469, 46.750561646052766, 35.082423959459575, 31.240125724247523, 29.184549808502197, 39.874197006225586, 26.354345287595475, 59.57559871673584, 68.00273527417863, 18.753022977284022, 0.7024211340716907, 0.6740451252886227, 0.37358713203242844, 0.1874314160751445, 0.20936716401151248, 0.2786839673561709, 0.17623043140130384, 0.2554473727941513], [0.06822460623724119, 0.01338295397415225, 0.04728245409205556, 0.052968859140362055, 0.055350523841168196, 0.04009677842259407, 0.07512329891324043, 0.20032921327011927, 0.13017656334808894, 0.10009205088551555, 0.09858988291983094, 0.023064913327938745, 0.08567900356969663, 32.34915549414498, 57.808772563934326, 36.37956230981009, 23.75012571471078, 41.50980295453753, 30.792203153882706, 38.50877870832171, 33.144859722682405, 15.74307029587882, 30.691204139164515, 20.530448607036046, 44.59620666503906, 6.790047602994101, 7.361381036894662, 46.738058362688335, 45.4457802772522, 64.59932695116315, 65.41162695203508, 50.95163706370762, 45.98513766697475, 11.571740984916687, 1.8094858122723443, 0.05944962852767535, 11.241250787462507, 58.04262113571167, 57.32700531823294, 57.52309043066842, 55.14144597734724, 59.52219486236572, 56.41443238939558, 53.39027411597115, 52.543966157095774, 55.38825988769531, 53.23897014345442, 51.03202772140503, 49.92199393681118, 52.420013768332346, 53.35798583711897, 52.445489338466096, 54.76522534234183, 54.74627065658569, 51.75442150660923, 50.00972189222063, 51.79193483080183, 53.59889725276402, 47.290290764399934, 33.47315515790667, 19.43623239653451, 13.467587368828909, 16.478121961866105, 17.10728481837681, 13.971672228404454, 14.435130970818655, 17.40776140349252, 17.961970567703247, 16.096314975193568, 11.329061252730233, 6.252661764621735, 2.1188160308769772, 1.1008306784289223, 5.118737467697688, 10.958035264696393, 11.35790583065578, 13.688001598630633, 9.546137860843114, 5.767695307731628, 3.236450276204518, 0.5983093806675502, 1.0222113771098, 0.7817285784653255, 3.959659823349544, 6.288888369287763, 8.02626631941114, 5.033228158950806, 6.021790930203029, 5.378405111176627, 7.486164603914533, 10.920543653624398, 16.59831190109253, 21.25614278657096, 24.492003985813685, 20.29284974506923, 13.655303376061575, 4.341104635170527, 0.9069548760141645, 0.4932966413242476, 3.319487763302667, 6.022110113075801, 15.378979478563581, 15.85097929409572, 14.272183554513113, 8.762294207300458, 2.3565460400921956, 2.6178745201655795, 0.47288896782057627, 0.32333216869405335, 0.17221061353172573, 0.4966800883412361, 2.4905639801706587, 5.732695060116904, 14.390321169580732, 11.449212108339582, 17.507751192365372, 16.45190988268171, 17.093311991010392, 17.231763533183507, 26.489355734416417, 25.985646077564784, 34.7163268498012, 38.419939041137695, 44.58227900096348, 45.58911466598511, 46.62680728094918, 46.173829896109446, 45.08734703063965, 42.41459390095302, 44.67320312772478, 42.78912959780012, 44.471291950770784, 46.90896667752947, 47.131152697971885, 50.00894716807774, 52.87974827630179, 49.50777012961251, 49.229932512555806, 51.013792174203054, 51.508813108716694, 54.77014814104353, 45.96441813877651, 6.793910367148263, 1.1132879299776894, 23.52269206728254, 46.56960276194981, 44.78757047653198, 43.41660751615252, 52.03053249631609, 53.74668891089303, 47.32826961789812, 53.2156137738909, 32.28864363261631, 0.4690611075077738, 6.560073086193629, 29.332740988050187, 31.065340314592632, 57.66625458853585, 58.75459262302944, 33.43979685647147, 34.21009152276175, 17.16109687941415, 22.693179641451152, 25.713721377508982, 27.771588461739675, 43.20108829225813, 49.71912043435233, 4.61795083114079, 0.2156370718564306, 0.11879160068929195, 0.16588560864329338, 0.03794096749542015, 0.11410995333322457, 0.018278444185853004, 0.1592989470809698, 0.11915154994598456, 0.04329373348238213, 0.018719581853864447, 0.05307659353794796, 0.01690419533822153, 0.0725479463913611, 0.04765538711633001, 0.1290839591196605, 0.015802676855985607, 0.15857619872050627, 0.10427202337554523, 0.024218353309801648, 0.05566633100222264, 0.156387665442058, 33.304074219294954, 68.91965430123466, 36.89653260367257, 26.985835790634155, 52.74534232275826, 33.780182157244, 32.20455305916922, 32.679861954280305, 26.12756998198373, 31.657740252358572, 35.500893115997314, 53.69730111530849, 9.83513081073761, 6.493632674217224, 49.19838421685355, 46.76818227767944, 66.00707367488316, 70.69294575282505, 54.395313671657014, 53.49890225274222, 18.106341975075857, 4.050418496131897, 0.06387643848678895, 9.557355727468218, 58.52899851117815, 60.71748651776995, 61.47579901559012, 57.219141483306885, 62.19090761457171, 57.72918789727347, 54.77941008976528, 54.20055219105312, 58.30928952353341, 54.23006813866751, 51.60671670096261, 52.08667394093105, 55.752741541181294, 54.95092289788382, 54.128103324345176, 55.699122292654856, 57.887697151729036, 53.20025478090559, 54.019697529929026, 53.98680823189871, 53.88050774165562, 49.108411993299214, 41.31881781986782, 26.405543088912964, 16.609382118497575, 19.48936700820923, 20.389005865369523, 18.220867395401, 18.869419200079783, 20.43270308630807, 19.402439832687378, 15.485726390566144, 9.880396587508065, 5.599542822156634, 2.7659302098410468, 2.383683532476425, 8.083156432424273, 11.51504281588963, 11.931157401629857, 15.615489210401263, 17.806799922670635, 12.710643666131155, 6.150115472929818, 2.3052785396575928, 1.529709973505565, 2.4273722852979387, 1.964639846767698, 1.4208299645355769, 2.623374887875148, 4.138892080102648, 6.070198595523834, 6.862273693084717, 6.309784642287663, 8.295206768172127, 10.546601159232003, 14.561467460223607, 11.188252534185137, 15.691026551382881, 10.280393958091736, 6.3517743434224805, 5.23298669712884, 3.710340653147016, 7.894015175955636, 12.715230345726013, 21.06881414140974, 18.591685806001934, 11.265215124402728, 9.129213809967041, 4.55283795935767, 2.4123919691358293, 0.2519301458128861, 2.0042888735021864, 0.9449048510619572, 3.170932237591062, 8.516269786017281, 10.169620565005712, 18.910359723227366, 16.554437501089915, 21.712877409798757, 21.317792415618896, 21.503116505486624, 24.205955335072108, 30.123074259076798, 32.71558264323643, 37.47343805858067, 41.38207074574062, 48.20654623849051, 48.47445835386004, 48.23905338559832, 49.76390157427107, 47.93911007472447, 45.89771890640259, 45.85956982203892, 46.98832205363682, 47.49467202595302, 49.7850866317749, 49.00976146970476, 52.63557120731899, 54.721128599984304, 52.21442699432373, 50.153323786599294, 51.650198527744834, 51.73708227702549, 54.38927568708147, 40.063486780439106, 6.652458940233503, 2.1434966836656844, 33.03583206449236, 50.77879367555891, 52.66116489682879, 47.635338306427, 56.318780013493125, 57.27215623855591, 52.61861412865775, 56.437212058476035, 28.13395438875471, 1.092549511364528, 15.13208566393171, 26.67359243120466, 33.77187211172921, 56.96236733027867, 63.354918479919434, 39.63581473486764, 30.070684841700963, 23.734252555029734, 27.138340064457484, 24.04353424480983, 27.63565390450614, 52.41958992821829, 60.472506931849885, 9.199681571551732, 0.43443926530224936, 0.18493668708418096, 0.1431788277945348, 0.05734995619526931, 0.1046353110245296, 0.030710857960262468, 0.0903067888159837, 0.08701684392456498, 0.11558347355042185, 0.14752232043870858, 0.1296838383589472, 0.12853872909077577, 0.15230904572776385, 0.2850809783807823, 0.2827167452446052, 0.4506995699235371, 0.3492463438638619, 0.23652550099151476, 0.2870977744460106, 0.2648907074970858, 0.20391088750745567, 50.395531041281565, 78.60321971348354, 49.72209773744856, 33.284789494105745, 57.12146718161446, 39.50922203063965, 53.821805885859895, 44.15822001865932, 24.005815948758805, 44.48152664729527, 34.76246983664376, 57.65842049462454, 11.640090414455958, 12.189801488603864, 52.93771709714617, 51.39645726340157, 66.15873200552804, 70.93415941510881, 62.302537373134065, 60.853844915117534, 13.55511122090476, 2.732216030359268, 0.15970461602721894, 15.785492522375923, 64.25446701049805, 61.241769790649414, 63.53438350132534, 60.694800649370464, 65.15138912200928, 59.61457116263253, 56.293690068381174, 56.919642857142854, 61.954446520124165, 57.57355867113386, 55.716305187770296, 53.26121827534267, 58.85767609732491, 58.17967782701765, 56.69657441547939, 58.63285323551723, 61.020066670009065, 59.22144903455462, 56.84417152404785, 57.01969691685268, 58.99431242261614, 51.88547842843192, 48.31725883483887, 36.23894814082554, 22.640199627195084, 23.519343035561697, 23.907651799065725, 21.57660412788391, 24.514662061418804, 25.81839598928179, 26.011753933770315, 18.168735061373027, 12.970293504851204, 7.018460512161255, 4.674497442586081, 6.032127678394318, 17.359066690717423, 22.41375262396676, 17.596418891634258, 26.295516627175466, 24.334806203842163, 13.106709224837166, 4.668762138911656, 2.9052077191216603, 5.185136190482548, 5.393582582473755, 9.323021650314331, 14.393737077713013, 14.054196851594106, 13.414132271494184, 10.924267888069153, 11.335856590952192, 12.000758375440325, 15.167306082589285, 20.368175165993826, 26.905761275972637, 26.451272657939366, 26.922601972307476, 21.356662375586374, 12.09239034993308, 8.624995197568621, 3.437048460756029, 7.116219495024, 12.474502188818795, 26.96824468885149, 26.238579613821848, 20.178065504346574, 20.10353738921029, 13.060711281640188, 6.063520073890686, 0.5279401423675674, 1.131580039858818, 0.8957263699599675, 2.7763857288019995, 12.346877677100045, 15.366846186774117, 22.886680024010793, 23.351047243390763, 28.693176678248815, 26.18207859992981, 28.575680903026036, 31.22363417489188, 35.99478496823992, 37.85198981421334, 41.885488578251426, 43.01483835492815, 51.269263539995464, 52.892668451581685, 53.10077394757952, 51.96602889469692, 50.58234378269741, 47.75416987282889, 50.29195424488613, 47.73760536738804, 49.934521538870676, 50.99573728016445, 51.26664754322597, 54.099591391427175, 57.39057786124093, 53.858714716775076, 51.07250792639596, 52.47941044398716, 50.205949442727224, 55.07912411008562, 49.32899297986712, 11.857125214168004, 1.3654647639819553, 30.531635284423828, 53.53348691122872, 54.16287211009434, 50.12474931989397, 61.878454072134836, 60.60872636522566, 57.412356989724294, 58.32384599958147, 41.28945820672171, 1.5519386721508843, 11.999216743877955, 36.09648922511509, 41.22119562966483, 59.716716630118235, 68.49539034707206, 35.303011894226074, 49.151817389896934, 26.473008360181534, 29.941622052873882, 33.900472845349995, 42.307893889290945, 61.1888245173863, 70.48748752049038, 14.516245109694344, 0.7494398653507233, 0.5459015071392059, 0.25535102082150324, 0.3177362632538591, 0.1650542268263442, 0.13817304426005908, 0.26748569682240486, 0.3130657710134983], [0.02335455278599901, 0.10710834725094692, 0.061448205927652974, 0.04495773883536458, 0.0781604013006602, 0.021225571133462445, 0.11284063144453935, 0.04215178958007267, 0.06547769970659699, 0.08271556972925152, 0.026266307703086307, 0.12513128907552787, 0.14815635713083403, 13.5454341173172, 65.14366272517613, 44.405770438058035, 33.376182624271934, 30.53155885423933, 40.09059517724173, 31.3918639591762, 43.56113004684448, 26.892458949770244, 27.7792557988848, 22.55141380855015, 27.322201558521815, 19.92814748627799, 1.8027512707880564, 23.81299648966108, 63.8715100969587, 51.104559966496055, 56.24972186769758, 39.33049699238369, 58.058643681662424, 64.97370283944267, 37.71461003167288, 17.35414562906538, 1.8856874661786216, 18.865189484187535, 52.690243107931956, 56.13007388796125, 58.29547650473458, 57.017219884055, 57.778346402304514, 53.524753025599885, 54.461488315037315, 51.97433199201311, 53.59810863222395, 52.29721825463431, 51.403037207467214, 51.78724479675293, 50.978780201503206, 53.49966655458723, 54.03996889931815, 52.530153138296946, 53.46111447470528, 49.75075905663626, 50.23480531147548, 44.791815825871055, 27.67063113621303, 14.8912159374782, 11.245593411581856, 9.929983275277273, 15.405170713152204, 18.80310732977731, 18.235005242483957, 22.874734333583287, 24.451471669333323, 15.872431857245308, 12.538382189614431, 7.292705910546439, 4.78285242830004, 1.0879654373441423, 2.6761690378189087, 6.993946833269937, 14.068182706832886, 12.973686831338064, 8.931383831160408, 4.672759090151105, 1.6219360189778464, 0.41562761472804205, 2.032674001795905, 0.9198193571397236, 3.062814142022814, 8.053639616285052, 11.835856778281075, 15.918765919549124, 8.056033270699636, 10.312346117837087, 11.788013219833374, 9.50177013874054, 17.303067684173584, 17.004421949386597, 23.188176257269724, 26.22698654447283, 24.74705845969064, 20.85901849610465, 7.216572327273233, 1.5757639365536826, 0.7495238951274327, 0.3750469594129494, 2.0833912917545865, 6.370607435703278, 11.371321065085274, 16.113456181117467, 16.264207771846227, 4.890503908906664, 2.015298077038356, 1.616126999258995, 1.1367594876459666, 2.576678433588573, 3.2709087814603532, 6.7082599231175015, 7.044534061636243, 11.796831352370125, 19.184179544448853, 13.593139580317906, 17.614491156169347, 17.27162708554949, 19.650686808994838, 18.160291263035365, 25.97982348714556, 34.97544949395316, 39.912544114249094, 43.162369455610005, 47.13346297400338, 47.27853093828474, 46.6692225592477, 46.699082442692344, 44.676086630140034, 42.892515318734304, 43.99888392857143, 42.97665105547224, 46.01059586661202, 50.29209668295724, 51.36282450812203, 50.70002889633179, 54.94604526247297, 49.730574539729524, 47.41657427379063, 45.65149906703404, 44.12027243205479, 17.084941148757935, 1.8115083894559314, 18.522089174815587, 52.78654514040266, 38.61985261099679, 41.15151909419468, 49.091510500226704, 49.258691106523784, 44.21998603003365, 47.323906149183, 33.68507521493094, 2.644793144294194, 6.389371914522989, 59.75438976287842, 36.690330914088655, 33.94665057318551, 63.933675629752024, 48.74396160670689, 25.014520679201397, 30.651446546827042, 12.043347358703613, 33.06328787122454, 32.075302668980186, 29.27283361979893, 47.99728039332798, 54.33432238442557, 2.7033610301358357, 0.33336968294211794, 0.03683312337047287, 0.04640643145622952, 0.012591372476890683, 0.06813397431480032, 0.03898229143981423, 0.03789661505392619, 0.0163678405473807, 0.05130075882854206, 0.12984250698770794, 0.01735084779959704, 0.07962586730718613, 0.05922147112765482, 0.03422954718449286, 0.12263964063354901, 0.02161323854566685, 0.1023120546181287, 0.14758341573178768, 0.0469264437311462, 0.16577493958175182, 0.1778909151575395, 16.201482909066335, 78.48148727416992, 49.74160133089338, 31.462065083639963, 38.49007068361555, 38.751472336905344, 34.73182480675833, 30.496449606759207, 34.20329965863909, 32.77293307440621, 28.827579157693044, 39.19478130340576, 23.250854219709122, 2.0890006593295505, 19.058253867285593, 66.51671709333147, 56.824640137808665, 55.042791979653494, 45.929427010672434, 60.723837171282085, 63.44293825966971, 43.94632428033011, 25.64992128099714, 3.1858856294836317, 16.62159357752119, 56.33784934452602, 58.583409854343955, 63.28929969242641, 57.83486999784197, 56.5025702885219, 55.44584308351789, 56.34764630453927, 54.54150377001081, 55.02873229980469, 56.45639256068638, 53.877794470105854, 53.75804574148995, 53.44738483428955, 56.56949533735003, 55.93941879272461, 55.007213728768484, 53.45394393375942, 52.58599581037249, 52.646267959049766, 48.31465326036726, 35.47174889700753, 20.014364208493912, 12.136250853538513, 13.964467814990453, 18.51037277494158, 23.525092669895717, 20.701223169054302, 27.323516505105154, 27.100310836519512, 16.303536312920706, 12.144362875393458, 6.455849238804408, 4.9494255014828274, 3.1232956051826477, 7.033796489238739, 11.113302315984454, 11.189858436584473, 14.741438831601824, 16.78774585042681, 12.658527834074837, 6.31777811050415, 2.3672325866562978, 3.0392095914908817, 1.4077355414628983, 2.5601558344704762, 2.7431192738669257, 5.394887541021619, 6.800059957163675, 6.967289635113307, 11.07867249420711, 10.080616746629987, 9.239834342684064, 16.55649937902178, 24.448070526123047, 26.622445004326956, 30.250063010624476, 24.502129248210363, 19.458503110068186, 7.661677837371826, 5.414446720055171, 4.199124710900443, 2.2349636384419034, 6.305930997644152, 14.416925821985517, 19.62855158533369, 18.233659029006958, 14.371548874037606, 11.33515134879521, 7.961852175848825, 0.12581678586346762, 2.0497216241700307, 3.7619127886635915, 4.8775555065699985, 11.0830602816173, 12.860196692602974, 15.204246180398123, 24.296829087393625, 17.566050052642822, 23.571874891008648, 20.54743868964059, 23.03897758892604, 21.590081896100724, 31.63687481198992, 38.66943843024117, 43.332072257995605, 44.67751448495047, 49.68231235231672, 48.426289967128206, 50.250025340488975, 47.56059306008475, 46.40612554550171, 44.922271728515625, 46.70017678397042, 45.09600101198469, 50.892136165073936, 53.565243652888704, 54.30038390840803, 53.09781401497977, 57.01046623502459, 49.10838072640555, 50.06668669836861, 44.68203428813389, 41.66428572790963, 18.25580988611494, 2.887871095112392, 24.649363313402446, 57.23038714272635, 42.14382607596261, 45.62498821531023, 55.52388177599226, 54.01480252402169, 47.050657817295615, 52.7606908934457, 28.554681709834508, 3.078430652618408, 11.67980284350259, 65.68319729396275, 39.61784321921212, 36.76561117172241, 62.25205176217215, 55.78072541100638, 26.09138376372201, 34.616679259708945, 17.039503404072352, 33.247832025800435, 33.602784224918906, 29.371088096073695, 58.85970497131348, 57.975501537323, 3.8111433812550137, 0.12854873069695064, 0.09977438793118511, 0.1080449562785881, 0.12611808255314827, 0.088994732791824, 0.016682256711646914, 0.029187421314418316, 0.020217732892238667, 0.1078474008079086, 0.4321257323026657, 0.13470383041671344, 0.3146748760981219, 0.14408463133232935, 0.17771190404891968, 0.26913437406931606, 0.09133438938962561, 0.18721134002719605, 0.3109465704432556, 0.1380463753427778, 0.37397519978029387, 0.3399832009204796, 24.592297758374894, 91.93705599648612, 59.602342333112446, 45.25181783948626, 39.93365274156843, 47.753145013536724, 44.07778072357178, 57.96455465044294, 35.29371173041207, 44.165776184626985, 35.7069662639073, 43.128840923309326, 26.565078939710343, 4.115571320056915, 30.920036111559185, 73.17131955283028, 58.299416133335654, 59.39996215275356, 49.66115856170654, 66.20674405779157, 71.90676130567277, 45.58823224476406, 21.177878277642385, 3.0015518750463213, 26.00198824065072, 64.92065334320068, 61.39708982195173, 65.31845160893032, 61.33970464978899, 57.85086127689907, 57.95875290461949, 58.6537812096732, 56.4649110521589, 58.03619752611433, 58.68489524296352, 57.19827951703753, 57.6689088003976, 55.600027084350586, 61.38288075583321, 61.1394019808088, 59.66161741529192, 58.730913162231445, 56.62690135410854, 57.01513542447771, 54.67828948157174, 41.411993162972585, 26.175787006105693, 15.854409967150007, 18.078323364257812, 22.04374541555132, 26.119503123419626, 25.094011545181274, 32.80296318871634, 31.060775348118373, 20.351214613233292, 12.719011902809143, 8.106470244271414, 5.471417171614511, 3.816282876900264, 12.52927918093545, 19.570664405822754, 20.38529031617301, 21.943019117627824, 21.415056773594447, 12.229067495891027, 4.343378433159419, 1.192326077393123, 4.917583210127694, 6.542192331382206, 11.427599736622401, 15.50069454738072, 20.86633321217128, 23.478315659931727, 15.267462628228323, 19.45337881360735, 17.774812153407506, 17.274889264787944, 25.099799394607544, 28.965424469539098, 31.613028594425746, 31.997125012534006, 30.202026639665874, 27.560832227979386, 18.5540908404759, 7.613759585789271, 4.962342636925833, 1.7620571915592467, 4.86452806847436, 13.463289039475576, 24.307550157819474, 25.04717721257891, 21.000132935387747, 21.20766694205148, 12.71241111414773, 1.4367746689489909, 2.3369488630975996, 5.081481226852961, 6.609982865197318, 13.000537276268005, 18.530213356018066, 21.506712198257446, 28.15573525428772, 23.927999598639353, 29.38516514641898, 26.074617760522024, 25.18243953159877, 26.053820065089635, 34.759593282427105, 42.3969315801348, 47.06492246900286, 47.94219854899815, 51.73993798664638, 50.55191762106759, 52.34268726621355, 51.08266271863665, 50.167386940547395, 48.589381558554514, 49.941775458199636, 48.58450044904436, 53.003450529915945, 55.373272623334614, 55.638725076402935, 55.657231603349956, 56.63634743009295, 50.63517788478306, 47.29018306732178, 47.19874824796404, 46.92066396985735, 23.92434310913086, 3.063490071466991, 22.416907106127056, 60.00131484440395, 47.56202091489519, 50.59421477999006, 58.08753776550293, 58.46214294433594, 51.297261306217735, 54.36860827037266, 38.49440288543701, 5.6047874093055725, 9.440247314316885, 69.52614865984235, 44.79625225067139, 40.79844985689436, 66.91379969460624, 59.12168679918562, 28.155981915337698, 50.965172154562815, 16.206186839512416, 45.91659368787493, 43.12192746571132, 44.508381434849326, 63.03219549996512, 76.05539172036308, 7.685730763844081, 0.5687680287020547, 0.31254468326057705, 0.2017481792718172, 0.25667706823774744, 0.23432900171194757, 0.10698439247374024, 0.15648629729236874, 0.13772237487137318], [0.08925678301602602, 0.11042924012456622, 0.03209484548174909, 0.04258844722062349, 0.03856960983414735, 0.04772264011470335, 0.04296085777293358, 0.039660154708794186, 0.07432952150702477, 0.0567247336730361, 0.04163172980770469, 0.07865865635020391, 0.12147554595555578, 3.247351348400116, 47.49350472858974, 46.243954590388704, 32.26865019117083, 30.867980207715714, 54.79291043962751, 28.85467713219779, 41.51821027483259, 31.552301338740758, 26.520513193947927, 15.64509722164699, 19.6927581514631, 35.41796636581421, 11.179941620145526, 0.0756627478237663, 15.002482652664185, 56.573077133723665, 58.16215099607195, 53.94694641658238, 45.41236639022827, 54.257899148123606, 57.31439086369106, 56.12174299785069, 27.573069742747716, 2.0954993963241577, 16.167810201644897, 40.770674433027, 54.97492544991629, 53.38338845116751, 48.50794519696917, 49.14074196134295, 52.209886346544536, 53.74939523424421, 52.55648333685738, 50.2786727632795, 50.86519799913679, 52.18230199813843, 53.37569332122803, 52.530882699149, 51.5433908190046, 55.26366826466152, 50.60345241001674, 43.30262926646641, 34.73518426077706, 22.059359754834855, 16.945662770952495, 14.82398169381278, 10.576930914606367, 13.205364959580557, 20.840159348079137, 19.06949952670506, 16.29637793132237, 22.804503679275513, 16.595819234848022, 14.180438671793256, 7.4615097897393365, 4.6281351532254895, 0.911159947514534, 2.147825845650264, 7.363524556159973, 12.996414388929095, 13.384677989142281, 8.830623660768781, 4.320428967475891, 1.2782902760165078, 0.6768975779414177, 0.17596576203192982, 1.1792925596237183, 2.199938637869699, 2.8995820667062486, 12.42684188910893, 11.24846909727369, 8.454613208770752, 13.853193283081055, 20.452291795185634, 12.884946175983973, 16.90454159464155, 21.339597599846975, 25.213327748434885, 30.17734316417149, 31.77819769723075, 33.04534762246268, 22.097658225468226, 7.0848705257688245, 0.6839938057320458, 2.100273460149765, 0.18942020221480302, 0.618510508111545, 1.0788686169045312, 4.342288000243051, 10.870908328465053, 17.642561878476823, 14.743945394243513, 4.581588736602238, 1.536048250538962, 2.3548847692353383, 4.334195954459054, 9.609270061765399, 9.098805018833705, 14.597341878073555, 8.429724761417933, 10.86810907295772, 21.67525291442871, 18.385570968900407, 17.56181686265128, 21.642193385532924, 23.973810808999197, 29.133763687951223, 35.80268464769636, 42.730917590005056, 44.26005629130772, 48.28897966657366, 47.300445556640625, 49.965569564274375, 45.04605736051287, 44.94609362738473, 41.98960386003767, 47.00988926206316, 46.41626991544451, 49.38640941892351, 45.78254556655884, 52.504271098545615, 52.13372366768973, 51.89531012943813, 44.06810188293457, 54.152123246874126, 39.99061407361712, 37.04214947564261, 14.47860584940229, 10.11159268447331, 53.375349385397776, 43.284626483917236, 50.200950213841026, 37.51583249228341, 35.391921043395996, 43.650254590170725, 47.11363976342337, 47.18559183393206, 6.463700268949781, 1.7866289530481612, 58.09102576119559, 55.31303868974958, 16.73994745526995, 38.32102101189749, 53.29822785513741, 35.11584826878139, 31.11697585242135, 20.15528757231576, 17.140830721173966, 39.489777496882844, 20.56649759837559, 33.08703681400844, 54.29424517495291, 36.493189675467356, 0.5057131807718958, 0.04543504411620753, 0.06653403623827867, 0.0569905090544905, 0.0792459894769958, 0.12379130455000059, 0.030098673488412584, 0.02208186705995883, 0.08681200777313539, 0.046935251115688255, 0.07473343304757561, 0.07365536303924662, 0.016107374702447226, 0.018120352311858108, 0.14039121594812187, 0.14262867160141468, 0.07619963865727186, 0.09697535634040833, 0.051192274649760554, 0.06962397614760057, 0.07081369230789797, 0.12217226571270398, 4.680315690381186, 53.658182757241384, 57.365394115448, 26.664457287107194, 36.622947284153526, 62.44090379987444, 33.393507957458496, 32.96482842309134, 32.14077207020351, 37.08188622338431, 22.607365914753505, 32.40890652792794, 45.81436136790684, 18.835404293877737, 0.3026030052985464, 11.564299464225769, 55.59592417308262, 60.806923730032786, 61.65877982548305, 51.72590609959194, 59.7268123626709, 59.32396970476423, 61.358763558524, 35.84596150262015, 3.7465194889477322, 14.9050897530147, 42.552682399749756, 54.156066349574495, 53.0665853364127, 49.74483571733747, 50.20603282111031, 52.19258533205305, 55.97289868763515, 57.25619970049177, 53.84076057161604, 54.51193571090698, 54.79121855327061, 56.473314898354666, 53.72934620720999, 56.08896834509713, 55.03235925946917, 53.373306615012034, 49.38225439616612, 42.40712111336844, 28.364924669265747, 21.76266472680228, 18.067875010626658, 14.02797087601253, 17.276551621300833, 22.156420878001622, 20.773946489606583, 21.656332969665527, 26.861607210976736, 19.04363659449986, 15.152424778257098, 9.580197930335999, 4.1042040671621045, 2.859219763960157, 4.282001955168588, 8.429655279432025, 10.445302503449575, 17.717842136110576, 16.97628000804356, 10.564251320702688, 5.670340188911982, 1.3102448242051261, 1.5519778643335616, 2.852037932191576, 2.9951988330909183, 0.3699639450226511, 8.481354219572884, 15.590916906084333, 17.03812418665205, 12.052067347935267, 18.015805210386002, 13.387661371912275, 15.55976813180106, 22.79670606340681, 26.448965856007167, 31.692717484065465, 31.311758177621023, 32.14916549410139, 27.98068928718567, 11.395299298422676, 2.2667103920664107, 1.5594569487231118, 1.2913092459951128, 1.4423828423023224, 6.610263832977839, 12.73898102555956, 17.7725088255746, 19.258599962506974, 13.06760389464242, 8.921828321048192, 3.3123975609030043, 3.3640176824160983, 7.858689665794373, 10.528169325419835, 10.387644614492144, 15.395783696855817, 14.33614867074149, 12.276984878948756, 25.78078886440822, 22.547488076346262, 20.743848630360194, 23.113528285707744, 26.87810049738203, 32.53294924327305, 38.71339620862688, 44.93659891401018, 47.46076134272984, 50.710367815835134, 49.35550730569022, 51.513735907418386, 47.5446469443185, 47.594951902117046, 44.69493014471871, 49.45138897214617, 48.715119634355815, 51.44402463095528, 48.830602169036865, 57.5402455329895, 52.978172983442036, 52.89248085021973, 45.84818172454834, 55.359681946890696, 38.15865898132324, 41.785253865378245, 17.092672756740026, 15.743714741298131, 56.75634281975882, 47.90520633969988, 53.853465352739605, 43.544204235076904, 42.67853512082781, 48.37617608479091, 49.87597949164254, 47.41677229745047, 3.948351630142757, 4.419623621872493, 61.867948395865305, 66.5876373563494, 22.549640280859812, 36.071392331804546, 55.90044634682791, 42.570122378213064, 29.23798492976597, 28.358871051243373, 19.371685368674143, 39.08589260918753, 23.561815636498586, 36.582491397857666, 64.50154495239258, 39.26564598083496, 0.45199695602059364, 0.12973723906491483, 0.09382871125957795, 0.03751881014821785, 0.0599252815757479, 0.015428695495107343, 0.03042572397472603, 0.024365673440375497, 0.048000700372670374, 0.24023863460336412, 0.21641088676239761, 0.10741648357361555, 0.1731833613344601, 0.07888050337455102, 0.15489806394491876, 0.1542694555329425, 0.21683532398726257, 0.1605139183146613, 0.21346540695854596, 0.21353469895465033, 0.13440877624920436, 0.4967901738626616, 8.698284796306066, 78.29592173440116, 66.74762657710484, 45.214255877903526, 40.81734200886318, 68.24187837328229, 40.97978394372122, 60.540842464991975, 39.080966336386545, 44.55484751292637, 32.663047313690186, 35.46550246647426, 46.87339537484305, 18.875163623264857, 1.616968599813325, 21.220246655600413, 63.562336104256765, 69.32852799551827, 64.40240805489677, 55.7501220703125, 64.0913997377668, 65.48037937709263, 66.86806665148053, 33.70581211362566, 3.611939396177019, 22.731017793927872, 53.05878250939505, 59.88794803619385, 55.77052545547485, 51.64186416353498, 49.72432116099766, 54.519071510859895, 58.869786807468955, 60.04036372048514, 56.43211555480957, 57.788403919764924, 59.17473629542759, 60.31082929883684, 58.04379538127354, 59.30555003029959, 61.04014696393694, 57.51343590872628, 53.730635098048616, 46.75995213644845, 35.2390433038984, 24.45247220993042, 22.553413152694702, 17.81634153638567, 21.17589977809361, 26.78081876891, 26.971602405820573, 26.654481410980225, 33.17567498343331, 22.08759375980922, 18.87576116834368, 9.160874145371572, 6.006973462445395, 3.737875061375754, 7.136186012199946, 14.542513642992292, 16.67463959966387, 24.809244837079728, 21.5127432346344, 11.251688718795776, 3.466273235423224, 0.8744857811502048, 4.866222560405731, 6.409797881330762, 14.008066892623901, 17.534473964146205, 21.13866785594395, 25.166479519435338, 20.74500550542559, 20.086370127541677, 28.298211540494645, 20.69804436819894, 25.946065664291382, 36.91819708687918, 38.41500929423741, 40.41269629342215, 38.347778524671284, 40.15748201097761, 35.66848366601126, 19.23287078312465, 8.756807735988072, 5.448008690561567, 2.96317588857242, 0.8186105393937656, 6.5505688190460205, 14.496634687696185, 22.473812852587017, 22.91957974433899, 22.609332254954747, 14.00919771194458, 7.19677734375, 6.666714906692505, 8.17088438783373, 14.46571433544159, 13.03080449785505, 19.46845814159938, 21.21116188594273, 19.982650893075125, 30.917152609143937, 26.76581587110247, 24.39435747691563, 29.356052194322857, 27.772059202194214, 34.83286551066807, 40.66275153841291, 48.87593221664429, 50.622448784964426, 55.80143799100603, 52.38744756153652, 54.36422743116106, 51.80970137459891, 50.87381029129028, 46.523730754852295, 53.10072531018938, 52.66057429994856, 54.95065539223807, 51.43624612263271, 59.01031412397112, 57.47242416654314, 56.35809292112078, 45.27807855606079, 55.72745704650879, 44.780198437826975, 45.60046802248274, 20.383718286241802, 12.899189114570618, 61.296368735177175, 48.93853201184954, 58.718031202043804, 45.038789544786724, 44.046017033713206, 50.81788771493094, 55.16650118146624, 54.70555421284267, 9.356849823679243, 3.4337122397763387, 69.22955785478864, 64.58101844787598, 25.207456520625524, 40.88095971516201, 62.53478785923549, 40.81896093913487, 42.78809084211077, 33.39461966923305, 22.070919820240565, 55.56416743142264, 28.208503348486765, 48.852843352726524, 67.7317555291312, 57.10029254640852, 1.2264829874038696, 0.33938788143651827, 0.1869185385959489, 0.08840221565748964, 0.2467963227203914, 0.18484280497900077, 0.10130972947393145, 0.08356232714972325, 0.2551419234701565], [0.04949228658473917, 0.045419861895165274, 0.21114723277943476, 0.007829407778834658, 0.07974779326468706, 0.1487246166382517, 0.034452310231115134, 0.08752375029559646, 0.03137562211070742, 0.13654206320643425, 0.022683257735999565, 0.10693256596901587, 0.029329296201467514, 0.6157665124961308, 15.226419619151525, 49.82394790649414, 35.145280838012695, 34.59397602081299, 40.46634333474295, 16.387282950537546, 36.13474948065621, 37.93155016217913, 15.10173419543675, 10.455812522343226, 13.229912945202418, 21.47159947667803, 51.51108864375523, 11.8126072372709, 0.5810160200510706, 15.873434134892054, 49.853974546704976, 49.95009592601231, 67.37855080195835, 53.35345908573696, 56.517349106924875, 55.29716900416783, 52.42579466956002, 23.056460993630544, 1.6934631637164523, 9.277330296380178, 29.735194546835764, 33.840402194431846, 48.02575411115374, 49.83818823950631, 46.51885311944144, 44.36345590863909, 49.89280455453055, 51.593139920915874, 52.09976087297712, 49.936473982674734, 50.66634055546352, 52.301863125392366, 51.26344789777483, 44.46864468710763, 35.84468650817871, 25.25358039992196, 17.564616986683436, 19.254203489848546, 20.03955316543579, 18.493035282407487, 16.991741486958094, 12.658777100699288, 11.966303995677404, 13.023765972682408, 17.511696032115392, 18.890173469270977, 12.11897155216762, 7.604881525039673, 1.9407421691077096, 1.6244216284581592, 0.19122472538479737, 5.616497295243399, 13.17309318270002, 14.41888347693852, 8.46990532534463, 3.9148882372038702, 1.53266176368509, 0.3609037383326462, 0.9255036349807466, 2.257040019546236, 1.3508591077157428, 0.5368374735116959, 4.3732496074267795, 8.82773494720459, 14.709157500948224, 16.17608724321638, 21.522915397371563, 21.62456406865801, 14.35297633920397, 23.417682204927715, 25.36213731765747, 20.774679524557932, 28.999844108309063, 31.776071548461914, 30.383742877415248, 17.43477773666382, 2.6325779940400804, 1.0666299079145705, 0.38393986650875633, 1.4195013386862618, 0.49922361757074085, 0.4397664980164596, 3.045881816319057, 8.663661922727313, 13.596611942563738, 16.782251562391007, 9.127574035099574, 2.4589511965002333, 5.821473062038422, 7.127937197685242, 10.898908700261797, 10.107374259403773, 16.094739471163066, 21.260824135371617, 4.67447920356478, 4.973419368267059, 20.66431781223842, 22.45435789653233, 23.819051844733103, 27.751596757343837, 33.239643573760986, 42.37124408994402, 48.42888164520264, 47.303874492645264, 45.52971799033028, 44.766545227595735, 44.879592418670654, 45.73089613233294, 42.94456080027989, 44.425260135105674, 43.12370620455061, 47.7776825768607, 48.581571783338276, 53.67713744299752, 51.15816879272461, 52.38781929016113, 48.34812273297991, 48.73157296861921, 40.39607967649187, 32.98237957273211, 33.710446562085835, 10.509614161082677, 36.88580458504813, 53.93592309951782, 42.64266504560198, 53.04041147232056, 45.18538958685738, 48.94648769923619, 54.3253036226545, 48.47627878189087, 20.748021023614065, 0.5164180749229023, 20.346180643354142, 48.96213851656233, 16.41132892881121, 15.520833900996617, 48.5963054384504, 45.46265050343105, 26.265161684581212, 29.65497064590454, 13.936570797647748, 26.315485749925884, 29.892147404806956, 25.899069786071777, 41.0432140486581, 58.10457822254726, 18.672227587018693, 0.3711615050477641, 0.1055092912699495, 0.05657636520585843, 0.07703110189842326, 0.1580130960792303, 0.10283998200403792, 0.12506293345774921, 0.03380286740139127, 0.061692437822265286, 0.09161132667213678, 0.03955847962892481, 0.13705110017742428, 0.0827048353052565, 0.040149805934301445, 0.08936562003301722, 0.03446425923279353, 0.05333453183993697, 0.055874190027160306, 0.11867971026471683, 0.06904216629586049, 0.11422145020748888, 0.04502079509464758, 0.6011135216270174, 21.820742981774465, 68.0793878010341, 36.77792337962559, 37.46116753986904, 45.95086567742484, 16.68292706353324, 33.21417842592512, 33.36699710573469, 26.977379832948955, 17.296748297555105, 17.84571852002825, 33.12568269457136, 62.15553433554513, 15.617422546659197, 0.07545156058456216, 15.527288777487618, 55.460191113608225, 55.207693576812744, 73.48027120317731, 57.90745088032314, 64.91980566297258, 58.697415896824424, 58.98944173540388, 30.2370559828622, 3.611970445939473, 8.747433747564044, 32.24300439017159, 34.52517148426601, 47.38345568520682, 50.90572336741856, 47.136944021497456, 46.29676089968, 51.77513408660889, 53.87447670527867, 54.50413288388933, 51.97592660358974, 54.07509551729475, 55.041805335453574, 55.44056592668806, 48.61153588976179, 43.778831005096436, 30.09038645880563, 23.441293920789445, 23.78825569152832, 23.43908613068717, 21.399725573403494, 20.976083483014786, 15.124501705169678, 15.104247706277029, 17.49286641393389, 25.26524121420724, 21.393197740827286, 17.45383664539882, 10.352839350700378, 5.335774004459381, 3.2952209625925337, 2.804417367492403, 6.657198480197361, 10.130757553236824, 16.537258080073766, 19.74327676636832, 11.347685899053301, 3.316254028252193, 0.7836165885840143, 0.6485320457390377, 0.0986407594755292, 0.4702315532735416, 2.4523897085871016, 6.94945056949343, 13.696856209209987, 21.352479560034617, 17.32539050919669, 21.004077775137766, 26.36671655518668, 16.544753449303762, 21.072428941726685, 26.636780875069753, 33.97684744426182, 38.921974182128906, 41.212062222617014, 35.70475326265608, 30.790045738220215, 12.104831099510193, 2.460654373679842, 1.263779940349715, 1.7416108144181115, 0.4334302023053169, 0.9279911986419133, 7.168566354683467, 16.771181344985962, 20.47267086165292, 15.565550770078387, 10.12468569619315, 8.400341698101588, 6.424407337393079, 10.143953919410706, 12.909307428768702, 17.451863356998988, 19.806441102709087, 26.984720604760305, 8.504016637802124, 6.741264300686972, 22.692823546273367, 26.577622175216675, 25.627947602953228, 28.57721471786499, 35.44125325339181, 42.616345269339426, 48.16615636008126, 48.66470697947911, 45.782833916800364, 47.43476465770176, 46.09133046013968, 47.787215505327495, 45.82858780452183, 47.39455543245588, 45.42242043358939, 50.34733486175537, 50.356992857796804, 56.582742077963694, 53.473318985530305, 56.18695184162685, 50.222440992082866, 51.62373978751046, 39.07269450596401, 37.697427136557444, 32.07427086148943, 13.710310527256556, 42.55759825025286, 56.73516123635428, 47.37883513314383, 56.5055684362139, 47.755701950618196, 47.23856837408883, 56.20519086292812, 55.13614797592163, 19.184092691966466, 1.8879725549902235, 28.041074344090053, 61.50680882590157, 27.297436441693986, 15.727407319205147, 46.24865157263619, 53.59444693156651, 31.87895699909755, 31.883219718933105, 21.19148632458278, 25.654135363442556, 33.92243957519531, 20.253340550831386, 46.796756744384766, 63.363047872270855, 26.219836848122732, 0.29363820063216345, 0.043564258608967066, 0.19271275268069335, 0.02259666140058211, 0.0904574439461742, 0.017450071671711545, 0.09875749464013747, 0.08416292563612972, 0.04087144149733441, 0.25996169341462, 0.1988001481762954, 0.3275683985224792, 0.138247886672616, 0.18697378491716726, 0.20353332348167896, 0.19400167066071713, 0.23408101073333196, 0.1955374125391245, 0.30905492337686674, 0.1306991981608527, 0.3374137787946633, 0.16983852296003274, 0.8131401357906205, 42.702343123299734, 77.67538506644112, 48.811650957380024, 49.57335417611258, 55.21189028876168, 27.20666343825204, 53.213268756866455, 51.429440362112864, 29.552835600716726, 26.374767780303955, 21.811342069080897, 33.67658451625279, 65.33996323176792, 15.846473387309484, 1.6928350031375885, 20.780731405530656, 59.90207372392927, 60.1308570589338, 74.5441654750279, 63.86090019771031, 66.9775424684797, 65.55615643092564, 62.008607728140696, 29.147772993360245, 3.478206983634404, 15.13153154509408, 40.29151970999581, 41.72322729655674, 55.98537070410592, 57.059214796338765, 51.87616784232003, 48.90122365951538, 55.06130198069981, 55.888332162584575, 58.421141624450684, 56.388532979147776, 58.57548195975167, 60.852121761866975, 59.809113774980815, 53.304106031145366, 48.46488373620169, 37.148137296949116, 27.020727906908306, 27.07039189338684, 27.3401609148298, 25.704372576304845, 26.46876301084246, 22.62761470249721, 22.067285912377493, 23.277717692511423, 30.30713551385062, 28.20161247253418, 18.79979303904942, 12.993632503918239, 5.708212213856833, 4.377943115574973, 4.772348489080157, 9.907547542027064, 15.387751579284668, 20.551393951688492, 24.356800726481847, 12.180362360818044, 2.7560657220227376, 0.6992451559220041, 3.9912328720092773, 6.918455524103982, 9.92350321156638, 11.270818846566335, 22.45195034572056, 24.692190272467478, 29.642165115901403, 25.8736115864345, 32.27104384558541, 31.97869144167219, 20.74075494493757, 34.45583888462612, 37.78672538484846, 38.37500851494925, 46.058576651981895, 46.191707611083984, 44.38548517227173, 35.12015962600708, 15.894968339375087, 6.456916221550532, 7.215190504278455, 6.659661616597857, 1.8447949290275574, 0.5541661722319466, 8.780870216233389, 20.516998631613596, 26.123239517211914, 21.38435615812029, 17.6853540965489, 12.881736976759774, 12.540715047291346, 13.755070822579519, 17.739447559629166, 22.640300376074656, 24.162256377083914, 31.772472381591797, 11.49146670954568, 10.160789404596601, 31.55421209335327, 30.18265506199428, 27.14427730015346, 30.765355314527238, 37.93098388399397, 45.19484608513968, 52.79567854745047, 51.09547867093767, 48.79067087173462, 48.88043464933123, 47.99047810690743, 50.19263669422695, 48.15766218730381, 50.469987937382285, 49.41044323784964, 52.36243404660906, 53.91919878550938, 58.7995822089059, 58.107753549303325, 55.93226909637451, 51.879791327885215, 52.85702419281006, 45.75403363364083, 43.20201587677002, 44.42050756726946, 15.62198577608381, 43.59234135491507, 63.32712568555559, 50.67656830378941, 61.53787422180176, 54.083356925419395, 55.385657787323, 61.93670082092285, 57.877709116254536, 27.293776478086198, 2.6842719401632036, 26.02088212966919, 61.23002733503069, 21.392707892826625, 23.041256598063878, 52.82590668542044, 57.09760706765311, 30.36260298320225, 43.98942743028913, 21.850396156311035, 34.43705790383475, 44.67166757583618, 32.49361549104963, 57.2634015083313, 73.39471108572823, 39.622661794934956, 0.3640768394938537, 0.2498340154332774, 0.26036449894309044, 0.2100674392921584, 0.22079074888357095, 0.1987398671252387, 0.1843089879091297, 0.17481944497142518, 0.13457496304597172], [0.09201834590307303, 0.10339563433080912, 0.03759556602952736, 0.056311251396047216, 0.09684680109577519, 0.03859722960208144, 0.049178647343069315, 0.05429463174992374, 0.023862113943323493, 0.0800892524421215, 0.01158969194096114, 0.07398851694805281, 0.030066493965153183, 0.12037686205336026, 2.622828585760934, 28.507625034877233, 56.999092033931184, 30.674236638205393, 37.057779448372976, 27.003661394119263, 31.71031379699707, 40.99073430470058, 21.447277307510376, 13.672065905162267, 12.89859504359109, 16.232087986809866, 32.83987201963152, 44.6635034424918, 3.0748888083866666, 7.031437575817108, 41.251319544655935, 37.00290952410017, 42.07713031768799, 61.55063806261335, 49.15646573475429, 56.18779952185494, 39.121210302625386, 43.85262434823172, 24.107541050229752, 1.2287494029317583, 9.506299495697021, 36.083575998033794, 24.38088665689741, 47.38551582608904, 47.65764202390398, 48.8738442829677, 44.36175012588501, 48.69769702638899, 47.45123188836234, 54.00681209564209, 52.66965906960623, 48.19542217254639, 39.187245982033865, 33.61290775026594, 25.680321386882238, 24.49931522778102, 23.75574507032122, 22.54877175603594, 24.6165052822658, 19.656307901654923, 14.393895149230957, 5.550131576401847, 8.63913825580052, 11.58334013393947, 16.383324214390345, 12.973094497408185, 14.19941246509552, 8.108813524246216, 6.070318451949528, 2.4708252336297716, 2.9522995693343024, 12.78980883530208, 17.975875650133403, 12.086179528917585, 5.497706983770643, 2.262574476855142, 0.12644315510988235, 1.2299701145717075, 1.3409413141863686, 1.8046897096293313, 2.391490702118192, 2.2700648520674025, 3.778122067451477, 10.739813191550118, 22.141285964420863, 28.989331483840942, 24.53328149659293, 19.40834059034075, 11.633850932121277, 27.597454445702688, 26.884949684143066, 16.349615028926305, 18.145861591611588, 20.355241094316753, 12.453186852591378, 7.024164983204432, 3.966894200869969, 5.839965258325849, 3.7689230867794583, 3.1907534939902167, 1.4502500487225396, 0.5075443567974227, 2.211779888187136, 7.55282301562173, 15.685560056141444, 17.77874309676034, 14.944102151053292, 4.3981519511767795, 6.170836303915296, 10.206354822431292, 15.218392712729317, 10.57592603138515, 13.588876860482351, 26.519660302570887, 24.673096622739518, 5.223759923662458, 2.1441092107977187, 12.09736612864903, 25.635151147842407, 29.201819556100027, 32.14339501517159, 38.31500734601702, 42.90536601202828, 46.43543304715838, 48.27284247534615, 46.997809818812776, 46.015539509909495, 45.80952542168753, 43.975888865334646, 47.624818733760286, 47.96180289132254, 49.09234428405762, 48.340041978018625, 47.914120878492085, 51.291320596422466, 53.79093156542097, 44.74909482683454, 43.015342099326, 31.71958269391741, 18.203069584710256, 4.576976435525077, 26.421504838126047, 45.05497537340437, 38.48306342533657, 44.678556714739116, 49.94726800918579, 47.680883748190745, 58.588461194719585, 55.663773332323345, 37.2250851222447, 4.874774490083967, 4.780639861311231, 44.59074190684727, 15.21002881867545, 11.390784706388201, 27.296692984444753, 48.28629418781826, 39.61036695752825, 20.901470252445765, 24.91118880680629, 18.361877611705236, 38.593664850507466, 23.769719634737285, 37.60739237921578, 35.20290919712612, 56.06974615369524, 6.035970900739942, 0.11618557838456971, 0.09453626043562378, 0.054805419341261895, 0.07137205877474376, 0.06790297385305166, 0.022584653027089577, 0.03430290699803403, 0.0036754431119853897, 0.0106403705597456, 0.08758354280143976, 0.025293534455288733, 0.05812681772347007, 0.02653330105489918, 0.08777265729648726, 0.04022025143993752, 0.09178835645850215, 0.047409879575882635, 0.008313579834066331, 0.1893084474972316, 0.018248200183734298, 0.06842064178947892, 0.01720310188829899, 0.06740136684051581, 5.724029353686741, 45.474264417375835, 66.43566635676792, 29.47749628339495, 43.978932176317485, 27.516662529536656, 29.318069866725377, 33.728369440351216, 26.00202819279262, 23.29407548904419, 19.523748431886943, 22.365311520440237, 48.30179909297398, 49.58426284790039, 5.769770213535853, 5.814634731837681, 42.61854090009417, 42.728635106767925, 51.09727130617414, 66.12485953739711, 53.361800398145405, 60.352087702069966, 45.40143687384469, 49.330406938280376, 33.05096524102347, 2.1466950263295854, 10.42349818774632, 43.73613779885428, 30.329522609710693, 48.07853957584926, 50.365952559879844, 52.08292538779122, 47.57176228931972, 52.599662917000906, 49.336854866572786, 58.31239536830357, 57.832712582179475, 54.47428689684187, 44.651260716574534, 39.90487330300467, 30.767196587153844, 26.96054434776306, 26.690049239567347, 28.974217414855957, 27.52111111368452, 24.882355519703456, 16.25544956752232, 8.325043201446533, 10.913611088480268, 16.55887392589024, 20.444238833018712, 16.875439064843313, 18.01102658680507, 11.851818527494158, 8.32767483166286, 4.958694398403168, 6.423454565661294, 10.9962877035141, 18.239632742745535, 22.392819438661846, 10.786627548081533, 4.751573809555598, 0.43494417678032604, 0.31831562359418186, 1.3145661694662911, 0.6959430245416505, 1.565514583672796, 4.801361126559121, 8.081002490861074, 18.302932568958827, 21.62843942642212, 22.167645692825317, 27.23127395766122, 23.046931539263042, 15.707742180143084, 27.879115309034074, 30.893789291381836, 31.633713381631033, 38.250764301845, 36.44866909299578, 33.050388540540425, 25.824499981743948, 9.614520294325692, 3.8791119626590183, 0.4548054667455809, 2.9367026005472456, 3.3551645917551856, 2.050369760819844, 4.458825792585101, 12.08205577305385, 20.7307391166687, 21.928344522203716, 13.730585370744977, 9.497567347117833, 9.176717775208608, 13.350483298301697, 18.273944684437343, 13.93234976700374, 19.37422146115984, 28.25171593257359, 25.62908363342285, 7.948693156242371, 1.9584932965891702, 15.222924675260272, 26.697506393705094, 29.30918312072754, 32.81163106645857, 40.15862151554653, 43.96359402792794, 47.22289323806763, 49.759277548108784, 49.126557213919504, 47.956077575683594, 47.16822133745466, 47.19638933454241, 50.62752791813442, 50.94833319527762, 51.58840472357613, 51.46035289764404, 49.52449791772025, 56.762453760419575, 51.83858503614153, 45.167206151144846, 44.39206164223807, 34.221090521131245, 14.890488113675799, 6.33425315788814, 34.50844717025757, 47.50566060202462, 45.349332332611084, 48.68552725655692, 53.68678501674107, 52.17077146257673, 62.277892112731934, 59.023814473833355, 37.22054100036621, 2.383081861904689, 9.768286534718104, 47.32201623916626, 22.266037396022252, 15.506824595587593, 24.077338968004497, 48.859492778778076, 48.17099230630057, 25.81761952808925, 31.34795481818063, 21.839258193969727, 40.38758897781372, 29.219200474875315, 34.61683212007795, 44.95589058739798, 60.40891007014683, 8.573330998420715, 0.31112936777727945, 0.1286850483821971, 0.22786291582243784, 0.03248422958755067, 0.15978048981300422, 0.09705346250640494, 0.06918872985988855, 0.06951405347457953, 0.10611512804669992, 0.25704887828656603, 0.10948168632707425, 0.13455291065786565, 0.11122877150774002, 0.25189673474856783, 0.1664809959807566, 0.3981553922806467, 0.15244940748172148, 0.27951590557183537, 0.25137176577533993, 0.16341758679066384, 0.16553722162331852, 0.0879951421437519, 0.21413985719638212, 11.205131445612226, 71.33912822178432, 74.75320202963692, 45.756131989615305, 49.46025834764753, 41.19570616313389, 44.55364547457014, 57.637739181518555, 33.77358831678118, 33.85536514009748, 26.3914886202131, 23.205776044300624, 47.27377142224993, 51.27870266778128, 6.4068852833339145, 11.333408219473702, 50.83877747399466, 45.38204445157732, 55.55578442982265, 70.55519771575928, 59.892464365277974, 68.36252689361572, 49.565040656498496, 56.24263817923409, 30.604622636522564, 1.7439601740666797, 15.59413913318089, 49.98365919930594, 32.072644983019146, 52.16947562353951, 54.173190185001914, 56.662827014923096, 50.83115530014038, 55.04682888303484, 51.567355155944824, 60.46004186357771, 62.21678270612444, 56.65491301672799, 47.72157934733799, 45.03574970790318, 35.471926076071604, 30.901946476527623, 30.699361324310303, 33.40269695009504, 32.73699351719448, 30.250511169433594, 24.970783506120952, 14.411157080105372, 16.425789867128643, 21.713551385062082, 25.848573752811976, 25.36079284123012, 24.645414999553136, 14.010456204414368, 12.861938084874835, 7.216913657529013, 8.719430770192828, 16.05917337962559, 22.582757132393972, 27.095299448285783, 13.915270226342336, 6.077778211661747, 0.21414430838610443, 0.9936651374612535, 4.736680780138288, 8.239094853401184, 14.315271071025304, 10.334783588136945, 14.528843930789403, 23.707178899220057, 33.92992973327637, 40.51232303891863, 32.39847380774361, 25.534172977719987, 19.28047983986991, 37.49694381441389, 34.63408102308001, 36.60325608934675, 41.74399546214512, 40.29756464276995, 34.95272193636213, 24.725426980427333, 20.094334500176565, 16.13119145802089, 19.17067572048732, 14.568453005381993, 14.2258859702519, 7.905972157205854, 5.9070627093315125, 16.272448335375103, 27.89543489047459, 24.75161474091666, 19.708023343767437, 16.68403877530779, 13.648891057286944, 18.345382588250295, 22.175493683133805, 17.995314972741262, 22.146788937704905, 30.878333023616246, 28.044774259839738, 8.185330561229161, 5.811119377613068, 25.44795799255371, 33.13916219983782, 33.299821921757285, 35.751657077244346, 43.39570733479091, 45.98363338197981, 52.460400172642295, 53.27444764545986, 53.1306859425136, 48.94115843091692, 51.61883435930525, 49.82993377958025, 52.50501108169556, 53.288350990840364, 55.443796839032856, 54.928924901144846, 51.127259731292725, 57.576949392046245, 56.03644691194807, 46.785719530923025, 45.22697108132498, 43.12304959978376, 22.763674327305385, 8.063198600496564, 32.71570423671177, 51.871578557150706, 48.34504815510341, 54.224026679992676, 57.34879486901419, 56.797378880637034, 65.10808794839042, 65.84245000566754, 45.55435630253383, 7.596887622560773, 7.447987726756504, 54.116930621010916, 22.0765791279929, 16.442215408597672, 33.95485292162214, 53.59794882365635, 51.966751507350374, 25.994944504329137, 38.52100058964321, 23.667815617152623, 53.79813684735979, 36.276468413216726, 51.42310013089861, 51.40190117699759, 72.80009119851249, 16.742742368153163, 0.40421902547989574, 0.1662849129310676, 0.33660879198993954, 0.2959396828498159, 0.3501627461186477, 0.21838712000421115, 0.12249420343765191, 0.12472951492028576, 0.22845942952803203], [0.19966061200414384, 0.03253315196239522, 0.014890398397775633, 0.11804655566811562, 0.0849973133632115, 0.10471950364964348, 0.06456840849880661, 0.1348308657429048, 0.16920888317482813, 0.0491302576182144, 0.1723935872848545, 0.11251669204128639, 0.16863990442029067, 0.09343844505825213, 1.2070896966116769, 26.451126745768956, 56.565232617514475, 45.97532681056431, 34.91714021137783, 41.17646312713623, 27.84623990740095, 44.64316259111677, 23.15990056310381, 16.301245144435338, 11.855671303612844, 25.79591509274074, 15.7125711781638, 50.11256217956543, 21.16720063345773, 0.7145266873495919, 5.308488862855094, 30.036603927612305, 60.29227066040039, 50.21821996143886, 57.25016171591622, 55.63040113449097, 53.21274764197213, 35.90350648335048, 36.9863589150565, 9.569251911980764, 0.537525128040995, 26.331671578543528, 57.72322286878313, 38.71692936761038, 40.03915418897356, 40.070619106292725, 49.21099519729614, 45.41191128322056, 50.002193519047324, 48.0236314364842, 44.48850958687918, 34.88790219170706, 31.31564222063337, 27.482220309121267, 25.70688956124442, 20.18300567354475, 23.95829200744629, 22.83234163693019, 21.525282996041433, 14.213139499936785, 12.209575193268911, 5.372071393898555, 9.931604811123439, 11.805476648466927, 15.182475737163, 9.414348772593907, 10.854733790670123, 7.6661959035055975, 8.781396542276655, 7.055018024785178, 7.551283989633832, 12.890404854501996, 14.888886553900582, 9.551805853843689, 4.998760317053113, 2.041771582194737, 0.30162632199270384, 0.5563694568617004, 0.6106069322143282, 4.969840177467891, 8.556083832468305, 11.591790011950902, 10.966494696480886, 17.597945758274623, 31.013718673161097, 36.76877607618059, 29.864163534981863, 20.832634449005127, 16.57131814956665, 26.571082183292933, 30.863245010375977, 19.085766996656144, 9.380066360746111, 10.274967414992195, 6.6175776805196485, 11.668630140168325, 16.081904411315918, 20.7873843056815, 18.004330260413035, 17.91386124065944, 10.322819658688136, 8.895907197679792, 7.830547724451337, 10.332022547721863, 20.494225910731725, 19.098110471452983, 15.541881731578282, 9.28737391744341, 10.971076164926801, 8.601859433310372, 17.90348584311349, 21.47853204182216, 10.538399679320198, 18.081762722560338, 28.850075687680924, 30.038657120295934, 14.117877091680255, 2.756477402789252, 7.637669205665588, 25.933951480048044, 34.054010663713726, 39.47319562094552, 47.88004691260201, 47.42748294557844, 44.266938482012065, 41.658126149858745, 44.5553686278207, 46.74135875701904, 49.13196638652256, 47.846514906202046, 48.06465012686593, 47.480310099465505, 48.63237006323678, 56.49137326649257, 48.50647912706648, 45.31518541063581, 47.03659118924822, 35.48049667903355, 7.368842533656529, 0.11733322537371091, 12.603877646582466, 47.92227111543928, 43.539427348545615, 47.697107791900635, 47.18762765611921, 52.5846791267395, 25.741481167929514, 31.67164707183838, 34.00511966432844, 4.640650595937457, 0.5171891078352928, 21.920868260519846, 49.93172836303711, 15.768146344593593, 26.4127779006958, 37.73791428974697, 49.92688546861921, 32.88934666769845, 21.077787739889963, 19.636416946138652, 28.983243124825613, 28.712268590927124, 32.598998819078716, 34.346845967429026, 42.13224342891148, 48.822875772203716, 1.412545757634299, 0.08127607804323946, 0.09568356815725565, 0.05047673572387014, 0.07677611522376537, 0.05789701148335423, 0.10022113538746323, 0.019795964006334543, 0.030014769240681614, 0.07199993436889988, 0.09924584307840892, 0.05227450407775385, 0.057876417945538244, 0.0810229776959334, 0.042231863497623374, 0.0861719117632934, 0.04648447994674955, 0.034783509959067614, 0.06106933232929025, 0.06505933537014894, 0.10542059317231178, 0.055573911140007634, 0.11112191581300326, 0.05982011543320758, 0.9567330735070365, 38.073029381888254, 73.65816593170166, 41.240428243364605, 40.018146310533794, 50.58894109725952, 33.74433640071324, 36.041918073381694, 26.297244991574967, 22.916336672646658, 17.972179208483013, 28.330777747290476, 25.952074119022914, 66.87773854391915, 31.498824528285436, 4.159037947654724, 2.4343215695449283, 27.983963625771658, 62.34210041591099, 58.41420732225691, 62.038936614990234, 60.879546301705496, 54.05696071897234, 43.29240151814052, 42.7580120904105, 14.321429780551366, 1.0394493149859565, 23.96234107017517, 57.41271134785244, 43.63796322686331, 46.85441289629255, 42.49109704153878, 47.453253814152305, 46.500749588012695, 51.32399450029646, 50.21109458378383, 45.85263899394444, 40.502310684749055, 35.46071515764509, 29.8389276776995, 27.75763647896903, 23.26825945717948, 25.933406046458654, 26.956799268722534, 25.660453013011388, 18.863237040383474, 15.121979509081159, 10.207468271255493, 12.506360547883169, 16.04195921761649, 19.302948577063425, 13.794680765696935, 14.021638461521693, 12.302573357309614, 11.194650956562587, 9.70180790764945, 9.899888021605355, 12.231909309114728, 18.36353475706918, 17.463756935937063, 8.440021123204913, 2.5536280018942694, 0.3740403934248856, 0.6724409056561333, 1.954659628016608, 2.4405273965426852, 1.081774266702788, 4.962376509393964, 9.381984063557216, 17.75111358506339, 31.38990456717355, 36.339881147657124, 32.36797816412789, 24.062223161969865, 16.648788826806204, 28.119760956083024, 33.797576972416465, 25.54705146380833, 31.00672878537859, 31.334190436771937, 26.07692108835493, 19.805046251841954, 11.274909598486763, 12.57630111489977, 4.629421438489642, 5.51177100624357, 3.79621821641922, 3.1972958743572235, 6.038960797446115, 12.537349513598851, 22.17341790880476, 22.42427393368312, 16.930767570223125, 14.92928511755807, 14.781114782605853, 15.416152341025215, 20.007250990186417, 23.416299513408116, 14.06306449004582, 26.07473587989807, 32.115640435900005, 32.405182293483186, 18.350454773221696, 8.15871982915061, 14.216795989445277, 27.126470804214478, 36.611430644989014, 40.23639270237514, 49.80190822056362, 47.907002449035645, 47.56215293066842, 45.269556590488975, 47.06215361186436, 48.15670680999756, 49.98548657553536, 50.461104665483745, 48.33439656666347, 49.31862279347011, 51.7727439062936, 58.08270181928362, 49.57428870882307, 45.29193673815046, 47.47620023999895, 34.517695222582134, 4.688511524881635, 0.7154549775379044, 19.683860983167374, 52.02053056444441, 47.06382812772478, 50.82096924100603, 52.44537469318935, 56.4858147076198, 31.59436920710972, 36.7116653578622, 31.225989614214214, 2.290372916630336, 2.8858706653118134, 33.39382062639509, 54.92668758119856, 24.212832314627512, 21.58166241645813, 35.08129487718855, 50.354369912828716, 41.29679897853306, 27.572724069867814, 27.265667540686472, 26.647239650998795, 32.525361810411724, 33.283823694501606, 37.705410616738455, 49.559020042419434, 53.051754406520296, 2.1994329392910004, 0.17541644722223282, 0.055552157307309766, 0.1333270285810743, 0.010932861561221736, 0.08009919976549489, 0.029544727677213292, 0.018914511394021765, 0.04460280055978468, 0.15173324091093882, 0.18987279864294188, 0.11453091645879404, 0.27609019939388546, 0.15234430240733282, 0.19857290679855005, 0.20435634574719838, 0.15938376395830087, 0.25478571972676683, 0.3249203749001026, 0.10464450517403227, 0.3232163291956697, 0.1939839201846293, 0.2597538445677076, 0.18675474024244718, 1.98526622567858, 56.75071130480085, 81.70161601475307, 59.40294292994908, 47.814792905535015, 55.92947244644165, 39.74519327708653, 60.000342096601216, 36.95849663870675, 36.161750180380686, 24.421031611306326, 31.335038117000035, 21.1144186428615, 63.94691889626639, 25.73040052822658, 2.735388534409659, 9.098575728280203, 37.54255526406424, 71.27006312779018, 61.66617965698242, 66.43951565878731, 64.75794737679618, 62.55839088984898, 47.36038071768624, 47.742100851876394, 12.963576333863394, 1.4725756964513232, 33.66276107515608, 69.51903370448521, 50.40709284373692, 48.144158363342285, 44.72831971304757, 50.70739051273891, 48.772324153355186, 54.85606261662075, 52.394090039389475, 50.34542063304356, 45.56330558231899, 39.19341598238264, 33.16731630052839, 32.178486892155235, 27.95719221660069, 33.16485316412789, 30.019487040383474, 32.41917596544538, 24.232228210994176, 20.60504620415824, 14.31385624408722, 19.37978870528085, 18.870006322860718, 25.008672033037456, 15.402188198907034, 17.46530291012355, 15.92666254724775, 14.971709081104823, 13.760364481381007, 15.30645591872079, 15.119664021900721, 22.007210050310405, 25.202822072165354, 12.804399183818273, 3.900695238794599, 0.6431805757539613, 3.5130821636744907, 6.99483403137752, 17.785220554896764, 21.76072791644505, 24.386054379599436, 21.26297286578587, 31.163448878696986, 42.95043202808925, 41.60755716051374, 39.38715260369437, 30.636327266693115, 26.961141892841884, 31.709136077335902, 40.4433274269104, 38.640398434230256, 34.6080322265625, 35.389259883335654, 27.400950704302105, 31.48351764678955, 35.64290387289864, 37.77843965802874, 32.54374326978411, 30.39521435328892, 24.584328174591064, 21.787987436567033, 17.48639590399606, 20.149336440222605, 34.62284926005772, 26.844943693705968, 19.052749156951904, 21.396934134619578, 19.125257083347865, 19.54824083192008, 23.869330746786936, 26.845888648714336, 15.79000016621181, 29.28407233101981, 35.25514228003365, 35.95574998855591, 19.200784002031597, 13.247824532645089, 18.41839599609375, 34.65769100189209, 37.646097319466726, 44.67225122451782, 52.92792361123221, 52.6513158253261, 48.88428047725132, 47.44202552522932, 48.26753405162266, 52.4470214162554, 54.26522254943848, 53.69788476399013, 52.94240713119507, 51.38401651382446, 52.21149832861764, 60.410834721156526, 54.21074172428676, 45.97127948488508, 47.308439459119526, 43.40540354592459, 10.682104928152901, 0.5275692822677749, 16.5451477595738, 56.44121422086443, 53.90759876796177, 56.50772932597569, 58.32832758767264, 60.73004886082241, 35.89815289633614, 40.039043017796104, 41.18448829650879, 7.225669690540858, 2.40709896172796, 27.970124551228114, 61.14613478524344, 20.204359224864415, 37.17791032791138, 41.48091581889561, 54.48898581096104, 38.01017597743443, 31.21010603223528, 30.870179312569753, 36.960021768297466, 43.714181491306846, 40.71565164838518, 49.651615210941856, 53.33086701801845, 71.35590812138149, 4.212578160422189, 0.3246798478066921, 0.15991220703082426, 0.24040395287530764, 0.19378991345209734, 0.17863043690366404, 0.17389046267739364, 0.10033198765345983, 0.19890760098184856, 0.3567024937697819], [0.04463116671623928, 0.07688197347202472, 0.05664798118440168, 0.0684173848213894, 0.07017337916685001, 0.04343491287103721, 0.08298874114240919, 0.053368713041501384, 0.03795601061678358, 0.02539251744747162, 0.1459711351032768, 0.02686091642161565, 0.12326244078576565, 0.08373165556362697, 0.1601484322122165, 16.75606553895133, 61.598789078848704, 39.27529008047921, 24.492955889020646, 34.96847002846854, 21.651166984013148, 36.415324687957764, 32.19356448309762, 15.7554589339665, 16.809954030173166, 12.895287701061793, 23.428952183042252, 28.79335059438433, 82.07011372702462, 12.944478341511317, 2.3327551909855435, 6.668195741517203, 49.223380361284526, 52.615543024880544, 43.10470288140433, 45.77818557194301, 57.820664405822754, 46.22525003978184, 34.26015329360962, 30.16967930112566, 3.484612354210445, 0.14576468403850282, 5.800921159131186, 10.978817326681954, 28.682417392730713, 36.7090493610927, 36.194462299346924, 35.22198895045689, 37.87006207874843, 40.72436816351754, 37.32190479551043, 30.970559937613352, 35.17227806363787, 30.738167013440812, 28.8534768308912, 32.1204868044172, 31.99267816543579, 21.154204027993337, 12.436248012951442, 10.787280678749084, 6.552174287182944, 9.319862825529915, 12.881503343582153, 15.915792090552193, 17.339297328676494, 10.533775653157916, 13.92919875894274, 9.508139899798802, 10.335969124521528, 7.489712527820042, 11.980399285043989, 19.40150008882795, 18.931725433894567, 9.157704898289271, 4.393592630113874, 1.1180098823138644, 0.2832422027630465, 2.709356891257422, 6.09493852513177, 13.42713669368199, 20.488054173333303, 22.164932421275548, 23.173968928200857, 29.926290852682932, 36.877775941576274, 42.4199891771589, 36.68269484383719, 40.62626654761178, 26.910920313426427, 27.745405912399292, 35.18738692147391, 22.52806612423488, 10.67237137045179, 12.394483259746007, 12.95816455568586, 24.886790207454137, 32.433444091251914, 30.880288941519602, 24.921800443104335, 36.28872503553118, 23.49480026108878, 25.037175280707224, 23.510254791804723, 24.30408648082188, 25.20004279272897, 20.556535618645803, 14.22143999167851, 12.646891338484627, 12.035750372069222, 11.50358089378902, 16.197074277060374, 17.70646619796753, 25.27298150743757, 16.386122601372854, 26.957857131958008, 34.60191433770316, 28.356760535921367, 15.983264310019356, 10.283678718975612, 7.977427431515284, 20.81861298424857, 36.21944107328142, 40.10517597198486, 46.50531455448696, 46.05382408414568, 49.72666270392281, 46.91717250006539, 46.49048362459455, 44.50843702043806, 50.62814630780901, 50.5959483555385, 50.787416390010286, 51.019864899771555, 43.23686456680298, 44.57541765485491, 45.85925367900303, 26.338449546269008, 5.558854171207972, 0.13656597478049143, 8.302734272820608, 36.93049887248448, 46.15378434317452, 47.144666944231304, 50.26231322969709, 47.916684763772146, 43.809444768088206, 26.06322271483285, 38.96785661152431, 6.098139473370143, 1.0194690099784305, 15.729959045137678, 55.42050995145525, 29.802626814161027, 14.090638416154043, 29.163528033665248, 41.710769176483154, 45.660319805145264, 21.604977096830094, 23.33052052770342, 21.440792901175364, 33.69200951712472, 30.13873549870082, 26.59096792766026, 31.37789808000837, 53.162863050188335, 29.193627629961284, 0.3985456313405718, 0.05943504002477441, 0.006794901415040451, 0.07069344911724329, 0.057973814862115045, 0.03643747977912426, 0.027145453296335678, 0.03212239739618131, 0.05767393631062337, 0.033686797201101265, 0.012233568239025772, 0.053205810354224274, 0.05262534400182111, 0.09777395134525639, 0.029632726883781806, 0.026187465326594453, 0.03204150584393314, 0.024341266535754715, 0.03368576582787292, 0.006097082431162042, 0.1029323170493756, 0.03223721230668681, 0.06821683022592749, 0.057537387923470566, 0.08957004906343562, 18.849764483315603, 74.95078100476945, 45.17387294769287, 24.042901958738053, 45.16337769372122, 28.832343884876796, 38.46954223087856, 25.931835753577097, 28.948747055871145, 22.028447219303676, 20.86304497718811, 23.26569730894906, 43.44936827250889, 78.0948964527675, 22.356435196740286, 4.136962217944009, 5.470724957329886, 51.00601019178118, 58.348706654139924, 48.63091788973127, 51.47925894601004, 61.06882217952183, 50.510103361947195, 40.19202150617327, 35.107308932713096, 6.225418746471405, 1.0439822546073367, 4.741479814052582, 11.587317977632795, 29.892432280949183, 43.644390310559956, 42.84476729801723, 40.46918167386736, 41.173482349940706, 44.07310806001936, 41.429648535592214, 33.775506019592285, 37.28585754122053, 35.257914611271445, 35.18761968612671, 36.264246531895225, 33.848865100315635, 27.668657847813197, 17.011540378843033, 16.483968870980398, 12.508901851517813, 13.022105353219168, 17.355332033974783, 21.984661408833094, 20.588139499936783, 13.660531895501272, 14.34049390043531, 12.462634665625435, 11.979917253766741, 10.977637869971138, 14.885582685470581, 17.727373327527726, 18.78140115737915, 16.034837314060756, 9.51172343322209, 3.9391092232295444, 2.1842218126569475, 2.717135182448796, 3.133038716656821, 4.399304483618055, 10.974365268434797, 14.17920276096889, 17.348013843808854, 27.19259854725429, 37.19812263761248, 47.22912229810442, 37.86924566541399, 30.83606365748814, 24.80510023662022, 30.698336465018137, 39.6950272832598, 25.819532019751414, 21.27102756500244, 23.44076759474618, 17.679290056228638, 18.056975024087087, 21.947379112243652, 22.811029774802073, 19.696692568915232, 21.691126074109757, 18.28718273980277, 12.582722118922643, 16.458347388676234, 21.41420909336635, 26.319708517619542, 23.457497119903564, 17.09513415609087, 16.884494304656982, 16.15159831728254, 16.650477239063807, 22.05775993210929, 21.77217854772295, 26.587464298520768, 18.89269913945879, 30.94041517802647, 34.647035939352854, 30.80447714669364, 19.90389132499695, 17.577837671552384, 11.762420398848397, 25.59773162433079, 37.85373381205967, 41.45146240506853, 46.32047510147095, 49.30332286017281, 50.31620693206787, 50.01644427435738, 48.27967255456107, 48.69873578207833, 52.860168252672466, 54.583908626011436, 51.02730642046247, 52.98198407036917, 42.78180619648525, 48.22339909417288, 44.18335165296282, 21.688513551439556, 3.449093814407076, 0.5645367386085647, 13.29415512084961, 39.60340486254011, 50.942722524915425, 49.83806664603097, 53.90921769823347, 51.74328007016863, 47.44609022140503, 29.833664417266846, 35.09060893739973, 4.735581661973681, 2.1950438490935733, 28.247270822525024, 54.980862685612266, 40.06337908336094, 18.298329387392315, 20.036068643842423, 36.61847611836025, 50.73167446681431, 31.57982315335955, 26.11390287535531, 26.04671379498073, 27.280020781925746, 34.1716262953622, 24.846709523882183, 37.4419800894601, 57.85703475134713, 33.21642269407, 0.5994245665413993, 0.13769874828202383, 0.1672121174633503, 0.041345242144806046, 0.09424252262605087, 0.024217946188790456, 0.008255023110125746, 0.04636490511308823, 0.032195336518010924, 0.03672031692362257, 0.16185916827193328, 0.1993650421500206, 0.19343688525259495, 0.18963318078645638, 0.18485336298389093, 0.14673383560563835, 0.16637031334851468, 0.20145111664065293, 0.11418493145278522, 0.0739348109013268, 0.23817317400659832, 0.10786958211766821, 0.14390443957277707, 0.25012073719075745, 0.22664696749831947, 30.42799595424107, 85.18003708975655, 55.18341657093593, 34.51762226649693, 46.38251556668963, 29.427024568830216, 49.59802375520979, 44.258138588496614, 33.40271084649222, 34.4681510925293, 20.883837461471558, 26.843686069761002, 34.28930446079799, 89.91958400181362, 17.841104916163854, 3.8943936569350104, 9.489894798823766, 58.53867735181536, 62.56110763549805, 55.09355551855904, 56.87698091779436, 68.59222739083427, 55.6091604913984, 45.298249176570344, 36.12940979003906, 5.349307358264923, 0.40727039745875765, 9.936855912208557, 19.14912588255746, 43.52859510694231, 49.10968698774065, 47.436988081250874, 42.67315721511841, 44.136930738176616, 45.80726030894688, 45.73377963474819, 35.469754764011924, 42.22545351300921, 39.55917610440935, 38.92869309016636, 40.681626319885254, 42.6135972567967, 32.35761840002877, 23.29800990649632, 22.668185234069824, 19.788945538657053, 18.19255174909319, 22.8392550945282, 26.475231783730642, 27.13003523009164, 16.32157209941319, 19.135259015219553, 14.582378932407924, 15.011603900364467, 13.981454423495702, 22.779900108064922, 25.149769101824077, 24.113071816308157, 24.980722904205322, 13.778250013078962, 7.15333069222314, 5.458846143313816, 14.568182894161769, 20.088918379374913, 31.920229298727854, 33.57764911651611, 34.76838275364467, 34.02193430491856, 39.76407848085676, 42.65714509146554, 48.16537468773978, 46.40154668263027, 45.27909299305507, 38.8116854258946, 33.32682262148176, 44.360030446733745, 37.69151074545724, 32.12804644448416, 35.513174057006836, 34.57700851985386, 39.83195195879255, 40.107243061065674, 34.55903353009905, 30.717245987483434, 38.601210594177246, 36.24992629459926, 37.174985136304585, 33.6569002696446, 31.87734154292515, 31.746781417301722, 24.230524165289744, 21.417900323867798, 22.056476252419607, 21.16338954653059, 22.87354098047529, 24.582396575382777, 27.699348040989467, 31.71270397731236, 23.511875459126063, 33.25371715000698, 38.60656418119158, 32.66506576538086, 23.531557968684606, 22.428451538085938, 18.075094188962662, 32.743472712380544, 44.96381153379168, 45.16377374104091, 51.19696058545794, 51.1487192426409, 54.25920193535941, 52.04648208618164, 51.598542145320344, 49.441439151763916, 56.30984115600586, 55.32372849328177, 57.69526331765311, 55.930281911577495, 44.23721408843994, 44.73930134092058, 49.93111344746181, 34.386360372815815, 9.073252149990626, 0.3343169721109526, 12.155677148274012, 44.45064885275704, 55.667230061122346, 54.33819253104073, 58.977261543273926, 56.261773518153596, 53.65165145056588, 33.27538858141218, 45.63104704448155, 9.619932072503225, 2.2649155855178833, 19.70464825630188, 64.33951296125139, 37.557514735630576, 16.96545992578779, 36.91638708114624, 43.864495345524375, 53.66533245359148, 26.623344796044485, 35.22126286370413, 29.713564804622106, 43.57490485055106, 44.84814487184797, 36.08373580660139, 46.33580977576119, 64.63697229112897, 48.97158111844744, 0.7413134585533823, 0.15367081122738974, 0.1991584146661418, 0.26408254514847485, 0.23800522301878246, 0.10005988154028143, 0.1523649977254016, 0.19565520621836185, 0.14180064174745763, 0.11015932567949806], [0.013665939548185893, 0.08022757180567298, 0.07074365392327309, 0.08851342754704611, 0.015215554075049502, 0.07727865182927676, 0.03366510443655508, 0.022724251429151212, 0.06024589615740946, 0.03926290638212647, 0.04319612621994955, 0.09845499015812363, 0.019420986895316412, 0.060630496591329575, 0.06623328237661294, 2.861864422048841, 60.879191943577354, 51.80424009050642, 34.89714329583304, 27.882313217435563, 31.231391838618688, 23.745717082704815, 47.856964996882844, 11.808315856116158, 19.999581915991648, 12.766640935625349, 29.28479494367327, 12.469307541847229, 51.6645257132394, 72.01909978049142, 6.374776789120265, 3.9918404051235745, 24.89042237826756, 62.206700869968955, 57.67580141339983, 54.187788350241526, 48.04389933177403, 51.99376262937273, 45.58671406337193, 39.38432468686785, 17.555924790246145, 0.14787492794649942, 7.565807461738586, 12.4374908719744, 5.194561421871185, 12.62514955656869, 22.881291696003505, 24.935182673590525, 30.063840866088867, 30.631470475878032, 34.15936619894845, 30.499833379473003, 27.37432173320225, 15.022493464606148, 13.161487085478646, 11.331857902663094, 10.122457930019923, 10.353541118758065, 10.90386884553092, 9.93089348929269, 11.821010214941841, 20.317835467202322, 24.113579034805298, 21.531699657440186, 14.188373514584132, 15.532986300332205, 19.613830089569092, 14.94339690889631, 15.743674789156232, 14.315258043152944, 12.831292186464582, 15.586466584886823, 22.41775131225586, 16.436470985412598, 10.522348472050258, 5.836287924221583, 6.1269371509552, 15.252471889768328, 22.28501640047346, 27.84395568711417, 34.842224734170095, 36.12199258804321, 33.8942403112139, 29.422014917646134, 38.98193713596889, 44.068112305232454, 29.370334216526576, 39.08926248550415, 37.51417187282017, 32.72888496943882, 37.07110261917114, 26.775880336761475, 13.865092941692897, 18.935451405388967, 23.209764310291835, 37.97952399935041, 35.716867446899414, 30.999579089028494, 28.716407980237687, 21.338475465774536, 3.700500701154981, 4.977207005023956, 13.518421258245196, 25.844488212040492, 26.42074053628104, 20.32028991835458, 12.99375149181911, 15.474894148962838, 16.173651899610245, 19.074189560753958, 12.847412875720433, 9.28799317564283, 24.312851633344376, 22.437004770551408, 19.612306697028025, 30.335098539079937, 32.82832758767264, 18.351516110556467, 16.89707922935486, 10.201525824410574, 3.383586415222713, 16.956055538994924, 34.43672786440168, 39.06646197182791, 39.347540923527305, 43.29024062837873, 42.55285610471453, 46.89675521850586, 46.63821622303554, 48.83374622889927, 47.13839619500296, 43.82046113695417, 45.24853828975132, 55.918157305036274, 39.19223131452288, 19.250246490750992, 1.74773228594235, 0.06503319820123059, 4.249870445047106, 31.956137589045934, 47.73156043461391, 49.860405104500906, 43.60855150222778, 45.05260951178414, 47.40520354679653, 41.734532015664236, 61.95420333317348, 38.26577935900007, 2.4916826401438033, 7.935656598636082, 40.792787075042725, 53.96115895680019, 9.108337078775678, 24.83113513674055, 32.56014796665737, 39.84717198780605, 37.31626285825457, 17.73012134007045, 27.938553673880442, 25.60907803262983, 42.36740868432181, 21.158727305276052, 38.74528496606009, 34.37251608712332, 60.62061473301479, 10.475534984043666, 0.05479272734373808, 0.10926961699234587, 0.04374704576496567, 0.0059116578943628284, 0.05841035715171269, 0.03320507126461182, 0.0560085331755025, 0.12522308129285062, 0.059988487112734995, 0.0277929623012564, 0.06369798377688442, 0.07658962665924005, 0.025294596362592917, 0.011657344426826706, 0.013062385193604444, 0.04511373742882695, 0.020334842947444746, 0.04497829505375453, 0.022880741960502098, 0.047253975977322886, 0.05044712784833141, 0.04519683082721063, 0.02774237242660352, 0.07229928366307702, 0.1346830129623413, 4.238025937761579, 66.52271338871547, 63.82884120941162, 28.292906590870448, 29.919085570744105, 26.321358714784893, 28.65769396509443, 35.87764181409563, 19.9979247706277, 29.07186392375401, 19.12379969869341, 28.238861765180314, 16.995809657233103, 60.82442624228341, 61.56906468527657, 11.612054433141436, 2.583424048764365, 25.84635901451111, 64.24387100764683, 61.55214582170759, 57.199554511478965, 54.689708845955984, 54.20378310339791, 50.57519408634731, 43.93683998925345, 19.77800907407488, 1.8823762152876173, 13.427286079951696, 17.85403551374163, 8.261264818055288, 12.389794094221932, 26.804510389055523, 29.654421738215856, 33.34578078133719, 32.45337152481079, 34.45802409308297, 34.42832401820591, 30.81271423612322, 18.57153950418745, 17.041030270712717, 14.842707089015416, 12.977268627711705, 13.799738185746328, 13.09115047114236, 13.377180014337812, 15.457044226782662, 25.00354426247733, 27.576891251972743, 25.164751155035837, 21.358828476497106, 19.86954116821289, 21.596071243286133, 19.56858515739441, 18.427991458347865, 16.186188186917985, 16.474632229123795, 18.278315101351055, 25.807765245437622, 19.17194550377982, 11.033710701125008, 5.125758188111441, 1.014490191425596, 1.8661215560776847, 10.120565414428711, 16.8947012083871, 27.099018471581594, 29.61683545793806, 28.23140287399292, 34.290669781821116, 46.23168407167707, 44.39632436207363, 35.41828598294939, 43.846582889556885, 37.21976280212402, 36.181385789598735, 41.65476669584002, 30.36071307318551, 19.045271158218384, 23.635520390101842, 21.86594101360866, 33.06257568086897, 35.977313722882954, 34.027857644217356, 34.308564867292134, 37.4764084134783, 24.295984881264822, 22.813725675855363, 28.90620149884905, 33.379510811397004, 28.353613001959665, 21.24398343903678, 16.47518982206072, 19.427519355501445, 20.789041451045446, 22.87085723876953, 19.306123903819493, 14.972968442099434, 24.505669355392456, 23.95929949624198, 19.93869832583836, 36.51558024542672, 32.59128284454346, 23.17063900402614, 20.826862233025686, 15.574404512132917, 7.009420471532004, 22.01011266027178, 39.681718008858816, 42.5860024860927, 40.493882519858225, 45.97402054922921, 44.63773604801723, 48.737902777535574, 48.690345832279746, 49.296954836164204, 50.35037817273821, 45.62022869927542, 46.82836757387434, 56.431389468056814, 33.62526164736067, 15.676737580980573, 3.247028474296842, 0.23612283117004804, 6.571158937045506, 34.90733977726528, 50.68131739752633, 51.20729603086199, 48.909707409994944, 50.03152533939907, 51.78040082114083, 45.90387501035418, 60.49368504115513, 37.295644078935894, 3.4940115298543657, 11.110041873795645, 45.93977287837437, 49.90922662190029, 12.606225269181387, 18.392925637108938, 27.18622010094779, 37.83604369844709, 45.66064289637974, 22.97666961806161, 31.625135830470494, 24.614789077213832, 36.88416133608137, 23.72830663408552, 37.90665129252842, 43.17550502504621, 64.37319087982178, 12.602941376822335, 0.36846845384155, 0.126884609993015, 0.07476503242339406, 0.0871086564979383, 0.06945311424455472, 0.028110353841579387, 0.0649681809757437, 0.09121147277099745, 0.07996962671833378, 0.03179058698671205, 0.0758035166987351, 0.17443816257374628, 0.13107081821986608, 0.13014537787863187, 0.057429365148501735, 0.15160691126116685, 0.14716944151691028, 0.11511930131486484, 0.10317558542426143, 0.320078294724226, 0.19419961289635726, 0.13826850056648254, 0.15886354473020348, 0.17692635048713, 0.22358430469674723, 7.349603840282985, 81.44861125946045, 71.4327551977975, 48.151429653167725, 39.251336165836875, 38.31339536394392, 32.96086794989449, 67.18117332458496, 22.61841528756278, 42.73932491030012, 23.17505805832999, 37.08203213555472, 14.729890925543648, 58.0542003086635, 75.24828897203717, 10.845032368387495, 6.295892587729862, 32.41714014325823, 72.71540655408586, 66.35899993351528, 61.16035079956055, 58.753953388759065, 60.28548921857561, 57.424078600747244, 49.96090037482125, 21.711772646222794, 0.9453441074916294, 12.579017860548836, 21.341774123055593, 11.056241972105843, 22.17426906313215, 36.63997037070138, 41.219239711761475, 45.62291765213013, 44.46207863943917, 45.94995893750872, 42.43622364316668, 40.155154364449636, 26.220865181514196, 26.398775543485367, 19.830052818570817, 18.554307971681865, 18.754964998790197, 17.555339404514857, 18.429323775427683, 20.414278200694493, 29.544466495513916, 35.19468252999442, 28.771027769361222, 25.218168905803136, 23.69260678972517, 29.2428069795881, 23.33103816849845, 24.29533348764692, 19.364283800125122, 22.327825989042008, 21.30625319480896, 25.982154607772827, 26.342509031295776, 19.429272038596018, 14.920341048921857, 20.091008050101145, 33.69412176949637, 35.7530015536717, 38.53694323131016, 41.14006846291678, 42.857444286346436, 37.1905734198434, 34.696607862200054, 47.892991406576975, 46.93620709010533, 38.27368988309588, 45.10520390101841, 46.264392716544016, 38.363102776663645, 44.94795227050781, 41.951607636043, 34.72990710394723, 40.92971175057547, 39.523719446999685, 45.33034985406058, 39.61449418749128, 33.97429050718035, 43.72809525898525, 38.80118669782366, 19.543540375573293, 17.828751019069127, 27.212854283196585, 35.76713766370501, 32.615924630846294, 21.03379695756095, 21.313164915357316, 23.384834596088954, 25.427334002086095, 26.846640791211808, 22.31831737927028, 18.060483864375524, 30.44990709849766, 31.412739821842738, 23.831315415246145, 40.40082877022879, 37.44126442500523, 23.776843275342667, 24.291487659726823, 20.36880918911525, 9.485195211001805, 30.465752465384348, 44.34214925765991, 46.17595951897757, 43.78282274518694, 48.95113256999424, 47.08589908054897, 51.803190912519185, 50.87961551121303, 53.43539571762085, 52.21370785576956, 47.19620868137905, 45.835424831935335, 56.529310430799214, 43.01046446391514, 26.645801373890468, 4.174728282860347, 0.20067431618060383, 6.441826905523028, 35.44860792160034, 54.993126256125315, 59.39368792942592, 53.48315416063581, 54.699853215898784, 56.39257335662842, 51.38727869306292, 71.38131073543003, 44.62945032119751, 4.5155565312930515, 10.310370223862783, 46.57601594924927, 62.287591797964915, 12.82188606262207, 32.51924392155239, 41.12598099027361, 41.736512252262656, 45.25538573946272, 22.296109199523926, 43.599112374441965, 33.15987825393677, 56.746452059064595, 32.80588490622384, 52.22512027195522, 49.045471736363, 73.31791264670235, 22.94660997390747, 0.4589773171714374, 0.1724679275814976, 0.21819589526525565, 0.20775123286460126, 0.2785293427961213, 0.1426104868629149, 0.12435248015182358, 0.22396359220147133, 0.19423831653382095, 0.08810038971049444], [0.03657284751534462, 0.017486877107460583, 0.10006619191595487, 0.0574847064646227, 0.08443339647991316, 0.08407238192324128, 0.05411636024447424, 0.07059166886444602, 0.042457048914262226, 0.04843817225524357, 0.018245674337127378, 0.11477113142609596, 0.0388771761874003, 0.1115814061569316, 0.05449909131441798, 0.33592276594468523, 28.302271025521414, 59.81298392159598, 49.6256810597011, 37.03775126593453, 51.45184482846941, 25.562389612197876, 35.996171133858816, 30.42444542476109, 14.291886908667427, 19.19056841305324, 19.252872909818375, 35.43112972804478, 22.531203235898698, 69.29419694628034, 29.467174734388077, 2.80809730717114, 8.533942529133387, 46.682267802102224, 58.16700431278774, 56.32196923664638, 52.52540751865932, 56.65522915976388, 47.27544593811035, 46.307231834956575, 32.20585584640503, 9.972111940383911, 6.72185537644795, 22.2046274798257, 20.5003924369812, 2.3364685688699995, 8.037230576787676, 3.0303617119789124, 3.549298346042633, 1.5693802790982383, 2.8109758155686513, 4.494930803775787, 5.1371957915169855, 3.1641846682344164, 2.811126070363181, 6.67482909985951, 6.036489844322205, 7.311512078557696, 6.077997948442187, 11.358702267919268, 25.0804260798863, 30.829626151493617, 24.650871072496685, 12.699426668030874, 8.002637233052935, 16.618934154510498, 25.327795846121653, 14.53999492100307, 19.8341018812997, 18.528078522000992, 16.086233139038086, 12.638879196984426, 15.144892930984497, 16.01070622035435, 13.76687581198556, 12.870632018361773, 10.223305821418762, 5.469469938959394, 9.091643163136073, 19.951500381742203, 26.619700465883525, 33.32820878710066, 42.46491622924805, 39.638899735042024, 45.11595971243722, 45.34267248426165, 39.03863443647112, 43.249517236437114, 35.52702529089791, 37.574586459568565, 40.832593304770334, 31.365467752729142, 23.663261072976248, 26.34525009563991, 35.21564524514334, 41.279404163360596, 37.936855111803325, 35.53821883882795, 18.832944631576538, 4.607513768332345, 3.465417955602918, 1.1943684135164534, 10.041978682790484, 19.550773450306483, 24.172824587140763, 18.835859400885447, 13.563423871994019, 16.07976610319955, 13.819306918552943, 17.26332572528294, 19.837612458637782, 6.692443651812417, 14.489588345800128, 28.393354960850306, 19.369086742401123, 16.71389865875244, 27.857654060636246, 23.408274344035558, 14.814269849232264, 14.685660430363246, 3.4158204112734114, 1.9524144913469041, 8.431830065590994, 24.384445871625626, 41.72676740373884, 43.4113199370248, 46.532607078552246, 47.74118021556309, 42.329544476100374, 44.400753838675364, 41.90358863558088, 48.61986330577305, 36.959976605006624, 17.17913614000593, 3.4376896492072513, 6.9212169987814764, 3.4119578642504553, 3.4119487447398047, 21.212970154626028, 43.40041821343558, 48.46497753688267, 47.90953506742205, 44.038693632398335, 37.37996046883719, 41.34854916163853, 51.21373006275722, 51.32560648236956, 30.85261079243251, 3.6382298597267697, 18.061970778873988, 73.39277948651994, 61.15848868233817, 37.829460280282156, 32.16020270756313, 43.4989401953561, 41.85810225350516, 36.52556133270264, 23.926106214523315, 20.29087471961975, 34.330114705221995, 29.76018374306815, 25.196139642170497, 43.65508706229073, 41.89729356765747, 48.97226204190935, 1.7193800530263355, 0.1567287514252322, 0.11880977185709135, 0.030765826082123176, 0.06064206561339753, 0.017388452210330536, 0.020347974296393137, 0.049495926925114224, 0.13105378699089798, 0.08771078168813672, 0.10941276752523013, 0.018947410164400935, 0.047504409682005644, 0.05744437434311424, 0.028055221174976656, 0.09423223603516817, 0.05875917843409947, 0.011659091654499727, 0.03162140106516225, 0.031246289943477938, 0.09853137963052307, 0.0372904118682657, 0.08927218576094934, 0.033892413667802296, 0.07896548988563673, 0.049111655580678155, 0.19633193633386067, 32.48106704439436, 72.61262880052838, 46.009949684143066, 34.12862736838204, 48.015873772757395, 26.072757380349294, 36.33885281426566, 25.019228083746775, 28.160678897585186, 19.04453812326704, 24.98358382497515, 28.13267765726362, 30.329866545540945, 60.21661172594343, 32.98095519202096, 3.2622838956969122, 8.620895760399954, 48.52716391427176, 59.847961153302876, 57.532995087759836, 55.68530232565743, 60.82928998129708, 52.753655842372346, 53.38349267414638, 36.95653029850551, 8.726844498089381, 9.4241726568767, 30.320316246577672, 27.20809476716178, 4.125269268240247, 12.284050328390938, 4.952759768281664, 3.3241143950394223, 2.98365809236254, 4.555221191474369, 5.8646074788911005, 6.8230593630245755, 5.614448010921478, 4.603491195610591, 9.541367053985596, 10.322189978190831, 9.757851208959307, 8.206392288208008, 13.6039422920772, 30.385952404567174, 34.078492641448975, 27.929265669413976, 19.419037342071533, 9.825630017689296, 20.36699570928301, 27.477405207497732, 15.436691216060094, 24.041564430509293, 20.66064395223345, 21.031860147203716, 15.234076533998762, 18.567598138536724, 20.950474160058157, 16.760310888290405, 11.863454154559545, 8.573170321328298, 13.096430233546666, 24.531141451426915, 34.760632038116455, 45.36846072333199, 46.97491897855486, 43.29929413114275, 38.428454058510916, 46.076965059552876, 49.15320702961513, 36.9209520476205, 42.44111517497471, 42.32751907621111, 40.1399621282305, 45.658749512263704, 35.19784048625401, 24.694714205605642, 28.72137073108128, 33.745500223977224, 43.82156590053013, 43.362675598689485, 39.84939888545445, 33.59524890354702, 14.495781796319143, 7.249430792672293, 6.01676173721041, 17.698854446411133, 30.53038113457816, 29.93363162449428, 18.017846243722097, 14.08745527267456, 19.941239629473003, 15.79531727518354, 23.69360559327262, 20.68670490809849, 13.888594354901995, 18.30542697225298, 31.129590306963237, 21.537119252341135, 21.049532890319824, 31.421696049826487, 28.733370270047867, 15.582092693873815, 18.864093405859812, 6.394814091069358, 4.347410993916648, 11.447003449712481, 29.61805486679077, 45.37503024509975, 47.2734101159232, 50.43925258091518, 50.594492707933696, 47.544650418417795, 45.02471249444144, 43.73499829428536, 46.264305864061626, 33.23213604518345, 10.225015078272138, 3.3823272713593076, 11.329189794404165, 8.879845568111964, 6.872055888175964, 25.296572378703527, 46.50940356935774, 50.86061913626534, 50.18862758363996, 48.90601096834455, 42.48104647227696, 48.91401876722063, 53.91714211872646, 51.99882786614554, 33.336077622004915, 4.630910524300166, 28.14797411646162, 74.06612246377128, 61.98035635266985, 41.605302470070974, 18.920307806559972, 42.39851229531424, 41.01596321378435, 45.21844564165388, 27.550894566944667, 24.23915035384042, 32.188787596566335, 33.880173683166504, 26.176394973482402, 43.957166944231304, 50.613287585122244, 52.4886793409075, 2.1705127997057776, 0.26281973719596863, 0.03902360065174954, 0.023304161382839084, 0.0034377223970035887, 0.02999719518369862, 0.02833227889745363, 0.044471873835261376, 0.031835061564509354, 0.06289540577147688, 0.04333669153441276, 0.11386281730873243, 0.09111329553914921, 0.18991010449826717, 0.07989837375602551, 0.19620613594140324, 0.172567237966827, 0.11585177986749581, 0.2917133596326624, 0.12117675984544413, 0.31149363251669065, 0.15072769272540296, 0.3811953009239265, 0.1199430881866387, 0.24758836307695933, 0.24105436940278324, 0.4277118891477585, 47.193512780325754, 82.11534649985177, 62.010845048086985, 50.137836251940044, 64.79632922581264, 34.59219033377511, 50.46362338747297, 43.38901621954781, 32.28095197677612, 34.09025594166347, 26.486260311944143, 41.07929604394095, 30.878770760127477, 74.2948363167899, 34.998097147260395, 4.986842853682382, 11.09203474862235, 54.86372300556728, 65.77412836892265, 64.30682168688092, 61.03206620897566, 66.66596439906529, 55.710909911564414, 57.37408283778599, 39.53894295011248, 15.463004044124059, 8.512255464281354, 29.940173353467667, 29.658958911895752, 3.6373090062822615, 16.918132271085465, 6.690176802022116, 5.123568637030465, 6.2829815319606235, 6.7862699542726785, 9.215824842453003, 8.81868144444057, 10.533915485654559, 8.347181030682155, 13.868275216647557, 14.646069594791957, 13.13377332687378, 11.547812257494245, 16.63617263521467, 37.740082127707346, 43.238344533102854, 35.96346248899187, 22.631076642445155, 14.636560985020228, 24.649719408580236, 34.1392685345241, 20.85010916846139, 27.529308250972203, 26.97591028894697, 24.300523791994365, 20.047988278525217, 19.0300771849496, 21.265168496540614, 22.401197229112896, 27.904896599905832, 24.47193932533264, 20.67987482888358, 27.827095883233206, 42.71302250453404, 47.84033795765468, 51.17881189073835, 50.056226185389924, 46.916001728602815, 51.57139900752476, 47.98223059517996, 48.014338220868794, 45.283921991075786, 43.64284781047276, 41.263426780700684, 47.27046407972063, 46.25701372964041, 42.135189465114046, 41.74176509039742, 44.85859843662807, 45.49443851198469, 44.21503891263689, 44.4746618270874, 36.67711891446795, 10.712346962520055, 6.720094008105142, 5.71214359147208, 20.96156174795968, 34.89326967511858, 31.836903027125768, 20.191147225243704, 18.798441614423478, 25.410660062517437, 20.3929819720132, 27.888045481273107, 28.093031236103602, 17.911583968571254, 25.088901145117624, 38.435784408024375, 27.068910190037318, 24.313539505004883, 36.95181941986084, 34.978826318468364, 20.116653851100377, 22.69668674468994, 9.01645931175777, 4.721242317131587, 17.72419105257307, 37.23863410949707, 50.096602167402, 51.39053392410278, 52.20469951629639, 50.90981585638863, 49.12268359320504, 48.86891106196812, 44.520832606724326, 52.06324461528233, 43.298137256077354, 21.212581055504934, 6.256219242300306, 10.755403212138585, 6.530515015125275, 6.229216805526188, 25.67506160054888, 49.57524061203003, 54.86093330383301, 56.12229190553938, 53.897412708827424, 48.235843317849294, 51.679328850337434, 57.69507571629116, 59.29370335170201, 36.600455965314595, 5.49769048179899, 22.635632923671178, 78.42561680930001, 69.03557109832764, 41.69867236273629, 42.65941367830549, 49.52627318246024, 45.89000640596662, 43.57752432141985, 34.282523018973215, 31.014670576368058, 40.865017073495046, 45.233353001730784, 34.708579608372276, 57.97116238730294, 54.51874147142683, 66.8136066709246, 5.601528704166412, 0.4389608869595187, 0.2969193517097405, 0.14658394722001894, 0.36805281043052673, 0.12025296155895505, 0.12609474094850676, 0.1419605995927538, 0.32458004887614933, 0.18953988222139223, 0.17824631822960718], [0.028035586067874516, 0.02112497662061027, 0.06213313274617706, 0.023484590629647886, 0.03802518726193479, 0.09265728840338332, 0.11013116647622415, 0.03789483389950224, 0.12939037196338177, 0.046144483012280295, 0.11124340072274208, 0.07078209293207952, 0.06424438088600125, 0.16441462614706584, 0.04733216356752174, 0.11329871043562889, 3.799599817820958, 59.752680506025044, 53.30956384113857, 27.471575668879918, 30.236388955797466, 35.63010876519339, 24.347231319972447, 46.3136693409511, 15.425127676555089, 24.43384756360735, 16.124152932848247, 35.39486707959856, 39.98070246832711, 55.317370891571045, 64.18142059871128, 13.321894935199193, 4.037196508475712, 37.07772077832903, 57.243296895708355, 62.692845480782644, 54.56584678377424, 52.06577375956944, 53.57164294379098, 33.89350380216326, 35.07323496682303, 29.113002470561437, 9.26107324872698, 1.728897130915097, 4.578786441258021, 12.300206627164568, 8.106703877449036, 6.456093728542328, 4.44425585440227, 12.704888820648193, 15.118613106863839, 16.103442089898245, 15.420564447130475, 8.71969827583858, 17.620615993227275, 20.109943628311157, 10.030483756746564, 4.4797720057623724, 7.409109081540789, 22.65484642982483, 28.4848609992436, 24.543781961713517, 7.359633564949036, 11.771631104605538, 19.419933659689768, 22.513667719704763, 28.66335674694606, 10.032203435897827, 15.800302607672554, 24.849507910864695, 15.862994466509138, 13.841994524002075, 10.980635149138314, 15.121451445988246, 22.834738765444072, 20.190370764051163, 15.246169873646327, 2.7730412568364824, 2.8692180046013425, 16.791555200304302, 25.33796627180917, 27.788154704230173, 40.28063883100237, 42.142974921635215, 51.63546139853341, 42.43395505632673, 38.67900262560163, 41.014917509896414, 32.83314963749477, 38.32257740838187, 43.481948375701904, 39.86329875673567, 36.600000858306885, 34.60803917476109, 42.506049564906526, 39.21438911982945, 47.350472586495535, 30.605067321232386, 10.090631706374031, 5.354559762137277, 3.0543377740042548, 1.593929784638541, 8.116460016795568, 23.68984661783491, 25.501179456710815, 19.651213135038102, 14.450765286173139, 12.447260039193289, 14.406713707106453, 18.881205081939697, 21.910484177725657, 16.379158769335064, 13.462781820978437, 23.422898565019878, 22.38706633022853, 9.18253515447889, 15.380376066480364, 27.125835044043406, 19.494333233152116, 14.050544704709734, 7.181618545736585, 3.2907020279339383, 2.2912442641598836, 0.6214799944843564, 8.248271686690194, 17.762421778270177, 23.25907220159258, 29.233809062412806, 38.55953529902867, 32.17056247166225, 25.330483061926707, 10.317299314907618, 6.297683920179095, 3.033247168575014, 25.064648457935878, 26.431494610650198, 2.4726170003414154, 13.450137836592537, 38.821128027779714, 49.983381271362305, 43.861872400556294, 47.33924082347325, 50.01450572695051, 48.849063532693044, 48.30185815266201, 47.64637204578945, 50.500403676714214, 29.464808872767858, 2.538302229983466, 14.718306541442871, 26.365330389567784, 33.403145108904155, 19.03653727258955, 27.042925664356776, 41.731797899518696, 41.7354040145874, 30.325763634272985, 24.558644158499582, 23.140636682510376, 29.98163672855922, 24.732844182423182, 29.94536713191441, 38.158839634486604, 53.73874364580427, 29.22538784572056, 0.15137346807335103, 0.15562702768615314, 0.030335787550679276, 0.09657930902072362, 0.10007206124386617, 0.10328682445521865, 0.10316253041050263, 0.08501165759350572, 0.047791440172919204, 0.04782089537807873, 0.03711477307868855, 0.06779100878962449, 0.08747309087110416, 0.04030860348471573, 0.054655273112335374, 0.037393349023269754, 0.05570559443107673, 0.07620404913489308, 0.1050238741029586, 0.04990993845941765, 0.08542310765811376, 0.03182923634137426, 0.13197945803403854, 0.050253250037453005, 0.10585335602185555, 0.056270335734422715, 0.3591453012611185, 5.643410273960658, 72.40760135650635, 60.12629209245954, 27.740469217300415, 36.34776735305786, 28.25345298222133, 29.363462448120117, 35.996504647391184, 24.345270190920147, 29.565818309783936, 19.911784478596278, 36.664494037628174, 38.20020573479788, 54.79149300711495, 60.985311780657085, 18.825162649154663, 4.255516724927085, 40.07126528876168, 61.571135248456685, 69.12588378361293, 59.04541642325265, 56.2520877293178, 56.191926751817974, 39.12870740890503, 40.60539068494524, 29.902239663260325, 7.208084234169551, 2.522569554192679, 4.213298601763589, 9.284909043993268, 13.117775968142919, 9.15349428994315, 13.657690950802394, 21.613153389522008, 20.658304146357946, 23.400143214634486, 21.761236871991837, 11.958567176546369, 23.617140667779104, 26.073248965399607, 15.132971559252058, 5.511837448392596, 11.475696904318673, 28.001122202192033, 32.31345564978463, 28.855387585503713, 14.44364425114223, 12.149539283343724, 19.279496669769287, 25.24988569532122, 31.77592216219221, 14.550070677484785, 20.305679593767437, 27.786706004823955, 19.769898789269583, 18.892113753727504, 14.123254128864833, 19.989713736942836, 26.23170610836574, 24.531749418803624, 17.71872455733163, 16.77022075653076, 24.072791372026714, 30.52976621900286, 38.121701513017925, 40.93920646395002, 44.33820615495954, 45.682213578905376, 50.867553438459126, 51.528792653764995, 43.81841836656843, 48.95800086430141, 42.67412648882185, 42.4099976675851, 48.45521184376308, 40.35924727576119, 33.900882789066856, 37.44724334989275, 45.30398491450718, 48.4341344833374, 41.87501416887556, 38.80487619127546, 26.6932749407632, 7.323717457907541, 5.026999533176422, 4.902896021093641, 14.62430088860648, 29.279389245169504, 29.829259259360178, 17.922202553067887, 15.166131837027413, 17.80243992805481, 18.491385085242136, 27.670985494341167, 23.755411556788854, 20.50634183202471, 17.38323426246643, 25.82693706239973, 24.429649114608765, 11.981541395187378, 19.126026596341813, 28.251795836857386, 21.074482134410314, 15.581170320510864, 11.440764835902623, 8.388983130455017, 5.197260362761361, 1.8863349514348167, 9.394473450524465, 16.729518209184917, 23.60575430733817, 26.218276977539062, 38.08192307608468, 31.34417847224644, 23.102353845323833, 8.025466408048358, 7.1711949450629096, 7.015028102057321, 35.00508008684431, 35.14717769622803, 4.1711395382881165, 15.489125796726771, 42.0754280090332, 52.746221269880024, 48.43342229298183, 49.51346417835781, 53.08838530949184, 52.0281457901001, 51.89105783190046, 51.56447165352957, 55.888752528599326, 29.32044267654419, 3.8473656432969228, 17.34068696839469, 28.652291740689957, 46.27812235695975, 20.803144557135447, 24.51038544518607, 43.13437516348702, 47.65747874123709, 40.170047828129356, 25.344085897718156, 27.641914231436594, 26.111816678728374, 28.63341348511832, 29.765009266989573, 43.18982526234218, 61.15936415536063, 34.379842962537495, 0.10978191093142543, 0.15377597058457987, 0.042891477567276785, 0.17817153009985173, 0.12108278274536133, 0.03468787044818912, 0.08209441163178001, 0.03628426996458854, 0.09005412273108959, 0.03218421532905527, 0.0373620482028595, 0.11684739430035863, 0.13091076537966728, 0.18774088232644967, 0.18584031930991582, 0.1665327546319791, 0.25580061812485966, 0.20300337406141417, 0.18335278279014997, 0.2590592961226191, 0.2215655544506652, 0.1970926962260689, 0.2654336169362068, 0.3386644273996353, 0.23612766233938082, 0.19760907494596072, 0.43886828050017357, 11.425549149513245, 85.14806147984096, 69.97810118538993, 42.13866703850882, 40.78605079650879, 44.452378954206196, 36.381803103855674, 61.887062890189036, 26.33279718671526, 44.36788191114153, 23.914389814649308, 42.78706250871931, 42.34231526511056, 63.98348726545061, 69.39047813415527, 18.4104003565652, 5.706056535243988, 45.03699343545096, 64.02465534210205, 71.09747682298932, 62.29814611162458, 61.823014395577566, 61.507385526384624, 43.24728339059012, 42.079690728868755, 34.62495803833008, 14.34939454283033, 3.2243232812200273, 7.543870261737278, 15.94224214553833, 17.329185962677002, 10.09411883354187, 19.31816339492798, 25.0916074684688, 25.129030466079712, 28.661571059908184, 22.97616239956447, 16.150840963636124, 26.23401117324829, 35.61863381522042, 20.568764448165894, 7.659300684928894, 17.102672951562063, 32.465937341962544, 38.738840511866975, 36.55306230272566, 13.974939618791852, 19.617993797574723, 27.27529600688389, 32.468716621398926, 40.26769781112671, 18.78619020325797, 24.06763580867222, 33.73347636631557, 24.866732495171682, 20.38702389172145, 17.602793863841466, 19.86279273033142, 32.09360769816807, 33.12003033501761, 26.042273896081106, 22.92033883503505, 32.76809712818691, 38.85565710067749, 46.20454788208008, 48.65769624710083, 49.0948942729405, 50.75547899518694, 55.89218841280256, 47.281775747026714, 44.753409658159526, 45.97986051014492, 43.606307234082905, 40.090306827000205, 48.013504437037874, 50.09824889046805, 44.336594172886436, 42.502745696476524, 45.24803107125418, 44.38323743002755, 44.49336290359497, 41.86818756375994, 31.06897074835641, 12.262490936688014, 10.314457501683917, 11.215425201824733, 24.037720339638845, 37.59641769954136, 32.3173952783857, 21.48840022087097, 19.661487783704484, 20.084702559879847, 22.105591331209453, 30.080836159842356, 31.190074375697545, 25.59105440548488, 23.036479711532593, 31.212388515472412, 30.772185393742152, 15.634318828582764, 21.689309120178223, 35.89443908418928, 25.530414002282278, 20.446823562894547, 15.004233598709106, 9.778287598064967, 5.464353024959564, 4.635965773037501, 15.126105001994542, 23.821855442864553, 31.187552179609025, 34.74339355741228, 44.788876737867085, 39.90078428813389, 31.113585131508962, 14.52314293384552, 10.36631625039237, 5.311315042631967, 34.18380648749215, 33.3037302834647, 5.652115498270307, 16.26974027497428, 42.07540021623884, 54.97264296667916, 50.972846439906526, 55.15486642292568, 58.57258456093924, 57.14314556121826, 57.37157106399536, 56.222884450639995, 60.35514490944998, 34.34903464998518, 4.676592758723667, 21.063041925430298, 33.2846679006304, 59.7417231968471, 22.793754816055298, 35.17223637444632, 45.705451829092844, 50.657099451337544, 35.65904801232474, 35.795409883771626, 33.66699252809797, 38.23336948667254, 38.33099167687552, 40.32070214407784, 52.83771167482649, 65.73243917737688, 49.33134841918945, 0.1304728795907327, 0.2243413869291544, 0.286697655916214, 0.2592277627970491, 0.28449646117431776, 0.1565051877072879, 0.1584451871791056, 0.15497590548225812, 0.14315718252743992, 0.16096502196575913, 0.23179722470896585], [0.06495351783399071, 0.03837141314787524, 0.04252485152600067, 0.07178121539098875, 0.04189025164980974, 0.05497831006401351, 0.040219712004597695, 0.02873610731746469, 0.017119692971131632, 0.02912820895601596, 0.046381753137601275, 0.01192731230652758, 0.11564082333019801, 0.04051870846056512, 0.023846312559076717, 0.023632865798260485, 0.12555620127490588, 41.23094047818865, 62.8063234601702, 35.781475271497456, 31.663250173841202, 42.1243884904044, 22.944984095437185, 40.211570262908936, 29.649571895599365, 18.037295988627843, 21.411770275660924, 15.244359867913381, 51.22985683168684, 49.36300093787057, 58.84353651319231, 32.330225127083914, 3.9933347020830428, 13.713933144296918, 45.64032983779907, 42.04166671207973, 47.83500868933541, 53.59454073224749, 53.6328044618879, 38.78430257524763, 49.08972481318882, 29.82273142678397, 23.654523713248118, 14.320413606507437, 2.9892874360084534, 1.3042496144771576, 2.2177955082484653, 8.311845098223005, 38.0504720551627, 6.167390865939004, 24.301008428846085, 8.851071340697152, 3.3602072468825748, 5.028690116746085, 7.609204173088074, 8.306519304003034, 1.2323062292167117, 2.9335652717522214, 10.874255623136248, 26.98839099066598, 28.826264211109706, 10.227372254644122, 3.6326511076518466, 20.860741649355205, 12.19491102014269, 27.341163192476543, 20.637259789875575, 13.899577719824654, 20.897857189178467, 25.89922785758972, 16.362887825284684, 10.205834576061793, 15.583280835832868, 22.141690696988785, 28.777890852519445, 24.562081779752457, 15.614009244101387, 2.2922550099236623, 6.509543180465698, 16.180502823420934, 27.332531792776926, 29.18367780957903, 37.414513860430034, 34.69742774963379, 49.40818854740688, 42.89410645621163, 31.96178994859968, 34.89503451756069, 30.232755047934397, 35.19675656727382, 43.15776974814278, 48.099259104047505, 42.36070714678083, 40.569701262882774, 40.45793948854719, 43.360834326062886, 47.137173312050955, 30.402805260249547, 15.20118202481951, 6.556914261409214, 7.053718277386256, 2.0491959495203833, 12.714743971824646, 26.277286291122437, 33.76462166649954, 22.204677854265483, 17.671381269182476, 7.996667861938477, 13.223854984555926, 16.70140927178519, 19.240383522851126, 27.015897171837942, 22.222731011254446, 17.212841851370676, 18.900283098220825, 13.7113345180239, 8.058535490717206, 12.538722651345388, 18.253284215927124, 16.90916735785348, 11.47943069253649, 2.516604308571134, 2.1543777797903334, 3.702424917902265, 2.4927313838686262, 2.967827490397862, 7.634568572044373, 4.726233295031956, 7.375133258955819, 10.058099372046334, 4.537719547748566, 10.340183206966945, 17.03022234780448, 22.614430495670863, 27.548466171537125, 10.007146494729177, 13.046523928642273, 23.532832963126047, 39.51646205357143, 49.522284916469026, 46.07390090397426, 47.271846771240234, 48.35569279534476, 48.952661173684255, 47.39696993146624, 47.71330056871687, 48.79355090005057, 15.283301046916417, 2.3431751004287174, 22.403179202760967, 21.549822296415055, 12.897323523248945, 18.654857090541295, 31.948334762028285, 37.30622271129063, 39.657868317195344, 18.99543867792402, 29.880154814038956, 18.043380873543875, 40.39769165856497, 21.450666291373118, 36.51247092655727, 39.63567577089582, 53.09970045089722, 8.245843291282654, 0.09681728482246399, 0.1747872145580394, 0.008042176004632242, 0.03165551780589989, 0.06396500087742295, 0.07039136532694101, 0.016881311744717614, 0.01574652808319245, 0.02610912167334131, 0.041412620672157834, 0.06197679149253028, 0.03875854791009, 0.08905546846134321, 0.04477385584531086, 0.005299327961568321, 0.08854834495910577, 0.06674633627491337, 0.08702330357794251, 0.09168953461838619, 0.09814762736537627, 0.05373961724607008, 0.058976730331778526, 0.004647813055531255, 0.08399067273629562, 0.05714406152921064, 0.015426376601681113, 0.04498577929501023, 0.665906504860946, 46.22144590105329, 73.4575366973877, 35.03348432268415, 32.903520992824006, 32.5642717225211, 25.411987168448313, 37.37163305282593, 30.428131444113596, 30.300208159855433, 23.168596233640397, 22.78977870941162, 45.459079129355295, 60.039974621364046, 65.81001581464494, 41.227146761757986, 6.417941170079367, 14.284441913877215, 47.20968471254621, 52.55246032987322, 50.42345585141863, 58.485002517700195, 57.003542355128694, 44.101779801504954, 52.50089079993111, 37.60521411895752, 20.113056421279907, 8.547492384910583, 2.6052118624959673, 1.0747797105993544, 3.1729072630405426, 14.159997940063477, 39.58580160140991, 11.439819880894252, 27.709103311811173, 11.578630992344447, 5.336165274892535, 6.187994880335672, 8.782285911696297, 9.809623973710195, 1.4802173035485404, 2.6968457911695753, 12.842285973685128, 30.061624390738352, 28.651023694447108, 16.995469195502146, 4.79443724666323, 17.763029745646886, 17.847092526299612, 27.968985046659196, 26.721173695155553, 16.076225996017456, 20.934427295412334, 30.414634568350657, 18.59799303327288, 15.375210080827985, 16.645392894744873, 20.98927811213902, 31.184574876512798, 32.78550583975655, 21.328815732683452, 8.38796956198556, 14.032499364444188, 25.785709926060267, 36.57753038406372, 39.621338163103374, 45.70200899669102, 46.353840351104736, 55.10489845275879, 46.7593754359654, 44.079451765332905, 43.703095640454976, 39.570334911346436, 40.826711654663086, 50.50094911030361, 48.53797878537859, 46.66477223805019, 42.77573347091675, 48.81129659925188, 46.20253985268729, 49.55377067838396, 37.370952129364014, 21.165322882788523, 8.837058561188833, 8.993871586663381, 6.624274875436511, 16.123972279684885, 33.978136335100444, 35.84889711652483, 21.53435386930193, 18.226403372628347, 13.225586823054723, 15.636332069124494, 21.3752019064767, 23.24831986427307, 28.964017459324428, 24.88959206853594, 21.183237075805664, 23.603791441236222, 14.72870625768389, 11.481104339872088, 18.83697111266, 18.250777653285436, 17.912990978785924, 11.730522956166949, 4.789498380252293, 8.935360806328909, 8.705160907336644, 5.681018267359052, 4.686382336275918, 11.960277301924569, 7.7798684324537, 9.314288633210317, 13.15640013558524, 9.539461510522024, 15.640791075570242, 21.250716243471416, 24.0986647265298, 31.435686247689382, 12.948997276169912, 12.21775496006012, 24.68215881075178, 44.43550525392805, 52.18977131162371, 49.67753546578543, 49.326220648629324, 51.39314297267369, 49.997076170785085, 52.22315045765468, 51.589634554726736, 53.816292490277974, 18.637924330575125, 4.47706481388637, 23.134949581963674, 25.907447576522827, 23.01459809712001, 15.080941711153303, 34.21410410744803, 38.46564776556832, 50.65809999193464, 27.660344328199113, 28.58764570099967, 23.503839867455618, 34.33162593841553, 28.374738999775477, 33.40927342006138, 48.534355299813406, 57.86267668860299, 9.251019205365862, 0.061828999780118465, 0.2366292897079672, 0.031532095678682835, 0.20906315318175725, 0.0820613262642707, 0.061064759003264565, 0.07828367075749806, 0.06036925382379975, 0.006759729128264422, 0.061138556471892765, 0.04563698970845767, 0.1327046084084681, 0.17034983980868543, 0.11583599714296204, 0.12942317234618322, 0.0956373531371355, 0.11248060754899468, 0.23429863048451288, 0.17510520320917877, 0.26840912869998385, 0.17817728407680988, 0.1499025941427265, 0.17644084511058672, 0.2377569606261594, 0.21374467840152128, 0.09020993472742182, 0.1238074672541448, 1.3393006707940782, 63.363263266427175, 80.19509369986397, 48.76923220498221, 43.35540778296334, 52.900429589407786, 33.08766562598092, 55.05745267868042, 41.00837925502232, 34.58439098085676, 34.21669578552246, 20.51358359200614, 52.51338366099766, 59.71447236197335, 63.97456577845982, 40.017187459128245, 5.440391293593815, 18.665265492030553, 52.56473432268415, 53.42454263142177, 54.05629716600691, 63.20021683829171, 61.13910320826939, 48.27522223336356, 59.151077679225374, 38.46742303030831, 29.896503925323486, 20.271112305777415, 6.90159615448543, 2.954500194106783, 6.109121969767979, 19.259371212550572, 46.658532755715505, 18.825767142432078, 32.90535879135132, 13.371095129421779, 7.102061237607684, 9.98717302935464, 13.197127870150975, 14.594413212367467, 3.4260598846844266, 4.924132321562086, 19.054095370428904, 34.12267623628889, 36.21014438356672, 19.16890914099557, 8.824096696717397, 30.889769758496964, 21.480640820094518, 35.41931779044015, 32.155807971954346, 22.331293140138897, 28.339893783841813, 36.057850292750764, 25.088546786989482, 17.785164969308035, 22.437600578580582, 24.578919001988, 35.66057314191546, 42.008989334106445, 37.13610996518816, 30.591424533299037, 37.8762320790972, 43.61097642353603, 48.88223423276629, 50.96965374265398, 52.16561589922224, 47.576170921325684, 55.116435936519075, 45.381499017987935, 42.27020338603428, 42.80762570244925, 43.12920570373535, 38.210996287209646, 47.7539301599775, 51.44560882023403, 46.2691696030753, 43.062298025403706, 43.74736956187657, 47.198470320020405, 47.03507995605469, 40.494466168539866, 37.122967447553364, 27.42794966697693, 19.519650731767925, 22.584537608282908, 33.279585293361116, 41.8875105040414, 37.7165972164699, 26.158484254564556, 22.94052161489214, 14.210037997790746, 19.340600865227835, 27.24988991873605, 27.4903792313167, 33.40451390402657, 30.756419931139263, 25.52577781677246, 27.145703417914255, 18.794632264545985, 15.232144934790474, 21.820595332554408, 22.7007931300572, 21.69697298322405, 15.49797259058271, 8.298716476985387, 8.31158627782549, 7.0162844232150485, 6.2045745849609375, 6.072742938995361, 13.534310051373073, 10.511216589382716, 11.912458062171936, 18.413188321249827, 12.966808983257838, 17.245458432606288, 23.330739395959036, 35.323363167899, 38.717606816973, 12.094184722219195, 20.69897542681013, 26.508994817733765, 45.96844809395926, 55.79930141993931, 54.03381974356515, 53.07280050005232, 54.70066615513393, 55.37982130050659, 58.21560001373291, 54.93722799846104, 58.25468363080706, 20.448108979633876, 4.863256982394627, 29.24070167541504, 29.249466827937535, 24.14804904801505, 25.03179737499782, 41.0580484526498, 39.63077729088919, 48.33764484950474, 23.40957018307277, 43.48029123033796, 26.1634452683585, 52.09046070916312, 31.353589807237896, 47.13028417314802, 52.820758070264546, 71.02067838396344, 16.110880136489868, 0.24020419216581754, 0.40359735169581, 0.072528913484088, 0.3307313487998077, 0.11859798750707082, 0.25513853079506327, 0.1616337996508394, 0.13174936680921487, 0.2122817433306149, 0.24269183725118637, 0.11499526511345591], [0.11081253098590033, 0.017408458815355386, 0.07621886833970036, 0.07916493168366806, 0.08926480329994645, 0.13341251042272362, 0.12923972361854144, 0.03411869831117136, 0.008470918534190526, 0.05545252461784652, 0.07469469548336097, 0.03128076630777546, 0.09989533679825918, 0.15255850234201976, 0.18741077503987721, 0.11791634479803698, 0.3469365563775812, 13.073844245501927, 62.742865562438965, 48.87981973375593, 33.83772018977574, 40.179643290383474, 35.28420659473964, 29.373075280870708, 45.78663805552891, 20.898855992725917, 36.21878446851458, 17.785969223294938, 35.91653088160923, 39.23405599594116, 31.151261738368444, 60.231355803353445, 22.850309678486415, 5.966239648205893, 24.337225914001465, 61.90835217067173, 55.20607117244175, 61.71441405160086, 59.63508224487305, 53.06636994225638, 49.53497232709612, 46.095725195748464, 22.465315205710276, 12.440971050943647, 4.891927421092987, 0.36379009059497286, 2.832347388778414, 9.472077880586896, 14.922456775392805, 6.058714526040213, 3.2144507595470975, 0.9360423151935849, 0.5319664606026241, 8.882333891732351, 17.460989815848215, 2.5027270189353397, 3.2805259568350653, 4.111522691590445, 19.724111897604807, 31.425159726824077, 17.567415373665945, 3.3889235002653937, 17.371034962790354, 18.9636332988739, 15.527754306793213, 28.72796630859375, 18.362685339791433, 19.349230527877808, 21.234754494258336, 18.915145295006887, 25.111757244382584, 8.778777071407863, 18.962853363582067, 29.523976257869176, 33.507215227399556, 25.373442036764963, 12.727746656962804, 5.415096376623426, 7.619753275598798, 10.357713512011937, 26.683266060692922, 35.01221588679722, 38.031003202710835, 41.39524105616978, 49.830340249197825, 41.82173538208008, 35.50546850476946, 35.81275953565325, 32.35172632762364, 33.3739800453186, 39.604804924556184, 44.8225998197283, 40.17320578438895, 36.36871269771031, 37.42630842753819, 45.22832945414952, 46.05937916891915, 38.09582642146519, 26.022429840905325, 11.961766821997506, 8.59381776196616, 9.805384704044886, 10.895793301718575, 23.42889312335423, 35.18748072215489, 28.755237988063268, 18.85846883910043, 5.238533096654074, 8.859796541077749, 16.31631578717913, 24.375833579472133, 24.137783084596904, 24.747030666896276, 18.57289613996233, 17.190143823623657, 16.09271059717451, 14.725621257509504, 5.119929952280862, 8.791100570133754, 14.856004204068865, 15.763166223253522, 10.042643104280744, 3.722640701702663, 1.7912455967494418, 3.8902043274470737, 6.99599438054221, 22.446843419756206, 21.498141595295497, 20.720712866101945, 34.625117846897666, 28.183338710239955, 16.062821183885845, 3.931530475616455, 0.9324034133127758, 2.973736499037061, 8.163327353341238, 14.487728834152222, 26.06007170677185, 42.4128394808088, 49.13332823344639, 44.87951251438686, 49.50209692546299, 46.148128509521484, 49.27591221673148, 46.77450166429792, 47.03221035003662, 45.990998472486226, 14.48040543283735, 5.063821945871625, 51.764183725629536, 44.22495746612549, 27.06815457344055, 37.312392711639404, 28.322636195591517, 40.13275337219238, 26.04871835027422, 25.548738139016287, 29.073151077542985, 35.072057247161865, 29.485993930271693, 25.987094776971, 43.06561926433018, 47.27949326378958, 30.027213437216624, 0.3090689011982509, 0.2903100406484944, 0.14048276389283793, 0.12473369469600064, 0.081551719323865, 0.04363696702889033, 0.09378192627004214, 0.024557495290147405, 0.08328403958252498, 0.09829534443893603, 0.07651090981172663, 0.15795540703194483, 0.17976017056831292, 0.027719853545672128, 0.027406580712912337, 0.05669800957132663, 0.08853081839957408, 0.07870128192007542, 0.19864487222262792, 0.0525530562736094, 0.02848888308342014, 0.10907722517315831, 0.05363203551886337, 0.044763691390731504, 0.0491449682574187, 0.04628672091556447, 0.07993586960115603, 0.02367848710023931, 0.5123835057020187, 15.571321249008179, 75.34960065569196, 52.94078472682408, 34.21437856129238, 43.00159856251308, 29.255140032087052, 31.529243741716655, 34.16258668899536, 33.07846621104649, 38.561050006321494, 21.793578999383108, 37.59972504207066, 44.63386937550136, 37.66660492760794, 63.10925102233887, 31.63194853918893, 8.95493301323482, 24.068764890943253, 62.13866410936628, 56.503866127559114, 66.63182095118931, 61.38474287305559, 53.33200652258736, 53.229937485286165, 51.545051438467844, 27.062717608043126, 13.790015050343104, 6.100134040628161, 1.1907173522881098, 3.1844916471413205, 12.766485469681875, 19.71543880871364, 6.917378553322383, 3.9401171462876454, 0.8345708229712078, 1.7596611487013953, 11.185575740677969, 21.95859350476946, 3.0776342153549194, 4.1663578748703, 5.478910369532449, 23.82337883540562, 34.765957832336426, 25.758195059640066, 7.623269932610648, 12.60976711341313, 22.029409544808523, 19.028875146593364, 32.81937483378819, 22.624689510890416, 23.259068727493286, 22.62364901815142, 21.78838869503566, 26.421550001416886, 14.957267250333514, 19.657115629741124, 29.279135635920934, 39.547558716365266, 37.92937190192086, 17.475817271641322, 9.846970541136605, 18.85993317195347, 27.979155472346715, 36.4836220060076, 39.11967822483608, 42.18898936680385, 42.19335630961827, 54.15004920959473, 47.46903664725167, 39.57882561002459, 41.003171580178396, 39.296502930777415, 40.5135042326791, 47.969859327588765, 50.71639885221209, 47.06918518883841, 42.08829607282366, 43.96119342531477, 46.3894498688834, 49.4906393459865, 38.99747330801827, 27.153440237045288, 13.680170978818621, 12.223768625940595, 12.126506873539515, 24.899708645684377, 34.974900586264475, 37.53285557883126, 25.455133744648524, 18.186845541000366, 6.70636089359011, 14.256503207342965, 19.502248968396867, 26.204111337661743, 27.589903490883962, 25.113860811505997, 22.16415422303336, 18.599188123430523, 21.71721829686846, 15.63371433530535, 13.37618555341448, 12.630378944533211, 16.970089163099015, 17.174857786723546, 9.447505576269966, 6.632921040058136, 7.099724905831473, 8.853056788444519, 11.321377413613455, 26.38459948131016, 27.14849485669817, 26.406578370503016, 39.177077293395996, 32.63788441249302, 18.28222520010812, 3.568047191415514, 1.2946118116378784, 3.520607714142118, 6.261017841952188, 12.711736270359584, 28.828602279935563, 45.06775311061314, 54.31066724232265, 47.74906642096383, 52.03403091430664, 48.721414702279226, 54.393156255994526, 49.69017423902239, 51.31293991633824, 52.645701680864605, 16.647803919655935, 8.404065932546343, 53.7861442565918, 37.8557105745588, 34.01886320114136, 34.05160658700125, 31.672341891697474, 44.00460229601179, 39.55733135768345, 24.41469485419137, 30.438623223985942, 33.803795610155376, 30.749204226902553, 30.556148529052734, 41.92780310767037, 59.5714020047869, 34.10793563297817, 0.20257669767098768, 0.18328354507684708, 0.026157177219699537, 0.04688247466193778, 0.08000728541186877, 0.07026952079364232, 0.060695357753762176, 0.07197505927511624, 0.005367242107500455, 0.07749158290347882, 0.10871709271201066, 0.09316006928150143, 0.26247658846633776, 0.12375356443226337, 0.22639475603188786, 0.1623704715498856, 0.20217980896787985, 0.22734366011406693, 0.2736682907811233, 0.10767598250614745, 0.0959471043731485, 0.4026232739644391, 0.2706076907260077, 0.2936900407075882, 0.24281948325889452, 0.3101172649434635, 0.24199522605964116, 0.15552291327289172, 0.5869391965014594, 25.5106828553336, 87.4526469366891, 62.90127754211426, 48.78854472296578, 53.71762112208775, 44.32656444822039, 40.27953406742641, 53.721091747283936, 31.748560156141007, 54.5350558417184, 25.328977039882115, 39.45364339011056, 42.52748475755964, 36.98059885842459, 66.3396075112479, 29.956557205745153, 9.187943458557129, 29.710118498120988, 69.07912240709577, 63.38734572274344, 72.16790240151542, 68.14884199414934, 59.701298577444895, 57.778391565595356, 56.6541382925851, 27.663462332316808, 18.40458992549351, 10.427079115595136, 1.926879427262715, 8.565390075956072, 15.520781789507184, 22.425576720918926, 8.25588343824659, 7.5066244431904385, 2.8780022646699632, 2.587397115571158, 12.532311201095581, 26.60694009917123, 4.3654133422034125, 7.986886535372053, 9.814955847603933, 31.287668773106166, 42.37992933818272, 29.308001926967076, 7.836705565452576, 25.651799031666346, 28.509131056921824, 24.709684099469865, 39.37976319449288, 28.459055389676774, 26.90875768661499, 29.033000911985123, 28.076180117470876, 29.88421951021467, 17.402894190379552, 24.449507066181727, 34.956588608878, 45.74239192690168, 50.24413326808384, 30.053342138017925, 23.516115597316197, 28.846665859222412, 39.743098395211355, 47.06277200153896, 50.914200169699534, 48.362585408346995, 47.80775090626308, 55.74903120313372, 44.68514708110264, 42.947353976113455, 45.746098790849956, 43.998731068202424, 40.85922227587019, 44.25644670213972, 48.35185391562325, 45.04603999001639, 39.329096930367605, 43.24510860443115, 48.807704380580354, 46.20712218965803, 44.626837798527305, 46.0476645060948, 40.608163016183035, 35.573018891470774, 37.159709521702354, 34.486404010227744, 41.278327192579, 44.03561558042254, 35.66854967389788, 25.767524753298076, 10.686228684016637, 15.643893446241107, 24.885906049183436, 34.07642207826887, 30.49959019252232, 31.63674279621669, 25.68771427018302, 24.109898226601736, 24.689683709825786, 24.606993198394775, 12.853667991501943, 12.700744220188685, 22.802686725343975, 20.824234076908656, 15.48686763218471, 7.861541901315961, 5.600018339497702, 8.635437471526009, 11.44958644253867, 31.153050899505615, 30.69437599182129, 26.343056201934814, 42.35929318836757, 38.06114796229771, 26.00640903200422, 7.268297323158809, 2.4891285257680074, 5.6237212504659375, 13.656568816729955, 19.138965879167827, 29.67852851322719, 48.95515905107771, 57.445638860974995, 52.41014037813459, 56.27866806302752, 53.19591563088553, 58.364347049168174, 53.71376487186977, 54.936501911708284, 55.509342670440674, 19.345360381262644, 8.902462823050362, 60.583608627319336, 51.993481227329795, 32.357479436056956, 47.9470032283238, 31.308145114353724, 45.905733653477256, 34.40175410679409, 31.27327557972499, 43.63691404887608, 44.98046636581421, 42.2897868837629, 36.92829629353115, 57.41339921951294, 61.421019417899, 50.936931201389854, 0.5630487927368709, 0.4540689034121377, 0.14465188660791942, 0.2507101941321577, 0.3004041447171143, 0.16227877432746546, 0.19563362880476884, 0.14695402021918977, 0.23264042660593987, 0.19602138442652567, 0.14899024952735218, 0.2955409213900566], [0.18173242759491715, 0.036604026199451516, 0.0798157010493534, 0.01667240438317614, 0.06453083122947387, 0.1497441562158721, 0.10169660978551422, 0.03146060522911804, 0.03779966597046171, 0.059346721906747134, 0.027608999583337988, 0.03466078333024468, 0.06966813520661422, 0.10144920913236481, 0.04538559926939862, 0.058160364494792054, 0.03423967431964619, 0.8281256631016731, 53.230187620435444, 53.840652874537874, 34.97187117167881, 31.820842266082764, 44.67605536324637, 26.76498556137085, 45.18803685052054, 29.872886998312815, 28.118232352393015, 24.59356233051845, 13.64653127534049, 25.634855849402292, 56.11055987221854, 62.89845657348633, 56.35943044934954, 15.805861166545323, 14.015623927116394, 62.58785125187465, 56.317803791591096, 52.76526975631714, 55.24759013312203, 57.78972407749721, 55.83995532989502, 49.55183907917568, 49.408619335719514, 18.072724853243145, 2.019210998501096, 0.6677919094051633, 4.338770908968789, 6.616682231426239, 5.688998707703181, 2.215231840099607, 0.9016720194901738, 4.318003611905234, 2.6354478171893527, 3.4178388629640852, 6.657036066055298, 2.829896411725453, 2.15933119399207, 8.375647800309316, 30.26466464996338, 25.353335687092372, 8.26139075415475, 7.864942176001413, 21.81014003072466, 13.927654521805898, 19.784363201686315, 21.572049583707535, 23.080378430230276, 25.0849597794669, 20.853477307728358, 17.185396466936382, 17.988074949809484, 11.058628678321838, 18.573300872530254, 31.147739001682826, 39.03476776395525, 27.25789598056248, 10.78429729597909, 4.1033433590616495, 7.7470407996858865, 11.693945901734487, 27.917483261653356, 38.98598446164812, 40.906219891139436, 46.197762966156006, 48.24233988353184, 43.453780378614155, 40.32048327582223, 35.250462668282644, 34.67177847453526, 28.856445448739187, 33.04133851187569, 34.520398071834016, 33.391746589115684, 29.20397002356393, 38.60791213171822, 45.39011131014143, 46.41680145263672, 42.44449199948992, 33.51351029532296, 25.390987975256785, 14.657600130353655, 7.925635559218271, 6.054053587572915, 15.893029791968209, 35.562704290662495, 35.93775068010603, 19.13144098009382, 6.2040899481092175, 3.205834776163101, 11.324207067489624, 21.556200742721558, 22.191387687410625, 20.509067262922013, 23.204023361206055, 20.115623780659266, 15.865110192980085, 13.56888689313616, 11.424982871328082, 1.7401617893150874, 7.115877296243395, 10.678651673453194, 10.41337205682482, 9.119355184691292, 2.6671481047357832, 1.6872325837612152, 2.266167781182698, 3.436442013297762, 1.211437314748764, 5.135093527180808, 8.242330976894923, 7.247352847031184, 1.6677540689706802, 0.21874868417424814, 1.2547642184155328, 3.0082178030695235, 8.234564627919879, 19.323998144694738, 38.260516098567415, 41.26063707896641, 49.014204842703684, 49.05964606148856, 47.991409165518625, 45.59684453691755, 48.56291587012154, 47.61163452693394, 53.1548239844186, 29.7358580998012, 4.134427862507956, 23.963253021240234, 48.57715620313372, 55.395096915108816, 34.29043354306902, 16.11541904721941, 36.34168767929077, 36.89499010358538, 16.174136536461965, 32.01576008115496, 28.27154435430254, 36.96050466809954, 37.10949836458479, 35.219835008893696, 38.65346104758126, 55.69501938138689, 12.026570064680916, 0.3227501484964575, 0.23367196268268994, 0.11477590831262724, 0.14882505339171204, 0.08685400909078972, 0.04111014333154474, 0.02111829474701413, 0.06288704622004714, 0.005445967860785978, 0.048212562754218063, 0.06708050120089736, 0.017102585406973958, 0.1354764239596469, 0.08308458421379328, 0.07965001636849982, 0.00866705586668104, 0.07669826011572566, 0.09390883945993014, 0.08355108382446425, 0.05890929752162524, 0.03162784714783941, 0.08176104737711803, 0.04234730266034603, 0.07009103215698685, 0.03941287958462324, 0.0603864479011723, 0.032402730746460814, 0.09946963749825954, 0.06787661955292736, 1.6232283839157648, 61.00350911276681, 66.47701508658272, 34.14836025238037, 40.13176325389317, 38.38482631955828, 27.76418341909136, 35.541352476392476, 30.177965027945383, 39.97484861101423, 24.49032425880432, 24.54679921695164, 24.65629414149693, 54.7599447114127, 64.89921120234898, 59.313776697431294, 20.083898305892944, 16.099062987736293, 62.358345304216655, 59.470152854919434, 58.1164561680385, 58.920724051339285, 60.269230433872764, 61.474603925432476, 53.853312492370605, 54.75200639452253, 23.264000211443218, 5.225585562842233, 0.8338535843150956, 2.63028530563627, 8.546036737305776, 9.285146151270185, 3.3983287555830817, 0.43586961712156025, 2.6992809176445007, 1.0045541588749205, 5.270631168569837, 7.854499902044024, 4.575827811445508, 5.399739120687757, 10.730684995651245, 35.47957951681954, 27.951652765274048, 17.907119750976562, 7.5044600793293545, 20.48634144238063, 20.147241558347428, 25.252046585083008, 28.349051509584697, 27.038155726024083, 27.25091130392892, 25.989285196576798, 20.462750571114675, 21.940036603382655, 13.849556769643511, 21.96088293620518, 34.8238536970956, 42.92014830453055, 35.56882217952183, 16.86117093903678, 9.005857229232788, 13.430015853473119, 23.385786499295914, 37.478065558842246, 44.43776689256941, 47.58005496433803, 49.150337423597065, 53.693813119615825, 48.17428575243269, 44.803238664354595, 44.24498912266323, 39.900238854544504, 38.22891569137573, 40.36033814293997, 45.280447891780305, 39.7303797176906, 36.82467085974557, 42.21344007764544, 49.35416282926287, 49.98852293831961, 45.46542630876814, 38.422315325055806, 26.03671533720834, 18.898353236062185, 20.30333457674299, 21.170056343078613, 28.876374619347708, 41.29390157972063, 35.13824231284005, 21.598515272140503, 8.374990327017647, 5.414988679545266, 17.829258237566265, 24.73250719479152, 25.135476657322474, 22.69954071726118, 27.691583429064067, 21.259773220334733, 18.160993031093053, 15.63470619065421, 12.334155525479998, 7.577172109058925, 9.378439613751002, 11.19920289516449, 11.977043305124555, 6.612928467137473, 7.458042638642447, 6.361936518124171, 6.5631537437438965, 7.151395184653146, 3.8497493096760342, 3.958054789475032, 8.426631944520132, 6.444168014185769, 1.6343394219875336, 0.28117082534091814, 1.9471390715667178, 1.4449215403624942, 7.062748329980033, 16.307804243905203, 41.1927809715271, 45.76283005305699, 52.03817204066685, 50.44913291931152, 50.907286712101524, 50.639485767909456, 51.250072615487234, 50.31680447714669, 60.496012687683105, 35.44829525266375, 7.053016075066157, 29.56143399647304, 46.71669265202114, 59.13029561723982, 36.0619010925293, 21.309913158416748, 38.07623944963728, 43.01749604088919, 25.39945261819022, 26.41516634396144, 33.79110472542899, 29.41716854912894, 41.97561713627407, 31.925346646990093, 46.202237606048584, 65.13110038212368, 14.483397500855581, 0.250329101724284, 0.23372708686760493, 0.018276364476020848, 0.1930333740477051, 0.10021004133990832, 0.02063369351838316, 0.08295769137995583, 0.08904683749590601, 0.03676777705550194, 0.03567960026807018, 0.0677381373409714, 0.035134916459875445, 0.3599030620285443, 0.21531791612505913, 0.1793477162718773, 0.1539583065147911, 0.19596304398562225, 0.3490201202886445, 0.21770918209637913, 0.11878035057868276, 0.1826400767479624, 0.24875001502888544, 0.14690707916659967, 0.16163888866347925, 0.265625995184694, 0.24650859673108372, 0.14080581441521645, 0.1900675789053951, 0.17672506985919817, 3.614272036722728, 79.94457639966691, 70.15736470903668, 47.48276628766741, 43.53324692589896, 59.62757819039481, 36.73476811817714, 56.949391569410054, 36.42299549920218, 46.585086822509766, 33.41821575164795, 20.374140194484166, 29.106224502835953, 62.23632798876081, 69.29510716029576, 63.44177096230643, 21.629087345940725, 18.36404718671526, 69.16251468658447, 64.61920574733189, 63.98796885354178, 64.64028658185686, 66.86737183162144, 64.97106947217668, 59.28889519827706, 53.05449547086443, 23.340479033333914, 4.810638274465289, 1.115647820489747, 7.419762407030378, 12.810446722166878, 10.42870499406542, 5.721477627754211, 2.5226125461714606, 11.05796946798052, 5.829270677907126, 7.6839867659977505, 9.486120189939227, 7.231864878109523, 5.586967885494232, 17.963709354400635, 38.85548686981201, 37.136301040649414, 15.78223729133606, 14.157645974840436, 30.40585551943098, 21.5100542817797, 31.734952109200613, 32.05994715009417, 31.557790415627615, 34.54047836576189, 30.264237335750035, 23.64082360267639, 23.319066422326223, 17.023720570972987, 26.341911486216954, 37.94558204923357, 46.87251990182059, 47.62654536111014, 28.073913267680577, 17.48955386025565, 25.483661311013357, 39.16018622262137, 49.161155768803184, 50.61243643079485, 52.61268384116036, 51.514111110142295, 52.78432171685355, 46.71177680151803, 45.86585099356515, 46.430336543491904, 44.061518464769634, 39.597200121198384, 39.54229893003191, 46.45540564400809, 40.12587118148804, 39.640650681086946, 42.782897063664024, 50.410639899117605, 47.63914244515555, 45.69559233529227, 47.74087449482509, 48.298766204289024, 41.5776868547712, 32.42639514378139, 22.249392986297607, 34.64371817452567, 46.18799032483782, 39.52352837153843, 29.850760459899902, 13.672662581716265, 8.801665306091309, 19.32271099090576, 27.872929675238474, 28.636898006711686, 28.62633674485343, 32.754791327885215, 27.76738132749285, 22.851516927991593, 20.33630551610674, 18.941741262163433, 5.020563764231546, 10.623559406825475, 16.06868198939732, 15.871005739484515, 14.529620391981942, 6.142714772905622, 5.0526105931827, 5.724274711949485, 6.746105458055224, 5.118572013718741, 6.893987877028329, 12.430534856660024, 10.359155263219561, 3.4096347774778093, 0.3323998121278626, 3.3022071591445377, 6.651416276182447, 16.683722632271902, 23.74468353816441, 42.48937388828823, 51.16829579217093, 54.442815031324116, 56.99282823290144, 53.783330236162456, 53.738378865378245, 54.61205925260271, 55.54389953613281, 60.406047412327354, 38.32066665376936, 6.04183691740036, 30.64353254863194, 54.136361258370535, 68.7037251336234, 38.96392740522112, 24.083069494792394, 38.93430723462786, 44.96564933231899, 20.43287331717355, 44.73943683079311, 42.970234394073486, 46.09252207619803, 50.105235304151265, 47.261539118630544, 53.95303651264736, 72.75877026149205, 22.41342432158334, 0.5820403365152222, 0.3649619477135794, 0.2100843619555235, 0.5231473509754453, 0.185880895704031, 0.37939202625836643, 0.17046531289815903, 0.20762133412063122, 0.1085840319948537, 0.2266787365078926, 0.17952100054493972, 0.1597683033240693], [0.08056540760610785, 0.08338626766843454, 0.052622751998049874, 0.0012266935622652195, 0.06636308612568037, 0.07267542276531458, 0.0416616464166769, 0.06777734309434891, 0.07563328583325658, 0.041931065531181436, 0.030041581551943506, 0.07182024472526141, 0.031002193755869354, 0.06206204941762345, 0.04759620529200349, 0.08216288938586201, 0.0497215499968401, 0.23965672297137125, 29.588389532906668, 70.65266704559326, 31.919683865138463, 31.53571251460484, 62.55271421160017, 47.31530427932739, 36.37604999542236, 49.247785908835276, 23.017092500414165, 28.20759834562029, 12.811774696622576, 42.83561652047293, 77.7969993863787, 49.634209973471506, 38.46849305289132, 6.630384513310023, 20.224074738366262, 58.57184110369001, 59.338943072727744, 51.5362480708531, 54.90852846418108, 42.57633754185268, 30.182613372802734, 51.31211308070591, 35.13775593893868, 28.22306850978306, 14.711915935788836, 2.747908102614539, 0.0892343031508582, 1.2032869692359651, 6.121132799557277, 1.0814731057201112, 0.08783041419727461, 0.35834397854549543, 1.7289655272449767, 4.3567567552839, 4.780360196317945, 4.922518602439335, 1.8268870328153883, 19.79492446354457, 31.765183721269878, 23.25630681855338, 6.77578512259892, 13.950990046773638, 17.572725534439087, 17.19193124771118, 21.814051866531372, 24.846983977726527, 29.75928395135062, 26.778107234409877, 21.935119015829905, 14.39387777873448, 14.715110370091029, 16.81008083479745, 18.060904230390275, 34.104485852377756, 39.95243372235979, 21.99745304243905, 8.132469534873962, 4.10348927123206, 7.413628016199384, 10.371143511363439, 30.538503578730992, 41.44693217958723, 41.6643100466047, 45.07015371322632, 48.8534756387983, 44.42279005050659, 40.67871502467564, 40.34040028708321, 36.563710417066304, 31.236140932355607, 30.25981480734689, 29.340745312826975, 29.835717609950475, 28.3100425856454, 37.98245613915579, 49.218381132398335, 44.704324109213694, 42.729698181152344, 38.77009003502982, 26.047742128372192, 9.605081166539874, 7.420866302081516, 4.990173212119511, 11.716284360204424, 28.7896819455283, 31.702625615256174, 18.782990557806833, 7.567010368619647, 5.128204388277871, 5.296639578683036, 12.905560612678528, 22.410160405295237, 22.18213963508606, 18.404278993606567, 20.859673363821848, 17.951221704483032, 12.322336639676776, 10.35404052053179, 7.279612464564187, 1.6200656507696425, 6.983906686306, 6.647136185850416, 4.717314847878047, 7.262591549328395, 4.372962994234903, 1.6889519372156687, 5.870607682636805, 4.674468781266894, 4.1345841969762525, 0.6384093889168331, 2.7529787676674977, 1.5008966624736786, 1.65243861079216, 2.398962838309152, 2.1048121537481035, 5.954626168523516, 10.770208086286273, 47.020148277282715, 48.904100213732036, 45.57406834193638, 47.06280326843262, 46.35246808188302, 47.38123573575701, 46.63097620010376, 52.38789919444493, 39.56340060915266, 13.199932336807251, 11.99118115220751, 47.2299074445452, 50.92488997323172, 32.597609179360525, 16.304444789886475, 20.740037543433054, 38.28337914603097, 26.041822263172694, 15.125219106674194, 34.18934767586844, 24.681385823658534, 58.03344603947231, 39.28793232781546, 39.06164687020438, 47.56688812800816, 45.69773932865688, 0.9595941028424672, 0.0764065036284072, 0.028813358529337814, 0.0587041899561882, 0.08784496877342463, 0.07822344398924283, 0.0336381835596902, 0.05700435795422111, 0.04665363194154842, 0.03625548990177257, 0.052237808903945346, 0.016169665913496698, 0.038223465372409136, 0.043268339309309206, 0.017353855406067202, 0.09943654534540006, 0.021289411100691984, 0.04672429457839046, 0.04901567680229034, 0.02513983439920204, 0.07891424692102841, 0.03729155519977212, 0.07014408681009497, 0.08121724227177245, 0.03144376398995519, 0.047106143552809954, 0.02708953183277377, 0.01878928266731756, 0.028332538437098265, 0.08271810745022126, 0.22088247324739183, 37.09419495718819, 82.15037931714738, 35.72258234024048, 37.650554588862825, 66.39683982304165, 39.7154723576137, 28.484478848321096, 37.176451206207275, 33.56919315883091, 33.37739855902535, 21.456346443721227, 42.91351277487618, 78.06565843309674, 56.24344417027065, 43.86891092572893, 8.741962041173663, 24.602928502219065, 67.25990336281913, 63.34426689147949, 59.240903990609304, 60.63929149082729, 49.53234243392944, 40.39831352233887, 57.87864364896502, 41.141419887542725, 30.80192368371146, 16.08663787160601, 3.3647194504737854, 0.11701634952000209, 3.361176520586014, 9.586596352713448, 2.12358010666711, 0.41997208446264267, 0.7990797502653939, 0.97039638033935, 3.2874526594366347, 7.420835903712681, 10.421135800225393, 5.597416239125388, 25.25538866860526, 35.11077260971069, 28.4367481981005, 11.122592057500567, 8.888336266790118, 21.956192902156285, 19.84253352028983, 28.5039598601205, 31.92195245197841, 32.429153578622, 29.32677595955985, 27.487716334206716, 19.51705731664385, 15.750664676938738, 19.91922426223755, 21.540897335324967, 37.11889232907976, 46.817660399845664, 33.775641509464805, 12.848995327949524, 5.875503991331373, 12.071906191962105, 23.534675972802297, 37.905668122427805, 45.00842244284493, 48.206636565072195, 47.74030474254063, 53.07136222294399, 49.36690929957798, 43.10496343885149, 46.71865551812308, 43.11577830995832, 38.51309701374599, 37.698584011622835, 37.73220981870379, 35.775763852255686, 36.62528535297939, 41.62858588354928, 50.37933479036604, 48.59093795503889, 44.14189870016915, 44.83063193729946, 38.95476620537894, 29.579975264413015, 16.80480020386832, 11.70035822050912, 22.824439798082622, 39.29141684940883, 36.00079863412039, 20.733846698488506, 13.920579518590655, 9.102232217788696, 12.643174920763288, 19.901006085532053, 24.711089372634888, 25.900607075010026, 20.581752368382045, 25.329982791628154, 18.59128975868225, 16.73805754525321, 9.348664845739092, 10.02991053036281, 7.490995338984898, 7.750552245548793, 7.765313693455287, 4.523358489785876, 8.404230083738055, 10.402326158114843, 8.805432966777257, 13.568728821618215, 10.263698305402484, 5.735794825213296, 0.8895452416368893, 2.693307421037129, 2.3790189027786255, 0.6416653799159187, 1.2831495638404573, 1.3982088012354714, 3.575810717684882, 12.757676890918187, 49.565203939165386, 52.678611823490684, 50.284446716308594, 51.25251490729195, 50.590014593941824, 51.913594314030235, 51.79576676232474, 56.819359506879536, 43.99960306712559, 15.46949713570731, 16.051268066678727, 47.60015262876238, 50.31989642551967, 42.68641785212925, 21.39490352358137, 22.344737904412405, 39.17102888652256, 40.11577892303467, 21.729417596544536, 32.37592690331595, 26.008811371667043, 48.46540832519531, 46.585712160382954, 36.91751963751656, 59.53878716060093, 51.60015760149275, 1.6723422684839793, 0.09499787459416048, 0.08880647325089999, 0.04573725004281316, 0.0772338549473456, 0.07606794858085257, 0.06749211411390986, 0.023810769198462367, 0.027074668523190275, 0.04228390034820352, 0.03835070765178118, 0.08291535079479218, 0.19502627210957663, 0.12670071343226091, 0.1145983628396477, 0.192603291411485, 0.1870249600282737, 0.13996107902910027, 0.31895968903388294, 0.1311086533325059, 0.18905794593904698, 0.12452349811792374, 0.18077570678932325, 0.12346496991813183, 0.14911975472101144, 0.1814883178366082, 0.19911543625806058, 0.13324105819421156, 0.16857868699090822, 0.14665512554347515, 0.3219750172325543, 53.4654084614345, 90.45603357042584, 46.468589850834434, 40.55528027670724, 78.40549482618059, 61.42079012734549, 47.2539621080671, 58.1673378263201, 34.15352276393345, 46.00026389530727, 17.08638116291591, 46.74373504093715, 88.17402975899833, 58.06233317511422, 44.12607070377895, 8.804238745144435, 24.92065051623753, 66.13943685804094, 67.84331580570766, 60.842345646449495, 66.25388758523124, 53.71118361609322, 39.58254984446934, 62.4472405569894, 44.62043155942644, 35.31779071262905, 19.945917504174368, 4.153006042752947, 1.2834625584738595, 5.775563274111066, 13.156790971755981, 3.6508154358182634, 1.3363742849656512, 2.219349516289575, 6.5361977730478555, 8.161572933197021, 9.06167471408844, 11.791088666234698, 8.723178454807826, 28.663438388279506, 41.563550744737896, 33.65288421085903, 10.516984462738037, 21.059317690985544, 26.24415033204215, 24.059909411839076, 33.01246179853167, 37.2632029397147, 37.61650494166783, 35.78226389203753, 30.15300015040806, 19.732138804027013, 19.32067690576826, 23.051142147609166, 30.735050746372767, 40.73253577096121, 46.68048211506435, 41.36382825034005, 19.205930880137853, 13.226219977651324, 26.426863636289323, 37.67058971949986, 44.6531332560948, 50.849227564675466, 50.53742715290615, 48.22140148707798, 52.677465370723176, 47.60116359165737, 45.40875332696097, 49.12242303575788, 47.72250345775059, 42.5493403162275, 41.76942239488874, 42.47845826830183, 40.71107278551374, 38.19799968174526, 44.543178013392854, 50.241444315229145, 46.0581945010594, 44.32913180759975, 48.40515007291521, 50.29214532034737, 40.729409081595286, 20.60794186592102, 16.927597454616002, 30.50255707332066, 43.43758412769863, 38.03440087182181, 28.529013327189855, 20.098239387784684, 13.11180225440434, 11.718737942831856, 22.730576583317347, 27.4063720362527, 29.868804931640625, 24.655239752360753, 28.957878725869314, 25.89806750842503, 20.24359917640686, 16.198130403246196, 14.00923592703683, 5.172088776315961, 13.048559750829424, 9.717730573245458, 10.477140017918178, 12.246078423091344, 6.1737727863448, 6.032047339848109, 12.823192323957171, 8.72112352507455, 7.916980709348406, 1.4563811825854438, 5.33465621301106, 5.300091964857919, 4.083301280226026, 2.3887385640825545, 6.018531356539045, 11.634681241852896, 14.809687512261526, 53.62529693331037, 55.55507918766567, 55.64415509360177, 55.22021770477295, 55.42522777829851, 55.63078328541347, 54.97644363130842, 59.227605138506206, 46.41922984804426, 18.125119481767925, 15.992345605577741, 53.97528811863491, 58.45770999363491, 40.73196601867676, 20.64242230142866, 26.182243619646343, 41.94459342956543, 36.39133950642177, 22.647182566779, 48.71124948774065, 33.82741601126534, 69.62124170575822, 53.04454565048218, 51.57984454291207, 60.60886532919747, 67.09832995278495, 3.9897455232484, 0.351852542587689, 0.21668148652783462, 0.16572527081838676, 0.3406170340520995, 0.1473132230873619, 0.1202520794634308, 0.14037858162607464, 0.26407570551548687, 0.143812199522342, 0.2480949301804815, 0.12616859269993647, 0.3180759378841945], [0.06820863352290221, 0.09599690205816712, 0.07849107855664832, 0.03476272303877132, 0.039706773457250426, 0.11413497770471231, 0.05799294276429074, 0.0572433312024389, 0.0595717512603317, 0.05993310508451291, 0.0452777732695852, 0.04265341016330889, 0.02619791476588164, 0.056927574931510856, 0.07802196658615555, 0.06230895474020924, 0.13209085991340025, 0.4659850097128323, 10.334370170320783, 58.94440351213728, 40.94482408251081, 22.415116207940237, 52.41998944963728, 73.60838208879743, 43.81358936854771, 51.45186914716448, 33.73233686174665, 27.189138344355992, 21.05418470927647, 15.009085178375244, 45.3704548563276, 58.38105746677944, 47.45797858919416, 23.145903417042323, 21.466416120529175, 43.542884077344624, 49.890108653477256, 54.324740818568635, 45.219505241939, 47.58042321886335, 16.618237597601755, 37.456908294132774, 54.95203808375767, 38.47172743933541, 15.973634106772286, 1.790076996598925, 1.6229720605271203, 10.520487223352704, 2.3153204236711775, 1.0347580867154258, 0.5333669568811144, 1.0903977411133903, 0.45841429595436367, 2.805001450436456, 7.144093062196459, 2.3749711428369795, 4.028279364109039, 24.0239212172372, 25.434504543031963, 16.162513937268937, 12.358809471130371, 14.745885678700038, 15.811103582382202, 19.554713078907557, 23.65524458885193, 31.34014504296439, 28.11375250135149, 25.822205339159282, 22.543136766978673, 9.905973775046212, 5.9814896413258145, 13.61512541770935, 17.74711663382394, 36.963023390088765, 36.52739218303135, 21.15307320867266, 5.848848095961979, 3.515271931886673, 6.243944815226963, 14.096243006842476, 31.177383490971156, 42.179591928209575, 47.4708605493818, 49.49065324238369, 48.04923207419259, 43.33171442576817, 41.47827550343105, 42.454702377319336, 38.54604884556362, 32.438582284109934, 29.14113746370588, 28.92769227709089, 29.071368864604406, 30.012055941990443, 38.358881746019634, 48.667854513440815, 48.35962894984654, 44.862322671072825, 38.70249795913696, 23.75147713933672, 5.0178400703838895, 5.881144625799997, 5.189845332077571, 10.85766419342586, 26.510318449565343, 29.415664264133998, 22.57721594401768, 7.532910346984863, 9.99870182786669, 4.100291797092982, 9.671737841197423, 18.522530385426112, 21.84035948344639, 19.181747674942017, 19.684489795139857, 18.045154401234218, 14.31247181551797, 4.1743126937321255, 8.194148693765912, 5.67656056370054, 1.1693035470587867, 5.132610414709363, 3.5161022416182925, 10.961841140474592, 11.59217129434858, 4.449218605245862, 2.463373724903379, 3.6132554284163882, 8.025459459849767, 2.6586954040186743, 0.8641766086220741, 0.43142146723611013, 0.625136483992849, 2.2858281433582306, 1.5363727531262805, 5.690202917371478, 16.703405141830444, 32.97986432484218, 46.79838957105364, 47.14580644880022, 40.52590676716396, 41.01161016736712, 44.618333203451975, 46.03417457853045, 50.39109809058053, 31.497612067631312, 14.568978462900434, 30.338145324162074, 68.17095811026437, 36.898512840270996, 12.124814987182617, 16.402400493621826, 29.30325630732945, 40.98372704642159, 15.331069912229266, 27.721189703260148, 26.67223232133048, 34.61938558306013, 62.61068998064314, 29.67512389591762, 39.91306175504412, 56.403350012642996, 23.05832658495222, 0.39557633495756556, 0.4042777866125107, 0.06575899996927806, 0.21608976327947207, 0.03230338643438049, 0.21072485830102647, 0.05759270888354097, 0.12642241907971247, 0.04031928023323417, 0.08328500988760165, 0.10467824193515948, 0.07887751782046896, 0.09710647644741194, 0.10856476160032408, 0.04623861278274229, 0.12914281524717808, 0.04684560985437461, 0.02817366285515683, 0.10419315725032773, 0.04114034153254969, 0.030071372631937265, 0.058295603309358866, 0.06477684088583503, 0.050324041595948596, 0.08045769017189741, 0.03655958215573004, 0.07080597736473594, 0.035825095139443874, 0.018312477806050862, 0.14574244166059153, 0.5437139645218849, 12.723205140658788, 70.79869733537946, 46.41276107515608, 20.34238518987383, 52.80705969674246, 69.37791579110282, 37.39944321768624, 33.991643633161274, 36.54875441959926, 34.1421867779323, 25.792154380253383, 25.53301783970424, 49.06602450779506, 62.16229493277413, 47.24079874583653, 25.03762170246669, 24.990137713296072, 51.43531853812081, 56.915400981903076, 57.85024983542306, 55.0054349899292, 51.917582580021445, 20.881947551454815, 42.484225273132324, 56.925732953207834, 41.408303669520784, 20.924606016704015, 3.5432974909033095, 2.421105444431305, 11.289226361683436, 3.1690605665956224, 1.4643136369330543, 0.6566707204495157, 0.7544735638158662, 1.285636150411197, 6.380109965801239, 13.597259862082344, 5.206779394830976, 8.035681997026716, 23.498283045632498, 24.89484143257141, 18.98959697995867, 12.191520299230303, 12.908219167164393, 20.064729963030132, 23.13734323637826, 30.719695227486746, 36.728955950055806, 29.36066927228655, 30.24986846106393, 26.7372761453901, 16.638960599899292, 11.680620993886675, 15.912906851087298, 22.018285478864396, 36.30742958613804, 46.11541986465454, 28.990210430962698, 10.904772111347743, 6.818726292678288, 11.41552550452096, 25.508751256125315, 40.73655530384609, 45.39076444080898, 49.1903520992824, 51.919590609414236, 53.851356574467246, 46.628690242767334, 44.232867990221294, 46.84698179789952, 44.5898733820234, 39.70512996401106, 37.79092904499599, 39.31248378753662, 36.46689421789986, 35.86185203279768, 42.34638343538557, 48.60908317565918, 49.1309415272304, 46.73576545715332, 47.97005387714931, 40.60494947433472, 21.611977406910487, 9.54304243837084, 10.621445417404175, 20.42853937830244, 36.382390226636616, 33.093109539576936, 23.140308380126953, 12.546226705823626, 9.955324224063329, 7.846969791821071, 16.61646580696106, 22.631712402616227, 25.565141098839895, 20.241636310304912, 24.71347781590053, 21.74037664277213, 17.511859314782278, 5.1489386813981195, 9.109040583883013, 9.784929207393102, 6.39257242849895, 6.010076701641083, 6.258956832545144, 6.986252571855273, 14.041503361293248, 9.61282319681985, 7.741926056998117, 11.398378218923297, 17.937804733003887, 6.972663198198591, 1.201839138354574, 0.4797794095107487, 0.6278607206685203, 1.3794119698660714, 1.2241194056613105, 5.024945037705558, 17.791442666734966, 40.28317492348807, 50.915864263262065, 52.33276523862566, 44.530778953007285, 45.740755626133506, 50.48768152509417, 50.604678767068044, 56.00578103746687, 34.744623388562886, 15.129568678992134, 33.47116449901036, 65.78574575696672, 42.215632234300884, 17.799976791654313, 21.780591079166957, 27.179581097194127, 45.55264357158116, 28.45456337928772, 28.82775981085641, 28.569109644208634, 31.55221448625837, 59.86319160461426, 33.6151624407087, 40.16024739401681, 65.71342890603202, 25.92640573637826, 0.27442046041999546, 0.24894282753978456, 0.0683538807289941, 0.05836954327034099, 0.06665032356977463, 0.03727842215448618, 0.0354219537361392, 0.08194291511816637, 0.044351192989519665, 0.026382113274719034, 0.06424089321600539, 0.0674383198576314, 0.19656227183129105, 0.17805855401924678, 0.20688053672867163, 0.3859036825597286, 0.1963908603148801, 0.12282673987959113, 0.28190624873553005, 0.16119067557156086, 0.1669813205621072, 0.2271763062370675, 0.13893658614584378, 0.17255355870085104, 0.2575139733297484, 0.22055228453661713, 0.2523032857903412, 0.2982947693339416, 0.14196567503469332, 0.3727866235588278, 0.5514900301183973, 21.447871378489904, 88.37584713527134, 54.15256098338536, 32.22027335848127, 61.238031659807476, 90.39910003117153, 59.93012360164097, 60.074180603027344, 41.48299333027431, 44.74642324447632, 26.65894215447562, 19.55185215813773, 53.06907626560756, 64.76497895377022, 53.240536962236675, 28.259355476924352, 25.59037000792367, 51.12129817690168, 59.45855631147112, 61.19375079018729, 55.714547293526785, 55.7096140725272, 21.10259280885969, 43.95866775512695, 63.75147301810128, 45.663467339106965, 22.318614414760045, 5.460651806422642, 3.8584749443190436, 15.114458084106445, 4.812697981085096, 3.1731547926153456, 1.738708964415959, 2.532710232904979, 3.0529099191938127, 7.634296723774501, 15.033131156648908, 5.4372546161924085, 8.106511064938136, 31.269777161734446, 31.437927041734966, 21.904022353036062, 18.063247510365077, 22.0057943548475, 23.62692199434553, 26.515651191983903, 34.01002509253365, 41.85104635783604, 34.43122489111764, 36.25946964536394, 29.18819066456386, 17.551920890808105, 10.554476073810033, 18.73800618307931, 29.37099082129342, 38.48861851011004, 46.90485334396362, 40.2719292640686, 17.526580810546875, 12.985752378191266, 29.874523299080984, 45.64569732121059, 46.54829611097063, 52.375910077776226, 54.547308989933555, 51.85790450232369, 51.1471072605678, 46.186718804495676, 44.0263466835022, 48.91854551860264, 47.48906830378941, 44.124642848968506, 43.45178624561855, 45.563232626233784, 40.75873742784773, 39.48283972058977, 45.15405321121216, 50.409594195229666, 49.08800860813686, 47.2778708594186, 50.97937774658203, 50.26372371401106, 30.659391811915807, 15.572224514825002, 18.096298354012625, 30.855331012180873, 40.23574651990618, 33.14874723979405, 27.259685141699656, 17.671898909977504, 16.60727334022522, 10.859557577541896, 17.839522463934763, 25.052694082260132, 28.42642491204398, 24.473520040512085, 29.36017942428589, 28.765985114233835, 23.755856241498673, 9.421959655625479, 19.688052483967372, 10.373226233891078, 5.9971582634108405, 11.51140022277832, 8.552431685583931, 18.055392571857997, 16.723893642425537, 6.159368736403329, 4.444459523473467, 7.740267174584525, 15.540808234895978, 5.613546916416713, 2.652440288237163, 1.9972807466983795, 2.254663518496922, 4.890050973211016, 4.551059220518384, 10.242686952863421, 21.59569604056222, 43.15344796861921, 54.86084297725132, 56.01128053665161, 48.79513508932931, 50.1360297203064, 52.49104520252773, 56.708223070417134, 58.196909359523225, 38.48556130273001, 17.778347049440654, 39.47225761413574, 75.37405831473214, 47.4826968056815, 14.201410940715245, 26.78270867892674, 30.459453923361643, 47.72842679704939, 21.49152864728655, 38.02434682846069, 40.541609695979524, 48.762704372406006, 71.76120349339077, 41.420664514814106, 50.956486906324116, 71.84951509748186, 36.86329936981201, 0.4265485272875854, 0.4099990853241512, 0.18888702296784946, 0.25581714723791393, 0.20863392549966062, 0.2617896396134581, 0.15443375600235804, 0.17696533910930157, 0.1374998560973576, 0.12049137162310736, 0.30755101836153437, 0.1695703523499625, 0.3168790563941002], [0.05893323623708316, 0.04623731678085668, 0.01991386794751244, 0.02867468972025173, 0.045436061918735504, 0.13032024992363794, 0.06841709305133138, 0.030536440533718893, 0.06298382566975695, 0.02388928927082036, 0.03348372524072017, 0.03363803767466119, 0.1479527559131384, 0.09088655627731766, 0.1351830932710852, 0.030153773924601928, 0.02527810456896467, 0.27548616752028465, 0.8667176951255117, 49.968494755881174, 44.73616770335606, 63.43901947566441, 75.56043679373605, 48.58634172167097, 33.00031982149397, 44.85057326725551, 41.27936594826834, 25.361689158848353, 34.219367367880686, 12.184452244213649, 43.92359324863979, 47.05194670813424, 63.55606188092913, 50.76108966554914, 14.34459854875292, 30.0502119745527, 46.97689226695469, 66.89374024527413, 46.3301157270159, 48.85151277269636, 32.669196469443186, 30.307482923780167, 51.37423692430769, 36.39401456287929, 18.466666868754796, 4.070637319769178, 3.092759140900203, 2.2671600707939694, 0.5130519441195897, 0.8233258692281586, 0.989059350320271, 0.366905434855393, 0.38210942330104963, 8.429825510297503, 4.244811722210475, 3.0256764548165456, 12.37213785307748, 24.301614659173147, 18.61703630856105, 15.339496340070452, 13.283018027033124, 12.48925929410117, 16.840705020087107, 18.002431665148052, 31.759989942823136, 30.96002299445016, 25.44609761238098, 24.01864058630807, 19.936011110033306, 8.271419610295977, 7.641099010195051, 11.281598108155386, 17.410893304007395, 35.79276956830706, 37.90493161337716, 20.87889208112444, 7.912552969796317, 4.366931523595538, 6.135524690151215, 13.180013588496617, 30.809757777622767, 44.00073562349592, 46.78078283582415, 48.610139301845, 48.08071436200823, 45.59072664805821, 41.10504259381975, 44.64591407775879, 39.15600340706961, 33.12645047051566, 31.48561600276402, 31.023334980010986, 30.80253859928676, 30.719597952706472, 39.97542878559658, 47.55844954081944, 47.33295270374843, 43.90239429473877, 34.62013251440865, 11.598055550030299, 6.538361702646528, 5.639109773295266, 5.99391519171851, 11.344791105815343, 29.878181525639125, 32.253197397504536, 20.080269609178814, 6.502112516335078, 19.253668478557042, 21.728517804827007, 8.766535214015416, 17.421103681836808, 19.517792088644846, 17.56660417148045, 17.343193531036377, 16.71996443612235, 9.748748200280325, 4.985038927623203, 7.348971554211207, 9.525921208517891, 1.581478504197938, 4.566066460950034, 1.8309521632535117, 5.890727060181754, 21.098482949393137, 19.041465282440186, 14.11742545877184, 3.7517401916640143, 1.1713379578930991, 2.1429534213883534, 3.868185920374734, 0.40897224470973015, 0.0847622077646, 0.882059534745557, 1.3410161158868243, 2.197368238653455, 18.698457036699565, 39.0323463167463, 49.495273794446675, 44.533745833805625, 41.63742399215698, 42.74237169538225, 44.65094109943935, 46.62883962903704, 52.07639408111572, 36.31430830274309, 33.55649185180664, 53.595815726688926, 55.399488176618306, 36.142118045261924, 24.318111419677734, 17.125331027167185, 35.04770381110055, 35.51240280696324, 11.434151019368853, 35.99097040721348, 20.966052021299088, 51.32302175249372, 45.67947251456124, 32.47913197108677, 48.71970891952515, 53.61579179763794, 4.389936574867793, 0.12450900460992541, 0.1169865211205823, 0.004616313339543662, 0.12303855137101241, 0.05886454813714538, 0.07860623273466315, 0.03999314916187099, 0.10491148834781987, 0.08363702706992626, 0.037317773792892694, 0.013008999754674733, 0.0732932628265449, 0.029780091119131873, 0.07697511597403459, 0.04731484396117074, 0.0680266572162509, 0.0478372277159776, 0.03433493724358933, 0.06202692165970802, 0.040486036999417205, 0.04335671849548817, 0.09452463713075433, 0.057838799964104376, 0.018134550657123327, 0.09419443484927927, 0.026698076498827765, 0.03481749777815171, 0.11246903852692672, 0.04367662400805524, 0.04222007055899926, 0.30152872151562143, 1.7668880351952143, 62.77513994489397, 55.16089398520333, 58.91186509813581, 78.73235893249512, 52.13493960244315, 39.97281278882708, 30.12106622968401, 36.40377330780029, 34.43412923812866, 31.227295875549316, 20.129499333245413, 55.14367287499564, 56.780581610543386, 58.56499712807791, 54.04237992422921, 18.136505842208862, 28.46959580693926, 55.16708830424717, 68.22095039912632, 53.83291605540684, 55.072196756090435, 33.19526890345982, 35.27808175768171, 56.640314851488384, 39.55107797895159, 21.592593669891357, 6.5856055447033475, 5.984744438103267, 3.1413594016007016, 0.9290999791451863, 1.1091661282948084, 1.0593611150979996, 1.8818216621875763, 5.1835159574236185, 11.37469094140189, 12.027314390454974, 7.27629600252424, 10.487216642924718, 23.625485454286846, 21.08559056690761, 17.097607714789255, 11.386449898992266, 13.435567464147296, 21.866295371736797, 21.96289096559797, 34.68922540119716, 35.373671599796836, 27.806953055518015, 28.84528316770281, 21.678409133638652, 11.678825753075735, 6.024223233972277, 13.976235457829066, 22.312562533787318, 35.86668103081839, 46.14395611626761, 30.72691787992205, 10.143354637282235, 5.1825089028903415, 12.231436831610543, 26.849277632577078, 40.69075625283377, 46.562293257032124, 52.34342724936349, 51.778767994471956, 52.814077377319336, 48.22132158279419, 44.06753560474941, 48.24233293533325, 46.38857439586094, 41.26209620067051, 39.307838916778564, 38.016766343797954, 37.04737104688372, 34.71351282937186, 42.37611130305699, 50.058988094329834, 48.40626178468977, 47.36075244631086, 46.61701032093593, 37.03789022990635, 14.954758950642177, 9.390247208731514, 10.130268573760986, 21.508218220302037, 33.316681725638254, 34.467609133039204, 24.455055202756608, 10.954543794904437, 24.031249829701014, 23.35360070637294, 18.437588657651627, 21.361609492983135, 22.579210077013286, 20.551623242241995, 22.242632389068604, 22.796499354498728, 13.662882992199489, 5.49446564912796, 5.328974323613303, 12.062055383409772, 6.108078871454511, 4.99981427192688, 4.900265259402139, 4.987880740846906, 17.28547137124198, 20.102267605917795, 17.533367463520594, 7.030585552964892, 3.761613581861768, 7.291470868246896, 9.158151320048741, 1.2089690757649285, 0.398652758449316, 0.2825277325298105, 0.22214495550308908, 1.2724590003490448, 19.833368846348353, 45.711402961185996, 55.07780395235334, 49.73945781162807, 46.87141513824463, 48.76768970489502, 51.70908103670393, 53.709161690303254, 55.19867134094238, 39.3924297605242, 33.70381103243147, 53.82140983854021, 58.37611729758126, 42.291805335453574, 27.147669758115494, 20.89707030568804, 31.579885687146867, 45.21898065294538, 20.63291542870658, 30.5016816002982, 27.005219527653285, 41.48772505351475, 55.63163096564156, 34.086406639644075, 53.62491825648716, 62.57763739994594, 5.905581874506814, 0.42915659876806395, 0.11189630747373615, 0.09904989573572363, 0.07451784211610045, 0.02769429822053228, 0.04846593451553157, 0.05015229081202831, 0.0768126475491694, 0.09892523528209754, 0.07690241773213659, 0.03591952685798917, 0.1401206161826849, 0.04333509697711893, 0.27591587017689434, 0.12410413633499827, 0.18103741774601595, 0.12689356665526116, 0.2330825871654919, 0.22679799582277024, 0.2202542855271271, 0.1312495714851788, 0.2443909432206835, 0.09127364014940602, 0.13639847162578786, 0.23549944747771534, 0.2502730275903429, 0.20757200462477549, 0.22443655825087003, 0.18337372238082544, 0.11058749484696559, 0.3731450257556779, 4.20303350687027, 82.97708988189697, 64.2477342060634, 68.66631603240967, 84.40139416285923, 54.23594978877476, 45.00225591659546, 61.63502393450056, 47.599343163626536, 42.8208133833749, 44.043658120291575, 14.886376517159597, 52.152251039232524, 53.0157071522304, 67.70305252075195, 59.93575859069824, 18.51237906728472, 34.42524596623012, 56.65486090523856, 75.05824184417725, 55.59106043406895, 59.29029178619385, 39.43522718974522, 40.36621979304722, 62.59533446175711, 43.98392098290579, 25.617700747081212, 9.435147336551122, 6.571166753768921, 6.089003460747855, 2.4128336140087674, 2.1780023063932146, 1.6045862585306168, 2.4175388472420827, 4.659944440637316, 11.969397681100027, 9.162739736693245, 6.224056899547577, 19.274445329393657, 31.782227652413503, 26.532344239098684, 22.306006908416748, 18.270946536745342, 19.89125428880964, 24.274077211107524, 24.628499610083445, 39.938888209206716, 41.47816433225359, 34.44863012858799, 33.645421845572336, 25.779802220208303, 13.148348910467965, 9.813365578651428, 17.909624576568604, 28.950939212526592, 36.88473456246512, 47.43948943274361, 39.96728202274868, 19.65248465538025, 13.635666029793875, 27.356959921973093, 41.837639808654785, 46.87899562290737, 53.115587506975444, 56.71957990101406, 51.70594392504011, 50.282216344560894, 48.22635555267334, 44.76310586929321, 51.75164222717285, 49.733610902513774, 43.76547309330532, 45.672652857644216, 44.61294487544468, 41.36094127382551, 38.10407740729195, 44.91765465055193, 53.10710375649588, 47.81771809714181, 47.46581615720476, 53.75668042046683, 47.1349846294948, 27.274832214627946, 16.52224997111729, 19.8443626335689, 32.7485032081604, 38.736175877707346, 34.83967127118792, 27.58074402809143, 15.436522722244263, 27.053848232541764, 29.26620156424386, 15.418422664914813, 23.903616632734025, 24.07543168749128, 24.38166832923889, 29.0529648235866, 31.057030269077845, 18.08209797314235, 10.540795070784432, 13.588869043758937, 21.248718636376516, 5.01743403502873, 10.493780085018702, 7.097977868148258, 12.584486092839922, 29.68028293337141, 24.617735113416398, 18.62493293625968, 4.626518828528268, 1.8441923899309975, 3.7081788948604038, 6.9300559759140015, 1.6410303200994218, 0.8300311522824424, 1.3093203880957194, 2.871544131210872, 4.104311764240265, 22.309105804988317, 52.29724604742867, 58.105405058179585, 55.05189411980765, 49.64644922528948, 54.109968526022776, 54.66499410356794, 56.2183472769601, 57.380037443978445, 42.58820506504604, 38.44277776990618, 65.7759279523577, 63.53746850149972, 44.570199557713096, 30.177016598837717, 25.24195432662964, 34.74175378254482, 47.612332820892334, 14.517956972122192, 49.156997271946494, 32.21921375819615, 59.69464915139334, 60.15223666599819, 45.84819214684622, 59.74883815220424, 73.2915928704398, 9.686990874154226, 0.8192424454859325, 0.2835140238915171, 0.2483832532806056, 0.40151671905602726, 0.17258433704929693, 0.16799552685448102, 0.13742413158927644, 0.17393151404602186, 0.1869970450976065, 0.24685988788093838, 0.07687815331986972, 0.2757367912147726, 0.10784386564046144], [0.0512864824517497, 0.16870627871581487, 0.06510460722659316, 0.010671026771888137, 0.11553324838834149, 0.10388040688953229, 0.07644689681806735, 0.14081505606217043, 0.15757426034126962, 0.058697499600904326, 0.016172863509772078, 0.07995554033134665, 0.04724184377118945, 0.06743221982781376, 0.0510140777831631, 0.06249549758753606, 0.0839834531236972, 0.09280782139727048, 0.11941593433065073, 22.84368804522923, 56.29895680291312, 53.15215240206037, 93.05231830051967, 36.83869232450213, 25.75684016091483, 43.61610071999686, 45.382492610386436, 28.046926464353287, 53.11349262510027, 19.15826623780387, 15.391534873417445, 30.127673966544016, 55.511117935180664, 57.713860171181814, 24.633917467934744, 22.62756606510707, 47.36262845993042, 51.94488205228533, 47.51520395278931, 51.94432272229876, 27.899513483047485, 39.704115527016775, 55.1635308265686, 42.972603729793, 23.905240774154663, 8.627658094678607, 0.9897859799010413, 0.3649931331830365, 0.6397571765950748, 0.24586643118943485, 0.08488951450479881, 1.1511803652559007, 3.543773659637996, 3.794347413948604, 3.471580356359482, 11.488075120108467, 15.465098925999232, 14.291480439049856, 15.304673705782209, 15.163792031151907, 9.986629332814898, 13.253961529050555, 13.638165644236974, 24.65507994379316, 30.9104962348938, 27.495350667408534, 23.01100066729954, 19.87869541985648, 10.107289143971034, 7.103989796979087, 10.7791599716459, 7.5624167408261975, 13.715109995433263, 30.51602963038853, 36.769335406167166, 23.924421276365006, 8.953397461346217, 2.961186098200934, 6.376546408448901, 11.168523124286107, 30.35022129331316, 42.667178290230886, 46.05124282836914, 49.86783620289394, 51.477393354688374, 43.09893240247454, 41.98424332482474, 42.320421491350444, 40.19497101647513, 35.47324970790318, 34.22504752022879, 34.728774547576904, 30.155251366751536, 31.490500586373464, 39.14869737625122, 49.46426745823452, 54.753722599574495, 39.98691415786743, 21.94625871522086, 7.521738512175424, 4.824436094079699, 4.563035309314728, 7.173192117895399, 18.660545928137644, 36.36530113220215, 28.451214347566875, 24.817893607275828, 7.801760469164167, 3.1362418362072537, 8.925728866032191, 10.602386508669172, 16.690872328622, 24.30478651182992, 19.512212685176305, 11.990369950022016, 15.200914519173757, 7.215529663222177, 3.3178188928536008, 5.488268290247236, 7.958436267716544, 4.655154960496085, 1.2370031028985977, 4.399522917611258, 3.3950452974864413, 14.493516683578491, 19.310954638889857, 19.488569702420914, 18.61241923059736, 11.654977798461914, 2.4828838322843825, 1.2873973016227995, 5.183715718133109, 0.3331603684595653, 0.6466013693383762, 1.334533772298268, 2.7849370070866177, 17.51209381648472, 40.9713523047311, 44.364310537065776, 41.49851908002581, 45.52253702708653, 52.240507057734895, 42.31089898518154, 37.23401008333479, 52.65367126464844, 40.67145068304879, 52.63536276136126, 54.22290802001953, 49.719752720424104, 34.64243275778634, 27.29380600793021, 19.648347003119333, 38.835955483572825, 19.833495650972637, 19.4741712978908, 37.76212876183646, 23.149954216820852, 55.26149695260184, 31.270305224827357, 40.16199834006173, 51.68793766839163, 32.32264811652047, 0.472018868795463, 0.2374041766992637, 0.06908213200845889, 0.008608812117017806, 0.06133185074265514, 0.08737323765775987, 0.032215241342782974, 0.058583247874464305, 0.10702716053596564, 0.09345760010182858, 0.020652845169284513, 0.027687735090564405, 0.015241991495713592, 0.11324663287294762, 0.07337515521794558, 0.07516171078064612, 0.10121991857886314, 0.07688054854848556, 0.018472802060257112, 0.037631687841245105, 0.10415334081543343, 0.06192387254642589, 0.0740174903933491, 0.08804819679686002, 0.033038769116891284, 0.052204486049179516, 0.01806452075418617, 0.01980951943966959, 0.06548832556498901, 0.09770586714148521, 0.043981452472507954, 0.252353524523122, 0.03863496971981866, 34.84090805053711, 70.55660820007324, 57.43687718255179, 96.82450226375035, 38.0078934941973, 27.561888354165212, 35.44768728528704, 36.26881149836949, 37.59025812149048, 47.01875168936593, 25.534596817834036, 26.2877676486969, 32.21368299211775, 56.79620810917446, 63.194296973092214, 27.98646671431405, 24.326379776000977, 49.267807143075125, 57.61330584117344, 48.21590893609183, 58.812207085745676, 31.85359607424055, 45.090379919324604, 62.017800194876536, 46.57778426579067, 24.875575814928325, 10.217689939907618, 1.7233364007302692, 0.6612708078963416, 1.2325493076017924, 0.44117592381579535, 2.5897063059466223, 7.810978123119899, 7.261967079980033, 11.37792011669704, 10.179621628352574, 9.655144674437386, 12.36806012902941, 18.86850377491542, 17.918502637318202, 16.63193075997489, 8.693348101207189, 16.419392313276017, 17.615853003093175, 27.051148857389176, 37.74885075432913, 33.23685039792742, 27.56224618639265, 24.75924038887024, 13.006808025496346, 11.783190301486425, 13.062957286834717, 10.2110561473029, 18.352184874670847, 33.7776460647583, 44.370279039655415, 31.384665625435964, 10.290783252034869, 6.755400844982692, 9.70381941114153, 24.638291358947754, 42.242799690791536, 45.63527154922485, 49.30811364310128, 54.459706102098735, 52.82560443878174, 48.74588973181588, 44.121081897190635, 46.187274660382954, 46.02327285494123, 42.91249486378261, 39.18017618996756, 39.50371905735561, 38.44359070914132, 35.96030453273228, 42.65446308680943, 52.064877441951204, 51.26281908580235, 48.27967255456107, 44.47160809380667, 24.35731315612793, 9.52193033695221, 7.737426229885646, 11.520469358989171, 26.856220620019094, 40.792731489454, 32.957466806684224, 28.821099962506974, 11.05711657660348, 7.844349452427455, 16.157518182482036, 14.298032590321132, 23.178057943071636, 27.438528299331665, 25.145530700683594, 19.605243853160314, 16.865782805851527, 8.0334837606975, 4.981192231178284, 4.650588256972177, 9.84724065235683, 10.18638483115605, 3.622888454369136, 5.785554349422455, 5.132344211850848, 12.945654324122838, 16.536556312016078, 20.204433917999268, 20.550619227545603, 15.564508540289742, 5.6434215647833685, 7.6142164298466275, 12.221218637057714, 1.5982086807489395, 0.8096942092691148, 0.6751669879470552, 1.7095468321016856, 19.964891297476633, 46.542414460863384, 51.126856735774446, 47.621716363089426, 50.159789085388184, 52.75603560038975, 49.3027982711792, 44.44956840787615, 58.21007966995239, 44.03909315381731, 55.7551143510001, 56.832495076315745, 55.522301060812815, 39.19846384865897, 31.54330689566476, 20.788994550704956, 36.27955341339111, 33.67163392475673, 19.980007103511266, 38.25078167234148, 25.730779205049785, 50.691527775355745, 41.53465666089739, 39.22922352382115, 64.04133101872036, 38.54301248277937, 0.276099861732551, 0.07858515065163374, 0.02967869084594505, 0.027345113921910524, 0.08016172676746335, 0.07319471918578659, 0.06343456969729491, 0.05254203686490655, 0.09621557353862695, 0.03265633660235575, 0.04225297950740371, 0.05318531859666109, 0.05961059739014932, 0.10295580793172121, 0.15213095742676938, 0.22855580864208086, 0.1877124381384679, 0.1259556005575827, 0.18413613789847919, 0.2250952393348728, 0.20581767947546073, 0.2639012677328927, 0.29779878737671034, 0.22536444131817135, 0.1672184956925256, 0.22075043033276284, 0.13891028612852097, 0.14666481502354145, 0.1464723010680505, 0.18046898181949342, 0.3451204981122698, 0.22666891132082256, 0.14636672101914883, 53.619199889046804, 80.72803442818778, 65.70660577501569, 97.43158027103969, 46.53970466341291, 35.27167204448155, 58.341487475803916, 59.37453869410923, 38.061523165021626, 66.56664684840611, 22.770136151994976, 20.574529715946742, 34.06954336166382, 61.85384355272566, 66.98836081368583, 30.29156460080828, 27.597449234553746, 56.32030514308384, 62.292900221688406, 55.83573429925101, 63.23180334908621, 32.10048294067383, 48.940612997327534, 64.69856112343925, 50.055197851998464, 30.461250032697404, 15.939853702272687, 3.8620788880756924, 1.4144607463053294, 2.198446729353496, 1.6406655396733965, 2.4267172004495348, 5.884911852223532, 7.544780475752694, 8.17011226926531, 7.296493547303336, 19.357167107718332, 22.80044072014945, 21.71902482850211, 22.618493454796926, 22.591607400349208, 15.64814921787807, 21.087442261832102, 19.952384540012904, 32.70177657263619, 41.16569341932024, 38.172405992235454, 33.36355774743216, 27.68165966442653, 14.576938492911202, 11.662163972854614, 13.614540031978063, 13.243599159376961, 23.31674746104649, 34.76325845718384, 44.14196123395647, 42.79871463775635, 23.297370672225952, 13.480603950364248, 24.776643889290945, 37.478597096034456, 49.57136351721627, 49.093268394470215, 52.31404331752232, 52.000762939453125, 53.34598282405308, 47.672135966164724, 47.619107314518516, 48.245747974940706, 48.377051557813374, 46.04007707323347, 43.56516695022583, 43.523887702396934, 42.71021543230329, 40.501667976379395, 44.73250947679792, 54.15357542037964, 56.46795783724104, 47.34369114467076, 51.67052548272269, 32.314706325531006, 17.202601943697246, 14.465458989143372, 21.74804745401655, 36.22087240219116, 44.66871459143502, 30.428763730185374, 33.296632698604036, 14.958990403584071, 7.706901056425912, 13.65490472316742, 16.779941286359513, 26.582492862428936, 35.2955321584429, 32.679931436266216, 28.01544417653765, 23.549317564283097, 14.029772196497236, 10.082009860447474, 11.389514923095703, 16.550791433879308, 13.443907039506094, 6.803027272224426, 10.93517221723284, 9.648508276258196, 23.248088836669922, 23.824787582669938, 26.750310965946742, 24.80116581916809, 17.147240434374126, 3.1936343908309937, 4.376094460487366, 7.876025421278817, 1.8261796193463462, 1.3847833616392953, 3.775156489440373, 5.107869182314191, 23.550073180879863, 49.452045576913015, 54.044436591012136, 49.146793842315674, 56.93243449074881, 59.56605189187186, 52.082946232386995, 44.53070599692208, 61.77088900974819, 45.38304499217442, 60.59846387590681, 61.277407101222444, 60.46771962302071, 41.83496127809797, 37.232352937970845, 22.264420202800206, 40.579651083265034, 29.311361380985804, 26.151068789618357, 52.57518093926566, 34.506067412240164, 64.50309440067836, 46.80584846224104, 48.94257933752877, 69.96087660108293, 47.786093371255056, 1.3096496675695692, 0.36395464890769547, 0.25325019497956547, 0.19628472386726312, 0.23194253976855958, 0.21640458995742456, 0.13032301834651402, 0.10353634213762623, 0.1545922617827143, 0.1651653437209981, 0.14159400069287845, 0.11756571861250059, 0.2228612442101751, 0.20641046123845236], [0.17216526025107928, 0.10192319298429148, 0.09598305994378668, 0.029000746152762855, 0.0626356489956379, 0.029093138873577118, 0.029388518737895147, 0.03454614823151912, 0.08080769210521664, 0.15793173973049435, 0.05632503244227596, 0.05650310377989497, 0.03862604359164834, 0.06768864499671118, 0.021997806749173572, 0.02574489764603121, 0.03306958817743829, 0.12849561497569084, 0.14493426574128015, 0.9530583449772426, 48.50327600751604, 46.5606187411717, 43.19745091029576, 37.83912869862148, 37.72746767316546, 29.35791778564453, 46.82675906590053, 28.29625735964094, 40.967225074768066, 29.83540494101388, 18.519615616117203, 58.35008239746094, 64.05414349692208, 62.26405824933733, 48.54736927577427, 22.651719740458898, 31.91043928691319, 52.4637804712568, 54.32450805391584, 49.17319004876273, 13.484460200582232, 25.894167831965856, 50.344996792929514, 38.2583760534014, 18.08454200199672, 6.90021823985236, 4.105432595525469, 0.5488428750208446, 0.7108261744890894, 0.4553853156311171, 0.1266898297305618, 2.4448105267116, 4.975643226078578, 6.462892540863582, 13.801797458103724, 14.796730858939034, 7.338245272636414, 10.616824865341187, 16.596864938735962, 15.707945414951869, 8.159493684768677, 10.842918378966194, 15.523307459694998, 25.365875448499406, 28.915850809642247, 30.501539162227086, 24.007674591881887, 14.04032129900796, 6.4802031091281345, 7.433374796594892, 3.159632078238896, 2.3760066415582384, 7.275778795991625, 23.9579758644104, 36.285584449768066, 28.12287722315107, 13.032435587474279, 4.978304386138916, 6.777863936764853, 8.904770493507385, 29.63415036882673, 41.97316094807216, 45.4890467098781, 49.68068299974714, 49.80761963980538, 43.94483041763306, 42.19200488499233, 43.42628288269043, 39.50988558360508, 34.55697686331612, 37.91295678274972, 35.364753586905344, 34.91189432144165, 30.14363397870745, 37.56795787811279, 51.05077396120344, 50.45917306627546, 32.86311026981899, 13.376588548932757, 6.6215676835605075, 5.223597075257983, 4.388794898986816, 9.6462379523686, 24.46300220489502, 41.07409879139492, 28.473090750830515, 21.66127140181405, 10.864202448299952, 7.26691506590162, 11.39872476032802, 19.213516575949534, 9.847255417278834, 19.378402539661952, 18.359664610454015, 12.792350138936724, 11.093956794057574, 8.666299632617406, 1.528147823044232, 3.9510140929903304, 8.241604021617345, 7.939569302967616, 1.5752584551061903, 3.720408592905317, 1.4431614748069217, 11.325726985931396, 21.813935484204972, 19.898930311203003, 15.33773670877729, 12.440835561071124, 14.97155795778547, 5.3595494372504096, 4.057007559708186, 4.42289274930954, 0.34763159336788313, 0.0641691517084837, 0.2919650689831802, 14.71351054736546, 45.026150771549766, 38.41987303325108, 37.66997480392456, 47.64842176437378, 49.91931193215506, 34.368204729897634, 50.094232831682476, 52.17101812362671, 54.085955551692415, 50.861591884068076, 50.64880677631923, 50.237883363451274, 40.96070419039045, 19.1514378956386, 31.555507932390483, 42.272034236363, 13.126786044665746, 32.71948405674526, 23.374083995819092, 37.057195799691335, 53.770990235464915, 27.912807124001638, 43.27456896645682, 56.27343259538923, 7.356789146150861, 0.12240128485219819, 0.1377607120999268, 0.011934302065388432, 0.033352421929261515, 0.014146296540275216, 0.034253587680203576, 0.11070783981787306, 0.02909042812617762, 0.06658044124820403, 0.1934660758290972, 0.05519722242440496, 0.05638492672837206, 0.15699580923787185, 0.1041869961523584, 0.13444412792367594, 0.11116891114839486, 0.08667908276298217, 0.021416173316538334, 0.07704977518213646, 0.022685683498691236, 0.05152288065957172, 0.006557070650160313, 0.04548339991431151, 0.1258330164211137, 0.0572505101029362, 0.030093038255082707, 0.019282389332407286, 0.06707652498568807, 0.03723544713908008, 0.048623293571706326, 0.15470020313348087, 0.08929878433368035, 0.21199662291577884, 7.578903079032898, 68.92034217289516, 55.30997453417097, 50.89541571480887, 40.05655942644392, 41.328840596335276, 38.14037479673113, 33.02382557732718, 36.2905524117606, 45.52756404876709, 29.55449274608067, 25.735170466559275, 51.70880658285958, 66.74276283809117, 62.73754324231829, 48.847048555101665, 26.17633765084403, 32.493994167872835, 58.30925478254046, 58.36537538255964, 56.7825687953404, 16.00641049657549, 33.5667404447283, 54.324087687901084, 43.793390955243794, 20.08210219655718, 6.474342737879072, 3.175549098423549, 1.0685569473675318, 0.821453004011086, 3.259512867246355, 6.235563550676618, 7.3818017925534924, 14.243517892701284, 15.3799261706216, 11.814265251159668, 9.278810262680054, 11.225195237568446, 14.559682641710554, 21.72032414163862, 18.68361394745963, 7.066485158034733, 14.243028044700623, 18.34039899281093, 29.806538649967738, 35.48742403302874, 37.02887494223458, 29.70914227621896, 19.391091687338694, 8.103497283799307, 10.061694196292333, 4.817594724042075, 2.9007198342255185, 11.902860862868172, 30.1860214642116, 41.49896723883492, 33.618254389081685, 14.075728450502668, 6.079102277755737, 9.554856981549944, 21.758435010910034, 39.89684118543352, 46.86777080808367, 51.766695499420166, 52.33137559890747, 53.07181732995169, 46.158196449279785, 44.80374935695103, 49.584617206028526, 45.957945891789024, 38.79246323449271, 42.65296575001308, 41.87185273851667, 40.49479968207223, 35.1641069820949, 44.04032645906721, 51.89400039400373, 53.08763142994472, 45.412265641348704, 31.376828057425364, 14.180292759622846, 9.478906222752162, 8.560761707169668, 14.524189506258283, 29.210428374154226, 42.2021700995309, 31.38423831122262, 25.936308656420024, 15.27429097039359, 8.448271240506854, 10.665893043790545, 22.772022587912424, 17.655853782381328, 21.174741165978567, 19.945187943322317, 12.685758692877632, 11.544408508709498, 9.90964068685259, 3.1122399355684007, 3.7456409760883878, 6.625062193189349, 7.399867108889988, 3.544530144759587, 4.448577633925846, 3.299086115189961, 8.663761803082057, 14.675295455115181, 12.509702631405421, 9.190664546830313, 11.900517582893372, 17.679701736995153, 9.539112363542829, 11.191497342927114, 13.469326155526296, 1.4804513709885734, 0.10090750070022685, 0.36640709159629686, 15.11984293801444, 48.95816414696829, 43.3514438356672, 45.63668203353882, 52.95762716020857, 54.63607917513166, 36.40088285718645, 51.24457311630249, 58.190246037074495, 58.723152024405344, 56.66099269049508, 55.591869899204795, 54.03525454657418, 44.680787086486816, 26.16420783315386, 29.367120674678258, 50.13769728796822, 22.25152955736433, 28.167620147977555, 31.232468809400284, 28.37997967856271, 56.587845529828755, 31.866009031023296, 45.100739683423726, 66.41462721143449, 11.294785789081029, 0.3505326562694141, 0.10678727126547269, 0.04687093278127057, 0.03233316055099879, 0.019241370194192444, 0.10132902700986181, 0.03299147183341639, 0.1270230854196208, 0.06690274538206202, 0.08692418318241835, 0.039398375898599625, 0.013474798777938952, 0.06489691444273506, 0.07026762768094029, 0.24137135382209504, 0.1986117868551186, 0.16250254160591535, 0.14446689082043512, 0.16345121498618806, 0.25620760342904497, 0.1030188166935529, 0.10601972602307796, 0.17484400793910027, 0.4505642428994179, 0.11105660681745835, 0.2050190030464104, 0.16060687761221612, 0.2505040823348931, 0.09204674259360347, 0.15567657431321485, 0.22942501200096949, 0.1394643506833485, 0.4124551921018532, 16.377091680254253, 85.44364479609898, 61.93283067430769, 58.81153311048235, 49.36103459766933, 50.15061398914882, 43.45047998428345, 64.78622654506138, 36.25568287713187, 51.4718382699149, 35.330127239227295, 22.430233751024517, 64.12823908669608, 71.23118795667375, 71.34819562094552, 55.671107155936106, 29.276047161647252, 37.937876496996196, 63.26214613233294, 62.849437032427105, 57.21677214758736, 15.056668179375784, 33.42454556056431, 59.05385153634207, 46.641801493508474, 24.876098666872295, 11.487241336277553, 7.527416058949061, 2.475624050412859, 1.6142991887671607, 2.946164961372103, 4.549523234367371, 6.79960571868079, 11.750331401824951, 11.763797879219055, 22.137872661863053, 27.182902336120605, 17.00849880490984, 19.320755073002406, 24.746431384767803, 24.213066816329956, 16.13844016620091, 19.034180096217565, 23.342912639890397, 34.39844329016549, 39.66385071618216, 41.2483491897583, 35.34010137830462, 23.473891394478933, 10.10034441947937, 10.3324932881764, 5.457708810056959, 5.306676685810089, 17.841226509639196, 32.778606278555735, 39.4801299231393, 40.5227175440107, 31.962606361934117, 19.196031434195383, 19.62251533780779, 33.44578272955758, 51.38403735842024, 51.79434585571289, 55.27586235318865, 49.154033865247456, 52.06911236899239, 45.48291492462158, 47.259739535195486, 53.76275314603533, 49.37745666503906, 41.61429691314697, 47.31381041663033, 46.85778277260916, 44.2264860698155, 38.401039940970286, 46.59178141185215, 54.94842849458967, 57.0809383392334, 47.762862069266184, 39.90493583679199, 24.06335745538984, 20.06982820374625, 15.151978356497628, 27.22372473989214, 36.683601583753315, 40.54717867715018, 33.05815315246582, 29.352824756077357, 19.355683667319163, 12.86091843673161, 16.906712906701223, 29.122627462659562, 16.25439691543579, 26.497274943760463, 24.247993673597062, 17.06908883367266, 16.094885383333477, 15.450646672930036, 8.481464522225515, 9.644620759146553, 16.301384108407156, 16.125761440822057, 7.035263861928668, 8.77389075074877, 7.036072892802102, 20.99757078715733, 33.69024467468262, 27.078173875808716, 21.937851394925797, 17.92846461704799, 20.135615485055105, 7.0274050150598795, 6.726329147815704, 10.776125345911298, 1.7628345212766101, 0.14002722262271813, 1.5739523023366928, 17.43450501986912, 52.94559982844761, 47.20850004468645, 44.38742371967861, 58.236732959747314, 59.465455872671946, 42.709298270089285, 58.633680071149556, 61.41144480024065, 60.37906755719866, 59.29031957898821, 58.97172382899693, 60.45653302328927, 45.683335712977815, 27.28711141858782, 29.18317059108189, 49.98718888419015, 17.876896824155533, 47.525233677455354, 34.48363515308925, 44.18220520019531, 61.92491667611258, 42.95237752369472, 52.181322302137104, 76.98476886749268, 16.4224043573652, 0.5138239541224071, 0.272666257406984, 0.20765359167541775, 0.1638449010040079, 0.05680038354226521, 0.2484569964664323, 0.19168213941156864, 0.18212894988911493, 0.1806788934128625, 0.2100134686167751, 0.25179859144347055, 0.18506750863577637, 0.21974366078419344, 0.2748081753296511], [0.09987181198916265, 0.1318480936544282, 0.17741727057312215, 0.03694643871858716, 0.1277960589421647, 0.24646226636001042, 0.06930149559463773, 0.0655486269720963, 0.08259031216480903, 0.07537696922996215, 0.05602474676977311, 0.022857644628467302, 0.06588912262980427, 0.08202434610575438, 0.02845020149834454, 0.041261928222541294, 0.08103494705366236, 0.044690263723688464, 0.11723858330930982, 0.5775579884648323, 19.220049619674683, 59.82758208683559, 44.39747428894043, 49.50087751661028, 32.81904826845442, 21.90174160684858, 48.42925337382725, 39.4008127621242, 34.13928590502058, 41.0311450277056, 19.393304688589915, 47.700675691877095, 71.05844184330532, 56.42562246322632, 58.038903849465505, 51.914247444697786, 31.88032579421997, 48.161772046770366, 55.49861117771694, 42.054076194763184, 49.04350192206246, 31.764082431793213, 52.98118155343192, 35.75244222368513, 23.08408182007926, 2.633888380868094, 1.006386203425271, 0.2962953437651907, 1.4620653518608637, 0.5135582940919059, 3.4188268099512373, 9.141783101218087, 10.478484494345528, 18.449516977582658, 18.43414408820016, 6.444221428462437, 4.440664504255567, 10.252707123756409, 19.011827741350444, 20.40020636149815, 7.376577615737915, 9.135953562600271, 15.015069314411708, 19.626053707940237, 31.39843695504325, 29.583286081041607, 21.459950821740286, 13.026630367551531, 4.444117758955274, 7.62990893636431, 6.772803911140986, 2.1367877636637007, 4.323195653302329, 6.846948138305119, 21.7975846358708, 25.516981397356304, 17.335861444473267, 5.350562376635415, 7.806847419057574, 9.460288524627686, 27.903472219194683, 42.19452708108084, 47.29015874862671, 49.11793449946812, 49.91203022003174, 43.2518309865679, 43.0710631779262, 43.502160685403005, 42.33560677937099, 36.48383045196533, 36.96998201097761, 35.73592982973371, 36.94864409310477, 32.82606594903128, 37.3691907610212, 52.265735966818674, 51.96355186189924, 28.324352400643484, 10.463985340935842, 4.706333654267447, 6.008477747440338, 4.953765954290118, 12.643721222877502, 29.700429235185894, 40.49829462596348, 30.085432393210276, 20.410727671214513, 11.627122470310756, 5.972433967249734, 14.080811057771955, 17.205516713006155, 6.015600519520896, 6.1978309239659986, 15.005065645490374, 13.033430048397609, 7.185747947011675, 7.56540880884443, 3.151180897440229, 1.7109105246407645, 7.787817171641758, 9.935298647199359, 5.045773565769196, 3.9788003734179904, 2.6930579372814725, 6.114563277789524, 12.101348314966474, 23.083251510347637, 40.33374738693237, 30.707584517342703, 16.45146346092224, 16.46331708771842, 9.97299349308014, 4.07450008392334, 3.7732678822108676, 0.38621447873967035, 0.15678672545722552, 10.715927021844045, 41.70417186192104, 32.89655542373657, 42.80518341064453, 58.55287252153669, 38.764472416469026, 49.51781375067574, 57.63628005981445, 50.88743918282645, 48.69885042735508, 51.09816067559378, 46.70363351276943, 48.179496901375906, 34.2193534714835, 17.50743157523019, 51.57584238052368, 45.437529291425435, 29.363973140716553, 25.902649845395768, 26.22536587715149, 58.285689967019216, 46.30646058491298, 31.495597090039933, 49.1791272844587, 27.4380784034729, 0.45545240917376106, 0.19539606012403965, 0.10431550389954022, 0.06872968734907252, 0.03157568137560572, 0.023037734607766782, 0.07649200582610709, 0.0567609776210572, 0.04856593022122979, 0.018399321806750128, 0.05416881100141576, 0.021720021297889094, 0.03343086736276746, 0.04952389613858291, 0.1756025150950466, 0.10173278248735837, 0.03788974827953747, 0.16303323741470063, 0.09915880739156689, 0.15624602804226534, 0.11682834103703499, 0.007054259127471596, 0.05163541229973946, 0.039357877536011596, 0.023180016615827168, 0.06417037985686745, 0.02130258485807904, 0.026605673599988222, 0.09498909435101918, 0.015672637315999185, 0.03860684444329568, 0.0826918345742992, 0.037864581415695805, 0.13574813652251447, 0.27800535091332024, 34.45387601852417, 71.03290721348354, 51.57119403566633, 56.90321036747524, 33.95829227992466, 29.910077231270925, 36.176956312997, 32.836318016052246, 36.69943652834211, 32.55735131672451, 23.88581361089434, 52.20239618846348, 72.16577625274658, 62.429932594299316, 60.22994531903948, 52.49469995498657, 37.77406576701573, 52.05787018367222, 61.79051072256905, 44.16811077935355, 43.881886686597554, 33.15389238085066, 59.61393887656075, 42.59196751458304, 24.70169540813991, 4.2277213249887735, 1.7890117509024483, 0.7317134365439415, 4.196553877421787, 6.790666426931109, 8.938645567212786, 19.628291027886526, 17.403161696025304, 15.572024754115514, 11.680563671248299, 9.229788116046361, 11.90376239163535, 17.894388914108276, 22.94300559588841, 24.04108500480652, 8.18763996873583, 11.195283242634364, 17.0120267527444, 23.343666519437516, 34.45345217841012, 35.47032799039568, 26.837599447795323, 16.64293496949332, 9.555237395422798, 10.488276243209839, 7.775533625057765, 1.9675413710730416, 6.339603705065591, 15.076861381530762, 30.003360271453857, 33.12450497491019, 22.515898091452463, 9.417128052030291, 9.168763824871608, 18.0423230103084, 37.625224930899485, 48.4006233215332, 53.20411103112357, 50.27765485218593, 52.763748100825715, 48.382599694388254, 46.11689983095442, 48.24178402764456, 47.62708037240164, 44.36674588067191, 42.23488221849714, 43.24126277651106, 43.22606011799404, 37.92931979043143, 41.728108406066895, 53.87646041597639, 51.37221499851772, 39.55891554696219, 23.930111851011002, 10.508478130613055, 10.777600969587054, 8.992732950619288, 18.43731072970799, 35.41322769437517, 42.65960475376674, 30.892267635890416, 25.172413281032018, 13.301743422235761, 9.682217461722237, 19.37287872178214, 20.059984343392507, 13.204935039792742, 10.232377563204084, 19.22655487060547, 15.895425183432442, 10.899434157780238, 8.14349285193852, 4.838255192552294, 2.079792776278087, 6.548198180539267, 6.3543794836316785, 8.090114184788295, 7.348458256040301, 5.994266075747354, 9.962868230683462, 16.34763479232788, 21.028068167822703, 30.29963493347168, 20.911034447806223, 14.061438611575536, 17.86208847590855, 12.846609490258352, 9.426528096199036, 11.136833259037562, 2.066421619483403, 0.38816426268645693, 12.287859678268433, 43.7154495375497, 37.30527775628226, 47.63984073911394, 60.33597482953753, 44.62065042768206, 54.76451662608555, 62.13642678941999, 56.5580655506679, 55.16103989737374, 58.501296043395996, 50.926137174878804, 54.340117182050435, 40.123689447130474, 23.560632705688477, 47.29237869807652, 57.42048985617501, 32.26690966742379, 24.585825511387416, 27.56134292057582, 47.05242613383702, 60.4741883959089, 32.86918994358608, 59.02594757080078, 35.77455833980015, 0.6512510712657655, 0.06790415450398411, 0.06844797318003007, 0.0311212020127901, 0.058936371068869314, 0.07950143755546638, 0.027631325081789067, 0.15294023257281097, 0.12373398191162518, 0.030597030318209102, 0.08368244820407458, 0.025516299198248556, 0.06813337720398392, 0.10758174077740737, 0.0988910710439086, 0.3137412390538624, 0.19168653631848948, 0.18078538269868918, 0.25509985429900034, 0.21652668554868015, 0.35806729910629137, 0.09633861907890864, 0.30006460579378263, 0.19908327369817666, 0.16166256953563007, 0.11564646874155317, 0.1020747437807066, 0.11272434411304337, 0.1578610906643527, 0.14245859001364025, 0.102424861064979, 0.20125439576804638, 0.10720385105482169, 0.2682282584054129, 1.1142307136740004, 52.981970173971995, 83.00540379115513, 56.651859283447266, 65.62093448638916, 44.324375765664236, 33.42685236249651, 66.29616737365723, 47.91008397511074, 41.95290347508022, 49.43068681444441, 21.180317095347814, 56.594797202519004, 78.32100473131452, 65.69502312796456, 64.5441860471453, 60.377809933253694, 40.53339345114571, 56.776523862566265, 65.0279265812465, 47.65336888177054, 54.01887764249529, 36.885193143572124, 61.80897208622524, 44.67291130338396, 29.294803823743546, 8.006952932902745, 3.619997352361679, 2.4065847950322286, 4.3896156549453735, 5.08369596515383, 7.482204130717686, 16.505647250584193, 15.173903397151403, 28.7757716519492, 32.5301456451416, 16.594486917768204, 9.832040599414281, 18.281306300844463, 26.84151128360203, 29.09644317626953, 16.183683361325944, 15.441931894847325, 22.804656539644512, 27.17446722303118, 40.133955410548616, 40.348522731236045, 34.16187449863979, 19.95377939088004, 8.720186386789594, 10.819070424352374, 10.8703533411026, 4.139736286231449, 10.738003185817174, 15.121336800711495, 22.99067371232169, 33.65170649119786, 38.85290561403547, 23.553495168685913, 22.170035873140606, 33.37864228657314, 47.82826893670218, 54.39384412765503, 56.162883281707764, 48.33089467457363, 54.428380148751394, 48.027664865766255, 50.60137837273734, 51.054772649492534, 53.133451325552805, 45.54045295715332, 42.75941910062517, 46.23088502883911, 49.08513552801949, 43.13532359259469, 44.881711619240896, 56.63412053244454, 57.76770176206316, 45.50794233594622, 35.38892636980329, 22.813218457358225, 23.000739915030344, 21.366937024252756, 32.86543444224766, 42.86781447274344, 40.21554463250296, 31.324761731284006, 29.264509677886963, 17.50010643686567, 9.207714557647705, 21.463440554482595, 23.015093156269618, 10.541568926402501, 10.921312298093524, 22.533840077263967, 19.55404952594212, 14.75597620010376, 12.389931321144104, 9.408629536628723, 7.262177262987409, 16.074876308441162, 18.86471700668335, 12.540646433830261, 9.442661813327245, 9.031951189041138, 11.051007372992379, 19.576042311532156, 32.051025663103374, 50.54957955224173, 40.99853713171822, 24.166899510792323, 24.267327036176408, 12.373213955334254, 5.8420180167470654, 7.159924098423549, 1.769989863038063, 0.4533160280968462, 15.014603785106114, 49.82273197174072, 38.732865061078755, 47.44581576756069, 65.24926144736153, 49.023595333099365, 55.92122840881348, 66.29058102199009, 59.986404010227744, 56.78663001741682, 59.065816334315706, 55.502620288303916, 58.31680747440883, 42.84629590170724, 23.370252064296178, 51.65080649512154, 49.44422190529959, 34.0581066267831, 35.82665940693447, 35.1312906401498, 67.53233528137207, 64.51216179983956, 39.99828141076224, 65.73541995457241, 47.187853472573416, 1.317647478410176, 0.20924266640629086, 0.1698594761214086, 0.09127427797232356, 0.1498444572623287, 0.17245646033968243, 0.12192371833537306, 0.23852419374244554, 0.2930765636265278, 0.10978018745247807, 0.1363427231886557, 0.2580170934753758, 0.17460671067237854, 0.14237625657447747, 0.20088694191404752], [0.12889373861253262, 0.09251645846026284, 0.09827806893736124, 0.045954150546874316, 0.020171904637079154, 0.08364648584808622, 0.06479491705873183, 0.15391302108764648, 0.05282106064260006, 0.025838196211095368, 0.02001615201256105, 0.04344234282949141, 0.05559620101537023, 0.041304190776177814, 0.02550803973073406, 0.19480663032404014, 0.02844168758019805, 0.07222298240022999, 0.04156807643760528, 0.24457686181579316, 5.651471921375819, 68.89591925484794, 50.541745458330425, 58.72544492994036, 55.47955921718052, 34.89946052006313, 33.53297219957624, 56.92758117403303, 32.64493335996355, 46.26784944534302, 26.684818983078003, 22.463777916772024, 66.15309701647077, 59.61727401188442, 59.53513240814209, 66.54409299577985, 49.10448278699602, 43.98525503703526, 64.94989136287144, 61.82032544272286, 71.62249660491943, 45.09584467751639, 39.37427064350673, 38.044097082955496, 14.264914870262146, 2.7146787771156857, 0.2593827673367092, 1.0160674325057437, 1.2910661676100321, 2.2031662932464053, 7.072170955794198, 10.6274972983769, 30.353448731558665, 34.874544279915945, 14.420827235494341, 3.046608988727842, 3.459848974432264, 9.60256678717477, 24.18343448638916, 25.63659289905003, 11.24105623790196, 6.564564228057861, 12.133353454726082, 18.2256338596344, 34.148586068834575, 29.868797983442033, 23.791978188923427, 6.378123215266636, 8.707213231495448, 11.895329015595571, 6.5617519446781705, 2.4493253358772824, 4.602785084928785, 12.43393165724618, 16.403713703155518, 28.619412864957535, 22.484738894871303, 8.873496651649475, 6.886542447975703, 8.833310008049011, 22.62752958706447, 41.413414069584434, 47.11865288870675, 49.11913306372506, 48.75944914136614, 43.69972923823765, 39.88713107790266, 44.63960511343819, 40.26229906082153, 33.5389198575701, 35.34637907573155, 36.14512661525181, 37.59530251366751, 32.37758404867989, 38.13303402491978, 52.171803270067485, 49.86767986842564, 30.421346528189524, 13.405360170773097, 5.657311013766697, 6.735674040658133, 5.0591171469007215, 10.203884737832205, 28.05606508255005, 41.021580832345144, 32.26033319745745, 22.20149036816188, 12.84677972112383, 9.392703396933419, 12.280119385038104, 20.128722872052872, 14.894462483269827, 5.279610846723829, 11.4305978843144, 15.15773320198059, 10.37531590461731, 5.8575398581368585, 3.3151798801762715, 1.6692070024354118, 3.5604884198733737, 7.718676515987941, 7.909179619380406, 6.245199399335044, 2.228764976773943, 9.046477266720363, 12.118986317089625, 8.14852247919355, 10.00321468285152, 33.06178706032889, 27.817832197461808, 22.807208265577042, 24.478316034589493, 12.60107752255031, 5.427781181676047, 3.28656068444252, 0.3087850292878491, 2.9164003985268727, 34.31417553765433, 39.4298597063337, 49.192311491285054, 55.867570945194785, 53.27347142355782, 51.6903452192034, 46.931367669786724, 53.67850971221924, 47.266590459006174, 55.386505467551096, 36.83780990328108, 55.834511416299, 29.360714435577393, 20.62077692576817, 51.23099981035505, 53.75853558949062, 34.74412659236363, 22.172650132860454, 43.952768734523225, 60.98324816567557, 37.773301465170725, 32.736913612910676, 64.1392936706543, 14.245018703596932, 0.25200196195925983, 0.08537877217999526, 0.12019939800458294, 0.08021052022065435, 0.03607603435271552, 0.06333327120436089, 0.044797146559825966, 0.12549336893217905, 0.02442319455024387, 0.07434037128197295, 0.07352358475327492, 0.021125495699899535, 0.015421336782830102, 0.1714065902467285, 0.0738122131941574, 0.05701304320245981, 0.09259423892945051, 0.08107088905360017, 0.13320671075156756, 0.02055533290175455, 0.019623561828796352, 0.06991525087505579, 0.04986445286444255, 0.13637689421219484, 0.09697614344102995, 0.053958641564739604, 0.015730596080954586, 0.10096909132386957, 0.044078435482723374, 0.05272477652345385, 0.05294567359877484, 0.032751029556883235, 0.08014370487736804, 0.03548346293557968, 0.3138524373727185, 12.002237473215375, 80.5237226486206, 56.94354118619646, 63.91069793701172, 54.729146821158274, 32.578991481236045, 33.419695717947825, 33.220699310302734, 37.59478139877319, 34.94519703728812, 29.247382368360245, 34.97775282178606, 70.70195756639752, 63.41085842677525, 63.5126564843314, 66.80313573564801, 51.6298576763698, 48.271438939230784, 66.5273825781686, 60.49887534550258, 60.825822830200195, 44.524150371551514, 45.24772187641689, 39.78831727164132, 16.04728674888611, 2.963105320930481, 1.1024436375924518, 4.093067407608032, 7.109517957483019, 9.908385668482099, 14.820542335510254, 13.167950647217886, 18.537990127290996, 19.626771109444753, 16.988995211465017, 11.35290139062064, 10.76188588142395, 17.573522840227398, 26.511808838163102, 29.78294951575143, 13.998454928398132, 8.163005130631582, 15.103066512516566, 21.69254003252302, 33.87414959498814, 34.54898643493652, 26.810982636043004, 11.886904324804034, 14.286744373185293, 12.088909302439008, 7.520133478300912, 2.907340164695467, 7.499000532286508, 11.925063831465584, 19.668402978352137, 35.503491742270334, 30.7691525050572, 12.127430983952113, 11.087765949113027, 18.4814578465053, 36.12175634929112, 47.13080876214163, 51.729435784476145, 50.3526154926845, 52.95003972734724, 46.391638551439556, 45.021210602351594, 50.10267489297049, 47.1661160332816, 40.1752416065761, 40.33862154824393, 42.92370925630842, 44.661596161978586, 39.52206230163574, 43.740619386945454, 53.497252055576865, 52.58087498801095, 36.79918834141323, 21.754389422280447, 10.779201660837446, 10.959733230727059, 9.19375649520329, 21.12368927683149, 37.204310008457725, 41.67172030040196, 31.854488917759486, 26.7005010672978, 16.41068795749119, 10.065440143857684, 17.387245110103063, 19.471683842795237, 19.478175197328838, 10.461226037570409, 14.236116324152265, 15.455234221049718, 12.756000638008118, 7.217342274529593, 4.415340925965991, 2.6616750955581665, 4.842259091990335, 7.320945126669748, 13.275871804782323, 8.851413539477758, 7.512366260801043, 13.575135929243904, 15.573318856103079, 14.023636068616595, 18.750537259238108, 38.63656302860805, 27.827076775687082, 21.901237862450735, 23.151805911745342, 16.63805385998317, 10.829457112721034, 7.751434666769845, 0.5139438105481011, 3.7669406788689748, 35.699778352464946, 46.91918747765677, 53.26575892312186, 57.796585423605784, 61.028731073652, 57.16469539914812, 51.67691782542637, 60.76343495505196, 52.49665239879063, 59.70872620173863, 43.20365565163748, 62.562101227896555, 36.086494241442, 24.79893023627145, 49.108901841299875, 61.815510341099326, 32.76713827678135, 23.932502031326294, 35.36657748903547, 56.43152495792934, 43.746424606868196, 34.84137010574341, 71.18448911394391, 18.36168132509504, 0.37626159137913157, 0.04672680176528437, 0.1575743281947715, 0.02546980258609567, 0.02694808951179896, 0.07039888349494763, 0.058592903427779675, 0.11682588474026748, 0.023614379111677408, 0.01705230426575456, 0.03355661007974829, 0.049925568513572216, 0.057055566992078505, 0.22071829491427966, 0.03787379931392414, 0.12707591615617275, 0.17700465342828206, 0.1592712899936097, 0.2945767231285572, 0.12434570837233748, 0.22472948181842053, 0.20112795755267143, 0.23529851968799317, 0.2713744081556797, 0.17658203467726707, 0.12338848545082978, 0.14200577645429543, 0.2197726478001901, 0.13692040076213224, 0.13322720250913075, 0.27074719752584187, 0.2536748764770371, 0.1591308603861502, 0.13116102266524518, 0.5628339956913675, 20.500979559762136, 94.27732045309884, 65.66565309252057, 73.37190014975411, 71.91355664389474, 45.509644644601, 46.71666833332607, 69.18142073495048, 38.55061033793858, 56.124167919158936, 31.98577513013567, 30.48470367704119, 76.3781077521188, 68.43215479169572, 65.74184703826904, 76.51413958413261, 56.37411199297224, 54.220038414001465, 72.30098124912807, 68.06930596487862, 76.53075967516217, 52.52016510282244, 50.0796902520316, 48.067915780203684, 19.02197732244219, 4.636688385690961, 1.2862467233623778, 4.341772965022495, 5.7626791426113675, 6.4386676464762, 10.702455333301, 17.12129933493478, 43.59137208121163, 50.0305769102914, 25.068322317940847, 9.600021140916006, 7.43897157055991, 16.592075892857142, 33.06163419995989, 33.08583130155291, 20.933588300432476, 12.283107110432216, 21.37938298497881, 25.516581875937327, 41.40010479518345, 39.96814012527466, 36.812897137233186, 10.369775584765843, 15.378432307924543, 16.141902106148855, 8.467490826334272, 4.0585795896393915, 8.914676019123622, 14.386054975645882, 20.447080646242412, 41.283142294202534, 43.08278478894915, 33.003609793526785, 25.15346728052412, 35.17624201093401, 45.72204760142735, 53.359938280923025, 52.69175781522478, 47.98015308380127, 52.77719981329781, 47.51273734228951, 47.27687726702009, 52.90972280502319, 51.72227913992745, 41.672901494162424, 45.75289412907192, 46.21089506149292, 48.61043807438442, 42.381433623177664, 50.03017738887242, 57.020812102726524, 53.607384477342876, 45.24209383555821, 37.054597173418315, 24.632904767990112, 27.287001984460012, 21.03351034436907, 30.408099787575857, 41.193239552634104, 38.9325076511928, 33.31678942271641, 33.209790638514924, 21.654519489833287, 13.168157356125967, 18.96407798358372, 27.185827527727398, 23.158139194761002, 9.643185087612697, 18.68722527367728, 19.569021156855992, 17.228666373661586, 10.662843653133937, 8.102560145514351, 8.88962515762874, 9.41466578415462, 13.609328883034841, 15.363825457436697, 11.01079727922167, 8.109738503183637, 12.592110003743853, 16.248824460165842, 9.671980159623281, 14.098969306264605, 44.86836065564837, 39.66930505207607, 33.85329457691738, 30.425164563315256, 18.96081233024597, 9.097477912902832, 6.674823454448155, 0.755242751113006, 4.408232484545026, 44.322669982910156, 48.25452702386038, 57.56217404774257, 63.127128737313406, 62.38233743395124, 60.22353213174002, 56.38198430197579, 62.179519517081125, 53.83431264332363, 61.295562744140625, 45.426141193934846, 68.774430002485, 37.364941937582834, 24.254995720727102, 59.044610432216096, 57.91549342019217, 39.408261231013704, 29.994536059243337, 56.587227140154155, 64.34056213923863, 48.575815200805664, 41.87967293603079, 81.49349662235805, 22.966242109026226, 0.42998867269073215, 0.20302839843290194, 0.1497378186987979, 0.13838664708392961, 0.1444265858403274, 0.167805265635252, 0.143731168870415, 0.2580472747130053, 0.18866305212889398, 0.23453082516789436, 0.171160132757255, 0.1143844478896686, 0.2080713114035981, 0.29507479497364586, 0.1301810552499124], [0.13322374198053563, 0.0479217697866261, 0.07810883263924293, 0.12123659306338855, 0.00676330246330638, 0.05523417204884546, 0.08926717138716153, 0.06946177235139267, 0.004291226788024817, 0.08862446980284792, 0.025615957332774997, 0.06229417624750307, 0.05793579654502017, 0.033561743197164366, 0.09507598076015711, 0.009965115409743572, 0.02169329719617963, 0.1113729194871017, 0.22778960689902306, 0.14101997363780225, 0.4744822766099657, 43.13344757897513, 61.39170496804373, 56.03586326326643, 57.01877975463867, 64.38874789646694, 22.78261685371399, 57.323920318058555, 33.76462514059884, 34.04760789871216, 37.27608837400164, 15.610630682536534, 50.86846365247454, 64.78594166891915, 51.41494294575283, 60.03237329210554, 67.96055970873151, 58.299707957676475, 59.66403538840157, 59.63279628753662, 53.26116616385323, 51.703529426029746, 33.996583802359446, 34.24654524666922, 6.204734393528529, 0.29507053377372877, 0.820458325956549, 1.901121803692409, 4.111562643732343, 10.064904264041356, 19.921126331601823, 56.88432516370501, 55.772154808044434, 22.40717441695077, 8.412340368543353, 6.307005362851279, 16.875982761383057, 11.245002814701625, 22.764417784554617, 26.5795624596732, 15.317896127700806, 4.450672950063433, 8.485556142670767, 19.578910180500575, 32.761051654815674, 30.371232645852224, 17.499416828155518, 5.152105322905949, 18.839832033429825, 11.597140124865941, 12.645988072667803, 4.660439934049334, 6.085868086133685, 13.923847777502877, 27.546876771109446, 35.86253990445818, 24.271765198026383, 8.638434750693184, 6.163625376565116, 10.697766167776924, 21.251999923161097, 38.99717800957816, 46.518627302987234, 52.516072613852366, 51.04240485600063, 44.79408441271101, 41.45278951099941, 42.429713181086946, 39.83073602403913, 34.16566126687186, 38.05864313670567, 40.130123479025706, 37.12913744790213, 34.73341594423567, 38.54315144675118, 51.12575544629778, 52.92101015363421, 41.304598331451416, 16.702368123190745, 5.535043128899165, 5.1522164940834045, 4.096515016896384, 6.2626584853444776, 20.956741435187205, 36.62500742503575, 31.652529103415354, 20.105955362319946, 10.74148075921195, 11.963873863220215, 19.81725423676627, 19.89417426926749, 22.44662802559989, 7.79672736780984, 4.655945318085807, 12.84871392590659, 11.439743450709752, 7.357872196606227, 4.876753858157566, 1.9732254317828586, 3.8537080458232333, 13.169179609843663, 15.822430883135114, 10.935830559049334, 6.145595235483987, 14.294080802372523, 21.21386820929391, 19.251934903008596, 8.921045780181885, 6.022853136062622, 13.97407717364175, 17.742247683661326, 18.642496245247976, 19.804254157202585, 11.953752074922834, 8.863371389252798, 5.152312900338854, 0.31040363386273384, 11.769501481737409, 33.230020318712505, 41.95471348081316, 51.022505215236116, 34.58981057575771, 53.22124876294817, 51.09905351911272, 51.50220537185669, 48.48623555047171, 55.838082790374756, 39.25314964566912, 57.59890569959368, 22.07945568220956, 22.557413578033447, 43.872958251408164, 45.6029554775783, 54.987258502415244, 38.203381061553955, 57.589289392743794, 66.82760034288678, 34.25379916599819, 45.460552147456575, 50.08154194695609, 1.854890444449016, 0.05913592143250363, 0.07537815666624478, 0.040567484950380664, 0.08293819028351988, 0.06291960911559207, 0.08531365317425557, 0.037810661630438905, 0.02377687976695597, 0.04150601762479969, 0.05053950021309512, 0.04428391624242067, 0.049112646241805384, 0.056717602269990106, 0.042890670110604594, 0.16940549548183167, 0.10700486387525286, 0.06334338816148893, 0.08236625311630112, 0.07456225223307099, 0.040475577382104735, 0.0648846940270492, 0.04219646771837558, 0.025268204743042588, 0.024610982509329915, 0.03334786895928638, 0.03437152724446995, 0.025392754934728146, 0.038602108268865516, 0.08068733356360878, 0.050700435148818154, 0.07938758616468736, 0.046584014248635085, 0.050780597275921276, 0.14099770411849022, 0.14930105927799428, 0.9468463297401155, 58.05427326474871, 72.3935659953526, 60.37968594687325, 63.88856097630092, 51.78280142375401, 25.01942089625767, 33.83276265008109, 32.53510665893555, 35.04991333825247, 26.583957195281982, 25.3674179485866, 57.316589968545095, 69.9027201788766, 54.404214314052034, 68.20576858520508, 70.49633257729667, 64.36507538386753, 63.55356747763497, 63.431828090122764, 54.569932324545725, 51.3275728225708, 39.651851177215576, 38.32918514524187, 6.072319967406137, 0.5047349504062107, 1.4922202080488205, 8.025139842714582, 12.13879302569798, 18.929997069495066, 19.68789267539978, 42.26330382483346, 51.953317165374756, 29.791047641209193, 17.203213385173253, 12.58328926563263, 16.909608568464005, 15.533906936645508, 27.331262009484426, 30.867563315800258, 19.78066849708557, 8.773612822805132, 12.16010228225163, 21.05976584979466, 35.38258613858904, 33.6395262990679, 26.16219285556248, 14.315884249550955, 22.028188398906163, 14.020944510187421, 11.459002988679067, 4.444994969027383, 9.044549141611371, 16.343432869229996, 25.816817011151993, 40.772779737200054, 34.711400577000205, 16.794622829982213, 12.031607508659363, 19.299575226647512, 35.58128377369472, 48.46275758743286, 49.786667346954346, 52.34609188352312, 52.274011271340505, 46.136021273476736, 46.29645865304129, 48.671867098127095, 45.8878698348999, 37.79928077970232, 44.13887970788138, 44.436769826071604, 45.18371507099697, 40.14551721300398, 42.138090338025776, 55.58638777051653, 51.55470248631069, 42.80665642874581, 24.334349359784806, 11.249044060707092, 9.808647751808167, 5.826043673924037, 16.970837831497192, 34.450089250292095, 39.83125366483416, 31.681589944022043, 25.514721495764597, 12.453741839953832, 14.093913623264857, 20.755085604531423, 20.28597971371242, 22.696731907980784, 13.762648701667786, 11.517260159764971, 14.071181723049708, 13.427459784916469, 7.921306831496103, 5.214753321238926, 3.719283853258405, 4.640275393213544, 13.965834004538399, 20.47418209484645, 13.3739994764328, 12.423221009118215, 17.781077691486903, 20.805981159210205, 19.69715462412153, 9.916567172322955, 10.419000097683497, 16.184718642915996, 21.32883484022958, 21.07069536617824, 26.05489877292088, 19.29737091064453, 15.170781918934413, 9.021380373409816, 0.33228383692247526, 10.894420163972036, 38.32791709899902, 47.75882863998413, 54.94898435047695, 44.51358910969326, 60.13111414228167, 55.80704518726894, 57.92497771126883, 54.15687581471035, 60.31595706939697, 43.65131766455514, 60.966815676007954, 30.462695258004324, 22.12235038621085, 50.47944443566458, 48.37935141154698, 54.970134666987825, 36.67427710124424, 47.21439559119088, 73.66980416434151, 41.53183569226946, 47.27203784670149, 56.23480061122349, 2.3767218717506955, 0.05593609616958669, 0.04031256273654955, 0.04848406157855477, 0.006183754677684712, 0.06814801998968635, 0.03454635179202471, 0.03168192978150078, 0.03768463392875024, 0.07125969337565558, 0.06210161479456084, 0.016168402142024467, 0.007734654604324273, 0.03062752028927207, 0.07275179188166346, 0.10718265362083912, 0.24326547075595173, 0.11988108365663461, 0.15515753573604993, 0.14926924955632004, 0.1203758849629334, 0.15389060229063034, 0.19114169983991555, 0.19934479466506413, 0.17233425618282386, 0.23394923923271044, 0.18892983852752618, 0.24366075811641558, 0.15130397251674108, 0.1421541313507727, 0.12395487220159598, 0.1386234693761383, 0.08080703392624855, 0.09967074849243675, 0.28859872104866163, 0.182170177676848, 1.5003314699445451, 72.25933374677385, 83.9370391028268, 69.29509326389858, 74.12494591304234, 74.3162784576416, 37.010118280138286, 70.94703442709786, 40.77918597630092, 43.071198667798726, 44.744568075452534, 17.543817554201397, 63.31699521200997, 70.7766923904419, 58.61077186039516, 69.9983412878854, 76.68940094539097, 67.52749933515275, 69.10408033643449, 70.00890254974365, 63.71378598894392, 58.081986154828755, 41.796426568712505, 43.09889766148159, 7.707804322242737, 0.9718672271285738, 2.7485002194132124, 8.371748123850141, 8.944258843149457, 16.10930289540972, 29.095757041658672, 67.52216311863491, 62.61514377593994, 31.350994655064174, 15.080879177365984, 10.225256528173174, 24.12744763919285, 18.340465000697545, 31.29585722514561, 32.7627991267613, 24.13760069438389, 13.991874115807668, 18.561688695635112, 29.2314327784947, 42.247354234967915, 41.150459493909565, 29.278551987239293, 12.186100704329354, 29.650350093841553, 16.60942554473877, 16.479693991797312, 6.27222832611629, 11.760274274008614, 20.64256821359907, 32.87488399233137, 44.58614567347935, 45.23190082822527, 36.38626732145037, 28.24616084780012, 37.62364074162075, 45.88712985174996, 53.356672627585276, 53.099432945251465, 53.2984745161874, 55.47653675079346, 49.08038990838187, 48.93244538988386, 49.43021781103951, 50.58573797770909, 41.9948810168675, 49.1840500831604, 48.826391560690745, 49.816148553575786, 44.606069632938926, 48.50928272519793, 58.72477790287563, 53.36516332626343, 55.523054940359934, 42.17097963605608, 29.99404968534197, 27.7133503981999, 16.438454696110316, 20.513964005878993, 35.7663698877607, 38.368452889578684, 32.42683635439192, 32.697656290871755, 19.074168716158184, 17.289730616978236, 29.29809726987566, 28.312592574528285, 31.362869126456125, 15.350085394723074, 12.03396555355617, 19.64810902731759, 16.809194939477102, 10.859251856803894, 8.845263515199933, 9.113538673945836, 9.651059133665902, 20.26790050097874, 25.249656404767716, 17.57577405657087, 14.090528113501412, 19.892953123365128, 31.15602125440325, 27.568423134940012, 12.851942232676915, 9.63595722402845, 19.369220495224, 26.677481685365947, 25.747656379427227, 25.203751393726893, 19.803554126194545, 14.231617365564619, 11.012248584202357, 0.6814094558358192, 15.822997161320277, 43.62946557998657, 48.49323238645281, 64.00492245810372, 43.06662327902657, 67.08996432168144, 59.334218297685894, 59.490656988961355, 56.74243252617972, 63.87373352050781, 44.26455177579607, 68.5386984688895, 28.044062069484166, 27.167588506426128, 52.824676854269846, 51.17982632773263, 61.26519216809954, 46.3570990562439, 69.03916331699916, 78.70513589041573, 47.140081133161274, 53.053599153246196, 68.14084461757115, 3.7297517486980984, 0.43832450253622873, 0.13589206737067017, 0.1830664410122803, 0.26730903344494955, 0.21756052864449366, 0.16544008255004883, 0.11108163118894611, 0.1980879713914224, 0.12415622068302971, 0.17740463625107492, 0.09973775382552828, 0.2175051194748708, 0.1623043550976685, 0.1778062204165118, 0.18110832465546473], [0.04901925268183861, 0.14693816964115414, 0.10839828981884889, 0.17230012587138585, 0.11476290758166995, 0.14010258072188922, 0.04753061470442584, 0.05353227051507149, 0.048785823064723184, 0.02261054253072611, 0.037827458764825544, 0.06857791263610125, 0.013717543832691652, 0.0604813817356314, 0.10214917907225234, 0.05546496555741344, 0.03940639278984495, 0.014862583551023687, 0.0512670559941658, 0.13853726828736918, 0.15941640149269784, 9.518490978649684, 65.71945994240897, 59.55171080998012, 53.93292842592512, 65.35528400966099, 49.02685751233782, 35.97207130704607, 55.02236427579607, 21.236705201012747, 55.48913036073957, 14.35416795526232, 39.829613889966694, 58.65933976854597, 59.19348948342459, 55.04511962618147, 51.443152632032124, 59.66846833910261, 58.34754630497524, 57.80309241158621, 48.05648946762085, 41.6882118497576, 40.510235105242046, 25.162859507969447, 1.0465755611658096, 0.46407083528382437, 2.6486018427780698, 3.9609717300959995, 9.631875157356262, 24.211477415902273, 42.41399982997349, 34.658347606658936, 14.107105646814619, 12.822250843048096, 14.464723348617554, 17.96873985018049, 20.99791819708688, 12.255763343402318, 19.14007932799203, 28.749922616141184, 17.919867958341325, 3.6960959775107245, 7.099999359675816, 22.904071365083965, 25.520948818751744, 27.114658866609844, 12.264739547457014, 14.323451706341334, 25.514599902289255, 13.838275500706263, 9.567704200744629, 6.092149691922324, 12.929848040853228, 21.119989361081803, 35.867355006081716, 36.559815951756065, 26.49255016871861, 11.464235850742885, 3.7150615198271613, 9.256602951458522, 14.526769024985176, 33.1527806690761, 43.167076860155376, 47.42353636877877, 53.176085472106934, 45.17785773958479, 41.55400391987392, 42.94745472499302, 41.201712880815776, 40.787666252681184, 38.81530543736049, 38.860315867832725, 34.73250225612095, 33.81459311076573, 37.76731211798531, 48.39487716129848, 51.17501122610909, 42.69712850025722, 25.675204038619995, 2.438691335065024, 4.072038684572492, 3.2653402345521108, 2.7127169966697693, 14.840092829295568, 32.915628228868755, 28.375610998698644, 11.740755915641785, 14.070320146424429, 12.436472092356, 21.33317746434893, 20.224370036806377, 24.816488334110804, 15.407354184559413, 3.0482350843293324, 7.809861200196402, 9.748574495315552, 8.019589100565229, 4.633808357375009, 2.238565193755286, 6.277628379208701, 24.441523586000713, 22.149392775126866, 13.270098720278058, 7.015586997781481, 20.52244254520961, 23.052879197256907, 20.80228819165911, 20.99157796587263, 20.734187160219463, 20.740195614951, 22.800237485340663, 23.98493140084403, 18.133410419736588, 15.59284850529262, 16.19773088182722, 9.71036982536316, 1.4882433414459229, 0.5912878460117749, 22.79848653929574, 26.294519560677664, 35.63992656980242, 42.22785064152309, 48.92203351429531, 49.167391777038574, 49.288019452776226, 52.20701674052647, 52.545741421835764, 41.18050003051758, 48.27991574151175, 18.610807248524257, 26.297040019716533, 16.21055030822754, 45.99575451442173, 37.16211012431553, 41.8506190436227, 70.32043198176792, 44.04345662253243, 26.44104838371277, 54.9643120765686, 33.370568479810444, 0.05711660800235612, 0.04396458748461945, 0.044388196896761656, 0.10348342997687203, 0.017808383962671672, 0.019411202420347502, 0.020679265626573136, 0.02275989657001836, 0.098522680811584, 0.10032687149941921, 0.025176555018073747, 0.024391388221244727, 0.040372324708317, 0.05125540215522051, 0.1941648040499006, 0.20898875860231264, 0.027963021836642708, 0.3123724710728441, 0.11001010225819689, 0.2056604629116399, 0.05438604398763605, 0.13738849493009703, 0.07283763334687267, 0.039755733151521, 0.02124922486421253, 0.09689347073435783, 0.03889860771596432, 0.08957787935755082, 0.061512544618121216, 0.10883122908749751, 0.07539769847478185, 0.08949108115796532, 0.04180165533242481, 0.06750429381749459, 0.01947750716603228, 0.13302513478057726, 0.2848298118582794, 17.498986039842876, 77.96568775177002, 64.79811491285051, 60.618884631565635, 69.76499993460519, 43.14467934199742, 26.338072606495448, 37.74728740964617, 30.16061885016305, 39.39866576875959, 20.889613151550293, 49.87226220539638, 63.2497991834368, 62.936143602643696, 59.425587109157014, 57.71884202957153, 64.17657075609479, 66.10458469390869, 62.165421622140066, 51.966195651463096, 46.41708285467965, 42.92263228552682, 28.702124220984324, 1.0090901383331843, 1.6274015371288573, 6.611144951411656, 11.575026614325386, 17.31438456262861, 25.644598960876465, 40.290505273001536, 47.1817182132176, 22.003117561340332, 18.158715759004863, 18.339033671787806, 17.904712200164795, 17.967028856277466, 13.67257399218423, 24.230098588126047, 34.52168001447405, 24.292870351246425, 6.954105428286961, 10.775841338293892, 24.27567877088274, 29.508280277252197, 28.491018840244838, 22.277540138789586, 20.643923112324305, 25.525149004799978, 14.958387647356306, 11.766472935676575, 9.243809580802917, 16.37086956841605, 22.928165980747767, 37.899630137852256, 42.44305372238159, 37.849936621529714, 19.256630148206437, 10.118127465248108, 18.198131152561732, 31.048146997179302, 44.640233925410676, 48.68800776345389, 50.08171912602016, 55.28048290525164, 46.59468923296247, 46.51755033220564, 50.02213484900338, 48.17511606216431, 46.14048549107143, 44.00377893447876, 46.01584523064749, 44.10582365308489, 40.072238036564414, 44.068758487701416, 52.52512959071568, 53.57108013970511, 47.10437086650303, 29.128436156681605, 12.926201973642621, 7.9365763664245605, 4.982911476067134, 9.109908240182058, 24.70569235937936, 34.92275088174002, 30.348053455352783, 16.550562143325806, 14.00099275793348, 13.345475384167262, 20.17896008491516, 20.7115638256073, 24.379220826285227, 18.60432457923889, 9.826684406825475, 9.074685215950012, 11.704421179635183, 9.403714554650442, 5.55872345822198, 3.9412748898778642, 6.369646847248077, 25.470852306910924, 24.205602713993617, 17.639523778642925, 14.149860518319265, 21.593364919934952, 22.630744865962438, 20.492435012544902, 17.284449986049108, 18.882337638310023, 19.762566702706472, 21.699159928730555, 23.849147966929845, 20.434490510395594, 20.591095958437236, 24.375878742762975, 17.646603993007115, 5.560820945671626, 0.915622102362769, 24.532694373811992, 30.173375742776052, 42.93735899244036, 48.96144022260393, 54.54013844898769, 55.03067432131086, 53.79648665019444, 57.272812843322754, 56.122555937085835, 46.921292781829834, 55.570837702069966, 28.51807859965733, 22.30598953792027, 32.89781999588013, 55.559345381600515, 45.663647992270334, 34.744647707257954, 65.97666835784912, 53.4106045450483, 34.37903002330235, 57.76465497698103, 41.783075605119976, 0.21514138845460756, 0.029884276778570244, 0.06282844793583665, 0.03203929042709725, 0.01852557512133249, 0.012058218675000327, 0.027841762539797595, 0.03119086381047964, 0.07164501984204565, 0.05023091605731419, 0.03693254232140524, 0.07473317520426852, 0.03407647646963596, 0.06535457274211304, 0.04602012111406241, 0.14810529058533056, 0.1310250171061073, 0.440294723957777, 0.20609676092863083, 0.28392054779188974, 0.2009614450590951, 0.12495765196425573, 0.2181071021727153, 0.17992084766072886, 0.08826042219464268, 0.22418643667229585, 0.13948556168803147, 0.17803647448973997, 0.12421548393155847, 0.19505320994981698, 0.2344389786677701, 0.20345284922846726, 0.13797320212636674, 0.18166218564978667, 0.1469890054847513, 0.24321897753647395, 0.3205935199345861, 22.278802973883494, 98.79261425563267, 74.16688523973737, 71.04061276572091, 83.38959053584507, 62.807789530072895, 51.91425439289638, 68.44502980368478, 27.635478462491715, 68.1743905203683, 17.09343879563468, 49.41696064812796, 65.91231414249965, 66.53194754464286, 63.2923777444022, 63.74619238717215, 65.5527240208217, 70.03354086194719, 65.93921061924526, 55.150530747004915, 50.428937980106895, 50.14635821751186, 35.21563482284546, 3.7731840695653642, 2.6545616601194655, 7.171969669205802, 11.201626079423086, 15.133074045181274, 33.72423873628889, 57.56492553438459, 45.66989094870431, 19.406570536749705, 18.620545148849487, 22.12468671798706, 25.67054353441511, 30.271175112043107, 20.11984654835292, 28.199178865977697, 38.437962668282644, 29.796988351004465, 12.542887227875845, 16.063116482325963, 32.51319898877825, 31.46345124925886, 37.57559394836426, 21.011208363941737, 27.035359076091222, 34.06260905947004, 17.121895142963954, 10.787194694791522, 8.459939002990723, 21.60349886757987, 29.327477727617534, 41.932746750967844, 42.1153176171439, 48.21533918380737, 35.339962414332796, 20.385854857308523, 32.158507347106934, 41.86457102639334, 51.83771651131766, 51.48439366476876, 51.29552773066929, 58.548175539289204, 49.50574125562395, 48.21211869376046, 51.764208044324604, 53.624678543635774, 48.47297838756016, 46.66985831941877, 50.494178090776714, 48.482038838522776, 42.54677643094744, 48.63216161727905, 57.121915340423584, 52.54626253673008, 53.61009080069405, 54.9874495778765, 37.944143772125244, 29.245579310825892, 12.247944014413015, 10.718240771974836, 29.36080823625837, 37.36908653804234, 30.515498093196324, 21.87237330845424, 21.13765515599932, 18.08349977220808, 29.111902918134415, 27.009989465985978, 35.24716574805123, 23.205091646739415, 8.45913474900382, 14.098062566348485, 14.636517558779035, 11.255593606403895, 7.83509966305324, 6.907589410032545, 13.984932865415301, 33.36672265189034, 29.271200793130056, 21.26624894142151, 15.751258747918264, 29.931085109710693, 28.8352986063276, 29.156583309173584, 27.816796915871755, 29.004671369280132, 26.685232400894165, 29.869027273995535, 34.62860584259033, 24.284047876085552, 21.962788479668752, 23.64807752200535, 17.193140234266007, 7.964678355625697, 2.070161270243781, 32.32038647787911, 34.33005564553397, 46.01036657605852, 52.89604180199759, 59.77314295087542, 57.11094413484846, 57.331632818494526, 60.25894015175955, 60.51785087585449, 49.58894593375069, 57.97737407684326, 25.370258024760656, 33.82409477233887, 24.516492911747523, 51.17263494219099, 40.62356717245919, 52.642005239214214, 80.26861258915493, 52.69631930759975, 34.440907205854145, 69.37836742401123, 50.29809992653983, 0.39339156076312065, 0.17737902833947114, 0.1772860283298152, 0.17183770425617695, 0.13379570628915513, 0.1620943077972957, 0.12390417206500258, 0.13482094556093216, 0.14945586025714874, 0.1277015661554677, 0.18523639600191796, 0.1462550884378808, 0.12172958946653775, 0.10095286755157368, 0.18296098309968198, 0.19889669013874872], [0.04004362877458334, 0.10966241412929126, 0.07668565293507916, 0.07772492431104183, 0.056400953725512536, 0.039014606670077355, 0.07030088946755443, 0.1766310249056135, 0.04028922452458313, 0.03102012743641223, 0.0639200411470873, 0.03642559523827263, 0.03216701785900763, 0.03509476754282202, 0.021028297254815698, 0.03186452355501907, 0.03360804642683693, 0.038273432691182406, 0.08349731670958654, 0.03158577458400812, 0.11007392526205097, 1.011370015995843, 29.461769035884313, 59.58198411124093, 54.32834693363735, 46.98368065697806, 72.89942264556885, 32.95737995420183, 56.66380671092442, 19.779683589935303, 33.202922344207764, 27.071854489190237, 25.392096212932042, 63.46358830588204, 63.12067386082241, 70.735566002982, 58.15608869280134, 58.224934918539866, 58.57263319832938, 54.72806985037667, 56.95992851257324, 44.626299313136506, 60.74040862492153, 17.315461533410208, 0.10119068050490958, 1.9080634883471896, 1.3263664905514037, 9.898000717163086, 21.009235075541906, 32.56099564688546, 19.747344936643326, 15.508869103022985, 19.81732198170253, 21.982993841171265, 24.614570208958217, 23.151878867830547, 17.19782679421561, 11.292602317673818, 12.151450906481061, 31.093202590942383, 24.289349351610454, 10.790469901902334, 8.412412456103734, 18.87488569532122, 22.308115686689103, 20.108552251543315, 11.935456599508013, 33.49753638676235, 25.927534818649292, 19.863072395324707, 14.645777770451136, 5.206442841461726, 17.323759419577463, 25.318052734647477, 36.78880773271833, 36.80841902324131, 27.376055308750697, 10.601749011448451, 2.7594538373606543, 5.4653739758900235, 11.653726254190717, 23.95030505316598, 39.21690436771938, 47.97835350036621, 53.549443449292866, 44.80965879985264, 41.71160643441336, 46.321124758039204, 41.700298241206575, 40.717419964926584, 42.34395503997803, 37.88483394895281, 33.8214544568743, 33.74212339946202, 41.42046996525356, 47.89538506099156, 51.759945324489046, 46.36486019407, 23.13232316289629, 4.193932669503348, 3.8812020676476613, 3.4099001118115018, 2.447390479700906, 12.247023378099714, 24.874493632997783, 19.13220007078988, 13.834472230502538, 12.363352724484034, 14.39956487928118, 22.055873496191843, 19.871636050088064, 27.09737695966448, 19.740115336009435, 11.17856500829969, 2.9712992012500763, 11.445260320390974, 8.0290846824646, 6.263536129678998, 0.1508799017007862, 17.785583598273142, 33.21585294178554, 25.527464491980417, 14.48334799494062, 9.891407745225088, 24.69452486719404, 24.58392517907279, 19.62894936970302, 18.615841218403407, 22.470581940242223, 24.834518909454346, 24.328250578471593, 24.714493989944458, 24.551577840532573, 23.166899136134557, 10.140620521136693, 12.443322147641863, 11.5891192981175, 0.7717677386743682, 8.91428518295288, 24.50306030682155, 39.994282722473145, 65.82017408098493, 46.198669706072124, 47.21788706098284, 45.502050263541086, 54.66644627707345, 47.99514034816197, 47.779249395642964, 33.85542072568621, 19.481585025787354, 26.121690068926128, 4.642868374075208, 19.208011865615845, 27.36335400172642, 57.264631339481895, 71.66884803771973, 49.11374820981707, 45.08057253701346, 50.64584684371948, 29.818260260990687, 0.142521273078663, 0.12443714775145054, 0.11010576891047613, 0.09462947079113551, 0.13936740159988403, 0.04260302893817425, 0.09180167610091822, 0.15685081987508706, 0.10668414751333849, 0.06702879004712615, 0.07900714515043156, 0.016542787231238823, 0.037293957213738134, 0.07977623066731862, 0.05363532641370382, 0.15096121733742102, 0.11536376391138349, 0.0701302175543138, 0.04874684462057693, 0.10159050726464816, 0.08586480002850294, 0.08024921028741769, 0.05417586437293461, 0.0306122939634536, 0.03205485941310014, 0.04437258380598255, 0.12075247189828328, 0.012251359427214732, 0.044795233091073375, 0.046262955226536305, 0.15346753570650304, 0.03195450069116695, 0.05873841526252883, 0.09644606509911162, 0.06027547349887235, 0.08222959616354533, 0.048794186008828025, 1.5744490985359465, 54.47622891834804, 72.22642707824707, 58.73237228393555, 57.75907904761178, 68.03831005096436, 33.770840304238455, 32.55081306185041, 25.62530381338937, 30.60657160622733, 25.588969945907593, 37.766714572906494, 66.90993649618966, 66.91491140638078, 71.72888047354562, 62.09659971509661, 63.06538009643555, 66.69603620256696, 59.8378723689488, 61.75540842328753, 47.106781891414094, 61.831998416355674, 17.195035355431692, 0.024885612772777677, 3.595457834856851, 4.571778314454215, 17.130919115883962, 26.533996173313685, 33.552413259233745, 24.897856950759888, 18.507407631192887, 17.42071979386466, 22.090671811785015, 28.07173327037266, 22.352030038833618, 16.588306495121547, 11.331267305782863, 17.423144715172903, 31.258330004555837, 29.364476885114396, 13.387512854167394, 9.624623843601771, 22.76334776197161, 26.20631739071437, 23.739724261420115, 23.511621849877493, 33.36534343447004, 22.242720978600637, 17.294059344700404, 11.83041981288365, 7.572952815464564, 22.61764403751918, 27.816128151757376, 36.967216627938406, 40.89373050417219, 42.6541816847665, 21.45564293861389, 7.580975379262652, 14.200095125607081, 24.847793442862375, 40.89280986785889, 46.27184813363211, 48.70276573726109, 54.94021224975586, 48.113158975328716, 47.40938983644758, 50.999857561928884, 48.037722383226665, 44.87172358376639, 47.159306798662456, 42.80449901308332, 41.71531329836164, 40.31073842729841, 48.42327444893973, 50.82739979880196, 51.673686913081575, 53.85782534735543, 36.86328199931553, 15.181131260735647, 5.140478381088801, 5.104945293494633, 7.063144377299717, 20.68225458690098, 30.38688346317836, 23.079016583306448, 15.284695897783552, 14.809849057878766, 15.434842995234899, 24.34568360873631, 20.83196915899004, 26.48353488104684, 22.998559917722428, 16.569907665252686, 8.955300399235316, 12.34097605092185, 9.392439365386963, 7.631490520068577, 3.3126162120274136, 16.279719625200542, 38.99196686063494, 26.02852167401995, 19.580332824162074, 14.92953177860805, 25.111611332212174, 24.105202981403895, 16.82272481918335, 16.634513752801077, 22.89236191340855, 24.578562906810216, 24.916573660714285, 26.0643379007067, 22.769707100731985, 24.37156391143799, 17.68495110103062, 22.190927369253977, 20.567435605185374, 1.1112360400812966, 7.18466272524425, 29.71686519895281, 47.56528309413365, 66.64452225821358, 53.831092153276714, 53.19092335019793, 52.17683029174805, 59.623735836574006, 52.01559386934553, 49.61506768635341, 44.97752032961164, 25.188791922160558, 24.296797820499965, 10.977231400353567, 33.903189590999055, 31.878977843693324, 44.51412412098476, 75.83196544647217, 45.89911202022007, 38.69973257609776, 60.50937407357352, 36.192405632564, 0.11916959897748061, 0.12380756224904742, 0.11758882951523576, 0.013362443556876054, 0.06813955865800381, 0.03658494918740221, 0.04328024759888649, 0.04474182559975556, 0.08447132658745561, 0.0521723167039454, 0.06046506975378309, 0.0852281441912055, 0.054491861523794274, 0.010126829812569278, 0.1663346631186349, 0.16868561053914682, 0.25435807981661385, 0.1648150160908699, 0.18670729707394326, 0.11741695659501211, 0.20141640278909886, 0.16176318270819529, 0.16332282258995942, 0.3198304937354156, 0.13033235498837062, 0.2993488327733108, 0.21209558046289853, 0.22545140236616135, 0.1672747598162719, 0.14681110717356205, 0.24854422892842973, 0.15807322785258293, 0.1705649218388966, 0.26747918288622585, 0.22277515168700898, 0.22303081011133535, 0.11875213709260736, 2.4955807966845374, 70.03747354234967, 88.6607997076852, 66.29078946794782, 70.63966001783098, 83.92230197361538, 48.65071678161621, 70.84057412828717, 25.85384569849287, 38.3385408946446, 33.21167707443237, 31.700197219848633, 74.22185938698905, 68.14222730909074, 74.16229942866734, 65.71911253247941, 68.35826764787946, 69.37299646650041, 65.00847162519182, 65.89330387115479, 51.28265619277954, 70.85367843082973, 20.40826279776437, 0.12945259362459183, 4.362858576433999, 5.302349260875157, 16.91728285380772, 30.238497734069824, 46.0093104498727, 30.93880319595337, 21.94482912336077, 27.042312485831125, 29.196545873369487, 37.142742020743235, 33.046605246407644, 26.19425184386117, 19.337580135890416, 21.1799818447658, 39.04837233679635, 34.301481178828645, 21.573050124304636, 14.00119251864297, 28.997938564845494, 31.792351177760533, 30.516050474984304, 20.559384380068096, 46.885860443115234, 32.819784777505056, 22.30913359778268, 16.43310805729457, 6.8131004231316705, 27.992464746747697, 32.95154346738543, 38.535567487989155, 40.12354353496006, 49.402181829724995, 30.72531979424613, 18.600784472056798, 24.834336519241333, 35.952446120125906, 46.156403814043315, 50.32450655528477, 53.75874056134905, 57.1431177684239, 52.37695925576346, 50.83877052579607, 55.033926078251426, 53.314514432634624, 50.04198932647705, 51.18738944189889, 47.26297739573887, 46.4201956476484, 45.008547510419575, 54.21421234948294, 55.44611406326294, 54.95657525743757, 58.723846844264436, 52.95087351117815, 38.1377066884722, 26.15526897566659, 11.185283916337148, 9.153834751674108, 28.037888595036097, 30.57850088391985, 20.180195127214702, 20.878044400896343, 20.593571254185267, 20.501059464045934, 31.77536630630493, 28.19859000614711, 37.257699966430664, 30.240988663264684, 18.604281152997697, 9.327288712774005, 14.534612672669546, 11.208233816283089, 9.807231187820435, 5.924986456121717, 27.56430459022522, 43.7704028402056, 32.766144684382844, 22.62806112425668, 15.67022885595049, 33.68124328340803, 32.40807621819632, 26.287173577717372, 25.098451444080897, 29.602358886173793, 31.802391324724468, 33.33124514988491, 34.66310364859444, 34.6438501902989, 30.627655914851598, 14.878294025148664, 20.33719662257603, 19.949902296066284, 1.685778021812439, 15.895697900227137, 40.34413841792515, 47.20051309040615, 77.03569916316441, 59.280744961329866, 58.759081159319194, 54.60035848617554, 65.54622745513916, 55.296474184308735, 52.107490743909565, 44.121081897190635, 25.200529166630336, 32.2653671673366, 6.105475468294961, 24.962318863187516, 32.53741346086775, 68.35090950557164, 77.8567955834525, 58.47649097442627, 49.27108669281006, 67.17374570029122, 44.72727400915963, 0.2961253300309181, 0.342210125710283, 0.19899125077894755, 0.17953588760324887, 0.2563581024961812, 0.10556007961609534, 0.2349360462810312, 0.28788631356188227, 0.20199997004653725, 0.09180949960968324, 0.24407243888292993, 0.2149005899471896, 0.10674647095480136, 0.23627251599516186, 0.2620161888854844, 0.2270097801727908], [0.0828360164804118, 0.05537876446864434, 0.010266257732707475, 0.11690490692853928, 0.006433937748494957, 0.0877679211220571, 0.044842455735696216, 0.08771188091486692, 0.034251803133104525, 0.10399514037583556, 0.07898862114442246, 0.015057287478287305, 0.05345824234453695, 0.05316857235240085, 0.035996808603938134, 0.0200961004011333, 0.03717102023905941, 0.10290392035884516, 0.0690217831039003, 0.08012270421854087, 0.008043600928171404, 0.17983717072222913, 11.5950574023383, 53.35918092727661, 63.82654135567801, 69.46340642656598, 69.55137062072754, 46.66333048684256, 40.75855330058506, 38.9043778691973, 19.947713613510132, 38.372062478746685, 16.63492543356759, 53.82982063293457, 56.996538570949006, 62.93792234148298, 62.56362983158657, 58.95856394086565, 57.26667063576834, 54.31325544629778, 56.12316043036324, 54.77216311863491, 49.655561787741526, 5.449329282556262, 0.4332446094070162, 4.023941082613809, 12.30563143321446, 16.146800586155482, 28.76511311531067, 28.787105900900706, 23.28181712968009, 26.14737582206726, 19.42173671722412, 20.91934970446995, 28.087156534194946, 21.56246280670166, 18.237287725721085, 9.549213307244436, 5.2385265827178955, 26.840236289160593, 26.284375190734863, 17.42934250831604, 10.07180643081665, 17.57182400567191, 21.716886520385742, 12.516315579414368, 14.444500616618566, 37.80881718226841, 42.57848106111799, 20.92271958078657, 16.536214113235474, 10.916289619037084, 20.381694623402186, 29.54841307231358, 37.42463738577706, 36.95918798446655, 24.467337880815776, 6.80465749331883, 1.692410511629922, 5.139584234782627, 6.983219683170319, 17.936970949172974, 31.935834952763148, 44.92056247166225, 54.967716693878174, 47.8726783479963, 42.38088124138968, 48.37804167611258, 40.00936378751482, 37.52788066864014, 41.143580777304514, 38.43294954299927, 31.786813463483536, 33.69626876286098, 42.34248202187674, 49.00797578266689, 46.11310264042446, 38.85996150970459, 18.205650840486797, 6.545781944479261, 4.527470086302076, 0.6679561691624778, 3.431942403316498, 13.760826536587306, 20.564373186656407, 14.810816594532557, 15.152450834001813, 16.085977792739868, 18.158324922834122, 18.565454619271414, 19.76615718432835, 29.19764368874686, 22.178128787449428, 16.811788354601177, 3.3989260835306983, 5.05553491626467, 10.189816372735159, 5.482157783848899, 3.5427466290337697, 32.00913497379848, 32.07283953257969, 28.09619961466108, 7.837211046900068, 17.926807471684047, 29.248907497950963, 22.481363807405742, 23.256178276879446, 23.728671414511545, 25.78281773839678, 24.58115632193429, 19.19107563155038, 19.090632472719463, 21.94780990055629, 26.037715877805436, 24.188386814934866, 8.797566737447466, 9.245079364095416, 3.324822242770876, 0.2617205376071589, 16.35386732646397, 38.747682094573975, 56.060435567583355, 51.29990856988089, 42.66698374067034, 44.492344992501394, 49.732950823647634, 49.15619822910854, 50.38695349012102, 25.736943994249614, 27.337940965379985, 27.023027760641916, 23.223169122423442, 25.05008155958993, 40.63694940294538, 74.40404115404401, 74.66352857862199, 84.18456172943115, 59.22737584795271, 47.227461678641184, 16.1034768308912, 0.7063788388456617, 0.16271934711507388, 0.15755807049572468, 0.07599461930138723, 0.06392710469663143, 0.013878929994202085, 0.033404540204043896, 0.05412343057936855, 0.16874528090868676, 0.10825356508472136, 0.03158357613054769, 0.1023408245029194, 0.0917575645393559, 0.04396346450916358, 0.13163290305861405, 0.25158368583236423, 0.0456285419474755, 0.025373284372368028, 0.03909800201654434, 0.07702589074948005, 0.05264285359797733, 0.028974551308367933, 0.052156595047563314, 0.08146441222301551, 0.06382614547120673, 0.049760772713593075, 0.0729688484487789, 0.07286208096359457, 0.036203551438770125, 0.06827308077897344, 0.05336588694314871, 0.02603900186451418, 0.017820729907335978, 0.10759541325803314, 0.1469452671174492, 0.08902268164924212, 0.09440947616738932, 0.5475281998515129, 27.398920093263897, 77.54739924839565, 71.60001918247768, 78.32130350385393, 76.2449733189174, 47.18613031932286, 34.57965578351702, 31.925791331699916, 25.565495456968033, 30.603872231074742, 26.910083055496216, 60.13517883845738, 64.82079383305141, 68.57942186083112, 71.17033563341413, 63.42435877663748, 66.99236992427281, 60.349787848336355, 61.72884546007429, 60.56135354723249, 55.487810203007285, 5.591470752443586, 1.0408663132361002, 9.0300578049251, 22.347951446260723, 23.03190953390939, 27.547990219933645, 25.46547266415187, 23.68230434826442, 24.1556555884225, 18.37881210872105, 21.768709659576416, 29.736723150525773, 20.754491533551896, 17.352710826056345, 9.582009673118591, 10.05316354547228, 27.398015090397426, 32.29746437072754, 22.403041975838796, 14.179060322897774, 21.07147877556937, 24.07520934513637, 22.959761176790508, 26.12836033957345, 35.751750877925325, 33.01049198423113, 19.284732137407573, 15.593392201832362, 11.634770699909755, 24.477480513708933, 32.81056799207415, 37.69932052067348, 42.05689368929182, 37.45657825469971, 15.17432723726545, 6.5819434097834995, 11.01249611377716, 18.91749726022993, 32.34264850616455, 42.51479039873396, 48.74440976551601, 56.023537158966064, 49.46642139979771, 46.87691463742937, 53.22932604381016, 47.436585085732595, 44.03146750586373, 46.016998631613596, 44.94103533881051, 38.521914277757915, 40.60573809487479, 50.6881822177342, 50.55389438356672, 52.42252901622227, 51.511314460209434, 32.79425362178257, 14.961972917829241, 3.4670019277504514, 3.2845997725214278, 7.348709259714399, 15.910412447793142, 23.44950669152396, 17.31192490032741, 18.645880017961773, 19.15008647101266, 15.617177622658865, 19.67295925957816, 21.885190997804912, 29.198699814932688, 23.973967143467494, 19.048922436577932, 10.05283350603921, 8.701570425714765, 11.001114964485168, 7.262040036065238, 5.100447637694223, 33.528841495513916, 33.58808878489903, 28.3977792263031, 14.992913246154785, 19.070011956351145, 29.587434155600413, 22.397235018866404, 20.523000138146536, 22.918091092790874, 23.69152113369533, 25.058061565671647, 19.976270709718975, 20.36657186916896, 22.270246267318726, 25.33593044962202, 27.781552178519114, 15.072930438177925, 21.306204557418823, 8.758112260273524, 0.4196766231741224, 21.221665825162614, 48.73593643733433, 61.66442176273891, 56.447589193071636, 50.82731989451817, 51.74142837524414, 55.75687224524361, 52.561878613063264, 54.39289917264666, 34.56600604738508, 28.673591443470546, 25.514665910175868, 21.01007580757141, 23.50447736467634, 30.842139857155935, 72.25684629167829, 73.27151257651192, 80.45189911978585, 57.42299815586635, 59.348566327776226, 23.36557071549552, 0.4324433138327939, 0.14716318542403833, 0.23018364129321917, 0.0804722990308489, 0.07551244553178549, 0.03895424758749349, 0.03757061968956675, 0.028972251074654714, 0.14141536956386908, 0.017803020143349255, 0.04086769259135638, 0.09413511053259883, 0.010002741872865175, 0.07342789774494511, 0.11067488337201731, 0.2771736298288618, 0.12794844433665276, 0.16962576151958533, 0.17715334759226867, 0.18734319295201982, 0.1382999438792467, 0.14266311403896126, 0.2282969339617661, 0.23310267180204391, 0.12278741198991026, 0.1856382651520627, 0.25111498098288265, 0.10957984998822212, 0.1660540753177234, 0.180573720484972, 0.1534815678106887, 0.07964601979723998, 0.19378376592482838, 0.17915403523615428, 0.16304000919418676, 0.21817625846181596, 0.19556625027741703, 0.700388134590217, 35.594575677599224, 96.51481410435268, 80.99439362117222, 85.97204140254429, 87.6903726032802, 57.26786225182669, 59.77037756783621, 46.789422920772004, 26.844771725790842, 45.953043937683105, 19.787274496895925, 64.15108476366315, 66.69391700199672, 72.11722224099296, 69.41756221226284, 69.51059164319719, 67.70967415400914, 64.94844613756452, 65.60510648999895, 65.52922521318708, 61.851328304835725, 8.312533838408333, 0.9094839660184724, 9.351658650806971, 20.520467519760132, 23.473484924861364, 34.60177884783064, 39.644836970738, 36.66925007956368, 38.64802060808454, 27.848261833190918, 28.24906345776149, 40.897430419921875, 31.8461753981454, 27.98609151159014, 18.00592487198966, 12.109733922140938, 36.14341388429914, 37.08924436569214, 29.291572911398752, 18.515432800565446, 27.089565447398595, 32.368738991873606, 26.142453023365565, 27.594385078975133, 49.48351396833147, 52.725595542362754, 24.752870627811976, 17.857276848384313, 13.393561261040823, 26.868869815553936, 36.92253623689924, 36.99379696164812, 43.19991404669625, 41.45422778810774, 22.945704971040996, 12.582397290638514, 18.967666728155955, 29.755215781075613, 38.85751921789986, 49.706797804151265, 52.9201659475054, 58.25850861413138, 54.6001535143171, 50.15812151772635, 57.646539075034006, 52.42654854910714, 47.50673409870693, 50.30867508479527, 50.5258549281529, 43.192819935934885, 45.06014135905674, 57.200020040784565, 57.71558332443237, 53.51700578417097, 57.76399489811489, 49.958367756434846, 35.497679574149, 18.642468452453613, 4.6289728454181125, 11.622028572218758, 24.097315038953507, 23.757992812565394, 16.526750666754587, 20.94125042642866, 24.059617587498256, 23.910724639892578, 26.793778896331787, 29.287494318825857, 43.08311482838222, 30.722339017050608, 27.245040076119558, 7.661573614392962, 10.522140894617353, 13.05024642603738, 8.572262712887355, 10.05679224218641, 43.06014060974121, 41.22348158700125, 36.96192210061209, 14.609871217182704, 24.897077015468053, 41.05852093015398, 29.275713648114884, 29.87415157045637, 29.547370842524938, 32.613694259098594, 32.705785683223176, 26.086351530892507, 28.048904963902064, 28.870081288473948, 33.67538595199585, 30.635055746350968, 14.888966458184377, 17.70246750967843, 7.598455309867859, 0.9542594062430518, 33.047341755458284, 53.75435624803816, 67.4354634966169, 60.14437825339181, 55.77984993798392, 51.67878689084734, 61.97958510262625, 53.848268100193565, 58.38833917890276, 31.104066099439347, 36.350900990622385, 30.231038842882427, 27.403071641921997, 27.234282527651104, 48.099043709891184, 83.75124427250454, 80.91143907819475, 86.00127247401646, 64.03821127755302, 66.84135777609688, 28.25643375941685, 0.9876381180116108, 0.31840524449944496, 0.5262364223599434, 0.16423896700143814, 0.30967689571636065, 0.10398049759013311, 0.22481045818754605, 0.0857761629990169, 0.3831453834261213, 0.11522668626691614, 0.10321371230695929, 0.2701809736234801, 0.2069128349955593, 0.31491993580545696, 0.14741144781666143, 0.30044298406158176], [0.2031649603907551, 0.06954675207712821, 0.09302319519753967, 0.0932715865118163, 0.03062247538140842, 0.17273035778531007, 0.04656750209895628, 0.0493877514797662, 0.07865385232227189, 0.04298225537474666, 0.01251301694927471, 0.08914441761693784, 0.050018490491701026, 0.039985983832074065, 0.04904447043580668, 0.0865089265363557, 0.10739764065614768, 0.13210858324808733, 0.11283983755856752, 0.1414345856755972, 0.20358163517500671, 0.05856775691998856, 5.408398313181741, 34.27230569294521, 62.56716646466936, 52.607750620160786, 48.46628032411848, 78.0522484098162, 32.98697580610003, 49.61984804698399, 20.02412121636527, 39.487095492226736, 15.427425793239049, 30.65768255506243, 55.04038095474243, 72.11829226357597, 66.76437868390764, 56.50966787338257, 59.8291871207101, 54.83077812194824, 58.78333037240164, 57.77776970182146, 30.83997549329485, 0.9079638847282955, 0.23825611812727793, 12.121396473475865, 14.428994842938014, 23.52039221354893, 29.687026160103933, 33.68534966877529, 24.989098957606725, 19.850711550031388, 16.249359471457346, 22.107311010360718, 30.488243784223283, 23.04183850969587, 15.72367787361145, 9.470576201166425, 2.0003201493195126, 15.845255715506417, 26.20444311414446, 28.799808944974625, 13.15029353754861, 15.045106376920428, 14.653059482574463, 7.745214291981288, 21.383590119225637, 32.37109790529524, 34.58503021512713, 27.699526957103185, 17.473432302474976, 13.046530876840864, 21.0699553830283, 25.48563633646284, 32.51312255859375, 33.92937387738909, 23.106133665357316, 6.729407634053912, 2.3230880754334584, 4.144120599542346, 6.5776251043592175, 13.313099384307861, 26.397212198802404, 41.995947565351216, 52.16799218314034, 49.27844830921718, 45.0540269442967, 48.18092475618635, 38.96131835665022, 31.98773799623762, 41.97965056555611, 37.450008732931956, 35.44365038190569, 34.823461123875205, 43.68604128701346, 50.61279426302229, 43.69729042053223, 26.262632540294103, 3.426817021199635, 3.198066907269614, 1.2495271222931998, 1.956643121583121, 9.60861258847373, 18.836166858673096, 15.844873564583914, 11.030906234468732, 18.412790536880493, 17.61967624936785, 19.142106464930944, 19.33658480644226, 19.06951516015189, 32.469394070761545, 27.13308548927307, 21.00679452078683, 10.171044945716858, 3.525324021066938, 8.606081332479205, 2.4734963817255835, 18.887349026543752, 33.28662729263306, 34.1639415877206, 15.233656167984009, 8.08817390033177, 25.312405586242676, 20.151589393615723, 20.26485197884696, 18.45135303906032, 20.709861516952515, 26.633014951433452, 21.432065963745117, 25.222688708986553, 22.850933279309952, 23.283573286873953, 30.063625471932546, 30.14660780770438, 15.537031888961792, 5.932180881500244, 5.720220438071659, 0.37613340254340855, 6.163413022245679, 34.434139660426546, 48.47169991901943, 46.92909560884748, 43.40334687914167, 45.691586698804585, 45.66329710824149, 50.70666095188686, 57.56678070340838, 22.946368524006434, 29.43140540804182, 28.781701939446585, 35.04434783118111, 32.46323101861136, 57.86388914925711, 66.70924472808838, 72.0799173627581, 79.61824035644531, 49.865171568734304, 44.66222149985177, 4.607803421361106, 0.39488080942205017, 0.1042359863807048, 0.1857376162494932, 0.09726012391703469, 0.13338593899139337, 0.04272659355774522, 0.08259396946855954, 0.018416877204020108, 0.09548388208661761, 0.018702710080625753, 0.09688051071550165, 0.08850558368223053, 0.08476528831358467, 0.05321902482371245, 0.09178480093500443, 0.07882711623928376, 0.12368002480694226, 0.05296872682603342, 0.02785705671911793, 0.15795061657471315, 0.05831602042807, 0.03752788216141718, 0.04085740939314876, 0.03921413328498602, 0.050582672003656626, 0.08310707764966146, 0.02004005340859294, 0.014396458830950516, 0.033101384328412156, 0.09177654316382748, 0.04049096316365259, 0.02827257799383785, 0.058226494517709525, 0.03983942705339619, 0.11583104383732591, 0.06860842635588986, 0.027454520908317397, 0.020982467303318635, 9.239590287208557, 62.43002986907959, 75.3003796168736, 60.71763937813895, 67.61718668256486, 74.34464795248849, 34.21963139942714, 35.298544202532085, 25.59049333844866, 34.64756052834647, 22.452785866601126, 40.25408976418631, 64.93898963928223, 75.5760007585798, 70.03897435324532, 65.07948221479143, 63.43100125449044, 64.49679933275495, 60.418672289167134, 64.88092354365757, 36.81348773411342, 2.3471683604376654, 0.8610918798616954, 24.116571971348353, 22.629362174442836, 26.26881296294076, 31.93086004257202, 32.497860840388704, 26.376775809696742, 20.916035413742065, 16.18368683542524, 22.54937277521406, 31.198363576616558, 23.05080689702715, 16.617791175842285, 8.778420976230077, 4.223859863621848, 17.98995096342904, 30.2508898462568, 36.07062455586025, 16.43712064198085, 15.933054889951434, 19.89154611315046, 19.577325991221837, 27.23750475474766, 31.7388048853193, 34.936859198978965, 21.7126533303942, 16.179934808186122, 11.33922907284328, 22.246413946151733, 29.88160698754447, 30.91253900527954, 40.33333396911621, 32.80896643229893, 12.987700479371206, 6.406085806233542, 10.323000311851501, 16.420455387660436, 27.834262950079783, 37.269095012119834, 46.502531800951274, 56.0391115461077, 51.80549076625279, 48.51333352497646, 50.82587814331055, 45.121455737522666, 39.927395888737266, 46.65705278941563, 45.0455709866115, 41.479078020368306, 41.30690860748291, 48.9854462487357, 50.292961733681814, 52.166804041181294, 43.0795121874128, 22.925468342644827, 5.720340728759766, 1.6631158207144057, 4.716356430734907, 10.384087136813573, 22.008373873574392, 19.551633289882115, 14.42437515939985, 21.795100654874528, 21.148450919560023, 18.281803097043717, 21.57953974178859, 21.63130382129124, 32.76552629470825, 28.916790553501674, 20.055822372436523, 14.692730222429548, 8.716185961450849, 10.207080040659223, 4.729993138994489, 19.755953754697526, 36.364755698612754, 33.659637859889436, 22.05675070626395, 13.594894868986946, 23.81439655167716, 20.83148452213832, 17.18785960333688, 18.05320562635149, 20.165452786854335, 26.866265978131974, 20.68480978693281, 23.763846669878276, 23.965672731399536, 22.597987583705358, 29.39916229248047, 33.41916070665632, 21.079050574983867, 10.831974966185433, 15.656190020697457, 1.0110273829528262, 8.570210388728551, 50.27317326409476, 54.68475825445992, 55.314720153808594, 47.96765327453613, 52.915538447243826, 50.0061331476484, 54.575633321489605, 59.57545280456543, 28.44412544795445, 29.646591118403844, 24.691043819699967, 26.47581716946193, 25.241554805210658, 46.847426482609336, 71.1623660496303, 79.16380732400077, 85.46075820922852, 52.38707930701119, 61.33780779157366, 9.818495954786028, 0.5622160945619855, 0.18363953168903077, 0.0888368376929845, 0.02829417576348143, 0.08033054628010307, 0.05285585931103144, 0.017463052046618292, 0.03557939421651619, 0.042094341412718804, 0.016922838087858896, 0.055604703059153895, 0.01424045514847551, 0.028060035380933965, 0.025890758926314966, 0.10199177930397646, 0.10965739297015326, 0.19288839825562068, 0.17486513751958097, 0.3298710478203637, 0.21755220980516501, 0.14542077534965106, 0.3754802718758583, 0.16305450270218508, 0.08700566166745764, 0.16218477008598192, 0.12744098156690598, 0.13907023040311678, 0.1497646208320345, 0.17103142823491777, 0.17832163561667713, 0.13730698930365698, 0.17527045362762042, 0.21348722864474567, 0.13437342457473278, 0.23485600629023143, 0.21033968111234053, 0.577927002949374, 0.24639557993837766, 15.036714690072195, 84.33787373134068, 85.6086436680385, 67.43552603040422, 76.31503895350865, 88.28769533974784, 49.6381322315761, 57.695930344717844, 25.177751234599523, 47.02485915592739, 21.76698476927621, 37.30800839832851, 69.46948610033307, 81.44283035823277, 73.54587609427315, 65.78787190573556, 71.06516075134277, 64.76693834577287, 66.91992800576347, 68.05673667362758, 47.1428256716047, 3.5360579022339413, 1.469170862010547, 19.315490075520106, 18.67697320665632, 31.243811743600027, 42.62773336683001, 47.663603578295024, 37.52986437933785, 31.33308914729527, 25.00126872743879, 32.14207138334002, 44.01113360268729, 35.33820104598999, 27.72956054551261, 15.931239673069545, 6.997064837387629, 23.29096269607544, 35.43614980152675, 41.242366790771484, 23.068507432937622, 21.526142835617065, 26.523935181753977, 16.461696420397075, 33.712426798684255, 43.049082551683696, 39.259792123522075, 29.703496864863805, 19.701090778623307, 14.8838769027165, 27.227365595953806, 33.12792348861694, 29.11366602352687, 41.337063789367676, 39.67016315460205, 21.937978199550084, 12.840852907725743, 18.44645803315299, 27.121367352349417, 35.87546355383736, 45.26722199576241, 51.429645333971294, 58.97080666678292, 55.74622065680367, 50.974183968135286, 53.887636593409944, 50.2312547819955, 45.11978122166225, 52.90995904377529, 50.33033261980329, 46.94923496246338, 46.91214200428554, 56.11049386433193, 53.897190366472515, 58.04545600073678, 50.49753407069615, 30.8314048903329, 17.85831560407366, 8.92035096032279, 6.073426902294159, 17.333450419562205, 27.795519794736588, 13.917068072727748, 14.25261742728097, 26.47085268156869, 25.3517393384661, 26.876139368329728, 28.83682026181902, 31.24693148476737, 46.775832244328086, 39.70907654081072, 30.005177225385392, 15.545951638902936, 8.76841035911015, 12.96067111832755, 6.911135162625994, 27.347894259861537, 43.004266670772004, 43.28108637673514, 25.585959638868058, 14.931810787745885, 35.32162264415196, 28.0361967086792, 28.40143050466265, 24.25676577431815, 27.067216566630773, 35.58230863298689, 30.242753505706787, 32.59589992250715, 30.42422308240618, 28.775445086615427, 41.65571165084839, 38.358044488089426, 24.861458812441143, 8.714205724852425, 13.644222736358643, 1.0722466579505374, 16.223211663109915, 52.47823619842529, 61.30604757581438, 61.77840001242501, 52.987080574035645, 58.935113770621165, 54.214729990277974, 56.35110650743757, 64.69473266601562, 28.825501646314347, 36.53594888959612, 31.445705550057546, 40.74004677363804, 38.031131744384766, 67.88582488468715, 78.15441472189767, 77.87256799425397, 90.48126247950962, 55.27847140175955, 72.67876870291573, 9.827413967677526, 0.8434449210762978, 0.31397356944424765, 0.3289284812552588, 0.18723918710436138, 0.32430266376052586, 0.09489787888846227, 0.16994147029306206, 0.16421023782874855, 0.16431231663695403, 0.11509119639439241, 0.16065510788134166, 0.16082091469849857, 0.13973728460924967, 0.20090618516717637, 0.17045916537089006, 0.1499229094811848], [0.024883734927113568, 0.04798851727641054, 0.04552298225462437, 0.031635456918073554, 0.049071974852787595, 0.06169446664197104, 0.013377321285328694, 0.03404655646798866, 0.018339251101549183, 0.0237383593339473, 0.03532336259792958, 0.053758324456534216, 0.11756487722907748, 0.03170489819188203, 0.043778248197798214, 0.07620042575789349, 0.02659682889602014, 0.07042559741863183, 0.027387910821874226, 0.036341402613158734, 0.03219568596354552, 0.14019802345761231, 0.9016180623854909, 26.200041430337087, 67.81152084895542, 50.22371251242501, 46.18965789249965, 90.11753817967006, 47.77312108448574, 47.402198450905935, 38.976013796670095, 34.29463720321655, 26.36644557544163, 32.80976894923619, 60.47530705588204, 66.46511977059501, 76.02675819396973, 59.39450781685965, 77.72731590270996, 57.41134602682931, 65.68990230560303, 50.82732336861746, 21.557248183659144, 0.8476303964853287, 5.3060700212206156, 11.136459793363299, 19.810479743140085, 26.860929761614116, 31.125883443014963, 28.636350836072648, 29.183722972869873, 21.02919203894479, 13.903193388666425, 17.37168288230896, 25.592866148267472, 25.129914624350413, 17.67824956348964, 10.152722546032496, 2.3460718478475298, 7.410204291343689, 24.03143916811262, 29.969751834869385, 20.58150397028242, 10.908119406018939, 7.728197285107203, 16.91523139817374, 26.792225973946707, 18.86839955193656, 16.71113153866359, 26.448238032204763, 22.09866918836321, 14.883663245609828, 22.41453777040754, 26.8812723500388, 23.915989637374878, 27.445865597043717, 23.543745109013148, 8.240890962736946, 1.4235334651810783, 4.968908250331879, 5.37449848651886, 13.815306493214198, 21.753922155925206, 36.38479082924979, 56.73331648962838, 49.14243037360055, 47.63445588520595, 48.299815382276265, 37.495446477617534, 34.04003088814871, 43.448565755571636, 38.252911295209614, 34.194788115365164, 37.04840980257307, 48.0772020476205, 46.64752333504813, 32.45431995391846, 10.413454566683088, 1.3641700106007713, 1.7397051623889377, 1.1374431252479553, 10.074496252196175, 19.016776595796856, 19.681872061320714, 16.45246226446969, 11.266070621354238, 26.300215346472605, 24.24422948701041, 21.638048785073416, 17.35984836305891, 20.40779553140913, 36.57682514190674, 34.031415121895925, 16.888352291924612, 18.326474802834646, 8.109364168984548, 1.6472599229642322, 10.679562755993434, 35.01786477225167, 33.76419087818691, 24.363189595086233, 5.586251786776951, 14.588385650089808, 19.187097787857056, 13.910212806292943, 16.274654388427734, 16.80461433955601, 27.47600861958095, 19.277151652744838, 26.48791572025844, 21.40096582685198, 25.036980731146677, 22.47370341845921, 34.35987731388637, 35.72482313428606, 21.086170741489955, 18.723607778549194, 12.033722366605486, 2.9011920945984975, 1.522109512771879, 26.698704957962036, 31.76077161516462, 40.25031341825213, 41.36670133045742, 47.274702480861116, 43.61929341724941, 53.2195360319955, 53.4574944632394, 22.04758255822318, 28.161264283316477, 36.401372705187114, 35.150700432913645, 37.12058768953596, 67.53553145272392, 57.63738829748971, 28.263854435512, 36.56058372770037, 50.113604409354075, 34.4287964957101, 0.4081294227923666, 0.12962035462260246, 0.04711660656279751, 0.13271393147962435, 0.04887721494638494, 0.014437125130955662, 0.09498168474861554, 0.04118857519435031, 0.025918646715581417, 0.10680343396961689, 0.08911850436457566, 0.03204716482598867, 0.01829467643983662, 0.0663264791614243, 0.02714838456761624, 0.08750610159976141, 0.021850084586601173, 0.06595736289662973, 0.045351428245859485, 0.04133364258866225, 0.07565746882132121, 0.06484354087816817, 0.06241899954953364, 0.046091567458851, 0.03164225583896041, 0.04697069099971226, 0.03655401138322694, 0.05438514153606125, 0.06473068693386656, 0.047884572496903796, 0.06703527005655424, 0.0394451744588358, 0.10546061995306186, 0.01061574652391885, 0.10246840944247586, 0.07410975079983473, 0.1057451500424317, 0.07227586063423327, 0.10146284090088946, 2.186035943882806, 45.87700285230364, 81.2468911579677, 56.86051716123308, 60.597706522260395, 89.50842435019356, 46.01798527581351, 35.565507888793945, 31.931033747536794, 29.479612009865896, 29.59610550744193, 40.85615464619228, 65.28489875793457, 73.25887380327497, 76.97889069148472, 68.01973056793213, 81.548873765128, 61.48752062661307, 68.32565975189209, 58.47649792262486, 28.2698872089386, 1.16800434248788, 8.37976895059858, 22.37097430229187, 19.691363300595963, 31.052649429866246, 28.872909205300466, 28.760895558765956, 30.120805672236852, 24.427714041301183, 15.464499643870763, 17.629798037665232, 22.88535291807992, 25.349726097924368, 18.124358654022217, 11.759010570389883, 3.3817180011953627, 9.635877319744655, 27.824238436562673, 38.39797578539167, 28.017601592200144, 11.236869948250906, 15.565964187894549, 24.650495869772776, 29.63429628099714, 24.58007414000375, 18.77755011831011, 22.55088574545724, 20.205608163561138, 12.846665944371905, 21.939452954701014, 29.48388167790004, 25.067895003727504, 35.003565379551475, 27.695745400020055, 13.646789227213178, 6.9094424077442715, 8.254677925791059, 14.442023583820887, 22.559829814093455, 34.678959437779014, 44.72387981414795, 56.407268796648296, 53.17778778076172, 49.258176939828054, 54.45812191282, 41.88836513246809, 39.765186718532014, 48.87432370867048, 46.04185233797346, 39.46994733810425, 47.1588134765625, 52.35593400682722, 53.29607738767351, 50.2831335067749, 26.071689094815934, 5.742099012647357, 1.1258397421666553, 4.598832862717765, 11.10994633606502, 16.97895506450108, 20.454605545316422, 20.059815849576676, 14.352298021316528, 26.25093698501587, 26.250961303710938, 15.028804165976387, 22.326196636472428, 22.300496986934117, 36.5160596711295, 24.094620874949864, 17.307848044804164, 18.5337621484484, 16.11269187927246, 7.571545805249896, 12.79074249948774, 34.078492641448975, 33.658342020852224, 28.943311827523367, 11.439363036836896, 16.787250791277202, 18.664018290383474, 12.290069205420357, 13.91742764200483, 18.017446722303117, 26.946137257984706, 20.206448895590647, 24.736379078456334, 21.911852972848074, 22.23114354269845, 19.275716849735804, 31.34414025715419, 38.37701307024275, 24.23162371771676, 20.559601511274064, 14.383900165557861, 5.122437817709787, 0.7562017110841615, 36.251958642687114, 45.576788561684744, 50.07478134972708, 51.40299899237496, 52.08628831590925, 48.42302778788975, 61.22772053309849, 54.95176362991333, 29.538716861179896, 28.317810671670095, 27.149669102260045, 25.11288980075291, 28.56346423285348, 59.74520424434117, 66.10253497532436, 40.59508303233555, 42.705501079559326, 61.2178749356951, 49.318949358803884, 0.700140930712223, 0.11491621578378336, 0.10260794338371072, 0.15578948254031794, 0.07573044526257686, 0.02043285733088851, 0.03912185252244983, 0.02093442023864814, 0.05188806142125811, 0.04688183005367007, 0.030551955236920288, 0.024073150208485977, 0.02148769430017897, 0.057121907360851765, 0.014906472892367413, 0.02613893141304808, 0.00968179480904447, 0.10429332937513079, 0.08556991549474852, 0.11257685095603977, 0.1557501817920378, 0.15625982944454464, 0.29150306805968285, 0.1227844807186297, 0.1238034503268344, 0.1621760848377432, 0.12235571444034576, 0.10965213432375874, 0.2662376809333052, 0.1815843034003462, 0.14958772675267287, 0.18073579535952636, 0.23027934187224933, 0.09519463617886816, 0.11980974248477391, 0.3254865173782621, 0.3473271754171167, 0.1361740936658212, 0.22429528725998743, 1.7034077729497636, 64.66075597490583, 93.4065305164882, 65.34700870513916, 69.25847625732422, 104.85070691789899, 62.06653485979353, 59.269495827811106, 47.986750398363384, 39.70251049314226, 32.291825907570974, 39.033152307782856, 72.13303634098598, 79.12362589154924, 84.41385923113141, 67.13141032627651, 85.07975373949323, 63.54363850184849, 74.8465997150966, 62.6927273614066, 40.745178018297466, 1.2786669986588615, 8.686492834772382, 16.85415152141026, 27.277385677610123, 37.015562193734304, 39.17098372323172, 37.88945797511509, 38.40263107844761, 33.54792472294399, 24.347339017050608, 27.404499496732438, 34.97353179114205, 38.386882986341206, 28.08443805149623, 19.504932710102626, 9.015714117458888, 12.915154337882996, 34.37720612117222, 43.94388893672398, 32.45132875442505, 17.516858543668473, 16.86594261441912, 24.14530450957162, 40.0115316254752, 27.90762029375349, 22.596636159079416, 32.290488379342214, 25.220529556274414, 17.60725634438651, 27.38849605832781, 31.072232927594865, 23.850443805967057, 33.68628420148577, 38.112439564296174, 24.284768751689366, 14.534405963761465, 17.776957409722463, 25.1436060496739, 35.40782199587141, 42.1243884904044, 51.384249278477256, 61.10515430995396, 55.7283672605242, 52.05614703042166, 56.02629906790597, 47.10423537663051, 42.856322152274, 54.82593175343105, 48.375258922576904, 43.565701961517334, 50.69515126092093, 56.63431508200509, 56.49535805838448, 55.24644715445382, 30.622340542929514, 11.934678401265826, 8.164231487682887, 10.375572987965175, 17.717927251543315, 29.6487763268607, 20.41564004761832, 22.843422276633127, 17.609219210488455, 29.485441548483713, 30.597723075321742, 26.746037823813303, 29.693053722381592, 33.756964751652305, 53.18539605821882, 43.76746375220162, 22.518531458718435, 26.92637484414237, 12.337250079427447, 7.989405257361276, 19.25041151046753, 41.846745422908235, 42.624651840754915, 35.56956563677107, 11.869292378425598, 21.397410086223058, 28.030259472983225, 20.983408621379308, 24.644294602530344, 21.92890558923994, 37.58995934895107, 27.792109966278076, 35.58136715207781, 28.54643246105739, 33.13859939575195, 31.40957144328526, 42.38077354431152, 42.766898836408345, 29.881891863686697, 30.078539780208043, 16.199839660099574, 4.052087800843375, 4.2466655884470255, 50.61942284447806, 48.6549517086574, 57.47202117102486, 51.484629903520855, 61.652248518807546, 49.62978744506836, 67.01256138937813, 58.23295313971383, 29.841321332114084, 31.680075236729213, 42.56792674745832, 39.698730673108784, 48.54243605477469, 73.42573479243687, 70.2511237008231, 42.93482984815325, 47.21569837842669, 69.85885620117188, 54.5187657901219, 0.4794817769101688, 0.2535247302481106, 0.21109102293848991, 0.28579436295798843, 0.24160870537161827, 0.05647885293832847, 0.18514388453747543, 0.1275600508919784, 0.08506045104669673, 0.13534336324248994, 0.2081389884863581, 0.1499585054282631, 0.09680910847548928, 0.24444156193307467, 0.1605321301945618, 0.14776842508997234, 0.12941323859351023], [0.06975713185966015, 0.1125288378181202, 0.07079157885164022, 0.011723313297677253, 0.04251912469044328, 0.02040977356955409, 0.0332948448402541, 0.02230724416274045, 0.030021089794380323, 0.08029555422919137, 0.024479446799627373, 0.08461702841200999, 0.06075575415577207, 0.01892173270295773, 0.015191428762461458, 0.10061712163899626, 0.0955585412947195, 0.07347669119813613, 0.09791691867368561, 0.025883274685059274, 0.059891456605068276, 0.03320203821307846, 0.17885154432484082, 6.545222180230277, 66.3876543045044, 60.93549319675991, 43.915304047720774, 70.49354634966168, 79.21648856571743, 42.892800194876536, 46.7755161012922, 36.601887294224326, 32.51128823416573, 32.89628096989223, 76.47436114719936, 66.13293334415981, 70.15715626307896, 61.274954387119834, 62.08973489488874, 68.79883902413505, 57.71623298100063, 40.29315253666469, 11.001013347080775, 1.540918829185622, 11.336771147591726, 15.861215727669851, 30.25483294895717, 23.778714077813284, 32.75483996527535, 32.65479980196272, 31.08215148108346, 25.205625670296804, 21.09517560686384, 13.088649119649615, 22.69646266528538, 24.818326132638113, 21.830704961504253, 12.59076031616756, 3.7156356147357394, 2.421901664563588, 13.832462464060102, 33.23302888870239, 28.344734941210064, 10.893238970211574, 6.118576731000628, 25.625949995858328, 28.861231020518712, 20.032624074390956, 16.531438963753835, 24.820820535932267, 26.780466147831508, 16.246149403708323, 19.936561754771642, 26.129360880170548, 14.143790398325239, 18.764911345073156, 28.084467581340245, 17.562166009630474, 3.951083140713828, 5.627455472946167, 6.694274067878723, 12.176269003323146, 21.92676728112357, 40.29744304929461, 49.95107214791434, 53.905559471675325, 47.630821977342876, 52.03790800912039, 35.088510581425254, 34.03195708138602, 48.42717933654785, 39.193523679460796, 38.59162902832031, 41.73107181276594, 50.871566023145405, 41.701972757067, 22.375799826213292, 3.7988646115575517, 2.4963913474764143, 1.3906983413866587, 11.886431847299848, 21.86763984816415, 15.392835923603602, 5.582376863275256, 4.4192458135741095, 4.7956744602748325, 21.610158715929302, 28.563330480030604, 23.42852486882891, 20.182430710111344, 23.006647620882305, 37.26722942079817, 33.01946905681065, 17.313674109322683, 26.059444631849015, 14.170164023126874, 8.758834872926984, 25.612689358847483, 35.286016600472585, 33.16649293899536, 9.743654302188329, 9.287485957145691, 16.50711679458618, 10.64632431098393, 12.32855440889086, 13.145595686776296, 25.049979073660715, 24.16840726988656, 28.41450354031154, 22.17117711475917, 19.663633040019445, 28.511771372386388, 31.22182069505964, 39.25953156607491, 36.28415659495762, 29.485837595803396, 44.38476255961827, 32.7821672303336, 18.30593592779977, 1.4354798070022037, 10.78823345048087, 25.486539602279663, 26.092201914106095, 35.682901178087505, 45.54173837389265, 46.57904536383492, 53.69592884608677, 50.18854767935616, 23.429118939808436, 32.736434187207905, 38.00078548703875, 29.376135962350027, 53.83164800916399, 69.49454825265067, 47.85000985009329, 31.262776851654053, 53.51972600391933, 39.66244370596749, 1.0203243983643395, 0.13754879204290255, 0.0016468158345170586, 0.05128782595108662, 0.030543639790266752, 0.07220781035721302, 0.0996389387707625, 0.012881497935658055, 0.06242966612002679, 0.044638596674693484, 0.11987728386053018, 0.0579784560416426, 0.031418522487261465, 0.05522966318364654, 0.06747819736067738, 0.05754563890929733, 0.12830140468265328, 0.0032871779528379974, 0.07895042640822274, 0.10614939406514168, 0.04537145859960999, 0.0731228216152106, 0.02459536772221327, 0.023525289160066416, 0.035824196080544164, 0.05659118441066571, 0.06772299922470536, 0.06950702385178634, 0.010733309501249875, 0.04346859195668783, 0.012388602464592882, 0.027209254247801642, 0.014685387523578746, 0.11078169835465294, 0.04753929316731436, 0.08104038211916174, 0.049093959387391806, 0.06883864650236708, 0.05537993833422661, 0.11220867106957094, 0.08617093467286654, 14.272131443023682, 83.86411775861467, 67.22981766292027, 52.76951857975551, 86.28184768131801, 67.8000076838902, 37.02668625967843, 39.54132965632847, 31.657260826655797, 28.34439969062805, 41.13700430733817, 75.72408771514893, 72.25358758653913, 74.45871652875627, 70.19910948617118, 67.86607810429165, 70.22219140189034, 64.05403927394322, 49.26745973314558, 19.751548596790858, 2.521401822566986, 21.485183204923356, 21.233901602881296, 29.657426834106445, 23.46029029573713, 30.968478952135357, 33.825446196964805, 30.113048008510045, 28.178916181836808, 21.322586672646658, 15.324175562177386, 22.594609022140503, 26.1355082988739, 19.053178208214895, 12.362652693475995, 5.132012869630541, 3.9343996473721097, 20.338115521839686, 36.71510819026402, 37.50916222163609, 14.632676942007881, 14.972240618297032, 30.21403660093035, 31.669628620147705, 24.973168475287302, 16.77338218688965, 22.455384492874146, 22.18496581486293, 17.006221532821655, 17.764813695635112, 29.362097127096995, 17.28766005379813, 21.971748181751796, 35.485252720969065, 17.722229923520768, 8.914339900016785, 10.522217324801854, 13.726451192583356, 25.805828435080393, 33.35166590554373, 42.91027838843209, 55.353042943137034, 59.2568153653826, 52.67582906995501, 55.97169317517962, 42.282897744859966, 38.827207701546804, 54.36693375451224, 43.19228145054409, 43.74216883523123, 48.253380571092876, 52.70177016939436, 56.946681771959575, 33.305703571864534, 12.129529339926583, 4.791594130652292, 7.949957728385925, 9.63412811074938, 20.159546818052018, 18.217127527509415, 10.413182718413216, 7.195497572422028, 12.440436039652143, 25.61811763899667, 28.593110459191458, 12.860154134886605, 22.126140628542217, 23.394786153520855, 32.8146778515407, 29.357351507459367, 17.91183931486947, 23.526039361953735, 20.611419439315796, 13.605254633086068, 26.572650739124843, 32.9757753099714, 29.647341523851665, 17.11350519316537, 11.703526599066597, 16.169509036200388, 10.535464065415518, 9.881947772843496, 11.843194944517952, 23.19029198374067, 23.793749979564122, 24.478969165257045, 21.682149001530238, 19.86494493484497, 25.151884828295024, 27.426775421415055, 36.673446791512625, 37.36962154933384, 31.57274293899536, 36.47776467459542, 31.79163898740496, 25.160816737583705, 3.0094593593052457, 9.269167031560626, 40.49145759854998, 37.82434640611921, 46.54150424684797, 53.197555405753, 55.81116199493408, 56.971163749694824, 53.68333871023995, 28.59886356762477, 27.246024983269827, 25.312316996710642, 28.023512772151403, 43.25251885822841, 71.05173683166504, 58.655004092625205, 31.78183160509382, 52.55016047613961, 57.3044410433088, 6.158274395125253, 0.14345037750899792, 0.05546315726158874, 0.1062217733955809, 0.04737273317628673, 0.06139249141727175, 0.015573118281151568, 0.012790061949220086, 0.06576543926660504, 0.059196616389921734, 0.11727409783218588, 0.09943522898746388, 0.015785959449463656, 0.03276783686929515, 0.029715908491717916, 0.08942373655736446, 0.0913921802171639, 0.016558878689206073, 0.1003876750224403, 0.223610021173954, 0.14583831865872654, 0.24210229888558388, 0.16988759461258138, 0.13918461783656053, 0.07848649844527245, 0.14302334828036173, 0.17092398900006497, 0.14842660405806132, 0.08272088944379773, 0.1864250400768859, 0.1183933142040457, 0.08643466766391482, 0.10459827658321176, 0.20040505991450377, 0.15888331724064692, 0.25308297680956976, 0.25608188446078983, 0.15394126171512262, 0.09757123900843517, 0.21006555296480656, 0.29758605307766367, 17.627642359052384, 101.37308488573346, 79.97912284306118, 63.505569321768625, 89.98630755288261, 93.40293829781669, 59.67918940952846, 55.8817001070295, 45.69374411446707, 37.065957478114534, 39.89641039712088, 84.95246274130685, 78.00195734841483, 81.59943580627441, 72.00532150268555, 70.36817305428642, 75.13873672485352, 71.494323185512, 56.740518297467915, 26.169431141444615, 3.322704779250281, 16.497054065976823, 21.68525310925075, 40.35152087892805, 33.608290672302246, 41.87354115077427, 45.49566486903599, 42.41257892336164, 34.98128945486886, 29.098989691053117, 23.569950239998953, 35.52693496431623, 35.84652778080532, 31.49028866631644, 20.118783473968506, 11.197624785559517, 6.409920343330928, 23.765594141823904, 46.878050667899, 43.07410996300833, 20.60523554256984, 13.898025665964399, 36.891033104487825, 42.159087794167654, 29.552258900233678, 22.888887814113072, 31.061220032828196, 30.92127983910697, 23.30045567240034, 23.462232317243302, 31.90628773825509, 17.380255222320557, 16.688560315540858, 44.31651735305786, 28.840162345341273, 19.76595047542027, 22.905619076320104, 30.52440220969064, 37.004740374428884, 47.28676455361502, 55.413978644779746, 56.53879124777657, 63.399657930646626, 53.388940061841694, 59.18269198281424, 44.86539724894932, 45.220696857997346, 58.51252433231899, 46.45465176446097, 47.11900724683489, 52.81527246747698, 53.996653829302105, 57.273542404174805, 39.32122114726475, 16.90556124278477, 8.605508974620275, 13.653875521251134, 22.83335954802377, 36.23831238065447, 18.08549737930298, 9.896310567855835, 8.566777110099792, 19.30199146270752, 28.222361530576432, 32.299569674900596, 26.226307358060563, 31.91420521054949, 34.2401841708592, 48.416607652391704, 42.6492588860648, 23.41900236266, 32.361405168260845, 17.917615004948207, 15.137630326407296, 37.26317514692034, 41.47661140986851, 40.884663105010986, 19.65143026624407, 15.933412722178868, 25.432098729269846, 18.180687699999126, 21.205318450927734, 20.668617010116577, 33.387153829847065, 34.28286348070417, 35.20810644967215, 31.69383266993931, 26.639398608888897, 36.355049065181184, 39.87746613366263, 47.0792635508946, 46.150247710091726, 39.59523030689785, 57.716743673597065, 38.96860006877354, 27.63808924811227, 3.018360435962677, 18.997047185897827, 44.03521605900356, 41.48704065595354, 49.767038685934885, 60.522561754499165, 60.533658027648926, 62.42889731270926, 55.67886481966291, 29.614000592912944, 36.23195130484444, 45.956754275730674, 40.4987462588719, 61.408137457711355, 82.80895737239292, 63.97654601505825, 46.65417276109968, 66.85873522077287, 69.07034683227539, 4.1372935601643155, 0.16419558147234575, 0.10733314590262515, 0.13524626488132135, 0.13436388437237057, 0.1471236404031515, 0.20541243122092315, 0.11286252776959113, 0.12133335215704781, 0.22360713061477455, 0.3521579104874815, 0.17881636906947407, 0.2140323365373271, 0.16998822135584696, 0.21988419895725592, 0.1212875781846898, 0.23194652955446923, 0.09530174293156181], [0.02938612350927932, 0.046116910741797516, 0.06984678669167416, 0.049530199728906155, 0.09578242392412253, 0.021053866150655916, 0.058050048271460195, 0.10160511612359967, 0.04646367606307779, 0.04500518200386848, 0.02505918881589813, 0.06390450948051044, 0.027681363646739295, 0.04522218428818243, 0.03962714058746185, 0.00893239104854209, 0.04198212529133473, 0.010248396994679101, 0.05087600608489343, 0.08750732296279498, 0.06188997293689421, 0.06636466711227383, 0.08345112204551697, 0.14233204323266233, 45.171003341674805, 83.2312341417585, 42.25681420734951, 58.463358879089355, 99.72001811436245, 60.06184755052839, 46.58840806143624, 34.075800214494976, 37.9089754649571, 27.057344913482666, 73.68827247619629, 71.82992812565395, 58.32488822937012, 71.09847041538784, 46.18432167598179, 48.0498400415693, 43.64442157745361, 26.65826644216265, 9.350402763911656, 1.3794063244547163, 17.704730885369436, 26.8948004926954, 24.14061794962202, 39.440344538007466, 30.128650188446045, 30.552604947771343, 35.12713214329311, 28.293969665254863, 23.228003331593104, 13.711797441755023, 14.151033895356314, 20.010782412120275, 21.831535271235875, 15.911696127482823, 7.326641780989511, 1.5552387407847812, 2.531347300325121, 22.116274186543055, 36.94011517933437, 23.61121732848031, 12.714317526136126, 26.183447395052227, 37.11971569061279, 26.124674320220947, 14.90005578313555, 20.523309332983835, 32.26600987570626, 20.915967668805802, 19.882169519151958, 19.91988434110369, 8.38405077798026, 10.255300538880483, 23.06373402050563, 27.21884536743164, 18.884324823107036, 7.964680092675345, 8.868258578436715, 11.949970517839704, 21.590036732809885, 31.159196581159318, 45.86208854402815, 57.78424889700753, 50.76766960961478, 55.96947322572981, 22.321332897458756, 38.36379759652274, 51.79078837803432, 40.4919022832598, 39.517125606536865, 46.55168683188302, 48.92915194375174, 36.03287499291556, 12.877514209066119, 4.444383527551379, 5.781629920005798, 12.739553383418492, 29.19503811427525, 18.661688906805857, 8.006010583468846, 2.4992889634200504, 1.0627448878117969, 1.1065196245908737, 8.441972698484149, 21.80495320047651, 21.536414010184153, 24.08811388696943, 28.484980855669292, 24.50050684383937, 16.598497765404836, 19.268888507570537, 24.169385228838237, 22.061650923320226, 26.26878343309675, 35.199396882738384, 36.76910958971296, 17.492623226983206, 4.770963191986084, 12.051843268530709, 12.247438532965523, 10.935072336878095, 11.190549782344274, 22.03059594971793, 29.01457950047084, 31.542865685054235, 26.40146449634007, 25.124331746782573, 27.015032121113368, 22.006035804748535, 23.446920224598475, 32.730997221810476, 47.460844721112935, 34.53962026323591, 37.87466526031494, 34.53592382158552, 28.310096434184484, 4.254771964890616, 1.623347046119826, 12.707543901034764, 33.63149070739746, 38.71435506003243, 44.26649032320295, 48.26566846030099, 60.73304353441511, 50.078762667519705, 25.209568772997173, 41.3431955746242, 35.87733956745693, 29.380805151803152, 66.54123728615897, 60.81658172607422, 40.776194776807515, 37.20435169764927, 39.278333391462056, 1.6768146284988947, 0.32054963228957994, 0.13383673051638262, 0.02687769998530192, 0.02595760819635221, 0.02211101183534733, 0.023985843107636486, 0.023218233404414992, 0.10788214858621359, 0.03535453449668629, 0.024709400621109774, 0.07331969176552125, 0.15990565238254412, 0.10104450370584216, 0.07534192289624896, 0.07378875623856272, 0.14779123743729933, 0.10361245341066803, 0.02578776579217187, 0.04300675048891987, 0.04281082010961004, 0.09943560218172413, 0.01941562646866909, 0.01418309349433652, 0.07166853108044181, 0.05198500032669731, 0.0392681107457195, 0.022547745811087743, 0.07710697568420853, 0.1374666350228446, 0.011419925023801625, 0.017040421421240484, 0.08971037010529212, 0.08559724688529968, 0.009501404577999242, 0.08773229124822787, 0.08558835807655539, 0.16429242199020727, 0.030415298284164498, 0.05162800269733582, 0.02325608378409275, 0.03918891892369304, 0.8688701167702675, 62.17012555258614, 85.71461759294782, 48.30695118222918, 68.03332819257463, 100.8459667478289, 47.20593268530709, 34.917018617902485, 32.149050848824636, 30.358482701437815, 34.6316248348781, 78.65929167611259, 75.76167052132743, 66.44116933005196, 73.91079548427037, 52.90353543417794, 60.039898191179546, 56.267648220062256, 42.92535250527518, 13.87491682597569, 2.859259933233261, 27.07348210471017, 24.80719338144575, 26.50547902924674, 33.4825109073094, 22.761044434138707, 30.60532440458025, 33.198016916002544, 28.151555912835256, 25.952204397746495, 15.408726453781128, 14.097537108830043, 21.028663975851877, 20.963324853352137, 13.376765727996826, 8.442756976400103, 4.527222990989685, 7.606798359325953, 31.917460441589355, 43.32086828776768, 29.202952112470353, 15.955737284251622, 27.59378058569772, 32.35031931740897, 27.689648355756486, 16.56791874340602, 19.712755067007883, 25.56825910295759, 18.285334518977574, 14.41979716505323, 25.813636473246984, 10.98875846181597, 11.952049766268049, 27.131629841668264, 28.15987811769758, 17.480663640158518, 11.818098051207405, 18.190218891416276, 24.2948488507952, 34.194232259477886, 41.86542565482003, 50.96696478979928, 61.24253409249442, 53.506368092128206, 62.6191737311227, 30.31997925894601, 40.20449699674334, 56.41886534009661, 46.229335580553325, 46.63308497837612, 46.59855937957764, 56.64647442953927, 46.25292124067034, 25.40106460026332, 7.514261381966727, 10.050272226333618, 9.507229685783386, 26.01191200528826, 17.999350139072963, 10.049269080162048, 4.637800531727927, 1.4424819626978465, 4.452754369803837, 17.779684577669414, 27.53577528681074, 19.564980779375347, 18.947529111589702, 25.93428325653076, 26.693915912083217, 20.422923496791295, 15.565945080348424, 25.95096067019871, 26.36084532737732, 25.0705874306815, 36.06341927392142, 34.968073981148855, 20.122057812554495, 7.211503182138715, 12.026636941092354, 10.68510741846902, 8.294700418199811, 7.107030068125043, 15.594097443989344, 23.08052260535104, 26.552216087068828, 19.566306148256572, 21.27252663884844, 22.784930603844778, 22.15184027808053, 23.788742065429688, 31.62340920312064, 38.97246674128941, 35.246074880872456, 39.87872723170689, 39.600872244153706, 33.77970967973982, 6.45402273109981, 0.12094286882451602, 15.289910520826067, 40.22916657584054, 43.82806246621268, 54.30875301361084, 57.208430835178916, 63.68598624638149, 54.006224972861155, 29.758696828569683, 29.270047392163956, 27.74648462023054, 30.31017882483346, 58.154386384146555, 74.33114065442766, 47.236390113830566, 40.207720960889546, 65.15311227525983, 8.690035547528948, 0.22226515119629248, 0.1401708142033645, 0.06542668065854482, 0.0672860565994467, 0.01990251605665045, 0.01989769167266786, 0.026916781906038523, 0.041005299493138275, 0.03532724381823625, 0.07437637435006243, 0.010112669634898859, 0.05751599371433258, 0.035114845394023826, 0.008836684532330503, 0.04110551911539265, 0.03292334691754409, 0.027865607956690446, 0.02434832160361111, 0.13588802330195904, 0.07882320109222617, 0.2147782500833273, 0.08841164729424886, 0.1729939550693546, 0.1325933558068105, 0.16494141359414372, 0.15974482601242407, 0.18072621444506304, 0.11793096044233867, 0.15483129609908375, 0.18048541593764508, 0.12365267984569073, 0.1567010807671717, 0.10519438316779477, 0.07467790174164943, 0.20117587569568837, 0.19667076958077295, 0.34441748155014856, 0.27596912160515785, 0.1771777341408389, 0.1667117928819997, 0.21603971453649656, 1.1065989860466547, 77.15704250335693, 99.32996709006173, 57.88428906032017, 80.39249897003174, 116.26952934265137, 77.3351526260376, 60.366081374032156, 43.21273347309658, 43.954286915915354, 34.738095555986675, 82.27033301762172, 85.79853793552944, 68.61577483585903, 82.24686895098004, 55.228513853890554, 66.6646511895316, 58.781899043491904, 50.387537138802664, 19.609002828598022, 3.3541327842644284, 20.420493364334106, 33.93802785873413, 34.3828376361302, 52.134776319776265, 38.70931414195469, 39.61462272916521, 45.042708328792024, 39.44099766867501, 34.0551050049918, 21.897763763155254, 24.274525369916642, 30.38671670641218, 31.428029332842144, 25.462912252971105, 17.022747823170253, 7.630807859557016, 10.188702055386134, 38.12382766178676, 52.95527866908482, 32.21675756999424, 18.86641410418919, 32.26340430123465, 47.9378593989781, 38.59328269958496, 23.736609731401714, 29.31833389827183, 37.39408615657261, 27.760318483625138, 24.871420792170934, 24.254726478031703, 13.676538808005196, 11.229384132793971, 27.283772809164866, 44.74170194353376, 28.40092154911586, 30.224698611668178, 38.35528257914952, 40.481507778167725, 43.08777706963675, 48.86271674292428, 51.64915977205549, 62.676107270377024, 55.67968470709664, 62.753996576581685, 33.250128405434744, 46.90622908728463, 59.10010569436209, 49.748216015951975, 47.22777782167707, 49.22586434228079, 55.146313190460205, 49.799657004220144, 30.562881333487375, 12.594947474343435, 24.067910262516566, 28.841032607214792, 44.37570905685425, 19.113837718963623, 11.426573140280587, 3.5116560459136963, 1.010822193963187, 6.763665292944227, 25.377239227294922, 26.8907253742218, 28.31640018735613, 28.54822162219456, 44.9787049974714, 31.077704633985245, 21.598028898239136, 24.954142570495605, 29.194864409310476, 34.583887236458914, 34.59608827318464, 42.87894548688616, 48.15253094264439, 26.16192534991673, 9.47786225591387, 18.681922061102732, 20.468362978526525, 17.640923840659006, 19.92626973560878, 27.88979642731803, 41.91061326435634, 43.389884744371685, 38.00701802117484, 32.356294768197195, 36.463388851710725, 29.4268091746739, 32.356301716395784, 37.77494124003819, 53.13603605542864, 43.38937405177525, 45.156620570591514, 39.926548208509175, 36.6334216935294, 5.860056843076434, 2.083272520984922, 23.249977009637014, 45.64767060961042, 52.74667985098702, 59.909487451825825, 61.28045041220528, 65.32340567452567, 59.98041466304234, 29.55057396207537, 49.83939027786255, 44.51836599622454, 41.88407461983817, 77.21845763070243, 80.38734340667725, 58.86285250527518, 54.873870849609375, 77.26730346679688, 10.417415039879934, 0.41827297849314554, 0.34321582317352295, 0.15106325543352536, 0.11508054339459964, 0.18205327966383525, 0.09464699056531702, 0.34076785881604466, 0.3112060965171882, 0.07719781116715499, 0.2018597847116845, 0.16412961429783277, 0.14441274372594698, 0.1324970716876643, 0.19225860919271195, 0.0880017171480826, 0.22207541923437799, 0.1264843014734132, 0.10304038732179574], [0.11869959134076323, 0.06972726953348943, 0.015965275898841873, 0.030516664630600383, 0.04222571936302951, 0.020145567300330316, 0.04404254098023687, 0.12581276893615723, 0.0011553748668770172, 0.046369346124785285, 0.06335887233061449, 0.04739045311829873, 0.01870043868465083, 0.029347823600151708, 0.009869227385414498, 0.038268754192228825, 0.033975154227976284, 0.05182805856955903, 0.021494343943361725, 0.11923836171627045, 0.01695923979527184, 0.04359776806086302, 0.12581545593483107, 0.1164584851690701, 16.859842096056255, 103.87461008344377, 59.1904114314488, 47.30087634495327, 74.49668148585728, 78.65041187831334, 52.265221800122944, 43.98078734534127, 35.26028047289167, 27.71624779701233, 55.658447538103374, 75.51639911106655, 58.15375062397548, 60.47989981515067, 55.88341283798218, 54.46307250431606, 45.44637087413243, 24.184627839497157, 0.9542848105941499, 6.372858217784336, 30.33601917539324, 33.758604526519775, 33.83497565133231, 35.31402131489345, 38.61259174346924, 33.006594044821604, 32.706633363451274, 35.337534018925254, 33.46087769099644, 24.535765477589198, 18.076110363006592, 19.133773837770732, 21.103364058903285, 18.003453050340923, 8.647624611854553, 5.205862666879382, 0.8986975390996251, 5.410639541489737, 33.13996819087437, 35.07628870010376, 33.48361914498465, 21.79587016786848, 34.688009466443745, 32.52811677115304, 18.19338379587446, 18.375765323638916, 26.304181030818395, 16.446101188659668, 18.993034601211548, 13.459038478987557, 3.6213298865727017, 1.8263717804636275, 7.04050714629037, 26.90623549052647, 33.98747818810599, 22.167883668627056, 12.059897967747279, 17.733475582940237, 20.718258414949688, 30.081110613686697, 43.68498863492693, 51.17998266220093, 61.22973551068987, 41.94535425731114, 17.297024488449097, 45.89637442997524, 51.173413140433176, 44.355802467891145, 40.3407963344029, 50.35849019459316, 46.71878753389631, 40.167647225516184, 16.302393334252493, 13.192271079335894, 21.21592661312648, 33.64035313470023, 35.21192795889718, 14.063675931521825, 3.367420562676021, 0.09048163371958903, 0.569206959434918, 0.17807698303035327, 2.7461465171405246, 7.284451016357966, 9.608974763325282, 22.13739844730922, 21.823662962232316, 10.502004146575928, 10.621622596468244, 24.654392072132655, 21.745690277644567, 34.97355610983712, 44.13002075467791, 32.62587445122855, 22.195296049118042, 4.546820819377899, 12.062523518289838, 12.591341359274727, 9.276135206222534, 7.644139715603419, 13.807145833969116, 26.466400623321533, 27.23985845702035, 24.35420731135777, 24.471994910921367, 27.342573676790508, 25.3998121874673, 24.382663658687047, 24.604140962873185, 30.47756440298898, 50.11910390853882, 41.16875410079956, 31.33069896697998, 39.25926406042916, 43.52702481406075, 12.432131205286298, 1.173702733857291, 3.155863331896918, 25.077462673187256, 37.528617177690776, 44.409817763737266, 52.5235002381461, 65.51371683393205, 38.67352744511196, 24.91881619180952, 43.83793585641043, 27.35602365221296, 43.60490369796753, 73.64055919647217, 53.802093846457346, 34.041027954646516, 43.553087506975444, 14.48820652280535, 0.22458069265953132, 0.1133282199235899, 0.1059743252449802, 0.010182060018580939, 0.04329764862943973, 0.046838247749422274, 0.04412340878375939, 0.03408956541014569, 0.12652613994266304, 0.08005196694284678, 0.06634969184441225, 0.04823500529995986, 0.05995586993438857, 0.17176406963595323, 0.10733798385730811, 0.06644761123295341, 0.08069755908633981, 0.02546673221513629, 0.08477227722427674, 0.07078309037855693, 0.04320347475420151, 0.024842495265017663, 0.02663484212410237, 0.02293560321309737, 0.04732759024149605, 0.002652121761847021, 0.029615322460553477, 0.05141572980210185, 0.10770032834261656, 0.05604529620281287, 0.03971643240324088, 0.0376319931820035, 0.019641529436090162, 0.03979324596002698, 0.02751160436309874, 0.05515230679884553, 0.10468529191400323, 0.11006367938326937, 0.07148265319743327, 0.07130102972899165, 0.03679112205281854, 0.15400762243994645, 0.3485071478145463, 26.89916569846017, 111.39005960736955, 63.588301522391184, 59.96674755641392, 91.07044192722866, 66.49497617994035, 41.864376476832796, 33.828715324401855, 28.777128287724086, 35.900598662240164, 68.23055280957902, 80.18464360918317, 65.56659957340786, 67.6489816393171, 62.09039497375488, 64.77121148790631, 56.98772825513567, 27.991853305271693, 1.054508124079023, 11.243048633847918, 31.983384949820383, 27.31171498979841, 38.359250000544954, 36.228901045663015, 32.7179901940482, 29.567221845899308, 31.72917468207223, 32.749184131622314, 31.122187001364573, 23.610998460224696, 16.3904686995915, 16.969277960913523, 19.999161549976893, 14.612261397497994, 9.046589306422643, 6.195763834885188, 4.692249655723572, 14.233275379453387, 39.7198531968253, 43.0667587688991, 25.594144616808208, 22.778305496488297, 32.73022249766758, 29.982724121638707, 18.06928375789097, 18.840118646621704, 25.872546775000437, 13.18536022731236, 15.133728912898473, 16.68672251701355, 7.2487099170684814, 2.2639780129705156, 10.896094679832458, 30.196356909615652, 36.37718949999128, 19.756744112287247, 17.0259005682809, 21.660111052649363, 30.217184134892054, 35.157019819532124, 48.992919036320274, 58.687042236328125, 59.995957783290315, 53.29463563646589, 22.94675588607788, 49.46371160234724, 54.857174328395296, 48.2327617917742, 47.58955315181187, 52.500602449689595, 50.89916426794869, 42.67590870176043, 20.879213435309275, 13.505533218383789, 20.01793384552002, 30.259964193616593, 36.015087604522705, 17.944056374686106, 9.498505353927612, 0.41865054251892225, 0.745123351258891, 1.1616585744278771, 5.949982166290283, 13.633386152131216, 19.754301820482524, 18.611201558794292, 15.869529247283936, 14.31410811628614, 12.288613557815552, 21.578645161220006, 25.793681246893748, 26.936482736042567, 39.58607605525425, 37.39192526681082, 26.69721804346357, 8.17654195853642, 9.595222541264125, 10.806698288236346, 4.821847890104566, 3.2169521110398427, 7.871946828705924, 20.544888700757706, 21.706646612712316, 16.53432420321873, 20.45161955697196, 26.517165899276733, 22.935279199055262, 22.73123492513384, 25.21622688429696, 30.558514390672954, 38.476420947483604, 38.15224231992449, 34.34393119812012, 42.33724308013916, 50.87953213282994, 13.84875077860696, 1.4235788456031253, 0.9126527245555605, 27.7288361958095, 42.07216930389404, 56.0278902053833, 59.96407944815499, 68.10000310625348, 45.7376879964556, 28.150536264692033, 25.84997728892735, 25.370511634009226, 38.71669660295759, 75.81024537767682, 64.84304891313825, 41.90216425486973, 57.91994374138968, 26.94367412158421, 0.6624999876533235, 0.09106796261455331, 0.06488607145313706, 0.029309547439749752, 0.06277265878660337, 0.1297251611415829, 0.02870023317102875, 0.018821728515571783, 0.06400314133082118, 0.09856094340128557, 0.025615012472761527, 0.0846743578357356, 0.07984438272459166, 0.08373862411826849, 0.0507827923367066, 0.05973942404878991, 0.07595906406641006, 0.038807684023465426, 0.034282483093972714, 0.1421626673213073, 0.3219826439661639, 0.1368004764829363, 0.17678733223250934, 0.1638585395578827, 0.16778474673628807, 0.08342569055301802, 0.12958456868571894, 0.13590965499835356, 0.2325981403035777, 0.13651589889611515, 0.12768122367560863, 0.08559769471841198, 0.09497245667236191, 0.08566590105848652, 0.1570752114057541, 0.09827399772724935, 0.2020178698003292, 0.15833236037620477, 0.2619863876274654, 0.33680176734924316, 0.19065785008881772, 0.30544853689415113, 0.4523017539509705, 32.0755215372358, 128.9697107587542, 72.34863199506486, 66.17586626325334, 94.41144153050014, 96.21375560760498, 67.2908992767334, 55.317885058266775, 41.41133655820574, 36.46340274810791, 67.1284156526838, 88.38965320587158, 70.58982753753662, 76.00790078299386, 64.90096909659249, 71.54738657815116, 60.36485849108015, 39.9065443447658, 3.2243043908051083, 8.651978526796613, 37.98676402228219, 42.11308029719761, 42.4176024709429, 45.70689705439976, 52.9901898929051, 44.920461722782676, 43.595329080309185, 45.00217253821236, 44.60301242555891, 34.779732636043, 26.60094380378723, 27.072663954326085, 31.925694056919642, 28.633062601089478, 16.603549105780466, 11.851501515933446, 8.934868352753774, 19.53544225011553, 47.488335268838064, 42.00884689603533, 41.12410497665405, 30.28990398134504, 43.76678630283901, 45.77631998062134, 25.566619328090123, 28.92940674509321, 35.41204997471401, 22.51580602782113, 27.614159652165004, 21.49257435117449, 13.738796404429845, 2.080967456102371, 11.421355043138776, 34.996082169669016, 47.388333320617676, 37.69325474330357, 27.78661915234157, 34.64755705424717, 37.577115603855674, 45.25595201764788, 53.21249403272356, 58.27822412763323, 58.74858243124825, 53.0609746660505, 26.8228588444846, 53.2982382774353, 57.44183472224644, 50.5298501423427, 51.7599071093968, 54.129774366106304, 48.7185173034668, 49.53355489458357, 30.920150756835938, 29.75390257154192, 38.48255968093872, 45.19547489711216, 42.16776956830706, 21.358918803078787, 7.783037679536002, 0.6915670164993831, 1.0371785568339484, 1.8505198104040963, 11.7435108763831, 14.064650416374207, 16.60887142590114, 31.944117205483572, 32.9651688848223, 14.443209988730294, 16.62644863128662, 31.573125089917863, 28.4891254561288, 45.05037914003645, 54.29055220740182, 42.23923526491438, 35.05598258972168, 12.433749267033168, 18.956422805786133, 21.601027045931133, 17.561045612607682, 15.036580937249319, 22.926453249795095, 38.26646375656128, 39.151573930467876, 35.10127442223685, 35.74519525255476, 40.029253005981445, 37.12769569669451, 33.193420682634624, 30.121309416634695, 36.98349973133632, 54.96376664297921, 46.088446957724436, 37.37128216879708, 44.225169386182515, 51.722233976636616, 16.3252146925245, 1.7562779188156128, 3.834841081074306, 33.966039521353586, 48.100235325949534, 63.59351961953299, 65.26920972551618, 74.50761100224086, 48.95181696755545, 28.90666355405535, 51.74697303771973, 35.13914210455758, 53.98429993220738, 87.60645920889718, 73.72041484287807, 53.7749194417681, 73.6966450554984, 34.12127617427281, 0.6691563076206616, 0.3626982734671661, 0.2058536418314491, 0.09872141014784575, 0.17214505347822393, 0.2711997532418796, 0.1312870266182082, 0.10006387132619109, 0.262057036693607, 0.20171182336551802, 0.11431974279029028, 0.09695976360567979, 0.1154437360486814, 0.27370680442878176, 0.16719965956040791, 0.13491344345467432, 0.07567498181015253, 0.07336898054927588, 0.11421720257827214], [0.07682638109794684, 0.05084712763449975, 0.020224017822848897, 0.02426918576072369, 0.08376865607819386, 0.007891654036939144, 0.03190014325082302, 0.028834447397717407, 0.020678454777225852, 0.028701254366231815, 0.08429420180618763, 0.07169253764940159, 0.03984358647306051, 0.12446092361850397, 0.050572120784116645, 0.05263933878658073, 0.061405872127839496, 0.057439224262322695, 0.029432579409331083, 0.05689468973183206, 0.09675549063831568, 0.13364489509591035, 0.020467666177345172, 0.1037446048909, 0.5443957022258213, 64.5456382206508, 76.89685331072126, 43.682462964739116, 64.92597566332135, 92.41108294895717, 50.560199873788015, 37.800107615334646, 41.657063075474326, 24.013104609080724, 53.786005292619976, 68.46788937704903, 53.291071210588726, 56.167684486934114, 56.39553328922817, 52.468102250780376, 49.58793497085571, 5.297913704599653, 2.6718539893627167, 26.103781087057932, 41.497032165527344, 43.75903558731079, 30.909881319318497, 35.08889968054635, 24.803246804646083, 31.844268117632183, 27.958170175552368, 27.740969487598964, 27.509160212108068, 26.143323285239084, 15.473867552621023, 16.15888524055481, 13.422638603619166, 20.99024564879281, 13.327033996582031, 8.907069478716169, 3.9939444065093994, 0.5945316233805248, 19.8006306716374, 38.82099253790719, 45.48291145052229, 29.05849732671465, 22.474907193865093, 34.251634802137104, 19.876626593726023, 18.90102481842041, 23.85219301496233, 15.63608888217381, 11.428117377417427, 14.429237161363874, 5.556702835219247, 2.289080334561212, 1.8978185866560255, 16.894758531025477, 38.004301275525776, 44.46356555393764, 21.828384263174875, 17.704671825681412, 21.921434538705007, 31.37061984198434, 40.97982563291277, 49.811448097229004, 54.768463202885215, 17.535764592034475, 10.344995703016009, 44.982915605817524, 53.320656640189036, 42.079989501408164, 46.15512534550258, 47.66419070107596, 41.911891732897075, 47.23476423536028, 37.98922368458339, 33.891596521650044, 38.39484562192644, 39.732189723423545, 34.98691749572754, 8.46344610622951, 1.263004564813205, 1.309009456208774, 0.1868947898702962, 0.9032957809312003, 2.0346082065786635, 4.60798624583653, 7.719820363180978, 17.254543202263967, 12.905789034707205, 13.288944840431213, 19.113446882792882, 26.61126708984375, 23.82456350326538, 42.68234968185425, 45.416236536843435, 34.451583112989155, 14.638740982328143, 4.3239191344806125, 12.686609847205025, 7.401342732565744, 6.337761129651751, 9.904039570263453, 21.38071182795933, 24.385585376194545, 27.046168736049108, 28.416685274669103, 29.176489898136683, 27.331687586648123, 23.470339127949305, 27.742228848593577, 21.99295060975211, 21.081805535725184, 47.13035018103463, 44.958277293613975, 41.81062521253313, 42.37734113420759, 35.29300648825509, 32.792384556361604, 0.8597762276019368, 0.3897800174142633, 8.07619868006025, 29.675624166216167, 41.55633851460048, 55.78961215700422, 63.93256391797747, 32.846042019980295, 30.952932357788086, 41.73874262401036, 28.86193973677499, 60.72568539210728, 67.87975910731724, 38.70505837031773, 41.43862908227103, 34.52698148999895, 0.6978424883314541, 0.06816494265305144, 0.06803427716451031, 0.07557481647069965, 0.06375776949737753, 0.05368405540606805, 0.034059587733021805, 0.03905403973268611, 0.1327755967421191, 0.044109264721295664, 0.001700032699903074, 0.06749714884374823, 0.07622857139046703, 0.08680030982941389, 0.3613916592938559, 0.07203460072300263, 0.0913968960355435, 0.03504219804225223, 0.0243029700193022, 0.03400989182825599, 0.061430747221623144, 0.040879136084445884, 0.02222328563220799, 0.027893717966175506, 0.09302250309182064, 0.0473735033135329, 0.07659209652670793, 0.13867760289992603, 0.04319442309705274, 0.005137844260648957, 0.06289488329951252, 0.08933610375970602, 0.009054831844488425, 0.09474122550870691, 0.07076697517186403, 0.09599205731813397, 0.048687968137008805, 0.0892320911266974, 0.14423697601471627, 0.024297870828637054, 0.13105537476284163, 0.047543506869780164, 0.006251358393845814, 0.0463434328724231, 2.5831326586859564, 83.83100959232875, 82.01483385903495, 48.585257802690776, 80.62384619031633, 92.17344760894775, 41.60347856794085, 36.80111646652222, 30.651429176330566, 27.688418524605886, 69.59995242527553, 72.83299786703927, 63.12389782496861, 62.98587185995919, 66.04960359845842, 54.50243404933384, 54.53173460279192, 3.6462969354220798, 3.815646682466779, 31.11601005281721, 39.02637781415667, 33.0193509374346, 31.218947614942277, 35.335536411830354, 24.17873055594308, 30.73566218784877, 28.615193571363175, 28.949216059276036, 30.30779559271676, 26.21203749520438, 14.424937094960894, 12.061855622700282, 11.606144990239825, 19.155438320977346, 11.18992097037179, 8.391344649451119, 4.6658269592693875, 5.575628425393786, 26.657116515295847, 45.569475582667756, 36.46569912774222, 25.425244331359863, 23.609462908336095, 30.885159628731863, 21.17115763255528, 21.370072398866924, 23.389493363244192, 12.371081726891653, 11.777609160968236, 17.094409806387766, 5.701978376933506, 0.7993085522736821, 1.5967548787593842, 18.488001312528336, 45.73512758527483, 44.248022011348176, 22.27031922340393, 24.037246125085012, 28.413023574011667, 38.90723010471889, 50.312361104147776, 52.352567604609895, 61.28240980420794, 25.63521715572902, 13.589668955121722, 50.412585394723074, 54.869514329092844, 47.060899462018696, 51.37839194706508, 50.46841417040144, 48.671842779432026, 50.48021568570818, 37.1966461454119, 33.93154171534947, 39.17681326184954, 45.71784046718052, 39.992653369903564, 16.569429976599558, 3.2888386079243253, 0.29140427336096764, 0.10842211318335362, 0.338955356074231, 2.5302963852882385, 11.75750367982047, 16.472780534199305, 21.651569979531423, 11.686112676348005, 15.008571011679512, 15.313140085765294, 26.38963345118931, 25.141047375542776, 36.28028992244175, 39.67607607160296, 41.27903938293457, 21.20163937977382, 4.733248804296766, 8.640948261533465, 5.370785542896815, 2.9862999277455464, 10.298854453223091, 21.256451981408254, 24.685077054159983, 24.28571023259844, 25.707674707685197, 30.053088528769358, 24.68550263132368, 22.228628294808523, 26.236689703805105, 20.385615144457134, 20.1521052973611, 39.44130686351231, 34.4929735319955, 44.40571485246931, 41.501089913504465, 40.427982330322266, 36.36383506229946, 1.2406923792191913, 0.14281122466283186, 7.604213629450117, 32.09290245601109, 47.08050727844238, 59.627390589032856, 66.20147732325962, 42.606704643794465, 27.200001852852957, 27.89193820953369, 28.821386575698853, 55.467531885419575, 78.13582829066685, 53.029475007738384, 52.26242862428938, 54.91102981567383, 4.1912932225636075, 0.14591763940240654, 0.09004065381096941, 0.02394101399529193, 0.03498466166534594, 0.007721020291293306, 0.03215674823150039, 0.08943601125585181, 0.05438761140352913, 0.037606751679309776, 0.00944273080676794, 0.06436302273401193, 0.09812457074544259, 0.026007497483598332, 0.1550764643720218, 0.07830003023679767, 0.03451319517833846, 0.04033148029286947, 0.03459865666393723, 0.0656038529372641, 0.12223241105675697, 0.2585947167660509, 0.11598390420632702, 0.09105759459946837, 0.19199896098247596, 0.12041855124490601, 0.2076159194111824, 0.19575708146606172, 0.11157523827361208, 0.14983301716191427, 0.25233395557318417, 0.137107377871871, 0.15870874375104904, 0.1850652830409152, 0.24125925983701432, 0.22134223500532763, 0.126717636095626, 0.2616613150707313, 0.2616568367396082, 0.11603076383471489, 0.3705091343394348, 0.19818373982395443, 0.12786575805928024, 0.22718466578849725, 2.7928631646292548, 92.56256062643868, 94.11505222320557, 58.80553681509835, 84.90834862845284, 108.30555970328194, 64.13138662065778, 50.084904875074116, 52.91890484946114, 31.7057557787214, 69.96825558798653, 79.03872585296631, 69.4664705821446, 72.6478909083775, 78.59505558013916, 60.944984436035156, 64.07417515345982, 8.331991400037493, 4.347967284066336, 37.165420940944124, 48.02519825526646, 52.320581572396414, 38.20212343760899, 41.13730307987758, 31.774028778076172, 41.67706346511841, 40.32884543282645, 39.59896843773978, 40.81156458173479, 37.941142150333945, 23.267847776412964, 24.62032331739153, 24.05972875867571, 35.29586219787598, 23.446515492030553, 15.474897623062134, 10.333261064120702, 9.201968397412982, 33.979164668491904, 48.21381752831595, 47.38671439034598, 41.10652256011963, 27.293324845177786, 49.98455204282488, 29.308116572243826, 29.453021253858292, 29.431659017290386, 26.097668409347534, 18.69189272608076, 25.07014969417027, 8.999671595437185, 2.8611003373350417, 2.2808306515216827, 22.52645414216178, 51.36421414784023, 52.36062056677682, 37.729413168770925, 37.60630151203701, 41.26599761417934, 45.060478346688406, 54.67200831004551, 54.78474630628313, 60.29457746233259, 28.111852169036865, 15.66456607409886, 52.746665954589844, 52.65805557795933, 49.90978595188686, 54.63360909053257, 50.94871882029942, 45.72566066469465, 51.17977769034249, 48.6556430544172, 46.06708124705723, 43.266978059496196, 48.01476206098284, 44.57666833060128, 17.9369501045772, 2.5868219350065504, 2.756511275257383, 0.15665924229792186, 0.9628722412245614, 3.163593202829361, 15.27298470905849, 18.962868997028895, 29.1598767553057, 21.695762259619578, 18.460786955697195, 26.304349524634226, 32.4464441708156, 34.338261468069895, 55.42806264332363, 54.98825209481375, 44.70912878853934, 25.726182971681865, 11.008344565119062, 21.450291088649205, 15.298668725149971, 15.842036962509155, 18.84968979018075, 31.846234457833425, 36.643777983529226, 40.382759979793, 43.042957714625764, 39.76242480959211, 36.05446304593767, 31.880562032972062, 37.68403795787266, 28.88555666378566, 26.50411023412432, 53.05414458683559, 53.638092041015625, 50.23559045791626, 49.032134669167654, 43.80156551088606, 36.53086975642613, 2.047968723944255, 0.4324494477893625, 10.380628670964922, 37.71979686192104, 57.850711890629356, 62.662440163748606, 74.0979174205235, 39.14880507332938, 38.14753144127982, 50.05833148956299, 40.09724807739258, 73.4888174874442, 86.42234025682721, 59.79357065473284, 63.73877171107701, 70.88580690111432, 4.801679006644657, 0.36309833771416117, 0.2519587257078716, 0.2848050860421998, 0.14487716023411068, 0.1450461968779564, 0.13061524980834552, 0.17959767500204699, 0.16911231407097407, 0.16952902956732682, 0.14675132823841913, 0.10334184685988085, 0.2245575681860958, 0.08971269748040608, 0.4835884336914335, 0.3155297487974167, 0.19943850035113947, 0.1443959024867841, 0.1119590855336615, 0.1612956720803465], [0.02889661138345088, 0.07048272328185183, 0.06221412268600293, 0.05465206703437226, 0.06725459971598216, 0.036789018594260724, 0.031186222630952085, 0.039487443797822507, 0.02641117662590529, 0.05352143091814859, 0.09478063482259001, 0.03042797671098794, 0.07995020704610006, 0.054601322793002637, 0.05812293650316341, 0.003710322780534625, 0.05602641596591898, 0.021267360408923457, 0.05140427613098707, 0.050255869182624986, 0.11587125382253102, 0.047407134901732206, 0.11333892042083399, 0.09940020300980125, 0.08730520095144, 11.201278669493538, 86.2182230268206, 60.6442038672311, 54.13622924259731, 84.49324934823173, 80.21028246198381, 34.29336220877511, 44.588403838021414, 38.96441030502319, 44.18425839287894, 73.64910548073905, 45.46980367388044, 55.39228636877877, 54.37192603519985, 47.53991174697876, 13.14297708443233, 0.503751237477575, 10.660060899598257, 45.242416926792686, 32.85552283695766, 54.65434946332659, 57.710705689021516, 43.74658441543579, 39.19012253625052, 24.65826048169817, 28.08145206315177, 28.28794036592756, 26.58574288231986, 22.25760923113142, 18.4158581665584, 10.217993923595973, 8.908419166292463, 7.7496941430228095, 15.593013525009155, 11.78932295526777, 6.777120913778033, 2.8579289189406802, 8.977847303662982, 30.913928644997732, 45.35810443333217, 46.60307570866176, 21.162208352770122, 26.202523674283707, 26.82829580988203, 20.2388014452798, 27.19600316456386, 13.779075980186462, 6.154147165162223, 20.8338851247515, 14.800128528050013, 8.086756467819214, 2.4659096002578735, 12.273082596915108, 29.861200128282817, 41.183946337018696, 40.96653372900826, 26.866120065961564, 25.461319378444127, 33.806418555123464, 46.41868788855416, 49.255887508392334, 54.86961855207171, 12.940736736570086, 3.685487381049565, 45.597532408578054, 50.816102027893066, 48.826579162052695, 48.30189636775425, 49.21913848604475, 39.33442619868687, 49.59952804020473, 52.21302693230765, 44.045673097882954, 51.14904580797468, 46.96765463692801, 28.45664436476571, 9.605990512030465, 2.8124907399926866, 0.8490814843348095, 0.6260089714612279, 0.05805947990821941, 1.4094987554209573, 8.17084183011736, 15.911157642092023, 15.262039559228079, 8.60163448538099, 15.35277955872672, 21.671968153544835, 25.167488745280675, 33.22821378707886, 60.47229848589216, 48.910412652151926, 29.523604529244558, 5.6269656249455045, 6.859606453350612, 4.794572302273341, 6.239487545830863, 6.651444068976811, 13.23995656626565, 22.139698301042827, 24.86741168158395, 24.834275722503662, 24.24113753863743, 24.476304531097412, 29.75281170436314, 27.709247486931936, 29.54038790294102, 22.5661335672651, 21.78589255469186, 36.57317386354719, 59.17673737662179, 40.453047956739155, 44.44312047958374, 35.74367012296404, 25.705968924931117, 3.763494372367859, 0.038244713696518114, 3.387851957763944, 17.918092693601334, 36.638073512486045, 55.12565619604928, 58.216180188315256, 23.14160943031311, 37.90456683295113, 31.523004259381974, 35.52879013334002, 70.60022899082729, 55.159132616860525, 27.05362241608756, 42.6285845211574, 13.192455206598554, 0.27339812527809826, 0.20919674315622874, 0.04292184879471149, 0.06122314943266766, 0.040400259995034764, 0.12533707517598355, 0.10269955918192863, 0.019876480667984912, 0.03338862855785659, 0.0461238453696881, 0.1684898803276675, 0.07472965360752173, 0.05601098268691983, 0.1054286677390337, 0.04998932366392442, 0.07208052397306476, 0.06349644530564547, 0.09430848980056387, 0.01547274089950536, 0.05211025449846472, 0.03604152745434216, 0.0679694227874279, 0.10183646263820784, 0.01260225278591471, 0.0351641579265041, 0.03293240196736796, 0.018354148337883607, 0.06332269962877035, 0.0385194830596447, 0.05773829535714217, 0.018740601172404628, 0.011423960610825037, 0.036985186460827074, 0.09178591373243503, 0.07211315472211156, 0.05737230713878359, 0.054673851401145966, 0.060723734088242054, 0.07857641112059355, 0.1854926108249596, 0.10748283751308918, 0.06670308645282473, 0.06640136907143251, 0.30468708489622387, 0.1459315222288881, 21.77085144179208, 103.12190478188651, 63.721901484898154, 66.92091464996338, 97.23078427995954, 64.15767860412598, 33.43842111315046, 29.668130534035818, 34.85394287109375, 60.61123466491699, 81.79657704489571, 53.4594851221357, 66.42017187391008, 61.58098084586007, 52.254681382860454, 11.13969417980739, 0.2605290301144123, 12.457282815660749, 46.575171743120464, 31.905787467956543, 51.200250557490754, 49.106817381722585, 42.19999878747122, 32.948333399636404, 24.890950441360474, 30.138311658586773, 26.741743837084087, 24.109835692814418, 24.64551227433341, 14.487469145229884, 8.025265778814044, 6.92175418138504, 9.479996221406118, 14.414714557783944, 8.279312763895307, 4.053107448986598, 4.654375025204249, 14.332271575927734, 38.025951862335205, 46.79450552804129, 38.95211546761649, 23.588215317044938, 24.93282549721854, 25.210821185793193, 19.837641988481792, 29.746499265943253, 13.611366442271642, 10.32316620009286, 24.764562708990915, 18.770593234470912, 6.7489060163497925, 3.740079811641148, 12.311876995222908, 35.433749198913574, 49.07801015036446, 41.096322604588096, 25.73195345061166, 34.58378301348005, 39.52119377681187, 53.78783614294869, 51.81911965778896, 58.01002018792288, 17.57169893809727, 5.4284069538116455, 50.77294329234532, 57.12281860624041, 53.296397004808696, 50.44972004209246, 54.19601501737322, 44.55734191622053, 53.25844594410488, 57.640535831451416, 48.89184011731829, 53.68357147489275, 48.146517276763916, 38.27220296859741, 11.71401229926518, 2.709781599896295, 0.7148898392915726, 0.6790201983281544, 0.14068021758326463, 1.143469927566392, 13.063906584467206, 18.14631322452, 21.591414213180542, 11.207088232040405, 15.64513543673924, 16.91218982424055, 26.977928740637644, 32.083397320338655, 51.1196688243321, 48.71037401471819, 40.696075098855154, 12.105571951184954, 5.793916940689087, 3.5216864219733646, 3.0897351545946936, 9.382601584706988, 17.14022970199585, 28.632732561656407, 29.12820165497916, 23.3712317602975, 24.846978766577585, 25.469624212809972, 27.54051569529942, 26.664653573717388, 28.483896936689103, 21.816075529370988, 22.150811944689067, 39.582254546029226, 53.85680743626186, 38.356369972229004, 45.91594055720738, 38.203526973724365, 30.175863197871617, 4.462803636278425, 0.06972764951309987, 2.9822456538677216, 17.851376090730938, 38.041574886866975, 57.84117896216256, 62.30669239589146, 34.80283887045724, 22.791328157697404, 28.355363948004587, 33.537307875497, 73.80514117649624, 71.12372016906738, 40.25457613808768, 58.801770891462056, 27.868899720055715, 0.2561624401382038, 0.1515602551932846, 0.03567420591467193, 0.026052348648330996, 0.034942097163626125, 0.07164326243634735, 0.18735289600278648, 0.01282295647875539, 0.00811499638283359, 0.035423684000436745, 0.017902791932491318, 0.05626613220998219, 0.07372336581881557, 0.05764749380094664, 0.07885452226868697, 0.06621144033436265, 0.052659158794475455, 0.049611969984003475, 0.02563595206343702, 0.08695470368755714, 0.21833967683570726, 0.1353578431797879, 0.14768573881259986, 0.10200092595602785, 0.1602691707334348, 0.2020040548273495, 0.0771951445245317, 0.16053738205560616, 0.14771093960319245, 0.15173142243708881, 0.18477181664534978, 0.10336877112942082, 0.13987770064600877, 0.19496263909552777, 0.18675981568438665, 0.09821094146796636, 0.10278516315988132, 0.2609471162515027, 0.21025327646306582, 0.2800319993070194, 0.12948261201381683, 0.4848232588597706, 0.15572855009564332, 0.3264797569385597, 0.4984456364597593, 22.75550671986171, 117.94938141959054, 78.09555653163365, 75.72185734340123, 102.72045176369804, 97.98638698032924, 47.836068289620535, 53.238608837127686, 47.931536538260325, 57.29297998973301, 89.3489076069423, 60.73375225067139, 73.4853572845459, 71.80838176182338, 63.57762908935547, 16.62774099622454, 0.5574082125510488, 15.512843472617012, 58.966206959315706, 41.02643414906093, 64.88033294677734, 64.86165618896484, 51.35480628694807, 46.18283128738403, 35.30693415233067, 37.549076148441856, 36.74109097889492, 38.00315829685756, 38.003210408346995, 30.141111782618932, 19.043283973421367, 16.5080634866442, 20.405605111803325, 26.971928971154348, 25.061636413846696, 14.20888807092394, 10.357196739741735, 18.509071724755422, 43.574887480054585, 51.0860847064427, 60.96600273677281, 29.068976947239467, 35.41266141619001, 37.73734106336321, 30.090775557926722, 35.33572053909302, 22.113784994397843, 12.368066208703176, 27.696905749184744, 18.256449120385305, 11.532382913998195, 3.3221940866538455, 12.397038459777832, 37.36992727007185, 49.134078638894216, 47.9813585962568, 36.69392660685948, 47.56706183297293, 44.18889284133911, 57.18204852512905, 54.685602460588726, 58.99514620644705, 24.722473996026174, 7.610418370791844, 55.69836146490914, 56.380188192640034, 56.45259884425572, 53.31185327257429, 56.02140058789934, 44.79943799972534, 51.476201738630024, 58.78721441541399, 48.734095164707725, 53.91473804201399, 52.14367348807198, 39.04462030955723, 13.985173446791512, 2.3208726857389723, 3.0611096620559692, 1.5135490064110075, 0.30311915331653183, 2.0209013649395535, 24.0007871900286, 28.488387210028513, 26.682510444096156, 15.643172570637294, 23.637182746614727, 27.569661651338848, 32.936191422598704, 44.45977531160627, 67.95168685913086, 58.89102745056152, 39.739110129220144, 11.595655815941946, 14.676645142691475, 14.150776812008449, 16.170030151094707, 16.447365760803223, 20.76895420891898, 35.29974971498762, 38.92795310701643, 39.21452113560268, 35.326500279562815, 35.005806173597065, 41.15538576671055, 40.37044429779053, 40.314625944410054, 29.40117379597255, 28.576141221182688, 47.04515484401158, 70.93945394243512, 47.19531236376081, 51.12983056477138, 45.01349810191563, 33.06586912700108, 5.845787848745074, 0.18502537161111832, 4.204192553247724, 23.02502039500645, 43.70585754939488, 63.62193775177002, 68.88792882646833, 29.393697534288677, 44.3639040674482, 41.83340835571289, 48.85583455221993, 87.56101104191372, 79.77383831569126, 42.394777638571604, 75.77458722250802, 36.503778730119976, 0.3215022683143616, 0.32009642517992426, 0.1480226857321603, 0.11138949609760727, 0.10937300537313734, 0.25024355202913284, 0.2876131625047752, 0.09788206911512784, 0.09682284202426672, 0.28410396937813076, 0.2810060227555888, 0.25969090365937775, 0.18032127831663403, 0.19531754005168164, 0.17585516082389013, 0.35633570488010136, 0.2512473224529198, 0.1919961789888995, 0.057890952165637694, 0.1886999508632081], [0.027493864065036178, 0.16429424046405725, 0.0912985559552908, 0.016333691576229672, 0.07218308454113347, 0.07930286428225891, 0.027984690852463245, 0.050372868975890536, 0.08050587294357163, 0.08481112335409437, 0.024599605173404728, 0.02060339184078787, 0.06579439914120094, 0.04639513724084411, 0.022956875285931995, 0.056250281631946564, 0.05644085158460906, 0.06251870348517384, 0.05248252595109599, 0.08725522006196634, 0.04746970600847687, 0.04636589577421546, 0.06996100449136325, 0.1009437751823238, 0.034572773945650885, 0.43114147654601503, 39.97453594207764, 70.87842096601213, 48.15845775604248, 77.32030432564872, 90.18539428710938, 52.466198444366455, 33.84421328135899, 36.90675687789917, 34.78968940462385, 70.87938676561627, 54.92338718686785, 50.81614719118391, 47.40028074809483, 23.155830655779155, 2.2389175977025713, 0.8422448911837169, 27.188096114567347, 51.81853253500802, 48.298151288713726, 48.33124555860247, 55.27511542184012, 39.31722245897566, 28.444597925458634, 31.56406463895525, 25.306779282433645, 27.45179067339216, 27.985862221036637, 25.675308261598857, 22.169308049338206, 11.553832871573311, 7.6793323414666315, 7.751736913408552, 12.013049738747732, 15.811925206865583, 5.75732512133462, 3.8093685507774353, 5.886925527027675, 22.45196771621704, 30.200494561876567, 37.34063366481236, 22.315093415124075, 17.954056569508143, 22.057874577386038, 22.430789606911794, 22.883532490049088, 14.02139093194689, 4.913008689880371, 20.56314856665475, 8.425885881696429, 3.878225198813847, 2.4490432824407304, 11.71050432750157, 21.169722829546245, 35.420269693647114, 45.84749385288784, 45.30788632801601, 36.269582748413086, 42.893793787275044, 49.66049153464181, 51.39566169466291, 56.09121608734131, 40.094861371176584, 4.537877185004098, 31.869371959141322, 53.77503061294556, 46.2052253314427, 51.342917919158936, 46.42925609861101, 43.70232439041138, 43.44384445462908, 48.992550781794954, 54.110465322222026, 44.2031192779541, 38.96483761923653, 22.960539375032695, 6.96255052941186, 1.0680038056203296, 0.2498961149581841, 0.5762464616979871, 0.060536770549203665, 1.1144355769668306, 10.114206944193159, 24.70607798440116, 18.200048855372838, 10.85855529989515, 17.45383664539882, 23.698234830583843, 21.8124555179051, 33.22521216528756, 61.55878829956055, 48.43050404957363, 22.720972435814993, 7.189810471875327, 4.753648715359824, 3.235602161714009, 6.284903143133436, 8.764546292168752, 14.973215103149414, 26.23390347617013, 26.818191392081125, 25.96448360170637, 26.762119429452078, 29.358313832964214, 29.41360412325178, 27.776714495250157, 23.99756669998169, 21.10015572820391, 15.800174065998622, 28.239801509039744, 48.436597619737896, 50.542714732033865, 45.145930767059326, 44.70198604038784, 22.817965814045497, 5.4347745435578485, 0.16815027355083398, 0.7086708758558545, 4.644823857716151, 26.71147574697222, 54.7760853767395, 48.27871717725481, 20.90541509219578, 37.840966497148784, 31.124973228999547, 47.02334097453526, 75.29791995457241, 41.6081269127982, 29.915041719164165, 35.07823766980852, 5.346376955509186, 0.47184472956827705, 0.045055234139519076, 0.05151662795937487, 0.04838659002312592, 0.025859507299693565, 0.019309825895886337, 0.18276180593030794, 0.0771259610940303, 0.0864323131474001, 0.004792416501524193, 0.03150186015825186, 0.029095581599644253, 0.021852177867133702, 0.002103179086199296, 0.06451216473111085, 0.039021805926625214, 0.04677619572196688, 0.008208906477583306, 0.02622401461537395, 0.038235360091286044, 0.03918940746890647, 0.10362565091678075, 0.015482024954898017, 0.054103010067982335, 0.04238518187776208, 0.14186310768127441, 0.08855526601629597, 0.009204013705519693, 0.04167906101793051, 0.09365802577563695, 0.008042958864410008, 0.07789199998868362, 0.07109210201139961, 0.017574084124394825, 0.03816415462642908, 0.01712887015725885, 0.1508543480719839, 0.07747548805283648, 0.07827533834746905, 0.0369393887397434, 0.08870976165469203, 0.08019474428147078, 0.0004820412962414723, 0.07323133293539286, 0.06539122041847024, 1.3347503606762205, 68.67862129211426, 78.36446571350098, 53.150213854653494, 93.09335436139787, 86.12509632110596, 46.26458379200527, 26.601145301546367, 30.953964165278844, 54.021841049194336, 78.69504710606166, 59.544449942452566, 59.296927315848215, 54.12789140428816, 23.80378144127982, 2.038885257073811, 0.48752062554870335, 30.195050648280553, 62.47185107639858, 43.133426734379356, 49.75981603349958, 52.834115982055664, 38.639161654881065, 29.91659811564854, 26.8871522630964, 23.945319720676967, 29.30643163408552, 25.275842428207397, 21.26498089517866, 18.12394002505711, 9.597699574061803, 7.821170261928013, 10.521580696105957, 14.026536073003497, 13.8861312185015, 5.629778342587607, 3.012328096798488, 9.242541534560067, 24.171554803848267, 33.23938996451241, 31.995763165610178, 21.883139542170934, 18.068422181265696, 24.580114092145646, 22.10823859487261, 24.58404850959778, 19.93411946296692, 9.543319497789655, 24.875779049737112, 10.887054204940796, 6.685915384973798, 2.766783752611705, 14.416111145700727, 24.458279166902813, 40.631171975817, 55.940450600215364, 46.65764686039516, 39.560506684439524, 46.14386578968593, 54.529219354902, 57.254539081028526, 60.8838472366333, 41.853787422180176, 6.301942297390529, 37.83358403614589, 59.16155556270054, 49.996509892599924, 52.18821144104004, 51.75691590990339, 46.707969188690186, 52.36387579781668, 55.93483645575387, 59.147151947021484, 52.18728385652815, 46.283437728881836, 29.6644549369812, 13.878592423030309, 2.736053390162332, 0.19403641165367194, 0.7759452887943813, 0.12871422538799898, 0.9867407147373471, 19.826203516551427, 19.29381169591631, 19.446873562676565, 9.921140824045453, 14.693576165607997, 20.21334845679147, 27.71378813471113, 34.10985680988857, 56.52920968191964, 49.45395285742623, 28.97618201800755, 11.430926186697823, 4.916317769459315, 3.772722448621477, 6.6011547446250916, 13.330495068005153, 21.891979387828282, 34.234576974596294, 31.22126136507307, 25.336232696260723, 29.88812092372349, 30.705548695155553, 27.315609455108643, 27.70406413078308, 24.826855046408518, 20.911777905055455, 20.405676330838883, 33.83047669274466, 52.24208777291434, 55.20048829487392, 54.12206881386893, 48.41863305228097, 28.686193738664898, 6.519451745918818, 0.1126763309751238, 0.4392957032791206, 3.6740892955235074, 28.455744573048182, 54.651584080287385, 56.35734946387154, 27.27381604058402, 22.998617240360804, 29.1558780670166, 45.82999134063721, 82.49284907749721, 54.714604241507395, 36.14840269088745, 58.39892128535679, 10.2921233858381, 0.4784889444708824, 0.20348882515515598, 0.2064212363745485, 0.09490452174629484, 0.013424904401680189, 0.12932410623346055, 0.24032906975064958, 0.03901770418243749, 0.03221511920647962, 0.03361347131431103, 0.033071379509887526, 0.08450970452811037, 0.05031176350478615, 0.03962165123916098, 0.04502652871555515, 0.12484251814229147, 0.058103367553225586, 0.03027341321909002, 0.01971906393633357, 0.07843336236796208, 0.1045510641166142, 0.24235509389213153, 0.12680109590291977, 0.15013786937509263, 0.20490085652896337, 0.4064113992665495, 0.19181396519499166, 0.1514892532889332, 0.1965704278222152, 0.25646265117185457, 0.07896774262189865, 0.23907068584646496, 0.14683394666228974, 0.20898217681263173, 0.1465184007372175, 0.18299283353345736, 0.2720984321619783, 0.17390260845422745, 0.1857464914875371, 0.17647122990872177, 0.16097878265593732, 0.25728226719158037, 0.14602016604372434, 0.2134129154895033, 0.12630519536989077, 1.1702947510140282, 74.5942689350673, 95.21514660971505, 64.32360158647809, 98.69650677272251, 105.51758807046073, 71.70496477399553, 46.99810511725289, 44.96745586395264, 42.582771573747905, 83.92380278451103, 65.78358486720494, 68.72452109200614, 61.792622974940706, 29.75444105693272, 3.2756489728178297, 0.9794379408870424, 32.78970602580479, 65.17476981026786, 58.488268171037944, 64.04429095132011, 66.91798945835659, 48.41174738747733, 34.83211857931954, 41.755001408713206, 36.45638159343174, 43.035120146615164, 41.98354503086635, 39.6099465915135, 36.89721352713448, 23.881196532930645, 16.958047934940883, 18.854623011180333, 26.62797055925642, 30.241395132882253, 15.720660618373326, 12.627542342458453, 12.220077395439148, 30.69064133507865, 41.23221199853079, 48.36445099966866, 30.229218414851598, 22.364939791815623, 32.388030665261404, 31.306981291089738, 30.531753403799875, 22.227997745786393, 11.625170026506696, 32.800764083862305, 12.463184441838946, 7.229832095759256, 4.153470269271305, 13.927140355110168, 23.95292452403477, 41.97707973207746, 55.21960278919765, 51.593723569597515, 45.198177746364046, 50.45285367965698, 53.60394164494106, 58.435566084725515, 58.25442654745919, 51.435415812901084, 8.310134104319982, 39.684622355869834, 62.44567721230643, 52.855572019304546, 54.29845578329903, 53.862306935446604, 46.72433567047119, 53.78816965648106, 51.65622609002249, 58.64189979008266, 53.635955469948904, 42.239798069000244, 28.957263810294016, 13.331497345651899, 1.8574460787432534, 2.1941879178796495, 0.6637881185327257, 0.20388686736779554, 1.6941996727670943, 27.382145404815674, 35.058935574122835, 26.179585933685303, 17.74470908301217, 25.741788625717163, 29.886338710784912, 31.531581810542516, 48.71839918409075, 72.4083309173584, 55.08504397528512, 30.422420024871826, 13.517846294811793, 13.964960268565587, 12.774500216756548, 14.186176146779742, 15.487329687391009, 28.528657232012065, 43.132398400987896, 41.02219574792044, 37.63746418271746, 39.03057452610561, 41.01180819102696, 38.42601524080549, 38.17612327848162, 33.00852216993059, 29.51967532294137, 23.311501571110316, 37.48723370688302, 60.0463878086635, 59.83628817967006, 56.52496780667986, 50.10437025342669, 32.94185767854963, 7.083468292440687, 0.22939203519906315, 1.2456463362489427, 5.989424918379102, 30.60674183709281, 66.41644069126674, 56.57306671142578, 28.597892556871685, 43.879083088466096, 45.51412623269217, 61.31182847704206, 96.00394085475376, 61.836528641836985, 45.753370080675396, 75.2422023500715, 10.948055914470128, 0.49133719503879547, 0.32328819962484495, 0.3136593263064112, 0.2244644867522376, 0.17553388806326048, 0.257911106305463, 0.3281836397945881, 0.1735879039125783, 0.161096114931362, 0.11479131105755057, 0.11297506280243397, 0.28131459334066933, 0.15412488686186926, 0.16180574042456491, 0.14015117739992483, 0.21903750939028604, 0.14945330896547862, 0.13639334190104688, 0.10695615863161427, 0.1894434081124408], [0.01992196456662246, 0.05882447385894401, 0.04425252042710781, 0.022646869599287, 0.035850726799773316, 0.10177413919674498, 0.043891363378082, 0.025497870187142065, 0.04397285543382168, 0.050363997130521705, 0.016190866740154367, 0.027906990111140267, 0.02230505588730531, 0.03847718657925725, 0.07664791281734194, 0.06821519495653254, 0.056435504728662114, 0.039932922393615754, 0.06788018864712544, 0.03419624807845269, 0.03290146077051759, 0.05801518514220204, 0.06609708682766982, 0.20716928052050726, 0.10114499474210398, 0.13876471322562012, 6.817139063562665, 64.07806614467076, 60.09089796883719, 56.141958781651084, 95.5730344227382, 68.54219341278076, 36.214021478380474, 46.69575425556728, 34.373179640088765, 61.04680333818708, 56.93703767231533, 48.9594669342041, 32.618429456438335, 3.146868020296097, 0.04661880613171628, 0.5034813433885574, 20.013836145401, 30.7181944165911, 48.52483974184309, 59.21451473236084, 43.932539054325645, 49.764311517987935, 27.895763192858013, 20.206987380981445, 27.12022958483015, 28.075813599995204, 23.773678370884486, 22.535361732755387, 15.434248924255371, 13.176855632237025, 9.9523104429245, 9.469889198030744, 11.91897199835096, 12.008892978940692, 8.927060314587184, 7.069577540670123, 7.040634385177067, 11.070968679019384, 18.143591267721995, 17.73344431604658, 29.420576640537806, 24.671154601233347, 21.931969744818552, 22.416493688310894, 23.353998490742274, 18.436336244855607, 15.415877887180873, 19.345989193235123, 2.3370754505906786, 2.4558442660740445, 1.0828281130109514, 4.065891265869141, 14.109665189470563, 22.04091923577445, 39.11379657472883, 49.87861633300781, 49.76703521183559, 47.13266045706612, 46.903585297720774, 53.70185565948486, 49.77830171585083, 62.1089814049857, 8.437200154576983, 12.098221625600543, 55.19505132947649, 40.451495034354075, 49.42052507400513, 40.22691535949707, 43.764510767800466, 33.681684494018555, 49.452139377593994, 52.16554641723633, 42.13662426812308, 34.690014021737234, 18.47113629749843, 4.530457377433777, 1.766342167343412, 2.124200016260147, 1.0085668521268027, 0.04422338413340705, 0.7315413600632122, 14.080187456948416, 27.37842117037092, 17.85960102081299, 12.177226986203875, 18.43682435580662, 22.03334743635995, 26.922534227371216, 31.249269553593226, 44.47841385432652, 32.39455154963902, 17.436719758169993, 12.829259838376727, 3.7399855766977583, 4.01057231426239, 5.3359885300908765, 8.914349453789846, 19.092956645148142, 28.786068882261002, 33.957069396972656, 27.023950134004863, 26.820996727262223, 31.238340037209646, 30.931782041277202, 26.74156665802002, 23.374810082571848, 21.96210755620684, 19.87900808879307, 32.29977464675903, 40.41794913155692, 37.90307991845267, 38.99514218739101, 34.160102707999094, 35.31393793651036, 6.261849888733455, 0.22410546030317033, 0.44812097400426865, 1.2958619445562363, 13.733278666223798, 49.96139022282192, 42.36591829572405, 24.66543275969369, 33.50900786263602, 36.711821692330496, 55.57745238712856, 66.08175986153739, 33.97003126144409, 38.858234882354736, 25.9445891720908, 0.43279058805533815, 0.12078994060201304, 0.06497522416923728, 0.12627831181245192, 0.049279691385371346, 0.06268812689398016, 0.010280887795878308, 0.13199772419674055, 0.045634513055639606, 0.013264139947880591, 0.11918230115302972, 0.045153201025511534, 0.039264653609799485, 0.02145166409068874, 0.012141716649888881, 0.05526516413582223, 0.11492996290326118, 0.06879446708730289, 0.07090768297868115, 0.0523378351437194, 0.05068519525229931, 0.02929486733462129, 0.08981804682740144, 0.01161061880910503, 0.051004432407873015, 0.022810766340366433, 0.07923663926443883, 0.022566198570919887, 0.0247945330172245, 0.023755170039034317, 0.012989021987388176, 0.036035047444914065, 0.023214672791904638, 0.049388080569250245, 0.09250009898096323, 0.09828998401228871, 0.05608361986066614, 0.017726211675575802, 0.03204043375860367, 0.013242984074167907, 0.04571122143949781, 0.0702217790697302, 0.012893172978822674, 0.19724182465246745, 0.08616821374744177, 0.13047363954995359, 0.03502086829394102, 14.807491881506783, 89.25124372754777, 65.10707351139614, 70.86053630283901, 102.17774881635393, 63.6785169328962, 43.255718503679546, 25.478005477360316, 49.52589103153774, 76.27951976231166, 58.70449611118862, 54.31604862213135, 34.02540840421404, 2.965707855565207, 0.0394389014025884, 1.0885570113148009, 27.678687572479248, 42.18628651755196, 59.41321931566511, 62.56520707266671, 46.806626660483225, 47.11098902566092, 27.04860234260559, 22.993336609431676, 25.959350619997295, 27.838496140071324, 23.704646280833654, 20.29627694402422, 16.710660798209055, 16.98704971585955, 13.730378661836896, 13.102081724575587, 14.947649206433978, 15.8816225869315, 11.826963952609471, 7.68257280758449, 10.72022795677185, 16.482297829219274, 22.173859119415283, 19.907096181597026, 27.13812814440046, 23.129740170070104, 21.29417027745928, 22.02051411356245, 25.66934323310852, 23.983364582061768, 16.665297746658325, 18.826276097978862, 7.74494765486036, 4.393613474709647, 2.813917074884687, 9.754827005522591, 17.421009881155832, 25.005147559302195, 44.58241449083601, 55.954611028943745, 53.475608416966026, 53.08882999420166, 50.78081560134888, 57.27612713405064, 55.20719678061349, 67.61849294389997, 8.78893186364855, 15.326546634946551, 63.50556237357003, 46.5586975642613, 53.38661241531372, 47.74190282821655, 50.653298786708284, 41.9053430557251, 56.14559268951416, 57.223890577043804, 48.391330105917795, 42.48805373055594, 23.23374949182783, 5.876076349190303, 0.7458966640489442, 1.0478736800806863, 0.8725388741918972, 0.2099869514682463, 0.511923567524978, 19.784590755190166, 14.4781767981393, 16.106033767972672, 11.814808079174586, 17.006664480481827, 18.5112795148577, 30.998255457196915, 28.013750553131104, 42.32689373833792, 36.767629623413086, 21.458769627979823, 14.458794798169817, 6.361679434776306, 5.779198484761374, 9.867320077759878, 15.911039522715978, 27.569640806743077, 36.22050414766584, 35.1800148827689, 31.561118602752686, 32.693320614951, 33.729053837912424, 30.022683211735316, 29.88035978589739, 23.22909246172224, 23.339568819318497, 21.408709594181605, 38.97536414010184, 52.84818261010306, 49.87538194656372, 47.037213053022114, 38.931225708552766, 31.207899979182653, 7.127807353224073, 0.16167604524110044, 0.5158020736915725, 0.9165119060448238, 14.573556457247053, 48.76242644446236, 56.60823154449463, 24.509833063398087, 23.35052960259574, 35.52226577486311, 57.42478731700352, 76.76348958696637, 44.40759086608887, 52.33126790182931, 43.680069310324534, 0.7472158446907997, 0.10366200003772974, 0.01219888068070369, 0.11275935652000563, 0.008084151029054607, 0.11032064738018171, 0.05021952006167599, 0.040824452947293005, 0.054001911742878814, 0.03340762753837875, 0.0729146809982402, 0.03719633638060518, 0.08626299830419676, 0.12295433160449777, 0.03973257135865944, 0.07013018362756286, 0.1128243873161929, 0.15644588374665805, 0.06903786438384227, 0.013956568819204611, 0.050573074125817845, 0.08930520327495677, 0.15823322640998022, 0.16433834524026938, 0.11622377990611962, 0.10799599319164242, 0.22655968075352056, 0.11764415726065636, 0.10743519078407969, 0.2384815817432744, 0.1207569773708071, 0.126848878338933, 0.19062168417232378, 0.08571900999439613, 0.13004362476723536, 0.2113397874470268, 0.15756577865353652, 0.20570831320115499, 0.10847997864974396, 0.1530041370008673, 0.11167638070349183, 0.1891398179743971, 0.13195596715169294, 0.3042513025658471, 0.18103160948625632, 0.29877278368387905, 0.1605194823018142, 16.979764529636928, 109.86119188581193, 76.89584582192558, 73.01604121071952, 118.00682912554059, 81.23012515476772, 52.3861517224993, 56.42702947344099, 43.53118678501674, 74.56532273973737, 70.16299969809396, 60.152292251586914, 42.19893223898751, 3.4867089731352667, 0.1502859799989632, 0.9737846042428697, 29.123725278036936, 42.25768968037197, 62.3788285936628, 69.04888384682792, 54.65906381607056, 60.12822369166783, 40.331339836120605, 31.998962811061315, 40.26904923575265, 41.979188510349815, 39.251509870801655, 39.34502567563738, 30.996372495378765, 24.42534817968096, 18.369901044028147, 20.63076322419303, 26.701003074645996, 28.18724012374878, 22.77401324680873, 19.168752806527273, 15.64537341254098, 17.70569668497358, 28.587517159325735, 24.321307591029576, 41.62576144082205, 31.027010577065603, 30.950066225869314, 29.46773406437465, 31.12771429334368, 25.124793801988872, 24.42480969429016, 30.060821873801096, 13.010553104536873, 5.340048015117645, 2.1449764328343526, 11.0502222265516, 17.670184441975184, 23.86448437826974, 45.49820443562099, 53.612717219761436, 51.58368689673287, 52.07897881099156, 51.36364092145647, 57.652535370418, 53.827972412109375, 67.03952734810966, 13.19216685635703, 14.56548091343471, 67.40904644557408, 48.91623871667044, 54.25453969410488, 47.78919226782662, 53.665832723890034, 47.78030552182879, 57.813445227486746, 54.227302755628315, 48.12863608769008, 51.176154204777305, 23.781059094837733, 13.465296200343541, 5.164669403008052, 4.865528609071459, 2.574901431798935, 0.5538273932678359, 0.9358627476862499, 28.46135524341038, 35.874049595424104, 25.17116434233529, 20.492601769311086, 28.13959285191127, 26.98040403638567, 39.396233899252756, 43.291897773742676, 54.034747328077046, 42.38426501410348, 24.51476628439767, 21.975501946040563, 13.705478923661367, 10.602135504995074, 13.177345480237689, 17.86137628555298, 33.255822454180034, 43.544735772269114, 46.33946105412075, 36.68132257461548, 35.4598605292184, 40.62338999339512, 36.38048642022269, 37.106795515332905, 33.25610385622297, 30.810136454445974, 28.973135232925415, 44.713044098445344, 52.20252125603812, 48.23969609396798, 50.155185903821675, 45.94694341932024, 41.77164581843785, 9.182998946734838, 0.36658826044627596, 0.5864400118589401, 1.7286867307765144, 16.74044077736991, 60.79820374080113, 53.759730679648264, 31.197779927934917, 38.51713044302804, 51.99760498319353, 69.98378481183732, 86.3780038016183, 51.80638360977173, 65.70092214856828, 54.858313832964214, 0.3430709423763411, 0.144305480910199, 0.14764780870505742, 0.2267649375966617, 0.10053414359156575, 0.26330879809600966, 0.15226143971085548, 0.2261956874281168, 0.12772648196135247, 0.12597554948713097, 0.14139844690050396, 0.11656705077205386, 0.1074547665193677, 0.18132206318633898, 0.13940164047692502, 0.18420243076980114, 0.2078132645360061, 0.13288960419595242, 0.19879090652934142, 0.13874538854828902, 0.14258239551314286], [0.06997477875224181, 0.08545080545757498, 0.080257189859237, 0.04414121354264872, 0.06031932721712759, 0.04238563649622457, 0.06464303378015757, 0.04727617764313306, 0.038785109163395, 0.12147642805108003, 0.096921093894967, 0.05593529889093978, 0.07675132833953414, 0.031895977045808516, 0.10486395018441336, 0.008440801757387817, 0.05474771672327604, 0.07504545737590108, 0.05816151121897357, 0.06583507731556892, 0.04915860681129353, 0.06324131613863365, 0.02246482204645872, 0.1000757117622665, 0.04756725559543286, 0.1795109582266637, 0.6260661855340004, 41.63672569819859, 66.57403973170689, 54.05290991919381, 86.642014503479, 82.12800611768449, 28.366807631083898, 37.89459964207241, 47.47747870853969, 45.31689814158848, 48.64068010875157, 34.128717694963726, 10.072580286434718, 0.6174726752298219, 0.46202915055411203, 2.7106787860393524, 23.07767731802804, 34.23689072472708, 31.311080728258403, 50.83307647705078, 48.077476501464844, 50.02172490528652, 34.733301298958914, 15.283929858888898, 19.554421254566737, 23.40902648653303, 19.503180027008057, 16.275621925081524, 17.21832745415824, 13.57201966217586, 15.788190160478864, 13.207835912704468, 12.548055819102697, 11.08362569127764, 10.475747772625514, 8.523072940962654, 12.0493723154068, 8.092816165515355, 8.667481694902692, 11.394140686307635, 24.89345179285322, 23.517576456069946, 19.550090789794922, 21.65244197845459, 24.033872774669103, 19.262299878256663, 21.6866740158626, 15.350439752851214, 5.34316862480981, 0.48859841057232445, 0.38072580897382324, 2.1720021026475087, 8.733302848679678, 13.369449274880544, 30.358312470572336, 45.671794755118235, 48.75001001358032, 50.190051964351106, 47.16758557728359, 48.66290739604405, 49.79836116518293, 60.16906520298549, 21.119635002953665, 3.7519864184515814, 45.05444383621216, 39.70933709825788, 48.176908697400776, 44.552064759390696, 42.364618982587544, 35.955232347760884, 49.04334906169346, 50.27956213269915, 48.96075929914202, 42.755552428109304, 27.52955491202218, 15.756799936294556, 4.3950851900236945, 1.657969159739358, 0.5638622748000282, 0.47123643649475916, 1.992735973426274, 12.2484564440591, 21.936956814357213, 11.812067014830452, 14.52692883355277, 17.945617982319423, 21.219464983258927, 31.649638652801514, 29.746422835758754, 25.175936017717632, 17.788828407015117, 13.935806495802742, 14.54186224937439, 3.4451767674514224, 5.1389945064272196, 8.502633077757698, 17.954233748572214, 25.334273304258073, 36.167013440813335, 34.61420917510986, 29.54274681636265, 34.64778634480068, 35.747984954289024, 26.865173373903545, 23.569856439317974, 24.901004484721593, 22.719098159245082, 27.2674514906747, 35.03746216637747, 32.57843215124947, 34.02020072937012, 39.27454662322998, 45.85694687707083, 37.55151149204799, 9.092981559889656, 0.2013673854193517, 0.30279986187815666, 0.0788480286885585, 6.900926521846226, 38.631160804203574, 27.870723622185842, 24.660800048283168, 27.972120421273367, 37.55799763543265, 59.57771791730608, 54.429540497916086, 35.96540798459734, 43.0401645387922, 9.574472614697047, 0.27789065135376795, 0.11173901627106325, 0.10034289849655968, 0.06532941944897175, 0.04989071556233934, 0.06523603945970535, 0.08880730784897294, 0.10173912678978272, 0.0677337743608015, 0.09754569216498307, 0.04057516257411667, 0.07639222046626465, 0.11776927911809512, 0.09307703016591923, 0.062304734252393246, 0.05977066380104848, 0.028759635519236326, 0.02837379166989454, 0.009407124681664365, 0.03361061807455761, 0.006737313723923373, 0.06729614641517401, 0.024744431687785045, 0.05494632053055933, 0.009143739439813154, 0.018599873009536947, 0.010107870695979466, 0.04454256361350417, 0.0073281841385843495, 0.10501849332026073, 0.01756481533604009, 0.04165805696642824, 0.028751079192651168, 0.05603012755247099, 0.022716678978343095, 0.04446226917207241, 0.02573653300558882, 0.01775284417505775, 0.11808007529803685, 0.05720249017966645, 0.049312627475176535, 0.052427836028592925, 0.051982968114316463, 0.0991087993606925, 0.11708705286894526, 0.09055621828883886, 0.12555592986089842, 1.4689593762159348, 63.29575456891741, 77.7943868637085, 62.025269508361816, 106.73045866830009, 75.29483495439801, 36.27924421855381, 25.87960093361991, 41.00798668180193, 67.15752860477993, 51.217839922223774, 38.56078944887434, 11.55532499722072, 0.6233017795852253, 0.7527643612452916, 2.0983624884060452, 25.83915546962193, 35.97272791181292, 40.56434767586844, 63.83320467812674, 50.48495783124651, 48.07402324676514, 35.45193610872541, 16.36300073351179, 19.783048255102976, 28.74970374788557, 23.590711457388743, 21.616090740476334, 23.157836948122295, 20.32855306352888, 20.859329427991593, 18.062264340264456, 18.160482338496617, 16.10338303021022, 15.02498265675136, 13.534739102636065, 15.088829653603689, 11.637469206537519, 13.74377999986921, 15.820391586848668, 27.20097460065569, 27.260346957615443, 21.876835788999283, 22.038409199033463, 22.923788615635463, 22.287660190037318, 20.06050545828683, 14.657509803771973, 8.587797147887093, 0.23944431436913355, 0.6390121994274003, 3.5842653725828444, 10.510921290942601, 16.65100356510707, 32.903062411717, 49.47323758261544, 54.5667986869812, 54.91449696677071, 52.37758806773594, 56.45119183404105, 54.13218886511666, 64.76836272648403, 20.3635059765407, 4.97838602747236, 51.43001706259591, 45.53843797956194, 54.23372983932495, 49.622081892830984, 46.35317332404, 42.068295683179585, 55.891865321568076, 54.53332574026925, 56.02179316111973, 48.06872871943882, 32.96721165520804, 16.7058231149401, 4.0202463780130655, 2.4974166410309926, 0.5959390678576061, 0.2297289685479232, 3.428087890148163, 20.739427839006694, 9.168890629495893, 8.50779037816184, 9.564392515591212, 11.373987436294556, 21.015054191861832, 34.26676797866821, 30.380084650857107, 25.11810094969613, 19.494850873947144, 16.88625741004944, 13.080576181411743, 7.490881562232971, 8.915753858430044, 14.59337271962847, 25.40225795337132, 34.941326890672954, 40.621281215122764, 39.31046880994524, 36.066650186266216, 39.20654112952096, 39.34313229152134, 32.092238903045654, 28.316872664860316, 29.702791622706822, 23.9985967704228, 27.794560943331035, 40.14107036590576, 44.71398210525513, 48.55182307107108, 51.01418127332415, 50.8643433707101, 41.91013036455427, 9.42252767086029, 0.12277841461556298, 0.10310323323522295, 0.07550416740455798, 7.467358435903277, 42.23971469061715, 43.58099147251674, 18.23553156852722, 27.639949628285, 41.41276788711548, 64.93018627166748, 65.8586254119873, 43.16671902792794, 61.604021072387695, 21.042443990707397, 0.7517254427075386, 0.04005878724689994, 0.13285444251128606, 0.053495867111321004, 0.04682531487196684, 0.07021232029157025, 0.058074143049972396, 0.053410171531140804, 0.028154964126380425, 0.11293914115854672, 0.049023201755647144, 0.030455209713961397, 0.07963468826242856, 0.09483361483684608, 0.0733980286334242, 0.03857322981847184, 0.030949237490338937, 0.015236039047262498, 0.04200612846761942, 0.050866781401314905, 0.016621354801048125, 0.1541578093809741, 0.1524090210774115, 0.23725720601422445, 0.10443362327558653, 0.1941136017973934, 0.1881697435996362, 0.0701036121962326, 0.12073590207312788, 0.17886569856532983, 0.16235804078834398, 0.2152167058416775, 0.22704289268170083, 0.16561411321163177, 0.17852721815662725, 0.1648023139153208, 0.18948026613465377, 0.06848087534308434, 0.22804378611700876, 0.22670533508062363, 0.12057202229542391, 0.1545260910476957, 0.1671123592449086, 0.10780375065015894, 0.20774561459464685, 0.2140885463782719, 0.19035602414182254, 1.0150290025132043, 72.57597010476249, 92.25568648747036, 73.94696780613491, 113.54568263462612, 99.69995171683175, 39.692411286490305, 47.61875295639038, 60.02120753696987, 54.232833521706716, 58.02003949029105, 40.80246591567993, 15.886177131107875, 1.3099358464990343, 1.0688095795256751, 2.646362134388515, 29.459799221583776, 45.02660240445818, 45.04953840800694, 63.591997964041575, 60.71415138244629, 56.33657087598528, 44.512060506003245, 27.441274574824742, 34.82224171502249, 42.66076857703072, 34.86192635127476, 32.12646572930472, 31.611600739615305, 24.00210734776088, 25.308783837727137, 23.256041049957275, 26.119572605405533, 26.156219141823904, 25.007704496383667, 20.605895621435984, 23.99440700667245, 14.084398933819362, 16.355983052934917, 19.363566398620605, 36.388768672943115, 32.73855338777815, 26.781233923775808, 30.3547272000994, 33.35347591127668, 28.61626533099583, 29.724709715162003, 26.326430899756296, 15.302540608814784, 1.118608187351908, 1.2023572134120124, 3.8459668840680803, 11.16523836340223, 17.768093245370046, 38.25612483705793, 51.766848359789165, 52.43293741771153, 52.86785643441336, 51.25692353929792, 54.11637476512364, 55.673636300223215, 61.603694507053916, 23.973013503210886, 6.4195162398474555, 54.77848597935268, 49.473921980176655, 57.564369678497314, 50.95406893321446, 52.72169760295323, 46.75321585791451, 55.28248746054513, 51.14045088631766, 52.870045116969514, 48.437000615256174, 39.56489447184971, 25.662045887538365, 8.31350484916142, 1.6201578229665756, 1.0074526433433806, 1.635078319481441, 5.676857599190303, 35.8131034714835, 30.75233439036778, 21.26970567022051, 22.879132543291362, 25.485530376434326, 27.936972958701, 44.256245204380576, 42.71593032564436, 34.42783069610596, 24.987792696271622, 22.26221067564828, 24.758642843791417, 13.295800106866018, 11.762958884239197, 15.787719420024327, 26.525434255599976, 40.24058246612549, 46.09788261141096, 43.42127670560564, 35.87478610447475, 42.23583064760481, 42.94975110462734, 34.08168533870152, 33.16693067550659, 36.93201010567801, 33.96631397519793, 37.8554812840053, 47.679838044302805, 48.12300109863281, 49.80012600762503, 54.65033687864031, 57.08005244391305, 48.15699863433838, 11.333957995687213, 0.4533591557826315, 0.46267039328813553, 0.18860488810709544, 9.216494475092206, 47.52659205027989, 39.43511949266706, 29.07676761490958, 41.97930315562657, 52.526567867824006, 75.31724289485386, 77.10390268053327, 47.749406882694785, 76.05361298152378, 20.90945373262678, 0.7410044808472905, 0.18116378810788902, 0.24512916217957223, 0.19412300629275187, 0.14910622473273957, 0.15362264881176607, 0.24100413067000254, 0.10760534701070615, 0.17163182316081865, 0.4141875191458634, 0.1827648321964911, 0.16044215645108903, 0.33690981726561275, 0.1896977230374302, 0.15723393431731633, 0.2996239922940731, 0.10778150148689747, 0.11997861628021513, 0.1379325714494501, 0.16854657871382578, 0.24237089018736566], [0.04197931954903262, 0.05069323928494539, 0.05097574055460947, 0.017660424312842742, 0.08075779942529542, 0.07235773945493357, 0.04450879292562604, 0.0938823562381523, 0.10320466064981051, 0.08382800075092486, 0.1526269122425999, 0.031132265526269163, 0.08560494825776134, 0.020696751474003707, 0.04680684854143432, 0.036303614997970204, 0.03451149884079184, 0.08014403735952717, 0.07467215455004148, 0.1332272296505315, 0.0607301394588181, 0.027858501998707652, 0.046725427731871605, 0.05695332533546856, 0.2020208282130105, 0.03206689323165587, 0.20691700120057377, 21.40849593707493, 72.99297319139752, 66.76974269321987, 68.13722460610526, 89.67592457362584, 55.24552304404122, 28.629852533340454, 49.822245597839355, 40.33666910443987, 43.51926020213536, 26.690334115709575, 1.8876266649791171, 0.10353039138551269, 0.7866899179560798, 4.251214052949633, 27.197840963091167, 49.919617652893066, 48.424907275608604, 38.10914264406477, 62.22106974465506, 57.40436308724539, 31.71487181527274, 16.371642555509293, 20.929042441504343, 23.55181544167655, 19.47989661352975, 16.690992185047694, 18.841860907418386, 23.225609677178518, 16.97426676750183, 14.05579059464591, 14.612478528703962, 16.260950803756714, 14.2370491198131, 11.025371994291033, 17.894489662987844, 14.141302074704852, 9.625142352921621, 14.961403165544782, 26.536438465118408, 25.526375361851283, 21.610396691731044, 20.3124349798475, 30.80641916819981, 23.458726951054164, 22.232823269707815, 16.2410546370915, 4.236408744539533, 2.0847946107387543, 0.4322168731263706, 0.5788389540144375, 2.900301205260413, 11.872594509805952, 23.574338027409144, 33.57563066482544, 43.52407530375889, 43.48496389389038, 42.11149958201817, 49.86517851693289, 46.23430354254586, 58.128566878182546, 25.272863388061523, 1.417970889381, 36.416877610342844, 38.67893314361572, 45.24579375130789, 43.08776317323957, 45.53357771464756, 38.879218442099436, 45.65374680927822, 45.42050620487758, 51.31830392565046, 51.19838496616909, 39.192349433898926, 23.235580342156545, 7.566793237413679, 0.856926217675209, 0.5169889671461922, 0.12212236624743257, 1.3580731834684099, 4.703412805284772, 11.47964608669281, 18.509153366088867, 18.221885306494578, 22.83199770109994, 23.285272121429443, 35.9061850139073, 25.919139657701763, 16.0288462298257, 11.223626681736537, 15.744169848305837, 15.373078720910208, 6.308116206101008, 9.270706926073347, 13.583191496985298, 24.910325493131364, 35.187289646693635, 38.82516840526036, 37.2247759274074, 37.636415004730225, 41.57116597039359, 39.84214844022478, 30.618849073137554, 29.25472661427089, 26.767870800835745, 24.604762826647075, 34.13421719414847, 52.51808064324515, 43.10971253258841, 38.29028912952968, 31.614428656441824, 35.81645597730364, 33.329869406563894, 8.725193432399205, 0.362082299377237, 0.23033997576151574, 0.13431838181402, 3.01359766295978, 19.28328343800136, 25.875543185642787, 29.403605665479386, 25.172237839017594, 40.97454500198364, 65.87516212463379, 39.926315443856375, 38.02723033087594, 24.914685487747192, 0.9590758106538227, 0.17391240649989673, 0.03934372668819768, 0.09623083379119635, 0.03547036720971976, 0.05227139978004353, 0.03371913278741496, 0.06331203305827719, 0.0434392826365573, 0.06574918156755821, 0.07697608627911125, 0.11802757025829383, 0.08855874690094165, 0.05899490149957793, 0.01665324085791196, 0.0246410110765802, 0.02537901120792542, 0.0657461756574256, 0.049400141529206715, 0.005981925284556512, 0.020220043303977166, 0.0009133780030034748, 0.0820727799353855, 0.048082680973623476, 0.05959320653762136, 0.04735323886520096, 0.092332534758108, 0.0583507614210248, 0.01605578398864184, 0.03437810903415084, 0.08965308139366762, 0.09841021363224302, 0.01332680689769664, 0.004816005771447505, 0.025001718596156155, 0.0363343424562897, 0.05189034469159586, 0.03398866046752248, 0.06790600690458502, 0.09514753227787358, 0.09270958988262074, 0.19821781585259096, 0.015741233813709447, 0.07448178476520947, 0.023800058523193002, 0.11104199795850686, 0.04994229779445699, 0.0425014895653086, 0.15724128963691847, 30.43931109564645, 88.11255209786552, 68.23496491568429, 85.4354111807687, 95.54186480385917, 49.656701292310444, 28.360991988863262, 32.37841088431222, 54.526575565338135, 48.47182846069336, 27.94637039729527, 2.6394766867160797, 0.23182952297585352, 0.6993842284594263, 6.166360795497894, 28.311286313193186, 63.295810154506135, 57.47472749437605, 44.53306838444301, 62.162274088178364, 53.29782485961914, 36.11022233963013, 20.19018142563956, 24.83008074760437, 23.57023685319083, 22.522941827774048, 21.500290325709752, 27.568044458116802, 32.70932926450457, 25.68593900544303, 19.550754342760357, 18.33922301019941, 19.426843643188477, 20.15834477969578, 17.25107431411743, 20.829936810902186, 14.880727631705147, 15.320944649832589, 17.363515274865286, 27.31961509159633, 24.38756387574332, 21.558054174695695, 21.086108207702637, 27.19503215381077, 21.882639271872385, 20.27143713406154, 14.902006489889962, 7.789828675133841, 1.667788918529238, 0.49384902311222895, 0.7060156869036811, 4.721806858267103, 12.34461864403316, 27.359853846686228, 38.73922266278948, 49.3093261037554, 51.045496804373606, 48.44961506979806, 53.687365191323416, 53.07585423333304, 63.34653895241873, 28.776577642985753, 1.5094092914036341, 41.16030509131295, 47.08217484610421, 49.59024524688721, 50.03735835211617, 50.48877239227295, 45.06356334686279, 52.48028244291033, 49.85788985661098, 55.687956537519185, 58.38542788369315, 41.4378091948373, 24.44869586399623, 8.085845385278974, 4.3256049411637445, 1.2608304300478526, 0.07217730342277459, 2.0115343247141158, 12.181547897202627, 4.880220140729632, 3.7926516192299977, 7.516452670097351, 18.10000000681196, 27.162564958844865, 33.40544843673706, 27.400158609662736, 17.229421990258352, 14.584616252354213, 17.19902535847255, 15.614554677690778, 11.274910467011587, 12.891393235751561, 21.67554473876953, 32.67221546173096, 39.70621040889195, 41.39767639977591, 42.1080949647086, 40.71144104003906, 45.52111612047468, 44.219732420785085, 36.840113231113975, 33.64608192443848, 33.993332045418875, 29.368809086935862, 37.88260357720511, 54.01715101514544, 48.384409700121196, 45.06353555406843, 42.59571606772286, 40.0686388696943, 36.8732248714992, 9.14667202745165, 0.7254122889467648, 0.2777904453022139, 0.07466311646359307, 3.0360696571213857, 29.31592287336077, 28.457090786525182, 20.103511333465576, 33.26743984222412, 43.87373644965035, 72.55427088056291, 49.376661096300396, 44.59914575304304, 49.345533166612896, 2.5874012410640717, 0.2530470144535814, 0.0690938231668302, 0.16422684836600507, 0.014956004252391202, 0.08596276691449539, 0.042143155221960375, 0.1600559614598751, 0.029906074716044322, 0.0250013928993472, 0.04729828770671572, 0.05360032757744193, 0.050806619093886445, 0.07425927956189428, 0.02559260555010821, 0.04318508306252105, 0.038496575717415125, 0.07025142426469497, 0.02761487230392439, 0.04034554632380605, 0.021010405982711484, 0.06703359407505818, 0.1937567466603858, 0.2052921676742179, 0.09793962924075977, 0.12225781540785517, 0.19101642870477267, 0.25257548689842224, 0.057730655052832196, 0.2091596680028098, 0.15067830894674572, 0.14277029543050698, 0.23100580860461506, 0.09008692989924125, 0.13084760734013148, 0.1146902364811727, 0.16317862032779626, 0.0727345503068396, 0.2033165722553219, 0.17940176837146282, 0.12305068357714585, 0.2295095303228923, 0.333281011985881, 0.12211912285004344, 0.10508116959993329, 0.19866837667567389, 0.2375146693417004, 0.10889215474682194, 0.3337116917329175, 37.143238816942485, 113.11035020010812, 84.84463364737374, 100.27383817945207, 115.43072891235352, 75.16204793112618, 38.441238743918284, 57.777634211948936, 51.50483873912266, 55.33402919769287, 33.273231165749685, 2.8860104978084564, 0.35954829677939415, 2.4926158700670515, 8.773624113627843, 33.2888194492885, 65.3265323638916, 64.85795974731445, 49.033499990190776, 70.40913268498012, 68.84694835117885, 44.497594356536865, 27.862589018685476, 33.955446992601665, 40.74790171214512, 36.20461709158761, 31.18808024270194, 30.462417330060685, 35.657175472804475, 27.026625190462383, 22.238459995814733, 24.25574960027422, 29.851927757263184, 28.83677683557783, 24.30932715960911, 32.26110444750105, 23.146931750433787, 18.192416259220668, 21.485376017434255, 37.72010258265904, 31.26652193069458, 27.77660506112235, 27.68813017436436, 41.83351257869175, 31.220239979880198, 32.35315070833479, 26.992627654756816, 14.821549824305944, 2.583016493490764, 0.6051237721528325, 1.5343051212174552, 4.3148921217237195, 12.239237921578543, 27.131098304476055, 38.596861021859304, 51.11431176321847, 52.31815317698887, 50.21241474151611, 54.85027824129377, 53.02188410077776, 62.953479358128135, 30.054266248430523, 2.8421630220753804, 46.43451935904366, 51.1917598588126, 54.03643226623535, 52.06893171582903, 54.08102927889143, 50.20737034933907, 57.50614377430507, 48.32152850287301, 52.59435101917812, 52.958850043160574, 43.87672764914376, 27.308013336999075, 13.59983764375959, 4.19031743492399, 1.4200084486177988, 0.31307290920189446, 4.477982410362788, 27.955849477222987, 25.771492174693517, 29.20903526033674, 28.518969706126622, 29.087302821023123, 31.63270241873605, 49.29532200949532, 34.575639724731445, 22.184041704450333, 17.533344881875173, 23.534134013312205, 26.05958706992013, 16.71776533126831, 15.779513597488403, 22.84506552559989, 33.46076304571969, 45.09314182826451, 48.227918897356304, 45.114167077200754, 42.21726853506905, 46.35728318350655, 44.15660803658621, 36.299286297389436, 39.29599918637957, 40.096997942243306, 37.0700569152832, 45.23401655469622, 61.18080629621233, 56.22842911311558, 52.779423236846924, 44.763734681265696, 46.0090776852199, 40.724948338099885, 10.521687524659292, 0.7289557073797498, 0.6843756852405412, 0.19280096223311766, 3.6822477834565297, 29.048573562077113, 35.14995002746582, 43.36395059313093, 51.8211589540754, 55.9391165460859, 87.36516911642892, 53.655938489096506, 53.84875447409493, 60.06609289986746, 1.6568049022129603, 0.28152472206524437, 0.18764694593846798, 0.23008541656391962, 0.09259832371026278, 0.20233386355851377, 0.10224060488066503, 0.3364247190100806, 0.09220530265676123, 0.1795615769390549, 0.171504122870309, 0.18565886547522886, 0.15024536289274693, 0.1872815684016262, 0.18702740275434085, 0.11498583347669669, 0.17605444655886718, 0.15130512602627277, 0.1804239135235548, 0.13979130956743444, 0.10855692452085869, 0.1902020645460912], [0.0744509453486119, 0.030459844108138765, 0.07000301937971797, 0.1017570129728743, 0.04439430710460458, 0.02651053450868598, 0.04738452611491084, 0.02828940566230033, 0.09124972857534885, 0.08870976844004222, 0.08484994234251124, 0.08613474840032202, 0.008818236013342227, 0.028060247423127294, 0.06640824263117143, 0.03677198736529265, 0.008176620085058468, 0.059400394026722224, 0.059171245965574465, 0.05600044843075531, 0.070740084829075, 0.10424634082508938, 0.072278907256467, 0.11417647690645286, 0.03186229456748281, 0.08606140555015632, 0.32094166268195423, 5.795502432755061, 75.9719021660941, 78.0487812587193, 70.99870818001884, 89.32623563494, 71.78734956468854, 38.554226875305176, 33.046365533556255, 39.79113129207066, 37.73548242024013, 18.89778174672808, 0.7461414794836725, 0.05132830735029919, 0.5938302895852497, 2.664202719926834, 33.620363167354036, 44.94072961807251, 41.89908272879464, 60.014273234776084, 54.862910066332134, 56.77962275913784, 31.422335284096853, 23.674176692962646, 22.77658408028739, 23.965321847370692, 25.091291325432913, 30.694994381495885, 32.57621567589896, 32.29948282241821, 22.750882693699428, 21.49836220060076, 21.781291110174998, 20.30385569163731, 17.57186916896275, 16.496854305267334, 18.750816924231394, 17.70325439316886, 12.922408257211957, 17.384999104908534, 25.85701928819929, 33.513353960854666, 29.021204607827322, 19.54310785021101, 27.35788229533604, 21.556980678013392, 25.700328724724905, 10.075027789388384, 2.3729131732668196, 2.5103774198463986, 0.2674130121512072, 0.16794555953570775, 1.1432893829686301, 2.884929184402738, 5.756807046277182, 21.10236872945513, 33.36062560762678, 42.07675164086478, 37.32564640045166, 43.13462182453701, 45.828403677259175, 57.17053536006382, 21.73890015057155, 1.1394747133765901, 33.85402066367013, 43.4741872378758, 45.721314566476, 45.323436396462576, 45.98013843808855, 43.53904519762312, 45.46507542473929, 47.276710510253906, 53.60065862110683, 52.493629932403564, 43.763145446777344, 30.281823226383754, 15.815335035324097, 0.6075935853379113, 0.445466653576919, 0.3017176256648132, 0.5914795728666442, 2.4015547335147858, 3.105209227119173, 13.680531416620527, 29.809873785291398, 20.61185196467808, 20.554069008146012, 34.4885961668832, 20.698093005589076, 10.973018186432974, 8.29614998613085, 12.631463732038226, 10.780546137264796, 9.842722586223058, 13.522524169513158, 21.98650962965829, 33.877696650368826, 37.899261883326936, 40.94261108125959, 38.081071921757285, 41.4769275529044, 47.795688833509175, 45.287350927080425, 38.82382392883301, 34.31080566133772, 30.16998849596296, 27.887731075286865, 36.99252544130598, 56.18040663855416, 55.78820514678955, 41.24538230895996, 35.68131004061018, 34.211425576891216, 28.47673681804112, 5.577499662126813, 0.3290750991020884, 0.16146474943629333, 0.11497607614312853, 1.229861006140709, 8.858102917671204, 23.661320788519724, 17.14483288356236, 24.165282317570277, 45.2747677394322, 67.84949970245361, 32.39296736036028, 56.62335082462856, 22.16645928791591, 0.6907737276383809, 0.1760373203349965, 0.07055530617279665, 0.03792728144409401, 0.10069214047065803, 0.05136372348559754, 0.08237388663526092, 0.05317021440714598, 0.09145451044397694, 0.05509803078270384, 0.06182553246617317, 0.14347181921558722, 0.08408286528927938, 0.018114610209262798, 0.08922048139252833, 0.02886455399649484, 0.0770204421132803, 0.09209970225180898, 0.033983537528131685, 0.056245647237769196, 0.05125278640272362, 0.07847750785627536, 0.16822799295186996, 0.06682089370276247, 0.0404164566259299, 0.0854376418782132, 0.060115176386066844, 0.05338692492140191, 0.059036984241434505, 0.027298671592559134, 0.04403605757813368, 0.12112829887441226, 0.03806769748085311, 0.03322774790493505, 0.06106074207595416, 0.023358298299301947, 0.027181866878111447, 0.05337046705452459, 0.08686840760388545, 0.06215912063739129, 0.08304743442152228, 0.12037857196160726, 0.04947829858532973, 0.038183017899947505, 0.025050043860184293, 0.056518079047756534, 0.118648497653859, 0.07202060933091811, 0.14235733901815756, 12.974426814488002, 94.4163816996983, 82.63376549312046, 85.2155910219465, 99.14793818337577, 72.51415893009731, 36.28565393175398, 28.580468211855205, 46.5900547845023, 48.039000851767405, 18.471893651144846, 1.1919223219156265, 0.2996159584394523, 1.0447997535978044, 3.3252274096012115, 37.7992217200143, 53.442208426339285, 45.69939647402082, 65.24923365456718, 59.77211461748396, 61.29360335213797, 37.16930150985718, 25.245131390435354, 25.995844296046666, 26.17749626295907, 29.905387197222026, 38.16388750076294, 39.56834077835083, 38.41771214348929, 30.60071427481515, 28.076597009386333, 28.29739339011056, 24.31104336466108, 23.064871788024902, 19.12487666947501, 18.445447070258005, 18.56238525254386, 17.30915778023856, 21.429529871259415, 26.958756923675537, 30.42164182662964, 27.174333470208303, 19.733789001192363, 25.70713448524475, 19.70239356585911, 22.025964975357056, 12.46205449104309, 5.370951431138175, 2.693806605679648, 0.14053967941020215, 0.40777995011636187, 0.9327276987688882, 3.7774971638407027, 11.103212663105555, 26.108936650412424, 37.085672991616384, 49.745026792798726, 42.17652777263096, 52.14716843196324, 52.15103163037981, 63.679378509521484, 23.66361369405474, 1.241556561418942, 38.85914509637015, 49.35246052060808, 51.802291120801655, 50.54125908442906, 52.596053327832905, 47.1299124445234, 54.19182525362287, 56.72957835878645, 59.57191617148263, 59.28346865517752, 53.736579281943186, 36.38971710205078, 18.368438448224747, 1.8188615377460207, 0.5248740868909019, 0.20212643540331296, 0.2864358771060194, 3.2975579457623616, 7.225924168314252, 6.804721764155796, 19.00661138125828, 24.204544850758143, 24.963774510792323, 33.40800884791783, 23.843361854553223, 12.705637489046369, 11.361954893384661, 13.756707123347692, 13.620423419134957, 12.52027084146227, 17.495682171412877, 27.868583577019827, 38.935710770743235, 40.40171466554914, 43.26546335220337, 40.12522152491978, 46.01684924534389, 51.962447098323274, 48.53655440466744, 43.13314185823713, 38.100068296704976, 37.582375390189036, 36.48075934818813, 43.64959798540388, 57.9125508580889, 59.912496021815706, 47.61339589527675, 44.95745045798165, 37.607663358960835, 31.531043325151714, 6.116408893040248, 0.5899685568043164, 0.9137494542769024, 0.026226213068834374, 1.3792469501495361, 12.49442093712943, 15.563806772232056, 20.886406557900564, 34.645965916769846, 51.457934924534385, 76.00975595201764, 38.78607783998762, 61.8372859954834, 31.639959812164307, 0.9180109798908234, 0.10923872329294682, 0.12840439272778376, 0.0549574315414897, 0.13874916120299272, 0.08234245689319712, 0.041217779341552935, 0.09062224653150354, 0.1586979143321514, 0.06288593342261654, 0.014434122613498142, 0.08391820519630398, 0.03454440439652119, 0.027051455840202313, 0.008155656745657325, 0.03250494186899491, 0.00715179811231792, 0.035204432372535975, 0.08091398461588792, 0.027197710670796887, 0.034427092477147064, 0.02166302265998508, 0.2843247103903975, 0.12148017356438295, 0.11788980050810746, 0.1782652357859271, 0.2184677299644266, 0.10651760787836143, 0.138480827744518, 0.20275598019361496, 0.11624936067632266, 0.26729858400566237, 0.20976349631590502, 0.22844094623412403, 0.18210594755198273, 0.10160185237015996, 0.35532286922846523, 0.17806962771075113, 0.14349664002656937, 0.2753821616726262, 0.17280681511121138, 0.3542923373835427, 0.14768731301384314, 0.16952825603740557, 0.09597193196948085, 0.2598932428019387, 0.3082771322556904, 0.2241139148495027, 0.5115453249641827, 13.346221446990967, 113.43859004974365, 101.79945414406913, 101.85855552128383, 119.8255478995187, 96.63689395359584, 49.45711081368582, 40.26804869515555, 51.48187146868025, 45.06268787384033, 22.1338027545384, 1.5628666686160224, 0.5057637180600847, 1.3392267376184464, 5.009186089038849, 41.67654235022408, 60.79973929268973, 53.39407478060041, 76.11750861576625, 65.41920743669782, 71.27095249720982, 40.71173633847918, 37.2346111025129, 35.354848929813926, 39.73220361982073, 37.32681022371565, 42.68035554885864, 44.03500413894653, 44.89172397341047, 33.56884227480207, 32.298548289707725, 31.762334959847585, 30.851210730416433, 29.538529259817942, 27.444005216870988, 31.185300963265554, 30.567501885550364, 21.02623210634504, 25.819922855922155, 37.40921933310372, 46.8058762550354, 37.39951269967215, 28.864845820835658, 38.89464691707066, 32.179285934993196, 36.55562618800572, 23.020212241581508, 10.524874142238072, 3.8736736944743564, 0.22839369305542537, 0.6941019690462521, 2.9505227846758704, 6.473246659551348, 13.789936883108956, 27.93677840914045, 38.75793416159493, 56.06277016230992, 46.29273789269583, 54.18877499444144, 54.611743109566824, 64.05089173998151, 23.146245615822927, 2.0536110954625264, 43.20272806712559, 54.15801879337856, 55.80452993937901, 53.49862779889788, 55.80374131883894, 51.131581510816304, 54.34441811697823, 54.86880908693586, 56.57187162126814, 55.676884583064485, 50.94476876940046, 35.09477438245501, 21.63924387523106, 1.6687942360128676, 0.42991517377751215, 0.3002112779234137, 0.8434548548289708, 17.417648690087454, 21.69211619240897, 23.248830556869507, 40.58752686636788, 25.002788645880564, 30.09556634085519, 44.070839473179404, 28.7394951071058, 16.820730686187744, 12.556303330830165, 20.173031534467423, 21.05784640993391, 19.730182886123657, 21.518209729875835, 30.342355932508195, 41.92179638998849, 47.36519929340908, 47.33909143720354, 44.70337568010603, 45.37263659068516, 52.49356739861624, 50.4400828906468, 47.43492099217006, 43.556269781930105, 42.45549099785941, 39.36279916763306, 46.995082650865825, 64.5152815410069, 68.3964341027396, 54.686554363795686, 50.140229906354634, 44.663326263427734, 35.8460761478969, 6.617765716144016, 1.3315448526825224, 1.734866936291967, 0.20835408408726963, 1.434862611549241, 13.649287973131452, 27.97281002998352, 34.46028225762503, 48.96856560025896, 63.294851303100586, 88.18898228236607, 44.89983252116612, 80.16122123173305, 38.51418093272618, 0.8336618031774248, 0.22172249960047857, 0.18104309029877186, 0.25802548016820637, 0.17386275130723203, 0.16746883440230573, 0.16009921128196375, 0.28211434185504913, 0.3611042047185557, 0.16207298822700977, 0.09525674248912505, 0.15754315629601479, 0.13305379609976495, 0.15843810327351093, 0.17624712336276258, 0.10019998545093195, 0.09014261726822172, 0.4265533855983189, 0.1732036902436188, 0.11812616139650345, 0.19093260248856886, 0.14804802222975663], [0.04442644930843796, 0.051940729309405596, 0.028751818795821497, 0.030976589236940657, 0.04193575760083539, 0.07437672040292195, 0.0979375597089529, 0.0830998851784638, 0.0035712752640912576, 0.13114019164017268, 0.11895505977528435, 0.009974041537913893, 0.05526807165837713, 0.00844950566533953, 0.0223240633495152, 0.03240270699773516, 0.03475983247959188, 0.03619391284883022, 0.07707813794591598, 0.03025813939582024, 0.08053015092653887, 0.009688351153662162, 0.05032761747549687, 0.04828058249716248, 0.12994484363922051, 0.03193905384146741, 0.05906804757458823, 1.3817376622131892, 58.21331058229719, 84.7341503415789, 62.9524371283395, 83.54384749276298, 79.91817324502128, 49.215789454323904, 26.135011502674647, 35.40123162950788, 23.140638419560023, 10.39902923788343, 0.6284051771674837, 0.2501147389411926, 0.7284680849739483, 2.494810849428177, 39.906971658979145, 51.70344257354736, 55.61940213612148, 63.847281728472026, 58.62689168112618, 55.070748056684224, 38.427363191332134, 29.62003857748849, 24.94493099621364, 28.42911560194833, 30.665349892207555, 41.06818240029471, 37.0426219531468, 43.590955189296174, 31.70593990598406, 25.47752778870719, 22.8900203704834, 23.55607295036316, 17.341803891318186, 21.803798062460764, 16.679847274507793, 14.40486374923161, 17.14348840713501, 24.722658123288834, 31.277110985347203, 26.778605767658778, 25.723976918629237, 21.260110207966395, 25.452050481523784, 25.607019628797257, 27.05300750051226, 6.37622548852648, 4.5481027620179315, 2.8259239963122775, 0.1087904627035771, 0.14085236191749573, 0.2277328542300633, 0.04221687126638634, 2.5341628406729018, 8.850280114582606, 20.33388406889779, 35.44985512324742, 36.852592195783345, 36.07960510253906, 41.517647470746724, 59.683358328683035, 14.88312476021903, 1.515896411878722, 42.81351430075509, 53.531211376190186, 50.04738460268293, 51.321625164576936, 54.91509451184954, 49.61140945979527, 49.45877143314907, 46.345408712114605, 54.08571236474173, 54.75837441853115, 42.94167382376534, 28.159626245498657, 10.4097364119121, 0.6044927345854896, 1.4218133517674036, 0.27585909036653383, 0.20131965726613998, 0.21818153746426105, 1.5098125040531158, 7.4650238411767145, 18.888523272105626, 17.59570149012974, 26.60687756538391, 36.16879217965262, 20.94995825631278, 10.420987282480512, 9.602075202124459, 14.32730621950967, 15.01008745602199, 11.350749186107091, 18.067692620413645, 30.149116107395717, 36.75988585608346, 40.08448771068028, 36.64048106329781, 43.33134617124285, 48.99189070292881, 49.32053354808262, 45.52551433018276, 42.46452713012695, 36.85742466790335, 39.544692584446494, 33.4372364452907, 41.27203212465559, 54.85543727874756, 50.4750531741551, 38.0993561063494, 35.18572282791138, 34.35495451518467, 21.025497334344045, 2.8594642536980763, 0.21689875344080584, 0.8111010566353798, 0.08451959756868226, 0.4836302857313837, 5.172017557280404, 10.361794710159302, 8.895697014672415, 27.328672068459646, 57.40544353212629, 53.354699339185444, 34.85646506718227, 58.86343615395682, 3.656202026775905, 0.5290722644754818, 0.130081853430186, 0.20435838135225431, 0.13621986763817923, 0.021971839214009897, 0.03941015187384827, 0.07731257858020918, 0.10585523556385722, 0.046758390963077545, 0.050489359867892096, 0.06645861028560571, 0.1367940575416599, 0.023206208067546998, 0.08836269777800355, 0.06202418716358287, 0.09141686532114233, 0.061855991903160296, 0.10371566537235465, 0.01954435813240707, 0.019775533316923038, 0.1369566209614277, 0.06420861530516829, 0.036867969536355565, 0.07274285557546786, 0.08492255237485681, 0.07543652424854891, 0.027553626036803638, 0.0466861201982413, 0.10872792891625847, 0.06891061871179513, 0.041874814978135486, 0.08709457011095115, 0.06117812863418034, 0.11236974171229772, 0.02448599466255733, 0.033314912513430626, 0.01943345836895917, 0.06814757894192423, 0.02685090633375304, 0.06014319309698684, 0.04141253246260541, 0.03108702420390078, 0.04944662457065923, 0.10009362508675881, 0.044306480924465826, 0.0853447640048606, 0.04808908973687461, 0.06840931025466748, 0.08528057459209647, 1.9919627692018236, 85.01951285770961, 96.3865920475551, 83.79106439862932, 96.28941454206193, 86.02841213771275, 46.8322377204895, 20.969630343573435, 35.04441383906773, 33.067324774605886, 11.376353297914777, 0.7234827524849347, 0.5088837306414331, 0.8308779639857156, 3.210610577038356, 41.47127519335066, 56.282791818891255, 61.581279618399485, 73.6163169315883, 70.02571024213518, 66.4100900377546, 44.503083433423726, 37.0248693057469, 30.18249872752598, 31.192016397203716, 37.666959285736084, 49.134756088256836, 46.36010067803519, 48.82848644256592, 37.25457327706473, 30.60712398801531, 28.914066859654017, 30.60777711868286, 24.35997257913862, 22.977783066885813, 17.682494912828716, 15.858078616006033, 17.34191506249564, 25.189385993140085, 28.29598637989589, 23.21191304070609, 24.44657145227705, 18.11454779761178, 21.0963203225817, 14.470674480710711, 19.06879081044878, 11.514057908739362, 6.687207315649305, 2.829220699412482, 0.04123407096735068, 0.11007351814103977, 0.1387387253344059, 1.0551443185125078, 3.4182483724185397, 11.808750987052917, 23.34350844791957, 41.455572264535085, 43.69462578637259, 44.333946909223286, 50.7194630077907, 63.9844183240618, 18.24821550505502, 1.1914887108973093, 49.553221770695274, 61.32014547075544, 57.116290773664204, 59.76962716238839, 60.74695382799421, 55.59559760774885, 57.7880391393389, 51.939921038491384, 62.20169816698347, 60.45232936314174, 52.12277678080967, 33.815319197518484, 14.528086577142988, 1.266733033316476, 1.5088810111795152, 0.23671733641198703, 0.14764793084136077, 1.7573311137301582, 7.162926154477256, 6.4079383696828565, 19.43817789213998, 20.19082760810852, 22.50287890434265, 29.403025490897043, 21.495951175689697, 14.988379546574183, 13.475461414882115, 15.354817117963519, 16.488130841936382, 15.23390804018293, 26.24605761255537, 35.60240977151053, 38.396297795431956, 40.4635397366115, 38.25159113747733, 45.12144531522478, 53.05500616346087, 49.6204560143607, 49.79961878912789, 47.12897443771362, 44.10162694113595, 45.016690799168174, 42.297732148851665, 48.88185208184378, 61.73448739733015, 58.42540087018694, 45.23682362692696, 40.89804186139788, 38.11881801060268, 23.907491990498134, 3.4470992471490587, 0.9021293520927429, 1.1293198125702995, 0.0672464505104082, 0.4346147615994726, 3.348727737154279, 7.235677267823901, 20.882684060505458, 38.067995412009104, 59.16912909916469, 64.47036143711635, 38.90201200757708, 75.99461582728794, 10.517958947590419, 0.49336373486689156, 0.08714364854884998, 0.036023807512330155, 0.019531352312437127, 0.06219133748007672, 0.03800753517342465, 0.03981470802266683, 0.009180077534568096, 0.0756194233628256, 0.0864533477329782, 0.06059484636144979, 0.013564963359385729, 0.06827173049428634, 0.07623765018901654, 0.022906594144712602, 0.03668247502563255, 0.01673149799795023, 0.04031567042693496, 0.0557064629559006, 0.015046298603660293, 0.08778576659304754, 0.06547449023595878, 0.11276189424097538, 0.183925276356084, 0.1342173343790429, 0.17711826733180455, 0.13964296824165753, 0.14782988679196152, 0.2924505743597235, 0.12329933952007975, 0.10316084764365639, 0.2835364969713347, 0.32555496799094336, 0.18137736379035882, 0.20816598060939992, 0.14624044565217836, 0.0751361164397427, 0.1210043305265052, 0.10913599309112344, 0.1195152582866805, 0.1355765350162983, 0.14194967517895357, 0.17946917404021534, 0.20882624946534634, 0.1821391550557954, 0.18344876835388796, 0.1916897390037775, 0.17577574508530752, 0.1456387343683413, 2.3055542962891713, 95.51822008405412, 115.63628441946847, 98.5457239151001, 112.99442645481655, 109.88629572732108, 70.76057256971086, 39.778669697897776, 48.890638078962056, 29.721506595611572, 12.731308477265493, 1.0737356351954597, 0.7553028964570591, 1.6054489208119256, 3.3743893887315477, 47.81269802365984, 64.4956806727818, 70.03366592952183, 80.85085078648159, 72.94853946140834, 70.69840703691754, 50.86091790880476, 45.196068968091694, 37.618492126464844, 37.85432093484061, 41.82849250520979, 50.598307268960134, 52.80874810900007, 54.967932088034495, 43.99405493055071, 36.436273506709504, 32.660695348467144, 33.58279773167202, 30.14870616367885, 33.49643162318638, 29.404536724090576, 27.69738343783787, 25.509520769119263, 34.52254853929792, 41.83668095724923, 36.67310285568237, 33.06071703774588, 27.848895856312343, 32.45132875442505, 37.33961227961949, 40.561241831098286, 20.12484404018947, 15.576749529157366, 3.243549163852419, 0.36807634202497347, 0.22873733033026966, 0.7580071027789796, 3.148810910327094, 5.773425834519522, 11.030152354921613, 25.032417501722062, 43.51956592287336, 46.553882462637766, 50.34482308796474, 52.53921358925955, 64.47960254124233, 18.649560826165335, 3.061008478913988, 50.26792390005929, 60.70063018798828, 57.41158921377999, 56.991469860076904, 60.067510332380024, 55.242524896349224, 58.09597635269165, 50.77606998171125, 62.232478686741416, 56.34608990805489, 50.48882450376238, 29.758964334215435, 14.913978236062185, 2.8298677504062653, 1.8470765437398637, 0.26833744826061384, 0.22251520492136478, 5.125003005777087, 10.605290855680193, 15.311363083975655, 32.16780056272234, 23.36834304673331, 33.517196314675466, 48.385924407414024, 27.445367063794816, 15.099316222327095, 16.010888610567363, 24.438294410705566, 26.61706015041896, 23.063787869044713, 28.269230604171753, 38.3941855430603, 45.976386410849436, 47.2927747453962, 42.85351160594395, 47.960656438555034, 54.05157586506435, 52.054392610277446, 50.871263776506694, 49.444791657584055, 45.397104672023225, 50.407398564474924, 44.52193737030029, 54.62881135940552, 65.72767271314348, 64.34874016898019, 53.26368488584246, 46.09722253254482, 41.42023720060076, 26.302956410816737, 2.645471462181636, 2.963659005505698, 1.9585113184792655, 0.08623637937541519, 0.5413100506578172, 6.7864744918687006, 12.8113717011043, 36.26161316462925, 49.65914705821446, 74.08857904161725, 70.96024990081787, 48.42439658301217, 84.51521260397774, 7.480312483651297, 0.9345471497092928, 0.16378563775547914, 0.30171757138201166, 0.15759591917906488, 0.11910688877105713, 0.09605141556156532, 0.1324975738035781, 0.2168285386370761, 0.20713810862175056, 0.20737240676368984, 0.15588003982390675, 0.15786256987069333, 0.12285291776061058, 0.15940420143306255, 0.1615477478397744, 0.17355389573744365, 0.18073666388435022, 0.3170914107135364, 0.10101706374968801, 0.10532249057931559, 0.2963926728282656, 0.17126754485070705], [0.2106402585549014, 0.024671200795897415, 0.024674328842333386, 0.07590438771460738, 0.15779273504657404, 0.03240032194714461, 0.07547977407063756, 0.012956945940719118, 0.10757684175457273, 0.024404149768607955, 0.07687775298420872, 0.03375780249812773, 0.01411810765109424, 0.03742343187332153, 0.02095055071237896, 0.09797026509685175, 0.15709685667284898, 0.018834466314209358, 0.05206065019592643, 0.056343844825667996, 0.062491752074233124, 0.05364483608199017, 0.08655996594045844, 0.009940035907285554, 0.14223304497344152, 0.23762983030506543, 0.13965310555483612, 0.13402749385152543, 24.792376347950526, 76.8519401550293, 57.296832765851704, 72.54555089133126, 77.84894411904472, 55.86622646876744, 31.818007401057653, 30.601256234305247, 21.08038636616298, 4.554070396082742, 0.3503932851765837, 0.5706434994935989, 1.5185172941003526, 0.9462682179042271, 28.154222284044536, 65.32495512281145, 42.53672933578491, 64.95301805223737, 57.351859024592805, 61.639436040605815, 55.92669664110456, 30.69675922393799, 28.454441785812378, 31.299352169036865, 42.17072950090681, 57.20425844192505, 51.268586090632844, 43.308601243155344, 35.091685908181326, 34.01973867416382, 31.686252185276576, 25.38001503263201, 21.08941207613264, 16.78172176224845, 16.09292425428118, 13.060245752334595, 15.438707930701119, 23.748478991644724, 30.915801184517996, 30.029270103999547, 26.336905309132167, 22.343594925744192, 26.992909056799753, 41.68546036311558, 25.89507978303092, 4.1155270252908975, 2.756255711827959, 1.2313829873289381, 0.2795462225164686, 0.14617211717580045, 0.08833953937781708, 0.3630890282137053, 1.5317911761147636, 4.109057818140302, 7.5367249080113, 17.638309580939158, 24.163062368120464, 29.49884114946638, 38.08051259177071, 62.01785578046526, 8.727789453097753, 2.0707249428544725, 51.75455699648176, 55.21413803100586, 50.43217584065029, 54.37079695292881, 52.741666725703645, 50.26016971043178, 49.18701001576015, 47.08176837648664, 57.90762111118862, 54.03432696206229, 39.11563784735543, 18.432224648339407, 2.6255425087043216, 0.48389811707394464, 0.48880549946001595, 0.20660456296588692, 0.18178478335695608, 0.06055410033357995, 1.5034299322537013, 3.1216595215456824, 18.85802241734096, 19.243202754429408, 28.649158103125437, 24.406885078975133, 21.040010384150914, 12.367647579738072, 12.55678015095847, 17.621708597455704, 14.125330771718707, 12.987994040761675, 18.557069880621775, 27.074922118868145, 37.93386738640921, 39.10689353942871, 42.591210160936626, 39.26558344704764, 42.43206167221069, 47.16953802108765, 44.85492631367275, 45.924076897757395, 42.10927268436977, 37.314466748918804, 38.50285536902291, 44.90437664304461, 46.35182189941406, 46.144723892211914, 39.498573916299, 31.66779429571969, 17.431671891893657, 9.846551912171499, 1.239753286753382, 0.8027749976941517, 0.276240562754018, 0.09655477997979947, 0.0752707581434931, 0.8296511183891977, 4.046778074332646, 23.16472782407488, 34.14194359098162, 75.08965465000698, 39.007082666669575, 51.640637806483674, 19.612072195325577, 0.44925795442291666, 0.16389021357255323, 0.2933082426232951, 0.08214565459638834, 0.11842968368104526, 0.027946857436160957, 0.10003207517521721, 0.07323585197861705, 0.0759041230859501, 0.031181930896959136, 0.09656980953046254, 0.01559408670956535, 0.021165179820465188, 0.04396009897547109, 0.014431025101138013, 0.06207821212176766, 0.02484921276170228, 0.06135026618306126, 0.07335918928895678, 0.11856102091925484, 0.09328811562487058, 0.05300116079992481, 0.008319308365961271, 0.11822986868875367, 0.05811841067458902, 0.016835037352783338, 0.1047900305794818, 0.08693031035363674, 0.06883024623883621, 0.047688492839889865, 0.07119907984243971, 0.04481103956433279, 0.05177324651075261, 0.03662213629909924, 0.0676061079970428, 0.06567347741552762, 0.009917675633914769, 0.051575633364596536, 0.07514379067080361, 0.11528713016637734, 0.02242645089115415, 0.02112724123123501, 0.05576644205887403, 0.0689108833404524, 0.029260777735284398, 0.019925728739638413, 0.03459040228543537, 0.043986354888017686, 0.05446586345455476, 0.017089562623628547, 0.13720724465591566, 44.28368364061628, 99.99118546077183, 71.37213911328996, 87.73046370915004, 85.56578023093087, 64.86259419577462, 30.513601234980992, 25.518134798322404, 23.38502046040126, 5.2944439479282925, 0.4582112782767841, 0.7073991926653045, 2.4112954565456937, 0.9640389957598278, 31.249707290104457, 66.56192902156285, 56.958823748997276, 67.95224271501813, 65.37155669076103, 66.09712232862199, 53.89011015210833, 37.825385161808555, 36.87757444381714, 37.642185483660015, 48.20873839514596, 61.636615071977886, 57.487268992832725, 49.34351471492222, 40.66612836292812, 37.83985825947353, 35.611136708940776, 33.426011630467, 28.83719720159258, 21.367253167288645, 17.45755566869463, 13.728493962969099, 16.092027936662944, 27.980937685285294, 29.890618801116943, 28.97601178714207, 23.593452521732875, 21.576875107628958, 18.706725393022808, 30.03519344329834, 19.56827769960676, 8.110342127936226, 5.207038215228489, 1.0844240273748125, 0.20199710662875855, 0.07356253266334534, 0.1370362945433174, 0.4647833513362067, 2.3056266009807587, 4.901505947113037, 12.033773609570094, 22.33020748410906, 30.814135142735072, 37.32327706473214, 45.46930340358189, 64.83316162654332, 12.286092230251857, 3.2105308898857663, 59.32094029017857, 59.79903193882534, 58.59932122911726, 60.27881894792829, 57.657374790736604, 55.053367137908936, 55.75121988568987, 53.26968812942505, 63.155255045209614, 60.72554642813546, 43.02054630007063, 21.52086567878723, 4.482495265347617, 1.005658271057265, 0.7434378702725682, 0.13943336877439702, 0.1246785433696849, 0.23098284697958402, 2.592945469277246, 4.801874424730029, 21.09528156689235, 21.847646406718663, 27.066061428615026, 24.965601887021744, 22.438496896198817, 16.109766687665665, 12.35428966794695, 18.401338168552943, 16.776759011404856, 20.07319286891392, 26.90022008759635, 29.934965678623744, 39.1614716393607, 40.27047709056309, 44.84108897617885, 44.67992203576224, 46.435252393995015, 47.74039854322161, 47.4491092136928, 49.6063164302281, 48.179684502737864, 43.26731504712786, 45.21087210518973, 53.375133991241455, 54.18225411006382, 53.028481415339876, 47.96225452423096, 29.00322961807251, 18.050289119992936, 12.440535051482064, 1.0756618061235972, 0.40117405887160984, 0.27342323107378824, 0.19306094971086296, 0.15808275448424475, 0.7621556658829961, 3.226542579276221, 39.1828373500279, 37.15908070972988, 77.12299633026123, 49.189181327819824, 57.66797079358782, 40.59440210887364, 0.5841000974178314, 0.04822703590616584, 0.15452261694840022, 0.021018607774749398, 0.09626287421477692, 0.016732127339180027, 0.06545197644404002, 0.03375702218285628, 0.05378003079178078, 0.018516559087272202, 0.06682423209505421, 0.07213669988725867, 0.05667798600292631, 0.028086759482643435, 0.03821708375055875, 0.08093293609895877, 0.019930717668363025, 0.07619332149624825, 0.06549049687704869, 0.0938687991084797, 0.06434785747634512, 0.029102913170520748, 0.019248498204563345, 0.2892697107579027, 0.18464581269238675, 0.15375209972262383, 0.1855570309396301, 0.13670639081725053, 0.13600751331874303, 0.3036248247538294, 0.15824014746717044, 0.20087356120347977, 0.17323972045310906, 0.20158975491566317, 0.17314232353653225, 0.20486109437687056, 0.14060586371592113, 0.10361655854753085, 0.18175557920975344, 0.24919858095901354, 0.1435873465878623, 0.15209985338151455, 0.169465287987675, 0.184018059234534, 0.16693674081138202, 0.21284164328660282, 0.11630377918481827, 0.27880879065820147, 0.3350439545299326, 0.43766265947903904, 0.18013092210250242, 49.078673703329905, 120.27159445626395, 85.6328511919294, 106.89955697740827, 104.22086661202567, 89.73833329336983, 55.36990622111729, 41.46679013116019, 28.34838100842067, 5.342133777482169, 0.5723525392157691, 1.2299432988677705, 2.643169871398381, 1.063786683338029, 36.33840118135725, 75.52288178035191, 53.926921708243235, 75.91025774819511, 68.97144617353166, 70.25784260886056, 65.16402789524624, 44.20709364754813, 43.85169676371983, 44.489669936043875, 52.27451501573835, 65.32715770176479, 62.08978353227888, 55.383260658809114, 46.16916070665632, 45.681053229740684, 40.57592337472098, 34.94483573096139, 34.37718875067574, 26.66920985494341, 29.206471375056676, 25.636688436780656, 27.514772619519913, 37.06674609865461, 42.052592754364014, 39.655280113220215, 35.29852335793631, 30.885288170405797, 33.63524620873587, 48.01414367130825, 35.4989788872855, 18.374558074133738, 14.339912857328143, 1.8115469302449907, 0.32242681298937115, 0.3110047887478556, 0.23693148206387246, 0.2812662273645401, 2.9952667951583862, 5.424413476671491, 12.830791916166033, 23.763063260487147, 33.65992273603167, 45.51720775876726, 49.95268760408674, 63.768037523542134, 14.683562074388776, 6.0915030751909525, 63.216531208583284, 61.44478920527867, 60.74649524688721, 61.39871570042202, 60.855234554835725, 55.776726722717285, 54.37862409864153, 51.597128186907085, 59.28890214647566, 55.81848887034825, 41.252966267721995, 19.875146627426147, 7.4642239298139295, 0.7993343366043908, 0.7683016732335091, 0.21830779926053115, 0.30779387961540905, 0.2641667920563902, 3.6350853656019484, 18.385082857949392, 31.840015820094518, 26.41214735167367, 40.86555208478655, 30.450588021959575, 27.683464459010533, 15.027021953037806, 17.96979945046561, 29.761809621538433, 26.34073202950614, 25.527488810675486, 27.50409844943455, 34.5506192616054, 45.22681474685669, 48.21481806891305, 50.66292551585606, 46.83842856543404, 49.64641101019723, 52.02976819447109, 51.893486227308, 53.57414429528372, 49.114766120910645, 48.5275217464992, 50.1832983153207, 56.59739930289132, 60.79405566624233, 60.18714441571917, 57.02573490142822, 41.5059814453125, 21.06733591215951, 10.829393710408892, 1.9965785443782806, 2.9990318502698625, 0.6031243194426809, 0.44894075287239893, 0.213197901312794, 1.7331212013959885, 8.96897097996303, 54.149771281651084, 46.96391650608608, 93.8504022870745, 54.713874680655344, 76.80551924024309, 38.8666422026498, 0.4567760410053389, 0.29901863049183575, 0.3766716436616012, 0.07642870529421739, 0.3222176342138222, 0.24174788647464343, 0.26640848176819937, 0.17203328518995217, 0.1866654586046934, 0.19415223758135522, 0.14033637674791472, 0.17147487801100525, 0.18933085272354738, 0.13705542923084327, 0.27159919323665754, 0.2717917886163507, 0.10531572558517967, 0.3390564577920096, 0.12925372858132633, 0.31169143904532703, 0.13744213990867138, 0.19431832938322, 0.10788603659187045], [0.11133766280753271, 0.040566585891480954, 0.03474264518756952, 0.06912772956171206, 0.15261293442121573, 0.034298632227416546, 0.02528859980936561, 0.07843305024185351, 0.03687083634680935, 0.054428720447633944, 0.10584527466978345, 0.03069899038278631, 0.07999698525028569, 0.01705217534410102, 0.10104164028806345, 0.01970991728428219, 0.03546064041022744, 0.06566228158771992, 0.050193026661872864, 0.06009241153619119, 0.0617467477651579, 0.0321216985051121, 0.031801653892866204, 0.040054790675640106, 0.11109443514474801, 0.1856800221971103, 0.0539963952531772, 0.05585335221673761, 7.206930833203452, 85.1896811894008, 77.89189788273403, 53.988722460610525, 77.89613628387451, 59.86962563650948, 29.590626852852957, 12.839404208319527, 7.825804710388184, 1.345567837357521, 0.28864339579428944, 0.9323678037949971, 0.6860446099724088, 0.6862759632723672, 14.337541784558978, 62.88370554787772, 60.82280036381313, 65.84465953281948, 69.28015463692802, 61.92151205880301, 57.49468272072928, 39.683201449257986, 27.603475059781754, 32.91647938319615, 52.876288073403494, 60.71802847726004, 54.007090023585725, 43.21141331536429, 35.35995932987758, 32.73153918130057, 30.913351944514684, 29.88740873336792, 21.952685798917496, 19.653782231467112, 13.659507036209106, 13.179283159119741, 13.678210718291146, 23.441399880817958, 31.79404306411743, 23.512519904545375, 24.513517345700944, 12.911490031651088, 24.436383656093053, 30.93627405166626, 11.00079013620104, 4.7261859604290555, 3.4741066779409135, 2.0845857305186133, 0.09856124874204397, 0.12082673077072416, 0.047092467679509094, 0.1185944319835731, 0.08278145547956228, 1.7110439517668314, 6.365678123065403, 12.607731291225978, 20.806019374302455, 23.357540334974015, 28.070724044527324, 51.044398988996235, 13.119437456130981, 9.103513291903905, 41.13801179613386, 65.34875965118408, 52.0512033871242, 55.98265743255615, 49.40838309696743, 49.67403357369559, 48.58791896275112, 43.81918266841343, 52.17510713849749, 43.73749617167881, 25.237618650708878, 4.008280711514609, 1.151966380221503, 0.4040041741515909, 0.24419948777982167, 0.10808758863380977, 0.20782212620334967, 0.6621129512786865, 2.7073334455490112, 2.445257599864687, 16.706809759140015, 15.37662751334054, 24.600830146244594, 20.56427070072719, 23.328611510140554, 20.415469816752843, 15.953763995851789, 14.228052071162633, 17.481540850230626, 15.84530782699585, 19.680082900183542, 28.278435230255127, 31.478118896484375, 36.017248494284495, 34.84909997667585, 37.993555886404856, 41.85344696044922, 42.15401560919625, 45.01246976852417, 48.86176136561802, 41.02300173895699, 36.76187998907906, 46.07727425439017, 39.40597874777657, 44.62678221293858, 44.92369263512747, 45.4912805557251, 28.9684191431318, 12.011581063270569, 2.090249163763864, 0.3702236882277897, 0.3106961910213743, 0.24565725241388592, 0.03383659737716828, 0.15733662380703858, 1.929062898669924, 33.169522353581016, 23.115713494164602, 63.81028257097517, 55.03590631484985, 33.28023147583008, 58.839096614292686, 3.9507309538977484, 0.4890817446368081, 0.018707724454413568, 0.29581344819494654, 0.057290462244834216, 0.021724776132032275, 0.018031886612464274, 0.11607963192675795, 0.04747903586498328, 0.03297950586836253, 0.06662173010408878, 0.20318587284002984, 0.0489280915020832, 0.17562474390225752, 0.026672658577029194, 0.02146588109566697, 0.07867162315441029, 0.06258353072085551, 0.051288321281650236, 0.04457264985623104, 0.10992732777127198, 0.07303733977356128, 0.1131554241957409, 0.019601872456925254, 0.06291361086602722, 0.10941442993602582, 0.00801167415920645, 0.03228647055636559, 0.010451178033170956, 0.0390168424429638, 0.05685963322009359, 0.009577576919192714, 0.02419126110284456, 0.003590054144816739, 0.08489665947854519, 0.033825459224837165, 0.12758422030934266, 0.04128964637805309, 0.0210433573395546, 0.010199225258215197, 0.0403212717335139, 0.026967856933229735, 0.027173787222376893, 0.04928904838327851, 0.10774720154170479, 0.03084934356489352, 0.006275883618010474, 0.09680225527180092, 0.14126332343689033, 0.06611721217632294, 0.04708158737048507, 0.10031972652567284, 15.523144177028112, 102.38450636182512, 82.87367984226772, 78.26148646218437, 88.70262786320278, 72.97718688419887, 44.46226276670183, 12.148928710392543, 8.490863697869436, 1.9844886788300105, 0.26987457435045925, 0.7944225573113987, 1.0486982358353478, 0.7362841569951603, 17.220602989196777, 67.50183268955776, 65.36041872841972, 73.27157511029924, 68.44977542332241, 70.17986297607422, 61.58594880785261, 44.71102564675467, 35.115070070539204, 40.277932507651194, 57.16535895211356, 65.09060628073556, 59.71824523380825, 48.189273016793386, 40.16023349761963, 37.37761197771345, 37.47835738318307, 35.367633615221294, 29.295811312539236, 26.583239793777466, 18.831132888793945, 17.53710559436253, 12.393571308680944, 21.99950623512268, 31.70181267602103, 25.49526306561061, 21.81213763781956, 15.196622269494192, 25.345545019422257, 33.95627382823399, 9.980735523360115, 8.378027558326721, 1.5899682257856642, 2.299477228096553, 0.026907469012907574, 0.07875192098851715, 0.12705036252737045, 0.16531251796654292, 0.016632209665008953, 2.5161947991166795, 8.023391502244131, 13.048672659056527, 24.552684341158184, 30.06379222869873, 35.81029987335205, 56.30216339656285, 21.657627071653092, 12.185052394866943, 48.41665628978184, 70.23530960083008, 59.058819498334614, 61.81710147857666, 58.90674427577427, 56.57290342875889, 55.65024518966675, 53.82530777794974, 57.92490822928292, 49.467335087912424, 29.984822477613175, 4.78335530417306, 0.3033749610185623, 0.4212042497737067, 0.4074151968317372, 0.27371565252542496, 0.17075633656765732, 0.7309721506067685, 3.4095123154776434, 2.797554067202977, 17.85860742841448, 17.335738113948278, 25.692458152770996, 16.58770547594343, 20.90122011729649, 21.90429506983076, 20.37295205252511, 16.484887770244054, 24.1363274369921, 24.36030956677028, 29.12631869316101, 34.693185874394004, 34.069404397692, 38.2034227507455, 37.08088568278721, 43.49823842729841, 43.38828318459647, 40.098728043692454, 45.16337421962193, 50.9523457799639, 47.53799057006836, 44.619576930999756, 50.79814440863473, 45.26350818361555, 54.176389830453054, 54.8633964402335, 39.937429087502615, 20.874759640012467, 12.003277097429548, 2.7322468629905154, 0.3910818004182407, 0.15109448161508354, 0.11434608351971422, 0.014560302985566003, 0.18339760681348188, 0.7515635713934898, 38.77283804757254, 34.733732087271555, 54.647373471941265, 71.61687551225934, 41.2004656791687, 74.61753150394985, 10.36838333947318, 0.35330734880907194, 0.1639534258948905, 0.12846707579280647, 0.01955073805791991, 0.06883389675723654, 0.03247315928872142, 0.09071903276656355, 0.03992358575175915, 0.04204774980566331, 0.07377189464334931, 0.039832953829318285, 0.02421037543431989, 0.07804131161953722, 0.03633899042116744, 0.043599515288536034, 0.054895705210843256, 0.0318931780888566, 0.047034758276173046, 0.0888571191046919, 0.06074159312993288, 0.03690985550305673, 0.08730164542794228, 0.018987964506128004, 0.3330986217728683, 0.20372028702071734, 0.04028381660048451, 0.10460075323602983, 0.2202159482985735, 0.12170603073069028, 0.18983811193278857, 0.10405103130532162, 0.19277356298906462, 0.12459367220955235, 0.19488470256328583, 0.15859257855585643, 0.26463964954018593, 0.058855652543050904, 0.24152000727398054, 0.10227588191628456, 0.22124194752957138, 0.15818975945668562, 0.13122534778501305, 0.17069864752037184, 0.18288875983229705, 0.1452466089810644, 0.11254633045090096, 0.22960194679243223, 0.23630416286843164, 0.32768749498895233, 0.3526636633489813, 0.15503803214856557, 16.091239316122874, 118.56426920209611, 104.04090132032121, 87.4188300541469, 107.69229779924665, 93.310457774571, 69.6028220312936, 19.46828964778355, 13.279207808630806, 2.8443851428372517, 0.4327487631567887, 1.5450190263135093, 1.7102546798331397, 1.7287302655833108, 18.336429834365845, 78.83194746289934, 74.10989611489433, 75.56839942932129, 75.72163500104631, 72.10057435716901, 69.36900125231061, 52.75376353945051, 44.596321310315815, 44.062164647238596, 62.98964473179409, 68.27612604413713, 64.16094425746373, 55.24782984597342, 48.90936347416469, 44.348274094717844, 42.46650389262608, 39.61610964366368, 34.31562771115984, 35.59316866738455, 30.275896412985666, 25.81053236552647, 24.614266225269862, 34.660654408591135, 42.96564858300345, 31.400583948407853, 32.99511562074934, 21.241671425955637, 34.69263696670532, 42.24365431921822, 18.211871215275355, 23.40486798967634, 11.155072280338832, 2.9671632860388075, 0.2093860815678324, 0.4406975566276482, 0.23064670073134558, 0.22935240875397409, 0.19040638501090662, 3.2076276285307745, 9.439554231507437, 15.837866306304932, 28.864677327019827, 35.905163628714426, 39.79125983374459, 59.69120979309082, 32.33346993582589, 11.671897530555725, 47.151528290339876, 64.98456287384033, 54.298747607639854, 56.63751820155552, 55.778595788138254, 52.7422434261867, 55.54671355656215, 52.327442918504985, 54.664351395198274, 46.416996002197266, 29.061493737357004, 5.9498445051057, 1.3860101529530116, 0.656238466501236, 0.7840900431786264, 0.20342786556908063, 0.328182581279959, 0.9966835869210107, 4.349932321480342, 20.483341557638987, 30.785477297646658, 22.088153089795792, 33.81667409624372, 26.46578570774623, 27.10190371104649, 24.349439110074723, 26.747618538992747, 25.565919297082083, 30.786922522953578, 26.484097685132706, 30.745827402387345, 39.670388971056255, 41.11949137278965, 42.99752344403948, 43.4306081363133, 48.23226499557495, 51.41978931427002, 46.87440981183733, 49.26340545926775, 54.10844339643206, 50.913446290152415, 48.927519117082866, 57.53533315658569, 52.638079507010325, 59.82289205278669, 58.991623469761436, 57.53200149536133, 34.95164843967983, 15.060258660997663, 2.9598967730998993, 1.0195771413190025, 0.8785411949668611, 0.9865989280598504, 0.0927856672289116, 0.6901764539735658, 2.9996932319232394, 56.83645902361189, 36.473095485142295, 78.52010536193848, 73.24580424172538, 48.51935413905552, 88.57721982683454, 8.666211911610194, 0.7613412610122136, 0.2456023453601769, 0.4457640419048922, 0.17151382592107567, 0.1617765769894634, 0.2403530084661075, 0.1795834664787565, 0.19860426868711198, 0.08737948017993144, 0.15473412988441332, 0.3471001647412777, 0.15132265937115463, 0.3202343577785151, 0.14407582394778728, 0.1834094404642071, 0.17360189530466283, 0.12192745027797562, 0.29605717797364506, 0.1781634148210287, 0.33238157310656136, 0.19586401858500072, 0.19510507716664247, 0.18048914788024767], [0.07974991707929543, 0.08548418938049249, 0.011748694748218571, 0.09792202125702586, 0.057137052262468, 0.06449729802885226, 0.1024089562041419, 0.07985699669058834, 0.035490675762827904, 0.033964813354292085, 0.019604664628526995, 0.053690973070583174, 0.0648867024907044, 0.06918999193502323, 0.05841144959309271, 0.04091329014460955, 0.1482677725808961, 0.04981968312391213, 0.0706712542367833, 0.03040673177955406, 0.07254752569964953, 0.05749122718615191, 0.08351773382829768, 0.03367974043690732, 0.05883515400013753, 0.14405374441828045, 0.17062904339815888, 0.11497717536985874, 0.4444849762533392, 52.475116457257954, 101.44794477735246, 68.4841342653547, 82.77148573739188, 69.14806243351528, 42.818760190691265, 11.150885122162954, 1.7595182763678687, 0.04946091451815196, 0.5732078733188766, 0.5413557567766735, 1.0264099346739906, 0.36593165567943026, 2.2259385798658644, 46.33348560333252, 70.49500547136579, 64.71053981781006, 74.44382653917584, 60.98670836857387, 63.374178886413574, 45.23417636326381, 37.20862831388201, 35.10294198989868, 51.52843482153756, 60.20960794176374, 60.33757291521345, 47.77412857328142, 36.03835712160383, 34.6380797113691, 31.062686102730886, 30.119819028036936, 23.31760730062212, 21.21812050683158, 15.717631203787667, 13.125587480408804, 13.992424760546003, 24.349699667521886, 31.124580655779155, 22.812980481556483, 21.200711795261928, 18.20731840814863, 12.222398093768529, 4.446230445589338, 4.652581087180546, 3.431854030915669, 5.561838856765202, 2.6656158098152707, 0.17265269266707556, 0.0762012739266668, 0.3354826952729906, 0.25967003192220417, 0.36498167951192173, 0.9460996155227933, 6.611700373036521, 11.877498200961522, 13.73700898034232, 20.380612441471644, 23.920413902827672, 25.963371889931814, 8.18342067514147, 8.54969756943839, 33.97592680794852, 55.24441828046526, 50.44206312724522, 47.23860658918108, 44.5240079334804, 39.27186461857387, 29.82557671410697, 29.471986361912318, 32.460920742579866, 23.500016621180944, 5.697980122906821, 0.8478289086903844, 1.3056443567786897, 0.10579443204083613, 0.31259603479078835, 0.06800358702561685, 0.06271007750183344, 1.9883950863565718, 2.056849390268326, 6.415978303977421, 10.798042569841657, 21.268051998955862, 21.526881081717356, 18.49425642830985, 24.046443802969797, 25.933524165834697, 10.70110651424953, 7.871922510010855, 15.548218488693237, 18.15863585472107, 22.916906424931117, 22.808222702571324, 25.117218528475078, 26.825163909367152, 31.153683185577393, 37.22897263935634, 36.94011517933437, 36.17916236604963, 37.06334842954363, 42.33356748308454, 43.158527101789204, 38.94515684672764, 42.0024093900408, 44.721183913094656, 37.081875801086426, 40.83005721228463, 44.0212710244315, 20.92282554081508, 5.845355323382786, 0.9567840993404388, 0.01917151501402259, 0.2719515429011413, 0.09340821632317134, 0.17735437037689344, 0.3709936626255512, 34.76880659375872, 22.258488178253174, 39.54752744947161, 74.76365906851632, 36.680471420288086, 49.027479376111714, 28.974832330431255, 0.5571574260081563, 0.14738005878669874, 0.03990902778293405, 0.03453346641202058, 0.045496074948459864, 0.05274266949189561, 0.06095917895436287, 0.07774950763476746, 0.052900595124810934, 0.05497643052201186, 0.029899062056626593, 0.03435629413330129, 0.0715064290644867, 0.036719020921736956, 0.05119536876944559, 0.09197557784084763, 0.009655275116009372, 0.08957967747535024, 0.03704122666801725, 0.039768659243626256, 0.13294335774012975, 0.15964090158896788, 0.011778135534508951, 0.004558454234419125, 0.04871923842334321, 0.0513595267465072, 0.05181779572740197, 0.0356218094405319, 0.03517582194347467, 0.06104850808956793, 0.007975899248516985, 0.036913726545338116, 0.06693919628326382, 0.025432825820254426, 0.008687925907517118, 0.03782421536743641, 0.04688975873536297, 0.07014038200889315, 0.05881289126617568, 0.07300392192389284, 0.13263144876275743, 0.006495014381861048, 0.06269998768610613, 0.07334445829370193, 0.0444303949895714, 0.03096781238647444, 0.13343932612666062, 0.09148315819246428, 0.0681561284831592, 0.1292490331189973, 0.051841296787772856, 0.03963217870997531, 1.8601990853037154, 80.73517022814069, 108.48178686414445, 71.01773234776088, 102.1396518434797, 77.50712054116386, 59.9618421282087, 15.976265736988612, 2.215994404894965, 0.28686053146209034, 0.6735566886407989, 0.3338760057730334, 1.7907990664243698, 0.7937718693699155, 3.19670375755855, 48.737673486982075, 77.96742480141776, 76.43898786817277, 83.67699582236153, 61.19007519313267, 69.59225382123674, 55.64535018375942, 44.87751143319266, 45.37635735103062, 58.731656619480674, 65.9941291809082, 62.39838777269636, 50.302300112588064, 41.5455618585859, 36.52104500361851, 37.35927220753261, 36.512543882642476, 33.105661460331504, 24.124628407614573, 23.66834889139448, 19.70889707974025, 16.11038507734026, 23.56415891647339, 35.16616364887783, 21.138820716312953, 16.973271438053676, 16.32616659573146, 13.873620118413653, 8.539638314928327, 7.08634397813252, 7.936855162893023, 1.1693053926740373, 3.1890683387007033, 0.12293020289923463, 0.16010354033538274, 0.1036927444594247, 0.15484270905809744, 0.34714025259017944, 1.8683745094708033, 9.11013318811144, 12.005328553063528, 12.819992678506033, 19.82935278756278, 28.23840492112296, 29.18045731953212, 9.954682384218488, 10.052373187882559, 39.62921742030552, 63.696630886622835, 57.88759640284947, 54.51529516492571, 50.55324125289917, 46.46975367409842, 32.93814386640276, 33.90888711384365, 41.030731609889436, 23.35021867070879, 7.708979436329432, 1.70033341220447, 1.042525629912104, 0.3011860341898033, 0.5391685941389629, 0.12152079067059926, 0.060946300359708924, 1.9121449036257607, 2.8299993319170813, 2.7378557963030676, 10.556031601769583, 17.979674577713013, 21.380981070654734, 18.78405363219125, 23.338380677359446, 27.69184398651123, 16.17331838607788, 17.017086778368267, 26.89715419496809, 26.53263780048915, 31.11913674218314, 30.435308933258057, 31.706846645900182, 32.79998935971941, 36.2830240385873, 40.23183468409947, 36.9848963192531, 38.24824210575649, 42.02580050059727, 47.51642336164202, 51.73686688286917, 46.43197284426008, 51.11439861570086, 55.16743918827602, 49.04632636478969, 44.15464169638497, 33.275134972163606, 17.752739463533672, 7.13937132699149, 1.212338626384735, 0.10153568842049156, 0.1389202605932951, 0.027188248499961834, 0.225978909060359, 0.6450491526297161, 31.353499480656215, 40.918250696999685, 35.49898930958339, 83.53490516117641, 49.12918710708618, 51.96180091585432, 54.33436407361712, 1.2537631349904197, 0.05242625164932438, 0.04072164471394249, 0.04557781466948135, 0.07538924392844949, 0.10692993325314351, 0.03189474889742477, 0.028800351013030325, 0.08375977405479976, 0.04065001516469887, 0.05994102358818054, 0.02113518857264093, 0.022041015859161104, 0.01726164249703288, 0.08167718723416328, 0.02355250350332686, 0.06438097677060536, 0.04183488319228802, 0.09462248866579362, 0.09742209701133625, 0.06746646549020495, 0.17220711229102953, 0.05435375250609858, 0.07692240058843579, 0.16855747598622525, 0.24485926809055464, 0.10881519530500684, 0.24566648049013956, 0.187225019293172, 0.09953928233257361, 0.18158431697104657, 0.14761530687766417, 0.1020495972729155, 0.17722103824572905, 0.09234144392290286, 0.14196711352893285, 0.1326095727937562, 0.22495292340006146, 0.20414138585329056, 0.11992273213607924, 0.24678326770663261, 0.11805943426276956, 0.11441958243293421, 0.1290148842547621, 0.14320879190095834, 0.07400113769939967, 0.33949205013258116, 0.16474509984254837, 0.14286128697650774, 0.2915869892707893, 0.23125124829156057, 0.15951610542833805, 1.2666887385504586, 86.84611088888985, 130.42159243992396, 89.70148699624198, 117.76942307608468, 102.40883895329067, 79.63171986171177, 33.66554382869175, 3.376811704465321, 0.7214979018483842, 0.9867332237107413, 1.5955097398587634, 2.7024386567728858, 1.114787438086101, 3.8867510727473666, 56.6054870060512, 86.51722485678536, 73.58414677211216, 79.23907021113804, 66.40050152369908, 76.39816720145089, 61.84497765132359, 54.3486704145159, 50.254802227020264, 63.632026536124094, 72.59788472311837, 65.61033848353794, 55.624429157802034, 50.25637946810041, 45.81702252796718, 42.54956265858242, 39.642811570848735, 37.3876382282802, 32.57161944253104, 30.549905572618755, 23.99577580179487, 25.274192231042043, 34.87262657710484, 44.36268465859549, 29.514262676239014, 26.485452583857946, 26.482501336506434, 17.600016321454728, 9.251188567706517, 12.091415865080696, 19.310918160847255, 9.267166818891253, 4.035267514841897, 0.45105213671922684, 0.6823452913335392, 0.8674614780715534, 0.4617666932088988, 0.6356163216488702, 2.2212344322885786, 9.733035717691694, 14.95364202771868, 20.02649576323373, 28.459892647606985, 33.791285378592356, 32.47515065329415, 17.63410418374198, 13.57592715535845, 41.43492916652134, 59.93914236341204, 54.04950530188424, 56.46654735292707, 53.88004568644932, 50.011010783059255, 42.17407158442906, 39.195830481392996, 43.31234632219587, 23.834610598427908, 10.76086710180555, 2.537131892783301, 2.246735623904637, 0.595461867749691, 1.0495346252407347, 0.1936177826885666, 0.19614191938723835, 3.400818816253117, 4.278356322220393, 13.822508301053729, 16.459146431514196, 28.95829909188407, 26.561613525663102, 23.48216496195112, 28.535296235765728, 33.7410637991769, 19.919919082096644, 19.79346534184047, 29.2003812789917, 28.338408606392996, 34.73195334843227, 32.63198191779, 35.15087066377912, 38.560466357639854, 44.01265178407942, 50.2597701890128, 45.490505831582205, 44.939371245247976, 45.60416099003383, 51.28234352384295, 54.34918805531093, 54.221247400556294, 56.68646478652954, 57.30167218617031, 54.45683997017996, 53.50424541745867, 53.79310287748064, 27.25502290044512, 7.658736143793378, 1.4213083045823234, 0.3714685014316014, 0.8032083372984613, 0.3073868400284222, 0.3833415614707129, 0.6950606033205986, 56.8960155078343, 40.10851805550711, 55.12203965868269, 93.33618695395333, 55.83656808308193, 66.16772297450474, 56.94667134966169, 0.7821463389056069, 0.16360760373728617, 0.17701156091477188, 0.13677435288471834, 0.17587916739284992, 0.3156476781836578, 0.1318149132920163, 0.2662195504776069, 0.23632202191012247, 0.1226841253893716, 0.3435832905982222, 0.11681832586015974, 0.13206095008977822, 0.09536345569150788, 0.18597327146146977, 0.10860419127025775, 0.08455164477761302, 0.1627539252596242, 0.3012034318276814, 0.21637271238224848, 0.1597899350204638, 0.31546504369803835, 0.16692315654030868, 0.18822980751948698], [0.0667587738218052, 0.06338292639702559, 0.045385270179914575, 0.04388068662956357, 0.04652214203295963, 0.03833190205373934, 0.06666960074965443, 0.03528174804523587, 0.06161789396511657, 0.017524483214531626, 0.02211721534175532, 0.07070409533168588, 0.04527978512591549, 0.0653748270124197, 0.0291372266864138, 0.033322881907224655, 0.029099917438413416, 0.06483974786741392, 0.09123178810945579, 0.04103273605661733, 0.010973992657714655, 0.03652837972289749, 0.10316087478505713, 0.0805952020787767, 0.06715750814016376, 0.18694930337369442, 0.12738627807370254, 0.06406296097806521, 0.08149937713252646, 23.516667979104177, 101.6091638292585, 94.77337319510323, 73.99116529737199, 79.84573132651192, 54.1907239641462, 39.008555684770855, 4.903497040271759, 0.4793934587921415, 0.21048832099352563, 0.7501255114163671, 0.5043771181787763, 0.710715111877237, 0.5583035530788558, 12.839918375015259, 46.29820612498692, 66.63922773088727, 53.08082219532558, 65.41928386688232, 58.52418340955462, 45.900366170065745, 41.48199278967721, 43.95850099836077, 51.57884747641427, 49.0244152205331, 46.77607543127877, 40.76925005231585, 38.65017107554844, 31.855482510157994, 32.04832281385149, 24.191360643931798, 28.468808923448833, 19.566719566072734, 16.731979608535767, 11.174125977924891, 15.140037877219063, 18.634872334344045, 24.784488405500138, 23.72195598057338, 20.837400913238525, 18.514503479003906, 10.467536738940648, 4.216862159115927, 4.047935817922864, 3.0479753954069952, 4.948980816773005, 1.68388746040208, 0.06124855378376586, 0.23321753421000072, 0.13233815878629684, 0.8430779150554112, 0.3021167128213814, 0.3589869311877659, 0.6276146567293576, 4.407542875834873, 7.55587066922869, 18.0347147328513, 21.224523271833146, 22.473375116075786, 5.876366436481476, 4.217569138322558, 18.495041574750626, 31.017807688031876, 31.05201366969517, 26.634717260088237, 28.58898149217878, 21.39717905861991, 11.677936383656093, 14.723899841308594, 16.033409459250315, 5.077600657939911, 0.2238966343658311, 2.5214641392230988, 0.2773554500724588, 0.6688579693436623, 0.10677038931420871, 0.045976318285933564, 0.11397211572953633, 0.8362449045692171, 3.3619736092431203, 6.476809782641275, 16.04547848020281, 22.594146966934204, 18.810052054268972, 20.235910994665964, 18.01700724874224, 15.275406156267438, 6.970383754798344, 5.369244345596858, 12.897618821689061, 17.817435877663748, 23.829072884150914, 19.081559862409318, 28.94331530162266, 28.252294370106288, 34.98172719138009, 32.63654688426426, 27.719358852931432, 27.148423637662614, 28.538190160478862, 33.1680771282741, 38.23388712746756, 45.00604615892683, 43.52470758983067, 49.33449247905186, 46.0702600479126, 43.86360250200544, 27.912141833986553, 12.154389125960213, 0.7253922585930143, 0.13885590833212647, 0.08316935359367303, 0.07802396826446056, 0.06428653826670987, 0.10154899449220725, 30.49497311455863, 26.30538306917463, 30.083386148725236, 72.54984487806047, 50.489745140075684, 33.2263308252607, 65.84096309116909, 4.2315632445471625, 0.6238291912845203, 0.05200834193133882, 0.16718583101672785, 0.10227085397179637, 0.13557749853602477, 0.017535697702052336, 0.149631831528885, 0.0846003500212516, 0.028663639777473042, 0.039512196755302806, 0.10442096859748874, 0.11688411661556788, 0.0380536993034184, 0.041995546714003594, 0.06587245102439608, 0.13886847480067185, 0.09214056363063199, 0.06850071570702962, 0.023688646465806023, 0.06317640747874975, 0.04449459118768573, 0.1908165594296796, 0.07628775321479354, 0.0369444132915565, 0.03843960252457431, 0.0229606377626104, 0.009765109579477991, 0.02882160272981439, 0.017027854952695112, 0.08575497235038451, 0.06376135894762618, 0.05266196792945266, 0.05925068884555783, 0.08633579832634755, 0.05894093082419463, 0.05426616042054125, 0.06818776178572859, 0.11261801089027099, 0.04345763361613665, 0.10626202409288713, 0.010950393209766065, 0.04015990932072912, 0.045661905514342446, 0.09406507893332414, 0.0826853070674198, 0.08012081110583884, 0.035697177717728276, 0.04292981818850551, 0.1123134708032012, 0.030314932776881114, 0.1563299356826714, 0.20815318343894823, 0.08324201112346989, 43.253446442740305, 118.26792853219169, 94.70789337158203, 92.91569587162563, 94.56745638166154, 66.32166726248605, 52.31077766418457, 1.816622480750084, 0.244240579860551, 0.04280191773016538, 0.686036576117788, 0.25707086282117025, 0.7835142655032021, 0.443761983620269, 18.15901279449463, 52.30257878984724, 73.76342419215611, 65.00776985713414, 72.25469929831368, 68.87917409624372, 50.60574184145246, 46.13455867767334, 54.710977281842915, 59.833724294389995, 56.66936526979719, 58.65768609728132, 51.3350282396589, 45.10258790424892, 38.098661286490305, 36.400017806461875, 29.809526375361852, 37.439391885484966, 29.654178551265172, 25.267641816820415, 18.601015499659947, 22.278295755386353, 19.48228853089469, 25.39125026975359, 23.882078954151698, 21.414513077054703, 17.723478862217494, 12.129955785615103, 6.56765443938119, 9.979543907301766, 7.34848952293396, 3.1867265786443437, 0.44756316393613815, 0.09166816076529877, 0.26310067783508984, 0.2753700837492943, 0.4234575831464359, 0.15359275255884441, 0.5965432897210121, 2.1808938426630835, 5.3012775012425015, 9.52462797505515, 18.941902807780675, 22.284651620047434, 27.54425208909171, 7.950816699436732, 6.8116234966686795, 23.321307216371807, 33.61651039123535, 30.605751718793595, 28.624908890042985, 33.397065435137065, 22.15557493482317, 17.708611454282487, 20.273940222603933, 12.674321957996913, 3.1028607359954288, 0.2662489717560155, 2.4645798887525285, 0.4399263337254524, 0.28228321565049036, 0.164163934599076, 0.13312289810606412, 0.2631186454423836, 1.325495685849871, 2.0544585585594177, 1.1986000835895538, 6.461759550230844, 15.281758546829224, 12.439808964729309, 15.596650906971522, 16.86133074760437, 19.68219862665449, 16.628538302012853, 17.841834477015905, 22.897977794919694, 27.295221703393118, 31.64556006022862, 29.23678289140974, 38.03712109157017, 34.16706132888794, 40.76396942138672, 37.023708956582205, 33.1540904045105, 31.710619517735072, 37.21602119718279, 42.93790095193045, 47.129995822906494, 53.03950473240444, 55.0150408744812, 57.20392492839268, 49.329378604888916, 37.800131934029714, 21.147427797317505, 10.757600579942975, 1.2980862366301673, 0.13567948234932764, 0.7496026594723973, 0.17857092938252858, 0.1301062535494566, 0.144750694877335, 26.761014665876115, 47.33730575016567, 31.745621068137034, 68.3234919139317, 69.73098850250244, 41.678442682538716, 78.96287931714738, 13.055265630994525, 0.7729325390287808, 0.10888031431074653, 0.04524667261700545, 0.10443641883986336, 0.06895323749631643, 0.1158962103405169, 0.05628022877499461, 0.03566951045234289, 0.043368480900036435, 0.01984606703211154, 0.04607664308111582, 0.0270522921346128, 0.028773287643811533, 0.026786883162068467, 0.05907981337181159, 0.07300422047930104, 0.009269730670244565, 0.051383241545408964, 0.01824439869129232, 0.08086753210851125, 0.05832157762987273, 0.12780858469860895, 0.017735417699441314, 0.03168425715661474, 0.10131163615733385, 0.222289985577975, 0.1173708297844444, 0.18937217550618307, 0.10190321691334248, 0.22433358377643994, 0.1751598659902811, 0.19412923524422304, 0.17830908271883214, 0.1323680414685181, 0.09267990397555487, 0.1516389652554478, 0.23610885334866388, 0.17673391795584134, 0.07394870051315852, 0.31289266315954073, 0.1403891939137663, 0.20421341913087027, 0.2746356374451092, 0.16065670922398567, 0.3828560289527689, 0.15110478177666664, 0.34612434996025904, 0.18296873196959496, 0.17744080216756888, 0.36921058116214617, 0.1892046316393784, 0.287610828344311, 0.20652817349348748, 47.30419410978045, 139.13700975690568, 116.02008206503731, 98.46224825722831, 114.90521580832345, 86.26506778172084, 72.88258716038295, 8.734814081873212, 2.114796063729695, 0.29663317278027534, 2.267609532390322, 1.587611157979284, 1.2729487397841044, 0.8276272384183747, 20.32125571795872, 60.23947824750628, 72.87929371425084, 55.68254736491612, 70.91560077667236, 71.0760555267334, 57.506272315979004, 55.493393080575125, 61.72771985190255, 66.2679785319737, 62.84414945329939, 62.651899746486116, 57.50561918531145, 49.38761840547834, 42.153935704912456, 44.56439781188965, 37.35546112060547, 42.17597539084298, 37.612978730882915, 32.87763895307268, 23.798236778804235, 27.992925064904348, 28.326758214405604, 33.65899862561907, 33.26394142423357, 27.91774729319981, 27.808988877705165, 15.857494967324392, 8.541560360363551, 14.166653445788793, 10.72649610042572, 8.54840954712459, 2.6021765853677477, 0.2453801929950714, 1.1412414014339447, 0.7099934763142041, 1.4757602512836456, 0.39076153188943863, 0.9054376717124666, 2.23060125538281, 7.470836009298052, 14.722213166100637, 26.061614206859044, 29.69707325526646, 28.168052673339844, 10.659128972462245, 8.859564644949776, 25.48397397994995, 39.2936680657523, 39.849899155753, 40.980968611580984, 48.08271196910313, 39.79567888804844, 28.24352400643485, 29.635043212345668, 19.30870863369533, 6.306683574404035, 3.328022539615631, 4.997590848377772, 0.4105418047734669, 0.9053357286112649, 0.22065648037408078, 0.29713450159345356, 0.19370050967804023, 1.390369170478412, 4.506908629621778, 10.56867732320513, 24.743740694863455, 28.57718345097133, 20.297664846692765, 22.893880094800675, 22.434968948364258, 21.755184991019114, 16.138370684215, 16.96543734414237, 20.72314473560878, 28.65717806134905, 34.96129601342337, 30.64342485155378, 41.030398096357075, 38.50181661333357, 47.5603220803397, 43.42962496621268, 39.346453530447825, 34.81395251410348, 38.23203543254307, 44.29282052176339, 52.91185242789132, 58.70518398284912, 58.0546658379691, 62.902430943080354, 58.56584480830601, 54.022636617933, 34.18513011932373, 13.474440898214068, 1.4710251625095094, 0.24185349366494588, 1.7710818158728736, 0.5422683049525533, 0.645984336733818, 0.1811383566153901, 55.168300764901296, 44.49286263329642, 45.662591866084504, 88.64677129473004, 71.90328025817871, 49.2740535736084, 94.6385086604527, 9.951522690909249, 1.3473029328244073, 0.176865513037358, 0.4317857591169221, 0.1700411063752004, 0.18881066063685076, 0.3025828663791929, 0.29173564272267477, 0.14557379856705666, 0.13577966125948088, 0.09787416418216058, 0.3335957165275301, 0.2670864739588329, 0.11325469386896916, 0.14440373278089932, 0.12258641634668622, 0.2632783997271742, 0.16398747478212627, 0.14374297537973948, 0.11138001696339675, 0.3865095057657787, 0.08019269510571446, 0.37222970915692194, 0.1371909055326666, 0.1667613937918629], [0.0986885011994413, 0.08020692398505551, 0.05040656163224152, 0.035392746196261475, 0.025953438598662615, 0.024945177969389727, 0.028923630647893463, 0.05527106399780937, 0.027919230882876685, 0.013952114236807185, 0.022712702763133814, 0.013325923954003623, 0.029663532373628447, 0.025215287493275743, 0.07603360792355877, 0.06853836082986423, 0.04120891767420939, 0.012666715309023857, 0.0625888097233006, 0.027662069503484026, 0.09552425492022719, 0.022485016944951246, 0.05909385226134743, 0.025065936846658587, 0.0735103397497109, 0.2301312583897795, 0.04697018888379846, 0.06015052127518824, 0.09326720317559582, 3.0505069281373705, 99.5200628553118, 100.89180401393345, 68.02016135624477, 76.69079753330776, 83.09510503496442, 45.482112407684326, 41.22816119875227, 0.9542866562094007, 0.5026809434805597, 0.03917078507531967, 0.47142018377780914, 0.2074824380023139, 0.09348143025168351, 1.1551881730556488, 17.16581470625741, 41.90851143428257, 49.54796545846121, 61.13821383884975, 60.232342447553364, 62.32348619188581, 50.91790355954851, 44.03038706098284, 45.95421123504639, 45.00229065758841, 43.59300490788051, 38.907893657684326, 29.592471599578857, 27.6486713545663, 31.82203040804182, 30.349832194192068, 28.311915125165665, 15.06379703113011, 11.457174743924822, 9.2104651757649, 7.464037196976798, 12.487720268113272, 19.876501526151383, 21.369886534554617, 17.263567175183976, 11.108376043183462, 10.281907796859741, 5.942774278776986, 5.093659681933267, 1.0631762189524514, 6.085864612034388, 0.3534887619316578, 0.3963898170207228, 0.2566092690186841, 0.1538831384054252, 0.7180133802550179, 1.146836546914918, 0.11417639548225061, 0.8503788975732667, 4.503618657588959, 3.1301224274294714, 9.618613651820592, 10.82830458027976, 13.870086090905325, 4.23044501883643, 5.45183367388589, 14.027128406933375, 16.97395236151559, 10.966897691999163, 11.859915784427098, 10.551455344472613, 5.341617439474378, 5.4765071613448, 5.378235748835972, 1.9432013971464974, 0.6142497424568448, 0.7320766970515251, 0.5092431370701108, 0.01700026571883687, 0.0699671588039824, 0.08001989937786545, 0.11318500832255397, 0.029537558954741274, 0.23830095572131021, 1.4456940931933266, 2.2107741364410947, 6.027422879423414, 15.259475673948016, 17.88312762124198, 18.15207154410226, 16.287199360983713, 10.456761819975716, 4.050336420536041, 7.463986822537013, 9.404031566211156, 15.226259810583931, 27.22391060420445, 28.411932706832886, 24.872954607009888, 24.314583471843175, 22.253110272543772, 22.713523966925486, 23.58706886427743, 21.480302095413208, 25.469243798937114, 35.94320501599993, 46.469260351998464, 40.445561272757395, 41.2808632850647, 47.86930499758039, 47.40446356364659, 32.35860851832798, 16.653025490897043, 2.746933400630951, 0.28738981591803686, 0.2618621342948505, 0.08941680871482406, 0.15176921683762754, 0.0502288024207311, 29.135029997144425, 24.402010917663574, 25.793488434382848, 66.75814614977155, 67.54279232025146, 30.48332793372018, 51.889018535614014, 36.05668646948678, 0.4149108374757426, 0.03403703662167702, 0.1372151699449335, 0.023332664942634956, 0.09063624470893826, 0.09399768683527197, 0.11508601238684994, 0.022089218986885886, 0.044809451792389154, 0.04700788150408438, 0.010159462257953627, 0.048328761876161606, 0.04328606942934649, 0.013381478160486689, 0.020499372422429066, 0.10504781960376672, 0.017826633161998222, 0.05786893370428255, 0.025064038644943918, 0.025569073955661485, 0.03153796500659414, 0.05852790655834334, 0.0559793154575995, 0.08430107536592654, 0.03208321199885436, 0.007879931496323218, 0.00731849465851805, 0.017050643551296422, 0.12428594300789492, 0.06416337059012481, 0.068281433545053, 0.03162005417315023, 0.04517081579459565, 0.032267118737633736, 0.03547604315515075, 0.02268190405863736, 0.02351521121870194, 0.03997115105656641, 0.08066213955836636, 0.20377952312784536, 0.03300656923758132, 0.05208906724250742, 0.031164404337427447, 0.04187927634588309, 0.11680220386811666, 0.06735226804656641, 0.036385103661034784, 0.03517937407429729, 0.05760430504700967, 0.09713045587497098, 0.09981241981898036, 0.05443298504022615, 0.16251694011901105, 0.090488073016916, 12.963453003338405, 116.02000563485282, 108.17748355865479, 82.41813509804862, 90.19141837528774, 84.31593826838902, 60.66394369942801, 36.95811448778425, 1.3629363796540668, 0.5768452009984425, 0.10097821761987039, 0.8613366410136223, 0.47502201050519943, 0.2176937793514558, 1.5101135564701897, 17.333347933632986, 45.26971639905657, 52.27615826470511, 62.489075660705566, 67.33567346845354, 74.04682731628418, 58.036416394369944, 52.01638943808419, 54.16361209324428, 54.16617945262364, 48.91177797317505, 45.04443148204258, 35.18817554201399, 35.88679606573922, 37.63272551127842, 37.25900970186506, 35.44727734157017, 24.258426393781388, 21.1520448752812, 20.882003137043544, 15.787681204932076, 20.61289072036743, 24.23441341945103, 23.26511366026742, 22.300243377685547, 19.197297743388585, 12.74445446899959, 7.804115039961679, 8.628071512494769, 9.311531066894531, 1.3687234691211154, 0.37398043807063786, 0.3306860498019627, 0.08392648332353149, 0.13367978536656924, 1.0344330413000924, 1.1550425865820475, 0.27692392894199913, 1.5911427970443452, 6.11534321308136, 6.299496965748923, 11.66017244543348, 14.019636511802673, 13.301430753299169, 3.6110721741403853, 8.482337389673505, 16.07688954898289, 17.557778222220286, 11.725657480103628, 10.58949499470847, 11.121278847966876, 8.96042469569615, 8.868649414607457, 4.561584872858865, 0.9941111249583108, 0.26505171028631075, 0.7857370376586914, 0.21271943912974425, 0.1279198508709669, 0.3263378616954599, 0.12723144995314734, 0.15540175405996187, 0.02955197443121246, 0.4533630098615374, 0.11721910935427461, 1.0821651028735297, 5.582911006041935, 10.419502105031695, 12.185829724584307, 12.855869701930455, 19.963081291743688, 23.723852838788712, 17.119850635528564, 17.366197279521398, 24.494547026497976, 25.500618389674596, 33.349918433598106, 36.58236633028303, 34.37750836781093, 35.359486852373394, 32.82486391067505, 30.09836299078805, 33.12184728894915, 32.777473722185405, 38.32156991958618, 43.98851374217442, 54.00217069898333, 50.96111788068499, 48.64554384776524, 51.90008701596941, 44.73746354239327, 23.775686400277273, 14.480837089674813, 3.0884471322808946, 0.29605416527816225, 0.47171396229948315, 0.1130383497636233, 0.27013491466641426, 0.4348267359392983, 22.48126653262547, 43.45149094717843, 30.43625041416713, 57.60954686573574, 79.13329083578927, 48.62736736025129, 55.22306646619524, 57.51776463644845, 0.8356596274035317, 0.11100599489041738, 0.12798102758824825, 0.022734957015407935, 0.06814479016299758, 0.05492774224174874, 0.07510673587343522, 0.039335014298558235, 0.02383967818293188, 0.0453993158548006, 0.023308137598048364, 0.026667096286213825, 0.0656720796333892, 0.013611711029495512, 0.012592658300751021, 0.12253764324954577, 0.052022764193160195, 0.11074785302792277, 0.05021026823669672, 0.020558868069201708, 0.007347362930886447, 0.040167617478540966, 0.06605199817568064, 0.09850074377443109, 0.02498894856710519, 0.22910496060337338, 0.11495425445692879, 0.12781057959156378, 0.24550938606262207, 0.09647964579718453, 0.0902893233246037, 0.06639573044542756, 0.17117807322314807, 0.10772201432181255, 0.14046651976449148, 0.1756218804844788, 0.10502590292266437, 0.13023529733930314, 0.1090479531724538, 0.2556861899793148, 0.23456477906022752, 0.08708630555442401, 0.15179676535938466, 0.09099583434207098, 0.32280814966985155, 0.23094001784920692, 0.15091138572565146, 0.19002977093415602, 0.147709867517863, 0.14470569443489822, 0.5888331777283123, 0.15740568510123662, 0.2030660028436354, 0.14596719960016863, 9.060119186128889, 136.9526767730713, 124.78985513959611, 95.38412679944719, 102.29347106388637, 112.89511585235596, 69.93463325500488, 71.36098725455147, 1.950037556035178, 1.8692877633231026, 0.0909651034910764, 2.6777996931757246, 2.422694844858987, 0.2764099250946726, 2.2695910717759813, 22.712328876767838, 51.37533473968506, 52.24682991845267, 61.63524627685547, 71.35383061000279, 82.68310465131486, 65.05301652635846, 61.36495440346854, 60.135665212358745, 62.391488211495535, 57.760545117514475, 53.54469435555594, 40.117859908512656, 37.57279035023281, 43.89619650159563, 44.72677721296038, 47.121147292000906, 30.661153180258616, 26.0622239112854, 24.207699332918438, 20.4089298248291, 25.158403975622996, 28.577885219029017, 28.19476154872349, 25.01871391705104, 20.544107028416224, 17.299682174410137, 9.192340799740382, 9.503294399806432, 10.113559893199376, 9.359959142548696, 0.5959316853966031, 0.41656822711229324, 1.1974250780684608, 0.2955370401697499, 2.611841095345361, 5.048052574907031, 0.791854763669627, 2.498320992503847, 6.576293655804225, 6.93216301713671, 15.766862664903913, 19.417145695005143, 17.574994121279033, 4.706330180168152, 16.408669505800518, 28.773956435067312, 25.207077843802317, 22.552848611559185, 23.27851673534938, 25.61567187309265, 21.41861946242196, 14.651546512331281, 7.639764087540763, 1.9055951407977512, 0.5497916841081211, 1.7254114151000977, 2.114707039935248, 0.3505065733832972, 0.425408914153065, 0.3852111968610968, 0.39199130875723703, 0.06360748756144728, 1.1367846748658588, 1.6726141167538506, 9.961292726652962, 17.2411071232387, 24.926198652812413, 25.18791123798915, 21.54596257209778, 23.272202559879847, 24.70709936959403, 14.725803647722516, 17.390913758959087, 21.119817393166677, 28.27252405030387, 39.37147399357387, 41.1963141305106, 37.65550170625959, 40.6789790562221, 33.371339729854036, 33.536421980176655, 35.918368680136545, 33.883116245269775, 41.049641132354736, 50.729242597307476, 61.52061489650181, 52.376347814287456, 53.11730023792812, 59.58102525983538, 61.843858991350444, 36.916536467415945, 19.820924622671946, 3.417398303747177, 0.40749043279460495, 0.7874302268028259, 0.3948768467775413, 0.5558510561074529, 0.38333697457398686, 50.28829254422869, 39.613535336085725, 41.57650566101074, 81.39802837371826, 87.13050760541643, 51.73229496819632, 72.05401447841099, 56.88137912750244, 0.7151844863380704, 0.29174986481666565, 0.14651879428752831, 0.10443837980606727, 0.15385755763522216, 0.1598324520247323, 0.11563634499907494, 0.20670133563024656, 0.18771725573710032, 0.14327113569847175, 0.09793436380901507, 0.08578568284532853, 0.16775657396231378, 0.1581123928938593, 0.12433732167950698, 0.2980326648269381, 0.08569886428969246, 0.2013718094676733, 0.14659352813448223, 0.1895522858415331, 0.07975592889956065, 0.12164455545800072, 0.16318871692887374, 0.20610463193484715, 0.07596715898918253], [0.05700151489249297, 0.05107743938320449, 0.019456425083002875, 0.0881398261657783, 0.05957418041569846, 0.03429695624592049, 0.028137839598847286, 0.04600364967648472, 0.02467900055593678, 0.058891180636627335, 0.06487552023359708, 0.10124081067208733, 0.041716885952545066, 0.02146071574783751, 0.0368466669294451, 0.022556047687040906, 0.026886697359649197, 0.026084412820637226, 0.059646267976079664, 0.06556964798697404, 0.0661507114501936, 0.0867775653355888, 0.035892687405326536, 0.05249575059860945, 0.10590965407235281, 0.04385140784350889, 0.22304752921419485, 0.12356487741427762, 0.11507374447371278, 0.23451361751982144, 24.98455830982753, 102.6788945879255, 80.37770625523159, 67.32969106946672, 96.26210812159947, 62.56549194880894, 44.56583956309727, 38.29446152278355, 1.1417960630995887, 0.7683667040296963, 0.03733506965051804, 0.22103584930300713, 0.2170528487435409, 0.14637468702026776, 3.840796555791582, 27.840853316443308, 40.21284178325108, 53.576145376477925, 65.30131040300641, 57.10242216927664, 45.77371440614973, 48.48342153004238, 53.48628085000174, 38.6017872946603, 34.43201003755842, 32.52262422016689, 25.958758286067418, 21.837427343641007, 23.08384731837681, 30.138916151864187, 35.31631074632917, 22.916939428874425, 10.172907931464058, 3.820278091090066, 6.258993744850159, 12.815549305507115, 15.608290876661028, 19.725643975394114, 20.23076237951006, 11.814550995826721, 12.521222744669233, 5.373146627630506, 5.826072769505637, 4.103453661714282, 5.516300363200052, 0.35733306993331226, 0.19019967610282557, 0.12066737003624439, 0.07784796306597334, 0.35269246037517277, 0.32824069101895603, 0.16700394291962894, 0.7943965015666825, 1.2618412843772342, 2.3771552656378065, 3.1907619621072496, 4.094792297908238, 3.7391956533704485, 2.1149778025490895, 1.2234040669032504, 8.239093116351537, 7.265741688864572, 4.805083623954228, 1.4254964398486274, 1.7703185996838977, 1.5086398869752884, 2.7064614466258456, 0.5771882140210697, 0.09382480289787054, 0.09986457880586386, 0.5335366992013795, 0.026443279813975096, 0.36074433688606533, 0.12139311752149037, 0.20584164533231938, 0.06810226637337889, 0.23360845180494444, 0.786134387765612, 0.23769122415355273, 4.286249475819724, 4.54499648298536, 6.716573442731585, 15.423289878027779, 16.768468073436193, 7.842586347034999, 5.177317295755659, 5.121992698737553, 11.655215774263654, 8.697027172361102, 26.00742868014744, 43.15299980981009, 44.743487630571636, 36.367031233651296, 31.67218903132847, 30.07993984222412, 33.18586104256766, 27.460701738085064, 24.73362238066537, 32.60349777766636, 42.91630942480904, 46.974432604653494, 52.83939661298479, 49.10352740968977, 38.778775283268516, 36.15955107552664, 23.69214126041957, 5.490782235349927, 0.5799484944769314, 0.15903627260455064, 0.1322754214384726, 0.39950282712067875, 0.37512290105223656, 32.78363330023629, 24.856838260378154, 21.59023823056902, 57.564807415008545, 73.99028982434953, 32.601538385663716, 41.70256335394723, 57.47236163275582, 2.947153125490461, 0.6170075801866395, 0.013261413933443171, 0.1606686514403139, 0.03408062910395009, 0.1680604490850653, 0.08653220028749534, 0.09017537693892207, 0.01621936690727515, 0.09003548337412731, 0.059449133197111745, 0.03972504301262753, 0.02870566484385303, 0.050712689491254945, 0.1080164849492056, 0.0218575518644814, 0.03450478473678231, 0.010548712353089025, 0.09589880625052111, 0.016370420676789114, 0.04063747923022934, 0.1282840341861759, 0.07476424532277243, 0.04151488268481834, 0.026208961315985237, 0.1006188044058425, 0.00815817411057651, 0.11219522929085152, 0.06438213706548725, 0.052693356959415336, 0.04224879973168884, 0.0018229663879277983, 0.028164935198479464, 0.02701839422141867, 0.0782137205824256, 0.056448356181915314, 0.01712199829385749, 0.06238991075328418, 0.06567728399698224, 0.024181413863386427, 0.05898308141955307, 0.06137854073728834, 0.04085780294345958, 0.06776065791824035, 0.029934634254979234, 0.0009159353378761027, 0.044908005611172745, 0.022939279176560894, 0.024918386014178395, 0.021521315710352998, 0.08324730369661536, 0.030858734489551613, 0.13522825656192644, 0.03376457427761384, 0.04215907704617296, 0.3907842221004622, 66.59926864079067, 116.56256267002651, 81.2119973046439, 85.5382445199149, 98.24979318891252, 65.56511960710797, 62.801869664873394, 28.32050483567374, 1.3526699819735117, 0.770285383931228, 0.11841163464954921, 0.30505031826240675, 0.1151210247938122, 0.16866520020578588, 4.4643040129116605, 19.079348598207744, 34.87815734318325, 56.31092854908535, 72.97538730076381, 68.76022788456508, 60.38391739981515, 59.867826053074424, 60.35567992074149, 47.93502453395298, 43.70892865317208, 43.58736297062465, 33.67659841264997, 31.463812555585587, 32.38824258531843, 39.037515776497976, 42.9492404120309, 35.167608874184744, 17.974286249705724, 17.05382364136832, 16.97787114552089, 20.053800446646555, 19.61406285422189, 24.18876028060913, 19.578727790287562, 17.63891407421657, 17.838860648018972, 13.110583714076451, 11.713059527533394, 9.589822922434125, 1.5949612664324897, 0.15426515362092427, 0.16845716136906827, 0.10885143586035285, 0.04947956405313952, 0.666675040764468, 1.1636347940989902, 0.10730552952736616, 1.3009506314992905, 1.894086969750268, 1.8502364541803087, 4.01818276303155, 3.2461579952921187, 4.499989092350006, 2.276505615030016, 0.38286995249135153, 8.863154258046832, 5.704487979412079, 2.636232529367719, 3.1146939524582455, 4.7197619165693006, 5.0623007246426175, 1.9308157988956995, 0.6344914191535541, 0.2666891509933131, 0.1559025129037244, 0.508687606879643, 0.06341990655554192, 0.3017078547605446, 0.09418492178831782, 0.16912646831146308, 0.3377580946045262, 0.21712195074984006, 1.3626964496714729, 1.0929893106222153, 0.6271035298705101, 5.535708853176661, 8.262989708355494, 14.4746219260352, 22.56669463430132, 21.383399043764385, 20.264940568378993, 17.17188048362732, 24.21854373386928, 21.0425568989345, 33.965556621551514, 51.19140897478376, 52.079604148864746, 46.378322328839985, 45.37361281258719, 40.10309498650687, 46.992140088762554, 39.672848633357454, 37.176364353724885, 40.557663508823936, 52.55886656897408, 59.09656211308071, 58.96977138519287, 51.32930639811924, 37.3726544380188, 27.107851369040354, 19.130876438958303, 5.346068629196711, 0.8074350133538246, 0.11743107012340001, 0.20427869419966424, 0.08109570986458234, 1.1320052913257053, 23.085928303854807, 43.74154002325875, 28.94915352548872, 53.73604079655239, 81.81432274409703, 61.6054801940918, 46.4939090864999, 77.6931655066354, 11.663181015423365, 0.35366393253207207, 0.21439611273152487, 0.10257167568696396, 0.05474841561434524, 0.1112600519720997, 0.060452625421541076, 0.014468741470149584, 0.04463495294164334, 0.05819982809147664, 0.050363606972885985, 0.03788871690630913, 0.026667781606582657, 0.04779491427221468, 0.04467169222022806, 0.04823736999449985, 0.0243410985983376, 0.008315658695729715, 0.023887440262894546, 0.09064403429095234, 0.01530786876433662, 0.05774996615946293, 0.1523668433406523, 0.08760717617613928, 0.010573484818451107, 0.10191243141889572, 0.14752462745777198, 0.21262600485767635, 0.1538507722850357, 0.18174818317805017, 0.10084837315870182, 0.1127617856753724, 0.12565329963607447, 0.09102316573262215, 0.14006266929209232, 0.2357656503362315, 0.09533547290733882, 0.22094180434942245, 0.11807347993765559, 0.1425506536449705, 0.10185743615563427, 0.2408306428364345, 0.12476150106106486, 0.1493094459708248, 0.22693028301000595, 0.16969976254871913, 0.22358650315020764, 0.16256560465054853, 0.1079427349780287, 0.11448021632220064, 0.1382228351597275, 0.1547756562275546, 0.3445211074181965, 0.2254387137613126, 0.25846606652651516, 0.18808195473892347, 51.351825509752544, 138.55605697631836, 102.2843828201294, 103.19881439208984, 117.05084037780762, 93.29387242453438, 66.63825498308454, 66.22635187421525, 1.8544231780937739, 2.1136628559657504, 0.1653687142367874, 1.168398978454726, 1.0998056020055498, 0.17639793455600739, 6.518483775002616, 32.24579061780657, 48.72474636350359, 58.940463883536204, 71.56614671434674, 69.8561464037214, 64.60217571258545, 63.840514183044434, 69.96852656773159, 58.64729159218924, 52.442067350660054, 50.260034220559255, 37.61902018955776, 34.59048455102103, 35.72939852305821, 45.946439674922395, 52.99556085041591, 43.517578738076345, 24.096100841249736, 18.60564821107047, 17.812141350337438, 23.861791951315745, 21.920123066220963, 29.101810659681046, 24.957277945109777, 18.447059052331106, 19.948710680007935, 11.196664197104317, 11.434845839227949, 11.011941126414708, 7.59025730405535, 0.39887203382594244, 0.49114639099155155, 0.16062584945133754, 0.1628626129989113, 1.022225490638188, 1.2784138236727034, 0.3485545909830502, 1.7212753913232257, 1.6799872411148888, 3.525162692580904, 7.312206029891968, 8.49958802972521, 6.487450948783329, 2.7452530222279683, 2.3522444537707736, 28.0025691645486, 15.50137025969369, 11.047386493001666, 11.29130300453731, 11.24207067489624, 9.127586194447108, 4.0885502099990845, 1.447975490774427, 0.5711336731910706, 0.6096384727529117, 0.7673510185309819, 0.2249228778694357, 0.5505213535257748, 0.2142504991165229, 0.8403690404125622, 0.3323915611420359, 0.2996284163423947, 2.571986662490027, 1.506418309041432, 7.317812357630048, 9.144632731165204, 14.737542629241943, 23.628278630120413, 25.604872635432653, 16.693413632256643, 13.16063506262643, 15.317939553941999, 25.085864782333374, 19.27931080545698, 38.335240500313894, 57.56619358062744, 58.35875374930245, 50.02168321609497, 44.59643248149327, 40.581030300685335, 43.725837094443186, 39.829509666987825, 38.90572234562465, 42.89461367470877, 58.553629875183105, 61.1898250579834, 66.29568794795445, 58.09512172426496, 53.22056436538696, 40.69829504830496, 26.701678786958965, 6.508402807371957, 0.8868803903460503, 0.8509632519313267, 0.2083632443100214, 0.5845074355602264, 1.4866157259259904, 54.23735679898943, 40.7945727620806, 36.488235609872, 79.50599915640694, 92.24507658822196, 60.070803778512136, 60.756611824035645, 89.95974458966936, 6.625400483608246, 0.7157349682279995, 0.2705591076186725, 0.34798893705010414, 0.12168173917702266, 0.32917009400469915, 0.1592658210013594, 0.09410250013960259, 0.1446643445108618, 0.11773517594805785, 0.22289156115480832, 0.22432905116251536, 0.17824933092508996, 0.12946910916694573, 0.17677396509264195, 0.1336370376603944, 0.2125595219965492, 0.18013036570378713, 0.17887983923511847, 0.16161750123969146, 0.3308155685663223, 0.2213461162256343, 0.2747904248535633, 0.14689177141657897, 0.12298156800014631, 0.22157445683010987], [0.05444776353293231, 0.0245222555739539, 0.022008330827312808, 0.08632625133863517, 0.03069173005808677, 0.04341926246083208, 0.04463952287499394, 0.04122608461018119, 0.01243669617854591, 0.04460551809253437, 0.015430210324536477, 0.015231664192729762, 0.05174617296350854, 0.05770192588014262, 0.11102078016847372, 0.020023904275149107, 0.016311732486688664, 0.008222382183053663, 0.044472209710095606, 0.05889081422771726, 0.06378246817205634, 0.03239681731377329, 0.023554388134341155, 0.0250836279509323, 0.03842079353385738, 0.019938419040824686, 0.11045076325535774, 0.11652712577155658, 0.03778253296124084, 0.017392192634620836, 0.802689719413008, 48.23240048544747, 101.99811008998326, 66.64714867728097, 81.97839055742536, 96.70944009508405, 51.43660395486014, 47.139893531799316, 49.26981864656721, 4.43586460181645, 1.3008289294583457, 0.5215783608811242, 0.9076386221817562, 0.2706711473209517, 0.17576430498489312, 8.373357500348773, 29.954781941005162, 40.55461324964251, 52.82029601505825, 55.59648697716849, 53.76535177230835, 48.219970158168245, 46.63643748419625, 51.42129012516567, 35.76648800713675, 26.74086662701198, 23.953643662588938, 29.120379720415386, 26.070452315466746, 34.963022640773225, 36.053083828517366, 28.692200456346782, 16.276328904288157, 13.27390285900661, 5.639791131019592, 16.96071604319981, 14.296569994517736, 20.001115730830602, 24.463917630059377, 15.302559716360909, 10.106248651232038, 6.247397635664258, 4.801887018339975, 2.9966069289616177, 3.2914205150944844, 0.3804519793816975, 0.1765992966081415, 0.2726066820323467, 0.21162914192037924, 0.4509761136557375, 0.20109898410737514, 0.10734928146536861, 0.12785199736910208, 2.5177047295229773, 3.3397554414612904, 4.2219825472150525, 1.8597014205796378, 2.20891940167972, 0.7644785898072379, 0.10382930641727788, 0.5189614413040025, 1.2032927232129234, 0.6450683144586427, 0.4703450043286596, 0.8675277030893734, 0.5071952641010284, 0.3746898871447359, 0.37330288014241625, 0.0354614614376, 0.05959898087063006, 0.08816043327429465, 0.028419278961207186, 0.15846700886530535, 0.0362394086218306, 0.11577148203338895, 0.2123335019818374, 0.5806110703519413, 1.3666677794286182, 0.6310635688049453, 0.7252947123987334, 1.982829145022801, 4.307949568544116, 5.113685693059649, 5.374033825738089, 4.350905069283076, 1.8414378634520938, 17.244569063186646, 7.379275253840855, 10.204431039946419, 32.00791903904506, 37.558355467660085, 45.38400731767927, 47.61967011860439, 47.55989476612636, 38.44517142432076, 38.85052238191877, 38.65032046181815, 36.985316685267854, 44.01893295560564, 52.06958832059588, 49.40815033231463, 47.587037903921946, 40.09575421469552, 36.889438492911204, 19.68846242768424, 4.7236915571349005, 0.4678073919245175, 0.04881721888003605, 0.13497457945985453, 0.6634399486439568, 3.6644603950636725, 45.15218761989048, 26.61142689841134, 20.850929055895122, 47.93075486591884, 84.1739170891898, 44.09325783593314, 26.747314555304392, 65.58169106074742, 19.790632213865006, 0.5643785585250173, 0.17327043094805308, 0.13534858796213353, 0.07864469209952013, 0.0704672798248274, 0.025149143899657896, 0.19404866599610873, 0.06387056237352745, 0.10855076342288937, 0.025194212195596526, 0.0390547454091055, 0.018886443792975376, 0.04951765361641135, 0.01981309531921787, 0.05492050227309976, 0.02088679386568921, 0.02462275678824101, 0.04897519201040268, 0.06888685641544205, 0.06443674556378808, 0.0790257030831916, 0.1487630352910076, 0.03916275461337396, 0.055616526531853845, 0.017290229177368537, 0.01926620627221252, 0.04520883071901543, 0.04566979009125914, 0.02537742173964424, 0.019326841857816492, 0.044912321093891344, 0.045050260477832386, 0.016014546022883484, 0.04385455285332032, 0.011698964916701828, 0.04410402982362679, 0.02780781882548971, 0.08477175475231238, 0.010775340504811277, 0.06794776394963264, 0.07511120741920811, 0.10738480277359486, 0.04109257605991193, 0.02277405759585755, 0.04811589526278632, 0.041378235910087824, 0.03360410413837858, 0.04555581656417676, 0.018307437987199852, 0.026372997156743492, 0.0757628045976162, 0.0325772940580334, 0.13045758541141236, 0.055725139632288895, 0.07332746099148478, 0.03535539962883506, 5.089535057544708, 96.26046139853341, 104.19236510140556, 77.6873915536063, 100.2184749330793, 87.17875589643205, 58.670713969639365, 64.41706875392369, 33.06844343457903, 2.1513249150344302, 0.15408374049833842, 0.6962451626147542, 0.22187333793512412, 0.4896122504557882, 0.2650094511253493, 7.67358010155814, 18.430610929216655, 33.79256384713309, 57.920086179460796, 69.8130189350673, 66.87888499668666, 60.868894713265554, 57.304892676217214, 59.74897016797747, 41.6952086857387, 33.58005666732788, 31.63586732319423, 36.545530455453054, 37.11548771177019, 45.45091152191162, 46.63308150427682, 39.21078300476074, 25.909184626170568, 17.554851293563843, 13.282987628664289, 22.53040419306074, 19.74596745627267, 33.026351247514995, 31.734667233058385, 16.85494361604963, 16.914844036102295, 14.637978417532784, 8.927370377949305, 14.771852833884102, 5.197900465556553, 0.9737153393881661, 0.5684809269649642, 0.10958664890910898, 0.3200111197573798, 0.7709830264960016, 0.7114643231034279, 0.3620666116476059, 0.24957177521927015, 2.7403426000050137, 4.417579982961927, 5.393160045146942, 2.1455507448741367, 1.9213886133262088, 0.4884472329701696, 0.08547978568822145, 0.9772192942244666, 0.5655924305319786, 1.4210026924099242, 0.4649937514747892, 0.3694824294320175, 0.8017943246023995, 0.7090642090354646, 0.45442934121404377, 0.3421364368072578, 0.0291720151768199, 0.10353014711290598, 0.06558890481080328, 0.20312260623489106, 0.09410638814525944, 0.10147307320897068, 0.21902890556624957, 0.7331665871398789, 3.978905899184091, 4.956287281853812, 1.2858141980000903, 3.2167673323835646, 6.012865969112941, 10.746816975729805, 11.80985140800476, 17.458776814596995, 14.954673835209437, 25.065685476575577, 22.73855311529977, 21.913996492113384, 47.861648082733154, 54.74160146713257, 68.76393822261265, 63.03778185163225, 58.400964055742534, 54.333530289786204, 51.656563077654155, 49.71035875592913, 45.876526900700156, 53.86274814605713, 61.648329734802246, 57.43904849461147, 53.15571682793753, 37.03847735268729, 27.057101726531982, 17.75412389210292, 5.145002092633929, 1.2126550951174326, 0.17593909560569695, 0.38409058270709856, 0.7019331316862787, 1.991271857704435, 38.30035706928798, 52.621914522988455, 27.75472170966012, 45.987764086042134, 78.96554047720772, 67.75530992235456, 35.75901869365147, 79.1873061316354, 39.33259882245745, 1.1000036256653922, 0.237278620579413, 0.06160341402781861, 0.038455660055790625, 0.036352350775684626, 0.06129887394074883, 0.15106231905519962, 0.07068338644291673, 0.04407046948160444, 0.04628089569242937, 0.032845556270331144, 0.04227815315659557, 0.03047458188874381, 0.05261080978172166, 0.04920370224863291, 0.0725463382633669, 0.027346710175541893, 0.02640686114318669, 0.08607962421540703, 0.003064108293204169, 0.05691628750147564, 0.0736280587900962, 0.045815376564860344, 0.03650119421737535, 0.08040443874363389, 0.06924557073840074, 0.2082450163683721, 0.2069984661149127, 0.0795196019379156, 0.12202148166085992, 0.1257041354796716, 0.14663369740758622, 0.1697592157870531, 0.1042169670441321, 0.14451085988964352, 0.12393395975232124, 0.0935409716995699, 0.1806376791958298, 0.12268666311034135, 0.16244680673948356, 0.23814616831285612, 0.1168013217725924, 0.17381445318460464, 0.08568397723138332, 0.10708769943032946, 0.10902911704033613, 0.20929439791611262, 0.13033569338066237, 0.16018957857574734, 0.12413924373686314, 0.1290018835238048, 0.11477749608457088, 0.20634638039129122, 0.10363492649048567, 0.2631173426551478, 0.11949250022215502, 1.9353796797139304, 92.51422895703996, 127.76346179417202, 91.96390383584159, 111.56368814195905, 116.99918746948242, 77.80659484863281, 66.63752542223249, 72.98993682861328, 7.767881052834647, 2.407750572477068, 0.960082973752703, 1.9955769181251526, 0.928820856979915, 0.27970366978219574, 12.362186295645577, 41.4508752822876, 49.95705802100045, 59.549209458487375, 62.83383137839181, 70.23331546783447, 65.68567780085972, 59.899537631443565, 65.69003432137626, 49.40076092311314, 42.17844200134277, 36.785938126700266, 39.78210210800171, 38.21758665357317, 50.668411118643625, 53.4312094279698, 43.92125865391323, 32.492288385118755, 25.337092535836355, 16.891216686793737, 31.088272844042095, 26.163573810032435, 30.14983524594988, 34.783022608075825, 22.47798350879124, 19.926789113453456, 12.15182524068015, 6.620965795857566, 13.711200765201024, 7.778180888720921, 1.8515116657529558, 0.76168242841959, 0.37019730678626467, 0.7807351489152227, 2.1613079564911977, 0.4581876652581351, 0.9652124813624791, 0.27470335523997036, 3.513000305209841, 5.438923052379063, 7.927354369844709, 5.515854809965406, 2.9248385514531816, 0.952000481741769, 0.24364569463900157, 0.8125694064157349, 5.075053708893912, 3.380218493086951, 4.651485877377646, 2.135127578462873, 2.4929363557270596, 1.473606852548463, 0.6152954463447843, 0.7482310416443008, 0.1630211187792676, 0.44322626665234566, 0.15169921916510376, 0.21692968106695584, 0.1670277187866824, 0.17801193866346562, 0.6422818696924618, 1.36018391592162, 4.089796543121338, 5.688698632376535, 2.3073512741497586, 1.4974991019283022, 5.373628658907754, 12.090542997632708, 7.465153251375471, 9.871495945113045, 12.876895819391523, 31.699391228812082, 22.245503732136317, 20.32344092641558, 48.32674312591553, 53.06893382753645, 66.12044743129185, 57.912891319819856, 53.25971051624843, 46.241564410073416, 47.00734969547817, 45.535776819501606, 47.45908335277012, 63.614412852696006, 64.54885523659843, 59.9075072152274, 61.880760874067036, 56.2887464250837, 44.4533725466047, 26.304050752094813, 7.09619174684797, 1.7225051139082228, 0.45198254393679754, 0.42071825585194994, 1.0939709608043944, 8.07553686414446, 70.74704442705426, 46.761348724365234, 35.56159257888794, 67.17883178165981, 97.28702299935478, 67.45275756290981, 40.59324523380825, 98.04580102648053, 33.305613245282856, 1.1911813616752625, 0.3237623598958765, 0.26287556705730303, 0.1783177408256701, 0.07992528445486512, 0.12474218995443412, 0.3194097477410521, 0.12229156573968274, 0.1370161013411624, 0.10996631639344351, 0.11952360426740986, 0.1774153842457703, 0.1899835762700864, 0.11452163409973894, 0.20114364528230258, 0.2623879446515015, 0.11562626196869782, 0.14786922825234278, 0.1368286492569106, 0.20653352034943445, 0.1549004116760833, 0.20595650774027618, 0.14713290919150623, 0.14223764544086798, 0.12274503069264547, 0.1617968516158206], [0.08360422668712479, 0.020933680635477816, 0.028129793869863664, 0.024274371464603713, 0.025337152382625, 0.08409854623356036, 0.05864447208919695, 0.06265992697860513, 0.03387461569426315, 0.04881494239504848, 0.04978222120553255, 0.0623448695987463, 0.05721792006599052, 0.111291135661304, 0.02470369583794049, 0.048120095394551754, 0.07074666661875588, 0.026284458514835154, 0.004933697246347687, 0.08737340729151453, 0.016302847070619464, 0.046045084417398484, 0.08626894227096013, 0.10275008968476738, 0.03672028299687164, 0.07588711899838277, 0.04966093307094915, 0.1811445312840598, 0.03714746828856213, 0.2677207684942654, 0.04890792204865387, 9.110070654324122, 93.21388476235526, 76.77216788700649, 57.46408632823399, 85.80433968135289, 88.64298452649797, 43.45596211297171, 43.94962120056152, 62.157292229788645, 7.783834985324314, 1.2950367374079568, 0.1113229114562273, 0.2914755738207272, 0.12160327338746615, 0.5176479603563036, 10.469203438077654, 28.781769684382848, 39.9890125138419, 34.884594849177766, 48.71616186414446, 61.234342166355674, 53.883495467049734, 52.99646411623274, 51.79655190876552, 44.76136187144688, 37.51080199650356, 39.23829787118094, 44.3311641556876, 49.99769803455898, 57.205582073756624, 61.33952399662563, 28.773563861846924, 18.440644127982004, 12.17186210836683, 14.560923763683864, 23.512735298701696, 17.62618671144758, 23.441587482179912, 24.27590458733695, 18.66606453486851, 8.8633314371109, 7.910036853381565, 2.2914385965892246, 3.182201564311981, 0.3382459884243352, 0.21247897988983563, 0.10906079105500664, 0.3060060484068734, 0.3562588675745896, 0.4236630978328841, 0.45444321046982494, 0.26399824395775795, 0.8584106894476073, 0.7925711880837167, 0.9031545370817184, 0.8474089226552418, 0.42022922209330965, 0.03370085305401257, 0.21678969929260866, 0.416205455149923, 0.10285639576613903, 0.07915575789021594, 0.06775085987257105, 0.13711774588695594, 0.4694594347051212, 0.27264145016670227, 0.07185426647109644, 0.01019203448335507, 0.02833745951232101, 0.0844117919249194, 0.08275811387492077, 0.03533281459073935, 0.06690258253365755, 0.15710771323314734, 0.2813359264816557, 1.275937442268644, 1.0334252268075943, 2.2492734534399847, 0.11799719903085913, 0.3653243939791407, 0.29398645194513456, 0.6224431885140282, 2.4674870584692274, 1.147538097841399, 12.89882607119424, 17.25571744782584, 3.1140542839254652, 7.680440579141889, 22.87259428841727, 19.94558572769165, 21.689536673682078, 31.777016503470286, 31.688791751861572, 26.518819570541382, 34.3233436856951, 33.400480474744526, 34.71196685518537, 39.997909682137625, 40.37311588014875, 41.51634815761021, 38.20897783551897, 39.85013192040579, 20.498975004468644, 6.235889247485569, 0.6809656396508217, 0.11172592054520335, 0.3272179758974484, 0.5887712410518101, 8.19636082649231, 37.43291616439819, 19.349603993552073, 23.468120915549143, 51.20734119415283, 87.70301832471574, 52.94341114589146, 33.57898664474487, 64.29864365713937, 28.935479470661708, 0.4111066987471921, 0.20405635184475354, 0.06592679489403963, 0.04036200758335846, 0.14174455404281616, 0.04695778526365757, 0.14733633399009705, 0.036124339260693104, 0.017065561143681407, 0.03591536743832486, 0.061652078559356074, 0.025074462639167905, 0.03310796951076814, 0.0410353110970131, 0.09281360930097954, 0.025466090999543667, 0.006914650547384683, 0.03452956483566335, 0.043316942772694995, 0.042372696833418946, 0.014887290707390224, 0.06263109602566276, 0.029940954808677946, 0.04724314655842526, 0.04848286396424685, 0.03363015649041959, 0.036873614947710714, 0.07062332930841617, 0.08724617519016777, 0.02711099898442626, 0.01710864981370313, 0.032060830521264246, 0.025351111544296145, 0.06642644772572176, 0.011505667253264358, 0.039687479313995154, 0.042394508341593404, 0.03788239974528551, 0.041868212832404036, 0.08125574234873056, 0.056589993581707985, 0.04973765502550772, 0.09286264024142708, 0.07448791193642787, 0.008695850348366159, 0.10550449402736765, 0.0809169498139194, 0.038874299198921235, 0.05984104823853288, 0.05385651186640773, 0.051385409464793544, 0.056789869642151256, 0.04784919707370656, 0.027005325636959503, 0.12735801030482563, 0.052739802681441815, 0.0718318544594305, 0.33816136153680937, 32.27271836144583, 121.57282529558454, 80.36552606310163, 83.42155224936349, 102.41197259085519, 76.58687332698277, 51.971358163016184, 65.19305052076066, 42.2273017338344, 3.696455546787807, 0.2162921702755349, 0.2014370709657669, 1.110024339386395, 0.08476016537419387, 0.5503023767045566, 8.83108311040061, 20.6773613180433, 28.574713366372244, 39.97235073362078, 64.00280325753349, 74.80452837262834, 65.61364582606724, 67.12333651951381, 63.28710406167166, 55.12929705211094, 47.23870733806065, 52.56665202549526, 54.77680451529366, 62.48166193280901, 68.57112571171352, 72.31047248840332, 39.99238586425781, 23.79427456855774, 16.88231430734907, 21.96602460316249, 24.845847947256907, 22.55580333300999, 25.35798055785043, 25.17337039538792, 21.496652943747385, 15.000660487583705, 10.936758143561226, 9.453194413866315, 3.5191692199025835, 0.8992238108600888, 0.2733166196516582, 0.27837599388190676, 0.4518582634627819, 0.9937342937503542, 0.1291670525180442, 0.2744953435446535, 0.2543754503130913, 0.25466097784893854, 0.41844505497387474, 0.3061904470835413, 0.06926233733871154, 0.19360883959702083, 0.1335128793226821, 0.24799665116838046, 0.6872958285467965, 0.44977657230837004, 0.06317737099847623, 0.10829170553811959, 0.18047929555177689, 0.5618729729737554, 0.21070400013455323, 0.07180433986442429, 0.010944597672538033, 0.06471855472773314, 0.06395680417439767, 0.09264800604432821, 0.10566145274788141, 0.013191829319112003, 0.06833015235939197, 0.5694217021976198, 1.8268668396132333, 3.661505239350455, 4.772104433604649, 0.5028389607157026, 1.202573150396347, 2.135167964867183, 6.577097909791129, 14.616473742893763, 16.197072540010723, 26.89716809136527, 34.86582081658499, 19.816067831856863, 19.543010575430735, 35.598358971732004, 34.730421270642964, 35.89727742331368, 47.397654329027446, 44.29663160869053, 36.660457134246826, 42.99869074140276, 45.032550062452046, 45.22682169505528, 51.272654260907856, 45.23662560326712, 41.045222078050884, 30.098595755440847, 27.23906636238098, 14.642995016915457, 5.573061500276838, 0.28723418712615967, 0.2698555753699371, 0.542006824697767, 1.3567706133638109, 5.446741947105952, 46.30187129974365, 48.339079652513774, 28.73073516573225, 43.008015223911826, 74.53799547467912, 77.93859672546387, 45.39064979553223, 60.099513735089985, 57.48146029881069, 2.3458527624607086, 0.18645826115139894, 0.07968774291553668, 0.07624700040157352, 0.024892348929175308, 0.09593812735485178, 0.12418440702770438, 0.12023529250706945, 0.04998240939208439, 0.08851097125027861, 0.011277995005782162, 0.033389907596366744, 0.022000305454379747, 0.0708112156550799, 0.031113609205931425, 0.07057218133871045, 0.057322210898356776, 0.05091033656416195, 0.06850465121013777, 0.0991640728233116, 0.04543560051492282, 0.06326781293111187, 0.039391380202557356, 0.025988800451159477, 0.06130741669663361, 0.05080372514203191, 0.0952389920130372, 0.19715719776494162, 0.1745689841253417, 0.17271389652575764, 0.1079180363033499, 0.12573150758232388, 0.16667281783052854, 0.2491121898804392, 0.10602329511727605, 0.18261335603892803, 0.2309888723705496, 0.1703226984079395, 0.0820799588358828, 0.06549462236996208, 0.23242229116814478, 0.1892635149082967, 0.27942414049591335, 0.14640560107571737, 0.11903835673417364, 0.08340576197952032, 0.22823062751974377, 0.11951918021908828, 0.1841921034668173, 0.14771125172930105, 0.1941083227949483, 0.0839804947110159, 0.15169305806713446, 0.23594744343842777, 0.3527518729014056, 0.14306007059557097, 0.3780782738966601, 0.4245285013956683, 24.14280663217817, 130.55248260498047, 101.58172539302281, 88.27877385275704, 113.11654799325126, 109.73731245313371, 64.22863360813686, 61.626032965523855, 82.51588930402482, 14.462511215891157, 2.2013124270098547, 0.18152037183088915, 1.3553713113069534, 0.26569349584834917, 0.8525790880833353, 12.694729685783386, 42.85407788412911, 54.37125900813511, 43.695848669324604, 57.771811621529714, 68.94163840157645, 64.35160282679966, 66.94051551818848, 64.37932613917759, 60.52459757668631, 51.2288111277989, 54.972955635615754, 54.10860667909895, 63.287750244140625, 71.34224101475307, 78.54186711992536, 44.48124177115304, 30.303932394300187, 26.089856897081646, 34.87630912235805, 37.079971994672505, 25.85199052946908, 24.078330823353358, 28.671779700687953, 22.40839729990278, 14.429156388555255, 11.32663459437234, 10.981242247990199, 6.241298854351044, 2.226426907948085, 0.4570831188133785, 0.36130980082920616, 0.7311094860945428, 2.0206279967512404, 0.5509596871478217, 1.95110627583095, 0.8651824689337185, 1.549075145806585, 1.2569051321063722, 2.5133484261376515, 1.076980009675026, 0.5594629794359207, 0.21979030328137533, 0.7098422444292477, 0.5868520183222634, 0.557437253849847, 0.15281732273953302, 0.17897365348679678, 0.332342408065285, 0.5591228434017727, 0.8620066536324364, 0.3007970707757132, 0.1770372231091772, 0.14284866622516088, 0.16835585609078407, 0.21977829321154527, 0.1739993675478867, 0.098536835052073, 0.2678847839789731, 0.7436843141913414, 2.5053675515311102, 6.296427599021366, 5.377712028367179, 0.21415675271834644, 0.42921202150838716, 0.49829163615192684, 3.611214177949088, 9.678082415035792, 13.157807145799909, 32.271273136138916, 37.59822423117501, 21.122723477227346, 24.200725078582764, 41.432820388248985, 35.73510994229998, 32.16682086672102, 42.50811317988804, 43.564201150621685, 36.99003798621041, 44.64637960706438, 44.15956449508667, 49.40568372181484, 51.88639906474522, 48.87857600620815, 56.02568415233067, 54.13922739028931, 49.00103453227452, 24.529173374176025, 8.788555792399816, 0.9450649853263582, 0.34324529873473303, 0.9695046224764415, 1.2546839884349277, 17.61692476272583, 56.712329455784385, 32.58618286677769, 35.390969140189036, 66.49064745221818, 102.2782267161778, 77.22735132489885, 54.64099155153547, 91.34181771959577, 57.491403170994346, 0.7161319926381111, 0.3362464542899813, 0.10825723595917225, 0.09341274893709592, 0.23307338623063906, 0.23058525260005677, 0.3441881367138454, 0.2434483766555786, 0.25309643894433975, 0.16079210410160677, 0.14348875544965267, 0.1763640756585768, 0.18361595938248293, 0.10642109984265906, 0.1330939789435693, 0.16685961852116243, 0.13009436561592988, 0.15043339851711476, 0.2495052787874426, 0.12678600528410502, 0.07970728472407375, 0.14657869535897458, 0.15819996462336608, 0.14770591844405445, 0.12160252699894564, 0.10831445003194468, 0.22547885589301586], [0.0444554465024599, 0.11848668062261172, 0.06301771849393845, 0.03417712017627699, 0.025201701525864855, 0.04217439836689404, 0.0049653233394825035, 0.036035183151917796, 0.07638768785234008, 0.060170626267790794, 0.0328516020173473, 0.0803390143971358, 0.06217605008610657, 0.011053245547892792, 0.0774374765210918, 0.04252064121620996, 0.005546976704083915, 0.060629295584346564, 0.0590667040752513, 0.07206325525684015, 0.04470793616824916, 0.05692608893982001, 0.0632383373699018, 0.07504246503646884, 0.18417204597166606, 0.05402290900903089, 0.11239763628691435, 0.053632174618542194, 0.10924820242715733, 0.011200246767007878, 0.04986832390672394, 0.05399951312158789, 43.83544840131487, 103.56459535871232, 63.41206741333008, 52.29665545054844, 100.39662674495152, 79.09003829956055, 44.70693663188389, 33.44887120383126, 59.99193477630615, 16.116294520241873, 0.8968162600483213, 0.2491656041571072, 0.6450444300259862, 0.11427320885871138, 0.03591896367392369, 9.722182631492615, 25.817836659295217, 35.16473231996809, 34.32302059446062, 32.70846421377999, 38.16932099206107, 44.85925851549421, 49.968616349356516, 45.65788098743984, 46.25504044124058, 50.51546737125942, 53.034939765930176, 54.97639151981899, 53.27489927836827, 55.935263769967214, 46.24380867821829, 24.167868784495763, 11.07882969720023, 17.278919219970703, 26.0391298362187, 24.374233756746563, 44.34676286152431, 36.4181352342878, 23.923740352903092, 14.335569364683968, 13.145717280251638, 13.893755129405431, 3.7196447253227234, 0.10218047989266259, 0.7425080058830125, 0.08831922403935875, 0.46458011652742115, 1.0846174912793296, 0.37355996349028175, 0.20527175734085695, 0.2930083301450525, 0.4510147901518004, 0.5468367455261094, 0.3390711412898132, 0.36420657538941925, 0.6159648618527821, 0.06107765795396907, 0.19078335192586693, 0.751919395157269, 0.27700035912649973, 0.5600031475935663, 0.22563744309757436, 0.015944582277110646, 0.04472897753917745, 0.0504170619616551, 0.13475774680929525, 0.13807389672313417, 0.12138635931270463, 0.04855810331978968, 0.010597582989638405, 0.0630547393645559, 0.03972492426899927, 0.1737214531749487, 0.09033014399132558, 0.6485854057329041, 2.2032142792429243, 1.7013322157519204, 2.3718461905206953, 0.10941738834870712, 0.5504572998200143, 9.622670531272888, 10.365710888590131, 9.85332293169839, 18.523324217115128, 15.072407586233956, 2.0736162619931355, 4.572273807866233, 3.20843557374818, 14.436116746493749, 21.774190051215037, 28.231689487184795, 31.06684112548828, 28.69713020324707, 34.32312829153878, 37.009388719286235, 38.98674528939383, 34.12783179964338, 37.660632950919016, 37.31719739096505, 30.458960601261683, 15.378854410988943, 2.9754173117024556, 0.6192735614521163, 0.26884645809020313, 0.9570086130074092, 0.3749430349894932, 7.871762701443263, 23.420624767030986, 15.491345746176583, 34.91460411889212, 56.118234157562256, 87.93112768445695, 58.30150754111153, 40.18510110037667, 60.730465752737864, 44.16988951819283, 1.0485536264521735, 0.08527299535593816, 0.09992696331547839, 0.03225307645542281, 0.054068720300814936, 0.06420079858175345, 0.03744578281683581, 0.02285374135577253, 0.07086849079600402, 0.039924413564481905, 0.01714247139170766, 0.040334893324013264, 0.08125181363097259, 0.057603945423449786, 0.014488671739984835, 0.025384161288716962, 0.06881814795945372, 0.0317300650557237, 0.0319061788198139, 0.051311520393937826, 0.0362170169662152, 0.02366565600303667, 0.030596646945923567, 0.1061104190136705, 0.08829493248569113, 0.042941197220768244, 0.02935930441266724, 0.026134039175563624, 0.037095899627144845, 0.03634144671793495, 0.0697515814432076, 0.03717251301610044, 0.02776570724589484, 0.050572490585701804, 0.03728274781523006, 0.07469504153622047, 0.03556993883103132, 0.03250084691015737, 0.06298480276018381, 0.023546279640868306, 0.09485197599445071, 0.07905874095324959, 0.035380474890449216, 0.06878750531801156, 0.03323316600705896, 0.024074251131553735, 0.047144999860652854, 0.061066197497504096, 0.036150717309543064, 0.0209900414504643, 0.03483980122421469, 0.0677571634628943, 0.03652063763833471, 0.04917965157489691, 0.04234458852027144, 0.08847091732812778, 0.06008268812937396, 0.05229986432407584, 0.23207469124879154, 0.7357590794563293, 80.76818111964634, 105.35313810620988, 73.08309827532086, 85.35942568097795, 104.14786883762905, 68.10465145111084, 48.1727363041469, 67.36173616136823, 52.86638341631208, 2.6939299362046376, 0.7942596546241215, 0.589670544224126, 0.7641370967030525, 0.2617270244019372, 0.8878921132002557, 10.18174169744764, 16.863839047295706, 18.983128207070486, 30.489393711090088, 47.42402621677944, 55.3292418888637, 59.65561417170933, 62.209521838596885, 58.98300770350865, 60.13622801644461, 63.13279846736363, 69.44220052446637, 69.81338718959263, 66.11253343309674, 71.5968438557216, 63.31325013296944, 37.159264836992534, 19.446873562676565, 24.954298904963903, 25.58335927554539, 21.906341314315796, 27.074107442583355, 30.251741000584193, 28.393226419176372, 22.252262592315674, 15.556554589952741, 22.514843702316284, 7.640740309442792, 1.6630020439624786, 0.5916685312986374, 0.216023538261652, 0.4839571767619678, 1.452939652970859, 0.49756831782204763, 0.18897202983498573, 0.19779597063149723, 0.3615542362843241, 0.26268375877823147, 0.38303136240158764, 0.4104289508291653, 0.2665316494447844, 0.5170636602810451, 0.10000234855605022, 0.9757213060344968, 0.5056403332522937, 0.4691238041434969, 0.15315543673932552, 0.14135819620319776, 0.09010598994791508, 0.0376129670600806, 0.26389586659414427, 0.22186845248298986, 0.11221197553511177, 0.12927949934133462, 0.050343831069767475, 0.052113474147128205, 0.11505251989832946, 0.1555153001099825, 0.12689391949347087, 0.9527596810034343, 3.3858610817364285, 7.57629576751164, 6.849878541060856, 1.3468428317989622, 5.766320867197854, 19.418825422014507, 21.69462275505066, 25.000900472913468, 42.46491622924805, 30.99693877356393, 19.198626586369105, 21.66468470437186, 26.34336018562317, 30.20652907235282, 33.62038401194981, 43.10696104594639, 44.60892881665911, 39.06019122259957, 46.24169989994594, 47.337062563214985, 45.84039626802717, 33.20839752469744, 27.010635648454937, 20.581665515899658, 18.9159426007952, 13.821164693151202, 2.183176325900214, 0.7634610586932727, 1.219966662781579, 1.4280135333538055, 2.691361274038042, 12.775299259594508, 44.08570861816406, 37.01463808332171, 26.52502257483346, 42.345678193228586, 75.57806437356132, 87.44221074240548, 52.11442157200405, 56.79648951121739, 74.68057250976562, 5.415640941687992, 0.03553251762475286, 0.02606456058232912, 0.09972679548497711, 0.04271011872749243, 0.025158258321295892, 0.03834069247490593, 0.047278274316340685, 0.11445014365017414, 0.099975960329175, 0.053355915871049674, 0.14554079462374958, 0.013400280365853437, 0.009476718625852039, 0.021154002652370503, 0.0817058417680008, 0.02082134916314057, 0.04842645056279642, 0.06663419479238135, 0.03306623621444617, 0.02604981092736125, 0.019646659160831144, 0.043161422546420775, 0.07798003990735326, 0.08727060923618929, 0.027004567374076163, 0.022615930098774176, 0.04269709764048457, 0.1346531981336219, 0.1528520637324878, 0.19585199494447025, 0.09120330320937292, 0.08626323579145329, 0.1318448773984398, 0.13852601817676, 0.18165807372757367, 0.1371455793934209, 0.10461864620447159, 0.1504106947353908, 0.1495597032564027, 0.17069167218038014, 0.27722921541758944, 0.17846125098211424, 0.14056299387344293, 0.17961846531501838, 0.09972121114177362, 0.1630057974585465, 0.19202826012458118, 0.16689494305423327, 0.14730985755366938, 0.19233809278479644, 0.19114776594298227, 0.2931575264249529, 0.15390082102801117, 0.20391391377363885, 0.24083919237766946, 0.1473156251013279, 0.17440659712467874, 0.36601666254656656, 0.20286721922457218, 75.56955977848598, 133.89580290658134, 93.2943171092442, 81.33561270577567, 122.52642386300224, 99.12541907174247, 67.77202033996582, 55.552595206669395, 76.3807133265904, 27.44850591250828, 1.756971761584282, 0.9714564148868833, 1.7254985932792937, 0.23342671298554965, 1.2566971204110553, 14.046277642250061, 37.557170799800325, 48.66470697947911, 50.85887861251831, 51.304164341517854, 52.95797457013811, 54.523070199149, 55.70955153873989, 54.61039515904018, 60.24369580405099, 67.0020557131086, 68.32370035988944, 69.93136065346854, 65.31795133863176, 74.6083459854126, 57.98131717954363, 36.17475025994437, 21.572386571339198, 34.683104038238525, 39.704355239868164, 36.213354451315745, 53.7567012650626, 41.275579180036274, 30.345062255859375, 23.928965398243495, 20.42979179109846, 26.091034616742814, 16.35787991115025, 3.0446105131081174, 1.3713230724845613, 0.3141311795583793, 0.5117458456328937, 2.1965924288545335, 1.1470537866864885, 0.5641087187188012, 0.5272811491574559, 0.6372313978416579, 0.41475558866347584, 0.6627677104302815, 1.374672212771007, 2.171006338936942, 0.9519818084580558, 0.46008816042116707, 1.8778305734906877, 0.5031462556549481, 0.9060312541467803, 0.3290247789451054, 0.32806818027581486, 0.16428109045539582, 0.13325194189591066, 0.32497140073350494, 0.3229218449975763, 0.2570286308016096, 0.16620853702936852, 0.12902270097817692, 0.18378973220075878, 0.16361854172178678, 0.3765470374907766, 0.41803405274237904, 1.0848714262247086, 4.343146102769034, 8.04139428479331, 5.735592893191746, 0.29031093631471905, 1.7109056391886301, 15.729250328881399, 27.371005705424718, 27.791026047297887, 46.594977583204, 35.11603239604405, 18.70226638657706, 19.707523073468888, 23.402420486722672, 29.6942001751491, 31.491115501948766, 42.977523054395405, 42.46223075049264, 38.35683897563389, 44.40511383329119, 50.023847579956055, 48.58605337142944, 38.85598019191197, 48.31719977515084, 49.34225014277867, 40.37502316066197, 24.23292997905186, 5.50373671736036, 1.0124901958874293, 1.157711780497006, 3.51392810685294, 2.4699065514973233, 24.967229502541677, 39.14969444274902, 24.321123463766916, 47.683225291115896, 70.90549114772251, 100.3080233165196, 79.88274438040597, 64.90928609030587, 77.73724487849644, 81.09166840144566, 2.1987235716411044, 0.20382745484156267, 0.17572693127606595, 0.20077301588441643, 0.11550697551241942, 0.15428373190973485, 0.17897321922438486, 0.11973597215754644, 0.22588847391307354, 0.2181288424347128, 0.11787773615547589, 0.12135381677321025, 0.16505896300077438, 0.1020917614389743, 0.17394117638468742, 0.14564189634152822, 0.11881609580346517, 0.16944850103131362, 0.2263037780565875, 0.06741950408156429, 0.12979876862040587, 0.11527978841747556, 0.12909776052193983, 0.16874047688075475, 0.17401044123939105, 0.22003070823848248, 0.11998454667627811, 0.09588210750371218], [0.05487287590014083, 0.018925188142540197, 0.007455264417720693, 0.008063749177381396, 0.02361564797216228, 0.04740231051774962, 0.012000611051917076, 0.05491133526499782, 0.09894815619502749, 0.05703888860132013, 0.09942465062652316, 0.03571270599163004, 0.08771838806569576, 0.015622656426525541, 0.07456231330122266, 0.02351985070189195, 0.09986307924347264, 0.03248725585373385, 0.0206481072985168, 0.0329169686883688, 0.020295282659519995, 0.06266550453645842, 0.04586706736258098, 0.0907324609745826, 0.07753581660134451, 0.010019184472704572, 0.10081490781158209, 0.030807148864758865, 0.023129289337833012, 0.1154120077512094, 0.04253413388505578, 0.02176491147838533, 2.2428114116191864, 76.8942129952567, 92.24961376190186, 54.022268363407676, 55.83754083088466, 95.56678104400635, 67.49975517817906, 47.76101732254028, 29.65680844443185, 52.50613668986729, 25.31514491353716, 0.2355364683483328, 1.3334501790148872, 0.45547933344330105, 0.04172593082434364, 0.6233638791101319, 5.139893863882337, 21.97594836780003, 41.56680250167847, 44.952996662684846, 39.59510176522391, 31.008059365408762, 35.55194500514439, 38.71801676068987, 38.803969451359336, 38.392385959625244, 33.43219552721296, 34.985180446079795, 31.67233841759818, 32.767982482910156, 22.027695076806204, 17.236813136509486, 9.081179176058088, 9.17482612814222, 25.767589024135045, 45.41373865944998, 71.76059900011334, 81.11536870683942, 44.63022157124111, 17.57809475490025, 15.484804017203194, 14.450312784739904, 4.12093619789396, 0.5198770293167659, 0.5986318747912134, 0.27185576089790886, 0.7241666615009308, 0.8969277026397842, 0.824712794806276, 0.1222411777291979, 0.08854865029986415, 0.052995759661176374, 0.21019698519791874, 0.05538568891850965, 0.03688305676249521, 0.09382340511573212, 0.2466854229569435, 0.1882728130689689, 1.1525367838995797, 0.1200589005436216, 0.06282010195510727, 0.1257890337812049, 0.0567153461410531, 0.045936579882566414, 0.13601492292114667, 0.06133964711001941, 0.05848477887255805, 0.1023868088211332, 0.03725757077336311, 0.05743819967444454, 0.04129965137690306, 0.09205699525773525, 0.03783199137875012, 0.3747452013194561, 0.23283953592181206, 2.1164770935262953, 1.813193870442254, 2.43699597460883, 2.341274116720472, 5.8774807538305005, 17.981826782226562, 27.45419475010463, 14.633211953299385, 13.225648488317217, 6.887906466211591, 2.4152906707354953, 2.3144675322941373, 4.166654476097651, 11.885257601737976, 16.953173773629324, 24.51732495852879, 24.71435328892299, 27.40917042323521, 30.197746549333843, 22.760589327130997, 23.68656185695103, 26.942418234688894, 24.934842211859568, 16.637084586279734, 9.01381812776838, 3.053923921925681, 0.9684651068278721, 0.22572346776723862, 0.7296522642884935, 0.9176802890641349, 10.997875366892133, 14.35944858619145, 15.861061130251203, 44.434334482465474, 60.015218189784456, 91.04297569819859, 57.938043798719136, 36.560187680380686, 57.97452531542097, 68.75239031655448, 2.6503734162875583, 0.11434289440512657, 0.10231736754732472, 0.01323690015955695, 0.05430781229266098, 0.07570127504212515, 0.03066878200375608, 0.06161072863531964, 0.05273473063217742, 0.018624483474663327, 0.046919051092118025, 0.05665276146360806, 0.026204170858753578, 0.060001230000385215, 0.09971211877252374, 0.04702505522540637, 0.019649078138172626, 0.047918855478721004, 0.0980538809671998, 0.02744670588124011, 0.06214882047580821, 0.041485654788890054, 0.036459881612764936, 0.0660179289323943, 0.053970112199229855, 0.03620114603212901, 0.03520070042993341, 0.024367035599425435, 0.0774351627166782, 0.026217846732054437, 0.04930771827431662, 0.03475679264270833, 0.026891665932323252, 0.08282613701054028, 0.04237751443205135, 0.0226718193319227, 0.06174099378819976, 0.05594602992225971, 0.003864485936771546, 0.09466096838670117, 0.021521709260663817, 0.05208678397216967, 0.06253327841737441, 0.057706166724009175, 0.03831733051421387, 0.11078885689909969, 0.06781584317130701, 0.08123852112995726, 0.02716626735803272, 0.043167844880372286, 0.03408086998388171, 0.07545865127550704, 0.07649942899921111, 0.12391288445464202, 0.08109407459518739, 0.11178056975560528, 0.12289193352418286, 0.09298525830464703, 0.04671366532732334, 0.04126360759671245, 0.10403003743184464, 13.198157940592084, 113.51776477268764, 85.70329202924455, 68.86057376861572, 91.96484879084996, 102.07501970018659, 62.24122646876744, 44.0584716796875, 59.39725235530308, 62.33020509992327, 7.297813705035618, 0.5976274801152093, 0.5028025912387031, 0.36146374685423716, 0.1886529148157154, 0.2996538206934929, 5.5817172186715265, 22.273784637451172, 26.057061399732316, 25.245345047542028, 29.179338659558976, 34.22053119114467, 49.27444614682879, 51.194024971553254, 52.74681881495884, 54.537678786686485, 45.22856221880232, 49.016633238111226, 43.68342876434326, 40.652197224753245, 35.50869594301496, 35.35735028130667, 21.897489309310913, 21.970787593296595, 43.361553464617046, 52.45341375895909, 70.48663289206368, 73.53709357125419, 52.52591126305716, 24.890677724565776, 21.313038110733032, 22.122298274721416, 11.065647227423531, 0.6790168870772634, 0.41972648192729267, 0.30336771426456316, 0.8777449205517769, 1.1481336887393678, 0.29912830889225006, 0.2614360957273415, 0.03744913477982793, 0.013072044139594903, 0.0637670247150319, 0.02569954945439739, 0.09547356835433415, 0.08102493866213731, 0.1625279188156128, 0.25227997132710045, 1.0835964317832674, 0.43545617216399735, 0.08215101502303566, 0.23252816977245466, 0.036505808255502155, 0.008351331826166382, 0.1957104661102806, 0.08169295638799667, 0.07042634380715233, 0.05416746410940375, 0.019482981247295226, 0.03837584737422211, 0.09332225950700895, 0.09192202785717589, 0.10878177066998822, 0.22855103175554956, 0.27451469536338535, 1.7771139379058565, 5.198662161827087, 9.703616176332746, 7.899201137678964, 13.322705268859863, 33.712128026144846, 39.06760147639683, 35.72420127051217, 32.819697925022666, 25.176710741860525, 14.983105863843646, 15.62070904459272, 14.996924093791417, 19.58781429699489, 25.958914620535715, 36.102117265973774, 38.44518184661865, 40.75004523141043, 37.980948380061555, 26.50018102782113, 15.909771476473127, 12.572336299078804, 11.121185047285897, 10.714688505445208, 5.424667085920062, 3.382521386657442, 3.180303837571825, 4.408551233155387, 2.197664839880807, 7.381157347134181, 20.997874770845684, 33.25873374938965, 30.54756055559431, 28.733177457536968, 48.78514010565621, 85.57187380109514, 83.44895594460624, 53.452714102608816, 59.41571371895926, 86.50660800933838, 15.009908539908272, 0.27469515853694504, 0.11834725524697985, 0.05651423853955098, 0.08492778387985059, 0.08330442277448517, 0.012955970546629812, 0.06866033428481647, 0.09475303880338158, 0.023937502576570426, 0.039767217356711626, 0.10870441089251212, 0.05604395270347595, 0.0644241315977914, 0.06117350781070335, 0.10258816408791713, 0.011485680156121296, 0.05720572000635522, 0.05679485348186322, 0.046508941134171825, 0.024845200923404524, 0.048280402685382535, 0.027026258442284803, 0.08698856937033789, 0.020235530865777816, 0.05159478162282279, 0.05849381695900645, 0.0744988431355783, 0.05979828017630747, 0.1792467095490013, 0.10096096247434616, 0.1304725403232234, 0.20304414044533456, 0.09728584717959166, 0.15265420292104992, 0.11414560356310435, 0.19006338555897984, 0.1086919190628188, 0.15733319041984423, 0.22263339215091296, 0.17626411387962954, 0.1197073786918606, 0.07717632874846458, 0.24220065932188714, 0.08842791856399604, 0.2064115468944822, 0.09491269130791936, 0.14247395204646246, 0.14176092030746595, 0.16400770869638237, 0.21081126295030117, 0.24194107896515302, 0.12107571241046701, 0.2556451793227877, 0.1092396325298718, 0.24402719416788646, 0.1882424961243357, 0.15892185802970613, 0.15132677129336766, 0.10268950329295226, 0.1405537115143878, 5.34418089049203, 122.18333571297782, 114.24674197605678, 86.03349821908134, 78.68169266836983, 118.92261559622628, 82.58955410548619, 67.72172927856445, 47.43178040640694, 71.0911956514631, 42.91113649095808, 0.3388030928160463, 1.853828455720629, 1.0364595268453871, 0.15173067604856832, 0.7409846133419445, 10.87493828364781, 42.36512967518398, 64.78815119607108, 60.75776522500174, 52.00832257952009, 50.31037391935076, 52.42252206802368, 51.85392318453108, 50.99691847392491, 53.93873017174857, 46.33589662824358, 47.39645576477051, 41.903901304517476, 42.348221233912874, 33.34109074728829, 27.558221442358835, 18.6286814893995, 18.361031668526785, 42.72491782052176, 62.477326256888254, 80.74685014997209, 84.31150531768799, 46.55476140975952, 24.40408842904227, 20.228307928357804, 22.53684343610491, 13.429386172975812, 0.9200475620371955, 1.702317557164601, 1.3565386086702347, 2.391640088387898, 2.2088557822363715, 1.2452587570462907, 0.33534297134195057, 0.20514419275735105, 0.09724795099880014, 0.42657461017370224, 0.19418216097567761, 0.13752656323569162, 0.45827348636729376, 1.0849559988294328, 1.0539246925285883, 2.5998524129390717, 0.24927156418561935, 0.23692776369197027, 0.22548911534249783, 0.2106488895203386, 0.13863447521414074, 0.3373991224382605, 0.11960083512323243, 0.12269648829741137, 0.20474980106311186, 0.061460494196840694, 0.1287036266710077, 0.26147132526550976, 0.13912960221724852, 0.18988049323005335, 0.34532465572868076, 0.9206235025610242, 2.7695658547537665, 5.372604668140411, 8.20024834360395, 4.5074987922395975, 9.529498662267413, 27.045425278799875, 56.647718157087056, 50.65694659096854, 46.989920139312744, 27.517906257084437, 12.333216650145394, 20.11663474355425, 15.235355002539498, 25.408870901380265, 30.952209745134624, 33.58832849775042, 32.51895557131086, 40.153917585100444, 40.78898293631417, 34.08598279953003, 30.749961580548966, 35.832631383623394, 35.95503085000174, 29.127169847488403, 14.915201119014196, 3.8955066714968, 3.6633578027997697, 5.459001609257289, 3.8970083509172713, 10.521187254360743, 31.170921666281565, 26.937181030000957, 28.557110105242046, 57.69403696060181, 73.9398250579834, 108.3939129965646, 72.78037221091134, 59.47859491620745, 71.65487521035331, 101.74484130314418, 8.669586130550929, 0.38442911739860264, 0.23307846167257854, 0.21160508106861795, 0.37992953455873896, 0.17733984972749436, 0.13086268438824586, 0.1427902036479541, 0.1323292835482529, 0.12320319110793726, 0.12094290953661714, 0.1485113530818905, 0.16373858813728603, 0.21542534178921155, 0.1404925212264061, 0.17783504458410399, 0.11596813505249363, 0.11377709797982659, 0.12400550448468753, 0.12289931598518576, 0.1954435304339443, 0.2039375946457897, 0.13717316862727913, 0.20767117930310114, 0.19012874205197605, 0.10728921076016766, 0.08970697743019887, 0.1780564369899886, 0.22414769232273102], [0.05724866448768547, 0.04726077489820974, 0.03488456078671983, 0.019389136461541057, 0.041702497617474625, 0.025247886011909162, 0.04679428207288895, 0.018377776623570492, 0.04692909001771893, 0.05150363401376775, 0.055798190712396584, 0.036229308628078015, 0.04241768031248024, 0.03260328534192272, 0.04145498839872224, 0.021131246284182583, 0.11799023726156779, 0.0854188668142472, 0.09475634326892239, 0.028284477801727395, 0.06672530168933527, 0.05264124207730804, 0.04056330517466579, 0.062274763360619545, 0.0342212453085397, 0.06553559231438807, 0.17098458217723028, 0.04091392796752708, 0.07008329007242407, 0.10870491300842591, 0.1397427807429007, 0.14431656817240374, 0.1478491707571915, 5.252665298325675, 90.72734682900565, 89.42328807285854, 49.819348199026926, 70.04031535557338, 104.19608238765171, 76.25431864602226, 60.75315856933594, 31.768897533416748, 35.71320922034127, 36.627477509634836, 7.732170786176409, 0.9571713528462819, 0.7833027797085899, 0.4676615340369088, 1.0267378027950014, 4.380318096705845, 14.204792107854571, 27.08786834989275, 32.998558453151155, 39.04164300646101, 32.442063331604004, 33.155160427093506, 33.33961078098842, 33.05496392931257, 36.31890801021031, 30.56448289326259, 21.5853362764631, 13.801436151776995, 15.023558276040212, 8.92357405594417, 11.798617039408002, 13.007418598447527, 23.63642191886902, 50.841320514678955, 64.16935852595738, 42.28545468194144, 11.243966664586749, 11.398703915732247, 12.570089425359454, 9.883958407810756, 4.401687715734754, 0.44295743107795715, 0.5636605599096843, 0.5836075352770942, 0.9870111516543797, 0.9400111479418618, 0.31174813743148533, 0.02719359874858388, 0.035178393591195345, 0.07236957310565881, 0.07776548713445663, 0.0242971447961671, 0.08965787185089928, 0.027246580459177494, 0.025361257339162484, 0.12884031076516422, 0.9747054576873779, 0.5966627661670957, 0.03022968163713813, 0.07630437732275043, 0.07627942759011473, 0.05259732389822602, 0.04656595843178885, 0.08642423858067819, 0.07182972385947194, 0.12603956248079026, 0.029457535927316973, 0.03412223008594342, 0.05293557699769735, 0.12201959533350808, 0.013365524105860718, 0.11690411982791764, 1.114358929651124, 1.6806581765413284, 2.6812618502548764, 1.5154180718319756, 9.906731128692627, 14.405304959842137, 16.554543461118424, 12.81531740937914, 5.225292435714176, 14.441558923040118, 16.848853519984655, 3.6045232798371996, 7.864383714539664, 9.296295404434204, 13.968928558485848, 16.5321980544499, 22.941923413957866, 30.35843058994838, 25.550322328295024, 19.464042561394827, 24.301187344959803, 33.32936218806675, 32.567982060568674, 18.35574930054801, 8.099793025425502, 2.0905099383422305, 0.5664473303726741, 0.33918179678065435, 1.3500928516898836, 3.20963630931718, 5.7184755717005045, 8.477352057184492, 20.78866277422224, 40.19685745239258, 61.76540688105992, 92.70341450827462, 59.416839327131, 35.524371079036165, 56.73185736792428, 74.32990387507847, 9.740515453474861, 0.4014723157244069, 0.04844922559069736, 0.0977020605600306, 0.0116919997547354, 0.038275878809924634, 0.06250835582613945, 0.1755763100726264, 0.008238594080986721, 0.11540330893227033, 0.030606658730123724, 0.012404565000906587, 0.0523510869326336, 0.03347766253032854, 0.062277830338903835, 0.026000975065731576, 0.032281819198812754, 0.0251029051308121, 0.054040391463786364, 0.06949194001832179, 0.07206787608031716, 0.09679973112153155, 0.008430392182032977, 0.056569993762033324, 0.05592490712712918, 0.024162506485091786, 0.1043019535552178, 0.025491609005257487, 0.011430667929484375, 0.019260476043980037, 0.04997873851763351, 0.02155381244873362, 0.02617373177781701, 0.08672483637928963, 0.012164926788370525, 0.011532921460457146, 0.02432303429980363, 0.009529323749510306, 0.06396343346152987, 0.059691261633166244, 0.04217021519850407, 0.07155527680047921, 0.09048482961952686, 0.03264954446681908, 0.05046824046543666, 0.038762279852692566, 0.13031236534672125, 0.07628410269639321, 0.013843338287967657, 0.06791352507259164, 0.026887925508032953, 0.06234645058533975, 0.026524790529427782, 0.08379824020500694, 0.15499997990471975, 0.08711810170539788, 0.052508805612368245, 0.10136877559125423, 0.10195689581866775, 0.008950657211244106, 0.05064860864409378, 0.0861777810912047, 0.825290960924966, 32.49906982694353, 111.67128099714006, 77.60987745012555, 67.16723523821149, 92.59779494149345, 96.14247403826032, 66.75806971958706, 45.66399540219988, 53.211938176836284, 58.24551200866699, 23.28774915422712, 5.003098164285932, 1.1835138073989322, 0.9557591314826692, 1.1897178973470415, 1.0601882764271326, 2.441091069153377, 10.302286863327026, 23.33887573650905, 21.99928389276777, 20.742919308798655, 20.267084087644303, 28.219500609806605, 35.60333388192313, 35.81939853940691, 41.31053556714739, 38.531947476523264, 28.940093074526104, 18.756441490990774, 18.5335693359375, 15.01897941316877, 21.53268803868975, 21.669577973229543, 31.857295989990234, 55.381454127175466, 66.0956701551165, 60.90324660709926, 27.452452489307948, 12.814350741250173, 12.826491849763052, 13.223934888839722, 8.003682068416051, 0.8718731499144009, 0.7019008877021926, 0.46448919283492224, 0.8838365908179964, 1.42975948538099, 0.14708416323576654, 0.10370240001274006, 0.028383423474484255, 0.09057495264070374, 0.07818820766572442, 0.031856428632246594, 0.0665746804858957, 0.016627327605549778, 0.1553374153694936, 0.21156335116497108, 1.0213147337947572, 1.4619756766727992, 0.23870164422052248, 0.09112481706376586, 0.07390266191214323, 0.054634526904140196, 0.07284872060907738, 0.04178926867565938, 0.04119260569236108, 0.17903989207531723, 0.06905043085238763, 0.030544959540878023, 0.07393989312861647, 0.023935307515785098, 0.08277540294719593, 0.2891908107059342, 0.7947071077568191, 2.0906977568353926, 4.371604187147958, 7.529881800924029, 14.890415157590594, 18.53343732016427, 20.436034747532435, 26.09283593722752, 21.436358213424683, 24.577456406184606, 18.83793691226414, 12.892972213881356, 13.620674422809056, 10.543655123029437, 17.269834450313024, 23.76399084499904, 32.40657540730068, 37.27745369502476, 29.06212602342878, 18.77711238179888, 11.544704675674438, 17.67444368771144, 16.924187626157487, 11.94537775857108, 8.94774944441659, 5.960188635757991, 6.402418460164752, 5.81072940996715, 8.09273886680603, 13.283083166394915, 19.796100446156093, 24.645496640886577, 27.01576689311436, 26.690883023398264, 48.74585846492222, 84.24448299407959, 81.60107558114188, 52.57614326477051, 52.767256941114155, 82.12587996891567, 30.496473925454275, 0.5101788097194263, 0.04924161200012479, 0.05608572671189904, 0.04854948931772794, 0.11534853758556501, 0.03753370399187718, 0.0990281215469752, 0.03741710114159754, 0.025393796485981772, 0.043404779130859036, 0.0408330906980804, 0.013543627673893102, 0.03359251476026007, 0.024888505028294663, 0.012047131412795611, 0.0330242009700409, 0.027829377579369714, 0.144471762701869, 0.08425046343888555, 0.04135837519009199, 0.08274370857647487, 0.018905787130019495, 0.029373102422271456, 0.07532716475959335, 0.06998107555721488, 0.02352027648261615, 0.09751686799739089, 0.008718964643776417, 0.015411793187792813, 0.21447403569306644, 0.11616739364606993, 0.2073928170970508, 0.1550524713737624, 0.1591889565544469, 0.0904608637626682, 0.07655347431344645, 0.1681104978280408, 0.12849032240254538, 0.1252681224473885, 0.19016470440796443, 0.19484823809138366, 0.16656858128096375, 0.13016566607568944, 0.14795027247497014, 0.07403643509106976, 0.22211963257619313, 0.1632716746202537, 0.20682147704064846, 0.09466254937329463, 0.1371967816459281, 0.14854184644562857, 0.13179112385426248, 0.1823606017444815, 0.22894488062177384, 0.18519282048302038, 0.3887487527515207, 0.18813884311488696, 0.27292570205671446, 0.24246878921985626, 0.2285117038658687, 0.49254042761666433, 0.618356236389705, 17.180129732404435, 136.63401848929269, 108.07988221304757, 82.50310461861747, 90.07760688236782, 122.88297762189592, 87.30491433824811, 77.30127320970807, 48.06748499189104, 50.11928456170218, 59.19851997920445, 14.254753129822866, 1.2742103806563785, 2.91689914890698, 1.9460199773311615, 1.0314943875585283, 3.639256021806172, 23.9460996559688, 52.32776600973946, 59.67447853088379, 57.92178153991699, 45.62784392493111, 47.5524845123291, 50.666677543095176, 46.30332694734846, 48.47118575232369, 38.68433536802019, 30.681712899889263, 20.290713174002512, 22.132830006735666, 18.634771585464478, 21.003779002598353, 24.36084805216108, 37.171271324157715, 60.88816901615688, 69.44421550205776, 54.19320099694388, 23.8121748651777, 19.547467844826834, 24.17905538422721, 14.227309482438223, 13.21737231527056, 3.7484311120850697, 4.023917632443564, 2.5329770871571133, 3.235671643699918, 2.252758409295763, 0.6674733236432076, 0.12672691845468112, 0.17757270937519415, 0.2340102531015873, 0.12585813578750404, 0.12255462019571237, 0.19901400884347303, 0.07587832518454109, 0.5092382516179765, 0.6956443605678422, 2.5559074452945163, 1.2308261543512344, 0.19438493438065052, 0.1981183969016586, 0.11578434705734253, 0.1977068925542491, 0.16987517742174013, 0.14046831109694072, 0.22129632532596588, 0.3265619953828198, 0.1470844889325755, 0.12832621192293509, 0.15432314122361795, 0.19790957096431935, 0.11933103602911745, 0.1277635164026703, 1.751927586538451, 2.5061294649328505, 4.098165214061737, 6.159248445715223, 18.193416799817765, 22.008061204637798, 22.18354664530073, 25.386337893349783, 29.536851269858225, 42.5551038469587, 31.912982327597483, 23.62351563998631, 14.967237915311541, 16.920063870293752, 28.9790655204228, 38.10374389375959, 35.89642974308559, 46.49296760559082, 41.072260992867605, 30.475153378077916, 33.77125719615391, 42.84216867174421, 44.68108238492693, 26.185257400785172, 11.359689780644008, 7.218029711927686, 8.596871495246887, 7.665835465703692, 9.921590719904218, 18.02171812738691, 19.434130566460745, 19.01011848449707, 35.27850907189505, 60.17857033865792, 78.0766852242606, 107.41546072278703, 73.99022729056222, 61.97695173536028, 70.39604227883476, 105.61094406672886, 20.281954969678605, 0.650733864733151, 0.16822077333927155, 0.292003121227026, 0.16934658507151262, 0.20961805912000792, 0.14387177489697933, 0.33106209390929764, 0.10001238408897604, 0.211060353155647, 0.11373861825891904, 0.18683643585869245, 0.15319502247231348, 0.2611554536436285, 0.1787536045802491, 0.15223971301955835, 0.11273374860840184, 0.1709575086299862, 0.3334257299346583, 0.14870379918387958, 0.17193343197660788, 0.23054806888103485, 0.08100197025175605, 0.23278476457510675, 0.10322410067809479, 0.10568731850279228, 0.18193244614771434, 0.1193530477051224, 0.05813346736665283, 0.08672020877046244], [0.05638107943481632, 0.025203645528693284, 0.040629560726561716, 0.03560776715832097, 0.010309390507505407, 0.05875440154756818, 0.02278971648775041, 0.06095719084675823, 0.064668119219797, 0.08027743734419346, 0.032824419904500246, 0.051170744733618836, 0.055719419582081695, 0.006567299989650824, 0.05279234843328595, 0.07009273527988366, 0.08383623816605125, 0.07553740204977137, 0.03690936017249312, 0.03247275895306042, 0.13592215361339705, 0.027099574151049768, 0.056333008621420176, 0.0753990284034184, 0.03723393739866359, 0.06793436966836452, 0.0421929936190801, 0.052019975414233546, 0.0767756470346025, 0.07273752907557146, 0.05860287110720362, 0.12523304218692438, 0.11739706194826535, 0.13273903727531433, 13.179362194878713, 103.40118067605155, 88.61807523454938, 42.536242961883545, 63.925726890563965, 106.82902581351144, 79.19338580540249, 77.47754205976213, 39.55254404885428, 23.08044270106724, 25.50936269760132, 16.220201356070383, 3.1400277359145026, 0.38375280797481537, 1.0865359540496553, 0.6806940627949578, 2.0128316836697713, 7.031942623002188, 17.627188989094325, 29.545046670096262, 37.064005034310476, 33.36246688025338, 29.756084305899485, 22.143254041671753, 21.615729434149607, 24.21490808895656, 26.938339642116002, 17.00589496748788, 17.436483519417898, 23.264547382082256, 24.619697979518346, 30.765226772853307, 43.44630759102957, 44.74648230416434, 15.945077010563441, 2.0792868605681827, 6.404864226068769, 5.632115977151053, 2.5793402450425282, 4.789218280996595, 4.543212532997131, 0.5945271721908024, 0.48920230673892157, 0.8053697156054633, 0.49000596361500875, 0.3806004428437778, 0.055618921760469675, 0.1577682670738016, 0.09910831760082926, 0.18237136330987724, 0.03344159160873719, 0.054492896289697716, 0.07657535028244768, 0.08468848493482385, 0.1476517849202667, 0.04660705390519329, 0.27404859608837534, 2.089263388088771, 0.24681135905640467, 0.15457004654620374, 0.03920133272185922, 0.01969807006285659, 0.1281733786953347, 0.03613160637074283, 0.0586561971743192, 0.0545542494260839, 0.029982657570924078, 0.014124605472066572, 0.025990220285685997, 0.02542224237030106, 0.10013008955866098, 0.05608873601470675, 0.4345229150993483, 0.8018406278320721, 0.7370574697852135, 3.1168954457555498, 7.989204628126962, 15.510072878428868, 17.673184326716832, 8.606308017458234, 6.33185168675014, 13.388368351118904, 6.173740650926318, 4.695780209132603, 10.270714248929705, 7.852196574211121, 6.519840845039912, 9.788795879908971, 10.898366740771703, 18.529221500669205, 21.808778183800833, 38.169671876089915, 41.14667967387608, 20.94422251837594, 7.772800377437046, 2.869555426495416, 0.9643152952194214, 0.5657204293778965, 3.4475550055503845, 2.646790099995477, 2.8062740564346313, 6.789567743028913, 13.087098802839007, 25.994517190115793, 49.9531010219029, 72.02408858707973, 89.88218184879848, 43.21136467797415, 40.75785848072597, 61.29447187696184, 70.75572967529297, 13.961045827184405, 0.14352435139673098, 0.08853666737143483, 0.06816233707857983, 0.028626869964812483, 0.029050754183637242, 0.06209794392010995, 0.004525091939805341, 0.026632061826863458, 0.040694272611290216, 0.01834115948128913, 0.0431592512343611, 0.05475679552182555, 0.029662331366645436, 0.027826013742014766, 0.011381635292699295, 0.02265199593135289, 0.07658727214272533, 0.03747102092685444, 0.061531231472534795, 0.04033475083165935, 0.06571262888610363, 0.07404412967818123, 0.02696823182382754, 0.013512185209297707, 0.08328256037618433, 0.045412730492119274, 0.050527798876698525, 0.04477868362196854, 0.01307945289382977, 0.009237909074207502, 0.0110767364302384, 0.02730950270779431, 0.06890644572143044, 0.05588076163881591, 0.053940663779420514, 0.06683893594890833, 0.03979886083730629, 0.057130158346678526, 0.08138505076723439, 0.08103884863001959, 0.015988905880866305, 0.02360708316388939, 0.012484420939082546, 0.020078887664047734, 0.03713641495310834, 0.07782075381172554, 0.028287225868552923, 0.04631394034783755, 0.03031987590449197, 0.0505094886092203, 0.03004744409450463, 0.061074448483330865, 0.04239145493400948, 0.16616520578307764, 0.060691673308610916, 0.055224937187241654, 0.19721100559192045, 0.016851293355492607, 0.026482027556215013, 0.07897164419825588, 0.04504991103229778, 0.04936037937711392, 0.17644934036902019, 1.306917939867292, 51.49283572605678, 112.8717212677002, 75.3623297555106, 74.75903156825474, 94.18682711465019, 97.60122053963798, 73.3769862311227, 54.20618718011038, 47.14525406701224, 51.55674525669643, 37.9281907081604, 13.586974791118077, 6.884005921227591, 3.1463112958839963, 4.007931130273001, 3.8000201838357106, 3.1395739316940308, 6.9343721100262234, 12.934024776731219, 19.083830186298915, 20.319753170013428, 14.322053381374904, 13.962784613881793, 12.737937927246094, 17.346104826245988, 25.96527569634574, 30.424059799739293, 18.70052238873073, 17.87888922010149, 17.517709697995866, 26.105247156960623, 44.0489387512207, 55.09363194874355, 61.04043878827776, 43.405156884874614, 17.018644911902292, 9.941831690924507, 7.017160764762333, 10.014030422483172, 10.87291635785784, 6.464099356106349, 0.4104784296027252, 0.5944633898990495, 0.2766541434185845, 1.0940004906484058, 0.5567921570369175, 0.14873886587364332, 0.4519432431885174, 0.06009292722280536, 0.07486003411135503, 0.029452087291117226, 0.050385360805583854, 0.11868473142385483, 0.03247642982751131, 0.09787393348025424, 0.05422854243910738, 1.53632433286735, 2.742178661482675, 0.3033232295087406, 0.11472484176712376, 0.044619139683033736, 0.034762675541320016, 0.09352728564824377, 0.004684302124327847, 0.00513217128380867, 0.056319933251610825, 0.004484639802415456, 0.021628359698557427, 0.02662975311146251, 0.028668416664004326, 0.07827966061553784, 0.006039198729143078, 0.7351819447108677, 1.1389651064361845, 2.1764055235045294, 6.184180753571646, 12.503243412290301, 20.33310760770525, 19.53406650679452, 14.976399115153722, 15.497840574809484, 13.642833965165273, 9.851434758731298, 8.748096432004656, 4.864321359566279, 4.378124637263162, 11.729216694831848, 23.262511559895106, 19.838515724454606, 19.5828115940094, 12.209068843296595, 21.634268965039933, 24.51375184740339, 16.606932878494263, 10.274599160466876, 6.235811514513833, 4.601490114416395, 5.687256446906498, 11.222873670714241, 18.217216117041453, 17.579168251582555, 16.505822692598613, 20.375399555478776, 23.875035217830114, 33.336748123168945, 49.74691322871617, 80.2298833302089, 79.10630403246198, 52.81729786736624, 52.38106564113072, 80.21061597551618, 41.76395763669695, 0.8127920744674546, 0.07797694578766823, 0.03308867197483778, 0.07739547520343747, 0.06612572779080697, 0.0058854019818162275, 0.06355264157588993, 0.02361223324468093, 0.01891740195320121, 0.1195567167763199, 0.047992062621882985, 0.02738073022503938, 0.057917150402707715, 0.07332756277173758, 0.03598212171345949, 0.0014330502682631569, 0.08833597028361899, 0.011974836899233716, 0.05149651618142213, 0.020175117500392453, 0.006856395771527397, 0.04979199550247618, 0.007247450345728014, 0.020405017039073364, 0.07881763031972305, 0.03237055122320141, 0.02064266544766724, 0.07928683049976826, 0.005330806897420968, 0.05887420369046075, 0.15525021004889691, 0.14499470964074135, 0.1551097940121378, 0.19274853861757688, 0.14142626683626855, 0.20344989081578596, 0.10239746860627617, 0.1135123675423009, 0.26261715378080097, 0.2848752737045288, 0.10244598386010953, 0.10197438166609832, 0.23339574464729854, 0.1079944936292512, 0.11466024523334843, 0.21535193787089416, 0.15733818443758146, 0.15026730671525002, 0.09783738758414984, 0.11375573769743953, 0.24919277269925388, 0.21679735316761903, 0.25785136808242115, 0.38851769800697056, 0.359519255480596, 0.26579087919422556, 0.3169317921357495, 0.2343765805874552, 0.12943379820457526, 0.18623412746403897, 0.21982975330735954, 0.43534065836242264, 0.29942531724061283, 0.476511150598526, 30.893004144941056, 139.88160651070731, 105.15509360177177, 73.54265907832554, 83.1281715120588, 125.92154993329729, 91.55157688685826, 94.95244216918945, 55.90463958467756, 38.09132398877825, 48.430980001177105, 35.57775408881051, 10.304910676819937, 3.916265283312116, 6.171046486922672, 6.4125988738877435, 3.867385140487126, 7.963974850518363, 27.822669880730764, 51.01835019247872, 61.61879294259207, 50.49759660448347, 42.83438321522304, 35.80306679861886, 34.541030747549875, 36.47389105388096, 35.27855770928519, 27.02854289327349, 24.341007471084595, 28.504988193511963, 32.97261387961251, 46.61855976922171, 65.72963210514614, 76.58181503840855, 46.58115414210728, 18.38356293950762, 20.549253906522477, 22.647615092141287, 13.02416375705174, 12.052196758134023, 6.741804088865008, 0.8864784804838044, 2.047544449567795, 2.1354734684739793, 2.4449870543820516, 1.070492672068732, 0.2481202802487782, 0.6511517880218369, 0.13988606019743852, 0.22607671309794697, 0.15827336854168347, 0.11845301171498639, 0.2932776542646544, 0.4099041718457426, 0.33484745078853195, 0.1321574920522315, 1.6792529033763068, 3.7710653032575334, 0.40681618611727444, 0.23802101931401662, 0.22309867718390056, 0.09473083035222121, 0.18751828212823185, 0.15999052354267665, 0.32786057570150917, 0.12194251375538961, 0.09939743458692517, 0.08960015566221305, 0.12140185705253057, 0.24186410595263752, 0.24383104326469557, 0.16672838984855584, 2.0070533880165646, 1.344572725040572, 1.1738631938185011, 8.272045816693987, 13.383309194019862, 22.808846303394862, 37.810140814099995, 30.536148139408656, 29.051210403442383, 21.63162170137678, 15.325480086462838, 18.701656682150706, 11.497655817440577, 20.121196235929215, 29.401792185647146, 30.811390604291642, 24.212927852358135, 30.871940680912562, 33.38850178037371, 50.38698475701468, 52.32280152184622, 30.031483105250768, 13.701675653457642, 7.4600958313260755, 5.45842490877424, 7.079113943236215, 15.045314822878156, 23.236808436257498, 18.280290126800537, 13.812800799097333, 25.53410175868443, 46.71997914995466, 70.12949548448834, 82.8794607434954, 100.076523235866, 64.82452501569475, 62.5871216910226, 72.58946350642613, 100.28325298854283, 28.495024476732524, 0.40715010677065167, 0.16252206984375203, 0.3003474191895553, 0.12165438064507075, 0.18093998011733803, 0.10466446767428092, 0.306292824447155, 0.10132883702005659, 0.10221164500606911, 0.19321600853332452, 0.1237465755215713, 0.10283897098686014, 0.18095247873238154, 0.3405444850879056, 0.09526117332279682, 0.16245845040040358, 0.41051165067723816, 0.037549917586147785, 0.12499711556094033, 0.12094883993268013, 0.10821450182369777, 0.1556469223328999, 0.057336073368787766, 0.11189546609031302, 0.12454423414809362, 0.11956342070230416, 0.17498168269438402, 0.13554211972015245, 0.16975426248141698, 0.12047424539923668], [0.04671283072925039, 0.036973702255636454, 0.04368011846340128, 0.060028059275022576, 0.0464387195450919, 0.04555081236841423, 0.04912716689120446, 0.05702493113598653, 0.030221556180289814, 0.014430263445579579, 0.036624304218483825, 0.020228487672284245, 0.00846762424667499, 0.046262656671128104, 0.04313543126253145, 0.11050981615803071, 0.010336265583256525, 0.04413825852264251, 0.029151821974664927, 0.08719398906188351, 0.054620403197727034, 0.07057621183672122, 0.038167208034012995, 0.03790316291685615, 0.05963009848658528, 0.0488177447446755, 0.07247731768126998, 0.0718476575400148, 0.08236853977931397, 0.04458399496174284, 0.07900766083704573, 0.04036226881934064, 0.2685958615371159, 0.05790613777935505, 0.1866393078650747, 32.22080489567348, 108.12481621333531, 80.57199873243059, 58.06899649756295, 71.1045639855521, 100.91826970236642, 84.54763984680176, 68.87336540222168, 47.66526767185756, 30.05416897365025, 15.12932549204145, 8.881634729249136, 7.487925972257342, 3.080721603972571, 0.6913624246205602, 1.7051120357854026, 0.5653184652328491, 1.9688784650393893, 7.75719906602587, 17.170077426092966, 30.958334582192556, 38.54608358655657, 37.79051562717983, 32.113958971840994, 30.530026776450022, 24.306212629590714, 19.447476318904332, 19.420501674924576, 21.277727365493774, 26.107788460595266, 10.867910180773054, 11.393419810703822, 6.541623447622571, 5.298859093870435, 4.093932458332606, 9.77613365650177, 8.338146635464259, 5.563765679086957, 5.658706298896244, 0.47871595514672144, 0.16108071218643868, 0.598674758204392, 0.3361937456897327, 0.1487649351890598, 0.11848978831299714, 0.1604769110147442, 0.0863263870456389, 0.10772949177771807, 0.12259890139102936, 0.07733781329755272, 0.031736439892223904, 0.18030713764684542, 0.0380913003214768, 0.09241997078061104, 0.09351226966828108, 1.4552625226122993, 2.1570402426379065, 0.06148882981921945, 0.15195467402892454, 0.0670402165768402, 0.07536341210028955, 0.08389271942100354, 0.028788055958492414, 0.07526957749256066, 0.11735288931855134, 0.13428889268210956, 0.029805553145706654, 0.036575137571032555, 0.04445667125816856, 0.055307104385324886, 0.13501674362591334, 0.4018873891660145, 0.6020318237798554, 0.2456230813903468, 3.0203350271497453, 11.534567253930227, 25.004176548549108, 9.695975763457161, 3.6607070650373186, 3.268795443432672, 3.703467147690909, 2.7632792549473897, 1.9545918830803461, 4.8391198090144565, 2.611847175019128, 5.814587831497192, 12.133037311690194, 17.382681880678447, 28.81782214982169, 31.454828534807476, 18.109934193747385, 7.466099943433489, 0.33420216398579733, 1.6356882410390037, 3.4879854874951497, 2.9226370581558774, 1.9166065156459808, 1.9802921840122767, 2.211064223732267, 5.063004229749952, 17.229722499847412, 34.51219572339739, 58.12991482870919, 78.64987686702183, 77.90011760166713, 41.52900430134365, 37.88117572239467, 56.146541118621826, 70.20275729043144, 12.32624065876007, 0.3378373474947044, 0.10760034620761871, 0.010057257920769709, 0.017191912845841477, 0.0875383862959487, 0.055297862738370895, 0.059242973902395794, 0.03092818594138537, 0.014381588736016835, 0.06970126128622464, 0.03417431104129978, 0.11774269411606447, 0.07230995023357016, 0.041197016169982295, 0.04722333672855582, 0.06277143063821963, 0.030687404397342886, 0.09891341520207268, 0.02648025318714125, 0.06177537515759468, 0.09663109481334686, 0.08784245140850544, 0.03149783644559128, 0.05796711093613079, 0.039535616391471455, 0.05440168761249099, 0.06886350124010018, 0.029259576728301387, 0.051936746308846135, 0.07021299882658891, 0.08939932965274368, 0.10664948794458594, 0.03054652356409601, 0.029335464084787027, 0.04227243310638836, 0.05690964464364307, 0.013844070257619023, 0.033328283045973094, 0.048369545223457475, 0.036140308582357, 0.08731807276074376, 0.03669656480529478, 0.044672421645373106, 0.05212500584977014, 0.020665320035602366, 0.05390323239511677, 0.044153189685727866, 0.07511529898537056, 0.024873227812349796, 0.029429129058761255, 0.06297653141830649, 0.026378483112369264, 0.022677128868443624, 0.11225681312914405, 0.1034692350242819, 0.05674485902168921, 0.13718990130083902, 0.09393453558108636, 0.04441302788576909, 0.003951535194313952, 0.015530482533254793, 0.053359305153467824, 0.025752163059743385, 0.23208888620138168, 0.020653681463695, 1.34339739382267, 74.18297726767403, 117.29260989597866, 64.54153183528355, 76.53868062155587, 97.70815331595284, 97.5028965813773, 79.94793237958635, 52.39765099116734, 41.65760156086513, 45.62835809162685, 37.28470066615513, 22.935852425439016, 12.663812807628087, 8.429552793502808, 7.190873111997332, 7.7066622120993475, 6.758886235100882, 4.825630749974932, 10.46909921509879, 19.233558654785156, 23.987613405500138, 23.84496862547738, 17.74008158275059, 9.157935057367597, 10.465282917022705, 14.247612987245832, 19.423782961709158, 17.88282537460327, 25.168058497565134, 35.47511529922485, 29.7862777028765, 40.91866411481585, 30.66553749356951, 21.087240764072963, 25.25677309717451, 19.66850025313241, 10.833435824939183, 5.910439533846719, 9.001405170985631, 1.0200175919703074, 0.48713282921484535, 0.6214091554284096, 0.2766988453056131, 1.1404090289558684, 0.1854954335306372, 0.18657646195164748, 0.08874806495649473, 0.07565015421382018, 0.15304612474782125, 0.16922619938850403, 0.03103450559345739, 0.1508728585072926, 0.07845491264015436, 0.15600810652332647, 0.1610908494996173, 2.1706356959683553, 2.255197878394808, 0.3513108273702008, 0.17469888286931173, 0.0685701976929392, 0.02325631448599909, 0.03617857117205858, 0.016030790151229928, 0.0600023427978158, 0.02380529002818678, 0.016409149759316018, 0.04253456475479262, 0.041729676337646585, 0.039150669904691834, 0.056455711501517465, 0.061224017957491536, 0.9418554604053497, 0.7047155595251492, 0.9139862358570099, 5.725973980767386, 10.447761297225952, 19.41936390740531, 19.581593922206334, 12.789996436664037, 1.8253356303487505, 4.123056701251438, 3.007631983075823, 2.7878980253423964, 4.751101332051413, 6.759669210229601, 12.018377270017352, 14.878368718283516, 10.827859895569937, 13.81625839642116, 16.03632422855922, 19.16795376368931, 9.863054752349854, 4.466253851141248, 5.342583239078522, 10.536198837416512, 13.199211461203438, 14.59328065599714, 16.3279435975211, 15.934263876506261, 14.644084147044591, 20.808202845709665, 31.7548691204616, 39.251405647822786, 63.87082917349679, 86.82628073011125, 73.97666440691266, 40.95398875645229, 53.91084705080305, 82.7331177847726, 41.043491976601736, 1.1011431302343095, 0.08042097464203835, 0.057790556124278476, 0.013154967056055154, 0.08005855551787786, 0.0648499530340944, 0.012592297829022365, 0.06534398759582213, 0.030523809604346752, 0.014367956967492188, 0.08151019298072372, 0.02418794815561601, 0.06670985144696065, 0.05545013278190579, 0.034267599428338666, 0.1439543254673481, 0.012494627802100564, 0.018628680213753666, 0.09076137335172721, 0.024740491095664244, 0.11738757602870464, 0.09637125661330563, 0.021122274354898503, 0.014935685521257775, 0.028147810670946325, 0.08369326405227184, 0.02398988717634763, 0.050613911755915196, 0.036694118686552556, 0.08520935555653912, 0.05213298202891435, 0.16429010140044348, 0.11443361453711987, 0.1446844155767134, 0.14971930826348917, 0.1440727026867015, 0.21783283831817762, 0.09281630987035376, 0.2089452373662165, 0.09942431814436402, 0.18529721988098963, 0.10951331962964364, 0.16390856115945748, 0.07465836671846253, 0.1173706805067403, 0.15475711865084513, 0.2523567000670092, 0.14721721038222313, 0.1214242215667452, 0.13042460860950605, 0.20461349694856576, 0.14850265426295145, 0.2613449820450374, 0.23440923169255257, 0.17430060995476587, 0.2476730713886874, 0.2143353567059551, 0.17214372354958737, 0.25567994745714323, 0.1576171980372497, 0.10990433900484017, 0.1954998624111925, 0.21513872859733446, 0.3966101237705776, 0.23093461671045848, 0.29168304268802914, 57.39844669614519, 148.9456010546003, 96.53809056963239, 88.50424289703369, 91.63171740940639, 121.26529802594865, 97.70913996015275, 82.50969845908028, 64.57888535090855, 48.45641040802002, 33.81884888240269, 29.140626771109446, 24.431455646242412, 11.490117021969386, 11.972455757004873, 9.09110380922045, 8.367164918354579, 6.948628510747637, 16.26767144884382, 30.914609568459646, 53.16232456479754, 64.8804371697562, 58.63070624215262, 42.98163291386196, 35.15752008983067, 32.6002425466265, 30.10912922450474, 27.054339817592076, 29.865848473140172, 36.46835681370327, 23.305628606251307, 29.485438074384415, 17.68079260417393, 11.8223876953125, 25.420717579977854, 23.56874646459307, 9.024233477456228, 6.592244114194598, 7.268531824861254, 0.30950367929680006, 0.6731877284390586, 2.2638442601476396, 2.1484173110553195, 1.4791954840932573, 0.23809815517493657, 0.24418086877890996, 0.2526246942579746, 0.34461460954376627, 0.2720842372093882, 0.2719717361032963, 0.12217249641461031, 0.3101121352187225, 0.12535644056541578, 0.46517923580748693, 0.23452580400875636, 3.810273119381496, 4.196178674697876, 0.3903671944780009, 0.1993724246110235, 0.11534781833844525, 0.2006450713213001, 0.34612483850547243, 0.25000489769237383, 0.13016436328845365, 0.1483715341559478, 0.15873174608818122, 0.13040053418704442, 0.16114083038909094, 0.1298301847917693, 0.1290859268712146, 0.24356378189155034, 1.4884108581713267, 1.1002683086054665, 0.4429276298199381, 5.198443293571472, 16.750331538064138, 31.943415437425884, 27.508022444588796, 27.969393253326416, 11.208767090524946, 7.3497167485100885, 4.127966472080775, 2.7133753384862627, 8.891015665871755, 10.085778389658246, 24.34076428413391, 36.744228090558735, 34.927228995731895, 40.887053285326274, 53.158815724509104, 37.03524991444179, 16.135782480239868, 7.391251342637198, 4.783772196088519, 9.361142941883632, 14.817398275647845, 14.544697982924324, 16.636212587356567, 11.548961315836225, 14.999885763440814, 40.74374321528843, 58.49285398210798, 72.34680461883545, 87.1591272354126, 88.4409100668771, 60.349794796534944, 56.55555725097656, 67.62301622118268, 103.93339879172188, 30.283021790640696, 0.6717227984751973, 0.20948240639907972, 0.10307320127529757, 0.12814508378505707, 0.17711065416889532, 0.19879527629486152, 0.25277076927678926, 0.11215370973306042, 0.19888811345611299, 0.14753002859652042, 0.23458198670830044, 0.10478578973561525, 0.14284690203411238, 0.23311122134327888, 0.12338057373251234, 0.2845858649483749, 0.08140789704131228, 0.1282267522599016, 0.10708809298064027, 0.08127698049481426, 0.18420352999653133, 0.20497173629701138, 0.1634774607207094, 0.10066771320998669, 0.2909445794565337, 0.19059640195752892, 0.1215203699788877, 0.2513469313936574, 0.116836564881461, 0.19361371147845471, 0.14638004744691507], [0.04096305390287723, 0.048452343459108045, 0.08464676860187735, 0.00946799521001854, 0.037606415804475546, 0.020270312570833733, 0.02646313714129584, 0.03239353320428303, 0.007568934300382222, 0.010037285242495793, 0.0931330228756581, 0.03650738584942051, 0.008082597183861902, 0.023992720060050488, 0.03702283497633679, 0.028323105104001503, 0.02397943434438535, 0.04199075286409684, 0.013508803560398519, 0.01426459233542638, 0.07777109183371067, 0.09964617873941149, 0.01567141425662807, 0.06527915357479028, 0.04918503575026989, 0.021605155497257198, 0.03584299150056072, 0.053739427256264856, 0.08689670251416308, 0.06981983528073345, 0.04498333656894309, 0.09582490700164012, 0.04207326950771468, 0.14018781829093183, 0.08610801412058727, 0.154000619958554, 27.97191197531564, 100.39915588923863, 81.76260035378593, 74.69745663234166, 67.39851992470878, 92.31863021850586, 88.22526577540806, 62.38408143179757, 46.700704847063335, 36.45676374435425, 18.220002344676427, 9.223708442279271, 5.041609857763563, 3.476120352745056, 3.9559955171176364, 1.0408328750303812, 1.8223898112773895, 2.6418032475880215, 2.396463223866054, 1.8461378855364663, 9.535273483821324, 22.678065572466167, 29.84177643912179, 41.078212124960764, 41.425201688494, 27.29883997780936, 18.838796751839773, 12.048080818993704, 11.818646090371267, 11.533154164041791, 6.445822553975241, 3.632794414247785, 1.5849553176334925, 2.6979123396532874, 9.525704077311925, 13.501956633159093, 5.881058207580021, 1.032078036240169, 1.0307800258908952, 0.04011220491624304, 0.11651738200868879, 0.13216786006731646, 0.048169167047100406, 0.060445629725498815, 0.015048098417797258, 0.06767626851797104, 0.0061369938609589425, 0.03538907192913549, 0.03992921080706375, 0.05467914736696652, 0.13131954201630183, 0.08520769993109362, 0.050563829086188755, 0.10576991657061235, 2.124333986214229, 1.9846502244472504, 0.2751599278833185, 0.15469800468002046, 0.023625802248716354, 0.05481895272220884, 0.10669050538646323, 0.04932100398998175, 0.06585324169801814, 0.06442831137350627, 0.033542041932897906, 0.08637048503650085, 0.11582877753036362, 0.03644877399450966, 0.019870097349796976, 0.11093046715749161, 0.5578895924346787, 0.16473357831793173, 0.7264259116990226, 0.9434186965227127, 9.11506380353655, 7.614746229989188, 14.82470256941659, 8.532464299883161, 3.8234994496617998, 4.812129097325461, 6.284937884126391, 8.850119437490191, 8.972960114479065, 17.790878125599452, 25.100534166608536, 25.2029801436833, 21.652402026312693, 10.67454355103629, 3.1875972747802734, 1.0104725041559763, 3.8635458265032088, 2.406677075794765, 3.514629223517009, 3.5713653905051093, 1.2266525668757302, 4.5276146956852505, 7.577853901045663, 15.035229512623378, 32.85881280899048, 48.2791861806597, 64.21301405770438, 85.09129469735282, 54.88704810823713, 27.62794487816947, 46.85681002480643, 67.98567744663784, 68.08237552642822, 10.002744810921804, 0.0669109895825386, 0.1325507845197405, 0.037985486177993674, 0.06365044561347791, 0.0020563979134229676, 0.01819376810453832, 0.0625728437943118, 0.027076961971553307, 0.026421354651185017, 0.02419387685534145, 0.026123258950454847, 0.022834214814273373, 0.04337210766971111, 0.03572717575090272, 0.02251799713953265, 0.03475641266309789, 0.03918848466128111, 0.09804852054055248, 0.02711199134189103, 0.008750722627155483, 0.03476687567308545, 0.11626116718564715, 0.03996560064011386, 0.04702013245384608, 0.01727577468513378, 0.03582269651815295, 0.014863604746226753, 0.031256922587220154, 0.07448761338101965, 0.0364073392535959, 0.04459835954808763, 0.05686312089008944, 0.025312776012080054, 0.016695148877001235, 0.05793174569095884, 0.04660571040585637, 0.029373462045831338, 0.03618284594267607, 0.03148283403632896, 0.02156451973132789, 0.15737103910318442, 0.011818993520656866, 0.07700941591922726, 0.01903631691155689, 0.07861484334404979, 0.04709680691095335, 0.04232187795319727, 0.09262022682066474, 0.06001140124031475, 0.05087088993085282, 0.022668782887714248, 0.03980830943744097, 0.09634762323860611, 0.019057566932003413, 0.11955930878009115, 0.03277916840410658, 0.14329191244074277, 0.046587624054934294, 0.05504692013242415, 0.042572786632393084, 0.06845646843846355, 0.13613342227680342, 0.023434748839853064, 0.09057654719799757, 0.09510817724679198, 0.24527955268110546, 0.3215912921088082, 1.8013907266514642, 77.5231500353132, 111.6400488444737, 76.41525976998466, 84.48231983184814, 95.03961426871163, 102.37081146240234, 77.61660330636161, 51.503737449645996, 45.03250142506191, 39.978256702423096, 27.852969237736293, 22.48375746182033, 16.27268978527614, 12.906363998140607, 11.647858500480652, 6.440546265670231, 8.759182282856532, 12.688223566327776, 9.3432982308524, 7.760318807193211, 13.65452778339386, 23.59427067211696, 23.72748327255249, 27.56631783076695, 24.043214627674647, 19.719533034733363, 16.37528167452131, 15.295505557741437, 16.911760772977555, 16.46261705671038, 14.915649277823311, 10.216295089040484, 4.613675083432879, 11.272319657461983, 27.402835403169902, 18.076098203659058, 11.113435200282506, 3.8726575204304288, 0.6775847982083048, 0.13629857770034245, 0.07879603255007948, 0.1989187425268548, 0.28644420951604843, 0.3081414523933615, 0.044820505127842934, 0.0516481925068157, 0.016518841730430722, 0.07821913529187441, 0.04997511514063392, 0.06480890166546617, 0.03033149242401123, 0.09332739601710013, 0.09434856407876525, 0.12397953016417367, 1.7092280834913254, 1.518681988120079, 0.1521561446466616, 0.06488678391490664, 0.07978933317852871, 0.02177665352688304, 0.026949712906831076, 0.053812444409621615, 0.14410509594849177, 0.09517710283398628, 0.06082845239767006, 0.017843715281092694, 0.1058847111250673, 0.015634198307192752, 0.08997968065419368, 0.05538544125322785, 0.936376262988363, 0.7487494966813496, 1.0552920762981688, 2.4854813729013716, 13.130961912018911, 16.191682474953787, 14.252952677862984, 16.678419419697352, 4.006282670157296, 1.3413807877472468, 0.8660035505890846, 2.597612270287105, 3.2553280975137437, 4.639458979879107, 13.103564296449933, 17.987258536475046, 17.537017004830496, 14.863037518092565, 13.900884849684578, 8.240502732140676, 9.01392843042101, 10.660206811768667, 13.35876989364624, 18.099951369421824, 15.391421965190343, 18.63880501474653, 21.270899023328507, 22.421072551182338, 28.970093658992223, 44.4024144581386, 52.91799463544573, 76.41214697701591, 73.20212786538261, 54.10188429696219, 44.933590344020296, 64.65286976950509, 79.14884785243443, 35.427815437316895, 0.8306693551795823, 0.06090518792292901, 0.08867635059037379, 0.05178240334082927, 0.08139094723654644, 0.038537284425858936, 0.024288356071338058, 0.02818359830416739, 0.0815360044528331, 0.030789171079439775, 0.03648025801937495, 0.04845998376341803, 0.03993925991068993, 0.009465199645741709, 0.07889882382005453, 0.09166259677814585, 0.09349693477685962, 0.05534880714757102, 0.04087293427437544, 0.04355435539036989, 0.03629881775538836, 0.0942361851089767, 0.03853397656764303, 0.015232743063409413, 0.053634848046515665, 0.08081905078142881, 0.014575527615046926, 0.04078627856714385, 0.06430456694215536, 0.01800294030856873, 0.03553466858076198, 0.042673304810055664, 0.13902464642056397, 0.11553575896791049, 0.1788396428206137, 0.13569815563304083, 0.12004059366881847, 0.13142862330589974, 0.09308316412248782, 0.09669979648398501, 0.2887345909007958, 0.05966474448463746, 0.17188032982604845, 0.12798828791294778, 0.1919596330927951, 0.14473325652735575, 0.18002060587917054, 0.1274171649877514, 0.11933927344424383, 0.15925106965005398, 0.1003672443330288, 0.1481284150587661, 0.15329107588955335, 0.1974541518305029, 0.24433823462043489, 0.24761536877070153, 0.43494425820452826, 0.2070547980921609, 0.27459055557847023, 0.19316906748073442, 0.19491286176655973, 0.3410495051315853, 0.2876211420765945, 0.15997742781681673, 0.16488870499389513, 0.2323411926627159, 0.3426848016679287, 0.274326496890613, 58.10875756399972, 143.7915107182094, 98.88145392281669, 100.16832978384835, 88.5118442262922, 113.43439333779472, 107.86217430659703, 75.55750465393066, 66.32543318612235, 55.2484586579459, 31.542219502585276, 19.486071825027466, 22.876580817358835, 16.39036100251334, 14.142671738352094, 8.50994258267539, 8.740279708589826, 11.061692833900452, 10.365787318774633, 13.287158284868513, 24.10792667525155, 38.59009347643171, 52.77801275253296, 65.02868393489292, 57.59895781108311, 39.95490033285958, 26.29412177630833, 18.43712486539568, 17.790860755102976, 15.949888638087682, 8.452725035803658, 4.132487578051431, 0.9704959349972861, 3.715717690331595, 22.554669039590017, 16.977581058229717, 9.984597853251866, 2.2294152847358157, 1.1844269526856286, 0.27146394763674053, 0.17486831306346826, 0.5268534549645015, 0.2258382758923939, 0.19309896124260767, 0.12510338771556104, 0.12599172576197556, 0.08371353867862906, 0.15349574919257844, 0.10912849527916738, 0.2210850566625595, 0.18571541458368301, 0.24735692835279874, 0.3747946800930159, 0.19143663187112125, 5.085247584751674, 4.952708959579468, 0.5723053131784711, 0.32437982676284655, 0.13967272878757545, 0.13670812786689826, 0.2202800020043339, 0.15365658913339886, 0.30947357948337284, 0.21425386465021543, 0.20306824200919696, 0.19839274218039854, 0.27230940226997646, 0.11731352071676936, 0.24211193408284867, 0.23124826273747853, 1.190810393009867, 1.5609820783138275, 2.754561654159001, 2.3843803065163747, 14.638193811689105, 11.648243256977626, 19.745479345321655, 27.044200658798218, 11.592140895979744, 4.176261229174478, 8.613808597837176, 25.67191927773612, 35.7319450378418, 48.37809378760201, 59.906381607055664, 56.60582399368286, 44.530556610652376, 27.576194695064, 19.905044725963048, 9.618518114089966, 8.6708767584392, 9.204629557473318, 14.000001771109444, 17.13643424851554, 11.827807290213448, 15.694768156324114, 20.735872098377772, 39.321043968200684, 64.65844917297363, 65.40716620853969, 77.90544686998639, 94.65432970864433, 68.91283811841691, 48.63388477052961, 60.36295468466622, 81.98519284384591, 93.43828378404889, 23.582554272242955, 0.3510396033525467, 0.23137756437063217, 0.14428698404559068, 0.15299678168126515, 0.12311715286757265, 0.19597817531653813, 0.2310422866472176, 0.15795608556696347, 0.1421672542180334, 0.12635388704282896, 0.1437145583331585, 0.11040788662752934, 0.12545419032020227, 0.15000779421201774, 0.13159664214721747, 0.14989363748048032, 0.1644031453345503, 0.18057182058691978, 0.1792873673673187, 0.10819546891642468, 0.17224770225584507, 0.2876490977193628, 0.12875702737697534, 0.11630179786256381, 0.2563765857900892, 0.14528949239424296, 0.08985869786036865, 0.0713365985346692, 0.18853064280535492, 0.11177707530025925, 0.1163749982203756, 0.11808790559215204], [0.033409703855535815, 0.0527645115341459, 0.06916883521314178, 0.022455166493143355, 0.057027190657598634, 0.015030091794739877, 0.012474006274715066, 0.06796524979706321, 0.03920881017776472, 0.013657157608707036, 0.04785157194627183, 0.04743892426735588, 0.05509904519255672, 0.029427632889045135, 0.05311318014615348, 0.03020993626809546, 0.05698919269655432, 0.018726959225854704, 0.027517926613134996, 0.012909359431692531, 0.1022551255300641, 0.09279423034084694, 0.06752135218786341, 0.06405409252537148, 0.0763195561511176, 0.07684839955930199, 0.06758837109165532, 0.03260370942630938, 0.06758393347263336, 0.16667101292737893, 0.11690683396799223, 0.03321062507373946, 0.05742398436580386, 0.12522074713238648, 0.10157105366566352, 0.02085011056624353, 0.2332683429121971, 26.24905228614807, 101.17695808410645, 76.65983636038644, 69.28346197945731, 56.69418770926339, 81.1345248903547, 109.92491381508964, 67.84936073848179, 64.7000549861363, 60.09701933179583, 35.76347596304757, 23.09920631136213, 21.13912296295166, 13.432367818696157, 4.6780609999384195, 4.506985059806278, 3.8751271707671027, 1.5174162217548914, 1.9954179780823844, 2.5069817049162726, 2.4343341631548743, 3.671409462179456, 6.583914961133685, 6.862347083432334, 9.913793972560338, 22.67170623370579, 24.540731702532085, 25.426448106765747, 35.24660641806466, 12.30316048009055, 9.70154561315264, 8.606633714267186, 7.49620475087847, 10.205865842955452, 13.873336110796247, 9.265607816832405, 2.9026483935969214, 0.6395025902560779, 0.23227857745119504, 0.22241730588887418, 0.23244392286453927, 0.10756053655807461, 0.11471234315208026, 0.05584704862641437, 0.06478359230927058, 0.03115249265517507, 0.13160611449607781, 0.1410597222191947, 0.07883933665496962, 0.05174678025235023, 0.06557371241173574, 0.14408433277692112, 0.07162921676146132, 2.170950536217008, 1.8077208612646376, 0.20585893440459455, 0.11406986548432282, 0.025623117573559284, 0.018444656427683573, 0.02472755143285862, 0.02525104459242097, 0.030008659032838683, 0.025574897482459034, 0.016302404326519797, 0.03852940324161734, 0.0308480984531343, 0.05450998519414237, 0.06236787872122867, 0.15389655982809408, 0.08832132749791656, 0.23767360938446863, 1.1081382291657584, 1.4019750505685806, 4.761818928377969, 8.612815873963491, 22.208391666412354, 14.01060037953513, 4.377959617546626, 9.982033967971802, 6.1347894838878085, 6.390020268304007, 9.790354013442993, 15.270179373877388, 15.916533810751778, 8.464258176939827, 4.225428853716169, 3.40884268283844, 4.056403500693185, 3.659914970397949, 8.487226315907069, 12.503774080957685, 13.888592617852346, 10.727966512952532, 14.959897143500191, 25.633386305400304, 41.14869465146746, 55.16882535389492, 68.56992367335728, 84.43295982905796, 68.96849318913051, 41.489590644836426, 35.92702266148159, 54.357136794498985, 67.48039749690464, 61.71367059435163, 9.054306149482727, 0.1780410749571664, 0.09742106563810791, 0.07238455515887056, 0.07715630518006426, 0.06638057197311095, 0.020636543365461484, 0.034806356233145506, 0.03370998274268849, 0.04707054760573166, 0.06561541517398187, 0.021289243163274865, 0.05893621500581503, 0.10800295496093375, 0.0289818489524935, 0.03286143059709242, 0.07131428830325603, 0.045716357949588976, 0.048892254675073285, 0.0520352628082037, 0.017799079551228454, 0.07039951453251497, 0.05505514397685017, 0.06386388558894396, 0.05191175586410931, 0.05169002419071538, 0.015114442179245608, 0.037550419702061584, 0.06927864932055984, 0.04567051612372909, 0.055596414753901105, 0.06018281275672572, 0.1720241792500019, 0.08214553924543516, 0.0580011462526662, 0.03231597665165152, 0.06469258040721927, 0.030998007194804292, 0.060514813156000206, 0.01747810364966946, 0.06755754524575812, 0.09613858017006091, 0.026344690372103026, 0.03432958699496729, 0.053777201300753016, 0.07004153302737645, 0.02895256338108863, 0.016038511879742146, 0.02412767049723438, 0.03840236791542598, 0.09155867235468966, 0.10376696940511465, 0.024826096769954478, 0.023650370305404067, 0.06839350038873297, 0.09029110108635255, 0.04225035018420645, 0.010498544018316482, 0.07905272913298436, 0.08688712159969977, 0.02007933719349759, 0.03022274361657245, 0.056068335859371085, 0.012934533080884388, 0.055776966137013266, 0.019800106462623392, 0.10724579808967453, 0.09273263971720423, 0.11303986968206507, 0.0955194780336959, 2.1937597351414815, 75.57820333753313, 110.70915004185268, 84.63236618041992, 77.79698548998151, 89.27713966369629, 97.90164675031389, 86.33551556723458, 54.05206918716431, 51.86524527413504, 50.757865701402935, 45.20364597865513, 36.73457704271589, 28.29057025909424, 17.319246564592632, 15.361193827220372, 18.625725030899048, 16.70749068260193, 12.317727378436498, 15.368631873811994, 14.78125548362732, 10.75977623462677, 13.533503191811697, 16.950528247015818, 16.84658145904541, 20.538544995444163, 32.428264209202354, 28.891728401184082, 25.223694460732595, 35.174161025456016, 24.410833392824443, 15.873644317899432, 12.536045857838221, 10.902249915259224, 20.8477554661887, 19.50677571977888, 9.604287334850856, 1.862130684512002, 0.7256375082901546, 0.10148091707378626, 0.38645579293370247, 0.08096207239265953, 0.129868087757911, 0.09366918089134352, 0.06569044757634401, 0.027947714086622, 0.02473617222027055, 0.02762961686987962, 0.02346419556332486, 0.054364819412252734, 0.09377425203898124, 0.046137358394584486, 0.13550708017178945, 0.048917092449430905, 0.8160536023122924, 1.2889708514724458, 0.2674709047589983, 0.05735497735440731, 0.03285131363996437, 0.06073701980390719, 0.06781886265214, 0.027209384865792732, 0.04876284786899175, 0.08373420685529709, 0.04857228470167943, 0.009667788149922021, 0.025091607522751604, 0.038693588360079696, 0.10042006149888039, 0.13038313654916628, 0.8269927267517362, 0.6723738663962909, 1.4761327398674828, 1.482664155108588, 7.923362629754203, 9.508336186408997, 18.36853919710432, 14.615209170750209, 1.468409708568028, 6.760752694947379, 6.004067378384726, 10.447989719254629, 14.266085641724722, 18.004460539136613, 18.64531373977661, 14.401261108262197, 10.563152636800494, 10.629360284124102, 12.253981130463735, 14.495032259396144, 19.610863208770752, 28.653742177145823, 31.20989063807896, 25.153993606567383, 32.16020270756313, 39.77051946095058, 40.77014636993408, 49.15365171432495, 68.0824728012085, 77.63630144936698, 81.29934310913086, 69.50226770128522, 50.737260818481445, 42.14603907721383, 64.63424859728131, 75.16663374219621, 27.884818043027604, 0.7139890162008149, 0.07019900743450437, 0.1853556146046945, 0.09056715627333947, 0.06859295575746469, 0.011952600458503833, 0.02989270757617695, 0.04894469525398953, 0.00982363916201783, 0.05758396256715059, 0.00709487368918157, 0.011965480749495327, 0.04413699305483273, 0.06526394760502235, 0.08051516208797693, 0.06210261224103825, 0.03996158032012837, 0.08368902999375548, 0.04498929410640683, 0.02187464416160115, 0.10320733407778399, 0.13915250955947808, 0.004743380896148405, 0.015529775160497852, 0.06570027276341404, 0.012153736049575465, 0.05262876721099019, 0.035895879912589274, 0.06905122473835945, 0.09011759289673396, 0.05493196951491492, 0.10656855907291174, 0.06953166824366365, 0.23827503568359784, 0.0844818235241941, 0.1963339312268155, 0.08870994485914707, 0.09436885906117302, 0.11012733275336878, 0.2756458946636745, 0.3068862711744649, 0.20743115432560444, 0.12574110206748756, 0.20263017980115755, 0.16828888468444347, 0.1659547377909933, 0.11813521305365221, 0.17942619563213416, 0.14540123354111398, 0.12668404861220292, 0.23290646661605152, 0.17491157645625727, 0.16874709938253674, 0.255442487342017, 0.2605973450200898, 0.19404264060514315, 0.19746973099453108, 0.1815767173788377, 0.28745473814862116, 0.13922941471849168, 0.1563796858702387, 0.1676486733236483, 0.2898991469826017, 0.26800626888871193, 0.13128158476735863, 0.19843718622412, 0.26203925907611847, 0.423535126128367, 0.16412124117570265, 0.33373636326619555, 57.09944486618042, 142.15939276559013, 92.2674150466919, 94.79517664228166, 81.41838659558977, 98.03035518101284, 133.2068473270961, 84.54431165967668, 84.4032632282802, 87.50316728864397, 59.75810704912458, 38.02944680622646, 35.88664320537022, 25.20483010155814, 17.67968784059797, 15.585815191268921, 15.77985405921936, 11.014215792928423, 13.114268864904131, 13.287391918046133, 13.858736208506993, 16.88666214261736, 23.313855273383005, 22.196532828467234, 28.65146664210728, 43.05394976479666, 43.770958696092876, 34.94370664869036, 52.677482741219656, 26.06846513066973, 25.782074281147548, 26.49813825743539, 14.353118777275085, 28.380160331726074, 24.04337443624224, 12.784204244613647, 4.178284892014094, 1.7466152544532503, 1.208164170384407, 0.6969532817602158, 0.4767376727291516, 0.2443456713642393, 0.12880946456321649, 0.12072701326438359, 0.1660366641091449, 0.29791506113750593, 0.25227090609925135, 0.20858751370438508, 0.23189824500254222, 0.23708529238189968, 0.16603160223790578, 0.3488210652555738, 0.2162785588630608, 5.632318777697427, 4.733199298381805, 0.5349951152290616, 0.18985655451459543, 0.22722586643482956, 0.08925661338227135, 0.26187939622572487, 0.1320266162178346, 0.10301634682608501, 0.22050138083951815, 0.07543015959007399, 0.11640667223504611, 0.19288012012839317, 0.20261019015950815, 0.15793957002460957, 0.28339310895119396, 1.1968205847910471, 1.7755636210952486, 3.1697477868625095, 2.0614734164306094, 7.392707858766828, 13.898843816348485, 30.067905562264578, 35.61034114020211, 20.59113417352949, 21.47263823236738, 37.00112383706229, 35.145364216395784, 38.929346220833914, 29.714270046779088, 22.371875831059047, 14.225162489073616, 9.211394497326442, 10.605557492801122, 11.062373757362366, 14.319467782974243, 22.54842608315604, 30.94097798211234, 33.86492238725935, 25.2516314302172, 33.07558618273054, 52.56332731246948, 66.43202550070626, 77.046628679548, 89.77199731554303, 100.71984304700578, 82.7252037865775, 60.56609916687012, 53.92222820009504, 67.31383528028215, 79.5471533366612, 86.0971576145717, 15.153178657804217, 0.28240334349019186, 0.22679163116429532, 0.3771008849143982, 0.40586311583008083, 0.16594320269567625, 0.1380891501903534, 0.08289833992187466, 0.13069607689976692, 0.12273475767246314, 0.25018883496522903, 0.13507266848215035, 0.17485452523188932, 0.2276704968618495, 0.1119509973962392, 0.1938607253666435, 0.20222668216696807, 0.11508005484938622, 0.23074248273457798, 0.13984481883900507, 0.10823313439530985, 0.3256779999605247, 0.22437493370047637, 0.19044716496552738, 0.11899008575294699, 0.14962560257741384, 0.06441517493554524, 0.22110747545957565, 0.23007977115256445, 0.1936491581478289, 0.1357272919267416, 0.16115501177098068, 0.25555862539580887, 0.220242709719709], [0.04355593976963844, 0.0007733748123947797, 0.0164695275016129, 0.07290379051119089, 0.010142281751281448, 0.056306929127978425, 0.041863734501280954, 0.09061295060174805, 0.057551223252500804, 0.06382100896111556, 0.07063177706939833, 0.054152994350131066, 0.03811828905184354, 0.034195457585155964, 0.05207696557044983, 0.026581929963348166, 0.002717777870462409, 0.11938937647002083, 0.030820919732962335, 0.013897604126084064, 0.05098991175847394, 0.023414913564920425, 0.0512430053204298, 0.06852683930524758, 0.07462066052747623, 0.021569795341097882, 0.08826615581555025, 0.031070800431604897, 0.023231291810848882, 0.05199112749791571, 0.14764323537903173, 0.04431413479947618, 0.03651053425190704, 0.020345334795170596, 0.1172503355358328, 0.17393002126898083, 0.09834274010998861, 0.20616312165345463, 13.102197238377162, 104.54629938943046, 93.23203345707485, 74.31654248918805, 61.312300954546245, 62.415070397513254, 106.295654296875, 96.13597747257778, 74.44795376913888, 64.0000170298985, 36.64599098478045, 35.10531479971749, 45.285884857177734, 36.04505865914481, 19.582776853016444, 13.107972059931074, 14.83859201839992, 8.92638807637351, 6.246440955570765, 5.0796008706092834, 2.2737397977284024, 8.637998751231603, 7.399504065513611, 1.1414033813135964, 7.631791029657636, 11.103982176099505, 11.266767178262983, 18.07702578817095, 19.076822928019933, 18.48005257334028, 16.835863862718853, 9.361282774380275, 6.153392851352692, 8.29265764781407, 9.323852828570775, 1.9226944403988975, 0.17637867773217814, 0.7009218430944851, 0.16655943462891237, 0.39829270062702044, 0.07204409342791353, 0.046917724556156566, 0.06718428991734982, 0.0064793779664406815, 0.043838624243757555, 0.14466621726751328, 0.07356218661048583, 0.038962417149118016, 0.1100324939138123, 0.03497557947412133, 0.02137599895442171, 0.03716764113466654, 0.5938340893813542, 0.34464164237890926, 0.1633028600897108, 0.0643114201458437, 0.04645024785505874, 0.04000751035554068, 0.06394670078796999, 0.015427012728261096, 0.15463011046605452, 0.031052446059350456, 0.0868167710889663, 0.050422907540840764, 0.1134099562519363, 0.03335138037800789, 0.1800255998969078, 0.1820122825780085, 0.157718652593238, 0.32378746569156647, 0.23273900417344912, 0.5057946049741336, 1.6271389169352395, 8.10326017652239, 8.78123412813459, 10.86301256929125, 10.067396061761038, 9.667469910212926, 6.265129438468388, 9.687521542821612, 8.817613158907209, 9.585375206811086, 14.3106609412602, 16.640508311135427, 12.688664776938301, 15.19268958909171, 22.418553829193115, 24.199163470949443, 28.41537206513541, 29.28244297845023, 31.65652779170445, 50.083136558532715, 62.72740582057408, 76.07055963788713, 83.44757325308663, 81.30340780530656, 70.18633869716099, 39.15775087901524, 38.455242838178364, 45.7967198916844, 57.866755281175884, 66.52121952601841, 38.91757249832153, 4.01369856936591, 0.10436030078147139, 0.018092410239790167, 0.05164659455684679, 0.01842142847765769, 0.04285280107121382, 0.042383041099778244, 0.05529813075970326, 0.06336664155657802, 0.0353119564242661, 0.015278267674148083, 0.03152400075591036, 0.05172124358692339, 0.07475615718535014, 0.03417085051270468, 0.03776329310078706, 0.058678249562425275, 0.061282589100301266, 0.04572087699281318, 0.06499655731022358, 0.04084818470957024, 0.06750847359320947, 0.08762703689613513, 0.049872788667146645, 0.04690837434359959, 0.03457616322806903, 0.030582153437925235, 0.01481117434533579, 0.03289724706805178, 0.00979946380747216, 0.02481001379367496, 0.032273948192596436, 0.03788733948022127, 0.03260198255468692, 0.05084360603775297, 0.028210273212088004, 0.02543927020659404, 0.012672610081998366, 0.09221807947116238, 0.06404585511024509, 0.04787124267646244, 0.05422856618783303, 0.09810427576303482, 0.07483844991241183, 0.05460220828120198, 0.09496269933879375, 0.05540343939459749, 0.017968565724524002, 0.033577661628701856, 0.08811526998345341, 0.07677342143974134, 0.028863621010844196, 0.04083337229011314, 0.01738975160489125, 0.06094317909862314, 0.006022361730824092, 0.02448618974137519, 0.07335101972733225, 0.053417319897562265, 0.043988190325243134, 0.018071229769183055, 0.06690951037619795, 0.038089912717363665, 0.08257122497473444, 0.062074066272803714, 0.126115015574864, 0.06482573611927883, 0.06368197035044432, 0.04670180792787245, 0.10183356529367821, 0.08110672248793499, 0.19598509637372835, 1.9226015082427432, 62.091888836451936, 105.12534836360386, 87.65216445922852, 71.4198384966169, 86.95093836103166, 100.84690475463867, 95.01262746538434, 81.73903901236397, 67.9250613621303, 57.177758012499126, 51.56809513909476, 57.353557859148296, 63.63527829306466, 42.36906235558646, 27.632148538316997, 29.704778807503835, 30.987034116472515, 23.648254701069423, 25.160797630037578, 27.064461605889456, 25.16706316811698, 26.52530918802534, 19.851105860301427, 14.256826298577444, 22.263812235423497, 28.669596229280742, 27.642197370529175, 36.48831898825509, 26.87945192200797, 21.820503268923076, 15.910678216389247, 11.901522466114589, 13.24618215220315, 14.818902560642787, 10.293090053967067, 2.916367828845978, 0.5498259908386639, 0.3494378264461245, 0.305897021400077, 0.5393487587571144, 0.19029034195201738, 0.014456738185669695, 0.04436646681278944, 0.020450444958571876, 0.024206865711935928, 0.08177449594118766, 0.013580513685675604, 0.07067976985126734, 0.07788467859583241, 0.009048557091903473, 0.07079790279801403, 0.06536747847816773, 0.9093686150653022, 1.12186113851411, 0.06185447198471852, 0.14635747937219484, 0.037268698747668944, 0.013564752165361174, 0.051294546840446334, 0.02262047289072403, 0.038117037154734135, 0.06205867709858077, 0.05877753959170409, 0.05847277558807816, 0.09493297271962677, 0.10107425746640988, 0.12834701580660685, 0.18879449793270656, 0.3401744392301355, 0.9186681274856839, 1.1829026916197367, 1.6968442222901752, 3.5670014875275746, 10.619057842663356, 16.1102773802621, 14.558553559439522, 9.28224962098258, 14.091800502368383, 9.276951619556971, 10.982685736247472, 17.31552059309823, 21.055188723972865, 23.977062565939768, 21.923836878367833, 19.591284922191075, 22.236495392663137, 28.184224605560303, 37.15415096282959, 41.312376839774, 41.644740445273264, 47.60274430683681, 55.847299575805664, 62.400235993521555, 65.65099239349365, 73.76508481161935, 76.46277850014823, 81.28502982003349, 72.61366408211845, 56.445907729012625, 42.12856783185686, 51.844925267355784, 72.39298234667096, 63.62346635546003, 15.90842352594648, 0.246179425822837, 0.07296108600816556, 0.09988913498818874, 0.08290848402040345, 0.02290585114886718, 0.022953187448105643, 0.00786142360552081, 0.06409667059779167, 0.013903358103042203, 0.03300985334707158, 0.03476131507860763, 0.013702604187918561, 0.02686091642161565, 0.00805465511179396, 0.028035326528229883, 0.03569585457444191, 0.03251862792032106, 0.03401632773290787, 0.03704571517716561, 0.025127084726201634, 0.025988773309758732, 0.06876892024385077, 0.047080287975924354, 0.07549138380480663, 0.06650622987321445, 0.03409629987020578, 0.018960086894886832, 0.10721407657755272, 0.00854393229487219, 0.04736581211909652, 0.041138719833855114, 0.15399156830140523, 0.024333836577300514, 0.03692470524193985, 0.1987988996718611, 0.15051761828362942, 0.07496380247175694, 0.17834125884941646, 0.16528871495808872, 0.16225509345531464, 0.07696922629007272, 0.14109516888856888, 0.1844855970037835, 0.11209359831575837, 0.1670691772763218, 0.147379339539579, 0.12194916339857237, 0.17835531809500285, 0.1384874638170004, 0.1922358918402876, 0.08621782144265515, 0.15433091723493167, 0.12782296964100429, 0.16665869073144027, 0.18228023605687277, 0.1021916689351201, 0.1602456255682877, 0.19297173592661107, 0.18357813784054347, 0.1580219848879746, 0.20008423498698644, 0.1866010927728244, 0.18517772986420564, 0.24724355872188294, 0.225096229996, 0.0810517000832728, 0.1932558656803199, 0.0767251436731645, 0.2146163380571774, 0.15797834151557513, 0.21354106361312525, 0.2983871858034815, 36.51488889966692, 136.81280953543526, 105.49969645908901, 92.3227435520717, 87.68286160060337, 81.83937100001744, 122.73132623944963, 116.53587463923863, 88.41796016693115, 85.50883279527936, 55.84806735174996, 54.836746624537874, 71.72512149810791, 57.447386332920615, 37.86275952202933, 34.861276694706504, 36.47478042330061, 23.487662724086217, 22.659161261149816, 27.578374692371913, 24.395997251783097, 27.633711882999965, 22.686155012675695, 16.476530824388774, 23.601291826793126, 26.74698277882167, 20.929283891405376, 30.56596633366176, 29.179863248552593, 34.761893136160715, 33.47480535507202, 21.959637471607753, 15.25718103136335, 17.081359352384293, 14.710420336042132, 4.58224447284426, 0.6326735966971943, 1.5147434451750346, 1.5159779446465629, 1.1181228991065706, 0.45413800541843685, 0.2179702009473528, 0.21842236311307975, 0.06486067388738904, 0.3171473762818745, 0.20975198836198874, 0.13967010964240345, 0.17972500888364656, 0.17357098124921322, 0.06427195654915911, 0.23681211418339185, 0.2644981342766966, 3.744309093270983, 1.6115331543343407, 0.41808475287897245, 0.24596218605126652, 0.2076361533254385, 0.1041560685262084, 0.138829146910991, 0.18667361459561757, 0.23611487873962947, 0.11345981500510659, 0.1580388939806393, 0.17513264316533292, 0.2926123913909708, 0.1731789508568389, 0.4582342399018151, 0.4678909331560135, 0.5414069997412818, 0.7227167678730828, 1.1926903149911334, 2.153807593243463, 2.4557361347334723, 13.085394757134573, 13.582990867750985, 16.23472830227443, 26.089320148740494, 21.326416867119924, 10.253150939941406, 16.893813576017106, 20.543406997408184, 22.379617861339025, 34.93927369798933, 34.34177725655692, 28.89151300702776, 30.864273343767437, 40.507223061152864, 44.966896533966064, 44.82350655964443, 41.90062870298113, 47.189277853284565, 69.70794132777623, 85.67471408843994, 89.0373295375279, 99.30590547834123, 96.72950649261475, 88.46299839019775, 61.55665520259312, 57.58841044562203, 60.21581268310547, 72.33865438188825, 85.931533404759, 62.293053082057405, 6.664101081235068, 0.24614815892917769, 0.16561388250972542, 0.4036213718354702, 0.14986222130911692, 0.11052748520991632, 0.19400689538036073, 0.23558974691799708, 0.15795208221035345, 0.10679846709328038, 0.14937085339001246, 0.0676296463768397, 0.11229711810925178, 0.23779238015413284, 0.14197487596954617, 0.11766375335199492, 0.11209182733935968, 0.14693006793303148, 0.08520561004323618, 0.10268550672169242, 0.22178728612405912, 0.25336421600409914, 0.24380705026643618, 0.06772208320243017, 0.14774994179606438, 0.21081285072224482, 0.14038004726171494, 0.07441909491483654, 0.17160185905439512, 0.0894240215420723, 0.13705257938376494, 0.11890125194830553, 0.30862986189978464, 0.1485057890947376, 0.21214320005050727], [0.10402420881603446, 0.0236999288068286, 0.012871856801211834, 0.022613953865532364, 0.09942589234560728, 0.03733555141038128, 0.029447815913174833, 0.06517389922269753, 0.11348602002752678, 0.07291969537202801, 0.049149443195866685, 0.0018106316814997367, 0.03583354629310114, 0.03720572391258819, 0.0369421503772693, 0.06323495826550893, 0.11422747559845448, 0.07088221077408109, 0.030426548394773687, 0.01393766822626016, 0.10403493645467929, 0.10337387371276106, 0.006982021441217512, 0.07147738098033837, 0.010201028465027255, 0.03192913026681968, 0.0217240348325244, 0.10180577249931437, 0.07002239155450038, 0.12197004870644637, 0.0508553379082254, 0.09332880058458873, 0.1599027482526643, 0.0361000918118017, 0.06625095142849854, 0.03938749898225069, 0.09319292394710438, 0.2060341321464096, 0.03626033464180572, 19.600017070770264, 100.13142095293317, 95.0009822845459, 74.98252732413155, 56.37036691393171, 52.718327726636616, 84.83371107918876, 106.01631586892265, 111.97513266972133, 106.89379692077637, 68.1464935030256, 48.41291468484061, 32.5717271396092, 38.70589215414864, 33.309195041656494, 37.13519280297415, 26.926102127347672, 17.629304715565272, 16.96286998476301, 15.3655138696943, 18.08819501740592, 15.758939981460571, 11.790016906602041, 15.43920646395002, 13.733684267316546, 13.982431513922554, 19.3373247895922, 26.286485706056865, 18.625058003834315, 19.6190881388528, 16.368637459618704, 10.978696601731436, 6.5110969713756015, 2.5628940761089325, 2.6076954092298235, 0.9644676127604076, 0.4877820515206882, 0.31931849835174425, 0.3691623237516199, 0.32214291393756866, 0.08930786313222987, 0.10426719899156264, 0.10672303435525723, 0.09359348352466311, 0.06674912505384002, 0.062457764255149026, 0.09318562969565392, 0.1166185380092689, 0.042843973330621204, 0.03399125247129372, 0.032735816801765134, 0.7200731411576271, 0.5788240805268288, 0.08285360410809517, 0.11175190843641758, 0.08084322019879307, 0.04753316938877106, 0.016530230940718735, 0.04579095948221428, 0.07677844259887934, 0.03343048059780683, 0.04333798075094819, 0.06030645540782383, 0.09922020124005419, 0.041384780380342684, 0.4965720112834658, 0.5925616462315831, 1.0869980092559541, 0.27838595477598055, 0.46390065870114733, 1.9034815856388636, 2.397151746920177, 8.238818662507192, 8.886481097766332, 16.285682916641235, 17.014269283839635, 11.509767396109444, 13.273522445133754, 14.214552589825221, 14.242083958217076, 17.19868837084089, 23.409806421824864, 29.342002936771937, 30.829990931919642, 31.908274923052105, 44.28330496379307, 53.418257985796245, 56.82777030127389, 57.32084921428135, 68.37746552058628, 84.9334385735648, 89.09011500222343, 81.61973844255719, 61.59521075657436, 47.441122259412495, 35.64061791556222, 38.531176226479666, 50.95677873066494, 58.00540310995919, 57.417373589106965, 14.5618383203234, 0.1752067120479686, 0.11721383035182953, 0.02602459317339318, 0.06042827958507197, 0.024171329136671763, 0.10725010678704296, 0.07958022225648165, 0.08695412014744111, 0.0680528147412198, 0.13549713284841605, 0.04233407801283257, 0.08334446312593562, 0.11729886436036654, 0.05434861260333231, 0.02304644530106868, 0.025546667033008168, 0.048173299325363975, 0.04386945687500494, 0.009208943262430174, 0.042339489329606295, 0.05682110260905964, 0.05146648422149675, 0.026252713253987685, 0.1330261118710041, 0.08566602319478989, 0.07846057840756007, 0.030206418064023768, 0.02640115127100476, 0.07092888719801392, 0.03817970325638141, 0.11284317595085927, 0.010037557504672025, 0.0720201614978058, 0.09029218674238239, 0.0484608488955668, 0.11082714663020202, 0.050687129077102454, 0.03067954017647675, 0.012553375364015145, 0.011025887015940887, 0.04434973753190466, 0.040928916806089025, 0.03275831363030842, 0.09832389719252076, 0.1471181306988001, 0.10405308048107795, 0.03386134354929839, 0.0237641640207065, 0.054790528890277655, 0.014211984667261797, 0.07046807371079922, 0.06087112546499286, 0.012593933098417307, 0.041285317324634106, 0.04617901365937931, 0.05428528832271695, 0.07876169189278569, 0.03722888231277466, 0.04281203468729343, 0.023725139775446484, 0.011201670842378266, 0.012873442028649151, 0.0935126564332417, 0.06941367778927088, 0.1415632494858333, 0.10422547587326594, 0.09550138150474854, 0.044003922159650495, 0.02021036060926105, 0.005669594343219484, 0.05830417999199458, 0.0241711595029171, 0.2975717767008713, 0.15420314909092017, 0.8189184314438275, 58.48333495003836, 113.28281838553292, 93.80933148520333, 70.85086441040039, 68.5748985835484, 91.89083657945905, 101.64748314448765, 96.04213510240827, 77.27453654153007, 52.35330411366054, 51.43368918555123, 61.70144176483154, 61.172913142613, 61.827259744916645, 55.993798868996755, 54.60724762507847, 43.604538917541504, 35.67873920713152, 40.035280568259104, 35.60523074013846, 31.666877133505686, 30.118220942361013, 30.1089312008449, 36.26697717394148, 24.21722878728594, 25.192205224718364, 29.55029603413173, 24.522131374904088, 19.05500384739467, 20.645180736269268, 15.194437061037336, 11.72359994479588, 10.574719650404793, 10.54364730630602, 3.5756354928016663, 0.1365627720952034, 0.26845483481884, 0.7329657950571605, 0.08991350991917507, 0.07184562193495886, 0.019181898296145455, 0.05526833289435931, 0.05922934891922133, 0.0751900328323245, 0.07155700706477676, 0.015184626448899508, 0.022773530034880553, 0.020539626512410383, 0.008404468751645513, 0.04349643224850297, 0.046867417969873974, 0.5793074145913124, 0.5466089748910495, 0.4275593544755663, 0.06445086587752615, 0.0968985597469977, 0.08512213666524206, 0.018537994008511305, 0.05618798193920936, 0.03696990245953202, 0.04525502538308501, 0.051089364636157236, 0.08263740249510322, 0.07407730325524296, 0.03209705411323479, 0.07824630383402109, 0.21012424624391965, 0.3844369069806167, 0.6076582904372896, 0.46429410044636044, 2.0243363806179593, 2.930385385240827, 10.230468545641218, 10.834414652415685, 16.323102440152848, 18.860977138791764, 15.563084159578596, 13.312145744051252, 19.66767862864903, 22.02914377621242, 26.37352752685547, 36.7507107598441, 44.12000840050833, 43.374185289655415, 49.42128242765154, 60.73797675541469, 59.67330428532192, 59.26472936357771, 56.15275280816214, 57.33679533004761, 67.4994980948312, 77.78505543300084, 84.34950501578194, 81.21882043566022, 74.99349852970668, 61.60349300929478, 43.27527073451451, 52.61971194403512, 62.32376411982945, 70.3873153414045, 38.17446265901838, 2.9222533873149326, 0.24418640562466212, 0.025798235587509613, 0.10692229294883353, 0.028560505847313573, 0.11796652924801622, 0.12445736809500627, 0.07875009572931699, 0.021264851525692, 0.15282813858773026, 0.08509865256824664, 0.029818289248006682, 0.023513201058709195, 0.06773469716842685, 0.020649072514580827, 0.06190011025007282, 0.01684741722419858, 0.09110098691391093, 0.012919193948619068, 0.04143086987148438, 0.027627050311171582, 0.03457587145801101, 0.03984500800392457, 0.0622651960168566, 0.044510377304894586, 0.05513859699879374, 0.08058553295476095, 0.12491539280329432, 0.07409573226634945, 0.031871207124952755, 0.06947933962302548, 0.05158586228000266, 0.0564162343341325, 0.06285845275436129, 0.023882369909967695, 0.02793228080762284, 0.20792093447276525, 0.21617770141788892, 0.10698821941124541, 0.11743273931954588, 0.1964415604514735, 0.12241762397544724, 0.1341319339615958, 0.14006550556847028, 0.26663494961602346, 0.196352143106716, 0.10081315719123397, 0.10266708449593612, 0.1492605371666806, 0.08762023118989808, 0.08119863684156112, 0.0881736579218081, 0.19739486144057342, 0.14314602741173335, 0.18393628219408648, 0.11650754325091839, 0.19704096471624716, 0.2037841643073729, 0.17752850960407937, 0.1449841923479523, 0.07631856548999037, 0.21277377621403762, 0.2489074622946126, 0.31678161876542227, 0.16034680871026857, 0.3576936705836228, 0.24208047719938414, 0.23292690409081324, 0.19797359752867902, 0.17024127420570168, 0.22365567301000866, 0.10891358966806106, 0.36384084501436775, 0.25357423616307123, 0.19368940884513514, 33.164537021092, 135.37611661638533, 111.39130333491734, 88.69870213099888, 75.85210827418736, 76.798980985369, 101.05937371935163, 125.0163803100586, 128.5774710518973, 118.45184734889439, 83.8785422188895, 65.77206475394112, 53.69609907695225, 62.25034250531878, 54.35547617503575, 55.98129905973162, 48.30692686353411, 35.80298689433506, 37.34765829358782, 32.738060065678184, 34.17376981462751, 35.16801881790161, 37.18413243974958, 43.86769846507481, 33.37411553519112, 26.977713346481323, 34.80365180969238, 38.435072217668804, 25.079706941332134, 25.838936601366314, 23.186338458742412, 19.67703264100211, 14.182953919683184, 10.375195179666791, 4.354640594550541, 0.6730735717075211, 1.1401921148811067, 1.6666420314993178, 0.9683876995529447, 0.5297479225056512, 0.0991399712594492, 0.15681877945150646, 0.30069841178400175, 0.20256140349166735, 0.1573303270020655, 0.13976595949913773, 0.21081815686609062, 0.23349880054593086, 0.1914410830608436, 0.14815026388636657, 0.2252130058727094, 1.805372912968908, 1.9656323535101754, 0.42836795108658926, 0.208914581154074, 0.15894931155656064, 0.21352526731789112, 0.15358775854110718, 0.1591042618134192, 0.1645670115415539, 0.1386514250189066, 0.14184405441795075, 0.19475420670849936, 0.41533682176045006, 0.16271458379924297, 0.8797592467495373, 1.7553099478994096, 1.6206456082207816, 1.7735280160393034, 0.7468805941087859, 4.850134875093188, 5.591623178550175, 14.916660240718297, 15.444916146142141, 25.535281215395244, 30.615569523402623, 23.635364055633545, 26.5960887500218, 30.36399609701974, 28.477052961077007, 38.84485265186855, 45.5508439881461, 44.687387875148225, 46.781859806605745, 43.78049857275826, 59.20974131992885, 65.87334864480155, 69.38573946271623, 72.60797350747245, 81.548109463283, 96.5264731815883, 102.28478581564767, 99.19947297232491, 80.78048637935093, 70.97635582515171, 61.88301903860909, 57.15532922744751, 69.37352452959333, 78.18249934060233, 80.0601874760219, 29.853355612073624, 0.6623010411858559, 0.5586253415260996, 0.15801019194935048, 0.295359589691673, 0.15698035221014703, 0.36289268732070923, 0.18747306455458912, 0.1360115438167538, 0.1126086131802627, 0.3043464060340609, 0.13255410934133188, 0.17432148169193948, 0.1672727513526167, 0.2587742299905845, 0.10898583329149655, 0.1928849784391267, 0.12027510894196373, 0.1873926038720778, 0.09924787189811468, 0.20186609508735792, 0.11241836553173405, 0.2186901266021388, 0.1387369611433574, 0.30682343883173807, 0.15289330509092125, 0.08575797147516694, 0.24251737232719148, 0.17066013387271337, 0.10962159346256937, 0.13594705584858144, 0.19646122439631394, 0.0804597529183541, 0.15588196686335973, 0.2278601745409625, 0.10671012183385235, 0.13606106330241474], [0.019166962044047456, 0.061709509763334475, 0.024456254472689967, 0.02350294160922723, 0.042781850056988854, 0.06714620374675308, 0.04835267345021878, 0.1282485332340002, 0.06456039500023637, 0.09311273467860051, 0.013184772554918059, 0.12567869041647228, 0.08507086655923299, 0.0584623125780906, 0.01832039630971849, 0.029617334316883768, 0.03925102184127484, 0.1129257468772786, 0.03479391529357859, 0.009148060859713172, 0.14198347979358264, 0.09885454550385475, 0.12180293910205364, 0.14671964065304824, 0.013697264117321797, 0.041497217025607824, 0.09265998218740736, 0.055990548604833226, 0.09472063197089092, 0.04251576254942587, 0.07169947906264237, 0.05682279894660626, 0.09529304411262274, 0.07412195085947003, 0.030830548144876957, 0.06872364838740655, 0.0709343154781631, 0.13086538495762007, 0.10966152524841682, 0.06886367087385484, 8.290697387286595, 76.768388066973, 110.92965807233537, 94.02177265712193, 66.79511056627545, 47.16405936649868, 51.627519607543945, 72.65261568341936, 101.95898478371757, 111.40609604971749, 102.5836625780378, 82.9415567943028, 69.13900198255266, 54.60041407176426, 56.93427228927612, 49.92272697176252, 35.1279103415353, 30.01349421909877, 23.7257080078125, 28.261445147650583, 32.78736795697893, 31.306091921670095, 29.375170162745885, 18.064647572381155, 17.731163569859095, 27.00916610445295, 35.35422706604004, 17.193819420678274, 12.920694657734462, 6.408634926591601, 4.12644134249006, 3.8451951997620717, 5.634397157600947, 2.7293965816497803, 2.1375025595937456, 0.6901555550949914, 0.7195262419325965, 0.21092909734163964, 0.27248202157872065, 0.17273750954440661, 0.048262519894966056, 0.04563507963238018, 0.17750147676893643, 0.09037293919495173, 0.17020263842173985, 0.09506044909358025, 0.1289543860724994, 0.09043061467153685, 0.09301092728440251, 0.10134890130055801, 0.45471940136381556, 0.9451210051774979, 0.032089603798730035, 0.05448831957099693, 0.06890442368707486, 0.03459120974210756, 0.13222729973495007, 0.0770356005855969, 0.12936412622886045, 0.08727724530867167, 0.0036209961898358805, 0.10560439473816327, 0.061304471854652674, 0.21179199032485485, 0.26668665398444447, 0.8007431924343109, 0.3278962123606886, 0.4762993391071047, 1.638797777039664, 4.194647031170981, 2.7552060995783125, 11.761474575315203, 2.328099463667188, 16.266351291111537, 33.545812470572336, 35.52941199711391, 35.49818679264614, 40.94504295076643, 53.01798963546753, 49.61709656034197, 56.36256408691406, 62.88332339695522, 62.23415320260184, 63.09788376944405, 62.81688472202846, 60.843325342450825, 75.04494994027274, 70.76434544154576, 73.51638793945312, 62.03999968937465, 60.1749711717878, 53.02735928126744, 46.48693309511457, 48.0328551701137, 45.53290373938424, 52.48223488671439, 63.56974983215332, 39.56658288410732, 5.501054712704249, 0.19280256357576164, 0.1449551781905549, 0.1568215207329818, 0.07799833321145602, 0.08597308064677886, 0.04441381837906582, 0.044118285844368596, 0.03306818360994969, 0.08018945849367551, 0.0865075694663184, 0.036891317926347256, 0.041293493671608825, 0.07025008755070822, 0.033922849356063774, 0.11955432833305427, 0.09187029634735414, 0.0303245306547199, 0.10554790669786078, 0.033027396869978735, 0.06380284457866635, 0.03061610393758331, 0.20775381129767212, 0.09388183376618794, 0.024225330346130898, 0.10540807420121771, 0.044642600031303506, 0.028561208131057874, 0.001716755619522051, 0.029243366526705877, 0.09647568993802581, 0.0735049182549119, 0.005981183136879865, 0.04870374746886747, 0.04787580243178776, 0.14886997240994657, 0.024147532913567762, 0.07291952573827334, 0.025241115928760598, 0.058620329813233445, 0.062097224672990184, 0.02433986196826611, 0.01413199132574456, 0.033710858052862544, 0.05118041725030967, 0.08427976258099079, 0.009736539014349026, 0.027074186763327037, 0.042654170122529776, 0.023803108538101827, 0.03981179032208664, 0.014863823573770267, 0.02420159858385367, 0.00832520313893578, 0.04018944255741579, 0.11019830073096923, 0.019005655610401715, 0.03754496767318674, 0.0958567913621664, 0.04933336011267134, 0.05872642554874931, 0.01889654209039041, 0.07267068659088441, 0.04545831447467208, 0.08087530133447476, 0.09732919878193311, 0.10179653085236039, 0.10810220427811146, 0.090870122159166, 0.05980338275964771, 0.09922271860497338, 0.030862758202212195, 0.03469132758410914, 0.08127098224524941, 0.026903162011876702, 0.24946945213845798, 0.11951229987399918, 1.9707401479993547, 37.60477638244629, 100.6730955668858, 99.43883841378349, 75.15071541922433, 65.93097005571637, 79.8597388948713, 95.0796150479998, 102.65392971038818, 104.81344372885567, 82.68511962890625, 69.70785100119454, 61.984143120901926, 63.72750173296247, 59.51761599949428, 65.83849648066929, 62.85534300122942, 51.018878255571636, 37.55950539452689, 35.43759502683367, 40.79012591498238, 45.7631322996957, 45.92576878411429, 42.36345168522426, 34.49034711292812, 32.468699250902446, 35.3937657901219, 37.555353845868794, 27.911896909986222, 25.216747999191284, 18.576312916619436, 14.838244608470372, 13.197314602988106, 9.754752312387739, 6.205883886132922, 4.315272101334163, 1.2418782413005829, 0.5462052736963544, 0.00998019500236426, 0.3030683174729347, 0.12415882625750133, 0.036335329724741836, 0.029094224529606954, 0.12846141681075096, 0.08433775018368449, 0.05131212429010442, 0.029329479405922548, 0.035717510019562075, 0.1019245907664299, 0.12411135594759669, 0.02988727590335267, 0.47640187931912287, 1.7653912412268775, 0.27089921651141985, 0.05090607197156974, 0.05172300777797188, 0.0624306635665042, 0.015105728093268616, 0.06440910204712834, 0.05346379615366459, 0.009421279770322144, 0.10766362638345786, 0.06491552665829659, 0.08680104264723403, 0.04008261739675488, 0.7393293135932514, 0.9101329169103077, 0.4381513403994696, 0.6545572738562311, 0.8370963845934186, 2.756743388516562, 5.513304386820112, 13.538550189563207, 8.930063673428126, 18.94667100906372, 26.230794157300675, 19.67527822085789, 25.431999717439922, 30.459613731929235, 36.49090371813093, 44.31842810767037, 49.72300100326538, 48.41149377822876, 46.62086657115391, 45.5158737046378, 53.96811410358974, 63.694469996861045, 74.68164948054722, 77.7448045185634, 79.32107285090855, 79.99338749476841, 83.03095926557268, 77.11092036111015, 62.54795469556536, 55.51482479912894, 50.631707259586875, 61.4825804574149, 73.92417771475655, 56.67768573760986, 21.8625259740012, 0.48189014196395874, 0.07667965468551431, 0.12460505802716527, 0.12595279142260551, 0.06436335521617106, 0.04624167976102658, 0.04904280123966081, 0.029662446717598608, 0.06709462151463542, 0.029000339031751667, 0.01358769937152309, 0.03725389989891222, 0.01890000601166061, 0.05764119699597359, 0.06369696597435645, 0.06637402411018099, 0.045759699373905144, 0.02440778841264546, 0.06207498229507889, 0.034132265618869236, 0.07928185683808156, 0.14400931394525937, 0.01600123486215515, 0.06193303276917764, 0.05369859980419278, 0.006010124775847154, 0.024132703530735204, 0.023906858238790716, 0.01153977636048304, 0.06517301712717329, 0.012322553865877646, 0.04517695992918951, 0.062483501088406355, 0.03545935797904219, 0.06660943504955087, 0.057280134941850386, 0.08696548560900347, 0.07607027595596653, 0.16979614166276796, 0.20927822164126805, 0.09134731548173086, 0.15953027323952743, 0.12449243478477001, 0.13345979074282305, 0.1778531614691019, 0.11633957869240216, 0.1319082389984812, 0.11050778733832495, 0.20823870599269867, 0.09796648565679789, 0.15389333000140532, 0.11127841991505452, 0.07308970232095037, 0.09488139048750911, 0.28205191663333345, 0.14039243731115544, 0.1017471267176526, 0.22094050156218664, 0.19691972407911504, 0.22002293222716876, 0.25545366959912436, 0.15275499251271996, 0.13992116759930337, 0.24422817624041013, 0.1797784095896142, 0.17708693258464336, 0.3506240142243249, 0.3046299251062529, 0.21437653021088668, 0.1244976595044136, 0.16896737899099076, 0.1683726023350443, 0.14488754181989602, 0.14840185110058102, 0.5033757090568542, 0.1568200143852404, 0.31468394132597105, 15.98973308290754, 107.83441625322614, 133.0762072971889, 103.66018867492676, 86.23586450304303, 70.48918982914516, 77.4165368761335, 89.98272228240967, 119.75456510271344, 127.55395971025739, 119.96327509198869, 104.39682974134172, 92.76578848702567, 76.28869833265031, 80.8567567552839, 73.7884099142892, 57.90232310976301, 44.72515133449009, 39.638833727155415, 44.881211348942344, 54.43797561100551, 50.417310169764924, 47.62966857637678, 30.923579692840576, 30.95361328125, 41.757745947156636, 55.370819909232004, 36.42789397920881, 33.05307749339512, 20.687926054000854, 16.31809973716736, 14.169556924274989, 15.228637831551687, 12.023731725556509, 5.473925037043435, 1.6576533424002784, 1.5914228963000434, 0.46806317248514717, 1.412206164428166, 0.34853618911334444, 0.1446017971528428, 0.10250458214432001, 0.25345991658312933, 0.25656245010239737, 0.3996272975844996, 0.21017785051039287, 0.1572439766355923, 0.2721649557352066, 0.23850755606378826, 0.11802234553865024, 0.7024210255060876, 2.614732197352818, 0.2593712593827929, 0.1759197844990662, 0.20299433597496577, 0.14896918780037335, 0.1690306184547288, 0.2073391992598772, 0.1648247055709362, 0.22650520796222345, 0.1937924511730671, 0.20467957268868173, 0.27708398178219795, 0.5957631372979709, 1.274408404316221, 1.9080452493258884, 1.1503396332263947, 1.2026691223893846, 2.6247376033238004, 6.579465074198587, 8.650481190000262, 20.884497540337698, 8.478737354278564, 25.714001042502268, 47.19804300580706, 54.298740659441265, 57.78628124509539, 65.56898280552456, 83.32517378670829, 72.88190623692104, 69.92749745505196, 71.32785824366978, 73.13231236594063, 77.77312537602016, 79.12618282863072, 81.94314929417202, 95.8083838054112, 88.88012654440743, 90.78165394919259, 81.04710265568325, 82.29001031603131, 73.60708972385952, 64.35527147565568, 65.25088037763322, 66.86065987178257, 80.8998772757394, 91.78028379167829, 56.91205889838082, 12.219881977353777, 0.14365449441330774, 0.15558950469962188, 0.1810027038944619, 0.12409587177847113, 0.24204942743693078, 0.138386552089027, 0.16720557638577052, 0.0785376735563789, 0.11152685872678246, 0.18464639623250279, 0.09470094088464975, 0.15808370443327086, 0.12626890731709345, 0.1632795049143689, 0.14317387448889868, 0.19082945159503392, 0.1287954053176301, 0.3124368233340127, 0.14058265781828336, 0.17578870510416372, 0.17997279630175658, 0.2534818196935313, 0.17836880737117358, 0.12564688069479807, 0.15810530898826464, 0.10036310526941504, 0.09743439885122435, 0.08942318015864917, 0.1896169502288103, 0.2598596146064145, 0.11954279323773724, 0.11514926542128835, 0.1850467047521046, 0.12234949905957494, 0.22696301553930553, 0.17417155259421893, 0.2202520870736667], [0.06818804677043643, 0.08900654608649866, 0.06807197657014642, 0.05015176834006395, 0.11002813771899257, 0.025436937742467438, 0.05997712165117264, 0.004622117358459426, 0.025169722170435956, 0.0961116762565715, 0.044554855275366984, 0.057081215615783415, 0.01976539770008198, 0.003353385371156037, 0.010762487355220531, 0.07842577634645359, 0.036657226737588644, 0.020040402854127542, 0.014042110880836844, 0.03891110633100782, 0.12054691649973392, 0.030973617253558974, 0.0027551770243527634, 0.0645734296579446, 0.10954103778515543, 0.03798297220574958, 0.10017627743738038, 0.08264943970633404, 0.0336228249195431, 0.06464276915150029, 0.06579765610929046, 0.06754548089312655, 0.1019385007343122, 0.10061339648174387, 0.08946892698960644, 0.05821625542427812, 0.10322749335318804, 0.17073615693620273, 0.11758820526301861, 0.06888801671032395, 0.08353388296174151, 2.2355368648256575, 43.349571296146934, 110.5449641091483, 99.68212958744594, 79.60284314836774, 56.76099116461617, 35.19133697237287, 36.626963342939106, 58.46818787711007, 77.67117445809501, 85.20945576259068, 91.75001049041748, 90.74693380083356, 81.26886136191231, 80.44653511047363, 79.35366685049874, 63.546119008745464, 51.34598207473755, 50.047763279506135, 54.082450185503276, 51.61776781082153, 43.87181527273995, 39.43658208847046, 39.333932876586914, 49.06736898422241, 59.257892336164204, 64.92105633871896, 53.82505416870117, 43.25155305862427, 30.22624111175537, 29.2135237966265, 27.046253851481847, 19.535843508584158, 9.20240787097386, 3.345650336572102, 1.3718356106962477, 0.2626385683459895, 0.8857533165386745, 0.17758338951638766, 0.010561556172823268, 0.0458265927487186, 0.06453905507389988, 0.11378218020711627, 0.17799264112753527, 0.0907819126067417, 0.10131305429552283, 0.1115494810843042, 0.01585394865833223, 0.12973581414137567, 0.7151719470109258, 0.2607990599104336, 0.05961909943393298, 0.15055283425109728, 0.08154145987438303, 0.053084844523774724, 0.07436451355793647, 0.10771568359008857, 0.04653122422418424, 0.07258057035505772, 0.12112665681966714, 0.14017331121223314, 0.2950156538614205, 0.17648162506520748, 0.2822436977710043, 2.399140885898045, 3.0912863399301256, 5.647719894136701, 7.295658026422773, 9.194939426013402, 20.50069120952061, 16.5530617577689, 9.053250891821724, 27.967041288103374, 34.525414671216694, 54.5835542678833, 68.0246637889317, 82.26997171129499, 82.31608690534318, 82.82252720424107, 74.02220984867641, 66.33686992100307, 58.488038880484446, 45.38614041464669, 43.41012832096645, 50.52238082885742, 53.26527254922049, 46.58997140611921, 40.23069517953055, 48.06230510984148, 52.38996628352574, 54.826560565403526, 54.12404557636806, 55.920780250004356, 56.24234288079398, 41.84663772583008, 8.929984637669154, 1.204583785363606, 0.3287538806242602, 0.10840006758059774, 0.17064270909343446, 0.03113697116662349, 0.012099611007475426, 0.06585704827947275, 0.05696117598563433, 0.033733527907835584, 0.010985089249775877, 0.0581052199538265, 0.031076337277357067, 0.05495763849467039, 0.04455847865236657, 0.0372651059047452, 0.03266045870259404, 0.05488867898072515, 0.032920948296253166, 0.09081447550228663, 0.06278099119663239, 0.03600783819066627, 0.09632945885615689, 0.0796808557850974, 0.027654977116201605, 0.0747649102870907, 0.11018758666302476, 0.11913519725203514, 0.1510993263551167, 0.09717445208558015, 0.010465900546738079, 0.04876213540722217, 0.13694836997560092, 0.05673289984198553, 0.04184012148263199, 0.03472982087571706, 0.05669249986697521, 0.07100187720996992, 0.06398197103823934, 0.13570154830813408, 0.07232065751616444, 0.05108407545568688, 0.07077300734817982, 0.09224164499236004, 0.011267353032183434, 0.03319516804601465, 0.06970977011535849, 0.056264164458428106, 0.04263416351750493, 0.06091687908130033, 0.04573389468714595, 0.029291091287242513, 0.036402565759739706, 0.036452974126275094, 0.0043969501774492005, 0.0068480832934645665, 0.03627638878034694, 0.015815594466403127, 0.006141303406496133, 0.017823101387226155, 0.08328477240034513, 0.07048959684159074, 0.03280012495815754, 0.15722296919141496, 0.012492135034075804, 0.017207717622763345, 0.027102222133960043, 0.0746473880218608, 0.043640861819897375, 0.024625474320990697, 0.04870665499142238, 0.07696634930159364, 0.05260018053065453, 0.06991877247180257, 0.04648350964167288, 0.09089527545230729, 0.08623454054551465, 0.11509673324014459, 0.20574442483484745, 0.1936194518847125, 1.376421638897487, 17.314035415649414, 82.30697086879185, 112.23606531960624, 91.20608466012138, 65.43479224613735, 58.73457486288888, 61.41883768354143, 79.2784595489502, 91.16395773206438, 99.55499839782715, 91.81967312949044, 86.6945081438337, 82.9792229788644, 79.59229578290666, 83.8341223852975, 81.91344574519566, 75.55942930494035, 66.47669546944755, 65.99173900059291, 64.47272382463727, 65.77774143218994, 57.486449105399, 47.70315967287336, 39.77741207395281, 40.719924790518625, 49.59861087799072, 35.913907936641145, 32.961204937526155, 18.580688544682094, 11.799757412501744, 14.976979289736066, 14.26630972112928, 8.225456408091954, 9.182867799486433, 1.0558534690311976, 0.7010378454412732, 0.41829029470682144, 1.2719111783163888, 0.1465828615639891, 0.15622587555221149, 0.006570501826770071, 0.08594988831984145, 0.10617134467299495, 0.06275533578757729, 0.09164106007665396, 0.057801500894129276, 0.06755888874509505, 0.046780429780483246, 0.050240286625921726, 0.3452515910778727, 1.07322515973023, 0.21911490309451306, 0.20722239624176705, 0.10809862839856318, 0.06354217178055219, 0.05899037567100354, 0.016734950044857602, 0.02320969573754285, 0.030295058486184905, 0.1569565763430936, 0.09348727243819407, 0.09760454829250063, 0.08024731038936547, 0.48739903207336155, 1.7603068969079425, 2.2040189674922397, 2.44803101675851, 2.6258430182933807, 6.239703374249594, 11.346120817320687, 18.356449331556046, 11.574683547019958, 26.86086549077715, 40.18268660136631, 36.79991790226528, 37.881116662706646, 50.258859974997385, 58.41433933803013, 61.763252939496724, 65.18940271650041, 67.97704778398786, 69.06944356645856, 72.96210929325649, 67.0891444342477, 73.29095363616943, 77.19684178488595, 70.41524709974016, 70.54105118342808, 66.48742348807198, 65.26442241668701, 60.55075059618269, 58.065004757472444, 63.38486521584647, 69.7975800377982, 62.65861865452358, 29.341773646218435, 5.042789314474378, 0.5069968061787742, 0.23700633804712976, 0.07819204138857977, 0.05655279968466077, 0.02872388350910374, 0.03710186734263386, 0.054989950332258425, 0.013920601374203605, 0.03603992611169815, 0.0038219337334989435, 0.04142319903309856, 0.06254566846681492, 0.02764114857252155, 0.05176482249849609, 0.04957673705316015, 0.04674908824797187, 0.04018779032464538, 0.023620675916650465, 0.10915304467614208, 0.05374541532780443, 0.0845562316743391, 0.05524388527763741, 0.0895624291151762, 0.037314163986593485, 0.05580003632764731, 0.03975803677790931, 0.023533971015630022, 0.11650925315916538, 0.03585152068574514, 0.0251102333090135, 0.04444772477394768, 0.024929566574948173, 0.0195143702772579, 0.07966621978474514, 0.02677246768559728, 0.005283356943566884, 0.024341643122690063, 0.04309582517349294, 0.1657057154391493, 0.17283342725464276, 0.15353670556630405, 0.11062636133283377, 0.14959538062768324, 0.11432029918900558, 0.15899052577359335, 0.08374752649771315, 0.1349449817623411, 0.12272828444838524, 0.11182177718728781, 0.13819154112466744, 0.1546593281839575, 0.1412245383752244, 0.17038246377238206, 0.11593078848506723, 0.10616538035018103, 0.11630618119878428, 0.14057850518396922, 0.15892778842576913, 0.2647029975695269, 0.16273080078618868, 0.1557903510651418, 0.3325573408177921, 0.19716536732656614, 0.18990992807916232, 0.1747819355555943, 0.17337360898298876, 0.14579591022006103, 0.19947325491479465, 0.15603224879928998, 0.21083251466708525, 0.15808048817728246, 0.22246149208928856, 0.16363260096737317, 0.15594207149531158, 0.18305985922259943, 0.17871559304850443, 0.3258267348366124, 0.23397138661571912, 0.45660021901130676, 4.739547346319471, 65.06380013057164, 137.81008447919572, 123.10955837794712, 96.28110449654716, 75.72950731004987, 53.84819861820766, 61.57092680249895, 80.95980548858643, 98.82458986554826, 105.94451318468366, 109.14964076450893, 108.01759856087821, 101.87221567971366, 106.11707169669015, 106.00560174669538, 94.8677088873727, 84.05081585475376, 78.79457310267857, 77.23691204616001, 77.81386266435895, 64.10212080819267, 60.243654114859446, 59.462926728384836, 66.13551807403564, 74.80350003923688, 75.27927098955426, 68.2368061883109, 64.31863362448556, 52.51561055864607, 44.86778742926461, 37.99291317803519, 33.02098029000418, 16.08832802091326, 5.279429759298052, 1.6913767499583108, 1.5796801149845123, 1.7838481536933353, 0.7877690057669366, 0.38637662146772656, 0.14734847976693086, 0.34983474229063305, 0.22562533803284168, 0.32442751420395716, 0.2842414134315082, 0.23951735187854084, 0.2058339507452079, 0.18834507704845496, 0.15664826360132011, 1.088180614369256, 1.8219483835356576, 0.2357970800782953, 0.3477369291441781, 0.2088946457952261, 0.19689114418412956, 0.17487824681614125, 0.146760637738875, 0.23046832744564327, 0.16550739322389874, 0.3320761780653681, 0.28495487943291664, 0.4599765006984983, 0.31807645357080866, 0.3726438597909042, 3.068719676562718, 5.547987188611712, 11.05092660018376, 14.090044345174517, 15.830883366721016, 30.628996917179652, 28.06202142579215, 22.032600505011423, 49.637124742780415, 57.152546473911826, 68.24498421805245, 79.90773010253906, 90.75622354234967, 87.96016420636857, 93.16357285635812, 88.27717576708112, 85.95800604139055, 80.40929971422467, 81.34144224439348, 71.07853603363037, 79.8711825779506, 81.20088713509696, 73.08201435634068, 70.67327540261405, 73.32467324393136, 70.46454456874302, 69.1503483908517, 69.45053836277553, 78.48687212807792, 82.15658405848912, 63.82710415976388, 17.569619689668926, 1.3838602283171244, 0.3885701894760132, 0.20144642117832387, 0.19492897018790245, 0.08002757360892636, 0.17123048326798848, 0.20627662699137414, 0.14347707107663155, 0.17891607300511428, 0.2294803261756897, 0.1974535547196865, 0.09462660737335682, 0.15739592776766845, 0.20273985820157187, 0.15516679095370428, 0.12334334930138928, 0.20533377544156142, 0.10997614836586372, 0.40785255336335724, 0.14245864429644176, 0.08539786615542003, 0.27487003058195114, 0.15143174066075257, 0.11878873727151326, 0.2313915150506156, 0.2666660536612783, 0.19683311586933477, 0.27899356931447983, 0.21726314031652041, 0.1544892465961831, 0.24334743778620446, 0.19694723188877106, 0.1823965505297695, 0.11242709827742406, 0.15800899772771768, 0.12012695760599204, 0.22659833010818276, 0.19344851534281457, 0.25014890996473177], [0.15981316805950233, 0.05052588201527085, 0.03277610821117248, 0.08358253392257861, 0.049112418932574134, 0.012720805576204188, 0.0529657243085759, 0.09324819740972348, 0.00824401218311063, 0.04251711961946317, 0.0851077042253954, 0.06506767456552812, 0.09419070969202689, 0.05417539618377175, 0.05104257964662143, 0.08398649974593095, 0.019640353874170353, 0.06157039651381118, 0.00739522255025804, 0.06600747949310712, 0.0664104139432311, 0.10217222890683583, 0.03473410243168473, 0.04855215596035123, 0.04119201536689486, 0.044444807073367495, 0.0386670304994498, 0.05071716442970293, 0.01144895444823695, 0.032330778893083334, 0.09427008471850838, 0.044118285844368596, 0.06921723511602197, 0.03812496244375195, 0.12269709897892815, 0.11532542668282986, 0.14274584102843488, 0.1502996456942388, 0.10818613227456808, 0.0761353610349553, 0.06697141991129943, 0.04363166767039469, 0.2804403688226427, 14.079122645514351, 75.82570511954171, 103.2249813079834, 93.74667957850865, 70.97250652313232, 58.16532979692732, 45.175061089651926, 41.46019629069737, 61.39401871817452, 65.86652551378522, 67.96575001307896, 66.92516694750104, 61.91022818429129, 74.03240285600934, 77.81186158316476, 64.76003878457206, 60.86781079428536, 60.16318007877895, 51.63243893214634, 39.60274130957467, 32.032255104609895, 30.528373105185374, 35.911858218056814, 51.632484095437185, 55.672159808022634, 58.26813186917986, 56.35163804462978, 51.66118015561785, 46.14406033924648, 40.03200101852417, 36.66884708404541, 24.394717046192714, 8.697578685624258, 4.449212959834507, 1.9770955783980233, 0.2770254649221897, 0.3340228407510689, 0.04380775768575924, 0.15034787596336432, 0.41332149133086205, 0.33147648881588665, 0.450386141027723, 0.21221665825162614, 0.1926899810454675, 0.1030567264450448, 0.036322417203336954, 0.04499242554551788, 0.5563530091728482, 0.7985260656901768, 0.08238540815987758, 0.5034810176917485, 0.05335447737681014, 0.05591212013470275, 0.20290329014616354, 0.11530410711254392, 0.02862193701522691, 0.1909094780151333, 0.12234857625194959, 0.17927433949496063, 0.07177649278725896, 0.2686464802495071, 1.048844039440155, 6.468633055686951, 11.591735294886998, 19.566321781703405, 20.97471989904131, 25.350737060819352, 35.99791513170515, 37.58805554253714, 30.48220579964774, 15.66931516783578, 21.86216640472412, 33.11436060496739, 39.68013729367937, 43.984942368098665, 37.73908853530884, 30.75460297720773, 31.793386459350586, 31.786789144788468, 37.88986097063337, 38.166308947971885, 31.692199843270437, 23.16112344605582, 24.427265882492065, 34.340540477207725, 39.321884700230186, 49.28392348970686, 48.25442974908011, 61.69857215881348, 55.26893499919346, 38.45472519738333, 12.350349170821053, 0.8976468411939484, 0.13272999918886594, 0.05703060368874243, 0.22495037210839136, 0.15585266772125447, 0.018397264149306074, 0.011775989667512476, 0.06156038812228611, 0.04708752455189824, 0.05279737977044923, 0.06965925318322011, 0.04058027872815728, 0.047350670610155375, 0.06963003546531711, 0.0880965017048376, 0.011220217748944248, 0.09911327769181558, 0.020860817848837802, 0.016196179669350386, 0.033529485642377815, 0.048319163998322825, 0.05939178341733558, 0.06253874740962471, 0.11859781108796597, 0.057050369413835664, 0.07841564581862517, 0.009379337824481939, 0.0845289613519396, 0.054599616277430735, 0.06884131993034057, 0.07551214019102709, 0.03479938767850399, 0.055380939173379114, 0.04755422772307481, 0.03467240324243903, 0.03251597824107323, 0.038095880432852676, 0.047017604910901616, 0.051120366901159286, 0.10721166777823653, 0.16102740647537367, 0.06420582652624164, 0.0674499703039016, 0.09035116500620331, 0.058797339243548255, 0.08692037660096373, 0.02924014687804239, 0.030975408586008207, 0.05608767410740256, 0.07392508070915937, 0.01108663625616048, 0.03185741590069873, 0.05170438538438507, 0.12468216674668448, 0.03678570734336972, 0.054988304884838204, 0.07986241140003715, 0.05619169691843646, 0.05024075820775969, 0.030294936349881545, 0.024890080925875475, 0.07625823015613215, 0.15826699031250818, 0.09321041657988514, 0.049345946937267265, 0.03654538041778973, 0.04533854965120554, 0.026451045647263527, 0.032920894013451676, 0.02444752342333751, 0.08579900248774461, 0.006322033753219459, 0.0464193405849593, 0.03670862237257617, 0.01943319204396435, 0.0566888866680009, 0.06211654935032129, 0.22701457063002245, 0.051205316092818975, 0.12383061886898108, 0.05144244711846113, 0.05188996810466051, 0.5548248397452491, 4.796328025204795, 45.97813388279506, 102.01577241080147, 105.35041441236223, 85.25291674477714, 56.286769662584575, 50.70557703290667, 63.19983468736921, 65.95100171225411, 77.95352145603725, 85.03518799373082, 86.44105870383126, 87.6580148424421, 90.01585824148995, 86.18026501791817, 92.531571660723, 86.12770189557756, 79.61498859950474, 77.02573544638497, 75.23526109967912, 65.34772436959403, 60.12913390568325, 58.58409077780587, 59.562619481767925, 62.00901072365897, 65.29598808288574, 56.98427847453526, 50.86507293156215, 41.40638944080898, 39.48706769943237, 35.55880287715367, 27.037982021059307, 11.867988722664968, 5.1086408666202, 3.3101832568645477, 1.3447779140302112, 0.0985718203176345, 0.36432271344321115, 0.1313442135495799, 0.0961233674149428, 0.26083152102572577, 0.08394806752247469, 0.24340402760675975, 0.13559186990771974, 0.11818565534693853, 0.05911760777235031, 0.12586703816694872, 0.07390180017266955, 0.21699980087578297, 1.1127422792570931, 0.15950637523617062, 0.45553622181926456, 0.31379470761333195, 0.05737564553107534, 0.12846723864121096, 0.06178532248096807, 0.12749161384999752, 0.23416734752910479, 0.15610950679651328, 0.08077823690005712, 0.12644732131489686, 0.184468877900924, 0.8389096472944532, 2.356328908886228, 3.220091828278133, 8.087746586118426, 9.40139819894518, 17.577330453055247, 30.102055958339147, 29.682961463928223, 19.03871032169887, 37.087423937661306, 41.5238105228969, 53.97241851261684, 60.38477202824184, 67.14114475250244, 72.27448081970215, 66.91514069693429, 69.97614874158586, 67.21130071367536, 65.64063957759312, 55.26274415424892, 55.57770599637713, 56.010356426239014, 54.53151226043701, 54.74554456983294, 50.9114556312561, 60.973298345293315, 63.53566891806466, 70.83995573861259, 68.56163447243827, 61.743881361825125, 32.36648777553013, 7.020772959504809, 0.2574067105140005, 0.038374242638903, 0.20098637443568024, 0.14573461136647634, 0.03605515243751662, 0.04262398209955011, 0.07978458343339817, 0.049292237497866154, 0.05884938287947859, 0.09802173197801624, 0.11148989213896648, 0.09594868535974196, 0.03375273384153843, 0.1282099381621395, 0.035414652699338536, 0.08428783036236252, 0.035073051029550176, 0.032030747671212466, 0.0790687764861754, 0.05983483964311225, 0.024883936791281615, 0.035878991175975115, 0.022182368274245943, 0.009223750592874629, 0.07846400500940424, 0.06451576096670968, 0.06773836804287774, 0.02075030654668808, 0.021137434523552656, 0.04412601775090609, 0.003867387946229428, 0.02867885253259114, 0.0723110833870513, 0.01540479070640036, 0.031167997180351188, 0.02885134970503194, 0.04989098019099661, 0.02040247931810362, 0.11076715056385313, 0.1258343599204506, 0.2295247023659093, 0.1309050249734095, 0.1450330875813961, 0.32107530693922726, 0.16899363829621247, 0.13308222671704634, 0.07381975850356476, 0.18582244669752462, 0.15281815055225575, 0.1653778473181384, 0.198659175740821, 0.18532019507672104, 0.24101629001753672, 0.14561717052544865, 0.11004812736064196, 0.2693545179707663, 0.1777301023581198, 0.24964606123311178, 0.11871542834809848, 0.16074388740318163, 0.10156126919069461, 0.15613799169659615, 0.1770624646118709, 0.21105550841561385, 0.1221600520823683, 0.13930068803685053, 0.13494882227054664, 0.19545463126684937, 0.11800899196948324, 0.14617720618844032, 0.14877818019262382, 0.165577553744827, 0.14114476979843207, 0.14095374861998217, 0.16268928801374777, 0.247383608349732, 0.41503120958805084, 0.25706182473472183, 0.2528240478464535, 0.17997085569160326, 0.3131474123469421, 0.25358194432088305, 0.7842387780547142, 22.6696652003697, 105.11721897125244, 133.80086272103446, 119.1441102709089, 92.00182015555245, 80.89242880684989, 68.63196413857597, 58.534445898873464, 81.0540439060756, 90.15355764116559, 91.86130673544747, 91.77660819462368, 89.4273110798427, 94.78652613503593, 109.35183334350586, 97.53935377938407, 95.88984448569161, 95.63189956120083, 94.49619565691266, 76.22052260807583, 67.64909281049455, 69.86372688838414, 73.86009447915214, 86.54945755004883, 91.64403656550816, 88.74770082746232, 76.82675988333565, 65.61140850612095, 61.53970854622977, 48.88797344480242, 44.75879103796822, 32.46346378326416, 16.797579288482666, 7.926431127956935, 4.018521921975272, 0.40497209078499247, 0.4116831820990358, 0.45131082140973633, 0.21999064753098146, 0.6679087259939739, 0.2916092723608017, 0.6034991421869823, 0.3653538152575493, 0.46491726700748714, 0.303186653980187, 0.4959570957081658, 0.19918746953564032, 0.916537310395922, 2.2502392530441284, 0.30199582502245903, 1.0405972876719065, 0.46023939230612343, 0.22016611668680394, 0.42170234876019613, 0.24687467994434492, 0.30014847272208756, 0.687055410018989, 0.3970116265118122, 0.2874611163777964, 0.19597531189875944, 0.7922565106834684, 3.5034035401684895, 10.345742634364537, 16.67919761793954, 27.651275191988262, 29.850889001573833, 36.00197287968227, 48.71475485392979, 48.518336227961946, 51.00004863739014, 57.49592644827706, 58.23345341001238, 61.42892646789551, 65.54957648686, 68.23623643602643, 65.85974407196045, 61.62843704223633, 67.49682303837368, 73.14723014831543, 74.00340802328927, 72.81177112034389, 69.6247991834368, 63.31549440111433, 57.60754925864083, 65.96002742222377, 63.498683656964985, 72.73362473079136, 71.79424217769078, 86.20408344268799, 76.67574773515973, 56.338829040527344, 20.518654039927892, 2.2484733249459947, 0.1511880923062563, 0.15782687892871244, 0.30203461008412497, 0.20599966256746224, 0.14631478594882147, 0.16367769640471252, 0.19317723704235895, 0.16008249217910425, 0.20006526314786502, 0.22024261472480638, 0.20958375238946506, 0.23081576451659203, 0.20730770166431153, 0.272003708673375, 0.21175955635096344, 0.3057813447500978, 0.11854070558079652, 0.13720400125852653, 0.16537095340234892, 0.09917838991220508, 0.12007344833442143, 0.15636635944247246, 0.17342401056417397, 0.1782441876296486, 0.19836531579494476, 0.25826931851250784, 0.1712594838546855, 0.13025007583200932, 0.16651151648589543, 0.20549692240144524, 0.1416231912693807, 0.1041329779795238, 0.12681732646056584, 0.22246507475418703, 0.11218903426613126, 0.2377999254635402, 0.1913804356008768, 0.12421449327043124, 0.22332458863300936, 0.23865080837692532], [0.0435904975581382, 0.028736884240061045, 0.02545424547445561, 0.04676169203594327, 0.06436883777912174, 0.07101767350520406, 0.06653259774403912, 0.12048185856214591, 0.16807582468858787, 0.057867664843797684, 0.0680395018841539, 0.11366885807365179, 0.02971746912226081, 0.07047316950878926, 0.06595567334443331, 0.03562553799045937, 0.05793728253671101, 0.02288132210794304, 0.040371079596557786, 0.03649111457967332, 0.0396965445418443, 0.04764102931533541, 0.04598984827420541, 0.05537922926513212, 0.04750583121286971, 0.053432600506182225, 0.0800869454230581, 0.09056673558162791, 0.04084386244150145, 0.10656902047672442, 0.13778432511857577, 0.0802049223067505, 0.1989318246820143, 0.14349252810435636, 0.18764169407742365, 0.09466133479561124, 0.0330623074966882, 0.10043357791645185, 0.176473021241171, 0.0839871239981481, 0.011001656530424953, 0.014893945439585617, 0.04722567767437015, 0.3899228626063892, 0.9176941854613168, 21.818083558763774, 62.867815017700195, 92.2839309147426, 77.09038843427385, 72.92886216299874, 68.38546984536308, 49.99648209980556, 42.812527656555176, 45.132131644657676, 52.38789572034563, 51.74940143312727, 51.54338387080601, 50.85425806045532, 52.89239399773734, 50.69572796140398, 52.82839066641671, 50.65708555494036, 47.769806793757844, 37.34135627746582, 27.529490641185216, 20.208008766174316, 16.171979120799474, 14.787856272288732, 21.325991289956228, 28.71573053087507, 34.474984645843506, 32.60749299185616, 28.01533647945949, 35.8468473979405, 38.60169349397932, 23.52977749279567, 10.833692908287048, 2.4182744877679005, 0.08668620059532778, 0.7091269056711877, 0.48181751157556263, 0.14037248838160718, 0.10411152948758431, 0.0237886370824916, 0.06992487250162022, 0.047251933586916754, 0.13043366026665482, 0.14506999988641056, 0.08941016585699149, 0.2499400840273925, 0.1337799642767225, 0.45720742642879486, 0.5120565061058316, 0.3266636942114149, 0.7021496114986283, 0.543756685086659, 0.227846658123391, 0.309547485517604, 0.43776362548981396, 0.30076203122735023, 0.14484479411372117, 0.8104874981301171, 0.5356889037149293, 0.4513116899345602, 2.0685460312025885, 8.630212426185608, 20.37954068183899, 29.41823509761265, 37.54363570894514, 49.087695939200266, 54.89125524248396, 47.53770916802542, 26.68616693360465, 12.523361921310425, 9.915366871016365, 5.538122483662196, 5.445768330778394, 6.986915256295886, 14.227834071431841, 20.223426818847656, 23.810733113970073, 23.31892224720546, 15.45416419846671, 5.374948816640036, 13.806426695414952, 23.88711813517979, 31.320057800837926, 36.98062317711966, 36.56671551295689, 46.644622462136404, 45.67655427115304, 28.42482508931841, 7.996891072818211, 0.6084460424525397, 0.04630224918946624, 0.16714942082762718, 0.18217061193925993, 0.08431590814143419, 0.018298499984666705, 0.0073311230433838704, 0.13683685953063623, 0.049003843151565106, 0.05903905377324138, 0.03543375685278859, 0.09478377643972635, 0.059333965448396545, 0.0434798013551959, 0.09179860233728375, 0.10247928635882479, 0.05062491759391768, 0.050796661592487774, 0.04790536620255027, 0.05797094465898616, 0.08147020012672458, 0.019104134790333252, 0.05288222718185612, 0.07153882911162716, 0.13295420072972775, 0.05056309966104371, 0.08451295471084969, 0.07517880986311606, 0.0420224031300417, 0.07357017296765532, 0.1544906443783215, 0.09743998319442783, 0.11864766984113626, 0.034940455108881, 0.0606413260102272, 0.04568002579201545, 0.10209841786750726, 0.07625835229243551, 0.0925383140732135, 0.03951899228351457, 0.042575446489666186, 0.024376251801316227, 0.077342189848423, 0.09623629599809647, 0.1041004965081811, 0.06167457199522427, 0.0857733538640397, 0.02516788842954806, 0.023227195155673792, 0.0408206904706146, 0.04245357820764184, 0.12531772335725172, 0.1474035225276436, 0.04971014043050153, 0.10054970239954335, 0.04171552548983267, 0.045987449652914486, 0.04946855142978685, 0.06288620483662401, 0.017114661633968353, 0.012754912138916552, 0.03203202331704753, 0.03191222117415496, 0.04645013928945575, 0.09160371350922755, 0.029962983448058367, 0.02809170600292938, 0.05217302916571498, 0.05919307443712439, 0.09323810759399619, 0.07622318382241897, 0.08435016737452575, 0.07669278433812515, 0.05808466034276145, 0.1512186128113951, 0.05841781425156763, 0.11359088082930871, 0.07986724935472012, 0.10139546915888786, 0.07306693068572453, 0.21963335813156196, 0.08666015842131206, 0.10007956584117242, 0.0724214810345854, 0.010195288906938263, 0.3216113767453602, 2.882065223796027, 12.30727641923087, 57.41022389275687, 92.19825962611607, 99.11510794503349, 85.70989976610456, 70.56940678187779, 65.15500218527657, 67.85144519805908, 65.10307829720634, 67.71335669926235, 70.87525953565324, 66.87286785670689, 73.62091663905552, 76.11379827771867, 71.58259310041154, 75.5748404094151, 76.9948159626552, 71.58909661429269, 69.01621341705322, 63.149001666477744, 56.41290031160627, 53.11368370056152, 54.7969195502145, 55.15981354032244, 56.64142656326294, 61.16160147530692, 61.75041961669922, 50.07628216062273, 42.260927540915354, 39.93847131729126, 30.318252631596156, 15.886262246540614, 9.288410936083112, 3.7902631759643555, 0.295202766678163, 0.6477974365864481, 0.36981187175427166, 0.20746680455548422, 0.16966829209455422, 0.17994988895952702, 0.16934226958879403, 0.131308414041996, 0.13397361817104475, 0.07338129595986434, 0.11499037966132164, 0.11537509544619493, 0.04878194184441652, 1.308855727314949, 0.4694619317139898, 0.15561803031180585, 0.5690844974347523, 0.5580188940678323, 0.4167444019445351, 0.3111136800476483, 0.16580721070723875, 0.36656467456902775, 0.5119219390409333, 0.050730419611292224, 0.408458729407617, 0.3477361149021557, 2.8707075246742795, 8.589841655322484, 15.972275733947754, 24.43395004953657, 26.717103787830897, 36.76181745529175, 50.434496538979666, 47.59686613082886, 37.68542412349156, 29.37448229108538, 29.290565422603063, 38.78128358295986, 39.91544498716082, 45.717944690159385, 46.13703918457031, 44.0682304246085, 42.65618971415928, 44.33486059733799, 43.85987479346139, 45.43544135774885, 43.411219188145225, 41.95440081187657, 40.98085396630423, 53.557826450892854, 59.492380142211914, 67.88979230608258, 64.27926513126918, 52.157441343579976, 26.576878717967443, 5.7296187451907565, 0.4459632597863674, 0.08330533201141016, 0.07720180095306464, 0.02347602921405009, 0.20246034248598985, 0.021679081887538944, 0.02845624215634806, 0.026457210137907947, 0.00353906541879821, 0.0199278932663479, 0.04859896469861269, 0.06158934121153184, 0.03683679763759885, 0.13083991275302, 0.16678567177483014, 0.09570464345493487, 0.054259436138506444, 0.08419044023113591, 0.04682477204395192, 0.04441948075379644, 0.09625990901674543, 0.05644210687439356, 0.04209667218050786, 0.07130288212959256, 0.009613983715618295, 0.0341490016851042, 0.05297340193231191, 0.033539589028805494, 0.005473448953125626, 0.09998094756156206, 0.1605685810957636, 0.1570298581251076, 0.04682310963315623, 0.1076227989313858, 0.05670439458585211, 0.09351866146815674, 0.06373004455651556, 0.043576977747891626, 0.03283169040722506, 0.034667039423116615, 0.012618307772624706, 0.10183222857969147, 0.24281720338123186, 0.15500953367778234, 0.12781243877751486, 0.11800698350582804, 0.10418470270399537, 0.1642239306654249, 0.1526645709361349, 0.20054612734488078, 0.3512039173926626, 0.22601438287113393, 0.17399605629699572, 0.23953005405408995, 0.20678928733936378, 0.1556882993983371, 0.15252168503190788, 0.1369496320507356, 0.1343302968889475, 0.06522796489298344, 0.07478006197405712, 0.20055292626576765, 0.15164410855088914, 0.13837629263954504, 0.16417423476065907, 0.10044692470026867, 0.146567648808871, 0.1506226555045162, 0.2572604997881821, 0.14924153818615846, 0.12890591153076716, 0.19403329039258616, 0.22527430472629412, 0.24849024468234607, 0.24017713218927383, 0.24452225331749233, 0.251154254589762, 0.15876489930919238, 0.13790931126901082, 0.36152177516903194, 0.20234367517488344, 0.240256167948246, 0.14365011107708725, 0.11949043747569833, 0.25786708295345306, 0.9177739811795098, 2.550377982003348, 35.78470965794155, 90.87007672446114, 121.97969790867397, 106.48344326019287, 102.23356369563511, 98.37935624803815, 73.778578213283, 63.134090832301546, 66.59295272827148, 73.225341796875, 74.92745590209961, 75.63457407270158, 78.83947931017194, 79.27211584363664, 84.4301597050258, 93.88039766039167, 92.41709314073834, 94.29568454197475, 85.3160480771746, 71.21814618791852, 65.42755222320557, 60.89396381378174, 53.86188309533255, 52.79769352504185, 60.79897499084473, 66.70322063991001, 56.97977951594761, 54.53512532370431, 52.20474815368652, 54.61225380216326, 30.83219698497227, 17.733852522713796, 6.14112537247794, 0.20602852744715555, 1.1748604774475098, 0.841249018907547, 0.3154745160468987, 0.14904229316328252, 0.2041081783494779, 0.1677967296647174, 0.21239488225962433, 0.1892400783087526, 0.2150195642773594, 0.16453305764922074, 0.3062327333859035, 0.21210495781685623, 3.241966928754534, 0.5488503117646489, 1.1799607809100832, 0.8555154076644352, 1.3369736756597246, 0.9111108758619854, 0.7981202474662236, 1.0741726117474693, 0.8103000053337642, 0.6332065452422414, 0.8521306578602109, 0.8778549517904009, 1.8072810620069504, 4.692740372249058, 10.436143909181867, 22.889754601887294, 33.50477293559483, 43.888671602521626, 61.64473751613072, 66.87313883645194, 66.28377178737095, 58.30681596483503, 50.64556891577584, 42.295717171260286, 40.77987037386213, 42.40033272334507, 47.84189782823835, 53.02530261448452, 57.986149651663645, 65.62839685167584, 65.62668064662388, 56.21656853812081, 49.4020984513419, 53.10453292301723, 61.7375168119158, 63.3922233581543, 72.81978934151786, 72.81591919490269, 78.68329075404576, 70.55150127410889, 42.09968417031424, 16.028896604265483, 1.7126325922352927, 0.2223015342439924, 0.3724789486399719, 0.259428934859378, 0.20741834358445235, 0.29643791754330906, 0.16101583066795552, 0.24758535038147653, 0.3265432406749044, 0.23858672752976418, 0.17425125331750937, 0.2408017643860408, 0.22248355804809503, 0.2558569365314075, 0.3204447036342961, 0.24685679376125336, 0.2795845733157226, 0.2868138211114066, 0.16258510574698448, 0.2220554838755301, 0.31243158504366875, 0.13196510023304395, 0.13595532040510858, 0.09757702012679406, 0.2812222311539309, 0.24461127711193903, 0.18352168372699193, 0.1944988061274801, 0.15245689850832733, 0.18567472962396486, 0.3129343794924872, 0.2904586126761777, 0.2673307465655463, 0.24152090294020517, 0.15816552218581947, 0.15995281056634017, 0.2632540538907051, 0.16302414504545076, 0.2548572916005339, 0.17445102759769984, 0.2669714758438723, 0.08266181618507419, 0.2082806665982519], [0.03630044623943312, 0.017649133490132432, 0.029169820116034577, 0.05396067377712045, 0.038019874332738776, 0.04798063269949385, 0.14061444039855683, 0.05519952944346836, 0.0994643381397639, 0.06893455742725305, 0.043351978928382905, 0.11306580329047781, 0.052125745452940464, 0.11605752525585038, 0.1003740703953164, 0.07193844552550997, 0.039554791791098456, 0.05127274211762207, 0.017263460970882858, 0.02069110606264855, 0.04024220883314099, 0.03691736349303808, 0.09759360352264983, 0.02470715806287314, 0.03523585532924958, 0.04263358676273908, 0.04536302101665309, 0.05067405031461801, 0.02573827005523656, 0.03594103641808033, 0.023944603445540582, 0.0581338337755629, 0.10380173075412001, 0.08719649964145251, 0.1665461217718465, 0.013397662068850227, 0.15201738423534802, 0.034090562856623104, 0.11944467707404069, 0.04761583870276809, 0.07581154376800571, 0.04030197759025863, 0.03261393155636532, 0.06646922257329736, 0.09153146310044186, 0.2556775047310761, 0.7589706767882619, 19.84417850630624, 59.68404620034354, 85.18862506321499, 85.75604970114571, 80.53689643314907, 69.78314862932477, 56.0125207901001, 54.53490645544869, 51.34742382594517, 55.12820618493216, 47.583178179604666, 29.746450628553117, 26.339703696114675, 29.30166516985212, 22.70707951273237, 24.448730604989187, 22.89138569150652, 13.603538428034101, 11.556520955903189, 5.408922467912946, 7.531961049352374, 6.861543263707842, 12.344883544104439, 13.23894386632102, 15.023957797459193, 13.308111446244375, 24.031595502580913, 32.64384249278477, 42.3592723437718, 22.439042329788208, 6.110912433692387, 0.5683145501783916, 2.212107756308147, 0.5577533968857357, 0.18466132400291307, 0.044263692506189854, 0.04742777932967458, 0.18394665020917142, 0.13197298480996064, 0.074625199926751, 0.23829585313796997, 0.12408764793404511, 0.1731450648180076, 0.0890676753063287, 0.6790990712387222, 0.13983272734497273, 0.21078094600566796, 0.3043336495757103, 0.8027184350149972, 0.8421750835009983, 0.71108271500894, 0.4010048322379589, 0.751872711947986, 0.752451095197882, 1.2630351803132465, 1.236901811191014, 3.4119450535093034, 6.279681137629917, 19.442122731889995, 33.02196346010481, 44.856430598667686, 50.33094058718, 52.258429936000276, 53.439884253910606, 34.39231497900826, 10.811440433774676, 3.6073959256921495, 5.628150727067675, 3.550107159784862, 7.589137775557382, 9.749179857117788, 10.467151113918849, 12.877595850399562, 11.005403740065438, 1.5627066429172243, 9.369052597454615, 13.977560826710292, 29.193749223436626, 33.07858085632324, 34.39671318871634, 35.20567110606602, 31.793223176683696, 21.21387689454215, 6.123501266751971, 1.0418616426842553, 0.07063417908336435, 0.20472249681396143, 0.11558660838220801, 0.09112967537449938, 0.10141889897308179, 0.08876207670462982, 0.08934827667794057, 0.11499670360769544, 0.14315231064600603, 0.12225862964987755, 0.023656504261972647, 0.05056814456890736, 0.04531019028010113, 0.04439655305551631, 0.0824032129187669, 0.1308200859597751, 0.11685504817536899, 0.13087276741862297, 0.08057118872446672, 0.07190943815346275, 0.045009548376713476, 0.013878522873190897, 0.05368574156558939, 0.03625028893085463, 0.10304054338485003, 0.004266047625735934, 0.03849383443593979, 0.0604777176465307, 0.04754000562908394, 0.08144013424004827, 0.1394939755222627, 0.06508376941617046, 0.06684420816600323, 0.05394428715642009, 0.0191053408863289, 0.045014671316104274, 0.08352705689945392, 0.11398568642990929, 0.12561891148132937, 0.07551181449421815, 0.05423162638076714, 0.03160961151921323, 0.11588242250893797, 0.043070821158055744, 0.11846632457205228, 0.04733176662453583, 0.06099442884858165, 0.01744692835823766, 0.11499626934528351, 0.057943301142326424, 0.19703499360808305, 0.10970812024814741, 0.11532449030450412, 0.08600917870977096, 0.07444247723157917, 0.025182102041851197, 0.02615404747692602, 0.02638625742734543, 0.04007677521024432, 0.018228766940800206, 0.05128396169415542, 0.009222280716390481, 0.019999656826257706, 0.023499062085258107, 0.047265772308622084, 0.036772872853491984, 0.028717732589159693, 0.0549390059230583, 0.0812382565013, 0.05924773043287652, 0.04379500801275883, 0.01757701878835048, 0.04169220084856663, 0.07722680496850184, 0.11678594616906983, 0.14719320381326334, 0.10763863593872104, 0.1838830036244222, 0.08985588194004127, 0.10840802001101629, 0.15317835765225546, 0.06830387948346989, 0.17931574370179856, 0.08014989311673812, 0.0357023854739964, 0.027711882455540553, 0.10145879004682813, 0.29689668864011765, 0.18581882332052502, 1.7812043641294752, 13.445327077593122, 52.20297983714512, 81.2600371497018, 92.46183953966413, 90.1429477419172, 81.94576876504081, 69.17988518306187, 63.876874106270925, 68.0979255948748, 67.76847675868443, 70.19383580344063, 65.21896035330636, 65.89543001992362, 59.24257850646973, 65.47828796931675, 62.88364996228899, 59.03339603969029, 55.684235777173726, 45.936347416469026, 37.10934203011649, 30.440415859222412, 30.038479941231863, 33.99808113915579, 38.42658846718924, 43.5831732068743, 41.104365144457134, 33.53626217160906, 46.29927267347063, 45.98242439542498, 36.3000818661281, 20.551277569362096, 6.962152310780116, 0.5118999545063291, 1.720184632710048, 0.7737733253410884, 0.380897722606148, 0.07816621634577002, 0.06509571163249867, 0.13110984755413874, 0.29986028532896725, 0.1635693750743355, 0.2083934255476509, 0.13115043751895428, 0.11192823254636355, 0.14135366358927318, 0.9970110207796097, 0.06764618227524416, 0.9522367204938615, 0.5827954645667757, 1.1201891196625573, 1.2073715329170227, 0.5409054266554969, 1.2659339904785156, 0.8914157726934978, 0.643503124160426, 1.0553356111049652, 2.068016231060028, 1.8937247948987144, 4.3959550176348, 14.840961354119436, 31.125709738050187, 40.62461287634713, 47.255653994424, 60.142113140651155, 63.57853930337088, 58.45607021876744, 37.42881325313023, 22.90947880063738, 18.40141807283674, 18.289336681365967, 18.594020400728496, 18.241520915712627, 24.784870556422643, 31.6060699735369, 38.467985834394185, 36.5616363797869, 34.24714626584734, 28.222146136420115, 37.240617820194785, 49.3453038760594, 53.548550605773926, 58.74910354614258, 49.71807473046439, 41.26299946648734, 20.38016775676182, 6.046748425279345, 0.34184105694293976, 0.3000940813549927, 0.11773000551121575, 0.055033373180776834, 0.12208971514233521, 0.02872778508546097, 0.031179138725357394, 0.05406771946166243, 0.2777443863451481, 0.15530291864914553, 0.14309702361268656, 0.08522632571735553, 0.05979165767452546, 0.1378632387412446, 0.16454516271395342, 0.09057099678154502, 0.04826763944168176, 0.15400851810617106, 0.12830573373607226, 0.0647948831319809, 0.08154203662914888, 0.05722039671880858, 0.05596024862357548, 0.07953002423580204, 0.059556083886751106, 0.05369922744908503, 0.1216750895338399, 0.05772853123822382, 0.024648408804621016, 0.07060540241322347, 0.09961583465337753, 0.17035484739712306, 0.2016506330775363, 0.09105583719377007, 0.08014610010598387, 0.05113292319167938, 0.17968002201191016, 0.05761501911495413, 0.12886365236980574, 0.1389466691762209, 0.07503601895379168, 0.10834540479949542, 0.08092487510293722, 0.07177710346877575, 0.2319841475359031, 0.1831193667437349, 0.2439988042627062, 0.16016041514064583, 0.23039301005857332, 0.11740224595580782, 0.21902080385812692, 0.2094969677605799, 0.19097030189420494, 0.18635315607701028, 0.20794471033981868, 0.3053035746727671, 0.10995469308857407, 0.2139858976006508, 0.25870127390537945, 0.11961345587457929, 0.13608467632106372, 0.14108181531940187, 0.12155160973114626, 0.0984998345375061, 0.12109187511461121, 0.10342373246593134, 0.15479403095585959, 0.1775492456342493, 0.13846229016780853, 0.10799503645726613, 0.11195615426238094, 0.10889605632317917, 0.11605384759604931, 0.18144387379288673, 0.32275071846587317, 0.1775411982089281, 0.30167305948478834, 0.25019062629767824, 0.3471335215227944, 0.1229940801858902, 0.3440822852509362, 0.13099877137158597, 0.2439847992999213, 0.13229705313486712, 0.23606694702591213, 0.1529488092554467, 0.14278773378048623, 0.3354954517313412, 0.13766691141894885, 0.24499133814658436, 3.4855279965060095, 33.09092433112008, 80.77884660448346, 105.5143015725272, 107.90980420793805, 107.90718473706926, 98.24918869563511, 84.08611270359584, 81.47857189178467, 80.87331431252616, 84.90291513715471, 80.11637060982841, 68.95400619506836, 59.91699845450265, 70.92669010162354, 66.30761105673653, 65.680084500994, 74.77884783063615, 64.18620790754045, 60.49156584058489, 49.757373741694856, 51.050621100834434, 52.040534428187776, 46.190154688698904, 45.76469217027937, 45.79375301088606, 50.16896765572684, 60.1959547315325, 61.76861000061035, 60.27173178536551, 37.13455009460449, 14.413058280944824, 0.9252934519733701, 3.9315673879214694, 1.782240514244352, 0.6755586926426206, 0.2669582851231098, 0.2977386420326573, 0.3992739165467875, 0.47428018174001146, 0.48155820263283594, 0.4896603993007115, 0.2625173277088574, 0.18236697997365678, 0.3357279449701309, 3.3652249319212775, 0.9878036805561611, 1.4732672593423297, 0.5334667829530579, 2.1392539399010793, 1.9286236422402518, 1.2998423938240324, 1.678230106830597, 1.9254856620516096, 1.326316224677222, 2.0277522887502397, 3.4285353975636617, 5.84082509790148, 10.536385570253644, 25.590272733143397, 40.311023303440635, 53.6822304725647, 60.66496508462088, 67.29979991912842, 75.17263698577881, 68.98562744685582, 49.832337856292725, 38.16731991086687, 35.222423212868826, 39.232367583683555, 45.64131300789969, 43.53072820390974, 51.48482097898211, 52.862054688589915, 46.82994828905378, 39.460039206913535, 44.78694861275809, 51.70659358160836, 64.71705722808838, 70.2158476965768, 64.93714141845703, 62.98282854897635, 49.10433687482561, 32.39319665091378, 10.23318008014134, 2.157819526536124, 0.16700483858585358, 0.350650069969041, 0.2938247434794903, 0.16518050219331468, 0.2506629138120583, 0.30399248216833386, 0.1361175716987678, 0.3305509941918509, 0.3385114584650312, 0.2993318151150431, 0.2420434020459652, 0.29933520779013634, 0.21993491266454968, 0.16331651221428597, 0.2706113005323069, 0.33458928178463665, 0.29014759936503, 0.23937290534377098, 0.27138670321021763, 0.20345641832266534, 0.20143233479133674, 0.22515709458717278, 0.16878876143268176, 0.1815082939075572, 0.26176792649286135, 0.12496408447623253, 0.1993802956172398, 0.1774542371609381, 0.22584229281970433, 0.2135615146585873, 0.2569111356777804, 0.25459545850753784, 0.40897832438349724, 0.15386549649494036, 0.17820370623043605, 0.16814608020441874, 0.33211352463279453, 0.22074561273413046, 0.21757055739206926, 0.2534596451691219, 0.22082192078232765, 0.19078652746975422, 0.29610809524144444, 0.1324031895824841], [0.046853253551359685, 0.05909936196569886, 0.024962231250745908, 0.03544432842837913, 0.05103158398664423, 0.0374453349837235, 0.07860194439334528, 0.03224806886698518, 0.05354163769100394, 0.047510794696531126, 0.0417327806353569, 0.0021307076759902494, 0.04347181160535131, 0.02062055029507194, 0.025387939032433287, 0.026479688306738223, 0.03634647126974804, 0.02340550228421177, 0.06517455061631543, 0.04426700036440577, 0.07323636087988104, 0.061462197319737503, 0.0013494832736406742, 0.0718861169048718, 0.08588935621082783, 0.1867822344814028, 0.05412910652479955, 0.08720067941716739, 0.10983857539083276, 0.030397520666675906, 0.09258862065949611, 0.025649105464773517, 0.053540823448981555, 0.02645859434934599, 0.020027578542275087, 0.02680617051997355, 0.045401134328650575, 0.039583504000412564, 0.02274638015244688, 0.015658369420894554, 0.033961033914238214, 0.012871928895557565, 0.0746002976915666, 0.016300136323219964, 0.04165361595473119, 0.11211844626814127, 0.1480979352657284, 0.08711685320096356, 0.6931912664856229, 8.97952789919717, 31.47142083304269, 48.50291470118931, 56.388512134552, 63.56455952780587, 70.4764746257237, 74.10067585536412, 74.42596966879708, 60.21338776179722, 42.60222652980259, 32.89360591343471, 26.751754454204015, 11.838756782667977, 9.816594753946577, 10.576358556747437, 14.3161187512534, 12.339735797473363, 10.438456790787832, 8.200934478214808, 5.353458906923022, 7.895072170666285, 9.619049651282173, 11.227072988237653, 14.887321472167969, 21.89018154144287, 38.38792174203055, 52.91677522659302, 34.11189610617501, 13.701422912733895, 2.8440457667623247, 4.154442148549216, 4.390554096017565, 0.9447112785918372, 0.2279371746948787, 0.09806313618485417, 0.13276331525828156, 0.10162150952965021, 0.10739423441035406, 0.14945294255656855, 0.13854375508214745, 0.2596678877515452, 0.10156486542629344, 0.8057165284241948, 0.2606739380529949, 0.2238321735390595, 0.1691591465579612, 0.4177878802376134, 0.5540084264108113, 2.0213275934968675, 1.3038607324872697, 0.7118893574391092, 1.1339211485215595, 0.920183920434543, 3.174188120024545, 9.490897944995336, 18.061757121767315, 28.01940291268485, 28.50794812611171, 32.057817527226035, 38.63762957709176, 37.32821028573172, 33.578892844063894, 20.50838460241045, 9.787322861807686, 4.629999876022339, 2.040447950363159, 2.45541912317276, 3.406611659697124, 6.994713306427002, 5.341467618942261, 2.567247122526169, 3.4263176194259097, 13.488039391381399, 19.956312009266444, 28.787253550120763, 33.127607345581055, 35.221092632838655, 33.99419709614345, 15.454428230013166, 2.6718605032988956, 0.9330700061150959, 0.01151592331007123, 0.08835127124828951, 0.16818029194005898, 0.028051229692729454, 0.10050787750099387, 0.07041759749076196, 0.07574622798711061, 0.07579609352563109, 0.07017625615532909, 0.05732925409185035, 0.0797610314829009, 0.008890861312725713, 0.08537587483546563, 0.09726621037615196, 0.0642851676259722, 0.1070438524974244, 0.12556088316653455, 0.024348537038479532, 0.20224029357944215, 0.14551524099494728, 0.1264376182641302, 0.1634200702288321, 0.050183988575424464, 0.029508219100534916, 0.03983814801488604, 0.02850348176434636, 0.02797388857496636, 0.0883560006373695, 0.010377675727275866, 0.017348912278456346, 0.049152941043887816, 0.10503522599382059, 0.07100672873535327, 0.07404470643294708, 0.062320408411324024, 0.10000102541276387, 0.04889150150120258, 0.04012541938573122, 0.058050326470817835, 0.05201942580086844, 0.07330209056713752, 0.07447209528514318, 0.12635103719575064, 0.11447638938469545, 0.07012623455375433, 0.054452689697167704, 0.05441816244274378, 0.06834581973297255, 0.09710867490087237, 0.025692784460261464, 0.06971901854766266, 0.015517570011849915, 0.028734434728643725, 0.10888973916215555, 0.06427970541907208, 0.19837169402412005, 0.04380575940012932, 0.05334031295829585, 0.12259852141141891, 0.07102025872362511, 0.006281999763034816, 0.021887040996391858, 0.10334025230258703, 0.042844366880932024, 0.031063882767089775, 0.057676569026495726, 0.013972002946372544, 0.033512318706406016, 0.04294264928570815, 0.08757264552904026, 0.025376178324222565, 0.10160004746701036, 0.13581968125488075, 0.0020153673249296844, 0.03105971316940018, 0.02455208058069859, 0.058756905341787, 0.06130346762282508, 0.06093001551926136, 0.11869497730263642, 0.049879411168928654, 0.05458132636600307, 0.058470461783664565, 0.07950189217392888, 0.06130409866039242, 0.15159294701048306, 0.026735959108918905, 0.016725964544873153, 0.12244590531502451, 0.08647761893059526, 0.027021096487130438, 0.19367327328239167, 0.26582320460251396, 1.1909923489604677, 12.24773817402976, 36.33315181732178, 60.64186232430594, 73.45937102181571, 81.48965426853725, 79.1976728439331, 79.56518391200474, 76.84127467019218, 79.65483651842389, 74.53888484409877, 58.692760603768484, 51.942571776253835, 48.49912445885794, 36.5095214162554, 35.61830724988665, 40.26204892567226, 33.899048464638845, 30.06879493168422, 21.719056095395768, 20.474397489002772, 19.94353253500802, 22.611180475779943, 23.591979503631592, 30.23691007069179, 32.09832205091204, 40.28538792473929, 51.32717330115182, 61.069579533168245, 40.31702307292393, 15.883418696267263, 6.011100692408426, 5.640584094183786, 3.5314078203269412, 0.7892926154392106, 0.11432679955448423, 0.10615115825619016, 0.2523596041968891, 0.23679102531501225, 0.20835352768855436, 0.30914033736501423, 0.34076023208243506, 0.5893737258655685, 0.388947319239378, 0.8218732071774346, 0.8105255503739629, 0.3197670371404716, 1.095535282577787, 0.5753523696746145, 0.6431259129728589, 1.2998036359037672, 0.6723467249955449, 1.2652367821761539, 1.9585048045430864, 3.5073985372270857, 4.324026831558772, 9.073936547551837, 16.231726680483135, 30.915881088801793, 40.954669679914204, 46.87536866324288, 50.7458279473441, 56.55564062935965, 61.078910963875906, 48.66752447400774, 29.023721592766897, 18.042559249060496, 14.355623602867126, 14.29698862348284, 15.57382607460022, 17.958810874394008, 23.184040342058452, 25.743207795279368, 24.602466447012766, 17.862432411738805, 21.822195155279978, 34.46347148077828, 48.85216242926461, 52.96614565168108, 53.176488467625205, 33.69779389245169, 13.939926777567182, 5.208694492067609, 1.0478402418749673, 0.23163307351725443, 0.16681639584047453, 0.15775293218238012, 0.0444373262247869, 0.04436409194022417, 0.09654157568833657, 0.06898644500012908, 0.1734226942062378, 0.07768430720482554, 0.09277084802410432, 0.14433750776307924, 0.09438695559012038, 0.12143533597035067, 0.10963240252541644, 0.08775750560952084, 0.19843190722167492, 0.17896370616342339, 0.21269038426024572, 0.16567934756832464, 0.22349652940673487, 0.07687671482563019, 0.04988490730257971, 0.029101827514490912, 0.10763625428080559, 0.14640094632548944, 0.04262852489149996, 0.14245260533477577, 0.043866125268063376, 0.05863776137786252, 0.010992981460211533, 0.11525025857346398, 0.1929499820939132, 0.16076370062572615, 0.1550013641161578, 0.09506895113736391, 0.07940718904137611, 0.06554916301476103, 0.07396587423448052, 0.10955520559634481, 0.13655581032591207, 0.17773601918348245, 0.041753062047064304, 0.09577894303947687, 0.057704538239964416, 0.058877107820340564, 0.26387594480599674, 0.2041536673371281, 0.14272111521235534, 0.11732401086815766, 0.20976182711975916, 0.1120753592944571, 0.2687353140541485, 0.13154400140047073, 0.18798546705927166, 0.32585235631891657, 0.1338218841701746, 0.17633955340300286, 0.1516330891421863, 0.07148953354252235, 0.09757976819361959, 0.13088027201592922, 0.19788055680692196, 0.0858083391296012, 0.14964433014392853, 0.11424161626824311, 0.1020632493974907, 0.12675215995737485, 0.1488354078360966, 0.15271822948540958, 0.20344993152788707, 0.21069987464163983, 0.3179384395480156, 0.23940172951136315, 0.1971740254334041, 0.10159282106906176, 0.19383522602064268, 0.2643128942166056, 0.18077671102115087, 0.1594520110104765, 0.25529614090919495, 0.09959575001682554, 0.1859203457300152, 0.13616026512214116, 0.15325550708387578, 0.2079942976789815, 0.09940331070018665, 0.1169837119856051, 0.22743572374539717, 0.11762127705982753, 0.12567122653126717, 0.2702682332268783, 0.19233286806515285, 0.11158990820071527, 2.830472243683679, 17.454726014818462, 46.62936074393136, 63.937406812395366, 81.69449411119733, 88.74998678479875, 99.78566469464982, 100.24166801997593, 97.21816635131836, 88.8499505179269, 75.11205564226422, 66.69683524540493, 61.193201882498606, 43.712003231048584, 47.27666187286377, 54.188385895320344, 51.653099400656565, 47.147557394845144, 54.7875394821167, 53.70686878476824, 48.26322964259556, 44.61828456606184, 39.321294103349956, 41.83583327702114, 63.88890143803188, 67.66886043548584, 81.92267295292446, 84.15007087162563, 61.825946535382954, 30.9735198702131, 9.383601256779261, 8.414219856262207, 6.527675807476044, 2.093686567885535, 0.6743735362376485, 0.34861872611301287, 0.44490680790373255, 0.3712570699197905, 0.2734258366482598, 0.36971606260963846, 0.41213071665593554, 0.42780834968600956, 0.5148667810218674, 3.0536023506096432, 2.530807512147086, 0.858115445290293, 2.1090294931616103, 1.6695364990404673, 0.9780230053833553, 3.638549042599542, 2.652258115155356, 3.4812798244612555, 4.138513837541852, 4.431337850434439, 7.888783182416644, 14.659957306725637, 26.144011156899587, 40.923447949545725, 48.89230564662388, 52.81220483779907, 57.76449169431414, 64.23949364253453, 66.95337663378034, 60.11716215951102, 48.68091712679182, 44.54811470849173, 43.66974081311907, 41.4089081627982, 42.08394997460501, 39.313404423849924, 38.60266971588135, 37.463762692042756, 39.107136726379395, 48.809455326625276, 54.3318384034293, 63.09525735037667, 62.88937527792794, 62.698105267116, 58.09921768733433, 27.87766660962786, 7.110494179385049, 1.8527297718184335, 0.43939039962632315, 0.18192916203822407, 0.2535893810646874, 0.2488908517573561, 0.25245202066642897, 0.22898214576499804, 0.17195903988821165, 0.20633956789970398, 0.2968171371945313, 0.18174935025828226, 0.2218496977750744, 0.2501113462660994, 0.1799246474568333, 0.23379233479499817, 0.1742791546774762, 0.2761262431740761, 0.32506834981696947, 0.3024781277137143, 0.36517088221652166, 0.26244304169501576, 0.3213536962866783, 0.2783299349248409, 0.08574956442628588, 0.15792671857135637, 0.4332079142332077, 0.23307238199881145, 0.19703403008835657, 0.25435406288930346, 0.2347129982497011, 0.130702265139137, 0.2010009086557797, 0.3052498346992901, 0.4089544399508408, 0.25051795159067425, 0.4593739616019385, 0.23181478519524845, 0.2332520852131503, 0.14152964843170984, 0.169405034078019, 0.1738607564142772, 0.3182844652661255, 0.44489334576896256, 0.29896852746605873, 0.22822335362434387, 0.15780397158648285, 0.17433529666491918], [0.0614420651857342, 0.02196858054958284, 0.033218211095247946, 0.02902686296563063, 0.05894035406942878, 0.025526470438178097, 0.05626332986035517, 0.07654323522001505, 0.10796501128269093, 0.07699745334684849, 0.09214913352791752, 0.06371425504663161, 0.09772703064871685, 0.04370896977239421, 0.05866295538310494, 0.011140796921348997, 0.018971983310101286, 0.026185392402112484, 0.029769061532403742, 0.011481888841704598, 0.028784154382135187, 0.04331509715744427, 0.06735476505543504, 0.05179581458547285, 0.017435427189671567, 0.03976539209751146, 0.06094580502914531, 0.07960741794002907, 0.047290487946676354, 0.011185299488715827, 0.09465759606765849, 0.0170683007288192, 0.011882606178655155, 0.032186488421367745, 0.056038476925875456, 0.08717176704002277, 0.04386809641229255, 0.10619761076356683, 0.018846607002030526, 0.04402931294004832, 0.025951394511918937, 0.04365952831826039, 0.07784013277185814, 0.15242818290633814, 0.051891789971185584, 0.04192158639697092, 0.11147292876350028, 0.19139017936374458, 0.05723522270896605, 0.15876716561615467, 0.19104757346212864, 0.4462191489126001, 8.495702249663216, 24.033094576426915, 26.382669619151525, 41.35407992771694, 57.42936617987496, 58.547772543770925, 61.50087506430489, 44.931533677237375, 31.551405021122523, 21.51823057447161, 17.834606613431657, 10.804975134985787, 1.3775526753493716, 7.615466237068176, 13.011623995644705, 11.703966072627477, 8.601796899523054, 1.3561650344303675, 3.9558296288762773, 3.707623907497951, 12.96428678716932, 19.18329017502921, 34.75348581586565, 51.49478816986084, 43.49006734575544, 16.74701029913766, 4.173731216362544, 7.898978795324053, 5.806361598627908, 2.501124373504094, 1.2190365812608173, 0.06839160049068076, 0.27402897285563604, 0.34774515298860414, 0.1055108993979437, 0.21690502310437815, 0.36093318675245556, 0.06724339710282427, 0.0795800933348281, 0.9830910648618425, 0.3705932998231479, 0.15581207775643893, 0.3057924455830029, 1.318474205476897, 0.34856183773704935, 0.6670430238757814, 0.40209065111620085, 0.7591056238327707, 1.334900398339544, 3.5581546936716353, 8.224782432828631, 13.920827048165457, 25.504825523921422, 31.101849624088832, 35.00380856650216, 30.9817430632455, 23.301534380231583, 13.100368125098091, 14.530502813202993, 11.633805768830435, 5.193186981337411, 2.9332113478864943, 7.663120457104274, 5.740023672580719, 6.735753944941929, 2.5674642537321364, 6.688280378069196, 8.016643932887487, 12.93531106199537, 17.62753987312317, 21.017527750560216, 29.864406721932546, 34.380544730595176, 17.64572330883571, 7.095985037939889, 0.5544057222349303, 0.04600979041840349, 0.051217027607240846, 0.10386793541588954, 0.060057765538139005, 0.11467754787632398, 0.016787385534761206, 0.025810394935043793, 0.016439230913030248, 0.06660352500953845, 0.03901522752961942, 0.0555127819201776, 0.05089898467329996, 0.017133492677073394, 0.07482137118599244, 0.08008509302245718, 0.05762996045606477, 0.06774440021919352, 0.10026975920689957, 0.0599187540688685, 0.1657678692468575, 0.15790317340620927, 0.09191927300500018, 0.023417118803731034, 0.15713827445038728, 0.10291676502674818, 0.11575987908457007, 0.020482580377055064, 0.09883526832397495, 0.032986158904220374, 0.0874421021768025, 0.0526172151522977, 0.06506255162613732, 0.10816671938768455, 0.01624673222457724, 0.1421156855566161, 0.1754877883940935, 0.10969699227384158, 0.09203969261475972, 0.11108598059841565, 0.02234768824252699, 0.022817198852343217, 0.013715769463617886, 0.0842213203598346, 0.03954632028139063, 0.06638424284756184, 0.06528436472373349, 0.11990165683840003, 0.021331168145739605, 0.05383495141619018, 0.09117983946842806, 0.05265979661739298, 0.04620368519265737, 0.07280642752136503, 0.05372001776205642, 0.061729716536189826, 0.07599069058362927, 0.07678109567080225, 0.09275347074227673, 0.0646655068599752, 0.06856370411281075, 0.0845684724460755, 0.05695240931319339, 0.08577994243907076, 0.05233786228512015, 0.029669496696442366, 0.029215682297945023, 0.03315707169739263, 0.028981051673846583, 0.0279940257979823, 0.026169160148128867, 0.03610607649066618, 0.06292313749768905, 0.06659395088042531, 0.05730508467448609, 0.14576338125126703, 0.05763033365032502, 0.06956366116979293, 0.014046443326930915, 0.07372211731438126, 0.043595684958355765, 0.06128545251807996, 0.02755840801234756, 0.014901631545009357, 0.07579532678106002, 0.023752720527616993, 0.00848321698140353, 0.03892117579068456, 0.08293373230844736, 0.029160598825131143, 0.04557637617524181, 0.1824859000210251, 0.06270215221281562, 0.047626291534730365, 0.043366947410894294, 0.10105277504771948, 0.25216671026178766, 0.17372563295066357, 1.6273813439267022, 2.574601573603494, 11.90096834727696, 29.88395200456892, 49.572183404650005, 58.876741954258506, 72.19923182896206, 82.5539584841047, 81.41794885907854, 71.04004301343645, 60.029309136526926, 48.41510336739676, 38.05111128943307, 35.77017055238996, 33.385798931121826, 29.98385320390974, 26.19711971282959, 23.890434162957327, 19.204513447625295, 16.958431822913035, 18.522886480603898, 20.422110557556152, 30.970143045697892, 34.89728225980486, 43.41149364198957, 54.41929190499442, 67.39271123068673, 54.19241237640381, 27.354611430849346, 10.259892429624285, 10.276700122015816, 8.068138769694738, 2.7438364582402364, 0.6914997058255332, 0.22221340611577034, 0.18878404849341937, 0.2765514946409634, 0.4175413006118366, 0.1311430821993521, 0.33128706898008076, 0.7203405382377761, 0.25537289679050446, 1.0282264543431145, 0.47304877638816833, 0.226992504671216, 1.6185486635991504, 1.6516429334878922, 1.612673310296876, 1.99933545930045, 1.1669510390077318, 1.7206008732318878, 1.2903210818767548, 2.2997877257210866, 10.208825775555201, 18.899914843695505, 34.77868693215506, 45.723426818847656, 45.23185913903372, 43.60939918245588, 41.376088346753804, 36.71521588734218, 40.280652727399556, 32.032324586595806, 23.709409270967754, 15.268694196428571, 11.962445139884949, 16.416651248931885, 20.00084822518485, 22.069281782422745, 19.798782450812205, 14.745512213025775, 14.24321825163705, 27.619853700910294, 35.59078196116856, 46.40285989216396, 49.688343388693674, 35.10283776691982, 19.87941803250994, 3.8129946419170926, 0.46887437467064175, 0.14331228206200258, 0.08446196280419827, 0.16455812273280962, 0.16590433620980807, 0.07683151082268783, 0.08710257003882102, 0.017702422237821987, 0.04280041816777416, 0.11716002252485071, 0.09660760393100125, 0.15553222277334758, 0.04255405228052821, 0.07002367398568562, 0.09713612842772688, 0.07003121929509298, 0.11088515458894627, 0.07493662035890988, 0.1619057429156133, 0.3078284306185586, 0.2479503479387079, 0.28872918976204737, 0.29744263791612213, 0.21386538978133882, 0.1413799093237945, 0.08611359846379076, 0.03967164909201009, 0.06639788140143667, 0.049152829085609744, 0.10669827461242676, 0.1947501219276871, 0.0761136207729578, 0.12522286416164466, 0.05748648422637156, 0.14100237243941852, 0.21757492715758936, 0.07222033611365727, 0.11723211008523192, 0.09445414412766695, 0.03910422418266535, 0.050396061302827935, 0.013775222701951861, 0.08721501007676125, 0.08765206126762287, 0.025321602056335126, 0.033763196851525984, 0.10420989670923778, 0.04142045435894813, 0.14065469109586307, 0.0917999797633716, 0.16619405709207058, 0.1271662970206567, 0.19170943009001867, 0.1947482084589345, 0.18672047422400542, 0.27320433567677227, 0.29205952105777605, 0.20698347049100058, 0.1473347055060523, 0.15003500346626553, 0.2904045470058918, 0.16486137360334396, 0.2073550634086132, 0.20018957076328142, 0.11193782703152724, 0.13798504934779235, 0.12505660951137543, 0.09836241084017924, 0.12362947394805295, 0.09883151602532182, 0.17841782474092074, 0.09753806543137346, 0.12968282055641922, 0.14706829908703054, 0.22911950839417322, 0.24641696736216545, 0.1468159519135952, 0.08373202875788723, 0.20783292848084653, 0.1263476445206574, 0.10444554513586418, 0.2189022773610694, 0.18803753783660276, 0.23724306534443582, 0.1364517637661525, 0.15142719447612762, 0.09808809948819024, 0.1644513891743762, 0.20237131869154318, 0.09704086889645883, 0.23559148396764482, 0.1715196884636368, 0.1944241537047284, 0.21234579703637532, 0.19674992747604847, 0.5543296720300401, 0.12770099618605205, 0.32172813905136927, 0.3919356146029064, 3.3345733880996704, 15.95143461227417, 37.15418570382254, 44.28468765531267, 60.89527007511684, 84.42915221623012, 88.82256766727993, 86.95469733646938, 83.24563775743756, 69.20687893458775, 60.97664042881557, 57.16941670009068, 46.656910351344514, 42.49789932795933, 41.405090127672466, 47.16130093165806, 44.22232409885952, 49.83377960750035, 47.10602453776768, 52.64099080221993, 49.38982445853097, 57.51988731111799, 65.46536431993756, 81.16417980194092, 88.39528124673026, 85.52078369685582, 54.56205654144287, 26.829056637627737, 20.696333374295914, 11.860142469406128, 3.669459189687456, 1.963604348046439, 0.8375675050275666, 1.1515428658042635, 0.906527290386813, 0.8593487505401883, 0.43593958765268326, 0.8914894887379238, 0.9965694844722748, 0.30590106546878815, 3.3466154847826277, 0.8270404413342476, 1.1148558344159807, 4.645433127880096, 5.233344963618687, 3.3703553080558777, 2.7674410087721686, 1.4230034479073115, 3.2887278710092818, 1.9161147134644645, 5.107617310115269, 16.557882070541382, 27.7227269921984, 49.77454621451241, 66.22092533111572, 73.19279643467495, 67.10307557242257, 63.040637561253135, 45.71411970683506, 46.329400062561035, 44.39614370891026, 47.290283816201345, 41.267303875514436, 43.279523032052175, 43.874778679439, 41.15152951649257, 39.1479434967041, 31.33943632670811, 37.12319326400757, 47.051387378147666, 56.0753116607666, 54.93406309400286, 57.13406079156058, 55.09794330596924, 30.14885207584926, 10.777491535459246, 1.163730440395219, 0.2626789276088987, 0.1788597953106676, 0.14051131664642266, 0.3176611629979951, 0.28331830725073814, 0.21280109403388842, 0.240100837711777, 0.12424585515899317, 0.16507671347686223, 0.22317612517092908, 0.20330906765801565, 0.3431658829961504, 0.14519787659602507, 0.18745644044663223, 0.17309212551585265, 0.1761744794036661, 0.1532059604568141, 0.17668616266122886, 0.399075377200331, 0.3898613873336996, 0.3846964601959501, 0.26060752304536955, 0.3473261711852891, 0.4046870789357594, 0.21583498695066997, 0.14184444796826157, 0.2878530653459685, 0.3199472017586231, 0.27272450285298483, 0.37813038538609234, 0.3113194390067032, 0.2714954588030066, 0.3866945558360645, 0.263364953654153, 0.3243497812322208, 0.4197146211351667, 0.2793992246900286, 0.2299331533057349, 0.16583793477288314, 0.1819587325943368, 0.12494444767279284, 0.2343999764748982, 0.2667623513511249, 0.2648305078702313, 0.3738332502543926, 0.15282443378652844, 0.23807568209511892, 0.1630825126277549], [0.058978521664227755, 0.0398694929400725, 0.03162921778857708, 0.032450306229293346, 0.1206213789326804, 0.09846427930252892, 0.05293728012059416, 0.005673770302174879, 0.020045688641922813, 0.05461677982072745, 0.07732547753091369, 0.009942974812085075, 0.029006564590547766, 0.04140508893345084, 0.037045240202652555, 0.02082636862594102, 0.0242339647042432, 0.04129103058949113, 0.0839916430413723, 0.042995826075119634, 0.03618767032665866, 0.03865721209772995, 0.052467723709664175, 0.08578438684344292, 0.07202896888234786, 0.03881637605705431, 0.06693078923438277, 0.017212043283507228, 0.049360667754496844, 0.031953109694378715, 0.06381347043705837, 0.009941115626133978, 0.012829376268200576, 0.06475490384868213, 0.07461778353899717, 0.05950435916227954, 0.06148827342050416, 0.07980191321777445, 0.01757752938595201, 0.028752246272883246, 0.010474293176749987, 0.037812273151108196, 0.030845682868467908, 0.041685754765889475, 0.056067134852388074, 0.013841888767534068, 0.04112153932718294, 0.011266448036102312, 0.03477794936458979, 0.026115954520979097, 0.11040989509118454, 0.10243145642536026, 0.015359871688165834, 0.11326700249420744, 0.6756056472659111, 6.0224657739911756, 15.652526582990374, 28.11330607959202, 41.34429339000157, 41.337491103581016, 34.40052774974278, 28.704589094434464, 30.5619398525783, 19.42214318684169, 11.767872997692653, 5.865904186453138, 2.181166125195367, 3.793257415294647, 3.9130769286836897, 8.000095929418292, 8.20385011604854, 5.5785084537097385, 13.665724805423192, 19.670756680624827, 28.562020744596207, 27.88935000555856, 31.689267703465053, 11.93640329156603, 7.645583203860691, 9.472414868218557, 4.210435509681702, 5.021239476544516, 3.296680301427841, 0.614732696541718, 0.304477797555072, 0.31591968930193354, 0.18518896640411445, 0.11366319230624608, 0.3471820774887289, 0.060673800696219714, 0.2704378126987389, 0.30859164680753437, 0.20551297653998646, 0.0733882441584553, 0.3370222369475024, 0.24853367092353956, 0.634982949921063, 0.7172821909189224, 1.0415716639586856, 2.2671374891485487, 5.797044932842255, 11.795157705034528, 16.965041296822683, 18.795116901397705, 20.568807874407085, 18.50838037899562, 17.004941327231272, 12.409640754972186, 8.18502049786704, 10.847016947610037, 8.370181305067879, 8.937222923551287, 4.314876054014478, 7.217228063515254, 2.8202992124216895, 3.1559345509324754, 4.891903102397919, 4.980394056865147, 6.139081733567374, 13.106158580098834, 14.33425007547651, 25.78276562690735, 26.989662511008127, 18.282980816704885, 6.546092442103794, 1.0228826382330485, 0.10023765092981712, 0.03604482852720788, 0.05701729761702674, 0.06223603258175509, 0.03646670428237744, 0.06504234485328197, 0.08305420620100838, 0.052673560700246265, 0.012488431929211532, 0.05424446765599506, 0.11242736969143152, 0.0974748395383358, 0.057135247359318395, 0.04431448085233569, 0.0357441560897444, 0.054656548758170435, 0.10612063096570117, 0.058638663829437325, 0.03612650378740259, 0.0843030024053795, 0.03538987599313259, 0.14988326946539537, 0.09306768673871245, 0.08712977250771863, 0.05561859267098563, 0.0523944656763758, 0.0765521986676114, 0.07426291650959424, 0.10188855377158948, 0.042926642644618235, 0.019929302922849144, 0.033548494800925255, 0.02742380871703582, 0.11689349396952561, 0.2814859641449792, 0.11738777958921023, 0.14070977456867695, 0.06899088261915104, 0.032861569696771245, 0.06473581665860755, 0.03983666541587029, 0.058196713615741046, 0.07532526486154113, 0.04022406819941742, 0.08434929884970188, 0.0246016526528235, 0.046987613663077354, 0.03435972412782056, 0.06061802511768682, 0.04255634233621614, 0.017039512184315493, 0.11214858679366962, 0.07160832466823713, 0.05937601426350219, 0.10760176434580769, 0.07334609356309686, 0.08634359469371182, 0.027169743153665746, 0.04419351502188614, 0.029929077053176503, 0.04776512997757111, 0.06848304665514401, 0.0633736304672701, 0.0235417894353824, 0.007333709958142468, 0.018049218093178103, 0.04347468859383038, 0.026864371861198118, 0.035858750476368835, 0.11082433749522481, 0.03158896030592067, 0.013513176718593707, 0.025758626105796014, 0.07761369885078498, 0.06919410385723625, 0.04516641888767481, 0.10288173226373536, 0.06376409344375134, 0.044258701881127696, 0.09899460870240416, 0.057873072767896314, 0.14795776350157602, 0.08335068529205662, 0.08237531834415027, 0.025018120483894433, 0.04859692230820656, 0.06252622165318046, 0.040596651778157265, 0.03573982025097523, 0.05329419293307832, 0.03273424260052187, 0.009452326140100402, 0.03886015174378242, 0.09121247021747486, 0.07609822481338467, 0.05731799719589097, 0.009382944238106055, 0.03582105107073273, 0.033883602890585146, 0.29027489253452843, 0.14174464903771877, 0.2526754486773695, 1.2806774164949144, 3.0534720718860626, 7.884529147829328, 23.381433452878678, 40.39580522264753, 55.82189696175711, 71.52035113743374, 67.63466835021973, 60.24829551151821, 48.646130970546174, 36.67750801358904, 24.694660357066564, 20.780368362154277, 21.89575399671282, 23.438905477523804, 22.089787653514318, 18.230455909456524, 16.15975202832903, 17.74651735169547, 20.577970811298915, 30.153375353131974, 39.90640190669468, 60.2845790045602, 60.823516028267996, 61.11283901759556, 34.331490448543, 10.16891098022461, 8.077484965324402, 12.923698885100228, 11.253124390329633, 3.587141275405884, 0.5646336876920292, 0.16378679126501083, 0.3134442035640989, 0.4104972114520413, 0.5641519278287888, 0.3435515894421509, 0.13541755426142896, 0.25596620781081064, 0.2864866315254143, 0.11590471916965076, 0.15661397044147762, 0.5081485243780273, 0.15838508254715375, 0.20712845985378536, 0.7511486879416874, 1.491041077034814, 2.7493400829178944, 7.692967312676566, 16.97474445615496, 25.035012653895787, 33.27754599707467, 40.74732501166207, 43.957236426217214, 40.07012578419277, 32.05387095042637, 29.71572916848319, 23.06912234851292, 22.19564172199794, 21.05426287651062, 14.676417589187622, 13.816964507102966, 19.464690480913433, 18.532933575766428, 18.400492225374492, 13.319835662841797, 7.115930710520063, 16.408433267048427, 28.598163536616735, 38.41870920998709, 38.153083051954, 32.45517805644444, 19.528068474360875, 5.3563219990049085, 0.6531875016433852, 0.05824706769947495, 0.03622564793165241, 0.050887619211737595, 0.07953760347196034, 0.16958194172808103, 0.11429170572331973, 0.08812951243349484, 0.059829173875706534, 0.0735425633777465, 0.04851281789264508, 0.01940883942214506, 0.035084090794303587, 0.05705319890486343, 0.02875589339860848, 0.049967803925807984, 0.06604906690440007, 0.06229595400925193, 0.13104104410324777, 0.07942615409514733, 0.07466843617813927, 0.1550566918615784, 0.25729971911226, 0.17080709098705224, 0.2604140591408525, 0.16366739624312945, 0.23274698374526842, 0.10339693033269473, 0.19388512548591408, 0.10641337132879666, 0.11871540120669774, 0.1658665825213705, 0.25260037556290627, 0.12135245970317296, 0.24145465078098433, 0.1587615202047995, 0.17394196348530905, 0.11845966135816914, 0.13466903514095716, 0.08848592652274029, 0.06326471202607666, 0.11080658701913697, 0.054485222058636804, 0.01858822934861694, 0.07578953887735095, 0.019334960529314618, 0.0801030131322997, 0.027330771387953843, 0.011053399914609534, 0.03135869944734233, 0.0969296841483031, 0.14926867958690437, 0.10464096322123494, 0.2951448740703719, 0.2088411772357566, 0.20150216961545603, 0.184232408446925, 0.10707783353115831, 0.13997302124542849, 0.09142095688730478, 0.15591403442834104, 0.1281677604253803, 0.11855990812182426, 0.08202863444707223, 0.11229059738772255, 0.10493286898625748, 0.12544030749372073, 0.07283154010240521, 0.19563957277153218, 0.21330145932734013, 0.07371759827115706, 0.08735919198287384, 0.11688533797860146, 0.1959152886910098, 0.23142829164862633, 0.13311580062976905, 0.269420254443373, 0.15260696331305162, 0.2752141835434096, 0.10830514731683902, 0.1711645025227751, 0.22842031876955712, 0.15534034664077417, 0.1540015156247786, 0.15157719142735004, 0.15707438359303133, 0.1885032435613019, 0.2207537144422531, 0.11505101355058805, 0.18902667904538767, 0.08595387132040092, 0.10614465110536132, 0.16969703483794416, 0.2024428905653102, 0.21498049423098564, 0.1468306625527995, 0.13013107436043875, 0.10281527654400893, 0.11012763809412718, 0.3340065287692206, 0.2840595117637089, 0.1402419518147196, 0.28394413366913795, 0.5245965932096753, 2.491396244083132, 11.588962963649205, 27.541775056294032, 44.459424427577424, 67.97799968719482, 71.1353861945016, 73.44166701180595, 70.1955589566912, 65.00194031851632, 61.27411365509033, 54.655065127781455, 43.315608501434326, 34.2450270652771, 29.159831592014857, 32.598397799900596, 42.42779895237514, 51.60166188648769, 50.45787722723824, 65.39809186117989, 66.57736097063336, 80.9799622126988, 70.66033785683769, 80.22087151663644, 66.00941521780831, 37.53301886149815, 23.377247163227626, 27.071917022977555, 18.3832711151668, 5.857956750052316, 0.647557289472648, 0.39062536348189625, 0.6175311378070286, 0.5546474978327751, 0.3249464849276202, 0.43796889590365545, 0.15277996260140622, 0.5957367015736443, 1.7911327970879418, 0.454956725771938, 0.2230951895139047, 0.9784545536552156, 1.4729678354093005, 2.430411470787866, 2.656342787402017, 1.5914676253284727, 2.308776740516935, 7.871651530265808, 22.910595723560878, 40.505955014910015, 55.26803868157523, 67.29131616864885, 65.8075839451381, 57.70055784497942, 47.4136768749782, 44.27247272218977, 48.23741708483015, 39.349840777260916, 43.129396779196604, 35.10734714780535, 38.662504128047395, 35.53797912597656, 33.807217597961426, 33.23956714357649, 42.505705629076274, 38.997820717947825, 45.50021941321236, 49.54489435468401, 56.76848479679653, 46.56249475479126, 29.235229969024658, 10.978346586227417, 1.8745683942522322, 0.241548695734569, 0.15651485004595347, 0.2101913804986647, 0.2100306898355484, 0.22562022187880107, 0.3377481608518532, 0.21725719634975704, 0.2357209213078022, 0.20528692938387394, 0.27972351014614105, 0.18246669747999736, 0.11578121222555637, 0.15278232390327112, 0.1427295697586877, 0.12285673112741538, 0.11288576759397984, 0.21645701357296535, 0.16787898167967796, 0.19820865562983922, 0.3123643015112196, 0.14125125908425876, 0.3030832181019442, 0.2504407614469528, 0.3198388804282461, 0.4304219308708395, 0.36663011248622623, 0.21446606969194754, 0.18818206579557487, 0.2713615431317261, 0.23660155119640486, 0.4186263052480561, 0.26103543436953, 0.48743437017713276, 0.35287688619324137, 0.6240966969302723, 0.2692325445158141, 0.437806671751397, 0.19630589415984495, 0.35562598439199583, 0.21084094207201684, 0.16129715128668717, 0.1915406377187797, 0.21575928958398954, 0.13011043332517147, 0.2818265887243407, 0.21178719986762318, 0.2214172538369894, 0.11888594419828483, 0.1830410095197814, 0.10110971770648446], [0.08376774684126888, 0.026932875060343316, 0.022504714816542606, 0.07637088732527834, 0.039564990172428746, 0.08246748375573329, 0.04603746446913906, 0.027889456766258394, 0.022469593843977367, 0.037122131790965796, 0.07077176562909569, 0.04044874132211719, 0.05198999434443457, 0.05191273295453616, 0.06584815268537828, 0.06456820493830101, 0.04554967921493309, 0.0450700329882758, 0.0718023788982204, 0.015587252165590013, 0.037219355681112835, 0.010766012344642409, 0.007194159053532141, 0.06370637046971492, 0.0322655818558165, 0.082063592571233, 0.027612785808742046, 0.043899102069969685, 0.04996725431244288, 0.05360629190025585, 0.08624731057456561, 0.009476058750546404, 0.07903023569711617, 0.03341955279133149, 0.05721734331122466, 0.03188706788101366, 0.03558513123009886, 0.08337747385459286, 0.08893232114080872, 0.019997431231396537, 0.05881629751196929, 0.028393352138144628, 0.16344164764242514, 0.04646721801587513, 0.06445235186921698, 0.05173096699374063, 0.04586400038429669, 0.03341427378888641, 0.00886994122993201, 0.07756962800132376, 0.04779514836679612, 0.023885772763086215, 0.14177750370332173, 0.18549114518931933, 0.06430263311735221, 0.04545993956604174, 0.20121808057384832, 3.02920309986387, 10.238571013723101, 19.69945968900408, 31.071135112217494, 26.017317703792028, 30.114395959036692, 28.902232340403966, 26.394182784216746, 14.52472104345049, 5.400397896766663, 6.698275796004704, 4.129019558429718, 3.5139526426792145, 9.333635892186846, 16.231763158525737, 13.317745123590742, 19.80703169958932, 27.630114453179495, 19.655515807015554, 26.460736104420253, 18.99861400468009, 4.220806564603533, 4.351237280028207, 6.579916707106999, 5.510471258844648, 5.5305962818009515, 3.632354506424495, 2.3026529891150336, 1.3241481695856367, 0.7692963512880462, 1.3754810265132358, 0.8896603211760521, 0.34193382625068935, 1.1365248773779189, 0.3392666407993862, 0.5132818317839077, 0.8926518463662693, 0.9770915125097547, 0.7852879560419491, 1.032592528632709, 2.5619588920048306, 5.815410324505397, 12.641606364931379, 15.292151314871651, 11.11100333077567, 11.909961921828133, 13.017899087497167, 14.874887670789446, 14.930881466184344, 16.815060956137522, 15.646836008344378, 9.736103347369603, 8.856443166732788, 9.179117509296962, 7.246925967080252, 2.6362564138003757, 1.0740946616445268, 4.196177806173052, 4.6275293571608405, 9.186399221420288, 21.169425794056483, 20.509857620511735, 28.49067316736494, 34.357983929770334, 25.346601145608084, 11.549652661596026, 2.7144110543387274, 0.16308133197682245, 0.0812963323135461, 0.04070434546364205, 0.07176444879067795, 0.03519589300932629, 0.040467716553913693, 0.058524615663502894, 0.006634191668126732, 0.018216512598363415, 0.02563512764338936, 0.09506863901125533, 0.04394028914560165, 0.14382609591952392, 0.0916747764817306, 0.0075082427356392145, 0.03192097766857062, 0.045128176654023786, 0.034381223509886434, 0.05527712331552591, 0.07092700765601226, 0.0618580003668155, 0.020416579275791134, 0.05307167415906276, 0.0941342216517244, 0.08319282411996808, 0.07078661197530371, 0.09317556702132736, 0.13191338229392255, 0.06912983302026987, 0.049936788090105565, 0.11856809125414916, 0.03375047431992633, 0.044910397447113476, 0.03288858217586364, 0.04013595364189573, 0.03919674921780825, 0.13627860162939343, 0.12220213482422487, 0.05170330651370542, 0.11620083185178892, 0.05192486855334469, 0.07077820492642266, 0.041778283193707466, 0.18571176406528267, 0.09149599607501711, 0.07292616859610591, 0.07578430737235717, 0.06047282540904624, 0.011837956878090543, 0.05696713352309806, 0.03924034170008131, 0.022098050120153596, 0.06263103495751109, 0.06925028655678034, 0.06788005294012171, 0.029499377789241926, 0.05955848590071712, 0.03159561334177852, 0.032453091615544896, 0.007582855294458568, 0.07595441610153232, 0.03690275802676167, 0.20505170843430928, 0.05184741038829088, 0.051673420438809056, 0.026867399823718836, 0.052539573782788854, 0.04063654285190361, 0.009541496667744858, 0.04717760007562382, 0.018650228789608394, 0.038516032709074874, 0.072321478543537, 0.02523903452259089, 0.017076626353498017, 0.04958587691986135, 0.05393011934523072, 0.02224043899747942, 0.009377850136453552, 0.06971072684973478, 0.06362578086555004, 0.028183416796049902, 0.053642074444464276, 0.03995003504678607, 0.03534516053540366, 0.05758865802947964, 0.08468780639980521, 0.05026999628171325, 0.07014946080744267, 0.07020904975278036, 0.04399204101147396, 0.06150463968515396, 0.016515722165682485, 0.07837051645453487, 0.1381742384816919, 0.08371959799634558, 0.043811082507350614, 0.009679581088546132, 0.03966271957116468, 0.0514531577937305, 0.059126048747982295, 0.057612847802894454, 0.04056113386260612, 0.04195173031517437, 0.15367984931383813, 0.19949217247111456, 0.3326224801795823, 0.3454411466206823, 2.8176215503896986, 11.898025785173688, 27.293885912214005, 40.86931106022426, 51.27633680616106, 51.15859958103725, 51.97697230747768, 44.66353818348476, 30.512746606554302, 16.36374419076102, 11.739851781300136, 11.95531976222992, 17.438107660838536, 19.512203999928065, 21.8251724583762, 27.2196843624115, 32.34506300517491, 35.58853769302368, 49.990996497017996, 46.850275244031636, 52.92576272147042, 51.938413279397146, 29.122538873127528, 10.698499202728271, 6.09632773058755, 7.5636700221470425, 8.911162836211068, 5.36939286334174, 2.9492150034223283, 1.4370626934937067, 1.1962359590189797, 1.2488825683082854, 1.4408438163144248, 1.3515356885535377, 1.8558662320886339, 0.8611539793866021, 1.307432649391038, 1.7126880692584174, 1.1870535888842173, 0.6454596391745976, 1.007248974272183, 2.659079074859619, 7.323521171297346, 14.838044847760882, 19.804632834025792, 24.420119660241262, 26.381191389901296, 30.65307937349592, 34.136291231427876, 31.44362109048026, 29.94690615790231, 23.28601905277797, 16.97140063558306, 19.925173657281057, 21.807317325047084, 20.189479657581874, 15.205528123038155, 14.623015471867152, 15.618207693099976, 11.26552084514073, 10.699296508516584, 19.11187137876238, 26.362707444599696, 35.02713714327131, 39.29834072930472, 36.767466340746196, 24.01521338735308, 8.935469371931893, 1.8702589912073952, 0.23565903891410145, 0.09372304978647403, 0.042549818222011836, 0.02209992626948016, 0.07163901480713061, 0.040783822270376344, 0.0530451977226351, 0.04310497521821942, 0.05637791406895433, 0.06845348966973168, 0.08570629424814667, 0.07076274789869785, 0.05980151678834643, 0.0636639552456992, 0.036814579008413215, 0.012905105017125607, 0.011202952425394739, 0.14084924065640994, 0.06883593236229249, 0.08124289089547736, 0.024029790124456798, 0.0749193923547864, 0.08139130007475615, 0.1838950136942523, 0.17632390638547285, 0.20378359433795723, 0.16869158164731093, 0.10109221150300332, 0.1841565210904394, 0.144354091158935, 0.08857878404004232, 0.1502132953277656, 0.05787527122135673, 0.1174736956932715, 0.1157597569482667, 0.1477081983217171, 0.2611817808023521, 0.23169978708028793, 0.2152074370533228, 0.20360078343323298, 0.13818869127758912, 0.019749891478568316, 0.18604206134166035, 0.09370785738740649, 0.06350086935396705, 0.01843647668803377, 0.12038596799331051, 0.01907075595642839, 0.03034241683781147, 0.037966551658298285, 0.04907104865248714, 0.1716370071683611, 0.1932207447077547, 0.18514092612479413, 0.15441550341035637, 0.1714855988642999, 0.13430289764489445, 0.12476261385849544, 0.09613046489123787, 0.1612449719437531, 0.15151589257376535, 0.2239050753414631, 0.09048085340431758, 0.17039360531738826, 0.17303426004946232, 0.15589837384011063, 0.12614383974245616, 0.17492402078849928, 0.1405763474426099, 0.13228846288153104, 0.11106765336756196, 0.10169248429260083, 0.10387953157935824, 0.11771252644913537, 0.164325195231608, 0.14458814502826758, 0.1214862260967493, 0.1490467714944056, 0.16470153789435113, 0.16056692547031812, 0.22939263230987958, 0.14695434591599874, 0.1272325763212783, 0.20322648994624615, 0.18184921704232693, 0.11197055277547666, 0.171719489885228, 0.12443067452737264, 0.2005215236651046, 0.1758092511445284, 0.25029303080269266, 0.20984810963273048, 0.22342425185654843, 0.2860915884375572, 0.28963753102081163, 0.12714357966823236, 0.11728743783065251, 0.1535379540707384, 0.13456399792007037, 0.1830718285803284, 0.279388069574322, 0.2484919817319938, 0.22135345797453607, 0.25158311586294857, 0.260440711996385, 0.22606534085103444, 0.11315585845815283, 0.4826097690633365, 4.771795238767352, 16.26775656427656, 32.97066143580845, 53.37424462182181, 54.05604008265904, 63.84621170588902, 66.26724202292306, 64.64427484784807, 47.866303375789094, 34.153335162571494, 32.09259673527309, 32.34090450831822, 31.974644115992955, 33.45332152502877, 59.51594148363386, 57.56955998284476, 59.454880714416504, 70.90077332087925, 62.782859393528526, 70.81238528660366, 84.52120889936174, 65.7883860724313, 44.16621044703892, 35.69648143223354, 30.475202015468053, 20.536536966051372, 9.709120886666433, 4.064167244093759, 1.9752351982252938, 1.650474984730993, 1.3208119486059462, 2.3265074576650346, 3.6859090498515537, 2.479325920343399, 0.6952992847987584, 1.839160374232701, 2.786392003297806, 1.7615558356046677, 1.4476978885275977, 1.5803625583648682, 3.632702350616455, 8.82628972189767, 21.367873294012888, 35.58632469177246, 43.60849591663906, 58.310401235307964, 60.02284036363874, 62.575733593532014, 58.11641795294625, 58.31006077357701, 56.719604219709126, 47.26227910178048, 44.911321367536274, 46.370165143694194, 39.39123467036656, 35.74057470049177, 30.62492527280535, 34.39355523245675, 31.405833312443324, 45.07295731135777, 54.9308808190482, 56.162987504686626, 56.18572548457554, 56.155810015542166, 35.19225760868618, 16.715250083378383, 3.9393967049462453, 0.6073360134448323, 0.2826240845024586, 0.3586409868938582, 0.17310315849525587, 0.10689812353146927, 0.18210278557879583, 0.15129083607878002, 0.12346662554357733, 0.10124490902359996, 0.13818455221397535, 0.19348329704787048, 0.18165983791862214, 0.2844119971351964, 0.17487929176006997, 0.09657422679343394, 0.10237238316663674, 0.08889781084976026, 0.1689964881432908, 0.15434398581939085, 0.12028699687549047, 0.12253510552857604, 0.11442674776273114, 0.10093304075832878, 0.2037133795342275, 0.23309737922889845, 0.20515709849340574, 0.3606107740529946, 0.3768739828041622, 0.2107393518090248, 0.356484874018601, 0.2557004392147064, 0.20147775592548506, 0.3029158099421433, 0.25844101501362665, 0.4412397061075483, 0.2893521120505673, 0.3401777504810265, 0.4426118124808584, 0.37910185754299164, 0.2543802543410233, 0.22608512693217822, 0.18908455808247837, 0.18167830764182977, 0.31346089552555767, 0.27891187369823456, 0.2867169534521443, 0.19737162840153488, 0.2912204989365169, 0.10990566214812653, 0.16802823224237987, 0.1109095411375165, 0.10235179641417094], [0.042478857029761584, 0.07410909262086664, 0.03196344378271273, 0.03558428645400064, 0.12659687043300696, 0.030731539707630873, 0.035039449975426705, 0.042837147268333604, 0.015954809496179223, 0.07305675944579498, 0.060443159858030934, 0.022915075832445706, 0.01392958772235683, 0.02383137121796608, 0.08999194178198065, 0.020149813233209506, 0.015217669407970138, 0.031916892887758355, 0.006027415120375476, 0.05988641508987971, 0.03632614575326443, 0.013806245323004467, 0.021630651450582912, 0.05124808754771948, 0.06397123661424432, 0.035033427977136204, 0.05360600013019783, 0.03113337153834956, 0.023523119544344287, 0.03831687928842647, 0.046376138260321956, 0.08618805411138705, 0.09334615072501556, 0.012954730523883231, 0.0809677110186645, 0.06601474660315684, 0.07783238390194518, 0.02396779746881553, 0.06000503658183983, 0.023668648342468908, 0.03106281068176031, 0.022468046784134846, 0.022721191236217107, 0.03696851824809398, 0.08032533513115984, 0.05022759123572281, 0.10375696101358958, 0.03957456769421697, 0.09198540302791766, 0.20305464416742325, 0.0687587218625205, 0.15327253831284388, 0.01451852049545518, 0.10097968325551067, 0.03900203002350671, 0.08397490358246223, 0.06539774792534964, 0.14373234952134745, 0.26366964301892687, 1.2399827944380897, 6.999806335994175, 21.49154601778303, 31.711679118020193, 43.51937484741211, 37.677909646715435, 20.664929253714426, 15.783783265522548, 4.802406830447061, 8.673164452825274, 8.720907262393407, 9.273993424006871, 4.982091154370989, 17.026981013161794, 12.983530691691808, 28.359583241598948, 27.26117205619812, 33.752462318965364, 38.39076702935355, 31.716588020324707, 17.750721011842998, 13.363552859851293, 12.220938972064427, 5.9671333602496555, 3.368236541748047, 1.142000057867595, 4.4812975696155, 4.161306534494672, 1.809681556054524, 1.5292264223098755, 3.201722093990871, 5.045470016343253, 7.618645037923541, 10.352522339139666, 12.366932783808027, 13.604670984404427, 11.625288145882742, 14.969862597329275, 19.742964097431727, 14.627872262682233, 13.931278007371084, 12.266461832182747, 13.67842958654676, 24.334726299558366, 26.44007911000933, 20.792583295277186, 19.438711166381836, 12.849089128630501, 12.848455105509077, 10.581470693860735, 5.597106175763266, 4.908544906548091, 4.6131791557584485, 4.871203550270625, 6.092232201780591, 7.476653388568333, 6.039036359105792, 12.711083139692034, 23.384089401790074, 30.302243982042583, 26.653180360794067, 17.08848820413862, 2.3395765849522183, 0.0547413079600249, 0.1397743597626686, 0.021373376416574632, 0.014220364574742104, 0.06253088997410876, 0.028411362153877105, 0.047604982142469714, 0.07641019485890865, 0.04495339621124523, 0.06864899596465485, 0.04615390786368932, 0.06289655928100858, 0.014246378759188312, 0.05519704261262502, 0.051551606439586194, 0.05954528160925422, 0.09457588009536266, 0.011393624158310038, 0.007363165163301996, 0.049219199988458834, 0.08415808768144675, 0.03699376653613789, 0.03524944977834821, 0.024352402991748283, 0.038359335224543295, 0.10980373261762516, 0.04318577516824007, 0.10317634538348232, 0.1743502922888313, 0.13635478754128727, 0.041594624120209894, 0.06258685554244689, 0.06975660938769579, 0.020387807694662894, 0.06758660690060683, 0.04641292503635798, 0.06840943917632103, 0.0844750924568091, 0.2017501334526709, 0.14271399059465953, 0.07549780274608306, 0.1055229501798749, 0.10094281166259732, 0.021190394181758165, 0.08343330371592726, 0.10559634052749191, 0.10525106798325266, 0.08556059920894248, 0.04420971504545637, 0.01529657285261367, 0.025713742710649967, 0.0459422117232212, 0.009997882713962878, 0.0364579443952867, 0.04396146283085857, 0.12276747663106237, 0.13109768820660456, 0.06167784931936434, 0.0939870745475803, 0.07680807422314372, 0.042804112790950706, 0.06374066362955741, 0.06107130008084433, 0.0691611949088318, 0.054728775418230464, 0.11540348535137517, 0.028545720569257225, 0.07713432743081025, 0.03168807052341955, 0.03400038555264473, 0.030358002787189822, 0.06785964939211096, 0.09654421518955912, 0.0920121440930026, 0.033220005820372274, 0.020344612155375735, 0.05141110558594976, 0.028173274393858652, 0.0498259222534086, 0.014366974788052695, 0.03482941624575427, 0.01495418238586613, 0.03350637813231774, 0.04675632821662085, 0.04016829262088452, 0.04192998666050179, 0.07077770281050887, 0.018635964287178855, 0.05958342206265245, 0.05773211390312229, 0.04256367051441755, 0.05370872015399592, 0.07155069668910333, 0.034348470624536276, 0.02027907415426203, 0.038696801223392994, 0.04294109544051545, 0.09284177528960363, 0.11299780729625906, 0.03921473718115261, 0.06783459109387227, 0.03215486190414854, 0.1117836299485394, 0.15428042065884384, 0.1978221485125167, 0.0941639414855412, 0.10490992093192679, 0.016371438479317085, 0.05315615176888449, 0.06822762571807418, 0.16612457510616097, 0.8349329435399601, 2.811146697827748, 8.615483113697596, 22.039241245814733, 32.141459941864014, 48.568509169987266, 52.10920694896153, 48.546059540339876, 31.349038737160818, 18.866495745522634, 12.287038922309875, 9.266032525471278, 16.290557077952794, 22.218280690056936, 32.13159697396414, 35.924979891095845, 38.694233076913015, 52.08729927880423, 38.91637045996529, 58.14165728432791, 61.963347162519185, 59.69259248461042, 40.412623337336946, 21.738259179251536, 7.014681560652597, 3.54656640120915, 9.845540949276515, 9.557803886277334, 6.554095029830933, 7.195128883634295, 5.854070535727909, 8.176201496805463, 10.064956375530787, 13.31945264339447, 19.45248770713806, 22.08687114715576, 20.08948118346078, 16.630591494696482, 12.4758814062391, 18.136203595570155, 21.7442398411887, 17.933748722076416, 19.50433169092451, 15.012191023145403, 13.692870548793248, 24.166446140834264, 35.53104134968349, 38.81605584280831, 39.38122926439558, 39.727002893175396, 36.2671925680978, 31.46775565828596, 24.825804131371633, 20.54378741128104, 21.756588527134486, 18.19640278816223, 14.94872270311628, 11.621648158345904, 13.428951910563878, 25.358631951468332, 37.6020770072937, 41.74037545067923, 42.23623364312308, 30.07545825413295, 9.937152079173497, 0.6104208507708141, 0.5839833893946239, 0.017556637292727828, 0.019181879636432444, 0.10193381884268352, 0.06244534027895757, 0.036531772397990735, 0.0768911676215274, 0.009452682370985193, 0.04180833211700831, 0.04801662219688296, 0.07939161666269813, 0.10857394896447659, 0.11692917134080615, 0.08217384094106299, 0.06821705414248364, 0.06809000524559192, 0.030166900184537684, 0.048044421776596985, 0.021869361766480973, 0.019931969565472434, 0.09583254730595009, 0.014405157649889588, 0.059890065608280044, 0.014698349238772477, 0.13637808843382768, 0.06433138264609234, 0.12948365695774555, 0.11476913653314114, 0.2086446327822549, 0.15118252831910337, 0.06379929584051881, 0.0254318606041904, 0.11115186634872641, 0.1741492287921054, 0.0869837992691568, 0.10735883523843118, 0.06856576007391725, 0.13876455037721566, 0.16177444638950483, 0.09004225515361343, 0.16834873147308826, 0.14444337279668876, 0.07410504176680531, 0.04438951664737292, 0.05617757999737348, 0.13834465933697565, 0.15973904489406518, 0.03618286629872663, 0.07774458825588226, 0.05622235991592918, 0.022199426644614766, 0.02712453406171075, 0.04242256237193942, 0.23817352684480803, 0.1269451081752777, 0.15396171276058468, 0.14357216097414494, 0.23356467272554124, 0.15774341912141868, 0.16444536378341063, 0.15161247524831975, 0.1324250791221857, 0.16586743747549398, 0.18050811971936906, 0.34065199217626024, 0.1240384541451931, 0.23272087371775083, 0.13262511124568327, 0.16205952609223978, 0.1226084144519908, 0.13744045714182512, 0.14207798615098, 0.16594907880893775, 0.11869891280574457, 0.12716005449848516, 0.11569336908204214, 0.21183952848826135, 0.17513341669525417, 0.08084703356559787, 0.10475275865090744, 0.0951973299628922, 0.10064559296837874, 0.114980459479349, 0.13425606515790733, 0.12937989538269384, 0.13792916520365647, 0.1571451955075775, 0.28689812230212347, 0.14738456425922258, 0.12146068603864738, 0.12252479179629258, 0.19331166840025357, 0.12476185389927455, 0.11584308104855673, 0.089153374279184, 0.15560980646737985, 0.1443176945405347, 0.18026139081588813, 0.16038974640624865, 0.22295765046562466, 0.1719132930572544, 0.3035727132643972, 0.42154761563454357, 0.30960684376103537, 0.3982076666184834, 0.14897667882697924, 0.25499867115701946, 0.17051316318767412, 0.15962043697280542, 0.2338756588952882, 0.2752237101750714, 0.6572823790567262, 2.853343976395471, 12.491327251706805, 32.60927867889404, 54.073813574654714, 68.69531781332833, 70.36847877502441, 55.98826462881905, 52.731060300554546, 39.26688970838274, 39.048636368342805, 35.168717111860005, 46.259879861559185, 47.985266957964214, 63.4675418308803, 55.02755110604422, 67.80655288696289, 62.40710776192801, 81.90223830086845, 84.87800584520612, 96.34569495064872, 78.20924295697893, 53.13235698427473, 34.08131013597761, 29.54350069590977, 30.9380875314985, 22.03477876526969, 13.99918188367571, 9.814935003008161, 6.87434184551239, 7.26736409323556, 8.252296430724007, 9.226959330695015, 18.83241309438433, 21.86429602759225, 25.231102977480205, 28.142648322241648, 23.225859812327794, 28.521820204598562, 39.99629422596523, 40.97074433735439, 47.63445241110665, 46.39136062349592, 48.24792276109968, 52.88261093412127, 64.7337120601109, 70.44755622318813, 68.08582183292934, 64.34753813062395, 57.81267397744315, 54.60681683676583, 44.09461620875767, 33.565840653010774, 35.69057893753052, 36.507885115487234, 36.74281760624477, 39.31335578645979, 41.05924006870815, 47.68794311795916, 51.378263405391145, 55.69961214065552, 43.28794772284371, 21.956720965249197, 3.6999244349343434, 0.09818318260035344, 0.29901645917977604, 0.2089708045657192, 0.13962779619864055, 0.15936006951544965, 0.10862742430929627, 0.2882019951939583, 0.20896270285759652, 0.21216575455452713, 0.1550622015659298, 0.11103627112294946, 0.1357034889182874, 0.3401090827371393, 0.2314844743481704, 0.15186453743704728, 0.11295354645699263, 0.21804196281092508, 0.1024029308131763, 0.11400273122957774, 0.13450256335948194, 0.1665525542838233, 0.10658393467643432, 0.11065082930560623, 0.10370334317641598, 0.10938419441559485, 0.22424882118191036, 0.13875251316598483, 0.36101729795336723, 0.41133875772356987, 0.27094313129782677, 0.27040157892874306, 0.171945007784026, 0.186517171561718, 0.13263520784676075, 0.35558912636978285, 0.3824581631592342, 0.2520611030714852, 0.7183415197900364, 0.5494392801608358, 0.43795380528484074, 0.20486371352204255, 0.35869874379464556, 0.28664445877075195, 0.15208865755370685, 0.12549541810793535, 0.344082312392337, 0.43436525070241516, 0.5210112684539386, 0.26703943791134016, 0.1322828038994755, 0.12600102169173105, 0.09169886447489262, 0.1593249621135848, 0.12129577488771506], [0.05825297095413719, 0.07477414514869452, 0.01912067238507526, 0.0318405610908355, 0.080413320767028, 0.022347832431218455, 0.04063063281189118, 0.017728159071079323, 0.08321486293737378, 0.10185196037803378, 0.031226039065846374, 0.03382144569020186, 0.038248045303459675, 0.041559421723442416, 0.05151875177398324, 0.027636140984083925, 0.05582821588697178, 0.045991137490740845, 0.0809279013691204, 0.07742248768252985, 0.05651624361053109, 0.01714425254613161, 0.0660008569913251, 0.0423791463087712, 0.027018546891797866, 0.036856597289443016, 0.06661845277994871, 0.050654898663716655, 0.014608553610742092, 0.023272794405264512, 0.0516655663959682, 0.044536904631448646, 0.05655433317380292, 0.04197361306952579, 0.0658496522477695, 0.0677682642957994, 0.06966452540031501, 0.04212117747270635, 0.027221362705209425, 0.048521112983248064, 0.01914025320937591, 0.03644608021048563, 0.030844006886971847, 0.07990750683737652, 0.04009330432329859, 0.03801957577733057, 0.04284807846748403, 0.045121981629303524, 0.04977689470563616, 0.0313338616729847, 0.050835575575807264, 0.1470251442598445, 0.07263191509991884, 0.04640290307413254, 0.08636988114033427, 0.04440261237323284, 0.032108517962374857, 0.0829766360776765, 0.18218100709574564, 0.20445628038474492, 0.1350170150399208, 0.7482679539493152, 4.873304077557155, 14.252712096486773, 35.097095080784385, 33.44794014522007, 32.96867077691214, 27.685321365083965, 14.17220071383885, 20.849921567099436, 17.670264346258982, 18.236518212727137, 21.533082348959788, 21.008927617754253, 20.131495203290665, 26.363860845565796, 25.04606897490365, 26.820301907403127, 25.314804451806204, 22.487848213740758, 19.61016491481236, 12.963500772203718, 17.24933900151934, 12.807205387524196, 12.94385300363813, 9.754814846175057, 12.300821542739868, 17.777494158063615, 21.037885972431727, 41.03951760700771, 41.26292651040213, 38.7967016356332, 20.000940288816178, 26.001293420791626, 33.50711447851998, 32.01550299780709, 28.68439415522984, 36.80785274505615, 29.62366553715297, 20.712751967566355, 19.69581709589277, 20.83592094693865, 13.410266467503138, 16.570505210331508, 19.7497490133558, 15.531266621180944, 13.449699231556483, 9.085242135184151, 11.139095766203743, 8.283128193446569, 10.516696112496511, 11.77072697026389, 16.28832844325474, 15.523361308234078, 12.845996311732701, 16.15162784712655, 24.879227093287877, 26.345953600747244, 17.420883076531545, 5.513257920742035, 0.23878268844314984, 0.017852675336013948, 0.05786550710243838, 0.02589376314011003, 0.038678267039358616, 0.07878556954009192, 0.054350865339594226, 0.014683128001966646, 0.016952773356544118, 0.08140852807887963, 0.04832327252786074, 0.01862933500004666, 0.05074228718876839, 0.05689839453303388, 0.03511241963133216, 0.020583422555189048, 0.03126126181866441, 0.024938436723979454, 0.023979391935946684, 0.021201959811151028, 0.07635589848671641, 0.0901193842291832, 0.05988368059375456, 0.04635143619296806, 0.027564038156664798, 0.014775217078360063, 0.018910446969260062, 0.009802595246583223, 0.034485368457223685, 0.037948129432541985, 0.1699921975710562, 0.12688148873192923, 0.014384703211752432, 0.0925965052364128, 0.05506355441840632, 0.03386169978018318, 0.04815183387004903, 0.07675520955984082, 0.07680506152766091, 0.09585198733423438, 0.23248580204589026, 0.12677825641419205, 0.05688032853816237, 0.0860411784212504, 0.10308441745915584, 0.10758089260863406, 0.09030731807329825, 0.12761878488319262, 0.11867548977690083, 0.08199501982224838, 0.0380257334826248, 0.10153726262173482, 0.026906916006867374, 0.06252075266093016, 0.04542864213830658, 0.06434515012162072, 0.08082139172724315, 0.16368169976132257, 0.2194799685052463, 0.1645486910960504, 0.0713284086169941, 0.06686907647443668, 0.021919515682384372, 0.03875600001109498, 0.06860394802476678, 0.14387265699250357, 0.0142180702782103, 0.022664433478244712, 0.04780335185517158, 0.034438369729157, 0.030601729173213243, 0.12167226682816233, 0.14618639355259283, 0.02674773338783, 0.07495645393750497, 0.08974499574729375, 0.10884994308331183, 0.020550625565062677, 0.02411164858910654, 0.02885481362630214, 0.015360017573194844, 0.03750486286090953, 0.029661690151052814, 0.05407659809238144, 0.020522848037736754, 0.055106030710573704, 0.0335156367426472, 0.05396847692983491, 0.06594276760837861, 0.057787149878484864, 0.13620787113904953, 0.04264515917748213, 0.10853863121675593, 0.07568285960171904, 0.03586034842633775, 0.03121302815686379, 0.08557386456855706, 0.018919181411287615, 0.05339635995083621, 0.053439484243946414, 0.044425407757184336, 0.01895061963503914, 0.06383447788123574, 0.046034407668880055, 0.024638598884588907, 0.08414319383778743, 0.09300030821136065, 0.12517323611038073, 0.18671435383813723, 0.04892565216869116, 0.09377952425607614, 0.031758495673005066, 0.022674759084890996, 0.09325850435665675, 0.17374286774013722, 0.8948223984667233, 1.5553891041449137, 7.442897302763803, 18.57719533784049, 34.502197265625, 47.7367125238691, 45.9377509525844, 40.775437423161094, 31.826855931963237, 24.401290042059763, 20.792010068893433, 24.107344763619558, 27.160039288657053, 40.32302631650652, 33.543238162994385, 38.95928600856236, 42.67576278959002, 46.52132320404053, 57.70644991738455, 61.7938597542899, 59.2940160206386, 54.081230776650564, 45.21444347926548, 45.13087749481201, 41.94303355898176, 53.907345158713206, 50.27276679447719, 49.74607597078596, 61.10317407335554, 56.55057191848755, 84.51569897787911, 76.1990179334368, 65.51846940176827, 41.62561900275094, 48.74471548625401, 62.784367152622764, 48.500663484845845, 45.091793877737864, 58.73022529057094, 52.80715697152274, 41.166614055633545, 37.843335832868306, 45.011701992579866, 34.76005186353411, 36.58101143155779, 46.00230319159371, 41.66026619502476, 38.452859606061665, 31.29581901005336, 33.13638292040144, 30.36611877168928, 18.06596773011344, 17.605493238994054, 18.244995015008108, 22.734950474330358, 25.143887451716832, 26.50074209485735, 32.61194331305367, 38.107492446899414, 32.88397223608834, 15.354956081935338, 2.996869440589632, 0.5532755543078695, 0.014487531801153506, 0.06491639518312045, 0.04042722836935094, 0.015294021560943552, 0.09203302940087658, 0.003379674150242603, 0.04672891540186746, 0.049844697317374606, 0.04756922334698694, 0.038836287667176554, 0.05411894546289529, 0.029343559007559503, 0.03808097641116806, 0.021604726323857903, 0.02399352751672268, 0.050254763170544586, 0.15617921948432922, 0.07223195941852671, 0.02100666386208364, 0.035969215977404795, 0.033434192184358835, 0.10567256036613669, 0.060277597313480716, 0.07600549621773617, 0.06608772304441247, 0.022691423904949, 0.04687690728210977, 0.09045050931828362, 0.13624063080974988, 0.06247824922736202, 0.09866246581077576, 0.13037033937871456, 0.029897131624498537, 0.12558222987822124, 0.11815889392580305, 0.11506005163703646, 0.08290856544460569, 0.13061001151800156, 0.12035523035696574, 0.09907420086009161, 0.1260050521897418, 0.05253590630101306, 0.05103283927642873, 0.02296112461148628, 0.05099918393950377, 0.08769782166928053, 0.17560763124908718, 0.14404237217136792, 0.04128505608865193, 0.1263387014291116, 0.02254904350931091, 0.0241539162317557, 0.1303415559232235, 0.1065238978979843, 0.1474741037402834, 0.14229745151741163, 0.2604716531932354, 0.1981522829404899, 0.23149818075554712, 0.11440818304462091, 0.11587209520595414, 0.12146608717739582, 0.1463597592498575, 0.19268516344683512, 0.10805697313376836, 0.1599647934947695, 0.0846846444266183, 0.0795880729066474, 0.0866957815097911, 0.1575448526335614, 0.22663038410246372, 0.2262009528598615, 0.13970841972955636, 0.1405547293169158, 0.12102779426745006, 0.08272477744945458, 0.11526458923305784, 0.09737168864480086, 0.07457918846713645, 0.06391054165682622, 0.17761624418199062, 0.18057361191936902, 0.10580862699342625, 0.1478052016879831, 0.2003655827471188, 0.16046253964304924, 0.10703984914081437, 0.161638807239277, 0.11523657930748803, 0.2191473642098052, 0.2033457356904234, 0.10210098951522793, 0.16558721608349256, 0.08820791036954947, 0.22238583543470927, 0.17772612614291056, 0.15831679478287697, 0.1970924519534622, 0.14909984650356428, 0.10541492740490607, 0.13931877778044768, 0.24896945325391634, 0.11522113585046359, 0.18987260865313665, 0.1981698569974729, 0.2818298999752317, 0.4090823845139572, 0.17396767996251583, 0.16152612971408026, 0.16007189346211298, 0.20086513379854815, 0.273063878927912, 0.31790912683521, 0.6106390676328114, 0.47722817212343216, 2.0428105550152913, 9.538860491343907, 22.323773452213832, 46.30606453759329, 56.0577883039202, 61.343797138759065, 64.92814350128174, 55.74015835353306, 60.076556886945454, 54.43958759307861, 56.17566449301583, 64.71710586547852, 62.79046767098563, 54.65190717152187, 64.60800525120327, 66.02065045492989, 74.1201308114188, 72.59003325871059, 64.71176964896065, 61.79607622964041, 55.747381005968364, 57.0807785306658, 58.99251283918108, 70.39633410317558, 67.99862888881138, 70.02606460026333, 74.39216668265206, 65.8310410635812, 95.44895349230084, 91.31813131059918, 78.91466576712472, 56.217103549412315, 70.08524240766252, 91.90207876477922, 79.23376873561314, 72.00425148010254, 82.69890485491071, 74.5304010936192, 65.9769115447998, 57.17809500013079, 55.19679185322353, 41.531102657318115, 42.7390261377607, 63.52532305036272, 58.08074937547956, 58.71147905077253, 50.213873863220215, 55.014693464551655, 52.74457802091326, 43.30788210460118, 43.62361519677298, 46.82719680241176, 50.51806252343314, 47.64702517645699, 41.690952914101736, 49.565075397491455, 40.79460750307356, 24.228055817740305, 6.666730540139334, 0.6200628876686096, 0.18146059289574623, 0.20176507479378156, 0.14405744921948227, 0.10305884347430297, 0.1632598273988281, 0.22600575190569672, 0.13248403024460587, 0.14972595790667192, 0.28876140660473276, 0.16570528117673738, 0.1410682581897293, 0.16521198621817998, 0.12513762659260205, 0.12941802905074187, 0.14023570929254803, 0.20589077126766953, 0.11559692211449146, 0.1861177044255393, 0.14841711813850061, 0.09500837831624917, 0.2740252544837338, 0.1131372055304902, 0.2097097427717277, 0.10695757676980325, 0.1340780718518155, 0.11625121986227376, 0.21123929641076497, 0.14725771892283643, 0.2362733030957835, 0.28108440712094307, 0.18240245378443173, 0.22120883502066135, 0.2783018707164696, 0.12420818289475781, 0.15559808138225759, 0.2068668303212949, 0.343749748808997, 0.2650350997490542, 0.40750647336244583, 0.4366951228252479, 0.5515208627496446, 0.4245116194444043, 0.32861383099641117, 0.1301893333771399, 0.22007049753197602, 0.2157304925577981, 0.25067043198006494, 0.4299937481326716, 0.37708462721535135, 0.2830566098647458, 0.39748285551156315, 0.3044472634792328, 0.19424309342035226, 0.40661490548934254, 0.2189206520893744], [0.0354594529739448, 0.03426999465695449, 0.015057619960446442, 0.03659823829574244, 0.10776550163115774, 0.047191472724080086, 0.10727388943944659, 0.02548231477183955, 0.02954999989430819, 0.022685613948851824, 0.04948274977505207, 0.04293497844732233, 0.07367306601788316, 0.08448598294385842, 0.051992118159042935, 0.07963272051087447, 0.05156526195683649, 0.015834123561424867, 0.08236105553805828, 0.1587867345660925, 0.048460648727736304, 0.009683491994759865, 0.07428019201116902, 0.03152347489127091, 0.03518867000405278, 0.06616510996328932, 0.007810582672911031, 0.07732639355318886, 0.009476343735254236, 0.04179793356784752, 0.012165628223946052, 0.07160124754799263, 0.0410425374949617, 0.023490656732714603, 0.0656903050839901, 0.02556548620175038, 0.031816059191312106, 0.03792023825060044, 0.03820173868111201, 0.09762442258319684, 0.028974992356130054, 0.05758403720600264, 0.004952387069351971, 0.05955022812954017, 0.033438324462622404, 0.06451189331710339, 0.0898974354245833, 0.02376593160443008, 0.02629492661383535, 0.07031834817358426, 0.050621297609593184, 0.037590643257967064, 0.03891794935667089, 0.05162516642095787, 0.0038438711947362337, 0.02434259476805372, 0.0192987742567701, 0.07438777373837573, 0.021686578003157462, 0.019710365117394497, 0.0298446367627808, 0.07121334264853171, 0.042578625426228554, 0.34045915252396036, 2.036773656095777, 10.09546330996922, 23.43919035366603, 34.111746719905305, 32.03505870274135, 36.59312561580113, 32.22598130362374, 28.757631642477854, 24.743287324905396, 26.764280319213867, 35.41170603888375, 30.989365237099783, 35.63023035866873, 40.47877713612148, 35.77925532204764, 29.723007406507218, 26.26491676058088, 27.319667203085764, 25.700657027108328, 22.507117305483135, 14.851008449281965, 31.180253096989222, 40.13277421678816, 35.985818317958284, 43.17267710821969, 49.37144994735718, 45.85425097601754, 51.24974605015346, 43.34350899287632, 41.94572598593575, 63.24227428436279, 42.4461213520595, 31.03403867994036, 21.322343485695974, 17.294997351510183, 29.521916116986954, 26.267709936414445, 17.850750752857753, 20.05496253286089, 23.10347076824733, 30.042513370513916, 29.628841945103236, 25.755577325820923, 25.847211905888148, 28.373847893306188, 22.68801018169948, 15.555274384362356, 21.920977694647654, 34.17989812578474, 30.186354977743967, 21.306807313646587, 18.326865639005387, 9.850321309907095, 3.5090020511831557, 0.4488217649715287, 0.12086875922977924, 0.16246727135564598, 0.12568371157561029, 0.08981711723442588, 0.05988999775477818, 0.04026647324540785, 0.026895638754857436, 0.07516988034227065, 0.07447166780808143, 0.0608437465769904, 0.0628915788339717, 0.06829790837530579, 0.10350279536630426, 0.14532706966357573, 0.05951632173465831, 0.043461175568933995, 0.037815655648176155, 0.030178991678569998, 0.0721632848892893, 0.07845274811344487, 0.044037648742752414, 0.07681135154728379, 0.064927367094372, 0.15261552642498696, 0.07725928643984453, 0.04222490172833204, 0.024175783719069192, 0.061924666432397704, 0.0725046219304204, 0.05677015141450933, 0.06613607544984136, 0.05535938890118684, 0.05937754775264433, 0.018082249177885906, 0.04511267891419785, 0.015173853009140916, 0.07014807659600462, 0.03160025791398116, 0.03122941477756415, 0.07303759761686836, 0.10376535449177027, 0.24827210924455098, 0.142306598169463, 0.14231163289930138, 0.06349117987390075, 0.014895880960726311, 0.07326276267745666, 0.04077954410708376, 0.06165351705359561, 0.1179481138076101, 0.026831466305468763, 0.011815916364347296, 0.13151368445583753, 0.12385351264051028, 0.12819472540702137, 0.03165719039472086, 0.11393756472638675, 0.05450640252924391, 0.07253702197756086, 0.03693546002198543, 0.04249751674277442, 0.03840929236529129, 0.011526823975145817, 0.03307600711871471, 0.02978174335190228, 0.05146734256829534, 0.07282866989927632, 0.048278227980647764, 0.06415194406041078, 0.025480964487152438, 0.08830205031803676, 0.017682135737101947, 0.030081041755953004, 0.09337725477027041, 0.017449058958196213, 0.02277601177671126, 0.04277231324730175, 0.07127641247851507, 0.022808126839143888, 0.05775696864085538, 0.02766023067358349, 0.013408396492845245, 0.03807201635624681, 0.03584369717698012, 0.06815568065004689, 0.02481199681226696, 0.019550746539607644, 0.02095591792437647, 0.046299192389207225, 0.013963691740562873, 0.03175390538360391, 0.02905897463538817, 0.15079576335847378, 0.062300615544830046, 0.014122406170437378, 0.023374298155041676, 0.05174719076603651, 0.05147793110726135, 0.03210910828784108, 0.01790986566006073, 0.03679224842094949, 0.027177269803360105, 0.023037113748224716, 0.03194733875404511, 0.06159529196364539, 0.023137552198022604, 0.17394589898841722, 0.19232389783220633, 0.025496613201020018, 0.02151874575896987, 0.035578963346779346, 0.01014568205989365, 0.10792488950703825, 0.031344161834567785, 0.02271787659265101, 0.055448680716965876, 0.1095018998852798, 0.09968032940690007, 0.3026591608566897, 0.5117914974689484, 3.3583451296601976, 12.67467110497611, 24.455419983182633, 41.02678503308977, 49.845098223005024, 49.22107703345162, 52.62550674165998, 48.75637803758894, 41.75821495056152, 43.43136896405901, 41.01205832617623, 42.015791620527, 45.2431777545384, 45.726160934993196, 53.925076961517334, 56.90641001292637, 55.025275571005686, 54.30433048520769, 53.01993860517229, 49.95191635404314, 55.48402343477522, 47.85389736720494, 65.45870099748883, 71.17679050990513, 65.04166316986084, 66.00057016100202, 78.0724607195173, 69.00820214407784, 82.02997398376465, 74.15790816715786, 72.07410172053746, 96.06384127480644, 76.76704706464494, 60.96188245500837, 49.43112802505493, 44.53448234285627, 56.6914188521249, 49.68997621536255, 37.83182266780308, 32.72374677658081, 34.82758487973894, 42.214801924569265, 44.315294470105854, 38.8309006690979, 32.38270834514073, 37.554565225328716, 34.701127665383474, 32.777859347207205, 34.44250181743077, 43.09615659713745, 44.63519300733294, 35.409010137830464, 29.205502101353236, 23.779617343630107, 12.174227101462227, 3.5226559128080095, 0.6074697119849068, 0.2787861818713801, 0.04624621576762625, 0.06542505217450005, 0.09575557429343462, 0.017270429525524378, 0.029191672336310148, 0.027148708568087647, 0.03413744962641171, 0.02573870601398604, 0.07652635326875107, 0.05105210288560816, 0.02113041847145983, 0.0737135134903448, 0.04198036788563643, 0.02348545745813421, 0.13006841843681677, 0.09812515428555862, 0.030671787913888693, 0.024376786147643412, 0.048634947410651615, 0.05970337348324912, 0.04939449272517647, 0.07314126419701747, 0.04502721403592399, 0.08443692486201014, 0.10310261576835598, 0.01941766377006258, 0.034393087694687505, 0.018482384671057974, 0.04290186933108738, 0.032997164742222855, 0.08804665652236768, 0.06838824852768864, 0.05285327409261039, 0.06803085056266614, 0.10748989427728312, 0.0357685019262135, 0.07126337782080684, 0.04695995657571724, 0.05111365958249994, 0.07382684919450964, 0.09895338770002127, 0.12136943664933954, 0.0957908241876534, 0.098621977626213, 0.07890558202884027, 0.08609145786613226, 0.07825633258159671, 0.13247411006263324, 0.056894421710499694, 0.084116798825562, 0.06833662558346987, 0.12057350150176457, 0.014085934065016252, 0.06971045543572732, 0.12131300967718874, 0.17754183603184565, 0.15805193542369775, 0.06672800225870949, 0.08711078031254665, 0.25175451380865915, 0.10462749430111476, 0.2779896631836891, 0.2656574792095593, 0.16720345935651235, 0.1744145088429962, 0.14473189945731843, 0.09768288516040359, 0.09750703602497067, 0.14119709841907024, 0.21719648103628839, 0.16188534615295275, 0.2582728740360056, 0.19003366572516306, 0.12387970409223012, 0.19095814254667076, 0.15573042285229477, 0.0998136547527143, 0.21647570042737893, 0.11754570182945047, 0.12003820522555284, 0.216445939881461, 0.0999375484617693, 0.10958856916321175, 0.05503020102956465, 0.20602886671466486, 0.0885506384074688, 0.17529379523226193, 0.17764836602977344, 0.05884818865784577, 0.14721480836825712, 0.23700750512736185, 0.15095787894512924, 0.15742305559771402, 0.23620439107928956, 0.18113896729690687, 0.11146391781845263, 0.15921660007110663, 0.06748461630195379, 0.17892010350312504, 0.10777930303343705, 0.10325251093932561, 0.2188767237322671, 0.15284488483199052, 0.11837924138775893, 0.2755349134760243, 0.2733553775719234, 0.19360118572201046, 0.13680693613631384, 0.12911727518907615, 0.04909641229148422, 0.21784570334213121, 0.0997577231111271, 0.23116352728434972, 0.09207300189882517, 0.29923462175897186, 0.2176051898194211, 0.2284729459456035, 0.21833416713135584, 0.7627810037561825, 3.8794285399573187, 13.532923885754176, 34.30200229372297, 55.67915664400373, 61.57374777112688, 70.78700351715088, 77.12965965270996, 73.35311916896275, 69.49295016697475, 71.77273750305176, 77.29479054042271, 74.55067593710763, 81.06263187953404, 89.10929203033447, 85.81401852199009, 81.81701169695172, 69.93034621647426, 71.46243095397949, 67.93926348005022, 76.2600439616612, 66.10740566253662, 87.15413842882428, 95.01646287100655, 84.67045620509556, 87.02463790348598, 84.19124589647565, 72.24597930908203, 82.12590081351144, 70.93998895372663, 74.92929717472622, 106.62457506997245, 85.81844452449253, 65.18577575683594, 62.93699823107038, 60.76936871664864, 75.36191981179374, 72.35788004738944, 59.65305723462786, 61.27892875671387, 64.61678777422223, 68.17896938323975, 75.98833465576172, 64.9767461504255, 65.26721559252057, 72.03294059208461, 68.4857462474278, 57.24820927211216, 56.95232718331473, 66.80242701939174, 59.302680424281526, 42.170802456992014, 29.20264639173235, 15.867549010685511, 4.498918201242175, 0.7742584507380212, 0.25653012469410896, 0.36801147407719065, 0.15428845451346465, 0.17717075880084718, 0.3490397978041853, 0.20229980110057763, 0.21551859964217457, 0.28532812797597473, 0.1974312580589737, 0.1770855483732053, 0.2437059756900583, 0.10561481025069952, 0.3465777470597199, 0.25871267329369274, 0.17393971074904713, 0.18614312234733785, 0.119846749784691, 0.1337407992354461, 0.10235225103263344, 0.15033435954579286, 0.11626339278050832, 0.18342712308679307, 0.1421108136751822, 0.2509129675371306, 0.14664228766092233, 0.20742814163012163, 0.12312505101518971, 0.14192481365587029, 0.15320350416004658, 0.11136772190885884, 0.12873150088957377, 0.19859067084533827, 0.1436177585273981, 0.12851069202380522, 0.14624773311827863, 0.18939809554389544, 0.18577082375330584, 0.13544990681111813, 0.27422300672956873, 0.2670143592570509, 0.3356127840067659, 0.386634247643607, 0.2890576549938747, 0.4367736428976059, 0.24357824825814792, 0.37395478944693294, 0.24880019947886467, 0.13243578640478, 0.2211137722645487, 0.18828909790941648, 0.16045751848391124, 0.3561881370842457, 0.30782129243016243, 0.3324671228017126, 0.1672657217298235, 0.1497590025620801, 0.3494284355214664], [0.07057022037250654, 0.1002656744260873, 0.008590651975412453, 0.04168868264449494, 0.02001724615027862, 0.10753982766930546, 0.04340521339327097, 0.0066005180955731445, 0.03628754050337842, 0.023357857251539826, 0.07951173093169928, 0.05890252574213913, 0.021889341230105077, 0.06039810513279267, 0.028360538184642792, 0.03569081984460354, 0.014670220569574406, 0.0467094651955579, 0.03421123691701463, 0.042913007483418496, 0.01805883293439235, 0.029075778555124998, 0.03220554507736649, 0.05129149343286242, 0.04296494255374585, 0.04040176973545125, 0.04906700797645109, 0.030949821030454974, 0.04665732656472495, 0.09713108691253833, 0.03654441689806325, 0.07053703322474446, 0.01654263286452208, 0.0493163085276527, 0.05324275319331458, 0.07002138732267277, 0.02455233672766813, 0.054997532961091826, 0.03427402176229017, 0.036968504677393606, 0.03727246800969754, 0.03206132245915277, 0.06037603917398623, 0.12156865453081471, 0.0190217267123184, 0.0353998097458056, 0.031898613154355965, 0.023846343093152558, 0.03342041453080518, 0.06511950107025248, 0.049389128905854056, 0.047296476018215926, 0.11269262260092155, 0.04683951321723206, 0.01851614348457328, 0.0634779552263873, 0.02331747254356742, 0.007829330595476287, 0.05443668305607779, 0.023272701106699448, 0.056724896521440575, 0.019862570700102618, 0.052495842200836966, 0.040726258752069304, 0.0541921356426818, 0.12170788991664137, 1.6878838688135147, 7.834492564201355, 19.761237859725952, 36.9214141028268, 47.298910004752024, 52.90521689823696, 37.67971270424979, 44.915386063711985, 44.47771208626883, 42.192883832114084, 38.6908666746957, 41.38030590329851, 45.557350976126536, 42.361558301108225, 46.90115690231323, 50.71410247257778, 45.65765169688633, 39.86971541813442, 44.18463012150356, 49.3591342653547, 60.604515756879536, 58.5752318246024, 56.976128237588064, 51.31152943202427, 49.275748934064595, 36.23946925571987, 30.076107910701207, 23.749406576156616, 51.59979976926531, 52.57085221154349, 33.475913592747276, 46.12284401484898, 41.7263366154262, 45.78447716576712, 56.572142601013184, 45.50641025815691, 40.72859614236014, 38.44512626102993, 38.6130051612854, 38.087377411978586, 43.723700523376465, 42.48467343194144, 40.58387906210763, 40.93152175630842, 39.75223527635847, 31.881347179412842, 20.912424087524414, 11.675024219921657, 4.485973273004804, 0.5376899849091257, 0.17177415266633034, 0.038747406365083795, 0.07161909301898309, 0.045210818826620064, 0.026843152374827435, 0.03336909353466971, 0.0753589134131159, 0.035779073501804044, 0.046405508648604155, 0.04164782465834703, 0.019632174134520546, 0.048004802116858106, 0.03919750239167895, 0.0785240757146052, 0.036006766105336804, 0.04616195528901049, 0.043235823911215575, 0.054727598159973107, 0.0665265859237739, 0.01453643721262259, 0.024029966543561647, 0.0327221782478903, 0.01891883196575301, 0.033251286284731965, 0.09532581056867327, 0.05276418583733695, 0.1036653316446713, 0.03750479161473257, 0.061028871286128245, 0.025150719797238708, 0.09635561638112579, 0.026081681717187166, 0.06331504575376, 0.01266225563761379, 0.0756742422069822, 0.021469363676650182, 0.06466431263834238, 0.05715330317616463, 0.02386308424840016, 0.03364582386400018, 0.01799877579989178, 0.013240993422056948, 0.022494166989677718, 0.058421539408820014, 0.055913768974798064, 0.015064666546615106, 0.023409220656113963, 0.047476084237652164, 0.057853259545351775, 0.07878024304019553, 0.0621968200430274, 0.07628140891236918, 0.041850716806948185, 0.05267046658056123, 0.14336835619594368, 0.027777378048215593, 0.1009879478120378, 0.12843502179852553, 0.03609368304855057, 0.06386945636144706, 0.03230424478117909, 0.014571814332157373, 0.08745642605104617, 0.03246040961572102, 0.015622211986088326, 0.06281691284051963, 0.01818504384053605, 0.025009299528652003, 0.021059755834617784, 0.036502062742199214, 0.05720736884645053, 0.06489963536815983, 0.11713862153036253, 0.05370881175622344, 0.021253487760467187, 0.04798731966210263, 0.03947920299002102, 0.03256579288946731, 0.040058936524604044, 0.021501237859151194, 0.04331720061600208, 0.01367880542030824, 0.0613796671054193, 0.05458143153893096, 0.06640512137008564, 0.042501665984413455, 0.02400022805003183, 0.03170848085678049, 0.08569150897009031, 0.07573267085743801, 0.06338885679308857, 0.03527016205979245, 0.04236214900655406, 0.051668911573610136, 0.03614871223856296, 0.07932778008814369, 0.048336710913905075, 0.03827110192339335, 0.02199032759693052, 0.05604106214429651, 0.03616833207862718, 0.04110899321468813, 0.010540780278721025, 0.09340176345514399, 0.056496834116322656, 0.04294474935159087, 0.04426224383392504, 0.022425763874447772, 0.059170533503804884, 0.020216128156919564, 0.001638559335593267, 0.12931117335600512, 0.03774120339325496, 0.05594165337138942, 0.03276151292292135, 0.03356371434139354, 0.07940974033304624, 0.03560685792139598, 0.09401737113616296, 0.08369759310569082, 0.0929844237065741, 0.0376956974422293, 0.06417198798486165, 0.057824733933167796, 0.25438565547977177, 1.6004489319665092, 8.16925503526415, 20.636639663151332, 35.88540295192173, 55.00155094691685, 63.113253184727256, 63.68645177568708, 60.21666036333357, 58.959613118852886, 58.74291270119803, 53.814027377537315, 56.60353108814785, 64.8676872253418, 68.67698846544538, 63.227655274527415, 66.55746827806745, 69.36920969826835, 66.38555594852993, 62.73377731868199, 61.29822390420096, 70.4654130935669, 83.96321296691895, 70.92570345742362, 68.72957938058036, 55.66355446406773, 55.49061727523804, 46.80354166030884, 41.32680824824742, 38.205611433301655, 70.24769129071916, 67.17027854919434, 40.53485952104841, 53.10364702769688, 47.995696204049246, 57.896066256931846, 68.725083896092, 62.26626777648926, 58.67293044498989, 54.30544219698225, 57.86917325428554, 55.73126465933663, 55.73858458655221, 56.572417054857524, 58.48402976989746, 53.68156344549996, 47.408931255340576, 49.19867604119437, 40.86746283939907, 28.086371387754166, 15.019976479666573, 5.622036746570042, 1.3024408029658454, 0.33101600781083107, 0.11981036673699107, 0.052656682141657384, 0.05693500488996506, 0.0627112513674157, 0.0887087234961135, 0.06257435014205319, 0.01950557646341622, 0.03062101313844323, 0.06485814295176949, 0.07130238679902894, 0.06515123615307467, 0.03921181269522224, 0.011531477029036199, 0.017080246337822506, 0.02814810413734189, 0.01824626975160624, 0.037345838001263995, 0.03589100463848029, 0.09342809061386756, 0.05093201236533267, 0.04206218903086015, 0.04819043572725994, 0.029205986032528535, 0.024753488433946456, 0.02752370773149388, 0.05629178422636219, 0.07940735188978058, 0.025244579850030795, 0.03165956187461104, 0.010898370778055062, 0.07056128406631094, 0.03317639637472374, 0.10749816561916045, 0.030303377325513532, 0.11911607613520962, 0.10092692715781075, 0.06411536423755543, 0.020585848317880715, 0.042082877563578744, 0.058312417407120974, 0.038191323168575764, 0.06437816763562815, 0.15545492406402314, 0.11308648503784623, 0.10738119296729565, 0.0831008351274899, 0.20996177781905445, 0.17284698438431534, 0.039246153352516036, 0.049598446781081815, 0.029220825593386377, 0.17131126964730875, 0.09356136167688028, 0.10289657860994339, 0.05531486004058804, 0.06374561693519354, 0.05222487263381481, 0.047714273777923415, 0.1237912502671991, 0.18092521519533225, 0.1573875682162387, 0.17488921194204263, 0.15043677762150764, 0.28191040136984413, 0.17274056295199053, 0.09463395590760879, 0.08599513982023511, 0.08505429673407759, 0.10694646236619779, 0.22952016975198472, 0.22222989451672348, 0.13855980922068867, 0.10399630067071744, 0.1373573908848422, 0.13482133911124297, 0.14021714457443782, 0.11271881405264139, 0.09338936662035328, 0.14852923926498207, 0.13771244111870015, 0.08451375538217169, 0.19271757027932576, 0.10868681647947856, 0.0707480644008943, 0.18534796072968415, 0.14151278005114623, 0.15928121017558233, 0.21846528723835945, 0.14935068732925824, 0.08017298366342272, 0.0880698895614062, 0.13684589761708463, 0.1198654230684042, 0.1245666393744094, 0.1181160919368267, 0.1668712350406817, 0.09741837863943406, 0.2583776127014841, 0.13351342215069703, 0.13679738236325129, 0.13249466967369827, 0.31614265590906143, 0.08554553573152848, 0.12735921809715883, 0.11754027354930129, 0.23272725194692612, 0.12447439932397433, 0.22609640418418817, 0.096027280070952, 0.25432971705283436, 0.20031792244740895, 0.1193627371851887, 0.09896412212401628, 0.14589318500033446, 0.17119581012853555, 0.09010459216577665, 0.15378206382904733, 0.14835870984409535, 0.19475712440907955, 0.08998768736741372, 0.0956961481965014, 0.14652483324919427, 0.12504491156765393, 0.4294537156820297, 2.6893163323402405, 10.569190621376038, 27.96600774356297, 52.563862323760986, 74.36048289707729, 88.40493924277169, 84.79922716958183, 93.33394963400704, 94.46039853777204, 89.58051885877336, 83.17196600777763, 86.90578896658761, 88.50324235643659, 80.02486978258405, 87.56538145882743, 92.19996193477085, 81.14194556644985, 74.66747515542167, 73.79284286499023, 84.27465902056012, 95.6711846760341, 79.27502019064767, 80.67147609165737, 72.94538497924805, 73.55435289655412, 63.09115096500942, 56.228602818080354, 51.04144947869437, 93.21204348972866, 90.75358322688511, 65.34670298440116, 73.51383100237165, 71.31504576546806, 76.60808617728097, 94.98835740770612, 84.43436336517334, 80.84693200247628, 78.97822788783482, 83.72386142185756, 81.33955928257534, 84.44381291525704, 83.75375257219586, 84.86704853602818, 77.50355611528668, 69.43773283277238, 56.71991341454642, 32.724719524383545, 16.93571295057024, 7.382801464625767, 1.5980941440377916, 0.2636952373598303, 0.12514579615422658, 0.1645931215690715, 0.11168944250260081, 0.12660537926214083, 0.15756079820649965, 0.15402170882693358, 0.11067856103181839, 0.24648213386535645, 0.1334247647651604, 0.3128319749874728, 0.2771292264972414, 0.2511810431522982, 0.10303432121872902, 0.15702136286667415, 0.10921230792467083, 0.12367262877523899, 0.14320039163742745, 0.16221090725490026, 0.08896291628479958, 0.10848601082605974, 0.1724721344986132, 0.10725353338888713, 0.14777583469237598, 0.14985614163534983, 0.0974667106888124, 0.18945813232234546, 0.19669806025922298, 0.13880581887704985, 0.17293317190238408, 0.18361886351236276, 0.09516174758651427, 0.13535848100270542, 0.08199852106294461, 0.17759997291224344, 0.09477048393871103, 0.17695862161261694, 0.12376311820532594, 0.09670063108205795, 0.09326350515974419, 0.13211551787597792, 0.23409192157643183, 0.28725655164037434, 0.22715052190635884, 0.244172102106469, 0.19432146421500615, 0.2847628268812384, 0.21878463295953615, 0.34245382834758076, 0.2707975448242256, 0.240867446575846, 0.12369758529322487, 0.14299560976879938, 0.3100055509379932, 0.3345008822424071, 0.3441202560705798, 0.29634189126746996, 0.16559344503496373, 0.1888919084199837, 0.10513135404991251], [0.06407098804733583, 0.09954806936106511, 0.04064105850245271, 0.08298894470291478, 0.09227072021790914, 0.007072311975727124, 0.025090045195871165, 0.03133544944492834, 0.08871161405529294, 0.08948048244097404, 0.04481398440631373, 0.09460638024445091, 0.07298003749123641, 0.018075190717354417, 0.011486835361990546, 0.023756929141070162, 0.06757670707468476, 0.04978856211528182, 0.04785356005387647, 0.017403513991406987, 0.016624267412615672, 0.015208502399868198, 0.04548322010253157, 0.012904823425092866, 0.0412506815046072, 0.026977943356281946, 0.008464160325404788, 0.04895352977993233, 0.06424164638987609, 0.01814117655158043, 0.03438592915024076, 0.05164227907412818, 0.020272931716005718, 0.05539288817505751, 0.06886276163692985, 0.04419032929997359, 0.05829941667616367, 0.03137368489322918, 0.0036547617887013723, 0.06501928144799811, 0.05411495906966073, 0.06724302390856401, 0.028993753849395683, 0.10118919451321874, 0.08676322110529457, 0.058654561904924254, 0.023692848293909004, 0.06352410239300557, 0.04785500533346619, 0.013082921055943837, 0.08600632207734243, 0.028762878916625465, 0.06773555890790053, 0.04021261792097773, 0.04508942212643368, 0.0508892748371831, 0.05439785049696054, 0.0523728780847575, 0.0715865029820374, 0.027405162574723363, 0.01256335576597069, 0.02983848245016166, 0.02179805961038385, 0.07455752962934119, 0.06976954226515122, 0.08276401034423284, 0.048042552412620614, 0.039139165343450646, 0.04953772807493806, 1.06545609661511, 4.302931232111795, 14.336048790386744, 23.69342146600996, 27.21951413154602, 39.51093823569161, 43.913417611803325, 62.354051317487446, 62.52173914228167, 68.35114574432373, 74.81852204459054, 70.72056484222412, 80.4361058643886, 70.77705369676862, 70.35606234414237, 64.85437447684151, 66.3470768247332, 65.25652926308769, 85.66831479753766, 85.00686018807548, 70.8103494644165, 69.03256947653634, 67.99564811161586, 76.80540806906563, 70.14420482090541, 63.57701069968087, 65.74826717376709, 62.33026763371059, 64.94980103628976, 72.36773259299142, 86.09838744572231, 71.72032029288155, 60.88429886954171, 54.852671895708355, 63.18282549721854, 55.61873510905674, 49.40971367699759, 44.34124599184309, 30.354063647133962, 12.461165121623448, 14.079714979444232, 6.776912033557892, 1.217896208167076, 0.2106666671378272, 0.1065481962370021, 0.052648604182260375, 0.05481005034276417, 0.01554989711647587, 0.04657551559752651, 0.04187496764851468, 0.04411107301712036, 0.04138913657516241, 0.07420710700431041, 0.030095243493893316, 0.02354292937421373, 0.0774442075884768, 0.0728652768635324, 0.03508126808862601, 0.048747679218649864, 0.016229210754058192, 0.025428508641198277, 0.02270232965903623, 0.03786008272852216, 0.02149968401395849, 0.03287043136411479, 0.036147317849099636, 0.03798837673717311, 0.06373383078191962, 0.07861293666064739, 0.08017123982842479, 0.04673212147983057, 0.028660504945686886, 0.019868360300149237, 0.01080491699810539, 0.02340722406682159, 0.02392348913209779, 0.08900767245462962, 0.04832837511120098, 0.01577187136613897, 0.017172057214858275, 0.03269736761493342, 0.009496319806203246, 0.03447864078251379, 0.025153165915980935, 0.03727733649845634, 0.039185709453054836, 0.03251330481309976, 0.024550832076264278, 0.03102241749210017, 0.08156664709427527, 0.040447961006845744, 0.052061579788901975, 0.021566596048484956, 0.04441214239756976, 0.05535874768559422, 0.04824361590934651, 0.03628267201461962, 0.034733729237424474, 0.15060897623854025, 0.11046033059912068, 0.12732116585331305, 0.11181928696376936, 0.08981649298220873, 0.06146877232406821, 0.06365144305995532, 0.08140107097902469, 0.043995145309184275, 0.0472417691323374, 0.005571257231557476, 0.042865767875420194, 0.04894634748675993, 0.06642625095056635, 0.05476902950821178, 0.05282660088102732, 0.0783845078466194, 0.09955914305256945, 0.06526972193803106, 0.07712728423731667, 0.02566340219761644, 0.04623979004099965, 0.025080796763566986, 0.021433170618755475, 0.017423016784180487, 0.04324337600597313, 0.04076905056302037, 0.008034744349840497, 0.028316085659233586, 0.027572111027049165, 0.01756753626146487, 0.03358984472496169, 0.052737217463020764, 0.03692125149869493, 0.009349538262800446, 0.04897433366360409, 0.01647599902935326, 0.08362928498536348, 0.028416256087699106, 0.020128147610064064, 0.010712843188749892, 0.02511644360077168, 0.03292158951184579, 0.025442215048574975, 0.08074218633451632, 0.07421076430806092, 0.03279513094042029, 0.03316615388861724, 0.06357367616146803, 0.02627674866068576, 0.021241956057825258, 0.032119795214384794, 0.061846451700798104, 0.06462836385305439, 0.047988245862403085, 0.041166865466428657, 0.033693816645869186, 0.08959824897881065, 0.0532925474856581, 0.016962047233911495, 0.013798879825377038, 0.05091515077011926, 0.015974592184647918, 0.01582184207758733, 0.0696244714781642, 0.0444276842421719, 0.028426281442599635, 0.09517988482756273, 0.07282923986869198, 0.061169891219053946, 0.013586654427594371, 0.034534290832068236, 0.05740421185536044, 0.036029025446623564, 0.06698613055050373, 0.09120290287371192, 0.23585926102740423, 1.177163371018001, 7.619477953229632, 17.956137554986135, 36.07018334524972, 41.260727405548096, 53.59608323233468, 64.52993529183524, 66.30829892839704, 83.18270097460065, 81.70968982151577, 87.99280684334892, 92.81074333190918, 86.99768584115165, 96.14700426374162, 85.2382629939488, 91.25069209507534, 87.20383889334542, 97.85226590292794, 97.09466212136405, 110.99678461892265, 108.17748355865479, 91.11627919333321, 82.2791919708252, 72.96549306597028, 75.06646851130894, 72.07308728354317, 70.72942379542759, 76.19857324872697, 74.43297345297677, 81.18858187539237, 93.28260939461845, 106.76927130562919, 92.42885644095284, 81.70177582332066, 78.80543313707624, 81.28550229753766, 73.94562680380685, 69.58517360687256, 66.96894059862409, 54.19302729197911, 37.913151332310264, 31.32857976640974, 21.396190677370342, 8.460687671388898, 2.3067630657127927, 1.0450874524457114, 0.34054054958479746, 0.21434877812862396, 0.06196962616273335, 0.07200073504022189, 0.06606455107352563, 0.017267557626057948, 0.020887034745620828, 0.07509767743093626, 0.06476118708295481, 0.017867231608501503, 0.08831635383622986, 0.10137154401413032, 0.00299774735633816, 0.022543920569920113, 0.02266646229795047, 0.049853575948093615, 0.026419670188001225, 0.06404231315744774, 0.043737675196358135, 0.039150422239410024, 0.003899127269895481, 0.03920816217682191, 0.01364586000064654, 0.0735068724357656, 0.08375264265175376, 0.022478168830275536, 0.01324895687866956, 0.028514789550432136, 0.02645657061865287, 0.03160881084789123, 0.09007911317582641, 0.05771788502378123, 0.019306577409484556, 0.036773008560495715, 0.023719477400715862, 0.028111814388207028, 0.026107175974175334, 0.02764296704637153, 0.03558268850403173, 0.0479302548670343, 0.03635379944794944, 0.09349174398396697, 0.10228220586265836, 0.029993588770074502, 0.05812251581145184, 0.04588338612977948, 0.07914175971278123, 0.04398621578833886, 0.04436521152300494, 0.11279248938496624, 0.06856979057192802, 0.08070120281938996, 0.10504913596170289, 0.10564269803996597, 0.1496834951852049, 0.03812496583642704, 0.056217637312199385, 0.13205791025289468, 0.01480941185062485, 0.027430473627256494, 0.06706819936100926, 0.0506258573649185, 0.14947738338794025, 0.18503716454974242, 0.10685458193932261, 0.18595098837145738, 0.1767519669873374, 0.12077631561883859, 0.1334962145026241, 0.1354250181466341, 0.136680755764246, 0.2690877180014338, 0.13177653535136155, 0.24728633356945856, 0.1698839305234807, 0.1492937175290925, 0.1083718201677714, 0.13143372588924, 0.15553252132875578, 0.17084635102323123, 0.07110097046409335, 0.14022038797182695, 0.11359267894710813, 0.12374504203242914, 0.11416226838316236, 0.1741787450654166, 0.08716819794582469, 0.15620379602270468, 0.14691788144409657, 0.12237634190491267, 0.17699724382587842, 0.07818013988435268, 0.14168651215732098, 0.13999655283987522, 0.07136361101376158, 0.12042414237345968, 0.1295643076300621, 0.2602474109402725, 0.20270909342382634, 0.10390798933804035, 0.13088536102856907, 0.15795634341027054, 0.1913218508873667, 0.15445879394454615, 0.11939560542149202, 0.16890859071697506, 0.20454877827848705, 0.1291544996201992, 0.11385614052414894, 0.16450493915804795, 0.2055794322597129, 0.24036549351045064, 0.1035343472446714, 0.13622568946863922, 0.20805309952369758, 0.17167550724531921, 0.14433529573891843, 0.12010495950068746, 0.17574279542480195, 0.1610511959131275, 0.3939436711370945, 0.12594160916549818, 0.0974807563636984, 0.12573825222040924, 0.1797478348016739, 0.14554988699299948, 0.1277842524328402, 0.2043007058756692, 0.1460601860391242, 0.09832900656121117, 0.20052659910704407, 1.9237203853470939, 7.420319131442478, 22.36212577138628, 35.23892865862165, 52.20657900401524, 70.67299052647182, 78.54309695107597, 103.26773357391357, 102.50930295671735, 108.55276271275112, 118.21269035339355, 111.05871391296387, 117.8098337990897, 108.35611479622978, 110.44301319122314, 109.22860704149518, 122.03494998386928, 125.6913561139788, 131.2238870348249, 124.04010282244, 100.7102267401559, 92.2567217690604, 90.46404484340123, 94.38799136025565, 93.6597923551287, 86.69317408970424, 95.71710532052177, 88.66348171234131, 96.78327860151018, 109.47571277618408, 129.7823442731585, 107.37465395246232, 97.03541483197893, 95.60669844491142, 98.90233325958252, 86.13638714381626, 82.30383028302873, 69.70993546077183, 51.277326924460276, 31.41335473741804, 23.176930597850255, 11.754372647830419, 2.95599079983575, 0.48567539027759005, 0.29050035615052494, 0.08212854194321803, 0.19695517074848923, 0.12454432914299624, 0.13969019427895546, 0.15432080706315382, 0.15179516401674065, 0.1449546625039407, 0.17505721721265996, 0.15742532190467629, 0.07684645216379847, 0.24779754185250827, 0.16904253352965626, 0.11481151783040591, 0.13260597655815737, 0.11615368723869324, 0.0971956088074616, 0.10999661298202616, 0.1611034973923649, 0.12906053609081677, 0.145771930792502, 0.08483732159116439, 0.08519929966756276, 0.09966557127024446, 0.16451331228017807, 0.2363474534026214, 0.1008724815079144, 0.10454727789121014, 0.1212073482040848, 0.10091166011989117, 0.09005186999482767, 0.1946361687566553, 0.19832012536270277, 0.1388426904699632, 0.13138586202902452, 0.09467493942273514, 0.12174955196678638, 0.18796543670552118, 0.13358986590589794, 0.12537273897656373, 0.1286552878362792, 0.10383188485034875, 0.15442509789552006, 0.11499944488917078, 0.20380935152726515, 0.18910354349230016, 0.0938309436397893, 0.2062218420739685, 0.2009195794484445, 0.15582613700202533, 0.19812131460223878, 0.1802732516080141, 0.155338921717235, 0.21100032994789736, 0.3241899183818272, 0.24650181138089725, 0.19450726067381247, 0.20812389786754334, 0.24299506098031998, 0.12466086074709892, 0.14637324852602823, 0.21282849327794143, 0.12420795219285147], [0.07326906626777989, 0.04356130698163595, 0.05272043729200959, 0.08857344396944557, 0.03447919039587889, 0.01723114574061973, 0.061434438452124596, 0.023594377595665197, 0.03731339045667222, 0.09301416389644146, 0.03133666741528681, 0.02370786597020924, 0.02476775972172618, 0.00936175019679857, 0.05027259846350976, 0.013854747006137456, 0.05715649907610246, 0.041428790161652226, 0.04361099270837648, 0.010646040567995181, 0.015869271675390855, 0.05174394736864737, 0.04726580962804811, 0.04539864071245704, 0.0686538949874895, 0.009461674656319832, 0.027128701963062798, 0.024110523917313133, 0.004448748268519661, 0.056872182725263495, 0.023146225571898476, 0.05476900915216122, 0.06269601825624704, 0.061718622488634925, 0.045325745695403645, 0.08844629329230104, 0.08692231721111707, 0.09398348509733166, 0.09139822596418005, 0.02396522242841976, 0.005789293857690479, 0.02393507511754121, 0.013138088497466274, 0.04062131991876023, 0.027242722987596477, 0.04473270608910492, 0.07044325289981705, 0.07687009910919837, 0.033717070040958266, 0.07868596059935433, 0.04326073632442525, 0.07904156044657741, 0.05765824858099222, 0.087909239610391, 0.007514230807178787, 0.022712278678747158, 0.10937802653227534, 0.08848642185330391, 0.02467428134488208, 0.021121086918615868, 0.011712284559117896, 0.04387258152876582, 0.04970921083752598, 0.00874092203697988, 0.03196752177817481, 0.006789260244529162, 0.018459075296829854, 0.05284137937373348, 0.09340802633336612, 0.06314222288451024, 0.04093648586422205, 0.0980564933270216, 0.04959575978240796, 0.5578981691173145, 2.13229010786329, 2.9229351793016707, 7.178277765001569, 8.148410439491272, 13.678385291780744, 21.943335260663712, 28.406308140073502, 30.33891657420567, 33.13362101146153, 35.53394569669451, 33.01884719303676, 12.188019275665283, 3.477115030799593, 29.356559412819998, 51.81552396501814, 94.10070419311523, 122.26701981680733, 110.46123831612724, 110.04374190739223, 99.04552173614502, 102.62428869519914, 101.83201340266636, 87.5415769304548, 76.06092943464006, 50.491555145808626, 28.169195652008057, 7.149806218487876, 7.964911988803318, 7.005276305334909, 6.325251332351139, 4.913669203008924, 2.999315857887268, 1.2064173498323985, 0.34827354177832603, 0.5162341647914478, 0.043206531554460526, 0.08335216449839727, 0.04390914438824568, 0.01676066991473947, 0.05460609967953392, 0.028413723455742, 0.047631848736533096, 0.029759738461247513, 0.04165824356355837, 0.04676878272688814, 0.05919194806899343, 0.06195998418011835, 0.0377121654871319, 0.0479193100971835, 0.1257018691727093, 0.052744107986135144, 0.031000982570861067, 0.029721852458481277, 0.011708838449391936, 0.02589054518778409, 0.07598047863159861, 0.07084257754364184, 0.07547260874084064, 0.021662724104576876, 0.043926022946834564, 0.041019837105912824, 0.017124459679637636, 0.045807834648128064, 0.03370184710781489, 0.07051924203655549, 0.007775247113646141, 0.03444721443312509, 0.030231747776269913, 0.028894372217889343, 0.03819897025823593, 0.08852224171693836, 0.02995015574353082, 0.0221395153951432, 0.0329245988146535, 0.038415724877268076, 0.03866156489987459, 0.010990062063293797, 0.03198393554027591, 0.041822150482663085, 0.0216387395880052, 0.03703227000577109, 0.02724014625086316, 0.019779858977666924, 0.020449203239487748, 0.028328882829685296, 0.02551527291403285, 0.07065935951790639, 0.08762669084327561, 0.07474299360598836, 0.018874616927600334, 0.028761559166014194, 0.014191770260887486, 0.06723018602601119, 0.08844095322170428, 0.030277514963277748, 0.05209890600027783, 0.04058948644836034, 0.01482259578603719, 0.0416260504695986, 0.05880985821464232, 0.038999061432800124, 0.04228751015450273, 0.02002484234981239, 0.01816787351188915, 0.0814971447523151, 0.017202888149768114, 0.03751638438552618, 0.04799497353711298, 0.0227241055441222, 0.03735987349812474, 0.018638544416587268, 0.041372386938227076, 0.04895507683977485, 0.018123526159407835, 0.005164290587085166, 0.02772806551573532, 0.07036233759884324, 0.006390862225089222, 0.04245956627918141, 0.02416678125570927, 0.06775504643363611, 0.04272659695042031, 0.041165138594806194, 0.03559495641716889, 0.03535095861713801, 0.03786406912175672, 0.012080222717486322, 0.025928794206785302, 0.007445837021805346, 0.03515343028785927, 0.037845290665115626, 0.05551807449332305, 0.10388452559709549, 0.023710619126047407, 0.0840049966105393, 0.03787626578871693, 0.03191294042127473, 0.03940838768279978, 0.0279247219275151, 0.01766364396150623, 0.014575973751821687, 0.01408428861759603, 0.038179710041731596, 0.0908784002863935, 0.024740445294550488, 0.06782035542918102, 0.04667212202080658, 0.0427671156690589, 0.03003342556101935, 0.08961334638297558, 0.010765704459377697, 0.010039481999618667, 0.02612042097773935, 0.04487733582832983, 0.08719822990575007, 0.026543916735265936, 0.05003894492983818, 0.021630544581317475, 0.02349933180292802, 0.01829575022150363, 0.04424175886171205, 0.029666046345872537, 0.06411072984337807, 0.07909660320729017, 0.018399408319965005, 0.01795124272549791, 0.04100201199097293, 0.042062148318759034, 0.030203724279999733, 0.033806640056094954, 0.0911241995968989, 0.09772629104554653, 0.2227596810885838, 0.37645402391042027, 1.8533438188689095, 3.093840020043509, 9.37228958947318, 10.45956107548305, 18.698160001209803, 22.433850288391113, 31.872658457074845, 43.327559403010774, 49.42093849182129, 50.420937129429404, 52.967778478349956, 54.83420010975429, 52.23011602674212, 26.603820358003887, 12.408861688205175, 45.20600141797747, 70.88102654048375, 110.48422295706612, 139.6309155055455, 129.4100181034633, 125.84097862243652, 115.21440369742257, 123.14133943830217, 127.6975233895438, 110.73547676631382, 100.48639052254813, 70.40989003862653, 48.117619718824116, 17.808592557907104, 18.13786768913269, 18.125937632152013, 18.92681132044111, 15.937932525362287, 11.456198522022792, 5.850938200950623, 2.847305340426309, 1.496564352086612, 0.6110570452042988, 0.28151535828198704, 0.07133194378444127, 0.03889360012752669, 0.044350422852273495, 0.10262649453112058, 0.02923484073419656, 0.02336138393729925, 0.03285838397485869, 0.07456193332161222, 0.03830614147175636, 0.03334592156378286, 0.009316928717972977, 0.08273717428424529, 0.09186446773154394, 0.052733427844941616, 0.030449130040194308, 0.06676724872418813, 0.020188796766368405, 0.045421225750552754, 0.10886964774025337, 0.04889358121103474, 0.054998859497053285, 0.010045738092490604, 0.042837337258138826, 0.08537425313677106, 0.043448456430009434, 0.009468516833814127, 0.023498110439894453, 0.10210117271968297, 0.03557017631828785, 0.018141449661925435, 0.04152762896514364, 0.06628175013299499, 0.06391590208347354, 0.05263771030253597, 0.038976612101708136, 0.009569629577786794, 0.07327438598232609, 0.07685720015849386, 0.04106483415567449, 0.03750054059284074, 0.047298348774867396, 0.04313398937561682, 0.03217868187597819, 0.03907103703490325, 0.05680010195023247, 0.03818371339834162, 0.020383113928671395, 0.03888299123251012, 0.028433387400582433, 0.05681412048371775, 0.09536600019782782, 0.10054935634668384, 0.04751377346526299, 0.024792833287002783, 0.032484952227345536, 0.07345573125141007, 0.04516684975741165, 0.04930145539609449, 0.04602573259866663, 0.09528761583247355, 0.10004109969096524, 0.0646187150850892, 0.010170292525020028, 0.05845726427755185, 0.059798517663564, 0.11442418290036065, 0.08029522174703223, 0.21419901187930787, 0.23802726183618816, 0.1769782312746559, 0.2054854958717312, 0.12991721369326115, 0.13688032648393086, 0.12017632781394891, 0.10657861496188811, 0.22462646663188934, 0.09287692340356962, 0.10896656968231712, 0.21287614000695093, 0.22958560766918318, 0.11795673120234694, 0.1137041486799717, 0.10759090100015913, 0.146487310262663, 0.11277425714901515, 0.09927202774477856, 0.1405510516571147, 0.11255242369536843, 0.13719705305993557, 0.1582926253655127, 0.12336895721299307, 0.13886075307215962, 0.13824890447514399, 0.09847693398062672, 0.19607395731977054, 0.17167693216885838, 0.1317044070788792, 0.1341319882443973, 0.15142876867737087, 0.11685517031167235, 0.20602345200521605, 0.13391873825873646, 0.2238691129854747, 0.18511607817241124, 0.11936146153935365, 0.1866524578737361, 0.21746032259293965, 0.09791128004768065, 0.1537723879196814, 0.1706303461853947, 0.20154056112681115, 0.12836319208145142, 0.16260246267276152, 0.10445323293762547, 0.17929749110979692, 0.1386808462973152, 0.13294380557324204, 0.19714811896639212, 0.15314866495983942, 0.15133449302187987, 0.1553077498184783, 0.2526975960603782, 0.12248569460851805, 0.1741564076926027, 0.14331893170518534, 0.14780290823962006, 0.27096986557756153, 0.12486378342977592, 0.11602815826024328, 0.16175863652357034, 0.10703258203076464, 0.10226684382983617, 0.14208752635334218, 0.2011794719312872, 0.15114406895424637, 0.17177804745733738, 0.17541502229869366, 0.36381430072443827, 0.8789317597235952, 3.50018087880952, 4.114059218338557, 9.34962977681841, 12.950198446001325, 21.87730131830488, 31.934778826577322, 41.90104212079729, 43.22605316979544, 47.68646315165928, 51.741133076804026, 49.01485102517264, 25.023105178560527, 12.75057930605752, 47.478534834725515, 80.03048392704555, 134.7397311074393, 162.0998055594308, 158.2265739440918, 148.37905883789062, 137.39190019880022, 141.1645496913365, 155.15376091003418, 131.8350227900914, 111.24143069131034, 74.21163858686174, 45.710767201014924, 13.667713727269854, 10.96903600011553, 12.015128987176077, 11.446187904902867, 8.499389137540545, 5.26569447347096, 1.8932043313980103, 0.8525314277836255, 0.5276811591216496, 0.16870287247002125, 0.17310865462890693, 0.11837287672928401, 0.12629490877900804, 0.12603610195219517, 0.2704929911664554, 0.13114019164017268, 0.10467038449964353, 0.12125297289873872, 0.14363777531044825, 0.17216701087142738, 0.13303907188986028, 0.08737243698643786, 0.18773531833929674, 0.37247341179421967, 0.14472898175673826, 0.06831263258521046, 0.2666844826723848, 0.13781419423009666, 0.2922541249011244, 0.3835081553884915, 0.1304863417255027, 0.1422412416764668, 0.14450822717377118, 0.2210719609366996, 0.17064387617366655, 0.14439945801028184, 0.1423426012375525, 0.19300510627882822, 0.18607643592570508, 0.10942009570343153, 0.12194256803819112, 0.16120427341333457, 0.1893847691161292, 0.15437783114612103, 0.18154021219483443, 0.12959708087146282, 0.09954996925911733, 0.09548312212739672, 0.1079557899917875, 0.1309135609439441, 0.10956190273697887, 0.1462398756827627, 0.15535049752465316, 0.10291891598275729, 0.19688476595495427, 0.22674901916512422, 0.149660357141069, 0.12862529658845492, 0.14869139556373867, 0.1349032111465931, 0.16092798752444132, 0.18735491803714208, 0.2311468624642917, 0.1913970054260322, 0.1157125716230699, 0.13528693627033914, 0.18177630166922296, 0.19084995692329748, 0.21183544370744908, 0.1918385960161686, 0.19784882850944996, 0.22328117596251623, 0.1400862280279398, 0.18647462741604873, 0.11762814383421626, 0.16973629487412317], [0.03407388446586473, 0.04459040033231888, 0.01125645830429026, 0.045807369851640294, 0.008211820785488402, 0.013445084881303566, 0.015279146376997232, 0.08771257980593614, 0.04708752115922315, 0.009358399930143995, 0.0375743075273931, 0.03300853020378521, 0.017108575174851075, 0.028943084246878113, 0.026155742118135095, 0.00512212302835126, 0.050308900087007453, 0.01993964718920844, 0.04703551823539393, 0.015410542987020952, 0.034916974404560666, 0.01738872192800045, 0.02066283829377166, 0.016776591738952056, 0.052337964065372944, 0.010221346347991909, 0.026955231092870235, 0.0978596910302128, 0.03189226206658142, 0.03640150385243552, 0.06377906192626272, 0.06782049113618475, 0.05771206319332123, 0.06861623629395451, 0.01923375024593302, 0.06385811804128544, 0.039300836489668915, 0.024037954597068683, 0.04613843047991395, 0.02719075738319329, 0.024720420029812624, 0.027047026702868085, 0.013570253388024867, 0.019731486216187477, 0.043189466398741515, 0.04930562160110899, 0.024442113802901337, 0.008805008821322449, 0.02919574354642204, 0.07088330321546112, 0.038397570672844133, 0.004338519830655838, 0.013767375444461192, 0.010130009597300418, 0.02392798612293388, 0.01996599300764501, 0.01504459887343858, 0.03528352580698473, 0.11168027549449887, 0.06844437694443123, 0.031092513552201644, 0.034083041295941384, 0.02057682380213269, 0.04920892357560141, 0.028542738407850266, 0.010581311719891216, 0.04837015590497425, 0.07660721428692341, 0.06232889688440731, 0.05777529587170907, 0.024190504536298767, 0.04503726653222527, 0.021295758795791438, 0.02987300631191049, 0.12657779002828257, 0.0854208684925522, 0.03638619610241481, 0.12146074032144887, 0.2239142084228141, 0.12925067517374242, 0.08222458857510771, 0.13113503477403096, 0.07718288339674473, 0.0733882984412568, 0.21029373072087765, 0.1901721004396677, 0.06012515763619116, 0.19608437961765698, 0.07922188112778322, 2.4010103855814253, 10.514582991600037, 17.829081058502197, 26.34465949875968, 27.04741941179548, 20.490565947123937, 18.56305227960859, 9.634802954537527, 1.5145417302846909, 0.11935710534453392, 0.1546000785061291, 0.021835519832425883, 0.047106872977955, 0.06797763984650373, 0.055852656718343496, 0.06675702320145709, 0.03396906437618392, 0.052486861789865155, 0.05219786354739751, 0.06322950962930918, 0.016388391676758016, 0.03410462549488459, 0.025704855598243218, 0.05060752674138971, 0.010120619520811098, 0.03842104119913919, 0.06455020340425627, 0.002959102878646393, 0.02517120646578925, 0.014400007569098046, 0.04913354851305485, 0.01684962076667164, 0.04017278791538306, 0.04133047043745007, 0.021502220038590685, 0.03187076946986573, 0.03228740014934114, 0.009564658460606421, 0.01498938987164625, 0.044280927295663526, 0.039521248412451575, 0.04419277881139091, 0.034941574691661766, 0.04112103381859405, 0.06986476786966835, 0.05215366377628275, 0.03416782085384641, 0.027941441030374596, 0.017732817213982344, 0.025188042615939463, 0.05292278661259583, 0.07807899745447294, 0.06400858318167073, 0.0315296529526157, 0.030095715075731277, 0.013614087598398328, 0.049021841292934756, 0.023645376287666813, 0.03996187548286148, 0.06412500622017042, 0.0684512165774192, 0.038112246697502475, 0.044478306347238164, 0.012782961928418704, 0.05420535350484507, 0.01922909210303, 0.015828954820920314, 0.010386249017236488, 0.03129785181954503, 0.0507911790295371, 0.023022465873509645, 0.04842628092904176, 0.03684950659849814, 0.020334476538534676, 0.041221877693065574, 0.04864971911800759, 0.053255445190838406, 0.010449965999993895, 0.031264467896627526, 0.04473326588049531, 0.03576091590470501, 0.06784096253769738, 0.032083072899175544, 0.013324002851732075, 0.02665916081917073, 0.007414893280448658, 0.045813880395144224, 0.02217649724999709, 0.038078913664711375, 0.019086111203900406, 0.06947410133268152, 0.019396561330982616, 0.022420157478856187, 0.03511615835928491, 0.017609461243929606, 0.04782218120193907, 0.03926736774987408, 0.02108680224046111, 0.056975072382816246, 0.1122965549251863, 0.01491096818686596, 0.046812809471573145, 0.038704641695533476, 0.06324227287300996, 0.025379175752667443, 0.007464315226700689, 0.0328115379171712, 0.03849598199927381, 0.02677647952389504, 0.06643045786768198, 0.05684603198564478, 0.04148637403600982, 0.03895814237850053, 0.07174791967762367, 0.020707470630960803, 0.013607124980938221, 0.009909714721808476, 0.03200028823422534, 0.06001603563449212, 0.026650843676179647, 0.020665942591481974, 0.02204298530705273, 0.043436056202543635, 0.038831666843699555, 0.046522579688046656, 0.01299224587689553, 0.08685217704623938, 0.017392389409776245, 0.0495342437976173, 0.03363074342321072, 0.06888380300785814, 0.03931476002825158, 0.03693181968161038, 0.0709186548899327, 0.04817479888775519, 0.03857270734650748, 0.0578542027090277, 0.07215021630483014, 0.0708421432812299, 0.1300692462495395, 0.010799060392725681, 0.021692102974546806, 0.01006214931008539, 0.025093593934018697, 0.01568138363238956, 0.04095353405656559, 0.06215131069932665, 0.01746314195250826, 0.011470947464528893, 0.02144283295742103, 0.025149213449497308, 0.03334861534780689, 0.006941883126273751, 0.022835571884310672, 0.04692763795277902, 0.03639046408768211, 0.09815169179013797, 0.02451646767024483, 0.027047238745061413, 0.07421370915004186, 0.11053443340850727, 0.07781024330428668, 0.045702183353049416, 0.12581305392086506, 0.1179972126015595, 0.22272565934274877, 0.40712736227682655, 0.32969576865434647, 0.30920653524143354, 0.21707956945257528, 0.2498301884957722, 0.16221412351088865, 0.2820859248084681, 0.14846324494906835, 0.02283127506130508, 0.06995417842907564, 5.194524943828583, 17.39275676863534, 26.70108297892979, 40.9376083782741, 43.482129028865266, 35.81873846054077, 32.517173358372276, 19.67691104752677, 4.416822195053101, 0.6609369686671666, 0.2375381737947464, 0.14632917089121683, 0.0264638852261539, 0.0805174894630909, 0.021459764102473855, 0.041772536002099514, 0.015345103373484952, 0.050358965793358426, 0.03280720207840204, 0.12912578401821, 0.03351036113287721, 0.020114327548071742, 0.02395255587595914, 0.04561761753367526, 0.01688815646671823, 0.010049175720528832, 0.04670412512496114, 0.08123565771217857, 0.029419972228684595, 0.056805336847901344, 0.06266865293894495, 0.03134878265804478, 0.016688567087320343, 0.09306652644383055, 0.024175659886428287, 0.07057768425771169, 0.01585525314190558, 0.029434625192412307, 0.06501750368624926, 0.08858772034623794, 0.051846178847232034, 0.009293088390092765, 0.03477879414068801, 0.03225410104330097, 0.022332168450312953, 0.07502826329852853, 0.059265087358653545, 0.027039242209866643, 0.016724081610196402, 0.03802827459626964, 0.06238794978708029, 0.030308422233377184, 0.0558228826017252, 0.041956503809030564, 0.0455971664882132, 0.020610631809436848, 0.054994255636951754, 0.07531691209546157, 0.03100833449778812, 0.06963704473205976, 0.03831171563693455, 0.10127130403582539, 0.03146621332104717, 0.03034868310870869, 0.020630607880385857, 0.0009694535152188369, 0.0520567452268941, 0.015503115519615156, 0.04245543400091784, 0.04055194989112871, 0.06967827930514302, 0.03756550692820123, 0.01831210121911551, 0.024601464359355823, 0.023589429379041706, 0.023538695315697362, 0.0536451719568244, 0.019107926104749953, 0.024445460676880817, 0.037652786887649975, 0.05468644840376718, 0.02314253943040967, 0.04828206170350313, 0.02307342385341014, 0.03459223093731063, 0.028245367043252503, 0.024987812020948956, 0.0875918548554182, 0.1054622009396553, 0.10483743303588458, 0.17524332579757484, 0.11053394486329385, 0.05084450848932777, 0.17529517944369996, 0.10333352123520204, 0.2556948752275535, 0.17522876443607466, 0.12154820348535265, 0.18638554933880055, 0.1599117727684123, 0.1226962711662054, 0.18659404957933085, 0.14119316291596207, 0.10166333442819969, 0.1568147082413946, 0.10011083952018193, 0.16490991599857807, 0.18021007999777794, 0.20519117452204227, 0.12698896867888315, 0.11150129831262998, 0.11683338933757373, 0.11540192472083227, 0.17397822439670563, 0.22899674783859933, 0.13124548670436653, 0.07312672319156782, 0.17060595963682446, 0.1427665634879044, 0.0952788559453828, 0.17197110424084322, 0.06690027551459414, 0.15043947819088185, 0.1467477320028203, 0.17651533468493394, 0.11868313008121081, 0.1332651868994747, 0.2032249971692051, 0.13196268464837754, 0.14727918777082646, 0.09985170021120991, 0.1725366088960852, 0.1187323374407632, 0.1313189041933843, 0.1418726071715355, 0.11753788510603563, 0.2770839274993965, 0.12707531904535635, 0.1387750812407051, 0.30948250900421825, 0.13323960612927163, 0.13920960149594716, 0.14153731587742055, 0.14020415741418088, 0.15252959675022534, 0.17598833010665008, 0.10493623451994998, 0.1412014410431896, 0.1307993092175041, 0.2138999814965895, 0.12282925045916013, 0.090184543947024, 0.0623381385313613, 0.1483606911663498, 0.20700344656194958, 0.20636121316679887, 0.1444925530148404, 0.13246081077626773, 0.13625443221202918, 0.1869245504162141, 0.16833710138286861, 0.17418521828949451, 0.1761128141411713, 0.16963751374610833, 0.3014715888670513, 0.47591355123690193, 0.440346754023007, 0.20289459132722446, 0.3135457666856902, 0.21739198054586137, 0.3308820107153484, 0.37505719172103064, 0.4545461306614535, 0.3625909292272159, 0.32241997335638317, 0.14244618639349937, 4.167599865368434, 15.957656724112374, 28.67461630276271, 42.611533641815186, 46.96468775612967, 36.201983724321636, 31.232566084180558, 17.142958606992448, 2.9132802230971198, 0.3853264663900648, 0.2897526648427759, 0.19151310276772293, 0.17477106542459556, 0.28359639804278103, 0.2856441353048597, 0.16964368841477803, 0.13533793496234076, 0.10461096518806048, 0.14925288329167025, 0.2643093115517071, 0.11977745778858662, 0.1152716867093529, 0.08641708003623144, 0.21180089270429953, 0.12000573053956032, 0.14339966380170413, 0.1785526903612273, 0.2218810868050371, 0.11096152370529515, 0.09935270555849586, 0.1340205863650356, 0.11352359051150934, 0.11964114010334015, 0.12627607264689036, 0.0784102107531258, 0.1256674810179642, 0.14269511375044072, 0.10504495618598801, 0.16721249744296074, 0.12205971032381058, 0.12133867187159401, 0.08930297089474541, 0.10602596175989934, 0.14590060817343847, 0.2516483909317425, 0.1451177280396223, 0.17130174301564693, 0.09007884854716913, 0.10862949384110314, 0.1254870585565056, 0.15618033228175981, 0.19684687655951294, 0.12789306230843067, 0.14833755312221392, 0.11758268198796681, 0.12913057447544166, 0.13850689705993446, 0.10898201313934155, 0.1259928114180054, 0.17647625106785977, 0.12510987451033934, 0.1492489477885621, 0.10000925604254007, 0.10039755449231182, 0.11608123326940195, 0.12002325031374182, 0.11727773477988583, 0.144213023728558, 0.08038200637591736, 0.12122155672737531, 0.10752623661288194, 0.2378067108137267, 0.04672212665900588, 0.1595174353569746, 0.12714268400200776, 0.09607499465346336, 0.14921835942992143, 0.0835462933672326, 0.07542657692517553, 0.11028585888977561, 0.099745930172503, 0.09636204210775239, 0.13118785193988255, 0.07830122445843049, 0.0853983818420342, 0.07273927969591958, 0.1778422234846013], [0.07818651132817779, 0.09664457051881722, 0.023557750275358558, 0.019179453873740773, 0.02688992040098778, 0.022736646567604372, 0.02223010321280786, 0.03329130967280694, 0.034568414358156066, 0.048044404813221524, 0.026697106193751097, 0.03280006728268095, 0.06456285808235407, 0.039683163831276555, 0.05789584440312215, 0.019584069394373467, 0.06026417589081185, 0.004725619817950896, 0.06747449934482574, 0.03643625841609069, 0.03758191390495215, 0.03229196329734155, 0.037174043112567494, 0.011431702695387815, 0.01256447789325778, 0.13196429956172193, 0.06882696212934596, 0.019142504249300276, 0.04466809259195413, 0.06988405183489833, 0.035844270539070876, 0.02967197334926043, 0.027631716935762336, 0.018617745621928146, 0.007753853752676929, 0.03801141978640642, 0.016704958797033344, 0.028172716298805814, 0.03137557800593121, 0.08114149062229054, 0.025851373361157517, 0.016946162729124938, 0.04383947919788105, 0.03792490317885365, 0.022274435298251252, 0.04174371861985751, 0.056096732549901517, 0.0974297101742455, 0.025830102984660437, 0.01952678577176162, 0.04430828582761543, 0.049463153683713505, 0.0435183048248291, 0.007545305166526565, 0.04780033915968878, 0.04213753355933087, 0.031023869557040076, 0.05354103718751243, 0.03320115272487913, 0.04386454088879483, 0.015685397167024866, 0.02670826979114541, 0.030092580243945122, 0.04811974934169224, 0.04333500876756651, 0.03253537077190621, 0.046802166649805646, 0.033950411448521275, 0.0446792544930109, 0.011479278178220349, 0.030718996987811158, 0.046115730090865066, 0.029511984969888414, 0.03846143438879933, 0.030270112146224295, 0.01919879042543471, 0.01252282178029418, 0.07634021075708525, 0.07700675606195416, 0.015206073244501437, 0.07258361697729145, 0.054249560061310015, 0.048476119326161485, 0.009527478982428355, 0.11078294007373707, 0.1593607616211687, 0.043651355363960774, 0.22321163969380514, 0.18773723180804933, 0.0838023724832705, 0.3152898188148226, 0.45831875822373797, 0.4378994410591466, 0.6140820628830365, 0.3500309203352247, 0.268005726060697, 0.2828800821942942, 0.05002887886283653, 0.09235320972012621, 0.18693163432180882, 0.05762587567525251, 0.01724114565045706, 0.00742918492427894, 0.041004308832011054, 0.03133513392614467, 0.0434904441769634, 0.02574708592146635, 0.03436591575986572, 0.009045969328976102, 0.045197129382618835, 0.022869999054819345, 0.04418224794790149, 0.015517883834296038, 0.045663812197744846, 0.051950754664306126, 0.018984921276569366, 0.05509803417537894, 0.03779688058421016, 0.040196288975753953, 0.04110111542312162, 0.04466806884322848, 0.03185242527563657, 0.01481471290545804, 0.03355349899668779, 0.029461274655269723, 0.029840412882289717, 0.03189791087061167, 0.023430180602840016, 0.06402042361774615, 0.03455608198419213, 0.01168210756233228, 0.07562852930277586, 0.056957260838576725, 0.012805032128069018, 0.07608901030783143, 0.033565593883395195, 0.058079978451132774, 0.05651492385991982, 0.006205777803968106, 0.035462282464972565, 0.004802903684321791, 0.056857305844979625, 0.03775412609268512, 0.03622888793636646, 0.05175162838505847, 0.01608464547566005, 0.020022443728521466, 0.032093827679221115, 0.02318318876703935, 0.005627909816601979, 0.04640313038336379, 0.05343657672139151, 0.006634364270472101, 0.03935990296304226, 0.11906030055667673, 0.02073374859589551, 0.04043744371405669, 0.03231208186064448, 0.06255378374563796, 0.003025511737048094, 0.027034411040533866, 0.04518507520801254, 0.04838252220568912, 0.00934934233581381, 0.016410803688423972, 0.02579286159016192, 0.030077493017805473, 0.017988870884957056, 0.0824492040223309, 0.0487310415399926, 0.03650150295080883, 0.034307348009731085, 0.030287201050668955, 0.06768312850700957, 0.015215940840010132, 0.07870352108563695, 0.09348913840949535, 0.03621880490598934, 0.027280045806297233, 0.05647432371707899, 0.03431354981980153, 0.0017506419764166431, 0.01960797418308045, 0.026973083349210874, 0.054935046671224494, 0.053648751229047775, 0.026189806272408793, 0.03193664504215121, 0.06805219048900263, 0.031480930745601654, 0.017738635651767254, 0.025107147671016197, 0.04155951671834503, 0.015257592712129866, 0.055075445744608126, 0.005431781813967973, 0.02760632785170206, 0.037967230193316936, 0.07650717108377389, 0.057601550194833956, 0.012524110996829612, 0.04734183608421257, 0.013472603717153626, 0.027121422978650247, 0.024905704194679856, 0.025677532689379792, 0.01789926863940699, 0.045571093780121634, 0.006535849043367696, 0.010106779102768217, 0.049384538616452894, 0.03524602996185422, 0.03774384967982769, 0.01889027073048055, 0.0495284185744822, 0.03189591597765684, 0.016068681243008802, 0.04331577908513801, 0.06285701426012175, 0.048213356640189886, 0.03288425990779485, 0.052820008913321156, 0.04268333695030638, 0.041065834994826994, 0.08661720715463161, 0.018889543001673052, 0.056658763105848005, 0.03989735019526311, 0.07715904646153961, 0.0526134492829442, 0.059303322806954384, 0.014019510575703211, 0.01702005010364311, 0.019148612760805657, 0.02019987385054784, 0.07788402041686432, 0.007020546963238823, 0.037312498183122704, 0.03931661582152758, 0.041602132110191245, 0.03147744646828089, 0.014912929153069854, 0.04248626323949013, 0.07120724261871406, 0.10581132756280047, 0.04329541964190347, 0.027606492396444082, 0.05116255481594375, 0.024664473121187518, 0.06311329015131507, 0.013359638662742717, 0.06628986541181803, 0.0450295719451138, 0.02561567913341735, 0.02486825584700065, 0.05355475038023932, 0.0863153472808855, 0.03215793566778302, 0.030696113394307237, 0.051217926666140556, 0.05674695230222174, 0.1275598066193717, 0.14786340642188275, 0.22410353326371737, 0.09433415199496917, 0.09293305182031222, 0.23666905186006001, 0.22980748862028122, 0.24808448074119432, 0.3010832497051784, 0.18504115433565207, 0.20035843098802225, 0.4051356448658875, 0.059721754996904304, 0.027912303040336286, 0.09207030132945095, 0.04769381933978625, 0.029270487571401254, 0.04149114413719092, 0.010833574076449233, 0.06219941883214882, 0.021482968303774084, 0.026856495765969157, 0.09383804790143456, 0.03263944108039141, 0.048272562213242054, 0.06211891743753638, 0.04671490365373237, 0.02520833590200969, 0.06552573320056711, 0.09192694045071091, 0.035614583042583296, 0.025064995379320214, 0.02655163507110306, 0.06354530661233834, 0.006205220132999654, 0.06781568032290254, 0.03654792492410966, 0.06074309947767428, 0.010706290236807295, 0.021813911884757023, 0.027636537927069833, 0.03361008542456797, 0.03161698380219085, 0.031767774639385085, 0.028197326763932194, 0.019423149725688354, 0.05908243930233376, 0.04732267764796104, 0.06600887048989534, 0.02742031595802733, 0.012005824745366616, 0.01741268778485911, 0.005189008345561368, 0.005413533886894584, 0.01859067377102162, 0.023193387148369635, 0.04011025752073952, 0.025369471005563225, 0.07999718881079129, 0.03002361733732479, 0.022062162403017282, 0.04680630232074431, 0.03687024602134313, 0.011775797133200934, 0.025678530135857205, 0.03441734532160418, 0.08491263219288417, 0.034826315340719054, 0.0036576833060410407, 0.04990597242223365, 0.07427042789225068, 0.06061513455850737, 0.07019224244036845, 0.09071205742657185, 0.02033632554646049, 0.028037407934399586, 0.06936189878199782, 0.02574904858400779, 0.020410791372082064, 0.11967300410781588, 0.04602116605799113, 0.0647230873416577, 0.0213743721667145, 0.06809525710663625, 0.03926632280594536, 0.05867715033569506, 0.014706919136058007, 0.02037237780833883, 0.05948392168751784, 0.009654535512839044, 0.06313349692417042, 0.2022463461118085, 0.20722686100218976, 0.07387952386800732, 0.145776042714715, 0.13039672082023962, 0.0365177843985813, 0.1032065266211118, 0.10689397768250533, 0.21534868090280465, 0.1645751946738788, 0.050924249924719334, 0.11505793460777827, 0.15579573863318988, 0.16120890102216176, 0.33063703243221554, 0.13764969020017556, 0.1848188934049436, 0.17217706676040376, 0.14549658128193446, 0.1055972972618682, 0.08482577292514698, 0.08168701242123332, 0.10042149999311992, 0.20040279360754149, 0.12569082262260572, 0.23531184611575945, 0.11655175659273352, 0.07538342209798948, 0.08612360006996564, 0.10419068059750966, 0.10954899021557399, 0.07699762976595334, 0.145034539646336, 0.09952452419591801, 0.15423491810049328, 0.1086647573060223, 0.09406468538301331, 0.08158101168062006, 0.11719861759671144, 0.18627893791667052, 0.08897547596799475, 0.09967566108597176, 0.1353513563850096, 0.17191851777689798, 0.15069912640111788, 0.09041570725717715, 0.15874207339116506, 0.3643021674028465, 0.14191011658736638, 0.1076381541788578, 0.09458717770342316, 0.14994075495217526, 0.17958198727241584, 0.08980142271944455, 0.11515123317284243, 0.08725325909576245, 0.10447388754359313, 0.18115709775260516, 0.09119173418730497, 0.1296587868460587, 0.09780945229743208, 0.05185630258971027, 0.09981186342026506, 0.11796453435506139, 0.20814603167985166, 0.1342507725847619, 0.12933604844978877, 0.12141431495547295, 0.14914426340588502, 0.0960793983457344, 0.15685623458453588, 0.3185969442129135, 0.1110188327729702, 0.15465323493949004, 0.11889623078916754, 0.11572508380881377, 0.08674089730318103, 0.13103489657597883, 0.13659536891749927, 0.15282934638006346, 0.22068425959774426, 0.16906343240823063, 0.17101236140089376, 0.13440661850784505, 0.25689447085772243, 0.2572280115314892, 0.24933113956025668, 0.35650281448449406, 0.2684843646628516, 0.15777626021632127, 0.3718198468642575, 0.5293738597205707, 0.5218701852219445, 0.5587632741246904, 0.44094945596797125, 0.5287624182445663, 0.5395922171218055, 0.17614617092268808, 0.14366429245897702, 0.29767730246697155, 0.1080368681411658, 0.1345014777034521, 0.13000692959342683, 0.1429481937416962, 0.19743117663477147, 0.09147555860025541, 0.05666171134050403, 0.1931121383926698, 0.1348558629729918, 0.1468593238719872, 0.12901567135538372, 0.1191651884998594, 0.09775064366736583, 0.1930567699351481, 0.13423579053155013, 0.1578177458473614, 0.1807480768433639, 0.14891341222184046, 0.20743546980832303, 0.0885381872898766, 0.2199941080595766, 0.13416976907423564, 0.11895429981606347, 0.15222545021346637, 0.08831493569804089, 0.1630505264869758, 0.08813087628888232, 0.12415428007287638, 0.09410246621285166, 0.18784123765570776, 0.12706923937158926, 0.16352677664586476, 0.14476761754070008, 0.16497753879853658, 0.1613391526043415, 0.17070621997117996, 0.14612657390534878, 0.10526400764605828, 0.11248098752860512, 0.15446061241839612, 0.08533415171716895, 0.17511667045099394, 0.12966870702803135, 0.12088231635945183, 0.15171479832913193, 0.11502296291291714, 0.10669764357485942, 0.11496260043765817, 0.08754498165632997, 0.10836467519402504, 0.10113925433584622, 0.15211269126406737, 0.10677878957773958, 0.0975680091817464, 0.23163234069943428, 0.12952060997486115, 0.18183795336101735, 0.09087893632905823, 0.1396437417715788, 0.18821851669677667, 0.09023476232375417, 0.17011753655970097, 0.14369401229279383, 0.0828754257942949, 0.17078940836446627, 0.08168163842388562, 0.16961019592625753, 0.08908239951623337, 0.17615553470594542, 0.0991520763241819, 0.10151508809732539, 0.10779718921652862, 0.11942816153168678, 0.11723996752074786, 0.12976619893951075, 0.1763237706784691], [0.030941230777118887, 0.07066790905914136, 0.028328585970614637, 0.03383512156350272, 0.03821036286119904, 0.028495081500815492, 0.027617971512622068, 0.036125163680740764, 0.03215700268213238, 0.029772250646991388, 0.024610802697549974, 0.04356051988101431, 0.021210109016724994, 0.0023543235563140896, 0.02546261520391064, 0.03535306207569582, 0.01955003577417561, 0.027661981293931603, 0.031051994833563055, 0.009605141556156533, 0.04054633840652449, 0.050312679527061324, 0.01866334317518132, 0.0768406642600894, 0.02410287513131542, 0.02432708515386496, 0.05040863794939859, 0.02506812851476882, 0.0454414359160832, 0.059613908641040325, 0.06269636430910655, 0.017317109342132295, 0.04039398354611226, 0.013750638530057455, 0.015491071523034146, 0.008849674237093754, 0.05817242884742362, 0.043204994672643285, 0.015723172907850573, 0.027507865635145987, 0.04020980200065034, 0.032376071105578115, 0.007211364157098744, 0.053619638684072664, 0.009039744618348777, 0.09193730846579586, 0.016955602847571884, 0.031207002765898193, 0.021349802413689237, 0.04270478204957076, 0.044822137004562786, 0.029592194594442844, 0.017165984326441373, 0.10254524674798761, 0.028420790397961224, 0.07402901870331594, 0.06591171106057507, 0.044324496029210944, 0.00853311559850616, 0.10229209890323025, 0.024823503069845692, 0.0809812138655356, 0.05386830141235675, 0.05056808010808059, 0.01449497533030808, 0.03361538478306361, 0.0315260872510927, 0.00873064816862877, 0.028685142552214007, 0.03341564442962408, 0.06700414565524884, 0.06176573996032987, 0.028301120569397296, 0.03501585052747812, 0.07616473481591259, 0.01569730036758951, 0.05336390562089426, 0.06488192560417311, 0.007141391081469399, 0.0641080496300544, 0.0724973955324718, 0.05285426136106253, 0.10843083914369345, 0.0856645100616983, 0.06665837778044598, 0.11261951723801238, 0.040520666034093926, 0.0732289512774774, 0.09471524440284286, 0.07785531160022531, 0.047181162384471724, 0.054105289945644994, 0.19487907072263105, 0.17232889575617655, 0.1479407458433083, 0.11735807332609381, 0.0304248350938516, 0.05059214435251696, 0.006518378887059433, 0.06762927318257944, 0.04533039366028138, 0.11997971550694533, 0.06184056880218642, 0.052063320231224806, 0.04074791080451437, 0.02154779214678066, 0.01800872651594026, 0.017145416233688593, 0.022279661714232395, 0.013528973861996616, 0.06428410232599292, 0.07512810972652265, 0.054641054411019595, 0.05000299953722528, 0.006505525737468685, 0.036423440889588425, 0.01706702508298414, 0.04045311787298747, 0.017950374200674038, 0.05503121204674244, 0.05072523221107466, 0.032930824373449595, 0.022174103717718805, 0.01584003190509975, 0.05089597197781716, 0.10528939164110593, 0.02703930327801832, 0.026249822694808245, 0.05942680260964802, 0.007661293942614326, 0.01127927065161722, 0.01651100125829024, 0.03924050794116088, 0.03828871329980237, 0.07714274126504149, 0.07252028930400099, 0.0214246244701956, 0.005203279633341091, 0.022431394018765007, 0.02055814882208194, 0.053128867875784636, 0.030437557625451257, 0.0386909760002579, 0.08087752014398575, 0.014868717507592269, 0.0644203182309866, 0.020413931292880858, 0.043308467870312076, 0.09449703432619572, 0.02674337719301028, 0.08834283027265753, 0.042186628960605176, 0.018163344290639673, 0.04126410971262625, 0.02891439917896475, 0.04952163661697081, 0.053278905539108176, 0.011716773916435028, 0.05712410581431218, 0.07662718357252223, 0.0727505162358284, 0.02600029144170029, 0.052722873232726536, 0.02508629798623068, 0.039536569733172655, 0.07283833902329206, 0.04288236823465143, 0.01684310513415507, 0.05328158235975674, 0.044690701378775496, 0.022229229598971348, 0.050138048361986876, 0.01680134130375726, 0.04256889184138604, 0.02060213655100337, 0.023007173390526856, 0.040630941545324664, 0.037130525269146473, 0.048730783696685515, 0.058236394343631606, 0.04417454318276473, 0.04809128140498485, 0.0348582709474223, 0.04609454283490777, 0.010059441107192209, 0.01566112766574536, 0.044090859458914826, 0.00872739713772067, 0.03464283607900143, 0.029678127661879574, 0.019657632768420235, 0.03277645426403199, 0.018980493835572685, 0.03826586363304939, 0.01771015753703458, 0.024577924283221364, 0.017713804662759815, 0.027980343139331256, 0.03682903180431042, 0.06570874766579696, 0.060264108037309985, 0.043174542021006346, 0.024481263577139804, 0.05733443131404264, 0.035123897051172595, 0.029173721692391803, 0.0485881658137909, 0.04821427605514016, 0.010112656064198484, 0.011278106964060237, 0.0440769121716065, 0.03500423740063395, 0.0696129228121468, 0.004249012580008379, 0.004543595589763884, 0.004036433071762855, 0.03983596991747618, 0.06846049893647432, 0.033229769939290624, 0.061085535745535574, 0.037521948372679095, 0.0780204398823636, 0.021262264610933404, 0.04485201968678406, 0.037751924246549606, 0.05366667812424047, 0.02461986622906157, 0.047123975453100035, 0.01555365789681673, 0.010685118247887917, 0.016779495868831873, 0.062308846174606254, 0.01070916892162391, 0.044319949844585996, 0.009959483569088792, 0.024330035084858537, 0.04371227423793503, 0.0603705294696348, 0.06153817967112575, 0.0914439931511879, 0.029371507864977633, 0.018494644102507403, 0.03733214855726276, 0.04533192714942353, 0.03364774751077805, 0.008965047242652093, 0.03373635739886335, 0.020211819459551146, 0.031100737396627665, 0.03949815108041678, 0.07754047135157244, 0.03017372963950038, 0.027538932360974804, 0.13098940758832864, 0.036272392209087095, 0.03441039373033813, 0.04264832115066903, 0.040976393901343854, 0.05773393237697227, 0.05061403728489365, 0.08329222271484987, 0.137191502643483, 0.05128760542720556, 0.15628739153700216, 0.14798512203352793, 0.06803783947335822, 0.03995490353554487, 0.048991829689059935, 0.14061653028641427, 0.07451985736510583, 0.11683416286749498, 0.09422629206840481, 0.11720236311001436, 0.042051936366728375, 0.05439854599535465, 0.10091073052691561, 0.04039305056046162, 0.04528316423030836, 0.09382312013102428, 0.020204340307308093, 0.01348173086132322, 0.06283159633832318, 0.07754542465720858, 0.049268163075404506, 0.012189543190678316, 0.039713599519538026, 0.06654635164886713, 0.04184114607051015, 0.02396568043955735, 0.09283661842346191, 0.04325177966217909, 0.038845213795346875, 0.004471031358532075, 0.014217445177824369, 0.009986469754949212, 0.03234025802729385, 0.11187446543148585, 0.013641733659564384, 0.003423500939139298, 0.02735738013871014, 0.02456259448081255, 0.0700915614143014, 0.02236461260222963, 0.08129369959767375, 0.14829175200845512, 0.034393759444355965, 0.006313397274685225, 0.0376950460486114, 0.051834487688860724, 0.028524183867765323, 0.019953375648973242, 0.06400989275425673, 0.011522558534384837, 0.016167353805420653, 0.03700886394030281, 0.021035247149744203, 0.01952920644544065, 0.009988462103397718, 0.030576623377523253, 0.041264866279172044, 0.015914903155394962, 0.016916865283357244, 0.045961970662964244, 0.018169647880962918, 0.0502116829822106, 0.03450786867844207, 0.042228776163288524, 0.03837521294397967, 0.04247544060594269, 0.0883069493408714, 0.008538488747685083, 0.048954679896788936, 0.06426236884934561, 0.013317395616987986, 0.042673555868012567, 0.02249104403225439, 0.05495007961456265, 0.012377899422842478, 0.03693369583093694, 0.03691353994820799, 0.038842106104961464, 0.04561232156785471, 0.02283614863907652, 0.022834596490221362, 0.052325000653841665, 0.02115385846367904, 0.024166379223710725, 0.028738997876644135, 0.033337416127324104, 0.044526350019233565, 0.0206436900355454, 0.02287674369290471, 0.11194267177156039, 0.10351631178387574, 0.09306602432791676, 0.12437352830810205, 0.11901797354221344, 0.13465287243681295, 0.1462940906307527, 0.11987790811274733, 0.14112494300518716, 0.0661245132131236, 0.07714050209947995, 0.06270217256886618, 0.13387965464166232, 0.08654215439621891, 0.05785602796822786, 0.18225359677204064, 0.0972910922552858, 0.08380700009209768, 0.1258906511855977, 0.06055902649781533, 0.11931526687528406, 0.2257455201553447, 0.10602956478084836, 0.19953273529452936, 0.13195873557456902, 0.12440406238394124, 0.09851689969322511, 0.09771813505462237, 0.11464478820562363, 0.26662070038063185, 0.08644910688911166, 0.11521409265697002, 0.151192557066679, 0.06423194333910942, 0.1588514803775719, 0.07527846630130496, 0.2906439070190702, 0.0967332889725055, 0.07747888072792973, 0.05962894497705357, 0.12936082854866982, 0.18702626281550952, 0.06283924342798335, 0.15514557994902134, 0.08897637163421937, 0.15999302055154527, 0.08652992040983268, 0.2169597808803831, 0.12168617679604463, 0.14722624846867152, 0.08878648360925061, 0.09236473124474287, 0.1025553433490651, 0.17438056852136338, 0.07757009619048663, 0.15532503889075347, 0.1883080561778375, 0.15919935171093258, 0.14850939890103682, 0.1637265644967556, 0.16417690818863256, 0.2821852080523968, 0.10765784526509897, 0.15178970859519073, 0.1587252864348037, 0.10868733216609273, 0.16101931833795138, 0.210937551887972, 0.17282220428543432, 0.10226529676999364, 0.13520962399031433, 0.17157644113259657, 0.13833722259317124, 0.1447177180754287, 0.1833619972957032, 0.12597377172538213, 0.13478815874883107, 0.16223707156521933, 0.1891193397875343, 0.18743072396942548, 0.2181747928261757, 0.24253002021993908, 0.2525115960410663, 0.20234964628304752, 0.24514862256390707, 0.28219590176429066, 0.1729545864675726, 0.25397579318710733, 0.22507253555314882, 0.09824051880942923, 0.14708230404981545, 0.17843701371124812, 0.36144632207495825, 0.2616630792617798, 0.24886713017310413, 0.22658226239894116, 0.19176918188376085, 0.08249984309077263, 0.13547835099909986, 0.2706681617668697, 0.18994891670133385, 0.2759814166596958, 0.1143970007875136, 0.09335286143635001, 0.3010317353265626, 0.16616141955767358, 0.11243040952831507, 0.1912080334233386, 0.1396635142820222, 0.18368332433913434, 0.2168972742344652, 0.19171859031277044, 0.10751987195440701, 0.1503625458904675, 0.1550839011158262, 0.10593585230942283, 0.09605498465576343, 0.14154640824667045, 0.09457790212971823, 0.15675517357885838, 0.2511794960924557, 0.10097021769200053, 0.1528251123215471, 0.08923981964055981, 0.18389991271708692, 0.1449090785213879, 0.07610279135406017, 0.1353294804160084, 0.29650520107575823, 0.07611845194229058, 0.08392589978341546, 0.10802962817251682, 0.13588495632367475, 0.10653577226081065, 0.14572124422660895, 0.18125328687684877, 0.10439545568078756, 0.11891072429716587, 0.0833559710798519, 0.09056280686386994, 0.15118469963116304, 0.10768932928996426, 0.09691672412944691, 0.13691782232906136, 0.15794205346277781, 0.11820637780640807, 0.14779392443597317, 0.07879331841000489, 0.2612180417137486, 0.09843436269355671, 0.1362918737743582, 0.15111968240567616, 0.07700390621487584, 0.19744983634778432, 0.09531482508672134, 0.09884539885180336, 0.20759005365627153, 0.09990398811974696, 0.1841685175895691, 0.20756323795233453, 0.11951421334275178, 0.12581492667751654, 0.12482665399355547, 0.14954003931156226, 0.07906712764608008, 0.26651512033173014, 0.1300665456801653, 0.11176830184246812, 0.15281489358416625, 0.11442608279841286, 0.08739014675042459, 0.20079725315528257, 0.09041916100042206, 0.13669220943536076, 0.17724459698157652, 0.10762790830007621], [0.044208378331469636, 0.022953492788864032, 0.06945147897515978, 0.024273326520674994, 0.034215420085404596, 0.05089891003444791, 0.04777882281424744, 0.03669721959158778, 0.030459613406232426, 0.03936744827244963, 0.02953554709841098, 0.01061921044518905, 0.011159728896538062, 0.048528295276420455, 0.04308423918804952, 0.03365487891382404, 0.022369274137807742, 0.03760125215298363, 0.03535384578364236, 0.04087568573387606, 0.015490194516522544, 0.018856639142281244, 0.02950766948716981, 0.022660567524975965, 0.035827490368059704, 0.041449926527483125, 0.019013401087639586, 0.030340506761733974, 0.02740573593681412, 0.02653355889820627, 0.025915739193026508, 0.09673023556492158, 0.08630174265376159, 0.020553643349558115, 0.031256868304418664, 0.03007355412202222, 0.059239533729851246, 0.03999646380543709, 0.05398580671421119, 0.06599756609648466, 0.09537463794861521, 0.03806277810196791, 0.024657431624031494, 0.04652756692043372, 0.02953512979937451, 0.003318284754641354, 0.06821427214890718, 0.05354541034570762, 0.06987647259874002, 0.06349923408457211, 0.027323360089212656, 0.03722212749666401, 0.07106987998953887, 0.05420732804174934, 0.036038959199296575, 0.011213529938166695, 0.04740146913432649, 0.04974813160619565, 0.056507290340960026, 0.04746885783970356, 0.05706100884292807, 0.055563699187976975, 0.041882614738174846, 0.06653997341969184, 0.04527712866131749, 0.019101247623828903, 0.04801034574796047, 0.07397855605397906, 0.02657348389870354, 0.0076450201283608165, 0.013302688370458782, 0.013041867990978062, 0.040006760574345074, 0.07123836023466927, 0.01809798101229327, 0.053163588512688875, 0.04411196529066988, 0.00983915725789432, 0.009249410242773592, 0.012007938381949705, 0.033444780723324845, 0.04660706747589367, 0.05745124111750296, 0.01607612646850092, 0.0544560043407338, 0.0344908340567989, 0.11823555481220994, 0.07208626437932253, 0.10339382942765951, 0.04767373131055917, 0.10863062699458428, 0.052763208746910095, 0.10822194535285234, 0.04200489692656057, 0.04286574751936963, 0.09443488051848752, 0.10561014192977122, 0.03574866495494332, 0.06573031829403979, 0.049485714973083565, 0.03067360638773867, 0.07172014045396022, 0.034721291690532646, 0.03832922184041568, 0.03158126911148429, 0.03342935083700078, 0.025075541509847556, 0.012220925435290804, 0.01578492298722267, 0.11581029423645564, 0.03948743361979723, 0.02769416760254119, 0.02038290019014052, 0.03263155311079962, 0.01984334271401167, 0.043868232119296274, 0.02783658362126776, 0.023987651403461183, 0.03181276151112147, 0.03763509747971382, 0.0748223482764193, 0.06164189374872616, 0.04107941587322524, 0.019368609080889394, 0.03746504303334015, 0.03335487483335393, 0.03837779137705054, 0.03709128898169313, 0.010418061283417046, 0.030543968879750798, 0.056734151739094935, 0.02287807362154126, 0.017073213322354213, 0.002882155099151922, 0.024209864836718355, 0.036872532684355974, 0.08768223571990218, 0.021645153440268974, 0.0021281894629022902, 0.05881711175399167, 0.04257947359500187, 0.05131711830784168, 0.04970200479562793, 0.043618056257920604, 0.03886434169752257, 0.06957529126001255, 0.0015014111870966318, 0.03664631589448877, 0.01008543832826295, 0.013168173892024373, 0.029779415976788317, 0.016847708994256597, 0.011981320301336902, 0.026819715775283318, 0.014488161142383302, 0.04690789258373635, 0.04854339607326048, 0.029098207530166422, 0.03496130649000406, 0.013186993060766585, 0.02029129456994789, 0.03562594171879547, 0.052505545251603634, 0.03645493509247899, 0.04587452446243592, 0.09561433044395276, 0.03927111665585211, 0.014027837048550802, 0.02393357894782509, 0.029315671218293052, 0.053431216294744184, 0.08565543126314878, 0.09474060125648975, 0.055374041864914555, 0.01041064998467586, 0.04905179861400809, 0.0565597682393023, 0.027662717504426837, 0.059325884096324444, 0.019407312718353102, 0.009469123274487044, 0.1199824975005218, 0.005219480929164482, 0.052767320669123104, 0.02110042722363557, 0.05155693293948259, 0.030481662401663404, 0.04074237056608711, 0.06521383779389517, 0.029443330796701566, 0.018447808222845197, 0.017203164652788212, 0.003104686383656891, 0.050817116030624936, 0.03501351636701396, 0.09442935724343572, 0.020506827825946466, 0.061131370786045275, 0.07520544914794819, 0.020162851283592836, 0.01600828653733645, 0.017216458850141083, 0.01728484160932047, 0.039802178873547485, 0.029593789151736667, 0.06316546949424914, 0.04458463278466037, 0.10376218573323318, 0.022444957933787788, 0.05913489684462547, 0.06851153155522686, 0.04805041663348675, 0.019178985684577907, 0.015619121259078383, 0.001568597392179072, 0.044341914023139646, 0.05309872395758118, 0.07308834525091307, 0.04435309288757188, 0.036460726388863156, 0.01573527797258326, 0.005034133575723639, 0.04136855321537171, 0.01374326624707984, 0.018018622949187244, 0.023861630487122705, 0.03834554060761418, 0.004091075920898999, 0.08798137466822352, 0.040741206878530126, 0.05617696253050651, 0.05025442051036017, 0.0497046816162765, 0.03365352523646184, 0.017412803135812283, 0.03726381668820977, 0.03614678519910999, 0.046749634468661885, 0.021873818045215945, 0.03761111465947969, 0.0329098406779979, 0.017830254842660258, 0.017809094728103707, 0.03513519465923309, 0.06014910313699927, 0.04603894028280463, 0.06033517100981303, 0.004742235868304435, 0.05032636218571237, 0.02222051551299436, 0.03690247643472893, 0.026560812257230282, 0.02868402636210833, 0.04308151486994965, 0.01841958286240697, 0.04143743469778981, 0.03715005011430808, 0.030561264737376144, 0.04422285148341741, 0.020419535992134894, 0.055991162679025104, 0.0567065557198865, 0.0867110417623605, 0.08195347312305655, 0.03591408161446452, 0.08489533633525882, 0.10075115944658007, 0.07211688666471414, 0.042609776968934705, 0.11249503320349113, 0.03863565843286259, 0.03481316193938255, 0.07983962619411093, 0.01033558280739401, 0.021758674045226405, 0.10339153597929648, 0.021361100021749735, 0.024701492295467427, 0.05503864200519664, 0.062035980102206977, 0.10000719329608337, 0.038411548494228294, 0.006880795466713607, 0.019194941435541426, 0.04685203558100121, 0.022197543709938015, 0.012070010765455663, 0.015876116397391473, 0.08671653789601155, 0.059105305932462215, 0.017246680799871683, 0.019773224601522088, 0.06812226280037846, 0.015129960275122097, 0.04628882776679737, 0.011916092729994228, 0.03443045122548938, 0.03305518287899239, 0.025460732269233892, 0.01491440157406032, 0.03137208694326026, 0.003909065687496747, 0.030917855245726447, 0.017632112439189638, 0.05597719503566623, 0.02790139219723642, 0.01960391315099384, 0.06515094438301665, 0.021976745022194724, 0.021881002034725885, 0.03153264189937285, 0.04708219126665166, 0.05211401018979294, 0.0278047111351043, 0.03859032550826669, 0.06978540641388722, 0.058084768908364434, 0.023755867233765975, 0.036644941861076016, 0.025937131705826948, 0.021590236208534667, 0.016236264125577042, 0.03778201048927648, 0.0533695103201483, 0.053822598686175685, 0.042890446194048436, 0.03959377362791981, 0.0679807203954884, 0.02254961008605148, 0.021160723541730216, 0.02749534496771438, 0.11023004938449178, 0.006971658515145204, 0.03936892408611519, 0.03616147208958864, 0.026299459227759923, 0.031495763521109305, 0.021512430294283798, 0.045123063892658265, 0.13392054316188606, 0.029776152223348618, 0.04770009918138385, 0.013919122167862952, 0.02462267197136368, 0.05240790066974504, 0.08335484471172094, 0.02458143570194287, 0.03613254274906857, 0.05688694425459419, 0.014784764066072447, 0.015635205931695442, 0.044052264387054105, 0.06912663712033204, 0.09356982979391303, 0.10546479294342653, 0.09482418998543705, 0.11129109494920288, 0.2349686159619263, 0.12983888361070836, 0.13632186502218246, 0.15423219038971833, 0.15459660440683365, 0.15162832582635538, 0.08582606924963848, 0.10591434953468186, 0.11171868736190455, 0.09462791016059262, 0.10972730921847479, 0.1106636468321085, 0.08666608881737504, 0.12061495999140398, 0.17733036380793366, 0.0914662830265505, 0.22621851334614412, 0.13029198215476104, 0.089789541571268, 0.11759189649352006, 0.1252004046525274, 0.06279772387019225, 0.1404506420450551, 0.0970591079177601, 0.15759849761213574, 0.1660394732441221, 0.21290400065481663, 0.14140121532338007, 0.1847541747348649, 0.2163099478930235, 0.08533318141209227, 0.10631397273391485, 0.11149842810950109, 0.08560595927493912, 0.19194398607526506, 0.23006457196814672, 0.16952338415597165, 0.0986251395993999, 0.12825082668236323, 0.10536397621035576, 0.04504415026998945, 0.11648577584752015, 0.07488136046699115, 0.18534071397568497, 0.21987824141979218, 0.06186883657106331, 0.14662324796829904, 0.25111251111541477, 0.14302371468927177, 0.07732722136591162, 0.17078159164105142, 0.11023939959704876, 0.14928377020571912, 0.1165121030062437, 0.2244782474424158, 0.13937561187360967, 0.11847381559865815, 0.12614911874490126, 0.13880683667957783, 0.11937176170093672, 0.12373342551290989, 0.1342604620648282, 0.19570857978292874, 0.08115953965378658, 0.12332763443035738, 0.19204666199428694, 0.06450115889310837, 0.14839393938226358, 0.10159301784421716, 0.180264769920281, 0.18611185545367853, 0.07183063309639692, 0.11470325078283038, 0.18837052211165428, 0.14963346001292976, 0.11771159007080964, 0.11094318968909127, 0.15810773814363138, 0.08112184024815049, 0.20151761307248048, 0.1293476785400084, 0.18023566076798098, 0.15286765646721634, 0.17579231491046293, 0.3216903310801302, 0.24333270000559942, 0.21316625443952425, 0.24608513659664563, 0.1690483417894159, 0.20819518475660256, 0.2375852641250406, 0.24967640531914576, 0.10323009214230947, 0.11318272844489131, 0.2286399198429925, 0.10218896836574588, 0.19544841588607856, 0.17249785097582, 0.11085733465318169, 0.16352604382804461, 0.08839328613664423, 0.11155582538672856, 0.10701801388391427, 0.10093732231429645, 0.14578790350684098, 0.1865414495446852, 0.1510027843926634, 0.1345140848840986, 0.1420064957014152, 0.06701672569449459, 0.1167450983609472, 0.09856913331896067, 0.1492540503719023, 0.10619389239166464, 0.10488359377320323, 0.1055857485958508, 0.18865786812135152, 0.1545955187508038, 0.10387814058257, 0.1307843814470938, 0.1290410485650812, 0.09023019578307867, 0.16927707594420227, 0.17427464920495236, 0.08186605067125388, 0.20720874411719187, 0.16864101721772126, 0.18191548277224812, 0.08838271456105368, 0.10627201212836163, 0.15517458053571836, 0.11691524780222348, 0.1291471171591963, 0.16040699476642267, 0.1062813148434673, 0.1383873934724501, 0.1007539075134056, 0.2874192643378462, 0.10917490707444293, 0.13903881423175335, 0.1198419728981597, 0.11813585087656975, 0.08808791823685169, 0.16264075918921403, 0.06906200665980577, 0.08240710770977394, 0.17133602260478906, 0.07461107282766274, 0.09177517930844001, 0.08251717287514891, 0.1916484840746437, 0.10925021089081254, 0.11046626778053385, 0.12330050660031182, 0.08859435641872031, 0.09226084074803761, 0.08789539071066038, 0.22952690081936972, 0.26226838678121567, 0.13814565858670644, 0.15900670204843792, 0.129141648166946, 0.13070397504738399, 0.15511134107198032, 0.10195367956267935, 0.17062611212687834, 0.20392386109701224, 0.14865841876183236, 0.1670728549361229, 0.13285780804497854, 0.1489925022636141], [0.05856791976839304, 0.019572790446025983, 0.06655830743589572, 0.015289107271070992, 0.08519416994282178, 0.055514349336070676, 0.015132173995620437, 0.013309252348595431, 0.027272938151976893, 0.028597089062844003, 0.10442949099732296, 0.009305053506977856, 0.057432961384100575, 0.03411511903894799, 0.029912300274840424, 0.014503935385229332, 0.03913142325888787, 0.036820916525487385, 0.07168088041778121, 0.059699478692242076, 0.011737271611179625, 0.009076189582369157, 0.02221131627447903, 0.08746087045541831, 0.02791262704080769, 0.02496105059981346, 0.07562305352517537, 0.05750958155840635, 0.03243906968938453, 0.032905416629676304, 0.014747599006763526, 0.0457965234693672, 0.03222499528367605, 0.023728145685579096, 0.036640819760837724, 0.05185009399428964, 0.009038389244649028, 0.049366526904382875, 0.0715333397633263, 0.026971049440492476, 0.019186517423284904, 0.013817068804720683, 0.016097780217283537, 0.031156526545860937, 0.01787554705515504, 0.08308980893343687, 0.04753452645880835, 0.05872730764427355, 0.06642623737986598, 0.025738242913835814, 0.031224247733397142, 0.005902523964843047, 0.06678955217025109, 0.013603764536258365, 0.05677652625100953, 0.04095165790723903, 0.028971511471484388, 0.02526268994967852, 0.031576997733541896, 0.052373956955437145, 0.020280899413462197, 0.005938193702604622, 0.024994707633075968, 0.0017571657725576578, 0.05141862714663148, 0.016616523631715348, 0.029433651494660547, 0.013254836384606148, 0.05327285300674183, 0.017610646983874694, 0.038991017400154045, 0.07792632028992687, 0.03932945370408041, 0.019876409421807954, 0.040057878009974957, 0.028248856409585903, 0.055951464987759075, 0.01856931179229702, 0.0375776730610856, 0.0032203581566656275, 0.05121385545602866, 0.03897698868864349, 0.027908282720350792, 0.028205469184155976, 0.0251531828793564, 0.0008100509554164351, 0.04266336087935737, 0.12109644844063691, 0.07005595189652272, 0.036962268940572224, 0.035332543176731894, 0.06142673707966294, 0.041862217975514274, 0.07526355888694525, 0.03714417739372168, 0.03268823114090732, 0.030189298625503267, 0.016150358199541057, 0.02238692113730524, 0.057461751624941826, 0.04966776931126203, 0.06592630634882621, 0.015449806415875043, 0.08944726815181119, 0.08010937100542442, 0.07534585839935712, 0.024379249229761105, 0.028549944449748312, 0.015496879782793778, 0.01227166289131024, 0.03216699071760688, 0.04390567707430039, 0.03155378165787884, 0.028141440923458765, 0.01761914393864572, 0.015833472167806964, 0.05575332258428846, 0.02353358255433185, 0.025570249517581294, 0.022675493599048684, 0.006517484917172364, 0.030406178773513863, 0.0542905367910862, 0.03604359020079885, 0.058819208427199295, 0.02134303911589086, 0.04581016541591712, 0.046083940725241385, 0.03073908162436315, 0.015542597776012761, 0.047630895394831896, 0.02603946496466441, 0.01860857013213847, 0.029464894639594213, 0.0502790038340858, 0.011301133049918073, 0.0258677498038326, 0.030470222301248993, 0.06288599449076823, 0.028588899145168916, 0.027773138900686587, 0.03957228781655431, 0.034020205560539446, 0.04265925234981945, 0.04156136233359575, 0.05616273365116545, 0.011715374437959065, 0.03857523488945194, 0.06242892651685646, 0.020708690297656825, 0.04927478896986161, 0.016231326086978828, 0.06562917586416006, 0.07104298286139965, 0.05354184803685971, 0.02490565160821591, 0.01928391942887434, 0.0352760585291045, 0.0676403468740838, 0.0277498380081462, 0.05938742722251585, 0.058594213000365665, 0.050254220342529674, 0.03810357841263924, 0.030863823502191474, 0.018579108141628758, 0.041821739968976805, 0.04692817060276866, 0.04832963379366057, 0.023651898705533574, 0.082331172855837, 0.019388217046590786, 0.006539454184738653, 0.036523921747824976, 0.030195259555642093, 0.02183674798080964, 0.07389939815870353, 0.040474043892962594, 0.054353104505155764, 0.03264429260577474, 0.05217957702864494, 0.05074675873454128, 0.05351478806031602, 0.06375435646623373, 0.03595309737803681, 0.03498865484393068, 0.06200616527348757, 0.04574869692857776, 0.03925044508650899, 0.027236924905862128, 0.021838230579825382, 0.04528438559334193, 0.03955234567235623, 0.048325952741184404, 0.007767485521201576, 0.03920470164822681, 0.09057806711643934, 0.032247902625905614, 0.05179270010973726, 0.02406438353604504, 0.03312719580052154, 0.01772750767746142, 0.025887788639270833, 0.0562725036538073, 0.03030017464022551, 0.028445796109735966, 0.0307387559275542, 0.025379606622404287, 0.028980379924178123, 0.006365368392185441, 0.026138646428340247, 0.08613231245960508, 0.022752659994044473, 0.00948773294554225, 0.018844152401600565, 0.049860520754009485, 0.03125595906749368, 0.055181460055921755, 0.036404709930398634, 0.011445772967168262, 0.021776785841211677, 0.054244097854409895, 0.03865057263257248, 0.05397090269252658, 0.033060380457235236, 0.037185547673808675, 0.04959161054076893, 0.022061829920858145, 0.020407933043316007, 0.028122810048184226, 0.04122686831812773, 0.033695384061762264, 0.045225919623460085, 0.0424486757921321, 0.07128322497010231, 0.029189426385398422, 0.014050182054883667, 0.050254780133920054, 0.028526579096381153, 0.025668564152770808, 0.027272941544651985, 0.032657038886100054, 0.020649622127945935, 0.06067467600639377, 0.05161926316629563, 0.04332232016271778, 0.017563135961868932, 0.05071089476613062, 0.005855416247088994, 0.04077786473291261, 0.04374498641118407, 0.04302126435296876, 0.07433351129293442, 0.09377991780638695, 0.02264794846996665, 0.06866620361272778, 0.023428041521193724, 0.029458197498960153, 0.040855265222489834, 0.02065085366900478, 0.07092485670000315, 0.04080948107210653, 0.04956957172336323, 0.0527021575586072, 0.03817967950765576, 0.07438304434929575, 0.04931751971266099, 0.012469544058798679, 0.029511119837739637, 0.08182225802115031, 0.026248959258997014, 0.02343039264503334, 0.04579684916617615, 0.02434461680240929, 0.016402810545904294, 0.02065602071317179, 0.08577512484043837, 0.07055579471801009, 0.016285052489755408, 0.026476275275594423, 0.036280344639505656, 0.10609484663499252, 0.0529022677136319, 0.06446588185748883, 0.046121579062725813, 0.05245044481541429, 0.055159743542649915, 0.05860015696712902, 0.08185935353061982, 0.05416978469916752, 0.08105693158826657, 0.016541567564542805, 0.025140942107619982, 0.057147664550159655, 0.044935258970196755, 0.009369129265126373, 0.06734197467033352, 0.044508687752698145, 0.040741098312927146, 0.04475430046607341, 0.059179551234202724, 0.06812596760158028, 0.030944721839789833, 0.03807195868077023, 0.010087294969707727, 0.03757588512131146, 0.04438803065568209, 0.03347727915804301, 0.01685076579451561, 0.04148298814626677, 0.0226583894275661, 0.04110827736024346, 0.06437961291521788, 0.042346149150814326, 0.0183084914128163, 0.04806693217584065, 0.020498095080256462, 0.03753493892561112, 0.04330301923411233, 0.048929462142820866, 0.04364394576155713, 0.05743592658213206, 0.036381029058247805, 0.008918433583208492, 0.0491955733991095, 0.05988492231283869, 0.04411612810300929, 0.05218214528369052, 0.0404810667304056, 0.07161365116813354, 0.05031145477135267, 0.051252667659095356, 0.0032763676177377677, 0.009116799903235264, 0.015932146426556364, 0.007048578517112348, 0.0938977657684258, 0.07092531131846563, 0.05336681314344917, 0.052412680948951414, 0.05911106669477054, 0.042520966913018904, 0.01906712070506598, 0.011279354620325779, 0.02643538166635803, 0.05263291984530432, 0.06536961586347648, 0.05338373241413917, 0.04175509425944515, 0.03569755769733872, 0.06388932386679308, 0.08673257167850222, 0.13305501746279852, 0.10479798979525055, 0.15472387043493135, 0.07150910927781037, 0.1518792887883527, 0.10802353492804936, 0.11311321253223078, 0.18436352855392865, 0.13406759527112755, 0.1156739629805088, 0.1591157561966351, 0.11315564132694687, 0.22308788847710403, 0.06392622938645737, 0.09314870381993906, 0.12555245576160295, 0.1673986738813775, 0.10073065411831651, 0.13307237438857555, 0.17396964771406992, 0.09714155670787607, 0.1125467104305114, 0.09437586154256548, 0.1571328868823392, 0.10891618167183229, 0.10070793676589217, 0.17635182131614002, 0.20972608189497674, 0.12125636557383196, 0.12964168776358875, 0.10693287809512445, 0.16701447378311837, 0.1127359267058117, 0.08912744067077126, 0.08090268022247724, 0.23859367572835513, 0.10468887457890169, 0.13604523986577988, 0.10538254771381617, 0.16631535201200418, 0.16550543904304504, 0.17356055895132677, 0.14494683220982552, 0.16785630503935473, 0.08146876841783524, 0.18802343787891523, 0.14987670124641486, 0.15637204556592874, 0.18172820710710116, 0.18028960430196353, 0.13293221619512352, 0.12855476965861662, 0.14532709680497646, 0.1190602598445756, 0.13744868098625115, 0.10798561839120728, 0.1734658626041242, 0.0856551191370402, 0.21923470523740562, 0.1529728972486087, 0.09906601094241653, 0.15746901955987724, 0.11750925092824868, 0.14148268023771898, 0.13567123136350087, 0.0857964919081756, 0.08383730346603052, 0.10561102402529546, 0.10731653536536864, 0.0868486011666911, 0.09881434908935002, 0.21508933124797686, 0.09612358454614878, 0.18395100640399115, 0.1332449936973197, 0.17986706697515079, 0.19233467296830245, 0.17959175817668438, 0.2466376812330314, 0.17504265585115977, 0.1464857632028205, 0.1750472563185862, 0.13586138401712688, 0.14094788607742104, 0.15359078480729035, 0.15202871577015944, 0.1605514141597918, 0.2663531133106777, 0.21025426712419304, 0.1866675213511501, 0.14557835832238197, 0.16222466794507845, 0.16502909388925346, 0.19317250086792878, 0.12712767480739526, 0.0987081244321806, 0.0989958911335894, 0.17521374167076179, 0.0835011029349906, 0.19005141620125088, 0.1541849100696189, 0.18058445490896702, 0.13593926626656735, 0.148173239082098, 0.14505393217716897, 0.14082062004932336, 0.06427439927522625, 0.1681204451514142, 0.14299341131533894, 0.10742757083582026, 0.08353637318525996, 0.13525575080088206, 0.11591786917831216, 0.19231192847447737, 0.1271800169987338, 0.14195450634828635, 0.13039905498070375, 0.275505682187421, 0.13522996647017343, 0.15001441671379975, 0.13348941558173724, 0.0826244628322976, 0.1195644520755325, 0.21844384553177015, 0.09804889373481274, 0.12936576828360558, 0.11575179094714777, 0.13240077399781772, 0.11004873125680856, 0.14014435133763722, 0.1109325841867498, 0.14031135237642697, 0.09800305869430304, 0.06625254598579236, 0.07894486242106982, 0.15621576538043364, 0.13928289684866155, 0.0925469993214522, 0.1235791945031711, 0.11601616176111357, 0.12278741198991026, 0.07370002421417407, 0.15965612791478634, 0.16918186391038553, 0.16196249558457307, 0.13614726439118385, 0.114013547077775, 0.10325152027819838, 0.19633515258984907, 0.17582329681941442, 0.10549562557467393, 0.14514389234994138, 0.14648801593908242, 0.13972629234194756, 0.12505774945020676, 0.1539803317614964, 0.09234504694385187, 0.14619822720331804, 0.08528482900666338, 0.13251968047448567, 0.15644291176327638, 0.14310934580862522, 0.14416430491421903, 0.15238584232117447, 0.19209665645446095, 0.07399663222687584, 0.11671792981880051, 0.1202660979969161, 0.10800050544951643, 0.10809079810444798, 0.15009613947144576, 0.16086113825440407, 0.06745224339621407, 0.09307581558823586, 0.17207114744399274, 0.16406134010425635], [0.03721859911456704, 0.033749900957835574, 0.020674090100718395, 0.0640050887263247, 0.0750735147989222, 0.01691030215338937, 0.042989413919193406, 0.08675469192011015, 0.03707880393735, 0.0320922806193786, 0.05920058581978083, 0.020451469546450034, 0.052639080943273645, 0.09022346471569367, 0.14354450388678483, 0.05358693329617381, 0.03456842792885644, 0.1121956906946642, 0.02018265432811209, 0.023211424305502857, 0.030993511900305748, 0.05210890421377761, 0.06455230686281409, 0.08072015430246081, 0.018110116611101797, 0.024009517194437127, 0.01842295009243701, 0.04372853193698185, 0.01927736647693174, 0.03780595938275967, 0.04075610750753965, 0.019785690986152207, 0.04532276353399668, 0.09599893087787287, 0.05078315535294158, 0.07009946634726864, 0.030084173195064068, 0.01867872047504144, 0.053965267459196706, 0.01078827677494181, 0.03425731962280614, 0.007442531708095754, 0.03005837868633015, 0.03609052107536367, 0.04226546794442194, 0.05128734419122338, 0.047586817760020494, 0.06788667544190373, 0.018471278749140244, 0.04862096280391727, 0.08571301174483129, 0.0692597453349403, 0.05212732983220901, 0.008713822196503835, 0.026072920133758868, 0.051166032307914326, 0.014445523698148983, 0.04915438632347754, 0.0436884440880801, 0.012896003318019211, 0.011858737013036651, 0.07234343593674046, 0.08174780237355403, 0.020036608147035753, 0.0603936268016696, 0.014594158490321465, 0.00857654438420598, 0.05073714050065194, 0.014648124076692122, 0.029772925789334943, 0.010483351619248944, 0.018142910208553076, 0.03841727193711059, 0.042720113548317125, 0.009833729825913906, 0.005148775459799383, 0.058501402980514934, 0.09266283881983586, 0.04506969711344157, 0.11125762960208313, 0.03835002572408744, 0.035934627654829195, 0.0676861819145935, 0.026221056202692643, 0.028944414175514663, 0.036560420146478076, 0.017159285489469767, 0.03308728776339974, 0.042831908977989636, 0.05706362120274987, 0.05885088922721999, 0.08204951296959605, 0.055609439233584065, 0.14278653955885343, 0.08398283565683023, 0.05384250690362283, 0.09160528771047081, 0.07293010409921408, 0.021686024997117262, 0.03626423282548785, 0.05647235596552491, 0.007992184088964547, 0.01823127073501902, 0.02750777403291847, 0.02053317703705813, 0.018189272810039774, 0.010144545513737415, 0.08567912570599999, 0.07478610772107329, 0.08148523646273784, 0.02258458686992526, 0.02822027142558779, 0.06753537072134869, 0.022992318562631096, 0.05385014720793281, 0.03769880173993962, 0.017309533498649086, 0.1075735983571836, 0.017947293651689376, 0.03285937463598592, 0.007481790047937206, 0.022834842459165623, 0.03326706900926573, 0.012708471505902708, 0.04816786765253969, 0.007948673879062491, 0.07375386596790381, 0.09599134485636439, 0.01788665128073522, 0.053246685303747654, 0.03574022737198642, 0.0067422793280067185, 0.032936191585447104, 0.008300215238705277, 0.05027544831058808, 0.06497317499348096, 0.0575422394488539, 0.04152789020112582, 0.021525137558845536, 0.029525402999882187, 0.025691193295642734, 0.1067251106724143, 0.020535173626350503, 0.020220811744885783, 0.0027470799811583546, 0.08166986584131207, 0.039175005563135655, 0.026370274534981166, 0.038646759265767675, 0.036399827870939455, 0.03651544006009187, 0.05781581119767257, 0.036581926313894134, 0.030016553787780658, 0.0027136678566291395, 0.035849247593432665, 0.025607032900942222, 0.05333344279123204, 0.006206624276403869, 0.03838937396981886, 0.024042163210521852, 0.02261708191196833, 0.04516519752464124, 0.023003463500312397, 0.022286326624453068, 0.022946137469261885, 0.047422473185828755, 0.07138019440961735, 0.025076365929895213, 0.05001048717115607, 0.032603329446698935, 0.07896566630474158, 0.059868386414434226, 0.029666850409869636, 0.040137996032301865, 0.025827870604449084, 0.0694789799994656, 0.009370806942959982, 0.013857029428306435, 0.05204067073230233, 0.023875326716474125, 0.029610643961599896, 0.05869280413857528, 0.06007621490529605, 0.06419207262141363, 0.006382742705422321, 0.010059614133621966, 0.030200541950762272, 0.014819817185135824, 0.023711226414889097, 0.04244588362053037, 0.03608584596908518, 0.03222523955628276, 0.004839461030704635, 0.03406969790479966, 0.0882664340149079, 0.022858116210305264, 0.05441831511312297, 0.05450315913185477, 0.07960688189736434, 0.05144792628873672, 0.026406696598444666, 0.018790178333542178, 0.017429744458890388, 0.021322679672656313, 0.022891547630674074, 0.04049212006585939, 0.053914828558585474, 0.047153624040739875, 0.016511779877224138, 0.07331547806305544, 0.015459808022049921, 0.027671200888497487, 0.03297967550211719, 0.027668076234736612, 0.014074006267557186, 0.06332609230386359, 0.030167103745043278, 0.02577860387308257, 0.06513942964375019, 0.08919933824134724, 0.06845098587551288, 0.06056195098374571, 0.046405603643506765, 0.03744577603148563, 0.04296811809763312, 0.07976409846118518, 0.04970462733347501, 0.03206994663923979, 0.015137415678639497, 0.05944390847746815, 0.043679026022021256, 0.03856603056192398, 0.020379839997206415, 0.03731645404228142, 0.031053189055195878, 0.03737509982394321, 0.038236781622150114, 0.05972760396876505, 0.03057762421667576, 0.062443073971995285, 0.022959107666143348, 0.03546913566866091, 0.014353439710768206, 0.03757968491741589, 0.002399899481263544, 0.028626907284238508, 0.044997633301786015, 0.030422029351549487, 0.038879557845315764, 0.068242173508874, 0.039419403698827536, 0.03729260353637593, 0.07324018103203603, 0.10805687135351555, 0.028924845225576843, 0.016777696054694907, 0.024014953956274048, 0.031668515144182105, 0.031049714955900396, 0.05928999637918813, 0.01381232584494033, 0.05955474717276437, 0.04647585915933762, 0.01072333418830697, 0.10879835406584398, 0.04329904301890305, 0.09198302815535239, 0.08783198839851789, 0.12351841133620058, 0.05167004133441618, 0.03961183623011623, 0.0283545857361917, 0.009856636319974703, 0.039750474505126476, 0.054886599270893, 0.010132545621932616, 0.08309740174029555, 0.0577634350795831, 0.09888403463576521, 0.08531091189278023, 0.027125624806753228, 0.019923382704811435, 0.02280552465734737, 0.012477056289623891, 0.02631504517713828, 0.033341154855276854, 0.04397871458370771, 0.010779848521841424, 0.027339119065020765, 0.01788415257552905, 0.04004185101283448, 0.01830204193746405, 0.03238928557506629, 0.05932084258113589, 0.031604610716125796, 0.03868236878354635, 0.024051638952057277, 0.012544928451201745, 0.04753517785242625, 0.030121689396245137, 0.021760942048526237, 0.044709666432546716, 0.024550628515758684, 0.026009090344554613, 0.02771303426873471, 0.043241493071296384, 0.03707056652222361, 0.03509900499401348, 0.01851955651571708, 0.03385951829009822, 0.004029422108682671, 0.030146194688443626, 0.026536305268694247, 0.027348878094926476, 0.06084959554885115, 0.04761799644412739, 0.04049676463806203, 0.026822292512016635, 0.03380751536626901, 0.010192857207065182, 0.04967614921874233, 0.030220233037003448, 0.020823496726474593, 0.01683854028981711, 0.004291938825710011, 0.09969492469515119, 0.032480965834110975, 0.03856554201671055, 0.062448536178895404, 0.0395675719981747, 0.039039454622460265, 0.050483259838074446, 0.04310602016214814, 0.02897842913599951, 0.03131328509854419, 0.02267308479973248, 0.01932059763930738, 0.04313350761575358, 0.0006601493701704644, 0.019600693502330353, 0.04203199761520539, 0.023484958734895502, 0.03981034504249692, 0.03214438532346061, 0.025517932771305953, 0.014482081468616213, 0.0172370574769697, 0.03602000432355063, 0.05971875587212188, 0.01166549532873822, 0.01857120999401169, 0.15937597437628678, 0.0990010683557817, 0.10347085672297648, 0.15650716902954237, 0.15835742545979364, 0.10202512251479284, 0.10749161097088031, 0.13005545841796057, 0.1052010395963277, 0.18880629087133066, 0.1096690705578242, 0.1754200705992324, 0.09520562166082007, 0.1508553930159126, 0.17206793118800434, 0.0993878740285124, 0.18297399740133966, 0.1332230091627155, 0.1740020816879613, 0.21506961302033492, 0.15550282863633974, 0.17612042730408056, 0.14789342481110776, 0.17294691902186188, 0.12899672665766307, 0.14996837132743426, 0.15228053368628025, 0.13671658241323062, 0.14521550493580954, 0.17461399813847883, 0.11600280819194657, 0.19391909294894763, 0.10201081221124955, 0.1575450019112655, 0.19758733468396322, 0.11771106081349508, 0.12798831505434854, 0.08567691368183919, 0.1384969904486622, 0.11322141172630446, 0.1524851391358035, 0.11079851245241505, 0.1504382432571479, 0.15118958508329733, 0.1910808216780424, 0.14640109560319356, 0.17645143025687762, 0.21999170604561055, 0.10367420688271523, 0.1676202155649662, 0.21289067422705038, 0.15048310799258097, 0.12885628347950323, 0.07913261984608003, 0.24258880849395478, 0.10466644221118518, 0.17413440958729812, 0.13962795904704503, 0.10657341059829507, 0.08514270306165729, 0.15614354211304868, 0.13461198391658918, 0.1611140011144536, 0.22915096527763776, 0.1120296735316515, 0.09160369993852717, 0.1701053772121668, 0.13451542838343553, 0.09666796640626021, 0.11587046672190938, 0.13854466431907245, 0.12140265772385256, 0.19281043458197797, 0.1125202543501343, 0.1358533501625061, 0.08743921840297324, 0.15653515181371144, 0.0844475371497018, 0.2096173127314874, 0.30643743383032934, 0.18528691971940653, 0.17299077952546732, 0.18663652587149823, 0.20026530884206295, 0.20985011809638568, 0.1677260398864746, 0.1211295338081462, 0.1494662282722337, 0.19399849511682987, 0.27158708817192484, 0.13377803723726953, 0.15518156944641046, 0.17168717804763997, 0.25491865830762045, 0.21110626283500875, 0.16840400493570737, 0.1555200634258134, 0.15360198063509806, 0.28563045603888376, 0.11578050654913698, 0.24379825645259448, 0.22135537144328865, 0.14758399927190372, 0.13090737270457403, 0.16897187089281424, 0.05137052919183459, 0.1087993582976716, 0.15058900016759122, 0.2463312548186098, 0.14887595708881105, 0.13682822856519902, 0.1078689375094005, 0.08901236113160849, 0.12155732299600329, 0.10505394677498511, 0.19279587322047778, 0.07019043075186865, 0.26877716609409874, 0.14899470071707452, 0.11113763068403516, 0.16111093413616928, 0.09772642675255026, 0.1512922067195177, 0.08518116242651429, 0.11676238743322236, 0.11128213150160653, 0.13542584595935686, 0.2045592005763735, 0.08872477084930454, 0.11973256591175284, 0.1601991459195103, 0.08974139951169491, 0.12040556408464909, 0.07889849812324558, 0.1226266941853932, 0.11173907055386476, 0.09007810215864863, 0.1900215878018311, 0.1224790992481368, 0.09848353612635817, 0.09688712643193347, 0.17589290094162735, 0.056748356869710345, 0.11369532772472926, 0.07036856655031443, 0.18916822145027773, 0.1353590509721211, 0.09919972305319139, 0.09674716501363687, 0.1209946410464389, 0.15984579202319893, 0.10219310064400945, 0.10482697002589703, 0.12343387944357735, 0.1313054013465132, 0.11774211057594844, 0.13943638146987983, 0.13649396864431246, 0.19789050413029535, 0.15250580731247151, 0.17806079318480833, 0.07348484718906027, 0.21262384711631707, 0.15091585048607417, 0.10582386010459491, 0.14812225396079676, 0.09414973296225071, 0.1941412995968546, 0.10609614263687815, 0.09219602708305631, 0.11854546889662743, 0.11152024301035063, 0.10324830402220998, 0.1850931979715824, 0.13401848290647778, 0.11521316984934465], [0.043601201448057375, 0.026074512994715145, 0.04078411404043436, 0.02793717134876975, 0.029435856733471155, 0.019443074906510965, 0.03125938566933785, 0.03473700995423964, 0.09668273811361619, 0.055264034375016174, 0.030634566875440732, 0.035400189725416045, 0.004474628866384072, 0.023746946194608296, 0.05144066935671227, 0.0187453848442861, 0.046961944683321884, 0.055271294699715715, 0.03939141412930829, 0.06578045524656773, 0.014009095911335732, 0.01835040282458067, 0.02261159765268011, 0.03945053827815822, 0.06234991789928504, 0.01376438734587282, 0.03366237333310502, 0.03805581633267658, 0.00224324779784573, 0.017786820119779025, 0.06379636456923825, 0.07276866704757724, 0.020596672647765706, 0.010009432228149047, 0.06230781480137791, 0.04956149376396622, 0.008801167464948126, 0.0681239455672247, 0.017386228311806917, 0.06128228375954287, 0.031011486292949746, 0.03896809309454901, 0.033534106465854814, 0.02497678921957101, 0.014397768403536506, 0.03797100963337081, 0.029721828709755625, 0.043417851107993295, 0.07259492137070213, 0.052471669390797615, 0.03869350693587746, 0.04210662289655634, 0.02524924647462155, 0.03352209978869983, 0.05869156920484134, 0.01644316641613841, 0.013341033232531377, 0.060349603449659686, 0.013241703339320208, 0.01140363170166633, 0.022924253018572927, 0.06863182902868305, 0.026687579562089274, 0.035875439045152495, 0.04555827625361936, 0.05006304649370057, 0.0418209867951061, 0.035633191865469725, 0.013725887268914707, 0.04710746330342122, 0.024880198063328862, 0.04373422484578831, 0.019830727051677446, 0.02795068098099104, 0.022696692729368806, 0.05313559555049453, 0.019625843402796557, 0.035621127512838156, 0.010905803281015583, 0.02121539819719536, 0.03288268231387649, 0.04435196651944092, 0.04320425846214805, 0.09027841926685401, 0.02644725433284683, 0.012127463173653399, 0.03812231954985431, 0.02303742926700839, 0.05087986694914954, 0.030752869455942085, 0.009660918831026979, 0.040353023779711554, 0.10806966173861708, 0.041972839539604526, 0.04467023676261306, 0.025006376739059175, 0.042156512183802466, 0.04035065569249647, 0.008959120239264198, 0.05506666550146682, 0.029994060351912464, 0.08471074088343553, 0.02850890325914536, 0.05561202784468021, 0.025200934781293784, 0.05016039252015097, 0.03529368686888899, 0.029076694577400173, 0.03214047356907811, 0.02555343202714409, 0.006553256859271122, 0.03224093746393919, 0.026670604312260236, 0.035316794378949065, 0.05719888037336724, 0.011563439421089632, 0.02870204485952854, 0.0185505214612931, 0.08638683094510011, 0.020440385676920414, 0.0548983922095171, 0.018021123350730965, 0.049266290318753035, 0.0186824812553823, 0.0395374993261482, 0.016151469300634096, 0.009503296842532498, 0.04259331910205739, 0.026764262500884275, 0.042515117941158156, 0.06678620020725898, 0.011642887390085628, 0.03110027260013989, 0.034831068478524685, 0.03342847213415163, 0.056853696038680415, 0.0515907613028373, 0.010275122792726117, 0.016586885222100785, 0.05333113916484373, 0.01082398383212941, 0.05513287694858653, 0.04399702485118594, 0.021224081749096513, 0.07032072304614953, 0.0273346848386739, 0.015192012302577496, 0.004441652912646532, 0.06676968466490507, 0.023495174079601253, 0.041632170855466805, 0.01810279691458813, 0.010909476699972791, 0.04805202136880585, 0.002225950455925028, 0.0572925792740924, 0.02367605285585991, 0.045644840358623436, 0.10980216520173208, 0.04205574294818299, 0.048013572181974135, 0.018702404739867364, 0.014507613045030406, 0.004134642534024481, 0.022921216574364474, 0.042792024689593484, 0.031241289140390496, 0.05476737388276628, 0.05862379712717874, 0.07549208948122603, 0.06083827079938991, 0.03877832042053342, 0.023143145022913814, 0.04497771490631359, 0.034159858245402575, 0.04175045647259269, 0.03183695128453629, 0.031470739149621556, 0.04343337598921997, 0.012718339101411402, 0.01764720305800438, 0.01612336268382413, 0.0346485222024577, 0.017736995293359672, 0.027847898192703724, 0.06791767092155558, 0.04776621224092586, 0.0187694066802838, 0.016746223904192448, 0.014154410122760704, 0.04700452275574207, 0.012214917855869447, 0.015957822191662023, 0.050945600029081106, 0.04353448109967368, 0.05076136759349278, 0.0362633541226387, 0.048593380355409214, 0.034107173393879614, 0.026713703160307238, 0.04547455181766834, 0.02065360852118049, 0.04571354542193668, 0.021547525821785842, 0.03878892931554999, 0.03452047585908856, 0.017448426224291325, 0.009242906484619846, 0.028242608798401694, 0.016077373276597688, 0.027198309477950846, 0.023761022403570156, 0.0145269699527749, 0.04487280660708036, 0.03503637960446732, 0.028796714065330367, 0.01534020435065031, 0.0540310853560056, 0.0338829752456929, 0.02387927409394511, 0.05667388765141368, 0.033686647923397164, 0.08325843845627137, 0.02074488335555153, 0.021814626042864153, 0.07822858728468418, 0.03811370554779257, 0.0649673328069704, 0.022874267040086643, 0.03767077824366944, 0.02865389601460525, 0.017821084441883222, 0.04398501478135586, 0.010547709817598973, 0.025614630796813538, 0.022299030496339713, 0.033007169741072824, 0.09581026421593768, 0.03181414572255952, 0.04397456194939358, 0.02296550285869411, 0.03357379397909556, 0.04855762155992644, 0.028306072178695883, 0.011700789327733219, 0.011626735712135476, 0.02616244604411934, 0.01483631576411426, 0.02801428346096405, 0.0171079102105328, 0.033069615318839035, 0.04428653199491756, 0.09809193999639579, 0.10105217115155288, 0.018920144931014096, 0.05210404251036899, 0.019373979685561996, 0.0036099356449475245, 0.038885433958577256, 0.030539507512003183, 0.08439630775579385, 0.09336933626660279, 0.03377777856907674, 0.027602059866434762, 0.02038242351928992, 0.08103819045105151, 0.05249203222670725, 0.07544932141900063, 0.07951362404440131, 0.03429398426253881, 0.05383822534765516, 0.028266500016408305, 0.028870905084269385, 0.0736718378694994, 0.03572685005409377, 0.005825219318337206, 0.0705088943775211, 0.08034552833331482, 0.0712267030030489, 0.020251802135525004, 0.04169062664732337, 0.00798020709771663, 0.033277589694729874, 0.006406037236696908, 0.017096712686387554, 0.02606928488239646, 0.014969262826655592, 0.05166613297270877, 0.027889801122780358, 0.06521075045956032, 0.02333981161271887, 0.02500203750761492, 0.04823736999449985, 0.027029798698744605, 0.02133867104670831, 0.023905277252197266, 0.04502211823793394, 0.0373621499831123, 0.026225071433665495, 0.048039017245173454, 0.010300568704094206, 0.027779305087668554, 0.022470805028985654, 0.035800627166671414, 0.0389545902476779, 0.06835126158382211, 0.016449383493246775, 0.05607400501945189, 0.06284501776099205, 0.030272656652544225, 0.03206278809479304, 0.028198198681431155, 0.04484645909230624, 0.018594066446114863, 0.0281613779786442, 0.046465911835964234, 0.0211966027771788, 0.011219719873874314, 0.05513226626706975, 0.027395001512819102, 0.028370748440335904, 0.038003545387515, 0.011629614396952093, 0.014863160305789538, 0.011369832176049905, 0.02609279951346772, 0.03825827082619071, 0.017025956750980446, 0.05572309724188276, 0.024171892320737243, 0.03714162949472666, 0.034015642412539036, 0.011584312854600804, 0.026148600537063818, 0.010525441994624478, 0.04623938970533865, 0.01899920783138701, 0.046447316583778174, 0.013081369755257453, 0.023529631784185767, 0.008407288064647998, 0.02725857526196965, 0.01901542312199516, 0.028898267008896385, 0.03838169973875795, 0.11283396144530602, 0.052976848890206645, 0.023052397749519775, 0.033056278713047504, 0.018593158905527422, 0.031231630194400038, 0.03153362577514989, 0.11726239988846437, 0.12688611634075642, 0.18847133884472506, 0.068453828937241, 0.11393973603844643, 0.10431251834545817, 0.1409179355416979, 0.11224560373063598, 0.2082547058484384, 0.15457221785826342, 0.08797647564538888, 0.11219693241374833, 0.15969606648598397, 0.14328113730464662, 0.15812445724649088, 0.11574793686824185, 0.12046876283628599, 0.10750197220061507, 0.07753895143313067, 0.1103281384067876, 0.13995371013879776, 0.15944139872278484, 0.1625910225723471, 0.1025264241865703, 0.13964898006192275, 0.05810324541692223, 0.12731315914009297, 0.12297338486782142, 0.09266161067145211, 0.0793120584317616, 0.13517949703548635, 0.18785026217145578, 0.17761149443686008, 0.07276216668209859, 0.08724788509841476, 0.1556557704295431, 0.05345307190769485, 0.17934341435985907, 0.13602507380502565, 0.12060441555721418, 0.14271399059465953, 0.09044421929866076, 0.11459423734673432, 0.07015852603529181, 0.13316693502877439, 0.11623914193894182, 0.09593791700899601, 0.08239612222782203, 0.1120056737480419, 0.23830098286271095, 0.1290552028055702, 0.17030217950897558, 0.08112731602575098, 0.07881980841713292, 0.16028645980570996, 0.13460868623639854, 0.10821089201739856, 0.17770254026566232, 0.1421511729380914, 0.16537336898701532, 0.18145300687423774, 0.12035181054047175, 0.08632423608962979, 0.09302736140255417, 0.09467205564890589, 0.13822170879159654, 0.09813136288097926, 0.20064653695694037, 0.07458906115165778, 0.09317602163978986, 0.1082273872037019, 0.20408824299063, 0.10746746869491679, 0.1471455842256546, 0.15539848352117197, 0.1386873602334942, 0.16137516924313136, 0.16175376464213642, 0.08084528294524976, 0.2481097493852888, 0.10402174573391676, 0.18480881037456648, 0.12075422251863138, 0.11407409954283919, 0.14953292826456682, 0.21343745131577763, 0.13183612429669925, 0.09270335414579936, 0.11102298540728432, 0.15824888699821063, 0.1298501608627183, 0.10952311767531292, 0.2061153527881418, 0.16065110452473164, 0.20447386801242828, 0.14765183920306818, 0.17160435606326374, 0.12602817666317734, 0.1426413737769638, 0.14137186189847334, 0.10831746951277767, 0.17913997599056788, 0.1596646231732198, 0.12082972989550658, 0.18183382786810398, 0.13554591951625689, 0.06913429099534239, 0.11061716039798089, 0.05852748586663178, 0.09765880395259176, 0.10247389879077673, 0.14269705436059407, 0.08174678457102605, 0.14437885768711567, 0.13350156135857105, 0.06431553206805672, 0.10216009670070239, 0.07038296506341014, 0.2294656155364854, 0.060817202287060876, 0.16137637703546456, 0.09068543849779026, 0.1037039877846837, 0.16533991721059593, 0.1052816224151424, 0.10650550281362874, 0.04098117757322533, 0.19507942854293756, 0.10890888742038182, 0.19577764107712678, 0.11852492285626275, 0.12586540968290397, 0.18560133927634784, 0.16576473441507134, 0.13561449226524147, 0.09482058696448803, 0.11536465957760811, 0.057773490968559466, 0.19012221454509667, 0.11684252241892473, 0.11093867743121726, 0.19455481240791933, 0.22213156122182096, 0.09437708290559904, 0.1671191310243947, 0.14891265226261957, 0.07197742736233131, 0.1117737301226173, 0.2336051676954542, 0.10096069784568888, 0.13011464024228708, 0.12215048473860536, 0.13208495665873798, 0.14063586853444576, 0.10005069417612893, 0.15226447954773903, 0.10393127665988036, 0.16165795549750328, 0.12831056490540504, 0.13775535167327949, 0.1378283891826868, 0.13345801298107418, 0.11055017542093992, 0.10568566966269698, 0.11384642390268189, 0.09319003338792495, 0.11611526858593736, 0.08495953931872334, 0.12878252672297613, 0.16578173850263866, 0.1519074479916266, 0.1587934656334775, 0.11431063685034003, 0.10435750521719456, 0.13481563941708632, 0.13808479399553367], [0.06057432067713567, 0.04395158336098705, 0.032437376744513, 0.10008259889270578, 0.007764628888773066, 0.09455259955887284, 0.01969320835944797, 0.07182327099144459, 0.060361552451338084, 0.013166705711877771, 0.06466428549694163, 0.04649201847080674, 0.02636464947967657, 0.0489354196802846, 0.0581101393327117, 0.054100017728550095, 0.017328133839847784, 0.05507928625281368, 0.0027733420429285616, 0.09502472422484841, 0.018704623549378345, 0.04497966230181711, 0.07028972756649766, 0.028416269658399478, 0.017203866936532513, 0.00035595597208677124, 0.02437933743931353, 0.016904188552871346, 0.04767073897112693, 0.04987382682572518, 0.029710045949156796, 0.010160511442726212, 0.04739240051380225, 0.013192579948476382, 0.03620347001456788, 0.047237358654716184, 0.042010142002254725, 0.01273548144048878, 0.05941653637481587, 0.026367000603516186, 0.017957378378404037, 0.04646850383973547, 0.041894007341137955, 0.031059950656656708, 0.012001875671558082, 0.09353411849588156, 0.03532434647370662, 0.023562391454886113, 0.05488315909834845, 0.044103144335427454, 0.01716825063340366, 0.036464410834014416, 0.042441279760428836, 0.06759267978902374, 0.043438054488173554, 0.03973496658727527, 0.0659728402804051, 0.034566840156912804, 0.025663147746984447, 0.008030111652000673, 0.03185676111440573, 0.05602167979148882, 0.012057818339339324, 0.039495246950536966, 0.016000627573313456, 0.02826679009012878, 0.043449189247829575, 0.06707474722393922, 0.05345317708062274, 0.009553102161070066, 0.03130133609686579, 0.07037702788199697, 0.01650190380002771, 0.048550581759107966, 0.054396412002721, 0.06813141623778002, 0.005287752578234566, 0.03273782526542034, 0.05252473422193101, 0.05914457953934159, 0.04330271050067885, 0.02344990391949458, 0.037949493287929466, 0.03584745965365853, 0.02578687351862235, 0.06396162177303008, 0.05135163877691541, 0.04095074527763894, 0.06737640353717975, 0.03478362191734569, 0.056613494642078876, 0.01737481026378061, 0.02060170398492898, 0.05468024320102163, 0.026790754204349856, 0.04727907159498759, 0.03536233764940074, 0.017911344866401384, 0.034110620351774354, 0.048793850133993795, 0.036499223073146174, 0.013386656230847751, 0.01873009236130331, 0.029054031507777314, 0.013540782915827419, 0.05035343234028135, 0.04374465732170003, 0.006573344888498208, 0.06541638049696173, 0.021583026773961525, 0.017621079459786415, 0.0876088725136859, 0.08601048149700675, 0.08613775431045465, 0.06472862418740988, 0.030660018723990237, 0.04195077018812299, 0.03228793619200587, 0.020406187511980534, 0.03279084259910243, 0.02559921787386494, 0.049757946615240405, 0.029707650720540966, 0.02123159313175295, 0.032379138083862405, 0.04645370499097875, 0.05386232351884246, 0.015323139194931303, 0.018629272235557437, 0.05309164005198649, 0.03960106109402009, 0.02713817940093577, 0.07004059664905071, 0.05459162313491106, 0.013834266274768327, 0.04034094246370452, 0.017145959061703513, 0.027411157431613122, 0.03743038346458759, 0.03449631661974958, 0.02961888476940138, 0.015343910848189677, 0.018438303643571477, 0.045395075010934045, 0.022198668381731426, 0.01983942247794143, 0.03857376925381167, 0.02869349531829357, 0.04195333505049348, 0.025655671987416487, 0.034806841385683844, 0.026166369672864676, 0.03010593381311212, 0.03495970854003515, 0.007212085100556058, 0.01672642764502338, 0.007999876979738474, 0.01580334690931652, 0.016165930578219037, 0.051773144730499814, 0.06833050519760166, 0.04898089509723442, 0.03449970929484282, 0.02713897667958268, 0.0635521530306765, 0.02687993406185082, 0.019452138438022563, 0.05771786466773067, 0.05065382657838719, 0.019812684805531586, 0.026183677404852848, 0.04563057755253144, 0.04093434169356312, 0.04229026161400335, 0.051780930919838805, 0.03730075613462499, 0.028013710098873292, 0.10525413496153695, 0.0369125798211566, 0.0912943829649261, 0.014010979694181254, 0.028690587795738662, 0.05588244440566216, 0.05601741519889661, 0.020509881233530383, 0.0530301376378962, 0.010314031687032963, 0.06047036911227873, 0.020599407143890858, 0.04376980722216623, 0.04466200952551194, 0.03152896423957177, 0.0335083594545722, 0.022574875337470855, 0.04914323799312115, 0.03858024926323976, 0.006786339575358267, 0.06980678705232483, 0.028108090927292193, 0.09916023231510605, 0.0609731703464474, 0.017753059609926174, 0.021814227403540696, 0.029265931208751032, 0.05039760157732027, 0.01747596965703581, 0.07824342684554202, 0.03302639942350132, 0.0389561508782208, 0.06889656625155892, 0.011255286983214319, 0.025827224299843823, 0.0669419172086886, 0.02498449059203267, 0.04685064797688808, 0.010460340800429029, 0.07850944649960313, 0.02827955163749201, 0.018193686680336083, 0.03457065013104251, 0.038308580805148394, 0.03325288762737598, 0.023708905825125318, 0.05663060390257409, 0.020996034611016512, 0.02705941505597106, 0.06187163892069033, 0.04837970628536173, 0.009001784824899264, 0.017134822605709945, 0.03010497029338564, 0.05999902476157461, 0.013412938436626323, 0.09169161093554326, 0.04987017630732485, 0.024193708917924335, 0.02289102685504726, 0.016765487513371875, 0.016068165556394627, 0.05716086884162255, 0.023668443085625768, 0.03303440613672137, 0.02429711595842881, 0.020070504363892332, 0.11282911670527287, 0.030237559428704635, 0.04462170793807932, 0.018184653682900325, 0.04237657805372562, 0.0347278429461377, 0.05408651827435408, 0.045550272933074405, 0.0519216014072299, 0.013895001096118773, 0.046911960401173146, 0.04458942663456712, 0.03495647871334638, 0.05635936292154448, 0.05615830960284386, 0.02250179202694978, 0.06266855794404234, 0.05861629252987249, 0.04120216625077384, 0.09220766395862613, 0.027209920908457468, 0.09828342936400856, 0.07501885201781988, 0.017674816040588275, 0.04653956002688833, 0.06755850198013441, 0.05113199699137892, 0.06850176743630852, 0.010409799271396228, 0.0728377215564251, 0.021984867086367946, 0.06068338161068303, 0.07854483210082565, 0.007945281203969248, 0.014408604607784321, 0.010091132085238184, 0.034829270360725265, 0.018501146164323603, 0.04359567817300558, 0.04129608567538006, 0.03485232698065894, 0.12140587397984096, 0.009889535938522645, 0.07035325880029372, 0.06646770944020577, 0.07621428822832448, 0.046580648714942594, 0.03721377473058445, 0.025351437241105095, 0.02119799207762948, 0.03550296403201563, 0.02979818425540413, 0.036434514581092765, 0.03883308498188853, 0.009125319758563169, 0.008961143121788544, 0.042155609732227664, 0.04512330816526498, 0.06261580863169261, 0.043678652827761004, 0.013201634998300245, 0.0240785615252597, 0.016575134691915343, 0.013599667881083275, 0.03142455127090216, 0.03254150812114988, 0.012871506507508457, 0.07046882688466992, 0.025462598240535175, 0.013654272138540233, 0.04525473700570209, 0.04461837972381285, 0.0173665066914899, 0.03713643191648381, 0.08292582059012991, 0.0869089907833508, 0.013781962251024587, 0.01923767726735345, 0.0060317021894401735, 0.0646052665210196, 0.03860876130472336, 0.030844532751611302, 0.023857985057735016, 0.0167636435944587, 0.05639630915330989, 0.07093282270112208, 0.07498330356819288, 0.03544360578858426, 0.013542271452024579, 0.019984077662229538, 0.028109139263896004, 0.01786904499333884, 0.058267763017543724, 0.036521784362516234, 0.05058718765420573, 0.03890214288341148, 0.02618481225467154, 0.07618420198559761, 0.037707490380853415, 0.06217625364661217, 0.042655106500855515, 0.017691450326570442, 0.0030400839127001484, 0.028882050021950687, 0.08775053026952914, 0.04253213559942586, 0.02854462473520211, 0.049607783422938416, 0.16269189358821937, 0.1704979097204549, 0.1262755026774747, 0.22156749506081852, 0.09738456723945481, 0.1536491388188941, 0.22614946562264646, 0.2929759775953633, 0.19682424063129084, 0.09354340764028685, 0.08891471315707479, 0.14439602462308748, 0.09070967576865639, 0.20287776365876198, 0.16931886013065064, 0.19043006588305744, 0.16835984587669373, 0.11659873835742474, 0.10967069904186896, 0.22960400953888893, 0.06797232691730772, 0.11359225825539657, 0.12140165349202496, 0.15365534062896455, 0.12151381533060755, 0.1719239189156464, 0.17050130239554814, 0.138973525592259, 0.14941509387322835, 0.16401665178792818, 0.1385725521083389, 0.13641580141016416, 0.07762317119964532, 0.18108369383428777, 0.09926060800041471, 0.12494317202695779, 0.19943825607853277, 0.06667686785970416, 0.09899989449019943, 0.07306239128644977, 0.14893014489540032, 0.24691593487347874, 0.09715069657457726, 0.08176618388720922, 0.06183487589337996, 0.1876530527536358, 0.1259025934019259, 0.16878830002886908, 0.12506617685513838, 0.10082385768847806, 0.14316083304584026, 0.11765737512281962, 0.16024087582315716, 0.108531574452562, 0.2186572447951351, 0.14042029795902117, 0.15847544984093734, 0.13543215633503028, 0.0886442626693419, 0.08530263376555272, 0.09123020712286234, 0.10615461199943509, 0.14017502112048014, 0.08996724989265203, 0.08670308254659176, 0.14551712732229913, 0.07846499567053147, 0.18635387532413006, 0.17767577884452684, 0.1489835184599672, 0.10916885454207659, 0.13286141785127775, 0.13868628814816475, 0.17393015697598457, 0.14600936376622745, 0.16971737731780323, 0.10410157537886075, 0.0999281575371112, 0.1295753541801657, 0.13026269658335618, 0.1837030289960759, 0.12501654880387442, 0.12117954183902059, 0.15549597543265137, 0.21851750729339464, 0.1271814147808722, 0.12980199844709464, 0.15578451566398144, 0.16685889927404268, 0.15251371903078897, 0.13301790159727844, 0.11673485248216561, 0.14613086224666663, 0.16314193872468813, 0.07481881310897213, 0.18508173072976725, 0.16176652110048703, 0.11592534663421766, 0.11837533302605152, 0.15393226434077534, 0.1854052155145577, 0.10397357653294291, 0.11145540898931877, 0.10531123368335621, 0.08063119157616581, 0.15879243426024914, 0.15286081683422836, 0.11390705779194832, 0.10301908132221017, 0.12485070127461638, 0.06425301863678864, 0.09931094851344824, 0.17321707095418656, 0.3020587387893881, 0.15088313152747496, 0.11285146764878716, 0.12451391720346042, 0.1722972895950079, 0.1610873346882207, 0.12127554097345897, 0.11288538761436939, 0.17212191543408803, 0.12351362087896892, 0.09584592123116766, 0.09905584648783718, 0.1389266795345715, 0.1844795173300164, 0.09499217490000383, 0.11170186647879225, 0.14373220024364336, 0.11099262775055, 0.1238865844373192, 0.13860892158533844, 0.06873806725655283, 0.0816215473626341, 0.11474992042141301, 0.1547965822475297, 0.10833006312272378, 0.15664206179124968, 0.15777962575001375, 0.10152047566537346, 0.09768357726612262, 0.15944912045129708, 0.1508561529751335, 0.17959474373076642, 0.10111279147011892, 0.14568217418023519, 0.13659844946648392, 0.08960636425763369, 0.15563572650509222, 0.07858113372432333, 0.07946249643074614, 0.13853797396378859, 0.16300190266753944, 0.14442950354090758, 0.08250584134033748, 0.1460689798529659, 0.13464956118592195, 0.0825555304597531, 0.09013908210077456, 0.15621124633720943, 0.20252640465540545, 0.1836859570550067, 0.09666373913309403, 0.13324818281190737, 0.08624507140900407, 0.0788788613198059, 0.23259545330490383, 0.11506006520773683, 0.05464511205043111, 0.09176994780344622, 0.10200226945536477, 0.17582020269972937, 0.14765912666916847, 0.13069490981953485, 0.23987024437103951], [0.010962522871393179, 0.024246870440297892, 0.022060728997790387, 0.008037846103044493, 0.02646731013166053, 0.09892308432608843, 0.06840762748782124, 0.04908769650916968, 0.03199456479134304, 0.03887350192027433, 0.037306757776864936, 0.023743524681776762, 0.014215763259146894, 0.05238953611946531, 0.015287358347060425, 0.04392436732138906, 0.04679379352767553, 0.02729731791519693, 0.030274519231170416, 0.03384181870413678, 0.0062312597625090605, 0.026114539775465215, 0.06796034398887839, 0.03582147176244429, 0.048613057870950015, 0.03035443030031664, 0.015237842254074556, 0.006007168907672167, 0.0016101769579108804, 0.018288062419742346, 0.024706516847280518, 0.06908033389065947, 0.0838899849248784, 0.05681597627699375, 0.03747738219265427, 0.013734770988646363, 0.050047199308340035, 0.04157134358372007, 0.04957387024270637, 0.002737734857614019, 0.044068501730050356, 0.02302895436462547, 0.03645992571754115, 0.008040446588503463, 0.02579102954561157, 0.01862872771120497, 0.03848990232550672, 0.03500386420637369, 0.025750984105148485, 0.0072048816031643325, 0.06672872150582926, 0.035612184421292374, 0.01714155706577003, 0.02971051413831966, 0.04890340639810477, 0.012100564349176628, 0.022096930537372828, 0.015158194117248058, 0.03812737463574324, 0.050254915840923786, 0.04198572152693357, 0.03339679811948112, 0.09186937353972878, 0.0246491178737155, 0.09297271219215222, 0.022111166202064072, 0.026678441391725625, 0.039237227224345715, 0.02764728931444032, 0.04238342447206378, 0.013722737170090633, 0.04292792168312839, 0.015450474772868412, 0.025570212198155265, 0.023998830267893415, 0.04629233579284378, 0.10357444866427354, 0.03409655432083777, 0.033281759292419465, 0.0027756700541691054, 0.03249216166191867, 0.03922053865556206, 0.0188138117082417, 0.0428960882127285, 0.039257135441792865, 0.05982028506696224, 0.03873604768887162, 0.012654655197236155, 0.025559107972575084, 0.028809497665081705, 0.029692149588039944, 0.08069352180297885, 0.07735616766980716, 0.09913044462778739, 0.022538288729265332, 0.07741119007446937, 0.014614294016999858, 0.010086283952529942, 0.05042466494653906, 0.057175484485924244, 0.012124992458016744, 0.056802269869617054, 0.019787428035799946, 0.029363514722457955, 0.05435994753081884, 0.02729689552714782, 0.029044735578021834, 0.0062904199585318565, 0.05963188303368432, 0.019976718949952295, 0.04429919685104063, 0.069027448871306, 0.0207947268416839, 0.03092416562139988, 0.0754909020449434, 0.030440529608832936, 0.009680187529219049, 0.024805089325777123, 0.036542215051927736, 0.027702097980571643, 0.038092324909354956, 0.04520477307960391, 0.012778425921819039, 0.013186871772632003, 0.027391279748241817, 0.014512522245890327, 0.017493234980585318, 0.031027570965566804, 0.029385869058647325, 0.040198422968387604, 0.052759900888694186, 0.04850232774125678, 0.06355524715036154, 0.0245326473377645, 0.026978830540818826, 0.04270297036107097, 0.03032127029395529, 0.06253991448985678, 0.09037004863577229, 0.034306415024080446, 0.036343075201979706, 0.07474796726767506, 0.007981256282489215, 0.04295916482806206, 0.01215840776317886, 0.043362231592514684, 0.03990598116070032, 0.017098953548286642, 0.018130660955128924, 0.04096179522041764, 0.01130469620693475, 0.03374907314511282, 0.011105869331264069, 0.016226751064615588, 0.019756049183862548, 0.059572226234844754, 0.02803560303124998, 0.04066008462437561, 0.034621784530047855, 0.027908131746309142, 0.0508460487638201, 0.053052990697324276, 0.035680071849908145, 0.044010242713349204, 0.021610614311482226, 0.06785371221069779, 0.04855623056313821, 0.057570330798625946, 0.05575751593070371, 0.034675527896199904, 0.005525675369426608, 0.043239399790763855, 0.08137451311839478, 0.022541947729353393, 0.04512135398441127, 0.01858388672449759, 0.020027525955811143, 0.01268704337001379, 0.06906090743307557, 0.042123755905777216, 0.011264223289409918, 0.079723922402731, 0.041632577976478, 0.034296966423945766, 0.03158005453380091, 0.02186497673392296, 0.054449320770800114, 0.027332903684249947, 0.03933692776731082, 0.041987153235822916, 0.019485189878780926, 0.027572022817496742, 0.08293739639754806, 0.022566215534295355, 0.03143984545022249, 0.031260613817721605, 0.014323446766606398, 0.037052670161106756, 0.07458059303462505, 0.0236679494513997, 0.01402750626272921, 0.05469158830653344, 0.04482782991336925, 0.03623643324577382, 0.05171686025070293, 0.04779452411457896, 0.019042130260329162, 0.05644969968125224, 0.05003134873030441, 0.008285995689220726, 0.029903380932020288, 0.006832509642533425, 0.016896588960662484, 0.026525321483079876, 0.031232681923678944, 0.05020509101450443, 0.05622027681342193, 0.054893985124570985, 0.02737965644337237, 0.04102562500962189, 0.04516271408647299, 0.018022694159299135, 0.07572575658559799, 0.003236397240211123, 0.03550267226195761, 0.01848293428442308, 0.010968709414425706, 0.019982318560193692, 0.03275210842756288, 0.07433079036750964, 0.017217690391199927, 0.0220647391397506, 0.02176938302415822, 0.015812101707394634, 0.017995793638484817, 0.020995963364839554, 0.04839699875031199, 0.05095920465620501, 0.03310936390023146, 0.0031875005224719644, 0.10404087363609246, 0.030367420853248665, 0.06147554410355432, 0.05736077882881675, 0.028401628569034592, 0.05460779940975564, 0.030064706025379043, 0.018852123491732136, 0.018395140334697704, 0.06706215361399309, 0.04993689665570855, 0.028258769806208353, 0.05947555535073791, 0.03220004555104034, 0.030804750243467943, 0.008133533959543067, 0.026416379293160777, 0.05432633969134518, 0.056892979823585065, 0.0407031648127096, 0.09537520113268069, 0.01453672898268061, 0.08458521869033575, 0.011714659431683165, 0.027892810425588062, 0.044499507173895836, 0.030324469586568217, 0.016666641924530268, 0.03674869325810245, 0.01376134920532682, 0.01813000107982329, 0.06616506246583802, 0.07127405117665019, 0.02555597314078893, 0.04251955895285521, 0.08043728662388665, 0.038383524997958114, 0.04290298552119306, 0.023135041618453603, 0.03108480878706489, 0.043908957791115553, 0.015507670185927833, 0.05457975895010999, 0.02711896668188274, 0.0962766891877566, 0.04216394553493176, 0.0287290743019964, 0.06548502788479839, 0.028234853143138543, 0.00758005803384419, 0.03105639513315899, 0.027268934795366864, 0.011913868831470609, 0.045436251908540726, 0.06462933415813105, 0.041509712247976234, 0.11235043739101716, 0.05241944255041225, 0.01883576061975743, 0.04136326403490134, 0.03888398189363735, 0.02185774185428662, 0.026988235036177293, 0.04841750407857554, 0.016718943403767686, 0.02195888089149126, 0.005471345494567815, 0.025463029110272015, 0.0687688048928976, 0.02187915811581271, 0.03955461197931852, 0.05352475234706487, 0.03758680274976151, 0.05016723893848913, 0.04360779341576355, 0.012518331574808274, 0.03602076767544661, 0.04948521964251995, 0.00814182820197727, 0.037131990904786756, 0.025570461559774618, 0.035429953664009056, 0.04747364151158503, 0.04120621710483517, 0.029076392629316876, 0.03186280686142189, 0.012166827534591513, 0.028353723996718014, 0.014678456288363253, 0.017380425141059926, 0.028116330038756132, 0.023967463290318847, 0.049696169394467554, 0.025709547667897174, 0.007064970650909734, 0.02287387857878847, 0.03487973301006215, 0.025744310713240078, 0.06534363475761243, 0.0517110485982682, 0.039597743057778904, 0.04660144581326416, 0.013085767510347068, 0.03552034470651831, 0.014805530630318182, 0.08144059564386096, 0.016564761587817754, 0.10257026433412518, 0.06780591620398418, 0.05743537696876696, 0.017991035411666547, 0.030366420014096156, 0.10793104381965739, 0.09438193443098239, 0.19947258995047637, 0.11844444860305105, 0.10690826084464788, 0.2519562015576022, 0.12111791728862695, 0.16143707877823285, 0.1245052862380232, 0.11456063629261085, 0.16051119060388633, 0.14882022222237928, 0.07293866042579923, 0.08425454821969781, 0.1043711912685207, 0.20514217072299548, 0.1268950594323022, 0.07705004659614392, 0.13852829805442265, 0.15942052698561124, 0.1134801914117166, 0.12885451928845473, 0.18566219029682024, 0.2275064949478422, 0.0935481031026159, 0.09590349492749997, 0.10297798924148083, 0.10371662889208112, 0.15291284689945833, 0.08047663486961808, 0.06621289918465273, 0.13755099049636296, 0.3042048636291708, 0.23104833917958395, 0.09982844681612082, 0.09366119453417403, 0.12434444629720279, 0.12513690734548227, 0.10951110760548285, 0.14670478073613985, 0.18266051422272409, 0.1398863723235471, 0.14836658085031168, 0.2354932049555438, 0.17269025636570795, 0.10900789925030299, 0.10638662347836153, 0.12309225063238825, 0.15252746615026677, 0.11143651178904943, 0.1639118588396481, 0.12062626438481466, 0.08042216886367116, 0.14162115566432476, 0.2506830798728125, 0.061045128985175064, 0.06585823571575539, 0.11628961137362889, 0.07900495348232132, 0.10102215276232787, 0.13851497162665638, 0.12028459486152444, 0.2237872409501246, 0.06178994330444506, 0.18801107497087546, 0.14234363261078084, 0.09340150561183691, 0.15420366477753433, 0.12348685945783343, 0.16433465400976793, 0.09844733628311328, 0.11084567063621112, 0.11187923553266696, 0.0986226833026324, 0.16259324816720827, 0.13889094788048947, 0.200798542371818, 0.10727587754705123, 0.06857089658400842, 0.13833129219710827, 0.1477362761007888, 0.1290614724691425, 0.1752684044518641, 0.1314321652586971, 0.2162112481892109, 0.12311623005994729, 0.23568403614418848, 0.12089613133243152, 0.11252501088061503, 0.15290649581168378, 0.0964500413143209, 0.10909683483519725, 0.1665315604103463, 0.1975624053073781, 0.07268310378172568, 0.11897158888833863, 0.12893314792641572, 0.09920504276773759, 0.09872518958789961, 0.1614633109420538, 0.12015257908829621, 0.18115911978696073, 0.09765317889728717, 0.09773967175611428, 0.11167111527174711, 0.1114983195438981, 0.07083464546927384, 0.10170313050704342, 0.12381452401833874, 0.11875364344034876, 0.1259067188948393, 0.13031019403466157, 0.08660409785807133, 0.08784850394087178, 0.24249568634799548, 0.08227022684046201, 0.1334452158106225, 0.12738105335405894, 0.14414639158972672, 0.09609865516956363, 0.12036599192236151, 0.20418128371238708, 0.14392708907169954, 0.0800696292093822, 0.10245261993259192, 0.14484982884355954, 0.10576144845357963, 0.1482228942747627, 0.11469243493463312, 0.09854609705507755, 0.147127915173769, 0.07189136198056595, 0.17345729949218885, 0.17643677390047482, 0.17208435173545564, 0.09504467315439667, 0.10880332772753068, 0.14341636933386326, 0.16190251308892453, 0.08868259311254535, 0.10202072560787201, 0.13942917542798178, 0.1397622139858348, 0.1208777158920254, 0.11277691022093807, 0.09662871315543141, 0.10328677017241716, 0.11775025299617223, 0.11252067504184586, 0.1295251968715872, 0.15170285611280374, 0.19112032598682813, 0.1224139327449458, 0.12115210188286644, 0.11581424331026417, 0.14855912194720336, 0.1302153348390545, 0.09474378358572721, 0.1484931819140911, 0.13182589198861802, 0.14043776345040115, 0.1116794544671263, 0.18292128880109104, 0.10650619491934776, 0.10199794718729598, 0.15533643827906676, 0.07604507516537394, 0.12029311726135866, 0.11618172430566379, 0.11638535266476017, 0.1406861072672265, 0.18938869104853698, 0.2137278914451599, 0.12691962239997728, 0.14454785361886024, 0.1091354638338089], [0.048840322997421026, 0.04799758589693478, 0.10273402197552578, 0.060007893214268346, 0.029557039695126668, 0.05724158736744097, 0.016034549235233238, 0.034309312368610075, 0.057019523211887906, 0.02501066168770194, 0.006075266258059335, 0.038251074962317944, 0.01922003535686859, 0.027852737843724232, 0.03355780430138111, 0.017830527953005264, 0.017407059336879423, 0.09156511843736682, 0.0182612263597548, 0.01651529808129583, 0.01563471569014447, 0.039407953420387845, 0.013285719905979931, 0.06860669609159231, 0.03354422342298286, 0.05077589163556695, 0.06820699825350728, 0.01503353875263461, 0.0790812751012189, 0.057109076263649125, 0.035223872400820255, 0.03906819736585021, 0.04783310561573931, 0.029206087812781334, 0.03021314913140876, 0.007779848429241351, 0.04852665322167533, 0.06461463708962713, 0.027642955172008703, 0.06789941154420376, 0.02352649695239961, 0.011623270942696502, 0.048213000409305096, 0.042932837669338496, 0.028963511543614522, 0.027318912292165414, 0.06364322600087949, 0.05340796968500529, 0.08263423373656613, 0.016656036422188793, 0.038686758905117, 0.03547011275908776, 0.049644766974129846, 0.018048429296218922, 0.047618298392210684, 0.004001911330435957, 0.02582935998881502, 0.04687459347769618, 0.03553841070138982, 0.060473877138325145, 0.0619137759453484, 0.06545538268983364, 0.037774539818721156, 0.03639291359909943, 0.00868859511267926, 0.053590716128902774, 0.0373996017234666, 0.03126149930592094, 0.0652469095907041, 0.02021598057555301, 0.05965880730322429, 0.00703738777831729, 0.010072036413475871, 0.01691789156757295, 0.043922077265701125, 0.0698968693614006, 0.045511097713772736, 0.03774670970493129, 0.06822950526007585, 0.013528747400934142, 0.050372716305511336, 0.03080982229273234, 0.05522274551913142, 0.033215632662177086, 0.06561280281416007, 0.0163047113455832, 0.0847294752353004, 0.02580557733641139, 0.040511963822479756, 0.06417964864522219, 0.10233042256108352, 0.018700832234961644, 0.031937642488628626, 0.03089994192123413, 0.031036602266665016, 0.04993509514523404, 0.04154541676065751, 0.047008302195795944, 0.031524665720228634, 0.03509307799062558, 0.10035535639950208, 0.038413214297699075, 0.03624471815835152, 0.06204236511673246, 0.0187438530514815, 0.023625057556533387, 0.07589009776711464, 0.034510643886668343, 0.011851600520978016, 0.018798044250745858, 0.01810390462300607, 0.0347111747334046, 0.030695930189852203, 0.06931119186005422, 0.019229183705257516, 0.03749482732798372, 0.01806334179959127, 0.016880149753498178, 0.01042481864403401, 0.024795382882335355, 0.09266509155609778, 0.02269949677533337, 0.0700458213686943, 0.036484054422804287, 0.02890455024316907, 0.03214130477447595, 0.013548002528425838, 0.06453045124986342, 0.015862323476799896, 0.05890555879367249, 0.03525409774322595, 0.07598350489778177, 0.052392650595200915, 0.033184854313731194, 0.049747337720223835, 0.04211334717859115, 0.03336553801117199, 0.06352178180324179, 0.039679011196962426, 0.06361612531223468, 0.021068977125521218, 0.016639042512646744, 0.02258113312668034, 0.003114341724930065, 0.042690332646348646, 0.035305788540946584, 0.010180831870197185, 0.04117322673222848, 0.08030162711760827, 0.03545688132622412, 0.043530260611857684, 0.02861192523102675, 0.012932413507119885, 0.022152195518304194, 0.03768200799822807, 0.022468119726649353, 0.022411021004830087, 0.01789595908485353, 0.03148184337520173, 0.009386224106752446, 0.025287726195529103, 0.036324008367955685, 0.02547283054861639, 0.03630515527246254, 0.02299337538092264, 0.019073375101600374, 0.008439397189899214, 0.03924098630834903, 0.0521578062325716, 0.04077840416825243, 0.016243029119712964, 0.03734979386042271, 0.019480536824890544, 0.05219817567350609, 0.018984393715592365, 0.01536138482125742, 0.045459651188658814, 0.04305485183639186, 0.08784628513136081, 0.033102822822651694, 0.06513890717178583, 0.08994972333312035, 0.020123969530686736, 0.016108585887455514, 0.04350788591961775, 0.04668604216671415, 0.031360154904957326, 0.023504088333408748, 0.0034161634310813887, 0.04644292985488262, 0.030082897549229007, 0.05802899332983153, 0.012267997105871993, 0.04368539068049618, 0.031183708658707992, 0.030537773855030537, 0.044350046265338144, 0.05254783833931599, 0.022691059192376475, 0.014841107917683465, 0.04713238589465618, 0.013735022894772035, 0.036057690158486366, 0.04717533037598644, 0.025321875166680132, 0.0404304649813899, 0.05686429136299661, 0.008166701599423374, 0.03915429328169141, 0.05869410692581108, 0.038964415434747934, 0.02862590305241091, 0.005771980612605278, 0.018781518530366675, 0.03534738952293992, 0.026870575367606113, 0.03655673909400191, 0.006922919344755688, 0.014430835111332791, 0.04955993991877351, 0.027143935074231455, 0.10435481143317052, 0.033840146115315814, 0.011865268760759915, 0.028493273204990795, 0.0032841620767222984, 0.04213156245116677, 0.07502176971840006, 0.05473883130720683, 0.023164345849571482, 0.04791555101318019, 0.08672576597226517, 0.06982231193355151, 0.021161376631685665, 0.032650396028267484, 0.02455595162297998, 0.08801596638347421, 0.03104889053585274, 0.058839937672019005, 0.04166648776403495, 0.03146257298067212, 0.025209267191322784, 0.05777104824249234, 0.024459377430113297, 0.044509213617337604, 0.03942250121118767, 0.039803020256970606, 0.051636002625205686, 0.03596852047901068, 0.027887412679514716, 0.01977599811341081, 0.03431107655965856, 0.012507634470239282, 0.042541621518986564, 0.04949599138594099, 0.018379790176238333, 0.057788629084825516, 0.05283913342282176, 0.01876762552585985, 0.042039084913475175, 0.02285745633499963, 0.013082606385328939, 0.014597919270662325, 0.031435265338846614, 0.022882061711113368, 0.04989831176187311, 0.021261711604893208, 0.026097013215933527, 0.016358319004731517, 0.04395529155486396, 0.022910570359921882, 0.037736446862774234, 0.09026712165879351, 0.015162019358415688, 0.08364454523793288, 0.02922562962131841, 0.10263619758188725, 0.05889855631228004, 0.022555096041677252, 0.02039468295073935, 0.05466757495222347, 0.06206751162452357, 0.03613284469715186, 0.05181586868794901, 0.043129962270281146, 0.04239620467914002, 0.0007245359821743996, 0.014493189086871488, 0.008384799717792442, 0.025094426835754087, 0.015906606368454437, 0.034070861592356644, 0.10081533528864384, 0.018031172454357147, 0.06069716265691178, 0.0030393487624158816, 0.048972206456320624, 0.012097735706317638, 0.0382571682067854, 0.07471746033323662, 0.044766758369015794, 0.026789120631292462, 0.028689084840672355, 0.05779008793511561, 0.03543058130890131, 0.05190576779256974, 0.023110446420365145, 0.01679343467445246, 0.07632967989359583, 0.05348325314532433, 0.055581320742411275, 0.02885722242561834, 0.023288446511807184, 0.028017012868076563, 0.008128944518310683, 0.07215453178754874, 0.011147117475047708, 0.04122225088732583, 0.034214619414082596, 0.05785295420459338, 0.05586298741400242, 0.01952240752455379, 0.007826708905797983, 0.016542490372168164, 0.0323547922473933, 0.035314246479954035, 0.02533895898211215, 0.05368194176948496, 0.01623901558507766, 0.043892055483801026, 0.05290159257128835, 0.02891272319746869, 0.006095577779758189, 0.008774782630747982, 0.01564577581094844, 0.03216854456279959, 0.012122017930128744, 0.018752818195415393, 0.07850108694817338, 0.049555044288613966, 0.05132366956344672, 0.053900463972240686, 0.026185889429013644, 0.010609748274353998, 0.10284760195229735, 0.040619511622935534, 0.02518371695519558, 0.010349942304726158, 0.017226155115557567, 0.03476827345522387, 0.0448470799518483, 0.010259808257355221, 0.075644725933671, 0.11607143522373267, 0.18372297792562417, 0.1919897057648216, 0.16452613659203053, 0.14982016570866108, 0.08622255761708532, 0.14737841673195362, 0.1304112278989383, 0.1220048711236034, 0.08983881678432226, 0.16998059462223733, 0.0678733829408884, 0.1663417470242296, 0.08466448515121426, 0.1300205952887024, 0.07451900241098233, 0.17444823203342302, 0.16920002150748456, 0.17463928035327367, 0.10153564092304025, 0.11317732730614287, 0.1293383011860507, 0.11837915996355669, 0.11537025070616178, 0.16698582603463105, 0.10975044726261071, 0.1054636597899454, 0.23167427416358674, 0.09154633658805064, 0.13309365324676037, 0.11527612432837486, 0.0951021925679275, 0.1004898895376495, 0.10071656094597918, 0.1036607651039958, 0.2034162219081606, 0.12653772932078156, 0.1108112417693649, 0.12644033240420477, 0.0837000629731587, 0.06369991081633739, 0.08695228131754057, 0.10285792246993099, 0.06595959527684109, 0.16356724447437695, 0.11181179593716349, 0.15153793139117105, 0.12414944890354361, 0.1288262243781771, 0.08178145771047898, 0.21379940903612546, 0.13016371189483575, 0.15634429348366602, 0.16588322020002774, 0.1147313014205013, 0.13639716883855207, 0.15773849295718329, 0.14748544884579523, 0.1246870793402195, 0.23247741535305977, 0.20073072958205426, 0.12280885369649955, 0.19422071533543722, 0.1310560940099614, 0.14796414173075131, 0.2009021546691656, 0.131827819028071, 0.12538371767316545, 0.13689909476254666, 0.13844973726996354, 0.13344034392918858, 0.056260907490338595, 0.08208691381982394, 0.1135086559557489, 0.1502324300152915, 0.07760729348020894, 0.1783845629543066, 0.20935803093016148, 0.04982921654092414, 0.16779178992978164, 0.1967548264988831, 0.14506990489150795, 0.14364404497402056, 0.137770252302289, 0.07901530114135571, 0.12198423008833613, 0.12233107004846845, 0.10413063024835927, 0.13993699103593826, 0.11148690658488444, 0.10821505143706288, 0.15410569789154188, 0.1683992687612772, 0.12345754674502782, 0.15359580596642836, 0.20462770547185624, 0.10798873965229307, 0.10807626388434853, 0.17345636311386312, 0.29686802732092993, 0.1665994274829115, 0.11387550591358117, 0.19718809824969086, 0.19763191443468842, 0.13207016459533147, 0.17237773670681886, 0.1309658759938819, 0.14136553795209952, 0.10537885648331471, 0.10012474948806421, 0.0627489032756005, 0.12874535657465458, 0.14145278398479733, 0.0959957485486354, 0.08827072235622577, 0.20882197469472885, 0.11128610093146563, 0.2201196098966258, 0.04469108135838594, 0.1262005516993148, 0.09888655878603458, 0.16779468048896107, 0.1792432761618069, 0.1530974627073322, 0.08584411149578434, 0.28136665054730003, 0.20483425153153284, 0.10050456625010286, 0.13199050458414213, 0.12688228940325125, 0.1528412207428898, 0.19421850331127644, 0.1183742880821228, 0.1118390051914113, 0.10806540732405015, 0.1183914550180946, 0.1719297000340053, 0.08625140892607824, 0.14745374768972397, 0.07174586371651717, 0.1199305352887937, 0.13358968948679312, 0.10606229731014796, 0.1884097685771329, 0.10233638009854726, 0.10145515309912817, 0.126865434593388, 0.14892671150820597, 0.14398530737629958, 0.18198923952877522, 0.14907218941620418, 0.0800531611644796, 0.1731676600341286, 0.09729307357754026, 0.06606880548809256, 0.06822084715323788, 0.12689246742853097, 0.14741664539490426, 0.15825826435216836, 0.08028417519692864, 0.11121887846716813, 0.1890659797936678, 0.10894576579864536, 0.15742152210857185, 0.16865868626960687, 0.08984207375241177, 0.12267563013093812, 0.17978173441120557, 0.1853435773934637, 0.09420491821531739, 0.09185850340873003, 0.24821807071566582, 0.10738375104431595, 0.10430132251765047, 0.15521385414259775], [0.0654908429299082, 0.01269088133371302, 0.0276358780517642, 0.0642370255663991, 0.08860421553254128, 0.025674614988799607, 0.0554354662474777, 0.04034199758565851, 0.033102673544947586, 0.07245804050139018, 0.017516625779015676, 0.044039036346865554, 0.008537048557108002, 0.013635476718523672, 0.0558862408090915, 0.03524475770869425, 0.0424277429868068, 0.0903578417907868, 0.018564144748130014, 0.04116474165182028, 0.07320059529904809, 0.032100545175905736, 0.028342188901400993, 0.02328339481859335, 0.043220200642411194, 0.011007542821711727, 0.04650401157726135, 0.057324042942907126, 0.017704934513728534, 0.025580452987924218, 0.0643761863133737, 0.05047872722414987, 0.05113216323245849, 0.04370755163420524, 0.045960657697703154, 0.02680179736177836, 0.024157030707491294, 0.05208353039675525, 0.0318363473883697, 0.014579268039337226, 0.028635361830570867, 0.05649038803364549, 0.05301646176459534, 0.025676698091306856, 0.04219060178313937, 0.004630294129518526, 0.03485024727082678, 0.027619774719434123, 0.03807847600962434, 0.022405363719112108, 0.009245674907495933, 0.039685345321361504, 0.07135705636548144, 0.024880807048508098, 0.00951364789424198, 0.036796991380729845, 0.019840533579034463, 0.017792889615520835, 0.0426994928691004, 0.028942717837968042, 0.011231084487267902, 0.05224056375612106, 0.06273811456880399, 0.036349843588790724, 0.016614718728565743, 0.07429463123636586, 0.07453858493162052, 0.03421215293928981, 0.0367217079204108, 0.02796044509990939, 0.018890001012810638, 0.057022122001009326, 0.01793174841441214, 0.0488699071242341, 0.051091627550444434, 0.0707398269857679, 0.04008643076355968, 0.0048598412540741265, 0.0618178378790617, 0.01998363491812987, 0.05034963254417692, 0.005397689670124757, 0.022758975458730544, 0.035757092359874926, 0.04764822517920818, 0.059269538548375876, 0.04621502351281898, 0.015658730740791986, 0.06047732409621988, 0.0642846180126071, 0.012689740546712918, 0.04083507880568504, 0.015369656163134744, 0.08886821315224681, 0.03137930655585868, 0.07477320198501859, 0.042695248632558754, 0.012552469519765248, 0.005462719618143248, 0.04583681487877454, 0.06431454140692949, 0.04378974597368922, 0.03867470133783562, 0.02331691444851458, 0.04585131177944796, 0.04652768227138689, 0.01934786626536931, 0.03919954478208508, 0.015841650211119225, 0.028248591780928627, 0.0360503416242344, 0.03640879810388599, 0.04648131797356265, 0.019625146208064895, 0.0459422117232212, 0.02076491879831467, 0.04264604127300637, 0.055438692681491375, 0.043713315789188655, 0.06330011798334972, 0.04492798846747194, 0.05318401920210038, 0.023013526174638952, 0.032098604565752406, 0.06443088980657713, 0.02702727963748787, 0.045773846829043965, 0.026330475063462342, 0.047306372451462915, 0.12508727929421834, 0.013406377851164766, 0.09604062685476882, 0.0210841457758631, 0.028469483767236983, 0.03486892055453999, 0.0478799007833004, 0.014141997172763305, 0.06367240300668137, 0.06248976396662848, 0.06895409923579011, 0.030723234439002614, 0.01907882882681276, 0.03425944343741451, 0.02757173274377627, 0.018829908255221586, 0.03876762331596442, 0.02183312121113496, 0.0832575699314475, 0.031149072838681083, 0.03266042138316801, 0.03129962958129389, 0.029413648282310793, 0.07420646918139287, 0.03169345809146762, 0.02202787942120007, 0.011365008640236087, 0.03102112149021455, 0.013843610550143888, 0.09206599941743271, 0.008029353389117335, 0.030392787884920835, 0.028780683675514798, 0.02999420284426638, 0.014790085476956196, 0.03679935607526984, 0.008827853399062795, 0.05277180239292128, 0.007764555098089788, 0.13540809548326901, 0.036486154488687, 0.018763184514162794, 0.057373487789716036, 0.059158937340336185, 0.03502952640077897, 0.02884119882115296, 0.013860714721626468, 0.039629471355250905, 0.031519899011722634, 0.06988419432725225, 0.05270969947533948, 0.04612935507403953, 0.02702503707925124, 0.048865988584501405, 0.039230346879256625, 0.0223453998831766, 0.08736461347767285, 0.0977430237191064, 0.03603542742452451, 0.039586109574884176, 0.0530961523098605, 0.027247969759628177, 0.03312052919396332, 0.016870950514982854, 0.039061076140829494, 0.012673024836528515, 0.00314242098829709, 0.046934613292770724, 0.026249410484784415, 0.027954462117382457, 0.012599832960404456, 0.052774543674396615, 0.03282955641459141, 0.019056628857340132, 0.09263342432677746, 0.031520926992275884, 0.03967948277880039, 0.03053743458752121, 0.019703810469114354, 0.051426009607634375, 0.027949907451069782, 0.02614028169773519, 0.014776297645377261, 0.022713783330151012, 0.027835798216983676, 0.054979891050606966, 0.04610872760947261, 0.044332485779055526, 0.04888471954369119, 0.046523967292159796, 0.034365254188222547, 0.024569295014121702, 0.02116489313941981, 0.03861928199018751, 0.013322209822945297, 0.03857230022549629, 0.10257650007094656, 0.03312185912259987, 0.009910903854428657, 0.054121768168572865, 0.025517595200134174, 0.04622622612597687, 0.034722319671085904, 0.020694047511954392, 0.04672786367258855, 0.007868055437159325, 0.03989065983997924, 0.005296529004616397, 0.011046323642533804, 0.06992439752710716, 0.04736403775002275, 0.02802673457855625, 0.01857944232012544, 0.023503391138677086, 0.023264967503824403, 0.03664311660187585, 0.038051782441990714, 0.06555391275989157, 0.03757679435823645, 0.016598852883492197, 0.0031861614760211004, 0.055747758597135544, 0.04023983396057572, 0.032025963999331, 0.023612316365220716, 0.0193039701386754, 0.04831900454259344, 0.04431449442303606, 0.07074739265122584, 0.028597611534808363, 0.01859018692214574, 0.03922324261761137, 0.04493457704250302, 0.07463990378060512, 0.02521667509738888, 0.04795842764100858, 0.0010324610047973692, 0.04134478074099336, 0.0907952661759087, 0.03417371053780828, 0.020056492615757242, 0.04025936559108751, 0.029604425188153982, 0.04407739732414484, 0.028594524200473512, 0.028293013772261993, 0.020124056043901613, 0.05299963070345776, 0.0826758686453104, 0.04876207433907049, 0.018304830716390694, 0.0677445155701467, 0.04202321058671389, 0.02578620007261634, 0.058530064299702644, 0.043231148804937086, 0.013792962151845651, 0.08321860166532652, 0.011815218321446861, 0.037029511760920286, 0.12213972317320959, 0.03389897849410772, 0.043864869978278875, 0.05258668786180871, 0.03669893628518496, 0.0197824051803244, 0.014982411138979452, 0.03615738730877638, 0.05481036246887275, 0.01242242828344128, 0.09073801817638533, 0.03404682788199612, 0.020478203826184784, 0.08737416046538524, 0.023136181557284932, 0.01969520834141544, 0.027250644883939197, 0.020032689607303058, 0.04775485356471368, 0.04836328234523535, 0.051027370284178426, 0.019988023343362978, 0.01530089003166982, 0.05474400852939912, 0.018261087260075977, 0.04101634604324188, 0.048621515809957466, 0.038559716793575456, 0.04653194007862892, 0.01785306549364967, 0.032661082954811196, 0.05408743429662926, 0.039236334950796196, 0.008539284329994448, 0.06391428038477898, 0.0014674924937675574, 0.061943997895079, 0.02802766247519425, 0.0194733816731189, 0.01492371955620391, 0.030094320686267953, 0.03428914291518075, 0.014712734181167824, 0.05260384122708014, 0.02413036597759596, 0.046294910833239555, 0.005035000404209963, 0.0699715760669538, 0.032842228056064675, 0.03725041222891637, 0.024966589141903178, 0.03140017490035721, 0.02862576734540718, 0.05542345278497253, 0.014262149609359247, 0.03789605186986072, 0.019039005606568286, 0.025220798893964717, 0.009974446114418762, 0.049976750410028865, 0.0409986125305295, 0.046454149431415966, 0.03586841620770948, 0.0821230865216681, 0.12276921368071012, 0.12713264168373176, 0.2262558327721698, 0.16194983412112507, 0.10368393707488265, 0.09853878244757652, 0.14275475697857992, 0.14751210170132772, 0.17214600342725003, 0.189266473320978, 0.11892775552613394, 0.14467300261769975, 0.12813634425401688, 0.10921102549348559, 0.07557630246239048, 0.13171343159462723, 0.2623108902147838, 0.15848817915788718, 0.1045480039236801, 0.12462065076189381, 0.07061095282967601, 0.10814702830144338, 0.17691663386566298, 0.14748778300625937, 0.07642619471464838, 0.16781799495220184, 0.2310644340302263, 0.1502166065786566, 0.10128963805202927, 0.15513004149709428, 0.19548393040895462, 0.1284954928393875, 0.2054183887583869, 0.058382910410208363, 0.06636219724480595, 0.09303105263305561, 0.12005833057420594, 0.09894213080406189, 0.18332152946719102, 0.13635907588260515, 0.11612628799464021, 0.14029000566474029, 0.18128539515393122, 0.09663342218846083, 0.07535536467496838, 0.07825009005942515, 0.1420373147619622, 0.12787786312401295, 0.1709671981100525, 0.13060960439699038, 0.14439894232366765, 0.1794526856392622, 0.12330988395426955, 0.08915944716760091, 0.13887486660054751, 0.10467605026704924, 0.11766340051378522, 0.11518286647541182, 0.1187512685677835, 0.15445152004914625, 0.11023650903786932, 0.15548429105963024, 0.16056958532759122, 0.1030329709340419, 0.1283634363540581, 0.15244300211114542, 0.08930984445448432, 0.10746393352746964, 0.10434908459761313, 0.08628254011273384, 0.12343287521174975, 0.0639856012005891, 0.12760395210768494, 0.1087986526212522, 0.11710115282663278, 0.12219691010458128, 0.12637758148568018, 0.11061156248407704, 0.10039604135922023, 0.14125333540141582, 0.14126154567514146, 0.14036225607352598, 0.12856236925082548, 0.10694758873432875, 0.18674893198268755, 0.11792302158262048, 0.08327808204506125, 0.10858039504715375, 0.1227011430476393, 0.15459460951387882, 0.18611592666379043, 0.0868036210803049, 0.17560818764780248, 0.2102391357932772, 0.20292553252407483, 0.15244174003601074, 0.1984743292310408, 0.08549055403896741, 0.11995216698518821, 0.20006930721657618, 0.1751117171453578, 0.17160126194357872, 0.15044460791562284, 0.18984484300017357, 0.13158167366470608, 0.1294424563114132, 0.18846763404352324, 0.16969362859215054, 0.09719252825847693, 0.13282350131443568, 0.11941212096384593, 0.08401607030204364, 0.2343983751322542, 0.11593308193343026, 0.1268685558544738, 0.1497048418968916, 0.17775344396276133, 0.12665937707892486, 0.16768800121332916, 0.09434221977634089, 0.15193001606634685, 0.1079483600333333, 0.14032040403357574, 0.15447662584483624, 0.08447649023894753, 0.19883868896535464, 0.13883659722549574, 0.18810265005699225, 0.1611172987946442, 0.08898261415639094, 0.14991005802793161, 0.15641695101346287, 0.19352432127509797, 0.23623457231691905, 0.09919221167053495, 0.10118460761649267, 0.24515155383518764, 0.13303033235882009, 0.1906279538358961, 0.13512864762118884, 0.1042649530406509, 0.09465361985244922, 0.16408336535096169, 0.20232591112809523, 0.11051995347120933, 0.14571853008653435, 0.15023853683045932, 0.11246948636003903, 0.16279866785875388, 0.08151469845324755, 0.06772329778011356, 0.18197929220540182, 0.10836188641509839, 0.10600307477372033, 0.10301348340830632, 0.17547326774469443, 0.08197788681302752, 0.18336848409048148, 0.04998381395957299, 0.10078967987958874, 0.13941103140158312, 0.17534142839057104, 0.07643379430685725, 0.10808807717902319, 0.07506920610155378, 0.21362862177193165, 0.03916163503059319, 0.23407278688890593, 0.08186267156686101, 0.0648176751232573, 0.12656021597129957, 0.14341322093137673, 0.1556949219001191, 0.09528099333069154, 0.10516741818615369], [0.05021346752930965, 0.012402657469335412, 0.015766577096655965, 0.024845519834863286, 0.02800904177794499, 0.06761422327586583, 0.04069875094241329, 0.019221585809386203, 0.020000292952837687, 0.01911249603810055, 0.016309282975271344, 0.0423624780960381, 0.01946865737305156, 0.051888644961374145, 0.023628521477803588, 0.038080755887287, 0.0568197658950729, 0.029915462248027325, 0.016237738242905055, 0.03165834390425256, 0.002427956904284656, 0.016418779867568185, 0.005419254785270563, 0.038832565902599266, 0.04801037288936121, 0.01738202987637903, 0.014518435678577848, 0.05203002451785973, 0.04204953774543745, 0.061729492619633675, 0.011188321514055133, 0.04896050511992403, 0.02431530917861632, 0.029257222211786678, 0.013227707706391811, 0.05032387874754412, 0.020263070905847207, 0.041077943452234776, 0.027676561315144812, 0.014366581237741878, 0.054878080263733864, 0.02342753261992974, 0.03141799322994692, 0.02807759925989168, 0.04990149748378566, 0.027845708220931034, 0.052712824129100354, 0.037787109679941616, 0.0028470595716498792, 0.03785624561299171, 0.013496190442570617, 0.020683038281276822, 0.03060573252982327, 0.03359984293846147, 0.01964033691079489, 0.030758664145001342, 0.026059792177485566, 0.03202484780922532, 0.1085669125563332, 0.04688363156414457, 0.030177495508853878, 0.04714020261807101, 0.07069181384784834, 0.1063208734350545, 0.01338219825577523, 0.062136159012360234, 0.07744090990828616, 0.007583525347789484, 0.051939585977899175, 0.023970618478155563, 0.01304825215733477, 0.03374222333409956, 0.004698407595112387, 0.03493643478889551, 0.02652102635641183, 0.06480232666113547, 0.018975267419591546, 0.03412290522828698, 0.021393573011404703, 0.027587490023246834, 0.02974364361060517, 0.03300397384113499, 0.020672917931473682, 0.0707385784813336, 0.020859710140419856, 0.023108709370717406, 0.019153393040012037, 0.016999895917251706, 0.07044502387621573, 0.034247769242418666, 0.06579770360674177, 0.03299941747848477, 0.06547083971755845, 0.05442325484805873, 0.03382969667602863, 0.011730249621905386, 0.02446393040008843, 0.012861705917332853, 0.03121754720008799, 0.07275215829057352, 0.018831463796751838, 0.0490896947947996, 0.02093788924893098, 0.017852899252570102, 0.02053398110105523, 0.042243649650897296, 0.008351324192647423, 0.034837955608963966, 0.06769256692911897, 0.04066619822489364, 0.03695828594001276, 0.035199289077094624, 0.037155522499233484, 0.05178147374785372, 0.08118558182780232, 0.03700895893520542, 0.044039073666291575, 0.01992342172057501, 0.0241023068582373, 0.006794066816967512, 0.02962457767820784, 0.08846475623015847, 0.019829261416037167, 0.061214437043028216, 0.04469554272613355, 0.040678157404597313, 0.03452435368672013, 0.056984219034867625, 0.04081153364053794, 0.05351924942806363, 0.02935999651838626, 0.016686336403446536, 0.025051809747570326, 0.029372213541397026, 0.07623126517449107, 0.010595118211183165, 0.06862395802246672, 0.03590520976909569, 0.025326874273430024, 0.03684047869007502, 0.026066480836431895, 0.015965465888647095, 0.01398781281230705, 0.040523074833410125, 0.04100724010329161, 0.004222348274197429, 0.03469583644930806, 0.017167539867971624, 0.06534613855183125, 0.0273687456002725, 0.03203820477106741, 0.06634012450064931, 0.05259295413270593, 0.04246175455461655, 0.028308336789320623, 0.037523590427424224, 0.002929078764282167, 0.018573674772466933, 0.05898021121642419, 0.02334417968190142, 0.027618510947961892, 0.05274890183604189, 0.0404272996155279, 0.03218094818294048, 0.0020618111385764287, 0.07985796021031481, 0.022116911697334478, 0.0514223828379597, 0.02347311660248254, 0.0062757012617242125, 0.08219820713358265, 0.018050907645374537, 0.018916977868814553, 0.03058760885947517, 0.07216530692364488, 0.06748328637331724, 0.05433470602812512, 0.023055105104244182, 0.019579838728532195, 0.025807494197839072, 0.03127022187358566, 0.0279543654261423, 0.046578552041734965, 0.05500506130712373, 0.027221883480836238, 0.018421956038634692, 0.03530981225360717, 0.026887151978111694, 0.025986988762659684, 0.01937966580901827, 0.04604339825787714, 0.009373495637971376, 0.06697965054107563, 0.07645410285996539, 0.053165105038455555, 0.030887131180082048, 0.014030852288539921, 0.036641776495214017, 0.03330347241301622, 0.03354208943034921, 0.009811908139714172, 0.024215842730232646, 0.013912989907631916, 0.006769794347097299, 0.02870816524539675, 0.024644435982086828, 0.04236671554722956, 0.0890007038999881, 0.039931185343968015, 0.017262848593028526, 0.04064898379147053, 0.07379522267729044, 0.024527468419234668, 0.047109210531094244, 0.013989880647776383, 0.012120609121796275, 0.047819446705813916, 0.00877659092657268, 0.05435854296333023, 0.04384749608912638, 0.020201590544145023, 0.06211203709244728, 0.048449578428907056, 0.018693493878734962, 0.031219542093042816, 0.05510142345779708, 0.023336525806891065, 0.013539893186784216, 0.02278995736768203, 0.055649713679615936, 0.027037841035053134, 0.027506476334695305, 0.03751756842913372, 0.030057265888899565, 0.06931320032370941, 0.10451672345932041, 0.04026977092559848, 0.030629253946244717, 0.054868350071566444, 0.02593205456754991, 0.031670873053371906, 0.08820783573069743, 0.05213113980633872, 0.024855833567146744, 0.04248754906335047, 0.012131480100963796, 0.07770623067127806, 0.04785898154867547, 0.04749896104580589, 0.05235460852938039, 0.059700896830431054, 0.07704272520329271, 0.038162064738571644, 0.03965061450643199, 0.03376936134217041, 0.020300229179805944, 0.02811606032108622, 0.061281761287578514, 0.05557368043810129, 0.03529084719983595, 0.027459116286731193, 0.03295072580554655, 0.04443670875791993, 0.03770233351471169, 0.045705793159348626, 0.030480210336723497, 0.06225739964949233, 0.03470531219084348, 0.062398609572223256, 0.034556234654571326, 0.059770019192780764, 0.007046838498873902, 0.11233664955943823, 0.01696683599480561, 0.04895055440387555, 0.03957623689036284, 0.02677265089005232, 0.07729269750416279, 0.022975365365190164, 0.04753719310143164, 0.012043860025836952, 0.037594697504703484, 0.016106355203581706, 0.02865353299837027, 0.04925266872825367, 0.06969784146973065, 0.030650732972260033, 0.04968762324590768, 0.05616383966324585, 0.02830125288372593, 0.0486791845011924, 0.05264888916696821, 0.034146484320185015, 0.06968157698533364, 0.005216703600516277, 0.03481611356671367, 0.00835801794060639, 0.01697993341700307, 0.03443780315241643, 0.047652499949825664, 0.036993291561624835, 0.04951286994452987, 0.09144775902054139, 0.03113647922873497, 0.009245871682651341, 0.056568928462054045, 0.031984125530081134, 0.01966040119129632, 0.0194465727545321, 0.04626438693542566, 0.0036701950677005307, 0.041968931177897115, 0.041866112766521316, 0.025295992448393787, 0.007123078269484852, 0.10608467539506299, 0.06229646291051592, 0.052769624295511415, 0.021144106219123517, 0.008453760079906454, 0.04231085854449442, 0.03539175892780934, 0.04590896689998252, 0.02597090239370508, 0.03517230713207807, 0.03258122277579137, 0.05455841563109841, 0.09397091862878629, 0.0757969416944044, 0.02445416628117008, 0.0063602242485753125, 0.014737220813653298, 0.03844364998596055, 0.049785257649741003, 0.04142157054905381, 0.08665048929729632, 0.023400532015200173, 0.08267348698739495, 0.022473614163962857, 0.03483081402789269, 0.0389050436206162, 0.04382545727172068, 0.00524693403193461, 0.05173845462767141, 0.04631106675203357, 0.07362501216786248, 0.14771480725279876, 0.01612625493934112, 0.03254898896973048, 0.03949042595922947, 0.060353627162320275, 0.033194136672786305, 0.17593970628721373, 0.1416049251066787, 0.11630627619368689, 0.10618733095803431, 0.0944049231974142, 0.18709760398737021, 0.14070555408086094, 0.1021387092769146, 0.12285469552235943, 0.1047993740066886, 0.10892888384738139, 0.11385170290512697, 0.07539079098829202, 0.13563723675906658, 0.14244088024965354, 0.10864185674914292, 0.1295011903026274, 0.11436350829899311, 0.19418009822922094, 0.1348375425274883, 0.09099563756691557, 0.0831569635442325, 0.05960939638316631, 0.10606780701449939, 0.1289450494306428, 0.10061174764164857, 0.11390333942004613, 0.12164002284407616, 0.06661822207804237, 0.12441736167030674, 0.10577123292854854, 0.19368517478661879, 0.16871929301747254, 0.10108473404709782, 0.1279679454330887, 0.24172867036291532, 0.1677214801311493, 0.19524904872689927, 0.15145913990480558, 0.14082663186958858, 0.08743408189288207, 0.08875298433537994, 0.10785427436764751, 0.106595130504242, 0.1005726708099246, 0.11422132807118551, 0.1309669887913125, 0.08607958350330591, 0.10688873260681118, 0.16313413557197365, 0.0717507152419005, 0.15016308373638562, 0.13156768227262156, 0.23175895533391408, 0.12007628461079937, 0.14188662570502075, 0.13324498012661934, 0.1325523994330849, 0.21583509551627295, 0.16073132093463624, 0.0938629229952182, 0.12006112613848277, 0.11410575998680932, 0.12713029395256722, 0.17142838479152747, 0.12130973913839885, 0.11142779261405979, 0.1117880472115108, 0.12134008322443281, 0.08423439572964396, 0.08855160871254546, 0.1427169625780412, 0.13490340113639832, 0.19424328341015748, 0.13011993281543255, 0.11920307789530073, 0.12097412214747497, 0.11705050697284085, 0.16002274038536207, 0.10350962142859187, 0.13933811602847918, 0.144404085619109, 0.08628473856619426, 0.3068995161780289, 0.13647574319371156, 0.19414686358400754, 0.11207777487912349, 0.10538078352276768, 0.15719065735382692, 0.11556912932012763, 0.22516778829906667, 0.09519937235329833, 0.19522722704069956, 0.19132997973689012, 0.12254334294370242, 0.12347642358924661, 0.1452357117086649, 0.06937212430472885, 0.11486144443707806, 0.22056297824851104, 0.13904006273618766, 0.15414974838495255, 0.11488508459712778, 0.0815975543643747, 0.05683419833491955, 0.09678983808095966, 0.08383541713867869, 0.09416418575814792, 0.1947623219873224, 0.1366546457367284, 0.11534988108490195, 0.18695857216204914, 0.11523438085402761, 0.17617963626980782, 0.14769141136535577, 0.12137570631291185, 0.15609862309481415, 0.12349402478763036, 0.07947249803692102, 0.13136290040399345, 0.14062955815877232, 0.15016883771334374, 0.1450033270354782, 0.16282419434615544, 0.12918234669736453, 0.12309424552534308, 0.20288209271218094, 0.2066105612154518, 0.06816057288753134, 0.15615019175623143, 0.10773139167577028, 0.1378485281020403, 0.07922338069017444, 0.1958542883928333, 0.09468301398945705, 0.13772669035409177, 0.12861936619239195, 0.10651614224272114, 0.08062168530055455, 0.18591964005359582, 0.15548844369394438, 0.11418870410748891, 0.07737458311021328, 0.12127488957984106, 0.15226606731968267, 0.07567105309239455, 0.11055609903165273, 0.12600293516048364, 0.14519797159092768, 0.13169778457709722, 0.11407310888171196, 0.16106209318552697, 0.1251669121640069, 0.08451422357133456, 0.15702141714947565, 0.22078913397022656, 0.09512050622808081, 0.12902882136404514, 0.10140030711357083, 0.1884460159178291, 0.0699392438733152, 0.11414637709302561, 0.12507480782057556, 0.11353091190436057, 0.13311258437378065, 0.24674507975578308, 0.07327902037650347, 0.1382883002183267, 0.11781726511461393, 0.21147374383040837, 0.2684402870280402, 0.09807664581707545, 0.16066528590662138, 0.14161956789238112, 0.1416622477450541, 0.05722881733839001], [0.016008115207244242, 0.022237704501354268, 0.010679903706269605, 0.07575263335768666, 0.024950697851766433, 0.05312487469719989, 0.09109532114650522, 0.04006456497258373, 0.04840807244181633, 0.032458262052387, 0.05240953593913998, 0.025880071999771253, 0.018097799504175782, 0.02531990402245096, 0.008675518894701131, 0.027610704402572343, 0.017392353786687766, 0.026788146933540702, 0.009748615241343421, 0.03946449574349182, 0.05785999061273677, 0.03806247276120952, 0.04760994901880622, 0.059281419696552415, 0.017393570060708692, 0.05450882489926048, 0.02476430937115635, 0.05139841019575085, 0.048799532864774973, 0.04321243480912276, 0.043981360870280435, 0.012109521859591561, 0.024669319557558213, 0.03446563665888139, 0.028161247360653112, 0.06913387708898101, 0.04585538298955985, 0.07729959820530244, 0.01860818506351539, 0.024494651073057736, 0.04541685937770775, 0.04895425241972719, 0.030113428232393095, 0.05255193669082863, 0.06214237439313105, 0.08487482422164508, 0.030713765482817377, 0.04766764485144189, 0.04485830631373184, 0.06566410684692008, 0.029165735335222313, 0.06565504840442113, 0.003384550060478172, 0.024854011700621674, 0.008691166760399938, 0.0034055661983854535, 0.05878745298832655, 0.02953936385789088, 0.04400375931124602, 0.06639159816716399, 0.02617452566378883, 0.041139344086072276, 0.002883883030985349, 0.06628215046865599, 0.08075784013739654, 0.012231117031270904, 0.04350322438403964, 0.016763194065008844, 0.029985938287739242, 0.031819655426910946, 0.06096026461039271, 0.017472273337521722, 0.016161085838185887, 0.049159119105232615, 0.04632902078862701, 0.02829472198417144, 0.007811709889210761, 0.0733884002215096, 0.03140487375536135, 0.0399234636154558, 0.044582512362727096, 0.026725392622341002, 0.036330142324524264, 0.05177568584414465, 0.024796594067343643, 0.0489016863118325, 0.04318076079445226, 0.05502491184909429, 0.01875475202021854, 0.013571874238550663, 0.02158295383144702, 0.040390760504773686, 0.025955189219010726, 0.04042726229610188, 0.02324311189087374, 0.011877043887839785, 0.04525902534701994, 0.032412080959017785, 0.015476391417905688, 0.03014744658555303, 0.024345137578036104, 0.015896357096997753, 0.054412184549229484, 0.02336041023954749, 0.006482372426294855, 0.05296416367803301, 0.0010450026644061186, 0.014769357928474034, 0.01833547335783286, 0.02965525085372584, 0.008663669976937984, 0.03679204825311899, 0.013063533614123506, 0.06826930133891956, 0.07318804918655328, 0.006804631183123482, 0.06086760386824608, 0.05155751647959862, 0.015017511755494135, 0.042767946874456744, 0.0392638427604522, 0.04084921947547367, 0.03977353112506015, 0.03736861302916493, 0.04602078947105578, 0.032200486598802466, 0.04013123443084104, 0.009813278780451842, 0.021592387164543782, 0.03584507799574307, 0.08200426146920238, 0.04508138148646269, 0.006174629229852664, 0.023286173419494714, 0.02533703194265919, 0.044316916793052635, 0.005329477816953191, 0.03980832979349153, 0.08651826996356249, 0.04654229452301349, 0.09282912739685603, 0.033929997722485235, 0.04476215450891426, 0.040611280993159325, 0.06911093582000051, 0.02393196233814316, 0.08878874313086271, 0.017164094606414437, 0.04698120150715113, 0.05793871424560036, 0.017622611252591014, 0.029599309034113373, 0.011106702232999461, 0.03131812305322715, 0.03671900735103658, 0.028956071407135044, 0.0833186652245266, 0.023989854945934246, 0.019787853816524148, 0.04597992809223277, 0.035853624144302945, 0.013325459157515849, 0.009012906013854911, 0.039005198782043796, 0.04023578989186457, 0.009241623205265828, 0.01986160548403859, 0.03752375666850379, 0.03661375978429403, 0.01911328822773482, 0.01854191594091909, 0.07874166832438537, 0.052148605297718725, 0.12502680825335638, 0.029078455375773565, 0.0501192597273205, 0.01430193381384015, 0.03900363136615072, 0.020545059881572212, 0.0480995866736131, 0.03071811149961182, 0.022634019842371345, 0.01970741179372583, 0.019522768844451224, 0.04162938207654016, 0.021717617587585534, 0.009455069966082062, 0.023556510252611976, 0.02445624938367733, 0.06886706354894809, 0.08422881138644048, 0.009788881205687565, 0.008322181113596474, 0.02485409821383655, 0.034099041151681116, 0.06670464029801743, 0.0529759634020073, 0.06400398949959449, 0.04431131887914879, 0.10865037914897714, 0.010934813197569122, 0.04806172102689743, 0.05296804489833968, 0.0478889897598752, 0.008047586473237191, 0.015304082538932562, 0.07906353141048125, 0.04133136610367468, 0.026479611971548626, 0.04702717225466456, 0.014205791338879083, 0.03861337534285017, 0.02755691184263144, 0.037970504124781916, 0.04466875416359731, 0.011216926854103804, 0.023038686253130436, 0.04296885430812836, 0.027059379432882582, 0.05582466036347406, 0.07953081133642367, 0.02718521035941584, 0.04181058485327022, 0.043850464679832966, 0.03489971925903644, 0.08633505872317723, 0.040283151636166234, 0.026505353893818598, 0.044378317426890135, 0.009931558460396315, 0.06732071616819926, 0.018790163066504256, 0.023017444714371647, 0.011611488182097673, 0.04648143332451582, 0.09534549486956426, 0.035156283527612686, 0.027483087232602493, 0.06293225700833968, 0.046186029711472135, 0.05965350115937846, 0.029704030736216476, 0.026263366253780465, 0.03929153038188815, 0.04496689566544124, 0.040224017309291024, 0.03300215536728501, 0.08912463832114424, 0.08033877690987927, 0.01379571106683995, 0.05634095087381346, 0.017349673934014778, 0.038996964759592495, 0.03067789812173162, 0.019677257697497095, 0.05775042077792542, 0.0661612558843834, 0.014071589834722025, 0.02931904693001083, 0.016833071297566806, 0.032262029724993875, 0.05987862550786563, 0.023303465884444968, 0.03510151218090739, 0.07701782296810832, 0.032559611435447416, 0.01472511574892061, 0.04827345109411648, 0.05061944181631718, 0.04384193888732365, 0.013001381502752858, 0.05296229092138154, 0.009585587873256632, 0.03183977738288896, 0.007895862650392311, 0.04337519500404596, 0.04922686404149447, 0.0302076563904328, 0.05671553613085832, 0.03990405072857227, 0.02163764205761254, 0.06333099811204843, 0.03127080202102661, 0.03062250591548426, 0.02284847422769027, 0.01662436410385583, 0.031025090920073644, 0.034992271435580084, 0.06078765208699873, 0.08541845290788583, 0.03921308494838221, 0.02083868234019194, 0.03801380483699696, 0.035818608344665596, 0.04967478536335485, 0.040502345588590415, 0.017830224308584417, 0.013060144331705357, 0.0648836355124201, 0.04691002318369491, 0.04127361598823752, 0.031662784915949614, 0.027605922427028418, 0.05471030230234776, 0.01600598799996078, 0.023365388990246823, 0.059776818113667626, 0.07658413052558899, 0.07426195298986775, 0.02013163867273501, 0.08502037676849536, 0.03023129315780742, 0.01951895378130887, 0.009091892579038228, 0.0658810752044831, 0.038491622411778996, 0.033369968844843764, 0.019144378702289293, 0.020698047475889325, 0.06235250990305628, 0.050347125357283015, 0.039457062392362525, 0.07422159372695855, 0.03709834574588707, 0.09344613286001341, 0.024798962154558728, 0.015120113035663962, 0.035733238461294344, 0.024768465398145572, 0.036314600479922125, 0.05693379031228168, 0.03780178978507008, 0.05310375868741955, 0.021668871631845832, 0.026100528027330126, 0.04783312597178987, 0.07430615276098251, 0.03275067671867354, 0.04815613917474236, 0.01695907864320491, 0.04150944761931896, 0.05326678690367511, 0.05731199216097593, 0.049725977437836785, 0.018113802752590606, 0.005794250131917319, 0.03964392075847302, 0.04992082216111677, 0.054801266706947765, 0.034194205688046556, 0.01138304325286299, 0.0406610481441021, 0.07957972692591803, 0.12143287967358317, 0.13320453943950789, 0.20047294055776937, 0.07963582820125989, 0.15709254119013036, 0.16038818577570574, 0.06870377409671034, 0.10931632055767945, 0.10798133683523961, 0.0920089278370142, 0.14343163637178286, 0.1194831228681973, 0.09950503667018243, 0.15469355349029812, 0.06910167381699596, 0.05976315241839204, 0.08502373551683766, 0.19336158143622534, 0.0884225649226989, 0.1581746552671705, 0.09685736588601555, 0.12806066045803682, 0.22257346393806593, 0.0771954430799399, 0.1382028998008796, 0.16809122743351118, 0.12199009263089725, 0.17643454830561364, 0.0981932927721313, 0.14403015854103224, 0.09017840999045543, 0.12801920196839742, 0.10876824746706656, 0.0825611555150577, 0.09105895166950566, 0.13927498513034411, 0.15458771559808934, 0.12918906419404916, 0.0983245282300881, 0.1869256225015436, 0.19082695458616528, 0.11901083535381726, 0.24457431052412304, 0.1984945224331958, 0.2286201880446502, 0.19091823111687387, 0.1131033669891102, 0.210590250524027, 0.17300802788564137, 0.0919675100594759, 0.16048060224524566, 0.12468482660395758, 0.06828743857996804, 0.11304003931581974, 0.1340131496212312, 0.1197101471147367, 0.10102777103228228, 0.14047426863440446, 0.15359054053468363, 0.1576376762241125, 0.10753786670310156, 0.12461485607283455, 0.14015583215015276, 0.14427836665085383, 0.08806701257292714, 0.0719376787809389, 0.13847101612814836, 0.146495751238295, 0.13154176223490918, 0.14197106260274137, 0.14903761127165385, 0.1508200549121414, 0.12412342030022826, 0.1636435253811734, 0.12644877337983676, 0.09437812106417758, 0.18752379183258328, 0.1154886686376163, 0.17695574462413788, 0.28567979910543984, 0.16582383481519564, 0.1496862093252795, 0.0834808758060847, 0.0813167222908565, 0.1463668838675533, 0.11737214614238058, 0.11129096602754933, 0.16958382805543287, 0.0835211875715426, 0.06010881851294211, 0.12983888361070836, 0.15742359842572892, 0.12858899496495724, 0.11276078144354479, 0.08115897646972112, 0.10053284758968012, 0.18540488981774875, 0.08173142932355404, 0.10883851655359779, 0.23982000563825878, 0.1420457421668938, 0.11673800088465214, 0.12779341265559196, 0.08950425830802747, 0.1769950318017176, 0.16699198713260038, 0.12856931744941644, 0.14580577611923218, 0.14575913362205029, 0.0924245033945356, 0.12533091407801422, 0.09647493676415511, 0.2567071137683732, 0.11922123549239975, 0.08214262833020516, 0.15151016573820794, 0.14995874970086984, 0.15148777408259256, 0.12965958751738071, 0.09634446805076939, 0.09596058686396905, 0.16580267809331417, 0.07584370632788964, 0.16225896110492094, 0.10340837721845933, 0.10339000249015433, 0.09911229381603853, 0.09166264427559716, 0.20520870786692413, 0.17325080771531376, 0.21958911764834607, 0.10648872942796775, 0.12140295627926077, 0.11713624665779726, 0.11762610822916031, 0.10199853751276221, 0.0946528734639287, 0.17735122197440692, 0.2138076735926526, 0.1650550410683666, 0.17034059816173144, 0.12556666428489344, 0.20456437101321562, 0.12394736760428973, 0.10844970920256206, 0.12942281950797352, 0.08412654937377997, 0.1350629518606833, 0.1287713444658688, 0.1404649591339486, 0.07014724199793168, 0.15818898592676434, 0.054757304423089535, 0.0691193292981812, 0.11949262235845838, 0.14230495611471788, 0.10999761042850358, 0.10305901989340782, 0.17045736046774046, 0.1717068012803793, 0.10507681340511356, 0.1322693417647055, 0.10984956087278468, 0.19921811217708246, 0.11918701018605914, 0.21913836683545793, 0.16570118282522472, 0.10300009591238839, 0.12327934987843037, 0.14647273533046246, 0.12472826641585145, 0.12324736373765127, 0.20485376619866916, 0.1432170428867851, 0.14754172654024192], [0.06717360977615629, 0.04772877746394702, 0.09713093763483421, 0.05701894645712205, 0.026663927527676736, 0.03421075515715139, 0.027048643312550018, 0.022135573106684854, 0.024860076107350842, 0.022974961636854068, 0.03573113500273653, 0.042405263121638975, 0.02762850237611149, 0.07949351905179874, 0.032567299237208705, 0.01829430663825146, 0.03581546333485416, 0.025183679635769556, 0.04159449180588126, 0.019969640133370246, 0.04931891070944922, 0.05966285815728562, 0.013816528521212084, 0.01299085233560098, 0.05937785987875291, 0.02156731529560472, 0.022305454526628767, 0.040677899561290226, 0.04924439738637634, 0.05990234709211758, 0.02418422299836363, 0.04415063839405775, 0.03839152153315289, 0.013167433440685272, 0.021076875273138285, 0.04438939790374466, 0.04025732998603156, 0.04310098882498486, 0.044307580151196034, 0.023426692932844162, 0.04987076324011598, 0.04415580204554966, 0.04261053014280541, 0.011026116869678455, 0.023745967407843897, 0.02933816465416125, 0.03900813344599945, 0.008206543479380863, 0.018937749522072927, 0.066223206131586, 0.029852093862635747, 0.024479887847389494, 0.02857451420277357, 0.011971003176378352, 0.02192702536870326, 0.002414608212088102, 0.008588161751894014, 0.06044920560504709, 0.024192209355533123, 0.022610520478338003, 0.022086917056835124, 0.0464043313903468, 0.060829429488096914, 0.01888040652764695, 0.03034144314005971, 0.024058636344437088, 0.02534444154506283, 0.003627722168208233, 0.07670243989144053, 0.035707382884408743, 0.07256634826106684, 0.05369908495673111, 0.04261115439502256, 0.02647353569045663, 0.020030006001304303, 0.04345089915607657, 0.05728561071945088, 0.017875799809449484, 0.00932771318392562, 0.04106575017794967, 0.032075083149330955, 0.04996637560959373, 0.017148260991754274, 0.023877667662288462, 0.011124006572312542, 0.09500391355582646, 0.022357837430068424, 0.06993513873645238, 0.057658648916653225, 0.06163534588579621, 0.021237045160627792, 0.04117492985512529, 0.04921962746552058, 0.04618213492046509, 0.010392315968471979, 0.0467850200698844, 0.036432475583361726, 0.019387976166659167, 0.07521355085607086, 0.029698890833450214, 0.013113467006145843, 0.05721304818455662, 0.014586351944931915, 0.04823599935376218, 0.04592622204550675, 0.04840694946636047, 0.029350554703601768, 0.02186380117200315, 0.03851020409326468, 0.09692515153437853, 0.03788804515664067, 0.020500788864280497, 0.021374238156048313, 0.016403253290003965, 0.07642810818340097, 0.02177704029184367, 0.05056767977241959, 0.027847630171371356, 0.03279032351981316, 0.005113929293916694, 0.037464666446404796, 0.06118407938629389, 0.03844401300219553, 0.03056763278852616, 0.02115084237552115, 0.06422950739839248, 0.058547950482794216, 0.0237393126756485, 0.03738871802176748, 0.06663528723376137, 0.05559988885319658, 0.05875111743807793, 0.015069324689518129, 0.01888619952036866, 0.03724712133407593, 0.028978958393314054, 0.03111036241586719, 0.02704629049237285, 0.007202402405839945, 0.04741484984489424, 0.03208446389596377, 0.00842820221026029, 0.03155579012153404, 0.05238998395257762, 0.07241921472762312, 0.03683679424492376, 0.031249852252325842, 0.02341356497657086, 0.07695424423686095, 0.048845367905284674, 0.03761562352467861, 0.02524547721259296, 0.10037253690617425, 0.039435773356152434, 0.039528583376003165, 0.01965445213552032, 0.035550654865801334, 0.03918365349194833, 0.10349664105368511, 0.033144881815782616, 0.055589809215494564, 0.028506260365247726, 0.04883123402084623, 0.03313478860738022, 0.07634996809065342, 0.04579107483316745, 0.021550129699919904, 0.008829652365030987, 0.08694072586617299, 0.014867134824661272, 0.031435560501579723, 0.035316546713667255, 0.007893696427345276, 0.07945261696087462, 0.03250834811478853, 0.033182815316000154, 0.043923400408987484, 0.041365218215755055, 0.14559790013091906, 0.06257381409938846, 0.010588132693166179, 0.05294563288667372, 0.04100355226546526, 0.034538066879447014, 0.04961313706423555, 0.013084441822554384, 0.03912326726796372, 0.016316036095044444, 0.03602537153554814, 0.03680496755987406, 0.0125436714650797, 0.02217571354205055, 0.0671224482357502, 0.023542043886014392, 0.020927168395636336, 0.05829438873167549, 0.1024484062301261, 0.05766134270067726, 0.02007827189351831, 0.010949578119574912, 0.04502714618242212, 0.035422133547919135, 0.02428987598977983, 0.062154194473155906, 0.04897627766643252, 0.04926662280091217, 0.03540906496345997, 0.05049434370760407, 0.02680447757510202, 0.0024663011302306715, 0.05295109848624893, 0.01794809432301138, 0.018380083642633896, 0.05574631331754582, 0.017453130168308104, 0.0474239048947181, 0.05508138971137149, 0.04397312345515404, 0.048498158143567185, 0.025113812581236874, 0.013317110632280154, 0.04423241204183016, 0.15148824905710562, 0.023441887028249245, 0.022215397662616203, 0.07154702581465244, 0.03358988204438772, 0.04309001012838312, 0.018497490556910634, 0.00510960999443861, 0.0349103790441794, 0.02673644426145724, 0.015289502517719353, 0.026544116903096437, 0.010792882331380886, 0.023453674877860715, 0.04025805941117661, 0.07095993017511708, 0.02658415216553424, 0.026948539041248814, 0.08954174736780779, 0.013931044876309378, 0.10346783724214349, 0.028438588371500373, 0.08898154885641166, 0.03272186272910663, 0.03940700686403683, 0.04013719196830477, 0.03348150643120919, 0.012783202808350325, 0.040100601967424154, 0.03055242003340806, 0.007868774684279092, 0.020287806899952035, 0.005150551949295082, 0.05330503931535142, 0.023190175981393883, 0.03572664649358817, 0.05889587609895638, 0.05897673711712871, 0.02537859390888895, 0.00944297423120588, 0.03997057430180056, 0.018299266729237776, 0.017230940483776585, 0.030570794761713063, 0.046511953829654624, 0.021259402889492254, 0.03739880444481969, 0.024722766064639603, 0.013629531055422766, 0.017075382938076342, 0.036999910670731745, 0.03433682357094117, 0.050252459544156275, 0.02377771436502891, 0.06285651214420795, 0.020540700294077396, 0.030369344500026534, 0.04709034386490073, 0.02331719095153468, 0.05607574885444982, 0.08437034022063017, 0.02303618754792426, 0.05330006226098963, 0.14286875086171286, 0.028353221880804216, 0.02409538410470954, 0.03508657423247184, 0.021970639903364435, 0.04052900183679802, 0.04119093310354011, 0.016336056270769665, 0.04762600315734744, 0.020462273520284464, 0.06151409846331392, 0.06911353460912194, 0.0536387496228729, 0.049708182856972725, 0.03394614685592907, 0.011702774890831538, 0.025910751960639442, 0.046720562635787895, 0.018837037961930037, 0.04345574728878481, 0.026494259846263697, 0.07379483591232981, 0.035712512609149726, 0.007289845213693167, 0.054079980589449406, 0.016611865488812327, 0.024742776062339544, 0.051831549632229974, 0.045090853835323026, 0.006112148877166743, 0.01884794032334217, 0.018004906363785267, 0.01635223424195179, 0.04556807090661355, 0.066696219678436, 0.02918161984000887, 0.01216678851882794, 0.03300372278317809, 0.02112082568263369, 0.004534205513274563, 0.04117806807958654, 0.04300661138924105, 0.031989682731883864, 0.01830036086695535, 0.032883740828505585, 0.02657936849365277, 0.019298012601211667, 0.026812058507597873, 0.023237983862470304, 0.023602818571297184, 0.04377035005018115, 0.042889285899166546, 0.022590250940993428, 0.02153607045433351, 0.00800502281968615, 0.05082986909630043, 0.0870965039357543, 0.02641303581185639, 0.019951628421300223, 0.056689124155257425, 0.01230344716792128, 0.029181039692567926, 0.0494394083507359, 0.06361793700073447, 0.0342919283014323, 0.026727302698418498, 0.08589549016739641, 0.1218102401388543, 0.17502896301448345, 0.25365107346858295, 0.19053891647074903, 0.09667241759598255, 0.07471404730209283, 0.09265335968562535, 0.12329685608191149, 0.10144413369042532, 0.13247556212757314, 0.14760687947273254, 0.06867142833237137, 0.11991856593106474, 0.16690844590110437, 0.13316427517150128, 0.10587836003729276, 0.1469399066908019, 0.10263665220034973, 0.15864523287330354, 0.1173268471445356, 0.16331595581557068, 0.16907707096210547, 0.12306379287370614, 0.059380886144936085, 0.16734473034739494, 0.10091771943760769, 0.06899819044130188, 0.16868457916591847, 0.12471150660089084, 0.12070494730557714, 0.146967563778162, 0.2594127857259342, 0.18366152979433537, 0.11244139501026698, 0.14529032020696572, 0.12384233038340296, 0.08611526765993663, 0.2496618575283459, 0.1505342423915863, 0.10621910675295762, 0.11842543605182852, 0.1530789387013231, 0.08260987432939665, 0.09409614226647786, 0.15688959136605263, 0.19169352522918157, 0.17224922217428684, 0.12787904377494538, 0.150782599779112, 0.2227599932146924, 0.1429494558168309, 0.15649936587682792, 0.1074896500046764, 0.08238535387707607, 0.1156861630401441, 0.12287483444171292, 0.12893696129322052, 0.18692160557423318, 0.15623085599924835, 0.08252631952720028, 0.09590517090899603, 0.1249211739216532, 0.08802450235400881, 0.0823388606575983, 0.13632092864385673, 0.1264230026198285, 0.1666242890059948, 0.0710281975833433, 0.23390779431377137, 0.087735934981278, 0.12619775613503798, 0.13487758966428892, 0.11820918694138527, 0.22565300869090216, 0.10615502590579645, 0.17226827543761047, 0.07760915266616003, 0.13089226851505892, 0.13355800190142222, 0.19050120349441255, 0.17429941573313304, 0.18812786441828522, 0.14752415248325892, 0.17878991977444716, 0.1093479199334979, 0.07793681044131517, 0.08537827006408147, 0.15557487548461982, 0.08564532109137092, 0.10658191264207874, 0.1588844164673771, 0.1858781272811549, 0.1015179447297539, 0.13837085078869546, 0.09704295199896608, 0.10301582435412066, 0.17982757623706544, 0.11687122445021357, 0.18834437137203558, 0.1743556120033775, 0.08888902382126876, 0.06858087104878255, 0.08010217853422676, 0.11657633313110896, 0.12647021508642606, 0.11690563974635941, 0.15592141688934394, 0.11177164023475987, 0.20999206762228692, 0.1875948208783354, 0.05998114536383322, 0.14144605291741236, 0.12369852167155061, 0.10625238211027213, 0.13417086830096586, 0.1016483727310385, 0.15253472647496633, 0.12339220382273197, 0.12547388140644344, 0.08887686447373458, 0.12371704567755971, 0.1296546749238457, 0.14636839021529469, 0.10156657533454043, 0.10552160668053798, 0.1636827447052513, 0.17226417708609784, 0.10423344865973506, 0.25657762214541435, 0.13469397808824266, 0.2058615128376654, 0.13892133267862455, 0.11108614344682012, 0.11536476814321109, 0.14776972787720816, 0.1131323336490563, 0.11162783830825772, 0.13459382631949016, 0.11162000122879233, 0.1333709162260805, 0.0856169176154903, 0.0849844551246081, 0.08479170368186065, 0.1175302719431264, 0.12135031553251402, 0.12070198889289584, 0.08929742726364306, 0.20393781177699566, 0.1710896465395178, 0.16006669588387012, 0.14651059758450302, 0.16635801829397678, 0.24069224883403095, 0.12076658542667117, 0.13386282697319984, 0.09533935412764549, 0.0999009075707623, 0.09917458333075047, 0.21741647566003458, 0.13380196238202707, 0.08255420731646673, 0.1460052654147148, 0.09303202972348247, 0.15429680049419403, 0.199885844918234, 0.31312211656144684, 0.060794824202145846, 0.26339155222688404, 0.20062939716236933, 0.12905076518654823, 0.14776671518172535, 0.14490203532789434, 0.13416662067174911, 0.17328070396823542, 0.17245385476521083, 0.2637270199401038], [0.07110707727926117, 0.04134915389918855, 0.04391557350754738, 0.08038662041404418, 0.053188711271754334, 0.021831321396997998, 0.024854308559692333, 0.03740750326375876, 0.03133051649534276, 0.07915457723928349, 0.02717531901518149, 0.016178714177970375, 0.01026429167749094, 0.03119146770664624, 0.0209381046837994, 0.06452476512640715, 0.0854883962976081, 0.016854333192376152, 0.07356823914285217, 0.025453371860619103, 0.021500662800722888, 0.0541250149586371, 0.03714179573580623, 0.12181903395269598, 0.04275583841704896, 0.04900791096900191, 0.02871374280325004, 0.02487570616150541, 0.020655471099806682, 0.052210117889834304, 0.008695036954512554, 0.037117466862712584, 0.10228397683905703, 0.09353870539260761, 0.0076521277826811585, 0.06052599541310753, 0.05542253676269736, 0.056167727668902705, 0.031893055952553234, 0.021381671507177607, 0.08078616218907492, 0.03454372246882745, 0.057781273765223365, 0.019361438662079827, 0.0833951293357781, 0.03555646991091115, 0.029831045706357275, 0.04735872821350183, 0.06081419637692826, 0.03886285909850683, 0.12364805223686354, 0.03706173878163099, 0.031798997428268194, 0.029853210052741424, 0.025055383930781057, 0.08767709920981101, 0.05020647183326738, 0.022719727296914374, 0.02311321484324123, 0.024353320710361004, 0.048188271200550456, 0.003805100976023823, 0.049093433522752354, 0.03268688085622021, 0.0670028632240636, 0.06813712950263705, 0.04023764907781567, 0.018452337444094673, 0.021422268257343342, 0.009279292924994869, 0.033891779237559864, 0.06513175541268927, 0.02606825520550566, 0.015034539591787117, 0.03716924926266074, 0.0407195310773594, 0.03957472375727125, 0.026451961669538702, 0.025323113493089165, 0.09851742216518947, 0.019557443680241704, 0.05958919639566115, 0.034540743700095584, 0.05431840083162699, 0.009054241519022201, 0.040726428385823965, 0.05875120564763035, 0.02912403257297618, 0.013128084346785076, 0.04752026704539146, 0.020276166631707122, 0.01386808361192899, 0.009677937337463456, 0.01697998769980456, 0.06573623511940241, 0.04272213897534779, 0.03232320644227522, 0.05083005569343056, 0.03710732276418379, 0.031688905121492486, 0.057343740814498494, 0.04485112402055945, 0.03058140704940472, 0.04558165517768689, 0.07271676590400082, 0.011712185323371418, 0.04455074674582907, 0.029719494549291472, 0.04153431932042752, 0.02490023520242955, 0.08180498930492572, 0.05019419374210494, 0.024419964723555104, 0.005632291456484901, 0.024978076739768897, 0.014537214135218943, 0.014509621508685606, 0.06344970102821078, 0.0737734009910907, 0.03358419252825635, 0.02058296793672655, 0.014288008578919938, 0.0214349653438798, 0.012784147668363792, 0.032256041653454304, 0.053407515066542795, 0.009376399767851191, 0.013633207867055066, 0.03288028708526066, 0.011066605054241205, 0.043071448802948, 0.017963363057268516, 0.03810233669355512, 0.055085715372115374, 0.07383564300835133, 0.010716788869883333, 0.03169510014621275, 0.05068151419982314, 0.03167175514889615, 0.09089493618479796, 0.09046270937791892, 0.0564540898028229, 0.04591693290110145, 0.019302170324538435, 0.03380830246689064, 0.013582207478715904, 0.03819393213572247, 0.060838786486004076, 0.020671856024169495, 0.04353139715801392, 0.022626204815294062, 0.048320585529186895, 0.03549017025423901, 0.010404733159313244, 0.04992636918489422, 0.06295522541872092, 0.044258647598326206, 0.024995493037360053, 0.04250511633498328, 0.0335164916967707, 0.07120180755321469, 0.03788469319364854, 0.005120476732762265, 0.011749970394053628, 0.020588343630411794, 0.10481103123830897, 0.037634870170482566, 0.03264401440641709, 0.014731706020289233, 0.03880075618092503, 0.024652274757889763, 0.034102932550013065, 0.05253723283697452, 0.09311877364026648, 0.02615531803374844, 0.10557798615523747, 0.08302871364035777, 0.01873009236130331, 0.02123230728986008, 0.08766566589474678, 0.02836771708514009, 0.05780537532908576, 0.005175769703263151, 0.021742587676271796, 0.016868158343381116, 0.03882133275536554, 0.011108607220064317, 0.05263830741335239, 0.004836984801970954, 0.04628275487838047, 0.04181422519364527, 0.07144010226641383, 0.047904511248426776, 0.024162516663117067, 0.04548419380028333, 0.023117009550333023, 0.03630807636571782, 0.06901486204671008, 0.04324803075620106, 0.05548999332157629, 0.029613958605165993, 0.034341953295682154, 0.019206296719078506, 0.03065117062734706, 0.0037375413646389332, 0.05760593353105443, 0.01624017587995955, 0.055117111187428236, 0.041172561767910204, 0.01280071579718164, 0.004355397541075945, 0.010144494623611016, 0.01524079218506813, 0.020267981803044677, 0.028443382221407125, 0.0164855188756649, 0.05953962941254888, 0.018580921526466097, 0.025886457014296736, 0.026411705883219838, 0.05447480993877564, 0.00651475805456617, 0.03363907922591482, 0.015732389109741365, 0.0646563194958227, 0.05596772607948099, 0.06594890835029737, 0.07337900251150131, 0.03667153025578175, 0.03217532312763589, 0.02001700866302209, 0.009335419645399919, 0.10462492943874427, 0.0772666824715478, 0.049754089143659384, 0.03249180882370897, 0.017897311065878187, 0.0200422060609396, 0.07124760866697345, 0.0357999282756022, 0.04381516728816288, 0.0696896854788065, 0.010855284652539661, 0.026695611720372523, 0.027935033963461007, 0.027512596720563512, 0.03788654559424945, 0.05235707839684827, 0.01863173531767513, 0.01615858543664217, 0.03987805944468294, 0.06340531805264098, 0.014398475776293447, 0.017131999900032367, 0.03804715483316353, 0.029254111128726175, 0.020747799359794174, 0.026234224871067063, 0.055195549835583994, 0.04607960149379713, 0.0422570032200643, 0.025735778135380576, 0.057763523289135525, 0.03530413291550108, 0.03495776114453163, 0.04054209416998284, 0.05393177157800112, 0.015207871362300856, 0.02265245563882802, 0.05240266577207616, 0.06124852664236512, 0.042002138681709766, 0.048561821691691875, 0.02554501310390021, 0.01692806450384004, 0.04686481239540236, 0.0679028992141996, 0.02739144768565893, 0.04035351232492498, 0.04579821641423872, 0.035372990649193525, 0.010025487214859043, 0.02364503702015749, 0.00967388563523335, 0.0222466492892376, 0.02392389964578407, 0.06786472483405045, 0.03135297939713512, 0.021374497695692947, 0.026889781301308955, 0.02331658366269299, 0.016133499997002736, 0.07095183525234461, 0.031073416184101785, 0.03362705219270928, 0.05329998762213758, 0.02673491755766528, 0.04742700579975333, 0.05033931202654328, 0.024668564687349966, 0.0533171477727592, 0.04898325639909931, 0.026470933508660113, 0.015025001085762466, 0.04704381332599691, 0.018659950500088077, 0.02581787747996194, 0.0036615916677484556, 0.036317419792924605, 0.010360203450545669, 0.0634399436946426, 0.019111970173461095, 0.06234123943639653, 0.041583906659590344, 0.0420181385374495, 0.05903247876891068, 0.04249801207333803, 0.04291303801749434, 0.047191808598914316, 0.01731997275991099, 0.0171446342220796, 0.018095865679372634, 0.013683860506197172, 0.027291156817227602, 0.02152027076642428, 0.03077671317649739, 0.016615366729508554, 0.007096900812549782, 0.06792089396289416, 0.009478213947399386, 0.024198087165132165, 0.025008912763691375, 0.03927601907136185, 0.032902146090886424, 0.02272332353251321, 0.03962704559255924, 0.053429889758782725, 0.055406628509185145, 0.04453455011493393, 0.04189038057146328, 0.12443910193230424, 0.034686289461595674, 0.011770104224394475, 0.020863696533654417, 0.03888533557099955, 0.02383170200378767, 0.06748065365744488, 0.009946177497373095, 0.04018430943999972, 0.017538023380828754, 0.02975200655471001, 0.08219588654381887, 0.1125435484573245, 0.06798404521707978, 0.12854802502053125, 0.20808987612170832, 0.12227629870176315, 0.10862388235649892, 0.07563454790839128, 0.08058344985225371, 0.08592111843505076, 0.11301445854561669, 0.07688220417393105, 0.10642029238598687, 0.0804000621927636, 0.1447366356317486, 0.22045306914619037, 0.15983564113931997, 0.22478132189384528, 0.07524431563381638, 0.1538349488484008, 0.2539624124765396, 0.16395706284259046, 0.18749082860137734, 0.2015069465019873, 0.28493840460266384, 0.1001704488215702, 0.18413691142840044, 0.08103325750146594, 0.07163767809314386, 0.11417445487209729, 0.15461873821914196, 0.11469430769128458, 0.16440207324922085, 0.1792261227965355, 0.16573124192655087, 0.12927597095923765, 0.14051764059279645, 0.12745152600109577, 0.13163316090192112, 0.13776299197758946, 0.08666298112698964, 0.3091226140303271, 0.11746653036347457, 0.16448664585394518, 0.11698079428502492, 0.1297900155186653, 0.07605872728994914, 0.10153068083205394, 0.10870645328291825, 0.1813110573483365, 0.14364856401724474, 0.38559413488422123, 0.22714258304664067, 0.12588947053466523, 0.06650287112487213, 0.10379548823194844, 0.23571771862251417, 0.19144231799457753, 0.14030394277402333, 0.10262601955660752, 0.07263878865965775, 0.13553032678152832, 0.13467938958534173, 0.13922104159636156, 0.12133449209587914, 0.11590930606637682, 0.22108713297971658, 0.14096315311534063, 0.14454275103552, 0.11424728882099901, 0.14033238696200506, 0.17548629561705248, 0.21661775851888315, 0.15552450104483537, 0.0744319667241403, 0.06830085321728672, 0.11971478829426424, 0.12900596830461705, 0.10164037280316864, 0.1739570541041238, 0.1750766775969948, 0.12106581936989512, 0.25388142253671375, 0.18034525774419308, 0.10808709330324616, 0.17846826703420707, 0.08351305193666901, 0.16650044279439108, 0.13167251593300275, 0.062471212819218636, 0.10848673007317952, 0.11348971804337842, 0.19549732469022274, 0.1568895642246519, 0.10843216907233, 0.22043773425476892, 0.15108765555279596, 0.09247741555528981, 0.1002202465065888, 0.16338193656078406, 0.14593405994985784, 0.15060569212904998, 0.16301406201507362, 0.10244498641363212, 0.11818287335336208, 0.16356809942850045, 0.1214603739125388, 0.1690311205706426, 0.11482071876525879, 0.09473846387118101, 0.09864365682005882, 0.14601935180170195, 0.12429492681154183, 0.13995380513370037, 0.11077927598463637, 0.12577680658016885, 0.1276841549468892, 0.15047599694558553, 0.09259864262172154, 0.12007499539426394, 0.10282489138522319, 0.16631636981453213, 0.08903659161712442, 0.119491808116436, 0.07514711549239499, 0.2255465465464762, 0.13254729684974464, 0.13711501817618096, 0.06289156526327133, 0.09389366063156299, 0.1116268408617803, 0.09883719536342792, 0.08749664282160145, 0.16090742791337626, 0.2112469095736742, 0.10447537353528397, 0.0805524272312011, 0.13541730998882226, 0.08073971646704844, 0.09787423203566245, 0.1889082882553339, 0.2516229865806443, 0.12975340176905903, 0.1539165766111442, 0.07816371933690139, 0.04837310074695519, 0.10153796829815422, 0.08208058308809996, 0.18051285589379923, 0.10840253066271544, 0.17191994270043714, 0.07358825592590229, 0.12329233703868729, 0.16819311625191144, 0.1499313504568168, 0.09071304808769907, 0.1393540073186159, 0.12860058434307575, 0.16331112464623793, 0.12877302723271505, 0.12659426485853537, 0.175719983077475, 0.1457395511014121, 0.06821663345077209, 0.07247483424310174, 0.22416677272745542, 0.21405894868075848, 0.06953388026782445, 0.1273810669247593, 0.14190626250846045, 0.12316754087805748, 0.08930509470935379, 0.07248313951173, 0.20718967728316784, 0.18225544238729136, 0.09005172071712357, 0.21805854620678083], [0.013645933791329818, 0.03293590320806418, 0.035963869121457846, 0.03708893446517842, 0.03265539343867983, 0.028415278997272253, 0.0764543471325721, 0.03687299069549356, 0.058904140655483515, 0.019202016859448383, 0.043674744466053586, 0.010322362400724419, 0.04117649727101837, 0.08297706355473825, 0.04393327309350882, 0.0278962794358709, 0.07238676718303136, 0.037573954689183404, 0.023052211152389646, 0.026947921574381844, 0.042673063930124044, 0.033225658017077615, 0.05184394307434559, 0.04719509270840457, 0.012701155202064131, 0.025016765110194683, 0.06857897793608052, 0.014733724661969712, 0.012843634833448699, 0.04200736000867827, 0.03305661119520664, 0.028587830452514545, 0.03201091069994228, 0.062232646692012034, 0.017180118210879818, 0.05899475222187383, 0.04612922615238598, 0.008222690068318375, 0.05405288668615477, 0.04911300586536527, 0.012566138607715922, 0.10536056996456214, 0.04364986937226994, 0.0785864262974688, 0.03779948955135686, 0.015469563659280539, 0.04357093200087547, 0.011500374680118901, 0.017268599177311574, 0.07116363317306552, 0.035716665243463855, 0.03212067052455885, 0.04328535018222673, 0.021284294946651374, 0.04606134890179549, 0.06815981292831046, 0.03305523716179388, 0.04478808133197682, 0.052328705455043485, 0.019545973045751452, 0.034809494457606754, 0.013848785227829856, 0.052136466306235106, 0.030475779503051723, 0.11434670777193137, 0.033299234961824756, 0.007992896550734128, 0.051612399784582, 0.07732510433665343, 0.04500267142429948, 0.02110788262715297, 0.017631259181403687, 0.019332337991467545, 0.03455858238573585, 0.018785489656563317, 0.04849588844392981, 0.03792780730873346, 0.03690944838204554, 0.04317760221394045, 0.011738280932019864, 0.02335155026854149, 0.025870896509981582, 0.021257353713735938, 0.04731760899137173, 0.025618778342115026, 0.07728958981377737, 0.03281862521544099, 0.02223569943037416, 0.03880213699968798, 0.01933769672177732, 0.015692764360989844, 0.07751693297177553, 0.013581876692894315, 0.028683140873908997, 0.01897192733096225, 0.04283375459324036, 0.035674741957336664, 0.06954247052116053, 0.022325350869713084, 0.017599354464826838, 0.05783664222274508, 0.10987742152065039, 0.016425587270142775, 0.0671766631837402, 0.03978272866723793, 0.051289573178759644, 0.041090269040848525, 0.028676840676260845, 0.042232348650161705, 0.03762752163623061, 0.0226152651344559, 0.04523305781185627, 0.025111078085111718, 0.041467022217277966, 0.009097930692535425, 0.03784174871231828, 0.006314910831861198, 0.05070125956886581, 0.01631550005237971, 0.019743776181712747, 0.009343169363481658, 0.020044594504205242, 0.012963143509945698, 0.07459516796682562, 0.027726201240771582, 0.02798718786133187, 0.022947747293593626, 0.02186250008110489, 0.020702961765761887, 0.04422551134069051, 0.020866890737254704, 0.03842452547645994, 0.016069924658430473, 0.0585495653961386, 0.014541834958695939, 0.051013599415974956, 0.03656529542058706, 0.021437806709270393, 0.06380800823015825, 0.01946844193818314, 0.016585275397769043, 0.04417514029358115, 0.09359592625073024, 0.040087804796972444, 0.02771422509769244, 0.022729962997670685, 0.020672402244859507, 0.035895717064184804, 0.042594679564769776, 0.02571414813532361, 0.02689734866310443, 0.008002157705569906, 0.03308444809434669, 0.01862554538196751, 0.013948921729544443, 0.06311039959213563, 0.04452620752687965, 0.046654751524329185, 0.08268085587769747, 0.038569894818855185, 0.013879807000713689, 0.027157554968393276, 0.051670255072947056, 0.027040166713829552, 0.03168337166841541, 0.016629110456311276, 0.04325179323287947, 0.02635383532781686, 0.00880081971575107, 0.019456587931407348, 0.07667623486902032, 0.019039409334904382, 0.07241728768817016, 0.05058075174955385, 0.018990101891436746, 0.05315339691670878, 0.03977270670501249, 0.024149843325306262, 0.07901151491595165, 0.003525729237091062, 0.04367894459781902, 0.007159981244642819, 0.039148478236581595, 0.0627551254417215, 0.04902924410998821, 0.007988040784506925, 0.03521241194435528, 0.04907354905403086, 0.07622221351734229, 0.04569132000740085, 0.038130899625165124, 0.039795970278126855, 0.04336095255400453, 0.017095991742930243, 0.009402594612246113, 0.059583863110414574, 0.023538820844675814, 0.01484339458069631, 0.027139967340709906, 0.06423453534288065, 0.025776868519772376, 0.029042001081896678, 0.02566789579577744, 0.04917333780654839, 0.019491128756531646, 0.023687886506585137, 0.02274110963168953, 0.05389506283349224, 0.033210275628204854, 0.055989727577460666, 0.029419717778052603, 0.04191163228824735, 0.020039839670062065, 0.03912524180486798, 0.10555509916905846, 0.0813637583383492, 0.023352873411827853, 0.06460432335734367, 0.030415267750088657, 0.04784856264346412, 0.015884594692449485, 0.050171493353056054, 0.02367371360638312, 0.018678457542721714, 0.04280755635617035, 0.07950983781899724, 0.06278521168444838, 0.019737326706360494, 0.02980596705206803, 0.029660007384206568, 0.01886661021438028, 0.019500825021948134, 0.017479973013645837, 0.014176719506005091, 0.01664942579476961, 0.013335281800079559, 0.01795917310352836, 0.008528132606962962, 0.025081851885520985, 0.034021705122930665, 0.07816671846168381, 0.09054806908326489, 0.06117000657000712, 0.07442127979759659, 0.04605169674115522, 0.03578377574948328, 0.08926730030881506, 0.06237013824284077, 0.022438649254451905, 0.060413657155420096, 0.04422356394518699, 0.03775628722671952, 0.04572433752140828, 0.023697660803528767, 0.03880030495513763, 0.04263809902061309, 0.028423535072111657, 0.048277630869831355, 0.08513935788401536, 0.043057243672332594, 0.023693280859983394, 0.06434635791395392, 0.03432103406105723, 0.0175096368683236, 0.01616155742002385, 0.005938300147785672, 0.035722802592707534, 0.04865888612610953, 0.02630316572529929, 0.03666930805359568, 0.04170829909188407, 0.032095530802117925, 0.0939914918105517, 0.06203939313335078, 0.027583849682871784, 0.009159573054473315, 0.026731633448175023, 0.08031890940453325, 0.07773392847073929, 0.07538315068398203, 0.04366015935582774, 0.018271009138386165, 0.054398060842816315, 0.029097437392920256, 0.028013426810503006, 0.030216799649809088, 0.07729370173599039, 0.04127446754968592, 0.04817022895440459, 0.024340552377647588, 0.03453599734764014, 0.04175148445314594, 0.01787568106582122, 0.08327513041773013, 0.032048742419907024, 0.018044771992468407, 0.025313907469223653, 0.02071453078782984, 0.015804234093853405, 0.011700467871768134, 0.029228730526353632, 0.037660912344498296, 0.024038336273016672, 0.01594427184733961, 0.0224284101610205, 0.03933433237086449, 0.018382850369172435, 0.020371063146740198, 0.01108496027466442, 0.023040363930964043, 0.044297500513494015, 0.018325665134138296, 0.01701082881273968, 0.060776401976389546, 0.016296149929985404, 0.02560673943454666, 0.03652378264814615, 0.049146732448467186, 0.10453633990670953, 0.0822873462789825, 0.058228536908115656, 0.07032860083771603, 0.06959933854107346, 0.036335194017738104, 0.02667086385190487, 0.03556488713781748, 0.004850688664841333, 0.04715261980891228, 0.040768819861114025, 0.04459394907046642, 0.05563475537512984, 0.03347945725545287, 0.03703814951170768, 0.045077330632401366, 0.019556000096989528, 0.026755392351852994, 0.04814197814890316, 0.08762517771018402, 0.06131843610533646, 0.02201567596888968, 0.034932478929736784, 0.01083276916428336, 0.046133107372692654, 0.030242845216499906, 0.022618422018630163, 0.07051224634051323, 0.016366071267319576, 0.01906507322564721, 0.06929481881005423, 0.017651605053937862, 0.14646798558533192, 0.03227530186995864, 0.15197032104645455, 0.11131716426461935, 0.19924323154347284, 0.0936078413256577, 0.12737053606126988, 0.08225327703569617, 0.14697620831429958, 0.14471190981566906, 0.11142241183136191, 0.10843184337552104, 0.19903824611433915, 0.1506464856543711, 0.1337007520986455, 0.14824276178010873, 0.15069040044077806, 0.1265777764575822, 0.18368316149072988, 0.09160449382449899, 0.06252304610929318, 0.09557378119123833, 0.10706988110073976, 0.11766322409468037, 0.1368387865700892, 0.11995188200048038, 0.1722086322094713, 0.15146213902958802, 0.12080946883984975, 0.13295544923416205, 0.17494272121361323, 0.16896953673235007, 0.12652518999363693, 0.14552996520485195, 0.13560079942856515, 0.10240272725267069, 0.09774861484766006, 0.19149417164070265, 0.11256600796644177, 0.12186913697847299, 0.2133112980851105, 0.14763867562370642, 0.11202674226037093, 0.15917827641325338, 0.08063369537038462, 0.12369329695190702, 0.12038495019078255, 0.08739477435925178, 0.1201531354870115, 0.1196774145854371, 0.10831784949238811, 0.12068110358502183, 0.1666017887847764, 0.1103273309501154, 0.08765735384076834, 0.18644027997340473, 0.1706293419535671, 0.1941618320665189, 0.07096324142600809, 0.12186620570719242, 0.06974995295916285, 0.20615603774785995, 0.07857259096843855, 0.16192654679928506, 0.127954239025712, 0.1495775215859924, 0.16197669053716318, 0.11667577922344208, 0.09587619067834956, 0.202009238834892, 0.1926442477852106, 0.07527503969946078, 0.19008878991007805, 0.12967708015016147, 0.11478246296090738, 0.14944143460265227, 0.07244413053350789, 0.129334528531347, 0.23734354280999728, 0.12737225954021725, 0.146144337952137, 0.08236357290297747, 0.09533761029264756, 0.11631843554122107, 0.16234516219369002, 0.14796186185308866, 0.14437636067824705, 0.10823426076344081, 0.16366427498204367, 0.12377561682036944, 0.25708921040807453, 0.10734584807817425, 0.12319418016288962, 0.23258209973573685, 0.09942401280360562, 0.15371666662395, 0.07264884454863411, 0.14268380935703004, 0.15534306078084878, 0.09178354564521994, 0.17053939535149507, 0.08036591831062521, 0.08045959685529981, 0.216484399246318, 0.12768659767295631, 0.1712459810078144, 0.14842321138296807, 0.11601340690893786, 0.14936655147799424, 0.15740115248731204, 0.0991444428052221, 0.11777402886322566, 0.20737575872668199, 0.1205676118178027, 0.1611110427017723, 0.08397014026663133, 0.08068298415413924, 0.12203528306313924, 0.06750417168119124, 0.20049933556999477, 0.08518639393150806, 0.14406962213771685, 0.1411256758230073, 0.11084290221333504, 0.10541928359972579, 0.13249278334634645, 0.13163481652736664, 0.2601100211696965, 0.12370774974780423, 0.16101665848067828, 0.0867755568719336, 0.11944861257714884, 0.08566638281834976, 0.09683264685528618, 0.12397752170051847, 0.1297919832702194, 0.12078261242381164, 0.14087383076548576, 0.15203304482357843, 0.1104760861822537, 0.10934023213173662, 0.08957714653973069, 0.10383706207254104, 0.18927226801003727, 0.2171305545738765, 0.1822850943676063, 0.1770956992570843, 0.09530841293079512, 0.17383257006960257, 0.11960148651685033, 0.125254022489701, 0.14850117505661078, 0.06839860297207322, 0.11387294105121068, 0.10552206129900046, 0.08420335275254079, 0.1679289625691516, 0.09622383130980389, 0.15999824527118886, 0.11693568527698517, 0.17615134135953017, 0.1844532173126936, 0.12873312937361853, 0.14385645357625826, 0.18140565870063646, 0.11700755570616041, 0.05828425820384707, 0.09944589555795703, 0.13627367546515806, 0.07478027231991291, 0.12138479868216173, 0.10998087775494371, 0.17877225072256156, 0.07775217427739076, 0.09323768011693444, 0.1165779751858541, 0.18090741043644293, 0.10542942769825459], [0.039030196012130806, 0.03893280927357929, 0.020634087068693976, 0.0022211510929212508, 0.00630602626396077, 0.041175594819443564, 0.01635297723779721, 0.04189210744308574, 0.022538543179897324, 0.018799509886386137, 0.01913916246433343, 0.03721049740644438, 0.027568930394149253, 0.035543937369116714, 0.04054839776030608, 0.043075486086308956, 0.022874859061890414, 0.041141512005456855, 0.047890625029270134, 0.07010658417961427, 0.023524089849420955, 0.030168301359351193, 0.02015461726114154, 0.055631118427429876, 0.11129406693258456, 0.04083640194897141, 0.01875215153475957, 0.012402397081522005, 0.05233365197532943, 0.02372466480093343, 0.06702145508357457, 0.07871154815490757, 0.04462135170719453, 0.04929178627207875, 0.025002200356019393, 0.07926794008484908, 0.009733147187424558, 0.028404296907995428, 0.06201490480452776, 0.03595777926966548, 0.04278750903904438, 0.021470130421221256, 0.021918932142268335, 0.03640317304858139, 0.039678488724998066, 0.00889520563318261, 0.019567374040239623, 0.026109832438773344, 0.04621798871085048, 0.028446023418967212, 0.011655212978699377, 0.0330137074259775, 0.024078698928600976, 0.05050611968285271, 0.07565158592270953, 0.00949991010462067, 0.01823744031467608, 0.053931232142661295, 0.03408892758722816, 0.05845912346350295, 0.0228414564792599, 0.0047924453392624855, 0.04505549876817635, 0.07786996117127792, 0.016504141269251704, 0.02301517840740936, 0.0369705674238503, 0.031297207211277316, 0.031135804086391414, 0.08267176350844757, 0.05860538847212281, 0.034110396435218196, 0.02609443647920021, 0.01185402543550091, 0.04011243901082447, 0.015588446387222834, 0.025411194123859917, 0.04436375267271485, 0.016201887845194766, 0.020918165932276418, 0.03102340136787721, 0.005966972493167434, 0.024199717345514467, 0.025835203871663128, 0.008187790467802967, 0.05699992712054934, 0.008013115197952305, 0.00458599893941677, 0.038481651339679956, 0.07206069717981986, 0.08440330345183611, 0.12365201488137245, 0.02120938976960523, 0.05630942274417196, 0.030159107209848504, 0.08519840400133814, 0.021007113391533494, 0.019519659457728267, 0.008477876062637993, 0.020458144634695988, 0.03882215378273811, 0.0912317813241056, 0.09015029149928264, 0.03977356165913599, 0.03187784319743514, 0.05640166957995721, 0.07288608753255435, 0.046400456955390315, 0.041526872398597856, 0.010517252925118166, 0.1052763027005962, 0.010798480245284736, 0.02409030357375741, 0.004467791353818029, 0.036776021255978515, 0.03378524584695697, 0.0471640022338501, 0.1007058604487351, 0.01314556595337178, 0.04180951276794076, 0.029987716049488102, 0.030990987750036374, 0.044903269436742575, 0.027192657281245505, 0.01833459465498371, 0.027023371275780455, 0.01902309396038098, 0.035750734486750195, 0.06903656838195664, 0.04910799827692764, 0.015261660529566663, 0.0161096477947597, 0.040510820490973334, 0.027228180285809294, 0.015148681056286608, 0.08273633290082216, 0.08614808161343847, 0.04480886485959802, 0.07242891777838979, 0.02636757057293185, 0.038759470717715364, 0.07700651857469763, 0.08274825476109982, 0.04521629799689565, 0.028172931733674238, 0.046921951829322746, 0.026512305485084653, 0.04100416973233223, 0.04526064704571452, 0.0178256391081959, 0.07210608438721725, 0.02558383039597954, 0.005045165706958089, 0.05738762845950467, 0.02797320664727262, 0.0268025556246617, 0.03504101399864469, 0.026235587030117, 0.017252723154212748, 0.035373492765107324, 0.006239613376757396, 0.02584034377442939, 0.032378690250750096, 0.04127408417740038, 0.03323629405349493, 0.027902652576033558, 0.017813361017033458, 0.0649682352585452, 0.023506809258833528, 0.03173781053296157, 0.04242788547916072, 0.02311356089610074, 0.030928294506988356, 0.03510807700721281, 0.02183713813844536, 0.02764055485438023, 0.07612882674272571, 0.03428366035223007, 0.04171442626310246, 0.011724664430533136, 0.03795601061678358, 0.0884295945454921, 0.06339266337454319, 0.05534944497048855, 0.013454541963125979, 0.08331075350620917, 0.042994072062096426, 0.07589311724794762, 0.023813013453036547, 0.06434407125094108, 0.0476092026302857, 0.05801649471478803, 0.034776890849960704, 0.05116736902190106, 0.06485884184283869, 0.09007491304406098, 0.06033411928053413, 0.030916657631418536, 0.0223728347503181, 0.019807851939861263, 0.016841607268101404, 0.04865671481404986, 0.036535592550145726, 0.0193498560693115, 0.013026666262054017, 0.04614933453766363, 0.025908387266099453, 0.03287210056026067, 0.050014497313116274, 0.05937864697937455, 0.031466769719762464, 0.025183803468410457, 0.04437720802213464, 0.04032066444467221, 0.048059447934584956, 0.030756570864468813, 0.01820929637844009, 0.03411839297041297, 0.008666692850446063, 0.00609059860497447, 0.017908376275694797, 0.028715551099074737, 0.021535420757053152, 0.03354721236974001, 0.019168705879045383, 0.06036936238940273, 0.03143108895580683, 0.02361974462733737, 0.04795594420284033, 0.023245407035574317, 0.021729307049619298, 0.031452534055071216, 0.043869300811950646, 0.004851225979759225, 0.04111760721674987, 0.019359321632821645, 0.019430856187162653, 0.031426132257495604, 0.04390606383926102, 0.07533470328365054, 0.03082194771351559, 0.0557702214989279, 0.07650172923292432, 0.057562880484121184, 0.031793837169451375, 0.0166997103286641, 0.049877317888396125, 0.04850313180525388, 0.03673167220715966, 0.02843984535762242, 0.04207196332780378, 0.009382067231594451, 0.062169902558837614, 0.07998314313590527, 0.008544638819460357, 0.021190538370449628, 0.05326394044927188, 0.031984203561608276, 0.07485413764204298, 0.040441002630229504, 0.018460956535169055, 0.02538419691180544, 0.05486866559035011, 0.03475839398535235, 0.028929428729627813, 0.01820958814849811, 0.014572033159700888, 0.08037668666137116, 0.029133603309414217, 0.06844968308827706, 0.03720295209703701, 0.04052067281944411, 0.035816135084522624, 0.013225449032948484, 0.08625352595533643, 0.03883543610572815, 0.02793944444108222, 0.045234767720103264, 0.030684340811733688, 0.014535387179681232, 0.011342408335102456, 0.026747628214902112, 0.04160664097539016, 0.023653522100565687, 0.05557270674034953, 0.04054193471425346, 0.07393737576369729, 0.05618709984368511, 0.06274540203490428, 0.040757284765797, 0.05517136684751936, 0.052696888734187396, 0.027101507975852916, 0.05861486082098313, 0.021462313697806427, 0.03205324789243085, 0.03748619296987142, 0.006264129695149937, 0.05768610244350774, 0.016861116846225092, 0.06488709604101521, 0.06326074938156775, 0.056570818182080984, 0.07050850761256047, 0.06411549994455916, 0.026321983197703958, 0.022219275490247777, 0.030164705123752356, 0.0254346222417163, 0.06531205573784453, 0.03858825258378472, 0.09685732517391443, 0.04741385918376701, 0.01023444122568305, 0.01894212268026812, 0.004065718219083334, 0.06465535597609622, 0.03203730231949261, 0.06857224686869554, 0.021193813998252153, 0.029041777165340524, 0.012723367045899587, 0.03598218956696136, 0.01902861723543278, 0.021982112234192233, 0.0032215067892268833, 0.027590541734493206, 0.03946274173046861, 0.02081865368277899, 0.02153018077037164, 0.025140421331993172, 0.029543818440288305, 0.02808457120720829, 0.029398781580052206, 0.0565350627792733, 0.006551359505725226, 0.06714294677866356, 0.03375477283926947, 0.013441423336709184, 0.031556339734899144, 0.04274348907970956, 0.03400062303990126, 0.02630005803491388, 0.07126388672207083, 0.014735750089000379, 0.07729449562196221, 0.02569542565782155, 0.05602156783321074, 0.022762398667899624, 0.049885158360536606, 0.017407429138464586, 0.03899117685588343, 0.13669330866209098, 0.15666955603020533, 0.16828774474561214, 0.08068425301462412, 0.2557927742600441, 0.12575085940105574, 0.1259351223707199, 0.1030890518533332, 0.07278586791029998, 0.17378492334059306, 0.09369909750031573, 0.1671712018017258, 0.12285331131092139, 0.12992864022297518, 0.10652171301522426, 0.18792994932404586, 0.10580332763493061, 0.14248521572777204, 0.19804120675793715, 0.15001751083348477, 0.13909760250576905, 0.085909956533994, 0.10071810122047152, 0.24439740287406103, 0.2228923211140292, 0.11255623027682304, 0.10959064548036881, 0.09796829734529768, 0.13289637597543852, 0.11114400212786027, 0.16152028074221952, 0.19853049835988454, 0.12402512771742684, 0.13659502964998993, 0.10449228941329888, 0.12473156409604208, 0.11630508197205407, 0.11317407033805336, 0.08817515069884913, 0.12248798805688109, 0.12955189043922083, 0.08538519112127167, 0.12376648373901844, 0.1282675593559231, 0.10017873373414789, 0.11853592869426523, 0.08501747263861553, 0.1274908131786755, 0.11036851802574736, 0.15704918280243874, 0.10651749252740826, 0.1635675294590848, 0.13949863027249063, 0.14612695388495922, 0.15375923791102, 0.15103901816265924, 0.09476017699177776, 0.1820354884756463, 0.1092230627047164, 0.12373205487217222, 0.07857356127351522, 0.11418799843106951, 0.12288874440959521, 0.11512683305357184, 0.0879020607098937, 0.16706554032862186, 0.1788838833038296, 0.11662653115178857, 0.08640438464603253, 0.1490563116967678, 0.15851236214595182, 0.10286342538893223, 0.06709688782159771, 0.08807297689574105, 0.10688428141708885, 0.1288681307009288, 0.11146582450185503, 0.13573121385914938, 0.11306212563067675, 0.08979530911892653, 0.10819524499986853, 0.09845177390213523, 0.18095432434763226, 0.08823053272707121, 0.1427278055676392, 0.1305948666163853, 0.11027122288942337, 0.19148355935301098, 0.08260370644607715, 0.10888875528637852, 0.2040904550147908, 0.253914725035429, 0.11270473445100443, 0.10452065896242857, 0.16181580988424166, 0.18171923687415464, 0.13970399568123476, 0.06789295189082623, 0.23335562965699605, 0.1726420803793839, 0.11088881867804698, 0.1547150630503893, 0.2291674129664898, 0.15590486063488893, 0.06195661186107567, 0.13647153627659592, 0.1327856933431966, 0.16234285517462663, 0.10759850737771817, 0.07089249057961361, 0.1563475640224559, 0.13072388326483114, 0.13043295459023543, 0.08031707735998289, 0.0903326477855444, 0.13980849007410662, 0.14775237095143112, 0.19730517268180847, 0.12470060932849135, 0.12462895603052207, 0.09033457482499735, 0.08400818572512694, 0.0778230879721897, 0.08428868531648602, 0.15157347305544785, 0.18921048061123916, 0.11224046043519463, 0.10535079227494341, 0.1633913139147418, 0.2112130235348429, 0.06729864342404263, 0.10936147027782031, 0.09618786216846534, 0.13770215452781745, 0.14368383426751408, 0.14534978701600007, 0.1287035723882062, 0.09417351561465434, 0.0774460599890777, 0.1013320872027959, 0.12652715774519102, 0.1668684259057045, 0.22854598345501081, 0.09273446497640439, 0.09112782297389847, 0.14376291073858738, 0.11693947150238923, 0.1578404496290854, 0.1356892939656973, 0.06840295916689293, 0.1719400409076895, 0.16591534204781055, 0.07427582224564892, 0.1865199671259948, 0.09456129159246172, 0.10135480455522027, 0.12538009429616587, 0.09661749697157315, 0.16185512420322212, 0.13187941483088902, 0.20068479276129178, 0.09680153602468115, 0.1037334090630923, 0.1145031236644302, 0.13137234561145306, 0.13030217375074113, 0.15057148039340973, 0.20692100455718382, 0.09168171789497137, 0.18249951143349918, 0.09161014602120433, 0.102297947875091, 0.17160487174987793, 0.13540284362222466, 0.08925261002566133, 0.07980268674769572], [0.02269714225881866, 0.016240784865138785, 0.061674809482480795, 0.09339785509343658, 0.03265165471072708, 0.08585553802549839, 0.007866125853200043, 0.040194175339170864, 0.03940092379759465, 0.023060648735346537, 0.006057978882121721, 0.011903809549819146, 0.061464952171913216, 0.06755507537829024, 0.013684587386835898, 0.01677703787572682, 0.0492470843850502, 0.04511901303859694, 0.03293560465265598, 0.09474482852965593, 0.04003168995093022, 0.028184434598577873, 0.006488926226406225, 0.021151587067704116, 0.039563548285514116, 0.010288352529252214, 0.02770408269550119, 0.06300319784453937, 0.06274912719215665, 0.049419279609407694, 0.03181319238085832, 0.07736464935754027, 0.038917966320046356, 0.003030940017197281, 0.03572251082264951, 0.03952971313680921, 0.03224050998687744, 0.013440681189032537, 0.05179833534306713, 0.01871316969793822, 0.059129719622433186, 0.07376389471547944, 0.06108927447348833, 0.016640321551156894, 0.03325147966721228, 0.013192100733119463, 0.011723823895278786, 0.04543533927894064, 0.06202461464064462, 0.057043204084038734, 0.05373903370595404, 0.08781646351729121, 0.022976325492241552, 0.03565982775762677, 0.050530960849885426, 0.010178833584567266, 0.03760972027001636, 0.021132384526676366, 0.020863973036674515, 0.029396993640278066, 0.039600067040217776, 0.051337355614772866, 0.050098764577082226, 0.031142908348036662, 0.056047104498637576, 0.03690678173942225, 0.05200679826417139, 0.031510545406490564, 0.020981403699676906, 0.0393161544177149, 0.04484247609174677, 0.04242290163944874, 0.03747654080923114, 0.03053047621090497, 0.035974535691951, 0.03608785104006529, 0.027369130668895583, 0.009376324280830366, 0.016838874468313794, 0.029845413685377156, 0.007298216639485742, 0.015607833829043167, 0.019204395124688745, 0.03720078757032752, 0.08970443970922913, 0.04564064361953309, 0.03472494220893298, 0.03391834727621504, 0.0407834422907659, 0.017807420442945192, 0.055290622769721916, 0.05449505063838192, 0.05308944499120116, 0.012150075353149856, 0.016809943431456174, 0.03114922550906028, 0.022797014131875973, 0.06441798407052245, 0.01152014294971845, 0.028850891693894352, 0.024962595963318433, 0.016791986002187644, 0.005273053389308708, 0.027097801478313546, 0.024437365754108344, 0.0485695909176554, 0.03412288147956133, 0.078310411822583, 0.009163782516095256, 0.1037757292922054, 0.009879548751216913, 0.0823586331680417, 0.07924685121646949, 0.04916523609842573, 0.027577505380447422, 0.013849494296924343, 0.021283937019429038, 0.0379126793704927, 0.05209820032385843, 0.07170346884855203, 0.050893780309706926, 0.07104970035808426, 0.058096555061638355, 0.03256723477638193, 0.03711504449269601, 0.02465041896461376, 0.01972922499823783, 0.05112452971349869, 0.017999883508309722, 0.03364443286721196, 0.01163320045452565, 0.0402505344578198, 0.01453735662757286, 0.02221907701875482, 0.02655202353240124, 0.018784047769648687, 0.04882594144770077, 0.016647006817428128, 0.05165869962157948, 0.03156578154968364, 0.10097295218812567, 0.037880052014120986, 0.04527835002435105, 0.01014247683009931, 0.018333546318379895, 0.02023559363026704, 0.02538621555348592, 0.03429849312773772, 0.05886823936764683, 0.011119956566419984, 0.042233583583895645, 0.03422624271895204, 0.04432528991518276, 0.014912357487316643, 0.07813431841454335, 0.05352412470217262, 0.039023322452391894, 0.10401290442262377, 0.052853263914585114, 0.039885581005364656, 0.033151663773294, 0.044747735639767985, 0.0265563848162336, 0.026430016150698066, 0.045269824231841733, 0.030470768521939005, 0.04292160452210477, 0.04264650267681905, 0.03314043741141047, 0.022138348314911127, 0.05048412157754813, 0.06643997092864343, 0.022102589519428353, 0.038608856299625974, 0.0173075691397701, 0.011916889160472368, 0.015950354913781797, 0.017179929917412143, 0.03705828843106117, 0.07589986867138318, 0.05188349148790751, 0.038552534500403066, 0.05013182280319078, 0.02448924145262156, 0.009996036250543381, 0.013293757153275822, 0.01791220830221261, 0.024002119466396313, 0.020620677520387938, 0.0833268551422017, 0.006844252963284296, 0.03189734768654619, 0.015626198379322886, 0.02225725139890398, 0.07195813661175114, 0.05974175142390387, 0.03545740040551339, 0.0395117489221905, 0.02109995564179761, 0.0913846484784569, 0.009422813259464289, 0.028837063150214295, 0.02384133211203984, 0.055832826532423496, 0.050460362673870156, 0.045843532375459156, 0.025090878097606555, 0.06632578705570527, 0.06801519675978593, 0.003896951292907553, 0.013503288767034454, 0.0358541500089424, 0.07926357710467917, 0.0472877534505512, 0.020997596937896948, 0.00650583574315533, 0.02417028080006795, 0.0889248979677047, 0.04645803404439773, 0.0009259472280973569, 0.03275246465844767, 0.017265713707144772, 0.05119187092142446, 0.061940069177321026, 0.042908033821731806, 0.03768598760611244, 0.015132781284462129, 0.02474468613841704, 0.02440683846361935, 0.030835046832050596, 0.05728745633470161, 0.012173921618211483, 0.07082669982420546, 0.02326225336374981, 0.01641107170975634, 0.02606066409498453, 0.059627954315926344, 0.01759052842057177, 0.009701870963908732, 0.01429437323739486, 0.037713512379143915, 0.02892834985894816, 0.028236069417159473, 0.06126530681337629, 0.027037668008623377, 0.0349140465259552, 0.02774721377396158, 0.029730988932507377, 0.018632456261132444, 0.056308164061712365, 0.09173313049333436, 0.04785228440804141, 0.02699076257912176, 0.05582876889301198, 0.038282752369663546, 0.06401874763625008, 0.004436629633086601, 0.06251619290560484, 0.02629725229261177, 0.024425376040328826, 0.07856210081705026, 0.06658572025064911, 0.07529038137623242, 0.021644401962735822, 0.02900080043556435, 0.048125896868961196, 0.019937185803428292, 0.03146437109847154, 0.038321829201387506, 0.08821465500763484, 0.060224339099867005, 0.08055997932595865, 0.0709545018949679, 0.07010258760835443, 0.028888920189014504, 0.06820581081722464, 0.0323480170752321, 0.06632561742195062, 0.04916618944012693, 0.025741013033049445, 0.04496268874832562, 0.047402887272515466, 0.0425960230641067, 0.04839271719434431, 0.030826843343675137, 0.015505643062559622, 0.014430512807198932, 0.060971589359853945, 0.01854716949830098, 0.023814599528642635, 0.04180215405566352, 0.02588065723622484, 0.017060974246955345, 0.01280131799701069, 0.019942595423864465, 0.05539657940555896, 0.05254610807501844, 0.015794218916978155, 0.04323900963312813, 0.07579287726964269, 0.004275100555137864, 0.04181213530578783, 0.07671905721404723, 0.01932079780713788, 0.04856295823784811, 0.06300956250301429, 0.017352247278073003, 0.05340155413640397, 0.018334469126005257, 0.04398548975586891, 0.03945456199081881, 0.02615896685581122, 0.007196613653962101, 0.006159411385721926, 0.023541002334760766, 0.02961188568068402, 0.0852587189791458, 0.02968650756935988, 0.045229963692171235, 0.01011037194569196, 0.03300109685265592, 0.02540156401560775, 0.06556631638003246, 0.030640229250171354, 0.03852386300319007, 0.022426941132705127, 0.0068643744951779285, 0.025124248449823687, 0.06896207880760942, 0.00540997666705932, 0.07109909092209168, 0.009424323848049556, 0.03913690921451364, 0.10157668550631829, 0.02862747386097908, 0.037318577856889794, 0.0488014768676034, 0.0037191076886041886, 0.02021186356432736, 0.043157978981201134, 0.02503187608505998, 0.014385561558551021, 0.06001727735357625, 0.041177352225141864, 0.014377320750749536, 0.012723586721611875, 0.016897072416863272, 0.0433727183512279, 0.0626032625191978, 0.02120089451117175, 0.03775821765884757, 0.050506733757044585, 0.09426135875816856, 0.056160657334008386, 0.16423656498747213, 0.16204729889120373, 0.11834528749542576, 0.1673085508602006, 0.11783285784934248, 0.14203343354165554, 0.09091952629387379, 0.08347109811646597, 0.09421947957681757, 0.11997622783694949, 0.08812075254640409, 0.23262321895786695, 0.1358079697404589, 0.07149819164936032, 0.16665346601179667, 0.08079707981752497, 0.10809978190809488, 0.16552370520574705, 0.10961080475577287, 0.11009638477116823, 0.10851836337574891, 0.1681377070822886, 0.07823666863675628, 0.12692735769918986, 0.07918885004307542, 0.14062187714236124, 0.1539195485945259, 0.06420314631291799, 0.17592951469123363, 0.14503202906676702, 0.1428981042866196, 0.08916603574263197, 0.1308732152517353, 0.1890170167067221, 0.13181010926408426, 0.11234314992491688, 0.0990130105721099, 0.11611022028539862, 0.14291983097791672, 0.20452162330704077, 0.15814383620662348, 0.1451957459960665, 0.10285930668136903, 0.1259396956967456, 0.08866492406065975, 0.13267171303076403, 0.12241577836019651, 0.21331774416778768, 0.08894034142472915, 0.18769080644207342, 0.10714427568018436, 0.07985519178743873, 0.11913890205323696, 0.12038018687495164, 0.2499104184763772, 0.1194968835583755, 0.07586291565426759, 0.09655228297093085, 0.15428327050592217, 0.1418578422495297, 0.13504768482276372, 0.11059487730796848, 0.12040772182600838, 0.09743927751800843, 0.18675380386412144, 0.09425474304173674, 0.0680854929877179, 0.0995640352900539, 0.10334582986044032, 0.13493276813200542, 0.10187771756734167, 0.11839463056198188, 0.14565168081649713, 0.15573910810053349, 0.07775128539651632, 0.19540831446647644, 0.11805556661316327, 0.1131381011967148, 0.11160808615386486, 0.11518562132758753, 0.17653560931129114, 0.16626610394035066, 0.16400033980607986, 0.1905073103095804, 0.2065813842096499, 0.11092099480863128, 0.09241719557238476, 0.14772812010986464, 0.056346477541540346, 0.15394968912005424, 0.11027735684599195, 0.2723013684153557, 0.12527308932372502, 0.1647714405719723, 0.20464810223451682, 0.18323405273258686, 0.12208571178572518, 0.10135036015084811, 0.13428909624261515, 0.11549508757889271, 0.10375034529715776, 0.18991253365363392, 0.11037568335554429, 0.124799784006817, 0.16183875793857233, 0.11057667899876833, 0.07121213485619851, 0.12508683146110602, 0.07826045128915991, 0.20629338680633477, 0.12581407172339304, 0.11651290367756571, 0.129247784614563, 0.12848916889301368, 0.1172564694924014, 0.11035686757947717, 0.09021998383104801, 0.12669814856989042, 0.16076100005635194, 0.1523234849529607, 0.12428302530731473, 0.1456021884722369, 0.17819864435919694, 0.17669552644448622, 0.12955081835389137, 0.08096118351178509, 0.10639291349798441, 0.13393034120755537, 0.07251281184809548, 0.10995780077895947, 0.10096467406089817, 0.1434335634112358, 0.14815035888126918, 0.0956589373360787, 0.16863188413637026, 0.06352700652288538, 0.11934880007590566, 0.12900295560913427, 0.20023808601711476, 0.1369238748614277, 0.15505871389593395, 0.12606511610959256, 0.18967581992702826, 0.11652382809136595, 0.16461824093546185, 0.13828460898782524, 0.1634976946349655, 0.12670573459139892, 0.12489809016031878, 0.12591156363487244, 0.08916961162218026, 0.10154794954827853, 0.17518704810312816, 0.14456769398280553, 0.12499813336346831, 0.2297380066343716, 0.17548044664519175, 0.07862808156226363, 0.18439415762467043, 0.09387803397008351, 0.08714712943349566, 0.07280813064426184, 0.12710915080138616, 0.068861384210842, 0.10791609569319657, 0.14803043460207327, 0.09294158779084682, 0.10108757032347576, 0.1220424755343369, 0.10647209853466068, 0.09343138829405818, 0.1135968112253717, 0.09422015132648603, 0.18443998587982996], [0.05296079475166542, 0.008868477290629275, 0.0345206047807421, 0.01627143768460623, 0.02522933486449931, 0.025669403839856386, 0.02792153281292745, 0.02809834886076195, 0.02523740773488368, 0.022264623681881597, 0.013827048358507454, 0.04954674919801099, 0.08582280549619879, 0.009573516735274876, 0.03989654273859092, 0.04069597912686212, 0.017935173319918767, 0.0192943315487355, 0.09302677107708794, 0.0388165355127837, 0.02408068873254316, 0.02756884557727192, 0.01341619370837829, 0.024715541363028542, 0.016415044532290528, 0.05509461435888495, 0.03723623763237681, 0.06073466528739248, 0.04331175197980233, 0.06456984699304615, 0.04814313844378505, 0.032053872144648006, 0.02060992274034236, 0.009895571507513523, 0.020592102714415108, 0.03162535013897078, 0.042435325615640195, 0.021232770390010307, 0.02055680362640747, 0.0015799173706909642, 0.08161072472908668, 0.012901630069661354, 0.04494033780481134, 0.027600892786202685, 0.05835564008780888, 0.017670746526813934, 0.06891859149826424, 0.024915442868535007, 0.053090517076530626, 0.006784033828548023, 0.0434072557836771, 0.009528137161396444, 0.02706890436820686, 0.026068377341809015, 0.040459577526365004, 0.06508157774806023, 0.07153053741369929, 0.06357612567288534, 0.032410360872745514, 0.02558178291656077, 0.03990826103836298, 0.006797084601462952, 0.012375259921619934, 0.05694781563111714, 0.02632236826632704, 0.030022521503269672, 0.007534915099053511, 0.042416601441800594, 0.06953097613794462, 0.015445451917392867, 0.06211601330765656, 0.01729138777591288, 0.03858267502593143, 0.033492091577500105, 0.025564643121989708, 0.044508524904293675, 0.038292309535401206, 0.010723379141251956, 0.02481313675109829, 0.07216535442109619, 0.07354578641908509, 0.07240008004009724, 0.02805666815090392, 0.032875995351267714, 0.026022501589198197, 0.023490758512967398, 0.03490884894771235, 0.053655824956617186, 0.0735990989155003, 0.028689271437802484, 0.03219776567337768, 0.03696195002911346, 0.11207356117665768, 0.03996460319363645, 0.00180443623269509, 0.04240059480071068, 0.012749982582006072, 0.04570510783897979, 0.027021920907178094, 0.02470114963528301, 0.0588392862784011, 0.05875215559665646, 0.07829196245542594, 0.030480773520788977, 0.06205297061907394, 0.03479480078177793, 0.02687022083305887, 0.04325081274977752, 0.008751286659389734, 0.03593424428254366, 0.030009798971670013, 0.026459764822253158, 0.05491955232407365, 0.03265966820929732, 0.025396023777180483, 0.03697223661999617, 0.006112983899324068, 0.03792689467913338, 0.03688806435093284, 0.027287932079551474, 0.0038072896755433506, 0.035671335711543045, 0.0076365045138767785, 0.04489281999745539, 0.028516390893076147, 0.004959659692498722, 0.03658776171505451, 0.022809806213315045, 0.07808673953903572, 0.010070368913667542, 0.05195557565561362, 0.01954309775360993, 0.036053384853793044, 0.020100767025724053, 0.02891901321709156, 0.03804283595776983, 0.09414130555731909, 0.008003396880147713, 0.0812638101301023, 0.06595086931650128, 0.044895693593259366, 0.07691429209496294, 0.01292494622923966, 0.04855561648894634, 0.0497161793921675, 0.013659037150708693, 0.01019936944690666, 0.03873297053256205, 0.006803076913846391, 0.069797368986266, 0.06337376617427383, 0.04833718588841813, 0.03232203596936805, 0.03093360743618437, 0.06765438576361962, 0.012497102758581085, 0.05363549944013357, 0.021475858953116194, 0.020908501897273318, 0.02686712671337383, 0.09073410302932773, 0.0638629084985171, 0.021410707716963122, 0.015585423513714756, 0.012053549505903252, 0.03103970656437533, 0.037907122168689966, 0.04251987107896379, 0.016520015596012984, 0.027992962194340568, 0.030832773739738122, 0.046654039062559605, 0.012620675011671014, 0.023998996508972983, 0.02290490289617862, 0.0019456995900587312, 0.03796415303700736, 0.03577177246500339, 0.01870450480575008, 0.025510647001543214, 0.02976266633985298, 0.03659818401294095, 0.02191090676933527, 0.03922826038407428, 0.06189916030104671, 0.10421748951609645, 0.04110296103837235, 0.03819359965356333, 0.06720853397356612, 0.09195971369211163, 0.015016331104561687, 0.08116110028432948, 0.020148412058395997, 0.01462660264223814, 0.07081590433205877, 0.042854300633605034, 0.008596691785247197, 0.0931136439155255, 0.056390646778579266, 0.02843455956982715, 0.05217466104243483, 0.02954317383202059, 0.02429825589726014, 0.058244943884866576, 0.03221807761916092, 0.02514162233897618, 0.025630932600636567, 0.0031861165230761147, 0.05740997940301895, 0.0036705720787202673, 0.03863671016214149, 0.06885451743645327, 0.033208854097340784, 0.025748247912685786, 0.016031648498028517, 0.011339680624327489, 0.08722567664725439, 0.020185302311022366, 0.04325253962139998, 0.03434826706403068, 0.015226726154131549, 0.03502662566357425, 0.03969029862699764, 0.028684555619422878, 0.014434027618595531, 0.010815925380614187, 0.006968189928946751, 0.012807440079216446, 0.020157572281147753, 0.01092487944489611, 0.029176517256668637, 0.045494578778743744, 0.007494331919588149, 0.014348834154329129, 0.08228349898542676, 0.017015398746090274, 0.009900058320324336, 0.009559512620658746, 0.010795798335623528, 0.045250580978712866, 0.02907947657097663, 0.037139526036168845, 0.056802680383303335, 0.015511615867061275, 0.06860503368079662, 0.021017508548019186, 0.02488246437029115, 0.022075171615662317, 0.07191555175398077, 0.05382928904145956, 0.04458149116752403, 0.024751586839556694, 0.02243556870546724, 0.056314806919544935, 0.016191957485196844, 0.04495790507644415, 0.04866262146138719, 0.0008839962174533866, 0.026498156333608285, 0.038820311560162475, 0.03829544097451227, 0.024310427119157145, 0.10650795911039625, 0.023951575392857194, 0.07107108778187207, 0.050670281052589417, 0.12991692870855331, 0.015397191114191498, 0.03846832151923861, 0.031668454076030424, 0.03527348009603364, 0.017039193272856728, 0.02675979774046157, 0.03770028094628027, 0.017103496340236495, 0.035489257624638934, 0.013394830033316143, 0.011653414012731185, 0.04510342708921858, 0.03384499764069915, 0.014271443842777183, 0.02165319408023996, 0.03784014058432408, 0.05280074530414172, 0.034391438854592185, 0.011998413446625429, 0.014069048721077186, 0.020558957975091677, 0.07025168210800205, 0.0318523608148098, 0.02865216914298279, 0.030041045509278774, 0.02392273935090218, 0.02376217591310186, 0.021258098405918906, 0.03746912442147732, 0.07991829554417304, 0.029353217953549962, 0.06327816059014627, 0.02799792567800198, 0.034568634882037125, 0.030211720815194503, 0.05589159784306373, 0.03782460213239704, 0.04872101279241698, 0.07843708073986427, 0.039326892234385014, 0.024693115780662214, 0.05233102265213217, 0.06295270805380174, 0.026242643794310943, 0.03627349143581731, 0.05095407832413912, 0.0789392034390143, 0.04330055954466973, 0.06604070735297032, 0.11596605873533658, 0.05632501208622541, 0.03630787619788732, 0.026562321997646774, 0.06123309675604105, 0.022246742587802664, 0.005193736886472574, 0.01811987055199487, 0.0421929427289537, 0.04163389772708927, 0.05194625936980758, 0.024621642294472883, 0.01586287478650255, 0.039701362140476704, 0.005834560625122062, 0.02977481550936188, 0.03320124771978174, 0.0259611518454871, 0.027361659998340265, 0.040891767013818026, 0.024415462643706372, 0.026575680655826415, 0.015567803655618002, 0.011161831506927098, 0.05550825609160321, 0.029233314030404602, 0.03427329572982021, 0.08071218830134187, 0.02085719956085086, 0.032941192388534546, 0.021237740659021904, 0.03947854481105294, 0.04288759634697011, 0.0358924533107451, 0.08762773578720433, 0.023982589532222067, 0.09391179108726126, 0.059786480452333174, 0.066769318255995, 0.10429258298661027, 0.09306505402284009, 0.11990745152745928, 0.08836299633341176, 0.11277531566364424, 0.1051672078402979, 0.19613066927662917, 0.1588399452822549, 0.13844589676175797, 0.1279730208750282, 0.17159214243292809, 0.10352172649332456, 0.12865585780569486, 0.1229338398469346, 0.1394292704228844, 0.2717757209071091, 0.0952258895018271, 0.08435565672282662, 0.1802211944013834, 0.13081528193184308, 0.13476681203714438, 0.10299426051122801, 0.16502181999385357, 0.11551438511482306, 0.14860018688653195, 0.1246090071009738, 0.10823017598262855, 0.07954586802848748, 0.13028944443379128, 0.17589382374925272, 0.11842057774109499, 0.10170217377266713, 0.10811525250652007, 0.058471099606582096, 0.11742281913757324, 0.1427728467221771, 0.12916265561112336, 0.20572625366704805, 0.19350787358624594, 0.1043490506708622, 0.15439954426671776, 0.1852208711206913, 0.09524355176836252, 0.17437195112662657, 0.14356306860489504, 0.11273890547454357, 0.11623270942696504, 0.0958864162010806, 0.07447565080864088, 0.2106184640101024, 0.05658644823623555, 0.10785371118358203, 0.13047772433076585, 0.07731418670820338, 0.14705170212047441, 0.13300849710191998, 0.08670959648277078, 0.07426652631589345, 0.07229860512805836, 0.08059404178389482, 0.20848919398018292, 0.10828252495931727, 0.0951152882937874, 0.19515984851334775, 0.14192881701248033, 0.146400566345879, 0.08799255013998065, 0.12473961152136326, 0.10051616241357156, 0.1381757991122348, 0.26571062207221985, 0.2121042249990361, 0.10683994593897037, 0.13691201406930173, 0.1522601776357208, 0.09864118016724076, 0.25375027528830935, 0.14946400267737253, 0.07551378224577222, 0.23276207436408314, 0.14578497223556042, 0.06001330113836697, 0.07329624838062695, 0.18769704896424497, 0.15279871730932168, 0.19853078334459237, 0.19499238607074532, 0.14504345559648105, 0.09182590658643416, 0.2134118705455746, 0.11389715118067605, 0.09978251678070851, 0.10387073098016636, 0.130831580342991, 0.07164691295474768, 0.07451789639890194, 0.13447361705558641, 0.0912379559927753, 0.1393687722406217, 0.1332005632242986, 0.13513251527079514, 0.12732797834490026, 0.13788318767079286, 0.1309834500508649, 0.17030283090259346, 0.11850474322480814, 0.14320240010108265, 0.10964604107929127, 0.1093875803053379, 0.23331543324249132, 0.13637682635869297, 0.14509121089109353, 0.09752640819975308, 0.10228956118226051, 0.16838135543678487, 0.07865628147763865, 0.12803905590304307, 0.21998924974884304, 0.18519374329064572, 0.13209014066628047, 0.11350957876337425, 0.14813807739743165, 0.13462913728186063, 0.13280952349305153, 0.06903886861566987, 0.20868773332663945, 0.12693103535899095, 0.15156105586460658, 0.16326141517077172, 0.14161814296884195, 0.14457103237509727, 0.07954647871000425, 0.08159876894205809, 0.1848677886383874, 0.22050784049289568, 0.16811422977064336, 0.1812853408711297, 0.3227691746183804, 0.18902097935123102, 0.15628082331802162, 0.13270201640469687, 0.17745378932782582, 0.09345714548336607, 0.08906477117644888, 0.10900259310645716, 0.06962337225143399, 0.22349272961063044, 0.1455485299229622, 0.12021260229604584, 0.11109871670071568, 0.08501773048192263, 0.10015240657542433, 0.1512014323047229, 0.11577897305999484, 0.13787139473216875, 0.20150018829320157, 0.10519001340227467, 0.11515183028365884, 0.2470337285527161, 0.08928534255496093, 0.08595334206308637, 0.10495395785463707, 0.16025771706232003, 0.11661093841706004, 0.13825193074132713, 0.08216789697429963, 0.07870863723967757, 0.10094209920082774, 0.1418115118784564, 0.06911072547414474, 0.13791163185877459, 0.20626761604632649, 0.10117949146245207], [0.014961970271542668, 0.01863141979889146, 0.0235891308236335, 0.012321055999823978, 0.04686631874314376, 0.060028038918972015, 0.08171657619199582, 0.07751946390739509, 0.038476158598704, 0.0182597200120134, 0.01974669048961784, 0.025830996954547505, 0.049494447718773565, 0.02917802699708513, 0.07181448396295309, 0.050258637605501075, 0.0351707872136363, 0.049364857708237, 0.060387893180762015, 0.02545602323620447, 0.0431820941157639, 0.01691500609740615, 0.0336997334712318, 0.03646204274679933, 0.013559774262830615, 0.030451053686972176, 0.02229007383409355, 0.019649802474305034, 0.03340144269168377, 0.04476327069901994, 0.05367639135303242, 0.005013665142801723, 0.03413416212424636, 0.0038951459656735615, 0.019999181851744652, 0.015045548822464687, 0.06470374909362622, 0.049026516399213245, 0.02431774851200836, 0.01624793662423534, 0.05397342345012086, 0.033330495070133886, 0.05663442744740418, 0.07521657712225403, 0.013014377144697522, 0.07273985645068543, 0.04666872595303825, 0.024404165035645877, 0.012878497962706854, 0.0416050633814718, 0.020891007568155016, 0.0405247915270073, 0.018910238319741826, 0.025937769528744475, 0.0027622161890446606, 0.014580497884058526, 0.01802160680693175, 0.027534299663134983, 0.0638868065018739, 0.009855516737193933, 0.052811062429100275, 0.017948218155652285, 0.01983260489734156, 0.016694590781948397, 0.007748435650553022, 0.026493031697879945, 0.07637062948197126, 0.04266653303056955, 0.03968806624678629, 0.031670045240649154, 0.08549350566629853, 0.041355450704161606, 0.02742717764340341, 0.036997892029051266, 0.01623418102306979, 0.04385798963318978, 0.035366924546126804, 0.04059028372700725, 0.015995036444759796, 0.05130601408226149, 0.03785208619332739, 0.0264250034732478, 0.08072133495339326, 0.013903960302871252, 0.01852444196785135, 0.04202705788026963, 0.08030308596789837, 0.009143078716338744, 0.027763435849919915, 0.057914775530142446, 0.03534416648160134, 0.014673699757882526, 0.08680252185357468, 0.06344691903463431, 0.04887801901038204, 0.01178934408484825, 0.04284560860001615, 0.050699308780687194, 0.054036089551768134, 0.003388924490926521, 0.011535779789223202, 0.01585673404458378, 0.0062661305252861765, 0.032581351697444916, 0.02358542432609413, 0.06202137802860566, 0.010724020356844579, 0.03128499358094164, 0.023151497788993374, 0.018906614942742244, 0.07495808920689992, 0.05254510723586593, 0.059768356781985076, 0.05274097993969917, 0.03955781466460653, 0.0435384878489588, 0.017790546973368952, 0.02513792771579964, 0.03049312285812838, 0.045794911948697906, 0.040587576372282844, 0.018075696225943308, 0.06966105130101953, 0.051068788061716726, 0.06799455572451864, 0.028924950398504734, 0.04046198293300612, 0.018082255963236094, 0.04135256353765726, 0.02514618039796395, 0.05332986691168376, 0.010173636854493191, 0.0164728167001158, 0.02130611493651356, 0.062229131880615435, 0.037759011544819386, 0.04024877365944641, 0.0787776985338756, 0.016707890068313906, 0.04556711417223726, 0.026631205176402415, 0.03322896248261843, 0.017780058518318192, 0.01674061411592577, 0.05438852742580431, 0.017791658074461987, 0.03366843943617173, 0.021696823881939054, 0.035043846882347546, 0.050550231244415045, 0.07440665058259453, 0.028136831974344592, 0.03127826251355665, 0.01314963461897735, 0.0206540563542928, 0.01902687848944749, 0.03159596957266331, 0.02655700228310057, 0.06850608291902713, 0.025858813497637, 0.060524577274918556, 0.06320787114756447, 0.011080168969263988, 0.033965020307472775, 0.07221470427300249, 0.03512085382161396, 0.05984604225627013, 0.015072354348376393, 0.05997420395059245, 0.03279489006048866, 0.017665884823405316, 0.04491334568176951, 0.0027173440321348608, 0.05241922541920628, 0.03621807887351938, 0.03306487914440887, 0.02582221501506865, 0.06864225132656948, 0.03449985857254692, 0.022469641341428672, 0.02912556945479342, 0.03365050236295376, 0.029205334638910632, 0.0322247170843184, 0.013840187340974808, 0.03153212960543377, 0.03103298567501562, 0.03801667843280094, 0.03882955659979156, 0.041222101609621725, 0.04848499456420541, 0.040377566391336064, 0.03335607923301203, 0.037428938184997866, 0.018098259211650917, 0.04122303459527237, 0.08787888195365667, 0.05113489433590855, 0.029993717691728046, 0.015178640073697482, 0.031428195003952296, 0.08562989799039704, 0.067733319742339, 0.02138854337057897, 0.05504851468971797, 0.04561469644041998, 0.010521168072175766, 0.024881918149601136, 0.010222474412460412, 0.029243492055684328, 0.02541364702795233, 0.039184420236519406, 0.09717940539121628, 0.03332163679546543, 0.03072008942919118, 0.032457617444119284, 0.011368540415008153, 0.0849547895735928, 0.024473811566297497, 0.04298124435756888, 0.032158241008541415, 0.035790147193308385, 0.021693490578659942, 0.026748313535270945, 0.00463780720851251, 0.043760853952595165, 0.042483070732227395, 0.04907844468419041, 0.03576043075216668, 0.06752650226865496, 0.034323028954012055, 0.08699523258422102, 0.03186285775154829, 0.029226036742329597, 0.016635139239951968, 0.02128971813778792, 0.07488903469805207, 0.02869813310514603, 0.032034530503941436, 0.0445325077245278, 0.008811440485130464, 0.014554006180592945, 0.0711218761280179, 0.03738385631835886, 0.024327997783465043, 0.019058181006195288, 0.0032255345306891415, 0.04215747570352895, 0.07283434245203223, 0.04135918264676418, 0.0200124607820596, 0.06194293938044991, 0.025090153761474148, 0.0010650249605532736, 0.049046869057097604, 0.03548183784421001, 0.047978647984564304, 0.041168521091874154, 0.042473340540059974, 0.03845202989344086, 0.015443630050867796, 0.03768625223476972, 0.05386047111824155, 0.016103439199339067, 0.04688383173197508, 0.10852254315146379, 0.03077343924503241, 0.009467757722762014, 0.04186096268572977, 0.0311055380318846, 0.05043967753382666, 0.01794050999784044, 0.05795801178153072, 0.09861390984484128, 0.04527584623013224, 0.07234872172453574, 0.05996034826551165, 0.06244358965860946, 0.04094572751117604, 0.013997762680186756, 0.060675564887268205, 0.030980785976030996, 0.039274329519165416, 0.02361445375052946, 0.01845402529995356, 0.010488773962216718, 0.0187513339000621, 0.027917649896283234, 0.06402428448200226, 0.01744514041846352, 0.020589366521952406, 0.052952007723173926, 0.023874376767448018, 0.020242971002257297, 0.0420631186238357, 0.03813718964478799, 0.013254732059847032, 0.03373410466260143, 0.044930244596408944, 0.06559936103544065, 0.08662707983915295, 0.033608131243714263, 0.06542001744466168, 0.011912362483729209, 0.020798538512151157, 0.03948555747047067, 0.01823826982373638, 0.03333834232762456, 0.03935487501855407, 0.033692876874868355, 0.044583964427667, 0.007975660913091685, 0.03200597096500652, 0.031009705138525794, 0.018249675997399857, 0.08953052439859935, 0.0707522848887103, 0.08231790749622242, 0.06821095411266599, 0.0226929048076272, 0.04290077688970736, 0.07000868514712368, 0.07927838952413627, 0.06621739108647619, 0.023645471282569424, 0.01872791935290609, 0.0880355964015637, 0.047245779274297614, 0.025251714645751884, 0.03130402988088982, 0.05539818414087806, 0.029287020077130625, 0.035153959545173814, 0.04625599345724497, 0.008323885932830828, 0.05036518117412925, 0.06415499746799469, 0.015210185166714447, 0.012623642754208828, 0.09955551967556987, 0.022414098161139658, 0.017335831819634353, 0.016168805870360563, 0.03762279224715062, 0.03692419294800077, 0.028616457844951322, 0.02174630604817399, 0.0424496834166348, 0.01051065162755549, 0.06399653239973954, 0.029079646204731295, 0.0362246979826263, 0.18037664677415574, 0.11533740961125918, 0.21163824786032948, 0.11530393069343907, 0.1818239755396332, 0.1662271696009806, 0.11459760288042681, 0.15684414309050354, 0.0987126434754048, 0.10004487234566893, 0.11473303847014904, 0.08026751037687063, 0.128146427284394, 0.10165652872196265, 0.11630749755672046, 0.09921119708035674, 0.10077997682882206, 0.10052034218928643, 0.09996003511228732, 0.13392663640635355, 0.15218650230339595, 0.10341776814311743, 0.09637291223875113, 0.14082015864551067, 0.08822394415204014, 0.12397939445716993, 0.09478533707026925, 0.07024106982031039, 0.12304841727018356, 0.10688908544502088, 0.1253694820084742, 0.11753028551382677, 0.09391333814710379, 0.11312284772949559, 0.10504796888147082, 0.14895333722233772, 0.19646122439631394, 0.16083353544984544, 0.07386290654540062, 0.11355432814785413, 0.11445969742323671, 0.19033840937273844, 0.12777768421385968, 0.19091988674231938, 0.13632377849093505, 0.14828141113477095, 0.13992559164762497, 0.13295607348637922, 0.09560103794293744, 0.07498683195028986, 0.21363277440624578, 0.11035563943109342, 0.11901363091809408, 0.1755940741194146, 0.07176822144538164, 0.22557119093835354, 0.15233200735279492, 0.13479989740465367, 0.17986705340445042, 0.11239237764051982, 0.24632699361869267, 0.093617530805724, 0.09235715200858456, 0.10450482195509331, 0.17922894550221308, 0.11403368599712849, 0.20038877507405622, 0.13995859559093202, 0.08974827307143382, 0.06571253389120102, 0.15734639471130712, 0.13170842400618962, 0.09628130322588341, 0.09834377826856715, 0.09850351219730717, 0.126251061846103, 0.08946524932980537, 0.14706202942345822, 0.13791596091219357, 0.12968854739197663, 0.09611296547310692, 0.14396459848753043, 0.11803156004420348, 0.12197102579687323, 0.14293726932789597, 0.19702124648860522, 0.23939841826047215, 0.07965024707040616, 0.1350358918841396, 0.17419521989566938, 0.09358196878539664, 0.1385669745504856, 0.2028736245951482, 0.07498859614133835, 0.08632366612021412, 0.08531781259391989, 0.12632206375045435, 0.12465588030006204, 0.11929162671523434, 0.18093124058629784, 0.14563044267041342, 0.16013248663927826, 0.12240538320371083, 0.10327990339802844, 0.13120845226304872, 0.09730917521353279, 0.1385547880615507, 0.08952128275164536, 0.10007590175207172, 0.11316287451024566, 0.12841934763959476, 0.166942779773048, 0.11589228840810911, 0.16862185538879462, 0.16817128099501133, 0.14363321555512293, 0.11974893217640263, 0.148129867123706, 0.10791838235620942, 0.12317385125373091, 0.12102183672998633, 0.14233947997646673, 0.12246335723570415, 0.13365987714912209, 0.20375874638557434, 0.09382647209401641, 0.20859561541250773, 0.0610859767932977, 0.10614205910159008, 0.13104104410324777, 0.08796843500541789, 0.10384460059659821, 0.10590206126549415, 0.13338595256209373, 0.22023730858096055, 0.1163349917956761, 0.10007801199597971, 0.1815527786633798, 0.12219952924975327, 0.2398095561989716, 0.12870928565306322, 0.11249394076211111, 0.10586856877697365, 0.07566095649131707, 0.16958950060818875, 0.10977894573339395, 0.23036787712148257, 0.12206964407648359, 0.07468094157853297, 0.10789453185030393, 0.23628627668534005, 0.08849161264619657, 0.16007516400090285, 0.09770695958286524, 0.1070540440934045, 0.12102848637316908, 0.1031118913420609, 0.10305213276296854, 0.11316312556820256, 0.11522462352045945, 0.09839717218918459, 0.1307402631001813, 0.13814483077398368, 0.18696774595550128, 0.1690681685826608, 0.11451475375464984, 0.12610459327697754, 0.09663191584071942, 0.2491530105471611, 0.08751616427408797, 0.10411171947738954, 0.11577931232750416, 0.0437638496847025, 0.1986032644552844, 0.13724662682839803, 0.1164611993091447], [0.026574722225112573, 0.023217731288501194, 0.01832257949614099, 0.016874507734818116, 0.021058985697371618, 0.02217438700608909, 0.05393666720816067, 0.011338012276350387, 0.03740690954561744, 0.049604875900383504, 0.03639839616205011, 0.02583782810584775, 0.01861408492550254, 0.015458644334492939, 0.01855939669933702, 0.03527437576225825, 0.025702477333002856, 0.042125526882175884, 0.03411584507141795, 0.024390165161873614, 0.020516963442787528, 0.09344007354229689, 0.06773534177669457, 0.09393051865377597, 0.02436924253457359, 0.061129911935755184, 0.02645554772711226, 0.054329074187470336, 0.07221980007099253, 0.01449184219485947, 0.03468726994469762, 0.018594546509640555, 0.06996485178491899, 0.0658380560843008, 0.020242701284587383, 0.11811955246542181, 0.047035134863108397, 0.013667290681041777, 0.04583179711231163, 0.03318754470508013, 0.04877318535000086, 0.047834377868899276, 0.019046250664229904, 0.016788997055430497, 0.03383957953857524, 0.029776254003601413, 0.040176133093025, 0.03292221037138786, 0.017271270908947502, 0.005710563015392316, 0.03374854728047337, 0.009300861008731382, 0.09365803934633732, 0.04725140093692711, 0.03362408360200269, 0.009350341478628772, 0.04145116485389216, 0.029652835269059454, 0.03578634400452886, 0.030146693411682333, 0.061961653376264234, 0.021520935730742555, 0.031104873067566326, 0.032319983400936635, 0.02301407409166651, 0.08791677813444819, 0.04250676856775369, 0.06766154430806637, 0.07854844869247504, 0.010317488822952976, 0.04621624487585255, 0.02854192755850298, 0.039440261865300794, 0.09708892274647951, 0.06423657773328678, 0.05622008003826652, 0.02889078955299088, 0.013007138024217315, 0.04850295199347394, 0.03512405650690198, 0.07310046388634614, 0.040346455560731034, 0.02484408812597394, 0.033099752451692305, 0.026476253223206316, 0.030093085752534013, 0.04580403485202363, 0.027143555094621012, 0.040752840361424854, 0.09884701376514775, 0.03935719221564276, 0.01757423340209893, 0.03082059064347829, 0.027063036736633097, 0.042465557743396075, 0.01865250357825841, 0.02221756218932569, 0.0868065794929862, 0.030672765004315546, 0.05375846694888813, 0.030672242532351186, 0.0314784948048847, 0.0408727510699204, 0.024571488378569484, 0.058755595769201, 0.061524086498788426, 0.07902924503598895, 0.058002360830349584, 0.04301523896200316, 0.05129669101110526, 0.03472910502127238, 0.08486137565757547, 0.04991704950641308, 0.03551326758627381, 0.030643944229398454, 0.05743513269616025, 0.017280804325959513, 0.017394124763086438, 0.05634833672749145, 0.09864958721612181, 0.052528242247977426, 0.03646221238055399, 0.0603578272940857, 0.01774576196580061, 0.016255259713424102, 0.03483766383890595, 0.030412010781999146, 0.009992782675128962, 0.03286634658330253, 0.027397791988083293, 0.016111788572743535, 0.013092473980837634, 0.042191755292671065, 0.04599823496703591, 0.008124986114645643, 0.0041217783582396805, 0.02607940014318696, 0.01827058505399951, 0.0063480000161299744, 0.027108432425718223, 0.025771793077832887, 0.029650609674198285, 0.04383724342499461, 0.048361009252922874, 0.017906437361879007, 0.06905634089240006, 0.0038982129439578523, 0.040516007891190906, 0.05263009713962674, 0.03118831930415971, 0.03659761743620038, 0.055939865431615284, 0.04655550899250167, 0.020817805514005677, 0.07978030866278069, 0.10256022880119936, 0.04501222859003714, 0.0052299486040802935, 0.04085783687021051, 0.005310413951519877, 0.014451179287529417, 0.07514669480068342, 0.06122295944286244, 0.01898586274390774, 0.07712718245706388, 0.026068282346906405, 0.07886744836079222, 0.05683368264830538, 0.07432544351156269, 0.024054090159812143, 0.03103715188003012, 0.016747696325182915, 0.042739502686475, 0.07204950135201216, 0.017290415774498667, 0.053645477297582796, 0.0268776592732008, 0.03635787744341152, 0.030029758079243556, 0.025406882033816407, 0.028828452540827647, 0.03545850641759379, 0.029780294679637467, 0.017794536759278605, 0.010809483538780893, 0.06939539805586849, 0.031066549409713064, 0.019831590487488678, 0.015052554696532232, 0.012039553872974855, 0.049801891935723167, 0.02130907674186996, 0.04506699315139225, 0.0218520031443664, 0.08243161639464752, 0.03251724370888301, 0.07167744703058686, 0.03870139829814434, 0.00487917907802122, 0.0370996383550976, 0.02515590889379382, 0.053217040108782906, 0.041285032339926274, 0.013861020062384861, 0.07457194171313729, 0.022126524842211177, 0.027423072506540587, 0.07542509771883488, 0.034417423353131325, 0.015785799993734275, 0.019362207102988447, 0.02888421794133527, 0.026634061808830926, 0.018844625679776073, 0.026781497290357947, 0.03334990117166724, 0.040742072010678906, 0.018728860820244466, 0.06429699449134724, 0.036699095740914345, 0.00536793633364141, 0.05913219627525125, 0.021267954127064774, 0.023228438571095467, 0.03239923968378987, 0.028459726433668817, 0.031045077169047933, 0.01943427600365664, 0.07850963648940835, 0.07390272976564509, 0.05953301369611706, 0.008668204287200101, 0.07878313359937497, 0.028569581253187995, 0.0390146880942796, 0.0021781654754054864, 0.032809152866580656, 0.012255248281040361, 0.024153098597058227, 0.018042732994737368, 0.03205815709329077, 0.01586920891090163, 0.032821084904883585, 0.013048861142514008, 0.07140806184283324, 0.015135866922459431, 0.02598805066996387, 0.03868699299969843, 0.03332020169390099, 0.06092367800218718, 0.03969370487279125, 0.04962514713406563, 0.06732001727713005, 0.06950669815497738, 0.0179321945511869, 0.03217272094583937, 0.0417305720038712, 0.029280709701457193, 0.015760090301877687, 0.02129351793389235, 0.014781205149899636, 0.049977072714162726, 0.044998009888721366, 0.026476370270497034, 0.021403837549899305, 0.024621046879994016, 0.04944997314097626, 0.027201573231390545, 0.005939717013721487, 0.01160626855146672, 0.044781105991985114, 0.06557264032640628, 0.029309197994215146, 0.08040907992316143, 0.037539362973932705, 0.04036594647914171, 0.054483668213444095, 0.0353106502443552, 0.03857872934479799, 0.0356650355138949, 0.02022565987759403, 0.06682933467839446, 0.02574470765622599, 0.03072457793833954, 0.04738082131370902, 0.03736974957532116, 0.10575870717210428, 0.038203842139669826, 0.05689555825665593, 0.04153140161984733, 0.03018400605235781, 0.04635978556637253, 0.057504926808178425, 0.03442642751282879, 0.028517703858337233, 0.13719461033386843, 0.06597840426755802, 0.013779559388889797, 0.008812114779305245, 0.012916171923279762, 0.04570650562111821, 0.053115941783679385, 0.08023884227233273, 0.02467040521358805, 0.01174172364907073, 0.07013155426830053, 0.030237230339220593, 0.01687536608161671, 0.03964546781831554, 0.028138943914590136, 0.010273319585914058, 0.03265654694821153, 0.010952466982416809, 0.02496598015672394, 0.0290602638519236, 0.0229415098604347, 0.021803397984643067, 0.03497250910316195, 0.049592964218131134, 0.011243918128976864, 0.022157096237476383, 0.034014353196003606, 0.0060890837755453375, 0.08045384966369186, 0.037657071836292744, 0.0403416040353477, 0.019108597854418412, 0.05028467299416661, 0.06479077120976788, 0.024646673451310823, 0.0356874237768352, 0.1097709322348237, 0.011840804180662547, 0.036591245992375274, 0.06262412747102124, 0.03268378673653517, 0.015471192143325294, 0.05597670988312789, 0.04488686924534185, 0.038528093669031344, 0.08445063126938683, 0.016839127222608243, 0.0759860561894519, 0.03518762845279915, 0.07576627869691167, 0.028647792592112507, 0.045978024801505465, 0.03850869774552328, 0.023727828470457877, 0.0467293462716043, 0.025456423571865474, 0.016950888725529824, 0.08235876208969525, 0.10105966217815876, 0.06990041809954814, 0.10941523060734783, 0.12098392019314425, 0.08332505702440228, 0.09389807789453439, 0.07609793304332665, 0.1286930279540164, 0.281383532498564, 0.11039812929396119, 0.11352935805916786, 0.12949770263263158, 0.12010901714009897, 0.11680436160947595, 0.07109238699610744, 0.07778441147612673, 0.16425438331706183, 0.20375863781997136, 0.11934295110404491, 0.13391442277601787, 0.10625578157071557, 0.15557088569871017, 0.15201705853853906, 0.11219394007431609, 0.18304474146238395, 0.08921702764928341, 0.10051452714417662, 0.10795089775430304, 0.07619646989873477, 0.12059726379811764, 0.19361867835479124, 0.1087942828557321, 0.16381743390645298, 0.08600134163030557, 0.13844044134020805, 0.11833311457719121, 0.08051377109118871, 0.11487261312348501, 0.11189083848148584, 0.12154985911079816, 0.12204509467950889, 0.12499559564249856, 0.050614061033619304, 0.11078491461064134, 0.2267971680100475, 0.1141726906810488, 0.12083040843052523, 0.10493012770478215, 0.16211165115237236, 0.10750825543488775, 0.07018414073224578, 0.16108533979526587, 0.14742709483419145, 0.10551601555198431, 0.1057612109663231, 0.14243011868425778, 0.11105574507798467, 0.08175088970788888, 0.10576429151530777, 0.15446285158395767, 0.09127766386206661, 0.18992325450692857, 0.13085436554891722, 0.14935771695205144, 0.10469164300177779, 0.0997686203835266, 0.19776569439896516, 0.1062233815235751, 0.09410564854208912, 0.15193502365478448, 0.15174772084823676, 0.18448149865227087, 0.18053813810859407, 0.08703091674085174, 0.1796118835253375, 0.2730180642434529, 0.16255590159978184, 0.1190904410822051, 0.1264917246465172, 0.18517261371016502, 0.13720488335405076, 0.07557544750826699, 0.11684656648763589, 0.11908585418547903, 0.08521692800734725, 0.16156153567135334, 0.10252582707575389, 0.11427793146244117, 0.18348831337477478, 0.12090237385460309, 0.1218920171793018, 0.1427682869668518, 0.09376011815454278, 0.0879938800686172, 0.15109011184956345, 0.10779946230884109, 0.19707846056137765, 0.06265559792518616, 0.16221267144594873, 0.17421648518315383, 0.07644473229135786, 0.10231211568628039, 0.10887687413820199, 0.1553721156503473, 0.14760240114160947, 0.10981655014412743, 0.0966228438275201, 0.1423499836985554, 0.14461779700858252, 0.21046465369207518, 0.1445664590490716, 0.15048660923327717, 0.13445913711828844, 0.08651679075722184, 0.22406344541481563, 0.0768908690661192, 0.10182997584342957, 0.17589656503072806, 0.3173273780516216, 0.12156355194747448, 0.10386994387954473, 0.08038684433060032, 0.14938284988914216, 0.1729425356856414, 0.14358459173568658, 0.2609308042696544, 0.05817839317023754, 0.1370110394699233, 0.14220256518040383, 0.14652196983141558, 0.06856609255607639, 0.0989543783611485, 0.14919239868010792, 0.08532330194222075, 0.13007468810038908, 0.10337357515735285, 0.11013797896781138, 0.11265618527042014, 0.1200721048350845, 0.11302155602191176, 0.0921138497069478, 0.09916634591562407, 0.10663966954286609, 0.09354196236069713, 0.12965806759893894, 0.08677747712603637, 0.18009506831211702, 0.09524760262242385, 0.10962110491735594, 0.143093291670084, 0.15441901822175297, 0.16186560078391007, 0.10271686182490417, 0.1303236290280308, 0.178719216425504, 0.1034480036635484, 0.22868177188294275, 0.11582503201706068, 0.09548009586121355, 0.13590580091944762, 0.15738934597798757, 0.19015576131641865, 0.14173440315893718, 0.17936353970851215, 0.1730337172214474, 0.15730129927396774, 0.1432655309992177, 0.16315105823533876, 0.1210349053144455, 0.12644627637096814, 0.05097966587969235, 0.11444129555353097, 0.2472116675760065, 0.137862926615136, 0.09675574169627257], [0.029493779875338078, 0.03431028267368674, 0.04559819446876645, 0.037842013340975554, 0.02562477659167988, 0.02155186335689255, 0.05222213135233947, 0.027989744242014628, 0.043224282030548365, 0.03179025111187782, 0.02179548456998808, 0.019318636673103486, 0.008935657346488109, 0.04062815955174821, 0.0403608303251011, 0.018900908463235413, 0.006684999522154352, 0.07242226134985685, 0.07337368279695511, 0.021464678392346417, 0.03389526351488062, 0.033185848367533514, 0.029832592766199793, 0.028247967528711473, 0.0457780469608094, 0.030293365541313375, 0.04360132697703583, 0.05499707834262933, 0.03399651111768825, 0.05371937993913889, 0.026592318334483674, 0.015263867464714816, 0.05003020539879799, 0.013394023424812725, 0.03474359174392053, 0.057226992079189846, 0.06382233888975211, 0.037606395448424985, 0.008875476379346634, 0.032174943148025444, 0.08177895391626017, 0.02754394503842507, 0.04447079496458173, 0.029564435726829937, 0.02988398161583713, 0.03903755472440805, 0.03453110171748059, 0.008511682373604603, 0.05773879747305598, 0.029921545314469507, 0.03379526102383222, 0.041740213986486197, 0.028740633146039078, 0.018294844377253736, 0.029148191812315156, 0.029585249788526977, 0.020233094925060868, 0.021904201147013476, 0.016170958522707224, 0.006054717673188341, 0.03735865892044135, 0.01479484370377447, 0.0100032940307366, 0.036393117159605026, 0.024562275569353784, 0.023203643205176507, 0.015093624724873474, 0.054499067565692325, 0.07494839294148342, 0.04834042250045708, 0.01886276461716209, 0.06218398894582476, 0.050540670686002286, 0.03529456557173814, 0.07582550123333931, 0.02947025845891663, 0.019993307434820702, 0.025079056321244155, 0.022618018290294067, 0.03863366014723267, 0.0211082185019872, 0.025573170610836575, 0.02291049063205719, 0.022110063582658768, 0.0562707428554339, 0.016349525190889835, 0.02190470665560237, 0.05330169413770948, 0.028166209147976976, 0.0569663599931768, 0.06131540983915329, 0.050047090742737055, 0.04980312686945711, 0.027831766022635356, 0.0370274456217885, 0.031610273090856414, 0.040442875386880975, 0.05021151674113103, 0.027215322047205906, 0.05706481542438269, 0.0016357148955908737, 0.037685064798487086, 0.01128444108845932, 0.018020799350259558, 0.037456303502299955, 0.0443159804147269, 0.038728797542197366, 0.029105776588299444, 0.0910806647901024, 0.02406036830507219, 0.01344802717877818, 0.06712610553950071, 0.07049443479627371, 0.04529528286574142, 0.007026901867772851, 0.01722506606685264, 0.07364072025354419, 0.008610018213013453, 0.026085232151672244, 0.019901332013042908, 0.05219317826309374, 0.061538206812526496, 0.04183085608695235, 0.06104901020548173, 0.07261540634291512, 0.01853858263763998, 0.038798863068223, 0.02987418357016785, 0.007648774123351488, 0.009632427993762707, 0.019576613990856067, 0.027070543030276895, 0.05455291610477226, 0.0255744377749839, 0.03970100251691682, 0.0638622028220977, 0.027391620712088685, 0.0011479293233216076, 0.05720043421855994, 0.0641585597768426, 0.04110736133796828, 0.0806079992492284, 0.03826621307858399, 0.03674069672290768, 0.05328348565048405, 0.02256938598916999, 0.0706473630187767, 0.016395784315786192, 0.03719021938741207, 0.046294744592159986, 0.031051384152046273, 0.01994943166417735, 0.03496671441410269, 0.0068434701035065305, 0.030066622886806726, 0.01277667869414602, 0.016429136008290306, 0.05731052652533565, 0.029133386178208247, 0.010450247592026634, 0.03952234424650669, 0.042183263426912684, 0.09377028260912214, 0.05112819380259939, 0.022207131409751515, 0.04784999435235347, 0.015381128493962544, 0.10223343276551791, 0.022649174922012856, 0.023444175387599638, 0.033696697027023347, 0.029952462762594223, 0.04179971132959638, 0.024317724763282707, 0.08493610271917922, 0.0131116188463888, 0.02531379890362067, 0.031269332992711237, 0.028465741646609137, 0.014362979913130403, 0.06019843263285501, 0.06436581829828875, 0.020211551438218782, 0.02156182933997895, 0.02044913368964834, 0.034361936151981354, 0.10298137513122388, 0.046880008187144995, 0.04238898167386651, 0.04242543936041849, 0.03132130198978952, 0.07178492697754077, 0.01377683931163379, 0.036903477273881435, 0.018475458524855118, 0.014712747751868196, 0.05377211568078824, 0.03722467539565904, 0.05691709156547274, 0.050853797633733065, 0.0790270601532289, 0.005700200089320008, 0.04360426503366657, 0.08976628139082875, 0.03737592763666596, 0.05423505298261132, 0.04667379121695246, 0.0357139816374651, 0.01733682756977422, 0.027806224268195883, 0.033332062486026964, 0.06805449072271585, 0.0770740056676524, 0.050695943246994696, 0.057507824152708054, 0.04478246306202241, 0.08405149661536727, 0.02244909869373909, 0.01974633934774569, 0.02619929558464459, 0.05943522322922945, 0.05412096071190067, 0.02082176985485213, 0.03576426786769714, 0.03207163279876113, 0.02588307621356632, 0.06235854886472225, 0.03193801907556398, 0.028074576386383603, 0.01439613991949175, 0.015644347494734184, 0.04356490321723478, 0.021278822561725974, 0.03363329471488084, 0.002529115449371082, 0.01209181039926729, 0.03088134666904807, 0.007117270009725222, 0.015864225071189657, 0.014986375479825904, 0.09307762727673564, 0.019648419959204536, 0.02096192804830415, 0.07272400587264981, 0.043880564493260214, 0.04030387409563575, 0.034685465041548014, 0.019803005503490567, 0.008761452810306634, 0.058152113508965285, 0.06243418516325099, 0.06885147081421954, 0.012233168751533543, 0.022487763315439224, 0.009459374422606612, 0.014736294613352843, 0.00395595797038238, 0.03438517597637006, 0.00542965969569715, 0.010648015104899449, 0.03500547233436789, 0.03433087281882763, 0.044557423530412574, 0.016306986134233217, 0.022561745684860007, 0.026104762085846493, 0.09504725837281772, 0.01735327356228871, 0.07186428843332188, 0.09008762879031045, 0.03747874604804175, 0.03019398051713194, 0.023371512768790126, 0.07175559390868459, 0.021789121607850705, 0.047572992609015534, 0.005715656268876046, 0.0060399909187773505, 0.017864232483719076, 0.005709410778113774, 0.02994566723438246, 0.014441881661436387, 0.03530606674030423, 0.05441169261134096, 0.017118475000773157, 0.01615739630402199, 0.022606137142117535, 0.06601756252348423, 0.059074025468102524, 0.06643765712422983, 0.01301682326343975, 0.0252041154141937, 0.046378720086067915, 0.01773174343231533, 0.045274557013596804, 0.042654037808201144, 0.01813874569987612, 0.04424151119643024, 0.019751272297331264, 0.014761429246781128, 0.024813842427517687, 0.0043712247944703055, 0.023324156113501106, 0.023976591282657216, 0.048360225544976335, 0.02417046230818544, 0.09097858598189694, 0.031486260638173134, 0.039810820017009974, 0.05563039918031011, 0.062309558636375835, 0.020387115588943874, 0.05731726437807083, 0.06404628937265702, 0.011292171298659273, 0.04115237195843032, 0.0733397492606725, 0.052407608899687014, 0.04522206893722926, 0.005734565767592618, 0.036714773292520216, 0.02501663958121623, 0.02720646377253745, 0.040638520781482966, 0.06488952519638197, 0.037567128626895804, 0.039377290422895124, 0.08891463851822273, 0.0050624089781194925, 0.013530416597080017, 0.03462551307997533, 0.05370220961049199, 0.04457334874730025, 0.02632033435760864, 0.00531068366918979, 0.026621369811307107, 0.09053783677518368, 0.007749928427594048, 0.06170504500291177, 0.12222087596143995, 0.04248239219720874, 0.07427825140101568, 0.011019598692655563, 0.05631801299750805, 0.04370723950809666, 0.024021791892924478, 0.07431080751121044, 0.024217187925907116, 0.011260074895939656, 0.0206935165583023, 0.028940546525908366, 0.009296131619651402, 0.13668826036155224, 0.16388211186443055, 0.10666578635573387, 0.13234026224485465, 0.19433234791670526, 0.18901229410299233, 0.117755884836827, 0.10768523093845163, 0.1298351923802069, 0.10321475046553782, 0.22168294100889138, 0.11452814803591796, 0.15948226010160788, 0.07973530143499374, 0.18981964220958097, 0.17331210656889848, 0.08165552839636803, 0.15886608245117323, 0.13246216784630502, 0.12982966910515512, 0.08494297627891813, 0.08881874794938735, 0.1318858609135662, 0.10709056963345834, 0.1072499303679381, 0.08005130876387868, 0.13779131402926786, 0.19161974133125373, 0.1066021126295839, 0.10547301000250237, 0.16244466256882462, 0.1483801786920854, 0.10184405544506651, 0.10619031651211636, 0.15294606797397137, 0.1366153314177479, 0.14856817360435212, 0.1893925451274429, 0.09783518234533922, 0.11895256276641573, 0.326859709407602, 0.08461945756737675, 0.09218676508005176, 0.16030701941677503, 0.13988234182553633, 0.15868826556418622, 0.0815139724207776, 0.07620748930743762, 0.1377341542392969, 0.11595236589866025, 0.1168673432299069, 0.1668700272483485, 0.11626280924039227, 0.08454559224524669, 0.11062791517802648, 0.111068528677736, 0.1941420595560755, 0.07739191967993975, 0.11652571441871779, 0.11632283244814191, 0.11573778598436288, 0.06770752862628017, 0.1289559467030423, 0.09138137793966702, 0.13642991493855203, 0.10797241409974438, 0.08482188491949014, 0.14768746229154722, 0.19200949184596539, 0.09737037907221488, 0.11941046533840043, 0.18535193694489344, 0.09315220506063529, 0.15601985874984944, 0.24034673880253518, 0.12192742313657488, 0.09606270638427564, 0.11107506975531578, 0.08471977896988392, 0.16009790849472794, 0.13009047082492284, 0.09123694497559752, 0.105176999100617, 0.09044822265527078, 0.1430342998355627, 0.1023605088038104, 0.1609942532543625, 0.10169781079249722, 0.18315517982201918, 0.13456682062574796, 0.1593003041510071, 0.09990606443690402, 0.18018341357154505, 0.20079619464065346, 0.13845774398318358, 0.09120440922145333, 0.14328670129179955, 0.13077864104083606, 0.09695924791906561, 0.12330859473773412, 0.14185348605471, 0.0913300264094557, 0.09525423869490623, 0.07925612000482422, 0.09093295450189284, 0.05112955426531179, 0.16084255996559346, 0.09620490696813379, 0.14712988292532309, 0.11778759956359863, 0.08828805892595223, 0.1774354145995208, 0.16812223648386343, 0.15234629730028765, 0.17333315472517694, 0.10339623144162552, 0.1255544913666589, 0.0820921113980668, 0.13248464092612267, 0.07838112874222652, 0.12163524595754487, 0.12157565701220717, 0.2364659256168774, 0.1631195063569716, 0.17699079774320126, 0.08154673887682812, 0.17530868229057106, 0.17128114269248076, 0.11393274712775435, 0.11049936671874352, 0.13886010167854174, 0.12769948983831064, 0.16946349665522575, 0.1564866637012788, 0.12411352725965635, 0.13482566816466196, 0.14077705810112612, 0.09377467951604299, 0.12940939808530466, 0.1493500495063407, 0.10521219471203429, 0.2133399322628975, 0.09342152918023722, 0.08481455674128872, 0.17550533530967577, 0.12695456695343765, 0.21807719234909329, 0.11804500860827309, 0.1923161218208926, 0.12239832643951688, 0.1372457854449749, 0.14558380017323153, 0.08065078766750437, 0.08021628776831286, 0.09754549538982765, 0.20907148559178623, 0.07522569663290467, 0.18676217698625155, 0.14274295046925545, 0.09304659108498267, 0.2458757406898907, 0.11237819625863008, 0.16593249541308197, 0.2249386470232691, 0.14477139019540378, 0.291690642280238, 0.14211119365479263, 0.18474300604845795, 0.14134499191173486, 0.09819056506135634, 0.20216627897960798, 0.08241140962179218, 0.1360788137785026, 0.10920709677572761, 0.17678943569106714, 0.09821349275963646]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.028370695853871957, 0.04150935262441635, 0.06041652735854898, 0.1048329547047615, 0.031953822156148295, 0.02771364325391395, 0.06667008929486785, 0.019758583512157202, 0.01920696846874697, 0.028038663224184086, 0.03473265715209501, 0.029164693783968687, 0.08610856373395238, 0.009502978779242506, 0.051777728234550784, 0.011765738699718245, 0.022449427783223133, 0.05131601908111146, 0.012054795465831245, 0.011121616432709354, 0.07629772767956768, 0.017829198024368713, 0.0435536972114018, 0.021371206800852503, 0.07684164813586644, 0.017963990702160766, 0.01642387736189578, 0.01621838303149811, 0.06518557681036846, 0.02873096741469843, 0.03279061528987118, 0.02661839613158788, 0.030032801308802197, 0.03217928916481989, 0.009113106128227497, 0.03807295273457255, 0.04120390330042158, 0.029080853997064487, 0.020274675551003644, 0.05488344408305628, 0.00903999906898077, 0.009622591780498624, 0.06913736475897686, 0.019177077304837958, 0.021780170034617186, 0.0730886845184224, 0.02537993571188833, 0.026647064236125777, 0.009916014919456626, 0.02859890753669398, 0.012169625643374664, 0.06562601389097315, 0.06460959557443857, 0.031382119083510976, 0.01795791442106877, 0.023174876713060906, 0.042251937956150086, 0.03136126770238791, 0.004921100667810866, 0.02347713692246803, 0.02200855135119387, 0.03600697645119258, 0.07265459852559225, 0.022302589412512522, 0.01981670342917953, 0.024179251033014486, 0.058639294867004664, 0.03325520482446466, 0.04092664371377655, 0.01593624647440655, 0.03392508173627513, 0.028507339235927378, 0.04558257459263716, 0.026356081278728585, 0.04079622928319233, 0.07011889280485255, 0.07257938970412527, 0.05688499685909067, 0.06382775359920093, 0.038188093341887, 0.07305639982223511, 0.046953697090170214, 0.05419356735157115, 0.027501110819035342, 0.04798634257167578, 0.04418038876195039, 0.06279849061476332, 0.005813827139458486, 0.05148795985483697, 0.04316345815147672, 0.03221686304147754, 0.038908538075962236, 0.023543679155409336, 0.03745764700163688, 0.04188490818653788, 0.05250649180795465, 0.030702064146420786, 0.041716502580259524, 0.013468194935869957, 0.033587798941880465, 0.015477343063269342, 0.057228668060685904, 0.053142672670739036, 0.045549580827355385, 0.013352742202446928, 0.0624409094452858, 0.059505458389009745, 0.02011285343074373, 0.03531650260889104, 0.021671996285606707, 0.06549387598144156, 0.028602917678654194, 0.019365314793373858, 0.07914826007825987, 0.041495123745075295, 0.03471135454518454, 0.04256191650139434, 0.07517463008740119, 0.0485804847973798, 0.01855271991475352, 0.03251262627808111, 0.031043384224176407, 0.03585017040105803, 0.03723535553685256, 0.09623285582555191, 0.013918586973366993, 0.052980574047459025, 0.034687619390232224, 0.020858756798718656, 0.02227304599780057, 0.03400073839085443, 0.046521928294428756, 0.02021487965248525, 0.02626928816815572, 0.032869576409991295, 0.022029604596484984, 0.01809824224827545, 0.012272111572591322, 0.057219582476786206, 0.05732234660536051, 0.030806039460003376, 0.016233454990599836, 0.07175881695002317, 0.021133412507229617, 0.01758792284610016, 0.04925256355532578, 0.013815974667003112, 0.08834576832928828, 0.017194443781461035, 0.03418227704241872, 0.02890847556825195, 0.005049564734300864, 0.015380066586658359, 0.039268249845398326, 0.01192325127444097, 0.04973533443574395, 0.08471323789230414, 0.051598846047584496, 0.02185410151391157, 0.05908619838633707, 0.045793639695537944, 0.05581558495759964, 0.041644068967018805, 0.050263536628335714, 0.008392160126407231, 0.043809908641768355, 0.03987034110884581, 0.045195517861949544, 0.027735022196014012, 0.02144407298016761, 0.013236416703356164, 0.03239815063508494, 0.03355186033461775, 0.08161026332527399, 0.015413000980126006, 0.04941066560734596, 0.03692901733198336, 0.03356793482920953, 0.03619854724300759, 0.05885992731366839, 0.055928306587572606, 0.048398094584367106, 0.05714378332985299, 0.03526507643982768, 0.004158254704504673, 0.0326806586900992, 0.007334263812351439, 0.049577154352196624, 0.07489039176808936, 0.015363617201468774, 0.04979295562952757, 0.06807697058788367, 0.03027911630592176, 0.11276363807597331, 0.013539585301519504, 0.019378464802035263, 0.03805001485826714, 0.05342681938782334, 0.031149951541530232, 0.023676242845665132, 0.0563731609311487, 0.024838310400290147, 0.06187106216592448, 0.023160698723846247, 0.044661086717886586, 0.0022690098641240703, 0.0089868316094258, 0.009056954810928022, 0.02203331109402435, 0.059715831386191506, 0.00993572296907327, 0.0755068136911307, 0.027786982711404562, 0.03850870792354856, 0.02258410002104938, 0.06553443880485636, 0.011457451403007975, 0.0129547093196639, 0.03144863587138908, 0.05522123917139002, 0.024468900669100027, 0.08549521557454552, 0.05764728345509086, 0.03835536240200911, 0.055519845469721725, 0.0552235597611538, 0.03645003606964435, 0.04424979950168303, 0.05880539345421961, 0.017351168407393352, 0.008695091237314045, 0.03222714963236025, 0.020010755962825248, 0.03728640511898058, 0.06663009644086872, 0.028723900472479205, 0.012277431287137526, 0.01972119792896722, 0.034023818759513755, 0.07805967277714185, 0.02766253599630935, 0.041817173428301296, 0.03168762608298233, 0.04112112202814647, 0.03847342410257884, 0.054150246283305545, 0.007840313532921885, 0.040500082674303224, 0.17073398562414305, 0.05100823898932763, 0.03718299298946347, 0.07754613033362798, 0.04801297846383282, 0.026501135102340152, 0.028235891301717077, 0.07244615935321365, 0.02732899532254253, 0.05148619566378849, 0.05559691347713981, 0.06013289972075394, 0.03710117184423974, 0.052168347274086306, 0.026530608967212693, 0.04742684634402394, 0.06457006412425212, 0.01625203836842307, 0.08845564350485802, 0.019377891439944506, 0.03305119648575783, 0.03781415269310985, 0.06962567927049738, 0.03824595880827733, 0.028980603840734278, 0.026216487965679595, 0.021445028018206358, 0.0035690797792215434, 0.02085832762531936, 0.03181173013789313, 0.035158509122473855, 0.03154695898826633, 0.01574872144764023, 0.03955491053472672, 0.026822518124910336, 0.0143586389853486, 0.032856406045279334, 0.03348014936117189, 0.03709755864526544, 0.03245751905654158, 0.008361024698907775, 0.010814352875708469, 0.036788180603512695, 0.030522516995136226, 0.02511850804356592, 0.012085204012691975, 0.05494327051565051, 0.023503160436770747, 0.0173529783995556, 0.05151625815778971, 0.11946442244308335, 0.031238493576113666, 0.13461879640817642, 0.07484961859881878, 0.05269118904003075, 0.05347294619839106, 0.05601067395348634, 0.05362496179129396, 0.03664858898680125, 0.06097592519862311, 0.06508852594665118, 0.03123428326632295, 0.058458037807473114, 0.007224479390840445, 0.009420687748518373, 0.013070697247582887, 0.012369651829690805, 0.08321947697550058, 0.06020076000796897, 0.015340787890766348, 0.08108021891010658, 0.05407397894720946, 0.05620109462844474, 0.011506169369178159, 0.029537884651550224, 0.05439614737406373, 0.011685388279147446, 0.015705700631120374, 0.07114603876003198, 0.02936999812456114, 0.026067325612530112, 0.0355788344251258, 0.06765045026051146, 0.020991128802831684, 0.016371287505275438, 0.0364660766374852, 0.015113219119874495, 0.004917222416094903, 0.064539095786001, 0.06665410300982849, 0.06386369559913874, 0.01345435536599585, 0.02186362136022321, 0.041524042907570086, 0.022106138257575885, 0.007737636765731233, 0.03309391026518174, 0.008945020281576684, 0.05514305836654135, 0.0362803751735815, 0.03934061899781227, 0.08136286267212459, 0.04236610486571278, 0.0162102287369115, 0.11251832052533116, 0.12011102560375418, 0.15059300352420124, 0.2116529449288334, 0.0925077935680747, 0.11698364413210324, 0.15250644513538905, 0.0917116752160447, 0.1412699595093727, 0.11132426852626459, 0.09644962740795952, 0.11490734054573945, 0.22973987939102308, 0.13759022339114121, 0.1532174955521311, 0.14017774883125508, 0.1102262292323368, 0.24245231438960346, 0.0525995969905385, 0.1445582623460463, 0.13165217345314367, 0.204835676455072, 0.15880105165498598, 0.09147876807089363, 0.22465975555990422, 0.14028946283672536, 0.1830802017024585, 0.0830824603991849, 0.16219262752149785, 0.073943842202425, 0.09425587619521789, 0.08110704818474394, 0.08761092168944222, 0.1368191633373499, 0.08451608954263584, 0.14730395429900714, 0.12381593537117754, 0.12842280816818985, 0.05262754584795662, 0.16859327549380915, 0.12108397696699415, 0.058032609921480925, 0.085813061733331, 0.2042247506656817, 0.07069949486425944, 0.17535147070884705, 0.1032242499557989, 0.10712747515312263, 0.1690814678690263, 0.09091907167541129, 0.15088318581027643, 0.14782304715897354, 0.15986652805336884, 0.13257625672434056, 0.09166677655386073, 0.09125067852437496, 0.08088814600237779, 0.11087692395917007, 0.11376237376992192, 0.0829399884013193, 0.15254018189651625, 0.11547608859837055, 0.17195081604378565, 0.10824697650969028, 0.0645933650167925, 0.1064871484413743, 0.15356558401669773, 0.10269993916153908, 0.0832360332299556, 0.1027822115325502, 0.07975860232753412, 0.1752847707165139, 0.20224426979465143, 0.14021216412740095, 0.1039459669430341, 0.22485017962753773, 0.14417332942996705, 0.09599136521241494, 0.2738406929586615, 0.1438903531857899, 0.21795406538460935, 0.15630625481052057, 0.18341625295579433, 0.09561871378017323, 0.11828054168394633, 0.14791265449353627, 0.20402778552046844, 0.08661935132529054, 0.16237599482493742, 0.14221711297120365, 0.11886273830064706, 0.08500244987330266, 0.1300352516451052, 0.14776055408375605, 0.14200365942503723, 0.11937788208680493, 0.17753468427274907, 0.10082060072038855, 0.07575616852513381, 0.10962205486638205, 0.09356653889907257, 0.1297496969678572, 0.08430020005575248, 0.14767134029950413, 0.0598884846216866, 0.16530149855784007, 0.15146876153137, 0.07721829613936798, 0.10623332884694849, 0.06149780683751617, 0.1042680743017367, 0.11707808263599873, 0.1138589768005269, 0.18929959940058844, 0.10821144841611385, 0.06224035484982388, 0.10481381323188543, 0.18207816832831927, 0.1460287155849593, 0.12526031929467404, 0.07578204785074506, 0.1364995733435665, 0.18744106484310968, 0.11602993602199213, 0.13581151169325623, 0.21478713889207157, 0.17753800909434045, 0.09433778215731893, 0.17178746552339622, 0.18913703598082066, 0.08818298099296433, 0.1494981465595109, 0.19304701260157994, 0.08730337569223982, 0.12786993783499512, 0.12028379419020244, 0.08489488850214652, 0.16874138611767972, 0.1219118032604456, 0.1830516896609749, 0.1354649702885321, 0.0819844211052571, 0.2600574211350509, 0.10439515034002916, 0.10737507936677762, 0.11969515149082456, 0.07171218802354165, 0.19664578592138632, 0.09295720766697611, 0.12016556624855314, 0.09127546540860619, 0.10628185767148222, 0.09506583666162831, 0.17734107109052794, 0.14814778044819832, 0.10577669513544866, 0.13165222773594515, 0.136239653719323, 0.11401179645742689, 0.15892040596476623, 0.11181237947727952, 0.1715126181287425, 0.18187455353992327, 0.10340210076953683, 0.1827528356973614, 0.15589082853070327, 0.1839132798569543, 0.11590077009584222, 0.09508709516376257, 0.0952503914013505, 0.1541540367262704, 0.08783838698374373, 0.12238592281937599, 0.1976752592516797, 0.08582247979938984, 0.14556767818118843], [0.03438508437414255, 0.01750376245139965, 0.004814784408413938, 0.022119150862896016, 0.01657325854258878, 0.030602261823202883, 0.04959339848054307, 0.015494350543511766, 0.007458787710805024, 0.01856812265967684, 0.006786863319575787, 0.01286302990878799, 0.052421868313103914, 0.032931760751775334, 0.039411563226687055, 0.026796023028769662, 0.06213047967425414, 0.005012230465321669, 0.031324501282402446, 0.014418619784659572, 0.016868299139397483, 0.026668541565803543, 0.05001703503408602, 0.02910584444180131, 0.04432695232597845, 0.01620223220171673, 0.022386407147028616, 0.0650078413475837, 0.07577881123870611, 0.0624141480241503, 0.025663118909246156, 0.01135143030634416, 0.034688124898821115, 0.015765718749857376, 0.04217061892684017, 0.014330403446885092, 0.049904628922896724, 0.031180624717048237, 0.018437854114121625, 0.04681283661297389, 0.06225660576352051, 0.02593209019063839, 0.022060301520728638, 0.04692951070943049, 0.003944108628534845, 0.004899231908244214, 0.04738005117646285, 0.009312482617263283, 0.11604046688548156, 0.06739928373800856, 0.05121487665123173, 0.00959481340500393, 0.028614001548183814, 0.0114758507282074, 0.02261272571714861, 0.012000367627479136, 0.02650813588739506, 0.016768948041966984, 0.020398048484431844, 0.05057917754831059, 0.028374197094568183, 0.03765641026464956, 0.030578007588961294, 0.03292844271553414, 0.014744562562555075, 0.050310755880283456, 0.03551195462101272, 0.05896377031292234, 0.019816720392555, 0.04399599347795759, 0.055278534668364694, 0.021115885947697928, 0.03362346613513572, 0.04256070192371096, 0.04099442936213953, 0.027047830766865184, 0.02520109254068562, 0.003346103206110586, 0.04391353450981634, 0.026534625894523094, 0.03359495409365211, 0.04007373537336077, 0.06022225599735975, 0.004375169627434973, 0.04079801383029137, 0.009873338459458734, 0.013495679844969084, 0.057228057379169125, 0.017527472161288773, 0.002114046672691724, 0.01659390127419361, 0.0523060050659946, 0.0640022728059973, 0.056561142272715054, 0.04260539024003914, 0.03594673950491207, 0.021862233756110072, 0.0392238804405289, 0.011420412720846278, 0.007163220401188093, 0.031114922171192508, 0.029086787785802568, 0.01656228832767478, 0.056176616477647, 0.05853982163327081, 0.042109147046825716, 0.007507875478560371, 0.03493845682325108, 0.00599169873333137, 0.01712298216963453, 0.05900125937270267, 0.01886058651975223, 0.007977197794908924, 0.037691795865872076, 0.020558603440544436, 0.011693360217447792, 0.02299805387987622, 0.03525532249893461, 0.009892812414493943, 0.0312901843738343, 0.010323763575537928, 0.018546097412971512, 0.025004103646746705, 0.010526333420005227, 0.08485367428511381, 0.09274654289973633, 0.03197738428467086, 0.039138473237731626, 0.02172475747231926, 0.042320537846535444, 0.022365944227203727, 0.03554577619901725, 0.05425647772582514, 0.09233362041413784, 0.038837129050599675, 0.03071705637765782, 0.0427595364329006, 0.0379188540391624, 0.05423033716423171, 0.032163173958126984, 0.0388180893579764, 0.017054843683061854, 0.013066821116288858, 0.038592978580189605, 0.023588196141645312, 0.013347255398652383, 0.048145387787371874, 0.018380110784034644, 0.054998927350555143, 0.07678755532417979, 0.013814445418704833, 0.0185722583306155, 0.00706685019291139, 0.01774586035337831, 0.02471647604501673, 0.05824343075177499, 0.014037819995012666, 0.04648178616272552, 0.04921258087935192, 0.052639498242310116, 0.01528256619349122, 0.06528449364538703, 0.008820011230584766, 0.03033658822200128, 0.07399591976510626, 0.028711697020168816, 0.030115521512925625, 0.032931238279810975, 0.0181779395788908, 0.01715591995577727, 0.03464075976184436, 0.015344752231612802, 0.016510721362595047, 0.06380684793527637, 0.00617674710727962, 0.01350415644368955, 0.011190890617269491, 0.03853802742170436, 0.05598092019291861, 0.04138940798916987, 0.03995996540678399, 0.02028487223599638, 0.024398955583040203, 0.019398880224408846, 0.03641381587034889, 0.044641907925584486, 0.028464954545987502, 0.03585895064419933, 0.045903229886399846, 0.04015575668641499, 0.0347662480281932, 0.012402795720845461, 0.06508101456399475, 0.04859093762934208, 0.045260680972465446, 0.06648282041507107, 0.016198332321697047, 0.009784518225517656, 0.016592196454959254, 0.043091682717204094, 0.028200344548427632, 0.06406444696975605, 0.039958649048847814, 0.07161343403692756, 0.0522534932409014, 0.07357803718852145, 0.039023492086146555, 0.05025999806821346, 0.024414185301533768, 0.060893693539713106, 0.030174584593623877, 0.005532875898227627, 0.032241039244191985, 0.03536963529352631, 0.04011620148750288, 0.051057968820844374, 0.044777143347476206, 0.05419092445767351, 0.04348214908636042, 0.04877494614837425, 0.06841437891125679, 0.02301057624364538, 0.028981536826384918, 0.007590463368355164, 0.06457043053316218, 0.0724598386191896, 0.08178322868687765, 0.03992532958675708, 0.005417693306558898, 0.025860737144414867, 0.04765852873346635, 0.023845074232667685, 0.02582512253762356, 0.010052246091488217, 0.04331808610420142, 0.018189420391406332, 0.050214838170047314, 0.0359798587991723, 0.025171910445871096, 0.03074049297720194, 0.05282010730089886, 0.03277327872014471, 0.03158835640975407, 0.008990340483640986, 0.035297133826783726, 0.017432506096416285, 0.02222597093454429, 0.03577375378725784, 0.058921205811202526, 0.05526580195873976, 0.0340953329578042, 0.02470655077403145, 0.04083808471581765, 0.009900333975175661, 0.020425585131826143, 0.057787428077842505, 0.052314245873796086, 0.04575219477659889, 0.035552978848240206, 0.0421764780767262, 0.02513059614492314, 0.01832858283471848, 0.04237012857837336, 0.013361877828304256, 0.04933298352573599, 0.02866087474727205, 0.01002744648472539, 0.013217949524654873, 0.015567075926810503, 0.03983021594051804, 0.06434386090508529, 0.047132674272039106, 0.01571561742041792, 0.04469055888642158, 0.04060268734714814, 0.046342242043465376, 0.030097689612635543, 0.0276950412163777, 0.005522983705824507, 0.014672415630359734, 0.026184864841135483, 0.04842185688072017, 0.054972349133874686, 0.032904653277780326, 0.020811464604256407, 0.08565890536244426, 0.04385254438966513, 0.06344686475183282, 0.025176480379221693, 0.026083121907764246, 0.068607157495405, 0.06102118348436696, 0.03344000722946865, 0.056245833834899325, 0.017912790145991103, 0.046943142477955134, 0.03022476565092802, 0.046367809242968044, 0.026639337418600917, 0.03540057988305177, 0.04836903971486858, 0.052670327480882406, 0.024176072096452117, 0.04347529588267207, 0.0612585214631898, 0.05464655393734574, 0.04194356414622494, 0.030687550282371894, 0.01647757662327162, 0.057722627983561585, 0.07162166466670376, 0.022074796725064516, 0.08732371817209891, 0.04221795692241617, 0.0548208288715354, 0.008999667795641082, 0.07228185888379812, 0.0054259209677443975, 0.027408380527049303, 0.02260942125160779, 0.009498730301856995, 0.02156386324869735, 0.03202333128345864, 0.027305860671081712, 0.008404619725687163, 0.0294174582564405, 0.036560487999979935, 0.053137770255229304, 0.025263125908428004, 0.021396824890481572, 0.054750257836920876, 0.0218622456304729, 0.038725503254681826, 0.05421735339664987, 0.013685623000908111, 0.029630871090505804, 0.03120119111346347, 0.03940107307529875, 0.008645399573392101, 0.046040931783084355, 0.05856897828302213, 0.0349497917507376, 0.016385127923318317, 0.019621348108298013, 0.04055247914844325, 0.025612211819472055, 0.027510506832706075, 0.015077373811176844, 0.008457469970120915, 0.016897696669080427, 0.025599043151097636, 0.07501706068537065, 0.09466438141784497, 0.11644981349153177, 0.12600703351199627, 0.0799877436033317, 0.07632531012807574, 0.08950043815587248, 0.10219806073499577, 0.07175106808011021, 0.13590504096022674, 0.12267835784171309, 0.10269949811377696, 0.09129435582352535, 0.07822037701095853, 0.09525705461523362, 0.1344045286199876, 0.08330117937709604, 0.1299347606088434, 0.09009902817862374, 0.12210087025804178, 0.08176921693874256, 0.11812955407159668, 0.14446767792105675, 0.10607489770544426, 0.11031208426824637, 0.16492599727852003, 0.0790040171039956, 0.1913082937576941, 0.17279059812426567, 0.1767362385456051, 0.186526304643069, 0.1355075958584036, 0.13321838155388832, 0.0948703575081059, 0.11891262419521809, 0.10896477834986788, 0.13443836037601742, 0.18672492541372776, 0.11056700987475258, 0.10176930124206202, 0.18532284136329377, 0.22132622157888754, 0.1772292349487543, 0.1129779058641621, 0.1468157483530896, 0.15443106900368417, 0.10974871699831315, 0.13883458876184054, 0.12396522664598056, 0.17491780540772847, 0.19764095252113684, 0.2772194173719202, 0.10491742552923304, 0.09979130380920001, 0.09135083707847766, 0.11993115954101086, 0.09990257676690817, 0.19503479450941086, 0.09302404336631298, 0.11659165445183005, 0.12299228885344096, 0.12936916095869883, 0.11341602235500302, 0.07456774836672203, 0.10860673577657767, 0.16258421008075985, 0.16361392768365995, 0.0812522614640849, 0.16552994772791862, 0.10254024594490017, 0.12704813693250927, 0.09716130207691874, 0.12795798453901494, 0.14989652803965978, 0.1095483795340572, 0.11613228624420506, 0.10141556058079004, 0.09711035088236843, 0.05215703270265034, 0.16241779258208616, 0.09034855264638152, 0.07689413960490908, 0.20089042958404335, 0.14182984589466027, 0.11932159082165786, 0.0866414579961981, 0.1459348334797791, 0.10221927173967872, 0.13180971571377345, 0.1888019618179117, 0.07795513767216887, 0.07790655456483364, 0.16562387054519995, 0.1473062341766698, 0.21680854899542673, 0.3013826464968068, 0.1442878118583134, 0.10951728905950274, 0.08039884761508022, 0.13051192249570573, 0.1047115647899253, 0.2968168114977223, 0.10494095033832959, 0.12990048101970128, 0.1321063305118254, 0.2533828621464116, 0.07563857840640204, 0.176288690418005, 0.10580439293490988, 0.1055841947506581, 0.13940641736345633, 0.1709159958575453, 0.10542695104543652, 0.0753245252583708, 0.08916596110377993, 0.148262493578451, 0.12319112675530569, 0.08977856966001646, 0.14424529485404491, 0.08259818317102534, 0.07568610299910818, 0.10242718844009296, 0.09622847248933145, 0.11550236147429262, 0.09522800653108529, 0.19351509319884436, 0.1780981533229351, 0.14168929415089743, 0.1331971434078046, 0.1442921816238335, 0.17198221864444868, 0.10623976135892527, 0.09271425141819886, 0.1005677989284907, 0.09881208956773792, 0.12621020046728, 0.11858335829206876, 0.1933468979384218, 0.11056232119777373, 0.1671989538839885, 0.1366812035973583, 0.13890682559992584, 0.06520620427493538, 0.11852191016077995, 0.15571842635316507, 0.15211651820157254, 0.13816961087286472, 0.13074670918285847, 0.10418773575552873, 0.13913184138281004, 0.11439805930214268, 0.11468634169016566, 0.13360857990171227, 0.14544768604849065, 0.17647733672388963, 0.21358937530645303, 0.10823051525013787, 0.1314716288553817, 0.12445259120847497, 0.12872398272156715, 0.20453481402780327, 0.09426326544157096, 0.1759711495999779, 0.08530301374516316, 0.07185195266668286, 0.2066993543079921, 0.11375925250883613, 0.1093122764889683, 0.09010634957147495, 0.07830936009330408, 0.12926356733909675, 0.08702768691416297, 0.08866685110011271, 0.12839424184390477, 0.16094028257897922, 0.09770830986755234, 0.15406293661466666], [0.0162033263394343, 0.04027947397636516, 0.03314151967476521, 0.06562399864196777, 0.025418949779123068, 0.02525273075194231, 0.05362431379035115, 0.00947723091979112, 0.02336090726644865, 0.07172437451247658, 0.045419716010136266, 0.013449424960916596, 0.022853860099400793, 0.021341509019423808, 0.04746062042457717, 0.021282657980918884, 0.05934073044253247, 0.0361141510573881, 0.041729757761848826, 0.027096337539010813, 0.021173569905970777, 0.07354593569678919, 0.04579616045313222, 0.04747585692842092, 0.011669661533752722, 0.03618578399930682, 0.05246617325714656, 0.026753550129277364, 0.013489084484587823, 0.06564345902630261, 0.027364679479173253, 0.028019372473603914, 0.036628585774451494, 0.022785195748188665, 0.042265108320862055, 0.016775256721302867, 0.007848184539138206, 0.013578989526389964, 0.051544977152454, 0.0202879510886435, 0.05608388448932341, 0.01489914980317865, 0.017388671037874052, 0.058820965832897594, 0.04407537528978927, 0.029857800342142582, 0.04951309046841093, 0.04707282409071922, 0.017495947424322367, 0.045726088141756396, 0.012169709612083222, 0.04668047817956124, 0.02242567905757044, 0.010824779414438775, 0.06599086217050042, 0.0417217374779284, 0.07222196459770203, 0.06764952066753592, 0.05496912269986101, 0.013093155908531376, 0.06091153222535338, 0.04910695333299892, 0.04759928244831307, 0.004584440429295812, 0.032758697002593956, 0.016645256197080016, 0.02141168650372752, 0.037360877729952335, 0.017710853035428693, 0.04388133802318147, 0.10424339598310844, 0.0345128728742046, 0.059548111100281985, 0.08597344027033874, 0.01058689012591328, 0.018752234655299356, 0.0345034344520952, 0.025692636878894906, 0.016638525129695023, 0.03020996001682111, 0.05113273659454925, 0.020742535624387007, 0.019651994142415266, 0.022329603587942462, 0.04876245431868093, 0.02068735206765788, 0.04331780451216868, 0.03112660315153854, 0.03382881458050438, 0.007570522072325859, 0.04309270051973207, 0.032432399690151215, 0.03560326507847224, 0.04080669907853007, 0.047631020923810344, 0.01863919411386762, 0.029095289829586233, 0.05284337087401322, 0.04647795243987015, 0.06657214955027614, 0.049156628881714175, 0.04094532717551504, 0.015743160853162408, 0.060697542636522224, 0.024560969389442886, 0.028635578961776834, 0.01758386181401355, 0.018293801129662564, 0.017250460239925554, 0.03497108417962279, 0.01970603776031307, 0.07787049042859248, 0.03912737579750163, 0.011078825469927063, 0.01868344477510878, 0.030606763903051615, 0.009275049536621996, 0.02759667738739933, 0.020092071599460075, 0.04757208676476564, 0.005867147269392652, 0.03207797710118549, 0.0413260362111032, 0.057245692504303794, 0.01815956654692335, 0.021991428519998277, 0.065745571761259, 0.02750127706011491, 0.050540375523269176, 0.05458518723025918, 0.057911742478609085, 0.05238865741661616, 0.05648667644709349, 0.0339831304071205, 0.0552398751356772, 0.028827631513455083, 0.02576036824445639, 0.032721750770828555, 0.0021116762530125144, 0.007379582318078194, 0.040830291741128476, 0.03309256337316973, 0.02525612342703555, 0.04891579984022038, 0.012255948868447115, 0.0400719135068357, 0.018316365811707716, 0.026091279595025947, 0.02806681055309517, 0.054612131855849705, 0.08287931379995175, 0.014189039157437426, 0.023155124558668052, 0.016961314416091357, 0.04148466073508773, 0.05113040582676019, 0.043762855630900176, 0.029413129203021526, 0.02862210325630648, 0.01702812297402748, 0.08421674024845872, 0.0701578746416739, 0.03146660687135799, 0.01995050035683172, 0.017737339649881636, 0.03204605881390827, 0.041037295811942646, 0.026855233690834472, 0.08183686688010182, 0.04418294005362051, 0.04266617679968476, 0.04679407851238336, 0.03820226115307637, 0.06691774100597415, 0.024335909501782486, 0.0407362976776702, 0.026922559631722312, 0.04908688905249749, 0.012237647930825395, 0.043638693900512796, 0.07207388790058238, 0.06322856646563325, 0.01659598607303841, 0.040004745325339694, 0.025399397792560712, 0.08437926974147558, 0.0572943366797907, 0.010824441843266999, 0.026942571325759803, 0.032926973687218766, 0.03615091747737356, 0.04528804289709244, 0.011430231970734894, 0.035902858645256074, 0.04376203799620271, 0.05280965107626148, 0.0022088920855562067, 0.023439666522400718, 0.009159295703284442, 0.06133776078266757, 0.01634539121628872, 0.05236116996301072, 0.05061038337381823, 0.022352032562983886, 0.02646492508106998, 0.07469272094645671, 0.018088540893846324, 0.041129688532756906, 0.06291681355131523, 0.032391036195414405, 0.026375662103029232, 0.024755809023710232, 0.03301137665818844, 0.03299025725573301, 0.016411967375980954, 0.030000235020582165, 0.034102182768817456, 0.06973879105810608, 0.018533318902232816, 0.03184823192922132, 0.08615492803177663, 0.091915846403156, 0.026049269795683876, 0.026321347071123973, 0.01172665338630655, 0.08546380618853228, 0.07253923400172166, 0.04335070328254785, 0.029426543840340207, 0.008962450149868215, 0.04580000774668796, 0.02440088431883071, 0.010637333267368376, 0.018576197226398757, 0.03109727008268237, 0.04187625686505011, 0.026115542310955267, 0.029706615954637527, 0.021509812845449363, 0.025986705474289398, 0.03266275215095707, 0.04571074985765985, 0.035627057908901145, 0.02823989126565201, 0.01627342409587332, 0.06622789480856486, 0.0385920761286148, 0.01682532242765384, 0.014519943722656794, 0.03570278241698231, 0.04085523808108909, 0.025059984398207495, 0.004873374635021069, 0.01060677205012845, 0.050877688851739676, 0.0384902619490666, 0.01989339824233736, 0.06278578165386405, 0.04573398968204856, 0.009172606864012778, 0.008016725004251515, 0.06837498316807405, 0.054843566580010314, 0.01839035327014114, 0.005510574996670974, 0.024326499917411377, 0.040107058228126595, 0.003856194662928049, 0.08970178663730621, 0.0541996198839375, 0.03173386824450322, 0.013787107242803489, 0.030459413238401924, 0.016809997714257667, 0.008356089204815882, 0.0409034276381135, 0.054778610422675095, 0.005620252973000918, 0.02290497923136822, 0.057047546708158085, 0.02022331384276705, 0.06215199601969548, 0.06503940001130104, 0.07306239128644977, 0.04126700705715588, 0.026736556219735315, 0.0454336022292929, 0.05926765900637422, 0.0267865167531584, 0.0420070410972195, 0.013782656901249928, 0.03123008313455752, 0.014194542924607438, 0.045471701970590014, 0.08201744540461472, 0.027947971929929087, 0.005551022893216993, 0.03791137997593198, 0.08102286913033042, 0.04267040068017585, 0.04608087713963219, 0.049423472955822945, 0.02946108127278941, 0.017268857020618658, 0.010467416224335986, 0.017155497567728162, 0.015384974091180732, 0.08028400556317397, 0.03137682990304061, 0.01819573076707976, 0.036890021924461634, 0.022381894889154604, 0.058116273289280276, 0.03229898952745965, 0.06164032633283308, 0.006017509357271982, 0.039629244046019654, 0.05158005062756794, 0.016599512758797834, 0.026003439844186817, 0.041273310647479126, 0.031331476622394154, 0.008511684918110924, 0.02802343011301543, 0.040477294075701914, 0.016491218569821546, 0.027475828604240502, 0.017852242769939557, 0.02582922258547374, 0.07414519746920892, 0.04288978462240525, 0.015070227141092931, 0.019562637865809456, 0.06752179323562554, 0.030766263737210205, 0.014004007746864642, 0.03370670881122351, 0.04525445541366935, 0.033838649945599694, 0.007706862658129207, 0.01980117685161531, 0.04831414623185992, 0.019246479562882866, 0.07543184235692024, 0.006968665751628578, 0.04020397677751524, 0.07056189474782773, 0.024243706770773445, 0.04971113448430385, 0.0076573923662570965, 0.03342679954533066, 0.055551251463059864, 0.1352775182042803, 0.1100576947044049, 0.11835915675120694, 0.10177082116050379, 0.15482459217309952, 0.10261787713638373, 0.07787649546350751, 0.08406826321567808, 0.11796057171055249, 0.14231406205466815, 0.16942031468663896, 0.06593760395688669, 0.1024536309497697, 0.11549295697893415, 0.16413915450019495, 0.09197595782045807, 0.16618921235203743, 0.14724352397024632, 0.10443380648004157, 0.12742874079516955, 0.0734179164948208, 0.11525648752493517, 0.1211512740701437, 0.16951069555112294, 0.09788947871753148, 0.22297512952770504, 0.08535292678113494, 0.07051393589270966, 0.09921530900256974, 0.13039836287498474, 0.059037567781550546, 0.09000177375440087, 0.10909298075629131, 0.11605828521507126, 0.15971220204872744, 0.14722529851964541, 0.06615285562085253, 0.19789741161678517, 0.17480770631560258, 0.10746282073003904, 0.12933368714792387, 0.10563821292349271, 0.16435893199273519, 0.08117859291711024, 0.1688309120280402, 0.1394222408000912, 0.1548001513417278, 0.09037646079169852, 0.07808202372065612, 0.11757824436894485, 0.1124646755467568, 0.16197997464665345, 0.09323001945657389, 0.12974255877946103, 0.15168619129274571, 0.1238416518483843, 0.14405280803995474, 0.13532378072185175, 0.15036793345851557, 0.12497571456645216, 0.12747732390250477, 0.11626540124416351, 0.204162651140775, 0.13959796779922076, 0.09742465508835656, 0.13782674712794168, 0.1141803716974599, 0.13277144410780498, 0.09147362477545228, 0.1685480172080653, 0.14411041566303798, 0.16398343071341515, 0.12536287307739258, 0.12034347813044276, 0.1268452549619334, 0.21934415293591364, 0.10151543415018491, 0.08810725648488317, 0.09521517543388264, 0.09489475762737648, 0.13979075316871914, 0.11302446693714176, 0.11492610882435526, 0.07815629616379738, 0.13520464354327746, 0.139283168262669, 0.24386138735072954, 0.09739520666854722, 0.05613802479846137, 0.11318591077412878, 0.12312688305974007, 0.10407442719276462, 0.11133076889174325, 0.16999896935054234, 0.14056614227592945, 0.10503183331872736, 0.07764647887753588, 0.1070605648149337, 0.18819626074816498, 0.20192983666700975, 0.17174836833562168, 0.16370805406144687, 0.09763462774987731, 0.19389649773282663, 0.05644006109131234, 0.10649060218461923, 0.08398177035685096, 0.15796382086617605, 0.1831022948026657, 0.11206202608134065, 0.12204307264515332, 0.16029883628445013, 0.08020918350666761, 0.11576122258390699, 0.1019607363268733, 0.11268213244953326, 0.06133230536111763, 0.10607064329087734, 0.10864433340196099, 0.1274262030741998, 0.0862090615555644, 0.14019802345761231, 0.1813199325863804, 0.1734747514128685, 0.14121330183531555, 0.13122134442840303, 0.08550468792340585, 0.18918909318745136, 0.1366701570472547, 0.11450328651283469, 0.09732688497751951, 0.13168306036719254, 0.1025483680090734, 0.09626598190516233, 0.1453165388000863, 0.13024584177349294, 0.153955429526312, 0.10054498658116374, 0.18064708369118826, 0.11267817659037453, 0.2320927402802876, 0.11888635131929602, 0.13330439265285218, 0.1505292619445494, 0.10097935755870172, 0.09769936677600656, 0.13488030380436353, 0.13844550321144716, 0.13134072587958404, 0.18226142706615583, 0.2168268830116306, 0.1370311105357749, 0.10513735229947738, 0.17249539467905248, 0.11747528346521513, 0.07979021527405296, 0.13449162537498133, 0.11744659500462667, 0.11282550689897367, 0.08167388276862246, 0.1450879674937044, 0.16312720094408306, 0.09938072905476604, 0.0821752455085516, 0.06530180985906295, 0.15239477184201988, 0.12009778060019016, 0.12060383201709815, 0.17835024265306337, 0.15230527307306016, 0.16833969338663987, 0.1611021946051291, 0.12314732053450175, 0.08043599740735122, 0.1471514603389161, 0.10518010000565223], [0.019657890611727322, 0.023370532285688177, 0.04720990512786167, 0.023551365260833075, 0.021216354931571653, 0.05117910089237349, 0.058182477951049805, 0.0169926186291767, 0.02047157284271504, 0.043169636212821515, 0.03749136679938861, 0.01975438677306686, 0.018652378049279963, 0.010865822301379271, 0.04669984356899347, 0.03261186880990863, 0.04786291026643344, 0.007219488765778286, 0.04777865996584296, 0.032951445052666326, 0.027037929244605557, 0.06252721909965787, 0.05514045279206974, 0.028229908319190145, 0.04411625702466283, 0.04679745761677623, 0.02406609005161694, 0.030978319501238208, 0.029804257143821036, 0.07333780865051917, 0.05419593883146133, 0.02715685438098652, 0.034711229016206095, 0.05412646023822682, 0.06026957702956029, 0.0207539095676371, 0.0222801095473447, 0.025091185134702494, 0.0035172583635098165, 0.07484801047082458, 0.08426920457610063, 0.010663126927933522, 0.028497347807777778, 0.01476404839195311, 0.011227418701829655, 0.04084483613925321, 0.0642712644434401, 0.0077683922136202455, 0.03585802444389888, 0.06238681663359914, 0.022671395247536044, 0.025414406987173215, 0.03389343825568046, 0.03456188006592648, 0.015685936602364694, 0.03445854936061161, 0.01428148616105318, 0.06355184090456792, 0.0251382466272584, 0.017608038016727993, 0.026874619436317256, 0.04770540871790477, 0.045526100123035054, 0.06964456290006638, 0.02438067245696272, 0.035341638938656876, 0.04702955391258001, 0.08861322647758893, 0.03737609048507043, 0.02859325533998864, 0.04814255151099392, 0.03349604404398373, 0.027603683261466876, 0.01288756403872477, 0.04310939587386591, 0.030050565355590413, 0.06000806284802301, 0.007115783169865608, 0.017387408962739364, 0.018500713598249213, 0.07088303180145365, 0.05784158195768084, 0.022874061783243502, 0.0450383521882551, 0.05366931423278792, 0.01329428980326546, 0.042392035081450424, 0.026467104874817387, 0.07861254989568676, 0.03309758792498282, 0.0414238809607923, 0.030845153611153364, 0.04455106904996293, 0.036824719714266915, 0.03529212963102119, 0.02695358225277492, 0.03304492003683533, 0.05109012798805322, 0.034951189532876015, 0.02368949633091688, 0.03278656104313476, 0.0376419846101531, 0.009042339166626334, 0.022319990443065763, 0.008354221537177051, 0.037516805077237744, 0.018457884467872124, 0.035280913447162936, 0.027084437731121267, 0.0521433466513242, 0.037784005382231305, 0.02378204002577279, 0.049414156670016904, 0.02736731049870806, 0.01004936486216528, 0.02361842996573874, 0.021318728902510235, 0.047396658321044276, 0.06259212775954179, 0.01574824477678963, 0.04581476588334356, 0.049507808073290756, 0.026343139919585416, 0.008115274582191237, 0.04024840385786124, 0.02869998550574694, 0.0811959837696382, 0.0577804052403995, 0.03560438466125301, 0.04884288107444133, 0.07312480293746505, 0.02020837419799396, 0.045135413229997666, 0.010186434024944901, 0.03967351167063628, 0.07104050620858159, 0.007775820475736899, 0.029286826694650308, 0.01600187098873513, 0.04837015251229916, 0.0387815943519984, 0.04781315329351595, 0.02158289954864553, 0.005987802245986781, 0.06062056962400675, 0.06852415909192391, 0.0036748443048314323, 0.01979268159318183, 0.03365322668105364, 0.02814837046233671, 0.04150439253343003, 0.033399919380566905, 0.04889587126672268, 0.004345510437685464, 0.09812515428555862, 0.030630078366292373, 0.08083680804286685, 0.09117104565458638, 0.024176214588806033, 0.05127298299755369, 0.04985556405569826, 0.09735549879925591, 0.024015624009604965, 0.02919601835310459, 0.03434451137270246, 0.028594636158751588, 0.037721539448414526, 0.04761870890589697, 0.05112555430137685, 0.01775821308339281, 0.01571335959514337, 0.048257240892520974, 0.0249436597472855, 0.05215718876570463, 0.025874665772010173, 0.054485876844929795, 0.04830343555659056, 0.023873299593105912, 0.03727212534951312, 0.0312930443989379, 0.02391334672990654, 0.030107050003217797, 0.03916613032509174, 0.04942730328600321, 0.034932183767003674, 0.05549377615430525, 0.03510624835533755, 0.007746119301633111, 0.02089787264620619, 0.07644833531230688, 0.01748484998409237, 0.04349910228380135, 0.030226601088153462, 0.0043960116787015325, 0.010988313987452005, 0.010989029841896678, 0.006163364700374326, 0.02979977542002286, 0.04201106480988009, 0.009866192637543594, 0.026462838585887636, 0.05652179741965873, 0.06338082972381796, 0.015498793251546366, 0.060307900687413554, 0.015610493686316269, 0.06567874963262252, 0.017924030078575015, 0.015966349680508887, 0.026107510152672018, 0.08890425014708724, 0.04740961494722536, 0.01348273763765714, 0.012857678811997175, 0.04956614172884396, 0.01911064194116209, 0.058218019615326605, 0.025968675102506365, 0.03377702200253095, 0.06050769532365458, 0.06330492879663195, 0.01867391135809677, 0.007982106147600072, 0.017943001917696426, 0.015506837284192443, 0.07130469381809235, 0.010164245929835098, 0.00895886663680098, 0.08499287574418954, 0.023548337298312357, 0.020681467472708652, 0.045739801334483285, 0.02807759417087904, 0.029510519334248135, 0.012458412691817751, 0.061149351964039464, 0.03309369652665087, 0.0704784756526351, 0.02415008420523788, 0.06462781423968927, 0.045135128245289834, 0.01526756548056645, 0.030623907090297768, 0.05954125789659364, 0.08098415192216635, 0.04899568376796586, 0.060817256569862366, 0.03685292302231703, 0.010251649721924747, 0.011159653409517236, 0.020590425036581497, 0.051128930013094626, 0.033427495043724775, 0.02389586257881352, 0.050841468652444224, 0.04166817731623139, 0.049052144666867595, 0.04381076020321675, 0.0065363821174417224, 0.03791522387681263, 0.05245439388922282, 0.03529431451378124, 0.01538258564791509, 0.008771730071332837, 0.012626473941574139, 0.03282210949276175, 0.033689270461244245, 0.06372872141322919, 0.009239792857053024, 0.04424210152189646, 0.014839759329333901, 0.057730783974485736, 0.027562538594273583, 0.03128945155601416, 0.023610935546457767, 0.014133805558750672, 0.005054109222588262, 0.03772942063265613, 0.01725758146494627, 0.009843865442754967, 0.03747982152604631, 0.008681186358444393, 0.048407281948519607, 0.05444390266867621, 0.006653541366436652, 0.08447140801165785, 0.027563883789948056, 0.05332086614466139, 0.029518811032176018, 0.022286577682409967, 0.019072923875812973, 0.0567009374499321, 0.007480555962372039, 0.020202306398589696, 0.03435342053749731, 0.042317769423659356, 0.05435396624462945, 0.0578413512557745, 0.05672302037211401, 0.041747640552265305, 0.0690400085545012, 0.00468827537094642, 0.02227972787139671, 0.019261310642052974, 0.027925615897402167, 0.028496954257466962, 0.0478557517219867, 0.02771890190030847, 0.023148766685543314, 0.009600647957995534, 0.04363612225279212, 0.06116086670330592, 0.03941800591668912, 0.020095659353371178, 0.04057639750785061, 0.05098826291837862, 0.03808071856786098, 0.04496633926672595, 0.0484049240393298, 0.01693116540887526, 0.02309455004121576, 0.017414272164127657, 0.056109058138515265, 0.03419652288513524, 0.035929915229124684, 0.017539249832874963, 0.02357445750385523, 0.02951643955228584, 0.022976132109761238, 0.06132536394787686, 0.02333882773694183, 0.039539504397128306, 0.0322637735599918, 0.05138733311157141, 0.03363846515172294, 0.035815364947276454, 0.04875371818031583, 0.08708216649081026, 0.027377515665388534, 0.07226820675922291, 0.042874544725886414, 0.01202980162841933, 0.01967551725517426, 0.03816261435193675, 0.08108651571507965, 0.005776264288994882, 0.024185893890847052, 0.03719436523637601, 0.052474159614316056, 0.007769850215741566, 0.011104049161076546, 0.053737164341977665, 0.212307907640934, 0.10175365422453199, 0.11356268769928388, 0.10994484076010329, 0.08769911767116614, 0.16205901040562562, 0.1898237405610936, 0.10887893688465868, 0.09645652810909919, 0.08520110457071237, 0.09666513012988226, 0.18638249593121664, 0.13566208471144947, 0.1623254982488496, 0.15246179753116199, 0.07986211284462895, 0.1264419880296503, 0.07009595153587204, 0.12191031048340456, 0.11168050619640521, 0.11827359348535538, 0.11723392855908189, 0.27758004516363144, 0.11929005251399108, 0.16067899231399807, 0.07771056651004724, 0.08739248769623892, 0.10725937557539769, 0.12562702676015242, 0.14912291669419833, 0.08412098538662706, 0.09935205416487795, 0.09273432248405047, 0.11015241140765802, 0.16361917954470429, 0.209834701780762, 0.12049027239637715, 0.09558882431260177, 0.10466826068503515, 0.10133984285805907, 0.11606099935514586, 0.12230643922729151, 0.1555174985634429, 0.1314285418816975, 0.15987066711698258, 0.26025077647396494, 0.1174013502895832, 0.17744594546301024, 0.1265276598611048, 0.1974272004195622, 0.12844697758555412, 0.1333991297121559, 0.17077461630105972, 0.09356640319206885, 0.061170264413314204, 0.14369056533489907, 0.10109002662024327, 0.1563097560512168, 0.13869391488177435, 0.057985634942139895, 0.15274385096771376, 0.16145824907081469, 0.18072484380432538, 0.17028395405837468, 0.09991810843348503, 0.09324031283280679, 0.08844326702611786, 0.0997639995600496, 0.24500580451318196, 0.08644469641149044, 0.10387323477438518, 0.12305689895791666, 0.05775181856006384, 0.14935600704380445, 0.16681893356144428, 0.21607525620077336, 0.11081493299986635, 0.10979482345283031, 0.14922743822847093, 0.10797876518751894, 0.14469215087592602, 0.134280940251691, 0.10200982833547251, 0.09179322833993606, 0.1519640242414815, 0.0657899072393775, 0.10675405019095965, 0.1878102421760559, 0.16965580705021108, 0.1627076898834535, 0.07528548235339777, 0.13223073312214442, 0.15070353687873908, 0.15659778059593268, 0.12369652677859579, 0.08045509816812617, 0.10777609356279884, 0.10673131248248474, 0.16261684761515685, 0.10624248906970024, 0.15210396530372755, 0.09025344917816774, 0.1623017088110958, 0.12330400784100805, 0.10046762001833745, 0.07767106220126152, 0.11322943879557507, 0.1299670860171318, 0.10418942530772515, 0.2084041056888444, 0.13180735441190855, 0.1230590431285756, 0.11250280242945467, 0.10767221663679395, 0.10868015326559544, 0.10040072325084891, 0.11536438816360065, 0.076415847055614, 0.11419890927416937, 0.11497987593923296, 0.14967539347708225, 0.08944163631115641, 0.0971565523317882, 0.14001110063067504, 0.13869643903204373, 0.1010191332814949, 0.1382456882191556, 0.12268865800329617, 0.21677528720881256, 0.19482252161417687, 0.1345521371279444, 0.07112398637192589, 0.09693092586738722, 0.1446503395480769, 0.10634890371667487, 0.12951447601829255, 0.08924916306776659, 0.10781896340527705, 0.17271526716649532, 0.1760137208870479, 0.20110279747417995, 0.11832746916583606, 0.09966365101614169, 0.10222636921597378, 0.14546390303543635, 0.2642704179244382, 0.11965439867760454, 0.2626115083694458, 0.11742678178208214, 0.12867915869823524, 0.1404427710388388, 0.10316428781620093, 0.09720647215311017, 0.1292756995452302, 0.1887763539063079, 0.20809576580567019, 0.11597160915178911, 0.13547768603478158, 0.10123181329774004, 0.11605987298701491, 0.1379815616777965, 0.14895738129104885, 0.10739842097141913, 0.17994019947946072, 0.1405126465750592, 0.1309659709887845, 0.05190339631267956, 0.17662130828414643, 0.13693178657974514, 0.0743499861231872, 0.06691292340734176, 0.11753017694822379, 0.17848045352314199, 0.1097180675715208, 0.0663903360920293, 0.11466606706380844], [0.012332156832729067, 0.03014491225725838, 0.06177443199391876, 0.011882193968631327, 0.015078985331846135, 0.04300765972584486, 0.029781885844256197, 0.028445852088875005, 0.04167221799226744, 0.09557029352124248, 0.026468351682914153, 0.016023536611880575, 0.02495728642679751, 0.02486059009762747, 0.010147164658909398, 0.020464524560208832, 0.019194741267710924, 0.09602092219782726, 0.0621575125093971, 0.05721057831708874, 0.02268542904805924, 0.024877738373886262, 0.07404379041067191, 0.01504059212415346, 0.02009994939102658, 0.018531642920736755, 0.01826534845999309, 0.0626733416159238, 0.05804717806833131, 0.021284585020371845, 0.07732450722583703, 0.014643710206395813, 0.019129471287929585, 0.03542332098420177, 0.017945632937231233, 0.009759419215177851, 0.029272034631243775, 0.028948990894215446, 0.04194433428347111, 0.05626086677823748, 0.00677383756763967, 0.0121926008391061, 0.02715049820419933, 0.004600345290132931, 0.044903717269854884, 0.032035256536411386, 0.13058344008667128, 0.019323822376983504, 0.06431124372673885, 0.048325355630367994, 0.02973397109391434, 0.012203188529903335, 0.039700785385710854, 0.038709598393844705, 0.024306976768587316, 0.01911073863240225, 0.02265804337470659, 0.02937294975189226, 0.007393929941047515, 0.0415237341741366, 0.021004411125821725, 0.06008686111973865, 0.008925637928768992, 0.01338613630338971, 0.10906666038291794, 0.05108690155403955, 0.029982036711382012, 0.02710834251982825, 0.02037031845455723, 0.027533846741010035, 0.01751873771926122, 0.027111741980271678, 0.04852684660415564, 0.0151913829613477, 0.06356521482978549, 0.008416913932056298, 0.02647267564732049, 0.014845964532079441, 0.052215932934944115, 0.01865381993619459, 0.04274234235552805, 0.05266139796003699, 0.06889533131782498, 0.026105379552713463, 0.007226406430293406, 0.0317047624848783, 0.048351194243878126, 0.04587972882602896, 0.02972097714830722, 0.049646263143845966, 0.04636750050953456, 0.0252505764032581, 0.021852749532886913, 0.017849964588614445, 0.1048761298879981, 0.02293277032939451, 0.0857424194525395, 0.004098432512754309, 0.035783975917313776, 0.02198882294552667, 0.00937411395300712, 0.06964039669505187, 0.057036676577159336, 0.021177446037264805, 0.07605949403452021, 0.017346211709082127, 0.022585082200488875, 0.06745723741395132, 0.01344183469856424, 0.005793530036628778, 0.06198249797203711, 0.025985095649957657, 0.07210597582161427, 0.038566973725599904, 0.009153736805144166, 0.034461141364382844, 0.09071993521813836, 0.030760452084775482, 0.028616607122655426, 0.05071590913991843, 0.03133272173415337, 0.044651468483997245, 0.025086637253740003, 0.016411293929974948, 0.020429803923304592, 0.024063708393701484, 0.0978050214637603, 0.01423798019199499, 0.03231113530429346, 0.04601617543292897, 0.031294567710054774, 0.06024652719497681, 0.011785975158480662, 0.029626698100141118, 0.057700344893549166, 0.018695298781884567, 0.033445734065026045, 0.003150304505002818, 0.0524976301406111, 0.06961915854896818, 0.031619273857878785, 0.013138037607339876, 0.08140203449875116, 0.04427069498758231, 0.009022643839541291, 0.04056546970137528, 0.03385286864691547, 0.05689407226496509, 0.05515352137652891, 0.017586659074627926, 0.0415810703832124, 0.02126435110611575, 0.07034826478255646, 0.03671345693458404, 0.03211123210244945, 0.08425177979682173, 0.00903100339097104, 0.02905400436637657, 0.019777523120865226, 0.09563930731798921, 0.07619902119040489, 0.028940539740558182, 0.035212442478431125, 0.03178920956062419, 0.07524129615298339, 0.0443326011300087, 0.04302756455061691, 0.07109035817640168, 0.02947644330561161, 0.0522391354399068, 0.017999763068343912, 0.034235735423862934, 0.031108828926725045, 0.014050831752164024, 0.038703969945865016, 0.005588816445586937, 0.016273478378674815, 0.03209810923518879, 0.04586722342563527, 0.05651717320350664, 0.032977684001837454, 0.04023515206894704, 0.016998304752632976, 0.013331454014405608, 0.03749806733269777, 0.011912904463575354, 0.023909302661195397, 0.05100238662479179, 0.07594879104622773, 0.03798014610739691, 0.030743800835417848, 0.033715611190668175, 0.020431914167212586, 0.041598162680332146, 0.02997452872140067, 0.04589397806142058, 0.022068474475028257, 0.010296609452260392, 0.02871472667902708, 0.04013503761962056, 0.039516251002039225, 0.01978733134455979, 0.017045646140884076, 0.051975955454898734, 0.02213221096566745, 0.025745404850957648, 0.0582421686766403, 0.0394862936809659, 0.03428172652742692, 0.036187534619654925, 0.01445976275551532, 0.011575468150632722, 0.043420694169721434, 0.023081187990361025, 0.03574572689831257, 0.03634448655481849, 0.011171985783481171, 0.05207897064142993, 0.025526319464136447, 0.02499543366554592, 0.013967605191282928, 0.004442967150160777, 0.09255149800862585, 0.010702063811809888, 0.0620973671653441, 0.024531936572332467, 0.018403354001098444, 0.035323172608124356, 0.06081250682473183, 0.08521200184311185, 0.05009949400222727, 0.011449783957297248, 0.04342191892543009, 0.014269007902060236, 0.012824874188351845, 0.04838743819189923, 0.017892954871058464, 0.023029429339138523, 0.049485582658754926, 0.023235529262040342, 0.05584615635286484, 0.03048466831179602, 0.02902790790955935, 0.04427926827754293, 0.06649388732122523, 0.03649024266217436, 0.04705024923064879, 0.04447102566648807, 0.04896426420392735, 0.03509305084922484, 0.012137406256182917, 0.05609835085592099, 0.02185666298360697, 0.04331656279308455, 0.026614652314622487, 0.1019853875041008, 0.01766953194913055, 0.10060488765261003, 0.06263695178287369, 0.008622951938637664, 0.08085182402282953, 0.023839260883895413, 0.004720941318997315, 0.04190684183101569, 0.01729840213166816, 0.02488767382289682, 0.043168160399155955, 0.06421875261834689, 0.019635994286675538, 0.05096040227051292, 0.012744645055915629, 0.004022540915424803, 0.07315005801085915, 0.026407807699537704, 0.056355213679905446, 0.08341649640351534, 0.03572821390948125, 0.039936291319983344, 0.01729554041022701, 0.02113442013173231, 0.046374248540295024, 0.048462630049990754, 0.01629423306855772, 0.012262602752473737, 0.05051407889862146, 0.02297366563496845, 0.03285349513004933, 0.021194780910653726, 0.0764357213463102, 0.0462024638296238, 0.02800861938989588, 0.016743945722867335, 0.07184292815093483, 0.043636705792908154, 0.0110271482429068, 0.052149260084011724, 0.04780248333034771, 0.012901769169340176, 0.02849746655140604, 0.006748874688387981, 0.02133692890804793, 0.05340504180639982, 0.015035847468035561, 0.02843878514665578, 0.041967733563589196, 0.022372376739180515, 0.02421064006297716, 0.022558442915656736, 0.03407214402354189, 0.07547245267778635, 0.026627072898138846, 0.028429738578519652, 0.00833782134577632, 0.018583181048078195, 0.06982816769076244, 0.023097852810419033, 0.019425399069275175, 0.024107012498591627, 0.010789481174599911, 0.009799113513768783, 0.018605467530765703, 0.017027658177539706, 0.011379743028166038, 0.06156530750117131, 0.042813317118478675, 0.04610328236594796, 0.02792240473042641, 0.04202795693916934, 0.025128523220441172, 0.022666743889983212, 0.0061402754259428805, 0.026028309848957827, 0.024763333977067044, 0.04203680164313742, 0.01917280423055802, 0.04127388400956988, 0.07026826550385781, 0.03658844703542335, 0.05114318264116134, 0.009599356196953781, 0.03099227018122162, 0.04325753363913723, 0.05641089426353574, 0.11401490414781229, 0.12260750521506582, 0.0674260248030935, 0.022053368589175597, 0.0664660402440599, 0.014252402453816362, 0.047051348457379, 0.042603266425430775, 0.008689768978261521, 0.11058746092021465, 0.06571602834654705, 0.18294343618409975, 0.11150371389729635, 0.09586766149316515, 0.10705483797937632, 0.1043568809649774, 0.08419213656868253, 0.10102489404380322, 0.327628245311124, 0.06779826232897383, 0.1747813927275794, 0.16463103810591356, 0.18679572375757353, 0.08171431667038373, 0.11460315329687935, 0.12231691580797945, 0.17371043376624584, 0.15861570302929195, 0.11804944622729506, 0.05327819647001369, 0.07988464699259826, 0.11507489798324448, 0.12059217478547778, 0.21202579992158072, 0.12965265288949013, 0.11040597994412694, 0.1044065836550934, 0.19806908097650322, 0.10892758106014558, 0.13512178084680013, 0.05097372530560408, 0.13515055073159082, 0.10421246835695845, 0.08112124992268425, 0.07860982218491179, 0.09729350105460201, 0.09882614202797413, 0.12999029191476957, 0.16188472190073558, 0.041782096560512266, 0.16143722805593694, 0.1061555619484612, 0.0980393196056996, 0.11269143516463892, 0.09108132975442068, 0.28458165803125923, 0.08239768285836492, 0.19296952390245029, 0.19294354958193644, 0.15318776214761393, 0.17149304917880467, 0.18956934421190194, 0.17379179011498178, 0.14955063802855356, 0.17291477003267833, 0.15655370296112128, 0.06482319839830909, 0.15354406088590622, 0.16892400703259877, 0.0855451761079686, 0.15387602735842976, 0.11948123654084546, 0.08323483900832278, 0.1721707292433296, 0.14182996803096362, 0.09843634401581117, 0.08030350665960993, 0.1268172450363636, 0.12015567320798125, 0.08476768354220049, 0.18924345741314547, 0.16522900387644768, 0.11641451609986168, 0.13641601854137012, 0.09600899355219943, 0.10388534662446805, 0.11082185405705657, 0.12129637199853148, 0.1939759948956115, 0.24669104122689792, 0.20876226361308778, 0.1242614071816206, 0.09370127559772559, 0.11882068270019122, 0.0794711477522339, 0.1107934709372265, 0.12294875404664449, 0.06866325877074685, 0.09697605523147754, 0.11097128103886332, 0.1617454458028078, 0.11765137687325478, 0.19500803308827536, 0.1335692112999303, 0.07378918371562447, 0.17302968672343663, 0.0935823419796569, 0.1270656974187919, 0.12722220830619335, 0.10535381854112659, 0.15108047665229865, 0.1312350644064801, 0.11575309373438358, 0.2610296532511711, 0.08126436652881758, 0.06358145217278174, 0.14379842526146344, 0.2122836432286671, 0.08524590823799372, 0.1587403499122177, 0.11415043473243713, 0.1523563667599644, 0.13428518788090774, 0.06971799395978451, 0.06289521578167166, 0.11015026045164891, 0.08958811166563205, 0.08090343339634792, 0.19486518789614948, 0.11366739922336169, 0.08896495867520571, 0.15910082842622483, 0.0945380042706217, 0.09053303274725165, 0.212172553475414, 0.19015615486672946, 0.1021200359932014, 0.11614763470632689, 0.10674803837069444, 0.0821244843038065, 0.17626753369612352, 0.0954605404819761, 0.1892838031053543, 0.1254476085305214, 0.08645332059157745, 0.13789443778140204, 0.08027665024357182, 0.16200524329074792, 0.15058406043265546, 0.09159080098782267, 0.1455019824206829, 0.1376044319144317, 0.10576735170824186, 0.09073895455471107, 0.09635123304490532, 0.12394059582480363, 0.16458094865083694, 0.11938423317457948, 0.12966254593006202, 0.05640082819653409, 0.09797913354954549, 0.14611107616552285, 0.12773459724017552, 0.11791895037250859, 0.19143307634762355, 0.10579222001667533, 0.12691116785364492, 0.10102739783802203, 0.1439332365989685, 0.16268898945833954, 0.11425844393670559, 0.1492835395038128, 0.09631601707743746, 0.15251812950841018, 0.11759296857884952, 0.1775129304400512, 0.2215940664921488, 0.24392516964248248, 0.1498122132782425, 0.07390360507581915, 0.1387193463742733, 0.0867684797516891, 0.14122349343129567, 0.10056463695530381, 0.10669672076723405], [0.08179356956056186, 0.04873416280107839, 0.08781347117785897, 0.043612186930009296, 0.040660892081047804, 0.03609598328226379, 0.02772603160701692, 0.04222571597035442, 0.03226132404857448, 0.04587433107995561, 0.03023866204810994, 0.04260950894760234, 0.027854649616139274, 0.006122395604117108, 0.05539135129324027, 0.03912220196798444, 0.014578560666580285, 0.02063262991474143, 0.07916356782828059, 0.026291014859452844, 0.03141342668927141, 0.11626614763268403, 0.023041466550369347, 0.004941137382827167, 0.06195114965417555, 0.028700653862740313, 0.04989302936675293, 0.02380749017798475, 0.045757103977458816, 0.015170757193118334, 0.02991698895181928, 0.010831260272035641, 0.007019000327480691, 0.076566556468606, 0.03130977367982268, 0.04208610060491732, 0.07600715862853186, 0.06304126365908555, 0.0829145365527698, 0.047696747218391726, 0.059101696126163006, 0.008982011466287076, 0.05478208452197058, 0.05370933083551271, 0.0259363513905555, 0.02290494360827974, 0.060769141651690006, 0.05108713564862098, 0.030126303434371948, 0.018222241130258356, 0.04438332501532776, 0.024748645390250852, 0.030398938804864883, 0.02208844376062708, 0.03455732370327626, 0.025331352604553103, 0.05842441639729908, 0.04828777496836015, 0.029983912860708575, 0.03034680356670703, 0.013428231767777885, 0.03947438539138862, 0.01590470307772713, 0.04038298110078488, 0.042556929269007275, 0.008346599892580082, 0.031029118025409322, 0.01328800741716155, 0.01100001871652369, 0.03772026380257947, 0.02202977592657719, 0.012151051595407938, 0.011927358955810112, 0.03547592441152249, 0.03921644708939961, 0.032807782225842984, 0.03549466894141265, 0.03053238967965756, 0.046137633201267035, 0.022865480011595146, 0.027565144168745195, 0.03541538890983377, 0.025424888656873788, 0.02936230693012476, 0.012353715586609073, 0.04664153366216591, 0.024327806097322276, 0.019627270022673265, 0.034466851236564774, 0.024058110479797636, 0.011169990890526345, 0.028650720470717976, 0.021677141277385608, 0.02164556734663035, 0.02378334790202124, 0.04923397508848991, 0.006786361203661987, 0.03584845370746084, 0.0141637501572924, 0.03684226662984916, 0.059090283167149336, 0.014724545779504945, 0.031283005473337004, 0.016280777719137923, 0.06337641924619675, 0.07088797153638941, 0.038746659976563284, 0.015941635738792162, 0.010324294529190021, 0.04182198424158352, 0.038982769807002375, 0.04313704278320074, 0.014281803376174398, 0.04362570334758077, 0.03514684510550328, 0.017464515985921025, 0.007652383929650698, 0.019240857900253365, 0.008129260037094355, 0.038060318412525315, 0.010129554130669152, 0.02565614696192954, 0.028793111044381346, 0.04595072055235505, 0.018357203441805074, 0.009099342045374215, 0.055570745774145634, 0.042713039820747714, 0.013098767393135598, 0.038776006616119824, 0.01175165909808129, 0.031649451702833176, 0.02007912175862917, 0.005427105011351938, 0.03151063361604299, 0.07625545494790588, 0.016449146005990248, 0.026304166564451795, 0.033053452614694834, 0.014235306764021516, 0.04981759662872978, 0.026851606921159794, 0.05324537233848657, 0.006367523589038423, 0.05932658977274384, 0.053532630138631375, 0.038248024947409115, 0.01586654396461589, 0.01745368995969849, 0.04979336953588894, 0.0748821407822626, 0.01929173445595162, 0.059524090960621834, 0.03806785015123231, 0.03729383507743478, 0.03385191530521427, 0.03315060865134001, 0.008906726309630488, 0.06281799849654947, 0.009930710291623004, 0.01430009668027716, 0.04497026459180883, 0.05331595015845128, 0.04218264935272081, 0.08870193814592701, 0.019155567744746804, 0.02903541929221579, 0.077356744424573, 0.035595295684678216, 0.04947228676506451, 0.04307222572554435, 0.08024450125438826, 0.04111725777121527, 0.024700223434982554, 0.03220385891784515, 0.01501775942077594, 0.0537693269018616, 0.07144783078027622, 0.02326567148390625, 0.042256518067525964, 0.02221928397193551, 0.03535823929788811, 0.05606476676517299, 0.07495918164827994, 0.020624409462990503, 0.05907016460384641, 0.03602464889575328, 0.01745115902407893, 0.030778904844607626, 0.05059994750523141, 0.017512591888329813, 0.04352198587730527, 0.09453195173825536, 0.016029655301411237, 0.03431493742391467, 0.030281966153000082, 0.050374996183173995, 0.024527427707133547, 0.021401282865554094, 0.037983783055096865, 0.028660423521484648, 0.06119503772684506, 0.021981739039931978, 0.06455220508256129, 0.000855817824360981, 0.02167773838820202, 0.018238695604460578, 0.018477460203160132, 0.050816739443689585, 0.03550652973353863, 0.022092923788087707, 0.06949576695582696, 0.018199247274813906, 0.080080065077969, 0.026005487323605588, 0.04898691370284983, 0.04944173572584987, 0.02449529568132545, 0.04094050279153245, 0.03471705763201628, 0.020762357328619276, 0.03650862417582955, 0.05842586846223899, 0.04092346477721419, 0.040856632470552406, 0.046800833328494, 0.0287301294239504, 0.06742455916745321, 0.02416563283519021, 0.026174016762524843, 0.04510262981057167, 0.09276818816683122, 0.030492101662925312, 0.05602358647489122, 0.042035393682973723, 0.05753052793443203, 0.009238997274743659, 0.008036073430308273, 0.00721191122595753, 0.0030914644926919466, 0.02428042230063251, 0.017091920532818352, 0.06899504203881536, 0.05721918892647539, 0.050376417714038065, 0.03232481796294451, 0.05018860939890146, 0.027789701940491796, 0.04356512713379093, 0.04352147697604128, 0.06603179140282528, 0.04618554116625871, 0.007679369267342346, 0.0198463638911822, 0.07527183701417275, 0.027299680913399373, 0.011133258397291814, 0.032350293560219665, 0.05321730473744018, 0.02984129837048905, 0.06075772190732615, 0.040153958568615575, 0.035134560228990655, 0.045255873551858325, 0.027919770318216512, 0.032739670880671055, 0.027274649756561433, 0.0720808564552239, 0.05134849715977907, 0.013625641353428364, 0.023329019513247267, 0.012882684523771917, 0.07065912881600005, 0.027497339860669205, 0.07398474429334913, 0.0742998355999589, 0.028108509922666208, 0.07181465359670774, 0.02604088479919093, 0.028771408101809875, 0.03691319050267339, 0.0187375036600445, 0.0381763445080391, 0.011810488084198108, 0.0474162747684334, 0.017031600465998054, 0.02371763687447778, 0.04140607620190297, 0.01514402630605868, 0.05367306653144104, 0.030573580147964612, 0.0565198534168303, 0.026852906315720508, 0.06750855501741171, 0.03853910289970892, 0.048660992977342436, 0.0728594618184226, 0.022431824888501848, 0.07505013926752976, 0.040652739482798746, 0.036263639107346535, 0.015808707335963845, 0.020871535309457352, 0.060066444001027515, 0.041577813415122886, 0.020822039572522044, 0.02007306244091264, 0.04276427939268095, 0.0035574452361158493, 0.04697168844618967, 0.01864371824610446, 0.04593497175457222, 0.04849781209070768, 0.015026702512321728, 0.04599760392946856, 0.06793975723641259, 0.057776876858302524, 0.012889656471088529, 0.06576630100607872, 0.008316020015627146, 0.04150511517322489, 0.0050579828093759716, 0.020421668288431, 0.030119884493095533, 0.021307763776608875, 0.03544060666380184, 0.040396070041294606, 0.029773146313216006, 0.06135061223592077, 0.025978503682251488, 0.029839510430714915, 0.01828674097279353, 0.028033625101670623, 0.03472549182229808, 0.020522751346496598, 0.019641232577019503, 0.031483716131853204, 0.02486530930868217, 0.044510448551071544, 0.032443473381655555, 0.032731759162353616, 0.03603902705279844, 0.014448816289326974, 0.02452500703345452, 0.010322914558595844, 0.013108469595733498, 0.029984496400824616, 0.03728867481861796, 0.018248727744711295, 0.008372436809752668, 0.051139630510338714, 0.028732982663703815, 0.20806155407002994, 0.1738552331392254, 0.18395521332110676, 0.10505045910498925, 0.12326292933097907, 0.16533729806542397, 0.08223512622394732, 0.10765302766646657, 0.12953788547643594, 0.12943641734974726, 0.1603751986154488, 0.16519969116364205, 0.15508261189929076, 0.17414127636168683, 0.09873808175325394, 0.10259625222533941, 0.19656022265553474, 0.07731600518205337, 0.1398595566196101, 0.09249707950013024, 0.13309205190411635, 0.22749752471489565, 0.08557758294045925, 0.07050423962729317, 0.12264764734676906, 0.1319697414125715, 0.14673360490373202, 0.10116383087422166, 0.21856899453060968, 0.12091947293707303, 0.10380082830254521, 0.07483796136719839, 0.13379171650324548, 0.08951098937541246, 0.10666290258190461, 0.09232384272451911, 0.15541802532970905, 0.15742879600397178, 0.20499011102531636, 0.12150935057018485, 0.1499979825956481, 0.08948911340641123, 0.08639398270419665, 0.17343079591436045, 0.08761029743722507, 0.1593989631427186, 0.13073573048625672, 0.08711560469652925, 0.17333248976085866, 0.2022409721144608, 0.10561728690351758, 0.18373158174966062, 0.06305437974099602, 0.0697727178090385, 0.11160757725260087, 0.18024596092956408, 0.11519581292356763, 0.11679134730781827, 0.09203528892248869, 0.16010010694818838, 0.1021721406972834, 0.161355871707201, 0.07442597525992564, 0.06740256106214863, 0.06820479980004684, 0.11695096588560513, 0.10623960529587098, 0.15342556153024944, 0.1376345045864582, 0.11649482750466891, 0.14913309471947805, 0.13073738611170224, 0.11870636312024933, 0.10017975832202605, 0.11927048356405326, 0.14604562467762403, 0.09321586521608488, 0.12623325708721364, 0.12539751907544477, 0.07282823563686439, 0.060153561112071784, 0.15118767161454472, 0.10550688925598349, 0.14598999837679522, 0.20443808207554476, 0.14255548481430325, 0.12073548138141632, 0.16493679955601692, 0.2333875208028725, 0.08290463672684771, 0.1348804123699665, 0.14455668814480305, 0.192443632121597, 0.13601362013391086, 0.08215235852237258, 0.1144603081047535, 0.1765461673161813, 0.12324251899761812, 0.12404115471456732, 0.19156862050294876, 0.13580794259905815, 0.10604690813592502, 0.09071160280810935, 0.0992267762443849, 0.1214032412639686, 0.1650449987500906, 0.12070398378585066, 0.12216309191925184, 0.15391562666211808, 0.08822127750941686, 0.11181614534663302, 0.15133724787405559, 0.07638234778174333, 0.09498467030269758, 0.08571935604725565, 0.1569107345172337, 0.12543577487979615, 0.07710407155432872, 0.11617174984088965, 0.1079484618135861, 0.13055058542106832, 0.1776431141687291, 0.1328158610101257, 0.10102117567190103, 0.1482164074799844, 0.1455059043530907, 0.1404993880007948, 0.18167677415268763, 0.11265326756983995, 0.10400545410811901, 0.1798669584095478, 0.0869461948584233, 0.1321683350418295, 0.11559746494250638, 0.11703154870441981, 0.08816120001886572, 0.1170489734836987, 0.16036982461810112, 0.09270342878465142, 0.14999906825167791, 0.19026884596262658, 0.13833490200340748, 0.13524440569537027, 0.1559434285653489, 0.10777730814048223, 0.12494113642190184, 0.15921228458838804, 0.10956429118024451, 0.15155820601752826, 0.07875918809856687, 0.2098845469632319, 0.10220696989979063, 0.12991720012256078, 0.10362212932003395, 0.204699413052627, 0.07559078918503863, 0.09007821072425161, 0.10831523713256631, 0.17932987080088683, 0.10783267659800393, 0.1261730846017599, 0.11842838089380946, 0.1387245168111154, 0.13568605056830815, 0.1567349260939019, 0.09467156031834227, 0.1266064920595714, 0.12703643898878778, 0.15126385752643856, 0.12286278365978173, 0.08687876883362021, 0.11782563823674407, 0.10934490045266491, 0.07569162627415997, 0.14472321420907974, 0.10377172593559537], [0.03725436808807509, 0.048706763557025363, 0.011892472077826304, 0.019995461783504913, 0.0729445976072124, 0.01975566750791456, 0.03426045784726739, 0.031240091526082585, 0.02565654899392809, 0.018251413047047596, 0.031114772893488407, 0.00950870307029358, 0.049608339821653705, 0.12185026013425418, 0.012723015055858662, 0.025890027804832374, 0.0050322896568104625, 0.039434592705219984, 0.07069080961602074, 0.07493849311556135, 0.03409254078620246, 0.036596219654061964, 0.022076613502576947, 0.06214451856378998, 0.08244803015674863, 0.039370857910918336, 0.07816904583679778, 0.015361910685896873, 0.019244667874383073, 0.04053243522399238, 0.017047997264723693, 0.005781642103102058, 0.01312549743202648, 0.045243782057826004, 0.03467162631984268, 0.028898155050618306, 0.021891258091532757, 0.031574337876268795, 0.01710884489252099, 0.023204572798152055, 0.001824831511060308, 0.02832809233638857, 0.09744233092559235, 0.03692943802369492, 0.01326121122110635, 0.0075518962860639605, 0.014090894156002572, 0.027122869954577515, 0.05021790175565651, 0.002728782860296113, 0.024872902115540843, 0.04363304848915764, 0.010797483646976096, 0.08228424537394728, 0.025784607211660062, 0.03228585308949862, 0.030962513027978793, 0.01768658692682428, 0.01470155531673559, 0.006253898659321878, 0.055065813940018415, 0.03925659600645304, 0.024188740345250283, 0.01298935616588486, 0.05993378361953156, 0.0269180219287851, 0.022879442565941384, 0.021398324452872788, 0.031068893748202493, 0.025063054769166877, 0.04066343319469264, 0.05774989152061088, 0.05990462018443005, 0.01873312032382403, 0.013510131792697524, 0.0828373735504491, 0.032042818809194226, 0.03590270597487688, 0.035408159119210074, 0.04419138781460268, 0.03199444265503969, 0.015697252870138203, 0.01952103179480348, 0.026397595747507045, 0.011520172635625516, 0.04044460904385362, 0.015532650452639376, 0.037485524612878046, 0.038541589730552266, 0.004067765698502106, 0.03582513924422009, 0.06351763595427785, 0.028474979900888035, 0.012867572700737842, 0.054960471378373246, 0.0029110087406089796, 0.050273283783878596, 0.058805162752313275, 0.06876834348908492, 0.06238851975649595, 0.04136401042342186, 0.08143739974392311, 0.053615787997841835, 0.09310052104826484, 0.07818283366837672, 0.032868921623698304, 0.0662152808425682, 0.04880241324592914, 0.004636618075892329, 0.04873382014089397, 0.024690864740737846, 0.05800896297608103, 0.03092477630291666, 0.046665333277945004, 0.05923486540892294, 0.0033137175778392702, 0.026758706995419095, 0.06382174177893571, 0.047615367120930126, 0.02177448900017355, 0.04834562347137502, 0.0113875809558002, 0.011949361301958561, 0.06555503234267235, 0.029467910727752105, 0.04545637047184365, 0.024898786530164734, 0.01908132413934384, 0.017477431900001, 0.005092639833622212, 0.10759077886385576, 0.03181592348430838, 0.04879782974187817, 0.03066291267584477, 0.05217093588518245, 0.0770484045413988, 0.02238497883081436, 0.01295209611167333, 0.03134893532842398, 0.031147783622145653, 0.03428095978285585, 0.040795459145946164, 0.07212655578872987, 0.05279174453711935, 0.018267806453098143, 0.02817256362842662, 0.038983662080551894, 0.006950842757110617, 0.018953701880361353, 0.009813121021060007, 0.02169042020770056, 0.050021370872855186, 0.027528705141906227, 0.03804836601817182, 0.009924090334347315, 0.031216810989592756, 0.049584509671798775, 0.041452559243355475, 0.02740052987688354, 0.05227069410362414, 0.045780957876039405, 0.007785425987094641, 0.03454949680183615, 0.029194681639117852, 0.011310336529277265, 0.04368050183568682, 0.0381152967124113, 0.027149687354852046, 0.006541228129728032, 0.0600820163797055, 0.022062963074339286, 0.1151369432253497, 0.052414312825671265, 0.04061202059632965, 0.05404820818720119, 0.01973629872580724, 0.028971145062574317, 0.04544381418132356, 0.05891665962657758, 0.06189698898898704, 0.036875392709459574, 0.041783046509538374, 0.027498795318284204, 0.03344579513317772, 0.05572526855394244, 0.023149594498266066, 0.0497049835643598, 0.03601734446627753, 0.03542639474783625, 0.09195136092603207, 0.055033729411661625, 0.04457047175882118, 0.03368209495342203, 0.0049056699333180276, 0.023530334067930068, 0.0515799217059144, 0.03761403914541006, 0.008060502387317163, 0.01800350858164685, 0.08947339175002915, 0.06998508569917508, 0.050101641565561295, 0.011895180280719484, 0.03786286811477371, 0.04236616932653955, 0.06315018888562918, 0.015943985166294233, 0.082407182348626, 0.05725079508764403, 0.06375613422798258, 0.036266424493598085, 0.030153393944991485, 0.03818561329639383, 0.005940638125009302, 0.04888154739247901, 0.04168452322483063, 0.10929812224847929, 0.040082943093563826, 0.035160656685807874, 0.03705228678882122, 0.008340455757986222, 0.05550724846710052, 0.03286779186289225, 0.0466420425634299, 0.03086557751521468, 0.01415759330016694, 0.06120681030941861, 0.028265984329794134, 0.016868166825068847, 0.05794218834489584, 0.06882212417466299, 0.018346314651093314, 0.022408167765076672, 0.06696519774517842, 0.034227335160332065, 0.03361020077552114, 0.05304673799712743, 0.010088516332741295, 0.06321596607033696, 0.031806797188307555, 0.023257296665438583, 0.0053419755838279214, 0.04031614540144801, 0.03130819269322923, 0.061693672755999227, 0.056486265933407206, 0.024551430883418237, 0.039855962951800654, 0.03466994694567152, 0.0410253671663148, 0.04565060790628195, 0.017191877222752998, 0.05005343843783651, 0.03682716583300914, 0.028508794693542377, 0.046630297122257094, 0.007490238657088152, 0.0198578616670732, 0.044069431323025904, 0.0776779493317008, 0.03813300647639802, 0.04060710461011954, 0.03698406009269612, 0.02979284418480737, 0.03788112409945045, 0.059446324062134535, 0.07919209344046456, 0.0367814529288028, 0.01700868464208075, 0.02732974340740059, 0.03937990617539201, 0.027905782318807075, 0.053917386635605774, 0.023791807537366236, 0.050056532557521544, 0.010869057217080678, 0.03779460409922259, 0.015000125991978815, 0.05192306025751999, 0.01296085599876408, 0.02307736105285585, 0.027617730632690445, 0.03883664050538625, 0.06833794194140605, 0.07707960358155624, 0.055189093574881554, 0.042350281429077895, 0.053038151136466434, 0.021823163709736297, 0.05836887830602271, 0.02328197837674192, 0.04148448770865798, 0.0795680425528969, 0.028321720892563462, 0.03171962918713689, 0.07371457200497389, 0.06271434548710074, 0.044682989828288555, 0.12140515473272119, 0.08249681003923927, 0.06638819192137037, 0.023637032003274987, 0.010241337685978838, 0.05134300781147821, 0.03849507276234882, 0.008661349387174206, 0.06276827545038291, 0.029996092564293315, 0.026687769551894495, 0.022182237656254853, 0.014975296699308922, 0.0743267395134483, 0.04377458071602242, 0.023714987195229957, 0.040057576061891656, 0.034101643333477635, 0.04604706913232803, 0.028612474844391857, 0.08835803624242544, 0.03722519108227321, 0.054725878073700836, 0.03551410557702184, 0.028439083702063987, 0.056282125280371735, 0.01718472546365644, 0.06380114824111972, 0.023650533153808544, 0.05085939894031201, 0.0431668338631945, 0.04253282431246979, 0.02433965671142297, 0.05217632006055542, 0.07750100096953766, 0.04852323001250625, 0.035669615625270774, 0.0360943208714681, 0.031651511056614776, 0.012510059384762176, 0.05075454153120518, 0.03203825566119381, 0.006233494263142347, 0.03748416754284075, 0.06717455293983221, 0.0289777811350567, 0.06712263822555542, 0.010950847828228558, 0.02318747541201966, 0.026083881866985133, 0.06755867839923926, 0.05387231833966715, 0.01096937183423766, 0.01356480729633144, 0.12424122755016599, 0.1572479528508016, 0.1615650097706488, 0.12278575636446476, 0.19715391365545137, 0.10699541188244309, 0.12598002781825407, 0.08320425743503229, 0.09075739035116774, 0.10767132097056933, 0.10626935905643872, 0.061785749958029816, 0.13646597228944302, 0.15980292218072073, 0.2091913420174803, 0.146325357524412, 0.08356740259166275, 0.14519309970949376, 0.12967097333499364, 0.15420632463480743, 0.15103489266974585, 0.14576310983725957, 0.11801499021904809, 0.1755462238298995, 0.2139070654021842, 0.12777764350175858, 0.17626659731779779, 0.14958658681384154, 0.160870597032564, 0.12444188392588071, 0.10156795954597847, 0.13750885347170488, 0.09559961980474846, 0.177722177069102, 0.12243555087063994, 0.15772315806576184, 0.12581783080739634, 0.13543795102408954, 0.11892444427524294, 0.09230529157710926, 0.18305627655770096, 0.09555526397057942, 0.13301506532090052, 0.19078531967742102, 0.17310272423284395, 0.12863356114498206, 0.1871892333562885, 0.21272637375763484, 0.17178087016301496, 0.14075128734111786, 0.1645015057708536, 0.13263667348240102, 0.11506792264325277, 0.1262942845267909, 0.12451213944171156, 0.12039012062762465, 0.1279571567262922, 0.09354560609374728, 0.14116455587957585, 0.13384344801306725, 0.12831201697034494, 0.12588345871440001, 0.13313232974282332, 0.06808153034320899, 0.1507152212517602, 0.09831090324691363, 0.12993458418973855, 0.07381674580808197, 0.1264679352087634, 0.10239517515791313, 0.15038862877658435, 0.1539828830531665, 0.07581379650426762, 0.10234060058636324, 0.13725544778364046, 0.12123976860727582, 0.12759848311543465, 0.11622775612132889, 0.09261157549917698, 0.14817116276494094, 0.15494530355291708, 0.06481028587690421, 0.1217594857194594, 0.16487422505659716, 0.08589532053364174, 0.1324921998062304, 0.1283232942223549, 0.12087303400039673, 0.08137010942612376, 0.14979914469378336, 0.12465559531535421, 0.1233305928430387, 0.0916315538010427, 0.18446472526660987, 0.1729983248348747, 0.08860057858484131, 0.07055560472820487, 0.09725585593176739, 0.21567023864814214, 0.10484009289315768, 0.10112263701323952, 0.10705413230295692, 0.1253582454685654, 0.17239642356123241, 0.11811245498912674, 0.10175494344106742, 0.11708306308303561, 0.1895142878804888, 0.1564167881650584, 0.19973622794662202, 0.15648415312170982, 0.16011347408805574, 0.09777263498732022, 0.1495858132839203, 0.14579026480870588, 0.10717839920627219, 0.1171746381691524, 0.09983614818858248, 0.10376843504075493, 0.17522839802716458, 0.10129558201879263, 0.12380578448729855, 0.30400038031595095, 0.09720190561243466, 0.12433272121208054, 0.07626969061259713, 0.12321792888854231, 0.2176058819251401, 0.1309555351201977, 0.07513938019318239, 0.14334995432623795, 0.15253738633223943, 0.1370621467275279, 0.1306072159537247, 0.2063268114413534, 0.2985143432659762, 0.17270550983292715, 0.1277927476912737, 0.23698446207812854, 0.07841996808669396, 0.1200522780418396, 0.14322551100381783, 0.17194512992032937, 0.13913782606167452, 0.08884604541318757, 0.09689005091786385, 0.18848870934120246, 0.08076066284307412, 0.04974388058430382, 0.12838160752185754, 0.09535542862223727, 0.1485120044755084, 0.13994195791227476, 0.14852263033390045, 0.08713669356490884, 0.15309466714305536, 0.14361978056175367, 0.10908036000494446, 0.10938668463911329, 0.15298679364579065, 0.13806677210543836, 0.08401299653840916, 0.10911902971565723, 0.11942894863230841, 0.10482407946671758, 0.13654416666499206, 0.12237205356359482, 0.09162430704704352, 0.1523344229374613, 0.075661390753729, 0.11213624424168042, 0.1988079377583095, 0.10788440810782568, 0.0855882970084037, 0.13140403319682392, 0.10623129324189254], [0.04509545769542456, 0.047179086067314656, 0.027545383532664607, 0.009436623143431331, 0.02542752815809633, 0.038503853005490134, 0.010698199554878687, 0.030548046875212873, 0.014127467193507721, 0.030396546968924146, 0.02376491210556456, 0.0365434398076364, 0.023548637550058107, 0.06968378222414426, 0.03237952145614794, 0.0588809551138963, 0.024480278005025218, 0.010694304763871645, 0.03736780557249274, 0.0075415740720927715, 0.10433727808828865, 0.050623774262411256, 0.03268503863364458, 0.023367137914257388, 0.049584044875311, 0.030900152267089913, 0.022808008095515624, 0.01590129004658333, 0.0025768120082960066, 0.018906445308987583, 0.013923886331862636, 0.04012883920222521, 0.02894232768033232, 0.03424573363736272, 0.05563209212518164, 0.02314263951432492, 0.08507924646671329, 0.04541637083249433, 0.053764848570738516, 0.05793118250689336, 0.027988378690289598, 0.03158692470086472, 0.09240528728280749, 0.02815935085527599, 0.021247309699122394, 0.08541848683463675, 0.020725202447335635, 0.03553085182128208, 0.06358655475612197, 0.021509583839880567, 0.04663605788456542, 0.027633355597832372, 0.025083800977362052, 0.034015845973044634, 0.02967683844534414, 0.04913836611168725, 0.03702032778944288, 0.03572972704257284, 0.011622671287373772, 0.04227937791230423, 0.04035045213199087, 0.048736378217914274, 0.050451657069580894, 0.032505807001143694, 0.07451866314347301, 0.04162544318075691, 0.047250084578990936, 0.07418993328298841, 0.002498139689643202, 0.057505035373781405, 0.023457891973001615, 0.10761043602334601, 0.030450327654502223, 0.0072723644552752376, 0.013840642807606076, 0.047315966936626604, 0.10256112446742398, 0.018273916660941074, 0.11222089148525681, 0.032275196697030745, 0.02967534906097821, 0.07077652215957642, 0.043231596638049395, 0.01562134176492691, 0.030412848772747175, 0.07234762249780552, 0.03982793267018028, 0.034054044101919444, 0.0377373696703996, 0.06172456645539828, 0.005636665038764477, 0.07924169435032777, 0.05531903303095272, 0.04155363042705825, 0.018181357699047242, 0.041831873889480314, 0.03809030966034957, 0.028786739600556235, 0.049871333209531646, 0.03111972619912454, 0.03852713693465505, 0.05540055562076824, 0.0895686512812972, 0.03428421675094536, 0.01408473729887711, 0.016215336409264376, 0.029477708773421388, 0.057208841267440996, 0.033989193117512126, 0.0066726968340974835, 0.037496655979858975, 0.04294676799327135, 0.022443237847515514, 0.01659583509899676, 0.04020754587171333, 0.023061573239309446, 0.06761168555489608, 0.0007771899285476788, 0.08088499759989125, 0.06194082235119172, 0.029062706577990736, 0.05220788211694785, 0.013312766311823257, 0.05309026941124882, 0.07559710634606225, 0.1157854598547731, 0.027986684049080526, 0.043981937625046284, 0.031896221318415234, 0.032452470756002834, 0.014977293288601297, 0.043401013261505535, 0.0598827577861292, 0.03382327773475221, 0.03660753083282283, 0.029615115507372787, 0.03995003843946116, 0.09053917348917041, 0.03963691149173038, 0.03044563897752336, 0.03517682956797736, 0.01564768249435084, 0.03100340494087764, 0.0046958355233073235, 0.004848739148915878, 0.05016360538346427, 0.019864742012162293, 0.015110925671511462, 0.011861090681382587, 0.025163347333935753, 0.0297662218633507, 0.05551517714879342, 0.014297679399273224, 0.009552036861090787, 0.06460963628653969, 0.05800826408501182, 0.02921784682465451, 0.05343864964587348, 0.02547151588701776, 0.008965627390093036, 0.036251418691660674, 0.04754543730190822, 0.01990008181227105, 0.04208176476614816, 0.011546226684004068, 0.029819463113588945, 0.06686900862093483, 0.040756585874727795, 0.020265958072351556, 0.0824939330507602, 0.027349215666098253, 0.027177173112119948, 0.03161285491660237, 0.05138982333508985, 0.03732359901602779, 0.04714993281023843, 0.013398556038737297, 0.017454585625923107, 0.019848173883344446, 0.016912166428353106, 0.0015321144726060862, 0.020776413181530576, 0.04961146108273949, 0.01020387576759926, 0.01793302914925984, 0.02803722133726946, 0.02054679693121995, 0.0332040772108095, 0.042356588412076235, 0.024195369632382478, 0.024841306132397482, 0.02040474223239081, 0.021816888957151344, 0.04363293653087957, 0.013317386287131479, 0.015182217649583305, 0.06404486444911786, 0.04176010863323297, 0.025457638149548854, 0.025631124286779335, 0.04541927156969905, 0.023204409949747578, 0.033195670161928446, 0.017931901084791337, 0.0366977624196027, 0.03904007887467742, 0.040749943016895225, 0.03682577483622091, 0.039987137341605763, 0.09236548441861357, 0.01802317252648728, 0.0373969384735184, 0.13158138867999825, 0.027103952398257594, 0.058339307749910016, 0.005608015593939594, 0.026774917197014605, 0.07099640821771962, 0.04751760718811836, 0.043410010635852814, 0.019203521510852233, 0.06984533462673426, 0.04997451463714242, 0.062279567388551574, 0.03674823524696486, 0.025790339136230092, 0.04446542775258422, 0.014454885785068785, 0.013097569778827685, 0.0762471564646278, 0.044574369942503314, 0.02209144288540951, 0.03853027855179139, 0.03861213023109095, 0.018594867117436867, 0.003981755447707006, 0.01839857202555452, 0.0344401780249817, 0.08486757746764592, 0.05106683727353811, 0.014976054962192262, 0.008107521471434405, 0.020720009958105426, 0.04187354611765061, 0.02609536098316312, 0.011120147404393979, 0.059073163728628836, 0.05996914886470352, 0.11032659134694509, 0.016927794786170125, 0.018152579332568815, 0.011260689818300307, 0.07590530373688255, 0.018056481810552732, 0.025998642601604973, 0.027597868216357062, 0.09750376548618078, 0.03215154047523226, 0.03742538944685033, 0.015655307531622902, 0.02667263991731618, 0.02508779245960925, 0.053265209309756756, 0.04569346417805978, 0.040882542330239496, 0.0068163948599249125, 0.042568471149674485, 0.0485223004195307, 0.0483450840360352, 0.025134686014748046, 0.03759793411674244, 0.021873711175950508, 0.020710870091404234, 0.021445212918998938, 0.04246181562276823, 0.03901656424360616, 0.08833567172821079, 0.047893960028886795, 0.047834323586097786, 0.01418373640626669, 0.020815634201946, 0.03365283991609301, 0.016881937693272318, 0.04747312582497086, 0.040334282642496486, 0.021124511824122498, 0.04026611701452306, 0.03451225880001273, 0.030310142319649458, 0.06783163946654115, 0.07581281262849059, 0.006465974355316055, 0.018799806745456796, 0.03726173697837761, 0.027772482418056046, 0.046040677332452366, 0.05480264413303562, 0.02486354511763368, 0.0213760023470968, 0.05994236708751746, 0.0341633594860988, 0.023982255353725383, 0.053232446246381314, 0.042168166022747755, 0.0930951199095164, 0.03583837406975882, 0.01222128251434437, 0.046585215255618095, 0.11999515896396977, 0.030007027156118835, 0.024377451111961688, 0.032960401714912484, 0.05217092909983226, 0.098034203451659, 0.025606067684878196, 0.0833482425659895, 0.040236980720822296, 0.02780734045830156, 0.017485996708273888, 0.028571369192962135, 0.009590582739162658, 0.04614751606381365, 0.021626844869128296, 0.03182102606764861, 0.03675090188958815, 0.026174266124144197, 0.0804476003561701, 0.04214164887421897, 0.03146866622513958, 0.017805876775777767, 0.041336200665682554, 0.012437325519775706, 0.008951239055022597, 0.03927382401057652, 0.045379869041166136, 0.026434843927355747, 0.042171775829046965, 0.03596069697024567, 0.04285453133551138, 0.010485211653368813, 0.04850511312750833, 0.034361529030970166, 0.05139865107568247, 0.0337138911043959, 0.033038229681551456, 0.11425787396728992, 0.04077784776953714, 0.015947951203478233, 0.026341750619134734, 0.06308509023594004, 0.0295940741364445, 0.04205770052171179, 0.12625601515173912, 0.1342138602797474, 0.16330809838005475, 0.2408065955553736, 0.12104326486587524, 0.1351498043430703, 0.1501211231308324, 0.05419400500665818, 0.08894825314304658, 0.1495806292763778, 0.05888151151261159, 0.11348027962126903, 0.13289972793843063, 0.12297015504113265, 0.10350743654583182, 0.11596247607043811, 0.15169889346829482, 0.11877359236989703, 0.11561298982373305, 0.13010834343731403, 0.19286074116826057, 0.16958051680454186, 0.12017972048904214, 0.1088029138211693, 0.16039624677172729, 0.10708369607371943, 0.1013316936524851, 0.2075580403740917, 0.10477908580963101, 0.11108690340604101, 0.12957672482090338, 0.10537019837647676, 0.17574860368456158, 0.21773230656981468, 0.12497621668236596, 0.10065529601914541, 0.3324432112276554, 0.1178140217172248, 0.13605092598923615, 0.11363297035651547, 0.17324546085936682, 0.14716879012329237, 0.19108452647924423, 0.10845829267054796, 0.09671002200671605, 0.20481700317135879, 0.1648810375481844, 0.1951420573251588, 0.1442878118583134, 0.08883113799882786, 0.10707215419305222, 0.14629812112876348, 0.12544591219297477, 0.13891452018703732, 0.18141469678708486, 0.15620907502514975, 0.15419921358781202, 0.1489016464246171, 0.12040195427834988, 0.07272809743881226, 0.09736305767936365, 0.15497202426195145, 0.157369641321046, 0.13120660664779799, 0.060125408694148064, 0.13234551410589898, 0.12153181007930211, 0.13408100312309607, 0.1338009445794991, 0.14506284812731401, 0.21261111779936723, 0.20138414523431233, 0.1439031232148409, 0.06285830347665719, 0.14033667530332292, 0.135985026668225, 0.23981058757219995, 0.06713496042149407, 0.1926376252834286, 0.15613059566489287, 0.13039323315024376, 0.10826737327235085, 0.13811391671853407, 0.09566881680595023, 0.12917732553822653, 0.08422615831451756, 0.16805343303297246, 0.1457734778523445, 0.12056260422936507, 0.11966176756790706, 0.2513149859649794, 0.1659268228603261, 0.16098107610430035, 0.1235287929219859, 0.13011344602065428, 0.10013983332152877, 0.12436731292733125, 0.23480069211551122, 0.16699210926890373, 0.17411678124751362, 0.1251952342156853, 0.13103712217084, 0.14213834862623895, 0.09292152351034538, 0.1373220934931721, 0.12298532708414964, 0.14317387448889868, 0.11005360313824245, 0.1045819374599627, 0.04922906928030508, 0.1365725022873708, 0.11037649081221648, 0.13445415667125157, 0.14726826335702622, 0.2132331444216626, 0.08221630366253001, 0.12993363424071244, 0.09259641702686038, 0.2430833519569465, 0.16727735182004316, 0.12704387573259218, 0.17458521468298777, 0.18264598000262464, 0.12312602810561657, 0.14173034551952565, 0.17769447926964077, 0.1282655508922679, 0.08114098172102656, 0.17317760735750198, 0.2290585216666971, 0.08818075539810316, 0.1785839301134859, 0.21993544192186423, 0.107812958370362, 0.1347194502928427, 0.12328929720180375, 0.1550583474870239, 0.2469846840415682, 0.1222204959818295, 0.1788334817226444, 0.234048848173448, 0.11238705792597362, 0.11687152300562177, 0.0912306278145739, 0.08860679396561214, 0.08016233066362993, 0.09441962026591812, 0.0721701177369271, 0.1582491991243192, 0.11393425347549574, 0.16008743191404, 0.17049329568232807, 0.08437828586569854, 0.13727864011057786, 0.2451313334916319, 0.09308269593332495, 0.1258834180022989, 0.1568246419940676, 0.11620646369244371, 0.07434995219643627, 0.14082227567476885, 0.13570612163415977, 0.12265619688800403, 0.14569506634558949, 0.12401105490114007, 0.14332225652677671, 0.14623793507260935, 0.08900691249540874, 0.16279686295560428, 0.18969927009727272, 0.11819587408431939, 0.0946941894612142, 0.10869176978511469, 0.20337986600186142, 0.11694707109459809, 0.1384493980024542], [0.013442750720839416, 0.025144009085904275, 0.04928736222375717, 0.11076109803148679, 0.0033612548930770053, 0.05199351254850626, 0.021373247494921088, 0.04987216441492949, 0.0330418225244752, 0.03641765977122954, 0.03986716217228344, 0.015393411674137627, 0.03084456667836223, 0.02987111998455865, 0.07816636562347412, 0.03165577564920698, 0.04262608216543283, 0.015782758460513184, 0.010423416621051729, 0.04414477924417172, 0.020042806564431106, 0.022221855619656186, 0.011178449677702571, 0.07234224171510764, 0.02919660528589572, 0.062022300836231024, 0.023167032848245332, 0.061168920913977284, 0.036641403300953765, 0.030108251010200808, 0.03466505131551197, 0.04445822849603636, 0.03934076149016619, 0.052605479889150174, 0.03663396994982447, 0.027622726346765245, 0.028723289790962423, 0.0632758807124836, 0.06017817157719817, 0.05982046148606709, 0.025616159196943045, 0.020783266385218928, 0.05257115280255675, 0.05177658151036926, 0.034397820476442575, 0.08450621007276432, 0.01402781329982515, 0.01784812066970127, 0.01965600937338812, 0.10484825566943203, 0.032016474687095196, 0.018154667524088706, 0.08045260794460773, 0.025066262543467537, 0.03956639473991735, 0.009640306633497988, 0.05912646943969386, 0.04653213346110923, 0.028084510139056613, 0.018727625886510526, 0.03036310537053006, 0.01408229287647243, 0.027799106435850263, 0.04471784956487162, 0.043224244711122344, 0.01741807026389454, 0.03964642116001674, 0.002478291480136769, 0.022741469255249416, 0.029686785768717527, 0.02172385502074446, 0.05059821724093386, 0.03248401924169489, 0.09049768785813025, 0.09124883290912424, 0.024706830669726645, 0.02736948011443019, 0.07216053003711359, 0.048647035512008836, 0.05265954555943608, 0.0068013161154729974, 0.004264291068206408, 0.04734054008232696, 0.024542358870218908, 0.023176919103467038, 0.07188849177743707, 0.012290219975901502, 0.043032582317079814, 0.04973528015294245, 0.0223385229307626, 0.04774795625624912, 0.014915699272283485, 0.06536080169358424, 0.020687520005074993, 0.07728841594819512, 0.020622480727199997, 0.03897787078416773, 0.026541407852034484, 0.017791800566815903, 0.054665865043976476, 0.029874658544680903, 0.046059717025075636, 0.05460825742089322, 0.011891535699500569, 0.03695679655564683, 0.009569737295221006, 0.07649211439171008, 0.02928846874939544, 0.020515233178489974, 0.03964367648586631, 0.04232410015538335, 0.04187207030398505, 0.022717956320515702, 0.012016157985531857, 0.017832097065235888, 0.019175245260287608, 0.026382462720253637, 0.052627315146050284, 0.003728216597145157, 0.03556133500699486, 0.0218274537473917, 0.04803731072960155, 0.022670964377799203, 0.037988929743213315, 0.01921723979259176, 0.04773681131856782, 0.047626909001597335, 0.03615699715114065, 0.03613837815022894, 0.05241772585681506, 0.05271386568035398, 0.061431914301855226, 0.05648206580164177, 0.05447972592498575, 0.017479109577834606, 0.02199694331336234, 0.07085346803069115, 0.046351252988513024, 0.03435807528772524, 0.026737441707934653, 0.01665753428824246, 0.044129505420901945, 0.06337702314236335, 0.03291712475142308, 0.0347338683371033, 0.015113928188968982, 0.028288079126338874, 0.020941275138674036, 0.02843694292408015, 0.01385459433575826, 0.04103080562448927, 0.0319335882418922, 0.015718572440424135, 0.0439416190742382, 0.024082866829953024, 0.03645110476229872, 0.03666697050045643, 0.05203562582443867, 0.028698713252586976, 0.01072506360443575, 0.07006161087857825, 0.05631573311984539, 0.04131064364420516, 0.023574315011501312, 0.01165881345514208, 0.032574949719543965, 0.05469836347869464, 0.014919329434633255, 0.025922297233981744, 0.030925824639520476, 0.05678078405825155, 0.010770784142161054, 0.0461721909897668, 0.043466919367866855, 0.04620087605768016, 0.03161779125886304, 0.07246574865920202, 0.048972542331154854, 0.034671134381954155, 0.01949198031798005, 0.024404353329113553, 0.04969549085944891, 0.011057981722322958, 0.017540248975689923, 0.02769566886126995, 0.0390059994533658, 0.04638837903205838, 0.02942175677578364, 0.035068148614040444, 0.06272800439702612, 0.020512875269300172, 0.04055989892887218, 0.029022588195013146, 0.01947707968897053, 0.026984214716191803, 0.00668794012329142, 0.017458951998768107, 0.048758532386273146, 0.038930071384779046, 0.19488534038620337, 0.024259750731289387, 0.01262777588064117, 0.03074698316465531, 0.029969544881688695, 0.05805044182177101, 0.021425496387694563, 0.0415641986099737, 0.04202685771243913, 0.0134063863328525, 0.0179374158781554, 0.05394344577299697, 0.02986009039783052, 0.028752100387854234, 0.031024585411484753, 0.05177061379488025, 0.013397120089004082, 0.030035970067339282, 0.02518954048199313, 0.05333272015143718, 0.040442427553768666, 0.006169686102241809, 0.05691418743559292, 0.049580204367105446, 0.042420771039490185, 0.0388329492748848, 0.013377083798072167, 0.05959773236619575, 0.028441294029887234, 0.021684537309088876, 0.002207118352609021, 0.0018041552767889307, 0.017228701318215047, 0.018226607503103356, 0.026764116615855267, 0.050731447591845474, 0.009859808471186884, 0.0035269052230952574, 0.029861223551311662, 0.008752199288989817, 0.024394251639023423, 0.04217780800536275, 0.07316967445824828, 0.027751352837575332, 0.04882784813110318, 0.00526258656256167, 0.011276989925785788, 0.04337775647374136, 0.07192124466278724, 0.03200632041054113, 0.022790985348235284, 0.03646946931257844, 0.03502384366999779, 0.033683580945112875, 0.019019696196275096, 0.07531642355024815, 0.0746124434684004, 0.05132109791572605, 0.004360719376044082, 0.032774710429034064, 0.03268953732081822, 0.028982096617775302, 0.041514431459030936, 0.03254526720515319, 0.06781167696629252, 0.03308978137959327, 0.05556893069297075, 0.056393265923751254, 0.031747964809515646, 0.009830582271596151, 0.03613413730636239, 0.03517192715246763, 0.021546852375779833, 0.06101590448192187, 0.05470625144828643, 0.02375431508491082, 0.050073787703045776, 0.004882214674060898, 0.03179410179810865, 0.07235866226255894, 0.03480000514537096, 0.028614086365061145, 0.014358730587576116, 0.0690331757068634, 0.02758032299711236, 0.014240655316306012, 0.010319838250455047, 0.06133579981646367, 0.03849731532058545, 0.041327403459165774, 0.0598152842638748, 0.03564704076520034, 0.021384309312062602, 0.03309197983305369, 0.009773562429472804, 0.024097852275839875, 0.06123966497502156, 0.015455319512901562, 0.04767819946365697, 0.010852659570186265, 0.035990152175405195, 0.06095209504876818, 0.0390254801937512, 0.01858789347378271, 0.015885783825069666, 0.02658988578644182, 0.050765421840229204, 0.012807356958676661, 0.08937748761049338, 0.022778744576498866, 0.06569407095334359, 0.04418651254049369, 0.009054222011140414, 0.03405415606019752, 0.047936161514371634, 0.04340528463944793, 0.045808190879012854, 0.006823482582279081, 0.004221993739650185, 0.04402447159269026, 0.02307279111950525, 0.018816520759303654, 0.02089976066989558, 0.06629697645881347, 0.039301508239337375, 0.022239979290004288, 0.05301705887541175, 0.04939888963209731, 0.08718556844230209, 0.08113751440708127, 0.019171269045078328, 0.042811559712780375, 0.06618802409086909, 0.06470803064959389, 0.02575477711590273, 0.032774296522672684, 0.01674887358344027, 0.018371145640100752, 0.041956934678767405, 0.02196543723610895, 0.024162382652450885, 0.012864342025880302, 0.05798005059893642, 0.05787310669464724, 0.03613501600921154, 0.011661458893546035, 0.029020661155560186, 0.015636184718459845, 0.0199066585129393, 0.03277159934597356, 0.012139398604631424, 0.0600048533773848, 0.054287873541138, 0.15563940416489327, 0.1096389978857977, 0.08331819025001355, 0.11832285512770925, 0.09591394436678716, 0.14175868114190443, 0.06430563902748482, 0.13038133164601667, 0.1330541760793754, 0.14415010996162891, 0.2610881972525801, 0.15091130430144922, 0.14316409001392977, 0.09870779873537165, 0.15819530987313815, 0.12993799043553217, 0.1693878671420472, 0.19062460187290395, 0.15292979670422419, 0.1154694389551878, 0.12346887827983924, 0.13057332991489343, 0.10800422382141862, 0.1784188018313476, 0.1266423458499568, 0.2011771106294223, 0.10368900573147194, 0.16402520132916315, 0.10882073215075902, 0.08902670536190271, 0.1372276007064751, 0.08337117026426963, 0.11082605418882199, 0.12244304189724581, 0.10590401544634785, 0.09440644990120615, 0.11828274013740675, 0.11395599373749324, 0.16132161925945962, 0.1424158965902669, 0.13367081513362272, 0.15761624808822358, 0.12251316170607295, 0.15963277273944446, 0.15766134352556296, 0.18826927111617156, 0.13877022292997154, 0.14280947404248373, 0.10140585753002337, 0.18167598705206597, 0.15504327043890953, 0.11206201929599047, 0.15942393323140486, 0.0977186235998358, 0.09673657986734595, 0.07027977345777409, 0.19152290081339224, 0.10591907213841166, 0.11655225870864731, 0.13065149714904173, 0.06393563388181583, 0.09218430878328425, 0.16277595050632954, 0.08687389016683612, 0.16111535818449088, 0.12452452949115209, 0.10235360810267073, 0.12374649409736906, 0.11307311111262866, 0.20336512822125638, 0.14399023354053497, 0.19336675187306746, 0.09573683994156973, 0.16684112165655407, 0.15150020484413418, 0.10571691620030574, 0.1082122287313853, 0.1592447864157813, 0.23372722257460865, 0.16180265987558023, 0.13534854725003242, 0.08008237209703241, 0.092040249013475, 0.11323128441082579, 0.1258902440645865, 0.12197292569492545, 0.09226518337215696, 0.14127294506345475, 0.10601204500666686, 0.14515268616378307, 0.10298749551709209, 0.12585782366139547, 0.138434035969632, 0.11372248948152576, 0.22717220788555487, 0.11922317610255309, 0.11722008644470147, 0.12135396605091435, 0.08264439819114548, 0.11886264330574445, 0.07767241927129881, 0.12931723945907184, 0.11144729371049575, 0.13109421410730906, 0.12567440207515443, 0.09988129790872335, 0.14770856473062718, 0.12075233619127955, 0.12910648648227963, 0.1375861657517297, 0.12234308011829853, 0.19129663652607373, 0.13333954076681817, 0.12845389864274434, 0.13049305922218732, 0.08071560133248568, 0.13069344418389456, 0.13199217378028802, 0.10014144144952297, 0.13349654019943305, 0.07103802277041332, 0.1251458911491292, 0.10349626107407467, 0.11927189491689205, 0.11542764119803905, 0.12043619315539088, 0.11475708575120994, 0.12140477475311075, 0.20098819290953024, 0.1336051058024168, 0.22561726346611977, 0.19712804790054048, 0.0896229747948902, 0.1536482431526695, 0.132233664393425, 0.07813608939094202, 0.17230171364332947, 0.0872712606298072, 0.15673489895250114, 0.14770598629755632, 0.04238735658249684, 0.25994494717035976, 0.18429164455405303, 0.09765073617122003, 0.12745702213474683, 0.056645032949745655, 0.1052006460460169, 0.11889802212161676, 0.09638119036597864, 0.11425902747682162, 0.15035729402942316, 0.21610090482447827, 0.1364828949528081, 0.12744309859616415, 0.12187485024333, 0.08152341084288699, 0.13432333511965616, 0.08391526035432305, 0.1558628593172346, 0.11405146361461707, 0.08774926819439445, 0.08449062412338597, 0.0772670420951077, 0.10774985461362771, 0.11015026045164891, 0.09783712974084274, 0.10618264228105545, 0.1211724579334259, 0.06812110250549656, 0.10361811239272356, 0.10905476566404104, 0.0991284768762333, 0.16252116060682706, 0.1126762834776725, 0.2501172902328627, 0.08531963785312005], [0.025775871073294963, 0.02774209761992097, 0.005491394932115716, 0.013911436062439211, 0.006290709184083555, 0.06390355953148433, 0.05260573773245726, 0.01234020001720637, 0.03539417451247573, 0.007648400929091232, 0.040208597600992234, 0.008128267679629582, 0.026878210582903454, 0.02543837284403188, 0.028404678583943417, 0.05027736856469086, 0.05301295034587383, 0.02897340797686151, 0.04891689906695059, 0.048909462323146205, 0.0872233153453895, 0.05662695677684886, 0.004838496662809381, 0.05577231138678534, 0.05225251615047455, 0.023470361750306826, 0.04473705549857446, 0.035027982733611546, 0.04971074093399303, 0.054585977723555903, 0.04804047948813864, 0.017135122857455696, 0.018688101221674254, 0.0033064913919328576, 0.017654649979834045, 0.0404265973317836, 0.031776605772652795, 0.03683324211410113, 0.022283587039315274, 0.040052185101168494, 0.025174375224326338, 0.05359949976471918, 0.01825902790629438, 0.03861641178705862, 0.012614814165447439, 0.04785868299326726, 0.019896901179371134, 0.08286150904106242, 0.016876611193375926, 0.02985192762155618, 0.007759929185600153, 0.01580442238732108, 0.03799823585099407, 0.01951852800058467, 0.006585357926918992, 0.004508510664371508, 0.07963129558733531, 0.03047761833295226, 0.016493276227265596, 0.03262849631054061, 0.0012435283341411768, 0.061941086979849, 0.015809104278949753, 0.06044124638927834, 0.07888650162411587, 0.017728769752596105, 0.048170812494520626, 0.02845033211633563, 0.024186468949275355, 0.05450119138030069, 0.009353046288846858, 0.019479775169332112, 0.01836469955742359, 0.04247862632785525, 0.019328746844881346, 0.07410998828709126, 0.03757327954683985, 0.04532298405787774, 0.009920326161331363, 0.004096093687361905, 0.02544347712370966, 0.030399712334786142, 0.04873061406293085, 0.021331826324707696, 0.06726397028458969, 0.008453404697190438, 0.026527777779847383, 0.049976787729454894, 0.04298898304945656, 0.025076438872409717, 0.02599447130757783, 0.04367189122630017, 0.05020811388801251, 0.08893842117062636, 0.055721628213567395, 0.02108711775924478, 0.04876821168831416, 0.03153006346630199, 0.045329209616673846, 0.026494195385436927, 0.058594755828380585, 0.059838286601006985, 0.04181764840281435, 0.01970400215525712, 0.029511428571173122, 0.06625721430672066, 0.04709167040086218, 0.06505932858479874, 0.024798828143892542, 0.027584361976810863, 0.011579310355175818, 0.0522825616811003, 0.021414899367040822, 0.055186386220157146, 0.06403150409460068, 0.024801111414230297, 0.06088572075324399, 0.03640162938141397, 0.06925325854016201, 0.046150932487632544, 0.0584427300574524, 0.03566671149539096, 0.03897919732012919, 0.06207996952746596, 0.0920430106510009, 0.03952868854893105, 0.01653556422596531, 0.03145417271714125, 0.02737434351417635, 0.05286512131403599, 0.017524362774565816, 0.028192142756389718, 0.02366634301974305, 0.009075768042488821, 0.02021753102807062, 0.08118737316025154, 0.011995642479243023, 0.03033701909173812, 0.011009409641181784, 0.038509803757603676, 0.04390472373259919, 0.03886937303468585, 0.07012728628303323, 0.04064336891419121, 0.046461277441786866, 0.007605133295458342, 0.022939072223380208, 0.07787952172969069, 0.037667582343731604, 0.05039533866303308, 0.02917300583794713, 0.04838612861931324, 0.0745637517954622, 0.05278541041272027, 0.02869588036888412, 0.011522616209861423, 0.02713400641057108, 0.04360102502895253, 0.027321970788761973, 0.04799919402492898, 0.023753388884610364, 0.029179173721266643, 0.03096769025017108, 0.010119740817961949, 0.03616730070539883, 0.0651864656912429, 0.05295627231576613, 0.01706423800039504, 0.002199127754595663, 0.0296787654847971, 0.04797702628586974, 0.011260048602707684, 0.032369051660810194, 0.02293420203828386, 0.014013126409346504, 0.0689006374616708, 0.05726434543196644, 0.0196337042309876, 0.010719354580422598, 0.023920087975316813, 0.016659289997603213, 0.03840581826599581, 0.011442035087384284, 0.032274301030806134, 0.10826961243791239, 0.03441044122778943, 0.06657119960125003, 0.07469545544258185, 0.042131386032061915, 0.040811224907104454, 0.04186694397191916, 0.002983926234134872, 0.04115072990368519, 0.05786951045904841, 0.05899054530475821, 0.0385422750509211, 0.061930359341204166, 0.04570985758411033, 0.007783134235069156, 0.06418131105601788, 0.08808073255100421, 0.02308928800214614, 0.08056626256023135, 0.046642385223614316, 0.03369232726150325, 0.013320853601076772, 0.03320680831425956, 0.05570494643013392, 0.08843402537916388, 0.02668785097609673, 0.04937512733574424, 0.011061478722175317, 0.08654490924839463, 0.04995702539703675, 0.04276482900604606, 0.009975623372676117, 0.06882186633135591, 0.04239984841219016, 0.041881454443292956, 0.014035839520926987, 0.04128486270617161, 0.12240908800491265, 0.05911433044821024, 0.03808464389294386, 0.024855475639924407, 0.053605721930840185, 0.008135209092870355, 0.03612923489085265, 0.024773534054734876, 0.06269618110465151, 0.07255215330847672, 0.014548213187871235, 0.058895760748003206, 0.025045132962986827, 0.0176535931615425, 0.055069423746317625, 0.025852118053340485, 0.03478671942970582, 0.02818426157214812, 0.03809153441605823, 0.028042885408337628, 0.04684349282511643, 0.025724858810592974, 0.07532993318246943, 0.05149395131905164, 0.020569914619305303, 0.02970647346228361, 0.025186134236199514, 0.05516033726079123, 0.08174155985138246, 0.029487411824188063, 0.03383073822728225, 0.004507682003479983, 0.05337867732825024, 0.023074311037947024, 0.012761136001375104, 0.01123107600558017, 0.02889821951144508, 0.06868107710033655, 0.003195131496925439, 0.030357860294835906, 0.036976172123104334, 0.09055249313158648, 0.006454217039780425, 0.05533416096919349, 0.017692483396136334, 0.024101662249969583, 0.03214683822755303, 0.05195555869223816, 0.09038145480943577, 0.012742255764481212, 0.009786849841475487, 0.02585754294081458, 0.0892001117712685, 0.016898541445178644, 0.004700650577433407, 0.009627826678167497, 0.04713053688673036, 0.034210015553981066, 0.01747300785167941, 0.026735190668010285, 0.07349018725965704, 0.04705740438242044, 0.022199350309425166, 0.06096084815050874, 0.017487323244235346, 0.02579008977461074, 0.032117138749786785, 0.03647566094462361, 0.012317519984208047, 0.05298288445919752, 0.012751771369948983, 0.02033723478338548, 0.04847770031275494, 0.014736789943916457, 0.05491383905921664, 0.025706670679418103, 0.04960028561098235, 0.039468475351376195, 0.026905343501961658, 0.07084838580340147, 0.025018532693918263, 0.03302277943917683, 0.011324013250746896, 0.02109478520495551, 0.06803492855812822, 0.07127885520458221, 0.008346097776666284, 0.05058975590925131, 0.010263086429664066, 0.013393383057388877, 0.03829085407778621, 0.043123353339199505, 0.024873556901833842, 0.03332904300519398, 0.042188949550368955, 0.05659908934363297, 0.05453300788732512, 0.07143119310161897, 0.027271028075899397, 0.026752098064337457, 0.03553753199854067, 0.057374966996056695, 0.027347524417564273, 0.027566765867439762, 0.041093061212450266, 0.010921730194240808, 0.0617596535012126, 0.039246373876397095, 0.07549705635756254, 0.02052166229779167, 0.016675098167200173, 0.026166881966803755, 0.04289918572508863, 0.02415794672976647, 0.061826624907553196, 0.053880406477089436, 0.02650987124070525, 0.043781952999000034, 0.01542822052059429, 0.03217246649520738, 0.026594460808805058, 0.02323914585368974, 0.055861392856708596, 0.045270672400615046, 0.059687108998852115, 0.08185662581984486, 0.03486983996949025, 0.04813890777794378, 0.05671732407063246, 0.023119856004736254, 0.022112720047256777, 0.09007848213825907, 0.14262054275189126, 0.07968553089137588, 0.08491697481700353, 0.06948529037513904, 0.13266502267548017, 0.12506477907299995, 0.11992710190159933, 0.1563260816037655, 0.15876758630786622, 0.18717817323548452, 0.12094858208937304, 0.08624087806258883, 0.11678439910922732, 0.18064052904290812, 0.0870373153260776, 0.12072921171784401, 0.11327450030616351, 0.1598464162754161, 0.13786656356283597, 0.1330515162221023, 0.11094128979103905, 0.057006461412778923, 0.1605091549988304, 0.2443503396851676, 0.06019342504441738, 0.17239113098808698, 0.1776507951851402, 0.1517188966806446, 0.13743322395852633, 0.15955934167972632, 0.117307468184403, 0.19907783184732708, 0.1369117833673954, 0.1321244609675237, 0.09657296471829925, 0.2361546137503215, 0.13731714018753596, 0.09075971094093152, 0.1882805890802826, 0.1454660879181964, 0.20292114918785437, 0.11658598189907414, 0.10888555938644068, 0.15205369942954608, 0.17868022780333245, 0.16070441023579665, 0.1422492348189865, 0.09740642285240547, 0.13139614861990723, 0.1639165407312768, 0.14109652595860617, 0.09561562644583838, 0.1325873846986464, 0.15236191717641695, 0.13710881636611053, 0.1718792984528201, 0.08965594481144633, 0.0880097442173532, 0.20580557441072805, 0.09149814703102623, 0.10003995975213391, 0.12518158209111008, 0.18796870724431106, 0.12419018814606325, 0.13926738553813525, 0.11474664988262312, 0.15664979709046228, 0.18297878785857133, 0.11740558434809957, 0.07608236066464867, 0.14953366108238697, 0.1842393973576171, 0.1235199041132416, 0.10650576744228601, 0.1269277376788003, 0.13417282248181955, 0.14055171662143298, 0.10595901749495949, 0.11645915013338838, 0.06952304406357662, 0.14152518367128714, 0.16309247352182865, 0.10933221863316638, 0.18695777149072715, 0.06901892647147179, 0.14714843407273293, 0.13561901130846568, 0.16830918645220144, 0.1507980975189379, 0.09765707368829421, 0.1431994688298021, 0.1472185267401593, 0.15775564632245473, 0.10926534900707857, 0.07863443265003817, 0.1398369614034891, 0.12798233037548407, 0.11918920863951955, 0.16742771518017563, 0.06454102282545396, 0.10834288743457623, 0.16264119345162595, 0.1236030925065279, 0.13763446387435707, 0.14638804058943475, 0.13295956115637506, 0.10539913110967193, 0.14623773151210376, 0.1353200894913503, 0.10708680376410484, 0.08217457375888314, 0.11634249639298234, 0.13744412123092584, 0.14188859345657484, 0.07648573616253478, 0.1094230269747121, 0.07936519450907197, 0.12808160004871233, 0.1296380508158888, 0.12544587148087366, 0.1740757298788854, 0.12636071310511657, 0.15406299089746817, 0.19299142701285227, 0.1610755417495966, 0.12100902598883424, 0.10612878017127514, 0.08468436622726065, 0.20051327267927782, 0.1621781475841999, 0.05985438823699951, 0.12647614548248903, 0.06917386315762997, 0.14162602754575865, 0.1150300061064107, 0.12512899562716484, 0.1258384311305625, 0.17401732158448013, 0.1007243369572929, 0.1764142465378557, 0.09439464339188167, 0.14939104659216745, 0.14248525643987314, 0.1301594099828175, 0.20417011502598012, 0.11213841555374009, 0.1232995702219861, 0.08023701022778239, 0.09729026444256306, 0.1173779544021402, 0.15112004881458624, 0.11215971476797547, 0.17435624982629502, 0.0692731938990099, 0.1488922012171575, 0.12816360779106617, 0.11444417254201003, 0.1680481947426285, 0.16361831101988042, 0.14098797392632278, 0.1065887115629656, 0.15094823017716408, 0.0831559660977551, 0.19035909112010682, 0.14470794717116015, 0.09659534958856446, 0.09867455051945788, 0.09001044543193919, 0.11855602690151759, 0.16550906242004462, 0.13992503524890967, 0.09016870015433856, 0.11041544550763709, 0.16025698424449988, 0.1402654426970652], [0.03267624821247799, 0.01408118092721062, 0.030577939735459428, 0.06711941518421684, 0.024480681733361313, 0.025274713590208973, 0.0221255104323583, 0.03058690657573087, 0.010438452957064977, 0.024869127764499614, 0.047629769026700935, 0.0007777874104379277, 0.04458457850185888, 0.02417971922217735, 0.031904102502656836, 0.04866612270208342, 0.0385008063832564, 0.014800020925966757, 0.003623252742857273, 0.06193774180220706, 0.057328514488680024, 0.03847102548128792, 0.026874923080738102, 0.023736964944483976, 0.023656948702409863, 0.05664730943473322, 0.06128959158169372, 0.03673680193190064, 0.06476989268724408, 0.07987949012645654, 0.02544806232409818, 0.04521374670522554, 0.03431652519585831, 0.03621121209913066, 0.024096256022208502, 0.00982018796327923, 0.06712865683117084, 0.04461288019748671, 0.037141829662557156, 0.051165710003780465, 0.00877908878361008, 0.06056113674172333, 0.04617718161482896, 0.03812047732727868, 0.018572005576321056, 0.054912634659558535, 0.05971180767353092, 0.03592001201052751, 0.04566722183621355, 0.025507272986162986, 0.04083584215758102, 0.05043676322592156, 0.03784946026280522, 0.041372285157974274, 0.04459969965474946, 0.0065427259957816985, 0.040961187931575944, 0.022589920155171837, 0.018157476659065912, 0.041241093804793696, 0.03865535291177886, 0.01235870281899614, 0.03201373679829495, 0.015721239083047425, 0.05589007453194686, 0.02761685532251639, 0.03682740671294076, 0.026094478887638876, 0.02726196963340044, 0.03340028239680188, 0.07474496814289264, 0.022140667208337357, 0.07823892137301819, 0.011259494748498713, 0.04699435490848763, 0.03004984271579555, 0.009671797443713461, 0.029077417217195034, 0.06562370008655957, 0.03778656006657651, 0.05756792199930974, 0.05768158340028354, 0.027854527479835918, 0.026250660685556274, 0.03864314267411828, 0.06850526189165455, 0.022705774920593415, 0.03890610892059548, 0.020390990023900355, 0.05073521685387407, 0.01268303916523499, 0.03197719090219055, 0.06161291351807969, 0.019834749068000486, 0.00763964613101312, 0.017290827984522496, 0.011257890861348381, 0.05149044668568032, 0.0455054421243923, 0.049315345007926226, 0.015525208619822348, 0.04331117522503648, 0.03100875179682459, 0.09008815804762499, 0.046048253175935576, 0.03859812526830605, 0.034501083328255584, 0.017978781069229757, 0.017541751930756227, 0.03767629812604614, 0.025657142712069408, 0.006034474853160126, 0.024053572776860425, 0.036847708480698724, 0.046052124218216965, 0.07988996670714446, 0.037581310008785555, 0.0275361486710608, 0.012153803054908556, 0.015175576488088285, 0.01955926215409168, 0.004943681040978325, 0.039603578458939276, 0.02585828593666, 0.0410791376738676, 0.029753441656274453, 0.04411269471581493, 0.024587396632081697, 0.04504244036174246, 0.08817639241793326, 0.040291758852877786, 0.058647383004426956, 0.04870721139013767, 0.06847488387886967, 0.0837287242923464, 0.02720484716285552, 0.03680362745321222, 0.025513544346072843, 0.013128017341451985, 0.03996172620515738, 0.017577015395675386, 0.0777632479688951, 0.0462903714339648, 0.03266398369201592, 0.05520313924976757, 0.03229607521955456, 0.0325886391635452, 0.03793085393096719, 0.027707841779504503, 0.05985799804329872, 0.036941828073135445, 0.026166476542130113, 0.08111472241580486, 0.03370268509856292, 0.021585659489833882, 0.05188296562326806, 0.07215607206204108, 0.03635335840018732, 0.09915281592735223, 0.0418332377448678, 0.01246431509831122, 0.07539068242268902, 0.04392617900988885, 0.025243002256112437, 0.04643138797421541, 0.04198554510782872, 0.026181540019544106, 0.046573463029095104, 0.027452587083514248, 0.06831422035715409, 0.022993889371199266, 0.048414735655699453, 0.03814704536593386, 0.01412458426784724, 0.055254785942712, 0.037338540357138426, 0.06379345365400825, 0.01601281575858593, 0.05962375418416091, 0.04623423623187201, 0.03309293996010508, 0.07091247343591281, 0.05276060995778867, 0.011757270582685513, 0.05603578653452652, 0.023533044815329567, 0.006644627112629158, 0.04664209006088121, 0.013193383164304708, 0.027653290956680263, 0.01811657626447933, 0.04379641258024743, 0.07266749069094658, 0.06443451318357672, 0.033592701357390196, 0.010161120427905448, 0.054029300808906555, 0.025144185505009124, 0.024242953596902744, 0.025613519695720503, 0.006708734677106674, 0.04243661143950053, 0.022458935755171945, 0.04985286009364894, 0.035610220062413385, 0.05774650563086782, 0.040352630229400735, 0.05091687424906662, 0.037731663190892765, 0.0326705213769206, 0.03577726520597935, 0.04912797774055174, 0.04687485471367836, 0.03563355488170471, 0.017556206422990987, 0.06593326811811753, 0.03160705344219293, 0.04449165652373007, 0.044951384354914935, 0.005491163382040603, 0.01884642888658813, 0.02405415801331401, 0.04311797934185181, 0.0362226386288447, 0.06749687064439058, 0.025961219698988965, 0.08396730399025337, 0.08492827242506401, 0.01450561815207558, 0.04932036616706422, 0.03965348470956087, 0.010860868995743138, 0.023125528557492152, 0.023041955095582774, 0.09066120122692414, 0.04540100201432194, 0.002772728180778878, 0.03284389725221055, 0.0465594580663102, 0.04259348873581205, 0.03304227714293769, 0.018378590865592872, 0.09724800528160163, 0.004185458445655448, 0.07422566493707043, 0.1055957909141268, 0.051023716373103004, 0.0441923309782786, 0.034392130960311205, 0.014163795110237385, 0.03593038341828755, 0.010231491294689476, 0.0412769374171538, 0.023160518912066306, 0.01211220970643418, 0.036005867046437094, 0.033209868507193666, 0.04732027563399502, 0.033054534878049574, 0.06314788186656577, 0.029333777925265685, 0.07246411338980709, 0.08168988940971238, 0.01994752498077495, 0.04304928445656385, 0.03538652403014047, 0.07206339774919407, 0.039670387016875405, 0.06509448348411492, 0.002145495286510725, 0.03940556158444711, 0.06378388631024531, 0.07806820196232625, 0.03863562450611165, 0.08235968489732061, 0.03643009053277118, 0.016202540935150216, 0.03465171470972044, 0.01387232360762677, 0.07389058398881129, 0.014623160773356045, 0.021031852778313414, 0.039599218871444464, 0.04616550402715802, 0.007557270283411656, 0.05142266782266753, 0.03064631570928863, 0.00807512057612517, 0.006155011934294764, 0.09063236348863159, 0.008754709020390041, 0.07132184039801359, 0.041610433986144404, 0.01841450572412993, 0.026426307956821153, 0.050490387848445346, 0.049917690722005706, 0.028450803698173592, 0.0725086863551821, 0.011176229171854044, 0.022715413510533314, 0.035401465371251106, 0.02232143741899303, 0.03583097125270537, 0.014658860197024686, 0.08639261884880917, 0.036603069465075216, 0.014512220297807028, 0.02625107459191765, 0.02053086323264454, 0.026642211014404893, 0.043429861177823374, 0.03825167885848454, 0.0441695898771286, 0.008085685366365527, 0.06984504964202642, 0.00982279862676348, 0.07660291916025536, 0.026347014354541898, 0.03544833517766424, 0.00469172784193818, 0.06508993729948997, 0.027941451208399873, 0.031137164549103806, 0.027998836611264517, 0.03214366946901594, 0.024348811845162084, 0.04584217530542186, 0.07284462225756475, 0.03112669475376606, 0.03519941460607307, 0.04111236214105572, 0.02284624524015401, 0.0225251014011779, 0.09738073351659945, 0.03509527305141091, 0.02705919962110264, 0.021240159636363387, 0.0292926553104605, 0.03293379974950637, 0.04614884259977511, 0.04702986603868859, 0.07873435371688434, 0.03642356302589178, 0.05188515729137829, 0.028687273152172565, 0.017588974575379064, 0.04855175901736532, 0.03427793690934777, 0.014208002514871103, 0.021164810018880025, 0.010247793946681278, 0.09814241621643305, 0.10038181926522936, 0.2158581249948059, 0.09728024248033762, 0.07896820402571134, 0.12227320458207812, 0.09793244355491229, 0.10648803053689854, 0.17602484886135372, 0.1180279909500054, 0.11555346873189722, 0.08817923547966139, 0.10479376252208437, 0.08685521009777274, 0.17677412794104644, 0.12810633943549224, 0.14995162508317403, 0.2257450180394309, 0.11750667249517781, 0.13032005993383272, 0.1580024023673364, 0.10691983665206603, 0.12137235434991972, 0.10197763863418784, 0.057308701266135485, 0.11849692650139332, 0.08348180539906025, 0.20021912774869374, 0.14487386255392007, 0.1340366947863783, 0.13839457237294742, 0.1405497081577778, 0.07863659039139748, 0.14420390421790735, 0.08923918860299246, 0.17595715820789337, 0.21708510629832745, 0.08510475259806428, 0.12581898431692803, 0.19263117920075143, 0.05698449044887509, 0.15931026504508086, 0.07031825996403183, 0.2077650206961802, 0.11311157047748566, 0.10560977552086115, 0.13939545223755495, 0.10732767012502466, 0.11002987476864032, 0.06846047858042376, 0.11507647218448774, 0.22131475433707237, 0.1319926758962018, 0.18536998597638948, 0.09470171441457101, 0.11157919413277081, 0.12561049764709814, 0.14392392709851265, 0.13341023054506096, 0.1395903139242104, 0.08853376324155501, 0.12106799068195478, 0.09975507682455437, 0.06142773452614035, 0.1507877159331526, 0.15276388132146426, 0.15348797318126473, 0.11706111926053252, 0.19173418304749898, 0.18887692636677197, 0.17086427791842393, 0.23164425577436173, 0.11430366151034832, 0.09032484463282994, 0.10368055797048978, 0.11039899103343487, 0.1295269067798342, 0.0845048190759761, 0.1714634107691901, 0.1021066756386842, 0.19208048017961638, 0.13289895440850938, 0.11149127635040454, 0.20659617627305643, 0.11616496449070317, 0.2260353360325098, 0.17681032099894115, 0.10227996669709682, 0.11672976346952574, 0.14658412363912376, 0.10484092070588044, 0.09080101336751666, 0.10459144373557397, 0.11241208229746137, 0.08247886278799602, 0.17322506409670624, 0.21171375523720468, 0.1969491182161229, 0.14520786463149957, 0.1873511860945395, 0.14610783276813372, 0.12821044027805328, 0.1039420517959765, 0.2344674499971526, 0.10010072256305388, 0.1101486591090049, 0.11247610886182104, 0.12828820039119038, 0.13901293490614208, 0.14222567608313902, 0.12542460619338922, 0.09956562984734774, 0.09263137515102114, 0.25684002520782606, 0.0923961406307561, 0.2362750130040305, 0.12747584469616413, 0.15011747261243208, 0.14076541444020613, 0.11456257690276418, 0.1602445263415575, 0.08981187215873174, 0.12110613792070321, 0.06820560725671904, 0.19103777541645936, 0.1093368733833943, 0.093359992839396, 0.08057253900915384, 0.1440364010632038, 0.21052459547562258, 0.10349824918167931, 0.1459099312445947, 0.11873863424573626, 0.08947894895183188, 0.13585086672433785, 0.128165602684021, 0.11636826715299062, 0.1263060231826135, 0.1563230010547808, 0.1335197596677712, 0.08840905529047761, 0.21319532287972315, 0.11318519152700901, 0.10850253993911402, 0.14008174969681672, 0.09587626531720161, 0.17544238083064556, 0.10806071864707129, 0.07907789599682603, 0.12960071781916277, 0.19830709749034472, 0.09467595043991293, 0.17239816061088017, 0.09729539416730404, 0.13302695325442723, 0.11135585433138268, 0.1494092449013676, 0.11990015049065862, 0.15591034319783958, 0.16225391280438217, 0.10017829268638577, 0.1966262034007481, 0.13902505354157516, 0.16096827893384866, 0.10877111088484526, 0.17740300776703016, 0.1395296257521425, 0.17371960755969795, 0.2528049945831299, 0.18602532866810048, 0.15284768039626734, 0.14820750510053976, 0.1792617051729134, 0.10023368149995804, 0.1515268169875656, 0.10465029986309153], [0.02766749099828303, 0.030975523936961378, 0.03596142300271562, 0.031536455266177654, 0.028717423855726208, 0.01401589737672891, 0.03217606273080621, 0.040180991403758526, 0.03423041570931673, 0.01612959842064551, 0.01968747643487794, 0.027774270357830182, 0.058424701382006915, 0.013418204716539808, 0.0522519393957087, 0.026182530680671334, 0.017371532939640538, 0.06420782141919647, 0.05469193775206804, 0.09592509269714355, 0.03509837056377104, 0.007536021111133907, 0.015787917022992457, 0.026794209643932324, 0.056456274685582945, 0.00942156305869243, 0.09502065301473651, 0.0746848431548902, 0.06046914774924517, 0.02633833249897829, 0.10535604413598776, 0.046587664767035415, 0.03433294913598469, 0.029773906272436892, 0.09979912731796503, 0.045243432612291405, 0.03737018723040819, 0.0507836981809565, 0.04166509676724672, 0.058346785205815516, 0.08041053198810134, 0.044351959734090736, 0.0023492750437331517, 0.0415351810599012, 0.03597932614918266, 0.04275587573647499, 0.038075113868606944, 0.06080692248152835, 0.07225515174546412, 0.04455166616077934, 0.03277039833899055, 0.031958799210510085, 0.013161948333228273, 0.04505516628601721, 0.009372510914025562, 0.021409963024780154, 0.048953048020069084, 0.03767714968749455, 0.006367174567588205, 0.01860798489568489, 0.05144605013941016, 0.05437250382133892, 0.05959476716816425, 0.032380206776516776, 0.027065421787223647, 0.08245816068457705, 0.05910442383693797, 0.02393397080179836, 0.02536932342419667, 0.05346501073134797, 0.018838339052828293, 0.06503899967564003, 0.06480865739285946, 0.03490287444687315, 0.028846708525504385, 0.06612797374171869, 0.04321821253480656, 0.05282633285969496, 0.07810427288391761, 0.06989874211805207, 0.02900663244404963, 0.030021541020167724, 0.12138326519301959, 0.025121702247166207, 0.013503000389651527, 0.05909721100968974, 0.023028092625151788, 0.07152830503348794, 0.04613360948860645, 0.011961536764699434, 0.04075874700876219, 0.06073332857340574, 0.02082656879377152, 0.016529523567961793, 0.02461611562674599, 0.04222476602132831, 0.01752225592333291, 0.024855377252346704, 0.027871718164533377, 0.08959258999675512, 0.03885105258918234, 0.031158602863018, 0.02369397126936487, 0.01822588825598359, 0.006164628895930946, 0.019381119570295726, 0.01718076621182263, 0.0053073143187378135, 0.027174457275707806, 0.023377085237630775, 0.028844102951032773, 0.020369843480044177, 0.06955539661326579, 0.04525821789034775, 0.010099290620668657, 0.05630419123917818, 0.0385904205031693, 0.03721748631713646, 0.0470574722359223, 0.0016322219245401876, 0.045669481357825656, 0.025033234851434827, 0.030512332184506313, 0.02688770498415189, 0.04812508262693882, 0.024921223986893892, 0.07330411938684327, 0.03503173503226467, 0.025530075155464665, 0.026797799094180976, 0.03565346649182694, 0.06928445758031947, 0.012161123599591, 0.035964730860931535, 0.03130693740344473, 0.013797233529788042, 0.049081745757056136, 0.032474804736141644, 0.005191560909484646, 0.056407691578247716, 0.02677770088692861, 0.01523382871943925, 0.05969913263938256, 0.07426822943879025, 0.05010855583740132, 0.0011759346899842577, 0.02197138120287231, 0.02021419263577887, 0.012096340468685542, 0.015886738863108412, 0.07045666075178555, 0.06868177599140576, 0.011976126963937921, 0.0397800789879901, 0.05341158627665468, 0.03858682426757046, 0.07996075826564006, 0.00880162971692958, 0.018865595804527402, 0.006684948207943567, 0.018592972308397293, 0.017227295054388896, 0.006984127868366028, 0.022735945980197618, 0.011869485855900815, 0.0298034700431994, 0.01632052969320544, 0.014468039186405284, 0.034591369197836945, 0.030059362562107186, 0.02211342572367617, 0.018107994492830973, 0.036487589590251446, 0.03854735727821078, 0.06765463682157652, 0.04217142638351236, 0.03528073363538299, 0.0353686853445002, 0.028474057093262672, 0.014838899286197764, 0.03181486836235438, 0.031105853550668274, 0.037263725085982254, 0.04342367633112839, 0.03330951476735728, 0.014217213627749255, 0.00802540177080248, 0.046928011147039275, 0.044260605171855004, 0.012997045663983693, 0.05820957863969462, 0.010743568102563066, 0.018524776146348034, 0.023495978143598353, 0.07855406017707926, 0.043747551273554564, 0.0654104161741478, 0.010413534606673887, 0.030417618873928274, 0.01898228347168437, 0.05313562608457037, 0.02496536777886961, 0.03470534272491932, 0.09139240413372006, 0.02761122178552406, 0.029366476527814354, 0.061272763913231235, 0.0180049657355994, 0.012720873429706054, 0.04049152974039316, 0.038744997565767596, 0.04940503715936627, 0.01841982713501368, 0.042089703625866344, 0.01671885689055281, 0.05701638159475156, 0.036876010176326544, 0.07833558547177485, 0.03926632959129555, 0.015600975536342179, 0.007713117902832372, 0.016256933998582617, 0.01694861563321735, 0.05209937758211579, 0.023660957148032527, 0.06036306558442967, 0.03905719152784773, 0.017026835453829596, 0.07082484742360455, 0.03758166963234544, 0.010606952710077167, 0.04776060414899673, 0.036723041241722446, 0.014983574826536434, 0.03351421521178313, 0.047240391706249545, 0.0405983447230288, 0.07522009193365063, 0.03251711817990456, 0.02012221891033862, 0.01714593361664031, 0.010702852608769067, 0.013208268526276308, 0.030765137369079248, 0.049168448961739025, 0.02431517856062523, 0.03024035838565656, 0.03978467267006636, 0.037446519027331045, 0.05004021039764796, 0.013451484314698194, 0.05788155445562942, 0.07091969304851123, 0.010563113410691065, 0.001641388190494451, 0.04653983483357089, 0.027235851124195114, 0.016861786899556006, 0.04603015325431313, 0.020835840974801352, 0.050214858526097875, 0.02480315719731152, 0.007830660524112838, 0.043550603091716766, 0.02827625734997647, 0.06097927037626505, 0.06539338494517974, 0.01303688669577241, 0.030733324254729917, 0.05272944823705724, 0.05256777709083898, 0.04940273014030286, 0.016027955571189523, 0.06247947059039559, 0.025306413049942682, 0.0388954525281276, 0.024327129258641174, 0.012733617165525044, 0.04631844921303647, 0.07215441643659558, 0.011193864296988716, 0.03015625397009509, 0.024150845860796313, 0.02233622269704938, 0.040594297261642556, 0.06205011398664542, 0.08157919999212027, 0.051063363174242635, 0.03609915543347597, 0.04806365145902548, 0.03334268155906882, 0.08428702969104052, 0.08977576731038944, 0.024308055639266968, 0.0824506560872708, 0.018380231224000454, 0.008260140112335128, 0.047836491505482366, 0.045986292750707695, 0.053087802936456034, 0.05376722005062869, 0.011111548669370157, 0.010933914138669414, 0.04048972483724356, 0.09420103020966053, 0.05905091456536736, 0.02074333799204656, 0.07727986640696015, 0.033851535325603824, 0.01802091809388782, 0.026900144227381264, 0.008707696721622986, 0.01931072834746114, 0.014463991725019045, 0.0027107011743022925, 0.07216899136879615, 0.04153485197041716, 0.00911000183051718, 0.0646833251895649, 0.12016140004353863, 0.030439922319991247, 0.028929533902555704, 0.02167113115345793, 0.0658740930791412, 0.048369823422815116, 0.035676930232771804, 0.030062551676694835, 0.08942081885678427, 0.026056842246491994, 0.030106992327741215, 0.05190133356622287, 0.024260112051186816, 0.07281932647206954, 0.017349885976208106, 0.04053681856021285, 0.033155544993600676, 0.009218810009770095, 0.03759115215923105, 0.04832945398188063, 0.022888268610196452, 0.08025790910635676, 0.03937778914613383, 0.025260820585702146, 0.026643464607851844, 0.0711713752576283, 0.013074811714302217, 0.0206757457261639, 0.030602451813008105, 0.03699860449082085, 0.05701131972351244, 0.03289554055247988, 0.06352414989045688, 0.10087206760155303, 0.10826075077056885, 0.10421088058501482, 0.1509390292423112, 0.1570484499846186, 0.06704080011695623, 0.1736294845385211, 0.09692654931651694, 0.07494086798812662, 0.11868443286844663, 0.11493526904710702, 0.14309661649167538, 0.09454052842089108, 0.09971427651388304, 0.15928091162017413, 0.06720680370926857, 0.23827145301869937, 0.08606907299586705, 0.15059662690120085, 0.16784481065613882, 0.1761295875268323, 0.08357222019029514, 0.07260881776788405, 0.09068694484553166, 0.11764156525688511, 0.11051379915859018, 0.21836774104407855, 0.23698025516101293, 0.10423612887305872, 0.12774804580424512, 0.32282763719558716, 0.07445901312998363, 0.09289725231272833, 0.13582817651331425, 0.1803580413439444, 0.15825796579676016, 0.08519490276064191, 0.22512749688965933, 0.2555538485092776, 0.12363700568675995, 0.1891300877822297, 0.1277425903826952, 0.12019106559455395, 0.09194183429437024, 0.07314151525497437, 0.10428501053580216, 0.11233378614165954, 0.16375143959053926, 0.18722898193768092, 0.13686743431857654, 0.11459079038883958, 0.08512074566845383, 0.14067890122532845, 0.10921610772077527, 0.10547235182353429, 0.1238486407590764, 0.15962691019688333, 0.10618974654270069, 0.19460720888205937, 0.15852002959166253, 0.15345423642013753, 0.1953297265406166, 0.13319221724356922, 0.09218686007495437, 0.13781218576644147, 0.10462788106607539, 0.07326970409069743, 0.09375196216361863, 0.06606217620096036, 0.1566428081797702, 0.12433778308331966, 0.12695703682090553, 0.11758136563003063, 0.09723003088895764, 0.12771585610296043, 0.1349852867424488, 0.24208308277385576, 0.17070290872028895, 0.1560236042631524, 0.1333168369850942, 0.09935980303479092, 0.11021573908094849, 0.2064834851771593, 0.08265396553490843, 0.11008241373513426, 0.1700642987021378, 0.12739013215260847, 0.10619683723364558, 0.12438397774738924, 0.1708024362368243, 0.15362355804869107, 0.10689386233155217, 0.12187231252236025, 0.11922344751656055, 0.16304186838013784, 0.1664603278040886, 0.07993757272405283, 0.17524845552231583, 0.12991976498493127, 0.17871467024087906, 0.08819533033030373, 0.09637667132275445, 0.21153933102531092, 0.12322864974183695, 0.15889924924288476, 0.14966285414993763, 0.12973316785480293, 0.08818373416683503, 0.09368497718657766, 0.1751449517905712, 0.15038941587720597, 0.16571537777781487, 0.18079861413155282, 0.11292842709060226, 0.07368171055402074, 0.15709465821938856, 0.10987826290407351, 0.16130876780620643, 0.23961709652628216, 0.14174626395106316, 0.14555622451007366, 0.1008922200916069, 0.07954419204699141, 0.10846138000488281, 0.13756796744252953, 0.04816561830895288, 0.17040368834776537, 0.17003152546073708, 0.168620851156967, 0.1684854155672448, 0.20087456543530735, 0.16404652089944907, 0.0807322525818433, 0.1063696193907942, 0.1902807881789548, 0.1406691846038614, 0.16672653066260473, 0.1252111526472228, 0.09674042716090168, 0.21920282766222954, 0.11151084530034236, 0.10748850328049489, 0.16406100083674702, 0.23998529676880154, 0.11905096391482012, 0.06528548430651426, 0.11884468926915101, 0.19706995173224381, 0.0942930124167885, 0.1288463090147291, 0.20747984599854263, 0.1865727842918464, 0.1340201385319233, 0.11881287954747677, 0.10473090982330696, 0.12109669271324362, 0.22456876401390347, 0.08624984829553536, 0.09941233521593468, 0.15948668414992945, 0.0774588096620781, 0.15925522228436811, 0.09550714905240706, 0.12317789532244205, 0.09644424662526165, 0.13512441356267246, 0.07819119321980647, 0.08424254493521792, 0.09682480299047061, 0.20006124622055463, 0.138608650171331, 0.08893038053065538, 0.13057593548936502, 0.15704976634255477, 0.1676094132874693, 0.09846545995346137], [0.0319272642955184, 0.043201442541820664, 0.010151837220681565, 0.025673025520518422, 0.030536233580538204, 0.03752143268606492, 0.031731914063649516, 0.037059760852051635, 0.024949069367721677, 0.02493019761251552, 0.00760954716575465, 0.03364337435258286, 0.0185290102048644, 0.032473369634577205, 0.03919563642037766, 0.04639590737809028, 0.024316471169835756, 0.0184540558340294, 0.021267153455742767, 0.033179429426257095, 0.09235252439975739, 0.02381204654063497, 0.017649379459076693, 0.03283802792429924, 0.06880390550941229, 0.03951805929786392, 0.047035508057368655, 0.013541422435082495, 0.023056664038449526, 0.032355233295155425, 0.05169391219637223, 0.056146306318363974, 0.011620708624832332, 0.025715444137209227, 0.014392005944890636, 0.03451095601277692, 0.017870240911309208, 0.036879474097596746, 0.02593754730852587, 0.06614073020006929, 0.030559354661298648, 0.05648311413824558, 0.055409078020602465, 0.022305661479809454, 0.02514251970153834, 0.022481064478467618, 0.013366561416270477, 0.0110747279665832, 0.08614751842937299, 0.03773729842422264, 0.08749101776629686, 0.010767896975656705, 0.007231568385447774, 0.02951283992401191, 0.015148662396573594, 0.03183919045009783, 0.042843919047819715, 0.053329598890351396, 0.015277848678774067, 0.03613863599353603, 0.08438205852040223, 0.03810300165787339, 0.02095443193268563, 0.011670758215976613, 0.02259176746676011, 0.06574933084526233, 0.03265055887667196, 0.02157265706253903, 0.023547704564407468, 0.018738314509391785, 0.03994758214269366, 0.03052518703043461, 0.02534237879860614, 0.01522519945033959, 0.03952425092990909, 0.03448886630524482, 0.00881836493499577, 0.014224349271639116, 0.06127184789095606, 0.07582920603454113, 0.013697309070266783, 0.04195389823455896, 0.0222595516326172, 0.04461470545668687, 0.0659434257873467, 0.0374432756299419, 0.10526375658810139, 0.024713083369923488, 0.037348453753760884, 0.039921872450837066, 0.04613493602456791, 0.01827405745695744, 0.03572385432198644, 0.013526403062444712, 0.003293906687758863, 0.016441948445779935, 0.04202315969658749, 0.035365957633725235, 0.11943044140934944, 0.029064996633678675, 0.010940571415371128, 0.022846418266583766, 0.027494320379836217, 0.022261085121759346, 0.02384537278807589, 0.03643908112176827, 0.05069017909201128, 0.10085160298539059, 0.07546415419450828, 0.03151360220674958, 0.017509099129321318, 0.03113234355779631, 0.01810585880385978, 0.09476946613618306, 0.03472734761557408, 0.0037815244286321104, 0.02227164651932461, 0.016491610423794816, 0.03575632222262876, 0.08749835272984845, 0.09037627758724348, 0.01938877853431872, 0.02761942188122443, 0.043149551576269526, 0.04081161845741527, 0.029567506097789322, 0.02835189025583012, 0.042114117315837314, 0.037060975429735014, 0.0041351790007736, 0.060238608691309176, 0.031422396922217946, 0.04227729480979698, 0.012461058130221707, 0.031493843267006535, 0.046409454329737594, 0.07740872020700149, 0.026456321257033517, 0.02694561964433108, 0.012843639074292566, 0.03982052646045174, 0.0422218110013221, 0.043266022112220526, 0.051376805640757084, 0.07697566558739968, 0.05586572530280266, 0.05417790676334074, 0.035896263284874816, 0.04947558105258005, 0.07038395572453737, 0.059772360138595104, 0.038242318467902284, 0.040399774842496426, 0.00404469932462754, 0.03937928870852504, 0.0051045744164314654, 0.031159298361412117, 0.061653164215385914, 0.029672173517090932, 0.03186578902282885, 0.029134587185191255, 0.03761977615899273, 0.028007472665714364, 0.055606351899249215, 0.003084464555805815, 0.0327177609849189, 0.018189011574057595, 0.03749662544578314, 0.035230399907699654, 0.010602545625131046, 0.02387254641923521, 0.03993418786142554, 0.04775813767420394, 0.048709850891360214, 0.008671816638005632, 0.04359547461249998, 0.02483991513560925, 0.07421400770545006, 0.03925814645897065, 0.03658040978812745, 0.011539943449731385, 0.019652779546699355, 0.048240888198571544, 0.004266457291253443, 0.050191832440240045, 0.0671922762745193, 0.036106887340013466, 0.009084458379740161, 0.020608621649444103, 0.027290030449096645, 0.07122515594320637, 0.028684073859559636, 0.002872843902358519, 0.007834920875861176, 0.02663878271622317, 0.017614692748923386, 0.03845439798065594, 0.0337973305556391, 0.053592609241604805, 0.07092993892729282, 0.02813153770486159, 0.03225269986848746, 0.041809862213475366, 0.06396362345133509, 0.008995292092939573, 0.014774441852101257, 0.054135335476270745, 0.06253566686064005, 0.0358905975174691, 0.0615308243515236, 0.023564964798944335, 0.00917163910344243, 0.07709917931684426, 0.03904162932719503, 0.06818044039287738, 0.06936394117240395, 0.02337931252882949, 0.019268688014043227, 0.022753672707559805, 0.01273327789801572, 0.0551309838358845, 0.03204211652544992, 0.040542362191315205, 0.03909619032804455, 0.12551645269351347, 0.05243256202499781, 0.0464570433832705, 0.07599824267838683, 0.025466462497466376, 0.014525314327329397, 0.039190238674304316, 0.01900807798041829, 0.028267356666869352, 0.03236073621415666, 0.02487499369973583, 0.0477923969072955, 0.033412058372050524, 0.019788486550429037, 0.014732167424101914, 0.024839913439271704, 0.014285803340109331, 0.07345798398767199, 0.09522778939987932, 0.07452742981591395, 0.0298853522565748, 0.046619338781705925, 0.022140799522665993, 0.02160355924362583, 0.0035338720813992298, 0.04369681042486003, 0.05772911477833986, 0.030846989048378806, 0.06252388749271631, 0.01856779696286789, 0.02759784446763141, 0.08574635495564767, 0.04972465090187533, 0.01241890583852572, 0.034424758316682916, 0.05469904201371329, 0.029262772628239224, 0.019565511461613432, 0.04391035557325397, 0.04436190366478903, 0.08013748271124703, 0.015917552834642783, 0.049771059304475784, 0.005053158001308995, 0.017657635533916097, 0.0662082919318761, 0.18831656500697136, 0.015050839699272598, 0.03389466640406421, 0.011506802103083049, 0.07144214465681996, 0.0518192376143166, 0.04172943206503987, 0.02669747599533626, 0.015677130914160183, 0.022324965801090002, 0.052397770141916614, 0.023042482656559775, 0.03945722184809191, 0.019908960442990065, 0.015051121291305338, 0.05484459116788847, 0.026751728262752295, 0.031693227389561276, 0.05060704158885138, 0.07670930666582924, 0.035421590719904215, 0.01015187454010759, 0.03310721294422235, 0.037066702265292406, 0.01645728333720139, 0.15238840718354496, 0.05043623396860702, 0.03414831297206027, 0.036989681755325625, 0.10046187961207968, 0.032865291461348534, 0.05370362096333078, 0.004439029102546296, 0.030560216400772333, 0.016164532796080624, 0.013702181799869453, 0.04557993169873953, 0.025368656763540845, 0.04199496317388756, 0.014091635455510445, 0.012490113847889006, 0.06692552380263805, 0.016820565897173116, 0.02389205090834626, 0.00976713076566479, 0.03457220397623522, 0.009055388243203717, 0.05261333053931594, 0.014494544460571237, 0.03034345499639, 0.009109676981877004, 0.06929418777248689, 0.025306988108370985, 0.035225382141236744, 0.08451928544257369, 0.06865361678813185, 0.02143954375891813, 0.013215174316428602, 0.051660541844155104, 0.061827873411987505, 0.015506448822894266, 0.03620780924601214, 0.01667532038741878, 0.04517838146005358, 0.027744686231017113, 0.0787845720936145, 0.00853426062635013, 0.03870926930436066, 0.10031164517360074, 0.01086647030232208, 0.0468932090859328, 0.027420909676168646, 0.07179517285632235, 0.012255092217986072, 0.06285022890993527, 0.05663984215685299, 0.06878333232764687, 0.022048785085124627, 0.03185323951765895, 0.027761914235140597, 0.04350272226812584, 0.0184293062692242, 0.08970532859010355, 0.16364207331623348, 0.12090789712965488, 0.08755522074976138, 0.10797643102705479, 0.10250121661062751, 0.08981737507773296, 0.11812768131494522, 0.09448212691183601, 0.15082363757703984, 0.06908891735864536, 0.056558377242514064, 0.08642379753291607, 0.12702672236732074, 0.12957599200308323, 0.1261586725179638, 0.12984048495335238, 0.09922183650944914, 0.15679634708378995, 0.08641076287520782, 0.19696636657629693, 0.1399823443165847, 0.09350524004548788, 0.20727203786373138, 0.1949046922049352, 0.1394220779516867, 0.13494138552674226, 0.1484200358390808, 0.12063368755791869, 0.0800909623503685, 0.08092547221375362, 0.22137552393334253, 0.11082974541932344, 0.1831827147730759, 0.14571487956813403, 0.10306378999458891, 0.17346962168812752, 0.10318291360246283, 0.19919501484504767, 0.1502007017178195, 0.11793192396206514, 0.12910774855741433, 0.0981346062783684, 0.10782827969108309, 0.09328221237020833, 0.09646762894200427, 0.12743752103831085, 0.08561101436082806, 0.3323086170213563, 0.15494736629937375, 0.22172841642584118, 0.1291812610413347, 0.10496466513723135, 0.0711712259799242, 0.1942953813288893, 0.07966686439301286, 0.08239621043737445, 0.11220627584095512, 0.12639487055795534, 0.1288371623626777, 0.19079966390771524, 0.11780422367155552, 0.0955179716859545, 0.09100033302924462, 0.16150885421250546, 0.20114192180335522, 0.1368103288114071, 0.25766110686319216, 0.14257907069155148, 0.14478630439511367, 0.10368946034993444, 0.08658161799290351, 0.07454790121742658, 0.14162994947816643, 0.16363555938005447, 0.17837347569210188, 0.1752420908638409, 0.10755818882691008, 0.13967013678380422, 0.1781483513436147, 0.16732613848788397, 0.14356016447501524, 0.10767403511064393, 0.21699435902493341, 0.14888799430004188, 0.11583894198494298, 0.13782821276358195, 0.1662291916353362, 0.21320429311266967, 0.12625118398240634, 0.1891885232180357, 0.08064255703772817, 0.09899475798010826, 0.12065721915236541, 0.29098035182271687, 0.07164065686187573, 0.15142301470041275, 0.1277628242969513, 0.13616861110287054, 0.11781392672232219, 0.12387156167200633, 0.13440304941364697, 0.2652773367507117, 0.06927318032830954, 0.1584157251885959, 0.10805975512734481, 0.17246779187449388, 0.15391205756792, 0.12047645742339746, 0.17696042651576654, 0.1087128993655954, 0.17175446158008917, 0.12733671787594045, 0.17306878391121114, 0.12447509142969336, 0.13029247069997446, 0.048370067695421834, 0.1913735145436866, 0.09298227953591517, 0.2452320009469986, 0.17461141970540794, 0.09209966153970786, 0.11660560513181345, 0.20200739321964128, 0.16306948475539684, 0.12194446793624333, 0.1228669091526951, 0.13048697954842023, 0.15676041186920234, 0.10771708137222699, 0.15521765393870218, 0.09996866607772452, 0.1274634139346225, 0.12264610028692655, 0.1295120875750269, 0.08899406104215554, 0.11545189203960554, 0.04979503533935972, 0.11922458745539188, 0.12370570057204791, 0.10588118274297033, 0.08805209837321724, 0.16511519998311996, 0.14990405977836677, 0.26455836104495184, 0.11858510891241686, 0.12178015389612742, 0.12957478421075003, 0.28863039506333216, 0.16153694556227752, 0.17427306143300875, 0.13317829370498657, 0.10025401040911674, 0.17129790250744137, 0.07362906302192382, 0.11171980015933514, 0.11934071193848338, 0.22998092217104776, 0.09972518057163272, 0.16659334780914442, 0.11856635420450143, 0.10637124108948878, 0.22543499538941042, 0.11450084378676754, 0.10772604481982333, 0.20899703672954015, 0.11591101597462382, 0.07596575442169394, 0.11674781250102179, 0.13534348537879332, 0.1887633531753506, 0.11401110435170786, 0.13310953096619674, 0.1276815358017172, 0.10810514233474221, 0.2549840419420174], [0.020126057722206627, 0.0813545777595469, 0.009774533582718244, 0.027884647649313723, 0.030366671072053056, 0.019906534680298398, 0.046538742392190864, 0.02238705345163388, 0.039608066968087635, 0.040000514659498415, 0.057559833861887455, 0.07890811296445982, 0.012133187464704471, 0.023009054628866057, 0.07443114569676773, 0.03192829566874674, 0.0399220556552921, 0.047628466239465136, 0.02535385961112167, 0.04074589894818408, 0.03294777757089053, 0.02745227326106812, 0.04195556743070483, 0.05127094399982265, 0.010566470462695828, 0.053745150699147155, 0.023933098884299397, 0.07081747853330203, 0.006625034838050071, 0.04502662710313286, 0.02574631748055773, 0.011664821882732213, 0.0371006934770516, 0.010831952377754663, 0.030651262229574577, 0.022501015104353428, 0.016247190235714828, 0.05537338707862156, 0.04624924881915961, 0.03827031821544681, 0.07192810465182577, 0.03537550462143762, 0.01707220569785152, 0.03166097662012492, 0.060407258570194244, 0.02767254099515932, 0.05814444606325456, 0.0319738525098988, 0.023352752971862043, 0.01864690227167947, 0.055446790996938944, 0.10087337717413902, 0.05524771900049277, 0.04837933648377657, 0.04597155157742756, 0.05933805022920881, 0.012996673317892211, 0.018398209009319544, 0.02138668588096542, 0.014350839225309235, 0.03448770601036293, 0.09488168225756713, 0.03376052003087742, 0.03125359776562878, 0.029221975710242987, 0.008557665843649634, 0.04536241033513631, 0.02667818185208099, 0.02116039614858372, 0.041895557793655565, 0.012613957514986396, 0.050297025724181106, 0.09268187172710896, 0.0280756569534008, 0.04241753103477614, 0.03520803878616009, 0.03449527167582086, 0.0045858835884636, 0.024593235425917164, 0.031732738483697176, 0.039323937214378796, 0.055888683535158634, 0.034657645105783424, 0.04617345306490149, 0.045329654057111056, 0.10536223916070801, 0.04874926020524331, 0.03692384010979107, 0.02268981238427971, 0.050324638706765006, 0.021549130557104945, 0.020683528522827795, 0.022904097135843973, 0.08133842862610306, 0.05053289806736367, 0.03525740220876677, 0.03978335291945508, 0.011644881434871681, 0.07533315622380801, 0.03161036130040884, 0.04632616076352341, 0.08880707036171641, 0.03695078134270651, 0.08893671804772955, 0.011818235257773526, 0.030178265646100044, 0.03415305253916553, 0.028504021199686185, 0.01593210910713034, 0.01650027870865805, 0.06186720130166837, 0.037459095673901696, 0.05148481145235045, 0.04691861343703099, 0.021184139785223773, 0.01804461932208921, 0.017631125170737505, 0.008947388368791767, 0.011151514381968548, 0.04469262841822846, 0.048975951969623566, 0.07003381129886423, 0.034421501348593404, 0.04110884054430893, 0.04694547324574419, 0.01600513813484992, 0.02977258652182562, 0.022077739870707904, 0.07870554311999253, 0.05291512595223529, 0.05335744596751673, 0.08500460761466197, 0.015094425396195479, 0.023461135370390754, 0.025967679352366498, 0.006688064804101097, 0.04771821606638176, 0.05380024774266141, 0.059602475325976095, 0.06345316155680589, 0.03257404048261898, 0.03556052755032267, 0.038377709952848296, 0.009856055324364985, 0.04177276331133076, 0.02534744406252035, 0.024285149993374944, 0.030268032436392138, 0.020765736433012143, 0.03581306810623833, 0.034012704355908294, 0.01025648258759507, 0.007243779471277126, 0.06892351087714944, 0.044919025019875596, 0.04387144837528467, 0.04920476754861219, 0.03690316514777286, 0.02275557260561202, 0.005229946483658361, 0.009264449123293161, 0.0116191810728716, 0.013720689690671861, 0.04276397744459765, 0.03016351429479463, 0.004963292399354811, 0.011874314480727273, 0.024414356631625975, 0.02694690546819142, 0.06769283155777625, 0.01905224721745721, 0.010601607550467764, 0.03490267088636756, 0.04661358480474778, 0.034137578548065255, 0.025667576884318675, 0.030375983965184008, 0.028704046537833552, 0.024616368381040435, 0.03471278964674898, 0.06680445279926062, 0.0481411096240793, 0.04413826870066779, 0.060437921567686965, 0.052489776097770245, 0.004943365098110267, 0.024675367000911917, 0.029176327266863415, 0.00840577153888132, 0.033853503077157905, 0.03527238086930343, 0.013389925073300089, 0.025997643458790014, 0.01733993356382208, 0.012661175918765366, 0.02174154612501817, 0.020212282559701374, 0.011118222909447337, 0.05772188159504107, 0.046901259903929064, 0.022251361714942113, 0.020486015460586975, 0.02112937861654375, 0.033770382537373474, 0.02847028783123408, 0.031951203010976315, 0.0458814149855503, 0.0017026749576741296, 0.058938583093030114, 0.009734103921800852, 0.012238965136930346, 0.024152526931305016, 0.021824726036616733, 0.06219413982970374, 0.023507056924115335, 0.025653624507997717, 0.06346652869667326, 0.025110986482884203, 0.02633878542110324, 0.04905032280034252, 0.017958316453067318, 0.07477994662310396, 0.050890055152454546, 0.012057234799223287, 0.09412903764418193, 0.008208707157921578, 0.021556609709347998, 0.01669766624192042, 0.0982124749571085, 0.025732653481619697, 0.014017570813718652, 0.017759434446426373, 0.03226335286828024, 0.04655507133741464, 0.016803253076172302, 0.033348998720092435, 0.027318009840590612, 0.024512971518561244, 0.0399046342686883, 0.013090106741791325, 0.038888443261384964, 0.024788137824673737, 0.03580337862617203, 0.030091769394597838, 0.013047448941506445, 0.07431426803980555, 0.048036737367510796, 0.058498559918786795, 0.04975589404680899, 0.023024905206901685, 0.03688827808946371, 0.020630524759846072, 0.029112911384020532, 0.03586212618808661, 0.006963435518887958, 0.09803774540445634, 0.04859712926138725, 0.055416206030973365, 0.03362308954820037, 0.03799056840528335, 0.03927561534302575, 0.04123502091637679, 0.03816222419430103, 0.053637487547738213, 0.00630826542952231, 0.03130509178819401, 0.05346128557409559, 0.03587127962548818, 0.014226886992608863, 0.06445431962077107, 0.06169251246111734, 0.06488489080220461, 0.09357628266194037, 0.05381589476019144, 0.04801756196788379, 0.03196000021749309, 0.03916055615991354, 0.014382594664181982, 0.04032652698723333, 0.03790894403521504, 0.031473039383334775, 0.07256262310381446, 0.01579660057489361, 0.013922593722652112, 0.021773834213880554, 0.05020343878173402, 0.021585747699386308, 0.040851322934031487, 0.03917023206927946, 0.029191373780901943, 0.0026762926635066314, 0.048818430065044334, 0.0365576958283782, 0.028664012971733297, 0.011449982428790202, 0.029821977085833038, 0.08749392868152686, 0.052222691143729856, 0.02867091028019786, 0.009967696387320757, 0.11507782925452505, 0.010414414157691811, 0.021593720485855426, 0.07290857418307237, 0.03404934185424021, 0.036540678170110495, 0.023725153346146857, 0.02966872995187129, 0.005749498627015522, 0.025284713500046303, 0.028064327114926915, 0.058458078519574234, 0.03582001969750438, 0.04132875713652798, 0.035424023267946074, 0.018370662183899964, 0.03105486842936703, 0.018107005528041294, 0.0547689718327352, 0.009324057576512652, 0.04636483047423618, 0.023246611435232416, 0.011227947110975427, 0.05506007692643574, 0.03620846063963004, 0.05251870543829032, 0.022209728502535393, 0.02757883022007133, 0.03201622023646321, 0.05821160067405019, 0.014932272490113974, 0.03320166501881821, 0.11754901308034148, 0.024288537579455545, 0.019632811957438077, 0.04305695190227457, 0.0471617936023644, 0.047650722188076804, 0.03916504806173699, 0.005937551214758838, 0.03227990912273526, 0.0691345352679491, 0.08535548485815525, 0.04869080102071166, 0.02432728192902037, 0.05283436671431575, 0.007864875652428185, 0.02857968463961567, 0.06792046648583241, 0.026936459421579326, 0.04711191788581865, 0.03189265222421714, 0.09475435516131775, 0.10094876920006104, 0.09473933918135506, 0.08821344721530165, 0.21234579703637532, 0.10456200210111481, 0.12080473266541958, 0.15490490357790673, 0.1624369001282113, 0.1272162507687296, 0.09958935143159968, 0.1475735634033169, 0.12295138676251684, 0.10952889200832162, 0.1690398601016828, 0.09130547022713081, 0.16439458222261497, 0.08998717846614973, 0.12205505557358265, 0.11899330200893538, 0.15225936339369842, 0.12777351800884518, 0.09520169972841229, 0.1587893401405641, 0.1882423468466316, 0.11032456252723932, 0.0664169889475618, 0.18087610283068248, 0.09407363525990929, 0.0989107485594494, 0.10079035841460739, 0.08753886805581194, 0.14565092085727624, 0.08492977877280541, 0.15205103957227298, 0.1207215849842344, 0.13778869488409587, 0.15724261956555502, 0.1478731366140502, 0.10455048057649817, 0.1468710218157087, 0.10078161209821701, 0.08866206064288105, 0.11399163039667265, 0.10692282899149827, 0.20506450560476097, 0.15643096954694816, 0.07986560729997498, 0.09021855212215867, 0.08098360230880124, 0.14119476425860608, 0.19465604983270168, 0.19367579743266106, 0.191101218440703, 0.09713730907865933, 0.118943185412458, 0.06629184673407248, 0.11082578956016473, 0.18893214554658957, 0.10477729447718177, 0.1257866317672389, 0.2312800996005535, 0.09192437558834042, 0.09201333831463542, 0.14660545678011008, 0.07977386258010354, 0.10093033340360437, 0.0944077323323914, 0.1146925435002361, 0.17246787329869612, 0.12142086960375309, 0.12030102897967611, 0.2053291206913335, 0.18906166431094917, 0.06850869527884892, 0.14432164361434324, 0.11972472204693727, 0.1153309770992824, 0.09757319997463908, 0.12730737802173409, 0.1460942756384611, 0.2503978780337742, 0.21965106789554867, 0.11950075120798179, 0.10053040486361299, 0.19520248765391962, 0.17865035869181156, 0.12400053760835103, 0.1155746118830783, 0.15257136736597332, 0.0829008776428444, 0.11580159541751657, 0.14401221807513917, 0.14233239607087203, 0.108421726418393, 0.1504384468176535, 0.14226526181612695, 0.24423254600593022, 0.16764378787151404, 0.1102827037019389, 0.1301017887890339, 0.10203293923820768, 0.13310873029487474, 0.148616743140987, 0.11541168205440044, 0.13552077300846577, 0.10843637598944561, 0.111556205366339, 0.1370386965572834, 0.11997829058340617, 0.19709973941956246, 0.10221285279840231, 0.07523953874728509, 0.11881971918046474, 0.07491361802177769, 0.20615769337330545, 0.1216859325234379, 0.08377721240477902, 0.11142577057970421, 0.08546543467257704, 0.14757667109370232, 0.13060993009379931, 0.10483703948557377, 0.13695035129785538, 0.313460216990539, 0.08724251788641725, 0.08689755746828658, 0.08999314957431384, 0.11463136678295476, 0.10907895543745585, 0.11707683413156442, 0.1790720410645008, 0.06959823931434325, 0.11017339171043464, 0.15312631401632512, 0.11539732425340585, 0.09105367266706058, 0.2622706666588783, 0.1301534931574549, 0.13343814547572816, 0.08377404364624194, 0.11286383055682693, 0.2266381736844778, 0.1145519781857729, 0.18065194200192178, 0.08876824458794934, 0.09980384992169482, 0.14757975164268697, 0.08945593982934952, 0.17440766921000822, 0.16260350761669023, 0.13195606214659555, 0.11811430060437747, 0.1467506904155016, 0.16590911309633935, 0.09051394555717707, 0.1723372010248048, 0.0759855540735381, 0.11515845278544085, 0.11308214919907705, 0.10542861345623221, 0.10889410214232546, 0.11152637696691922, 0.13771822223705904, 0.140145654124873, 0.1997068745217153, 0.13905554690531322, 0.14750348430659088, 0.0945263063269002, 0.15131554832415922, 0.08012170677206346, 0.09356033708900213, 0.12095527244465691, 0.13588046442185128, 0.11838038132659026, 0.1650720994387354], [0.014912491497982825, 0.047767155404601774, 0.023337112739682198, 0.025107410603335927, 0.026694615970232656, 0.008392020178559636, 0.050352811480739286, 0.06337183913482086, 0.03219171314101134, 0.025359888394762362, 0.03808507815535579, 0.05087348871997424, 0.05639209545084408, 0.011707816406020095, 0.059091389179229736, 0.043907461621399434, 0.05296880146488547, 0.03547266744343298, 0.04692100527297173, 0.03361456375569105, 0.09625030096088137, 0.054436940899384875, 0.011960944742895663, 0.022365917085802982, 0.060493629292718, 0.069364416146917, 0.047930980899504254, 0.01484091962421579, 0.019126232979553084, 0.007979155368437725, 0.037302506754973104, 0.05328338047755616, 0.04113706420840962, 0.038667994019176276, 0.0784734637875642, 0.03155700469921742, 0.03877713976960097, 0.032290429808199406, 0.022476185811683536, 0.039242051608328304, 0.06131514521049602, 0.05003258705671344, 0.09341874040131058, 0.08689683822116681, 0.04966859373130968, 0.025593837091167058, 0.006154964436843459, 0.02270036869283233, 0.01754293936703886, 0.027462573422651206, 0.0025829376952190486, 0.020858544756525328, 0.0784231097038303, 0.037031024894011874, 0.13060002348252706, 0.011951418111233838, 0.014940766052209904, 0.04276676961619939, 0.023725188969235336, 0.08732622196631772, 0.049719114056123156, 0.05269104654767683, 0.056491928308137825, 0.02030902129731008, 0.028971138277224133, 0.03485508183283465, 0.03960951224767736, 0.013933216188369053, 0.0291211114797209, 0.03309550482247557, 0.008956434088759124, 0.05749312029885394, 0.007662082739573504, 0.015357557883752244, 0.04319084382482937, 0.014363388730479138, 0.050114326777734926, 0.006185019721410104, 0.014251617049532277, 0.007354105872634266, 0.07043762105916228, 0.030267618530030762, 0.03844163812963026, 0.02832537141096379, 0.04765473233003702, 0.004609465648952339, 0.08013590172465358, 0.06595460125910384, 0.042896994056978395, 0.06876908987760544, 0.033843569324484894, 0.06049193974052157, 0.06122491362371615, 0.06773607459451471, 0.0548191732460899, 0.046239572909793684, 0.03844456261556063, 0.07012094198060886, 0.0332062349521688, 0.024090527490313565, 0.08432571297245366, 0.06650417391210794, 0.03431690178279366, 0.02641453198157251, 0.06200108304619789, 0.012683308882904904, 0.02858435296054397, 0.02597550455746906, 0.02625161063458238, 0.10816175929669823, 0.060369674515511305, 0.02170039976148733, 0.012045576719434133, 0.020014148637918488, 0.07527692602681262, 0.033627683230276616, 0.03913734686960067, 0.03856243432632514, 0.02369108240652297, 0.052629018268947086, 0.016175173921510577, 0.03958974652258413, 0.022974196588620543, 0.1103954083685364, 0.03226167010143399, 0.0434107705950737, 0.07426259759813547, 0.06196033023297787, 0.013345584506168962, 0.10240470857492515, 0.015106917225888796, 0.016583864044930254, 0.03817854296149952, 0.058079340628215244, 0.025074014806055596, 0.002534224818061505, 0.09922294252152954, 0.09549123740621976, 0.05459741103862013, 0.06805303187242576, 0.08953075510050569, 0.0042951147936816725, 0.05833050036536796, 0.009886070320914899, 0.04810822103172541, 0.035517376115811725, 0.026079944667539427, 0.04394341040668743, 0.05768553925944226, 0.030592039693146944, 0.04472450938607965, 0.019737394559862356, 0.008367281639948487, 0.07959598462496485, 0.068131124467722, 0.021399771428800056, 0.06940685851233346, 0.04095770365425518, 0.06203580368310213, 0.04668556379952601, 0.038512945374740024, 0.052222541866025755, 0.08146354369819164, 0.019017151689955165, 0.04686245448621256, 0.040689461798007996, 0.04696558841637202, 0.03445039676236255, 0.02745675837754139, 0.059749330660062175, 0.03950308742267745, 0.024275701393240263, 0.03886009406830583, 0.03305820235982537, 0.04728024885324495, 0.05542568516518388, 0.03957794340593474, 0.044832331993217976, 0.032097515517047474, 0.02675234403328172, 0.02250803624545889, 0.0521523847377726, 0.04469534934365323, 0.03141401022938745, 0.06353255015398775, 0.026363093938146318, 0.02274270249264581, 0.013487303330163871, 0.03253920449476157, 0.01965388046976711, 0.01942749404614525, 0.019301939622632096, 0.005256402988119849, 0.038153569480138164, 0.03420159832707473, 0.013931463023514619, 0.06358162859188658, 0.03345530819413917, 0.030728720394628387, 0.039055488404950926, 0.01575761364905962, 0.02728080576551812, 0.024693085246586373, 0.022232364430757504, 0.04046648840552994, 0.017771288453202163, 0.053659170134259124, 0.04414070124870964, 0.03991817443498543, 0.03288450078772647, 0.019655705728967274, 0.024692988555346216, 0.01189266546030662, 0.025689479994720647, 0.0032024715494896683, 0.05343434773385525, 0.040557178003447394, 0.02823868177698127, 0.043100347609392235, 0.05402558582967945, 0.01513789574216519, 0.02163053609962974, 0.04644065336989505, 0.02114483225159347, 0.04102482094562479, 0.014300590314503227, 0.044273555012685914, 0.0324973219207355, 0.1000108980972852, 0.011701788470548178, 0.07341372314840555, 0.034950069950095246, 0.03311774380771177, 0.04625836832981024, 0.01842606456817261, 0.07006521389952727, 0.05406954472086259, 0.0625272055289575, 0.03026460244187287, 0.038160307332873344, 0.024915860167571476, 0.052364752627909184, 0.03559706326840179, 0.028961964483772005, 0.051607938416834385, 0.013447907586981143, 0.05391116786215987, 0.016859705493386303, 0.04160764520721776, 0.049683850591204, 0.016876467004684464, 0.07505864809666361, 0.021113799452515583, 0.03488064563966223, 0.017024767618360262, 0.02591844485141337, 0.04597748875884073, 0.023634825068126832, 0.04475271608680487, 0.03605746963460531, 0.07200226174401385, 0.06358033937535115, 0.08682281683598246, 0.04195670397686107, 0.00966450828127563, 0.06353077917758908, 0.06307261876229729, 0.022824625418122326, 0.04358332883566618, 0.047123242635279894, 0.06909862719476223, 0.02373247134632298, 0.03058000248191612, 0.02935148768925241, 0.011973993819473045, 0.04247155599296093, 0.06717985229832785, 0.02979553457615631, 0.08819400718701736, 0.027289984647982886, 0.042563097152326784, 0.04534876838858638, 0.06374765254024949, 0.045481031827096424, 0.02559288714214095, 0.03267103027818458, 0.05650809779763222, 0.026180035368140255, 0.02940911566838622, 0.023995598744867102, 0.025212817625807862, 0.08330173577581133, 0.05655939843771713, 0.033674413937010934, 0.007757103935416255, 0.10322046373039484, 0.01453945499711803, 0.04230683143915875, 0.044444596727511713, 0.08614432252943516, 0.063093348007117, 0.014505847157644374, 0.029795079957693815, 0.04285249233778034, 0.039541448399956734, 0.05820525637162583, 0.006175810304869498, 0.037139994225331714, 0.02721536106296948, 0.04592658166906663, 0.0615328328151788, 0.019832004393850054, 0.02984630935160177, 0.012942244631371327, 0.06031034341348069, 0.03410834725946188, 0.07330027887863771, 0.05753765933747802, 0.07890913755233799, 0.019908068169440542, 0.01106494349161429, 0.010443796420336833, 0.005733396142854222, 0.027619547410202876, 0.01782996137626469, 0.013432281773670443, 0.10348594055644103, 0.03410952451771923, 0.03026563042242612, 0.0360062130992966, 0.04373923582690103, 0.014113465623397912, 0.04976396182818072, 0.04256332106888294, 0.08200983224170548, 0.004645683727825859, 0.05290709549028959, 0.06344099542392151, 0.053997423233730454, 0.01894355269281992, 0.014117192476987839, 0.029531167154865604, 0.044570424261369875, 0.01777353440411389, 0.012522995654892708, 0.03346106217109731, 0.014131474790961614, 0.023156888749716536, 0.08458626363426447, 0.016941119517598833, 0.054803210709776194, 0.03229859258447375, 0.07264928559639625, 0.18880316961024488, 0.06366312064762626, 0.0848688870402319, 0.10781591678304331, 0.21268153616360255, 0.13867995063109056, 0.17404838491763386, 0.11807265212493283, 0.086649240792862, 0.09287623129785061, 0.19505301996001176, 0.1375675331801176, 0.161531178014619, 0.08421205157147986, 0.10149212647229433, 0.06281751673668623, 0.09539626964500972, 0.1474816490496908, 0.08779042812862567, 0.14779511865760597, 0.11764795705676079, 0.09980658441781998, 0.08532505934791905, 0.10862600617110729, 0.10559133972440447, 0.12323941130723272, 0.049312162678688765, 0.10328672267496586, 0.16235987283289433, 0.16688982690019266, 0.13272980919906072, 0.13913203137261526, 0.20708724563675268, 0.18094377991344246, 0.0834254462804113, 0.10723003572119133, 0.09710049855389766, 0.1007999393290707, 0.1370637480701719, 0.12539108656346798, 0.0895073524277125, 0.18114409702164785, 0.1538470403424331, 0.14019369440419333, 0.1280441042035818, 0.10634966367589575, 0.11086060519197158, 0.15365030589912618, 0.1514578235468694, 0.13059952136661324, 0.13613548502326012, 0.1964140119297164, 0.12059292117399828, 0.18743973491447313, 0.195633452385664, 0.20250071531959943, 0.10302424497370209, 0.12204958658133234, 0.26128136260168894, 0.1572070914719786, 0.1677023590143238, 0.13819163611957005, 0.0949276869318315, 0.13651978011642182, 0.23092262021132878, 0.1361280075673546, 0.11885979345866612, 0.1367613657244614, 0.05251186919797744, 0.21263992839625903, 0.11798071062990598, 0.09668902813323907, 0.09555874485522509, 0.13132996431418828, 0.21738520876637527, 0.08297244273126125, 0.10235409664788417, 0.16816480777093343, 0.09848310186394624, 0.16630467187081063, 0.11911113640027386, 0.13260498589703015, 0.07879585613097463, 0.1201392255191292, 0.20929389580019883, 0.18859484578881944, 0.087586535140872, 0.10941446386277676, 0.18693422632558004, 0.32324949598738123, 0.07632770535669156, 0.12209206287349973, 0.1102558947833521, 0.17903994635811873, 0.12695896386035851, 0.14184756922934735, 0.11827769183686801, 0.09867482871881553, 0.10916698178542511, 0.1772506223725421, 0.2015303559601307, 0.18898414847041878, 0.10993913428059646, 0.2068650254181453, 0.22647639736533165, 0.10452072003058024, 0.08427221048623323, 0.12194407438593251, 0.17305006991539681, 0.12901795123304638, 0.1387901854302202, 0.10775640247655766, 0.11523978199277606, 0.1683068930038384, 0.2143705455320222, 0.1455975744341101, 0.12665244245103427, 0.07077520580164023, 0.1803845042096717, 0.08906877453305892, 0.11423324314611298, 0.13542033625500544, 0.20957731987748826, 0.18433219380676746, 0.09655653060014759, 0.14963105799896376, 0.1185907136116709, 0.1525662647826331, 0.17951823212206364, 0.082053550252957, 0.195540560941611, 0.1470246964267322, 0.13697342148848943, 0.09479756427130528, 0.12179365674299852, 0.12761007249355316, 0.12050959707370826, 0.12884653971663543, 0.09698381767209087, 0.17290202714502811, 0.17241144632654531, 0.23903485919748033, 0.16421451259936604, 0.15914460750562803, 0.15084121163402284, 0.11693909152277879, 0.14389310803796562, 0.16812841115253313, 0.10396691331905977, 0.2049863247999123, 0.12983129758919987, 0.10771867592952081, 0.09987548964896373, 0.14269614512366907, 0.07699158401893717, 0.1575401843126331, 0.10234496356653315, 0.15865401311644486, 0.17908684669860772, 0.11274811998009682, 0.15867564481283936, 0.15311629883944988, 0.1329556256532669, 0.09778875019401312, 0.17082212732306548, 0.13349436888737337, 0.11106147191354207, 0.16593827653144086, 0.10692571276532752, 0.08452351950109005, 0.14688603101032122, 0.11463588582617895, 0.17807131047759736, 0.10265732037701777, 0.09871784105364766], [0.010125918031137968, 0.03288298426195979, 0.0335170955929373, 0.028107712644019296, 0.061920608792986186, 0.028511081356555223, 0.041919971483626535, 0.006349075494134533, 0.021726659066709023, 0.0502370364431824, 0.07230567546295268, 0.05249751478965793, 0.0356619210381593, 0.059923761657306125, 0.01955103830966566, 0.010437923699750431, 0.01656069716305605, 0.014809661212244203, 0.022341430453317504, 0.027456322418791906, 0.055967987315463166, 0.043630721114043675, 0.0463912288791367, 0.022248138673603535, 0.012892468998740827, 0.034940824910466156, 0.022004492015444806, 0.04860476617302213, 0.08040933098111834, 0.005533530684520623, 0.021504713654784218, 0.08574243302323989, 0.023878909381372587, 0.007414218986273876, 0.07168895498450313, 0.04020228043996862, 0.026074633434680954, 0.024067155351596217, 0.0531696512230805, 0.061539665662816594, 0.009012429343004311, 0.03556289563753775, 0.012618304379949612, 0.02718403310115848, 0.029867944440671375, 0.015103056361632687, 0.038088002641286166, 0.024852435803040862, 0.028843875641801527, 0.030197749779160534, 0.024260508994172727, 0.05177331775692957, 0.01219101476350001, 0.06228967077497925, 0.02886041154020599, 0.02671679897632982, 0.024074987342048968, 0.010515342000871897, 0.006029218751271921, 0.029350731122706617, 0.02162921126000583, 0.046413722315004895, 0.02451231673226825, 0.016654940588133674, 0.06718227466834442, 0.0233696671535394, 0.02715333108790219, 0.008320792661314564, 0.06126076062875135, 0.047273877409419844, 0.05456964877833213, 0.020211129050169672, 0.03890039226306336, 0.06936269266796963, 0.02379424517442073, 0.06796098181179591, 0.008144374404634749, 0.02994326182774135, 0.027344940895480768, 0.028987789526581764, 0.04685489899877991, 0.01135459482403738, 0.05663656483271292, 0.019186005129345825, 0.036703251767903566, 0.02418025187216699, 0.025216159410774708, 0.04904040261836989, 0.03523332439363003, 0.09658663041357483, 0.052228991341378005, 0.010048043415216463, 0.023484315822965333, 0.017824448279238174, 0.057327632393155775, 0.02237392888803567, 0.1501887459307909, 0.09053789784333535, 0.042140437689210684, 0.05977710988372564, 0.010329286002420952, 0.02094992476382426, 0.06655433122068644, 0.030901244708469937, 0.046400979427354674, 0.058145938840295584, 0.02011000188732786, 0.0397917803243867, 0.05123478826135397, 0.033565427642315626, 0.024899880667882304, 0.019220333912276795, 0.041177301335015466, 0.020130230712571313, 0.015979547186621597, 0.033160871493497064, 0.039496400460068665, 0.021489076815279465, 0.017365163192152977, 0.07318745207573686, 0.03533169161528349, 0.048425707566951, 0.010562953954961683, 0.05410097785560148, 0.030900508497974703, 0.03330745880625077, 0.04297538860035794, 0.0363911222666502, 0.011321606147768242, 0.03390274436346122, 0.02546772457260106, 0.04585844996784415, 0.03687903983518481, 0.06465048409466233, 0.014143965772486158, 0.024657989719084332, 0.05364009312220982, 0.04275171970948577, 0.030170163937977383, 0.044115378321813684, 0.0652749195162739, 0.005751910819006818, 0.06875150224992208, 0.02660015202127397, 0.03890639390530331, 0.07173466110335928, 0.029778116582227603, 0.03705838342596378, 0.05570132305313434, 0.05784572780664478, 0.045047563301133256, 0.002943172996830461, 0.029430957710636512, 0.02119908621534705, 0.02261968409376485, 0.0049773024511523545, 0.0504975904976683, 0.03312578784035785, 0.06911474240145513, 0.035326724738946984, 0.039102985856256316, 0.039445520511695316, 0.010472207529736417, 0.06890031176486186, 0.029493776482662985, 0.00891084671353123, 0.06480830455464975, 0.04499566215755684, 0.023451949702575803, 0.010854968285587217, 0.0299421829570617, 0.027787508576044014, 0.1110295264848641, 0.014617411885410547, 0.04260374818529401, 0.026335000892036727, 0.02117107798611479, 0.02095094765536487, 0.019572513943005885, 0.024556156879823123, 0.02179901804109769, 0.028358911396935582, 0.08645834175071546, 0.020951631279396157, 0.053018622898629734, 0.014107659908144601, 0.03665559486086879, 0.01399977708102337, 0.008852625016256102, 0.06243984414530652, 0.03259422689942377, 0.03440937932048525, 0.10486112747873579, 0.04089030137817774, 0.008635513318170394, 0.022065132690061415, 0.05093753564038447, 0.007346492709725031, 0.09312762852225985, 0.03948765753635338, 0.0426208744091647, 0.028920539920883517, 0.02366002755505698, 0.0760752156909023, 0.06676493491977453, 0.0015005102198171827, 0.04084547735484583, 0.012151451082900167, 0.028298214743179933, 0.026707835528733473, 0.032132928259670734, 0.02204203705436417, 0.01717700034246913, 0.07120537664741278, 0.03214196973879423, 0.055179814608501535, 0.040547379957778115, 0.058496001841766496, 0.04293290213016527, 0.05052646555538688, 0.03782075823151639, 0.040716233397168775, 0.05712777668876307, 0.043234365060925484, 0.059540274020816596, 0.022429712948256304, 0.018817523294793706, 0.029637924462024654, 0.01771733134851924, 0.10992015565612487, 0.037514674477279186, 0.02042195157680128, 0.05619580884064947, 0.0352440316762243, 0.06784383274082627, 0.014683882872174894, 0.01763493853754231, 0.03921764131103243, 0.022390442734052027, 0.020496997549863796, 0.043586422955351214, 0.026480865564995577, 0.05310822344784226, 0.04893527379525559, 0.030493034648575952, 0.00930895677967263, 0.02442828525922128, 0.0053923992174012315, 0.030136260935770612, 0.02100721008277365, 0.006360263264338885, 0.02276410348713398, 0.03746987759534802, 0.009862804203294218, 0.01902198964463813, 0.03320198053760188, 0.02863671550793307, 0.02169070688874594, 0.004932623040596289, 0.026989398723734275, 0.04791481141000986, 0.03614776228953685, 0.013349528490964855, 0.023358842823654413, 0.05683715674760086, 0.03021721016349537, 0.04523661672802908, 0.012224005984275468, 0.04740796271445496, 0.035924205356942754, 0.027670193263994794, 0.03767906654892223, 0.025013681168534925, 0.06432577116148812, 0.07434748232896839, 0.03776150516101292, 0.02002425372068371, 0.04097489094627755, 0.03715268622285553, 0.06338993566376822, 0.03184800801266517, 0.00935216504149139, 0.06438660861126014, 0.02936792859275426, 0.04470416012087038, 0.04600248598892774, 0.012796520754428846, 0.04776925886315959, 0.05183774126427514, 0.036891243287495205, 0.013192687665910592, 0.06311563109712941, 0.012574204692750104, 0.034033430208052905, 0.05166650616696902, 0.03871718780802829, 0.019117166055366397, 0.019623078372595564, 0.02710065132539187, 0.028041742076831203, 0.12657944565372808, 0.02269832799876375, 0.021253387676551938, 0.017139670738418187, 0.0565981224312314, 0.008898382025238658, 0.04315033867689116, 0.005325251816040171, 0.07047588364886385, 0.02418424844342683, 0.051640470778303485, 0.06706888468137809, 0.028072752823520983, 0.09330658534807817, 0.041842034951384575, 0.0655486812548978, 0.0736238518729806, 0.002330579495589648, 0.029055880515703132, 0.027387138988290514, 0.03226606700835483, 0.01884156887951706, 0.025632791786587665, 0.01097079336510173, 0.035893437186522145, 0.04722659369664533, 0.02595125710857766, 0.017053439115573252, 0.019459880522585342, 0.05194425429882748, 0.004109889576544187, 0.04428979914103236, 0.05128992262429424, 0.03627199865877628, 0.03407019662803837, 0.02114320207121117, 0.03689336031675339, 0.0340192250774375, 0.02656337203058813, 0.03675598750955292, 0.014762043320973004, 0.027023561265585676, 0.03439238880361829, 0.043094413820654154, 0.012167357640074832, 0.03142654277118189, 0.03563667953546558, 0.027918114692771008, 0.04137622066108244, 0.0036848047748208046, 0.04073960892856121, 0.030800458509474993, 0.14082011793340954, 0.12880369701555797, 0.16761543867843492, 0.1399581070457186, 0.1040932633248823, 0.15841645800641604, 0.1984922154141324, 0.05438370643449681, 0.1567937143679176, 0.08431095483579806, 0.14935003593564034, 0.19664721084492548, 0.04376072842361672, 0.19771337934902736, 0.19339329616299697, 0.10039000918290444, 0.17851029549326214, 0.12467593779521328, 0.14181020909122058, 0.06463019589760474, 0.1959327541823898, 0.12383019817726952, 0.216604689934424, 0.11436421397541251, 0.1898362391761371, 0.1314367385847228, 0.07392381863402468, 0.22602833355111734, 0.14138645040137426, 0.1072184599137732, 0.0872939508408308, 0.16991732801709855, 0.12115329610449926, 0.08988366116370473, 0.11020738631486893, 0.099828962502735, 0.1261568676148142, 0.14250820449420384, 0.14691172034612723, 0.19618162725652966, 0.06991959349917513, 0.12861228228679725, 0.12704718698348316, 0.17254636622965336, 0.10274398965494973, 0.13284380308219365, 0.11399513163736888, 0.08887742765780006, 0.20980473767433847, 0.14572452833609922, 0.20372659739639076, 0.15406930127314158, 0.12014291674963065, 0.1498057400541646, 0.08572422792868954, 0.08270661306700536, 0.11832213588058949, 0.15860110095569066, 0.14531728518860682, 0.10610533678638083, 0.14579166259084428, 0.11362821382603475, 0.11498265793280942, 0.06291646071310554, 0.16641538164445333, 0.13217445542769773, 0.08183630369603634, 0.19099506842238562, 0.12027766023363386, 0.06227948596434934, 0.15888619422912598, 0.059620775415429046, 0.07332883163222245, 0.13153687678277493, 0.1515463316547019, 0.1419548863278968, 0.06611846068075725, 0.11123315484396049, 0.15548378894371645, 0.08042217564902135, 0.10371371119150094, 0.12187577305095536, 0.09058268793991633, 0.12417410686612129, 0.10879132444305079, 0.11012746167502233, 0.15557426480310305, 0.08541684477989163, 0.1076197794505528, 0.252785859895604, 0.13500104232558183, 0.11177695316395589, 0.13571591967982904, 0.1487902852573565, 0.10953898860939912, 0.18095133879355021, 0.24367848145110266, 0.23446416588766233, 0.1079736083213772, 0.2225476253245558, 0.061769824741142135, 0.08195671652044569, 0.12597791078899587, 0.0771639251283237, 0.12816786899098329, 0.18222266914589064, 0.09452397895178624, 0.14650822271193775, 0.1170224699058703, 0.16612103315336363, 0.07889581112457172, 0.12704691556947573, 0.23475604451128415, 0.11308666145695107, 0.10761884307222706, 0.20203853797699722, 0.11813263462058135, 0.10586647888911621, 0.09241820658956255, 0.15978015054549488, 0.15567357518843242, 0.10547386495662586, 0.13348530365952424, 0.11230451414095503, 0.295401360307421, 0.09123792885137455, 0.15104580351284572, 0.13799629945840153, 0.15992797618465765, 0.14234859948711737, 0.14168537221848965, 0.12129205651581287, 0.20616537438971655, 0.1012915311647313, 0.1077700410304325, 0.14561501278408936, 0.1454284835074629, 0.2254406272300652, 0.1828995213976928, 0.16718398540147714, 0.1419417770313365, 0.0748122041778905, 0.09336528541254145, 0.0703935298536505, 0.14020780793258122, 0.2522997574082443, 0.11506895401648112, 0.1586302372493914, 0.1456001257257802, 0.09711869007774762, 0.15010061780256884, 0.1320775199149336, 0.07628331559577159, 0.06699054781347513, 0.09138064512184688, 0.12789558645870003, 0.1138955226966313, 0.15181972698441573, 0.14623196396444524, 0.13072665168770722, 0.10357333586684295, 0.09440442108150039, 0.0787576681801251, 0.17595881383333886, 0.103205223833876, 0.08442237707121031, 0.14194214344024658, 0.10371196057115283, 0.10411832162312099, 0.10795701814017125, 0.14340373501181602, 0.08228245404149805, 0.1521759850106069, 0.04224911864314761, 0.15245552786758967, 0.09952837148947374], [0.008386910809869213, 0.04599692539444991, 0.11110335109489304, 0.035855954912092, 0.08456136818443026, 0.02161290606350771, 0.03171618562191725, 0.026324227452278137, 0.05447602451645902, 0.021156114592616047, 0.02344900486059487, 0.037713872002703805, 0.03001050464808941, 0.03476983069309166, 0.013468803072880422, 0.017433364443214874, 0.031467726454138756, 0.05994371058685439, 0.02923046757600137, 0.09350478542702538, 0.020812672396589602, 0.018861911359376142, 0.01627264208426433, 0.011002226499840617, 0.03975529549643397, 0.06090822097446237, 0.03808491869962641, 0.03709055955654808, 0.01351183491559433, 0.07289720193615981, 0.0762644794636539, 0.05975685561341899, 0.013127108104526997, 0.012189811212010682, 0.022144227820847715, 0.08743709458836488, 0.009774655719021601, 0.012642021723357695, 0.05402027968583362, 0.040016470410461934, 0.03053590449105416, 0.04637124263016241, 0.020892630963187133, 0.00831373080810798, 0.05542514233716896, 0.016873264319396446, 0.03305238392204046, 0.036010894990925274, 0.02523189633419471, 0.02787176057297204, 0.03810818227274077, 0.04373915779537388, 0.025577126469995295, 0.04724223732150026, 0.03480536896469338, 0.043510325253009796, 0.007489854436633843, 0.0253059007560036, 0.026047800767368505, 0.02056460508278438, 0.05818371967013393, 0.04456189168351037, 0.057463468318539004, 0.024381188143576895, 0.016510551728840386, 0.04123624906476055, 0.015046128969905632, 0.017508987171043242, 0.027324103085058074, 0.017930411700425402, 0.02563319381858621, 0.013404255732893944, 0.026676183566451073, 0.005480152030941099, 0.039585509071392674, 0.008398244041018188, 0.05542588533301439, 0.05697139472301517, 0.040362584338124306, 0.049504591817302365, 0.004268226147230182, 0.04529060097411275, 0.01835672337827938, 0.033448651765606234, 0.037039275879838636, 0.1012096998414823, 0.10286537956978593, 0.032059408990400176, 0.02483124515440847, 0.0329827831925026, 0.05618458926411612, 0.05975815161530461, 0.03405257168092898, 0.061017838306725025, 0.038228160834738185, 0.03330377096842442, 0.01996750444439905, 0.06714125722646713, 0.011024686857126653, 0.030228463666779653, 0.023228869440832307, 0.017542337167209814, 0.06982798448630742, 0.07763621264270373, 0.07388516927936248, 0.028927949523287158, 0.08458540189479079, 0.03304135433531233, 0.05521638425333159, 0.07984500019145863, 0.021260768441217284, 0.02607031455928726, 0.022878402711025307, 0.047234535949038606, 0.04272476490586996, 0.04336909158155322, 0.007854046233530556, 0.04260564808334623, 0.03992600133642554, 0.07196292028363262, 0.07157307477401835, 0.03567800571077636, 0.04823718339736972, 0.03434914915955492, 0.059243794929768355, 0.0016900859066351715, 0.0435179044891681, 0.02560655283741653, 0.028298494638875127, 0.04161272404183235, 0.03529620423380818, 0.04513955568628652, 0.036144043917634656, 0.011386664933525026, 0.043927057712738, 0.016527993471494744, 0.01297907211950847, 0.04110548858131681, 0.033743688969739845, 0.005442635405675641, 0.052993198191480975, 0.039461350733680386, 0.02045656195176499, 0.04228771371500833, 0.011753095047814506, 0.020886503791968738, 0.05518434043707592, 0.020536126968051707, 0.030164949396359067, 0.03942826197349599, 0.012607006771889116, 0.016642993282792822, 0.058529691105442386, 0.021967099646904638, 0.013076057674230208, 0.05986877317939486, 0.022332048010347143, 0.029449359580342258, 0.02715770254975983, 0.08750711940228939, 0.01519830571487546, 0.03716900499005403, 0.016763070232367942, 0.01290160886544202, 0.05754150663103376, 0.07528711762279272, 0.027293545260493244, 0.03227345286203282, 0.020993885351344943, 0.02096312735894961, 0.04173714700820191, 0.09843516336487872, 0.08002304099500179, 0.03690997763936009, 0.02125511285183685, 0.032567692787519524, 0.014274135930463672, 0.04629868348794324, 0.010826115280256739, 0.018536351953766177, 0.030345823083605086, 0.030263194481709173, 0.07334503504846777, 0.04605386805321489, 0.023171022634154985, 0.06344672225947891, 0.013944592676125467, 0.06124179557498012, 0.05049946325431977, 0.042592616818313084, 0.04494623427412339, 0.03819091265488948, 0.018561476409169178, 0.05554863231788788, 0.05609893439603703, 0.08538365763212953, 0.053226912793304236, 0.018046581984630654, 0.04017480994973864, 0.045166876898812394, 0.015491768717765808, 0.025474521797150373, 0.01794328011705407, 0.04921122720198972, 0.04808558849617839, 0.016323474535186375, 0.010594884964770504, 0.03241341767300453, 0.05662012732188616, 0.025037903172363127, 0.04940510840554323, 0.006484503450337797, 0.017681336762117486, 0.06107733225716012, 0.06473741121590137, 0.04123361634888819, 0.028353924164548516, 0.03020960378593632, 0.021773552621847818, 0.03569785625274692, 0.034124479429530244, 0.036860522614525895, 0.023493019730917046, 0.0229944508589272, 0.011563099305411535, 0.004339773424102792, 0.02652930448363934, 0.0176244008887027, 0.021573559514113834, 0.02896001369559339, 0.049480347761086056, 0.037086023549948416, 0.00847527981802289, 0.027841872801738124, 0.049236753689391274, 0.02549488972207265, 0.07918120295341526, 0.05945807628865753, 0.0398207978744592, 0.0550246065083359, 0.02500683135752167, 0.06727108133158513, 0.0063231512155782965, 0.03627276201067226, 0.045393914716052156, 0.02752404360632811, 0.01742236708690013, 0.005101506165894014, 0.033812645091009993, 0.022769382489579063, 0.042407749952482324, 0.05493152168180261, 0.01802863134071231, 0.05789611581712961, 0.01223338079372687, 0.03973925153591803, 0.02696511395541685, 0.059998814415718825, 0.07020419822739703, 0.010329798296360033, 0.013380359425874693, 0.05281346444306629, 0.040937371352421384, 0.024542564127062048, 0.03698876912572554, 0.025218849802123647, 0.03801896170313869, 0.03812296076544693, 0.021648502010586004, 0.00455081944320617, 0.05362080915697983, 0.03576600491734488, 0.034754852032555, 0.039649566169828176, 0.05092122705121126, 0.05022386607847043, 0.060587674246302674, 0.014945425891450472, 0.05436073463144047, 0.11281908117234707, 0.014447260747796722, 0.08221257171992745, 0.05381442912455116, 0.01339260274211743, 0.05288312624075583, 0.04072197719610163, 0.03552924369328788, 0.07142924570611545, 0.01786015279191945, 0.015341278132317322, 0.007458782621792385, 0.03450113082570689, 0.030092515783118348, 0.06537005012588841, 0.054686081994857104, 0.026653746109721915, 0.05799189782036202, 0.027888966524707418, 0.020388967989544784, 0.009400670965468245, 0.012092721332529826, 0.027137210792196647, 0.05502288981473871, 0.036505485951368294, 0.03392500709742308, 0.052993293186383586, 0.011410726633455073, 0.045278770716062615, 0.028253326259021248, 0.04783508015264358, 0.014769413907613074, 0.005419970639715237, 0.016163593025079796, 0.03895419330469199, 0.023185370257124305, 0.01789294638937073, 0.04748472538111465, 0.030885343240307908, 0.04793353558384946, 0.027157293732411096, 0.039953522716781924, 0.01864977926015854, 0.027624261532244936, 0.03532372222148946, 0.05515692083697234, 0.03764480392315558, 0.04269552343924131, 0.011424260014402015, 0.023902469813557606, 0.042289179350648604, 0.03501471058864679, 0.0802636630833149, 0.010325490447160388, 0.06390265029455934, 0.005320432945154607, 0.07920995926750557, 0.04059361872662391, 0.019563301133790185, 0.04500742456210511, 0.0016196389167037392, 0.09179391366030488, 0.06746415847114154, 0.02100903873464891, 0.016747139926467623, 0.02253456017933786, 0.03751429449766874, 0.05603541673294135, 0.017308919424457208, 0.07009534763970546, 0.03787220814930541, 0.04263298625924757, 0.012054160187420036, 0.1400372785116945, 0.08470164851418563, 0.20978016113596304, 0.16306088093136037, 0.2817249984613487, 0.11138313822448254, 0.10772540021155562, 0.1847954568053995, 0.07788646992828165, 0.17212325893342495, 0.0667471776583365, 0.1575445405074528, 0.13525159816656793, 0.09719214827886649, 0.1195922177284956, 0.11349462385156325, 0.13138636414493832, 0.13090193085372448, 0.1236220643456493, 0.18944040898765835, 0.15375923791102, 0.13333618880382606, 0.12708203654204095, 0.10497863617326532, 0.0897943184577993, 0.07798926119825669, 0.13575135277850287, 0.15541886671313218, 0.16975129049803528, 0.1794854724513633, 0.18558448446648462, 0.18011515294866903, 0.14244888696287358, 0.12282728270760604, 0.1353867623422827, 0.2056678453726428, 0.05855355518204825, 0.0952904521088515, 0.17975657433271408, 0.145837097295693, 0.18274632176118238, 0.1490384933671781, 0.079038853091853, 0.11507603792207581, 0.11117353875722204, 0.13519381412437984, 0.10670634239379849, 0.11811867036989757, 0.06953494556780372, 0.09717743763966219, 0.0659881073183247, 0.06388635188341141, 0.18462834720100674, 0.1360070247735296, 0.11946653947234154, 0.1611310187727213, 0.0849999189376831, 0.2012331033391612, 0.11068023022796426, 0.10796063473182065, 0.17908216480697903, 0.1793566865048238, 0.1588687151670456, 0.17088460682758264, 0.18982361842479023, 0.15543612864400658, 0.06777482572942972, 0.07367117290518113, 0.19449873827397823, 0.1052842822724155, 0.11180926500154392, 0.10507781763694116, 0.12858390595231736, 0.15394959412515163, 0.1106382899784616, 0.16436049262327806, 0.1258941117141928, 0.14803008176386356, 0.2264415342360735, 0.19751667204712117, 0.124874083591359, 0.10635972635022231, 0.13214717831994804, 0.14186830525951727, 0.08380556838320834, 0.19852455439312117, 0.24476858867066248, 0.11110092872487647, 0.06599077396094799, 0.08787339939070599, 0.14406333890344414, 0.1358757282474211, 0.16676182805427484, 0.10943588521331549, 0.09726275663290705, 0.10561429456408535, 0.15187418620501245, 0.15936639346182346, 0.13108020914452417, 0.1261753916208233, 0.12161788903176785, 0.10957442849342312, 0.17361041770449706, 0.1578853822180203, 0.13170310429164342, 0.16779571186218942, 0.15358846421752656, 0.11036551211561475, 0.15609361550637654, 0.20186579653194972, 0.16181230864354543, 0.11057087752435889, 0.0796194551512599, 0.10677974631211587, 0.0943691779726318, 0.19366017755653175, 0.09755197539925575, 0.14853788380111965, 0.14159303717315197, 0.1562419296907527, 0.18444706978542463, 0.1256335135549307, 0.14498762573514665, 0.08677972307694809, 0.15386257879436016, 0.09624683364693608, 0.11574288856770311, 0.13559306412935257, 0.12620831413992814, 0.12133875329579626, 0.16746587598962442, 0.11279620097151824, 0.12837708847863333, 0.10493348645312445, 0.08645353772278343, 0.1125873818195292, 0.06820446053253752, 0.10241392308047839, 0.11663224441664559, 0.07115486650062458, 0.134371103984969, 0.14709966097559246, 0.10288155584463052, 0.15207033710820334, 0.10282489138522319, 0.10458294847714049, 0.14087916405073234, 0.16145784194980348, 0.17273494468203612, 0.17493190536541597, 0.06716654622661215, 0.08067304361611605, 0.12828214785882405, 0.08866026252508163, 0.08220820195440735, 0.21350618691316672, 0.09276625434202806, 0.21471144152539118, 0.14671339813087667, 0.20765842284475053, 0.14536761891629013, 0.13555212132632732, 0.07739833183586597, 0.13000393046864442, 0.1448897538440568, 0.12154939770698547, 0.0942437711304852, 0.11983201200408594, 0.10984426829963923, 0.13295017023171696, 0.1301520818046161, 0.13879277743399143, 0.1700514472488846, 0.1617799968059574, 0.10759347943322999, 0.10443849515702043], [0.028196814469993114, 0.04084114830142685, 0.03823680876355086, 0.023504305464614714, 0.011076526084382619, 0.023868007019960454, 0.030703007310096706, 0.04784227262384125, 0.030416081992111037, 0.043841877819171975, 0.02787013378526483, 0.019044254074937532, 0.05335040616669825, 0.018641662284997956, 0.018978617686246122, 0.016290857356839945, 0.010126297162579638, 0.029771229451788322, 0.007530441856943071, 0.021166687864544134, 0.025974593624206524, 0.050003277736582925, 0.0468231265965317, 0.0816036815355931, 0.04015715107587831, 0.01621111422511084, 0.009523935333293463, 0.07643169763364963, 0.019784632471523116, 0.0773139763623476, 0.08054421017212526, 0.03624854848853179, 0.027997035100790005, 0.03707707028037735, 0.010822052551832582, 0.04072361585817166, 0.07139867770352534, 0.04780904137130294, 0.028411760793200562, 0.014582080566989524, 0.034973638863967996, 0.027647944100733315, 0.04684082278981805, 0.07100647089204618, 0.04890174398730908, 0.07609707130385296, 0.01769660210369953, 0.0320687863443579, 0.016821921270872866, 0.005203228743214692, 0.011630292083801968, 0.02627472492999264, 0.017279654209102904, 0.08661459479480982, 0.10048728396317788, 0.04328254443992462, 0.014786721639601248, 0.04793215476508651, 0.043753607198596, 0.010943884362599679, 0.039232514798641205, 0.015754738356918097, 0.06457528205854551, 0.027556036532457386, 0.023823215227041925, 0.06428375627313342, 0.023957368385578905, 0.04967093467712402, 0.017892373027279973, 0.027767727583912865, 0.042113761084952524, 0.06954816342996699, 0.06608639990112611, 0.007386977501612688, 0.04768212818141494, 0.029152687106813704, 0.026968576180349504, 0.021606010451380695, 0.018116379489323924, 0.06826158639575754, 0.006058173536855195, 0.019219209240483384, 0.06436672074986355, 0.017717819893732667, 0.053638047339128594, 0.03311989137104579, 0.024454810889437795, 0.034952051272349696, 0.0166116025564926, 0.02302729195382978, 0.018028346356004477, 0.03209054017705577, 0.026114222560343996, 0.02640905959664711, 0.03757097931312663, 0.051817839832178185, 0.0274788921898497, 0.03529012456004109, 0.03222391641299639, 0.014260538088689958, 0.055641690003020425, 0.02786724322608539, 0.00914484036288091, 0.01582235097885132, 0.02754855398753924, 0.04644671268761158, 0.02672097196669451, 0.1735825299152306, 0.05030634879533734, 0.07267048303037882, 0.04412909829989076, 0.03597291738593152, 0.03606593096628785, 0.053242366428353956, 0.030133163423410485, 0.06627876457891294, 0.01822575254897986, 0.061252631779227934, 0.03412075087960277, 0.026985914446413517, 0.014026264543645084, 0.010718681134416588, 0.010849473000104939, 0.0874310013438974, 0.01063172856811434, 0.0636734411652599, 0.07647000772080251, 0.06911795187209334, 0.03196594418425645, 0.016642788025949682, 0.038830659219196866, 0.011417925041834158, 0.016924726111548286, 0.05282557290047407, 0.011331863052743887, 0.050762487176273546, 0.03068454097956419, 0.0643406378637467, 0.04215823905542493, 0.0692773126065731, 0.03171016701630183, 0.017388292754601156, 0.07336832237030778, 0.02951495016791991, 0.052554189427090545, 0.036922608568732224, 0.06125668263328927, 0.11752774779285703, 0.0719335600733757, 0.040477019269019365, 0.016508261673152447, 0.04729959727930171, 0.02826111244836024, 0.05474304500967264, 0.006806232525767493, 0.0835756603628397, 0.026515967877847806, 0.014819225163332053, 0.013887754342119609, 0.04572906691048827, 0.032123537335012636, 0.047438934445381165, 0.0037472762217346045, 0.032798618610416136, 0.018085382313334515, 0.01842806115746498, 0.0661772218133722, 0.03446345177612134, 0.04401135890345488, 0.021067051782405803, 0.02282989933155477, 0.018531693810863153, 0.04173552191683224, 0.04157367095883403, 0.054314346584890566, 0.05466658089842115, 0.04492677728246365, 0.022687917575240135, 0.005564242027633424, 0.06816724288676466, 0.005667889948069517, 0.03471312212890812, 0.05363497018281903, 0.09183009993284941, 0.023347484147442237, 0.023937507665583065, 0.04531652779717531, 0.02644598377602441, 0.0757171663322619, 0.03589224975023951, 0.023427264598597373, 0.029030177609196732, 0.02945273868473513, 0.051267724351159165, 0.05134297388472727, 0.016375820119200007, 0.019041509400787096, 0.003179356829995023, 0.00967886608227023, 0.06131870073399373, 0.022554515894236307, 0.014952553901821375, 0.061976004391908646, 0.07685558524514947, 0.02872086063559566, 0.03897257481834718, 0.03645099280402064, 0.03309229535183736, 0.04065338409106646, 0.05326927034184337, 0.033007587040109296, 0.02216355249817882, 0.032187200883137326, 0.047531221993267536, 0.036910883483609984, 0.0327324716241232, 0.0418469441522445, 0.027566986391320825, 0.05611351950626288, 0.07328526289867503, 0.02753016399219632, 0.07394008990377188, 0.0835428803360888, 0.009529114251823297, 0.004315136665744441, 0.06123515271714755, 0.07366953085043601, 0.03288317085908992, 0.024516143669773425, 0.03374643703656537, 0.03207488637417555, 0.03555571334436536, 0.06949517663036074, 0.024177956727466414, 0.020947142770247798, 0.020456029301775352, 0.04958760039880872, 0.011058774760126002, 0.008328459258856518, 0.08325214843664851, 0.016287793771230748, 0.024881141227004782, 0.0070029775711840814, 0.028749549096184115, 0.04500768579808729, 0.06580202587481056, 0.05001749304522361, 0.012164129509723611, 0.10141363354133708, 0.01285684506209301, 0.02941132090719683, 0.0237592700868845, 0.0185066948844386, 0.030275984866810695, 0.05212454444595745, 0.04232636646234563, 0.03182595901723419, 0.016864818254751817, 0.007324483578226396, 0.028564149580363716, 0.05785517979945455, 0.025577852502465248, 0.018737507052719593, 0.014388771029189229, 0.02874566787587745, 0.04540792985686234, 0.0075576070064146605, 0.0061154910862179735, 0.015382164956203528, 0.036164057308009694, 0.01404236363513129, 0.02726258710026741, 0.019922283478081226, 0.02169120221930955, 0.01783591043204069, 0.046499573958239386, 0.03778059574376259, 0.016077283370707716, 0.03349006615046944, 0.023352322102125202, 0.025857378396072557, 0.028616871751312698, 0.054951229731419256, 0.10980124917945691, 0.036896698709045134, 0.04462685801887086, 0.01974428677931428, 0.027178769365751317, 0.023419659917375872, 0.0371229290696127, 0.019215453549155166, 0.020950654188969305, 0.0803136643288391, 0.0800573273694941, 0.0878180173624839, 0.05612914277506726, 0.017845140204631856, 0.009543220994860997, 0.060619422899825234, 0.05357984260522893, 0.04274856452164905, 0.024751004995778203, 0.007333105213807097, 0.027437884925997684, 0.05061573701511536, 0.014842775417491794, 0.03587749839893409, 0.024587447522208095, 0.03378134427059974, 0.03722841751628688, 0.032556279828505855, 0.01829588762484491, 0.12066829284386975, 0.012767586324896132, 0.01808367240508752, 0.03180368271257196, 0.03492570375757558, 0.02132472375939999, 0.030904284545353482, 0.016067965388564125, 0.023789247764008384, 0.043229242121534686, 0.06115828827023506, 0.11303822084196977, 0.04223041143268347, 0.06733934195446116, 0.008798395649396946, 0.09579796916139977, 0.06739306157188756, 0.045000459400138686, 0.025152551841789057, 0.05932633871478694, 0.025943674479744265, 0.04599861494664635, 0.037507638069135804, 0.0159327079142843, 0.02778883171933038, 0.012651544962344425, 0.037391014862805605, 0.03887122882796185, 0.06134829164615699, 0.054631717769162993, 0.03205479495227337, 0.01629963590364371, 0.051662957428821495, 0.07846642737942082, 0.046470308742885075, 0.011199894776966954, 0.049552313185163906, 0.02900297853297421, 0.05688172292762569, 0.05023761659062334, 0.14818576483854226, 0.08618650705154453, 0.10538062745971338, 0.12824438059968607, 0.12037607495273862, 0.11849010043910571, 0.11664452590048313, 0.14500214638454573, 0.12177897324519497, 0.11191888233380658, 0.22184208461216517, 0.11905318950968129, 0.16583652342004435, 0.10331143492034503, 0.08379437255540065, 0.11521559900471143, 0.10641094895878009, 0.12837347867233412, 0.09820348436811141, 0.1307924831552165, 0.16163542813488416, 0.11981255161975111, 0.21371411718428135, 0.1657701219831194, 0.1059415927156806, 0.12362008302339486, 0.19070579537323543, 0.18136144535882132, 0.0985268945140498, 0.18458942643233708, 0.16597563666956766, 0.12689670148704732, 0.10091139549123389, 0.10667833246822868, 0.23549051795686993, 0.18822503063295568, 0.15555340663662978, 0.13473426949765, 0.13866829339947018, 0.14031809701451234, 0.16605647733168943, 0.04896006067948682, 0.09755753938640867, 0.17879317674253667, 0.15319376039717877, 0.14801514042275293, 0.10765677317976952, 0.13538978860846587, 0.13013548483805998, 0.11479063252253191, 0.11893212529165403, 0.17733438073524407, 0.10649299062788486, 0.26367759544934544, 0.10776418527322155, 0.08299145528248378, 0.26327397567885263, 0.1086325268926365, 0.12873374005513533, 0.06371285726449319, 0.09557754027524165, 0.10947036157761302, 0.16117798696671212, 0.17113787680864334, 0.10409134307077952, 0.19953767502946512, 0.10188113059848547, 0.09919620824179479, 0.10359318301613842, 0.08435499854385853, 0.10891795264823095, 0.17309744523039886, 0.14509255439043045, 0.06122658281986203, 0.1864968833646604, 0.06113458704203367, 0.1437069315995489, 0.10626241764319794, 0.146099147519895, 0.20815215206571988, 0.08012769823627812, 0.13874446574066365, 0.1383285237742322, 0.09026560852570192, 0.1594072819820472, 0.1114477618996586, 0.07637047341891698, 0.2242896282779319, 0.09217809340251343, 0.06729156630379812, 0.08215476732168879, 0.11962879076600075, 0.11953667285186903, 0.14549614701952251, 0.08912659250199795, 0.0921330793893763, 0.1363915777099984, 0.20323973494981015, 0.09384973905980587, 0.07441889135433094, 0.10237502266785928, 0.12905551493167877, 0.10598136843847376, 0.1308822397674833, 0.10132435190358333, 0.06387158017605543, 0.1359379906207323, 0.27639613726309364, 0.19464042995657238, 0.1114678465362106, 0.06460865241076265, 0.09058481175452471, 0.130279646388122, 0.12015970370599202, 0.07200892495789699, 0.1119157135752695, 0.11066679523459502, 0.16816321999898978, 0.19908609640385422, 0.0605053747338908, 0.08258448354899883, 0.11127734104437487, 0.1323434513594423, 0.16332393538738998, 0.2966253289154598, 0.09397005010396242, 0.15647685208490916, 0.14108770500336373, 0.10196870232799224, 0.10464932277266469, 0.11286966595798731, 0.12909512780606747, 0.10814197321555444, 0.17036890664270946, 0.08880265988409519, 0.09426429002944912, 0.2646586485207081, 0.09691953326442412, 0.0982430429596986, 0.13352940843573638, 0.09037745823817593, 0.060240759647318294, 0.15020389083240712, 0.1384113593293088, 0.15464773880583899, 0.12074799356716019, 0.1622280470494713, 0.2050482343350138, 0.1439463866076299, 0.23033129051327705, 0.1191975681909493, 0.2445014901459217, 0.15927051646368845, 0.09730765529509101, 0.10030136536806822, 0.1746814852314336, 0.09492082694279295, 0.11724425586206572, 0.08980406900601727, 0.12485460963632379, 0.09797741685594831, 0.10886111176971879, 0.08950593428952353, 0.12699424768132822, 0.17486756667494774, 0.13620503486267158, 0.10860735324344464, 0.14822613767215184, 0.10307131494794573, 0.1550887187144586, 0.08582677492605788, 0.20781363094491617, 0.09262335486710072, 0.12385208771697112, 0.23998866230249405, 0.08398299850523472], [0.04616222670301795, 0.02353453928870814, 0.027126233791932464, 0.05029358555163656, 0.044747867954096625, 0.039964599800961356, 0.06025674593235765, 0.06351149521235909, 0.041999587390039644, 0.14181580021977425, 0.04673276948077338, 0.037867702676781585, 0.05410142568871379, 0.01411763352474996, 0.010599927328127836, 0.011431756130020534, 0.02169735822826624, 0.05573995205174599, 0.03218919577609215, 0.013946449317570244, 0.08151435240038804, 0.028737355821899006, 0.009526807232759893, 0.012367162454341139, 0.05504977676485266, 0.005528909436959241, 0.008148812023656709, 0.047435287319655926, 0.030112580063619783, 0.04639040106641395, 0.03309348278811999, 0.06798177891011749, 0.0472606968666826, 0.01365947480579572, 0.020051646179386547, 0.09978238107370478, 0.04250298573502472, 0.012021153699606657, 0.01611262317081647, 0.013435166395668472, 0.014251255729634846, 0.022627237884859954, 0.039547307549842765, 0.04230573899777872, 0.06519812292286328, 0.04893553163856268, 0.010870949481613934, 0.027030833464648043, 0.07609561245356287, 0.014051155752635427, 0.031555878331086466, 0.012861635519324668, 0.052957130662564716, 0.04234933487272688, 0.023000104751970087, 0.014884987081001912, 0.02012958949697869, 0.03115402614431722, 0.09500913149011986, 0.006181692355312407, 0.029025868911828314, 0.0602327257926975, 0.04742397274821997, 0.04585358487176044, 0.06169690936803818, 0.04773106073428478, 0.0361834294827921, 0.04766567709988781, 0.015405430225655437, 0.03616255435294338, 0.027525963860430887, 0.0338339273418699, 0.06365799770823546, 0.05693229753524065, 0.007437379082797894, 0.05869818492127316, 0.027613006332623105, 0.037658717283712964, 0.04659820241587503, 0.024892693285697272, 0.0675026314066989, 0.02538537247372525, 0.03150469982730491, 0.024047978255631666, 0.10268775267260415, 0.00874398138174521, 0.07598321991307394, 0.012822908981304084, 0.008863356047576028, 0.07222345737474305, 0.047697995722826035, 0.06490118921335254, 0.03646744049287268, 0.04086554502802236, 0.05675752727048738, 0.019748218889747347, 0.0396806803931083, 0.04857274949816721, 0.030257525321628367, 0.04554860034425344, 0.07855758177382605, 0.01879653281399182, 0.03157043969258666, 0.015788383515817777, 0.05543769184233887, 0.029818645478891473, 0.040824435983917544, 0.04145599602322493, 0.00889658136293292, 0.04549035829092775, 0.020285352299522077, 0.03477250072839005, 0.03140768289033856, 0.031287775574518104, 0.09161629354847328, 0.04224180403564658, 0.03489459292697055, 0.08187622191118342, 0.06203479945127453, 0.02326694712974131, 0.051271408796310425, 0.018653012479522398, 0.020987780232514654, 0.017518929405403987, 0.026237056058432375, 0.05016637719901545, 0.004906823018765343, 0.061744875008506436, 0.03386045466842396, 0.04086458490097097, 0.02784672093444637, 0.04674302214490516, 0.011083223225016679, 0.02536108431273273, 0.04460688873327204, 0.038440264096217494, 0.10478404590061732, 0.03300981942032065, 0.09343872325760977, 0.07624941598623991, 0.05249211365090949, 0.02456170559993812, 0.05716956766056163, 0.02361615008807608, 0.06929869324501071, 0.041017160285264254, 0.0183586453287197, 0.014965115281354104, 0.035333140287548304, 0.028217360510357788, 0.07304132277412073, 0.004981850756199232, 0.07278637002621378, 0.04298975657937782, 0.03224252862855792, 0.031402994213359695, 0.02931442271385874, 0.05015815674726452, 0.016047263285145164, 0.002211023957767923, 0.014070070764449025, 0.005028627688131694, 0.055758364099477015, 0.00389396701107866, 0.030494927761277983, 0.05080971660624657, 0.03450045568336334, 0.03157919618700232, 0.02427380658420069, 0.03466695460623928, 0.04226330002503736, 0.031145239115825722, 0.04258781957573124, 0.0426540106668004, 0.12836753470557077, 0.026593756828723208, 0.004282147565390915, 0.03649439190381339, 0.025024195068648884, 0.02686020395984607, 0.03297124470451048, 0.014800188863383872, 0.043145901057869196, 0.08726891289864268, 0.024932289196710502, 0.04417566955089569, 0.04268034461087414, 0.067356291759227, 0.04078082314559391, 0.023140373207362633, 0.047491687150405984, 0.005223823977368218, 0.05801772964852197, 0.044074225172932656, 0.03546148518632565, 0.07036254115934883, 0.06981253424393279, 0.03667907556518912, 0.06516967194953135, 0.03405565901526383, 0.05974958850336926, 0.041208283243966956, 0.03396507798294936, 0.05019054322370461, 0.023975293584434048, 0.01313666272575834, 0.028185759438201785, 0.06072378158569336, 0.032004030354853184, 0.016132059806425656, 0.030981284699269702, 0.028932546598038504, 0.018953002989292145, 0.005714912424861852, 0.034103136110518656, 0.03619052017373698, 0.037098688406071494, 0.02922165679878422, 0.020651790047330514, 0.04044066336272018, 0.06260144404534783, 0.05400430697149464, 0.020113197787265693, 0.020264521274449568, 0.020697345192145025, 0.06373866195125238, 0.07590491018657174, 0.014914796820708683, 0.010611697366195065, 0.06467345250504357, 0.07082965823688678, 0.03678804150383387, 0.09673044591077737, 0.030925787320094447, 0.07634008183543171, 0.03431074747017451, 0.03401014627888799, 0.03657527667071138, 0.033162744250148535, 0.026288643379562666, 0.0668325237929821, 0.07007486266749245, 0.07834346326334135, 0.021774821482332687, 0.07597101306808846, 0.07081768887915782, 0.05039149476215243, 0.049441040227455754, 0.03981089126318693, 0.04567431591983352, 0.024205215175503066, 0.03270102491868394, 0.03887413974319186, 0.04228900632421885, 0.012980295178879584, 0.04555194552189537, 0.18469569858695778, 0.02210036731724228, 0.0103481263753825, 0.002503190958772653, 0.10262068627136094, 0.04472721674080406, 0.011434678919613361, 0.020834158207955103, 0.03446854757411139, 0.042805907516075034, 0.03462111617305449, 0.021858064158420478, 0.0011495008740374552, 0.01828945511286812, 0.04019071820325085, 0.02486842548075531, 0.04782295812453542, 0.02667179683755551, 0.03639441994684083, 0.07698589111013071, 0.02585393313451537, 0.06865610701165029, 0.06616776303521224, 0.04143097843708737, 0.03356066093380962, 0.04625329288787075, 0.02758498622902802, 0.05225624130772693, 0.04794126409771187, 0.0509917913004756, 0.01777586686824049, 0.02890120167285204, 0.019304904820663587, 0.045092757126050334, 0.03769839461892843, 0.020201066375843117, 0.03727161644824913, 0.050582485406526496, 0.013446211249434521, 0.034037172328680754, 0.062027030225311, 0.031017630427543606, 0.045153000857681036, 0.0896145881020597, 0.025348701048642397, 0.07489989125835043, 0.012943823921627231, 0.031285041078392944, 0.008460754927779948, 0.0399913374733712, 0.020289197896740267, 0.023037861833082776, 0.02700631969076182, 0.0024672892468515784, 0.029067385076944317, 0.06486973911523819, 0.10248602421155997, 0.024367742972182374, 0.07569776701607875, 0.04338835519073265, 0.03893054296661701, 0.013633812611390437, 0.07392983045428991, 0.01530330561633621, 0.044925796799361706, 0.03456371211047683, 0.05059783386864832, 0.015056490199640393, 0.014635135220097644, 0.03945749665477446, 0.09029641401554857, 0.02976328719939504, 0.0636026088946632, 0.057706349928464205, 0.01978699546972556, 0.031119804230651686, 0.020676198648288846, 0.02928350187305893, 0.017211944895929525, 0.029310568634952818, 0.0224112907225, 0.05614957007180367, 0.11950870363840035, 0.021569617225655487, 0.051174222225589414, 0.03675522755033203, 0.05276170239916869, 0.06095219682902098, 0.032693330331572464, 0.03444817456017647, 0.02823958931756871, 0.04022361358095493, 0.011228915719714547, 0.030894164195550338, 0.011633447271638682, 0.026430224800216298, 0.14198478258081845, 0.19077184397195066, 0.1195989487958806, 0.09411284779863698, 0.11691850477031299, 0.12303427660039493, 0.1318854402218546, 0.2511710822582245, 0.12298848905733653, 0.20370633634073393, 0.07459691858717374, 0.15835305569427355, 0.19204485709113733, 0.12548188811966351, 0.13521309808960982, 0.052242090459913015, 0.10874916027699198, 0.20307833861027444, 0.09388519251453024, 0.1184408523674522, 0.13248229319495813, 0.05396794088717018, 0.16482633405498096, 0.13148860580154828, 0.21004970238677093, 0.11951152634407793, 0.06898662820458412, 0.12663876318505832, 0.1455210085426058, 0.10633757896721363, 0.11425583836223398, 0.17531879246234894, 0.1148046510560172, 0.10971901752054691, 0.13792727887630463, 0.12721965701452323, 0.19049504239644321, 0.11311978753656149, 0.12389353263591017, 0.07703965143965823, 0.15137782426817076, 0.1271153933235577, 0.12204444328589098, 0.08952931660626616, 0.19418259523808956, 0.15377713766481194, 0.11882389895617962, 0.18462228109794004, 0.12222384794482163, 0.20349888104413236, 0.1952360887080431, 0.09331219004733221, 0.14334585597472532, 0.11259663025183336, 0.13073331490159035, 0.07583600495542799, 0.16835914020027432, 0.13691269260432037, 0.17285230409886154, 0.14934672468474933, 0.17343280437801564, 0.13693059235811234, 0.18468514058206761, 0.1167155278048345, 0.12689005184386457, 0.14094295991318567, 0.16801975055464677, 0.1922421750745603, 0.08937728404998779, 0.1716810440910714, 0.07424663166914668, 0.10843383826847587, 0.15608266395117554, 0.14773886810456002, 0.15611337444611958, 0.07589621136763267, 0.15228191789771828, 0.1609542875417641, 0.11589192199919905, 0.27326201115335735, 0.2728665880858898, 0.11266201388623033, 0.14392744190990925, 0.10245431627013854, 0.17109626904129982, 0.1920607348105737, 0.1121853973184313, 0.10408419131168298, 0.11993694065936975, 0.17324565084917204, 0.14132686145603657, 0.109969681927136, 0.12590340764394828, 0.0968777694340263, 0.15346156459833893, 0.18022434280386992, 0.08394051542771713, 0.17590330966881343, 0.1384411741580282, 0.2706135261271681, 0.13132370822131634, 0.12635711686951773, 0.15123762536261762, 0.1417962448405368, 0.09613379649817944, 0.12110859421747071, 0.0769785697172795, 0.12908258847892284, 0.10547354604516711, 0.14534009753593377, 0.11051052861980029, 0.11421271067644868, 0.09391757220562015, 0.15506138732390745, 0.2247516427721296, 0.14672521821090154, 0.17082328083259718, 0.20569106484098093, 0.13989346979984216, 0.07273721694946289, 0.15809973143041134, 0.1677303553691932, 0.18069728171186789, 0.12734876865787165, 0.16662185985062802, 0.16197529275502476, 0.1456951613404921, 0.08879263792186975, 0.10512595291116408, 0.11649773163454873, 0.10485000628978014, 0.12505047555480683, 0.1396690918398755, 0.07430900939341102, 0.16358867261026586, 0.1577287356236151, 0.29490578547120094, 0.07340307693396296, 0.23834560332553728, 0.1496992643390383, 0.0959211029112339, 0.0957685885950923, 0.13868983010096209, 0.07279366427766425, 0.1543716700481517, 0.06643110926129989, 0.12849067524075508, 0.12304997790072646, 0.14843235803501947, 0.09771667620433228, 0.18111672491899558, 0.12030687795153686, 0.12858135466064724, 0.15062698455793516, 0.14868566872818129, 0.14350285540734017, 0.06057896185666323, 0.1336293566439833, 0.154365386813879, 0.20738510893923895, 0.12560049604092324, 0.09049051574298314, 0.17180912436119147, 0.11652152107230254, 0.12646006420254707, 0.10996286943554878, 0.13759908505848475, 0.2155212459287473, 0.10881394680057253, 0.10055711200194699, 0.1421515257763011, 0.18053276411124639, 0.12796453918729508, 0.07029767321156603, 0.16087967583111354, 0.12410489629421916], [0.05307394725137523, 0.07567945335592542, 0.01822447351046971, 0.06579163071832486, 0.03187961417383381, 0.05976140858339412, 0.03640525275841355, 0.04485595179721713, 0.01340359416125076, 0.03342927959082382, 0.049541460017540624, 0.03680416349587696, 0.04232174903154373, 0.11275032521890742, 0.08165907034916536, 0.024251537064888647, 0.033696602032120736, 0.035830224864184856, 0.038775283976324966, 0.055609171212251694, 0.00579495750467426, 0.027295116069061414, 0.022449597416977798, 0.03576678862529142, 0.020335506215425472, 0.04268166096881032, 0.06195957027375698, 0.059465628383415084, 0.010673762964350837, 0.0672572460025549, 0.06026648969522544, 0.04369761109618204, 0.03379470801779202, 0.053173783501344066, 0.06658338609018497, 0.003680278098077646, 0.07259587810507842, 0.03005870777581419, 0.013747422274069061, 0.08596951833793096, 0.02523696668712156, 0.030035688475306545, 0.029213382064231803, 0.03161470392452819, 0.018319595638396483, 0.02730526864927794, 0.08001274083341871, 0.02964681327076895, 0.06532198270516736, 0.044504144960748296, 0.002663334340987993, 0.04123447130301169, 0.03160022059455514, 0.06209092108266694, 0.04246354927974088, 0.006419766544630485, 0.027886062394827604, 0.05703567913068192, 0.03554792715502637, 0.020132792182266712, 0.02625432816733207, 0.03560582994084273, 0.057923582914684496, 0.01958669362855809, 0.05340193072333932, 0.024007293295913508, 0.0404834789223969, 0.05035894882998296, 0.03462510935163923, 0.02996283077767917, 0.03564577190471547, 0.016397073532321622, 0.03717337136289903, 0.04563895406733666, 0.05380648687215788, 0.027767812400790196, 0.014387066209954875, 0.007330436874846262, 0.08085069765469857, 0.058038411395890374, 0.05764449467616422, 0.01278606622612902, 0.017961648060008883, 0.02861756385703172, 0.0698659485206008, 0.0432202481398625, 0.02550932894726949, 0.03616631682962179, 0.057937988213130405, 0.03055893736226218, 0.020886493613943458, 0.03709009476006031, 0.03717693706442203, 0.03474891145846673, 0.0221757627358394, 0.03352268332881587, 0.08101634840880122, 0.031956329343042204, 0.04024785424449614, 0.030851579337779964, 0.05233466299250722, 0.07326829273785863, 0.010600942586149489, 0.027664235726531063, 0.02374873074170734, 0.02685680958841528, 0.07962166717542069, 0.007531598759149867, 0.03390660862039242, 0.030416278767266443, 0.0538764099058296, 0.045811841397413185, 0.033800730016082525, 0.1263857374766043, 0.0347462685645691, 0.01542066503316164, 0.04801994362579925, 0.0337793052728687, 0.04155848873779178, 0.07564589979925326, 0.045695947616228035, 0.034502413256892135, 0.009602325635829141, 0.009503821010834404, 0.06039365394307034, 0.00871092061113034, 0.01973887885521565, 0.0048106491615596625, 0.032894549891352654, 0.0347985293317054, 0.01626849114628775, 0.027960306000230566, 0.0089494053141347, 0.015032487023355705, 0.034512062024857314, 0.028515407017299106, 0.016370798960062008, 0.02643061156517693, 0.025730214148227657, 0.0417288145981729, 0.0724268075344818, 0.05369883729144931, 0.03275906001882894, 0.034185635790761025, 0.015670503323365535, 0.0293749887496233, 0.01881629175373486, 0.04884524916165641, 0.1081180955682482, 0.015335853244843227, 0.036371298866080384, 0.01951026514039508, 0.01839523872227541, 0.01316839102323034, 0.030677881158356155, 0.02378510870039463, 0.01686414989775845, 0.04191977810114622, 0.05293240145381008, 0.030851603086505617, 0.05925231732960258, 0.04819834744557738, 0.04905975104442664, 0.021306167522977506, 0.024875441532848135, 0.04826638415189726, 0.035019606218806336, 0.027881387288549116, 0.035383928633694134, 0.04718663137672203, 0.01925901889002749, 0.06097846291959286, 0.042184762989303896, 0.03492330513628466, 0.020274743404505507, 0.03400193939783743, 0.06588525498019797, 0.024773398347731148, 0.02747240030605878, 0.06630857940763235, 0.03845262361158218, 0.036316473236573596, 0.02628161714944456, 0.10211992064224822, 0.03591177459540112, 0.005201681259287787, 0.02361861995554396, 0.059119127690792084, 0.035315199821655235, 0.12314417213201523, 0.050630766565778425, 0.02428112119170172, 0.035330578817852905, 0.005861964958187724, 0.05145979725888797, 0.055001135982040844, 0.053213046930198155, 0.027419557695143988, 0.018562061645622765, 0.012252979429571756, 0.07442316612494843, 0.08567157361124243, 0.05140465271792241, 0.020957537926733494, 0.035977785874690325, 0.03820517206830638, 0.07581864802965096, 0.07529178594372102, 0.04116250587893384, 0.035766744520515203, 0.0429527696355113, 0.0018366242376422243, 0.05089044191741517, 0.01992489074889038, 0.05508763901889324, 0.08738550557089703, 0.01675934507511556, 0.08027536102703639, 0.04594460016648684, 0.06560698098370008, 0.04779425948592169, 0.023151029599830508, 0.031552356734339676, 0.03514815467808928, 0.02330710961749511, 0.025486901668565612, 0.04336996010637709, 0.00424674669713048, 0.06067682696240289, 0.01648578859333481, 0.04596042699579682, 0.024828125589660237, 0.011435203087915267, 0.04261773279202836, 0.026230635420818414, 0.048768744338303804, 0.031006946893674985, 0.03140954886163984, 0.011745470858711218, 0.03408185385965875, 0.03467625732134495, 0.008107622403518429, 0.04846794976453696, 0.019423962271373187, 0.03194548974611929, 0.06639123175825391, 0.06562410042222057, 0.023203599100400294, 0.05142152449116111, 0.029090937027441602, 0.09066135728997843, 0.05063868506944605, 0.047421628409730535, 0.07440660308514323, 0.023601442841546874, 0.015534080465191176, 0.025382665119000843, 0.020122358010017445, 0.0075121375266462564, 0.057692412819181166, 0.10184573142656259, 0.029830852323876958, 0.052380766054349284, 0.06050812280071633, 0.080734715663961, 0.015710611528317844, 0.07597325901900019, 0.02493629933867071, 0.04825344788176673, 0.022525774847183908, 0.04250036658985274, 0.03902563625680549, 0.06026750071240323, 0.022938034064801674, 0.02979150747082063, 0.024431511693234955, 0.011865345944118286, 0.024302661285868714, 0.024670371286837117, 0.030584915075451136, 0.031498226603227, 0.057596311904489994, 0.04114370706624218, 0.04317224517996822, 0.05724622176161834, 0.03593225617493902, 0.002106574729883245, 0.026093707054055164, 0.054059909523597786, 0.08727914520672389, 0.049348583045814715, 0.06595268100500107, 0.053689120669982264, 0.04429087461903691, 0.053518733741449456, 0.01353812390672309, 0.021022409267191376, 0.053746344920779975, 0.006931747085348303, 0.02712356375663408, 0.08656514994800091, 0.01268826303670981, 0.013561994768679142, 0.032539034861006906, 0.028347281306715946, 0.0757955371269158, 0.03781394573992916, 0.02949096734768578, 0.03681913537106343, 0.04126319369035108, 0.07462332717009953, 0.015120223297604492, 0.023402353881725242, 0.033328344114124775, 0.05604023772424885, 0.03652267324339066, 0.057117211898522716, 0.040798529516905546, 0.028281225922650526, 0.048409578789557726, 0.030163022356906107, 0.06659929095102207, 0.044942163064011505, 0.01604680697034512, 0.02682020771317184, 0.04829652467742562, 0.07391702649848801, 0.024660186476207206, 0.02525428120445992, 0.008102241620820547, 0.02074977898571108, 0.016629191880513514, 0.020163494195523005, 0.040117297321558, 0.037974860319601636, 0.02791707483785493, 0.09245988221040793, 0.09712563827633858, 0.014275404790948545, 0.014028404473460146, 0.005124619189051113, 0.013065449627382415, 0.03699595481157303, 0.058143136490668566, 0.08716180614594903, 0.033664663388792954, 0.07714324338095528, 0.061957093620938916, 0.04906822594680956, 0.0499884313903749, 0.012037181544915905, 0.052054489097957096, 0.17957218922674656, 0.1744465764079775, 0.09577341976442508, 0.12310082731502396, 0.1605444795319012, 0.10422407809112753, 0.09814128984830209, 0.2763678559235164, 0.07324737350323371, 0.11100960469671659, 0.18376032449305058, 0.09227397040064846, 0.2300305095102106, 0.19146405825657503, 0.12233353991593633, 0.08575476200452872, 0.10185352779392685, 0.1781493012926408, 0.14214100848351205, 0.10831101664475032, 0.16973644415182726, 0.08316714156951223, 0.1714102407651288, 0.09418712702712842, 0.0874512352581535, 0.1316427553870848, 0.152393211211477, 0.1284607925585338, 0.10928033784564052, 0.11817402525671891, 0.16867058777383395, 0.16803511258746895, 0.13132214759077343, 0.12369002641311713, 0.1320325873259987, 0.08525105831878525, 0.2287003637424537, 0.09494418211813484, 0.11455950992447989, 0.13382476115865366, 0.09476006842617478, 0.12994672996657236, 0.23419511318206787, 0.13674681793366159, 0.1875434693481241, 0.10153543736253466, 0.12728508136102132, 0.08154203662914888, 0.13470573031476565, 0.15286544444305555, 0.19071004300245217, 0.12588690567229474, 0.12572896986135415, 0.10217998456209898, 0.13319696698869976, 0.07155611139855214, 0.1494463471961873, 0.14901196264794894, 0.13992255181074142, 0.10824185357029949, 0.08435023522802762, 0.15779407854591096, 0.17642895717705998, 0.09289400212998901, 0.09781165753624269, 0.05835089034267834, 0.12723100212003502, 0.11746126493172986, 0.1272687150963715, 0.16699746969555104, 0.20372510461934976, 0.07862453282411609, 0.13861272138144287, 0.11064807445343051, 0.19258316606283188, 0.21814305095800332, 0.14275515052889073, 0.10905069445392915, 0.16348428678299698, 0.10542456938752107, 0.18555028630154474, 0.11964903825095721, 0.11804346154843058, 0.1367669432823147, 0.1829095094331673, 0.0977984464594296, 0.23228481997336659, 0.1962089722177812, 0.27377172665936605, 0.12550733318286283, 0.21278552844056062, 0.057356951891311576, 0.11650400129812104, 0.06918846523123127, 0.13281392039997236, 0.11230220033654145, 0.12679040219102586, 0.14054464628653868, 0.08930957304047686, 0.13549857134265558, 0.14402988712702477, 0.15263937014554227, 0.23131543770432472, 0.06998946903539555, 0.11616326815315656, 0.10422325706375496, 0.11372232663312129, 0.1217668138976608, 0.13681454929922307, 0.1614383137119668, 0.14972161528255257, 0.19893125471259865, 0.08188165019133262, 0.1874260963605983, 0.13084823159234865, 0.1713141466357878, 0.12301831745675632, 0.14047592425984995, 0.13045723257320269, 0.15341291363750184, 0.1260413131011384, 0.1459282109779971, 0.07319507880934648, 0.15476060632084096, 0.1553017379982131, 0.10407013885144677, 0.1035990659147501, 0.08956766740552016, 0.07326973801744835, 0.18901275550680502, 0.10584459613476481, 0.14178405835160188, 0.08125912823847362, 0.13068978009479387, 0.12795050708310945, 0.043881405876683335, 0.10887268079178673, 0.0629234089116965, 0.12546987804983342, 0.16973995896322386, 0.17048254768763269, 0.11656038755817072, 0.14424686905528816, 0.15653384902647563, 0.06226751660662038, 0.10084002717797245, 0.0957234049482005, 0.09111596896712269, 0.12495026950325284, 0.12599564769438334, 0.09470597561448812, 0.11565727101905005, 0.08346493701849665, 0.08952667710504361, 0.1519965124981744, 0.09893324878066778, 0.08443987648934126, 0.1733234381037099, 0.2566932716539928, 0.09872872475534678, 0.20636187813111714, 0.21322055081171648, 0.14608359549726757, 0.09334861380713326, 0.052952845713921955, 0.0917738222384027, 0.15933310453380856, 0.13077462411352567, 0.12672030952359947, 0.08194594816969973, 0.14496603475085326, 0.11101098212280444, 0.07741617730685643, 0.19840245880186558, 0.06927772651293448, 0.08329348478998456], [0.03679799561255744, 0.01948891164335821, 0.01332453210904662, 0.015260695313502635, 0.012129307940735348, 0.08197603441242661, 0.03373346005433372, 0.026921568970595087, 0.018534815071948936, 0.015498586298365678, 0.034479495736637285, 0.0635080278984138, 0.011506322039557355, 0.028097699163481593, 0.030102985578456094, 0.02953300259209105, 0.025374763578708683, 0.013581233780964144, 0.02508589086521949, 0.021426685520314744, 0.011201439292303153, 0.02983512370181935, 0.0376921826308327, 0.04095336442281093, 0.014779091513316547, 0.01940969267993101, 0.09707029696021761, 0.05221254704520106, 0.018437548773363233, 0.010290075160030807, 0.06760582979768515, 0.023564343939402273, 0.05074642285970705, 0.038610467820295265, 0.042926646037293334, 0.07892302716416971, 0.016019585841734494, 0.019586634256743958, 0.010692068990985197, 0.009364213278916265, 0.028274364237274443, 0.03231419210455247, 0.010781982514475073, 0.03659157847453441, 0.04474063477079783, 0.02192415346923683, 0.06711132704679455, 0.029853953048586845, 0.032339107910437245, 0.0244283514163856, 0.029376240646732703, 0.016557482603405203, 0.05688863041411553, 0.06163435522466898, 0.04826292023062706, 0.03406635272715773, 0.05957036026354347, 0.023797466519421766, 0.043124625592359474, 0.06287244414644581, 0.014792645250314047, 0.02028576111687081, 0.022854173921846917, 0.01658893270151956, 0.07187614922544786, 0.06042899883219174, 0.0511443056166172, 0.0342467446545405, 0.01548834890127182, 0.04009406428251948, 0.06054233453635659, 0.06354692152568273, 0.04322880107377257, 0.03519328064950449, 0.024260234187490175, 0.05005125694775155, 0.06538208055176906, 0.039149095703448565, 0.052478573484612365, 0.08908186347356864, 0.025168621247368198, 0.04642656019755772, 0.02838719612918794, 0.07037321451519217, 0.030883738504988805, 0.029072484267609458, 0.038088358872170956, 0.07024888654372521, 0.025457648327574134, 0.026560980194647397, 0.042168464578155956, 0.008823179989121854, 0.05934015368776662, 0.015335463087207504, 0.03556296009836452, 0.08199519624135324, 0.013927306996525397, 0.008719799241849353, 0.04102093293996794, 0.036371841694095304, 0.036694814184946675, 0.02332035801373422, 0.07683867615248476, 0.02659253546568964, 0.018286474647798708, 0.03158481784963182, 0.014534552581608295, 0.057752727796988826, 0.048760625666805675, 0.05342314851337245, 0.023452996342842067, 0.01664055055672569, 0.035490916642759524, 0.02395140745544008, 0.03153726611552494, 0.012202960372503315, 0.024622188515162895, 0.03563606206859861, 0.008643947508452194, 0.011331321921066513, 0.013139190268702805, 0.02062085733216788, 0.06130366439798048, 0.08767215947487525, 0.03577383181878498, 0.07871743783886943, 0.03422431907217417, 0.10045258368232421, 0.04395506424563272, 0.06786297421370234, 0.03473905912999596, 0.04180461374510612, 0.11319994287831442, 0.05596068288598742, 0.008229835042064744, 0.03458245664036699, 0.039846592383193116, 0.02594545224149312, 0.023943432972633412, 0.04259577879149999, 0.023582214855455925, 0.0486407794191369, 0.04786911207650389, 0.015873529482632875, 0.017233946393909197, 0.03540762646922043, 0.013601030040133213, 0.017336255904021006, 0.030554136727005243, 0.0160793240647763, 0.027221393239285265, 0.031848011405340264, 0.042667452445519824, 0.060068221762776375, 0.04762604047677346, 0.04805254384077021, 0.03347215282597712, 0.023078097263351083, 0.029883326829544136, 0.0707411840558052, 0.05423885277871575, 0.08033622561820916, 0.04018387857026287, 0.04008563009223767, 0.040659192350826094, 0.025892848814172403, 0.019499537501750246, 0.013033938461116381, 0.03290788310446909, 0.05530038349596517, 0.03004072659782001, 0.009495851617040378, 0.022318412849147404, 0.017511803091370633, 0.05399189317332847, 0.017542360915935466, 0.05163075076416135, 0.014715941955468484, 0.014503387468201774, 0.022932863627959574, 0.0391892412278269, 0.04016331895919783, 0.040871258292879374, 0.008864649504955326, 0.024936957517638803, 0.013437634566798806, 0.022645079963175312, 0.047092525354985676, 0.04040539989780102, 0.007753027636291725, 0.014863536892724889, 0.04690422510196056, 0.035338660169925006, 0.02093590623033898, 0.03921391615378005, 0.01664582277382059, 0.027371056012011, 0.028490596384342228, 0.028098686431933726, 0.07476876436599664, 0.02142854979527848, 0.013957986957393587, 0.05443412158638239, 0.046785233808415275, 0.01631845167971083, 0.02124363203932132, 0.06532831343689136, 0.022591275528871586, 0.029608866199851036, 0.0024193392975056277, 0.0405068239197135, 0.05708524611379419, 0.024051764481035725, 0.04560924441154514, 0.02515964931808412, 0.03748080200914826, 0.05994377165500607, 0.04828340859551515, 0.018003924184345772, 0.029146590469671146, 0.06201174283134086, 0.020746703525739055, 0.02430840508480157, 0.048520329275301526, 0.0286535703177963, 0.04882345122418233, 0.030844797380268574, 0.004338583443313837, 0.032958566277687035, 0.0793318445129054, 0.06557074721370425, 0.06929751937942845, 0.05060090423960771, 0.020006922239969884, 0.03514998672263963, 0.030161434584962468, 0.01828140259853431, 0.010995526814700236, 0.022287980553561022, 0.02327048229718847, 0.08287970735026257, 0.05871958591576133, 0.057127837756914754, 0.01846544334797987, 0.014310181406991822, 0.02265815363664712, 0.06457318538533789, 0.06587855105421372, 0.05269178954352226, 0.05906472275299685, 0.04927314691511648, 0.093205062938588, 0.05739442738039153, 0.027672848032255257, 0.02216108263071094, 0.06507695013923304, 0.14485833767269338, 0.04500244411506823, 0.020749992724241953, 0.007871245399915745, 0.04572492106152432, 0.008142211574262806, 0.035930512339941094, 0.09338564146310091, 0.03558052397732224, 0.07562707045248576, 0.010590045313749994, 0.03252198327598827, 0.019919119808556776, 0.04896917679746236, 0.030740520118602684, 0.030089954313422953, 0.009623802965506911, 0.02365139658961977, 0.03749550925567746, 0.029757363588682244, 0.02201752328047795, 0.07750163200710501, 0.07071769995880978, 0.01962163478934339, 0.02576186441417251, 0.016899454074778726, 0.05426023341715336, 0.04862001285489116, 0.06702467812491314, 0.05657098442316055, 0.016907813626208475, 0.0263697554556919, 0.02604514599910804, 0.028186539753473232, 0.026655364415741394, 0.01663460658996233, 0.0290533868995096, 0.060380470007658005, 0.014801622268610766, 0.021121977495827844, 0.014688430753137385, 0.042295208134289296, 0.06748457558985267, 0.056904413138649294, 0.025326596074072377, 0.09967857878655195, 0.020128010206722786, 0.017288743185677698, 0.04003012253503714, 0.015084471287471908, 0.09911618182169539, 0.02258346219813185, 0.0414223237229245, 0.03719585801341704, 0.037257703087691746, 0.06277288948850972, 0.02516207847345088, 0.010903728660196066, 0.062076088307159286, 0.016495294868946075, 0.014659272407048514, 0.042238167087946615, 0.025282428533371006, 0.01745717932603189, 0.08253440766462258, 0.015839226144765104, 0.03510418560888086, 0.015292676365269082, 0.04278337676078081, 0.04520943122250693, 0.026669588206069808, 0.024265962719385113, 0.04249783226155809, 0.04018621951607721, 0.05576273047232202, 0.01871950042966221, 0.05471249736313309, 0.013409547457870628, 0.015029940820698227, 0.028357574682948843, 0.07823827676475048, 0.11843232996761799, 0.032977463477956395, 0.028471746681524173, 0.039208833926490376, 0.019571857460375344, 0.040562178806534836, 0.03255478026611464, 0.043395215179771185, 0.055059208401611874, 0.039078270218202045, 0.029691074110035385, 0.011946333339437842, 0.03729651189808335, 0.09206409273403031, 0.014746158816186445, 0.11722631539617266, 0.10116875703845706, 0.09425353524940354, 0.12032329849898815, 0.1449634020349809, 0.12266475999993937, 0.10253638508064405, 0.10382039046713284, 0.13428577142102377, 0.06067609414458275, 0.09906187866415296, 0.19783333076962403, 0.13310966667320046, 0.13361206757170813, 0.15954536385834217, 0.14266027776258333, 0.13855333599661077, 0.06625872743981225, 0.08666523386325155, 0.09409490054739372, 0.0798897970733898, 0.12334735265799932, 0.13296980703515665, 0.14154205205185072, 0.14042776184422628, 0.17473964925323213, 0.22326611248510225, 0.16194090460027966, 0.1048849644139409, 0.20407627363290104, 0.2014856812145029, 0.0647267582161086, 0.16121598492775643, 0.08768448845616408, 0.16490805681262696, 0.16995703588638986, 0.11612965352833271, 0.09432001132518053, 0.059142007891620905, 0.1250584279852254, 0.09066156085048403, 0.14853939014886106, 0.07373234283711229, 0.1673070038003581, 0.1565711141696998, 0.06974801234900951, 0.11430085237537112, 0.11668989275182996, 0.11513124353119306, 0.1279327023242201, 0.11677337970052447, 0.11624857357570104, 0.12426287281726088, 0.19690632979784692, 0.1556475330144167, 0.22314189986458846, 0.10369679531348602, 0.06741940230131149, 0.09661600419453212, 0.13125867742512906, 0.10679905741874661, 0.10689694288053683, 0.15089287529034273, 0.1371895620333297, 0.18228366944406713, 0.09842186407851321, 0.1263909621962479, 0.15296058862337045, 0.1174460386059114, 0.1566795576363802, 0.08364523734365191, 0.14655763363199575, 0.09951435295598847, 0.14957639521786145, 0.17686654441058636, 0.27741119850959095, 0.24261695412652834, 0.1455325029258217, 0.19341281083013329, 0.15764371518577847, 0.1705940988446985, 0.08314644625144345, 0.10363906555409942, 0.13875336812010833, 0.11543853847043854, 0.13579021926437104, 0.15552490816584655, 0.1952126792498997, 0.17393211115683826, 0.17409578737403664, 0.08812690007367305, 0.09956727868744306, 0.1135875288663166, 0.10222150411989007, 0.16185897828212806, 0.15286305599978992, 0.16237727047077247, 0.14376202864306314, 0.1033051245446716, 0.10424028150737286, 0.24216333989586147, 0.16532802927706922, 0.16884784826210567, 0.10943014480705772, 0.08995256639484848, 0.09986793076885597, 0.14751746212797506, 0.23550965264439583, 0.13657200017145701, 0.18013332411646843, 0.08647226528929812, 0.13190726190805435, 0.09561999621135847, 0.109476291973676, 0.10809117808405842, 0.1003915833841477, 0.12393968658787863, 0.10460818997983422, 0.10735247057995626, 0.1208670221801315, 0.07439788391015359, 0.17200056623135293, 0.12858018758041517, 0.22269189544022083, 0.057899752764829567, 0.2728138252028397, 0.09596315851168973, 0.12499403501195566, 0.16029304159539087, 0.12920198350080422, 0.15374315663107804, 0.19101584516465664, 0.20533836233828748, 0.23624445178679057, 0.1227470255856003, 0.11966373531946115, 0.07098243718168565, 0.10747984517365694, 0.16308338115257875, 0.08834198210388422, 0.07964147361261503, 0.16676276443260057, 0.15159556615565503, 0.09902806047882352, 0.1468115821480751, 0.0871127141373498, 0.11289241723716259, 0.07456202831651483, 0.10869366289781672, 0.14562120102345943, 0.14388326928019524, 0.1874227715390069, 0.1858581376395055, 0.09682960701840264, 0.17631656463657105, 0.11815812039588179, 0.14966962592942373, 0.12686219119599887, 0.13360161813242094, 0.10435956117830106, 0.12247662938066892, 0.22015914134681225, 0.1267058024449008, 0.12168525398841926, 0.08898260737104075, 0.14963131584227085, 0.10253977097038712, 0.07702829276344605, 0.07872886436858348, 0.12424732079463345, 0.09025448733674628, 0.09090531777058329, 0.07912702193217618, 0.2028758909021105, 0.2026390414685011, 0.14207976391272886], [0.023870543044592653, 0.01923990116587707, 0.03874548950365611, 0.006824922772856163, 0.03311347921511956, 0.03269016496571047, 0.03233863293592419, 0.02874131507373282, 0.01203440294401454, 0.002475568646332249, 0.036409690377435515, 0.006448125067566122, 0.026789761846885085, 0.014373902630593096, 0.01694967584418399, 0.015036587071205889, 0.00930947925163699, 0.020609966845118573, 0.003152682346158794, 0.054605285437511544, 0.03791519334273679, 0.021146995081965412, 0.044974115278039656, 0.0256610866968653, 0.008004086441360414, 0.015880669367366602, 0.045642234784151824, 0.06277900987437793, 0.04770340703959976, 0.014240027671413762, 0.025750347978568504, 0.05621211742982268, 0.024170579355476157, 0.003749138376276408, 0.022347194608300924, 0.0794111109737839, 0.03706320780994637, 0.026504548133483956, 0.0532543425714331, 0.018665556895679662, 0.03159593225323728, 0.0034460526866106583, 0.01243317882264299, 0.02918959262647799, 0.03171782089131219, 0.030749028947736536, 0.006884032926921333, 0.02898261569706457, 0.020108631246590188, 0.02972939098253846, 0.04883661141086902, 0.05853237810411623, 0.033930486267698665, 0.0036019615862252457, 0.028980295107300793, 0.0408724525145122, 0.03362104037244405, 0.0429818346830351, 0.041800355937864096, 0.017297655743147646, 0.04677126955773149, 0.08109259538884674, 0.06580032275191375, 0.007017963865239705, 0.032249917874911, 0.01992259730052735, 0.03769514104351401, 0.04017700161784887, 0.023387563514656255, 0.06715497041919402, 0.0592468347666519, 0.06769401220870869, 0.015941635738792162, 0.04400787123345903, 0.05066965680037226, 0.024184029615883316, 0.05403783677944115, 0.021391975061435784, 0.07853147174630846, 0.030296707326280217, 0.05721618301634278, 0.07215337149266686, 0.030989416941468204, 0.06622587955955948, 0.07305741083941289, 0.047122492854084284, 0.017141456981854777, 0.06301271769085101, 0.03239953484652298, 0.04170227370091847, 0.017294692241453698, 0.007433292605648083, 0.05996161712599652, 0.06861472994621311, 0.033733195425676446, 0.08387489430606365, 0.041748780491096635, 0.0594714434285249, 0.029345194276954447, 0.03525793146608131, 0.027290054197822298, 0.0172152951625841, 0.057679018537913046, 0.07714525862996068, 0.05172389665884631, 0.031810125402574024, 0.03453313732253654, 0.009822764700012547, 0.06304977927356958, 0.06707208058131592, 0.030011108544256006, 0.019483630944575583, 0.024779834252383028, 0.062029696867934296, 0.05113486380183271, 0.02843125001527369, 0.08122525577034269, 0.002765751992618399, 0.021492106474137733, 0.03412057106782283, 0.03631596094263451, 0.026180871662550738, 0.030061482984040464, 0.013200304221494921, 0.03928562034187572, 0.023555149789899588, 0.04664720282224672, 0.016001558862626553, 0.06608305472348418, 0.02141510632022151, 0.0816407295476113, 0.040254490316978524, 0.036069042049348354, 0.042830847070685456, 0.055773671849497726, 0.0602018999468003, 0.07316202736858811, 0.03749062380354319, 0.0665038957127503, 0.0334679967989879, 0.023615705647638867, 0.03409482744921531, 0.035318941942283084, 0.05399481765925884, 0.047874767665884325, 0.04487935107733522, 0.06585793716034719, 0.031390984143529616, 0.04568724540461387, 0.032530068020735464, 0.016627682140097022, 0.006893780930632991, 0.029868490661361387, 0.046200587680297237, 0.03707808469023023, 0.04768938511343939, 0.024168888106942177, 0.06697207809026752, 0.046270551426070075, 0.003698389894062919, 0.014878634296889817, 0.02170215038183544, 0.03776301829410451, 0.016759482478456836, 0.012260372916768705, 0.06241685537887471, 0.0482103880494833, 0.041608469627265415, 0.03258184702800853, 0.036738868071032424, 0.030114798873130764, 0.03844431834295392, 0.025874638630609428, 0.03609677377556052, 0.04174330471349614, 0.04024529277480074, 0.0421798877151949, 0.046711002077375136, 0.03179203226630177, 0.08084381730960948, 0.021862683285559927, 0.07366754952818155, 0.05950846429914236, 0.05552021187863179, 0.05585429198773844, 0.007368589202607316, 0.06425063697887318, 0.040573846216180494, 0.02073386055417359, 0.037647850545389314, 0.02119121860180582, 0.052601106730954986, 0.05633662182039448, 0.04835899400391749, 0.0170318277752293, 0.011979417858778365, 0.0399933968271528, 0.09810198910002198, 0.03803192511466997, 0.048317725504083295, 0.07916500632252012, 0.010967116553469427, 0.008238971516090845, 0.04005290434828826, 0.020796816729541336, 0.04173561351905976, 0.05601708271673747, 0.053143849928996394, 0.04766545318333166, 0.09367498236575297, 0.040320023229079585, 0.03648164901616318, 0.03318916301109961, 0.019143328669347932, 0.046713604259171655, 0.02151549218355545, 0.05173206961314593, 0.013999389467893966, 0.06228960292147739, 0.04370035916300757, 0.016445522628990666, 0.05427810263686946, 0.025531903807339922, 0.03768914279394916, 0.05882454849779606, 0.04763702256605029, 0.08079009769218308, 0.02494211947279317, 0.046761607219065936, 0.036491535271384885, 0.03411106139953647, 0.04157397969226752, 0.044195632051144323, 0.10176540645105497, 0.05451843974047473, 0.0045062600485315275, 0.0012067869351345248, 0.04873302286224706, 0.04833392213497843, 0.02039036407534565, 0.019519445719197392, 0.024320345604792237, 0.016459659906104207, 0.036361103877425194, 0.013267953314685395, 0.015807954162093144, 0.013256252826457577, 0.03197366591276867, 0.016944766643324068, 0.022245093747707348, 0.04079698584973812, 0.05484228754150016, 0.059368048262383254, 0.0341437803581357, 0.05673434851425035, 0.045230058687073846, 0.04155975081292646, 0.05674765119329095, 0.012595883038427149, 0.031095885871244327, 0.05053982251722898, 0.033758379252893586, 0.02936242228107793, 0.0726753074143614, 0.010136621072888374, 0.05378107912838459, 0.03474524397669094, 0.003979897958093456, 0.044500175530889204, 0.0692310229476009, 0.02659567877916353, 0.005563402340547847, 0.013554604674157287, 0.04858596396765538, 0.03927098773419857, 0.01580000851702477, 0.027982828273837055, 0.01747777795286051, 0.05705811149839844, 0.06638623774051666, 0.011495516369385379, 0.022209613151582222, 0.07035918241100651, 0.04963926066245351, 0.04779873103169458, 0.04248681963820543, 0.04544282012752124, 0.012281047878786922, 0.008615817142916577, 0.05756146234593221, 0.08936097206813948, 0.009947423457301088, 0.12001487719161169, 0.003530088612543685, 0.04939462164683001, 0.015687112164284502, 0.043067401341561756, 0.03412119532003999, 0.1260007909898247, 0.04557289189792105, 0.04088003853602069, 0.012521425694493311, 0.04654902559039848, 0.09446806088089943, 0.05141463057537164, 0.05650106478216393, 0.02521652581968478, 0.009142746234179606, 0.017317541908206682, 0.04285123704799584, 0.012385828104535384, 0.019694185449874828, 0.04343464484970484, 0.0031714207268253502, 0.03600311219426138, 0.05261622788384557, 0.007544951480148094, 0.053701412331845076, 0.04102583196280258, 0.08238030557653733, 0.02160301641561091, 0.060782461294106076, 0.07068431603589229, 0.05475998802908829, 0.040115682408213615, 0.03034319376040782, 0.0669450316844242, 0.021527668494465094, 0.05482602984245334, 0.021089516380535703, 0.021209114962922673, 0.03446869006646531, 0.022382904209994843, 0.07347787184906857, 0.04506723063864878, 0.051523772933121235, 0.023862719535827637, 0.057269787282816, 0.09099406336567231, 0.04382680755640779, 0.04293151113337704, 0.00931507971004716, 0.031299320847860405, 0.04616138871226992, 0.04990105304334845, 0.014491075450288398, 0.08397203337933336, 0.02420798020570406, 0.009887881161245917, 0.039260799530893564, 0.017943356452243667, 0.022942086615200554, 0.09404669741966895, 0.10837768271033253, 0.12888463267258235, 0.19263283482619695, 0.09281304611691407, 0.13372925056942872, 0.14692048701856816, 0.10953539915915046, 0.14745017859552587, 0.10491954934384141, 0.12662880229098455, 0.15496327116021089, 0.07577757630497217, 0.1880110071173736, 0.11146604841841118, 0.12110243311950139, 0.14024150398160729, 0.09734495436506611, 0.16255459881254605, 0.08429151480751378, 0.10410798074943678, 0.1634243314287492, 0.11814529608402934, 0.09545192308723927, 0.18627792011414254, 0.05948840680399111, 0.17415026016533375, 0.130749857585345, 0.1196409094014338, 0.08906055747398309, 0.18757491266088827, 0.13852384686470032, 0.11224411095359496, 0.14449707205806459, 0.12066769573305335, 0.08313563718859639, 0.1897706248398338, 0.10368557912962777, 0.13995064316051348, 0.12784268786864622, 0.1844985977347408, 0.08014581512127604, 0.1265584924923522, 0.12658950154270443, 0.1539059914648533, 0.15927272848784924, 0.11838770950479166, 0.12037356437316962, 0.1667050211025136, 0.2101351706577199, 0.08666773765747036, 0.13640544696577958, 0.1483126508870295, 0.06372424308210611, 0.12556621645178112, 0.15707970330757753, 0.1524391480322395, 0.27689241777573315, 0.1285170702529805, 0.11280193459242582, 0.11714174279144832, 0.31728677451610565, 0.17402699749384606, 0.1592860413449151, 0.11077844138656344, 0.11399564732398305, 0.08158132380672864, 0.1401440120701279, 0.12912471193288053, 0.1529694910028151, 0.11366256805402891, 0.11532548096563135, 0.13625897839665413, 0.1571037641593388, 0.14113284115280422, 0.0832739904788988, 0.12499038449355535, 0.10616497322916985, 0.13054671777146204, 0.1404846773615905, 0.10695180922214474, 0.1273503021470138, 0.13362376551542962, 0.12069111876189709, 0.1893070497150932, 0.14815550217671053, 0.13023275961833342, 0.18977534744356359, 0.12676309794187546, 0.1669092872845275, 0.18792488745280675, 0.0963899977505207, 0.14720369396465166, 0.1833447353648288, 0.10261671005615167, 0.14720084411757334, 0.1372327847140176, 0.14908274742109434, 0.15604520881814615, 0.11042831053159066, 0.07132854432399784, 0.17027874290943146, 0.15545216921184743, 0.19259898949946674, 0.12176583680723395, 0.13905341630535467, 0.15296992526522704, 0.1943001039326191, 0.18280367154095853, 0.16647258214652538, 0.11200573481619358, 0.08753735492272036, 0.06952080489801508, 0.15139656540538582, 0.15837543377918856, 0.12442288494535855, 0.2074674288077014, 0.11727189937872545, 0.1691634077578783, 0.10796856680618865, 0.12861475215426513, 0.11096172726580075, 0.18147197871335916, 0.1103869741782546, 0.09063306916505098, 0.11090903902160269, 0.16068584551768644, 0.20135416755718843, 0.20035266344036373, 0.13657761844141142, 0.21651230060628482, 0.06751022421355758, 0.0576517346448132, 0.15505761466920376, 0.08254499959626369, 0.1268439928867987, 0.18831588647195271, 0.08647201423134122, 0.16212003784520285, 0.09238601010292768, 0.12036496054913316, 0.13481059111654758, 0.1424628919256585, 0.11401814754520144, 0.07223247510514089, 0.23544546323163168, 0.14015505862023148, 0.09101507080984966, 0.1480220886213439, 0.14381590432354383, 0.1101415887741106, 0.07259613594838552, 0.15699471001114162, 0.15129041538706847, 0.10049990471452475, 0.10787409437554223, 0.13471593548144611, 0.15311445322419914, 0.18507413113755838, 0.1348939694996391, 0.0639504666573235, 0.1622949777437108, 0.12530378624796867, 0.119907695800066, 0.12817005387374333, 0.11470927617379598, 0.11299384465175015, 0.11631519214383193, 0.15963146995220864, 0.17273220340056078, 0.21348887069949082, 0.1381760569555419, 0.09847679827362299, 0.09241756198129483, 0.12854460520403727, 0.15061277603464468], [0.0374976975311126, 0.03150026899363313, 0.0016407920338679105, 0.04153213783034256, 0.04511935569878135, 0.03554327919014862, 0.152235478961042, 0.06359338081840958, 0.02650813588739506, 0.00933637807611376, 0.009025089110114744, 0.03858270895268236, 0.07604717862393175, 0.02022968019757952, 0.028110662575012872, 0.03735188374828015, 0.06828521977045707, 0.017868810898757408, 0.026951119170657227, 0.11649888514408044, 0.029150563292205334, 0.018808824475854635, 0.04961389023810625, 0.03128931924168553, 0.029666558639811616, 0.08154578214245183, 0.027777121901246052, 0.07547083776444197, 0.04467951912166817, 0.016915861051529646, 0.01891587524940925, 0.06321758776903152, 0.024192915031952516, 0.037651012518576214, 0.01972838191847716, 0.012420348573609121, 0.037126582980688126, 0.02185003369647477, 0.02519312993224178, 0.06924301266138043, 0.02485747222921678, 0.032575869134494236, 0.040473277148391516, 0.029896425948079144, 0.047816712209688764, 0.005482662610510098, 0.03162185229094965, 0.04516713474211948, 0.04278191112514053, 0.039263869901852946, 0.038101284964276214, 0.07278438870395933, 0.04001385805064014, 0.06546342332980462, 0.015041577696268047, 0.02670790677491043, 0.08377529893602643, 0.02323674044704863, 0.005208966604966138, 0.015438820933923125, 0.01187235945170479, 0.048147857654839754, 0.06864100960748536, 0.03120908247573035, 0.01816429932867842, 0.04303521503295217, 0.021188024398205534, 0.041662966167288165, 0.03072436759248376, 0.028328141530177424, 0.009627416164481213, 0.08134418938841138, 0.03483381654535021, 0.030068641528487206, 0.04528599711401122, 0.04252219506140266, 0.05508439901417919, 0.030458032419638972, 0.041354568608637364, 0.054745426667588096, 0.04432113388819354, 0.047575740675841055, 0.018061701441183686, 0.030601488293281624, 0.059571330568620136, 0.09081786817737988, 0.037336945799844604, 0.012540674884803593, 0.05984976062817233, 0.0306255966424942, 0.043010512965598276, 0.0028482175340676413, 0.008842770143279007, 0.004185458021571061, 0.04150536623118179, 0.028971793063517128, 0.05599124071055225, 0.044124453727688105, 0.13601558788546494, 0.014286882210788983, 0.09206019794302327, 0.0668216265205826, 0.01818642974831164, 0.020084144614104713, 0.06310963963291474, 0.06101331247815064, 0.03653836436569691, 0.049554626989577494, 0.05333541054278612, 0.050454130329723866, 0.04161454251568232, 0.04073022139657821, 0.04531700616436345, 0.04520442024139421, 0.07385539516274418, 0.03970564369644437, 0.05618085732151355, 0.02518180857545563, 0.02704895374232105, 0.014472271548584104, 0.03665867880252855, 0.045561984447496276, 0.028888933759714876, 0.03714716973315392, 0.053710189182311296, 0.04143988760188222, 0.05949692241847515, 0.02884208770202739, 0.0411151814540582, 0.029866092040070465, 0.09203286655247211, 0.052223495207726955, 0.005783631058875471, 0.024347218984205807, 0.02930975439293044, 0.013230385375209153, 0.14417901555342333, 0.01764647532919688, 0.05240627218570028, 0.03981743573344179, 0.04593893439908113, 0.058676600722329955, 0.029328600703073398, 0.05679693997704557, 0.018616595505071536, 0.025823416022051657, 0.024857847119814584, 0.024510766279750636, 0.04839069176731365, 0.034863811185849566, 0.0599954624527267, 0.034133907673614364, 0.015098238763000284, 0.02992688199239118, 0.058514926183436594, 0.03127829983298268, 0.01730535372293421, 0.02311667537183634, 0.06905765046498605, 0.02107046650988715, 0.012546687553237592, 0.05829188493745668, 0.044662219871367724, 0.0279186456464231, 0.026797302067279816, 0.05146569712087512, 0.054707784937428575, 0.07534878288528749, 0.04333994850250227, 0.052602304345262904, 0.021343247765409093, 0.05200483051261731, 0.024531039209770303, 0.02395003172568977, 0.01859767794875162, 0.026387704403272698, 0.04362583226923432, 0.05916508486760514, 0.009761690611152776, 0.016079948316993456, 0.040344196039118936, 0.05068757351753967, 0.045859959708260636, 0.0818136745531644, 0.06222497924630131, 0.004051695020669805, 0.04663286876997777, 0.025324764029522027, 0.02340648615998881, 0.0407605994093631, 0.036272035978202305, 0.05081948751051511, 0.032173392695507834, 0.011791042118732418, 0.03597489531551089, 0.059509692447526116, 0.00957710194467966, 0.029300278651395013, 0.051767794481877766, 0.040185781860990186, 0.05694654677063227, 0.04910117560731513, 0.06227524512048278, 0.09008330652224165, 0.031232223912541355, 0.025897423836535642, 0.014136337342539003, 0.02107753514844392, 0.07591324938195092, 0.030544070660003593, 0.022147245605343154, 0.029805495470230068, 0.026037202050377215, 0.01334920703499977, 0.038744400454951186, 0.021374507873718227, 0.06079314822064979, 0.00848277423730386, 0.05693456384220293, 0.023665812066090957, 0.010184134639400457, 0.03054926484557135, 0.06592628599277564, 0.0026777898934337175, 0.02944252673270447, 0.029212001245468855, 0.02707857688489769, 0.04992774661098208, 0.032322660221585205, 0.0324428491294384, 0.007076007022988051, 0.022151973298085586, 0.07299957929977349, 0.0091821716632694, 0.033168786604489596, 0.04792801230879767, 0.04702651746837156, 0.040564981156161854, 0.02686794604440885, 0.055793593637645245, 0.015984001769019023, 0.017577296987708126, 0.04626415284084422, 0.031541618917669566, 0.10948248021304607, 0.04565902852586337, 0.0459320710173675, 0.060526144690811634, 0.08907492884567805, 0.038142275264752765, 0.06015561707317829, 0.0813583911263517, 0.051574320399335453, 0.0365510699339211, 0.028186039333896976, 0.020918198162689805, 0.027154106314160993, 0.006699294982744115, 0.010761280411056109, 0.07054646486150366, 0.10100795780973774, 0.04457453618358288, 0.042271730822644064, 0.050144986382552555, 0.06777018454990216, 0.09994071043495621, 0.0637014578761799, 0.047262671403586864, 0.042623412130134444, 0.0319391624070704, 0.0028033958431998534, 0.09472008914287601, 0.06325692922941276, 0.0759705923763769, 0.0934150152440582, 0.01933251441057239, 0.13577405656022684, 0.040576974262616465, 0.044564995981220684, 0.03714610104049955, 0.0501937119822417, 0.032042869699320624, 0.03729978922222342, 0.017868865181558898, 0.023936578072607517, 0.049772854029600105, 0.05509918089956045, 0.045546137262135744, 0.04470943573064037, 0.01854366316859211, 0.07660593864108835, 0.05147366990734424, 0.06472320947796106, 0.02170698664018086, 0.055630931830299754, 0.05373909816678081, 0.025217328187344328, 0.017298378382942507, 0.02896129951945373, 0.0382232855606292, 0.013056436985997217, 0.018101609478305494, 0.023804577566417198, 0.01938362675718963, 0.03619826904364994, 0.01747086537735803, 0.02552881308032998, 0.03275410332051771, 0.017498870213915194, 0.012514294291447316, 0.028317500404747467, 0.03626556953947459, 0.03326880605891347, 0.03237292609576668, 0.06754108398620572, 0.0774519903851407, 0.057383197625832896, 0.05043064623272844, 0.0030339173016337945, 0.007485843446504856, 0.02363160202678825, 0.01292210231934275, 0.006059957235785467, 0.046364742264683755, 0.03851072317255395, 0.024113358497353535, 0.021027555955307822, 0.03476058904613767, 0.015286354115232825, 0.017548155604994724, 0.10048592689314059, 0.051497954675661664, 0.04120182359058942, 0.029735901526042392, 0.04316139201234494, 0.027159794133954814, 0.0427177658171526, 0.014145534036548009, 0.01856849924661219, 0.02971915528178215, 0.04140207623796804, 0.03179378288664988, 0.013043871365620621, 0.022573104361072183, 0.017808246559330394, 0.026156454579904675, 0.04645780673516648, 0.032773034447538, 0.010496512654104402, 0.05340985940503223, 0.025906227828402604, 0.01710187124886683, 0.14112270383962564, 0.11508458746331078, 0.09956199289964777, 0.08093639662755386, 0.13792460544833116, 0.18503814164016927, 0.1543115654161998, 0.1700465210846492, 0.09326779350106205, 0.06614214155290808, 0.13864598316805704, 0.22443171351083688, 0.19604248686560563, 0.14040952282292501, 0.07954117935150862, 0.14891642491732324, 0.12584586787436688, 0.059072905885321755, 0.0832894000091723, 0.20226360804268292, 0.09068205260804721, 0.11724654931042876, 0.2751885620611054, 0.10488974808582238, 0.14478384809834616, 0.194067814254335, 0.153205702613507, 0.14178671820887498, 0.11494162013488156, 0.12062390308294978, 0.13684470339545182, 0.25442997738718987, 0.15296710255954946, 0.12374952036355223, 0.1190090033092669, 0.11880400430943285, 0.11874928724552904, 0.09455553083015339, 0.175630511449916, 0.17747759233628, 0.16337635900293077, 0.10627656509833676, 0.14334584240402493, 0.10412241318928343, 0.20161914905267103, 0.09880816084997994, 0.09698643681726285, 0.06077368783631495, 0.22014202869364194, 0.12292391966496195, 0.12975665873714856, 0.13147897060428346, 0.12297102356595652, 0.21549660153687, 0.07091446832886764, 0.1647067761846951, 0.17567817174962588, 0.09756161738187075, 0.08056463407618658, 0.09879339592797415, 0.16039685745324406, 0.11759961822203227, 0.16892977458025726, 0.16388496171150888, 0.07283719908446074, 0.24365329423121043, 0.08040535476590906, 0.15205114813787596, 0.22918828470366343, 0.13114547064261778, 0.1287668797054461, 0.13863568300647394, 0.16073033027350903, 0.11989294444876057, 0.1519384706126792, 0.18427766673266888, 0.3419067662741457, 0.1541992271585124, 0.10124812527958836, 0.15407599162842545, 0.15432167558797769, 0.107448082949434, 0.0830549525895289, 0.20918243963803562, 0.13354805457804883, 0.2267400896442788, 0.13496830979628222, 0.1675441110772746, 0.2041840385645628, 0.19101834217352526, 0.10812722186424903, 0.21494664890425547, 0.17520566710403987, 0.14358676304774626, 0.09137227878506694, 0.11517401837876864, 0.18982553189354284, 0.1946396699973515, 0.1989796749715294, 0.09007075362439666, 0.19092767632433347, 0.24491843634418078, 0.10167493737701859, 0.09803492948412895, 0.16955330755029405, 0.18735171535185405, 0.13296391735119478, 0.11797278534088816, 0.1843836810439825, 0.14863827984247888, 0.1310606130531856, 0.12305440194904804, 0.1765061608914818, 0.16039612463542394, 0.2379109337925911, 0.16720446358833993, 0.12176931090652943, 0.08449716520096574, 0.2407905821289335, 0.17544071163449967, 0.1438275072723627, 0.12420514305787426, 0.14974860740559442, 0.11030283583594219, 0.1607965010085276, 0.11311062052845955, 0.0993406887033156, 0.11603906910334315, 0.1063076691435916, 0.09089890561465706, 0.2042597495019436, 0.15344086928027018, 0.12536053891692842, 0.10425432718225888, 0.09728919914258377, 0.07245581490652901, 0.21896888235849993, 0.12377748957702092, 0.15424808167985507, 0.178708264870303, 0.14406380030725682, 0.17734293027647904, 0.12081359433276312, 0.07647653522768191, 0.07657844440213271, 0.11374097956078393, 0.07286153135022946, 0.0967396672016808, 0.1968217571931226, 0.13545844278165273, 0.1976992522499391, 0.08501578987176929, 0.11022298583494765, 0.11232700079147305, 0.1816388847572463, 0.11134671446468149, 0.13983576718185628, 0.11284087571714606, 0.15115860317434582, 0.09261882903852633, 0.142304888261216, 0.17337616027465888, 0.0719086646235415, 0.12156619823404721, 0.16091411826866014, 0.09773397884730782, 0.1483700413789068, 0.20277738118810312, 0.12144233845174313, 0.19008661859801837, 0.0986007394801293, 0.195692579927189, 0.14034404419362545, 0.134911394278918, 0.13560408353805542, 0.115735207551292], [0.041002680347966294, 0.03165838122367859, 0.04529474682307669, 0.07454807085118123, 0.06472367766712393, 0.07290324089782578, 0.04459458010803376, 0.010465933625320238, 0.07921259876872812, 0.057328779117337296, 0.04257654910907149, 0.014080630465676742, 0.027856332382985523, 0.016185670858249068, 0.06455637128757578, 0.03499782524470772, 0.03577850353238838, 0.008680597729315715, 0.05252020839335663, 0.03343138304938163, 0.013855896274825292, 0.01957075823364513, 0.026983498861747127, 0.03951227478682995, 0.028043100843206048, 0.05964647153658526, 0.05052435191880379, 0.03574877691322139, 0.02124150822471295, 0.013809185924141534, 0.10299098318708794, 0.034474125131964684, 0.03159363541219916, 0.017431266073669707, 0.013253895765436547, 0.0509134238984968, 0.012307084115621234, 0.04866138992032834, 0.02564418438955077, 0.031115448035831963, 0.02207291209405022, 0.01989087918108063, 0.028295634613771523, 0.02655064101730074, 0.01787986932322383, 0.042272551850016625, 0.06078515507813011, 0.050802371464669704, 0.04115320994917836, 0.036550479608454874, 0.05416897724249533, 0.013516114775224455, 0.021622673575101153, 0.03194441766078983, 0.033450504166207144, 0.0753121759210314, 0.002798535836128784, 0.04282875039747783, 0.06268448316093002, 0.052292990764336925, 0.04061074834316969, 0.043732942414603064, 0.03618139048506107, 0.0705398220036711, 0.003951078455429524, 0.04811630238379751, 0.029453217051923275, 0.019030445887308036, 0.02170430133784456, 0.052921246338103495, 0.03677317140890019, 0.0593477939920766, 0.04324719615812812, 0.04103045957162976, 0.00867086584081075, 0.016777277059320892, 0.03448975179344416, 0.010967920617466527, 0.0862649864118014, 0.03477748117542692, 0.06836219278297254, 0.04651761281171015, 0.05259099995185222, 0.0531506725986089, 0.05748661993337529, 0.028568376853529896, 0.013882729790306516, 0.04342209534453494, 0.005911115490432296, 0.05076605627047164, 0.037767968207065544, 0.03954800304823688, 0.024390504429382936, 0.0243690864715193, 0.022038564651406238, 0.06111598839717252, 0.011511340654189033, 0.029664119306419576, 0.03016261523589492, 0.062147266630615504, 0.028830053883471658, 0.026709652306245904, 0.05334513734227844, 0.05876544809767178, 0.0568769460410944, 0.013604612705031676, 0.018284060759469867, 0.046179654874971936, 0.03555912298283406, 0.05648261880768197, 0.03488950730700578, 0.04048627448667373, 0.04948098219132849, 0.05262835330462881, 0.04031068319454789, 0.012827907239885201, 0.01602893096527883, 0.041098743943231444, 0.04686035781300493, 0.01583383179136685, 0.06433244116072144, 0.031080625618674924, 0.05179189604574016, 0.008741507273433464, 0.05201384824301515, 0.035440487920173576, 0.021342014528012702, 0.036539355026824136, 0.011130377167968877, 0.021153712578650032, 0.011284926240997655, 0.08216377148138625, 0.06423416893397059, 0.007489831536076963, 0.021659969252401164, 0.02884417419720973, 0.06340441560106617, 0.010382807148354394, 0.020118632852765064, 0.06688010945383992, 0.01121392348847751, 0.03639666250507746, 0.012333632646394628, 0.046219254178660255, 0.009512732720135577, 0.02405339466141803, 0.04875401673572404, 0.04074638070804732, 0.03447007088522826, 0.017506907461211085, 0.05375788340877209, 0.018057277392862097, 0.017684978798830082, 0.05047408943729741, 0.054767180500285964, 0.04934938371713672, 0.0275042202057583, 0.03620252345821687, 0.005293344979041389, 0.03928360848554543, 0.030638271676642553, 0.028002617747655938, 0.029702938294836452, 0.012607098374116634, 0.06703790955777679, 0.022421419553990875, 0.01979795211393918, 0.011206907436384686, 0.08615355739103896, 0.030082894156553915, 0.05972664723438876, 0.05270847811230591, 0.04334968887269497, 0.026758279518357346, 0.04840862884053162, 0.010846119340775269, 0.013365158545119422, 0.05732724562819515, 0.03353827606354441, 0.059244914512549124, 0.010415983269922435, 0.020118352957069874, 0.03515950656895127, 0.029322968862418617, 0.021773990276934843, 0.06284895326410021, 0.007770786594067301, 0.0318450292439333, 0.04701961337455681, 0.01623470688770924, 0.03645465689312134, 0.010286272819420057, 0.004389358642843685, 0.09296695821519409, 0.056128834041633775, 0.03513257212138601, 0.022383852462683405, 0.05094610893034509, 0.05091580555641225, 0.02972164550530059, 0.05013132068727698, 0.022358459985948036, 0.030249752702989748, 0.023481031713475074, 0.05347360098468406, 0.01536745940601187, 0.026550313624154245, 0.03691973497292825, 0.04473350676042693, 0.04253267503476568, 0.018366735162479535, 0.009833129322422402, 0.030857828645301715, 0.04908536574138062, 0.007690665179065296, 0.020535789396879927, 0.023509156989998052, 0.044286610026444705, 0.037988909387162755, 0.02666273500238146, 0.04279464044209037, 0.016382873490718857, 0.04006964380719832, 0.017096787325239608, 0.028628318637077297, 0.024669645254367163, 0.05424480353082929, 0.07025784999132156, 0.012755627145192452, 0.03785703271361334, 0.003169344409668286, 0.025216532605034963, 0.04206779033743909, 0.016619001980870962, 0.06797478321407523, 0.058190633941973956, 0.01969563921115228, 0.026397996083168045, 0.014250994493652667, 0.07334253125424896, 0.009590017858759632, 0.013386942063724356, 0.0655305100870984, 0.0951909992311682, 0.10794347458119903, 0.060959077174110074, 0.02879767758505685, 0.015684454003348947, 0.06356761005840131, 0.016898254764133265, 0.03637365338259509, 0.027398399276924983, 0.04204180583889995, 0.11018869267510516, 0.02357057967622365, 0.07919061423412391, 0.014245839323848486, 0.01334164391404816, 0.031004602555185556, 0.01975648514261203, 0.007720798919243472, 0.037333746507231674, 0.007000594216931079, 0.058271114980535846, 0.04270397120022348, 0.012589722788626594, 0.04792412430314081, 0.013165684516674705, 0.030671530070581605, 0.04682870415438499, 0.04591880226507783, 0.06361918550516878, 0.017626300786754916, 0.06765696419669048, 0.07709954572575432, 0.0261235592022006, 0.01748117571696639, 0.030601885236267532, 0.021206429660586373, 0.015434312068724206, 0.024389188071446757, 0.007820473168976605, 0.043753057585230896, 0.07591158697115523, 0.05348902069298284, 0.034062749706208706, 0.0034265465011620627, 0.04392248099403722, 0.01072253521332251, 0.06828602044177906, 0.060704579044665606, 0.025812186267493025, 0.018941070950989212, 0.07375109075967755, 0.0419113031987633, 0.05099111955080714, 0.07810423217181649, 0.02473863530238824, 0.05611078501013773, 0.03558839837621365, 0.04389138373413256, 0.027753702265077403, 0.04979370880339827, 0.035754171266619644, 0.04377790214493871, 0.001334214221320248, 0.03161501944331186, 0.026987894072330425, 0.030684920959174633, 0.021388431412300894, 0.0457528461702168, 0.08428546906049762, 0.0019224707918640757, 0.035432236934346814, 0.08554385975003242, 0.041887082891272645, 0.02635214407928288, 0.028306029770257216, 0.02728309921388115, 0.03669041727802583, 0.03292979300022125, 0.06081517346735511, 0.037946982708360465, 0.009636579779908061, 0.029097132052161863, 0.05118584892313395, 0.07388764593218054, 0.014597539291051882, 0.057679391732173305, 0.08348788507282734, 0.016754474890019213, 0.02467223216912576, 0.04298827737303717, 0.040027103054204156, 0.006624590397612857, 0.07021734823605844, 0.032911235067461214, 0.02410419488192669, 0.043841501232236624, 0.03000916793410267, 0.06969034365777459, 0.04775448715580361, 0.06540528644940682, 0.005046053315579359, 0.0438835330839668, 0.059398975888533254, 0.06192816088774374, 0.04658552059637649, 0.01102019241079688, 0.03424636467493006, 0.05283231075320925, 0.03514709955613528, 0.1268945980284895, 0.1602427214384079, 0.1474244485476187, 0.22057086282542773, 0.18340422931526387, 0.1688319162598678, 0.10928213596343994, 0.1345486223165478, 0.12073556280561856, 0.14837954086916788, 0.12452603583889348, 0.1269550554986511, 0.12446639261075429, 0.11044574209621974, 0.12834849501294748, 0.06178740558347531, 0.0983733691807304, 0.1694532372057438, 0.16633008979260921, 0.13850107522947447, 0.1322046909481287, 0.0757882089487144, 0.22490374318190984, 0.1824135139052357, 0.1588037929364613, 0.09954841541392462, 0.16254501789808273, 0.09580993851912872, 0.16732423858983175, 0.05156663938292435, 0.14655407810849802, 0.13549812350954327, 0.09522415245217936, 0.13930470496416092, 0.14559855152453693, 0.1482271554746798, 0.10864572439874921, 0.24138986425740377, 0.12043807948274271, 0.0926037316343614, 0.0764583165624312, 0.08315823240471737, 0.1624946841703994, 0.11762176560504095, 0.07867105318499462, 0.10472311345594269, 0.08534492685326509, 0.12335394801838057, 0.07563688206885542, 0.10401076703731503, 0.14622056457613195, 0.14685344775872572, 0.10953888682914631, 0.1169178940887962, 0.14333980344235897, 0.12681269885173865, 0.17003923361854895, 0.11172597482800484, 0.24396354758313724, 0.18165618740022182, 0.11722881240504128, 0.10728817938693933, 0.06351163091936282, 0.12212166057101317, 0.12415765917726926, 0.22111054243785994, 0.1890764156622546, 0.1755276591117893, 0.18397736070411547, 0.1593865052397762, 0.1478204144431012, 0.09839708397963218, 0.1505782657435962, 0.10008738934993744, 0.17786779068410397, 0.0724427734634706, 0.18174374555902822, 0.20021971128880978, 0.191628847271204, 0.2474346613245351, 0.18988662718662194, 0.13767126761376858, 0.07731064475540604, 0.1191538976771491, 0.09108988608100585, 0.12565125046031816, 0.070978447395776, 0.09991342654185635, 0.25389124772378374, 0.21341022849082947, 0.11635397720549788, 0.1379425594849246, 0.07209891227207013, 0.07875453334833894, 0.10155088760490928, 0.1850530965519803, 0.06828233599662781, 0.14403987516249928, 0.16561119551105158, 0.10140119599444525, 0.06225934025964566, 0.0818756315857172, 0.18397202741886887, 0.14915669416742666, 0.14281748075570377, 0.1238915106015546, 0.1322605208094631, 0.11515861563384533, 0.17322038220507757, 0.18165124766528606, 0.12838274746068887, 0.12342868186533451, 0.08755753455417496, 0.16563911044171878, 0.17179688358945505, 0.12554416406367505, 0.14127614774874278, 0.1706476623990706, 0.11994372600955622, 0.09637511069221155, 0.21575496053057058, 0.13590829792831624, 0.24961680280310766, 0.0932875524408051, 0.10902607720345259, 0.15142154906477245, 0.10143377924604075, 0.13943906846855367, 0.13466230407357216, 0.10033875264759574, 0.11239819268562964, 0.12210138594465596, 0.1741260771772691, 0.06889858828591448, 0.15009935572743416, 0.12013623996504716, 0.12908902099089964, 0.09417810929673058, 0.154842111947281, 0.15590125082858972, 0.07319871575704642, 0.08439240617943661, 0.06479767869625773, 0.14141089123274597, 0.12004712117569787, 0.12568734852331026, 0.12309469335845538, 0.13795040334974015, 0.10758706727730376, 0.16852220573595592, 0.12135279897068228, 0.09289626165160111, 0.1251905251826559, 0.11690250491457325, 0.07870589595820222, 0.146598359303815, 0.17695057418729576, 0.13547996591244424, 0.12080889887043408, 0.1169506809008973, 0.13050125592521258, 0.06989070826343127, 0.09379852323659829, 0.13615442972098077, 0.10829931191567864, 0.10803364509982721, 0.15468617102929524, 0.09391206928661891, 0.2786091113729136, 0.09897535187857491, 0.20442527133439267, 0.12487392074295453, 0.09140364745897905, 0.14657927889909061, 0.18022194078990392, 0.16652377082833222], [0.00889737524890474, 0.022161396453157067, 0.04492576287261077, 0.045781592306281836, 0.02475622801908425, 0.04717627014698727, 0.039019848353096416, 0.055783754879874844, 0.024098719104326198, 0.023841374520478503, 0.0196119673616652, 0.023864758533558676, 0.0596598047497017, 0.07118130222495113, 0.012825237204586821, 0.0273400808884097, 0.03804483085072466, 0.040904954341905456, 0.037835054964359315, 0.04095088437731777, 0.03514284174889326, 0.03628583738048162, 0.008560522476078143, 0.03811139174337898, 0.029438377491065433, 0.02360855388854231, 0.03800529261518802, 0.06539959354060036, 0.00853244639334402, 0.012122689679797207, 0.010886854342451053, 0.02188546849148614, 0.05870980822614261, 0.015254510466807654, 0.03225874561550362, 0.04490870110956686, 0.048787115673933706, 0.05966719399605479, 0.03864533434222851, 0.04013641504570842, 0.025483709161302874, 0.049293862589235814, 0.036459053800042183, 0.02922379079141787, 0.054535749168800454, 0.053752224426716566, 0.03796562885067292, 0.029141430210854326, 0.028105161352349178, 0.03646340320951172, 0.027448548103815744, 0.014073577094157892, 0.06884299591183662, 0.010962042807867485, 0.07547292086694922, 0.024485058284231594, 0.02390260891323643, 0.04569528265190976, 0.06952734597559486, 0.028847929888537953, 0.06183598190546036, 0.026911538526681916, 0.03311455808579922, 0.053415637130716016, 0.03093838771539075, 0.045645362830587795, 0.025523793617529527, 0.020444933557882905, 0.051014797030282874, 0.0207421386814011, 0.034446437510528734, 0.02398832654580474, 0.047171489867780886, 0.03140067023092082, 0.024873867331604873, 0.03418378678283521, 0.038736722831215174, 0.005217961010722709, 0.057821497321128845, 0.049097277423633, 0.008280020340212753, 0.05514081580830472, 0.04290861736184784, 0.04379584600350686, 0.04888979159295559, 0.03889195468010647, 0.023345092311501503, 0.029330629522779157, 0.021604398930711404, 0.006667464056850544, 0.067492446596069, 0.028970558129783188, 0.00322360621898302, 0.019378339273056815, 0.05338176466258509, 0.07244661397167615, 0.11152168828994036, 0.039548766400132856, 0.07985369222504751, 0.06341768774603095, 0.022170517660145248, 0.02184805746323296, 0.016582668126959885, 0.05608222886387791, 0.023148340904819112, 0.02906041991497789, 0.06685211988432066, 0.05163455395294087, 0.05087860826668995, 0.011887310122671937, 0.07251681520470551, 0.010417807680953826, 0.0688507379963994, 0.05477847810834646, 0.012410144255097424, 0.020135850678863268, 0.02194767997467092, 0.018162850656413605, 0.03293427133134433, 0.018067655585972325, 0.028001974835725765, 0.030526628917349235, 0.06321663103465523, 0.04241692713860955, 0.06660846474447421, 0.06103405529367072, 0.025047190620430877, 0.07965851841228348, 0.08730429171451501, 0.07624056788959674, 0.01228939725219139, 0.021569849623899375, 0.056337497130568535, 0.019452172364773493, 0.01923863569806729, 0.07519890128501824, 0.07735717868698494, 0.023718407011723945, 0.007535288293313767, 0.02202986752880471, 0.02977418786446963, 0.023023887404373715, 0.02174398036939757, 0.07507546219442572, 0.02649501641280949, 0.033534578047692776, 0.023128028959035873, 0.024330418457144072, 0.023499119760734693, 0.043001345957496336, 0.04348775378561445, 0.012631426399041499, 0.05406079501179712, 0.011567224798324918, 0.048997780441173484, 0.02881272749177047, 0.013251003509919559, 0.038163791610194106, 0.052635301503219774, 0.06268339071955, 0.03869417529287083, 0.0075166192504444295, 0.014568803333012121, 0.06578472323183503, 0.026088685894917165, 0.045320113854748864, 0.02175406170343714, 0.01940966384219272, 0.010313579613076789, 0.04846133065543004, 0.029748281397457634, 0.08221807463892869, 0.03783751465380192, 0.011828223293248032, 0.027318510260166864, 0.00816495097907526, 0.015589945949614048, 0.03971360291221312, 0.004557022101445389, 0.021738365492118255, 0.04905847539859159, 0.06087765297187226, 0.0471645043497639, 0.011527774772340698, 0.01645267608442477, 0.04494890430942178, 0.01285707576399935, 0.03993923616196428, 0.025242793606594205, 0.05639535920428378, 0.02307257059562419, 0.017298444540106823, 0.016494385632021085, 0.021442678590704287, 0.020585853406893354, 0.02578912116587162, 0.056193189695477486, 0.034657387262476344, 0.01735908182204834, 0.032156256293611865, 0.01447117401819144, 0.01952779509260186, 0.05028688162565231, 0.021473926824650595, 0.011941011080385318, 0.0373248000230108, 0.03636390283437712, 0.0021124230656174143, 0.022091500560886095, 0.02209655903945012, 0.008165537063697619, 0.0027663968129283084, 0.043081321487469335, 0.041263895974095376, 0.027622957048671584, 0.04225666395255497, 0.022831512548561608, 0.06408441625535488, 0.04973924279745136, 0.028646167500742843, 0.032137752643653324, 0.05472711979278496, 0.053020152995096784, 0.06918948981910944, 0.0406042174436152, 0.04362209014860647, 0.014377738049786006, 0.04628904150532825, 0.042400588015360494, 0.041347650944122245, 0.004189650519817535, 0.027151582163891623, 0.09026919797595058, 0.02487050519058747, 0.0699890890557851, 0.05322061598833118, 0.05242371392835464, 0.030446178412863185, 0.027462152730939642, 0.016807105458740677, 0.06362698187253304, 0.043901327664830854, 0.031376453316105266, 0.06344035760100399, 0.008073817788889366, 0.06192556209862232, 0.06163837215197938, 0.024464354484475086, 0.05029680859297514, 0.038046584863747866, 0.088165976905397, 0.01940898021816143, 0.019502009065555673, 0.025694341698129262, 0.0174426145718566, 0.05118281926427569, 0.019796800300745026, 0.03607254668271967, 0.05885345408959048, 0.005088117821807308, 0.10239325490381036, 0.07472121263188974, 0.031282055524310896, 0.03205848279009972, 0.03655041175495301, 0.06368595335100379, 0.08767145379845585, 0.024270948255434632, 0.03356277457039271, 0.04838086997291871, 0.07391845820737736, 0.02381713385693729, 0.07013552369815962, 0.05237366518537913, 0.056188646903527636, 0.029821668352399553, 0.026945628126018813, 0.04366235780928816, 0.04455823437975986, 0.04347846464120916, 0.01518654839933983, 0.020467525381328802, 0.04505834182990449, 0.05245989002287388, 0.0712817729051624, 0.04409956506320408, 0.05221776497949447, 0.025805350027180145, 0.05935816879251173, 0.01931463331649346, 0.030439952854067087, 0.06322574375995568, 0.010894322468500053, 0.007892627734690905, 0.029302008915692568, 0.05704986051257167, 0.01389946331203516, 0.04068165525261845, 0.023840029324804033, 0.0485387650717582, 0.050528847213302336, 0.09589459254805531, 0.028215847377266203, 0.0635681189596653, 0.034462020067231994, 0.018873475292431455, 0.030918700021824667, 0.03403091284313372, 0.028678849139916043, 0.032873895285384994, 0.014156529696525207, 0.04186920688620635, 0.025984759775123427, 0.0365147717030985, 0.02800161690850343, 0.04864163776593549, 0.029095459463340894, 0.04863612466890897, 0.014989518793299794, 0.07878596987575293, 0.028284367539786866, 0.01531948019484324, 0.07256915739604405, 0.012689855049497314, 0.04376320507643478, 0.0321656777523458, 0.04258636072544115, 0.01675298041664064, 0.03342226693140609, 0.0356639803919409, 0.04094546627519386, 0.04192016486610685, 0.04496044619008899, 0.019708673868860518, 0.02926035365089774, 0.03959666418709925, 0.05307192860969475, 0.061069094842033725, 0.0036333039669053896, 0.014503972704655357, 0.06709747814706393, 0.05208493496424385, 0.048765636647918394, 0.04064955376088619, 0.06194344828171389, 0.008504454279318452, 0.018645015944327627, 0.027408662119082043, 0.02004691000495638, 0.0544635326867657, 0.029206067456730773, 0.04482204879501036, 0.13035812574837888, 0.11370264233223029, 0.08893248398921319, 0.18913300548280987, 0.20571037594761166, 0.12905362860432693, 0.06054715892033918, 0.13353558310440608, 0.13922777266374656, 0.11665766233844416, 0.07697674445807934, 0.13305974006652832, 0.21782354238842214, 0.1439694296568632, 0.07276134565472603, 0.08435105625540018, 0.1296236930148942, 0.09385943532522235, 0.12567666838211672, 0.14203130294169697, 0.1369419646050249, 0.09014591494841234, 0.11832493144486632, 0.06898503364729029, 0.13679191337100097, 0.07700671534985304, 0.2189810417060341, 0.07720601465553045, 0.1124383687440838, 0.15269597353679792, 0.10173259928290333, 0.06434519083372184, 0.11712676073823657, 0.18141308187374047, 0.09567827558411018, 0.1450211996478694, 0.18426664732396603, 0.21690946072340012, 0.11200519198817865, 0.12582144061369555, 0.08806997098560844, 0.14869390614330769, 0.09860713128000498, 0.07460510850484882, 0.1119559235604746, 0.194118826517037, 0.137644139783723, 0.14132861207638467, 0.13657877195094312, 0.11923291986542088, 0.2345852708177907, 0.14761405837322983, 0.1608134779546942, 0.14189953144107545, 0.22118462489119597, 0.1308945348220212, 0.16948254991854939, 0.11390935124031135, 0.11485748179256916, 0.1183173589940582, 0.11848552711308002, 0.12625122469450745, 0.08408924351845469, 0.11769576663417475, 0.13786231593361922, 0.14892416021653584, 0.10038337311042206, 0.10215488555175917, 0.14633370350514138, 0.1534233766474894, 0.1593240121645587, 0.11157721959586654, 0.10818827644522701, 0.08684095407703094, 0.1940233837813139, 0.11257378397775547, 0.18154501622276648, 0.11623851768672466, 0.14641947033149855, 0.20862746584628308, 0.10073336147304092, 0.08971757614719016, 0.1611878392951829, 0.1231045728283269, 0.14381654214646133, 0.1436179620879037, 0.10065267687397343, 0.09840382861771754, 0.11939899809658527, 0.14561118584658417, 0.1216757952102593, 0.11342982375728232, 0.08139419063393559, 0.17746858139123234, 0.15956774194325718, 0.18922719971409865, 0.2303987368941307, 0.16655422347996915, 0.11777824935104166, 0.14373543007033213, 0.0973071124670761, 0.16835329122841358, 0.1400575124259506, 0.1270971814436572, 0.10704494493880443, 0.1430566914911781, 0.12964179632919176, 0.24787557337965282, 0.17656281856553896, 0.1335003264248371, 0.10480962667082037, 0.07787726899342877, 0.1229310714240585, 0.11607015957789761, 0.10333501401224307, 0.1603342965245247, 0.07349087258002587, 0.10802158753254584, 0.15123207494616508, 0.1197024118155241, 0.10027041060051747, 0.23080173241240637, 0.12525422605020659, 0.1265295869005578, 0.14507090912333556, 0.20129395435963357, 0.11144208934690271, 0.18347050861588546, 0.14952143388135092, 0.15258848001914366, 0.11116178653069905, 0.0817139774028744, 0.08468963844435555, 0.06439194868185691, 0.08728886861354113, 0.12950030820710318, 0.1287100998950856, 0.07250571437180042, 0.09504206079457488, 0.17118019025240624, 0.1702264550008944, 0.1601517434631075, 0.17867964426321642, 0.15977337876600878, 0.07925039316926684, 0.13255447575024196, 0.1772956092442785, 0.13427879608103208, 0.1450724426124777, 0.19403111908052648, 0.08939554342733962, 0.0646429659266557, 0.15578005090355873, 0.17886040599218436, 0.0725090866908431, 0.13044565676578454, 0.14046311351869786, 0.10460244957357645, 0.16442435633923325, 0.13114332647195884, 0.16087664956493036, 0.17770931204514845, 0.1023474537900516, 0.13860703525798662, 0.11150336105908666, 0.12119028983371598, 0.11861543942775045, 0.09848228083657366, 0.1452443426741021, 0.12117427640727588, 0.12065550924411841, 0.12932525974299225, 0.15414856773402008, 0.12887131981551647, 0.08596875837871007, 0.13915417875562394], [0.03338408576590674, 0.07673011733485119, 0.02984887421397226, 0.02653664962521621, 0.04772822445790682, 0.05119383867297854, 0.03781574385772858, 0.046967501885124614, 0.05936985316553286, 0.026681761124304364, 0.02730098200429763, 0.010223410790786147, 0.01244312190517251, 0.042687340306916406, 0.005706175862412367, 0.04219948719920857, 0.045531005931219885, 0.046430427847164016, 0.027184404599081193, 0.03053667802097542, 0.02598801674321294, 0.06592167195464883, 0.044213806611618826, 0.02226300198318703, 0.012801513075828552, 0.03967999507273946, 0.007922259358955281, 0.030084546389324323, 0.017530763056129217, 0.012599312184777643, 0.022041957326499478, 0.016069938229130845, 0.08099428244999476, 0.06135905999690294, 0.020223084837198257, 0.015567130209611995, 0.021373067683141147, 0.015995989786460996, 0.016089880373328924, 0.010525479314050503, 0.03520347224548459, 0.013122327825320619, 0.03518060561535614, 0.02299314976802894, 0.05685413030109235, 0.05179998418316245, 0.10009002206580979, 0.034590544777789285, 0.021593695040792227, 0.048073666635900736, 0.02202521956392697, 0.014738450658374598, 0.04267476026767066, 0.03275565038036023, 0.06154558927352939, 0.01697892409616283, 0.01797304575198463, 0.05958923032241208, 0.05128219750310693, 0.04362372541800141, 0.023066043088744794, 0.02148652552360935, 0.0365622623690537, 0.08840003077472959, 0.048186208454093764, 0.04770939511113933, 0.02884127346000501, 0.05235673912933894, 0.0464533284040434, 0.10603749006986618, 0.13925427624157496, 0.008174721883343799, 0.03794481139630079, 0.06260460601853472, 0.03518877178430557, 0.023567098791577985, 0.06367189410541739, 0.05965578103704112, 0.05190257867798209, 0.04204120194273336, 0.017011534489159073, 0.08841784231896911, 0.012039807475438076, 0.03747989616489836, 0.01640500730302717, 0.025712271985997046, 0.04167094913178256, 0.1474993588136775, 0.1686129801507507, 0.2607409773128373, 0.08738725619124514, 0.028392856807581017, 0.08855586991246257, 0.026341056817078164, 0.05913368226694209, 0.17274318209716252, 0.01760528146821473, 0.054487803884382756, 0.024958563768970113, 0.038489240753863535, 0.012944203053068901, 0.10790917463600636, 0.09843443054705858, 0.13079852211688245, 0.04909763365451779, 0.010635201819241047, 0.058713831938803196, 0.0414497365376779, 0.02626077933902187, 0.06265334518892424, 0.02238813741132617, 0.03477359316977007, 0.03638727158041937, 0.045067671686410904, 0.049048219341784716, 0.016681971726939082, 0.07481838563191039, 0.05165455037994044, 0.033675292639860084, 0.024858094785096388, 0.014792402674044882, 0.01527722442655691, 0.03875909413078001, 0.08110964018851519, 0.03424204240686127, 0.011061672104655631, 0.021161210390606096, 0.03640051658398338, 0.021219113176422458, 0.02373039672550346, 0.06555431309555258, 0.009178175092009562, 0.029236689742122377, 0.05590107697727425, 0.09630465840122529, 0.03580843031938587, 0.04145021829754114, 0.03774931188672781, 0.029157304537615607, 0.04904022959194013, 0.021321573660575917, 0.028529364482632706, 0.013158996705897152, 0.022100374102592468, 0.04292961123532482, 0.06739946015711341, 0.022525067474426966, 0.04121084471366235, 0.11133110137390238, 0.020232720034463064, 0.02568877092562616, 0.03280735814145633, 0.025051529851875136, 0.024807099485769868, 0.048702088450746875, 0.03938921228317278, 0.030157197133771012, 0.05279494382973228, 0.05336118469546948, 0.08125177970422165, 0.05959191732108593, 0.0746352897424783, 0.01103463672500636, 0.07083694570298706, 0.020050044836742536, 0.05223370376708252, 0.06865206294293914, 0.031698743879262886, 0.036429629128958495, 0.047823324533445496, 0.012233289191499352, 0.0742245249982391, 0.05336374955783997, 0.013554357857044255, 0.021678377907457094, 0.03577968418332083, 0.031390013838452954, 0.006956006408602531, 0.06877896256212677, 0.039771553195480785, 0.012887315525274192, 0.03516042598390153, 0.044462632188307386, 0.022621236242620007, 0.06846848529364381, 0.03879458151225533, 0.07964808932904686, 0.036396184137889316, 0.04014828262318458, 0.026762591608400856, 0.06313581072858401, 0.02353256305546633, 0.04118401883170009, 0.04691088831584368, 0.06265528579907757, 0.024119380495644042, 0.01540564396418631, 0.06602680417043821, 0.021267265414020846, 0.04441575559654406, 0.04295884930927839, 0.021724759168656807, 0.03138506392549191, 0.004056795483588108, 0.014004620972887745, 0.008534130856527813, 0.07726238734487977, 0.03604856046981045, 0.03443560469895601, 0.0490637917204627, 0.031537469676030536, 0.015194393960492951, 0.038411422965249846, 0.057052595008696826, 0.03826276272801416, 0.04547748987429908, 0.05005957578708019, 0.050778076518327, 0.021985009578721862, 0.04190198012760707, 0.026389887589695196, 0.02523543150164187, 0.01749196951277554, 0.029241242712097507, 0.008951105044356414, 0.005228140308255596, 0.02777934410343213, 0.023352622353870953, 0.0681014114192554, 0.035970885173550675, 0.0354037757829896, 0.022755175662626113, 0.015101402432524731, 0.05466514579685671, 0.00549113581655547, 0.027989773079752922, 0.04103376064449549, 0.010649558772066874, 0.029389801169080392, 0.09789827253137316, 0.026228309742041996, 0.025507753049688678, 0.024538394529372454, 0.05390609581289547, 0.03577874780499509, 0.08152889340583767, 0.12080021362219538, 0.05624320790437715, 0.019885544199496508, 0.03474903359477009, 0.03391973827300327, 0.04087430491511311, 0.08207835749323879, 0.03607232276616352, 0.029604438758854355, 0.04062146241111415, 0.042410094290971756, 0.029115622131420032, 0.015406244467677814, 0.04429437925240823, 0.09308135921933822, 0.058867492979126315, 0.03845840472994106, 0.2123580513788121, 0.20175347184496267, 0.29416422812002047, 0.06435975219522204, 0.10119361177619014, 0.2205902553562607, 0.00974431841833783, 0.026594798379976834, 0.09556522486465317, 0.05931299871632031, 0.10939570236951113, 0.14232808058815344, 0.08965266748730626, 0.0528202871126788, 0.04801642202905246, 0.09279307004596506, 0.03629122494852968, 0.06684568737234388, 0.0556704666731613, 0.017897075274959207, 0.11075073001640183, 0.0482111378306789, 0.05049866936834795, 0.020447457708152275, 0.03109741596771138, 0.049578429998031685, 0.02372606427940939, 0.029289988667837212, 0.02139990883214133, 0.037040191902113814, 0.009404157787295324, 0.021124333708680103, 0.09177288586007697, 0.023861379429165806, 0.059806592230285914, 0.053708933892526796, 0.05519808416387864, 0.06078136206737586, 0.0672555835917592, 0.032906580317233286, 0.011803154816984065, 0.024245969685060636, 0.009771721055065947, 0.06957143039575645, 0.02921132949580039, 0.023320264715169157, 0.027315373732043163, 0.05325843413759555, 0.06779705453664064, 0.028460968152752945, 0.12839561248464243, 0.02654766903391906, 0.015831278803359185, 0.009943339524657598, 0.08415502070316247, 0.027442671990554248, 0.007128586277498731, 0.014946408070889967, 0.029147302931440727, 0.03223023357402001, 0.06651344948581286, 0.04185966668384416, 0.012162293224329395, 0.008987388008141091, 0.048178259416350296, 0.05850874472941671, 0.02368009013922087, 0.056197844445705414, 0.036931032580988746, 0.02813038249899234, 0.10877497853445155, 0.05257138689713819, 0.014126406134372311, 0.09413174499890634, 0.08299202525189944, 0.026184817343684177, 0.019699591677635908, 0.048149730411491225, 0.05759611512933459, 0.05227570169206176, 0.008871931033874196, 0.032207665499299765, 0.03022544418594667, 0.024240141069250445, 0.04040713355477367, 0.027523478725925088, 0.018297931711588587, 0.09446211691413607, 0.08021502569317818, 0.08260398464543478, 0.1603009940258094, 0.11976738832890987, 0.11958155115800244, 0.10320945110704217, 0.08747820702514478, 0.1381474770605564, 0.08132959410016026, 0.11888981184789113, 0.11351383317794118, 0.11977017032248632, 0.07319808471947908, 0.11419686009841305, 0.06680584379604884, 0.1390853345926319, 0.09257612204445259, 0.18830557273966925, 0.16176752533231462, 0.133684725101505, 0.24495464297277586, 0.09729506847049509, 0.12929385714232922, 0.10641414485871792, 0.1996329684874841, 0.08311627858451434, 0.10074516798236541, 0.07566785719245672, 0.13574850293142454, 0.13842472646917614, 0.08442769678575651, 0.15988502491797718, 0.09979642674859081, 0.17456865842853272, 0.15277278370090894, 0.09944886754133872, 0.0699695608179484, 0.13111826138836996, 0.20954804787678377, 0.10529438565884318, 0.22736428757863386, 0.10965253465941974, 0.1560192752097334, 0.1337614402707134, 0.13857499483440602, 0.10822264424392156, 0.10533128439315728, 0.15594123011188848, 0.21341657957860402, 0.1328069722013814, 0.13718937204352447, 0.13070297081555637, 0.0747890118509531, 0.16214955411851406, 0.0993990698563201, 0.14749075498964104, 0.15988795618925775, 0.08732099724667412, 0.17840346693992615, 0.16741911135613918, 0.10905205830931664, 0.0848175355100206, 0.1041734933054873, 0.0983552522957325, 0.19677474828703062, 0.10046489909291267, 0.1366248173373086, 0.190460613529597, 0.15910475035863264, 0.10647310955183846, 0.2750923457954611, 0.23431173978107317, 0.13877814821898937, 0.1004455608448812, 0.0902887194284371, 0.15703429574412958, 0.18018938467970916, 0.19171949954969542, 0.11693347325282437, 0.1266245682324682, 0.09187225052820784, 0.15818894521466323, 0.12641408666968346, 0.11791710475725786, 0.28080783624734196, 0.14425350512777055, 0.10084865814340965, 0.13659854446138653, 0.29718102195433205, 0.36674451349037035, 0.5299821527940887, 0.2868996965033667, 0.24747314783079283, 0.4134749759520803, 0.08745865164590733, 0.17666439525783062, 0.17093489984316484, 0.11548291466065816, 0.2470342442393303, 0.36721701813595636, 0.17445127187030657, 0.1686340554484299, 0.2283414187175887, 0.35073540253298624, 0.28048737772873467, 0.16718478607279913, 0.11218722936298166, 0.1983703640954835, 0.20677638160330908, 0.12150762709123747, 0.1449291631579399, 0.09779132862708398, 0.1386166297431503, 0.2180550992488861, 0.19668793651674474, 0.2526021940367562, 0.11272470373660326, 0.13874219943370136, 0.11810458398291043, 0.16672259515949658, 0.15048472290592535, 0.12088588545364992, 0.09712977055460215, 0.11042495178324835, 0.1918990941984313, 0.140052179140704, 0.17873821540602616, 0.1274636582072292, 0.20321300067007542, 0.09933483294610466, 0.09598324314824172, 0.18658953053610666, 0.07035424267607075, 0.1789180136152676, 0.09088205080479383, 0.1497915315308741, 0.2090878247150353, 0.12251236103475094, 0.24434681130307062, 0.13443739685629094, 0.1615761648863554, 0.16985152369099005, 0.13639406114816666, 0.1561908767159496, 0.11224085398550544, 0.20212308344032082, 0.14636704671595777, 0.09090555525783982, 0.11194451060146093, 0.16322921189878667, 0.100941162822502, 0.0621911474902715, 0.12561028051589215, 0.1435748886849199, 0.08365065205310072, 0.1215190129088504, 0.15228187718561717, 0.17907532517399105, 0.16446508201105253, 0.1272056113396372, 0.1908248918397086, 0.19918243480580194, 0.15887902889932903, 0.17920312045940331, 0.1769480907491275, 0.15685670955904893, 0.19067299499043397, 0.22392036952078342, 0.12554671535534517, 0.22391685470938683, 0.14464443629341467, 0.08025335613638163, 0.2506092552627836, 0.15633193057562622, 0.1503889544733933, 0.12450983242264815, 0.10929429531097412], [0.06359072774648666, 0.07015249385897603, 0.04468144276844604, 0.032224181041653664, 0.05228344038394945, 0.018312560926590647, 0.04032869151394282, 0.0313343128987721, 0.022136933569397246, 0.005505483439524791, 0.024235274276829193, 0.03487614016713841, 0.03905473862375532, 0.019898809559111084, 0.041933342016169, 0.007457638442117188, 0.022896712978503535, 0.02169048466852733, 0.027652089949697256, 0.02590600900085909, 0.03324059257283807, 0.06908596573131424, 0.02101253827900759, 0.021106790185772946, 0.016387227989201034, 0.012577589734324386, 0.020170722289809158, 0.032588774870548926, 0.013458508000309979, 0.007684044373620833, 0.04425616755283304, 0.038648913614451885, 0.0033089222436371657, 0.018673322728968093, 0.04154508427849837, 0.015939191316387484, 0.02655923127063683, 0.01583010663411447, 0.02758327462444348, 0.012895787034982016, 0.07175311047051634, 0.01695659859771175, 0.009650679737595575, 0.04395141372723239, 0.03288705547207168, 0.03299270676715033, 0.014204774384519883, 0.03346714523753949, 0.03909891464614442, 0.01684259284021599, 0.039089625501739125, 0.03394697466865182, 0.056143761812044043, 0.06996280939451285, 0.017011407263843075, 0.022281303768977523, 0.03296249499544501, 0.0627153157921774, 0.04368836944922805, 0.018611028125243526, 0.03533506054165108, 0.014569846580603292, 0.031752337967710834, 0.02053608964862568, 0.011261065557066883, 0.06553975173405238, 0.04504986014217138, 0.02069879386440984, 0.12316504386918885, 0.07364774987633739, 0.08070657681673765, 0.004818968849057066, 0.0087812999596021, 0.014366657572931476, 0.05779396237007209, 0.05926137577210154, 0.3077933367873941, 0.061942593327590396, 0.1252628977277449, 0.03833482314699462, 0.10518316698393651, 0.09178110970450298, 0.5661158795867647, 1.4443261665957314, 1.42032176894801, 0.8179923668503761, 0.22540551982820034, 1.4973873879228319, 3.6264066312994276, 6.100224801472255, 1.7621331874813353, 0.9093382709792682, 0.7652458772063255, 0.7013569197484425, 0.17982532350080355, 0.06809807981231383, 0.047969837207347155, 0.15469733971570218, 0.2090663287256445, 0.14662735989051207, 0.016220969946256707, 0.0675778334428157, 0.05776306867067303, 0.05944183894566127, 0.022716689156368375, 0.049592085515281985, 0.060195487790874073, 0.045029622835240195, 0.03672237967007926, 0.02160360334840204, 0.024149595660024455, 0.0679351364129356, 0.024852749625486985, 0.015407749119081667, 0.018039101136050055, 0.016049370136378065, 0.048433653212019374, 0.042755190416106155, 0.03376815015716212, 0.02589232803854559, 0.006695217835450811, 0.0730545949190855, 0.005441733802269612, 0.04127576355157154, 0.0167613586277834, 0.020402621810457537, 0.004477979133038649, 0.14916980346398695, 0.06841163762978145, 0.06263679571981941, 0.04663218005693384, 0.022889116778969765, 0.027910565990688543, 0.026406121540016363, 0.06461225543171167, 0.02835215997350003, 0.019973867406536425, 0.014141977664881518, 0.0232211663720331, 0.040200760521526845, 0.04134242622447865, 0.11148521024733782, 0.022914383726726686, 0.020640049695170352, 0.01238932425621897, 0.011744722773853158, 0.014779276414109128, 0.03610845814858164, 0.0385399646391826, 0.036318977030792406, 0.030565067926155667, 0.05016813460471375, 0.04565988687266197, 0.041705676554036994, 0.043054977365370305, 0.025702859008950845, 0.02687213260547391, 0.06393559316971473, 0.05090152917961989, 0.03173184960282274, 0.01708640743579183, 0.01877534555803452, 0.0589780466897147, 0.07822555423315082, 0.014120300167373248, 0.025886845475594913, 0.024671711393498948, 0.035042147152125835, 0.03907315406416144, 0.0420957527655576, 0.017166589918945516, 0.044379029888659716, 0.034831217756228786, 0.014738320040383508, 0.032339721984629116, 0.02938634403316038, 0.007263797950664801, 0.03800273793084281, 0.04559338704815932, 0.06907796580344439, 0.026259320488731776, 0.013357893979576017, 0.01425710300515805, 0.05344655118616564, 0.021347665028380494, 0.006904987784634743, 0.06404301883386714, 0.012750717096163757, 0.04694705083966255, 0.04811455176344939, 0.04305847182071634, 0.05470751352342112, 0.06844287738204002, 0.03241676285064646, 0.05408488300495914, 0.009071889366688473, 0.029641554624374424, 0.044299722715680084, 0.0345765296369791, 0.02320923433373017, 0.015570453334865826, 0.02686094186667885, 0.025632807053625584, 0.022654265630990267, 0.03958291706762143, 0.003397618220852954, 0.07239103516829865, 0.03587595812444176, 0.013220604292915335, 0.02073947373511536, 0.023992915138868347, 0.03583766160798924, 0.009674899196917457, 0.04364540461184723, 0.021907144292656864, 0.011213649529963732, 0.011085204547271132, 0.0244235813152045, 0.030146150583667413, 0.009808406899017947, 0.06396214424499444, 0.019125389899792414, 0.035151102912745306, 0.04489785472729376, 0.03644834312477282, 0.030359386998627867, 0.05660966091922351, 0.03337321563490799, 0.07172309886664152, 0.01958524665263082, 0.016440643962206583, 0.051406630647501776, 0.0112549443230299, 0.08825118733303887, 0.01788762497848698, 0.04283027710126979, 0.028651894336300235, 0.05668545328080654, 0.02525264084605234, 0.04706307014982615, 0.025816121770601188, 0.05135258872594152, 0.011714124237187207, 0.008671258542952793, 0.08827278510268245, 0.08450517869953598, 0.09459977809871946, 0.0558137495203742, 0.0145850050529199, 0.05202339862340263, 0.13607172987290791, 0.09613269727144923, 0.2742104674024241, 0.04208125586488417, 0.06959496877555336, 0.07677706517279148, 0.35394294613174027, 1.2472769916057587, 1.618945905140468, 3.849837464945657, 4.985937850815909, 2.627637607710702, 1.5634056968348367, 3.330121112721307, 6.910772553512028, 12.53536319732666, 5.858853501932962, 2.9761045319693427, 2.7483801458563124, 1.2560369329793113, 0.1341989053679364, 0.07403763609805278, 0.06251466620181288, 0.11124997572707278, 0.16529437394014426, 0.22969905872430119, 0.08183174394071102, 0.03905718813517264, 0.07409599010965653, 0.1459728450115238, 0.03909975942224264, 0.059424197035176415, 0.035427782351949384, 0.06334399884300572, 0.022125900589994023, 0.018159517353134494, 0.05738357760544334, 0.023646039555647543, 0.00726195827259549, 0.056012719736567566, 0.023036416553493057, 0.02480099775961467, 0.03218638324843986, 0.041165603391293965, 0.025416235639048473, 0.05587279563769698, 0.06968528857188565, 0.0411022316132273, 0.05656969520662512, 0.03710469344098653, 0.06248650699853897, 0.03449989928464804, 0.008221636642701924, 0.007453335681930184, 0.056385106540152004, 0.019069424331454293, 0.024682530634371296, 0.03058245199333344, 0.07405643830341951, 0.00637693953467533, 0.08266075088509492, 0.029140656680933068, 0.00526641689274194, 0.016018907306715846, 0.029228560892598968, 0.009465150451952857, 0.013734279898926616, 0.01238669069217784, 0.02232527283818594, 0.027680941258690188, 0.006859228655230254, 0.06374517588743142, 0.015757852832653692, 0.05227864992671779, 0.02682232134975493, 0.035857681783714464, 0.05446592452270644, 0.08173531054386071, 0.012583965418993362, 0.049056748526969125, 0.0400831059419683, 0.046292345970869064, 0.020346099843404124, 0.021041211472558122, 0.024851334879973104, 0.03345554907407079, 0.024132739153823683, 0.03928758470075471, 0.059982929910932264, 0.09229154445763145, 0.029333472584507296, 0.024925435993022153, 0.006243827927391976, 0.03074762098757284, 0.04112624157486217, 0.021695644927344153, 0.030379760012562786, 0.08521204255521297, 0.014068527945450373, 0.027801600052043796, 0.018267261928745678, 0.06462299664105688, 0.09478317254355975, 0.13691357469984464, 0.1761297910873379, 0.1755034082702228, 0.0885643380294953, 0.18439959947551998, 0.12574628607503005, 0.10564966659460749, 0.11008415757013218, 0.18596037929611547, 0.18508121504315309, 0.10712383820542268, 0.2951642530305045, 0.1303037479519844, 0.13600944035819598, 0.13120447604783944, 0.16608203096049173, 0.14042137004435062, 0.11505519332630293, 0.09487693929778677, 0.13824996298977307, 0.1628094972776515, 0.08436395520610468, 0.14406380030725682, 0.12291478658361094, 0.11036927798496825, 0.1052764994757516, 0.11506227723189763, 0.09597568426813398, 0.16290446503886155, 0.17089512412037167, 0.10950654785015754, 0.09212284029594489, 0.20799300846244606, 0.1219889119799648, 0.11217183340340853, 0.10546820597457034, 0.08417629277599709, 0.1139239804553134, 0.0840662479666727, 0.10464451195938246, 0.08049325219222478, 0.12532980128058366, 0.11977558503193514, 0.13786287233233452, 0.16452672013214656, 0.06773829340402569, 0.12214578927627631, 0.13176539380635532, 0.10596203019044229, 0.217752730473876, 0.1396257605935846, 0.24278818922383444, 0.13810483791998454, 0.12328120906438146, 0.1250865871884993, 0.1678385002804654, 0.12861834838986397, 0.10935285966843367, 0.11812715205763068, 0.12745202811700956, 0.11908670913960252, 0.09956875110843352, 0.11609867161938123, 0.1158166453242302, 0.18054376994924887, 0.15801481955817767, 0.09723094691123281, 0.1899166048637458, 0.26320272950189455, 0.17875158254589352, 0.131274283730558, 0.16651442061577523, 0.2004134873194354, 0.1853642455701317, 0.23502447296466145, 0.5588455125689507, 0.19602664985827037, 0.23977831644671305, 0.3417630254157952, 0.35255957607712063, 1.1436650199549538, 1.6693879812955856, 3.5408063445772444, 4.756632966654641, 1.9480093334402357, 1.299103279198919, 3.340694316795894, 7.160393101828439, 12.959590673446655, 6.238318077155522, 2.6907033664839606, 2.9698170636381422, 1.3720277718135288, 0.22074711908187183, 0.09659038271222796, 0.08266796371234314, 0.20996841389153684, 0.3695690376417977, 0.31525480640786036, 0.18205078265496663, 0.12055336258241109, 0.21086584430720123, 0.3015415593981743, 0.16202034748026303, 0.11360903164105755, 0.14926502906850406, 0.22893223272902624, 0.15318078680762223, 0.14107690272586687, 0.13274058433515684, 0.17950072591858252, 0.14876325242221355, 0.18381443087543758, 0.10815243622554199, 0.08959630158330713, 0.14044631299163612, 0.09883964487484523, 0.1583226030426366, 0.13233410114688532, 0.06865460066390888, 0.10074908991477319, 0.14594607001968793, 0.1737400721758604, 0.14961534312793187, 0.14423533395997115, 0.07786854981843915, 0.1987091837716954, 0.1419386693409511, 0.12843690812587738, 0.11407243034669332, 0.08853938151150942, 0.10207405846033778, 0.06956135415072952, 0.15792499509240898, 0.18094980530440807, 0.10832250424261604, 0.09681511351040431, 0.1202979212892907, 0.10101911971079451, 0.14742261650306837, 0.24187260121107101, 0.05945895838418177, 0.08603632011051689, 0.10703045821615628, 0.1034924816340208, 0.10704484315855162, 0.13174931252641336, 0.08978681386049304, 0.1068640746442335, 0.2147017249039241, 0.14310184121131897, 0.1436769946345261, 0.180653841899974, 0.15606048942676612, 0.09725340642035007, 0.0821423637015479, 0.0879929301195911, 0.11076188513210841, 0.16861615569463798, 0.17509894711630686, 0.11490848048457078, 0.2801638793732439, 0.18476117721625737, 0.13327513422284806, 0.09141983730452401, 0.0532799436976867, 0.09357513593775885, 0.102368936208742, 0.09973961979682956, 0.09197809520576682, 0.25795238837599754, 0.10150788884077754, 0.07291778868862561, 0.09827486625207321, 0.17387473423566135], [0.00899290364967393, 0.04516560125297733, 0.05844015840973173, 0.04859777047697987, 0.003960030028663043, 0.03511050616257957, 0.01769890233741275, 0.009984435846230813, 0.022796866550509418, 0.11960078084043094, 0.03302104238952909, 0.048460336601627726, 0.03275547056858029, 0.027291055036974803, 0.046438770435218296, 0.06428533725972686, 0.024180236605129073, 0.033305355347692966, 0.06479968715991292, 0.02013977600394615, 0.02440711496663945, 0.017778511458475674, 0.004697106928298516, 0.0344877738638648, 0.016981505921908786, 0.08158792595246009, 0.008801086040745889, 0.030808539861547093, 0.04497075313702226, 0.006365953204554639, 0.022949090792930553, 0.014174837419497115, 0.041294301128281016, 0.01955458874415074, 0.04639902185382588, 0.07379829644092492, 0.0415910584186869, 0.02378964301065675, 0.014945853368512221, 0.03661542558776481, 0.02417840456057872, 0.019682857307738492, 0.024379671617810215, 0.026981329246025, 0.015642072706084167, 0.03276432205789855, 0.05257997375779918, 0.02677689682293151, 0.06196491712970393, 0.05987719379897628, 0.033925115663026056, 0.038403114303946495, 0.07480869615184409, 0.01268408919817635, 0.02385167807473668, 0.011958278948441148, 0.09067418838718108, 0.04687092260324529, 0.05673192614423377, 0.008417086958486055, 0.02758907779519047, 0.09875103498675994, 0.03318115629787956, 0.03400599364457386, 0.03412845903741462, 0.03556488374514239, 0.01782604114019445, 0.04199369092072759, 0.32027696977768627, 0.20755368417927197, 0.08983380241053444, 0.12592991122177669, 0.16237306355365685, 2.1724192116941725, 3.7840462752750943, 5.435322148459298, 15.664915221078054, 41.2424327986581, 36.10886744090489, 49.79662758963448, 62.34961141858782, 59.87628895895821, 70.34095696040562, 80.27528285980225, 86.18545532226562, 80.86488614763532, 78.5696599142892, 78.14867550986153, 97.11108071463448, 100.07023511614118, 94.59360245295933, 83.39258520943778, 69.70992851257324, 57.24242837088448, 46.454064641680034, 37.6656356539045, 40.48893192836216, 23.294096333639963, 14.012726528303963, 2.5708434666906084, 0.39454466317381176, 0.24423246458172798, 0.24220649472304753, 0.38838057965040207, 0.0673768310142415, 0.01833247423305043, 0.039794453752360175, 0.08949145435222558, 0.02658871022452201, 0.003431061303542395, 0.004258486625206257, 0.007262786085318241, 0.02772414019065244, 0.03367615098665867, 0.0786997823576842, 0.0428620528961931, 0.03259731423375862, 0.02122190365168665, 0.09050538244524173, 0.047265348224235434, 0.04106127523950168, 0.04667123653260725, 0.03443991339632443, 0.008856112686251956, 0.025352907965758016, 0.047848426936460395, 0.025956003461033106, 0.01412108472348856, 0.018523549694301825, 0.03805235919675656, 0.00835822319744953, 0.03177453624084592, 0.027146155580079982, 0.0262631491225745, 0.02064395636054022, 0.0770658700327788, 0.043544184150440354, 0.09795916426394667, 0.010917874418997338, 0.04570282117596694, 0.1545782568199294, 0.03141445806249976, 0.05050971591845155, 0.07061547187290021, 0.03449807741812297, 0.01711692115558045, 0.022986204962113073, 0.07164610549807549, 0.04580539870741112, 0.02236936574003526, 0.024724357229258333, 0.04572784894012979, 0.039929909698132954, 0.0530550364804055, 0.033635075869304795, 0.01460493023374251, 0.02336357899808458, 0.02995265953774963, 0.022812410091449107, 0.023438947275280952, 0.10053736663290433, 0.035064107938004394, 0.01668775623797306, 0.021905227431229184, 0.08137307462415524, 0.028089273454887525, 0.06750687225056545, 0.03233677374997309, 0.024498533989701952, 0.03320382276017751, 0.03204656432249716, 0.01114108953957579, 0.04030524812904852, 0.023876461566292813, 0.03153853497600981, 0.03303516270326717, 0.020200991736991063, 0.011759119590611329, 0.023949729777606468, 0.05974432985697474, 0.018067896465903947, 0.04048961627164057, 0.04660046872283731, 0.05454849884180086, 0.02023487099047218, 0.03516906712736402, 0.011465098492668142, 0.0568495366190161, 0.05935298478496926, 0.03895214073626058, 0.07144872644650084, 0.07996007294527122, 0.07084228577358381, 0.030526615346648862, 0.08547748545450823, 0.05143865750038198, 0.045246889748211415, 0.025002858534987484, 0.031073046382516623, 0.029760444137666906, 0.06538539858801024, 0.051981098750340085, 0.04979557138202446, 0.0437653560324439, 0.04988041200808116, 0.02266678969109697, 0.061230769380927086, 0.08232731199158089, 0.01964723930827209, 0.019272862700745463, 0.04248349481661405, 0.0077470633134778056, 0.0396404195177768, 0.06710310998771872, 0.034214785655162165, 0.006942557420448533, 0.03167139213266117, 0.011796607802222882, 0.04344870748796633, 0.006513792414417756, 0.01615405112638005, 0.020505218001614724, 0.046641170645930936, 0.012884897396101483, 0.04981169676674264, 0.020323010993057063, 0.021652096549847295, 0.040527753332363706, 0.06399104983678885, 0.025133194934044565, 0.02641204515072916, 0.03471869629408632, 0.038709747671548805, 0.008193354454955884, 0.06231160102678197, 0.02087415275829179, 0.025878886259826164, 0.08895601558365993, 0.04832395106287939, 0.011307511279093367, 0.05018681128110204, 0.09118874863322292, 0.1320019175431558, 0.0597301416897348, 0.1618361116519996, 0.09430267475545406, 0.02784940623678267, 0.551274581679276, 0.7220777507339204, 5.195843364511218, 6.915909009320395, 12.256399972098214, 26.848296199526104, 60.44821602957589, 54.26246064049857, 72.67315455845424, 83.63331944601876, 83.54841245923723, 95.85456848144531, 103.55442319597516, 113.28515298025948, 106.1966633115496, 103.008850642613, 102.75661018916539, 120.37934712001255, 125.09973090035575, 120.93720408848354, 108.9745739528111, 95.62425654275077, 83.94614819117955, 73.4778184890747, 62.31635039193289, 63.35031182425362, 44.535163266318186, 28.03269134249006, 7.5739359855651855, 1.4478040656873157, 0.04955599084496498, 0.033822765440813134, 0.2901212450649057, 0.25708063372543877, 0.07378421005393777, 0.0670501028320619, 0.043581042172653336, 0.025468484531821947, 0.06070350695933614, 0.03182326862588525, 0.021493751921557953, 0.04198839834758213, 0.018817994876631668, 0.04567083503518786, 0.025319247539820414, 0.06971371918916702, 0.07168360134320599, 0.028610174610678638, 0.04310525341757706, 0.07648351056767361, 0.04471340516049947, 0.005994216098250555, 0.03584227903879114, 0.06201010077659573, 0.04046069710914578, 0.05107431812211871, 0.02177939480835838, 0.015722955776644603, 0.03604805835389665, 0.07835229100393397, 0.022913647516231452, 0.018935949707935964, 0.009282040991820395, 0.023842131087024297, 0.056976863715265474, 0.029204615391790867, 0.019770848032619272, 0.028340601129457355, 0.004037759607724313, 0.013070274011365004, 0.16617917003376143, 0.02869785829846348, 0.06759090881262507, 0.012068081181496382, 0.03531494876369834, 0.05800128195966993, 0.08657083607145719, 0.027258883995403136, 0.03929623941491757, 0.008038297328831894, 0.06396434269845486, 0.04589992881353412, 0.022524198949603096, 0.012749794288538396, 0.05922556947916746, 0.039635625667870045, 0.04412253008091024, 0.11682101285883359, 0.08780141361057758, 0.04389751429802605, 0.030635839128600698, 0.009569494718951839, 0.03462093636127455, 0.04133867731850062, 0.03396806353703141, 0.049692359420337846, 0.014974484153624092, 0.04690461865227137, 0.03608859403591071, 0.015590500651991792, 0.060043489161346636, 0.0039982620842887884, 0.010177289917399841, 0.034670181040252955, 0.03372419805132917, 0.08231515264404671, 0.11425609620554106, 0.15354319236108235, 0.1579506979989154, 0.12899082340300083, 0.06099406922502177, 0.15533430767910822, 0.11614293924399785, 0.1012844540444868, 0.19833509384521417, 0.18795728071459702, 0.13048250121729715, 0.13537723571062088, 0.1171378887125424, 0.10936274592365537, 0.11474662274122238, 0.19823327288031578, 0.12571543987308229, 0.17125891388526984, 0.14692332329494612, 0.19924612210265227, 0.06687270663678646, 0.12057770841888019, 0.12715753034821578, 0.15741479104118689, 0.1962050502853734, 0.14000409814928258, 0.10757795455200331, 0.17540469499570982, 0.10176835129303591, 0.16002138331532478, 0.23053987217800959, 0.12595717475882598, 0.11667172158403055, 0.1844365932047367, 0.22446555883756705, 0.131512028830392, 0.12849830197436468, 0.10961798365627017, 0.13494213191526278, 0.08686113370848553, 0.0668665658948677, 0.10063352861574718, 0.07080704266471521, 0.14170605396585806, 0.12589389458298683, 0.16844401136040688, 0.1110749611897128, 0.10080975773079054, 0.12703113284494194, 0.08919868006237916, 0.1004191522619554, 0.14861554891935416, 0.08804964886179992, 0.13542127263333115, 0.08921617269515991, 0.20434049516916275, 0.21904779598116875, 0.19016459584236145, 0.09526607234563146, 0.09654021183294909, 0.22838677199823515, 0.12379992194473743, 0.07101867773703166, 0.1554204680557762, 0.18551068699785642, 0.2507668382355145, 0.16901381792766706, 0.6238454761249679, 0.2478524489062173, 0.1525774606104408, 0.5355136788317135, 0.5288463394556726, 5.088975293295724, 7.387012941496713, 13.057466472898211, 27.609325442995342, 61.70309543609619, 57.93578563417707, 75.00429603031704, 91.56544549124581, 92.7881338936942, 105.08206803458077, 115.3402008329119, 125.2258129119873, 114.24153777531215, 112.57293483189174, 112.40075152260917, 133.1730512891497, 137.12171254839217, 134.28832054138184, 121.31508881705147, 106.55803217206682, 91.72657421657017, 77.70702716282436, 63.856036458696636, 65.87024280003139, 46.215949875967844, 30.132183347429546, 6.751042587416513, 1.231583616563252, 0.19200528492884977, 0.3457142976777894, 0.5835562380296844, 0.29290150159171646, 0.1813559899372714, 0.07459007216883556, 0.3173308250095163, 0.11614196215357099, 0.1563230553375823, 0.11540777369269303, 0.1453620684998376, 0.08748358780784266, 0.13730465514319284, 0.14331176637538842, 0.13075842069728033, 0.11328603540148054, 0.19460154990000383, 0.1538569469537054, 0.19275256911558764, 0.15827634052506515, 0.14267049649996416, 0.06994660597826753, 0.13724892027676105, 0.1388160376144307, 0.19244482634322985, 0.1814216992684773, 0.07874297111162118, 0.09397150895425252, 0.13046698990677083, 0.1628414834184306, 0.11746118350752763, 0.20878667730305875, 0.12381889378385884, 0.1694502787930625, 0.1187318896076509, 0.16198849704648766, 0.1166889699442046, 0.1509575532483203, 0.09488512921546187, 0.18695165110485895, 0.1948712539992162, 0.11270620008664471, 0.1696160448981183, 0.10253093644444432, 0.1336673138929265, 0.1174964401870966, 0.2445807158946991, 0.09499746068779912, 0.1262983421662024, 0.07516126294753381, 0.11957425012120179, 0.10785919374653272, 0.17634561950606958, 0.09405743862901415, 0.13627197912761144, 0.1538043740604605, 0.07971229231251137, 0.14054626119988306, 0.16735019933964523, 0.20294937624463014, 0.1376886245395456, 0.07691468564527375, 0.08127944357693195, 0.11163414868393115, 0.08399939869663545, 0.22422731162181922, 0.09696224025849785, 0.09949296553220068, 0.10811694884406668, 0.07094399817287922, 0.1449981837400368, 0.09395201464316674, 0.14881184910024914, 0.1652508391333478, 0.16930085181125573], [0.09211940012340035, 0.035144982526877096, 0.07872048446110316, 0.024921005159350376, 0.0501879885393594, 0.04147365489708526, 0.07469057677579777, 0.057253780641726086, 0.006525574750932199, 0.03330434772319027, 0.052925212375287495, 0.04319777166736977, 0.057124601144875796, 0.034004829957016876, 0.03217343340760895, 0.047015301284513304, 0.06399431359022856, 0.06326747366360255, 0.021639229829556177, 0.01838776296270745, 0.012352378872622336, 0.005731024662964046, 0.11048715987375804, 0.021617911955607787, 0.021642466441595128, 0.06890476295458418, 0.035808949398675134, 0.008395333125788187, 0.05585601207401071, 0.12248819161738668, 0.050369683253977976, 0.027460780393864428, 0.03165597581703748, 0.029718551385615553, 0.029781885844256197, 0.03377986167158399, 0.06460925630692925, 0.059226119092532566, 0.03856095851265958, 0.036722108256071806, 0.02868129525865827, 0.06145907605865172, 0.05587193729089839, 0.04674736137634941, 0.04644929112068244, 0.05183350042040859, 0.06608975864946842, 0.025335868255102208, 0.04813282810417669, 0.013277663998971028, 0.02017680705258889, 0.049282422488821406, 0.035089325691972456, 0.06507876182773284, 0.07161707776997771, 0.060803916571395736, 0.06460202990898065, 0.061218494682439735, 0.043074997541095526, 0.012941301467695406, 0.058018638885446956, 0.011764530059216278, 0.03565664542838931, 0.020172018291694776, 0.07190949922161442, 0.07827253599784204, 0.23697040283254214, 1.272776989000184, 9.11893481867654, 21.019704273768834, 32.56707879475185, 57.401622022901265, 61.391732760838096, 75.83904566083635, 80.68920789446149, 90.1762226649693, 105.76858479636056, 111.22337927137102, 109.5805333001273, 106.81458745683942, 103.17105633871896, 105.92612130301339, 103.63997636522565, 92.94114712306431, 92.47963387625558, 100.77766595567975, 106.09325327192033, 107.75772203717912, 98.20284421103341, 98.74156584058488, 107.81564222063336, 109.40965625217983, 103.80796296255929, 112.16789654323033, 113.00871889931815, 115.2095399584089, 112.88759790148053, 108.37750135149274, 103.10160909380231, 83.17325142451695, 61.22758156912667, 39.60304703031267, 25.830207926886423, 9.760958790779114, 3.226572109120233, 1.070433178118297, 0.2963772565126419, 0.38709521719387596, 0.059485740161367824, 0.12956848740577698, 0.02767813721272562, 0.05114992388657161, 0.07451257668435574, 0.04537218123940485, 0.035342215693422725, 0.0019854019462530103, 0.07700323446520738, 0.12819882375853403, 0.020793617436928407, 0.046956428193620274, 0.04019919649830886, 0.03994572974209275, 0.044636462682059834, 0.05015540189508881, 0.028705417178571224, 0.06865727409188237, 0.048396147188863585, 0.01683416882795947, 0.04015065071039966, 0.024126423689137613, 0.07756297157279082, 0.017176645807921886, 0.04154678740139518, 0.009161202386686844, 0.01662857610998409, 0.057157096186918874, 0.04862554291529315, 0.029153128154575825, 0.06708732726318495, 0.08986679956849132, 0.015225628623738885, 0.023449413677943603, 0.006430086638179741, 0.03206481012914862, 0.012319163735290723, 0.03109791808362518, 0.00810051305286054, 0.02155428403057158, 0.040093830187938044, 0.023336330728073205, 0.031165690161287785, 0.1005399925634265, 0.05610433553478547, 0.024982188661981906, 0.05357882480270096, 0.030190614983439445, 0.019584013415234428, 0.030778792886329547, 0.07235447570149388, 0.08305687962898187, 0.03593911277130246, 0.032930434215813875, 0.06771432754716702, 0.10921394997941596, 0.04266317767490234, 0.053899751510471106, 0.028299298702872226, 0.04021177314487951, 0.08049483996416841, 0.022050203223313605, 0.11595775346670832, 0.06536284408399037, 0.018686303103874837, 0.03338271512516907, 0.01746053128902401, 0.014759166332493936, 0.06209107714572123, 0.07764443648712975, 0.037066105154475996, 0.05673192275155868, 0.02590859930829278, 0.018690971424803138, 0.051795071589627435, 0.027282888868025372, 0.02394585025363735, 0.06480123421975545, 0.0389057934018118, 0.0565090104272323, 0.03235662089926856, 0.0879586912425501, 0.035040501704705615, 0.01279375996507172, 0.061159903183579445, 0.019249285305184976, 0.023312734672799706, 0.0061611310479098135, 0.010280326308150376, 0.018943522158744078, 0.045426562428474426, 0.037324399687349796, 0.028224259515159895, 0.0011953361265893492, 0.10352545165057693, 0.02934685329507504, 0.09293223757828985, 0.06869105835046087, 0.041649890797478814, 0.02787043573334813, 0.040905402175017765, 0.03742494161373802, 0.06553595872329813, 0.062498747770275385, 0.07542714010924101, 0.007971300477428096, 0.06730353566152708, 0.07554684725723096, 0.05028551098491464, 0.0347790519839951, 0.039411542870636494, 0.016888916425939118, 0.03331794556496399, 0.028856991723712002, 0.08792246425790445, 0.030665630208594457, 0.027440125787896768, 0.03300393312903387, 0.02143937921417611, 0.02225571621342429, 0.03999278275296092, 0.03088830504566431, 0.032000552862882614, 0.022327276212828498, 0.051339448895305395, 0.03696448775008321, 0.07068428210914135, 0.04135847357766969, 0.030137892812490463, 0.03873764563884054, 0.021276727584855895, 0.014275849231385758, 0.057901225185820034, 0.08977096328245741, 0.36203431338071823, 3.2032268132482256, 16.310336862291607, 34.32547330856323, 50.42663812637329, 78.87292793818882, 83.41081033434186, 100.63594354901994, 103.50439616612026, 115.39958013807023, 128.26413508823939, 126.27650560651506, 127.69207600184849, 119.76614080156598, 118.11555453709194, 125.82035636901855, 119.27740451267788, 104.06045355115617, 111.36668586730957, 118.4527645111084, 117.46047837393624, 123.95048495701381, 109.2214503969465, 111.64459991455078, 119.37690271650041, 122.74991961887905, 119.00711958748954, 125.91008540562221, 125.76599366324288, 128.89002881731307, 130.49353408813477, 125.16537748064313, 123.21713038853237, 106.39624336787632, 83.22400801522392, 59.86325413840157, 42.19331809452602, 19.402592693056377, 8.746223023959569, 2.7493005650384084, 0.07879009536866631, 0.30539118711437496, 0.0505712895787188, 0.07974402739533357, 0.04014777372192059, 0.03340788198901074, 0.021513451489486864, 0.02769708869579647, 0.013206787623598107, 0.04529974423348904, 0.027114914131483862, 0.07338290408785854, 0.06501003980104413, 0.01870678298707519, 0.03582083393952676, 0.0796593665810568, 0.033912226890346835, 0.09782744704612664, 0.023064713160108243, 0.04146517999470234, 0.038895065763166974, 0.06849310932947056, 0.0779669713228941, 0.017565186833962798, 0.015401565968724234, 0.07044302219791071, 0.025368203841415898, 0.03186894760334066, 0.032337815301226716, 0.08560169807502202, 0.03896750955443297, 0.04249637680394309, 0.023162076149934104, 0.06850813888013363, 0.07341801827507359, 0.03720444148140294, 0.057959165291062424, 0.04071382459785257, 0.041549111383834055, 0.02554498426616192, 0.04098523860531194, 0.016514315901856338, 0.027133567059146504, 0.031009637285023928, 0.01757072876872761, 0.09475097605692488, 0.038598478106515746, 0.04961613279634288, 0.01826339597547693, 0.04070730387632336, 0.06710226860429559, 0.059263777786067555, 0.03633399301075509, 0.08450141283018248, 0.017064037832564542, 0.015336031360285622, 0.05166433146223426, 0.032422560932380814, 0.022015036449634602, 0.039136305318347046, 0.012922264319578452, 0.058513623396200795, 0.04941016688410725, 0.08290515241346189, 0.07431034610739776, 0.0409847534527736, 0.060659802518785, 0.046607101402644596, 0.010958328676809157, 0.07404834338064704, 0.14584865953241075, 0.16544329880603723, 0.14475729023771627, 0.15995893095220837, 0.14626875413315638, 0.15409676837069647, 0.18063136882015637, 0.13322490906076773, 0.18799480370112828, 0.08585187393639769, 0.17196041052894934, 0.21465908576335224, 0.1578089113214186, 0.15332215279340744, 0.08104770351201296, 0.07853460657809462, 0.1731067140187536, 0.10338537488132715, 0.09391871214445148, 0.11894746018307549, 0.09546446241438389, 0.13626751436718873, 0.22676757031253406, 0.11846024489828519, 0.07483868061431817, 0.16058391598718508, 0.1392234843224287, 0.1969355203743492, 0.20735620334744453, 0.25594837591052055, 0.10780511450554643, 0.16830902360379696, 0.19660002551972866, 0.10397626353161675, 0.11227273156068154, 0.12616517288344248, 0.15145192029220717, 0.2096005529165268, 0.16328394253339085, 0.19537096789905004, 0.1329609453678131, 0.16143261401781014, 0.1512501782604626, 0.0793599019359265, 0.09857773714299713, 0.1481376974178212, 0.13649694062769413, 0.1266015794660364, 0.11637153769178049, 0.15916945545801095, 0.09590536768415145, 0.13816197056855473, 0.1582521711077009, 0.1286367095474686, 0.19453453778156213, 0.14909038772540434, 0.1449981837400368, 0.1885988355747291, 0.19303762167692184, 0.10881594169352736, 0.1081105163320899, 0.1107425604547773, 0.12205463488187109, 0.1312867280628, 0.20905741277549947, 0.19037890434265137, 0.5029994749597141, 3.029246526105063, 17.11879277229309, 36.179610524858745, 52.94584648949759, 84.30031871795654, 88.1329242161342, 109.60269805363247, 113.30756092071533, 128.75637326921736, 143.25121879577637, 141.9437484741211, 139.83499799455916, 135.3961969103132, 131.63258007594516, 134.1553737095424, 130.5828184400286, 118.8461993081229, 119.94568225315639, 128.64484078543526, 131.93688338143485, 135.8877958570208, 122.99210602896554, 125.95340047563825, 134.62910188947404, 137.72981888907296, 134.30467660086495, 142.5188786642892, 142.96638434273856, 148.24338831220354, 149.73662567138672, 145.80343110220772, 141.6485195159912, 122.89430318559918, 92.44817243303571, 65.35775756835938, 44.5103304045541, 19.837258100509644, 9.429373383522034, 2.3666005177157263, 0.26359009157334057, 0.6599038041063717, 0.2507843444389956, 0.21085124223359994, 0.09495959843375854, 0.2188232144606965, 0.13699953151600702, 0.1624518550400223, 0.15511539871139185, 0.10153564770839044, 0.15040289158267633, 0.2282053588756493, 0.14758231650505746, 0.09071597935897963, 0.18985294470829622, 0.14651035331189632, 0.10471168692622866, 0.1918448656797409, 0.08161301139209952, 0.12197437775986535, 0.11173485006604876, 0.17174854475472653, 0.13651022634335927, 0.09421976456152541, 0.13658523160432065, 0.13559169348861488, 0.10231601726263762, 0.08969834646476166, 0.06280473992228508, 0.15522625776273863, 0.12416775577834674, 0.09755788543926817, 0.12653637225074427, 0.2034943891423089, 0.18473238019006594, 0.15937047824263573, 0.09668993058481387, 0.1528301199099847, 0.2540707609483174, 0.10402991529554129, 0.15154815012855188, 0.09876520279794931, 0.1755697147122451, 0.14863327225404127, 0.11138023409460272, 0.19341001526585647, 0.16314899548888206, 0.15009478240140847, 0.1231955915157284, 0.1241271115307297, 0.1416722900633301, 0.1111200905538031, 0.1029016472665327, 0.0989198884261506, 0.09755806864372321, 0.15053090399929456, 0.1620075095977102, 0.20955046346145018, 0.12253533623048238, 0.1030047099505152, 0.06819677273077623, 0.16154778855187552, 0.14807056316307612, 0.1472777628472873, 0.23959150218537875, 0.12488940491208009, 0.15018791811806814, 0.07817261493099587, 0.12017874339861528, 0.12550894809620722], [0.047075161643858464, 0.02316855955203729, 0.04697509469198329, 0.07210018791790519, 0.07975240051746368, 0.01409341745810317, 0.044551045301237276, 0.06198955473623105, 0.03850133564057095, 0.02562224565606032, 0.007735854763138507, 0.031636878448937616, 0.012649150581897368, 0.060059258315180025, 0.04459146223962307, 0.050089818092861345, 0.03065614428903375, 0.02431952627375722, 0.06579825322010688, 0.053072311981980286, 0.014157179393805563, 0.013394467017081167, 0.041901342304689546, 0.03383858887744801, 0.025598083024046252, 0.03799712983891368, 0.04077274179352181, 0.07985036061810595, 0.023623486747965217, 0.023084539953353148, 0.061036090898726664, 0.0747314788667219, 0.022009526745283177, 0.022660691357616867, 0.002036283803006102, 0.04259761083605034, 0.020213766855054667, 0.06965622691703693, 0.0281123300748212, 0.053656099763299735, 0.023917999783796922, 0.046415537396179776, 0.05269917200452515, 0.049597266130149364, 0.047569155493485074, 0.06189498731068202, 0.05282365603904639, 0.01062292796892247, 0.04229022768725242, 0.08599096004452024, 0.060889242349990776, 0.06992264012140886, 0.0989111013976591, 0.013152356392570903, 0.12311964987644128, 0.048292673991194794, 0.03209271148911544, 0.047549942774432044, 0.12374930323234626, 0.007583063095808029, 0.0557339741582317, 0.11990680013384138, 0.10004994100225822, 1.315789595246315, 12.098473497799464, 28.986529622759136, 35.64261899675642, 66.59165341513497, 88.76288264138358, 99.42469188145229, 103.40150029318673, 90.24245289393834, 81.22452490670341, 83.97421891348702, 79.32417869567871, 78.72486182621547, 68.21971361977714, 74.35459777287075, 69.4654700415475, 73.45390973772321, 69.26388195582798, 65.13339328765869, 75.66471535818917, 84.37997286660331, 58.531986236572266, 59.70695441109793, 77.17521204267229, 71.74302700587681, 78.60290009634835, 79.03592572893415, 75.3287352153233, 85.78883130209786, 82.62114061628068, 80.41146755218506, 88.07402433667863, 84.64764526912144, 77.55260344914028, 79.1285035269601, 90.85779925755092, 86.90301663534981, 99.12213257380894, 105.80076885223389, 102.47741767338344, 106.72071034567696, 84.29425988878522, 66.51958669934953, 37.45183610916138, 12.304637840815953, 1.3670483018670763, 0.18687024047332151, 0.2474030687340668, 0.2113194449671677, 0.08602244406938553, 0.10984987299889326, 0.040829484284456284, 0.016090501232870986, 0.03648677534822907, 0.02229581763302641, 0.045665718881147246, 0.03751107145633016, 0.031832819006272724, 0.01161667303780892, 0.06879732371973139, 0.05787548156721251, 0.030333809621099914, 0.010189977674079793, 0.026053912671548978, 0.05074271127315504, 0.09109986733113017, 0.06870482582598925, 0.03575954187129225, 0.021377135500577942, 0.04174399342654007, 0.046361546364745924, 0.025919058925605247, 0.04756548461903419, 0.06986425896840436, 0.042898544509496005, 0.026732427334146838, 0.04617109176303659, 0.021776008918615322, 0.012532592684562718, 0.04828022626627769, 0.04275931251634445, 0.04132389882579446, 0.055950626997011046, 0.038475832901895046, 0.10555184898631913, 0.03166019291217838, 0.02814688447064587, 0.08590974618813821, 0.05817139068884509, 0.07852818085146801, 0.021754495965849076, 0.006068577175028622, 0.011834705847182443, 0.04423607952360596, 0.09054931080234901, 0.044133264504905255, 0.05550901944349919, 0.008575742016546428, 0.0512960701515632, 0.02091963665692934, 0.04731624513598425, 0.014214864200247186, 0.04654682035158787, 0.04335767862253955, 0.08552344941667148, 0.044139476493000984, 0.054000547887491326, 0.02287935435638896, 0.06680103976811681, 0.07188190998775618, 0.028148304305172393, 0.009380879795311816, 0.04794455159987722, 0.04245208543060081, 0.04570213585559811, 0.07327022656266179, 0.06413960829377174, 0.06138943122433765, 0.04396954418293067, 0.047272812109440565, 0.01796649449637958, 0.02961082038070474, 0.03850987161110554, 0.034089331315564256, 0.04227553740409868, 0.03163464606872626, 0.07792473930333342, 0.021645565650292804, 0.02283127506130508, 0.04489729832857847, 0.04733816520976169, 0.07772975548037461, 0.06653444335928985, 0.07344337512872048, 0.019948094950190613, 0.01532385335303843, 0.03713271693725671, 0.07294839740331684, 0.029271661436983516, 0.048177696232284815, 0.04340492840856314, 0.03340726112946868, 0.019879266054236462, 0.07557096917714391, 0.04849311662837863, 0.01212159893475473, 0.011097270596240248, 0.013578725745901465, 0.01958202530762979, 0.026413488733981336, 0.03238437298153128, 0.029049919585564306, 0.04704825094501887, 0.02887896608029093, 0.057137805436338694, 0.026931328000500798, 0.02199000190012157, 0.07683967359896217, 0.05672144277819565, 0.01887891035793083, 0.05215928204623716, 0.10448907315731049, 0.026869031700438688, 0.0005361689358583785, 0.020096437972305075, 0.05794257510985647, 0.025065339735842178, 0.06054382052804742, 0.04745890373097999, 0.031526799712862284, 0.06572894086795193, 0.15686471627226897, 0.02147055620194546, 0.023414067092484663, 0.10159112473151513, 0.4979051426053047, 3.381881935255868, 20.266693251473562, 44.910112380981445, 52.812027658735005, 86.29563985552106, 107.7625788279942, 115.65325886862618, 115.14173248835972, 105.39891978672573, 97.9937173298427, 97.02876540592739, 95.1137307030814, 95.85153211866105, 85.10662242344448, 91.13093989236015, 90.20072201320103, 96.95122350965227, 95.25573798588344, 93.18375042506626, 100.1825180053711, 106.81635229928153, 80.22437340872628, 91.97991943359375, 106.17474174499512, 96.76054409572056, 97.46741907937187, 104.43883160182408, 107.48486627851213, 106.78088174547467, 95.69380106244768, 92.51679284232003, 111.39260959625244, 113.83406066894531, 92.93052332741874, 91.75376946585519, 100.87558691842216, 98.40487003326416, 111.13603346688407, 122.62750625610352, 120.62400708879743, 128.99594715663363, 110.06570516313825, 92.91527203151158, 56.53974315098354, 23.77676510810852, 3.8858126316751753, 0.17580802978149482, 0.09558287356048822, 0.1686213125607797, 0.17571687538708958, 0.024063151994986192, 0.07086750692022697, 0.02349228860943445, 0.03289610712922045, 0.04008958934407149, 0.022191725272153105, 0.0583429786243609, 0.05451513188225882, 0.06317029387823173, 0.006183568080554583, 0.01692107559314796, 0.06361493787595204, 0.030542771265442883, 0.0506022647023201, 0.031399218165980916, 0.048584328698260446, 0.07041584687041384, 0.02558335711780403, 0.04717927605711988, 0.03072411653452686, 0.062227245553263595, 0.02469495969957539, 0.017183867116857852, 0.043128052194203646, 0.03131161590239831, 0.01133059079958392, 0.042448960776839934, 0.032037261607391496, 0.057922252986047945, 0.02513506599435849, 0.009830167517066002, 0.030008143346224512, 0.03643416513555816, 0.05263707247961845, 0.022400111858067766, 0.016879354171188812, 0.048056411490376504, 0.08129935857972928, 0.05485972589147942, 0.05787288277809109, 0.02320686455017754, 0.04750406023647104, 0.03911049723891275, 0.05085498846269079, 0.0653378264978528, 0.007333506397636873, 0.02783178468234837, 0.015569452495713319, 0.059676652774214745, 0.03291328763589263, 0.03137773235461541, 0.016548737983352373, 0.03874356924955334, 0.007556465371245784, 0.049033905645566325, 0.025201447075232863, 0.042022019757756164, 0.019450496383277432, 0.07621469534933567, 0.028976824400680404, 0.04021394445693918, 0.05602731841749378, 0.03572683987606849, 0.22808875941804477, 0.1332861129194498, 0.12553112262061664, 0.10983923356980085, 0.09565228769289595, 0.17034831989024365, 0.17933278850146703, 0.12961337928261074, 0.10434530515755926, 0.09559665460671697, 0.09334092600537197, 0.16073267800467356, 0.10917794012597629, 0.12785129169268267, 0.22796347471220152, 0.1428121067583561, 0.13779041836304323, 0.1119035135156342, 0.11181874413575445, 0.15027082152664661, 0.14323946168380125, 0.11225748487881251, 0.10695365483739547, 0.11190087401441165, 0.20724203304520675, 0.09785881572003875, 0.2442584117608411, 0.17418991375182355, 0.12047052702733449, 0.07956049724348954, 0.12285666327391352, 0.13144545097436222, 0.06239590221749885, 0.12399076670408249, 0.12027908515717302, 0.13365738014025347, 0.13724873028695583, 0.20700739563575812, 0.10885436713163342, 0.09877180494368076, 0.11226076898830277, 0.14418467453547887, 0.11788823987756457, 0.11466548352369241, 0.13717124158782618, 0.16170100175908633, 0.09623514927391495, 0.15089994562523706, 0.20525419685457433, 0.154997659314956, 0.1370868454022067, 0.19370812284094946, 0.23305446867431912, 0.09793356313769307, 0.18479739741555282, 0.1588888405156987, 0.1273233507360731, 0.16172609398407595, 0.2271864435502461, 0.24771546625665256, 0.1290863204215254, 0.3659340169812952, 0.5187083206006459, 2.780338385275432, 20.620146376746042, 46.99729217801775, 56.763155528477256, 94.7637082508632, 119.45173481532505, 127.25900868007115, 134.4900406428746, 115.88915021078927, 107.11154651641846, 107.77391828809465, 101.71507522038051, 100.45733315604073, 88.99438272203717, 97.95007569449288, 95.0321102142334, 98.69217804500035, 94.48245906829834, 89.02514934539795, 98.31612069266183, 116.15079852512905, 82.38867473602295, 88.38423361097063, 104.09786265236991, 96.51395947592599, 106.7305976322719, 107.0931476865496, 102.71108559199742, 113.7933303288051, 108.31332084110805, 105.18436636243547, 113.66171060289655, 110.5940739767892, 104.90932192121232, 103.02280262538365, 113.411422593253, 113.59065832410539, 127.16337367466518, 137.76241983686174, 138.2403586251395, 143.3798438480922, 121.71862629481724, 101.88743223462785, 59.40475640978132, 22.573415279388428, 3.5902436460767473, 0.2601956251476492, 0.34871887788176537, 0.3055008112319878, 0.32091072148510386, 0.2006343776094062, 0.22572540837739194, 0.06560352045510497, 0.16306098949696335, 0.15987704534615788, 0.10194194090685674, 0.19590622346316064, 0.22988269744174822, 0.08334725190486227, 0.18598241811352118, 0.11428026562290532, 0.10804328708244221, 0.12259799215410437, 0.17370058143777506, 0.1899340432137251, 0.17767762445977756, 0.12612880340644292, 0.17265409044921398, 0.10106329912585871, 0.14960090390273503, 0.13711547957999365, 0.15513603974665913, 0.14937253615685872, 0.12935176332082066, 0.11353450135460921, 0.10249959491193295, 0.10423935869974749, 0.09280282059418303, 0.166884235771639, 0.19971933242465767, 0.12344712444714137, 0.11548290108995778, 0.07941305836928741, 0.18320065523896897, 0.1917116828262806, 0.07921398298016616, 0.1014721096892442, 0.21437962433057173, 0.11529122851788998, 0.18817415407725743, 0.09157363405185086, 0.1192850720669542, 0.15720475731151445, 0.22113944802965435, 0.15733192834470952, 0.1343616587775094, 0.12782439456454345, 0.07112591341137886, 0.11297707126608916, 0.1060496833441513, 0.10535932146012783, 0.07203823088535241, 0.1476875301450491, 0.1170719215380294, 0.10193587480379002, 0.10301386338791677, 0.1603421132479395, 0.10038027899073702, 0.1289146782032081, 0.17179681573595318, 0.08211343775370292, 0.10445900727063417, 0.12141044730586664], [0.11029468663036823, 0.04554451895611627, 0.041925789921411445, 0.029906831282590116, 0.06835996718811137, 0.05932596552052668, 0.04000228902857218, 0.04544660296025021, 0.0811914172289627, 0.02075232858104365, 0.07814863550343684, 0.04524610943293997, 0.05653503563787256, 0.02156399386668844, 0.07543515360781125, 0.03035130225388067, 0.01904885793503906, 0.049424521292426755, 0.03989757411181927, 0.035802930793059726, 0.05416260579867022, 0.0408751089791102, 0.0346166446272816, 0.04488513219569411, 0.03616888169199228, 0.0361093300660806, 0.021753347545330013, 0.017552764554108893, 0.01260321885014751, 0.028291919634544423, 0.03630777781030961, 0.008907230121881833, 0.03852255003792899, 0.005779033984124128, 0.03989952829267297, 0.014170370962736862, 0.021876620394842963, 0.030151246381657462, 0.017078036009999256, 0.024941512183951478, 0.026466319470533302, 0.02051593885490937, 0.041778751382870336, 0.06787265690841846, 0.10072620292859417, 0.025434469571337104, 0.05563240425129022, 0.001954436152508216, 0.06118761455374105, 0.027075598116165826, 0.054283575021794865, 0.03467881200569017, 0.029620031493582895, 0.05229072445737464, 0.04088943963870406, 0.04281226878187486, 0.06187870247023446, 0.04418466692524297, 0.13438087488923753, 0.04425973664703114, 3.1506413263933997, 19.204867805753434, 40.22026593344552, 67.73098427908761, 96.52238069261823, 98.77823843274797, 90.51808793204171, 81.45749105725969, 74.05584607805524, 69.78162697383335, 65.42056233542306, 89.64740221840995, 61.24365275246756, 75.0102367401123, 83.0570775440761, 55.82012864521572, 61.25493662697928, 64.05828462328229, 62.73068537030901, 62.20025988987514, 33.032722745622905, 36.74206372669765, 45.11086320877075, 46.74520805903843, 45.82385608128139, 28.233933755329677, 39.6427629334586, 53.98483146939959, 60.40784004756382, 53.67424699238369, 48.06209666388375, 59.94493021283831, 81.82873330797467, 65.59439931597028, 64.8397137778146, 62.23276356288365, 68.50660473959786, 67.53663621629987, 98.15101759774345, 97.81746237618583, 62.34865256718227, 79.36025374276298, 71.48092705862862, 84.40756416320801, 92.55769688742501, 100.92937292371477, 100.09713159288678, 92.63040283748082, 70.96676731109619, 36.426191670554026, 18.716152361461095, 9.595956444740295, 2.1818898235048567, 0.16910157964697906, 0.12837940906839712, 0.11699323861726693, 0.10830459091812372, 0.09753174827034984, 0.05578877603901284, 0.0674602636801345, 0.04240864561870694, 0.03016714784981949, 0.03514569498864668, 0.04890135382967336, 0.04439040892092245, 0.014857815146180136, 0.04928341314994863, 0.07714749101017203, 0.04094653496784823, 0.02469621498935989, 0.038780613868896446, 0.03957215550222567, 0.048807203703160794, 0.015043138326810939, 0.01767275668680668, 0.006659521380372877, 0.023061844653316906, 0.03155719468902264, 0.044689517335167954, 0.03597388090565801, 0.014321545172216637, 0.00892611884046346, 0.014630453328468969, 0.025041979471487657, 0.061145199329725335, 0.07301148080400058, 0.03214162368593471, 0.016977972450799177, 0.06217728501984051, 0.056934136365141184, 0.051579389055924754, 0.02034190988966397, 0.06423360574990511, 0.007829432375729084, 0.04935928015038371, 0.03654033211725099, 0.02857661426865629, 0.06638462961252246, 0.0281424027468477, 0.011495608819781669, 0.06887268860425268, 0.013158091709816029, 0.04211160334359322, 0.035280143309916766, 0.037507078277745416, 0.04155862444479551, 0.02295121460753892, 0.06158893409052065, 0.03072146006992885, 0.041239258367568254, 0.013230329396070113, 0.04047234416274088, 0.08508970269135066, 0.01473323442041874, 0.08749044101153101, 0.03336244389148695, 0.10072092392614909, 0.08541545378310339, 0.04843839956447482, 0.10669883779649224, 0.02614676849251347, 0.05303331996713366, 0.04068341265831675, 0.018077455327979157, 0.057736212254634926, 0.01924512249284557, 0.05006606597453356, 0.06816378914351974, 0.04178852567981396, 0.05841694572674377, 0.04598255402275494, 0.021582129411399364, 0.013920341834558972, 0.07148451916873455, 0.024940107616462877, 0.05552415077441505, 0.03475910644712193, 0.02629379346035421, 0.06798101216554642, 0.016911944208134497, 0.03463070387286799, 0.011935566685029438, 0.11618067936173507, 0.05739237820463521, 0.04723547572003944, 0.06962080060371331, 0.04635922238230705, 0.05722716849829469, 0.05419678021488445, 0.037360918442053456, 0.09869241634649889, 0.01363087709926601, 0.052958908424313576, 0.01797079131938517, 0.02313713150631104, 0.058058014272579124, 0.011482410465500184, 0.0040211164159700274, 0.032894142770341465, 0.05661212060866611, 0.01777020618984742, 0.05976691150239535, 0.03095631461058344, 0.06679695498730455, 0.0770639633493764, 0.048329993417220454, 0.048777948665831766, 0.04299996513873339, 0.04263961554637977, 0.05894920216607196, 0.01855804132563727, 0.0465946502850524, 0.08300146367400885, 0.015110250529167908, 0.06250585881727082, 0.15225603857210704, 6.696732861655099, 32.39159509113857, 57.469783851078574, 88.59058816092355, 112.97385283878872, 114.58571679251534, 105.30231203351701, 93.27460506984166, 87.10200609479631, 91.95297431945801, 86.6678409576416, 107.43974467686245, 74.49921063014439, 106.07640389033726, 105.20668397630963, 90.66625826699394, 93.74995912824357, 92.2076119014195, 97.87110246930803, 85.06257084437779, 71.53924328940255, 60.05909606388637, 71.82989338466099, 80.6052806036813, 68.94279180254254, 48.989997318812776, 64.39816965375627, 84.03935132707868, 86.19466863359723, 86.30623585837228, 79.4214951651437, 84.72340842655727, 116.62294251578194, 105.14172526768276, 95.46693543025425, 89.68650668007987, 100.38279982975551, 97.4466370173863, 126.19743510654995, 120.39632851736886, 84.02519784654889, 99.68463093893868, 89.34403691973004, 94.29270376477922, 102.06974601745605, 112.96902384076799, 116.77143941606793, 111.41806084769112, 95.62857832227434, 59.079177720206125, 33.76108850751604, 20.5546543938773, 7.450699261256626, 0.11611255444586277, 0.12684792838990688, 0.11030354829771177, 0.030000411439687014, 0.0915049866640142, 0.06086214166134596, 0.08743222949228116, 0.013034047026719366, 0.0632771427876183, 0.008712169963733425, 0.014690469750868422, 0.038670012660856755, 0.06499100010842085, 0.042191304066883664, 0.04425515653565526, 0.034804541151970625, 0.0716728533485106, 0.0356273327155837, 0.01874589883456273, 0.04625308593469007, 0.022891009891671792, 0.078706106304058, 0.05213148246652313, 0.04405406929020371, 0.014649778005800076, 0.05000828193234546, 0.031599759190742455, 0.016544610794101442, 0.018199459317007234, 0.021737122076696584, 0.02151952268156622, 0.037569225300103426, 0.037473663820752075, 0.03147156696234431, 0.028570992606026784, 0.009540489043242164, 0.05953063882355179, 0.01984292032596256, 0.0547820234538189, 0.05090524415884699, 0.038485725942466936, 0.05535069686759796, 0.053704631980508566, 0.004378569511962789, 0.027342983321951966, 0.02968574082478881, 0.014201354568025895, 0.0355579016198005, 0.05737802718899079, 0.06392002757638693, 0.03864677622914314, 0.04269863452230181, 0.030579306983522007, 0.025872898188286593, 0.03776112857407757, 0.05365547211840749, 0.06649403659892933, 0.06145496413643871, 0.02004567507122244, 0.055570823805672784, 0.027586299194289104, 0.041531265912843604, 0.10708242721323456, 0.24678956451160566, 0.12160891879882131, 0.1383858057005065, 0.12220744096807071, 0.11968106510383741, 0.15402649928416523, 0.21392556226679257, 0.11027466306196791, 0.13602206110954285, 0.1137398396219526, 0.2028469174568142, 0.1117502935230732, 0.1257978683071477, 0.1168419388788087, 0.1516266159181084, 0.08467546384781599, 0.16121464142841951, 0.18824774798538002, 0.08689658037785973, 0.25256965149726185, 0.1489859747567347, 0.11564519309571811, 0.16336509532162122, 0.11577530897089414, 0.15748822210090502, 0.10435217193194798, 0.14296442429934228, 0.1634462345391512, 0.11284288418080125, 0.09143710602074862, 0.10904155458722796, 0.14140816352197103, 0.24376164270298822, 0.12646936013230256, 0.2509491741657257, 0.07728901305901152, 0.12958713354808943, 0.09324506936328751, 0.1497885731181928, 0.1403139850922993, 0.11767346997346197, 0.05922518949955702, 0.18022278217332705, 0.22344642638095788, 0.21853761907134736, 0.10958409761743886, 0.0713824810726302, 0.11232774717999355, 0.1975315319640296, 0.12233283423951694, 0.18590366733925684, 0.12729285737233503, 0.1253645694149392, 0.15533653327396937, 0.17856396761323723, 0.13664258138409682, 0.18452949821949005, 0.16254249374781335, 0.2524936284337725, 0.2105504340891327, 6.177095762320927, 33.22280461447579, 59.4465845652989, 95.44033772604806, 125.4970566885812, 124.28417914254325, 117.54120254516602, 104.08297266278947, 93.80898407527378, 92.25604779379708, 88.67345932551792, 112.03392137799943, 83.57451684134347, 100.21036638532365, 107.75916031428746, 79.78810991559709, 88.09230504717145, 88.16922160557338, 88.56661687578473, 86.46498135157994, 52.58408505575997, 58.103080885750906, 64.82039778573173, 71.36625398908342, 66.07150432041713, 45.2599333354405, 58.73452622549874, 77.25458826337541, 82.1588213784354, 73.0636989048549, 65.3020886012486, 84.13165814535958, 107.18249457223075, 93.87183053152901, 87.25160775865827, 85.92967128753662, 97.5138191495623, 95.2425503049578, 129.7747985294887, 127.37151391165597, 91.09027903420585, 104.71936511993408, 95.86669308798653, 108.07979883466447, 113.77375725337437, 124.48667744227818, 130.09322057451521, 126.44299834115165, 104.94265242985317, 60.676561628069194, 32.7829384803772, 19.617741925375803, 6.073155054024287, 0.1909399035253695, 0.2371304285313402, 0.27502215813313213, 0.1897995982851301, 0.16187124619526522, 0.1365869686539684, 0.17375072517565318, 0.13235746989292757, 0.1803247117038284, 0.15390154027513095, 0.1768597454896995, 0.22091458152447427, 0.18542611439313206, 0.18301994779280253, 0.19299154914915562, 0.1035894782149366, 0.07950265891849995, 0.13758508009569986, 0.13398580465997967, 0.1161838820470231, 0.08068738784641027, 0.1548779657376664, 0.16645632444747857, 0.1885868797877005, 0.09906947147101164, 0.11175432402108397, 0.17772254347801208, 0.18087074240403517, 0.10869666202259914, 0.12903756089508533, 0.10723836813122034, 0.08355924660073859, 0.14029585463660105, 0.17851560163710797, 0.12138880203877177, 0.15051665476390294, 0.20079235413244792, 0.11722216276185853, 0.15196981893054076, 0.20521680957504682, 0.10974741421107735, 0.16634117705481394, 0.15242356886821135, 0.030510778339313607, 0.11476780660450459, 0.08506957734269754, 0.12257315777242184, 0.1282960306853056, 0.1228063702583313, 0.10839977581053972, 0.12965031872902597, 0.10042479088796036, 0.07341113114463431, 0.1431306925203119, 0.1463002110166209, 0.13334070784705027, 0.11898963791983468, 0.12462071861539568, 0.052476680371910334, 0.12248082272708416, 0.08560867341501371, 0.11832643779260771, 0.18580130354634353], [0.08566121916685786, 0.10422517053250756, 0.10553709084966353, 0.023746096329497438, 0.026297644146585038, 0.024175054293924143, 0.04108509181865624, 0.04578170765723501, 0.03228212793224624, 0.03507560571389539, 0.024916138366929123, 0.055322758188205104, 0.05966299386428935, 0.008347071474418044, 0.04297727492770978, 0.048144638006176264, 0.02572086902468332, 0.029760179509009634, 0.05874296144715377, 0.03378464195079037, 0.013405629766306706, 0.10270923509129457, 0.05460095638409257, 0.0238880390700485, 0.01771943989608969, 0.025119232379698327, 0.06305068851049457, 0.04308643764150994, 0.06680804224950926, 0.06460120209625789, 0.04386339755728841, 0.062071148572223525, 0.04610322808314647, 0.0804440380473222, 0.024254761802564775, 0.06920327765068837, 0.02448544335285468, 0.020817657932639122, 0.05470721496801291, 0.04115352886063712, 0.06697957590222359, 0.02832733576984278, 0.048217522845204384, 0.03595878350149308, 0.09645401752953019, 0.025530840203698193, 0.01221871086662369, 0.008759401090043997, 0.034285329548375945, 0.044664543853806596, 0.07076925504952669, 0.046479051666600366, 0.018363900582439134, 0.01610695061806057, 0.10813659243285656, 0.0272624666603016, 0.042263123605932505, 0.17004314198025636, 11.81052017211914, 34.78155306407383, 64.06690038953508, 89.3825785773141, 85.42976924351284, 75.09733935764858, 62.51588181086949, 62.41215910230364, 52.17111192430769, 66.7916920525687, 58.93557235172817, 48.218048981257844, 73.28681945800781, 56.08583470753261, 58.50893211364746, 31.316795621599468, 51.99169206619263, 34.49575628553118, 29.165612493242534, 27.417661121913365, 27.406073263713292, 56.090232917240684, 26.69195130893162, 35.71397352218628, 29.99473408290318, 26.758664437702723, 32.65041548865182, 59.26977375575474, 52.85153859002249, 32.69561004638672, 29.981869493212017, 24.190073490142822, 37.24742010661534, 45.76884719303676, 29.195111070360454, 24.39425846508571, 59.05840955461775, 48.752292496817454, 27.616671425955637, 45.20091533660889, 53.23361308234078, 67.57009874071393, 56.47566686357771, 69.68201759883335, 80.15602397918701, 95.75338881356376, 69.20685808999198, 77.92776448386056, 77.24874482836042, 83.53166035243443, 77.74152496882847, 93.16091169629777, 92.06106049673897, 100.70451532091413, 75.97085298810686, 39.87874460220337, 9.889809659549169, 0.83575125677245, 0.07246986058141504, 0.29688800339187893, 0.012235971949329334, 0.05811444124472993, 0.042254560493997166, 0.056046666843550544, 0.03295532627297299, 0.07722668961754867, 0.05089729172842843, 0.030948949112956013, 0.05232589632006628, 0.02667818863743118, 0.04692630463146737, 0.04201293756653156, 0.03717324922659567, 0.06986889336258173, 0.05732813450906958, 0.013506356593487518, 0.037781745860619206, 0.06036560330539942, 0.07040151621082, 0.01530023354903928, 0.010028856989395405, 0.07195230799594096, 0.06345034563647849, 0.030486106806035553, 0.04434641271031328, 0.06876178205545459, 0.021198104035907557, 0.025729155633598566, 0.051024510259074826, 0.01648957821141396, 0.03506096971354314, 0.024598992795550396, 0.05082383013463446, 0.038477325678936074, 0.03203666449657508, 0.10005160341305391, 0.05973486429346459, 0.019027723265545707, 0.041232299990952015, 0.021444688750697032, 0.040454044073287926, 0.02319241514695542, 0.04156355739438108, 0.024481399284143533, 0.02750907851649182, 0.05312193664056914, 0.02995223884603807, 0.014636270069916333, 0.028892438393086195, 0.03611524010609303, 0.038528100454381535, 0.03359555120446852, 0.06003842729010752, 0.05985315330326557, 0.08338606410792895, 0.0431743622092264, 0.12496382663292543, 0.052598528297884126, 0.05976391237761293, 0.0718589551480753, 0.1211018767207861, 0.0396998049026089, 0.02689011887248073, 0.061301988416484425, 0.09103181705410991, 0.09076948863055025, 0.04027726534487946, 0.04284806489678366, 0.02832145626390619, 0.06479714265359299, 0.06134447827935219, 0.03931575747472899, 0.047269836733383794, 0.05223186154450689, 0.05040090943553618, 0.03801856815282788, 0.030107776035687754, 0.036415658092924526, 0.03158244636974164, 0.02639873229366328, 0.04756130145064422, 0.02205277487103428, 0.0433647319940584, 0.010214573720337024, 0.010907339314664049, 0.015880869535197104, 0.07331201753446034, 0.05321471273366894, 0.027600114167268788, 0.006475282159434366, 0.09542607090302876, 0.0364428809178727, 0.04108030814677477, 0.06970774808100291, 0.022536678904933587, 0.015216315730607935, 0.027167788972812038, 0.02951876014204962, 0.017426054924726486, 0.033658719422029595, 0.07605137875569717, 0.02284688306307154, 0.0696439454331994, 0.054038427104907374, 0.04377574101090431, 0.04391267955569284, 0.014944309701344796, 0.019173369110961045, 0.04815027663218124, 0.12326588774366037, 0.03449694087196674, 0.05792616134775536, 0.15467748578105653, 0.07599804590323142, 0.03367246654150741, 0.5418707377144268, 21.02436477797372, 52.51899085726057, 83.52751922607422, 100.05316339220319, 99.61829648699079, 84.89556394304547, 76.02535465785435, 76.95988042013985, 74.68376173291887, 93.61969430106026, 79.2427110671997, 76.17043999263218, 91.81936740875244, 88.6342853818621, 73.90384033748082, 53.29836681910923, 69.86285141536167, 43.9630138533456, 37.06912933077131, 38.90472527912685, 34.18045398167202, 69.70500223977226, 25.417078460965836, 41.25858041218349, 37.120129108428955, 35.15540436335972, 36.39149931498936, 55.60650627953665, 53.09679610388619, 37.177135603768484, 43.478682722364155, 32.43500048773629, 42.756427901131765, 56.78303779874529, 51.85130718776158, 36.31182084764753, 67.35384995596749, 69.03783621106828, 42.401576450892854, 63.965824944632395, 91.61017799377441, 98.43883282797677, 82.11649990081787, 105.94283866882324, 120.63862609863281, 118.1819098336356, 99.3907082421439, 102.4767506463187, 95.73676177433559, 97.93302481515067, 93.1200145993914, 104.89702360970634, 112.98665142059326, 121.83085359845842, 99.89279202052525, 60.96749659946987, 19.931995051247732, 1.8846906168120248, 0.05992072182042258, 0.44880588725209236, 0.037538185715675354, 0.009291705874992269, 0.04689630659829293, 0.04200506656031523, 0.06895099154540471, 0.08919409316565309, 0.015830749546044638, 0.03245060817737665, 0.08157991923924003, 0.03665894343118582, 0.044395620069865666, 0.03415953254859362, 0.020768990008426563, 0.053397354004638534, 0.041750181665910144, 0.07806414432291474, 0.018730436717825275, 0.038764977029391696, 0.02554136767451252, 0.05967821340475764, 0.02955549942063434, 0.0942567650760923, 0.03906189377552696, 0.03362197335809469, 0.04150566478659, 0.016981215848188316, 0.02679704422397273, 0.058968011156788895, 0.03410250507295132, 0.04961173249674695, 0.02980498317629099, 0.03027184580319694, 0.042877574384744675, 0.05602031254342624, 0.004583112621081195, 0.034624610628400526, 0.01911306770385376, 0.011786814845566238, 0.04204513405316642, 0.008685109139020954, 0.08010219210492713, 0.010655102403169232, 0.04518814557897193, 0.03161623062832015, 0.028146772512367794, 0.09998527661498104, 0.05170807322221143, 0.0442553363474352, 0.0272267214355192, 0.035659254395536015, 0.06556594318577222, 0.0249243062322161, 0.0433711102232337, 0.025353561055713465, 0.0434565072480057, 0.1039298992337925, 0.06045646592974663, 0.04592925509704011, 0.17024586110242776, 0.12982634428356374, 0.12478690541216306, 0.11671400788639273, 0.1434267916317497, 0.15334428660571575, 0.2431286780961922, 0.12495515495538712, 0.09834168159535953, 0.07920083297150475, 0.09858680915619646, 0.18802753623042787, 0.1964958703943661, 0.16257665120065212, 0.1457717815147979, 0.15898013061710767, 0.09842521604150534, 0.13148184759276255, 0.11160051370305674, 0.1446702613362244, 0.12981449706213816, 0.22800073985542568, 0.17602543240146978, 0.0856564287096262, 0.15579244095299924, 0.11167363942201648, 0.1272406101758991, 0.09920171794614621, 0.20941171662083694, 0.17791182760681423, 0.11278893386146852, 0.10830983599381787, 0.19271364834691795, 0.21891635017735617, 0.1308458974318845, 0.15663254873028823, 0.14531230474156992, 0.14610832131334714, 0.10243154463491269, 0.07567912087376628, 0.16412274752344402, 0.13517729858202593, 0.12031039276293345, 0.0809825641502227, 0.13793894967862538, 0.07405865032758031, 0.13782524078020028, 0.1698788007987397, 0.12154570647648402, 0.11496707876878125, 0.23741397474493298, 0.2561930827796459, 0.12491992541721889, 0.11106195367340531, 0.27374710940888947, 0.12959112333399908, 0.14931971899100713, 0.4330070950090885, 19.788721459252493, 56.57323694229126, 90.39553560529436, 117.06523704528809, 110.94417980739048, 95.9824639729091, 81.59482220241001, 81.14592688424247, 71.83364541190011, 88.6387391771589, 79.21937206813267, 66.79750769478935, 98.77957943507603, 77.05728721618652, 79.70896993364606, 42.721825872148784, 66.87821102142334, 46.3687025478908, 44.780531951359336, 39.12618521281651, 38.801721709115164, 81.04364245278495, 38.87512942722866, 55.51566553115845, 46.19572366986956, 42.269605840955464, 50.52561868940081, 84.45005239759172, 76.26620701381138, 50.20225300107683, 47.09159312929426, 38.856209482465474, 54.689615045275005, 63.90454183306013, 43.47334997994559, 36.145685945238384, 77.55384022848946, 72.10095650809151, 45.18252345493862, 66.64765589577812, 72.01120662689209, 91.0976093837193, 79.97405065808977, 95.58544390542167, 109.71092319488525, 124.30042403084892, 94.25378690447126, 105.03340979984829, 99.03084019252232, 106.17658996582031, 99.66969231196812, 119.73102460588727, 124.87460926600865, 136.48342323303223, 111.29050581795829, 64.21194403512138, 17.76448713030134, 1.6135728848831994, 0.22383179355944904, 0.6454403144972665, 0.10673148211623941, 0.18572618971977914, 0.2103317151112216, 0.14710629704807485, 0.09723871613719634, 0.29909728627119747, 0.15768305664615972, 0.07321596411722046, 0.15122302328901632, 0.10548477579972573, 0.17237722102020467, 0.21140093702290738, 0.159850378919925, 0.19094945729843207, 0.08440582760210548, 0.14094257993357523, 0.1620160319975444, 0.13240272817867144, 0.12080930599144526, 0.16344877226012094, 0.1535968780517578, 0.15814676747790404, 0.09964389207639865, 0.15088271083576338, 0.1396925827222211, 0.12623255141079426, 0.1151590363255569, 0.16401967805411133, 0.22682743067187922, 0.09322979554001774, 0.1304513564599412, 0.06370100325771741, 0.15096902049013547, 0.1970873765115227, 0.08346022120011704, 0.17711764307958738, 0.16894875999007905, 0.09125995409807988, 0.14910678113145487, 0.14677138573357038, 0.11934152618050575, 0.13443418060030254, 0.14866577408143453, 0.1558993916426386, 0.16152950881847314, 0.17119536229542323, 0.09692446621400969, 0.16628137097827025, 0.08301622859601464, 0.09110190293618611, 0.173290257741298, 0.11691699842257158, 0.16153432641710552, 0.16303877426045282, 0.09783382527530193, 0.2533406844096524, 0.1758532202137368, 0.10646496713161469], [0.019762753109846796, 0.04852604254015854, 0.01538198344808604, 0.0345126218162477, 0.09665591562432901, 0.13714971845703466, 0.011669306999205478, 0.05563286904777799, 0.02744369488209486, 0.032585874133344205, 0.059462622473282475, 0.011194191690135216, 0.018387876617323076, 0.05005870386958122, 0.015187277824484875, 0.028490036592951844, 0.0632016829081944, 0.03995126658784492, 0.016688248175861578, 0.007293069951369294, 0.012668373478975679, 0.01937737575333033, 0.0415201209751623, 0.012473766242952218, 0.010549549495668283, 0.037549876874046664, 0.009049491773891662, 0.024782044580206275, 0.0647689698796187, 0.009529671498707362, 0.06667492046420063, 0.03269299106406314, 0.04786989239177533, 0.029054106146629368, 0.07332420402339526, 0.05637694037120257, 0.017087696652327265, 0.01420231384690851, 0.10869443642773799, 0.028108671074733138, 0.06499066762626171, 0.06520070135593414, 0.024748397724969045, 0.03647994250059128, 0.04679705388844013, 0.0627136601667319, 0.08331350835838489, 0.021037603362596462, 0.03922527822266732, 0.016870618032823716, 0.04180948223386492, 0.026049666738669788, 0.02958478159936411, 0.025132285697119575, 0.10905117621379239, 0.7222210573298591, 6.016446462699345, 33.86190686907087, 74.8911098752703, 83.10731301988874, 77.72344575609479, 64.50239958081926, 52.82962397166661, 70.09962517874581, 65.27583830697196, 54.320617062704905, 62.48917988368443, 43.989368370601106, 48.4399744442531, 33.5154835837228, 31.14019673211234, 19.04476567677089, 17.7092923777444, 48.027115958077566, 35.112137930733816, 67.69560405186245, 50.51023885181972, 52.59963512420654, 59.07388319287981, 31.813491071973527, 89.1442484174456, 53.2412109375, 62.065339769635884, 50.6521349634443, 57.42166062763759, 57.52993093218122, 68.69842365809849, 83.93910271780831, 45.93432896477835, 73.59014306749616, 76.9025160925729, 39.215278489249094, 42.95490319388253, 75.69654505593437, 43.087346281324116, 39.800157002040315, 67.80480888911656, 47.958763054439, 28.55246523448399, 22.58345021520342, 29.056958300726755, 25.41444683074951, 30.489824499402726, 45.00091144016811, 45.21210541043963, 64.48747485024589, 60.53506851196289, 53.712086881910054, 56.23858390535627, 58.43382903507778, 64.58980791909354, 69.84068666185651, 73.85926764351981, 87.145904813494, 87.74100412641252, 45.86440576825823, 21.92362322126116, 6.749191761016846, 0.03318314779815929, 0.3145308909671647, 0.015579740782933576, 0.050473885876791816, 0.017205142582367574, 0.04746027776439275, 0.009448848648129829, 0.06019149121961423, 0.022703250770324042, 0.003868699639237353, 0.022123861592262983, 0.05339921319058963, 0.014311406162700482, 0.05015431623905897, 0.030997382942587137, 0.008013979481932307, 0.042162459543240924, 0.04267767118290067, 0.026832730076940994, 0.09659021986382348, 0.06633399054408073, 0.05541867250576615, 0.04842805529811552, 0.029493023308792284, 0.00968031645087259, 0.12390755116939545, 0.036295367404818535, 0.0474972511375589, 0.01229413936380297, 0.04811393768925752, 0.04620566990758691, 0.06330959711756025, 0.02762592224670308, 0.015010570342253362, 0.05742419471165963, 0.051106928515114954, 0.028152126153664928, 0.012727999743739409, 0.01953927760145494, 0.024629277509770224, 0.015420493703069431, 0.05659812582390649, 0.07114784366318158, 0.024031203173633133, 0.03550438895555479, 0.08874214813113213, 0.027347989214052047, 0.06711551360785961, 0.054420734090464454, 0.07120348353471075, 0.041542655123131614, 0.08726594770061118, 0.06011570564338139, 0.06624035949685744, 0.024311551790950552, 0.07265142298170499, 0.018163810783464993, 0.036752092718545876, 0.05252904970464962, 0.011520352447405457, 0.033273993459131034, 0.05788305401802063, 0.056164698010044437, 0.015181371177147542, 0.04541947852287974, 0.031398617662489414, 0.059451019524463584, 0.05678561862025942, 0.04793448892555066, 0.044164999587727446, 0.02548907806963793, 0.028550775655146157, 0.024380621566836323, 0.007363917489003922, 0.029440528447074548, 0.03317409614101052, 0.014443466040704931, 0.036100115560527356, 0.02520581005540277, 0.07017888887120144, 0.011945696364689087, 0.05277613823169044, 0.05278240450258766, 0.11103319735931498, 0.03505246088440929, 0.050637015873300176, 0.027953574932845573, 0.07185822911560535, 0.06244188653571265, 0.041605066774146895, 0.08051268543515887, 0.014501884513135468, 0.03576349773045097, 0.04581920010969043, 0.015938231189336096, 0.046249954495579004, 0.09440183586307935, 0.01501040579751134, 0.03929018348987613, 0.040153639657156806, 0.041621850337833166, 0.03912416971953852, 0.06812666649264948, 0.08412733647440161, 0.09463710431009531, 0.022423589169713, 0.07396267154919249, 0.05412937793880701, 0.007868259845833694, 0.03409654753548758, 0.037363177963665554, 0.08999186035777841, 0.04942127110968743, 2.5496327877044678, 11.315549612045288, 52.37742131096976, 90.49775750296456, 99.28405339377267, 89.6210685457502, 80.34721755981445, 72.93300328935895, 94.01447010040283, 97.26803357260567, 81.30363014766148, 82.74711840493339, 61.13129343305315, 62.04282760620117, 25.52532618386405, 34.83655500411987, 13.178902745246887, 17.147174426487513, 28.07701563835144, 24.022877250398906, 28.66609607424055, 27.243162325450353, 24.61004172052656, 24.377127681459697, 22.820694719042095, 32.487546239580425, 26.495881829942974, 26.077108689716884, 20.388786997113908, 22.85641019684928, 32.227402210235596, 41.98360061645508, 35.21400547027588, 23.795599937438965, 21.2251364503588, 30.459704058510916, 26.354230642318726, 15.71572392327445, 34.45076322555542, 28.239448887961252, 26.73644757270813, 43.02351318086897, 35.29755061013358, 19.06632767404829, 25.183007546833583, 34.59607785088675, 28.502080372401647, 36.1734231540135, 54.29461342947823, 53.58553239277431, 90.32531711033413, 97.63607965196881, 91.11555658067975, 83.77585479191372, 83.37155996050153, 80.0544204711914, 80.39862728118896, 83.95853682926723, 98.26575320107597, 104.26460552215576, 67.73558398655483, 38.581647941044395, 15.803099257605416, 0.17245503541614327, 0.33350598705666407, 0.031288410004760535, 0.032919095895652256, 0.01419260655529797, 0.07704427904848542, 0.019045475437971096, 0.03949513499225889, 0.03074611463983144, 0.07043731571840388, 0.017834753529833894, 0.11209570177431617, 0.033092855143227747, 0.012483098643964954, 0.0846197832641857, 0.037477724852838686, 0.0617993613705039, 0.04336872517264315, 0.005086991453676352, 0.09975789953023195, 0.008756234027844454, 0.03969465482181736, 0.07435314131102391, 0.04982802910464151, 0.013196665577457418, 0.041465363199157376, 0.013254641305788286, 0.07211843372455665, 0.09202678009335484, 0.0419734536137964, 0.027489075304142067, 0.07904943823814392, 0.016362722697002546, 0.061231814324855804, 0.04880889664803233, 0.026445116947538087, 0.026729287413348044, 0.08536985622985022, 0.07045821459697825, 0.04841401980125478, 0.040610809411321364, 0.03834224971277373, 0.06373667384364776, 0.01877989004632192, 0.02688476353484605, 0.04748027079871722, 0.02742807161329048, 0.05456574380929981, 0.02192230106863592, 0.02024068942825709, 0.09558667335659266, 0.04864834508459483, 0.05802029451089246, 0.020477918841476952, 0.06445368179785353, 0.04378306240375553, 0.030132780051124946, 0.049807822331786156, 0.13267629992749008, 0.10773089634520666, 0.13889649829694203, 0.07965214018310819, 0.16454373779041426, 0.23345146594302996, 0.1541114111563989, 0.09166786220989057, 0.17146620633346693, 0.0886396486312151, 0.10903402284852096, 0.22868318323578152, 0.07414323650300503, 0.11765457955854279, 0.1794018769370658, 0.13584779974605354, 0.12442653546375887, 0.24706730246543884, 0.08742946106940508, 0.21801104875547545, 0.09580265783837863, 0.1765839345753193, 0.15280409130666936, 0.15832291516874517, 0.13711649738252163, 0.31238150915929247, 0.10221559407987765, 0.09267976148320095, 0.12216824878539358, 0.09690391338829484, 0.10196901445410081, 0.14500209210174425, 0.11949791493160383, 0.11240528337657452, 0.16307997490678514, 0.1322620678693056, 0.10378417026783739, 0.1172701216169766, 0.17526620599840367, 0.11922103193189416, 0.12257075575845582, 0.15717818588018417, 0.08712750620075635, 0.13701458142272063, 0.11326741640056882, 0.18889930445168698, 0.25314301358801977, 0.11667964687304837, 0.1539639247847455, 0.08760113042912313, 0.1598587656127555, 0.11523571078266416, 0.2100446947983333, 0.29209279641509056, 0.2974953465163708, 1.9023553260735102, 11.894804426601954, 54.94955062866211, 101.80317837851388, 105.30761350904191, 97.76184899466378, 81.48533943721226, 71.66154548100063, 89.16771248408726, 86.7530745097569, 73.811005456107, 84.15544182913644, 59.626084327697754, 65.83911487034389, 53.14534664154053, 49.47355372565133, 28.933068445750646, 27.293858119419642, 69.72575650896344, 52.4411084992545, 100.2166336604527, 76.58471243722099, 76.59639930725098, 89.05590207236153, 49.32455655506679, 135.3470731462751, 83.26731613704136, 91.64118780408586, 76.7839937210083, 83.92355959756034, 86.947756086077, 96.08788899012974, 117.68348775591168, 66.2024917602539, 99.36540290287563, 106.29309041159493, 60.049271311078755, 62.93262781415667, 110.77547059740338, 64.99947370801652, 58.86408928462437, 95.23130117143903, 69.44746725899833, 41.86235107694353, 35.52922439575195, 43.49621650150844, 39.04460988725935, 42.679302896772114, 61.85808195386614, 61.212802750723704, 83.5260670525687, 81.505065373012, 77.55520207541329, 80.77648421696254, 82.54940046582902, 82.22109808240617, 87.00490501948765, 92.46581390925816, 111.4353688103812, 116.52188096727643, 73.24181597573417, 38.82867724554879, 13.594920056206838, 0.13453505161617482, 0.46939277542488916, 0.11691224867744104, 0.16092064577553952, 0.08915408674095358, 0.1835159161793334, 0.0701521545914667, 0.12151727585920266, 0.12329762961183276, 0.0994353646944676, 0.22676780101444038, 0.1979689970612526, 0.12763705104589462, 0.09828685596585274, 0.17837526702455112, 0.17979169530527933, 0.13376312303755963, 0.12423071025737695, 0.1661833498094763, 0.17022458224424294, 0.1523753385990858, 0.19390408375433513, 0.23158476182392665, 0.13696397628102983, 0.10529047729713575, 0.13159086102885859, 0.11859478482178279, 0.15838059064533028, 0.15411113974239143, 0.10854676685162953, 0.1798716267304761, 0.22095399083835737, 0.17490841448307037, 0.1259072074400527, 0.12077413073607854, 0.14328184298106603, 0.12208553536662034, 0.19775173014828137, 0.18898391776851245, 0.1308385692536831, 0.08202658527131591, 0.13177960232964583, 0.1256669381899493, 0.28517895883747507, 0.12001265159675054, 0.1485673457916294, 0.08374775041426931, 0.2649510156895433, 0.12697379663586617, 0.1111427875501769, 0.1712878601891654, 0.12412264677030699, 0.20485519112220832, 0.15033404741968426, 0.21377842873334885, 0.11414263157972268, 0.08797381578811578, 0.15347692663116114], [0.04884000408596226, 0.061920520583433766, 0.09600997064262629, 0.07269420461463076, 0.015898910085005418, 0.03759660418810589, 0.03949273297829287, 0.10043299437633582, 0.07461522546197687, 0.0050499464102488545, 0.025068226902346526, 0.06993439913328205, 0.06742904428392649, 0.06278561202010938, 0.07764713027115379, 0.03323657225285258, 0.0795512827379363, 0.061469946189650466, 0.03569716075435281, 0.03945697079013501, 0.011261637222820094, 0.03367908565061433, 0.04266503346817834, 0.010116996143811514, 0.0635455237435443, 0.021707994264683554, 0.04854532311271344, 0.04450738157278725, 0.007268693580824349, 0.030593335695032562, 0.07686439262969152, 0.03567718807607889, 0.03772986846576844, 0.018447820097208023, 0.0450380536328469, 0.030585691998047487, 0.10340311178671462, 0.06784275387014661, 0.029594976588019302, 0.06382758396544627, 0.04709483915939927, 0.061136839778295586, 0.016784293111413717, 0.06405262010438101, 0.023640801265303577, 0.03988881083205342, 0.04762510070577264, 0.049394496117851565, 0.03205746838024684, 0.012695199360937943, 0.03626617004296609, 0.1454690056187766, 0.05895866094423192, 3.7585086056164334, 31.10799183164324, 49.36753116335188, 76.592848777771, 78.15851415906633, 76.82389722551618, 56.31402744565691, 69.25507858821324, 50.07957213265555, 59.630503382001606, 35.27304431370327, 33.72324514389038, 25.067495482308523, 25.146091767719813, 44.35135562079293, 25.9136940070561, 52.95853737422398, 32.07180425098964, 80.57431943075997, 48.38942977360317, 74.40340191977364, 57.02877821241106, 61.956496238708496, 68.04136725834438, 88.0652973992484, 62.37564631870815, 65.55817140851701, 58.23142801012312, 64.42810944148472, 70.60240377698625, 67.27739892687116, 73.64574255262102, 67.61012036459786, 69.52267456054688, 80.91170310974121, 80.86716515677315, 84.04106058393205, 79.15900611877441, 67.66155787876674, 71.52608340127128, 62.92136478424072, 53.40590756280081, 79.96708856310163, 51.817406926836284, 81.67781148638043, 114.13862800598145, 56.84098924909319, 46.573757784707205, 53.56549378803798, 67.13901165553501, 32.91344649451119, 30.060891355787003, 37.4479729107448, 24.75971634047372, 32.196864877428325, 32.26373781476702, 33.76189797265189, 58.31789834158761, 59.24802589416504, 54.7986809185573, 74.27440861293248, 76.36321081433977, 89.41283798217773, 89.41806302751813, 81.78051280975342, 36.02327953066145, 3.2912062065941945, 0.14047038741409779, 0.389150825462171, 0.028832405007311275, 0.027753259520977736, 0.08289331197738647, 0.09134628410850253, 0.04538606745856149, 0.04332770773076585, 0.02836686891636678, 0.026280153210141828, 0.06525625301791088, 0.03975729378206389, 0.00481335269952459, 0.008196050783486238, 0.08029368825789009, 0.048694943477000506, 0.03689168433525732, 0.03529852143089686, 0.0131217722747741, 0.08703308126756124, 0.038236635737121105, 0.09290318270879132, 0.03135416004806757, 0.022817103857440606, 0.037878552451729774, 0.028697831157062734, 0.03750799769269569, 0.011912364180066755, 0.12268555031291076, 0.04959661812920656, 0.03630975234721388, 0.019510182019855295, 0.036619120210941346, 0.011314812315894025, 0.018832166080496142, 0.037309950284127674, 0.02742978321787502, 0.021045241970568895, 0.06806838033454758, 0.02905395008357508, 0.06111580519271748, 0.011758515694444733, 0.007975045990731035, 0.05817988594727857, 0.13727564098579542, 0.05900455026754311, 0.07643633202782699, 0.0399670391343534, 0.06744399241038732, 0.026140134116368632, 0.07693764727030482, 0.036273087707481215, 0.05846842617860862, 0.10044370844428029, 0.040489460208586285, 0.016262484415035163, 0.02311883311319564, 0.006589964755611228, 0.13886698202363082, 0.05232780300346868, 0.03782666148617864, 0.04658699641004205, 0.03448454064450093, 0.02795738829965038, 0.007628671675255256, 0.0231097169952201, 0.11059362880353417, 0.07306669319846801, 0.041553922197116275, 0.008169975530888354, 0.03158826480752655, 0.021617167263424823, 0.012511993209565324, 0.035688601035092554, 0.017934864586485282, 0.05394600045734218, 0.0733622426965407, 0.04274863576782601, 0.03767118197200554, 0.11148655374667474, 0.044674084056168795, 0.027790947052251016, 0.06412398163229227, 0.029672444931098392, 0.028956210506813865, 0.04827165636899216, 0.03802197439862149, 0.03054784331470728, 0.01633256860077381, 0.05552563676610589, 0.03736136966784086, 0.0541736116366727, 0.09779457880982331, 0.08706694695034198, 0.0720354285357254, 0.0637148114453469, 0.07443449087440968, 0.05123825218262417, 0.09367554554981844, 0.019007743801921606, 0.06302567770970718, 0.01675132309485759, 0.08357167736228023, 0.03563997382298112, 0.06612314257238593, 0.02839749289809593, 0.0017802839907484927, 0.14211697477315152, 0.1685154339564698, 8.480556913784572, 46.256843498774934, 67.8122226170131, 95.06145245688302, 92.4157382420131, 90.252242905753, 75.75110925946916, 92.2479600906372, 79.16428674970354, 66.36110523768834, 44.52737780979702, 42.574419839041575, 25.321776969092234, 28.333096708570206, 27.888691663742065, 24.167689868382045, 40.233505725860596, 26.164904390062603, 43.63869973591396, 33.109041758946006, 51.87948908124651, 44.50319113050188, 56.28750964573452, 53.15943758828299, 76.86833790370396, 53.19933761869158, 46.45036472593035, 52.944745200020925, 48.22549397604806, 58.490019117082866, 58.8630678994315, 63.82236548832485, 58.37706225258963, 59.447890826633994, 76.77645492553711, 67.59445912497384, 69.64893027714321, 61.16851493290493, 43.63381167820522, 43.57954624720982, 54.364307335444856, 36.44444458825247, 41.85377352578299, 42.199442931583945, 68.82883439745221, 74.00427654811314, 32.33915703637259, 23.07412678854806, 25.536014250346593, 35.38778339113508, 28.432714768818446, 20.669325726372854, 31.149048737117223, 24.054882390158518, 41.137938840048655, 49.3482221194676, 56.18000364303589, 88.74255916050502, 89.85306194850376, 81.29020622798375, 91.94613034384591, 85.26038605826241, 101.71642317090715, 100.36923694610596, 99.50767421722412, 53.88254008974348, 9.091063857078552, 0.5357505146946225, 0.2952653547482831, 0.035913698242178986, 0.06013314399336066, 0.08123069762119225, 0.1770549871559654, 0.040413019846060445, 0.06797521069113698, 0.05262987661574568, 0.023800499570955123, 0.0436533502569156, 0.0473478954019291, 0.037175593565085104, 0.07703081012836524, 0.08958403367016997, 0.026467985274004083, 0.010350543656386435, 0.04487948678433895, 0.03173240939421313, 0.09610488412103482, 0.025989652012607882, 0.020681986551997916, 0.05090392440823572, 0.021763795288279653, 0.04633937184033649, 0.07623438643557684, 0.07612625509500504, 0.04336360901860254, 0.07657789478876761, 0.029841339082590172, 0.01736143124955041, 0.02128028480469116, 0.0786865780662213, 0.09515500973377909, 0.0799619389165725, 0.0048936674970069104, 0.013834194180422595, 0.016068226624546305, 0.04244278271549514, 0.04429779228355203, 0.05624056161780443, 0.014130507878560041, 0.03775631097544517, 0.0024856955694433835, 0.09866593991007123, 0.04386653917442475, 0.012668033363297582, 0.07795199605503253, 0.0409001129945474, 0.04793246349852, 0.020559592405334115, 0.022498109278136065, 0.06805761876915183, 0.028987959160336425, 0.021994107036984394, 0.04058575111308268, 0.1294354945421219, 0.1460363966013704, 0.29259795216577394, 0.21623214706778526, 0.08929701335728168, 0.10549895718161549, 0.15288398201976502, 0.14633799184645924, 0.12260986651693072, 0.09106026124209166, 0.18202811958534376, 0.11300649254449777, 0.11044615600258112, 0.14585959751691135, 0.20013492155287946, 0.09677372965961695, 0.18634394157145703, 0.1811168199138982, 0.05016461979331715, 0.13127707929483481, 0.13255026883312634, 0.10678973434759037, 0.06572883908769914, 0.19143941386469773, 0.12450938458953585, 0.09975604712963104, 0.11571493292493479, 0.16160247847437859, 0.08250172941812448, 0.12706763802894525, 0.247094525290387, 0.1670199427753687, 0.12554888666740485, 0.1717825529298612, 0.104102749244443, 0.12109804978328091, 0.30872960654752596, 0.18545447715691157, 0.08789958405707564, 0.16915337901030267, 0.12700183370283671, 0.18300698777394636, 0.2254006208053657, 0.21541004760989121, 0.09236081609768526, 0.15173261665872165, 0.15559844779116766, 0.17549838711108479, 0.21636189653405122, 0.13816137345773832, 0.15957399803612912, 0.4212201274931431, 0.20099073063049996, 7.24958712714059, 47.71992915017264, 72.52196175711495, 106.20718288421631, 102.57759680066789, 95.99754156385148, 74.13654940468925, 91.27139772687639, 68.99208927154541, 81.73731585911342, 47.43351398195539, 50.53088542393276, 36.34095811843872, 39.790922846112935, 65.43583447592599, 43.0729079246521, 78.68900912148612, 49.646101815359934, 111.10723318372453, 65.593232018607, 113.53027153015137, 85.30547291891915, 98.44954695020402, 94.61286285945347, 126.8183400290353, 91.38946151733398, 94.21507154192243, 86.43966906411308, 89.86135114942277, 102.5742964063372, 95.79637731824602, 103.26339094979423, 96.5113330568586, 94.88028512682233, 113.68078340802873, 113.62735870906285, 118.65196936471122, 114.16612202780587, 90.8093911579677, 98.5736139842442, 90.82339872632707, 73.94458457401821, 106.28223037719727, 76.07407542637416, 105.01945086887905, 143.21210043770927, 77.82998943328857, 65.77633789607457, 80.65013817378453, 97.33352034432548, 52.18848589488438, 47.849273341042654, 54.015306268419536, 34.17887674059187, 43.22569186346871, 46.3377274785723, 51.270885944366455, 82.97893115452358, 85.5922737121582, 77.73775904519218, 91.92873205457414, 94.3389162336077, 111.80203914642334, 114.81921795436314, 110.34175709315709, 53.94199582508632, 7.859170828546796, 0.3850051664880344, 0.6154204596366201, 0.13793230003544263, 0.18868491452719482, 0.19625066140932695, 0.3589927394475256, 0.12628414721361228, 0.2691593441580023, 0.1819495316594839, 0.14118185852255138, 0.18582569009491376, 0.1288703970078911, 0.10509565632258143, 0.09421342704445124, 0.14719655577625546, 0.18495563178190164, 0.12213227285870484, 0.12663778609463147, 0.11975235199289662, 0.1728165860154799, 0.21979613868253572, 0.15661671172295297, 0.11967755029244082, 0.08215039077081851, 0.13936236687004566, 0.13631231124911988, 0.1817634773573705, 0.17721917905977794, 0.21535398704665049, 0.13273318830345357, 0.1457249761692115, 0.12775386763470514, 0.1530022235321147, 0.1405295149556228, 0.2383046198104109, 0.08174963441810437, 0.0797056019572275, 0.09868065054927554, 0.20201329647430352, 0.10827575317983117, 0.194219833239913, 0.146832209612642, 0.09319641161710024, 0.21411365217396192, 0.2919810824096203, 0.11954515453960214, 0.1474293747118541, 0.1674042378685304, 0.12869424931704998, 0.15021934786013194, 0.22011415447507585, 0.11602510485265936, 0.19390621435429367, 0.17520022525319032, 0.17290722472327097, 0.1386015662657363], [0.028851838250245367, 0.013617717760748096, 0.05811125213014228, 0.1064179175134216, 0.09249336112822805, 0.06823930330574512, 0.057684256828257015, 0.08007387005324874, 0.04344049382156559, 0.012310054402665367, 0.053772743325680494, 0.0698105189949274, 0.08105032944253512, 0.02740638393775693, 0.041699444209890704, 0.03194047876500657, 0.048667347457792075, 0.08219144213944674, 0.011262496417787458, 0.05679342855832406, 0.03244527489213007, 0.0357928002652313, 0.04022889258340001, 0.05055350178320493, 0.008598835955906128, 0.022400252654084137, 0.06175841856747866, 0.026715414764891778, 0.008007021105316068, 0.06038629862346819, 0.05645772335784776, 0.045985261377479346, 0.037162518195275746, 0.05311438115313649, 0.03675521058695657, 0.04700277213539396, 0.04887729637058718, 0.002650941110914573, 0.04342866695619055, 0.004645900010863053, 0.02949670436126845, 0.1184180128787245, 0.0032896007469389588, 0.052164486409830194, 0.02673391332583768, 0.1370700313044446, 0.025540164971191968, 0.051127566157707145, 0.0376798875762948, 0.06296169185744864, 0.04846047909398164, 4.418339942182813, 29.40944562639509, 71.49437877110073, 81.53300407954625, 81.00427395956856, 68.83054365430559, 62.073100907461985, 51.565614632197786, 53.16994326455252, 55.234447615487234, 30.19918830054147, 30.65134927204677, 51.62868690490723, 56.229103088378906, 75.02356338500977, 49.28172091075352, 55.403858593532014, 64.41081537519182, 53.942013195582796, 59.9689918245588, 52.67825051716396, 54.980622972760884, 50.17989717211042, 52.77939196995327, 43.054227692740305, 46.89438588278634, 34.70849970408848, 38.57822247913906, 38.446220602308, 32.59130368913923, 28.2759199823652, 19.799866369792394, 17.829704659325735, 14.754319054739815, 16.028038501739502, 17.503361667905533, 15.846226726259504, 20.800139461244854, 24.602284056799753, 30.757979801722936, 44.91288471221924, 47.10614960534232, 42.55008029937744, 59.20981775011335, 55.073304993765696, 54.57941314152309, 55.75504486901419, 67.07448373522077, 70.98875141143799, 75.54089151109967, 69.74726118360246, 64.95520673479352, 48.095124925885884, 53.5017649105617, 67.85376589638847, 75.87751783643449, 54.973994391305105, 54.841867446899414, 33.22188745226179, 24.279911960874283, 26.119254725319998, 29.504285063062394, 45.81789800098964, 79.01654025486538, 67.78472164699009, 67.54644012451172, 71.73795482090541, 87.05950396401542, 70.04927853175572, 39.29366111755371, 8.805729133742195, 0.07453760105584349, 0.3667722520019327, 0.06954511002238307, 0.014911086930494224, 0.05124962103686162, 0.03903339869741883, 0.04789925938738244, 0.04151395648451788, 0.03602050983213952, 0.02965206852448838, 0.016743865995002643, 0.09036630312246935, 0.021040514277826463, 0.008209636750897127, 0.06341434935373919, 0.02927002956026367, 0.036010467513863526, 0.11973534790532929, 0.06533336852278028, 0.022746385241459523, 0.03591899760067463, 0.025158390635624528, 0.040233425197324583, 0.06447567311780793, 0.05756932656679835, 0.11149841453880072, 0.07021764000611645, 0.03153174962582333, 0.027685382270387242, 0.02576895001610475, 0.04336227908996599, 0.04105814040771552, 0.02338696301116475, 0.027509850350075533, 0.02875259911109294, 0.031060795432754924, 0.016809685588149086, 0.06400016934743949, 0.03236884470762951, 0.006730994866562209, 0.062366616646093984, 0.12191664800047874, 0.023927833452554684, 0.07754464434193713, 0.06185812928846904, 0.16340768017939158, 0.0738524231793625, 0.004128330886097891, 0.015852393116801977, 0.07348115595855884, 0.017263803631067276, 0.06886371158595596, 0.010035580423261439, 0.08026746287941933, 0.04458630537348134, 0.03367994739008801, 0.031016490488712276, 0.10393042170575686, 0.0894255211044635, 0.020495421652282988, 0.052115177270025015, 0.057003190873989036, 0.007223870405661208, 0.04314871358552149, 0.0771902251456465, 0.06679043426577534, 0.04989448143169284, 0.039142269641160965, 0.09394298334206853, 0.04932383687368461, 0.09092261362820864, 0.033838127473635335, 0.0397299284647618, 0.03478691281218614, 0.022784042238656963, 0.03099720991615738, 0.09456375467457942, 0.017106215569323728, 0.014855106095118182, 0.10272110945412091, 0.02979186370170542, 0.017470719492329017, 0.033738881549132724, 0.041604320385626385, 0.022576391863237535, 0.06689961055027586, 0.01015009084117732, 0.01606649296757366, 0.015063258586451411, 0.026500994306323782, 0.08981743614588465, 0.1052871931876455, 0.047876484359481504, 0.022307586822924868, 0.011398144897871783, 0.08194033668509551, 0.03982733555936387, 0.038870146564607105, 0.046322893617408614, 0.06431783908712012, 0.06989665901554482, 0.005329932435415685, 0.05611795373260975, 0.016009248360725384, 0.11043665651232004, 9.62129999910082, 44.1646853174482, 87.13460009438651, 95.32243374415806, 93.96342168535504, 83.53015954153878, 82.39068971361432, 78.22681495121547, 71.78891985757011, 71.92472239903041, 42.01956449236189, 41.76816824504307, 34.85153532028198, 37.064904826028005, 45.29101957593645, 29.080861840929302, 47.01602104731968, 50.48253985813686, 53.461597374507356, 61.86578055790493, 56.425052710941856, 57.78194556917463, 50.364205087934224, 50.31401824951172, 44.633956227983745, 46.19106142861502, 37.293990407671245, 41.03761380059378, 41.042984758104595, 28.9797169140407, 24.281985998153687, 17.34650261061532, 15.589925050735474, 12.828518986701965, 14.547631859779358, 15.48285504749843, 15.251598153795515, 20.384645870753697, 23.746186086109706, 28.628160646983556, 43.061592783246724, 43.455031054360525, 43.160354478018625, 60.38555022648403, 53.413686071123394, 53.29571608134678, 55.56832592827933, 63.39415495736258, 66.16548565455845, 70.33291789463588, 69.43209784371513, 68.48478044782365, 47.622452872140066, 47.54683562687465, 54.68081515175955, 40.972790581839426, 33.79953636441912, 39.07666540145874, 25.735986879893712, 28.959131138665335, 42.47781555993216, 44.66340964181082, 69.79003429412842, 103.17776135035923, 86.84162930079869, 81.0750344140189, 84.42849908556256, 97.63147299630302, 91.12983512878418, 59.46332972390311, 19.48273147855486, 0.03859436618430274, 0.3336724724088396, 0.14106923528015614, 0.05000623954193933, 0.05354513893170016, 0.042554215128932676, 0.08506579790264368, 0.05331746668421796, 0.08636441893343415, 0.005912392832604902, 0.02250787678972951, 0.03583495764593993, 0.03000291862658092, 0.054089066173349104, 0.026742574825350727, 0.04782302597803729, 0.058450390717812946, 0.05466117636699762, 0.05449372749509556, 0.062188297643193176, 0.019510740114908134, 0.009379576159907239, 0.035013244953006506, 0.03931482448907835, 0.037103159951844385, 0.03985137605507459, 0.03801191850964512, 0.05179443037403481, 0.04246631770261696, 0.0084721619496122, 0.02395991119556129, 0.030380866024643183, 0.028020585354949747, 0.08338964677282742, 0.014381839793973734, 0.06524351691561085, 0.013814737188762851, 0.04721383384561964, 0.13297007844916411, 0.0671737522685102, 0.05770098950181689, 0.014307860817228044, 0.036574075663728375, 0.03639689999233399, 0.0920416060835123, 0.04724572499149612, 0.03399956113259707, 0.07424895225891046, 0.005603080523932087, 0.047518268759761534, 0.08271659431712967, 0.004067036697441446, 0.05639350680368287, 0.08667374947773558, 0.08976459183863231, 0.10427808269326176, 0.15268977172672749, 0.1749013712895768, 0.22347257712057658, 0.17524662347776548, 0.1980283824460847, 0.18880093044468335, 0.12162538005837373, 0.12839851661452226, 0.28354548077498165, 0.13940991860415253, 0.27106703179223196, 0.19582573563924857, 0.16548444516956806, 0.16702212765812874, 0.15965025180152484, 0.10409899694578988, 0.10084050215248551, 0.15511812642216682, 0.14257817502532685, 0.14711374736257962, 0.12589183183653013, 0.07674032928688185, 0.10430693400225469, 0.10512668572898422, 0.1433661441717829, 0.11418870410748891, 0.13794957553701742, 0.19583579152822495, 0.09907483189765896, 0.16960250133914606, 0.11527360017810549, 0.18132192747933523, 0.08242872583546809, 0.16074524447321892, 0.14444076722221716, 0.20124922533120426, 0.16377077783857072, 0.09816149662115745, 0.1843958811036178, 0.19080153666436672, 0.09432378397988421, 0.16561063911233628, 0.20026214686887606, 0.21696622696306023, 0.12331972271203995, 0.08083986823580094, 0.12229693973703043, 0.13942722124712809, 0.13989034853875637, 8.244413699422564, 45.83443818773542, 95.7362059184483, 106.58950056348527, 104.18959971836635, 87.63310555049351, 81.48742389678955, 72.29093415396554, 70.29341738564628, 72.25772871289934, 44.74511003494263, 53.26748555047171, 70.06380026681083, 78.28602749960763, 101.81114796229771, 66.45460714612688, 82.95704432896206, 91.76057175227574, 77.08717141832624, 87.79918834141323, 78.03432205745152, 82.95341736929757, 71.44868741716657, 71.74542413439069, 61.071733474731445, 67.62347480228969, 51.15845366886684, 57.69997419629778, 59.4879332951137, 47.143742833818706, 39.03192942483084, 27.59400987625122, 24.935490131378174, 20.64618648801531, 23.45385800089155, 25.42389464378357, 22.864246027810232, 30.50589915684291, 34.52783611842564, 45.03384937558855, 69.51516355787004, 67.60628495897565, 62.442682538713726, 89.95522131238664, 81.90350982121059, 79.57387610844204, 78.63994094303676, 91.06482083456856, 102.10100596291679, 106.2193352835519, 101.05714334760393, 98.48951298849923, 73.97782475607735, 77.89401013510567, 97.58409323011125, 109.8415423801967, 76.53430325644356, 79.05744429997036, 49.91249227523804, 34.21952370234898, 39.22392552239554, 43.20922810690743, 63.83874934060233, 103.57739394051688, 87.09677410125732, 83.25799860273088, 87.94935280936105, 112.41131278446743, 100.20427281515938, 63.11159256526402, 17.886111872536794, 0.1294162105768919, 0.5437129331486565, 0.19227840884455613, 0.22507036424108914, 0.20469456831259386, 0.1681875522647585, 0.15642669477633067, 0.19103286282292434, 0.15488521249166556, 0.12432076542505197, 0.18976910492139204, 0.1399237188909735, 0.04870526060195906, 0.10946593752929143, 0.11018194803701979, 0.2089569895927395, 0.12862768503172056, 0.180693902607475, 0.09465809818357229, 0.11349076977265732, 0.11374987515487842, 0.1590341827166932, 0.17785698840660707, 0.1843467823096684, 0.1742041087044137, 0.18556369415351323, 0.19327105129403727, 0.12319320307246276, 0.14811599786792481, 0.1718322624053274, 0.17572649701365403, 0.09185196911650044, 0.23448579758405685, 0.18389828423304216, 0.1424841165010418, 0.1804350143564599, 0.2089469065623624, 0.18525253156466143, 0.2040815254939454, 0.13592379566814217, 0.17273778095841408, 0.20202892992113317, 0.08331102492021662, 0.15153356162565096, 0.25420060540948597, 0.2880661796246256, 0.21828628970044, 0.1866444783019168, 0.1271521020680666, 0.1716299368334668, 0.20350395648607186, 0.12768316428576196, 0.1571393601064171, 0.17489751721067087], [0.052605035448712964, 0.024435654149523804, 0.05120132291423423, 0.03447629983669945, 0.029537341823535304, 0.09117170383355447, 0.05183621795315828, 0.022775887944070355, 0.08833639776068074, 0.0370860337279737, 0.016738437714853456, 0.028447087022608945, 0.04030985198915005, 0.04663368301200015, 0.05607741126524551, 0.026393548286120807, 0.02475787346650447, 0.05038609362340399, 0.035988432089132924, 0.060346231130617004, 0.04338808038405009, 0.015428147578079785, 0.022264399765325443, 0.012873346185577767, 0.06381410825997591, 0.02261675282248429, 0.03298477469278233, 0.03436587504776461, 0.03854997303070767, 0.057952488506478925, 0.0421352604670184, 0.01204494568186679, 0.09838678381804909, 0.06235545474503722, 0.057530032603868415, 0.006937777141242155, 0.041859768464096954, 0.008819414119768356, 0.056666077713349035, 0.04103698707850916, 0.03537718399560877, 0.014401836220973303, 0.017105060363454477, 0.05826095731130668, 0.025048126998756613, 0.047892891336232424, 0.04616752606151359, 0.008944000782711166, 0.078318343896951, 0.6656227686575481, 21.77600700514657, 75.32091849190849, 93.43419824327741, 72.7003914969308, 66.2822709764753, 50.49440738133022, 54.43308407919747, 60.5031623840332, 25.16275528499058, 28.126875911440166, 36.40531928198678, 55.57721267427717, 25.95869401523045, 90.6663485935756, 77.3031005859375, 51.381591592516216, 73.3967399597168, 50.81355551310948, 56.05766323634556, 37.011765003204346, 23.452655962535314, 16.264435325350078, 13.016620618956429, 9.97443698133741, 11.985775453703743, 7.994351506233215, 3.916261374950409, 3.9296514221600125, 2.2848677720342363, 1.797897411244256, 1.2316476702690125, 0.3104782727147852, 0.2271563165954181, 0.09401765612087079, 0.15440261124500207, 0.1165743518088545, 0.2222115197884185, 0.2884569615125656, 0.623477113034044, 0.5806069448590279, 1.5510807867561067, 2.29768111876079, 3.348055064678192, 3.9238049473081316, 2.4831155112811496, 2.7767765649727414, 4.196014957768576, 6.045076949255807, 3.8941717488425116, 6.510157661778586, 13.535549436296735, 18.89697575569153, 21.17255595752171, 36.67096281051636, 40.68448897770473, 52.121105739048545, 65.38748891013009, 60.242528506687705, 57.1722480910165, 69.54572173527309, 71.36352334703717, 46.40022305079869, 39.15308516366141, 32.677753176007954, 46.996489661080496, 72.45361927577427, 63.36426380702427, 53.773700032915386, 61.732083320617676, 69.74817139761788, 80.02732944488525, 67.8357492174421, 23.38042596408299, 6.315025321074894, 0.4801414757966995, 0.4626686562384878, 0.020995361165010502, 0.08420978526451758, 0.08048882814390318, 0.11918831297329494, 0.042620982974767685, 0.017497474128114324, 0.021971175946029167, 0.03562573815828987, 0.005255128190453563, 0.08235171211085149, 0.06282538774290256, 0.03501248838646071, 0.06105271500668355, 0.029557440030787672, 0.038816043574895175, 0.014401444367000034, 0.02196480450220406, 0.0192648118827492, 0.019163730521021143, 0.02909395650827459, 0.035031409335455725, 0.03421023947053722, 0.011111358679564936, 0.029311725537159612, 0.00694612566647785, 0.03497497897062983, 0.04293814381318433, 0.0192129260062107, 0.036783373182905574, 0.03163276652672461, 0.06521721689828805, 0.018496459183682288, 0.008777772425673902, 0.055890651286712716, 0.035573792909937244, 0.03220818457858903, 0.043981883342244794, 0.035065756778099706, 0.04056019748428038, 0.031062848001186336, 0.029278680881751434, 0.022324818219723444, 0.08110723817454916, 0.009714770762782012, 0.05739109577344997, 0.05502765652324472, 0.10577198610241924, 0.0378375723292785, 0.04612644076613443, 0.046481348507638486, 0.014199783759457725, 0.032607912950749905, 0.023102594073861837, 0.02534792073337095, 0.01750889726515327, 0.08738881682178803, 0.01915428531356156, 0.06152848340570927, 0.07243081089109182, 0.02084767971453922, 0.016183363839185665, 0.009978557188462998, 0.047078269334243875, 0.03752996187124934, 0.03993213529299412, 0.05813143854694707, 0.014659767737612128, 0.10671779606491327, 0.018834893791271106, 0.006851192680187523, 0.042707577613847594, 0.04206799389794469, 0.03845041498009648, 0.03880023370896067, 0.022666453816262738, 0.011539445574661451, 0.014777013499821936, 0.01654603741397815, 0.05038375607026475, 0.046906739074204645, 0.022882307680057626, 0.027972319462735738, 0.08581715329949345, 0.014422373779650246, 0.07772833734218564, 0.030876006598451307, 0.06620928937835352, 0.02335146884433925, 0.09530404316527502, 0.01961197075434029, 0.01410424433249448, 0.030737612596047775, 0.02092578588053584, 0.006331038761085698, 0.008377424042139734, 0.08525756546961409, 0.12164846381970815, 0.014101296097838452, 0.04781245440244675, 2.009435100214822, 34.64113344464983, 95.86685984475272, 104.4745522907802, 84.63317217145647, 77.03222506386894, 75.80812617710659, 87.61611720493862, 83.98252201080322, 41.40758800506592, 24.74060184614999, 35.7393969808306, 28.63561953817095, 24.03858539036342, 90.30317320142473, 75.47751004355294, 54.46398966653006, 75.21601458958217, 53.012952191489084, 58.682213238307405, 41.6585499899728, 23.722028936658585, 16.33695888519287, 12.49433582169669, 9.359316434179034, 12.766052944319588, 7.967369914054871, 2.922539783375604, 2.6765457604612624, 1.826634509222848, 1.158946931362152, 0.602315288569246, 0.21529025903769902, 0.17714582942426205, 0.1359230221382209, 0.12491497211158276, 0.1564278754272631, 0.20511471719614097, 0.42037141589181765, 0.5114635207823345, 0.665256142616272, 1.168126370225634, 1.2937632628849574, 2.8066006217684065, 2.9053075994764055, 2.0900939149515967, 1.3922510466405322, 2.920873301369803, 4.843745137963976, 2.4151999098914008, 5.421885200909205, 11.703827977180481, 17.879498924527848, 19.292792047773087, 32.82673297609602, 41.18218149457659, 56.67274556841169, 70.05479540143693, 47.51386642456055, 39.531119278499055, 51.53865214756557, 47.87588841574532, 24.74620383126395, 25.317793914249965, 32.50459017072405, 66.41551658085415, 100.69409302302769, 89.00578471592495, 75.23639365604946, 83.37881387983049, 81.26481751033238, 90.18520668574742, 84.78847830636161, 41.88304281234741, 15.342048066002981, 1.5545102655887604, 0.21064849597002777, 0.05834141799381801, 0.04307830539931144, 0.06745802451457296, 0.05817556367920978, 0.048217393923550844, 0.02179842601929392, 0.028723771550825665, 0.023379378685993806, 0.015669061436450908, 0.04832592559978366, 0.02316171313369913, 0.06013428393219199, 0.06672069443655865, 0.040831248475504775, 0.050455663818866014, 0.03569775786516922, 0.02567317140554743, 0.010626396131036537, 0.04011688680787172, 0.04580408234947494, 0.042302468458988836, 0.032806774601340294, 0.026867420179769397, 0.05249648341642959, 0.015040425883073891, 0.05255575005763343, 0.003877894636908812, 0.019607631522896032, 0.01948727128495063, 0.059646274761429856, 0.0629483111468809, 0.018672206538862417, 0.00542358892770218, 0.0030030034582263655, 0.03200593703825559, 0.027656150981783867, 0.049453311533268006, 0.029557277182383195, 0.07791553836848054, 0.04709434722151075, 0.023330593714490533, 0.02530930530545967, 0.052718927551593096, 0.02794892357529274, 0.02339654731830316, 0.04200097160147769, 0.017106597245271717, 0.050981494531567605, 0.021492891878421818, 0.02214817689465625, 0.22794594136731966, 0.1563311027629035, 0.09228015185466834, 0.08972920623740979, 0.11545008713645594, 0.17675902375153132, 0.13013643478708609, 0.21809321934623377, 0.20651434494980744, 0.1548170197222914, 0.07138295604714326, 0.13003217109612056, 0.1551903904016529, 0.16917662562004157, 0.14271985313722066, 0.11478723984743867, 0.08498787494110209, 0.16569264685469015, 0.07038292435130902, 0.13683611314211572, 0.1322317916367735, 0.1385602027709995, 0.1339278713400875, 0.09941515792161226, 0.15294623082237585, 0.0812637015644993, 0.06968754809349775, 0.09398410934954882, 0.3121655450335571, 0.12229645119181701, 0.15332154211189064, 0.1866837926208973, 0.22873078925268991, 0.2201792395540646, 0.27401792630553246, 0.0776749434215682, 0.1153014065431697, 0.16197536060852663, 0.16666474326380662, 0.09513676392712764, 0.11539284592228276, 0.1792384178510734, 0.1074362900108099, 0.10827438932444368, 0.14202925376594067, 0.18285692296922207, 0.2775884047150612, 0.11808941193989345, 0.20715944176273687, 1.4163100527865546, 35.68011147635323, 103.94643361227853, 117.59781646728516, 91.59373160770961, 85.09442138671875, 68.33173942565918, 71.53623471941266, 76.16862651279995, 36.38944264820644, 41.02523211070469, 52.28404099600655, 82.20972388131278, 37.82801158087594, 116.62181690761021, 98.83850710732597, 73.99311774117606, 104.51772144862584, 71.29074791499546, 80.89366558619908, 59.90935543605259, 36.422418798719136, 27.891349349703106, 22.90287106377738, 18.711392845426285, 24.51226840700422, 15.68028289931161, 7.050412671906607, 7.46117193358285, 5.806190499237605, 2.3312930294445584, 2.280239620379039, 0.6365212159497398, 0.9079360919339317, 0.4333664471549647, 0.5769363418221474, 0.4516364910772869, 0.5905012882181576, 1.6481990154300417, 1.3354995719024112, 2.852921656199864, 3.464930061783109, 3.1819709709712436, 6.612393455845969, 7.965067454746791, 4.786759921482631, 4.638780661991664, 8.016905358859471, 10.118541751589094, 6.70644166639873, 11.307933517864772, 21.136065755571636, 30.781155518123082, 33.54908159800938, 57.746384688786094, 63.762659617832725, 77.14095742361886, 98.84045260293144, 86.95381491524833, 82.29200444902692, 93.67061070033482, 95.0508564540318, 66.44492135729108, 56.93685007095337, 46.646098954336985, 61.632043157305034, 91.69951793125698, 84.55579008374895, 74.00688212258476, 81.21035752977643, 88.68302699497768, 102.24291597093854, 97.16977909633091, 44.0199682371957, 14.342661738395691, 1.1483915320464542, 0.7846046984195709, 0.1437123327382973, 0.1636131134416376, 0.15691959618457726, 0.16215334034391812, 0.08295979483851365, 0.12129935755261353, 0.06178313081285783, 0.11243595994476761, 0.10142290911504201, 0.17045073796595844, 0.2417687310704163, 0.13328448443540505, 0.12337439906384264, 0.17459235287138394, 0.1019836300984025, 0.06954380723514728, 0.07276716748518602, 0.15906876086124352, 0.13652899462197507, 0.09078775479325227, 0.13162778690457344, 0.15841659371341976, 0.10579433026058332, 0.1359372985150133, 0.12105826048978738, 0.1721318763281618, 0.1050695598657642, 0.1065182253452284, 0.14536124068711484, 0.10427451359906367, 0.2039732313049691, 0.10632814054510423, 0.11145026569387742, 0.10940936806478671, 0.07033232599496841, 0.10998489468225411, 0.13774933985301427, 0.16783877169447287, 0.18262524397245475, 0.124968467812453, 0.1282638409840209, 0.13693991542926856, 0.13940687876726898, 0.13824439900262014, 0.20463955269328185, 0.16353577402021202, 0.25652453356555527, 0.15723864335034574, 0.08928849095744745, 0.0896266388839909], [0.07858556455799512, 0.039264450049293895, 0.02135652839206159, 0.057360934891871045, 0.02560809480824641, 0.02011902131406324, 0.04771124751174024, 0.056183629137064726, 0.04221396713650652, 0.04216735178072538, 0.009149490024096199, 0.023813815820696096, 0.020708948140963912, 0.03824631843183722, 0.012076447518276317, 0.04726705134713224, 0.047800590217645676, 0.012590129909637784, 0.07306586538574525, 0.07708728459796735, 0.032913094253412316, 0.01538046692231936, 0.051863332212503464, 0.05685117528108614, 0.010217930772341788, 0.05030883562618068, 0.01971467551110046, 0.04058198185105409, 0.04563234852893012, 0.021511570251147662, 0.06338199001869985, 0.021930840431845615, 0.029841366223990917, 0.025846571029563035, 0.03849236201494932, 0.031331344308065515, 0.012497688843203443, 0.07709782224680696, 0.042012089397758245, 0.005667395041590291, 0.05544562391670687, 0.06718827970325947, 0.01660403858737222, 0.02645249431952834, 0.15520155908805983, 0.04891596268862486, 0.029630151843386035, 0.029977137688547373, 10.338632890156337, 57.417297158922466, 87.58037567138672, 77.88472039358956, 60.38744708469936, 71.63639995029995, 53.53039843695504, 38.42295455932617, 28.843410628182546, 33.44616140638079, 33.56349563598633, 48.48045464924404, 41.78110579081944, 51.45569065638951, 51.9220745904105, 37.58325433731079, 36.471354961395264, 26.34058264323643, 15.552338770457677, 9.658980080059596, 7.147013911179133, 5.046466214316232, 1.4755762325865882, 0.025410351044099246, 0.17173253132828645, 0.14027533573763712, 0.07553768024912902, 0.08598680741020612, 0.08132202843470232, 0.059494425409606526, 0.026732953198786293, 0.38427948685629026, 0.061579570307263305, 0.2622197222496782, 0.09534343890845776, 0.09186069507684026, 0.05523767668221678, 0.1730470165078129, 0.05918335781565734, 0.04080441241551723, 0.09455406519451312, 0.05871001857199839, 0.10454189710851226, 0.11959513542907578, 0.03540845428194318, 0.053341293441397805, 0.05591786054096051, 0.012136331626347132, 0.06710424992655005, 0.04044314001553825, 0.07211199442722968, 0.1127112280311329, 0.256820374833686, 0.08192492715482201, 0.4192267544567585, 0.9282811773674828, 3.353585179362978, 11.280935423714773, 20.622626883643015, 42.045234612056184, 57.23228400094168, 43.901414598737446, 79.4865094593593, 73.30586447034563, 46.17350680487496, 44.708962031773154, 43.391215324401855, 30.42736714226859, 29.44511420386178, 39.757925851004465, 47.39308588845389, 64.10607433319092, 56.99580206189837, 66.6221490587507, 73.06822913033622, 70.68750531332833, 47.10736901419503, 17.45746534211295, 0.6939483487180301, 0.3426340472485338, 0.05084537362147655, 0.037562823322202475, 0.13887882924505643, 0.04516698885709047, 0.013166861774932061, 0.00788854040937232, 0.03917309209438307, 0.04796131480751293, 0.04974482035530465, 0.028614378135119165, 0.07683109691632645, 0.025040110107511282, 0.032184469779687266, 0.010443323142161327, 0.06101270858198404, 0.040227013041398356, 0.019575801445171237, 0.01563445445416229, 0.08355730599058525, 0.0400238189447139, 0.01340226168810789, 0.05024556223569172, 0.04823685430788568, 0.03074698316465531, 0.05474524685580816, 0.041539011390081475, 0.05785331382815327, 0.03741736916292991, 0.0607424887961575, 0.01808879364814077, 0.053583384558026276, 0.014941766891362411, 0.022820259045277323, 0.045714417339435647, 0.040162060276738236, 0.04321498270811779, 0.01776962773874402, 0.057331092921750884, 0.04597679326044662, 0.05117642407172492, 0.058741271894957335, 0.0369867335206696, 0.02906676082472716, 0.03235798475465604, 0.031198643214468445, 0.03310552678470101, 0.02176642630781446, 0.01092057753287788, 0.05376838713086077, 0.03029863436573318, 0.0016727069284700388, 0.02085583400912583, 0.05464893898793629, 0.039843396483255286, 0.07866738231054374, 0.08219554049095937, 0.03146148393196719, 0.015597925521433353, 0.007746593427977392, 0.0756338354466217, 0.08649189530738763, 0.044958603967513354, 0.028694217958088433, 0.04041985947904842, 0.06112622070525374, 0.020596151872138892, 0.030037608729409318, 0.054376123805663416, 0.021676915664491907, 0.049400779352124245, 0.025148551877854124, 0.02309414292020457, 0.03723757773903864, 0.05876432851489101, 0.01378567807842046, 0.003223359401869987, 0.015135378377246005, 0.041873183101415634, 0.023343585963760103, 0.07390260762934174, 0.08821115376693861, 0.030734012967773845, 0.04165029113313981, 0.05048917666343706, 0.02852609733651791, 0.06235433516225644, 0.0275301996152848, 0.03714974816622479, 0.05602943205407687, 0.09556080760168177, 0.038553989958018064, 0.032283227158976455, 0.19941015115806035, 0.034007337143910785, 0.04048797421689544, 0.2858408290360655, 18.895893573760986, 76.70855712890625, 102.15635531289237, 83.08303601401192, 79.41433852059501, 86.57950850895473, 75.60400894709996, 59.88361236027309, 40.45343358176095, 31.293887410845073, 20.018005064555577, 35.04662684031895, 29.34737389428275, 43.07803569521223, 44.57493822915213, 41.67527430398123, 34.69212280000959, 24.94689038821629, 12.349035961287361, 8.046733106885638, 5.373454085418156, 3.054910566125597, 0.8675012673650468, 0.07853069143103701, 0.1153669258845704, 0.09712325661842312, 0.14272294725690568, 0.1504747620118516, 0.035614576257233105, 0.10281895420381001, 0.0674042370436447, 0.4178838793720518, 0.08241890743374825, 0.25876103926982197, 0.03251560843948807, 0.2946843387825148, 0.12002658870603357, 0.1740414367190429, 0.2402323649397918, 0.07252317986318044, 0.05388261850125023, 0.13896246547145502, 0.025508604611137083, 0.060721454210579395, 0.06531336531043053, 0.0687880345753261, 0.2221360124115433, 0.03188796354723828, 0.039111267376158915, 0.03450468634920461, 0.04329521608139787, 0.09855948455099549, 0.06149069579052074, 0.14225762151181698, 0.13904444607240812, 0.3362249583005905, 0.8590573604617799, 7.185964643955231, 15.453693458012172, 37.01216799872262, 51.55129786900112, 42.85034670148577, 74.7244851248605, 69.80980191911969, 35.585511752537315, 34.126289299556184, 32.491767270224436, 34.635449818202424, 50.57736192430769, 59.912683623177664, 75.3602522441319, 88.33139950888497, 76.86165373665946, 78.2771338054112, 83.33800016130719, 86.34632696424211, 67.26239081791469, 29.27887855257307, 1.5676563658884592, 0.4363104748938765, 0.041125142348131964, 0.02734563809021243, 0.07266845421067306, 0.027370044994833212, 0.03496800363063812, 0.05284898914396763, 0.04359102003010256, 0.05770354757883719, 0.05176937886114631, 0.0581056202894875, 0.02574745233037642, 0.036405592025922875, 0.02414193330332637, 0.05168061630268182, 0.014442466897889972, 0.04238169760044132, 0.01236440590582788, 0.024883785817239965, 0.02375223028606602, 0.08477172761091165, 0.018102686652647595, 0.0507719493471086, 0.02985018378655825, 0.021373671579307744, 0.012491566760997688, 0.013456575871844376, 0.030829374279294695, 0.02220110601878592, 0.0509964087312775, 0.03183143479483468, 0.038535974853272946, 0.010044699933912073, 0.01988276729493269, 0.03783248331663864, 0.034530250156032186, 0.024202160071581602, 0.04439607808100326, 0.04863867596057909, 0.035348125733435154, 0.014435483076210533, 0.11035371239164046, 0.030947948273803507, 0.04431985824235848, 0.022034905651318173, 0.027874695236927698, 0.016839159453021627, 0.01840736753573375, 0.047626257607979436, 0.21685715924416268, 0.09419528980340276, 0.09710994376135723, 0.18334060987191542, 0.12297664183591094, 0.15829565163169587, 0.11617788379745823, 0.1541966080133404, 0.08987317101231643, 0.15235275695366518, 0.1346843293202775, 0.14100272527762822, 0.17887191394610064, 0.13222520984709263, 0.12809381367904799, 0.17028809312198842, 0.13568461207406862, 0.09924969715731484, 0.09429527193840061, 0.10257776214608125, 0.113156883046031, 0.11550180507557732, 0.1161517466285399, 0.11427996706749712, 0.1417482452733176, 0.20173410645553044, 0.09146223895783935, 0.22328729634838446, 0.12522321699985436, 0.1611427709992443, 0.08728469562317644, 0.11196971817740373, 0.14989247040024825, 0.12659362703561783, 0.09596963852111783, 0.12791155917303904, 0.13448709276105675, 0.15999160919870647, 0.13386113063565322, 0.09277455961065632, 0.3217221408018044, 0.18774010879652842, 0.1339957791247538, 0.1418614113437278, 0.24881045892834663, 0.09698643003191267, 0.10891729446926288, 0.3482002871377127, 17.831796067101614, 81.89229542868478, 111.83520984649658, 93.81279863630022, 76.98088482448033, 91.14709445408413, 69.92242527008057, 51.207532269614084, 37.92733955383301, 44.84492438180106, 49.467849254608154, 68.3339489528111, 62.07291330610003, 78.30316870553153, 76.74707794189453, 55.05257504326956, 52.5969739641462, 41.81722600119454, 22.495498180389404, 18.308485916682653, 11.423528092248098, 6.746475449630192, 2.7484524505478993, 0.42245929528559956, 0.32832971481340273, 0.2966939423765455, 0.271965249308518, 0.19876698138458387, 0.3621037410838263, 0.1935724022665194, 0.1382785700261593, 0.6989602254969733, 0.283695219882897, 0.47194178721734453, 0.2041757061545338, 0.5215139271957534, 0.21941313280590943, 0.392929912677833, 0.7787100747227669, 0.13822063670626708, 0.2574266051607472, 0.1558180081525019, 0.24774779166494096, 0.22507921233773232, 0.23566501002226556, 0.26344640499779154, 0.5760781850133623, 0.19223758817783423, 0.24865643147911343, 0.07429509264017854, 0.11651487142911979, 0.23103248860154832, 0.5341871700116566, 0.6620625225561005, 1.800557485648564, 1.7013899726527077, 5.782000780105591, 17.99962980406625, 30.890367303575786, 63.783636229378835, 80.96999849591936, 63.91687488555908, 104.43936661311558, 101.10794162750244, 67.50496632712228, 63.93445382799421, 59.625827244349885, 43.106391293661936, 40.99513946260725, 54.96529177256993, 64.93450805119106, 82.23970535823277, 74.78218991415841, 84.87174551827567, 95.86014788491386, 97.19589042663574, 71.03157315935407, 30.476692404065812, 1.2499157871518816, 0.5285806251423699, 0.11923058570495673, 0.17338582261332444, 0.29254231229424477, 0.10433643670486552, 0.09954803543431417, 0.13210611338061945, 0.10243260314954178, 0.11294524797371455, 0.15855767471449717, 0.16557836798684938, 0.1593442867909159, 0.15478028383638176, 0.1039052005591137, 0.19128919978226933, 0.15862571820616722, 0.10998488111155373, 0.14593140009258473, 0.10443037309284721, 0.09321769726063524, 0.20338875481060573, 0.07388171553611755, 0.13001332139330252, 0.1428633497229644, 0.08391196267413241, 0.07618035469204187, 0.13898824980216368, 0.1223203491951738, 0.11208734222288642, 0.14884512445756368, 0.10678855369665793, 0.22746658351804527, 0.06099689871604953, 0.10048321953841619, 0.09079754605357136, 0.1059823048167995, 0.09367861252810274, 0.13351344929209777, 0.14918654970824718, 0.11920603630798203, 0.11521416051047188, 0.1994928102940321, 0.15959512761660985, 0.12661145893590792, 0.07628168711172682, 0.11025189142674208, 0.08672275327678237, 0.12460372809852872, 0.1255078081573759], [0.030802304124725715, 0.07631933901991163, 0.03820769961125084, 0.016974428801664283, 0.10776309961719172, 0.03150679310783744, 0.06175273922937257, 0.03831353411078453, 0.06009829443480287, 0.07607197907886334, 0.0664262305945158, 0.04323351349947708, 0.06084882201892989, 0.03373653042529311, 0.021145463289160813, 0.038252985038395436, 0.03358557673969439, 0.015772208937310746, 0.02570585474105818, 0.07274555614484207, 0.04748860999409642, 0.029439575105373348, 0.015338250169796603, 0.02729769280579473, 0.03389085303725941, 0.012746040293547724, 0.010317253032033997, 0.013078267153884684, 0.056009065825492144, 0.027592804648780396, 0.04664409513186131, 0.0033384374567374054, 0.041571150201239755, 0.012614371421347772, 0.02757865040829139, 0.06107666050749166, 0.053223079070448875, 0.04191212083346077, 0.05556674241753561, 0.06548187269696168, 0.05925510610852923, 0.05015697270365698, 0.015284822322428226, 0.08987601407404457, 0.20425866384591373, 0.11517864598759583, 4.4564217158726285, 42.641633238111226, 83.89470372881208, 86.20487553732735, 59.690160615103586, 74.5785243170602, 53.70795270374843, 62.60065678187779, 46.19107532501221, 27.672401189804077, 50.089935370853965, 48.13349287850516, 57.60156338555472, 57.18528291157314, 49.26366254261562, 36.356900760105674, 28.672974790845597, 15.612814153943743, 8.641220109803335, 2.582591784851892, 0.5588430698428835, 0.1382029540836811, 0.11171076885823693, 0.026406494734276618, 0.050129739700683525, 0.06051277755094426, 0.0641407346619027, 0.14862508912171635, 0.31018359852688654, 0.12957984608198914, 0.16174950344221933, 0.3419704942830971, 0.0414080677021827, 0.1631816601646798, 0.061652675670172484, 0.1230045703372785, 0.060063282027840614, 0.11041275172361306, 0.11034790413188082, 0.02586644871293434, 0.015225696477240749, 0.02828812662379018, 0.10382516056831394, 0.013508066501734512, 0.037588678899088075, 0.1634332880909954, 0.144798287323543, 0.04390158550813794, 0.042921763977834156, 0.052832012197801044, 0.2625370866486004, 0.10199248498039586, 0.062161509080656936, 0.07798323580729109, 0.18517715989478997, 0.08436815533787012, 0.03273015103435942, 0.05413295042568019, 0.044293493764208894, 0.07350324905876603, 0.07342151951576982, 1.6461896832500185, 9.124925902911595, 21.213908161435807, 34.59206179210118, 44.20208052226475, 46.907271317073274, 36.40356486184256, 50.099961621420725, 60.27355916159493, 35.18184573309762, 32.06427240371704, 22.155517612184795, 31.10908964702061, 49.821130411965505, 57.83066633769444, 50.85832970482962, 60.63985429491316, 67.09895529065813, 71.34681987762451, 44.437336104256765, 5.659542254039219, 0.10707500404013054, 0.07797478804630892, 0.045106287114322186, 0.019431069925693528, 0.10473966292504754, 0.009616136367964958, 0.08133032013263021, 0.0693115514836141, 0.034418549721262286, 0.012859694909171333, 0.08104034819241081, 0.028790807417993034, 0.038282657374760935, 0.0645511940653835, 0.01398229886711176, 0.021283981124205247, 0.02342610769639058, 0.03391121248049395, 0.06500336301646062, 0.026713260416207567, 0.027742450458130667, 0.03495607837768538, 0.029608503183616058, 0.023725473953943168, 0.05180937510782054, 0.03168223851493426, 0.07455356698483229, 0.04254941110100065, 0.11108175332524947, 0.02612540142477623, 0.025625431377972876, 0.030701453464904, 0.0165635079943708, 0.047928643346365006, 0.01450503121928445, 0.06114457507750817, 0.044305378305060525, 0.08963985674615417, 0.04089713083314044, 0.023544814005228024, 0.09474900152002062, 0.049005339321281226, 0.031018064689955542, 0.018693307281604836, 0.015643965818786194, 0.027244982509208576, 0.0034701678211734232, 0.05238008751933064, 0.07559805629508835, 0.04274541951183762, 0.026916685214798366, 0.02978110213630966, 0.029847310190754275, 0.016540760107870613, 0.016860211001975194, 0.017503692901560237, 0.03426506510004401, 0.11829135753214359, 0.07031931847866092, 0.05174786251570497, 0.026763022478137697, 0.02413870856565024, 0.056731050834059715, 0.034944492392241955, 0.07476925291121006, 0.01481065696238407, 0.044677415663110356, 0.019914783969787613, 0.025380585409168686, 0.015657656959124973, 0.10969591340316193, 0.026604942478505627, 0.06564892123320273, 0.040982704277017286, 0.01812517160682806, 0.03332579621512975, 0.05993685059781585, 0.0181465641196285, 0.06746016868523189, 0.014596175435664398, 0.060424357652664185, 0.023706544523260424, 0.028196141023987105, 0.0480693681165576, 0.03713333440412368, 0.07133963158620255, 0.036262346498136006, 0.13672866033656256, 0.03847352249015655, 0.031028870360127518, 0.06177080861691918, 0.07064455388379948, 0.28217076882719994, 0.2016064604478223, 11.279633505003792, 60.05171707698277, 102.56955078669957, 92.67023686000279, 73.49513339996338, 97.67808846064976, 77.77204145703996, 94.50632613045829, 56.061859948294504, 23.36659904888698, 26.294642891202653, 27.011200189590454, 35.21696540287563, 53.45765079770769, 48.79973827089582, 37.22666583742414, 25.7478700365339, 13.392852544784546, 6.082679297242846, 1.1093557924032211, 0.14089257190270082, 0.09773857252938406, 0.07835560225482498, 0.016584951397297636, 0.03830359357276133, 0.07359645262892757, 0.1353804383959089, 0.42268386323537144, 0.2717385914708887, 0.0933004988889609, 0.20498981246990816, 0.40814608761242455, 0.11002649566424744, 0.12385102920234203, 0.09428896834807736, 0.03337396202342851, 0.033724438931260786, 0.03006205295345613, 0.12042906853769507, 0.03870703013879912, 0.034146667524640045, 0.10841326508671045, 0.4315335340797901, 0.04148912888818553, 0.16585857580815042, 0.08846298525375978, 0.2860366813838482, 0.07855931882347379, 0.03529655367934278, 0.02831258611487491, 0.2208360614521163, 0.046888968242066245, 0.0702855952882341, 0.03440743871033192, 0.10239134822040796, 0.05493488382282002, 0.03215448870988829, 0.03541816411806004, 0.10750747511961631, 0.09842646454593965, 0.07943406581346478, 0.29985344569597927, 6.43641208750861, 15.659417458942958, 30.438459941319056, 44.49951900754656, 49.72785084588187, 35.099617276872905, 40.29320464815412, 38.682143211364746, 27.666285037994385, 37.1489189692906, 36.4037628855024, 58.42678356170654, 74.11410672324044, 84.15560858590263, 68.67329897199357, 72.9379643031529, 76.37905270712716, 84.90187985556466, 62.446309498378206, 13.568668024880544, 0.06187811893011842, 0.08659429302705185, 0.07311442813702992, 0.027883828318278705, 0.12883140838571958, 0.06110905376928193, 0.06751839377518211, 0.08270934077778033, 0.02739221103755491, 0.026341643749869297, 0.05742397079510348, 0.04277227592787572, 0.0137551465470876, 0.02921008099136608, 0.044670905119606426, 0.04154039899419461, 0.031226130668073893, 0.015517049236223102, 0.06584435288927384, 0.026322254611711417, 0.019875556164022003, 0.0318972934037447, 0.05471651768311858, 0.06747485896838562, 0.03989101607086403, 0.012670795848992254, 0.05789670614259584, 0.04396140515538199, 0.04445407246904714, 0.01717791466840676, 0.027209076132359247, 0.06515085617346422, 0.07381142609353576, 0.02643672177301986, 0.07225973185684, 0.04749903229198285, 0.03196060750633478, 0.06542586641652243, 0.01509290378141616, 0.01782612256439669, 0.021434300379561524, 0.026710888936317394, 0.06506764063877718, 0.025991441648719565, 0.008054157236724027, 0.043516082622643025, 0.022967368829995394, 0.024343461596540043, 0.16309621903513158, 0.12077521639210836, 0.12034175465149538, 0.11515770639692034, 0.15024138667753764, 0.08949517272412777, 0.1580340356699058, 0.08817420753517322, 0.15687737773571694, 0.2960571236908436, 0.16029515862464905, 0.16037893055805139, 0.10131648768271719, 0.19973466731607914, 0.2135911394975015, 0.13043138038899216, 0.13718186744621821, 0.2099869107561452, 0.11408298835158348, 0.15150393678673676, 0.11829643297408308, 0.10083316040358373, 0.2144422802541937, 0.07117039138185126, 0.1725259016134909, 0.13878909977419035, 0.13093640043267182, 0.11543648929468223, 0.12309713608452252, 0.11150262824126653, 0.1416539153350251, 0.07258552366069385, 0.1197511577712638, 0.08011778483965568, 0.07512848970613309, 0.11397757115108625, 0.12476279027760029, 0.20135008277637617, 0.0917722141104085, 0.26504096229161533, 0.14322534815541335, 0.1764326755489622, 0.1298381100807871, 0.15172683554036276, 0.4570809475013188, 0.2615009093923228, 11.498448780604772, 65.30010141645158, 109.97453784942627, 104.61656652178083, 76.4290588923863, 97.96047019958496, 69.733934538705, 81.82340403965541, 58.74356583186558, 38.75091300691877, 69.61553028651646, 71.29046998705182, 81.55887222290039, 74.79330008370536, 70.56815610613141, 52.84325633730207, 42.35471085139683, 25.256199870790752, 16.06729061262948, 4.883983458791461, 2.1024074256420135, 0.27392512985638207, 0.4845942940030779, 0.12695597830627645, 0.10076586330043417, 0.2462635641651494, 0.33587149583867615, 0.9573545030185154, 0.7096875927277974, 0.275547344237566, 0.5145435269389833, 0.8219060482723373, 0.4082631484738418, 0.28566696122288704, 0.390891077795199, 0.2659179280911173, 0.3369476523782526, 0.23837695164339884, 0.47192973643541336, 0.13480204157531261, 0.22095677283193382, 0.23597130072968348, 0.4691338464617729, 0.7184060620410102, 0.429492039339883, 0.3789147175848484, 0.6499551779457501, 0.3245409109762737, 0.22906462848186493, 0.32712748646736145, 0.6100562874759946, 0.39654004467385157, 0.3604505312229906, 0.21595561690628529, 0.3345780723861286, 0.23851911830050604, 0.10383305193058082, 0.16367830708622932, 0.28748304662959917, 0.22628507763147354, 0.6000850796699524, 3.1425855415207997, 15.562385865620204, 34.35547910417829, 52.59398276465279, 64.21454960959298, 69.01310062408447, 53.86254317419869, 73.64976555960519, 80.03324236188615, 46.950096539088655, 44.457437242780415, 34.08348144803728, 44.26709829057966, 65.21442317962646, 77.73983655657086, 66.28159700121198, 78.31420939309257, 87.51787662506104, 96.6579817363194, 67.87691729409354, 13.049190299851553, 0.13736087855483803, 0.17994043018136704, 0.17532066521900042, 0.07800089128847633, 0.20212135996137345, 0.07864660556827273, 0.2309491645012583, 0.1734891634966646, 0.09362166986933776, 0.11739905684122018, 0.2167131741132055, 0.19480014352926187, 0.10812078935227223, 0.2605288672660078, 0.1203682039465223, 0.13607270696333476, 0.14214005853448594, 0.2334518459226404, 0.11379796971700021, 0.0719373259427292, 0.09311433602124453, 0.0730181033057826, 0.13971729496760027, 0.12000959818916661, 0.08903592665280614, 0.1043201315083674, 0.10734814831188746, 0.08867736839290176, 0.23351706670863287, 0.11297219259930508, 0.08376138896814414, 0.10373736492225102, 0.16792270647627966, 0.11782767384180001, 0.17693275585770607, 0.11813696367400033, 0.08622751770807163, 0.15658298853252614, 0.13034593925944396, 0.10658954616103854, 0.14088905709130423, 0.09532375460756676, 0.14869588746556214, 0.10213430558464356, 0.0620672469958663, 0.08850801962294749, 0.08241316702749048, 0.1310233614806618], [0.011844651474218284, 0.054025273703570874, 0.0203402627459062, 0.012923512824012764, 0.02166166389361024, 0.018314311546938758, 0.04651383676433137, 0.047899459555212937, 0.020727090471025025, 0.02840807125903666, 0.03209725767374039, 0.03670946714867439, 0.03228885560695614, 0.02910841948219708, 0.017459925696519867, 0.014315183906416808, 0.02474260812492243, 0.02949479767786605, 0.047561152172940116, 0.0335767354284014, 0.03420446853020361, 0.05687833364520754, 0.047949352235134156, 0.03775832283177546, 0.07313856362764325, 0.007407845846111221, 0.023742057349798933, 0.009304914407299032, 0.04412235366180539, 0.06260012768741165, 0.042806674260646105, 0.015244006744718977, 0.011964167784234243, 0.009232511328134154, 0.038786018400319984, 0.035094530055565495, 0.04951761629698532, 0.04382873120318566, 0.1673630779342992, 0.006866741310139852, 0.04125528536470873, 0.19679070743066923, 0.038125491701066494, 0.19097737222909927, 7.978447079658508, 29.683204650878906, 71.54341220855713, 87.37203393663678, 66.39136464255196, 64.07043702261788, 75.92161110469273, 37.17949104309082, 30.94407687868391, 17.920600993292673, 33.937371253967285, 59.2597336087908, 60.44629832676479, 54.11985233851841, 52.36222560065133, 35.27200208391462, 24.418782132012502, 12.037118298666817, 2.599316967385156, 0.49645655176469256, 0.22211124588336262, 0.032478604532246075, 0.07504804259432213, 0.06226171513221093, 0.014417951427666205, 0.07148785077567611, 0.017298480163195303, 0.03775640257767268, 0.1569721826485225, 0.07257246864693505, 0.1546463817358017, 0.14799680640654905, 0.11528018196778637, 0.15259461397571222, 0.06767044668751103, 0.04976565816572734, 0.1032845920750073, 0.16509136983326503, 0.09667449391313962, 0.18853966732110294, 0.044153919110872915, 0.11346090744648661, 0.09563453043145792, 0.44987278857401436, 0.2859991176852158, 0.14670974761247635, 0.08639814890921116, 0.04764934476198895, 0.03693186378638659, 0.07349224322076355, 0.07427355593868665, 0.08265656432402985, 0.05444318002888134, 0.01748472954412656, 0.01960737707226404, 0.09943227736013276, 0.06303356228662388, 0.05776444609676089, 0.06538700671600443, 0.03697977853672845, 0.05677354069692748, 0.14878995956054755, 0.041035273777587075, 0.0431285780588431, 0.1921415619019951, 0.293514218713556, 1.6490478898797716, 12.579517262322561, 31.81003086907523, 52.68969072614397, 45.66995348249163, 47.56964308874947, 61.317942891802105, 48.210093293871196, 42.49222264971052, 21.28663843018668, 21.839678559984478, 24.486763307026454, 32.255365235464915, 50.860382897513254, 56.76083830424717, 65.13048894064767, 72.28158187866211, 70.8598553793771, 29.64580249786377, 1.6942501557724816, 0.3180898614227772, 0.02577669040432998, 0.024163436078067337, 0.08550719171762466, 0.04243589219238077, 0.03966049397630351, 0.14231445560497896, 0.045972409924226146, 0.038472145064068694, 0.04194858191268785, 0.06222744911376919, 0.02935387273984296, 0.05423187404604895, 0.017682641245690838, 0.04126023867034486, 0.06909999105014972, 0.059568168595433235, 0.001995091214277116, 0.03342960189495768, 0.06893209434513535, 0.056322684711111445, 0.037892265644456656, 0.033498055900314024, 0.01663295435719192, 0.04566357471048832, 0.02195134067109653, 0.037388192157128027, 0.02071421526904617, 0.04285815471251096, 0.02340211809080626, 0.047800440939941576, 0.029190121883792535, 0.016938770090096762, 0.044327847992203066, 0.020535368705168366, 0.009287102014890738, 0.024304415298891918, 0.01998573837668768, 0.04876116170947041, 0.008684027723834982, 0.025972725956567695, 0.048929947295359204, 0.025950040834556733, 0.09948305213557822, 0.02140967464739723, 0.08075342965977532, 0.028635283799043725, 0.04822715125711901, 0.03649515525570937, 0.019210203384448375, 0.058178922427552085, 0.008224435599653848, 0.032952754625252316, 0.03586293025208371, 0.02636374193908913, 0.01699498332371669, 0.01741536969452032, 0.04702382707702262, 0.049922871336873086, 0.002016948099480942, 0.05075846007093787, 0.05176889710128307, 0.03239750602681722, 0.07382560069007532, 0.06869156725172486, 0.06203547120094299, 0.026808184072641388, 0.055635084464613876, 0.053622783693884096, 0.012351260986179113, 0.05211604240217379, 0.03750846248918346, 0.10457199013658933, 0.018364577421120236, 0.022525686637631485, 0.08170687992657934, 0.02305959870240518, 0.020682478489886438, 0.023672556704176322, 0.013135352305003574, 0.014608428081763642, 0.02391084802470037, 0.025356387154066136, 0.04595988756045699, 0.04262702872178384, 0.015216834809897202, 0.15819311141967773, 0.16934089894805635, 0.005753420135338924, 0.20780316793492862, 14.495272840772357, 46.43658297402518, 90.37737301417759, 101.25627871922084, 76.31681769234794, 86.99813747406006, 102.43331050872803, 57.39475720269339, 42.51940400259835, 19.925514119012014, 29.304552146366664, 31.598833424704416, 48.23213645390102, 53.935401984623496, 52.028013774326865, 35.676831926618306, 22.538413728986466, 10.385531493595668, 1.2725288080317634, 0.2661926804908684, 0.2827260818864618, 0.03913090757227369, 0.030908715379025255, 0.013454189973085054, 0.016695423683683788, 0.04879823347021427, 0.1765229342771428, 0.009050434089398809, 0.09505557042679616, 0.10825551248022489, 0.1353521163442305, 0.14884044256593498, 0.06925333317901407, 0.2525172143110207, 0.25996096059679985, 0.03536824768941317, 0.30032570606895853, 0.23692274253283227, 0.3432154431939125, 0.7347822061606816, 0.3560988690171923, 1.1669332342488425, 0.5008677893451282, 0.7660084962844849, 0.41243926009961535, 0.7353645520550864, 0.2639430926314422, 0.2324981785246304, 0.2718342920499188, 0.13840352903519357, 0.5360962418573243, 0.06482107458370072, 0.07840442284941673, 0.09483155209038939, 0.0668809236958623, 0.24164960746254238, 0.0643048519268632, 0.2152870970645121, 0.11826018563338689, 0.05336416346420135, 0.22992202533142908, 0.1736139596572944, 0.036850622788603814, 0.03605643147602677, 0.3620582792375769, 0.3511230360184397, 0.8642894082835743, 9.141236799103872, 29.13148467881339, 47.22411264692034, 49.681867667606895, 48.15071051461356, 39.75619922365461, 30.26043667112078, 25.327884435653687, 24.145691871643066, 36.817680971963064, 44.31950855255127, 57.81390380859375, 75.75629261561802, 77.91897501264299, 80.6749085017613, 81.99813733782086, 88.04654421125139, 47.99018280846732, 5.430170059204102, 0.19930345831172808, 0.10316519026777574, 0.06944670887397868, 0.1006886392299618, 0.07129641569086484, 0.09797181894204446, 0.0823647603392601, 0.022600876799385463, 0.02862510916643909, 0.02491789746896497, 0.06094533683998244, 0.013158318170878504, 0.04710043707330312, 0.007469792700638729, 0.021934913338295052, 0.11912345859621253, 0.03104445630950587, 0.024895629645990472, 0.11603970692626067, 0.05605321131380541, 0.004715552478696087, 0.04407625738531351, 0.05951330903917551, 0.022945046724219407, 0.03648312482982874, 0.004651813867634961, 0.08475450639213834, 0.041546811150120835, 0.055467985038246424, 0.04831955076328345, 0.038080036640167236, 0.03975932938711984, 0.008043723064474761, 0.026787071455536143, 0.029987020551093986, 0.015452556179038115, 0.039743963961622546, 0.035463758278638124, 0.03318664564618042, 0.0220862503961793, 0.014652122344289507, 0.08884897668446813, 0.03456266377387302, 0.06770704008106675, 0.03249820740893483, 0.04439853098509567, 0.09522135010255234, 0.15261313798172133, 0.09793900498854262, 0.14342269328023705, 0.1645816271858556, 0.1341324360775096, 0.1190791909715959, 0.1289362691875015, 0.12342490921063082, 0.08702165473784719, 0.07548617944121361, 0.10342748476458447, 0.17409593665174075, 0.15415210968681745, 0.09964153755988393, 0.1733629966952971, 0.18568110785314015, 0.1437431246574436, 0.18160763143428735, 0.21687254841838563, 0.10899630987218448, 0.16761324022497448, 0.15403422101267747, 0.14843144879809447, 0.16398348499621662, 0.10487251329634871, 0.17689042884324277, 0.16640942410698958, 0.14113546029797622, 0.16968328771846636, 0.17688400990196637, 0.12702892082078115, 0.11480942794254848, 0.14966388552316598, 0.10547880469156162, 0.09288092676017966, 0.12834124825894833, 0.140138448082975, 0.2891914078167507, 0.11919572257569858, 0.164827609700816, 0.30305132695606773, 0.13423431132520947, 0.3124310150742531, 13.979522824287415, 49.37606355122158, 100.41408061981201, 106.1999637058803, 83.9636298588344, 82.63992159707206, 95.21755763462612, 46.885089193071636, 40.20577546528408, 24.603597266333445, 51.327232360839844, 88.26332105909074, 88.03487123761857, 78.01375538962228, 73.60324042184013, 54.364453247615266, 37.10644463130406, 20.642054046903336, 4.37893670797348, 0.8422656814966882, 0.4308770921613489, 0.11977224663964339, 0.21089215789522442, 0.3422974667378834, 0.16318377719393798, 0.20784567136849674, 0.2857266180217266, 0.11559557861515454, 0.18611220829188824, 0.2988577091268131, 0.2598002020801817, 0.2639135356460299, 0.23114995658397675, 0.41546750760504175, 0.28784033602901865, 0.30995436225618633, 0.2675615841788905, 0.4207164373781, 0.36080635498676983, 0.602542407810688, 0.167520511629326, 0.7120737018329757, 0.286527370767934, 1.1579364027295793, 0.9209828547069004, 0.41131642035075594, 0.4247589318880013, 0.42792356493217604, 0.21412457658776216, 0.2861590619598116, 0.6657422451036317, 0.19471018335648946, 0.18380392715334892, 0.21685965625303133, 0.1732864850865943, 0.3014320709875652, 0.1831651542867933, 0.38475125868405613, 0.4241927894098418, 0.25305768102407455, 0.3392986405108656, 0.5354194438883236, 0.10620332402842385, 0.14458639440791948, 0.6230983819280351, 0.7834337098257882, 3.386971707854952, 21.58279844692775, 50.46186201913016, 77.95396614074707, 66.71657507760185, 70.30427742004395, 88.02767985207694, 66.77279295240129, 58.88876233782087, 29.321147918701172, 32.766780444553916, 34.37881462914603, 46.6791341645377, 69.82874965667725, 74.68742343357631, 82.75091212136405, 91.21130970546177, 98.47366414751325, 51.52519348689488, 4.805489659309387, 0.34893600908773287, 0.26648493909410065, 0.0943365947210363, 0.21887953286724432, 0.10222543283764805, 0.20621918221669538, 0.24396827018686704, 0.1617591522101845, 0.11881663863148008, 0.13285224405782564, 0.19594162942043372, 0.15083039578582558, 0.11816124165696756, 0.13387543415384634, 0.1023984049846019, 0.17491802253893443, 0.14822912322623388, 0.116905951872468, 0.23972585211907113, 0.13122078802968773, 0.1462047818515982, 0.10743903129228524, 0.20307466095047338, 0.06877153260367257, 0.1736669668129512, 0.16977936827710696, 0.11988009299550738, 0.12931463388460024, 0.08900906345141785, 0.12191816791892052, 0.18824857579810278, 0.12810932498957428, 0.10651412020836558, 0.08250641130975314, 0.11783964319952897, 0.16566412124250615, 0.0868168185864176, 0.1329593440251691, 0.1212837105350835, 0.13632562410618576, 0.13359057158231735, 0.1723136015768562, 0.10513921148542847, 0.1467727292329073, 0.13320281596056052, 0.14239691118044512], [0.015552149852737784, 0.005149191910667079, 0.02008648047090641, 0.11759017301457268, 0.08145565912127495, 0.03814554919621774, 0.01978086999484471, 0.02972634436030473, 0.02088673279753753, 0.03690256464428135, 0.04107143969408103, 0.016118185461631844, 0.039146968496165106, 0.021089039709685103, 0.03179320613188403, 0.006415877690804856, 0.03888357137995107, 0.015503466661487306, 0.01819960859471134, 0.03924650279805064, 0.03439187990235431, 0.01409035811333784, 0.07095836954457418, 0.06574633850583009, 0.05552325850086553, 0.03587000397965312, 0.08638862906289951, 0.02812741051561066, 0.027847655616434555, 0.09625672668750797, 0.061104337950902324, 0.023908968482698714, 0.03929851250723004, 0.08625425198780638, 0.0188886897438871, 0.042756666229771714, 0.053935646012957604, 0.026443551227982556, 0.0302495253937585, 0.12034978850611619, 0.028468696666615348, 0.03785493943308081, 2.8034257292747498, 28.857084683009557, 74.99875831604004, 94.56704643794468, 76.43990503038678, 62.91165815080915, 59.583450181143625, 45.149189472198486, 31.908552850995743, 29.81812824521746, 45.60590498788016, 53.35367795399257, 39.0684700012207, 44.55402762549264, 44.330952235630576, 33.39854192733765, 11.689858623913356, 2.810736754110881, 0.2575440731431757, 0.0888551649238382, 0.023731628266562308, 0.10335936663406235, 0.1281252977039133, 0.030103759108377353, 0.12204851449600287, 0.046565195079892874, 0.14790215077144758, 0.06984550426048891, 0.0474042748766286, 0.06153044437191316, 0.0961270382893937, 0.01392336979707969, 0.014705326275101729, 0.14218305051326752, 0.048016849506114206, 0.09684230240860156, 0.07526790829641478, 0.14318485318550042, 0.06222469426159348, 0.2188960076974971, 0.13790000176855496, 0.12551170294838293, 0.3563059036220823, 0.07386986152934176, 0.03321201607052769, 0.5017629127417291, 0.4310914006616388, 0.03651692605178271, 0.258912515427385, 0.3584343594099794, 0.01827740602727447, 0.08194944262504578, 0.03532323367627604, 0.05319290461816958, 0.15053361813936914, 0.12545368820428848, 0.04596401983872056, 0.044228822591581514, 0.12285689397581986, 0.09462586777018649, 0.05998410377651453, 0.030445384526891366, 0.02965403627604246, 0.05387901208762612, 0.02646418547789965, 0.12434334707047258, 0.1447646048452173, 0.1164453351604087, 0.15751639487487928, 0.17570405107523712, 0.07392375078052282, 1.0493604860135486, 13.284355555261884, 32.29890612193516, 59.52146530151367, 56.0205077443804, 62.10255432128906, 61.968697275434224, 41.25378268105643, 27.447170121329172, 21.000626257487706, 25.520262684140885, 40.98130212511335, 49.44047335215977, 59.967755045209614, 62.30269023350307, 75.6517778124128, 58.890874590192524, 17.67778924533299, 1.3087266428130013, 0.4258388339408806, 0.13593922555446625, 0.07519523719591753, 0.07524945892925773, 0.032447008549102714, 0.05605977274743574, 0.08581347563969237, 0.09285505421991859, 0.05157039507425257, 0.020425744587555528, 0.030432068277150393, 0.03274881414004734, 0.021067557290994694, 0.07870464066841773, 0.026718892256862352, 0.030164274254015515, 0.029006052296608686, 0.017696564784273505, 0.056649355217814445, 0.12800331067826065, 0.004355884389951825, 0.03808438265696168, 0.03479942839060511, 0.048258754025612555, 0.05745700187981129, 0.024362297728657722, 0.04141102272218891, 0.02415029115841857, 0.045464987866580486, 0.020914963246988397, 0.030924348825854913, 0.04143567729209151, 0.06531845432307039, 0.046187583556664843, 0.11195711099675723, 0.01425583244833563, 0.0680178226903081, 0.04107501218095422, 0.04107398420040097, 0.09176813611494643, 0.017352191298933964, 0.011349738209641405, 0.029642982940588678, 0.004391496028152427, 0.0685970608943275, 0.07791449342455183, 0.01751739252358675, 0.0822162086676274, 0.028878501283803155, 0.02866756170988083, 0.02060424000956118, 0.03803055786660739, 0.03034072050026485, 0.02567580751409488, 0.02032471920496651, 0.02311947093611317, 0.035822499742997546, 0.03209009573661855, 0.08589240283306156, 0.1101239672196763, 0.01572704564646951, 0.023912362854129503, 0.03235629180978451, 0.052725868964833875, 0.040145839897117445, 0.0063330132979899645, 0.05604216815637691, 0.09976659834917102, 0.011714148834081633, 0.03405646986461111, 0.07784199874315943, 0.04984835462112512, 0.023783378436097076, 0.040712952680353603, 0.0605411199586732, 0.03732528178287404, 0.1018380436248013, 0.09195127950182982, 0.017771724411951642, 0.02280308023494269, 0.0632655873362507, 0.039563117415777276, 0.06085640125508819, 0.12198204520557608, 0.06606202013790607, 0.013813007772634072, 6.121467615876879, 43.97291851043701, 93.18316677638462, 107.61184460776192, 93.72543198721749, 89.12175709860665, 89.83861664363316, 65.80156680515834, 47.15990086964199, 29.376177651541575, 20.368051835468837, 25.81079987117222, 28.020651851381572, 44.12262439727783, 46.5694568497794, 34.38753114427839, 10.778273207800728, 2.0651199179036275, 0.1378491794956582, 0.14092564369950975, 0.06644643736737114, 0.05932469666004181, 0.16148477979004383, 0.046434621193579266, 0.22550459951162338, 0.04469293036631175, 0.26884415107113974, 0.1907900558518512, 0.1343824898025819, 0.20866885648242064, 0.5638358390757016, 0.4942718861358506, 0.7464136534503528, 0.6767082395298141, 0.5929355461682592, 0.4745745573725019, 0.9044090669069971, 0.7385962786419051, 1.0394071915319987, 0.9035172547612871, 1.0181074887514114, 1.0575631601469857, 1.6647127121686935, 1.2153265689100539, 0.6591741889715195, 1.0834760325295585, 2.3690606142793382, 2.1527618893555234, 1.7963803155081612, 2.268737311874117, 0.857124078486647, 0.5249782013041633, 0.17218408281249659, 0.46285262065274374, 0.9775937369891575, 0.6077762469649315, 0.4294196803654943, 0.2720122853560107, 0.20375547584678444, 0.6320166119507381, 0.5066490162696157, 0.3506034681839602, 0.09009554729397808, 0.05367736505078418, 0.4548525299344744, 0.2861046977341175, 0.07738043208207403, 0.025248642578454952, 0.23974813520908356, 0.3318207503429481, 0.1967664158770016, 0.8406956600291389, 9.762734055519104, 28.165754556655884, 50.643060616084504, 42.96086474827358, 33.054974351610454, 17.94916156360081, 17.443042618887766, 26.811858109065465, 30.52033403941563, 39.38600615092686, 65.1843513761248, 72.49083382742745, 80.88466766902378, 73.81217970166887, 86.49619265965053, 78.33737468719482, 32.5600437436785, 3.6023104957171848, 0.4049526032592569, 0.019923053615327393, 0.023227278276213577, 0.09404247014650277, 0.065563242616398, 0.04757025132754019, 0.017250565412853445, 0.047244445952985964, 0.028039937173681598, 0.049346482979932, 0.04383348434099129, 0.042423949976052554, 0.004108141500702394, 0.05086756171658635, 0.034888330048748424, 0.03951297028522406, 0.019926176572750722, 0.012107594820138599, 0.04109622318563717, 0.04919413151219487, 0.021663151581638625, 0.04460292608876314, 0.044897155836224556, 0.07635547779500484, 0.05833195921565805, 0.0607949463384492, 0.05536808093477573, 0.020788988131763678, 0.017226046549954584, 0.02897312638482877, 0.030517645113702332, 0.05628080552976046, 0.08494974127305405, 0.041115809098950455, 0.02807903436145612, 0.07888339393373046, 0.015555179511596049, 0.026351282339809195, 0.03653457474761775, 0.04264280805364251, 0.01934247530464615, 0.009484698197671344, 0.02570699298355196, 0.046702455928815265, 0.08953426991190229, 0.12905972184879438, 0.13854722918144294, 0.16478693831179822, 0.22068135546786444, 0.10439673132662262, 0.09722960341189589, 0.10267401233847652, 0.07778782450727054, 0.09653181156941823, 0.12422119719641549, 0.13525670074990817, 0.11521654895373754, 0.19044112600386143, 0.20331797003746033, 0.1697866286018065, 0.14219814113208226, 0.1763447102691446, 0.1459118989961488, 0.1265689419316394, 0.09304851812443563, 0.11794121989182063, 0.18708085774310998, 0.18734222943229334, 0.19170069055897848, 0.14382490169789108, 0.167289171900068, 0.24475528938429697, 0.17236065119504929, 0.1715272744851453, 0.16333380128656114, 0.1478615200945309, 0.12860981241932937, 0.14706589707306453, 0.09196071113858904, 0.1060614287853241, 0.19527944709573472, 0.09428625420800277, 0.09079525260520832, 0.307765679700034, 0.13282284992081778, 0.13514193333685398, 6.735457343714578, 49.36493253707886, 104.85401426042829, 115.66640486036027, 95.18019022260393, 80.3797629220145, 80.02903175354004, 59.62887750353132, 44.00639145714896, 42.339938981192454, 65.10981804983956, 77.80410739353725, 59.40827914646694, 66.29647309439522, 63.00040749141148, 49.77924319675991, 18.7799802507673, 5.421523894582476, 0.7899193103824342, 0.16915660883699143, 0.14087674846606596, 0.2660961385284151, 0.32776335520403727, 0.31482852356774466, 0.48443231412342613, 0.1903794335999659, 0.32434798989977154, 0.42196382901498247, 0.10079459925847394, 0.23536485327141626, 0.27802643978169983, 0.22847517154046468, 0.5488921095217977, 0.49553944383348736, 0.3226651959121227, 0.30875264959675924, 0.2772924820227282, 0.39377270745379583, 0.3972547048968928, 0.4851267540029117, 0.5747322429503713, 0.4932565263339451, 1.7101432915244783, 0.9834455315555845, 0.6093869262507984, 1.6676966377667017, 1.8525297939777374, 0.6504834038870675, 1.0283332828964507, 0.8366214100803647, 0.3731045579271657, 0.3422403340893132, 0.14357190313083784, 0.37764645421079224, 0.534542342381818, 0.5629952698945999, 0.2383417221052306, 0.27339429834059303, 0.4299867999340807, 0.20563684989299091, 0.2943979427218437, 0.2208045231444495, 0.20512949568884714, 0.25237328346286503, 0.33126440591045786, 0.5504377037286758, 0.548893466591835, 0.19399365037679672, 0.3413513446492808, 0.473682202398777, 0.2644901004220758, 2.0969563467161993, 21.591337782996042, 49.34360156740461, 86.4846030644008, 79.06314182281494, 86.61775139399937, 81.21954304831368, 53.08849300657, 38.68544707979475, 28.195251396724156, 34.77575479234968, 55.66495105198452, 66.12674944741386, 76.15756498064313, 78.10686819893974, 97.65293598175049, 89.2051910672869, 33.603402614593506, 3.2208952137402127, 0.5196803627269608, 0.27847427289400783, 0.16142945204462322, 0.15453535983605043, 0.17411010446293013, 0.13844048205230916, 0.18015586504978792, 0.2569381685129234, 0.23089846436466488, 0.1113765292934009, 0.1480430689241205, 0.13010571072144167, 0.12575301714241505, 0.14569759049585887, 0.08308391246412482, 0.09759081474372319, 0.13079898352069513, 0.08120394977075712, 0.19324891748172895, 0.23078471475413867, 0.09441140320684228, 0.09649876691401005, 0.1352651688669409, 0.16715290849762304, 0.13079290384692804, 0.17396952557776654, 0.21948961727321148, 0.10145344319088118, 0.07259906721966607, 0.16295671223529748, 0.147958672738501, 0.14363193990928785, 0.16726561316422053, 0.11768637570951666, 0.15083514553095612, 0.17436361871659756, 0.14889602815466269, 0.13502219904746326, 0.17280705938381807, 0.25327215237276895, 0.08008482160844974, 0.13244426809251308, 0.16552982559161528, 0.07577778665082795], [0.042565909679979086, 0.046021573179002316, 0.03662805651713695, 0.039766284371060986, 0.037168173784656186, 0.03360421948933175, 0.021104415313207676, 0.0794962535479239, 0.036128291727176735, 0.01890581427142024, 0.040707174954669814, 0.07747807327125754, 0.0659487455018929, 0.05959737952798605, 0.04085460704352174, 0.07291055550532681, 0.006755983190877097, 0.04580654203891754, 0.03306793933734298, 0.0134584342096267, 0.044245324563235044, 0.0063872846492033985, 0.015067407828090447, 0.01710332161746919, 0.05133220214130623, 0.04690724119011845, 0.08111823044185128, 0.03201358073524066, 0.050745876639017036, 0.05788308794477156, 0.06622068198131663, 0.03700090811720916, 0.03672015746789319, 0.04856516347665872, 0.035263627767562866, 0.07621759947921548, 0.021483294000583034, 0.0926160809717008, 0.018617906773995076, 0.14400274572627886, 2.863982971225466, 28.337734631129674, 63.50162969316755, 85.95437213352749, 84.87669263567243, 58.6592355455671, 62.23085975646973, 38.47611175264631, 23.657931804656982, 33.74346440179007, 37.25739771979195, 51.302375180380686, 63.061544690813335, 57.45716939653669, 59.37455953870501, 35.18088340759277, 16.51355603763035, 3.734134759221758, 0.3042500269200121, 0.10109695446278368, 0.04501278159607734, 0.0677755381911993, 0.07601990151618208, 0.14691748789378575, 0.08243432374937193, 0.04195756910900984, 0.03760287045900311, 0.059688920687351904, 0.083538157732359, 0.0662712531962565, 0.218915834490742, 0.04880132080454912, 0.22629480782364095, 0.28041328170469826, 0.06442989236009972, 0.18768304400146008, 0.23019221797585487, 0.4780282463346209, 0.28992422563689096, 0.25128765457442825, 1.504280435187476, 1.5161060520580836, 1.4053578461919511, 2.0504238264901296, 2.771007171698979, 3.9708042996270314, 1.9533459842205048, 2.287306372608457, 1.052645246897425, 2.944423569100244, 1.4387529513665607, 0.8161384463310242, 0.6559417024254799, 0.1298313790134021, 0.4149771439177649, 0.024938803132889525, 0.18881158344447613, 0.4476630985736847, 0.052324176233794005, 0.2375853726906436, 0.19300514699092933, 0.08117925109607832, 0.17110659634428366, 0.038419650202350955, 0.06162668099360807, 0.09804938906537634, 0.08571687260908739, 0.02782236661628953, 0.044520121067762375, 0.08890243845858745, 0.007552883554516094, 0.1661924421787262, 0.06036787639771189, 0.03261557700378554, 0.3248014412820339, 0.9858212726456779, 15.023527009146553, 40.54000118800572, 60.29762772151402, 69.76968302045549, 73.87017631530762, 52.34427840369088, 49.685428619384766, 35.05369315828596, 23.532020023890905, 32.26658657618931, 38.91111414773123, 50.771202768598286, 55.563059193747385, 71.35701983315604, 72.67067405155727, 51.399444988795686, 4.674718916416168, 0.2783755867608956, 0.06876114423253707, 0.04419211384707263, 0.22688681605671132, 0.0115331326544817, 0.06901558129382984, 0.06326694440628801, 0.031646472934101305, 0.024217320240235755, 0.03675889163943274, 0.06524085705833775, 0.05823754785316331, 0.02749736700206995, 0.05125611461699009, 0.062162479385733604, 0.024917997552880218, 0.05395108607730695, 0.0022486188266027185, 0.06911767367273569, 0.046656261264745674, 0.02967096572475774, 0.011858356185257435, 0.05630379429619227, 0.030167795850762298, 0.031565116585365365, 0.017742421877171313, 0.02278300916909107, 0.028746495688600198, 0.01382944273895451, 0.034994836297950575, 0.02022394657667194, 0.011347286153717764, 0.03548006347513624, 0.05953684741897242, 0.09813656045922212, 0.03874750814533659, 0.04665176257757204, 0.03676267786483679, 0.042444699576922824, 0.1065295229532889, 0.029867316795779125, 0.036531497591308186, 0.018801389428387796, 0.030184789760304347, 0.002377313170914671, 0.04707675620115229, 0.042098758675690205, 0.03615897508072002, 0.03431412657456739, 0.004095560613287879, 0.06865291789706264, 0.021443867723324468, 0.04949008813127875, 0.01873578187743468, 0.03603557330955352, 0.0006830513583346536, 0.007429813417339963, 0.029231648226933818, 0.02639001651134874, 0.020516703903142895, 0.021951744399432625, 0.014618092116766741, 0.026608872892601148, 0.0670193312689662, 0.040686262505395074, 0.03259808437100478, 0.04020400391891599, 0.08819215478641645, 0.06475702087794032, 0.024851168638893535, 0.0414232804573008, 0.014740696609286326, 0.017141434929466674, 0.009031008479983678, 0.005500700615812093, 0.07719055084245545, 0.09848490676709584, 0.041977816593966315, 0.050522431664701016, 0.03661820079599108, 0.10037300509533711, 0.05575744807720184, 0.056319370067545345, 6.565758449690683, 43.44075945445469, 81.98363644736153, 101.69208363124302, 94.64469255719865, 76.97161592755998, 79.18644455501011, 56.61818136487688, 34.148242133004324, 29.587924003601074, 22.318359068461827, 31.654512814113072, 50.019741194588796, 57.3968242917742, 65.349287714277, 36.88065596989223, 15.6540048122406, 2.4056732782295773, 0.15562097515378678, 0.1243633231414216, 0.010149129865957158, 0.03235624431233321, 0.15243871376982757, 0.20077779277094773, 0.05032918828406504, 0.06890281555908066, 0.11291558242269925, 0.38365862731422695, 0.2503041587769985, 0.21493615875286715, 1.1557727988277162, 0.9931070016963142, 1.2387298388140542, 1.3465239746229989, 1.3826120495796204, 1.1869327553680964, 1.3427124534334456, 1.7242478089673179, 3.0578338035515378, 2.4466911000864844, 3.629224342959268, 6.455951724733625, 6.530535859721048, 3.621621710913522, 5.515232077666691, 5.768556015832083, 6.495414452893393, 5.06034654378891, 3.679133687700544, 5.338073858192988, 4.809425813811166, 6.083164802619389, 3.6626308475221907, 2.35053237421172, 2.9707285804407935, 1.274034395813942, 1.2581384373562676, 1.9063175363200051, 1.8542080010686601, 1.9088733877454485, 1.3231748789548874, 1.0184018101011003, 0.8672059689249311, 0.3930839944098677, 0.29082998846258434, 0.23748828790017537, 0.5072427615523338, 0.05350469145923853, 0.27667903208306854, 0.2045089482728924, 0.24979181055511746, 0.2666327783039638, 0.037710150238126516, 0.016707983366878967, 0.29078145963805063, 0.4918196605784552, 10.32426140989576, 33.68711798531668, 57.12817914145333, 54.619907242911204, 40.87751688276018, 18.778953654425486, 24.64860074860709, 31.66783251081194, 33.08723136356899, 53.53821863446917, 62.72842025756836, 75.43596676417759, 74.14123943873814, 82.01773820604596, 85.87831715175084, 71.7634060723441, 10.945146356310163, 0.12427087953048092, 0.057848428376019, 0.06751852269683566, 0.16319528514785425, 0.01825711613387934, 0.05087745136448315, 0.09299228114209004, 0.018900268943980336, 0.024564869269462566, 0.035897532145359685, 0.045841228749070845, 0.018169439231444682, 0.04347753504823361, 0.02272551180794835, 0.05051716623295631, 0.009509194160013326, 0.07800203122730766, 0.024353271516572152, 0.02766212378628552, 0.034612861794552634, 0.06150230552468981, 0.020783944920237576, 0.08009596315345593, 0.03424424086032169, 0.04509028047323227, 0.10144179274461099, 0.05202374467626214, 0.0437810166206743, 0.044612931087613106, 0.10739440404410873, 0.039129849057644606, 0.02882036779608045, 0.021882691586922322, 0.051704300567507744, 0.04544564283319882, 0.06200357326971633, 0.05579663347452879, 0.023553249891847372, 0.0511965663837535, 0.04388231172093323, 0.037057830419923575, 0.039052421426666636, 0.019343155536002347, 0.1112178403085896, 0.10685486013868026, 0.09160547091492585, 0.13017170503735542, 0.15643198734947614, 0.10905503029269831, 0.13852267978446825, 0.31013753956982065, 0.10228374613715069, 0.17040571038212093, 0.10486030645136322, 0.17129765823483467, 0.12302564563495771, 0.1924093525324549, 0.1300177454416241, 0.14236647209950856, 0.11233200159456048, 0.10892141317682606, 0.05354232301137277, 0.0685895291556205, 0.1409222103123154, 0.12635931532297814, 0.14566637788500103, 0.14781404978462628, 0.1420216948858329, 0.13444009742566518, 0.22756130700664862, 0.11738558113574982, 0.1604342447327716, 0.16239770794553415, 0.27188911767942564, 0.14407211914658546, 0.19537212140858173, 0.21848522259720735, 0.110674944440169, 0.3046223797968456, 0.20267360604235105, 0.2562717657004084, 0.18475896519209656, 0.24817250030381338, 6.484565275056021, 44.687467779432026, 94.2755834034511, 109.04465348379952, 102.70864677429199, 75.0000923701695, 80.08258846827916, 51.02300895963396, 32.83519588197981, 47.65798943383353, 51.628770283290315, 74.37394850594657, 90.60712909698486, 81.19633606501988, 84.97925499507359, 48.78429937362671, 25.2200014931815, 5.035649606159755, 0.7431378492287227, 0.19028446583875588, 0.09827254566230945, 0.31952813853110584, 0.3452094947653157, 0.3613124335450785, 0.16098554086472305, 0.12279533727892808, 0.09553004960928645, 0.24991131414260181, 0.23581683901803835, 0.16174796995307716, 0.6525474531309945, 0.32428198201315744, 0.6484532813940729, 0.43840348401239937, 0.3021655673427241, 0.5568169642771993, 0.5673824059111732, 0.9703492628676551, 1.1557175389357974, 1.4184825590678622, 5.082300680024283, 5.403241881302424, 6.076641746929713, 4.411435169833047, 9.12871961934226, 10.895458919661385, 8.553077868052892, 6.296471459524972, 4.3165028010095865, 8.317956038883754, 4.948098395551954, 3.0984414645603726, 2.4812034538814, 1.3320728072098322, 2.2866760407175337, 0.5121824964880943, 0.5125236096126693, 1.181652992963791, 0.9622233446155275, 0.9808552648339952, 0.32715937761323793, 0.6041764287011964, 0.5867942614214761, 0.22779332527092525, 0.3205661342612335, 0.26375882966177805, 0.23976857268384524, 0.1279361221407141, 0.1894061972520181, 0.25176333476390156, 0.39940978639892166, 0.4875014637197767, 0.18659077904054097, 0.21113215573132038, 0.48481848197323935, 1.860401234456471, 20.485809905188425, 56.966240950993125, 83.02927085331508, 97.41677365984235, 104.266724722726, 70.33572496686662, 63.92886747632708, 47.985242639269146, 31.51884228842599, 43.27660826274327, 49.57935394559588, 68.18894699641636, 71.90385001046317, 87.8134182521275, 96.97415951320103, 78.12735148838588, 9.516258001327515, 0.40874849100198063, 0.1613086320992027, 0.18923292654965604, 0.3316584990492889, 0.09188985172659159, 0.13980611520154135, 0.21742362741913113, 0.11342107065554176, 0.1165267186505454, 0.142209920500006, 0.18512792539383682, 0.15952811549816812, 0.09090470030371632, 0.18318551033735275, 0.22445346734353475, 0.07443709644888129, 0.14433849842420646, 0.2403634036225932, 0.12391478435269423, 0.11490378502224173, 0.15994464100471564, 0.1792308861123664, 0.14877579174935818, 0.10161346888967923, 0.12405354476400784, 0.20950357669166156, 0.10576081741601229, 0.13457386381924152, 0.11674717467810426, 0.2608846096055848, 0.0773874209927661, 0.09035649829144989, 0.07824061771056481, 0.13416831700929574, 0.17677747990403855, 0.22539581677743367, 0.17889760328190668, 0.11457339275096144, 0.1929518412798643, 0.1954055324729, 0.20124979530061993, 0.16291519946285657, 0.09349521129791226], [0.021179505391046405, 0.09890063160232135, 0.022041461995935867, 0.02760604117065668, 0.02336460697863783, 0.028624953103384802, 0.021467132992776375, 0.06774936031017985, 0.037817715001957755, 0.02732067139420126, 0.04453994107565709, 0.032173837135945044, 0.006396961830822485, 0.006160357093904167, 0.0781189835231219, 0.021618615935689638, 0.07510643731802702, 0.030305097411785806, 0.039511236628251414, 0.05427646058212433, 0.03668392030522227, 0.018050717655569315, 0.016025996301323175, 0.036668544701699696, 0.06347866090280668, 0.03993612168622868, 0.022817275187532817, 0.04354983973982079, 0.02137422458534794, 0.023341416348037974, 0.02237847676899816, 0.0586993723575558, 0.060165123348789554, 0.012751861275838954, 0.055763140986008305, 0.02903368224256805, 0.09375568053552083, 0.186441962740251, 0.3072713262268475, 18.492076431001934, 69.25880977085659, 83.04765578678676, 85.9021703175136, 63.10311576298305, 67.97164903368268, 56.14289678846087, 70.29519612448556, 82.73364584786552, 52.292396204812185, 53.353327069963726, 61.75806958334786, 67.5274715423584, 52.024480615343364, 45.638658796037944, 16.56525410924639, 4.3971492392676215, 0.22028424963355064, 0.031938575474279265, 0.016275437648541162, 0.06136131951851504, 0.052136900568647046, 0.05665047140792012, 0.05526255177600043, 0.1051901016118271, 0.019112241587468555, 0.07327703905424901, 0.2874085706259523, 0.11794930802924292, 0.40727805133376804, 0.07583939763052122, 0.6970865460378783, 0.6257238239049911, 3.09442258306912, 1.8724648271288191, 1.48871625321252, 2.2840722032955716, 1.1749689344848906, 1.5144778937101364, 5.717569700309208, 2.2692330224173407, 2.6874991612774983, 7.58417763028826, 7.581962891987391, 3.454750733716147, 3.7890064205442155, 1.9536343344620295, 3.4625120886734555, 1.9974327385425568, 5.922092531408582, 10.45505690574646, 5.063594826630183, 17.638980082103185, 3.715585674558367, 1.0913606094462531, 2.3075694910117557, 0.4998596491558211, 2.6479969152382443, 1.1826996739421571, 2.1868210903235843, 1.5793639719486237, 1.3399351281779153, 3.1746440955570767, 2.0300245668206895, 0.7113821389419692, 0.23565561909760746, 0.4177490680345467, 2.306960220847811, 2.638385168143681, 0.12471552352820124, 0.03611513493316514, 0.12327394873968192, 0.03118918782898358, 0.11629016777234417, 0.10125654589916978, 0.05986154678144625, 0.04235424068091171, 0.39646687145744053, 0.402134864458016, 8.768779482160296, 21.554159709385463, 46.68628733498709, 77.48836735316685, 84.35675198691231, 66.1247136252267, 38.42309004919869, 27.018339463642665, 20.536750623158046, 36.285667828151155, 39.162472179957796, 50.39480495452881, 55.539681979588096, 65.63282285417829, 57.34762062345232, 17.579211677823746, 0.5538161024451256, 0.3938307086271899, 0.11663700773247651, 0.04121702956035733, 0.10065151657909155, 0.02421791904738971, 0.14554447228355066, 0.07289439280118261, 0.014537660271993704, 0.028190012156431164, 0.05343339439215405, 0.038082167240125794, 0.025097585416265895, 0.014839196145268423, 0.004447241072609488, 0.0316962299070188, 0.03620871848293713, 0.026588131773418615, 0.043541018784578354, 0.0018104124298718358, 0.06751205625810794, 0.017369758570566773, 0.013771206622810235, 0.03477910965947168, 0.04694885913548725, 0.041640350595116615, 0.017222129706559435, 0.023943887591095905, 0.00501703067649422, 0.037810346111655235, 0.06101943286401885, 0.04273303285507219, 0.033821438904851675, 0.07086003624967166, 0.03355789929628372, 0.04073091350229723, 0.04021691983299596, 0.01726070781504469, 0.009882812504656613, 0.05620333379400628, 0.018206170028341667, 0.02201713990819241, 0.029145640520645038, 0.016644406331969158, 0.062492403467851024, 0.12698932151709283, 0.040425606670656374, 0.037937367867146216, 0.007944322773255408, 0.03369247314653226, 0.024377639405429363, 0.08772823360881635, 0.08061419427394867, 0.020535093898485814, 0.034531033863978725, 0.019995821407064795, 0.02904852180342589, 0.046321122641009946, 0.024357376653434973, 0.04014624362545354, 0.004375609402943934, 0.04321797504755003, 0.05135540125359382, 0.031140200993312255, 0.030775284860283136, 0.07519242127559014, 0.028547427084829127, 0.044990674925169775, 0.005571181320452264, 0.022897632393453802, 0.06030965130776167, 0.06553148717752524, 0.07278552185744047, 0.02110991144685873, 0.06695509435875074, 0.03952469537034631, 0.07400512069995914, 0.036336971779486964, 0.20542497054806777, 0.24431386164256505, 1.073119416832924, 30.609496797834122, 90.50482382093156, 95.48946149008614, 104.08885083879743, 76.60876710074288, 91.0677877153669, 83.17199380057198, 88.94170148032052, 71.70703533717564, 34.019485064915244, 40.719615595681326, 43.822288513183594, 60.74414675576346, 55.33163206917899, 46.90452330453055, 13.475699390683856, 2.808198924575533, 0.2571381192122187, 0.021144856000319123, 0.02949282992631197, 0.1617571980293308, 0.14288575494928019, 0.1617981136909553, 0.18354612455836364, 0.10699983593076468, 0.1782314040298973, 0.14987870971007006, 0.47247690707445145, 0.3067396261862346, 0.9436697001968111, 1.3447410017251968, 3.106574982404709, 1.6702509692737033, 3.2242733410426547, 6.129949195044381, 6.481519358498709, 7.967684320041111, 6.122487264020102, 6.201689779758453, 10.10421543461936, 5.964328893593379, 4.817315493311201, 10.214724796158926, 12.787664447511945, 8.090727363313947, 7.853871958596366, 9.494853207043239, 7.837840727397373, 5.023238386426653, 6.1838841523442944, 4.333237103053501, 4.464286642415183, 4.027874197278704, 2.6722960684980666, 4.350680555616107, 3.3234104556696753, 7.3104976415634155, 4.417813616139548, 4.311299034527369, 2.3238432577678134, 3.5468217475073676, 3.2504990994930267, 2.975134824003492, 1.1768410397427422, 1.446099585720471, 0.17706554516085557, 0.4119281603821686, 1.3506887682846613, 5.0250913841383795, 0.9691303968429565, 0.2588070439440863, 0.21459527633019856, 0.09223334650908198, 0.16464155539870262, 0.10508791423801865, 0.014427305032898272, 0.11443130751805645, 0.5147341138550213, 0.12614609247871808, 6.382232206208365, 20.200537715639385, 48.375912053244456, 65.00555338178361, 60.50125857761928, 38.43655913216727, 15.646695307322911, 24.662703854697092, 28.808565412248882, 55.52373586382185, 61.63533660343715, 69.9092584337507, 68.98353603907994, 72.7871675491333, 73.16773428235734, 30.838102953774587, 1.2104297173874718, 0.2958405895956925, 0.15431315318814345, 0.05480031675792166, 0.20243146403559617, 0.05547058382736785, 0.12356848722057683, 0.03964947796027575, 0.025070912204682827, 0.04161928208278758, 0.018606821208127906, 0.02820632922729211, 0.04997990220519049, 0.021334978119869317, 0.02500829190414931, 0.01537465866255973, 0.010240396218640464, 0.029934549438101903, 0.02007559168019465, 0.009834836686163076, 0.026672287079106485, 0.029049553176654235, 0.018241538666188717, 0.017925857034112726, 0.05555412166618875, 0.043426600817058764, 0.06511402529265199, 0.06743656923728329, 0.032670212643487115, 0.04311976728162595, 0.03806077981633799, 0.015714256957705532, 0.006744413320640368, 0.03076403814234904, 0.036829998716712, 0.045085425555173836, 0.031944621221295426, 0.004948766236858708, 0.020462309143372943, 0.07301371996956212, 0.033476261355515034, 0.0404063668102026, 0.12824979530913488, 0.2088147279407297, 0.14311915742499487, 0.20207508387310164, 0.11757064477673598, 0.11775194933371884, 0.08728800008871726, 0.12336236185261182, 0.19696841575205326, 0.3982443617922919, 0.16953411857996667, 0.11057460268161126, 0.12555240147880145, 0.10861426751528468, 0.16882190108299255, 0.06867488207561628, 0.13881481625139713, 0.1409250194472926, 0.15214950857417925, 0.12080983524875981, 0.15181089245847293, 0.11901075392961502, 0.08241549440260444, 0.1314232764499528, 0.2296680361032486, 0.1520373738769974, 0.08825371826865844, 0.1949414416615452, 0.08361867948302201, 0.11321134226662771, 0.1194744376199586, 0.15301902405917645, 0.1142996581537383, 0.1671595581408058, 0.19771203584969044, 0.06595348846167326, 0.32472088560462, 0.5109071763498443, 1.4077732137271335, 34.18904890332903, 100.54219845363072, 109.32524953569684, 106.70379843030656, 80.41329492841447, 89.72322096143449, 72.33683395385742, 82.82894039154053, 92.80764443533761, 75.58563791002545, 75.13598523821149, 84.51381601606096, 90.87674699510846, 70.5226662499564, 60.158371925354004, 20.24307632446289, 5.678822636604309, 0.5309676027723721, 0.12482240636433874, 0.1800674247954573, 0.31836977068867, 0.3279404528439045, 0.1865784568446023, 0.18310989439487457, 0.16493762736873968, 0.4048542156815529, 0.23436070286801883, 0.969100758433342, 0.4698521707739149, 0.8077782435076577, 0.7809377866131919, 1.752582779952458, 3.308939095054354, 8.46559657369341, 7.9614161763872415, 6.2593889236450195, 8.452698111534119, 6.600866394383567, 6.764438714299883, 15.90684802191598, 6.72927952664239, 11.423019136701312, 18.83632493019104, 20.67794496672494, 13.587897164481026, 11.225044982773916, 13.44197370324816, 11.698820063046046, 9.978159478732518, 19.736879212515696, 24.499726908547537, 19.305613211223058, 35.75693770817348, 12.22916042804718, 8.546482290540423, 9.901286346571785, 7.235084065369197, 7.511615855353219, 5.830157441752298, 5.358426000390734, 4.045615553855896, 4.545907131263188, 10.537128158978053, 5.44300251347678, 3.232340851000377, 0.44159884112221853, 0.7031026003616196, 4.335209957190922, 6.836096789155688, 1.2437788993120193, 0.3826720102557114, 0.28015489556959694, 0.1929612322045224, 0.30814734207732336, 0.5543619702969278, 0.11736453297947134, 0.22854715053524288, 0.616807222366333, 0.9912579123462949, 11.954186337334768, 33.381682123456685, 64.04462446485246, 104.1118493761335, 112.15089430127824, 80.2816960471017, 51.129052366529194, 37.29412589754377, 28.614458799362183, 45.948885440826416, 52.3398107119969, 67.6677417755127, 70.19905390058244, 83.87191363743374, 82.94494751521519, 30.99913787841797, 0.9079360919339317, 0.5660595340388161, 0.4111995223377432, 0.15475455378847464, 0.22331295854278974, 0.13344069676739828, 0.2200588131589549, 0.17199794708618096, 0.08404722184474979, 0.13594054191240243, 0.14675833071981156, 0.13559702677386148, 0.14084290313933576, 0.08298799475388867, 0.08206264262220689, 0.12632000100399765, 0.08464826816426856, 0.19515406739498886, 0.25356213109833853, 0.09883782640099525, 0.14828849504036562, 0.1375598521637065, 0.07632474015866007, 0.16743745894304343, 0.10389373331729855, 0.11940221435257367, 0.11699820549360343, 0.10318511205592326, 0.1598038449883461, 0.1197925755488021, 0.10713783638285738, 0.0855963376483747, 0.12797706494373934, 0.17223346659115382, 0.10071555671415158, 0.15385637698428972, 0.10969569627195597, 0.05756055310900722, 0.0898883023432323, 0.14851916980530533, 0.1459488927253655, 0.08156868269933121], [0.046232909695910554, 0.03797665165205087, 0.03463510756513902, 0.011662108590826392, 0.013861630743901645, 0.04644470422395638, 0.01264089111438287, 0.06631319344575916, 0.040649150032550097, 0.10321352910250425, 0.11544426530599594, 0.05101116008258291, 0.07067803280161959, 0.009416668276701654, 0.023836606115634953, 0.07180980207132441, 0.05134031742012926, 0.007597957787636135, 0.012344789458438754, 0.048169387570981465, 0.011670381629041262, 0.018107930032004203, 0.040029420251292844, 0.0739664781306471, 0.02014335018715688, 0.023767365009656975, 0.04860927503822105, 0.027788799488916993, 0.03606296576825636, 0.01674237152162407, 0.023064614772530537, 0.043941513901310306, 0.02747498213180474, 0.08219872960554701, 0.04075445527476924, 0.15502618492713996, 0.3254670027111258, 7.269705636160714, 51.479293687003, 87.89325305393764, 83.07511506761823, 80.0299767085484, 64.71742548261369, 67.40739277430943, 48.9943607875279, 27.782663890293666, 33.46907309123448, 57.38229213442121, 49.70103774751936, 47.12734508514404, 67.33625016893659, 58.12098291942051, 26.320517982755387, 3.239836437361581, 0.02594583391744111, 0.057066416767026694, 0.18443569753851208, 0.05197171461103218, 0.039984728542289565, 0.02412868321074971, 0.09278513797159706, 0.033506720792502165, 0.12111418534602438, 0.11323578309799943, 0.048931182229093144, 0.2834998832217285, 0.4498670074556555, 0.622876202421529, 0.8746772365910667, 2.2213080397674014, 3.097045962299619, 7.652114510536194, 2.2915925426142554, 3.5900740666048865, 12.617636816842214, 4.201662106173379, 5.95309886762074, 4.3623756766319275, 11.625215189797537, 6.189633786678314, 3.9856790900230408, 8.777632355690002, 6.397691948073251, 5.222482323646545, 3.6663446596690585, 4.577512315341404, 6.159950648035322, 5.163444348743983, 3.0155305649553026, 5.671658609594617, 4.322139527116503, 13.265481642314366, 5.345070694174085, 3.3776834862572804, 4.709403455257416, 9.142171331814357, 4.245123088359833, 5.4095026424952914, 4.35850726706641, 4.75491806438991, 7.4592620474951605, 4.594990943159376, 2.610990809542792, 1.5940087118319102, 0.788394886468138, 1.0842612875359399, 4.326265888554709, 1.688236055629594, 1.6153152542454856, 0.44836578943899696, 0.08282880365316357, 0.09975450006978852, 0.03000838422615613, 0.056295461886163266, 0.09801654118512358, 0.07447586793984685, 0.26509798637458254, 0.053441156832767386, 0.23759807486619267, 0.2067009692213365, 5.400834330490657, 33.60659531184605, 57.98070921216692, 58.95608343396868, 65.636581829616, 66.32441874912807, 47.47051313945225, 22.25823630605425, 25.270584378923687, 34.49031237193516, 56.29361711229597, 59.16664859226772, 65.05832495008195, 71.03668703351701, 49.015740394592285, 5.9594243339129855, 0.6129784935287067, 0.034257814953369756, 0.02143331989645958, 0.09020029274480683, 0.08276348108691828, 0.05355788521202547, 0.028331157618335316, 0.04031674251226442, 0.06664239149540663, 0.06386189069598913, 0.0321741119426276, 0.04127410453345094, 0.04172221923779164, 0.017397754925436208, 0.02649809356911906, 0.050593742302485874, 0.03298375689025436, 0.013255208730697632, 0.058958355603473525, 0.05807587331426995, 0.05434242436396224, 0.04715451292161431, 0.046090268064290285, 0.04211976272719247, 0.039668141065963676, 0.012086994496972432, 0.04795095018510308, 0.01619377595904682, 0.015096279493133937, 0.060146945395639966, 0.02424142519677324, 0.05808077233710459, 0.018104477985096828, 0.021410295506939292, 0.016828738851472735, 0.04956801448549543, 0.015729105000251105, 0.017685699742287397, 0.0666105749883822, 0.02061458257958293, 0.03991671897737043, 0.07726622106773512, 0.020316291800034896, 0.06184008704232318, 0.05177302598687155, 0.05115085008687206, 0.010834314527788332, 0.030705945366727452, 0.08775534108281136, 0.042871158836143355, 0.09072376894099371, 0.03828917131093996, 0.03249501490167209, 0.0715947946799653, 0.007052296040845769, 0.027774646944765533, 0.017502510554290245, 0.04022266363192882, 0.051184546135898144, 0.07530520736638989, 0.03347219014540315, 0.045104509352573326, 0.05129184287839702, 0.05949151449437652, 0.07153981977275439, 0.04513075847976974, 0.061840582372886796, 0.05208042270636984, 0.028147749602794647, 0.04964036667453391, 0.043236984206097465, 0.05464031141517418, 0.03512589194412742, 0.10462756215461663, 0.046720019807772975, 0.02341146830336324, 0.06036438872771604, 15.204273973192487, 74.05537360055106, 103.4506449018206, 93.48881108420235, 99.88305064610073, 86.38444478171212, 101.17117718287876, 73.07624040331159, 32.32043511526925, 28.61532211303711, 45.47661985669817, 41.36656584058489, 46.07925796508789, 70.11653014591762, 60.3165476662772, 23.0382410798754, 2.2317036305155074, 0.19933589228561946, 0.10730417245732886, 0.10408696651990924, 0.01732887513935566, 0.08452845245067563, 0.17896409971373423, 0.1602390030665057, 0.3650823469672884, 0.2559227815696171, 0.03359051647463015, 0.19924570141094072, 0.4880820725645338, 0.5665360827531133, 0.13894725271633693, 0.8747176772781781, 1.0271372156483787, 2.2136087843350003, 3.1688655827726637, 1.9633481332233973, 6.149560051304953, 8.42945030757359, 9.648361495562963, 12.444224544933864, 9.006944622312274, 15.040798493794032, 11.873777440616063, 8.83704205921718, 10.572348577635628, 9.134723731449672, 12.296417253358022, 8.583380699157715, 9.71659801687513, 4.051906713417598, 3.533882247550147, 2.384918574775968, 1.4166189219270433, 2.3058485090732574, 2.737967836005347, 1.5826566581215178, 1.6006926617452075, 1.0755384755986077, 2.747068239109857, 3.225374413388116, 2.8723292776516507, 3.6760430421148027, 2.3113590819495062, 1.4285760117428643, 1.3259880308594023, 2.8313535792487006, 4.129759107317243, 2.183444917201996, 2.496218293905258, 3.467351726123265, 1.9142634528023856, 0.5777745768427849, 0.2835680624204022, 0.06983485804604632, 0.3151434723820005, 0.08503302466124296, 0.015550594311207533, 0.10819173018847193, 0.048386043802435906, 0.0897808156109282, 0.0215518396081669, 0.362454815102475, 0.32098259191427914, 3.432467209441321, 32.133108207157676, 55.616386617933, 52.58070475714547, 37.41332571847098, 24.895131519862584, 16.59510009629386, 18.182094710213796, 38.80918060030256, 54.76000724520002, 78.7789466040475, 74.69835294995988, 75.81170449938092, 81.48895944867814, 67.36944171360561, 13.040987951414925, 0.4164414224880082, 0.042779173236340284, 0.06532186735421419, 0.12728466066930974, 0.11143091387514557, 0.026671974952997904, 0.03530426862250481, 0.04639119155971067, 0.04633788924132075, 0.026249391825071404, 0.009657978229889912, 0.08937876325632844, 0.04234241720821176, 0.01765072126207607, 0.008243052056059241, 0.0664285376135792, 0.018293901213577816, 0.017313769253503, 0.061261859855481555, 0.011934102745726705, 0.016928592064817036, 0.0807908440807036, 0.025516672392508814, 0.025207575942788805, 0.0548419143472399, 0.07722857594490051, 0.05238225204604013, 0.0344578029720911, 0.051826911845377514, 0.004736458566705031, 0.025719756227252737, 0.03306967977966581, 0.044106832173253806, 0.06439566026840891, 0.027279925366331424, 0.034406831421490223, 0.03801912455154317, 0.04072122402223093, 0.06058156064578465, 0.04108042010505285, 0.13953945093921252, 0.162353603169322, 0.10394048438008342, 0.12606563179620675, 0.15153141745499202, 0.16176364411200794, 0.1745297648012638, 0.06554600782692432, 0.15879427987549985, 0.13875275743859156, 0.17154581206185476, 0.16617560093956335, 0.17068348904805525, 0.10483432534549918, 0.14942334485905512, 0.15313052093344076, 0.10206999403557607, 0.07791884283402137, 0.11928486850644861, 0.2061844276530402, 0.11771020585937159, 0.13092139123805932, 0.167148104469691, 0.14356644770928792, 0.16931018845311233, 0.1800318831311805, 0.10394723580351897, 0.1276943872549704, 0.14802090797041143, 0.11212468879031283, 0.12242512857275349, 0.10848582083625452, 0.14238080275910242, 0.22837653969015392, 0.15355281398764678, 0.20036259719303676, 0.30141556901591166, 15.637099845068795, 79.85529899597168, 116.49236501966203, 103.09407029833112, 99.10601275307792, 83.50324222019741, 89.06156485421317, 61.33131122589111, 38.08095727648054, 43.78594248635428, 76.43391568320138, 74.58618123190743, 67.52153778076172, 89.39542579650879, 74.22376319340297, 35.826742785317556, 4.767633702073779, 0.6448968893715313, 0.3510311623769147, 0.4505048846559865, 0.19428366981446743, 0.31584483331867624, 0.1757752972521952, 0.3668421139674527, 0.2795308604836464, 0.6960854083299637, 0.4021608659199306, 0.4055102233375822, 2.6600296752793446, 1.7032607751233237, 3.2197973983628407, 4.029770186969212, 7.877582686288016, 11.133769103458949, 13.94603511265346, 12.72751476083483, 21.499390533992223, 26.94254677636283, 14.070876002311707, 17.90153166225978, 12.92662581375667, 30.4225937298366, 22.711123364312307, 14.86794468334743, 19.17727824619838, 16.191955191748484, 17.750008821487427, 13.574791993413653, 16.010666268212454, 15.501912219183785, 12.711133514131818, 15.321352856499807, 17.409463712147303, 15.108288083757673, 30.77165733064924, 17.182134287697927, 19.595514638083323, 18.538745743887766, 17.282452378954204, 12.647912723677498, 12.397939120020185, 16.316383532115392, 18.6058167048863, 21.690373931612285, 12.094040547098432, 10.257450137819562, 6.91317445891244, 2.811714278800147, 2.592869039092745, 8.54145700590951, 4.478731947285788, 3.8528794731412614, 0.7725259608456067, 0.23349258516516003, 0.5001170582004956, 0.20678142990384782, 0.17810797851000512, 0.2598599674446242, 0.3928370890872819, 0.4406429481293474, 0.10089549063039677, 0.5984315712537084, 0.8174994790128299, 8.46013355255127, 43.788561957223074, 74.17117227826799, 81.04108551570347, 92.55900314876011, 88.01770223890031, 59.85902268545968, 31.434220177786692, 33.452727454049246, 45.854480266571045, 71.62508828299386, 76.73371655600411, 82.42403411865234, 94.7459625516619, 70.74211815425328, 11.896795954023089, 0.5698248605642999, 0.11818519394312586, 0.11297010949679784, 0.19611772282847337, 0.2174092424767358, 0.12517919364784444, 0.13842879767928803, 0.21360836071627481, 0.1575995832681656, 0.12208307906985283, 0.09761788829096726, 0.1854147014341184, 0.08223639508443219, 0.054032873295779736, 0.13934791407414845, 0.11241428075092179, 0.15543098534856523, 0.15002489329448768, 0.15674276995871747, 0.10653919207730464, 0.1521608265382903, 0.13974150509706565, 0.10159936214664153, 0.14977162331342697, 0.1358010351125683, 0.15312308418963635, 0.1631282323173114, 0.12146954770599093, 0.10149875575942652, 0.0992351086544139, 0.11928315859820161, 0.13821847896490777, 0.07167210695999009, 0.1496682417179857, 0.1291235312819481, 0.12675557977386884, 0.1086407575224127, 0.11728530723069396, 0.12299439231199877, 0.12089106946119241], [0.02494918811134994, 0.07723200254674469, 0.056821146713835854, 0.00963212180483554, 0.025993068436426774, 0.04107561607712081, 0.008313594252935477, 0.03341812447511724, 0.04861991446731346, 0.060930171582315645, 0.04105786560103297, 0.034491895964103084, 0.061067825981548855, 0.019281330817778195, 0.035149355685072284, 0.05232921774898257, 0.029135452317340032, 0.03001228240983827, 0.04656468278595379, 0.014210000800501024, 0.09834860943789993, 0.02583064411633781, 0.05688859988003969, 0.04662247022081699, 0.05078614769237382, 0.02103137271478772, 0.050868464168161154, 0.0685349138719695, 0.0032230824747655007, 0.0337138402142695, 0.021215179369651845, 0.044479951794658384, 0.05505033655624304, 0.05671435547992587, 0.07606843712606601, 0.18133652955293655, 19.800333636147634, 78.51444952828544, 92.704359463283, 74.987106187003, 83.1699023927961, 73.1631693158831, 54.78291198185512, 25.333734818867274, 25.947983367102488, 60.56555025918143, 64.84183992658342, 46.237635203770225, 59.39882959638323, 76.71324021475655, 38.03822585514614, 5.550831173147474, 0.22012684307992458, 0.05071591592526861, 0.050968609151563475, 0.15795475563832692, 0.09667549814496722, 0.05754992725061519, 0.016132092036839043, 0.09769957712186234, 0.01760439428367785, 0.03838207293301821, 0.7986414166433471, 0.12424977709140096, 1.714193331343787, 4.561105447156089, 1.9116326911108834, 2.9190203036580766, 1.7211450040340424, 4.368126613753183, 9.894834075655256, 0.8322147322552544, 2.300239358629499, 6.479681994233813, 7.674159407615662, 8.197551574025836, 6.566449795450483, 5.047062456607819, 6.190373335565839, 4.800482613699777, 2.2110622695514133, 2.994698997054781, 3.8874207053865706, 4.543673719678607, 7.422271575246539, 5.329904513699668, 3.034991600683757, 3.425392206226076, 2.886467776128224, 0.6464739133204732, 1.2402557283639908, 1.4465552355561937, 0.7320958588804517, 4.514333648341043, 1.7846607672316688, 9.528017827442714, 3.405108026095799, 2.4747157905782973, 2.951521153960909, 3.8604195713996887, 6.8952741622924805, 5.354504610810961, 9.749701840536934, 8.994644573756627, 13.730182375226702, 11.146983708654131, 6.004192011696952, 0.6473388554794448, 0.30492329650691574, 0.7643265979630607, 0.12025849840470723, 0.2368575217468398, 0.016876254962491136, 0.07693947931485516, 0.05373947136104107, 0.05493700424475329, 0.09870000236800738, 0.04904245857947639, 0.06184395469192948, 0.06929760080363069, 0.32571059678282055, 0.0703032643401197, 8.92542314529419, 55.706313678196494, 66.99858161381313, 58.081392083849224, 78.30856745583671, 60.06413350786482, 47.819364820207866, 19.946706124714442, 24.422379561832972, 59.47437735966274, 54.69086572102138, 54.3353715624128, 76.77906050000871, 60.23495497022356, 20.716894830976212, 0.02300861188476639, 0.20551256941897528, 0.11113648395985365, 0.1397004672991378, 0.018934619779299413, 0.05804250296205282, 0.05365055273952229, 0.026409312350941554, 0.0381854809820652, 0.03207146995035665, 0.03053137526980468, 0.015963803477851406, 0.019368563279775635, 0.0561927825744663, 0.021105550163026367, 0.05658251612580248, 0.032017862291208336, 0.023106493953881518, 0.016283183125779033, 0.008953504513816109, 0.007272041302972606, 0.010269517245303308, 0.00601919975763719, 0.035966878424265554, 0.032432474329003265, 0.01704039767251483, 0.0044631535669655675, 0.06501428064491067, 0.07418646596904312, 0.03088598445590053, 0.014437501717891012, 0.047931523727519174, 0.015607784635254314, 0.057853727734514644, 0.019385577545368245, 0.007345198404176959, 0.029173857399395535, 0.03810433158650994, 0.03294806594827345, 0.01814781262406281, 0.05513509236542242, 0.10449019952544145, 0.046444928140512536, 0.05821068465177502, 0.023775994278756634, 0.018060724350756834, 0.06697511114180088, 0.05045379784756473, 0.029350541132901396, 0.037595596563603194, 0.03021402783425791, 0.014339707858328308, 0.011028835250596915, 0.04385613723258887, 0.06904830025242907, 0.06997472446944032, 0.025572802505588958, 0.09457739322845425, 0.06326344995094196, 0.05429288452225072, 0.015791431834389056, 0.06107236538082361, 0.004471945260385317, 0.02526111914111035, 0.005851102884792323, 0.010638966840425772, 0.08591737970709801, 0.027775902234550034, 0.05359140144927161, 0.040006858961922784, 0.025468330165105205, 0.022420851280912757, 0.06136825414640563, 0.08096002321690321, 0.21962560926164898, 38.73853131702968, 98.64843218667167, 104.61430835723877, 92.53025845118931, 105.01990250178746, 98.54405634743827, 79.42665767669678, 41.04803262438093, 20.95588333266122, 32.945717402866904, 47.79628985268729, 38.978313650403706, 59.71763379233224, 77.3492991583688, 35.20208583559309, 3.2334015369415283, 0.27857195479529245, 0.008413939404168298, 0.030020848914448704, 0.05706554824220283, 0.1332390768719571, 0.16640884056687355, 0.11486881332738058, 0.23097142044986996, 0.15240910250161374, 0.10329577433211462, 0.27875724913818495, 0.7628890265311513, 3.9082557473863875, 8.098233154841832, 5.904105816568647, 5.9016687359128674, 4.444406109196799, 3.9213856714112416, 3.4481234550476074, 2.1190077577318465, 1.6934213659593036, 2.533905105931418, 3.4739824788911, 7.8630687679563245, 9.171308602605547, 8.73876586982182, 11.163161720548358, 10.258819801466805, 9.874845845358712, 6.49854895898274, 10.07146336351122, 8.300261582647051, 7.958863581929888, 1.333603907908712, 4.943317600658961, 1.869794330426625, 0.14646575999047073, 0.3517595561487334, 0.3703148833342961, 0.1124911859099354, 0.9564506943736757, 0.44812629371881485, 0.16239529236086778, 0.7797224489705903, 1.6986879919256483, 0.5757166615554264, 1.2193272113800049, 2.042265121425901, 4.892553627490997, 7.795336859566825, 14.051229970795767, 15.788153682436262, 19.991690499441965, 15.938271250043597, 8.876610313143049, 1.6894212663173676, 1.2440859228372574, 0.709265543946198, 0.3015508417572294, 0.2640081505690302, 0.026113094495875493, 0.014208303614785629, 0.03749944815146072, 0.1396165732294321, 0.08693499224526541, 0.04096535413659044, 0.043388853913971355, 0.0261813686894519, 0.20104798541537353, 0.3277346667434488, 6.590960434504917, 52.2345871925354, 73.2579288482666, 51.244781562260215, 51.03367791857038, 29.368906361716135, 25.64286364827837, 24.475104229790823, 41.74173034940447, 83.25563621520996, 74.46112060546875, 69.21047115325928, 86.52550710950578, 76.36892918178013, 37.51654815673828, 0.31972005537578035, 0.4318070922579084, 0.19590045591550215, 0.2140148574752467, 0.07395874961678471, 0.020945644904194132, 0.03571959990741951, 0.019552673579060605, 0.021697980784145848, 0.030305073663060154, 0.009911085362546146, 0.07355357600109917, 0.03331173696954336, 0.014099609090148338, 0.03758938118283238, 0.030434697600347654, 0.08003897978258984, 0.015387024963274598, 0.07525237662983791, 0.02262919206571366, 0.054978601834071536, 0.05963614423360143, 0.02230858087672719, 0.003992102258572621, 0.01792038804186242, 0.030771434174052308, 0.06983272066073758, 0.03821618129898395, 0.027795993656452214, 0.042625976992504935, 0.035833271486418586, 0.032085804002625604, 0.032442631998232434, 0.03846701194665261, 0.035465631035289595, 0.022481702301385145, 0.004922470884464149, 0.03410998252885682, 0.01615152527977313, 0.12159690872899123, 0.17267644139272825, 0.20695826970040798, 0.09536099260939018, 0.10983746259340219, 0.13365979572491987, 0.04498836112075618, 0.111329086124897, 0.16025023960641452, 0.10809230445218937, 0.09753419099641697, 0.09173704564039196, 0.2098916851516281, 0.14903339078383787, 0.166985351060118, 0.16451162951333181, 0.2117446150098528, 0.04966848177303161, 0.18513741131339753, 0.15416587037699564, 0.1399331098156316, 0.13606054761580058, 0.15524280044649327, 0.09158838540315628, 0.12050806358456612, 0.0972127282459821, 0.10237569441752774, 0.22057331912219524, 0.09430288510130984, 0.19012723570423468, 0.12947837795530046, 0.12844515911170415, 0.1800501492938825, 0.14539489602403982, 0.18341785429843835, 0.16490163787135056, 39.547447545187815, 112.40662969861711, 116.34772436959403, 95.6862553187779, 103.56235803876604, 93.11534540993827, 68.94017233167375, 32.78005845206124, 35.84197671072823, 82.13419001443046, 95.3297849382673, 67.20358126504081, 79.62764821733747, 94.82684653145927, 48.05826473236084, 7.763775535992213, 0.42589485379202024, 0.14081820446465695, 0.12358881612973553, 0.6712710027183805, 0.20704753776746138, 0.19467749153929098, 0.26451051075543675, 0.36561464411871775, 0.22977464752537863, 0.26446130339588436, 2.006622599703925, 1.073692534651075, 4.018642212663378, 7.966794950621469, 4.30434649331229, 5.688184899943216, 5.464355630534036, 11.05980726650783, 19.79749182292393, 5.084435514041355, 6.862988489014762, 16.454419919422694, 16.447515147072927, 20.23735100882394, 19.969716821398052, 18.33922301019941, 19.14729503222874, 18.731933457510813, 11.774352192878723, 10.253318565232412, 12.818172250475202, 15.802084820611135, 21.02653956413269, 18.145335265568324, 14.46734368801117, 10.18030081476484, 7.102229297161102, 4.6951770186424255, 4.603537227426257, 3.141510090657643, 3.217322971139635, 11.634068063327245, 9.011756249836512, 21.404052564076014, 14.39054524898529, 9.665705936295645, 10.481737988335745, 11.683808479990278, 10.953916719981603, 7.181838716779437, 11.444488201822553, 11.649192554610115, 18.38987364087786, 13.227873648915972, 6.939524633543832, 0.8463073074817657, 1.7831415001835142, 1.795065151793616, 0.5783412350075585, 0.4522773266902992, 0.1556286561701979, 0.19513707687812193, 0.38555947531546864, 0.17991217598319054, 0.1253932307341269, 0.3748785470213209, 0.3256892093590328, 0.18287556911153452, 0.7694396036011832, 0.40668617880770136, 13.944139122962952, 69.47963047027588, 86.59409277779716, 84.63472161974225, 109.46605478014264, 77.72785786220005, 60.81289223262242, 28.291678496769496, 31.076436587742396, 76.60925347464425, 72.34726319994245, 71.18924862997872, 94.46982029506138, 86.99627535683769, 37.63860716138567, 0.17523986526897975, 0.4901336910469191, 0.2619721383920738, 0.22517954052558967, 0.13809598982334137, 0.12086550226168973, 0.16684657707810402, 0.13948713588927472, 0.1052274074671524, 0.16569127621395247, 0.17202673054167203, 0.1830414437821933, 0.07063397552285876, 0.11954254896513053, 0.08736632338591985, 0.17043639373566422, 0.12700925687594072, 0.3219912477902004, 0.13684341417891638, 0.08713900058397225, 0.16853724207196916, 0.12993781401642732, 0.10402052437088319, 0.12247922138444015, 0.08615140643502985, 0.15266750220741543, 0.14507256474878105, 0.17266665691775934, 0.10118624967123781, 0.11355511524847575, 0.13754587434232235, 0.13568720407783985, 0.1428254060447216, 0.1614363052483116, 0.09368497718657766, 0.09072415570595435, 0.0698156962171197, 0.13426521180995873, 0.06657474155404738], [0.008454854217624026, 0.030541777211640562, 0.0678712794823306, 0.11846156125622136, 0.04714712706793632, 0.05071495579821723, 0.028759537131658623, 0.029643074542816197, 0.005655669956468046, 0.06646293933902468, 0.053944572141127925, 0.030265769522104944, 0.016892592389402643, 0.012234995707071252, 0.028002828093511716, 0.054222025110253265, 0.06769174590174641, 0.02412475279665419, 0.04703833076304623, 0.011957752235632921, 0.0781427797462259, 0.047853139362164905, 0.11062963865697384, 0.09051196423492261, 0.07894054693835122, 0.012041713310671704, 0.038379881264907975, 0.04493192736325519, 0.07205287367105484, 0.025224071129092147, 0.07441105427486555, 0.03129869998831834, 0.06758793682924338, 0.05019956434677754, 0.342837852026735, 35.030850955418174, 95.52910096304757, 83.02244772229875, 75.44880703517369, 64.66847542354039, 56.46118334361485, 49.1833622114999, 30.976229667663574, 51.399684701647075, 76.15591825757707, 55.35631207057408, 60.49338626861572, 82.79590170724052, 57.99714170183454, 14.30970208985465, 0.34177800746900694, 0.1374535257262843, 0.07212693576834031, 0.02426230032662196, 0.0940776454018695, 0.06992582923599652, 0.10508950200996228, 0.08117483383310692, 0.08820442948490381, 0.28437828751546995, 0.4549176150134632, 0.5399982524769646, 1.6078922982726778, 10.75213234765189, 26.598920140947612, 34.779600620269775, 39.08490596498762, 32.05525711604527, 27.540229082107544, 16.74740982055664, 14.307414395468575, 8.280400156974792, 5.874090467180524, 6.378329924174717, 3.394742182322911, 8.224057214600698, 10.59038175855364, 6.815590049539294, 7.598655070577349, 7.321697269167219, 5.558214502675193, 4.166678360530308, 4.398700424603053, 8.41329140322549, 4.1461555532046726, 6.844401623521533, 2.4648476115294864, 0.8344633430242538, 1.1737729758024216, 0.9483283587864467, 4.25108985389982, 3.7044937440327237, 5.1912645016397745, 3.4341421595641544, 0.6331147530249187, 2.023736664227077, 2.9577028793948035, 3.524408813033785, 1.3018440178462436, 2.0451332075255255, 5.926725677081516, 16.967652082443237, 28.053615842546733, 38.66802447182791, 38.16001388004848, 37.3123197555542, 30.942211287362234, 25.49511889048985, 12.72362550667354, 5.854212973799024, 6.9523844463484625, 6.63201082604272, 2.1263272506850104, 0.11359438207000494, 0.07320658676326275, 0.052721641691667695, 0.08599142144833292, 0.02667522513573723, 0.07367312708603484, 0.09588782076856919, 0.1266805880836078, 0.04637311199413879, 0.2388624841613429, 0.5061737703425544, 23.401909794126237, 60.135005133492605, 51.864150932856965, 52.6076602935791, 66.09392615727016, 47.88122115816389, 36.52375480106899, 18.804394483566284, 39.19753279004778, 51.29115036555699, 49.13867139816284, 71.70410319737026, 66.93914672306606, 32.15148619243077, 2.7819130207811082, 0.44266283831426073, 0.05923427508345672, 0.024640602259231464, 0.030246851965785027, 0.009939975687302649, 0.01734282073032643, 0.020487825452749218, 0.04817330271803907, 0.02781659228328083, 0.0311429897722389, 0.0254983553396804, 0.05198840317981584, 0.054251432817961485, 0.0662841046495097, 0.013424230107505406, 0.040085674197013886, 0.0322924925546561, 0.04668010837797608, 0.06747442470597369, 0.03587516084579485, 0.09167491897408452, 0.0361195250547358, 0.0265801555942744, 0.028122821922547052, 0.018413367481636148, 0.013009161754910434, 0.0731648907863668, 0.052597683521785905, 0.05003981345466205, 0.025225333204226832, 0.057465768552252224, 0.04041548632085323, 0.06771481609238045, 0.06805829051882029, 0.026627938030287623, 0.04542294583682503, 0.008013675837511463, 0.023410465767873184, 0.014150512787247342, 0.05620694360030549, 0.09227563281144414, 0.02849845721253327, 0.03892792721412011, 0.04581869460110154, 0.035107456147670746, 0.05535384527008448, 0.03441542506750141, 0.04381386110825198, 0.028965251985937357, 0.03235002553888729, 0.022084988321044614, 0.013024257462737816, 0.03623452316969633, 0.016751550404088836, 0.014012354575762791, 0.12984157060938223, 0.04492716404742428, 0.02712783683091402, 0.010109906301035412, 0.03871253984315055, 0.011017551213236791, 0.03777132695540786, 0.07341815398207732, 0.04834753354745252, 0.04231081783239331, 0.09741723870060273, 0.066000707713621, 0.07078372141612427, 0.07300743673528944, 0.037848361036075015, 0.04433397177074637, 0.4887973570397922, 57.31929629189627, 112.28903838566372, 91.07426343645368, 99.31005355290004, 91.21295642852783, 90.41239888327462, 69.97892802102226, 30.372705663953507, 25.394337006977626, 45.13671745572771, 50.4529196875436, 62.720193590436665, 89.66532857077462, 58.5960625239781, 10.24155787059239, 0.14681616904480116, 0.11676446375037942, 0.1224440054169723, 0.12226101809314319, 0.23864847421646118, 0.157225154074175, 0.2148640983338867, 0.20635764407260077, 0.3988208451441356, 0.30615695459502085, 0.21508663067860262, 0.4063807837665081, 3.9411923800195967, 17.01063711302621, 35.03464814594814, 44.78093842097691, 49.833710125514436, 44.39222492490496, 36.68760027204241, 23.87595064299447, 20.914887223924907, 11.97712060383388, 7.9752691473279675, 7.1216013090951105, 1.260113354240145, 2.4441015933241164, 5.621060524668012, 5.825968546526773, 5.745477139949799, 9.40316390991211, 5.028729634625571, 8.373737914221627, 7.7245347159249445, 15.14435270854405, 5.948350642408643, 3.4543609832014357, 2.1856025499956946, 0.5857746675610542, 1.2897744540657317, 1.8153240361383982, 6.667091412203653, 6.716656821114676, 8.482769915035792, 6.839175709656306, 1.8680946273463113, 1.5333730855158396, 1.8955258982522147, 4.195642360619136, 1.8165767746312278, 3.6656498398099626, 11.337473784174238, 23.56174441746303, 35.521438939230784, 47.389729908534456, 46.42506633486067, 46.789707796914236, 40.67940289633614, 33.156008107321604, 19.930416073117936, 10.672975863729205, 12.617885214941841, 10.79984997000013, 5.277384383337838, 0.45200398564338684, 0.04606255330145359, 0.1634316188948495, 0.316432634634631, 0.1465215084276029, 0.1136500762243356, 0.13147906559918607, 0.07721828256866761, 0.021097071867968355, 0.241618883396898, 0.20344594174197742, 20.59375885554722, 67.29994583129883, 60.757855551583425, 46.048880440848215, 36.69092845916748, 20.326640571866715, 21.096155302865164, 35.72897120884487, 64.40609060014997, 74.95715945107597, 66.61504105159214, 80.05348246438163, 79.00486728123256, 50.21150452750069, 5.97315354006631, 0.3943348601460457, 0.10150693210640124, 0.019826621914814626, 0.021637735356177603, 0.027329470297055583, 0.05247751836265836, 0.0206410047332091, 0.03670155543035694, 0.021835828565859368, 0.06884070924882378, 0.03804769766117845, 0.07071421228881393, 0.02340424869076482, 0.027682522245283638, 0.04106425740090864, 0.007108206902298012, 0.0022904693822576, 0.02183491763259683, 0.04555209819227457, 0.03863089850970677, 0.05279334248708827, 0.006797809361679745, 0.021885638125240803, 0.019432136922010353, 0.024865663843229413, 0.10099539812654257, 0.13514893581824644, 0.022956768416666558, 0.05807329488119908, 0.028638469520956278, 0.06728812613125358, 0.03265153596709881, 0.04602838906326464, 0.028707564741905247, 0.03021833992430142, 0.03426831867545843, 0.0437781090981194, 0.21273519471287727, 0.1117147450734462, 0.14882533837641987, 0.2529580992247377, 0.13790070744497435, 0.14056200321231568, 0.14952637361628668, 0.1711354883653777, 0.08796357669468437, 0.1516633653747184, 0.18255394351269516, 0.11687760267938886, 0.10000384133309126, 0.12484162247606687, 0.11456801875361375, 0.1704136221004384, 0.1583606552864824, 0.10362258393849645, 0.2196379043161869, 0.11424458825162478, 0.1278095075062343, 0.12878800928592682, 0.1824438851326704, 0.15621543968362467, 0.18519786878355912, 0.1510465634720666, 0.20457844382950238, 0.14418725296854973, 0.20009395160845347, 0.18553081234650953, 0.24729757010936737, 0.1355509271046945, 0.14056467664028915, 0.1594179214111396, 0.46984223702124184, 61.8437408719744, 124.77084486825126, 99.29445484706334, 95.5608959197998, 84.58415263039726, 72.58420372009277, 61.46861457824707, 40.57357835769653, 71.62615830557687, 101.271071434021, 83.3457612991333, 78.24344893864223, 103.33984892708915, 74.39644677298409, 17.62337269101824, 0.7442845734102386, 0.15917679720691272, 0.28016838484576767, 0.3299284247415406, 0.4664769747427532, 0.5102689191699028, 0.28176652480448994, 0.24801578585590633, 0.754544620003019, 1.0287873042481286, 1.9309914580413272, 2.9564962812832425, 2.940441599914006, 12.515390600476946, 29.873373372214182, 38.85485110964094, 46.019684110369, 39.32280533654349, 32.56874983651297, 20.252510241099767, 19.91329050064087, 12.467285616057259, 8.736658828599111, 12.200737953186035, 9.571330291884285, 18.904132400240215, 24.610338756016322, 20.604479925973074, 19.65909239224025, 19.105605840682983, 15.49604446547372, 16.081567423684255, 15.045973164694649, 23.97955870628357, 14.082244992256165, 16.040355920791626, 7.744070444788251, 3.100099261317934, 2.4875011273792813, 1.9044087358883448, 6.719968506268092, 6.680036340441022, 8.260877455983843, 6.219044208526611, 1.1888041006667274, 5.052189792905535, 8.503754343305316, 11.70361432007381, 5.582697783197675, 4.518174699374607, 10.59709198134286, 22.741243805204117, 35.21512065614973, 47.75078957421439, 44.65267814908709, 45.0086030960083, 37.78003774370466, 31.7937616620745, 15.618374449866158, 8.241524117333547, 9.591137869017464, 8.394579904420034, 3.417258905512946, 0.2952367477118969, 0.3364493634019579, 0.39017991881285397, 0.3678198829293251, 0.1645869876125029, 0.18240649785314286, 0.38271972483822275, 0.13159685927842343, 0.07644079000289951, 0.6897364918674741, 0.9831914880446025, 32.54012673241751, 75.70065144130162, 65.08363723754883, 77.44165461403983, 94.99857820783342, 61.64641898018973, 48.221026284354075, 25.550921610423497, 50.92393807002476, 65.98471437181745, 64.7260273524693, 85.56682940891811, 90.36681870051792, 55.912376403808594, 5.08606139251164, 0.588504821062088, 0.12201320353363242, 0.16153375644768986, 0.11905852279492787, 0.15407949286912168, 0.08707374587122883, 0.09993658494204283, 0.10767416403229747, 0.19822289129453047, 0.13406912876026972, 0.12141978394772325, 0.12852351633565767, 0.18057750671037606, 0.30049292423895424, 0.09143252590937273, 0.09702201240829059, 0.11817992851138115, 0.09256023753966604, 0.19938172054077896, 0.10514841242028133, 0.08347061635660273, 0.0709037406902228, 0.09845659150076763, 0.19084423008774007, 0.20006303755300386, 0.19407636379556997, 0.2670849268989903, 0.1266180814376899, 0.18065066635608673, 0.07100699336401053, 0.13806787133216858, 0.0637880050178085, 0.17249308765998908, 0.10225239781928913, 0.14258601889014244, 0.0958365642332605, 0.11334450476403747], [0.022484694640817385, 0.09078210938189711, 0.04652144992724061, 0.037753250782511065, 0.08042940883232014, 0.09384303513382163, 0.1035801347877298, 0.05397418001666665, 0.03148065933159419, 0.11639494714992386, 0.0037146768549324144, 0.015066654654219747, 0.033960735358830006, 0.056348482612520456, 0.006231236013783408, 0.03686169987278325, 0.012749614476758455, 0.02828637769977961, 0.06331515431936298, 0.04489123222551175, 0.08276810869574547, 0.0942066688356655, 0.08159279104854379, 0.04680840917197721, 0.07095913628914527, 0.02329353043543441, 0.02033587601701064, 0.12764405352728708, 0.05198602152190038, 0.025080547401947633, 0.024480427282729318, 0.033136909029313495, 0.02088380152625697, 0.9861512035131454, 48.594029903411865, 89.80452878134591, 78.91992555345807, 76.4110700062343, 56.055849756513325, 46.39655440194266, 26.880478518349783, 31.059173788343156, 59.62393733433315, 87.91958672659737, 59.3440499986921, 66.37133993421281, 74.93544633047921, 25.45106383732387, 2.63394353219441, 0.15701795662088053, 0.09018561603235346, 0.05026130424812436, 0.06191988954586642, 0.0413261854888073, 0.145314272493124, 0.09927387336002928, 0.15146597953779356, 0.5640907511115074, 0.5107660410659653, 0.5479259842208454, 2.3129404485225677, 13.397623351642064, 36.58313758032662, 59.96674755641392, 76.71017605917794, 83.18942683083671, 83.33911187308175, 79.85739040374756, 69.83928312574113, 65.01661491394043, 47.82536111559187, 31.221435070037842, 20.665019580296107, 15.689975636345999, 7.79889520577022, 7.126983991691044, 6.321988718850272, 4.262763261795044, 7.167501977511814, 5.91166979925973, 9.705455711909703, 3.283559714044843, 9.771807534354073, 5.078814421381269, 4.954981020518711, 5.13630815914699, 0.794903882912227, 3.1584847569465637, 4.0304871542113165, 12.265843442508153, 19.397145305361065, 23.60773801803589, 30.721262046269008, 38.53348650251116, 35.407141072409495, 21.77785348892212, 9.556096366473607, 2.134161344596318, 2.9075453536851064, 16.080236843654088, 29.309315136500768, 43.55877113342285, 55.30827569961548, 61.534330640520366, 68.38861737932477, 68.80737836020333, 67.51422827584403, 61.77322360447475, 56.56651108605521, 42.590411118098665, 35.895609855651855, 32.136332171303884, 27.168691532952444, 12.41188154901777, 0.3829155500446047, 0.07970670118395771, 0.5173206893461091, 0.061054859177342484, 0.07454313790159565, 0.052591322255986075, 0.12589681228356703, 0.01669398010043161, 0.28023124432989527, 0.03406716696918011, 0.30204565663422855, 8.000344327517919, 56.672172342027935, 72.20653438568115, 55.79823834555489, 66.40136310032436, 58.61266871861049, 32.075389521462576, 23.631360156195505, 20.636139392852783, 40.50517681666783, 42.465437344142366, 59.61049951825823, 66.77985232216972, 59.94353362492153, 8.02343840258462, 0.5455999661769185, 0.03375768714717456, 0.013210171817003616, 0.08285270844187055, 0.04141171822058303, 0.06843155941792897, 0.07647133086408887, 0.022100798186979125, 0.016235972355519022, 0.014319110927837235, 0.05074648732053382, 0.048140522691288164, 0.0189990365012948, 0.04030958396781768, 0.0497893254671778, 0.029343725248639072, 0.03916382330602833, 0.014500177997563566, 0.032106268618788035, 0.06430010896708284, 0.06026213350040572, 0.044363182703299184, 0.012229416452880417, 0.05978522516254868, 0.07544171504144158, 0.054090810008347034, 0.05004272097721696, 0.0426155513019434, 0.03900903250489916, 0.0685529357620648, 0.045878666918724775, 0.013280063468430723, 0.01911828394180962, 0.05675167151327644, 0.05647552811673709, 0.08072622719087771, 0.013175602154141026, 0.06874160920935017, 0.050258264411240816, 0.042410596406885555, 0.04688250519601362, 0.036714478129787106, 0.0625551136742745, 0.015441848896443844, 0.04117325387362923, 0.02943882193150265, 0.03205701715445944, 0.007571173465943762, 0.05138687849310892, 0.05796142481267452, 0.02756743592077068, 0.08753460685589484, 0.07639939258141176, 0.08670956934137003, 0.1289317501442773, 0.15405180864036083, 0.026964896824210882, 0.06322344352624246, 0.03815567633137107, 0.07259087730199099, 0.09308251272886992, 0.0817372240126133, 0.09499524866363832, 0.09381630763943706, 0.07901602038847548, 0.02255229708472533, 0.018986312273357595, 0.08671313843556813, 0.04389771107318146, 3.34599991781371, 76.6590998513358, 101.89003086090088, 92.64370863778251, 104.27431910378593, 83.12696947370256, 72.63304260798863, 37.376354353768484, 30.38202667236328, 37.431700229644775, 61.802399090358186, 64.08124147142682, 72.67015293666294, 79.36574281964982, 22.103017023631505, 1.1943123936653137, 0.2382679246366024, 0.03557629670415606, 0.07691128618483033, 0.2687477176742894, 0.30668037650840624, 0.1836757654590266, 0.2955927343240806, 0.27280074304768015, 0.27250780590942925, 1.7626915403774805, 2.0680750736168454, 7.15668363230569, 20.35447679247175, 50.020144190107075, 72.01095649174282, 88.91956451960972, 92.11143493652344, 92.75268418448312, 88.16592121124268, 83.65927791595459, 75.9097991670881, 57.35842159816197, 39.66523340770176, 29.29425491605486, 20.982851028442383, 11.392216903822762, 4.215914164270673, 2.8627027656350816, 2.1475687623023987, 2.3813904098102023, 2.6112956617559706, 4.530782205717904, 8.142996055739266, 9.308259333883013, 4.864269682339259, 0.3224001329924379, 3.0464565626212528, 0.9859943262168339, 3.348930537700653, 6.575498955590384, 17.194335324423655, 25.697737046650477, 30.99101890836443, 40.20603949683053, 47.66070965358189, 49.65292494637625, 32.71187925338745, 16.67847500528608, 6.524704584053584, 5.98455205985478, 16.83566062791007, 30.90387807573591, 48.05739273343767, 60.36804076603481, 67.95691885266984, 72.6445210320609, 75.9097991670881, 72.7365916115897, 70.2246927533831, 65.46033382415771, 52.74273327418736, 46.02217851366316, 40.652308395930696, 31.840286799839564, 17.556016853877477, 1.0563467911311557, 0.054856265362884314, 0.5899130254983902, 0.3748002712215696, 0.2201007873352085, 0.06608580957565989, 0.09624027221330575, 0.10880612329180751, 0.32606804903064457, 0.047391396281974654, 0.22363983600267343, 4.885616719722748, 52.84247466496059, 78.22134671892438, 56.45980412619454, 52.08500984736851, 29.110447270529612, 11.517499004091535, 25.073168686458043, 36.436780725206646, 60.58003725324358, 69.89743259974888, 72.4897151674543, 75.9423862184797, 78.27185317448208, 17.027773107801163, 0.38572107521550997, 0.11979068922145025, 0.01812578907369503, 0.040118861344775984, 0.0088926509488374, 0.05692838238818305, 0.040625109536839385, 0.10058567154088191, 0.07531497148530823, 0.014552794995584657, 0.06885592200394187, 0.06466346446956907, 0.07006373469318662, 0.045955558507038016, 0.012205824638450784, 0.027080059483913437, 0.015551900491118431, 0.042732951430869956, 0.02842466313658016, 0.07524700263249022, 0.07716599466013056, 0.02325933057415698, 0.06166651099920273, 0.09695052195872579, 0.05175701256043144, 0.0811617448925972, 0.027534107976992215, 0.03438355427767549, 0.024842770071700215, 0.04283654337216701, 0.05738878875438656, 0.06900666534368481, 0.05140220999185528, 0.0740651371223586, 0.07913987338542938, 0.08540077028529984, 0.13057596263076576, 0.29764950967260767, 0.14626238947468145, 0.1348567179271153, 0.17340924564216817, 0.15577369981578418, 0.12757322804204055, 0.1875720221017088, 0.11067488337201731, 0.23873901792934962, 0.11789239251187869, 0.1258391910897834, 0.13485199532338552, 0.10781661567411252, 0.12038751505315304, 0.20141773271773541, 0.18266921304166317, 0.17396877918924603, 0.2119668759405613, 0.23993693079267228, 0.2057662872331483, 0.22883433369653566, 0.20851678321404116, 0.1276835985481739, 0.12236867445920195, 0.09611595781253916, 0.15991131136459963, 0.2428813385111945, 0.19535347526626928, 0.1371985458369766, 0.18425604860697473, 0.10949546058795281, 0.12411655352583953, 3.0262238425867896, 82.03173187800816, 118.72011729649135, 98.52237796783447, 102.14994212559291, 72.31213310786656, 57.241427830287385, 35.56376041684832, 41.93683923993792, 80.68714427947998, 115.09788240705217, 85.47461986541748, 82.64735616956438, 90.63749967302594, 31.462141513824463, 3.366379418543407, 0.2949764073959419, 0.2379031984933785, 0.17844170917357716, 0.2581506020256451, 0.2567591981164047, 0.20932635691549095, 0.39582904853991097, 0.43208580730216845, 1.746081871645791, 3.074657997914723, 1.6243577918836047, 5.085676201752253, 15.748224122183663, 41.57263551439558, 68.08789934430803, 88.40824658530099, 97.24554225376674, 94.79324504307338, 89.9574169431414, 83.64675031389508, 77.54448795318604, 55.473618507385254, 38.539937904902864, 28.837346587862285, 21.08600398472377, 12.407658781324114, 12.580565571784973, 14.144056166921343, 14.841143744332449, 17.744337354387554, 17.02855130604335, 27.39900173459734, 18.817988634109497, 25.452835627964564, 17.262115001678467, 14.70664746420724, 9.884865147726876, 2.740785981927599, 5.765923082828522, 7.275966397353581, 19.64641887801034, 28.060772487095424, 35.005573408944265, 44.74168109893799, 57.341106687273296, 56.95646136147635, 34.22741685594831, 11.103300384112767, 4.063471555709839, 6.269131600856781, 18.743938207626343, 33.06483037131173, 51.34613493510655, 63.003353527614046, 71.60833617619106, 78.5349953515189, 79.32898684910366, 75.81286484854562, 70.32347529275077, 63.30061830793108, 50.09168979099819, 43.92759541102818, 39.04584666660854, 30.404566628592356, 14.459788390568324, 0.6802373273032052, 0.303231735846826, 0.9264250312532697, 0.2520418055355549, 0.3064004129597119, 0.22312314515667303, 0.32017687229173525, 0.15106119268706866, 0.4490533896854946, 0.1090131171845964, 0.6272283803139413, 12.072881545339312, 69.52321652003697, 86.39006587437221, 72.23689801352364, 93.29504667009626, 81.4149819782802, 42.22564806256975, 27.860485451562063, 26.493877274649485, 52.02367115020752, 61.868677956717356, 74.8044866834368, 85.44614614759172, 87.50824642181396, 16.888595478875295, 0.5127543115190097, 0.23899091726967267, 0.061531394320939264, 0.13286544834928854, 0.10777830558695964, 0.1563348618469068, 0.1523994401629482, 0.20293286070227623, 0.09208621297563825, 0.07871337341410772, 0.1872984639235905, 0.1328976516212736, 0.1963469319577728, 0.152985205873847, 0.10279590436922652, 0.09901984341974769, 0.11804157522107873, 0.06816321917410408, 0.0801278135872313, 0.206993309248771, 0.16607576129691942, 0.10268550672169242, 0.13332036536719116, 0.24820629134774208, 0.13780698818819864, 0.17502238122480257, 0.0925601561154638, 0.10402258033198969, 0.1437995923416955, 0.16660111024975777, 0.17264064188514436, 0.1418102498033217, 0.11329838473881994, 0.13953174278140068, 0.14939700412963117, 0.1286075325416667], [0.062104505353740284, 0.06573718506842852, 0.17159677004175528, 0.09230282170964138, 0.06774518053446497, 0.05134626477956772, 0.06674977644745793, 0.01032382294735206, 0.05333965138665267, 0.07379055435636214, 0.045094819872507026, 0.058663070734058104, 0.0483452333137393, 0.0884807085884469, 0.08341063386095421, 0.03880860683109079, 0.04339397006801196, 0.02771476114035717, 0.038373984795595915, 0.08840611723384686, 0.11057129821607045, 0.1229206762675728, 0.0966547689001475, 0.10876572331679718, 0.08202465144651276, 0.015643365315294692, 0.023157014278694987, 0.07032334219132151, 0.08506371480013643, 0.10248913190194539, 0.06948172806629113, 0.09513951877930335, 0.404890096613339, 45.7791930607387, 102.14266041346959, 75.29234749930245, 74.33567087990897, 53.03167758669172, 41.75129801886422, 36.28867639814104, 55.02356284005301, 52.992635658809114, 49.99349784851074, 52.18640143530709, 64.68094049181256, 60.72899273463658, 12.25132257597787, 0.20777080181453908, 0.13721635059586593, 0.059279641934803555, 0.15023496773626122, 0.11484028771519661, 0.025795725007940615, 0.14998665106083664, 0.6006122742380414, 0.4783889555505344, 1.5332803704908915, 7.876565643719264, 20.587958846773418, 40.68016372408186, 55.09479577200753, 73.0592520577567, 87.69529192788261, 87.71407985687256, 90.98226928710938, 86.23705959320068, 83.33160781860352, 82.20715304783413, 79.63695880344936, 79.61522483825684, 73.54018551962716, 59.61794103894915, 45.35782650538853, 33.647554942539756, 18.249410595212662, 11.191917708941869, 4.340232636247363, 1.8729915874344962, 1.8694731933729989, 3.0692965941769734, 1.04912403013025, 5.933860174247196, 4.966330902917044, 9.12057285649436, 4.974546279226031, 0.831205886389528, 0.5373159764068467, 6.570801104818072, 15.168641873768397, 26.84235201563154, 37.48227269308907, 47.38842364719936, 59.309976032802034, 63.01414408002581, 65.1809606552124, 72.34617233276367, 76.06989261082241, 73.26578726087297, 58.45229039873396, 41.020080021449495, 50.31506395339966, 62.888694354466026, 76.50887979779924, 84.67493779318673, 86.5339491707938, 87.54534980228969, 91.7201679774693, 96.03631251198905, 92.06345762525285, 85.68344797406877, 68.05877944401333, 57.73297813960484, 44.079201630183626, 34.62336342675345, 16.410125153405325, 0.9531647392681667, 0.19849182186382158, 0.16305136787039892, 0.08151555340737104, 0.33952600402491434, 0.11164429956781012, 0.09139923019600765, 0.06791920441069774, 0.07162924390286207, 0.17019901504474028, 0.2735260155584131, 1.0510864619697844, 32.58474458966936, 78.85212503160749, 68.91262967245919, 50.79445144108364, 71.83577850886753, 56.516327721732004, 30.978362764630997, 21.865687404360088, 22.703461238316127, 36.088457107543945, 50.978710719517295, 63.99521582467215, 56.547445229121614, 18.848258461271012, 0.8130517633897918, 0.15256849037749426, 0.042859016451984644, 0.08937654444681746, 0.06663737712161881, 0.01757208414242736, 0.022623628078560745, 0.029007073491811752, 0.10190002101340465, 0.03030069711218987, 0.08880504832736083, 0.05788365112883704, 0.029260180624467984, 0.015966838225722313, 0.03644730835886938, 0.05723892751016787, 0.03277928036238466, 0.03108260015557919, 0.013852466280306024, 0.0064877867116592824, 0.08201874140650034, 0.0539145605372531, 0.04214230705318706, 0.09153421795261757, 0.05582807000194277, 0.037324939122689624, 0.03785983167056527, 0.07919410190411977, 0.07321093617273228, 0.05989860836416483, 0.11405355350247451, 0.0364019686489233, 0.05929665280772107, 0.02294567776178675, 0.06033196832452502, 0.045090925081499984, 0.10570709779858589, 0.10789157343762261, 0.09656264420066561, 0.08816927458558764, 0.04657448422429817, 0.08417108162705388, 0.013211096320966524, 0.05030646075361541, 0.11267908582729952, 0.014507255117808069, 0.08075581131769077, 0.03436520669077124, 0.036209308808403354, 0.08293083496391773, 0.018344701434086477, 0.07361153646239213, 0.0491836752875575, 0.06501630946461644, 0.03741697561261909, 0.09881181815373045, 0.09742067208779709, 0.16430360424731458, 0.07614250600870166, 0.03988001023286155, 0.016404396621510386, 0.03216335716258202, 0.04934787397672023, 0.05151886712493641, 0.15272548981010914, 0.03555977776912706, 0.10846742575189897, 0.1475168378757579, 71.7117531640189, 111.8863138471331, 92.70298371996198, 97.89098126547677, 77.42909227098737, 65.51168101174491, 41.27851479394095, 26.013084513800486, 22.212227072034562, 43.487496512276785, 57.63203123637608, 75.32278060913086, 60.43012292044503, 8.226134725979396, 0.1573940957231181, 0.04364439359466944, 0.09618775360286236, 0.07362900873912231, 0.22030376430068696, 0.06600899262619869, 0.20031414979270526, 0.40993093326687813, 0.5498828249318259, 3.1993438558919087, 13.380684512002126, 30.676671981811523, 54.362017904009136, 69.99404035295758, 87.4798560823713, 95.35619504111153, 95.38716316223145, 95.31495748247418, 91.61304065159389, 86.43654932294572, 86.26761777060372, 85.54693671635219, 87.23025594438825, 82.3980964933123, 69.7106511252267, 56.41211863926479, 43.36967938286917, 24.989437682288035, 14.255464451653616, 7.298381720270429, 2.2683553780828203, 0.7181846424937248, 1.087120688387326, 0.9063539654016495, 0.36804542796952383, 2.0511136523314883, 1.046578275305884, 2.427035949059895, 0.9401716079030717, 1.1139624480690276, 8.236465828759329, 21.760938099452428, 37.31337240764073, 46.009956632341655, 58.31626551491873, 70.06170191083635, 75.58050319126674, 80.75809928349086, 90.46281501225063, 94.68751430511475, 93.34232221330915, 84.03630801609584, 69.68331691196987, 70.006025995527, 78.20229475838798, 84.16505813598633, 87.93392780848912, 88.11890969957624, 90.24445397513253, 93.34678295680455, 98.5345790045602, 94.169741494315, 91.16990539005825, 75.56954588208879, 66.64945547921317, 51.46629360743931, 43.344214235033306, 21.545212166649954, 2.2803512258189063, 0.3298218133194106, 0.14806718405868324, 0.4605879421745028, 0.8243451373917716, 0.13515340057866915, 0.05600455356761813, 0.10766853897699288, 0.049461521806993654, 0.17341383253889425, 0.1705558837524482, 0.22659909006740364, 27.86493750980922, 80.02518939971924, 74.5470142364502, 54.05995191846575, 48.39028092793056, 21.527148587363108, 15.526908363614764, 28.510604075023107, 40.698819637298584, 54.51624706813267, 68.3520906993321, 70.22162164960588, 71.90863037109375, 33.775127342769075, 2.080098497016089, 0.21925820969045162, 0.09972959104925394, 0.06133810005017689, 0.05795043254537242, 0.0506640147816922, 0.019887600160603012, 0.06980154197663069, 0.047943252205316506, 0.08840066181229693, 0.09478444818939481, 0.060038963332772255, 0.024324203076373254, 0.06790791358798742, 0.04524774470233491, 0.08745333871671132, 0.037060432601720095, 0.035784854620162926, 0.039049890491047075, 0.053987095930746624, 0.07066184974142484, 0.075534477563841, 0.041975010851664205, 0.11930198115961892, 0.022208337505747165, 0.06203422948185887, 0.04555694293230772, 0.04171043647719281, 0.030603259269680296, 0.058781943283975124, 0.022749068847458278, 0.07161928300878831, 0.04651138386023896, 0.02123554390189903, 0.04928284318053296, 0.09894702982689653, 0.14329120676432336, 0.21654075836496695, 0.14383155134107384, 0.1788510014968259, 0.1386286669543811, 0.22102759831718036, 0.11202583302344594, 0.184310236413564, 0.21512598570968422, 0.16950232242899282, 0.18880201610071318, 0.13286406413785048, 0.16140936740807124, 0.1304423048027924, 0.1068335473537445, 0.20611160727483885, 0.22555692813226155, 0.1483965313860348, 0.08530838095716067, 0.22383526765874454, 0.17580271006694861, 0.2644942801977907, 0.19600503173257622, 0.19977749644645623, 0.10815650743565389, 0.10951893111424786, 0.16777367304478372, 0.17557351450834954, 0.23578410648873874, 0.09618427950356688, 0.1984566194670541, 0.40063389071396416, 82.41375078473772, 130.76433318001884, 93.27190916878837, 99.32639571598598, 66.57161481039864, 55.27909326553345, 47.18636655807495, 72.89547606876918, 72.8146824155535, 72.06903648376465, 73.4297786440168, 79.33370467594692, 76.57360921587262, 15.618454354149954, 1.0125699916056223, 0.19501050295574324, 0.28934638521500994, 0.13160620949098042, 0.2699490232127053, 0.1734929225806679, 0.40804191891636166, 1.3161396107503345, 1.389741552727563, 3.1642498075962067, 9.565737860543386, 23.739541871207102, 47.14978429249355, 61.776878356933594, 85.76426942007882, 98.66615009307861, 100.6378265108381, 101.49076652526855, 97.97085080827985, 93.34772096361432, 94.67989213126046, 92.79711791447231, 93.59263801574707, 88.01199081965855, 71.83769621167863, 58.112923009055, 44.05683537891933, 23.494275672095164, 16.58459094592503, 12.433572956493922, 9.272205131394522, 9.527739899499075, 14.944055250712804, 8.561929873057775, 16.742969921657018, 13.494982378823416, 22.223417145865305, 11.565507582255773, 1.5525514164141245, 2.5075916264738356, 9.548143284661428, 24.556448527744838, 41.56872715268816, 53.175991671425955, 68.75995690482003, 77.8308162689209, 82.04154968261719, 88.34112003871373, 103.66673387799943, 114.31213842119489, 106.30391570499965, 91.40018953595842, 80.19567040034703, 82.51525701795305, 91.75507572719029, 98.90176350729806, 98.71432195390973, 98.48800522940499, 98.73222051348004, 103.16638714926583, 106.66375596182687, 101.59219632829938, 100.38427284785679, 83.06728444780622, 72.17272445133754, 55.994236605507986, 42.90496301651001, 17.955077954701014, 1.9880146724837167, 2.2942315552915846, 1.1506734724555696, 0.36488068635974613, 0.5256618931889534, 0.26733916039977756, 0.20459928842527525, 0.25002908068043844, 0.12402196574423995, 0.2652815436678273, 0.5449767996157918, 1.5402164097343172, 42.468619619097026, 95.42800467354911, 82.60490267617362, 71.38247803279332, 100.82721355983189, 77.40353679656982, 38.3431510244097, 25.5476142678942, 29.488543919154576, 50.71669067655291, 67.39958299909318, 80.98479121071952, 83.09491743360246, 34.40565204620361, 1.6928807092564446, 0.2580886653491429, 0.11310648825019598, 0.1672330977661269, 0.2394038193992206, 0.13920327754957335, 0.10990112953420196, 0.1850283435945, 0.1619301430348839, 0.15915800178689615, 0.25962104169385775, 0.12188968301883765, 0.09764617641589471, 0.11440852231213025, 0.09687225972967488, 0.1264398167175906, 0.34469152827348026, 0.31558758712240625, 0.14507251046597958, 0.12148698605597019, 0.13948311896196433, 0.21854109317064285, 0.09079818387648889, 0.18114379846623965, 0.16995352107499326, 0.08630111161619425, 0.10450101537363869, 0.14605559914239816, 0.11573558753090245, 0.11033253531370844, 0.1635666202221598, 0.15107689398740018, 0.14151317360145704, 0.10725864275757756, 0.1835688961935895], [0.051464658962296586, 0.07995143519448382, 0.08515451635633196, 0.02193597694193678, 0.06550155021250248, 0.06844958809337445, 0.14993802724140032, 0.08598623744079045, 0.03372339738000717, 0.04916696636272328, 0.040186935370521884, 0.034566426250551424, 0.024842417233490517, 0.0017593900951656646, 0.11153523863426276, 0.1344975150589432, 0.14802595627095017, 0.11671235226094723, 0.006684572045092604, 0.022573764236377816, 0.014264263245942337, 0.08318569950227227, 0.07217655024890389, 0.08462626327361379, 0.04944434808567166, 0.05455169813441379, 0.023987364722415805, 0.10766869504004717, 0.03035009785422257, 0.0825754115357995, 0.09283352430377688, 0.05825177673250437, 32.15685020174299, 84.10849979945591, 77.80777604239327, 72.03148147038051, 64.18990434919084, 50.08024263381958, 31.788376808166504, 59.585145541599815, 64.98295783996582, 72.83023248400006, 74.39280591692243, 87.51554203033447, 46.406653608594624, 2.228813397032874, 0.2474162323134286, 0.12790990354759352, 0.10766351781785488, 0.09596520768744604, 0.0397685879974493, 0.12314130871423654, 0.5035829065101487, 0.6079275331326893, 0.7748654953071049, 5.688220075198582, 26.917706966400146, 52.571748529161724, 72.74826458522251, 81.98107256208147, 89.27809156690324, 89.13719599587577, 86.12369973318917, 81.01044395991734, 77.7933098929269, 77.00171552385602, 73.70430197034563, 71.0445384979248, 72.81976154872349, 75.69027083260673, 79.2182812009539, 69.51035540444511, 65.22048895699638, 58.903221539088655, 42.72012703759329, 30.42771107809884, 19.84165457316807, 7.188134218965258, 3.2061324630464827, 0.36632705160549706, 1.2802889687674386, 4.49171552487782, 3.7206847837993076, 1.6066582330635615, 0.46238426864147186, 1.9091322081429618, 4.230627843311854, 16.42141945021493, 27.143841300691875, 50.36571979522705, 58.21733358928135, 74.94953032902309, 85.5784398487636, 96.15281990596226, 88.40796170915876, 81.88878658839634, 79.31471524919782, 81.17401150294712, 83.20109285627092, 85.91810253688267, 84.2273348399571, 88.71191760471889, 89.58135264260429, 86.87249319893974, 85.8312986918858, 84.99410329546247, 84.18817479269845, 86.50194576808384, 85.94918877737862, 89.06928430284772, 86.76865931919643, 79.85643850054059, 68.47956929888043, 57.407649585178916, 36.35266930716378, 10.165838139397756, 1.5639415766511644, 0.8560673551900047, 0.3249385596386024, 0.17547135427594185, 0.29901450499892235, 0.19290700368583202, 0.099207750122462, 0.07495931735528366, 0.039907168596982956, 0.4231733855392252, 0.1955793188618762, 0.21618155549679482, 9.228646874427795, 64.94601426805768, 76.66513783591134, 52.98016364233834, 78.01454053606305, 79.36670861925397, 43.19944504329136, 24.38180034501212, 17.529768296650477, 37.30230392728533, 45.84142460141863, 64.97969218662807, 67.02495002746582, 47.78074673243931, 2.6045035805021013, 0.1275904628315142, 0.13951771067721502, 0.10746781474777631, 0.024285231417577182, 0.008990773049715375, 0.07897511151220117, 0.04904858235801969, 0.0363330362763788, 0.02643575655695583, 0.07138003156121288, 0.10421343187668494, 0.025344550110665814, 0.09060295578092337, 0.11637849946107183, 0.06371022454862084, 0.06642742481614862, 0.06191275814282043, 0.15455962424831732, 0.14140006181384834, 0.06332398884530578, 0.12767092351402554, 0.12399117382509367, 0.10965262286897216, 0.04667111439630389, 0.04367512783833912, 0.02833151045654501, 0.03426192009023257, 0.13476014882326126, 0.04862010106444359, 0.02921089862606355, 0.03215645306876727, 0.0701981389096805, 0.10747756529599428, 0.017813790190432752, 0.02508096639732165, 0.07408984936773777, 0.03642679963793073, 0.08604748879692384, 0.06703084600823266, 0.1551312357187271, 0.00874644361569413, 0.017888848037858094, 0.1499587632715702, 0.0721552035372172, 0.03538202873564192, 0.034339765020247014, 0.04836297361180186, 0.05753039901277848, 0.012745992796096419, 0.08113598091793911, 0.05929412187210151, 0.031521323935261795, 0.009849065565504134, 0.012305772846697696, 0.04238151439598628, 0.09388775059155055, 0.08375577748353992, 0.06771864302988563, 0.14925419964960643, 0.04379782732576132, 0.041831110537584336, 0.017631666302414875, 0.049133599403181245, 0.040901812724769115, 0.13282143856797898, 54.14882285254342, 96.33516842978341, 93.45845440455845, 96.0241948536464, 90.98015008653913, 72.84845066070557, 28.282711846487864, 18.122199501310075, 37.65796136856079, 66.98120416913713, 77.75054373059953, 99.03009673527309, 44.93890919004168, 0.42933958609189304, 0.23026427839483532, 0.03385042252817324, 0.08410622724997145, 0.05491322837769985, 0.09712771459349565, 0.26715259041105, 0.3071023167244026, 0.6314639587487493, 1.9643777694020952, 8.816669940948486, 33.197110176086426, 62.06089292253767, 78.64827183314732, 87.19427122388566, 91.34116458892822, 90.04993220738002, 89.47578866141183, 85.1695522580828, 81.46657930101667, 80.01097338540214, 79.48116629464286, 77.25296238490513, 79.64610958099365, 84.11501720973423, 84.05343532562256, 78.6231610434396, 78.5028668812343, 65.3934713091169, 53.20727940968105, 39.97711024965559, 29.54068320138114, 11.54007283278874, 5.828643602984292, 1.442697899682181, 0.9336923041513988, 0.7438200754778725, 3.7989775197846547, 1.2672906262534005, 1.5146069782120841, 3.503754207066127, 7.323709641184125, 22.21703175136021, 38.63442645754133, 65.72877747671944, 67.6937905720302, 85.86179433550153, 97.14790616716657, 104.2517374583653, 97.36435644967216, 93.34631047930036, 92.37721742902482, 92.89325319017682, 94.6172124317714, 96.82735102517265, 92.26645619528634, 93.72459125518799, 93.98993601117814, 91.38243688855852, 88.12772696358817, 86.07758453914097, 85.98362404959542, 87.370484488351, 88.89943558829171, 89.5305404663086, 85.3711472920009, 81.2329878125872, 74.58361039842877, 63.06767300197056, 43.53618948800223, 13.913648690496172, 3.0109675526618958, 1.529737332037517, 0.5928491822310856, 0.3170938534396035, 0.575298466852733, 0.18059882628066198, 0.06823199548359428, 0.10576938731329781, 0.0648922732632075, 0.29113332075732096, 0.19732847357434885, 0.4451606885663101, 6.366131058761051, 65.13351835523332, 87.43985530308315, 58.37720121656145, 72.76800441741943, 45.70723404203142, 11.575169052396502, 10.94218989780971, 33.13377039773123, 62.708624839782715, 68.74435819898332, 83.05931486402238, 76.18089703151158, 68.81919724600655, 5.551426981176649, 0.32525747109736713, 0.035368030558207204, 0.1121330415563924, 0.008344056234428925, 0.03249652464208858, 0.07514031657150813, 0.04998681308435542, 0.07325082724647862, 0.099140181605305, 0.06370072505835976, 0.0895629787285413, 0.03007872116618923, 0.07318462258470909, 0.004333945232376988, 0.0834340365337474, 0.07054386607238225, 0.13478927154626164, 0.11103800817259721, 0.12968486973217555, 0.10371572644050632, 0.12386799257780824, 0.15446963693414414, 0.13045373133250646, 0.02866627588602049, 0.026715759121413742, 0.018527692150590674, 0.04053990928722279, 0.02641751753565456, 0.017215668356844356, 0.024830103519239595, 0.047638807113149335, 0.15003668623311178, 0.126326962773289, 0.08278376249862568, 0.25276249114956173, 0.10729522936578308, 0.12256083557648317, 0.16303458091403755, 0.11339398353759732, 0.26202112862042015, 0.10612434255225317, 0.09622340383274214, 0.2704011718077319, 0.17569016824875558, 0.18873009138873645, 0.08336758759937116, 0.16019160061010293, 0.14752674448703015, 0.2090901860169002, 0.19280691977058137, 0.2014766838401556, 0.13730108604899474, 0.11200540911938463, 0.08108952162521225, 0.18499866447278432, 0.12613309174776077, 0.1490792461803981, 0.1035447424011571, 0.2453054455774171, 0.11342121993324586, 0.2154165751167706, 0.12523338145443372, 0.32932862692645615, 0.20500967997525418, 0.23507188899176462, 55.6409068107605, 113.39296817779541, 97.14746843065534, 95.22296333312988, 76.96454266139439, 61.180396352495464, 43.70625359671456, 80.83591910770961, 90.55002880096436, 104.60285077776227, 96.78187506539481, 102.55103383745465, 61.48310852050781, 2.8463328097547804, 0.3448862135410309, 0.24766077633414949, 0.2616704617227827, 0.16602248272725514, 0.1869299922670637, 0.39549898196543964, 1.2087900510856082, 3.1875948863370076, 2.637451721089227, 7.251128324440547, 31.169976711273193, 59.55757508959089, 82.56029524121965, 92.1614202771868, 99.2914810180664, 97.93420600891113, 98.29660320281982, 91.27887398856026, 89.12566893441337, 86.32613549913678, 85.91084861755371, 81.37884439740861, 87.92199080330985, 90.83820533752441, 92.20704909733364, 90.1941420691354, 84.59769466945103, 68.668518611363, 56.87757498877389, 38.473679883139475, 27.577297721590313, 8.959506664957319, 6.603870187486921, 3.6027738537107195, 4.437103986740112, 11.633698071752276, 10.988611681120735, 6.233975453036172, 2.057233278240476, 4.609903514385223, 7.186953459467206, 25.44510054588318, 42.6750853402274, 73.56863144465855, 74.97617667061942, 91.81151594434465, 101.61602170126778, 109.10772923060826, 100.33262688773019, 90.77182224818638, 92.39318438938686, 96.99420506613595, 99.83196749005998, 103.87637492588588, 100.6238397870745, 101.77394035884312, 101.57410321916852, 100.38253579820905, 97.69365242549351, 94.63630608149937, 92.21847193581718, 95.1360969543457, 98.58096517835344, 102.33946813855852, 96.4361743927002, 91.10336944035122, 82.09539822169712, 68.58771106175014, 44.23579665592739, 12.767126441001892, 3.641292712518147, 5.195654894624438, 2.737676663058145, 0.3689150113080229, 0.4354230325136866, 0.2710376919380256, 0.166121955960989, 0.20254210595573696, 0.248180235603026, 0.5578810700348446, 0.2662525272795132, 0.6353592925838062, 13.348227739334106, 82.0111860547747, 93.54193006243024, 67.37234606061662, 103.41987133026123, 111.6970032283238, 64.36428328922817, 35.706472941807334, 23.27865743637085, 47.89324501582554, 63.32900169917515, 82.25748579842704, 88.69998059953961, 77.12785312107631, 5.672481971127646, 0.40627181104251314, 0.170355390225138, 0.2183150053024292, 0.1788660514035395, 0.11927068712455885, 0.15247498825192451, 0.25074691644736696, 0.257869227124112, 0.1768525665892022, 0.16180014929601125, 0.17945326917937823, 0.05659590022904532, 0.20884215432618344, 0.2131190419729267, 0.13787569664418697, 0.1651513251875128, 0.172009373615895, 0.2990991047450474, 0.2080154272594622, 0.22689181007444859, 0.18956990061061724, 0.16536389663815498, 0.2744752046253, 0.10652547209922757, 0.08197800216398068, 0.24135859736374446, 0.12552820492003644, 0.2686270741479737, 0.17045456490346364, 0.07155542607818331, 0.11502337003392832, 0.28807934320398737, 0.27040022185870577], [0.08421019917087895, 0.0828764300261225, 0.035497118452829976, 0.09742487900491272, 0.08884099711264883, 0.1895496802670615, 0.11687708699277469, 0.06167829715247665, 0.030287964402564933, 0.07440369216991322, 0.12060608475336007, 0.0615029637036579, 0.09800399507262877, 0.022014900742630874, 0.15822482614644937, 0.07027460980628218, 0.03931612049096397, 0.017283347135941898, 0.10434822285813944, 0.05985942975218807, 0.021295880932094793, 0.05526315227949193, 0.050705317208277326, 0.08658565527626447, 0.044068369415721724, 0.07348437221454722, 0.08037997755621161, 0.02132925806966211, 0.05215381983933704, 0.15015894467277185, 0.8311985582113266, 49.85204642159598, 84.21951116834367, 90.68241282871791, 77.55372210911342, 58.09981175831386, 33.81671231133597, 35.60808644975935, 68.55973066602434, 67.6343765258789, 65.5581853049142, 82.65757696969169, 94.03712122780937, 36.9275667326791, 1.0668473648173469, 0.021068536077759097, 0.19246791010456427, 0.0946745662284749, 0.17383698054722377, 0.018052975480843867, 0.02516110477569912, 0.07832407073250838, 0.10205434701804604, 2.372923595564706, 9.61803868838719, 30.263990674700054, 55.518820013318745, 68.91003104618618, 70.83628708975655, 68.73199735369, 69.88821234021867, 70.35668073381696, 71.7006846836635, 73.09814807346889, 74.84116622379848, 76.67813791547502, 82.4438920702253, 78.59846019744873, 79.21771839686802, 78.35612787519182, 76.40395505087716, 76.05480807168144, 72.54639162336076, 80.77356597355434, 74.72204630715507, 72.65164293561662, 64.34821210588727, 50.2353264263698, 26.42757408959525, 11.120017749922615, 3.5558214017323087, 1.7745393046310969, 1.034629653607096, 1.2006937712430954, 14.532166906765529, 17.896801676068986, 20.04357269832066, 31.365328788757324, 47.774628843579976, 65.62520068032401, 81.06326416560582, 94.64424092429024, 101.35255990709577, 102.15037291390556, 106.17011424473354, 112.29217897142682, 108.40982437133789, 102.12869453430176, 91.18792901720319, 90.87519059862409, 88.91170610700334, 85.57983643668038, 86.52839756011963, 84.92027173723493, 81.70572240012032, 79.86640916551862, 77.81396688733781, 76.55323014940534, 72.27572454724992, 72.60641711098808, 75.564939226423, 74.52980354854039, 76.49496950422014, 73.73801462990897, 57.739123821258545, 32.22142675944737, 9.772422449929373, 0.9678304323128292, 1.191918847816331, 1.7011919489928653, 0.026000756238188063, 0.11888850906065532, 0.1893331054598093, 0.16873339297516005, 0.03932696008788688, 0.016705664473452737, 0.15939823032489844, 0.7482471093535423, 0.012396029030371989, 3.3977550949369157, 53.13241951806204, 83.50645923614502, 61.152339526585166, 97.2287345613752, 139.6861675807408, 90.59476130349296, 27.824653591428483, 15.64910980633327, 20.345562253679546, 32.231404372623985, 46.138473987579346, 66.12490817478725, 53.990737438201904, 3.1370347993714467, 0.3908226271825177, 0.2509600307260241, 0.057963575768683634, 0.07717253573771034, 0.060985343264681954, 0.030736777997974838, 0.022205370611378124, 0.0238437103772802, 0.0386249070454921, 0.01608715605522905, 0.05052745282383902, 0.04204248098124351, 0.012843532205027128, 0.045672131037073474, 0.08226407252784286, 0.17242226217474255, 0.07944159076682158, 0.09768995549529791, 0.021051267361534492, 0.08127748939607825, 0.07563455469374146, 0.028941004537045956, 0.08161662119839873, 0.008168151968025734, 0.034018465118216615, 0.052805824138756306, 0.006432710872364363, 0.046085311365979056, 0.05563998348744852, 0.1056269695982337, 0.04294629641143339, 0.0655815630619015, 0.08818754074828965, 0.07495165669492312, 0.04024442085730178, 0.12808518271361077, 0.069312202877232, 0.23878005572727748, 0.022838486192215766, 0.06712603768599884, 0.06931690512491123, 0.05782358720898628, 0.018933303421363235, 0.036428119388542006, 0.022844967897981405, 0.10606446183685746, 0.03798460068979433, 0.06170676848185914, 0.05011977202125958, 0.14836455881595612, 0.13889231852122716, 0.06929961605263607, 0.02983634506485292, 0.031239270498710017, 0.06769689598253795, 0.04065623054546969, 0.06641335878521204, 0.12759380122380598, 0.05639486726639526, 0.08149799292108842, 0.11568054477018969, 0.190449879105602, 2.6418088929993764, 75.15666307721818, 95.15389823913574, 101.76452554975236, 96.44172600337437, 83.19030925205776, 48.87259360722133, 21.45708121572222, 19.0772693497794, 51.166551794324604, 71.65914835248674, 93.77730028969901, 100.54601996285575, 30.640569141932897, 0.2195093355008534, 0.04513413419148751, 0.21341982297599316, 0.06875577702053956, 0.10666921295757804, 0.15197964411761078, 0.10160174380455698, 0.10753684211522341, 1.394932074206216, 4.094778401511056, 14.609270198004586, 36.89855105536324, 62.88119724818638, 75.73510755811418, 77.15493025098527, 75.33852522713798, 75.24062510899135, 76.1858719417027, 74.8566676548549, 77.78149795532227, 81.45810944693429, 82.53749125344413, 88.10269955226353, 86.22893714904785, 86.31100232260567, 85.25136729649135, 86.75360257284981, 88.3352279663086, 80.53180340358189, 85.20219489506313, 82.0746717453003, 80.6425507409232, 73.37401935032436, 59.58372810908726, 34.81743008749825, 16.248331138065883, 7.396192380360194, 2.8034869602748325, 1.4218974901097161, 2.1146512372153143, 20.084726878574916, 28.12838888168335, 26.117733069828578, 40.41756698063442, 60.48046261923653, 74.66749600001744, 88.8585593359811, 100.2880472455706, 102.95402240753174, 106.5333035332816, 109.58304854801723, 115.57010282788957, 113.09704439980644, 112.310946055821, 101.55981077466691, 98.26352282932827, 94.88763632093156, 93.14630658285958, 91.93241459982735, 89.659512928554, 85.73180048806327, 84.63893917628697, 83.9452657699585, 78.76049218858991, 76.89933381761823, 77.3739652633667, 79.96876307896206, 79.42275973728725, 80.45346246446881, 78.33409513745988, 62.187614168439595, 40.75180312565395, 14.888756275177002, 2.2947843713419775, 1.4122760806764876, 0.9831121265888214, 1.6588933787175586, 0.6484610438346863, 0.5435021530304636, 0.2427082849400384, 0.08332572198872056, 0.09145891413624797, 0.08922929556242057, 0.3782039385821138, 0.09491308485823018, 0.977243395788329, 51.52140324456351, 94.81471497671944, 64.13822364807129, 94.71174962180001, 122.4282180241176, 50.23323154449463, 8.49252084323338, 19.724210909434728, 33.95571797234671, 56.11943619591849, 63.14142118181501, 73.6834226335798, 73.91606221880231, 6.567786889416831, 0.48280317868505207, 0.2049897988992078, 0.1020079759348716, 0.1366626660206488, 0.07932583947799035, 0.057884356805256436, 0.10704632915024247, 0.04384986078366637, 0.03485931928402611, 0.005509980006276497, 0.09062440427286284, 0.04460350623620408, 0.034085772399391444, 0.007988936450731541, 0.07942813541740179, 0.04790002273927842, 0.08084467226373297, 0.15425382208611282, 0.05771086897168841, 0.06365940906107426, 0.04506291854860527, 0.013112216805373984, 0.04468734941578337, 0.048941041342914104, 0.05955068953335285, 0.022299359585823755, 0.05212884296530059, 0.042082877563578744, 0.06186840909400156, 0.10403338260948658, 0.052034529990383556, 0.09403968136757612, 0.23597111073987825, 0.2870870807341167, 0.14315638185611793, 0.2989065907895565, 0.17783566883632115, 0.3697586746088096, 0.19321267014103277, 0.14894965956253664, 0.15507122608167784, 0.20874854363501072, 0.126759515276977, 0.14539647022528307, 0.12879062843109879, 0.29906992773924557, 0.38066677642720087, 0.129631618303912, 0.1956504021904298, 0.1788044539945466, 0.2789499802248818, 0.12412002762513501, 0.08950289445263998, 0.23567706080419676, 0.1268572514610631, 0.1811857455010925, 0.16293408987777575, 0.2465998732617923, 0.1930445155927113, 0.14111552493912832, 0.1605689882167748, 0.35012681090406006, 2.4096393968377794, 78.51428277151925, 112.62250328063965, 111.39831406729562, 97.09332111903599, 69.51541369301933, 41.025569098336355, 44.678066866738455, 89.9379550388881, 98.40500899723598, 90.29678085872105, 99.4309035709926, 111.15474496568952, 46.57693658556257, 1.9433030145508903, 0.13251100879694733, 0.4078571945428848, 0.24811854319913046, 0.3363846583025796, 0.3090288947735514, 0.2350322354052748, 1.9326457806995936, 1.6832032799720764, 3.8215457030705045, 13.009449209485735, 33.206636156354634, 64.38010433741978, 77.44617094312395, 82.64730753217424, 79.87657438005719, 82.76266847337995, 82.95880917140416, 81.31187071119035, 82.83911950247628, 85.60409954616001, 86.0808710370745, 92.62625476292202, 88.20283004215786, 93.54856559208461, 92.51238768441337, 97.32484204428536, 92.96764060429165, 85.83449486323765, 93.93227985927037, 89.8290489741734, 84.53128378731864, 77.55084555489677, 60.18926361628941, 32.886390209198, 15.107153790337698, 6.018730682986123, 3.146043573107038, 3.625055640935898, 2.7228872052260806, 20.235285656792776, 27.621285029820033, 24.75159215927124, 44.346790654318674, 63.831828934805735, 80.47124290466309, 94.50494343893868, 105.46783896854946, 106.78236171177456, 109.14294964926583, 110.72852856772286, 119.14965493338448, 115.28876331874302, 114.1375093460083, 103.11291381290981, 103.43005044119698, 98.3507296698434, 96.76476165226528, 100.28718566894531, 96.57497160775321, 92.42250578744071, 92.52141339438302, 90.84955174582345, 88.33765288761684, 83.32179696219308, 85.9608964920044, 87.99999128069196, 90.23382323128837, 92.10721043178013, 90.80889783586774, 67.56445680345807, 39.64298527581351, 13.17564056600843, 2.7055336449827467, 4.6809709923607965, 8.0693963936397, 2.7885305285453796, 0.5096600289855684, 0.4352141794349466, 0.3470427063958985, 0.16818303322153433, 0.22903490864804812, 0.3257624368582453, 0.6663167742746217, 0.13928151263722352, 4.813616446086338, 68.3872138432094, 100.54948711395264, 74.90308856964111, 108.88630403791154, 158.31314849853516, 116.12466635022844, 38.203551292419434, 21.74518132209778, 25.790104661669048, 44.439410141536165, 59.88505063738142, 83.55202552250454, 84.78911754063198, 6.370412886142731, 0.6486557562436376, 0.36813507601618767, 0.2599742056003639, 0.23320665050830158, 0.10402597979243312, 0.18796292612595217, 0.232389151517834, 0.10711556007819516, 0.0888586322377835, 0.0731378308098231, 0.15466342653547013, 0.14469088880079134, 0.10837304153080497, 0.1062348826921412, 0.21378772466310433, 0.14822210717414105, 0.18938764610460826, 0.19171472266316414, 0.14614496220435413, 0.09419839749378817, 0.1676270416272538, 0.1722946704498359, 0.2126643963690315, 0.12759260700217315, 0.12936468262757572, 0.14112795570066997, 0.15273908765188285, 0.15455173967140062, 0.17113120002405985, 0.2696340743984495, 0.10569318104535341, 0.2786811175090926], [0.1014749256095716, 0.1558161082544497, 0.125176411654268, 0.15291940154773848, 0.08259985236717121, 0.03720722686765449, 0.07562636477606637, 0.07974855322390795, 0.07015366093920809, 0.0453666817130787, 0.05485706264153123, 0.02732463912772281, 0.10570656175592116, 0.2155919899897916, 0.1278030342821564, 0.06935509307576077, 0.02055016246491245, 0.048775577185941596, 0.03782591170498303, 0.036336055757211785, 0.030151324413184608, 0.0857952366183911, 0.006391217183720852, 0.020183198852464557, 0.03846074906843049, 0.0636918633910162, 0.14756083408636705, 0.09287976646529776, 0.20226930773683957, 2.952033583606992, 61.747438839503694, 89.8073844909668, 83.64246327536446, 74.3859133039202, 58.92128685542515, 33.34107337679182, 43.73998710087368, 88.96679142543248, 86.83743953704834, 69.34951155526298, 93.50185285295758, 89.78114114488874, 17.708397797175817, 0.21154865409646714, 0.013166447868570685, 0.017239340747307454, 0.1243635674140283, 0.01955926724310432, 0.12637572229972907, 0.0388561449944973, 0.1599152332970074, 0.7912643839206014, 4.499741562775203, 17.782345737729752, 35.50722639901297, 56.56414175033569, 68.40597397940499, 71.2664292199271, 68.46841049194336, 69.18052441733224, 67.3556912285941, 72.59059606279645, 76.35215623038155, 79.68670095716203, 87.75271184103829, 90.27981335776192, 89.50736822400773, 90.65020098005022, 89.33979157039097, 87.18132672991071, 85.82479517800468, 88.33043370928083, 90.48118604932512, 86.11670984540666, 87.62833213806152, 86.88156754629952, 85.34305572509766, 77.75997938428605, 73.37328284127372, 62.05529267447335, 54.691313879830496, 22.351062502179825, 10.99264771597726, 9.300417423248291, 24.5920250415802, 55.330106939588276, 54.08591038840157, 59.714708600725444, 61.53594262259347, 80.76615919385637, 90.16395214625767, 99.37358093261719, 97.16536699022565, 95.18886852264404, 88.639739717756, 86.51593944004604, 86.70700100490025, 88.28545107160295, 88.19991179874965, 90.57169328417096, 83.27776622772217, 84.02375956944057, 83.62815693446568, 81.7009767804827, 80.16626562391008, 79.81389468056815, 76.82015214647565, 76.18654591696603, 78.29150268009731, 80.03056730542863, 75.44646549224854, 73.01654148101807, 72.57512937273297, 74.38323824746269, 63.92904812949044, 50.788309233529226, 34.39869342531477, 11.794263992990766, 1.1650311648845673, 0.7170565915959222, 1.504467710852623, 0.6724349345479692, 0.3275525208030428, 0.1529280325131757, 0.09785027296415397, 0.11310150101780891, 0.05735026832137789, 0.006825916402574096, 0.0843694174130048, 0.2304579322891576, 0.5297885260411671, 36.10978807721819, 92.36978285653251, 69.05591542380196, 86.15196500505719, 130.29103578839982, 137.28296634129114, 53.66995995385306, 22.8088185106005, 20.463996035712107, 26.847773347582134, 52.22883408410208, 58.63730008261544, 48.87978151866368, 8.833201442446027, 0.37747994171721594, 0.07285399282617228, 0.10121347249618598, 0.062127908026533465, 0.06371378685746874, 0.057708297323967726, 0.0811449782922864, 0.05169432271005852, 0.016458898250545775, 0.042477645844753296, 0.032863120149288855, 0.055818305883024416, 0.04315249981092555, 0.09166598266788892, 0.07163051276334695, 0.03311497199216059, 0.03444132474916322, 0.05166457573484097, 0.08967351208307914, 0.033896888606250286, 0.05023356234388692, 0.02038665927414383, 0.04179794035319771, 0.005047725480315941, 0.03288561697783215, 0.06980067345180682, 0.03560658650738852, 0.02350507560186088, 0.052179359897438965, 0.035966057396892986, 0.04717527609318495, 0.05353733238631061, 0.026869964686089327, 0.07053863456738846, 0.13664305635860988, 0.0178816911897489, 0.040650585134114535, 0.07144278926508767, 0.032259522538099966, 0.06287102600825684, 0.05066032355119075, 0.12744330215666974, 0.03935765701213053, 0.042411434397633584, 0.09193851625812904, 0.03785536012479237, 0.05293318855443171, 0.028215279104188085, 0.043391174503735135, 0.08077371107148272, 0.06013995648494788, 0.029916961810418537, 0.06109353567340544, 0.014341285452246666, 0.013816867788721408, 0.032269812521657774, 0.06460694250251565, 0.10518586755331073, 0.10215610012944255, 0.4416390103953225, 7.231462751116071, 85.76238645826066, 99.81959969656808, 95.6608943939209, 90.00824996403286, 94.08445235661098, 46.83424922398159, 20.662884746279033, 40.761332580021445, 76.15473011561802, 81.37630135672433, 108.9946403503418, 93.81129782540458, 13.038653356688362, 0.081765993897404, 0.05861419585666486, 0.09584706795534917, 0.13912983291915484, 0.14133735160742486, 0.1132407703303865, 0.15136034520609037, 0.2682153119572571, 1.1945226852382933, 6.776686651366098, 21.769661562783376, 42.078947271619526, 63.43215465545654, 77.06748022351945, 78.63957963671002, 77.0945851462228, 76.07995360238212, 72.93770721980503, 76.88654218401227, 81.62170478275844, 84.83571216038295, 94.14224052429199, 93.51297691890171, 94.69749886648995, 94.7638750076294, 96.37534986223493, 91.73509270804269, 92.53079346248082, 91.5514657156808, 92.92382526397705, 87.66159316471645, 87.04834515707833, 89.47469084603446, 88.19335269927979, 85.45763151986259, 85.43484837668282, 75.9347015108381, 68.53975459507534, 32.59735904421125, 17.120580196380615, 14.000053014074053, 34.10442679268973, 67.24828597477504, 63.74469157627651, 67.75153010232108, 71.04567800249372, 87.36509268624442, 95.88630785260881, 104.37012086595807, 100.10410063607353, 97.7492310660226, 93.44537789481026, 92.78265176500592, 92.90560708727155, 92.35353796822685, 91.03067738669259, 95.9671709878104, 89.97595473698208, 88.1426864351545, 86.56933634621757, 86.10890701838902, 83.73595128740583, 80.91196019308907, 80.63565812792096, 79.69959681374687, 81.04829774584088, 82.34003734588623, 78.53862231118339, 79.36631952013288, 80.39518097468785, 77.24506228310722, 70.13187176840646, 53.64735051563808, 36.053247111184255, 14.464117986815316, 1.981539168528148, 0.28186602517962456, 0.9520329428570611, 1.4487003833055496, 0.8346156605652401, 0.11071552761963435, 0.17871450739247458, 0.10584474541246891, 0.16747837460466794, 0.0832747911502208, 0.06072937949959721, 0.26488723339779036, 0.11127081353749547, 31.801474162510463, 99.1114115033831, 74.26955182211739, 86.14800453186035, 125.32975796290806, 102.21251760210309, 21.39824387005397, 25.13656231335231, 34.573204381125315, 44.58832393373762, 69.83203615461076, 66.74145657675606, 67.70162814004081, 17.304009165082658, 0.28353893969740185, 0.12802715439881596, 0.16936563833483628, 0.16047005781105586, 0.1591459917170661, 0.17282227213893617, 0.045006464435053725, 0.04707797756418586, 0.02793435542844236, 0.12697522155940533, 0.06300099939107895, 0.09407622047833034, 0.06871946182634149, 0.038785272011799474, 0.034542765734451156, 0.11152108439377376, 0.03231481296409454, 0.03421194937878421, 0.043933188276631494, 0.027727615986285464, 0.016933302794184004, 0.011528496563966786, 0.030533919776124612, 0.0333899313450924, 0.030617189593613148, 0.007690829723807318, 0.045561777494315586, 0.03545741058353867, 0.03943175642884203, 0.043416032634143314, 0.045300599187612534, 0.2135927408401455, 0.25775566750339096, 0.12040141145033495, 0.24943452115569795, 0.22350513323077134, 0.11048986044313226, 0.11283236688801221, 0.18813435121306352, 0.10787758204553809, 0.0950551497350846, 0.10582771418350083, 0.13332089462450572, 0.20570726825722627, 0.1854109423501151, 0.13246155716478825, 0.15479977136211737, 0.10146627428808383, 0.2608810540820871, 0.1494461436356817, 0.1500454121934516, 0.09887695751552071, 0.17572056661759103, 0.17765813693404198, 0.10392630978354386, 0.0587029346664037, 0.24653429963759013, 0.41553158845220295, 0.22730629997594015, 0.4607100784778595, 6.811574859278543, 97.13378742762974, 116.17929308755058, 101.56509835379464, 92.97169140407017, 71.75373417990548, 42.316811902182444, 50.50946760177612, 120.82207243783134, 120.82524081638881, 89.8795554297311, 113.46042128971645, 110.66151319231305, 24.804398468562535, 0.8371957764029503, 0.19839457422494888, 0.25922754566584316, 0.2206401683922325, 0.1518241646034377, 0.28897055823888096, 0.41281991824507713, 0.890325991170747, 2.2809392171246663, 7.363722579819815, 22.503162043435232, 41.2962327003479, 66.85658127920968, 81.67467090061733, 86.20540360042027, 83.31992789677211, 83.59411770956856, 78.39904689788818, 82.3030173437936, 86.26678398677281, 90.20783696855817, 100.10829039982387, 99.16352994101388, 99.73962593078613, 101.23619147709438, 99.90422875540597, 97.45284870692662, 96.36797087533134, 96.15209034511021, 97.37313202449253, 97.6735234941755, 97.52468613215855, 101.88119275229317, 99.8587805884225, 95.4039500100272, 92.09744126456124, 78.25193268912179, 66.09555203574044, 31.71341269356864, 15.091718367167882, 13.265987992286682, 34.527902126312256, 66.69476468222481, 66.42655032021659, 73.52649756840297, 75.72845813206264, 90.0725346973964, 100.52999741690499, 103.55508327484131, 100.91555990491594, 99.70489188602993, 96.20564705984933, 92.69844654628209, 95.06599657876151, 96.84254673549107, 97.50901794433594, 101.9644877570016, 96.38156849997384, 96.69130529676164, 92.87489604949951, 90.76682649339948, 91.1226645878383, 87.3805524281093, 86.90555272783551, 86.61989838736397, 88.07857540675572, 89.20859568459647, 84.83786610194615, 86.6822862625122, 85.91125856127057, 90.20599569593156, 85.74966430664062, 66.34827886308942, 37.597362654549734, 13.175116845539637, 2.6596570781299045, 4.138743996620178, 6.27959862777165, 3.396784518446241, 1.4595685601234436, 0.2763700272355761, 0.299806789628097, 0.2676577461617333, 0.20565834588238172, 0.18346841872802802, 0.14066721685230732, 0.2643711125212056, 1.2126768082380295, 48.33630732127598, 108.9264646257673, 80.77758203233991, 91.06675938197544, 135.89413261413574, 157.7220791407994, 69.19708892277309, 31.407268115452357, 25.162022250039236, 38.371249539511545, 67.44057042258126, 74.16865008217948, 80.99214240482875, 18.7860894543784, 0.5339724815317562, 0.2154216505587101, 0.21373064629733562, 0.26145550182887484, 0.18556461696113857, 0.29116665039743694, 0.13719456962176732, 0.1244651305356196, 0.07832468141402517, 0.2072918103741748, 0.16377900168299675, 0.19635179026850633, 0.18836585379072598, 0.09928031944270645, 0.17008225273873123, 0.12580116598733834, 0.06085707979010684, 0.15311733021267823, 0.1881336998194456, 0.09126521274447441, 0.12452461091535431, 0.12811936730785028, 0.07014334042157445, 0.08645143426422562, 0.09704112673976592, 0.14865779450961522, 0.12129566632211208, 0.1026422433289034, 0.15508305973240308, 0.11713117121585778, 0.3676992122616087], [0.17854065314999648, 0.07128922321966716, 0.10381766954170805, 0.1657828920121704, 0.06194753984787634, 0.07115633892161505, 0.14808474454496587, 0.11549381193305765, 0.05391133749591453, 0.07206959955926452, 0.030572141653725078, 0.04187997184427721, 0.24079948450837815, 0.11365781830889837, 0.11695406000529017, 0.12996310980192252, 0.06837866761322532, 0.13237393115247997, 0.022856944041060548, 0.050284024993223805, 0.050560222672564645, 0.05323665316349693, 0.07748026493936777, 0.05189418519980141, 0.017570360663479993, 0.21515003299074514, 0.13605543146175997, 0.2691054141947201, 6.927568086556025, 67.58074338095528, 88.08264705113002, 74.8149367741176, 87.14580059051514, 57.844451563698904, 25.263010842459543, 60.93501377105713, 85.64591380528041, 79.2737625667027, 83.51070458548409, 104.61227253505162, 68.49563353402274, 4.947411392416273, 0.1707893812230655, 0.05235062213614583, 0.15078452681856497, 0.07367467414587736, 0.2229624137814556, 0.07490856972123895, 0.21717151094760212, 0.8705748138683183, 2.154466369322368, 11.096024751663208, 30.68214021410261, 47.03359998975481, 63.50131702423096, 72.88021087646484, 80.17451313563755, 78.80624607631138, 78.1024421964373, 79.41250419616699, 80.17306096213204, 82.58798381260463, 89.31496565682548, 88.98770550319126, 91.2797633579799, 90.59891632625035, 94.61683028084892, 95.4941793169294, 92.59832300458635, 88.16699818202427, 83.90965625217983, 83.45864173344204, 93.39535086495536, 84.7504299708775, 77.96663965497697, 78.71705899919782, 74.83240454537528, 75.61116559164864, 77.876083782741, 84.69634519304547, 87.54792063576835, 76.65311745234898, 64.17584119524274, 45.36526802607945, 51.14969546454293, 78.85807268960136, 77.66837433406285, 77.1537699018206, 73.72033146449498, 85.17399215698242, 92.01337500980922, 94.3150144304548, 89.66908754621232, 86.95437771933419, 87.78912040165493, 90.32539354051862, 88.16229425157819, 85.78250844138009, 77.55386107308524, 81.25258173261369, 83.10959202902657, 75.42157704489571, 76.75305339268276, 78.64068440028599, 76.2020959854126, 77.77145780835832, 80.40853541237968, 81.70061547415597, 79.85021291460309, 80.59222493852887, 79.89382675715855, 81.08233002253941, 76.31057126181466, 71.51993424551827, 70.36736011505127, 57.66021312986101, 38.31635529654366, 20.669231925691875, 7.408960563795907, 0.6953544361250741, 1.0082481035164423, 1.2822120998586928, 1.0636841974088123, 0.04455632430368236, 0.20515324441449984, 0.05623919436974185, 0.04332371115950601, 0.060452435431735854, 0.06370721863848822, 0.1130660136363336, 0.13862664492002555, 0.2071973718702793, 20.483954736164637, 86.52084486825126, 68.99253395625523, 53.07764686856951, 95.46385043007987, 134.97767911638533, 49.65005186625889, 30.687907218933105, 28.905812399727957, 36.488103594098774, 53.51135342461722, 71.75153160095215, 65.01121616363525, 13.883854814938136, 1.365099549293518, 0.17205848598054477, 0.04462034408269184, 0.08838816998260361, 0.07319405422146831, 0.025199547177180648, 0.04395675719050424, 0.04536211856507829, 0.0902163265272975, 0.01613352374572839, 0.028715897151934247, 0.004122204563048269, 0.0758762556527342, 0.18629086656229837, 0.1132923322064536, 0.16851812095514365, 0.03674230145822678, 0.06535356851028544, 0.06049749015697411, 0.060689047378088744, 0.03856675320171884, 0.05955240622695003, 0.04484019960675921, 0.02322958699161453, 0.06546226303492274, 0.004491128717615668, 0.059885729769510884, 0.0593867011900459, 0.06644067660506282, 0.2576666437089443, 0.08158583606460265, 0.027935782048319067, 0.007030350097920746, 0.12131104192563466, 0.039864363215331516, 0.05871897523424455, 0.21085422778768198, 0.17315377720764705, 0.11182596374835287, 0.008742092509887047, 0.016728363166164075, 0.036144230514764786, 0.1481388509273529, 0.079930264901902, 0.09446579457393714, 0.10527331714651414, 0.0854005395833935, 0.11336659786424466, 0.05622166781021016, 0.05666831687891057, 0.05012685253417917, 0.037212546582200696, 0.0550722464519952, 0.1275914806340422, 0.051936990581452847, 0.4789741784334183, 0.12196470185049943, 0.293869961053133, 16.643584626061575, 93.50379140036446, 95.11217430659703, 94.1488343647548, 114.71047169821603, 93.43619237627301, 27.752204724720546, 24.18441939353943, 53.910826206207275, 78.99700886862618, 96.68005616324288, 112.36730984279087, 69.40672302246094, 2.8909200515065874, 0.19945348240435123, 0.02847033193601029, 0.10892600685890232, 0.1247921029904059, 0.4198035363640104, 0.1561263616063765, 0.44699864994202343, 0.8230977186134883, 4.411714834826333, 18.020917347499303, 41.902921608516145, 56.069645404815674, 73.43898500714982, 79.52126434871128, 88.81498718261719, 84.95408861977714, 87.92008699689592, 87.70708996909005, 86.87035315377372, 88.83714498792375, 92.84658214024135, 92.47962692805699, 91.72234276362828, 92.35901314871651, 93.8496310370309, 95.2306410925729, 95.32997253962925, 89.50966112954276, 85.25207601274762, 83.18092918395996, 94.39631530216762, 86.48464475359235, 80.49842425755092, 81.99555955614362, 81.65488243103027, 80.84104687826974, 84.16920621054513, 92.14960833958217, 94.82024574279785, 86.96361882346017, 73.57655933925084, 58.880542618887766, 60.72950690133231, 83.87294891902378, 84.50854233333042, 78.54917662484306, 80.36137798854283, 88.34176622118268, 96.94318444388253, 98.20982715061733, 93.70840195247105, 91.53581837245396, 91.76345525469098, 94.85586220877511, 94.65032059805733, 91.50037561144147, 83.93402358463833, 83.58136081695557, 88.67589119502476, 83.62830284663609, 83.86289487566266, 82.30122470855713, 82.50191647665841, 82.05711364746094, 83.19823714665004, 85.56541197640556, 84.44812774658203, 85.95352445329938, 84.38439192090715, 86.27271774836949, 82.9770759854998, 82.17909622192383, 76.68985257829938, 70.23455224718366, 49.977454457964214, 24.55180539403643, 8.100742323057991, 1.3694786514554704, 0.8701116187231881, 0.2184211281793458, 0.5420613246304649, 1.2534430835928236, 0.17142759769090585, 0.31999885184424265, 0.10445932618209294, 0.07495263378534998, 0.0673578998872212, 0.06052168671573911, 0.10317011643201113, 0.39502658588545664, 16.095872027533396, 90.04267828805106, 80.3834593636649, 59.152898107256206, 97.00355734143938, 120.68712452479771, 26.48803036553519, 23.28474405833653, 43.020407336098806, 58.51369162968227, 74.98224244798932, 81.01384162902832, 81.16881425040108, 25.676902873175486, 1.7606184801885059, 0.24011774680444173, 0.10202368402055331, 0.07810742128640413, 0.12764959037303925, 0.07010555280638592, 0.08835346291639976, 0.0973235737266285, 0.03072491381317377, 0.009376768721267581, 0.029554356089127914, 0.04581781250557729, 0.07113026282084839, 0.07675102299877576, 0.07570149217333112, 0.03931897373071738, 0.08043352753988334, 0.012388985836878419, 0.022792020114138722, 0.018820473225787282, 0.03097077419183084, 0.06112666853836604, 0.07096053407128368, 0.024080607308340923, 0.05871017463505268, 0.023383013937356215, 0.08160489611327648, 0.1008584290476782, 0.11104777229151555, 0.1695799875472273, 0.20873145812324115, 0.22372287511825562, 0.11704993700342518, 0.22156915068626404, 0.12812604409243378, 0.1088393647223711, 0.2153291662356683, 0.1886484907673938, 0.2539274814937796, 0.0879761635192803, 0.07350508110331637, 0.09095987198608262, 0.2960629319506032, 0.15222360459821566, 0.20703501201101712, 0.1723875483231885, 0.19346223532089166, 0.21168186409132822, 0.12918576651385852, 0.19444018070186886, 0.1486687867769173, 0.09828471179519381, 0.17537773001406873, 0.2403473901961531, 0.23966573391641888, 0.4794464388063976, 0.21926902553864888, 0.281562150056873, 16.62499472073146, 105.81111471993583, 109.50711168561662, 94.32445008414132, 107.11283888135637, 72.69224820818219, 30.28088174547468, 76.40506676265171, 124.52139064243862, 99.23047583443778, 102.58874865940639, 120.05782617841447, 86.67754759107316, 7.26147940329143, 0.20661840508026735, 0.1395412287009614, 0.23053751087614469, 0.2625480517745018, 0.6183635102851051, 0.3198084006352084, 0.891414144209453, 2.8043148815631866, 4.019702247210911, 16.64646986552647, 39.526001930236816, 54.754914215632844, 76.45237009865897, 88.79108537946428, 96.03903620583671, 91.72172437395368, 91.00412831987653, 93.9613928113665, 92.13870661599296, 95.06890092577252, 100.8494200025286, 97.5655415398734, 97.80089092254639, 100.48732158115932, 101.31913212367466, 100.68620681762695, 97.0460455758231, 93.36391026633126, 87.63226481846401, 87.9538413456508, 98.48328740256173, 95.04383877345494, 87.65600681304932, 92.48357350485665, 89.48736436026437, 90.881256375994, 90.91894340515137, 97.59508528028215, 99.76618194580078, 92.22841480800084, 78.38760321480888, 60.093364579336985, 63.23792471204485, 87.07439395359584, 87.08109896523612, 86.37890011923653, 84.77393572671073, 92.26993029458183, 98.18958704812187, 99.0260111945016, 93.7048236301967, 92.0296824319022, 93.51881340571812, 96.81095327649797, 95.59032848903111, 95.29937962123326, 89.9996758869716, 92.90324469975063, 96.73993573869977, 90.24413435799735, 93.60870225088937, 91.2292707988194, 89.10369178227016, 87.24773761204311, 89.45033740997314, 90.80461774553571, 90.61371598924909, 90.57015078408378, 91.16752215794155, 91.5631456375122, 90.79556424277169, 87.3162260055542, 83.20205865587506, 83.90692561013358, 69.10667896270752, 34.91253355571202, 8.438606296266828, 2.0270194709300995, 2.936760140316827, 5.182182337556567, 5.280643088476999, 1.8609707696097237, 0.2534266955086163, 0.28811972960829735, 0.1970446423760482, 0.1604622003755399, 0.13604438491165638, 0.16924008221498557, 0.2167051945413862, 0.3899590420935835, 27.94945192337036, 102.36582960401262, 86.38873182024274, 69.99823011670793, 106.57467310769218, 155.97457940237862, 66.26311479296002, 40.82431105204991, 35.15153769084385, 47.73188352584839, 72.3944901057652, 87.20595114571708, 93.51064232417515, 28.77549719810486, 2.0093365226473128, 0.4611380440848214, 0.30081628688744133, 0.2600797042250633, 0.1605468408337661, 0.14190596395305224, 0.1688459755054542, 0.217304422387055, 0.16867917802717003, 0.09096887614578009, 0.14775884417550905, 0.08977673083011593, 0.23792249602930887, 0.30696612117545946, 0.19211663252540997, 0.1593396184699876, 0.17476357439798967, 0.205361595377326, 0.11519489011594228, 0.0904087997706873, 0.10689361127359526, 0.18508034651832922, 0.11343380675784179, 0.14607577877385275, 0.10926676714526755, 0.11627731631909098, 0.1068980081805161, 0.11118784906076533, 0.14217902001525673, 0.2275509661329644], [0.14995045800294193, 0.011516360965158259, 0.07180858749364104, 0.07519035174378327, 0.17312370453562054, 0.05744806557361569, 0.137124951928854, 0.08130361299429621, 0.05207432606922729, 0.030235384723969867, 0.10475387823368822, 0.035752525819199424, 0.041332987802369256, 0.12410638907126018, 0.05062447315348046, 0.16012640696551117, 0.11546922182398182, 0.09082069766840764, 0.04300105418743832, 0.08454860494072948, 0.1544796521110194, 0.03346149982618434, 0.06471079228711979, 0.09975703779075827, 0.1214885873986142, 0.09436007203268153, 0.17620927467942238, 17.039986303874425, 93.76520347595215, 80.07821805136544, 71.81578854152134, 61.175331115722656, 43.20930106299264, 27.10396385192871, 67.47069781167167, 93.05529907771519, 79.46641526903424, 95.30558436257499, 110.95064163208008, 61.526500020708355, 1.4938995007957732, 0.1599084208054202, 0.12716356930988176, 0.15757500672979013, 0.18182320200971194, 0.0876193151676229, 0.07079714283879314, 0.9913519301584789, 0.5121737026742527, 7.337648596082415, 34.504326888493125, 67.17701830182756, 79.91646398816789, 89.6439072745187, 89.87212780543736, 92.31134850638253, 91.18619891575405, 87.5813067299979, 85.49394280569894, 90.10822064535958, 87.25822244371686, 86.72672694069999, 89.14440822601318, 89.89801679338727, 91.82446738651821, 89.44408403124127, 87.67397485460553, 84.11603164672852, 85.98359625680106, 87.09667682647705, 90.89330455235073, 85.90135043007987, 83.49768366132463, 79.24903392791748, 75.05424662998745, 77.96867547716413, 72.39744309016636, 71.69544574192592, 70.82309246063232, 74.50975104740688, 79.83686542510986, 81.26842362540108, 82.2523649760655, 84.98699528830392, 82.48767961774553, 87.28483404432023, 93.24704156603131, 84.52524580274309, 83.37034402574811, 87.14338261740548, 93.28135177067348, 90.21600805010114, 85.46677534920829, 82.5751713344029, 78.92155838012695, 74.9214735031128, 73.83974320547921, 73.39121614183698, 67.48895072937012, 62.89571898324149, 61.59639889853341, 67.66387857709611, 69.6682323728289, 67.8073866707938, 69.05356693267822, 71.35255214146206, 75.40197617667062, 79.5792818069458, 84.75170149121965, 81.82379313877651, 80.50494166782924, 81.26997307368687, 70.2818694795881, 76.00223800114223, 76.78074891226632, 64.24020235879081, 55.79614346367972, 38.77427632468087, 17.85940647125244, 1.833976366690227, 0.5747338714344161, 1.5125656191791808, 1.8353901079722812, 0.5659953717674527, 0.08814016543328762, 0.1733558177947998, 0.11490202083119325, 0.10647192890090601, 0.15129820496908256, 0.10494564580065863, 0.16897135520620005, 0.059545980500323434, 0.39538048260978287, 11.037135294505529, 75.89915452684674, 82.98917974744523, 54.5632655279977, 33.97342893055507, 73.84133434295654, 67.68067932128906, 26.500837632587977, 26.029249497822352, 40.92652252742222, 47.654195717402864, 64.07293837411063, 72.02045467921666, 44.00636713845389, 9.868727087974548, 0.2950311244598457, 0.12503979541361332, 0.09109062568417617, 0.11935095781726496, 0.05281062138133815, 0.05505395314789244, 0.0895755316263863, 0.042454894565578015, 0.024422855282734548, 0.04215054107563836, 0.0184110078761088, 0.041398914264781136, 0.06078024248459509, 0.06451000020440135, 0.12707084071423325, 0.07099675427057914, 0.031836859682308774, 0.031589136725025516, 0.06724835040846042, 0.05268887184294207, 0.05380874639376998, 0.09044645846422229, 0.1533041444740125, 0.051489184610545635, 0.07657930614160639, 0.06860357483050653, 0.1005756835054074, 0.08497037552297115, 0.16867198555597238, 0.03224503920812692, 0.08173950389027596, 0.01683283381031028, 0.11859736325485365, 0.022533199716625468, 0.05248255987784692, 0.1757960875651666, 0.07300979803715434, 0.04086833719962409, 0.1309667716601065, 0.04049489866676075, 0.03726811520755291, 0.07021978417677538, 0.09522202185222081, 0.1311808494584901, 0.09150194004178047, 0.09107134850429636, 0.06506331837070839, 0.05719280069960015, 0.1059396385348269, 0.06478835562510149, 0.04355184820347598, 0.07077621681881802, 0.10153764938669545, 0.3591461426445416, 0.045452804770320654, 30.20504215785435, 116.84074074881417, 85.9050121307373, 92.99799033573696, 82.66239901951381, 77.53593472072056, 31.480516024998256, 23.968083756310598, 63.32864039284842, 82.60654245104108, 106.34796033586774, 117.32265390668596, 63.528387205941335, 0.9219912120274135, 0.16406075656414032, 0.1623563173093966, 0.14578574576548167, 0.24978176823684148, 0.3483719022146293, 0.35075385868549347, 0.8624583951064518, 1.0935229105608804, 11.578960163252694, 43.82143388475691, 75.97372954232353, 86.53372682843889, 95.71817534310478, 94.45820985521588, 95.96908174242292, 94.96388585226876, 92.15547261919293, 88.658034324646, 91.81487192426408, 89.19938932146344, 88.79455253056118, 91.56049837384904, 89.96178041185651, 94.1042616707938, 89.52348109654018, 89.616468838283, 87.46922533852714, 88.88130773816789, 89.5316938672747, 94.12179197583879, 87.65816075461251, 87.67009775979179, 85.01635142735073, 80.54869447435651, 85.396897315979, 80.28499644143241, 79.89020674569267, 76.8373280933925, 78.25467027936662, 83.88143961770194, 85.8250731059483, 86.08745792933873, 87.92861243656704, 86.21866076333183, 92.12208652496338, 99.44425800868443, 88.80636446816581, 85.90267753601074, 90.99519988468715, 94.33688735961914, 93.81103379385812, 90.39093589782715, 88.25734560830253, 83.25136307307652, 80.56963634490967, 80.1605611528669, 77.34009279523576, 73.89599582127163, 70.62825107574463, 68.07638617924282, 73.22661331721714, 76.00649029867989, 77.33524295261928, 75.47015190124512, 77.48335075378418, 78.93123027256557, 83.36946855272565, 87.65798704964774, 85.62517343248639, 85.30929442814418, 83.19320665087018, 76.64062459128243, 80.66966261182512, 82.56421402522496, 69.45042719159807, 64.9272471836635, 57.82277665819441, 39.74243484224592, 8.357169934681483, 1.176281275493758, 0.4545186364224979, 0.6492747430290494, 1.3239627395357405, 0.16364371537097863, 0.244155545852014, 0.20804464497736522, 0.4677966439298221, 0.2631857932678291, 0.1770226481769766, 0.1846723026995148, 0.09446300579501049, 0.3871905377932957, 7.64022353717259, 73.33062785012382, 94.13553551265171, 56.73758268356323, 36.10285030092512, 60.86989525386265, 31.778235912322998, 26.174211502075195, 38.62735666547503, 61.163248198372976, 68.09999615805489, 70.20974717821393, 87.14001968928746, 63.86118507385254, 18.64654357092721, 0.2485889308154583, 0.1111504617812378, 0.14783508437020437, 0.1252772148166384, 0.05924103329224246, 0.11446535640529223, 0.02943072361605508, 0.033088699116238525, 0.051442358908908706, 0.026013790895896297, 0.10150784812867641, 0.020265130259628807, 0.06975143895085369, 0.03935844750542726, 0.046260244479136806, 0.06362597085535526, 0.016222245592091764, 0.04022443800100258, 0.07042771444789, 0.061620594534490786, 0.04463584182251777, 0.043399707081594636, 0.11089318165821688, 0.020093130114089166, 0.089687333841409, 0.040252298648868284, 0.13145249416785582, 0.11616729865116732, 0.19384338201156684, 0.07978126539715699, 0.13455603191895144, 0.11989346013537475, 0.32782678465758053, 0.15982310181217535, 0.13934614988309996, 0.24476888722607068, 0.12867438181170396, 0.1479809693992138, 0.2100192361644336, 0.15031609338309082, 0.1378428012664829, 0.1240569781512022, 0.13135749926524504, 0.26949117492352215, 0.21962958547685826, 0.18014736979135446, 0.18496954174978392, 0.15375321252005442, 0.2202875337430409, 0.13124984289918626, 0.22663301681833609, 0.18728935798364027, 0.13611974301082747, 0.3994719944894314, 0.23995565835918697, 32.181762967790874, 135.10132925851005, 99.39803859165737, 93.8653131212507, 78.5303817476545, 52.146602153778076, 30.53778096607753, 84.0494818006243, 127.5470393044608, 98.62675380706787, 114.2494934626988, 127.2669574192592, 77.00546060289655, 3.516244028295789, 0.30275990973625866, 0.4178415387868881, 0.4543812737933227, 0.30200122616120745, 0.3972529135644436, 0.5443672037550381, 2.883506540741239, 1.909337614263807, 10.1914188010352, 38.88884169714791, 72.7854791368757, 87.93152373177665, 100.46241923740932, 99.38371835436139, 102.93995230538505, 101.01014573233468, 98.50819669451032, 96.81421198163713, 99.71288231440953, 95.22624288286481, 94.10344178336007, 100.8269008908953, 98.67227145603725, 104.1051721572876, 98.56845147269112, 97.61176095690045, 93.04036739894322, 94.86101082393101, 97.45940780639648, 96.22372627258301, 89.31108161381313, 93.57567051478794, 92.71146052224296, 89.07323087964738, 90.70306287493024, 86.97647993905204, 87.3918571472168, 84.63302625928605, 85.9207706451416, 92.34279605320522, 95.65375859396798, 93.91015679495675, 98.50584820338658, 96.13062735966274, 98.36017227172852, 102.37093652997697, 95.37748432159424, 90.71188013894218, 92.79653426579067, 96.2447932107108, 94.378659929548, 91.51178455352783, 90.42503765651158, 86.94854818071637, 84.75639152526855, 84.28435870579311, 83.58404976981026, 84.5198609488351, 84.07554449353898, 84.53436878749302, 85.78275857652936, 84.70236928122384, 86.8768983568464, 85.50798511505127, 84.02801881517682, 87.03515747615269, 87.80977044786725, 95.29990768432617, 88.66575377328056, 88.29163496834892, 86.76929160526821, 83.03812980651855, 84.34779575892857, 87.14562688555036, 73.8719481059483, 73.56279495784214, 73.50836971827916, 55.72005374091012, 11.23219120502472, 2.3019127888338904, 6.592569811003549, 4.935634195804596, 4.1973099282809665, 2.608106655733926, 0.44747954128043993, 0.13353831081518105, 0.4261174404195377, 0.3398445083626679, 0.16656045243144035, 0.22785496339201927, 0.14273993777377264, 0.497148548918111, 17.06307864189148, 87.81218842097691, 98.25875636509487, 73.80240358625139, 46.552704742976594, 101.31207970210484, 91.72298199789864, 34.92088876451765, 33.089791774749756, 51.20188685825893, 64.8161176953997, 75.61794703347343, 98.33492946624756, 73.2640780040196, 20.231729916163854, 0.3905212219272341, 0.13850058668426105, 0.26874125802091187, 0.19641664464558872, 0.22229986504784652, 0.1314672590898616, 0.18613599772964204, 0.1450550314038992, 0.09380997690771307, 0.06566497537174396, 0.23264856902616365, 0.09088098550481455, 0.18058271785931929, 0.24358218376125607, 0.24033851495810918, 0.18198063570473874, 0.12284683808684349, 0.097036363423935, 0.17232145901237214, 0.15813120188457624, 0.1590750440955162, 0.17114669776388577, 0.1709431508289916, 0.1872671970299312, 0.08482954557985067, 0.1458916107990912, 0.09565059135534934, 0.13965093424277647], [0.057842504765306196, 0.037147108665002246, 0.12062245101800986, 0.0600727272353002, 0.06938489433377981, 0.11079107570861067, 0.07060384856803076, 0.17644298928124563, 0.04558885443423476, 0.16831404476293496, 0.028599304479679892, 0.048552223813853095, 0.11346288198339087, 0.10084630362689495, 0.00450691780341523, 0.08487715159675904, 0.08795004670641252, 0.17286747614187853, 0.0842905987852386, 0.14123905902462347, 0.1950181975428547, 0.17808359196143492, 0.04150038239146982, 0.02119927111613963, 0.15752415731549263, 2.460408364023481, 29.98789358139038, 91.33089515141079, 78.86724431174142, 84.4855854851859, 54.01492411749703, 52.30780036108834, 28.80509305000305, 83.44735785893032, 88.37037890298026, 64.14301790509904, 104.14901529039655, 104.17830889565604, 50.28279651914324, 1.789013596517699, 0.12763639965227672, 0.044026035615908246, 0.06665320055825369, 0.2025725043245724, 0.16345928955290998, 0.11348770279437304, 0.3246469252875873, 0.24228202924132347, 7.254731833934784, 47.11372314180647, 75.79867662702287, 82.05800301688058, 87.78730692182268, 86.58817986079625, 89.05996676853725, 87.9755961554391, 86.4469438280378, 87.1044032233102, 83.78068378993443, 82.8019049508231, 86.12039239065987, 85.4450135912214, 86.03496428898403, 83.8119089944022, 81.68320328848702, 80.94442217690604, 75.83556461334229, 77.28636932373047, 78.19994626726422, 80.76271288735526, 86.39949457986015, 87.86344528198242, 86.98593643733433, 80.78607967921666, 74.09784099033901, 73.85968453543526, 73.69032914297921, 73.06797899518693, 66.92514610290527, 68.49040848868233, 72.92936243329729, 76.97782066890171, 79.8159235545567, 89.81121294839042, 75.6932099206107, 75.36323302132743, 84.38418347494942, 90.81014156341553, 88.71800422668457, 85.78379385811942, 91.13215582711356, 89.8102263041905, 85.5429276057652, 77.61582510811942, 75.57962771824428, 72.1968833378383, 73.22072124481201, 65.03731359754289, 58.570256914411274, 55.24735736846924, 49.32137080601284, 43.65025111607143, 56.95272670473371, 64.35464613778251, 67.27265330723354, 69.47480147225517, 72.28148460388184, 77.39717919485909, 79.7329273223877, 79.8777972630092, 80.24752480643136, 72.90685721806118, 73.350006375994, 78.09195041656494, 75.71317904336112, 75.13137163434709, 69.43915026528495, 62.328787667410715, 53.24357679912022, 44.25201375143868, 16.370242493493215, 1.027649319597653, 0.5485239092792783, 1.7615354252713067, 1.4067571482488086, 0.6961591786571911, 0.29176099279097145, 0.18793202564120293, 0.19354306241231306, 0.24170158324497087, 0.17352788070482866, 0.10311195241021258, 0.05965871909367187, 0.733691121850695, 2.3842487250055586, 54.27329288210188, 92.06443732125419, 77.10292298453194, 35.34012917109898, 63.175800868443076, 61.61850111825125, 33.25857394082205, 25.18048013959612, 37.98592676435198, 55.24343511036464, 55.02512271063668, 75.66340214865548, 73.06527614593506, 25.374251501900808, 0.18259407207369804, 0.1338407067315919, 0.04914269855778132, 0.04016638593748212, 0.0374881573287504, 0.04343246675229498, 0.10668296686240605, 0.014687053327049528, 0.027904036787471602, 0.043432707632226605, 0.058131309625293524, 0.07972591051033565, 0.027547453064471483, 0.0589421046897769, 0.24398935905524663, 0.16605379033301557, 0.09384654315986804, 0.18184192957622664, 0.32182362249919344, 0.09895413408854178, 0.0947694457801325, 0.1614155556474413, 0.14442554089639867, 0.027325368552867855, 0.0899553687444755, 0.04306963372177311, 0.013840973593427666, 0.035611699268754037, 0.01588903909682163, 0.0670085357768195, 0.07582147752067872, 0.07074969288493906, 0.10054162104747125, 0.05871688534638711, 0.23571782718811715, 0.033541010559669564, 0.13191925840718405, 0.059723573470754285, 0.12253634046230998, 0.08244072911994797, 0.09771861681448561, 0.07480182259210519, 0.038352509162255695, 0.02338329383305141, 0.15015006943472795, 0.13806126240108693, 0.08826396414744002, 0.1313653431300606, 0.0014010948736021028, 0.10998402615743023, 0.08744953213525669, 0.04406263918748923, 6.047345970358167, 49.36704478945051, 107.97786181313651, 88.99511228288922, 111.75754288264683, 77.44549001966203, 73.9655681337629, 21.005491733551025, 29.68962131227766, 79.1783082144601, 71.43012877873012, 107.74143545968192, 110.74306419917515, 49.35789748600551, 0.7583602666854858, 0.16811034855033669, 0.018243698103885566, 0.0198862244308527, 0.1525433167283024, 0.4211634833897863, 0.42314230863537106, 1.5328012704849243, 0.47755392321518486, 10.822567973818098, 56.96585532597133, 81.48809092385429, 87.723890713283, 92.53929110935756, 88.00661291394914, 89.95615237099784, 90.33422470092773, 89.0443194253104, 87.9637703214373, 87.8323312486921, 84.60249587467739, 88.62157712663922, 88.84904725211007, 87.28099169049943, 86.068037714277, 83.20390687670026, 82.58824784415108, 77.24393667493547, 78.93824100494385, 79.6034129006522, 83.96686771937779, 90.87414836883545, 90.57398618970598, 88.09206186022077, 85.7435359954834, 80.49206665584019, 82.00076375688825, 81.7862798145839, 80.18251051221574, 77.46568843296596, 76.51899637494768, 77.66366345541817, 81.18128626687187, 84.73112787519182, 93.61678300585065, 80.6612274987357, 74.00175435202462, 87.3772520337786, 93.10918235778809, 95.54546397072929, 91.18827642713273, 96.30784116472516, 92.43850054059709, 92.52843802315849, 85.61245822906494, 82.20914023263114, 78.62999807085309, 77.68196501050676, 72.29760442461286, 67.74647876194545, 63.77990504673549, 60.10354369027274, 55.43321820667812, 63.851026807512554, 70.58451911381313, 75.91814395359584, 77.66392053876604, 77.04382160731724, 81.90091119493756, 81.9778277533395, 82.26208550589425, 83.52533054351807, 77.92998790740967, 78.74880531855992, 82.52786105019706, 80.69459969656808, 80.7256303514753, 77.47052437918526, 72.33857795170375, 66.55348696027482, 65.69862229483468, 29.563421181270055, 3.292698766504015, 1.1034733823367526, 1.396167659333774, 0.49084349295922686, 0.2180797436407634, 0.6720252079623086, 0.20172060360865934, 0.591557685817991, 0.491410205406802, 0.2007014032985483, 0.13201641105115414, 0.07139385331954275, 0.6929438997592244, 0.7623545580676624, 49.62338120596749, 97.78941249847412, 76.3574299131121, 34.149117606026785, 57.35607310703823, 21.03616281918117, 27.577464478356497, 41.52995273045131, 57.206071921757285, 80.61291667393276, 70.49126039232526, 82.55960736955915, 86.12784085954938, 40.824950286320274, 0.1857390683144331, 0.18793758962835583, 0.008228379584449743, 0.03629774906273399, 0.0431946945110602, 0.034215606682534726, 0.05149740506229656, 0.06733521646154778, 0.07652226170258862, 0.007771555883144694, 0.08189594013882534, 0.061452100718660016, 0.034511017080928595, 0.06117692084184714, 0.063413141561406, 0.12169297571693148, 0.10252792374896151, 0.12624114166413034, 0.24398588495595114, 0.07144514378160238, 0.06815889690603529, 0.0569515475737197, 0.11122073765311923, 0.14260317225541386, 0.04818600828626326, 0.023515996622986028, 0.028664966313434497, 0.09198722828711782, 0.14115346861737116, 0.1970057894608804, 0.1262667224343334, 0.13500389217266015, 0.1367637813091278, 0.12949544989636966, 0.21757187375000545, 0.1694185912076916, 0.2943273479385035, 0.1420209077852113, 0.22149976369525703, 0.15106902298118385, 0.21422822959721088, 0.1483089325151273, 0.1701284066906997, 0.432257530944688, 0.41316303983330727, 0.18216310734195368, 0.2562536081033093, 0.35897965729236603, 0.2601524974618639, 0.2524357358259814, 0.19788815639913082, 0.17990761622786522, 5.815954889569964, 53.52709109442574, 127.01073564801897, 94.38276631491524, 109.59258147648403, 73.6038657597133, 62.32616819654192, 36.17232881273542, 103.78176825387138, 118.97939627511161, 81.86247376033238, 122.2301526750837, 117.96651567731584, 64.01273918151855, 2.8951278371470313, 0.33898586300866945, 0.25757183879613876, 0.18821391622935021, 0.35029812742556843, 0.40317891272050993, 0.4315764174929687, 2.9242134307112013, 2.3400217039244513, 10.68645363194602, 54.542250701359336, 87.8147314616612, 94.9882184437343, 104.61748368399483, 97.78576469421387, 101.25146361759731, 97.88114956447056, 98.26772648947579, 97.49577467782157, 96.41615663255963, 91.55111135755266, 95.12416689736503, 96.0380426134382, 95.96898446764264, 93.58452251979283, 89.47053582327706, 90.27264281681606, 83.77452073778424, 85.77626895904541, 86.76223918369838, 88.35232748304094, 99.76013006482805, 94.79010445731026, 89.22898864746094, 91.41529491969517, 85.71445778438023, 87.64101260049003, 84.66022845676967, 84.34075028555733, 79.91847201756069, 81.44319166455949, 84.05271966116769, 87.86507810865129, 93.9981974193028, 97.55948965890067, 92.52292810167584, 88.72186047690255, 92.73497322627476, 96.5018835067749, 96.66771616254533, 94.49897493634904, 93.56756196703229, 89.8860172544207, 89.78656768798828, 87.54274422781808, 85.73100839342389, 82.4224499293736, 86.61658409663609, 80.61662006378174, 77.32862826756069, 72.45817729404995, 69.84132589612688, 68.29750565120152, 78.83062035696847, 81.36644881112235, 83.0467038835798, 85.88265282767159, 85.35412420545305, 89.72287355150495, 88.03325925554547, 88.00186034611293, 88.34955515180314, 84.56847054617745, 85.3678538458688, 87.57462256295341, 84.88876860482353, 85.9558104106358, 81.8597639628819, 78.84064660753522, 73.89273016793388, 82.34886850629533, 37.347071170806885, 3.8212968707084656, 2.2555945771081105, 6.5496664217540195, 4.726775254522051, 3.2493704514844075, 1.950070125716073, 0.31915467285684174, 0.7835106285555022, 0.5421139789479119, 0.3011272730571883, 0.19466584787837096, 0.07265868330640451, 0.9140878532614026, 7.099867343902588, 69.719649042402, 104.15363584245954, 93.05414567674909, 47.88352448599679, 88.53806672777448, 79.34434236798967, 43.44832256862095, 30.47608096258981, 44.26899862289429, 74.82675565992082, 69.72899436950684, 91.52678571428571, 100.17117159707206, 47.76656893321446, 0.5072066634893417, 0.18849508757037775, 0.22470980430287973, 0.19337897907410348, 0.34626741228359087, 0.1670039157782282, 0.24776035813348635, 0.11496987433305808, 0.19748195819556713, 0.18299142218061856, 0.15869768363024506, 0.2332611232995987, 0.21563016436994076, 0.16719159856438637, 0.18207462637552194, 0.24410150732312882, 0.17653019460184233, 0.18279554269143514, 0.3218563278870923, 0.12506161709981306, 0.13293658596064362, 0.17914961118783268, 0.2774789977286543, 0.2926209680736065, 0.14615685013788088, 0.07893781922757626, 0.13137104282421724], [0.14496774465910026, 0.17675850806491716, 0.4037474979247366, 0.07795994848545108, 0.13911600437547478, 0.014530386376593794, 0.030867246711360555, 0.16618503257632256, 0.05073185471285667, 0.05863225845886128, 0.06396861746907234, 0.005640594604691225, 0.15568949361996992, 0.11739270575344563, 0.04134419720087733, 0.08470580793384995, 0.03912782363061394, 0.07929155988884823, 0.14171906826751574, 0.20366164802440576, 0.17950930260121822, 0.27232682704925537, 0.3438327472124781, 1.3543345097984587, 18.30483637537275, 69.78633785247803, 93.95789091927665, 81.63218961443219, 71.73013809749058, 48.037284646715435, 54.202862467084614, 40.773141043526785, 107.44918727874756, 137.92175592694963, 97.33080359867641, 97.2465705871582, 108.59409754616874, 43.98384802682059, 0.4417246957974774, 0.057140282089156766, 0.039313257073185275, 0.0797056019572275, 0.3179069012403488, 0.05281490293730583, 0.14076067826577596, 0.11023768968880177, 0.515500858426094, 1.1832367479801178, 32.0317166192191, 69.57170104980469, 75.8302422932216, 78.00391674041748, 81.40976388113839, 84.82327488490513, 83.7276690346854, 85.13543660300118, 78.08405031476701, 77.82365267617362, 73.08348042624337, 75.37629563467843, 77.92932782854352, 74.75870500292096, 70.9900507245745, 71.09942926679338, 68.20888832637242, 67.00978905814034, 65.7082872390747, 69.01569925035749, 69.8864336013794, 71.31272506713867, 73.5926513671875, 85.25566823141915, 82.70665904453823, 82.21522685459682, 76.3085354396275, 69.64879826136998, 75.1580457687378, 72.91315923418317, 71.32450921194894, 63.68486063820975, 68.62717682974679, 74.38701806749616, 77.15750803266252, 88.34712328229631, 92.60569504329136, 65.55174432482038, 66.61760493687221, 78.37565231323242, 96.74915599822998, 102.96017851148332, 115.74683720724923, 100.8696323122297, 91.19400174277169, 74.76422882080078, 78.15679795401437, 67.50834315163749, 59.198130880083355, 56.29804311479841, 52.55886656897408, 53.500288418361116, 55.35453680583409, 52.92069401059832, 46.65466955729893, 50.70561524799892, 65.14795671190534, 66.88557611192975, 73.2607706614903, 77.1383171081543, 77.20407485961914, 74.96208572387695, 75.42602389199394, 70.09277425493512, 66.77261229923793, 75.96075030735561, 73.76915645599365, 72.95419529506138, 71.58785288674491, 68.79797049931118, 61.78281211853027, 52.83228860582624, 46.50909784861973, 35.645763056618826, 19.314598969050817, 3.234038165637425, 0.32061650870101793, 1.1389837797198976, 1.1810276550906045, 0.6914425460355622, 0.11965043603309564, 0.4569502887981278, 0.7129388611231531, 0.2863460662109511, 0.16425378620624542, 0.07029461980398212, 0.8021163301808494, 0.8101878027830804, 35.29501799174717, 85.89285973140171, 99.81624371664864, 40.79364170346941, 59.78316225324358, 54.85341535295759, 27.39503605025155, 22.98656037875584, 27.609690223421367, 46.45875467572893, 54.64377430507115, 63.332864897591726, 71.10608564104352, 19.641886915479386, 0.7996334891234125, 0.10352460348180362, 0.02110177750832268, 0.08227642865053245, 0.05743457629744496, 0.0691095312525119, 0.05457279039546847, 0.07553524430841208, 0.06485135081623282, 0.042591985780745745, 0.022813740020085658, 0.10229963064193726, 0.1452212589127677, 0.43492075375148226, 0.34662060333149775, 0.4163592111851488, 0.2185941274677004, 0.19648441672325134, 0.058086879152272425, 0.056441268883645535, 0.12426372777138438, 0.061400348852787695, 0.12324038839765958, 0.05122644906597478, 0.08641203852104289, 0.015144199332488435, 0.02733936333762748, 0.021969316760078073, 0.17924548818596772, 0.034683093561657836, 0.10957877111754247, 0.03930559980549982, 0.07788294154618468, 0.06921906716057233, 0.0583302764488118, 0.024814992544374297, 0.03545609761827758, 0.04073627053626946, 0.09859976917505264, 0.039339801363114796, 0.09519002214074135, 0.09077730535396508, 0.02934168285823294, 0.025982432400009463, 0.13746564436171735, 0.1288734097033739, 0.1356619761458465, 0.23181625083088875, 0.3671264201402664, 4.899427567209516, 33.49742521558489, 89.30543272835868, 107.12570694514683, 92.57487283434186, 103.72130502973283, 63.823081152779714, 52.93457998548235, 25.76278955595834, 50.192838191986084, 132.65586907523019, 104.45143563406808, 102.37671743120465, 117.75352559770856, 43.83981534412929, 0.501633882522583, 0.013319275158989643, 0.13178276430283273, 0.11708171958369867, 0.10855424430753503, 0.34813634199755533, 0.5895916713135583, 0.5066959166101047, 0.24531426653265953, 1.8038740562541145, 36.828179700034006, 75.52878774915422, 86.01733670915876, 82.66237817491803, 84.25815010070801, 90.43951075417655, 86.7071886062622, 88.69451236724854, 80.97962869916643, 82.14857278551374, 77.20731272016252, 78.53310544150216, 78.70002201625279, 77.51127556392125, 74.01287841796875, 73.62502302442277, 69.76005281720842, 70.56357724325997, 68.29592146192277, 72.46313830784389, 71.09963771275112, 76.35740212031773, 78.16282899039132, 89.17740522112165, 85.95956243787492, 85.86797128404889, 80.72979927062988, 76.75167070116315, 82.25442859104702, 80.27375425611223, 77.65378311702183, 68.81561197553361, 72.35743536267961, 79.40702901567731, 81.92727266039167, 90.67145551953996, 98.24133028302873, 72.69265815189907, 71.84911210196358, 77.77570315769741, 95.26727199554443, 110.9234116418021, 119.47056443350655, 105.91839490618024, 93.94486999511719, 79.99456174033028, 79.97260543278286, 70.08958503178188, 67.8246043069022, 68.40083926064628, 63.073078700474326, 64.9530736378261, 63.044000489371165, 64.44575091770717, 59.118879726954866, 60.38730117252895, 71.37279224395752, 74.86434541429792, 80.31886890956334, 81.0533560344151, 81.34830706460136, 79.56293964385986, 80.04644393920898, 76.32433564322335, 74.8499070576259, 81.21527685437883, 78.17928927285331, 78.1245722089495, 77.75662340436662, 76.12140655517578, 71.90446840013776, 61.25549248286656, 61.5818841116769, 55.176051480429514, 31.81839997427804, 7.792768631662641, 1.0020678980009896, 0.6038873185004506, 0.8638803330915314, 0.7197058094399316, 0.5627566969820431, 0.8033662459680012, 0.7280829484973634, 0.30918973471437183, 0.22414928009467466, 0.061699691361614635, 0.7019791092191423, 0.5613768824509212, 33.74349914278303, 89.24433026994977, 98.15727792467389, 38.40012277875628, 44.42856747763497, 19.206811564309255, 18.633458375930786, 30.71541166305542, 45.84020866666521, 73.11908994402204, 69.23706190926688, 72.05750247410366, 82.44698401859829, 32.034714766911094, 0.3358711430004665, 0.03598587401211262, 0.03437595807814172, 0.015325651470837849, 0.07058785549764122, 0.02405472289371703, 0.044337327126413584, 0.022478229898427213, 0.09229592779385191, 0.09484517028821365, 0.09373536519706249, 0.09772080169724566, 0.009799580854762877, 0.23600319187555993, 0.2016088624617883, 0.22764221552227223, 0.1435687140162502, 0.18509523357663835, 0.08053564027483974, 0.061246742095266066, 0.0554286401851901, 0.02829216729982623, 0.14995425779904636, 0.0825164264866284, 0.05373912870085665, 0.013610607561921435, 0.14206544682383537, 0.27059854407395634, 0.49027032085827416, 0.11537266629082815, 0.2102980597742966, 0.10678188369742461, 0.21176046558788844, 0.18284925552351133, 0.20752186088689736, 0.1436027493327856, 0.2678685805627278, 0.0948054895603231, 0.18159387074410915, 0.16826087475887366, 0.25235843711665695, 0.2582416885665485, 0.10268015986574547, 0.13162128653909477, 0.33061073241489275, 0.24082871579698154, 0.3840008260948317, 0.2970271573535034, 0.5307960691196578, 7.774116192545209, 41.18910537447248, 104.2663425718035, 122.71822193690709, 97.14584950038365, 96.30593041011265, 61.752483231680735, 65.21958569117955, 53.479106834956575, 132.40881892613, 163.84747205461775, 107.56061553955078, 117.60495921543666, 123.56884820120675, 54.88382414409092, 1.1132895584617342, 0.15298551799995558, 0.30540470353194643, 0.2247920156057392, 0.36608799014772686, 0.6119141706398555, 0.38329992656196865, 1.211730876139232, 1.625765996319907, 1.9422466712338584, 35.50493696757725, 81.29966967446464, 91.8780379976545, 89.91181591578892, 89.991532598223, 97.77184745243618, 93.7942955834525, 95.115113394601, 85.76451955522809, 90.33523218972343, 83.22704437800816, 84.63474246433803, 85.83450875963483, 84.72339453016008, 79.63997432163784, 81.20030348641532, 77.03733198983329, 78.09790502275739, 75.35101808820451, 78.06543609074184, 75.46092469351632, 81.5554050718035, 79.9023938860212, 92.55898230416435, 89.07889366149902, 91.48453371865409, 86.89344201769147, 79.34279986790249, 85.30877331324986, 81.82954624720982, 80.1026131766183, 74.39428588322231, 80.29395266941616, 86.74891253880092, 89.41880648476737, 98.10481902531215, 103.53767108917236, 84.11202948434013, 85.2940570286342, 88.42617988586426, 97.71497644696916, 103.1076192855835, 102.92403398241315, 92.28977434975761, 90.81399086543492, 80.34784289768764, 83.74032170431954, 77.05587673187256, 73.59176199776786, 70.45037719181606, 69.35614708491734, 73.64438765389579, 72.26171003069196, 72.44649042401994, 68.37266431535993, 72.88906982966832, 82.41751670837402, 81.72102233341762, 86.54810959952218, 87.97088527679443, 87.00154903956822, 86.10811492374965, 83.1414703641619, 83.22558525630406, 80.02680138179234, 86.18768569401333, 84.70933832441057, 84.47737966264997, 84.08411162240165, 81.5457957131522, 76.20598002842495, 67.61410168239048, 72.95227759225028, 67.82911368778774, 37.74705464499337, 8.178199972425189, 1.4681574021066939, 4.712004687104907, 3.700215825012752, 2.874537067753928, 0.9955765434673854, 0.9486486273152488, 0.986902260354587, 0.5334370359778404, 0.44891589134931564, 0.1751159512038742, 1.065811106136867, 2.2283999792167117, 51.224013396671836, 97.94704627990723, 118.14746066502163, 52.12743207386562, 90.56685733795166, 69.52269540514264, 34.36943456104824, 27.376489571162633, 33.76186670575823, 62.307213510785786, 70.87340436662946, 76.89303180149624, 90.94828564780099, 42.236146790640696, 0.7231016872184617, 0.15426250733435154, 0.09735471169863429, 0.2876869871148041, 0.25389963441661423, 0.14238134558711732, 0.15103937100086892, 0.21344589229140962, 0.12829428006495747, 0.25544020746435436, 0.14556695893406868, 0.21423147299460002, 0.20397606758134706, 0.40413301438093185, 0.4341879630727427, 0.3823392295411655, 0.22353243747992174, 0.3878008393304688, 0.1597851174218314, 0.09350301445062671, 0.2089001147874764, 0.1181138799126659, 0.3841447840843882, 0.11725530241216932, 0.20948389917612076, 0.10624036525509187], [0.37868176294224604, 0.041425173570002825, 0.3122474306396076, 0.027904537207047855, 0.04226851795933076, 0.023305732191407254, 0.08299254093851362, 0.07034781016409397, 0.07297469742063965, 0.06221035681664944, 0.07382760236838035, 0.15002570753651007, 0.09787572481270347, 0.16033819131553173, 0.05194401002622076, 0.03275994550702827, 0.05723254928099258, 0.11566611911569323, 0.032035968998180966, 0.2631391371999468, 0.173873811428036, 4.288607520716531, 36.39883313860212, 71.13106441497803, 89.64706870487758, 88.42880630493164, 78.48714310782296, 66.37844099317277, 36.074814319610596, 41.473304067339214, 73.15582506997245, 112.02577808925084, 93.98317541394914, 89.69320474352155, 111.13503292628697, 106.80725015912736, 40.47064426967076, 0.38287605930651936, 0.05552922960902963, 0.06456084283334868, 0.07620224423174347, 0.13103830282177242, 0.05865807671632085, 0.19971986168197223, 0.7691084785120827, 1.2148037169660841, 0.4170762598514557, 5.189483591488429, 57.166137150355745, 83.75982529776437, 86.54077925000871, 81.68516268048967, 77.80497591836112, 78.46304675510952, 75.60639912741524, 71.27369703565324, 70.30905083247593, 63.35175010136196, 64.13556248801095, 62.873456954956055, 66.25458935328892, 61.731569153921946, 59.81132330213274, 59.941608973911826, 63.44495323726109, 70.5006890978132, 72.19391645703996, 72.78060150146484, 73.85477910723004, 66.93308094569615, 71.44968100956508, 80.86726243155343, 84.65307876041958, 83.91019821166992, 74.65441949026925, 68.4068077632359, 68.15151705060686, 69.34425871712821, 66.5205386025565, 54.45783356257847, 65.2477467400687, 65.3602728162493, 65.46895653860909, 67.85030569349016, 92.48198236737932, 84.64417811802456, 63.03981072562081, 54.817840576171875, 91.703033719744, 115.17200578962053, 103.14372212546212, 84.59258774348667, 69.49293627057756, 67.952194077628, 78.61970778873989, 79.98821108681815, 77.58644117627824, 83.83633191244942, 68.97354452950614, 56.79972389766148, 57.85077095031738, 59.22719519478934, 62.605687277657644, 59.44741140093122, 55.83318778446743, 61.01951081412179, 68.76846844809396, 71.04825578417096, 70.97005380902971, 69.19758224487305, 69.05009978158134, 66.0561557497297, 67.58537782941545, 71.26449067252022, 66.05475221361432, 68.31978157588414, 69.20643424987793, 63.15037046160017, 60.427086557660786, 56.892204420907156, 53.32882424763271, 50.25349249158587, 53.533653667994905, 51.71492447171892, 28.726557561329432, 2.383130716426032, 0.9909992005143846, 0.12462668972355978, 0.3054736969726426, 0.22008291472281727, 0.3146199147616114, 0.17364601365157536, 0.06933959533593484, 0.19516082560377462, 0.03854048032579677, 0.7888973823615483, 0.17022441939583846, 22.402043172291346, 74.43261214665004, 103.64581285204206, 49.18975108010428, 71.25507586342948, 72.27150004250663, 41.13582311357771, 24.245217868259974, 23.294099807739258, 38.720104694366455, 60.106322969709126, 64.70580114637102, 64.01769324711391, 24.979868275778635, 1.003180803997176, 0.07722841988184623, 0.07529277660484825, 0.04003161870475326, 0.0329487444832921, 0.048160804102995565, 0.250663375215871, 0.1238841281405517, 0.04149900157270687, 0.020453722282711948, 0.16500496518399033, 0.34984975148524555, 0.3788226268121174, 0.3120352663099766, 0.21741012457226003, 0.12255695435617651, 0.10286241437175445, 0.0344982131251267, 0.2952840008905956, 0.2160136452210801, 0.1329697798937559, 0.08179357634591204, 0.15477212784545763, 0.17816587111779622, 0.2164045356746231, 0.25804404488631655, 0.07685163617134094, 0.2469288541802338, 0.10568822095436708, 0.03774578011195574, 0.07325901037880353, 0.05348617423857961, 0.062067443771021705, 0.033814680696065934, 0.046607023371117454, 0.11672516300209931, 0.11833856999874115, 0.010356692031824162, 0.0955616014876536, 0.03530966636857816, 0.013063688829009022, 0.055903838614800146, 0.0806946074590087, 0.03579229136396732, 0.1346586671258722, 0.10865445035908904, 7.5683018650327405, 52.19620534351894, 91.78210421970913, 107.30722863333565, 109.96330956050328, 101.20199244362968, 98.67841366359166, 65.22132274082729, 47.37113652910505, 55.96628400257656, 81.15994834899902, 99.98618275778634, 100.28620597294399, 113.24395711081368, 117.18124416896275, 36.72570071901594, 0.3591611518391541, 0.01511595700867474, 0.10879209797297205, 0.14122109141732964, 0.20163038559257984, 0.22037602828017303, 0.4013325103691646, 0.5003367406981332, 3.1294781991413663, 1.6725546228034156, 5.303047554833548, 62.18102032797677, 91.33763490404401, 90.9913922718593, 85.77514335087368, 83.3165510722569, 79.63375568389893, 77.67162609100342, 73.64465168544224, 74.00618035452706, 67.26148060389927, 70.11957345690045, 65.23819991520473, 69.7114223752703, 65.01155662536621, 67.28352723802838, 64.03190231323242, 67.63042994907924, 75.30611188071114, 77.70228849138532, 77.0327878679548, 78.95163713182721, 69.56535734449113, 76.23261942182268, 84.29990877423967, 85.59080069405692, 89.01342078617641, 78.72754383087158, 75.60775402614048, 74.63665989467076, 76.60748863220215, 68.44715595245361, 60.76383100237165, 70.841324533735, 71.31033488682338, 73.53221593584333, 76.97089331490653, 94.87364264896938, 93.24777807508195, 68.23438126700265, 62.30511515481131, 92.09031241280692, 116.12606988634381, 105.91257926395961, 86.9630629675729, 71.56540325709751, 70.5188933781215, 81.92704336983817, 86.58775602068219, 86.28912244524274, 93.52795028686523, 82.85450976235526, 68.64577020917619, 69.94254030500139, 70.62483256203788, 70.07372924259731, 69.2720113481794, 68.08621788024902, 68.02994441986084, 73.19826466696603, 76.46029104505266, 76.37286186218262, 74.85064356667655, 73.42518588474819, 70.85218456813267, 72.7291361945016, 74.20081329345703, 71.33551515851701, 72.13095188140869, 75.5952125276838, 70.42073617662702, 67.5564524786813, 66.47748061588833, 62.69583320617676, 59.526836259024485, 66.77307088034493, 67.55496556418282, 45.147428103855674, 5.879084050655365, 1.3653849682637622, 0.2582661158272198, 0.09884188404040677, 0.8748202174901962, 0.5284919270447322, 0.3138435621346746, 0.12851605245045253, 0.17318368703126907, 0.040475858974137476, 0.5493591044630323, 0.16209805331059865, 21.451849222183228, 78.99066516331264, 103.53811577388218, 56.101829460689, 55.42694745744978, 24.813559668404714, 18.31069196973528, 31.411197321755544, 34.43289245877947, 55.26370995385306, 79.35979516165597, 76.9896742956979, 77.5220730645316, 41.80104712077549, 0.8604251784937722, 0.010334761780021446, 0.0344926423526236, 0.03547822464523571, 0.009089336198355471, 0.07106387495462384, 0.018948144678558623, 0.08733933804822819, 0.09104116726666689, 0.06464044856173651, 0.08686992073697702, 0.18930201498525484, 0.22953973870192254, 0.23681542543428286, 0.2529063948563167, 0.0461709865901087, 0.03030967413048659, 0.0391768918904875, 0.17060946087752069, 0.11227465181478433, 0.053933532376374514, 0.06308398422385965, 0.2304609449846404, 0.0670853459409305, 0.11123373159872633, 0.3342522127287728, 0.24427374665226254, 0.385886013507843, 0.2345125318637916, 0.07883072604558297, 0.1212267814470189, 0.18575462033706053, 0.2214412604059492, 0.21407427000147955, 0.12512904990996632, 0.19358142678226742, 0.17844624178750174, 0.19937124396009104, 0.2780708431133202, 0.21862513651805265, 0.07603890728205442, 0.16706484822290285, 0.20160902531019279, 0.11434829554387502, 0.4769178916301046, 0.18420818474675926, 11.746713995933533, 69.7516941343035, 110.39422294071743, 122.86407852172852, 109.96856934683663, 96.21517998831612, 88.23370783669608, 41.84499447686331, 52.56276798248291, 87.57836764199394, 128.08724784851074, 116.79402106148856, 101.55103519984654, 122.71943092346191, 124.18387494768415, 51.0155222756522, 0.6310822420886585, 0.10370980282979352, 0.2633603938988277, 0.23620031986917767, 0.3117036798170635, 0.15531263527061256, 0.4467431407954012, 1.727560579776764, 5.9778978569167, 2.2487039182867323, 7.626856940133231, 67.91787692478725, 96.59255055018834, 99.81584766932896, 92.78180408477783, 87.11345672607422, 88.16046687534877, 85.51793493543352, 78.49054772513253, 77.15980093819755, 71.80608885628837, 71.4483608518328, 70.39994716644287, 74.47933183397565, 70.09585230691093, 71.24363218035016, 66.93521404266357, 71.7488009589059, 81.49364253452846, 82.09283433641706, 80.97385474613735, 82.22530174255371, 73.35804544176374, 81.61507620130266, 90.44618797302246, 91.49560914720807, 91.96361895969936, 84.98334748404366, 78.14112976619175, 79.17919063568115, 81.45654610225132, 74.7559813090733, 68.38786002567836, 78.42415073939732, 73.90559823172433, 76.26888901846749, 82.3099308013916, 109.8885747364589, 103.59563991001674, 77.66496276855469, 72.24997452327183, 94.65478134155273, 97.18350873674665, 88.41328402927944, 81.30647196088518, 76.5085254396711, 74.12661348070417, 86.24038083212716, 88.46376964024135, 89.26934378487724, 90.83510644095284, 83.22448744092668, 73.8622692653111, 78.04772513253349, 79.12832982199532, 76.28832312992641, 77.67720549447196, 72.79387950897217, 77.4195454461234, 84.00253977094377, 85.61362552642822, 81.15380614144462, 77.75454589298793, 76.55716282980782, 76.35464368547711, 76.66754191262382, 79.95652730124337, 76.98307350703648, 78.76004750388009, 79.19144030979702, 75.56520325796944, 72.63830934252057, 73.43553870064872, 67.00927489144462, 63.33343464987618, 73.11864525931222, 77.3666627066476, 53.86055946350098, 6.33285483292171, 2.0011480706078664, 2.604406305721828, 2.738186921392168, 2.5848147741385867, 1.5620379873684473, 0.4469705857336521, 0.19921303673514298, 0.2609654366970062, 0.3612345920077392, 0.8876551144889423, 0.9213575146027974, 35.011805943080354, 86.49733911241803, 120.61148643493652, 58.840958731515066, 101.82496098109654, 94.63902977534703, 55.779787404196604, 36.14891338348389, 27.570412056786672, 50.352209023066926, 79.99704919542584, 83.75952652522496, 87.07397706168038, 57.53668458121163, 1.8469052272183555, 0.09657633025199175, 0.1626013634460313, 0.19916404650679656, 0.11313011483954531, 0.2688971039439951, 0.308710797556809, 0.2755221841590745, 0.21872333410595143, 0.23242894081132753, 0.2221241109073162, 0.30616688834769384, 0.39335657549755915, 0.27597273141145706, 0.3523534914212567, 0.2410958143217223, 0.2404045228447233, 0.09465574366705758, 0.44680038200957434, 0.18085447113428796, 0.1570192186960152, 0.15301227942109108, 0.22283756333802426, 0.23337579571775027, 0.3066501409879753], [0.14245860358434065, 0.2531584027622427, 0.07685377355664968, 0.06375964903937918, 0.039728340692818165, 0.07841420053903546, 0.06958783058715717, 0.0710558614560536, 0.15262887999415398, 0.01397003180214337, 0.18262680460299763, 0.10475123194711548, 0.08431634240384613, 0.013315042796810823, 0.018300377830330814, 0.06315964087843895, 0.04801261544759784, 0.03391292238874095, 0.015345010074919887, 0.049919543122606616, 23.672285045896256, 82.43303898402623, 94.40198503221784, 83.78787517547607, 83.7367503302438, 60.314706393650596, 53.51460518155779, 38.50913654054914, 31.082693440573557, 63.70499651772635, 119.32964106968471, 92.15085206712995, 76.662323815482, 100.3592871257237, 102.14839962550572, 36.295023577553884, 0.41748088385377613, 0.04404035949015191, 0.25590687670878, 0.13997786598546164, 0.26039877853223253, 0.24333218431898526, 0.1626279620187623, 1.8560709868158614, 3.0371121040412357, 3.748630004269736, 1.2632906351770674, 8.001760022980825, 60.64947754996163, 89.52964414869035, 89.33773490360805, 83.7313654763358, 81.71745790754045, 71.89929894038609, 68.32147693634033, 69.16922664642334, 66.04360730307442, 63.50388090951102, 61.926257678440635, 67.60228974478585, 66.99172374180385, 68.26457118988037, 72.1303265435355, 73.33697155543736, 73.45781462533134, 81.72693525041852, 78.97590718950543, 76.59462751661027, 83.80024296896798, 70.30875900813511, 75.39638982500348, 79.89784976414272, 80.20232677459717, 81.19478661673409, 71.23623929704938, 68.67391736166817, 67.79093333653041, 70.17490196228027, 70.87605857849121, 67.18056883130754, 60.619350160871235, 58.98213223048619, 54.79550559180123, 58.88588578360421, 64.72870935712541, 92.65058735438755, 79.15126582554409, 58.50533989497593, 78.6306928907122, 79.02200153895787, 67.30315589904785, 59.64745698656355, 56.259484086717876, 63.333643095833914, 74.56787272862026, 76.38229056767055, 74.38329383305141, 70.25214508601597, 71.51405606951032, 60.12180355616978, 66.38737637656075, 60.987771442958284, 61.3337014062064, 63.699160030909944, 63.33621392931257, 56.82629728317261, 57.24939741407122, 60.26608984810965, 68.38934694017682, 68.9557432447161, 74.46527562822614, 69.2099222455706, 68.61398220062256, 74.10662351335797, 73.17362635476249, 72.9592535836356, 69.56987367357526, 67.73171383993966, 65.80934878758022, 64.11120905194963, 61.44813823699951, 60.19500282832554, 57.35403381075178, 51.13963099888393, 55.30664982114519, 47.02936506271362, 12.968974215643746, 1.4510591881615775, 0.9699438789061138, 0.8928568182247025, 0.1771109120122024, 0.1512788124382496, 0.051541655723537715, 0.10600036741899592, 0.35679957856025013, 0.09346600715070963, 0.744247986802033, 0.15054029492395266, 18.788682869502477, 60.51819828578404, 94.7252082824707, 67.15811225346157, 73.0349542072841, 69.95615182604108, 39.5006479535784, 34.02884776251656, 26.673347507204326, 41.391985825129915, 55.861268929072786, 61.1129640851702, 71.1366855076381, 36.660533564431326, 0.5991779054914201, 0.20239802582987718, 0.08316865470260382, 0.11185703386685678, 0.18780104124120303, 0.3187398708292416, 0.06164820412439959, 0.14430169468479498, 0.02767085992465062, 0.08307582432670252, 0.07789702114782163, 0.04893760456304465, 0.10454717611095735, 0.02673504308664373, 0.06593039791498866, 0.037205062340945005, 0.2294441738298961, 0.12248174553470952, 0.08081903721072844, 0.03236484813636967, 0.1728650876986129, 0.14283557049930096, 0.1169536393135786, 0.4496206178196839, 0.2297232145709651, 0.10638298653066158, 0.05841447585927589, 0.01184900597270046, 0.020153528212436607, 0.06780581442373139, 0.052972112715776475, 0.04981305383677993, 0.20824608845370157, 0.03437885202999626, 0.12585637159645557, 0.06689928485346691, 0.15740240099174635, 0.033901746916983805, 0.027528881561011076, 0.07104373603527035, 0.046815618606550355, 0.04400013254157134, 0.015857700956985354, 0.10058326952691589, 29.874752589634486, 104.76640442439488, 107.38739000047956, 98.78022561754499, 102.80795737675258, 82.83645139421735, 85.90733977726528, 67.01821027483258, 36.00036784580776, 50.875175612313406, 122.12787519182477, 97.0528061730521, 86.80288614545549, 103.65121160234723, 111.05597632271903, 35.61641386577061, 0.4678987498794283, 0.08315267520291464, 0.31854095150317463, 0.21132867304342134, 0.3624374717473984, 0.6585567221045494, 0.3716488560395581, 3.7499284488814215, 6.657190229211535, 6.146734305790492, 1.3786445196185793, 14.166137542043414, 67.65779890332902, 93.46133095877511, 90.47395992279053, 90.69128567831856, 83.63970484052385, 75.69577380589077, 69.53830800737653, 72.08307184491838, 67.87220641544887, 67.5005681174142, 65.31426184517997, 71.74382604871477, 71.81760896955217, 75.06302220480782, 75.50312110355922, 79.60490676334926, 79.87658827645438, 88.60704844338554, 85.26173400878906, 81.2841682434082, 86.02289526803153, 74.62352779933384, 78.93046597072056, 84.43275833129883, 83.35522474561418, 84.88954680306571, 75.90123203822544, 76.1051755632673, 73.33875029427665, 77.25040544782365, 77.58421080453056, 75.21846730368478, 67.73463903154645, 64.833863394601, 66.45348153795514, 67.66993740626744, 75.22571427481515, 95.89186641148159, 88.98366859980992, 61.66009303501674, 78.53310544150216, 80.78293909345354, 68.98045103890556, 63.63476412636893, 57.2857642854963, 68.50112261090959, 76.6630950655256, 80.16380596160889, 76.03732640402657, 75.15698964255196, 77.99404335021973, 67.07687391553605, 73.13543210710797, 71.48306710379464, 68.70516341073173, 72.16697829110282, 72.501798084804, 66.37630789620536, 64.77185767037528, 67.90749631609235, 70.68145343235561, 73.14937019348145, 76.72817884172711, 76.4095344543457, 74.93383434840611, 77.77691214425224, 77.76606600625175, 76.09346784864152, 75.15705912453788, 73.46203218187604, 72.83791024344308, 70.78679507119315, 68.04238169533866, 70.95224557604108, 66.99256447383335, 60.41548306601388, 66.4972482408796, 64.6674609865461, 24.80207255908421, 1.9569012905870165, 0.5465120800903865, 0.7178724078195435, 0.33839271483676775, 0.37455925558294567, 0.20292086420314653, 0.061605700690831454, 0.4227774739265442, 0.2316548137792519, 0.37915467470884323, 0.3812542791877474, 19.031913246427262, 65.38134670257568, 97.65990502493722, 75.00403199877057, 65.53276879446847, 44.948212827954976, 17.677332401275635, 33.148917470659526, 47.16520234516689, 55.55707679476057, 76.08032880510602, 69.74459307534354, 83.5777894428798, 51.16643367494856, 0.286635909229517, 0.2548322672290461, 0.10035149553524596, 0.08423440251499414, 0.16734690165945462, 0.3005835222346442, 0.10213914353932653, 0.13824152201414108, 0.05576845391520432, 0.02971296025706189, 0.13154413710747445, 0.10448988739933286, 0.1222619137593678, 0.03924476235572781, 0.031423631855951886, 0.015648126934788058, 0.2569834946521691, 0.09972470559711967, 0.10340203291603497, 0.015418318998334664, 0.08893610058086258, 0.0521660368623478, 0.1969665972782033, 0.28113472727792604, 0.38393707094447954, 0.24914182829005377, 0.1488317166055952, 0.11244729147957903, 0.2467417956462928, 0.24187865374343737, 0.19686667621135712, 0.13278315562222684, 0.40109979999916895, 0.11450499642108168, 0.25643664970993996, 0.27645242852824076, 0.26203038383807453, 0.10467634882245745, 0.23696185329130717, 0.15472781950873987, 0.13585192523896694, 0.12530439692948545, 0.10471854691526719, 0.20566285135490553, 38.438831193106516, 121.45150974818638, 123.04705238342285, 104.62140941619873, 102.96727262224469, 80.04699284689767, 69.63588156018938, 44.663315841129844, 41.732610838753835, 73.79479530879429, 128.24672290257044, 106.38824599129813, 98.4433491570609, 117.57986232212612, 120.69518443516323, 51.489500590733115, 0.661959276667663, 0.16459036671689578, 0.49967047359262196, 0.1906588271792446, 0.9973710243191037, 1.1044116062777383, 0.21716948891324656, 3.7697464483124867, 15.168796471187047, 9.910732422556196, 2.148922575371606, 14.45344729082925, 76.52334594726562, 100.93876688820976, 96.45221778324672, 93.73076820373535, 89.16662856510708, 81.91939340318952, 73.27862753186906, 76.95245974404472, 72.14673818860734, 71.72846358163017, 67.97828456333706, 78.18427807944161, 74.33861691611153, 76.6743997846331, 78.28698635101318, 83.21202932085309, 83.25274576459611, 93.46192155565534, 88.39581625802177, 87.70530428205217, 91.47187410082135, 79.39025606427873, 83.27761336735317, 92.5832940510341, 91.23778929029191, 89.77751418522426, 81.0137026650565, 79.0906844820295, 76.43410328456334, 82.51387432643345, 82.96555587223598, 77.8312679018293, 76.27300235203334, 72.94146619524274, 69.9894962310791, 68.89804540361676, 82.48566464015416, 106.3113294328962, 98.72958714621407, 74.73574120657784, 82.10858590262276, 78.37755611964634, 72.2073334285191, 70.10169574192592, 65.73367595672607, 73.12587833404541, 84.06891591208321, 85.4078059877668, 81.73601654597691, 84.04495157514299, 83.13689150129045, 74.29976953778947, 81.34272071293422, 77.97829873221261, 77.67508629390171, 79.17890575953892, 75.76682608468192, 68.76500824519566, 69.47977638244629, 72.81869152614048, 80.17421436309814, 78.82608318328857, 79.98649488176618, 81.32466929299491, 79.21847575051444, 82.58649689810616, 82.75628307887486, 81.06468159811837, 77.7843119757516, 76.79118510654995, 76.09924180167062, 76.2166246686663, 73.82786178588867, 76.38160964420864, 70.02412605285645, 60.862002100263325, 73.02323954445976, 77.08127239772251, 30.94987515040806, 1.7012835783617837, 3.5206435407911028, 2.9469101556709836, 1.22413612476417, 0.44566022604703903, 0.18426618592015334, 0.16036956677479403, 0.36295513968382564, 0.31248774060181206, 0.8331752121448517, 0.6552034563251904, 33.95051377160208, 75.03618826184953, 115.35616779327393, 79.6512234551566, 97.86250059945243, 101.11322225843156, 51.974446637289866, 47.00666529791695, 38.14668376105172, 52.25232246943882, 74.52614184788295, 75.51560006822858, 95.53334631238664, 67.96104608263288, 1.327759061540876, 0.3324597403407097, 0.22165293619036674, 0.16619377210736275, 0.31326911438788685, 0.4142562954553536, 0.18308898194559983, 0.2042254020592996, 0.16727333489273274, 0.1143126046018941, 0.1517635171434709, 0.21099274392638886, 0.21065974608063698, 0.11016089988074132, 0.17457866003470762, 0.07893798886133091, 0.2846374607511929, 0.18317386667643273, 0.15770633039729937, 0.12364092761916773, 0.1700002449963774, 0.18719097040593624, 0.2975725366600922, 0.426521223038435], [0.14672007491546019, 0.2132873186575515, 0.0427579791950328, 0.05595140731228249, 0.061924761427300315, 0.1061272873942341, 0.15767973182456835, 0.008565383331317986, 0.17659119490001882, 0.0321340003450002, 0.08251544939620153, 0.07087771208690745, 0.060213448612817695, 0.03091278319646205, 0.0321762696839869, 0.050295977387577295, 0.07245766730712992, 0.0629373663770301, 0.18171231581696443, 26.127229520252772, 93.2947062083653, 79.41935511997768, 83.93890122004917, 61.758931159973145, 48.04373952320644, 62.75680364881243, 38.87628630229405, 33.163845675332205, 116.86543464660645, 143.76241166251046, 90.98643125806535, 75.42737184252057, 96.95198781149728, 106.19436345781598, 41.59968485151018, 0.37659214649881634, 0.16241385707897799, 0.13766516079860075, 0.05283005123159715, 0.12042597441801003, 0.42043237547789303, 0.0945453867316246, 0.4219665160136563, 1.669545292854309, 1.099284595676831, 0.34068252625209944, 12.528971723147801, 80.24348790305001, 96.24309090205601, 96.57317897251674, 91.7195565359933, 87.30280208587646, 81.98720087323869, 73.35820525033134, 68.1415741784232, 66.56003216334751, 66.68925476074219, 67.33805670057023, 68.9284576688494, 77.82445866721017, 77.38737528664726, 81.99329444340297, 80.39056737082345, 85.24719837733677, 85.8283804484776, 86.57492269788469, 81.96326432909284, 79.63137245178223, 78.79990931919643, 71.9147378376552, 72.76378686087472, 81.00942257472447, 87.90801102774483, 78.90855135236467, 70.24194513048444, 70.80513831547329, 69.98439625331334, 71.71238545009068, 72.5123176574707, 70.82562855311802, 65.99291324615479, 59.60883889879499, 62.73356887272426, 62.64329092843192, 68.70282186780656, 70.70953110286167, 86.75556891305106, 67.04657282148088, 49.93803037915911, 58.72167205810547, 40.35635335104806, 46.47373846599034, 41.11455815179007, 57.375670501164024, 62.38322680337088, 65.06634317125592, 59.26914841788155, 50.490544182913645, 53.239439146859304, 51.937134810856406, 57.72289630344936, 66.93417181287492, 67.4635898045131, 64.85680634634835, 65.61227008274624, 68.14407552991594, 70.15853895459855, 67.70007174355644, 58.84644086020333, 62.63363988058907, 65.9171222959246, 67.86374350956508, 69.06874874659947, 75.3504205431257, 72.10832159859794, 74.73679733276367, 75.77705383300781, 72.4133266721453, 68.7867213657924, 70.6557103565761, 67.8814058303833, 65.6154454095023, 62.519633838108604, 61.044385365077424, 59.21170766013009, 51.29300900868007, 49.091482707432334, 26.329521111079625, 4.03691771200725, 0.6442148802535874, 0.5132758606757436, 0.17792520831738198, 0.4779841686998095, 0.13760957520987305, 0.09836327936500311, 0.5775688450251306, 0.07647872689579215, 0.33347105607390404, 0.48742492496967316, 17.255906786237443, 51.413191999707905, 81.05314064025879, 72.02069091796875, 50.67333044324602, 71.4760355268206, 42.38470622471401, 19.056709630148752, 25.367245980671473, 43.430788789476665, 61.35924298422677, 57.25829458236694, 71.82145827157157, 32.67148242677961, 2.0598959582192555, 0.05915801453271082, 0.09921291377395391, 0.13704825033034596, 0.16333863245589392, 0.14987714907952718, 0.025502947325419103, 0.035621744979705126, 0.01631742878817022, 0.039734556073588986, 0.14878075862569468, 0.06484905736786978, 0.030496722486402308, 0.0682923783149038, 0.044169131865991015, 0.19034501830382006, 0.048430881396468194, 0.017654434544965625, 0.05358927084931305, 0.06897183614117758, 0.06237156995173011, 0.03808440640568733, 0.2414013450699193, 0.09391173001910959, 0.038999454983110936, 0.04985141142138413, 0.0726231484274779, 0.059743827741060934, 0.05031531563560877, 0.044166227736111195, 0.024089815028543984, 0.14458575658500195, 0.10137547951723848, 0.044338019232132604, 0.15700855212552206, 0.08861222903111152, 0.06847042590379715, 0.033937895870102305, 0.04896229984504836, 0.0596260204911232, 0.12100050358900002, 0.16670925516102994, 33.45413099016462, 108.96622221810478, 86.98099626813615, 107.63429423740932, 92.25144113813127, 76.87346567426408, 93.16508061545235, 57.1619473866054, 39.23557765143258, 67.6154704775129, 127.33193697248186, 101.81207207271031, 81.0289956501552, 105.19530977521623, 112.75012084415981, 43.60295125416347, 0.2538885064423084, 0.0766385897461857, 0.12048822322062083, 0.08442637364247016, 0.14376033230551652, 0.46083400611366543, 0.3641677089035511, 0.5893925077148846, 1.6993718466588428, 0.6383677540080888, 0.217786969350917, 23.40223114831107, 92.50386919294084, 101.45186356135777, 98.6232727595738, 95.50554656982422, 91.85741574423653, 84.07293891906738, 76.94083540780204, 71.17092623029436, 70.81624153682164, 69.85404804774693, 71.99494784218925, 73.52202987670898, 84.0224255153111, 81.87545994349888, 87.27484253474644, 85.17028181893485, 89.6024751663208, 89.13463905879429, 87.61786815098354, 86.3901423045567, 85.62275545937675, 80.59271826062883, 74.99124036516461, 76.31230136326381, 82.67660113743374, 89.22307573046002, 80.91851234436035, 75.00109985896519, 74.44857215881348, 74.01097461155483, 77.36461993626186, 72.53129318782261, 70.93361745561872, 74.12769739968437, 68.11891610281808, 70.58037103925432, 67.8681069782802, 70.45116928645542, 79.43053477151054, 91.63731070927211, 72.18131937299455, 59.80009501320975, 62.38460949489048, 47.120118958609446, 50.043038504464285, 49.683934756687705, 68.23936312539237, 68.90560504368374, 74.59129510607038, 67.37042835780552, 61.71849264417376, 63.5557770047869, 59.567191396440776, 64.22795963287354, 71.65767533438546, 74.95690931592668, 73.27174881526402, 72.03039060320172, 74.36358874184745, 76.67290592193604, 77.41161060333252, 65.6767007282802, 66.98613044193813, 69.84067971365792, 73.89022186824253, 73.44279261997768, 79.71475778307233, 79.17535523005894, 79.4831326348441, 80.16750240325928, 78.1400944846017, 76.20712648119245, 77.01406942095075, 74.58794607434953, 74.93949713025773, 72.43182277679443, 72.11699295043945, 68.94425092424665, 61.559969493321006, 63.549739020211355, 43.253043447222026, 7.814575552940369, 0.8787238565938813, 0.24996160715818405, 0.30206897109746933, 0.45074693166783875, 0.575084809746061, 0.13797050155699253, 0.5979700045926231, 0.051555389272315164, 0.3714289292693138, 0.3603266035871846, 19.68314184461321, 58.17427560261318, 87.89461490086147, 80.81005791255406, 55.22491816111973, 41.73792273657662, 23.820917436054774, 23.206830433436803, 47.917198930467876, 67.90463365827287, 81.48859814235142, 64.89026887076241, 83.33454690660749, 50.123602867126465, 2.0598703367369513, 0.04711265070363879, 0.05449095567954438, 0.09431825391948223, 0.07071334376399006, 0.1818452136857169, 0.03279806899705103, 0.05318127113527485, 0.011389959221040564, 0.01743209219005491, 0.11767063369708401, 0.02660264054845486, 0.027290583455136845, 0.1062880934083036, 0.052361685649624894, 0.12280320828514439, 0.07925776884491954, 0.05950444737183196, 0.04806918151942747, 0.04630248328404767, 0.0644877374704395, 0.06652476744992392, 0.18034688622823783, 0.2541557949568544, 0.24211866515023367, 0.1634724395615714, 0.22194352559745312, 0.25344295320766314, 0.21776122573230947, 0.1530137179153306, 0.17270793898829392, 0.3284129574894905, 0.31810929466571125, 0.09707282789583717, 0.26268864423036575, 0.12730127120656626, 0.12906326380159172, 0.15150172476257595, 0.1313799994864634, 0.1181001327931881, 0.2734926587768963, 0.2501815882112299, 42.59140818459647, 126.7777486528669, 99.60341344560895, 105.43910816737584, 84.65130002158028, 69.27525615692139, 77.73874568939209, 46.078483240945, 42.50909982408796, 134.29746437072754, 158.0977404458182, 105.14638056073869, 96.73626708984375, 116.59667832510812, 122.82718358721051, 57.176743575504844, 0.4560105449387005, 0.21477321535348892, 0.24869559652038983, 0.21395999113363878, 0.5206397569605282, 1.7705091323171342, 0.21244208115552152, 0.6072099687797683, 6.2490434902054925, 2.9763815913881575, 0.5371282664792878, 19.975188527788433, 91.96206951141357, 104.21573189326695, 103.83412987845284, 100.02013860430036, 98.34663023267473, 90.04868847983224, 83.10368606022426, 75.99821499415806, 75.8657614844186, 73.29598413194928, 76.54256466456822, 76.07883494240897, 86.7616138458252, 83.47789519173759, 93.32689026423863, 88.95371491568429, 92.3337356022426, 90.94990457807268, 92.53756100790841, 89.38960320608956, 88.59073407309396, 86.22006429944719, 79.89900316510881, 83.14680658067975, 92.61345618111747, 96.46842793055943, 87.10261753627232, 81.27289131709507, 78.71466187068394, 78.73128890991211, 84.75484207698277, 83.39147349766323, 83.46139322008405, 77.83384568350655, 73.46671526772636, 72.2620713370187, 75.17770222255162, 81.05712195805141, 87.50300053187779, 97.00004155295235, 89.48948356083461, 63.63304097311837, 67.19731398991176, 54.1761257989066, 58.12594393321446, 58.267336300441194, 74.2304334640503, 76.36854703085763, 81.4903004510062, 77.13106318882534, 69.0579651423863, 67.8102354322161, 64.72917488643101, 72.47821589878627, 76.43732724870954, 78.42515822819301, 76.85221808297294, 78.08463396344865, 79.72873061043876, 79.96813774108887, 77.33493028368268, 70.0992569242205, 72.21257931845528, 75.78253596169608, 75.92373030526298, 79.85633427756173, 83.53401579175676, 82.5075375693185, 84.25912284851074, 84.72539561135429, 80.60868522099086, 79.08317347935268, 82.02718080793107, 77.46928759983608, 75.23426055908203, 76.18102904728481, 75.26299830845424, 69.0817071369716, 62.56293501172747, 74.39946923937116, 54.656180313655305, 7.757684571402414, 2.2636983479772295, 1.3682733561311449, 0.4013680656041418, 0.7242635020187923, 0.7255589610763958, 0.49457044154405594, 0.848980681172439, 0.21110316871532372, 0.42437816517693655, 1.2772780103342873, 35.55335896355765, 72.69257477351597, 99.684540612357, 86.35157980237688, 69.10417761121477, 103.59122780391148, 54.026770796094624, 24.70821108136858, 33.35132196971348, 52.3995235306876, 79.55892358507428, 74.09834126063755, 92.32134696415493, 66.71742275782994, 4.515019782951899, 0.3295055074351174, 0.23897346534899302, 0.20702115632593632, 0.2203127345336335, 0.2390649861523083, 0.06106636713125876, 0.11218273067580802, 0.09734354301222733, 0.17953485623002052, 0.30919334452067104, 0.2007546547268118, 0.06672758156699793, 0.17338309490254947, 0.17111701864217008, 0.1873275459344898, 0.1287915919508253, 0.13671392255595752, 0.16031107705618652, 0.13225271765674862, 0.2150451179061617, 0.10654668988926069, 0.1737966484257153], [0.2024183411683355, 0.07455106997596365, 0.031076554408563033, 0.06659577613962547, 0.09433158713259868, 0.0853987889630454, 0.10397381402019944, 0.10147533273058278, 0.02807600300626031, 0.10835134876625878, 0.07921585573681764, 0.015054556374837245, 0.03699738312778728, 0.05969080701470375, 0.07472237971212183, 0.1652019710413047, 0.027076330933985964, 0.3224628839109625, 8.299701384135656, 89.14076042175293, 84.75179876599992, 82.50786413465227, 63.25861644744873, 51.645251410348074, 47.4928411756243, 24.964132343019756, 48.25691373007638, 77.66811725071499, 117.80874988010952, 72.80869306836809, 64.47638552529472, 99.60167639596122, 105.8162008013044, 43.36483996255057, 0.432748518884182, 0.10362849397850887, 0.1317413600959948, 0.030945095034050088, 0.272628232304539, 0.7293965380106653, 0.2693620089973722, 0.029585219254451137, 1.7180224401610238, 1.2476565369537898, 0.2634042001196316, 18.633204766682216, 101.56709943498883, 99.08910778590611, 98.18242345537458, 95.35296412876674, 94.62080465044293, 86.83579281398228, 80.83144446781704, 71.751024382455, 66.57158006940568, 67.82678604125977, 70.39522239140102, 76.78089482443673, 79.97161184038434, 82.77516828264508, 84.40744604383195, 82.90449510301862, 85.17959935324532, 84.86277539389474, 87.76750455583844, 82.07462310791016, 82.89946460723877, 80.37382221221924, 71.126631464277, 66.13157844543457, 69.30186775752476, 75.27798557281494, 77.95688438415527, 73.35469641004289, 65.50512886047363, 62.920364243643625, 61.3586871283395, 65.10528087615967, 61.674114499773296, 55.306833948407856, 65.5245282309396, 64.99051053183419, 63.095278194972444, 55.330756596156526, 57.89628859928676, 68.14576394217355, 84.01908343178886, 84.5997235434396, 45.08342824663435, 40.02906193052019, 31.195674623761857, 34.32062346594674, 54.365971429007395, 62.35503796168736, 67.02000291006905, 68.68003177642822, 65.30481229509626, 59.93138122558594, 58.21764278411865, 60.910535267421174, 62.388597760881694, 64.6130565915789, 66.28202084132603, 67.19032410212925, 65.1578231539045, 64.03113106318882, 66.27609402792794, 71.4385986328125, 71.27971417563302, 64.3100734438215, 63.25415570395333, 65.39775834764752, 64.45257404872349, 70.67494297027588, 72.48786694662911, 74.64526176452637, 70.6839130946568, 72.72869845799038, 76.10423060825893, 71.46577303750175, 74.17683506011963, 71.96778038569859, 68.26241724831718, 65.06711442129952, 63.79732418060303, 66.82533523014614, 58.04165881020682, 51.65166112354824, 43.66253553118025, 7.562927433422633, 0.24979468754359654, 1.086724423936435, 0.3816141741616385, 0.028123317253110663, 0.7017422190734318, 0.014261879891689335, 0.2730593734553882, 0.15876992046833038, 0.2619222524975027, 3.185607050146375, 13.785899979727608, 41.44208581107003, 81.84367888314384, 83.71942847115653, 63.500191416059224, 63.37020451681954, 62.897330965314595, 23.710524456841604, 27.994943516595022, 28.423154047557286, 64.2343658719744, 60.96848324366978, 74.64245469229562, 46.334878717150005, 1.960157173020499, 0.10703416980270829, 0.015510703237461192, 0.1379554652209793, 0.05389755305701068, 0.06275372765958309, 0.009931113171790327, 0.017699070274829865, 0.020502415651987706, 0.018727931227268915, 0.07462840939738921, 0.3129389121064118, 0.019592746160924435, 0.07081297984612839, 0.11258411806608949, 0.013631655718199909, 0.042925675732216666, 0.029311060572841337, 0.018234592163935304, 0.17144047628555978, 0.04429888811760715, 0.331293772906065, 0.03216122656262346, 0.0709601676623736, 0.025697880258251513, 0.08884540759027004, 0.07758796880287783, 0.018943474661292772, 0.1211606107120003, 0.05351101540561233, 0.011406120228847223, 0.1040988340973854, 0.042933964037469456, 0.12274425716272422, 0.08350600874317543, 0.015407978124650461, 0.07084072514304093, 0.18338521676404135, 0.17476725205779076, 0.44766811973282267, 10.801529697009496, 107.72198745182583, 93.0472947529384, 103.09389659336635, 82.26947144099644, 73.38453197479248, 60.913863454546245, 23.466171945844376, 43.82524149758475, 33.54140383856637, 93.80984565189907, 84.58302007402692, 73.12821292877197, 105.39445904323033, 110.82699843815395, 48.37713493619646, 0.4430196391684668, 0.14681945315429143, 0.20519038742142065, 0.015209518506058624, 0.564227109508855, 0.9310980205024991, 1.3526406692607063, 0.3167282044887543, 3.791308011327471, 0.20060579771442072, 0.19461243360170297, 30.12214320046561, 108.74631868089948, 96.47081811087472, 97.49994359697614, 96.28596128736223, 96.55020822797502, 90.27240657806396, 83.74253123147147, 74.37528256007603, 71.03788212367466, 72.00277846200126, 73.87243447984967, 82.65383883884975, 85.07748862675258, 88.2026424407959, 87.66198921203613, 86.74099854060582, 90.26644502367292, 87.37099170684814, 90.69128567831856, 86.27345425742013, 84.32238619668144, 80.95085620880127, 72.82135268620083, 71.20120647975376, 75.28487818581718, 80.7473851612636, 82.0070310320173, 76.26333045959473, 72.24029568263462, 67.02679130009243, 66.28274345397949, 71.5209139415196, 70.06750365665981, 62.028604643685476, 67.51054573059082, 72.02246270860944, 66.34505489894322, 62.19791834694998, 65.94540841238839, 75.03825187683105, 86.62116295950753, 91.8501409803118, 57.597787039620535, 47.477350166865754, 39.03084550585066, 43.79576029096331, 60.88840525490897, 65.20949690682548, 74.33439935956682, 76.4030100958688, 72.13782364981515, 67.39641462053571, 67.58989415849958, 69.1523494720459, 67.55739743368966, 69.3720098223005, 70.73897062029157, 71.78116566794259, 72.10117885044643, 69.23210784367153, 70.49604770115444, 73.18127632141113, 76.78419521876744, 74.98553589412144, 69.12236104692731, 71.28790610177177, 69.30580738612584, 73.5944995880127, 78.1043598992484, 77.90152113778251, 73.55840369633266, 75.17276205335344, 80.13754871913365, 78.32920360565186, 77.51756368364606, 77.11827850341797, 74.83359268733433, 71.06834302629743, 71.9525568825858, 79.34630175999233, 68.31946195874895, 62.84612968989781, 59.965086936950684, 14.300432324409485, 0.9195468574762344, 0.36137849571449415, 0.6582320566688264, 0.13951133244803973, 0.8927676858646529, 0.015273292316123843, 0.3304193583982331, 0.14723211101123265, 0.22379942743905953, 3.2225045902388434, 18.147219964436122, 49.71899536677769, 90.91870021820068, 91.16444410596574, 69.71959345681327, 34.622401101248606, 17.90194855417524, 19.12663803781782, 44.32089124407087, 43.65203332901001, 82.74951553344727, 67.64612592969621, 79.41066987173897, 65.1769654410226, 1.941293248108455, 0.06458350590297154, 0.026191100577956865, 0.13343844403113636, 0.03016632003709674, 0.16959119694573538, 0.048272565605917146, 0.050640489972595654, 0.05363989295437932, 0.04993744287639856, 0.04453410906717181, 0.13789388138268674, 0.040998643064605336, 0.06350703723728657, 0.19270900716739042, 0.053351318796298335, 0.07172778075827019, 0.09662375306444508, 0.0749058895079153, 0.08425014452742678, 0.04744790807100279, 0.13436429149338178, 0.30197183202419964, 0.15774735462452683, 0.14202911805893692, 0.1776171534189156, 0.2473410234919616, 0.1732485278376511, 0.16261538197951658, 0.1963331169847931, 0.09677263721823692, 0.24328237984861645, 0.19501787184604577, 0.20079020996178898, 0.20471147740525858, 0.16554977452116354, 0.1060864735128624, 0.3762781747749874, 0.24124055941190037, 0.6742709417428289, 16.304573331560405, 126.21512522016252, 104.83082812173026, 110.2133960723877, 83.94730159214565, 64.05985491616386, 59.539106777736116, 35.451870100838796, 65.75941208430699, 101.15527275630406, 139.17740658351352, 87.8477006639753, 83.91170597076416, 118.286438533238, 119.4659091404506, 61.97926548549107, 0.7358108109661511, 0.38172629528811997, 0.3228190062301499, 0.10173580875354153, 1.2366163922207696, 1.7432536291224616, 1.4101058542728424, 0.3009548437382494, 14.216565830366951, 6.685759484767914, 0.5393135292189462, 27.6438684122903, 115.24261338370187, 104.61478778294155, 106.47830854143415, 104.50397791181291, 100.12279823848179, 97.14061750684465, 88.23642458234514, 80.41922174181256, 72.3989508492606, 76.14794867379325, 76.2043958391462, 85.16526521955217, 88.74839564732143, 90.75546618870327, 89.83670588902065, 92.54211902618408, 91.58786037990025, 90.56564835139683, 95.53865473611015, 91.99248872484479, 90.96359947749546, 88.01092774527413, 77.51133809770856, 75.61825970241001, 80.21445832933698, 86.33444554465157, 87.58264078412736, 83.77281842912946, 80.85979311806815, 78.54031767163957, 76.03497096470424, 81.0299197605678, 77.31828239985875, 73.22697462354387, 79.83772005353654, 76.55814947400773, 73.15710353851318, 65.25968374524797, 69.67479147229875, 81.74406950814384, 99.17705113547188, 104.89491135733468, 60.40982723236084, 48.82938623428345, 44.78318963732038, 47.61624118259975, 69.28643580845424, 70.42651012965611, 79.03808661869594, 79.43990789140973, 77.77228464399064, 72.80788012913295, 69.78173119681222, 72.21381609780448, 75.09641524723598, 71.81469767434257, 75.29716260092599, 76.93685409000942, 75.5099789755685, 72.46522971561977, 77.31500285012382, 77.86795439038957, 81.89801379612514, 74.94283921377999, 72.67591299329484, 76.89266354697091, 74.44404193333217, 78.88610172271729, 80.66279779161725, 79.03759329659599, 79.42499010903495, 80.33738585880825, 82.0148686000279, 79.71418108258928, 82.5725518635341, 80.3594811303275, 74.39985139029366, 72.61705480303083, 74.94087982177734, 81.96755831582206, 67.94922024863106, 69.75994164603097, 74.58661202022007, 15.26289245060512, 1.5723441200596946, 2.4648602051394324, 1.1482016508068358, 0.14287483053547995, 1.7116455137729645, 0.1213541424700192, 0.377950410757746, 0.22417769714125566, 0.37086832363690647, 6.111571644033704, 34.014753341674805, 63.940338952200754, 98.73269993918282, 101.77139731815883, 80.15170914786202, 92.16135774339948, 82.90883077893938, 29.084575653076172, 34.65185104097639, 37.506768567221506, 81.89684649876186, 77.74351215362549, 93.57282870156425, 82.56221989222935, 5.479211747646332, 0.2577276032950197, 0.16200782172381878, 0.18951477642570222, 0.11590870895556041, 0.3130135509584631, 0.13837532911981854, 0.09820853945400033, 0.09092186045433794, 0.11800440507275717, 0.14452896320394107, 0.2775048906249659, 0.09048432071826287, 0.12505450605281762, 0.3052496989922864, 0.13747046196034976, 0.12931757872658117, 0.17321124912372657, 0.13823168325637067, 0.17401972359844617, 0.07658761141023465, 0.38225777819752693], [0.033850018799837144, 0.054814854370696206, 0.037582022470555136, 0.036072726494499614, 0.0524128404046808, 0.015241608123428054, 0.04486553271168044, 0.06372213283819811, 0.08049910794943571, 0.05943258372800691, 0.07552632157291685, 0.06836057786962815, 0.09670650040996925, 0.057521313428878784, 0.0345729673281312, 0.057071322575211525, 0.07684240809508733, 0.07775095291435719, 45.407266412462505, 94.2612840107509, 85.20446000780377, 64.89106096540178, 63.61124447413853, 61.516063826424734, 63.11870057242257, 171.1469576699393, 115.6711504799979, 81.26671436854771, 72.17233535221645, 73.643143926348, 106.5335328238351, 106.20408398764474, 50.31789187022618, 0.19709152914583683, 0.040763693529048135, 0.08878461763794933, 0.0566691073722073, 0.15715511568955012, 0.38563794110502514, 0.11263575458100863, 0.20989633990185602, 1.5664465108088084, 4.308324771268027, 0.8321270112480436, 9.64566125188555, 93.9176469530378, 86.1240679877145, 88.7662455695016, 87.4569478716169, 89.0268724986485, 82.05505698067802, 79.90310955047607, 71.93458189283098, 66.96953119550432, 67.97682544163295, 76.14213303157261, 77.60047653743199, 84.44255529131208, 89.69817270551408, 86.8456939969744, 89.87884671347481, 87.9669942855835, 87.43164253234863, 84.88564191545758, 77.44971452440534, 79.68022523607526, 75.14162717546735, 65.81861073630196, 63.957139696393696, 68.2059075491769, 73.1377180644444, 76.91555786132812, 77.25929914202008, 64.13757051740373, 59.019082750592915, 60.42785085950579, 59.274408204214915, 57.78456504004342, 61.42876665932791, 56.67741823196411, 52.74978569575718, 63.8410769871303, 55.89542974744524, 58.53391088758196, 61.37918431418282, 79.69713715144566, 72.86988585335868, 83.81864874703544, 57.5917455809457, 34.17851196016584, 31.595751898629324, 49.093035629817415, 54.43292427062988, 61.04138374328613, 69.03763471330915, 69.43957410539899, 70.38601602826799, 67.80136953081403, 62.5871981212071, 61.67350305829729, 58.8909718649728, 65.87936578478131, 67.59654358455113, 66.3798862184797, 66.25457545689174, 68.43991592952183, 66.58483028411865, 64.59062085832868, 67.22812230246407, 67.3061922618321, 60.781875474112375, 57.5086555480957, 58.47571277618408, 69.78162002563477, 70.64789363316127, 72.79171167101178, 71.50214685712541, 73.43712288992745, 73.97029985700334, 78.50343663351876, 73.66825471605573, 74.44406972612653, 69.18591621943882, 71.45215456826347, 64.85030283246721, 63.61094570159912, 65.94458157675606, 62.2932893208095, 53.69503252846854, 47.16049494062151, 7.464958701814924, 0.717268457370145, 0.44769935948508127, 0.14811305302594388, 0.09248732216656208, 0.2649390734732151, 0.08513956144452095, 0.16676233017018863, 0.11318899132311344, 1.006133354135922, 9.097062758037023, 13.075081893375941, 44.507985387529644, 75.82514231545585, 79.78278064727783, 70.69639205932617, 80.10481575557164, 88.02904169900077, 38.65943302427019, 27.92533298901149, 31.350480488368444, 50.41667440959385, 55.37801129477364, 65.72592176709855, 36.73031084878104, 2.8767103339944566, 0.06296425671981913, 0.08326088118233851, 0.1964840367436409, 0.03556224085124476, 0.019018556257443767, 0.02294665145953851, 0.07248344485248838, 0.025253936847937957, 0.06877927468823535, 0.025946410672206963, 0.05828700627067259, 0.035167635418474674, 0.10463853406586818, 0.07186127573783908, 0.13405797364456312, 0.12761277306292737, 0.03809804495956216, 0.08726497061018433, 0.19537905603647232, 0.07402827231479542, 0.06420757036123957, 0.04897408599832228, 0.04225578185703073, 0.09256401019436972, 0.062038558535277843, 0.03690412188214915, 0.03162990650162101, 0.0729326078934329, 0.05068927324776139, 0.092092862618821, 0.06926840344177825, 0.12463998900992529, 0.12110491655766964, 0.017988034590546573, 0.006139261016090001, 0.020744686580396125, 0.02170862869492599, 0.12194677495530673, 61.96903773716518, 103.12455899374825, 103.21464933667863, 81.42813491821289, 80.10447529384068, 65.10002108982631, 56.42356579644339, 112.24158913748605, 65.86476761954171, 59.97466155460903, 74.50970935821533, 81.7766079221453, 106.4901830128261, 112.68724659511021, 57.95105777468, 0.1253336010766881, 0.05389119518388595, 0.022633963863232305, 0.13646704437477247, 0.25076740820493015, 0.3070765866764954, 1.3919745300497328, 1.2013898938894272, 2.324556750910623, 6.5586704186030795, 0.2469720361488206, 16.198760952268326, 104.33050918579102, 87.55069296700614, 94.80605752127511, 90.19197423117501, 92.99966485159737, 83.52788053240094, 80.98840427398682, 73.38460840497697, 72.82370812552315, 71.38187353951591, 80.73022311074394, 82.90936579023088, 87.28693240029472, 92.92479801177979, 89.22210993085588, 92.38309560503278, 90.42189707074846, 89.37772178649902, 87.09616265978131, 81.63765784672329, 81.71224675859723, 77.3622019631522, 68.33551229749406, 67.76710796356201, 71.68917846679688, 76.80950055803571, 81.48939718518938, 84.2629165649414, 70.5514109475272, 67.44116796766008, 68.72283962794712, 68.19208063398088, 64.61104161398751, 67.72662081037248, 63.87528991699219, 62.227469035557334, 69.08076218196324, 61.17699868338448, 63.82704162597656, 66.1556956427438, 82.4057742527553, 77.06531238555908, 86.64805248805455, 66.1178001676287, 43.21812527520316, 38.98193713596889, 57.695760113852366, 60.76810414450509, 68.31557096753801, 76.20969036647251, 74.18112904684884, 73.78932012830461, 73.16918645586286, 67.3695181437901, 67.55742522648403, 63.110460008893696, 70.55960982186454, 71.62507438659668, 71.34593050820487, 71.10839939117432, 70.75643839154924, 71.3369117464338, 71.19248649052211, 71.29849515642438, 69.17718928200858, 69.63436685289655, 65.07885687691825, 65.5436566216605, 71.79947417122978, 72.41659927368164, 75.91680295126778, 76.84273379189628, 75.3099055971418, 75.95230824606759, 80.86897863660539, 78.26024968283517, 77.48833956037248, 76.01431397029332, 76.64140278952462, 71.31494154248918, 70.98196302141461, 76.56577859606061, 72.80450330461774, 62.43622071402413, 65.15373066493443, 13.689976624080114, 0.7619511825697762, 0.3036474606820515, 1.6533439393554414, 0.9355239144393376, 0.3636385058718068, 0.0418409187612789, 0.08538331157927002, 0.2719071667109217, 0.4997948897736413, 9.749344876834325, 15.735046863555908, 50.401669774736675, 82.20852184295654, 86.74142932891846, 75.73726844787598, 64.42994376591274, 33.65146677834647, 25.83892617906843, 47.207961559295654, 53.274468490055625, 72.70139898572648, 67.19377040863037, 74.23292091914585, 50.78551605769566, 2.3274695660386766, 0.0841615821367928, 0.13763439602085523, 0.08742644837392227, 0.026019566925242543, 0.023247970201607262, 0.011084864431593035, 0.0812073831579515, 0.0791523652151227, 0.05050966163565006, 0.012083583162166178, 0.07529966373528753, 0.040514060495687385, 0.07502460599477802, 0.03844164491498044, 0.04466021140771253, 0.0555300506364022, 0.05262718622439674, 0.1340550288025822, 0.10666436143219471, 0.0547399542826627, 0.14717039146593638, 0.19317330153925077, 0.11570033085133348, 0.2000039778649807, 0.10538964519011122, 0.1252188200929335, 0.11050333614860262, 0.24200904103262083, 0.17737659918410437, 0.17109700185911997, 0.1439702846109867, 0.2546236312815121, 0.19328445914600575, 0.13975835990692886, 0.1794357086930956, 0.151088931198631, 0.190991662176592, 0.24200591977153504, 79.48407064165387, 118.06783430916923, 109.415360723223, 85.69484996795654, 82.02112197875977, 78.934891973223, 78.38884694235665, 181.7804113115583, 134.4966275351388, 107.17459447043282, 93.6653161730085, 95.36856978280204, 124.45156124659947, 123.67497498648507, 70.83829511914934, 0.5507094434329441, 0.1925906842308385, 0.2160405966320208, 0.4368904323450157, 0.5107300515685762, 1.7300025458846773, 0.8002022100346429, 0.81601858990533, 4.680579287665231, 10.18237919466836, 1.4473855452878135, 15.36104965209961, 109.70571899414062, 91.47448662349156, 100.95168358939034, 94.9046802520752, 97.330963407244, 88.58780193328857, 87.87727914537702, 78.03121621268136, 77.57061317988804, 74.61751065935407, 83.70286396571568, 83.4344620023455, 91.38178375789097, 95.43144403185163, 91.70424270629883, 96.31483105250767, 94.37869467054094, 94.53692599705288, 92.35396875653947, 85.32823521750313, 87.57829816000802, 83.48380810873849, 72.50882966177804, 71.85627569471086, 75.53686850411552, 83.53545406886509, 88.08731624058315, 86.63314165387834, 77.08909606933594, 73.61554568154472, 74.16378634316581, 73.7374518258231, 69.77040563310895, 72.44157109941754, 73.59639644622803, 68.23015676225934, 76.71152400970459, 64.82412896837506, 71.09113311767578, 70.02138846261161, 90.66398620605469, 85.86460140773228, 102.08622019631522, 67.56075341360909, 43.65020595278059, 39.23744324275425, 60.59429495675223, 67.04762894766671, 71.42481340680803, 79.56653881072998, 77.9295710154942, 76.3086882999965, 76.54524666922433, 71.15294429234096, 70.00981276375907, 70.17005906786237, 73.39302267347063, 74.85903699057442, 74.92893586839948, 73.86844621385846, 74.44047055925641, 74.77077402387346, 75.17902932848249, 77.05758598872593, 74.6139531816755, 74.77089214324951, 71.56542410169328, 73.46642344338554, 79.59085055759975, 77.2875644138881, 80.66700145176479, 78.52403804234096, 80.69395351409912, 80.15689250401088, 83.17065279824394, 79.57231276375907, 78.95204707554409, 75.83995587485177, 79.9838684626988, 71.60058893476213, 74.8281591960362, 78.6492862701416, 73.72349289485386, 66.33872509002686, 79.76682758331299, 14.973024027688162, 1.2910083021436418, 1.7355160500322069, 0.843984492123127, 0.37332177055733545, 0.6560695384229932, 0.15634978961731705, 0.2152757519590003, 0.3835122265986034, 1.0477398186922073, 16.979404960359844, 34.809974670410156, 66.6548889705113, 87.363265310015, 96.53146198817662, 89.57171549115861, 114.1800114767892, 120.2303638458252, 49.238833154950825, 35.4452554157802, 42.97481325694493, 68.86864757537842, 74.06183542524064, 82.36902523040771, 71.67159257616315, 5.912670339856829, 0.16649996781987803, 0.20500509307852813, 0.25660221225449015, 0.1521607722554888, 0.1548129078000784, 0.122880113444158, 0.14058315993419715, 0.12081698700785637, 0.13341846796018736, 0.10412461842809405, 0.18927097879350185, 0.08509509025939874, 0.16204975518797124, 0.17359159514307976, 0.18149533388870104, 0.18091841627444538, 0.11156064977071115, 0.1520808001181909, 0.3134141308920724, 0.1524921144757952], [0.15880498715809413, 0.10887403107647385, 0.10902258953345673, 0.13627739383706025, 0.1118521484147225, 0.03342543908261827, 0.05883113707282713, 0.008621620313663567, 0.08441989363304206, 0.011563145954694067, 0.09639536496251822, 0.04069671533735735, 0.05344077006780675, 0.028438400078032697, 0.11763236432203225, 0.11733049766293593, 0.48052308389118736, 6.7268658961568555, 81.55492564610073, 78.5157835824149, 58.22954504830496, 66.75055871691022, 34.87520783288138, 39.68400396619524, 33.11353376933506, 96.58433083125523, 123.82491711207798, 56.54726457595825, 90.23259340013776, 105.181197983878, 109.31967013222831, 47.45278828484671, 0.5023939503090722, 0.05851344697709594, 0.09175099632037537, 0.02107484814977007, 0.16515691631606647, 0.560432415987764, 0.03605687591646399, 0.4044809942798955, 1.1791098437138965, 1.4249630570411682, 1.7926734515598841, 1.165192710501807, 70.4740149634225, 93.85732964106968, 91.51293795449394, 87.20382499694824, 78.73482554299491, 74.46348299298967, 71.43697970254081, 69.37566457475934, 65.52886390686035, 71.75609656742641, 75.52271502358573, 84.47435024806431, 86.74540369851249, 87.54327923910958, 86.69131892068046, 89.1501613344465, 84.52992194039481, 78.76920522962297, 81.53121144430978, 76.95434270586286, 73.04678698948452, 70.60600294385637, 65.498854637146, 62.78543717520577, 65.39201913561139, 63.65916619982038, 69.88339723859514, 76.24069322858537, 77.3424482345581, 69.89773832048688, 66.23573194231305, 71.97659764971051, 72.69302640642438, 71.89319842202323, 67.82825905936105, 63.77197715214321, 62.682958194187705, 59.80552155630929, 55.22241333552769, 52.803846154894146, 55.6736467225211, 61.7256840297154, 64.3694041115897, 61.069357190813335, 55.43627193995884, 61.00355775015694, 48.70205354690552, 59.889323779514854, 62.12911033630371, 72.21150929587228, 75.17263003758022, 70.4007670538766, 71.70977292742047, 67.3469990321568, 63.52731023515974, 53.01898322786604, 52.55354077475411, 58.71087455749512, 66.79144886561802, 64.87146704537528, 68.15819426945278, 65.48853656223842, 65.3967091696603, 64.65789331708635, 64.99731281825474, 63.972265924726216, 61.81515598297119, 55.268938473292756, 50.18441350119454, 56.62696736199515, 65.50205775669643, 64.72121919904436, 68.23759133475167, 68.12744154248918, 71.19609260559082, 73.1860636302403, 75.17151137760708, 77.89756761278424, 77.32487624032157, 69.64153739384243, 66.31964533669608, 69.5206526347569, 64.56121608189174, 64.46320479256767, 62.44740036555699, 54.45154891695295, 35.116834912981304, 2.716647071497781, 1.2217363906758172, 0.452670904142516, 0.3296700928892408, 0.1645251323602029, 0.3046287037432194, 0.014594453653054578, 0.061725380697420666, 0.33940139785408974, 3.4289859448160445, 2.8450265484196797, 15.161087444850377, 39.361124651772634, 70.8603903906686, 79.16828196389335, 63.78286497933524, 74.35793985639299, 76.45774800436837, 23.41792365482875, 21.324742351259502, 22.517025436673844, 48.392726693834575, 63.22946875435965, 63.785512242998394, 33.40566383089338, 3.183017760515213, 0.07115185380514179, 0.12302930972405843, 0.024332572805828283, 0.021126072454665388, 0.05237389927996056, 0.08990188661430563, 0.011388398590497673, 0.059133383711533885, 0.1046624659959759, 0.14229754651231424, 0.03873080939852765, 0.09998391954494373, 0.08660480353449072, 0.03946346097758838, 0.08630153230790581, 0.04673403834125825, 0.052194101070719104, 0.07483020571193524, 0.06013456213154963, 0.08623218602899994, 0.047341283078172376, 0.11861320026218891, 0.08877935220620461, 0.05053538489820702, 0.02570545270905963, 0.06612971079136644, 0.04616379751158612, 0.132685283731137, 0.013565702962556055, 0.06955511162855796, 0.03965244994365743, 0.028654852748981545, 0.09946661123207637, 0.10131361747958831, 0.014560626986037408, 0.578975746674197, 10.45968701158251, 95.79982362474713, 87.85511439187187, 75.06416865757534, 73.41515963418144, 55.67106546674456, 55.810383796691895, 39.914618151528494, 103.03323881966728, 105.58219936915806, 57.31852504185268, 97.13309260777065, 110.32581097739083, 118.75277382986886, 55.53560338701521, 0.15640699011938913, 0.10651875460254294, 0.16038260821785244, 0.07795515124286924, 0.18505243158766202, 0.7975414842367172, 0.48250163772276466, 0.967804485133716, 1.871697051184518, 1.9218144076211112, 0.9843389179025377, 2.363251485994884, 83.23568098885673, 94.3329199382237, 95.97379262106759, 87.46436854771206, 80.26645864759172, 74.56631633213588, 75.29048538208008, 71.32762895311627, 69.9924978528704, 76.24908665248326, 81.84244210379464, 87.91596671513149, 86.71637412479946, 89.97549615587506, 89.60029343196324, 90.24482917785645, 87.39383043561662, 82.71680341448102, 84.38017436436245, 79.32148279462541, 77.19055366516113, 73.71714918954032, 68.5045758656093, 66.04852662767682, 68.07529531206403, 67.983704158238, 75.29970564161027, 80.97723851885114, 80.38295214516776, 73.9000049318586, 73.556291443961, 73.03331443241665, 75.93734182630266, 74.97370311192104, 72.97731889997209, 71.46816321781704, 68.55936935969761, 66.83733476911272, 61.586296217782156, 58.7219569342477, 63.52067470550537, 67.36780888693673, 73.32661873953683, 65.54184314182827, 59.00325475420271, 64.73567840031215, 54.629648617335725, 64.16056210654122, 63.792092187064036, 73.76134668077741, 74.73419175829206, 74.9391427721296, 74.94251264844621, 71.06937830788749, 67.14857237679618, 61.75260829925537, 56.25573900767735, 67.68559864589146, 70.09004361288888, 66.31158542633057, 70.22221919468471, 70.47975417545864, 70.40242767333984, 69.13172721862793, 69.9566034589495, 69.33113356998989, 66.15359728676933, 64.16727406638009, 60.70459066118513, 60.41644886561802, 70.18043272835868, 68.73549229758126, 71.37501566750663, 71.71018287113735, 75.06890732901437, 76.44931289127895, 78.22555732727051, 81.28728798457554, 80.7468432017735, 73.51642268044608, 73.39297403608049, 74.481534412929, 73.36349282945905, 73.1834441593715, 74.278000831604, 63.01900087084089, 53.55248328617641, 4.267019033432007, 0.8516481380377496, 0.596948402268546, 0.30068057988371166, 0.43898753981505123, 0.4261704475751945, 0.13515101213540348, 0.012427932898780065, 0.2753345285143171, 1.082757436803409, 2.9149380198546817, 17.614652701786586, 46.286592211042134, 77.72241047450474, 84.53878784179688, 69.87155055999756, 69.69057777949742, 35.74105065209525, 20.47855598585946, 36.00970622471401, 37.11023139953613, 62.479591369628906, 70.76873670305524, 71.83683463505336, 46.26020295279366, 2.5849326763834273, 0.15953844280115195, 0.1000104977616242, 0.03396655718929001, 0.0238885920760887, 0.01460102865738528, 0.09422610886394978, 0.019391915062442422, 0.061365465367478986, 0.056566102363701375, 0.06355663136179958, 0.03803931775369814, 0.0335021847859025, 0.10073169227689505, 0.015865130915439556, 0.03198202546419842, 0.03281983979312437, 0.05232136031346662, 0.07419215887784958, 0.03917476807587913, 0.2126026903944356, 0.1730014325252601, 0.23213022255471774, 0.2072438650897571, 0.1689016425183841, 0.15774453191884927, 0.16131059985075677, 0.11503981772278037, 0.20910671512995446, 0.12713368662766047, 0.14062925960336412, 0.14302488176950387, 0.09645029915762798, 0.17261420616081782, 0.20261130295693874, 0.41317780475531307, 0.8506560655576842, 15.410270690917969, 114.2846096583775, 100.43700272696358, 81.2875450679234, 87.21851348876953, 52.77572679519653, 52.02784701756069, 43.55609260286604, 101.21537467411586, 143.5853715624128, 74.57145799909318, 112.64678028651646, 122.60122816903251, 128.96705654689242, 66.88839708055768, 1.6120514465229852, 0.22427091428211757, 0.1830040565026658, 0.17256916500627995, 0.6504485543285097, 2.8338384287697926, 0.7144883636917386, 2.1786589111600603, 4.622765498501914, 7.80644268648965, 4.357760335717883, 2.156924511705126, 82.56661810193742, 100.20675332205636, 103.00757217407227, 94.1078747340611, 86.65900979723249, 80.3557152066912, 78.29841613769531, 74.98550810132707, 72.91724477495465, 78.53197288513184, 85.61004025595528, 90.40409578595842, 90.98936339787075, 92.12089143480573, 94.08035986764091, 94.03038147517613, 93.36063071659633, 85.93261732373918, 88.46551363808769, 85.01104300362724, 83.84790066310337, 78.44618347712925, 74.46989618028913, 71.22143963405064, 72.22375896998814, 73.74811731066022, 79.55658899034772, 84.53659915924072, 86.48364421299526, 81.17569991520473, 77.11692360469273, 80.82141126905168, 81.50020858219692, 81.36375985826764, 78.84586470467704, 76.77282101767403, 77.13241808755058, 73.94056851523263, 69.81340108598981, 67.19658442905971, 72.2266285760062, 75.2329820905413, 78.27418776920864, 75.36429609571184, 68.55700002397809, 65.50949232918876, 58.35853140694754, 65.2090174811227, 70.07825946807861, 77.50682871682304, 77.95022800990513, 76.49273913247245, 77.67065334320068, 76.59759439740861, 71.70033727373395, 65.14646979740688, 59.93888528006417, 69.32477596827916, 78.05404799325126, 72.94921343667167, 76.85241263253349, 72.56040613991874, 76.39776420593262, 72.10971818651471, 72.36625262669155, 72.90043708256313, 70.6000622340611, 67.22093786512102, 67.35945715223039, 69.58587537493024, 75.82380131312779, 72.48805454799107, 74.8637478692191, 75.80303314753941, 79.21291024344308, 80.26661845615932, 82.96586159297398, 83.70458017076764, 84.96743610927037, 76.8513981955392, 74.50659656524658, 78.4863510131836, 74.90807737622941, 75.99095412663051, 77.71920040675572, 68.95039313180106, 65.69065271105084, 4.144990861415863, 2.6263943144253323, 2.534045372690473, 0.23037992790341377, 0.7522182762622833, 0.8602470223392759, 0.2537314662975924, 0.12823451470051492, 0.5752020605972835, 5.124666452407837, 8.056397182600838, 35.509460244859966, 64.08755043574742, 85.56887912750244, 91.97757094247001, 73.19330365317208, 98.04411956242153, 101.79939855848039, 29.451996394566127, 27.836323090962, 31.992973463875906, 65.12060860225132, 82.56473514011928, 82.2526637486049, 68.93019471849713, 6.416156351566315, 0.20583620348146983, 0.21056914808494703, 0.16273894320641244, 0.09806609459753547, 0.15283652528056077, 0.09813920674579484, 0.09771696118904011, 0.18097858875989914, 0.23711617929594858, 0.19870412190045628, 0.13580938109329768, 0.10514674322413546, 0.18386268828596386, 0.14570338518491813, 0.19762668971504482, 0.07113026960619859, 0.136173795110413, 0.16174070962837764, 0.23817260403718266], [0.08961291212056365, 0.02861926019457834, 0.022657639646370496, 0.0684717558324337, 0.06188662775925227, 0.017101995081507733, 0.03435816688995276, 0.03420461102255753, 0.05809738287436111, 0.043809002797518454, 0.0546980343892106, 0.07032735233328172, 0.031782196901206455, 0.04750143430594887, 0.06736501093421664, 0.09825478161552123, 0.09935843239405326, 36.575484139578684, 91.37121554783413, 78.72254112788609, 79.63925865718296, 65.01405797685895, 85.25529997689384, 34.45353903089251, 32.9239695412772, 30.907484190804617, 47.67682600021362, 90.69539901188442, 100.98982919965471, 95.19767189025879, 46.38363422666277, 1.403969292129789, 0.058073898777365685, 0.05935428757220507, 0.056614166391747336, 0.08177543231951338, 0.3649362176656723, 0.07639277007962976, 0.23409466285790714, 2.181825335536684, 2.533813259431294, 0.7694933978574616, 0.5956233590841293, 26.790761641093663, 93.88627583639962, 92.30132920401437, 83.43949249812535, 74.30534199305943, 70.01720564705985, 71.63616371154785, 69.51728275844029, 70.66928713662284, 74.84281989506313, 79.77825736999512, 84.17024149213518, 84.61450236184257, 84.16548197610038, 87.77605084010533, 83.83150291442871, 85.2246584211077, 77.03683866773332, 75.93883568899972, 73.06488009861538, 67.3284056527274, 63.233408382960725, 63.672166279384065, 61.25831345149449, 65.01284899030412, 63.33790928976876, 69.08695997510637, 72.63871928623745, 78.2304766518729, 74.78709534236363, 65.38972623007638, 66.44627625601632, 67.10046999795097, 70.35838999067033, 73.15935475485665, 67.53585106985909, 64.69347504207066, 56.84930624280657, 58.33772155216762, 57.02497059958321, 56.33336080823626, 58.25863020760672, 53.45847415924072, 60.42359856196812, 61.5100953238351, 40.13578973497663, 64.03530693054199, 67.21896457672119, 63.94600173405239, 58.10922309330532, 68.03277233668736, 76.89649200439453, 71.47727925436837, 74.84801714760917, 65.53180994306291, 65.2954808643886, 43.40741157531738, 47.34037685394287, 61.519246101379395, 59.262617111206055, 60.43429183959961, 61.983191217694966, 70.86312103271484, 69.81406116485596, 68.7000981739589, 65.96993555341447, 64.93666199275425, 62.156159673418315, 58.45850208827427, 50.83535548618862, 48.94238478796822, 55.56986495426723, 60.24620410374233, 63.489928926740376, 65.47443171909877, 66.08532428741455, 66.89510904039655, 70.87225791386196, 76.80299704415458, 76.25886276790074, 72.39200265066964, 69.46374688829694, 66.34717409951347, 70.52524403163365, 67.3613748550415, 66.06676564897809, 56.93975441796439, 60.21174103873116, 15.660727194377355, 0.13341245613992214, 4.221032381057739, 10.548936622483389, 0.45230061401213917, 0.20082345817770275, 0.07032143550791911, 0.05613011308014393, 0.18661151507071086, 0.15347687234835966, 0.3663989763174738, 2.7633354919297353, 5.748521753719874, 28.25680548804147, 68.73005185808454, 83.0932012285505, 65.23032760620117, 70.4826307296753, 97.07376194000244, 35.59199442182268, 28.26133918762207, 33.62330572945731, 49.46307931627546, 63.20694269452776, 66.75647163391113, 42.333525793892996, 2.3846554117543355, 0.16362007521092892, 0.09297672911946263, 0.03195997986144253, 0.048454942248229466, 0.02370253438130021, 0.09659539030066558, 0.11039069933550698, 0.010408586390050394, 0.038048508510525735, 0.03772905422374606, 0.09626221603580884, 0.023249705554917455, 0.05100934839408312, 0.1363245113087552, 0.10495544384632792, 0.16162146388420037, 0.04354486607813409, 0.13166381711406366, 0.04017287612493549, 0.015294394755203809, 0.07982751434402806, 0.0654193524803434, 0.06352783433560814, 0.09323525774691786, 0.06717192700931005, 0.048097873372691016, 0.06953158681946141, 0.024972997905154313, 0.08860211207398347, 0.05067483741523964, 0.05069279145183308, 0.07952855181481157, 0.051016181241720915, 0.15530537494591304, 0.15300496481359005, 49.85830674852644, 103.88313552311489, 88.83205195835659, 82.51600047520229, 79.76074096134731, 88.55140726906913, 39.501012734004426, 26.334838220051356, 27.870423112596782, 60.47423703329903, 93.30053574698312, 107.38914094652448, 105.50287178584507, 57.02725655691964, 0.8769879468849727, 0.037915983836033514, 0.05644239525177649, 0.17263178021780082, 0.3123736652944769, 0.4612295648881367, 0.37940603122115135, 0.8956403317196029, 2.418538736445563, 1.6002314750637328, 0.594092421233654, 0.640793923820768, 35.85380949292864, 98.23621640886579, 96.45783192770821, 88.46810531616211, 78.17343194144112, 74.34121554238456, 75.11451530456543, 73.05464540209088, 73.62869167327881, 80.26420743124825, 83.45998968396867, 89.28026635306222, 86.31168324606759, 87.65949480874198, 90.09257330213273, 85.47316769191197, 87.4379653930664, 79.33109215327671, 77.50272233145577, 73.9567230769566, 72.78734125409807, 67.77081830160958, 66.25845255170549, 64.84405640193394, 68.71142373766217, 67.29356043679374, 74.19590786525181, 75.46373871394566, 81.62779140472412, 77.81650297982353, 69.89297185625348, 72.06017753056118, 73.53375843593052, 74.44489656175885, 75.7028957094465, 71.81318296704973, 70.62718105316162, 64.08492401668003, 62.30915205819266, 62.734840393066406, 63.60751329149519, 62.493911606924875, 59.661193575177876, 65.78966454097203, 63.99635532924107, 48.505155495234895, 67.17093167986188, 72.45308426448277, 64.29018075125558, 60.56525843484061, 69.45145552498954, 77.72481455121721, 75.31692327771867, 75.46582317352295, 70.91583701542446, 69.23782621111188, 52.5543189729963, 56.26294081551688, 67.24882098606655, 65.97265924726213, 67.05910042354039, 67.40961619785854, 72.06726469312395, 73.94923291887555, 72.54533549717495, 69.71249239785331, 67.76293209620884, 68.98070117405483, 65.25111661638532, 59.34408473968506, 57.05862767355782, 58.9366215297154, 64.3621085030692, 66.53818702697754, 69.05062784467424, 68.42162132263184, 71.46106215885708, 73.83959034511021, 80.17711176191057, 78.12259197235107, 76.35811083657401, 70.25576509748186, 73.77205385480607, 77.41879504067558, 77.42249148232597, 75.76385920388358, 67.11638137272426, 68.79247447422573, 26.843428986413137, 0.41023564977305277, 1.7879634414400374, 5.6518614547593256, 0.36565313062497545, 0.10160331122045006, 0.08125431063984122, 0.04656838419448052, 0.1307350383805377, 0.3795749050165926, 0.18510705365666322, 2.2794753185340335, 4.514933364731925, 32.690829685756135, 75.95209285191127, 87.17443411690849, 72.62917246137346, 55.75916862487793, 35.445119925907676, 27.735334498541697, 46.262117181505474, 53.92826965876988, 66.19188186100551, 69.30461229596818, 74.452470098223, 50.472200938633506, 2.147919646331242, 0.054710461758077145, 0.024219091216634427, 0.08936502292220082, 0.0754758385675294, 0.06683813527758632, 0.06432468550545828, 0.03733269477795277, 0.049477426667830775, 0.02277088544464537, 0.016922488642324294, 0.056391505125377855, 0.01566234733244138, 0.061050781181880405, 0.06684109369026763, 0.04504961586956467, 0.08410105681312935, 0.047590726121727905, 0.1181506836520774, 0.12195946356015545, 0.1341822405478784, 0.24944811899747166, 0.19455299393406936, 0.13562258040266378, 0.12778909717287334, 0.15926637740007468, 0.1215885898896626, 0.10343767636056457, 0.08965865895152092, 0.12018980351941926, 0.2698255841221128, 0.13498622312077455, 0.21382180069174084, 0.25323369300791193, 0.22277070049728664, 0.2133178934454918, 65.19107723236084, 116.85406739371163, 99.61589241027832, 101.29061671665737, 73.29455280303955, 98.04127080099923, 45.74820409502302, 46.067248003823416, 48.949711663382395, 68.32084465026855, 112.99396092551095, 120.09006581987653, 113.3973524911063, 75.42459951128278, 3.4269075649125234, 0.14916115892784937, 0.23738615480916841, 0.19277619570493698, 0.5064277052879333, 1.1661529732601983, 0.6357331382376807, 1.0730023831129074, 6.636449422155108, 5.645528171743665, 5.491338959762028, 1.2538467305047172, 37.71478026253836, 103.17003495352608, 103.75366279057094, 93.09658527374268, 83.15878527505058, 77.22999858856201, 78.97264153616769, 76.12265028272355, 77.08115427834647, 83.23957198006767, 87.42942605699811, 91.32843548910958, 90.52459144592285, 90.94579819270542, 94.821822983878, 89.31510462079729, 93.17269584110805, 85.70268058776855, 84.1804483958653, 79.84946945735386, 76.01560633523124, 72.39828382219586, 72.05655057089669, 69.35711288452148, 73.67859363555908, 73.33934783935547, 77.6053819656372, 82.31166090284074, 85.83691283634731, 84.6392935344151, 75.89855698176792, 76.83171394893101, 78.20699868883405, 80.56654439653668, 79.93561322348458, 76.55605111803327, 75.38848277500698, 73.07192557198661, 67.77495942796979, 70.08248397282192, 73.56640107291085, 72.96520124162946, 68.47021007537842, 74.9320764541626, 75.0831789289202, 59.82022394452776, 74.08930165427071, 76.39495713370187, 70.73930413382394, 62.84230123247419, 73.66003499712262, 79.17678655896867, 76.26224654061454, 79.37688773018974, 72.3363892691476, 74.67372158595494, 56.27337006160191, 57.32397590364729, 73.55992535182408, 70.96416868482316, 72.00233377729143, 72.42727865491594, 78.60390758514404, 79.43145193372453, 77.90222985403878, 73.9486631665911, 71.06602232796806, 73.1882106236049, 69.80691146850586, 65.42457144601005, 66.5704266684396, 67.68414647238595, 70.58174678257534, 70.89923082079206, 73.38334383283342, 72.21165520804269, 74.74390533992222, 77.42990521022251, 82.43258040291923, 80.21078273228237, 79.86755561828613, 73.92935412270683, 75.26419339861188, 81.24548762185233, 77.76066030774797, 76.51333359309605, 68.836227280753, 77.2504471370152, 34.417488302503315, 0.5349743249160903, 9.033234868730817, 21.46618161882673, 0.7076544846807207, 0.9751248466117042, 0.2596771429691996, 0.18079001030751637, 0.2419965559882777, 0.6678282788821629, 0.708140532885279, 5.024480811187199, 13.98573625087738, 49.73056411743164, 84.55603327069963, 101.63771397726876, 78.25498989650181, 97.18415491921562, 129.0541730608259, 44.95485183170864, 38.385979720524375, 47.400885241372244, 67.81924029758999, 82.39869403839111, 85.44652829851422, 70.88749531337193, 3.6630785720688954, 0.3394260693873678, 0.22015967060412678, 0.21459614485502243, 0.12742452030735357, 0.12632838769682816, 0.20995974221399852, 0.11639185303023883, 0.16751772963574954, 0.07490818295627832, 0.061984567503843985, 0.14344714768230915, 0.1811245009303093, 0.15225599786000593, 0.3665401116013527, 0.16262417579335825, 0.16795045855854238, 0.10641784965991974, 0.19961046826626572], [0.11986493452319077, 0.08134051172861032, 0.06212016594197069, 0.039283496527267356, 0.04899671174851911, 0.04096685369898166, 0.10312576059784208, 0.0857981000361698, 0.05985400825738907, 0.04803090535902551, 0.05872008124632495, 0.01216224572687809, 0.019151108073336736, 0.05552998278290033, 0.03221215061577303, 0.07259773050567933, 2.1938802429607938, 67.3160378592355, 73.39613546643938, 65.99526868547711, 50.895196846553254, 44.42197363717215, 43.620822020939414, 75.9597567149571, 69.29165390559605, 78.31691919054303, 104.66544709886823, 97.64372961861747, 97.86889294215611, 53.44906282424927, 3.1319821562085832, 0.06607302597590856, 0.0697519342814173, 0.12205228715070657, 0.3854401617177895, 0.43098174940262524, 0.22666555935783045, 0.21447137583579334, 0.3090956083365849, 0.59381574179445, 0.8281427621841431, 0.26269781802381786, 6.5128457461084635, 63.09898158482143, 97.00229971749442, 87.03838838849748, 85.71736907958984, 72.90044403076172, 73.54795360565186, 76.50589207240513, 77.95583520616803, 75.62010097503662, 81.68341868264335, 84.71775954110282, 86.26806940351213, 83.51863942827497, 89.27818189348493, 79.45608329772949, 79.4612180164882, 73.0514144897461, 72.36969198499406, 67.3933504649571, 67.13591970716203, 63.24181570325579, 64.91669287000383, 61.46307686397007, 64.32417133876255, 64.64383016313825, 67.19799491337368, 69.07892090933663, 71.18448216574532, 77.63109724862235, 74.33568477630615, 66.08795765468052, 71.49202333177838, 67.85186903817313, 74.17709214346749, 69.92888014657157, 66.699551991054, 60.78588458469936, 67.17534378596714, 60.45940957750593, 62.39692170279366, 50.66350221633911, 43.930465017046245, 42.817947251456125, 50.640541894095286, 52.956449440547395, 34.78955738885062, 41.94158485957554, 61.3938102722168, 65.90424033573696, 62.25261456625802, 65.93489578792027, 71.6613439832415, 74.48324366978237, 71.8034485408238, 63.55096885136196, 62.498268127441406, 41.04963418415615, 47.782403877803254, 62.66250964573452, 59.7376515524728, 66.6587243761335, 65.09467792510986, 65.29605756487165, 65.55939429146903, 68.42631830487932, 66.67695644923619, 65.31220517839704, 64.41273307800293, 57.70739139829363, 53.52417285101754, 46.89330891200474, 46.49406542096819, 57.608216285705566, 58.87949344090053, 61.302747181483674, 60.85287911551339, 63.62999071393694, 67.36830220903668, 72.37986414773124, 75.79464667184013, 71.4173093523298, 65.32734530312675, 71.92643165588379, 71.54417651040214, 72.53835950578961, 71.36286326817104, 64.97507858276367, 54.29936947141375, 53.465943472726, 3.2248765315328325, 1.031903354184968, 3.8652099200657437, 2.702497716460909, 0.19019954039582185, 0.14853960728006704, 0.0907249835186771, 0.21608402287321432, 0.22451437264680862, 0.21673889059041226, 0.1733104916555541, 1.81796424303736, 1.1582538485527039, 25.15986657142639, 62.020405769348145, 84.20633738381522, 73.46512413024902, 70.54728371756417, 70.56878839220319, 24.24534640993391, 23.73845100402832, 33.23299067361014, 53.41015638623919, 56.954408168792725, 65.04105867658342, 26.481521640505107, 1.067193906222071, 0.06729488434003932, 0.03397924579413874, 0.06476861704140902, 0.1372323233102049, 0.0707307414018682, 0.11324634788823978, 0.0732950202322432, 0.027597316906654408, 0.025230057504294173, 0.08529076618807656, 0.02487302934085684, 0.09151289838233165, 0.0621316060423851, 0.020867508204121674, 0.10308242256620101, 0.10462208637701613, 0.1610012421650546, 0.08614077379128762, 0.041460569349250624, 0.038548079918005636, 0.05873213881360633, 0.061063951546592374, 0.07562167609908751, 0.0526657134427556, 0.06481667767677989, 0.05817711752440248, 0.0987256509917123, 0.02526421665347048, 0.05512921285948583, 0.07468253613582679, 0.060160970714475424, 0.09088933827089411, 0.2067781322236572, 3.2510408418519154, 79.04185949053083, 80.99670042310441, 79.76237378801618, 75.9503002166748, 61.916835921151296, 58.61876228877476, 40.8923373903547, 37.851618085588726, 91.95225170680455, 108.40961592538017, 108.72414003099713, 104.14006601061139, 65.18464320046562, 2.510758702244077, 0.06231157388538122, 0.07499026533748422, 0.17163361449326786, 1.354372073497091, 0.36447446101478165, 0.6650914485965456, 0.635437079838344, 1.4281050541571207, 2.683627711875098, 1.1628733149596622, 0.22192236887557165, 9.554103102002825, 72.04307801382882, 102.20493711744035, 91.22457381657192, 87.91984380994523, 76.62726320539201, 76.39952904837472, 81.21531159537179, 82.3993193762643, 80.89520113808769, 85.31793798719133, 87.61064897264752, 88.67507825578961, 89.58004638126918, 90.24673298427037, 81.90794277191162, 82.62626838684082, 73.74722099304199, 73.96208013807023, 69.23003033229283, 69.54044805254254, 65.2206974029541, 68.33950751168388, 65.0547605242048, 67.94494710649762, 67.616776738848, 71.10429995400565, 73.06980637141636, 76.17941706521171, 80.5353330884661, 76.88709803989956, 70.37813677106584, 74.4660746710641, 73.15295546395438, 77.61203139168876, 73.28172642844063, 72.15552765982491, 66.4670444216047, 72.16141973223004, 63.62648187364851, 68.45813410622733, 54.83668756484985, 49.82601499557495, 49.17460400717599, 58.044639587402344, 54.928118910108296, 36.69141483306885, 45.82422086170742, 64.38960252489362, 68.55579798562187, 65.47231946672711, 68.5141157422747, 74.25598199026925, 74.77934115273612, 76.47308962685722, 68.18693896702358, 67.7825677054269, 50.33227811540876, 59.491205896650044, 68.05276925223214, 66.34029538290841, 72.09161118098667, 70.8377879006522, 68.7986375263759, 69.34296635219029, 73.5066465650286, 70.60369614192417, 67.64748777662004, 67.49674660818917, 64.60139751434326, 61.788419314793174, 58.8855105808803, 55.95818240301949, 60.43506308964321, 63.913122858319966, 64.69385024479458, 67.48150226048061, 67.29862567356655, 69.72201142992292, 73.62580122266496, 79.55571351732526, 74.5088199887957, 69.15413515908378, 74.50760405404228, 76.2113092967442, 78.07396847861153, 78.0178061894008, 72.92281028202602, 61.450688225882395, 64.65496117728097, 6.211207074778421, 0.7070243156382016, 2.1597283269677843, 4.5115704366139004, 0.312815717288426, 0.12366494775882789, 0.126035694831184, 0.19684395885893277, 0.12450196141643183, 0.35540844606501715, 0.09753236573721681, 1.4439406501395362, 0.4303915596434048, 27.98105754171099, 70.06824711390904, 87.98800563812256, 86.72498294285366, 63.93574619293213, 39.06802879061018, 25.77099190439497, 38.07167795726231, 45.96973351069859, 66.65463188716343, 66.512784412929, 75.71033028193882, 34.89396449497768, 0.693788431584835, 0.060104197689465115, 0.04542417737788387, 0.07005779751177345, 0.03737808198535016, 0.04560877282970718, 0.06729051457451922, 0.10819998795964889, 0.042539043085915704, 0.03900397402633514, 0.1093698094731995, 0.006874345991361354, 0.03653720407081502, 0.06672390390719686, 0.03491133917123079, 0.01636230030895344, 0.1438729012651103, 0.16223133115896157, 0.1919901535979339, 0.09488414533968483, 0.08609608547495944, 0.19262085189776762, 0.11433116932000432, 0.1386659185269049, 0.12601356101887567, 0.13132843082504614, 0.13782756136996405, 0.2192874274083546, 0.2315293662250042, 0.18616564970995697, 0.177536136337689, 0.1745238886880023, 0.24602531694940158, 0.5545459347111839, 5.905301340988704, 99.97324521200997, 91.67434460776192, 90.34677314758301, 66.88190051487514, 59.06752559116909, 52.60482890265328, 100.8631010055542, 97.98049490792411, 105.99217782701764, 122.29942621503557, 117.26665142604283, 110.8784567969186, 79.28531742095947, 8.636372872761317, 0.39098778260605677, 0.1631095183214971, 0.28900676486747606, 0.8441934809088707, 0.7164219170808792, 1.2094097435474396, 1.1524023796830858, 1.9210564025810786, 3.7783930471965244, 5.4387106980596265, 1.125688727412905, 10.651547619274684, 76.21594374520438, 107.8871044431414, 96.22330243246896, 93.096189226423, 78.60191345214844, 81.50922734396798, 84.21037428719657, 84.81780665261405, 82.47154590061733, 90.05683176858085, 93.88172476632255, 92.40776865822929, 92.53813770839146, 95.26541682652065, 85.29969201769147, 87.17159925188336, 79.05862549373082, 79.76734175000871, 73.88101550510952, 74.96724128723145, 67.91777965000698, 74.56018802097866, 68.54245744432721, 73.15791647774833, 72.06881414140973, 74.85754312787736, 79.0067641394479, 79.55609566824776, 83.64203943525041, 81.26402541569301, 76.55397360665458, 80.43567507607597, 76.43432562691825, 84.03337587629045, 75.96200793130058, 76.5272855758667, 72.3904948915754, 79.57238224574498, 70.56699575696672, 76.07480498722622, 64.19637312207902, 59.26513235909598, 57.00947264262608, 67.62526048932756, 66.95136165618896, 48.56553186689104, 60.069712911333355, 74.05516515459333, 73.92551871708461, 69.09781306130546, 72.98266901288713, 77.03128010886056, 78.46194893973214, 80.68042537144252, 70.39289474487305, 72.96830708639962, 55.110578605106895, 60.656967708042686, 72.56465148925781, 67.06707000732422, 75.16909340449742, 74.22509029933384, 73.48345347813198, 74.30442483084542, 79.0574790409633, 73.68031678880963, 71.82203497205461, 71.76031412397111, 68.9897894178118, 68.74428871699742, 63.28178868974958, 64.27984877995083, 69.20232786451066, 67.18400124141148, 68.53596087864467, 69.60017476763043, 72.47339384896415, 74.3424870627267, 77.67705263410295, 80.49654129573277, 78.44747584206718, 71.78121430533272, 79.81864030020577, 77.76683030809674, 81.14078521728516, 81.65176963806152, 76.51514707292829, 64.25892775399345, 73.01707649230957, 9.025693467685155, 2.9519749581813812, 9.19748159817287, 6.762602652822222, 1.1051112030233656, 0.3283603845962456, 0.17366520262190274, 0.3652972797197955, 0.37304392403789927, 0.37457182205149103, 0.2246315556445292, 2.5468574166297913, 5.058830533708845, 41.72590582711356, 76.78357682909284, 98.43367031642369, 89.88645499093192, 100.28806809016636, 94.77524226052421, 29.847091811043875, 32.83237838745117, 44.24580206189837, 72.45188917432512, 74.32548482077462, 83.20132909502301, 52.949744428907124, 1.1490828778062547, 0.16863890018846306, 0.11434487572738103, 0.18761874602309295, 0.1987752052290099, 0.15290718791740282, 0.10554137919098139, 0.15308983597372258, 0.0443644787051848, 0.12656248227826186, 0.13588666623192175, 0.05893576717270272, 0.17309705168008804, 0.14377276306705816, 0.08763480612209865, 0.16491970047354698, 0.22345064686877386, 0.24754170700907707], [0.14584908022412232, 0.06615698111376592, 0.03387754696554371, 0.14907783482755932, 0.0511500290594995, 0.06342683439808232, 0.08080677608294146, 0.19579872994550637, 0.05297592268990619, 0.04497991335977401, 0.06554043705442122, 0.04841420300570982, 0.0525784572320325, 0.04096751866329994, 0.03988738251583917, 0.31964590506894247, 14.033416526658193, 91.27503163473946, 69.89820384979248, 60.118600436619346, 29.50324978147234, 31.709441798073904, 40.6517699105399, 72.23873233795166, 74.03086730412075, 86.63125174386161, 91.98387990679059, 88.4227544239589, 52.32553563799177, 4.057509132793971, 0.3525066503456661, 0.18266485684684344, 0.08412933136735644, 0.1685636913669961, 0.2840107115251677, 0.2581280203802245, 0.408520801791123, 0.28709207475185394, 0.9056358582207135, 2.213884323835373, 0.2285041314150606, 1.4014301598072052, 29.90788507461548, 86.58788803645542, 91.65192971910749, 90.13746561322893, 80.58059365408761, 79.5152541569301, 78.70451055254254, 81.86873408726284, 84.78948579515729, 85.29308428083147, 85.95647048950195, 85.90799985613141, 85.68737370627267, 86.53891713278634, 81.67727647508893, 76.42088781084333, 70.59062658037458, 66.32170895167759, 65.6313567842756, 65.02568926130022, 63.76238863808768, 62.90753786904471, 65.0832828794207, 68.66578796931675, 61.5904859815325, 66.04127270834786, 66.87251349857875, 72.92392199380058, 72.89488547188895, 82.65993240901402, 71.4651129586356, 63.30530139378139, 71.74406228746686, 71.12914671216691, 71.17250347137451, 67.19347163609096, 67.0497967856271, 61.51721027919224, 63.92115497589111, 59.577669279915945, 59.878693035670686, 46.19273247037615, 40.53722538266863, 50.96167026247297, 52.366203444344656, 35.09789759772164, 27.664242267608643, 23.723364727837698, 35.87542186464582, 58.70503112248012, 66.0880479812622, 60.550250325884136, 65.6342750276838, 72.63848999568394, 72.05125604357038, 67.41454247065953, 58.121698583875386, 46.23345238821847, 58.373817443847656, 64.76950223105294, 69.35145705086845, 67.19893292018345, 69.62977409362793, 65.17854963030133, 69.90824399675641, 67.57208592551095, 65.66615336281913, 66.31576129368374, 65.18897192818778, 59.26242256164551, 56.78760276521955, 52.274018219539094, 46.26885346003941, 47.89070544924055, 58.22499745232718, 58.94982310703823, 66.23173672812325, 58.60470608302525, 63.06929193224226, 67.02078110831124, 71.612685748509, 69.48011684417725, 70.59573350633893, 67.89494786943708, 76.71979931422642, 72.43168381282261, 66.09127194540841, 66.03081566946847, 58.009429591042654, 59.187326431274414, 20.274089608873638, 0.36634567060640877, 0.9276492169925145, 2.0638753218310217, 0.08381911872753076, 0.08585049651030983, 0.30919589581234114, 0.2012578427259411, 0.08024463696139199, 0.23440250062516757, 0.3592242827372891, 1.3571789285966327, 0.44581846041338785, 0.4193474251244749, 38.270900181361604, 67.51026780264718, 78.31599508013043, 63.777556555611746, 60.253659520830425, 72.96557644435337, 22.472054958343506, 27.338635785239084, 20.958117178508214, 54.096134662628174, 62.73017815181187, 52.59779385157994, 34.371164662497385, 3.4944140911102295, 0.13527287702475274, 0.028941791637667587, 0.024043075840121934, 0.20742442325821944, 0.10402982030063868, 0.050845770564462454, 0.1398538297840527, 0.03730263228395155, 0.09356821488056864, 0.06639226991683245, 0.015552706251453077, 0.11572635945464883, 0.049143309239298105, 0.03157621741827045, 0.004365851221206997, 0.1659019613372428, 0.13952859437891416, 0.050158696182604344, 0.02757374629644411, 0.10363968980631658, 0.011086601481240774, 0.04964821393202458, 0.07996911103171961, 0.11502627416380815, 0.07258460085306849, 0.17915445592786583, 0.01527427788823843, 0.10934500901826791, 0.02869044869605984, 0.12189182718949658, 0.3155486120709351, 0.3550234724368368, 19.37793527330671, 100.28013324737549, 79.7456077848162, 68.71230615888322, 39.04947362627302, 43.03556483132498, 24.07901348386492, 43.053188937050955, 79.4735163279942, 94.31298555646623, 98.87434591565813, 97.8655230658395, 60.599478312901084, 2.913414193051202, 0.2902393101581505, 0.12432828359305859, 0.040119702728199105, 0.18021929450333118, 0.3588841195617403, 0.26858796338949886, 0.536064974963665, 0.47477529517241884, 1.2528904846736362, 2.8235001606600623, 0.44053611957601135, 1.638797668474061, 35.48876503535679, 92.07167039598737, 94.03104850224086, 94.7264381136213, 83.24357414245605, 83.7099163872855, 84.22566032409668, 87.08257893153599, 88.76297296796525, 87.64629323141915, 90.76080935341972, 89.39500195639474, 88.58605098724365, 88.7252095086234, 84.8217671258109, 79.4866692679269, 73.95974554334367, 70.44920989445278, 67.51037202562604, 68.48397445678711, 67.62950583866665, 65.77382959638322, 68.50156034742082, 71.11937059674943, 68.28390107836042, 71.13142572130475, 72.78173405783517, 75.46292577471051, 78.00673076084682, 82.57580362047467, 72.84575475965227, 68.77142143249512, 76.28397355760846, 74.37519223349435, 76.2860163279942, 69.3544864654541, 70.44950866699219, 65.36879825592041, 67.11046845572335, 63.652676582336426, 65.1627424785069, 56.454002380371094, 51.78098794392177, 54.62791156768799, 56.91091591971261, 45.25138010297503, 38.87392044067383, 29.739912373679026, 41.274352822984966, 62.19700813293457, 68.71719074249268, 60.629536220005576, 68.53995609283447, 71.60310418265206, 74.5745291028704, 70.310391834804, 64.63415132250104, 59.5719370160784, 65.84438855307442, 69.5609382901873, 71.05918530055455, 70.54886790684291, 72.95864214215959, 68.56305885314941, 73.17425169263566, 71.44963932037354, 70.922180720738, 69.05661719185966, 69.83419009617397, 63.05028166089739, 63.03564875466483, 61.53156525748116, 57.19568089076451, 56.412816933223176, 62.50381973811558, 63.95142132895333, 69.91367053985596, 63.10048934391567, 67.78747313363212, 71.14780957358224, 74.09071213858468, 71.93657602582658, 72.04029178619385, 72.07785374777657, 78.78751373291016, 77.22694138118199, 72.11927890777588, 72.19646644592285, 65.63130119868687, 66.1170289175851, 27.012537717819214, 0.7947472227471215, 0.30881936315979275, 1.101915357368333, 0.08757575321942568, 0.11749295251710073, 0.7963871604629925, 0.1164929276066167, 0.04152480965214116, 0.12077784910798073, 0.15059437416493893, 2.707782907145364, 0.25918908630098614, 0.4393769103501524, 42.64648655482701, 73.27293000902448, 82.1563686643328, 72.45555782318115, 43.61708389009748, 28.42253565788269, 29.671969413757324, 40.266777174813406, 37.58021102632795, 59.911981855119976, 71.00919301169259, 61.09054919651577, 42.97783572333199, 2.714028252022607, 0.08413615742964403, 0.040467065160295794, 0.10930336053882327, 0.07157424863960062, 0.022412554493972232, 0.10926450083830527, 0.05574982812894242, 0.0359657520561346, 0.10559738547142063, 0.06508849201990025, 0.021649926934125166, 0.07520310141678367, 0.10521629306354693, 0.07937990514827625, 0.03601491191823568, 0.08522618322500161, 0.1760212526257549, 0.11652544300471034, 0.14918469052229608, 0.28869013328637394, 0.1688000386846917, 0.16406569629907608, 0.23918516827481134, 0.3595909902027675, 0.10548738137419734, 0.2540181880550725, 0.13864664813237532, 0.24085311591625214, 0.25236332256879124, 0.24839193852884428, 0.469727483178888, 0.5570614540151188, 29.44929701941354, 117.16736166817802, 90.62269306182861, 81.43925203595842, 40.579598971775596, 39.59973621368408, 54.772263867514475, 102.49035521915981, 99.78595651899064, 101.56971890585763, 111.5206023624965, 106.90750571659633, 76.94894395555768, 7.608847209385463, 1.0187281583036696, 0.29673180463058607, 0.24835877173713275, 0.24615293581570896, 0.8223100208810398, 0.7068024618285043, 0.8611939315285001, 1.965068246637072, 3.407311256442751, 6.862014004162379, 3.092599549463817, 1.7038754735674178, 38.21268122536795, 100.52964305877686, 102.46864904676164, 99.95650005340576, 87.49463490077427, 87.32106889997209, 86.59800461360386, 89.63648659842355, 91.03094141823905, 90.96468339647565, 93.10511071341378, 93.32644557952881, 91.93741730281285, 94.02794960566929, 89.76975304739815, 82.98003591809953, 77.6495030266898, 75.70971189226422, 70.48957892826625, 72.9185232434954, 69.90415845598493, 70.3000042779105, 72.8193029676165, 74.98439638955253, 69.12511948176792, 74.10651929037911, 77.07489395141602, 77.72908769335065, 82.97271251678467, 85.10559409005302, 77.3319286618914, 72.31553772517613, 80.25180489676339, 81.06455653054374, 82.56531878880092, 74.77438708714077, 75.08584008898053, 71.46952506474086, 73.27695996420724, 72.59443146841866, 71.53615828922817, 60.89235183170864, 54.914722783224924, 60.30595166342599, 61.621787616184776, 49.40195253917149, 41.51957906995501, 37.53138256072998, 50.10118103027344, 71.65487521035331, 70.93167196001325, 64.53785623822893, 71.1463851928711, 77.44269684382847, 77.23856571742466, 72.0652219227382, 70.18972941807338, 63.20396191733224, 66.13425350189209, 72.40100751604352, 75.3161311830793, 75.16001210893903, 75.90352494376046, 73.46246991838727, 76.4031560080392, 75.11006150926862, 74.82515062604631, 74.93872588021415, 74.24177292415074, 68.27556324005127, 68.84600339617047, 66.50730923243931, 61.815552030290874, 65.42181301116943, 70.98884173801967, 67.51387391771588, 74.85634803771973, 65.33424486432756, 69.61802468981061, 74.7473724910191, 76.2808816092355, 74.30049215044293, 75.10696261269706, 72.84193325042725, 81.2471204485212, 80.25746767861503, 75.01418331691197, 76.99991594042096, 67.63771166120256, 71.94866589137486, 32.911410672324045, 0.8473392235381263, 1.0145662959132875, 3.54617925626891, 0.5677981578877994, 0.40428685184035984, 1.0933433430535453, 0.3052007901881422, 0.10931371498320784, 0.5362737466182027, 0.5566871198160308, 3.479076159851892, 0.5688387591923986, 1.6231706270149775, 56.01475463594709, 81.38164452144078, 94.82718699319022, 75.64414174216134, 88.29761736733573, 95.81007916586739, 31.67159148624965, 37.450821672167095, 35.24687392371041, 68.8170919418335, 80.39511844090053, 72.8532657623291, 64.14176028115409, 6.811711651938302, 0.22768019991261618, 0.2004175992416484, 0.15924490855208465, 0.3011702378945691, 0.10997247070606266, 0.25685131603053635, 0.2190471174461501, 0.11298539689076798, 0.12162566504308156, 0.2122269719839096, 0.09292867526944194, 0.15710250208420412, 0.09403012080916337, 0.21170768913413796, 0.09445705504289695, 0.1945481491940362], [0.023010113143495152, 0.10997793291296278, 0.12511556063379559, 0.029694232690547193, 0.04107103935842003, 0.06028001968349729, 0.049611596789743216, 0.05337570534486856, 0.0684657304414681, 0.04948513482564262, 0.06821900153798716, 0.08705444833529846, 0.036400224813925366, 0.025172332833920206, 0.10592895839363337, 0.15481156430074147, 48.28050981249128, 76.23247350965227, 68.70819977351597, 59.84092262813023, 63.31327792576381, 48.74066121237618, 75.81354577200753, 57.25206899642944, 80.64220333099365, 102.30016912732805, 89.39954607827323, 48.613957336970735, 3.851749522345407, 0.5773605619158063, 0.08764289425952093, 0.16053496647093976, 0.022978657956368158, 0.5334352446453912, 2.0969554781913757, 0.24544438240783556, 0.3288458085485867, 0.4524017428713185, 0.48058637763772694, 1.8462429770401545, 0.16776543562965734, 3.862349433558328, 53.74337462016514, 92.11884866441999, 87.64821093423026, 86.32785170418876, 82.13139683859688, 81.62587370191301, 85.63365718296596, 85.44319316319057, 87.5846140725272, 86.10271617344448, 84.44216619219098, 83.79310716901506, 81.8939768927438, 78.65394851139614, 74.2535709653582, 71.45038972582135, 65.16948223114014, 65.11215264456612, 64.25300094059536, 65.57215118408203, 67.92139966147286, 69.15476744515556, 66.6967796598162, 66.78161021641323, 67.5297019141061, 68.96347658974784, 74.40265846252441, 73.64187935420445, 73.74508789607457, 79.36772305624825, 63.53181961604527, 66.02181080409459, 66.08426121303013, 68.99661949702671, 64.35690430232457, 62.779232433864046, 64.7972811290196, 68.03150081634521, 60.511910166059224, 59.31206744057791, 58.423045430864605, 62.65242086138044, 52.95405926023211, 61.88798700060163, 69.58442320142473, 60.64485699789864, 68.66548224857875, 45.71902166094099, 38.29279048102242, 46.21641540527344, 53.581992285592214, 55.50284610475813, 63.98865672520229, 71.00068146841866, 66.36238370622907, 70.34878063201904, 58.16667774745396, 61.4350061416626, 65.69689914158413, 68.4970509665353, 67.8635003226144, 67.61127376556396, 69.19379547664097, 63.9103227342878, 65.65446649278913, 70.20705822535923, 68.93833105904716, 65.3170063836234, 65.67842388153076, 60.36375372750418, 54.82995128631592, 59.571659088134766, 53.15142284120832, 48.205444949013845, 50.53550945009504, 58.109184878213064, 62.147592544555664, 62.83448450905936, 60.65533488137381, 61.40020261492048, 66.46563393729073, 65.2955572945731, 66.53349699292863, 71.40211364201137, 74.35505635397774, 72.52310820988247, 69.209150995527, 60.67881979261126, 58.520486967904226, 51.489733355385916, 36.01948234013149, 0.3863896221986839, 0.376061559255634, 0.14442650441612515, 0.21958864267383302, 0.10005333367735147, 0.13751699589192867, 0.13942918899868215, 0.21142237872949668, 0.13008763454854488, 0.15185685642063618, 1.384792915412358, 0.9969071234975542, 0.11822568891303879, 2.3547627414975847, 69.71140153067452, 76.13307258061, 82.20436682019914, 73.70368358067104, 69.920549256461, 42.932613372802734, 21.377989871161326, 22.487512963158743, 30.610247203281947, 56.39094747815813, 68.7345403943743, 60.66713292258126, 57.02850028446743, 5.603776880672999, 0.10466051181512219, 0.11775288571204458, 0.1577806571232421, 0.0692500015720725, 0.021684935948412334, 0.047703814160610945, 0.032854160094367604, 0.08812751754054002, 0.057783180448625765, 0.0989671755316002, 0.195949826123459, 0.07578618012900863, 0.09615406433918647, 0.17962656702314103, 0.17216616948800428, 0.005617627890647522, 0.05053982590990407, 0.05331473897344299, 0.027676021879804984, 0.021563576567651968, 0.0697616780442851, 0.037505337835422585, 0.0907359825713294, 0.07803947278963667, 0.04851961342085685, 0.04792963740016733, 0.03972223727032542, 0.1159074604511261, 0.020076466990368705, 0.039785120503178666, 0.11715719981917314, 56.14672177178519, 87.31289781842912, 77.85725416455949, 78.8199826649257, 67.0099766595023, 37.879511628832134, 28.684088434491837, 55.83507422038487, 90.61543219430106, 108.37481239863804, 99.69440705435616, 60.02159663609096, 3.958136430808476, 0.33437814882823397, 0.07157547678798437, 0.1558902585612876, 0.07034118766231195, 0.2828187426286084, 0.6989611483045987, 0.9741697950022561, 0.21529224035995348, 0.29722767802221434, 0.7837254256010056, 1.4078069776296616, 0.7292062225086349, 4.3168454340526035, 57.720266410282676, 98.3772439956665, 92.30149596078056, 91.51290321350098, 86.69124943869454, 84.20207118988037, 89.91355296543666, 89.27890450613839, 90.29523835863385, 89.40848840985979, 85.06959547315324, 88.23379121507917, 85.26774420057023, 82.15460382189069, 78.26849719456264, 74.93650245666504, 67.60679912567139, 66.66347694396973, 69.02332837241036, 68.2437196459089, 70.62198380061558, 73.01468631199428, 70.050598689488, 71.9660085950579, 71.55500875200543, 72.72085394178117, 77.97447027478898, 78.18541758401054, 77.77999714442662, 79.72147669110979, 65.69526631491524, 68.53118746621269, 70.44725050245012, 70.95717184884208, 63.70862347739083, 63.70344706944057, 66.98974350520542, 68.25570528847831, 63.035829407828196, 62.739537375313894, 63.44987951006208, 65.64438465663365, 59.655773980276926, 66.6963975088937, 72.15157413482666, 65.75326987675258, 67.16696425846645, 53.68283496584211, 48.20706387928554, 51.58744587217058, 56.83456563949585, 57.79543202263968, 64.32506070818219, 71.31213447025844, 69.88678101130894, 70.46390533447266, 69.17047732216972, 71.98100975581578, 69.81280354091099, 71.35033566611153, 73.42449106488908, 70.39883545466832, 72.65252535683769, 67.93839495522636, 67.50642544882638, 73.14404787336076, 72.2441658292498, 70.86250959123883, 67.78306102752686, 65.4783991404942, 60.23579570225307, 65.40932015010289, 61.28061022077288, 59.001149450029644, 56.40386765343802, 61.85584463391985, 66.01753071376255, 67.87864739554269, 63.970035552978516, 64.67194952283586, 69.69294711521694, 68.07406548091343, 70.13009997776577, 74.99348463330949, 77.38887609754289, 74.36105959756034, 76.95461368560791, 69.44729355403355, 68.52920028141567, 58.92958995274135, 43.90445443562099, 1.6662370818001884, 0.8575081293072019, 0.11192838860941784, 0.22965905229960168, 0.46380550095013207, 0.127287144107478, 0.04494733350085361, 0.1721839199640921, 0.06328325638813631, 0.1755160697336708, 1.9673715744699751, 1.0173401470695222, 0.3288018394793783, 2.8376037010124753, 74.5566096987043, 81.59347425188336, 89.66981710706438, 77.65634005410331, 48.71811430794852, 20.830873080662318, 31.0861953326634, 31.902035440717423, 46.111212730407715, 70.9133426121303, 81.18806770869664, 71.35076645442417, 67.25388622283936, 4.433226457663944, 0.19003707197095665, 0.04376825337697353, 0.09345139150640794, 0.039949895947107246, 0.0345172392470496, 0.04736277906756316, 0.08151294783289943, 0.06667991448193789, 0.0539119549627815, 0.10546747994210039, 0.09365605802408286, 0.12561657732086523, 0.06193839319582496, 0.06356679581637893, 0.09840283795659031, 0.10164118025984083, 0.22230918811900274, 0.1643357260950974, 0.1021523071186883, 0.14040037617087364, 0.10712349215256316, 0.1985235908733947, 0.09293723838137728, 0.15442321156816824, 0.11678156283284936, 0.14834507129022054, 0.1119166092414941, 0.14286001133067266, 0.10052632008280073, 0.26774671567337854, 0.2719499415584973, 75.52979523794991, 97.10738427298409, 89.14452634538922, 81.32913698468889, 84.63365854535783, 68.58711351667131, 104.60342747824532, 84.91748550959996, 97.97128159659249, 127.30196244376046, 111.48647975921631, 74.72845949445451, 8.316883410726275, 0.770549795457295, 0.14448960817285947, 0.28624227749449865, 0.1282858255186251, 1.5708205103874207, 8.308303253991262, 2.4446722141333987, 1.3826492875814438, 1.5354528767721993, 4.562497692448752, 6.394473629338401, 2.329812628882272, 4.824317974703653, 61.448749678475515, 103.32376384735107, 100.63696493421281, 97.08143275124687, 89.97310597555978, 89.06188447134835, 94.8053765978132, 94.27733434949602, 91.42017255510602, 93.53259863172258, 89.21398748670305, 92.69101892198834, 88.2191583088466, 87.07600593566895, 80.08152539389474, 78.93265465327671, 72.72012438092912, 73.08525916508266, 70.81112766265869, 73.4709814616612, 73.52465629577637, 77.29776436941964, 74.10695007869175, 75.9221739087786, 75.00358731406075, 78.69827107020787, 81.84806319645473, 84.49636214120048, 79.92467675890241, 82.04021562848772, 69.9848826272147, 75.17253276279995, 74.9266221182687, 76.79299858638218, 69.3630188533238, 71.55205576760429, 72.9385757446289, 72.97079454149518, 69.0280670438494, 68.31621020180839, 67.57761669158936, 70.96753856113979, 60.92647443498884, 73.02153723580497, 80.92318848201207, 70.28038256508964, 72.13800430297852, 54.66813816343035, 50.189829621996196, 54.43884413582938, 61.38464559827532, 60.02423695155552, 67.47396346500942, 75.85627024514335, 71.74643162318638, 74.66616889408657, 74.81629862104143, 71.83321462358747, 71.64430005209786, 73.70795672280448, 74.20840767451695, 73.67869785853794, 75.95895072392055, 71.13467747824532, 71.98986176082066, 77.09516184670585, 74.9510589327131, 74.6373269217355, 72.69481209346226, 69.20159135546002, 65.14458683558873, 71.41519015175956, 67.03688703264508, 65.9100420815604, 67.15433243342808, 70.89342212677002, 70.77323913574219, 70.67140633719308, 68.82766015189034, 68.95452730996269, 74.33632401057652, 70.98310252598354, 74.60662978036063, 79.4702159336635, 80.86590753282819, 75.70044299534389, 78.07112666538784, 72.40104225703648, 73.02500438690186, 60.50459371294294, 52.54907308306013, 2.797826132604054, 0.9998719415494374, 0.42260678165725296, 0.4442020542919636, 0.6130817394171442, 0.3099691000367914, 0.44221307816249983, 0.22163625779960835, 0.2765718778329236, 0.3539286697549479, 2.5814247046198164, 1.3753359828676497, 0.327960374632052, 2.9843704998493195, 83.45618207114083, 91.18747738429478, 96.40636662074498, 93.90606430598667, 106.46084771837506, 56.27766057423183, 30.148143359592982, 32.22277123587472, 48.010909284864155, 74.9003301348005, 90.43115901947021, 75.70179094587053, 87.41551576341901, 9.433254820959908, 0.3111661172338894, 0.2174155664231096, 0.2444437603865351, 0.18029501901141234, 0.13946421497634479, 0.12654542390789303, 0.12627732115132467, 0.2209913781178849, 0.23747268159474644, 0.15583863561706884, 0.21642251685261726, 0.1685972245676177, 0.17440681425588472, 0.23696304751294, 0.27107612416148186], [0.07946687298161642, 0.03450397388743503, 0.13811961641269072, 0.08181643619069032, 0.05158882747803416, 0.0780578339472413, 0.13974971537079128, 0.0645471296406218, 0.04245168509493981, 0.16229049941258772, 0.09489564650825091, 0.06011000594922474, 0.0197157102770039, 0.05762364329504115, 0.0905756718878235, 5.0044092025075635, 64.6456366947719, 73.77927998134068, 63.7887362071446, 47.713460377284456, 30.833670003073557, 48.01765251159668, 48.91767699377877, 57.61909369059971, 96.04028688158307, 82.41995552607945, 56.776308468409944, 1.4941335682358061, 0.2868022860160896, 0.017841973142432313, 0.21129010511296137, 0.07696968769388539, 0.11079889921737568, 0.41564061545899933, 0.5151360237172672, 0.07301457492368561, 0.22025568330926554, 0.3676708766392299, 0.9313802910702569, 0.7346182721001762, 0.3025596061987536, 7.95754429272243, 52.76863963263375, 93.14786297934396, 83.7957683290754, 86.6720724105835, 85.29246589115688, 84.5522951398577, 87.85425281524658, 85.05123138427734, 85.11523818969727, 83.68101188114711, 81.46725327627999, 79.0683946609497, 78.35971314566476, 71.87760666438511, 70.2604203905378, 64.78499671391079, 63.68748010907854, 62.02869497026716, 65.36697087969098, 69.17760617392403, 72.94963727678571, 71.95986638750348, 69.10681792667934, 66.29742499760219, 69.3755464553833, 69.59600584847587, 69.19764477866036, 76.9449348449707, 84.03332029070172, 68.15999385288784, 63.41310964311872, 62.55368001120431, 60.73087569645473, 64.21625886644635, 63.55469308580671, 66.34892504555839, 71.06789139338902, 63.84608663831438, 62.236800466264995, 60.786711420331685, 60.512681416102815, 57.5240284374782, 62.14554282597133, 56.36447136742728, 55.10494014195034, 50.72267654963902, 45.848827907017295, 58.562745911734446, 57.84329816273281, 56.77409199305943, 54.047080380576, 56.410715103149414, 57.44096619742257, 62.59637669154576, 66.61943926130022, 69.74263368334088, 68.87023176465715, 76.05096571786063, 67.22161184038434, 72.55070645468575, 71.22166197640556, 70.57692473275321, 68.1129823412214, 72.25276769910539, 64.51540660858154, 67.56344931466239, 67.08917917524064, 68.25215475899833, 60.20306273869106, 62.66180787767683, 57.75949246542794, 61.979724066598074, 58.90222099849156, 56.33614008767264, 46.103305680411204, 54.83370678765433, 63.521953174046104, 63.845815658569336, 60.70286750793457, 59.05756187438965, 60.560207094464985, 64.5926010949271, 62.45325074877058, 68.44006184169224, 70.22059331621442, 71.3391421181815, 65.19691371917725, 66.08024515424455, 57.24698986325945, 52.687342235020225, 34.41490704672677, 4.589150547981262, 0.8477423276220049, 0.7169049797313554, 0.043047910423151085, 0.25109652483037537, 0.2296153817858015, 0.04461175722203084, 0.35616153851151466, 0.10857701594276087, 0.30906746270401136, 1.1032689533063342, 1.2170868515968323, 0.7183332688042096, 0.20651348999568395, 6.695272871426173, 62.872178486415315, 78.89409909929547, 77.77283355167934, 69.50349058423723, 79.53150599343437, 38.550391469682964, 20.78925337110247, 19.64280755179269, 37.609726973942344, 40.82019077028547, 58.34172371455601, 58.76679365975516, 56.29354068211147, 2.6285953734602248, 0.1141461328204189, 0.0691780090065939, 0.03716121880071504, 0.17029323641742977, 0.05282025657860296, 0.029038099505539452, 0.05954180072460856, 0.041622050505663664, 0.07181803270110063, 0.06188473464655025, 0.08335027817104544, 0.012149800546467304, 0.16707691257553442, 0.054982299849923165, 0.029959614521690776, 0.0542815970922155, 0.07576222105750016, 0.15727113160703862, 0.04588079751868333, 0.10468156675675086, 0.07802868408284017, 0.06379596423357725, 0.007518523389340511, 0.09437412449291774, 0.06395669560879469, 0.0570540131468858, 0.08222209156623908, 0.0603238937578031, 0.30552369143281666, 5.628139001982553, 75.94385228838239, 79.70674651009696, 81.574387550354, 62.08603845323835, 51.1609445980617, 45.63408688136509, 43.478957176208496, 70.15757315499442, 101.39185891832624, 90.23793656485421, 69.89414610181535, 2.07983945948737, 0.19110961870423385, 0.10274019664419548, 0.22069113994283335, 0.13467662116246565, 0.12174636285219874, 0.1865497955254146, 0.35203832547579494, 0.5354834975940841, 0.25820895603724886, 0.4606826113803046, 0.48053991155964987, 1.3787907574857985, 0.6344375706144741, 8.165288482393537, 58.28253548485892, 98.63035992213658, 87.89688001360211, 92.75585256304059, 90.08818204062325, 91.15115220206124, 91.62515136173793, 89.6616460255214, 86.40816593170166, 87.93834686279297, 85.41606739589146, 80.79816954476493, 79.83482265472412, 77.05624498639787, 72.76455116271973, 68.18726553235734, 66.82042980194092, 65.15549550737653, 67.39698437282017, 73.36839130946568, 76.7460218157087, 75.95156478881836, 71.19885798863002, 70.24821935381208, 72.44446155003139, 73.30903284890312, 74.67688996451241, 80.9606601170131, 83.78407451084682, 69.05855573926652, 66.93344920022147, 67.07734639304024, 65.5605685370309, 67.790023122515, 67.14751625061035, 69.78370448521206, 72.60030269622803, 68.45180429731096, 68.22210380009243, 65.90408052716936, 64.83733749389648, 63.22293049948556, 63.91484601157052, 61.19801698412214, 59.41640853881836, 53.1618903023856, 45.424588271549766, 60.38822528294155, 62.655818530491416, 64.7219626562936, 58.48708002907889, 59.75167996542794, 59.341972487313406, 64.26010199955532, 70.13068362644741, 73.59237343924386, 79.19235747201103, 78.37031609671456, 68.3221926007952, 72.13722610473633, 73.49359784807477, 74.0071461541312, 72.0418620790754, 73.85293088640485, 68.41415895734514, 72.72551618303571, 69.9773507799421, 71.04255131312779, 65.4287612097604, 66.5300715310233, 61.52222687857491, 66.38756397792271, 62.57163415636335, 62.378411701747346, 58.537371090480256, 60.49071816035679, 67.2657606942313, 66.23618357522147, 65.19471114022392, 61.67760249546596, 62.78314426967076, 66.56852286202567, 64.97142383030483, 71.98870141165597, 71.99360683986119, 75.74688475472587, 69.37859671456474, 71.34092085702079, 63.65112018585205, 62.35542011260986, 43.07780987875802, 7.86706919329507, 2.4563360682555606, 0.64203401442085, 0.25054978845374926, 0.3804288006254605, 0.7119934175695691, 0.07964302067245756, 0.23034730393971714, 0.07812918190445219, 0.40159287782652037, 0.7558246627449989, 1.6414691422666823, 0.537287423653262, 0.4009284834776606, 8.030419605118887, 68.6725138255528, 80.94598552158901, 86.4075197492327, 70.39563233511788, 45.98329986844744, 28.57977339199611, 32.776118823460166, 32.38071768624442, 48.48500919342041, 52.100869110652376, 64.97575950622559, 67.03068229130336, 66.67768601008824, 1.7848334951060159, 0.09289338466312204, 0.018294308334589005, 0.06312973105481692, 0.08838789178324596, 0.019650969554537108, 0.06514863057860307, 0.00722974567075393, 0.05103579768911004, 0.017128144124788896, 0.025527936073818376, 0.10852088752601828, 0.028266140392848423, 0.1789082834231002, 0.03950400683762772, 0.38312833862645285, 0.08913381211459637, 0.2425498063010829, 0.2804254139108317, 0.13580568986279623, 0.19477832184306212, 0.2045767746333565, 0.1265795270779303, 0.08909597700195653, 0.2662881910800934, 0.22762869910470077, 0.1858986597508192, 0.20029863848217896, 0.16737761215439864, 0.5459086181862014, 8.927026442119054, 94.77133737291608, 92.95184734889439, 89.33807536533901, 59.54635374886649, 44.26771668025425, 68.3248051234654, 72.04732336316789, 79.42998586382184, 117.18419020516532, 98.0010198865618, 85.65295233045305, 5.779974511691502, 0.32378700428775375, 0.39998398987310274, 0.38901921680995394, 0.29910000041127205, 0.6011824065021106, 1.0056517571210861, 1.6284793764352798, 1.2343869975634982, 1.1513972793306624, 1.7679286364998137, 5.182211867400578, 4.320330389908381, 1.8864157242434365, 8.060117942946297, 68.71621799468994, 103.24456827981132, 91.66745199475969, 98.34333678654262, 93.16576848711286, 93.79984719412667, 95.98463181086949, 91.70757784162248, 89.5999390738351, 90.47293853759766, 88.89405768258231, 85.29357760293144, 84.97462054661342, 82.03212792532784, 76.62746470315116, 74.37626920427594, 69.90617343357631, 67.94137573242188, 73.58789879935128, 77.65627752031598, 81.0273836680821, 79.10596357073102, 77.02251148223877, 74.6579144341605, 77.02695832933698, 78.65920829772949, 79.26924623761857, 83.5669641494751, 85.09004402160645, 76.38344396863664, 70.37108434949602, 70.81084973471505, 67.10724449157715, 69.11389814104352, 68.67026260920933, 74.28525475093296, 76.3708746773856, 72.9582530430385, 72.78381851741246, 68.50201198032924, 64.28771414075578, 62.20416477748326, 63.02927030835833, 63.43278694152832, 64.54991831098283, 59.15896388462612, 51.03816645486014, 62.67769145965576, 61.74941907610212, 64.7375613621303, 58.07359273093087, 59.93272917611258, 59.110597474234446, 69.24876267569405, 73.86295018877301, 79.43697575160435, 79.02623299189976, 79.86533219473702, 72.44656685420445, 78.8905416216169, 77.44535105569022, 78.32411752428327, 75.4501063483102, 77.34681170327323, 73.19086483546666, 76.5460318156651, 72.60881423950195, 73.9006928035191, 69.17805085863385, 72.29955686841691, 65.47013773236955, 72.01151929582868, 70.1404458454677, 70.74656500135148, 64.65578801291329, 68.13230528150285, 73.3524590900966, 71.22485814775739, 68.93996388571603, 67.42261627742222, 68.02875627790178, 71.6800068446568, 69.70046506609235, 75.29853834424699, 77.49917180197579, 77.88448415483747, 73.02800600869315, 74.14195510319301, 71.45808138166154, 65.8596259525844, 49.23890263693673, 14.211128864969526, 2.6967383112226213, 0.6191829091736248, 0.4720330908894539, 0.725177461547511, 1.2672110476664133, 0.11279837228357792, 0.860292837023735, 0.12093182227441243, 1.3130540677479334, 1.3595252484083176, 2.328881787402289, 1.3517543396779468, 0.7414082363247871, 9.045961362974984, 76.72929750170026, 90.70205538613456, 90.60688591003418, 89.97798361097063, 111.04978547777448, 47.598151547568186, 31.807116099766322, 31.0866539137704, 54.394062995910645, 59.1642028263637, 77.74663189479283, 72.7044700895037, 84.66777420043945, 4.098934727055686, 0.28152284930859295, 0.12187592232865946, 0.11129287271095173, 0.17647475829081877, 0.09895895168717418, 0.12058640723781926, 0.20407304380621227, 0.09743827328618083, 0.09297170796032463, 0.10570580179670028, 0.1862988189927169, 0.1128465754113027, 0.27750467349375996, 0.07213283902300255], [0.18503359545554432, 0.10166406046066966, 0.10791676744286503, 0.06039346395326512, 0.04097946427230324, 0.17184797727635928, 0.07881800351398331, 0.016513116591210877, 0.11443194534097399, 0.006739153826077069, 0.09948592233870711, 0.004621781059540808, 0.07458782621792384, 0.10289665324879543, 0.3039533985512597, 15.214175156184606, 73.26742008754185, 70.22342818123954, 54.9122804914202, 41.51256833757673, 52.85939005443028, 37.950438840048655, 45.436841419764924, 86.23394680023193, 93.22017983027867, 78.77627849578857, 3.516652452094214, 0.0770122046981539, 0.008729156239756515, 0.026586530430774604, 0.061069020203181675, 0.164561447554401, 0.07568199107689516, 0.04054187364610178, 0.10649021541965858, 0.18092817360801355, 0.052768626849034, 0.2562466056219169, 0.19751136590327534, 0.38522778025695253, 0.3536619783512184, 10.189633113997322, 55.353772503989084, 90.91516358511788, 94.66375146593366, 90.16281264168876, 88.24801417759487, 88.27717576708112, 85.66774504525321, 85.46874863760812, 82.98610169546944, 81.12893853868756, 76.56513936179024, 75.41961765289307, 72.56301171439034, 68.29776968274797, 63.39254297528948, 61.58513586861746, 61.0721503666469, 64.75264590127128, 63.17717661176409, 70.62203243800572, 74.61993558066231, 71.17100960867745, 66.83802264077323, 69.04017080579484, 67.58852536337716, 69.92132745470319, 78.55887631007603, 80.13415105002267, 67.19784205300468, 64.52741309574672, 66.89852060590471, 63.83228751591274, 68.33670043945312, 72.07886818477085, 74.31222765786308, 72.65633991786412, 70.36275345938546, 67.2303248814174, 70.9010443006243, 71.60331957680839, 69.79091671534947, 72.73626504625592, 65.35884843553815, 64.48757212502616, 58.88448224748884, 48.43566656112671, 45.23898104258946, 61.739337239946636, 65.8147405896868, 72.01723071507045, 65.70445878165108, 68.46881348746163, 62.106577328273225, 64.35174873897007, 60.421972683497835, 68.58656460898263, 83.64031628199986, 72.65756974901471, 64.0665043422154, 64.89602197919572, 61.207049642290386, 61.808555194309776, 61.49488571711949, 64.84554331643241, 63.17469610486712, 65.82888712201799, 67.72373730795724, 69.23053755078996, 63.99535478864397, 58.21500941685268, 56.44502878189087, 59.392242704119, 59.56516947065081, 58.236142362867085, 52.38130535398211, 52.441115447453086, 59.754327229091096, 62.72637748718262, 61.10903140476772, 60.217473302568706, 58.659610748291016, 58.06749568666731, 59.566322871616904, 65.88298579624721, 66.83307552337646, 68.75332832336426, 64.07992131369454, 63.29755415235247, 53.55888605117798, 57.29708637510027, 27.357135363987513, 10.830465470041547, 2.1959868499210904, 1.1645064673253467, 0.04227802762761712, 0.863635951919215, 0.03995069661842925, 0.3132162429392338, 0.17711734452417918, 0.558702965932233, 0.10875980649143457, 0.2912493773869106, 0.3756650776735374, 0.15542034591947282, 0.08701440119849783, 0.03557628991880587, 5.940285520894187, 60.86348206656319, 84.49586187090192, 73.42728424072266, 57.70079060963222, 61.536415100097656, 23.599200419017247, 25.148825883865356, 18.5964800630297, 48.85869721003941, 57.01351302010672, 47.10621908732823, 60.188735553196494, 39.16831908907209, 0.2831787461681025, 0.043552635304097614, 0.06898300482758454, 0.015174763942403453, 0.011272788945851582, 0.14468373704169477, 0.07408153731375933, 0.0751009751111269, 0.014988204131701162, 0.11050284760338919, 0.060568410637123246, 0.10313359767730747, 0.010879061367761875, 0.10744705157620565, 0.13013524056545325, 0.07774969762457268, 0.09829563620899405, 0.06514084099658898, 0.08443286043724843, 0.035714100381093364, 0.08656258508563042, 0.018509639726419534, 0.022653544687532952, 0.02810411131940782, 0.08327507613492863, 0.039754084311425686, 0.0668421114927956, 0.17008018999227456, 0.6393646576574871, 18.893326214381627, 83.71525955200195, 80.37039675031389, 66.73714174543107, 49.16958045959473, 47.08546134403774, 28.63000191961016, 51.64778750283377, 90.21215874808175, 96.88544491359166, 90.57024805886405, 6.702751738684518, 0.4577295726963452, 0.015257947246677108, 0.07711745905024664, 0.05210661076541458, 0.35284920196448055, 0.06922961838011231, 0.1565527394413948, 0.10439493999417339, 0.32603971340826576, 0.020913999727261916, 0.5121683829597065, 0.223408916965127, 0.5244796137724603, 0.41099702034677776, 11.635286603655134, 64.66945511954171, 96.421569279262, 97.6127267565046, 95.51415538787842, 92.4042111805507, 92.7390935080392, 88.82703535897392, 89.87943036215646, 86.84363038199288, 83.54496615273612, 79.89338902064732, 76.22804055895124, 73.80779538835797, 71.27518395015171, 66.79335267203194, 64.51506614685059, 65.10289764404297, 66.7026230948312, 66.40569182804653, 74.55537291935512, 76.28896931239537, 76.42965643746513, 68.3731437410627, 71.81567737034389, 71.19244480133057, 73.79591396876744, 81.5617904663086, 80.47432095663888, 69.32472038269043, 69.13668823242188, 69.72062179020473, 68.70895017896379, 71.8974437713623, 75.52951036180768, 75.44304003034318, 76.37390409197126, 71.81721292223249, 70.97757870810372, 73.547849382673, 75.30013642992292, 73.45798138209751, 74.9586602619716, 66.89148208073208, 66.47024059295654, 65.63408047812325, 56.07419300079346, 57.78604848044259, 65.90412916455949, 66.61896678379604, 75.07812758854458, 67.24094867706299, 71.58829062325614, 65.46852575029645, 66.72548961639404, 61.72716399601528, 69.7504573549543, 82.59137453351701, 71.6292780467442, 65.4024692262922, 67.83376898084367, 64.31525679997036, 65.13930620465959, 63.203996658325195, 67.37246417999268, 66.51136698041643, 68.86315849849156, 70.49528339930943, 72.9836973462786, 68.46319934300014, 63.8823492867606, 60.89531176430838, 61.68145874568394, 64.48397295815604, 63.45087310246059, 59.446494238717214, 61.049360275268555, 62.104013442993164, 64.89236027853829, 62.580201285226, 64.7829817363194, 61.962353570120676, 64.08992671966553, 63.85996219090053, 69.64715153830392, 70.77721350533622, 72.85461371285575, 68.0799228123256, 67.90762833186558, 62.09366062709263, 67.69499955858502, 41.351012298039024, 17.205518450055802, 4.372213023049491, 1.6238662068332945, 0.17419547773897648, 1.2106599850314004, 1.5825497210025787, 1.0466943319354738, 0.2303032534463065, 0.44630271728549686, 0.06377213408372231, 0.3911636588828904, 0.17945545406213828, 0.16804074442812375, 0.09880268507237945, 0.19744121895304748, 8.044492312840053, 71.22605323791504, 87.3800104686192, 85.79775278908866, 55.551414012908936, 33.50866740090506, 25.375253779547556, 37.87517247881208, 36.21827377591814, 62.07638045719692, 71.36136245727539, 55.14874158586775, 73.00809941973004, 48.16457564490182, 0.1329856983252934, 0.05030123942664691, 0.0544209139022444, 0.07291636376508645, 0.02397588051722518, 0.1769659633615187, 0.021823419856705835, 0.0967571326930608, 0.023476195455129658, 0.028557177633047104, 0.04162233888304659, 0.0026255753514955616, 0.05747127825660365, 0.052187746590269465, 0.17144295972372803, 0.21471765690616199, 0.15680921210774354, 0.10792710153119904, 0.21516173093446664, 0.19101034903100558, 0.16295673937669822, 0.10601596693907465, 0.1766481375587838, 0.23400069932852471, 0.25343771491731915, 0.22977006062865257, 0.3226139800889151, 0.4011973461934498, 0.9199888280459813, 27.2684520312718, 95.67660427093506, 89.74626118796212, 72.12163434709821, 59.645379475184846, 71.39819485800606, 55.54853745869228, 65.07230472564697, 104.59479086739677, 108.75212042672294, 103.96562453678676, 8.380439451762609, 0.6555720908301217, 0.06674964752580438, 0.2712579444050789, 0.16532687576753752, 0.7875643053225109, 0.2863301342087132, 0.27891803479620386, 0.48008062477622715, 0.995339001928057, 0.17790682001837663, 0.6607472502759525, 1.4095377304724284, 2.974894676889692, 0.8721411441053663, 15.803054094314575, 77.07895864759172, 101.1381037575858, 104.41470050811768, 102.11342239379883, 94.85201290675572, 97.19112396240234, 92.36273043496269, 93.19568743024553, 91.31119006020683, 87.99969945635114, 83.58072853088379, 81.86727496555874, 77.65377616882324, 74.68523475102016, 70.93518774850028, 68.07419054848808, 66.79525647844586, 73.18432658059257, 69.4858352116176, 79.27457550593785, 81.2402903693063, 80.7598363331386, 71.86058357783726, 77.56939724513462, 77.18259797777448, 76.3368285042899, 84.95783369881767, 83.35481480189732, 78.27435452597481, 75.57566724504743, 74.68675640651158, 73.23745945521763, 76.68817806243896, 81.59189006260463, 80.96147305624825, 80.52891295296806, 76.92382621765137, 75.47197232927594, 74.91412230900356, 77.89300959450858, 74.419278553554, 74.14777769361223, 68.0447996684483, 68.76006807599748, 65.823349407741, 57.6888918195452, 54.79350798470633, 65.52139459337506, 68.39284883226667, 76.93234470912388, 68.80945587158203, 73.03452341897147, 67.54657214028495, 66.00103569030762, 63.58911446162632, 73.09825924464634, 80.34742600577218, 74.41045434134347, 67.35158484322685, 68.15497030530656, 66.17030770438058, 68.12613528115409, 65.55274486541748, 70.40736089433942, 70.80556215558732, 73.74610233306885, 73.75795595986503, 78.26347364698137, 70.12805720738002, 67.85538482666016, 67.51779964991978, 68.42836802346366, 68.88375990731376, 69.37166241237095, 65.6381938116891, 67.89961011069161, 69.75704424721854, 73.9552639552525, 70.07579980577741, 71.82668331691197, 67.76652431488037, 67.34872913360596, 69.28069659641811, 76.9930441720145, 76.47185284750802, 79.51027924673897, 74.008389881679, 71.94654669080461, 68.5775944846017, 70.9236398424421, 50.506399972098215, 25.61873081752232, 5.5355642437934875, 2.0197583862713406, 0.2855920238154275, 2.3221670048577443, 3.104593877281461, 1.6669720709323883, 0.35664935090712135, 1.0394494235515594, 0.3152318447828293, 1.0997222236224582, 1.270747572183609, 0.5453104217137609, 0.21649126602070673, 0.4478919548647744, 10.421521425247192, 79.38812296731132, 98.83662414550781, 89.70610060010637, 80.06034033639091, 81.60978862217495, 31.01676893234253, 34.959301880427766, 30.891458170754568, 64.08960015433175, 73.84745570591518, 67.03938838413784, 80.96365479060582, 63.284706933157786, 0.30300996346133097, 0.10778347602380173, 0.12309640326670238, 0.2073144463023969, 0.09089824065033879, 0.25036538977708134, 0.19539531373551913, 0.13510899724704878, 0.10733917129359075, 0.12238699490470545, 0.11632855928369931, 0.20560732004897936, 0.13604177933718475, 0.14680134983999388], [0.08542400332433836, 0.06895413994789124, 0.12495466641017369, 0.07396273940269436, 0.01671154567572687, 0.09618478161948067, 0.06836352271160909, 0.06292149544294391, 0.16755101856376442, 0.0418772169921015, 0.09889495904956545, 0.06159500019358737, 0.08441914045917136, 0.06282514347029583, 0.02656201665688838, 41.80954129355294, 74.13512502397809, 64.83767100742885, 68.16446849278041, 44.85135841369629, 48.3575827053615, 33.32981729507446, 46.833766324179514, 84.64278847830636, 91.16860607692173, 11.938209823199681, 0.4158221371471882, 0.17160094981747015, 0.15736932919493743, 0.11397320138556616, 0.20340090058743954, 0.19832700570779188, 0.24437330131019863, 0.18210081782724175, 0.06610616562621933, 0.3296172214405877, 0.1756056770682335, 0.3572125349725996, 0.04473003266113145, 0.6887644497411591, 0.6982240421431405, 13.867583870887756, 79.01999350956508, 90.463454246521, 84.06321144104004, 84.76340225764683, 87.10390990121024, 83.52913120814732, 87.95047841753278, 85.01362078530448, 80.6177317755563, 74.24835981641496, 67.9471913746425, 64.29778902871269, 64.46351051330566, 61.99946389879499, 61.81478772844587, 60.087472506931846, 61.00294630868094, 63.484148025512695, 66.7711045401437, 69.39495972224644, 72.17710876464844, 66.80011326926095, 69.35150568825858, 66.54869270324707, 71.24085290091378, 82.55127647944859, 74.33023738861084, 65.44614560263497, 68.29824216025216, 68.64627047947475, 68.28709030151367, 67.4523754119873, 67.48494161878313, 68.60016918182373, 67.15338053022111, 67.06126826150077, 69.86610317230225, 70.3301316670009, 74.7662854875837, 70.74806581224713, 74.51248863765171, 72.28300625937325, 65.21855735778809, 68.59621565682548, 69.91027287074498, 64.50226061684745, 75.25799560546875, 66.91317435673305, 65.24785791124616, 67.00992107391357, 68.36186681474958, 69.37412207467216, 66.8897728238787, 68.75640637534005, 65.73186247689384, 64.25763538905552, 70.20475837162563, 66.89037036895752, 65.43817601885114, 66.9922240121024, 66.81277288709367, 64.93361173357282, 65.08386652810233, 63.151016644069124, 59.16057586669922, 57.88950368336269, 60.2543682370867, 65.07808562687465, 65.74489729745048, 62.15686838967459, 56.31361402784075, 54.75549439021519, 59.08820343017578, 58.281333446502686, 55.919494833265034, 49.44832829066685, 49.32823910032, 53.15759631565639, 55.260208061763215, 56.319954259055, 55.958411693573, 54.54718739645821, 58.04053667613438, 59.300047057015554, 64.02765001569475, 66.12908404214042, 65.81494208744594, 59.673325129917686, 60.43942655835833, 52.08208812986101, 30.659447397504533, 13.460653935159955, 2.220007423843656, 2.412034354039601, 0.37186878280980246, 0.14999792831284658, 0.9076055639556476, 0.3242753595113754, 0.21488802347864422, 0.18042965392981256, 0.14882231211023672, 0.6197640065635953, 0.22128336530710968, 0.20497993300003664, 0.06142421971474375, 0.1843249877648694, 0.19870610322271073, 8.715103779520307, 65.00521986825126, 83.74052320207868, 66.7442705971854, 77.76950536455426, 70.27922916412354, 26.747093949999126, 17.761779069900513, 22.10305871282305, 36.079719747815815, 51.8203911781311, 46.820672443934846, 63.85888522011893, 18.064640624182566, 0.7330973765679768, 0.10066206779863153, 0.043158508238515685, 0.07059195384915386, 0.1533079171287162, 0.03994105463581426, 0.08162886197013514, 0.0991947426061545, 0.1328703880842243, 0.06948408258280583, 0.06837815871196133, 0.13899291812309197, 0.06096691425357546, 0.058249116875231266, 0.0800346846559218, 0.1257715140070234, 0.059462228922971656, 0.026117079192772508, 0.03262401458674243, 0.08642457784818751, 0.03771209763363004, 0.11727225221693516, 0.01998620995852564, 0.096527109321739, 0.006952581079011517, 0.11100923150245633, 0.05512270570865699, 0.1218290627002716, 47.0804169518607, 81.75165694100517, 71.91692652021135, 73.76415375300816, 56.93919161387852, 66.39457471030099, 31.90316104888916, 52.891688755580354, 90.99326828547886, 103.49373068128313, 17.86863889013018, 0.4770695034946714, 0.13640873107526982, 0.5971873008779117, 0.0825726024008223, 0.24377917604787008, 0.3993992012526308, 0.5131822771259716, 0.05616454194699015, 0.40290065908006256, 0.12003998298730169, 0.23026191709297045, 1.1469454382147108, 0.19253151597721235, 0.32935598545840805, 0.5758224044527326, 20.008767434528895, 86.44645050593785, 93.97367027827671, 89.4906439099993, 88.0437718800136, 89.34616306849888, 88.63683537074498, 88.6344243458339, 86.42570318494523, 82.26571246555874, 75.88272203717912, 69.86961896078927, 67.65536703382219, 67.24989100864956, 64.81374835968018, 64.8563130242484, 63.740793636866975, 64.52199350084577, 66.30205944606236, 71.35469913482666, 74.24200221470424, 76.06217316218785, 71.14819867270333, 71.70158100128174, 71.94320460728237, 75.57060200827462, 84.40887042454311, 74.62654331752232, 68.82898725782121, 72.17442675999233, 71.77374499184745, 72.66477503095354, 70.7879832131522, 70.4264406476702, 71.32188279288155, 68.51551927839006, 70.88318743024553, 75.60596139090401, 75.223525592259, 78.0567786352975, 74.37706824711391, 76.7378020967756, 73.7518207005092, 69.43275097438267, 70.64892891475132, 74.42105034419468, 68.21293912615094, 77.14347267150879, 69.66594641549247, 67.84708867754254, 69.36080932617188, 69.60086958748954, 70.7593913759504, 71.35544259207589, 70.79349313463483, 72.26007720402309, 68.10688182285854, 71.1136383329119, 67.89965179988316, 70.09630393981934, 67.03052248273576, 69.95636722019741, 68.36025483267647, 66.33527183532715, 68.35652365003313, 64.71108177730015, 61.36910942622593, 62.26912348611014, 67.00819097246442, 67.79468536376953, 65.85905620029995, 61.19240978785923, 59.94913387298584, 64.79645429338727, 65.0634457724435, 61.55255576542446, 55.06636374337332, 55.38577243259975, 59.48727321624756, 60.81056458609444, 62.49610723767962, 62.04859461103167, 59.652966908046174, 64.53614698137555, 64.81515884399414, 70.70798165457589, 69.82547705514091, 69.45704187665666, 65.24855273110526, 67.95589051927838, 59.582908221653526, 44.018971170697895, 25.525756972176687, 5.292196639946528, 3.4730707449572424, 0.6598886592047555, 0.08338044583797455, 1.7875597945281436, 0.1845505463757685, 0.4875318078058106, 0.1795692036726645, 0.23671923631003924, 0.680613289986338, 0.2432621866464615, 0.19336113360311302, 0.12267572512584073, 0.0712654066405126, 0.2958107611962727, 13.078911219324384, 74.7780487877982, 87.04703194754464, 73.09384019034249, 57.44526365825108, 30.491349628993444, 26.233472687857493, 29.094695704323904, 39.970203740256174, 46.947223458971294, 62.94045843396868, 55.25783177784511, 75.2597326551165, 22.58189729281834, 0.7807903002415384, 0.20471957911338123, 0.07965597390596356, 0.05759141966700554, 0.14847038313746452, 0.1254594421812466, 0.061712603883019516, 0.13165652964796337, 0.13670036542628491, 0.10727694963238069, 0.07615341685180153, 0.16117933046604904, 0.040492411835917404, 0.24039464337485178, 0.1513338280575616, 0.2141625066953046, 0.19879610410758428, 0.20702381618320942, 0.12406472702111516, 0.2285455491925989, 0.11519776710442134, 0.2406204869704587, 0.10826201284570353, 0.2205193755882127, 0.09119045854146991, 0.3734272148992334, 0.14025959372520447, 0.1380271456603493, 58.7932037625994, 95.0548516682216, 80.79682854243687, 85.83057607923234, 59.96696295057024, 64.76055295126778, 49.21579987662179, 68.94338934762138, 101.54808916364397, 115.0176168169294, 19.054960421153478, 0.7335318018283162, 0.41680338020835606, 0.8825388518827302, 0.3699265984552247, 0.4329097388046128, 0.7800406004701341, 1.3887713019336974, 0.24662050072635922, 0.6536022765295846, 0.43678971060684746, 0.5591717522059168, 2.2345788819449286, 0.48182331983532223, 2.3566876096384863, 0.9971512875386647, 26.333222763878958, 93.08059052058628, 97.98451096670968, 92.65632656642369, 90.6794251033238, 92.0603587286813, 90.69169562203544, 92.88325473240444, 90.09383787427629, 85.20625959123883, 79.34200082506452, 75.72516468593052, 71.55393178122384, 72.41286809103829, 69.03436211177281, 68.97285665784563, 66.84399114336286, 68.47348962511334, 70.55567019326347, 75.2262075969151, 77.9157441002982, 80.37252984728131, 76.35137108394078, 77.26077216012138, 75.74588421412876, 77.32210390908378, 85.2840655190604, 82.65656253269741, 76.42908668518066, 78.7709492274693, 76.14412716456822, 75.99481732504708, 75.38918454306466, 78.49769742148263, 77.27361937931606, 73.7537453515189, 73.49178436824253, 78.24997329711914, 76.20983627864292, 81.26393508911133, 79.85315895080566, 81.44576249803815, 78.98635033198765, 70.89639595576695, 71.76608112880162, 77.51758452824184, 66.73563398633684, 81.04765156337193, 71.87734958103725, 71.30060740879604, 73.62760775429862, 73.18825926099504, 76.43521499633789, 73.79224531991142, 75.21344375610352, 73.03238337380546, 69.24230779920305, 74.09064960479736, 71.64729472569057, 73.86536121368408, 69.42118222372872, 72.58349500383649, 69.91488647460938, 69.47480842045375, 70.33809430258614, 67.71654592241559, 64.27307428632463, 67.41623783111572, 72.02999455588204, 73.86888395036969, 69.92305060795375, 67.98444761548723, 65.45694310324532, 70.274719783238, 69.32246916634696, 68.50751495361328, 63.51474094390869, 63.95196328844343, 67.49498871394566, 65.55531569889614, 66.10466807229179, 64.01774883270264, 63.05225494929722, 69.00759070260185, 68.41907133374895, 76.10675280434745, 75.77019596099854, 77.91880130767822, 70.17992550986153, 70.47060339791435, 68.78360162462506, 54.467408180236816, 34.79899304253714, 8.25560290472848, 4.393791522298541, 0.6990414868508066, 0.6846118697098323, 4.242354231221335, 0.7708056845835277, 0.9042488240769931, 0.2866999629352774, 0.38047876794423374, 1.558920743209975, 0.6103922437344278, 0.39493620502097265, 0.24557905803833688, 0.3701787420681545, 0.5507134603602546, 16.021694796425955, 81.66467244284493, 97.29919624328613, 83.04281984056745, 103.86117921556745, 90.85787568773542, 36.90108714784895, 24.50650313922337, 32.44964729036604, 52.34129415239607, 71.33602932521275, 65.72802707127163, 89.42669269016811, 32.548884936741416, 0.832335077226162, 0.34019265111003605, 0.1973383937563215, 0.2120094472276313, 0.19410989699619158, 0.28675541281700134, 0.08385248229439769, 0.1797855749194111, 0.22309688585145132, 0.17394828743168286, 0.1054062760834183, 0.24765116827828543, 0.13796419118131908], [0.0905562997130411, 0.08662960398942232, 0.05002597473295672, 0.12844913532691343, 0.012409458086559815, 0.10302601595010076, 0.0459879958736045, 0.11075770535639354, 0.06941594409623317, 0.04039780369826725, 0.11167555967611925, 0.08484846992152077, 0.0665560546996338, 0.15203495829233102, 1.2514920511416026, 60.60974775041853, 68.96175343649728, 70.38771138872418, 48.61719172341483, 42.437825202941895, 34.50260026114327, 40.15050949369158, 69.7086430958339, 102.88022559029716, 42.97833946772984, 0.1749795385237251, 0.11362315195479564, 0.06986762450209685, 0.3572917878627777, 0.10110105281429631, 0.24599388720733778, 0.0510532360390893, 0.49492230266332626, 0.33296410899077145, 0.08155201787927321, 0.03873248877269881, 0.02359515960727419, 0.29489943438342636, 0.06790112823780094, 0.36227519331233843, 0.23388667830399104, 51.3547020639692, 89.65040384020124, 76.33919784000942, 83.37884862082345, 84.7435998916626, 81.04066862378801, 83.92318439483643, 83.12332861764091, 81.31924274989537, 74.27285916464669, 67.92123290470668, 61.966063908168245, 62.52414321899414, 64.10421916416713, 65.22549165998186, 63.213849203927175, 64.46160670689174, 61.30276107788086, 63.594276973179404, 66.51725905282157, 67.22907420567104, 66.31435775756836, 66.16092068808419, 65.70602212633405, 71.04297515324184, 79.6891119820731, 68.85860048021588, 64.870758329119, 70.26954337528774, 69.97446727752686, 69.5922885622297, 67.98314135415214, 65.4644888469151, 64.02341856275285, 66.9330392565046, 68.92134966169084, 74.08210332053048, 73.16382939474923, 71.71031488691057, 68.1227445602417, 71.81704616546631, 68.3422520501273, 70.29305607931954, 71.22931889125279, 71.89799267905099, 71.20135239192417, 67.42169911520821, 67.77183968680245, 65.7241291318621, 62.684160232543945, 67.3424688066755, 67.25695037841797, 66.36599676949638, 66.89328861236572, 68.14782060895647, 70.43227018628801, 69.88906002044678, 70.87906020028251, 63.525712149483816, 69.50923674447196, 68.15105152130127, 67.84530993870327, 69.06655311584473, 70.5491805757795, 68.63973917279924, 66.88993263244629, 65.31924370356968, 61.41411290849958, 59.083027022225515, 59.0021083014352, 57.6086540222168, 51.570012841905864, 50.732216426304404, 56.32689898354666, 60.087875502450125, 56.471685545785085, 51.397120816367014, 51.08731801169259, 53.611699308667866, 58.50695882524763, 60.345876012529644, 59.093094961983816, 55.78276123319353, 55.16370800563267, 59.56365476335798, 60.1430789402553, 61.047970635550364, 65.09246144975934, 62.939332825796946, 64.34640557425362, 47.87656586510794, 39.39901317868914, 12.127261621611458, 5.925586172512599, 2.364713647535869, 1.4571179087672914, 0.12868574048791612, 0.7302519806793758, 0.4087137228676251, 0.2794448493846825, 0.11789332889020443, 0.3661909917635577, 0.16373377053865365, 0.26363767044884817, 0.10410009617252008, 0.05294523933636291, 0.1325695120862552, 0.1055763101737414, 0.16719163927648747, 17.656543391091482, 72.67613533564976, 80.23462894984654, 73.02102306910923, 87.26848493303571, 63.74424689156668, 38.09246001924787, 23.242808205740793, 25.579275471823557, 30.85453544344221, 59.33316217150007, 50.949528285435264, 55.44542966570173, 2.5528480666024342, 0.32237736135721207, 0.10444154177925416, 0.10550489436302866, 0.02819913505975689, 0.08230897119002682, 0.09910430067351886, 0.10579059153263058, 0.07216242314981562, 0.15313845979315893, 0.0499591593896704, 0.10845883549856287, 0.09698166671608176, 0.1401403886931283, 0.027914002770558, 0.0660801777350051, 0.04395990898566587, 0.0052964573343550515, 0.024722745708589042, 0.03511034331417509, 0.05525848056588854, 0.11880627061639513, 0.02277953506979559, 0.04692329532865967, 0.07734760455787182, 0.07799105253070593, 0.13228302103068146, 1.1327385434082575, 70.91824804033551, 73.80448109763009, 79.21853133610317, 61.84041963304792, 53.38614341190883, 31.811455249786377, 31.72134406226022, 75.51847662244523, 106.47219412667411, 53.00911678586687, 0.2945041741643633, 0.023236124676519206, 0.11423641869000026, 0.31367721248950275, 0.18774560493017944, 0.4981208624584334, 0.122659725270101, 0.1320382055959531, 0.5098924679415566, 0.044962987303733826, 0.07594585298959698, 0.0637905155973775, 0.6002237722277641, 0.11070615026567664, 0.4500962980091572, 1.1680909778390611, 59.748872893197195, 94.65539278302873, 82.24362414223808, 87.74037184034074, 89.01177406311035, 82.93131514957973, 86.25850173405239, 86.62412289210728, 82.76878983633858, 77.49149404253278, 70.68028613499233, 66.1062661579677, 66.88042054857526, 68.36489622933524, 71.94884654453823, 65.90968077523368, 68.88253007616315, 65.27717236110142, 67.07024533408028, 69.85975946698869, 70.42328616550991, 70.5816147668021, 69.46318408421108, 70.27414308275495, 73.32008048466274, 83.17965766361782, 70.74884401048932, 69.31026812962124, 73.73292854854039, 71.97504820142473, 73.3649172101702, 70.58979974474225, 70.70823873792375, 69.22003882271903, 70.68118940080915, 72.96014990125383, 75.71522181374687, 75.1150016784668, 75.16413239070347, 71.44919463566372, 74.48926080976213, 73.13283348083496, 73.54809256962368, 74.77665914808, 74.8579878125872, 75.68666471753801, 70.18391377585274, 70.67832674298967, 69.55858285086495, 67.47226115635463, 67.9179047175816, 69.65318952287946, 70.6180511202131, 69.37394836970738, 69.29638562883649, 71.30904947008405, 71.81003543308803, 71.50478717258999, 68.283602305821, 72.02544348580497, 71.03060041155133, 68.96478979928153, 71.89230905260358, 73.8094699042184, 72.51901572091239, 71.26392092023576, 70.54850660051618, 67.18000602722168, 62.31902544839041, 61.89004366738455, 58.10863249642508, 53.29337453842163, 55.5312294960022, 60.39620876312256, 64.50118364606584, 64.98891244615827, 58.809024810791016, 60.367290360586985, 59.59201036180769, 64.765152658735, 66.05094460078648, 64.68588066101074, 59.95905590057373, 61.50075694492885, 64.67096287863595, 68.63316617693219, 67.33234528132847, 69.21930231366838, 67.12801960536412, 67.45475169590541, 57.45144755499703, 52.53363071169172, 30.00561843599592, 5.653661906719208, 6.138730415276118, 1.6478214242628642, 0.021603491390123963, 1.4371136107615061, 1.2770102875573295, 0.6243332070963723, 0.4609927290252277, 0.536369012934821, 0.2952878549695015, 0.3229810675340039, 0.19218342751264572, 0.0148125500750861, 0.13968818581530026, 0.0953006912022829, 0.0667019940114447, 23.398116077695573, 82.7034559249878, 86.37334156036377, 79.36913354056222, 61.69873891557966, 35.206334659031455, 30.293294702257427, 28.883171694619314, 34.18598822184971, 44.26304401670183, 75.74372332436698, 59.36040605817522, 69.570387840271, 3.1894320334706987, 0.40164227517587797, 0.17816113494336605, 0.13427494200212614, 0.012299479434399732, 0.03086307372099587, 0.05532685653971774, 0.10119790690285818, 0.06620093661227397, 0.14805570324616774, 0.03557599136339767, 0.11401767257068839, 0.09317053907683917, 0.22498746083251067, 0.1712942791304418, 0.1740662982421262, 0.2959322732474123, 0.09966908608164106, 0.15247194841504097, 0.17075016189898762, 0.14978186919220857, 0.13602146399872644, 0.08276733516582421, 0.19698653263705118, 0.14393874630331993, 0.1881441492587328, 0.2845541366509029, 1.8168900949614388, 86.73887934003557, 85.10280091421944, 92.87812001364571, 61.140805516924175, 56.65693841661726, 45.1786150932312, 54.14215605599539, 88.40292426518032, 117.6880874633789, 57.61316687720162, 0.5040271569575582, 0.1894354692527226, 0.3236659807818276, 0.948459940297263, 0.9980609587260655, 0.8350174075790814, 0.8132910419787679, 1.4524969224418913, 0.8437295800873211, 0.1492801196873188, 0.37247333037001745, 0.5076492854527065, 1.1088702870266778, 0.28237663635185783, 1.3206801499639238, 1.90883669257164, 67.93594224112374, 96.11643913814, 90.49390125274658, 92.59286172049386, 90.6282377243042, 87.0575167792184, 88.04156930106026, 91.56070681980678, 86.89556816646031, 83.52744279588971, 74.64296191079276, 69.5065061024257, 69.90342889513288, 71.07334572928292, 72.21947887965611, 68.74751962934221, 71.95642702920097, 69.01870782034737, 70.11084651947021, 74.71338190351213, 72.41879490443638, 75.95770004817417, 74.19695009504045, 74.97104890005929, 80.88654368264335, 83.99902398245675, 77.87627138410295, 75.65942777906145, 76.60507760729108, 75.73362759181431, 77.32391044071743, 76.06661306108747, 74.79010391235352, 75.61140877859933, 76.85035596575055, 77.5728713444301, 79.81779261997768, 80.01628875732422, 77.48716531481061, 74.82718644823346, 77.10898876190186, 75.29543944767543, 75.26567336491176, 77.15408951895577, 76.25895309448242, 76.72778279440743, 73.7777235848563, 73.64294937678746, 72.78076825823102, 68.25045245034354, 68.83093970162528, 73.05297783442906, 73.0958273751395, 72.97289289746965, 73.74734606061662, 76.05302933284214, 73.18966279711042, 74.23497758592877, 71.89487988608224, 75.8945061819894, 74.03682885851178, 71.91334124973842, 74.61151436397007, 76.31878403254917, 76.93157345908028, 74.01050213405064, 73.25630991799491, 68.59716756003243, 66.8776968547276, 68.2178167615618, 65.4248354775565, 61.85943685259138, 61.38406889779227, 67.90982396262032, 68.88659477233887, 68.56922885349819, 64.55055754525321, 65.37644127437046, 63.6968879699707, 68.29281561715263, 69.56191798618862, 67.88728400639125, 63.92533779144287, 65.3775668825422, 68.23543739318848, 71.19575214385986, 69.87695625850132, 72.76625347137451, 72.58329350607735, 73.54815510341099, 65.40665204184396, 57.80668115615845, 40.92029346738543, 11.761015125683375, 6.954730766160147, 1.6672068983316422, 0.2995734007230827, 2.8163278826645444, 1.5535198215927397, 1.1917178928852081, 0.7377426273056439, 0.7004695587924549, 1.12398533310209, 0.9088527113199234, 0.60570220968553, 0.14027686922677926, 0.28807179789458004, 0.21365337472941193, 0.32651620783976143, 30.018719264439174, 88.2964848109654, 93.41838414328438, 88.52677590506417, 115.81862599509103, 82.68778773716518, 52.85894536972046, 34.937144075121196, 39.50650181089129, 46.85327686582293, 80.98525674002511, 66.53202397482735, 84.24223872593471, 4.611776922430311, 0.544634817966393, 0.23899357712694577, 0.14800007694533893, 0.11246410557734114, 0.19024511080767426, 0.18852182185011251, 0.195569887225117, 0.20380743805851254, 0.2708302230707237, 0.2511005417576858, 0.16035619963492664, 0.19528068202946866], [0.031337108463048935, 0.07328687781201941, 0.034971918777695725, 0.09575581178069115, 0.13839025689022882, 0.023367862250389795, 0.03930831055289932, 0.13113902455994061, 0.055974474110241444, 0.09819392380969864, 0.03819440711023552, 0.1994252417768751, 0.030923303881926194, 0.02003125280940107, 7.207947875772204, 68.47824914114815, 64.01460824693952, 63.437317167009624, 48.74770668574742, 48.808444363730295, 68.32122680119106, 63.509821619306294, 82.81486334119523, 83.21682357788086, 4.267924470560891, 0.28881568940622465, 0.05345552481178727, 0.15295091271400452, 0.08827254761542593, 0.3400280385145119, 0.09633160981216601, 0.10591531305440835, 0.20915030421955244, 0.16317304276994296, 0.14459911015416893, 0.16446434919323238, 0.24384198124919618, 0.5505282474415643, 0.13194839470088482, 0.3008179967956883, 18.85103600365775, 92.58425290243966, 72.83347034454346, 75.14378806522915, 78.53487723214286, 85.35775811331612, 83.3160160609654, 84.48153468540737, 80.84094265529087, 73.88680335453579, 66.39144107273647, 64.25023555755615, 63.371434347970144, 69.84888553619385, 72.11797959463937, 76.30447769165039, 72.65022550310407, 71.77767072405133, 68.51033592224121, 69.24209240504673, 67.46015739440918, 69.81614562443325, 63.357412883213584, 68.29898561750139, 68.21004172733852, 74.75429289681571, 69.28660256522042, 62.801390239170615, 71.44478947775704, 69.19259343828473, 68.85798903873989, 70.25025517599923, 67.72524506705147, 64.62762001582554, 65.1828783580235, 65.4905515398298, 69.19520596095494, 69.80437537602016, 65.84274877820695, 69.95881993430001, 71.5480466570173, 67.70365006583077, 67.57989570072719, 70.7932916368757, 69.36803545270647, 67.35886655535016, 60.344882420131135, 59.91028649466378, 67.56852844783238, 68.09412493024553, 67.62248120989118, 66.08556747436523, 65.55493354797363, 65.16750199454171, 66.49089758736747, 64.75482068743024, 62.95225647517613, 65.18607452937535, 66.25517995016915, 67.410338810512, 65.63686670575822, 68.54365948268345, 68.46725014277867, 68.64483220236642, 67.28478486197335, 66.94772774832589, 66.92153998783657, 65.91133444649833, 64.69711589813232, 58.58955206189837, 54.32289259774344, 52.19920349121094, 48.112557956150596, 49.23543201174055, 49.402369431086946, 54.45697546005249, 58.753696305411204, 58.362512724740164, 54.8860718863351, 56.51076568875994, 59.9013580594744, 60.40554019383022, 58.22608484540667, 58.575572286333355, 56.90455831800188, 59.99369961874825, 61.029405048915315, 64.1840261731829, 59.050370488848, 60.884521211896626, 62.279420716421946, 52.24774708066668, 45.36954116821289, 25.877902099064418, 9.11713523524148, 2.5338364924703325, 2.441505572625569, 0.35945156482713564, 0.23257444586072648, 0.5987978173153741, 0.22865164492811474, 0.35394954149212154, 0.5263361398662839, 0.33003224059939384, 0.12028930389455386, 0.11062306365264313, 0.14225607445197447, 0.06430939811148814, 0.03617287826325212, 0.15679539713476384, 0.7444745089326585, 31.30120038986206, 79.5423868724278, 77.85266835348946, 61.019295419965474, 62.91222095489502, 74.39668995993478, 34.110332761492046, 53.10256658281599, 58.36480563027518, 25.462128843579972, 47.53506885256086, 68.03648267473493, 16.29463219642639, 0.5324757418462208, 0.18940709291824273, 0.0769227941387466, 0.07866658163922173, 0.04785894762192454, 0.15876776272697107, 0.07490831866328206, 0.09678734107209103, 0.033809910594884834, 0.13436992333403655, 0.032564361180577955, 0.13901490265769617, 0.015158092336995261, 0.06600413431546517, 0.05487004301643797, 0.013719773668396686, 0.05146180232986808, 0.027282054269952432, 0.07825996952929667, 0.07091470581612416, 0.016435583787305013, 0.08397998580975191, 0.0448310665254082, 0.1371593807957002, 0.019491113489493728, 0.18510957780693257, 7.170882276126316, 76.77516256059918, 72.67692743028913, 76.52448545183454, 48.226275648389546, 57.65136807305472, 39.2494010925293, 52.274139813014436, 93.22858715057373, 92.07828508104596, 7.131346157618931, 0.6705082750746182, 0.043289984576404095, 0.27741138849939617, 0.14999533630907536, 0.5023148602672985, 0.22318790453885282, 0.19409332717103617, 0.8200071273105485, 0.7664247368063245, 0.20616312165345463, 0.16230394797665731, 0.35223298360194477, 0.984116792678833, 0.133835943415761, 0.2817033939063549, 24.36343104498727, 98.75515651702881, 83.24986921037946, 84.23322691236223, 84.71648802076066, 91.11251326969692, 89.03577314104352, 88.44031252179826, 83.88675498962402, 76.47333976200649, 68.16259247916085, 66.92959295000348, 66.92079653058732, 73.10356072017125, 75.05102961403983, 79.67506967272077, 77.23079068320138, 77.6744748524257, 72.02158723558698, 72.04245267595563, 69.99870954241071, 72.78049033028739, 67.71725463867188, 73.13274315425328, 71.81004932948521, 79.47995035988944, 72.84332289014543, 68.2663916179112, 76.78876713344029, 74.1533432006836, 72.51183128356934, 72.29002393995012, 69.28705419812883, 69.0651912689209, 70.4993064062936, 70.84863403865269, 72.77737058912004, 73.50927993229458, 71.49191216060093, 74.22891875675747, 74.42116151537213, 72.0296471459525, 71.22112696511405, 74.01583140236991, 71.52162265777588, 67.36020060947963, 61.728206225803916, 62.729497228349956, 69.81037167140416, 71.14993572235107, 68.4856767654419, 68.26516873495919, 68.992401940482, 68.47714437757219, 69.72915417807442, 67.70157255445207, 66.73837157658168, 67.15099034990583, 67.20816707611084, 68.7152521950858, 68.2148220879691, 68.92166233062744, 70.57052544185093, 69.21427181788853, 70.01905386788505, 69.40632002694267, 70.00738784245083, 70.03667449951172, 67.40685776301792, 64.64612306867326, 60.925105639866416, 59.81879956381661, 56.799581459590364, 56.19355957848685, 53.17646414893014, 56.26358699798584, 58.33807591029576, 64.29298087528774, 60.270126751491, 62.42117091587612, 63.66078513009207, 64.60096672603062, 62.3141964503697, 62.020697593688965, 62.93097414289202, 64.75133269173759, 65.55997794015067, 69.51983969552177, 66.93790994371686, 66.66450527736119, 64.94547230856759, 63.24114867619106, 56.603638785226, 42.34573030471802, 13.328240377562386, 4.879147946834564, 3.8335999591009955, 0.5965485551527568, 0.23344006655471666, 1.3528936271156584, 0.48622847774199074, 0.3828159139624664, 0.4304847632135664, 0.8856550103851727, 0.23236610846860067, 0.0853581650714789, 0.14564759603568486, 0.09208185678081852, 0.07700239986713443, 0.1500757291380848, 0.4740220127361161, 41.194681303841726, 85.39617470332554, 84.79405770983014, 65.73958887372697, 45.31092963899885, 39.211985043116975, 23.037831136158534, 49.2438462802342, 58.18411077771868, 41.90655204227993, 52.92360183170864, 80.33785138811383, 20.3277679170881, 0.5754000299743244, 0.24937204165118082, 0.06391216335552079, 0.1100183871707746, 0.03539873766047614, 0.09791565659855093, 0.025610768236219883, 0.10996907124561922, 0.02111935326164322, 0.11204095756901161, 0.058136866827096255, 0.1472596459622894, 0.12265759467014245, 0.17258525985692227, 0.15009130830211298, 0.2469573255096163, 0.1499495759074177, 0.08782935568264552, 0.15801895862179144, 0.2008859919650214, 0.10845355649611779, 0.16849924411092485, 0.12196562465812479, 0.26413834786840845, 0.2173767542200429, 0.5101192614861897, 11.357942308698382, 90.57331221444267, 80.93379838126046, 82.6385111127581, 64.16612066541398, 62.81551592690604, 90.01168932233537, 90.71627834865025, 97.80660928998674, 104.63671629769462, 6.83844484601702, 0.6611118678535733, 0.18784255401364394, 0.3501588377569403, 0.6623482672231538, 0.9170585338558469, 0.7181363308003971, 0.6589555921299117, 2.1197520835059027, 1.2087554186582565, 0.6243680566549301, 0.4207973730351244, 1.4369254665715354, 2.009867842708315, 0.4477770924568176, 0.3396062068641186, 29.722715582166398, 102.49983951023647, 85.61983721596854, 91.11202689579555, 87.45836530412946, 97.72104222433907, 90.35503455570766, 93.40068013327462, 87.17576817103794, 80.76573535374233, 72.93542126246861, 70.8753776550293, 70.03326293400356, 78.30732372828892, 80.71872384207589, 82.81729521070207, 80.17277608598981, 80.6965799331665, 75.47181946890694, 75.86808218274797, 73.75276565551758, 76.76075894492013, 74.92207104819161, 79.20495455605644, 76.67120361328125, 78.45566776820591, 78.61109897068569, 73.31721782684326, 79.04039342062813, 80.01598303658622, 76.40676212310791, 78.08360563005719, 73.40871865408761, 75.57043525150844, 77.17931842803955, 78.2396274294172, 75.59904793330601, 76.6150621686663, 71.45485741751534, 76.07347788129533, 78.48008373805455, 75.09414318629673, 73.80087498256138, 76.89724935804094, 72.7216877256121, 71.6873163495745, 63.915110043116975, 64.56460680280412, 73.34041786193848, 75.12450681413922, 73.42128794533866, 71.1756649017334, 71.70103904179165, 71.55340371813092, 73.68047659737724, 71.79638222285679, 68.87472030094692, 71.93825054168701, 69.0377528326852, 73.87203843252999, 71.23780958993095, 72.02010726928711, 72.10390254429409, 72.5096356528146, 72.70610291617257, 72.32261099134172, 74.3221218926566, 73.90536199297223, 74.31237357003349, 70.81413623264858, 63.93793487548828, 63.869106020246235, 60.76238577706473, 62.958892004830496, 63.009690284729004, 66.18223776136125, 66.54432923453194, 68.81153338296073, 65.60905306679862, 65.9803022657122, 69.35787023816789, 68.32996763501848, 65.68714387076241, 67.93407317570278, 67.80225195203508, 67.98061220986503, 69.75658566611153, 74.45574964795793, 70.31218447004045, 72.79531778608049, 74.31076158796037, 69.81789657047817, 60.56576565333775, 49.07935810089111, 22.767844983509608, 6.065370900290353, 4.7859600101198465, 0.4489345374916281, 1.567297882267407, 4.357191017695835, 0.845637674842562, 1.3406692487852914, 1.006874531507492, 2.2272847933428626, 0.7015030490500587, 0.14907579922250339, 0.4289712230009692, 0.17082862768854412, 0.27682459141526905, 0.2230910775916917, 1.3118507266044617, 49.27857337679182, 93.83565820966447, 91.68567017146519, 76.12835475376674, 88.28292887551444, 96.72083514077323, 49.58185182298933, 69.71336092267717, 70.78872667040143, 38.658043384552, 63.37090628487723, 89.98643262045724, 24.450815064566477, 0.7624796256422997, 0.6532649089183126, 0.14046943746507168, 0.24657571741512843, 0.07461027894169092, 0.2325195116656167, 0.12050072183566433, 0.21051814939294541, 0.11349257467580692, 0.24110490669097218, 0.10565018906657185, 0.30719497746654917], [0.08980143629014492, 0.046519678950841935, 0.09861534155373063, 0.05770009383559227, 0.03440441583682384, 0.03284546806077872, 0.037097249911831956, 0.07893650965499026, 0.07834473890917641, 0.05915869985307966, 0.11061533513878073, 0.08274639557514872, 0.07053417659231595, 0.07741752080619335, 10.680459942136492, 68.82901505061558, 56.87222834995815, 73.40646048954555, 76.95109094892229, 45.138829708099365, 41.495225633893696, 64.89848164149693, 98.20459515707833, 31.758791378566197, 0.06305013211177928, 0.06486523364271436, 0.14069521320717676, 0.1239494439214468, 0.06454709571387086, 0.108129040338099, 0.08658176048525743, 0.03553422074764967, 0.37736041098833084, 0.4595870758805956, 0.7052539906331471, 0.9944211883204324, 0.3680282746042524, 0.5720003523996898, 0.20316623603659018, 4.484431641442435, 82.07057230813163, 71.51886422293526, 66.987916128976, 74.62776620047433, 84.88043076651437, 80.78671196528843, 87.234133039202, 83.01314408438546, 80.08505507877895, 69.06359318324498, 62.02861854008266, 63.933599199567524, 64.78305121830532, 70.7342666898455, 76.4637234551566, 77.98464243752616, 76.64683628082275, 76.51328495570591, 75.69846275874546, 70.01211261749268, 69.09668745313371, 65.20987905774797, 64.20271682739258, 71.10789217267717, 73.34729657854352, 72.8456505366734, 63.368175642830984, 74.45679187774658, 67.79121126447404, 70.13031537192208, 68.14631979806083, 64.98583439418248, 62.371053559439524, 70.25167955671037, 64.39557797568185, 67.03196770804269, 70.28357178824288, 73.63354846409389, 72.09345245361328, 71.11257525852749, 66.21884781973702, 66.59845570155552, 73.29838126046317, 64.71156815120152, 64.47725405011857, 59.77629048483712, 60.275817326136995, 59.52069405147007, 63.8970308303833, 64.06743540082658, 66.76845032828194, 63.636390004839214, 62.3307956968035, 63.97068173544747, 66.77933120727539, 65.5345961706979, 66.97705609457833, 66.56199850354875, 66.51274967193604, 65.81483786446708, 67.32523727416992, 66.30729838779995, 67.05133233751569, 66.67513602120536, 67.43712411608014, 66.11383969443185, 64.42740072522844, 62.96383217402867, 57.705227034432546, 58.20179394313267, 60.00587286267962, 59.901253836495535, 54.727774551936555, 51.19947235924857, 46.21821846280779, 43.882529394967214, 44.141276836395264, 53.10953910010201, 59.10296835218157, 58.39450223105294, 55.280298777988975, 57.346526282174246, 60.04357378823416, 58.12972027914864, 57.48383658272879, 59.16451549530029, 60.90087727137974, 63.36085224151611, 61.506649017333984, 61.029627391270225, 51.7077956199646, 56.5686685017177, 51.424441133226665, 36.25475876671927, 11.00688110079084, 6.290432172162192, 2.8583369084766934, 1.672065100499562, 0.32890497680221287, 0.7266451599342483, 0.1470516478376729, 0.21728382206388883, 0.11190413776785135, 0.8892615597162927, 0.6708061248064041, 0.098579406339143, 0.1251521608127015, 0.08027101840291705, 0.08968975621142558, 0.01633440743067435, 0.0610987264662981, 3.8312184640339444, 54.77053376606533, 77.59744712284633, 83.73677117483956, 52.36016893386841, 80.67763914380754, 46.039875575474326, 73.23061547960553, 62.65979290008545, 39.08872400011335, 54.21714448928833, 59.89204052516392, 29.08396421160017, 0.39346630818077494, 0.10730278146054063, 0.14113422536424228, 0.024370192483599697, 0.08409564210368053, 0.18182155995496682, 0.07836530530559165, 0.06122436401035104, 0.026971716101148298, 0.05803363450935908, 0.11229465502713408, 0.048566707143826146, 0.04582034344119685, 0.09163851557033402, 0.062178343534469604, 0.13911566510796547, 0.05468721514833825, 0.10374875073986393, 0.05137140789468374, 0.07614370023033448, 0.03381212940439582, 0.08524575217493943, 0.08476990235171147, 0.09038788732141256, 0.06898230593651533, 0.5437982114298003, 13.463965620313372, 79.1948240825108, 63.52740750994001, 78.60606847490583, 68.22860036577497, 43.85776948928833, 34.30881152834211, 68.11522660936627, 105.45334502628872, 39.17472185407366, 0.03744039185611265, 0.18517329224518367, 0.1791120067770992, 0.07379587407090835, 0.3927345760166645, 0.06712267215230636, 0.06273673714271613, 0.07380309368350677, 0.3593952735619885, 0.5958244768636567, 1.8458371588162013, 2.323805694069181, 2.4439589381217957, 0.9478887766599655, 0.21941197929637773, 7.04166749545506, 88.59012957981655, 78.00668907165527, 74.45427662985665, 81.67091192517961, 86.99000113351005, 85.45843751089913, 90.65505082266671, 86.98458848680768, 82.86344514574323, 73.78401865277971, 65.61612633296421, 65.71665287017822, 68.20986107417515, 71.51943397521973, 82.33930083683559, 80.67924417768205, 78.3779799597604, 78.97156456538609, 78.330322265625, 74.01239899226597, 72.46593843187604, 70.28480161939348, 70.44117082868303, 74.41299738202775, 75.19585786546979, 77.80248846326555, 67.87916851043701, 79.21034635816301, 70.94982065473283, 72.35207830156598, 69.26488944462368, 69.38310609545026, 64.19246128627232, 72.99625968933105, 69.03043637956891, 70.45122487204415, 74.77393545423234, 75.35588182721818, 74.02953324999127, 73.38122463226318, 67.8127715247018, 70.86271803719657, 72.96568066733224, 69.45348439897809, 66.27139704568046, 61.1390198298863, 61.89890262058803, 63.21548203059605, 66.33442415509904, 67.93248898642403, 67.85308497292655, 64.99583285195487, 66.51521628243583, 66.27316188812256, 67.28785596575055, 66.439911706107, 68.60777051108224, 68.30190386090959, 69.46210711342948, 69.14274706159318, 70.34193665640694, 68.68011515481132, 70.55867876325334, 68.72418757847377, 71.06755093165806, 68.69622107914516, 66.60012326921735, 66.93014880589077, 62.79388618469238, 64.26004641396659, 64.91822842189244, 64.34847613743374, 61.48400483812605, 59.81536020551409, 55.312336921691895, 52.419659410204204, 51.73516804831368, 57.22124331338065, 61.63169574737549, 63.578560147966655, 59.997528076171875, 62.53828975132534, 61.595856939043315, 62.14382662091936, 61.149991035461426, 64.5480284009661, 64.85382556915283, 68.63053975786481, 66.38655648912702, 67.58377279554094, 59.26887048993792, 61.34095532553536, 63.367772647312705, 51.40159893035889, 26.405114037649973, 4.243125481264932, 4.490123953138079, 2.2480227776936124, 0.29550941022379057, 1.7221480416400092, 0.3242819005889552, 0.08265710036669459, 0.02125944190525583, 0.6200620734265873, 0.6791864122663225, 0.1225890897746597, 0.09840267510818583, 0.17698721507830278, 0.04711992120636361, 0.04354131733998656, 0.12035949155688286, 4.7930276308740885, 66.69707148415702, 84.70692035130092, 90.10714367457798, 54.73252017157418, 62.57382978711809, 28.01827383041382, 82.09352220807756, 75.826260975429, 33.857706683022634, 60.597643988473074, 68.62568991524833, 36.07319886343819, 0.37820575705596376, 0.31744259329778807, 0.059889081732503006, 0.06950674565242869, 0.0881680396518537, 0.07085743067520005, 0.061878431056227, 0.14856670796871185, 0.04143074434250593, 0.10006972029805183, 0.04877624215025987, 0.04472662641533783, 0.158126099301236, 0.17658459953963757, 0.19450190024716513, 0.1804235606853451, 0.1212617667125804, 0.17455092152314527, 0.20846593379974365, 0.14017948588090284, 0.11210714866008077, 0.15010513684579305, 0.23527067261082785, 0.2078000195324421, 0.38015521530594143, 0.7047696251954351, 18.609662532806396, 92.560788835798, 71.88301931108747, 88.15069770812988, 88.49618993486676, 60.332500730242046, 61.15047740936279, 85.04392187935966, 114.98705169132778, 44.801018714904785, 0.16153982255075658, 0.5424157913242067, 0.4715741298028401, 0.25010301385607037, 0.8821416103414127, 0.3915337047406605, 0.32187383409057346, 0.18274527681725367, 1.9483673827988761, 1.4612077921628952, 3.3910639796938216, 4.046959596020835, 5.35385799407959, 2.4373053865773335, 0.465158825474126, 10.446720804486956, 95.07598114013672, 82.0498388835362, 78.78317110879081, 85.37041078295026, 90.84487560817173, 88.26109068734306, 94.67122772761753, 90.83915724073137, 87.6411863054548, 78.87080873761857, 68.02168301173619, 70.24034704480852, 69.84460544586182, 75.54435866219657, 84.50119113922119, 85.582900592259, 82.75516441890171, 83.11739485604423, 82.290253502982, 76.13741520472935, 75.99740205492292, 73.86631311689104, 75.88483428955078, 80.54083606175014, 80.25124209267753, 79.76638984680176, 73.55599267142159, 81.20791176387242, 78.6178456715175, 74.49671622685024, 74.18648610796247, 72.31549603598458, 69.00226143428257, 81.08717291695731, 75.52330562046596, 75.11263929094586, 76.44462285723004, 77.770172391619, 77.69197041647774, 76.70608357020787, 73.25210625784737, 73.86322116851807, 78.01281043461391, 72.40235546657017, 67.97760363987514, 61.817671230861116, 63.550023896353586, 65.21832111903599, 70.62384591783795, 71.18663610730852, 71.86851842062813, 69.12254864828927, 68.80142375401088, 71.17963232312883, 73.00393744877407, 70.19190420423234, 71.84914684295654, 71.69782202584403, 71.98779119764055, 72.15919630868095, 73.26541205814907, 71.9935998916626, 71.79784829275948, 71.39542252676827, 73.62718391418457, 74.12454291752407, 69.39355618613106, 71.46563407352993, 66.13261372702462, 69.15066800798688, 67.29795864650181, 69.56783090318952, 65.07793276650565, 64.1773350579398, 58.42093317849295, 59.25190298897879, 58.486941065107075, 69.09899425506592, 69.12302112579346, 69.04817513057164, 64.37742928096226, 68.03173010689872, 68.11503205980573, 68.3982128415789, 65.163895879473, 70.21710532052177, 68.22240257263184, 71.34656974247524, 70.30091449192592, 71.57329641069684, 64.35222121647426, 71.00417641230992, 70.78485652378627, 54.39799220221383, 35.71704462596348, 7.700560825211661, 5.998606528554644, 2.3482112416199277, 0.7419709318450519, 3.147361125264849, 0.8194105593221528, 0.41615877194064005, 0.3031444491020271, 2.4788723332541327, 0.8764397991555077, 0.2933548172669751, 0.23953211680054665, 0.5009715780615807, 0.19606523135943071, 0.09679295255669526, 0.18903145593191895, 7.3237469877515515, 73.12209851401192, 91.60070065089634, 97.4577749797276, 66.07670157296317, 103.75469807216099, 65.01706654684884, 83.95074095044816, 73.07765088762555, 55.95630986349923, 69.21938569205147, 80.58333819253104, 41.22001791000366, 0.4202324247785977, 0.41755872539111544, 0.11857296313558306, 0.20582907886377402, 0.17842133955231734, 0.23817130124994687, 0.12385067636413233, 0.2573552504181862, 0.13945330413324492, 0.18063055457813398, 0.1990551823484046, 0.2887676219855036], [0.033840152900666, 0.0705631161108613, 0.05179355167118566, 0.05795942313436951, 0.06804308454905238, 0.02801280764729849, 0.019176485283034186, 0.03960287617519498, 0.08380757006151335, 0.12711907098335878, 0.05843420087226799, 0.12942376945699963, 0.10107349072183881, 0.10277908348611423, 6.7786551628793985, 66.37655803135463, 58.84994970049177, 68.97082778385708, 92.51270035334996, 59.90936238425118, 55.95226601191929, 87.4476511819022, 73.46372059413365, 2.815475642681122, 0.1822549674127783, 0.1338090734290225, 0.16401358480964387, 0.05992868782154151, 0.15218120973025048, 0.05955505929887295, 0.03353025917229908, 0.07693244290671178, 0.2590268350073269, 0.06590492571038858, 2.0368516061987196, 0.4355255998671055, 0.6136315699134554, 0.16328135052961962, 0.6890839583107403, 54.61879553113665, 71.02639675140381, 55.162339210510254, 72.35231454031808, 83.41771684374127, 75.95501804351807, 86.56650148119245, 84.32582555498395, 81.03371347699846, 75.9858888898577, 68.68321405138288, 64.20903968811035, 60.661581311907085, 62.96209512438093, 67.96590982164655, 75.75527123042515, 77.39939567020961, 77.96313776288713, 77.18500205448696, 75.76175389971051, 74.15732451847622, 71.56106063297817, 68.24484525408063, 65.6092893055507, 67.14477171216691, 77.14642565590995, 64.68893786839077, 68.57803222111293, 66.78267329079765, 70.72825649806431, 72.94598947252545, 70.7498584474836, 70.49310166495187, 67.43157945360456, 68.59938403538295, 61.19029753548758, 66.0928908756801, 72.58901882171631, 71.34226880754743, 70.76561001368931, 66.47014331817627, 67.42891829354423, 68.05961322784424, 65.25925295693534, 68.12396049499512, 59.21263871874128, 64.42072350638253, 65.49027361188615, 65.04053061349052, 63.76497336796352, 64.38627433776855, 62.26655960083008, 63.75828225272042, 63.119256428309846, 60.631294114249094, 58.69812461308071, 59.8832927431379, 61.63377325875418, 63.624369621276855, 65.275192124503, 65.44038554600307, 65.00360788617814, 68.80375140053886, 67.15666702815464, 67.32350022452218, 62.91417339869908, 66.35899298531669, 61.9563364301409, 61.399160385131836, 62.24612494877407, 62.47237913949149, 61.97622217450823, 62.50468826293945, 60.58451884133475, 58.65747765132359, 56.61482538495745, 52.818023954119, 47.59798131670271, 49.11958122253418, 55.529047761644634, 56.33906180518014, 56.29027155467442, 54.563654627118794, 55.75062928880964, 55.710604190826416, 56.36151838302612, 59.86059992653983, 58.99873147691999, 62.77361828940255, 58.58072784968785, 58.332253319876536, 56.742515904562815, 49.69519083840506, 49.85754592078072, 47.295550550733296, 21.838566848209926, 15.130529267447335, 2.866101086139679, 2.2878181508609226, 0.4083192768905844, 0.5759080627134868, 0.5810321420431137, 0.5153821419392313, 0.0530107043949621, 0.06375816983303853, 0.1553484212074961, 0.13012582249939442, 0.029198264304016317, 0.11359677051327058, 0.02667191218850868, 0.059608521072992256, 0.11400974728167057, 0.14333535225263663, 14.67542747088841, 71.23730931963239, 74.76462486812046, 46.928633553641184, 35.132409300122944, 46.74760518755232, 19.551572493144445, 20.828133753367833, 64.99736145564488, 48.83375317709786, 62.23104040963309, 31.100654533931188, 0.10408516161675964, 0.06947329387600933, 0.029047989153436253, 0.08887092050697122, 0.04474881111777254, 0.08034612544413124, 0.05500561770583902, 0.13795653730630875, 0.1086455819063953, 0.01269558273322348, 0.041873091499188116, 0.18176573009363242, 0.07698317018470593, 0.10050884780607053, 0.03813517100310751, 0.0710272476343172, 0.02926181928653802, 0.02559144016621368, 0.04375078110024333, 0.05575759056955576, 0.04466990088777883, 0.14728616311081819, 0.07247900044811623, 0.13130382714526995, 0.10377429079796587, 0.3895994728165013, 9.976385082517352, 72.74434580121721, 66.70761884961809, 73.67654391697475, 93.09726619720459, 45.30459288188389, 40.10488067354475, 94.94982964651925, 83.73173373086112, 5.442756720951625, 0.289673167679991, 0.0842203636254583, 0.30096871299403055, 0.08966201769986323, 0.2613978534936905, 0.013082772626408508, 0.0602277521310108, 0.4800073972770146, 0.7095890694430896, 0.3953799940645695, 4.002613152776446, 1.510157851236207, 1.4053315733160292, 0.053545569801437, 0.9295433610677719, 63.79025091443743, 78.26892103467668, 65.33987985338483, 83.5622671672276, 86.00259957994733, 82.1711961201259, 87.69503484453473, 90.06329359327043, 85.17960630144391, 78.53548867361886, 73.23154653821672, 67.49758039202008, 63.63671657017299, 66.10461248670305, 70.74728066580636, 79.57066604069301, 79.05838925497872, 80.28224495479039, 80.49258082253593, 80.80753571646554, 78.39090360913957, 74.53743961879185, 74.44603606632778, 71.35250350407192, 69.70393916538784, 81.6280345916748, 68.65199579511369, 71.76530987875802, 70.0356809071132, 75.6932794025966, 75.7553962979998, 74.3117482321603, 73.70113359178815, 73.57831028529576, 70.71176147460938, 65.4536635535104, 70.21117850712368, 77.23314612252372, 71.92720985412598, 73.28943198067802, 68.53023556300572, 71.48964009966168, 68.37031582423619, 69.1025447845459, 69.79628072466168, 59.377206802368164, 66.76751926967076, 68.18991279602051, 69.72828565325055, 66.03507491520473, 68.0028464453561, 64.89080388205392, 68.83002948760986, 66.8707000187465, 64.68358775547573, 61.31331539154053, 62.98069545200893, 63.78629738943917, 66.68357808249337, 66.74093546186174, 66.28537682124546, 68.38694286346436, 69.3989896774292, 67.3828239440918, 71.10631493159703, 65.04541519709996, 69.59531797681535, 65.24063178471157, 65.08860519954136, 65.70842620304653, 63.444161142621724, 66.09571184430803, 66.47412463596889, 64.42586517333984, 62.61030782972063, 62.80827590397426, 60.746835708618164, 57.08494050162179, 58.211170537131174, 60.75076838902065, 60.18060616084507, 62.42701435089111, 58.599043301173616, 58.542825426374165, 58.76504966190883, 61.07278265271868, 62.79558154514858, 64.59906986781529, 66.41084739140102, 62.966910226004465, 62.46009472438267, 63.445258957999094, 57.4316451890128, 55.85643993105207, 59.09652042388916, 45.06900378635952, 13.415192740304128, 2.320480329649789, 4.285096509116037, 0.8589025459119252, 0.9912282739366803, 1.085169221673693, 0.6739069212760244, 0.21640817262232304, 0.03490830272702234, 0.050563832478863854, 0.14688894871090138, 0.032875435559877327, 0.26238903030753136, 0.06981665295149599, 0.21908924090010778, 0.04633447281750185, 0.211238970713956, 19.853970255170548, 78.4272357395717, 82.74097619737897, 52.52007130214146, 39.47327552522932, 38.63925892966134, 21.740239415849956, 32.305684089660645, 66.42440332685197, 58.668038913181846, 69.92313398633684, 37.774413176945274, 0.20333789182560785, 0.1325935729380165, 0.009713670687883027, 0.10851237191153423, 0.09340981088046517, 0.06998484142656837, 0.03984530655933278, 0.08631746431014367, 0.06321699744356529, 0.10751377192458936, 0.04352102914292898, 0.1341892701706716, 0.10515557096472808, 0.23947397992014885, 0.18201719517154352, 0.14738218938665731, 0.10854063289506094, 0.16778861438589437, 0.11792589857109956, 0.09853123035281897, 0.21011742018163204, 0.1613728486533676, 0.18988351949623652, 0.27238091986094204, 0.31508150856409756, 0.5149196524705205, 13.560036625180926, 88.08268179212297, 76.49706091199602, 79.08923230852399, 102.26548371996198, 74.18419320242745, 78.59759862082345, 104.47503866468156, 92.26576137542725, 6.062552971499307, 0.39790696703961914, 0.13750672287174634, 0.29872240924409454, 0.46619996960674015, 0.49159563545669827, 0.601654015481472, 0.16693382311080182, 1.0562888170991624, 1.5123808405229022, 1.0810837894678116, 7.762556995664324, 4.653902113437653, 3.1481241243226186, 0.4611842930316925, 1.2007076676402773, 75.57843957628522, 82.48981966291154, 69.61260509490967, 88.53214686257499, 89.02309267861503, 86.49619265965053, 90.30483382088798, 94.51089804513114, 88.87291431427002, 83.26789283752441, 77.00509234837124, 71.93380369458879, 67.79182965414864, 71.381192616054, 74.35229791913713, 83.35116004943848, 83.33695793151855, 83.66433620452881, 81.90231473105294, 82.60364505222866, 79.70022215162004, 78.99882929665702, 78.11263520377022, 76.34702151162284, 75.57086603982108, 82.75353854043144, 73.21574633462089, 76.63939476013184, 73.36280495779855, 80.07315281459263, 80.39301313672746, 78.24361569540841, 78.89197295052665, 77.5545906339373, 79.25614193507603, 73.60744408198765, 73.73242827824184, 80.80640316009521, 73.58324350629533, 76.20458344050816, 70.9420873097011, 73.522947038923, 70.88527188982282, 73.34348201751709, 72.35071645464215, 60.889259883335654, 67.25726999555314, 69.97551645551408, 70.48388835362026, 69.96886008126395, 69.46223218100411, 68.93830326625279, 72.3130224772862, 70.32211344582694, 68.52936008998326, 65.51890019008091, 67.19226264953613, 68.3788343157087, 69.39810725620815, 70.45858996255058, 69.62413910457066, 72.10106073107038, 71.20453466687883, 69.840151650565, 74.6396267754691, 67.97968115125383, 72.91495881761823, 68.35826764787946, 68.74137047358921, 70.6393404006958, 68.86098371233258, 70.7534784589495, 72.33121980939592, 68.02645642416817, 67.31332111358643, 64.47123691013881, 63.612731388636995, 60.13652678898403, 59.89746012006487, 67.31940078735352, 65.68468420846122, 66.70934895106724, 63.65218326023647, 65.16291618347168, 63.86561802455357, 67.10664694649833, 68.40877410343715, 72.13976219722203, 71.41805280957902, 68.00911372048515, 68.99487549918038, 68.65344102042062, 64.48753043583461, 65.79632786342076, 66.92376341138566, 50.376114300319124, 20.827378136771067, 3.1707678692681447, 4.836031334740775, 1.1328139965023314, 3.197809172528131, 2.2006252067429677, 0.841739898281438, 0.35118464699813295, 0.11253368934350354, 0.5502326233046395, 0.2730041135634695, 0.21970999187656812, 0.7479591390916279, 0.2736513002642563, 0.2249694796545165, 0.13653717775429997, 0.49667731991836, 25.972778013774327, 88.37176854269845, 87.67526721954346, 64.45216410500663, 50.54385771070208, 67.28704997471401, 28.31135926927839, 28.689280475888932, 83.55461025238037, 63.462059702192036, 81.73090962001255, 42.48397513798305, 0.3249082698353699, 0.19530510929014, 0.09364531002938747, 0.18752250261604786, 0.1491895081209285, 0.18919848411210946, 0.15324223493891104, 0.20794172478573664, 0.16332590313894407, 0.254864755485739, 0.2316327749618462, 0.26041870032038006], [0.050491524394601583, 0.09685636165418796, 0.011027852222988648, 0.11473719110446316, 0.048519521818629334, 0.030658383454595293, 0.03942349865766508, 0.1066425261752946, 0.029522644755031382, 0.07024765160999127, 0.01513274057236101, 0.06698743333773953, 0.0910453266863312, 0.09944814829421894, 3.704842891011919, 58.06599834987095, 50.11807557514736, 59.61683627537319, 51.32354981558663, 36.761702810014995, 52.7532320022583, 90.99040562765938, 28.16997037615095, 0.16588977484830789, 0.08535750689251081, 0.013933719152451625, 0.2626701880778585, 0.2570205426641873, 0.11081519084317343, 0.10291497369429894, 0.02136391763841467, 0.2805467631135668, 0.22865653038024902, 1.4343037158250809, 0.582052441579955, 0.0843959820589849, 0.5241670534014702, 0.4681094214320183, 25.660308837890625, 73.81440312521798, 55.630039828164236, 74.80842631203788, 86.92381259373256, 77.90412671225411, 79.09870965140206, 82.33110196249825, 85.75516033172607, 82.40174429757255, 76.77340466635567, 69.55415684836251, 66.41910879952567, 60.490600040980745, 61.00388431549072, 62.86310413905552, 71.2281585420881, 76.78633526393345, 80.77708176204136, 75.96844891139439, 76.93784073420933, 75.5599365234375, 72.45286887032645, 71.59350177219936, 63.15321227482387, 73.22662721361432, 65.44788265228271, 63.40447303227016, 69.18355383191789, 64.98290920257568, 72.33026790618896, 73.64105251857212, 71.41065992627824, 68.1846113204956, 68.85980946677071, 60.528530257088796, 63.76450783865792, 71.26833997453961, 72.97544983455113, 67.6921716417585, 72.3699768611363, 69.88770512172154, 69.41000952039445, 63.295657294137136, 70.41911724635533, 62.58031245640346, 63.369551386152, 66.37401499067033, 68.66025720323834, 66.38793918064663, 61.53024509974888, 63.05724375588553, 64.5461037499564, 62.40636430467878, 61.58232879638672, 64.7227339063372, 60.49288599831717, 63.211215836661204, 61.22740091596331, 64.130295753479, 62.78221321105957, 62.32652255467006, 64.82892322540283, 66.47511822836739, 63.70071642739432, 65.64937346322196, 62.98089000156948, 66.06643213544572, 62.32010241917202, 63.33200332096645, 59.870049476623535, 61.7757944379534, 61.4366181237357, 62.37623691558838, 63.08404295785086, 62.87130996159145, 62.29109369005476, 61.1906727382115, 58.91674968174526, 57.16679375512259, 54.336688246045796, 55.20945494515555, 56.000111307416645, 56.596179894038606, 54.09725679670061, 53.369637966156006, 56.3876679284232, 53.699465479169575, 63.11055728367397, 64.21362549918038, 57.62430483954293, 58.818147795540945, 54.49692760195051, 56.28857619421822, 43.540407044546946, 40.85673829487392, 42.272753374917166, 12.231071182659694, 12.534876823425293, 1.772881833570344, 1.1846933726753508, 0.09381699295980589, 0.1266406766538109, 0.18829162205968583, 0.2286990066724164, 0.13445334242922918, 0.009104609173456473, 0.1643240281513759, 0.09682119996952158, 0.04479008301028183, 0.10061664666448321, 0.07605765520461968, 0.0063969066998522195, 0.03852758137509227, 0.9823970049619675, 41.699158736637656, 69.97740636553083, 82.17788028717041, 97.99507917676652, 69.27303273337228, 49.39808586665562, 38.31614337648664, 55.53843477794102, 38.917892115456716, 60.796049799237935, 24.175775834492274, 0.28086176621062414, 0.005683158682326653, 0.06697250556732927, 0.12188534039471831, 0.04483738029375672, 0.056312995231045146, 0.027807974888543998, 0.08318742976656981, 0.07598348454173122, 0.0274835350657148, 0.07498969536806856, 0.1209676760647978, 0.05997516747031893, 0.05392715075452413, 0.07506923324295453, 0.03542083754603352, 0.02689249544138355, 0.07802391398165907, 0.020743036043963263, 0.08372252248227596, 0.08620248655123369, 0.10322976644550051, 0.050291485485753844, 0.0528621052258781, 0.06807123696697609, 0.26284096177135197, 5.048267534800938, 66.16635417938232, 57.43705088751656, 63.20200947352818, 62.964818818228586, 29.83829539162772, 49.68284388950893, 104.26493208748954, 37.18052979878017, 0.14686251298657485, 0.09022324758448771, 0.5052302266870226, 0.11497361984636102, 0.19744284743709223, 0.05397825122677854, 0.1766262480190822, 0.28104887902736664, 0.16782604237752302, 2.0743069563593184, 4.164467096328735, 0.7056514493056706, 0.25202272513083046, 0.33724284225276535, 0.5961282977036068, 33.95977572032383, 81.64021478380475, 66.37545326777867, 84.48302159990583, 87.81718417576381, 82.844712802342, 81.44308049338204, 85.23316996438163, 86.91305678231376, 85.16428552355084, 78.70567090170724, 72.33862658909389, 68.23468698774064, 65.15480763571603, 64.17959322248186, 66.7657196862357, 74.65209184374127, 79.32182325635637, 81.28243119376046, 77.16753428322929, 79.01007843017578, 77.57888848440987, 73.9648802621024, 73.8273823601859, 66.97360978807721, 76.89277471814836, 68.70522594451904, 68.72271456037248, 72.9860736301967, 70.13259438105992, 76.34916155678886, 74.57555743626186, 74.43444647107805, 70.3923875263759, 72.60733427320207, 65.11543219430106, 68.67860739571708, 74.41540840693882, 74.6214085987636, 71.24159635816301, 73.87422711508614, 73.64479064941406, 71.5248327255249, 65.6832389831543, 72.87702165331159, 63.92686639513288, 67.60345009395054, 68.93266132899693, 71.94068935939244, 68.43730340685163, 65.33197280338833, 65.0729648045131, 67.2850558417184, 63.544868332999094, 63.190670013427734, 67.98565660204206, 63.9938748223441, 66.34973798479352, 64.27642331804547, 65.82113988058907, 63.27987098693848, 66.07556901659284, 67.0716905593872, 68.23476341792515, 66.38409682682583, 67.32781505584717, 64.92760848999023, 68.60927827017647, 66.58280141013009, 65.90738092150006, 62.231200218200684, 64.50780527932304, 63.66480118887765, 65.41031374250139, 66.3636691229684, 63.27506283351353, 64.44953768593925, 63.953596115112305, 63.0429721559797, 61.386646679469514, 60.85015542166573, 62.38675648825509, 61.446665218898225, 63.03660760607038, 60.416983876909526, 59.71339539119175, 59.91965961456299, 60.14814417702811, 68.67240960257394, 66.35369150979179, 60.01315457480294, 64.82633154732841, 59.93976770128523, 63.36010183606829, 52.16354186194283, 49.750015599387034, 54.044606821877615, 40.74892309733799, 8.275983708245413, 2.049854942730495, 1.726931007845061, 0.1740308922848531, 0.16300209265734467, 0.7776018370475087, 2.1736863894121985, 0.5235077887773514, 0.09766775382948772, 0.21432824565895967, 0.10976210449423109, 0.04540195535602314, 0.26920173902596745, 0.2224310122962509, 0.01241645887161472, 0.15374303449477467, 1.5246904428516115, 50.764435223170686, 78.58316721235002, 86.17990371159145, 101.78785065242222, 67.62604563576835, 42.55993284497942, 37.707856382642476, 53.966988495418, 46.67278698512486, 68.71773965018136, 30.590135642460414, 0.14080776859607014, 0.05581022792362741, 0.12405036922012057, 0.10022420236574751, 0.09648637007921934, 0.04605901134865625, 0.062152131726699214, 0.12012186859335218, 0.033822521168206415, 0.10504715463944844, 0.04207978005121861, 0.015886392810248902, 0.1334664946688073, 0.1913859045931271, 0.17893937389765466, 0.24810907085027012, 0.09391670368079628, 0.1308265184717519, 0.11957669284726892, 0.18888064473867416, 0.16912196283893927, 0.16426411350922926, 0.14313130320182868, 0.1396659705787897, 0.2876856300447668, 0.449300973543099, 6.611630891050611, 80.95839500427246, 65.8275044304984, 74.31784875052315, 57.519744873046875, 52.553262846810476, 71.58569199698312, 111.64200128827775, 43.414849621909006, 0.37011153995990753, 0.35130993170397623, 0.5632064299924033, 1.1099522518260139, 1.470626943877765, 0.479216496859278, 0.47804485687187737, 0.4194537651325975, 0.5610970546092305, 3.591027923992702, 5.563473420483725, 2.14677015372685, 0.7658328371388572, 1.6700121249471391, 0.6845889080848012, 43.66212906156267, 86.38113049098423, 68.96565832410539, 87.06715393066406, 91.44037096840995, 86.86217512403215, 83.6629535130092, 89.20561490740094, 90.28089032854352, 88.05850900922502, 82.93591485704694, 77.9967600958688, 73.84225845336914, 67.97064849308559, 65.5388901574271, 71.18636512756348, 76.57508223397392, 83.45810672215053, 86.76615796770368, 80.83560643877301, 81.63977704729352, 81.91598183768136, 78.18147100721086, 79.04231807163784, 73.5109474999564, 79.3433279309954, 72.7736463546753, 75.20380660465786, 76.70238018035889, 73.38103008270264, 80.94216401236397, 81.29178346906389, 78.08539131709507, 76.10384150913784, 78.8544179371425, 71.98296219961983, 73.25135585239956, 77.66622734069824, 78.17648914882115, 72.74157346997941, 75.29700974055699, 77.46197809491838, 74.60731765202114, 69.03803076062883, 76.98444925035749, 65.9991179874965, 67.08466284615653, 72.33167839050293, 74.74029227665493, 73.02670669555664, 66.36011859348842, 67.56638840266636, 69.03839206695557, 67.35044533865792, 67.08689321790422, 72.11431094578334, 66.07825796944755, 68.75738607134137, 67.10767527988979, 70.53813988821847, 66.61250495910645, 70.7468568256923, 70.02675942012242, 70.55490589141846, 66.16458238874162, 70.38736397879464, 65.97335406712124, 72.43700613294328, 69.83849103110177, 69.80379172733852, 65.52819687979562, 68.15905584607805, 66.82746832711356, 68.98882361820766, 69.27852875845772, 69.4530188696725, 69.89337485177177, 69.76963438306535, 66.43912655966622, 64.44606358664376, 63.23481886727469, 67.0044389452253, 62.77031789507185, 65.83425113133022, 64.0768849509103, 66.11515290396554, 66.40941606249127, 66.1998792375837, 71.29955128261021, 71.56923171452114, 65.72700568607875, 71.35245486668178, 65.95553193773542, 70.78492600577218, 61.2278664452689, 60.745119503566194, 61.314892632620676, 46.25584643227713, 12.54215679849897, 2.4929498178618292, 2.4716785592692236, 0.23653975022690638, 0.6509925222822598, 2.2341120498520985, 4.644588487488883, 0.6275905551654952, 0.18253558235509054, 0.5170619775141988, 0.22247055731713772, 0.21799428894051484, 0.7052167526313237, 0.2605380139180592, 0.1625189214412655, 0.20284955017268658, 2.2047967314720154, 59.48764841897147, 85.01457268851144, 97.22784519195557, 101.45941625322614, 86.54229395730155, 68.43728951045445, 53.67256552832467, 66.42302758353097, 53.50536060333252, 79.75052016122001, 38.17039448874337, 0.38612113946250504, 0.1635030007788113, 0.21301405903484139, 0.16992522616471561, 0.14583721943199635, 0.17062883983765328, 0.14855325940464223, 0.15485830179282598, 0.10841447287904364, 0.1428265595542533, 0.14609643337982042, 0.20764422789216042], [0.09161499076123748, 0.03427476475813559, 0.06730209716728755, 0.026390191234116043, 0.030480983866644756, 0.03569851443171501, 0.09477203778390374, 0.08421224834663527, 0.08324408744062696, 0.02313694151650582, 0.008603003857258176, 0.016045819701892988, 0.03264744779361146, 0.09296241881591932, 1.5986974430935723, 47.98279687336513, 64.76647281646729, 48.908199650900706, 27.613879987171718, 38.31444454193115, 61.295236178806846, 75.74628026144845, 1.3418056049517222, 0.09593470075300761, 0.06907562485763005, 0.18343297205865383, 0.4734804875084332, 0.2841464728116989, 0.15082770878715174, 0.13590121402272157, 0.14548553473183087, 0.3629212943570954, 2.36799276300839, 0.4368655708219324, 0.44906734036547796, 0.5852245656507356, 0.44291701753224644, 12.674701503344945, 76.93961947304862, 66.60881546565464, 82.22617721557617, 88.40148598807198, 81.31066172463554, 77.94290460859025, 75.66488906315395, 83.29594271523612, 80.70076274871826, 79.57454313550676, 74.19997950962612, 69.29610770089286, 63.72126919882638, 60.86011219024658, 59.47714969090053, 61.71148191179548, 64.66446631295341, 72.37736279623849, 72.43478270939418, 73.9266790662493, 72.33336680276054, 71.48165661948067, 71.40674114227295, 68.32354749952043, 52.38520676749093, 59.92647579738072, 60.8549496786935, 62.763626779828755, 65.79709911346436, 69.96554579053605, 69.98529257093156, 69.79063878740583, 72.82878031049455, 67.18819795336042, 63.79679611751011, 65.52923910958427, 69.55535193852016, 69.68880598885673, 69.80684893471854, 69.96172428131104, 71.64706543513707, 69.8331687109811, 60.964286531720845, 67.49793475014823, 67.18858705248151, 64.80015768323625, 67.74532536097935, 63.86487456730434, 64.50539425441197, 62.49641990661621, 61.8767100742885, 63.02362142290388, 62.487435885838096, 57.818847451891216, 60.54480293818882, 64.44306196485246, 63.46900790078299, 62.27605084010533, 64.46526840754917, 61.74156066349575, 64.90678473881313, 63.18231133052281, 60.42653070177351, 62.45630100795201, 67.01347160339355, 61.839134216308594, 64.49513176509312, 63.177044595990864, 62.46888419560024, 63.05717427389962, 62.61788831438337, 62.48390620095389, 62.250384194510325, 60.02438981192452, 62.88361522129604, 64.1671837397984, 62.53073705945696, 62.73632730756487, 62.05252034323556, 58.328355380467, 62.405989101954866, 61.37652315412249, 61.945775168282644, 62.01925236838204, 58.13981253760201, 55.056778703417095, 54.082113197871614, 56.309031690870015, 65.58235808781215, 52.52689095905849, 50.996195861271445, 58.694733892168315, 61.70283835274832, 52.65058626447405, 48.23818138667515, 38.58500392096383, 35.916523933410645, 37.184160232543945, 12.986260465213231, 6.823075430733817, 1.364426008292607, 0.6852877991540092, 0.3045208980994565, 0.38221204493727, 0.5669866842882973, 0.5736009350844792, 0.08233892851110015, 0.20376049700592244, 0.190131578328354, 0.17220081548605645, 0.13625558572156088, 0.24883722034948214, 0.05901483007307563, 0.06320833255137716, 0.13581281448049204, 10.877026217324392, 63.51141275678362, 89.51016139984131, 104.50204631260463, 75.2512697492327, 33.03019707543509, 49.65067025593349, 72.03057125636509, 42.90440021242414, 55.590601852961946, 8.281074132238116, 0.17726707006139414, 0.11046611171747957, 0.03463991837842124, 0.08540887199342251, 0.04900994657405785, 0.06399962651942458, 0.0404871905089489, 0.05494445116658296, 0.06915951214198555, 0.050590166422937594, 0.09332280912037406, 0.08993607120854513, 0.05204982416970389, 0.031375608540007045, 0.025980030386043445, 0.017520111752673984, 0.03440256343622293, 0.07870230650795357, 0.09665992576628923, 0.044517858153475184, 0.03292671245123659, 0.025389497966638634, 0.023577203874343207, 0.029749570613993064, 0.026830160125557865, 0.12396526735808168, 2.0069448224135806, 57.27906622205462, 69.39584909166608, 60.35128171103341, 35.975778170994346, 24.540670905794414, 65.65090206691197, 89.84752423422677, 3.4458674618176053, 0.1487481075205973, 0.13060459680855274, 0.4351707531937531, 0.3980357258447579, 0.373152706772089, 0.2202682633485113, 0.09675573491092239, 0.05352190249998655, 1.3805147792611803, 6.512065376554217, 1.1373892767088754, 0.43505314950432095, 0.8955713925617081, 0.4213545588510377, 15.27965497970581, 85.87087563105992, 78.12709440503801, 90.63069738660539, 92.50277832576207, 87.87327003479004, 82.4740264075143, 81.03411647251674, 85.19891534532819, 83.66748373849052, 84.28042602539062, 78.3837400163923, 73.19479056767055, 66.95881012507847, 63.52687249864851, 64.98229081290108, 65.70185320717948, 66.04438550131661, 72.66818659646171, 75.50137710571289, 76.1580513545445, 75.5755282810756, 74.74363436017717, 74.87146731785366, 71.72639301845005, 58.9227876663208, 63.181185722351074, 63.40231909070696, 65.7883860724313, 68.76912157876151, 74.09253256661552, 72.09921251024518, 73.70556654248918, 74.11451666695731, 70.0917111805507, 69.07739925384521, 69.09633309500558, 71.2932492664882, 71.60004697527204, 73.2493200302124, 70.6132082257952, 72.91551467350551, 74.02749047960553, 65.2784091404506, 69.09213638305664, 70.37829657963344, 67.93365628378731, 70.72663061959403, 65.996901512146, 66.69274970463344, 65.4607993534633, 63.62484209878104, 67.4018828528268, 65.96144485473633, 60.1874223436628, 63.17784363882882, 67.71391255514962, 65.84372152600969, 63.973155294145855, 66.47912039075578, 65.7275754383632, 66.30622836521694, 64.67962728227887, 62.95429229736328, 63.461038316999165, 67.42836938585553, 65.40660340445382, 66.52262306213379, 64.21562658037458, 65.53141389574323, 64.99769496917725, 65.15186159951347, 65.7460993358067, 65.15139607020787, 62.18431377410889, 65.43474360874721, 67.86582102094377, 64.40071269444057, 64.7310300554548, 64.32533863612584, 63.922544615609304, 65.83330617632184, 63.0684928894043, 64.87696307046073, 64.30406325204032, 63.426144463675364, 61.25099005017962, 62.2946720123291, 61.95267472948347, 67.99391106196812, 54.80015393665859, 54.08851943697248, 60.841532707214355, 64.04896014077323, 60.59205068860735, 55.14938429423741, 50.274962425231934, 45.01295614242554, 58.48663534436907, 33.647742543901714, 4.598738627774375, 2.508076480456761, 1.074260984148298, 0.5305671585457665, 0.8558519067508834, 3.227302972759519, 0.8350824926580701, 0.2470581829547882, 0.21104010567069054, 0.2457940179322447, 0.13216313746358666, 0.11235695132719618, 0.28031665831804276, 0.07418555673211813, 0.019523028384095857, 0.12874626581157955, 13.606113604136876, 72.45115961347307, 97.86195863996232, 105.69043840680803, 85.42724009922573, 33.61282784598214, 28.4205675806318, 65.52925300598145, 43.756218092782156, 66.72743511199951, 10.984739797455923, 0.16387664287218026, 0.11913766711950302, 0.06983177749706165, 0.08339219127914735, 0.015396283573604055, 0.13108095553304466, 0.02438493535321738, 0.022775195838351334, 0.04666735531230058, 0.009619693587800222, 0.06753703313214438, 0.0759978084159749, 0.11649546532758645, 0.09268497263214417, 0.13424567000142165, 0.09426989472870316, 0.14177875220775604, 0.2299135300729956, 0.19560365112764494, 0.12559584129069531, 0.13459645903536252, 0.16726338756935938, 0.11084992505077805, 0.09274357091635466, 0.21807454606252058, 0.18958761037460395, 2.932005835430963, 68.73531164441789, 81.04071726117814, 64.97593321119035, 31.94258165359497, 56.887253829411094, 77.69488865988595, 100.0048942565918, 4.267807219709669, 0.327760288225753, 0.1677520956311907, 0.37572359453354565, 1.1957912743091583, 0.767450356057712, 0.31551571669323103, 0.39125143417290276, 0.40136681709970745, 1.858918011188507, 10.946188586098806, 5.319723665714264, 1.2409669416291373, 2.06243074791772, 0.6206089183688164, 21.222313744681223, 93.07945101601737, 79.10569953918457, 92.40100806100028, 95.6512086050851, 90.8072372164045, 83.88014030456543, 84.5017192023141, 86.03446401868547, 87.58140400477818, 88.43747765677315, 83.02250330788749, 78.15856279645647, 72.51580565316337, 66.49082115718296, 68.36512551988874, 68.16620554242814, 70.89027459280831, 76.3572006225586, 80.05183574131557, 80.22387313842773, 81.1064680644444, 79.9441247667585, 79.48879541669572, 73.3482415335519, 63.86703545706612, 68.95068495614188, 70.596768787929, 72.9045990535191, 73.93249470846993, 77.0912778036935, 76.33773177010673, 75.39925943102155, 80.75833552224296, 75.04747908455985, 73.34876264844621, 74.84389686584473, 73.78793743678501, 75.94550595964704, 76.37202113015312, 75.31910501207624, 77.25155190059117, 77.40264742715019, 68.11402457101005, 73.74336474282401, 71.91718360355922, 68.63526453290666, 77.73884991237095, 65.75291551862443, 70.02413300105503, 67.74756962912423, 65.53914029257638, 69.39180524008614, 69.82213497161865, 63.28364385877337, 64.91868005480084, 70.45729064941406, 68.17217404501778, 67.66820035661969, 69.38752514975411, 66.29531969342912, 69.89135292598179, 67.4612065723964, 67.10970415387834, 66.8252032143729, 71.33133234296525, 67.37630653381348, 69.42745644705636, 66.62348311288017, 67.374513898577, 68.83386489323208, 69.35006741115025, 70.75205407823834, 69.03883675166539, 65.49861145019531, 68.98093046460832, 71.18227958679199, 68.87968131474086, 69.0528095790318, 68.3859840120588, 68.04776654924665, 69.3737051827567, 66.4802598953247, 68.81224904741559, 68.3062881742205, 67.83954988207135, 63.485030446733745, 66.5541192463466, 66.05996336255754, 71.85510144914899, 59.708851269313264, 59.07691955566406, 68.19310896737235, 72.21762371063232, 66.88989094325474, 62.869288035801475, 58.54340212685721, 55.118169512067524, 61.281061853681294, 37.45033182416643, 8.506227902003697, 2.9019342490604947, 1.717814211334501, 0.5624833287937301, 1.1902380351509367, 8.023021510669164, 1.085008978843689, 0.3649786396750382, 0.62885040470532, 0.689226070685046, 0.2561465624187674, 1.5517646414893014, 1.5916569637400764, 0.16080226855618612, 0.3404023455721991, 0.23454016180975096, 17.598395654133387, 81.58826310294015, 97.89470549992153, 107.55341025761196, 83.34808894566127, 47.67209080287388, 60.046971457345144, 86.18840830666679, 54.13929339817592, 78.28340108054024, 16.269950457981654, 0.45592494096074787, 0.25390867250306265, 0.13519230777663843, 0.1214462603841509, 0.16369265131652355, 0.2234786432236433, 0.12336861794548375, 0.160732949418681, 0.1230168246797153, 0.12335704213806561, 0.16588676215282508, 0.14506082609295845], [0.10631785395422153, 0.1415236366114446, 0.04920796684122511, 0.08847360432680164, 0.07865019501852137, 0.07049859421593802, 0.032280197500118187, 0.03143473947420716, 0.08294056515608515, 0.05989296295280967, 0.037555749594633064, 0.09822676490460124, 0.04817968433988946, 0.0785421451021518, 1.681617136512484, 46.801599638802664, 60.541238512311665, 40.60584579195295, 31.99425540651594, 53.4023813520159, 79.63757719312395, 31.933976309640066, 0.47861433774232864, 0.365903157208647, 0.07900825794786215, 0.3739482755107539, 0.2654851313148226, 0.2347949652799538, 0.0609480170533061, 0.18720352330378123, 0.057767207734286785, 2.3466422515256062, 2.4273292933191573, 0.17700013438505785, 0.3001545252544539, 0.3007424351360117, 4.147985100746155, 70.67653410775321, 77.8959903717041, 82.27462005615234, 83.5836398260934, 81.42101996285575, 80.86622020176479, 74.79270948682512, 77.84439999716622, 80.22280311584473, 83.13687065669468, 78.74233654567173, 74.81144877842495, 68.903562273298, 64.26379844120571, 59.131733894348145, 60.51452268872942, 61.155410630362375, 63.51309422084263, 63.96355288369315, 68.13621711730957, 68.78850705283028, 68.45179040091378, 71.58535848345075, 71.45898464747837, 73.79158524104527, 64.1603536605835, 56.479307719639365, 59.11065305982317, 56.958379064287456, 62.97073173522949, 66.45670550210136, 69.41038472311837, 70.58222620827812, 67.2860563823155, 67.36381367274693, 64.96588611602783, 64.72108718327114, 68.7563785825457, 70.43076242719377, 71.76476097106934, 67.62757423945835, 66.4692053113665, 64.42263426099504, 67.05726609911237, 69.0233075278146, 72.2377734865461, 63.582034247262136, 61.85503169468471, 61.70960589817592, 64.70443929944719, 69.34106254577637, 66.59115314483643, 67.66655363355363, 60.75380475180489, 61.08453900473458, 64.7444817679269, 65.06972694396973, 62.64221395765032, 64.30131871359688, 62.77136707305908, 65.85517910548619, 64.21811403547014, 62.60104588099888, 64.73483766828264, 60.8054507119315, 59.485709871564595, 62.01251956394741, 65.23899895804269, 64.9071043559483, 61.75251797267369, 62.259326526096885, 59.72247668675014, 61.637018067496165, 60.392998695373535, 61.70833437783377, 63.15444210597447, 61.95580836704799, 62.7572135925293, 60.56502914428711, 62.67956052507673, 64.93929536002022, 61.41437694004604, 60.035909925188335, 61.895379883902415, 60.46645505087716, 62.607584135872976, 59.546833174569265, 59.29056971413748, 57.03035545349121, 46.42393030439104, 50.29860714503697, 53.78259720121111, 48.25146286828177, 47.39836651938302, 52.73316560472761, 52.593986238752095, 51.24061264310564, 41.88608264923096, 28.041077818189347, 28.6423818724496, 17.38845235960824, 5.162850712026868, 0.7526695291910852, 0.12054408022335597, 0.635050043463707, 0.19074186629482678, 3.750159042222159, 1.6947718134948184, 0.29830961568014963, 0.09103370338146176, 0.08387158984052283, 0.05016466050541826, 0.17420748780880654, 0.09202458163989441, 0.05461376712524465, 0.029241208785346577, 0.4821143299341202, 41.78348554883684, 71.49218314034599, 104.04914883204869, 72.96095589229039, 29.522753374917166, 60.10821982792446, 47.374645369393484, 53.422906330653596, 48.51214190891811, 4.369508871010371, 0.3985703300152506, 0.09607098451150314, 0.05996679434818881, 0.07504831400832959, 0.09909396658518485, 0.06646844904337611, 0.03193416838933315, 0.08006114752164908, 0.1486205022249903, 0.08674475816743714, 0.05269974197394081, 0.07364005528922592, 0.05028242704325488, 0.10004865857107298, 0.04277024371549487, 0.08998420648276806, 0.02637737031493868, 0.10363403760961123, 0.01651077394905899, 0.02342738164588809, 0.025466966309717724, 0.04733083703156028, 0.06194955509688173, 0.19623425443257603, 0.023940771419022764, 0.18647888861596584, 2.118081910269601, 56.244458607264924, 67.75647721971784, 51.81182404926845, 29.497083255222865, 39.531060218811035, 93.03051485334123, 42.32987104143415, 0.4505961069038936, 0.0541327468651746, 0.11035696257437978, 0.7167875660317284, 0.11543260807437555, 0.2878260596522263, 0.13142722552376135, 0.1075557189594422, 0.3667208733303206, 3.5301224035876135, 4.730291477271488, 0.35263823185648235, 0.5689484104514122, 0.33285535339798245, 5.217477449348994, 79.98196465628487, 87.52529035295758, 90.3765253339495, 87.3212217603411, 85.87582274845668, 82.5754840033395, 77.216630254473, 78.75539221082414, 82.67063958304269, 86.10952540806362, 81.76150253840855, 78.27195739746094, 70.84767518724713, 67.86100591932023, 62.957280022757395, 63.931445258004324, 62.483517101832796, 67.09899697984967, 68.0444244657244, 70.56261144365583, 72.17517716544015, 73.23645196642194, 75.79246493748256, 74.19797148023332, 76.04552527836391, 69.09228924342564, 65.5333593913487, 68.02226666041783, 64.38091727665493, 66.36260604858398, 68.70252309526715, 72.65335219247001, 72.3207905633109, 70.80116394587925, 71.12468596867153, 69.42576803479875, 67.06571510859898, 72.16105842590332, 72.60832786560059, 74.58817536490304, 67.59529985700334, 69.66209711347307, 66.30423423222133, 69.90680571964809, 72.23491777692522, 74.97858074733189, 65.34710597991943, 65.6926190512521, 62.96608339037214, 69.48807947976249, 69.87570558275495, 67.40716348375592, 68.80150018419538, 62.61495617457798, 63.19743061065674, 66.84640216827393, 70.74220848083496, 64.71056066240583, 66.06149891444615, 64.99356079101562, 68.96216338021415, 67.65215001787458, 66.7023104258946, 66.6781029020037, 63.68804291316441, 62.17740726470947, 63.59169919150216, 66.97903633117676, 67.8465050288609, 66.03497069222587, 65.23952007293701, 64.6484854561942, 64.74008355821881, 63.93243190220424, 63.78392110552107, 66.53710310799735, 64.42380155835832, 66.38212353842599, 63.130498613630024, 63.598890577043804, 66.52739647456578, 63.300340379987446, 63.89806611197335, 62.57815851484026, 64.48610605512346, 66.5587467466082, 62.42798015049526, 61.677407945905415, 60.48256097521101, 51.15195362908499, 53.54898139408657, 58.735311371939524, 54.165258816310335, 51.83279371261597, 57.68690810884748, 57.69472483226231, 57.02990729468209, 52.142457553318565, 41.96829720905849, 51.23836490086147, 27.348026275634766, 4.1272260546684265, 1.9871830599648612, 0.1278329576764788, 0.9922364141259874, 1.1100726510797227, 5.191070820604052, 2.327385753393173, 0.10219088861984865, 0.16512379023645604, 0.07422260474413633, 0.061222776238407405, 0.03060124402067491, 0.2572653309575149, 0.03192505905670779, 0.043857144857091565, 0.29419842628496035, 47.738004888807026, 79.1507933480399, 106.63347571236747, 78.69128118242536, 34.869930676051546, 52.56204536982945, 54.81461661202567, 58.19254241670881, 58.81368705204555, 6.31649877343859, 0.26876457248415264, 0.16005928628146648, 0.021069701461653625, 0.08361711885247912, 0.045064099199537716, 0.11367047977234636, 0.07574225177190133, 0.07690405300153152, 0.1331414356827736, 0.09805653403912272, 0.10487053875944444, 0.06524965765752963, 0.15975260202373776, 0.21541387454739638, 0.12190284659819943, 0.19488508254289627, 0.212320351973176, 0.18229772868965352, 0.1300160355333771, 0.10475991719535419, 0.11621271978531565, 0.1645421500184706, 0.15659798415643827, 0.2695550114980766, 0.13556003304464476, 0.3036131810929094, 3.572502940893173, 65.6466497693743, 77.70603357042584, 49.478629384722026, 40.592487880161826, 75.336656161717, 100.71892588479179, 50.6540561403547, 0.6139004869120461, 0.5185461778725896, 0.2748488874307701, 1.9262736311980655, 1.461635974901063, 0.34361347183585167, 0.4593646249600819, 0.35201970647488323, 0.7512712042246545, 6.197833963802882, 8.494299582072667, 0.818186373582908, 1.2077951558998652, 0.7188166571514947, 6.969168254307338, 89.48461982182094, 87.28832898821149, 96.5344705581665, 92.60986396244594, 89.74647658211845, 86.40489333016532, 79.85768222808838, 81.54451029641288, 84.83412102290562, 90.75975322723389, 86.42830875941685, 82.70184394291469, 76.30613136291504, 72.58555167061942, 67.01263781956264, 69.18083013807023, 67.11522102355957, 70.7295002256121, 71.01344530923026, 75.20409148080009, 77.83671528952462, 76.6727739061628, 79.47554520198277, 80.19491999489921, 79.5326316016061, 73.97335011618478, 71.18929031917027, 70.12149115971157, 66.65799481528146, 72.51780673435756, 75.00576904841832, 76.86026409694126, 76.91801752362932, 75.39520863124302, 74.32387978690011, 75.54289259229387, 72.33092103685651, 74.88208416530064, 74.36176136561802, 78.05265140533447, 72.14581407819475, 74.1415799004691, 69.26208932059151, 71.54519789559501, 73.2206587110247, 77.4283696583339, 69.43424483707973, 67.19559778485979, 65.09774902888707, 70.55796309879848, 73.54657786233085, 71.05459254128593, 71.67387158530099, 64.6031415121896, 65.66249861036027, 71.29372869219098, 73.21573938642229, 66.66536685398647, 69.78767190660749, 68.7370834350586, 70.87876837594169, 70.98914745875767, 68.66100760868618, 68.39116042000907, 65.68828337533134, 63.83785997118269, 66.23314026423863, 69.56673308781215, 70.32568481990269, 67.03022371019635, 66.33511897495815, 66.80178778512138, 66.48761803763253, 66.8607988357544, 66.73757253374372, 68.41308198656354, 68.05053888048444, 68.48040308271135, 66.66858386993408, 67.20346314566476, 72.63370963505336, 66.29638971601213, 65.822279385158, 66.62433774130685, 66.55008929116386, 68.1213549205235, 69.52484934670585, 66.93257372719901, 63.7945032119751, 57.201055322374614, 58.39526653289795, 61.39399092538016, 57.07746423993792, 59.387281690325054, 66.47735554831368, 66.48757634844098, 64.80977399008614, 59.498709951128276, 51.168935026441304, 50.14072322845459, 30.769162927355083, 8.807212574141365, 2.389257073402405, 0.33504949137568474, 1.9649251571723392, 2.8661642713206152, 9.220072797366551, 3.9844501273972646, 0.47787636305604664, 0.25212827803833143, 0.2676917814782688, 0.09201981153871332, 1.615973161799567, 0.39550894285951343, 0.16683581551270826, 0.14763449584799154, 0.9269667736121586, 56.79522493907383, 83.70237759181431, 109.28886876787458, 78.16596262795585, 46.2110652923584, 72.87941878182548, 59.958673749651226, 66.29638971601213, 71.48652730669293, 9.129168646676199, 0.4380645693412849, 0.324719175696373, 0.09785253248576607, 0.2151840411658798, 0.1414228877318757, 0.15889760718813964, 0.1679607451494251, 0.178846129615392, 0.24590274638363294, 0.2151981818356684, 0.1651472539774009, 0.16403136242713245], [0.061424185787992816, 0.024720825454486266, 0.1528218010706561, 0.10517528240701982, 0.020469009676682096, 0.0850751752566014, 0.04469335445069841, 0.1053092320050512, 0.033312669955193996, 0.10017296618648938, 0.037449792958796024, 0.21972167624958924, 0.03862585699451821, 0.20307599087910994, 1.91951042839459, 54.41997977665493, 55.68619169507708, 51.59723240988595, 54.859112875802175, 57.46173783711025, 82.13637174878801, 7.196372611182077, 0.17460197449794837, 0.046959067694842815, 0.17726295813918114, 0.8225245465125356, 0.2680623158812523, 0.36861037622605053, 0.3680870628782681, 0.06833027449569531, 0.06473655626177788, 0.45425066937293324, 0.5015845937388284, 0.6226425692439079, 0.6857691247548375, 1.7162402272224426, 51.52608633041382, 84.24174540383476, 81.12148312159947, 82.9058222089495, 81.22333676474435, 78.33958421434674, 74.31982898712158, 74.08390985216413, 79.26140172140938, 80.16641848427909, 81.47353444780622, 75.87152848924909, 72.65768786839077, 66.31639357975551, 64.29717758723667, 60.25962802342006, 59.89957932063511, 58.643470082964214, 64.03958007267543, 65.46752520969936, 64.52580806187221, 64.7969059262957, 65.61693927219936, 67.35872759137834, 69.40731361934117, 69.80500071389335, 70.66123417445591, 70.38390377589634, 67.75396892002651, 68.41156727927071, 63.55440126146589, 66.23513439723423, 65.83354241507394, 65.24669756208147, 68.54074123927525, 70.44786889212472, 59.01657445090157, 67.85847677503313, 69.40814045497349, 69.82658876691545, 67.49473857879639, 64.17405550820487, 64.57496656690324, 65.4823248726981, 67.47226810455322, 69.88649613516671, 60.57943275996617, 62.67660754067557, 62.02306692940848, 59.32063456944057, 67.66236386980329, 58.67721748352051, 61.603882108415874, 60.98096220833914, 62.19939136505127, 58.88928345271519, 63.84537097385952, 61.54817840031215, 61.32480771200997, 64.01763071332658, 62.55944006783621, 63.724868365696494, 62.556827545166016, 64.8039652960641, 63.93025711604527, 67.24958528791154, 67.6184720993042, 59.97646113804409, 60.59876264844622, 62.95924636295864, 63.41253294263567, 60.2232472555978, 60.77018165588379, 62.00819083622524, 63.47022383553641, 60.60013839176723, 59.71916239602225, 61.16704191480364, 60.04815265110561, 62.99650955200195, 62.996829169137136, 59.30914224897112, 60.00435815538679, 61.463868958609446, 62.62675421578543, 63.791147232055664, 60.424355915614534, 54.236519541059224, 50.49067619868687, 46.004210472106934, 53.14762912477766, 56.06876993179321, 58.882272720336914, 59.1472144808088, 51.01054736546108, 45.965710503714426, 42.63995177405221, 47.12171009608677, 50.27495895113264, 48.295868805476594, 27.483227797916957, 16.448731081826345, 19.229777097702026, 3.3756806680134366, 0.6939517142517226, 0.030382630215691667, 0.8645064852067402, 0.28291561028787066, 0.31368948040263994, 0.12891698522227152, 0.11642879247665405, 0.07033728608595473, 0.10824088326522283, 0.11252752146018402, 0.2785334682890347, 0.08727880593921457, 0.0722109859011003, 0.0434549500101379, 8.26901466505868, 69.3629424231393, 57.131298882620676, 36.48882620675223, 22.219243015561783, 44.133713722229004, 43.6239070211138, 46.920691762651714, 28.004665783473424, 0.17768268633101666, 0.014251574641093612, 0.09379571410162107, 0.02828001304130469, 0.07873763782637459, 0.09968850575387478, 0.2155013241405998, 0.03844671017889466, 0.07378935334937912, 0.060498290828296115, 0.02365971033993576, 0.05269251557599221, 0.07220752537250519, 0.021705122365217124, 0.06631388555147819, 0.1412665939756802, 0.07995559461414814, 0.04724070383235812, 0.09339767188898154, 0.018980583741462657, 0.1411053469138486, 0.049723093664007526, 0.025668850833816186, 0.007570674742705056, 0.1551749605153288, 0.12846000545791217, 0.19937870784529618, 2.7197906970977783, 62.973726408822195, 58.90840489523751, 51.42448282241821, 31.676413536071777, 56.70681258610317, 95.01563603537423, 11.749246614319937, 0.22596984383250984, 0.05281575110607913, 0.3236488816993577, 0.7888485821230071, 0.5386962252003806, 0.09020960224526269, 0.13042701062347206, 0.24609395755188807, 0.21123399026691914, 0.7454096930367606, 0.7676595076918602, 1.880753593785422, 1.1635911507265908, 2.2211703785828183, 62.07303837367466, 94.44223594665527, 88.40178476061139, 87.48207255772182, 85.57417365482875, 80.91453102656773, 77.36828163691929, 76.69842665536063, 82.4419813156128, 83.55022593906948, 83.5056324005127, 78.62870570591518, 76.8190334865025, 70.49934809548515, 66.95758029392788, 64.0656566619873, 63.236298833574565, 63.64258779798235, 65.54845782688686, 68.90661948067802, 67.51256070818219, 69.30261816297258, 68.62318161555699, 70.12471512385777, 72.16788155691964, 73.55020482199532, 74.39676639011928, 71.8367234638759, 72.52481746673584, 72.89521898542131, 69.07613468170166, 71.23295974731445, 69.95319189344133, 69.19825622013637, 71.42727306910923, 71.46630110059465, 64.78710896628243, 70.37253652300153, 71.6269087110247, 74.4994260243007, 67.93949971880231, 69.2068372453962, 68.13621711730957, 69.22017778669084, 70.96818474360875, 72.08799811771938, 62.14946855817522, 67.42398507254464, 65.8361896787371, 63.415888922555105, 68.33008575439453, 59.80552850450788, 63.64200414930071, 62.91114398411342, 63.822052819388254, 60.623345375061035, 66.4591373716082, 63.897635323660715, 65.18424715314592, 67.02775709969657, 66.01766272953579, 66.71797861371721, 65.74350070953369, 66.9104367664882, 64.93181215013776, 67.15640994480678, 71.02128287724086, 63.07777568272182, 63.54305485316685, 64.59173257010323, 66.1012773513794, 62.790210587637766, 64.08818967001778, 66.87845420837402, 65.35067040579659, 63.47651890345982, 62.271180152893066, 63.773630823407856, 62.13380037035261, 65.81847177233014, 65.39273480006626, 63.52827603476388, 62.16053009033203, 62.81994192940848, 66.053619657244, 65.22824314662388, 60.79088033948626, 58.214182581220356, 54.64764445168631, 53.65622336523873, 60.105009760175435, 63.25572599683489, 62.7011833190918, 64.42356531960624, 57.447712898254395, 52.98777539389474, 49.024564606802805, 53.562176023210796, 55.54259327479771, 55.54953452519008, 43.875661100660054, 37.40963969911848, 23.84155532291957, 3.560680146728243, 1.5650644706828254, 0.07552180252969265, 1.62391516992024, 0.6569796981556075, 0.873879496540342, 0.14195495418139867, 0.1284668586616005, 0.0974425548421485, 0.04483308855976377, 0.06207313667982817, 0.6919936793191093, 0.14097972294049604, 0.03764658168490444, 0.09897402194993836, 10.645520056997027, 77.1812778200422, 65.5754724230085, 47.2987745148795, 26.168239525386266, 45.636584758758545, 45.01645108631679, 55.694842202322825, 36.32202427727835, 0.6053242385387421, 0.06586269369082791, 0.07509678176471166, 0.06283755387578692, 0.03733004509870495, 0.059622661742780886, 0.12593881360122136, 0.0220203086667295, 0.06440672717456307, 0.08988892659544945, 0.025868155228506242, 0.03577765536361507, 0.09722629216100488, 0.1347098829490798, 0.13346711892102445, 0.20948460485254014, 0.17855748081845896, 0.11745233541088444, 0.257966230490378, 0.14807812204318388, 0.2125276987041746, 0.14740074053406715, 0.18960439733096532, 0.1620433498173952, 0.3180583231151104, 0.4370983083333288, 0.41960393850292477, 4.119120112487248, 75.41280147007534, 70.71005916595459, 61.808075768607004, 71.93028790610177, 74.17705045427594, 101.42288957323346, 15.997720037187849, 0.5391473152807781, 0.4513846460197653, 0.4705714178936822, 2.4476534255913327, 1.0219342091253825, 1.3727628695113319, 0.9408598052603858, 0.5255321572933878, 0.6853872452463422, 2.110012011868613, 2.052779700074877, 3.733041286468506, 2.855447543518884, 3.248079823596137, 72.4705867767334, 97.44392721993583, 91.50972788674491, 90.1460188456944, 88.90673119681222, 86.58718626839774, 81.24669660840715, 79.67846039363316, 83.18225628989083, 84.69800581250871, 88.45002610342843, 83.64477007729667, 78.6155458177839, 74.43873350960868, 70.38982364109584, 67.63361917223249, 66.75298363821847, 67.16633892059326, 70.25094999585832, 72.15148380824498, 70.85199696677071, 73.60531098502022, 73.19053827013288, 75.08613886151994, 77.93919427054269, 78.31883689335415, 77.93947219848633, 73.53832340240479, 75.84882872445243, 76.0939611707415, 72.2627592086792, 75.94818796430314, 73.9463563646589, 73.92508098057338, 76.60925347464425, 79.3110466003418, 68.61946432931083, 72.00967802320207, 74.10847173418317, 77.10447243281773, 72.78274849482945, 71.36572592599052, 71.16379043034145, 70.91990171160016, 72.46187373570034, 76.3808661869594, 66.55039501190186, 69.33529554094586, 68.56677613939557, 62.6200908933367, 72.97967433929443, 64.45806312561035, 66.21849346160889, 67.6654280253819, 67.54920550755092, 63.734491620744976, 67.09211826324463, 66.01393154689244, 66.63824108668736, 69.94079630715507, 68.20610904693604, 68.27461828504289, 68.28094114576066, 69.3108239855085, 67.41107531956264, 70.02048519679478, 71.59441198621477, 65.15569700513566, 65.90331622532436, 68.81521592821393, 69.19281578063965, 66.179354258946, 65.36351762499127, 68.50306115831647, 67.752516746521, 67.08014651707241, 66.74691091264997, 67.70583180018834, 68.1435683114188, 68.3559330531529, 66.91864953722272, 66.46777398245675, 64.61578028542655, 67.00851058959961, 67.21999291011265, 70.66304765428815, 67.54210444859096, 60.90776293618338, 58.98582172393799, 60.678173610142295, 63.43801893506731, 65.43880135672433, 67.20732634408134, 69.87652547018868, 62.90528665270124, 58.5213554927281, 55.63484798158918, 60.805506297520225, 62.494099208286826, 61.89599827357701, 47.627132483891074, 35.3416543006897, 26.76188840184893, 7.34128337247031, 1.629633320229394, 0.13222829039607728, 2.7269521185329983, 0.9549916812351772, 1.0852309955017907, 0.36602838763168877, 0.5670279935002327, 0.1595687868871859, 0.32818488829902237, 0.22956498020461627, 0.4502565951219627, 0.21302724975560391, 0.272279221032347, 0.20401631827865327, 13.50338101387024, 85.46504524775914, 65.17237962995256, 51.91256945473807, 34.71051468167986, 52.459792205265586, 59.135138511657715, 63.41368634360177, 47.6020564351763, 1.1487494728394916, 0.13373370175915106, 0.18228440226188727, 0.1579297719789403, 0.25398613406079157, 0.2081711646169424, 0.27554986838783535, 0.16502608119377069, 0.15395936502942018, 0.11631644064826624, 0.06680755370429584, 0.09994120576551982, 0.19189110105591162], [0.10376941891653196, 0.04090623338041561, 0.05064635590783187, 0.038054293021559715, 0.0387034746153014, 0.08404869426574026, 0.13954308788691247, 0.02392694117900516, 0.05158666634399976, 0.06288526845829827, 0.11795844111059393, 0.08028678755675044, 0.07850477139332465, 0.42235211389405386, 5.934106835297175, 57.1428085735866, 39.65218121664864, 38.01063455854143, 38.685151781354634, 73.11915942600795, 56.280061176845, 1.0418274445193154, 0.2385358102619648, 0.055046414623835256, 0.02899538233344044, 0.3927687198988029, 0.21026653503733023, 0.28942615379180225, 0.2129597898040499, 0.32222669944167137, 0.4064447560480663, 0.9187457518918174, 0.6395184408341135, 1.496671506336757, 0.36005174262183054, 22.824606554848806, 63.806162289210725, 80.2790835244315, 80.62615299224854, 83.72584860665458, 75.2223791394915, 72.88460213797433, 69.89732837677002, 76.88648659842355, 82.55138070242745, 82.02586759839738, 79.87325314113072, 75.83392483847481, 69.84377861022949, 67.83537401471818, 63.80095114026751, 59.838483810424805, 61.362730979919434, 60.31991754259382, 62.78345693860735, 64.5158304486956, 66.14119475228446, 65.07793276650565, 64.73459448133195, 64.47340474809918, 67.05452850886753, 69.77488027300153, 66.44395555768693, 65.69250093187604, 70.28612872532436, 68.32691042763847, 70.03425652640206, 71.2222456250872, 67.37903022766113, 68.67056832994733, 68.63084547860282, 60.17977237701416, 66.71736022404262, 70.79663372039795, 71.91099970681327, 66.85789448874337, 64.21942029680524, 68.01066316877092, 66.45399570465088, 70.79290948595319, 69.30600888388497, 58.141702447618755, 62.4573849269322, 66.07169886997768, 62.641102245875764, 66.19223621913365, 55.99137394768851, 59.333447047642295, 62.26945005144392, 61.512805121285574, 59.141878264290945, 56.75053412573678, 57.719985008239746, 62.04488427298409, 60.05533708844866, 63.67019993918282, 64.00188609531948, 64.80256175994873, 64.80394445146833, 64.15548992156982, 61.943760190691265, 65.34509100232805, 63.53850378308977, 67.7030942099435, 60.997533661978586, 60.12481212615967, 59.43168762751988, 64.84596715654645, 63.968395778111045, 61.49690069471087, 61.63026441846575, 65.88170037950788, 62.08293955666678, 57.07125949859619, 54.99772596359253, 60.01339776175362, 60.79755061013358, 59.945673670087544, 59.420021602085654, 61.53961821964809, 60.621733392987935, 58.61020905630929, 54.40874801363264, 51.348268032073975, 56.23684338160923, 57.68260717391968, 57.83476230076381, 53.85232237407139, 58.006421021052766, 58.36966242109026, 61.927973883492605, 58.947273118155344, 47.03463874544416, 41.54645470210484, 45.25752231052944, 51.61666304724557, 53.22325679234096, 35.33943435123989, 23.324560710362025, 21.809420892170497, 1.5274439922400882, 0.2181478278445346, 0.16387208311685494, 0.30470440110989977, 0.5385688234652791, 0.39264823922089165, 0.05720139095293624, 0.41109337231942583, 0.13732316557850155, 0.04848473332822323, 0.903992337839944, 0.10655637936932699, 0.12862868926354817, 0.0077709884582353485, 0.36709186913711683, 37.671677112579346, 61.16081632886614, 25.57880994251796, 29.291941165924072, 39.44902283804757, 56.54657670429775, 49.027830260140554, 23.68294358253479, 0.21442533044942788, 0.10459432072405304, 0.06730244322014706, 0.07971749667610441, 0.12743743961410864, 0.043155122348772626, 0.104013895083751, 0.051475732653800926, 0.012167748645879328, 0.08569545804389886, 0.10825207230768033, 0.05112526931666902, 0.04072780241923673, 0.04463490544419203, 0.011555026435027165, 0.06047051838998284, 0.013370245013252964, 0.14837609391127313, 0.08475131049220051, 0.06998007811073746, 0.05010948882305196, 0.044078191210116656, 0.025842474374387945, 0.15062451469046728, 0.08778098970651627, 0.07662696644131627, 0.5541432648897171, 8.48484742641449, 65.99715164729527, 48.92903382437569, 48.998085021972656, 32.41511126926967, 80.98902961186, 66.45754623413086, 1.2204532538141524, 0.06506342693631138, 0.03318412149591105, 0.24421642401388713, 0.19538415861981256, 0.16359471157193184, 0.06111460418573447, 0.3167886755296162, 0.4607514419725963, 0.7926202597362655, 1.1748626487595695, 2.779985547065735, 2.7693726079804555, 0.6011182985135487, 31.18049280984061, 75.34563323429653, 88.3183924811227, 85.66055365971157, 87.97471373421806, 79.24054322923932, 76.94266973223004, 73.25863756452287, 79.80599457877022, 84.38838018689836, 84.59761129106793, 82.28339563097272, 80.0977008002145, 74.01619270869664, 69.86464405059814, 67.22506509508405, 63.5912892477853, 63.179455620901926, 63.70755345480782, 65.60138920375279, 68.26992130279541, 69.34605135236467, 67.52932671138218, 68.41377680642265, 67.13208430153983, 70.5070605959211, 71.49904796055385, 70.4465765271868, 70.06515516553605, 73.32363796234131, 72.42695903778076, 73.18023409162248, 73.30285590035575, 71.02238764081682, 71.96475097111293, 69.10289914267403, 64.73512254442487, 71.58203724452427, 71.54279381888253, 72.57259328024728, 68.29132175445557, 65.97123486655099, 70.21906471252441, 70.16287463051933, 73.42092663901192, 70.66612570626395, 60.62242126464844, 67.97426850455147, 67.4878876549857, 64.65735830579484, 67.94348103659493, 58.34547574179513, 64.33377374921525, 66.05925464630127, 64.58686188289097, 63.26188904898507, 59.38487761361258, 58.3873872756958, 66.03738866533551, 61.58369064331055, 64.41515799931118, 65.99080099378313, 66.41133376530239, 65.78762177058628, 67.38028090340751, 63.64990425109863, 67.39816556658063, 64.77932003566197, 68.46393585205078, 64.45417213439941, 61.18539210728237, 62.74558230808803, 63.06127371106829, 66.26563004084996, 65.56148569924491, 64.6309620993478, 65.75312396458217, 66.41225787571499, 60.30068492889404, 59.12632819584438, 61.07380403791155, 62.563824381147114, 61.56959274836949, 62.15718105861119, 61.371770586286274, 60.22442844935826, 59.89734200068882, 60.773356982639854, 57.182611329214915, 62.2696168082101, 61.7939361844744, 64.33108479636056, 60.91791425432478, 63.11230822971889, 62.80061204092843, 64.9068055834089, 63.48603098733084, 54.96801199231829, 47.79808596202305, 49.324789319719585, 54.97942788260323, 57.0123735155378, 54.17092159816197, 37.87499182564871, 27.731155157089233, 3.0513817497662137, 0.5835795253515244, 0.152189379291875, 0.7492577465517181, 2.6204149552753995, 0.6221594523106302, 0.22978116146155766, 0.425535827342953, 0.3137720174023083, 0.12984242556350573, 0.14253586158156395, 0.04551107396504708, 0.13201096920030458, 0.05981571174093655, 0.4567446655460766, 43.26372282845633, 64.49619483947754, 28.61014744213649, 30.95456518445696, 46.42745304107666, 57.40285880225045, 57.90214940479824, 28.874469075884136, 0.10276009807629244, 0.031318272330931256, 0.0023011505836620927, 0.0687105255201459, 0.08285511724118676, 0.09686073820505824, 0.10482730929340635, 0.06382634903171233, 0.038617762071745734, 0.05849856670413699, 0.03748632528420005, 0.03727988100477627, 0.06890656785773379, 0.25807221766029087, 0.09883862707231726, 0.09777822611587388, 0.08538021067423479, 0.21355681919625827, 0.12855210980134352, 0.17864005853022846, 0.0908465769940189, 0.10555402708372899, 0.08493583130517177, 0.26182212787015097, 0.16780613416007586, 0.38226062804460526, 0.7074682403888021, 11.63311789716993, 82.35754680633545, 53.723294326237266, 49.70270878928048, 57.701923166002544, 90.35310990469796, 76.29221412113735, 1.7746440704379762, 0.30357958003878593, 0.23521359424505914, 0.8879597495709146, 2.8705716005393436, 0.38366951101592606, 0.7585049846342632, 0.5495766156486103, 1.4864412610019957, 1.631289271371705, 2.9398418835231235, 5.1143158078193665, 5.0374695999281744, 1.0442874325173241, 38.70348112923758, 81.04839502062116, 91.38132517678397, 89.77804224831718, 91.02281202588762, 83.96349089486259, 79.85878004346574, 75.80807059151786, 84.24541405269078, 88.9152010508946, 88.20905562809536, 86.12216418130058, 83.03434303828648, 77.89779690333775, 74.0083065032959, 71.20399270738874, 65.39026818956647, 66.86305700029645, 65.47123554774693, 69.82251712254116, 71.98436573573521, 71.56404835837228, 72.17747007097516, 72.31343936920166, 71.35667937142509, 77.75314930507115, 77.658111844744, 74.37071064540318, 74.42556667327881, 76.817734173366, 78.39374542236328, 77.52752045222691, 76.55231993538993, 75.3046110698155, 75.04811137063163, 75.71754946027482, 66.40260682787213, 75.47550896235875, 76.62790243966239, 76.46094417572021, 72.4834965297154, 69.22372136797223, 73.1816793169294, 72.43601948874337, 76.16338757106236, 74.95975112915039, 64.97218118395124, 70.57119246891567, 71.55562019348145, 65.70762021200997, 71.91980307442802, 61.76784569876534, 66.08705438886369, 67.88158648354667, 67.43849985940116, 66.4073177065168, 62.41620990208217, 63.63007409232003, 67.9768601826259, 64.39120755876813, 67.93455954960415, 69.71620968409947, 70.10431521279472, 69.65296023232597, 69.0332156590053, 66.92281150817871, 69.88705893925258, 67.75294753483364, 71.87187440054757, 64.41325419289726, 62.57387842450823, 65.42391831534249, 66.756881577628, 67.81974056788853, 67.5423059463501, 68.46069799150739, 69.78851958683559, 68.6699082510812, 62.290857451302664, 62.52089146205357, 66.96702289581299, 67.19057423727853, 64.68997314998082, 65.84487492697579, 66.35579681396484, 66.2125597000122, 64.3789370400565, 58.7712960924421, 61.00649683816092, 65.39619500296456, 65.5512648991176, 67.82126917157854, 64.69235638209751, 65.85844475882394, 67.12771388462612, 69.63927228110177, 67.7382868358067, 57.90166997909546, 52.1084634917123, 57.360777037484304, 61.57654789515904, 64.28353827340263, 54.150219440460205, 37.923802920750205, 35.611195768628804, 7.478144645690918, 0.8801531770399639, 0.44755057032619205, 1.3951226068394524, 4.054123188768115, 1.139108738728932, 0.2696509563497135, 0.6688803338578769, 0.8224885570151466, 0.31599278109414236, 2.4068462210042134, 0.3000168912112713, 0.2474273331463337, 0.11664949277681963, 1.4552288672753741, 53.576145376477925, 74.97151442936489, 38.657108851841514, 42.070737974984304, 50.22874995640346, 67.6018659046718, 66.52901540483747, 36.798997265951975, 0.22847598578248704, 0.13713264651596546, 0.20279563378010476, 0.256382909736463, 0.1729943621903658, 0.22059995840702737, 0.11581748670765332, 0.1310251663838114, 0.11640338812555585, 0.13598388672939368, 0.2230823787727526, 0.09364373582814421, 0.10998029421482768], [0.0350708322200392, 0.03505409615380423, 0.016230930840330463, 0.013158778726522411, 0.030839314817317894, 0.07558928962264742, 0.05607358093506523, 0.040308294751282246, 0.0619203509496791, 0.012832829163276722, 0.010074412982378687, 0.19598995468446187, 0.06039332824626139, 0.22202900743910245, 17.56834990637643, 57.99332366670881, 38.64346258980887, 44.64930132457188, 36.98403474262783, 87.31869956425258, 26.30058012689863, 0.1786297990807465, 0.135439932346344, 0.06855165333087955, 0.11088299006223679, 0.295388115303857, 0.331422178872994, 0.04120274979088988, 0.06539605837315321, 0.06722663728786366, 0.6194843958531107, 0.23682115226984024, 0.4954503114734377, 0.7868838161230087, 23.38802034514291, 70.33612101418632, 75.21470138004848, 84.6508275440761, 80.26805673326764, 77.35989516122001, 69.44380555834088, 69.85427039010185, 69.9235508782523, 77.40867151532854, 77.63345268794468, 83.58601611001151, 79.39677347455705, 75.7583075932094, 70.90935434613908, 65.4672611781529, 62.7641270501273, 59.25402218954903, 61.504404749189106, 64.32039846692766, 63.06884724753243, 67.2198817389352, 65.4978471483503, 66.15830816541398, 64.9420051574707, 63.451776368277415, 62.42598601749965, 62.034830229622976, 67.61747850690568, 68.94796821049282, 64.42905439649309, 69.07237570626395, 67.88268429892403, 66.82092312404087, 70.14028603690011, 67.73730019160679, 63.33884729657854, 66.03481088365827, 69.03555025373186, 67.92695127214704, 66.78284004756382, 61.534476552690776, 67.24292891366142, 66.20514597211564, 70.46351623535156, 62.464659690856934, 55.68105697631836, 65.60232721056256, 67.61554690769741, 61.23489802224295, 65.51280661991665, 54.21807554789952, 60.1773544039045, 64.69310678754533, 64.84425095149449, 63.961975642613, 66.02308927263532, 61.31044578552246, 52.94713190623692, 60.164409909929546, 57.95848192487444, 53.31107160023281, 58.70657362256731, 60.498388971601216, 62.03847803388323, 64.62725176130022, 61.36523927961077, 60.68295397077288, 63.6287191935948, 62.70114857809884, 62.38893127441406, 64.02118124280656, 63.379306656973704, 59.38974135262625, 61.295423780168804, 63.8588296345302, 61.59962286267962, 59.06491306849888, 59.768647466387065, 63.33897931235177, 60.503815514700754, 57.62324871335711, 54.779500416346956, 59.53191539219448, 57.33859143938337, 54.80334315981184, 54.736317362104145, 62.02656882149832, 58.187727315085276, 58.330905369349885, 61.33051913125174, 56.05206993647984, 58.672645568847656, 57.703330176217214, 62.47694410596575, 58.37399114881243, 60.900460379464285, 57.16451474598476, 57.17671578271048, 48.552139214106965, 42.44858796255929, 39.92601319721767, 41.70460612433297, 43.740164279937744, 31.038033894130162, 25.719196557998657, 29.773798738207134, 2.00416966847011, 0.3106098813670022, 0.22906050298895153, 3.3143397995403836, 3.3553124581064497, 0.15679945477417537, 0.06687989910798413, 0.375574099698237, 0.05791261100343295, 0.9460696514163698, 0.1267767772078514, 0.113327677095575, 0.015243426597278033, 0.0371316177105265, 9.17728579044342, 72.91138049534389, 34.69744859422956, 20.101390395845684, 23.51610517501831, 38.51898561205183, 51.08050530297415, 15.930862733295985, 0.059704974825893126, 0.05183499659012471, 0.030637311549591165, 0.08825984543987683, 0.06857078123305525, 0.051093798862504106, 0.0835527190938592, 0.1508522310427257, 0.04265081476686256, 0.01707904363450195, 0.02961338863575033, 0.013339383544267287, 0.0570369954886181, 0.06031879795981305, 0.06554495609764542, 0.011175642239062913, 0.035597931793225665, 0.03764496337888496, 0.010377724921064717, 0.0539354967352535, 0.024955788560743843, 0.04461048836154597, 0.043095350198979886, 0.10543347176696573, 0.1273833739438227, 0.05546607156949384, 0.3092246928385326, 24.115185805729457, 68.33442143031529, 49.476649148123606, 36.59923308236258, 35.28291770390102, 98.14442375728062, 31.6976090158735, 0.34427656339747564, 0.04411948345867651, 0.07172503947679486, 0.29522314987012316, 0.4845517362867083, 0.2708374426833221, 0.03287293176565852, 0.04853717729981456, 0.1766068283468485, 0.7633042899625642, 0.527267687022686, 0.9851725931678499, 1.2212355775492532, 29.144667148590088, 79.1157535825457, 82.17007051195417, 89.55186448778424, 84.10954202924455, 83.08022894178117, 72.88000937870571, 71.86113248552594, 71.52734797341483, 80.17597225734166, 81.3652537209647, 88.07230813162667, 82.26075145176479, 79.11800479888916, 75.67566571916852, 70.20348685128349, 65.54003661019462, 64.84249305725098, 65.45452513013566, 68.3946762084961, 68.25152942112514, 69.74173736572266, 70.46134144919259, 68.1173597063337, 68.207213810512, 68.94283349173409, 66.18109825679234, 64.46650518689836, 71.27530206952775, 73.09200586591447, 68.62034675053188, 72.10377052852085, 72.64246436527797, 70.31604072025844, 72.18339688437325, 69.88571793692452, 68.45397908346993, 68.70070266723633, 72.21002932957241, 69.63793822697231, 66.56623690468925, 66.03615188598633, 68.61189079284668, 69.92282826559884, 72.30460820879254, 64.1711789539882, 59.790006228855674, 68.74376760210309, 68.95029585702079, 66.24820395878383, 65.40318489074707, 57.305090699877056, 64.6694620677403, 66.59352248055595, 67.04152148110526, 67.20454011644635, 69.8791171482631, 66.6338289805821, 57.40644754682268, 61.106189591544016, 62.8583585194179, 56.650254249572754, 60.15305655343192, 62.036150387355256, 63.927040100097656, 66.1362406866891, 63.76614761352539, 61.51971857888358, 64.99047579084123, 64.3191338947841, 62.29908411843436, 63.80175713130406, 65.12811960492814, 62.16234357016427, 62.24616663796561, 65.12343651907784, 64.81683335985456, 61.5873384475708, 62.05962140219552, 64.25506455557687, 63.99188763754708, 61.17161382947649, 59.144546372549875, 62.25144032069615, 60.39449255807059, 57.94727100644793, 57.7642172404698, 65.59594876425606, 58.95233140672956, 62.50660596575056, 63.23565265110561, 61.75030844552176, 63.894598960876465, 62.35711547306606, 65.64433601924351, 63.53653744288853, 64.92384951455253, 63.124460629054475, 62.39179393223354, 53.43308196749006, 51.298077719552175, 49.34987926483154, 49.46837731770107, 55.33354977199009, 49.66184990746634, 36.83735132217407, 37.81878089904785, 3.652855166367122, 0.6544636903064591, 0.15144707555217402, 3.7158171364239285, 5.200799601418631, 0.22698970910693916, 0.05416140139901212, 0.7940904551318714, 0.10734744942081825, 0.2734693171722548, 0.30197080065097126, 0.08837543388030358, 0.0504301169754139, 0.2928999816732747, 11.554295795304434, 77.8750832421439, 35.52581630434309, 23.704173803329468, 30.14892155783517, 41.067372935158865, 56.92634092058454, 20.335864305496216, 0.10559467133134604, 0.057693274558654854, 0.07958394741373402, 0.03343485714867711, 0.07372504858566181, 0.0870436867699027, 0.12252549747271196, 0.12829794415405818, 0.07691850579742875, 0.00989917537663132, 0.03764151981366532, 0.03883903234132698, 0.008701201445156974, 0.11892646630959851, 0.1627438829413482, 0.10358502702521426, 0.10593788791447878, 0.12269228138029575, 0.1770797943962472, 0.09614517553044216, 0.06590654062373297, 0.14006914251617023, 0.12771418690681458, 0.22111766705555574, 0.2457302627818925, 0.22838652772562845, 0.31385976555091993, 31.042911529541016, 80.87941483088902, 51.84969173158918, 58.0253826550075, 52.759468010493684, 107.48340020860944, 38.51253420966012, 0.5353150037782533, 0.15260529411690577, 0.3053811176546982, 0.39425294739859446, 1.7906121164560318, 0.7981337638837951, 0.28055702256304876, 0.43119825635637554, 0.4309876390865871, 3.063509613275528, 1.3274202282939638, 3.3720534912177493, 1.4738795693431581, 33.60574415751866, 89.0590773991176, 84.23026003156389, 92.06202629634312, 87.74479784284318, 85.919082232884, 75.97025544302804, 74.79742036546979, 73.269608770098, 82.90869876316616, 84.30562019348145, 89.75937938690186, 84.41680526733398, 83.16023744855607, 78.21432903834751, 75.34896836962018, 68.49826690128872, 67.95810004643032, 69.56793512616838, 72.61871542249406, 70.89045524597168, 73.18274933951241, 73.27957248687744, 72.95598793029785, 73.63671684265137, 73.51189940316337, 72.60526371002197, 71.9223530633109, 76.33019297463554, 75.37050778525216, 72.33943952832902, 75.78466211046491, 74.92521163395473, 74.62265927450997, 78.63933644975934, 76.27778966086251, 74.8937154497419, 73.88373919895717, 75.75025463104248, 71.95892143249512, 73.17267445155552, 68.49753734043666, 73.76241670336042, 71.83448614392961, 74.32249709538051, 69.2250623703003, 61.627860341753276, 71.51418808528355, 71.65967641557965, 67.2394826071603, 68.03605188642229, 59.67059448787144, 64.20025716509137, 68.41909217834473, 69.51234258924211, 70.75389535086495, 72.5786382130214, 66.92954431261334, 58.681476729256765, 64.87197426387242, 64.01541423797607, 59.81292833600725, 62.48781108856201, 65.3770249230521, 67.96682003566197, 68.38701929364885, 65.05239813668388, 64.46467781066895, 68.64971678597587, 68.23550687517438, 64.99301883152553, 67.94768469674247, 67.72734342302594, 61.73945535932268, 65.34293011256626, 69.90591635022844, 66.40154375348772, 64.75974001203264, 65.05341952187675, 68.02000154767717, 66.34735475267682, 64.36069107055664, 61.61832046508789, 65.19058391026088, 66.11301285879952, 61.55867712838309, 63.97576086861746, 64.48053359985352, 62.653324127197266, 67.21968024117606, 67.99255616324288, 64.66760689871651, 66.89731856754848, 65.61970465523856, 70.37042427062988, 66.88461726052421, 70.45364284515381, 66.6452865600586, 69.2631037575858, 58.89657211303711, 55.575826508658274, 52.04832335880825, 54.74630192347935, 56.90413795198713, 47.629602568490164, 37.59820338657924, 47.08811902999878, 7.005407452583313, 0.9884267385516847, 0.5967648178339005, 6.47480001619884, 7.735540662493024, 0.43153106421232224, 0.30652344492929323, 1.1281208140509469, 0.367753657911505, 3.829553936208997, 0.6684664817793029, 0.33860737617526737, 0.12801979907921382, 0.40396956886563984, 16.663246291024343, 85.7851209640503, 49.69332177298409, 30.179785455976212, 31.509667192186626, 50.68204001017979, 68.55301175798688, 26.213640792029246, 0.18820421317858355, 0.12264425467167582, 0.20143362400787218, 0.23553030725036347, 0.11681270759020533, 0.11029693258127996, 0.243596080158438, 0.2703977791326386, 0.12652763271970408, 0.07355927569525582, 0.18991884402930737, 0.14226471898811205, 0.1343981639615127], [0.040463665699852366, 0.01883862743021122, 0.02289748141941215, 0.08006196854902164, 0.066693308763206, 0.08555886894464493, 0.06258129834064416, 0.012343049016115921, 0.059592412651649544, 0.09217350650578737, 0.05996195639350584, 0.042372025083750486, 0.03803286827834589, 0.06321080241884504, 32.98088918413435, 54.33953700746809, 35.538924080984934, 53.61738988331386, 51.854298387254985, 83.1554570879255, 8.191184418542043, 0.11341005803218909, 0.060383238430534086, 0.22035232026662144, 0.1615468928856509, 0.05937092525086232, 0.09641372612012283, 0.09799271103526865, 0.05697352532297373, 0.11145855739180531, 0.06745240624461855, 0.30962861116443363, 2.979250111750194, 34.18243074417114, 82.9598583493914, 81.52063628605434, 84.57764216831752, 80.83407783508301, 82.6894622530256, 69.26033837454659, 67.63048553466797, 65.83343819209507, 70.69470364706856, 76.65208217075893, 84.54684775216239, 78.19265065874372, 76.11143589019775, 74.30666215079171, 69.90838296072823, 64.02261257171631, 61.170502117701936, 61.815218516758506, 62.92720127105713, 68.4738300868443, 66.36083425794328, 69.13691057477678, 69.46249621255058, 66.25973796844482, 66.02986376626151, 64.02856717790876, 62.418294361659456, 56.50507858821324, 58.37992491040911, 61.01363958631243, 65.90926388331822, 69.5198952811105, 67.22075026375907, 64.4919216973441, 67.81847599574498, 63.26983778817313, 64.23867375510079, 62.01775850568499, 67.67943559374127, 64.222991670881, 62.60080964224679, 64.98925290788922, 65.68002891540527, 71.30606869288853, 64.49006652832031, 58.45338821411133, 68.45112337384904, 66.73560619354248, 64.19814491271973, 69.48051289149693, 52.44389125279018, 61.41314710889544, 68.50891154153007, 64.234372820173, 63.14080279214041, 58.750319480895996, 60.55059773581368, 66.7093836920602, 65.1791958127703, 53.283431666237966, 64.36208071027482, 60.709704535348074, 55.77028226852417, 57.19859913417271, 57.99799633026123, 56.100158418927876, 64.14922959463937, 60.975167410714285, 64.1347564969744, 61.60566084725516, 59.70570373535156, 57.92718029022217, 60.05266203199114, 64.21211079188755, 60.863989285060335, 60.37347425733294, 63.36982236589704, 62.605312074933735, 61.22490651266915, 58.51966708047049, 61.67802633558001, 58.65421894618443, 61.788419314793174, 57.421910762786865, 58.776868547712056, 56.44083554404122, 58.03378997530256, 62.30508736201695, 56.257281507764546, 61.43760476793562, 56.00052472523281, 60.00428867340088, 57.91228335244315, 57.32941286904471, 57.77361815316336, 57.973594256809776, 57.33463791438511, 60.815720149448936, 56.71002265385219, 52.47886848449707, 49.72147934777396, 55.27214854104178, 48.449417046138215, 56.435214451381135, 50.48713609150478, 47.80945668901716, 37.77979108265468, 37.82899127687727, 3.143991683210645, 0.48904076112168177, 0.17321822446371826, 2.9994912999016896, 1.0991073080471583, 0.32356029216732296, 0.1135624705680779, 0.09348995943686791, 0.08122792241296597, 0.2498320069696222, 0.06809535210153886, 0.16338935973388807, 0.04525713562699301, 0.7775888091751507, 43.76050860541207, 42.75343670163836, 24.477676800319127, 43.09992599487305, 37.1405394417899, 46.853985582079204, 13.369767154966082, 0.12763483902173384, 0.19807315218661511, 0.08846924134663173, 0.08197099968258824, 0.05719056153403861, 0.10473890975117683, 0.03329525196126529, 0.15066589175590447, 0.038414320309779475, 0.09237514675727912, 0.028395374172500203, 0.15490722416767053, 0.04317785327189735, 0.06838208064436913, 0.06580073665827513, 0.007076269107139004, 0.0858068802793111, 0.025586178127144064, 0.05024646129459143, 0.06233839637466839, 0.08048329129815102, 0.049395391784076176, 0.04650021517383201, 0.009399958503698664, 0.045886748270796876, 0.09644290991127491, 0.04028364357405475, 43.26607479367937, 58.713341167994905, 49.11845908846174, 45.374762739454, 50.383448123931885, 98.20556095668248, 9.633321251188006, 0.15308143571019173, 0.0664720656350255, 0.15988579844789846, 0.11739132154200758, 0.06000348273664713, 0.06455339251884393, 0.2529310935309955, 0.19127640261181764, 0.5266141763755253, 0.16976039643798554, 0.3724277328167643, 5.977081877844674, 40.39149733952114, 89.47940172467912, 87.13307843889508, 89.56371116638184, 85.21868991851807, 85.71741771697998, 71.88436031341553, 71.81097343989781, 69.27480452401298, 74.7244851248605, 80.31158719744, 86.53601278577531, 80.44119194575718, 80.05225263323102, 76.92468084607805, 72.77333368573869, 68.58109637669155, 64.51732431139264, 64.03458431788853, 68.33322634015764, 71.6834739957537, 71.59286948612758, 71.4712690625872, 71.7344251360212, 68.6061932700021, 67.90233380453927, 67.98961707523891, 68.16898482186454, 62.225926535470144, 61.71193354470389, 64.91436522347587, 69.1562752042498, 71.96987874167306, 69.89377784729004, 66.67988858904157, 69.26543140411377, 66.87580694471086, 68.75462068830217, 68.01219177246094, 70.00528948647636, 65.6129787990025, 65.9847491128104, 68.62179892403739, 70.45508807046073, 71.62263556889125, 65.03279726845878, 63.06499794551304, 71.33685616084507, 68.7247017451695, 69.35759231022426, 69.79912948608398, 55.805332456316265, 68.1841596875872, 69.38500295366559, 65.54997253417969, 64.3059184210641, 59.89566053662981, 60.6523471559797, 67.13325159890312, 67.59788458687919, 55.70324952261788, 64.75824614933559, 64.79171562194824, 60.92613397325788, 59.046993664332796, 59.70466150556292, 56.90529135295323, 65.1862690789359, 63.629942076546804, 63.84235545567104, 64.0677411215646, 62.25819396972656, 57.87730264663696, 61.90923459189278, 66.12315028054374, 64.07785075051444, 60.404720306396484, 64.05919483729771, 65.68626144954136, 65.32204382760185, 61.70301900591169, 64.11788627079555, 63.13499409811837, 64.21287509373256, 59.6442677634103, 62.26702513013567, 59.086292675563264, 63.18238081250872, 64.5367236818586, 59.7569397517613, 64.96823460715157, 60.2060991014753, 63.22177015032087, 60.265811920166016, 58.809983662196565, 61.13250936780657, 60.53763934544155, 61.83003902435303, 63.35631506783621, 61.27677481515067, 57.02611705235073, 53.627791336604524, 56.51061977658953, 52.44276564461844, 59.28344086238316, 59.823496546064106, 61.94528879438128, 46.639703137534006, 50.90779740469796, 4.069627659661429, 0.6945811233350209, 0.18503683885293348, 3.5390656036990027, 1.6055364246879305, 0.6441585347056389, 0.1594402180718524, 0.1494395618460008, 0.09298058998371873, 0.1659345988716398, 0.15924125803368433, 0.23616343470556395, 0.008276001716564809, 1.110559350677899, 50.04022795813424, 48.22891248975481, 24.582450423921856, 45.36333990097046, 45.76179824556623, 54.124493735177175, 18.83645347186497, 0.22273240398083413, 0.2299051433801651, 0.09995995368808508, 0.10652864764311484, 0.02812136646493205, 0.11669970436819962, 0.06656140834093094, 0.06002648507377931, 0.10614043061754533, 0.12268755877656595, 0.034063736974660835, 0.049976787729454894, 0.017234504488962035, 0.1526155671370881, 0.17554534173437528, 0.087622884261821, 0.14347119496337005, 0.18409676929669722, 0.1737585961818695, 0.2053987926670483, 0.13844118772872857, 0.09757869610829012, 0.1734359934926033, 0.09854864834674767, 0.2587940160717283, 0.10735280984746558, 0.18136092967220716, 54.912561893463135, 73.37360940660749, 48.049374512263704, 74.64710303715297, 71.58521951947893, 102.29776505061558, 14.368153810501099, 0.4262380839458534, 0.319595856325967, 0.3669860990984099, 0.17574157406176838, 0.6737375589353698, 0.6099032099757875, 0.5297158413699695, 0.34628885399018017, 1.179461379136358, 0.6645240847553525, 0.9508390469210488, 7.411712918962751, 40.038900579724995, 98.63997622898647, 90.79366738455636, 92.38820253099713, 87.29040649959019, 88.83420589991978, 75.39613968985421, 74.09012848990304, 72.96538884299142, 77.23967048100063, 83.42105197906494, 90.43614087785993, 85.47466850280762, 85.56771877833775, 79.78428145817348, 77.45510632651192, 72.49467618124825, 68.58959402356828, 69.28386497497559, 71.60870443071637, 75.05614348820278, 73.13310446058, 76.6141311100551, 75.31886182512555, 72.97956316811698, 73.9311328615461, 73.00147778647286, 72.31728867122105, 66.9471788406372, 69.553468976702, 69.8320917401995, 72.58530848366874, 76.06769003186906, 74.82836069379533, 70.73367609296525, 76.03750010899135, 73.43601812635148, 75.11015878404889, 68.24900027683803, 73.2038996560233, 73.0254351752145, 66.93212904248918, 72.64745317186627, 71.09840788160051, 75.85592283521379, 69.658768926348, 63.92344093322754, 72.90664877210344, 71.11114392961774, 69.87335014343262, 74.2132853099278, 59.12134633745466, 68.95125470842633, 73.81720324925014, 69.15945053100586, 69.19692911420549, 62.73339516775948, 65.42046506064278, 70.2827102116176, 68.91952228546143, 58.37794467381069, 68.61223125457764, 64.74605900900704, 60.517225537981304, 60.25725868770054, 64.18365791865757, 59.55976377214704, 70.90614427839006, 65.11049897330147, 67.62510068075997, 64.43540505000523, 63.995681353977744, 60.67060007367815, 62.153818130493164, 68.78502600533622, 67.02332414899553, 64.69745635986328, 67.97392804282052, 68.37431103842599, 68.14893926892961, 61.865933418273926, 67.25240625653947, 67.4090325491769, 65.5242086138044, 62.74451923370361, 64.17505604880196, 64.43388339451381, 65.21422168186733, 69.06902667454311, 64.90502684456962, 67.80087620871407, 63.105130740574424, 66.80080114092145, 63.53279931204659, 63.68639619009835, 64.85241508483887, 64.17484760284424, 64.86613777705601, 67.6183192389352, 65.64892183031354, 62.214350836617605, 58.32701437813895, 60.64109107426235, 55.66639975139073, 62.502562114170615, 58.19004453931536, 58.907765660967144, 47.232992444719585, 62.2529411315918, 7.075682835919516, 1.1923430136271884, 0.8425191278968538, 6.369084477424622, 2.749101455722536, 1.0346651545592715, 0.26157565680997713, 0.8494749260800225, 0.12292557529040746, 0.5708949917129108, 0.6420561075210571, 0.29095801444990294, 0.15680073042001041, 1.9919818767479487, 60.392012051173616, 57.087066650390625, 37.40137481689453, 54.988665512629915, 49.37755046572004, 65.32571247645787, 23.489707231521606, 0.33432223754269735, 0.2938450995300497, 0.15448129416576453, 0.17852405618344033, 0.10766607589487519, 0.23511026693241938, 0.1580197321517127, 0.18344149445848806, 0.18939129662300858, 0.1634721274354628, 0.09021997026034764, 0.20992660256368773, 0.06926357905779566], [0.03796742018312216, 0.07056137227586337, 0.10009891087455408, 0.019546833088887588, 0.057489306932049136, 0.12626240695161478, 0.05570228657286082, 0.039271578059664795, 0.02799540152773261, 0.08481036339487348, 0.17611411692840712, 0.04143159929662943, 0.05387899851692574, 0.5356278898460525, 45.90643194743565, 49.692474092756, 28.687993322099956, 33.40383298056466, 64.08109555925641, 62.767767906188965, 1.0842039648975645, 0.09880408963986806, 0.039395061255033524, 0.1355914492160082, 0.34058913269213265, 0.24408934797559464, 0.055374784860759974, 0.029293405091656104, 0.259567383144583, 0.09685269077973706, 0.18287696689367294, 10.237061517579214, 53.45480898448399, 83.72370856148856, 81.39121913909912, 81.67908300672258, 81.03026022229875, 76.85433728354317, 72.84224591936383, 68.31208992004395, 66.98900699615479, 67.81359141213554, 69.46573407309396, 77.58405099596295, 77.37362480163574, 77.06208147321428, 77.61554718017578, 70.41378102983747, 66.55057566506522, 62.991895948137554, 60.247836930411204, 63.32793862479073, 65.65439006260463, 69.93950394221714, 73.32033061981201, 73.02797821589878, 72.67421068464006, 71.21963310241699, 67.0275764465332, 61.480836459568565, 55.56688417707171, 53.42327111107962, 50.8073125566755, 54.986428192683626, 66.44325378962925, 64.06610829489571, 60.97484084538051, 64.45282418387276, 65.85395622253418, 63.60232993534633, 61.90792138235909, 67.09241703578404, 61.588901792253765, 63.50102519989014, 67.31538472856793, 66.27141094207764, 70.58501243591309, 59.2038631439209, 60.31705488477434, 66.11887019021171, 61.195814405168804, 64.24616391318185, 69.0381280354091, 49.989905629839214, 62.13002749851772, 69.38727501460484, 57.65780210494995, 62.40876143319266, 58.30763585226876, 55.382003034864155, 55.68373550687517, 57.48317650386265, 62.41006074632917, 59.613737378801616, 54.02200780596052, 60.38931615012032, 64.27761146000454, 61.20472894396101, 58.09644883019583, 57.06519372122628, 55.2130297933306, 61.60630008152553, 61.95999118259975, 64.38100065503801, 61.303587913513184, 60.61889157976423, 60.1323161806379, 62.894364084516255, 64.0327638898577, 63.11148139408657, 58.31986468178885, 60.43052591596331, 62.195166860307964, 62.99857316698347, 60.685420581272666, 58.37614509037563, 59.963648659842356, 58.90037277766636, 59.75056825365339, 58.52435711451939, 59.84814180646624, 56.16627747671944, 58.70779650551932, 60.311551911490305, 57.908541747501914, 58.118582316807334, 55.65080451965332, 57.50501816613333, 56.515469619206016, 56.701723030635286, 57.191324370247976, 60.748079436165945, 59.38630199432373, 60.339316913059776, 47.741037777491975, 51.98231894629342, 54.508267062050955, 60.71159444536482, 63.505284445626394, 58.634347098214285, 59.067678451538086, 50.74011652810233, 50.52102940423148, 4.269358839307513, 0.20033228024840355, 0.22785974027855055, 0.9088768671665872, 0.24179025420120784, 0.02466895484498569, 0.07113959267735481, 0.2637048454156944, 0.291698974690267, 0.11349501061652388, 0.056500538917524476, 0.05275450314262083, 0.17925781038190636, 20.699439219066075, 52.357483455113, 35.89395618438721, 35.140820094517295, 22.63140320777893, 46.933212416512625, 15.943301745823451, 0.11784798918025834, 0.12758453243545123, 0.045974825508892536, 0.04316479486546346, 0.038887547595160346, 0.09498015125947339, 0.11776811203786305, 0.08304216898977757, 0.08420978526451758, 0.08290188866002218, 0.11332492902874947, 0.052662503972117386, 0.031874372490814755, 0.054220902134797404, 0.0493269547420953, 0.03581761089818818, 0.02097211285893406, 0.06660948254700218, 0.12635544767337187, 0.04881805347810898, 0.06624635774642229, 0.05306237144395709, 0.06368497626057693, 0.13354106566735677, 0.0882957060156124, 0.08620653740529503, 1.3001937121152878, 57.00286143166678, 62.02030154636928, 40.39511735098702, 30.536064761025564, 67.81740597316197, 70.87718418666294, 1.2905289850064685, 0.13587305481944764, 0.12633450808269636, 0.2432534471154213, 0.18625197293502943, 0.3089145751936095, 0.0958196415698954, 0.2812012237097536, 0.4365749407027449, 0.23236084303685597, 0.8492953585726875, 14.754843643733434, 59.09602015359061, 88.62393256596157, 87.76768520900181, 87.98271111079625, 84.89955220903668, 82.0567592893328, 76.4890843800136, 71.13265555245536, 69.52194499969482, 71.77028478894914, 72.45826067243303, 79.41323375701904, 78.65296881539481, 81.57375526428223, 80.59660925183977, 75.21048382350376, 69.0487309864589, 65.9143430164882, 63.348685945783345, 67.01440961020333, 68.10060065133231, 71.96965639931815, 75.74667630876813, 75.8545401436942, 77.6985364641462, 74.33820697239467, 72.11711801801408, 67.42387390136719, 59.80594539642334, 59.62016446249825, 57.36168725149972, 58.769684110369, 69.05026653834751, 66.8639463697161, 64.30964265550885, 70.97250652313232, 72.07922254289899, 67.24000372205461, 67.23222868783134, 71.72347477504185, 64.71030357905796, 65.58438001360211, 71.86940084184918, 69.23977865491594, 69.00818129948208, 62.06799398149763, 64.72727802821568, 68.42392117636544, 63.67509841918945, 67.03173146929059, 67.9970030103411, 49.967876366206575, 67.49983855656215, 70.08690302712577, 57.779187134334016, 63.37002386365618, 61.870915276663645, 60.05558027539934, 57.756761823381694, 59.49434648241316, 63.3148968560355, 65.46890790121896, 57.615365982055664, 61.066251346043174, 69.05236489432198, 64.8796728679112, 60.17217799595424, 59.44057437351772, 57.213739258902415, 60.79763398851667, 62.57769298553467, 63.960474831717356, 64.19068949563163, 61.48278890337263, 61.62494904654366, 63.48735114506313, 65.15926837921143, 66.73476546151298, 61.12535967145647, 61.63283525194441, 62.60858467647007, 65.23039013998849, 63.21280697413853, 62.031203269958496, 63.786304337637766, 61.12856279100691, 62.077610288347515, 58.38911042894636, 62.87666702270508, 59.20279312133789, 61.80578981127058, 63.35966409955706, 60.09560884748186, 61.72728211539132, 57.84380538122994, 59.35670266832624, 59.100091797964915, 59.206739698137554, 58.60861097063337, 63.85756506238665, 63.97789396558489, 63.231504576546804, 54.085872173309326, 54.99476950509207, 60.491142000470845, 64.2829337801252, 68.67863518851144, 68.1367312840053, 69.13732051849365, 56.25768102918352, 60.71970994131905, 6.418686364378248, 0.22439056714730604, 0.30890941832746777, 1.3167097972972053, 0.2314634940453938, 0.11723899043032102, 0.07408233798508133, 0.12541670804577215, 0.685665444603988, 0.05083585377516491, 0.11241837910243443, 0.07119885592588357, 0.10143599805555173, 21.752132994788035, 65.49986907414028, 20.872286081314087, 30.73032249723162, 29.398773193359375, 53.18028565815517, 20.669815574373516, 0.2023038315985884, 0.07153331940727574, 0.02560612027134214, 0.022105100098997355, 0.029834740329533815, 0.03005051446546401, 0.08352717903575727, 0.017281225017671074, 0.02993605239316821, 0.06270204364721264, 0.028844774700701237, 0.029737390910408328, 0.0870108592457005, 0.11420076846012048, 0.1354305007095848, 0.16065392723040922, 0.12069600421403136, 0.12896118499338627, 0.2600578825388636, 0.11061878888202564, 0.12670782447925635, 0.10295704286545515, 0.1338849472148078, 0.22698704924966606, 0.10370413027703762, 0.22887203310217175, 2.347452368055071, 69.68409511021206, 69.83151503971645, 38.37559911182949, 45.49818706512451, 83.18841239384243, 78.0925132206508, 2.5793745517730713, 0.27347596681543757, 0.23035710198538645, 0.3270653055182525, 0.8455661843929971, 0.6728702283331326, 0.4286307884114129, 0.5727420183164733, 1.2177343368530273, 0.9297521327223096, 1.0417612195014954, 14.763850246156965, 63.95588902064732, 93.2056997844151, 92.2301310130528, 91.31701959882463, 89.10719367436, 83.8735464641026, 79.70057650974819, 73.44598879132951, 73.47414289202008, 73.60708972385952, 74.47818538120815, 81.85672760009766, 82.54038170405796, 86.8792051587786, 83.90852369580949, 79.75867734636579, 74.14653396606445, 70.83019351959229, 69.25366810389927, 69.91011306217739, 71.04259995051792, 75.51099341256278, 79.1673161642892, 77.6619541985648, 79.78023065839494, 77.61267757415771, 76.57949434007917, 73.83392756325858, 68.65281568254743, 66.91856615883964, 64.45931380135673, 64.05870846339634, 73.47615786961147, 71.11538233075822, 68.34685870579311, 73.54798834664481, 77.39952073778424, 73.99655015127999, 69.65775448935372, 74.71618897574288, 67.70141274588448, 67.30298914228166, 75.42240388052804, 70.28368295942033, 75.11648164476667, 65.83322974613735, 65.71779237474713, 71.77125058855329, 65.26325511932373, 68.53153487614223, 73.64096914018903, 54.29545068740845, 68.29084232875279, 76.94995839255196, 60.38983031681606, 65.2193077632359, 63.8333158493042, 62.77363913399832, 58.00689697265625, 59.67755658285958, 66.70536068507603, 66.84256676265171, 60.95282200404576, 65.75691768101284, 71.20612580435616, 65.81673472268241, 61.10757228306362, 62.43798555646624, 60.92061710357666, 67.10419423239571, 65.8358770098005, 68.17390414646694, 64.43890694209507, 66.61688927241734, 63.882363183157786, 64.75618253435407, 66.60136004856655, 68.36813408987862, 62.1946804864066, 63.506020954677034, 67.0912149974278, 69.69670609065464, 65.90717942374093, 65.32871409824916, 67.59814861842564, 64.75097138541085, 66.27935968126569, 64.18597861698696, 65.349134853908, 62.71585096631731, 65.8793796811785, 67.8694132396153, 63.451449802943635, 64.39040851593018, 61.23179912567139, 62.31131989615304, 62.91810607910156, 63.19917460850307, 62.029591287885395, 67.98990889957973, 66.2128723689488, 67.3282527923584, 57.2150559425354, 60.36741542816162, 66.2021096093314, 68.33435194832938, 72.03872844151088, 69.84363964625767, 68.4788258416312, 56.7389896937779, 69.37671375274658, 8.443704536982946, 0.44494977274111336, 0.6595406521643911, 3.160000115633011, 0.6245832336800439, 0.34972875512072016, 0.6261730683701379, 0.47358319056885584, 0.9819108481918062, 0.393203715128558, 0.15096682203667505, 0.2202218651239361, 0.38364437807883534, 30.44912542615618, 70.6281954901559, 48.675382886614116, 47.55545834132603, 29.66981199809483, 67.48851994105748, 23.95345085007804, 0.24551478720137052, 0.15828897484711238, 0.19256913395864622, 0.0687304473082934, 0.09136334247887135, 0.151522392939244, 0.19454084815723555, 0.16904963100595133, 0.14064695579665049, 0.1624004085149084, 0.1710275470146111, 0.13000972515770368, 0.17125508694776467], [0.10792660620063543, 0.1351505643022912, 0.0917733744052904, 0.04863233844350491, 0.0693456953657525, 0.06795741950294801, 0.04916005887623344, 0.033991171047091484, 0.08140339156878845, 0.10016054899564811, 0.1555936030511345, 0.023648483978052224, 0.3727440115596567, 4.324840639318738, 57.699696268354145, 34.69916827338082, 40.9534398487636, 34.55424969536917, 69.2804742540632, 34.726502486637656, 0.16422312999410288, 0.19769218191504478, 0.19242605806461402, 0.3077659782554422, 0.013308956337693547, 0.1121846984273621, 0.019577996505956565, 0.4268505839364869, 0.18780094624630042, 0.15225797918226036, 14.559734753199987, 63.08807986123221, 85.98630605425153, 85.26804992130825, 80.05911745343889, 79.03792681012834, 76.2911718913487, 72.04630197797502, 69.78916576930455, 64.75391742161342, 62.384783199855256, 67.59444522857666, 73.11355917794364, 73.13176345825195, 79.5669834954398, 78.54051222120012, 72.58838653564453, 71.66607570648193, 70.83159705570766, 63.60247584751674, 60.762031418936594, 61.85208565848214, 65.40693691798619, 72.09120123726981, 73.5538387298584, 71.7191390991211, 70.92604391915458, 69.99479075840541, 68.25385011945451, 63.25327328273228, 63.2919955934797, 50.068524496895925, 48.414696897779194, 46.97403655733381, 56.244743483407156, 59.95672825404576, 62.9358309337071, 69.23893097468785, 64.32699230739048, 62.75270421164376, 64.26461138044084, 63.986113684517996, 65.90114838736397, 70.23894350869315, 67.30946486336845, 67.61189910343715, 55.88191897528512, 61.66468579428536, 67.76361996786935, 63.500448499407085, 64.90983499799455, 67.90974753243583, 50.754033769880024, 58.142532757350374, 68.64542279924665, 56.91250010899135, 58.845134598868235, 64.70782307216099, 64.29179273332868, 64.1764804295131, 65.37587847028459, 63.385969979422434, 59.37626184735979, 63.20869364057268, 61.977118492126465, 55.26545742579869, 55.819715227399556, 62.8481377192906, 64.95570700509208, 59.36070483071463, 59.15980461665562, 56.139207295009065, 56.113061223711284, 56.8013254574367, 61.510936055864605, 61.01198591504778, 58.65604632241385, 64.40716757093156, 63.16729627336775, 62.335346766880576, 61.90159157344273, 62.208048820495605, 61.38661888667515, 58.50819560459682, 61.18396772657122, 59.28867285592215, 57.64139740807669, 58.13448674338204, 56.05057954788208, 57.21726546968733, 58.17040198189871, 54.64032799857003, 56.7717296055385, 59.69497571672712, 59.605538504464285, 55.987364837101524, 56.47446135112217, 53.90924896512713, 53.709429195949006, 55.119600840977256, 54.720221860068186, 58.34459332057408, 61.16190719604492, 60.42326504843575, 58.02362476076399, 55.58648157119751, 61.91785730634417, 63.20256532941546, 65.17752824510846, 57.205668926239014, 62.705769130161826, 65.90289238521031, 60.86838749476841, 52.41119997841971, 3.927608217511858, 0.14321770785110338, 0.1500952709466219, 0.3286502276148115, 0.22164001688361168, 0.03731089684047869, 0.22421078250876494, 0.11722897525344576, 0.05080084476087775, 0.2102570626884699, 0.05139467825314828, 0.05772662455482142, 2.8968850799969266, 46.30194425582886, 40.68842165810721, 46.811351435525076, 26.96595525741577, 43.85668904440743, 22.537967307227, 0.05919455364346504, 0.03539767236049686, 0.0420458974050624, 0.1358698114220585, 0.06280179508030415, 0.08483669733894722, 0.018206205651430146, 0.054860512992101054, 0.13212022690900735, 0.07780404149421624, 0.08947037226919617, 0.15316154355449335, 0.04762042220681906, 0.04104327709813203, 0.1403859776577779, 0.031170962378382683, 0.07103254699281283, 0.07927731065345661, 0.040714309750390906, 0.04661379175792847, 0.024405466126544133, 0.07046688627451658, 0.011691441659682562, 0.025733890111691186, 0.09543419296720199, 0.43475046860320227, 7.8489126818520685, 67.30945096697126, 41.30953502655029, 42.052422523498535, 28.4704486983163, 83.26309858049665, 39.48374646050589, 0.14596824454409735, 0.08024520014545747, 0.10963092331907578, 0.6712532522422927, 0.05998187818165336, 0.018186940345913172, 0.2918037676385471, 0.7540941813162395, 0.5590800142713955, 0.45830958443028585, 19.42119128363473, 71.11984307425362, 85.72795118604387, 89.26934378487724, 85.90970911298479, 83.0825148991176, 80.6865953717913, 77.51863370622907, 74.17581367492676, 68.20751258305141, 67.96062224251884, 68.84594781058175, 73.88570553915841, 77.8673290525164, 83.14176218850272, 83.16463565826416, 77.44416291373116, 75.67682606833321, 73.36841215406145, 65.54640810830253, 63.69945880344936, 65.32812350136894, 68.55736133030483, 74.95262227739606, 74.03614098685128, 74.2135979788644, 73.45826625823975, 72.00209059034074, 71.9604708807809, 70.59931182861328, 68.8573637008667, 57.3819169316973, 56.910863808223176, 54.09172255652291, 57.78255353655134, 60.87241744995117, 67.1956672668457, 71.61185196467808, 67.05307633536202, 66.89403206961495, 67.63708632332938, 67.610474722726, 70.0874102456229, 70.54513672419957, 70.23407976967948, 70.16607775006975, 59.42819268362862, 66.41054167066301, 69.79361261640275, 65.63469886779785, 68.91027423313686, 69.20018087114606, 51.612983976091655, 62.30694253104073, 69.41469260624477, 58.29027230398995, 62.217540059770855, 65.89085810525077, 67.64901638031006, 65.524215562003, 66.16454764774868, 64.63879271915981, 58.40356963021414, 63.95511082240513, 65.05305126735142, 59.289138385227744, 56.439529282706125, 62.0574118750436, 65.07400008610317, 61.54332160949707, 60.83694689614432, 59.12885734013149, 56.515872614724294, 58.50483267647879, 62.31104891640799, 63.04377119881766, 61.82901069096157, 65.53845936911446, 64.31162289210728, 63.12324469430106, 65.36093984331403, 63.40532071249825, 64.53048419952393, 61.95429365975516, 64.11244583129883, 62.505556787763325, 59.702104568481445, 59.76552772521973, 59.19518484388079, 61.370054381234304, 63.77121979849679, 58.212980542864116, 59.6300448008946, 60.333570752825054, 61.018663133893696, 58.209162507738384, 58.84935910361153, 56.5667507989066, 56.199166774749756, 58.591900553022114, 57.405026640210835, 61.25203227996826, 64.22607667105538, 64.32317079816545, 62.45154844011579, 59.062342235020225, 67.1145053591047, 66.62540776388985, 67.33005932399205, 63.486315863473074, 68.85087408338273, 72.99648897988456, 67.65315055847168, 62.641609464372905, 5.755808676992144, 0.2408059441617557, 0.30468646064400673, 0.33147776446172167, 0.5397081651857921, 0.10079233973686184, 0.16600736496703966, 0.3171611369720527, 0.06508295517414808, 0.1644451737936054, 0.09018005883055073, 0.010720446173633848, 3.3533298330647603, 54.977930545806885, 39.005495003291536, 41.446626458849224, 35.93401254926409, 49.569963455200195, 29.56409863063267, 0.10418249746518475, 0.07615549995430879, 0.07442623310323272, 0.014738355663471987, 0.05217155335204942, 0.07707940680640084, 0.028792432509362698, 0.027260251243465712, 0.11580440455249377, 0.06574945298156568, 0.03152836373608027, 0.06398149606372629, 0.0448458246620638, 0.18178096999015125, 0.28931913524866104, 0.16836891110454286, 0.16662104560860566, 0.11859508337719099, 0.1279208143906934, 0.11993844700711113, 0.07461604648934943, 0.14783675356635026, 0.15706398843654565, 0.2705046891101769, 0.15178091478134903, 0.4599672183394432, 10.914932114737374, 84.37899317060197, 46.72585037776402, 50.59600394112723, 51.17836025782994, 89.43730953761509, 46.46958344323294, 0.20046302037579672, 0.21922756704900945, 0.3850054107606411, 1.3777668752840586, 0.15477894033704484, 0.37647940112011774, 0.4707512568150248, 1.619193109018462, 1.1714999377727509, 0.5975301510521344, 21.616009099142893, 77.12258638654436, 92.27710778372628, 94.27533326830182, 91.0258205958775, 87.4285088947841, 84.77020454406738, 80.746461050851, 74.71865558624268, 72.16127382005963, 68.99425016130719, 72.7049981525966, 78.36477838243756, 79.71851675851005, 84.12712097167969, 87.64074856894356, 80.11083289555141, 78.09879439217704, 80.05175931113106, 70.1096305847168, 67.35736574445451, 70.36496993473598, 71.07637514386857, 78.98684365408761, 75.99623475755963, 78.20114135742188, 75.08641678946358, 76.79884202139718, 74.7603656223842, 72.60697296687535, 73.88135596684047, 65.70381259918213, 63.23161574772426, 63.731239863804404, 65.10214029039655, 67.03738730294364, 70.8941238948277, 76.90186991010393, 73.73365116119385, 70.08089283534459, 70.3458901814052, 70.02558517456055, 71.50824042728969, 76.35456030709403, 71.5915423801967, 73.1646284375872, 63.48808070591518, 68.15729795183454, 72.84553241729736, 68.57938711983817, 69.17395836966378, 73.74437223161969, 57.28806413922991, 61.140722138541086, 74.45806339808873, 59.714402879987446, 62.941028186253135, 70.20716939653668, 69.70425878252301, 70.14661584581647, 70.69737870352608, 67.72920554024833, 59.548264503479004, 67.33047621590751, 68.20916625431606, 62.738321440560476, 60.2829600742885, 66.52747290475028, 68.22230529785156, 62.45036724635533, 63.08123588562012, 61.386056082589285, 60.02485534123012, 62.12995106833321, 64.96702562059674, 66.36068139757428, 62.88943781171526, 67.92526285988944, 66.19459165845598, 66.86887959071568, 66.61256749289376, 66.56133842468262, 67.26201561519078, 63.52409321921212, 67.43903487069267, 64.60246753692627, 62.828453472682405, 63.782795497349326, 60.87782314845494, 65.37396076747349, 63.83803367614746, 64.50269140516008, 62.3711508342198, 65.27915259769985, 64.9980354309082, 61.15645286015102, 61.96543857029506, 60.33612074170794, 60.778658458164756, 61.68446731567383, 60.47374371119908, 63.6181857245309, 68.77203982216972, 68.6020312990461, 63.71461977277483, 63.248527663094656, 70.64997809273856, 70.13649232046944, 70.47121483939034, 65.26426260811942, 69.33423246656145, 74.196380342756, 70.39636884416852, 70.77198151179722, 7.433082103729248, 0.37922912357108934, 1.033193330679621, 0.938874574644225, 0.8595721242683274, 0.19041878863104753, 0.22897679890905107, 0.543803476861545, 0.2251844938312258, 0.6965944181595529, 0.160711955545204, 0.11947675820972238, 6.685108959674835, 64.74106325422014, 56.877258845738, 63.17929581233433, 37.29889236177717, 59.935487610953196, 33.82425110680716, 0.13791604233639582, 0.14830496987061842, 0.21241735533944198, 0.23249057893242153, 0.12661441734858922, 0.12398457846471242, 0.12479274081332342, 0.19372319988906384, 0.3122381754219532, 0.16953634417482785, 0.12812144362500735, 0.20859307769153798, 0.15017171470182283], [0.09355469846299716, 0.08282569596277815, 0.07680595040853534, 0.06079508204545293, 0.09971028672797339, 0.02434217238000461, 0.0363731003765549, 0.026505957789985195, 0.08717611644949232, 0.11483513084905488, 0.09274131818009274, 0.0891822391588773, 0.22492533416620322, 20.173038482666016, 56.286116531917024, 30.386893885476248, 38.81993293762207, 32.13184363501412, 72.08309268951416, 10.784918291228157, 0.2629142978361675, 0.11052115447819233, 0.13925298702503952, 0.6451152147991317, 0.25911447459033554, 0.06996242941490241, 0.30176034622958725, 2.1250468279634203, 2.0388205519744327, 7.11078166110175, 47.970373494284495, 83.32421493530273, 87.42416627066476, 78.86028916495187, 77.07690892900739, 71.76475402287075, 69.12458447047642, 66.15266622815813, 61.85743577139718, 60.795688492911204, 64.97996316637311, 66.794082232884, 64.84218733651298, 71.89378207070487, 72.81990051269531, 75.53754247937883, 77.13603115081787, 73.00057452065604, 65.68091828482491, 62.18511281694685, 59.08617455618722, 59.014177322387695, 63.21119499206543, 68.46740995134626, 71.27362060546875, 68.88359315054757, 66.22996493748256, 64.34429332188198, 57.92563084193638, 56.69730050223214, 58.17454310825893, 58.40584169115339, 49.494224616459434, 49.685650961739675, 44.578888280051096, 57.56554739815848, 62.67836543491909, 64.4441111428397, 65.68701185498918, 64.86995233808244, 66.0811345236642, 67.9560294832502, 68.92923586709159, 66.91695417676652, 65.22800690787179, 55.163867814200266, 64.40926592690604, 66.85437175205776, 62.176010676792686, 67.23410470145089, 64.01453181675502, 48.81662934167044, 55.45441716057913, 65.77637958526611, 59.2358318056379, 63.90761293683733, 61.888494219098774, 60.04764543260847, 60.21946743556431, 60.99140535082136, 58.15598446982247, 59.18167059762137, 59.19004317692348, 60.2381511415754, 59.3674167905535, 60.706369400024414, 59.81369958605085, 50.95598316192627, 61.56173433576311, 61.04755374363491, 61.74393694741385, 63.63531303405762, 58.734769412449424, 54.00492218562535, 57.283318519592285, 58.66447448730469, 60.55653844560896, 63.88455186571394, 65.49076693398612, 60.74656472887312, 58.157120500292095, 60.80520057678223, 59.47482899257115, 59.8761430467878, 58.5789213180542, 59.08928734915597, 59.07073565891811, 57.778534003666465, 55.1458546093532, 55.11007138660976, 57.86386483056204, 54.71534422465733, 59.98453494480678, 57.03824860709054, 57.08208131790161, 54.83603096008301, 55.8300541469029, 53.89127744947161, 51.1501853125436, 54.042557103293284, 55.24023199081421, 54.56307097843715, 59.81509617396763, 59.451031412397114, 62.298757553100586, 57.79661669049944, 61.82105500357491, 63.687285559517996, 62.69226878029959, 64.23458126613072, 61.13032068525042, 63.64951515197754, 66.46655804770333, 59.5408090863909, 42.40367828096662, 1.784491079194205, 0.1395888211471694, 0.04348851374483534, 0.11902086410139288, 0.14712898725909845, 0.14553107800228254, 0.5258255015526498, 0.10378974104034049, 0.06816950919372694, 0.014913628044139062, 0.06432686360286814, 0.7576165923050472, 30.796778542654856, 37.878681319100515, 27.898705754961284, 35.80938965933663, 43.90307869229998, 26.956384113856725, 0.0401060506036239, 0.04694371923272099, 0.024579584997679507, 0.0905504235997796, 0.03319618924121771, 0.12449790377702032, 0.05743634048849344, 0.04822607577911445, 0.09262214707476751, 0.03416866223726954, 0.016120197317962135, 0.14536970880414757, 0.07078676803835801, 0.08936236306492772, 0.08025390574974672, 0.1081167927810124, 0.09323648589530162, 0.12422473914921284, 0.046432144540761194, 0.049517066683620214, 0.02185132121667266, 0.0633103231500302, 0.05686770100146532, 0.07310370049838509, 0.12342948253665652, 0.1901590589966093, 26.23308879988534, 65.55547550746373, 35.70613248007638, 33.387803486415315, 29.309975215366908, 81.35148239135742, 12.90563530581338, 0.2602774564708982, 0.03821186242359025, 0.1647599461887564, 0.10280233688120331, 0.0715213432641966, 0.08018542121031455, 0.3028522990643978, 4.107996480805533, 3.81339807169778, 10.656775270189558, 52.478941440582275, 85.36228139059884, 89.3091013772147, 82.59664126804897, 81.69966357094901, 75.8091823032924, 73.71343190329415, 68.11644949231828, 66.51576519012451, 63.151002747671946, 68.88608755384172, 70.28077166421073, 68.31264577593122, 73.7312957218715, 75.49052401951381, 77.95509869711739, 79.07317502158028, 74.69840853554862, 68.43881811414445, 64.19750567844936, 62.50898224966866, 63.15483120509556, 66.98873601640973, 69.5308039528983, 74.34973403385708, 74.13722337995256, 68.46510314941406, 66.82628713335309, 58.932626315525596, 59.19130080086844, 62.3243408203125, 64.86151722499302, 58.179288727896555, 61.473103114536826, 55.86731038774763, 60.99323272705078, 65.63506017412458, 69.0577289036342, 69.60544845036098, 68.3178847176688, 70.39717483520508, 70.92436940329415, 70.50871426718575, 70.56165259225028, 66.76508045196533, 57.495665890829905, 70.35706288473946, 68.7592968259539, 65.26695850917271, 73.71554415566581, 65.23876966748918, 50.69549172265189, 61.17113440377371, 68.23199803488595, 62.31645461491176, 66.49708148411342, 63.7443858555385, 61.67703969138009, 61.898124422345845, 63.15799958365304, 60.29923275538853, 62.18429292951311, 62.008176939828054, 62.717046056474956, 61.49307223728725, 63.69786071777344, 65.02450806753976, 51.658553736550466, 60.803268977573936, 62.88638060433524, 64.10211385999406, 63.857620647975374, 62.707422801426475, 56.214293003082275, 58.030850887298584, 60.88564682006836, 63.788694517953054, 64.19212777273995, 67.10372175489152, 65.07978098733085, 58.584764753069194, 64.97379316602434, 62.72628716060093, 61.76386438097273, 61.32956027984619, 62.316843714032856, 62.62407915932791, 63.7144113268171, 59.145790100097656, 58.525830132620676, 61.80322592599051, 58.52878311702183, 60.8581736428397, 60.177993638174875, 59.58690343584333, 56.970573152814595, 58.45724446432931, 56.753174441201345, 55.72493832451956, 57.05977760042463, 57.7802780015128, 57.662641525268555, 61.67530958993094, 64.04391574859619, 66.06419481549943, 61.462305613926475, 65.83639812469482, 67.02456092834473, 65.73963751111711, 67.70683928898403, 63.87974371228899, 68.25604575020927, 71.98686708722795, 67.76936612810407, 53.043833460126606, 2.7537489320550645, 0.20102032832801342, 0.09694625397345849, 0.1172545560236488, 0.07705280823366982, 0.2356296447770936, 0.6770785568015916, 0.21388174247528824, 0.11581239769501345, 0.14688073843717575, 0.047803579164402824, 0.8414602875709534, 36.333791051592144, 44.83126769747053, 26.24748546736581, 42.59314176014492, 47.655811173575266, 35.39621155602591, 0.0877198265599353, 0.10270101803221873, 0.07195324437426669, 0.03507155825250915, 0.026971867075189948, 0.08616772520222835, 0.06216414858187948, 0.04669006248669965, 0.10244252333151442, 0.07211742270737886, 0.10378268427614655, 0.04843297128432563, 0.07238733036709682, 0.16046412741499289, 0.15027852968445846, 0.18161189263420446, 0.1624638108270509, 0.23319829095687183, 0.14325380591409548, 0.11465180425771646, 0.1524473311645644, 0.20603816264442035, 0.2082486804574728, 0.16133293722357067, 0.3312141400362764, 0.27041504106351305, 31.29103864942278, 79.44713401794434, 41.715879576546804, 55.14867557798113, 47.17995684487479, 92.18473843165806, 15.935181038720266, 0.34501782219324795, 0.2350620095218931, 0.3019864340978009, 1.3769001960754395, 0.45663023740053177, 0.17300544945257051, 0.7429700610893113, 6.691661979470934, 5.440769101892199, 13.441782627786909, 55.83708572387695, 90.9228413445609, 94.17030429840088, 89.51326724461147, 84.01388617924282, 80.28410012381417, 77.1954174041748, 72.9166680744716, 68.17161124093192, 67.09269496372768, 72.63805225917271, 74.0105368750436, 70.04187870025635, 76.84727096557617, 77.86047118050712, 80.81516483851841, 81.96807943071637, 77.72925445011684, 72.01664011819022, 67.80943638937813, 66.28998347691127, 66.33173520224435, 70.46873433249337, 75.05092539106096, 80.91854013715471, 75.58451925005231, 71.1486155646188, 69.12993458339146, 59.98310361589704, 63.60212843758719, 66.55736405508858, 69.0206880569458, 64.59412275041852, 68.47539343152727, 63.3842259815761, 68.76692594800676, 70.74989318847656, 75.25212437765938, 74.60410063607353, 70.46343980516706, 72.81300095149449, 74.75755855015346, 73.63201986040387, 72.43075970241001, 71.86391871316093, 60.05394050053188, 70.79809979030064, 72.95488316672188, 65.8016779763358, 74.50621441432408, 70.68394783564976, 53.38955845151629, 61.82491820199149, 71.10423047201974, 63.58937849317278, 68.70858192443848, 66.83152607509068, 66.61473533085415, 65.3104681287493, 67.92044775826591, 63.85386862073626, 64.40871007101876, 65.14218275887626, 64.01237092699323, 65.0455402646746, 66.23927552359444, 65.8524832044329, 54.85879325866699, 68.06382383619035, 64.12989970615932, 66.66128826141357, 67.08327320643834, 63.95233154296875, 58.210493087768555, 62.51030240740095, 63.63975988115583, 66.50151443481445, 69.48777375902448, 70.09817995343889, 65.55454444885254, 61.494232586451936, 66.71549115862165, 64.94826548440116, 66.74695260184151, 63.89909444536482, 66.17373316628593, 65.04086412702287, 66.17280905587333, 61.99870654514858, 61.07601356506348, 63.82889679500035, 62.74009323120117, 63.66443988255092, 63.29273905072893, 62.73101888384138, 60.63352448599679, 61.84800706590925, 60.137603759765625, 57.609116077423096, 63.882807867867605, 62.03280830383301, 61.214623178754536, 65.1822669165475, 67.84749862125942, 69.6227216720581, 62.81081199645996, 68.63902350834438, 71.23886571611676, 67.85220949990409, 71.24838474818638, 66.68726062774658, 69.01522677285331, 73.0473358971732, 71.25763280051095, 64.54753507886613, 2.793117859533855, 0.432207319353308, 0.38135334530047005, 0.4987160733767918, 0.23774138146213122, 0.5604880015764917, 0.9746721280472619, 0.6901671716145107, 0.4864263928362301, 0.302687225065061, 0.10307406980012145, 1.7308438207421983, 46.394907678876606, 49.420618874686106, 39.83132314682007, 48.311005456107004, 56.37159327098301, 43.751399517059326, 0.24485278129577637, 0.2349717372230121, 0.11464633526546614, 0.2403586810188634, 0.09302966842161757, 0.24830614456108638, 0.09371676655220133, 0.105388654528984, 0.26002341295991627, 0.16404301965875284, 0.25380526376622065, 0.22343307281179087, 0.15470051525958947], [0.07084875899766173, 0.009358067447984857, 0.0447568144383175, 0.06883488741836377, 0.0341828368338091, 0.02984701842069626, 0.013707164791412652, 0.11749872006475925, 0.0743709664259638, 0.07987873695258584, 0.03585532387452466, 0.0658824322745204, 0.09002487108643566, 35.51563719340733, 51.568873337336946, 33.82483128138951, 35.21075023923601, 36.117392880576, 61.30385889325823, 1.0885871925524302, 0.03258539576615606, 0.04166988722447838, 0.19614562418844017, 0.3045468181371689, 0.11597462184727192, 0.6599294255886758, 0.1322357678519828, 0.9449442603758403, 1.2579122952052524, 25.75661608151027, 81.99498980385917, 87.96695954459054, 81.9380910055978, 76.92493792942592, 74.1484238760812, 70.35761179242814, 64.9984940120152, 63.751778738839285, 63.547876902988975, 62.28194291251046, 68.00789778573173, 71.95944254738944, 72.77113805498395, 75.13292803083147, 72.80927671704973, 77.07822908673967, 73.62476594107491, 70.36001586914062, 65.23971462249756, 61.2194104875837, 57.80844947269985, 57.642634187425884, 60.90570626940046, 65.16997555324009, 68.02298927307129, 71.3048597063337, 68.85627978188651, 70.66937051500592, 63.6988890511649, 54.907236099243164, 55.595448221479145, 58.63839789799282, 53.28605113710676, 54.573319571358816, 59.837566648210796, 61.55855206080845, 61.121246337890625, 64.53921808515275, 65.34615407671247, 64.11528069632394, 68.32132407597133, 64.74533639635358, 69.71366664341518, 64.75133269173759, 56.38881090709141, 64.77617944989885, 65.1423703602382, 61.66746507372175, 68.1554149900164, 61.02595179421561, 52.33339752469744, 61.96063041687012, 66.52563163212368, 60.424348967415945, 62.15769522530692, 57.501220975603374, 57.75202662604195, 57.41602563858032, 60.48493725912911, 60.29371588570731, 63.39661461966378, 62.83788912636893, 60.933707509722026, 62.41857923780169, 59.752492904663086, 54.214035170418875, 64.22807080405099, 63.37717356000628, 50.81771748406546, 56.07975850786482, 64.08437510899135, 58.46143422807966, 58.71746144975935, 60.79534803118025, 55.899393694741384, 56.296288694654194, 56.666975089481895, 60.26479748317173, 60.213714327131, 61.81016717638288, 58.324172564915244, 59.43710722242083, 61.00145244598389, 57.714589732033865, 58.96204498835972, 61.06800924028669, 58.401172501700266, 57.51711845397949, 57.994011538369314, 57.86826998846871, 55.719633374895366, 55.4712734903608, 57.67045824868338, 58.77525656563895, 55.92621374130249, 55.369610922677175, 55.85178116389683, 53.11062996728079, 52.09138134547642, 50.92816604886736, 53.83990246909005, 55.31116962432861, 57.52415003095354, 58.62982382093157, 60.18021011352539, 63.072640963963096, 63.28088542393276, 65.71893187931606, 62.48369080679757, 62.62037576947893, 61.04007053375244, 64.8827439716884, 65.74796840122768, 65.65347984858921, 53.60792643683297, 24.988183532442363, 0.1160078157803842, 0.07510678337088653, 0.1918808144650289, 0.12822098471224308, 0.07140665727534465, 0.24394810412611279, 0.16609271110168525, 0.04561607386650784, 0.11794883305472986, 0.024186233158356378, 0.18269529592778, 13.01616985457284, 53.13951710292271, 42.38468190601894, 28.1515246459416, 36.28859996795654, 36.426215989249094, 0.2453598098031112, 0.058292230990316184, 0.06367962261927979, 0.08029043807515077, 0.11418839198138032, 0.11271082091012172, 0.15698481697056973, 0.04244792940361159, 0.05274396549378123, 0.0733303651213646, 0.07787810359150171, 0.12510509762380803, 0.05476322464112725, 0.07902608984815222, 0.0317309675072985, 0.07650271310870137, 0.06471668197108166, 0.06642912793904543, 0.08634787624967949, 0.00793019906684224, 0.05508522004155176, 0.07301180650080953, 0.026491415088198016, 0.05114949980218496, 0.00745288106346769, 0.07251046411693096, 44.7227646282741, 57.13859101704189, 48.795649256025044, 30.63567761012486, 40.6768980707441, 71.3804908479963, 1.6966418560062135, 0.03870996141007968, 0.16503212015543664, 0.07718870522720472, 0.3783732194985662, 0.11330801993608475, 1.4258446097373962, 0.057897092907556465, 0.9236405406679425, 2.3406005757195607, 30.169047015053884, 85.16896860940116, 91.26306683676583, 87.36531502859933, 81.42195796966553, 78.96362972259521, 72.88538033621651, 69.85849489484514, 67.76407160077775, 67.18120806557792, 65.85344205583844, 70.83831596374512, 76.16087927137102, 75.4838537488665, 77.71080698285783, 75.58631883348737, 81.53666578020368, 76.53674902234758, 73.99255493709019, 68.2015162876674, 63.52856091090611, 62.05850274222237, 61.03909778594971, 62.40662833622524, 71.03891045706612, 70.57481248038155, 72.32376439230782, 73.46586063929966, 72.83359541211809, 67.71749087742397, 60.19093118395124, 57.875332832336426, 60.78420312064034, 59.878470693315776, 58.05644457680838, 68.72381237574986, 68.63288130078996, 65.93343666621617, 70.90713787078857, 68.93757370540074, 70.3525743484497, 68.69858346666608, 68.19494329180036, 70.76647853851318, 64.24014677320207, 59.46357291085379, 68.71495342254639, 65.90264919825962, 65.30568776811872, 70.25791209084647, 60.784988267081125, 54.80427074432373, 66.5691898890904, 67.72218091147286, 63.408273696899414, 63.32014274597168, 61.305672373090474, 60.71201828547886, 61.479724747794016, 63.014922278267996, 63.39332117353167, 66.07683358873639, 63.56191921234131, 61.75927856990269, 65.13699245452881, 62.009267807006836, 56.19387224742344, 62.913707869393484, 66.94234289441789, 55.645558629717144, 55.1425507409232, 66.26584543500627, 61.31977721623012, 60.22141293116978, 62.82011563437325, 58.64415795462472, 58.53717654091971, 58.417042187282014, 60.990140778677805, 62.446677752903526, 64.0270802634103, 60.49998010907854, 61.167097500392366, 65.09742246355329, 60.88629995073591, 60.71163613455636, 61.062172753470286, 59.84728717803955, 61.05686432974679, 59.75529997689383, 61.50354317256382, 59.48136724744524, 57.53462791442871, 62.4639926637922, 60.76885454995291, 58.488622529166086, 57.25723498208182, 56.8936322757176, 54.78791468484061, 53.17630781446184, 54.32803773880005, 56.44820063454764, 59.12591825212751, 58.57019438062395, 62.05590411594936, 63.418487548828125, 66.78068610600063, 66.7837780543736, 68.89074979509626, 65.45761707850865, 64.1399120603289, 63.331919942583355, 67.73678602491105, 69.88940743037632, 72.52534552982875, 64.8433893748692, 33.486308097839355, 0.41423775787864414, 0.06813296329762254, 0.26050074877483503, 0.3317490427621773, 0.11063113821936504, 0.23081644305161067, 0.05272798599409206, 0.17183067463338375, 0.19119054079055786, 0.14414468168147973, 0.08543128400508847, 13.520177415439061, 63.829195567539756, 35.22875649588448, 31.279643603733607, 46.31749779837472, 44.4003404208592, 0.32277069453682217, 0.08430285991302558, 0.07042715804917471, 0.022937004387910877, 0.05872163509151765, 0.027557145937212875, 0.17055542234863552, 0.10113328322768211, 0.09630585262285811, 0.06061054087643113, 0.017284636352477328, 0.010105759603902698, 0.022462571006534354, 0.12295241813574519, 0.10972321086696216, 0.18173303827643394, 0.1288675878729139, 0.1822960459228073, 0.22159649564751557, 0.10316874579127346, 0.1547818308962243, 0.1363843988095011, 0.1399378731314625, 0.10750018086816583, 0.13727132550307683, 0.1869983614555427, 52.41904102052961, 70.38413306644985, 45.56835692269461, 48.44810036250523, 52.95665441240583, 79.0426446369716, 2.461156598159245, 0.15975508546190603, 0.21417835727334023, 0.2781283014586994, 0.7881995226655687, 0.20006094766514643, 2.55339697429112, 0.18471646175852843, 1.4741200421537672, 3.929895043373108, 34.93823841639927, 91.0981443950108, 96.93182413918632, 89.90318625313895, 87.66665840148926, 83.77475002833775, 79.352846963065, 71.68783746446881, 70.44589560372489, 70.49829196929932, 69.51958956037248, 73.5702156339373, 78.98146574837821, 77.23682866777692, 81.5673142841884, 77.20016302381242, 83.56743662697929, 81.31740147726876, 77.4314546585083, 70.91605935777936, 68.07135568346295, 64.83080618722099, 63.983987535749165, 65.94131592341832, 72.59942027500698, 74.00178214481899, 77.09892777034214, 77.43703406197685, 76.11345781598772, 69.8349335534232, 59.61393887656075, 62.31900460379464, 63.365201813834055, 64.3583356312343, 63.22404221126011, 71.39898695264543, 73.81798144749233, 72.70779132843018, 76.78185367584229, 72.58154256003243, 72.33650738852364, 73.82875115530831, 69.59771510532924, 73.72816903250558, 69.22437449863979, 63.473746572222026, 68.37257398877824, 71.2054865700858, 66.51796082087925, 74.20730985913957, 66.61305386679513, 56.32260847091675, 67.59186744689941, 73.0258103779384, 64.08528532300676, 67.97461591448102, 64.7294875553676, 63.38205814361572, 62.079951831272666, 65.95701885223389, 64.45501286642892, 67.35770620618547, 66.95761503492082, 66.00860227857316, 67.25856930868966, 63.37335899897984, 59.37549754551479, 67.85898399353027, 67.6178537096296, 56.67613976342337, 60.99935409000942, 69.94605609348842, 61.986345699855256, 63.86678532191685, 64.89618178776333, 60.58107253483364, 62.426319531032014, 61.202039991106304, 64.30541120256696, 64.05253846304757, 66.3408373423985, 61.4675931930542, 63.987913267953054, 68.05652822766984, 62.88718659537179, 64.75607136317662, 64.77944510323661, 62.1281931740897, 64.29465539114815, 64.27133028847831, 62.913374355861116, 61.00027125222342, 62.11462334224156, 65.09821455819267, 64.85253320421491, 60.582406588963096, 60.13219806126186, 60.749573298863, 59.94850158691406, 56.828402587345664, 58.157068388802664, 61.16792433602469, 62.467077663966585, 61.87159620012556, 65.6338859285627, 64.50981330871582, 70.05129350934709, 66.90970025743756, 70.78687150137765, 68.69497735159737, 67.18079117366246, 66.92581312997001, 70.19612870897565, 72.61036368778774, 73.80842767442975, 72.33416584559849, 39.58768456322806, 0.5444909142596381, 0.15819506560053143, 0.6570480944854873, 1.1378706565925052, 0.31078575764383587, 0.5843814451779638, 0.3780768354024206, 0.41653554886579514, 0.5186621802193778, 0.3473190872796944, 0.26776452043226784, 22.385284117289952, 71.03424821581159, 55.30247047969273, 40.94627625601632, 48.38455213819231, 54.03970486777169, 0.24999352544546127, 0.20656108244189195, 0.14155991109354155, 0.2155332559985774, 0.25986276300890104, 0.20107367475117954, 0.24719074155603135, 0.21218855333115372, 0.11159513292035886, 0.10964505720351424, 0.10648406789238964, 0.1872237300766366, 0.15521830533232006], [0.1585119143128395, 0.06366457949791636, 0.059139334463647435, 0.06683685284640108, 0.06261080104325499, 0.07462361894015755, 0.06808704004756042, 0.07473522438002483, 0.023363385615604262, 0.04943437022822244, 0.07395936708365168, 0.12501908652484417, 1.3680139929056168, 57.31758008684431, 40.386984484536306, 29.812840666089738, 23.932868548801967, 48.09320722307478, 35.730041231427876, 0.1529132675911699, 0.10938642679580621, 0.2243710524801697, 0.20975129625626973, 0.22707470240337507, 0.397677622203316, 0.20875042996236257, 0.07651547635240213, 0.09746778955949204, 3.7376462050846646, 61.9548773084368, 84.48168754577637, 81.41119521004813, 77.99954632350376, 71.4760355268206, 67.20702062334333, 65.35231712886265, 64.125216620309, 63.29464980534145, 60.50767176491873, 67.17918613978794, 74.13333238874162, 77.46460451398576, 74.62137385777065, 76.68536404200962, 75.5940521785191, 76.85974298204694, 73.81503541128976, 70.74480015890938, 63.44527980259487, 60.655904633658274, 55.98010049547468, 57.77178382873535, 57.98033400944301, 61.39646448407854, 65.10938726152692, 65.80247701917375, 66.43420028686523, 66.44708919525146, 66.47631331852504, 65.9678510938372, 56.6363057409014, 58.67764827183315, 59.158831868852886, 52.49318177359444, 58.07258524213518, 59.76684788295201, 54.86856589998518, 59.46101597377232, 68.27363858904157, 66.4338389805385, 64.80298560006278, 72.90095124925885, 65.08329677581787, 54.268411772591726, 68.25199495043073, 64.35192244393485, 60.23639324733189, 65.99018955230713, 60.253138405936106, 52.07062707628523, 63.562620980399, 63.52634443555559, 60.09160668509347, 61.213824135916575, 61.574220248631065, 61.76473985399519, 63.03926181793213, 64.51332909720284, 59.56475952693394, 59.96530927930559, 59.94820281437465, 52.26028857912336, 48.962075982775005, 52.34577921458653, 57.683461802346365, 56.836921078818186, 57.146730831691194, 60.47070734841483, 62.91937065124512, 52.44019481113979, 53.397274426051546, 60.65508474622454, 61.78103337969099, 60.77679634094238, 59.17313820975167, 59.5298934664045, 58.208349568503245, 56.943579401288716, 58.75271660940987, 61.30760397229876, 60.873626436506, 55.18542112622942, 58.6341039112636, 60.32974924360003, 56.06587948117937, 60.565383502415244, 57.415462834494456, 55.00879444394793, 52.53414140428816, 58.29427446637835, 55.119309016636436, 54.503653458186555, 60.036236490522114, 57.73027181625366, 57.385894775390625, 55.37238325391497, 53.3912399155753, 51.905586515154155, 52.738606044224326, 50.86137648991176, 52.64365891047886, 53.81414549691336, 57.56338650839669, 59.488211223057334, 63.04878085000174, 59.756085123334614, 62.70417104448591, 63.283768926348, 64.04556941986084, 61.88297734941755, 59.528997148786274, 63.04350021907261, 59.78524671282087, 64.47520433153424, 57.2123635155814, 48.72967611040388, 11.775227665901184, 0.017144149069541266, 0.13396772848708288, 0.29578733816742897, 0.1957395209797791, 0.1923377535172871, 0.1585783293204648, 0.27401621639728546, 0.09030861407518387, 0.07417789607175759, 0.06784128823450633, 4.84255439043045, 42.524382386888774, 41.53381940296718, 29.939290932246617, 33.365784645080566, 46.128166334969656, 0.8458794504404068, 0.05554026937378304, 0.13389014479305061, 0.021028397338730947, 0.07706720674676554, 0.11734913023454802, 0.08708552523915257, 0.134472110707845, 0.06442772104804005, 0.060047119323696406, 0.09539992694876023, 0.02124604083863752, 0.09879244597894804, 0.11024267013583865, 0.021857509456042732, 0.10236358256744486, 0.05776109413376876, 0.07337899572615113, 0.0441423297327544, 0.02905437077528664, 0.03724117736731257, 0.057773850592119355, 0.028020203679001758, 0.08738978034151451, 0.16898014902004174, 2.08785594361169, 64.86412279946464, 47.65487316676548, 40.00523655755179, 28.746738604136876, 54.300877230507986, 42.43127999986921, 0.15031929606837885, 0.09120895540607826, 0.5274889980043683, 0.13140612308468136, 0.33801683357783724, 0.6168309439505849, 0.34424904201711926, 0.09858726377465896, 0.20140315778553486, 4.96751253093992, 65.45360101972307, 86.8795873097011, 85.52534866333008, 81.02913461412702, 77.2990289415632, 70.57522242409843, 70.14821393149239, 67.47915376935686, 67.22576686314174, 63.37606879643032, 69.9187079838344, 77.07645034790039, 78.5270813533238, 77.0268680027553, 81.31551156725202, 77.67318943568638, 77.46230466025216, 78.32536125183105, 73.83576883588518, 66.35082190377372, 63.352674211774556, 58.60822881971087, 60.76600578853062, 59.96116120474679, 63.680483273097444, 65.13546385083879, 68.38248211996896, 68.94092273712158, 69.5600141797747, 69.66787106650216, 67.61428928375244, 59.240091051374165, 64.45297704424176, 62.82912049974714, 57.64314488002232, 60.49463694436209, 66.8654054914202, 61.39496367318289, 62.5812782560076, 71.02272810254777, 68.41106006077358, 67.57154396602085, 72.31095886230469, 63.537572724478586, 58.21476970400129, 71.60753713335309, 66.78213827950614, 65.8471678325108, 67.90348025730678, 59.730126653398784, 56.20194952828543, 67.54830918993268, 64.96986743382045, 62.325904164995464, 63.92194707053048, 64.64490713391984, 61.74359648568289, 64.22207450866699, 63.90937083108084, 59.253167561122346, 59.00401210784912, 59.52166679927281, 54.06372479030064, 48.96516793114798, 53.901546886989046, 59.15584414345877, 59.9335629599435, 58.75200094495501, 60.416469710213796, 64.97427259172711, 55.78779172897339, 54.43857315608433, 61.19769736698696, 63.741849763052805, 62.12491362435477, 60.069497517177034, 62.72090230669294, 61.63121632167271, 60.878233092171804, 58.95695195879255, 62.34954193660191, 62.82638985770089, 57.238162176949636, 60.38176345825195, 63.68888364519392, 59.639487402779714, 61.56917585645403, 59.26456260681152, 58.461934498378206, 56.0042975970677, 60.71909849984305, 59.022605487278526, 58.34935283660889, 63.163349696568076, 60.94182995387486, 58.77055958339146, 57.79163135801043, 56.29925904955183, 54.655905859810964, 55.8826276915414, 53.785498074122835, 55.203698362622944, 55.353668281010215, 59.125362396240234, 61.49801935468401, 64.31413813999721, 64.60964502607072, 67.19065761566162, 67.8286828994751, 66.19061728886196, 66.14222308567592, 63.309616225106375, 63.75116729736328, 63.12860175541469, 69.26789801461356, 67.27256992885044, 60.516447339739116, 15.159082889556885, 0.038842404660369666, 0.0212792856618762, 0.28126473458749907, 0.10867712021406208, 0.2658079782766955, 0.19472352335495607, 0.5390063971281052, 0.12173087868307318, 0.2003812976181507, 0.05169687739440373, 5.0965101804052075, 49.2687486239842, 38.60104731151036, 33.70814323425293, 43.34313031605312, 51.077524525778635, 1.4268377678734916, 0.2044325452297926, 0.05662636984405773, 0.04480843738253627, 0.04161637456023267, 0.05452792566003544, 0.032282999849745204, 0.053264741120593886, 0.03719487413764, 0.06616029915000711, 0.08359963300504855, 0.022753662529534528, 0.08260401178683553, 0.3002371708197253, 0.12285986595920154, 0.17568151014191763, 0.15563782996365003, 0.18976040610245296, 0.18218404693262918, 0.11884565278887749, 0.08393441539789949, 0.1936387765620436, 0.13908504960792406, 0.148372741948281, 0.24196917031492504, 2.7649535536766052, 77.0851286479405, 54.85573257718767, 40.76868030003139, 38.233557088034495, 67.38281699589321, 49.86089842660086, 0.21077177221221582, 0.2196805705981595, 0.4321239138288157, 0.3692116396767752, 0.3482174133615834, 1.1765129544905253, 0.8522014426333564, 0.49329778126307894, 0.6749133786984852, 6.003156295844486, 70.39104652404785, 91.78161089760917, 90.18566526685441, 87.59278515407017, 80.05399663107735, 75.47874682290214, 74.05204541342599, 71.35379586900983, 71.23439802442277, 67.65964017595563, 73.50893947056362, 81.14770562308175, 81.474472454616, 80.36580399104527, 83.56828430720738, 83.83459486280168, 82.81268855503627, 80.99214935302734, 78.1111969266619, 69.46624823978969, 66.06532737186977, 62.687933104378835, 63.68355437687465, 62.28279754093715, 66.79436016082764, 69.85657024383545, 72.25482436588833, 74.13721643175397, 73.17350128718785, 75.98878628867013, 71.538437298366, 61.80749906812395, 65.97664056505475, 65.46055616651262, 62.32528577532087, 64.77924360547746, 70.07262447902134, 65.40595722198486, 65.79426424843925, 74.3203570502145, 72.93762384142194, 69.70484937940324, 76.51261098044259, 70.61772455487932, 59.867381368364605, 74.85547256469727, 68.44136810302734, 64.81419304439, 71.0040374483381, 65.66475677490234, 56.970503670828684, 70.68754005432129, 68.47849232809884, 64.07332052503313, 65.64336327144078, 67.37793936048234, 64.69303035736084, 68.45985725947789, 68.02050876617432, 63.675501414707725, 61.54211957114083, 63.75647572108677, 55.18867288316999, 50.54700524466378, 54.83290774481637, 61.170279775347026, 60.272329330444336, 60.53703485216413, 64.23340702056885, 67.90663473946708, 56.68479027066912, 57.961761474609375, 64.39533478873116, 65.71394307272774, 65.28526701245988, 62.88558850969587, 63.38220405578613, 62.96272046225411, 64.2885548727853, 62.2748418535505, 65.479337147304, 64.48297241755894, 58.59074020385742, 63.312395504542756, 66.56083815438407, 64.29634380340576, 64.63449873243059, 63.41203267233712, 61.090479714529856, 61.42751598358154, 63.947523389543804, 63.064803395952495, 60.92003345489502, 65.97198527199882, 65.14753981998989, 63.368828773498535, 62.679477146693635, 59.280564308166504, 57.81850699016026, 59.32984093257359, 57.131444794791086, 58.38267639705113, 59.18231678009033, 62.51829283578055, 65.80385971069336, 69.11629526955741, 66.64846883501325, 68.49986498696464, 70.12518065316337, 69.72845935821533, 69.82442092895508, 64.26240185328892, 67.02533217838833, 64.79940727778843, 72.18505750383649, 71.21622153690883, 70.7864476612636, 16.019726719175065, 0.1137519853987864, 0.5393817627004215, 1.5409770203488213, 0.49376325628587175, 0.6474580605115209, 0.3235294052532741, 0.7085934685809272, 0.3965463143374239, 0.3137651506279196, 0.14556595470224107, 8.84923962184361, 58.013633251190186, 55.48384625571114, 43.05243158340454, 42.96342168535505, 66.4817954472133, 1.2139425746032169, 0.21057179437151977, 0.21430406267089502, 0.2151075838399785, 0.15314300597778388, 0.22794697274054798, 0.16142763357077325, 0.2295434842152255, 0.18337315241140978, 0.18424747192433902, 0.16547045377748354, 0.19397470567907604, 0.1979985133345638], [0.05196702932672841, 0.06199473874377353, 0.0132735240871885, 0.0571683259414775, 0.023813920993623987, 0.03619065588074071, 0.048300399112382104, 0.014905321079173257, 0.02945545282480972, 0.09362227376550436, 0.08087137261671679, 0.4184979535639286, 5.839586581502642, 59.242363112313406, 37.484384945460725, 35.379879815237864, 16.926920005253383, 65.84033080509731, 13.74279682976859, 0.08502997125365905, 0.14155946326042923, 0.3972523978778294, 0.09946550521999598, 0.08434911564524684, 0.03806540063981499, 0.14907683059573174, 0.019461732923186252, 0.2530970631965569, 16.16817150797163, 80.0861737387521, 83.6189992087228, 82.01915563855852, 73.09096363612584, 69.2448091506958, 63.63511848449707, 66.08583845411027, 62.03009155818394, 64.92954008919853, 57.21560137612479, 67.83670112064907, 74.53059564317975, 77.40965121132987, 74.84800325121198, 76.87954534803117, 72.72428635188511, 74.50870881761823, 76.4306639262608, 71.22567803519112, 66.39378261566162, 61.81175831386021, 57.03268657411848, 58.007279123578755, 56.8260749408177, 59.64888136727469, 60.495352608816965, 64.19959013802665, 64.78116130828857, 68.08061068398612, 64.99103164672852, 65.96381419045585, 61.04973547799246, 57.24375895091465, 60.49688121250698, 57.95607784816197, 60.40875720977783, 63.56214155469622, 64.97629451751709, 59.65849072592599, 63.93383543831961, 63.28813239506313, 68.08387633732387, 59.57940632956368, 56.2370240347726, 67.10725143977574, 66.33079024723598, 65.56095068795341, 67.7141557421003, 59.1314629146031, 52.605165890284944, 62.55463886260986, 63.645214217049734, 64.83052825927734, 61.14723954881941, 61.17177363804409, 60.04014137813023, 57.094834736415315, 55.41618122373308, 53.90860973085676, 51.79100724628994, 53.46029806137085, 54.51122352055141, 58.03853906903948, 54.58760854176113, 57.20343508039202, 60.69770499638149, 62.18796852656773, 60.95777606964111, 58.76018592289516, 57.761497020721436, 59.52724620274135, 55.567843028477256, 47.601347718920024, 56.905760356358115, 59.93375750950405, 58.84787218911307, 59.52657222747803, 58.53512682233538, 61.6552015032087, 56.943721839359824, 58.22793306623186, 59.81803526197161, 61.229721614292686, 56.64159679412842, 56.37345538820539, 61.6053273337228, 59.01591437203543, 56.66384840011597, 56.91678714752197, 52.438756534031455, 57.966305596487864, 51.80519199371338, 56.41002375738961, 57.86147812434605, 58.04778017316546, 55.46549258913313, 54.69172034944807, 54.71870367867606, 51.40539264678955, 50.36006048747471, 50.405664988926475, 51.52783727645874, 55.61345795222691, 54.96936341694423, 58.2419684273856, 60.03648662567139, 59.67990507398333, 65.16919040679932, 64.25586359841483, 60.90095370156424, 58.462406975882395, 63.591601916721885, 63.53842735290527, 59.051350184849326, 62.87265791211809, 60.26019082750593, 54.12636974879673, 39.18170479365757, 2.243339691843305, 0.05013804496931178, 0.10047038165586335, 0.10117205471864768, 0.06793594386960779, 0.04920558179063456, 0.6223844002400125, 0.2459617517888546, 0.1853604322033269, 0.08132276125252247, 1.0298230201005936, 29.74926812308175, 39.81678056716919, 33.27535036631993, 30.238087790352957, 49.31105967930385, 2.736526301928929, 0.057542158024651666, 0.08840032933013779, 0.03946533712691494, 0.09380116273782083, 0.07521667890250683, 0.07325592304446868, 0.0888967794765319, 0.09476119479430573, 0.05332741400759135, 0.0927085110119411, 0.0902252085506916, 0.04733865375497511, 0.02194171734819455, 0.027444057898329835, 0.0601273493043014, 0.045815580125365934, 0.015592782225991999, 0.01636526550698493, 0.014447801879474094, 0.12645108039890016, 0.06858272344938346, 0.06349266586559159, 0.11631926335394382, 0.5149802320769855, 8.063967244965689, 70.48706368037632, 42.121862820216585, 42.64515250069754, 21.099874326160975, 68.63321481432233, 17.78921750613621, 0.1894823153104101, 0.05100776401481458, 0.5223359316587448, 0.06589932101113455, 0.09821945708245039, 0.10690692413066115, 0.23998871658529553, 0.25193380990198677, 0.33017424440809656, 18.323271683284215, 83.59228338514055, 86.50391210828508, 86.21748651776994, 76.25372804914201, 72.34994520459855, 66.04889488220215, 68.77935627528599, 66.08861773354667, 66.75130912235805, 63.29312120165144, 70.71202550615583, 78.49024895259312, 79.73748534066337, 78.66775458199638, 76.86199419839042, 75.95232214246477, 76.9479295185634, 78.93990857260567, 75.18869427272251, 70.33616965157645, 64.43933773040771, 59.2247633252825, 60.902989523751394, 57.51176486696516, 61.470018114362446, 63.40126296452114, 65.71327604566301, 67.01495156969342, 72.48107160840715, 67.72635677882603, 67.78230367388043, 65.0928852898734, 61.70219911847796, 64.03674520765031, 61.99975572313581, 65.7082108088902, 65.45397622244698, 68.98894868578229, 65.72968769073486, 69.21273626599992, 69.20732361929757, 68.61054284232003, 62.24769524165562, 59.75129781450544, 70.74723202841622, 67.44646944318498, 68.75045871734619, 69.1387448992048, 59.20198713030134, 56.689855507441926, 66.32407828739711, 66.58159937177385, 64.80456978934151, 63.32457569667271, 63.618373325892854, 62.416314125061035, 57.23200607299805, 53.8841347013201, 54.1925756590707, 54.865689345768516, 56.852561473846436, 55.667772020612446, 60.18786702837263, 58.688001087733674, 60.25107479095459, 60.774086543491904, 63.23356819152832, 62.8542034966605, 59.74018069675991, 58.339944975716726, 62.49009009769985, 58.795329911368235, 50.40667595182146, 55.776573862348286, 60.37733745574951, 61.02963433946882, 61.00523921421596, 59.056880950927734, 64.26982252938407, 58.75110462733677, 60.534721102033345, 58.820447649274556, 65.13920198168073, 59.789082118443076, 59.582505226135254, 61.7757180077689, 60.11769022260393, 58.622333662850515, 58.949691091264995, 54.844945498875205, 60.50613621303013, 56.221991607121055, 59.95214244297573, 60.4225354875837, 61.896039962768555, 57.10802936553955, 59.20327254704067, 57.149930477142334, 54.26230430603027, 52.42283821105957, 53.426130294799805, 54.547687666756765, 57.75352396283831, 59.33679607936314, 60.73171642848423, 63.32003852299282, 62.50067220415388, 68.09205436706543, 65.20513343811035, 63.61773409162249, 60.52440997532436, 67.14049857003349, 65.7191264288766, 61.97725050789969, 66.64634963444301, 67.70420592171806, 63.86107390267508, 44.172887665884836, 3.0440075397491455, 0.016825271537527442, 0.3505459555557796, 0.27990519468273434, 0.021873458421656063, 0.16827639964010033, 0.2673667903457369, 0.07057473941573075, 0.21931451452629908, 0.05769072326698473, 1.1536540325198854, 38.66041966847011, 42.91639627729143, 30.496157782418386, 35.90966953550066, 56.494263717106406, 3.9730889541762213, 0.16120871103235654, 0.09468385537288018, 0.04083812203524368, 0.1165240995053734, 0.03778224458385791, 0.016121252439916134, 0.059072865173220634, 0.09924142581543752, 0.07821991560714585, 0.10503313610596315, 0.06813402181225163, 0.04221002145537308, 0.09497668394552809, 0.14642899696316036, 0.0932931232133082, 0.1415813256587301, 0.1557219818766628, 0.12435584568551608, 0.07750373546566282, 0.14463367472801889, 0.20026544454906667, 0.27727150171995163, 0.25034283527306145, 0.7247080781630107, 10.371724554470607, 81.36762305668422, 50.76968806130545, 46.73863506317139, 25.052169493266515, 87.61485263279506, 20.100009441375732, 0.34955135892544476, 0.25894228954400333, 0.881237801696573, 0.2198117042758635, 0.48634496863399235, 0.2917030459003789, 0.2750202582350799, 0.7199445452008928, 1.0516416664634431, 21.648370334080287, 90.64697006770542, 91.17023890359062, 92.37658514295305, 80.88830852508545, 78.28860528128487, 71.13750539507184, 73.62601661682129, 69.52405725206647, 69.62383338383266, 64.35279096875871, 74.20909554617745, 80.0962347303118, 81.62253856658936, 81.69907297406877, 81.32362011500767, 79.0454169682094, 78.89159774780273, 82.99261215754917, 77.09751033782959, 72.4958712714059, 68.87927831922258, 63.15370559692383, 64.90355382646833, 61.90042427607945, 65.97755772726876, 66.87985079629081, 69.41709668295724, 71.28544643947056, 73.91265065329415, 70.81674875531877, 72.15380450657436, 67.82737663814, 64.86847931998116, 66.50502327510289, 63.75036825452532, 68.75159127371651, 69.19259343828473, 71.18470450810024, 68.90830094473702, 70.79153374263218, 71.42520250592912, 71.42751625605992, 66.04887403760637, 61.464522089277, 72.46081066131592, 70.91584396362305, 70.85396330697196, 74.83910260881696, 63.296171460832866, 57.73774112973894, 68.02970123291016, 69.47118146078927, 68.71204212733677, 65.95259284973145, 65.14194652012416, 64.55182211739677, 61.400556973048616, 57.79880884715489, 56.430180481501985, 56.78435795647757, 59.82166222163609, 57.384616306849885, 61.65526403699602, 58.636431557791575, 61.0125070299421, 65.0130921772548, 67.91393729618618, 64.62483378819057, 61.30393532344273, 61.17946529388428, 64.78733130863735, 58.74205807277134, 52.70237813677107, 61.98248250143868, 63.04138796670096, 62.675593103681294, 61.64999730246407, 61.17292703901018, 66.8328879220145, 61.9999989100865, 65.63841615404401, 64.24022320338658, 68.16197408948625, 60.71589538029262, 60.9804619380406, 65.92224311828613, 64.19019617353166, 62.16709613800049, 62.15969630650112, 58.24868386132376, 62.10949557168143, 58.71554374694824, 62.464541571480886, 64.70491177695138, 64.72046879359654, 59.93562657492501, 61.675837653023855, 61.79474912370954, 57.836047717503135, 55.785603046417236, 56.945344243730815, 59.61365400041853, 61.31146717071533, 61.66790975843157, 62.703288623264854, 65.2294590813773, 64.26525061471122, 70.15564850398472, 68.9744964327131, 65.767242704119, 62.89815780094692, 69.42136982509068, 70.59912422725132, 64.24145303453717, 69.77952861785889, 72.69602802821568, 73.79084178379604, 50.94275031770979, 3.6720452223505293, 0.28938278183341026, 0.7142910457083157, 0.4607822203210422, 0.14392981678247452, 0.4743628001638821, 1.3233802850757326, 0.30050288513302803, 0.766582048365048, 0.18941229049648556, 1.9521139817578452, 48.940748487200054, 52.90217011315482, 45.66319635936192, 40.382019996643066, 68.14829308646065, 4.638729419027056, 0.2832861446908542, 0.2568415994090693, 0.14202796454940522, 0.1669696904718876, 0.12842104397714138, 0.19848800849701675, 0.14107393074248517, 0.1648972545351301, 0.16666532680392265, 0.16525144981486456, 0.16690073774329253, 0.24560530377285822], [0.05060909754995789, 0.02682040788100234, 0.059430344562445364, 0.15445498057774135, 0.035455042496323586, 0.09448378253728151, 0.03684572037309408, 0.08675769783024277, 0.014734717019434487, 0.08472085105521338, 0.01728006641912673, 0.3998127819171974, 11.925292253494263, 54.24815777369908, 40.26522772652762, 46.58810234069824, 38.190492153167725, 60.19897024972098, 2.6292967072554996, 0.11025276673691613, 0.127436652513487, 0.6660384663513729, 0.2547042683831283, 0.16637996211647987, 0.14357852563261986, 0.7269986495375633, 0.07846266829541751, 0.3351267086608069, 32.857447487967356, 85.77515724727085, 77.54245213099888, 77.2561377116612, 70.65960829598563, 66.54952648707798, 68.74519893101284, 77.18685722351074, 74.196991784232, 67.61399051121303, 58.83346162523542, 66.72711549486432, 76.06753717150006, 77.4262226649693, 71.63334969111851, 75.68027932303292, 75.75509057726178, 74.2082131249564, 73.87627683367047, 73.02740846361432, 68.83536570412772, 63.27755028860909, 57.05315249306815, 57.007891927446636, 56.54378352846418, 56.58763360977173, 58.9168678011213, 61.41001347133091, 63.25375965663365, 64.6619371686663, 65.7165972845895, 67.24757031032017, 66.65033095223563, 59.699498994009836, 61.21504007066999, 62.32980210440499, 62.080201966421946, 65.4992367880685, 69.14344882965088, 66.0680719103132, 67.26801191057477, 63.894341877528596, 61.07831341879708, 59.11655902862549, 68.49104077475411, 62.12570571899414, 65.82836600712368, 64.14426858084542, 55.15353584289551, 53.23892150606428, 63.06749929700579, 63.13201332092285, 62.62973499298096, 59.541962487357004, 60.54218346732003, 59.85814721243722, 57.56795147487095, 54.64530290876116, 57.25885043825422, 58.20030702863421, 56.01784658432007, 55.729604039873394, 57.84295422690255, 56.446508748190745, 58.87935447692871, 59.847377504621235, 59.17289502280099, 58.10505417415074, 59.98078291756766, 60.09723472595215, 60.691354342869346, 57.237449986594065, 60.97171415601458, 58.67877388000488, 48.11487170628139, 55.23755693435669, 60.730938230242046, 61.70496450151716, 57.99514756883894, 56.815954889569966, 59.8517062323434, 58.021203313555034, 56.65036194665091, 57.428261416299, 61.30646446772984, 59.56074346814837, 57.48101561410086, 55.50772374016898, 57.845198495047434, 55.77271066393171, 53.91905287333897, 55.20589746747698, 53.86316156387329, 58.257330894470215, 57.31848335266113, 57.91274193355015, 56.993818351200645, 56.05466161455427, 53.35541500364031, 51.48123223440987, 49.863097531454905, 49.95254864011492, 49.99070814677647, 52.83252831867763, 54.385360377175466, 58.410920824323384, 58.69255910600935, 61.88603455679757, 63.423281805855886, 61.64466108594622, 57.74809741973877, 61.067050388881135, 66.60850279671806, 64.74791417803083, 62.245041029793875, 54.77496671676636, 63.73001003265381, 54.017550536564414, 54.57651226861136, 15.4664694581713, 0.08355330263397523, 0.16495497072381632, 0.34268056760941235, 0.14098633187157766, 0.13136568239756993, 0.3896102750939982, 0.021604003684063042, 0.07505498400756291, 0.07307558879256248, 0.04122767238212483, 19.5417286327907, 43.61500290461949, 40.426808084760395, 35.55378975187029, 53.77660437992641, 3.182377440588815, 0.073692926737879, 0.10237984026649169, 0.025463602472362772, 0.04832629540136882, 0.059832091576286724, 0.026267834406878268, 0.03471178202224629, 0.09480014948972634, 0.02028636501303741, 0.13019136898219585, 0.05020914186856576, 0.05570183534707342, 0.06108179023223264, 0.03110610121595008, 0.019361131624983888, 0.10610874981752463, 0.06693479259099279, 0.15914756591830934, 0.02614407810116453, 0.15862125344574451, 0.10746290215424129, 0.06619400876973357, 0.09239535353013448, 0.8102824719888824, 16.333396196365356, 62.58983843667166, 53.35018648420061, 48.85859298706055, 25.443203687667847, 70.11389677865165, 3.0591787142413, 0.06805179015334163, 0.12446015008858272, 0.35014920255967547, 0.15300903602370194, 0.15767027304640838, 0.17702036829931395, 1.5112790082182204, 0.16004188864358834, 0.3957085950034005, 35.50406149455479, 88.80315440041679, 81.2682638168335, 82.14657170431954, 72.58874784197126, 68.17812865121024, 71.93216391972133, 82.83536747523716, 76.95544746943882, 71.74609116145542, 60.3160890851702, 70.2697170802525, 77.73970454079765, 79.46407372610909, 73.56305204119, 78.76784338269914, 77.82811341966901, 77.35197421482631, 75.98264408111572, 76.38672351837158, 71.4756464276995, 68.39000007084438, 61.07584680829729, 59.33045237404959, 60.28254318237305, 59.916157722473145, 61.369540214538574, 64.37162058694022, 67.79166984558105, 66.63491984776088, 68.14083072117397, 68.47911766597203, 69.13659790584019, 62.23243004935128, 64.50754124777657, 66.32548182351249, 65.56657872881208, 68.46089948926652, 67.61733259473527, 65.96424497876848, 69.10526153019497, 67.14135319846017, 61.758639335632324, 64.09520040239606, 70.64976964678083, 64.34171554020473, 67.95243726457868, 67.07915292467389, 57.22080905096871, 57.136287689208984, 66.87227725982666, 64.30509853363037, 63.91282408578055, 62.558592387608115, 65.50625446864537, 63.3911463873727, 58.970125743321006, 59.40754263741629, 60.30497891562325, 61.14536353519985, 60.16855798448835, 57.66830083302089, 60.29155499594552, 58.95588193620954, 60.64042404719761, 63.67316681998116, 61.121531214032856, 61.46744728088379, 62.014583178928916, 61.55666215079171, 61.90593419756208, 59.871591976710725, 60.733946800231934, 63.94498034885952, 53.80016919544765, 56.08947556359427, 59.7983649117606, 63.224181175231934, 60.341950280325754, 58.00738334655762, 61.49237046922956, 60.44952923910958, 59.245399475097656, 58.287110873631065, 62.08293260846819, 61.77927548544747, 58.891611099243164, 57.421403544289724, 61.12247616904122, 58.55179555075509, 57.03329801559448, 59.877442359924316, 57.638246400015696, 60.263942854745046, 61.455343518938335, 59.80802985600063, 57.43401452473232, 57.335343156542095, 54.19458021436419, 53.40685599190848, 52.04755558286394, 52.550535678863525, 52.90465062005179, 54.77193035398211, 56.04482296534947, 59.80422919137137, 60.54200281415667, 64.50872244153703, 67.19841875348772, 63.96676989964077, 61.18040330069405, 63.86967577253069, 68.90444469451904, 67.59286103929792, 66.41928250449044, 59.71755736214774, 68.22844750540597, 63.17556462969099, 61.94673401968819, 18.220301117215836, 0.042677240313163826, 0.07900983214910541, 0.4265809884028775, 0.32577774460826603, 0.17512345580118044, 0.09342591930180788, 0.11986611517412321, 0.15931027861578123, 0.05524507271392005, 0.07723467597471816, 23.0215254511152, 52.00354221888951, 35.068892342703684, 38.80388259887695, 60.28623267582485, 4.673073061874934, 0.20037330447563104, 0.08628899298076119, 0.13257848231920175, 0.04054641304537654, 0.08532913734338113, 0.023447856440075805, 0.047073818144521544, 0.061287637400840006, 0.0305880465145622, 0.05454342679253646, 0.1655716776315655, 0.07206186426005193, 0.17620905754821642, 0.10181209644568817, 0.0733812688184636, 0.2336487296436514, 0.17083880571382387, 0.16111881871308598, 0.28114837940250126, 0.1824653132685593, 0.1913691040660654, 0.20436082407832146, 0.19418752140232495, 0.8324017365063939, 18.564139672688075, 76.44718674251011, 52.71315826688494, 58.465193203517366, 53.47047022410801, 82.56921672821045, 5.291878759860992, 0.16375519867454255, 0.2444822740341936, 1.1258261714662825, 0.7797466591000557, 0.6514654883316585, 0.364969900143998, 3.1685950372900282, 0.47057049508605686, 1.2353081767048155, 39.89684118543352, 93.97788783482143, 87.59789902823312, 87.23931639535087, 79.71161024911063, 74.04616028921944, 76.27029255458287, 85.24767780303955, 81.11822441646031, 74.19833973475865, 63.18365928104946, 74.538252558027, 82.62419087546212, 82.9576974596296, 77.65135819571358, 83.65084280286516, 80.41561562674386, 80.59287112099784, 80.09972967420305, 80.93001856122697, 74.48350075313023, 73.02094663892473, 63.89052036830357, 62.415000915527344, 64.02294608524868, 62.792809213910786, 62.91690404074532, 68.74084935869489, 70.29565470559257, 70.35777160099575, 71.40943704332624, 75.3241355078561, 72.97072505950928, 64.4889200755528, 66.68846961430141, 71.36325931549072, 67.99184049878801, 71.58248887743268, 74.31433296203613, 70.04513045719692, 71.68184116908482, 71.82605103084019, 65.37634399959019, 66.02699416024345, 73.16053594861711, 67.99678761618478, 68.4438555581229, 71.27380125863212, 60.261608260018484, 59.30325712476458, 68.25956153869629, 68.0633235658918, 67.16959067753383, 65.29152039119175, 66.8241331917899, 64.82906218937465, 60.35894557407924, 58.739744322640554, 61.67036942073277, 63.67276382446289, 61.23673234667097, 61.609739439828054, 61.52859837668282, 63.82360921587263, 64.13732038225446, 67.8834069115775, 62.813619068690706, 63.56997217450823, 65.60959502628872, 66.19730145590646, 64.30971908569336, 60.32020936693464, 64.04095581599644, 64.57001944950649, 54.02497468675886, 60.138784953526084, 63.330822127205984, 66.05897671835763, 60.01607976640974, 62.902653285435264, 63.89739213671003, 62.379252433776855, 60.70743942260742, 61.5327672958374, 65.29062407357353, 64.2806339263916, 61.750614166259766, 59.98726558685303, 63.75358527047293, 62.21085589272635, 59.515712193080354, 61.17929853711809, 61.71339961460659, 64.35661247798375, 62.87450613294329, 64.8115040915353, 61.857220377240864, 61.93754850115095, 58.486948013305664, 56.1414133480617, 55.94323682785034, 55.8732476234436, 56.40346813201904, 58.79659448351179, 59.47028487069266, 65.67554037911552, 65.0934203011649, 66.78044291904995, 69.78047357286725, 66.06627927507672, 64.4974524634225, 67.16326781681606, 71.20120647975376, 69.66905920846122, 67.41413252694267, 62.23574434007917, 73.02624116625104, 70.66100488390241, 69.73080090114048, 19.606286082948955, 0.1456153384808983, 0.31917288473674227, 1.0398510077169962, 0.5625751752938543, 0.6098420332585062, 1.6515150432075774, 0.41985591926745003, 0.5261515783412116, 0.1425056667732341, 0.30518179120762007, 31.17064721243722, 59.76012897491455, 54.74560710362026, 45.81981570380074, 72.17407935006278, 5.56694187436785, 0.4512115381658077, 0.2484990656375885, 0.14968985984367983, 0.17095467235360826, 0.31393787850226673, 0.1336074671042817, 0.08941722940653563, 0.1576790940016508, 0.08396976028702088, 0.15400093208466256, 0.2543661136712347, 0.16341185995510646], [0.07473709035132613, 0.1740581151098013, 0.06319818166749817, 0.10246470464127404, 0.0801346871469702, 0.07179783271359545, 0.05483661159606917, 0.06471206793295485, 0.05381770644869123, 0.08888065748448883, 0.025485371572098563, 0.354205566325358, 22.372780833925518, 61.948005540030344, 33.6068628174918, 45.55833414622715, 46.076131275721956, 42.395576681409565, 0.2596492687506335, 0.003273512045520225, 0.4306833839842251, 0.2587702673460756, 0.1401570670838867, 0.040793474431016614, 0.393275612699134, 0.617669124688421, 0.14629121364227363, 2.2880665489605496, 50.839656421116416, 84.1696925844465, 77.4723448072161, 77.96602126530239, 66.0154948915754, 64.95432431357247, 75.57370785304478, 79.09435313088554, 78.72058173588344, 73.88743564060756, 60.217799867902485, 65.82816450936454, 70.91929027012416, 77.49326583317348, 77.85923440115792, 74.24799156188965, 70.83059651511056, 73.16863059997559, 72.89239106859479, 75.09614426749093, 72.95275006975446, 66.17208644321987, 60.81193338121687, 56.275002888270784, 55.11432368414742, 58.16099064690726, 59.446091243198936, 60.86399623325893, 63.449545996529714, 63.82836178370884, 67.2584650857108, 64.11912999834333, 64.33576093401227, 61.292672293526785, 61.47308921813965, 60.80434594835554, 63.49673816135952, 62.89776175362723, 60.90688746316092, 63.99598012651716, 64.49853638240269, 58.705246516636436, 62.78744520459856, 65.80275494711739, 59.47195243835449, 65.75584765842983, 60.73552404131208, 54.43043334143502, 56.04178312846592, 62.72035339900425, 63.53217397417341, 60.94116292681013, 63.69430324009487, 64.69346809387207, 66.01714856284005, 62.62511444091797, 61.785376003810335, 60.192390305655344, 64.15725476401192, 60.33108329772949, 59.98425701686314, 58.82644394465855, 60.35717378343855, 59.341500009809224, 57.55824136734009, 57.18856246130807, 59.883376121520996, 58.528032711574006, 63.9031799861363, 57.763074261801584, 59.469826289585654, 61.03579044342041, 59.507138116019114, 59.36388710566929, 60.78504385266985, 54.162969384874614, 53.25469739096505, 53.49388565335955, 61.229353359767366, 56.96458727972848, 58.68959222521101, 58.647861344473704, 60.28107016427176, 55.429817063467844, 56.197818824223106, 56.67319025312151, 59.365742274693076, 57.297294821058, 56.84000607899257, 55.46910217830113, 55.56636306217739, 55.34459045955113, 55.208252906799316, 58.435044969831196, 57.4169636453901, 56.751270634787424, 53.00636529922485, 53.6213573047093, 52.407253401620046, 51.75463342666626, 50.3713686806815, 49.08833169937134, 50.55816057750157, 53.608749798366, 54.385617460523335, 57.75688689095633, 61.57062108176095, 62.12507343292236, 62.34246867043631, 62.31689929962158, 55.092923232487266, 57.86256899152483, 67.91236700330461, 65.63525472368512, 64.55268369402204, 54.54384183883667, 61.996316364833284, 57.054462228502544, 58.09614658355713, 39.4260208266122, 1.1579234834228243, 0.3135216651218278, 0.13167852775326797, 0.16845773133848393, 0.06451046160821404, 0.08542422045554433, 0.15861093971346105, 0.02020543783770076, 0.09530451135443789, 0.19573660327919892, 11.432291507720947, 36.646897724696565, 44.454828194209504, 23.761256728853496, 51.74165071759905, 7.911188517298017, 0.26645372648324284, 0.1908883484346526, 0.06082662035311971, 0.11926109263939516, 0.046949469817004034, 0.07228519049073968, 0.05627839333776917, 0.1079218021727034, 0.03715980066252606, 0.21609283025775636, 0.0666088175826839, 0.09554191718676261, 0.07801070290484599, 0.12693053324307713, 0.04561567013817174, 0.07004403003624507, 0.032154593882816176, 0.059571791972432814, 0.06864115209983927, 0.071098738083882, 0.10490378019000803, 0.08788796753755637, 0.1443785455610071, 0.508998918746199, 28.4794796194349, 67.48139108930314, 45.552160671779085, 37.41448259353638, 38.41686446326119, 51.71783229282924, 0.11144850828817912, 0.053486438867236884, 0.4316016047128609, 0.24237281722681864, 0.15749314826514038, 0.01414367145792182, 0.4652623970593725, 1.7182192695992333, 0.2129067690776927, 2.3707974467958723, 54.353304862976074, 88.57053565979004, 82.88100324358258, 81.92654309953961, 68.8550499507359, 70.18528257097516, 78.47879832131522, 83.24245548248291, 82.16052368709019, 76.38415963309151, 64.0080144064767, 69.054046358381, 75.60906028747559, 78.56963212149483, 79.29285621643066, 75.85057272229875, 74.39695399148124, 75.29840632847377, 74.93359116145542, 76.34834166935512, 73.55689593723842, 68.86755670819963, 66.11499309539795, 59.39894076756069, 58.415638651166645, 61.72364125932966, 64.0567490713937, 65.09629685538155, 64.92842142922538, 65.69343199048723, 69.2111451285226, 65.89202540261405, 66.01328536442348, 62.13105583190918, 64.31719534737724, 64.25030503954206, 67.28067152840751, 63.380515643528526, 64.60370431627545, 66.95865031651088, 65.28469726017543, 62.04668385641915, 66.21201079232353, 68.82658318110875, 62.20206642150879, 68.18258244650704, 61.4847274507795, 57.62131364004952, 60.93075452532087, 66.52513136182512, 64.75487627301897, 62.416543415614534, 69.06624044690813, 68.65232930864606, 67.14872523716518, 62.28240149361746, 65.45062024252755, 64.2711774281093, 64.50843061719621, 62.45818396977016, 63.79464217594692, 61.98482404436384, 62.044939858572825, 61.81434999193464, 60.96373067583357, 59.71409021105085, 59.65405082702637, 58.659402302333284, 62.49323068346296, 60.24644729069301, 61.17048127310616, 61.89144025530134, 59.803728921072825, 61.68937969207764, 61.77332782745361, 57.41779048102242, 54.312289646693635, 54.95834704807827, 62.997642108372276, 60.217876298086985, 59.959771565028596, 60.208975655691965, 59.887816020420615, 58.89239624568394, 57.33528062275478, 57.2024519102914, 62.591582434517996, 59.1529814856393, 58.897398948669434, 57.90526567186628, 59.760448592049734, 59.96612916673933, 57.41563653945923, 60.204223087855745, 61.66226087297712, 59.61682932717459, 57.095651149749756, 55.81164836883545, 54.83333158493042, 53.99338470186506, 52.221246651240754, 53.123640469142366, 54.07022830418178, 54.89554575511387, 56.27844224657331, 59.27401910509382, 61.69233267647879, 64.16937937055314, 65.24366119929722, 63.99343013763428, 60.230146816798616, 60.63181522914341, 69.27149023328508, 68.00384698595319, 67.91889136178153, 59.57867676871163, 64.7877482005528, 64.76241506849016, 67.05721051352364, 45.591744559151785, 1.5818850823811121, 0.03186350914516619, 0.263772508927754, 0.591246808213847, 0.10302467923611403, 0.05852781156344073, 0.2185343892446586, 0.03492829576134682, 0.23729742957012995, 0.21461103191333158, 13.458088312830244, 45.40843023572649, 40.689439569200786, 29.74697869164603, 62.02068369729178, 10.70147476877485, 0.2362322924392564, 0.21442450263670512, 0.049950318078377416, 0.10433637563671384, 0.040473277148391516, 0.07829781821263687, 0.07044414178069149, 0.08767781845693078, 0.02473926803629313, 0.14959732123783656, 0.04581626883840986, 0.08117412815668754, 0.1894945560821465, 0.19858651821102413, 0.2742932215332985, 0.20096189289220742, 0.1688639024006469, 0.17648945535932267, 0.1509473616523402, 0.1855502455894436, 0.1649215460887977, 0.09510014339217118, 0.1731330276067768, 0.4813554563692638, 32.60016959054129, 80.56662082672119, 44.457075936453684, 62.99124281747, 61.92252649579729, 62.25410148075649, 1.122682111603873, 0.14198844666991914, 0.7084230748670441, 0.7730445244482586, 0.6056675229753766, 0.09121491972889219, 1.6462796841348921, 3.3834155329636166, 0.6202314900500434, 3.135596739394324, 61.23259816850935, 94.23380388532365, 89.67631367274693, 88.26798330034528, 73.91625676836286, 74.34756619589669, 82.78629234858921, 87.4261395590646, 86.76203768593925, 78.91131673540387, 67.31117412022182, 71.88693114689418, 80.36162117549351, 81.30262960706438, 83.71212591443742, 79.93582861764091, 77.41145079476493, 80.71759128570557, 78.2112648827689, 79.66670404161725, 77.90341799599784, 72.24393653869629, 68.43300942012242, 64.09735434395927, 59.60467692783901, 65.63100242614746, 66.98232977730888, 67.56268501281738, 68.36588287353516, 68.69441454751151, 73.15766634259904, 72.42142827170235, 70.37800475529262, 66.6689521244594, 66.51796082087925, 69.38096605028424, 70.79356261662075, 66.856032371521, 66.31223160879952, 70.82024369921002, 69.62245764051164, 65.9236536026001, 68.17513397761753, 72.70369189126151, 65.93595886230469, 69.28367737361363, 67.3747501373291, 60.629654339381624, 61.35385118212019, 67.08112621307373, 67.9618034362793, 64.75444548470634, 71.44135011945451, 70.51830972943986, 71.22975662776402, 66.8606390271868, 67.55514621734619, 66.79513835906982, 70.70396559579032, 65.80385971069336, 66.17649854932512, 64.80955859592983, 65.81865242549351, 65.57326289585659, 61.93889645167759, 60.772099358694895, 64.16860812050956, 62.60613891056606, 65.60655171530587, 60.98839678083147, 65.1519797188895, 65.32200908660889, 61.35063416617257, 64.95910467420305, 64.21493176051548, 59.29069478171212, 56.3486260005406, 56.64766604559762, 66.06825951167515, 61.330970764160156, 62.05524403708321, 63.92227363586426, 63.7150297164917, 60.15161827632359, 60.64145238058907, 62.592979022434776, 63.96695055280413, 60.65737765175955, 61.14234801701137, 60.92390360151018, 61.67262758527483, 60.527223995753694, 61.00248077937535, 63.42425455365862, 63.62205587114607, 62.38927868434361, 60.784842354910715, 59.60951287405831, 59.5734030859811, 57.8946418762207, 57.83324759347098, 56.791340896061485, 57.621584619794575, 59.840971265520366, 58.994625091552734, 63.03826127733503, 66.7290540422712, 67.77100590297154, 67.10653577532086, 65.84696633475167, 62.48451764242989, 62.23350007193429, 71.88335282461983, 71.51688398633684, 69.99616650172642, 60.64353684016636, 69.75177751268659, 70.2706411906651, 73.67802388327462, 49.685487679072786, 2.3756855045046126, 0.396346635052136, 0.9461772399289268, 0.6208834807787622, 0.35707690939307213, 0.20561223264251435, 0.4156304102923189, 0.10454715575490679, 0.5864698131169591, 0.3231342264584133, 21.458177294049943, 53.099690028599326, 58.11935009275164, 35.448191029684885, 69.24184921809605, 12.425502623830523, 0.4445381462574005, 0.5205451420375279, 0.1818231748683112, 0.20392067198242458, 0.12167973071336746, 0.19017983573888028, 0.148118223462786, 0.23877992002027376, 0.10545088976089444, 0.2704603943441595, 0.1593000598784004, 0.12052808036761624], [0.03381522013140576, 0.10117928111659628, 0.031135597133210728, 0.08421900655542101, 0.060520886044417105, 0.031684959440359046, 0.058544394959296496, 0.12348456600947039, 0.06733552858765636, 0.04462970447327409, 0.04549825304586973, 0.15543163674218313, 39.93448999949864, 46.03763478142874, 30.078352178846085, 33.14838593346732, 43.00469051088606, 27.932010207857402, 0.37778658526284353, 0.07667548169514962, 0.5249295639140266, 0.08734921073274952, 0.36464385049683706, 1.4956621719258172, 0.1909617930650711, 0.22296681068837643, 0.04944299440830946, 4.07873283965247, 59.722837993076865, 83.18509115491594, 74.75986535208565, 72.90971292768205, 62.5484619140625, 66.96958678109306, 78.21219594138009, 78.68594496590751, 74.85882159641811, 77.10147081102643, 61.48005826132638, 63.85536248343331, 69.05153111049107, 77.39189161573137, 73.48582281385148, 71.24318054744175, 70.23070989336286, 70.82967240469796, 71.69324316297258, 70.43370151519775, 70.34101254599435, 69.50261511121477, 64.93190247671944, 59.57897554125105, 56.901980536324636, 58.881431988307405, 59.17254761287144, 57.944696698869976, 63.26516859872, 63.812054361615864, 66.71377495356968, 64.40946742466518, 65.72146797180176, 58.46192060198103, 59.92762919834682, 61.92725127083914, 65.63624136788505, 61.320208004542756, 64.81855651310512, 63.34471157618931, 58.5883708681379, 62.28048379080636, 69.07934474945068, 61.22314861842564, 63.96999386378697, 60.146615573338096, 51.562133584703716, 58.84958839416504, 63.970994404384065, 61.205729484558105, 60.991252490452354, 66.17273957388741, 60.904163769313264, 56.4400052343096, 48.38667828696114, 46.2385002544948, 55.14759513310024, 59.36258084433419, 57.3451818057469, 57.69370692116873, 57.0553411756243, 57.0102994782584, 59.27520029885428, 53.66910532542637, 60.30147007533482, 56.78768266950335, 43.97763981137957, 46.39206239155361, 46.724801199776785, 54.68885769162859, 58.71247264317104, 58.953130449567524, 60.01196643284389, 56.8409023966108, 56.645470414842876, 60.51473808288574, 55.80752113887242, 52.81415033340454, 54.037272998264854, 59.41863891056606, 57.82778630937849, 57.77861738204956, 58.50388077327183, 58.86796637943813, 56.070777961185996, 57.98238720212664, 56.634280341012136, 57.921500137874055, 55.4758870942252, 54.91734572819301, 56.54842145102364, 55.366515500204905, 54.09820869990757, 56.20779991149902, 55.98495033809117, 56.393153531210764, 54.91528558731079, 53.499861104147776, 51.20305415562221, 49.05926043646676, 46.7311692237854, 50.45106104442051, 51.329434939793174, 51.52876138687134, 54.38290418897356, 58.89302158355713, 60.966190338134766, 60.581447737557546, 62.848776953560964, 58.918778555733816, 55.314695835113525, 62.54383441380092, 67.12551825387138, 64.7381033216204, 65.54889556339809, 59.53263800484793, 56.064225809914724, 60.942830494471956, 59.03580011640276, 57.98623650414603, 8.120696680886404, 0.07832232689751045, 0.4621401588831629, 0.018358412930475812, 0.10859087841319186, 0.04383294829832656, 0.2743146632398878, 0.11289798800966569, 0.2757969637002264, 0.24092968180775642, 5.223316541739872, 29.098857675279888, 53.884645393916536, 24.901079177856445, 48.49236733572823, 12.850032346589224, 0.5809056631156376, 0.22700854523905686, 0.08546246268919536, 0.1786059553601912, 0.03728029491113765, 0.0731434083676764, 0.09675158227660827, 0.07837479801050254, 0.07028390573603766, 0.09605019419853177, 0.014116535994357296, 0.025774673458987048, 0.043714028250958235, 0.0993503781833819, 0.04047283270795431, 0.04260847078902381, 0.00991674604093922, 0.03286623462502446, 0.07266991984631334, 0.037925547787121365, 0.028118682858933295, 0.08240549958177976, 0.08963784828249897, 0.1600301499877657, 48.24458762577602, 51.1957550730024, 43.74479178019932, 30.057271344321116, 43.95590237208775, 35.4866875239781, 0.4315654252256666, 0.0989072337480528, 0.8093909855399812, 0.19923857679324491, 0.6781284404652459, 2.245531197105135, 0.8613806643656322, 0.6527139927659715, 0.16093883051403932, 5.156730651855469, 61.70744500841413, 86.08219119480678, 79.56306471143449, 76.95878260476249, 67.06744521004813, 72.5437513078962, 81.748551096235, 83.6314503805978, 78.08745493207658, 78.55584689549038, 65.31222602299282, 66.84907027653286, 74.64836760929653, 78.28396388462612, 76.32282093593052, 72.83606897081647, 72.15496485573905, 74.08745343344552, 73.74609538487026, 73.11109256744385, 72.15172699519566, 72.36926119668144, 67.34091241019112, 62.403126444135395, 59.48947579520089, 61.37731524876186, 60.92754445757185, 61.2699864251273, 66.35262148720878, 64.44757829393659, 69.57385499136788, 68.47021007537842, 67.41324315752301, 60.98009368351528, 63.94821126120431, 67.01157474517822, 67.97174630846295, 67.41850294385637, 67.96659074510846, 62.80159868512835, 61.89456694466727, 67.13084752219063, 69.69368362426758, 63.94896166665213, 65.70834282466343, 60.40210778372628, 56.79666321618216, 63.89582879202706, 65.58243451799665, 64.7865878513881, 66.4721930367606, 68.48270988464355, 61.176512309483115, 57.69917515345982, 50.07132462092808, 49.95960453578404, 56.34434938430786, 62.383574213300435, 60.27305889129639, 59.84065859658377, 59.74596159798758, 59.2839480808803, 60.50025803702218, 57.74677726200649, 60.774482590811594, 56.97669104167393, 45.70983614240374, 49.3787386076791, 48.45478800364903, 54.52695076806204, 59.887079511369976, 61.4977970123291, 61.77671160016741, 60.7875452041626, 57.88184329441616, 61.00796985626221, 59.019193921770366, 54.204627309526714, 57.259281226566856, 59.45002392360142, 60.72633852277483, 60.397070339747835, 59.471750940595356, 58.40361826760428, 58.888352394104004, 59.76666028159005, 59.271886008126394, 58.05511747087751, 57.65592956542969, 56.933219637189595, 57.56432451520647, 60.0404748916626, 58.34517002105713, 58.30502332959856, 57.52354206357683, 60.10846301487514, 58.24105473927089, 56.91329567773001, 54.74233102798462, 52.01900890895298, 49.41415010179792, 51.806157793317524, 52.58407810756138, 55.12752526147025, 57.08414145878383, 59.48720373426165, 60.981392996651785, 61.43551336015974, 64.46942343030656, 62.03513595036098, 58.42018972124372, 64.26760605403355, 68.02710260663713, 67.22632271902901, 68.65057141440255, 62.0644017628261, 61.01019327981131, 67.51491614750454, 66.83060196467808, 62.24784810202462, 9.287393024989537, 0.09002292369093214, 0.4317048777426992, 0.025325081244643246, 0.024596860499254296, 0.1813348060739892, 0.07260188992534365, 0.012714575776564223, 0.1818481720983982, 0.10372457453714949, 5.601055358137403, 37.36262123925345, 53.286217893872944, 26.29176981108529, 60.08656924111502, 16.828507457460674, 0.4048144263880593, 0.17798121459782124, 0.0693078873945134, 0.09441478909658534, 0.02698763453268579, 0.07584449342851128, 0.01721216202713549, 0.07128815791968789, 0.018608889043597237, 0.04344833090103098, 0.021507258161104152, 0.011403228821499007, 0.1442607654524701, 0.21132746525108814, 0.10286788336400475, 0.18457593715616635, 0.12737677858344146, 0.13413472952587263, 0.1694574034107583, 0.16775520332157612, 0.1424706815076726, 0.13722990772553853, 0.14308391431612627, 0.21678865434867994, 55.85068334851946, 62.62341908046177, 44.42663587842669, 48.20268998827253, 59.0300053187779, 43.508907386234824, 0.5255000218749046, 0.17792619897850923, 1.2950917801686694, 0.5518402627536229, 0.7854688806193215, 3.334449189049857, 1.5714762466294425, 1.2057580309254783, 0.3320276220994336, 6.878028733389718, 68.53835800715855, 90.26265130724225, 85.2674662726266, 82.28124168940953, 73.90882219587053, 76.70666027069092, 85.54904896872384, 87.0784933907645, 81.55726718902588, 83.38248947688511, 68.32010814121791, 68.54667500087193, 77.35798440660749, 82.20206001826695, 81.31717913491386, 78.50676482064384, 76.4724781853812, 79.18665994916643, 77.43636703491211, 76.17493547712053, 73.91360255650112, 75.5907517841884, 69.31686197008405, 66.11400645119804, 62.62852600642613, 65.59917272840227, 62.52349703652518, 64.34163216182164, 69.89643900735038, 68.45729337419782, 72.71407944815499, 71.18729618617466, 70.08861923217773, 65.68230097634452, 68.64321327209473, 70.11866324288505, 71.43515232631138, 67.373902457101, 72.229095186506, 69.28307982853481, 65.19350215366909, 68.5332441329956, 75.09992408752441, 65.83778776441301, 68.16100134168352, 63.10754176548549, 57.50071375710623, 64.41696453094482, 70.48018496377128, 67.95161042894635, 68.06238555908203, 69.61354310171944, 64.9418592453003, 63.90314524514334, 52.54289960861206, 52.87404727935791, 60.75709819793701, 66.19723197392055, 62.58265399932861, 64.06409331730434, 62.91325623648507, 62.874999455043245, 62.65971646990095, 59.6830804007394, 64.95842375074113, 62.36126354762486, 48.38270044326782, 52.93472589765276, 51.00533969061715, 58.5993629183088, 63.740133558000835, 63.70179339817592, 63.756538254874094, 60.87794821602957, 60.18630368368966, 65.55781705038888, 59.719982283455984, 55.77088328770229, 60.59179360525948, 63.43124444144112, 62.6582920891898, 62.12165491921561, 62.320324761526926, 62.94414792742048, 60.45490019662039, 64.45466545649937, 61.458157539367676, 64.73327432359967, 59.09029483795166, 60.701234681265696, 59.96349579947335, 61.377266611371724, 62.829697200230186, 60.15737138475691, 60.3914075578962, 61.98847879682268, 61.87856524331229, 60.72583825247628, 59.87816497257778, 56.12403242928641, 53.02853352682931, 57.01327330725533, 57.173675945826936, 57.984655788966585, 60.854504993983674, 62.54391779218401, 64.64901351928711, 64.09325490679059, 67.66968032291958, 64.32271916525704, 61.12700639452253, 67.42948804582868, 72.10452788216728, 69.17884990147182, 71.76278073447091, 66.34227561950684, 64.84384100777763, 71.90275914328438, 74.23679801395961, 65.80538136618478, 11.59725911276681, 0.19418315163680486, 1.1914529928139277, 0.09629028702953032, 0.3130370554115091, 0.21971706221146242, 0.7785409295133182, 0.27201809361577034, 0.6750143989920616, 0.3345948186303888, 9.775971242359706, 44.44900907788958, 67.70451164245605, 34.77624464035034, 65.01337705339704, 20.621621131896973, 0.8064523317984172, 0.46805144740002497, 0.22201036129678997, 0.283302402389901, 0.20729406311043672, 0.1753202580979892, 0.14782247718955788, 0.163638707782541, 0.15881279031080858, 0.10631867498159409, 0.0955531130145703, 0.10912073962390423], [0.11516157404652663, 0.10851606992738587, 0.1398244627884456, 0.04776587636609163, 0.08748081938496657, 0.09667855833790132, 0.06586533997740064, 0.02241152142440634, 0.08075902078832899, 0.08866727179182426, 0.026010155644533888, 0.3092943648142474, 45.622573716299875, 43.22557374409267, 27.003673553466797, 24.177144629614695, 50.83276728221348, 11.023119040897914, 0.17778055822210653, 0.0741344155477626, 0.48658804701907293, 0.10915994537728173, 0.07958062937749283, 1.1484749104295457, 0.473715532038893, 0.20177536138466426, 0.20134679866688593, 10.263903277260916, 75.61963544573102, 78.36664744785854, 77.93089812142509, 69.86442865644182, 62.267490659441265, 69.61658641270229, 78.540616444179, 78.06320571899414, 76.27888747623989, 74.52708680289132, 71.11573668888637, 68.48052815028599, 74.22377708980015, 72.60543741498674, 73.02423313685826, 70.06833049229213, 65.92463329860142, 66.82493223462785, 68.76746790749687, 68.41530541011265, 72.4569057737078, 70.09639426640102, 67.33656978607178, 61.70379025595528, 56.16770880562918, 56.44696732929775, 59.09485980442592, 59.44091483524868, 62.08733081817627, 62.880933216639924, 64.75349358149937, 66.64821175166539, 63.17869826725551, 59.01098115103585, 56.343102182660786, 62.33297743116106, 63.14377662113735, 62.85182721274239, 61.30692999703543, 59.33337756565639, 64.23913928440639, 63.529783793858115, 61.811445644923616, 63.859663418361116, 59.6177464893886, 53.676018783024375, 63.448267527988975, 66.12519999912807, 57.16168335505894, 61.89774227142334, 63.863901819501606, 53.84046179907662, 48.05381441116333, 50.31528629575457, 54.5812474659511, 49.70333065305437, 46.056193419865195, 54.76483276912144, 59.19437885284424, 57.25630044937134, 58.23744167600359, 56.87853731427874, 58.099005767277305, 62.04950482504708, 50.58218050003052, 43.21818086079189, 49.881927149636404, 51.78589684622628, 51.700176920209614, 47.830735547201975, 48.46264294215611, 59.96370424543108, 58.08486270904541, 59.66176332746233, 55.2331656728472, 53.79087597983224, 59.28658839634487, 58.071977274758474, 56.42169673102242, 53.288559436798096, 56.54819910866873, 58.31564712524414, 56.196655000959126, 57.304079736982075, 55.83544247491019, 55.57013593401228, 54.84385115759713, 56.68463741030012, 55.40322630746024, 51.67951992579869, 53.4127584866115, 52.454792976379395, 56.06000130517142, 58.37139252253941, 56.07270956039429, 55.71429368427822, 56.166478974478586, 54.72671842575073, 50.97982937949044, 47.6638537134443, 48.87844051633562, 47.31900419507708, 50.11301381247384, 55.75956119809832, 54.41211788994925, 58.71125670841762, 60.48584052494594, 60.62161527361189, 62.47484574999128, 58.74038355691092, 58.144909041268484, 59.802596364702495, 64.81422778538295, 65.42170183999198, 65.98034395490373, 62.102957316807334, 52.54642929349627, 60.82851873125349, 58.41764668055943, 67.31792776925224, 22.21699353626796, 0.05585326061451009, 0.10756249073892832, 0.1396961382457188, 0.07597568817436695, 0.09028512997818844, 0.39217559886830194, 0.06994558817573956, 0.1454728596976825, 0.05297992265384112, 1.8381607021604265, 16.225311756134033, 50.262410504477366, 29.97315297807966, 36.76771994999477, 27.798436301095144, 0.2059214139091117, 0.17266021083508218, 0.07191557211003133, 0.15241526359958307, 0.04561847248779876, 0.11844207373048578, 0.04489790561742016, 0.04252496687695384, 0.031091940190110887, 0.13408018888107368, 0.017989342466795018, 0.08950635498123509, 0.011119783539990229, 0.07131871235157762, 0.0815189867945654, 0.012211337735477303, 0.017393702375037328, 0.07511544147772448, 0.059669914921479564, 0.039517747171755345, 0.054952315387449095, 0.05390393467886107, 0.0814113507845572, 0.685488862650735, 55.0849814414978, 51.85485076904297, 37.13444239752633, 24.355303389685496, 56.360823563167024, 15.659467833382742, 0.13123791425355844, 0.09364177486194031, 0.5765677616000175, 0.06877696088382176, 0.10290100265826498, 1.5915473124810626, 0.357196358697755, 0.2642931081354618, 0.3259981599237238, 12.001236064093453, 79.49928719656808, 83.58942767551967, 83.25064046042306, 74.41546399252755, 67.78573608398438, 72.03473322732108, 81.1464410509382, 79.37572738102504, 78.72548021589006, 77.40505845206124, 74.59114919389997, 72.40755271911621, 78.22849641527448, 75.42283466884068, 75.78969260624477, 71.56428459712437, 66.8207563672747, 67.74215003422329, 70.12804331098283, 71.09863717215401, 77.33086558750698, 72.70555400848389, 69.38965129852295, 66.08416393824986, 57.06530141830444, 59.79925428118025, 61.193125452314106, 63.323860032217844, 65.19974858420235, 66.09762954711914, 66.91939299447196, 69.95997333526611, 66.8079855782645, 59.89615385872977, 60.40535259246826, 66.24348613194057, 66.7994601385934, 64.75576564243862, 63.075635637555806, 64.28255857740129, 67.1203418459211, 64.34364713941301, 64.82129410334996, 65.96390451703752, 60.94551249912807, 56.521747316632954, 66.35358033861432, 68.32591683523995, 59.85736206599644, 65.47561291285923, 63.60494245801653, 54.562667982918875, 50.59240477425711, 54.61052370071411, 58.06277091162545, 53.16209527424404, 48.94035938807896, 54.712811606270925, 64.54328278132847, 61.149560247148784, 63.940700258527485, 60.85683958871024, 61.40876279558454, 62.95441736493792, 52.45282316207886, 44.56537403379168, 54.25998708180019, 56.243715150015696, 55.35694783074515, 50.79393032618931, 49.60165071487427, 59.40737588065011, 60.62801456451416, 60.83678708757673, 57.243887492588584, 57.722444670540945, 60.56301416669573, 58.98955290658133, 59.4056179864066, 54.18885489872524, 57.85476963860648, 59.8269567489624, 57.784974983760286, 60.5556560243879, 57.99845838546753, 56.9840978213719, 56.0746168409075, 58.37834766932896, 57.92997694015503, 54.20108372824532, 56.3241822378976, 57.36791283743722, 60.08525603158133, 58.98762130737305, 59.14439351218087, 58.77568735395159, 58.01945236751011, 55.34637614658901, 53.99852636882237, 50.47560208184378, 51.03616189956665, 50.175860268729075, 54.259622301374165, 57.730007784707205, 56.397947788238525, 61.55837835584368, 63.33662387302944, 63.242156164986746, 65.7112958090646, 61.20733451843262, 60.1423841203962, 62.223140307835166, 67.6044089453561, 68.91817433493478, 67.05690479278564, 64.48779446738106, 57.50445188794817, 64.94914790562221, 66.4223119190761, 70.58803490230015, 26.258342027664185, 0.0766779040651662, 0.11159370121146951, 0.2967074045113155, 0.17130315436848573, 0.15168711410037108, 0.06736982853284904, 0.07152760614241872, 0.15395635233393737, 0.018110287941194007, 1.754960258092199, 18.555739300591604, 55.90259681429182, 28.469713926315308, 45.66589226041521, 35.22906221662249, 0.08526239663894687, 0.06656466530902044, 0.061325859278440475, 0.07643802836537361, 0.05033263524195977, 0.0967219981497952, 0.03181999808709536, 0.04888525897903102, 0.03931543856327023, 0.03786333630393658, 0.03620048785316093, 0.04270776081830263, 0.19441784332905496, 0.1518758282597576, 0.17937955313495227, 0.09521275306386606, 0.09227915440819093, 0.1446587805237089, 0.16065159306994506, 0.08127421885728836, 0.17239213521991456, 0.17996747658721038, 0.16331316025129386, 0.7455254782523427, 63.600738797869, 59.65893541063581, 37.35591275351388, 36.25280979701451, 70.68547643933977, 20.56125691958836, 0.1784402978207384, 0.3103591219655105, 1.3221691272088458, 0.4924845706139292, 0.16413824526326998, 2.7956376671791077, 1.2215427096400941, 0.6361366223011697, 0.4646589351551873, 13.380599396569387, 85.38699613298688, 88.51741668156215, 89.74414198739188, 78.68178299495152, 72.17886665889195, 76.6615525654384, 86.188387462071, 81.18961020878383, 83.1085706438337, 79.05378259931291, 76.66421372549874, 75.56099264962333, 81.8038170678275, 78.85939979553223, 78.53518990107945, 76.64096505301339, 71.23372404915946, 72.93961797441754, 74.53641823359898, 73.51444244384766, 78.80281366620744, 75.51378658839634, 73.98091670445034, 68.45417363303048, 60.16102613721575, 64.72024645124162, 64.48224285670689, 66.96149907793317, 69.02369662693569, 69.59379632132394, 70.75528499058315, 71.64643314906529, 68.72386796133858, 64.5003776550293, 64.50528308323452, 69.76861994607108, 71.32899774823869, 68.65229456765312, 66.60973957606724, 67.1071194240025, 70.36298274993896, 68.36555630820138, 66.10399409702846, 69.04730660574776, 65.81985446384975, 58.771164076668875, 69.32287216186523, 71.34855692727226, 63.06960460117885, 66.1214827128819, 69.6267238344465, 59.798747062683105, 54.59590816497803, 54.04788637161255, 59.73405933380127, 54.15096984590803, 51.165144784109934, 59.22336673736572, 65.02239581516811, 62.18715558733259, 64.72865377153668, 62.00011008126395, 63.87181581769671, 67.12859630584717, 55.908662591661724, 47.34852361679077, 54.10232898167202, 57.15669454847063, 55.68914120537894, 53.35864244188581, 55.37433917181832, 65.94876439230782, 64.030686378479, 63.89150006430489, 57.35633366448538, 59.25549520765032, 62.48093237195696, 61.87061650412423, 61.224559102739605, 57.34586272920881, 61.52103178841727, 61.95293181283133, 59.22228281838553, 63.290932519095286, 60.55736528124128, 59.87289128984724, 59.09058666229248, 61.81337724413191, 59.28856863294329, 57.29600245612008, 55.637988567352295, 60.319313049316406, 62.036150387355256, 64.36076055254254, 61.96602916717529, 61.48391451154436, 63.14960615975516, 61.52312319619315, 58.67166587284633, 52.713745389665874, 54.95482778549194, 52.307043007441926, 55.66032355172293, 62.786187580653596, 58.425428662981304, 64.4197438103812, 66.99046611785889, 65.81719330378941, 66.92388847896031, 64.93381323133195, 63.88255773271833, 65.7202728816441, 69.44352068219865, 70.68050847734723, 71.18665000370571, 68.47209303719657, 60.801504135131836, 69.8136442729405, 73.58674539838518, 76.08358056204659, 28.56696265084403, 0.3181592619844845, 0.5907971294862884, 0.9484573347227914, 0.3600499512893813, 0.2964345248682158, 0.8086137643882206, 0.21588941902986594, 0.4246345157069819, 0.13544219865330628, 4.3496153099196295, 25.34314615385873, 66.94175229753766, 39.95417077200753, 52.043278966631206, 40.13786724635533, 0.3174891136586666, 0.24780728561537607, 0.27815321726458414, 0.20462225005030632, 0.13125061642910751, 0.28275620884128977, 0.11606858537665435, 0.1464523249971015, 0.09688566079629318, 0.2625507116317749, 0.08936441224068403, 0.15782668893890722], [0.07405018221054759, 0.07520761367465768, 0.11986007621245724, 0.011973744457853692, 0.07801513373851776, 0.042068438338381905, 0.07817509836916413, 0.053312893358192275, 0.07798540033400059, 0.05978322348424366, 0.32992755621671677, 3.4162477254867554, 53.979804447719026, 34.53740726198469, 36.36898715155465, 40.18509415217808, 41.875983442579, 6.058669362749372, 0.14375664107501507, 0.2299578519804137, 0.40520634821483065, 0.07336326049906866, 0.07105046710265533, 0.11633386542754513, 0.22710823560399668, 0.13134749765907014, 0.15762882812746934, 24.928573199680873, 87.01798847743443, 73.63604286738804, 77.19239493778774, 65.81187793186733, 63.02513613019671, 69.13602120535714, 77.00193786621094, 77.56239346095494, 83.0177993774414, 76.8473960331508, 74.93357726505825, 69.62562601906913, 69.48754446847099, 71.71333735329765, 68.89853177751813, 63.60978535243443, 56.68804897580828, 61.658182280404226, 65.03418690817696, 68.67024871281215, 71.5197674887521, 71.70310265677315, 68.38565744672502, 63.34101513453892, 55.38810355322701, 54.94971738542829, 56.699450969696045, 58.471008845738, 61.257764543805806, 63.94317381722586, 63.78117656707764, 66.77320289611816, 57.08694853101458, 57.215274810791016, 60.65644659314837, 61.32073606763567, 63.48541259765625, 60.542926924569265, 62.49785123552595, 62.8286897114345, 57.08255379540579, 62.5539162499564, 64.7631585257394, 57.347794328417095, 54.38107681274414, 63.022836276463096, 62.17887333461216, 61.91730145045689, 63.82027408054897, 61.13931860242571, 49.52578680855887, 51.824980463300435, 61.85530267442976, 65.99244771684918, 60.536631856645855, 54.67841454914638, 46.42191880089896, 45.63897146497454, 51.8183970451355, 56.37718309674944, 59.96532317570278, 60.0241049357823, 56.4613744190761, 48.091310364859446, 42.90799937929426, 47.48274196897234, 56.67609807423183, 60.70044258662632, 60.52167933327811, 57.62178611755371, 52.28759152548653, 47.37275545937674, 49.544383662087576, 59.29248741694859, 58.45652879987444, 60.20146465301514, 54.848641940525596, 56.80419853755406, 58.713994298662456, 57.213746207101, 54.56714262281145, 55.98652063097273, 57.141012464250835, 59.09652737208775, 56.838258607046946, 59.25441128867013, 55.69680159432547, 51.92724405016218, 51.0484984261649, 57.43403884342739, 54.096711363111226, 48.31074142456055, 57.15811892918178, 54.92438077926636, 58.19658626828875, 53.308702264513286, 55.535797936575754, 53.11075850895473, 50.61669567653111, 48.179743562425884, 47.22126735959734, 48.09052521841866, 51.347875458853586, 51.45086513246809, 58.18137666157314, 59.50319848741804, 57.61983714784895, 60.494247845241, 59.98228372846331, 57.75602878843035, 58.42085674830845, 62.85416875566755, 63.61615685054234, 66.45778247288295, 64.37577560969761, 63.22967720031738, 52.871299266815186, 58.17765242712838, 57.86338540485927, 68.86085169655937, 42.349492754255024, 1.0359659876142229, 0.07222535727279526, 0.10025396291166544, 0.028189274249598384, 0.12924447336367198, 0.0940315593034029, 0.07367049437016249, 0.08602441860628979, 0.1968436874449253, 0.7448248501334871, 9.3935250214168, 43.35443850925991, 32.19577748434884, 36.7222717830113, 40.85827037266323, 0.06753749453595706, 0.024733302017141665, 0.06324768079710857, 0.11521584327731814, 0.0038877071014472415, 0.02394209286597158, 0.014114782829502863, 0.025418744522279928, 0.07055190671235323, 0.09335533808916807, 0.04872422904840537, 0.049361105409583876, 0.12117442568497998, 0.07525260054639407, 0.11486638417201382, 0.03921005868219903, 0.09120511489787272, 0.04639008215495518, 0.052535326153572114, 0.07650367662842784, 0.17210462636181287, 0.16102762360657963, 0.3230159713753632, 5.44932450566973, 64.17290210723877, 44.33471468516758, 42.2792638369969, 29.91462482724871, 55.35062844412667, 7.773368392671857, 0.15463038188006195, 0.08481703339410679, 0.1412049965666873, 0.06854052535657372, 0.06009917653032711, 0.47448357939720154, 0.16932749109608786, 0.14470061899295875, 0.1828803595687662, 26.911474432264054, 91.66215051923479, 76.62149620056152, 84.26361833299909, 70.70184639522007, 68.8236163003104, 74.13276958465576, 80.61722455705915, 79.70516232081822, 86.47891943795341, 80.24168831961495, 78.17827483585903, 73.98863615308488, 73.15206609453473, 74.0147613797869, 71.81171689714704, 65.07258265359062, 59.34195859091622, 64.65949835096086, 69.37551866258893, 72.33405467442104, 73.36404173714774, 74.266161101205, 71.62851374489921, 67.21952738080705, 58.631018911089214, 58.77656977517264, 58.02229765483311, 60.2854197365897, 63.55491542816162, 66.12085737500871, 68.10746547154018, 67.77177715301514, 60.12702860151018, 61.45878982543945, 63.576579911368235, 64.23296233585903, 65.13629068647111, 64.36927209581647, 68.47786699022565, 62.80762277330671, 60.387509618486675, 66.24174908229283, 66.69886411939348, 60.73580196925572, 60.2230110168457, 64.50781917572021, 63.178510665893555, 64.45696531023297, 67.51712567465646, 61.41981043134417, 50.596952370234895, 58.035301208496094, 65.65826020921979, 67.52603326525006, 61.43671539851597, 56.17643921715872, 47.98476321356637, 46.97764267240252, 51.9317638533456, 57.16836404800415, 60.25632068089077, 60.05982562473842, 56.930329186575754, 48.868306568690706, 46.9669702393668, 51.90595824377877, 57.772044386182515, 62.36521707262312, 64.33942263466972, 61.60568864004952, 57.86041852406093, 50.860733781542095, 50.32739700589861, 59.42692116328648, 61.26556042262486, 62.61171136583601, 57.69720533915928, 56.26206186839512, 61.15449346814837, 60.10013907296317, 56.752875668661936, 59.47785145895821, 58.112728459494456, 59.02749007088797, 58.41895294189453, 60.50658784593855, 58.086273193359375, 53.388846261160715, 53.075996671404155, 58.73367159707205, 56.51868316105434, 52.58753136226109, 58.09762307575771, 57.86091184616089, 60.48026806967599, 57.37320736476353, 57.18140581675938, 53.780603068215505, 52.06298753193447, 50.3863559450422, 50.22796828406197, 51.69634846278599, 53.30038179670061, 53.92468786239624, 58.33942386082241, 59.71651513235909, 59.09037821633475, 62.64729309082031, 63.66058363233294, 60.30270685468401, 60.545372690473286, 63.98216710771833, 65.07397924150739, 66.9645493371146, 65.75298500061035, 64.50934083121163, 56.550530229296, 64.1101598739624, 65.84172739301408, 73.57941504887172, 45.235197748456685, 1.455818812761988, 0.07597926405391522, 0.11379419027694634, 0.07091727067849465, 0.1377501812364374, 0.09102618521345512, 0.13070343221936906, 0.06031917793942349, 0.22996455590639794, 1.0580682073320662, 7.903826900890895, 50.96889986310686, 31.899353436061315, 44.45033965791975, 48.54995053155081, 0.11459463089704514, 0.04640127798276288, 0.04453797332410302, 0.08322440313973598, 0.005434950148420674, 0.03263735458520906, 0.019689064206821576, 0.04687028478032776, 0.07627408751951796, 0.06145090649702719, 0.09418887086212635, 0.04431472173226731, 0.20959929084139212, 0.1793651817632573, 0.2626739064497607, 0.15042102203837462, 0.1466673527445112, 0.09807766361960343, 0.15068391364599976, 0.13235433506114141, 0.21751907015485422, 0.19711515573518618, 0.3354436387973172, 5.004070477826255, 77.01054668426514, 45.503189768110005, 53.148046016693115, 55.699771949223106, 63.65958309173584, 12.855597853660583, 0.20185925545436995, 0.5624507591128349, 0.6816213758928436, 0.24679629557899066, 0.10636472036795956, 1.607631197997502, 0.4877687522343227, 0.2935051534857069, 0.367210857037987, 31.097774505615234, 96.24375792912075, 83.3019529070173, 88.51927879878453, 73.77435370853969, 73.37193489074707, 79.0875369480678, 84.62466757638114, 83.909823008946, 90.69531563350132, 81.00498267582485, 83.13791983468192, 79.30732236589704, 77.00998388017926, 79.55094705309186, 74.81865406036377, 70.4592569896153, 62.277155603681294, 68.97550392150879, 73.20186383383614, 74.70605850219727, 76.58829075949532, 77.06256089891706, 75.39196382250104, 69.30651610238212, 61.919524874006, 61.72309235164097, 63.548453603472026, 64.06893621172223, 67.0767627443586, 69.82449735913957, 70.57471520560128, 71.2788039616176, 62.7857984815325, 64.69612925393241, 67.74461664472307, 68.61152253832135, 68.86568764277867, 66.51905863625663, 71.59286948612758, 69.31820297241211, 64.93624510083879, 65.81261444091797, 72.01031030927385, 63.633791378566194, 61.63011155809675, 65.43279116494315, 66.6803263255528, 66.17457389831543, 69.49902289254325, 66.76545565468925, 55.437380177634104, 58.926657812935964, 65.7548610142299, 72.25021771022251, 66.80328164781842, 58.60653345925467, 49.83898033414568, 49.12198182514736, 55.81342363357544, 61.098393712724956, 64.05742304665702, 63.84252221243722, 62.47801412854876, 52.43866620744978, 50.189485686165945, 53.25301245280674, 61.06390980311802, 64.21879495893205, 66.13901996612549, 63.06888893672398, 58.258574622017996, 53.87140907560076, 54.34861830302647, 62.199752671378, 63.83656760624477, 64.21901730128697, 58.90190832955496, 58.60203797476632, 64.62545912606376, 62.239545004708425, 59.80254772731236, 63.35781587873186, 60.13510240827288, 62.2573949268886, 61.433623450142996, 63.506931168692454, 62.70129449026925, 55.628493853977744, 55.787531171526226, 60.443095207214355, 58.99830068860735, 56.00142451695034, 60.97445174625942, 60.684176853724885, 62.75200939178467, 60.45239189692906, 61.26214190891811, 59.20144517081124, 56.706857749394004, 54.486262117113384, 53.49344444274902, 54.57077305657523, 56.84956680025373, 56.61073637008667, 61.61187253679548, 63.4211209160941, 60.00162056514195, 67.46982233864921, 64.62459754943848, 63.59506906781878, 62.78743825639997, 65.38287530626569, 68.127427646092, 69.40504155840192, 69.59781238010952, 68.81889152526855, 59.694197518484934, 68.34441988808769, 70.81046758379254, 80.56980310167584, 48.92855787277222, 2.0488012049879347, 0.19976929974343094, 0.27434934995004107, 0.13074421217398985, 0.7507022661822182, 0.4057117753795215, 0.3971712722309998, 0.2283299650464739, 0.6234390607901982, 2.1415242637906755, 13.891518677983965, 62.214865003313335, 43.14345645904541, 50.860365527016775, 56.703498295375276, 0.22875000536441803, 0.09241810480930976, 0.12326082587242126, 0.20769270243389265, 0.16165248650525296, 0.10350078011729888, 0.10271490085870028, 0.16540728216724737, 0.15345899973596844, 0.1534796000591346, 0.21076463402381965, 0.20376732306821005], [0.0370774468673127, 0.06946529394813947, 0.04859681034992848, 0.04309522806267653, 0.07993174410824265, 0.17426521756819316, 0.0952924605725067, 0.15310196817985602, 0.09464912795062576, 0.05706614535301924, 0.32359856154237476, 8.508649349212646, 59.89446544647217, 34.49226481573922, 37.38139527184622, 37.73546157564436, 37.91712917600359, 3.127114074570792, 0.018520226569047997, 0.2808150830013411, 0.1596309949776956, 0.03312994386734707, 0.01890323414201183, 0.18348023880805286, 0.08658624560173069, 0.215072381443211, 0.7053888833948544, 52.64822735105242, 83.52919374193463, 75.28476006644112, 74.36268547603062, 66.85574054718018, 62.98227269308907, 68.1412684576852, 73.7272310256958, 72.3038786479405, 79.97844886779785, 75.52856540679932, 70.454879624503, 66.05880996159145, 64.92635086604527, 62.67871979304722, 60.52913475036621, 55.89711468560355, 57.68584156036377, 61.96508421216692, 67.24411705562046, 67.09648868015834, 70.64236981528146, 69.14246913364956, 67.18218776157924, 64.38991519383022, 56.47839403152466, 56.51056071690151, 56.2777543749128, 59.77284417833601, 67.02859088352749, 61.56719561985561, 67.03583785465786, 60.887050356183735, 57.09649535587856, 59.17865507943289, 58.8119569505964, 60.934110505240305, 60.471416064671104, 63.65133558000837, 62.99442509242466, 59.75529997689383, 61.34812586648123, 61.922880853925435, 54.29058000019619, 57.83932726723807, 63.242677279881065, 62.38588101523263, 61.98161397661482, 64.46368421827043, 55.38347257886614, 47.81156199319022, 54.24824810028076, 67.04990100860596, 60.00908987862723, 55.93446472712925, 55.91579839161464, 50.87340382167271, 44.55471202305385, 45.443813937050955, 43.4412909916469, 40.789973054613384, 44.21282591138567, 44.61140932355608, 42.40908397947039, 44.74516909463065, 44.65937968662807, 50.02553946631295, 55.199727467128206, 56.91640847069876, 56.43460300990513, 58.661521502903526, 61.9807801927839, 59.59251758030483, 48.671540532793315, 46.77614491326468, 56.49917261941092, 57.63256972176688, 59.531276157924104, 52.867422172001426, 56.04663297108242, 57.88757903235299, 57.727471692221506, 55.59243965148926, 55.01805639266968, 56.4025752885001, 60.176756858825684, 55.87443576540266, 58.3951484135219, 53.59196989876883, 55.508665221078054, 53.82375485556466, 46.32099969046456, 52.08419690813337, 53.77350895745413, 56.16744129998343, 55.01064961297171, 57.69808081218174, 51.72930029460362, 50.640170165470664, 48.76133557728359, 47.407291480473106, 44.95841973168509, 47.178275380815776, 50.08840676716396, 53.34518378121512, 57.37718173435756, 57.17485366548811, 59.21532072339739, 60.56821141924177, 60.313539096287315, 57.80973836353847, 58.15638051714216, 62.08129283360073, 63.041221209934776, 68.66089643750871, 66.25164331708635, 63.429507391793386, 53.7467167036874, 57.80901575088501, 61.2567709514073, 63.722408703395296, 53.962208134787424, 3.4514366601194655, 0.049798767281962295, 0.2754168483827795, 0.07411177961954049, 0.020533782629562274, 0.044915896973439624, 0.07456295790949038, 0.04018979539562549, 0.48191554631505695, 0.419533832264798, 1.3869545651333672, 36.96819632393973, 36.65152175085885, 31.990420000893728, 45.95575026103428, 0.7451162402118955, 0.07631042985511677, 0.0636793647759727, 0.019936049257272055, 0.053177841140755584, 0.05594421823375991, 0.1213698573410511, 0.044385034923574755, 0.07777027080633811, 0.10950240200119359, 0.035250345444572825, 0.08891522205833878, 0.04668638821957367, 0.008430726360529661, 0.11220791111035006, 0.04549373060997043, 0.030938631987997463, 0.03379452820601208, 0.11410365652825151, 0.12787027710250445, 0.07826966579471316, 0.1715454456529447, 0.3922869600355625, 11.562092542648315, 69.66591167449951, 42.76728446143014, 32.345181124550955, 39.189792496817454, 48.44003350394112, 4.3467239907809665, 0.046378665803266425, 0.17670555519206183, 0.1488693074456283, 0.07024672880236592, 0.046817484577851634, 0.05201267437743289, 0.05237426568887063, 0.03791233331763318, 0.7477573156356812, 53.1019412449428, 87.65172672271729, 81.5434958594186, 79.89798177991594, 70.11901760101318, 67.01148441859654, 70.54681818825858, 77.97337940761021, 75.56626633235386, 82.56354699816022, 79.62450068337577, 74.51404503413609, 68.83934007372174, 65.86125183105469, 64.64186382293701, 63.536593028477256, 57.94377258845738, 59.194934708731516, 63.86242880140032, 69.18643733433315, 69.95089203970772, 73.654830796378, 70.84680666242326, 71.35858317783901, 65.76480388641357, 59.66076973506382, 57.5304867880685, 57.33076776776995, 61.23293168204171, 68.90826620374406, 65.76189259120396, 68.66509314945766, 61.75727054050991, 61.23691994803292, 61.64323670523507, 60.79508399963379, 64.08004638126918, 65.5977622440883, 66.4396893637521, 66.9559405190604, 61.42902374267578, 65.27504621233258, 61.96183245522635, 57.262095246996196, 61.532246180943076, 66.44296891348702, 63.96173940386091, 64.403457232884, 65.98146261487688, 54.93160343170166, 49.728424072265625, 61.289038385663716, 67.10349941253662, 61.91259057181222, 59.182935169764924, 57.726082052503315, 53.78647429602486, 46.006638867514475, 47.358258043016704, 45.35878535679409, 44.41550833838326, 46.46906927653721, 45.85522024972098, 43.96356970923287, 46.644323689596995, 45.90648405892508, 51.208630084991455, 56.329980509621755, 57.337504046303884, 58.1375925881522, 58.40831524985177, 63.27361066000802, 62.88124588557652, 55.358135972704204, 48.69449738093785, 57.19158492769514, 58.58819021497454, 61.303511483328684, 55.970001288822715, 58.97995744432722, 59.16415418897356, 61.218333516802105, 56.95946645736694, 56.842236450740266, 59.719940594264436, 60.355207443237305, 56.6604403087071, 59.69549683162144, 58.11817584718977, 58.24046414239066, 55.897507258823936, 49.76896333694458, 57.60274805341448, 55.666722842625205, 59.64387171609061, 58.92151614597866, 59.366138322012766, 56.497710023607524, 54.02113580703735, 50.645812102726524, 49.30078329358782, 48.4422847202846, 50.250386646815706, 51.462232385362896, 54.382914611271445, 57.81362588065011, 59.73895781380789, 61.10898971557617, 61.91197913033621, 61.219063077654155, 59.68947969164167, 60.65950380052839, 64.60949911390031, 65.15951156616211, 70.74246556418282, 68.80946976797921, 66.0244094303676, 59.26181806836809, 60.84935637882778, 68.55945273808071, 70.89779949188232, 56.680266993386404, 4.329097713742938, 0.10893524172050612, 0.28876251940216335, 0.10785297158041171, 0.10938348873917546, 0.008887502564383405, 0.12242344580590725, 0.03529966815507837, 0.3273316169423716, 0.5232630276254245, 1.1003335565328598, 43.31118597303118, 34.93236371449062, 37.4522008895874, 54.28396878923689, 1.3872733137437274, 0.02345628384500742, 0.06599599868059158, 0.08265186886170081, 0.012090790900401771, 0.05907514505088329, 0.10634928369628531, 0.08709440047719649, 0.06025042198598385, 0.08542318908231598, 0.024302584950679114, 0.07935104705393314, 0.12152235130114214, 0.12439610995352268, 0.17573841208858149, 0.12361739602472101, 0.14744742374335015, 0.23193418021712983, 0.24110767511384829, 0.2664819806814194, 0.2045408258480685, 0.24437373557261058, 0.6795314880354064, 12.77093231678009, 83.06440789358956, 46.644007546561106, 50.99697405951363, 53.86779601233346, 59.1765011378697, 8.056497931480408, 0.07819125428795815, 0.4497907944023609, 0.45305248509560314, 0.15445930963116034, 0.34626404674989836, 0.7787204970206533, 0.34129489053572926, 0.4462036783141749, 1.340069858091218, 58.80916377476284, 91.20930862426758, 85.6882769720895, 85.15634373256138, 78.27141543797084, 69.96015398842948, 77.49273082188198, 81.67151641845703, 79.94636903490338, 85.79140213557652, 85.2624705178397, 78.82293564932687, 72.10538251059396, 68.39552388872418, 68.17520345960344, 66.3211669921875, 62.34920842306954, 62.97289957318987, 68.19819504874093, 72.79523440769741, 71.94464983258928, 77.68170097896031, 75.66128989628383, 76.86529459272111, 70.70496613638741, 63.13888508932931, 63.397441455296104, 62.70039817265102, 65.58242756979806, 72.48095348903111, 67.92715276990617, 71.34572901044572, 67.65959848676408, 66.07379027775356, 64.92245292663574, 64.86970915113176, 67.22079890114921, 68.13072109222412, 69.55704035077775, 69.69363498687744, 65.32574721745083, 69.47865077427456, 66.78584166935512, 60.325656754629954, 64.00919560023716, 70.21281133379254, 68.7094921384539, 68.19876480102539, 67.04066685267857, 60.31227452414376, 52.07864529745919, 60.80159446171352, 69.64822156088692, 66.47554206848145, 62.81825351715088, 59.85374205453055, 56.18290451594761, 49.96221705845424, 50.09101928983416, 47.63204138619559, 46.891134125845774, 49.55149514334542, 49.71962070465088, 47.76805237361363, 49.69144228526524, 48.80024896349226, 54.19866228103638, 59.917262486049104, 60.297454016549246, 59.12860025678362, 63.63352039882115, 67.19664001464844, 63.96312209538051, 55.921113763536724, 51.6896573475429, 61.54944297245571, 62.32101958138602, 63.79284259251186, 56.55815240315029, 61.28198596409389, 60.458888462611604, 65.11410508837018, 59.274081638881135, 58.87078734806606, 61.78008842468262, 61.75346292768206, 59.84980937412807, 61.555105754307334, 58.948294503348215, 59.64632443019322, 59.31943947928292, 54.49302618844168, 61.10522379193987, 59.41187136513846, 62.92031560625349, 60.44069113050188, 64.21467467716762, 61.50415461403983, 56.17942346845354, 55.48620169503348, 52.79336132322039, 50.66309922082083, 53.250903674534385, 55.088379110608784, 59.939482825142996, 61.14719785962786, 61.171787534441265, 63.46454020908901, 64.83582973480225, 64.3295978818621, 62.573308672223774, 62.64224869864327, 68.48185525621686, 68.61899185180664, 73.91865389687675, 70.31761101314, 70.77032089233398, 62.13352244240897, 66.52332483019147, 72.09492547171456, 74.63592338562012, 61.97000353676932, 6.143810851233346, 0.23073626735380717, 0.7398634020771299, 0.20871161775929586, 0.3333318478294781, 0.23407096841505595, 0.2644391288714749, 0.08390997456652777, 0.9349351631743568, 2.2938824083123888, 2.074521481990814, 53.159989970070974, 51.67078604016985, 44.984013421194895, 59.73255852290562, 1.3250580579042435, 0.29982923556651386, 0.1812186273080962, 0.14368169009685516, 0.10426105146429368, 0.14810527701463017, 0.28327235685927526, 0.21142589354089328, 0.11592397599348, 0.18544675542839936, 0.20942412024097784, 0.1307243989514453], [0.096979128995112, 0.027846624243206212, 0.1965437749666827, 0.021059743960254958, 0.07807234781129019, 0.061086024290749004, 0.06738409133894102, 0.09198013081082276, 0.08013883978128433, 0.17895302602222987, 0.3711206300982407, 21.57066341808864, 52.31486667905535, 33.69438927514212, 44.739961419786724, 39.824638979775564, 28.59360204424177, 2.8938493686062947, 0.15934721806219646, 0.09789962281606027, 0.044163927502397976, 0.15181695856153965, 0.11868555923657757, 0.5242061370185443, 0.5074950680136681, 0.1760075462183782, 11.856957588876996, 68.89411967141288, 83.6820193699428, 74.74858842577252, 72.32823208400181, 67.02998747144426, 60.913717542375835, 68.44895553588867, 77.7851596559797, 75.39956515175956, 78.06334468296596, 73.1603969846453, 72.61460208892822, 69.25336238316127, 63.71681540352957, 58.9985716683524, 56.90847362790789, 55.98341131210327, 53.64180237906319, 55.60645416804722, 65.13127408708844, 69.41865307944161, 66.50004141671317, 66.66948018755231, 67.22266796657017, 64.39142990112305, 59.535660471235005, 52.82503816059658, 55.512524945395334, 57.473841599055696, 63.56305871691023, 63.09993348802839, 68.72113731929234, 55.41001122338431, 62.69300528935024, 57.470214639391216, 57.075060163225444, 59.45037828172956, 60.91894258771624, 63.03178555624825, 61.090493610927034, 61.28910091945103, 57.13373075212751, 54.944290842328755, 61.21244144439697, 63.08344541277204, 62.7509046282087, 58.8724479675293, 64.49462454659599, 52.24754210880825, 44.18399436133248, 55.950226715632844, 63.65612983703613, 58.20485462461199, 56.844473770686555, 61.11961351122175, 56.11230387006487, 48.79731682368687, 45.29685606275286, 41.86795827320644, 45.46876491819109, 48.61915806361607, 52.836318561008994, 48.63769933155605, 45.34457976477486, 42.08625677653721, 44.58113949639456, 45.446711335863384, 50.460642610277446, 52.67243834904262, 55.00602906090872, 53.56441681725638, 55.555134773254395, 59.456784520830425, 61.7976256779262, 48.86844205856323, 45.8384507724217, 54.061998162950786, 54.632480008261545, 58.56489290509905, 57.87234858104161, 59.15753255571638, 54.66823543821062, 58.255729334695, 54.814745153699604, 54.6059239932469, 55.19359915597098, 55.70247827257429, 55.83640480041504, 58.6981315612793, 52.090759481702534, 46.466310841696604, 50.455195222582134, 52.06771578107561, 52.110954420907156, 53.25622252055577, 56.122614996773855, 55.35530458177839, 54.255675724574495, 50.155158111027305, 46.63492625100272, 48.09305088860648, 47.690503529139924, 47.5802321434021, 49.339686257498606, 51.578024114881245, 56.05482142312186, 58.642219407217844, 59.591801915849956, 60.51393904004778, 59.16941397530692, 57.48280130113874, 55.81545598166329, 58.748568534851074, 63.208756174360005, 65.59870719909668, 67.43495627811977, 62.06883471352713, 56.446543489183696, 57.10389518737793, 64.16283416748047, 62.916528838021414, 62.38362979888916, 8.190867406981331, 0.09947016675557409, 0.035559217977736673, 0.1065811323268073, 0.1084896477737597, 0.04584204977644341, 0.03388862744239824, 0.04110561750297036, 0.0625526641628572, 0.17915936852140085, 0.17461683441485676, 30.724169867379324, 37.20139523914882, 29.888965129852295, 46.336139815194265, 5.842691557747977, 0.291889670171908, 0.16687787111316407, 0.0932169101600136, 0.17822778065289768, 0.04888938107926931, 0.08843184728175402, 0.1072144904839141, 0.12569040193089417, 0.09704151350472655, 0.04549411737493106, 0.051446043354059966, 0.04469030782846468, 0.04968742307807718, 0.10078369520072426, 0.08490582648664713, 0.015496241959876247, 0.09345654158719949, 0.1059115743264556, 0.21222210010247572, 0.06487193078334842, 0.19968497141131333, 0.4210021820451532, 29.562135764530726, 57.95222854614258, 42.32580287115914, 38.335379464285715, 44.26213032858712, 39.000530515398296, 4.261076586587088, 0.16303368524781295, 0.12017621924834591, 0.0638590951317123, 0.07564895999218736, 0.13961137565118925, 0.5000745004841259, 0.7343876787594387, 0.22762137092649937, 13.431352513177053, 73.23654229300362, 85.27601950509208, 80.79037366594586, 75.86593518938336, 71.70778574262346, 64.38176495688302, 71.5525004523141, 82.30775601523263, 76.63305105481828, 82.48854119437081, 77.33737604958671, 75.41795703342983, 72.11529758998326, 67.10413864680699, 64.32952839987618, 59.32453945704869, 57.287084443228586, 56.57171181270054, 57.8940304347447, 68.15813868386405, 73.42658942086356, 70.30709838867188, 69.41330991472516, 70.60578060150146, 66.43957819257463, 60.70418071746826, 54.16440418788365, 57.69668769836426, 59.34122208186558, 65.7783111844744, 65.52085958208356, 69.9755025591169, 60.488397462027415, 63.56690801892962, 59.43877479008266, 60.94881984165737, 61.248731885637554, 64.23890999385289, 65.22359480176652, 63.54449313027518, 63.8901938029698, 60.72019631522042, 58.9166385105678, 64.73935399736676, 65.92191655295235, 64.78694220951625, 62.038165364946636, 65.82598277500698, 52.39939151491438, 47.959166049957275, 61.51857907431466, 65.49636023385185, 60.23116820199149, 60.72792966025216, 63.545827184404644, 57.78933150427682, 50.064143657684326, 48.191072600228445, 44.972882407052175, 48.76306915283203, 53.31299277714321, 57.513210092272075, 55.10678836277553, 50.1809081350054, 43.78417764391218, 46.50176749910627, 49.07216324125017, 51.374775409698486, 55.80255317687988, 57.947156361171174, 55.81200967516218, 57.826591219220845, 58.972870281764436, 61.0616238457816, 53.81859234401158, 46.89566435132708, 55.010243143354145, 56.551829542432515, 61.400994709559846, 59.674610546657014, 59.52107620239258, 58.302528926304404, 60.73560741969517, 57.67409563064575, 56.189682483673096, 55.67792681285313, 57.6839724949428, 57.57107469013759, 57.54033933367048, 54.94068125316075, 49.104083265577046, 53.39090987614223, 55.594135011945454, 55.953169277736116, 56.458247729710166, 58.20140484401158, 59.03498717716762, 55.93522902897426, 52.08238690240042, 49.26755700792585, 51.012395586286274, 50.440805503300254, 49.82858582905361, 52.012262208121165, 54.46845735822405, 56.46526888438633, 60.91842147282192, 61.82159696306501, 63.221471377781455, 61.16404724121094, 59.21686322348458, 57.67530461720058, 61.6604334967477, 65.30935641697475, 69.05413668496269, 68.2917594909668, 64.92011833190918, 59.3311402457101, 59.827860014779226, 68.16797733306885, 67.6846397944859, 65.85228865487235, 9.487186738422938, 0.04160780127027205, 0.04291190825668829, 0.15786586755088397, 0.126974882291896, 0.09934056656701223, 0.05369199426578624, 0.018774107231625488, 0.5005289018154144, 0.3072593840105193, 0.098457514308393, 35.44297988074166, 41.32526574816023, 31.154680252075195, 58.388214111328125, 7.935657467160906, 0.5068532824516296, 0.11823125290019171, 0.13080655597150326, 0.045200182790202756, 0.05500227592087217, 0.05608297525239842, 0.05870121118745633, 0.10805522251342024, 0.023147265426814556, 0.13827908571277345, 0.08915542345494032, 0.1472137634243284, 0.15873294030981405, 0.2880007417074272, 0.23992916835205896, 0.15728909921433243, 0.21996559601809296, 0.11909528582223824, 0.3568786143192223, 0.1574635777090277, 0.38239009252616335, 0.6194301673344204, 31.966643265315465, 71.41496086120605, 46.266404220036094, 66.2750517981393, 53.95949486323765, 50.38172844478062, 8.197567207472664, 0.22169704096657888, 0.21248462530119078, 0.40184238872357775, 0.2559611595102719, 0.2790167209293161, 1.2559010088443756, 2.523619817835944, 0.7076358113970075, 17.30980917385646, 81.24022783551897, 89.88074357169015, 85.05123138427734, 81.42766938890729, 75.38659981318882, 69.63946683066231, 76.2242259979248, 87.01341656276158, 81.06007494245256, 85.30379840305874, 79.39279215676444, 77.93128027234758, 75.45027310507638, 70.81633186340332, 66.98000907897949, 64.18803528376988, 60.765839031764436, 59.032562255859375, 60.62137903485979, 70.92713478633335, 75.45162105560303, 71.14505113874162, 72.05027634756905, 73.31374372754777, 70.99907643454415, 64.65851865495954, 57.99352169036865, 61.87841933114188, 63.173966544015066, 69.2606510434832, 69.3013744354248, 73.83707509722028, 62.09901768820626, 65.52737004416329, 63.69649887084961, 65.08976554870605, 64.86397688729423, 67.7123144694737, 68.72825227464948, 67.78521496909005, 66.88942541394914, 64.33364868164062, 60.530545234680176, 68.13720376150948, 69.36671529497418, 67.2716041292463, 62.63967786516462, 70.3945414679391, 57.84475033623831, 49.29386288779122, 60.704722676958355, 67.86012349809918, 62.261042731148855, 60.60250077928816, 66.09599672045026, 63.02534457615444, 53.132773876190186, 50.86991235188076, 46.60230793271746, 50.8297552381243, 54.00988667351859, 57.851253850119456, 55.55903271266392, 52.16206536974226, 48.04712677001953, 49.79567916052682, 51.36517647334507, 55.40497725350516, 59.983909606933594, 61.968509674072266, 58.58884334564209, 60.353553771972656, 62.937616620744976, 65.14647674560547, 54.047052587781636, 50.943125520433696, 59.25723920549665, 60.616675104413716, 63.81251989092146, 63.18159566606794, 63.26414026532854, 60.55617019108364, 62.910386630467, 59.83475957598005, 59.16814940316336, 59.78265503474644, 60.19621876307896, 59.616127559116904, 62.21300288609096, 58.7683778490339, 53.75122955867222, 55.382600579942974, 58.844995634896414, 58.62022141047886, 57.48221417835781, 61.64584922790527, 60.83268070220947, 59.56533622741699, 56.493558474949424, 51.81911618368966, 55.19490541730608, 53.52019500732422, 53.68826150894165, 53.433898380824495, 57.87804610388619, 60.36100918906075, 63.4364139011928, 64.56343255724225, 66.22524016244071, 65.30710520063127, 62.38011401040213, 59.249985286167686, 65.60543305533272, 65.99492127554757, 73.02921499524797, 71.07467283521379, 69.71865545000348, 63.835462842668804, 64.31055981772286, 74.67455536978585, 74.74249485560826, 69.5602365221296, 12.78562080860138, 0.13693646847137383, 0.2875204474798271, 0.5977054302181516, 0.23170757666230202, 0.32711855694651604, 0.3182999901473522, 0.09967282480959382, 2.375359590564455, 1.6446021284375871, 0.6174993823681558, 41.90108380998884, 54.2486788885934, 38.66727406638009, 65.26333849770683, 9.743163585662842, 0.7318179852196148, 0.2947180484022413, 0.31662064311759813, 0.2714468485542706, 0.17885955103806087, 0.19139397915984901, 0.18082215929669992, 0.21042907131569727, 0.24523251663361276, 0.3525136799684593, 0.1974247441227947], [0.03738497929381473, 0.08537663479468652, 0.05497162649407983, 0.032906712631561925, 0.0386120080947876, 0.07068497421486036, 0.04622963915712067, 0.09172450631324734, 0.024307253271607415, 0.07494066442762103, 0.07717976213565894, 36.08806800842285, 50.28530134473528, 22.47303465434483, 36.94359622682844, 48.3525904246739, 10.812164783477783, 3.477868910346712, 0.05626734678766557, 0.16185075443770203, 0.1429850517639092, 0.12513758588050092, 0.04354513409946646, 8.711947560310364, 20.884170975003922, 3.1551320339952196, 50.11568192073277, 79.94730704171317, 79.11655957358224, 75.57941927228654, 70.16752297537667, 63.75337682451521, 65.51462704794747, 69.40288066864014, 74.66388988494873, 75.59961073739188, 75.35101808820451, 76.49286420004708, 72.18019376482282, 71.65144974844796, 69.53590393066406, 71.14698273794991, 66.53374712807792, 57.67981399808611, 55.022315638405935, 54.9698463167463, 62.5346280506679, 66.40483719961983, 65.53603444780622, 66.64823954445976, 65.79288850511823, 66.12172589983258, 58.39714254651751, 54.896473339625764, 54.20244904926845, 60.188179697309224, 60.08117743900844, 62.47540160587856, 63.37620081220354, 61.430330004010884, 55.8799387386867, 56.56368316922869, 58.535946709769114, 62.40520395551409, 59.00910513741629, 60.87495354243687, 60.684142112731934, 57.82334293637957, 58.76429230826241, 65.05917957850865, 62.19393008095877, 61.74631323133196, 60.779867444719585, 62.006891523088726, 51.747306551252095, 47.119757652282715, 59.43718365260533, 61.55186094556536, 59.05425453186035, 61.61809812273298, 61.14184079851423, 54.7735458101545, 48.52788652692522, 44.671215942927766, 42.21712957109724, 47.36071423121861, 57.87833445412772, 57.95111336026873, 59.67389488220215, 58.84790693010603, 58.84578078133719, 48.93093763078962, 41.320676462990896, 42.555638858250205, 45.96359477724348, 49.44703245162964, 55.973722049168174, 57.84527839933123, 58.93817097800118, 58.10694408416748, 54.1184001650129, 59.79847608293806, 49.596057415008545, 49.34100294113159, 52.13488401685442, 53.69225672313145, 56.922165053231375, 56.139370577675955, 56.47091776984078, 55.98428678512573, 55.94799634388515, 57.53733423777989, 54.2581319127764, 54.27950804574149, 54.743699823107036, 54.34935828617641, 51.880986418042866, 50.25601468767439, 46.995117391858784, 49.294047015053884, 50.19195924486433, 54.59902095794678, 57.4984347479684, 54.69660840715681, 51.149143082754954, 47.68667507171631, 49.14676604952131, 47.02096469061715, 47.876902852739605, 46.60868985312325, 51.01597043446132, 52.94487026759556, 55.96457821982247, 58.72716808319092, 60.03208841596331, 59.93488311767578, 58.51262160709926, 56.592962878090994, 54.91224922452654, 58.151770387377056, 63.72909981863839, 66.18456540788922, 65.83098547799247, 60.91808795928955, 57.80697645459856, 55.45324291501726, 63.81193624223982, 62.69219235011509, 66.66117014203752, 13.951511161667959, 0.1702063160815409, 0.03127520910597273, 0.0633548079058528, 0.04826418909111193, 0.0738575461187533, 0.0527326305662947, 0.10717130851532732, 0.39726298302412033, 0.1844854477260794, 0.46550449835402624, 24.418347869600566, 38.744242736271445, 31.232076236179896, 50.636397293635774, 11.969477585383824, 0.5030731367213386, 0.11787514415170465, 0.07843734536852155, 0.18202307128480502, 0.2518195988876479, 0.07077975198626518, 0.10861159408731119, 0.10354331069226776, 0.1409219660397087, 0.12358906040234224, 0.05298286410314696, 0.04316659976861306, 0.06443986682487385, 0.03641854525942888, 0.030695784304823195, 0.04310057831129857, 0.04323100970525827, 0.043248471803963184, 0.06959804932453803, 0.02377915964461863, 0.05080429171877248, 0.5129815936088562, 44.794664587293354, 59.09770161764962, 33.71713072913033, 37.61809607914516, 55.465815680367605, 16.37963993208749, 4.484003024441855, 0.26497015037706917, 0.1238994901733739, 0.25779477826186586, 0.09149357370500054, 0.3273310198315552, 9.243597660745893, 24.925245012555802, 3.351670950651169, 54.39713757378714, 82.19454901559013, 85.06082684653146, 78.09971155439104, 75.53225490025112, 67.2134963444301, 68.92932619367326, 73.74578271593366, 77.18525218963623, 76.48425538199288, 79.03152057102749, 79.32524177006313, 75.4446450642177, 74.52244540623256, 73.26930304936, 75.36576216561454, 68.63174874441964, 62.49859469277518, 56.11624002456665, 57.39504555293492, 64.24018846239362, 71.9445664542062, 68.0501080921718, 70.28958892822266, 67.03813076019287, 68.29449708121163, 61.58214814322335, 56.65346084322248, 56.951861654009136, 61.819324902125764, 62.92097568511963, 65.85279587336949, 65.5013907296317, 64.24992983681815, 57.115957260131836, 63.065275873456685, 61.69115148271833, 64.11431489671979, 63.91830621446882, 65.45141928536552, 64.65642029898507, 61.389905384608674, 62.97276060921805, 67.69726467132568, 62.68428530011858, 62.56732627323696, 62.23825263977051, 63.51772172110421, 53.02771711349487, 52.56872953687395, 62.92019053867885, 64.69081388201032, 60.53825078691755, 65.25653621128627, 62.09073543548584, 55.37870611463274, 48.99500002179827, 49.50062738146101, 44.61903844560896, 52.14438220432827, 60.6311343056815, 62.29686764308384, 61.91684981754848, 61.38060174669538, 62.594257490975515, 52.765985420772004, 44.404835905347554, 46.92472866603306, 49.28638315200806, 50.37427650179182, 56.240814277103965, 59.819737570626394, 60.73616327558245, 61.47997488294329, 58.178705079214915, 62.2161990574428, 52.641088077000205, 52.181047848292756, 54.47478369304112, 55.940672942570274, 58.670637539454866, 58.10848658425467, 59.27762522016253, 58.75297369275774, 55.992468288966585, 57.67696871076311, 57.24475254331316, 54.47073289326259, 56.67588268007551, 55.62312984466553, 52.42994621821812, 51.66558878762381, 47.33569029399327, 51.12765577861241, 52.81322622299194, 58.833343505859375, 59.56534317561558, 56.7158591406686, 53.134695053100586, 49.60797010149275, 50.68014315196446, 50.17425176075527, 48.052310126168386, 49.36830588749477, 54.075220584869385, 54.8790020942688, 56.11115741729736, 61.20454134259905, 59.93972601209368, 60.694501876831055, 59.86066246032715, 57.742226191929404, 56.640804699489046, 59.72244194575718, 65.00506005968366, 67.1766778400966, 68.35301480974469, 63.067256110055105, 62.2278789792742, 59.396988323756624, 68.85495267595563, 67.93109934670585, 69.50909778050014, 15.646267993109566, 0.2776771028126989, 0.06395199336111546, 0.11879769393375941, 0.054158755112439394, 0.11000553571752139, 0.14721377699502877, 0.07296679927302258, 0.3700583428144455, 0.17191538294511183, 0.44463973652039257, 26.210010358265468, 48.94187756947109, 24.93330144882202, 58.86907114301409, 16.134022848946707, 0.3972709354545389, 0.07340019994548388, 0.0641529822189893, 0.1253699298415865, 0.11490438213305813, 0.09837385772594384, 0.15050435970936502, 0.10684528600956712, 0.045518395357898304, 0.09189983976206609, 0.02789911231957376, 0.06418120927576508, 0.2528340630233288, 0.11897621649716582, 0.17184168047138623, 0.1526910745139633, 0.1465133795780795, 0.12196301908365317, 0.18502541232321942, 0.18667009978422097, 0.16078983779464448, 0.44791087242109434, 53.56171744210379, 65.23178672790527, 34.17147690909249, 51.16060413633074, 69.42671298980713, 22.469206196921213, 11.731273361614772, 0.49062999870095936, 0.4346125360046114, 0.3685848633093493, 0.17744251207581588, 0.3485209085047245, 12.067119751657758, 31.192179679870605, 4.153071182114737, 60.63150256020682, 88.02045372554234, 91.0220616204398, 86.43313080923897, 81.26259408678327, 71.88677133832658, 73.41063635689872, 78.30343273707798, 81.47921807425362, 80.43466758728027, 84.63950198037284, 81.32573931557792, 79.66939994267055, 77.95352840423584, 76.31846441541398, 77.85922745295933, 72.28472941262382, 65.14947836739677, 60.44713905879429, 59.86978544507708, 68.27004637037004, 73.66298798152378, 69.30039473942348, 72.98380851745605, 70.88211045946393, 72.27173628125871, 64.99190017155239, 60.05974224635533, 59.24256461007254, 64.7208023071289, 65.37205696105957, 69.06713676452637, 69.15092509133476, 65.77273178100586, 61.84064197540283, 68.13903113773891, 65.66011537824357, 70.24905313764299, 65.73060485294887, 66.97707693917411, 68.18548679351807, 64.34728104727608, 65.9627024786813, 72.49696908678327, 65.20038087027413, 66.77400193895612, 64.86317089625767, 67.31795556204659, 58.9135674067906, 53.543867519923616, 65.00329521724156, 68.05690343039376, 65.38574491228376, 66.3247731072562, 66.23012474605015, 58.573515619550435, 53.016252585819785, 50.49415724618094, 46.654742513384136, 52.312924657549175, 62.46757098606655, 64.51817893981934, 65.01075758252824, 64.27152483803886, 64.16635690416608, 52.495808192661826, 45.548756054469514, 48.159051827022004, 51.79855646405901, 53.399435315813335, 57.7629075050354, 61.184822354997905, 63.07995046888079, 64.69833878108433, 59.284295490809846, 64.8614616394043, 52.9437655040196, 54.404728480747764, 56.67311034883772, 59.29517636980329, 62.405919619968955, 61.02982194083077, 60.30766786847796, 61.12035002027239, 59.05838871002197, 58.79630960736956, 58.135365690503804, 58.59103897639683, 59.0050265448434, 59.48475102015904, 57.46196017946516, 53.59102494376046, 50.967906270708355, 55.72220768247332, 55.99509123393467, 61.09277262006487, 63.26587036677769, 60.69740622384207, 56.998348576681956, 51.92884908403669, 55.54458393369402, 54.268925939287456, 53.62891347067696, 51.53775235584804, 57.55289125442505, 57.45799275806972, 61.404364585876465, 64.65184143611363, 63.724430629185264, 63.81500734601702, 62.51982143947056, 61.22039713178362, 58.617796489170615, 63.5438608442034, 68.87289292471749, 70.50461483001709, 70.67732620239258, 65.67565849849156, 65.75581291743687, 64.22350583757672, 75.54247570037842, 73.40161064692906, 74.11150114876884, 18.87270048686436, 0.25078901275992393, 0.25666851869651247, 0.14369403943419456, 0.25230065307446886, 0.1843673147793327, 0.28099478621567997, 0.23166504608733313, 1.1566065826586314, 0.5852491014770099, 0.4255230708846024, 31.4807904788426, 61.240567752293174, 39.18782615661621, 70.40573501586914, 17.2664315700531, 0.5903445737702506, 0.1947142274252006, 0.11769834506724562, 0.27876894708190647, 0.24969920409577234, 0.14750189653464726, 0.2455622303698744, 0.19597220420837402, 0.19511970638164453, 0.23032719216176442, 0.0904312932065555], [0.09335581984903131, 0.006292049714829773, 0.0673923355394176, 0.040450692110295804, 0.06898486401353564, 0.010070333290579063, 0.13666805358869688, 0.018674632301554084, 0.12256312902484622, 0.05815041038606848, 6.899764435631888, 58.86054570334298, 30.266443388802664, 21.313343831471034, 46.546420097351074, 33.92577471051897, 2.90355252793857, 0.47667790736470905, 0.46810079046658104, 0.10581968711423022, 0.12887894654912607, 0.08245883921959571, 0.06953070472393717, 0.2559843382665089, 5.071077602250235, 22.526346445083618, 73.1384059361049, 81.19475187574113, 75.00059958866665, 72.23199258531842, 68.85495962415422, 66.46489742824009, 67.24710478101457, 68.08912917545864, 71.78256920405796, 73.21557262965611, 74.12999030521938, 74.93478625161308, 74.44557053702218, 73.91665281568254, 70.76266397748674, 70.19760172707694, 67.87084456852504, 68.28094114576066, 57.692279066358296, 50.607972213200156, 58.3470390864781, 68.39824758257184, 68.312666620527, 67.93355206080845, 63.2823098046439, 66.22175911494664, 58.2852418082101, 53.90110567637852, 52.073093686785015, 61.26467105320522, 61.07694462367466, 64.45060770852226, 62.953583581107004, 58.48264013017927, 54.58622932434082, 58.12210157939366, 58.172684465135845, 58.517818859645296, 61.02798066820417, 62.1776157106672, 57.61791249683925, 57.60916124071394, 64.10392733982631, 58.39373098100935, 61.98546327863421, 63.15540790557861, 59.70010348728725, 50.82796607698713, 49.856100695473806, 62.64733478001186, 59.71237400599888, 58.31274972643171, 62.62544795445034, 59.49990504128592, 53.06586272375924, 48.539997237069265, 45.48322411945888, 44.946882247924805, 47.2870911189488, 59.48452172960554, 58.207689489637104, 56.18103545052664, 56.63573251451765, 55.84134496961321, 57.00453247342791, 57.83671474456787, 48.902925968170166, 42.867647715977256, 43.139704431806294, 42.56285456248692, 49.6279114314488, 59.10186358860561, 56.342806884220664, 57.218547412327354, 58.60146822248186, 54.07308748790196, 56.20053209577288, 50.91001040594918, 55.63821785790579, 49.6632638658796, 49.842183453696116, 57.43811396190098, 57.10060174124581, 55.95695604596819, 55.653767926352366, 55.770348276410786, 57.86071729660034, 55.618026392800466, 53.721758774348665, 53.56891924994332, 51.31019190379551, 49.58368962151663, 46.97041654586792, 43.65210975919451, 46.712290968213765, 55.3984181540353, 54.6676344190325, 53.99282537187849, 50.64181341443743, 46.987613337380544, 47.166088240487234, 45.96463353293282, 47.29137120928083, 47.34779405593872, 50.688321181706016, 53.768502780369346, 54.082613468170166, 57.20333433151245, 59.17520877293178, 58.231160504477366, 56.47829328264509, 54.678647313799175, 56.214574405125205, 58.62147208622524, 61.19123554229736, 64.26354830605644, 66.44806889125279, 61.62208638872419, 57.39739056995937, 54.54759734017508, 65.36642892020089, 64.02050031934465, 65.96867792946952, 16.7043605191367, 0.6719304844737053, 0.15372132137417793, 0.18554906493851117, 0.04927621728607586, 0.12109690984444958, 0.03638726818774428, 0.2701912602143628, 0.248440575918981, 0.4153304435312748, 0.4148420611662524, 18.465174743107386, 41.47586447851998, 25.473009722573416, 34.17025402614048, 20.123070512499126, 0.4736300366265433, 0.17230369496558393, 0.10790694904114519, 0.08579499234578439, 0.14803263305553369, 0.060210266283580234, 0.10134612609233175, 0.02255869736628873, 0.07583111271794353, 0.031123542958604436, 0.10124356552426304, 0.07237844834370272, 0.05027725999908788, 0.04716794112963336, 0.0204599715902337, 0.049462705850601196, 0.019688282195212584, 0.12532682929720196, 0.0520451015659741, 0.11385063081979752, 0.13191856630146503, 12.407767346927098, 67.45694037846157, 41.30087757110596, 27.70835985456194, 42.717521463121685, 41.60829019546509, 3.1675436879907335, 1.1412092660154616, 0.7822018159287316, 0.20844267361930438, 0.016784900400255407, 0.08576354224767004, 0.2536962367594242, 0.7829605266451836, 6.27432016815458, 25.589911426816666, 72.0649231501988, 83.67960139683315, 79.02819238390241, 77.65501989637102, 73.23852252960205, 70.28562150682721, 72.20966802324567, 73.08361939021519, 72.83630520956856, 78.41235269818986, 75.45838165283203, 76.39441517421177, 77.36293152400425, 76.92263112749372, 74.29684434618268, 73.97562912532261, 71.27776868002755, 72.3060325895037, 58.8139580317906, 52.83482122421265, 60.733912059238975, 68.62599563598633, 70.53798702784947, 69.76021262577602, 65.6192182813372, 67.47119808197021, 59.06250899178641, 58.149943011147634, 55.903072765895296, 63.49156175340925, 63.92571299416678, 66.97003146580288, 65.66249166216168, 61.805220058986116, 59.01038360595703, 60.84283896854946, 61.45762252807617, 62.73548657553536, 61.78319426945278, 65.50917966025216, 59.43710722242083, 62.0255126953125, 66.28049223763603, 60.63388579232352, 63.5042005266462, 63.29758194514683, 61.314017159598215, 52.624058042253765, 53.66434580939156, 65.60370990208217, 60.56942040579659, 61.48820155007498, 66.51516069684709, 58.51139872414725, 55.811498982565745, 50.005316734313965, 48.56689371381487, 46.70038522992815, 50.96586002622332, 63.10990415300642, 59.47649656023298, 57.948837825230186, 58.824303899492534, 59.62585503714425, 58.835907391139436, 59.42405155726841, 54.353888511657715, 46.697522572108674, 44.59386164801461, 46.50659997122628, 49.9625575201852, 58.116664613996235, 59.38369641985212, 58.91862569536482, 60.18246132986886, 56.155535561697825, 58.882015636989046, 52.34296866825649, 56.34060083116804, 53.58482715061733, 51.79509278706142, 58.038407053266255, 57.00063453401838, 57.79012707301548, 57.57270751680647, 58.69344847542899, 57.95483064651489, 57.48064041137695, 55.77204711096627, 54.643892424447195, 53.824043205806184, 50.887359278542654, 50.81159612110683, 44.5851103918893, 49.512679031917024, 58.450754846845356, 56.03928525107247, 56.025166511535645, 53.888400895254954, 50.11594942637852, 49.71221739905221, 48.114736216408865, 48.21554068156651, 49.70473766326904, 52.6325626373291, 55.08546781539917, 56.41434901101248, 59.78011199406215, 60.17501980917794, 61.033282143729075, 56.13461800983974, 56.37542520250593, 58.458780016217915, 61.33427810668945, 64.32235785893032, 67.01353413718087, 67.14006778172084, 62.41310405731201, 62.08387756347656, 58.71462658473423, 69.9541368484497, 65.97227014814104, 68.8764990397862, 18.34086799621582, 0.6461919684495244, 0.10711095961076872, 0.28394402510353495, 0.07423587688910109, 0.0732786539675934, 0.17412617217217172, 0.2535282314888069, 0.20302044600248337, 0.34409023768135477, 0.3594466250921999, 20.224034786224365, 51.977806091308594, 24.095081193106516, 40.077153887067524, 29.413538115365164, 0.2402942744748933, 0.1454584069017853, 0.1169706569718463, 0.09403917246631213, 0.12022649869322777, 0.028520971004452025, 0.057867047376930714, 0.011771317105740309, 0.09434165659227542, 0.06726856396666595, 0.07336271088570356, 0.22064007339732988, 0.1518343019166163, 0.09034879691898823, 0.11744479010147707, 0.2176466483090605, 0.07714393548667431, 0.21183889066534384, 0.20370834480438912, 0.2516320246670927, 0.2854374535381794, 11.863443732261658, 84.00594438825334, 43.0420891898019, 34.04221262250628, 62.148329053606304, 55.49052694865635, 7.656345094953265, 3.7699544600078037, 2.4946199910981313, 0.2403990945645741, 0.20252223845039094, 0.18533129590962613, 1.0138873266322272, 1.9167708839688982, 6.5929028902735025, 28.588882480348857, 81.84176118033272, 92.51411778586251, 86.85287843431745, 83.62320286887032, 79.32267788478306, 75.45989636012486, 75.59764439719063, 76.83123452322823, 77.36949062347412, 79.7782643181937, 80.04910509926933, 79.18047605242047, 80.39577851976667, 79.66839940207345, 76.42830153873989, 77.66164152962821, 74.68463025774274, 75.5825320652553, 62.408143043518066, 56.90026780537197, 63.39173003605434, 74.0299848828997, 74.07251480647496, 74.03318800245012, 67.45036738259452, 72.92283807482038, 63.44699600764683, 61.55775996616909, 57.59709916796003, 66.75121879577637, 67.99102061135429, 69.2152098246983, 69.28713757651192, 64.48104776654924, 63.340806688581196, 63.986551421029226, 65.30356856754848, 63.816640172685894, 65.19912324632917, 67.05702986036027, 63.741773332868306, 63.953269549778526, 70.05269704546247, 63.25970731462751, 65.17671530587333, 67.1273386819022, 66.61272035326276, 56.60450383595058, 54.77236114229475, 69.67088658469063, 65.05610847473145, 65.01301574707031, 68.0123793738229, 62.29786123548235, 57.7184841973441, 54.125838211604524, 51.12368835721697, 51.084785393306184, 51.72583661760603, 64.60430186135429, 62.53298132760184, 59.33940165383475, 60.91537816183907, 61.49626840863909, 61.10782241821289, 61.9282101222447, 53.768836293901714, 46.41429315294538, 49.0962769644601, 47.69383519036429, 55.28566626140049, 62.948685101100374, 60.638617515563965, 62.64809908185686, 62.63178471156529, 58.39156314304897, 61.17232254573277, 55.434687750680105, 58.5725428717477, 54.60412788391113, 55.228677136557444, 61.584281240190776, 59.73921489715576, 61.408943448747905, 58.470904622759136, 61.13349601200649, 62.191908155168804, 59.61609281812395, 57.44544431141445, 56.77104868207659, 57.158719948359895, 54.96315172740391, 53.86963728496006, 46.492019176483154, 49.97927836009434, 60.653306007385254, 59.25427232469831, 59.62173475537981, 56.579525062016074, 53.765775612422395, 52.694005557468955, 51.80783578327724, 52.09103740964617, 52.99771479197911, 56.8391375541687, 58.84857395717076, 58.19009665080479, 64.278486933027, 64.95384488786969, 64.04608358655656, 59.494436808994834, 59.11976909637451, 60.77848475319998, 64.21903814588273, 67.17896379743303, 69.5753071648734, 71.00218227931431, 66.37616198403495, 65.04062788827079, 62.38757637568882, 74.72898755754743, 71.00269644601005, 74.7072674887521, 23.18287651879447, 0.9964911001069205, 0.4426377868013722, 0.43574362673929756, 0.21560803055763245, 0.15839502987052712, 0.41736895271709984, 0.4856577483671052, 0.6168666077511651, 0.7062577881983348, 0.3549005761742592, 23.568228823798044, 63.47143977028983, 34.25261102403913, 53.19130897521973, 36.683299337114605, 0.3962617367506027, 0.18408304931862013, 0.301458479570491, 0.12930943630635738, 0.288945452443191, 0.15929334238171577, 0.20851581969431468, 0.19913971424102783, 0.34415195722665104, 0.0894910404458642, 0.16402859400425637], [0.0502225259718086, 0.08334235966737781, 0.03679514237280403, 0.01746162712307913, 0.07004297830696617, 0.018645925181252614, 0.07516941893845797, 0.019738400488027504, 0.07529848986970526, 1.9655203138078963, 33.73968458175659, 45.70895372118269, 22.23862327848162, 31.153717926570348, 56.857765674591064, 18.79277535847255, 0.35100459094558445, 0.26203605639083044, 0.29380281322768753, 0.18672189914754458, 0.2817049952489989, 0.21358759754470416, 0.1155834464090211, 0.29213410562702585, 1.270720213651657, 33.65927307946341, 74.04993316105434, 74.06876972743443, 70.18237127576555, 67.14671720777238, 69.14826393127441, 70.21056011744908, 71.69456332070487, 73.24180902753557, 73.9433616910662, 74.94562544141496, 72.46393735068185, 73.41540282113212, 72.05004705701555, 76.1349208014352, 72.81860814775739, 68.49703012193952, 66.72640677860805, 67.94503048488072, 65.67203848702567, 51.74027497427804, 52.84957572392055, 60.956553186689106, 67.69562489645821, 67.26189749581474, 65.31379631587437, 63.088350840977256, 55.73771258762905, 52.742583887917654, 55.379095213753835, 58.33718654087612, 60.88340950012207, 63.52580942426409, 62.2537054334368, 59.40447848183768, 57.759593214307515, 60.5010918208531, 58.81105368477957, 61.26050213405064, 59.752715247017996, 58.92333657400948, 58.118669169289724, 58.79505198342459, 59.3891716003418, 61.02092824663435, 61.9850046975272, 54.527030672345845, 53.02120317731585, 50.33973700659615, 61.97932801927839, 60.42725331442696, 57.96441568647112, 62.079687799726216, 57.37504516329084, 54.3291459764753, 53.55856990814209, 46.25539132526943, 43.4549685205732, 45.54327392578125, 57.24113948004586, 57.5505497114999, 56.39062091282436, 58.617754799979075, 57.70616851534162, 57.40150390352522, 57.557991232190815, 56.9358286857605, 55.20884697777884, 53.25920329775129, 46.01381288255964, 41.92763982500349, 44.65950128010341, 45.161004883902415, 54.337654045649934, 55.1005870955331, 56.59607914515904, 54.27148287636893, 55.23103952407837, 54.18145159312657, 51.90741389138358, 59.58240795135498, 50.903868198394775, 48.81909247807094, 55.93378380366734, 55.81188808168684, 55.80141714641026, 55.93490593773978, 53.78836420604161, 55.2752092225211, 52.2939248085022, 51.03648151670183, 50.505583558763774, 50.8777950831822, 49.762612683432444, 44.71693161555699, 50.21782391411917, 53.69170781544277, 53.15930209841047, 54.618406432015554, 49.7921598979405, 48.66596460342407, 47.16139473233904, 45.967107091631206, 46.157164641789024, 47.88352101189749, 49.44440255846296, 54.24363102231707, 54.91893686567034, 56.52961267743792, 58.301417214529856, 57.022083623068674, 54.29893173490252, 55.14873811176845, 56.14197267804827, 58.75309876033238, 62.83991800035749, 62.87713950020926, 64.88249383653913, 60.39405482155936, 56.690185546875, 58.67746067047119, 65.29225690024239, 64.16287585667202, 62.7299280166626, 18.897715738841466, 1.7831264095646995, 0.09402746773724045, 0.42496357804962565, 0.04982043290510774, 0.2540190837212971, 0.08397919870913029, 0.773204712995461, 0.41252793105585234, 0.21427065160657677, 0.7991049917680877, 14.995228733335223, 56.44318750926426, 24.78858436856951, 21.26869123322623, 19.175707953316824, 2.921963951417378, 0.11838257978005068, 0.08866045251488686, 0.03707186591678432, 0.11402540786990098, 0.031004239538950578, 0.161135483533144, 0.09551103705806391, 0.07086980036859002, 0.021733737883291075, 0.14465693490845816, 0.027022516321656958, 0.09128298357661281, 0.01639965535806758, 0.020870073066492165, 0.08282560096787554, 0.05050283557336245, 0.08565643549497638, 0.0204642141304378, 0.06291557861758129, 3.1107847222260068, 47.59170709337507, 53.97499629429409, 33.60357979365757, 24.32425536428179, 54.62318679264614, 25.221589156559535, 0.7195040402667863, 0.3539528527430126, 0.30895314312406946, 0.23802650187696728, 0.1530320519315345, 0.26585072598287035, 0.15898766235581466, 0.38691711532218115, 1.113804810813495, 38.47154678617205, 77.64238112313407, 78.66778932298932, 76.518906048366, 72.75337845938546, 73.20282963344029, 73.5343212400164, 74.72128895350865, 74.64181545802525, 76.2323831830706, 77.19197109767369, 74.43792057037354, 75.89292199271065, 74.59570721217564, 76.2285269328526, 74.26074845450265, 73.46446405138288, 70.41112681797573, 72.03496251787458, 69.71550096784318, 54.970805168151855, 53.54731730052403, 62.81922626495361, 68.44288281032017, 69.81435298919678, 67.83125373295375, 64.46184294564384, 58.56663690294538, 53.27194281986782, 58.262896401541575, 62.640733991350444, 63.683359827314106, 65.13371290479387, 64.19495568956647, 62.078673362731934, 60.57239423479353, 63.87247589656285, 61.06058856419155, 64.58664648873466, 62.64156777518136, 60.99663734436035, 62.62935979025704, 60.677805355616975, 61.62722110748291, 63.09741129193987, 63.32914066314697, 58.29018892560686, 54.71939155033657, 53.451710087912424, 65.53245612553188, 61.45396777561733, 61.253227370125906, 63.206372942243306, 57.615133217402864, 57.184744426182334, 56.56546538216727, 46.49935647419521, 45.52329785483224, 49.68321214403425, 60.87051364353725, 59.99957084655762, 60.169794763837544, 61.24772439684187, 56.32586022785732, 59.980025563921245, 60.38101305280413, 61.106717654636924, 57.07368789400373, 56.98142623901367, 50.76561989103045, 45.30309207098824, 47.39053242547171, 47.941236223493306, 53.692750045231406, 58.687848227364675, 57.337271281651084, 56.00706992830549, 57.480838435036794, 56.396120412009104, 53.62892389297485, 61.80255195072719, 54.96061910901751, 52.39723757335118, 57.336510453905376, 58.71822575160435, 56.79124362128121, 57.40919555936541, 54.963103090013774, 56.08272886276245, 54.359506130218506, 53.58985764639718, 53.00929396493094, 53.62202433177403, 51.699645383017405, 47.79751968383789, 53.27398559025356, 59.206843921116416, 55.5445213999067, 56.534017835344585, 51.98697076525007, 51.0853134563991, 49.71242931910923, 49.23588364464896, 47.57143919808524, 49.577988624572754, 50.7277626310076, 56.24969407490322, 55.85649899074009, 59.10462897164481, 58.95913369315011, 59.23515088217599, 55.42867061070034, 57.227427210126606, 59.678591864449636, 61.797535351344514, 66.44711698804582, 64.00175407954625, 63.62767696380615, 62.185091972351074, 59.04830687386649, 60.199644224984304, 68.74988201686314, 66.58514295305524, 67.49152156284877, 21.346260922295706, 1.5274817730699266, 0.07891318840639931, 0.46125138657433645, 0.04697175969236663, 0.09150501380541495, 0.1129437687673739, 1.2760271174567086, 0.3594011632459504, 0.21747724525630474, 0.6797676725046975, 15.888259853635516, 67.64308261871338, 27.984109537942068, 27.767284052712576, 34.02771520614624, 2.985048166343144, 0.06414654292166233, 0.09313013910182885, 0.04273052566817828, 0.05482888647488185, 0.04798147069024188, 0.16859080562634127, 0.08095454065395252, 0.05404666452003377, 0.04722068704930799, 0.031402115510510545, 0.09300640824117831, 0.21155602298676968, 0.10564094063426767, 0.08036156890115567, 0.28190760580556734, 0.07373612227716617, 0.16455899125763349, 0.08392605584646974, 0.13157073568020547, 3.728215762547084, 58.89994893755232, 67.85653127942766, 33.90297072274344, 45.07594156265259, 75.81708240509033, 32.44348076411656, 1.2042258445705687, 1.0172766361917769, 3.4790546638625006, 0.4523474600698267, 0.41780758489455494, 0.5003952032753399, 1.0263808390923908, 0.989908116204398, 1.728655789579664, 42.808230195726665, 83.67473765781948, 86.67340646471295, 83.9374976839338, 78.25985363551548, 78.36269392286027, 79.73861789703369, 80.08696583339146, 79.68789604731968, 79.75746835981096, 81.0256952558245, 76.47435419900077, 79.34543323516846, 78.40705122266496, 80.57524354117257, 78.00273554665702, 76.55951132093156, 70.56151362827846, 73.63270773206438, 73.33299023764474, 56.730742182050435, 57.87041003363473, 66.26020349775041, 72.98203672681535, 74.16065270560128, 69.7245683670044, 68.05139350891113, 62.63174302237374, 56.542772565569194, 60.74968447004046, 64.52764238630022, 65.42288303375244, 68.70159203665597, 64.90312303815568, 65.50311388288225, 65.47291006360734, 67.12522642953056, 64.32688808441162, 68.54714747837612, 66.6596484865461, 64.466171673366, 66.4236181804112, 64.11279324122837, 64.18644414629254, 67.40735803331647, 66.41191741398403, 61.596002851213726, 57.41910021645682, 56.208282811301096, 66.34633336748395, 65.84169960021973, 62.478132247924805, 65.76504707336426, 63.02412864140102, 62.07081495012556, 58.72154699053083, 50.944925103868755, 48.43825476510184, 49.58743470055716, 64.8048894064767, 63.96075970785958, 62.69186578478132, 64.57400076729911, 62.56720815386091, 63.849845613752095, 62.57075868334089, 63.850255557468955, 58.51023142678397, 58.345378467014854, 51.444549219948904, 45.857499258858816, 49.29881000518799, 49.67665651866368, 57.864816733769004, 60.93896034785679, 60.432770184108186, 58.53239618028913, 59.986765316554475, 57.81723199571882, 56.029300689697266, 63.91588824135916, 57.21058477674212, 53.729262828826904, 60.894012451171875, 60.624700273786274, 59.88120133536202, 58.98984473092215, 57.92540502548218, 58.56774861471993, 56.45741047177996, 56.4995756149292, 55.746773038591655, 56.73177746364048, 54.83771589824131, 48.47570555550711, 54.72031913484846, 59.57981627328055, 58.02124152864729, 61.23985208783831, 55.73738949639456, 55.23853663035801, 53.178513867514475, 50.92597041811262, 52.64005626950945, 53.569825989859446, 55.14657722200666, 59.43567589351109, 59.028164046151296, 61.93887560708182, 62.800618989127024, 61.06380558013916, 57.69959551947457, 59.84487615312849, 62.11391462598528, 62.73903710501534, 68.72803688049316, 65.13832650865827, 68.86103929792131, 64.39347961970738, 63.110432216099326, 64.14284420013428, 74.7290153503418, 70.62747982570103, 73.89149338858468, 26.985083648136683, 2.2749952503613065, 0.6348041423729488, 0.9558903872966766, 0.11987007781863213, 0.36266529666525976, 0.2228430730423757, 2.3032166617257253, 0.6336653434804508, 0.5272398942283222, 0.5549626637782369, 19.38911839893886, 81.70249148777553, 35.55693728583199, 34.74320248195103, 50.51670067650931, 5.380995920726231, 0.25560598714011057, 0.10595818968223673, 0.11520797227110181, 0.15732815569000586, 0.1796266348766429, 0.22990375916872705, 0.11829932353326253, 0.20859379693865776, 0.1100802831351757, 0.18393192599926675], [1.4207209646701813, 0.22493913556848252, 0.12500076607934066, 0.12520995842558996, 0.030017239108149494, 0.035625015518495014, 0.04206547314035041, 0.1104924524469035, 0.5072257710354668, 19.77701895577567, 48.61127880641392, 29.200589724949428, 20.112257378441946, 42.78095851625715, 59.3338291985648, 5.834376301084246, 0.15134950221649238, 0.30900658454213825, 0.22688475331025465, 0.06734844789441143, 0.17810535936483315, 0.3317322422351156, 0.04871495008202536, 0.17784519546798297, 2.6513563692569733, 38.50356755937849, 72.27414035797119, 67.91981547219413, 70.85247639247349, 71.24654347555978, 73.13762773786272, 72.92265047345842, 71.16508279527936, 74.31379795074463, 76.61316531045097, 74.77854210989815, 71.12634658813477, 73.21541976928711, 73.01733357565743, 70.84298515319824, 70.70638356889997, 70.01224463326591, 69.16402244567871, 71.08513682229179, 66.89639445713588, 58.424692153930664, 49.07713120324271, 52.23480258669172, 58.6846798488072, 61.194522040230886, 62.81213215419224, 59.130017689296174, 53.30709375653948, 50.13866656167166, 52.60488101414272, 60.02284731183733, 62.28901617867606, 61.98391383034842, 60.04922962188721, 60.292145592825754, 56.804455620901926, 61.57464408874512, 57.96452685764858, 61.71339961460659, 56.82447338104248, 61.52918202536446, 55.977564402988975, 55.43989889962332, 59.99175412314278, 62.360943930489675, 53.80273308072771, 54.40225144795009, 53.077188287462505, 56.32409538541521, 60.34695298331124, 58.641559328351704, 60.23719923836844, 56.708626065935405, 56.18402317592076, 54.23508126395089, 46.25453322274344, 44.13166052954537, 48.01466826030186, 57.63029766082764, 57.0977668762207, 56.317390373774934, 61.10779462541853, 60.64298793247768, 57.00592558724539, 55.537871973855154, 58.89654432024275, 56.75212178911482, 56.65284940174648, 55.75563893999372, 57.64111948013306, 46.207570348467144, 44.89762994221279, 47.19087593896048, 47.34606742858887, 56.70627062661307, 56.649344035557334, 54.76552758898054, 53.912584100450786, 57.38987956728254, 48.250378949301584, 54.79543958391462, 56.91504314967564, 54.05943080357143, 51.20177568708147, 54.4019387790135, 53.40114804676601, 54.55079698562622, 54.2595910344805, 55.661904266902376, 52.73006323405674, 50.43319027764456, 49.43832288469587, 50.963782514844624, 49.74071543557303, 49.090506485530305, 54.138001033238, 55.375228541237966, 53.82497773851667, 52.51841068267822, 47.68171405792236, 46.16128492355347, 48.541195801326204, 48.46422365733555, 47.47844450814383, 48.254520075661794, 47.67619718824114, 49.073115144457134, 51.915432112557546, 54.1838869367327, 56.62581048692976, 52.73619154521397, 53.497099195207866, 52.27156203133719, 56.59955324445452, 61.362508637564524, 63.70445455823626, 63.58579322269985, 63.448517663138254, 58.131651878356934, 57.44684784752982, 60.18060616084507, 62.60532597133091, 67.0199751172747, 54.26825543812343, 14.655637264251709, 3.4019046894141605, 0.35559007631880896, 0.2424561141857079, 0.010981881475475217, 0.1653655929757016, 0.09767405741981097, 1.163516783288547, 0.19732992563928875, 0.22232894705874579, 0.29017786202686174, 11.509119476590838, 55.9421911239624, 36.27208062580654, 17.969530207770212, 17.564504078456334, 13.659958669117518, 3.644308013575418, 0.07184945565781423, 0.08208627599690642, 0.10669699218124151, 0.0928242758714727, 0.12351239951593534, 0.5734709820577076, 1.9787588034357344, 1.8142286092042923, 2.4205328694411685, 0.5392284680690084, 0.06338731651859623, 0.05516801488452724, 0.12205534055829048, 0.056499449868819544, 0.015945550885849764, 0.07859061964388404, 0.10119536239653826, 0.6912945711186954, 29.920871257781982, 61.116306168692454, 41.21347270693098, 28.10151846068246, 35.382461071014404, 67.14485509055001, 8.222460865974426, 0.2601479377065386, 0.5393292712313789, 0.37277500703930855, 0.3295514035437788, 0.07471878347652298, 0.054173913584756, 0.16349314845034055, 0.07496959037546601, 3.41519963315555, 41.35923549107143, 76.99121679578508, 74.82342052459717, 74.48933723994664, 75.69422435760498, 76.0953369140625, 77.1270193372454, 74.90811211722237, 75.63453238351005, 78.87526253291539, 78.903534752982, 73.76737076895577, 75.57301303318569, 75.90802042824882, 73.1044361931937, 72.29518645150321, 70.4538790839059, 70.231522832598, 73.75253636496407, 68.36796733311245, 60.76904909951346, 51.99888692583357, 54.5717944417681, 60.10361317225865, 63.37539482116699, 63.014922278267996, 60.25220734732491, 53.96874291556222, 52.740475109645296, 57.28924880708967, 63.56195395333426, 65.069977079119, 64.16657229832241, 62.410456793648855, 64.56834493364606, 60.81844384329659, 63.12339060647147, 62.402952739170615, 63.85338224683489, 60.64725412641253, 63.57660075596401, 59.571964808872764, 56.97489493233817, 63.18088000161307, 62.56819479806082, 56.56758458273751, 57.00611318860735, 55.498187337602886, 61.161163738795686, 61.83903694152832, 61.76879760197231, 62.38638823372977, 58.63893290928432, 61.12226077488491, 55.67842708315168, 46.63841772079468, 46.44357633590698, 51.87407990864345, 61.88119166237967, 59.02442591530936, 56.65391942432949, 60.37118829999651, 63.05585411616734, 59.36575617109026, 59.07044383457729, 59.66246509552002, 58.347963196890696, 59.274262292044504, 59.777916363307405, 60.952828952244346, 47.82052516937256, 45.18213088171822, 51.845071179526194, 47.26277937207903, 56.37770421164376, 57.62081684385027, 57.004848616463796, 57.364490849631174, 58.13906908035278, 52.193377426692415, 55.86916903087071, 59.488676752362935, 55.843811580113, 54.50197546822684, 55.74748870304653, 56.91014814376831, 56.092077663966585, 55.72786699022566, 56.65603862489973, 54.4438259942191, 52.618440423692974, 51.30135726928711, 54.73578235081264, 52.29362951006208, 50.37925836018154, 54.66923597880772, 56.88124016353062, 55.27916622161865, 53.98758295604161, 49.83402974264962, 49.46541043690273, 49.15289783477783, 50.52928386415754, 50.36024114063808, 50.54091167449951, 48.71368483134678, 50.42699595860073, 53.49560185841152, 56.83824471064976, 55.79636928013393, 54.39527545656477, 54.467741693769185, 54.01609141486031, 57.96720538820539, 62.71146665300642, 65.73402336665562, 65.43809264046806, 63.71234771183559, 61.33512578691755, 59.015358516148154, 61.20598656790597, 65.31649916512626, 66.85874216897147, 60.183823176792686, 21.388615403856548, 4.241473112787519, 0.3164665071027619, 0.482058581496988, 0.025740315838317786, 0.1270755361765623, 0.07542365243924515, 2.2643940363611494, 0.09932079405656882, 0.20020219151462826, 0.23161898713026727, 12.241441369056702, 66.17578288487026, 41.10067217690604, 24.3153703553336, 31.773823806217738, 20.00301432609558, 5.152372394289289, 0.13996054977178574, 0.02541148250124284, 0.13580378996474401, 0.11400535037474972, 0.19103255069681577, 0.29814600731645313, 0.5620499891894204, 0.875924112541335, 1.4120683946779795, 2.303969455616815, 0.43293688020535875, 0.13561943200017723, 0.1951094740735633, 0.20817244026277745, 0.12639396132103034, 0.202723926199334, 0.16912000865808555, 1.2655139501605714, 33.76819998877389, 75.42410618918282, 47.59582390104021, 32.600044522966655, 59.49811240604946, 81.93410273960659, 10.659936700548444, 0.3260267126773085, 0.910872465797833, 1.3501600537981306, 0.9104493313602039, 0.21120721527508327, 0.4143092483282089, 0.4276467226445675, 0.3595905830817563, 4.30277316059385, 45.32820633479527, 85.13746547698975, 83.22718334197998, 81.53651291983468, 82.11183765956334, 83.39852591923305, 81.87989289419991, 79.11875520433698, 81.5283487864903, 84.31900242396763, 82.22037546975272, 77.25681863512311, 79.55117634364537, 80.60889366694859, 77.29923738752092, 76.48989731924874, 72.84352438790458, 74.87924930027553, 76.00498948778424, 72.34187834603446, 64.12550844464982, 55.934159006391255, 59.845230511256624, 63.260256222316194, 65.29805864606584, 66.80640833718437, 65.57365894317627, 57.175305298396516, 56.312349455697195, 58.80990028381348, 67.17463506971086, 68.00156797681535, 65.37954017094204, 65.30060863494873, 67.44328022003174, 64.02124377659389, 66.15467425755092, 64.72351905277797, 69.67119230542863, 62.32186031341553, 67.33461734226772, 61.20138686043875, 62.179123469761436, 64.353346824646, 66.97358894348145, 59.47664247240339, 59.4785601752145, 56.96864850180489, 62.99405683789934, 66.8039139338902, 64.40201200757707, 65.66750131334577, 62.650913102286204, 63.31198556082589, 58.31755787985665, 51.998515197208945, 50.24061747959682, 53.192215715135845, 63.80592605045864, 62.39563628605434, 57.815161432538716, 64.64462225777763, 67.16457407815116, 61.87966305868966, 60.4560466493879, 63.80815642220633, 61.09639957972935, 62.64736952100481, 62.006078583853586, 62.482891763959614, 49.8348183631897, 48.287485803876606, 52.59669256210327, 51.33935349328177, 60.46401623317173, 58.23395715441023, 59.51531614576067, 58.437865938459126, 60.146289008004324, 54.82938848223005, 60.29523059300014, 60.295473779950825, 56.27300180707659, 56.83759157998221, 58.15145771844046, 56.24050160816738, 60.152111598423545, 56.812703132629395, 60.49076679774693, 56.621794428144185, 55.38116577693394, 55.62910182135445, 58.32861246381487, 55.0818304334368, 52.42713219778878, 58.070622376033235, 60.79591083526611, 58.04553937911987, 59.22386005946568, 51.36371735164097, 52.030143397195, 53.39347376142229, 54.03910384859358, 51.37564740862165, 53.32085118974958, 52.968688692365376, 53.13463599341256, 56.05526263373238, 59.647616795131135, 60.708488600594656, 57.34676946912493, 58.17504685265677, 57.82472562789917, 60.36018235342843, 66.0142720086234, 68.53988661084855, 68.36730030604771, 68.11888831002372, 63.832273619515554, 63.59022617340088, 65.35223375047956, 71.81978375571114, 74.12015860421317, 71.03844492776054, 29.15996013368879, 6.036122024059296, 1.1019986271858215, 0.6278814566986901, 0.07221127767115831, 0.5411175095609256, 0.31889237836003304, 3.799172503607614, 0.2630738621311528, 0.6235392668417522, 0.24507653500352586, 15.6005106312888, 75.77015427180699, 52.682395117623464, 34.628626687186106, 41.937624386378694, 33.76903377260481, 6.77204829454422, 0.20780480998967374, 0.21680369068469318, 0.15879552837993416, 0.22684680963201181, 0.24127888306975365, 1.0228781870433261, 2.627777005944933, 3.5459753700665066, 4.045889139175415], [8.721249461174011, 5.119886091777256, 0.2373449813042368, 0.022939453899328197, 0.07629848763878856, 0.06785744415330035, 0.04391914260174547, 0.24201479500957898, 2.6548211319105963, 41.65527391433716, 52.731942721775596, 22.64775058201381, 22.24749265398298, 48.71726662772042, 41.500798089163645, 2.021173430340631, 0.17539731253470692, 0.8253176680633, 0.5874686166644096, 0.5072695229734693, 0.09985955764672585, 0.2393754023526396, 0.07510846613773278, 0.09727421708937202, 2.007576022829328, 43.97946718760899, 76.24922561645508, 64.82369123186383, 79.13666766030448, 73.7860336303711, 77.08637237548828, 73.15254552023751, 73.19660404750279, 72.94144535064697, 74.38403729030064, 74.84220845358712, 71.69850989750454, 71.52883488791329, 66.66797937665666, 69.04669516427177, 66.78140871865409, 72.85774735042027, 67.71502426692417, 68.45294380187988, 66.29033088684082, 61.836056164332796, 50.57806716646467, 48.88715703146798, 48.76552881513323, 52.80492312567574, 53.250775132860454, 50.79695626667568, 51.07604455947876, 50.84178951808384, 58.45370783124651, 60.725845200674875, 64.6117364338466, 63.50515242985317, 61.61605535234724, 61.115090233939036, 58.44943468911307, 61.67560141427176, 58.614683696201865, 58.29102965763637, 58.02202320098877, 58.86369323730469, 59.55300317491804, 56.44394138881138, 62.88537311553955, 53.18004594530378, 54.8702404158456, 57.25969117028372, 53.72613613946097, 59.84646034240723, 56.31364529473441, 57.594590868268696, 55.4726561818804, 59.22690337044852, 59.20085457393101, 49.408181599208284, 41.528410230364116, 50.69509220123291, 59.9574647630964, 57.935889857155935, 57.22888633183071, 54.676965849740164, 55.067465032849995, 53.32373816626412, 54.64010565621512, 53.98142337799072, 52.269293444497244, 50.38206543241228, 48.94958659580776, 54.099806785583496, 51.05051340375628, 52.855210712977815, 40.9133209500994, 49.16364669799805, 50.229326656886506, 48.953946590423584, 55.88629286629813, 56.11424936567034, 52.900745732443674, 53.78804111480713, 55.22865629196167, 50.00849553516933, 56.80049862180437, 56.636232784816194, 51.9594281060355, 51.882990973336355, 53.02174513680594, 52.92179530007498, 51.70488779885428, 53.3521180834089, 53.046077728271484, 50.351427350725444, 49.86219079153878, 50.072571822575156, 48.16376617976597, 48.49082136154175, 53.62008925846645, 51.806946413857595, 52.88736697605678, 50.850356646946494, 46.89498690196446, 47.9589923449925, 47.55228648866926, 47.937967096056255, 47.71448871067592, 46.979372773851665, 45.798005308423726, 45.04360812050955, 45.24076672962734, 44.909810134342735, 46.257823194776265, 48.000455720084055, 51.37252766745431, 54.64102976662772, 59.58046245574951, 59.76924501146589, 63.78367097037179, 61.421477999006, 62.12625462668282, 57.969779695783345, 56.807804652622764, 59.52195167541504, 65.1894930430821, 63.59452016013009, 31.17852646963937, 8.312677145004272, 2.723707092659814, 0.6383998351437705, 0.19621397980621882, 0.0576240707721029, 0.018028190292950188, 0.6157462650111744, 0.4399142286607197, 0.054823196958750486, 0.13834080525806972, 0.6132908367684909, 7.415166173662458, 59.932374817984446, 37.27038737705776, 38.18233149392264, 13.481905000550405, 16.540410825184413, 18.808012757982524, 0.1498314022485699, 0.08115667623600789, 0.0914676875940391, 0.08984613139182329, 1.4436974631888526, 6.566091528960636, 9.951346380370003, 11.231102074895587, 9.921656727790833, 6.3771882482937405, 1.995380197252546, 0.04566482660759773, 0.01554004818068019, 0.0114315093129075, 0.015765789996034334, 0.04934443041150059, 0.11946691945195198, 4.816349693707057, 57.21673045839582, 63.0516574042184, 37.53689595631191, 25.713905504771642, 51.86225060054234, 53.4269050189427, 2.475122477327074, 0.3371896451073033, 1.6459008987460817, 0.8711972747530256, 1.4531930450882231, 0.10161110080246415, 0.12016519983964306, 0.12704543636313506, 0.11801382313881602, 1.395921215415001, 45.220575264522004, 85.01325253077916, 73.89421708243233, 79.85587569645473, 76.61921719142369, 78.16160610743931, 77.11665262494768, 74.01843697684151, 76.26579012189592, 77.13348116193498, 77.73962116241455, 74.21641199929374, 72.88979939052037, 71.27505193437848, 71.75124672480992, 69.87838758741105, 75.15817778451103, 70.19421100616455, 70.18959740230015, 68.31915623801095, 64.80844688415527, 53.23670155661446, 51.512790952410015, 53.043701444353374, 54.813689027513774, 53.82177461896624, 53.47412150246756, 51.80161714553833, 53.68097979681832, 59.3221492767334, 63.278641155787874, 64.33867917742047, 66.90925557272774, 65.04546383449009, 63.89393193381173, 60.588222231183735, 64.76729270390102, 63.03604480198452, 61.9927727835519, 60.99632467542376, 61.209794180733816, 61.706819670540945, 60.71995312826974, 63.29142584119524, 53.682786328451975, 58.921161787850515, 59.635575566973, 57.39716822760445, 61.743214334760395, 59.45488766261509, 61.269632066999165, 59.0323885508946, 62.43284388950893, 61.42634868621826, 49.59530700956072, 45.450313976832796, 56.67554221834455, 62.03173828125, 59.80648735591343, 58.21707303183419, 55.20274298531668, 55.68374245507376, 54.82114791870117, 57.403970514025005, 57.499737535204204, 54.567771434783936, 50.71536009652274, 49.56975500924246, 55.43783875874111, 51.668190887996126, 55.95611531393868, 42.6662472316197, 50.75861610685076, 53.22922876902989, 51.1195923941476, 56.98387547901699, 57.779058592660085, 56.01659938267299, 55.45594923836844, 57.238547801971436, 53.675900663648335, 56.58222443716866, 59.00219167981829, 56.06320095062256, 54.27039548328945, 55.443195819854736, 56.70310572215489, 54.53778648376465, 56.556853090013774, 55.79435082844326, 54.403846059526714, 52.00849975858416, 51.58885983058384, 51.162605217524934, 53.30869879041399, 56.70646170207432, 54.410134179251536, 54.622453757694785, 54.20307438714163, 48.33510875701904, 50.14334964752197, 49.75005381447928, 50.270821298871724, 49.39286776951381, 47.682356766292024, 49.06076124736241, 45.837269578661235, 47.43360778263637, 46.756214005606516, 46.90129239218575, 50.14607681546892, 52.0639602797372, 57.43162781851632, 61.48981353214809, 62.683611324855256, 64.66518197740827, 63.1641070502145, 63.50554847717285, 60.074653080531526, 57.922743865421836, 61.27885232652937, 65.48844623565674, 67.96191460745675, 51.41894858224051, 17.03420713969639, 3.7877570475850786, 0.22329607659152576, 0.3884425163269043, 0.10009978618472815, 0.20013060607016087, 0.61345053677048, 1.4068292358091898, 0.06457309717578547, 0.3129812255501747, 0.6728091058986527, 9.036854011671883, 67.59147834777832, 41.78527123587472, 41.29010786328997, 18.417800188064575, 29.749327182769775, 24.055137736456736, 0.18797703965434007, 0.04075294553435274, 0.0030231796970058766, 0.06808587296732835, 0.991610967687198, 3.696647490773882, 6.213500848838261, 6.815372484070914, 6.858548155852726, 14.02527584348406, 5.924063648496356, 0.4743682827268328, 0.14671115896531514, 0.18474989996424743, 0.21585774501519545, 0.25495228650314467, 0.3402576276234218, 7.250370970794132, 68.42654759543282, 74.15327371869768, 40.44372347423008, 34.975852489471436, 65.44971697671073, 61.69151973724365, 4.385327313627515, 0.555602983704635, 3.147696375846863, 1.618016583578927, 2.6989309021404813, 0.1844150565032448, 0.29677026399544304, 0.3174878651542323, 0.35574605794889586, 2.0830347623143877, 52.56063488551548, 92.30148206438336, 78.71537058694022, 86.81532342093331, 83.38116931915283, 84.60162734985352, 82.81394617898124, 80.3623298917498, 82.38062872205461, 80.8768926348005, 82.84426811763218, 77.64717538016183, 78.01487404959542, 72.63321631295341, 77.31222357068742, 72.2719725200108, 79.01878452301025, 72.14454950605119, 72.07346248626709, 70.96451609475272, 68.66395364488874, 55.86049420492989, 52.41602897644043, 54.68652657100132, 57.491660254342214, 58.14875486918858, 56.56521872111729, 54.24024030140468, 57.330156326293945, 63.5773720060076, 67.34432397569928, 69.50748579842704, 70.63210037776402, 67.23953124455043, 67.42233834947858, 64.32988275800432, 67.91479192461286, 66.0457820892334, 65.3396714074271, 64.43019390106201, 64.48625891549247, 65.87664209093366, 62.83411625453404, 68.83191244942802, 56.947790009634836, 60.15088871547154, 62.962630135672434, 60.45841598510742, 66.12729835510254, 60.92039476122175, 61.30559594290597, 61.02017784118652, 63.955284527369905, 63.15867355891636, 54.19571624483381, 47.16489315032959, 57.400729179382324, 64.15762996673584, 64.3511928830828, 62.74587413242885, 60.15234088897705, 60.60634313310896, 57.33668763296944, 60.4837977545602, 59.30859334128243, 56.20537846429007, 54.46774864196777, 52.79923949922834, 59.08770315987723, 54.630617891039165, 58.34340517861502, 45.86063289642334, 54.48416723523821, 53.73258754185268, 54.15668821334839, 58.94870444706508, 59.75677299499512, 56.105001313345774, 56.77724647521973, 59.786073548453196, 55.61665064947945, 59.69696290152413, 59.88196563720703, 56.25796243122646, 58.109772000994, 56.944024085998535, 58.2699418749128, 56.85690757206508, 57.59415660585676, 58.30587100982666, 55.074187414986746, 53.503821577344624, 55.35607235772269, 53.76278788702828, 54.29259845188686, 59.8238856451852, 57.098076071058, 58.88063294546944, 57.815554005759104, 51.23599556514195, 52.74221215929304, 53.38661936351231, 53.524186747414724, 52.73289809908186, 51.06552151271275, 52.21778992244175, 49.29051733016968, 49.95112425940377, 50.095751013074604, 50.52888086863926, 52.6155812399728, 54.528187547411235, 60.03636850629534, 65.08183765411377, 63.98013823372977, 67.43544960021973, 65.81747817993164, 67.47653429848808, 63.00206116267613, 61.46261133466448, 66.17330932617188, 71.73907348087856, 76.0679679598127, 67.16166973114014, 24.432869604655675, 3.0044177898338864, 0.9198159916060311, 0.7995388742004121, 0.259054817791496, 0.36006102498088566, 1.4792814680508204, 2.872847135577883, 0.11732558506940093, 0.7849623135157994, 0.7417840904423169, 12.358884164265223, 77.74184458596366, 53.42350387573242, 52.280493940625874, 26.73947525024414, 47.37090029035296, 28.25205292020525, 0.46367001107760836, 0.12410565625344004, 0.1427531556359359, 0.13114447998149054, 2.359783466373171, 10.356951815741402, 15.086250134876796, 16.079316207340785, 16.62963264329093], [16.29441680227007, 15.333819661821638, 3.9209275245666504, 0.3132891718830381, 0.49139375771795, 0.2868941053748131, 0.416556610592774, 0.07383912389299699, 14.207800677844457, 55.28874431337629, 29.450169018336705, 12.864567978041512, 27.21986848967416, 48.24508094787598, 40.85906594140189, 2.936187131064279, 0.21552967333367892, 0.38893811830452507, 0.31977783941796845, 0.399289142872606, 0.14787163026630878, 0.17730307312948362, 0.02166294462845794, 0.20734837305332932, 2.23777505329677, 44.986928190503804, 61.69172123500279, 72.72975458417619, 78.0981343133109, 75.15434237888881, 75.27640833173479, 76.1133952822004, 69.84418160574776, 74.48334789276123, 73.08973380497524, 76.29964174543107, 69.42398929595947, 69.22509711129325, 62.27124268668038, 64.08354132516044, 64.43156269618443, 68.52572618212018, 69.77762481144497, 67.52196162087577, 66.33983680180141, 60.41587216513497, 52.27871172768729, 49.56221273967198, 52.57839100701468, 51.802787917000906, 52.25506700788225, 51.72793844767979, 50.308904375348774, 53.56867953709194, 56.09099721908569, 59.5480352129255, 62.15449210575649, 62.089033126831055, 65.10439150674003, 58.42884022848946, 59.76309585571289, 59.576015608651296, 62.90730857849121, 59.85481902531215, 57.70822518212454, 56.82675586427961, 58.74165507725307, 59.225840296064106, 55.65953145708357, 52.24004847662789, 62.320324761526926, 52.39635515213013, 57.501960958753315, 59.25083991459438, 56.581154414585654, 58.28584630148751, 58.00171709060669, 57.99022477013724, 50.83693272726876, 41.57664809908186, 49.24631289073399, 59.135729108537944, 58.31000518798828, 52.868724959237234, 49.624069077628, 49.19693204334804, 47.342325823647634, 50.21454783848354, 53.61768518175398, 51.92311334609985, 47.69525262287685, 44.86199957983834, 46.17656053815569, 49.46076556614467, 48.81786264692034, 53.14334556034633, 47.143468379974365, 39.67816053118025, 52.358511788504465, 51.28533124923706, 50.32196698869978, 55.530069146837505, 53.64306695120675, 54.627821241106304, 54.991187708718435, 52.40407460076468, 49.931106499263215, 56.09248760768345, 56.02111223765782, 56.09809480394636, 52.23574754170009, 54.037505762917654, 51.14197949000767, 50.26562752042498, 51.246119090488975, 50.673382554735454, 49.47797972815377, 47.69302919932774, 48.07000371388027, 50.41018826620919, 55.22749246869768, 52.52840914045061, 52.38138178416661, 47.18872199739729, 48.12060744421822, 47.17213664736067, 49.158414704459055, 48.855890137808665, 48.37629420416695, 46.76625067847115, 46.87494829722813, 44.75167955671038, 44.137281622205464, 46.4590881892613, 44.6239230292184, 47.49959135055542, 52.57109192439488, 56.30468211855207, 60.94181605747768, 61.24126257215227, 61.78205476488386, 62.507182666233604, 59.703132901872905, 57.379728249141145, 58.33655425480434, 60.14237717219761, 63.39198017120361, 44.928052629743306, 11.267530611583165, 8.866630094391958, 7.527888536453247, 2.447241961956024, 0.12503366145704473, 0.03767266117834619, 0.11845453163342816, 0.4096071363559791, 0.044031643707837374, 0.02806747891008854, 0.0766604792858873, 0.19241415656038693, 8.359827620642525, 69.01418454306466, 30.473680359976633, 35.635187898363384, 30.805561065673828, 19.04372344698225, 41.03447321483067, 5.653451723711831, 0.23992032025541576, 0.07380275441599743, 0.24673028769237654, 9.25949079649789, 25.195919036865234, 23.3401073047093, 29.886811188289098, 24.85018014907837, 15.213348320552281, 11.405729413032532, 1.478990620800427, 0.14638439007103443, 0.17051777722580092, 0.14614710637501307, 0.28882000488894327, 0.2447960286268166, 23.089829717363628, 65.10058389391217, 43.80074214935303, 23.220855372292654, 33.59645094190325, 61.43819536481585, 49.06054932730538, 3.9886607357433865, 0.16933149445269788, 1.0288939156702586, 0.26787867716380526, 0.85879028907844, 0.17516399148319448, 0.028211871162056923, 0.048054470880223174, 0.021215862993683134, 1.9459587463310786, 49.80197422845023, 74.60947854178292, 75.27497700282505, 82.29738235473633, 77.29840360369, 77.73746027265275, 76.60216631208147, 73.40316009521484, 75.06416170937675, 74.90342903137207, 77.66777678898403, 74.94797393253872, 72.78176879882812, 64.78599725450788, 66.98803424835205, 67.00347314562116, 71.45234216962541, 70.62879998343331, 71.41469682965959, 67.8226866040911, 64.61448792048863, 54.05907991954258, 52.689725467136924, 55.638099738529746, 55.65233312334333, 52.873091902051655, 54.98791510718209, 53.66612107413155, 57.0343610899789, 59.5012321472168, 62.51861245291573, 65.15491880689348, 65.91962364741734, 64.8957301548549, 60.10375908442906, 62.32178388323103, 60.60992840358189, 64.15533011300224, 61.25932094029018, 59.072229521615164, 60.13503987448556, 63.19383839198521, 60.3868009022304, 57.533526624952046, 57.24814326422555, 62.57848508017403, 55.884184088025776, 61.77450207301548, 59.02797644478934, 59.014469146728516, 61.24349989209856, 60.696850367954795, 59.77364322117397, 50.55473858969552, 44.322291306086946, 52.9206349509103, 61.700455120631624, 58.82703454153878, 52.93113020488194, 51.90226180212838, 51.51870386941092, 50.21337359292166, 53.453527041843955, 56.22396142142159, 51.97413049425398, 51.10686329432896, 49.08015019553048, 49.359742232731406, 50.43384688241141, 51.45560032980782, 53.900810377938406, 51.164606298719136, 42.203636169433594, 53.84257057734898, 53.90977355412075, 50.87315021242414, 56.71713760920933, 55.652343545641216, 57.45589787619454, 57.44430480684553, 54.22834151131766, 50.251046725681846, 55.71762187140328, 56.61233792986189, 57.863402775355745, 54.36010020119803, 54.30560200554984, 55.296078136989046, 52.818142073495046, 54.09224019731794, 54.15003183909825, 53.82985537392752, 51.069283962249756, 50.834570339747835, 53.78636659894671, 56.28295162745884, 54.15227958134243, 55.963115624019075, 50.21573250634329, 49.77276747567313, 50.247385025024414, 51.856407165527344, 51.65547915867397, 48.44481386457171, 48.493930680411204, 47.312448569706504, 45.85262162344796, 47.74679783412388, 47.70534488133022, 46.17210674285889, 49.22531543459211, 54.592611244746614, 59.07817023141043, 63.962385586329866, 63.86315836225237, 64.12042236328125, 63.671950885227744, 59.88599559238979, 58.36882863725935, 60.17021860395159, 61.296889850071494, 64.0363005229405, 59.52668339865548, 31.900979314531597, 12.915364520890371, 12.337317824363708, 2.658712123121534, 0.13491129928401538, 0.00870606314856559, 0.18107336653130396, 0.7153863097940172, 0.48730392860514776, 0.13917058573237487, 0.09385151682155472, 0.23900769065533364, 10.142652000699725, 76.13289887564522, 36.205172947474885, 42.41807494844709, 38.65090411049979, 30.457643917628697, 52.74198634283883, 6.777432714189802, 0.176659387669393, 0.03295279194467834, 0.19291727670601436, 7.202396265098026, 21.02218130656651, 19.82969672339303, 20.074365377426147, 18.66309939111982, 27.493780374526978, 23.56615478651864, 6.1306657280240735, 0.8841887776340757, 0.7489918693900108, 0.7695920839905739, 1.1963982645954405, 0.3509346746972629, 28.925536598478043, 81.29296466282436, 49.16531426565987, 23.08056082044329, 43.942419392721995, 67.13999829973493, 58.95667403084891, 4.801845329148429, 0.3776365747409207, 2.523860616343362, 0.8831696723188672, 1.6384874965463365, 0.5130629635282925, 0.5010867661663464, 0.1534094123968056, 0.26153839166675297, 2.7052125079291205, 56.223478521619526, 79.29701818738664, 80.17116410391671, 87.7769888469151, 82.78268623352051, 82.62569168635777, 82.42784867967877, 78.44304983956474, 81.19689886910575, 80.63129465920585, 84.07869897569928, 76.67788778032575, 75.45114857809884, 68.6911141531808, 69.98233958653041, 68.98292459760393, 75.48881476266044, 75.74218082427979, 74.50324753352574, 70.81337887900216, 67.82466684068952, 57.01779658453805, 54.974578039986746, 58.99424988882882, 57.69362701688494, 55.9568726675851, 57.71712929861886, 55.84195988518851, 62.02061421530587, 61.98552581242153, 66.76544175829206, 66.53895827702114, 68.79228687286377, 68.7652097429548, 63.011225836617605, 65.79402800968715, 64.14049570901054, 69.24025113242013, 63.01357432774135, 63.259019442967, 62.938380922589985, 66.59475925990513, 64.59074592590332, 58.676932607378276, 60.17840358189174, 68.02653980255127, 60.901127406529014, 64.9057286126273, 62.724258286612375, 61.669021470206125, 63.74290588923863, 62.37786974225725, 64.36982100350517, 54.69474628993443, 47.46028191702706, 53.50885902132307, 64.85247067042759, 63.54665402003697, 58.51670714787075, 54.390109470912385, 55.88800212315151, 52.91533694948469, 56.166124616350444, 59.317292485918315, 56.10642221995762, 54.3442166192191, 49.07488693509783, 49.30567135129656, 54.7225147656032, 53.227297169821604, 58.05849082129342, 51.16418593270438, 44.0910587310791, 56.40630994524275, 55.302227292742046, 54.6580285344805, 58.198761054447715, 57.18439701625279, 57.71457583563668, 60.43949604034424, 57.32635218756539, 51.21811090196882, 56.92904029573713, 58.34512833186558, 59.60420445033482, 56.710144247327534, 57.79981633595058, 57.403817653656006, 53.61396789550781, 56.9783273424421, 58.32012176513672, 54.6729393686567, 53.901109150477815, 54.6312849181039, 55.84411382675171, 59.90750026702881, 59.1246953691755, 58.979651723589214, 53.042134625571116, 53.091251441410606, 51.83387415749686, 55.35488074166434, 53.498659065791536, 52.41090815407889, 51.286012172698975, 50.10212598528181, 49.2485328401838, 49.80004262924194, 51.022838728768484, 48.08647441864014, 50.854747908455984, 55.89229958398001, 61.730554716927664, 68.27129009791783, 67.51739665440151, 67.30599076407296, 67.59532070159912, 63.362158502851216, 62.09343133653913, 64.1456651687622, 66.30373396192277, 69.61379323686872, 71.49609497615269, 48.39490147999355, 20.902337040219987, 11.672214542116437, 2.5971708425453732, 0.6367309646947044, 0.09680621113095965, 0.43653390290481703, 1.4496675942625319, 1.3874697089195251, 0.39655049411313875, 0.38824457409126417, 0.38766505090253695, 13.704598239489965, 87.58672632489885, 46.4148142678397, 51.92862326758248, 52.23198161806379, 44.132591588156565, 61.1362544468471, 8.681616936411176, 0.2392015073980604, 0.3145760271166052, 0.6217470658676965, 13.196169018745422, 35.54706736973354, 35.46443591799055, 41.824080399104524, 37.5996173449925], [22.297184433255875, 21.5945200579507, 9.130590421812874, 2.82378351688385, 4.920409824166979, 3.567213407584599, 1.9467905759811401, 0.3233355070863451, 26.435053825378418, 57.3853736604963, 21.674288851874216, 14.316355858530317, 31.736341748918804, 34.66577523095267, 40.94423695972988, 2.6272324408803667, 0.3009288694177355, 0.10268681629427842, 0.21458600754184382, 0.3243434301444462, 0.20894675728465828, 0.21036163850554399, 0.2718808395521981, 0.13202886895409652, 3.684563704899379, 47.1203864642552, 54.558724880218506, 82.65343584333147, 69.95025280543736, 76.03782667432512, 73.20925671713692, 75.01920686449323, 69.56478759220668, 72.38940402439663, 69.21041556767055, 73.65681798117501, 70.2129155567714, 71.49380207061768, 63.98262568882534, 60.583504404340474, 62.5702097756522, 66.75074631827218, 69.08237416403634, 68.19005175999233, 66.75653416769845, 60.653048924037385, 57.71129281180245, 50.11479949951172, 51.59837538855416, 50.69723572049822, 51.8322309085301, 50.006567410060335, 52.43542834690639, 55.586297443934846, 59.80634839194161, 61.31855433327811, 60.81581047603062, 60.84543064662388, 57.16303825378418, 57.347064767565044, 58.92149530138288, 56.69153697150094, 54.94621549333845, 59.62170696258545, 57.23518487385341, 56.779799938201904, 56.30949027197701, 58.869446345738, 56.91995552607945, 60.07330513000488, 57.1192124911717, 54.83588852201189, 59.54501969473702, 55.489818232400076, 59.79440443856375, 57.26110512869698, 58.60725607190813, 51.05551610674177, 41.58942583629063, 46.86433492388044, 55.00793286732265, 58.19326850346157, 53.99393013545445, 49.39922884532383, 49.20162902559553, 49.22150434766497, 51.46027299336025, 54.23605401175362, 52.69363382884434, 54.63333463668823, 53.654409885406494, 55.45646687916347, 51.89101961680821, 51.60702589579991, 51.994811807359966, 52.326174872262136, 53.4198317527771, 45.32088640757969, 44.73715782165527, 57.48440286091396, 50.972287109919954, 50.77628537586757, 56.829066140311106, 53.17085347856794, 53.049044609069824, 54.21900313241141, 47.68502834865025, 52.53439153943743, 53.3300575528826, 55.004163469587056, 55.24854898452759, 52.42380748476301, 50.98300470624651, 52.08431850160871, 52.30983618327549, 51.30500507354736, 49.056196280888145, 45.0127546446664, 49.35748406818935, 53.72655650547573, 51.620991774967735, 51.74843563352312, 51.369963782174246, 48.62238202776228, 47.550935064043315, 48.57765647343227, 49.508461475372314, 50.05257143293108, 46.59378596714565, 48.017673356192454, 47.79890584945679, 47.08125768389021, 45.77438838141305, 45.697596890585764, 47.52716875076294, 52.09261812482561, 55.23387091500418, 59.52204895019531, 59.24492004939488, 60.715089389256065, 61.07921668461391, 59.19938155582973, 57.57161317552839, 56.52994966506958, 55.47667224066598, 62.273646763392854, 54.85324512209211, 23.050233670643397, 8.33055659702846, 10.232120479856219, 14.27268295628684, 5.344512666974749, 0.5539135400738034, 0.049145107357097526, 0.2649026768548148, 0.097076023795775, 0.030663828698119948, 0.034964790767324824, 0.13676580334348337, 0.45638221928051537, 9.85620903968811, 66.45713629041398, 40.0524982043675, 28.5280544757843, 48.55745111192976, 27.68703235898699, 50.74920129776001, 18.535594735826763, 0.3190216528517859, 0.08978203018861157, 1.4981241141046797, 20.221972908292496, 42.77641092027937, 30.161963326590403, 38.81104619162423, 35.337242194584434, 26.024250268936157, 23.068206923348562, 8.35747218132019, 1.971285798719951, 1.740919360092708, 1.5359105893543787, 0.6928616613149643, 0.2443217597901821, 41.05647815976824, 68.69524138314384, 29.340505599975586, 18.111263036727905, 35.81188406263079, 43.30892086029053, 49.64792224339077, 3.173278123140335, 0.4542341674012797, 0.08358757543776717, 0.11758687533438206, 0.5148604299340929, 0.5956456150327409, 0.1471230432923351, 0.21528502074735506, 0.08886857956115689, 2.8650488683155606, 54.23832259859358, 63.502526010785786, 80.94702080317906, 74.24244689941406, 77.4375968660627, 76.39655521937779, 76.59597546713692, 72.24210916246686, 75.45968791416713, 72.61802060263497, 76.08592210497174, 72.24322782244, 73.11984034946987, 64.5430326461792, 63.06046077183315, 64.22051811218262, 70.17272022792271, 69.950989314488, 70.04508181980678, 68.83483764103481, 63.78615147726876, 58.97347477504185, 52.573336192539756, 53.15401104518345, 53.016742433820454, 55.8235957963126, 51.39796849659511, 54.39660256249564, 60.865087100437705, 62.29738875797817, 62.94430078778948, 62.87517316000802, 62.10916205814907, 61.13468415396554, 61.134350640433176, 59.166113580976216, 59.41515786307198, 57.637377875191824, 61.208765847342356, 60.64350209917341, 59.66256237030029, 60.674768992832725, 59.285726819719585, 60.646823338099885, 63.17787837982178, 59.154704638889854, 56.62460844857352, 59.404374258858816, 57.74725668770926, 61.197016443525044, 59.02691337040493, 59.99000317709786, 54.272681440625874, 46.396328585488455, 51.42560495649065, 57.04421363558088, 60.110477992466514, 55.21163320541382, 53.304060867854524, 53.933008330208914, 53.58194017410278, 54.80727931431362, 56.47631304604666, 55.3070319720677, 57.76870925085885, 57.76867798396519, 57.13852500915527, 55.24103103365217, 54.092181137629915, 53.0652026448931, 53.490752015795024, 55.84465231214251, 48.74434723172869, 46.405760765075684, 56.23790645599365, 54.41429615020752, 51.30065202713013, 58.734019007001606, 55.4656662940979, 54.642853668757844, 56.77715614863804, 52.403668131147114, 53.98194101878575, 55.21270670209612, 56.78173153741019, 58.117460182734895, 55.134230273110525, 52.96823705945696, 53.53250026702881, 57.048837661743164, 53.26938935688564, 52.4536326272147, 47.58070462090628, 50.000498158591135, 55.96315383911133, 54.118851797921316, 56.569321632385254, 54.85089315686907, 51.025513785226, 49.76432194028582, 49.42259216308594, 50.67518561226981, 50.740613324301584, 48.05571474347796, 50.44044072287423, 48.48029831477574, 49.314294065747944, 47.534968103681294, 47.352633476257324, 49.814380237034385, 53.98521362032209, 55.82909876959664, 61.62249633244106, 61.13229397365025, 63.69249670846121, 63.05056653703962, 60.825524057660786, 59.273275647844585, 57.06893185206822, 57.36851385661534, 61.55018642970494, 63.84682314736502, 40.64521428516933, 12.924787146704537, 11.23646695273263, 17.042953184672765, 5.407000856740134, 0.39719317534140175, 0.06267788101519857, 0.4687948503664562, 0.3651667024408068, 0.28826395901186125, 0.0028240589308552444, 0.2487562032682555, 0.3700625497315611, 12.305567162377493, 74.38992936270577, 47.49670784814017, 37.673400265829905, 63.607999665396555, 38.427637645176475, 64.5388776234218, 22.47909869466509, 0.18873311765491962, 0.09067058536623206, 1.8134588790791375, 19.21704626083374, 37.06903205599104, 37.20696769441877, 41.603374344961985, 37.160268851688926, 41.668055125645225, 37.632339886256624, 22.059404918125697, 9.727681262152535, 8.253131951604571, 5.608421317168644, 3.228799658162253, 0.9012929626873561, 48.457522119794575, 82.17203685215541, 36.45015948159354, 23.29291340282985, 48.31519521985735, 50.819152287074495, 59.03495938437325, 4.11966598033905, 0.48141907581261223, 0.4353060802178723, 0.3818768486380577, 1.195298495037215, 1.5242090629679816, 0.32644083616989, 0.537591027362006, 0.19526628351637296, 3.9689400110925948, 63.047036852155415, 70.88041509900773, 86.018691607884, 78.20868710109166, 81.12832014901298, 81.20374979291643, 82.40897042410714, 77.24787630353654, 78.89013167790004, 78.00319412776402, 81.57544367653983, 76.84085777827671, 77.8031415939331, 70.47022124699184, 65.89571489606584, 67.74746540614537, 72.60917554582868, 74.16306373051235, 74.02286297934396, 73.44582203456334, 66.77223014831543, 62.92567266736712, 55.973294734954834, 54.606229713984895, 56.042523111615864, 59.34756578717913, 55.28925848007202, 54.34901435034615, 64.93243053981236, 65.04172570364815, 66.42663369859967, 64.96611540658134, 64.1901683807373, 62.060872077941895, 63.79272447313581, 62.96347781590053, 63.01588807787214, 62.87734794616699, 63.15444905417306, 61.895046370370046, 63.72820350102016, 63.92207908630371, 62.95015811920166, 63.46627031053816, 65.4834018434797, 62.714301518031526, 59.73907593318394, 64.09722927638462, 60.05811636788504, 63.83998611995152, 61.473909105573384, 64.63078144618443, 56.33784587042672, 48.90751872743879, 52.99600206102644, 58.70553139277867, 65.0957340512957, 57.001450947352815, 56.27743475777762, 54.198968001774375, 56.0574825831822, 57.05847133908953, 58.392640113830566, 57.02017634255545, 59.67313058035714, 60.65358393532889, 61.7641909463065, 56.339697565351216, 58.2767128944397, 56.59493964059012, 56.40004614421299, 57.95248910358974, 49.26777935028076, 50.29167284284319, 58.72435406276158, 54.73217970984322, 55.018782479422434, 58.8554596219744, 56.38210242135184, 55.77551078796387, 59.224638257707866, 51.389755725860596, 56.82398700714111, 55.25500038691929, 58.987155778067454, 61.03508172716413, 59.19533770424979, 54.70289305278233, 56.267123631068635, 59.316847801208496, 56.57398039954049, 55.95752579825265, 51.58143220629011, 53.22477497373308, 58.2955390385219, 54.909945896693635, 59.06542028699602, 59.55066858019148, 55.17547130584717, 52.986239842006135, 53.4624137878418, 53.1842565536499, 54.074404171534944, 51.706975732530864, 52.43916995184762, 51.81093120574951, 52.66841186795916, 49.57574783052717, 49.47894205365862, 52.196215765816824, 57.20269857134138, 59.317181314740864, 63.23235920497349, 64.3540346963065, 65.11297253199986, 66.84039197649274, 63.5001288822719, 63.35981695992606, 62.01094232286726, 61.57859761374337, 68.09172780173165, 72.97422695159912, 53.46365751538958, 26.43086232457842, 20.608905928475515, 20.49120170729501, 5.8867939455168585, 1.0182807594537735, 0.23285622788327082, 1.2054269058363778, 0.6817133852413723, 0.7740824116127831, 0.12899862655571528, 0.49823816759245737, 0.4600849577358791, 16.432053668158396, 84.84061064038957, 56.845297132219585, 46.62270436968122, 66.9045307976859, 48.940269061497276, 76.51662009102958, 30.02534784589495, 0.3389255819576127, 0.41122356961880413, 4.99471993957247, 27.575677054268972, 56.21848276683262, 57.84772069113595, 65.25110271998814, 61.41874040876116], [29.75097737993513, 26.872324807303293, 16.102412019457134, 9.66603250162942, 8.741208161626544, 6.592049998896463, 2.002361399786813, 2.437449778829302, 41.93226037706648, 48.60000535420009, 29.953687599727086, 21.528216872896465, 56.54013919830322, 51.93467514855521, 38.767112731933594, 4.292145890848977, 0.4306881608707564, 0.2763831636735371, 0.3267364874482155, 0.5513976950730596, 0.198586586064526, 0.34959692933729714, 0.12698864298207418, 0.17552295007875987, 3.488960406609944, 49.96427025113787, 62.6094879422869, 78.61826256343296, 71.53198937007359, 74.32452596936906, 71.4584287915911, 73.22717612130302, 67.59147139957973, 72.31833090100969, 66.5211430958339, 74.35727977752686, 69.42897115434918, 70.9950395311628, 63.7517648424421, 59.50041920798165, 60.58055141993931, 67.04550279889787, 68.01269899095807, 68.75034059797014, 64.49484688895089, 60.89440849849156, 54.46845041002546, 50.38075917107718, 48.04128680910383, 49.482006209237234, 49.662186895098, 52.04588801520211, 58.083535603114534, 60.89826474870954, 60.523701259068076, 59.60904734475272, 63.6044282913208, 60.645065443856375, 59.179085867745535, 56.595829010009766, 57.49177142551967, 57.326949732644216, 55.8076114654541, 52.916660581316265, 55.65398679460798, 56.99068471363613, 56.527493476867676, 57.9679662159511, 59.85909216744559, 57.80252960750035, 56.3738305909293, 56.04908568518502, 57.51041691643851, 55.68725824356079, 58.56405912126814, 57.539151191711426, 56.272414684295654, 48.32835163388933, 49.74424859455654, 51.51431955610003, 57.504479680742534, 54.00430032185146, 51.82391391481672, 54.18639523642403, 54.828002316611155, 55.40464721407209, 57.100556577954976, 57.99111066545759, 57.8034849848066, 54.55471576963152, 56.053053106580464, 54.99176440920149, 51.52306038992745, 50.19308137893677, 50.35288994652884, 51.25417900085449, 55.04074573516846, 53.976504053388325, 44.296093123299734, 44.597770009722026, 58.96136406489781, 50.2254182951791, 55.86532320295061, 54.89697708402361, 52.2378910609654, 52.97556740897042, 54.251451219831196, 49.23017569950649, 54.492977551051546, 54.25691597802298, 54.93255533490862, 51.791604791368755, 51.861416816711426, 52.16538660866873, 51.438452175685335, 49.536528723580496, 45.59591000420706, 46.02654545647757, 48.8022153036935, 53.393192359379356, 52.67085415976388, 49.981373241969514, 47.52896138599941, 44.89492014476231, 46.325703620910645, 50.16208893912179, 48.87479966027396, 49.57990632738386, 47.0806427683149, 45.943274770464214, 43.61504806791033, 44.773896421704976, 45.24998351505825, 46.60019220624651, 46.8301671573094, 52.659250668116975, 56.161907059805735, 59.80671664646694, 61.5050231388637, 62.20726367405483, 59.74485683441162, 56.16556528636387, 58.95585414341518, 53.349133832114084, 60.407430103846956, 58.68619455610003, 39.93059206008911, 14.504198670387268, 5.3065546580723355, 7.526634386607578, 12.942868965012686, 9.966418760163442, 1.8848439114434379, 0.06801369719739471, 0.6789375799042838, 0.17123907352132456, 0.1867969451206071, 0.1536971926689148, 0.13396432224128926, 0.3710971256451947, 14.38044604233333, 60.48380470275879, 47.64198078427996, 30.806790896824428, 43.148785727364675, 23.191971710750035, 55.00262444359915, 32.363618169512065, 0.1667218352002757, 0.06550796915377889, 5.2246193289756775, 36.28787735530308, 31.765041283198766, 21.627094949994767, 25.35839397566659, 31.254574503217423, 40.06532457896641, 31.484000546591624, 20.34590792655945, 11.868236252239772, 6.542617474283491, 7.105669958250863, 1.7995465227535792, 3.5680510997772217, 58.9112606048584, 54.87138686861311, 40.54149852480207, 23.511368240628922, 55.87917791094099, 51.386128766196116, 48.14869553702218, 4.029873541423252, 0.3525581375828811, 0.23325577644365175, 0.23873896364654812, 0.9641389846801758, 0.5328442135027477, 0.4872074137840952, 0.09378265908786229, 0.10304811583565814, 3.510415358202798, 53.63724436078753, 66.60844721112932, 82.45974785940987, 73.38578959873745, 77.29142761230469, 72.60419368743896, 76.66549219403947, 70.41282912663051, 74.48197909763881, 69.66396617889404, 74.73181547437395, 72.3489168712071, 72.7445125579834, 64.91997936793736, 59.94425623757498, 64.24662249428886, 68.40386867523193, 69.39509173801967, 72.38002395629883, 66.68044444492885, 63.56172466278076, 57.95609521865845, 53.946310656411306, 50.72279119491577, 51.4244897706168, 52.56621081488473, 53.77016339983259, 59.622568539210725, 62.42005920410156, 63.60469927106585, 61.85485798971993, 65.9527040209089, 64.0192426953997, 62.756629943847656, 60.26232392447335, 59.235004970005576, 62.097315379551475, 60.201402119227815, 56.313996178763254, 57.26959582737514, 58.34684453691755, 60.51800373622349, 60.48248454502651, 63.21952588217599, 60.03732735770089, 58.1680326461792, 58.25802918842861, 56.91731868471418, 57.320543493543354, 58.75541945866176, 59.49914768763951, 60.01102147783552, 48.35387931551252, 52.35063253130232, 52.66901983533587, 60.53492954799107, 55.896923610142295, 53.71825688225882, 55.76411574227469, 56.400897298540386, 57.57618161610195, 58.54882172175816, 61.65066432952881, 59.23769392286028, 57.10052531106131, 57.99687419618879, 57.566666058131624, 54.328086376190186, 54.99027402060372, 53.17262874330793, 54.996992928641184, 55.027888093675884, 56.86272668838501, 45.97719587598528, 44.91274227414812, 59.52261870247977, 54.05587679999215, 55.33543620790754, 57.94615582057408, 52.363021169389995, 55.31814908981323, 55.16278736931937, 53.09530571528843, 56.523644174848286, 54.54860135487148, 55.9800066947937, 54.69804321016584, 52.56749275752476, 54.49403020313808, 54.40865421295166, 53.434270109449116, 48.85141202381679, 48.066286427634104, 52.71524620056152, 54.410808154514854, 54.62793241228376, 53.93761498587472, 50.881025995527, 49.39589023590088, 49.32520273753575, 51.686902386801584, 51.062012672424316, 50.811828885759624, 49.268706934792654, 49.11569717952183, 45.6361574445452, 46.06861332484654, 46.47782400676182, 48.655719484601704, 50.11654349735805, 54.89866549628121, 57.57974256787981, 63.09643159593855, 62.376361983163015, 63.95814718518938, 59.30948271070208, 58.846565927777974, 57.4948981148856, 54.291323457445415, 58.328994614737375, 61.02561828068325, 55.638287339891704, 28.251299040658132, 9.058979681559972, 9.452164343425206, 14.573645046779088, 9.997928840773445, 1.9307256894452232, 0.0052794825086104015, 0.8082205397742135, 0.15977607933538301, 0.24527550861239433, 0.09070514315473181, 0.25327462224023684, 0.24339789365019115, 16.485049315861293, 70.72507422310966, 56.96773828778948, 39.656377928597585, 51.648940903799875, 33.77571446555001, 61.80363586970738, 42.48653554916382, 0.25680821548615185, 0.13859525589006289, 5.84640189579555, 32.11977808816092, 50.12622233799526, 43.61172335488455, 42.21999222891671, 46.03878123419625, 54.98767539433071, 48.42845433098929, 38.348059926714214, 30.740317480904714, 11.3351582969938, 10.548498885972158, 4.005768937723977, 3.179856764418738, 72.38343552180699, 63.411497661045615, 56.07794502803257, 35.486145564488, 80.76085077013288, 70.33648232051304, 59.280932562691824, 4.794267450060163, 0.4262672338102545, 0.6184105191911969, 0.29793256734098705, 1.7797671726771762, 1.2449684526239122, 1.0082580915519168, 0.20056026801466942, 0.3723593364868845, 4.554856411048344, 61.115243094308035, 74.5534691129412, 90.03208923339844, 79.35560539790562, 81.0714213507516, 77.75701945168632, 80.28729629516602, 76.91274384089878, 78.5432220186506, 75.66237381526402, 80.53487450735909, 76.5102972303118, 77.78573635646275, 69.78922135489327, 63.01014191763741, 67.08211285727364, 72.32768317631313, 71.9395637512207, 74.97248717716762, 69.48878124782017, 67.98888751438686, 59.98545905521938, 57.86756822041103, 52.10827241625105, 55.92372281210763, 55.24886512756348, 57.1886110986982, 63.444133349827354, 66.09703895023891, 67.69459656306675, 66.11741106850761, 67.4333998816354, 66.57889652252197, 64.49183137076241, 62.80078574589321, 62.903924805777415, 64.88170174189976, 60.364768164498464, 60.40556103842599, 60.006539889744346, 62.30365603310721, 63.36911364964077, 64.76636164528983, 62.99457100459507, 63.7283216203962, 62.278468813214985, 62.68789141518729, 59.32727704729353, 60.77830410003662, 63.213335037231445, 62.01638971056257, 61.25137220110212, 53.82400846481323, 56.091358525412424, 55.75932495934622, 62.51331097739083, 61.04377392360142, 56.45749037606375, 59.89296463557652, 58.57089614868164, 60.575256892613, 60.473347663879395, 63.218532289777485, 62.54476547241211, 59.62279782976423, 59.54049641745431, 60.96455751146589, 55.04175322396414, 56.211041246141704, 52.78613519668579, 57.43357678822109, 58.132732323237825, 58.66816398075649, 47.80557264600481, 49.583922386169434, 60.51746872493199, 52.955198764801025, 59.54384544917515, 58.39805276053292, 53.46327189036778, 58.393598965236116, 57.22027403967721, 54.96586152485439, 59.37099511282784, 57.21714040211269, 59.04656982421875, 55.216576848711284, 56.16875103541783, 57.04203537532261, 57.66953761237008, 57.49278586251395, 51.2115135874067, 51.195140157427105, 54.23467132023403, 59.201452119009836, 59.35646642957415, 56.812112535749165, 54.46939189093453, 51.85443387712751, 51.633762563977925, 56.2514728137425, 52.312188148498535, 52.78092057364327, 51.05966418130057, 50.51926456178938, 48.98193046024868, 48.18474973951067, 51.943610531943186, 50.48407193592617, 53.37438358579363, 55.80756630216326, 61.77660042898995, 66.91857310703823, 67.35407229832241, 68.78023869650704, 64.18961947304862, 61.759507860456196, 62.59280531747, 59.117483139038086, 64.29436356680733, 67.47530446733747, 65.93761948176792, 40.92248214994158, 17.660067864826747, 20.139702762876237, 20.947392633983068, 10.746987206595284, 2.4936298727989197, 0.24790097773075104, 1.3001564741134644, 0.7149285972118378, 0.46887508034706116, 0.17285100131162576, 0.5219384187034198, 0.32181908988526886, 21.146474157060894, 81.68505150931222, 65.13679095676967, 50.19871636799404, 56.84697164808001, 42.36855166299002, 74.26059559413365, 50.01657976422991, 0.30207667925528114, 0.12407191949231283, 11.870156560625349, 42.39857135500227, 63.85565430777413, 58.11736985615322, 40.64370652607509, 58.15961837768555], [30.465693405696324, 45.33214248929705, 26.636242389678955, 17.725938524518693, 9.476377078465053, 7.300629462514605, 1.7876771539449692, 12.766833748136248, 51.016536712646484, 36.634394441332134, 17.052682399749756, 28.853957993643625, 97.09082671574184, 44.689548764910015, 42.296300819941926, 6.387538458619799, 0.5193597142185483, 0.325444122510297, 0.18310818448662758, 0.6271587897624288, 1.0368641508477074, 0.244876855718238, 0.28497699967452456, 0.1979307955397027, 4.819587554250445, 65.63961819240025, 74.6188725062779, 75.91275909968785, 72.79977852957589, 74.06421865735734, 72.72262573242188, 71.61438805716378, 69.97936575753349, 70.97891971043178, 68.45200579507011, 68.35355676923479, 68.78572082519531, 69.54285907745361, 63.77833475385393, 55.64009039742606, 60.43408339364188, 67.57762363978794, 66.4130916595459, 66.09099401746477, 65.93169961656842, 62.59695339202881, 58.43428066798619, 46.7393924168178, 49.30676221847534, 49.58427674429757, 48.453294140951975, 54.906155654362266, 59.40552765982491, 59.156629289899556, 63.25983933040074, 58.684158733912874, 62.006161962236675, 58.37203870500837, 56.430548736027305, 55.346098218645366, 56.533187525612966, 58.21288326808384, 55.85711738041469, 52.731025559561594, 55.066572189331055, 55.58772529874529, 57.84869691303798, 58.33300372532436, 58.60568577902657, 52.64317601067679, 54.40981456211635, 55.92979206357683, 56.261860370635986, 52.90598814828055, 57.87303992680141, 58.51934051513672, 52.91892569405692, 51.433866364615305, 50.800628389631, 54.34948682785034, 56.40930461883545, 52.30029630661011, 55.588107449667795, 53.07809155327933, 57.14274951389858, 53.55351161956787, 54.53612586430141, 56.786609172821045, 54.49377311979021, 51.01589053017752, 54.00928218024117, 53.28335176195417, 54.44640377589634, 53.17532811846052, 54.3956332887922, 53.77301563535418, 53.50992209570748, 54.80481617791312, 49.03585195541382, 44.05104752949306, 45.516651902879985, 56.06909302302769, 50.60082599094936, 51.80328818729946, 55.98924779891968, 51.46785347802298, 56.37487629481724, 50.087124824523926, 51.38615655899048, 52.16082164219448, 52.19748381205967, 51.544005734579905, 50.9318277495248, 51.980797290802, 50.6847254889352, 46.13036891392299, 48.375953742435996, 50.34613629749843, 52.60318217958723, 52.573363985334126, 50.32535423551287, 50.24437298093523, 47.23668193817139, 44.117232595171245, 49.467592171260286, 50.27059548241751, 50.85824980054583, 46.299953596932546, 45.35056216376168, 45.535853249686106, 45.344993182591026, 46.48240981783186, 47.80260576520647, 52.08436713899885, 52.627830914088655, 57.701777253832134, 57.88553278786795, 60.388795035226, 58.96264253343855, 60.70254094260079, 59.91191932133266, 58.20039735521589, 56.84540482929775, 52.030980655125205, 54.151376315525596, 49.580191203526084, 32.75007002694266, 12.522963268416268, 6.381605131285531, 6.849029558045523, 14.895919867924281, 15.539052077702113, 4.043184552873884, 0.13765802261020454, 0.4798361893211092, 0.1594751626253128, 0.05798406074089663, 0.19281375940356935, 0.3657270095178059, 0.6607614180871418, 13.557331170354571, 63.06881945473807, 52.503989696502686, 36.99509627478463, 37.65589427947998, 29.1644104548863, 49.30126966748919, 39.6535187448774, 0.16638886449592455, 0.07649896759539843, 15.607688120433263, 34.146758692605154, 19.184235130037578, 8.019659451075963, 8.432541387421743, 18.784216914858135, 48.72104297365461, 46.265959535326274, 33.329098156520296, 26.21727991104126, 10.330596429961068, 10.277118750980922, 1.5614894053765704, 20.364970309393748, 64.15519114903041, 44.41766227994646, 32.67180551801409, 33.10785361698696, 102.4752915246146, 53.522178718021934, 53.15081834793091, 7.250856910433088, 0.48046673834323883, 0.40729314195258276, 0.15736538012112888, 1.2045540383883884, 0.8085621414440018, 0.42179671941058977, 0.06144465718950544, 0.16319664221789154, 5.60816901070731, 67.695645741054, 75.28256443568638, 78.24837521144322, 72.60097667149135, 77.58952617645264, 72.02937616620744, 74.48897593361991, 72.2457778113229, 71.65006010872978, 69.82436534336635, 72.25559561593192, 71.88596534729004, 71.92213766915458, 65.36546312059674, 57.13029834202358, 62.754691396440776, 69.48079776763916, 69.79256343841553, 67.9209132875715, 67.4237140927996, 65.60479382106236, 61.77135453905378, 50.01401587894985, 51.07528373173305, 50.36121736254011, 50.341335092272075, 59.65745544433594, 60.825086321149556, 60.845708574567524, 64.72838973999023, 62.68732861110142, 61.70136533464704, 61.079723903111045, 60.591744967869346, 58.69610268729073, 59.485313824244905, 60.359341621398926, 59.35158879416329, 57.20358099256243, 57.58386632374355, 56.464223180498394, 61.46410519736153, 60.98555496760777, 59.12337521144322, 56.07189662115914, 56.374879768916536, 59.295905930655344, 58.27866186414446, 55.20172854832241, 59.41332353864397, 60.10693441118513, 53.23395701817104, 52.74742330823626, 52.106073311397004, 56.08588334492275, 59.9198819569179, 56.00456510271345, 58.27385023662022, 54.459157194410054, 59.54157338823591, 56.780828271593364, 57.13355704716274, 59.523876326424734, 55.49812132971627, 55.225529602595735, 56.91064493996756, 54.653762340545654, 56.75122894559588, 56.32451227733067, 56.33153690610613, 55.23874855041504, 57.05177327564785, 56.42029666900635, 49.870952469961985, 47.86441346577236, 47.501891204289024, 57.86438594545637, 55.587589808872764, 53.90435743331909, 57.07478223528181, 54.323858397347585, 57.08107730320522, 53.28641244343349, 51.04410369055611, 54.27055876595633, 55.21914073399135, 54.56210170473371, 55.0302609034947, 53.48327922821045, 53.12519686562674, 50.86698716027396, 51.45648969922747, 53.06552921022688, 54.33815084184919, 54.4216126033238, 52.067649773189, 53.11636223111834, 50.18828017371041, 48.428749629429404, 50.307334082467214, 51.718818937029155, 50.92197520392281, 50.270015307835166, 48.28475168773106, 47.508092471531455, 48.7892221723284, 49.06487805502755, 50.17103474480765, 53.33712387084961, 55.62288318361555, 60.174116543361116, 60.327769007001606, 62.809700284685405, 61.80908325740269, 61.25927925109863, 60.34215872628348, 59.03713417053223, 57.93209614072527, 56.060581479753765, 58.31079728262765, 58.421398707798545, 49.363129479544504, 21.551590612956456, 11.211809532982961, 7.341864415577479, 18.743396248136246, 16.87738456044878, 4.12148163148335, 0.21600060377802166, 0.40035465998309, 0.18989513601575578, 0.24920151223029408, 0.31649837110723766, 0.6723822802305222, 0.5220960559589523, 19.185174873897008, 71.98118346078056, 62.58119487762451, 44.08251244681222, 47.366748741694856, 35.333497115543906, 57.29838221413748, 52.55904722213745, 0.08556442614644766, 0.1344331085149731, 9.640697632517133, 48.294962065560476, 52.738338538578574, 38.23687832696097, 18.1116886138916, 34.25592878886631, 61.2934296471732, 74.19191265106201, 51.482100759233745, 57.359206744602744, 16.868112189429148, 15.873392445700508, 2.8370256977421895, 23.68286541530064, 82.58688599722726, 59.82545593806675, 39.982071263449534, 45.76783970424107, 111.98931394304547, 59.924724851335796, 65.05443395887102, 8.208705169813973, 0.3784091275717531, 0.7557650059461594, 0.3093967693192618, 2.2640841901302338, 2.189998588391713, 1.2055349286113466, 0.39194400129573687, 0.3839263772325856, 6.82032698392868, 76.14512075696672, 82.15885611942836, 84.63028172084263, 77.88218430110386, 81.8297894341605, 77.12385790688651, 79.1573246547154, 76.97952992575509, 77.46436132703508, 77.1847310747419, 75.69783047267369, 74.99659047807965, 76.72739369528634, 68.37429714202881, 61.667485918317524, 67.09748922075543, 73.08190318516323, 70.47084658486503, 71.58959688459123, 70.46457930973598, 68.32777200426374, 63.80995600564139, 50.949351106371196, 54.3211555480957, 54.79029791695731, 54.554958956582205, 62.23699501582554, 63.11788763318743, 64.32850006648472, 66.55042280469621, 64.17750181470598, 64.61660712105888, 63.52499648502895, 62.91706384931292, 61.229276929582866, 61.84036404745919, 64.81982108524868, 61.72663593292236, 59.79152093614851, 61.20682035173689, 60.22284426007952, 61.95475224086216, 64.9394760131836, 63.21190370832171, 58.40497316632952, 58.10953228814261, 63.32826519012451, 60.3996342250279, 57.88382353101458, 62.46102578299386, 64.49850858960832, 57.389737129211426, 55.70314877373831, 56.129552773066926, 57.32031420298985, 61.45232800074986, 57.087657247270855, 60.08218492780413, 56.15390968322754, 65.13996628352574, 59.46134948730469, 59.75666182381766, 63.94922569819859, 56.02637202399117, 56.0627041544233, 59.08908585139683, 57.83098248073033, 58.34583704812186, 59.36506829942976, 57.92376872471401, 57.189017568315776, 58.935989243643625, 58.10839973177229, 51.12324367250715, 48.23482888085501, 49.394333839416504, 60.04425471169608, 55.27393422807966, 58.76702989850725, 58.41873059953962, 54.207260676792686, 60.47687040056501, 53.698006357465474, 54.73612976074219, 55.02636643818447, 56.5682099206107, 57.35433953148978, 56.66049936839512, 59.553572927202495, 56.03555406842913, 53.058897154671804, 53.4459604535784, 57.25567511149815, 56.85266917092459, 59.23738125392369, 53.780071531023296, 56.84415762765067, 53.37651668276106, 49.40089641298567, 54.22138289042881, 54.620671544756206, 55.2565324647086, 51.36369998114449, 49.852953161512104, 52.575813225337434, 50.87967804500035, 50.61088350840977, 53.522772789001465, 56.44703333718436, 58.02518810544695, 62.51670864650181, 64.73113427843366, 64.56182752336774, 65.71690995352608, 64.11088248661586, 64.99567999158586, 63.9937983921596, 61.997810227530344, 60.5067754473005, 66.6009362084525, 65.09191949026925, 64.38974843706403, 39.24166079929897, 18.441363266536168, 16.464755364826747, 26.153842857905797, 19.279944828578405, 3.7889048031398227, 0.747574654008661, 1.018456635730607, 0.3829091989568302, 0.5478843493121011, 0.2672757852290358, 0.8632365390658379, 0.6773231008223125, 25.855806827545166, 81.28185449327741, 72.69342245374406, 52.37811265672956, 54.684365681239534, 43.407960483006065, 71.58749852861676, 64.65458597455705, 0.18366610312036105, 0.1897114294448069, 18.3227436201913, 54.90058319909232, 69.88351535797119, 42.53619432449341, 10.848778315952845, 30.506437642233713], [24.646844591413224, 42.973430565425325, 43.22695296151297, 28.73625898361206, 9.642929741314479, 5.665790855884552, 0.3795611986092159, 21.6963563305991, 44.073636123112266, 34.19763340268816, 17.759418419429235, 24.336756910596574, 50.066585949489046, 33.37983390263149, 45.45025839124407, 10.330856987408229, 0.5275619540895734, 0.2041447649576834, 0.2996752895414829, 0.42332651732223375, 0.6528214727129255, 0.6846055186220578, 0.2881470609988485, 0.16459992048995836, 11.800967267581395, 78.2604650769915, 75.42645468030656, 73.98243141174316, 69.5417890548706, 72.6710284096854, 72.35056359427315, 71.82761437552315, 69.6929679598127, 68.90413897378104, 65.85658958980015, 67.45616912841797, 65.9941291809082, 68.32335989815849, 57.82506956372942, 52.70494549615042, 60.085930006844656, 66.77643380846295, 67.14199243273053, 67.9404307774135, 65.54574802943638, 63.57364082336426, 62.53184182303292, 53.88102190835135, 47.61471605300903, 46.80722420556204, 50.59474631718227, 59.222741399492534, 61.506433623177664, 60.18014063153948, 60.9016763142177, 58.676988192967, 58.577580315726145, 57.393009730747764, 58.31354876926967, 54.89722374507359, 55.39700419562203, 55.724493639809744, 56.851557459150044, 54.05050931658064, 61.57314327784947, 57.64813368661063, 54.82621315547398, 57.376400062016074, 52.524733543395996, 55.93425280707223, 58.071376255580354, 55.19101790019444, 56.207327433994834, 55.247920172555105, 57.81646769387381, 51.354563099997385, 53.03930670874459, 52.64053569521223, 50.51345239366804, 57.1742387499128, 54.84426804951259, 54.91890907287598, 54.67728199277605, 55.81835338047573, 55.988969870976035, 55.63649123055594, 53.13004323414394, 55.096036025456016, 53.542787075042725, 54.092104707445415, 55.73001398359026, 52.70677982057844, 53.6466383252825, 52.549549034663606, 52.77893686294556, 53.151679924556184, 52.18930230821882, 54.02327585220337, 52.020853655678884, 46.75571026120867, 51.34169503620693, 48.341386454445974, 56.13365568433489, 51.791615213666645, 54.66270119803292, 53.53126696177891, 49.974709919520784, 53.09643479755947, 53.05827529089791, 49.83334534508841, 53.52580220358712, 51.29597241537911, 49.11188261849539, 49.090506485530305, 47.84697001320975, 52.555062430245535, 50.77182115827288, 50.44485977717808, 49.69637550626482, 51.22612912314278, 49.028354849134175, 46.50040912628174, 46.39941358566284, 49.934896741594585, 48.67042187282017, 51.149622508457725, 47.42690624509539, 45.66158437728882, 44.40254299981253, 46.146808351789204, 50.67163855688912, 51.422134331294465, 54.45765290941511, 54.63809415272304, 56.34710781914847, 57.32729714257376, 57.70279516492571, 58.73738193511963, 59.83146612984793, 60.65894794464111, 59.5780097416469, 54.617277349744526, 54.19919729232788, 41.42346811294556, 41.35920075007847, 38.99638591493879, 28.30894650731768, 13.507352777889796, 8.251772710255214, 8.540073445865087, 15.613333531788417, 17.047577210835048, 7.622385774339948, 1.189687498978206, 1.1078271887132098, 0.12078939777399812, 0.2403704332453864, 0.45685095127139774, 0.9830429702997208, 0.38211623579263687, 17.225145374025615, 61.086720739092144, 57.53906086512974, 36.56078175136021, 37.01618753160749, 39.50383717673165, 39.06729922975813, 42.39136607306344, 0.40250010628785404, 1.3363549602883202, 14.104809267180306, 23.84460210800171, 11.040655425616674, 2.6731113961764743, 1.1986352588449205, 14.079592517444066, 51.42384358814785, 65.19589233398438, 48.167361872536794, 46.40971776417324, 13.558481097221375, 11.092170238494873, 2.101175857441766, 30.950052329472133, 60.33117362431118, 44.38616262163435, 29.74634987967355, 30.99263436453683, 62.50624465942383, 39.27296938214983, 57.121592249189106, 11.585990003177098, 0.385458590728896, 0.5251050602112497, 0.049601252523383925, 0.6166823176401002, 0.26851454590048107, 1.3354235759803226, 0.08999134467116424, 0.35348778484123095, 9.59659915310996, 80.67148998805455, 74.77506106240409, 76.08508832114083, 71.35181563241142, 75.4795389175415, 74.10355240958077, 73.3015843800136, 72.78423540932792, 72.50451483045305, 68.95768179212297, 70.09988921029228, 69.25016621180943, 68.63342326028007, 60.66621576036726, 54.0359319959368, 61.19714151109968, 67.51014273507255, 70.52327074323381, 68.72583430153983, 69.20780304500035, 65.81032153538295, 64.64399691990444, 56.964569909232004, 49.204891204833984, 48.35602978297642, 51.062259333474294, 61.34621511186872, 64.3908462524414, 63.88612910679409, 62.955709729875835, 60.890538351876394, 61.88080256325858, 59.92986651829311, 60.45047419411795, 58.53827435629708, 57.82001822335379, 58.17603349685669, 58.48242473602295, 57.56085736410958, 61.28120081765311, 59.17097731998989, 58.8144166128976, 60.726984705243794, 56.43513454709734, 59.18542262486049, 59.668093136378694, 56.45548234667097, 57.803446769714355, 58.90527820587158, 58.22166926520211, 52.11508165087019, 57.513647828783306, 52.50868667875017, 51.77652372632708, 57.99828120640346, 55.85713822501046, 56.21375451769148, 56.8680351121085, 58.76978138514927, 59.098375592912944, 58.88456562587193, 54.75621700286865, 55.18466029848371, 56.628714833940776, 56.25252546582903, 56.959115573338096, 55.582746914454866, 56.473957606724326, 57.346654823848176, 56.87891946520124, 55.04396275111607, 54.32427528926304, 55.62053121839251, 55.33948353358677, 49.15132059369768, 55.44028799874442, 49.582327774592805, 58.64799336024693, 53.1448324748448, 54.9708433832441, 55.413061482565745, 52.41688013076782, 56.344231264931814, 53.51117277145386, 54.426014287131174, 55.343284198216026, 52.749744006565635, 52.91920362200056, 53.009005614689414, 51.85086250305176, 55.35592644555228, 53.25349187850952, 53.732889788491384, 52.928802558353965, 54.006523745400564, 50.382249559674946, 47.7591586794172, 50.13362216949463, 51.78146389552525, 52.06731973375593, 51.35057830810547, 48.427884578704834, 48.27937725612095, 47.44195604324341, 50.0570912361145, 53.291766030447825, 54.34553677695138, 56.32830251966204, 57.947826862335205, 60.64368970053536, 59.32207979474749, 60.38804462977818, 61.629069328308105, 62.694235120500835, 59.2582744870867, 59.4246768951416, 54.791611126491, 55.30721262523106, 50.45540714263916, 50.688887459891184, 50.770626068115234, 46.708577156066895, 24.71559180532183, 13.235892738614764, 11.274425830159869, 18.76895693370274, 21.003303050994873, 8.907329167638506, 0.894306766135352, 1.4225986067737852, 0.1914740734334503, 0.23535060403602465, 0.6204356476664543, 0.27363297981875284, 0.6022838045443807, 23.727632658822195, 70.56197220938546, 67.54124287196568, 45.094065938677105, 46.194518157414024, 45.13612338474819, 51.043645109449116, 55.526237215314595, 0.21761717274785042, 0.6823398630533899, 17.646002973828995, 51.08774185180664, 46.522900445120676, 25.469995941434586, 7.046834783894675, 22.542843205588206, 59.41116264888218, 89.43267508915493, 70.60933113098145, 75.00699887956891, 18.50869131088257, 14.285105466842651, 2.045486697128841, 41.95465094702584, 78.75127192905971, 61.03392137799944, 37.381610666002544, 39.64176934106009, 70.8752108982631, 46.355021544865195, 66.68659360068185, 14.0059346641813, 0.4383933059871197, 0.7881767238889421, 0.229640216167484, 1.23768869468144, 1.6299704164266586, 2.4786156841686795, 0.26760682889393395, 0.7374235529984746, 12.058954749788557, 85.38985879080636, 77.6800125667027, 82.63147258758545, 74.38907473427909, 80.65864276885986, 78.31398705073765, 77.7146076474871, 78.7015506199428, 77.22749028887067, 71.98423371996198, 75.58297674996513, 72.13630199432373, 74.01328141348702, 63.35664858136858, 57.86936085564749, 65.23016779763358, 71.8178938456944, 73.95592403411865, 73.0318831035069, 71.66721521105084, 69.54326902117047, 68.68376295907157, 58.81794629778181, 52.72257307597569, 51.854607582092285, 54.57265601839338, 64.24244662693569, 66.20038645608085, 65.62771592821393, 66.89943776811872, 66.0797518321446, 63.91955689021519, 64.60125160217285, 64.97271619524274, 60.70015771048409, 60.48991216932024, 62.06399181910923, 60.16862051827567, 61.586233683994834, 64.02219567980084, 61.220925194876536, 61.34578432355608, 63.050483158656526, 57.92526953560965, 62.09277125767299, 63.29951354435512, 60.15988663264683, 61.186983244759695, 62.38733318873814, 61.94587244306292, 58.066119943346294, 56.56745604106358, 57.40218482698713, 54.039350509643555, 60.03051812308175, 60.391351972307476, 58.66120188576834, 59.61454336983817, 61.849195207868306, 60.48248454502651, 59.93898950304304, 57.33579478945051, 59.77010658809117, 57.8946418762207, 57.51977613994053, 60.544795989990234, 57.36858333860125, 58.35828127179827, 58.62102740151541, 57.85624960490635, 58.620096342904226, 56.10372631890433, 58.1873208454677, 55.59639317648751, 51.92806741169521, 56.76692840031215, 52.08327974591936, 60.68320410592215, 55.01644788469587, 59.94782761165074, 56.271368980407715, 52.86792244229998, 57.409039224897114, 55.58391421181815, 55.89425202778408, 58.644484519958496, 53.53061383111136, 53.78501517432076, 54.64178017207554, 52.25532756532942, 59.09293515341622, 58.13773502622332, 56.119286809648784, 53.934450081416536, 59.81440830230713, 53.25116423198155, 53.08814212254116, 53.749398708343506, 56.049912520817344, 54.399927275521414, 55.88711622783116, 52.02927139827183, 52.01221357073103, 48.96443142209734, 52.86228397914341, 56.311929089682444, 57.58974797385079, 57.94547489711216, 58.726410729544504, 63.240912437438965, 62.74884101322719, 63.61722687312535, 63.30169527871268, 66.33342361450195, 64.58681324550084, 64.75218732016427, 57.58866058077131, 62.67694105420794, 55.0425557409014, 62.720818928309846, 58.52343300410679, 63.496891021728516, 44.62810237067086, 27.601392337254115, 24.955294234412058, 25.872723954064504, 19.344590868268693, 8.213806884629385, 1.2176807054451533, 2.4829407206603458, 0.36398811425481525, 0.6153753506285804, 0.8022764101624489, 1.9429414910929543, 0.8660082731928144, 30.7603109223502, 80.69272368294853, 76.50036130632672, 52.700522967747276, 60.85453973497663, 52.86582408632551, 65.68503856658936, 67.84629658290318, 0.23711487650871277, 0.8684940455215318, 23.833445038114274, 56.808405671800884, 50.71165323257446, 27.25635174342564, 3.5005445735795155, 21.42434130396162], [10.079047322273254, 39.77407693862915, 41.220698833465576, 25.355731078556605, 9.702765022005353, 3.8170389277594428, 1.6015698718173164, 27.25694407735552, 44.977245875767295, 28.281244039535522, 16.487243209566387, 24.110283851623535, 40.86806385857718, 32.01699686050415, 50.475167819431846, 19.228410039629253, 0.5485830775329045, 0.25317029069576946, 0.02648476374867771, 0.05071272002533078, 0.46049392436231884, 0.2060695652450834, 0.8436969561236245, 0.4940059004085404, 15.860022374561854, 47.9042648587908, 66.52403354644775, 71.1785831451416, 65.47161769866943, 67.88591521126884, 71.49043219430106, 73.75280734470913, 70.0505292075021, 68.27662631443569, 70.02016557965959, 67.16256604875836, 63.971723965236116, 62.193005970546174, 51.98676579339163, 53.753470352717805, 56.779063429151265, 65.38914952959333, 65.8278865814209, 65.85477610996791, 64.87050819396973, 62.38674259185791, 61.06493813650948, 56.61181681496756, 49.37905822481428, 46.8358507837568, 48.52187286104475, 55.96218803950718, 62.627546310424805, 60.41187000274658, 55.395944595336914, 57.534415994371685, 58.70798410688128, 56.964389256068635, 53.897061824798584, 51.075568607875276, 53.778820855276926, 54.60324546269008, 53.73011745725359, 54.48534148080008, 52.24383871895926, 57.25889212744576, 54.14577954156058, 54.185196672167095, 53.99179356438773, 56.85984666006905, 55.53634337016514, 56.59530789511544, 57.39312785012381, 53.92244012015206, 51.7117144039699, 55.86599023001534, 56.06540700367519, 44.58755268369402, 52.177274976457866, 57.13357094355992, 54.41736725398472, 49.9215874671936, 53.20403112683977, 53.53617238998413, 56.141812869480674, 51.507312297821045, 56.3126517023359, 52.27382714407784, 54.35788025174822, 53.85564361299787, 54.58644471849714, 51.8632824080331, 53.56978777476719, 54.23436907359532, 54.24326276779175, 51.77929605756487, 50.60449463980538, 53.290643896375386, 54.82600123541695, 49.245941162109375, 49.56244550432478, 53.750437464032856, 50.153591292245046, 54.46144315174648, 50.10719469615391, 53.750923837934224, 50.61256497246878, 53.14891801561628, 51.241310937064036, 55.420409202575684, 51.59551967893328, 51.113606521061485, 47.511583941323416, 51.77394594464983, 50.227335997990195, 50.5038743019104, 50.8502767426627, 50.39436721801758, 49.72676345280239, 49.99354996000017, 46.990614959171836, 47.52727992194039, 47.569980076381135, 51.03222574506487, 46.836219038282124, 47.118590354919434, 45.0667074067252, 45.45257908957345, 47.23367684228079, 53.31964567729405, 51.91733591897147, 56.75325434548514, 56.10520281110491, 58.26652683530535, 57.556532110486714, 59.01123823438372, 57.47898326601301, 60.667153767177034, 59.916442598615376, 59.347975730895996, 57.27976451601301, 52.727836336408345, 45.70979445321219, 39.61892018999372, 37.42292812892369, 36.50768709182739, 36.8084259714399, 20.42479256221226, 11.24126034123557, 8.863794360842023, 13.84273624420166, 22.36799873624529, 17.85903821672712, 3.7185972843851363, 0.038503920858992, 0.17146052021001065, 0.0473137583051409, 0.9157765912158149, 0.4947292187384197, 0.8592819284115518, 18.713989734649658, 57.907961572919575, 61.78634875161307, 40.2358055795942, 48.22511877332415, 52.76181650161743, 36.34936196463448, 43.33690125601632, 0.3938682723258223, 1.0551119659628188, 8.660160899162292, 12.723038383892604, 7.406890869140625, 2.730434685945511, 0.30694497802427834, 6.983977471079145, 41.2789421081543, 73.8903260912214, 62.06030927385603, 54.54541907991682, 15.746005909783499, 9.96385748045785, 2.2544314052377428, 40.223139013562886, 57.44964449746268, 43.50038889476231, 28.178883177893503, 29.784214087894984, 49.748869146619526, 38.48236165727888, 59.08816868918282, 20.64578001839774, 0.5077840153660093, 0.37797396949359346, 0.11779829327549253, 0.027043084414409738, 0.5698248605642999, 0.2883841411343643, 0.6506383270025253, 0.2829366448734488, 20.708569152014597, 64.88590540204729, 68.75150789533342, 74.9969378880092, 66.51290948050362, 72.46523666381836, 72.08469077519008, 76.85180119105748, 70.11143711635044, 70.40111446380615, 71.99139731270927, 69.13295010157994, 67.26856081826347, 65.12426335471017, 55.610418115343364, 55.69907365526472, 59.28299617767334, 66.63598987034389, 67.80563572474888, 65.37213339124406, 67.20298371996198, 65.09992381504604, 63.334407397678916, 61.23505088261196, 51.77439757755825, 49.103645529065815, 50.55426958629063, 56.70683690479824, 63.29845741816929, 63.133500235421316, 58.240710803440635, 59.85538182939802, 60.56156894138881, 59.0382319859096, 56.50271272659302, 54.52880246298653, 56.35047422136579, 57.70132909502302, 55.622243949345176, 56.46385840007237, 56.09026418413435, 60.64918572562081, 58.503394399370464, 58.34601075308663, 57.319317136492046, 58.93719128199986, 58.07964808600289, 59.594219888959614, 58.105867113385884, 56.109889371054514, 54.022268363407676, 59.31312356676374, 55.53378643308367, 45.21983528137207, 54.28932237625122, 59.73897865840367, 55.93716410228184, 53.155452796391074, 54.29744134630476, 54.54483890533447, 57.17127881731306, 53.33970512662615, 57.30872113364083, 55.667452403477256, 55.50926971435547, 54.27499171665737, 56.46491800035749, 55.123957361493794, 56.023526736668174, 57.7280900818961, 55.391341413770405, 54.35475703648159, 53.1682687486921, 56.33164460318429, 57.80475650514875, 52.20981339045933, 50.432780333927695, 57.99132605961391, 50.56570979527065, 55.52428477151053, 50.1856745992388, 55.42783682686942, 54.50372641427176, 53.79143530981881, 53.95674337659563, 57.50879103796822, 53.98217378343855, 54.956234795706614, 51.01415000643049, 54.33095598220825, 52.32880476542881, 55.104783807482036, 52.72700950077602, 54.600744111197336, 51.066504682813374, 51.813988413129536, 48.98645026343209, 52.09398691994803, 50.22322266442435, 52.1748674256461, 50.31911127907889, 49.59635271344866, 47.6451005254473, 46.503851958683555, 49.32672439302717, 54.481238569532124, 54.9983617237636, 58.10832330158779, 57.38450166157314, 59.401185035705566, 59.8779148374285, 60.14703941345215, 57.38873658861433, 61.51544543675014, 61.56525707244873, 58.6879038129534, 57.41195052010672, 53.96645695822579, 51.87412507193429, 46.23726347514561, 46.58753258841378, 47.34954152788435, 50.11786018099104, 31.156493731907435, 21.371870245252335, 14.25298307623182, 18.72547858101981, 26.20518136024475, 19.00604510307312, 3.643322237900325, 0.3223354278930596, 0.24694880310978207, 0.1680255995265075, 5.295781476157052, 0.4011113622358867, 0.8833901147757257, 26.126444373811992, 67.4913409096854, 71.88449232918876, 46.56079939433506, 58.92158562796456, 61.605820655822754, 45.38529968261719, 55.16398245947701, 0.15955092784549507, 0.1505494144346033, 17.87360511507307, 41.54677084514073, 29.716823509761266, 9.218391333307538, 1.7784289930547987, 10.358509949275426, 49.88126359667097, 87.58992944444928, 74.3105948311942, 76.98963955470494, 20.882216794150217, 11.993231739316668, 3.071570175034659, 56.429443972451345, 75.50515692574638, 58.75463431222098, 32.61068916320801, 39.46602507999965, 58.524009704589844, 48.5106897354126, 72.01078973497663, 25.98900032043457, 0.5047575320516313, 0.8299445169312614, 0.19994309970310756, 0.37790047058037346, 1.0372618266514368, 0.8475096715348107, 1.7286665375743593, 0.7004330807498523, 27.07558740888323, 75.77173151288713, 72.55679307665143, 78.6316031047276, 70.85340745108468, 76.57887595040458, 76.92377063206264, 82.48140539441789, 73.32961341312954, 74.36448505946568, 77.2269344329834, 75.86977754320417, 71.43545109885079, 68.86778599875313, 58.25698001044137, 59.42043849400112, 64.11259174346924, 72.64841897147042, 70.18189879826137, 70.59928403581891, 67.67347403935024, 66.83915519714355, 64.29935237339565, 63.4237334387643, 54.084927218300955, 52.06425557817732, 52.90030452183315, 60.13158661978585, 67.11024611336845, 66.4856516974313, 59.64719295501709, 62.14597361428397, 63.485211099897114, 62.491014208112446, 59.66737052372524, 57.083943435123985, 58.72702217102051, 61.13089043753487, 59.416616984776084, 59.85167843954903, 60.04234395708357, 60.8505653653826, 61.31950623648507, 62.656145095825195, 59.66426467895508, 61.96063041687012, 61.99625383104597, 61.17471272604806, 60.2808895111084, 59.24773406982422, 57.504952158246724, 61.43460314614432, 60.72583825247628, 49.37084197998047, 56.87437186922346, 63.68340846470424, 58.74683148520333, 54.2419182913644, 55.840010915483745, 57.66090447562081, 61.40881838117327, 57.7755115372794, 61.41388361794608, 57.92945235116141, 57.91407598767962, 56.61676740646362, 59.17536163330078, 57.4361024584089, 57.411380767822266, 60.067107336861746, 58.046828269958496, 56.50569697788784, 54.46590042114258, 60.61643191746303, 58.67753710065569, 54.60331841877529, 53.48714937482561, 58.73551286969866, 54.30302422387259, 58.3853097643171, 52.563646929604666, 57.624919755118235, 53.972345556531636, 55.95098406927926, 55.76839235850743, 59.15041760035923, 55.58858687537057, 58.22131143297468, 51.30951792853219, 57.9981735093253, 53.781520230429514, 58.14092424937657, 55.45028993061611, 56.874830450330464, 53.972463675907676, 56.09278290612357, 50.40153775896345, 54.33044181551252, 52.88771438598633, 56.33283274514334, 51.902397292000906, 53.218688351767405, 50.11921507971627, 51.255759716033936, 52.9263984816415, 58.4631712777274, 56.66192027500698, 62.75823497772217, 60.4179288319179, 62.40907410212925, 62.13207721710205, 62.97701985495431, 59.464941705976216, 65.68593488420758, 65.33385576520647, 63.92403847830636, 60.015655926295686, 57.98245668411255, 59.20393262590681, 53.68802179609026, 59.26600783211844, 54.84000880377633, 62.92965398515974, 50.367835521698, 43.581995487213135, 34.96039969580514, 35.453600202287944, 27.134228467941284, 20.15150080408369, 4.039479425975254, 0.6239919854061944, 0.23698698622839792, 0.8613916837743351, 5.057238527706691, 4.236808700220926, 1.0375192356961114, 35.813502992902485, 76.15998990195138, 80.01241861070905, 53.992068018232075, 70.97224249158586, 65.22004427228654, 63.271672112601145, 64.63530472346714, 0.34301361973796574, 1.0680577627250125, 25.368741580418178, 44.919388226100374, 33.724527086530415, 8.572069900376455, 1.5817551293543406, 9.57836013180869], [1.365393653512001, 29.355006490434917, 44.93171780450003, 12.447194031306676, 11.783591559955052, 6.091681122779846, 2.560692582811628, 39.42974158695766, 43.68303271702358, 25.500118119376047, 23.913646357400076, 31.263374396732875, 58.128215994153706, 38.17487260273525, 43.34864371163504, 28.781946863446915, 0.39185161196759766, 0.23803345007555826, 0.12026570444660527, 0.11111264702464853, 0.20549883587019785, 0.15455311031213828, 0.2879769929817745, 0.09662612793701035, 10.738836101123265, 29.695086070469447, 51.66895866394043, 63.37756265912737, 62.704011235918315, 63.349095889500205, 69.2319758278983, 72.633223261152, 69.50285829816545, 69.28480992998395, 66.2069525037493, 67.7641271863665, 60.772613525390625, 54.70233372279576, 51.32546404429844, 52.9373071534293, 53.976014205387656, 61.04282896859305, 65.43669605255127, 67.39362144470215, 63.899914332798545, 63.917632239205496, 63.63602869851248, 60.958102634974885, 53.85866607938494, 46.95995603288923, 46.19552217211042, 52.581680979047505, 61.487819399152485, 60.21812643323626, 60.810335295540945, 58.817494664873394, 57.19582332883562, 53.23829616819109, 53.63940872464861, 50.80587427956717, 52.66050481796265, 54.268658433641704, 55.6138505254473, 52.45962197440011, 51.564447334834504, 53.44451870237078, 56.43324811117989, 55.101611954825266, 55.24294178826468, 53.080575534275596, 55.069066592625205, 56.44552557809012, 53.92747061593192, 50.86383615221296, 57.181041036333355, 59.212263516017366, 46.14524848120553, 49.697570596422466, 55.264449937003, 58.48532213483538, 55.02774912970406, 54.59910086223057, 55.41722345352173, 50.653806005205425, 48.85481664112636, 49.46625811713082, 52.490697792598176, 55.211817332676475, 51.37228100640433, 52.92716973168509, 53.80271223613194, 52.259552070072715, 47.31442533220564, 44.48699140548706, 49.27669388907296, 50.83473014831543, 54.711585249219624, 53.2333664212908, 53.89070074898856, 52.1688676561628, 46.7623735836574, 54.65031950814383, 50.38859673908779, 51.89749533789498, 55.119190897260395, 51.8064044543675, 54.92090320587158, 51.45027453558785, 53.35267741339547, 52.938321590423584, 47.988303320748464, 48.138241972242085, 48.140760694231304, 50.13080814906529, 50.27770348957607, 50.243733746664866, 49.291288580213276, 47.89028855732509, 49.57973262241909, 49.52276086807251, 48.06151648930141, 50.051560470036094, 49.692109312329976, 50.144714968545095, 48.11910663332258, 46.21365002223423, 41.87153312138149, 45.53722899300711, 51.34488425936018, 51.823549134390696, 53.254085949489046, 55.87062120437622, 57.57168960571289, 58.927317891802105, 57.897327354976106, 60.37239728655134, 56.17824922289167, 55.75446816853115, 59.12570980616978, 58.037677492414204, 54.69851916176932, 47.23696681431362, 42.56451170785086, 36.21819734573364, 39.98111588614327, 41.64103358132498, 42.15806293487549, 34.69186224256243, 24.490953070776804, 13.039646080562047, 9.57920868056161, 24.466394662857056, 25.531833171844482, 9.228465352739606, 1.6128368100949695, 0.1442815557654415, 0.15437484559203896, 1.3804921976157596, 0.2283357461648328, 0.6459891679031509, 25.67599265916007, 58.58880165645054, 64.25067329406738, 45.03236593518938, 34.99345922470093, 40.53274726867676, 45.928749561309814, 41.37188468660627, 0.3045917914382049, 0.45289528210248264, 5.021469635622842, 5.694050916603633, 3.960481447832925, 1.0432974227837153, 0.27738411139164654, 3.9706844432013373, 31.19476788384574, 74.42970779963902, 68.18643869672502, 46.509341035570415, 16.76707669666835, 6.8194015707288465, 4.602579244545527, 50.45990262712751, 55.98315075465611, 41.25262928009033, 30.647086552211217, 28.528476578848704, 61.77197987692696, 43.79619107927595, 49.878112588609966, 34.98954391479492, 0.4121196972472327, 0.2878065992678915, 0.06312086260212318, 0.06634357145854405, 0.21592641275908264, 0.14789601681487902, 0.8757823258638382, 0.10285007860511541, 19.508451972688945, 39.429536615099224, 57.89531932558332, 67.33584022521973, 63.816084316798616, 65.19911629813058, 72.57169001443046, 72.51303332192558, 72.4695792879377, 70.70180470602853, 69.47236265454973, 69.33692141941616, 63.69454642704555, 55.50564970288958, 55.353557109832764, 54.731571742466514, 56.03744397844587, 62.75108528137207, 67.21002919333321, 69.39154815673828, 63.71670423235212, 68.6051024028233, 66.29392310551235, 65.77986758095878, 56.209464005061555, 50.30568388530186, 50.17337628773281, 54.81570747920445, 62.70856230599539, 60.538862228393555, 61.18847710745675, 61.5646664755685, 58.1581939969744, 56.29120608738491, 55.05937385559082, 54.35801921572004, 55.20235388619559, 57.24565928322928, 56.538117272513254, 55.487664290836875, 55.00540024893624, 56.60128334590367, 58.62305627550398, 57.06212261744908, 55.782066413334434, 56.99102864946638, 54.74420009340559, 56.78351027624947, 56.718186787196565, 54.109968526022776, 58.69251046861921, 59.20012501307896, 48.996118681771414, 51.33050496237618, 57.45343821389334, 57.55376672744751, 57.46972826548985, 57.88564395904541, 54.31118835721697, 52.27169752120972, 49.18519653592791, 50.255521365574424, 53.293371064322336, 58.707192012241904, 56.50420658929007, 55.033950396946494, 55.99493489946638, 52.903233187539236, 48.386945792606895, 45.70234251022339, 51.382046699523926, 53.32641322272164, 55.47101640701294, 55.523972102573936, 54.681030545915874, 52.99177060808454, 48.46052374158587, 56.06860664912632, 53.320733070373535, 54.9417165347508, 56.282850878579275, 56.69028282165527, 54.626594884055, 55.203389167785645, 56.23639522280012, 52.63365350450788, 49.443228312901084, 50.46879284722464, 52.16361829212734, 53.1133918762207, 53.0539048739842, 53.880837781088694, 51.658355712890625, 51.06906509399414, 52.08349166597639, 51.93003722599575, 50.438439641680034, 53.42525829587664, 53.08576236452375, 53.872288022722515, 50.37046194076538, 48.40522302900042, 43.9137476512364, 48.464303561619346, 54.40166779926845, 54.341444287981304, 56.86743409293038, 58.20706762586321, 58.42075252532959, 59.90040615626744, 59.72047560555594, 60.91564219338553, 57.54809004919869, 56.9153071812221, 61.772334235055105, 59.42050797598702, 56.14066989081246, 51.62358692714146, 48.84037133625576, 45.661622592381065, 49.232246262686594, 51.02893924713135, 53.55650976725987, 44.68590096064976, 33.66948693139212, 23.41309813090733, 21.111318009240286, 27.624086890901836, 24.118145738329204, 9.435646738324847, 2.674350998231343, 0.19096922980887548, 0.11406626924872398, 0.6185255987303597, 0.21135130897164345, 0.8236566143376487, 32.25918327059065, 64.89154733930314, 73.61892250605992, 51.87643534796578, 46.28109271185738, 47.36669315610613, 55.07851961680821, 51.07454374858311, 0.06627641684774842, 0.3581819443830422, 15.654348748070852, 25.90058101926531, 16.014915091650828, 3.947834857872554, 0.8499737307429314, 6.7535291739872525, 38.52289397375924, 91.65149198259626, 95.3091765812465, 63.49493857792446, 24.5282701083592, 12.513259240559169, 6.52503592627389, 65.96081951686314, 73.41354070390973, 56.039299147469656, 42.16202688217163, 47.86958987372262, 74.56083420344761, 54.886398451668875, 60.71811185564314, 44.89679963248116, 0.5746247087206159, 0.8413832059928349, 0.30008257340107647, 0.49250427527087076, 0.38387163302728106, 0.5409409276076725, 1.0002989300659724, 0.33031323552131653, 25.059371301106044, 51.266452993665425, 69.8679027557373, 71.9168917792184, 65.60566234588623, 67.5998787198748, 75.11855915614537, 77.1140262058803, 75.4565542766026, 75.36567878723145, 76.00514234815324, 75.18848582676479, 69.69762325286865, 60.24777439662388, 59.32109315054757, 57.73045594351632, 58.92348248617989, 66.77616282871791, 72.92087868281773, 73.26689897264752, 67.35742133004325, 70.2094692502703, 68.21314062391008, 68.9832581111363, 59.98723084586007, 52.64486789703369, 52.48434713908604, 58.9849670955113, 65.76995944976807, 64.43884440830776, 64.67096982683454, 64.6258134841919, 61.12629073006766, 59.08363151550293, 60.50998551504952, 57.667536531175884, 57.95070341655186, 61.7120794568743, 61.17971542903355, 59.20120198386056, 56.197697230747764, 62.86583478110177, 58.688397135053364, 58.31945473807198, 59.673804555620464, 58.0920923096793, 60.312795639038086, 59.70689882550921, 58.8161050251552, 54.69906112125942, 62.035017830984934, 65.04527623312813, 50.85269124167306, 55.05023002624512, 59.49279703412737, 60.99918038504464, 59.22069862910679, 60.3672000340053, 59.014177322387695, 56.40175540106637, 52.462484632219585, 53.90479516983032, 56.692315169743125, 62.44065366472517, 57.59892307009016, 57.286413942064556, 58.24932656969343, 56.662472656794954, 51.150654315948486, 48.435843740190776, 54.13570812770298, 55.979197229657856, 59.600778988429475, 58.950344221932546, 57.58380726405552, 54.665612493242534, 50.26700326374599, 59.41066932678223, 54.14583165305001, 56.326197215488975, 57.84720999853951, 56.130786078316824, 59.163883209228516, 56.453967639378135, 56.49189438138689, 58.34519781385149, 51.615811892918174, 53.08943101337978, 53.99208191462925, 56.32500907352993, 55.909600598471506, 56.07034717287336, 52.80601746695382, 53.778313636779785, 52.85869870867048, 54.436648505074636, 52.45571708679199, 54.75636291503906, 56.25699315752302, 56.77852841785976, 53.26827417101179, 51.50816692624773, 46.897582054138184, 50.230243819100515, 57.52898597717285, 57.90605776650565, 59.511897632053916, 59.80632059914725, 59.16507135118757, 61.68757316044399, 59.49010113307408, 65.1235476902553, 57.72692278453282, 60.26608289991106, 63.2622503553118, 60.536485944475444, 59.62277698516846, 54.14516462598528, 53.748908860342844, 51.17791209902082, 58.268461908612935, 57.4816826411656, 62.624836512974326, 58.166375500815256, 60.32483686719622, 47.45757906777518, 44.28477103369576, 32.31789207458496, 28.2367981501988, 11.265044025012426, 3.216134177786963, 0.2412717177399567, 0.19159667114061968, 1.9757363370486667, 0.7336887334074292, 0.6365066138761384, 39.778735705784385, 75.33369622911725, 81.92726571219308, 61.13876274653843, 58.95010798318045, 54.52280616760254, 71.5622626713344, 59.75477191380092, 0.522317421223436, 1.2104469793183463, 22.085344280515397, 30.858495916639054, 17.666915314538137, 4.852069514138358, 0.8405797662479537, 7.576789089611598], [3.442749457699912, 33.01437602724348, 51.57769407544817, 8.263400520597186, 11.999693564006261, 5.878137358597346, 2.901278078556061, 43.79919270106724, 39.5475309235709, 24.26246156011309, 21.79960482461112, 32.388343334198, 54.60213375091553, 37.069115434374126, 38.88133764266968, 33.9564197404044, 0.21619862743786403, 0.05402081233582326, 0.13213182985782623, 0.02262891556269356, 0.11815616621502809, 0.11250272779060261, 0.438915560820273, 0.3482009656727314, 10.737666198185511, 18.610185384750366, 42.84787661688668, 57.60164328983852, 58.04168312890189, 61.30627686636788, 60.55038234165737, 69.7207260131836, 67.74757657732282, 69.51747035980225, 65.91375936780656, 65.96079172406877, 56.623861517224995, 53.07323128836495, 51.7542929649353, 50.85432059424264, 53.329084805079866, 54.00813920157296, 64.5110639844622, 65.5267447062901, 62.47463730403355, 59.77789551871163, 63.85198565891811, 62.34817314147949, 59.79046480996268, 50.45143277304513, 44.63177101952689, 48.02710900987898, 56.84976134981428, 57.66311400277274, 60.61728654588972, 56.58005312510899, 53.63724783488682, 50.56483779634748, 48.251174518040244, 49.62771340778896, 49.19907208851406, 52.993597984313965, 54.28253746032715, 54.78236307416643, 52.51192453929356, 53.55443572998047, 48.81493050711495, 50.23891864504133, 52.83482122421265, 57.397581645420615, 54.88025624411446, 56.72103207451956, 52.30294009617397, 57.19944681440081, 56.09089994430542, 51.46934386662075, 55.02962861742292, 50.897034645080566, 54.26584441321236, 54.54298373631069, 54.32065527779715, 52.77440663746425, 52.743226596287315, 48.77910906927926, 42.50750173841204, 45.058393887111116, 50.7592761857169, 53.02858216421944, 54.50900704520089, 52.29003381729126, 52.467820848737446, 48.07359593255179, 38.05581521987915, 40.111516203199116, 46.675416878291536, 51.271330629076274, 52.66025815691267, 51.95823996407645, 54.673168659210205, 53.42410489491054, 49.38691316332136, 50.661515031542095, 49.91419110979353, 48.6152913911002, 50.773773602076936, 55.74222196851458, 52.083436080387656, 53.1731081690107, 50.11459800175258, 45.755211353302, 46.70151778629848, 47.83121149880545, 50.161383696964805, 48.00934246608189, 49.15097665786743, 49.03951365607125, 49.17737981251308, 50.30553102493286, 48.517974921635215, 51.24189111164638, 52.169520786830354, 54.09540162767683, 54.78654588971819, 50.887866497039795, 48.16814701897757, 42.822876998356406, 41.405896118709016, 46.999685832432334, 48.73690223693848, 52.356364795139854, 54.57618222917829, 58.14272730691092, 59.57743304116385, 60.4045535496303, 58.58803735460554, 62.54736409868513, 59.353110449654714, 61.82497378758022, 59.34261172158377, 57.809241567339214, 53.044903482709614, 45.96697507585798, 43.08582462583269, 41.11744512830462, 45.191604750497, 45.311832904815674, 48.88294294902256, 47.80568034308297, 44.28787340436663, 28.961384092058452, 8.625756893839155, 18.70825399671282, 26.0628753049033, 15.089185748781476, 7.337206516947065, 1.0808471164533069, 0.1764147893658706, 4.63659371648516, 0.3277947578047003, 0.5200894379190036, 22.412427255085536, 63.59333896636963, 61.61848027365548, 51.27520077569144, 39.740680422101704, 38.187000683375764, 55.48883506229946, 37.59222446169172, 0.33063046421323505, 0.44492037860410555, 5.346940193857465, 4.2358290042196, 3.077008877481733, 1.1733681346688951, 0.48916230031422203, 2.0783558019569943, 21.579121112823486, 70.64321749550956, 82.627199445452, 33.694351060049875, 18.716560568128312, 7.763831990105765, 5.7435490148408075, 52.03338473183768, 54.67451660973685, 36.03350727898734, 35.38926683153425, 31.529382705688477, 66.27266161782401, 46.515326908656526, 46.19947222300938, 42.76042658942086, 0.05840984146509852, 0.12938650431377546, 0.05736622067966631, 0.042094005537884574, 0.043710214884153435, 0.04388055092255984, 0.350441216890301, 0.22797085717320442, 15.718261752809797, 35.13396222250802, 55.78818777629307, 58.52925559452602, 64.14994525909424, 58.54790455954415, 66.19576590401786, 69.00200435093471, 70.51114613669259, 70.52772453853062, 68.04214545658657, 67.15013572147915, 58.75609343392508, 55.07358292170933, 55.10827875137329, 53.75851821899414, 53.677530016217915, 57.592110361371724, 67.49957452501569, 67.66130079541887, 64.56228610447475, 63.75762217385428, 65.15753827776227, 65.14148793901715, 62.18773923601423, 53.90551430838448, 47.94896262032645, 51.40361043385097, 58.15301064082554, 60.375461442129954, 60.83181912558419, 59.90116350991385, 56.30171871185303, 53.86306081499372, 50.83846827915737, 52.89302975790841, 51.67364174979073, 52.367308207920615, 56.995166301727295, 57.29198292323521, 55.28338377816336, 56.62128373554775, 52.43725919723511, 52.58311230795724, 56.65169947487967, 58.529387610299246, 57.56329965591431, 58.63830757141113, 55.54584503173828, 58.895745277404785, 56.99378361020769, 56.3774471282959, 57.51516253607613, 51.88557570321219, 58.74092551640102, 55.829637254987446, 55.801062788282124, 53.806679657527376, 53.248982497623985, 48.6706337928772, 43.66742358888899, 45.57696226664952, 52.27849980763027, 54.06678547177996, 57.152581214904785, 52.825892789023264, 54.23393133708409, 48.43272052492414, 38.733886446271626, 41.25085401535034, 48.421214308057515, 51.00562456675938, 53.93169512067522, 53.636101382119314, 56.74110542024885, 55.632680143628804, 51.04926272800991, 52.215382371629985, 53.37493249348232, 51.30229875019619, 52.27027661459786, 56.401060581207275, 54.422901494162424, 54.4511250768389, 54.15733092171805, 48.876925809042795, 48.02952350888933, 51.3647005217416, 52.219926493508474, 53.11100517000471, 54.073625973292756, 53.140274456569124, 52.771099294934956, 52.92096846444266, 51.698366914476665, 53.260387965611045, 53.6696264403207, 56.1206625529698, 55.731938634599956, 53.325919900621685, 50.188078675951274, 45.31646040507725, 43.195133686065674, 49.785621643066406, 51.411253452301025, 54.32696771621704, 55.941027300698416, 58.17706877844674, 59.32125990731375, 60.590605463300435, 58.12077099936349, 60.76863915579659, 60.537660190037315, 62.55990559714181, 59.70447390420096, 59.49119894845145, 55.61048412322998, 48.99436773572649, 49.522746971675325, 49.09063155310494, 53.02793598175049, 52.757324491228374, 56.6917210987636, 54.74627413068499, 51.65163680485317, 41.75356313160488, 24.1709919997624, 23.42391995021275, 33.91786418642317, 16.47438904217311, 7.656266059194293, 0.8146363869309425, 0.1531882235514266, 1.6794238942010062, 0.20226459870381014, 0.6335056977612632, 29.97411182948521, 70.703291620527, 71.35045378548759, 57.645885944366455, 49.20105927331107, 42.15826095853533, 64.31933539254325, 45.5076470375061, 0.2091906906238624, 0.666177973151207, 10.959160004343305, 16.92462362561907, 9.027974213872637, 1.2544598004647662, 1.0811846469129835, 3.852474306310926, 28.6682847567967, 97.73920481545585, 107.48324734824044, 52.06887265614101, 23.322941780090332, 12.016331894057137, 6.024853782994406, 68.661605153765, 70.93311718532017, 49.735539027622764, 34.85932077680315, 48.29261357443673, 69.11984579903739, 55.688015597207205, 56.67843614305769, 56.03757946831839, 0.20866257324814796, 0.4316140626158033, 0.250180828252009, 0.2850804626941681, 0.22986614118729318, 0.21706221252679825, 0.5487035853522164, 0.34879449382424355, 22.668609074183873, 45.73571123395647, 67.7271488734654, 63.32593059539795, 69.63668060302734, 60.29920496259417, 69.68178136008126, 73.10686806270054, 76.28722531454903, 73.1325763974871, 74.66121482849121, 71.0592200415475, 64.35998930249895, 60.10717064993722, 59.99238640921456, 58.76356969560896, 58.05192129952567, 59.7415703364781, 72.49466923304966, 70.8371834073748, 68.16651126316616, 66.58332252502441, 67.75602558680943, 68.5209458214896, 66.88229656219482, 58.067870889391216, 50.45512574059622, 54.19346155439104, 60.607920374189106, 65.66576426369804, 66.09561456952775, 63.083633014133994, 58.034314564296174, 57.32967342649187, 52.8479984828404, 56.18251541682652, 54.586090360369, 59.100022315979004, 59.25493240356445, 58.929075786045615, 57.421671049935476, 59.99315765925816, 58.71548816135952, 56.95846244267055, 59.774650709969656, 62.1096762248448, 58.716384478977744, 61.853343282427105, 55.749670437404085, 61.96524402073452, 60.08825765337263, 57.509086336408345, 60.55490561894008, 55.94355991908482, 61.40613637651716, 59.90454033442906, 59.506297383989605, 57.504396302359446, 56.85855776923043, 51.368257999420166, 45.77582665852138, 48.41063567570278, 54.84621354511806, 58.60880552019392, 59.336955887930735, 55.305597169058665, 57.29731566565377, 51.990986824035645, 40.12254646846226, 43.80756180627005, 51.12541845866612, 52.77911056791033, 55.34060566765921, 55.31712075642177, 59.24026475633894, 55.734391348702566, 54.54164273398263, 55.730257170540945, 53.328681809561594, 52.711799894060405, 54.93236773354666, 60.66991915021624, 54.94028867994036, 57.46268974031721, 54.28416681289673, 52.12271077292306, 49.40653140204293, 55.29678337914603, 54.581730365753174, 53.52663598741804, 55.77072695323399, 55.812082631247385, 54.64351027352469, 55.55104228428432, 54.29773664474487, 56.977524825504844, 56.754442487444194, 60.38650212969099, 59.04415185110909, 56.75841685703823, 51.83583354949951, 47.899748529706685, 45.25921072278704, 53.43377331324986, 53.93849393299648, 56.82117993491036, 57.59447969709124, 61.489618982587544, 61.191450936453684, 63.32760511125837, 61.235175950186594, 64.32954924447196, 64.4608701978411, 64.59012753622872, 62.671194893973215, 62.543243816920686, 57.909907068525044, 53.39832360403878, 53.756840229034424, 53.853920459747314, 60.1307806287493, 58.406050137111116, 64.45678465706962, 62.8528277533395, 64.81203215462821, 60.047443934849326, 47.90624162128994, 29.273132392338344, 41.61265019008091, 20.334650107792445, 10.090657762118749, 1.3521450672830855, 0.22197036844279083, 6.814632935183389, 0.42003062846405165, 0.4582737577813012, 39.198814732687815, 78.81356252942766, 78.3616725376674, 66.39554745810372, 61.70188644954136, 51.72346033368792, 77.10343715122768, 53.62150321687971, 0.5654479839972087, 1.4108182617596217, 22.841379506247385, 22.690706082752772, 11.038986120905195, 3.2645025423594882, 0.5592928571360452, 5.294206406388964], [5.950150225843702, 43.70720897402082, 66.57612419128418, 7.764225431850978, 9.252598183495657, 5.8811659046581815, 0.9122511403901237, 37.637863704136436, 35.70038979394095, 17.421240908758982, 14.259357179914202, 31.562504768371582, 29.615011555807932, 33.17478561401367, 41.543425287519185, 35.278255462646484, 0.786751963198185, 0.057452340344233174, 0.36130043704594883, 0.05839646753988095, 0.2745845844703061, 0.14705966812159332, 0.3419239196394171, 0.8901884385517665, 8.62563443183899, 27.994120155061992, 44.32528597967965, 56.026907035282676, 55.04205894470215, 59.88362625667027, 54.64025156838553, 61.41562761579241, 66.15428515842983, 66.08225318363735, 63.943785258701865, 60.76893098013741, 54.476736136845176, 50.562617846897666, 54.634262221200125, 48.297414779663086, 52.11010326657976, 48.198792048863, 58.32574980599539, 63.94065162113735, 63.14852224077497, 61.222036906651084, 57.74458857945034, 64.03073501586914, 59.84207602909633, 54.981470652988975, 45.3330249105181, 47.96124356133597, 50.80962978090559, 57.063491412571494, 57.04468611308506, 56.77382796151297, 50.852142333984375, 47.75611189433506, 45.47648089272635, 48.81667797906058, 48.10321610314505, 54.23144735608782, 50.59262016841343, 56.61745180402483, 56.88095876148769, 52.951940059661865, 50.07751546587263, 47.472232818603516, 46.94357565471104, 51.71783924102783, 53.13979155676705, 55.02055427006313, 55.84925896780831, 56.03829860687256, 53.4269015448434, 56.68376541137695, 52.406225068228586, 50.8731814793178, 54.82607766560146, 56.711002349853516, 53.28070102419172, 56.78954478672573, 49.37317310060774, 41.220320156642366, 41.42040395736694, 40.44723926271711, 43.772296224321636, 47.51822294507708, 46.51895039422171, 46.88264342716762, 46.50493935176304, 41.80437878199986, 39.91914142881121, 38.18273796354021, 40.10582562855312, 47.39265162604195, 53.265963894980295, 53.31583111626761, 53.10420635768345, 55.89351551873343, 50.31039476394653, 49.45995610100882, 53.48875788279942, 50.27581705365862, 49.61187498910086, 50.10445710590908, 51.674492904118125, 49.11997379575457, 48.45435374123709, 47.541416031973704, 50.02405950001308, 48.34786217553275, 48.02500023160662, 48.53257656097412, 49.127363204956055, 50.64223378045218, 48.439279624394004, 51.86990751538958, 50.959801197052, 50.93742452348982, 52.93238435472761, 50.78861495426723, 52.85554075241089, 50.883047921316965, 50.47752325875418, 43.947811194828574, 42.34337486539568, 48.04865884780884, 51.91875682558332, 55.38853086744036, 55.19162239347185, 58.23207071849278, 58.98049940381731, 58.43524646759033, 57.44313056128365, 60.183781487601145, 59.0909549168178, 59.89201273236956, 60.7774772644043, 56.87096030371529, 49.61483144760132, 45.78203139986311, 44.06876196180071, 44.039336340767996, 46.69984674453735, 50.20745372772217, 53.859475544520784, 53.96109989711216, 53.62590837478638, 38.866989612579346, 11.311199171202523, 9.601686103003365, 12.76903806413923, 12.787163308688573, 11.31769573688507, 7.1703594241823465, 0.12494128569960594, 0.0962345250216978, 0.3004336745611259, 0.21107213252357074, 32.598863329206196, 58.781982421875, 62.1477176121303, 56.27066026415144, 35.177583013262065, 36.561685017177034, 53.76638010569981, 30.525944709777832, 0.2446244949741023, 0.6118856721690723, 3.426379067557199, 5.526490764958518, 2.7211377790996005, 0.7750949487090111, 0.7463213184050151, 2.1240289168698445, 18.324115889413015, 67.33759811946324, 90.77815900530133, 24.96694983754839, 15.703590631484985, 8.78922368798937, 5.8941017133849005, 49.7060786655971, 48.48646484102522, 26.492249659129552, 20.23837239401681, 37.62080240249634, 31.13187279020037, 40.39931058883667, 48.297286237989155, 45.75677122388567, 1.742450243660382, 0.08173972102148191, 0.21178592422178813, 0.048302380434636555, 0.013944316173105367, 0.21614514530769416, 0.05326549768713968, 0.853750619505133, 12.406216161591665, 38.0928247996739, 58.0613500050136, 56.23943853378296, 62.024692807878765, 59.331904547555105, 58.325881821768625, 63.92911761147635, 68.78260108402797, 68.24858338492257, 67.01356887817383, 64.35991287231445, 56.61711481639317, 54.137691838400706, 55.00991310392107, 52.74401521682739, 53.24626922607422, 53.15690496989659, 59.99410956246512, 67.3858255658831, 63.82265036446707, 63.485947608947754, 58.78532450539725, 64.68535259791783, 64.26899569375175, 55.704093728746685, 47.03975261960711, 49.538019112178254, 51.75538035801479, 57.34971897942679, 57.31963675362723, 57.23405926568167, 52.49323388508388, 50.14298834119524, 48.886347566332134, 50.01175076620919, 51.16231686728341, 54.04937676021031, 54.84708901814052, 57.463190010615754, 58.91382449013846, 56.150852475847515, 53.57312638419015, 49.923355783735005, 50.66884190695626, 54.17329093388149, 56.795207568577354, 56.58749117170061, 59.42501040867397, 56.27056646347046, 57.44611133847918, 58.50594438825335, 54.38987670625959, 52.60088232585362, 58.01725326265608, 56.58440964562552, 57.55501045499529, 56.573146615709575, 50.395753383636475, 42.0259359904698, 42.16423293522426, 42.482793944222585, 44.045766898563926, 47.5112122126988, 47.96918535232544, 47.434073311941965, 46.22339487075806, 42.876451083592, 41.10619946888515, 39.77106489453997, 39.06013911111014, 46.5068952696664, 54.39986474173409, 53.39235162734985, 56.74545499256679, 55.265481744493755, 53.95449563435146, 51.48860427311489, 55.55396747589111, 52.68381602423531, 52.38226073128836, 49.85473190035139, 53.46431412015642, 50.56248583112444, 50.91608313151768, 49.71828317642212, 53.09214081083025, 49.68435859680176, 51.33969742911202, 52.170705454690115, 52.300567286355154, 51.9016364642552, 52.75751209259033, 53.48363011223929, 55.21284219196865, 53.53797197341919, 55.96909802300589, 53.541602407182964, 53.61067444937569, 53.59501668385097, 53.005604471479145, 46.77144793101719, 44.217297077178955, 50.06613084248134, 53.68109791619437, 56.67739391326904, 56.52803543635777, 58.76141575404576, 58.864839690072195, 58.34300218309675, 57.50398635864258, 60.05087634495327, 58.39277907780239, 59.84753731318882, 59.914795875549316, 58.72131769997733, 53.42650202342442, 49.749167919158936, 49.11951521464756, 50.66976601736886, 53.37323713302612, 55.45698799405779, 61.061484881809776, 61.27660805838448, 60.094914027622764, 55.8445793560573, 22.74046039581299, 17.070296083177837, 29.74474831989833, 20.73333079474313, 15.841416835784912, 7.263113532747541, 0.6334147740687642, 0.9874791779688427, 0.17131630437714712, 0.144587032230837, 46.700044768197195, 67.32113783700126, 70.75488894326347, 62.811277525765554, 43.61945669991629, 42.684326444353374, 66.70496463775635, 35.95901911599295, 0.44300039591533796, 0.8789584668619292, 9.729094352040972, 12.564822690827505, 5.369913109711238, 1.3035715137209212, 0.49407000839710236, 3.3096128531864712, 27.25399283000401, 101.75394344329834, 122.09253665379116, 38.328768253326416, 18.95266556739807, 12.556918246405465, 5.886768324034555, 68.27543817247663, 62.8987067086356, 39.96516282217843, 24.190231561660767, 46.275058201381135, 40.37600980486189, 50.50659104755947, 57.08135870524815, 63.213696343558176, 1.9329495472567422, 0.18543284546051705, 0.5558860142316137, 0.17866422794759274, 0.2406292265014989, 0.30597000462668283, 0.24602154429469789, 1.1022368201187678, 17.295803342546733, 61.0206572668893, 66.4720401763916, 60.23449638911656, 67.66952746255058, 60.76526233128139, 64.89645276750836, 62.8669673374721, 73.89746189117432, 69.91971547263009, 72.17703233446393, 68.23502050127301, 64.36294228690011, 56.529046399252756, 62.80367619650704, 56.0332681110927, 58.65487207685198, 56.050308568137034, 63.08293124607631, 70.86592115674699, 67.8969281060355, 67.5519917351859, 60.254131998334614, 69.60852650233677, 66.43108749389648, 59.21696744646345, 48.28922285352434, 53.44839232308524, 56.047383376530235, 62.25904859815325, 60.3825694492885, 61.976166588919504, 57.49201808656965, 53.54291909081595, 50.38325010027204, 54.395845208849224, 54.63754871913365, 58.52296052660261, 57.69964068276541, 62.48096016475132, 61.57917431422642, 59.97796194893973, 52.83097192219326, 53.655490330287385, 52.569160325186594, 57.716458797454834, 56.75406381062099, 59.89012977055141, 60.64409269605364, 59.81291443961007, 58.49878774370466, 63.03600311279297, 57.15216432298933, 56.16680553981236, 59.1897166115897, 60.69751044682094, 58.29162720271519, 60.61542442866734, 53.703467641557964, 44.064315114702495, 44.212228366306846, 43.973967688424246, 45.81749153137207, 51.70694099153791, 49.821721008845735, 50.36879784720284, 48.849886894226074, 44.744971070970806, 43.83821725845337, 41.34160096304757, 42.42287962777274, 52.04401200158255, 57.91238757542202, 55.28172663279942, 58.636174474443706, 58.25227607999529, 54.66158948625837, 53.95012174333845, 57.27763836724417, 55.76081187384469, 55.078217370169504, 53.608885288238525, 53.52047988346645, 52.69715656552996, 51.49618475777762, 51.44771065030779, 57.529194423130576, 54.049366337912424, 53.421509742736816, 54.77584218978882, 54.89866897038051, 55.168231282915386, 53.8366368157523, 55.641247272491455, 56.51566416876656, 56.720879214150564, 58.660784993852886, 56.471907888139995, 56.46506043842861, 57.36156913212368, 56.93982737404959, 50.700129645211355, 48.21203531537737, 52.168113776615684, 56.12044715881348, 59.105108397347585, 58.331739153180806, 61.86820547921317, 62.27026299067906, 61.13005665370396, 61.4006472996303, 63.912837982177734, 62.35959597996303, 64.22292218889508, 64.40838350568498, 61.83010850633894, 54.688948018210276, 54.23031479971749, 53.66217449733189, 57.253819942474365, 55.3346197945731, 61.17173194885254, 63.48244571685791, 67.10452774592808, 65.74597426823208, 69.7052732195173, 45.155404635838096, 23.25777288845607, 40.60310125350952, 28.009960310799734, 21.647027594702585, 8.31200577531542, 0.908254189150674, 1.3043904240642274, 0.5676314011216164, 0.3354151946093355, 58.981354032244, 71.8630154473441, 80.7890396118164, 70.3206056867327, 56.02598292487008, 47.149916308266775, 78.61012622288295, 45.557743549346924, 0.5084259094936507, 1.5235018666301454, 20.870314529963903, 19.546972785677227, 9.66278942993709, 2.565635574715478, 0.703043269259589, 4.893623650074005], [3.1398288437298367, 33.697015694209504, 55.62178884233747, 15.394840478897095, 10.90473563330514, 3.6728112612451826, 4.242659517696925, 37.79958650044033, 32.84401314599173, 16.434275354657853, 25.77172146524702, 31.99463060923985, 55.429261207580566, 37.824374198913574, 40.8942620413644, 29.42087541307722, 2.619869087423597, 0.056009086181542704, 0.2608745944287096, 0.12360843936247484, 0.14459038419382914, 0.057921452314725945, 0.1717029879135745, 1.1175635691199983, 13.65558304105486, 36.33262375422886, 50.688491412571494, 52.32200247900826, 54.45495006016323, 60.26004491533552, 55.93006304332188, 53.540608814784456, 54.11991834640503, 58.69218390328543, 59.69815799168178, 53.91321638652256, 46.75864587511335, 51.93557841437203, 52.83760745184762, 52.47428962162563, 50.716645513262065, 49.48001902444022, 49.13076434816633, 58.081093311309814, 63.53657913208008, 61.581168447222026, 59.68048872266497, 54.88744068145752, 58.5682349886213, 54.44131422042847, 47.42506497246878, 45.50920690808977, 49.68545641217913, 52.28487825393677, 51.546201365334646, 52.62650728225708, 49.70925399235317, 47.8805958202907, 43.87071050916399, 47.51934160505022, 46.88241761071341, 53.06364972250802, 52.03084863935198, 52.796154499053955, 51.40415934153965, 58.89502266475132, 49.85598605019705, 48.04329136439732, 47.10709456035069, 53.64408138820103, 50.633920260838096, 49.43827772140503, 55.89857380730765, 53.89352866581508, 53.788767201559885, 54.33209548677717, 50.380575043814524, 55.33498110089983, 55.37047597340175, 55.93602112361363, 52.97519220624651, 48.97620514460972, 41.68076685496739, 37.17695495060512, 38.17671734946114, 42.40021112986973, 40.22255189078194, 41.48724215371268, 38.53729411533901, 36.90307433264596, 40.32376282555716, 42.27177367891584, 36.83169896262032, 36.63028458186558, 34.79474074499947, 43.94688708441598, 42.53352621623448, 48.528445856911794, 53.98931653159005, 55.02159649985177, 53.073655128479004, 50.28786523001534, 52.165337971278596, 53.57848344530378, 51.61622878483364, 51.142500604902, 51.29984951019287, 47.96907070704869, 46.5523955481393, 49.048643589019775, 50.4679799079895, 50.110498564583914, 49.24543046951294, 46.42608772005354, 46.45023618425642, 46.87522275107247, 51.625761713300435, 51.855121748788015, 52.38406726292202, 50.266172954014365, 49.30883625575474, 49.65920959200178, 50.411386830466135, 51.43923037392752, 49.261522497449604, 44.37536859512329, 40.724958760397776, 47.058075019291465, 55.18375355856759, 54.44990914208548, 54.869701930454795, 57.1921512058803, 59.002469607761924, 56.38960647583008, 54.87391253880092, 54.091128485543386, 55.379633699144634, 57.50636611665998, 55.265054430280415, 54.342166900634766, 50.28491571971348, 47.75202635356358, 44.707944120679585, 48.156164850507466, 50.45048086983817, 53.96263892310006, 55.22896201269967, 56.450194767543245, 57.111823081970215, 42.09353501456124, 13.19239788396018, 6.065064745289939, 5.504478003297534, 6.961506128311157, 10.338195153645106, 19.379951987947734, 2.861760199069977, 0.10977273035262312, 0.29038218249167713, 0.6469927483371326, 41.33583395821707, 57.20051336288452, 62.44467667170933, 58.43847043173653, 36.65829277038574, 32.10447120666504, 51.47715711593628, 30.872684138161794, 0.3937045011137213, 0.42211945780685967, 4.7603224601064404, 6.934534958430699, 3.7145330224718367, 0.8515236675739288, 0.9643016159534454, 2.0398360746247426, 16.241103274481638, 74.246032169887, 74.81359577178955, 17.08077049255371, 13.966639995574951, 7.206589502947671, 7.513523135866437, 51.115176813943044, 43.956611088344026, 27.744697196143015, 23.629039457866124, 37.6768604687282, 60.73703180040632, 43.52393981388637, 48.967238494328086, 39.19766133172171, 4.484792513506753, 0.060695839513625414, 0.30061568479452816, 0.1736823966992753, 0.12545710802078247, 0.11861809928502355, 0.0981437936425209, 1.5836642554828098, 13.009819201060704, 50.3539252281189, 62.28502096448626, 55.4505226952689, 61.29611165182931, 57.8167074067252, 57.242841788700645, 54.400872230529785, 58.223955222538535, 59.696907315935405, 64.5543304170881, 55.49624531609671, 51.95295238494873, 56.86238970075335, 55.36707483019148, 57.338601861681255, 52.6982786996024, 52.33715302603585, 50.889478479112896, 61.337606293814524, 65.18627602713448, 66.05140318189348, 60.847139903477256, 58.58803735460554, 60.447312763759065, 56.56513186863491, 48.53910091945103, 46.68831968307495, 51.0441940171378, 52.90949351446969, 52.26211942945208, 54.21961109978812, 51.26688378197806, 49.84171792439052, 47.307793276650564, 48.307354177747456, 50.40263557434082, 52.4274240221296, 55.31708601542881, 57.63992438997541, 54.08088336672102, 60.811877795628135, 53.77620138440813, 50.074225493839805, 49.87959950310843, 55.81242309297834, 52.039005824497764, 53.585612297058105, 56.9321357182094, 53.43571880885533, 57.367860725947786, 55.90179429735456, 53.10671465737479, 54.95229516710554, 57.9605907031468, 59.41641548701695, 55.0247996194022, 51.74406174251011, 41.713034289223806, 37.525236879076274, 40.12244919368199, 44.889771529606406, 40.84157732554844, 39.32055064610073, 37.70719630377633, 36.48597397123064, 41.38182755878994, 43.96814857210432, 39.578617164066856, 37.251672404153005, 38.86526993342808, 47.40061773572649, 46.23976830073765, 48.827951431274414, 56.529550143650596, 56.88196277618408, 54.17555257252285, 51.43754196166992, 54.02985232216971, 54.63533919198172, 54.40396417890276, 52.62741749627249, 57.53449589865548, 50.12555183683123, 48.45145981652396, 50.69696126665388, 52.41694266455514, 51.45444345474243, 51.23512356621878, 51.61695487158639, 52.28628526415144, 50.970650809151785, 54.84715502602713, 52.471763951437815, 55.678875241960796, 53.54351316179548, 50.37998097283499, 51.89814152036394, 52.14732824053083, 53.9089606148856, 52.51848711286272, 47.27829122543335, 44.08107416970389, 48.93638849258423, 56.40608760288784, 54.10847118922642, 54.931916100638254, 59.1743471963065, 58.2933086667742, 58.292599950517925, 55.02683196749006, 57.12400674819946, 55.09798846926008, 58.58616134098598, 58.05531202043806, 55.720223971775596, 54.604343278067454, 50.291231632232666, 50.64169182096209, 52.29621076583862, 57.51783064433506, 59.57703699384417, 61.54578127179827, 62.60920306614467, 63.6084999356951, 54.29308829988752, 27.511381898607524, 14.460477999278478, 18.371568611689977, 15.765554666519165, 18.847356932503835, 20.57502130099705, 3.5150202768189565, 0.7675381856305259, 0.29671652402196613, 1.070266095655305, 51.67814418247768, 65.91378021240234, 69.63080937521798, 65.58025973183769, 44.77667222704206, 38.37789896556309, 59.27024623325893, 36.57205867767334, 0.7299688415867942, 1.150578803249768, 7.724150827952793, 11.335643802370344, 4.941660455295017, 1.1172435177224023, 0.5652568542531559, 3.0852826620851244, 29.024584906441824, 120.25314004080636, 99.99453449249268, 26.754936729158672, 17.215259824480327, 7.381636772836957, 10.88270376409803, 68.50943960462297, 58.239904812404085, 43.92469801221575, 39.34357350213187, 47.136502810886924, 64.57810020446777, 59.393132073538645, 56.81443670817784, 58.23426634924752, 6.083570837974548, 0.14273075040962013, 0.539535328745842, 0.23192736772554262, 0.2039716299623251, 0.11185484219874654, 0.1599735873086112, 1.0522028420652663, 23.94834566116333, 60.97694614955357, 64.09535326276506, 60.118016787937705, 65.64402335030692, 58.9986480985369, 64.51011208125523, 56.018041133880615, 61.17714459555489, 61.737357003348215, 69.30128410884312, 56.74077885491507, 55.979940686907085, 60.23672676086426, 61.42235347202846, 60.50083473750523, 56.97621161597115, 57.107793126787456, 56.06519855771746, 64.55285045078823, 70.46983909606934, 68.8150074822562, 63.306211607796804, 61.37964984348842, 61.91243076324463, 58.74152306147984, 52.009656633649556, 49.71138708932059, 53.77810519082205, 56.19602966308594, 54.50704765319824, 56.51154736110142, 56.20150136947632, 52.28909233638218, 50.42537008013044, 53.09952327183315, 54.615884235927034, 56.550405161721365, 57.40051031112671, 60.4777250289917, 56.01398686000279, 60.7392760685512, 57.95510162625994, 55.15589823041643, 50.335255418504985, 58.367383411952424, 54.859620094299316, 54.44999252046858, 58.326701709202354, 58.3051483971732, 60.95574024745396, 58.5922966003418, 54.33129644393921, 59.21666867392403, 61.28338950020926, 61.198010035923545, 56.6698933328901, 54.28232554027012, 44.86954879760742, 39.354256357465474, 42.61883967263358, 46.853394985198975, 42.75037949425833, 43.130331311907085, 39.74589851924351, 38.797556264059885, 41.86718702316284, 44.76561764308384, 41.89675855636597, 38.852169104984824, 39.92737851824079, 49.48471253258841, 47.72625548498971, 52.8273206438337, 58.77865423474993, 59.062008721487864, 58.02889149529593, 52.343538420540945, 55.83040850503104, 56.593459674290244, 56.52622543062483, 55.44938319069998, 58.37253897530692, 51.31691081183297, 50.354696478162495, 53.59749024254935, 55.14019182750157, 54.82406268801008, 53.38100521905081, 51.9543593951634, 53.11474677494594, 52.13769456318447, 56.867079734802246, 55.16236700330462, 57.42829615729195, 55.142856461661204, 53.481979915073936, 55.460034779139924, 54.91931554249355, 56.324741567884175, 56.981506143297466, 49.75163452965872, 46.37668602807181, 53.20054660524641, 58.81860637664795, 57.80644491740635, 58.44085366385323, 61.31382261003767, 62.54204872676304, 61.2131154196603, 59.813574518476216, 60.91222367967878, 57.94415821347918, 62.1412627356393, 62.10449981689453, 60.54601192474365, 56.87294748851231, 54.84071404593331, 55.81012323924473, 57.57788045065743, 60.46818515232631, 64.97131960732597, 63.757490158081055, 66.37664835793632, 67.36065919058663, 65.38475826808384, 50.17556149618966, 22.657552753176006, 26.348651238850184, 28.132106167929514, 29.251082284109934, 25.17409474509103, 6.42003778900419, 2.7753096265452246, 0.6128285101481846, 1.5361732095479965, 68.28732654026577, 70.48711926596505, 78.03622586386544, 71.31565025874546, 58.778042793273926, 45.048027174813406, 72.73720305306571, 48.5707881791251, 1.0040729961224963, 1.9407013484409876, 18.7363247190203, 16.58606743812561, 10.63071778842381, 3.715163137231554, 0.587863524045263, 5.9148759586470465], [9.866905791418892, 9.12186782700675, 23.575204815183366, 13.437497326305934, 7.338976570538112, 2.060682841709682, 11.06605977671487, 38.27619818278721, 31.764124120984757, 13.13125113078526, 29.723632744380406, 40.104411670139854, 39.329680579049246, 42.70788083757673, 43.72291885103498, 24.105633769716533, 5.6361680797168185, 0.22609991899558476, 0.17395191080868244, 0.1120101452938148, 0.331440336470093, 0.14397875272801944, 0.33668049957071033, 1.4367051869630814, 12.203714387757437, 25.924526248659404, 42.429532527923584, 49.96574674333845, 57.71219955171858, 59.232218742370605, 55.50935309273856, 54.09737491607666, 49.55675492967878, 50.23100812094552, 49.77183294296265, 48.72974559238979, 46.54254995073591, 51.093526227133616, 53.88259220123291, 54.6590325491769, 52.60225459507534, 50.14313425336565, 49.149152755737305, 50.62075342450823, 59.057575770786826, 61.59903226579939, 61.618014744349885, 58.941700662885395, 58.391104561941965, 54.89782476425171, 48.48382452556065, 46.07330683299473, 47.772936957223074, 48.83471550260271, 49.82648399897984, 47.939339365277974, 44.5036358152117, 43.540035315922324, 43.38783502578735, 47.05483021054949, 47.24713897705078, 52.8244823047093, 52.43767261505127, 55.40708255767822, 51.43672207423619, 57.53476687840053, 54.18524183545794, 43.86635398864746, 47.15536717006138, 49.043540137154714, 53.24722112928118, 48.775068691798616, 50.71444640840803, 52.66456604003906, 54.652535983494346, 53.79787628991263, 48.41173696517944, 53.373143332345144, 56.49321106501988, 58.2285201890128, 53.098095417022705, 43.06720692770821, 38.733233315604075, 36.046934672764365, 42.00919083186558, 44.144424370356965, 39.683364731924875, 33.25457525253296, 34.91389887673514, 32.8749361038208, 33.78226661682129, 43.51297903060913, 44.75141552516392, 36.3012387411935, 38.77114963531494, 42.26918894904, 38.71355601719448, 37.645600523267476, 50.832770756312776, 53.58143990380423, 48.66475214276995, 48.89544970648629, 52.87586770738874, 54.11168820517403, 53.65917634963989, 52.89138650894165, 49.86140217099871, 47.26652792521885, 46.74995715277535, 49.90729849679129, 50.68605259486607, 49.10094615391323, 48.23123666218349, 47.56965003694807, 47.887561389378135, 49.440931933266775, 49.876139300210134, 51.14113180977957, 49.42703553608486, 52.31935521534511, 49.168857846941265, 47.55987739562988, 48.39275448662894, 47.700793811253135, 47.49742003849575, 43.94171067646572, 40.85973991666521, 51.013114724840435, 54.78832810265677, 56.9766389301845, 57.014416285923545, 54.81038863318307, 54.51244292940412, 52.09013066973005, 50.497950962611604, 48.66234111785889, 47.4256659916469, 48.70227936335972, 50.35007592609951, 50.620517185756135, 48.93607929774693, 45.3261844090053, 46.48779467173985, 49.03608472006661, 52.220367704119, 56.54071242468697, 58.2578832762582, 60.27725560324532, 56.833592891693115, 45.45865528924124, 19.82417290551322, 7.209209842341287, 8.1967134475708, 8.258928486279078, 10.641216516494751, 24.542652879442485, 12.97794086592538, 0.8033165772046361, 0.12316393107175827, 0.6477160666670118, 24.87145553316389, 64.24387795584542, 60.38946206229073, 59.11903953552246, 36.445476395743235, 37.26092740467617, 49.48897525242397, 35.22632462637765, 0.4193896842854363, 1.587370685168675, 4.395610647542136, 7.414681536810739, 2.7614725061825345, 1.5296867404665266, 1.1064870549099786, 1.1830862760543823, 18.853598151888164, 69.87099470411027, 39.96805327279227, 19.818063701902116, 12.67233303615025, 5.41381790808269, 17.380769389016287, 51.3968185697283, 41.19473341533116, 25.95655744416373, 27.18539673941476, 49.308770247868125, 44.127738271440776, 47.874064513615195, 51.67879383904593, 37.85699251719883, 9.22359379700252, 0.14352735052151339, 0.162479607122285, 0.08583731257489749, 0.13880771877510206, 0.1846874611718314, 0.1915437861212662, 1.841389877455575, 19.454890046800884, 45.78868082591465, 55.94166653496878, 54.08182484763009, 64.60576098305839, 57.46528836659023, 59.508666719709126, 54.790846824645996, 53.472933360508506, 50.53602014269148, 52.09154462814331, 50.298013074057444, 51.49940872192383, 54.002664021083284, 58.58994116101946, 56.959963253566194, 55.03075769969395, 52.799395833696636, 50.922329562050955, 54.36170523507254, 61.125686236790244, 64.12389646257672, 63.22412558964321, 62.18598134177071, 59.04448536464146, 56.387897218976704, 49.58944272994995, 48.527754511152, 49.015045574733186, 50.9651061466762, 50.51615176882063, 50.4654403414045, 47.82995387486049, 46.49440588269915, 45.8959401675633, 49.90686770847866, 50.66276570728847, 54.65153891699654, 54.08058112008231, 56.333152362278526, 53.77414819172451, 58.44768374306815, 54.749272278376985, 46.617121492113384, 48.19838905334473, 50.353178296770366, 54.17914131709507, 49.91838782174246, 55.25019918169294, 54.00344221932547, 56.74139724458967, 55.147143500191824, 49.21757166726248, 55.034388133457725, 58.29583781106131, 58.40049852643694, 52.246948037828716, 44.2069616317749, 39.514672892434255, 38.087863785879954, 44.40236234664917, 48.03242090770176, 40.05398164476667, 32.60438019888741, 36.283163002559114, 34.08168881280081, 33.24510138375418, 44.02587420599801, 46.43366820471627, 37.522784164973665, 42.19044501440865, 41.11274119785854, 41.08453845977783, 38.70816421508789, 50.7930131639753, 54.55249582018171, 53.219633306775776, 51.96903051648821, 52.699605805533274, 55.3168671471732, 56.04224518367222, 53.45322479520525, 51.76480211530413, 50.34403446742466, 49.096902302333284, 51.13560799189976, 52.29804509026663, 51.24703625270298, 52.102894510541645, 51.15580987930298, 49.659890515463694, 51.53259679249355, 52.44829641069685, 53.673677240099224, 52.80463824953352, 53.14875820704869, 49.976033551352366, 49.575914587293354, 49.66890580313546, 48.84680189405169, 50.77099084854126, 44.95759637015206, 43.85809258052281, 51.68645770209176, 55.226200103759766, 56.436336585453574, 57.18890987123762, 55.21127189908709, 55.0705326625279, 53.959230831691194, 52.7196478843689, 49.95829480034964, 49.70872245516096, 51.416884967258994, 53.73663139343262, 54.291479791913716, 53.66343559537615, 49.386110646384104, 52.81113134111677, 54.2945613179888, 58.291126932416645, 60.35803536006382, 63.2798501423427, 65.56539058685303, 64.6128203528268, 58.5112041745867, 36.20817804336548, 14.555639658655439, 10.443670545305524, 8.704716222626821, 19.29828633580889, 30.69097137451172, 12.29140065397535, 1.8707492734704698, 0.21193605688001427, 0.17722875997424126, 37.48530905587332, 73.30569771357945, 67.87521498543876, 66.67208576202393, 44.41192306791033, 41.119011947086875, 59.62076200757708, 43.48268835885184, 0.94995564860957, 1.8700427285262515, 8.295771309307643, 11.505917225565229, 4.198894117559705, 0.6942345276474953, 1.1460230648517609, 3.0164939761161804, 32.4543581690107, 104.9061257498605, 43.8655549458095, 23.208934000560216, 14.054761392729622, 5.036750461374011, 24.6715350151062, 68.96169090270996, 55.52762338093349, 36.0200833593096, 40.69549492427281, 59.89334678649902, 49.983586243220735, 62.36265318734305, 60.72763088771275, 56.816253662109375, 13.765302913529531, 0.39335657549755915, 0.30852778309157913, 0.13740340912980692, 0.5192981032388551, 0.16194439227027552, 0.46109326077359064, 3.0545397060258046, 28.819263901029313, 52.89244610922677, 56.355876445770264, 61.3913506099156, 64.90709045955113, 62.23348617553711, 60.69314002990723, 58.23923083714077, 56.31827279499599, 55.226714270455496, 56.50545726503645, 54.261526107788086, 55.50084849766323, 59.30987180982317, 61.85109206608364, 61.16681957244873, 58.5112111227853, 56.10731158937727, 55.696839809417725, 56.89143664496285, 64.57346575600761, 67.5077942439488, 66.98877075740269, 65.90479619162423, 62.84302384512765, 60.36451802934919, 53.585636615753174, 51.18518686294556, 52.01175846372332, 52.64568083626883, 54.52415064402989, 53.908630575452534, 50.71442903791155, 48.793891361781526, 47.93940884726388, 53.94022056034633, 54.08938448769705, 58.437435150146484, 56.703977721078054, 58.309741156441824, 56.406108447483604, 63.24377509525844, 53.62986537388393, 48.15589039666312, 51.91965661730085, 55.06082950319563, 54.02515186582293, 52.19526733670916, 56.35395874295916, 53.82786471503121, 59.585215023585725, 58.71087455749512, 52.325212546757285, 58.04843330383301, 60.23632376534598, 65.22913251604352, 58.132666315351216, 48.718531199863975, 41.4384241104126, 40.08540834699358, 48.26817328589303, 47.18657152993338, 41.50046457563128, 35.794808864593506, 37.26268182482038, 34.578092438834055, 34.606705120631624, 45.68535416466849, 47.77689048222133, 39.22660057885306, 43.294572830200195, 44.759298256465364, 39.19934974397932, 39.22986970629011, 55.9621776172093, 58.77525656563895, 53.032233442579, 54.218384742736816, 54.8488712310791, 57.59076935904366, 59.729751450674875, 55.51208026068551, 54.963961192539756, 52.52369826180594, 52.664430550166536, 54.183945996420725, 56.04053592681885, 54.825688566480366, 52.465632166181294, 51.494253158569336, 52.11079808643886, 53.87090880530221, 55.267489773886545, 56.47416605268206, 54.9626271384103, 56.70590584618704, 54.06303691864014, 53.11634138652256, 52.318629128592356, 52.920357022966655, 52.89354739870344, 48.77346018382481, 47.26463106700352, 54.36631536483765, 59.288026673453196, 58.932480403355186, 61.18810885293143, 58.92843655177525, 58.08215985979353, 57.018654687064036, 58.37629795074463, 54.68694346291678, 53.87739494868687, 57.1878467968532, 57.81464726584298, 58.48430074964251, 56.1291949408395, 52.40438379560198, 56.00231736046927, 58.53401511056082, 61.31761632646833, 64.16206986563546, 66.73624542781285, 68.46995994022915, 67.96469388689313, 64.04570143563407, 58.21367188862392, 34.622647762298584, 19.513046469007218, 22.968274457114084, 33.51899242401123, 38.50853899547032, 17.448354516710552, 5.449886875493186, 0.6201299812112535, 0.5931701021535056, 49.83962651661464, 77.62737996237618, 75.74409852709088, 74.63284533364433, 57.33732686723982, 55.00033501216343, 70.28168187822614, 57.780111244746614, 1.3776929421084267, 3.840496914727347, 19.98195607321603, 17.634163243430002, 12.31760925906045, 2.892397629363196, 1.960157824414117, 3.4735608100891113], [14.557545202119009, 6.499928176403046, 9.808441911424909, 11.533597111701965, 3.9636650255748203, 0.4544521671320711, 14.972746099744525, 39.22530473981585, 32.13727365221296, 17.597759893962316, 28.167180674416677, 33.752285139901296, 65.95701885223389, 40.69266700744629, 48.42895460128784, 34.20529726573399, 11.512205345290047, 0.2711341253348759, 0.11075764428824186, 0.15321968043489115, 0.10556790312486035, 0.23564994654485158, 0.7408383754747254, 3.4759370940072194, 7.632559674126761, 19.654892206192017, 34.933628286634175, 51.03533853803362, 60.57988439287458, 59.625896726335796, 58.34114006587437, 54.81744452885219, 53.24959046500069, 51.818727084568565, 50.1895204271589, 47.71147666658674, 48.79574653080532, 50.98654133932931, 55.19999844687325, 55.626326016017366, 54.161871569497244, 51.94225563321795, 47.82817166192191, 49.40646539415632, 49.41123185838972, 55.0292638369969, 56.33158901759556, 58.46657589503697, 58.284505299159456, 53.16601405824934, 47.65357732772827, 47.41826616014753, 45.49808284214565, 44.228247438158306, 46.80488613673619, 43.81441273008074, 42.52646337236677, 47.61285740988595, 44.54350805282593, 47.473431382860454, 49.999612263270784, 51.129531792231965, 54.967244216373985, 52.03165463038853, 55.553335189819336, 51.42553547450474, 47.89552402496338, 49.84958675929478, 49.86754090445382, 48.66171925408499, 50.841987541743684, 49.25309780665806, 50.09222132819039, 56.4581469808306, 55.15731913702828, 51.28810358047485, 47.52254819869995, 51.99888345173427, 54.02933120727539, 45.64951535633632, 40.68150472640991, 36.52744082042149, 35.748509543282644, 38.72041041510445, 45.33818742207119, 54.91961778913225, 46.078462396349224, 31.50096457345145, 32.91740696770804, 30.289553097316197, 32.60665225982666, 49.210053716387065, 48.13708162307739, 38.254016058785574, 36.91290603365217, 35.11190169198172, 40.26606151035854, 39.28171716417585, 42.76290014811924, 52.85649960381644, 51.97875452041626, 49.34141288484846, 50.81174898147583, 54.6414292880467, 54.72213956287929, 52.668074880327495, 48.38165821347918, 48.08830874306815, 46.31396811349051, 47.46960987363543, 50.1603102002825, 47.57864448002407, 49.43040541240147, 47.30286700384957, 45.61436441966465, 45.088691507067, 47.578401293073384, 47.59750883919852, 47.46718495232718, 47.76722206388201, 45.230163778577534, 44.57679687227522, 41.90783745901925, 46.17662654604231, 43.23740652629307, 40.71491166523525, 42.383792536599294, 51.79677077702114, 54.03679357256208, 54.775821345193044, 58.430917739868164, 57.67002051217215, 55.64272723879133, 50.533761978149414, 45.319218839917866, 42.325754233769004, 40.88024057660784, 43.177922998155864, 43.367195401872905, 47.947965553828645, 44.23586613791329, 44.322815895080566, 47.89027118682861, 51.478644030434744, 53.19661392484392, 56.425594670431956, 58.842313630240305, 59.4840145111084, 57.6226372718811, 48.022853238242014, 31.174889087677002, 10.228131345340184, 10.890638606888906, 9.66544885294778, 15.758639471871511, 30.103403908865793, 21.56718237059457, 0.31447915945734295, 0.31478314314569744, 0.40097090548702646, 47.86585521697998, 63.540914808000835, 56.205107484545024, 64.14700617109025, 33.51913138798305, 36.11621516091483, 46.589088984898154, 24.721207686832972, 0.8631878473928997, 1.3946163654327393, 8.067042691367012, 10.682422808238439, 3.210730867726462, 3.4713627908911024, 0.13448357794966015, 3.9747591274125234, 15.17689459664481, 58.3864631652832, 19.39665198326111, 15.21888256072998, 9.39933284691402, 1.7907405495643616, 24.111845459256852, 50.04921197891235, 44.862621443612234, 26.26734515598842, 28.312568255833217, 42.5976858820234, 59.63339383261544, 52.56889629364014, 54.69549322128296, 52.995442731039866, 18.04847390311105, 0.07255251971738678, 0.10695064892726285, 0.11129777173378638, 0.0949671980259674, 0.14184481437717164, 0.39442358538508415, 2.809242240020207, 14.172987597329275, 31.615557738712855, 47.4190547806876, 57.030581269945415, 63.698645864214214, 59.439608573913574, 60.537284987313406, 56.02721970421927, 55.35831662586757, 53.57042006083897, 54.000444071633474, 51.11153595788138, 51.76241888318743, 53.63320050920759, 59.31153242928641, 57.05852345057896, 58.41212286267962, 55.07344395773751, 49.68761035374233, 51.673464570726665, 53.62687764848982, 58.79953357151577, 58.782364572797505, 60.65035302298409, 60.18271146501814, 55.896812438964844, 47.689287594386506, 48.60077313014439, 47.895228726523264, 46.59875045503889, 47.055135931287495, 46.241675581250874, 44.81589828218733, 48.52226890836443, 49.264016900743755, 52.491236277988975, 52.20626286097935, 53.468055725097656, 54.473355838230674, 55.402298722948345, 58.83998598371233, 55.447302205221995, 50.23884221485683, 51.99384600775582, 49.77906601769583, 50.628681319100515, 51.9605085509164, 51.0046136038644, 51.55955580302647, 57.9944874899728, 55.611620153699604, 54.262262616838726, 51.688309397016255, 55.14843239103045, 55.54965264456612, 46.307749475751606, 42.91754273005894, 40.135567392621724, 36.83399881635393, 42.26821272713797, 47.73780339104788, 57.775414262499126, 49.5930940083095, 34.14487573078701, 31.213017327444895, 30.514396803719656, 35.10278218133109, 51.86830595561436, 49.61335842950003, 40.99950640542166, 39.90004777908325, 36.96366957255772, 41.93817676816668, 41.958531515938894, 42.33358832768032, 55.53285190037319, 54.21233286176409, 53.3766313280378, 52.136773926871165, 56.112686020987375, 55.519018036978586, 55.27331236430577, 50.38402482441494, 50.06624548775809, 47.392953872680664, 48.898489543369834, 52.54864229474749, 50.983994824545725, 51.77196223395211, 49.971065589359824, 49.20845563071114, 47.85376187733242, 49.94278294699532, 50.6104805128915, 50.51423406600952, 50.45078311647688, 47.282890932900564, 45.386129992348806, 45.92762047903878, 47.80585057394845, 45.658579281398225, 43.0529214314052, 44.188184125082834, 53.37406049455915, 56.30347660609654, 55.57099403653826, 59.74653829847063, 58.25207805633545, 55.91901888166155, 54.07532828194754, 49.52897603171212, 47.374853815351216, 45.66091735022408, 47.96981416429792, 48.05804239000593, 50.80864661080496, 47.84809562138149, 50.274260657174246, 52.463770048958914, 57.16055774688721, 57.67960555212838, 61.27382183074951, 63.313673973083496, 64.47058377947126, 64.02401610783168, 61.808659417288645, 46.11836590085711, 20.245072194508143, 17.048661129815237, 13.224575860159737, 21.65726055417742, 37.10061509268624, 25.383947713034495, 1.2822531376566206, 0.20521642959543637, 0.5175662104572568, 56.281683581215994, 71.97832080296108, 65.24925449916294, 72.92952224186489, 42.65731184823172, 38.77029153278896, 53.88537842886788, 40.49979543685913, 0.544017459665026, 3.1940541054521288, 8.177559869629995, 12.796208994729177, 5.56563127040863, 3.1626682238919392, 0.3752068765461445, 3.967007977621896, 23.449605703353882, 55.21860224860055, 19.59895052228655, 17.26408134187971, 7.743195840290614, 1.2236701611961638, 33.75258043834141, 67.14902400970459, 58.46542944226946, 39.92262247630528, 41.9117944581168, 49.06602450779506, 77.81625284467424, 61.48078782217843, 63.929791586739675, 69.05286516462053, 28.064375128064835, 0.3005802924079554, 0.7115851023367473, 0.25261921169502394, 0.17103300243616104, 0.2042825347078698, 1.1976261415651865, 7.818141715867179, 23.186790091650828, 42.21135214396885, 51.659787041800364, 64.45183059147426, 63.488323892865864, 64.94702870505196, 62.035087312970845, 60.26468631199428, 57.73050110680716, 59.38988726479666, 54.71965210778372, 57.86882931845528, 57.05922174453735, 60.45329516274588, 65.83544622148786, 62.15595817565918, 62.905105999537874, 58.721206528799875, 54.45530094419207, 54.954570702144075, 57.564001423971995, 59.512995447431294, 63.87974371228899, 62.23099177224295, 63.603865487234934, 58.56397574288504, 50.9744097845895, 51.15061262675694, 51.20376982007708, 48.38984319141933, 51.983399391174316, 48.506743158612935, 48.2956360408238, 53.527369022369385, 48.723658970424104, 54.65048973900931, 56.06669936861311, 57.4343341418675, 58.151127679007395, 56.78537586757115, 60.82637868608747, 57.326734338487896, 54.295019899095806, 53.96755129950387, 52.90870836802891, 51.18212965556553, 53.49568176269531, 51.99088260105678, 53.86552047729492, 59.567344256809776, 60.15637084415981, 56.13714715412685, 53.96433775765555, 57.03018869672503, 58.71511990683419, 48.390062059674946, 43.28375448499407, 42.675133977617534, 39.38752433231899, 44.115860325949534, 49.880502768925254, 62.3181916645595, 49.96365533556257, 32.160987854003906, 34.46127585002354, 32.532591411045615, 33.50653430393764, 52.75128650665283, 52.39662265777588, 41.92462778091431, 40.54351350239345, 37.39553485597883, 43.04719264166695, 41.341041633060996, 45.588708196367534, 57.104628222329275, 56.580417905535015, 55.52781793049404, 55.451828956604004, 58.823490960257395, 58.266162054879324, 56.116920948028564, 53.32400567190987, 51.098351751055034, 50.724740164620535, 51.90731314250401, 56.02430146081107, 53.60573775427682, 54.00109372820173, 50.42526585715157, 51.60166188648769, 49.101046902792795, 53.20060566493443, 51.65861627033779, 53.091449465070454, 53.418678351810996, 50.804901531764436, 48.162449496132986, 48.65867941720145, 50.99515363148281, 49.063623905181885, 45.81789452689034, 46.6327862058367, 57.2388778414045, 57.23910365785871, 58.12142065593174, 60.7704039982387, 60.86630998338972, 59.16391795022147, 58.87963935307094, 53.5139867918832, 52.1929292678833, 50.74780123574393, 51.54458243506295, 51.840544428144185, 51.63096938814436, 50.65010608945574, 51.87913472311837, 56.26336465563093, 58.924274580819265, 60.04514408111572, 62.53486428941999, 67.89790780203683, 64.4729253223964, 68.43987424033028, 65.27747113364083, 61.855393001011436, 48.673392227717805, 34.97519588470459, 32.50128630229405, 41.896414620535715, 48.99025092806135, 30.77085828781128, 3.512814223766327, 0.47194428422621315, 1.355595390711512, 64.4300479888916, 77.67180674416679, 73.69517203739711, 80.83686406271798, 55.09380217960903, 52.01583010809762, 70.12529182434082, 58.446071760995046, 1.7036788612604141, 6.796585423605783, 22.943815061024257, 21.539624077933176, 17.224638155528478, 9.998669692448207, 0.20447624288499355, 4.966697420392718], [11.918327552931649, 2.718716766153063, 9.762545585632324, 6.431463667324611, 3.3982575365475247, 0.1728186487619366, 18.00095864704677, 36.676354612622944, 27.31654051371983, 17.3927116053445, 31.425955295562744, 43.02778284890311, 56.077482972826274, 37.15310525894165, 57.07435492106846, 38.039612020765034, 21.46253034046718, 0.04264357479821358, 0.06924748420715332, 0.11227573747081415, 0.03001414838113955, 0.022263918005462204, 1.022152100290571, 5.618135333061218, 10.634666970797948, 19.79823875427246, 36.81377261025565, 56.17282615389143, 63.22903101784842, 61.83786269596645, 61.650789397103445, 55.89513792310442, 52.37322112492153, 49.8772405896868, 48.70426654815674, 47.70609528677804, 48.088135038103374, 48.619908469063894, 53.59263692583357, 55.59487499509539, 55.34413882664272, 53.44093690599714, 49.51241500037057, 48.13441004071917, 49.49566289356777, 50.31738812582833, 50.35064220428467, 54.08090073721749, 51.415179184504915, 50.79654632295881, 44.501495770045686, 43.841986656188965, 44.98406205858503, 45.46288326808384, 44.23176670074463, 46.30991383961269, 44.70137112481253, 48.88094881602696, 50.11537619999477, 49.24276236125401, 49.32192318780081, 51.806793553488596, 53.06086349487305, 53.81391620635986, 55.48552771977016, 55.89673948287964, 45.16876254762922, 43.51215219497681, 46.13290500640869, 49.26085547038487, 47.016510895320344, 48.31487907682146, 44.75482709067208, 52.52719667979649, 55.71505798612322, 50.43090432030814, 50.077623162950786, 50.534859793526785, 57.16626221793038, 52.09564059121268, 42.01808452606201, 39.05972221919468, 36.2109295300075, 41.34440803527832, 49.73878036226545, 53.248374530247276, 54.22480140413557, 49.96120956965855, 32.25336415427071, 37.22096136638096, 51.408064229147776, 54.1337765284947, 51.761352334703716, 41.988502570560996, 37.914912700653076, 36.17974254063198, 40.23369680132185, 42.65365014757429, 37.43310376576015, 54.189563614981516, 51.33347879137312, 51.111449105399, 51.35168654578072, 49.39914894104004, 50.98108352933611, 50.825919832502095, 47.3888509614127, 45.030945028577534, 45.80960880007063, 48.924149240766255, 49.05482748576573, 51.59198304585048, 51.84370238440377, 47.980799266270225, 47.450314726148335, 46.307336057935444, 45.212327752794536, 45.531573159354075, 43.95352956226894, 43.41596828188215, 42.765748909541536, 41.17352751323155, 41.0829507963998, 40.24041223526001, 40.17358446121216, 39.99934101104736, 43.02293995448521, 48.705395630427766, 57.67610018593924, 54.46458721160889, 56.558551924569265, 58.41241468702044, 55.42478656768799, 51.57589796611241, 47.273715836661204, 40.79612568446568, 37.761579854147776, 39.95389979226248, 40.9987907409668, 43.70700747626168, 42.6235922404698, 47.7568484033857, 48.84627383095877, 52.7133458682469, 55.5891809463501, 60.1034186226981, 58.56536538260323, 59.660630771092, 57.23607424327305, 53.10381725856236, 39.63433476856777, 22.46030902862549, 17.541498592921666, 16.21291443279811, 28.44363907405308, 46.588637351989746, 38.56449283872332, 1.8132845227207457, 1.0373088355575288, 1.6117735185793467, 47.30016762869698, 57.608549799237935, 58.358107566833496, 58.472704206194194, 29.586277280535015, 30.49418796811785, 39.0995979309082, 14.865026439939227, 0.7546103021928242, 2.616295324904578, 15.060401099068777, 15.370526994977679, 5.04203109230314, 1.3221710813896996, 1.5044350326061249, 6.6532115169933865, 18.205447605678014, 36.915403911045615, 13.148831810270037, 12.05124224935259, 6.457273185253143, 0.6494158240301269, 28.856461082186016, 47.76283080237252, 37.9856036731175, 24.21444603375026, 30.33427517754691, 43.72894641331264, 63.832864216395784, 49.74141372953142, 64.5531005859375, 49.336674213409424, 29.128305877958024, 0.053586736521018405, 0.08172676100262574, 0.06836445908993483, 0.07883956057152577, 0.03900964997176613, 1.7138628576483046, 5.09521130153111, 11.455323917525154, 24.448939050946915, 47.864760875701904, 58.438894271850586, 64.6033638545445, 63.442514419555664, 62.67296668461391, 57.800643171582905, 54.27917800630842, 52.09836081096104, 53.03202847072056, 50.22775983810425, 52.48661920002529, 52.15625320162092, 56.91648837498256, 59.976759910583496, 60.064182145254954, 57.419458048684255, 53.117157799857004, 52.11264630726406, 51.97220931734358, 54.02513102122715, 54.06106015614101, 56.192228998456685, 54.01437520980835, 53.742519991738455, 46.56420748574393, 45.83954163960048, 46.23724957874843, 47.84319714137486, 45.75619452340262, 49.983065128326416, 48.4557329586574, 49.43784345899309, 50.79359681265694, 52.89030258996146, 53.200310366494314, 53.85290602275303, 54.73145014899117, 54.868399143218994, 57.800907203129356, 56.05460950306484, 48.362060819353374, 46.32579047339303, 48.984536034720286, 50.52655669621059, 49.71865143094744, 48.32756648744856, 47.435942377362935, 56.01457745688302, 56.41561705725533, 52.509124415261404, 51.920712743486675, 54.218614033290315, 58.15944814682007, 53.02282905578613, 41.70372370311192, 40.63314526421683, 37.29426833561489, 45.04537296295166, 49.845424788338796, 53.74543823514666, 56.261884689331055, 52.606239386967246, 34.984162534986226, 40.307413714272634, 53.121736662728445, 55.78128126689366, 53.53783995764596, 45.120135579790386, 39.21541050502232, 38.66423075539725, 40.99100875854492, 43.14647197723389, 39.156854561397004, 54.02196959086827, 53.51832594190325, 52.06723982947213, 52.164181096213206, 51.72052124568394, 52.10133811405727, 51.800745146615164, 49.80659825461251, 48.36259235654558, 48.76599434443882, 50.658728803907124, 50.38353845051357, 53.57750374930245, 53.96576908656529, 49.41438634055001, 49.989811829158235, 48.168921743120464, 47.335898739951, 48.04213796343122, 45.25602497373308, 46.20886966160366, 43.8703943661281, 42.847327709198, 44.186363697052, 42.25267308098929, 41.947942461286274, 41.516077177865164, 44.63069404874529, 50.48667403629848, 56.99267537253243, 55.45192970548357, 56.033740588596885, 59.03852381025042, 58.53347315107073, 55.68213047300066, 53.562777042388916, 47.57159205845424, 42.39680651256016, 43.730499335697715, 45.25707415172032, 47.47407756532942, 45.73162916728428, 50.19629839488438, 53.913202490125386, 57.21184240068708, 61.44403879983084, 65.44414452144078, 63.99684170314244, 64.98755059923444, 64.95880590166364, 62.57123810904366, 52.26596873147147, 33.7770276750837, 23.220356839043752, 22.268844468253, 35.192983695438926, 54.902914319719585, 45.041878019060405, 2.953191110066005, 1.012317793709891, 2.303645278726305, 60.83816977909633, 65.84634099687848, 67.85218865530831, 69.54800074441093, 39.030421665736604, 34.46575743811471, 46.10655396325247, 29.350059373038157, 1.302844015615327, 4.944022408553532, 14.15755477973393, 17.812709365572246, 8.877430200576782, 2.4215902984142303, 3.0609224949564253, 4.9249513404709955, 34.62714672088623, 33.44824586595808, 13.698088645935059, 11.231995786939349, 5.732253415243966, 0.3510562410312039, 38.56953375680106, 66.14437702723912, 53.86291142872402, 38.026302746364046, 45.158312456948416, 61.10507093157087, 73.78974396841866, 57.637582847050254, 74.6469223839896, 63.70517717088972, 39.25952114377703, 0.21394616258995874, 0.1769461501389742, 0.1374109951513154, 0.356800447085074, 0.0915494646344866, 1.7101414459092277, 11.35293960571289, 22.66815744127546, 35.46118763514927, 58.503026144845144, 63.961878367832725, 66.40837383270264, 64.83621188572475, 65.47102015359062, 60.67335850851876, 59.09611742837088, 54.58980417251587, 55.88004296166556, 57.75868647439139, 56.811938830784385, 56.081043924604145, 60.7682500566755, 63.91736820765904, 64.82163456508091, 60.088028362819124, 56.99779966899327, 56.29799795150757, 54.950422627585276, 56.76752247129168, 56.93790967123849, 58.05073663166591, 57.591398171016145, 55.59890147617885, 49.23964262008667, 48.44532803126744, 48.80247586114066, 50.55446413585118, 48.32901866095406, 53.469177859170095, 49.64719615663801, 52.746659006391255, 56.502830845969065, 54.79638801302229, 55.48876558031355, 55.66090720040457, 59.1903350012643, 57.522857666015625, 60.41874871935163, 58.74938147408621, 50.74329532895769, 48.700893197740825, 52.74119077410017, 54.686133997780935, 51.02400255203247, 50.90413222994123, 48.424257619040354, 56.95542260578701, 60.86002881186349, 54.697761808122905, 54.082029819488525, 56.43421391078404, 59.119102069309776, 52.14613315037319, 43.95525271551949, 43.285620076315745, 41.01252385548183, 45.545775277274, 53.50490549632481, 57.273094245365684, 59.67071955544608, 53.702870096479145, 33.05365766797747, 39.38217074530465, 54.54078115735735, 60.60934475490025, 56.80907964706421, 45.645478452954976, 41.03643608093262, 40.850978238242014, 45.1798449243818, 44.495930262974326, 39.38503687722342, 57.60093109948294, 56.05586017881121, 53.42853089741298, 53.90222781045096, 52.12463889803205, 54.33196347100394, 55.10357829502651, 49.93017544065203, 50.71068395887102, 51.3499390738351, 55.10440513065883, 54.61289998463222, 57.60358878544399, 57.31994594846453, 49.116850580487935, 52.72071443285261, 51.436763763427734, 50.01948063714163, 51.603961740221294, 47.32683481488909, 46.70409556797573, 46.1548752103533, 46.15190832955496, 46.010196345193044, 46.25205966404506, 44.845664364951, 42.44916466304234, 46.87396860122681, 53.60433421816145, 58.69424751826695, 56.617396218436106, 59.193767411368235, 62.368413243974956, 63.74227360316685, 60.672420501708984, 59.804819788251606, 53.2436705998012, 48.47971814019339, 48.54759856632778, 46.62795025961739, 49.99119104657854, 50.31989295142037, 53.08642244338989, 57.712439264569966, 60.64544759477888, 63.92068944658552, 67.7852566582816, 67.89549677712577, 66.82405676160539, 66.90842178889683, 66.15106119428361, 62.7283855165754, 52.11539084570748, 46.99988038199288, 47.28661864144461, 56.20284237180437, 63.056708744594026, 51.92447171892439, 5.679421918732779, 1.4055368708712714, 3.931176117488316, 72.37659154619489, 72.0600038255964, 75.40758337293352, 80.33195236751011, 51.467961175101145, 49.78702865328108, 57.97512286049979, 53.57940060751778, 2.4571526987212042, 15.421161992209298, 33.2066604750497, 35.60317407335554, 24.881850038255962, 5.495908268860408, 4.252055219241551, 22.192205837794713], [20.37341931888035, 2.3412641286849976, 4.352950010980878, 3.396538074527468, 1.8998945781162806, 0.34245803526469637, 22.39527562686375, 36.761417933872764, 32.11438281195504, 21.069330045155116, 35.93470042092459, 49.19271796090262, 55.90075554166521, 45.96044029508318, 57.66258593967983, 49.07565123694283, 30.483095169067383, 2.1460996525628224, 0.05771700292825699, 0.020664166526070664, 0.15756972772734507, 0.05245011233325515, 8.599151372909546, 15.659655434744698, 24.620373691831315, 35.7511568069458, 49.2297796521868, 63.26212528773716, 62.94835158756801, 65.67588084084647, 61.926396642412456, 56.55412939616612, 53.778751373291016, 47.51103155953543, 47.84411777768816, 47.10803256716047, 47.56735713141305, 49.39823177882603, 53.97226912634713, 54.83438423701695, 58.40737724304199, 57.79503597532, 54.65689597811018, 49.11444302967617, 48.0976436478751, 47.9383179800851, 48.739636353084016, 50.98418937410627, 50.739241055079866, 47.82191480909075, 44.63350459507534, 43.04017843518938, 45.927377292088096, 45.06829507010323, 45.069372040884836, 48.88333552224295, 50.69007560185024, 53.024941308157786, 50.55557584762573, 51.257121562957764, 52.44126830782209, 52.07194375991821, 53.27287040437971, 52.96590941292899, 53.590337072099956, 50.58376816340855, 50.079363686697825, 51.07950823647635, 47.421920912606375, 48.707417556217735, 44.953114782060894, 45.24727719170706, 44.47460971559797, 51.728841713496614, 54.08125509534563, 50.81805099759783, 49.265225887298584, 54.84174585342407, 53.90046991620745, 47.42135463442121, 39.58725724901472, 35.91020107269287, 36.93181208201817, 42.65714856556484, 44.960688318525044, 47.223233699798584, 49.81492567062378, 53.327087197984966, 50.69082600729806, 52.60149376732962, 50.897298676627024, 50.735502924237935, 47.970776489802766, 42.85348728724888, 39.65209436416626, 36.27769129616873, 38.588398115975515, 42.35299812044416, 37.32387113571167, 46.42222452163696, 54.205811977386475, 51.46627623694283, 50.58500146865845, 49.96487821851458, 47.61784621647426, 43.74183184759957, 44.87876558303833, 45.588228770664756, 43.25431844166347, 42.075247355869834, 48.83350651604788, 52.37468024662563, 52.575299058641704, 49.603158473968506, 48.379632813589915, 43.76079000745501, 45.22860738209316, 43.479718003954204, 43.015620027269634, 40.5772921698434, 40.5714487348284, 40.37768432072231, 40.15536975860596, 39.61337552751814, 40.271105902535574, 40.28367519378662, 41.134954588753835, 47.6242733001709, 55.65824951444353, 57.85246978487287, 55.61502824510847, 54.794796875544954, 51.62006766455514, 49.94968598229544, 44.727187156677246, 42.96600988933018, 35.91797958101545, 37.679514680589946, 37.462897641318186, 40.82429368155343, 42.86644220352173, 47.870986461639404, 51.35635226113455, 56.07695838383266, 57.65192740304129, 60.767638615199495, 57.997912951878135, 58.8453152520316, 58.6347987311227, 57.49123988832746, 48.99742146900722, 37.310308252062114, 28.552472182682582, 31.529059614453995, 47.70085287094116, 60.97614710671561, 48.88867521286011, 6.689785097326551, 1.1362310988562447, 5.255426338740757, 56.695830958230154, 57.100084100450786, 50.70513234819685, 61.72925540379116, 26.834314686911448, 27.577341147831508, 28.5808937890189, 10.039564183780126, 0.32148335075804163, 1.9018068526472365, 23.841147116252355, 28.61024124281747, 6.510689198970795, 7.076444097927638, 6.56504408802305, 22.152974571500504, 22.726927042007446, 10.606985347611563, 9.200412000928607, 7.705065863473075, 3.5609773993492126, 0.21745741846305983, 36.9132673399789, 50.49691915512085, 41.9778926713126, 24.744871514184133, 36.40885591506958, 50.77739013944353, 66.24862085069928, 53.752080712999614, 65.83677332741874, 56.9789457321167, 41.26442037309919, 2.003109851053783, 0.10792898785855089, 0.27068156961883816, 0.09311205614358187, 0.07141819915601186, 3.7735983559063504, 12.787355252674647, 31.396008559635707, 39.56122234889439, 55.15244150161743, 65.37309919084821, 65.48456914084298, 68.03345326014927, 62.10343674251011, 59.7494079044887, 54.03443118504116, 52.31600270952497, 51.37017570223127, 52.001370906829834, 49.37722737448556, 54.879512786865234, 57.386561802455354, 59.9827492577689, 61.78867639814104, 61.74093532562256, 57.186804567064556, 52.04840326309204, 49.95457404000418, 50.20235027585711, 52.64057043620518, 53.850345611572266, 53.22211728777204, 50.08257375444685, 46.78771366391863, 45.82725722449166, 46.30081517355782, 47.54692595345633, 47.9669063431876, 51.5643743787493, 52.66218628202166, 55.96176767349243, 53.89329590116228, 54.01923547472273, 55.59866523742676, 54.504657472882954, 56.00072622299194, 56.53465359551566, 57.62499271120344, 55.34701190676008, 52.91822392599923, 55.379473890577046, 52.38810069220406, 52.14314195087978, 47.39394399097988, 46.905909470149446, 47.96580505371094, 54.58681297302246, 55.84800829206194, 54.410134179251536, 53.317835671561106, 56.67489603587559, 53.094819341387065, 48.685801710401265, 41.849489961351665, 39.26865802492414, 38.773664883204866, 45.07446159635271, 47.77443429401943, 48.84323051997593, 50.812610558101106, 52.27033914838518, 53.03520379747663, 52.97194044930594, 52.94523852212088, 52.0814836365836, 49.67770569665091, 45.84926911762783, 41.86519636426653, 35.869797297886436, 38.92200544902256, 44.51309578759329, 39.398200239454, 44.18034655707223, 55.903031076703755, 53.892208508082796, 51.51667846952166, 50.74339607783726, 49.953872271946494, 45.25736250196184, 48.17924676622663, 45.89484582628523, 43.85834618977138, 42.9714538029262, 52.755361625126426, 53.499993119921, 56.271507944379536, 50.83615452902657, 51.06303405761719, 45.943378993443076, 47.29404279163906, 45.8036333492824, 45.16009814398629, 42.46097312654768, 42.232047353472026, 42.306917667388916, 42.551066943577354, 41.64585215704781, 41.84498405456543, 42.704976490565706, 42.9326411655971, 47.77840518951416, 57.748684542519705, 58.24771111352103, 56.700340339115684, 57.30035202843802, 56.17217302322388, 56.41467210224697, 52.70605025972639, 51.10571336746216, 42.72049181801932, 44.521690709250315, 42.60454722813198, 44.70495639528547, 48.93216746194022, 51.617882456098286, 55.628188133239746, 59.62323556627546, 63.00150530678885, 64.55343409946987, 63.810852323259624, 63.416479519435335, 65.57820306505475, 66.61023984636579, 58.47679669516427, 49.44773769378662, 38.64495645250593, 42.029430934361045, 57.486393519810264, 66.9784665788923, 57.81385864530291, 10.09473635469164, 0.9929697747741426, 6.9030561447143555, 67.74392182486397, 66.9710945401873, 63.45090784345354, 71.31738730839321, 39.544925349099294, 32.296988419124055, 37.34035921096802, 26.325852462223597, 0.34050621571285383, 7.443270768438067, 24.045907054628643, 27.014547484261648, 10.254999160766602, 5.681733497551509, 4.325951048306056, 12.77440641607557, 62.7399195262364, 11.134398783956255, 7.545424052647181, 6.178318645272936, 3.419308189834867, 0.5173719865935189, 52.494897978646414, 64.44065788814, 59.623402323041645, 38.19108622414725, 53.251223291669575, 62.040840421404155, 70.9354031426566, 62.97466441563198, 75.91359983171735, 67.12540708269391, 57.53570141111101, 3.71333532673972, 0.3075990857822554, 0.2064475906746728, 0.39875147172382897, 0.1702033169567585, 10.90191900730133, 35.30366849899292, 52.96139308384487, 53.944844586508616, 63.47954831804548, 68.5811380658831, 68.77303341456822, 70.50879764556885, 66.42107513972691, 62.16510895320347, 58.932876450674875, 55.040707520076204, 57.28713655471802, 55.517704827444895, 53.80762808663504, 59.207754135131836, 60.88677937643868, 63.591518538338796, 64.82511561257499, 65.79556356157575, 61.56435380663191, 57.62323134286063, 52.67591939653669, 52.859737464359824, 54.47205999919346, 55.1925812448774, 56.35740852355957, 52.75788034711565, 49.947948932647705, 47.35370002474104, 51.24529225485665, 50.285047735486714, 50.25472927093506, 53.974426542009624, 57.479295934949604, 60.257369858878, 55.529416016169954, 56.455398968287874, 58.67640454428536, 57.671827043805806, 57.811815874917166, 58.979276520865305, 59.19284330095564, 57.64937741415841, 54.382042612348286, 56.468742983681814, 55.510603768484934, 55.689148153577534, 49.78559385027204, 50.768465178353445, 51.742144039699006, 57.094793047223774, 59.868368012564524, 56.80584178652082, 53.243872097560335, 60.33782305036272, 59.20730250222342, 53.58298587799072, 45.04467814309256, 41.92904336111886, 41.60183184487479, 48.13419464656285, 49.54553706305367, 52.63070052010672, 56.443284784044536, 57.6539215360369, 54.81646483285086, 55.95456239155361, 58.05650363649641, 57.139313629695344, 52.73130348750523, 48.899219104221885, 45.04436547415597, 38.59288317816598, 42.87112528937203, 47.31849697657994, 39.17534024374825, 46.883178438459126, 57.20909786224365, 54.1465334211077, 54.91246461868286, 52.07025187356131, 52.50480958393642, 46.77648190089634, 50.2888240814209, 47.92261157717024, 45.17767013822283, 46.56706666946411, 54.268342290605815, 56.43673610687256, 59.70084694453648, 52.39756761278425, 53.252765791756765, 48.32684734889439, 51.08187757219587, 48.78466067995344, 47.88753012248448, 45.099398681095664, 44.24423176901681, 46.075325284685405, 44.759117603302, 43.51810680116926, 43.79414483479091, 42.79496261051723, 43.339927196502686, 51.89385795593262, 59.814311027526855, 58.84947722298758, 58.28627708980015, 59.537869998386924, 60.15574550628662, 61.94114071982247, 59.246941975184846, 56.70061131886074, 48.48210832050869, 47.68188428878784, 46.19791235242571, 47.825993401663645, 51.69768599101475, 55.34861694063459, 59.07475866590227, 61.43514510563442, 64.37583119528634, 66.80226721082414, 65.1226235798427, 65.41018172672817, 66.34054551805768, 70.04688140324184, 64.35477120535714, 61.413341658455984, 53.57037142344883, 58.56859629494803, 68.37544359479631, 70.65198612213135, 60.13876410893032, 12.760166083063398, 0.8729594573378563, 8.579944814954485, 79.50859778267997, 74.3025905064174, 76.04972893851144, 81.34717450823102, 51.02908515930176, 44.361753599984304, 49.750745160239084, 54.68570668356759, 1.1923684179782867, 20.23421389716012, 48.46483857291085, 63.9648244040353, 33.068592820848735, 11.416051830564227, 20.529957021985734, 51.89266286577497], [37.93204001017979, 1.4557212122849055, 3.1379745432308743, 1.90274464232581, 0.6183400058320591, 0.44203961747033255, 30.819735390799387, 38.98536259787423, 27.55954507419041, 21.638552529471262, 33.833603382110596, 47.75628212520054, 50.87279238019671, 44.21593523025513, 61.027494294302805, 52.93198135920933, 48.72732067108154, 12.934867245810372, 0.4773187158363206, 0.6151899748614856, 0.18303676189056464, 0.506289718406541, 3.9114150064332143, 17.86125295502799, 42.8829858643668, 59.27458190917969, 59.52696132659912, 59.44698756081717, 65.51831654139927, 62.69208117893764, 61.45557975769043, 59.442610195704866, 51.87042168208531, 47.816661970955984, 46.66821507045201, 46.816034521375386, 45.97332572937012, 46.50096845626831, 51.890623569488525, 55.128980909075054, 58.07853984832764, 55.51269170216152, 56.480655670166016, 48.11463894162859, 47.04899372373308, 46.54212958472115, 45.131582736968994, 46.307978766305105, 46.200052397591726, 45.27024098805019, 44.30061640058245, 44.55577857153756, 41.73943396977016, 47.43646001815796, 49.57689775739397, 52.70116915021624, 53.51394510269165, 53.7300375529698, 55.29601560320173, 53.212059770311626, 52.932439940316335, 55.51124995095389, 54.426563194819856, 52.343969208853586, 54.352172306605745, 56.12479673113142, 52.37620537621634, 51.63085126876831, 51.98675537109375, 48.151419230869834, 45.27228375843593, 40.55405044555664, 42.90462950297764, 46.626459871019634, 51.02070215770176, 48.99199840000698, 55.07274913787842, 46.30519601276943, 40.612571648189, 41.475002901894705, 41.403794288635254, 38.89550849369594, 37.544222831726074, 40.96143027714321, 44.42020532063076, 42.105715206691194, 47.1945515360151, 41.756113120487754, 45.5217136655535, 45.46651022774832, 42.0890325818743, 47.313480377197266, 41.555678435734336, 43.762794562748496, 38.50256354468209, 36.43161473955427, 36.59751687731062, 42.652437686920166, 43.30460602896554, 41.109607560294016, 50.24413674218314, 51.48484182357788, 50.3961181640625, 50.15950768334525, 45.27265548706055, 40.91941104616438, 42.63810702732631, 42.87656225476946, 37.628535747528076, 40.61903347287859, 47.30443034853254, 51.97482878821236, 48.56584800992693, 50.14218929835728, 48.977862289973665, 45.854282242911204, 43.665311336517334, 41.073365756443565, 41.22168895176479, 41.67351640973772, 41.41467864172799, 39.8175413949149, 39.77899626323155, 39.4564574105399, 41.03643955503191, 43.01461253847395, 43.434777055467876, 44.050269331250874, 49.65121568952288, 57.43765190669468, 56.47752898080008, 57.081139836992534, 51.08114801134382, 45.95085178102766, 43.18928677695138, 45.1678592818124, 40.05967569351196, 38.244062764304026, 39.987004484449116, 41.74891478674752, 45.094580105372835, 49.41291332244873, 53.829678194863455, 58.40493147713797, 59.5939975466047, 60.45363562447684, 61.04808875492641, 59.92196641649519, 59.361899920872276, 56.54703181130545, 51.62214517593384, 47.500108991350444, 43.089503696986604, 47.366491658346995, 58.35502256665911, 61.48085035596575, 64.73151642935616, 17.7557167666299, 1.2260106184652872, 8.77912187576294, 54.18105901990618, 55.3443854876927, 49.26869651249477, 57.50199569974627, 22.17011751447405, 24.326748030526296, 24.33861207962036, 0.16247199395937578, 0.4868456189121519, 2.9151462486812045, 26.104446377073014, 44.24681649889265, 26.173917940684728, 14.873954875128609, 15.93160445349557, 46.8687470299857, 23.221593618392944, 3.162101077181952, 5.530052150998797, 3.8561186364718845, 1.831838927098683, 0.7239495845777648, 41.932927404131206, 51.48630789348057, 38.998043060302734, 28.271212577819824, 42.23111629486084, 47.727207388196675, 59.10395499638149, 51.79402276447841, 69.67703574044364, 60.70609147208077, 63.34613595690046, 13.180320177759443, 0.32929860853723114, 1.5327419936656952, 0.06814970954188279, 0.12831166413213524, 6.428254468100412, 29.93363857269287, 59.67528452192034, 60.53623580932617, 61.44654015132359, 62.371310642787385, 65.10650375911167, 69.59157289777482, 60.24398762839181, 63.22415338243757, 54.07456745420183, 53.30921990530831, 48.53557818276541, 51.644848414829795, 49.41430296216692, 52.21884952272688, 54.77230903080532, 60.35692364828927, 59.73043237413679, 61.75571414402553, 59.30058901650565, 52.53888354982649, 48.95687525612967, 49.399944509778706, 48.56363500867571, 47.22780908857073, 49.60298476900373, 48.83438893726894, 45.15995223181588, 46.400591305324006, 43.94639376231602, 48.18325240271432, 53.3463510785784, 53.6543299811227, 56.347396169389995, 55.50623682567051, 58.53803811754499, 55.877357482910156, 54.64835664204189, 57.78955732073103, 57.39076198850359, 53.33286462511335, 55.84761571884155, 55.78541891915457, 55.147348472050254, 54.98393726348877, 55.32576084136963, 50.300285134996685, 48.80041224615914, 45.992301259722026, 47.69593007223946, 50.29841954367501, 53.72802257537842, 51.462413038526265, 57.220770835876465, 48.025931290217805, 43.68964740208217, 45.90563290459769, 44.691994530814036, 41.77142347608294, 40.020077909742085, 44.05729396002633, 46.77381379263741, 46.22152927943638, 49.69762618201119, 44.71729292188372, 48.60154438018799, 46.08575800486973, 43.56975623539516, 48.831477642059326, 44.48730060032436, 45.41905403137207, 41.871974331992014, 37.64732367651803, 38.41670118059431, 42.941764150347026, 44.70600209917341, 40.4335617337908, 50.892667702266145, 52.94967494692121, 51.06085927145821, 52.620740277426584, 48.143418380192344, 43.16569069453648, 44.75177335739136, 43.61108064651489, 39.26116786684309, 40.64658655439104, 45.15406363351004, 53.87390695299421, 50.8874009677342, 50.81318378448486, 49.341871465955464, 49.9127493585859, 45.52119255065918, 45.74144697189331, 44.72205591201782, 44.910848890032085, 43.54822029386248, 41.22573627744402, 41.64090851375035, 42.91412421635219, 43.28244474955967, 44.68408400671822, 44.574959073747905, 44.14460849761963, 50.09427799497332, 57.60848379135132, 55.562809058598106, 58.85133934020996, 54.38004847935268, 54.59441430228097, 52.08592006138393, 52.413895879473, 45.36788054874965, 45.100962025778635, 45.05935968671526, 46.13890477589199, 48.81416967936924, 52.85758352279663, 58.98391096932547, 62.36440413338797, 64.4491138458252, 64.4790049961635, 65.52086653028215, 64.82603277478898, 66.86038194383893, 64.79783003670829, 59.75300012316023, 54.82515008108956, 54.47470031465803, 57.62543739591326, 68.27003247397286, 69.33670602525983, 69.39608533041817, 23.31455704144069, 1.3044720653976714, 11.905965839113508, 66.8478057043893, 64.39798205239433, 59.8396372113909, 68.64994607652936, 34.80572237287249, 32.51515143258231, 37.00221470424107, 8.43196381841387, 0.15041182110352175, 6.627918337072645, 37.352198941367014, 43.31574051720755, 19.438198736735753, 5.547473890440805, 14.054452197892324, 19.3929694380079, 58.22733899525234, 1.627824291586876, 4.616477813039507, 2.9975288680621555, 1.2389145089047295, 0.6871121898293495, 60.831895555768696, 66.04225935254777, 55.471836294446675, 38.30571413040161, 53.28710726329258, 61.86591257367815, 68.19025325775146, 59.184936250959126, 80.00055803571428, 65.98941135406494, 77.31314073290143, 16.659424781799316, 0.5687901760850633, 2.4573993597711836, 0.18753535406930105, 0.34702202464853016, 7.647938643183027, 41.16773966380528, 74.862441607884, 66.15550804138184, 68.04402841840471, 64.34592614855084, 68.81468091692243, 68.65097440992082, 63.26491846357073, 65.7471832547869, 58.27735212871006, 56.700385502406526, 52.970248562949045, 54.66615792683193, 51.975200516836985, 55.51319197246006, 58.602406229291645, 65.06702409471784, 64.55097443716866, 63.23849446432931, 63.18629264831543, 54.34579038619995, 51.38620172228132, 52.75329106194632, 49.441960266658235, 50.948791776384624, 52.35441582543509, 51.475232464926584, 49.399694374629426, 49.31613533837454, 45.19774695805141, 51.14524514334542, 55.682022775922505, 57.90476540156773, 57.44942562920706, 56.710557665143696, 60.61849553244454, 58.25840439115252, 58.22602925981794, 61.24421555655343, 58.12121220997402, 57.58040612084525, 58.988184111458914, 57.63680464880807, 58.848031997680664, 57.96575321469988, 58.65817247118269, 53.49939210074288, 50.59947804042271, 45.74077647072928, 50.686254092625205, 52.429668290274485, 57.30058479309082, 55.353824615478516, 59.99511705126081, 50.23176894869123, 45.27587945120675, 48.59244224003383, 48.00941889626639, 44.554069314684185, 42.98101452418736, 46.20731673921858, 49.09508534840175, 48.82512698854719, 52.688836097717285, 48.46246228899275, 50.51304939814976, 48.949916635240825, 47.03262029375349, 50.21678863252912, 47.18100949696132, 49.050255571092876, 44.058416094098774, 42.79027605056763, 40.37189647129604, 47.3066120828901, 44.602821350097656, 41.27962303161621, 53.598601954323904, 55.40481744493757, 53.63315534591675, 55.29654366629464, 48.74797419139317, 44.740392208099365, 46.285004547664094, 47.9319360596793, 40.22145754950387, 41.84806210654122, 49.974564007350374, 57.406722000667024, 53.87434121540615, 53.832259450639995, 52.93078974315098, 51.767157554626465, 47.552203110286165, 46.256829602377756, 47.34940256391253, 48.18528822490147, 47.19122682298933, 44.270829473223, 43.06966311591012, 45.520150320870535, 44.27541528429304, 47.136110237666536, 45.36081075668335, 48.15360443932669, 51.107537269592285, 60.69459915161133, 59.16954599108015, 64.08406938825334, 58.798922130039756, 58.96062060764858, 57.386040687561035, 58.03582927158901, 52.20143733705793, 48.726403508867534, 49.37411805561611, 48.50785139628819, 51.88465854099819, 54.66889551707676, 60.847695759364534, 63.85613373347691, 67.49684388296944, 65.69456454685756, 67.79617227826799, 66.02877289908272, 69.47805322919572, 67.42074026380266, 64.00524207523891, 62.41176305498396, 64.40704945155552, 63.45952360970633, 72.30885355813163, 68.33428246634347, 74.70807347978864, 26.450497933796473, 1.1061812256063734, 13.065158128738403, 80.2182867867606, 68.44949054718018, 75.26271343231201, 74.80674484797886, 50.1440166745867, 38.727452414376394, 53.804407596588135, 33.47298840114048, 0.8658473789691925, 16.389263187135967, 57.884671211242676, 76.21112169538225, 48.829264640808105, 39.261800152914866, 58.39121573311942, 83.44062505449567], [20.441030502319336, 0.25323936556066784, 0.7322940996715, 0.5599140152335167, 0.24053637576954706, 0.6785363214356559, 37.47939266477312, 39.931915691920686, 33.827384744371685, 18.846292121069773, 26.881631919315883, 60.06225749424526, 65.27517127990723, 39.2616924558367, 60.357444763183594, 55.169551440647666, 50.38419852937971, 16.15067768096924, 0.3332828033183302, 1.1914479987961906, 0.23510551718728884, 0.5919852171625409, 1.514906836407525, 14.761651141302925, 43.267064911978586, 62.574302264622276, 60.99708897726876, 62.634953090122764, 65.47887856619698, 64.90320641653878, 59.66452176230294, 57.59306921277727, 53.05085114070347, 48.11043528148106, 48.69979190826416, 45.43970060348511, 45.55006231580462, 47.3942358153207, 49.72892434256417, 51.36750759397234, 55.13041223798479, 56.05290372031075, 54.304528508867534, 51.838004861559185, 47.294751507895334, 48.91900757380894, 46.56111901147025, 45.133785315922324, 44.076620374407085, 44.143111160823274, 44.32494899204799, 44.55565350396292, 46.91651936939785, 49.33613920211792, 52.56472390038626, 54.404791014535085, 52.66878707068307, 54.848669733319966, 52.373089109148296, 53.02347871235439, 53.638769490378245, 51.92241505214146, 50.96665212086269, 51.93662411825997, 52.21072360447475, 54.772083214351106, 53.639405250549316, 51.747202328273225, 52.774312836783274, 50.5464563369751, 47.47412967681885, 44.35586500167847, 42.3031656401498, 41.15648705618722, 49.814988204411094, 50.849404743739534, 49.0167999948774, 43.885395526885986, 45.38440683909825, 43.0109577860151, 45.347779410226, 39.05447285515921, 35.54961388451712, 39.39069618497576, 43.41056605747768, 44.09173270634243, 44.98137310573033, 43.43727493286133, 47.417119707380024, 47.08176490238735, 44.34833662850516, 47.66186652864729, 43.44343103681292, 41.566243171691895, 40.19384888240269, 35.706962789808, 40.41870995930263, 39.630301339285715, 46.09591974530901, 41.36045837402344, 48.40434408187866, 55.677110399518696, 47.69867461068289, 52.85083334786551, 43.164075238364084, 42.200891630990164, 42.94004794529506, 40.16808148792812, 43.04713010787964, 42.55090366091047, 38.37863894871303, 48.81690379551479, 49.0854412487575, 49.79820135661534, 45.72555296761649, 47.35369655064174, 45.28450563975743, 45.42376838411604, 44.84088053022112, 43.60947561264038, 44.351018633161274, 44.10048048836844, 38.613609654562815, 42.79172474997384, 43.62214912687029, 46.12419891357422, 46.31837327139718, 46.02924483163016, 44.11702414921352, 47.87981762204851, 52.033193656376426, 49.91798482622419, 51.616569246564595, 46.188945702144075, 44.72624914986746, 44.832164015088765, 43.38148784637451, 40.38850614002773, 41.89150224413191, 43.455048424857004, 47.63670015335083, 52.616547039576936, 56.74464552743094, 60.019282885960166, 60.59544835771833, 61.034671783447266, 61.92484024592808, 59.85105310167585, 60.845388957432334, 59.049668720790315, 56.8351388658796, 53.498770236968994, 50.48769542149135, 53.09321778161185, 63.36215155465262, 63.54914147513253, 65.99424730028424, 30.20890883037022, 0.20074833078043802, 11.381747705595833, 62.211460386003765, 48.764229501996724, 47.47938251495361, 56.00918565477644, 21.731338773454937, 18.515481437955582, 11.757089393479482, 3.6792465959276472, 0.5066932567528316, 5.76807051045554, 19.223297902515956, 58.31029006413051, 45.43411772591727, 45.94011681420462, 42.81546674455915, 57.97218724659511, 25.830029010772705, 1.8603721388748713, 1.6760464182921817, 2.03161244732993, 0.4386630372277328, 1.4011224848883492, 47.08108050482613, 53.28280980246407, 44.149166515895296, 25.52497008868626, 35.66838639123099, 63.67869063786098, 70.02093682970319, 47.10599674497332, 68.47221115657261, 63.2246675491333, 66.57593658992222, 19.021558693477086, 0.26815299530114445, 0.5166396030357906, 0.28653912299445694, 0.6070420177919524, 2.564279807465417, 23.056766714368546, 59.52226434435163, 68.8138540812901, 61.01407037462507, 68.25488540104458, 65.06272315979004, 66.01170812334333, 61.18100779397147, 62.114817891802105, 55.682974679129465, 52.52709245681763, 51.4001259122576, 51.61158043997628, 49.39826651981899, 52.49973739896502, 53.796003750392366, 55.51721845354353, 60.62757682800293, 60.34010900769915, 57.6292484828404, 54.85335976736886, 50.41995395932879, 50.01537077767508, 48.82810081754412, 46.59279932294573, 47.73271383558001, 46.71071720123291, 47.41181475775582, 45.80818094526018, 50.638276781354634, 51.40101875577654, 55.734137739454, 55.93588563374111, 55.2186404636928, 55.576761041368755, 55.00656754629952, 55.8035363469805, 56.252167633601594, 55.07024778638567, 54.99139962877546, 56.20034449441092, 54.66401788166591, 55.70804030554635, 56.27661487034389, 54.955241203308105, 56.33077955245972, 53.048057964869905, 49.32862819944109, 46.955217361450195, 45.229065963200156, 45.00574391228812, 52.75068201337542, 53.47935002190726, 51.14854206357683, 44.50819730758667, 47.773169721875874, 45.137575558253694, 46.60267966134207, 41.67346429824829, 40.12192807878767, 40.860445158822195, 45.84218542916434, 47.7646164894104, 49.92078842435564, 46.34011765888759, 49.62303727013724, 50.720505237579346, 46.282843657902305, 48.70102521351406, 44.38870218821934, 43.905830178942, 41.13018812452044, 37.85554729189192, 42.13919857570103, 43.26096091951643, 46.18913330350603, 41.24614313670567, 48.00181061880929, 57.982505321502686, 47.313796520233154, 54.01108523777553, 45.27143260410854, 46.75458117893764, 43.98351798738752, 40.88988815035139, 45.73613159997122, 46.86238595417568, 41.32996620450701, 50.39275871004377, 52.183997358594624, 51.20740025384085, 49.79703058515276, 49.22899797984532, 47.35517999104091, 47.41224554606846, 47.27515063967024, 47.88472305025373, 46.31698363167899, 45.36757482801165, 40.985095841544016, 43.826843057359966, 45.093159198760986, 48.13649102619716, 48.44853809901646, 48.72963094711304, 45.88335003171648, 48.116494110652376, 55.34896435056414, 55.436487334115164, 55.578835078648154, 52.99190609795706, 54.304691791534424, 54.27810450962612, 50.053335734776084, 45.67565100533621, 46.293168681008474, 47.38355295998709, 51.53439290182931, 56.92160224914551, 62.173148018973215, 63.17607879638672, 63.58674512590681, 66.13106427873883, 65.97930867331368, 64.10068253108433, 65.2150068283081, 64.34894166673932, 63.39130619594029, 61.56903689248221, 60.65853105272566, 64.37995147705078, 70.84249183109829, 72.36525208609444, 73.41611848558698, 38.56912728718349, 0.22244617076856749, 14.166755931718008, 71.8975966317313, 57.303846972329275, 59.25541877746582, 68.19244194030762, 31.88915695462908, 26.440695762634277, 20.182929243360245, 9.568792462348938, 0.30462001849498066, 2.1088857523032596, 39.19412122453962, 53.155369418007986, 27.843549217496598, 22.119654485157557, 12.11152742590223, 43.771987029484336, 25.081046206610544, 0.6972300154822213, 0.9497343919106892, 1.095409020781517, 0.47152310396943775, 1.3797859783683504, 65.95337799617222, 68.14727864946637, 58.06952108655657, 34.40522125789097, 44.30448307309832, 75.69853224073137, 83.18683515276227, 53.086724690028596, 78.81080409458706, 70.99714483533586, 78.22666209084647, 26.436360086713517, 0.5800248703786305, 2.527439590011324, 0.17556020165128366, 1.06390024295875, 9.560234018734523, 37.41454512732369, 69.30286829812187, 65.08974470411027, 67.73427772521973, 69.15034144265312, 71.01749610900879, 66.302184513637, 63.36210986546108, 64.52407101222447, 58.803424562726704, 56.87327057974679, 55.85838195255825, 52.53148371832711, 52.954604693821494, 55.51379646573748, 58.24825307301113, 57.96298435756138, 62.99013805389404, 64.1635011945452, 61.18462780543736, 59.39238166809082, 52.47587033680507, 53.740633555821006, 50.69876779828753, 51.650285380227224, 48.48735768454415, 49.54340396608625, 49.57175261633736, 49.546457699366975, 52.84404148374285, 53.827673639569966, 58.6542397907802, 59.94484683445522, 57.14730058397566, 58.73428303854806, 57.774865354810444, 57.212391308375764, 58.682393891470774, 58.45031016213553, 56.078813552856445, 57.30072028296334, 57.58262954439436, 59.3360595703125, 59.25238936288016, 56.049478258405415, 59.612577029636924, 55.62990433829171, 53.14795569011143, 50.373414925166536, 52.209747382572715, 46.98787042072841, 53.78631796155657, 55.72003289631435, 53.130845751081196, 46.98017181668963, 47.156819343566895, 48.340847969055176, 50.55561753681728, 44.49577740260533, 41.68724257605416, 43.18781723294939, 48.78890602929251, 49.25416088104248, 52.135693481990266, 48.05785826274327, 52.02377537318638, 52.52080086299351, 49.949508803231375, 51.802065304347444, 47.222848074776785, 47.72370549610683, 45.646444252559114, 40.706143038613455, 45.01856681278774, 45.14999546323504, 48.68576002120972, 41.65108415058681, 49.180641991751536, 56.316209180014475, 49.89292614800589, 57.38672161102295, 49.237933363233296, 49.319303716932026, 47.87520054408482, 41.36813265936715, 45.964456353868755, 48.47855084283011, 46.50672851290022, 54.394997528621126, 54.77902446474348, 53.78081151417324, 50.795545782361714, 51.23877831867763, 49.87583705357143, 49.20350851331438, 50.05519437789917, 48.29873841149466, 49.080164091927664, 47.53667041233608, 42.55300201688494, 46.111056395939414, 47.55077872957502, 49.92410271508353, 50.513806751796174, 50.419464111328125, 46.851532867976594, 50.26513419832502, 57.25406312942505, 57.86817618778774, 59.13990497589111, 58.443883078438894, 59.64581721169608, 59.909056663513184, 55.5222350529262, 50.53946644919259, 50.5709730557033, 50.531816482543945, 54.366502966199604, 59.59383773803711, 63.67825984954834, 63.760741915021626, 65.32701178959438, 65.32523305075509, 69.04975931985038, 65.69604451315743, 68.46349116734096, 67.52321229662213, 66.75801413399833, 63.07315513065883, 64.87023721422467, 65.41001496996198, 71.83359677450997, 73.40430654798234, 75.16820403507778, 42.820028236934114, 0.274132598723684, 16.19653752871922, 80.79764148167202, 64.56080613817487, 70.64968626839774, 73.99542454310826, 44.163639613560264, 35.55063874380929, 41.50282348905291, 34.07563345772879, 1.3599950117724282, 11.75744114603315, 46.53291974748884, 76.4208322252546, 68.57777513776506, 78.0216554914202, 73.20164843967983, 84.00744519914899], [2.0174263971192494, 0.10875340112085853, 0.16597457815493855, 0.1396003155303853, 0.10832366453749792, 0.5941131029810224, 34.92131955283028, 43.582930019923616, 38.571402822222026, 21.58653484072004, 38.93072196415493, 28.51246271814619, 46.520600591387065, 45.46308476584298, 61.47853660583496, 59.06645556858608, 56.93297645023891, 15.352218491690499, 0.29925888617123875, 0.49957167889390675, 0.19632204329328878, 0.6001464192356382, 2.862408769982202, 21.200119461332047, 57.635123184749055, 68.77448558807373, 60.70229080745152, 63.36953054155622, 64.68516499655587, 63.48289734976632, 58.81397887638637, 58.92546967097691, 54.763286794934956, 49.477830341884065, 46.94777931485857, 45.81355537687029, 45.23896367209298, 45.404601778302876, 48.802291733878, 52.842898505074636, 54.77254179545811, 52.93805408477783, 55.50940867832729, 55.389385495867046, 50.66516978400094, 46.43646485464913, 46.06516007014683, 45.37133032935006, 45.43651485443115, 43.78104748044695, 43.411667346954346, 43.75951501301357, 47.72004379544939, 52.6741441317967, 54.07063477379935, 54.63607570103237, 51.57533516202654, 54.294342449733186, 53.77449212755476, 53.42311477661133, 53.096063068934846, 54.808245113917756, 54.6607209614345, 55.451419012887136, 51.83560773304531, 55.61488233293806, 51.75801372528076, 52.33391169139317, 53.063038281032014, 50.16111619131905, 44.72139583315168, 42.789640290396555, 38.83038650240217, 43.20933927808489, 53.304929392678396, 56.986950056893484, 49.789873940604075, 44.1506256375994, 46.17145708629063, 41.73129415512085, 42.57939822333199, 41.64387192044939, 38.251709256853374, 37.889204365866526, 40.95482948848179, 47.93991606576102, 45.639027050563264, 48.80231952667236, 51.614168643951416, 50.86493744168963, 45.78068692343575, 45.42762116023472, 42.633948530469624, 39.95194387435913, 37.00137744631086, 37.570532185690745, 41.538658823285786, 46.334048407418386, 44.52158301217215, 42.582660402570454, 38.91218417031424, 49.35509736197335, 51.49370077678135, 46.3574812071664, 38.217187132154194, 43.59902899605887, 43.16500282287598, 48.034481048583984, 46.610013484954834, 50.90577547890799, 43.43282461166382, 49.44495494025094, 50.79843970707485, 49.92716339656285, 48.49619926725115, 50.24373722076416, 47.6333441734314, 48.346573284694124, 46.187094007219585, 44.72083650316511, 42.54716900416783, 45.16753619057791, 40.14273445946829, 42.19241830280849, 41.97477987834385, 47.723656858716694, 52.72629731042044, 51.203443254743306, 50.73269932610648, 47.525157247270855, 47.95091506413051, 51.24090099334717, 50.84293597085135, 47.055545875004356, 49.99924748284476, 46.87136650085449, 44.40159804480416, 41.62308291026524, 41.449113913944785, 44.643878255571636, 47.62867150987898, 57.16993086678641, 59.49107388087681, 60.050007820129395, 61.54324517931257, 60.27462223597935, 60.72827707018171, 60.655800410679404, 62.35496847970145, 60.85298333849226, 58.45367309025356, 54.75607109069824, 55.250817571367534, 55.70419100352696, 66.12706906454903, 65.5929957798549, 69.06869316101074, 38.27802208491734, 0.2680795778121267, 15.064245189939227, 64.97402245657784, 51.62716177531651, 51.771229199000764, 46.55856554848807, 20.298251969473704, 16.502180099487305, 8.845048121043614, 4.14059134892055, 0.5756557562521526, 3.4024848639965057, 4.5360841155052185, 44.63009302956717, 52.661936146872385, 42.1077857698713, 52.16266986301967, 42.49339689527239, 10.2714090687888, 0.26872014201113154, 0.33612439941082684, 0.589887295450483, 0.06301941483148507, 0.780893763261182, 46.480116912296836, 53.36005640029907, 50.856735093253, 27.005299431937082, 42.493699141911094, 34.65140288216727, 56.02173062733242, 52.83540487289429, 69.53266607012067, 67.36407075609479, 68.21066706521171, 17.002365282603673, 0.31300584280065125, 0.6886431819626263, 0.427666861563921, 0.765005675809724, 1.913860674415316, 28.565044948032924, 69.40215805598667, 69.77208709716797, 63.06803430829729, 68.81544521876744, 64.7573915209089, 65.89012854439872, 60.54696382795061, 64.1850197655814, 57.99655457905361, 54.80359329496111, 47.924331256321494, 50.46478721073696, 49.66633496965681, 50.608323097229004, 50.28030211584908, 57.710980142865864, 58.600321769714355, 58.99336746760777, 57.052645274571006, 58.19594703401838, 53.664349283490864, 49.20940753391811, 48.05379009246826, 46.915814127240864, 50.14015000207083, 46.69279432296753, 46.13879707881382, 47.55221700668335, 48.81091792242867, 53.54202624729702, 56.10138825007847, 56.394098486219136, 53.96042592184884, 56.38091427939278, 56.41911547524588, 53.85105085372925, 56.57949726922171, 57.16742256709507, 56.7071704183306, 55.99611609322684, 56.11898456301008, 57.03344392776489, 54.69548627308437, 52.34759964261736, 54.866589137486045, 52.11250039509365, 48.129733903067454, 45.39121954781668, 43.62680441992623, 46.388671670641216, 54.74658332552229, 57.37224503925869, 52.66106762204851, 46.34643357140677, 45.656383650643484, 43.56353759765625, 45.31354216166905, 44.65742376872471, 39.94683000019619, 40.13277769088745, 42.98892157418387, 49.69274507250105, 49.12775925227574, 50.64606918607439, 54.191060951777864, 52.16865226200649, 48.41818489347185, 46.394622802734375, 46.42389208929879, 43.035926137651714, 38.23640932355608, 37.863332748413086, 43.65522950036185, 45.91403675079346, 44.615296840667725, 43.248051166534424, 38.944361277988975, 46.76492704663958, 53.221585750579834, 46.03251395906721, 41.63209472383772, 45.30047607421875, 44.758037158421104, 49.354340008326936, 47.92429998942784, 51.89895445959908, 49.97487667628697, 51.88354335512434, 52.80761207853045, 52.8383161681039, 50.1880647795541, 52.25513996396746, 49.46208919797625, 48.503303800310405, 46.67131049292428, 46.61472436359951, 45.50471142360142, 45.307820320129395, 41.37656429835728, 44.76807035718645, 44.37728977203369, 49.25288241250174, 54.88287224088396, 52.93097734451294, 52.43689441680908, 48.561658246176584, 49.78100109100342, 55.55668074744088, 53.827611105782644, 55.723500047411235, 56.354650088718955, 54.98064381735665, 52.19768530981881, 46.870226996285574, 46.45861571175711, 49.95864568437849, 53.086825438908164, 61.29390212467739, 63.18680681501116, 64.8933608191354, 65.36181531633649, 66.22810282026018, 65.27685274396623, 66.63189043317522, 68.51299013410295, 66.79532596043178, 64.46267672947475, 62.29189968109131, 62.46140098571777, 64.11850466047014, 73.2541559764317, 73.08852481842041, 74.67577130453927, 45.573265824999126, 0.28789806578840527, 18.911106654575892, 72.70568602425712, 61.51976721627371, 60.58675616128104, 58.34420422145298, 28.3641152041299, 24.28441091946193, 15.526369878223964, 4.281786126749856, 0.7552570817725999, 2.0921755518232072, 29.971683434077672, 59.968456813267295, 52.13412666320801, 39.23414632252285, 40.876558031354634, 62.684896741594585, 2.3532206756728034, 0.20734137057193688, 0.2396412252315453, 0.3230210468173027, 0.2099568516548191, 1.0855378018958228, 62.815703528267996, 70.21219294411796, 61.23859446389334, 39.31073978969029, 61.56440244402204, 41.40140758241926, 64.89541748591832, 58.596771240234375, 79.29360662187848, 73.18370124271938, 81.90013994489397, 23.549988065447124, 0.7175903543829918, 2.852501290185111, 0.4896115990621703, 1.6640366741589137, 18.663017749786377, 49.354503290993826, 77.76127174922398, 65.90453910827637, 66.8559489931379, 67.1652341570173, 67.54035350254604, 67.47387313842773, 64.29464149475098, 66.19030461992536, 62.84223869868687, 56.50492920194353, 51.77226448059082, 52.52324315479824, 51.612125873565674, 51.98375374930245, 54.27525922230312, 59.147186688014436, 61.06471579415457, 60.93370056152344, 60.50932543618338, 63.64358833857945, 55.46377985818045, 52.31837204524449, 50.54478529521397, 49.21638699940273, 51.7592887197222, 48.541404247283936, 47.732738154275076, 49.07497378758022, 50.96959468296596, 57.26308536529541, 58.31695338657924, 57.77527182442801, 57.22570753097534, 60.20113808768136, 57.4118150302342, 57.78545788356236, 58.179347787584575, 59.752346992492676, 60.69628756386893, 59.722573961530415, 57.05228396824428, 60.68310683114188, 55.43215165819441, 56.241578578948975, 57.60570451191494, 53.197833333696636, 50.23388467516218, 50.042368003300254, 51.402220794132774, 48.63559055328369, 57.69404738289969, 59.65829617636544, 55.129720892224995, 46.74174438204084, 47.87379700796944, 46.461311612810405, 48.032611983163015, 47.36390692847115, 42.69515521185738, 43.91554723467146, 43.99556963784354, 54.44296441759382, 51.24965919767107, 52.64838368552071, 58.53399426596505, 56.40664693287441, 48.42455986567906, 48.97974872589111, 48.66107654571533, 45.34431573322841, 41.05723898751395, 41.27256713594709, 45.32317583901541, 50.5386882509504, 49.359467778887065, 44.28172772271292, 40.589625222342356, 49.4264623097011, 56.53466749191284, 50.45316982269287, 45.938018458230154, 49.85644463130406, 47.4781631061009, 48.09944323131016, 50.90530300140381, 53.330352851322715, 51.0601818220956, 54.867388180324006, 56.57080159868513, 54.73536545889718, 52.061535358428955, 53.673104013715474, 51.32490471431187, 51.80231891359602, 49.602710315159385, 47.927367619105745, 46.24987098148891, 47.406864166259766, 43.063197817121235, 47.19520466668265, 46.459185464041575, 51.34541579655239, 56.39454664502825, 55.89423813138689, 52.358289446149556, 50.18845040457589, 52.140459946223665, 57.329770701272146, 59.057207516261506, 59.494902338300435, 62.547044481549946, 59.054650579180034, 55.82975537436349, 51.56446817943028, 49.435401167188374, 51.12823595319475, 54.76112590517317, 64.3007698059082, 64.11280018942696, 65.97584847041539, 66.96534837995256, 66.43081651415143, 66.67285701206752, 66.79748685019356, 70.78188269478935, 68.59646579197475, 68.2011410849435, 63.81574385506766, 65.80092062268938, 66.70076792580741, 75.0614241191319, 74.67041424342564, 74.98286778586251, 49.72676345280239, 0.34501076542905396, 20.124102319989884, 83.04210417611259, 66.26779787881034, 72.32945496695382, 65.23896421704973, 43.6114627974374, 37.41314853940691, 36.190442766462056, 30.73094436100551, 0.9701036874737058, 6.794015024389539, 29.539738246372767, 69.4109058380127, 73.03152874537876, 61.04358632223946, 68.55362319946289, 58.20865528924124], [0.09855714360518114, 0.06592296795653445, 0.0211194652199213, 0.12526504189840384, 0.05108096097995128, 0.3754194751381874, 40.92041506086077, 47.09387561253139, 37.110641343253, 24.20916713987078, 38.68077094214303, 21.028109857014247, 41.43220894677298, 40.61035517283848, 62.924873624529155, 57.84335027422224, 66.90886647360665, 18.635855504444667, 0.5941497438720295, 1.1159151090042931, 0.4803887882402965, 2.897803762129375, 7.4906071083886285, 27.307804891041346, 63.67976760864258, 67.67621857779366, 61.98999350411551, 65.05174500601632, 59.974098750523154, 62.29664530072893, 59.052336829049246, 57.429182052612305, 55.29723501205444, 51.97100380488804, 46.90521117619106, 45.070990971156526, 45.40612690789359, 46.71488959448678, 46.40612554550171, 49.546561922345845, 53.077386311122346, 54.669079644339426, 53.44799974986485, 51.456083229609895, 52.38486977985927, 48.764872210366384, 46.37403876440865, 43.411445004599436, 43.77569041933332, 46.152252265385215, 42.83456039428711, 45.32501016344343, 49.01961054120745, 52.80570479801723, 53.46533203125, 54.07843065261841, 51.55557101113455, 55.34731067929949, 54.528152806418284, 53.94280876432146, 53.78994492122105, 55.61617469787598, 51.29614612034389, 52.144618443080354, 52.48029981340681, 53.37476921081543, 51.45535019465855, 53.99274546759469, 49.36076014382498, 53.53234393256051, 47.27783611842564, 44.31366164343697, 40.113982813698904, 47.39851590565273, 49.43056869506836, 49.04397439956665, 50.51822233200073, 42.64336681365967, 44.39489998136248, 38.918645995003835, 40.013414587293354, 41.57935789653233, 39.876048701150076, 40.29504592078072, 39.37928376879011, 42.48584072930472, 43.41504764556885, 46.87417357308524, 51.86316428865705, 51.33445848737444, 43.49226992470877, 45.08817734037127, 44.091961996895925, 39.66553912843977, 37.69678095408848, 37.302352564675466, 40.012942109789165, 41.49073362350464, 40.52276965550014, 43.06458050864083, 32.98143809182303, 29.00812636102949, 45.40531744275774, 44.99260834285191, 38.74325261797224, 41.46015807560512, 45.96608223233904, 47.14486844199044, 47.24561384746006, 50.57494395119803, 52.898807185036794, 51.22674403871809, 49.33428750719343, 51.40285655430385, 50.14792851039341, 48.03293854849679, 46.68294872556414, 50.75034080232893, 48.71070752825056, 48.167500836508616, 46.25233064379011, 47.43080071040562, 42.4588817187718, 42.123783997126985, 43.09559031895229, 47.244998931884766, 54.22141415732247, 51.26579291479928, 55.26932757241385, 53.73887913567679, 52.05920076370239, 50.55692032405308, 53.28320932388306, 50.14637906210763, 49.648922783987864, 51.01019300733294, 46.014681407383506, 42.00951739719936, 42.363100801195415, 46.490674700055806, 52.81816291809082, 58.67157554626465, 61.54424571990967, 61.28204154968262, 58.95180334363665, 60.998499461582725, 62.70922933306013, 59.13156713758196, 61.499068532671245, 60.94950771331787, 59.345752307346885, 57.09848601477486, 56.993022782461985, 57.99320902143206, 65.20901053292411, 67.54189600263322, 69.73984745570591, 40.71174676077706, 0.3203132849718843, 18.309222425733292, 73.23419380187988, 53.358239446367534, 41.943200315747944, 43.54942928041731, 23.51008803503854, 14.250004036085945, 7.604417732783726, 6.4204229797635755, 1.1431261003017426, 1.5404627450874873, 4.674684609685626, 21.524190391813004, 44.24530873979841, 43.332749707358225, 40.985377243586946, 5.840094668524606, 0.845233539385455, 0.10063816300992455, 0.07848483603447676, 0.14712834943618092, 0.004605935994602207, 0.47672203928232193, 50.29553951535906, 59.325901303972515, 46.166787896837505, 29.239576067243302, 41.861041341509136, 26.59874643598284, 48.485683168683735, 46.840728419167654, 73.37335927145821, 65.33038861410958, 80.42015974862235, 21.62459533555167, 0.7260417523128646, 1.8798859374863761, 0.7524248223219598, 3.429416733128684, 8.285765034811837, 37.544042178562705, 75.44704219273159, 71.92027555193219, 65.85627692086356, 67.94970662253243, 64.24937398093087, 65.40533188411167, 63.21368244716099, 62.66353103092739, 57.26063959939139, 56.15154382160732, 48.77649654660906, 49.171970639910015, 49.534058638981406, 49.88104125431606, 48.90398209435599, 53.17599514552525, 56.69962120056152, 57.79474067687988, 57.62677492414202, 55.46434613636562, 54.671171052115305, 51.68870197023664, 49.08339500427246, 45.54895755222866, 46.07016624723162, 48.261270250592915, 46.20864037105015, 47.643898487091064, 51.01211418424334, 53.64358459200178, 55.34241567339216, 55.61345795222691, 55.667348180498394, 56.78559126172747, 57.373203890664236, 57.42466919762747, 55.84413814544678, 56.53475087029593, 54.52547427586147, 53.04246813910348, 54.70335858208792, 54.98372534343174, 52.73152582986014, 52.46735879353115, 52.924498149326865, 56.53465012141636, 51.291268484933035, 46.93488693237305, 42.72837107522147, 52.5528633253915, 51.195630005427766, 51.50135769162859, 51.90076446533203, 43.95681953430176, 46.38523926053728, 40.84903621673584, 42.59467731203352, 42.617981570107595, 42.7020617212568, 40.83342708860125, 43.53066567012242, 44.39336442947388, 45.70605632237026, 48.24055072239467, 54.8639349256243, 52.28381865365164, 47.42034714562552, 46.6593804359436, 45.67553983415876, 40.34330463409424, 39.849732398986816, 40.016225133623394, 41.932854448046, 42.87297003609793, 41.1974640573774, 44.151122433798655, 32.02837453569685, 31.82526479448591, 45.10116352353777, 43.635263851710725, 40.16022654942104, 43.7466538974217, 50.024806431361604, 49.476089818137034, 50.4755082811628, 49.35387447902134, 52.83294521059309, 52.98526014600481, 51.71382318224226, 54.23220818383353, 51.94410732814244, 49.35815109525408, 50.79913452693394, 51.062620639801025, 51.545239039829795, 50.786335945129395, 47.544778960091726, 47.48703595570156, 44.803933484213694, 43.84735761369978, 43.79102509362357, 47.75189781188965, 54.276513372148784, 52.63566153390067, 57.55541345051357, 55.75851549421038, 56.76948186329433, 54.12904827935355, 55.815786021096365, 55.214495863233296, 55.85221542630877, 57.10521534511021, 51.66387605667114, 45.953686646052766, 46.13893951688494, 51.04869992392403, 55.64350891113281, 61.88808427538191, 63.75146606990269, 65.61534813472203, 61.840822628566194, 65.52908624921525, 65.04122543334961, 66.47623688834054, 63.99661936078753, 68.71313994271415, 65.41867242540631, 65.77709524972099, 64.00121212005615, 65.74593952723912, 72.32940632956368, 74.13869639805385, 74.60062653677804, 46.32713842391968, 0.3902411769543375, 22.317761523383005, 79.85272121429443, 61.40042495727539, 52.26900162015642, 54.97239283152989, 33.25204610824585, 22.98170358794076, 12.040105155536107, 4.621737165110452, 3.656942878450666, 4.105828642845154, 11.907381534576416, 48.388404914310996, 61.760390281677246, 52.72342423030308, 62.67331409454346, 24.513592038835796, 0.336174909557615, 0.1926829514226743, 0.1989984568208456, 0.2741254062524864, 0.1273188181221485, 0.7662376782723835, 63.2364239011492, 73.49753052847726, 57.913207462855745, 47.773590087890625, 61.539423670087544, 34.80189738954817, 59.19792243412563, 54.07947983060564, 79.34484958648682, 69.91803400857108, 84.4301597050258, 27.144263403756277, 1.2309990993567874, 5.741162308624812, 1.1053674178464072, 4.616701023919242, 33.01209006990705, 54.03944083622524, 73.70295401981899, 69.21325043269566, 70.13141318729946, 67.56623554229736, 68.03347410474504, 65.97383349282401, 68.69713824135917, 65.52971158708844, 62.607257570539204, 58.77994659968785, 51.61203554698399, 49.00893463407244, 52.9100980077471, 51.7711249760219, 52.66845008305141, 55.46035787037441, 59.04127529689244, 61.67965916224888, 57.99909067153931, 57.5692994253976, 57.52180848802839, 56.52279996871948, 51.40564278193882, 47.870093618120464, 47.5694693837847, 51.4437814440046, 47.04125690460205, 50.15376499720982, 53.47513593946184, 57.45207289287022, 58.05896329879761, 57.38420288903372, 56.38480527060372, 60.466760771615164, 59.133602959769114, 59.818083899361746, 56.1402599470956, 61.701407023838584, 56.16454042707171, 55.18086658205305, 57.147856439862935, 59.7461769921439, 57.371644020080566, 57.73598670959473, 53.58250992638724, 59.753820010593955, 52.24783740724836, 49.43178810392107, 48.640395232609336, 55.365685190473286, 54.08151912689209, 54.523386342184885, 52.5075124331883, 46.495458534785676, 47.627879415239605, 43.91407074247088, 44.240535327366416, 45.297050612313406, 45.040557861328125, 44.157546043395996, 46.38859176635742, 50.13284397125244, 50.25430890492031, 52.95985753195626, 57.66388872691563, 55.98594740458897, 51.18805299486433, 48.790264402117046, 49.86454275676182, 44.27077041353498, 43.34194564819336, 41.949245248522075, 43.969909940447124, 46.17722756522042, 46.29638569695609, 44.743949685777935, 33.8205303464617, 32.162554672786165, 47.32325996671404, 47.92564099175589, 44.66289547511509, 48.64024237224034, 49.629235063280376, 54.53269345419747, 52.545484338487896, 53.63564280101231, 55.463164942605154, 56.62181527273995, 54.27246257237026, 56.102909905569895, 54.030158042907715, 52.9739727973938, 51.407848834991455, 53.80664839063372, 53.92133188247681, 54.32932315553938, 49.23697451182774, 52.18717615944998, 45.680480003356934, 46.82442447117397, 46.58274875368391, 50.964734418051584, 59.237311771937776, 55.44902188437325, 57.89424235480172, 56.38960994992937, 59.93001937866211, 56.442708083561485, 59.44196401323591, 60.880275862557546, 59.5989168712071, 61.28684275490897, 55.547005380902974, 48.27960654667446, 46.60995095116751, 52.54798221588135, 58.30850437709263, 63.16139030456543, 64.83527387891496, 65.8888292312622, 63.88069561549595, 65.33992849077497, 68.9782554081508, 67.38439423697335, 66.97391550881522, 71.29937062944684, 68.76911463056291, 66.48048223767961, 66.96053327832902, 67.47373417445591, 72.90771879468645, 75.00959750584194, 76.11122049604143, 50.36727271761213, 0.4402429653065545, 23.77979278564453, 89.69391345977783, 66.6860169001988, 64.15349578857422, 62.63017272949219, 47.47861473900931, 35.60083947862898, 31.42749432155064, 30.057507583073207, 1.969122520514897, 7.2188960654394965, 17.663700035640172, 51.04158844266619, 64.36945274897984, 62.92381055014474, 60.74578653063093, 10.072876453399658], [0.054109951481223106, 0.05148002778046897, 0.04798323827396546, 0.05387880852712052, 0.14988550863095693, 0.12163202970155648, 30.393390451158794, 51.76032052721296, 43.55511290686471, 21.3021468094417, 37.41083131517683, 20.836891957691737, 38.669587816510884, 46.954942907605854, 57.75996841703142, 64.80552864074707, 65.76564461844308, 33.45216812406267, 0.040544482613248486, 0.2718210741877556, 0.9028847515583038, 10.130580374172755, 32.6882449558803, 42.86361081259591, 65.93319347926548, 62.8021753856114, 61.490459714617046, 60.40836811065674, 58.98928887503487, 57.01085186004639, 59.132609367370605, 55.747304575783865, 55.49075276511056, 51.39128432955061, 49.51063626153128, 46.06739044189453, 46.276711872645784, 44.63872964041573, 44.491386141095845, 47.94844497953142, 49.100084577287944, 53.386598518916536, 53.5951486996242, 54.10643536703927, 49.8352039882115, 50.62188250677926, 47.49838931219918, 44.13526317051479, 44.14512613841465, 46.61340420586722, 43.22388880593436, 44.57745347704206, 46.69771364756993, 52.68414258956909, 52.87085805620466, 55.352410657065256, 54.17023025240217, 52.23762355531965, 53.461555685315815, 52.59940583365304, 54.81879595347813, 51.78475039345877, 51.44191237858364, 51.99845266342163, 51.52145535605294, 52.45988253184727, 48.79338066918509, 50.5200149672372, 50.12245641435896, 52.31868124008179, 50.49755491529192, 46.145505564553396, 38.589864185878206, 47.37490245274135, 54.4248435156686, 46.090632166181294, 39.5436156136649, 44.621953214917866, 43.04440988813128, 38.4869509424482, 40.913380009787424, 41.98575108391898, 39.70738465445382, 39.59246144975935, 38.446932792663574, 38.431215967450825, 41.19627938951765, 42.3625727381025, 43.850869928087505, 44.89053235735212, 40.392258167266846, 39.46019901548113, 39.481307642800466, 38.94191551208496, 38.8454258782523, 40.24572760718209, 38.94117552893502, 38.56515291758946, 36.745186941964285, 41.366854190826416, 39.31607253210885, 30.44752734048026, 34.71836267198835, 37.97128690992083, 38.13220371518816, 44.46578202928816, 42.19766419274466, 46.75362580163138, 53.3212229183742, 49.83852175303868, 50.76031494140625, 51.16083690098354, 48.26864228929792, 47.0107091494969, 51.563273089272634, 51.39434501102993, 50.66911288670131, 51.589429582868306, 50.13114513669695, 49.14434807641165, 47.95237071173531, 46.82923262459891, 46.068592480250764, 42.445294516427175, 41.25043017523629, 45.69609260559082, 49.07820469992501, 57.02971969332014, 54.96259239741734, 55.362808636256624, 54.2256247656686, 55.20631088529314, 55.09465333393642, 50.63191570554461, 53.26028026853289, 52.048431055886404, 48.054203510284424, 45.26148278372628, 43.10281297138759, 47.90473733629499, 53.450758184705464, 57.18906620570591, 59.46142591748919, 59.005728312901084, 61.46070752825056, 60.66402012961251, 61.00470420292446, 60.045720781598774, 59.554851395743235, 58.6194293158395, 60.02392428261893, 60.330124446323936, 59.455026626586914, 61.50065272194998, 68.10389409746442, 68.12932450430733, 68.1437211717878, 36.31037562234061, 0.6803919247218541, 24.037480626787456, 64.83043793269566, 56.23641259329659, 38.07888323920113, 39.47081238882882, 24.290869270052227, 14.665706941059657, 3.450088926724025, 6.622091838291713, 2.688711621931621, 2.2314341706889014, 2.960003601653235, 10.253723297800336, 23.639989818845475, 28.69290222440447, 10.247322269848414, 0.16238782847566263, 0.013466057550561215, 0.024835672595405152, 0.050018897612712214, 0.008546112088619598, 0.07585059345832892, 0.0417066265030631, 37.50078616823469, 62.3058933530535, 50.84760168620518, 26.855607441493444, 37.69487714767456, 25.573150634765625, 49.99107640130179, 52.13768761498587, 66.20015021732875, 70.86319051470075, 74.0376556941441, 39.87855352674212, 0.11407346171992165, 0.9643400481769017, 0.8593218262706483, 10.600966470582144, 32.88172101974487, 52.48473971230643, 77.35929761614118, 67.58924797603062, 64.28989587511334, 63.696623938424246, 63.16150147574288, 62.86974661690848, 63.002332142421174, 58.959654808044434, 58.61744213104248, 56.14596094403948, 51.58930451529366, 49.193398884364534, 50.4670592716762, 47.10950558526175, 48.16861949648176, 52.69963707242693, 53.55521045412336, 56.94254411969866, 57.93060227802822, 58.89460577283587, 53.83142914090838, 52.65434871401106, 49.61744744437081, 46.47309923171997, 46.624952111925396, 48.401971272059846, 46.88385588782174, 46.59550217219761, 49.28540345600673, 55.516930103302, 54.59802736554827, 56.94375658035278, 56.49724102020264, 55.522453921181814, 56.24222476141793, 55.2173342023577, 54.35379123687744, 56.126096044267925, 52.693216936928884, 53.34408596583775, 51.144289766039165, 53.6969884463719, 50.75782053811209, 50.56019639968872, 52.92310503550938, 53.13863468170166, 53.12696518216814, 47.89778913770403, 42.82938051223755, 48.625164781297954, 55.23610476085118, 48.38331535884312, 40.72300284249442, 48.45939465931484, 47.885574204581125, 42.92093345097133, 43.12356724057879, 43.439449719020296, 43.09855372565133, 41.54106984819685, 39.83541216169085, 41.851563998631065, 43.40940570831299, 42.866998059409006, 45.69627325875418, 46.11837979725429, 42.881915841783794, 42.69144834790911, 41.04473223005022, 40.81461831501552, 41.760883058820454, 42.7151278087071, 41.00898722239903, 40.89996651240757, 39.89768886566162, 45.001137256622314, 40.59197718756539, 32.8891555922372, 34.180613790239605, 37.87832348687308, 40.751504353114534, 45.78903865814209, 45.61306163242885, 48.55140617915562, 53.85376065117972, 51.177484784807476, 52.758585589272634, 52.175002915518625, 51.39279556274414, 48.516012055533274, 50.99940592902047, 53.80201741627285, 53.506479263305664, 52.999677658081055, 53.279384340558735, 50.11291306359427, 50.294882910592214, 49.82448639188494, 47.70811721256801, 44.04330723626273, 41.8161108153207, 46.64938545227051, 50.40141269138881, 57.24356440135411, 56.19652993338448, 57.55547251020159, 56.75448765073504, 60.024556568690706, 58.55217770167759, 56.91901057107108, 57.24521459851946, 55.753881045750205, 53.01226084572928, 48.52405112130301, 48.4028536932809, 51.038781370435444, 56.59475551332746, 62.89290496281215, 63.47418430873326, 61.717332295009065, 64.01553235735211, 64.17169312068394, 65.08506856645856, 66.14320972987584, 65.53637490953717, 65.76395620618547, 65.66860607692173, 65.44126796722412, 66.43974494934082, 68.89059693472726, 72.5412152154105, 76.33780820029122, 73.12004879542759, 42.672083718436106, 0.4081810185951846, 27.794494935444423, 71.31523336683, 64.22568757193429, 47.19426318577358, 48.11116484233311, 34.81575557163784, 20.06801646096366, 12.883227365357534, 7.151392579078674, 6.226687661239079, 4.263870630945478, 3.075668526547296, 31.878338609422954, 48.16476672036307, 47.84596947261265, 28.750881467546733, 1.0121658018657138, 0.10197632906160184, 0.1426631004682609, 0.23488390765019826, 0.09782948265118258, 0.14370305037924222, 0.3541991338133812, 44.7827136857169, 77.54286902291435, 64.43084008353097, 48.905128547123496, 59.53138732910156, 33.36579506737845, 53.10081216267177, 64.03445925031389, 70.74650941576276, 78.55349840436662, 77.32539735521588, 49.35673018864223, 0.2443539494914668, 5.26367689030511, 1.3866395077535083, 12.391600625855581, 51.31390919004168, 61.42206859588623, 72.3941079548427, 67.46412481580461, 64.46298245021275, 63.69408089773995, 64.696900503976, 64.75114509037563, 69.12041555132184, 60.949313163757324, 62.67993572780064, 59.45290742601667, 53.88818550109863, 52.13950456891741, 53.60077674048287, 50.024882861546104, 50.16728271756853, 54.97204194750105, 55.81689773287092, 59.039017132350374, 62.17072309766497, 62.37254742213658, 56.84838908059256, 56.04381547655378, 53.554783139910015, 49.08424268450056, 48.4174588067191, 50.52551794052124, 50.207321711948936, 49.291510922568186, 50.22183649880545, 57.53858838762556, 57.452840668814524, 60.12165069580078, 57.78172322681972, 57.55997494288853, 57.81031158992222, 58.66234833853585, 59.74566282544817, 57.846577712467735, 55.95906482424055, 56.66564103535244, 55.63058526175362, 57.09025239944458, 53.96687732424055, 55.97997890199934, 55.410369055611746, 57.56913961683001, 56.718711376190186, 54.593778542109895, 45.950000626700266, 52.42282778876168, 56.93066964830671, 51.56295347213745, 43.07286623546055, 47.78418261664254, 50.82683004651751, 42.93012591770717, 45.44782304763794, 46.28476136071341, 45.53184413909912, 44.876392773219514, 42.98793492998396, 43.13027572631836, 45.946182591574534, 46.099129813058035, 51.78156464440482, 49.014607838221956, 47.56721469334194, 45.81307942526681, 45.959808009011404, 41.87903370176043, 44.1816007069179, 46.15629959106445, 41.70633275168282, 44.76366172518049, 40.01666634423392, 46.04954399381365, 41.44784239360264, 31.883643559047155, 33.07419306891305, 42.81448357445853, 47.39078256062099, 50.83919784000942, 50.924712794167654, 51.15550763266427, 55.10745538984026, 53.93199041911534, 54.11919920785086, 54.58888701030186, 53.44655799865723, 52.78193848473685, 54.19521944863455, 55.81857224873134, 57.17811584472656, 56.69615404946463, 55.64210884911673, 52.666890212467735, 51.38966192517962, 52.630436488560264, 51.87349278586251, 45.9106251852853, 44.85868876320975, 48.655848026275635, 52.82695933750698, 60.04100295475551, 57.6089562688555, 59.86758286612374, 61.78308309827532, 61.22881834847586, 59.928240639822825, 60.19974149976458, 61.60037326812744, 58.97968646458217, 55.45802327564785, 52.094275270189556, 49.24995027269636, 52.76728473390852, 58.95769541604178, 63.077032225472585, 64.49930763244629, 62.7555182320731, 64.8703761781965, 66.3756547655378, 67.1182643345424, 66.38149125235421, 66.82065909249442, 66.16164330073765, 66.66009317125592, 68.58925356183732, 68.70193249838692, 70.2984617778233, 74.95754855019706, 76.59893539973667, 74.66493211473737, 43.80147171020508, 0.8780673603926386, 30.13140514918736, 78.8936961037772, 69.27137211390904, 57.80424233845302, 58.7019739151001, 47.31743042809622, 33.64392103467669, 33.17318752833775, 33.14245217187064, 2.2711135957922255, 7.47896192755018, 12.907205598694937, 39.53721284866333, 42.88105773925781, 48.86589901787894, 16.12893329347883, 0.2445729805954865], [0.017834154722679938, 0.03178284490214927, 0.028564919717609882, 0.10616183839738369, 0.095118911670787, 0.5069466488701957, 24.66684671810695, 44.269992215292795, 34.07677296229771, 19.871997356414795, 47.052596364702495, 21.73714746747698, 40.670856612069265, 45.027047089168, 53.73247984477452, 66.15741184779576, 61.29531260899135, 49.14996916907174, 0.4820535331964493, 1.3723970034292765, 0.6570183475102697, 19.8578508240836, 59.55561569758824, 61.543307713099885, 67.11706229618618, 60.919199671064106, 61.36082717350551, 58.021043504987446, 59.574855259486604, 55.968743664877756, 55.8672513280596, 53.670686040605815, 54.29282079424177, 49.82783194950649, 49.525852816445486, 47.03617082323347, 47.30566017968314, 45.793381282261436, 46.02148716790335, 45.70840828759329, 51.45479781287057, 49.92183065414429, 51.98135314668928, 51.37743656975882, 51.27683012826102, 50.483641147613525, 48.691794531685964, 46.96569177082607, 45.93566649300711, 45.82264362062727, 43.611546175820486, 44.74085078920637, 46.19536236354283, 50.50367627825056, 53.54648699079241, 53.22905853816441, 53.9624582699367, 57.37439898082188, 52.377112116132466, 50.9928503036499, 52.15093435559954, 53.181703090667725, 52.84603214263916, 50.07367311205183, 50.48975208827427, 46.34982776641846, 44.411190032958984, 45.29309013911656, 47.43756825583321, 48.05926179885864, 48.9535505431039, 44.30122784205845, 36.00465488433838, 48.53056853158133, 54.259587560381206, 42.35144519805908, 38.599160875592915, 46.703004700796946, 45.51939296722412, 45.24848965236119, 39.702263832092285, 39.170122146606445, 40.545445101601736, 39.917473861149375, 39.58655548095703, 38.90363441194807, 37.76933056967599, 37.6549527985709, 37.349419661930625, 38.38226243427822, 37.64629186902727, 37.58019018173218, 37.1158629144941, 38.43590252740042, 38.50675678253174, 40.05912331172398, 38.832627296447754, 36.879877771650044, 40.00449310030256, 43.36201899392264, 43.02224166052682, 35.50492654527937, 36.08513586861746, 33.9815548488072, 35.87818724768502, 39.065256459372385, 44.92789282117571, 52.49246263504028, 48.04814468111311, 52.00019318716866, 50.4277845791408, 50.6505959374564, 49.954827649252756, 47.79533100128174, 46.641141414642334, 47.68105397905622, 50.28801114218575, 50.923965862819124, 53.92434740066528, 51.61283458982195, 49.13326917375837, 50.83157219205584, 46.93492514746529, 46.05670063836234, 40.62873663221087, 44.316107409340994, 50.53557893208095, 50.613047872270855, 54.71402406692505, 55.83850315638951, 58.298901966639924, 53.471689632960725, 51.10980585643223, 52.11880588531494, 54.45355347224644, 53.62388644899641, 47.27343790871756, 43.591101101466585, 43.971747738974436, 47.7570846421378, 54.84607458114624, 59.09011418478829, 60.01187610626221, 61.660676683698384, 63.101865087236675, 61.4396961757115, 61.50126416342599, 61.244437898908345, 61.04268305642264, 63.06989642551967, 61.61133057730538, 57.82761607851301, 59.02718435014997, 62.9141525541033, 66.36826188223702, 69.5433246067592, 69.18492957523891, 31.740229266030447, 0.16085064810301575, 28.374296052115305, 65.05888775416783, 51.15620245252337, 32.781958784375874, 37.02751309531075, 21.755165883472987, 12.814418486186437, 1.8037745015961784, 6.332559100219181, 10.25502608503614, 2.796451909201486, 2.6329425573349, 8.220056789261953, 15.096156529017858, 5.412249786513192, 0.40140131382005556, 0.17588927756462777, 0.07495067281914608, 0.08512518328747579, 0.049751076448176584, 0.1007911048031279, 0.07912768011114427, 0.3108572209519999, 29.036499329975673, 57.58670466286795, 44.72641243253435, 25.789977857044764, 65.2782632282802, 26.8706659248897, 48.265317576272146, 53.50948783329555, 62.757519313267295, 72.27364008767265, 69.81884847368512, 60.80349131992885, 0.44106111569064005, 1.0710384313549315, 1.1872064492532184, 21.860094104494365, 67.03599071502686, 69.62783554622105, 71.84770856584821, 66.21580450875419, 65.31484549386161, 62.06156689780099, 62.60713250296456, 59.88241032191685, 60.10998467036656, 59.174423626491, 58.77513149806431, 53.08286843981062, 52.7954284123012, 49.37290212086269, 51.00102138519287, 49.48819358008248, 49.39153371538435, 47.82826198850359, 52.43347242900303, 55.41458313805716, 56.281864234379356, 54.096881593976704, 56.61415835789272, 55.04969154085432, 51.90208462306431, 49.28695985249111, 48.08585950306484, 48.07886961528233, 47.04580797467913, 45.986829553331646, 47.01298468453543, 53.829309940338135, 54.30042559759957, 56.27683373859951, 55.695700304848806, 58.5142822265625, 54.69951622826712, 53.88081693649292, 55.99590069907052, 55.277582032339915, 53.494535309927805, 52.94710063934326, 50.83919089181082, 48.100141525268555, 47.91811956678118, 49.54173639842442, 48.90165097372872, 49.82708501815796, 51.179551873888286, 48.48201104572841, 39.6246976171221, 51.70304305212838, 55.54717213766915, 44.146800654275076, 41.731151717049734, 49.53489589691162, 48.74222108295986, 48.18591703687395, 42.918001311165945, 41.6427914755685, 43.51116207667759, 42.060569286346436, 41.572083132607595, 40.10032612936837, 39.305327142987935, 41.087595667157856, 40.671516690935405, 41.79944903509957, 40.598199299403596, 39.11504030227661, 40.91733006068638, 42.09699869155884, 40.021095820835654, 43.80143696921212, 42.841004848480225, 39.57511874607631, 41.14483492715018, 45.28741693496704, 44.32697091783796, 38.14889676230294, 36.89714404514858, 34.87709426879883, 39.504201957157676, 43.27970021111624, 49.403647899627686, 55.257807459150044, 48.829983779362266, 52.478691305433, 49.66412891660418, 50.14957523345947, 49.58451298304966, 51.66186107907976, 49.15396090916225, 49.24650396619524, 51.75051661900112, 51.519624505724224, 54.23433780670166, 53.338551725660054, 52.54910782405308, 52.938220841544016, 48.9027487891061, 49.350497654506135, 40.861053126198904, 44.610151699611116, 52.11889968599592, 53.92898532322475, 56.89325359889439, 56.63973120280674, 59.98304803030831, 55.88347537176949, 55.77782801219395, 56.63744177137102, 59.13080283573696, 56.465675354003906, 52.65816674913679, 47.55403743471418, 47.388864857809885, 52.1525046484811, 59.3349061693464, 61.7404420035226, 63.78214236668178, 65.00804778507778, 66.08895819527763, 64.25162519727434, 65.99655410221645, 63.7105689729963, 67.90266036987305, 66.7815476826259, 67.09551593235561, 64.15287739889962, 65.99046748025077, 68.75148010253906, 73.40273625510079, 74.78041117531913, 74.63142790113176, 33.55346243722098, 0.08454692217388324, 33.0328825541905, 74.81763962336949, 58.39068072182791, 42.03035504477364, 43.93127448218209, 35.037198134831016, 18.953624418803624, 12.638041939054217, 6.158042933259692, 16.941031796591624, 4.63046931368964, 1.9690769229616438, 16.47902349063328, 25.436227696282522, 14.986685923167638, 2.712137473481042, 0.04814047858651195, 0.13257297261485032, 0.17773999539869173, 0.09526790439018182, 0.18570147747439997, 0.2162917224424226, 0.503794500870364, 32.943789277757915, 71.73980304173061, 55.4147116797311, 43.35757909502302, 75.73890822274345, 37.08495385306222, 56.03429644448416, 63.44707243783133, 65.53071212768555, 78.7714147567749, 70.6624014718192, 68.2307265145438, 0.8473014427082879, 3.9900364790643965, 2.1592604092189243, 22.014321531568253, 69.3340379170009, 70.46004908425468, 69.26416683197021, 65.78070136478969, 64.20933846064976, 64.47045176369804, 64.44320092882428, 61.55343818664551, 62.6304715020316, 60.54870087759835, 59.074821199689595, 57.02803822926113, 56.23789603369576, 54.485869543892996, 52.53248773302351, 51.07010384968349, 52.003799302237375, 51.16176795959473, 56.54689979553223, 57.77304145268032, 59.289610862731934, 55.365744250161306, 57.78676414489746, 55.800093514578684, 56.18934897014073, 51.64377491814749, 52.30718891961234, 48.93348067147391, 50.20814854758126, 48.17977830341884, 49.79825694220406, 56.31928028379168, 57.85143102918352, 57.51256390980312, 60.14951297215053, 61.5013336454119, 56.631268296922954, 55.699403694697786, 57.88796465737479, 59.15179334368025, 57.40361615589687, 56.059688636234824, 54.63509600503104, 51.690880230494905, 51.497828006744385, 51.49023362568447, 53.77733394077846, 52.40691988808768, 52.71951239449637, 52.317819663456504, 44.40757349559239, 52.40540170669556, 58.158388546534944, 43.933226925986155, 42.03428425107683, 53.38065433502197, 50.44434561048235, 51.174208709171836, 44.08777223314558, 43.47407954079764, 45.69804852349417, 43.8892274584089, 43.87076956885201, 44.27914646693638, 40.86775813783918, 44.08243949072701, 42.515328884124756, 42.35710103171212, 42.56519610541207, 41.226066316877095, 42.852702140808105, 43.94406958988735, 42.43762370518276, 44.15626410075596, 43.32363019670759, 41.27796936035156, 42.08555848257882, 47.912387302943635, 45.52475697653634, 37.83024542672293, 37.595041956220356, 37.10967901774815, 43.76460109438215, 45.65004341942923, 51.10409096309117, 57.43929862976074, 51.03763839176723, 56.56208855765206, 53.59025716781616, 52.4136700630188, 51.86247294289725, 52.231922558375764, 52.06635740825108, 51.7495299748012, 55.88914162772042, 54.65842458180019, 57.59232922962734, 55.990050315856934, 53.21227516446795, 55.211237158094136, 51.31808158329555, 50.20831183024815, 44.04095527103969, 47.64282499040876, 56.40156085150582, 54.50297253472464, 59.017957142421174, 58.410448346819194, 61.1576201575143, 57.927426951272146, 55.865041800907676, 57.440816811152864, 60.18197495596749, 59.11226504189627, 52.817204066685264, 48.21834775379726, 48.348428453717915, 53.33099903379168, 58.7062748500279, 62.84289877755301, 62.85632964542934, 66.00426660265241, 68.9220861707415, 66.39915357317243, 65.63337871006557, 65.34580666678292, 67.14235373905727, 69.04665347508022, 68.68238026755196, 64.6165862764631, 67.36042990003313, 69.69392681121826, 75.07429218292236, 77.76762240273612, 76.7982097353254, 36.482392174857004, 0.3806907422840595, 35.38798141479492, 81.28300789424351, 63.452360016959055, 52.16060972213745, 55.09778002330235, 48.27152231761387, 34.762938840048655, 29.732116494859966, 35.869161537715364, 18.44609498977661, 4.633591226169041, 8.164265360151019, 23.47265461512974, 23.41715066773551, 9.456439222608294, 0.6374125395502362, 0.2523669595164912], [0.13188177613275393, 0.1979845626545804, 0.06840511012290205, 0.1171120365283319, 0.20594407697873457, 0.5814151614904404, 14.324725832257952, 32.054628304072786, 29.80496140888759, 16.48328968456813, 20.234437976564678, 30.678561891828263, 43.09897061756679, 42.87385245731899, 47.45890269960676, 67.02692331586564, 61.41049289703369, 49.46401732308524, 1.2930063435009547, 0.7966143882700375, 1.5717941267149789, 27.0312248979296, 66.8222085407802, 63.82551302228655, 66.58315576825822, 58.032223156520296, 60.08836882455008, 56.81613901683262, 57.21808188302176, 54.79201412200928, 54.196181774139404, 51.488986424037385, 52.4281952721732, 50.54798494066511, 50.10647555759975, 45.2586236000061, 45.85240970339094, 45.436455794743125, 47.4149866104126, 44.717126165117534, 46.39395577566964, 49.21416357585362, 49.74561391557966, 49.20512396948678, 49.5923991884504, 48.14441892078945, 49.617162568228586, 47.51348427363804, 43.628704752240864, 44.24972084590367, 44.24994318825858, 43.87818329674857, 44.70830890110561, 50.843575205121724, 52.78716353007725, 53.21664558138166, 52.405554567064556, 52.69290426799229, 53.80860778263637, 51.56350237982613, 50.88390602384295, 51.317501408713206, 49.74125392096383, 49.23404584612165, 47.67674262183053, 46.307026863098145, 42.76590871810913, 41.358439922332764, 46.747028487069265, 48.86853585924421, 49.2318571635655, 47.15202161243984, 34.48026875087193, 51.16122947420393, 45.654990536826, 42.44888326099941, 48.957795892442974, 41.20118829182216, 43.8992154938834, 40.32219253267561, 41.01601185117449, 38.247707094464985, 41.89582749775478, 37.641132831573486, 39.52285439627511, 38.279571533203125, 37.332768304007395, 38.33017178944179, 38.193167209625244, 37.752686159951345, 39.894819259643555, 36.315176827566965, 38.835785252707346, 37.91820962088448, 39.55373566491263, 40.1953010559082, 40.99668891089303, 38.200250898088726, 39.281668526785715, 40.2051431792123, 42.06996325084141, 39.19314500263759, 39.74839292253767, 32.005879742758616, 31.630652700151714, 46.5032057762146, 52.113320282527376, 51.46954883847918, 47.25086668559483, 48.82195166179112, 45.97813388279506, 47.41270760127476, 48.75211531775338, 53.82069417408535, 51.07890026909964, 49.99089227403913, 48.895526136670796, 49.47915397371565, 50.972519874572754, 52.41210324423653, 51.29164021355765, 51.00196634020124, 50.22058929715838, 46.689678055899485, 42.18765531267439, 41.19699852807181, 45.86570160729544, 51.35136692864554, 53.97564942496163, 51.82797166279384, 45.851718357631135, 50.03068808146885, 55.43614687238421, 54.56094135556902, 53.46891382762364, 47.20118011747088, 48.17121464865548, 42.95925971439907, 44.99711077553885, 48.0373923437936, 54.833456652505056, 57.71447508675711, 58.53375802721296, 61.463146345955984, 61.088249342782156, 60.54481683458601, 64.65991524287632, 61.493211201259065, 63.20141192844936, 62.747222082955496, 60.98664583478655, 58.514594895499094, 60.68650450025286, 62.35257135118757, 67.59547356196812, 69.35006741115025, 63.67739132472447, 20.651779787881033, 0.04786852514371276, 37.72661304473877, 61.46688447679792, 50.992287499564036, 32.61970097678048, 32.30490936551775, 28.6769700050354, 17.601235730307444, 10.337101680891854, 3.422569283417293, 18.020953825541906, 3.832209885120392, 0.9081533859883035, 1.8468162034239088, 1.3162473078284944, 0.33019850882036345, 0.046281642080949884, 0.23285671642848424, 0.12419968763632433, 0.06575251317449979, 0.024289541811283146, 0.18694205661969526, 0.1641701635505472, 0.5889290954385484, 18.242636101586477, 47.876406056540354, 44.24475983210972, 18.18607255390712, 36.04972090039934, 31.05850328717913, 51.15453488486153, 49.667950425829204, 55.855300426483154, 75.62255368913922, 68.22986493791852, 58.75935908726284, 1.791097838963781, 1.2661845598902022, 1.5826841252190726, 30.76717574255807, 74.7170991897583, 73.03685106549943, 72.31938007899693, 64.72632612500871, 62.79611655644008, 60.91639954703194, 60.62822995867048, 60.435660634722026, 57.47471359797886, 56.10710661751883, 56.92307874134609, 54.28302036012922, 53.6818413734436, 48.50720868791853, 49.524609088897705, 49.508315563201904, 51.07917124884469, 49.18267086574009, 49.332182203020366, 51.92795624051775, 54.27387653078352, 54.25855575289045, 52.35025385447911, 52.2626440184457, 52.64795289720808, 49.39967005593436, 47.57156079156058, 47.1053957257952, 47.6631623676845, 45.89345966066633, 46.87131438936506, 51.4284884589059, 55.046137537275044, 55.43240874154227, 55.74508115223476, 54.3929443359375, 55.501136847904746, 54.424360615866526, 53.22397593089512, 53.04208598818098, 51.33895397186279, 50.702443395342144, 48.6907696723938, 48.325881549290244, 44.8337482043675, 43.7521082333156, 46.6722172328404, 50.7192371913365, 50.55015972682408, 47.99285439082554, 38.97389459609985, 51.875365325382774, 45.50485733577183, 42.994202205113, 47.705390044621055, 44.39845051084246, 46.810569763183594, 46.058354309626985, 43.60111345563616, 44.55981200081961, 43.82252127783639, 40.61865132195609, 41.12409108025687, 41.10281569617135, 40.26928547450474, 40.04616492135184, 40.37924419130598, 40.35684667314802, 41.43447058541434, 40.65692547389439, 40.550023964473176, 40.358000074114116, 39.704459462847026, 40.080978870391846, 42.36765187127249, 40.885288442884175, 42.53731993266514, 41.77824313299996, 43.41382128851754, 41.504577909197124, 41.15826232092721, 34.32023089272635, 36.58574315479824, 48.917520659310476, 54.48702641895839, 53.87092964989798, 50.24075296946934, 51.49449634552002, 48.11950268064226, 49.371172019413535, 49.10545553479876, 54.399371419634136, 55.661921637398855, 54.87066773005894, 52.96707671029227, 51.83611495154244, 52.27737072535923, 52.483485562460764, 52.33763245173863, 52.46228313446045, 51.97528042112078, 49.75190898350307, 45.28156655175345, 42.92275387900216, 46.6905118397304, 54.25416101728167, 57.34165906906128, 55.054121017456055, 47.628258092062815, 53.67474031448364, 59.242620195661274, 57.79245819364275, 57.14113753182547, 52.324364866529194, 53.403218609946116, 47.45648125239781, 49.010404178074424, 52.16614396231515, 58.25192172186715, 61.02649375370571, 62.11057254246303, 64.75279876164028, 64.03819738115583, 65.43281895773751, 67.62857478005546, 65.81098856244768, 67.53665011269706, 66.06167956760952, 65.46505859919957, 65.04755524226597, 65.63747814723423, 66.52627781459263, 73.12477357046944, 74.60343360900879, 68.83417756216866, 21.483654601233347, 0.11607024100209985, 44.334606988089426, 69.48858669825962, 57.717615672520225, 41.22317239216396, 42.00847169331142, 44.158393723624094, 23.705030168805802, 18.391711439405167, 9.02918233190264, 25.40251156261989, 5.3351986067635675, 0.5617794979895864, 6.808655313083103, 7.250862555844443, 1.0234354542834418, 0.11052712558635644, 0.17424957055066312, 0.14011825488082, 0.2964951316160815, 0.2189152238092252, 0.37212328772459713, 0.20794918867094175, 0.6863273148025785, 20.280264820371354, 64.30908679962158, 55.99265589032854, 38.689807074410574, 40.15472705023629, 46.978566782815115, 61.224927357264924, 57.34961475644793, 61.6729610988072, 80.92486994607108, 72.7532742364066, 66.3500645501273, 1.664563651595797, 2.2366961283343176, 3.6721833177975247, 31.58395038332258, 68.44299398149762, 68.87314305986676, 70.87693405151367, 66.02031694139752, 63.95754964011056, 63.25554534367153, 60.14696298326765, 63.1366616657802, 58.429486410958425, 57.833827768053325, 58.179295676095144, 57.634678500039236, 58.492041042872835, 48.92766850335257, 50.65370525632586, 52.52668946129935, 53.50449902670724, 50.97288465499878, 51.82397992270333, 55.86639322553362, 56.58325277056013, 56.83436761583601, 53.232518741062705, 53.56044939586094, 56.71995857783726, 50.99305180140904, 48.21150377818516, 48.013421058654785, 50.441545486450195, 47.40457820892334, 50.630380153656006, 54.45170177732195, 57.971666131700786, 58.35104124886649, 58.053977966308594, 56.15305505480085, 57.89405475343977, 55.53426933288574, 56.36252587182181, 56.21516152790615, 54.28709895270211, 54.09524529320853, 52.92483513695853, 52.87022229603359, 49.71367652075631, 46.59640891211373, 50.56987871442522, 55.2537636075701, 52.75793245860508, 53.16749749864851, 44.41187443052019, 57.16004010609218, 47.292951924460276, 45.37855992998396, 50.93167488915579, 46.39371606281826, 48.953922271728516, 46.28938538687569, 46.19759620938982, 44.12268693106515, 47.369569710322786, 41.846557821546284, 45.28980711528233, 42.97725554874965, 42.727453913007466, 42.809585094451904, 43.10118361881801, 43.33232934134347, 44.41297919409615, 43.268416336604524, 43.94349636350359, 42.20041915348598, 42.82451677322388, 42.88142946788243, 44.94732345853533, 43.65280457905361, 43.3416051864624, 44.261904512132915, 48.07110847745623, 42.55597931998116, 40.0865478515625, 36.77895866121565, 43.21734707696097, 50.492816243852886, 56.68519674028669, 55.560074942452566, 53.69658545085362, 55.084373474121094, 50.78512348447527, 51.770655972617014, 52.72941705158779, 56.665345736912315, 56.32542249134609, 55.42429324558803, 54.38385261808123, 54.34615864072527, 56.703731060028076, 55.17958811351231, 53.502928733825684, 55.20259012494768, 55.62135110582624, 51.14765269415719, 47.64727531160627, 45.39848388944353, 48.79142822538103, 56.24238804408482, 59.72955690111433, 55.605436256953645, 48.5497281891959, 53.71818740027291, 60.01182746887207, 59.59073884146554, 57.81420952933175, 53.294277804238455, 54.39975357055664, 51.42446197782244, 48.775169440678184, 52.47968142373221, 58.70070934295654, 61.217339924403596, 63.499927384512766, 66.93014880589077, 63.793655531747, 66.79486737932477, 67.9098448072161, 67.74585342407227, 67.79626955304826, 69.1848531450544, 65.66784177507672, 67.49422441210065, 66.9897574016026, 69.06748417445591, 74.87314878191266, 75.37664999280656, 70.21946770804269, 25.11349081993103, 0.17579737678170204, 47.62013564790998, 73.86631311689104, 65.11136749812535, 51.696094853537424, 52.61536237171718, 57.65090601784842, 42.591442925589426, 36.19342006955828, 40.077511719294954, 42.921353816986084, 5.350149827344077, 2.2225315741130283, 5.235341702188764, 2.6586756450789313, 0.34873087438089506, 0.13131305522152356, 0.2689036178801741], [0.06210711771356208, 0.02432388416491449, 0.07548594873930727, 0.09152789400624377, 0.040005271189979145, 0.7219998006309781, 5.9234643663678845, 25.819255828857422, 24.181433405194962, 24.703767708369664, 31.47119849068778, 24.872499500002178, 46.933229787009104, 50.59223801749093, 41.492703437805176, 61.85954802376883, 61.77873352595738, 55.285933767046245, 3.1354523471423557, 0.7941753534334046, 1.8514115682670047, 31.037762914385112, 55.186505045209614, 68.6833530153547, 62.806990487234934, 59.85084465571812, 58.45565332685198, 57.138997486659456, 54.656729221343994, 53.971692425864084, 53.28075660978045, 52.07278796604702, 52.02593626294817, 51.588081632341655, 50.052147592817036, 46.803736209869385, 47.4612581389291, 46.35483046940395, 45.45751231057303, 45.0055250440325, 45.07890844345093, 45.59205722808838, 45.823129994528635, 47.898779256003245, 48.58645289284842, 49.43687071119036, 48.08767645699637, 46.764068944113596, 45.192681721278596, 44.53412798472813, 43.74190132958548, 46.281745842524934, 45.356013025556294, 49.74159090859549, 52.75683811732701, 52.4101299558367, 54.09523139681135, 52.30800880704607, 52.655856473105295, 50.72282246180943, 52.12574366160801, 50.38724878856114, 48.39595760617937, 46.306061063494, 44.90390763963972, 40.653833525521414, 40.612724508558, 41.58309602737427, 43.160027912684846, 45.211400168282644, 49.09368181228638, 45.51746484211513, 36.84006111962454, 39.68804781777518, 38.61256742477417, 43.01945890699114, 43.11501400811331, 38.81697300502232, 38.34829616546631, 42.59681040900094, 40.886455740247456, 41.785604749407085, 40.0112224306379, 38.02885273524693, 39.300369603293284, 39.523590905325754, 38.372868469783235, 40.84928287778582, 38.46987574441092, 39.53320721217564, 37.660118784223286, 38.177724838256836, 39.72474472863333, 39.76332112721035, 38.318693365369526, 38.63735512324742, 39.055334431784495, 38.74241883414132, 42.40272637775966, 40.30414111273629, 40.56113413402012, 40.00258929388863, 44.12094293321882, 41.01049150739397, 30.448854446411133, 45.72036961146763, 49.85304348809378, 51.65421806062971, 46.535084111349924, 46.09225109645298, 44.54634986604963, 46.27494355610439, 48.00354072025844, 48.95933491843087, 51.49936008453369, 56.45406491415841, 51.61198343549456, 56.56362063544137, 52.18833998271397, 47.69755942480904, 52.113688537052695, 50.612259251730784, 51.415547439030235, 50.29528938020979, 45.41994340079171, 39.62625401360648, 42.68499347141811, 50.747703960963655, 53.45670584269932, 53.94579996381487, 50.369624682835166, 55.115244320460725, 53.702421937670024, 52.80281434740339, 51.0046066556658, 47.50080033711025, 45.30111183438982, 43.897398539951865, 44.04884147644043, 49.34131213596889, 54.133165087018696, 57.76135458265032, 58.965512139456614, 59.22973823547363, 62.09978893824986, 60.475181988307405, 61.26398318154471, 64.37916633061, 64.28403159550258, 63.763569831848145, 63.84630898066929, 62.081007957458496, 59.10685934339251, 64.82584517342704, 66.00340502602714, 68.17118045261928, 61.18583679199219, 14.307297144617353, 0.17979027038174017, 39.34121458871024, 61.5947174344744, 54.23711708613804, 31.76721954345703, 26.539092676980154, 32.29224974768502, 17.7600576536996, 6.640027744429452, 5.630284692559924, 26.96849134990147, 5.360584284578051, 0.2123228082699435, 0.1830417559083019, 0.12317284702190331, 0.003643658835374351, 0.059269443553473265, 0.11178065796515771, 0.12458007436777864, 0.02978434892637389, 0.04207748660285558, 0.14408696549279348, 0.06585252923624856, 0.7677150389977864, 8.677626933370318, 41.016796997615266, 38.674826758248464, 24.126909153802053, 27.847996064594813, 30.064094475337438, 55.069684982299805, 58.12488433292934, 49.15620517730713, 68.13992745535714, 69.81282438550676, 60.58239964076451, 3.580405865396772, 0.41083778174860136, 2.6823181935719083, 36.82082503182547, 62.543869154793875, 74.49004595620292, 68.43459360940116, 65.69049985068185, 61.34843853541783, 62.254893575395855, 61.71408748626709, 57.69829273223877, 57.972635405404226, 56.17229809079851, 56.77554069246565, 56.05550234658377, 53.56314182281494, 50.34914486748831, 49.54130561011178, 49.039013385772705, 46.97636072976248, 47.942212445395334, 48.43933520998274, 48.529491560799734, 50.43179716382708, 49.95930576324463, 52.555371625082834, 52.267896856580464, 49.76233128138951, 49.00760405404227, 47.429629938943044, 46.27387353352138, 45.69382749285017, 48.11061940874372, 47.281331062316895, 53.67758560180664, 55.29810701097761, 53.558840887887136, 54.028681550707134, 54.80170685904366, 54.35503843852452, 53.26529686791556, 54.558235032217844, 54.24129295349121, 49.43378571101597, 48.57986947468349, 48.36914798191616, 44.18026665278843, 43.11241538184029, 43.364673205784385, 46.10579660960606, 46.75321585791451, 49.68049192428589, 47.52437557492937, 42.36909362248012, 40.0996903691973, 38.8019996370588, 45.64959178652082, 42.94305304118565, 40.550006593976704, 40.70835951396397, 45.1083653313773, 42.89247710364205, 42.0063351222447, 41.56371750150408, 39.84444481985909, 42.38715546471732, 41.027413845062256, 41.014688219342915, 43.197259834834504, 41.243242263793945, 41.559100423540386, 40.6049598966326, 40.31901025772095, 41.397679873875205, 41.70209435054234, 40.54134566443307, 41.26647703988211, 40.94748524257115, 41.47490215301514, 42.5162946837289, 42.23213420595442, 42.514745235443115, 40.35658611570086, 44.00112819671631, 43.925524847848074, 34.3197340965271, 46.984945229121614, 53.228172642844065, 54.436321939740864, 48.92076199395316, 48.18198783057076, 46.3340379851205, 47.907363755362375, 50.385532583509175, 52.47027356284005, 53.44230917521885, 57.00544963564192, 51.50389378411429, 57.39859955651419, 54.99235848018101, 51.306523254939485, 52.40421009063721, 52.28687238693237, 53.25565276827131, 53.58224589484078, 48.31517437526158, 43.03473799569266, 45.652715001787456, 50.97181463241577, 56.838960375104634, 57.32346173695156, 54.03536571775164, 56.4254035949707, 57.597248554229736, 56.15126241956438, 53.787565163203645, 50.26416145052229, 47.14388527188982, 47.81560584477016, 48.10598496028355, 52.39228698185512, 55.50499309812273, 62.2651560647147, 61.6754207611084, 63.77515247889927, 66.14041655404228, 64.39361163548061, 65.2280694416591, 68.8120197568621, 68.89672524588448, 69.22272082737514, 68.32283183506557, 65.38860062190464, 63.75354358128139, 67.81987953186035, 72.40149388994489, 71.46416105542863, 64.07047176361084, 14.446496486663818, 0.25848775250571115, 45.57325192860195, 70.12595885140556, 62.079395975385395, 40.103452818734304, 33.20397499629429, 46.427515574863975, 22.998202085494995, 15.708810465676443, 19.857352290834697, 39.84954827172415, 8.261411598750524, 0.6581739740712302, 0.6485687409128461, 0.40747338799493654, 0.1069493664960776, 0.061843649351171086, 0.04459442065230437, 0.1506428758480719, 0.19345806911587715, 0.11956864542194776, 0.26525657357914106, 0.2673245040433747, 1.104259614433561, 7.571938378470285, 56.281308378492085, 50.11193684169224, 47.03336722510201, 62.571960721697124, 41.46991682052612, 65.78869179316929, 64.63452652522496, 58.479367528642925, 71.92559787205288, 75.46526036943708, 69.08058847699846, 4.398864141532353, 1.215912388903754, 3.871345613683973, 37.964946678706575, 66.48083659580776, 73.821775163923, 68.01397051130022, 67.25116947719029, 64.2658759525844, 65.01714992523193, 62.09187494005476, 59.94323485238211, 60.208100182669504, 59.36490849086216, 57.52792985098702, 57.99278170721871, 54.97381026404244, 52.923782484872, 53.39255312510899, 51.55485187258039, 49.75492450169155, 49.93075908933367, 51.86805929456438, 50.81014742170061, 51.822447844914024, 51.67342982973371, 55.342915943690706, 53.74695989063808, 52.88675553458077, 49.66884674344744, 49.77736370904105, 48.9159642628261, 46.51376703807286, 50.93425267083304, 47.991537707192556, 53.83290910720825, 56.975805146353586, 55.38212810243879, 59.16899708339146, 56.02703210285732, 57.402580874306814, 53.93723978315081, 58.895008768354145, 57.4896730695452, 51.386597769601, 52.75257887159075, 51.97435631070818, 46.73757893698556, 46.78721686771938, 45.066419056483674, 50.18067537035261, 51.371395111083984, 54.4080080304827, 51.22730336870466, 44.83871616636004, 42.50575079236712, 41.81728506088257, 45.961857727595735, 47.50161675044468, 44.4041862487793, 43.57526963097708, 47.22120482581002, 44.47205972671509, 45.78519977842058, 44.32248932974679, 42.43408012390137, 46.297518253326416, 43.988492897578645, 44.041556290217805, 45.76161411830357, 44.09686395100185, 45.27516378675188, 43.80662727355957, 42.94780213492257, 43.12461641856602, 44.06962353842599, 41.42330483027867, 44.06298106057303, 43.427033288138254, 42.65191657202584, 45.31244434629168, 44.16159336907523, 44.78009768894741, 44.15664277757917, 45.846409933907644, 44.035278592790874, 36.232889311654226, 50.852142333984375, 53.90970059803554, 55.27739095687866, 52.65697513307844, 51.994443552834646, 48.794141496930806, 51.183873653411865, 53.594710963112966, 53.15432718821934, 56.76849174499512, 59.541198185511995, 53.92345803124564, 60.43948214394705, 56.384346689496724, 53.79810905456543, 57.57054315294538, 54.25097874232701, 56.682104791913716, 55.745049885341096, 49.74308129719326, 44.78834172657558, 48.22224221910749, 54.53832149505615, 59.567747252328054, 58.09598330089024, 53.45350967134748, 56.15631028584072, 57.58292831693377, 56.318918977464946, 56.05690240859985, 50.6339966910226, 49.22730956758772, 49.21390649250576, 48.704478468213765, 53.23231724330357, 58.044785499572754, 62.22345297677176, 62.67344611031668, 63.872510637555806, 65.59143243517194, 63.3095189503261, 64.92665658678327, 68.65993758610317, 68.60404627663749, 68.58199269430978, 70.95425360543388, 66.46705136980329, 66.12484564099992, 69.96254416874477, 73.35078457423619, 73.21843528747559, 68.54512555258614, 17.72804035459246, 0.15319252546344483, 48.910881655556814, 75.86437879289899, 69.43212563650948, 49.5535900252206, 43.355859415871755, 60.95487172263009, 39.90163891656058, 35.13025188446045, 46.14233718599592, 67.58177171434674, 9.81520858832768, 0.7277922640953745, 0.4684155764324324, 0.23408054932951927, 0.1840466662709202, 0.14380685266639504, 0.21014567437980855], [0.09672864100762776, 0.1730461208415883, 0.051426118173237355, 0.11255340757114546, 0.16640737493123325, 0.4347570368221828, 1.915956859077726, 19.805235590253556, 19.77187728881836, 17.396691186087473, 34.3252648626055, 31.392920085362025, 47.83565487180437, 61.16769504547119, 33.104032107761924, 59.578252928597585, 58.989782197134836, 59.87439904894148, 4.894343222890582, 0.8672787621617317, 1.6692029855081012, 37.671461718423025, 67.31391171046666, 66.63017422812325, 65.02373681749616, 57.5447792325701, 56.95507866995675, 54.96803978511265, 55.24802786963326, 54.360020296914236, 53.64961215427944, 51.35123838697161, 52.51516934803554, 51.31634105954851, 50.737038476126536, 48.29258925574166, 47.19296734673636, 44.68943759373256, 45.38749531337193, 44.974313735961914, 44.00279229027884, 45.9332936831883, 44.6800297328404, 46.17282935551235, 47.773795059749055, 46.41171884536743, 47.1869397844587, 45.958324568612234, 42.742604460035054, 42.487647260938374, 44.9122246333531, 43.48127440043858, 48.11970765250069, 52.003257342747276, 53.33594615118844, 53.13361808231899, 54.11293193272182, 52.716052191598074, 52.29359129496983, 49.77871860776629, 49.008913789476665, 47.04796539034162, 43.97049011502947, 42.71522160938808, 41.07616935457502, 41.02067061832973, 38.17585577283587, 39.18027693884713, 42.83903850827898, 43.43704216820853, 45.60052708217076, 48.00375264031546, 37.359967027391704, 36.71307584217617, 41.131567341940745, 43.88649334226336, 41.83459997177124, 40.12204967226301, 38.7304436138698, 39.49908460889544, 43.27577795301165, 40.444223744528635, 40.32783446993147, 37.27068962369646, 38.42544548852103, 40.78944846561977, 40.551583835056846, 40.30691344397408, 39.63667631149292, 43.26687731061663, 40.643227100372314, 38.562655040196006, 38.22698409216744, 39.287404264722554, 41.49189397266933, 39.52392094475882, 37.985186781202046, 41.50014843259539, 39.712845938546316, 39.85436337334769, 39.774285384586875, 39.498226506369456, 39.08479479381016, 40.56262104851859, 36.90998431614467, 48.922057832990376, 51.741532598223, 50.014648165021626, 45.589653151375906, 45.1672408921378, 42.92682899747576, 42.40632207053048, 44.60314791543143, 48.01659985951015, 48.50477681841169, 48.670675482068745, 50.18562248774937, 51.66001980645316, 54.80931166240147, 55.25235659735543, 50.791376863207134, 48.89846869877407, 51.50734009061541, 52.454424721854075, 46.69075502668108, 41.865286690848215, 40.52350269045149, 46.05285133634295, 50.765345437186106, 53.254857199532644, 55.71274076189314, 53.93016651698521, 54.414959703172954, 49.16182279586792, 46.60832507269723, 44.71460049492972, 44.47054154532296, 42.32948194231306, 46.1935384614127, 49.396244594029014, 55.3672902243478, 57.81941025597708, 61.013104575020925, 59.77411569867815, 60.621768133980886, 58.055652482169016, 57.64386401857649, 61.31567777906145, 66.74263777051652, 64.46631758553642, 66.53242697034563, 64.31648663112095, 61.324974468776155, 62.117451259068076, 70.25085966927665, 65.4654963357108, 45.24172905513218, 9.118460604122706, 0.08880540116557054, 40.65916974203927, 61.514417103358674, 52.69142777579171, 31.01938145501273, 32.87558576038906, 30.172958850860596, 17.479320900780813, 10.784305112702505, 18.994898455483572, 21.390361138752528, 2.975523271730968, 0.24578050151467323, 0.07696701426591192, 0.26371182075568605, 0.028983606358191798, 0.13142605844352925, 0.22925429259027752, 0.039698519078748565, 0.08029581885784864, 0.06377458359513964, 0.12546074496848242, 0.16603609413972922, 0.37854635449392454, 2.743799328804016, 33.322368826184956, 31.989937101091655, 21.344602039882115, 45.207908698490684, 43.16864367893764, 57.613118239811485, 67.34594985416958, 39.7693521635873, 69.57920510428292, 64.90319946834019, 67.2125027520316, 6.505653492041996, 0.5635443404316902, 2.6854407574449266, 43.08733238492693, 75.05810982840401, 72.37796728951591, 70.00223922729492, 63.32692418779646, 62.626413754054475, 60.10514177594866, 59.28196784428188, 58.42893055507115, 57.75959668840681, 54.82989570072719, 57.08517326627459, 54.4588097844805, 55.223792552948, 50.38730437414986, 50.30110502243042, 48.38022688456944, 49.3499869619097, 46.92464876174927, 47.20227445874895, 49.185245173318044, 46.850136280059814, 49.03564350945609, 50.33953550883702, 50.32871716363089, 48.50461006164551, 47.97304507664272, 45.954405784606934, 44.19600779669625, 47.926759651729036, 45.329071385519846, 49.725380761282786, 54.38140685217721, 56.08901350838797, 55.49145800726754, 55.399383953639436, 54.51395068849836, 55.48445769718715, 53.50499929700579, 49.87869276319231, 48.47719594410488, 47.56698887688773, 44.663687569754465, 46.32031529290335, 44.77527911322457, 43.20281144550869, 41.87204033987862, 44.35331153869629, 46.180569648742676, 49.49667733056204, 51.24132135936192, 40.98768057141985, 39.95766224179949, 42.91897405896868, 46.86010347093855, 42.65745081220354, 42.52212422234671, 42.20946570805141, 41.98021336964199, 45.972241810389924, 44.056845801217214, 40.95324182510376, 41.099025453839985, 41.712381158556255, 43.683595521109446, 42.47777039664132, 41.98432322910854, 41.585510526384624, 43.748158182416645, 42.9615387235369, 40.630098479134695, 42.16622359412057, 41.144077573503765, 41.73358358655657, 43.17185027258736, 41.32319865907942, 42.588903359004426, 41.01042202540806, 40.74454573222569, 41.96392331804548, 40.409468855176655, 39.07275703975132, 41.35286399296352, 39.532696519579204, 51.96155425480434, 52.7803612436567, 51.19953836713518, 47.78044448580061, 46.08963162558419, 43.96801308223179, 44.88295882088797, 47.130562101091655, 49.76601035254342, 51.29622255052839, 51.23718023300171, 51.8229272706168, 50.92747122900826, 53.90271071025303, 56.35570968900408, 53.7502498626709, 50.81787729263306, 53.15395198549543, 53.982847758701865, 49.111945152282715, 44.29828527995518, 41.527020590645925, 46.226163727896555, 53.63328388759068, 57.811162744249614, 56.542848995753694, 57.01198789051601, 56.66846547807966, 51.43360928126744, 50.5565972328186, 47.713040011269705, 46.97639547075544, 47.79868003300258, 48.259560993739534, 53.19927161080496, 58.44839940752302, 61.32056931086949, 64.38181359427315, 63.272700445992605, 63.34776183537075, 61.417614800589426, 61.005565779549734, 63.42287186213902, 69.26105403900146, 67.76487759181431, 70.48764038085938, 66.93005847930908, 65.84122017451695, 67.07094710213798, 73.86124093191964, 70.39525018419538, 50.279027121407644, 9.937017457825796, 0.06440250668674707, 47.18504640034267, 69.89746734074184, 62.237564768110005, 37.28539201191494, 37.06859084538051, 45.16153294699532, 20.248184987476893, 15.99462114061628, 36.925600392477854, 35.73296989713396, 5.396904255662646, 0.3757522558527333, 0.1779373540942158, 0.25450027361512184, 0.03355716987113867, 0.15493067433791502, 0.07010036879884345, 0.172705686252032, 0.23390133466039384, 0.0976311197238309, 0.2037907868091549, 0.1782478652894497, 0.525060059768813, 1.8565634403909956, 45.453437192099436, 47.8659212248666, 39.96721601486206, 63.85831546783447, 45.10143450328282, 64.74232782636369, 72.64019925253731, 48.19982385635376, 71.36115401131767, 68.98199353899274, 74.02308532169887, 7.483719706535339, 1.6078941438879286, 3.5801018817084174, 42.143892083849224, 75.59596988133022, 70.67415087563651, 69.88854585375104, 66.25465883527482, 64.10998616899762, 62.23154762813023, 61.862236976623535, 61.18334238869803, 60.490850176130024, 57.38516868863787, 58.79528822217669, 57.68224586759295, 57.11311197280884, 53.645415442330496, 51.61565555844988, 51.14530072893415, 52.90365007945469, 48.22935022626604, 49.86777714320591, 52.229556696755544, 49.40480824879238, 51.66202436174665, 53.23207058225359, 52.66231482369559, 51.662437779562815, 49.08487149647304, 47.37000397273472, 46.53309692655291, 51.30461597442627, 46.4872179712568, 53.51551192147391, 55.46770906448364, 58.43375955309187, 58.05672945295061, 60.2973358971732, 57.524539130074636, 59.40793868473598, 54.094925676073345, 54.30949994495937, 50.92273255756923, 49.31758403778076, 47.31988314219883, 49.69042437417166, 45.69485930034092, 45.50154651914324, 43.91840294429234, 47.95354495729719, 49.9225115776062, 51.384044306618826, 53.72483335222517, 43.25627783366612, 40.92367376599993, 45.04681471415928, 47.85502644947597, 47.06992864608765, 43.529960427965435, 44.53784874507359, 43.99535771778652, 48.04187740598406, 47.2963148525783, 44.65150737762451, 43.63610805783953, 43.95299455097744, 44.756564140319824, 44.99088518960135, 43.13757480893816, 43.32439449855259, 48.225553035736084, 46.83150121143886, 42.39406892231533, 42.791047300611226, 43.80332687922886, 46.32900401524135, 45.92079039982387, 42.68396513802664, 43.662327085222515, 43.92361756733486, 42.82078559058053, 44.176000458853586, 42.814403670174734, 42.55953679765974, 45.61415944780622, 42.229233333042686, 52.62336669649397, 55.68554203850882, 54.11434589113508, 49.319977692195344, 50.17284822463989, 47.729264054979595, 47.410696097782676, 49.646831376211985, 50.154345171792166, 55.8765549659729, 53.10173627308437, 53.80653027125767, 53.20642825535366, 59.080873080662315, 55.74889918736049, 54.0307799066816, 53.109507833208355, 54.20736142567226, 56.82328871318272, 50.26912593841553, 46.72746583393642, 43.75090619495937, 48.16653503690447, 54.93677636555263, 59.667391368321006, 59.44518797738211, 60.590640204293386, 57.20261866705758, 53.030781269073486, 52.01431540080479, 48.33234337397984, 47.81561279296875, 46.336970124925884, 49.665893759046284, 55.698434420994346, 58.856529644557405, 62.2073609488351, 64.69439220428467, 64.528733253479, 63.686048780168804, 61.497018814086914, 60.33257021222796, 63.38182885306222, 69.48646749768938, 69.3993787765503, 69.84127725873674, 68.5774485724313, 67.15832764761788, 69.24793584006173, 75.49251815250942, 70.42969935280937, 55.795532022203716, 13.159917661121913, 0.10225471840905291, 51.25885166440691, 74.86555440085274, 67.08530902862549, 48.58875274658203, 50.56493854522705, 57.31204584666661, 34.36229876109532, 35.71928194590977, 60.86697006225586, 58.00911692210606, 8.202721902302333, 0.39491707033344675, 0.25914359731333597, 0.21327211947313376, 0.26683853726301876, 0.1575410256960562, 0.3240098351878779], [0.07383362097399575, 0.10981378850660153, 0.14228621497750282, 0.069395343773067, 0.21482776956898825, 0.13094732484647206, 0.41995354688593317, 10.682763269969396, 15.103075197764806, 20.244368689400808, 13.837962831769671, 29.06217466081892, 32.635768686022075, 62.653400557381765, 32.838864530835835, 56.71241978236607, 61.46123559134347, 61.43140697479248, 10.024909564426967, 0.17305547105414526, 1.4181139788457324, 47.585853236062185, 69.43758692060197, 63.18736267089844, 63.86609050205776, 58.16594123840332, 56.72396421432495, 54.534361021859304, 53.786793913160054, 51.149400166102815, 52.90952825546265, 53.33670003073556, 50.732508250645225, 52.00598451069423, 52.99714503969465, 48.825387545994346, 47.57381895610264, 45.6242412839617, 45.41161945887974, 43.7545678956168, 44.840901374816895, 43.41075365883963, 42.953426701681956, 42.432492460523335, 45.25049073355538, 45.570625509534565, 46.19270120348249, 43.96744680404663, 42.67802790233067, 41.020302363804404, 42.13840995516096, 42.77097395488194, 51.9724247114999, 53.678933552333284, 53.60857956750052, 54.62455211366926, 56.827596596309114, 50.75020183835711, 47.70188120433262, 47.00222887311663, 47.95870399475098, 46.168674332754954, 44.15990148271833, 41.61927877153669, 41.42106403623308, 41.325185843876426, 38.54923459461757, 41.8075714792524, 42.01377316883632, 42.942003863198416, 47.39014332635062, 48.35887854439871, 38.812140532902305, 37.629744734082905, 41.73447643007551, 42.97840894971575, 39.13235868726458, 41.392055307115825, 40.021818433489116, 40.19322007043021, 43.015484537397114, 41.98340606689453, 37.434371812003, 38.44656801223755, 39.65561710085188, 40.32227938515799, 40.18693889890398, 41.32830558504377, 41.85279382978167, 44.18462664740426, 40.05345358167376, 41.812754835401265, 38.928790364946636, 41.077739647456575, 40.679378577641074, 41.33371475764683, 38.77782685416085, 40.0951566696167, 38.332857268197195, 39.19895369665963, 37.433089869362966, 37.95321117128645, 35.88008063180106, 36.32074580873762, 34.96306432996477, 47.0085517338344, 50.430706296648296, 48.35533843721662, 44.84390994480678, 42.34605687005179, 40.603653635297505, 43.2255528994969, 43.49690089906965, 42.61762721197945, 47.79284354618618, 46.82963214601789, 48.9320319720677, 47.61384405408587, 48.269177300589426, 50.800305298396516, 55.93300213132586, 52.08580889020647, 49.83914361681257, 52.48149490356445, 48.90318305151803, 43.14111839021955, 41.07458863939558, 43.331349645342144, 49.76315464292254, 53.72810247966221, 50.880310331072124, 55.60228524889265, 48.856247970036094, 45.76557806559971, 43.750694274902344, 43.29357576370239, 43.90234565734863, 45.0079082761492, 44.72811821528843, 50.20758921759469, 58.99916921343122, 60.25859274183001, 60.98765332358224, 63.029061862400596, 62.743595123291016, 61.2083420072283, 61.79329695020403, 61.709939411708284, 62.53523254394531, 67.27493231637138, 67.54919855935233, 67.30565725054059, 63.19121197291783, 63.406953539167134, 68.64276858738491, 67.47376891544887, 46.42821386882237, 5.75526237487793, 0.5003542197602135, 43.05731964111328, 65.49494280133928, 48.285425662994385, 35.59116758619036, 34.67718069893973, 33.0441004208156, 23.072872638702393, 13.246796199253627, 25.40967689241682, 4.783401770251138, 0.7941957094839641, 0.17734784287001404, 0.05018439230376056, 0.07530557377529995, 0.0253410929747458, 0.08185215427407197, 0.09636951277830771, 0.1529032252728939, 0.09387588979942457, 0.18559284401791437, 0.1260304701115404, 0.2075032690273864, 0.22308326086827687, 0.4841281133038657, 19.939471312931605, 25.250104563576834, 28.598194803510392, 21.725493601390294, 36.38348109381539, 46.70470700945173, 68.86841828482491, 38.955106667109895, 63.314924648829866, 70.54689461844308, 66.99456555502755, 11.587147746767316, 0.22837786961879047, 2.2075998953410556, 52.66880791527884, 76.12424836839948, 69.54276875087193, 72.57356602805001, 62.496371269226074, 62.85085446493966, 58.5531712940761, 59.333704130990164, 55.9341972214835, 58.650501659938264, 56.750145026615684, 56.77925797871181, 53.68796273640224, 56.241175583430696, 51.76317276273455, 50.7768794468471, 47.17119516645159, 47.81056145259312, 47.68340594427926, 47.29730497087751, 46.685397965567454, 46.537512506757466, 45.14737599236624, 47.072113854544504, 47.70507737568447, 51.397610664367676, 46.64234692709786, 45.507612296513145, 44.468738487788606, 44.83983135223389, 43.88187626429966, 53.985901491982595, 56.69296135221209, 55.54079021726336, 56.79242828914097, 56.35564715521676, 54.652862548828125, 51.05534587587629, 51.36819893973214, 50.638481753213064, 48.347671100071494, 48.57965408052717, 44.3127236366272, 44.305560043879915, 45.66317898886544, 41.672627040318076, 44.18214266640799, 43.175445965358186, 45.502863202776226, 50.27512918199812, 52.48216540472848, 46.51989534923008, 38.91346958705357, 42.29022809437343, 45.1175890650068, 40.85679735456194, 43.69830138342721, 41.35894366673061, 40.856269291469026, 43.150123255593435, 42.892737661089214, 39.76434946060181, 41.2247496332441, 41.448387827192036, 41.0382912499564, 40.409767627716064, 44.21659183502197, 44.30241250991821, 44.90009307861328, 41.68401166370937, 44.17349215916225, 43.60866962160383, 42.78485645566668, 41.19761691774641, 42.99326767240252, 39.80693844386509, 41.073299748556956, 39.87289074489048, 39.54687779290335, 38.94114078794207, 40.14110510689871, 36.583380767277305, 37.331875460488455, 36.838115624019075, 46.97110094342913, 55.43127271107265, 50.43788725989205, 44.301495347704204, 44.487439564296174, 42.25411830629621, 44.24829299109322, 45.48005921500069, 44.33574301855904, 48.90844283785139, 49.24416242327009, 51.01828418459211, 50.51954596383231, 50.58606801714216, 50.42861488887242, 55.35586738586426, 56.024704456329346, 52.262518950871055, 54.586215427943635, 51.64303493499756, 45.444936071123394, 44.206843512398855, 45.47285393306187, 52.405210631234304, 56.3693767956325, 53.73067331314087, 57.497774669102256, 52.94394963128226, 48.91460589000157, 46.839244978768484, 46.71665096282959, 45.71892091206142, 48.10483503341675, 48.786404677799766, 54.171880449567524, 61.095357349940706, 63.19237927028111, 64.7167306627546, 66.2663665499006, 67.6598903111049, 63.527442250932964, 63.81598009381975, 65.01084790910993, 65.68550409589494, 69.33194650922502, 71.43822343008858, 69.4198134286063, 66.56579221997941, 67.36866351536342, 72.71377372741699, 71.40979834965297, 56.683963435036794, 8.866829855101448, 0.4461388375077929, 49.74690628051758, 73.62919889177594, 55.395850794655935, 40.821163518088206, 37.34366307939802, 48.52100086212158, 24.94814280101231, 19.517140695026942, 44.55028254645211, 17.00291245324271, 1.4313412862164634, 0.2690473315971238, 0.09515863311077867, 0.0729243704783065, 0.04106149576338274, 0.19240992250187056, 0.08536053994404418, 0.2079439910926989, 0.3153259168778147, 0.36872415297797745, 0.19739769771695137, 0.31780856794544626, 0.34248710370489527, 0.5766548312136105, 26.982530185154506, 43.857463768550325, 43.61569425037929, 36.16251448222569, 44.05855505807059, 50.689068113054546, 75.45681830814907, 48.09414175578526, 67.15944630759103, 75.17340128762382, 73.90557043892997, 14.604607956750051, 0.5525183635098594, 2.6132122789110457, 54.71419082369123, 76.50338377271379, 70.7332592010498, 72.53102220807756, 64.03238868713379, 64.56761537279401, 59.99062851497105, 60.05195331573486, 57.29874699456351, 59.8800687789917, 59.83557946341378, 57.06366164343697, 56.71137407847813, 59.421445982796804, 54.32098184313093, 53.758146490369526, 48.98838881083897, 49.524661200387136, 49.780834334237234, 48.92550761359078, 49.55363866261074, 48.768947328839985, 46.28081130981445, 50.10583632332938, 50.16899197442191, 52.35580893925258, 49.27076360157558, 47.76226452418736, 45.77342258180891, 45.9274502481733, 46.53075190952846, 56.72547197341919, 56.90609734398978, 58.601572445460725, 59.925926889692036, 61.204777581351145, 56.986571380070274, 53.311050755637034, 53.87265975134713, 51.974873951503206, 50.387436389923096, 50.64244222640991, 47.24413735525948, 46.50991078785488, 48.17064837047032, 43.63065719604492, 46.788516180855886, 45.50983224596296, 49.34177419117519, 54.04746947969709, 57.07946532113211, 45.84477710723877, 39.13114275251116, 43.439519201006206, 46.277149609157014, 43.88396419797625, 47.80514185769217, 43.9338036264692, 43.8169071333749, 46.34622859954834, 44.66971860613142, 42.52433027539934, 44.55331890923636, 45.367248262677876, 45.17358112335205, 43.581165177481516, 46.07363339832851, 48.06649487359183, 48.275493213108604, 44.17626796449934, 47.577939237867085, 43.98041909081595, 45.976334299360005, 44.54589475904192, 47.07813099452427, 42.86764424187796, 45.63963154384068, 41.976367541721885, 41.821697166987825, 39.71286678314209, 43.458341870989116, 40.72691467830113, 41.38003839765276, 40.328973974500386, 48.646638189043315, 57.84357956477574, 51.64079066685268, 49.61311871664864, 45.633343424115864, 43.55188546861921, 47.585707323891775, 47.83722516468593, 46.62798500061035, 53.34989813395909, 51.08727632250105, 54.30784279959542, 53.6554799079895, 53.30337994439261, 55.41507298605782, 56.414470604487825, 56.75437995365688, 56.37089497702462, 56.068822043282644, 52.8095714705331, 47.46381507601057, 47.1528171811785, 48.69013391222273, 52.96623945236206, 57.914315700531006, 54.86100625991821, 59.94138663155692, 52.64106723240444, 49.80185958317348, 47.21546908787319, 48.754178932734895, 45.8624324798584, 49.895253794533865, 49.57859311785017, 55.252902030944824, 63.84425926208496, 63.388381004333496, 64.23545673915318, 66.2930267878941, 66.91394560677665, 65.54203074319022, 64.83407184055874, 65.04710360935756, 64.92464855739048, 69.00104549952916, 71.2874197278704, 72.36315373011998, 68.43557330540249, 68.93828936985561, 73.76117992401123, 74.34566238948277, 56.85963126591274, 9.677987745829991, 0.5329768806695938, 55.41065393175398, 79.04219995226178, 63.570062501089915, 52.43658522197178, 51.136149951389854, 56.33267641067505, 41.00840357371739, 38.518999508449006, 69.92368289402553, 33.92465605054583, 1.6110417864152362, 0.4115039131471089, 0.17182375357619353, 0.16719708112733705, 0.1745264942624739, 0.29141515706266674, 0.19741270691156387], [0.16804052729691776, 0.017998597684449384, 0.1477301014321191, 0.1051642494276166, 0.07548837110932384, 0.10406479878085, 0.07179056560354573, 3.392783224582672, 14.180998001779828, 20.894688810620988, 27.912357228142874, 26.977673394339426, 34.786930969783235, 58.788124629429404, 34.42034748622349, 53.13569559369768, 62.675419398716514, 66.56249182564872, 13.753353749002729, 0.19419182331434318, 3.4227049904210225, 55.04683583123343, 65.05542755126953, 64.31059455871582, 64.3957655770438, 60.2814245223999, 55.58484179633004, 54.45061091014317, 52.710333824157715, 52.280306339263916, 52.644972120012554, 51.64393820081438, 50.66652815682547, 49.98780032566616, 50.95029258728027, 49.89219658715384, 46.4582439831325, 45.42434161049979, 46.03944478716169, 45.877068860190256, 44.77831547600882, 44.69887672151838, 41.39620338167463, 41.90369633265904, 43.44395215170724, 41.73096758978707, 44.4350779397147, 42.071724619184224, 42.259041104997905, 42.03418002809797, 39.77515390941075, 43.014112268175396, 51.92016036169869, 56.372513907296316, 52.25749887738909, 53.001237528664724, 51.76854372024536, 49.036362648010254, 48.422277382441926, 48.2998640196664, 48.75096886498587, 47.54669666290283, 44.89139740807669, 44.14767960139683, 43.20000784737723, 40.132214886801584, 38.86400883538382, 39.344362122671946, 41.05663102013724, 43.7747037751334, 45.475310121263774, 49.15123374121529, 39.695892333984375, 41.766618796757285, 44.15230710165841, 39.783582074301584, 40.00543805531093, 39.282721178872244, 36.647668974740164, 39.50235373633248, 36.158283029283794, 37.398352350507466, 37.5399740082877, 41.09283460889544, 38.39864976065499, 40.56508765901838, 39.84171417781285, 40.882387569972444, 42.09010260445731, 43.2310072353908, 41.82088075365339, 40.01540524618966, 39.36978210721697, 39.59092589787075, 37.6547269821167, 40.653663294655935, 40.05973127910069, 38.002678871154785, 34.79816968100411, 38.27486760275704, 37.38353531701224, 39.05795737675258, 34.71285622460501, 32.53885521207537, 34.351671491350444, 46.27311270577567, 58.14818511690412, 47.45037725993565, 45.942159584590364, 41.529181480407715, 41.152679443359375, 40.19844511577061, 41.77620383671352, 44.9662503514971, 42.84983948298863, 42.484492778778076, 44.57034199578421, 46.77242067881993, 47.70458057948521, 49.6471266746521, 49.40174061911446, 51.60944734300886, 50.810724122183665, 52.34568541390555, 48.268489428928916, 41.54542636871338, 41.6235797064645, 41.64346545083182, 44.51871688025338, 50.26154892785208, 51.50170857565743, 52.97961820874895, 50.99128001076834, 45.91904987607683, 42.22071136747088, 43.60513646262032, 43.438334533146445, 44.50385120936802, 45.53429337910244, 51.946560042245046, 59.72726399557931, 58.54021290370396, 60.00453186035156, 62.08693477085659, 60.91165392739432, 61.589777265276226, 61.224406242370605, 63.883467946733745, 63.84390490395682, 60.70249925340925, 70.21950939723423, 68.41010815756661, 63.234978675842285, 61.28445952279227, 67.04297365461076, 63.794482367379324, 53.84600993565151, 9.719480650765554, 0.644444822200707, 45.42800331115723, 63.91012123652867, 52.01745251246861, 31.23011337007795, 37.4452839578901, 33.29891518184117, 18.279244422912598, 23.09894575391497, 16.1166957787105, 0.8414562163608414, 0.14554663002490997, 0.10694887795086418, 0.09790057955043656, 0.0997818178896393, 0.09329207148402929, 0.06478310376405716, 0.2010591405310801, 0.1722585316747427, 0.03041510490168418, 0.12124641825045858, 0.0334499715162175, 0.19042397263858998, 0.04905016673728824, 0.34326380917004173, 5.368522601468222, 20.256307431629725, 36.67230033874512, 28.29945179394313, 25.68052462169102, 41.848666599818635, 65.49336556025914, 40.49660273960659, 60.906282969883506, 68.37363011496407, 73.40302807944161, 16.417802912848337, 0.2779659687408379, 4.0207748753683905, 61.852467809404644, 71.1218511036464, 69.98507022857666, 68.31200654166085, 63.637849126543315, 62.388660294669016, 58.28967475891113, 57.28248126166207, 56.43490525654384, 57.935358319963726, 55.839865003313335, 55.777789797101704, 53.58910724094936, 55.053040572575156, 53.098988260541645, 49.37767205919538, 48.882550375802175, 48.58049481255667, 48.49611588886806, 47.937091623033794, 46.56631973811558, 45.63651180267334, 46.140992709568565, 46.141010080065044, 46.50017983572823, 48.021814482552664, 44.03312465122768, 45.95960998535156, 45.20653295516968, 42.60635723386492, 47.37151868002755, 54.407413959503174, 56.60837050846645, 54.640189034598215, 55.489912033081055, 53.94827699661255, 50.176537718091694, 52.72533845901489, 50.82660075596401, 49.36348383767264, 50.203017302921836, 48.45628881454468, 45.40741579873221, 47.73239769254412, 45.42237179619925, 43.85631036758423, 43.48424475533621, 43.051413672310964, 45.9642722266061, 49.034340722220286, 53.41597202845982, 46.01657479149954, 45.014317989349365, 44.964134625026155, 42.16255841936384, 44.01240512302944, 42.99564048222133, 37.295612812042236, 39.33816432952881, 39.37459373474121, 38.644650731767925, 40.858412810734336, 44.413472516196116, 43.28631142207554, 43.50076757158552, 41.41439723968506, 42.08978993552071, 45.06450482777187, 45.60600573675973, 42.07732139314924, 42.19223070144653, 41.113043444497244, 42.19231060573033, 38.69144684927804, 41.849396160670686, 40.639231886182515, 37.55744872774397, 38.123271805899485, 39.516969272068565, 39.42005232402256, 38.98817661830357, 36.43325798852103, 35.04864181791033, 36.858209814344136, 46.9117112159729, 57.02981001990182, 50.33891364506313, 46.794241496494834, 42.15827138083321, 43.2164021219526, 40.79829352242606, 43.14583274296352, 45.80588109152657, 46.75505713054112, 44.47169842038836, 46.763117040906636, 48.29872451509748, 48.67871107373919, 51.77311910901751, 50.20485510144915, 51.83782073429653, 55.09586232049124, 52.80504124505179, 51.77139942986624, 44.29750708171299, 43.630264622824534, 43.9389522416251, 48.4309834752764, 51.45901189531599, 55.06703771863665, 54.15984616960798, 53.57090990883963, 48.631400789533345, 45.88335697991507, 46.92253998347691, 46.48532806124006, 48.961210932050435, 47.329902444567, 57.59944765908377, 63.14080974033901, 63.05475630078997, 63.752946036202566, 65.82499613080705, 64.09592996324811, 63.416694913591655, 65.83932331630162, 66.65638978140694, 66.20535441807338, 64.8568480355399, 73.34734521593366, 70.15457153320312, 66.56683444976807, 66.12214279174805, 71.7901496887207, 68.11191231863839, 60.28377996172224, 11.767644575663976, 0.46323857137135094, 50.76546703066145, 69.10021713801792, 59.71638311658587, 35.1689498765128, 41.614025933401926, 43.55052709579468, 18.19576702799116, 34.46630981990269, 31.01558426448277, 4.461620705468314, 0.22972226462193898, 0.2313709690102509, 0.08279653252767664, 0.08332091117543833, 0.03461341480059283, 0.10220816412142344, 0.02276002718800945, 0.25158151452030453, 0.0927326532879046, 0.23720037192106247, 0.13412748277187347, 0.3045320532151631, 0.21301362477242947, 0.5400936816419873, 8.423705884388514, 37.528572014399934, 49.942536285945344, 50.50520140784127, 44.53572259630476, 49.098722730364116, 71.4514389038086, 49.66846806662423, 66.0152725492205, 73.04500130244664, 80.53327642168317, 18.241468804223196, 0.2727739544851439, 5.264566693987165, 63.12432166508266, 73.9325919832502, 69.38289764949253, 71.41439805712018, 64.74305738721574, 63.59568745749337, 61.96418789454869, 58.78669330051967, 57.831486225128174, 59.897265570504324, 57.795060294015066, 58.815035002572195, 55.21864741189139, 55.83000898361206, 55.47329889025007, 51.51078292301723, 50.541061060769216, 50.68741791588919, 50.64894921439034, 48.961502756391255, 48.94146415165493, 45.929830006190706, 45.9908629826137, 49.007173265729634, 46.42792204448155, 49.735900333949495, 46.756384236471995, 47.95958294187273, 47.17413078035627, 43.173781871795654, 48.44190951756069, 55.12910597664969, 61.286189624241416, 56.822538307734895, 58.224709102085654, 56.68148292813982, 53.72162675857544, 53.98429993220738, 53.36670582635062, 52.75019563947405, 53.589263575417654, 51.23561341421944, 47.50338159288679, 49.66075904028756, 46.863918031964985, 45.2701541355678, 46.956718172345845, 46.479627064296174, 49.19239486966814, 50.273736068180625, 55.191667556762695, 45.448076656886506, 46.45350531169346, 45.582468714032856, 44.232784611838206, 44.57412876401629, 44.2419319152832, 40.3284980228969, 42.69994946888515, 42.684816292354036, 41.45585366657802, 40.60039145605904, 47.177716050829204, 43.99663618632725, 45.51555756160191, 44.83653095790318, 46.193694795881, 49.04196637017386, 49.004720551627024, 47.281174727848594, 45.95282506942749, 45.88577842712402, 43.32137550626482, 40.79483331952776, 45.910948276519775, 42.96904625211443, 41.64821801866804, 38.98359775543213, 42.66160583496094, 41.871289934430806, 42.54109280450003, 40.09742873055594, 37.53632967812674, 40.771271978105815, 46.30295869282314, 57.24128539221627, 53.45090062277657, 49.96818208694458, 46.13218239375523, 46.23136098044259, 44.41661657605852, 45.51429993765694, 47.654035908835276, 48.52180685315813, 46.78584112439837, 50.13733945574079, 51.37741572516305, 51.7876547404698, 53.961419514247346, 54.00169127328055, 54.61478989464896, 56.317908014569966, 55.647823742457796, 53.50434964043753, 44.656732422964915, 45.347206183842246, 46.7403929574149, 50.00442736489432, 53.10348374502999, 55.511006764003206, 55.655018602098735, 55.25302015032087, 49.957672936575754, 46.07861525671822, 46.796617780412944, 47.52954503468105, 48.92999962397984, 49.042897428785054, 57.31037480490548, 63.43772711072649, 62.780656814575195, 63.43389170510428, 64.98586913517543, 67.1503997530256, 66.35276739937919, 65.70674473898751, 69.91405963897705, 66.62139865330288, 66.10284764426095, 74.26441015516008, 71.04451765332902, 68.86248452322823, 67.61644322531563, 72.8491176877703, 70.38893427167619, 63.29682459150042, 12.779522027288165, 0.4273413818861757, 57.28115068163191, 72.97503294263566, 66.57983452933175, 43.96452856063843, 53.80862167903355, 47.7490108353751, 32.98386301313128, 56.128910064697266, 60.771585191999165, 8.354897005217415, 0.3042815923690796, 0.31047023886016434, 0.2077505136174815, 0.1417339417551245, 0.17391636914440564, 0.09906415175646544, 0.14348210580646992], [0.2282145055277007, 0.047857593944562335, 0.16921173302190645, 0.0304461207373866, 0.06290799259607281, 0.09539262591195957, 0.06802205674882446, 0.23833507246204785, 8.331073369298663, 21.018010650362285, 42.93245356423514, 43.28823607308524, 33.02733094351632, 60.58790956224714, 41.97306367329189, 55.48578132901873, 64.15551771436418, 66.04287079402378, 15.731074231011526, 0.46111296543053215, 4.79081506388528, 59.261706897190635, 67.69268580845424, 63.920710291181294, 64.0121624810355, 59.809586252485005, 57.41268008095877, 54.63005856105259, 53.22889872959682, 51.0691727910723, 53.45742845535278, 49.46089063371931, 49.58851861953735, 50.49583871023995, 50.52278382437569, 51.16550261633736, 47.7334121295384, 44.876087052481516, 46.20189367021833, 47.34014408929007, 44.14960077830723, 42.57705668040684, 43.23998778206961, 39.8723418372018, 41.52030863080706, 41.20947749274117, 42.66322823933193, 40.385355131966726, 38.456090518406455, 40.48679535729544, 40.98398412976946, 40.99070303780692, 52.564984457833425, 53.66794845036098, 54.29527350834438, 54.82861723218645, 54.4513578414917, 48.71595341818673, 48.22307252883911, 46.61002738135201, 47.21448591777256, 46.66012041909354, 46.81373814174107, 45.67545298167637, 45.12960597446987, 40.27611207962036, 40.337221486227854, 38.82583543232509, 41.76842532839094, 44.405325753348215, 47.82522562571934, 44.550581318991526, 40.2937605040414, 47.51672213418143, 40.13451821463448, 39.318077087402344, 37.05389540536063, 38.879312242780415, 38.461322511945454, 38.85900960649763, 34.77822487694876, 35.89816331863403, 36.29545089176723, 40.80196564538138, 41.04519081115723, 40.942458220890586, 41.67696966443743, 44.383046354566304, 45.11639744894845, 46.114068440028596, 40.606012548719136, 39.17923123495919, 36.55439983095442, 41.701792103903635, 41.07666615077427, 41.902640206473215, 40.45915542330061, 37.88102633612496, 38.57950094767979, 35.79329068320138, 36.29530497959682, 37.7841580254691, 38.828896113804404, 34.81000941140311, 34.629140853881836, 52.58708667755127, 55.17276498249599, 48.80281979697091, 44.86954184940883, 38.958382742745535, 41.17806468691145, 42.50459391730172, 42.328338963644846, 44.39618539810181, 43.44998666218349, 44.944926330021445, 45.60947636195591, 47.745154585157124, 45.68450995853969, 46.1342043195452, 47.32302720206124, 49.46591418130057, 52.71435335704258, 50.23779651096889, 47.284419536590576, 42.046711104256765, 42.46667759759085, 40.66961983272007, 45.34028230394636, 46.81960589545113, 48.57510648454939, 50.65717588152204, 49.017866543361116, 42.31051336015974, 42.97786004202706, 40.49983712605068, 43.338513238089426, 44.16371604374477, 44.35673352650234, 52.658573218754356, 59.86190618787493, 60.992704663957866, 61.606911523001536, 59.78736591339111, 59.051204272678916, 59.09951509748186, 61.75401183537075, 61.06452819279262, 64.3441196169172, 66.10347993033272, 61.52712535858154, 70.63789517538888, 65.19582285199846, 63.06032875605992, 67.27172919682094, 62.668297495160786, 53.70811946051461, 11.61047111238752, 0.9494726402418954, 41.569717270987375, 66.0304057257516, 39.292712688446045, 31.726527418409074, 37.51629454748971, 29.873359475816997, 18.459670032773698, 22.523419516427175, 7.149355454104287, 0.470976964703628, 0.14773149921425752, 0.1237645431288651, 0.013436788942531815, 0.09498785941728524, 0.02085908079919006, 0.007766909614604498, 0.0887266911034073, 0.037928017654589245, 0.08555404456066233, 0.08634583385927336, 0.01366418892783778, 0.14275909960269928, 0.03121214945401464, 0.31135719269514084, 0.16768546349235944, 16.824517454419816, 35.217260701315745, 45.989813804626465, 45.148529393332346, 41.64603975840977, 68.99484770638603, 48.955575942993164, 61.14309842245919, 71.77060440608433, 73.98333467755998, 17.681320667266846, 0.5946159788540432, 6.366819364683969, 64.18335219791958, 70.50501782553536, 69.96619197300502, 68.5524628502982, 63.98760059901646, 61.95820549556187, 57.65688841683524, 57.51494714191982, 54.98336056300572, 57.69534322193691, 54.18691635131836, 53.84313685553414, 53.60999352591378, 53.272050516945974, 54.04405444008963, 52.162114007132395, 46.690209593091694, 47.72167314801897, 48.8132073538644, 47.36952107293265, 45.50831753867013, 46.35524388722011, 46.02995007378714, 43.68829597745623, 43.24765511921474, 44.64134216308594, 44.631461824689595, 41.85220670700073, 42.505167143685476, 42.60190691266741, 43.51604666028704, 55.00649806431362, 53.886875765664236, 55.39683396475655, 56.02748720986502, 54.181785106658936, 49.92826816013881, 50.3906603540693, 48.056597164699006, 50.80867092950003, 50.59478800637381, 51.25348765509469, 49.28348227909633, 49.37210307802473, 43.335115568978445, 44.1933570589338, 42.367551122392925, 45.926237787519185, 46.4786091532026, 53.55196564538138, 43.231139251164024, 55.19960239955357, 49.70413664409092, 37.66996438162667, 44.03892639705113, 38.46148232051304, 42.933839729854036, 40.290943009512766, 39.41223560060774, 35.71058280127389, 39.284437383924214, 38.35082183565412, 43.8743166242327, 42.666928155081614, 44.115902015141074, 42.716406277247835, 46.04686198915754, 48.18147366387503, 48.28343152999878, 41.456402574266704, 40.35184744426182, 39.51034763881138, 43.3974860736302, 42.22121511186872, 41.74448878424508, 39.8708792413984, 38.053004673549104, 39.34744017464774, 38.88842827933175, 40.4189635685512, 38.94951336724417, 38.78510856628418, 37.961090428488596, 35.95495441981724, 51.508358001708984, 58.71617603302002, 49.488728591373985, 47.01934576034546, 40.43322474615914, 42.87779208592006, 41.93107918330601, 43.48633616311209, 44.671636308942524, 47.36855179922921, 46.14835432597569, 49.24141093662807, 48.40872492109026, 48.0958058493478, 46.811222893851145, 48.786720820835654, 52.906345980507986, 53.93232045854841, 52.08703177315848, 49.14874281202044, 44.65979310444423, 44.85832745688302, 42.99080801010132, 47.71384947640555, 50.663161754608154, 51.82269103186471, 55.134615898132324, 50.83561951773507, 45.237845012119834, 45.62037808554513, 45.98338324683053, 48.04534455708095, 49.472223145621165, 46.34819841384888, 54.682454926627024, 63.458238192967, 63.655212674822124, 63.24588734763009, 63.337263107299805, 64.10182203565324, 63.02193301064627, 64.09791714804513, 64.17609133039201, 67.64930820465088, 66.76806817735944, 65.4140796661377, 72.40758051191057, 67.97089862823486, 65.36863844735282, 69.14918804168701, 67.14525808606828, 59.27973747253418, 13.398429342678615, 0.5971886036651475, 46.81369992664882, 73.25785936628068, 46.155323369162424, 32.43617820739746, 46.664605481284006, 38.75466503415789, 19.749676057270594, 42.99919448580061, 11.774011731147766, 1.1178753695317676, 0.11944748620901789, 0.10998832806944847, 0.09699238078402621, 0.05861736461520195, 0.05442276630284531, 0.18627650876130375, 0.04421441390046051, 0.17643685532467707, 0.18930400987820967, 0.21324524948639528, 0.1276384081159319, 0.16553059912153653, 0.22585424860673292, 0.4024735619979245, 0.9493167400360107, 33.19333383015224, 50.73616647720337, 61.29930087498256, 62.05693244934082, 45.248298576899934, 74.53354167938232, 57.246753624507356, 67.16019671303886, 75.5457205091204, 79.39712088448661, 19.410221815109253, 0.7552695125341415, 7.898487210273743, 68.62512711116246, 72.84893008640834, 71.45175157274518, 70.36773531777519, 65.3904696873256, 63.22916303362165, 60.9709290095738, 58.69141960144043, 55.806454590388704, 59.615689822605674, 54.250103269304546, 55.74319819041661, 55.253374508449006, 54.60406187602452, 58.045205865587505, 54.262054170881, 48.3422132900783, 50.112774099622456, 50.15273666381836, 48.43405110495431, 47.03854363305228, 48.14479412351336, 45.11562967300415, 46.578996726444785, 44.072496618543354, 47.8462404523577, 47.473209040505544, 41.727875641414094, 45.53517927442278, 45.58213867459978, 45.26589488983154, 55.9880805015564, 55.663714272635325, 57.01149109431675, 58.78934751238142, 57.3183548109872, 53.825898374829976, 52.81070402690342, 51.481954847063335, 52.95054347174508, 52.19535418919155, 54.10965238298689, 53.26950052806309, 51.644928319113596, 44.19930819102696, 46.77809388296944, 44.5426082611084, 48.24273245675223, 49.596863406045095, 56.040257998875205, 47.64050776617867, 52.4552515574864, 49.33528804779053, 40.20107153483799, 47.69763238089425, 40.72913462775094, 44.95259019306728, 44.161214692252024, 43.509869711739675, 38.89965656825474, 40.925584520612446, 39.961577551705496, 45.65927062715803, 44.92488772528512, 46.443673610687256, 45.8323016166687, 50.403806345803396, 51.04146684919085, 52.54389667510986, 44.813685280936106, 43.76693916320801, 44.13677440370832, 47.43925666809082, 45.04239565985543, 44.28393030166626, 43.94107491629464, 41.63949108123779, 42.411432470594136, 42.067041533333914, 41.11439486912319, 42.59202310017177, 41.511258602142334, 39.16191632407052, 39.614369119916645, 49.264301776885986, 54.51690367289952, 53.175348963056294, 49.52726330075945, 41.842732838221956, 44.753427028656006, 46.62977416174752, 45.803303309849326, 47.8196496963501, 49.35328388214111, 47.02002320970808, 51.56220306668963, 52.04221936634609, 48.874000617435996, 48.03726380211966, 51.732472147260395, 54.694572584969656, 56.37091929571969, 53.74800212042672, 52.183618681771414, 47.20240647452218, 48.09668132237026, 45.44732625143868, 49.76030935559954, 50.70526783806937, 53.0535192489624, 56.379059110369, 52.503767354147776, 46.40051140104021, 47.66936363492693, 47.19005952562605, 48.494274616241455, 49.64018889835903, 46.561883313315256, 55.79044941493443, 65.28805324009487, 64.55644266945976, 64.7088097163609, 64.65020860944475, 65.50449657440186, 64.54934855869838, 66.3748835154942, 65.7624067578997, 67.33805670057023, 69.55655397687639, 66.66663142613002, 73.60199669429234, 68.9623440333775, 66.94806821005685, 72.72677380698067, 68.49570996420724, 63.48555156162807, 15.29306674003601, 0.9551506212779454, 52.625989641462056, 80.04018361227853, 53.71031161717006, 43.951087270464214, 56.00656270980835, 46.61777114868164, 38.469007219587056, 64.77617944989885, 34.39082111631121, 2.0232383481093814, 0.24234312453440257, 0.19035465350108488, 0.2006611390305417, 0.190225962549448, 0.10362214289073433, 0.24540790436523302, 0.10866728824164186], [0.17283235516931328, 0.07812196229185377, 0.11511938273906708, 0.1008852311809148, 0.09492981074643986, 0.1290049369313887, 0.07586102932691574, 0.16535808837839536, 5.620397840227399, 28.924299819128855, 43.50807012830462, 26.98629263469151, 28.591481106621877, 54.97717319216047, 43.65740081242153, 49.74993222100394, 62.694825717381065, 67.53760201590401, 16.453771999904088, 0.3273583512221064, 5.2412702526365, 60.762212072099956, 60.82044492449079, 63.59875856127058, 63.50954369136265, 61.78802326747349, 56.54896688461304, 56.31437138148716, 53.66972024100167, 52.94713538033621, 50.835008076259065, 51.376404762268066, 48.64400829587664, 48.124564443315776, 49.31744507380894, 48.846318994249614, 49.857229777744834, 44.679404394967214, 44.21061985833304, 44.968133313315256, 44.224561418805806, 43.990372385297505, 43.195126737867085, 43.30160093307495, 40.140764645167756, 40.37612445013863, 40.97819628034319, 39.47181292942592, 41.01908295495169, 40.63336065837315, 41.709567138126914, 43.598219530923025, 50.441073008946006, 53.927734647478374, 53.66274772371565, 51.790010179792134, 50.79021303994315, 50.255059310368125, 44.26358250209263, 45.263313634055, 46.50423410960606, 47.317423479897634, 47.64850514275687, 46.179075786045615, 46.37189871924264, 43.47544486182076, 40.181623526981895, 40.78011008671352, 44.10699789864676, 45.90005350112915, 46.13753250667027, 43.9757707459586, 39.019464356558665, 36.04582296098982, 35.97346094676426, 38.466783796037944, 37.10151488440377, 36.39912496294294, 38.306249141693115, 38.96785661152431, 36.74832057952881, 36.464041982378276, 37.76372684751238, 39.58462735584804, 39.93595606940133, 40.767874308994834, 41.28586251395089, 44.393044812338694, 43.58846773420061, 43.91862876074654, 42.068886280059814, 40.728884492601665, 39.42137942995344, 38.60717214856829, 41.33365222385952, 42.74704783303397, 40.04662002835955, 38.64164216177804, 35.97754648753575, 36.47235550199236, 36.407379422869, 38.58619553702218, 38.649163586752756, 36.81583969933646, 36.261974470955984, 57.09036704472133, 56.38419035502842, 44.912047454289024, 45.69943816321236, 41.15671634674072, 41.63836547306606, 42.10783788136074, 42.70333671569824, 45.74719313212803, 45.45986080169678, 47.23963492257254, 46.62392725263323, 45.553911617824006, 47.02440057482038, 46.80284684044974, 45.564681325639995, 47.80499594552176, 47.400044509342735, 46.986164637974326, 45.99494504928589, 40.57752840859549, 41.45176812580654, 39.29070118495396, 44.43663433619908, 47.44555868421282, 50.32226228713989, 46.819317545209614, 46.537366594587056, 43.93905299050467, 42.21053573063442, 42.45024858202253, 43.86754560470581, 42.74553312574114, 44.84377792903355, 49.71982567650931, 60.63698468889509, 59.7025214603969, 59.39516789572579, 57.93733508246285, 56.03636005946568, 54.76066732406616, 57.32991313934326, 59.38804599217006, 63.03258459908621, 65.90210029057094, 64.94306823185512, 65.42091669355119, 66.75575596945626, 63.11864498683384, 66.49353095463344, 65.5355133329119, 55.626426764896934, 12.776495218276978, 0.6226303013307708, 45.087968894413535, 63.06460189819336, 33.74818570273263, 34.549827166966026, 40.38961785180228, 36.06200531550816, 26.242145776748657, 27.653119938714163, 3.1517245939799716, 0.34069482130663736, 0.0765163041651249, 0.16663644835352898, 0.040576991225991926, 0.06954183948359319, 0.10412930031972271, 0.12963543167071684, 0.16738287758614334, 0.1257764266005584, 0.057889907221708975, 0.057210225478879044, 0.1137837136962584, 0.06588752807251044, 0.1755973310875041, 0.10295033215412072, 0.27747115386383875, 11.107678617749896, 42.14118576049805, 50.99501814161028, 21.70326805114746, 36.33534744807652, 62.54137475149972, 49.644138949257986, 58.56112698146275, 68.90464619227818, 74.35034547533307, 18.147471836635045, 0.5320030472108296, 5.715762734413147, 65.7411800112043, 66.86323070526123, 70.16217286246163, 67.87445763179234, 65.46493353162492, 60.64459296635219, 59.333697182791575, 57.82434000287737, 56.919559478759766, 54.08566720145089, 54.84047085898263, 53.09260286603655, 52.29080854143415, 54.395855631147114, 54.250349930354524, 52.855443477630615, 47.730876037052695, 48.17553295407976, 47.7971271106175, 47.31374093464443, 47.37519080298287, 46.36776801518032, 47.093045302799766, 43.71020017351423, 42.646535192217144, 43.863769258771626, 43.545232568468364, 44.94487074443272, 42.23576463971819, 43.42863137381417, 46.028341565813335, 54.254477160317556, 55.50451019832066, 54.24032020568848, 53.781888484954834, 54.289273738861084, 51.1579464503697, 45.836995124816895, 49.1370073046003, 49.69261653082711, 49.00855595724923, 49.16025250298636, 50.97407627105713, 49.426768030439106, 46.123879296439036, 45.43026842389788, 44.07326092038836, 46.30544267381941, 49.426198278154644, 48.69448348454067, 45.158236026763916, 48.89542538779122, 47.68632766178676, 38.068502630506245, 41.111914362226216, 40.61120285306658, 39.37323536191668, 41.603881563459126, 39.50067227227347, 38.167149680001394, 38.05705894742693, 39.300928933279856, 42.472434180123464, 43.93424136298043, 41.83206040518624, 40.497106484004426, 46.31453439167568, 45.88591044289725, 45.720081261226106, 43.26308706828526, 45.108823912484304, 42.364063126700266, 40.21685784203665, 42.7274990762983, 42.24070828301566, 38.56388487134661, 38.70022242409842, 38.372482844761436, 40.478471415383474, 37.80173349380493, 38.73953880582537, 39.65996319907052, 36.957020146506174, 36.44254425593785, 55.622792857033865, 61.636872155325754, 49.356070109776084, 46.98395511082241, 45.32452031544277, 44.26864079066685, 41.24978051866804, 43.86608648300171, 46.01822846276419, 49.251576151166645, 50.189701080322266, 47.49340050561087, 48.85212421417236, 50.19272354670933, 48.04751239504133, 48.401019368852886, 49.97451536996024, 48.50977257319859, 49.19064392362322, 48.90292944226946, 44.463259833199636, 44.02640226909092, 41.824785641261506, 46.03064489364624, 50.379529339926584, 52.540064743586946, 52.80313049043928, 48.67753682817732, 47.67927176611764, 45.24178464072091, 47.24702433177403, 47.00213507243565, 48.15351063864571, 48.35311848776681, 53.22930867331368, 61.06795365469796, 62.4373254776001, 63.91391495295933, 61.286446707589285, 58.710589681352886, 58.69515773228237, 59.98403467450823, 62.299063273838584, 65.45375388009208, 67.27423054831368, 66.74943310873849, 69.4723209653582, 69.95310156685966, 66.76075172424316, 70.44571495056152, 68.66373825073242, 60.90396921975272, 14.488123144422259, 0.35626435013754026, 49.78114700317383, 68.39270292009626, 40.40156875337873, 35.37081241607666, 51.020379066467285, 43.48427949632917, 29.861509323120117, 51.89672408785139, 3.7828963484082903, 0.4589031668645995, 0.10416920496416943, 0.18924059399536677, 0.04122641709234033, 0.13483469268040998, 0.0791751572063991, 0.05533964013946908, 0.09011830535850354, 0.18324838339218072, 0.16767862385937146, 0.3061026175107275, 0.24963846164090292, 0.21235833636351995, 0.2919142059981823, 0.24198100396565028, 0.5182430084262575, 21.18697346959795, 60.89301191057478, 58.78357355935233, 38.52581916536604, 39.23197848456246, 70.36230877467564, 56.03610297611782, 64.09918866838727, 71.80278151375907, 78.04959419795445, 20.903363636561803, 0.6026590072682926, 7.6655566692352295, 69.43793433053153, 67.29721518925258, 70.07433373587472, 68.73221969604492, 69.03179822649274, 63.593165261404856, 61.79750061035156, 59.14208671024868, 59.431069237845286, 56.88099697657994, 56.8258387020656, 55.18756464549473, 53.49915933609009, 56.3825227873666, 53.97282498223441, 55.79266936438424, 49.33735166277204, 48.09834541593279, 49.05366366250174, 48.912931374141145, 47.78203909737723, 47.87448835372925, 48.27295364652361, 45.67621728352138, 47.55826888765608, 46.16390092032296, 44.931686537606375, 45.25205060413906, 45.51207651410784, 47.588972977229524, 49.13068444388253, 56.11158125741141, 58.717475346156526, 57.59394815989903, 56.91031837463379, 58.02477468763079, 55.12422834123884, 47.24980708530971, 52.82651117869786, 52.34329523359026, 54.37421894073486, 53.86928987503052, 53.19744076047625, 52.119194984436035, 46.760678223201204, 46.58195318494524, 45.35593312127249, 50.89371688025338, 53.53148930413382, 51.8631260735648, 50.51302855355399, 45.01450906481062, 40.05790737697056, 42.08323778424944, 43.586213043757844, 41.68055146081107, 40.99042510986328, 44.15053531101772, 42.436796869550435, 40.56905855451311, 40.89404664720808, 41.65366888046265, 45.99827323641096, 45.71197271347046, 44.35716084071568, 43.84210130146572, 50.35547815050398, 49.06665679386684, 49.43832983289446, 45.84609726497105, 47.55882821764265, 45.49521323612758, 43.10867725099836, 45.395492689950125, 44.436752455575125, 43.60118988582066, 41.395109040396555, 40.4498587335859, 41.76249851499285, 38.89095394951956, 42.19058050428118, 44.25043651035854, 41.754341329847065, 39.55468756811959, 52.26573944091797, 62.55233900887625, 51.43189655031477, 50.712136132376536, 47.07309355054583, 45.79998207092285, 46.4901396887643, 46.74372114453997, 49.16682897295271, 50.245498589106965, 52.947250025612966, 50.54072059903826, 51.493815422058105, 51.18747629438128, 49.638900007520405, 50.832513672964915, 52.727527141571045, 51.589471272059846, 51.23978580747332, 50.682918957301546, 45.34521899904524, 46.64400059836251, 42.97028650556292, 48.7701667376927, 51.96073089327131, 55.08525242124285, 52.312410490853445, 50.84952286311558, 50.190017223358154, 48.405469690050396, 47.07946157455444, 49.31046213422503, 49.38193825313023, 50.13718659537179, 55.415409973689485, 65.40642275129045, 61.99692780630929, 64.04348496028355, 62.778350012642996, 59.781209809439524, 59.394021442958284, 62.85068770817348, 64.71158899579729, 67.32172843388149, 67.92153862544468, 68.10876478467668, 72.04299463544572, 71.04640061514718, 67.73950277056012, 74.11794907706124, 71.67398275647844, 66.18516990116665, 15.698478494371686, 0.7191863230296544, 56.51737689971924, 74.35168647766113, 47.03234931400844, 47.21103613717215, 60.117606844220845, 52.01659440994263, 46.940382957458496, 72.25278854370117, 13.211294378553118, 0.7240196636744908, 0.34556328292403904, 0.2909983465714114, 0.10702252614178828, 0.1401667429932526, 0.15444900946957724, 0.23934652390224592, 0.1966102442571095], [0.16388462244399957, 0.043066970471824916, 0.17318154286061013, 0.0984790985073362, 0.035588931026203294, 0.18502493734870637, 0.07245518386896167, 0.2645320881690298, 0.8331117555499077, 24.317029237747192, 43.074499062129426, 40.34966918400356, 21.80145651953561, 50.329158374241416, 51.87948908124651, 38.951858384268625, 60.84943975721087, 70.47405665261405, 21.574802807399205, 0.521743217749255, 6.457578905991145, 61.5001038142613, 63.87588051387242, 64.9711389541626, 65.68995789119175, 62.599496432713096, 59.4263653073992, 57.30797072819301, 54.51510756356375, 52.89744186401367, 52.575590882982524, 50.56970500946045, 49.493429047720774, 49.427494117191856, 50.290724413735525, 47.70355224609375, 47.95189823423113, 44.25724574497768, 44.16741943359375, 45.79933588845389, 45.335561003003804, 43.884443623679026, 42.95332942690168, 42.494602407727925, 40.5063510622297, 38.48696483884539, 38.76776238850185, 39.97755493436541, 40.81842245374407, 40.88823447908674, 41.74654197692871, 43.511568546295166, 48.31847129549299, 52.16416719981602, 53.54079989024571, 52.8005770274571, 53.052216461726594, 49.60305772508894, 44.53539603097098, 44.07444211414882, 46.75447000776018, 49.21672746113369, 46.853815351213726, 46.47298458644322, 47.48356185640608, 43.98632158551897, 42.188141686575754, 43.72953701019287, 42.467754568372456, 47.28341899599348, 43.7554155758449, 43.64056185313633, 29.71344668524606, 34.95616476876395, 43.22664724077497, 33.42742906297956, 39.80083792550223, 35.15961844580514, 37.37170253481184, 40.27971124649048, 36.32786076409476, 36.33394043786185, 37.70811694008963, 37.707390853336875, 36.85683754512242, 37.88265568869454, 38.71641172681536, 38.92327002116612, 42.502610206604004, 41.797308989933555, 43.216443811144146, 38.086894512176514, 40.69643987928118, 39.6678980418614, 39.341318811689106, 42.34179762431553, 36.91136700766427, 35.569906098502024, 37.44855308532715, 37.162155287606375, 36.845619678497314, 36.03140892301287, 38.592323848179404, 30.910197462354386, 39.02022865840367, 63.91674286978585, 52.777641023908345, 44.442026138305664, 43.577774456569124, 42.11680105754307, 40.61082417624337, 42.4335173198155, 42.62630551201956, 46.8263977595738, 47.135929584503174, 47.970939772469656, 47.75494112287249, 46.18997056143624, 46.31093175070626, 47.03855752944946, 47.143920012882774, 44.85632637568882, 44.204543658665244, 43.694347858428955, 42.9056613104684, 40.037330286843435, 40.247085980006624, 40.44534240450178, 40.764907428196494, 43.654343605041504, 45.2108199937003, 44.56857715334211, 44.69422837666103, 40.21241099493844, 42.877295289720806, 43.55355303628104, 43.46487317766462, 44.63179186412266, 45.221975326538086, 49.5335236276899, 52.54396268299648, 57.21280125209263, 56.93673195157732, 51.33150897707258, 53.351697717394146, 50.38598769051688, 53.71912540708269, 58.3308219909668, 63.98158345903669, 64.12418828691754, 65.08085795811245, 67.99265343802315, 66.177672794887, 65.03035150255475, 66.15565395355225, 67.99528680528913, 60.23724092755999, 12.001430613654, 0.5020325896995408, 45.772491523197715, 63.07404450007847, 34.10496527808053, 36.705387660435264, 35.950834138052805, 32.153824261256624, 30.50326231547764, 35.60696431568691, 1.2641841300896235, 0.10823506143476282, 0.06620052949126277, 0.02095667109824717, 0.07589981438858168, 0.05609908367374113, 0.15154988717819962, 0.07659384714705603, 0.0682973519765905, 0.15682385489344597, 0.03701455345643418, 0.10822024901530572, 0.03968973544293216, 0.058346622357411046, 0.17570453962045057, 0.07946961426309176, 0.1754836764718805, 1.5603459924459457, 37.22004420416695, 57.827636923108784, 27.95518592425755, 24.614254065922328, 68.75876181466239, 53.460774012974326, 48.27656670979091, 66.37377180371965, 76.88292217254639, 24.34334553991045, 0.6385839624064309, 7.4147093296051025, 64.59073202950614, 66.91288253239223, 70.48998192378453, 69.32524149758476, 69.14610998971122, 63.71290356772286, 61.82094383239746, 58.07680974687849, 57.318219321114675, 56.28618253980364, 55.3420786857605, 54.43481765474592, 54.44402401787894, 53.42904853820801, 51.63318238939558, 50.88217939649309, 47.01774420057024, 47.624742303575786, 48.426814556121826, 48.016884735652376, 46.839040006910054, 46.633647782461985, 47.71372093473162, 42.939276695251465, 40.15053728648594, 42.64276926858084, 42.303537368774414, 44.38603407996041, 41.60779687336513, 43.709533146449495, 44.903970173427034, 51.09094844545637, 54.14451149531773, 56.30386223111834, 55.93242195674351, 52.73792164666312, 51.6901923588344, 47.35570805413382, 47.49203518458775, 49.27843441282, 50.851857457842144, 51.557572092328755, 51.384582792009624, 51.71387529373169, 47.202541964394705, 48.143779686519075, 48.55957726069859, 47.75576448440552, 52.18774243763515, 48.756485734667095, 45.032154015132356, 33.25103514535086, 50.80196591785976, 48.38207163129534, 37.76405341284615, 42.24940047945295, 38.23968192509243, 39.10234941755022, 42.211449418749126, 38.47126538412911, 37.824117115565706, 39.62758806773594, 39.078305176326204, 38.94831827708653, 39.852275439671104, 40.67912496839251, 42.40810080936977, 43.513069357190815, 44.27441126959664, 46.20810188565935, 40.67525829587664, 41.50711400168282, 41.476031235286165, 40.94677652631487, 42.06573179789952, 38.39634990692139, 37.20584208624703, 39.88018635341099, 37.659319741385325, 39.04818820953369, 38.105838775634766, 39.302342891693115, 33.77032961164202, 39.62947450365339, 64.03434113093785, 57.400763920375276, 48.67968034744263, 46.67894308907645, 46.5092785017831, 41.59483848299299, 43.14726059777396, 42.60627038138253, 49.28989894049508, 48.940057141440256, 52.29019709995815, 48.96510539736067, 49.10225936344692, 47.624829156058176, 47.63727337973458, 48.920734201158794, 47.850638662065776, 47.64456898825509, 45.70888423919678, 44.76695169721331, 43.15297549111502, 42.746214049203054, 42.17876509257725, 44.7231502532959, 46.29900516782488, 47.37725094386509, 48.4837897845677, 45.65447637013027, 42.68560143879482, 46.07688862936837, 45.71900429044451, 47.5202031816755, 46.981422492435996, 47.20066247667585, 49.81358119419643, 54.61762475967407, 59.778534752982004, 58.7694548198155, 56.05131605693272, 56.1354969569615, 53.74765123639788, 56.000479561941965, 61.81063270568848, 66.48222623552594, 66.55744743347168, 67.24128913879395, 69.84080478123256, 69.45792429787772, 67.08567033495221, 69.0691031047276, 71.28569657461983, 64.40131718771798, 13.53167234148298, 0.3522254382925374, 53.070903641836985, 68.52311365944999, 42.297457695007324, 38.74164410999843, 47.895871434892925, 35.63141850062779, 36.18196249008179, 54.52681875228882, 2.1047908748899187, 0.19713935229395116, 0.11940940682377134, 0.04786017577030829, 0.13682285456785134, 0.10034287135515894, 0.06311174309147255, 0.09742624964565039, 0.06605595403483935, 0.35988981702498024, 0.19900119810232095, 0.32930658810905045, 0.20718233553426607, 0.13553443870374135, 0.3149364377771105, 0.18939439074269362, 0.44150566469345776, 4.212726243904658, 56.39730855396816, 63.016499519348145, 56.01885754721505, 30.64938293184553, 67.80394036429269, 64.74677467346191, 51.28360462188721, 70.18419865199498, 79.54150445120675, 26.35351150376456, 0.8897585730467523, 8.496927738189697, 69.75001961844308, 68.1255099432809, 71.55869824545724, 71.1607471193586, 69.81960582733154, 63.867528779166086, 63.862776211329866, 58.447030612400596, 60.83368819100516, 59.0715902873448, 57.097666127341135, 55.57629203796387, 57.166661739349365, 53.87142644609724, 54.16270187922886, 52.91233532769339, 48.736256054469514, 49.49508966718401, 51.260637351444785, 48.28315707615444, 47.65019702911377, 46.27528401783535, 48.155699321201865, 43.84127446583339, 44.353005817958284, 44.29474169867379, 44.364824703761506, 45.0467278616769, 45.03463452202933, 46.304865973336355, 47.18613031932286, 52.75110237939017, 56.456455094473704, 58.49868352072579, 58.414909090314595, 56.40691096442086, 55.637106146131245, 49.077697481427876, 49.09941060202462, 50.66032688958304, 52.726721150534495, 52.693647725241526, 52.02608912331717, 54.829551764896934, 49.66588681084769, 49.300797189985005, 48.91206979751587, 48.557242665972026, 53.52687222617013, 51.77998045512608, 46.93701308114188, 33.38353034428188, 42.70244039808001, 48.05070856639317, 38.1081177847726, 44.381389209202354, 39.03075170516968, 43.167017800467356, 46.419285433632986, 39.973445074898855, 41.424357482365195, 43.05869191033499, 42.97386482783726, 41.703782762799946, 45.21190391268049, 44.62563576017107, 44.95253808157784, 45.60837854657854, 46.75852428163801, 48.23218856539045, 43.787283488682334, 45.743979590279714, 46.161753926958355, 44.013721806662424, 45.41058765138899, 42.142179352896555, 41.26954814365932, 40.39841774531773, 40.27971819468907, 39.47643348148891, 42.385362829480854, 42.31096499306815, 36.598628589085166, 42.028472082955496, 57.41266965866089, 58.4385746547154, 51.3929032598223, 50.792450359889436, 47.448949405125205, 44.76817110606602, 45.910038062504356, 44.53106035505022, 52.44432898930141, 52.73310307094029, 53.63036911828177, 52.089001587459016, 50.21829291752407, 49.2317008290972, 50.89117383956909, 51.72000707898821, 49.78597947529384, 48.890276772635325, 47.53653144836426, 48.77807378768921, 43.48999091557094, 45.66849436078753, 44.243022782461985, 44.48467765535627, 49.5884804044451, 47.45632839202881, 49.8495693887983, 47.204077516283306, 44.057061195373535, 46.854260035923545, 46.39484167098999, 48.30403641292027, 47.47302143914359, 48.70293249402727, 54.0245543207441, 57.610085351126536, 61.16317176818848, 61.33133207048689, 56.71603284563337, 58.200605801173616, 55.735642024448936, 57.48448623929705, 63.53760051727295, 68.78365721021379, 68.6203259059361, 69.09834112439836, 72.75169699532645, 74.73966693878174, 68.97440610613141, 73.05373518807548, 73.43141147068569, 69.14720780508858, 14.837933676583425, 0.5582692463483129, 57.36029413768223, 77.39211395808628, 45.9575845854623, 50.858934198107036, 52.84337445667812, 47.05836336953299, 47.830655642918174, 71.58171762738908, 8.128373571804591, 0.3836969238306795, 0.2636710815131664, 0.1903506230030741, 0.24041206815413066, 0.258283404899495, 0.22008710806923254, 0.15146527386137418, 0.40561162361076897], [0.05367854230904153, 0.22670184741062777, 0.03538790484890342, 0.09345265358154263, 0.044764726156634946, 0.1640808412006923, 0.09895113496375935, 0.25825631778155056, 0.13951950200966426, 10.753102489880153, 47.715381554194856, 55.49105153764997, 23.094745567866735, 29.735100746154785, 60.60637787410191, 38.16031960078648, 57.534631388528005, 70.17630549839565, 25.33943407876151, 0.8541391215154103, 9.78946464402335, 58.877693857465474, 59.95115579877581, 65.27722099849156, 66.50391851152692, 63.30965791429792, 63.00391633169991, 61.18703883034842, 54.933218887874055, 53.515775953020366, 52.4117488861084, 48.84928934914725, 48.302170821598594, 47.24087170192173, 47.80101810182844, 49.398183141435894, 47.04968159539359, 42.86409023829869, 43.953626837049214, 43.24992023195539, 44.9457288469587, 42.50163745880127, 41.521198000226704, 42.16801275525774, 40.84484992708479, 39.290207862854004, 38.41019071851458, 39.868030479976106, 41.70131267820086, 41.91270119803292, 42.356576442718506, 41.73675891331264, 45.10787548337664, 53.061641693115234, 53.257018089294434, 49.929810660226, 48.84603064400809, 50.39526353563581, 45.10860851832798, 45.19693749291556, 48.31672382354736, 49.69505187443325, 48.24363224846976, 50.02382673536028, 48.28078079223633, 47.88576875414167, 46.614609718322754, 47.894276823316304, 44.21066502162388, 45.97160952431815, 49.21801635197231, 40.819162436894004, 24.726472684315272, 25.653313738959177, 42.627233096531455, 34.34387213843209, 39.1681558064052, 36.580448627471924, 36.70357765470232, 38.05972358158657, 36.895869050707134, 36.97663491112845, 39.26679243360247, 38.64215980257307, 38.518440178462434, 37.34886033194405, 41.126884256090435, 40.06390367235456, 41.515358039310996, 41.12181901931763, 41.40886647360665, 39.31998436791556, 39.29832683290754, 37.858229296548025, 37.32135936192104, 40.48775768280029, 42.66166836874825, 35.78834703990391, 35.442754064287456, 36.67068140847342, 37.102265289851594, 37.05530588967459, 37.28221321105957, 33.052889892033164, 45.527414662497385, 65.73902606964111, 42.98957470485142, 48.9351030758449, 45.222823006766184, 46.243714877537315, 42.19921364103045, 45.323891503470286, 44.86394507544381, 46.69800894601004, 48.01496008464268, 48.4698760168893, 48.51709597451346, 47.52704020908901, 48.056555475507466, 49.59707532610212, 45.71041979108538, 46.83687216894967, 43.257302692958284, 44.8282139641898, 41.590596607753206, 40.2975229535784, 40.85925006866455, 41.79240703582764, 41.17986079624721, 40.311186586107524, 44.76638194492885, 40.87879187720162, 43.22826269694737, 41.57157938820975, 42.98126465933663, 44.92393582207816, 43.59368583134243, 43.52496119907924, 46.39550869805472, 46.02050052370344, 49.406253474099294, 49.3160137448992, 49.41234357016427, 49.633827822549, 48.86094842638288, 48.05838285173689, 52.040610858372276, 59.91503211430141, 63.81946114131382, 65.6846981048584, 67.02724988119942, 63.33308029174805, 63.301222801208496, 65.74519606998989, 66.987763268607, 68.88863754272461, 64.29596165248326, 11.572258625711713, 0.47983928344079424, 51.17282601765224, 54.3832550730024, 30.997241020202637, 36.33491665976388, 47.27082538604736, 32.75893940244402, 35.94281244277954, 40.664724826812744, 0.8357119017413684, 0.014102320685716612, 0.04056088619732431, 0.002733907920108842, 0.04020204295271209, 0.010941011614964476, 0.0935448936319777, 0.02365639739270721, 0.1055027637630701, 0.0474758671064462, 0.058628540086959086, 0.04381950991228223, 0.028822057348276888, 0.08934991194733552, 0.09892589346106563, 0.07581625958638531, 0.2228447286678212, 0.31623024120926857, 14.448352524212428, 63.8347749710083, 50.22909736633301, 17.511524064200266, 44.32893030984061, 63.58970505850655, 42.835487978799, 62.99219472067696, 76.00721291133335, 27.748376267296926, 1.0831457759652818, 12.64302727154323, 64.67739691053117, 63.346969740731375, 70.17581912449428, 70.30905083247593, 66.35203783852714, 65.61617497035435, 63.82665947505406, 59.05825669424874, 57.384480816977366, 56.253334930964876, 52.693105765751426, 52.063602447509766, 51.82675920213972, 51.951858043670654, 52.107626233782085, 50.794628620147705, 46.09456832068307, 49.73610877990723, 47.59863792146955, 46.28115177154541, 46.87729331425258, 46.622318744659424, 47.13336917332241, 42.850857394082205, 40.92132874897548, 42.066065311431885, 41.68814236777169, 43.8560984475272, 43.60312843322754, 43.707236766815186, 43.445762157440186, 47.718219893319265, 54.856694902692524, 55.9256648336138, 51.05828148978097, 49.828033447265625, 50.736670221601216, 47.72136395318167, 49.371807779584614, 49.610523564474924, 51.67814418247768, 50.11683532169887, 51.357717582157676, 52.24569041388375, 52.140435627528596, 52.13049275534493, 51.42542430332729, 49.1609924861363, 51.384568895612446, 53.03301164082119, 43.40705721718924, 27.301803384508403, 42.12618112564087, 52.659250668116975, 36.426695414951865, 42.482641083853586, 38.24075542177473, 39.72606488636562, 40.08866357803345, 38.07415846415928, 38.87807198933193, 41.17343371255057, 42.0675939151219, 39.7562826020377, 40.13074534279959, 43.09668813432966, 42.8421756199428, 41.431003434317454, 42.31385891778128, 43.105130195617676, 40.42454992021833, 38.78211041859218, 39.71924522944859, 39.61750275748116, 41.55788101468767, 41.37982995169503, 38.60476459775652, 36.89779370171683, 40.253391470227925, 39.111878871917725, 36.36311592374529, 37.54377467291695, 34.53314801624843, 43.31328780310494, 68.53611373901367, 48.440182890210835, 48.936221735818044, 47.516249656677246, 48.901209763118196, 44.21658141272408, 45.45304809297834, 46.70681578772408, 49.626139640808105, 50.81285374505179, 52.445583139147075, 50.6896413394383, 50.70060907091413, 49.876396383558, 48.971132959638325, 48.3905553817749, 48.42000879560198, 46.52837215151106, 48.17198589869908, 44.855016640254426, 43.571816376277376, 43.333847522735596, 42.924688952309744, 44.708739689418245, 43.881167548043386, 46.512540681021555, 44.09312582015991, 44.977718353271484, 45.36410072871617, 45.94115209579468, 47.22492558615548, 47.07323251451765, 46.40708787100655, 46.85676138741629, 48.3520484651838, 51.617444719587056, 53.47391653060913, 51.07302556719099, 51.967130184173584, 52.6511629649571, 50.824915817805696, 56.794533593314036, 61.98789514814104, 66.57907022748674, 69.87846401759556, 68.58078370775495, 68.38832555498395, 68.56715829031808, 68.68748024531773, 70.52793298448834, 73.21942887987409, 69.22671604156494, 11.633495705468313, 0.37399113178253174, 58.28736795697893, 59.08593831743513, 36.78264815466744, 41.581181798662456, 57.09429277692522, 32.08630166734968, 44.26433290754046, 48.30180951527187, 0.6422377377748489, 0.02762566609973354, 0.09811876927103315, 0.058531149955732484, 0.0553115148629461, 0.057913513455007753, 0.10195034795573779, 0.015543123640652214, 0.025809590871046697, 0.15479844143348082, 0.2813974288957459, 0.1181179511227778, 0.21460016178233282, 0.19072106241115502, 0.21472985696579727, 0.20099586035524095, 0.30437449738383293, 0.4725165335195405, 25.911246504102433, 73.30794198172433, 69.33454513549805, 33.029206957135884, 42.24282053538731, 76.63054275512695, 50.99850613730294, 68.7224783216204, 79.17010934012276, 30.983737196241105, 1.272924421089036, 14.759931462151663, 66.46725286756242, 64.27166380201066, 70.64264079502651, 72.49903270176479, 67.3190255846296, 67.25299685341972, 67.44801194327218, 58.65698432922363, 58.84330722263881, 57.63859033584595, 53.81872088568551, 53.287822927747456, 52.53132390975952, 52.738272530691965, 54.75347593852452, 52.77624096189226, 48.136383329119, 50.27642502103533, 47.632784843444824, 48.32105949946812, 47.998920168195454, 46.645077569144114, 48.694667611803325, 46.54244572775704, 44.27320575714111, 45.68673685618809, 43.357110091618125, 46.20274829864502, 46.43696859904698, 47.081434862954275, 44.35574688230242, 49.79249688557216, 56.84362261635916, 59.870709555489675, 52.53346742902483, 52.59998600823538, 54.881920337677, 49.29417903082711, 50.26632581438337, 52.64188017163958, 54.424666336604524, 51.60862398147583, 53.01577663421631, 55.14364160810198, 55.26358141217913, 52.4295015335083, 53.02935688836234, 48.57119812284197, 53.889352798461914, 55.53234120777675, 43.39288636616298, 27.875915663582937, 33.52644436700003, 50.59269659859793, 37.23271424429757, 45.75465202331543, 41.17855453491211, 42.276835441589355, 42.785214287894114, 40.55735431398664, 41.3420386995588, 46.03933014188494, 44.13404376166207, 43.21933773585728, 41.9320137160165, 45.27250610079084, 44.68933684485299, 45.19882045473371, 45.47713054929461, 46.225055490221294, 44.57773835318429, 43.82327168328421, 42.90967389515468, 43.48219851085118, 46.995443957192556, 46.3506372315543, 40.60524129867554, 39.021583557128906, 41.85564953940255, 40.565751211983816, 40.86430835723877, 41.58871364593506, 38.640398434230256, 47.5763133593968, 67.80879020690918, 53.06536592755999, 50.42085027694702, 49.841606753213064, 51.11194242749895, 48.80253144672939, 48.070514406476704, 51.294124194553916, 53.179233006068635, 52.161360127585276, 53.618532861982075, 53.259283202035085, 52.619788374219624, 52.7071168082101, 50.99963869367327, 50.61090782710484, 50.60193075452532, 46.70817068644932, 50.51960849761963, 47.15840005874634, 43.850699697222026, 45.7573618207659, 45.73179939814976, 46.62294060843331, 45.759543555123464, 48.153187547411235, 45.52694913319179, 48.570826394217356, 46.01016160420009, 48.746247564043315, 49.334138120923726, 48.29424292700631, 48.19655472891671, 50.76402875355312, 51.54459285736084, 54.047490324292866, 55.091328620910645, 53.79191126142229, 54.804281166621614, 54.53564296449934, 54.24020903451102, 57.42825794219971, 65.66296413966587, 69.750241960798, 71.76485129765102, 70.4742512021746, 70.71590954916817, 70.5079847063337, 72.38287271772111, 73.83617183140346, 74.70744814191545, 72.5350591114589, 13.426024113382612, 0.4403170884719917, 63.18700136457171, 64.70459910801479, 42.57980816704886, 49.68264586584908, 62.30479553767613, 42.66858877454485, 51.26533085959298, 65.56589085715157, 1.28245832664626, 0.20841869419174536, 0.10158051244382348, 0.1382525007107428, 0.1506930874394519, 0.1634562632867268, 0.20034046338072845, 0.08771549750651632, 0.22231002950242587], [0.06404500015612159, 0.11059602403214999, 0.051691825701189895, 0.17349444249910967, 0.05116549626524959, 0.0416827284997063, 0.04981001399989639, 0.27977651730179787, 0.07939323157604251, 1.0295131738696779, 46.461759771619526, 51.67993334361485, 41.32781573704311, 26.08834218978882, 55.817790576389854, 43.100996017456055, 51.82059962408883, 72.16274683816093, 33.30996629170009, 0.5940259248018265, 15.414420502526418, 67.3334708895002, 63.0247609274728, 66.61242852892194, 63.804327964782715, 63.36249896458217, 62.570564133780344, 60.239116941179546, 53.930694580078125, 51.21149621691023, 49.29900108064924, 51.177630696977886, 50.52057082312447, 48.54936688286917, 45.20305190767561, 48.99015712738037, 46.065583910260884, 43.01805189677647, 42.619378158024375, 43.810987268175396, 43.18907833099365, 41.50834730693272, 43.891242436000276, 42.904959542410715, 40.052380084991455, 38.224329880305696, 38.80527571269444, 40.130252020699636, 41.81170218331473, 41.89731093815395, 41.668135029929026, 41.962894984654014, 42.28314093181065, 51.54835878099714, 55.183357511247905, 46.725735732487266, 50.917896611349924, 49.263940470559255, 46.17002575738089, 46.82436541148594, 46.82585232598441, 52.53548240661621, 51.42619207927159, 48.94759246281215, 47.739547388894216, 46.65503781182425, 49.2154837335859, 46.25185816628592, 46.83437081745693, 46.303750787462505, 47.55142838614327, 44.74921989440918, 30.63825191770281, 20.06474733352661, 42.37070213045393, 36.47277239390782, 36.70329972675869, 36.569550377982004, 35.93567664282662, 36.6424161366054, 36.155111176627024, 37.24111461639404, 36.286859444209504, 34.8947878565107, 38.55516835621425, 39.23368774141584, 41.15568453924996, 38.229089396340505, 40.71660702569144, 40.27659150532314, 36.91821445737566, 40.261503492082866, 38.759094510759624, 37.83343117577689, 36.416047300611226, 35.414179597582134, 40.62374087742397, 35.70525353295462, 37.7939202444894, 36.13880722863333, 37.256181785038535, 35.35882677350725, 36.6582476070949, 32.57728222438267, 51.06962094988142, 50.574718134743826, 39.10924203055245, 43.736964634486604, 41.66640840257917, 43.8705541746957, 44.31619773592268, 47.22864982060024, 44.87363086427961, 50.549652508326936, 48.35133627482823, 49.532693317958284, 50.24198627471924, 50.023461954934255, 49.552770137786865, 48.480065550122944, 48.43640654427664, 45.45914166314261, 45.00984334945679, 44.06043801988874, 41.672213622501914, 42.048639229365754, 41.410593100956504, 42.1346891948155, 40.21449545451573, 39.17917912346976, 39.820094857897075, 39.1314241545541, 41.5242725781032, 39.91907542092459, 41.01142256600516, 43.13830436979021, 42.066732338496614, 44.8902405330113, 44.988679136548726, 45.954808780125205, 45.871082987104145, 46.669886112213135, 48.39810807364327, 45.14869267599923, 48.526114736284526, 47.009635652814595, 52.55655281884329, 60.14426013401577, 63.324596541268484, 65.26606219155448, 65.33663504464286, 63.26723221370152, 65.71706976209367, 66.63519082750592, 67.08549662998745, 69.23132964542934, 67.5280065536499, 8.009456021445137, 0.8303869217634201, 56.805087906973704, 45.42868423461914, 29.088270357676915, 35.27282544544765, 43.9488707951137, 44.99367836543492, 47.319990839277, 27.397040605545044, 0.11670294776558876, 0.04790721860315118, 0.14375088709805692, 0.018829774244555404, 0.03406466996031148, 0.09293113835155964, 0.06108810739325626, 0.08700659804578338, 0.10633655437933547, 0.03538332473752754, 0.03903462006045239, 0.08048690110445023, 0.047871826216578484, 0.04327388633308666, 0.09797643298017127, 0.1056888655626348, 0.19290680012532643, 0.03574438000630055, 1.560991414955684, 51.325012411390034, 61.07965442112514, 24.44136377743312, 33.60666479383196, 64.51646968296596, 46.61691304615566, 60.55477360316685, 75.65188898359025, 39.13757331030709, 0.4494820066860744, 19.23164963722229, 72.13357135227749, 66.68483570643834, 69.95697171347481, 69.6471584865025, 67.70376818520683, 64.87192562648228, 63.590643065316335, 55.647858483450754, 55.2320157459804, 53.72127934864589, 53.713226386478965, 52.2358969279698, 52.30407612664359, 50.17270231246948, 52.26075063432966, 50.451568262917654, 47.27663060597011, 46.59195859091622, 45.771404130118235, 46.97348764964512, 45.072707176208496, 47.21828658240182, 45.150540896824424, 42.29872226715088, 40.42664132799421, 40.51055472237723, 41.190786838531494, 42.65391765322004, 43.34381471361433, 45.48162950788225, 43.72056688581194, 45.442563261304585, 56.25957441329956, 56.230319023132324, 51.46513325827462, 52.93743222100394, 51.784420354025706, 48.24148178100586, 47.790498529161724, 51.78265898568289, 54.45150375366211, 52.45588731765747, 51.69289868218558, 51.328972884586875, 50.68396813528878, 49.66574089867728, 50.35879244123186, 51.13626459666661, 53.044733251844136, 50.143978459494456, 49.53933579581124, 33.12053407941546, 33.34027780805315, 55.27627924510411, 38.03893804550171, 42.049007483891074, 37.75803279876709, 40.50552422659737, 39.315110206604004, 38.583013262067524, 39.65806286675589, 40.28601673671177, 38.274975299835205, 41.28797129222325, 41.11965465545654, 41.21778753825596, 40.30810158593314, 42.44793135779244, 40.935881750924246, 39.52800301143101, 40.90608440126692, 38.364652224949424, 39.28142533983503, 39.65027741023472, 37.6606433732169, 38.99520124707903, 38.0993526322501, 38.85758522578648, 38.426095145089285, 37.729496547154014, 37.346838406154085, 38.305905205862864, 33.314194270542686, 48.397948265075684, 57.5830533845084, 41.89694268362862, 44.89901958193098, 45.66006619589669, 47.77733516693115, 45.58624158586775, 48.18600041525704, 47.66643149512154, 51.28519923346383, 50.742294788360596, 52.022517749241416, 51.97536032540457, 52.07666853496006, 52.337767941611155, 51.16352932793753, 51.57361895697457, 50.32482964651925, 48.54845666885376, 46.55866977146694, 43.95308835165841, 42.3712614604405, 43.17509160723005, 43.26931265422276, 42.78243153435843, 41.35959332329886, 42.666233335222515, 43.26675919124058, 44.871094771793906, 42.86982945033482, 45.27449675968715, 44.88090215410505, 45.621166706085205, 47.47861473900931, 46.16201795850481, 48.2177015713283, 47.150833470480784, 48.83315563201904, 48.93673242841448, 49.10966614314488, 49.97506080354963, 49.54508890424456, 55.81960753032139, 64.22080298832485, 65.83852427346366, 66.64764894757951, 68.89245210375104, 67.50929505484444, 69.5283373423985, 69.3358930860247, 71.45311341966901, 71.3246968133109, 71.0180311203003, 8.702885372298104, 1.0067043006420135, 65.24726036616734, 50.31771469116211, 37.739790303366526, 41.83663579395839, 58.647242954799104, 45.18139089856829, 50.29288182939802, 25.627636671066284, 0.1619386382933174, 0.021272681819807206, 0.07899449047233377, 0.020065534094880735, 0.027200787827106457, 0.042319506473307095, 0.06961690581270627, 0.048752266115375927, 0.12494243920913764, 0.1226338730858905, 0.1627856128449951, 0.1686525930251394, 0.15856356439845903, 0.21756343277437346, 0.17020347980516298, 0.20241456851363182, 0.25500947343451635, 0.23507066762873105, 2.8070804817335944, 71.4396756035941, 66.38105351584298, 58.439199992588584, 35.924952098301475, 69.57256262642997, 56.688104561397004, 63.743572916303364, 80.42990112304688, 40.892962728227886, 0.5793566490922655, 20.133548395974294, 75.15022209712437, 69.63721561431885, 72.92378302982875, 68.90802996499198, 68.26042311532157, 65.41232872009277, 65.55861609322685, 56.26832914352417, 56.00092772075108, 55.099902697971885, 55.14930786405291, 53.5359639440264, 52.80894265856062, 50.40917035511562, 55.17984519686018, 51.061272689274375, 47.50737680707659, 46.24256495067051, 47.88581739153181, 47.59741851261684, 45.82487746647426, 46.89468118122646, 47.20070416586739, 44.22860874448504, 41.95164932523455, 43.54862328938076, 44.2566933631897, 46.25107996804373, 46.22707741601126, 46.69413879939488, 46.54876511437552, 47.00246858596802, 56.84955637795584, 60.110332080296104, 52.86088391712734, 55.36604997089931, 55.523850509098594, 52.34174925940377, 49.49628128324236, 52.57909972327096, 56.99286992209298, 56.265237195151194, 53.46175023487636, 52.59124517440796, 51.9142370223999, 53.36207137789045, 50.99209295000349, 51.76834569658552, 52.672559942517964, 53.27483674458095, 52.50780078342983, 34.946079458509175, 27.806843621390207, 49.58164685113089, 41.464028222220286, 42.99854482923235, 41.49040705817086, 40.452120372227256, 42.62932103020804, 39.63650260652815, 43.80640493120466, 42.53657647541591, 40.54405893598284, 45.31367070334298, 46.52000304630825, 44.295391355242046, 43.639936515263145, 45.8254611151559, 45.22540078844343, 43.645436014447895, 47.07607780184065, 42.245276723589214, 40.679587023598806, 42.3179965700422, 41.66004037857056, 44.15722990036011, 41.825720173971995, 42.350409916469026, 39.158706256321494, 40.044368812016074, 40.11422600064959, 40.27329111099243, 37.47074910572597, 50.602288586752756, 62.18587711879185, 47.46376643862043, 45.323582308632986, 47.87417221069336, 49.21682473591396, 49.988561153411865, 51.30745431355068, 50.532546043395996, 56.51016466958182, 52.60432168415615, 55.289800439562114, 53.79980788912092, 54.40728541782924, 53.307621819632395, 53.42509501320975, 51.08057825905936, 51.36281061172485, 47.99587338311331, 47.50485461098807, 45.03645495006016, 47.5001402582441, 46.44497639792306, 45.89396687916347, 45.10917132241385, 43.368157727377756, 45.44949756349836, 44.46112673623221, 47.491757256644114, 45.04435505185808, 46.703946181706016, 47.184011118752615, 47.50387838908604, 50.02466399329049, 47.49995265688215, 52.104228564671104, 49.30922188077654, 52.58070823124477, 51.736012254442485, 50.069021293095176, 51.95809752600533, 51.92511442729405, 57.08521148136684, 65.92097159794399, 68.79445471082414, 70.28291170937675, 70.891587802342, 69.29282120295933, 70.66215828486851, 73.39693450927734, 72.42244270869664, 75.4163658959525, 74.30755846840995, 10.621340325900487, 1.2516060450247355, 70.76442881992885, 59.11120196751186, 45.511173248291016, 48.585421085357666, 59.65334905896868, 57.6440863609314, 65.13022490910122, 42.79546635491507, 0.30253314333302633, 0.24960893179689134, 0.2147417991821255, 0.12384834220366818, 0.09563848629061665, 0.14263726185475076, 0.13756867311894894, 0.17759366253657, 0.23334309032985143], [0.054888370247291665, 0.19645884952374867, 0.04549616655068738, 0.055873121334505935, 0.1668668652751616, 0.07138899500880923, 0.2867114437477929, 0.055482770316302776, 0.19540629243212088, 0.24306777279291833, 16.48897852216448, 57.20503316606794, 40.158899443490164, 22.42347662789481, 39.77025890350342, 46.67593799318586, 43.047383717128206, 68.76803765978131, 43.59965433393206, 0.17442083278936998, 24.172555344445364, 73.65522684369768, 59.22996057782854, 67.96155330113002, 62.88520635877337, 65.97472981044224, 65.05799838474819, 60.1618321282523, 53.55341781888689, 51.25151784079415, 47.97993074144636, 48.96279859542847, 51.03021076747349, 49.273817334856304, 46.49614988054548, 47.274942193712505, 44.62127923965454, 45.32429449898856, 41.81778185708182, 39.90782628740583, 41.01839855739048, 42.86365597588675, 42.7125882421221, 41.821895190647666, 41.00377607345581, 38.07372072764805, 38.516126428331646, 38.798643657139365, 43.16317197254726, 43.484616483960835, 42.16864851542881, 43.26792996270316, 42.798898765019004, 53.25020885467529, 50.51222603661673, 49.9199789592198, 50.2922808102199, 47.26290096555437, 46.85574695042202, 48.767436095646445, 48.2951739856175, 51.63712549209595, 50.58592210497175, 52.06153188432966, 49.533141476767405, 46.34963321685791, 49.66539001464844, 48.72866514750889, 49.61848272596087, 48.980255944388254, 50.603271756853374, 47.95526116234915, 44.755886690957205, 14.963645696640015, 36.68361548015049, 40.76594965798514, 34.318330560411724, 38.54800476346697, 34.36837148666382, 36.93772847311837, 35.91180610656738, 35.61397852216448, 36.00091675349644, 35.11145353317261, 37.45952429090227, 39.49901860100882, 38.46399062020438, 39.16296550205776, 38.1361711365836, 37.72471966062273, 34.20244155611311, 35.77334240504673, 39.059312275477815, 35.382144927978516, 36.73240573065621, 37.55120924540928, 39.06729922975813, 32.675359521593364, 35.795569692339214, 35.80333777836391, 38.028324672154014, 35.03633655820574, 37.34196424484253, 37.52713373729161, 48.61815057482038, 40.702884333474294, 36.77204520361764, 42.992725712912424, 43.48900079727173, 44.24563530513218, 45.590236800057546, 46.42213766915457, 46.66008915219988, 46.69272831508091, 47.128185817173545, 48.12509250640869, 49.83794852665493, 50.907064369746614, 50.0859158379691, 50.55102130344936, 51.967713832855225, 50.333650384630474, 48.091883591243196, 44.72761794498989, 42.66019187654768, 42.19898782457624, 40.741644859313965, 40.8460693359375, 40.36537558691842, 38.48147576195853, 38.003700256347656, 40.53287928444998, 41.670733656202046, 42.10787262235369, 40.01467915943691, 44.63319887433733, 42.465392180851524, 44.78316879272461, 45.60373714991978, 44.6720358303615, 48.404097420828684, 45.24747174126761, 48.460145064762656, 45.186404023851665, 47.5693929536002, 47.740534033094136, 53.97536454881941, 60.90427494049072, 63.62128462110247, 62.213475363595144, 65.13740239824567, 61.55735002245222, 66.70364448002407, 63.63307571411133, 69.74812970842633, 64.44950989314488, 67.91051183428083, 5.416219813483102, 1.142574804169791, 58.30147974831717, 44.139175006321494, 27.754818984440394, 29.139925003051758, 30.2278322492327, 21.565400157655986, 48.14397423607962, 12.05307309968131, 0.32970936649612015, 0.07208422877426658, 0.043566480811153135, 0.011200346850923129, 0.05410004486995084, 0.06245292630046606, 0.037305634801409075, 0.13273962081543036, 0.04475939965673855, 0.0380761384564851, 0.036137513018080165, 0.02948267904243299, 0.06095742154866457, 0.11043959456895079, 0.10532262628631932, 0.20384694236729825, 0.04090455061356936, 0.1649200940238578, 0.4473980356539999, 14.489676066807338, 68.11662319728306, 33.71490035738264, 24.15110625539507, 53.702362877982004, 51.19784300667899, 53.97587176731655, 72.41557788848877, 48.26554339272635, 0.09821190498769283, 30.225699152265275, 78.38401099613735, 63.242079734802246, 71.64293125697544, 67.38177476610456, 68.33554703848702, 67.32646015712193, 62.36720425742013, 55.41960321153913, 53.92606707981655, 51.22155373437064, 52.35337706974575, 54.171897820064, 52.83705159596035, 49.08633409227644, 49.5526624407087, 48.576020172664094, 47.823360034397666, 46.41590166091919, 44.9813939503261, 43.43438795634678, 45.76260076250349, 45.34540660040719, 45.714078017643516, 43.53186770847866, 41.85118532180786, 40.72820009504046, 44.20434216090611, 43.88996049336025, 46.83683047975813, 44.78155681065151, 44.681926591055735, 44.37711606706892, 56.166478974478586, 50.56842654091971, 53.449524879455566, 52.51739624568394, 49.33121987751552, 50.86643477848598, 51.964215414864675, 49.874134744916645, 52.5268805367606, 55.179146902901785, 55.166421277182444, 51.32939672470093, 50.50531952721732, 51.54822676522391, 52.194801807403564, 50.29959378923689, 54.79327869415283, 54.31889043535505, 51.49716097967965, 45.470859800066265, 25.915139232363018, 50.8597297668457, 41.787320954459055, 36.37803370612008, 41.5319572857448, 37.185608931950156, 39.10332563945225, 38.663567202431814, 38.51757860183716, 38.43978657041277, 38.07186555862427, 39.13454042162214, 39.91543109076363, 40.83017185756138, 39.74036775316511, 39.1414087159293, 40.03429044995989, 36.46481670652117, 39.87553106035505, 38.97885908399309, 37.73860216140747, 37.80643047605242, 41.05778094700405, 38.577437332698274, 36.76966544560024, 36.80495534624372, 38.881858757564, 37.675905091421946, 37.00312144415719, 40.406130245753694, 37.42222983496529, 48.180980341775076, 46.799706254686626, 41.16036415100098, 42.67334829057966, 45.83679362705776, 46.97851814542498, 48.065668037959504, 48.09037583214896, 48.32755953924996, 50.74135330745152, 49.06428050994873, 50.482036113739014, 52.93026862825666, 53.07346405301775, 52.51333849770682, 53.087898935590474, 53.75604118619646, 52.528145108904155, 51.68746171678816, 49.19643177304949, 44.59089476721627, 43.65879740033831, 43.76076916285923, 42.52288505009243, 41.49325234549386, 40.70461443492344, 41.862851347242085, 42.68885319573538, 45.94586297443935, 44.078548499516074, 44.84641824449812, 46.42759895324707, 43.681382519858225, 47.050727299281526, 46.980067593710764, 46.59252486910139, 49.30171087809971, 48.75439085279192, 49.76686498097011, 47.43106474195208, 50.259735448019846, 49.655485357557026, 56.57134008407593, 65.52718244280133, 66.91634968348912, 65.72251714978898, 69.71850953783307, 65.95462172372001, 71.69624478476388, 66.478182383946, 73.79719938550676, 67.52365003313336, 71.25256756373814, 6.268296948501042, 1.9054338123117174, 65.65516826084682, 50.84699371882847, 37.165688446589876, 36.213576793670654, 40.32193544932774, 22.580455541610718, 61.15932246616909, 16.106653894696915, 0.44057609885931015, 0.029037488824022666, 0.09433888816939932, 0.0024862659629434347, 0.047225932125002146, 0.043130070835884125, 0.012128939835487731, 0.059007013349660804, 0.04765566870836275, 0.12226263300648757, 0.2763274966606072, 0.16241788757698877, 0.2285596898623875, 0.28845804716859547, 0.2373110545533044, 0.3753711905862604, 0.16669259034097195, 0.30279720202088356, 0.7659504136868885, 28.647429738725933, 73.88874190194267, 53.75308820179531, 31.91422258104597, 52.4392602784293, 60.44868850708008, 55.52271100452968, 77.23547376905168, 50.710454668317524, 0.23804001829453877, 29.580791677747452, 83.59666075025285, 66.17868028368268, 75.08233819689069, 68.04552922930036, 70.66413157326835, 67.89319692339215, 65.38329219818115, 55.93385328565325, 55.99600144795009, 52.52470922470093, 54.25735371453421, 55.866466181618826, 55.71362665721348, 50.19948066983904, 53.32312325068882, 49.35520158495222, 51.20629549026489, 46.22095257895333, 45.216350759778706, 43.534626143319265, 48.58730752127511, 46.9148622240339, 47.9789788382394, 44.50641509464809, 44.66379526683262, 42.69820894513811, 46.1520368712289, 47.074392863682334, 48.45945371900286, 47.302245140075684, 48.306846959250315, 45.7007965360369, 57.15590592793056, 53.145704473767964, 56.2752217565264, 56.194424629211426, 53.52534709657942, 52.50769656045096, 52.54953861236572, 50.971199716840474, 56.12471682684762, 56.61607606070382, 57.83963993617466, 55.533181939806255, 52.67274406978062, 54.89125871658325, 52.93114062717983, 52.998340129852295, 54.941330909729004, 56.67680331638881, 54.99690955025809, 49.39296504429409, 20.92270221029009, 44.71318653651646, 44.29559632710048, 38.43271330424717, 43.1523814201355, 39.328787735530305, 41.978545801980154, 40.76471982683454, 40.767481735774446, 41.4982133592878, 42.18678331375122, 41.31755672182356, 44.20905998774937, 43.68088919775826, 42.30543075289045, 40.95858151572091, 43.03600256783621, 39.81050286974226, 44.0879077230181, 43.443976470402305, 40.42700610842024, 42.84282180241176, 44.188621861594065, 41.881878989083425, 38.82733276912144, 40.6917324747358, 40.882766246795654, 41.23076329912458, 40.47418090275356, 42.94844136919294, 40.76203782217843, 49.04654523304531, 51.68543631689889, 44.93480975287301, 43.58833919252668, 48.321347849709646, 48.81664323806763, 51.10939243861607, 50.00807864325387, 51.539183684757774, 52.78436688014439, 49.71640368870327, 53.96576908656529, 54.49437761306763, 54.19463232585362, 53.86890772410801, 55.689995833805625, 57.343576771872385, 52.91438504627773, 52.340887682778494, 50.41194616045271, 46.92592028209141, 46.28452512196132, 45.62989016941616, 46.18174042020525, 44.82556322642735, 43.749641622815815, 42.97577558244978, 44.99200732367379, 48.247095925467356, 46.270607880183626, 45.519257477351594, 49.26111255373274, 46.832856110164094, 50.13314969199044, 50.25435406821114, 50.948708398001536, 52.184699126652305, 51.677039418901714, 55.17689568655831, 49.52221890858242, 52.16548040934971, 52.85776765005929, 59.58449935913086, 66.99274512699672, 68.3676129749843, 67.35356507982526, 70.14041805267334, 68.70937401907784, 72.92081614903041, 70.91198076520647, 76.40156487056187, 71.51662690298897, 74.41827801295689, 8.1642792565482, 2.1205639370850156, 72.7138432094029, 56.95224380493164, 44.99640900748116, 40.56551149913243, 41.045343671526226, 29.314356054578507, 67.50399357931954, 21.532585552760533, 0.4590839828763689, 0.2769179035510336, 0.1345636857939618, 0.14544938238603727, 0.12304782015936715, 0.17635232343205384, 0.13465447377945694, 0.230814163173948, 0.1910681195024933], [0.12242021597921848, 0.27546643572194235, 0.07459592792604651, 0.08948880806565285, 0.028743289610637084, 0.04698557127267122, 0.10887618203248296, 0.13704058288463525, 0.13909866102039814, 0.33610594325831955, 2.617057455437524, 50.215048108782085, 45.76542867933001, 32.24525213241577, 26.312145403453282, 46.96561186654227, 50.292996474674766, 65.53880677904401, 45.92778376170567, 0.9522460571357182, 36.27957773208618, 71.60552215576172, 62.74621459415981, 65.05451038905552, 63.2448034286499, 62.10332557133266, 61.24094295501709, 56.166135038648335, 50.90855475834438, 51.20115382330758, 50.93224811553955, 49.392148630959646, 51.050753116607666, 46.93502242224557, 47.801903997148784, 45.744056020464214, 44.30321502685547, 43.78096410206386, 42.70017875943865, 39.998621872493196, 40.91382122039795, 40.10309846060616, 42.389333724975586, 40.358764375959126, 41.46661295209612, 38.11760554994856, 36.14595692498343, 39.37503841945103, 43.72502415520804, 43.70772661481585, 43.64169093540737, 42.562458515167236, 45.91568694795881, 52.26714645113264, 50.06530400684902, 50.8326005254473, 50.94214582443237, 47.80857079369681, 49.391530241285054, 49.84435823985508, 49.556980746132986, 50.79808187484741, 49.93266984394619, 48.81757429667881, 46.2445000239781, 48.12138911655971, 53.274993079049246, 51.0189859526498, 52.66995784214565, 47.014343057359966, 54.83056967599051, 45.74050201688494, 50.89918858664376, 18.49181761060442, 28.81492648805891, 45.33295890263149, 31.49038941519601, 39.96161576679775, 35.923930713108604, 36.58946738924299, 35.686107771737234, 35.645582403455464, 36.21101638248989, 34.84217957087925, 36.34465456008911, 38.599681990487234, 35.923239367348806, 36.81372397286551, 38.03912564686367, 41.63042368207659, 36.936696665627615, 36.127669266292024, 38.25147301810128, 38.60923228945051, 33.60976716450283, 35.95216471808297, 36.78855412346976, 36.039038045065745, 35.49170759746006, 34.64174836022513, 36.12021384920393, 33.481093474796836, 38.9601024218968, 34.8692740712847, 46.03970881870815, 35.85359409877232, 40.089716230119976, 46.229557922908235, 43.9060559953962, 47.027103424072266, 48.50712878363473, 50.261430808476035, 48.26200328554426, 46.319151469639365, 47.938620226723806, 50.47264909744263, 48.75787884848458, 50.22753054755074, 50.543145520346506, 49.80467012950352, 49.388681479862754, 49.40633337838309, 49.11112526484898, 48.815552370888845, 40.4661522592817, 42.33165325437273, 43.448600496564595, 40.14951590129307, 38.208046776907786, 39.518883500780376, 36.699283667973106, 39.92930664334978, 39.290645599365234, 41.48415715353829, 39.615189007350374, 44.56068399974278, 45.893900871276855, 43.18186957495553, 44.142305169786724, 43.85349287305559, 46.66442830221993, 42.65228830065046, 45.84251199449812, 44.69235583714077, 44.074101652417866, 45.25580957957676, 52.12773779460362, 59.89787701198033, 62.41055406842913, 61.78948933737618, 66.10965687888009, 62.94189671107701, 65.2428343636649, 63.40517480032784, 68.90061623709542, 63.43355819157192, 65.7012139729091, 4.3243555682046075, 1.8891878383500236, 62.32245091029576, 37.957605906895225, 25.64546922274998, 30.232178347451345, 27.72258108002799, 32.94978557314192, 58.327869006565635, 11.715690289224897, 0.2808647517647062, 0.07576861285737582, 0.07492281895663057, 0.06806960169758115, 0.0440955413505435, 0.09617883086736713, 0.022723238715635877, 0.05119535859142031, 0.037553863267281225, 0.0727481549339635, 0.1494202371686697, 0.06732834290180888, 0.053261161848370514, 0.05674306429656489, 0.019794627292347804, 0.10115948146475212, 0.08815484893109117, 0.10144680033304862, 0.16748458998543875, 2.712217377764838, 58.99453476497105, 48.07096256528582, 25.148303031921387, 37.11285434450422, 53.82709346498762, 55.64867837088448, 72.8494998386928, 51.92505884170532, 1.26711996112551, 42.65738133021763, 75.2167580468314, 65.19737924848283, 69.4499408176967, 66.47342981610979, 67.41006783076695, 63.704461506434846, 58.4862254006522, 52.92419590268816, 55.28436000006539, 52.663280623299734, 52.082362583705354, 53.988722460610525, 50.48520449229649, 49.428626673562185, 49.13628816604614, 48.14590236118862, 46.66047477722168, 45.74979523250035, 46.32713147572109, 45.137867382594514, 44.69966186795916, 45.177468640463694, 44.00543260574341, 43.20400653566633, 40.3096718788147, 39.461446217128206, 42.64158460072109, 44.18830919265747, 47.133605412074495, 47.04389027186802, 44.20875079291207, 47.38149976730347, 52.79085997172764, 51.479293687003, 52.66705002103533, 51.33901650565011, 50.77678912026541, 50.73587812696184, 53.135869298662456, 53.069472312927246, 54.929147243499756, 51.705415861947195, 50.766432830265586, 50.35077422005789, 52.122985226767405, 51.694792066301616, 54.23408072335379, 54.85821655818394, 51.081443309783936, 55.705594539642334, 50.22873258590698, 52.83141313280378, 28.465175015585764, 42.77037640980312, 46.16870559964861, 33.82075616291591, 39.966858182634624, 37.787388937813894, 39.71207121440342, 38.75803491047451, 37.226700578417095, 36.91707147870745, 36.757988997868125, 38.13249553952898, 38.70718451908657, 38.74911689758301, 39.5773525919233, 40.592067514147075, 41.19451802117484, 38.78282955714634, 38.473457540784565, 39.095567975725444, 40.72100176130022, 35.34868935176304, 38.08334745679583, 38.105102266584126, 37.78651693889073, 37.64881753921509, 36.725523539951865, 36.83539540427071, 36.64426435743059, 41.5776903288705, 37.37725067138672, 46.97265386581421, 41.34271962302071, 42.49611364092146, 47.71513489314488, 47.154443059648784, 49.1988844871521, 48.75220911843436, 51.711221081869944, 50.42968143735613, 47.90190594536917, 50.195085934230256, 51.93757949556623, 50.80421018600464, 52.28524998256138, 52.90030104773385, 51.20043815885271, 52.02717651639666, 51.313725062779014, 52.084943839481895, 53.387678963797434, 43.22369425637381, 44.655523436410085, 45.506670815604075, 42.8012090410505, 40.10339723314558, 41.25231661115374, 40.22317028045654, 42.64137268066406, 43.3949430329459, 43.700767993927, 43.43794890812465, 47.430738176618306, 47.85885490689959, 46.56166444505964, 46.17318371364048, 46.096677098955425, 47.320828097207205, 45.06917054312569, 49.0448568207877, 46.925479071480886, 47.75881821768624, 47.46412427084786, 54.500610147203716, 63.3055237361363, 65.2176262991769, 67.43830530984062, 69.95086424691337, 65.88140160696847, 69.615877696446, 68.8150908606393, 72.66310746329171, 66.73860781533378, 70.0728954587664, 4.377738577978952, 2.4650532347815375, 71.52827903202602, 45.751956122262136, 30.78450107574463, 38.000354698726106, 35.87420245579311, 33.369453293936594, 62.197828020368306, 10.043603692735944, 0.22472048444407328, 0.10997493378818035, 0.10241610796323844, 0.08777683028685195, 0.03142687864601612, 0.08267780247011355, 0.03910814950774823, 0.05821032502821513, 0.034318028150924614, 0.19062404547418865, 0.4430173050080027, 0.31916352095348494, 0.1505116064633642, 0.1223954087389367, 0.1631299015134573, 0.21660175866314343, 0.15161271952092648, 0.2384003203894411, 0.4546765722334385, 6.557709830147879, 74.10751983097622, 60.19639246804373, 42.25055040631975, 37.918393748147146, 63.58462592533657, 61.536602701459614, 76.89306654248918, 54.953775133405415, 1.1802883233342851, 43.081419467926025, 81.53620719909668, 69.18466554369245, 73.828688621521, 67.70557471684047, 69.82007135663713, 66.11735548291887, 60.68231473650251, 53.084615911756245, 56.00350897652762, 52.25893020629883, 55.31000232696533, 55.99191243307931, 51.98436519077846, 52.72142662320818, 51.81320326668875, 48.37561675480434, 48.8480977330889, 47.27953495298113, 46.75180537360055, 46.63856710706438, 46.0158417565482, 46.15520177568708, 46.84697137560163, 44.454675333840505, 43.25614929199219, 41.29264742987496, 46.13562870025635, 47.134550367082866, 49.81337969643729, 47.722746644701274, 49.31398834500994, 49.923567703792024, 55.509943689618794, 54.132254873003276, 54.51106718608311, 54.31364107131958, 52.61307988848005, 53.693761008126394, 54.12469175883702, 53.610135963984895, 57.2882204736982, 53.01207324436733, 54.36818790435791, 51.065716062273296, 53.23823710850307, 56.854791845594136, 56.024926798684255, 54.165602752140586, 50.991926193237305, 59.49648652757917, 50.36011607306344, 58.549349784851074, 23.77041619164603, 36.43924733570644, 49.40054900305611, 34.43380962099348, 44.19198478971209, 40.242121492113384, 42.27340650558472, 40.18267617906843, 41.14425127846854, 40.83500780378069, 38.810604981013704, 42.75165448869978, 43.663133076259065, 41.25136470794678, 40.923368045261924, 41.393556118011475, 44.996009486062185, 41.139936447143555, 43.42348623275757, 42.81772838320051, 44.38497795377459, 37.75353036608015, 40.83414275305611, 41.34369237082345, 42.55096272059849, 40.369190147944856, 40.05635098048619, 39.42067418779646, 38.9105270249503, 44.668797969818115, 38.94676882880074, 46.8177889415196, 46.641888345990864, 45.815719740731375, 49.581236907414024, 49.28436470031738, 51.804434640066965, 54.151984282902305, 54.52825355529785, 54.933760847364155, 51.218500001089915, 51.132060936519075, 55.32198102133614, 52.42220592498779, 54.36422048296247, 55.13395929336548, 53.26577629361834, 51.96862404687064, 51.0688601221357, 52.805791650499614, 54.80914837973458, 43.73947293417794, 46.375060149601524, 49.34563044139317, 45.38581732341221, 42.34435108729771, 44.73588282721383, 41.740712438310894, 46.36005898884365, 44.594083990369526, 47.01476342337472, 44.21777650288173, 51.63171284539359, 52.095168113708496, 47.859765120915, 48.26256956372942, 49.727145603724885, 51.75022826875959, 47.8664527620588, 51.0051486151559, 49.476656096322195, 49.44956854411534, 51.005628040858674, 57.735642773764475, 64.9143374306815, 66.5744149344308, 71.50736495426723, 73.8221573148455, 67.0454889025007, 70.43093613215855, 71.79126140049526, 75.03386756352016, 68.91848005567277, 73.53707272665841, 6.34376437323434, 2.9438831295285905, 77.47661100115094, 50.39726461683001, 42.60402611323765, 41.18016651698521, 41.11185877663748, 45.753884247371126, 74.3907492501395, 17.593570130211965, 0.4124469682574272, 0.3598144996379103, 0.23968657851219177, 0.12887810516570294, 0.10034731575953108, 0.1993787485573973, 0.11604073829948902, 0.12332872008638722, 0.12327238810913903], [0.0353116035860564, 0.1983700655400753, 0.019593373805816685, 0.04488118990723576, 0.03823086818946259, 0.1187733073851892, 0.08979087828525475, 0.1417195432420288, 0.07680204883217812, 0.04789569029318435, 0.0830833153533084, 31.1957197870527, 49.08740758895874, 31.8006785937718, 27.723866496767315, 47.48411423819405, 42.95986073357718, 53.93672909055437, 54.52573830740792, 2.2444223080362593, 40.09440973826817, 67.93291282653809, 59.626591546194895, 61.29456915174212, 57.848526682172505, 57.27547747748238, 55.61061266490391, 52.50987482070923, 50.48531566347395, 51.37123530251639, 50.42200367791312, 50.1841390473502, 51.08881187438965, 47.66060890470232, 47.339195660182405, 45.53361245564052, 45.34625775473458, 41.80870056152344, 42.12913758414132, 41.426664284297395, 40.900911467415945, 42.99621023450579, 43.87363917487008, 41.47955744607108, 42.22992467880249, 39.007218156542095, 36.29610054833548, 37.89763947895595, 42.66344015938895, 42.66990545817784, 43.62217691966465, 42.61231184005737, 47.54560579572405, 52.93849876948765, 50.4097192628043, 50.639100142887656, 51.171283517565044, 47.5412596975054, 50.47507749285017, 51.505682945251465, 50.68724421092442, 50.83977106639317, 48.54528134209769, 46.40423216138567, 45.729315417153494, 51.37901381083897, 56.251045499529155, 52.122290406908306, 55.57485376085554, 48.72517020361764, 51.866610595158164, 45.96087108339582, 52.95645638874599, 27.31062933376857, 21.144113506589616, 48.154830796378, 35.07279028211321, 35.75774022511074, 35.74275990894863, 35.08887536185128, 34.14116539273943, 35.252599239349365, 33.77652393068586, 35.240318298339844, 36.32939631598336, 38.46643986020769, 39.54485934121268, 42.128314222608296, 39.14163800648281, 41.49338436126709, 38.716460364205496, 33.81940821238926, 34.75592115947178, 35.71405690056937, 34.21357257025582, 40.24681152616228, 36.59674562726702, 34.632125105176655, 34.335371017456055, 35.37991803033011, 35.50111893245152, 35.761853558676584, 41.055967467171804, 43.56431232179914, 50.45625482286726, 28.458145175661357, 44.085805892944336, 46.530616419655935, 46.35310731615339, 48.593581744602744, 50.331197670527864, 48.24033532823835, 44.94113956178938, 41.85709823880877, 48.614937032972065, 49.43283380780901, 49.74483919143677, 49.146349157605854, 50.03017738887242, 50.06761428288051, 48.765327317374094, 50.03353336879185, 50.4876572063991, 48.638585226876394, 39.0540976524353, 43.69596331460135, 43.68525266647339, 40.031191553388325, 39.6788900920323, 37.77873843056815, 35.88705314908709, 40.32771635055542, 42.08706971577236, 40.02205119814192, 40.5407828603472, 43.416656153542654, 46.30780853543963, 44.03102282115391, 41.07340397153582, 41.94139378411429, 45.06918791362217, 43.74752242224557, 46.23657560348511, 44.22178908756801, 44.25894110543387, 45.80010713849749, 49.639653887067524, 57.58861541748047, 63.48701763153076, 60.14170319693429, 65.09440694536481, 64.11209842136928, 64.15940175737653, 62.105924197605674, 68.10877173287528, 61.647377831595286, 63.457487787519185, 2.0587471170084815, 3.401302150317601, 63.31584875924246, 33.3168762751988, 32.956608704158235, 30.048308168138774, 38.465574809483115, 37.06417179107666, 45.07801907403128, 4.58996479000364, 0.13756922951766423, 0.16791141565356935, 0.15869256747620447, 0.03838659876159259, 0.09121863131544419, 0.06465299467423133, 0.09080143405922822, 0.09476940506803137, 0.10753009747713804, 0.03402406642479556, 0.05239233507641724, 0.019427818046616654, 0.04817275310467396, 0.041644669470510313, 0.13946429640054703, 0.028524017626685754, 0.049699558676885705, 0.023656088659273725, 0.025011253709505712, 0.0744158990148987, 36.34479699816023, 55.464717864990234, 29.756146839686803, 36.81764275687081, 55.74456351143973, 45.38551507677351, 60.1051139831543, 60.2038756779262, 3.6479922958782742, 44.47088895525251, 74.91827038356236, 63.63918318067278, 66.83528505052838, 60.8099114554269, 59.72930676596505, 57.4584687096732, 56.273529870169504, 53.271664891924175, 54.953670910426546, 53.29490661621094, 52.77032804489136, 52.94498838697161, 51.062912464141846, 49.08564969471523, 49.11107662745884, 47.362030914851594, 44.93645995003836, 45.34183175223214, 44.936077799115864, 43.59094476699829, 47.17492634909493, 45.12250491550991, 45.35904244014195, 43.97787605013166, 41.831087657383506, 37.41885995864868, 41.40463849476406, 45.1683942931039, 45.27603925977434, 47.35566636494228, 46.78759554454258, 48.07270656313215, 54.194364820207866, 52.41963856560843, 52.1388201713562, 53.32602064950125, 48.991119452885215, 52.2366612298148, 53.19420289993286, 54.288742201668875, 53.20927701677595, 48.80755499431065, 51.39176375525338, 49.7538058417184, 53.73474495751517, 58.44463348388672, 54.051433426993235, 57.593166487557546, 51.55239915847778, 53.95496463775635, 48.79021576472691, 54.76973819732666, 33.26635939734322, 32.91417258126395, 48.73798268181937, 37.44249078205654, 37.12244633265904, 37.272954736437114, 39.54562364305769, 36.81928947993687, 36.64236749921526, 37.27700901031494, 37.10130991254534, 37.572769505637034, 40.308442047664094, 41.20422118050711, 43.379285267421174, 39.531522274017334, 43.460940497262136, 39.85844196592058, 36.41372660228184, 38.36964797973633, 37.84344700404576, 36.28614377975464, 39.9792537689209, 38.61659737995693, 37.28500986099243, 36.45728138514927, 37.411255155290874, 37.22793735776629, 38.033567087990896, 41.395168100084575, 43.32212591171265, 51.50447048459734, 36.69832829066685, 43.1999522617885, 49.896230016435894, 48.510609831128804, 50.8673415184021, 51.249825954437256, 50.336162158421104, 46.44778347015381, 46.813804149627686, 49.90129177910941, 51.64847190039498, 51.952288831983296, 51.73406328473772, 51.62616123471941, 54.18840673991612, 49.93836041859218, 53.059473855154856, 52.533290249960764, 49.380889075142996, 41.39562668119158, 45.13927091870989, 46.67688642229353, 42.552414894104004, 40.28127459117344, 41.584089619772776, 39.98962048121861, 42.92597784314837, 43.48600264957973, 42.999920572553364, 43.27868577412197, 45.390826974596294, 46.30803435189383, 46.0007016318185, 45.212654318128315, 45.27966969353812, 48.07298796517508, 45.748447281973704, 47.84532676424299, 47.25169004712786, 46.08611236299787, 48.07816437312535, 53.69437939780099, 60.12772342136928, 66.19166646684918, 65.67455373491559, 69.90085111345563, 66.72350937979562, 68.06006486075265, 65.30748040335519, 73.26641954694475, 64.11455808367047, 66.72960989815849, 1.6471608025687081, 5.226267354828971, 75.85759735107422, 38.49930831364223, 40.025796277182444, 38.85130752835955, 43.38817548751831, 39.775410992758616, 56.45482226780483, 5.783648805958884, 0.2546636919890131, 0.03461748940337982, 0.10048634079950196, 0.07758927159011364, 0.028894796302275996, 0.03823196402351771, 0.06514528540096112, 0.06954046205750533, 0.04101435454296214, 0.20870119546140942, 0.27793513610959053, 0.0912423257582954, 0.11732700999294009, 0.14535095409623214, 0.28572469098227365, 0.11021525053573505, 0.15766420694334166, 0.131793471585427, 0.1527509077319077, 0.3209479594869273, 53.711742946079795, 64.26988506317139, 46.66398709160941, 41.53229774747576, 61.67210647038051, 53.69568913323538, 62.88251740591866, 64.4776223046439, 3.6686423420906067, 47.740506240299766, 80.20703070504325, 67.99560642242432, 68.4264225278582, 63.88783836364746, 61.02269308907645, 59.533728872026714, 57.97456700461251, 55.768715449741904, 56.194372517721995, 53.642455509730745, 54.92401599884033, 55.296627044677734, 53.34877252578735, 51.961856501443044, 50.70859602519444, 50.12891476494925, 48.21483196531023, 47.71432890210833, 47.41273886816842, 45.075604575020925, 49.40269252232143, 48.42138106482369, 47.03183862141201, 46.48581790924072, 43.7173741885594, 38.910902227674214, 42.47616536276681, 47.40876449857439, 46.79476955958775, 48.81990194320679, 47.514936447143555, 50.11574445452009, 57.177938665662495, 54.26746334348406, 55.15610320227486, 55.12581253051758, 51.364217621939524, 54.91016476494925, 54.074911390032085, 55.57233156476702, 55.89161171231951, 51.76668855122158, 51.034973757607595, 51.62970134190151, 55.71021161760603, 62.20923696245466, 55.74136734008789, 59.40296377454485, 52.71993276051113, 57.455772808619905, 51.40619516372681, 60.71133041381836, 31.574577263423375, 26.057559932981217, 52.07038736343384, 39.041639532361714, 39.8195390020098, 39.6625896181379, 41.959938526153564, 38.26889215196882, 39.16283696038382, 39.609557492392405, 41.01278788702828, 40.34713656561715, 43.445967129298616, 44.31448153087071, 44.933374949863975, 42.808247566223145, 45.934450558253694, 41.72345658711025, 39.456050940922324, 41.751228536878315, 40.830731187547954, 37.98278270448957, 43.997007914951865, 42.771898065294536, 39.98205041885376, 39.32277059555054, 39.34267371041434, 42.43978112084525, 39.8220785685948, 42.400454316820415, 46.1461934362139, 51.1644777570452, 40.09858560562134, 48.9467065674918, 51.911092962537495, 49.33139705657959, 54.04436363492693, 56.14022173200335, 54.89006015232631, 49.205474853515625, 47.98136901855469, 51.92266171319144, 54.03497314453125, 53.99291222436087, 54.465639863695415, 53.677648135593955, 57.20554385866438, 50.7411379132952, 54.313182490212576, 53.59041697638375, 51.012652669634136, 40.713355268750874, 46.569231033325195, 47.754458223070415, 45.381078651973176, 44.383063725062776, 45.39210196903774, 40.586442947387695, 46.36535004207066, 45.97963121959141, 45.29519196919033, 44.984312193734304, 49.756130014147075, 49.97743361336844, 50.687456130981445, 48.3975487436567, 48.262951714651926, 51.920723165784565, 49.4509790284293, 51.751430307115825, 51.38987384523664, 47.64993299756731, 50.56399359021868, 55.66631637300764, 62.40194525037493, 68.75018078940255, 68.44115270887102, 71.85993044716972, 68.14925193786621, 69.27148328508649, 65.70063032422746, 76.30036435808454, 66.32512051718575, 72.62573310307094, 3.0757425682885304, 4.579137759549277, 81.13171781812395, 44.755049433027, 47.99967057364327, 41.9133300100054, 54.16202442986624, 50.02514341899327, 66.12800012316022, 9.851507714816503, 0.35737945458718706, 0.3168011334325586, 0.23980847054294177, 0.18468862825206347, 0.15458901838532516, 0.18083707349640982, 0.14366277254053525, 0.09395200107246637, 0.14286577887833118], [0.052960967778095176, 0.09603272870715175, 0.10571099937494312, 0.18183734267950058, 0.09309985608394657, 0.09897126031241246, 0.03870771545916796, 0.1439101935497352, 0.022855822761942233, 0.10629016972546067, 0.1833664756268263, 14.912128278187343, 53.76290600640433, 44.089432852608816, 28.327063935143606, 40.411233697618755, 48.06579310553414, 48.98174633298601, 60.49864605494908, 4.810238753046308, 36.13481201444353, 68.88949217115129, 59.78949901035854, 61.781012535095215, 55.530576365334646, 54.293546880994526, 52.620139258248464, 50.398035866873606, 51.08403498785836, 51.29606621606009, 52.3564064843314, 53.05164670944214, 49.74988010951451, 48.12142038345337, 47.0522072655814, 42.62544393539429, 43.84342840739659, 42.95405898775373, 43.60364607402256, 42.50266579219273, 42.5096105166844, 41.10504954201834, 43.15410109928676, 40.74707835061209, 42.01326595033918, 40.507157053266255, 38.104723589760916, 39.681665897369385, 45.086513246808735, 44.38954986844744, 43.32444313594273, 45.80991104670933, 48.95589903422764, 50.53323738915579, 51.80370855331421, 49.367930684770855, 48.717513288770405, 47.40331016268049, 49.75091191700527, 53.82816001347133, 52.46976981844221, 50.53975132533482, 50.40692956107003, 51.16991472244263, 50.71530103683472, 52.453483240945, 52.992267404283794, 51.8578975541251, 52.46463162558419, 49.23758595330374, 49.09862545558384, 46.996934345790315, 52.27918073109218, 34.2019100189209, 21.22556029047285, 43.442427022116526, 35.129501479012625, 38.01842696326119, 34.733534063611714, 36.580295767102925, 36.82241269520351, 36.798389298575266, 34.1573303767613, 35.371632303510395, 36.831212588718955, 42.31047167096819, 39.94238315309797, 38.10037749154227, 38.83136967250279, 40.70934615816389, 39.7082462310791, 36.77458129610334, 37.12548269544329, 36.84456007821219, 33.1566994530814, 35.322710037231445, 33.16863645826067, 34.296679973602295, 33.483622619083945, 33.94821739196777, 36.72023596082415, 44.346825395311626, 37.02049541473389, 43.133916582380024, 39.78352301461356, 31.435345785958425, 47.96512065614973, 45.479690960475374, 49.62884596415928, 46.906020641326904, 53.37991087777274, 49.37870734078543, 47.8377810205732, 43.12328931263515, 48.64998027256557, 49.76396410805838, 47.655654839106965, 49.95957326889038, 50.913626943315776, 50.86384310041155, 49.38495029721941, 49.98967981338501, 51.91511944362095, 47.235281876155305, 40.312207971300396, 43.41724327632359, 45.7839595249721, 40.18743569510323, 40.07954059328352, 36.78945738928658, 36.60118900026594, 38.86083003452846, 40.69706521715437, 41.465139933994834, 39.73498289925711, 42.59371151242937, 43.56527812140328, 40.26770823342459, 41.81629146848406, 42.368065289088655, 43.96091202327183, 41.32442849023001, 44.20664896283831, 43.7665604863848, 43.748595918927876, 48.05571821757725, 46.800467082432334, 54.69309261866978, 62.86893367767334, 62.89783123561314, 63.684693881443565, 62.914951596941265, 65.99599824632917, 62.9993930544172, 69.83234187534877, 61.90455845424107, 61.39786802019392, 0.5093633734754154, 11.453541704586574, 60.823147773742676, 28.621987172535487, 35.24689824240548, 28.552725791931152, 40.593266078404014, 38.91342789786202, 50.680862290518625, 2.4306996038981845, 0.06268269861383097, 0.04320960192541991, 0.023525625034900646, 0.15765588810401304, 0.02739592601678201, 0.04433523723855615, 0.07542306211377893, 0.0839997718908957, 0.06334625836461782, 0.045096051413565874, 0.012792368968283492, 0.03575693629682064, 0.0930643415610705, 0.04032502742484212, 0.08545294284288373, 0.04059321839096291, 0.29212835165006773, 0.07340686315936701, 0.20097266802830355, 0.2236798017152718, 17.83020840372358, 63.08313969203404, 42.38322973251343, 36.79612071173531, 49.692699909210205, 52.470416000911165, 52.62613902773176, 68.58017921447754, 6.718223639896937, 37.701304231371196, 74.49855055127824, 64.1916275024414, 66.91399424416679, 58.137568269457134, 58.982764516557964, 54.203592027936665, 53.50543703351702, 54.5791734286717, 56.61891787392752, 55.88373245511736, 54.559325899396626, 52.78937653132847, 50.75050755909511, 48.42271859305245, 47.14708144324166, 47.21368340083531, 46.29398162024361, 46.242172377450125, 45.65649482182094, 44.53010845184326, 44.91880457741873, 45.19815342766898, 43.98409468787057, 44.87236281803676, 44.574305943080354, 40.613867487226216, 41.263829776218955, 46.73089476994106, 47.227239336286274, 47.305562904902864, 46.766167300088064, 49.03032118933541, 51.19514710562569, 54.82861375808716, 51.769704069410054, 52.096436159951345, 51.14760753086635, 53.25547906330654, 54.41125978742327, 54.471900190625874, 52.96151467732021, 53.54831089292254, 52.969880308423726, 53.49552542822701, 52.89715698787144, 55.75022629329136, 53.52017763682774, 53.70654221943447, 51.759705611637656, 51.58266551154, 50.92909363337925, 52.970769677843364, 40.21959890638079, 30.8618449483599, 46.863334383283345, 36.87858540671212, 37.94167021342686, 37.39327669143677, 38.785532406398225, 37.95202650342669, 37.624186175210134, 36.68326112202236, 37.411616461617605, 37.358997753688264, 43.187382970537456, 41.96291235515049, 38.98070730481829, 37.40974044799805, 42.63814524241856, 40.76110676356724, 38.834513732365195, 37.42677395684378, 38.535129751477925, 36.374816690172466, 36.13524975095476, 36.255123547145296, 35.88514934267317, 37.148950236184255, 35.57145207268851, 39.59630380358015, 44.985024384089876, 38.60130092075893, 42.93613958358765, 47.608250754220144, 35.63844312940325, 48.12077072688511, 50.881092003413606, 51.9348349571228, 49.37079681668963, 53.67451102393014, 53.15801668167114, 51.64120061056954, 47.1146194594247, 50.43782820020403, 52.54789188929966, 51.53530658994402, 52.575302532741, 52.696545124053955, 52.91098042896816, 52.811193874904085, 51.687037876674104, 54.57092244284493, 49.96705995287214, 40.629636423928396, 46.21896539415632, 47.47234746388027, 42.70311437334333, 42.22403608049665, 40.80497421537127, 39.37493767057146, 40.4379425730024, 43.577270712171284, 43.34599297387259, 41.86345584051949, 44.0830648286002, 45.36099835804531, 43.13379151480538, 46.045312540871755, 45.08829893384661, 45.60689510617937, 44.55255460739136, 46.9996371950422, 47.64467321123396, 46.5971280506679, 49.900888783591135, 50.0622433253697, 57.37035165514265, 66.9740058353969, 65.48541682107108, 67.38391481127057, 67.78635447365897, 70.58856296539307, 66.29378414154053, 73.014130456107, 64.5315055847168, 64.65940107618059, 0.4932836134518896, 14.391043782234192, 69.47109113420758, 32.90847158432007, 43.85221093041556, 33.426178387233186, 39.32631765093122, 45.26808704648699, 59.26278386797224, 2.675957117761884, 0.1897890402802399, 0.005864346616103181, 0.07567225409937756, 0.07315413600632123, 0.046440344636461565, 0.051397100623164854, 0.034053782865937264, 0.011297507976580943, 0.01432863247048642, 0.19728822287704262, 0.15249881840177945, 0.11189887233610664, 0.20597094696547302, 0.3221769221127033, 0.17350204209131853, 0.17421005267117703, 0.4307394309767655, 0.11081010183053357, 0.2690806340958391, 0.29825533287865774, 28.50327025141035, 73.01404012952531, 58.04979862485613, 39.58182723181588, 52.483391761779785, 63.548717635018484, 58.054860387529644, 71.89593601226807, 6.807264370577676, 42.676634788513184, 79.24642140524728, 69.28027275630406, 70.11311858040946, 61.358992849077495, 60.872966357639854, 55.52888100487845, 55.6062387738909, 53.39774342945644, 57.46040725708008, 56.78740126746041, 57.42278970990862, 55.252936771937776, 53.30571453911917, 50.58477217810494, 47.04470321110317, 48.52227585656302, 46.90203237533569, 48.33745724814278, 46.70463057926723, 47.44528770446777, 47.44883475984846, 48.024044854300364, 47.6049781526838, 45.60059309005737, 45.5490756716047, 43.15139825003487, 43.79293237413679, 51.8044068472726, 49.4861056464059, 48.3678104536874, 51.143424715314595, 51.40818582262312, 53.64377566746303, 58.65460804530552, 52.7233373778207, 54.47348437990461, 53.304078238351, 54.529431274959016, 57.50082492828369, 57.15505824770246, 55.623154163360596, 55.673052651541575, 54.494683333805625, 56.95547124317714, 56.24797786985125, 59.081776346479145, 55.83255202429635, 57.575868947165354, 53.958049637930735, 55.01653126307896, 51.349244253976, 58.766182218279155, 38.75547449929373, 25.775259835379465, 46.976499693734304, 38.54979739870344, 42.627775056021555, 40.49460860661098, 41.83527742113386, 39.821133613586426, 41.05637046269008, 39.371421882084434, 39.7573595728193, 40.985773290906636, 48.80379254477364, 43.99200521196638, 41.92473895209176, 40.671818937574116, 43.80292388371059, 42.5822365624564, 39.90535620280674, 39.78953668049404, 41.35129370008196, 37.56477560315813, 40.235572814941406, 38.54564585004534, 38.03911869866507, 40.15436921800886, 38.69288512638637, 42.1508333342416, 48.301194599696565, 41.94558007376534, 44.248536178043906, 45.451026167188374, 37.03569459915161, 51.20289087295532, 50.48024000440325, 54.18448448181152, 51.63883127485003, 57.59492438180106, 55.690666334969656, 52.53823389325823, 49.38888645172119, 53.55083308901106, 56.59336239950997, 52.16793312345232, 53.863328320639475, 55.93016726630074, 55.83445930480957, 54.74642351695469, 53.81057759693691, 55.88011244365147, 51.802298069000244, 42.184316703251426, 47.0336868422372, 52.639177322387695, 47.677753584725515, 45.47062356131417, 44.234542506081716, 41.87426723752703, 44.03079700469971, 46.40127917698452, 47.0804169518607, 43.38551780155727, 48.561342103140696, 48.586859362465994, 45.30177191325596, 49.329003402165, 48.545913628169465, 49.01167917251587, 47.47046102796282, 50.553227356501985, 50.03958872386387, 49.10836335590908, 54.26513917105538, 52.542750222342356, 60.31398378099714, 69.65397466932023, 70.11438315255302, 72.70239952632359, 69.24353068215507, 72.58259868621826, 69.09880665370396, 73.53780228751046, 65.5120631626674, 68.8012500490461, 1.3373626662152154, 14.306831615311758, 76.89435195922852, 38.85100875582014, 49.32246514729091, 42.692740712847026, 59.483618463788716, 51.660214356013704, 73.58207620893205, 4.790728645665305, 0.3891244711620467, 0.21892631107142993, 0.19368499836751393, 0.17626844293304852, 0.1411879246256181, 0.1393482397709574, 0.0875587694879089, 0.12920012431485312, 0.14464740827679634], [0.049166521922286065, 0.08944215878312077, 0.06752886357051985, 0.05239303736016154, 0.10836073969091688, 0.07219238047088895, 0.07421068966920887, 0.06652453674801759, 0.05725323102836098, 0.1181452146598271, 0.3493991499500615, 5.795323516641345, 56.16843836648123, 37.30736221585955, 36.45480782645089, 32.36618552889143, 41.16467203412737, 41.96838753564017, 68.31617546081543, 9.466110246522085, 24.19664474896022, 69.09236567361015, 54.86928503853934, 63.47899941035679, 59.528295380728586, 57.23406621388027, 52.079482555389404, 54.142493043627056, 53.20774841308594, 51.92066410609654, 52.68809264046805, 52.53514889308384, 49.326588903154644, 49.74677079064505, 45.91201482500349, 45.95118876865932, 44.0760679926191, 46.52131972994123, 48.82626649311611, 46.12529672895159, 44.556000913892476, 42.1990955216544, 43.195752075740266, 42.33191728591919, 41.97353267669678, 40.70394393375942, 38.17132554735456, 36.78395789010184, 40.927227769579204, 43.04276316506522, 44.37061950138637, 44.16805171966553, 48.43315826143537, 47.252475193568635, 49.840776443481445, 49.04424885341099, 46.05835778372628, 49.314585890088765, 48.62419898169381, 51.79454387937273, 51.36196640559605, 51.090413434164866, 49.35498966489519, 50.93111208506993, 52.6350222996303, 52.836912631988525, 53.53291368484497, 53.21240718024117, 51.934932231903076, 49.35443033490862, 50.299420084272114, 49.92840712411063, 53.334719794137136, 40.94604696546282, 23.818112100873673, 43.10708958762032, 40.45817225319998, 36.54637466158186, 36.602564743586946, 35.461326599121094, 37.05527114868164, 34.81108290808541, 35.85515744345528, 34.28118896484375, 37.59313814980643, 39.47169828414917, 35.12440150124686, 37.801101207733154, 37.820952211107524, 36.38202544621059, 38.738440990448, 37.64491959980556, 36.74043090002877, 35.07824114390782, 38.92621258326939, 36.27244193213326, 28.668564421789988, 36.07835790089199, 30.96827745437622, 39.114984716687886, 39.797944000789094, 37.10709776197161, 30.904795237949916, 47.08050380434309, 38.47009113856724, 35.29280499049595, 48.55626644407, 46.71800238745553, 48.10024227414812, 48.76269047600882, 49.8071471623012, 48.75378288541521, 48.23700714111328, 46.5414034979684, 47.8169572693961, 49.211929730006624, 49.0669903073992, 49.93938527788435, 51.6684444972447, 46.51288461685181, 48.45756033488682, 50.13690519332886, 50.89737163271223, 42.667272090911865, 41.53685923985073, 44.058329241616384, 45.67270496913365, 39.97550174168178, 39.122718061719624, 35.61316210883004, 38.13069943019322, 41.12025220053536, 41.04700081689017, 40.87336533410208, 42.021954672677175, 41.670733656202046, 43.09325572422573, 41.50108296530587, 41.66677665710449, 40.984373228890554, 44.58030571256365, 41.07723937715803, 45.00049802235195, 45.434545040130615, 44.241820744105745, 45.30375214985439, 47.10405819756644, 51.92061199460711, 63.19477639879499, 59.049522808619905, 62.89288411821638, 59.18401214054653, 65.59178679330009, 61.87555667332241, 70.21146338326591, 64.99105943952287, 52.45064837591988, 0.15885598585009575, 20.53773900440761, 61.39904921395438, 34.8235445022583, 32.07121018001011, 43.45964118412563, 49.994109289986746, 39.90601975577218, 41.6229578426906, 0.9645324264253888, 0.07745953569454805, 0.15563062392175198, 0.048395132779010704, 0.035754273046872447, 0.03914158432079213, 0.055563149574611864, 0.08868680681501116, 0.030309555386858325, 0.13182511845869677, 0.039314471650868654, 0.10915832367858716, 0.029952045463557755, 0.11277064055736576, 0.07922572163598877, 0.0076352136010038, 0.09961920018707003, 0.0696573532851679, 0.03642767834077988, 0.08651799854955503, 0.193021472543478, 8.201569369861058, 67.72367477416992, 37.01730619158064, 39.189167158944265, 41.63028471810477, 48.485252380371094, 45.473965644836426, 76.84808390481132, 12.286928619657244, 24.758286748613628, 75.7163474219186, 58.51427527836391, 66.95526654379708, 60.87632233755929, 62.71110534667969, 55.82258135931832, 58.52057729448591, 56.386677810123985, 56.12225716454642, 54.276669706617085, 56.4941143308367, 53.042895453316824, 51.7730461529323, 49.2774338722229, 48.206688676561626, 46.97309855052403, 48.83628579548427, 52.51134783881051, 48.878725392477854, 46.41962242126465, 45.39017384392874, 45.931615693228586, 46.235922472817556, 45.19955696378435, 44.49413415363857, 40.61084849493844, 40.30347408567156, 43.72612197058541, 46.4504828453064, 46.62135641915457, 47.022385597229004, 51.55209343773978, 49.50572388512747, 50.39536428451538, 52.34769344329834, 47.148012501852854, 49.94138288497925, 52.73164742333548, 52.30494465146746, 53.38873161588396, 53.447235448019846, 52.173123427799766, 53.45024749210903, 53.201717376708984, 56.67890862056187, 55.423341342381065, 52.388583592006135, 54.702340670994346, 51.31768206187657, 52.96916464396885, 50.71535314832415, 52.95015089852469, 43.16807740075247, 32.72437906265259, 45.83970144816807, 42.44687523160662, 37.39072322845459, 37.62806674412319, 37.23873833247593, 39.42806707109724, 37.97054345267159, 37.23022331510271, 36.54751764025007, 38.954463958740234, 38.552903243473594, 37.024977002825054, 35.92240558351789, 37.28903634207589, 39.09788867405483, 36.988696983882356, 36.86089529309954, 42.05224881853376, 38.44589056287493, 37.78216389247349, 37.771807602473665, 32.003468717847554, 38.644980771201, 34.512789794376914, 41.99704885482788, 42.84599365506853, 37.430199418749126, 32.05889449800764, 50.17687470572335, 50.71273020335606, 36.783579213278635, 52.729653290339876, 50.256577491760254, 49.804930686950684, 49.67803921018328, 52.09778758457729, 51.69002907616751, 51.06349958692278, 49.15088285718645, 50.50723723002842, 51.56953689030239, 51.66897603443691, 51.39940677370344, 51.81702477591378, 49.00062458855765, 51.043711117335725, 50.59978028706142, 53.48151785986764, 43.808020387377056, 41.47407879148211, 47.16619941166469, 46.24485438210623, 40.894533021109446, 40.95156036104475, 36.77833679744175, 39.54239273071289, 42.82342938014439, 43.999933106558665, 43.78333691188267, 43.430583817618235, 43.497324739183696, 45.62188931873867, 45.11140864236014, 44.87331472124372, 45.73513453347342, 47.828849111284526, 45.481150082179475, 46.12754794529506, 48.00977325439453, 47.84042133603777, 48.95975875854492, 51.105470180511475, 54.857017993927, 64.93791266850063, 62.83711787632534, 65.76596423557827, 64.95456750052315, 69.15477439335415, 64.7335591997419, 73.86745956965855, 67.94943564278739, 53.313072681427, 0.22752181626856327, 25.714857407978602, 69.12704413277763, 41.71459068570818, 37.06954969678606, 38.34227902548653, 52.62485013689314, 44.235699381147114, 50.8644232749939, 2.1759931913443973, 0.09450002666562796, 0.052586888029639206, 0.08806493625577007, 0.022998449126524583, 0.06938469077327422, 0.08459611596273524, 0.13875792787543365, 0.011982810533871608, 0.14498777501285076, 0.09048731305769511, 0.2910735011100769, 0.1981591090027775, 0.11576418099658829, 0.1850511288004262, 0.18569436642740453, 0.16317123786679336, 0.20319826288947038, 0.16957811479057583, 0.36217205598950386, 0.553686257983957, 11.50574265207563, 78.33627687181745, 49.54330669130598, 47.75716454642159, 44.54880258015224, 55.163197313036235, 51.301728997911724, 82.37629999433244, 12.09324584688459, 29.183396407536097, 79.9623498916626, 64.13878645215715, 70.81385135650635, 64.26087324959892, 63.0262131009783, 56.774970940181184, 60.53142070770264, 57.71085854939052, 57.858309745788574, 55.578828130449565, 59.61122213091169, 55.695345946720664, 53.54128973824637, 52.366519587380544, 50.953165667397634, 49.95037732805525, 50.410441875457764, 53.86109447479248, 50.122977529253276, 48.757138865334646, 48.221814904894146, 49.72345263617379, 48.65100165775844, 47.6212751524789, 46.67188719340733, 42.47018643787929, 41.30375759942191, 45.62756947108677, 50.04900353295462, 48.13759231567383, 49.63246597562517, 55.09693234307425, 52.01633037839617, 52.847803933279856, 54.69437803540911, 49.38225787026541, 53.482726846422466, 54.489975929260254, 54.494023254939485, 55.30951942716326, 55.95373903002058, 54.11028814315796, 54.87695584978376, 56.776885168892996, 57.5022006716047, 57.95761340005057, 57.40756273269653, 57.67402614865984, 53.276570320129395, 55.26109743118286, 52.75912407466343, 58.22359044211251, 44.89770289829799, 29.237422125680105, 49.64299597058977, 44.24476678030831, 40.279766832079204, 40.62853513445173, 39.61921548843384, 41.6879825592041, 40.31256927762713, 39.99624558857509, 38.80496999195644, 41.83138295582363, 43.84845890317644, 38.487829889569966, 36.07195513589041, 38.558409690856934, 39.41220433371407, 39.83051715578352, 40.20129040309361, 44.15060479300362, 43.43162257330758, 41.97084024974278, 39.40029512132917, 36.58229684829712, 41.06304768153599, 37.57006318228585, 43.50258799961635, 45.08942454201834, 42.37874467032296, 33.773602213178364, 45.745445660182405, 44.282735211508616, 38.36742108208792, 52.35401630401611, 51.6719776562282, 52.29074253354754, 52.63314281191145, 55.5351482800075, 54.46740123203823, 52.97751290457589, 52.04539816720145, 53.04443447930472, 54.83923755373274, 53.12651702335903, 54.056269373212544, 53.303102016448975, 50.052529743739534, 52.17372097287859, 52.792131492069785, 55.72073813847133, 46.48638071332659, 42.21932520185198, 49.446421010153635, 49.73855454581124, 43.935294015066965, 44.463437012263704, 40.169689995901926, 43.11259256090437, 45.71823998859951, 45.909388405936106, 46.30456025259835, 46.1361984525408, 48.7648583139692, 49.81792729241507, 47.8860501561846, 48.716147967747276, 47.97622387749808, 51.634808267865864, 47.75782115118844, 50.45901673180716, 54.21643577303205, 50.06027698516846, 51.63327619007656, 54.87909242085048, 58.91099657331194, 69.01679706573486, 65.23119613102504, 70.76977893284389, 68.23201193128313, 71.93617303030831, 65.26721559252057, 77.7879250390189, 67.55650806427002, 59.255884306771414, 0.562797626214368, 25.462061098643712, 79.17293725694928, 46.76223809378487, 44.72740602493286, 58.46107986995152, 68.8950229372297, 49.03450400488717, 65.05032062530518, 3.0099355280399323, 0.21911410242319107, 0.29915365896054674, 0.20202327093907765, 0.15500616814408982, 0.15891822108200618, 0.24996812109436306, 0.2257371334625142, 0.07167578461979117, 0.293681192610945], [0.024409316812774966, 0.09383928962051868, 0.03855966590344906, 0.08043700163917882, 0.054862273790474446, 0.058555394011948786, 0.21725429221987724, 0.04975439448441778, 0.12821304585252488, 0.06807636669171707, 0.17052921732621534, 5.409579072679792, 51.90461376735142, 39.34552594593593, 36.44785267966134, 26.45223845754351, 42.40154865809849, 38.602555070604595, 69.95965371813092, 20.682522092546733, 12.78091253553118, 68.77741772787911, 56.28543560845511, 68.01066316877092, 58.675612449645996, 61.026104654584614, 57.49714585712978, 56.77292816979544, 55.652816023145405, 54.80490303039551, 51.9205390385219, 51.79141024180821, 49.69894981384277, 48.32217468534197, 45.34020587376186, 45.206178597041536, 46.10531023570469, 50.25725494112287, 48.8177375793457, 47.61724519729614, 47.984711102076936, 40.9224647794451, 42.13383804048811, 42.700536591666086, 41.109409536634175, 42.815192290714805, 38.57892772129604, 39.600750650678364, 40.40084266662598, 41.68605095999581, 44.17241518838065, 43.14296661104475, 50.16915873118809, 48.8045186315264, 49.02133022035871, 45.65546996252877, 46.27111162458147, 47.73178277696882, 49.536143098558696, 51.47924852371216, 51.12024899891445, 50.01815700531006, 50.75353697368077, 53.90748759678432, 53.49740491594587, 53.8234977722168, 54.38198702675955, 49.65263659613473, 50.97518450873238, 51.39436585562569, 48.73038830075945, 47.39975963320051, 51.522198813302175, 43.87864187785557, 30.9237916128976, 39.40979330880301, 42.750355175563264, 40.80603381565639, 34.40892812183925, 34.403338296072825, 35.55217776979719, 35.86162621634347, 34.8118576322283, 36.24586854662214, 37.11890622547695, 38.370853492191856, 40.129605838230674, 36.35202659879412, 38.379927839551655, 37.14998551777431, 42.30044542040144, 40.50976957593645, 40.34956496102469, 38.84998042242867, 39.13694102423531, 36.02479076385498, 29.9703563281468, 34.20156260899135, 36.18554081235613, 40.894154344286235, 35.05708040509905, 35.77701800210135, 37.26385607038225, 49.1741350037711, 27.318786518914358, 42.81342397417341, 49.35670239584786, 48.267624378204346, 48.87397977284023, 47.74974734442574, 51.33091490609305, 50.05684110096523, 46.932715620313374, 49.37759910311018, 50.20146438053676, 50.43817213603428, 47.69823340007237, 50.83801664624895, 46.661791460854666, 48.70206049510411, 50.74994822910854, 48.699006761823384, 53.04409749167306, 41.68474122456142, 40.22818340573992, 44.77280902862549, 42.9238725389753, 41.49912357330322, 39.45994540623256, 37.73679910387312, 39.32529279163906, 40.36744267599923, 42.280177525111604, 41.606633050101145, 41.0580449785505, 40.73941101346697, 42.279055391039165, 39.55296788896833, 40.0916999408177, 40.731114864349365, 42.68258592060634, 42.88586589268276, 44.68905544281006, 43.191027300698416, 44.631461824689595, 43.37220505305699, 45.28089257649013, 47.58302879333496, 55.596236842019216, 60.600124495370046, 60.69022873469761, 61.92795303889683, 60.17754895346505, 66.37789208548409, 66.36196681431362, 70.33750370570591, 41.28862789699009, 0.38100514827030046, 35.224069935934885, 56.652140685490195, 35.94587312425886, 31.60596922465733, 58.642803055899485, 41.005940437316895, 33.13677896772112, 50.78677715573992, 2.857582811798368, 0.06202986650168896, 0.3373305361185755, 0.058907662252230306, 0.18687032189752373, 0.04867619555443525, 0.07157016385878835, 0.15775211794035776, 0.02081112194407199, 0.03909915891875114, 0.016809085084657584, 0.018476310086303523, 0.08036259348903384, 0.008110697863490453, 0.09422369327928339, 0.032733380861048184, 0.14943217938499792, 0.12344666304332869, 0.1335622766720397, 0.09816917763756854, 0.21466897880392416, 5.516751561846052, 65.09823540278843, 41.50710705348423, 35.69298996244158, 31.32089853286743, 50.4243243762425, 44.64654983792986, 76.92048413412911, 25.32358523777553, 12.590481519699097, 73.97968687329973, 62.166630608694895, 69.23816667284284, 62.18188190460205, 65.67028059278215, 59.01720673697335, 59.67991897038051, 57.4361823626927, 58.003051144736155, 53.43052155630929, 54.52715573992048, 52.276901721954346, 50.682731355939595, 47.30263771329607, 48.233004978724885, 48.03828518731253, 52.244863578251426, 50.49756186349051, 49.85534681592669, 48.92104687009539, 44.89155374254499, 44.68325022288731, 45.76562670298985, 44.57469504220145, 45.228593485695974, 43.94899238858904, 42.48507295336042, 43.75801420211792, 45.09893315179007, 45.211382797786165, 44.04383529935564, 50.26158366884504, 50.25357239586966, 51.20873083387102, 48.31721019744873, 47.34967006955828, 50.759505476270405, 53.05539526258196, 52.9826545715332, 52.732561111450195, 52.41043220247541, 52.933940751211985, 55.497930254255024, 53.88706684112549, 55.20630046299526, 54.91941629137312, 51.87247140066964, 51.2173570224217, 53.99857153211321, 50.545903955187114, 48.2396821975708, 52.95766190120152, 47.089050088609966, 38.04175901412964, 42.08456489018032, 43.55986894880022, 40.628326688494, 35.223837171282085, 36.08367327281407, 36.81762538637434, 37.29671062741961, 36.826918601989746, 37.23429843357631, 36.10028294154576, 39.9698737008231, 39.90047509329659, 37.06022868837629, 39.31336273465838, 37.89569398335048, 43.369870458330425, 41.43072550637381, 39.675825936453684, 41.57974352155413, 40.618633951459614, 41.037790979657856, 33.42144318989345, 37.54847512926374, 38.916707447596956, 44.94520425796509, 35.30289724894932, 39.66956213542393, 33.28708239964077, 61.02824469975063, 41.2156058038984, 41.10131141117641, 52.91616031101772, 49.295738901410786, 50.525351183755056, 49.986855370657786, 56.06473650251116, 53.665377616882324, 51.26006065096174, 49.91788755144392, 53.39904274259295, 50.99120010648455, 52.417720862797324, 52.65821886062622, 51.66817004340035, 49.2423107283456, 50.410049302237375, 51.48133993148804, 54.20982108797346, 42.31337949207851, 42.99140902927944, 47.54985809326172, 47.36797857284546, 41.150278840746196, 42.16563299724034, 37.883534635816304, 41.47140026092529, 42.30079630443028, 44.386426653180806, 44.73505251748221, 44.03696700504848, 42.99230882099697, 46.99798699787685, 44.28324243000576, 44.057832445417134, 43.979335171835764, 45.98691293171474, 47.00646727425711, 46.13176202774048, 46.71637303488595, 47.546210289001465, 48.13702951158796, 49.08857488632202, 51.50999082837786, 61.63325909205845, 65.7287357875279, 63.91454723903111, 67.2710691179548, 62.824173382350374, 67.90541185651506, 70.50321129390171, 73.00694601876395, 44.25120081220354, 0.5373513145106179, 42.27545622416905, 60.174227714538574, 41.80417728424072, 31.50598464693342, 61.67670617784773, 48.346027851104736, 39.475099427359446, 62.327835764203755, 3.3507305553981235, 0.13235546142927238, 0.08754491380282811, 0.09007514374596731, 0.0643630363047123, 0.04781721432560256, 0.043846498642648966, 0.05780065951070615, 0.02009159492860947, 0.11050630134663411, 0.11649678168552262, 0.16926197175468716, 0.1875586278204407, 0.2433660025043147, 0.15617836453020573, 0.11454266868531704, 0.252793866608824, 0.26162624838096754, 0.20656283306224005, 0.29070065968802994, 0.33996596613100594, 8.936292733464922, 79.48161097935268, 52.739815030779155, 50.3697566986084, 38.658432483673096, 60.42842755998884, 48.65245035716465, 83.5891775403704, 23.32653226171221, 17.50934406689235, 80.96623257228306, 65.04577650342668, 74.3919929776873, 64.27337305886405, 67.65515163966587, 62.00167342594692, 62.307366371154785, 58.512878690447124, 59.26233918326241, 55.226936612810405, 58.59074020385742, 53.85902738571167, 52.62025390352522, 50.2434731892177, 49.523511273520334, 49.557786737169536, 55.67077016830444, 52.84110934393746, 53.844658511025564, 52.97755111966814, 48.21466173444475, 47.36518539701189, 48.148334230695454, 45.942899567740305, 47.020259448460166, 44.862475531441824, 45.14307853153774, 46.00498519624983, 47.532643931252615, 48.584972926548545, 45.37193134852818, 54.50731863294329, 51.760132925851, 54.14287519454956, 48.91041612625122, 50.308810574667795, 54.08182137353079, 56.36143847874233, 54.81571442740304, 53.369644914354595, 53.691516739981516, 54.32345887592861, 60.5133831841605, 55.86129672186715, 57.42670501981463, 58.690148081098286, 55.26341118131365, 54.0426196370806, 56.62111003058297, 52.43521295275007, 50.29913173403059, 57.263092313494, 49.53112997327532, 35.34826898574829, 44.293907914842876, 46.17342342649187, 42.270762716020855, 40.28462709699358, 38.27558674131121, 39.78102861131941, 39.95280545098441, 41.054338114602224, 40.082253864833284, 40.46737514223371, 44.76669808796474, 40.83101953778948, 39.72910124914986, 40.18895040239607, 36.56021547317505, 42.155742236546104, 41.431458541325156, 42.02279193060738, 39.09808669771467, 42.97316305977957, 44.90846218381609, 35.651620388031006, 38.71154451370239, 39.84984009606497, 44.91167572566441, 39.389636584690635, 39.034257071358816, 34.98644849232265, 49.27542584283011, 38.0622318812779, 44.197352273123606, 55.38374703271048, 53.38637965066092, 53.406116008758545, 52.72966023853847, 57.10773059300014, 56.1129708971296, 53.03075695037842, 52.17269263948713, 54.638524941035676, 53.45187337057931, 54.221983909606934, 54.38527005059378, 51.33168615613665, 51.64396946770804, 52.90201377868652, 51.90636471339634, 57.110478605542866, 42.90318775177002, 43.20279060091291, 50.390847955431255, 49.369080611637656, 44.60441248757498, 45.06429638181414, 40.69661705834525, 45.49759299414498, 46.17030021122524, 49.4293075970241, 47.21732773099627, 47.119028091430664, 46.49119928904942, 50.159987109048025, 46.868152959006174, 47.87774011066982, 46.72061838422503, 49.04849420275007, 49.730654444013325, 49.26826919828142, 51.69793265206473, 50.774398939950125, 52.09902088982718, 51.17421218327114, 53.5102938243321, 65.04126712254116, 69.52860832214355, 68.82774353027344, 71.00696958814348, 65.86835289001465, 70.27582454681396, 74.22929395948137, 74.0710209437779, 48.640746116638184, 0.6688253996627671, 43.02690737588065, 70.90953499930245, 45.949278014046804, 43.38946090425764, 71.91025624956403, 54.32351793561663, 45.18429871967861, 72.93738760266984, 4.730324915477207, 0.20280634106269904, 0.4174099362322262, 0.12132955236094338, 0.19938484180186475, 0.19026124637041772, 0.16562041001660482, 0.25275570579937523, 0.1979807357170752, 0.10837069379964046], [0.022253578828115548, 0.04990643721872142, 0.032639475007142336, 0.052961897371070724, 0.09902398926871163, 0.12335442299289362, 0.06716262429420437, 0.09470461854445082, 0.0321077919299049, 0.08195692008095128, 0.18995619059673377, 1.6684665850230624, 45.08714553288051, 46.73086697714669, 34.115109648023335, 34.751363141196116, 38.863241059439524, 32.630595752171104, 64.4824582508632, 36.448870590754915, 3.786582802023206, 51.8906444140843, 59.83355058942522, 62.09718336377825, 62.62885257175991, 65.1188576562064, 56.79231711796352, 56.719308921269004, 54.92749009813581, 55.55917515073504, 54.763252053942, 51.62836033957345, 49.651340757097515, 46.39969846180507, 43.921692916325156, 47.811819076538086, 51.155705656324116, 50.4144092968532, 50.30779961177281, 48.40002577645438, 46.20994315828596, 43.13281876700265, 43.58899927139282, 41.97386966432844, 43.11234589985439, 43.21984148025513, 41.993209975106375, 38.503932339804514, 38.40122754233224, 40.94646733147757, 42.61127655846732, 44.06531565529959, 46.10844734736851, 51.475670201437815, 48.25118841443743, 47.03025790623256, 42.69312981196812, 44.48397241319929, 49.08309275763375, 50.575180189950125, 50.38807215009417, 50.021224634987966, 51.19274302891323, 53.00790779931204, 50.3098076411656, 53.7922100339617, 52.15836197989327, 49.756533009665354, 51.517071042742046, 47.878685065678184, 50.287472656794954, 47.788570404052734, 50.47759274074009, 44.77946192877633, 36.57855871745518, 42.18516785757882, 37.63865579877581, 41.47818865094866, 37.3934816632952, 33.808982440403526, 33.08415331159319, 33.701021330697195, 33.18946715763637, 36.57283687591553, 38.48539454596383, 38.43069832665579, 37.987552642822266, 39.57954127447945, 51.879047870635986, 56.29177931376866, 65.08078847612653, 57.0455824307033, 35.400005272456575, 31.90409905569894, 44.17363807133266, 37.72698129926409, 33.82623829160418, 32.39849465233939, 39.02978590556553, 34.43530000959124, 37.963928767613, 33.4055735043117, 54.237033707754954, 41.37836735589163, 22.40152726854597, 48.069065707070486, 44.48251329149519, 49.15518379211426, 49.69814382280622, 49.461297103336875, 51.674218450273784, 48.89884042739868, 51.25127812794277, 51.52549573353359, 48.0843482698713, 48.763920307159424, 48.45940855571202, 49.28715787615095, 46.980849266052246, 48.97720915930611, 50.238765784672324, 52.530048915318076, 50.81017868859427, 44.18013463701521, 43.4192339352199, 44.2775935445513, 40.55752107075283, 41.283785002572195, 37.89065653937203, 38.12808690752302, 38.83426359721592, 42.17670842579433, 40.95904357092721, 42.20329223360334, 41.45951189313616, 41.257638931274414, 41.489965847560335, 41.895521777016775, 39.84416689191546, 42.668995244162424, 42.337031160082134, 44.99091993059431, 44.86831201825823, 45.246283599308555, 43.50367191859654, 43.512374537331716, 43.57503686632429, 47.26091725485665, 52.37581627709525, 57.91218260356358, 55.63629668099539, 60.47306973593575, 58.283716678619385, 64.88976860046387, 61.57913262503487, 71.80558163779122, 32.28978313718523, 0.6115981361695698, 50.06340714863369, 51.619431904384065, 34.31293528420584, 28.056627886635916, 76.56318691798619, 44.32234689167568, 38.06564344678606, 52.63791969844273, 2.1342314779758453, 0.024759422222684537, 0.2814937265855925, 0.1325528879782983, 0.09029779822698661, 0.0337637905696673, 0.13887804214443478, 0.07226191673960004, 0.14206028995769365, 0.02691376072886799, 0.06493732798844576, 0.06770559480147702, 0.06063976537968431, 0.0010101124997683136, 0.06207872780838183, 0.19485291998301232, 0.056475823279470205, 0.07714722638151475, 0.05403405733938728, 0.04849737443562065, 0.053577376130436144, 1.68154168341841, 59.30650193350655, 51.35909679957798, 35.05720547267369, 42.9165734563555, 45.89227499280657, 40.46922336305891, 67.09319523402623, 43.52273082733154, 4.027245385306222, 54.13590267726353, 63.87923649379185, 65.4698042188372, 67.43707547869, 64.6062126159668, 60.605481556483674, 59.6800023487636, 59.230023111615864, 57.24361651284354, 57.32617153440203, 54.844413961683, 52.287945883614675, 48.69277075358799, 47.57458325794765, 51.49390574863979, 52.367016383579795, 52.597828592572895, 53.849761962890625, 50.58275025231497, 46.80189493724278, 45.85676622390747, 46.428047112056184, 45.678423336574006, 45.69028391156878, 44.90979971204485, 46.31519794464111, 40.89945234571184, 41.319345882960725, 41.93688440322876, 44.41865587234497, 47.17369999204363, 49.25696447917393, 51.26894392286028, 50.90487568719046, 50.81027248927525, 46.454974855695454, 47.648786544799805, 51.83639635358538, 52.33348090308053, 54.429675987788606, 52.68903412137713, 53.32046209062849, 53.673541750226704, 50.67193732942854, 55.15003742490496, 53.922085762023926, 52.91385350908552, 51.47046947479248, 49.2284004347665, 49.269137723105295, 46.99827882221767, 52.06235524586269, 46.26557043620518, 41.39757912499564, 45.66709777287075, 40.19347020557949, 43.28081539699009, 38.500277587345664, 35.585633346012656, 35.83197130475725, 36.78192206791469, 36.38584000723702, 36.695312772478374, 37.89087540762765, 36.88462686538696, 37.64274828774588, 39.15059423446655, 47.20075280325753, 50.81233263015747, 62.97342068808419, 60.74805164337158, 44.55960008076259, 29.475241592952184, 43.176870346069336, 39.48828363418579, 38.10515090397426, 32.91988052640642, 39.70306634902954, 36.52001667022705, 39.70051288604736, 32.03807422092983, 58.4286595753261, 60.97170720781599, 23.914042404719762, 52.55549669265747, 47.46373169762747, 51.18081644603184, 49.38504409790039, 53.60072462899344, 54.8176668712071, 51.32086433683123, 50.75529139382498, 54.16007546016148, 51.023696831294465, 50.73330381938389, 50.57076460974557, 51.9861786706107, 48.37025274549212, 52.22028432573591, 51.73634576797485, 52.86886044910976, 52.23322534561157, 46.22461427961077, 48.41856009619576, 46.24063682556152, 43.61166776929583, 44.806678022657124, 38.9854598726545, 38.25240060261318, 41.913135460444856, 44.921389307294575, 44.1627710887364, 43.84054490498134, 43.35507774353027, 45.211143084934776, 47.43525103160313, 45.0976824760437, 44.07067619051252, 46.86451210294451, 45.5031862940107, 46.539242608206614, 46.390172481536865, 49.6917063168117, 48.062409332820344, 48.65629965918404, 46.964083262852256, 50.43304436547415, 54.76304708208357, 60.921263286045615, 59.70266042436872, 63.202759878976, 61.305338859558105, 69.23272623334611, 63.685784748622346, 78.05663967132568, 36.58674022129604, 0.5902019185679299, 57.40015595299857, 55.40096466881888, 41.087884017399375, 29.769442217690603, 86.412508555821, 52.27656820842198, 42.967653138296946, 55.64973102297102, 1.8292722191129411, 0.11691648273595742, 0.22120369172522, 0.053420553116926124, 0.13220551876085146, 0.04280121544642108, 0.18835624573486193, 0.06369001777576548, 0.04557712595643742, 0.07223368289747409, 0.08015313651412725, 0.15282227604516915, 0.20280397976083414, 0.14590876416436263, 0.185092600860766, 0.37121557071805, 0.23972533643245697, 0.2866852522960731, 0.3304476397378104, 0.1426608884441001, 0.29426744686705725, 2.890322723558971, 68.79075826917375, 63.93028490883963, 44.55948543548584, 49.90940727506365, 52.61556386947632, 43.23486695970808, 75.66164425441197, 43.621499470302034, 6.528285077639988, 61.714803150721956, 66.88556221553257, 69.670455796378, 68.76887839181083, 68.96433816637311, 63.97221033913748, 62.16214902060372, 61.891058104378835, 59.890963554382324, 61.068071774074006, 57.07279852458409, 54.859283106667654, 51.81074707848685, 49.12291635785784, 52.57546928950718, 55.19991159439087, 56.53119339261736, 57.173693316323416, 53.31510155541556, 48.720754623413086, 49.33388451167515, 49.64421190534319, 47.36129787990025, 46.19023806708199, 47.641230378832134, 49.19152634484427, 43.73385878971645, 44.26438154493059, 45.10917132241385, 47.240847383226665, 47.69095516204834, 52.63042606626238, 54.17740079334804, 52.99585614885603, 50.982004165649414, 47.98855345589774, 50.30998134613037, 51.18287311281477, 54.7613274029323, 58.160886423928396, 55.36051573072161, 57.25980928965977, 55.029225621904644, 53.75153527941023, 59.09483895983015, 55.93653876440865, 56.410930497305735, 56.43421391078404, 50.596618856702534, 53.1941681589399, 51.480669430324006, 56.48057229178292, 47.97580351148333, 41.35190166745867, 46.80606038229806, 42.706192425319124, 44.88671432222639, 42.15242099761963, 37.34918342317854, 38.08327102661133, 39.57495893750872, 37.98853928702218, 38.68396711349487, 39.34876380647932, 38.37711729322161, 37.45137752805437, 38.713288511548726, 46.19689791543143, 49.05645336423601, 61.78114455086844, 61.73479311806815, 51.48355988093785, 37.93959617614746, 47.75213057654244, 39.995800903865266, 37.07525416782924, 34.409091404506135, 42.3363676071167, 37.82209171567644, 38.269187450408936, 33.79190724236624, 52.9771272795541, 51.148389203207834, 23.74337206568037, 55.574110303606304, 50.97830424989973, 50.77826908656529, 51.36305032457624, 57.096457140786306, 56.810618673052105, 53.610358306339805, 52.74464055470058, 57.461887223379954, 53.12097236088344, 54.767125674656455, 51.78094278063093, 53.0227005141122, 51.17627579825265, 53.408037185668945, 56.125505447387695, 57.367061683109824, 55.374422550201416, 48.663404192243306, 47.79927410398211, 50.92533813204084, 45.19305344990322, 47.175607272556846, 41.503806659153526, 42.03792858123779, 44.25372300829206, 45.75458601542881, 46.718026706150596, 49.293842043195454, 46.95338303702218, 48.08994851793562, 50.06132616315569, 48.30668020248413, 45.726966926029746, 50.83426114491054, 50.56102670942034, 50.249323572431294, 53.351944378444124, 54.265767983027864, 52.18384797232491, 51.06992667061942, 49.878873416355674, 53.34989465985979, 59.35381916591099, 63.45871761866978, 63.31704384940011, 67.2041927065168, 64.32786083221436, 69.83951241629464, 66.27344676426479, 77.99717698778424, 43.27629906790597, 1.6661338359117508, 57.09416423525129, 64.9992652620588, 44.159053802490234, 41.54881361552647, 84.27543027060372, 55.82264389310564, 52.26266833714077, 75.17149748120988, 3.5138770810195377, 0.30124457819121225, 0.5294306938137326, 0.16049561143985816, 0.32384112424084116, 0.12146764780793871, 0.27632584103516167, 0.15474027741168225, 0.1568467350942748, 0.15251354261168412], [0.0181297941266426, 0.020879603090829084, 0.09543643213276352, 0.029508259812636033, 0.04210668396470802, 0.04680281804342355, 0.12132169492542744, 0.10654792482299463, 0.03893508915124195, 0.042055936330663304, 0.24323162542922155, 0.5628615170717239, 38.165579387119834, 50.018052782331196, 26.855482373918804, 33.07821260179792, 36.79376527241298, 28.410954747881206, 51.79806661605835, 54.47377967834473, 1.671876522047179, 26.937597921916417, 65.73708752223423, 61.21761785234724, 66.09630938938686, 60.76647826603481, 62.87222017560686, 59.856868743896484, 59.73833247593471, 54.20866421290806, 54.12536573410034, 51.74029581887381, 49.824406487601145, 46.155434540339876, 47.67102772848946, 50.52032763617379, 51.03866672515869, 52.28020906448364, 48.654038020542686, 49.67673642294747, 45.958668504442485, 43.79579503195626, 42.77357952935355, 40.708613123212544, 42.80934885569981, 42.07154744012015, 43.21147584915161, 39.03487893513271, 38.70962333679199, 40.715179170881, 43.306516783578054, 46.59358099528721, 48.38037974493844, 49.376532554626465, 49.02376208986555, 48.515411036355154, 45.03502709524972, 47.43054710115705, 51.24867255347115, 51.47815070833479, 52.05228730610439, 51.99678856985909, 49.08753265653338, 50.77107770102364, 50.629101685115266, 51.88020127160208, 48.33541447775704, 52.21830756323678, 49.26025792530605, 48.03494657788958, 49.471528325762065, 48.81810235977173, 46.84259401048933, 47.40386601856777, 40.9434483391898, 45.540463379451204, 40.47155795778547, 38.079845564705984, 41.6129663331168, 34.905533245631624, 35.24989291599819, 34.32405587605068, 35.020220211574006, 34.784120423453196, 36.36337300709316, 41.36995308739798, 40.05175822121756, 32.3366174697876, 39.42525652476719, 43.121611322675435, 46.489566462380544, 54.39403520311628, 60.763712882995605, 42.69209453037807, 27.91810859952654, 28.32016784804208, 32.97355883462088, 33.95312282017299, 28.84764208112444, 31.219579901014054, 31.92780978339059, 52.097978660038535, 51.808937072753906, 18.604381901877268, 32.036646366119385, 50.13815239497593, 50.21247380120413, 46.92483983721052, 46.94763340268816, 49.64517423084804, 47.6660076550075, 50.06005811691284, 52.35023995808193, 51.73778404508318, 51.27480820247105, 50.06855923788888, 48.40730054037911, 46.60459736415318, 47.30676146915981, 51.939733437129426, 48.41480112075806, 49.684091091156006, 48.80470275878906, 40.815757819584434, 42.64114686420986, 42.46767813818795, 40.98122569492885, 40.44423764092581, 33.87949275970459, 35.16017777579171, 39.46749809810093, 39.570359230041504, 40.489883831569124, 41.855732917785645, 41.50316742488316, 42.519838265010286, 42.46401991162981, 39.91211332593645, 40.85720729827881, 43.72145625523159, 44.338463238307405, 43.05128165653774, 43.084368978227886, 43.52679552350725, 42.352355412074495, 46.45158066068377, 41.621047088078086, 45.81575795582363, 45.565574169158936, 54.139380250658306, 53.690856661115376, 57.077881131853374, 56.796861239842, 67.06145586286272, 56.76147753851754, 76.02736268724713, 22.724658455167496, 1.527786625283105, 61.36748354775565, 45.25011900493077, 39.91065073013306, 29.929111821310862, 48.14243868419102, 38.3624461718968, 50.809136458805625, 36.32215976715088, 1.223908571260316, 0.11501475263919149, 0.127950927774821, 0.18133331329694816, 0.14707693005246775, 0.07547379617712327, 0.09370528573968581, 0.1481244931263583, 0.0526502462370055, 0.07225218654743262, 0.04212067535679255, 0.043276793855641565, 0.06077431208853211, 0.02001742596205856, 0.01454886288515159, 0.07197709488017218, 0.15299892585192407, 0.20373624616435596, 0.1445544082671404, 0.07773385383188725, 0.10451569208609206, 0.7325631795184953, 45.72562939780099, 55.6202254976545, 29.357823984963552, 42.90365328107561, 47.52129404885428, 33.23841721670968, 54.100105558122905, 64.71431963784354, 2.326261882271085, 25.187720162527903, 72.55677918025425, 68.08771869114467, 70.18597044263566, 63.182582310267854, 64.43987274169922, 59.82339927128383, 62.162239347185405, 59.589203289576936, 58.572021756853374, 54.58644124439785, 54.38146243776594, 48.53684622900826, 52.23656742913382, 50.055652959006174, 53.819363594055176, 54.45041288648333, 49.763641016823904, 51.13372850418091, 48.40490688596453, 44.93158578872681, 45.557795660836355, 42.78220224380493, 44.111597606113975, 43.92852994373867, 45.38471950803484, 41.7641487121582, 40.99736636025565, 42.57398905072893, 44.799594334193635, 48.54313782283238, 50.98499883924212, 51.66895171574184, 50.65445566177368, 48.3509714944022, 46.31911325454712, 46.65161582401821, 53.26771831512451, 53.1321450642177, 54.92172656740461, 53.09359645843506, 51.85529892785208, 52.39763709477016, 51.77110760552542, 53.38177646909441, 50.6346880367824, 54.280956745147705, 50.25189093181065, 48.845867361341206, 48.77811547688076, 52.76843466077532, 51.98114122663225, 51.619973863874165, 44.08307177679879, 48.44321925299508, 40.765741212027415, 39.148040771484375, 40.61723388944353, 36.82474728993007, 37.51306710924421, 35.68323121752058, 35.65678289958409, 35.854799611227854, 35.565497466496055, 45.202558585575645, 39.97749934877668, 31.897164753505162, 38.41411992481777, 41.31697307314192, 46.907351221357075, 54.239819935389924, 65.02002647944859, 56.44119685036795, 37.89196627480643, 30.340636253356934, 36.079785755702424, 35.28143078940255, 31.175809723990305, 32.05388832092285, 29.960889407566615, 51.08601869855608, 66.06713390350342, 26.827413388660975, 34.200002738407676, 52.49497788293021, 50.555978843144004, 50.27604981831142, 52.02146857125418, 52.28252281461443, 48.96157571247646, 51.25144141060965, 52.42985936573574, 53.16351965495518, 53.98438678468977, 54.30545261928013, 51.727128982543945, 50.4722078868321, 50.39882796151297, 54.99186863218035, 53.085557392665315, 52.52546657834734, 51.28417437417166, 43.31007773535592, 44.8144530568804, 44.55068901606968, 44.988085065569194, 43.861552783421104, 37.18652956826346, 39.463409083230154, 41.04750803538731, 41.99851145063128, 44.06298106057303, 44.53587545667376, 43.1949599811009, 46.802544593811035, 45.95119571685791, 44.52361536026001, 43.858717918395996, 46.08411823000227, 46.68009301594326, 47.11993483134678, 47.63411194937569, 47.73162644250052, 46.59430013384138, 49.904154436928884, 47.398109436035156, 49.84763084139143, 49.76685455867222, 57.77745703288487, 56.86606877190726, 60.12443692343575, 62.32059574127197, 70.76091303144182, 61.382644517081125, 81.21840354374477, 24.137691020965576, 3.7112864766802107, 69.4312640598842, 50.44081939969744, 44.62781054633004, 34.917515414101736, 61.763002804347444, 42.97613341467721, 52.56057582582746, 46.61647878374372, 1.1381771372897285, 0.12854155179645332, 0.08072512796414749, 0.1800357914928879, 0.007489691588229367, 0.01857827015088073, 0.030732988379895687, 0.17172452461506638, 0.06543147790112666, 0.1861529475344079, 0.10527857579290867, 0.16877918051821844, 0.2113014366477728, 0.07385897782764264, 0.12514594543193067, 0.1414619849196502, 0.18323029364858354, 0.391939712954419, 0.15355423891118594, 0.21048462976302418, 0.3084283912820475, 1.5116049221583774, 58.92394801548549, 64.19118976593018, 35.39803893225533, 45.14642756325858, 50.538340841020855, 40.73768438611712, 61.21961893354143, 65.88801629202706, 3.0607218657221114, 32.02900334766933, 75.5038298198155, 68.6027330671038, 74.78308623177665, 66.10261140550885, 69.48058237348283, 64.00566591535295, 66.58981909070695, 61.08588000706264, 63.468000411987305, 55.82172673089163, 56.824383054460796, 50.39699016298567, 53.61963415145874, 52.34699167524065, 56.626338550022666, 56.71816941670009, 52.487532888139995, 54.45399120875767, 53.18085888453892, 47.57896409715925, 48.074433190482004, 43.08284384863717, 46.49774101802281, 46.64574807030814, 48.52008717400687, 43.71769380569458, 43.694990566798616, 45.72437524795532, 46.02459301267351, 50.28329331534249, 52.93901293618338, 54.785451548440115, 52.30538238797869, 50.21867854254586, 47.4321278163365, 51.14301477159773, 55.58346257890974, 55.36793988091605, 57.99343483788626, 56.354229722704204, 54.38548197065081, 54.59086724690029, 56.11851903370449, 56.00231736046927, 53.887063367026194, 56.47157784870693, 52.78572872706822, 51.48174640110561, 51.76050465447562, 55.12353352137974, 56.14533560616629, 54.79542221341814, 44.18234763826643, 50.5558294568743, 43.28767326899937, 41.45088223048619, 41.84930583408901, 37.74234029224941, 40.248030935014995, 37.12950222832816, 38.62698841094971, 35.81096690041678, 38.33618198122297, 49.13872698375157, 45.75511407852173, 35.382315158843994, 41.54282774244036, 46.229568345206125, 50.54547316687447, 55.687553542000906, 62.841557775224956, 60.820806230817524, 46.097552571977886, 35.54977021898542, 39.03625120435442, 37.06865685326712, 31.36607919420515, 29.899533339909144, 30.761453901018413, 45.32180009569441, 55.08319575445992, 32.103317805698936, 36.74729572023664, 56.99422134671892, 50.45423984527588, 50.23168209620884, 52.35956791469029, 56.710401330675396, 55.396358013153076, 53.646700859069824, 56.83354425430298, 56.95572485242571, 56.46724912098476, 54.84232950210571, 53.807982444763184, 52.411429268973215, 52.118284770420615, 57.62914425986153, 54.709844725472585, 55.56579678399222, 54.117736612047466, 45.835032258714946, 47.81010634558541, 48.27011183329991, 48.382658754076274, 45.87595020021711, 38.76536178588867, 41.392347131456646, 43.78745024544852, 45.51700973510742, 46.483111585889546, 49.00628389630999, 47.908701283591135, 48.86943565096174, 48.60216276986258, 47.069654192243306, 48.0479188646589, 51.62521627971104, 49.661801270076204, 49.37721347808838, 51.88358851841518, 51.26281213760376, 50.787228788648335, 52.80991540636335, 48.22548702784947, 52.034128189086914, 54.04161562238421, 62.14368765694754, 60.67028045654297, 62.93722752162388, 65.04211480276925, 73.09826619284493, 65.06862218039376, 83.34451062338692, 29.83548137119838, 4.467190555163792, 69.3025347845895, 59.00032956259591, 51.183651311056956, 45.626131193978445, 56.09484652110508, 51.92350244522095, 66.20977347237724, 57.43666526249477, 1.9551351453576769, 0.1987492580498968, 0.22219010522322996, 0.2611351790172713, 0.21956469038767473, 0.1202142850628921, 0.11639639921486378, 0.2099445973123823, 0.20061904271798475, 0.22511328836636885], [0.05949181304978473, 0.03380715913538422, 0.041545895127845664, 0.05166141376165407, 0.035432555845805576, 0.2414848863014153, 0.1247368295277868, 0.02762658042567117, 0.07663609952266727, 0.07274704213653292, 0.09304458940667765, 0.07996101610894714, 35.82198326928275, 49.04212965284075, 34.85630178451538, 26.930912017822266, 19.178678308214458, 35.38165160587856, 38.433425494602744, 73.41691058022636, 6.852849330220904, 8.984324761799403, 73.08639172145298, 65.99618584769112, 65.79964215414864, 60.10015296936035, 56.00408567701067, 58.42808287484305, 60.558567319597515, 58.32037190028599, 52.19075795582363, 49.84533446175711, 47.108473777770996, 48.88392611912319, 51.28442798342024, 50.53882026672363, 51.68302181788853, 50.42318834577288, 45.47306932721819, 44.74503013065883, 42.17854275022234, 42.11128418786185, 42.91152559007917, 44.8651888029916, 44.11693729673113, 43.987103257860454, 41.35868310928345, 41.79277876445225, 40.4053555216108, 38.53293064662388, 43.478321416037424, 47.33733354296003, 42.728582995278494, 46.096583298274446, 45.61390583855765, 44.29146562303816, 43.864658628191265, 43.42825269699097, 47.26796620232718, 52.05065795353481, 51.888573850904194, 50.96452249799456, 49.51248100825718, 51.25216402326311, 55.460403033665244, 53.41734777178083, 49.63502638680594, 48.428245885031565, 46.14198630196707, 44.66668571744646, 46.34486327852522, 50.67636333193098, 45.57663222721645, 46.35781819479806, 45.51885795593262, 41.07985884802682, 49.4492107118879, 42.09888512747628, 40.13272557939802, 37.128585066114155, 38.14396006720406, 32.45310749326433, 36.67936665671212, 36.52391808373587, 59.757544245038716, 61.4745830808367, 19.625987700053624, 30.588405541011266, 33.27660799026489, 31.626011303492955, 34.91665036337716, 40.777344703674316, 57.95557410376412, 77.1949518748692, 61.6483644757952, 43.43378693716866, 40.2620906148638, 41.81246995925903, 40.99617821829659, 38.56090062005179, 38.50077438354492, 38.997195380074636, 14.766660792487007, 19.889661414282664, 46.86645065035139, 50.414642061506, 53.38399294444493, 50.92812435967581, 52.41615056991577, 50.76111398424421, 50.01472112110683, 51.60790484292166, 49.23034593037197, 49.9614041192191, 52.99128770828247, 49.36024250302996, 47.35858113425118, 47.29367453711373, 49.64495536259243, 47.60607596806118, 45.09340238571167, 47.09065859658377, 41.412080015454976, 38.947560923440115, 41.752677236284526, 40.35843433652605, 40.05284561429705, 39.58796943937029, 38.03430707114083, 40.06245844704764, 39.1687707219805, 41.185120582580566, 39.63939305714199, 39.477850914001465, 40.61974913733346, 42.80894586018154, 44.33351264681135, 48.07322072982788, 47.30929061344692, 46.57086385999407, 44.647453103746685, 44.988891056605745, 44.571547508239746, 46.65286649976458, 42.81249986376081, 42.24086461748396, 45.26432807104928, 46.439848627362935, 45.8834924697876, 52.372943196977886, 52.557122571127756, 57.42448159626552, 57.9880291393825, 66.99810218811035, 57.56436620439802, 72.0973573412214, 15.391635622297015, 8.129857012203761, 72.03505284445626, 38.16447114944458, 42.40838915961129, 25.886526550565446, 15.8185989516122, 28.015011651175364, 49.67700045449393, 43.41791377748762, 0.6898113478507314, 0.08700083049812488, 0.1628581482384886, 0.20149972688938889, 0.05180834712726729, 0.07251028091247592, 0.03675066440233162, 0.1129284067345517, 0.020716612193999544, 0.07721852684127432, 0.05896702728101185, 0.04626139459599342, 0.032023209147155285, 0.03331384721345135, 0.05526207680148738, 0.23094598895737103, 0.09342338836618833, 0.040786967280187776, 0.010912661573716571, 0.055823377932288816, 0.09397285245358944, 0.19105292031807558, 45.43039696557181, 55.03152894973755, 36.54766007832119, 33.07012142453875, 25.139087983540126, 45.739564010075156, 40.10642317363194, 80.31491538456508, 9.644942113331386, 8.802499958447047, 76.08499799455915, 67.55761977604458, 72.0233381816319, 62.719728061131065, 61.77319581168038, 61.48341424124581, 66.02636882237026, 59.33740752083914, 54.63096530096871, 54.00124658857073, 50.06813192367554, 48.871461050851, 54.91623054231916, 53.71015875680106, 56.801787512642996, 52.74520683288574, 48.622319493974956, 47.42330013002668, 45.54373598098755, 45.34025798525129, 45.12893894740513, 45.87529706954956, 45.905090945107595, 45.281865324292866, 45.79581315176827, 43.87303120749337, 40.21909863608224, 39.27845845903669, 46.202810832432334, 48.44039828436715, 45.85686002458845, 48.347466128213064, 47.65225716999599, 46.972837993076865, 45.034933294568745, 45.26425511496407, 49.01652206693377, 53.38276311329433, 53.15926388331822, 52.871299266815186, 51.47493716648647, 52.78992543901716, 55.591571126665386, 53.55055863516671, 51.46843712670462, 52.2001553944179, 47.317131655556814, 46.0390556880406, 50.52727583476475, 52.201086453029085, 48.81645563670567, 49.70479324885777, 49.580809593200684, 45.89858395712716, 50.78990037100655, 44.272719383239746, 39.66763053621565, 36.55377449308123, 39.61894450868879, 34.344101428985596, 36.60061924798148, 39.08623307091849, 66.50940064021519, 64.02408558981759, 21.145268644605363, 31.01711286817278, 32.45455619267055, 34.72182982308524, 34.912686416081016, 37.46671567644392, 49.75685262680054, 74.51564311981201, 66.813294001988, 49.61279215131487, 42.867501803806846, 41.688594000680105, 41.77373027801514, 39.49785130364554, 42.539730957576204, 49.643548352377756, 23.366816180092947, 24.373643159866333, 48.75821931021554, 50.62145171846662, 52.26346737997872, 51.138081550598145, 55.28261947631836, 52.17374529157366, 52.6034323147365, 52.907176290239605, 52.18799952098301, 52.95842967714582, 54.70622818810599, 50.94975062779018, 48.765198775700156, 50.738650458199636, 52.74022497449602, 49.761198725019185, 45.5705942426409, 50.102396965026855, 42.404015268598286, 40.05617380142212, 44.70521347863333, 43.66106946127755, 41.07392508643014, 40.146187714168, 42.0237785748073, 42.92001976285662, 42.64155680792672, 42.89600331442696, 43.07963030678885, 44.32642895834786, 44.112945556640625, 46.18899086543492, 47.719387190682546, 51.15246432168143, 53.24576895577567, 52.09794044494629, 49.07784686769758, 51.1917633329119, 47.30250917162214, 47.87103162493025, 46.96911028453282, 46.13341569900513, 48.09907497678484, 50.4735141481672, 48.491523129599436, 55.74687031337193, 54.40943241119385, 59.70047869001116, 60.9600898197719, 71.47936371394566, 62.12820707048689, 75.69796943664551, 15.771135807037354, 11.406682184764318, 77.3952545438494, 42.89398486273629, 48.371982846941265, 30.410906859806605, 21.708529574530466, 36.83303649084908, 55.37548909868513, 55.01318570545742, 1.138687612754958, 0.06290378567895719, 0.02210695080326072, 0.2958808402929987, 0.007283892765242074, 0.041362219090972624, 0.1049996300467423, 0.1415701298309224, 0.04306612230305161, 0.03792126962382879, 0.11223180232835667, 0.10912073962390423, 0.16176900453865528, 0.16479058883019856, 0.10918176706348147, 0.5015727058053017, 0.1597557368555239, 0.1506943902266877, 0.10801432042249612, 0.1911184803715774, 0.11520578738834177, 0.4195858080472265, 53.43155683789934, 65.90885393960136, 45.5697465624128, 38.44791596276419, 26.248524223055156, 49.55784579685756, 49.88640178952898, 86.90949235643659, 9.183632101331439, 11.821892636162893, 80.7361707687378, 69.30133969443185, 73.59815434047154, 63.80090945107596, 66.32401575360979, 63.894237654549734, 70.3961534500122, 62.462790625435964, 60.99217660086495, 57.19662931987217, 53.2936281476702, 52.487248011997764, 56.278897353581016, 57.49492243358067, 59.02431474413191, 53.14793484551566, 50.63301699502127, 50.16019555500576, 47.03531966890608, 47.58569342749459, 47.96680906840733, 47.77056067330496, 48.27071285247803, 48.08080816268921, 46.301110471997944, 46.803110871996196, 44.60554504394531, 41.9957286970956, 49.65670476640974, 51.635829653058735, 47.17146267209734, 51.81766748428345, 50.470880780901226, 47.505855151585166, 48.262357643672395, 47.9257869039263, 52.25904137747628, 54.96313088280814, 56.47139719554356, 57.12777614593506, 53.497794015066965, 55.87423079354422, 61.003182547433035, 55.33726705823626, 54.56788260596139, 53.82543979372297, 48.653489112854004, 47.59928410393851, 53.18051494870867, 55.8793238231114, 50.296289920806885, 52.43394143240792, 53.35756547110421, 46.08083520616804, 53.98216683523995, 45.49707882744925, 42.03782088415963, 38.09186942236764, 40.354011808122905, 34.6400008882795, 38.12532499858311, 43.23626702172415, 72.8843103136335, 60.99433749062674, 22.422436135155813, 30.60043634687151, 34.91942269461495, 37.46466943195888, 37.70654664720808, 38.9341995375497, 47.5619410106114, 61.55961513519287, 57.49894196646554, 47.763720171792166, 46.70118774686541, 44.23790543419974, 41.177255221775596, 38.650501114981516, 37.189347062792095, 46.538308075496126, 27.842340230941772, 25.347500937325613, 52.580986159188406, 53.93577371324812, 55.07280819756644, 53.42724200657436, 57.71883855547224, 55.113562856401714, 54.492487703050884, 56.42804043633597, 56.00978667395455, 54.74886928285871, 58.25491639545986, 52.77640771865845, 52.64071634837559, 53.0953300339835, 56.89698130743844, 55.08417197636196, 50.5060247693743, 55.23136261531285, 46.16480418613979, 42.51193816321236, 47.66750151770455, 47.33228915078299, 45.154838357652935, 43.82129144668579, 43.3167028427124, 45.080895628247944, 45.40367071969168, 45.793707847595215, 47.09498732430594, 45.70961727414812, 44.5077144077846, 46.94244309834072, 48.45667443956648, 53.89834029333932, 55.45873894010271, 54.4341402053833, 51.516428334372385, 55.34331546510969, 51.68853521347046, 53.7288806779044, 50.28623240334647, 50.75678178242275, 50.86297804968697, 53.65745667048863, 51.89846461159842, 58.37442193712507, 60.35948058537075, 64.00793102809361, 65.42373071398053, 74.31770978655133, 65.53930704934257, 80.32433714185441, 21.39091178349086, 11.224303262574331, 80.68760286058698, 48.87413958140782, 56.69199207850865, 37.48207119532994, 22.335736513137817, 39.52761391230992, 69.10385799407959, 64.18523515973772, 2.4014240205287933, 0.1750264252935137, 0.2798814730984824, 0.579002996640546, 0.18386708519288472, 0.28222977423242157, 0.23075700338397706, 0.22023227385112218, 0.22873407336218016, 0.15300781466066837], [0.0793899813933032, 0.05135251408708947, 0.09839905173118625, 0.029005970872406448, 0.04742085827248437, 0.030694298313132355, 0.029686195443251302, 0.10104511438735894, 0.038203611437763484, 0.13641927550945962, 0.26102943611996515, 0.1725592991071088, 35.60565458025251, 47.80679900305611, 37.101761545453755, 40.6917394229344, 33.06588649749756, 29.451638562338694, 40.36373928615025, 69.98412527356828, 26.018318244389125, 4.160581316266741, 67.91877324240548, 64.30451488494873, 66.25526332855225, 62.55535452706473, 63.86470086233956, 59.21047782897949, 58.98851762499128, 54.245017187935964, 53.073196547372, 50.94383076259068, 48.76182542528425, 48.921925817217144, 50.37651382173811, 51.50781256811959, 49.73672022138323, 46.658789839063374, 46.633397647312705, 43.16180317742484, 40.98600605555943, 42.480650424957275, 44.449863706316265, 44.32349681854248, 43.36980445044381, 43.00723007747105, 42.396160330091206, 43.43358196531023, 41.20879656927926, 41.187691416059224, 42.7099791935512, 42.283728054591585, 43.0842786516462, 44.54824672426496, 47.64024373463222, 48.36182805470058, 42.307654176439556, 39.94733027049473, 44.51899133409773, 48.73388671875, 46.244187355041504, 50.1275702885219, 53.34002474376133, 50.359205859048025, 48.36044536318098, 50.64762558255877, 48.034317765917095, 50.55435643877302, 47.62002100263323, 48.334400040762766, 49.5523567199707, 47.71354028156826, 44.93223197119576, 47.047492912837434, 43.11930799484253, 45.79135935647147, 45.682616574423655, 47.0392940385001, 38.94682788848877, 36.50733968189785, 35.07357195445469, 35.320316382816856, 34.49361276626587, 39.33661488124302, 60.269584792000906, 48.20159217289516, 34.02443218231201, 36.857171058654785, 37.12222746440342, 36.69377722058977, 35.27187006814139, 34.38460595267159, 34.08484329496111, 46.27933829171317, 49.363094738551546, 52.57447917120797, 56.280801159994944, 47.178883348192485, 47.519008091517854, 42.52779047829764, 33.85128654752459, 23.04002329281398, 28.442185163497925, 47.31162173407418, 49.46348231179373, 48.887368951525005, 47.10870654242379, 46.95758669716971, 48.77082334245954, 48.92933259691511, 51.09304680143084, 49.56112882069179, 50.448278290884836, 48.3571241242545, 50.3001982825143, 47.002044745853965, 45.26939678192139, 44.73984677450997, 47.958144664764404, 41.3238274710519, 38.014376163482666, 37.89413758686611, 35.70879711423601, 39.8547420501709, 39.46054295131138, 40.86225169045584, 39.12112692424229, 36.51641402925764, 37.515804699489046, 40.44669035502842, 41.65581239972796, 40.3071323122297, 41.34084013530186, 42.30927658081055, 45.22173908778599, 50.41077538899013, 54.73406614576067, 54.47186892373221, 51.986512184143066, 54.542396613529746, 54.79652350289481, 51.467745780944824, 46.22459690911429, 43.8341942514692, 40.751952511923655, 44.91149507250105, 43.576301438467844, 47.963779653821675, 45.90818289348057, 48.21897656576974, 50.002342905317036, 55.63501821245466, 57.580569403512136, 65.4392113004412, 58.703815187726704, 63.723284176417756, 6.806412781987872, 22.13994148799351, 67.04498168400356, 38.65640013558524, 26.759569440569194, 18.689648457935878, 36.45950828279768, 31.525033133370535, 45.92930541719709, 39.43197890690395, 0.04729343618133238, 0.16157697912837776, 0.22050337573247297, 0.06613606187914099, 0.1370008885860443, 0.24743721261620522, 0.1320534319217716, 0.0936980050589357, 0.023742148952026452, 0.07222320631678615, 0.03292116542745914, 0.06197058968245983, 0.06474277842789888, 0.019442793314478228, 0.028554439744246856, 0.02520047846649374, 0.009787863403159593, 0.06617117606635604, 0.04801893260862146, 0.027384893037378788, 0.24837508371898107, 0.28743894185338703, 45.95905760356358, 54.30277756282261, 40.48220607212612, 40.41713966642107, 33.07344266346523, 41.57539394923619, 45.94629723685128, 74.92902619498116, 33.13744599478585, 5.599890232086182, 68.36561884198869, 68.83701242719377, 71.98088468824113, 64.31590298243931, 65.63414996010917, 63.453971999032156, 62.76838629586356, 57.486970220293315, 57.13323048182896, 54.20047576086861, 51.40636886869158, 51.32820858274187, 52.86865895135062, 53.95283848898751, 52.90700258527483, 50.44121544701712, 49.348347187042236, 45.65195417404175, 43.08531393323626, 45.28786856787545, 47.11449786594936, 46.21755838394165, 47.21605968475342, 44.895740032196045, 44.921017578669954, 43.99358245304653, 43.10422345570156, 42.814438411167686, 44.124889510018484, 44.67539528438023, 44.95833287920271, 44.99868106842041, 48.53619657244001, 49.573392391204834, 43.66758687155587, 42.314126423427034, 47.19598286492484, 48.996917724609375, 47.83359473092215, 52.42844888142177, 57.10848099844796, 52.10560430799212, 50.30717774799892, 52.697608198438374, 52.288032736097065, 52.50773824964251, 48.878853934151785, 50.00968715122768, 51.875650201525005, 49.843072823115754, 46.335556166512625, 48.617268153599326, 45.293559142521445, 47.32303762435913, 47.09910065787179, 48.845547744206016, 40.00349603380476, 37.73891135624477, 36.87189081736973, 35.58490031106131, 36.46639742170061, 44.16156905038016, 67.34906264713833, 55.56856564113072, 37.41010870252337, 38.07390138081142, 35.45702566419329, 34.234271253858296, 33.61514507021223, 33.27112238747733, 33.85748086656843, 41.76881095341274, 42.06602362224034, 46.74688604899815, 54.447939327784944, 47.70052630560738, 48.23154238292149, 44.782202993120464, 40.452592849731445, 27.53199894087655, 32.16439247131348, 50.14797714778355, 50.617338384900776, 50.064664772578645, 49.77719347817557, 48.75734036309378, 48.06608840397426, 51.173187323978965, 51.62307970864432, 50.787148884364534, 53.23486375808716, 53.240116596221924, 51.00974832262312, 51.68338312421526, 47.487967014312744, 47.3793180329459, 51.072309902736116, 45.413210596357075, 40.003475189208984, 38.63994680132185, 38.676525592803955, 44.02137524741036, 43.537540912628174, 41.566972732543945, 42.753408908843994, 40.313013962336946, 40.38878059387207, 44.25254528863089, 44.59810699735369, 44.41652624947684, 42.72321898596627, 46.02142463411604, 47.72605051313128, 53.899309567042756, 57.15852539879935, 57.328304631369456, 57.458854334695, 56.59844153267996, 55.33444608960833, 56.641575949532644, 51.32527296883719, 48.198430742536274, 47.60557917186192, 49.715243339538574, 48.15940618515015, 52.00181559153965, 50.124975136348176, 52.21481956754412, 53.93857731137957, 58.48949105398995, 61.38898822239467, 70.1738805770874, 63.728127070835654, 64.77308055332729, 5.833285433905465, 28.602071898324148, 71.28781577519008, 41.670115266527446, 30.26970556804112, 22.926686014447892, 32.60626663480486, 35.895456995282856, 49.748723234449116, 47.36550154004778, 0.859003620488303, 0.07223380503377744, 0.1929165031760931, 0.04576571458684547, 0.016794047052306787, 0.262005549456392, 0.20472830507372106, 0.18129652312823705, 0.06236398393022163, 0.06052639574876853, 0.12686615384050778, 0.11522133941096918, 0.13746002609176294, 0.12727050642882073, 0.1269786956587008, 0.11915852528597627, 0.13585838489234447, 0.22805996239185333, 0.09654364522014346, 0.2698298453220299, 0.23079033302409308, 0.7446034848690033, 54.09847967965262, 62.43471990312849, 46.908886773245676, 54.846745082310264, 42.94349772589547, 43.82490798405239, 54.233021123068674, 82.81508568355015, 33.32736805507115, 7.157386703150613, 78.615323475429, 70.42442567007882, 76.82613454546247, 65.43940585000175, 67.4831906727382, 64.78528159005302, 67.6018659046718, 62.78278991154262, 62.65956360953194, 56.728897435324534, 54.21321528298514, 54.15657704217093, 57.53894969395229, 57.17064653124128, 54.1516820362636, 52.107053007398335, 52.52495241165161, 47.21932881219046, 46.05976479394095, 46.927261284419465, 50.82712534495762, 46.60835633959089, 49.77749572481428, 48.18782779148647, 47.87378658567156, 46.73103025981358, 45.025431632995605, 45.1493353843689, 49.299279008592876, 47.718879972185405, 47.35095548629761, 47.37738643373762, 52.04418223244803, 53.589736052921836, 45.58656815120152, 42.3063131741115, 48.536008971078054, 52.21550049100603, 49.10863086155483, 54.0949638911656, 59.688041414533345, 56.03741618565151, 53.01406042916434, 54.023494720458984, 54.58557966777256, 54.77377510070801, 51.16963332039969, 53.43037911823818, 57.730007784707205, 54.19779028211321, 51.36635071890694, 54.03367383139474, 46.137588092258994, 50.826854365212576, 50.58950737544468, 53.677092279706685, 40.84171281542097, 38.30101714815412, 38.86614888054984, 37.57140071051461, 37.720022678375244, 47.23105737141201, 67.95306260245187, 51.66934776306152, 32.75358581542969, 38.68207720347813, 36.665532793317524, 35.17711400985718, 33.25508941922869, 33.239428179604666, 34.7742783001491, 44.27617611203875, 41.24764742170061, 43.14615930829729, 54.42693839754377, 48.710978507995605, 50.188842977796284, 45.655063492911204, 42.3736446925572, 31.650736468178884, 34.22874743597848, 52.615192140851704, 52.60585723604475, 54.245652948107036, 52.49341106414795, 53.3169185093471, 53.22626188823155, 53.25534357343401, 54.97106572559902, 55.34714044843401, 56.73626599993025, 55.90633494513375, 55.03330421447754, 56.301322664533345, 50.59706701551165, 48.94342701775687, 52.440847941807334, 45.75773354939052, 42.47670384815761, 41.332936559404644, 39.220920426504954, 45.815195151737754, 45.96475165230887, 46.68630123138428, 46.00812578201294, 42.15355007989066, 42.72940635681152, 46.03268071583339, 47.59156812940325, 47.810419014522004, 45.96867391041347, 49.27186141695295, 49.536469663892476, 55.04682193483625, 59.55367715018136, 61.38712610517229, 60.40696457454136, 58.78439344678606, 59.14522729601179, 58.77257456098284, 53.8526246207101, 52.24340098244803, 49.69767829350063, 51.593039172036306, 50.56825283595494, 57.081876346043174, 52.23690441676548, 56.15414244788033, 58.38867269243513, 65.41209942953927, 66.41792065756661, 76.61414500645229, 67.3479231425694, 76.33677986689976, 13.345368555613927, 26.181444576808385, 78.21530178615025, 47.58772924968174, 34.199961049216135, 26.815127236502512, 53.64545018332345, 45.426099504743306, 59.66827378954206, 59.77481746673584, 1.8768313356808253, 0.21799643311117375, 0.36579491730247227, 0.13201798525239739, 0.16586477761822088, 0.4590554301227842, 0.30737451783248354, 0.39419223208512577, 0.08885629807731935, 0.18241108474986895], [0.017008004410724555, 0.0665728212999446, 0.023132224001788666, 0.01356253759669406, 0.08447940115417753, 0.023352566374731914, 0.08538199522133384, 0.056366646994969676, 0.04196900242407407, 0.17196345036583288, 0.23682888756905282, 0.29100382913436207, 33.65937730244228, 58.24018621444702, 26.524749858038767, 53.52461058752877, 63.34577465057373, 18.702737127031597, 44.98018148967198, 55.06367131641933, 46.707496711185996, 2.3892538164343153, 36.709146635872976, 67.88554695674351, 64.55269064222063, 68.15421295166016, 65.53264372689384, 61.031857763017925, 59.0815817969186, 58.65341990334647, 54.78200871603829, 49.90669747761318, 49.68177734102522, 48.69829109736851, 50.13890627452305, 49.23928478785923, 48.415099893297466, 45.47154072352818, 45.38898222787039, 45.28962993621826, 45.350961685180664, 46.512710911887034, 47.10349191938128, 47.32242965698242, 43.60250309535435, 39.10103620801653, 42.02143703188215, 41.05832985469273, 41.42698390143258, 38.317842211042134, 38.659752641405376, 40.62873663221087, 41.361149719783235, 44.938846656254356, 45.7776575088501, 47.80059078761509, 44.933590344020296, 40.260405676705496, 48.436305795397075, 49.354649203164236, 49.50205176217215, 50.12905372892107, 51.51667499542236, 45.296449593135286, 44.51365164348057, 48.88446460451399, 47.432579449244905, 49.02688530513218, 48.11873490469796, 49.41771452767508, 47.786718709128245, 50.48974861417498, 46.44538981573922, 44.39320462090628, 44.55706051417759, 44.58880335944039, 46.740271363939556, 50.376597200121196, 45.91013533728463, 39.2354074205671, 36.85483646392822, 33.006576674325125, 36.11243881498064, 49.818712438855854, 46.76632710865566, 38.47607353755406, 41.112640448978965, 37.94982739857265, 35.64987986428397, 36.41043315614973, 38.67307928630284, 35.582930496760774, 37.350611277988975, 35.53761087145124, 36.99445356641497, 33.69489649363926, 34.54599176134382, 38.23480428968157, 36.09119469778878, 42.33653783798218, 45.638366971697124, 49.530765192849294, 50.68406541006905, 48.46848290307181, 50.43094948359898, 49.65455082484654, 47.72544601985386, 46.433973925454275, 47.62023639678955, 47.814570563180105, 48.43992928096226, 45.82701751164028, 47.65731545857021, 48.45317602157593, 49.929115840366904, 49.063477993011475, 45.6707421030317, 48.29897117614746, 50.09512220110212, 44.82563965661185, 37.07394095829555, 37.97412524904524, 41.216179030282156, 39.350483485630576, 38.86061464037214, 38.55849654333932, 40.528217043195454, 40.01069784164429, 40.54935346330915, 40.91738217217581, 40.34854357583182, 41.28949989591326, 40.088934557778494, 43.41689934049334, 49.309003012520925, 54.33323499134609, 53.88750457763672, 54.512057304382324, 53.67356954302107, 55.07565001079014, 56.649139063698904, 56.262235573359895, 52.02364335741316, 49.565214361463276, 43.96644973754883, 44.71250908715384, 43.217360973358154, 47.47735364096505, 48.27283205304827, 51.0362001146589, 51.418979849134175, 56.47770963396345, 60.79201289585659, 64.15300246647426, 60.99573407854353, 42.716100556509836, 1.239693358540535, 36.98140484946114, 61.88094847542899, 32.33895206451416, 19.08770033291408, 22.152896404266357, 36.85620525905064, 30.990668024335587, 41.50438335963658, 47.97417415891375, 1.2191102973052432, 0.059796923106270175, 0.08613565085189683, 0.059212256622101576, 0.061325221455522945, 0.049817939288914204, 0.06663871383560555, 0.07471809137080397, 0.023791266405688863, 0.029328169833336557, 0.038697761350444386, 0.06396189997238771, 0.0458059584988015, 0.1027959179399269, 0.04150016865293894, 0.06574367186320679, 0.09267972755645003, 0.023759336244048815, 0.11436771521610872, 0.2803388328424522, 0.08584104451750006, 0.5080080404877663, 46.602134227752686, 66.83624390193394, 30.64185803277152, 55.78372008459908, 56.650681563786094, 25.201336894716533, 52.49633278165545, 59.405069078717915, 56.0849939755031, 3.7981406961168562, 35.48624631336757, 71.29534067426408, 69.33177975245884, 71.05308478219169, 67.6036376953125, 63.413818359375, 61.30161462511335, 59.369542939322336, 55.50255080631801, 51.26795380456107, 52.89837987082345, 51.6584529876709, 52.336350509098594, 54.04550313949585, 50.21121270315987, 47.44012519291469, 47.22309473582676, 47.16384744644165, 49.47676726749965, 49.33027492250715, 49.57362168175833, 49.02044085093907, 47.20195484161377, 40.639728682381765, 44.00834390095302, 41.437357561928884, 42.77884973798479, 39.90944174357823, 39.21760613577706, 40.825064931597026, 43.37763854435512, 45.65647397722517, 45.67690168108259, 46.778757435934885, 44.50289930616106, 39.90709325245449, 48.900584425245015, 51.127204145704, 51.85629946844918, 50.96543966020857, 52.3359648840768, 45.73545067650931, 46.844278948647634, 52.094007764543804, 50.307104791913716, 52.97265611376081, 52.045464175088064, 52.97231217793056, 51.08643559047154, 50.79149498258318, 48.43463822773525, 47.397088050842285, 47.538640226636616, 47.26385286876133, 50.61608076095581, 51.5483136177063, 44.942233903067454, 38.89173214776175, 38.101909569331575, 34.63152061189924, 35.275066239493235, 51.91483804157802, 48.84217439379011, 41.76918963023594, 40.27994053704398, 36.598757130759104, 34.47739219665527, 35.22937141145979, 37.07884291240147, 34.42960943494524, 36.34117351259504, 40.648914200919016, 39.104159423283164, 30.58055407660348, 35.7242568561009, 39.183438369206016, 37.11967052732195, 42.49091638837542, 46.84801360539028, 48.33719669069563, 51.17040804454258, 48.6387346131461, 50.90237780979702, 49.68136739730835, 49.33512823922293, 48.7912267276219, 51.15576819011143, 51.28554664339338, 49.60493721280779, 47.106712409428184, 51.73657853262765, 51.553180830819265, 53.33554662976946, 52.087448665073936, 51.50533900942121, 52.43399354389736, 52.681992122105186, 47.319414138793945, 38.703974451337544, 40.64481128965105, 43.30255283628191, 43.1613689150129, 41.97086456843785, 41.7510061945234, 44.12230478014265, 42.82310976300921, 43.98485551561628, 46.29429428918021, 44.058311871119905, 44.20164278575352, 43.42016151973179, 46.95323712485177, 52.4493282181876, 57.86373976298741, 57.09702689307076, 58.53915677751814, 57.0352817262922, 59.345050539289204, 61.76166875021798, 58.82765987941197, 57.70125961303711, 55.25824866976057, 49.1230205808367, 46.9826523235866, 46.72321353639875, 51.164244992392405, 53.08569983073643, 59.331133297511506, 55.8860079901559, 60.62413052150181, 65.4229177747454, 66.87895447867257, 64.22873783111572, 40.763691493443076, 2.035310843161174, 43.888438837868826, 68.05060141427177, 37.620458466666086, 24.285114424569265, 28.52843315260751, 36.27696520941598, 32.279881954193115, 46.59298345020839, 61.5818771634783, 2.783259234258107, 0.22654107532330922, 0.10588615640465703, 0.04070444045854466, 0.018455334872539555, 0.08701753603028399, 0.017877214554963366, 0.204567695834807, 0.03437155777854579, 0.10381445328571967, 0.09428157910172429, 0.17175552009471826, 0.0984530495479703, 0.17769439784543856, 0.17268315888941288, 0.17434821597167424, 0.2538562353168215, 0.10845399754387991, 0.13212361958410057, 0.2615092418023518, 0.24485506117343903, 0.5220608807035855, 52.12730353219168, 75.69996356964111, 38.398166860852925, 66.90515613555908, 78.53990772792271, 27.968748807907104, 59.194726262773784, 69.63475595201764, 57.65681546075003, 5.057463475636073, 47.29499816894531, 74.0977645601545, 72.1162633895874, 72.58499581473214, 70.50878374917167, 65.04879896981376, 61.69875281197684, 62.73109531402588, 59.2069342476981, 53.91542591367449, 56.490199020930696, 52.717014517102925, 54.87134517942156, 56.70090314320156, 52.44076803752354, 49.81547805241176, 49.98901973451887, 49.06824098314558, 50.25246415819441, 53.2931660924639, 52.23065103803362, 51.586632932935444, 49.381847926548545, 42.89961290359497, 47.09467118127005, 44.50836753845215, 47.132663931165425, 43.29730347224644, 43.64484541756766, 43.129619121551514, 45.72504227502005, 50.3885863167899, 49.12961094720023, 48.89209720066616, 45.988191400255474, 41.418288230895996, 50.99095344543457, 52.30569505691528, 53.913629804338726, 52.84216547012329, 55.370118141174316, 49.25550535746983, 47.6346469606672, 54.48932974679129, 52.4428768157959, 55.349509784153526, 55.85615158081055, 55.101010935647146, 53.248110498700825, 56.19776323863438, 52.411926065172466, 51.46618938446045, 51.053744316101074, 51.59907020841326, 52.869471890585764, 54.00306354250227, 48.2636639050075, 39.53113317489624, 39.852886881147114, 34.97920846939087, 38.57293490001133, 47.10312019075666, 42.79005370821272, 41.45339400427682, 41.74445056915283, 36.04453754425049, 34.15605885641915, 36.124334130968364, 39.639716148376465, 35.85560212816511, 36.08804021562849, 40.34859568732125, 37.195280824388774, 33.530950273786274, 35.6507796560015, 37.7099860055106, 37.4923232623509, 45.41754627227783, 48.46881989070347, 51.79520395823887, 53.480736187526155, 51.65816811152867, 55.51267433166504, 51.13278702327183, 51.85461105619158, 51.76659822463989, 54.001517568315776, 53.24571337018694, 54.241091455732075, 51.42730031694685, 52.66373920440674, 53.66060420445034, 57.23830114092146, 56.28235755647932, 55.00791202272688, 53.26546362468174, 55.62030192783901, 49.42802218028477, 41.502958978925435, 41.076110294886995, 44.85707678113665, 44.31085457120623, 44.72856289999825, 43.048891476222444, 46.974116461617605, 44.95104421888079, 46.69808190209525, 48.79216820853097, 46.354979855673655, 48.529234477451865, 46.2949925831386, 48.41572870526995, 52.87079552241734, 61.17864540645054, 60.56776673453194, 59.51491315024239, 60.90072441101074, 61.98506028311593, 63.94019998822893, 61.49750518798828, 59.07034655979702, 56.46266678401402, 50.77835941314697, 50.035913126809255, 49.81903205599104, 55.550000054495676, 54.515454973493306, 61.485519545418875, 60.10671901702881, 64.46207918439592, 69.1417465209961, 74.15917273930141, 67.60284560067313, 55.92975384848458, 5.109347411564418, 42.63729408809117, 74.15789427076066, 43.85859979901995, 26.492201021739415, 32.60227836881365, 55.22815254756382, 43.31302029745919, 52.9365359033857, 70.18071065630231, 3.6944401349340166, 0.2966543973556587, 0.18044317034738405, 0.1674246210604906, 0.12582828024668352, 0.21795813659472124, 0.1514800659247807, 0.30025568125503405, 0.0997544661430376, 0.18145474392388547], [0.01970243643570159, 0.05667409799726946, 0.03217820350879005, 0.0643826120400003, 0.0475757169271154, 0.11072084733418056, 0.12300913009260382, 0.10094488119440419, 0.14151542633771896, 0.2212006790297372, 0.07686783958758626, 0.908077498631818, 48.2071715763637, 54.44162688936506, 31.431819575173513, 45.70884949820382, 61.826384271894185, 19.218041590281896, 34.55106394631522, 51.53088753564017, 62.21257209777832, 6.03656497171947, 11.293251974242073, 74.07319572993687, 66.75307396480015, 63.378764697483604, 59.335232734680176, 62.203845160348074, 60.9228127343314, 58.923329625810894, 49.36329276221139, 48.93284491130284, 48.613391058785574, 50.81941631862095, 48.66721875326974, 50.27288143975394, 47.24741343089512, 43.82631499426705, 44.46837370736258, 45.044733728681294, 46.22494431904384, 49.74013178689139, 51.528073515210835, 51.205878598349436, 47.70194026402065, 43.23086132322039, 39.66589001246861, 41.23113850184849, 39.49916451317923, 37.72484472819737, 38.944868496486116, 38.83473607472011, 40.66103880746024, 40.37595074517386, 42.92784343447004, 47.95209278379168, 44.94624301365444, 41.62320102964129, 44.579881872449604, 52.084919520786826, 51.37749562944685, 49.32607821055821, 47.53009046827044, 43.48365763255528, 43.69711324146816, 49.32142986570086, 46.14295210157122, 49.43212856565203, 50.57416922705514, 48.55607884270804, 47.70701592309134, 47.89014611925398, 49.298181193215505, 48.52952977589199, 46.59838220051357, 48.65220022201538, 48.99074077606201, 52.32576492854527, 44.5905647277832, 35.51926415307181, 37.76006167275565, 38.0022793497358, 42.383518082754954, 44.98488194601876, 40.224757943834575, 38.61786195210048, 35.51616873059954, 42.493838105882915, 39.21407297679356, 37.75694193158831, 41.59783315658569, 38.32556513377598, 33.183731419699534, 43.29111957550049, 42.34838451657976, 38.29806416375296, 29.246645859309606, 32.70835999080113, 45.55751773289272, 50.912841796875, 51.91944817134312, 44.669878414699006, 47.27230882644653, 47.12889105933053, 47.79949992043631, 48.612011841365266, 46.68139232907976, 48.47868980680193, 46.14102745056152, 49.43824645451137, 44.86179460797991, 45.454705238342285, 47.55216836929321, 47.206349577222554, 45.16836997440883, 43.904447487422395, 47.1586606161935, 45.630282742636545, 50.28707660947527, 41.591892446790425, 39.946381841387065, 39.758936813899446, 40.443469864981516, 40.840045247759136, 38.8209855897086, 39.66852337973458, 38.578545570373535, 36.75306272506714, 41.299939564296174, 41.860054697309224, 40.66073656082153, 43.159444264003206, 40.82114962169102, 45.01456812449864, 48.13382986613682, 52.05472264971052, 54.61277491705758, 55.544903550829204, 54.07683604104178, 54.50606448309762, 54.6686384337289, 54.860169001988, 54.81882374627249, 55.953415938786094, 52.532133374895366, 45.467764377593994, 42.58283063343593, 47.49062817437308, 52.6444753238133, 53.9660643850054, 55.20331621170044, 59.07377896990095, 64.44247136797223, 61.04412828172956, 58.22969790867397, 25.255239282335552, 1.599393891436713, 54.635214124407085, 52.23654658453805, 28.486056089401245, 24.845722879682267, 23.191561767033168, 27.283597367150442, 50.20898233141218, 45.5190247126988, 51.5399340902056, 4.079461531979697, 0.2627628759614059, 0.019221071819109575, 0.06608613527246884, 0.05749200750142336, 0.028618686832487583, 0.05671426048502326, 0.07447163388133049, 0.002335830720507407, 0.023339111025312116, 0.06138571285243545, 0.0589164017832705, 0.1308828911611012, 0.05639212937759502, 0.027601589980934347, 0.16245887109211513, 0.04013788407402379, 0.08309067745826074, 0.11887678397553307, 0.2066660382385765, 0.06479841151407786, 1.6348551086017062, 56.889571053641184, 60.215715408325195, 33.69526127406529, 51.37010622024536, 68.13475799560547, 21.172990219933645, 47.93081739970616, 53.78082193647112, 70.93391622815813, 8.04483277457101, 10.981274383408682, 77.14588369641984, 70.50920064108712, 65.35060092381069, 62.95621000017439, 66.46281991686139, 65.49601282392229, 62.00416782924107, 53.516390868595664, 51.691251959119526, 53.37391110828945, 53.7976713180542, 50.82121590205601, 51.90331792831421, 50.097960540226524, 45.146778447287424, 47.08390147345406, 48.171374457223074, 51.61058684757778, 52.03761965887887, 53.7600850377764, 52.79033190863473, 48.99454491479056, 44.084774085453574, 40.99181474958147, 42.9470864704677, 41.576165199279785, 38.18079941613333, 39.7027918951852, 39.34365340641567, 40.46841389792306, 43.968489033835276, 45.53084707260132, 48.75777809960501, 46.96230104991368, 41.96014697211129, 46.215863023485454, 52.57334661483765, 52.4552515574864, 49.29540538787842, 48.61861263002668, 45.35474497931344, 47.454108442579, 50.34939500263759, 50.96591213771275, 51.96946825299944, 51.94245365687779, 51.44842978886196, 51.9162381035941, 51.26281213760376, 51.402505670275005, 50.201843057359966, 47.82737956728254, 49.809210777282715, 49.6873254776001, 52.621400356292725, 45.674681731632774, 36.56985262462071, 38.55234391348702, 37.756313119615825, 41.454335485185894, 43.48870897293091, 38.42277043206351, 36.80191898345947, 34.3909044946943, 40.77538878577096, 37.8084454536438, 35.70233528954642, 39.608081000191824, 38.2062645639692, 32.887237889426096, 39.87474591391427, 40.87867375782558, 40.09532690048218, 28.600697892052786, 32.51765625817435, 45.0750070299421, 51.437149388449534, 52.085253034319194, 46.54507909502302, 47.69668047768729, 47.71282114301409, 48.011353969573975, 50.14936678750174, 48.96403884887695, 50.51767689841134, 49.2577600479126, 53.81335687637329, 49.90055179595947, 50.360473905290874, 51.4792172568185, 50.50051484789167, 48.8131274495806, 47.902037961142405, 49.55920764378139, 48.72202614375523, 51.771684306008474, 44.334923131125315, 44.69162975038801, 43.38446862357003, 43.33403859819685, 42.64577089037214, 40.689995425088064, 42.27534852709089, 43.60158940723964, 39.79813160215105, 43.676021984645296, 45.053429399217876, 44.1598493712289, 45.44233397075108, 44.853627000536235, 48.7316563470023, 51.62790870666504, 57.28104993275234, 58.582972117832725, 58.797310147966655, 58.65740816933768, 56.92158835274832, 57.343437807900564, 57.69497149331229, 57.4915178162711, 59.52158342088972, 56.91687747410366, 47.41107824870518, 46.02979026521955, 49.5132348878043, 56.13325268881661, 60.03907830374581, 59.41294138772147, 64.65255015236991, 68.30169541495187, 64.36243506840297, 61.781929697309224, 24.583504813058035, 2.2776574960776736, 63.16475323268345, 51.637792519160676, 34.654581683022634, 31.02279302052089, 26.501021759850637, 32.48329046794346, 48.78220796585083, 47.219717911311555, 59.50139890398298, 7.308077931404114, 0.3843476117721626, 0.03653126349672675, 0.03254884308470147, 0.10944005141832999, 0.015491794162829007, 0.010033797572499939, 0.09032485141818013, 0.0038934992460001793, 0.1131930286064744, 0.12122653717441217, 0.2480034636599677, 0.30052964655416353, 0.2183801718056202, 0.10957650481058018, 0.23480196776134626, 0.14702169730194978, 0.12844908104411193, 0.18525056381310734, 0.3569054843059608, 0.2317315696605614, 1.9579213729926517, 69.42002882276262, 65.76544312068394, 45.63970797402518, 52.78034734725952, 78.55675016130719, 30.321497440338135, 51.267616816929404, 61.45086887904576, 73.52783162253243, 8.558038013322012, 14.676487071173531, 78.88810975211007, 69.3918399810791, 69.71675859178815, 66.23557213374546, 69.23590156010219, 66.24188109806606, 65.56712763650077, 56.38137633459908, 56.926170689719065, 55.73725400652204, 56.28596714564732, 52.795939104897634, 57.44521849496024, 51.84932347706386, 48.79699373245239, 49.49870273045131, 51.74480519975935, 53.159243038722444, 55.761763777051655, 57.244339125497, 54.409043312072754, 51.28257628849575, 49.36334834780012, 44.62218597957066, 43.71712752750942, 43.63400622776577, 39.47850751876831, 41.74322073800223, 42.19392606190273, 41.91181877681187, 43.41986969539097, 44.58610051018851, 49.44335685457502, 49.16734313964844, 43.36436401094709, 47.93133504050118, 55.98868499483381, 53.7535537311009, 52.97345863069807, 50.70108502251761, 48.410830225263325, 47.18086011069161, 54.558731828417095, 53.97393321990967, 55.36816569737026, 55.729708262852256, 54.74768461499895, 56.33895410810198, 55.30760867255074, 55.92584548677717, 53.77421072551182, 51.86930649621146, 52.198369707380024, 53.76904126576015, 54.86441087722778, 46.74793522698538, 37.776782512664795, 43.02567754473005, 38.75996650968279, 40.02995129993984, 43.511499064309255, 40.78566517148699, 37.34294394084385, 32.67755167824881, 41.37273931503296, 40.80498811176845, 37.63053682872227, 41.083760261535645, 38.52497843333653, 33.913146359579905, 41.73176663262503, 44.07804822921753, 40.25184897014073, 28.256864547729492, 33.63505513327462, 47.48883901323591, 54.29568692616054, 55.27803713934762, 47.75314848763602, 49.78554173878261, 49.2865047454834, 50.003909724099294, 52.675936767033164, 51.63057334082467, 54.489652838025776, 52.1302877834865, 56.516841888427734, 54.60494777134487, 51.67558377129691, 53.83347538539341, 54.33315161296299, 52.0956266948155, 52.59240204947335, 53.61343288421631, 51.28366715567452, 56.056002616882324, 47.962553296770366, 46.95958777836391, 45.48773002624512, 44.6741862978254, 45.17326150621687, 43.13358654294695, 46.29571172169277, 45.03416551862444, 43.66096871239798, 47.11318118231637, 48.0346234866551, 46.53528560910906, 47.41377762385777, 49.14680773871285, 53.03002044132778, 54.27371324811663, 58.00537531716483, 59.22579165867397, 59.588070733206614, 61.34606919969831, 60.973666599818635, 60.41483688354492, 59.57688413347517, 63.42466449737549, 62.2421019417899, 59.36426230839321, 50.545803206307546, 49.13606582369123, 52.84035893848964, 61.58715084620884, 61.550811767578125, 63.90106773376465, 69.23900045667375, 72.3421493257795, 66.70363058362688, 67.61041218893868, 38.57100330080305, 2.87960056747709, 62.11322675432478, 62.19393008095877, 42.230504853384836, 35.76001228604998, 38.72341898509434, 36.933163506644114, 65.47670378003801, 58.46448448726109, 73.42026656014579, 8.444688575608389, 0.42133691694055286, 0.27887729555368423, 0.14905933796295098, 0.1969773724142994, 0.1791603456118277, 0.3352516676698412, 0.20627626058246407, 0.070893196256033, 0.24530161863991193], [0.04554913977959326, 0.15152358716087683, 0.06345835234969854, 0.04455874667369893, 0.17773842119744845, 0.434171053980078, 0.11970344318875245, 0.17654152613665375, 0.15036219305225781, 0.03873538272455335, 0.047615702995764356, 0.9843952634504863, 48.49087347303118, 46.26052951812744, 34.00375434330532, 24.78009193284171, 31.0151013646807, 27.250626427786692, 20.052858965737478, 46.991309779030935, 63.511655943734304, 21.896202155521937, 3.377993549619402, 68.62690585000175, 58.94142273494175, 62.48453848702567, 61.940564019339426, 64.11001396179199, 58.84134088243757, 59.21849605015346, 47.69662836619786, 48.444855553763254, 50.01241431917463, 49.3283155305045, 47.46834182739258, 46.31026472364153, 44.97682898385184, 45.776403359004426, 46.95047174181257, 50.23034109388079, 51.041883741106304, 53.697912556784495, 54.367882183619905, 51.822604179382324, 52.454869406563894, 44.40475252696446, 39.39980179922921, 40.03552722930908, 39.69267531803676, 39.4404730796814, 39.59083209718977, 40.066752433776855, 38.96276010785784, 42.539046560014995, 41.97267804827009, 46.534104415348594, 45.284978117261616, 44.62658418927874, 42.89422457558768, 45.41843564169747, 49.108002049582346, 48.45287377493722, 46.46048477717808, 47.22042315346854, 47.430651324135916, 46.39604023524693, 47.45625196184431, 48.478804452078684, 49.05030073438372, 47.6974447795323, 46.14376156670706, 49.19860308510916, 48.11207158224923, 46.000454970768516, 46.29043109076363, 49.02028799057007, 48.130084787096294, 51.69692516326904, 46.286352498190745, 31.96696983064924, 37.67654779979161, 36.84445238113403, 38.654729093824116, 41.501979282924104, 37.22859048843384, 41.77259424754551, 41.178908893040244, 41.92871332168579, 55.313796043395996, 42.73598630087716, 47.72542864935738, 48.550888538360596, 41.29320675986153, 37.2125575201852, 32.90674148287092, 39.02286549976894, 31.631465639386857, 37.616546630859375, 47.442115851810996, 48.24607106617519, 47.78398806708199, 45.3374856540135, 46.476781776973176, 45.526615619659424, 48.72441284997122, 47.08992556163243, 46.69142900194441, 48.01189245496477, 49.2330835206168, 48.520514488220215, 45.18846069063459, 47.61911078861782, 46.57956647872925, 48.11135591779436, 46.527708598545615, 45.61890159334455, 48.597219126565115, 47.6140525000436, 41.337737764631, 39.60174771717617, 42.90277780805315, 39.92714575358799, 40.61004250390189, 38.11000074659075, 39.06286975315639, 39.65117372785296, 39.45049238204956, 38.609166281563894, 41.1057756287711, 40.019838196890696, 41.39705801010132, 42.521175793239046, 40.252036571502686, 40.86086205073765, 49.0385548046657, 50.31970535005842, 55.53833750316075, 52.52837439945766, 55.738789558410645, 51.2975183895656, 50.20234680175781, 56.18013218470982, 56.15243666512625, 56.04852288109915, 56.594293458121165, 48.46831962040493, 45.77053213119507, 46.15743909563337, 51.08150931767055, 53.29956190926688, 58.38995810917446, 58.51141956874302, 68.07497569492885, 56.72889396122524, 57.66763033185686, 8.849084155900137, 4.85516927923475, 56.84579045431954, 38.78069993427822, 26.826386792319163, 27.25809747832162, 29.483082635062082, 19.610595703125, 24.935250418526785, 36.948932443346294, 50.99435111454555, 6.2404051423072815, 0.051098904838519435, 0.03019778031323637, 0.1107803141432149, 0.057621533051133156, 0.040187230533255, 0.005088016465638897, 0.01541853104052799, 0.045719516530100784, 0.05686644910435591, 0.029041000242744173, 0.046015697065740824, 0.028641536499240568, 0.08702570559190852, 0.131705818431718, 0.17712624690362386, 0.10252671595662832, 0.19796332450849669, 0.11887062287756375, 0.0785546505025455, 0.0376535807736218, 1.2633365584271294, 56.91485554831368, 53.81743894304548, 39.18108292988369, 31.382542950766428, 41.15441301890782, 30.20493793487549, 24.01538709231785, 49.61571386882237, 68.35382080078125, 27.700610876083374, 3.5219000790800368, 69.06455203465053, 65.6603307723999, 66.19869109562465, 65.18469183785575, 70.44820240565709, 61.95596122741699, 62.480737822396414, 52.65811116354806, 52.503722190856934, 51.69633456638881, 53.61224126815796, 47.300608839307515, 49.04118122373308, 48.762179783412385, 48.070017610277446, 49.616790839603965, 54.83364077976772, 54.03468826838902, 55.351997239249094, 55.18855128969465, 56.275398935590474, 54.08177273614066, 47.3323586327689, 40.335936069488525, 41.77295902797154, 41.921754700796946, 41.75199978692191, 40.93733739852905, 40.56003284454346, 38.763089724949424, 42.82010119301932, 43.772167682647705, 47.70352792739868, 46.472553798130576, 47.54043633597237, 44.0395621572222, 46.06044919150216, 48.91620397567749, 50.78962591716221, 49.12708527701241, 49.286039216177805, 47.32911729812622, 48.31774868283953, 50.942260469709126, 48.71109315327236, 49.62116820471627, 50.551240171704976, 47.514429228646414, 50.18300649097988, 48.630712917872835, 49.34055825642177, 48.506159509931294, 50.72405924115862, 49.828109877450125, 50.53607225418091, 45.14022977011544, 32.366602420806885, 37.03330094473702, 37.38045379093715, 37.17800760269165, 38.24541071483067, 36.23194783074515, 41.350981031145366, 41.90091357912336, 39.68811729976109, 54.45516198022025, 41.38832759857178, 47.44154609952654, 46.78834247589111, 41.89952046530587, 39.449304240090505, 32.933405194963726, 36.442738805498394, 31.392874922071183, 38.16315793991089, 46.20669834954398, 49.28931529181344, 49.28997189658028, 45.663852964128765, 45.87351485661098, 45.68947444643293, 47.58683293206351, 48.61706665584019, 47.971314975193565, 49.65292147227696, 51.064097132001606, 51.74472876957485, 48.87108932222639, 51.25685058321272, 48.44209711892264, 51.76991251536778, 51.61295965739659, 49.71563591275896, 53.314816679273335, 51.701486655644004, 47.6668518611363, 42.71193858555385, 46.23492193222046, 41.287933077131, 43.43761886869158, 39.582459517887656, 40.23400947025844, 42.3071608543396, 42.08552374158587, 42.01657676696777, 41.512040274483816, 41.13648319244385, 43.630077021462576, 43.04906170708792, 44.17103944505964, 43.314201491219656, 50.5275433404105, 52.55353035245623, 55.97442034312657, 56.76936721801758, 57.8911087172372, 54.36805241448538, 58.54286016736712, 57.73534747532436, 61.067856379917686, 56.834020205906455, 60.06239645821707, 53.49877371106829, 48.781978675297324, 48.47522612980434, 56.003366538456504, 57.24281399590628, 62.425944328308105, 63.42066233498709, 69.36513805389404, 57.014742851257324, 59.23073877607073, 5.489936292171478, 6.266796571867807, 62.32177693503243, 38.33665445872715, 37.909218651907786, 32.718441826956614, 38.416395459856304, 23.1164447920663, 34.79908684321812, 46.62556702750069, 59.777617590767996, 9.253740293639046, 0.23308318427630834, 0.009232998177010034, 0.07412771162177835, 0.04759026471791523, 0.014025444364441293, 0.05453660412292395, 0.026796920391331826, 0.01075481142782207, 0.008541658354390944, 0.22707658873072692, 0.17818366230598517, 0.09319459992860045, 0.15238616801798344, 0.22413667291402817, 0.40261844279510633, 0.1533274317958525, 0.262282554592405, 0.18270812023963245, 0.3048756904900074, 0.239571390407426, 2.3062085126127516, 68.91340787070138, 62.92078808375767, 47.02973679133824, 35.28058310917446, 44.97198608943394, 38.33485834939139, 28.180694920676096, 58.32814693450928, 75.05530970437187, 26.19938656261989, 5.319495677947998, 73.00355529785156, 64.2364364351545, 72.57043933868408, 67.24921008518764, 75.90405995505196, 64.6123548235212, 65.88021346500942, 57.96464845112392, 55.49791635785784, 52.71983201163155, 58.22289909635271, 48.566469873700825, 51.72257096426827, 51.60599756240845, 52.09538350786482, 50.24489756992885, 60.11919103349958, 56.107290744781494, 58.071574279240195, 59.02768462044852, 57.574520996638704, 54.102551324026926, 49.926065581185476, 40.448733125414165, 42.05913100923811, 42.784887722560335, 42.288633482796804, 41.50224331447056, 42.06223685400826, 38.94983993257795, 44.811694622039795, 45.62204565320696, 50.60489068712507, 48.08950383322579, 49.309482438223704, 45.271349225725444, 46.87163053240095, 51.474544593266074, 53.05163976124355, 53.67222506659371, 56.202946594783235, 51.009067399161204, 52.75607034138271, 54.55172457013811, 52.59434059688023, 52.61062717437744, 53.60290288925171, 52.21500369480678, 52.15363720485142, 50.558431557246614, 50.99966301236834, 49.911922522953574, 51.47663600104195, 51.762491839272634, 52.83950778416225, 47.46260608945574, 31.582755293164933, 38.65263768604824, 38.08873578480312, 39.23665462221418, 39.55070277622768, 36.709292548043386, 42.28983204705374, 45.84140028272356, 38.54233850751604, 56.027018206460134, 45.73149367741176, 51.02029568808419, 50.682182448250906, 45.116140365600586, 39.68559857777187, 32.393564905439106, 37.92560945238386, 31.982829093933105, 39.095870222364155, 48.70726122174944, 52.86094992501395, 48.717228412628174, 47.73627826145717, 48.569572244371685, 48.519861357552664, 48.68268196923392, 49.42702511378697, 49.30551501682827, 49.88526575905936, 51.13640703473772, 56.53672763279506, 51.220858914511545, 52.74778808866228, 54.04558651787894, 53.589169774736675, 52.52983352116176, 55.870676789964946, 56.061773095812114, 54.55374302182879, 52.09447676794869, 44.943495001111714, 49.3582101549421, 44.50542150224958, 45.32167502811977, 42.12679256711687, 40.57029185976301, 41.860784258161274, 42.94714205605643, 45.234760011945454, 45.33838544573103, 43.27982527869088, 45.30148008891514, 45.30222354616438, 45.26489087513515, 46.808572156088694, 52.416741166796, 56.8720303262983, 61.71145411900112, 59.992699078151155, 61.70614569527762, 54.573396001543315, 60.74992070879255, 64.09799357822963, 63.275521414620535, 60.11106858934675, 62.794059889657156, 54.8242780821664, 51.48102726255144, 53.20943682534354, 58.86251899174282, 62.13655185699463, 66.94307940346854, 69.08969756535122, 77.4181558064052, 61.785890170506065, 68.97461455208915, 14.113482356071472, 6.002846666744777, 69.60089043208531, 48.05956751959664, 43.64517198290144, 37.071258953639436, 46.267436027526855, 27.620185477393015, 36.84089142935616, 50.10235527583531, 70.4290462221418, 11.203908562660217, 0.6765405599560056, 0.11559452010052544, 0.1882576003138508, 0.15550456568598747, 0.3121404935206686, 0.12357033283582755, 0.12994621427995817, 0.21702133757727488, 0.11662597475307328], [0.02962493390909263, 0.06439894437789917, 0.05860920183892761, 0.06292036228946277, 0.0646003946395857, 0.06390737289828913, 0.01740436046384275, 0.08189606906047889, 0.055119336782289405, 0.1435020954481193, 0.19166200049221516, 2.386971550328391, 49.721691267830984, 44.393260206495015, 37.199293409075054, 30.287503378731863, 27.855237824576243, 29.13150552340916, 19.355357101985387, 32.489630699157715, 56.524526596069336, 46.813220500946045, 3.7554652946335927, 40.951661109924316, 67.19083826882499, 57.67103147506714, 66.0040442602975, 57.74130555561611, 61.25827176230294, 49.70854180199759, 49.17999233518328, 49.46890190669468, 48.242308616638184, 46.07449497495379, 47.340164933885845, 46.620894363948274, 47.218981402260916, 48.60570982524327, 52.183372020721436, 51.34012821742466, 52.052728516714915, 53.3332884652274, 55.54197835922241, 52.775761536189485, 55.00914532797677, 44.25632858276367, 39.281873498644146, 40.10696513312203, 41.9088762147086, 41.29463808877127, 41.1918568611145, 39.48560510362898, 40.9244658606393, 39.45919500078474, 39.67186893735613, 40.95815420150757, 44.12539325441633, 46.233254364558626, 48.43438809258597, 47.31688846860613, 49.91337122235979, 47.86767217091152, 48.95473868506295, 47.62866108758109, 47.66685880933489, 47.551261629377095, 47.80606944220406, 47.669169085366384, 49.09991782052176, 46.773431641714915, 46.55467108317784, 49.92945977619716, 47.35021202904837, 46.13185582842146, 47.658434118543354, 50.8433632850647, 49.323854787009104, 50.85309771129063, 44.64119625091553, 36.46199573789324, 38.00287342071533, 36.28183242252895, 39.981317383902415, 41.21209001541138, 42.29443175452096, 43.38681711469378, 44.20584644590105, 40.31926734106881, 42.621865613119944, 45.71563788822719, 45.77301263809204, 45.021596227373394, 38.36119897024972, 36.0440685408456, 37.85489068712507, 38.60999311719622, 34.55562891278948, 33.30930968693325, 44.7614244052342, 51.27792794363839, 48.921908446720664, 45.74203062057495, 43.46951804842268, 47.421837534223286, 46.95712464196341, 50.13242360523769, 48.676668303353445, 47.539845739092144, 48.44415031160627, 46.92343282699585, 50.029944624219624, 47.55461760929653, 47.12823792866298, 46.51196050643921, 46.23099620001656, 44.070988859449116, 46.592048917497905, 46.03173228672573, 48.06971188953945, 42.76367834636143, 41.504133224487305, 38.1102682522365, 39.19671637671334, 37.90855162484305, 39.24705260140555, 40.87570687702724, 38.88891117913382, 39.76781661169869, 39.92018018450056, 38.3970308303833, 38.29393693378994, 39.11789601189749, 41.05003023147583, 40.50688259942191, 44.389984130859375, 47.95280497414725, 52.252280780247276, 53.304224150521414, 55.318701471601216, 57.54203816822597, 57.91722352164132, 45.56889888218471, 59.17339529309954, 56.13688312258039, 57.82758133752005, 53.56546599524361, 46.03939962387085, 45.22221156529018, 53.19122212273734, 53.33924307141985, 58.36575058528355, 57.79053354263306, 69.94756385258266, 61.60745348249163, 44.13637488228934, 1.2450935201985496, 13.83570727280208, 47.631714820861816, 47.6411018371582, 21.91168621608189, 21.807994774409703, 20.207202775137766, 31.923831939697266, 38.97479438781738, 31.873721531459264, 51.50278902053833, 11.614263091768537, 0.05983091092535427, 0.07440492710364716, 0.04069484597338097, 0.02873588340090854, 0.04744317189657262, 0.019094058545306325, 0.04277483739757112, 0.10835196623312575, 0.022529230286766375, 0.014810750260949135, 0.02798510475882462, 0.03648327410753284, 0.08071037661284208, 0.08891637556787048, 0.03659838078809636, 0.02468952633041356, 0.05417801532894373, 0.06187503838113376, 0.12515118372227463, 0.07019258170787777, 2.711645019905908, 59.387413706098286, 48.4692576272147, 43.77891785757882, 38.775012833731516, 33.181021622249055, 34.37088326045445, 21.915387868881226, 41.5881473677499, 60.547172273908345, 56.19071429116385, 4.857900789805821, 41.11037881033761, 71.07815388270787, 61.494413239615305, 68.64486694335938, 62.49489825112479, 65.90176677703857, 52.993983609335764, 54.57284014565604, 54.015108244759695, 52.125625542231965, 47.34554978779384, 50.59307527542114, 48.12575953347342, 49.9537923676627, 51.56116083690098, 53.4004601751055, 53.1137809753418, 53.716624055589946, 55.85216678891863, 58.21931035178048, 54.06203637804304, 57.594615186963765, 45.86328363418579, 40.303984778267996, 41.023922375270296, 43.06515026092529, 41.13818897519793, 44.106667859213694, 41.86177090236119, 41.92773709978376, 40.66570104871477, 41.33098064150129, 42.75815800258091, 43.941648142678396, 45.59275899614607, 50.468983922685894, 49.58414125442505, 51.20768165588379, 49.51345375605992, 47.378480775015696, 47.41163410459246, 46.36986984525408, 50.07003573008946, 50.05187313897269, 49.162993567330496, 49.37217256001064, 47.65135390417916, 48.508348192487446, 49.60158123288836, 48.48913642338344, 50.089052949632915, 47.791426113673616, 50.568054812295095, 48.80002662113735, 51.58907869883946, 45.6467638696943, 35.45219666617257, 35.65241943086897, 36.25674247741699, 38.82151017870222, 39.429769379752024, 40.608103956495015, 41.64697429112026, 43.27636160169329, 38.48358106613159, 41.57410505839756, 46.517640658787315, 47.33319936479841, 45.086006028311594, 34.83442538125174, 34.8224640573774, 37.120636326926096, 39.47520365033831, 33.58581672395979, 32.19966152736119, 46.787658078329905, 52.48123434611729, 50.0023637499128, 45.03346722466605, 43.78315625871931, 45.744476386478965, 49.24513169697353, 50.84402683803013, 51.2435691016061, 49.536903926304404, 50.89579439163208, 51.772646631513325, 51.221227169036865, 50.59137644086565, 49.940701961517334, 52.20864609309605, 50.082090854644775, 49.44592421395438, 51.384659222194124, 51.07257046018328, 51.50339698791504, 47.94143077305385, 45.41309247698103, 41.33631338391985, 42.21935994284493, 41.24350282124111, 41.95055498395647, 42.43072066988264, 43.56622655051095, 42.72830506733486, 42.24294907706124, 40.38551494053432, 42.569531781332834, 43.016273157937185, 45.046644483293804, 43.01067638397217, 45.16471174785069, 52.171271732875276, 55.689123834882466, 60.54692908695766, 61.18960271562849, 60.201416015625, 60.694501876831055, 48.799321378980366, 58.39994267054966, 58.58109610421317, 61.995135171072825, 58.61064679282052, 50.195190157209126, 49.09395279203142, 55.28430788857596, 58.022235121045796, 63.54600088936942, 63.5407133102417, 69.81959193093437, 63.65011269705636, 42.32902683530535, 0.5014531750764165, 19.194207532065256, 50.57720906393868, 50.74426460266113, 31.82744652884347, 26.88639838354928, 27.37127842221941, 33.74839762278965, 40.41302980695452, 42.55832086290632, 58.53353568485805, 18.51257014274597, 0.07626064574079854, 0.07557523716241121, 0.023444071911009293, 0.057031139731407166, 0.05266496705423508, 0.03550244156005127, 0.07647426213536944, 0.08145082116659198, 0.17846085743180343, 0.1258903390594891, 0.13212489522993565, 0.2438705882855824, 0.17409836580710752, 0.18958856032363006, 0.1853724287024566, 0.12219994994146482, 0.18894359921770437, 0.21565392666629382, 0.16641064547002316, 0.3045932299324444, 4.092702627182007, 67.92704159872872, 57.82506608963013, 50.220752579825266, 40.868821212223594, 40.24319846289498, 42.77049452917916, 30.800106729779923, 47.79132536479405, 69.4093633379255, 54.517991065979004, 6.40484424999782, 46.328670501708984, 70.35054547446114, 64.63676384517125, 70.95797089168003, 65.47900363377163, 68.96902820042202, 57.96137237548828, 57.321589197431294, 56.684647832598, 56.43625668116978, 48.79031998770577, 53.83773463112967, 51.314593587602886, 51.4380978175572, 53.3020076751709, 55.849519525255474, 55.16382959910801, 56.56210592814854, 59.00479030609131, 59.54353278023856, 56.075693811689106, 59.908542496817454, 45.74853760855538, 41.040174211774556, 41.85652501242501, 42.813417025974815, 42.63597740445818, 45.48400926589966, 43.01396983010428, 42.43101249422346, 42.2457526751927, 43.36143881934029, 43.31117902483259, 46.013145855494905, 49.2928831917899, 53.25438124792916, 49.822672912052695, 53.400481019701274, 51.54561424255371, 51.632167952401296, 49.281946727207725, 50.38273245947701, 53.96750613621303, 55.47344132832119, 51.332078729357036, 52.271172932216096, 52.5510185786656, 50.20292697634016, 52.32423285075596, 52.83689873559134, 51.7078720501491, 49.03856175286429, 52.1505834715707, 50.56619616917202, 53.41043084008353, 45.615368434361045, 35.70850528989519, 37.075014454977854, 36.4503436088562, 39.79158639907837, 40.881498200552805, 43.13475036621094, 43.67931195667812, 44.71101522445679, 40.09296451296125, 41.27637127467564, 48.414231368473594, 48.626915727342876, 46.78101560047695, 36.08567087990897, 35.875963824135916, 38.508664063044954, 40.08711065564837, 35.153667313711985, 32.43302372523716, 47.90037039348057, 54.36480760574341, 51.16101060594831, 46.513937268938335, 43.3265414919172, 48.12904255730765, 50.355655329568044, 52.500428744724815, 50.77602481842041, 51.27950865881783, 55.81869731630598, 55.35288660866873, 55.98348079408918, 53.986064774649485, 53.99549348013741, 55.991207190922324, 53.78676264626639, 54.02939721516201, 57.016424315316335, 54.86730132784162, 53.87021745954241, 50.42315707887922, 49.319817883627756, 44.92622872761318, 46.84997647149222, 43.26206915719168, 42.086499963487896, 43.03653063092913, 45.13380963461739, 44.94309547969273, 45.00988851274763, 40.55886207308088, 44.89745971134731, 45.15940679822649, 47.00749908174787, 45.46678468159267, 51.143466404506135, 56.82771471568516, 60.410174642290386, 63.3109780720302, 65.45300347464425, 60.709551674979075, 60.783014978681294, 51.355574062892366, 61.70351927621024, 59.70289666312081, 66.17654023851667, 63.09647328513009, 52.78347403662545, 51.31517376218523, 57.508506161826, 59.79048565455845, 68.23458971296037, 64.171964100429, 75.69234834398542, 69.82369136810303, 55.49798583984375, 2.3062004787581305, 16.954011031559535, 60.441372053963796, 60.92432049342564, 36.87564631870815, 30.435447897229874, 32.25103303364345, 42.077324867248535, 52.24853570120675, 42.4296749659947, 70.3799433026995, 22.179367303848267, 0.32587387944970814, 0.2440938534481185, 0.2184768087629761, 0.09621019954127924, 0.22746408650917666, 0.09815901318298918, 0.16601748870951788, 0.2206524634467704, 0.3635806675468172], [0.024954360244529586, 0.12326709553599358, 0.02482463283065174, 0.02442147276763405, 0.08590445361499276, 0.10808138682373933, 0.06770949637783424, 0.3333041364593165, 0.03260949733001845, 0.013915257910931749, 0.3402716868690082, 2.453555486031941, 39.87413794653756, 51.52304301943098, 32.68884597505842, 33.776107038770405, 52.54334429332188, 25.076807805470057, 33.067939690181184, 28.360714060919626, 47.823849882398335, 61.146287645612446, 8.53159316948482, 19.800218990870885, 77.94382871900285, 53.53037411825997, 70.17652089255196, 56.164717606135774, 59.23399748120989, 44.14758927481515, 52.85781281335013, 44.13047933578491, 50.69142702647618, 47.3169127873012, 50.13362564359392, 46.88293525150844, 52.639392716544016, 48.04428843089512, 54.84499761036464, 51.840165751320974, 55.227989264896934, 53.19639505658831, 54.98140811920166, 51.56521511077881, 55.916500159672324, 43.72955438068935, 41.224951131003245, 39.84808567592076, 40.58648463657924, 40.21371030807495, 42.023368631090435, 42.05838755198887, 39.73180409840175, 40.27061605453491, 39.87129265921456, 40.536551407405305, 42.41716820853097, 41.04203980309622, 49.02637808663504, 52.15204954147339, 50.901808057512554, 49.16754116330828, 50.461465971810476, 49.74231352124895, 48.710839544023784, 46.91459124428885, 47.035034792763845, 48.635653087071006, 46.44535507474627, 45.90809604099819, 47.572509220668245, 46.92765038354056, 47.507880551474436, 46.26581709725516, 50.38931935174124, 48.59328644616263, 49.06125456946236, 48.17110347747803, 39.3758339881897, 33.11417647770473, 35.50030599321638, 33.52423831394741, 38.88103192193167, 40.590420791081016, 38.0178850037711, 40.1963780266898, 41.544429302215576, 40.68391227722168, 40.7437675339835, 42.00899975640433, 44.513731547764365, 37.11689819608416, 32.711660385131836, 37.144173349652974, 37.6250581741333, 36.97469636372158, 34.08761215209961, 35.96315329415457, 42.18466411318098, 51.07718406404768, 49.93814502443586, 51.8262346131461, 46.46095378058297, 46.060567310878206, 44.50377825328282, 49.1168783732823, 46.75969157900129, 47.27750607899257, 47.33917134148734, 47.86721706390381, 47.43567834581648, 47.08491243634905, 46.65659073420933, 49.667495318821494, 47.73708077839443, 45.36790486744472, 45.90273897988455, 45.90345811843872, 46.632942540305, 46.997618743351524, 39.74103478022984, 38.077316420418875, 37.48589965275356, 39.037679059164866, 40.62443569728306, 39.223255021231516, 40.57376248495919, 40.83330202102661, 39.05846459524972, 39.98008407865252, 38.23537056786673, 40.1768535886492, 40.4479375566755, 39.716945375714985, 41.43599918910435, 45.34619174684797, 48.925090721675325, 52.91895696095058, 52.67664895738874, 55.51410218647548, 56.63425949641636, 46.56948116847447, 50.48652465002877, 58.39600304194859, 53.67420877729143, 58.16836615971157, 48.42785678591047, 47.815984521593364, 48.977879660470144, 57.43923609597342, 56.76470150266375, 64.90970298222133, 60.180119786943706, 65.25302737099784, 16.69293941770281, 0.7844545521906444, 30.83311414718628, 55.320980480739046, 38.976948329380576, 20.82032745225089, 36.458261081150596, 27.033113070896693, 35.75533267429897, 32.57614619391305, 35.385035378592356, 52.318629128592356, 24.89587845121111, 0.39775117539933746, 0.07668388195868049, 0.027542621895138706, 0.07487927057913371, 0.005175614064293248, 0.025434038701600263, 0.050365452588136704, 0.08173018081911973, 0.028258771502545903, 0.011522380418942442, 0.05549613745617015, 0.044763671034680944, 0.05185605492442846, 0.020833634039653198, 0.005844183099855269, 0.04896387743896671, 0.21095861361495086, 0.046316685021987984, 0.023128034048048512, 0.13043337528194698, 3.7797223244394575, 52.23507356643677, 58.62607874189104, 40.19574574061802, 39.29781266621181, 55.09883267538888, 29.56988648005894, 40.23968962260655, 37.423838342939106, 50.352149963378906, 69.68550559452602, 11.249684163502284, 19.441358430044993, 79.93430001395089, 56.10286821637835, 73.62099306924003, 59.974932534354075, 60.736587115696494, 46.52580826623099, 56.09586443219866, 48.5226788520813, 52.89713266917637, 49.140387603214805, 51.46235745293753, 49.52004412242344, 54.42264788491385, 50.1022857938494, 58.014275959559846, 53.8044353893825, 57.24426964351109, 54.43078075136457, 56.62329523903983, 54.09204912185669, 57.78102493286133, 44.386280741010395, 42.10753216062273, 40.99226985658918, 41.41787828717913, 41.08054671968733, 45.23077869415283, 43.64354263033186, 42.983825070517405, 41.08007076808384, 40.91769484111241, 42.880776337214876, 43.678189822605674, 42.06357438223702, 51.96766172136579, 51.68768058504377, 50.31454283850533, 50.49160725729806, 52.35009752001081, 51.41232347488403, 48.95298079081944, 47.026888029915945, 50.50125135694231, 49.51422153200422, 49.814981256212505, 47.8742938041687, 49.57019621985299, 46.30936145782471, 48.70776844024658, 48.5860082081386, 51.535841601235525, 49.27793066842215, 51.51377064841134, 50.07388850620815, 37.63023458208357, 31.605437687465123, 35.33956636701311, 32.035385268075125, 37.81253446851458, 38.93847267968314, 38.19874313899449, 41.421856130872456, 40.64384549004691, 41.6437086377825, 41.13523946489607, 40.83909681865147, 44.37208209718977, 37.94601631164551, 34.81566524505615, 37.28240776062012, 36.76404782703945, 34.060475962502615, 32.884156363351, 34.77055753980364, 42.03381872177124, 52.02352523803711, 51.74770607267107, 54.10481991086687, 47.06408173697335, 47.307852336338584, 44.61633907045637, 49.10285690852574, 48.06817633765084, 49.18248673847744, 50.727682726723806, 50.29953472954886, 51.243975571223665, 49.44023363930838, 51.41053778784615, 51.33443416867937, 49.476124559129985, 50.32085180282593, 51.43003443309239, 49.89203330448696, 48.29710905892508, 49.539057867867605, 42.47956303187779, 39.8967786516462, 40.74116543361119, 43.62028700964791, 45.20355217797415, 42.91437782560076, 44.729115281786235, 44.141877855573384, 43.33492449351719, 43.790528297424316, 41.22478437423706, 44.497285161699565, 43.9801481110709, 44.53239440917969, 44.51708057948521, 50.12159136363438, 53.189686570848735, 56.57596411023821, 57.51407514299665, 55.64971365247454, 58.02611221585955, 48.520952224731445, 51.63243893214634, 62.579277174813406, 59.09772941044399, 61.92953027997698, 52.309648581913535, 49.97492183957781, 53.37968853541783, 61.9105339050293, 61.80073152269636, 69.25045108795166, 62.315134457179475, 67.81740597316197, 14.033024821962629, 0.9003632611462048, 37.97905499594552, 57.31149346487862, 44.816367285592214, 28.978346381868633, 41.742411272866384, 39.20910848890032, 39.73115791593279, 33.967074802943635, 41.3952236856733, 62.72771848951067, 34.66653258459908, 0.2253492692751544, 0.030443318387759582, 0.10054922063968011, 0.030527090321161916, 0.03506759900067534, 0.015513305419257708, 0.015356022698272551, 0.09354886984718697, 0.05289234074630907, 0.13651023991405964, 0.3162988003875528, 0.14261649868318013, 0.1083947614367519, 0.15037380957177707, 0.12639245497328894, 0.17037251644900867, 0.3317277639039925, 0.19794588615851744, 0.1718052974236863, 0.42507198080420494, 5.246934337275369, 62.237203461783274, 67.33190754481724, 43.823473181043354, 44.19333621433803, 66.85198851994106, 34.324240003313335, 45.172632694244385, 42.76688494001116, 59.43493243626186, 73.12585054125104, 11.803353105272565, 25.341468163899012, 81.9672109058925, 57.74225051062447, 79.55198928288051, 64.3518043245588, 63.15230900900704, 49.782592228480745, 60.14655303955078, 50.55964749200003, 57.142659187316895, 51.6631395476205, 54.12888847078596, 51.81266825539725, 56.51646668570382, 51.177286761147634, 59.5901551927839, 55.94930260522025, 60.608962603977744, 56.49297135216849, 58.13980906350272, 55.0263421194894, 58.517888341631206, 47.182030882154194, 45.18393393925258, 41.64091893604824, 42.316245623997276, 42.120209148951936, 47.25547334126064, 45.34074435915266, 45.05028533935547, 42.23272132873535, 41.863681656973704, 42.798179626464844, 45.36647353853498, 43.6561918258667, 54.736581393650596, 54.88241713387625, 56.19021054676601, 51.97690282549177, 54.83058704648699, 53.416183948516846, 53.53237519945417, 51.64048842021397, 52.582552977970664, 50.47691181727818, 51.42711271558489, 51.98098141806466, 50.40609230313982, 47.73152569362095, 52.33328982761928, 47.76703446252005, 53.947543961661204, 51.34920951298305, 53.913244179316926, 48.94126612799508, 39.767229488917756, 31.250898906162806, 35.23841796602522, 32.34189462661743, 38.258886745997835, 39.04298053468977, 37.18671716962542, 42.59682777949742, 42.725609166281565, 43.16201509748186, 42.67847606113979, 42.023900168282644, 44.75137383597237, 40.36230795724051, 35.890780857631135, 38.952799865177695, 37.445454188755576, 34.66253737040928, 34.637714930943076, 35.99645601000105, 43.2427635874067, 53.9417005266462, 53.33572728293282, 55.080652713775635, 49.66086326326643, 48.07289069039481, 46.66534546443394, 50.936059202466694, 49.53223821095058, 52.55196005957467, 53.39129202706473, 51.75207996368408, 54.11511366707938, 54.384940011160715, 54.53859594890049, 54.21596676962716, 53.21442910603115, 52.65951122556414, 55.30382537841797, 51.44481325149536, 52.71156365530831, 53.739837987082346, 45.57885217666626, 43.652328627450125, 45.38362169265747, 46.056683267865864, 47.73322452817644, 44.61614452089582, 46.76142168045044, 47.320168018341064, 45.00535133906773, 45.570399693080354, 44.293324266161235, 45.89329290390015, 45.53048229217529, 45.67393480028425, 48.107447556086946, 53.43800476619175, 55.62905665806362, 59.95025948115757, 60.160122871398926, 59.38399519239153, 61.61348451886858, 49.10742882319859, 53.879927567073274, 67.22150066920689, 62.94715649741036, 66.37901769365583, 54.65231016704014, 54.58638913290841, 57.236341748918804, 66.49122415270124, 66.38534750257219, 73.88345432281494, 65.06764248439244, 75.65820489610944, 24.832698481423513, 1.3253304490021296, 38.87985072817121, 66.55878148760114, 53.199539116450715, 31.154454435620988, 45.60474811281477, 40.88481249128069, 46.27533265522548, 45.51029430116926, 46.084132126399446, 69.10351058415004, 38.711127621786936, 0.5441119660224233, 0.2293507531285286, 0.36046488902398516, 0.18243928466524395, 0.23275157064199448, 0.15356774175805704, 0.10746788938662835, 0.20272160560957023, 0.18148253671824932], [0.026426647224330475, 0.19419512099453382, 0.032658368814736605, 0.09589852805116347, 0.032836779419864924, 0.1037221657378333, 0.11139520936246429, 0.24394962404455456, 0.12219513234283243, 0.2985864851091589, 0.3178315838532788, 5.305911949702671, 50.33151033946446, 47.349871567317415, 35.99993010929653, 28.67414035115923, 34.776477405003135, 28.70427816254752, 14.017392243657794, 19.79003987993513, 46.828100068228586, 55.799252782549175, 19.39099441255842, 5.6053232891219, 73.46624973842076, 56.34211206436157, 67.63324396950858, 57.37665714536394, 59.99460983276367, 45.721342359270366, 53.44267048154558, 47.70623772484915, 52.176528045109336, 46.206663608551025, 51.48599869864327, 48.73254224232265, 54.534069197518484, 51.1258944102696, 53.74217258180891, 53.697165625435964, 59.72812557220459, 53.280773980276926, 54.47128527505057, 55.11978496823992, 54.11566604886736, 43.66430384772164, 40.14955064228603, 40.951824392591206, 44.654279708862305, 42.37566661834717, 42.06378977639334, 43.62902784347534, 43.50000326974051, 41.83413791656494, 41.453300203595845, 39.950043542044504, 39.77381985528128, 42.42476258959089, 47.91073710577828, 46.76765421458653, 50.35182339804513, 49.050356319972444, 51.749279839651926, 48.35719360624041, 45.8818735395159, 46.64604336874825, 50.00093242100307, 47.409393310546875, 50.12505504063198, 48.6418856212071, 45.794385296957834, 46.06885303769793, 46.56886625289917, 47.30910301208496, 47.937084674835205, 49.68274661472866, 49.70837157113211, 45.552598408290315, 36.99801451819283, 33.16261237008231, 31.105657236916677, 34.879654679979595, 33.25724336079189, 36.226097447531565, 39.00853484017508, 40.38868679319109, 40.27072722571236, 38.88148008074079, 36.93976429530552, 35.69361530031477, 31.558099610464915, 30.783674240112305, 29.74357407433646, 31.01577533994402, 32.094003745487754, 32.70957939965384, 34.82102925436837, 33.712194034031455, 38.21036400113787, 47.87754903520857, 52.21809911727905, 52.35744524002075, 46.90080949238369, 47.447868960244314, 46.64686325618199, 47.629029342106406, 49.332696369716096, 48.225365434374126, 47.4770062310355, 47.61909341812134, 47.73139367784773, 47.078117098127095, 47.3716333253043, 45.86604554312569, 47.06702429907662, 48.5345915385655, 47.72901739392962, 47.45240265982491, 45.2483993257795, 42.31072528021676, 39.12689740317208, 37.551084177834646, 39.17257138660976, 42.46335983276367, 42.113931451525005, 42.7956748008728, 41.70012106214251, 41.221084458487375, 40.605394159044536, 42.019818101610454, 40.48908131463187, 39.62539938517979, 39.53440925053188, 41.4898407799857, 41.383769580296104, 45.302616119384766, 48.11780732018607, 52.26211595535278, 52.5986693246024, 54.48948955535889, 52.341172558920725, 52.881759779793875, 46.35241944449288, 58.58965628487723, 53.15090520041329, 57.45470973423549, 51.45762920379639, 47.16894047600882, 47.674210003444124, 58.666718755449565, 57.46996797834124, 64.33109869275773, 61.66918822697231, 60.21697303227016, 2.617358399288995, 4.735667645931244, 45.19932072503226, 55.83407020568848, 26.18110064097813, 24.9608336857387, 25.121642793927872, 24.472575085503713, 40.574589320591514, 44.152008329119, 45.89356388364519, 41.92350912094116, 40.04192999431065, 1.2233250311442783, 0.09651815944484302, 0.25585462951234406, 0.08382070649947439, 0.10426672401704959, 0.03517149628273078, 0.12923971004784107, 0.04105453399409141, 0.010634408781438, 0.04381902815241899, 0.15299010489668163, 0.051412218383380344, 0.10654158730592046, 0.02915270407018917, 0.18483878805169038, 0.03186269151046872, 0.3565714822283813, 0.05733967638973679, 0.38214003880109104, 0.43963453652603285, 9.128347022192818, 61.91528647286551, 57.26084804534912, 40.838124070848735, 27.397592987333024, 43.38463190623692, 32.77970061983381, 19.59978256906782, 24.071177652903966, 52.280407088143484, 62.08490589686802, 24.309127398899623, 5.996527280126299, 76.64139584132603, 58.8908884865897, 71.69930894034249, 59.34239632742745, 64.0463684626988, 48.46876777921404, 56.908609117780415, 48.073001861572266, 54.34770461491176, 49.591683523995535, 53.813968317849294, 51.248512744903564, 57.27721800122942, 52.18372985294887, 56.04338468824114, 56.268777302333284, 60.98059395381382, 54.84829453059605, 56.121079444885254, 54.623061725071494, 54.268043518066406, 45.2955185345241, 43.203923157283235, 42.13089200428554, 45.55923741204398, 43.289848055158345, 43.02890498297555, 43.663820947919575, 45.150106634412495, 42.87882389341082, 44.88422686713082, 41.35135623386928, 42.03282165527344, 43.89317056110927, 49.06424576895577, 47.66749109540667, 51.54174062183925, 51.2773060798645, 53.206056526729036, 50.21592010770525, 48.22157171794346, 49.06008379799979, 51.27555513381958, 48.497234548841206, 51.521854877471924, 50.86833511080061, 48.61044502258301, 46.63072953905378, 49.97744403566633, 47.67252506528582, 50.09646667752947, 50.25076879773821, 52.01463154384068, 46.40362071990967, 36.89959675925118, 32.27447625568935, 29.593110833849224, 32.60713168552944, 32.85844802856445, 35.30384567805699, 37.20265981129238, 41.25647858210972, 39.49454048701695, 37.82247734069824, 37.22547422136579, 36.93461568014962, 35.23755291530064, 31.318160942622594, 30.092641149248394, 33.17727654320853, 33.59647526059832, 33.704655238560264, 33.77576310294015, 32.77541010720389, 37.418192931583945, 49.91643190383911, 53.856963770730154, 51.61419643674578, 46.39873961039952, 46.669260774339946, 47.35564204624721, 49.039312158312114, 50.86077199663435, 50.96350111280169, 48.576544761657715, 48.81686905452183, 50.93291514260428, 49.75635583060128, 50.39752517427717, 49.063992159707205, 48.134073053087505, 51.47115387235369, 50.57366895675659, 49.97767332621983, 48.22932938167027, 45.62289333343506, 41.89892292022705, 39.5738958631243, 41.91282973970686, 44.46649769374302, 46.08511529650007, 46.222588879721506, 44.91907555716378, 44.735650062561035, 43.9109787940979, 45.90376383917672, 44.4841947555542, 42.738859380994526, 42.999910150255474, 44.63650969096592, 47.17307812826974, 50.761631625039236, 51.140419619424, 54.75184311185564, 55.47514016287667, 57.72735357284546, 57.37605612618582, 54.774080821446006, 46.24782126290457, 62.90209742954799, 58.11255128043038, 59.99526991162981, 53.66235862459455, 51.34942143304007, 51.87521593911307, 63.10191372462681, 60.38836424691336, 68.59365177154541, 63.83167607443673, 60.77457291739327, 1.9509631863662174, 6.517832815647125, 52.345108713422505, 57.102991921561106, 33.397520542144775, 31.561497279575892, 18.205539669309342, 22.41990872791835, 44.594320229121614, 45.42450141906738, 57.344751017434255, 51.070611068180625, 54.6679470879691, 2.3438618864331926, 0.1106458759999701, 0.32161086105874603, 0.07053067535161972, 0.1651104638086898, 0.024766792809324603, 0.09620928351900407, 0.04903583947036948, 0.06413626990148, 0.09267655201256275, 0.4436418557805674, 0.17512093165091105, 0.31719775072165896, 0.17274858323591097, 0.4388331323862076, 0.1553666873701981, 0.30369528383016586, 0.24013430305889674, 0.5163704146231923, 0.45622469059058596, 10.906072293009077, 73.31448023659843, 65.06048583984375, 48.52483974184309, 39.16720390319824, 47.15374823978969, 36.93723515101841, 19.668272699628556, 29.733478341783794, 58.70808138166155, 68.008912222726, 24.332191944122314, 9.30926161152976, 76.8713812146868, 59.34432792663574, 76.30633980887276, 63.639495849609375, 67.43881947653634, 52.12894678115845, 59.481575693402974, 53.29074117115566, 56.91888550349644, 51.25921644483294, 57.59968737193516, 54.330914293016704, 57.654897757938926, 54.23264939444405, 59.422682762145996, 59.42599010467529, 62.87570122310093, 54.54689557211739, 57.36376128877912, 56.1686224937439, 55.687942641122, 46.3383458682469, 44.722212246486116, 43.31530972889492, 46.760355131966726, 44.43588740485055, 44.27792705808367, 46.85638965879168, 45.0598669052124, 44.72027369907924, 45.84626054763794, 42.71523550578526, 43.76438570022583, 45.750795773097444, 51.5519996370588, 48.466130937848774, 53.21619047437395, 50.53283091953823, 54.80407966886248, 54.017112800053184, 51.41785076686314, 51.67096321923392, 56.243447644369944, 52.86938156400408, 56.20304386956351, 53.32996375220162, 50.79399980817522, 48.88756002698626, 52.01703562055315, 51.604340417044504, 52.1968480518886, 52.44204650606428, 51.9847195489066, 47.57551084245954, 38.05776766368321, 31.66597386768886, 30.315153735024587, 33.3598439352853, 32.16354479108538, 36.076297760009766, 37.51347705296108, 41.838831424713135, 39.530657223292756, 36.74276549475533, 38.516821248190745, 38.50372736794608, 34.69840744563511, 33.2279497555324, 30.580074650900706, 33.26739467893328, 35.60545655659267, 35.93419667652675, 35.386894021715435, 33.69253758021763, 37.633653095790315, 51.12200689315796, 55.304627895355225, 54.41737420218331, 48.2682775088719, 49.2225535256522, 50.948475633348735, 50.443414551871165, 54.859550612313406, 53.71428598676409, 51.68247291019985, 53.44105502537319, 54.219816071646555, 52.261216163635254, 51.64287165233067, 50.811231340680806, 50.323328835623606, 54.93185009275164, 53.55680506569998, 51.847961630140034, 51.62325341360909, 48.82961899893624, 44.84081104823521, 41.282294613974436, 42.739509037562776, 48.13002225330898, 50.383576665605815, 49.94471454620361, 47.79652261734009, 46.939000265938894, 47.79044989177159, 48.56036935533796, 46.902984278542654, 45.79281847817557, 46.99497495378767, 48.6926908493042, 50.588274070194785, 51.5529202733721, 53.65525756563459, 57.28942946025303, 59.057541029793875, 60.976188795907156, 58.84699671609061, 56.96379518508911, 48.4428197315761, 66.30314336504254, 60.95459379468645, 64.10016141619, 56.38462461744036, 52.863941124507356, 54.61992808750698, 66.26891653878349, 64.49128246307373, 72.21618543352399, 65.96966457366943, 70.33350849151611, 4.138083483491625, 4.972102250371661, 56.02716064453125, 63.808830397469656, 42.32267270769392, 30.376558440072195, 33.00596175874983, 36.12667219979422, 53.9709107535226, 54.06113658632551, 58.11024447849819, 57.180870805467876, 62.41025529588972, 3.2573085512433733, 0.22655841867838586, 0.5172896938664573, 0.17212285181241377, 0.37177188800913946, 0.15100404646779808, 0.31357524224690025, 0.11858927511743136, 0.13904056485210145], [0.026408450611467873, 0.10012076648750476, 0.07730077885623489, 0.10253531978066478, 0.00627058934852747, 0.17684940461601528, 0.04139149109167712, 0.17181516332285746, 0.03364657364519579, 0.3690080791711807, 0.09221368256424155, 12.881715263639178, 55.772411891392295, 48.17738117490496, 53.49194015775408, 49.30134262357439, 37.30065025602068, 22.6972165448325, 31.72460971559797, 19.33918169566563, 49.759826455797466, 53.735033307756694, 36.302211488996235, 0.7764656437294823, 49.619236605507986, 65.53579126085553, 61.34175436837332, 59.484584263392854, 55.442414147513254, 48.576989446367534, 50.49782242093767, 48.79447501046317, 51.02795607703072, 51.095506463732036, 52.806993688855854, 53.02796377454485, 53.000945704323904, 53.808413233075825, 55.004159995487754, 53.55482482910156, 59.960320472717285, 55.033953871045796, 56.81995357785906, 55.55236939021519, 50.06196887152535, 43.15923581804548, 43.035019397735596, 41.79890012741089, 43.217138631003245, 42.87426587513515, 45.73356771469116, 46.301391874040874, 45.846246651240754, 45.451429162706646, 43.42581387928554, 42.940443992614746, 41.00417212077549, 42.12879364831107, 47.59493800571987, 48.08690868105207, 47.93261350904192, 51.87744978496006, 49.23210729871477, 49.71880429131644, 46.96746356146676, 46.33587230954851, 47.34955889838082, 46.31053570338658, 47.44936282294137, 47.79746062414986, 45.3430164200919, 46.82715163912092, 45.98096874782017, 46.248853070395334, 47.28549998147147, 50.0166666167123, 49.34671088627407, 41.72888660430908, 34.829936844961985, 32.058717318943565, 30.68911620548793, 31.409373419625418, 33.404267242976594, 38.39652361188616, 38.91089180537632, 39.16769027709961, 40.52308579853603, 37.56653697150094, 38.61003828048706, 34.99322646004813, 30.386852196284703, 31.14475475038801, 30.16514560154506, 29.735437733786448, 29.13138392993382, 31.624114445277623, 32.21716751371111, 38.50175060544695, 37.340244565691265, 41.77302850995745, 48.56311041968209, 50.47995512826102, 50.014286858694895, 47.850517068590435, 48.137547152382986, 48.66490152903965, 47.474101884024485, 45.642535890851704, 48.18136944089617, 45.67786748068673, 45.95147711890084, 45.74353837966919, 46.101513045174734, 45.97975281306675, 46.59756926127842, 47.2945465360369, 47.40189273016793, 45.71991450445992, 45.684819153376985, 44.399030685424805, 42.83870846884591, 44.04965788977486, 42.372008391789024, 41.52283430099487, 43.76391322272164, 42.65737785611834, 42.36233302525112, 41.736203057425364, 43.37854528427124, 43.85846430914742, 41.51534414291382, 41.9938075201852, 41.84279189790998, 41.254817962646484, 44.33352654320853, 46.103726046425955, 47.73945358821324, 48.76548712594168, 50.62428310939244, 53.89457784380232, 55.956059728349956, 59.256238664899556, 47.89806011744908, 52.681477955409456, 60.66413130078997, 56.08963189806257, 58.18462494441441, 48.73014163970947, 49.082366670881, 54.96765068599156, 60.849516187395366, 61.53823552812849, 67.29777799333844, 38.52624300548008, 0.5313058389084679, 13.201731051717486, 56.979241030556814, 41.25869505746024, 14.916286775044032, 23.37141067641122, 70.86367688860211, 45.017969267708914, 47.17085123062134, 38.3135621207101, 58.208717823028564, 57.57201964514596, 50.2979679107666, 13.338339584214346, 0.25594449469021385, 0.18827007178749355, 0.11937945628804819, 0.023709178935470324, 0.14886641688644886, 0.1626353987625667, 0.046489938760974577, 0.11227539820330483, 0.047798459617687125, 0.07550093757786921, 0.014593636018357106, 0.05052932558049049, 0.02872258411454303, 0.12826225321207727, 0.040820754931441376, 0.2860241691981043, 0.05770702167813267, 0.3834022225013801, 0.2000501046755484, 18.575251579284668, 67.3821291242327, 55.49892732075283, 56.27577066421509, 49.72169474193028, 43.19371277945382, 28.064444610050746, 36.63401576450893, 22.59848264285496, 55.40431022644043, 54.52662420272827, 43.361706324986045, 1.4137741774320602, 50.17121887207031, 69.84202766418457, 64.20637157985142, 63.684110232761924, 59.41765226636614, 51.432348183223176, 53.0223947933742, 51.88168123790196, 53.352434226444785, 53.38363511221749, 54.687985692705425, 56.41932739530291, 55.559328011104036, 55.775670596531455, 57.380190304347444, 53.89843756811959, 57.105305671691895, 55.129324844905305, 57.40887941632952, 57.54751682281494, 50.6874144417899, 44.816051142556326, 42.649366583142964, 42.89000701904297, 45.09496225629534, 45.664891719818115, 48.473582880837576, 49.92310912268502, 47.39147738048008, 45.790800026484895, 46.32785756247384, 45.556878498622346, 43.86648253032139, 44.30567816325596, 50.70935685294015, 49.91139793395996, 50.91631589617048, 52.47398737498692, 52.363851479121614, 49.06765733446394, 47.78797285897391, 46.53908279963902, 49.59731156485421, 49.06846332550049, 48.544155733925955, 49.042699405125205, 47.798492431640625, 47.47336884907314, 48.17079428264073, 47.3419645173209, 50.291975089481895, 51.78151600701468, 49.68022094454084, 40.54871770313808, 35.730346952165874, 31.112452575138636, 33.268763474055696, 30.78693641935076, 33.652470793042866, 36.6343423298427, 38.91925048828125, 38.37854862213135, 39.66813080651419, 37.410424845559255, 39.6662791115897, 35.10054833548409, 30.49702283314296, 31.11149024963379, 30.64409187861851, 29.496961661747523, 28.88143638202122, 31.090350355420792, 33.634554862976074, 38.845783710479736, 37.75976984841483, 42.64305067062378, 52.03939144951956, 50.37481151308332, 52.34585564477103, 49.58453035354614, 48.74362461907523, 51.73482411248343, 49.465928077697754, 50.40135710580008, 49.33150475365775, 49.16281638826643, 49.857813426426475, 50.27170719419207, 48.138797828129356, 49.75987161908831, 48.095416750226704, 51.511592388153076, 48.752566950661794, 49.07261140005929, 48.45895344870431, 45.85094015938895, 45.81759922845023, 46.34850760868618, 45.108309745788574, 42.35643400464739, 46.93264961242676, 46.93997648784092, 45.98882021222796, 46.41850028719221, 46.33701181411743, 46.617576599121094, 44.769974163600374, 44.48083182743618, 45.47537612915039, 45.271488189697266, 47.88465009416853, 47.88674150194441, 51.73656811032976, 52.01399578366961, 53.339322975703645, 56.45239387239729, 56.35211052213396, 60.92822538103376, 50.88059868131365, 52.49654122761318, 62.144472803388325, 59.75049877166748, 60.09924275534493, 49.96043484551566, 52.052144868033274, 58.471238136291504, 63.17227118355887, 66.07126808166504, 68.42130865369523, 35.75126102992466, 0.31819145168576923, 17.649831431252615, 64.53556333269391, 42.148721081869944, 20.08197886603219, 25.02253542627607, 54.058430262974326, 39.30261387143816, 53.846597058432444, 36.10165868486677, 60.88197817121233, 67.056779725211, 62.136162757873535, 24.918557371412003, 0.2453204004892281, 0.1769317923379796, 0.06875559381608452, 0.06089321177984987, 0.02204602344759873, 0.05895614357931273, 0.07593131876949753, 0.015926877602136562, 0.14911210084600107, 0.2062701266258955, 0.2644924074411392, 0.18372087446706636, 0.08328718119966132, 0.3881597029311316, 0.16587472494159425, 0.37945825127618654, 0.21195212458925589, 0.7491078717367989, 0.35410012198346, 23.283043486731394, 79.09285231998989, 62.93163422175816, 67.46297836303711, 65.47621740613664, 46.98229796545846, 31.915813718523296, 39.92641966683524, 28.0679760319846, 61.46449429648263, 63.56875623975481, 44.074820790972026, 2.5922799621309554, 62.02248328072684, 68.42784690856934, 69.33940192631313, 65.276109286717, 63.35775334494454, 52.412672996520996, 59.19201646532331, 53.75958129337856, 57.68126269749233, 57.118142468588694, 58.03850085394723, 58.85850988115583, 58.77620152064732, 57.60878603799002, 58.324346269880024, 57.18560947690691, 58.43639292035784, 56.240762165614534, 60.32260649544852, 60.68976320539202, 53.37065240315029, 47.4276635987418, 44.64364201681954, 43.20327697481428, 47.088080814906526, 46.798719610486714, 51.442603724343435, 51.264830589294434, 50.895068304879324, 48.09680986404419, 49.35631677082607, 48.105321407318115, 44.93799202782767, 44.86759287970406, 53.00624023165022, 51.56085164206368, 51.31207486561367, 55.635664394923616, 54.17464583260672, 50.92664786747524, 51.78497620991298, 49.44756746292114, 52.68410784857613, 50.23590660095215, 52.69145556858608, 52.42366852079119, 47.32801948274885, 48.62089858736311, 50.296529633658274, 47.518400124141145, 52.8995749609811, 56.573987347739084, 52.711132866995676, 43.88625362941197, 36.92420033046177, 32.214023453848704, 32.55133070264544, 30.774033614567347, 34.558814661843435, 37.00159284046718, 39.293536049979075, 38.31769977297102, 41.10647392272949, 38.264146532331196, 40.44917433602469, 35.565344606127056, 31.28465325491769, 32.71992179325649, 33.35090160369873, 33.25542640686035, 31.61308765411377, 33.64776338849749, 36.68928868430001, 39.4678316116333, 40.057129178728374, 43.96653659003121, 53.58542469569615, 53.557305335998535, 55.47855520248413, 51.62191241128104, 52.22543294089181, 54.04293230601719, 52.12822069440569, 51.516744477408274, 52.349103927612305, 53.50627776554653, 53.243684496198384, 54.97304596219744, 52.717639854976106, 54.11204603740147, 54.352113246917725, 52.51091705049787, 51.93247256960188, 50.388565472194124, 52.5153534752982, 48.58005012784685, 48.0936484336853, 49.74728495734078, 47.0608160836356, 44.283127784729004, 47.55220658438546, 48.165048122406006, 47.35271338054112, 47.82593434197562, 47.842300823756624, 49.632347856249126, 48.3054712159293, 47.73507969720023, 48.725976194654194, 48.56668526785714, 52.30677202769688, 51.75035681043352, 56.26518508366176, 55.626402446201865, 57.40164286749703, 60.49563748495919, 60.627187728881836, 62.374902861458914, 50.23295709065029, 56.92547239576067, 64.67793887002128, 63.12246649605887, 62.77752317701067, 54.50792660032, 56.28280571528843, 63.0413601739066, 66.73427213941301, 69.52792739868164, 69.83730288914272, 47.45862477166312, 0.8863560727664402, 16.583173513412476, 72.13629504612514, 49.35047333581107, 27.868998731885636, 27.948175191879272, 84.13746683938163, 61.421630859375, 63.23620155879429, 50.21421085085188, 63.71294525691441, 66.86522483825684, 71.00373867579869, 25.694474867412023, 0.26238376487578663, 0.3507340997457504, 0.24716815991061075, 0.18264197664601461, 0.15874140842684678, 0.19067835541708128, 0.190569952662502, 0.12969826401344367], [0.051427634699004035, 0.035113715633217774, 0.12631719186902046, 0.07846032734960318, 0.0447176052922649, 0.05385792661192162, 0.03346527248088803, 0.1919004376977682, 0.0569114902588938, 0.219677422195673, 0.16063484682568482, 12.720580458641052, 61.760543142046245, 43.72443355832781, 34.85733011790684, 19.41813407625471, 46.01421935217721, 15.477937459945679, 38.07129233224051, 16.418779134750366, 45.77253321238926, 49.44823448998587, 61.5704265322004, 3.876020882810865, 10.976302947316851, 78.52966608319963, 56.169160979134695, 64.99375534057617, 54.709090845925466, 53.68134805134365, 45.62320252827236, 54.261859621320454, 50.94605071204049, 53.74106781823294, 50.64299808229719, 54.58761201586042, 55.12715353284563, 57.33088936124529, 51.08894736426217, 54.70386927468436, 51.33253036226545, 54.81224727630615, 54.08282191412789, 53.16402339935303, 47.865188189915244, 42.21999570301601, 43.58292307172503, 44.38449157987322, 46.88950824737549, 48.9301837512425, 46.442746026175364, 47.96980026790074, 44.32058204923357, 43.51635585512434, 45.83160332271031, 45.2991281236921, 44.096728461129324, 47.77007777350289, 49.44941568374634, 47.548774174281526, 50.414721965789795, 48.63809537887573, 47.863732542310444, 46.70754534857613, 47.57181787490845, 46.962547710963655, 46.78485448019845, 47.23707103729248, 44.77891649518694, 46.94136265345982, 47.01218564169747, 46.878286906651084, 46.373406478336875, 47.3070741380964, 45.30006960460118, 48.50565923963274, 45.55744130270821, 36.65836572647095, 38.53508458818708, 31.465153557913645, 29.33876507622855, 28.521580491747173, 28.011297839028494, 29.567687375204905, 33.8771790095738, 36.82176651273455, 40.52989503315517, 36.90094470977783, 35.885448115212576, 32.58373710087368, 31.623902525220597, 35.2692540713719, 35.3075282233102, 32.045710291181294, 28.51297688484192, 30.390229020799907, 30.518801961626323, 35.92630352292742, 41.66978175299508, 37.555621351514546, 48.02050127301897, 50.521738120487754, 49.48182555607387, 48.82137148720877, 48.11121347972325, 45.81753322056362, 49.06365169797625, 45.09002208709717, 45.90998247691563, 47.660629749298096, 44.96141440527779, 46.05744062151228, 44.416241373334614, 45.896506445748464, 45.73515885216849, 47.62506192071097, 45.38871124812535, 43.56259611674717, 43.989024434770855, 44.45048904418945, 47.9301746913365, 42.34003973007202, 44.270204135349815, 44.50228091648647, 43.820582730429514, 42.87921299253191, 45.73189319883074, 44.258802141462056, 45.48842484610421, 43.09116084235055, 43.75805589130947, 41.28402124132429, 40.61355134419033, 41.197853156498496, 44.959076336451936, 45.785957132067, 47.53382165091378, 47.111722060612266, 51.80989939825875, 51.284820556640625, 53.37578364780971, 54.37143966129848, 57.73775502613613, 48.65243993486677, 56.518561567579, 55.84433616910662, 57.327036585126606, 52.29267760685512, 50.12710475921631, 53.27676486968994, 65.3014007295881, 60.24887916019985, 70.96120180402482, 16.63208188329424, 0.03323260282299348, 26.806301287242345, 52.57538938522339, 29.961511271340505, 9.733021821294512, 69.1352013179234, 139.37866810389926, 75.89598614828927, 47.77383327484131, 56.74426685060774, 19.53037875039237, 48.1519090788705, 51.14467886516026, 38.87594584056309, 1.129330343433789, 0.16824324641908917, 0.06927033048123121, 0.0709621354139277, 0.12663036292152746, 0.019575343434033648, 0.07608774144734655, 0.030686437484941313, 0.08266109693795443, 0.032154461568487544, 0.04115726758858987, 0.07954362886292593, 0.060689705557056835, 0.0632710156163999, 0.04208397339763386, 0.14224411866494588, 0.11091062000819615, 0.29143798298069407, 0.17894942978663103, 17.7456887790135, 72.79977852957589, 49.18960516793387, 39.6661262512207, 24.209894963673182, 50.90820734841483, 24.615353618349346, 46.333628041403635, 18.72238142149789, 51.754327705928254, 52.50670644215175, 68.24595696585519, 6.490687940801893, 9.507007343428475, 79.02654566083635, 59.28207206726074, 66.41867801121303, 57.95550462177822, 56.017655508858816, 49.356893471309114, 59.09872300284249, 53.86955043247768, 57.073302268981934, 55.15451206479754, 57.79757901600429, 56.49587917327881, 58.794197354997905, 51.75095088141305, 56.07241078785488, 50.7651925768171, 59.09824357713972, 57.1656368800572, 55.982188429151265, 49.00365400314331, 45.67694337027413, 45.27027225494385, 47.84361055919102, 48.80287538255964, 49.88943815231323, 48.569916180201936, 48.27732753753662, 47.68885333197457, 46.27482891082764, 48.62312201091221, 46.1016137940543, 45.62199354171753, 51.591580050332205, 52.5708452633449, 49.7221359525408, 50.93977996281215, 51.21600907189505, 51.359148911067415, 49.75205142157418, 49.91694607053484, 50.00914519173758, 49.74025338036673, 50.59912715639387, 48.83306877953665, 47.13846567698887, 48.30777454376221, 48.009964329855784, 46.975092683519634, 49.97102737426758, 47.3973833492824, 49.804993220738, 46.448123931884766, 37.689005919865195, 37.21227264404297, 31.522667271750315, 28.397713218416484, 29.545203004564556, 28.82908170563834, 30.646940640040807, 33.92363466535296, 37.06770147596087, 38.95881700515747, 36.76639631816319, 35.67356627328055, 32.93575716018677, 31.71035201208932, 34.488471099308555, 34.66268328257969, 31.82352774483817, 30.43414510999407, 31.173697471618652, 32.35020119803292, 36.70547798701695, 43.62248958860125, 38.65407943725586, 51.555247919900076, 51.38522550037929, 48.783257143838064, 48.2658143724714, 49.71618482044765, 47.69509628840855, 51.54966851643154, 47.6161994934082, 48.672568866184776, 50.706570625305176, 48.25824778420584, 49.424697467258994, 46.76994712012154, 47.89166777474539, 48.42857592446463, 48.934533323560444, 47.57903010504586, 47.07528223310198, 47.028218609946116, 48.01159020832607, 48.88151509421212, 45.204267842429026, 47.59499706540789, 47.6565511567252, 46.88901145117623, 45.07483332497733, 46.706339836120605, 47.26969630377633, 47.2573493548802, 48.139089652470176, 47.32632064819336, 44.884473528180806, 42.51734038761684, 44.69257123129708, 47.889593737465994, 48.99095964431763, 52.323103768484934, 50.651568685259136, 54.97404302869524, 52.96104219981602, 57.67028454371861, 57.26823398045131, 58.456042425973074, 50.49229165485927, 58.42272581372942, 58.48351560320173, 59.97334139687674, 55.00902026040213, 52.68355199268886, 57.42496797016689, 66.92588261195591, 61.94193281446184, 71.79864038739885, 15.221691370010376, 0.09812680312565394, 35.55166012900216, 56.038576534816194, 32.18216943740845, 10.667744738715035, 72.62131404876709, 140.04545892987932, 81.92293698447091, 56.39055837903704, 56.20481218610491, 21.187947954450333, 56.11625739506313, 56.393195220402305, 55.38748516355242, 3.2902592974049703, 0.2126642878034285, 0.03734900336712599, 0.06832650862634182, 0.12303857851241316, 0.012004828147057976, 0.04816562509430306, 0.008497350865841975, 0.15563328377902508, 0.09466934829418149, 0.21225038144205297, 0.2923584021627903, 0.13351842973913464, 0.1299428487462657, 0.15962287969887257, 0.2999796260680471, 0.1600695728723492, 0.574540950357914, 0.3283939856503691, 23.00348792757307, 81.81854724884033, 60.406922885349815, 47.11905241012573, 27.718210663114274, 59.4030054637364, 24.951095785413468, 47.94055182593209, 24.56669190951756, 59.53937775748116, 58.950052397591726, 75.67465128217424, 5.942524143627711, 16.958584683282034, 81.22243349892753, 62.75694261278425, 70.14276654379708, 61.20663969857352, 57.8840389251709, 52.54442821230207, 61.76975645337786, 57.10073375701904, 57.118100779397146, 58.097678661346436, 60.36665807451521, 59.38220255715506, 60.59501756940569, 55.2074955531529, 52.95643901824951, 52.483322279793875, 61.73473753247942, 58.12884133202689, 57.837232385362896, 51.63473183768136, 46.0498114994594, 47.39360352924892, 48.455350807734895, 50.696638175419395, 51.52765662329537, 49.28793954849243, 52.13287598746163, 49.58566985811506, 50.01615939821516, 51.45926897866385, 49.825872557503835, 49.278149536677766, 53.49791213444301, 54.59309414454869, 52.72804478236607, 54.799737044743125, 53.59710461752755, 54.96109158652169, 50.72855819974627, 53.95357499803816, 52.02556800842285, 53.275309222085134, 52.46964822496687, 49.62194640295846, 50.228673526218955, 50.388103416987825, 51.73320518221174, 50.430577754974365, 52.7347845349993, 50.57681649071829, 52.65881987980434, 47.32709189823696, 39.0295844078064, 38.033000809805735, 29.933482238224574, 28.544954231807164, 30.0485965183803, 29.097494091306412, 30.72943660191127, 35.152253355298726, 38.40185635430472, 40.91488429478237, 40.919595173427034, 39.76855312074934, 38.83278363091605, 34.87529468536377, 38.8895434652056, 37.83572408131191, 34.69197341373989, 34.48575782775879, 33.475510597229004, 31.998806476593018, 37.017354828970774, 44.78902612413679, 39.00363983426775, 53.500597613198416, 53.48757668903896, 52.744119439806255, 52.067229407174246, 51.95943852833339, 49.34909759249006, 54.46476786477225, 50.985606806618826, 52.0551951272147, 52.53544419152396, 50.99333667755127, 53.796768052237375, 49.16326802117484, 50.8094664982387, 50.330058165958945, 51.937391894204275, 49.87187658037458, 50.20455632890974, 48.70635448183332, 50.919852529253276, 51.70348078863961, 48.13814469746181, 49.40798010144915, 47.682624271937776, 47.564133167266846, 48.54469074521746, 50.09056765692574, 49.603158473968506, 50.22747496196202, 48.74739401681082, 49.77045719964163, 47.83051667894636, 46.11999177932739, 49.19076204299927, 49.917533193315776, 52.901989459991455, 55.640722683497835, 55.04992083140782, 57.802057129996165, 56.78372567040579, 61.12310150691441, 63.417278562273296, 57.193982056209016, 50.33776371819632, 63.40375736781529, 62.07191971370152, 64.01549066816057, 58.8846629006522, 55.81349311556135, 62.43721430642264, 71.18986701965332, 66.69243703569684, 76.99323872157505, 23.38294642312186, 0.19003650200154099, 35.1578049659729, 64.26391656058175, 43.5492833682469, 18.049111400331768, 75.59867967878068, 143.4341092790876, 84.38043144771031, 58.22117594310215, 74.7177175794329, 27.721498898097447, 61.67892265319824, 65.9231185913086, 61.95384202684675, 3.482596290963037, 0.3791146682841437, 0.22991583709205898, 0.2354971133172512, 0.20940125361084938, 0.10409570605094944, 0.1793451514095068, 0.06897284037300519], [0.017558067305279628, 0.009711702936328948, 0.04019415159044521, 0.0740023251356823, 0.0006197576648056773, 0.08683868777006865, 0.19767179872308457, 0.08289039427680628, 0.03591818335865225, 0.24696136957832746, 0.13022450863250665, 13.419405954224722, 59.73205130440848, 42.21283211026873, 38.190627643040244, 29.457544531141007, 46.72297382354736, 12.934416481426783, 26.970518486840383, 16.335786376680645, 28.506746087755474, 59.51929746355329, 51.295367922101704, 31.81112173625401, 0.5382467093212264, 53.045469760894775, 65.81072453090123, 62.71540628160749, 58.66050706590925, 57.89468009131295, 52.66064725603376, 54.17132111958095, 53.58806848526001, 56.21455703462873, 55.957567487444194, 57.15920284816197, 56.07258449281965, 53.90734168461391, 54.44488559450422, 52.36461578096662, 50.44972004209246, 55.97814457757132, 53.31665447780064, 53.60838501793997, 45.5082619530814, 43.74897459575108, 44.36866705758231, 47.48694215502058, 47.21747016906738, 47.88591814041138, 49.21404545647757, 49.283586502075195, 46.03817674091884, 47.612992899758474, 44.61475140707833, 48.656362192971365, 44.82357256753104, 45.33536645344326, 48.455006871904644, 49.323667185647146, 50.425012247903005, 50.80451243264334, 47.23765468597412, 47.047982760838096, 48.28855235236031, 46.257427147456575, 45.738389764513286, 46.10944441386631, 46.78761986323765, 45.52246754510062, 46.46327447891235, 45.11461523600987, 43.00022976739066, 45.03045170647757, 45.17622491291591, 47.93143926348005, 39.66464975902012, 36.19871807098389, 34.71223088673183, 31.326797553471156, 28.99445230620248, 27.00335567338126, 28.9514707497188, 33.8686466217041, 36.96841171809605, 40.275848048073904, 40.701915059770855, 36.770836217062815, 35.39656591415405, 35.64848675046648, 36.82637316840035, 34.532359395708355, 34.499327659606934, 35.97971085139683, 34.981484004429404, 31.906319005148752, 31.614657946995326, 35.4245845249721, 38.81001091003418, 36.93089491980416, 38.985199315207346, 45.66243553161621, 46.07174348831177, 48.33549090794155, 49.05772488457816, 46.24546234948294, 44.805597577776226, 47.14245741707938, 48.335511752537315, 46.253518785749165, 45.39309556143624, 46.98830468314034, 45.32370042800903, 45.313496998378206, 45.22495262963431, 46.11718818119594, 45.69527619225638, 45.2167398588998, 44.11568314688546, 44.64098085675921, 45.63301338468279, 43.72153615951538, 46.6334810256958, 44.99586009979248, 44.18138183866228, 42.248125485011506, 46.25541911806379, 45.64567995071411, 47.03072690963745, 46.24821731022426, 46.87001160212925, 41.39723866326468, 42.5928429876055, 42.971141133989605, 45.2298024722508, 45.624550478799, 46.947946071624756, 49.079854897090364, 52.27107218333653, 52.72846862248012, 57.16249629429409, 53.1971697807312, 52.03939144951956, 52.110440254211426, 55.30028179713658, 56.475983006613596, 58.929041045052664, 54.35610498700823, 50.44913291931152, 51.70521436418806, 63.27982929774693, 60.21285275050572, 66.37733622959682, 4.784770565373557, 1.696892751114709, 43.21376528058733, 49.93455975396292, 22.219451461519512, 8.940762162208557, 34.51966503688267, 30.456070150647843, 12.90089055470058, 29.84066125324794, 69.42321109771729, 45.613902364458355, 26.04687707764762, 47.33637816565377, 58.80731555393764, 15.587816272463117, 0.3899294579667704, 0.14243253426892416, 0.021250522562435696, 0.06764504233641283, 0.014812019121434008, 0.0490518902162356, 0.020406547135540416, 0.05044375552928873, 0.019318012420886328, 0.03253990338583078, 0.08856756107083388, 0.04468106957418578, 0.0908195645149265, 0.19775946544749395, 0.1263012055839811, 0.07554554446999516, 0.14442710152694158, 0.1001877650352461, 20.846565587180002, 68.1949849809919, 48.583704880305696, 41.28903784070696, 30.001529421125138, 54.31373487200056, 18.448895113808767, 32.73107017789568, 15.77552706854684, 30.999054500034877, 66.32405049460274, 55.24645757675171, 40.19556508745466, 0.27615110469715937, 48.530443464006694, 69.67673696790422, 63.478582518441335, 59.69101524353027, 60.54068265642439, 54.84748159136091, 56.46438993726458, 56.813929489680696, 58.312444005693706, 58.44058963230678, 57.762226581573486, 57.02301468167986, 53.80549846376692, 54.74717044830322, 52.65079123633248, 52.54796831948416, 57.9148576600211, 55.67296927315848, 57.076752049582346, 49.62574359348842, 42.44147300720215, 45.98121540887015, 48.623580592019216, 48.85765845435006, 49.57029349463326, 52.46852261679513, 52.91165787833077, 48.33646712984358, 47.30650438581194, 45.754287242889404, 48.44634941646031, 48.23603091921125, 47.93147053037371, 49.60449947629656, 51.479582037244526, 52.75320420946394, 51.21207639149257, 48.1891896384103, 48.36108807155064, 51.09718792779105, 47.537153312138145, 48.54337058748518, 47.845646381378174, 49.24329737254551, 48.791438647678916, 50.03358200618199, 46.063020024980815, 46.05197933741978, 46.79472092219761, 48.67387860161917, 49.07905238015311, 42.70499733516148, 35.71035698481968, 35.32393639428275, 30.45136969430106, 30.56921809060233, 25.274407625198364, 29.76028449194772, 30.398962906428746, 34.82350976126534, 38.68342515400478, 41.473595891680034, 37.00307280676705, 38.19172545841762, 38.64763150896345, 37.652260371616904, 38.17355244500296, 36.051992961338584, 36.02631936754499, 34.81315347126552, 32.245050634656636, 32.481414454323904, 35.95491967882429, 38.51008496965681, 35.76552220753261, 38.792352063315256, 50.68635136740548, 51.28159311839512, 49.691730635506765, 50.58980962208339, 47.126712799072266, 46.26765489578247, 48.02675117765154, 51.45476654597691, 48.48788922173636, 48.62795448303223, 47.935000215257915, 48.21636404309954, 45.62788214002337, 48.07138293130057, 46.56586810520717, 47.54947941643851, 44.633966650281636, 46.88543660300118, 47.742753982543945, 47.609400681086946, 45.074781213487896, 47.83579730987549, 46.522976875305176, 44.642780440194265, 45.41392626081194, 47.88354533059256, 47.17101798738752, 50.72802318845476, 49.93766907283238, 50.19231012889317, 46.91887133462088, 45.686167103903635, 45.298780713762554, 50.27317673819405, 48.5683319909232, 49.29961947032383, 50.116578238351, 54.02526651109968, 53.22899947847639, 59.33642782483782, 57.270394870213096, 57.494953700474326, 52.89802203859602, 55.597890513283865, 58.610466139657156, 61.977549280439106, 55.56738792146955, 53.243274552481516, 55.10446419034685, 68.80853870936802, 62.242004667009624, 68.59751496996198, 3.981721656663077, 2.7447527519294193, 49.55887413024902, 50.45640420913696, 27.32544984136309, 8.663343174116951, 34.01640701293945, 36.87043169566563, 28.04332208633423, 43.47327702386038, 71.09683064052037, 41.7453989982605, 33.95730216162545, 53.03913995197841, 70.04772908346993, 25.337768248149327, 0.3812858446368149, 0.068588674201497, 0.08686392927276236, 0.058673608382897716, 0.007935442446198846, 0.0633153443091682, 0.08258197296942983, 0.17316174320876598, 0.19054570182093553, 0.13799944786088808, 0.16769949559654507, 0.13684327847191266, 0.1820351763495377, 0.37057223809616907, 0.24072663698877605, 0.13151953342769826, 0.35980312739099773, 0.1705250646919012, 23.370255538395472, 81.50215407780239, 56.10603659493582, 50.70172078268868, 40.57475955145699, 66.32095159803117, 21.81804186957223, 34.69528423036848, 26.72530092511858, 40.19610357284546, 69.66409124646867, 63.65870761871338, 37.27275323867798, 1.2752414281879152, 63.10918154035296, 66.88240078517369, 68.55508926936558, 60.26326887948172, 64.88314696720668, 57.77912112644741, 60.257939611162456, 58.3384302684239, 61.480468205043245, 60.91515581948416, 63.26115948813302, 62.186995778764995, 57.92787858418056, 51.34975494657244, 54.68942049571446, 54.54980339322771, 58.95054571969168, 57.79104770932879, 58.351895877293174, 50.973763602120535, 45.32905401502337, 49.04513822283064, 51.4643793787275, 50.105989183698384, 52.28976283754621, 55.03382880347115, 53.69586631229946, 48.67120701926095, 51.10616152627127, 48.4123831476484, 52.253792013440815, 51.62842634746006, 50.69756228583199, 52.094608783721924, 52.90351111548287, 54.79693692071097, 54.09705877304077, 49.858285903930664, 52.51994970866612, 52.73035505839756, 50.97930826459612, 50.03669827325003, 49.60805000577654, 55.50973871776036, 52.42600311551775, 51.455131326402935, 49.79063824244908, 47.62202903202602, 48.29734877177647, 52.89146293912615, 52.800611768450054, 44.5552122933524, 37.09761694499424, 37.84538207735334, 32.58401850291661, 30.646023477826798, 24.892452989305767, 31.432365008762904, 33.087054184504915, 35.871916498456685, 39.11686767850603, 42.53586081096104, 39.98783132008144, 38.85713011877877, 40.89925084795271, 41.01361819675991, 38.568307399749756, 37.325573444366455, 38.19053731645857, 36.130611828395296, 34.169798919132774, 35.050858293260845, 35.14583669389997, 39.38742010934012, 36.022511754717144, 39.302634716033936, 53.022915908268516, 52.96138960974557, 51.10763454437256, 51.59151404244559, 50.09463235310146, 48.58197825295584, 50.89234808513096, 53.749627998897004, 52.017449038369314, 51.01935420717512, 53.07326602935791, 51.76890850067139, 49.35388142721993, 50.0832234110151, 51.12678377968924, 50.6261556489127, 47.831902844565256, 49.092976570129395, 50.821511200496126, 49.02063887459891, 46.912065574101035, 50.78716625486101, 48.85162394387381, 48.79343625477382, 47.92245176860264, 50.51203843525478, 48.176582132067, 52.26071241923741, 51.41722195489066, 55.13722842080252, 46.989089829581125, 48.15204456874302, 49.76060812813895, 52.241323471069336, 51.640887941632954, 51.747726917266846, 54.70768730981009, 58.70410006386893, 56.49806785583496, 63.62154170445034, 61.97557599203927, 61.440474373953684, 51.747914518628804, 60.069997787475586, 62.772277287074495, 65.26787567138672, 60.08147621154785, 57.90983758653913, 59.16365391867501, 70.38518224443708, 66.66209425245012, 75.20332023075649, 7.482304011072431, 1.9340230439390456, 53.44234044211251, 59.818090847560335, 37.493045875004356, 13.282842585018702, 40.364430631910054, 35.47033493859427, 20.281847272600444, 37.81706121989659, 87.34060723440987, 61.428975105285645, 35.92963171005249, 62.202038628714426, 77.39392048971993, 29.24801118033273, 0.4104223826101848, 0.21100009924599103, 0.17617141242538178, 0.17592658341995307, 0.10573893466166087, 0.12847933013524326, 0.10283340021435704], [0.1298984047025442, 0.11530237006289618, 0.02330230389322553, 0.01939137901977769, 0.1020123457003917, 0.10389401830200638, 0.1329592897423676, 0.15052426792681217, 0.12196186557412148, 0.3081425923321928, 0.24515866488218307, 19.58023033823286, 63.51715891701834, 41.60742514474051, 32.569131987435476, 31.164108957563126, 46.02832766941616, 26.046665157590592, 21.29574751853943, 14.002606477056231, 21.334518466676982, 66.1187937600272, 48.83658456802368, 64.36091341291154, 3.5463136604854038, 5.615392531667437, 74.30256271362305, 57.32279470988682, 64.79783698490688, 53.77475963320051, 57.6914279120309, 51.9493636403765, 57.13128498622349, 52.49276140757969, 57.335773944854736, 56.96328796659197, 53.899292196546284, 54.23352139336722, 53.8759879384722, 50.21153232029506, 55.42838226045881, 53.66141019548689, 53.713261127471924, 53.160222734723774, 47.42432846341814, 40.64710419518607, 41.92123358590262, 47.31849350248064, 55.46918903078352, 51.469246591840474, 53.84623227800642, 49.77312878199986, 50.92679377964565, 46.593035561697825, 47.075879778180806, 46.81077820914132, 52.075685364859446, 49.1437018939427, 48.34360292979649, 49.71947826657976, 53.86981098992484, 50.5748154095241, 48.13393061501639, 46.77299737930298, 46.100297110421316, 45.7754236630031, 44.75686638695853, 45.761311871664866, 45.008373805454795, 45.79818248748779, 47.234323024749756, 40.73932763508388, 40.99446548734392, 40.002575397491455, 43.493405955178396, 45.19599601200649, 37.78278228214809, 43.59068768365042, 56.33790840421404, 55.11100591932024, 33.507368087768555, 30.828048910413468, 33.60464286804199, 36.72272341591971, 38.049422877175466, 37.20475121906826, 39.90383802141462, 36.88779524394444, 36.22401646205357, 39.24299137932913, 37.64789342880249, 37.8740816116333, 34.91637590953282, 32.48231772014073, 33.83654594421387, 36.14312553405762, 31.73528562273298, 36.824413776397705, 44.792201450892854, 36.87916905539376, 38.802941117967876, 37.21519088745117, 46.056245531354634, 46.28355584825788, 47.79770728519985, 44.8071539742606, 42.99407713753836, 42.72312865938459, 45.00081763948713, 44.9226781981332, 48.12326513017927, 47.80251543862479, 46.130754538944785, 42.89097629274641, 46.22339487075806, 43.77945286887032, 46.08859634399414, 46.03166627883911, 47.56528309413365, 46.118192195892334, 45.43733821596418, 44.68305914742606, 44.319359166281565, 45.259995869227815, 41.03418486458914, 42.31809384482247, 44.534930501665386, 46.35113055365426, 47.12192896434239, 48.895526136670796, 47.72739846365792, 45.49129792622158, 39.600347655160085, 40.51152747017996, 45.21602766854422, 46.01636634554182, 47.793621744428364, 51.04316915784563, 51.2703092438834, 52.71422828946795, 52.73200872966221, 56.87793282100132, 53.47114072527204, 43.32943194253104, 51.474332673209055, 53.75388724463326, 62.34177385057722, 54.73655360085623, 52.02911853790283, 54.35500022343227, 63.33676283700125, 60.275511605399, 58.73936217171805, 0.7209582765187535, 11.661522133009774, 52.70962510790144, 51.29372467313494, 21.080203975949967, 4.653261142117636, 22.878852878298076, 11.928578751427786, 15.469347749437604, 32.74856921604702, 46.72204276493618, 48.87432370867048, 26.84385108947754, 35.89685705729893, 61.88495758601597, 31.752364294869558, 0.6328476816415787, 0.2168906924447843, 0.07476645734693323, 0.10143165543143239, 0.06911386030593089, 0.03717559017241001, 0.16617302250649246, 0.07268984841981105, 0.0930626452235239, 0.09718472510576248, 0.11056401753532034, 0.06690805152590786, 0.19796284953398363, 0.1452874160770859, 0.25091600737401415, 0.0741794431316001, 0.32869788791452137, 0.28224003368190353, 27.774524075644358, 73.64131655011857, 45.825871058872764, 35.34272084917341, 28.53550120762416, 52.40915373393467, 24.443281480244227, 23.18156157221113, 19.27500639642988, 27.55008336475917, 69.00763239179338, 52.64099427631923, 71.04768603188651, 7.360765252794538, 3.1008735511984145, 70.45547022138322, 59.81993212018694, 67.81127071380615, 57.5022736276899, 64.54314381735665, 57.417074816567556, 61.22767884390694, 54.13572897229876, 60.58165618351528, 56.73762437275478, 56.11012213570731, 54.3004082271031, 55.92986501966204, 52.28459685189383, 56.321430751255576, 53.36692469460623, 55.245210375104634, 51.386358056749614, 48.167782238551546, 43.20960330963135, 45.330012866428916, 48.28697163718087, 52.48542410986764, 50.78962244306292, 54.4850982938494, 48.96026250294277, 49.35253695079258, 45.853795869009836, 46.34168447766985, 47.70561933517456, 51.87117556163243, 51.69609832763672, 49.91124507359096, 51.56108093261719, 56.12502602168492, 51.662333556583945, 50.31707545689174, 50.124186515808105, 48.23237269265311, 48.08178091049194, 50.206679003579275, 48.5504994392395, 48.21822268622262, 48.616684504917686, 50.00904444285801, 46.630833762032644, 45.54917989458357, 43.31544869286673, 48.08667591639927, 45.787979057856965, 38.30714545931135, 45.88206461497715, 48.517023018428254, 42.84797389166695, 29.0965439251491, 30.539987019130162, 31.799872602735245, 36.3030800138201, 35.06888192040579, 38.39790282930647, 41.27671521050589, 37.837666102818076, 35.36339521408081, 37.03696264539446, 37.44315780912127, 37.43226998192923, 34.709250109536306, 35.07281460080828, 34.12313134329659, 35.078289781297954, 32.84745945249285, 36.81562430518014, 47.3684058870588, 38.44366019112723, 39.78090006964547, 37.69299765995571, 48.73118734359741, 48.25281081880842, 51.747751235961914, 47.862676416124614, 44.953073092869346, 46.01003653662545, 46.035098688943044, 45.20607089996338, 48.51522690909249, 45.618095602308, 49.311146531786235, 48.095837116241455, 49.1028847013201, 49.128822326660156, 48.74436460222517, 48.63274526596069, 50.77584069115775, 48.464758668627056, 51.45245974404471, 47.502176080431255, 44.88044357299805, 46.93925040108817, 45.07900224413191, 43.37317085266113, 46.03868048531668, 50.09708159310477, 50.42292431422642, 52.39826243264334, 51.65796313967024, 47.88218348366873, 44.595230443137034, 43.10095432826451, 48.8783849307469, 50.003027302878245, 49.9529481615339, 51.900132179260254, 53.94471257073538, 53.1816405568804, 55.07143592834473, 56.654909542628694, 52.8192572593689, 43.85941273825509, 51.51082808630807, 55.58589792251587, 62.53032711574009, 58.67026233673096, 55.652857712336946, 56.13994380405971, 64.30219418661935, 63.05332497188023, 55.917778628213064, 0.6945438853331974, 18.935454879488262, 60.43446554456438, 56.03850705283028, 27.340840101242065, 4.286829650402069, 20.97464346885681, 14.471290264810834, 25.963347571236746, 41.49705301012312, 56.74073369162423, 50.63425030027117, 27.049597672053746, 45.04221153259277, 64.38332830156598, 45.93492650985718, 1.1837509146758487, 0.07510297678943191, 0.04218648307557617, 0.05520419097904648, 0.010579466104640492, 0.024638610758951733, 0.08444893493184022, 0.10295660860304322, 0.1469681608889784, 0.12155618305717196, 0.17774186815534318, 0.20243949789021695, 0.2798697480133602, 0.20391276026410715, 0.30519093785967144, 0.21144160841192516, 0.4024961165019444, 0.22933962515422276, 33.340503624507356, 85.16508456638881, 53.808705057416645, 47.92032561983381, 44.70630781991141, 60.91015311649868, 35.67997598648071, 27.750799451555523, 26.427436862673076, 32.667994431086946, 76.36113330296108, 57.91540309361049, 76.3827213559832, 5.148929996149881, 8.694970505578176, 80.00665855407715, 59.96389184679304, 69.54035772596086, 59.73244735172817, 67.19146360669816, 59.357091767447336, 63.12271663120815, 57.2790801184518, 63.34892218453543, 60.018845149448936, 58.30286243983677, 55.183159487588064, 60.96862915584019, 55.37617002214704, 57.89955425262451, 57.47800704411098, 58.866812978472026, 55.812749658312114, 51.16780941826956, 45.247836521693635, 46.83293948854719, 47.39975963320051, 52.880971159253804, 52.508902072906494, 55.02962861742292, 51.177408354622976, 52.619923864092144, 48.62492854254586, 50.0852175440107, 50.24776717594692, 57.92083658490862, 54.151299885341096, 52.67151076453072, 55.898723193577354, 58.268830163138254, 54.81002732685634, 52.72224303654262, 54.953601428440635, 53.90536492211478, 52.098280906677246, 51.70650672912598, 51.651331084115164, 49.0570022719247, 51.693315574101035, 53.2389041355678, 47.97483771187918, 49.50692939758301, 47.57078954151699, 49.99341794422695, 48.43115023204258, 38.44800976344517, 44.37112324578421, 43.03871931348528, 38.736849852970664, 31.392708165305002, 31.25946603502546, 33.023922852107454, 35.77349526541573, 35.651404993874685, 37.898549692971365, 42.84842552457537, 39.61173922674996, 37.87063877923148, 40.33508838926043, 39.424196924482075, 39.06612498419625, 35.38290228162493, 35.223580087934224, 34.81002330780029, 35.37210478101458, 33.32529749189104, 37.70731789725167, 48.75716665812901, 40.458578722817556, 42.39613601139614, 39.216101850782124, 53.15603991917202, 50.490113394601, 53.95598949704851, 50.105902331215994, 47.89997434616089, 46.799483912331716, 50.27124513898577, 49.17731033052717, 54.41409812654768, 50.034249033246724, 52.56205926622663, 51.43039573941912, 51.888282026563374, 51.93400117329189, 52.37944323675973, 51.14189611162458, 52.912262371608186, 50.83391720908028, 53.402412618909565, 51.126359939575195, 49.81522444316319, 50.393960748400005, 45.99903406415667, 45.479451247623985, 49.34286158425467, 52.92482818875994, 52.49179560797555, 54.24667433329991, 54.224780559539795, 50.9352844783238, 46.56544426509312, 45.952314376831055, 53.17376824787685, 54.207417011260986, 54.113095215388704, 56.84495319638933, 57.512181758880615, 58.9798184803554, 59.07292434147426, 60.2995662689209, 56.92618458611624, 46.339638233184814, 54.27427952630179, 60.76783316476004, 66.85114083971295, 61.936874525887625, 59.50632517678397, 60.41497584751674, 69.18494347163609, 64.47253622327531, 66.16361658913749, 1.2783443416867937, 14.986705030713763, 66.3379955291748, 59.56750406537737, 35.68289770398821, 9.476211190223694, 29.257822036743164, 15.914301701954432, 22.402229036603654, 40.45077242170061, 55.80060420717512, 70.50473294939313, 42.07156828471592, 52.645034653799875, 79.38937364305768, 54.76523576463972, 1.3866471073457172, 0.22734846414199897, 0.23013275116682053, 0.13967717997729778, 0.17503743113151618, 0.12962925700204714, 0.2757042215338775], [0.05914419277438095, 0.17820597253739834, 0.11800896482808249, 0.05985595565289259, 0.20917891125593865, 0.2388671524822712, 0.08013271261006594, 0.3554942671741758, 0.1727949950311865, 0.2592114508152008, 0.06847728589283568, 24.646728209086827, 64.97580119541713, 39.35962036677769, 39.680689675467356, 30.368519374302455, 45.916263648441856, 24.042693512780325, 18.36377968106951, 6.5797582013266425, 21.8375472000667, 58.58210359300886, 55.89952918461391, 53.539768082754954, 46.924971852983745, 0.04266176971473864, 24.492533785956248, 74.4307917186192, 57.749497481754844, 60.07241576058524, 55.924049377441406, 54.919301646096365, 54.41174963542393, 54.594636644635884, 53.34899486814226, 55.648202419281006, 58.98802430289132, 52.56186124256679, 47.09477193014962, 55.05589975629534, 52.95279121398926, 57.17405809674944, 54.50874996185303, 51.018447467258994, 44.818837370191304, 42.21942247663225, 46.118810585566926, 47.03308234895979, 49.56746557780674, 50.38592863082886, 54.363671575273784, 54.09605128424508, 48.107096672058105, 50.59556967871529, 46.45227895464216, 44.79172549928938, 46.156414236341206, 46.441175733293804, 49.64960023335048, 49.68727336611067, 50.20286444255284, 47.70380585534232, 47.78486006600516, 47.41121026447841, 47.13412652696882, 44.862065587724956, 46.60520533152989, 46.30492155892508, 45.75955745152065, 44.93484449386597, 44.576751708984375, 41.349146706717356, 40.88490629196167, 36.711908544812886, 38.99541316713606, 36.654693603515625, 43.35601922443935, 69.0040054321289, 79.42115470341274, 109.19087137494768, 87.51501396724156, 41.77701677594866, 37.14093896320888, 35.68607997894287, 42.006835392543245, 42.92501899174282, 38.539329937526155, 33.519072328295024, 39.10324920926775, 41.34583241598946, 40.42798580442156, 35.80085379736764, 29.181443963732036, 29.315870761871338, 30.969781739371165, 34.76158741542271, 39.15811218534197, 37.52922167096819, 41.052462100982666, 44.54074614388602, 43.04794652121407, 38.40603569575718, 38.87350354875837, 43.3643605368478, 44.417870725904194, 45.04394163404192, 41.543390546526226, 42.14381217956543, 44.313553946358816, 45.85139179229736, 46.531259128025596, 47.15292140415737, 45.984095437186106, 45.10484606879098, 44.56200415747506, 43.32412699290684, 45.19265740258353, 47.78934165409633, 46.68875047138759, 46.05060706819807, 45.45996502467564, 44.641380378178184, 42.137426785060335, 44.01067154748099, 45.80207347869873, 43.51563324247088, 45.04822867257254, 48.039428165980745, 49.88365377698626, 48.68331772940499, 47.962278842926025, 47.82913746152605, 45.10769830431257, 40.335807527814595, 40.75255353110177, 44.842291014535085, 50.47180836541312, 51.60494838442121, 52.27620342799595, 53.403687613351, 52.210581166403635, 55.661313670022146, 56.512520108904155, 50.83297572817121, 47.97477517809187, 53.378632409232004, 58.03859118052891, 57.3936767578125, 51.74741424833025, 56.773119245256694, 58.848726817539756, 70.25705746241978, 29.923310075487407, 0.2667532046990735, 39.954323632376536, 46.90523896898542, 62.611106872558594, 18.207834311894008, 6.961321566786085, 31.675961903163365, 30.27081380571638, 24.47926446369716, 41.33617441994803, 40.58348996298653, 32.26120867047991, 29.179731232779368, 39.08875526700701, 53.24065855571202, 47.99692256110055, 2.663834031139101, 0.2672127628965037, 0.1995799613318273, 0.05253908184490033, 0.24644166603684425, 0.10533435815679175, 0.2674340195953846, 0.06469871436378785, 0.20871239128921712, 0.13064890514527047, 0.1297816423965352, 0.08258115194205727, 0.16961281507142953, 0.08737165667116642, 0.374570437840053, 0.05354351723300559, 0.28269120518650326, 0.12097638845443726, 33.71473707471575, 72.1892750603812, 45.35376875741141, 39.887471539633616, 31.19442047391619, 51.73933001926967, 15.437695230756487, 14.054975049836294, 13.295233828680855, 21.98582523209708, 60.849557876586914, 58.16685145241873, 57.41453524998256, 58.93732329777309, 0.5368981616837638, 15.115116425922938, 75.52775941576276, 60.508137294224326, 66.48692321777344, 60.06789248330252, 63.69664478302002, 60.7541869027274, 58.85717582702637, 53.65413195746285, 52.94439084189278, 59.21512617383684, 53.72106395448957, 49.73900965281895, 55.01457534517561, 49.90691287176949, 54.27361944743565, 52.74012769971575, 52.517479624067036, 45.67548424857003, 42.56458118983677, 47.29528651918684, 48.281360966818674, 49.399968828473774, 49.21484102521624, 51.468200887952534, 55.81891965866089, 48.325652258736746, 50.03336661202567, 45.914943490709575, 50.214895248413086, 48.771372250148225, 51.62972913469587, 51.42834602083479, 49.913819381168906, 51.64095742361886, 52.007151808057515, 53.39541578292847, 50.44910512651716, 50.21151147569929, 47.34592499051775, 48.5611822945731, 49.157966545649934, 46.783423151288716, 49.393451418195454, 48.52517672947475, 48.05874415806362, 45.187064102717805, 42.32096692493984, 45.719000816345215, 40.42857640130179, 43.556554658072336, 65.41334315708706, 77.7918507712228, 95.68724196297782, 57.44199800491333, 30.73065948486328, 37.322957447596956, 33.29306132452828, 39.2008991922651, 38.08949661254883, 38.53831550053188, 34.905672209603445, 40.406474181583945, 41.26857886995588, 39.44476359231131, 34.49122953414917, 30.241961411067418, 27.760535614831106, 32.918612480163574, 34.071520124162944, 38.80956622532436, 42.102911608559744, 38.98659242902483, 42.15755919047764, 44.339665276663645, 40.5289431299482, 41.12730114800589, 46.06373916353498, 45.072877407073975, 45.410799571446006, 42.665917192186626, 43.06419488361904, 45.29413931710379, 43.34988743918282, 45.076698916299, 47.61310407093593, 47.66570193426949, 48.94085965837751, 46.70294564110892, 50.746828487941194, 48.91326836177281, 47.20227445874895, 47.885428292410715, 48.28312233516148, 49.154829433986116, 49.378366879054475, 45.47862788609096, 44.74903924124581, 48.586338247571675, 49.4365302494594, 48.90580947058541, 52.08276210512434, 52.68550443649292, 52.86339916501726, 49.73345456804548, 48.97371074131557, 47.9984198978969, 46.75255230494908, 47.44314071110317, 48.64156947817121, 52.10120957238333, 53.76693248748779, 54.449363708496094, 56.53224604470389, 52.92998027801514, 55.570320061274934, 57.031053747449604, 51.687579836164204, 48.71008913857596, 56.97552374431065, 60.35870933532715, 61.53417083195278, 55.30386011941092, 63.37415109361921, 61.046831130981445, 71.46915681021554, 26.492883682250977, 0.26327552273869514, 46.85147728238787, 49.71766826084682, 68.86117826189313, 22.683565071650914, 7.97159789289747, 21.88001458985465, 32.45906557355608, 23.228331633976527, 49.906454290662495, 44.1399427822658, 42.190038544791086, 31.459824289594376, 52.17096601213728, 60.622900690351216, 64.3621849332537, 5.985556074551173, 0.46436075972659246, 0.1564613136329821, 0.05139480038945164, 0.18044527380594186, 0.04819210831608091, 0.07710107242954628, 0.14668038061686925, 0.20066126116684505, 0.09286546294710465, 0.16993965181921208, 0.25675341699804577, 0.2950438809181963, 0.160401403637869, 0.4578063285776547, 0.23109689514551843, 0.39818302222660606, 0.09282244382692234, 38.805042948041645, 84.53983007158551, 53.72492020470755, 53.23101098196847, 40.86387756892613, 63.726765223911826, 36.54407828194754, 25.87985106876918, 14.954970870699201, 34.240503787994385, 67.26592745099748, 63.169616971697124, 61.823820386614116, 58.4055290222168, 0.3414274219955717, 29.91035168511527, 76.22127301352364, 61.81933879852295, 70.41027913774762, 61.362876892089844, 62.32097094399588, 62.68648093087332, 61.09072984967913, 56.951330116816926, 56.343074389866416, 60.42439065660749, 58.266874245234895, 52.22235836301531, 57.79406322751726, 56.43427644457136, 60.04749257223946, 57.95686994280134, 58.49363912854876, 48.20662614277431, 45.17355333055769, 49.21784264700753, 50.14296054840088, 52.310249601091655, 51.637285300663535, 56.91517169134957, 55.616483892713276, 52.19417994362967, 54.47345658711025, 48.14072247913906, 51.16766698019845, 53.26517527444022, 54.61337941033499, 57.23853390557425, 52.69654859815325, 56.97062179020473, 53.75804921558925, 54.33160563877651, 53.97132764543806, 53.398191588265554, 51.31406552450997, 52.488870416368755, 54.35914134979248, 52.67103828702654, 53.892086914607454, 54.1347006389073, 50.13992418561663, 47.58663838250296, 45.3058192389352, 52.49819489887783, 42.83257668358939, 44.49321004322597, 65.48969691140312, 75.83765602111816, 81.66142068590436, 47.15587786265782, 30.60465042931693, 38.30044044767107, 33.91464022227696, 39.2070483480181, 38.7086193220956, 40.62516873223441, 37.77078969138009, 44.14944444383894, 44.115234988076345, 43.329824515751426, 35.32124049322945, 31.475603648594447, 27.847316878182546, 31.83074344907488, 36.7105119568961, 38.11253683907645, 43.10079799379621, 39.021163191114155, 38.84946972983224, 42.88300323486328, 40.28397396632603, 41.50576605115618, 48.795545033046174, 47.49630832672119, 48.43396772657122, 44.87941523960659, 45.39767095020839, 51.62188809258597, 47.55379772186279, 48.9884409223284, 52.50000837871006, 51.351304394858225, 52.23618527821132, 51.06465646198818, 53.184833254132954, 53.08366400854928, 52.623088768550325, 51.25090639931815, 49.994460174015586, 50.72870758601597, 51.91305235454014, 48.619738238198416, 50.13401126861572, 51.44676569529942, 50.05495466504778, 51.91117634092058, 54.09395292827061, 54.65993928909302, 56.272397313799175, 52.631638526916504, 49.82541397639683, 52.560037340436665, 49.93649135317121, 50.426975114004954, 52.20208699362618, 56.25836195264544, 58.62571048736572, 58.492617743355886, 60.28842830657959, 57.930932317461284, 58.452665601457866, 58.86244256155831, 52.324458667210166, 50.48586457116263, 58.36868967328753, 68.01141357421875, 64.41643646785191, 57.77880498341152, 64.73939568655831, 66.20935658046177, 71.69194384983608, 35.75043766839163, 0.4006080792418548, 44.96589946746826, 58.56054333278111, 73.92247540610177, 30.36165107999529, 15.327515908649989, 40.79100833620344, 40.06531068256923, 31.16134704862322, 56.42990950175694, 44.04190022604806, 44.84815876824515, 42.28392260415213, 57.44914770126343, 70.47372313908168, 70.71694483075822, 6.6820395929472785, 0.8168988940971238, 0.32502098807266777, 0.22969981868352207, 0.27834092719214304, 0.15108051736439976, 0.2381861475961549], [0.0880617064290813, 0.262202541743006, 0.16170982271432877, 0.09408227301069669, 0.1375060850488288, 0.03834028196121965, 0.08016807785523788, 0.09490083051579339, 0.21196698450616427, 0.4220441947025912, 0.09528925110186849, 28.765345879963466, 68.27473640441895, 33.809875283922466, 29.086425610951014, 16.26102375984192, 33.80722107206072, 30.038261072976248, 25.1880658354078, 11.732702953474861, 7.508165206227984, 34.3622327532087, 65.09269768851144, 48.22722407749721, 56.75616216659546, 25.608565602983745, 0.3189978769847325, 41.99523884909493, 66.40892274039132, 59.07887894766671, 54.98182153701782, 59.79161821092878, 55.31191655567714, 50.483220781598774, 50.722124167851035, 54.824281556265696, 54.493338857378276, 53.156922340393066, 55.33465106146676, 53.227151257651194, 52.67348057883126, 53.3072327205113, 51.46233660834176, 52.015555654253276, 45.11722428458077, 43.850216797419954, 44.57082836968558, 50.05969681058611, 56.10991368974958, 53.26244810649327, 47.41924238204956, 54.24156393323626, 51.72630214691162, 47.35430104391915, 46.613862786974224, 49.32904161725725, 47.50361783163888, 51.88682290485927, 50.048725605010986, 50.19309874943325, 50.105002539498464, 51.93543250220162, 51.68163912636893, 47.2644921030317, 47.03463874544416, 45.45575789042881, 45.626148564474924, 46.38019486836025, 43.00756706510271, 40.0006229536874, 40.16021612712315, 41.11864716666085, 38.77942841393607, 37.450839042663574, 33.188636847904746, 30.764198439461843, 36.649239267621724, 52.27012028012957, 64.61389037540981, 65.03301266261509, 100.674485206604, 89.53303486960274, 39.59954513822283, 39.38083321707589, 35.787492411477224, 39.84421552930559, 37.40934092657906, 42.145438058035715, 37.31133311135428, 38.2407762663705, 43.47583048684256, 40.59668806621006, 33.515077114105225, 25.891630002430507, 30.521091393062047, 34.765947410038535, 33.257865224565776, 47.074976512363975, 68.3617834363665, 60.720279693603516, 48.97789355686733, 40.85402849742344, 35.14831372669765, 37.86994743347168, 41.56392594746181, 42.00196123123169, 41.65318945475987, 40.5087377684457, 43.522234031132285, 41.36019434247698, 43.10922268458775, 44.504556451525005, 42.14871760777065, 43.52079575402396, 45.308695793151855, 46.639581544058665, 46.32011032104492, 44.09890672138759, 43.87437915802002, 42.894203730991904, 48.58940935134888, 41.77382755279541, 46.10902057375227, 44.67554119655064, 43.7092239516122, 43.085397311619346, 45.29845067432949, 49.000537736075266, 49.44293301446097, 49.42055981499808, 48.78527559552874, 47.223456042153494, 41.92289767946516, 41.99692031315395, 41.30124582563128, 43.412035601479666, 47.507303850991384, 48.312488896506174, 49.57725558962141, 50.17129877635411, 52.09695380074637, 54.2491374697004, 53.308573722839355, 52.22855268205915, 52.61014774867466, 59.398551668439595, 56.44469179425921, 56.99496480396816, 52.9700540133885, 61.71083572932652, 51.446838651384624, 71.35386535099575, 8.961858630180359, 2.062723223652158, 49.33732386997768, 42.84222425733294, 61.0590877532959, 12.765519670077733, 7.827304652759007, 21.719427824020386, 19.46275019645691, 31.11481843675886, 38.72549302237374, 43.68536731175014, 41.302246366228374, 33.56288072041103, 42.666757924216135, 53.835973262786865, 57.364098276410786, 7.386590838432312, 0.6400885188153812, 0.26424322224089075, 0.08591674188418047, 0.01693313824944198, 0.09771998745522328, 0.19468559324741364, 0.10290403570979834, 0.28886473391737255, 0.3567960501781532, 0.18514282602284635, 0.07671316074473516, 0.027825944192175354, 0.03394699502470238, 0.1362799722701311, 0.19628675947231905, 0.35253430743302616, 0.06036890098559005, 36.91207224982125, 78.02659566061837, 38.23334864207676, 41.5728509085519, 23.345012732914515, 38.09946380342756, 31.706957817077637, 16.32856719834464, 24.356178862707957, 15.418752704347883, 29.970436232430593, 64.66850321633476, 54.348871912275044, 60.86249542236328, 35.69259738922119, 0.10097517778298684, 33.17316320964268, 70.62136541094098, 65.68895735059465, 63.25093173980713, 64.85939107622418, 57.89789015906197, 53.10196556363787, 52.58918503352574, 57.22784062794277, 53.776451519557405, 52.176055567605154, 54.69803278786795, 50.07904059546334, 52.525393622262136, 49.76711859021868, 55.448201996939524, 53.06261791501726, 45.214214188711985, 45.26968165806362, 46.75853817803519, 51.249971866607666, 58.614023617335725, 54.09026690891811, 49.83081272670201, 52.55807794843401, 51.89023447036743, 48.2800338608878, 48.29675122669765, 52.19942583356585, 49.65170553752354, 54.43768378666469, 54.720169748578755, 52.18321916035244, 51.7708922113691, 52.184702600751606, 51.75757598876953, 48.056260177067344, 47.82980796269008, 48.65082447869437, 47.91261659349714, 47.992694582257954, 46.02879319872175, 43.98277105603899, 44.17320033482143, 45.62866381236485, 45.879330498831614, 43.252150603703086, 38.810375690460205, 30.882512365068706, 39.3834422656468, 56.8701091493879, 66.91340364728654, 73.86230400630406, 101.19772624969482, 64.80690438406808, 33.07270615441458, 39.321884700230186, 35.91979653494698, 39.30557727813721, 35.3535600389753, 39.28443043572562, 37.934256485530305, 36.32788855688912, 38.83936357498169, 34.52453224999564, 30.163467611585343, 25.636043991361344, 28.423348597117833, 34.44599676132202, 34.25147499356951, 35.122462953839985, 54.92009374073574, 62.946364402770996, 53.85849584851946, 43.20406559535435, 37.77292626244681, 37.81373998097011, 44.89000082015991, 45.49510901314871, 45.02120018005371, 39.392742429460796, 43.47005653381348, 41.4856927054269, 42.14759199959891, 45.45437519890921, 46.1300492967878, 48.076062543051584, 49.28068562916347, 49.53723743983677, 47.988518714904785, 46.54777847017561, 46.574942452566965, 45.82182025909424, 49.89810255595616, 45.88806438446045, 48.55700990131923, 47.75298867906843, 48.33902406692505, 45.63220739364624, 49.941646916525706, 53.5484950201852, 53.54193939481463, 53.19449472427368, 49.460560594286235, 48.07053872517177, 44.81878178460257, 48.151283740997314, 49.026551791599815, 49.53270026615688, 49.541802406311035, 52.153710160936626, 53.36135918753487, 52.43878780092512, 53.93690626961844, 54.65129920414516, 55.26879950932094, 57.11665555409023, 51.10530342374529, 58.788340023585725, 58.5984457560948, 60.25492409297398, 58.959981373378206, 67.96532617296491, 57.87553433009556, 72.98267596108573, 4.9546379532132825, 4.137091628142765, 48.66323396137783, 44.999361991882324, 68.40655067988804, 14.221658859934125, 10.26755976676941, 26.398422922406876, 21.009339298520768, 25.18035680907113, 51.47042778560093, 52.46280424935477, 48.57561717714582, 40.5087342943464, 54.213656493595664, 57.079017162323, 66.32992172241211, 10.550324525151934, 0.7140670205865587, 0.31025587607707295, 0.18970361272139208, 0.075875556761665, 0.08839716057160071, 0.16493553748088224, 0.3998861179820129, 0.38382687685745104, 0.28763213434389656, 0.12784879468381405, 0.15742149496717112, 0.12071363255381584, 0.13526906365794794, 0.407662427851132, 0.23417272152645247, 0.6666440452848161, 0.29572282305785585, 46.71526479721069, 90.84156131744385, 47.837176527295796, 46.2351199558803, 23.291139875139507, 52.89984246662685, 41.72549588339669, 29.739509378160747, 20.22402436392648, 16.252326352255686, 44.86308697291783, 73.89650303976876, 56.78166900362287, 69.67773056030273, 30.612661702292307, 0.4084737386022295, 53.46582882744925, 69.25716304779053, 68.81773117610386, 64.80271462031773, 67.03134931836809, 59.03576537540981, 55.71070146560669, 54.2851881980896, 57.64813021251133, 56.9308294568743, 55.00428853716169, 55.14877980095999, 54.50381326675415, 54.51763323375157, 56.24954816273281, 59.40645177023751, 56.02708421434675, 49.77882630484444, 47.89169904163906, 46.22288417816162, 51.76770646231515, 59.89912073952811, 55.52206482206072, 51.503000940595356, 57.20780202320644, 52.87914030892508, 52.71896001270839, 53.72787318910871, 54.266507966177805, 51.35910027367728, 58.43740735735212, 55.44185134342739, 56.151126929691856, 54.32218388148716, 57.96163640703474, 55.987420422690256, 51.93326813834054, 52.78373111997332, 48.82558904375349, 51.84028387069702, 52.4068260874067, 48.90510075432913, 47.185265268598286, 48.192531721932546, 50.211223125457764, 48.060248443058555, 48.20035539354597, 41.30402857916695, 35.09095982142857, 42.47853817258562, 62.84150218963623, 68.27962793622697, 83.25886017935616, 96.45372554234096, 55.31660311562674, 33.46295172827584, 39.50727653503418, 35.44219820840018, 38.44787079947335, 35.22591815676008, 40.257952962602886, 47.65238571166992, 44.755511488233296, 38.30082607269287, 36.699335779462544, 31.81501967566354, 27.310533796037944, 30.963733332497732, 36.06142861502511, 36.14617926733834, 33.419831207820344, 50.25901978356497, 55.27615417752947, 53.839669704437256, 45.0510253225054, 38.6832549231393, 40.59727866309029, 47.29645381655012, 48.02250235421317, 48.734070846012656, 44.27178137642996, 47.8787510735648, 45.53965391431536, 45.61104318073818, 49.17065395627703, 50.394936970302034, 50.36013691765921, 54.03498009272984, 55.54640436172485, 51.85220003128052, 50.995320388248985, 51.06168610709054, 49.78807783126831, 52.755319935934885, 48.878228596278596, 51.027212619781494, 51.0809326171875, 51.14597817829677, 49.556327615465435, 51.523237568991526, 56.55185038702828, 55.57209185191563, 55.07746001652309, 51.41883741106306, 51.08509806224278, 47.59338508333479, 51.429440362112864, 51.415102754320415, 50.40802737644741, 52.90802049636841, 53.15805489676339, 57.2391870362418, 55.284749099186485, 56.714962823050364, 58.858905928475515, 59.38714967455183, 59.775929178510395, 54.63514116832188, 64.06971440996442, 63.05409622192383, 67.28355503082275, 61.271250997270855, 70.85274042401994, 57.033377919878276, 78.56884002685547, 11.339758004461016, 3.2033345103263855, 58.600252287728445, 53.03149345942906, 73.05853639330182, 22.58887675830296, 16.867082118988037, 28.296092339924403, 27.809244224003383, 41.64002261843, 56.93947649002075, 54.63622161320278, 53.127086775643484, 44.6512885093689, 57.4175820350647, 66.68207727159772, 77.84992381504604, 15.056699446269445, 0.9315123068434852, 0.27139028587511604, 0.3306532087070601, 0.1792642700352839, 0.10429615208080836, 0.17902481502720288], [0.2745805132601942, 0.20475585359547818, 0.13929497477199348, 0.10757552539663655, 0.06899437707449708, 0.13449419023735182, 0.042585397205714665, 0.2644341348537377, 0.03488250821828842, 0.2748986376183373, 0.21103739153061593, 23.557285411017283, 60.56099918910435, 42.68071685518537, 28.93284089224679, 16.4846966947828, 43.78721053259713, 21.791683878217423, 27.57475641795567, 14.559290068490164, 7.277439849717276, 4.133525465215955, 26.62802788189479, 61.29017094203404, 46.83908864430019, 56.92922094890049, 7.057717834200178, 0.3561719336680004, 50.20314931869507, 59.72489465985979, 56.501868520464214, 50.02411161150251, 48.06056458609444, 51.55194752556937, 56.53698124204363, 53.47587592261178, 55.41821357182094, 55.15125683375767, 53.365555899483816, 54.09895215715681, 55.28921331678118, 50.742687361580984, 54.58627448763166, 48.30868475777762, 42.516690731048584, 45.03648621695382, 50.04846504756382, 50.28426258904593, 52.01078224182129, 48.25778920309884, 49.77181557246617, 55.12543037959507, 49.81286552974156, 50.848900999341694, 47.47204869134085, 46.70097582680838, 47.883104119982036, 48.369728156498496, 48.22752285003662, 50.7211583682469, 51.889445849827354, 50.588291440691265, 48.7059063230242, 48.47520181110927, 47.21210615975516, 46.58111940111433, 43.18539578574044, 42.44545085089547, 40.325628416878835, 39.08513525554112, 38.930652482169016, 36.53162016187395, 36.396331787109375, 34.02796534129551, 28.411448069981166, 21.440266575132096, 25.033730711255753, 30.730343341827393, 32.215197699410574, 40.477203369140625, 39.222660950251985, 68.06531769888741, 59.92945657457624, 37.18107523236956, 43.95922361101423, 40.03264372689383, 41.894267627171104, 40.00167213167463, 40.88044902256557, 43.01749604088919, 38.260592528751914, 38.08611283983503, 35.50114325114659, 26.423549345561437, 30.735047272273473, 30.18513904299055, 60.65072822570801, 89.55276080540249, 66.6700221470424, 46.28606414794922, 40.596132210322786, 32.14273493630545, 26.19061619894845, 28.915836913245066, 35.46742016928536, 39.35240118844168, 37.36333342960903, 38.71488312312535, 40.0847795350211, 40.89631870814732, 41.23505728585379, 43.50871631077358, 41.70001336506435, 45.4858991759164, 45.85926410130092, 45.98668711526053, 46.811848231724326, 44.6044784954616, 43.252202715192524, 46.85638271059309, 41.57649176461356, 46.819807393210276, 42.21406888961792, 44.323920658656526, 43.47768218176705, 41.72452660969326, 47.117020062037874, 51.387594836098806, 49.88092660903931, 50.27846431732178, 49.71579919542585, 49.24809510367257, 48.14094829559326, 43.499009677342, 41.979112080165315, 43.45558343614851, 45.80104167120797, 51.214324133736746, 53.35392461504255, 50.37255334854126, 53.095222336905344, 52.72109658377511, 55.7691775049482, 60.970477376665386, 53.11927005222866, 58.58151994432722, 57.9542852129255, 57.15231370925903, 57.04464789799282, 58.03961951392037, 64.66511249542236, 48.57368210383824, 0.17956395181162016, 14.808061633791242, 50.87290702547346, 52.78483935764858, 55.22457422528948, 6.308751097747257, 8.067659343991961, 25.311559643064225, 27.51104838507516, 31.089064938681467, 30.208255699702672, 46.53186362130301, 42.79858957018171, 17.35406572478158, 27.781696353639873, 49.99147939682007, 54.898488317217144, 5.206316905362265, 0.7980965801647731, 0.2267007210424968, 0.1096799678302237, 0.12777383013495378, 0.04646240720259292, 0.22452536491411074, 0.10104706178286246, 0.10229347632931811, 0.1262217898453985, 0.39763164467045237, 0.09084029375974621, 0.08978380795036044, 0.4894399025610515, 0.4920670273048537, 0.26436543996844974, 0.4642694560544831, 0.21611115070325987, 28.910278354372295, 72.44940866742814, 48.454843589237754, 36.14334787641253, 20.04321312904358, 49.90234790529524, 16.415890421186173, 21.441458191190446, 14.397440467561994, 16.286452429635183, 7.7006789445877075, 26.329442943845475, 64.57575171334403, 53.38835293906075, 67.45844118935722, 13.942368200847081, 0.5176207646727562, 42.67418902260916, 60.24102074759347, 65.97102642059326, 51.97654846736363, 48.65042495727539, 57.04538440704346, 58.80773939405169, 52.77869020189558, 55.33168418066842, 56.631483691079275, 54.86840261731829, 56.36024338858468, 56.26116902487618, 54.79761437007359, 54.36821569715227, 49.188048771449495, 45.083768708365305, 47.052777017865864, 53.22043234961373, 50.096195697784424, 51.50142369951521, 50.901644774845664, 52.79920128413609, 57.92346995217459, 51.50639166150774, 51.27985259464809, 49.49152871540615, 44.64661584581648, 49.12028299059187, 47.391633714948384, 49.236818177359446, 50.4412328175136, 49.326873779296875, 48.54679257529122, 45.51713827678135, 49.14025558744158, 48.3916323525565, 47.88481685093471, 46.75802748543875, 45.911031654902864, 44.61433104106358, 41.13401658194405, 43.66993883677891, 39.56371327808925, 40.18155057089669, 39.86956255776541, 30.83042172023228, 26.25956491061619, 29.725001539502824, 38.13557011740548, 47.584317684173584, 48.745313031332834, 45.73622192655291, 77.42059462411063, 48.39720828192574, 36.53329120363508, 38.970920767102925, 36.64567831584385, 39.44931466238839, 40.697662762233186, 41.654728480747764, 42.33130931854248, 37.0703626360212, 37.82253987448556, 31.744429452078684, 21.962084974561417, 27.961599111557007, 31.621769428253174, 39.42814697538103, 77.7155248097011, 81.56398609706334, 58.02566058295113, 48.452470779418945, 40.08796180997576, 33.672853333609446, 37.15419960021973, 39.76177167892456, 41.59257337025234, 40.934193338666645, 43.03128474099295, 43.19309786387852, 42.6162862096514, 42.6523369380406, 44.64830425807408, 45.755537918635774, 46.22249507904053, 48.74675825663975, 49.778527532305034, 48.578389508383616, 44.54877826145717, 45.88244676589966, 47.8230299949646, 45.96360867364066, 48.603941508701865, 46.56803594316755, 47.59624426705496, 45.48133420944214, 45.49302455357143, 51.87117556163243, 55.782660484313965, 54.924283504486084, 52.66597999845232, 52.30569505691528, 54.41903134754726, 51.37571689060756, 49.57187073571341, 47.0605902671814, 48.10113859176636, 52.80538518088204, 53.23503398895264, 56.01244783401489, 52.85896968841553, 53.89604391370501, 53.749037402016775, 57.00744029453823, 60.924195425851, 53.03101750782558, 57.03016437802996, 59.77264962877546, 58.0880970954895, 64.06795651572091, 60.884903362819124, 69.93309770311627, 44.06660107203892, 0.24272687679954938, 20.2523695400783, 55.49865286690848, 57.94019079208374, 54.097138677324565, 5.5520349485533576, 19.55428055354527, 28.959952763148717, 29.897386346544536, 27.78358973775591, 42.36568553107125, 56.218666894095286, 44.36079822267805, 27.75476861000061, 33.48026663916451, 55.41206094196865, 66.01286847250802, 10.651944535119192, 1.37867328950337, 0.3434916340879032, 0.10176446328737906, 0.139603178948164, 0.04270429350435734, 0.07486842758953571, 0.18972129534397805, 0.2576645809624876, 0.14830771115209374, 0.3664471251623971, 0.149438259058765, 0.14362666090684278, 0.484095815036978, 0.5236674887793404, 0.3401234676795346, 0.7611940460545676, 0.27605828110660824, 37.53736843381609, 83.03388445717948, 56.689282281058176, 42.490881647382466, 23.458405596869333, 67.65706934247697, 32.2068772315979, 34.06822320393154, 21.823862722941808, 13.616993614605494, 14.642691033227102, 35.40113435472761, 71.56630652291435, 56.13776206970215, 73.55269227709088, 9.808335082871572, 1.5490331309182304, 62.53486428941999, 61.824369294302805, 63.53159032549177, 51.06089401245117, 50.791428974696565, 52.09122501100813, 58.90773091997419, 56.69235338483538, 61.162372725350515, 58.793829100472585, 56.87630694253104, 58.66386999402727, 61.31077235085623, 57.548729283469065, 56.858356271471294, 53.225410733904155, 47.093587262289866, 47.87751082011631, 55.24083995819092, 49.69353369304112, 56.376731463841026, 55.91210542406355, 56.36076102937971, 60.88667515345982, 54.96673699787685, 54.28891590663365, 52.72421285084316, 52.93885660171509, 51.5980349268232, 50.738580976213726, 52.067357948848176, 54.20983498437064, 53.8020521572658, 54.705359663282124, 49.55080727168492, 53.28080872126988, 51.77114234651838, 55.17718056270054, 49.31222350256783, 50.83116224833897, 47.7290278162275, 48.194974013737266, 48.18555225644793, 46.85348531178066, 49.40979010718209, 43.372906821114675, 34.1951459475926, 30.975517477308, 31.86706863130842, 43.06502866744995, 57.50422607149397, 56.219952310834614, 57.95919758932931, 81.63455895015171, 44.63277850832258, 38.67195020403181, 40.23586463928223, 35.25042445319039, 37.549256801605225, 39.00346960340227, 42.57935306004116, 46.06641074589321, 38.051917280469624, 37.2323112487793, 33.96377788271223, 24.326702867235454, 32.11590099334717, 35.5488634790693, 40.12992198126656, 65.61293710981096, 74.51658807482038, 57.75553546633039, 46.55757195608956, 44.03884996686663, 34.12407977240426, 39.801504952566965, 44.975574834006174, 46.06279420852661, 44.100254671914236, 46.20304012298584, 45.95513187135969, 46.86766658510481, 49.232117721012656, 49.50393124989101, 47.802762099674766, 51.10532774244036, 52.36458798817226, 53.15938547679356, 53.44952835355486, 50.926564489092144, 51.04855401175362, 51.75715562275478, 49.42151171820504, 52.41930157797677, 48.404097420828684, 52.9221705027989, 49.307311126164024, 47.8992725781032, 53.29637616021292, 56.92932169778006, 55.30397129058838, 54.79088503973824, 54.331445830208914, 54.25794431141445, 55.102886949266704, 52.14511176518032, 50.58180182320731, 52.5962860924857, 55.025084495544434, 59.07421670641218, 60.516079085213796, 56.58897461209978, 57.81045055389404, 60.94867392948696, 61.14631543840681, 68.75122996738979, 57.58023588997977, 62.323291642325266, 64.36353983197893, 67.76745537349156, 65.67021805899483, 65.75114372798375, 66.55138165610177, 57.97414663859776, 0.2941000387072563, 17.341828210013254, 64.54160826546806, 62.252433913094656, 66.27541310446603, 13.797601614679609, 19.670940807887487, 32.078432832445415, 39.9520446232387, 43.61912318638393, 48.03710399355207, 60.37500286102295, 60.59025805337088, 25.782230615615845, 38.18998840876988, 60.43748106275286, 75.07123497554234, 15.151905400412423, 1.5250199394566673, 0.3442590300525938, 0.18834431708923408, 0.21817115587847574, 0.13042565355343477, 0.40881677876625744], [0.028370195434295704, 0.07000633063060896, 0.1998805794864893, 0.1916160908128534, 0.10944306411381279, 0.013548734498077204, 0.1530022642442158, 0.23649727393473896, 0.012023382687142916, 0.11515904989625726, 0.060959952484284124, 24.619828258241924, 66.30998039245605, 32.70573009763445, 37.1340011869158, 22.606870855603898, 37.65030792781285, 43.7642571585519, 49.63705178669521, 46.10813815253121, 14.19240607534136, 7.305114524705069, 7.407533577510288, 49.743095193590435, 51.25088555472237, 52.188697814941406, 46.20700754438128, 0.33697311101215227, 1.0634831339120865, 30.86032329286848, 49.02783373423985, 52.7631505557469, 54.14016192299979, 60.12948131561279, 50.521012033735005, 53.689018862588064, 57.34230177743094, 54.38491916656494, 53.55138547079903, 56.57793739863804, 51.28161743709019, 52.09756176812308, 51.74944659641811, 45.95081009183611, 42.63635260718209, 49.940309388296946, 52.3000739642552, 62.52283695765904, 67.48505973815918, 69.8227116721017, 49.13783066613333, 49.77413279669625, 61.261905670166016, 50.90401063646589, 52.27476862498692, 45.843356200626914, 45.360352175576345, 44.74192081178938, 47.68887765066964, 46.30649185180664, 48.680802481515066, 44.823906081063406, 47.93127598081316, 45.48396062850952, 46.498526164463584, 44.93484101976667, 44.58917856216431, 42.22982740402222, 38.436187403542654, 35.89846209117344, 34.09244809831892, 32.33687455313546, 27.947586332048687, 25.252783094133648, 15.388114622661046, 19.761336871555873, 21.667854819978984, 19.560433183397564, 15.26135516166687, 10.185801182474409, 26.8545252595629, 25.639259270259313, 52.68193653651646, 41.716386795043945, 41.83188670022147, 40.544131892068044, 42.4516555922372, 38.9956841468811, 45.611407961164204, 39.142405782427105, 36.38785151072911, 39.041295596531455, 37.45747109821865, 35.13857930047171, 33.077649797712056, 44.617287499564036, 72.16387939453125, 40.65858956745693, 30.594860417502268, 28.114975384303502, 24.593280928475515, 18.234777688980103, 14.709596974509102, 16.60732545171465, 24.137906415121897, 26.577043737683976, 31.65915421077183, 36.54333482469831, 36.366416318076, 39.923115798405235, 40.613266468048096, 42.13120814732143, 43.90433979034424, 42.097637925829204, 42.78833750316075, 43.89810030800955, 44.9726322719029, 44.39014046532767, 46.35737351008824, 43.04075860977173, 45.317603383745464, 44.73436117172241, 43.13881158828735, 44.288523060934885, 43.09287357330322, 43.813825607299805, 49.33762959071568, 51.190314633505686, 51.892475264413015, 50.76291356767927, 52.09438296726772, 51.990309374673025, 57.64168575831822, 50.38230167116438, 42.38850341524397, 42.86757823399135, 47.61108909334455, 50.16194302695138, 52.729285035814556, 53.14162935529436, 50.67794057301113, 51.82107904979161, 55.62707642146519, 57.81567212513515, 58.1911666733878, 54.25933395113264, 59.9051239831107, 56.08286782673427, 61.297619410923545, 56.29869624546596, 70.8985846383231, 8.217360019683838, 0.027994197128074508, 42.26162930897304, 47.473785740988596, 59.550897870744976, 24.909503868647985, 1.2498445681163242, 13.738847647394453, 18.736529690878733, 19.87708864893232, 30.33706487928118, 33.64032186780657, 39.66434056418282, 36.93929181780134, 29.746850149972097, 26.174878529139928, 45.2527106830052, 55.5741137777056, 6.927773058414459, 1.319115611059325, 0.2733057088085583, 0.08590170554816723, 0.04673546326479741, 0.09645394967602831, 0.18126518838107586, 0.01357134582940489, 0.04423545866406389, 0.22741088936371462, 0.2444331752402442, 0.09835240244865417, 0.10269488407565014, 0.2909995950758457, 0.2899041138589382, 0.06042783175195966, 0.10878956703735249, 0.07994834107479878, 30.30302218028477, 74.4500104359218, 39.76974126270839, 39.20447056634085, 21.76773691177368, 45.356106826237266, 32.660087381090435, 47.40756246021816, 39.479171071733745, 11.858844893319265, 9.378370131765093, 9.446345227105276, 50.06538391113281, 61.876633644104004, 55.28855323791504, 57.16451474598476, 1.010261886886188, 0.5623746546251434, 26.66890413420541, 43.961061409541536, 54.73962123053414, 58.17360857554844, 60.496019635881694, 53.21864318847656, 53.99566371100289, 58.57924093518938, 54.97778810773577, 55.61331898825509, 56.88307448795864, 55.740102767944336, 53.47514636175973, 51.67491327013288, 47.823686599731445, 47.41053976331438, 53.83495535169329, 57.71455846514021, 64.64865916115897, 72.06656987326485, 71.05428682054792, 50.19237961087908, 49.29592650277274, 61.93394238608224, 52.38305630002703, 51.7690509387425, 47.8910493850708, 44.23438269751412, 46.48304557800293, 50.81096036093575, 46.63729906082153, 50.17295592171805, 44.58686481203352, 49.62513910021101, 46.71672739301409, 47.800191266196116, 49.484458923339844, 48.26418501990182, 48.47518444061279, 41.26035220282418, 42.32073416028704, 40.453183446611675, 36.69676147188459, 34.45756203787667, 34.84280143465315, 22.006405796323502, 24.928363016673497, 23.307023457118444, 27.132477521896362, 22.621936287198746, 20.71970190320696, 31.930589062826975, 26.376942566462926, 54.45824350629534, 38.88322407858712, 40.79592766080584, 41.411941051483154, 42.01799419948033, 35.937104497637065, 40.299781118120464, 36.24001816340855, 35.07838010787964, 35.29850251334054, 35.31807211467198, 30.79927294594901, 29.911546775272914, 34.107664653233115, 67.71328026907784, 64.24262033190045, 46.834356921059744, 46.00691679545811, 41.87897464207241, 24.07002772603716, 19.316412448883057, 21.582527467182704, 31.596311228615896, 33.00975547518049, 38.76304803575788, 39.08569458552769, 42.59013319015503, 41.245000158037456, 43.9388028553554, 43.08316346577236, 46.282614367348806, 44.93246820994786, 48.42495938709804, 45.46607943943569, 44.61287539345877, 45.02355214527675, 49.32113109316145, 45.448608194078716, 47.48641061782837, 46.16170528956822, 45.77632692881993, 46.27881717681885, 44.13196277618408, 46.577523708343506, 51.469305651528494, 56.95547819137573, 54.90450893129621, 51.83082389831543, 55.909753458840505, 52.45873260498047, 58.71456405094692, 56.48260463987078, 46.28683539799282, 44.63280282701765, 50.36875268391201, 52.44053874697004, 53.74261726651873, 52.93351343699864, 51.84497390474592, 53.57374129976545, 57.944644587380544, 55.78621448789324, 58.441930634634836, 56.18938371113369, 59.0472993850708, 59.989065170288086, 65.86004284449986, 61.00771277291434, 69.33123779296875, 3.1518511814730505, 0.24321045513663972, 52.8400045803615, 54.293835231236045, 65.4222993850708, 24.135523183005198, 5.151152116911752, 17.20587280818394, 12.144632118088857, 24.2279429095132, 28.687836987631663, 41.39907993589129, 43.75598880222866, 42.07816559927804, 31.139144080025808, 28.404701369149343, 52.76041643960135, 64.53766863686698, 11.417876601219177, 1.0633980184793472, 0.15325522209916795, 0.0963435113163931, 0.016363933882010833, 0.06026247955326523, 0.12481441322181906, 0.06538550036826304, 0.1913889715714114, 0.359110315995557, 0.2929496504366398, 0.0870387198935662, 0.1414419545658997, 0.3370065220764705, 0.5658383316227368, 0.1012303340913994, 0.3252089965556349, 0.08275275344827346, 36.91632802145821, 90.89750126429966, 47.375958578927175, 55.834549631391255, 33.6890287399292, 54.47185155323574, 58.3282789502825, 55.62192780630929, 57.81510932104928, 21.2224440234048, 13.331137776374817, 15.988006455557686, 56.56325238091605, 63.81144986833845, 61.48202460152762, 56.43609687260219, 0.5600399513329778, 2.4092644112450734, 42.967566285814556, 50.49625907625471, 53.77590608596802, 54.72142737252371, 61.17194734300886, 54.759218624659944, 61.057642527988975, 61.52844551631382, 58.85756492614746, 57.15305716650826, 61.372764178684776, 58.07450641904558, 57.165313788822715, 56.03702361243111, 52.665709018707275, 49.29198687417166, 55.50603185381208, 57.28404460634504, 63.63549368722098, 66.49719265529087, 62.94154235294887, 47.93352024895804, 56.876143659864155, 62.9353723526001, 55.76624189104353, 57.66124146325247, 48.59416886738369, 47.37760877609253, 46.581022126334055, 52.16566801071167, 52.148700509752544, 52.96871995925903, 48.10802773066929, 52.10605246680123, 50.68942594528198, 50.64771243504116, 53.07134485244751, 53.06022078650338, 53.04092563901629, 47.5738536970956, 46.63300159999302, 47.525980608803884, 46.3042892728533, 43.662928104400635, 45.042572838919504, 27.714677504130773, 29.4119712965829, 30.21332093647548, 32.674466678074424, 34.84472261156355, 32.65354912621634, 43.22328431265694, 39.15712901524135, 59.79056903294155, 37.55875151497977, 40.954791273389546, 39.39724486214774, 40.08220870154244, 34.92097214290074, 39.10242584773472, 33.33917999267578, 32.9738576071603, 35.17691946029663, 38.2101868220738, 34.38971287863595, 33.52764293125698, 35.653531142643516, 62.52275357927595, 60.781257084437776, 49.42458977018084, 45.02186720711844, 47.32914509092058, 29.15138258252825, 25.360912697655813, 28.154793773378643, 40.93398836680821, 37.93373189653669, 42.90459476198469, 44.337014538901194, 45.69657897949219, 47.02342782701765, 47.6432523046221, 45.845346859523225, 50.64577736173357, 49.19022355760847, 49.087633405412944, 49.78041396822248, 50.57843542098999, 49.73390620095389, 52.30708817073277, 49.41106162752424, 50.59314823150635, 49.2249367577689, 50.09977749415806, 51.317424978528706, 49.46070998055594, 50.45257922581264, 55.664280550820486, 57.63894121987479, 56.64942046574184, 54.08799484797886, 56.796374865940635, 57.97202396392822, 55.93375253677368, 59.11922018868582, 49.27529035295759, 45.80960185187203, 51.97763933454241, 55.96600260053362, 59.11604486192976, 57.230932576315745, 55.3707469531468, 57.3799957547869, 63.52494089944022, 61.12816674368722, 61.98729065486363, 58.50467981610979, 65.56200681413922, 61.491224016462056, 71.07076794760567, 61.30868789127895, 78.42759704589844, 12.944032788276672, 0.13584893968488487, 51.63381120136806, 57.61716556549072, 71.65909276689801, 35.49520601545061, 7.764275806290763, 21.078129938670568, 25.898640734808787, 31.732148511069163, 39.7100145476205, 52.852483545030864, 49.811653069087434, 52.24581548145839, 38.75559261866978, 34.328485352652415, 59.03905882154192, 75.58429690769741, 18.10265248162406, 1.1824964391333717, 0.42137909467731205, 0.3818884380161762, 0.08699887631727116, 0.14153794012963772, 0.31892057827540804], [0.050268249054040225, 0.03918368402602417, 0.11415730150682585, 0.03361886227503419, 0.08736461347767285, 0.08925298321992159, 0.11529386123376233, 0.1271677083734955, 0.09186807753784315, 0.19484848236399038, 0.2722560694175107, 24.02095433643886, 61.61920288630894, 38.99051121303013, 45.26471022197178, 25.662815400532313, 37.82150459289551, 26.162898097719463, 78.76001971108573, 84.81716047014508, 16.09704453604562, 5.287394566195352, 10.655818155833654, 27.682594197137014, 54.792646408081055, 47.765373843056814, 59.990315846034456, 16.213411228997366, 0.5926280340978077, 2.4993161048207964, 19.26671024731227, 43.21775007247925, 55.80909490585327, 57.402049337114605, 51.6393141746521, 53.81971795218331, 52.75500726699829, 53.35502243041992, 55.734578950064524, 56.74034111840384, 55.8385135786874, 56.520468848092214, 52.57256146839687, 45.62137515204293, 46.865905216761995, 52.81555734361921, 64.05041231427873, 64.38127163478306, 63.71308422088623, 72.83822291237968, 86.97975254058838, 63.88590676443917, 52.88521998269217, 58.52361365727016, 53.596142292022705, 49.5130820274353, 49.72346305847168, 48.45543418611799, 52.22695459638323, 54.10714060919625, 46.55158608300345, 48.44193383625576, 48.629205158778596, 45.59210239137922, 46.12332691465105, 46.19915607997349, 37.182232107434956, 39.607243742261616, 37.85011032649449, 34.663242612566265, 30.617772102355957, 25.563916478838237, 21.708220379693167, 17.05549989427839, 21.18908224787031, 25.402692215783254, 24.789027316229685, 19.681463854653494, 18.42201427050999, 10.359555653163365, 15.631376266479492, 24.991166046687535, 29.957700184413365, 34.937085015433176, 38.1573839868818, 41.945788519723074, 40.032126086098806, 43.324533462524414, 38.69643912996565, 35.99332584653582, 33.961988721575054, 36.33623334339687, 37.87555462973458, 42.520071029663086, 33.05995968409947, 41.79191023962838, 29.559224469321116, 26.955968958990915, 13.980311444827489, 11.883691651480538, 12.332976068769183, 14.450412665094648, 12.860578843525477, 12.841460006577627, 12.507053630692617, 17.378377471651348, 23.997714349201747, 29.7928854397365, 35.11427102770124, 37.95738009044102, 39.53418690817696, 41.21186419895717, 43.494680949619834, 43.16778905051095, 42.65983057022095, 45.13571344103132, 43.70183801651001, 45.92452505656651, 44.820133209228516, 47.57239804949079, 45.42484882899693, 43.31965930121285, 43.24984380177089, 41.253060068402974, 42.1466018812997, 46.94589287894112, 51.1049143246242, 51.36509656906128, 50.24007204600743, 52.79940973009382, 47.49908760615757, 64.54135118212018, 84.12476553235734, 51.277865409851074, 48.46575920922415, 39.997541427612305, 47.68710238592965, 54.43856620788574, 54.57479953765869, 53.676491260528564, 54.487849780491416, 52.70716197150094, 55.61652905600411, 54.87455872126988, 58.35270186832973, 59.09162194388253, 57.173332009996685, 60.59195341382708, 56.988683632441926, 64.06268978118896, 28.106800828661235, 0.7781078070402145, 8.908942018236433, 51.081571851457866, 47.08568368639265, 54.39289569854736, 10.180694256510053, 3.4038753722395216, 13.802598237991333, 26.176433188574656, 23.60193279811314, 23.641369036265782, 37.418776580265586, 41.838077545166016, 31.09767028263637, 31.77672815322876, 36.686328751700266, 50.987534931727815, 50.74285759244646, 5.388221612998417, 0.649898995246206, 0.06152070739439555, 0.25559551055942265, 0.05695047548839024, 0.2161270419933966, 0.0010219274907805292, 0.13767875864037446, 0.0348699180010174, 0.009822277851136667, 0.06619390020413057, 0.15681443682738713, 0.20679833899651254, 0.15046131344778196, 0.12527737766504288, 0.18704019992479257, 0.1304541113121169, 0.2485213487276009, 28.25016474723816, 69.87063339778355, 44.9949186188834, 51.61111143657139, 31.127078533172607, 43.11182478496006, 39.79804127556937, 95.6400706427438, 98.91399233681815, 16.546863964625768, 6.586715519428253, 15.572518076215472, 29.115639311926707, 61.05011068071638, 53.423052242824006, 66.92757797241211, 22.03321542058672, 0.3123324917895453, 0.31368980609944885, 18.216241632189067, 44.046840395246235, 54.03134618486677, 58.05964074816023, 55.403935023716514, 56.532235622406006, 52.845073291233604, 58.880924769810264, 58.917208262852256, 58.48457867758614, 58.881244386945454, 55.531559535435264, 54.17018856321062, 46.29487098966326, 52.228639534541536, 57.95254121507917, 69.31158133915493, 62.21995108468192, 62.92712484087263, 69.8224128995623, 86.17991065979004, 65.29220131465367, 50.52284983226231, 58.85886423928397, 56.46338244846889, 51.958510943821494, 53.464522566114155, 48.34675741195679, 52.644982542310444, 52.782449177333284, 47.49008968898228, 49.10862738745553, 50.7138523374285, 49.39617163794381, 50.20351757322039, 49.521718638283865, 41.23369196483067, 42.71674673897879, 45.771678583962576, 42.12003891808646, 38.22937079838344, 29.93427085876465, 30.13427128110613, 20.939263241631643, 23.763534000941686, 27.348813159125193, 26.30432173183986, 22.125642095293315, 24.090168816702707, 10.752188801765442, 16.05666855403355, 24.19653010368347, 31.42818914140974, 37.88516746248518, 37.895951066698345, 38.668121746608186, 37.947214875902446, 39.77166591371809, 37.6641070502145, 40.98551620755877, 39.19814770562308, 34.720481872558594, 35.16599689211164, 36.53397907529558, 33.28211791174752, 42.4415876524789, 35.113861083984375, 30.242010048457555, 28.79208775929042, 27.085968017578125, 18.994191476276942, 17.333888156073435, 18.934933764593943, 16.460075753075735, 15.497117962156024, 28.24661421775818, 30.168908051082067, 36.45516218457903, 41.15955468586513, 43.40166541508266, 42.85753113882882, 45.07668501990182, 46.60561874934605, 44.586767537253245, 45.53275087901524, 47.336041178022114, 44.8380560874939, 46.83104610443115, 46.27256727218628, 49.5335236276899, 46.488426957811626, 47.20543588910784, 45.20597015108381, 43.694785594940186, 45.16295037950788, 47.943807056971956, 54.90074648175921, 51.18836218970162, 52.61231211253575, 55.44362660816738, 52.28935636792864, 58.63231127602713, 83.17437703268868, 56.097490310668945, 46.776235239846365, 43.57426561628069, 49.83438410077776, 53.562818731580464, 55.0952786718096, 51.12273645401001, 54.93499762671334, 54.31804275512695, 57.933454513549805, 56.314176831926616, 57.46744925635201, 58.51915291377476, 56.58958257947649, 60.58938258034842, 57.84046329770769, 63.70887361254011, 20.2902980191367, 0.5498466183032308, 14.679007530212402, 59.97543280465262, 55.5094746862139, 61.61778545379639, 14.296441452843801, 7.469787699835641, 10.183931248528616, 20.438565628869192, 25.267311777387345, 19.834589992250713, 29.447386264801025, 42.35031958988735, 36.31520462036133, 25.724539722715104, 32.46113961083548, 56.063343388693674, 62.43959059034075, 8.508179477282933, 0.8422083045755113, 0.1370415599750621, 0.20303229322390898, 0.021597323506804447, 0.047172198936875374, 0.03781007809032287, 0.20173109376004764, 0.17029075297926152, 0.09270193600761038, 0.16601438101913246, 0.1429226401128939, 0.2453689564551626, 0.2248281136687313, 0.31540943096790997, 0.21677227451332978, 0.3302910067141056, 0.23995172285607883, 34.67985922949654, 81.75909151349748, 51.22844634737287, 62.72999055044991, 37.68297488348824, 53.67578949247088, 33.464191981724326, 80.951217515128, 90.28808171408517, 24.27910770688738, 12.14505682672773, 19.09866111619132, 34.62022631508963, 64.21302795410156, 56.144025870731895, 69.91879136221749, 21.105973107474192, 0.7261363129530634, 4.367884295327323, 31.445743765149796, 51.42298201152256, 60.37933158874512, 59.03554998125349, 57.28748743874686, 62.10586166381836, 57.291979449135916, 61.20252636500767, 62.258367674691335, 62.50743280138288, 62.23360429491316, 61.453620365687776, 58.038987227848594, 49.15813677651541, 54.07781573704311, 58.32800102233887, 69.10580348968506, 65.38243756975446, 66.81323146820068, 71.37793391091483, 72.46953065054757, 52.50026546205793, 56.56965167181832, 61.363967759268625, 59.25966412680489, 54.5941606930324, 56.37104436329433, 51.29484680720738, 55.97856841768537, 57.67294570377895, 51.588613169533865, 51.65327310562134, 56.02757406234741, 53.14728518894741, 54.27804544993809, 54.07842370441982, 44.16975402832031, 49.2404659816197, 49.915181228092735, 47.33693402154105, 45.95398194449288, 43.713677746909006, 43.76849903379168, 27.961809294564382, 30.57591962814331, 34.56924043382917, 32.467438152858186, 28.237939391817363, 33.202366488320486, 19.908680370875768, 34.269700118473594, 37.83766262871878, 38.6869409424918, 37.60631888253348, 38.80083233969552, 40.13726622717721, 35.42260428837368, 39.28206804820469, 39.65239661080496, 40.77851894923619, 37.79789808818272, 37.288289410727366, 37.50073058264596, 41.75814546857561, 33.79099702835083, 43.929280349186485, 41.372357164110454, 38.17458425249372, 30.424813679286412, 33.268805163247244, 28.230336325509207, 25.06191781588963, 25.059878519603185, 23.27192463193621, 26.27168604305812, 36.16238941465105, 36.86716604232788, 41.67770964758736, 47.96432508741106, 46.07319566181728, 45.29274272918701, 46.72585037776402, 48.930374826703755, 48.87534856796265, 51.32359150477818, 52.888784408569336, 48.390197549547466, 49.014642579214915, 52.71116760798863, 53.005027770996094, 50.800934110369, 48.26440736225673, 51.424757276262554, 45.842484201703755, 49.5067800113133, 51.943711280822754, 56.643497126443044, 53.3437385559082, 54.560659953526084, 57.123374462127686, 55.72728681564331, 55.396451813834055, 84.7496726172311, 61.625011580330984, 49.39434426171439, 46.41238587243216, 52.03251968111311, 58.198100975581575, 58.103695801326204, 54.64421551568167, 57.47927509035383, 54.52163539613996, 61.82208333696638, 60.50998551504952, 59.64767238071987, 64.5484105518886, 60.39905752454485, 64.6222699029105, 59.836538314819336, 68.27875941140312, 36.655860900878906, 0.8631444211517061, 11.354338799204145, 65.16122082301548, 58.64674963269915, 66.13970783778599, 20.864026410239084, 10.905935066086904, 22.63210497583662, 37.6602577481951, 32.69688851492745, 30.456348078591482, 57.43416043690273, 51.13355827331543, 43.57681213106428, 41.25812183107649, 48.60186052322388, 63.34958921160017, 73.81618186405727, 15.923806837626866, 1.1267928395952498, 0.24448528672967637, 0.2774179567183767, 0.12491303150142942, 0.28493368199893404, 0.17305703168468817], [0.025310925307816694, 0.06011438928544521, 0.11176482095782246, 0.06025631166994572, 0.34384696930646896, 0.07649368859295334, 0.22571562390242303, 0.04044797457754612, 0.09767290391027927, 0.243799803512437, 0.24725655945284025, 23.61348417827061, 68.05786228179932, 49.49552740369524, 37.94775683539254, 13.137967433248248, 37.70917306627546, 11.429351551192147, 16.14769169262477, 29.910362107413157, 11.47882446220943, 3.5898489015442983, 22.776238407407487, 44.08735186713082, 46.80762025288173, 53.97334609712873, 55.02170419692993, 26.328544889177593, 0.1860088538378477, 0.04226594291893499, 4.010705632822854, 30.086398192814418, 48.252720492226736, 58.40420191628592, 50.42156941550118, 55.84332520621163, 52.25484813962664, 60.962424414498464, 55.51595735549927, 55.56424733570644, 52.81936495644705, 53.421877997262136, 51.137918267931255, 43.65809563228062, 46.32664162772042, 51.83285972050258, 51.64098869051252, 50.62862573351179, 43.18692091533116, 34.26726824896676, 41.09360238483974, 68.55260876246861, 66.65338815961564, 49.0256415775844, 54.37479911531721, 55.71703127452305, 52.5823723248073, 55.697701386043, 52.66773441859654, 52.02036033357893, 52.53819567816598, 47.98699358531407, 41.673106466020855, 44.218909059252056, 39.26003531047276, 40.184128352573936, 15.729978152683803, 13.986913102013723, 35.347619329180034, 25.886429275785172, 22.090440784181865, 16.299325704574585, 17.17836662701198, 24.087017808641704, 27.29088429042271, 24.142255987439835, 22.374528305871145, 23.944119419370377, 18.90110124860491, 16.680422237941197, 17.511006423405238, 19.638075828552246, 22.65116388457162, 30.233147621154785, 39.06306082861764, 33.99643094199044, 35.64390788759504, 34.022590909685405, 38.76343366077968, 37.800260475703645, 37.24581854684012, 34.15564891270229, 33.529543263571604, 35.07724755150931, 38.2025021144322, 32.92427526201521, 20.217618124825613, 17.749842064721243, 5.256743890898568, 7.639119642121451, 13.268769877297537, 12.600272400038582, 10.860868181501116, 9.450771229607717, 9.522466216768537, 11.249469637870789, 13.793944256646292, 23.192454610552105, 30.95474931171962, 34.35423885072981, 38.423256805964876, 41.89953088760376, 45.907929284232004, 43.93359170641218, 44.25568240029471, 44.13519368852888, 47.500272274017334, 48.90722342899868, 50.91941131864275, 47.54125622340611, 44.79817342758179, 47.14335026059832, 47.71702132906233, 44.47512040819441, 45.97135591506958, 47.81320524215698, 50.30209861482893, 50.03364453996931, 51.638212885175435, 51.01730101449149, 58.60747841426304, 81.16218566894531, 53.5272786957877, 50.15283046449934, 48.551135199410574, 41.68265676498413, 43.64622810908726, 47.95973232814244, 52.726790632520405, 52.98779623849051, 55.34551109586443, 52.150527885981965, 54.32857622419085, 51.70654494421822, 58.264445849827354, 52.061010769435335, 55.97912079947335, 49.84907954079764, 61.19853809901646, 35.273266656058176, 0.3699118063918182, 0.10670702771416732, 25.175628559929983, 49.546509810856406, 48.25886269978115, 47.08776119777134, 21.54824158123561, 9.207164781434194, 5.285776938710894, 16.313791854040964, 22.585425240652903, 62.94229275839669, 44.535531520843506, 40.53903538840157, 29.60500614983695, 40.30276884351458, 41.64745371682303, 46.88718407494681, 52.585891587393625, 5.191502043179103, 0.6631859051329749, 0.23100325731294497, 0.09256780320512396, 0.067518644833139, 0.2617386137800557, 0.1324094185339553, 0.015156173779230033, 0.05341986779655729, 0.1260758369628872, 0.10135519810553108, 0.2233386885906969, 0.19537858106195927, 0.22058911541742937, 0.015062639423246895, 0.03775308793410659, 0.13280124536582402, 0.29900831675955225, 26.234223093305314, 77.54679475511823, 49.69061892373221, 36.79763541902815, 19.34228754043579, 46.256697586604524, 20.26508821759905, 29.1121825831277, 40.555398396083284, 15.093580484390259, 5.677932398659842, 27.026387214660645, 49.07314988545009, 48.06544916970389, 61.0342618397304, 61.17118304116385, 32.7971544946943, 0.1776326783001423, 0.06503200397959777, 2.563818403652736, 36.22355440684727, 51.3872960635594, 60.105815751211985, 52.24448142732893, 57.13071870803833, 52.338421072278706, 62.1786926814488, 58.063281604221885, 58.127260616847444, 54.21131495067051, 56.86505086081368, 52.72005435398647, 44.952208042144775, 46.17768267222813, 55.23595190048218, 51.13950593130929, 53.70702164513724, 49.44241884776524, 38.78749874659947, 44.39505284173148, 74.4530884878976, 74.45510346548897, 52.67622511727469, 54.05434819630214, 56.72733061654227, 53.997289589473176, 57.05691841670445, 54.248268944876536, 53.50857761928013, 54.83323431015015, 48.80062764031546, 44.98525020054409, 47.32932226998465, 41.54096909931728, 43.42979172297886, 16.34392445428031, 16.279120343072073, 37.47225686482021, 33.280502455575125, 28.881988763809204, 23.039668934685842, 22.109973907470703, 26.312579665865215, 36.34133332116263, 32.42391811098371, 28.678710528782435, 26.237888268062047, 19.39790960720607, 21.64630671909877, 15.684604678835187, 20.334559781210764, 23.076499598366873, 32.52139438901629, 37.93779311861311, 35.723075662340435, 36.53587940761021, 35.98212882450649, 36.362921374184744, 34.058322020939414, 35.712632519858225, 34.91706725529262, 35.05501331601824, 34.99530744552612, 34.419767311641145, 33.31514964784895, 23.096527780805314, 25.661767959594727, 10.694530044283185, 11.409662961959839, 15.89946903501238, 14.832593985966273, 14.141249963215419, 15.882583175386701, 13.627343824931554, 15.237270968300955, 23.648310286658152, 30.580745152064733, 38.03128807885306, 39.79369865145002, 42.5405022076198, 44.26653896059309, 47.23726558685303, 47.30100836072649, 47.333817754473, 46.32630811418806, 49.43304225376674, 48.92618158885411, 53.33811051504952, 48.31892640250069, 47.463200160435264, 46.16547816140311, 48.07965128762381, 47.331865310668945, 48.58488607406616, 51.04658072335379, 53.876154695238384, 53.52586473737444, 54.65170914786202, 53.86366878237043, 56.922620160239084, 74.35568169185093, 54.722671100071494, 51.23879221507481, 50.033168588365825, 43.07176842008318, 44.70612021854946, 48.03851100376674, 55.946394784109934, 53.16700765064785, 55.00492082323347, 50.95653554371425, 55.38171468462263, 52.04922662462507, 60.46136202130999, 53.147299085344585, 59.51278700147356, 51.6218637738909, 61.91600908551897, 27.339457409722463, 0.2349658203976495, 0.13479478125061306, 33.898294585091726, 57.32678297587803, 55.606825896671836, 53.078654357365195, 32.77858195986067, 13.309947507722036, 6.546669576849256, 14.435911774635315, 26.809983832495554, 57.33165366309029, 46.05390746252877, 44.40780973434448, 34.84990249361311, 31.967994689941406, 37.41481958116804, 54.17025804519653, 65.14098766871861, 5.977220841816493, 0.7908112853765488, 0.14504546406013624, 0.16946189531258174, 0.059434558264911175, 0.15002819097467832, 0.038777509571186135, 0.27368202432990074, 0.11366841702588967, 0.19704678654670715, 0.1826439443975687, 0.2845505268446037, 0.2714922832591193, 0.380295319216592, 0.09072600810655526, 0.156074711520757, 0.3669875104512487, 0.43368989122765406, 33.95402956008911, 86.6214964730399, 59.16837174551827, 49.0723751613072, 18.806746448789323, 57.506699630192344, 18.138701472963604, 22.47373468535287, 33.42475400652204, 16.970441784177506, 9.95619969708579, 31.855145522526332, 50.11870091302054, 54.2347685950143, 62.517570223127095, 69.67142159598214, 32.73794194630214, 0.39991298796875135, 0.2465512901544571, 7.423353757177081, 48.232789584568565, 53.718868323734824, 62.79624162401472, 55.70521933691842, 62.56256675720215, 53.70263385772705, 68.41638238089425, 61.747028895786826, 59.90789631434849, 56.199722630637034, 61.193139348711284, 56.73587342670986, 46.503476755959646, 48.82686403819493, 54.027851240975515, 52.078933647700715, 56.81065688814436, 49.5953243800572, 45.079137734004426, 59.61481434958321, 67.34275368281773, 59.26418740408761, 56.088228361947195, 58.075211661202566, 58.34807436806815, 56.94100856781006, 60.79035227639334, 56.36227573667254, 58.22637319564819, 57.451631682259695, 52.169367926461355, 47.491441113608225, 52.88738087245396, 45.339000361306326, 45.69889620372227, 24.727575710841588, 28.23181802885873, 46.19691528592791, 39.423123427799766, 35.295747552599224, 32.643630572727744, 29.36220829827445, 35.253318377903526, 46.05230242865426, 39.600722857883994, 37.61435447420393, 34.32969086510794, 26.572808810642787, 29.073128495897564, 24.014770439692906, 31.58749396460397, 29.20900399344308, 35.16782774244036, 40.48285225459507, 37.06370278767177, 38.91188539777483, 38.321528230394634, 40.64145878383091, 35.821510791778564, 34.591432980128694, 36.1592001914978, 36.853363445826936, 35.4766195842198, 36.92013910838536, 38.89059264319283, 31.263273647853307, 33.65578508377075, 16.412845373153687, 20.375071253095353, 24.5593216078622, 20.62441951887948, 20.381644248962402, 21.8480407169887, 20.34265443256923, 25.96091570172991, 33.00140721457345, 40.33151354108538, 44.57220411300659, 43.146951402936665, 47.5026033946446, 50.36805091585432, 52.51622894832066, 49.401966435568674, 50.2615385055542, 50.183767318725586, 53.548422064099995, 54.21642187663487, 55.44408866337368, 52.980323450905935, 48.512822832380024, 51.35689074652535, 50.57355431147984, 48.86126456941877, 53.27273144040789, 54.380771092006135, 57.51960243497576, 57.7619104385376, 56.53135667528425, 59.16661385127476, 54.46696696962629, 79.13914816720145, 77.58241816929409, 53.17802401951381, 53.65984337670462, 45.059251989637104, 49.45854909079415, 51.88285895756313, 58.651335443769185, 56.15757833208357, 57.75828695297241, 52.32458373478481, 59.03778730119978, 54.10707112721035, 64.31823062896729, 55.70163059234619, 61.75886862618582, 53.37100676127842, 62.92917455945696, 43.44573089054653, 0.8229634229625974, 0.1333401378776346, 30.976319994245255, 64.13595853533063, 60.44565909249442, 58.3982264654977, 34.24470397404262, 15.666237115859985, 12.440866827964783, 22.08684856551034, 33.4794328553336, 73.64103862217495, 59.60703236716134, 49.68471990312849, 42.40079477855137, 52.84295409066336, 58.17604044505528, 59.01280157906668, 78.18197822570801, 10.421694261687142, 1.2322474952254976, 0.6140131780079433, 0.32188694338713375, 0.0794973052772028, 0.3611183725297451, 0.21386643472526753], [0.1243161242455244, 0.05655663001484104, 0.1074953293427825, 0.018038627857874547, 0.06688899826258421, 0.04060992731579712, 0.11116986788277115, 0.11340731675071375, 0.16247968854648726, 0.04216160119644233, 0.4596719741821289, 13.992409127099172, 67.42550672803605, 42.58728790283203, 41.430899211338584, 29.114392110279628, 38.35661315917969, 33.69551835741316, 11.935817037309919, 22.218046188354492, 10.99990337235587, 1.74464022900377, 14.498188478606087, 54.674120562417166, 55.50558369500296, 48.41738585063389, 56.1660064969744, 47.42761843545096, 3.4740124429975237, 0.07316626142710447, 0.1128688652866653, 16.901439223970684, 51.851109164101736, 52.69744838987078, 53.362672397068565, 52.22850751876831, 55.66406168256487, 53.95412390572684, 54.64591782433646, 51.80751616614205, 54.935886996132986, 52.90297263009207, 47.73871013096401, 42.400676659175325, 47.28507266725813, 48.00579193660191, 58.51000908442906, 57.04903221130371, 54.70780890328543, 51.121694224221365, 38.45841121673584, 30.49654688153948, 53.92197459084647, 69.29701096670968, 51.23245198386056, 46.44084916796003, 53.538190841674805, 53.455698353903635, 53.823977197919575, 55.41879027230399, 51.4513897214617, 46.28454944065639, 37.971610001155305, 40.02217973981585, 41.477017879486084, 39.60024690628052, 34.64770644051688, 28.522773844855173, 27.492752041135514, 25.602065563201904, 16.052874837602886, 12.983421257564, 19.019498552594865, 25.04769832747323, 19.402158430644445, 13.709957037653242, 12.538174612181527, 19.460214103971207, 22.163721697671072, 12.051981363977704, 20.640650510787964, 20.008176837648662, 20.300998244966777, 29.31654473713466, 28.03903157370431, 34.29407787322998, 34.885452951703755, 34.99911158425467, 37.967785017830984, 36.150994368961875, 38.1991947719029, 37.82633359091622, 36.958194392068044, 34.40168809890747, 27.947096484048025, 25.10721833365304, 20.36845656803676, 12.39249346937452, 9.139606578009468, 12.955824749810354, 10.16346880367824, 7.461817247526986, 4.664735223565783, 7.042218574455806, 9.444886105401174, 8.865198765482221, 11.985502736909048, 14.407900980540685, 28.3983941418784, 33.38156400408064, 35.39496088027954, 40.43100479670933, 40.567019258226665, 40.01677056721279, 43.22072042737688, 44.51844937460763, 47.3880032811846, 43.73203836168562, 52.95618888310024, 47.784856591905864, 47.0160036768232, 50.1198855808803, 49.55858925410679, 47.6700792993818, 47.362545081547324, 48.85415308816092, 50.33820840290615, 49.3244697025844, 47.02818039485386, 46.99927936281477, 64.27535329546247, 35.365010670253206, 39.32508781978062, 54.304802962711875, 50.27619573048183, 48.54233530589512, 40.21218170438494, 45.72944048472813, 50.50857128415789, 52.95650502613613, 53.559163979121614, 53.278998715536936, 53.38689381735665, 53.109285490853445, 51.73070730481829, 53.29814795085362, 53.871422971997944, 58.915165492466514, 40.7683676310948, 1.2828085592814853, 0.38865696053419796, 1.354305739913668, 27.66281267574855, 47.25191586358206, 50.76432752609253, 50.668727261679514, 47.23040771484375, 21.416034732546123, 5.536645991461618, 16.26425119808742, 21.86182768004281, 40.66939401626587, 26.67084789276123, 37.4209965297154, 27.908961296081543, 37.96518986565726, 37.42236532483782, 47.15983486175537, 52.33522490092686, 3.7071918163980757, 0.39441536154065815, 0.1266299965126174, 0.19146188694451535, 0.09945227378713233, 0.24021822427000317, 0.10525887113596712, 0.19657147276614392, 0.03189621453306504, 0.06300338783434459, 0.03248405995379601, 0.02600162137033684, 0.0883398854306766, 0.1706245243549347, 0.035659698835973225, 0.10569249572498457, 0.07556255534291267, 0.2901332144226347, 14.827014582497732, 78.02819374629429, 48.53123208454677, 46.68903534752982, 33.775103024074006, 47.01942219052996, 36.79249722617013, 17.369895458221436, 24.27102174077715, 15.288392339433942, 4.886443555355072, 16.664059230259486, 59.97803837912423, 57.46864434650966, 54.39191600254604, 60.649053709847585, 56.12710353306362, 5.0124543479510715, 0.04801751786310758, 0.1517013633357627, 13.38273857321058, 55.37086507252285, 57.23668915884835, 58.72752244131905, 55.10288347516741, 57.93267631530762, 56.44221476146153, 56.025673730032786, 55.06190994807652, 60.740422521318706, 56.26085288184029, 50.861411230904714, 46.17245762688773, 50.76845128195626, 48.891544818878174, 64.30027648380825, 57.91917249134609, 58.27623694283621, 52.41719279970442, 44.55525050844465, 34.71072660173689, 59.94249139513288, 79.31503486633301, 57.447344643729075, 48.40877703257969, 53.96204832621983, 55.6333714893886, 57.356378827776226, 55.42741298675537, 51.022762298583984, 47.48659821919033, 42.046016284397666, 40.3345742225647, 43.27454464776175, 42.22489070892334, 37.56330953325544, 41.00243854522705, 33.876313958849224, 28.65421986579895, 23.12906445775713, 17.463001319340297, 21.296657732554845, 35.19790996823992, 30.831620284489222, 17.225815875189646, 20.808003085000173, 25.903190067836217, 21.469410794121877, 18.596667664391653, 25.77908829280308, 21.408780813217163, 20.97223765509469, 31.381521565573557, 34.07243728637695, 35.8712876864842, 38.45631980895996, 32.41467353275844, 34.53629207611084, 37.2276976449149, 37.40882675988333, 33.133985791887554, 35.68034771510533, 35.96658917835781, 31.827644552503312, 25.58256196975708, 17.713016612189158, 14.498088598251343, 9.68193084853036, 12.112748571804591, 13.772886003766741, 9.126488379069738, 4.4324678012302945, 9.094934872218541, 11.193096297127859, 14.646566390991211, 16.37516529219491, 25.666089739118302, 32.99356617246355, 41.98516396113804, 39.437245641435894, 43.264490604400635, 42.10361337661743, 43.788992745535715, 43.56912047522408, 45.083904198237825, 45.78235796519688, 44.71717132840838, 50.78837871551514, 49.879630770002095, 45.59458637237549, 50.40135015760149, 49.02893154961722, 47.55019508089338, 51.501892702920095, 53.276125635419575, 51.97161872046334, 51.48002324785505, 50.82077816554478, 51.19081142970494, 60.87331376756941, 39.628859588078086, 44.51622247695923, 56.536091872623985, 50.10236917223249, 47.52869388035366, 41.2940787587847, 46.9961005619594, 52.7041186605181, 53.53911147798811, 52.99321583339146, 53.789246627262656, 54.6119168145316, 56.36544411523001, 56.62483079092843, 60.44583279745919, 57.32789121355329, 61.473721504211426, 34.690205097198486, 0.5114576582397733, 0.27176301873156, 2.624176102025168, 37.392331736428396, 53.06223576409476, 58.77335275922503, 56.31046996797834, 54.66999333245413, 23.384181465421403, 6.59387867791312, 18.211087805884226, 25.1094000680106, 40.08971275602068, 31.103430339268275, 41.822246074676514, 35.65848520823887, 34.85108021327427, 41.76543065479824, 56.238312925611226, 61.146377972194124, 3.892574097429003, 0.8925877926605088, 0.11204663012176752, 0.2079007819827114, 0.07130287534424237, 0.2539087267858641, 0.0159687771395381, 0.2866092292325837, 0.18147592778716767, 0.182312955015472, 0.125412663977061, 0.16665133541183813, 0.1659351416996547, 0.3010706289538315, 0.16635326854884624, 0.3607762280319418, 0.22092108188995294, 0.49414546149117605, 20.63349907738822, 88.85689871651786, 52.344205447605674, 56.62929500852312, 39.05638360977173, 52.59526123319353, 47.33226830618722, 14.238462209701538, 30.575186593191965, 16.26963084084647, 7.959572298186166, 22.707574571881974, 63.68055970328194, 63.2320465360369, 60.6724830354963, 65.44660418374198, 57.316353729793, 3.817030676773616, 0.165133249014616, 0.3160071117537362, 23.96621469088963, 63.9586752482823, 59.83881732395717, 63.03187588282994, 57.77186720711844, 59.54410253252302, 56.77700328826904, 57.26454101290022, 55.79887063162667, 63.197923932756694, 57.84033128193447, 51.45059415272304, 48.79004553386143, 51.72399187088013, 50.17795862470354, 58.33155850001744, 56.158683095659526, 59.81479740142822, 50.247694219861714, 46.258722986493794, 47.62235907145909, 62.31236907414028, 61.52586773463658, 58.08320208958217, 55.263167994362966, 59.406757490975515, 60.84593786512102, 64.17544514792306, 58.91772937774658, 57.12883922031948, 51.598517826625276, 46.444281578063965, 44.062908104487825, 47.17965112413679, 44.001906394958496, 46.254331724984304, 49.762810707092285, 39.769345215388704, 32.865531717027935, 30.72743899481637, 23.914410659245082, 26.912678207669938, 43.93154546192714, 35.08535957336426, 20.26417974063328, 24.355510098593577, 32.871937956128804, 27.12418484687805, 24.562797444207327, 31.64897162573678, 31.855503354753765, 27.513011251177105, 36.11020149503435, 35.32326936721802, 40.82417556217739, 41.021348067692344, 37.10616322926113, 40.065473965236116, 43.069868087768555, 43.00789015633719, 37.42374454225813, 38.6363719531468, 36.76127896990095, 33.59419625146048, 32.236361912318635, 26.815200192587717, 25.973278284072876, 18.61500917162214, 17.183174780436925, 16.77660267693656, 10.561359133039202, 3.918343663215637, 10.654693416186742, 16.616613456181117, 20.464173214776174, 26.67256930896214, 35.92269045966012, 44.024397713797434, 47.29811443601336, 45.37165689468384, 48.70513507298061, 46.23698207310268, 47.14549030576433, 48.74847098759243, 48.29588965007237, 49.30468818119594, 49.934785570417134, 55.95743547167097, 54.31478752408709, 52.40781273160662, 53.912181104932515, 51.533850942339214, 51.041223662240164, 53.65997886657715, 55.22307341439383, 54.93659918648856, 52.60718086787632, 54.63316093172346, 48.62649188722883, 61.256486075265066, 56.220192023685996, 47.630186217171804, 58.90353420802525, 53.528845514569966, 50.38675199236189, 45.85208313805716, 48.98141629355294, 55.36008841650826, 55.81865215301514, 56.08807897567749, 54.209567478724885, 57.3928290775844, 55.679698603493826, 59.89138044629778, 60.933526856558665, 60.97022724151611, 61.09811578478132, 48.487576552799766, 1.832719828401293, 0.5231436597449439, 1.8797632583550044, 40.91622877120972, 60.42275782993862, 63.21771935054234, 59.92568370274135, 57.66024439675467, 26.611598866326467, 12.14558836391994, 22.732848644256592, 30.709853104182653, 47.704646587371826, 37.678399494716096, 47.086253438677105, 40.055364336286274, 49.509215354919434, 56.51308291299002, 60.68901974814278, 78.3231725692749, 7.211659950869424, 1.1714836529323032, 0.3114476821252278, 0.32475627799119267, 0.1404262012136834, 0.2868604228964874, 0.1827825962432793], [0.05184659275359341, 0.18172621221414634, 0.04059253307059407, 0.06502475722559861, 0.12300222260611397, 0.02548004167952708, 0.09002252335527114, 0.12082417947905404, 0.1911721932036536, 0.09559300408831664, 0.2740165963768959, 10.627561569213867, 64.7624567576817, 49.1982695715768, 39.83847631726946, 32.20937858309065, 43.280183110918315, 32.531931332179475, 29.30036585671561, 33.245806625911165, 24.35635256767273, 1.809279971889087, 12.913765566689626, 47.31258405957903, 52.76265375954764, 52.341214248112266, 44.79889256613595, 44.99442182268415, 19.487890516008648, 0.08462040073105268, 0.035135343936937194, 1.880461118050984, 38.40322862352644, 50.297370365687776, 49.730053424835205, 51.41938631875174, 54.05277790342058, 55.07399633952549, 53.62694713047573, 51.36307116917202, 54.4316006387983, 50.621350969587056, 45.00587592806135, 39.158501284463064, 48.45097344262259, 50.67881604603359, 56.74861989702497, 68.20549760546002, 52.86400713239397, 47.05648388181414, 52.820963042122976, 41.360500063214985, 26.672954933983938, 43.48098952429635, 68.70213399614606, 54.57088770185198, 48.73135757446289, 49.633265018463135, 47.992590359279085, 41.38774742398943, 45.34656694957188, 38.85968705586025, 42.64813675199236, 41.502788748059956, 43.59418610164097, 31.269982133592876, 52.86451782499041, 61.44257272992815, 23.931465012686594, 22.544180733816965, 11.763161250523158, 15.61779601233346, 19.795905896595546, 22.29880336352757, 10.210350905145917, 4.152776752199445, 3.737128130027226, 11.428098269871303, 21.451897859573364, 15.153117861066546, 10.608999456678118, 22.132539919444493, 24.617061138153076, 26.451418570109777, 34.92631878171648, 35.30835158484322, 34.57578911100115, 33.851703439440044, 29.093160152435303, 21.47287620816912, 25.494137457438878, 33.81947422027588, 33.3306302343096, 33.51460116250174, 27.71432488305228, 23.296637637274607, 18.315751995359147, 15.164450372968401, 10.9349924325943, 10.390090380396162, 8.982165609087263, 2.3211126157215665, 0.883555894451482, 1.2265416128294808, 5.4567564725875854, 7.964751311710902, 7.920086554118565, 6.866007915564945, 14.261455535888672, 28.362744671957834, 28.513108900615148, 32.75079958779471, 34.83391121455601, 40.30327953611101, 39.95347942624773, 42.632996627262656, 39.81088849476406, 41.39597061702183, 36.081946645464214, 32.54266977310181, 48.15070356641497, 48.225150040217805, 48.351384912218364, 49.35747364589146, 47.05711269378662, 50.089619227818076, 46.983506952013286, 46.532228401729036, 41.288165841783794, 53.8234977722168, 35.23760502679007, 32.004979951041086, 45.94733599254063, 50.186828000204905, 52.310711656297954, 46.47839723314558, 41.69623007093157, 39.54251085008894, 47.09783261162894, 49.66396215983799, 48.415099893297466, 54.77471310751778, 53.1671952520098, 54.12531362261091, 52.69210869925362, 54.56501647404262, 52.01527772630964, 54.94935260500227, 3.5891030558518002, 0.13824054492371424, 0.14011256875736372, 7.142772035939353, 54.255905015128, 49.38830975123814, 57.812774726322715, 50.695516041346956, 54.66636637278965, 17.86563205718994, 3.466388532093593, 17.011384044374736, 24.68281888961792, 51.267012323652, 40.556968688964844, 36.587789399283274, 29.974931716918945, 30.164850303104945, 38.291258403233115, 57.06463091714041, 50.307532106127056, 2.3156263615403856, 0.2558220326900482, 0.118898103545819, 0.1375107533697571, 0.03875875486327069, 0.11697064340114594, 0.04867725746173944, 0.07556377670594625, 0.11572634588394846, 0.09821703471243382, 0.03191482335595148, 0.08055939578584262, 0.0508723080690418, 0.08924954304737703, 0.13426016350942, 0.197515247123582, 0.16469943443579332, 0.1762729619762727, 13.248205815042768, 75.66726534707206, 56.06855453763689, 40.20646333694458, 28.07625307355608, 48.049642017909456, 38.372569697243826, 18.22418863432748, 24.473151785986765, 26.99885150364467, 5.851444985185351, 14.677084616252355, 57.00700603212629, 58.69031483786446, 56.81655938284737, 49.46371507644653, 49.92016656058175, 24.839224576950073, 0.05921166629663535, 0.03610946238040924, 1.0504490733146667, 38.424173968178884, 53.29830081122262, 52.87895270756313, 56.27933161599295, 56.779191970825195, 58.31811373574393, 55.61812366758074, 53.27053580965315, 59.29762213570731, 56.71876001358032, 50.09731783185686, 42.37716048104422, 50.30127872739519, 51.955794198172434, 59.41005788530622, 73.11105782645089, 53.1608932358878, 48.62686014175415, 54.567840916769846, 46.130928243909565, 29.36830186843872, 48.632505553109304, 77.97679097311837, 62.413347244262695, 51.22559758595058, 53.98964309692383, 52.22991452898298, 46.35205813816616, 45.91211557388306, 42.3496629851205, 42.09995515005929, 44.00469957079206, 42.37897743497576, 36.36380726950509, 45.87870863505772, 71.7809224809919, 29.691382680620464, 27.671117510114396, 18.46216791016715, 18.58234395299639, 28.81455475943429, 28.036144597189768, 11.832014424460274, 5.142041725771768, 5.969989938395364, 15.760687453406197, 24.93483178956168, 16.348590169634136, 20.14802496773856, 23.013251883643015, 26.32955585207258, 30.272981643676758, 32.3848796572004, 31.859046936035156, 32.874501841408865, 32.37287317003523, 36.53117895126343, 36.83667387281145, 38.578990255083355, 38.83875560760498, 34.64279406411307, 35.142553670065745, 30.000678266797745, 26.030955280576432, 18.35228909764971, 13.975655283246722, 10.777939694268362, 9.62992879322597, 9.821211831910269, 2.501977264881134, 1.1670136813606535, 3.9445322922297885, 7.779083286012922, 10.044813547815595, 10.73999297618866, 13.101471151624407, 24.408627339771815, 31.181072984422954, 35.44780193056379, 37.18582780020577, 37.157937731061665, 41.34546416146414, 42.27190222058977, 41.05185413360596, 40.42707559040615, 41.854985986437114, 37.802765301295686, 30.40275662285941, 51.45635768345424, 48.71188177381243, 49.47320631572178, 50.47966677801949, 49.723793097904746, 51.572896344321116, 51.21887867791312, 47.861974648066926, 43.461600576128276, 54.297437872205464, 38.17039796284267, 38.22561877114432, 47.83394908905029, 53.20601136343819, 54.2014867237636, 47.072103432246614, 43.85644585745675, 41.835461548396516, 50.27661262239729, 51.504942962101524, 53.11487879071917, 56.78456292833601, 58.484995569501606, 56.84883723940168, 57.434869153159006, 58.10714905602591, 58.029134682246614, 55.072787352970664, 2.3180534541606903, 0.07697123475372791, 0.06597820070705243, 9.995565584727697, 61.22864464351109, 52.355920110430034, 64.67854336329869, 53.51875673021589, 64.54983493259975, 17.57573757852827, 6.53504524060658, 20.122978448867798, 27.181636026927404, 48.30969572067261, 41.78512532370431, 42.834153924669536, 38.058924538748606, 31.838702610560826, 45.07733815056937, 65.11758613586426, 56.084163665771484, 1.4686566953148161, 0.19831671911690915, 0.12472023256123066, 0.06289467295365674, 0.07890919183513947, 0.11366857308894396, 0.05969233371849571, 0.24833230887140545, 0.2847979207124029, 0.09799421738301005, 0.13983161454754217, 0.23170811949031694, 0.22967509286744253, 0.331960067152977, 0.31734922687922207, 0.5026582532695362, 0.3261868198003088, 0.40634121160422054, 15.530059371675764, 87.34341430664062, 63.50232451302664, 52.49534613745553, 41.81253596714565, 58.10353946685791, 48.836209365299766, 37.331086839948384, 43.37460912976946, 30.209551538739884, 8.03430712223053, 20.520960841860088, 60.14212008884975, 62.458468845912385, 61.73643984113421, 54.024318081992014, 55.102424894060405, 25.711228711264475, 0.19612955647919858, 0.09894318931869098, 3.7135507208960394, 49.63256325040545, 56.34652417046683, 59.960549763270784, 58.5258857182094, 60.32894325256348, 56.56350251606533, 56.69220747266497, 53.47551114218575, 59.971493176051546, 57.09532458441598, 51.58703940255301, 43.22339200973511, 51.17284338814871, 52.767913545881, 65.7082108088902, 65.98356791904995, 50.69351148605347, 53.50673982075283, 57.63526562282017, 45.10247325897217, 38.24321160997663, 55.3957257270813, 59.384161949157715, 52.653421129499165, 57.27716588973999, 56.60066148212978, 52.92250749043056, 51.96113736288888, 52.7854334286281, 46.89392382758004, 46.62580674035208, 44.05279500143868, 46.76148074013846, 40.06820808138166, 49.46179389953613, 74.33393383026123, 36.28093957901001, 35.21561745234898, 27.844349997384207, 26.22534155845642, 36.179645265851704, 39.71003886631557, 15.702901022774832, 6.994898736476898, 7.306073376110621, 19.28737245287214, 29.491802624293737, 23.942321572984966, 26.811906746455602, 31.193277495247976, 33.75561332702637, 34.79370198931013, 37.571181842258994, 36.52356719970703, 38.99754279000418, 40.46752105440412, 42.20755842753819, 39.473775795527864, 43.785511698041645, 45.047460896628245, 38.0980498450143, 37.73730979646955, 33.22461462020874, 33.17735644749233, 26.564276422773087, 23.729176895959036, 16.68047956057957, 12.452287929398672, 11.339921287127904, 2.1911100830350603, 0.994550381387983, 3.1165851652622223, 8.811135700770787, 15.827787944248744, 17.240506104060582, 21.720527376447404, 34.799604484013145, 38.93485614231655, 37.638242380959646, 40.85148893083845, 39.72582169941494, 44.84219026565552, 45.36134576797485, 45.274472440992085, 43.81081356321062, 44.551995277404785, 45.37361281258719, 39.0467985698155, 53.74842248644148, 54.04395369121006, 52.918908323560444, 52.59133202689034, 52.75057431629726, 54.056679316929404, 53.79710156576974, 51.13890838623047, 45.000835009983604, 52.268171310424805, 43.645793846675325, 37.460076672690256, 45.75427334649222, 52.01496505737305, 54.50464705058506, 49.245614596775596, 44.57612637111119, 42.89954342160906, 51.76615701402937, 55.852514198848176, 52.3519526890346, 59.49218559265137, 59.37919398716518, 58.241089480263845, 56.236725262233186, 61.07863998413086, 55.52657420294625, 60.498027665274485, 5.761209164346967, 0.23748513949768885, 0.40424681827425957, 9.030579788344246, 69.2942316872733, 58.10726717540196, 71.12389387403215, 59.28783212389265, 66.3205486025129, 25.965030772345408, 9.653488397598267, 22.805207184382848, 38.536356108529226, 57.12181806564331, 54.6049929346357, 48.43263367244175, 45.45145695550101, 40.64666645867484, 56.03253855024065, 72.67389106750488, 73.10356766836983, 4.927976846694946, 0.5290979402405875, 0.21130653923111303, 0.2239540655698095, 0.14807019675416605, 0.30995585503322737, 0.16062021761068276], [0.06642335360603673, 0.0075426334348906365, 0.08037650345691613, 0.042094266773866754, 0.11686180638415472, 0.19707882697028772, 0.1348512896469661, 0.0931396521627903, 0.05599835854289787, 0.06956027528004986, 0.09616057827536549, 4.608702344553811, 63.82267120906285, 36.93007155827114, 52.97182927812849, 41.01587636130196, 43.25732353755406, 33.06626864842006, 59.098959241594585, 99.06394141060966, 29.61299310411726, 11.3522595507758, 1.4037739826100213, 38.827798298427034, 57.57663324901036, 51.10662358147757, 52.56977524076189, 48.90524319240025, 34.59966312135969, 0.19356146428201879, 0.040211518694247515, 0.0640334514901042, 18.192503111703054, 53.44520309993199, 46.08948571341378, 52.2279759815761, 50.26658637183053, 55.47178418295724, 54.61714880807059, 57.49571452822004, 54.72355352129255, 52.39309992109026, 40.41213001523699, 43.82048545564924, 44.81340735299246, 53.70024715151106, 44.99225745882307, 46.27992194039481, 64.54302569798061, 58.37544332231794, 49.202198777879985, 47.80348471232823, 46.05009290150234, 28.630135672433035, 34.28959975923811, 63.94163826533726, 63.053637640816824, 48.72175516401018, 48.58880833217076, 47.034510203770225, 41.8607634135655, 39.53528124945504, 38.71101992470877, 38.630417346954346, 37.70039054325649, 33.259220123291016, 32.498875277382986, 37.39053562709263, 22.99347731045314, 12.88206354209355, 15.805743047169276, 19.19134487424578, 19.85403105190822, 10.763588190078735, 2.980677966560636, 0.5982043434466634, 0.9019992905003684, 5.752875234399523, 18.211965015956334, 18.048307146344865, 9.557556356702532, 20.826441867010935, 24.9583740234375, 30.722526618412562, 37.45255524771554, 34.09008571079799, 28.920592955180577, 24.18970697266715, 14.244645237922668, 6.63787727696555, 10.27307403087616, 21.99138900211879, 27.434967347553798, 31.715750762394496, 28.97499735014779, 27.10792432512556, 21.849541527884348, 9.721029230526515, 8.626672319003514, 7.877238750457764, 5.651475395475115, 0.690528423658439, 0.542848208120891, 0.7573167883924076, 2.0881317002432684, 4.531413623264857, 5.77613867180688, 6.226552605628967, 7.234925125326429, 17.077919994081768, 26.271269151142665, 29.00363608769008, 33.94270052228655, 34.89336347579956, 40.098102705819265, 39.10558727809361, 38.118950026375906, 41.9303218296596, 31.639758314405167, 21.64500740596226, 34.975407804761616, 52.00986507960728, 45.66745907919747, 47.688815116882324, 46.36158064433506, 47.058300835745676, 46.197026457105366, 43.846284117017476, 46.50811120441982, 38.882567473820274, 32.93340866906302, 46.11140380586897, 44.01992654800415, 52.44465555463518, 53.04812397275652, 48.72756385803223, 42.95000123977661, 41.02143144607544, 41.1026246207101, 46.407501288822715, 49.75708539145333, 53.166886057172505, 55.38744000026158, 52.147929259708945, 53.48498501096453, 54.75669642857143, 64.5996743610927, 26.0391298362187, 0.17908217837767942, 0.19000379661364214, 0.19683908697749886, 20.28531094959804, 48.87386165346418, 50.785255500248496, 56.104212692805696, 53.280103479112896, 57.62988771711077, 8.201534628868103, 6.888152692999158, 24.049280405044556, 24.226832934788295, 38.577079500470845, 37.01507581983294, 32.797703402382986, 27.182356902531215, 21.730541467666626, 44.01900938579014, 55.62474530083792, 39.84530987058367, 0.5330762181963239, 0.07025727323655571, 0.02349855488033167, 0.1021566293867571, 0.11522538347968034, 0.024276939719649296, 0.05272845757593002, 0.035602942774338384, 0.04977398718308125, 0.05692245199212006, 0.1337305669273649, 0.049838071422917504, 0.04661672642188413, 0.032692661974579096, 0.013888493097121162, 0.11032133948590074, 0.0596653280247535, 0.04712327656203082, 5.157406798430851, 74.88513442448208, 43.87903445107596, 50.33738504137312, 36.771940980638774, 52.682019914899556, 37.095723560878206, 54.44922821862357, 96.31701973506382, 31.04770926066807, 13.383865918431963, 3.560606973511832, 37.11124236243111, 68.18003245762416, 55.05953713825771, 59.730863162449424, 49.773066248212544, 40.813367639269146, 0.2966556187186922, 0.011325254969831024, 0.13318343700042792, 18.586122035980225, 57.10155711855207, 51.26776967729841, 58.16063976287842, 54.99377243859427, 57.98017072677612, 57.961744104112896, 59.45983478001186, 56.53396224975586, 55.33682237352644, 44.24066039494106, 47.971085684640066, 46.17397233418056, 53.202103001730784, 45.789094243730815, 50.6811888558524, 69.93673855917794, 57.61790902273995, 50.985297611781526, 49.74610028948103, 48.50305019106184, 32.15195172173636, 37.33713524682181, 72.3001822062901, 67.1782967703683, 47.18336493628365, 52.20028741019112, 48.86362000874111, 42.80130284173148, 43.70112235205514, 40.835852009909495, 40.807305335998535, 38.60069990158081, 37.60270929336548, 36.283996786390034, 41.42130722318377, 29.080398048673356, 23.200163636888774, 16.510271276746476, 25.83353090286255, 30.87786054611206, 17.798498562404088, 4.046402871608734, 2.703701926129205, 1.4206308552197047, 10.249220865113394, 20.306520325796946, 17.569499833243235, 14.916762726647512, 26.650771072932653, 30.804657799857004, 31.93105459213257, 34.70768676485334, 39.12517077582223, 36.23643636703491, 30.09744930267334, 27.856509344918386, 17.76970522744315, 22.086746079581125, 33.75954600742885, 36.411002908434185, 32.69773619515555, 28.9205356325422, 27.17295946393694, 22.981927667345317, 16.220055443899973, 10.173614042145864, 9.712500316756111, 7.875063095773969, 0.7130910700985363, 1.0846984812191554, 0.9021337489996637, 3.742458701133728, 5.986547929900033, 12.912504468645368, 11.280579328536987, 15.690279620034353, 25.57836525780814, 31.39051948274885, 33.748074531555176, 36.348361424037385, 36.834506034851074, 40.38397938864571, 40.320611817496165, 37.66797719682966, 40.38977418627058, 32.985756397247314, 22.18113214629037, 32.8893084526062, 52.71976947784424, 49.071239130837576, 49.97939647947039, 47.688523292541504, 47.64054945537022, 48.21577344621931, 44.503972802843364, 48.21271971293858, 42.07803705760411, 34.97507776532854, 47.80177198137556, 44.88955613545009, 55.00072758538382, 55.36410100119454, 52.42660413469587, 45.42199311937605, 42.58129160744803, 44.68547364643642, 50.10585021972656, 53.43457235608782, 56.15529237474714, 58.56369086674282, 56.85473278590611, 55.97889845711844, 56.93314668110439, 66.05466188703264, 27.79975472177778, 0.13716798461973667, 0.16106301599315234, 0.06664876293923173, 25.723141397748673, 50.974347250802175, 54.65177515574864, 59.56164673396519, 60.96031216212681, 63.55554076603481, 7.480138778686523, 13.164468731198992, 26.198563201086863, 24.10370217050825, 32.656967639923096, 34.21912418093, 39.16926751817976, 35.246391023908345, 23.162933451788767, 49.462346281324116, 62.932127543858115, 44.33059787750244, 0.9017114830868584, 0.060768632750426016, 0.08463673306895153, 0.10014965172324862, 0.10515408497303724, 0.028785073797085454, 0.070343481110675, 0.14136430301836558, 0.1282228846102953, 0.23894816956349782, 0.17573336378804275, 0.25523292858685764, 0.22454397034432205, 0.13973845168948174, 0.14789689891040325, 0.20199049769767694, 0.2225355745426246, 0.11491652790989194, 7.459949919155665, 91.08958421434674, 48.759223324911936, 67.72532149723598, 55.71479742867606, 62.271194049290244, 46.823809555598665, 67.07271889277867, 107.79246303013393, 38.383169174194336, 18.455952746527537, 7.595608285495213, 48.782864570617676, 70.38354941776821, 59.503552845546174, 61.5090183530535, 58.465158462524414, 42.43542112622942, 0.4457678959837982, 0.11920454353094101, 0.3354289281581129, 28.22662946156093, 63.95250524793352, 54.9946722303118, 64.55846459524972, 57.51205669130598, 61.807464327131, 59.44317994798933, 62.04223700932094, 59.287776538303916, 57.206975187574116, 46.90100404194423, 52.319845063345774, 48.45779309953962, 58.38563632965088, 50.523395265851704, 56.585007190704346, 62.92823655264718, 52.63306985582624, 52.89329726355416, 51.53494528361729, 45.9520503452846, 38.38486800874983, 47.76164266041347, 60.315547125680105, 56.870526041303364, 49.76403359004429, 53.2541241645813, 51.039048876081196, 47.02663442066738, 48.344030244009836, 43.93245220184326, 46.70631899152483, 42.75412457329886, 44.30655711037772, 39.06556218011038, 42.643842765263145, 35.791265283312114, 34.52157231739589, 25.39906004496983, 34.73322834287371, 41.797611236572266, 23.89607957431248, 5.901636600494385, 6.7597925407545905, 2.4348557123116086, 14.086653624262128, 24.845766305923462, 23.328460386821202, 24.270106315612793, 34.24543700899397, 36.69897099903652, 36.03721761703491, 42.49678414208548, 49.17558370317732, 43.2481449672154, 36.88102075031826, 28.370168822152273, 15.188551936830793, 19.585959127971105, 36.180941104888916, 44.634463446480886, 40.92775583267212, 33.706270694732666, 35.18131767000471, 29.296078818184988, 22.727568013327463, 15.572721311024257, 12.242107527596609, 8.814374429838997, 0.5771431592958314, 1.148740896156856, 0.7414806495819772, 3.8315419895308356, 8.698293481554304, 19.509796449116298, 19.477787835257395, 25.52609917095729, 31.24400281906128, 35.95647954940796, 35.45504890169416, 39.60159485680716, 41.26950298036848, 44.29421016148159, 41.16063165664673, 40.169130665915354, 41.544366768428254, 39.98696626935686, 30.442409992218018, 42.17520414079939, 53.68390498842512, 52.76844160897391, 54.44387115750994, 48.80543579374041, 50.36444827488491, 49.50083235331944, 46.06416995184762, 46.39580052239554, 43.256851060049875, 35.02740464891706, 47.76285859516689, 44.26417309897286, 56.38520131792341, 57.126702649252756, 53.648451805114746, 46.90795224053519, 43.94551828929356, 45.62605128969465, 52.94295951298305, 54.70880944388253, 56.93731560025896, 60.25239494868687, 58.94054726191929, 56.570478507450645, 58.077799865177695, 66.92346463884626, 32.17012126105172, 0.5096507466265133, 0.30826426723173683, 0.25889785907098223, 25.788197381155832, 61.730179514203755, 59.312456539699006, 67.71179335457938, 63.2721654347011, 69.52036081041608, 15.088239056723458, 14.998230355126516, 31.98986761910575, 33.374539375305176, 45.07718529020037, 49.06536790302822, 45.46157700674874, 42.77915893282209, 33.325693539210725, 61.64670385633196, 70.10516289302281, 63.9471412386213, 2.195140255349023, 0.2378487799848829, 0.18796979290034088, 0.22797164427382605, 0.25652219940509113, 0.15393470706684248, 0.28713463246822357], [0.14579563880605356, 0.0756675179249474, 0.15107265992888383, 0.23860146531036922, 0.03443235790889178, 0.02876963034006102, 0.1054576343989798, 0.10234530283404247, 0.09699949861637183, 0.020054619859105775, 0.0817352630464094, 1.161713291491781, 56.029033184051514, 47.17784806660244, 40.56028297969273, 28.635308606284006, 34.457377910614014, 39.14636278152466, 18.38063427380153, 36.46593189239502, 20.362901483263286, 13.429037894521441, 7.945717590195792, 16.535936185291835, 48.239737783159526, 52.53019135338919, 52.00206920078823, 55.91737910679409, 44.373006207602366, 2.7606519673551833, 0.03518878196233085, 0.27469963686806814, 4.219795601708548, 49.75229113442557, 45.41928332192557, 51.873249598911826, 53.27809892381941, 57.1720917565482, 57.48167221886771, 58.33656815120152, 54.486084938049316, 44.78976958138602, 42.68746355601719, 43.27310637065342, 46.61801086153303, 51.49055324281965, 50.38381290435791, 40.679243087768555, 40.7180939401899, 61.910978589739116, 58.328119141714915, 55.478405816214426, 49.57209655216762, 50.380780015672954, 29.319247586386545, 27.690694059644425, 63.43220329284668, 77.75164154597691, 50.977175167628694, 43.366792406354634, 45.3377879006522, 49.964388370513916, 41.142277990068706, 40.18179375784737, 35.644939695085796, 34.17544085638863, 26.78867891856602, 21.704570838383265, 18.688166754586355, 15.210219894136701, 25.138004064559937, 20.506116015570505, 15.547045980181013, 6.027762906891959, 1.1345140252794539, 1.8372563506875719, 1.0049071056502206, 8.183827144759041, 16.70741077831813, 18.895631279264176, 13.905016422271729, 21.884412799562725, 30.370940821511404, 35.50625712530953, 34.62972797666277, 25.455870253699167, 19.62469186101641, 17.367074489593506, 6.003898016044071, 1.5834174858672279, 3.2791154725211005, 9.799804432051522, 18.618854999542236, 25.32113426072257, 25.31288848604475, 31.450211456843785, 24.268084389822825, 13.116870965276446, 8.587914398738317, 7.636963094983782, 6.184282370976039, 1.2734690947192056, 0.19325095308678492, 0.3977074777441365, 0.6503965514046806, 1.970217730317797, 5.3463066049984524, 6.163766946111407, 7.888246434075492, 11.948830144745962, 20.975180217197963, 26.422119753701345, 34.65434544427054, 38.451966762542725, 41.090183871132986, 40.155307224818635, 36.74879305703299, 34.04729175567627, 53.640655926295686, 26.733881950378418, 18.144463266645158, 39.96689639772688, 47.930911200387136, 45.62484925133841, 46.004425866263254, 45.59452731268746, 45.35990401676723, 43.5533515385219, 43.811442375183105, 37.2798855645316, 39.20811142240252, 41.982773780822754, 46.21665164402553, 51.05325794219971, 52.20656163351876, 49.968623297555105, 45.35725327900478, 42.74999386923653, 42.63778741019112, 40.17714888708932, 43.06943729945591, 47.45053012030465, 49.54155921936035, 51.12030805860247, 54.346856934683665, 52.51815012523106, 58.29857540130615, 12.942772558757238, 0.14977393033249037, 0.2150038086942264, 0.36793648238692966, 16.938447066715785, 47.49991791588919, 50.14032023293631, 53.57937281472342, 53.325638498578755, 23.986216817583355, 1.5559805695499693, 25.041267769677297, 20.441751377923147, 23.67872950008937, 30.3492693901062, 23.104292392730713, 40.90919719423567, 32.70608098166329, 37.3423741885594, 36.802554743630544, 64.173645564488, 29.144170352390834, 0.25578748168689863, 0.03626624128914305, 0.10681792069226503, 0.07107218700860228, 0.05734059241201196, 0.12501880154013634, 0.1161240895411798, 0.04025016804890973, 0.01503587291309876, 0.06423919687845878, 0.07770076167902776, 0.037801419983484914, 0.0825545737253768, 0.017881809933377162, 0.041434493248483965, 0.03737720328250101, 0.028684966133109162, 0.10380496736615896, 2.477654661451067, 69.00722244807652, 53.40354170118059, 40.1841596194676, 27.0213497706822, 46.61797612054007, 35.2315913609096, 26.83114630835397, 44.69510037558419, 21.878501619611466, 14.71408724784851, 13.160111342157636, 24.37109317098345, 52.50139454432896, 58.0108504976545, 54.011686256953645, 60.63221822466169, 49.081828185490195, 3.6299999356269836, 0.06629105963345085, 0.11722627468407154, 3.9500087755067006, 55.39637885774885, 51.54320321764265, 56.88327945981707, 58.304384095328196, 61.850557054792134, 59.20392567770821, 61.01707894461495, 56.44690826960972, 46.1649466242109, 43.19713824135916, 46.19417074748448, 49.264781202588765, 51.311428683144705, 54.808047090257915, 44.12365273066929, 46.59710373197283, 64.47161906106132, 60.52063710348946, 58.02507693426949, 48.1594409261431, 51.97500249317714, 34.83952535901751, 34.307081426892964, 69.95515823364258, 76.84343555995396, 49.567382199423655, 43.78005388804844, 47.528923170907156, 49.02369955607823, 45.26144109453474, 42.703656332833425, 39.760659967150005, 35.74973937443325, 34.2014479637146, 34.217453139168875, 28.830646787370952, 19.366246666227067, 24.08788459641593, 32.88645969118391, 26.17199328967503, 8.946880051067897, 1.279745272227696, 2.1738399011748175, 1.2129254234688622, 11.197664737701416, 22.375334296907695, 19.477035692759923, 18.85108290399824, 26.812832593917847, 32.25542082105364, 38.40745312826974, 44.441716943468364, 44.3897305216108, 33.49539634159633, 29.77957616533552, 15.935533659798757, 4.0998419012342175, 7.9900349378585815, 17.62208206312997, 29.22300808770316, 34.37254735401699, 31.045676912580216, 32.4734275000436, 25.716724736349924, 18.351100955690654, 8.715007373264857, 11.135727626936776, 10.406986662319728, 1.2545964845589228, 0.8375960034983498, 0.13386623321899346, 1.8939771013600486, 4.035706988402775, 8.919351288250514, 12.412727492196218, 13.443994760513306, 23.271495580673218, 28.679017986570084, 30.580272674560547, 37.364907196589876, 44.147415569850374, 43.72721978596279, 41.73637676239014, 36.45318194798061, 39.25626591273716, 59.3393669128418, 29.37147719519479, 20.19377885546003, 40.75996378489903, 48.26020022800991, 49.59188502175467, 47.22678770337786, 48.07427338191441, 47.626774651663645, 44.15913370677403, 44.70384815761021, 41.25555099759783, 39.408674648829866, 43.44476509094238, 47.53769179752895, 52.16619954790388, 55.09852000645229, 54.007381847926546, 47.58952535901751, 45.06419563293457, 44.5982529095241, 44.23091902051653, 45.68010480063302, 51.158370290483745, 55.398442472730366, 54.99714578901018, 56.63491610118321, 54.08177273614066, 60.6574193409511, 15.682409048080444, 0.1496525811297553, 0.1994135845452547, 1.1036083293812615, 20.22655177116394, 52.21707425798689, 52.97478921072823, 60.225797244480674, 57.242800099509104, 22.916030951908656, 3.529726790530341, 27.720371552876063, 24.405267885753087, 27.67748727117266, 30.956475939069474, 24.797368628638132, 45.86933551515852, 36.62538262775966, 37.175721645355225, 39.16517850330898, 70.98539543151855, 33.68594373975481, 0.29765208810567856, 0.04520886464576636, 0.05919198878109455, 0.045645491752241335, 0.029244041669049432, 0.1149569143142019, 0.12180990087134497, 0.13601457008293696, 0.15889523231557437, 0.21072506186153206, 0.25349536325250355, 0.12609047974858964, 0.13277090127979005, 0.20396005415490695, 0.18651687300630979, 0.1213959130857672, 0.10176027672631399, 0.15737353611205304, 3.427866416318076, 83.2421567099435, 58.35344532557896, 53.486155782427105, 38.809997013636995, 53.00016055788313, 52.461678641183035, 20.001058408192225, 42.848043373652864, 25.724049874714442, 20.260479824883596, 15.63106186049325, 26.649945974349976, 57.16062375477382, 63.33626256670271, 60.98174040658133, 65.2562096459525, 52.820636476789204, 3.5995917958872656, 0.11528574595493929, 0.5778346679040364, 8.325017145701818, 64.0073265348162, 54.57882949284145, 60.43011597224644, 60.481553486415315, 63.9882606778826, 61.658585275922505, 66.40080029623849, 61.90210574013846, 50.379751682281494, 46.83064658301217, 48.32904992784773, 53.24708563940865, 56.45258494785854, 57.98757403237479, 46.34655516488211, 54.08426366533552, 69.18089267185756, 60.26101071493966, 56.55994503838675, 52.75851263318743, 54.77933018548148, 38.68248019899641, 44.152581555502756, 67.80196707589286, 63.824470792497905, 47.30009814671108, 50.55061483383179, 48.94609860011509, 52.79578277042934, 49.23203086853027, 47.897879464285715, 45.14044516427176, 39.73539284297398, 37.61126252583095, 40.035391739436555, 36.061640535082134, 28.81283160618373, 35.58134978158133, 44.79151010513306, 38.521236828395296, 13.316513555390493, 2.638598608119147, 4.501161166599818, 4.6564512337957105, 15.49449154308864, 27.232253653662546, 24.023493903023855, 29.091200760432653, 32.4183942931039, 40.80821207591465, 46.56609044756208, 55.24489770616804, 52.70033884048462, 36.51412112372262, 40.541609695979524, 17.78585284096854, 3.747354575565883, 6.385615110397339, 17.197981391634258, 32.92836080278669, 41.332398074013845, 37.190625531332834, 41.65154273169381, 32.050278731754844, 27.926767792020524, 14.450876457350594, 14.631784098488943, 13.23667962210519, 2.9351648773465837, 0.5752561262675694, 0.46728600561618805, 1.8817204790455955, 5.4339055844715665, 13.418566959244863, 18.595759187425884, 24.27079939842224, 34.73256826400757, 35.669918469020296, 38.4265467779977, 41.23148591177804, 50.16512877600533, 47.04242767606463, 44.97292409624372, 39.745328766959055, 42.80093806130545, 58.79213374001639, 42.59131438391549, 29.000650099345616, 47.37277977807181, 51.153680256434846, 49.83180979319981, 49.87411042622158, 51.837407316480366, 47.94689900534493, 46.469190870012554, 43.73465435845511, 39.11688852310181, 41.501235825674875, 43.42819363730294, 48.93340424128941, 53.532607964106965, 55.27740832737514, 55.39514207839966, 49.63097906112671, 46.484007903507774, 44.37029641015189, 45.15330627986363, 46.47933871405465, 53.51495606558663, 58.008960587637766, 58.8866639818464, 58.40227031707764, 55.31837143216814, 60.25126239231655, 19.15924940790449, 0.6744346043893269, 0.3800939571644579, 1.7783360608986445, 24.763440574918473, 62.058718136378694, 60.07056059156145, 64.54531165531704, 62.95009558541434, 33.31402403967721, 7.4835920333862305, 33.60019254684448, 28.894300971712383, 36.175452028002056, 38.19835751397269, 33.619831630161826, 57.474835191454204, 46.100244998931885, 52.52778727667672, 52.60940081732613, 79.06039033617292, 47.738088267190115, 0.5975565324936594, 0.1094986836292914, 0.28534709981509615, 0.10151692014187574, 0.15629683674446174, 0.188424180660929, 0.2921325314257826], [0.1012772683586393, 0.029201388957777193, 0.07328905590942927, 0.08037376896079097, 0.08838044146874122, 0.029429152807486907, 0.09490441996604204, 0.06910296303353139, 0.08342009263911418, 0.07414682595325367, 0.08060717822185584, 1.0093823969364166, 58.99707085745675, 48.28107956477574, 52.16428879329136, 29.64810582569667, 37.066249302455354, 48.21540519169399, 21.09495152745928, 14.652387244360787, 28.164269379207067, 11.419516376086644, 7.733459677015032, 49.31495067051479, 52.3624792098999, 57.51874433244978, 51.59599563053676, 46.92707020895821, 47.42730229241507, 8.229352610451834, 0.09189082203166825, 0.2986716819661004, 0.25263096392154694, 35.685329573495046, 51.47051811218262, 52.97124562944685, 58.01428638185774, 58.62800339290074, 55.832003116607666, 59.215633392333984, 52.89989110401699, 42.643054144723074, 47.772398471832275, 51.208706515175955, 49.04299817766462, 47.48792879922049, 50.62624944959368, 53.19211844035557, 52.42652770451137, 46.44867978777204, 49.58408914293562, 50.4266311781747, 50.34958955219814, 52.04023565564837, 55.14142165865217, 40.526552949632915, 31.77313593455723, 50.762934412275044, 85.88900348118374, 65.18102318899972, 42.172501291547505, 39.99170841489519, 45.846111161368235, 39.13385949816023, 39.07471643175398, 34.87823377336775, 31.63049636568342, 24.079683985028947, 20.334109885352, 21.044330426624843, 26.775724002293178, 20.607505866459437, 11.83741751738957, 2.2732434357915605, 1.5263108930417468, 1.499323221189635, 3.8737353597368513, 18.722438744136266, 27.46733205659049, 22.783341203417095, 22.579687765666417, 27.61505423273359, 34.054740224565776, 34.476999623434885, 21.558184453419276, 8.691184605870928, 8.351765973227364, 9.87818706035614, 2.915482584919248, 0.4217042757996491, 0.5333812332579068, 2.925541405166898, 6.07023116520473, 12.867221321378436, 21.265990121023997, 29.566478388650076, 28.530373437064036, 25.240067890712194, 17.73418082509722, 16.106445448739187, 12.023028220449175, 5.026755477700915, 0.6110555795686585, 0.6340895635741097, 0.35686754062771797, 0.21215766641710485, 4.219442546367645, 5.910529426165989, 8.083146010126386, 10.91718419960567, 18.247525896344865, 24.90083772795541, 32.3838061605181, 39.962915079934255, 40.656279291425435, 40.605797154562815, 43.39726373127529, 43.62953853607178, 55.45418439592634, 60.617494991847444, 19.27921005657741, 27.793525661740983, 35.75810847963606, 45.06356682096209, 42.388329710279194, 46.63898747307913, 42.33372729165213, 45.65463617869786, 44.90141323634556, 35.5258823122297, 40.987572874341694, 43.99158137185233, 48.58484785897391, 51.2275013923645, 50.48524270738874, 47.8726818220956, 42.51769127164568, 42.75552116121565, 44.42197016307286, 46.916369983128135, 46.292421749659944, 44.42919976370675, 48.654639039720806, 50.51618650981358, 55.00009877341134, 54.500988824026926, 59.28534466879708, 11.11832673209054, 0.15379188901611737, 0.40877397677728106, 0.4669980896370751, 23.00322389602661, 54.8047536441258, 49.41835723604475, 52.23596640995571, 43.65028585706438, 33.602078982761924, 3.6637160692896162, 25.362281492778234, 16.67212782587324, 20.727126053401403, 29.3124418258667, 29.65405695778983, 38.84647853033883, 30.794374465942383, 24.602256264005387, 36.57812098094395, 63.986370767865864, 23.961046968187603, 0.5777428756867136, 0.05609314649232796, 0.031823445044990094, 0.07740337335105453, 0.012127884713533734, 0.019743630296683738, 0.08243903956775155, 0.17062886697905405, 0.024754182236003022, 0.04448192972423775, 0.03933777593608413, 0.05576088824974639, 0.12869574209409101, 0.13704358200941766, 0.04246806153761489, 0.016139340487175753, 0.033241461097661934, 0.13201324907796724, 1.3196697298969542, 66.4373756136213, 53.91569341932024, 51.380545888628276, 29.32420860018049, 48.42331961223057, 41.84840256827218, 23.269115822655813, 23.406516449792043, 30.78249999455043, 19.480487210409983, 6.097654402256012, 56.98098502840315, 60.05214786529541, 62.3048928124564, 54.044082232883994, 53.20021309171404, 53.04847833088466, 10.18279434953417, 0.12635894891406807, 0.7614758823599134, 0.4186150144253458, 39.124475955963135, 57.60561071123396, 58.38364914485386, 57.79566478729248, 61.21054458618164, 58.60694340297154, 60.52320793696812, 53.41313716343471, 45.19652754919869, 48.85858603886196, 53.518673351832796, 50.63017518179757, 50.354970932006836, 52.28086566925049, 55.21013934271676, 55.416028363364084, 51.16410950251988, 52.7064984185355, 54.93276725496565, 52.94457844325474, 51.82889229910714, 53.25167145047869, 43.52828938620431, 36.06660849707467, 56.40636553083147, 84.23039204733712, 61.27027824946812, 47.16357299259731, 46.554205553872244, 48.16211598260062, 45.43707071031843, 38.926559993198936, 38.66144105366298, 36.312275954655235, 34.584925992148264, 30.074662685394287, 23.48595346723284, 34.925703866141184, 36.11947386605399, 19.136073691504343, 3.7547591839517866, 0.7516332162278039, 1.340684773666518, 1.972028170313154, 17.853276423045568, 28.95875767299107, 22.248651266098022, 26.806216171809606, 33.274936948503765, 37.24502297810146, 46.672321455819265, 36.970131397247314, 22.95505724634443, 17.247528995786393, 26.438192674091884, 8.7123236315591, 0.8533282993095261, 1.2242147262607301, 5.598541413034711, 17.527902705328806, 28.74919479233878, 32.37818159375872, 36.84855876650129, 30.321243831089564, 22.89749836921692, 13.992319669042315, 14.933792761393956, 11.693332723208837, 3.386089720896312, 0.3366382675511496, 0.6083398652928216, 0.70089909860066, 2.8128709367343356, 6.7095197183745245, 12.396693655422755, 11.27108027253832, 16.90870530264718, 29.046989372798375, 31.21444170815604, 38.56740065983364, 39.995856489454, 46.04867199489048, 42.478927271706716, 50.88931867054531, 45.159966128213064, 50.08953932353428, 62.366224561418804, 32.88013335636684, 30.32661131450108, 38.17085654394967, 44.76939398901803, 45.235777923039024, 45.7964836529323, 45.431852613176616, 40.293315819331575, 47.83244480405535, 36.937495708465576, 39.68451813289097, 46.37642547062465, 52.55019521713257, 53.858384677342, 51.67271416527884, 48.95718445096697, 45.655397006443565, 43.7093003817967, 47.29483836037772, 50.04455321175711, 46.945208481379915, 47.81217343466622, 50.1196528162275, 54.82499722072056, 56.963145528520855, 56.39110033852713, 61.779331071036204, 11.741967507771083, 0.11587699422878878, 0.43652893602848053, 0.31959802763802664, 28.540609870638164, 58.00158160073416, 55.35263647351946, 56.31654616764614, 46.13171339035034, 36.82355219977242, 4.574514167649405, 30.573605878012522, 23.76469608715602, 25.423637560435704, 30.320913791656494, 33.11284589767456, 41.36808054787772, 34.866922106061665, 24.786527701786586, 43.049047810690745, 70.01088278634208, 23.421878916876658, 0.5431566429989678, 0.07027994309152875, 0.03381444320880941, 0.05393940170428582, 0.07143081312200852, 0.06681005071316447, 0.05491597644452538, 0.34507302780236515, 0.15322014183870383, 0.1655385922640562, 0.15418653855366365, 0.14258700955126966, 0.1231563857623509, 0.2710065064685685, 0.15181906202009746, 0.2258840770061527, 0.21563944672899588, 0.19124231301248074, 1.8454484939575195, 81.43818896157401, 63.14479800633022, 64.79376534053257, 40.71134723935808, 51.947185380118235, 67.31013883863176, 24.495976618358068, 22.072502272469656, 35.43289109638759, 19.613934312547954, 13.166556664875575, 59.598764010838096, 63.22114481244768, 66.3548310143607, 58.41116401127407, 55.49858338492257, 54.80246768678938, 11.155536941119603, 0.1559231946510928, 1.3461989292076655, 1.975849679538182, 50.415837151663645, 62.62801878792899, 60.11664799281529, 61.31671306065151, 66.57838235582624, 61.68787888118199, 64.7504780633109, 60.1293979372297, 49.59708227430071, 51.70969942637852, 56.99112939834595, 55.65048142841884, 52.69295290538243, 55.611345699855256, 59.46999304635184, 60.9789958681379, 58.50631264277867, 58.98630114964077, 58.260818890162874, 54.57060629980904, 53.07728556224278, 56.79331418446132, 43.746612208230154, 47.20880576542446, 65.81961127689907, 72.41819735935756, 51.34888642174857, 51.015421526772634, 48.618032455444336, 51.79452650887625, 50.23383603777204, 44.81381382261004, 45.16530234473092, 45.03045865467617, 39.04689931869507, 38.47793912887573, 32.557896750313894, 43.91178478513445, 49.5980932371957, 27.58188874380929, 4.913094673837934, 3.012234078986304, 3.4754611424037387, 12.49796278136117, 30.25394705363682, 34.59861741747175, 28.39505900655474, 36.995110171181814, 42.00878436224801, 45.5102595601763, 57.23936768940517, 45.87550204140799, 23.062017815453665, 15.664046696254186, 32.06327881131853, 11.45219201701028, 1.214014662163598, 1.4224601856299808, 4.676564965929304, 18.103248289653234, 34.33661821910313, 40.62028067452567, 45.967715059007915, 38.743144920894075, 34.669409138815745, 24.6535131250109, 23.440614734377178, 21.61760197366987, 10.966340099062238, 0.5236602148839405, 1.3927698816571916, 1.3677150032349994, 3.7479469094957625, 10.880818196705409, 19.707648141043528, 19.170295306614467, 32.52524716513497, 36.78730692182268, 38.62108939034598, 43.07933153424944, 45.398202487400596, 48.18751859664917, 47.439253193991526, 51.703418254852295, 48.33117955071585, 46.016630377088276, 64.98140144348145, 43.41505806786673, 37.05120645250593, 42.780506883348735, 47.23526797975813, 47.13846915108817, 49.400851249694824, 48.22593866075788, 44.798781394958496, 44.02759041104998, 40.11762366976057, 39.91172422681536, 46.257152693612234, 52.25646012169974, 58.454895973205566, 53.18027523585728, 52.49342496054513, 47.49819128853934, 47.9254811831883, 47.78631223951067, 50.05395065035139, 47.589782442365376, 51.30736746106829, 53.49783223015921, 59.1835744040353, 60.806597164699006, 58.13543517248971, 63.52305098942348, 14.940247637884957, 0.17882295085915498, 0.7109909227916172, 0.6152360066771507, 31.95591872079032, 67.48991652897426, 60.031761850629536, 61.67355864388602, 51.73234013148716, 43.60916641780308, 9.185254505702428, 35.57139301300049, 24.96696720804487, 29.585363592420304, 41.60954434531075, 41.67064332962036, 55.80381427492414, 44.46793597085135, 36.77757249559675, 52.015305519104004, 81.9595261982509, 39.40043755940029, 0.6666943111589977, 0.13610921214733804, 0.2156132281358753, 0.20040234577442917, 0.21054480224847794, 0.15704996990306036, 0.17852221056818962], [0.07710445831928935, 0.1838765304003443, 0.03417604469827243, 0.014254517786737, 0.1431745665946177, 0.07362668136400835, 0.11998378671705723, 0.11420443254922118, 0.12467464857867785, 0.24995794306908334, 0.09408490572656904, 0.19253072887659073, 45.963504450661794, 52.637409005846294, 41.772434438977925, 28.224060365131923, 25.554748330797466, 47.38071462086269, 31.3649640083313, 30.81959990092686, 27.73937313897269, 33.2090437071664, 1.961398946387427, 15.939188412257604, 61.146072251456125, 51.86583239691598, 56.038149220602854, 50.44042682647705, 51.03532116753714, 11.295265214783804, 0.07766056526452303, 0.6579504374946866, 0.2671931396637644, 16.06281770978655, 55.682964256831575, 50.56229822976248, 57.936584677015034, 56.2590011869158, 57.86307273592268, 55.96579762867519, 47.26314067840576, 43.10971253258841, 53.10880953924996, 55.822386809757774, 54.97617959976196, 48.72732414518084, 47.93113006864275, 50.9433548109872, 54.27735410417829, 56.35349668775286, 54.751047543116975, 55.16953754425049, 54.34648520605904, 52.32906184877668, 46.984740257263184, 48.201894419533865, 42.35509647641863, 27.183223690305436, 35.95365163258144, 71.23728152683803, 77.75244058881486, 48.65914494650704, 46.20924833842686, 40.94526181902204, 41.45974465778896, 38.59204592023577, 36.37398985454014, 24.30715584754944, 22.142223971230642, 28.549244744437082, 23.414088249206543, 17.96349569729396, 8.84664707524436, 0.6927931564194816, 0.6215506164090974, 1.7460721007415225, 8.701678991317749, 26.737927539008005, 38.45389836175101, 31.849194390433176, 41.05324029922485, 33.95271635055542, 31.350438799176896, 20.403339999062673, 6.411904488291059, 1.3717348618166787, 2.1768052620547156, 8.497275148119245, 2.9661332155976976, 0.5491216172065053, 0.32921107751982553, 0.5803489929863385, 1.1087237234626497, 2.4341910736901418, 7.976824675287519, 18.8260954448155, 30.883349622998917, 33.62025547027588, 32.58883360454014, 29.707130772726877, 21.84330551964896, 10.542466981070381, 3.2822651777948653, 0.47744150353329523, 0.35466764867305756, 1.0810633791344506, 2.450575143098831, 6.269128995282309, 8.34707246507917, 11.481148634638105, 16.0779960496085, 28.631124053682598, 34.18665872301374, 39.0606359073094, 41.22711549486433, 46.97085428237915, 50.10790341241019, 42.2276109286717, 30.698176656450542, 69.99247700827462, 64.59830556597028, 26.679722479411534, 29.17726809637887, 35.1548832484654, 40.2779220853533, 38.343620027814595, 40.543530872889924, 45.48089647293091, 40.61507994788033, 45.30630908693586, 49.413799217769075, 47.47167001451765, 53.44142327989851, 50.93311316626412, 51.40395089558193, 43.63320371082851, 45.04831552505493, 44.44073029926845, 54.534114360809326, 54.41310453414917, 52.430071285792756, 47.50061968394688, 49.40827887398856, 49.85069152287075, 55.57864052908761, 53.20382615498134, 57.87441567012242, 5.554369109017508, 0.21360431664756366, 0.1871870756149292, 4.690680665629251, 44.125139645167756, 42.08562101636614, 62.04361970084054, 43.07558992930821, 60.47159671783447, 21.77338579722813, 4.254754160131727, 32.240746225629536, 14.497739451272146, 34.890393120901926, 29.99020038332258, 24.747511829648698, 38.19370222091675, 31.86712769099644, 36.58790751865932, 46.169695717947825, 59.419507435389924, 9.760640042168752, 0.23464530759624072, 0.05628915490316493, 0.037933384866586754, 0.08232341041522366, 0.13037792540022305, 0.05602025826062475, 0.11246692149766854, 0.030277806733335768, 0.07318664461906467, 0.06548549607396126, 0.029154790565371513, 0.045806063671729395, 0.17645371013454028, 0.0670023068253483, 0.06749961871121611, 0.040298154045428546, 0.19976408859448774, 0.15780865347811154, 0.16285718471876212, 49.292598315647666, 62.40346690586635, 45.80891745431082, 24.93790810448783, 36.11512081963675, 45.890152318137034, 25.295328651155742, 32.53686802727835, 26.150585889816284, 41.9101060458592, 4.911769304956708, 14.267503942762103, 63.888262203761506, 56.82047816685268, 62.48939527784075, 55.182989256722585, 57.15527016775948, 14.411979573113577, 0.10103202544684921, 0.6916281932166645, 0.33081882553441183, 18.08301513535636, 59.37062685830252, 52.56171533039638, 61.466585704258506, 59.34001309531075, 60.615799631391255, 56.019225801740376, 48.011756965092246, 45.2775296483721, 54.99680185317993, 57.34301744188581, 56.80909006936209, 51.25223350524902, 49.29128163201468, 54.554642813546316, 54.40615633555821, 58.65622697557722, 53.82518965857369, 55.97899573189871, 54.3569735118321, 54.13990831375122, 46.924832889011924, 47.82765054702759, 44.79462289810181, 33.12974739074707, 40.523766721997944, 71.75415802001953, 65.88953099931989, 53.479339599609375, 48.017555236816406, 46.230579308101106, 42.259273869650706, 46.408248220171245, 39.141144684382844, 38.31345442363194, 27.461915935788834, 32.085995946611675, 40.34104299545288, 33.673058305467876, 11.443359119551522, 1.6706918541874205, 0.7071329898067883, 2.339985008750643, 6.9587542074067255, 27.953615631375992, 35.83332967758179, 32.495307377406526, 39.47587067740304, 37.308609417506624, 43.33765860966274, 37.875877720969065, 22.295039176940918, 7.147742169243949, 4.799914164202554, 17.68464538029262, 6.671663326876504, 1.146001243165561, 0.8711179132972444, 1.9400332357202257, 6.37221941777638, 16.197310515812465, 23.910867077963694, 36.041911125183105, 34.422598702566965, 36.089058126722065, 31.119300024850027, 28.38578142438616, 21.53099615233285, 8.25842387335641, 1.7060386432068688, 0.39313181755798204, 0.1346708264734064, 2.6166909379618506, 5.361377247742244, 13.037203788757324, 14.509556600025721, 13.337607417787824, 26.011126858847483, 34.581580434526714, 40.413102763039724, 40.364371572222026, 41.7367137500218, 51.14913613455636, 51.22603532246181, 41.47189705712454, 33.524700369153706, 56.41354301997593, 75.75616059984479, 37.70019599369594, 33.9658727645874, 38.04083142961775, 40.60261140550886, 40.150874274117605, 40.61084502083914, 44.84272180284773, 44.56180265971592, 41.917596203940256, 51.52653101512364, 49.52443538393293, 55.80964381354195, 53.25491278512137, 54.35315547670637, 44.69090018953596, 45.08397715432303, 47.898306778499055, 56.333256585257395, 55.61480590275356, 56.85508714403425, 52.382959025246755, 51.90535375050136, 52.19809872763497, 57.723921162741526, 55.22748899459839, 60.2543751852853, 5.879543500287192, 0.11441989455904279, 0.045881170712943585, 6.5694900665964395, 49.835655621119905, 50.00226994923183, 69.93384116036552, 46.51570211138044, 65.01806708744594, 21.287149122783116, 7.759641357830592, 36.78347846439907, 18.862656865801128, 33.83794600622994, 31.920270987919398, 25.68408383641924, 43.386257784707205, 34.39626850400652, 39.46015385219029, 50.595375129154746, 66.28340353284563, 9.009118539946419, 0.6899237132498196, 0.1832199799163001, 0.1418054322046893, 0.1012983572270189, 0.0910243463835546, 0.036952223229621134, 0.21298330782779626, 0.1148019911987441, 0.3825547322630882, 0.18150575618658746, 0.2255626685385193, 0.21077692907835754, 0.38080403049077305, 0.24450561563883508, 0.15803824258702143, 0.25946538576057976, 0.27971954750163214, 0.2461949507040637, 0.41221064808113234, 64.8706749507359, 70.91378034864152, 57.285625321524485, 37.53678478513445, 39.116784300122944, 68.3971289225987, 37.72229821341378, 40.718955516815186, 34.37979085104806, 42.609251158578054, 6.177873960563114, 25.092849458966935, 69.31108801705497, 63.152802331107004, 65.23132814679826, 60.88188784463065, 60.90963200160435, 16.056526115962438, 0.23056750212396893, 1.4585271988596236, 0.41111432548080173, 25.182321412222727, 63.085856437683105, 57.468877111162456, 61.783027512686594, 61.50161157335554, 62.396796635219026, 60.619683674403596, 49.328878334590364, 49.71304076058524, 57.903587681906565, 59.19353117261614, 57.828776427677695, 54.43457794189453, 52.60009370531355, 58.456035477774485, 60.47507776532854, 59.901476178850444, 57.648654801504954, 58.4321962084089, 57.4195796421596, 54.56056267874581, 44.7070061138698, 53.77472141810826, 45.6159451348441, 39.060083525521414, 61.912778173174175, 73.74514348166329, 57.56762490953718, 53.92413895470755, 52.587142263139995, 48.683324677603586, 46.1561849457877, 51.63622570037842, 47.98829984664917, 44.610759666987825, 37.90703344345093, 39.9815536226545, 48.6766231400626, 47.05157150541033, 19.055983543395996, 3.3267555790288106, 6.4718717847551614, 8.557754005704608, 30.94927065713065, 41.06467703410557, 44.075876917157856, 42.44586426871163, 49.7558798789978, 48.27413831438337, 53.18588590621948, 48.15810339791434, 27.120015927723475, 5.798759835106986, 3.768583059310913, 21.452153205871582, 12.373398082596914, 2.321970066853932, 1.678415754011699, 1.948688954114914, 6.507123904568808, 17.30111176627023, 30.20753656114851, 42.926679611206055, 46.60276651382446, 44.15841109412057, 44.71062612533569, 36.33527449199131, 33.80609546388899, 17.259101220539637, 6.5888625127928595, 4.112654813698359, 0.9099094346165657, 3.8914875728743414, 6.806084913866861, 18.03810371671404, 21.910016911370413, 25.246199675968715, 36.69764389310564, 38.55461597442627, 46.314899172101704, 46.81727130072457, 48.126492568424766, 53.11445495060512, 52.47374071393694, 41.696431568690706, 35.97820656640189, 48.92440979821341, 70.4626407623291, 50.54058510916573, 38.8197592326573, 43.189919063023154, 44.72758667809622, 41.2270564351763, 41.033125264304026, 42.78974103927612, 42.66303021567208, 37.29355614525931, 47.47472027369908, 51.94879041399275, 56.125203200748985, 56.13069575173514, 56.71335431507656, 49.430898734501426, 46.96698066166469, 49.67812953676496, 60.28718457903181, 56.3506965637207, 55.003142084394185, 53.697603361947195, 54.17282887867519, 56.198857579912456, 62.00181238991873, 61.612046241760254, 62.31307084219796, 8.908914225442068, 0.3294712821287768, 0.7505956004772867, 6.496987785611834, 55.4477573122297, 56.20939104897635, 72.44957542419434, 52.684364931924, 70.80323450905937, 31.767177854265483, 11.54826215335301, 42.258030142102925, 22.28532385826111, 47.833094460623606, 44.36704117911202, 35.879083565303254, 57.011473723820274, 43.34323106493269, 50.545553071158274, 60.03798048836844, 81.53963266100202, 20.383865935461863, 0.9111589704241071, 0.5360435875398772, 0.2804816508931773, 0.22230086927967413, 0.17645597644150257, 0.17926238370793207, 0.3061521505670888], [0.04181216923253877, 0.061908971917416365, 0.16825205380363123, 0.10763938911259174, 0.046925432713968415, 0.0616456392620291, 0.03837863615314875, 0.050781957738633664, 0.029298606062574045, 0.0707283801000033, 0.13527888884501799, 0.25685834565332955, 23.30242027555193, 62.01548644474575, 40.89667306627546, 42.32013314110892, 36.574122292654856, 48.73483167375837, 33.641047954559326, 36.55015795571463, 26.245199510029384, 53.11481278283255, 8.399744153022766, 6.907889919621604, 50.49412945338658, 55.399460383823936, 54.51321070534842, 54.733246258326936, 53.159604345049175, 17.23617216518947, 0.05992670649928706, 0.19444685748645238, 0.46974800207785194, 8.035963399069649, 59.75430638449532, 54.921427794865195, 61.29105336325509, 56.38387768609183, 56.52973427091326, 48.87306955882481, 46.84987572261265, 55.417473588671, 60.18962492261614, 56.32075677599226, 61.066570963178364, 53.91515145983015, 45.38637317929949, 47.842352935246055, 52.826038701193674, 52.52970150538853, 55.905226707458496, 54.73987831388201, 58.35432079860142, 51.52483565466744, 51.14633253642491, 44.17696278435843, 42.41990579877581, 45.34303726468767, 31.821915762765066, 22.805799518312725, 43.242683683122905, 58.817626680646626, 46.93788160596575, 46.19802004950387, 39.39660562787737, 38.24593530382429, 39.320109435490195, 28.495434420449392, 29.77696364266532, 33.1793783732823, 26.171897751944407, 12.671652112688337, 5.249836078711918, 1.6636729793889182, 1.9885110344205583, 9.594895107405526, 27.4708217893328, 36.01993744713919, 42.18361840929304, 40.923833574567524, 38.854819842747276, 24.091777324676514, 14.949631180082049, 3.63675879580634, 1.2617279418877192, 1.2457288461072105, 0.9393004775047302, 7.618226408958435, 1.815534110580172, 0.6751105338335037, 0.9836924097367695, 1.2198191221271242, 0.8043046327573913, 0.9542407329593385, 1.7673697407756532, 4.348797593797956, 17.313349281038555, 28.826627254486084, 35.180240699223106, 38.032024587903706, 33.37655782699585, 18.250068937029155, 14.85078958102635, 7.883823905672346, 0.9397296373333249, 1.0115560974393571, 1.698122148002897, 5.477995378630502, 8.66679208619254, 12.248502475874764, 15.080109664372035, 26.1008836882455, 37.32337086541312, 40.61030306134905, 42.52120706013271, 42.857135091509136, 43.287186895098, 44.34163161686489, 39.89462123598371, 42.31962592261178, 83.69379656655448, 68.5065699986049, 41.89049128123692, 34.62222392218453, 40.5836706161499, 43.38510438374111, 61.60923222133091, 72.20293521881104, 67.09316744123186, 65.574020249503, 52.357473032815115, 53.82512365068708, 51.95328937258039, 51.87387841088431, 48.25983197348458, 42.489498955862864, 43.830247674669536, 52.72845125198364, 53.01689529418945, 55.133563246045796, 58.276160512651714, 55.46875824247088, 53.36655991418021, 53.07517678397042, 53.32703161239624, 52.82573645455496, 43.56679630279541, 1.4779514308486665, 0.15196711836116655, 0.054691825793789964, 16.028460604803904, 63.15422671181815, 48.67000845500401, 39.23051936285836, 47.69490868704659, 53.56711966650826, 7.189176448753901, 11.828084349632263, 33.60404532296317, 17.732657432556152, 35.19059004102434, 33.178131171635215, 36.889601775578086, 31.59768349783761, 33.82511963163103, 35.76383032117571, 45.36996153422764, 49.71428101403372, 1.9880096784659793, 0.14190661534667015, 0.04834233257653458, 0.07328644354960748, 0.03820027643814683, 0.0366333015928311, 0.014004296124247568, 0.1529705495174442, 0.03347957260640604, 0.012243650421234114, 0.05485035193019679, 0.10229658401970353, 0.03742176606985075, 0.03200310415455273, 0.06565755219863993, 0.09326634143612214, 0.11488014486219202, 0.08538150667612042, 0.09066248365810939, 0.24145364654915674, 26.590497187205724, 72.68718991960797, 45.03680235998971, 38.438317026410786, 45.18108170373099, 51.29007339477539, 24.66324234008789, 39.463238852364675, 22.71018362045288, 52.12906837463379, 13.171205878257751, 8.496847833905901, 54.15537847791399, 60.94198281424386, 57.0368971824646, 58.44917760576521, 57.41597352709089, 19.550747394561768, 0.10502264595457486, 0.483123990041869, 0.3050097147268908, 10.784814068249293, 60.71554797036307, 57.32295799255371, 63.80263260432652, 57.1920747756958, 55.31757238933018, 52.38524150848389, 47.350086961473735, 57.39727939878191, 60.78009673527309, 58.35876069750105, 60.576035090855186, 54.94313744136265, 47.50327042170933, 50.0869893346514, 56.52487400599888, 52.220253058842246, 57.52946192877633, 56.31049428667341, 58.83603940691267, 53.63108478273664, 49.29850428444998, 44.31767422812325, 41.83837979180472, 47.761291776384624, 35.87692614964077, 27.494951145989553, 44.90534244264875, 57.2842252595084, 50.85782248633248, 49.404832567487446, 45.7751214163644, 46.198791299547466, 42.2626576423645, 43.26895482199532, 31.114700317382812, 39.36720779963902, 42.97102648871285, 26.094161306108745, 7.14709381546293, 0.9107652029820851, 5.319358016763415, 6.4382164478302, 22.688128301075526, 37.26621150970459, 42.18903800419399, 38.18029567173549, 42.86398254122053, 35.112301213400706, 35.7156480380467, 25.51853953089033, 8.766941683632986, 2.2374532648495267, 3.350749445813043, 12.568905626024518, 5.149617433547974, 1.0294362008571625, 1.0429055009569441, 0.8594086787530354, 3.4703461825847626, 6.110205020223345, 14.5375109400068, 26.857877765383037, 34.218095847538535, 35.73726735796247, 37.395090171269004, 36.11686481748308, 34.51306772232056, 16.54190468788147, 4.347776208605085, 2.3046458193234036, 0.9985573206629071, 0.3896709904074669, 5.916534841060638, 10.305683663913182, 14.565982920782906, 15.69739978654044, 22.236028126307897, 34.66869347436087, 39.53135551725115, 44.8395881652832, 43.24477856499808, 43.19715561185564, 44.504796164376394, 46.45080941064017, 41.166193689618794, 37.97209290095738, 63.53924724033901, 81.46177114759172, 54.76968608583723, 45.215447493961875, 44.909108366285054, 45.38046721049717, 58.283914702279226, 69.39487634386334, 58.69431700025286, 62.929410798209055, 54.55735261099679, 53.87116241455078, 53.84950835364205, 52.559575285230366, 46.84281982694353, 43.6730967930385, 45.70788369859968, 56.4263277053833, 54.46133892876761, 54.925655773707796, 59.81185136522566, 58.05899803979056, 59.17283943721226, 54.73371178763253, 55.44592646190098, 58.42568574632917, 45.743448053087505, 1.5109497287443705, 0.07474243720727307, 0.02916663439412202, 19.557435035705566, 65.60512038639614, 55.794673919677734, 44.47939702442714, 53.56346838814871, 58.27223130634853, 9.169669696262904, 14.605556385857717, 38.67895746231079, 23.332309688840592, 33.474173069000244, 32.1626832144601, 31.95703043256487, 40.18644210270473, 33.87812396458217, 32.78426558630807, 51.44477503640311, 55.79364211218697, 3.1340852890695845, 0.5011574423738888, 0.10131268110126257, 0.007131967078229147, 0.028784622571298053, 0.06504395976662636, 0.012889685308826821, 0.04185551744220512, 0.16655719546335085, 0.10626818519085646, 0.15644041475440773, 0.18249667515712126, 0.10614226266209568, 0.10224210444305624, 0.1321272158196994, 0.27669835676039967, 0.2339256533554622, 0.12787691317498684, 0.23178180839334214, 0.30020557822925703, 38.201974051339285, 83.86491680145264, 52.516746589115684, 57.80436740602766, 49.180124350956504, 70.65821865626744, 41.23341751098633, 45.64824383599417, 30.34126853942871, 62.06971713474819, 13.469021303313118, 13.06151032447815, 59.41681153433663, 65.36092594691685, 61.460909026009695, 65.95057092394147, 63.60966028485979, 20.756082671029226, 0.31263937960777965, 1.1802537994725364, 0.5552131246243204, 14.472729410443987, 65.94772216251918, 61.80707522800991, 69.04163687569755, 61.37925379616873, 59.789707456316265, 56.68533917835781, 50.22655779974801, 57.21269702911377, 63.25075108664376, 62.9561196735927, 64.93974699292863, 57.10318647112165, 50.47921861921038, 53.70733778817313, 57.38231297901699, 56.88426610401699, 60.74402168818882, 59.05411556788853, 59.127377373831614, 55.314713205610005, 52.41630343028477, 46.343855789729524, 45.51781225204468, 49.53526415143694, 37.670944077628, 48.810827595846995, 60.839378765651155, 59.18980693817139, 52.12823806490217, 52.62601048605782, 47.55476352146694, 49.30378144127982, 44.83925117765154, 48.808673654283794, 40.033050196511404, 46.446810722351074, 54.22198738370623, 35.337947436741416, 12.020833458219256, 7.295649341174534, 11.269711477415902, 23.271054370062693, 40.22257620947701, 44.86694669723511, 47.09381307874407, 49.38575628825596, 48.735658509390696, 43.53526190349034, 45.01368917737688, 32.735530921391074, 11.401511856487819, 5.366465934685298, 5.9288418378148755, 20.524566956928798, 12.811208418437413, 2.589937116418566, 1.9248368740081787, 3.747272934232439, 4.526465637343271, 6.91025447845459, 17.565687009266444, 32.0419374193464, 40.868703092847554, 42.26769508634295, 43.57688856124878, 42.683221680777415, 37.963848863329204, 29.3035272870745, 22.174303804125103, 11.314734935760498, 6.042612510068076, 1.3110909845147813, 7.148005332265582, 16.040361131940568, 21.413151230130875, 22.774463142667496, 33.42995473316738, 40.4393287386213, 43.73403944287981, 48.214724268232075, 47.5674717766898, 48.64855241775513, 50.20694650922503, 50.288118839263916, 41.73939575467791, 39.87758425303868, 51.83017076764788, 66.89285087585449, 54.30992031097412, 49.447244371686665, 50.217132568359375, 50.43096685409546, 53.95512097222464, 63.329390798296245, 54.477962493896484, 65.76368522644043, 61.43306064605713, 54.68526547295706, 58.49385452270508, 54.05613040924072, 53.02083839688982, 47.238551003592356, 48.71296569279262, 56.70542642048427, 57.14600474493844, 57.81829159600394, 64.37838813236782, 59.375705991472515, 59.86189923967634, 58.59051786150251, 58.07940489905221, 59.37395504542759, 53.037632192884175, 3.3117277111325945, 0.2889123942170824, 0.6280584186315536, 19.521955796650477, 73.26772580827985, 57.274914673396516, 49.76015649523054, 56.67352376665388, 63.58322238922119, 13.673141138894216, 18.6568512235369, 42.70945460455758, 25.300046477999004, 44.30092559541975, 43.3110921723502, 48.268670082092285, 48.379545961107524, 44.57612984521048, 49.685574531555176, 59.07690565926688, 76.30727086748395, 9.460382325308663, 0.5816274072442735, 0.3735120046351637, 0.15541801175900868, 0.2221144214272499, 0.21896033281726496, 0.1257888302206993, 0.3863086865416595], [0.07596634474716016, 0.07386711346251623, 0.09542803865458284, 0.0810707262051957, 0.05900812614709139, 0.07506175578704902, 0.10458064824342728, 0.28415352957589285, 0.11071345808782748, 0.06836853030004672, 0.11503190600446292, 0.29480623081326485, 10.931947384561811, 65.0352430343628, 42.31690570286342, 35.999884946005686, 24.045451947620936, 48.51869753428868, 40.06565114430019, 35.41687549863543, 33.74781050000872, 73.87795829772949, 30.733952930995397, 0.5624610728451184, 41.005186557769775, 53.2567366872515, 56.98127337864467, 52.369830404009136, 53.9567676952907, 19.922745261873516, 0.1532483688954796, 0.2041245446141277, 0.11214437987655401, 2.3863989753382544, 53.694858823503765, 55.449873038700645, 60.38477202824184, 56.189098834991455, 54.96625062397548, 45.75088957377842, 46.88448469979422, 56.43498516082764, 56.43365805489676, 56.66642965589251, 55.601611273629324, 55.67842360905239, 47.70306239809309, 46.7963468006679, 50.99531691414969, 54.242574896131245, 54.54130227225167, 57.48351696559361, 55.374669211251394, 57.345994744982036, 47.19758095060076, 45.33439717973982, 42.10052490234375, 45.6079547064645, 43.88463817323957, 42.8368741444179, 27.53393054008484, 35.504520075661794, 45.435889516557964, 46.17658485685076, 41.26114777156285, 39.49141032355172, 35.705093724387034, 29.829978397914342, 35.53698205947876, 34.965614318847656, 25.888777766908916, 10.192669476781573, 3.4581777155399323, 3.240257671901158, 6.427458465099335, 21.05819034576416, 36.30690499714443, 39.81853151321411, 45.341630254473, 37.8228942326137, 26.383161204201834, 15.86330713544573, 4.2118125557899475, 1.9651212266513278, 1.8777374242033278, 0.7921823603766305, 1.7099882598434175, 15.258068663733345, 6.47900367634637, 0.3816857188940048, 0.6272196950657027, 0.840157011789935, 0.47271683705704554, 1.700532738651548, 2.9413780868053436, 1.35441169994218, 4.409748928887503, 17.51525350979396, 28.322712625776017, 34.20549528939383, 36.021424361637656, 26.063410316194805, 22.294234922954015, 15.376747369766235, 4.774051231997354, 0.5689095982483455, 2.2278484659535542, 4.3931787780353, 9.636219518525259, 10.670768073626927, 11.731411457061768, 27.16170859336853, 35.07726492200579, 41.05161094665527, 41.39409112930298, 43.54002489362444, 44.570157868521555, 46.810767786843435, 44.243151324135916, 39.72527626582554, 42.22654438018799, 72.01346479143415, 73.18636935097831, 66.6278326851981, 57.900808402470176, 62.255470275878906, 61.021345138549805, 49.79324034282139, 41.45688547406878, 39.97968108313424, 45.9000917162214, 50.38179097856794, 49.803481987544465, 49.535420485905235, 42.21350261143276, 42.95275967461722, 48.07629530770438, 52.90595688138689, 55.051755155835835, 54.967536040714805, 50.85459852218628, 58.43901933942522, 52.51811538423811, 57.59611599785941, 53.666458061763215, 61.37461934770857, 24.727507965905325, 0.5571276247501373, 0.23563686438969203, 0.37739026652915136, 28.215948343276978, 52.548888955797466, 36.54920257840838, 49.53588948931013, 57.829224586486816, 48.98603684561593, 6.315584651061466, 10.417229175567627, 20.49524555887495, 14.154807635716029, 33.10154117856707, 32.342856952122276, 42.13601630074637, 33.98062726429531, 27.058036259242467, 24.586341415132793, 50.295226846422466, 38.0268794468471, 0.13453122467866965, 0.09638484766972916, 0.06740973317729575, 0.04401724858741675, 0.18252749421766826, 0.1051471232037459, 0.04986101947724819, 0.03629748782675181, 0.11048408611012356, 0.06606581314866032, 0.016467317173789655, 0.032950111731354675, 0.07404843837554966, 0.029233096899198632, 0.08876707750771727, 0.25940184774143354, 0.05210848352206605, 0.09240072752748217, 0.058953884057700634, 0.3392334740076746, 13.370184915406362, 75.75511142185756, 48.02700478690011, 36.387799399239675, 29.064806291035243, 53.154869147709434, 29.846417835780553, 41.28386838095528, 38.36391918999808, 73.0919850213187, 31.12174231665475, 1.6744661373751504, 39.467105524880544, 61.66798618861607, 60.5633407320295, 56.912097113473074, 57.7758971623012, 22.203764166150773, 0.06654428890241043, 1.5756953230925967, 0.1112137216010264, 2.8339519883905138, 54.556518827165874, 57.644572734832764, 62.43137781960623, 59.37212072099958, 57.03951665333339, 47.00872891289847, 50.95794602802822, 56.96774871008736, 57.228608403887065, 58.397371837071006, 56.12663452965872, 56.580817426954, 49.60234900883266, 48.67271825245449, 54.068265438079834, 56.165818895612446, 56.92131389890398, 58.68113626752581, 56.121301787240164, 57.447028500693186, 50.151454721178325, 42.91894974027361, 43.45691054207938, 43.54489210673741, 47.601622172764365, 42.73332166671753, 35.31202023369925, 37.679837771824424, 50.168373584747314, 49.18890339987618, 47.8991197177342, 42.940683705466135, 42.94385208402361, 37.23460068021502, 38.32214314596993, 46.28567157472883, 39.614160673958914, 15.657987867082868, 4.325304431574685, 2.30968000633376, 5.602839742388044, 15.79750074659075, 38.07459272657122, 46.451844692230225, 43.01364326477051, 42.311830043792725, 37.93014662606375, 29.316047940935405, 22.787357262202672, 14.723689658301216, 3.7363703421183994, 2.089445561170578, 2.6991404337542395, 15.075803518295288, 8.44155580656869, 0.25370706617832184, 1.1096286177635193, 1.0270643681287766, 1.8701986287321364, 2.7263758523123602, 5.952031884874616, 17.068731001445226, 25.043030875069753, 29.88702310834612, 36.336417470659526, 37.0844292640686, 38.174198627471924, 28.7856502532959, 20.487590381077357, 9.737137760434832, 2.0515357553958893, 0.5827725029417447, 1.7482478639909198, 6.265541987759726, 16.030984537942068, 17.57325186048235, 16.961926766804286, 35.28113896506173, 37.65489373888288, 44.57288156236921, 41.28763083049229, 45.63721704483032, 44.929928643362864, 50.42572791235787, 46.20218896865845, 42.64336333956037, 35.836313928876606, 58.89056192125593, 71.21176079341343, 65.67845167432512, 58.873948778424946, 57.936146940503804, 59.904582023620605, 52.06770188467843, 48.38272476196289, 46.693735803876606, 46.3296571459089, 52.50664390836443, 50.838353633880615, 49.819337776729036, 43.85683148247855, 44.66326025554112, 52.61174930844988, 55.136992182050435, 55.545719964163645, 58.24840245928083, 55.25144290924072, 60.790088244846885, 55.30740370069231, 59.26586191994803, 57.009556021009175, 62.085225514003206, 25.049287727900914, 0.6219406383378165, 0.2564542644790241, 0.6676628791860172, 33.29508672441755, 55.984985079084126, 39.4150322505406, 49.17149468830654, 61.504856382097515, 52.07801995958601, 9.642823781285967, 12.641842603683472, 27.86082070214408, 16.941858632223948, 33.90447153363909, 28.785615512302943, 38.46585273742676, 44.06723683220999, 26.69697138241359, 30.62894480569022, 54.84604331425258, 47.316283975328716, 0.41184787611876217, 0.058378778131944795, 0.07366744774792876, 0.046293835355235, 0.03321800074939217, 0.05425156852496522, 0.029223186895251274, 0.06997088396123477, 0.13880098770771707, 0.20276894021247113, 0.2046134290950639, 0.13386962589408669, 0.1376494594982692, 0.15872074025017874, 0.17837998962828092, 0.3988580288631575, 0.2892374667738165, 0.2632185529385294, 0.17297076274241718, 0.5097492156284196, 19.747440474373953, 93.64047636304582, 53.86200816290719, 51.473724705832346, 34.76254974092756, 69.02703871045793, 50.42788880211966, 43.435857500348774, 41.85657712391445, 77.48260034833635, 32.97435787745884, 5.3749483823776245, 48.94952406202044, 64.80100536346436, 64.85667433057512, 64.29933847699846, 65.09313542502267, 25.880994047437394, 0.18047614714929036, 2.2802320207868303, 0.30239211661475046, 4.773938323770251, 59.459536007472444, 59.54670810699463, 65.8277337210519, 62.9413616997855, 60.54116208212716, 49.70236137935093, 54.21697078432356, 60.87410586220877, 60.617481095450266, 61.47095612117222, 59.55112716129848, 60.83422320229666, 51.98170403071812, 52.329082693372456, 57.68184287207467, 57.96741036006382, 60.71931389399937, 60.41439914703369, 59.133088793073384, 58.65905489240374, 51.28063426698957, 45.98433862413679, 45.16403429848807, 48.54544115066528, 49.17818232945034, 42.92108978543963, 39.410991873059956, 46.03640147617885, 52.60275486537388, 53.668389660971506, 48.7103705406189, 47.436859539576936, 46.04870326178414, 47.05750526700701, 44.269665649959016, 53.780252184186665, 50.71112516948155, 25.477487836565288, 10.434954898697988, 11.669980696269445, 22.09450200625828, 40.22397974559239, 44.86196831294468, 51.95291764395577, 49.8555691582816, 49.742511544908794, 46.23278883525303, 37.61035578591483, 29.05991128512791, 24.81164370264326, 9.07857881273542, 6.107483063425336, 11.291980453899928, 29.35176862989153, 18.168319906507218, 5.49403920343944, 2.2745785755770545, 2.8315498658588956, 3.615189416067941, 5.594248294830322, 9.7436569077628, 22.50093514578683, 34.66135270254952, 37.64539902550833, 41.299296855926514, 41.22459329877581, 37.42125013896397, 35.143512521471294, 29.0544239452907, 21.77120406287057, 11.609432356698171, 2.3011495726449147, 3.536359931741442, 9.560174090521675, 23.446657930101665, 25.931788853236608, 25.842619146619523, 44.05841261999947, 41.88008287974766, 49.815512793404714, 42.90565088817051, 50.24724606105259, 48.13398272650582, 53.37162167685372, 47.327484471457346, 42.920377595084055, 37.188815525599885, 50.853625774383545, 56.14904941831316, 58.400012152535574, 57.708013262067524, 59.67044162750244, 68.43612221309117, 64.12612683432442, 59.57703004564558, 57.86809975760323, 49.27065243039812, 56.116149697984966, 54.35029976708548, 54.310900006975444, 45.37309864589146, 47.35130637032645, 53.50027452196394, 57.50732844216483, 57.22061102730887, 61.31768580845424, 54.36370284216744, 64.75002643040249, 57.20496368408203, 62.740051542009624, 58.047127042497905, 64.54266439165387, 30.855966772351945, 1.2615919091871806, 1.1083462408610751, 0.8023666824613298, 34.48311403819493, 63.56323937007359, 43.70895644596645, 57.9294627734593, 65.36945138658795, 60.76028047289167, 14.242739694459097, 17.133441311972483, 26.14909897531782, 21.271807500294276, 43.409909452710835, 43.04643528802054, 55.13441440037319, 49.45303569521223, 36.37551498413086, 38.686729022434776, 61.41431440625872, 63.520341191973, 3.1139715569359914, 0.29285392271620886, 0.2593110868973391, 0.18848033621907234, 0.3297735559088843, 0.1718826097037111, 0.08369612747005054, 0.1916813658816474], [0.07838215333010469, 0.0512679041629391, 0.05715912500662463, 0.07170663082173892, 0.07274649252316781, 0.052405088142092736, 0.026216901872040968, 0.12813265302351542, 0.042278149763920476, 0.12501939865095274, 0.0760156742430159, 0.08391542320272752, 4.539817903723035, 60.059165545872276, 44.933291571480886, 39.352769442967, 33.265883445739746, 38.22395467758179, 44.194830077035085, 26.281361409596034, 26.95380633217948, 51.558162689208984, 69.88387666429792, 2.396989767040525, 16.534758465630667, 45.9303754397801, 52.27822535378592, 53.767182622637065, 54.70159373964582, 28.61556703703744, 0.4474791613008295, 0.741486457841737, 0.029430211322116, 0.8784448972770146, 44.60864741461617, 61.89371231624058, 57.05529253823416, 59.56835869380406, 55.02240596498762, 46.91297926221575, 51.08486877168928, 59.89577865600586, 56.36843531472342, 60.24661404745919, 58.53987939017159, 57.39753648212978, 49.14720378603254, 47.73943969181606, 50.378987380436485, 52.22921970912388, 53.287968839917866, 55.14196014404297, 57.42394658497402, 54.473477431706016, 53.43150472640991, 47.98395374843052, 47.89103201457432, 50.239068031311035, 47.86694261005947, 51.656719412122456, 51.53118978227888, 45.059293678828645, 44.08290849413191, 48.80425459997994, 44.22303976331438, 40.6555358341762, 31.65844202041626, 28.26283652441842, 33.86366128921509, 36.54000663757324, 23.126719440732682, 10.250298704419817, 3.4364413619041443, 6.383810315813337, 22.686254024505615, 34.094338008335654, 37.95980848584856, 44.41050216129848, 43.55273314884731, 35.43086222239903, 20.23509979248047, 11.534493429320198, 7.339549796921866, 2.7600049163614, 1.0599603972264697, 1.8256702295371463, 4.317462955202375, 18.44449864115034, 13.006636926106044, 1.0890291631221771, 2.3613424684320177, 0.9901023400681359, 0.49801338251147953, 0.8451257337416921, 2.0352889129093716, 5.394211394446237, 6.879344114235469, 16.963137490408762, 30.002432686941965, 36.03585229601179, 37.94911173411778, 28.78988344328744, 23.68426374026707, 23.122651270457677, 12.726196340152196, 2.5570154658385684, 0.3965460972062179, 2.6872627053942, 7.475988098553248, 10.005954878670828, 14.918046406337194, 26.4073965208871, 35.20157861709595, 42.6336532320295, 41.2534213747297, 44.03582402638027, 41.55630724770682, 46.21883685248238, 46.22255413872855, 44.61146143504551, 37.01600340434483, 40.91438749858311, 49.55095318385533, 50.064449378422324, 53.82236868994576, 42.88343402317592, 38.18289777210781, 33.832418714250835, 38.016544001443044, 46.46752330235073, 50.12667744500296, 50.62003081185477, 48.93061453955514, 49.216168131147114, 43.396996225629536, 44.861026832035606, 50.897934436798096, 54.901757444654194, 52.125736713409424, 53.6634008543832, 54.755445752825054, 55.866705894470215, 54.230106353759766, 59.937398365565706, 55.10062531062535, 52.068146569388254, 8.929049236433846, 0.2712291202374867, 0.4176730721124581, 3.392062566110066, 45.98066997528076, 42.131357533591135, 40.67038066046578, 63.69456727164132, 52.40843112128121, 37.83299343926566, 2.9763079839093343, 16.46854039600917, 15.927680458341326, 25.59006428718567, 26.029692445482524, 33.07257066454206, 38.63532624925886, 27.736981221607753, 31.980921813419886, 30.47381932394845, 52.53164005279541, 30.71162142072405, 0.3668417882706438, 0.05782334293637957, 0.08479647378304175, 0.06126031958098922, 0.057258754303412776, 0.04934902409357684, 0.061361326303865225, 0.10468657434518848, 0.03311445291287132, 0.0655110225613628, 0.03628475172445178, 0.04588702307747943, 0.026957254823563353, 0.06791131304843084, 0.010242786358243652, 0.11303981539926358, 0.08462395625455038, 0.08584299191300358, 0.01954990006717188, 0.13214170932769775, 4.09154748916626, 66.874938419887, 52.45170102800642, 40.90746014458792, 40.46274764197213, 47.6520209312439, 30.807888712201798, 29.16815205982753, 39.61368472235543, 63.91937623705183, 66.24229798998151, 4.377903597695487, 18.44687145096915, 48.044677530016216, 58.56119646344866, 58.892597743443076, 59.27779197692871, 32.294167450496126, 0.7712922756161008, 0.7611542567610741, 0.1573704012802669, 1.2027174340827125, 46.01461887359619, 64.09116349901471, 60.599464416503906, 62.274160930088584, 57.102328368595664, 48.34764330727713, 54.60565301350185, 60.74660641806466, 59.32608890533447, 60.975688525608604, 61.2782895224435, 57.63420254843575, 51.762408460889546, 50.739557198115754, 52.32570586885725, 53.43540613991873, 55.777463231767925, 56.63001414707729, 59.84935079302107, 54.97767693655831, 55.514154297964915, 49.103628158569336, 48.43001420157296, 49.94758415222168, 51.44529962539673, 54.05870819091797, 53.015526499067036, 47.32802990504673, 48.47303049904959, 48.43960966382708, 48.56025471006121, 43.38435050419399, 40.95365524291992, 33.49284635271345, 36.4377395766122, 44.409029143197195, 35.40464666911534, 11.473971145493643, 2.8692091022218977, 5.329238789422171, 16.71180898802621, 35.222680296216694, 42.192050048283164, 48.574554102761404, 46.656208583286826, 42.21543768474034, 34.55181782586234, 24.976255212511333, 17.525317975452968, 7.362721170697894, 3.006830551794597, 4.448173769882747, 3.502163286720003, 21.293668270111084, 9.72268203326634, 0.5472194935594286, 1.4857170198644911, 0.8761815215860094, 1.4791805020400455, 1.099443861416408, 4.0191767896924695, 9.842611415045601, 21.366674729755946, 27.21475808961051, 35.707664557865684, 40.37185825620379, 40.298863955906455, 35.66649300711495, 28.011221408843994, 23.012725557599747, 10.160453285489764, 1.7954349262373788, 1.4788518739598138, 4.991088203021458, 11.118751440729413, 20.34827552522932, 18.97640582493373, 30.21120868410383, 42.22220523016793, 40.32885932922363, 44.052669933864046, 42.03406885692051, 45.53202131816319, 46.828708035605295, 48.98144061224801, 43.44561971936907, 41.23886489868164, 37.56878123964582, 43.00301946912493, 45.147858892168315, 52.553596360342844, 46.97879259926932, 42.342006070273264, 42.90332324164254, 44.79029764447893, 47.17973797661917, 52.34254482814244, 52.392512798309326, 52.28721284866333, 50.996668338775635, 45.74318054744175, 47.11601604734148, 52.87437037059239, 56.66673885072981, 51.814655440194265, 53.70544440405709, 54.641345909663606, 57.172324521201, 58.08295542853219, 60.89292853219168, 57.04983472824097, 50.6648188999721, 8.136534231049673, 0.27842745397772106, 0.6656698318464416, 5.950826372419085, 51.472557408469065, 45.33007887431553, 46.26261397770473, 63.010635239737375, 56.34192793709891, 40.012341090611045, 5.672275262219565, 20.82743545940944, 21.780936752046856, 26.69210764339992, 27.439148426055908, 26.672498089926584, 39.85705232620239, 35.90036589758736, 31.697536059788295, 34.61736018317086, 59.47764996119908, 33.98396587371826, 0.17897292066897663, 0.06284598806606871, 0.1159689628652164, 0.0723677207050579, 0.12723476120403834, 0.020980240012119924, 0.04845712373831442, 0.10082352520631892, 0.2162579856812954, 0.1952438104365553, 0.1705191885786397, 0.22527051850089005, 0.12934751569160394, 0.06167429379586663, 0.11796712635883264, 0.19790283989693436, 0.20695767258959158, 0.2144144738891295, 0.31994147492306574, 0.22978971100279263, 7.573600734983172, 85.55486461094448, 57.712738037109375, 54.97644363130842, 42.147571155003135, 60.20844064440046, 56.584354060036794, 32.66102886199951, 34.40925121307373, 63.166719572884695, 69.31779302869523, 7.1299057091985425, 23.86498464856829, 55.77594157627651, 63.587745666503906, 62.59537615094866, 64.5995215007237, 34.66482332774571, 1.3039152324199677, 1.7610531768628528, 0.17774573580494948, 1.8971231154033115, 53.87997620446341, 64.75140912192208, 63.23741054534912, 65.21442317962646, 61.57367134094238, 53.88604198183332, 56.40393018722534, 61.54574653080532, 61.63546167101179, 65.68635872432164, 65.01544761657715, 59.93995530264718, 54.37413903645107, 52.931762490953716, 56.514330114637104, 58.48787907191685, 59.198422704424175, 59.20111165727888, 62.73033101218087, 56.851574829646516, 56.48175695964268, 51.02745928083147, 50.93700763157436, 53.21440826143537, 51.88574940817696, 59.475641931806294, 54.63952200753348, 51.001136030469624, 52.48882872717721, 53.90978397641863, 52.19475664411272, 48.98333052226475, 44.79398366383144, 45.46594394956316, 40.569374697549, 50.133156640189036, 48.979199818202424, 26.074963433401926, 16.706028086798533, 24.209933178765432, 36.65679195949009, 47.37672288077218, 46.92376981462751, 51.51542084557669, 52.190188203539165, 50.86478805541992, 46.156719957079204, 39.74900088991438, 28.5839318888528, 16.33200134549822, 11.836314490863256, 9.521841747420174, 20.947302307401383, 34.7628241947719, 26.602864980697632, 10.786155939102173, 4.958453382764544, 4.549665238176074, 5.314641058444977, 8.58609310218266, 10.688104697636195, 20.419070720672607, 33.28231246130807, 40.063629218510215, 45.63439607620239, 44.56777116230556, 40.344690799713135, 36.21264573505947, 33.09893907819475, 28.394072362354823, 19.19857621192932, 8.688660672732762, 1.4707560283797128, 6.149001155580793, 17.096954584121704, 26.610026836395264, 26.218365567071096, 40.89401190621512, 45.53150020326887, 47.45328508104597, 47.70735985892159, 47.73852252960205, 47.18167304992676, 50.76906272343227, 51.2342654636928, 46.08450385502407, 42.96918869018555, 42.241625445229666, 45.03184134619576, 45.35403626305716, 50.66354043143136, 50.91864354269845, 46.93708951132638, 46.770558561597554, 45.991186073848176, 46.5786771093096, 54.13907452992031, 54.835263184138704, 53.56238099506923, 55.816161223820274, 47.58077757699149, 50.12177201679775, 56.62752321788243, 58.926956585475374, 55.03259897232056, 55.00039059775216, 57.08118500028338, 60.39089339120047, 61.06545925140381, 63.48589202335903, 60.24398762839181, 56.867371559143066, 13.481974482536316, 0.48366133549383705, 1.288635709456035, 6.520169147423335, 54.652664525168284, 54.59032876150948, 50.58879518508911, 73.55543681553432, 59.65412725721087, 49.13642018181937, 8.277994343212672, 23.027033635548182, 21.12320463997977, 36.28352778298514, 34.61517150061471, 45.768273966653005, 54.98627880641392, 38.54581608091082, 44.79119396209717, 44.16645015989031, 70.23717866625104, 50.833524635859895, 0.908457695373467, 0.17704375061605657, 0.21363310010305472, 0.2446974782007081, 0.24800218801413262, 0.11994257250002452, 0.14835762418806553, 0.08730743333165135], [0.036516417150518725, 0.035904283568795235, 0.07765448559075594, 0.061041240979518206, 0.03312148592833962, 0.033932674543133805, 0.043696196350668154, 0.015529498657477754, 0.020346308492922356, 0.018654566324715103, 0.027362937340512872, 0.06217863530452762, 0.5235680426870073, 46.68161119733538, 52.0874799319676, 35.187960147857666, 23.567910943712505, 36.35310704367501, 41.85493734904698, 38.890630858285085, 21.352634157453263, 26.655841520854406, 40.25089706693377, 6.4231762034552435, 19.692417689732142, 58.12141023363386, 43.553542613983154, 50.93733072280884, 50.67601939610073, 38.99437093734741, 2.5482642097132544, 0.144071155626859, 0.016758074518293142, 0.289929138230426, 27.11070360456194, 58.09776551382882, 54.67114325932094, 58.54895373753139, 52.36312191826956, 48.24462931496756, 54.323643003191265, 58.19441148212978, 55.05672311782837, 55.94138513292585, 58.3533411026001, 56.32119798660278, 48.05541249683925, 47.402584075927734, 50.07255097797939, 55.5880240712847, 56.31966243471418, 56.83791814531599, 57.232099873679026, 57.79991708483015, 54.99662120001656, 50.415597438812256, 49.9267395564488, 49.74206338609968, 51.982815742492676, 53.79406520298549, 47.47138861247471, 49.11404698235648, 49.069533348083496, 49.02337646484375, 44.69233846664429, 36.85403394699097, 33.25749349594116, 23.108334507261002, 31.84592526299613, 40.27904421942574, 36.796099867139546, 26.133460317339214, 16.65228029659816, 26.666394097464426, 36.39054046358381, 39.22268526894705, 41.888403347560335, 44.334520135607036, 46.350057056971956, 35.384305817740305, 21.24530359676906, 10.784668156078883, 4.1466862218720575, 0.6860073176877839, 2.9682231034551347, 1.631130765591349, 10.521645835467748, 26.83184460231236, 18.818782465798513, 9.396817599024091, 2.0476527980395725, 1.0412571494068419, 1.9708415482725417, 0.8874053050364766, 1.0818054250308444, 2.6199846012251715, 9.768708637782506, 19.25608124051775, 28.969466584069387, 37.13267755508423, 40.15154824938093, 35.55894531522478, 27.33266380855015, 25.476317065102712, 18.159844841275895, 8.016930546079363, 1.6650857435805457, 2.0168937742710114, 7.0431214060102185, 14.861877168927874, 16.533493893487112, 20.587331771850586, 37.2468329838344, 40.93813991546631, 40.708734716687886, 41.517939295087544, 40.631119864327566, 46.07187897818429, 42.74401841844831, 45.8120094026838, 48.14931740079607, 37.472031048366, 39.17793887002127, 51.4284085546221, 42.90632486343384, 46.20834159851074, 45.607197352818076, 50.87863234111241, 43.52144888469151, 48.21058314187186, 49.11750718525478, 54.60280425207955, 47.5617082459586, 47.405773299080984, 42.90623801095145, 48.915377140045166, 50.60830225263323, 54.258600916181294, 50.291068349565776, 51.305623463221956, 46.021806785038535, 53.133374895368306, 49.930394308907644, 54.33256796428135, 46.594776085444856, 25.02757808140346, 0.8091774912817138, 0.15502889906721457, 0.7998854156051363, 12.853479521615164, 51.59502983093262, 53.44483137130737, 62.623961039951865, 49.84287132535662, 55.80850430897304, 31.365356581551687, 3.1572890153953006, 22.143545866012573, 14.442892108644758, 24.1580388205392, 31.07091624396188, 38.132676192692344, 27.470364945275442, 25.75120517185756, 35.13702637808663, 33.82519258771624, 54.26195689610073, 19.672756024769374, 0.2119956865374531, 0.021968052988605838, 0.09976308353777442, 0.11455849212195192, 0.007898457198669868, 0.055147227964230945, 0.020620674127712846, 0.05762058988745723, 0.024074089979486804, 0.12747883025024617, 0.041014117055705616, 0.052976736931928566, 0.025906875829345415, 0.04134997831923621, 0.058577656745910645, 0.05545276549777814, 0.042851087770291736, 0.01972563554798918, 0.00576830846590123, 0.11934398247727326, 0.5631695719701904, 52.75609118597848, 62.503993443080354, 32.96535996028355, 25.000891787665232, 50.43059165137154, 35.05075059618269, 32.525500774383545, 27.8819797039032, 40.293496472494944, 45.41150828770229, 7.640981759343829, 22.577985457011632, 63.7599150793893, 50.53916767665318, 61.99736554282052, 56.90861259187971, 42.57513550349644, 2.6121687463351657, 0.11531459726393223, 0.26183919981122017, 0.5960839486547879, 30.58614390236991, 60.76475511278425, 58.22403860092163, 60.708127294267925, 56.91709981645857, 50.577480043683735, 58.31458405085972, 60.19204984392439, 57.16980232511248, 57.23831156321934, 58.899580683027, 59.32966027941023, 51.564172880990164, 50.48007672173636, 52.633226190294536, 57.346474170684814, 55.100434235164094, 57.63062422616141, 57.31894540786743, 58.70259230477469, 56.8843286378043, 52.43984740121024, 52.86400365829468, 51.340927260262625, 52.68784250531878, 54.44899197987148, 51.10637692042759, 52.241493701934814, 50.658582891736714, 50.18173497063773, 47.80190747124808, 40.05497176306588, 38.200980458940776, 32.82054907935006, 36.643503529684885, 45.01826804024832, 39.81944520132882, 24.0984719140189, 11.167368854795184, 19.85828161239624, 33.57484551838466, 43.51383018493652, 45.67129101072039, 50.18559122085571, 46.8180182320731, 41.63652767453875, 35.08172566550118, 20.896835803985596, 13.451316424778529, 9.447654962539673, 2.7302090866225104, 4.597576541560037, 4.247945359774998, 27.29795060838972, 14.287506937980652, 2.3106130191258023, 3.3526397900921956, 3.619127090488161, 2.33502442921911, 2.1018168287617818, 2.3865603038242886, 8.979857070105416, 17.111471108027867, 26.820555516651698, 35.8208715575082, 42.428914138248985, 40.33356325966971, 40.614756856645855, 33.740973472595215, 31.096082619258336, 19.26894235610962, 6.891088741166251, 1.0951709364141737, 3.463041454553604, 9.466729504721505, 22.010340213775635, 21.89854196139744, 22.575899260384695, 42.025213377816335, 41.287318161555696, 43.97652115140642, 43.311026164463584, 44.24358558654785, 44.577686241694856, 46.045003346034456, 45.7345404624939, 50.64100742340088, 41.51417684555054, 40.96597787312099, 50.0573969568525, 47.53969635282244, 47.205672127859934, 48.42317022596087, 46.99589211600167, 45.6765125819615, 48.79205008915493, 52.23516389301845, 54.83639921460833, 51.410343238285606, 47.6142018863133, 46.48566157477242, 49.58424547740391, 53.94237102781023, 53.44925389971052, 54.07495307922363, 51.99002449853079, 48.61012887954712, 52.234215463910786, 51.13758128029959, 52.65514428274972, 47.16134262084961, 23.078960997717722, 0.5016533700483186, 1.080686330795288, 0.96133853495121, 17.661391496658325, 59.28212070465088, 55.9988363129752, 65.52632086617606, 54.7325827053615, 64.00262260437012, 32.65042591094971, 4.333341760294778, 28.008912869862147, 21.025618927819387, 26.92142425264631, 31.523365565708705, 28.484473637172155, 32.92903477805001, 34.98115743909563, 31.43917771748134, 39.92139264515468, 64.81989751543317, 24.545661449432373, 0.4138890994446618, 0.0650823919900826, 0.0797817132302693, 0.05446347501128912, 0.03637514955231121, 0.044616038777998517, 0.035227743443101645, 0.03324190553809915, 0.11592541448771954, 0.18502558874232428, 0.14835117810538836, 0.15045329316386155, 0.12137145868369512, 0.08620507855500494, 0.12017364081527505, 0.11461320918585573, 0.10467227761234556, 0.11745320393570832, 0.0917195597929614, 0.24147332406469754, 1.4369582533836365, 70.15244538443429, 67.38154547555106, 49.162270954677034, 31.974776131766184, 55.36918708256313, 56.74877623149327, 45.76270498548235, 27.73603800364903, 37.01075404030936, 49.617572511945454, 11.819808176585607, 27.222670350755962, 68.19923727852958, 54.109374455043245, 62.87959221431187, 63.76189531598772, 47.608817032405305, 3.923712883676801, 0.4007661779011999, 0.26480244366186007, 0.813226499727794, 36.82139825820923, 63.66289043426514, 62.358783040727886, 64.13718141828264, 59.13976601191929, 52.0761022567749, 60.86719240461077, 62.41976737976074, 58.639655521937776, 59.59873621804373, 61.954154695783345, 61.7280672618321, 52.53400591441563, 53.386546407427105, 52.83513389314924, 60.539883613586426, 60.787670271737234, 61.16060093470982, 58.410364968436106, 62.775966780526296, 58.657269205365864, 53.39323057447161, 53.96089145115444, 54.912714753832134, 57.44646569660732, 55.27614722933088, 53.946790082114084, 56.15572663715908, 52.15916449683053, 57.28315871102469, 50.686580657958984, 44.0895231791905, 42.85071843011038, 40.03120197568621, 41.919916902269634, 47.829054083142964, 50.17496395111084, 40.72680698122297, 35.71199328558785, 40.897791726248606, 46.595700195857454, 46.59536320822579, 47.54550504684448, 50.80326523099627, 52.75911365236555, 50.80015591212681, 46.99610751015799, 37.191011156354634, 28.834758383887156, 24.421962669917516, 21.907609360558645, 19.216082198279246, 26.584111792700632, 35.49801656178066, 29.7122620173863, 23.846519810812815, 10.77882124696459, 10.618961436407906, 9.9612831728799, 10.934096114976064, 15.949593339647565, 24.440014089856827, 30.20243658338274, 40.01081943511963, 43.583906241825645, 44.371908392224995, 42.811419418879915, 38.9066846711295, 37.75731366021292, 31.275016103472026, 28.01439152445112, 16.869366339274816, 5.660978359835489, 6.837398273604257, 17.258910145078385, 29.182993412017822, 28.458602019718715, 33.83668838228498, 47.076744828905376, 45.97357586451939, 46.788307734898154, 47.403681891305105, 45.16542741230556, 48.922999313899446, 49.21105078288487, 49.03387866701399, 49.88983072553362, 43.85148136956351, 39.414632729121614, 48.153934478759766, 49.07678031921387, 49.28286388942173, 50.150349957602366, 52.78453711100987, 46.40577466147286, 55.1037346294948, 54.53227308818272, 58.71256296975272, 53.51329892022269, 50.319760935647146, 47.70069306237357, 53.5576353754316, 56.065299306597026, 56.054887431008474, 54.21129758017403, 54.63573176520211, 48.42566810335432, 54.693568570273264, 53.20126574380057, 56.763471671513145, 48.420964172908235, 31.734997272491455, 1.6642842037337167, 1.0504242117915834, 1.3403698248522622, 19.360114880970546, 64.2182252066476, 61.60737705230713, 72.49900490897042, 59.76049028124128, 66.51029695783342, 40.67601564952305, 8.105411512511116, 28.67269859995161, 21.4322327205113, 35.46082285472325, 41.12364639554705, 50.18593863078526, 42.910368715013774, 35.81116492407662, 48.01411935261318, 45.93171296800886, 72.94416209629604, 39.2058185168675, 0.3367619237729481, 0.18606476512338432, 0.22437523225588457, 0.27691434802753584, 0.15900881907769612, 0.11092767837856497, 0.1679374035447836, 0.09487438122076647], [0.07072544204337256, 0.02066564742874886, 0.04722303817314761, 0.1252232848533562, 0.025040825961955955, 0.035629398854715486, 0.03307829378172755, 0.02455748341578458, 0.11009269354066678, 0.13797977034534725, 0.022493712371215224, 0.07640391162463597, 0.05152572711397495, 39.95718976429531, 55.82637160164969, 35.975889342171804, 43.3763496535165, 23.64074543544224, 40.09289155687605, 35.503036635262625, 35.42474780763899, 18.14470645359584, 39.00156579698835, 4.526562477861132, 13.322218894958496, 60.474084172930034, 50.9780923298427, 46.628099645887104, 48.94174207959856, 46.61788579395839, 3.8489902189799716, 0.35142216139606064, 1.071635759302548, 0.08999610798699514, 23.107412133898052, 68.06957694462368, 60.16696684701102, 58.297283036368235, 55.94997310638428, 50.718507630484446, 56.03569998059954, 61.54726818629673, 58.94989953722273, 58.74913133893694, 59.2515138898577, 54.72241401672363, 51.22630282810756, 51.37983022417341, 54.00538076673235, 53.63583040237427, 56.72059086390904, 56.273272786821636, 58.04295117514474, 56.02595165797642, 55.90715830666678, 54.58300188609532, 55.18494517462594, 51.16719797679356, 52.9948729787554, 50.74569245747158, 53.92851284572056, 50.148206438337056, 47.54729420798165, 45.05567019326346, 41.116878850119456, 33.49629960741316, 28.892166137695312, 26.615821634020122, 27.410591329847062, 37.27630724225725, 43.663973808288574, 40.359570366995676, 34.01356519971575, 39.06943580082485, 41.38882439477103, 41.51143230710711, 39.86968067714146, 47.64577102661133, 43.260255677359446, 31.022407395499094, 18.569013833999634, 10.813352056912013, 3.934502133301326, 0.375288545020989, 1.5499179405825478, 2.4299602721418654, 8.779799325125557, 26.97325955118452, 34.87740693773542, 18.418178864887782, 2.068651774099895, 2.8072693858827864, 2.1140245965548923, 0.8820937871932983, 0.2714032323232719, 4.417064947741372, 8.598789198057991, 16.751193114689418, 27.49669861793518, 38.9999885559082, 42.19128574643816, 39.40599611827305, 33.82074921471732, 25.977395091738018, 22.161223820277623, 18.667115449905396, 9.851202862603323, 10.548027276992798, 14.514313510486058, 20.482926402773174, 17.060231617518834, 14.921317270823888, 30.68719850267683, 39.03412505558559, 43.080012457711355, 40.0051531791687, 41.136667319706504, 43.87212099347796, 44.013249329158235, 45.404000759124756, 48.839638301304404, 50.5195563861302, 48.87782212666103, 38.34436001096453, 40.469195570264546, 45.67934397288731, 46.46499415806362, 46.812157426561626, 46.204888343811035, 51.14622483934675, 51.121256487710134, 50.24883719852993, 49.272274834769114, 46.16062484468733, 44.27516862324306, 48.432585035051616, 51.63852902821132, 53.59111179624285, 52.30820683070591, 49.012412207467214, 52.98959582192557, 48.11557347433907, 49.02827147075108, 52.05393402917044, 30.692340169634136, 5.7851457084928235, 0.19981359450944833, 0.18635527310626848, 1.4919711585555757, 29.132648502077373, 52.918008531842915, 46.00318561281477, 52.04707268306187, 50.98826796667916, 58.203461510794504, 17.40887658936637, 7.196728706359863, 27.00563815661839, 12.033089212008885, 28.949830974851334, 30.60295854296003, 40.385587896619526, 28.0247061252594, 24.399573837007793, 25.82921086038862, 39.820848737444194, 60.06342479160854, 16.014948095594132, 0.27707404802952496, 0.11816854269376822, 0.03807763123352613, 0.08072263774062906, 0.04022908257320523, 0.06015195298407759, 0.1169321026120867, 0.04298221805532064, 0.07997114663677556, 0.03964805982208677, 0.026086914918518493, 0.012911932775750756, 0.059051219906125746, 0.04850649394627128, 0.03464535005124552, 0.004065841627639851, 0.05511508236772247, 0.07681380784405129, 0.07002873585692473, 0.06319620034524373, 0.06589731933282954, 45.2115877696446, 67.0899156842913, 40.00837019511631, 36.35100521360125, 31.755939143044607, 35.538528033665244, 31.243936811174663, 37.74106877190726, 22.79582190513611, 48.860416889190674, 5.639807198728834, 14.538058110645839, 62.513178961617605, 55.64661128180367, 50.06112119129726, 57.012856415339876, 52.25783586502075, 6.314190668719156, 0.2752779115523611, 1.4501175986868995, 0.18353669292160443, 26.484754289899552, 71.26077338627407, 64.36461680276054, 60.148706981113975, 61.00901208605085, 53.81859234401158, 59.6275087084089, 62.78455475398472, 61.3066520690918, 61.03581823621477, 60.03013597215925, 55.65247556141445, 53.33034242902483, 53.78523056847708, 55.66669157573155, 55.90470906666347, 58.51483808244978, 57.61385127476284, 58.054391384124756, 57.32486874716622, 57.81695754187447, 56.294075693402974, 58.28276824951172, 54.68705463409424, 55.049080099378315, 53.75352593830654, 53.292064802987234, 52.001200675964355, 49.74486698423113, 48.84154210771833, 44.5161634172712, 38.394324507032124, 33.60574068341936, 32.39193902696882, 34.186318261282786, 42.04258387429373, 48.11818599700928, 42.39637919834682, 32.82457208633423, 38.29950591496059, 44.97120441709246, 45.30403355189732, 46.68720102310181, 48.25011839185442, 48.7891457421439, 44.63592256818499, 31.823062215532573, 22.591881854193552, 13.964149066380092, 8.013433865138463, 5.8547071644238065, 4.006332176072257, 15.191411120550972, 33.8595757484436, 26.253881284168788, 10.332248364176069, 1.6392310623611723, 1.355413977588926, 2.1813016150678908, 1.826801700251443, 4.6736719097409924, 10.257380655833654, 18.64473877634321, 26.87394894872393, 35.76750939232962, 44.98672669274466, 44.683521202632356, 44.00744758333479, 38.15322549002511, 31.69951629638672, 25.5257865020207, 19.04552824156625, 7.281818083354405, 10.196351153509957, 17.352304356438772, 27.297391278403147, 21.81524521963937, 21.051341159003123, 36.203022480010986, 41.065941606249126, 44.766701562064036, 41.43894522530692, 43.5974691254752, 46.37932286943708, 47.585227898189, 45.663613251277376, 49.967740876334055, 48.85511541366577, 48.34910242898123, 40.53675985336304, 44.19010877609253, 47.925679206848145, 47.99718311854771, 48.35864577974592, 52.00492491040911, 52.04207692827497, 54.26867233003889, 51.58275236402239, 51.703383513859336, 47.69799368722098, 47.22451911653791, 48.19578000477382, 52.990766593388145, 53.871277059827534, 52.481178760528564, 49.26648351124355, 52.88153396333967, 47.22361932482038, 50.40872567040579, 50.32201215199062, 32.49445274897984, 5.758458980492183, 0.14261025616100856, 0.22864928362624987, 3.5909304320812225, 36.0684289251055, 57.52696405138288, 50.32493039539882, 58.0957088470459, 53.86860547746931, 62.62742819104876, 17.225192274366105, 11.808984620230538, 38.00811236245291, 16.571696826389857, 29.91283914021083, 28.087264231273107, 30.16447162628174, 39.519345555986675, 26.553072452545166, 27.0430611542293, 47.464256286621094, 65.3023178918021, 16.70692961556571, 0.42014448664018084, 0.08900378444897276, 0.04570672953767436, 0.020745680634198443, 0.030749517492949963, 0.05675657732146127, 0.03245462171201195, 0.1003968556012426, 0.1579389457723924, 0.1575306033981698, 0.10207728828702654, 0.2486754847424371, 0.20044018088706902, 0.22567295762045042, 0.1003611171618104, 0.09757839076753173, 0.17147476944540227, 0.20951116271317005, 0.13327319361269474, 0.16164746534611496, 0.3393635627414499, 58.539413860866, 76.47357600075858, 47.865705830710276, 55.237313747406006, 36.39829465321132, 56.735456534794395, 46.94939477103097, 41.92686857495989, 27.041160821914673, 49.00295570918492, 9.064155220985413, 21.68260931968689, 71.30879933493478, 58.84634358542306, 54.23254517146519, 60.72055762154715, 56.612146854400635, 6.620462485722133, 0.5607917138508388, 2.681877851486206, 0.21557749648179325, 31.276638507843018, 69.46719319479806, 65.4884740284511, 64.45155961172921, 61.422673089163645, 56.81778226579939, 60.657655579703196, 66.37622451782227, 62.031286648341585, 64.81456129891532, 65.58137144361223, 59.13996056147984, 55.348078455243794, 56.42156818934849, 57.8619054385594, 59.4697915485927, 62.613441467285156, 60.81499753679548, 60.481546538216726, 60.33050659724644, 58.40422970908028, 58.51736027853829, 60.447125162397114, 54.926427023751394, 57.3527866091047, 58.037653173719136, 56.55108608518328, 52.86825248173305, 53.04255499158587, 52.83681188310896, 48.57136835370745, 42.41815137863159, 39.81675624847412, 38.25572878973824, 38.819953782217844, 41.091959135872976, 48.432216780526296, 48.20324584415981, 45.547206606183735, 45.15677343096052, 47.72408069883074, 49.028653621673584, 50.58304902485439, 53.8067387172154, 53.60327809197562, 54.39658866609846, 43.08469901766096, 40.057361943381174, 37.52478872026716, 23.966756650379725, 18.43333809716361, 16.12781810760498, 30.38083505630493, 41.79785442352295, 41.23088836669922, 32.07912070410592, 19.390959671565465, 17.358184269496373, 18.152431113379343, 17.342627252851212, 18.334807429994854, 26.14855354172843, 32.629244327545166, 42.28551721572876, 42.15083680834089, 48.49357284818377, 45.42952149254935, 45.17810787473406, 40.22510882786342, 35.09797750200544, 28.11053201130458, 25.144821984427317, 18.718650238854543, 14.124315466199603, 23.380731684820994, 32.18822479248047, 27.741910968508037, 31.177623203822545, 40.065293312072754, 43.586515290396555, 46.52238975252424, 43.90747342790876, 45.28334181649344, 48.826513154166086, 50.17690944671631, 46.43669414520264, 50.72862420763288, 45.75957134791783, 50.8349073273795, 46.74403728757586, 45.42992796216692, 50.07543100629534, 50.96460935047695, 51.54171282904488, 53.42365326200213, 55.34505251475743, 58.39874063219343, 54.999872956957134, 53.42396593093872, 51.51565361022949, 50.5152519771031, 51.8826470375061, 55.416893414088655, 57.951769965035574, 55.48625380652291, 49.57592153549194, 54.73809610094343, 48.97592374256679, 50.024337427956716, 52.99549831662859, 39.935431480407715, 10.16728162765503, 0.4262298329600266, 1.0845864415168762, 4.319388040474482, 38.197655745915, 63.38718591417585, 56.05874020712716, 62.48548344203404, 61.60183238983154, 68.11412879398891, 25.676381758281163, 13.116066711289541, 37.1503780909947, 19.166213239942277, 40.007470403398784, 39.896670954568044, 54.498629910605295, 43.0440103667123, 32.67776359830584, 38.961349623543875, 53.023027079445974, 79.21707221439907, 28.043408938816615, 0.5919277316757611, 0.3115940828408514, 0.1664324535855225, 0.2667291574180126, 0.17014897987246513, 0.23373883909412793, 0.24849789855735643, 0.21263474438871655], [0.048937356897762845, 0.07790823733167988, 0.023398041791681732, 0.10287350163395916, 0.01241529094321387, 0.015143888902717402, 0.006286861466443432, 0.028911440766283443, 0.07008253011320319, 0.036304364779165814, 0.03918952281985964, 0.027240673811840158, 0.1399747175829751, 22.09562587738037, 66.07686138153076, 34.22919906888689, 39.2457845551627, 36.028310026441304, 46.06944016047886, 35.647625173841206, 32.473184313092915, 28.54993087904794, 28.68276306561061, 12.595505935805184, 1.4069312874759947, 42.68710224969046, 60.78652381896973, 59.710414613996235, 37.547311305999756, 56.329337801252095, 21.17380837031773, 0.0738816408972655, 0.18034004659524985, 0.15571620075830392, 6.678540306431906, 54.50931971413748, 54.89636216844831, 61.999192919049946, 54.9432555607387, 56.94450351170131, 53.68371738706316, 58.54270730699812, 54.33412436076573, 56.109597546713694, 56.686405726841514, 54.31739657265799, 48.816750935145784, 54.5345972606114, 54.192384583609446, 55.459211417606895, 57.39756774902344, 56.9734844480242, 56.3374011857169, 59.395292963300435, 54.54193108422415, 57.577241216387065, 53.52908175332205, 51.47993292127337, 50.61483703340803, 51.37772144590105, 49.667495318821494, 51.86138554981777, 47.094261237553184, 45.680678027016775, 37.66795982633318, 31.874305180140905, 27.555358784539358, 28.99409099987575, 32.135571343558176, 36.084580012730186, 41.02292530877249, 39.956672123500276, 33.38360677446638, 38.42991665431431, 43.78017895562308, 42.101952757154194, 43.28355993543352, 46.03708587374006, 41.854523931230815, 31.530119214739116, 20.543639762060984, 8.507883310317993, 2.6962341325623647, 2.992056727409363, 2.5761924939496175, 3.5527750509125844, 6.450701492173331, 26.447477204459055, 36.50664833613804, 24.448803561074392, 8.415825758661542, 1.7682096042803355, 4.544811921460288, 2.1109508872032166, 2.356048592499324, 2.4914642061506, 8.745004483631678, 16.211272920880997, 27.39126317841666, 35.56199904850551, 40.745768615177695, 43.18510396139962, 36.44328771318708, 29.96976225716727, 22.891849483762467, 24.34499400002616, 22.184675727571758, 17.42192530632019, 18.627019132886613, 19.40961732183184, 16.47436124937875, 18.984919105257305, 26.189869267599924, 33.02742821829659, 39.38184417997088, 41.07830592564174, 40.891211782182964, 43.489633083343506, 43.805063928876606, 46.59401178359985, 47.140362535204204, 53.53443534033639, 43.34199775968279, 40.171642439705984, 54.514037540980745, 48.551256792885916, 54.06685495376587, 52.20601619992937, 53.91227490561349, 46.33616413388933, 48.71648842947823, 46.192239148276194, 48.072195870535715, 43.7088418006897, 46.106463636670796, 46.12642928532192, 53.58579989842006, 48.85139117922102, 54.386663164411274, 47.951609883989605, 45.34427056993757, 45.744038649967735, 52.765394823891775, 38.754196030753, 14.18590690408434, 0.7962844031197684, 0.07094017123537404, 1.2455405933516366, 9.502233930996486, 50.16004964283535, 48.741290024348665, 53.546612058367046, 55.842748505728586, 49.226698126111714, 51.99165037700108, 5.764190810067313, 13.061664921896798, 16.02628755569458, 17.954502991267614, 32.62863983426775, 27.830863543919154, 40.81628588267735, 23.147329534803117, 33.68109737123762, 37.264061042240684, 45.000185353415354, 55.55858107975551, 6.863750619547708, 0.16237651051155158, 0.11291687842458487, 0.01294222766799586, 0.08749116025865078, 0.08169478164719683, 0.04305313514279468, 0.017787568204637085, 0.020571083395874927, 0.05544855858066252, 0.06833356539053576, 0.05426888134596603, 0.07233888975211553, 0.04369557549112609, 0.00886485306546092, 0.031010746689779416, 0.07564718223043851, 0.022516660425545912, 0.05189391717846904, 0.030563256237655878, 0.08844908885657787, 0.1307224990533931, 26.2333893094744, 76.93645109449113, 39.47973040172032, 34.97122846330915, 41.620369638715474, 46.916286604745046, 25.376297746385845, 36.171481132507324, 27.461511203220912, 40.256486892700195, 16.8456642968314, 2.4012824509825026, 47.7531623840332, 62.49853910718645, 58.78162806374686, 43.620154993874685, 59.166190011160715, 27.009786231177195, 0.1674743848187583, 0.764357430594308, 0.3899785296193191, 6.2597233057022095, 57.43592527934483, 58.87581784384591, 64.96678243364606, 57.876402854919434, 59.750554357256206, 56.45518010003226, 61.04831804547991, 56.786230495997835, 57.94041313443865, 59.31691728319441, 57.51206016540527, 51.6024991444179, 56.148580414908274, 57.168075697762625, 59.28575461251395, 59.01884651184082, 58.33129446847098, 57.39386783327375, 59.29252910614014, 56.02067102704729, 57.13230984551566, 55.37576355252947, 51.8833383832659, 50.96940360750471, 52.64029598236084, 51.63835532324654, 53.25368642807007, 51.786119188581196, 48.139072281973704, 42.93742152622768, 37.71015623637608, 33.06069966724941, 35.60421282904488, 37.33926486968994, 40.72091143471854, 48.450129236493794, 47.405585697719026, 41.90263325827462, 47.05218989508492, 48.421478339603965, 44.892766203199116, 46.29527745928083, 49.85325540815081, 48.9550131389073, 43.18375948497227, 31.160787718636648, 23.993637493678502, 16.036789757864817, 9.28991608960288, 6.006762410913195, 4.448630179677691, 18.220533881868633, 36.38957118988037, 37.463119983673096, 26.24086036000933, 10.04818516118186, 3.6657193217958723, 2.622054947274072, 5.879170034612928, 8.702621340751648, 15.013144663402013, 21.535526377814158, 27.291982105800084, 37.61734914779663, 43.38611882073538, 45.033234460013254, 44.9236717905317, 39.784645148685996, 34.02397360120501, 27.97465651375907, 27.030818428312028, 20.33283315386091, 17.519780261175974, 22.765906436102732, 24.8392801625388, 24.084379230226787, 27.537920543125697, 32.2796630859375, 37.52862065179007, 42.11247927801949, 43.25285931995937, 44.45980657849993, 44.91874204363142, 44.696288517543245, 48.88600710460118, 49.0466251373291, 50.165260791778564, 44.97985145023891, 44.66468811035156, 54.01059191567557, 51.114072050367085, 54.91348947797503, 51.69513600213187, 53.388912269047324, 49.54096514838082, 50.61907890864781, 49.19805070332119, 50.15115942273821, 44.845171042851035, 47.051574979509624, 47.99524804524013, 53.940863268715994, 52.495620591299875, 55.7592658996582, 49.341982637132915, 46.95814602715628, 47.30781412124634, 52.66474321910313, 38.80418137141636, 15.370084047317505, 0.6119862039174352, 0.08330272643693856, 3.214130708149501, 14.940120833260671, 56.46046073096139, 51.180812971932546, 59.266765185764854, 58.05934892381941, 55.667494092668804, 52.81690876824515, 6.710729573454175, 18.746258905955724, 22.97757809502738, 22.41293273653303, 33.52081980024065, 26.265757492610387, 35.480218751089915, 35.623174462999614, 32.8722436768668, 41.52126053401402, 51.92216839109148, 62.955633299691335, 8.076777986117772, 0.21164292975195817, 0.11964435635932855, 0.0527238978206047, 0.04730772612882512, 0.07668852313820805, 0.010891816129774919, 0.04653239469709141, 0.0242497779628528, 0.21707719458001, 0.14999062727604592, 0.2050090150109359, 0.18422670875276836, 0.13304117534841808, 0.0732136367421065, 0.15927473695150443, 0.205527076497674, 0.1727852105562176, 0.12580884700374945, 0.14333764570099966, 0.11366025424961533, 0.20850523454802378, 40.4292642729623, 89.83501052856445, 45.444550446101594, 55.62819160733904, 45.96771158490862, 68.38897173745292, 47.598818574632915, 38.67992326191494, 36.15967961720058, 37.385008335113525, 19.38647982052394, 5.0871587736266, 52.12461110523769, 69.5083612714495, 65.85690225873674, 48.22770697729928, 64.37640789576939, 28.081690038953507, 0.23464989449296678, 3.641756070511682, 0.39826322506581036, 9.749647991997854, 66.53819397517613, 59.83850465502058, 68.65573392595563, 58.65314892360142, 62.225044114249094, 59.49074036734444, 65.84530571528843, 57.71284573418753, 61.25219208853585, 61.32375853402274, 59.88282026563372, 53.981767313820974, 59.55704007829939, 60.60721860613142, 60.85148252759661, 63.055763789585654, 61.115604400634766, 60.960784639631, 62.10824489593506, 57.38801397596087, 62.61285087040493, 58.35413319723946, 56.69608804157802, 55.71274076189314, 56.29778950554984, 53.978175095149446, 56.39027350289481, 52.04555450166975, 51.908348424094065, 46.77499498639788, 42.145865372249055, 37.92563377107893, 40.996223381587434, 42.21911675589425, 44.576081207820344, 48.80899327141898, 45.70452077048165, 41.67335660117013, 45.9681840624128, 48.94507026672363, 46.58209909711565, 48.35682882581438, 53.199695450919016, 54.380111013139995, 52.277474948338096, 45.12470402036394, 37.57274171284267, 30.221238408769878, 19.48487673486982, 15.544478620801653, 15.143136773790632, 25.07188674381801, 45.914953913007466, 46.44659880229405, 43.29393707002912, 33.50278227669852, 30.135553223746165, 33.00593744005476, 29.865348202841624, 33.34696544919695, 29.615727220262798, 34.14277042661394, 38.63882466724941, 45.75661836351667, 48.458411489214214, 46.08954477310181, 45.131857190813335, 42.52788427897862, 36.81147623062134, 33.29400627953665, 28.200931549072266, 30.781297956194194, 22.690641811915807, 25.83071861948286, 30.827691078186035, 31.58384963444301, 36.07605804715838, 38.50680889402117, 39.77053683144705, 44.53208174024309, 45.251105649130686, 45.17798975535801, 47.075139795030864, 46.81768124444144, 51.16314022881644, 51.37511934552874, 51.932802609034944, 48.50041682379586, 46.08536890574864, 57.50372232709612, 52.38138178416661, 59.1771890095302, 55.6043175969805, 58.54804352351597, 52.252589975084575, 53.90218959535871, 51.840954371861045, 53.47196408680507, 48.24619265965053, 48.94268356050764, 48.984098298209055, 56.19881589072091, 53.210944584437776, 57.51177181516375, 49.56861203057425, 46.49115065165928, 48.369168826511924, 53.260860443115234, 42.99614770071847, 23.954458338873728, 1.8220287220818656, 0.15998247611735547, 2.919332104069846, 13.179093820708138, 61.12533187866211, 59.22929355076381, 63.71930285862514, 66.58822795322963, 58.854542459760395, 61.64510577065604, 10.48909786769322, 19.40303216661726, 27.284749031066895, 28.883367981229508, 45.26499857221331, 38.261975220271516, 57.750254835401265, 36.734570094517295, 45.96954938343593, 51.531835964747835, 57.43777697426932, 76.5648614338466, 16.292945521218435, 0.48990364053419655, 0.35195527278951233, 0.07339445953922612, 0.24951035422938211, 0.20499810416783604, 0.16472302031304153, 0.19696581017758164, 0.11556664588195936], [0.04519707849249244, 0.025052218564919064, 0.03633614396676421, 0.05797361130160945, 0.08054889884910413, 0.0663644296250173, 0.1853819689048188, 0.039211992507002184, 0.021298927554328526, 0.02036155347845384, 0.10065570992550679, 0.026135140098631382, 0.09014862908848695, 9.747889229229518, 66.13013322012765, 39.89064686638968, 28.16764794077192, 50.70502812521798, 47.66094936643328, 39.677378858838765, 35.02556337629046, 36.40506567273821, 17.491553204400198, 22.15966742379325, 3.3509919813701083, 22.22674707004002, 52.52852725982666, 66.01923302241734, 69.63501303536552, 50.947308335985454, 53.47359343937465, 6.762610469545637, 2.1550569662026, 0.7122520208358765, 1.0017022490501404, 25.21171750341143, 59.19230828966413, 58.74203027997698, 59.33125836508614, 57.35230370930263, 57.5304833139692, 60.774413108825684, 59.684859139578684, 57.780319690704346, 58.22941303253174, 54.67906420571463, 56.03685685566494, 53.77820246560233, 54.602533272334504, 52.88208287102835, 55.89347382954189, 57.907075677599224, 57.83309473310198, 56.44127675465175, 56.43489830834525, 56.39300414494106, 54.299400738307405, 52.60348442622593, 49.20645802361624, 48.84836176463536, 51.77048921585083, 50.1383330481393, 47.432864325387136, 39.291135447365896, 35.0738707269941, 30.0116286277771, 28.79601001739502, 31.52615179334368, 32.31615849903652, 37.97916269302368, 36.920816557747976, 32.240982464381624, 27.511176926749094, 34.96535723549979, 42.60302209854126, 43.869890621730256, 44.46163395472935, 46.247067383357454, 38.65983254568917, 23.847077403749736, 11.863241365977697, 6.729243048599788, 3.226102237190519, 3.547562816313335, 1.6277664261204856, 4.115080169269016, 7.319717901093619, 25.64002878325326, 41.67254018783569, 28.260479348046438, 16.210376603262766, 12.573265620640345, 13.46028915473393, 9.924350891794477, 9.000955275126866, 8.063831755093165, 10.687157137053353, 13.41368671825954, 18.996897799628123, 28.44908993584769, 39.733398709978374, 45.1078268459865, 40.69492169788906, 32.80227531705584, 28.49024932725089, 24.09964963368007, 21.66639917237418, 17.049279519489833, 13.570944428443909, 21.27316587311881, 26.5026650088174, 23.92353364399501, 30.197614533560618, 35.79293632507324, 36.06330462864467, 37.35392904281616, 42.26645483289446, 45.29807547160557, 47.948121888296946, 46.03867353711809, 50.03817823954991, 37.321953432900564, 41.779705728803364, 50.83571331841605, 49.065621512276785, 48.1012601852417, 46.833432810647146, 47.67239652361189, 48.81959622246878, 48.936138357434956, 48.765362058367046, 47.96340445109776, 46.3228930745806, 45.75907802581787, 44.94595466341291, 46.86047172546387, 50.11455283846174, 51.58117512294224, 51.43454728807722, 51.21799625669207, 49.44489588056292, 46.084687982286724, 46.457399777003694, 23.574284178870066, 4.1814241749899725, 0.2942450823528426, 8.71771456514086, 24.984685114451818, 44.604544503348215, 45.511256626674104, 47.04462330681937, 48.782416411808555, 45.745025294167654, 57.18772520337786, 25.124154567718506, 2.3466357375894273, 23.08859814916338, 15.214696271078926, 22.383552278791154, 22.386479207447596, 31.628498758588517, 34.94314384460449, 32.11499425343105, 29.58707979747227, 25.252932480403356, 49.06540959221976, 46.68848991394043, 1.2876753381320407, 0.06258663841124092, 0.05387850318636213, 0.08183936388897044, 0.04110372778294342, 0.11289274293397154, 0.0518126626099859, 0.08167116862854787, 0.06843322182872466, 0.03178271258782063, 0.06160856410861015, 0.003257455362472683, 0.054750573355704546, 0.10577655264309474, 0.04812822424407516, 0.08500914701393672, 0.10586984442280871, 0.06101541593670845, 0.176392099154847, 0.16608197667769023, 0.03349685489333101, 0.08547004871070385, 14.310630542891365, 78.866334097726, 46.09285906382969, 30.42771107809884, 55.97991984231131, 52.67180953707014, 25.991979360580444, 39.35178974696568, 37.78666632516043, 25.58090829849243, 39.5971097946167, 4.807866811752319, 25.896710872650146, 56.59113550186157, 65.01847008296421, 74.68621444702148, 56.576808316367014, 62.73410388401577, 10.804301159722463, 1.0944169483014514, 0.4016394524702004, 0.7716478822486741, 29.112912143979752, 61.66229561397007, 64.94849477495465, 61.8537323815482, 59.3245325088501, 60.06702395847866, 63.07221712384905, 62.46046992710659, 60.85066958836147, 58.96071788242885, 57.07357324872698, 59.065600940159385, 56.37369510105678, 58.045205865587505, 57.19127573285784, 58.79971422467913, 60.0535375050136, 59.301909174237935, 57.93663331440517, 58.09045253481184, 58.77700056348528, 56.21707575661795, 53.795642444065635, 51.51164449964251, 51.91433777127947, 54.86227778026036, 52.12353760855538, 50.005334104810444, 47.39266552243914, 41.588529518672395, 37.930052825382774, 35.94589049475533, 35.97494438716343, 37.792176246643066, 44.363605294908794, 41.788787024361746, 42.05015046255929, 36.77927133015224, 42.44261251177107, 48.36512150083269, 48.1538302557809, 46.957326139722554, 49.040625367845806, 47.07752650124686, 39.57571281705584, 29.610658509390696, 21.755843332835607, 15.0111175264631, 8.59978105340685, 6.501150190830231, 6.631563101496015, 16.52158989225115, 36.39896168027605, 44.42143167768206, 34.05671003886631, 11.907245176179067, 9.500453455107552, 9.55757372719901, 8.99129033088684, 11.196133528436933, 14.47027930191585, 20.627365555082047, 28.61309174128941, 34.82173797062465, 41.20593391145979, 45.21587133407593, 46.664688859667095, 43.89493540355137, 38.22170346123831, 33.43149375915527, 31.35985013416835, 29.306709562029155, 23.03130156653268, 22.507223265511648, 29.37505899156843, 32.61775895527431, 30.370034081595286, 35.49631077902657, 39.770839078085764, 40.47123486655099, 41.724919182913645, 46.25488758087158, 47.12904739379883, 50.03088957922799, 47.86601502554757, 49.69952998842512, 39.44425637381417, 41.455193587711875, 52.43733562741961, 49.150472913469585, 49.82042516980852, 47.46131025041853, 48.90759515762329, 49.625983306339805, 50.383739948272705, 49.93561240604946, 49.4200109073094, 46.15082788467407, 47.67823301042829, 46.72336292266846, 49.34672130857195, 51.04370764323643, 55.03116069521223, 51.89590072631836, 53.08469929013933, 46.59384502683367, 47.92493574959891, 44.27069398335048, 26.412564243589127, 2.8607314314161028, 0.1361627485603094, 15.136862550462995, 34.300133228302, 51.516497816358296, 50.48510374341692, 54.95915651321411, 53.60040501185826, 51.052372046879356, 61.65161623273577, 18.74594623701913, 4.953571838991983, 30.364968844822474, 19.846024990081787, 26.26663817678179, 25.169922351837158, 26.911721093314036, 33.985640389578684, 41.19357654026577, 28.05444962637765, 30.574901717049734, 53.20197793415615, 55.18643208912441, 1.133202769926616, 0.04900750045531562, 0.06136103453380721, 0.099064463882574, 0.013026131915726831, 0.03206611291638442, 0.03014209633693099, 0.04284463829493948, 0.04178541798942855, 0.1372572255453893, 0.14796039621744836, 0.16060963246439183, 0.24314452867422784, 0.2370618964944567, 0.09193067239331347, 0.235636972955295, 0.14743033823158058, 0.10624112521431275, 0.2548386725996222, 0.2995882470692907, 0.28413406919155804, 0.16870557303939546, 21.692717211587087, 89.23476954868862, 51.34027065549578, 42.67595386505127, 64.01222501482282, 68.46063545772007, 55.60412999561855, 41.65647595269339, 42.114831243242534, 24.26004011290414, 31.313769681113108, 8.956898484911237, 30.225091184888566, 59.08768926348005, 68.00473635537284, 75.53574289594377, 61.015043122427805, 62.942820821489605, 8.102663499968392, 6.926011255809239, 1.6474777055638177, 2.3075508177280426, 38.564267022269114, 65.53901522500175, 68.42207295554024, 64.54378305162702, 62.26035485948835, 62.7718117577689, 65.5427325112479, 66.46531432015556, 65.00758920397077, 63.67539024353027, 60.2792705808367, 62.00435543060303, 57.86581380026681, 59.62262412479946, 59.82708876473563, 61.65484019688198, 64.86091273171562, 60.80830642155239, 59.477983474731445, 61.641589982169016, 60.539015088762554, 58.83881868634905, 56.73928846631731, 53.04797111238752, 55.26787887300764, 58.26536301204136, 54.16848972865513, 52.43013381958008, 49.555504253932405, 45.695119857788086, 44.32246501105172, 41.948946475982666, 42.20838873726981, 41.14218766348702, 46.93713467461722, 43.51922198704311, 45.54114777701241, 40.760596070970806, 46.683056422642295, 50.311829566955566, 52.352216720581055, 51.3164279120309, 54.601247855595176, 55.74668618610927, 49.668398584638325, 42.609080927712576, 32.687932286943706, 27.46282614980425, 22.96727739061628, 18.926390954426356, 22.04870469229562, 30.364572797502788, 45.810453006199424, 49.095641204289024, 43.15936088562012, 33.586139815194265, 33.67731755120413, 42.721520151410786, 37.04854876654488, 37.5855507169451, 35.78140231541225, 37.07330519812447, 38.673652512686594, 42.394093241010395, 47.00231919969831, 49.08781058447701, 49.10338149751936, 44.47632939474923, 41.529181480407715, 37.62489141736712, 35.53389358520508, 30.229437283107213, 25.452152967453003, 25.601957866123744, 33.09985276630947, 41.61524881635393, 39.4483836037772, 42.63140548978533, 43.50784083775112, 43.717172690800254, 43.334875856127056, 47.84750502450125, 47.83559233801705, 51.839179107121055, 50.02790880203247, 50.99317339488438, 44.37532690593174, 44.04255335671561, 52.71429777145386, 54.22459643227713, 53.1041716166905, 51.226174286433626, 51.96188082013811, 54.31055607114519, 51.34474182128906, 53.68051774161202, 51.260380268096924, 49.5671181678772, 49.46305499758039, 49.620925017765586, 52.439896038600374, 54.03185340336391, 56.389860085078645, 54.96051836013794, 54.256002289908274, 47.45733935492379, 46.173777784620015, 47.01415545599801, 33.76676171166556, 7.52860072680882, 0.4182736298867634, 11.666758469172887, 31.34361914225987, 54.332543645586284, 56.70406804765974, 57.32559483391898, 58.708095278058735, 56.48514768055507, 67.00618294307164, 34.49134417942592, 4.785572648048401, 34.7378488949367, 25.285611595426285, 36.2664213180542, 30.745653697422572, 43.73509209496634, 50.14821686063494, 46.318748474121094, 39.64103978020804, 39.71000412532261, 61.69491045815604, 71.40647711072648, 4.712560977254595, 0.2652140701455729, 0.2503152596099036, 0.1318589366440262, 0.10904373946998801, 0.1531065007937806, 0.16523805553359644, 0.1338961294719151, 0.13968260825744697], [0.02829768548586539, 0.09018852016223328, 0.0746318767113345, 0.03819784049742988, 0.0199857027535992, 0.02061847737058997, 0.08832669470991407, 0.03504394866260035, 0.04430954451007502, 0.023405047665749277, 0.02790519199334085, 0.025728916450004493, 0.09966071974486113, 4.973778937544141, 56.917165824345176, 53.138030188424246, 34.98257834570748, 39.31147629874093, 40.593707289014546, 42.15260165078299, 32.46341861997332, 20.641828230449132, 21.162845849990845, 7.682980145726885, 4.542703577450343, 7.795375943183899, 53.29097740990775, 55.65196486881801, 74.42566394805908, 51.23938628605434, 44.81633601869856, 47.19461406980242, 4.3651792747633795, 0.5418916908758027, 0.10682554064052445, 5.474790956292834, 44.169781821114675, 63.931445258004324, 59.81345639910017, 56.998244353703086, 59.346884863717214, 57.110176358904155, 51.28470591136387, 52.99501889092581, 58.087353638240266, 57.143395696367534, 59.329889569963726, 56.5206356048584, 55.3148695400783, 57.62728214263916, 57.61078017098563, 58.12064593178885, 57.71563196182251, 57.079708508082796, 55.52992670876639, 54.46958991459438, 52.32822459084647, 46.699735573359895, 47.92184380122593, 49.21991321018764, 49.59625891276768, 48.63286338533674, 41.893489428928916, 40.42943450382778, 35.99536166872297, 32.297829151153564, 32.32553856713431, 35.013487407139365, 37.93528829302107, 39.981678690229145, 37.809703077588765, 30.210083075932094, 29.544452599116735, 40.284741742270334, 47.97314929962158, 46.50352886744908, 46.52379328863961, 39.822822025844026, 25.27568088259016, 13.792175071580068, 9.017782075064522, 6.002747220652444, 3.1624484871115004, 3.569986173084804, 3.328564716236932, 6.314320078917912, 13.731661473001752, 27.012734004429408, 39.622411659785676, 36.1986277444022, 30.251984187534877, 21.19713694708688, 23.149127381188528, 22.44495872088841, 19.173864943640574, 10.87804673399244, 8.728746567453657, 13.770303010940552, 16.361425229481288, 18.296376943588257, 32.02306611197335, 43.43897724151611, 44.83235509055001, 39.93715810775757, 32.852583748953684, 27.42680495125907, 20.257799557277135, 15.732364858899798, 13.866737059184484, 21.726490667888097, 33.534483432769775, 35.55133008956909, 33.5624395098005, 36.76064668382917, 39.49168825149536, 38.80550152914864, 38.02702188491821, 38.29362079075405, 40.88920027869088, 46.813741615840364, 46.27278961454119, 46.21324355261666, 44.825535433632986, 44.89345407485962, 49.84487935474941, 46.765541962214876, 49.06612178257534, 52.29282004492623, 48.770712171282085, 47.308873721531455, 46.85067823954991, 45.36315924780709, 46.23593636921474, 44.97154140472412, 45.76590463093349, 46.322660309927805, 51.03272601536342, 49.2026504107884, 52.03340210233416, 54.82132509776524, 44.88073539733887, 49.78661176136562, 28.276081527982438, 9.535978725978307, 0.21491090367947305, 11.83631101676396, 40.55512046813965, 43.64961882999965, 47.371508257729666, 50.053492069244385, 50.07565334865025, 43.86396380833217, 47.312066418784006, 26.20652757372175, 1.1986781422580992, 24.058681317738124, 42.19696242468697, 12.38014565195356, 24.532965353557042, 25.222436836787633, 39.39275632585798, 36.11979348318917, 28.404225417545863, 27.588209867477417, 27.760196890149796, 53.00281824384417, 33.411993639809744, 0.14018971818898404, 0.0405722855856376, 0.12212736026516982, 0.04666270734742284, 0.011538728872048003, 0.08462956773915462, 0.03791044699028134, 0.009593072962681097, 0.034817789548209736, 0.013291602804591613, 0.10733133421412536, 0.06153868857238974, 0.07314508434917245, 0.008617861229660255, 0.03971321614725249, 0.06921195611357689, 0.07758457612778459, 0.009632975910790265, 0.021393115000267113, 0.06180560389267547, 0.026576523735587086, 0.20730247694466794, 6.627527500901904, 69.75825323377336, 60.92955943516323, 35.634058816092356, 42.19489533560616, 53.40075894764492, 29.588184561048234, 27.320818867002213, 26.241777522223337, 22.72792931965419, 16.70265473638262, 9.05502528803689, 5.662111784730639, 57.16042225701468, 62.11919525691441, 74.01198904854911, 54.28726918356759, 49.0003536088126, 53.619106088365825, 9.05285050187792, 1.4429689879928316, 0.10547436028718948, 4.9231109363692145, 46.520423412323, 67.41432012830461, 63.0334392275129, 61.43456145695278, 60.535089356558665, 60.38370200565883, 54.04322065625872, 54.77289267948696, 59.597659247262136, 59.68637384687151, 59.495784759521484, 59.218489101954866, 58.088639054979595, 59.14399746486119, 61.438160623822895, 59.0359251839774, 57.34567165374756, 58.56166199275425, 57.388038294655935, 54.83639574050903, 52.73126179831368, 50.676641259874614, 52.05339901787894, 52.03942271641323, 53.42133603777204, 52.02386917386736, 49.23672785077776, 45.85829482759748, 42.35675709588187, 37.96496752330235, 38.69331244059971, 39.74906342370169, 43.38510090964181, 44.54615879058838, 42.878632817949565, 39.898960386003765, 36.30437237875802, 47.72355610983712, 52.69821269171578, 47.5428786277771, 46.288735730307444, 48.41424526487078, 41.416221141815186, 32.36626543317522, 24.206827333995275, 17.189829417637416, 10.788860525403704, 8.351316945893423, 9.024127517427717, 9.80763852596283, 17.4205321925027, 35.96246542249407, 45.85286133629935, 37.1450766154698, 25.01836998122079, 19.206349509102957, 24.17888167926243, 21.748942034585134, 20.266377108437673, 18.506349767957413, 18.64405264173235, 23.2838807446616, 28.6152526310512, 36.20847681590489, 43.69918727874756, 48.01783316476004, 44.67847333635603, 39.95293746675764, 38.55414697102138, 33.479703835078645, 31.895240102495464, 23.961632353918894, 21.701298236846924, 27.52533561842782, 35.51238543646676, 37.98914378029959, 37.051946435655864, 40.09026166370937, 42.77803332465035, 41.5106645311628, 42.12871721812657, 40.59388794217791, 44.521287713732036, 49.077711377825054, 47.943449224744526, 49.44259950092861, 48.369471073150635, 45.570701939719065, 51.460182666778564, 50.108167443956646, 51.401984555380686, 51.13649041312081, 51.5523088318961, 47.554596764700754, 49.02838611602783, 48.33496284484863, 48.132822377341135, 45.70866884504046, 48.573501450674875, 48.250146184648784, 53.12867791312081, 49.7670247895377, 56.01309054238455, 54.719398498535156, 47.02056516919817, 47.1681101662772, 32.13366753714425, 7.493788514818464, 0.3137643092444965, 17.499503680637904, 47.26735823495047, 48.331019742148264, 51.72166075025286, 57.32928780147007, 53.09059831074306, 47.960819721221924, 52.36410856246948, 20.504662105015345, 4.303925258772714, 35.668949195316856, 46.96318347113473, 21.788616248539515, 26.197147505623953, 27.268238374165126, 28.015261786324636, 40.88454845973423, 36.00680882590157, 23.786761828831263, 33.30400473730904, 62.38945238930838, 41.06587559836251, 0.0855881952281509, 0.05742496145623071, 0.07807978455509458, 0.042868746644152064, 0.021867105637543967, 0.04953320563903876, 0.027007371420040727, 0.09950004265244518, 0.10210374436740365, 0.07944733117307935, 0.20861835990633282, 0.1829713782561677, 0.2627941428550652, 0.17579268131937298, 0.0852446122361081, 0.25093804619141985, 0.11458445287176541, 0.3601461946964264, 0.15280586906841823, 0.13080412681613648, 0.1236439538853509, 0.309502512216568, 11.012880870274135, 85.00056512015206, 66.60955892290387, 48.420140811375205, 52.02265671321324, 60.1586845942906, 59.53183201381138, 40.88129670279366, 25.940616539546422, 29.330583572387695, 12.671197005680629, 10.133510776928492, 13.710582375526428, 61.540597915649414, 63.675904410226, 76.40248898097447, 59.9354806627546, 55.69144453321184, 58.72798102242606, 6.212752614702497, 2.4735793258462633, 0.17931881068008287, 11.149764725140162, 56.540080138615195, 67.29369245256696, 67.23499407087053, 62.63086060115269, 64.87869317190987, 65.41159221104213, 56.807009083884104, 56.7707325390407, 64.48065171922956, 62.397018977573936, 64.86360168457031, 61.029766355242046, 61.64516830444336, 63.2185183933803, 63.30457183292934, 62.88482420785086, 62.133418219430105, 60.196163177490234, 60.44476972307478, 58.582381520952495, 55.57985298974173, 51.938222203935894, 53.16706671033587, 53.093874386378694, 54.5124637739999, 54.434546675000874, 52.230001381465364, 49.812323570251465, 47.75006001336234, 44.706158433641704, 43.95490183149065, 44.49429396220616, 46.08673422677176, 47.93277679170881, 45.56289563860212, 42.80530847821917, 42.00235380445208, 52.23396185466221, 56.98215927396502, 51.719711780548096, 51.90568726403372, 55.35429014478411, 51.57861818586077, 39.532164982386995, 32.87033987045288, 29.05328791482108, 27.771437338420323, 27.151404414858135, 27.980008363723755, 30.570069244929723, 36.53148814610073, 46.091205392565044, 49.45222970417568, 45.760735171181814, 42.41333627700806, 35.815740312848774, 43.96159642083304, 42.35705934252058, 42.04081903185163, 38.40492398398263, 32.59210273197719, 35.237542493002756, 36.70236866814749, 41.41644695826939, 48.85827684402466, 51.436600480760845, 48.75466183253697, 43.61842489242554, 40.83018922805786, 40.85772146497454, 36.63018383298601, 29.712355818067277, 29.26553453717913, 30.006045750209264, 39.464138644082205, 43.39496040344238, 43.393212931496755, 43.34679201671055, 45.711531502859934, 44.41050216129848, 43.657501561301096, 42.09786721638271, 46.697310652051655, 51.508934702192036, 51.84664494650704, 50.95386743545532, 49.09447390692574, 49.34564086369106, 54.26885993140084, 54.47608300617763, 56.181104932512554, 56.83740745271955, 54.54679134913853, 53.091567584446494, 53.009443351200645, 50.93589244570051, 51.149539130074636, 48.95163631439209, 51.38550342832293, 50.910986627851216, 54.96561138970511, 52.92446688243321, 55.568836620875764, 53.585706097739084, 44.796370370047434, 49.40072618212019, 37.444603034428184, 14.585590737206594, 0.4688967934676579, 13.748945985521589, 48.11416646412441, 52.472406659807476, 57.8692045211792, 60.292222023010254, 60.139549255371094, 53.40742574419294, 59.85757051195417, 36.26960359300886, 4.655965728419168, 29.881256103515625, 57.51497493471418, 23.76522762434823, 39.09619331359863, 33.858193056924, 51.464626039777485, 52.82032380785261, 39.47139603751046, 37.75166824885777, 41.498508657727925, 67.23864882332938, 53.903346470424104, 0.9683050811290741, 0.17027879719223293, 0.20800846549017088, 0.09075870670910392, 0.11494603061250278, 0.23039423142160687, 0.13406161059226307, 0.147036041532244, 0.11385452561080456], [0.04240290181977408, 0.03779869566538504, 0.06396139785647392, 0.012526059240501906, 0.06119321925299508, 0.03459898575342127, 0.01593725409890924, 0.07985650814537491, 0.038354683866990466, 0.0694799842312932, 0.02069092116185597, 0.03779919099594865, 0.05132234642016036, 0.7611133275287492, 42.89772299357823, 63.62304251534598, 23.582394463675364, 32.54570266178676, 41.88154547555106, 38.13122749328613, 46.75550528935024, 17.581025157655986, 25.631772586277553, 28.51112345286778, 9.050885030201503, 2.7311783603259494, 25.560586554663523, 59.20331423623221, 59.269099780491416, 56.36039277485439, 40.717197622571675, 64.72450569697789, 64.15241186959403, 31.639466490064347, 7.363737344741821, 0.17989735677838326, 9.24188492979322, 51.77433851787022, 60.676116943359375, 62.28289481571743, 57.81389338629586, 62.99200711931501, 57.37348876680647, 57.28680998938424, 57.98020199366978, 56.3383982522147, 55.81515026092529, 58.01923697335379, 58.34973498753139, 56.925930976867676, 57.260566643306184, 55.57303333282471, 58.45770999363491, 55.56585236958095, 53.87416056224278, 53.13079016549246, 52.74296603884016, 50.18197815758841, 48.12556845801217, 46.45052800859724, 45.320691858019146, 47.009618282318115, 42.63904850823538, 40.521571091243196, 38.999887807028635, 35.30262974330357, 36.726572717939106, 39.40250812258039, 41.87027202333723, 43.793390955243794, 35.57844890866961, 28.013081789016724, 31.045068945203507, 39.87685121808733, 49.13354362760271, 44.76675367355347, 37.27502529961722, 24.105779681886943, 15.746422801698957, 10.140386019434247, 6.368494314806802, 5.032806055886405, 4.885561568396432, 4.785391994885035, 6.141512734549386, 12.165256108556475, 21.29451768738883, 35.71961893354143, 41.10693597793579, 39.83087498801095, 33.524047238486155, 26.145397322518484, 29.62112249646868, 26.880655697413854, 22.329674209867203, 13.922346098082405, 12.010943566049848, 9.94968054975782, 12.16817261491503, 13.016029153551374, 21.869580132620676, 32.648313658578054, 41.2225991657802, 40.792926039014546, 36.670643193381174, 33.69845397131783, 29.35036509377616, 27.891160011291504, 16.635920763015747, 18.55515044076102, 28.77041459083557, 34.99431732722691, 38.90674025671822, 40.48996026175362, 40.47352777208601, 42.39127574648176, 41.999880245753694, 39.756577900477815, 37.61997904096331, 32.531212193625315, 33.21430001940046, 40.215197222573416, 41.174778188977925, 46.459004810878206, 45.27973222732544, 47.68548692975725, 46.31646946498326, 47.14707449504307, 46.203474385397776, 47.19507959910801, 48.54059130804879, 48.19985512324742, 47.921433857509065, 46.93944147654942, 47.17454072407314, 47.06186873572213, 50.37824044908796, 50.964056968688965, 55.97364909308297, 48.728418486458914, 52.72091245651245, 29.336896010807582, 21.59705788748605, 0.900338453905923, 9.630942361695425, 47.69545759473528, 41.097232818603516, 53.03500577381679, 46.01513998849051, 51.18034744262695, 39.702906540461946, 50.0135885647365, 25.027249779020035, 0.7929419939007077, 14.623540060860769, 62.421150071280344, 21.454133442470006, 10.806655730519976, 22.385240691048757, 29.55321080344064, 40.835455962589805, 29.584470748901367, 25.52141261100769, 30.670818124498638, 31.35241208757673, 55.20624140330723, 23.754911286490305, 0.02302387553001089, 0.05469383765012026, 0.044164375335510285, 0.022654613380187323, 0.04457052264894758, 0.09059644863009453, 0.03437236184254289, 0.06675053640667881, 0.05964549444615841, 0.058313190937042236, 0.01998390124312469, 0.012671288635049547, 0.007980510742137474, 0.04241663197587643, 0.015537468051271779, 0.13254919674779686, 0.021416882385632822, 0.15483696865183966, 0.056182672402688434, 0.00817566759152604, 0.08342752938291856, 0.12490944883653096, 0.6894350594707898, 52.83221912384033, 72.56791019439697, 27.839116266795568, 32.37929677963257, 53.68327965055193, 37.0453838620867, 29.57267270769392, 20.359378746577672, 27.019329581941875, 27.59753261293684, 17.571832690920147, 6.161084072930472, 19.016003608703613, 61.5011043548584, 65.75329766954694, 57.82800170353481, 41.26480252402169, 66.1895820072719, 63.57132707323347, 40.597639969417024, 11.887230890137808, 0.08575788326561451, 6.932179084845951, 54.870834486825125, 60.60835811070034, 66.4702683857509, 60.039238112313406, 63.75519725254604, 56.62049511500767, 62.25560229165213, 61.59404345921108, 56.586490631103516, 59.238527706691194, 58.287506920950754, 59.40929358346121, 58.0195426940918, 57.451402391706196, 57.14451783043997, 57.45092644010271, 55.105040890829905, 56.530449935368125, 53.27601446424212, 55.076046058109824, 51.886600562504356, 51.95685379845755, 50.1243428502764, 50.56795406341553, 53.42883661815098, 50.272193568093435, 47.09713431767055, 44.55649076189314, 41.28941304343087, 42.012307098933626, 41.76629223142351, 45.96463005883353, 47.85565873554775, 42.861602783203125, 33.84140273502895, 40.06337560926165, 46.666842801230295, 50.27400704792568, 47.66549696241106, 46.66605418069022, 41.24589647565569, 30.42827388218471, 22.116156067167008, 15.872235570635114, 14.383346915245056, 13.703344089644295, 10.898517864091055, 10.716018216950552, 12.644410831587654, 23.105228662490845, 38.60868338176182, 48.407981463841026, 43.27496153967721, 38.11231797082083, 35.990004607609336, 34.04268857410976, 33.87439278193882, 28.01662537029811, 22.50424075126648, 20.15002257483346, 22.18861014502389, 24.393803358078003, 28.395583595548356, 37.41083131517683, 43.32590225764683, 45.572793347494944, 40.86658041817801, 39.706106185913086, 41.95255953924996, 33.781738553728374, 32.56232622691563, 21.101696491241455, 24.360304355621338, 32.86312069211687, 37.43298217228481, 42.505903652736116, 42.407298292432515, 45.34330129623413, 45.92006778717041, 44.96327999659947, 43.508094446999685, 42.28096267155239, 35.95169571467808, 37.44170910971505, 42.431856700352256, 45.40920843396868, 48.26515776770455, 48.38268307277134, 49.353481905800955, 48.789979525974815, 49.836763858795166, 49.382018157414024, 50.0640845979963, 51.22984293528965, 49.49140017373221, 49.49005569730486, 49.2828117779323, 50.993322781154085, 50.68036896841866, 53.702661650521414, 53.136407784053254, 54.53022684369768, 50.506184577941895, 51.12185055868966, 31.51489918572562, 22.378601687295095, 1.3164924489600318, 14.951865025929042, 51.655044896262034, 43.2992559160505, 58.62959453037807, 52.79613018035889, 53.11116845267159, 46.095502853393555, 53.55047525678362, 25.2796048777444, 0.511836823608194, 21.739898954119, 62.41780798775809, 30.01680850982666, 18.068950244358607, 29.166828427995952, 27.37492970057896, 30.191246509552002, 40.58293410709926, 28.807017701012747, 31.89387478147234, 37.743955748421804, 63.10290731702532, 27.432288816996984, 0.009448626427911222, 0.028002929873764515, 0.07253279470439468, 0.05054366641810962, 0.03282782954296895, 0.026540378175143684, 0.011592131274353181, 0.04930575052276254, 0.02545872550191624, 0.09372989620481219, 0.1444220667971032, 0.12834962138107844, 0.1434466184249946, 0.1926118273820196, 0.07289611628012997, 0.27070111142737524, 0.09610796467001949, 0.2942016018288476, 0.1405835941966091, 0.13734421373478004, 0.20889693924358912, 0.2110107522457838, 1.6722196979182107, 68.48268904004777, 78.49450819832938, 35.978908334459575, 42.40249013900757, 58.05201162610735, 58.770649909973145, 61.367601667131694, 21.701110635484966, 33.98905195508684, 40.24247237614223, 14.325793249266487, 8.192892806870596, 32.665861334119526, 68.51082924434117, 69.80056081499372, 62.54659284864153, 47.1522022656032, 70.36071068899972, 73.21341173989433, 37.51595408575875, 9.74887934752873, 0.31498982491237776, 14.201448287282672, 62.61573437282017, 61.571024077279226, 69.03241661616734, 63.11287103380476, 65.9496329171317, 59.31873076302664, 65.31796523502895, 65.2546671458653, 60.23517731257847, 60.506782395499094, 63.12730939047677, 64.02806690761021, 61.52654865809849, 59.9575411932809, 60.97471577780587, 61.3245575768607, 58.760581970214844, 58.81570897783552, 56.52293198449271, 58.577733176095144, 54.91817603792463, 54.94340147290911, 53.899257455553325, 54.22294623511178, 55.19828224182129, 55.42207677023751, 50.472656045641216, 49.82489633560181, 47.50393744877407, 47.11057560784476, 45.514824526650564, 51.31209223611014, 51.34649971553257, 46.091274874550955, 39.4021120752607, 44.674509389059885, 52.323009967803955, 53.8779890196664, 51.80903434753418, 52.94082989011492, 46.92122329984392, 39.20252507073538, 31.569428648267472, 25.904967069625854, 28.700922182628087, 32.87582547324044, 33.051760809762136, 31.020013741084508, 35.06590461730957, 41.59047848837716, 48.40445525305611, 50.54508406775338, 48.97732727868216, 47.123891830444336, 41.470173903873985, 43.038285051073345, 44.28226968220302, 41.50096137183053, 38.28893075670515, 35.991745131356375, 34.12244347163609, 34.148877893175396, 32.56705447605678, 45.196266991751536, 48.722081729343955, 47.03616387503487, 43.91392830439976, 41.65795244489397, 45.904507296425955, 41.3856212752206, 38.09948117392403, 24.049770253045217, 27.57293598992484, 36.94718844549996, 41.01281220572335, 46.686249119894846, 47.35028845923287, 47.90345539365496, 48.624779156276155, 47.99984427860805, 44.04712527138846, 45.074027333940776, 39.4529242515564, 40.848782607487266, 47.88345152991158, 50.11009904316494, 49.861819062914165, 50.61182498931885, 53.12005172457014, 51.158662114824565, 53.00728940963745, 51.33307926995413, 52.53388779503958, 52.91043152127947, 51.173875195639475, 52.88574457168579, 51.54408911296299, 52.866932324000764, 52.056053229740684, 54.574768270765034, 53.96598448072161, 56.685943671635215, 48.51004702704293, 56.58592087881905, 36.900739737919395, 31.908215863364084, 1.948420362813132, 12.577020253453936, 55.547561236790244, 47.85144465310233, 62.28966236114502, 56.56564603533064, 59.556574548993794, 49.323760986328125, 57.002722467694966, 33.035158089229036, 3.114721962383815, 21.60199284553528, 73.39763627733502, 33.72027478899275, 21.774127517427715, 38.88521473748343, 37.61308642796108, 55.5725017956325, 46.260918617248535, 34.89636162349156, 46.144612721034456, 46.28044305528913, 72.43274688720703, 39.07209348678589, 0.11960259931428091, 0.20600473800940172, 0.12406697975737707, 0.09204158572746174, 0.16245870824371064, 0.12677580011742456, 0.10834525552179132, 0.08142510468938521, 0.11507907775895936], [0.058968961105815, 0.015417866076209714, 0.04939913729737912, 0.04965812393597194, 0.051465951571507115, 0.05831042251416615, 0.02336419646495155, 0.061225850002041886, 0.021298992015155296, 0.11158762153770242, 0.05134666511522872, 0.058037644651319296, 0.058266602722661834, 0.0564901810804648, 21.141391549791607, 68.35867064339774, 40.59183474949428, 36.670858587537495, 25.792338507516043, 22.627058846609934, 51.01288890838623, 25.082866634641373, 17.47940080506461, 25.764153139931814, 34.22122253690447, 10.719958714076451, 0.8088875125561441, 15.291435650416783, 47.2859377179827, 57.27344512939453, 50.6213891846793, 46.82675906590053, 53.90146003450666, 61.18491962977818, 49.40727138519287, 12.827120661735535, 0.13908219976084574, 10.197133694376264, 43.984410830906455, 53.84300136566162, 48.873656681605745, 43.66271618434361, 46.623083046504426, 48.65377746309553, 57.49148307527815, 59.18768078940255, 60.39543751307896, 56.2447122165135, 57.843843596322195, 60.12288747514997, 56.60224914550781, 60.13717991965157, 59.13643782479422, 57.2202809878758, 55.63860695702689, 51.78105047770909, 49.51294306346348, 47.440726212092805, 42.205077920641216, 42.99956968852452, 39.753749983651296, 43.60925327028547, 43.810118743351524, 42.06099312646048, 39.98995052065168, 38.18250519888741, 40.38497298104422, 43.572142941611155, 41.570033414023264, 38.393827710832866, 30.97494077682495, 30.515789917537145, 39.91264833722796, 51.043659005846294, 47.69299793243408, 37.77436453955514, 25.557074240275792, 14.566261717251368, 11.782899345670428, 6.67452164207186, 6.526540645531245, 7.110950589179993, 5.87300090278898, 9.446673529488699, 13.533147096633911, 17.522359779902867, 26.59189898627145, 36.4587995665414, 41.92454787663051, 44.51894964490618, 36.21995176587786, 32.597379888807026, 30.955378123692103, 28.53125412123544, 23.20351266860962, 15.813393013817922, 11.154862097331456, 11.60703262260982, 11.48562501158033, 13.707784857068743, 15.598202092306954, 22.781374863215856, 34.94112539291382, 41.38173028400966, 41.75898272650582, 36.95199659892491, 32.15586008344378, 34.5555351121085, 26.384952102388652, 13.766946162496295, 18.80632608277457, 29.26746961048671, 33.793884004865376, 39.02437673296247, 38.26877055849348, 39.21817936216082, 37.08281033379691, 37.05012600762503, 34.94434240886143, 29.38744068145752, 23.30646586418152, 20.9869487285614, 24.987775325775146, 31.261915275028773, 38.94736289978027, 45.272353240421836, 47.30531276975359, 51.75274351664952, 45.652148723602295, 45.706129278455464, 43.970510959625244, 47.34941298621041, 45.70883560180664, 50.55096571786063, 45.95760543005807, 51.59943846293858, 45.02886404309954, 54.118063177381245, 52.07266984667097, 51.866534164973665, 24.968125820159912, 37.72268731253487, 5.6779171994754245, 4.563449161393302, 46.04831763676235, 43.619057178497314, 47.388263838631765, 35.73595414842878, 43.03237908227103, 48.92263453347342, 48.46894495827811, 52.54190949031285, 6.845616689750126, 3.866870105266571, 52.25815200805664, 52.209611892700195, 15.394970757620674, 12.195088199206761, 22.529097931725637, 33.601498808179585, 38.46693318230765, 19.725810732160294, 27.228850773402623, 25.499329498835973, 38.63096278054373, 56.89992734364101, 14.78375162397112, 0.27301095319645746, 0.2096097809927804, 0.049881602837038894, 0.11136686016938516, 0.03754790912249258, 0.06653212276952607, 0.05601268241714154, 0.070796410020973, 0.035700597534222264, 0.015944509334596138, 0.008578796272299119, 0.06612388896090643, 0.008643330889753997, 0.06255313913737025, 0.08024163105125938, 0.013645065266505947, 0.06101938536656754, 0.05630835405151759, 0.11369256608720336, 0.10927003768405744, 0.05345105326601437, 0.05831069392817361, 0.007719274759957833, 20.52395030430385, 79.6483052117484, 44.38185821260725, 34.96494729178292, 30.750416687556676, 30.97219623838152, 32.21958548682076, 24.746414014271327, 24.122095789228165, 27.524288177490234, 38.716022627694265, 18.807821682521276, 1.827655894415719, 15.249072483607701, 53.36292600631714, 59.65568365369524, 56.18029546737671, 54.663451603480745, 56.514597620282856, 62.245471818106516, 55.71993562153408, 18.103182281766617, 0.09251198012913976, 8.992739898817879, 48.40655360903059, 52.800886222294395, 49.42991556440081, 47.04049260275704, 49.65428679330008, 48.65655674253191, 59.39641857147217, 60.24711431775774, 61.750773974827354, 58.96050943647112, 58.572674887520925, 60.14512171064104, 58.512649399893625, 60.920672689165386, 59.02317523956299, 57.185251644679475, 55.554756096431184, 55.671489306858604, 54.04480831963675, 51.75182635443551, 48.33317368371146, 46.51812008449009, 45.445144517081125, 49.32114846365792, 50.0554757799421, 46.29075070789882, 44.40107692990984, 43.52822685241699, 42.9380190713065, 44.71806764602661, 46.276413100106375, 43.27347809927804, 37.935225759233745, 36.17903382437569, 44.957043988364084, 53.109011037009104, 51.01542500087193, 46.07781273978097, 41.05102729797363, 28.971966198512487, 20.987728663853236, 14.80578088760376, 13.695660250527517, 14.224845477512904, 16.86773524965559, 14.654287576675415, 17.374694926398142, 19.896024227142334, 30.259133883884974, 41.7098068509783, 49.115367140088765, 46.09798683438982, 35.0537383215768, 41.81167091642107, 39.36674574443272, 36.93618597303118, 32.62981060573033, 25.544597012656077, 22.065500225339616, 19.16774705478123, 21.594539165496826, 21.2579927444458, 28.41844490596226, 36.737186091286794, 42.92050266265869, 43.95960576193673, 41.41764899662563, 41.89229086467198, 39.24775089536394, 41.21564054489136, 27.808188097817556, 18.51210982458932, 22.807154417037964, 30.01241030011858, 34.443898405347554, 39.75114440917969, 41.422248704092844, 42.3271473475865, 39.884862491062705, 41.10378844397408, 36.659435749053955, 33.16543333871024, 26.81229063442775, 25.94302930150713, 30.733820915222168, 36.86845145906721, 41.37712710244315, 46.43883419036865, 51.008810315813335, 54.34400817326137, 47.30754314150129, 48.87321547099522, 46.54911947250366, 50.01011446544102, 48.778876304626465, 52.359831946236746, 48.066408021109446, 53.312509877341135, 46.63994632448469, 54.37074136734009, 54.87767498833792, 47.97208969933646, 27.898554631641932, 43.819158349718364, 5.367086061409541, 8.02823873928615, 50.2747539792742, 46.060668059757774, 51.82395907810756, 40.68296732221331, 47.641463143484934, 54.50335815974644, 51.63742773873465, 53.38344056265694, 6.0268153463091165, 6.864542279924665, 55.744535718645366, 53.93755940028599, 27.187830345971243, 16.588358606610978, 29.186123575483048, 25.391625472477504, 34.24119513375418, 30.780061176845006, 27.487005880900792, 29.518674782344274, 45.00552156993321, 65.02506392342704, 14.840393338884626, 0.29100578331521576, 0.18732321688107081, 0.05275860149413347, 0.05319189699366689, 0.05230559455230832, 0.02255642766665135, 0.030596938715981584, 0.040464707251105986, 0.0433116196654737, 0.11948481920574393, 0.19474360799150808, 0.18547658382781915, 0.15989504009485245, 0.19657569325395993, 0.17710880855364458, 0.16135192263339246, 0.12748317287436553, 0.1580275081630264, 0.19220368856830256, 0.20642192848026752, 0.13149408836449894, 0.18164713574307306, 0.17249825809683117, 35.532552582877024, 89.96613693237305, 54.382779121398926, 48.15695694514683, 38.13881492614746, 41.12310791015625, 68.30539880480084, 31.649913106645855, 21.862527711050852, 34.9440575327192, 43.794926507132395, 17.158225536346436, 3.7063367537089755, 21.590387616838726, 57.24361998694283, 64.46189158303397, 59.23451164790562, 57.310440812792095, 60.94146864754813, 67.67015974862235, 59.760003907339915, 17.143632582255773, 0.2397131228021213, 18.2186769757952, 56.31253358295986, 54.853203432900564, 54.648394857134136, 53.82723937715803, 52.965600218091694, 51.08402109146118, 64.37426090240479, 64.60081386566162, 67.20604787554059, 61.92550032479422, 61.25686822618757, 63.7941905430385, 63.546112060546875, 65.41170338221959, 62.791648864746094, 60.835154260907856, 59.618496894836426, 57.12146718161446, 57.41111673627581, 55.9818514415196, 53.152426855904714, 49.471504007067, 48.4533497265407, 55.90416015897478, 54.14175306047712, 49.89623696463448, 49.6106937953404, 46.591937746320454, 49.579291411808555, 49.33459670203072, 48.74949584688459, 46.16866043635777, 42.07832193374634, 43.0759060723441, 51.467759677342, 59.496597698756624, 54.04574980054583, 51.56974533626011, 47.2671080998012, 35.351618017469136, 28.967832020350865, 27.614943061556133, 28.85345251219613, 32.23686565671648, 36.64285387311663, 37.51964357921055, 37.253753389631, 38.93619367054531, 41.53994076592581, 48.84235157285418, 47.901051316942485, 48.540125778743196, 42.020558084760395, 45.37195219312395, 44.49519375392369, 42.763751302446636, 40.80812174933297, 37.693998200552805, 34.556292465754915, 34.82604585375105, 33.147440978458945, 33.423305307115825, 36.54737867627825, 40.91776432309832, 47.520543643406455, 45.29543168204171, 43.50344957624163, 46.031711442129954, 42.31085729598999, 47.110179560525076, 32.315244810921804, 22.02618384361267, 25.819556338446482, 32.6837077822004, 40.276723521096365, 45.01039225714547, 45.97818946838379, 45.34172058105469, 42.870433943612234, 42.27509839194161, 41.73633854729788, 34.41146421432495, 29.834803921835764, 28.986270802361624, 36.32689496449062, 41.961929185049875, 45.92747804096767, 51.51858227593558, 54.55150917598179, 56.94094603402274, 50.12023646490914, 51.95842409133911, 49.93950687135969, 52.24984891074044, 52.297145298549104, 56.58184923444475, 49.73801258632115, 54.924901894160676, 48.62506750651768, 54.49046925136021, 54.65693071910313, 53.47622333254133, 30.0545163835798, 47.444672788892476, 8.890092423983983, 6.977760136127472, 51.51521587371826, 50.85644326891218, 54.330247265951975, 44.20458882195609, 51.42296116692679, 57.511365345546174, 58.13648435047695, 62.36140945979527, 10.51951881817409, 7.413914629391261, 58.77527046203613, 62.570307050432476, 27.301772117614746, 25.17932152748108, 35.213991573878694, 43.86794512612479, 51.47449595587594, 31.421626567840576, 36.36461673464094, 40.891520977020264, 52.671795640672954, 74.84461947849819, 24.220070600509644, 0.4771089128085545, 0.44427302905491417, 0.1157830578408071, 0.21776529694242136, 0.09610515553504229, 0.1545646996902568, 0.11146494919168097, 0.15148119229291165, 0.09635985722499234], [0.01808391498135669, 0.024696961377880404, 0.02602130567122783, 0.03313927372385349, 0.08992826805583068, 0.06827894332153456, 0.03738974939499583, 0.037961167482925315, 0.059682637453079224, 0.06302204754735742, 0.03806337521278432, 0.028748836634414535, 0.04399169156593936, 0.1580940317362547, 2.2239196939127783, 53.723860604422434, 58.032007762363975, 33.9804813521249, 24.185642276491436, 15.67754704611642, 37.17908804757254, 30.631467001778738, 21.331297976630076, 14.995951345988683, 20.448984452656337, 52.92150347573416, 9.141087412834167, 3.438121957438333, 30.000681740897043, 58.42694337027413, 44.69003513881138, 46.57050255366734, 56.969749791281565, 47.495033332279746, 52.9971832547869, 41.817854813167024, 9.078491960253034, 0.23121802721704754, 7.336751409939357, 34.707096167973106, 32.78619023731777, 55.1822874886649, 63.35526588984898, 57.8933356148856, 53.710749353681294, 56.95139612470354, 57.60337686538696, 56.52389430999756, 55.081517764500205, 56.11129290716988, 58.60664463043213, 58.44942774091448, 58.103268487112864, 53.94065482275826, 52.0362091745649, 48.22905840192522, 46.8553717476981, 47.21497923987252, 43.702220167432515, 43.149317264556885, 44.53923143659319, 45.9781825201852, 45.08101027352469, 44.72552306311471, 41.52886186327253, 41.962221009390696, 42.772540773664204, 43.58913128716605, 40.864871161324636, 31.8084397315979, 28.585144349506923, 36.01645987374442, 47.154161657605854, 53.004850591932026, 42.20531415939331, 27.67371266228812, 14.61799887248448, 10.72054844243186, 10.42081184046609, 6.8748277851513455, 7.071496980530875, 6.247469288962228, 12.50275616986411, 16.20213430268424, 19.52557407106672, 26.155411413737706, 33.81202227728707, 41.64764826638358, 45.84856734957014, 43.396996225629536, 40.818915775844026, 36.297313008989605, 34.44878993715559, 31.49540948867798, 24.182569435664586, 16.91909807068961, 13.564427018165588, 12.92070768560682, 12.940579533576965, 13.819277388708931, 14.62930532864162, 18.800065755844116, 27.449204206466675, 36.593768324170796, 42.479090554373606, 40.64411299569266, 39.045610427856445, 39.55951656614031, 38.586028780256, 22.886725187301636, 16.68915786061968, 22.93483451434544, 25.79523069517953, 30.943753787449428, 31.51830380303519, 37.48938764844622, 35.375867230551584, 30.953846045902797, 29.300991194588796, 26.18145326205662, 23.918327706200735, 22.551410334450857, 24.689706291471207, 27.190220526286534, 32.28078522000994, 37.195127964019775, 42.19115373066494, 43.68532909665789, 47.996210370744976, 46.66954217638288, 48.611000878470286, 44.51899133409773, 48.70025396347046, 45.99298913138253, 47.232314995356965, 44.849725587027415, 49.965673787253245, 55.56800978524344, 46.70236546652657, 29.121552228927612, 44.563425064086914, 28.326565401894705, 0.9490390292235783, 35.92442403520857, 44.41337871551514, 48.61988762446812, 44.595720291137695, 27.055663449423655, 44.97666917528425, 47.75902318954468, 49.27911533628191, 26.028672797339304, 2.839490136929921, 20.808487721851893, 49.63388340813773, 26.904484544481548, 7.913882681301661, 21.7435884475708, 23.83320185116359, 46.28896154676165, 31.495520659855433, 19.659780263900757, 34.01461090360369, 28.105374710900442, 41.2264449937003, 45.71977554048811, 3.652963297707694, 0.15422579858984264, 0.03461928752117923, 0.08235990202852658, 0.045950516991849454, 0.09382462647876569, 0.08988919122410671, 0.05115654978102871, 0.01829609797070069, 0.05856952111103705, 0.069191511853465, 0.1342769640364817, 0.06717257161757775, 0.042196600032704215, 0.04681756260937878, 0.11150532202529055, 0.09545675425657205, 0.07821048397038664, 0.07939159630664758, 0.158930258293237, 0.07396870372550828, 0.041138651980353255, 0.04919068794697523, 0.19964983686804771, 2.719198146036693, 65.0987217766898, 63.93306418827602, 34.61320516041347, 25.816348007747106, 27.831025089536393, 30.036048071725027, 26.099235228129796, 26.47272869518825, 20.903068338121685, 22.275851726531982, 52.09320872170584, 13.72176810673305, 3.5695475680487494, 33.62516784667969, 66.71547031402588, 48.348539624895366, 52.45821149008614, 64.04646573747907, 53.40066514696394, 56.7825687953404, 47.90590810775757, 12.738538077899388, 0.03731816734320351, 7.091287187167576, 34.21121365683419, 35.69424063818795, 56.90394687652588, 64.48568221500942, 57.69595466341291, 55.741026878356934, 56.32603393282209, 58.04985073634556, 56.31089033399309, 55.85495301655361, 55.8339764050075, 56.48277487073626, 58.496175221034456, 61.02286679404122, 55.08944913319179, 55.41500697817121, 50.95575039727347, 50.623108863830566, 50.62416499001639, 48.443594455718994, 48.08292041506086, 49.67895289829799, 50.53956372397286, 50.35249042510986, 50.583017757960725, 46.241435868399485, 44.59223229544503, 47.850287778036936, 46.6859781401498, 44.472775391169954, 38.32623216084072, 35.235312121255056, 42.842564719063894, 46.69125182288033, 54.28338861465454, 49.236088616507395, 39.709886005946565, 27.33487159865243, 20.818317685808452, 15.18841644695827, 14.111406581742422, 12.85971118722643, 15.8567202431815, 17.30658868380955, 20.011843749455043, 24.864423956189835, 27.59135045324053, 35.773616858891074, 46.68875047138759, 48.65358986173357, 49.30674137387957, 44.349302428109304, 42.119437898908345, 40.93366527557373, 38.265028953552246, 36.032135009765625, 28.64563536643982, 22.680297681263514, 22.32307689530509, 20.187687022345408, 22.029247999191284, 25.143067564283097, 27.3627564566476, 37.894898414611816, 41.84864228112357, 39.57780075073242, 43.175025599343435, 42.942243576049805, 42.555142062050955, 40.29216936656407, 24.80635264941624, 20.278235946382793, 26.76698316846575, 28.056299584252493, 34.110871246882844, 34.85302223478045, 38.97553784506661, 37.79908970424107, 34.17516640254429, 32.650679520198274, 29.68150929042271, 27.387438195092336, 26.53608931813921, 27.75482245853969, 32.84813690185547, 35.83648068564278, 41.195744378226145, 46.26080049787249, 47.39199849537441, 50.0758444241115, 49.33764696121216, 53.20842933654785, 46.78695283617292, 50.3845146724156, 48.93683317729405, 50.32397501809256, 48.393928732190815, 52.659473010471885, 56.830035414014546, 45.67426136561802, 30.40862090247018, 51.230874742780415, 21.945171322141373, 2.574352958372661, 43.36369003568377, 48.86919593811035, 53.05082334790911, 48.720018114362446, 31.04886613573347, 49.25917400632586, 52.02162837982178, 55.19126803534371, 26.946138995034353, 1.9169406805719649, 30.029572350638254, 53.14505481719971, 35.90844317844936, 16.735377277646744, 27.835558789116995, 28.58091984476362, 32.41037607192993, 32.834011214120046, 26.431065559387207, 33.618091106414795, 30.906507968902588, 49.0632278578622, 48.983035223824636, 3.570260844060353, 0.05557313082473619, 0.0687229223549366, 0.05390601099601813, 0.06733462613608156, 0.03418596148756998, 0.09141620714217424, 0.010874749277718365, 0.05048852866249425, 0.04165470839611121, 0.16942800927375043, 0.19921770505607128, 0.19886942660169943, 0.16585926791386946, 0.19409004306154592, 0.2279668945286955, 0.16322716272303037, 0.1535676196217537, 0.18825255201331206, 0.2619817193065371, 0.12878699148339884, 0.2098987554865224, 0.19797974505594798, 0.4121823124587536, 7.219616506780897, 82.3440603528704, 70.22162164960588, 47.130280699048726, 36.43036753790719, 34.33546829223633, 49.64559807096209, 40.01727431161063, 26.877634968076432, 20.922021286828176, 26.404747520174297, 58.90438188825335, 12.790925758225576, 7.31834476334708, 38.431229863848, 65.97776617322648, 52.58467565264021, 57.328242097582134, 66.01894814627511, 58.39080578940255, 61.31888089861189, 51.05330310549055, 13.081318770136152, 0.20554154286427156, 14.144603337560381, 47.396111828940256, 40.346226351601736, 60.02352128710066, 67.8900146484375, 61.0884438923427, 57.2371164730617, 60.820695059640066, 60.42022173745291, 60.247836930411204, 58.064997809273855, 60.05764389038086, 60.481338092258994, 62.872880254473, 63.3754643031529, 57.5227986063276, 58.71212523324149, 55.72381271634783, 55.20853778294155, 54.05338934489659, 50.97582721710205, 54.4747975894383, 55.424560751233784, 54.48537622179304, 53.58698456627982, 55.09290933609009, 50.26683650697981, 50.991599627903526, 50.21791771480015, 49.760872159685405, 45.76251738412039, 43.24116202763149, 41.930433000837056, 47.66000093732561, 52.04438720430647, 60.67261505126953, 54.025725092206685, 45.42115933554513, 34.32923575810024, 28.342242274965557, 27.203361306871685, 29.716760975973948, 30.673691204616002, 32.58795118331909, 39.585186685834614, 39.41169016701834, 41.45203215735299, 41.93618263517107, 45.51247950962612, 50.41829333986555, 51.229141167231965, 50.83116919653756, 49.05018261500767, 47.67214638846261, 47.7357953616551, 44.753211634499685, 43.54569462367466, 37.74468183517456, 37.92606455939156, 38.41093764986311, 37.348391328539165, 35.817195960453574, 36.92736870901925, 37.412165369306294, 41.764200823647634, 46.297827448163716, 42.96346337454659, 44.20912252153669, 45.644901752471924, 46.020941734313965, 43.46418530600411, 30.12365790775844, 24.0455162184579, 32.84838703700474, 31.088856492723735, 38.64570338385445, 38.72748020717076, 42.992065634046284, 41.93676280975342, 36.57346568788801, 35.5989009312221, 32.40388992854527, 30.71739537375314, 30.93852526800973, 31.332488128117152, 35.56080395834786, 42.18238510404314, 46.576134068625315, 50.93143170220511, 51.145206928253174, 54.40984582901001, 52.09704760142735, 55.04719713756016, 48.66105917521885, 53.29341275351388, 51.438222885131836, 51.089461530957905, 51.048633916037424, 51.34967851638794, 56.12992797579084, 48.01866347449166, 32.724993978227886, 56.42437873567854, 34.436071259634836, 2.5530397934573035, 40.32552766799927, 51.1924546786717, 59.39813477652413, 50.88219676698957, 35.28604439326695, 54.85715695789882, 56.49201944896153, 58.85468142373221, 33.750954559871126, 4.460641009466989, 27.596726621900284, 55.686764921460835, 37.466607979365754, 18.18907938684736, 37.176329612731934, 36.29096930367606, 60.353345326014924, 45.93382869447981, 27.462136541094097, 47.779926845005576, 43.21475192478725, 58.95277609143938, 64.03769016265869, 7.499782204627991, 0.3610183564679963, 0.16802428316857132, 0.14350111835769244, 0.12197108007967472, 0.16730084270238876, 0.23410926493150847, 0.08928010426461697, 0.12150080102894988, 0.11741614235298974], [0.07159237230994872, 0.0316982349779989, 0.04872516542673111, 0.017798290754269277, 0.05826517779912267, 0.05919897090643644, 0.05528782720544508, 0.024322901985474994, 0.056202485625232966, 0.11678448053342955, 0.07186282279768161, 0.04061864988346185, 0.11302232955183301, 0.06849574204534292, 0.056708635429718664, 33.06714759554182, 62.216727120535715, 38.119464193071636, 27.101738691329956, 46.7582220349993, 44.91485800061907, 38.01680108479091, 34.917025566101074, 20.200395277568273, 19.13850556101118, 39.26288059779576, 24.943072353090557, 2.66354763507843, 12.175961545535497, 40.95496845245361, 66.08700575147355, 38.216707706451416, 45.0004563331604, 56.15689046042306, 47.22040925707136, 50.69089896338326, 24.87652424403599, 2.494723128420966, 0.06878042141241686, 4.915501356124878, 33.345099857875276, 33.04354803902762, 36.92604160308838, 42.067607811519075, 49.74114274978638, 53.88995034354073, 54.124809878213064, 53.40844018118722, 53.22709914616176, 53.11913456235613, 49.13991859980992, 48.69703694752285, 46.12255219050816, 42.04656171798706, 41.97771896634783, 44.39185667037964, 48.31753328868321, 49.348295075552805, 46.51416655949184, 46.999849115099224, 48.27444403512137, 47.61329167229788, 47.12324217387608, 43.354976994650706, 42.348453998565674, 45.79925945826939, 45.62037461144583, 42.556747095925466, 32.14822401319231, 27.31242196900504, 40.489251545497346, 46.483573641095845, 51.834687096732004, 49.746041229793, 35.23900508880615, 19.2317191192082, 11.377583129065377, 10.804671151297432, 9.08905235358647, 7.0796849983079095, 9.558622905186244, 12.616981949125018, 17.237999541418894, 22.11092754772731, 24.75159215927124, 28.253473826817103, 36.487116949898855, 41.1813268661499, 47.4631723676409, 43.60737030846732, 39.9353654725211, 37.9025935445513, 32.95044565200806, 27.145361219133648, 23.4274548462459, 18.32282178742545, 16.57148664338248, 15.240831920078822, 15.316503013883318, 14.09921944141388, 15.229198898587908, 21.121448482785905, 28.72082356044224, 36.45420333317348, 39.55947835104806, 39.988647733415874, 38.33034896850586, 39.72291040420532, 38.14188602992466, 35.62601975032261, 29.546335560934885, 9.946510434150696, 10.164511901991707, 18.343025411878312, 20.391795567103795, 23.614373547690256, 30.523759501320974, 34.23369107927595, 33.677730969020296, 29.129452330725535, 28.53047071184431, 31.00889662333897, 33.56040021351406, 32.391265051705496, 37.58508518763951, 39.45393868855068, 42.53461708341326, 44.45803131375994, 47.07100214276995, 45.4536143711635, 45.51054791041783, 41.6427880014692, 39.481863498687744, 46.12896885190691, 44.61275379998343, 47.92977169581822, 53.737426962171284, 41.33096674510411, 37.938331604003906, 37.01998472213745, 16.69256247792925, 1.1682739108800888, 14.690637077604022, 47.7250326020377, 36.95362247739519, 50.420124190194265, 39.40107331957136, 55.551559925079346, 54.957700865609304, 51.414588587624685, 46.75085694449288, 8.4000255550657, 4.7578006982803345, 33.753945759364534, 25.82552136693682, 10.342688032558986, 10.256903835705348, 16.830683980669292, 26.105214153017315, 40.88072000231062, 19.35337860243661, 24.771792309624807, 22.04334589413234, 30.423955576760427, 47.53674684252058, 27.66325388635908, 0.3049368943486895, 0.1606489603540727, 0.10020529159477778, 0.04077945250485625, 0.025184432809640254, 0.0836599954803075, 0.00806542600704623, 0.07759151075567518, 0.06819058449140616, 0.017879984674177, 0.03342768842620509, 0.047235601249017885, 0.008506517873943915, 0.05266086870272245, 0.011023758960488652, 0.04203924436920455, 0.0701468823743718, 0.03468921394752605, 0.059627282566257885, 0.1386930870690516, 0.017290353010009443, 0.007319648168049753, 0.06851771979459695, 0.06106701173952647, 0.07072208329503026, 35.917072841099326, 71.30344227382115, 42.30178642272949, 26.835784230913433, 55.19949817657471, 48.48883417674473, 25.052298034940446, 35.3085218157087, 25.24606418609619, 25.14597017424447, 44.445406436920166, 36.20215048108782, 5.713465486254011, 8.401875512940542, 41.298240729740684, 72.60295690808977, 44.32511574881417, 48.78284025192261, 57.965593406132285, 54.95335129329136, 54.5632655279977, 29.33738933290754, 4.636568095002856, 0.22576818322496756, 4.069770531994956, 36.58608709062849, 35.425661495753694, 39.52531058447701, 42.17126451219831, 50.39848402568272, 51.86252505438668, 52.27219084330967, 53.36944689069475, 55.008982045309885, 57.219509737832205, 53.4570324080331, 52.42277567727225, 51.16942140034267, 46.698707239968435, 45.459874698093955, 46.93383428028652, 51.71454232079642, 52.54418502535139, 50.32187666211809, 51.4338698387146, 50.58205543245588, 50.719157287052695, 49.75466047014509, 47.466024603162495, 46.20135865892683, 47.38349737439837, 47.54863521030971, 45.047888210841585, 38.27310970851353, 34.087230001177105, 42.50830078125, 49.41025563648769, 50.18019594464983, 53.55608245304653, 45.17641598837716, 32.32352706364223, 21.014444487435476, 16.58687342916216, 16.597990546907695, 14.171651806150164, 16.850130251475743, 19.08942174911499, 23.5366336277553, 27.554882832935878, 31.323656967708043, 32.4343056678772, 38.7787891796657, 44.54339688164847, 51.365899085998535, 51.075610297066824, 44.41998297827584, 45.83237109865461, 42.230279036930625, 37.61168984004429, 33.421290329524446, 29.211234365190776, 26.544239555086406, 24.307128054755076, 22.261293513434275, 21.522316115243093, 23.296635900224956, 29.672709396907262, 35.10948371887207, 39.55617448261806, 40.59551382064819, 40.65844018118722, 42.51647533689226, 43.61564908708845, 40.90711620875767, 37.68775177001953, 30.31401423045567, 14.604043415614537, 13.299355847494942, 19.54171994754246, 22.199028968811035, 27.63177333559309, 34.7132522719247, 39.42276906967163, 35.33843381064278, 32.457328523908345, 31.455231530325754, 33.709921973092214, 37.721120493752615, 37.3874054636274, 40.792102677481516, 44.29002387183053, 45.75261967522757, 47.235222816467285, 47.871121951511924, 49.310493401118684, 48.14111852645874, 47.09170430047171, 42.923625877925325, 49.28369419915335, 48.115698541913716, 49.48519890648978, 53.496960231236045, 44.99179540361677, 38.46879529953003, 35.799960953848704, 10.022621870040894, 3.0237657002040317, 20.644638776779175, 52.26420388902937, 41.92087575367519, 51.80536569867815, 44.71622289930071, 59.30926731654576, 62.175427028111045, 57.07258660452706, 46.68929590497698, 5.793435777936663, 9.220692924090795, 44.21020991461617, 24.496294498443604, 17.04051262991769, 17.057139669145855, 23.846144608088903, 24.78911590576172, 31.984013761792863, 27.498538153512136, 28.88966131210327, 21.682164634977067, 33.02817514964512, 55.892706053597585, 31.590561594281876, 0.20805345236190728, 0.1414227248834712, 0.05362174553530557, 0.05021471942641905, 0.07721033013824906, 0.04722177270533783, 0.03423536901495286, 0.01691587462223002, 0.05964708221810205, 0.03407428819420082, 0.09153265053672449, 0.108729876311762, 0.10962450437779937, 0.08371984905430249, 0.1190552386854376, 0.12463357006864888, 0.1472520056579794, 0.09131604858807155, 0.15679751416402204, 0.3031507730484009, 0.18809559329279832, 0.16396551738892282, 0.35587905081255095, 0.131949493927615, 0.2312041036784649, 53.84127126421247, 80.19883183070591, 53.929204191480366, 38.5473690032959, 59.55369799477713, 59.567809786115376, 50.4131829398019, 42.68478502546038, 27.089120762688772, 24.485592535563878, 45.53976508549282, 32.07107469013759, 5.057156886373248, 15.824595246996198, 51.86368887765067, 73.01225444248745, 49.05322592599051, 55.15863234656197, 65.75891181400844, 57.71428401129586, 59.307773453848704, 29.46037244796753, 4.129447306905474, 0.11184804327785969, 8.904779178755623, 46.753195013318745, 44.519151142665315, 42.410091468266074, 44.55158185958862, 53.82316425868443, 56.59277180262974, 56.58432626724243, 58.62448065621512, 60.36515726361956, 61.303838048662456, 57.30327722004482, 57.35752180644444, 58.76925332205636, 50.529516628810335, 48.86641665867397, 50.76220137732369, 51.9270738192967, 55.707783222198486, 55.71592998504639, 54.93452862330845, 54.953827244894846, 55.285770484379356, 54.64374303817749, 49.96445785249983, 49.54563086373465, 52.936522006988525, 53.15425770623343, 49.22937318256923, 41.41635315758841, 39.385255745479036, 50.825457777295796, 53.65066480636597, 53.87896524156843, 57.756188596997944, 50.19532217298235, 38.785310064043315, 30.55370623724801, 27.9815491267613, 31.267164639064244, 32.164263929639546, 35.70644167491368, 39.11140292031424, 42.71058021272932, 42.51540184020996, 44.17960657392229, 40.878093583243235, 44.373072215488975, 46.816006728581016, 51.55290985107422, 50.00400352478027, 45.94020019258772, 49.812212399074006, 46.99104922158377, 41.98375695092337, 39.323222228458945, 38.70235552106585, 39.35219274248396, 40.57715667997088, 39.65668364933559, 36.01000499725342, 37.69332422528948, 41.212989807128906, 45.334796701158794, 45.83133234296526, 42.95476075581142, 42.63423340661185, 45.107444695064, 47.919231278555735, 45.273211342947825, 40.53226784297398, 31.731512750898087, 19.516041142599924, 18.696190186909266, 21.832942281450542, 25.920605727604457, 30.97003882271903, 40.03744145802089, 42.80591991969517, 40.506486552102224, 37.54344463348389, 35.139055252075195, 38.329761845724924, 42.25449350902012, 41.99628802708217, 43.699680600847515, 46.331321239471436, 49.54376179831368, 51.30904197692871, 50.957212993076865, 52.74681881495884, 51.773744446890696, 49.55605663572039, 48.13620615005493, 50.6831065586635, 49.80183873857771, 48.793530055454795, 51.553997244153706, 44.66062688827515, 44.51795605250767, 44.728250231061665, 18.936557906014578, 2.464744908469064, 20.755792583738053, 57.22041647774832, 45.46393592017037, 57.098565919058665, 48.19282354627337, 65.5612564086914, 63.74968038286482, 61.775162151881624, 53.356450285230366, 12.86560412815639, 6.822632917336055, 43.08515412466866, 30.423128741128103, 18.21752531187875, 21.486741338457378, 31.208744185311453, 36.77320555278233, 53.00911331176758, 28.732894318444387, 31.750877380371094, 33.30474124635969, 44.58751794270107, 65.79911409105573, 42.74259056363787, 1.0332821373428618, 0.19190900080970355, 0.18196010323507444, 0.22247937827238015, 0.15179035998880863, 0.22506660515708582, 0.0865127874006118, 0.26061178424528664, 0.14137376179652555, 0.12875777376549585], [0.038431273507220406, 0.030634756865245954, 0.04813239723443985, 0.018356248403766325, 0.09740391227283648, 0.0675111198797822, 0.004944437607524118, 0.022633302291589122, 0.0746719374188355, 0.012239193294330366, 0.12612199091485568, 0.10411096630351883, 0.021176940528675914, 0.02753801973137472, 0.3362939517412867, 6.585614229951586, 62.990249225071494, 50.559411253247944, 24.722194331032888, 38.78951372419085, 44.802140848977224, 32.53765664781843, 43.65300955091204, 23.42229754584176, 16.94745019504002, 27.26600452831813, 54.94339452471052, 10.435145105634417, 0.38735403759138926, 4.370963215827942, 35.05732011795044, 41.91004351207188, 48.55135754176548, 50.47664778573172, 53.32317188807896, 52.24111155101231, 38.91437980106899, 16.30676896231515, 1.0740679545061929, 0.11003066865461213, 10.576442803655352, 47.84840134211949, 41.117226260049, 36.96158511298043, 30.849438939775737, 37.012869766780305, 36.009463037763325, 36.6696218081883, 35.16628176825387, 33.49077231543404, 30.872006688799175, 32.33274037497384, 33.65803977421352, 35.74201645169939, 41.108638286590576, 44.82188762937273, 52.96167795998709, 53.940633978162495, 49.92984887531826, 46.684487751552034, 48.20510448728289, 44.962873526981895, 44.57236392157418, 42.126511165073936, 42.11036702564785, 42.737657342638286, 43.944569860185894, 33.56941550118582, 25.052166019167217, 39.04401929037911, 44.69705629348755, 46.320155484335764, 49.9716283934457, 44.63193430219378, 32.67296586717878, 17.967881747654506, 11.482787540980748, 12.192434855869838, 10.23973570551191, 8.32105667250497, 12.649846928460256, 18.878962550844463, 27.01823350361415, 29.561100482940674, 33.880389077322825, 34.3485552242824, 36.19305181503296, 42.671343735286165, 46.75815602711269, 47.59634849003383, 45.16148083550589, 40.5400150844029, 33.05685731342861, 29.76764610835484, 23.920094285692485, 23.189532893044607, 22.88018866947719, 23.54252396311079, 19.658982958112443, 18.139974730355398, 18.291582686560496, 23.462199313299998, 29.547273567744664, 35.16468020847866, 39.58831337520054, 40.65405586787632, 40.458370276859824, 41.38239731107439, 44.73760945456368, 40.98832327978951, 34.32398639406477, 22.984420333589824, 9.821350795882088, 10.803184236798968, 20.944674151284353, 19.996347529547556, 21.972832100731985, 33.05522796085903, 37.77888781683785, 36.8480862889971, 32.85029084341866, 25.10580611228943, 28.210775409426006, 35.40285055977957, 39.26332180840628, 38.22369064603533, 37.985037394932334, 40.350624561309814, 43.447537422180176, 45.58879157475063, 46.679509367261616, 53.32634721483503, 46.67994710377285, 36.96810599735805, 46.165752615247456, 47.806962285723, 42.75537872314453, 36.805445194244385, 17.32606622150966, 1.5579396358558109, 0.4246043616107532, 3.957526292119707, 40.17295912333897, 39.63111080442156, 49.03690808159964, 46.61743763514927, 53.958101749420166, 37.28922741753714, 42.49699258804321, 39.86252403259277, 10.101064426558358, 0.33794010483792847, 15.046282359531947, 48.138068267277305, 27.296201399394445, 12.35731213433402, 11.568980813026428, 21.522107669285365, 38.29049410138811, 28.466253723417008, 18.450807605470928, 27.66613565172468, 25.33158608845302, 41.64508090700422, 40.125527245657786, 14.227758509772164, 0.2069342631314482, 0.0974860285807933, 0.0670872051268816, 0.06636485031672887, 0.08412808286292212, 0.02054367397379662, 0.03659932055909719, 0.030770114423441033, 0.07187051738479308, 0.07570379919239453, 0.017219702247530222, 0.05381564709490963, 0.049104748094188314, 0.0194775987682598, 0.18847790706370557, 0.07719781795250517, 0.06755927551005568, 0.030138167619173015, 0.09908849759293453, 0.059412689081260135, 0.12547147939247744, 0.1342477598892791, 0.009117497097966927, 0.02537126912336264, 0.34357501247099465, 7.908774018287659, 72.00110394614083, 56.08486543382917, 24.781287022999354, 42.247962202344624, 51.994134357997346, 21.755674839019775, 36.387062890189036, 26.9013317993709, 21.342474154063634, 33.963996750967844, 63.038365500313894, 23.568612711770193, 2.852273085287639, 3.184572854212352, 34.03346831457955, 46.60255111966814, 55.881453445979524, 55.717722620282856, 60.87660721370152, 56.050190448760986, 44.89136961528233, 17.26720108304705, 1.7450001239776611, 0.5156004130840302, 10.285307203020368, 54.59160723005022, 46.42491347449166, 44.36732258115496, 37.51985897336687, 39.68927417482649, 39.21820020675659, 39.636843068259104, 40.398046016693115, 40.13522693089077, 37.47012376785278, 38.45918941497803, 37.45501838411604, 38.496813910348074, 43.790371962956016, 47.193366868155344, 54.256644998277935, 54.70830569948469, 52.58770506722586, 50.05890471594674, 51.31679269245693, 48.14460999625069, 45.599728039332796, 47.228552545819966, 45.73732669012887, 44.551230975559776, 45.1136668069022, 36.7570093018668, 31.354215145111084, 41.676966190338135, 47.41742890221732, 48.863057204655235, 53.685426643916536, 49.29168810163225, 40.096455982753206, 26.403936317988805, 17.906477042606898, 16.637350354875835, 16.553980657032557, 16.6769985130855, 20.28755521774292, 24.84706735610962, 30.695393902914866, 33.703303813934326, 37.627653326307026, 38.954293727874756, 41.18458904538836, 48.180302892412456, 52.50729703903198, 50.11526850291661, 49.455894878932405, 45.98598882130214, 42.35009724753243, 37.69113554273333, 32.70603929247175, 30.276737145015172, 30.91473811013358, 29.88936812537057, 28.220551524843486, 25.22419125693185, 25.444551638194493, 30.111255373273575, 36.84268406459263, 40.5870543888637, 42.448355197906494, 44.385627610342844, 44.55661582946777, 44.28240517207554, 46.00227887289864, 41.45885181427002, 34.91727570125035, 21.837337017059326, 12.085751346179418, 13.712179592677526, 22.21079053197588, 21.72152965409415, 24.516129868371145, 36.13817146846226, 41.69829021181379, 36.80900962012154, 34.09675598144531, 28.21393162863595, 31.57125949859619, 39.92918504987444, 41.4794636453901, 42.1226236479623, 40.260200704847065, 42.66349227087838, 48.51631082807268, 49.41681473595755, 49.95119374138968, 55.88532359259469, 49.24206754139492, 39.67024653298514, 45.13807235445295, 48.614259583609446, 45.48587485722133, 39.40131650652204, 11.627020852906362, 2.431772666318076, 1.3379706335919244, 8.118287393024989, 44.15536778313773, 44.25634247916085, 51.873378140585764, 53.05596154076712, 56.18201862062727, 39.43964276994978, 50.98883771896362, 42.961924348558696, 6.087081849575043, 2.76483000602041, 24.952165807996476, 49.94703524453299, 27.39118501118251, 19.08936616352626, 16.371258667537145, 27.577144861221313, 29.78766734259469, 24.98188672746931, 25.617464508329117, 27.801601205553325, 19.97705933025905, 48.055172783987864, 50.9000814301627, 16.742424488067627, 0.08829060343227216, 0.07701861006872994, 0.08275279416037457, 0.1098790160779442, 0.051193903133805306, 0.03557227638417056, 0.06469611557466642, 0.05745882035366126, 0.048009833454021385, 0.03195461264944502, 0.08983525447547436, 0.08055733982473612, 0.17406028642186097, 0.10278014200074331, 0.3042768154825483, 0.18890117720833846, 0.15631222591868468, 0.1285833902657032, 0.20323867643518106, 0.15001786367169448, 0.3076083409999098, 0.3948555679193565, 0.17379814120275633, 0.13417147898248263, 0.48078581265040804, 13.264469810894557, 87.47837611607143, 61.83692468915667, 39.19881820678711, 47.50724131720406, 61.30301121303013, 47.498910427093506, 54.07396990912301, 30.118394647325786, 24.21267076901027, 34.36310127803257, 63.845238958086284, 15.722906623567853, 1.3587229486022676, 7.462160314832415, 44.19358287538801, 51.917002405439106, 59.48859337397984, 59.75260407584054, 63.505652700151714, 62.28892585209438, 48.096736907958984, 20.43121443475996, 3.0433474608830045, 0.2531107696039336, 14.866179840905325, 63.190336499895366, 57.23190879821777, 53.17565815789359, 45.92479256221226, 47.29225710460118, 45.05273110525948, 47.249595165252686, 45.35609640393938, 46.99355752127511, 43.57344920294625, 45.02213471276419, 41.25454003470284, 41.524738107408794, 47.2468957901001, 50.54898548126221, 57.3996695790972, 59.15599700382778, 56.36492300033569, 55.513692242758616, 55.70263113294329, 51.36632987431118, 51.930968284606934, 51.31438166754586, 50.25124822344099, 49.416543756212505, 50.58448730196272, 40.48739290237427, 38.25107002258301, 48.6384254183088, 52.98169224602835, 52.32161337988717, 56.0624783379691, 52.8827360016959, 48.806616987500874, 38.467819077628, 30.1485150882176, 30.482514994485037, 35.54772744859968, 38.84621449879238, 39.900075571877615, 42.847761971609934, 47.445117473602295, 46.95168767656599, 47.26125424248831, 42.956744466509136, 42.351327078683035, 50.27294397354126, 52.54553644997733, 51.37746088845389, 52.20502608163016, 51.34799705232893, 47.99430309023176, 45.592199666159495, 37.48793894904, 39.24857773099627, 41.53668553488595, 46.431993688855854, 41.93061712809971, 38.062405586242676, 41.68147209712437, 45.491464682987754, 46.33434023175921, 44.851261138916016, 44.3045768737793, 46.68068013872419, 46.56399556568691, 46.83718483788626, 49.351466928209575, 44.36374773297991, 38.55535248347691, 25.588245596204484, 17.396586963108607, 18.5037841456277, 27.42253007207598, 26.259976591382706, 27.023927552359446, 43.373122215270996, 45.08927515574864, 41.24027190889631, 39.25725255693708, 30.530044146946498, 35.96422331673758, 42.54919787815639, 45.66309561048235, 46.715233530317036, 45.40854835510254, 45.98368549346924, 50.01641648156302, 49.37382623127529, 51.73205872944423, 55.738351821899414, 51.5762870652335, 44.05703340257917, 45.59477744783674, 47.763807024274556, 47.81196846280779, 46.388841901506694, 22.858188935688563, 1.7529662336621965, 0.5891522520354816, 8.136389187404088, 47.12675448826381, 47.5633202280317, 57.67319931302752, 53.11327028274536, 60.66555568150112, 44.16226387023926, 52.388607910701204, 46.26889862333025, 15.613771268299647, 1.64220586844853, 19.92232836995806, 54.10016809191023, 32.5520533152989, 21.701166221073695, 22.614666734422954, 32.855595793042866, 48.50694465637207, 38.74002865382603, 24.47779491969517, 36.35736281531197, 35.677439893995015, 55.17613138471331, 64.64405945369175, 24.24585883957999, 0.308031258306333, 0.24905779851334436, 0.14789275984678948, 0.14063863695732184, 0.1706720082355397, 0.0801830802645002, 0.1430648203407015, 0.1218075802815812, 0.21572293367769035, 0.19342271744140557], [0.039213773661426136, 0.0464955977430301, 0.07033111141728503, 0.07293757476976939, 0.022505910734512975, 0.024947941303253174, 0.06600574922880956, 0.10419709275343589, 0.0806895320170692, 0.05315677262842655, 0.15538093660558971, 0.057826715255422254, 0.06166707418326821, 0.01741936626578016, 0.045303815443600924, 0.3580044396221638, 38.35849264689854, 55.7256053515843, 30.702310834612163, 38.27783448355538, 60.08134419577462, 37.54510177884783, 42.62238325391497, 32.47233315876552, 19.64104097230094, 16.09103955541338, 46.874962193625315, 59.76367950439453, 8.475259780883789, 1.3252832229648317, 18.10756138392857, 43.94030019215175, 53.5285085269383, 51.807908739362446, 42.334220613752095, 57.150274412972585, 51.21506411688668, 31.593483311789377, 6.334810316562653, 0.6852836736610958, 1.1507824723209654, 8.94534102508, 17.12233461652483, 12.725415536335536, 18.983552047184535, 17.651462520871842, 19.21847758974348, 18.801735060555593, 19.132780245372228, 19.614297355924332, 26.37954466683524, 30.86984232493809, 32.25570569719587, 35.995733397347585, 40.769291741507395, 47.99396957669939, 51.502775124141145, 52.78268541608538, 49.61078412192208, 45.32419375010899, 44.268877029418945, 45.56702286856515, 42.59452445166451, 40.65410450526646, 40.15283366612026, 38.23004477364676, 32.3270845413208, 28.541756323405675, 38.7913167817252, 48.30737154824393, 49.63268484388079, 49.49881737572806, 50.82417236055647, 41.32794427871704, 30.949680600847515, 19.54621022088187, 14.290109038352966, 14.035542675427028, 13.376745751925878, 14.16344598361424, 19.984632866723196, 26.370286192212784, 33.6104793548584, 37.563406808035715, 35.9056430544172, 34.982967444828574, 38.06951706750052, 46.76851579121181, 48.96409443446568, 44.00354616982596, 42.85578714098249, 41.44995812007359, 35.2611003603254, 28.945609944207327, 26.370070798056467, 28.481275728770665, 29.1268241746085, 27.917373827525548, 25.711662973676408, 23.80106816973005, 25.222890206745692, 29.04492575781686, 32.38089139120919, 38.346850940159385, 39.739686829703196, 41.44505616596767, 39.30780070168631, 38.52655914851597, 42.53472825459072, 43.33665459496634, 41.31703560692923, 32.277060985565186, 22.93622589111328, 13.012479492596217, 16.343366861343384, 26.299440622329712, 26.08945390156337, 24.41132324082511, 33.89183276040213, 38.73057215554373, 37.127101625714985, 31.338866574423655, 31.88369914463588, 30.776218823024205, 34.390268734523225, 35.155150754111155, 36.666404792240684, 35.80817025048392, 37.77436106545584, 39.59927068437849, 41.37165887015206, 36.87000438145229, 46.85002163478306, 43.7894652230399, 40.03646871021816, 35.40070356641497, 25.098745005471365, 7.731422986303057, 0.16622514756662504, 0.31092995990599903, 0.7430316177862031, 12.886071784155709, 50.396559374673025, 46.310952595302034, 51.32451908929007, 43.50315080370222, 33.40113707951137, 32.283293519701274, 42.3183787209647, 14.426158240863256, 2.8152029258864264, 5.766991802624293, 51.406004088265554, 49.893909318106516, 18.492771250861033, 11.140640003340584, 22.2345255783626, 26.553617886134557, 39.50339944022042, 21.269895008632115, 24.467035634177073, 32.11834328515189, 23.185483830315725, 49.46054669788906, 27.1954733644213, 3.622930360691888, 0.13644230498799256, 0.05292913091502019, 0.08960421330162457, 0.05200557350846274, 0.06237376840519054, 0.03920319190781031, 0.020562031738726155, 0.0523356774023601, 0.039187802733587365, 0.09626963920891285, 0.024387342456196035, 0.07372185268572398, 0.07885115673499447, 0.04771630259762917, 0.04842741747519799, 0.0340433232486248, 0.08312579164547579, 0.16160042929862226, 0.006741256860550493, 0.12049726130706923, 0.1498708658452545, 0.04705388278567365, 0.025382899213582277, 0.08649202422904116, 0.033743824676743576, 0.7678855955600739, 44.583352497645784, 63.86096967969622, 33.18141072137015, 34.38940020969936, 67.38715267181396, 32.70529930932181, 28.735296658107213, 35.63083137784685, 24.765283584594727, 23.65583344868251, 50.41518749509539, 53.44927127020699, 17.143776757376536, 2.694997787475586, 17.805250474384852, 46.08654315131051, 55.7954694884164, 58.36839090074812, 48.3164632661002, 61.333131653921946, 52.272107464926584, 38.63307850701468, 5.050065815448761, 2.861056693962642, 2.2974487883704047, 6.794766298362187, 17.301083973475865, 10.609624794551305, 20.104689053126744, 24.22961221422468, 29.463509559631348, 25.15839355332511, 23.944355658122472, 23.72790711266654, 30.36169276918684, 33.401626927512034, 35.56349638530186, 39.572864055633545, 43.57875762666975, 51.3517803464617, 53.9933499608721, 53.66153526306152, 51.388074261801584, 49.54058994565691, 46.81438432421003, 47.34590762002127, 45.30554825919015, 44.52787113189697, 43.077792508261545, 40.18091133662632, 34.746457712990896, 32.26056248801095, 40.151680265154155, 47.835039956229075, 49.903247697012766, 52.05878039768764, 50.49474089486258, 50.22871174131121, 38.640217781066895, 24.867752143314906, 19.027753012520925, 19.16870938028608, 20.446889570781163, 21.895799160003662, 25.852501222065516, 30.595937388283865, 36.53233930042812, 41.516577448163716, 40.49596003123692, 39.894878319331575, 43.48605476106916, 50.148282868521555, 52.88438967296055, 49.604513372693745, 49.0916633605957, 49.85467978886196, 43.354223115103586, 35.24506391797747, 33.28632852009365, 34.00073882511684, 33.41599232809884, 35.914717401777, 34.16485527583531, 30.47481291634696, 31.853453636169434, 35.411521911621094, 37.84850181852068, 41.39670712607247, 41.506738798958914, 42.70022392272949, 43.12833023071289, 42.80380766732352, 43.404986654009136, 44.694471563611714, 39.73123434611729, 31.287137235913956, 23.406644991465978, 15.425346544810704, 19.01145601272583, 27.950087683541433, 28.536031007766724, 25.494517871311732, 36.2112352507455, 40.851568835122244, 37.417199339185444, 34.40724318368094, 35.388954162597656, 33.15096371514456, 38.34198372704642, 37.124409198760986, 39.83903217315674, 38.54561458315168, 39.83447068078177, 41.165585722242085, 43.77783046449934, 38.96904822758266, 47.72697809764317, 47.76298713684082, 44.92629820959908, 37.253284386226106, 25.51609376498631, 6.571597542081561, 0.5273104075874601, 2.002301037311554, 1.4502795785665512, 16.4936911378588, 55.53266429901123, 49.176723207746235, 55.14730330875942, 47.338612011500764, 35.78491810389927, 34.73186649594988, 43.68772622517177, 13.293034723826818, 5.382525827203478, 15.510658264160156, 51.64094352722168, 48.52990845271519, 21.66124013492039, 16.745902061462402, 26.077928577150615, 30.787485327039445, 26.997312477656774, 23.086213179997035, 28.846900360924856, 30.345274175916398, 21.674688373293193, 57.46871382849557, 38.52685097285679, 4.654682917254312, 0.05158632707649043, 0.14523146407944815, 0.0897781014708536, 0.06955621764063835, 0.09095641145748751, 0.06076694319822958, 0.02918294637597033, 0.08340359066746064, 0.043101898061909845, 0.07823592224823576, 0.18003200526748384, 0.1757224393742425, 0.13541659074170248, 0.15397113082664354, 0.14422700154994214, 0.06940564393465008, 0.23223213851451874, 0.33060926677925245, 0.2048684632671731, 0.14163526919271263, 0.26681288863931385, 0.12573141258742127, 0.16668002387242659, 0.16207053193024226, 0.2416195347905159, 1.2919946206467492, 65.3658035823277, 73.43190479278564, 44.6545923777989, 47.32205098015921, 69.73933328901018, 54.036366258348735, 50.780600207192556, 41.130942004067556, 25.58336101259504, 21.867217745099747, 53.19106926236834, 67.09423051561627, 12.702687978744507, 3.3421677691595892, 22.050806522369385, 52.6547760282244, 61.11870329720633, 64.02829619816372, 51.548463003976, 66.98180171421596, 58.56019592285156, 40.21085459845406, 8.569471274103437, 3.0684237267289842, 1.4238843492099216, 10.771001917975289, 21.64089928354536, 14.009359257561819, 28.02357530593872, 34.16153056280953, 41.056825569697786, 31.936130251203263, 27.96819642611912, 26.08857148034232, 34.14252723966326, 37.295404366084504, 39.367951256888254, 44.50500808443342, 46.036804471697124, 54.047935009002686, 57.84884282520839, 58.133830138615195, 56.399431228637695, 52.75541721071516, 51.90619795663016, 51.95900774002075, 52.06531170436314, 49.41466426849365, 49.60688965661185, 45.568301337105886, 40.49639081954956, 38.89109638759068, 46.301916463034495, 55.59058795656477, 52.294942719595774, 57.55311707087925, 52.4489460672651, 51.42738716942923, 45.06542893818447, 38.121934277670725, 35.96969154902867, 39.09481757027762, 40.966057777404785, 41.8999616759164, 44.92911570412772, 44.11563103539603, 47.15594734464373, 53.32904658998762, 46.042620113917756, 42.47364664077759, 44.74481126240322, 50.48142467226301, 54.670785427093506, 46.05499832970755, 49.539794376918245, 52.75202996390206, 49.71181092943464, 40.77482598168509, 39.066309111458914, 41.92061867032732, 41.98380558831351, 47.35696567807879, 45.825693879808696, 43.412987504686626, 45.5357003893171, 46.99521814073835, 46.69893305642264, 46.44126605987549, 44.37295757021223, 43.850362709590364, 45.407565185001914, 44.17873110089983, 45.52519471304757, 46.41592597961426, 45.14501707894461, 37.44057307924543, 28.882786069597515, 22.344645840781077, 23.240275587354386, 33.66614832196917, 31.907382079533168, 29.591686453138077, 41.205649035317556, 45.92743287767683, 42.55277967453003, 40.65370150974819, 41.014893191201345, 37.05221046720232, 42.02127374921526, 42.02159684044974, 45.19728142874581, 42.820320061274934, 42.808615820748464, 44.76544393811907, 47.98305395671299, 42.698073455265586, 50.05669518879482, 47.51970638547625, 47.979128224509104, 46.162928172520225, 34.72471679959978, 10.764338595526558, 0.19777708021657808, 1.2221769498927253, 2.439813469137464, 16.092689752578735, 58.65175928388323, 52.92545700073242, 58.62040206364223, 49.67547879900251, 40.4116644859314, 37.4180782863072, 51.581189019339426, 20.057118211473735, 5.943707508700235, 8.747310417039053, 58.605810846601216, 53.086929661887034, 23.833121946879796, 18.358294078281947, 33.90682349886213, 37.39869628633772, 50.51895884105137, 30.51956626347133, 31.038099902016775, 41.96328408377511, 33.77324090685163, 67.25060667310441, 52.15366152354649, 9.17369270324707, 0.45435790504728046, 0.13923180316175732, 0.2023789318544524, 0.16980591256703648, 0.1340309272387198, 0.12895737162658147, 0.07608064397105149, 0.21323940051453455, 0.10053651846413102, 0.2626097984611988], [0.05633272024403725, 0.06295956804284028, 0.015494947654328175, 0.017519507856507386, 0.06753914337605238, 0.030526998718934398, 0.03117602764229689, 0.04727648298389145, 0.03200908883341721, 0.021484605269506574, 0.04868265860048788, 0.1716452445834875, 0.10879406572452613, 0.06248145191265004, 0.11243387005691018, 0.17015824866081986, 10.415718810898916, 63.84148693084717, 36.12404578072684, 31.735671247754777, 28.249890293393815, 36.11403342655727, 41.508750302451, 35.8184883253915, 18.856943709509714, 18.146785702024186, 19.75150169645037, 72.97105857304165, 49.47248370306832, 2.4303463314260756, 9.638501133237567, 38.15087005070278, 53.99124813079834, 54.60535076686314, 47.31428984233311, 52.182427065713064, 51.28340312412807, 42.42536013466971, 15.78620297568185, 1.7942065064396178, 1.4007117812122618, 0.4666914460914475, 4.473304969923837, 14.775394678115845, 3.331637122801372, 4.813968632902418, 6.502571097442082, 10.990967988967896, 16.805510657174246, 18.306967735290527, 25.885096958705358, 29.93018879209246, 31.519585745675222, 34.043258326394216, 36.144160815647666, 40.587915965488975, 47.7155795778547, 50.09199551173619, 49.33136578968593, 45.35689197267805, 47.2345175743103, 47.10957506724766, 47.69138247626168, 48.61841460636684, 41.799094676971436, 33.37316015788487, 27.385909591402324, 38.697199957711355, 45.18141174316406, 48.575200285230366, 48.358485971178325, 44.8458901814052, 46.04118878500802, 44.84141206741333, 35.49836049761091, 24.25393785749163, 17.25233714921134, 19.598076786313737, 19.13842565672738, 21.405160801751272, 27.1139258316585, 34.427552768162315, 38.34972749437605, 41.88044418607439, 40.520129340035574, 36.24017449787685, 41.2989251273019, 45.744042124067036, 48.947679315294536, 44.815005438668386, 46.41299383980887, 44.44385698863438, 37.27400391442435, 32.26130594526018, 30.34647274017334, 31.918867451804026, 33.34034729003906, 33.66528674534389, 30.729856967926025, 25.784504413604736, 25.43317222595215, 30.9275575365339, 34.099201747349326, 38.02292244774954, 38.84766319819859, 39.88152040754046, 42.69531502042498, 40.72965921674456, 39.277576037815635, 39.08422156742641, 38.35049179622105, 35.063316413334434, 29.55842195238386, 19.518922907965525, 16.684374025889806, 24.099008662360056, 32.87863949366978, 28.374132769448416, 28.076866252081736, 35.595597062792095, 38.026636259896414, 35.61816828591483, 36.11656257084438, 31.712210655212402, 33.591548987797324, 31.121613774980815, 25.532161474227905, 26.573717287608556, 27.030493600027903, 26.58124566078186, 33.366048676627024, 34.582858903067454, 35.19817399978638, 26.86123721940177, 15.980726480484009, 11.342142973627363, 1.7325993265424455, 0.10861088162554161, 0.1984070185571909, 1.1070801487990787, 7.837205835751124, 34.21972867420742, 48.34645169121878, 48.09130341666085, 46.99736166000366, 41.499828815460205, 36.071350642613, 55.930358341761995, 44.669405937194824, 13.86864868232182, 1.6144543290138245, 23.72423151561192, 49.95084980555943, 18.918299777167185, 12.497609291757856, 19.345106772014073, 28.82735160418919, 27.312824964523315, 38.71044669832502, 16.89536997250148, 30.816514900752477, 23.93960656438555, 27.124521834509714, 42.72138466153826, 28.461574111665996, 0.7538287926997457, 0.08014943849827562, 0.01966995496435889, 0.09478578490338155, 0.07742462506783859, 0.030606075190007687, 0.014511633365015899, 0.052190979809633324, 0.05325371153386576, 0.038126017565705946, 0.01751035950811846, 0.022687998999442373, 0.04198404215276241, 0.04750311028744493, 0.02391117372150932, 0.04260572611487337, 0.026788621908053756, 0.03462586931086012, 0.027889466944283674, 0.04270161668370877, 0.04749551748058625, 0.17959322381232465, 0.10135012944894177, 0.08614833267139536, 0.04512560161362801, 0.1273404091064419, 0.1783574622656618, 13.501493709427969, 77.50030435834611, 42.53317533220564, 29.963592256818497, 35.258112634931294, 38.74356528690883, 28.78947697366987, 33.953029019492014, 25.423891169684275, 24.850187097276958, 27.253603730882915, 70.21443026406425, 47.2230669430324, 5.547772662980216, 9.600242614746094, 40.27306876863752, 60.08582578386579, 59.73808234078543, 50.49960463387625, 59.01888820103237, 55.05049753189087, 42.95452799115862, 17.833126647131785, 2.7601104421275, 2.1404160261154175, 0.9222799965313503, 7.715849467686244, 19.839823722839355, 4.327582137925284, 6.116832733154297, 8.987197841916766, 15.061962706702095, 20.54150492804391, 22.37369625908988, 30.077702522277832, 34.72926092147827, 33.36839369365147, 38.04423952102661, 38.9199800491333, 42.961795806884766, 50.00714758464268, 52.27479641778128, 51.65636852809361, 49.647567885262625, 48.74756077357701, 48.54396118436541, 48.616573333740234, 47.51111146381923, 42.60387325286865, 35.46133702141898, 31.229053769792827, 40.3092827796936, 47.26731654575893, 47.362986292157856, 51.53935391562325, 49.31705944878714, 48.464835098811555, 47.2934695652553, 40.36814444405692, 29.793166841779435, 22.394678081784928, 23.266340017318726, 25.805255208696636, 30.479110377175466, 33.630695138658794, 39.119459356580464, 41.96160609381539, 46.86319889341082, 45.4091910634722, 42.075410638536724, 45.96013110024588, 50.9742499760219, 54.473623343876426, 48.67703308377947, 48.38247115271432, 49.896789346422466, 43.83015387398856, 36.65736518587385, 35.23338399614607, 37.19976936067854, 39.39269379207066, 42.901415961129324, 39.46112659999302, 35.72550753184727, 35.331020082746235, 39.96455485480172, 41.530407837459016, 42.06000648226057, 42.03658757890974, 41.989735875810894, 43.722439425332205, 43.285609654017854, 42.1961008480617, 40.95870658329555, 41.02487775257656, 37.34891939163208, 31.17250238146101, 22.676938227244786, 19.103842735290527, 26.084234067371913, 33.902984619140625, 31.114797592163086, 30.270699160439626, 38.017641816820415, 39.74502304622105, 37.951620033809114, 37.865715980529785, 34.54727022988455, 36.69834566116333, 34.229011467524934, 28.183192798069545, 29.829766477857316, 29.525390216282435, 29.50046702793666, 35.712038448878694, 37.31891707011631, 36.960615839277, 27.932279450552805, 15.26624321937561, 9.158388427325658, 3.1271179829324995, 0.6881812896047319, 0.39180864713021685, 1.6530084716422218, 10.896048648016793, 39.52989639554705, 55.16013315745762, 52.2303592136928, 51.2290369442531, 43.11351319721767, 41.07644380841936, 59.60669885362898, 47.8865886415754, 15.642413479941231, 4.788626381329127, 24.62013919012887, 44.031318119594026, 18.274014166423253, 16.86371919087001, 23.784248317990983, 30.379424571990967, 26.952434062957764, 27.520138365881785, 23.312686238970073, 33.162146840776714, 22.991717679159983, 28.11854328427996, 55.92568220411028, 36.57756165095738, 0.8312448614409992, 0.12081102947039263, 0.06861673162451812, 0.0522323093776192, 0.09219489392957517, 0.059333951877696176, 0.07194009436560528, 0.07496792117932013, 0.02923257781990937, 0.03137588673936469, 0.06259730498173408, 0.19086837236370358, 0.121034050360322, 0.1823032112526042, 0.1827816055821521, 0.1429247028593506, 0.14964667787509306, 0.14100280670183046, 0.1590951287320682, 0.12407540716230869, 0.15715770769332135, 0.18727178392665728, 0.21705366298556328, 0.29306220582553316, 0.2518763786980084, 0.3006505343530859, 0.2684724767293249, 20.91457976613726, 90.24713597978864, 50.673194953373496, 44.78646223885672, 36.751919746398926, 52.68178020204817, 55.9355034828186, 44.37036936623709, 26.003438677106583, 25.816443545477732, 24.389990534101212, 78.68242917742047, 55.515321595328196, 5.428036962236677, 14.524267673492432, 45.045755113874165, 65.41641426086426, 64.50235094342912, 56.20488166809082, 62.095557485307964, 59.55783217293875, 48.45605257579258, 20.093227999550955, 3.411620225225176, 2.309817667518343, 0.3632853148238999, 10.152865852628436, 20.262510435921804, 5.96206682068961, 6.135021814278193, 13.026537435395376, 23.121100085122244, 24.913431337901525, 29.035292080470494, 35.80906309400286, 40.03790003912789, 35.712399755205425, 43.361508301326204, 44.97448744092669, 46.16194500241961, 52.5284230368478, 56.54467289788382, 55.65282644544329, 53.38006026404244, 53.12866054262434, 53.24978848866054, 53.56509774071829, 55.61007765361241, 49.04257433755057, 42.095633370535715, 37.8494085584368, 47.800729751586914, 53.20844323294503, 54.06512485231672, 55.1278691973005, 52.22940731048584, 51.65758793694632, 50.22782932009016, 49.82189471381051, 43.74561166763306, 38.88221658979143, 43.93212563650948, 44.05883993421282, 46.85342277799334, 45.790192059108186, 49.768445696149556, 49.80523293358939, 51.29604537146432, 49.41947589601789, 42.99868031910488, 48.23968914576939, 51.42215517589024, 55.12673316683088, 46.42054305757795, 50.00288833890642, 54.16969871520996, 48.09274516786848, 42.05938114438738, 40.80475534711565, 41.80521256583077, 45.15329238346645, 49.72165652683803, 47.81122153145926, 45.96586683818272, 43.545979499816895, 48.926438672201975, 48.69417428970337, 45.091536794389995, 43.601940291268484, 43.359469005039756, 46.17848866326468, 44.84802327837263, 42.64730991636004, 41.61468948636736, 44.565363611493794, 43.32489824295044, 37.33874722889492, 26.28847462790353, 24.181601899010793, 32.11103030613491, 40.49056475503104, 35.35169792175293, 34.49708686556135, 42.10107381003243, 43.77487400599888, 42.41759899684361, 42.416900702885215, 38.922279902866904, 43.374768938337056, 39.607010977608816, 33.33966984067644, 34.274633339473176, 33.041692870003835, 33.78968729291643, 39.48344073976789, 42.76052039010184, 40.76776313781738, 35.10642998559134, 25.099068096705846, 13.705706477165222, 3.8600013766969954, 0.5865264300789151, 1.0069056898355484, 6.11842691046851, 11.073770540101187, 38.69244391577584, 57.27631820951189, 56.076075962611604, 54.30473348072597, 47.570942401885986, 44.760698318481445, 63.73231683458601, 52.84411791392735, 19.566901956285747, 4.605253432478223, 28.593529088156565, 55.100719111306326, 22.170523984091624, 18.37979701587132, 27.530538082122803, 38.928818157741, 36.44490316935948, 53.23999152864729, 23.880691051483154, 39.40999828066145, 36.7116688319615, 37.030646732875276, 61.25602749415806, 48.02864456176758, 1.6382319331169128, 0.2539791858622006, 0.17886392080358096, 0.14721241992499146, 0.15835967819605554, 0.1390880758741072, 0.12548218667507172, 0.10964514541306666, 0.1538679799331086, 0.12648176375244344, 0.29847737667816027], [0.015331130641113435, 0.03342389541545084, 0.024510596645995975, 0.035731447128845115, 0.03257769100101931, 0.034085592587611506, 0.0036046396791269736, 0.06845302826591901, 0.07458855225039379, 0.1340750048735312, 0.0845437737713967, 0.06849828655166285, 0.04742863767647317, 0.11112173260854823, 0.03932932817510196, 0.10170305586819138, 3.129686427967889, 46.858196190425325, 50.400342668805806, 27.609909091676982, 29.831142221178325, 31.212676865713938, 38.16059752873012, 40.679552282605854, 31.502329894474574, 18.605636051722936, 21.22962498664856, 27.123943396977015, 63.3173565183367, 11.266940883227758, 2.6927300691604614, 24.191499607903616, 46.04231786727905, 57.45261485236031, 55.691281250544954, 54.76428386143276, 47.76323727199009, 49.152925627572195, 17.305471760886057, 8.901439700807844, 2.00188501392092, 0.9397388654095786, 9.94080422605787, 25.130242926733835, 16.15033721923828, 4.9212475163596014, 12.064905881881714, 9.571959103856768, 10.75180925641741, 16.608105387006486, 24.5055217061724, 30.346253871917725, 34.607205390930176, 33.88832739421299, 30.576524121420725, 35.29559816632952, 43.384413037981304, 47.456446511404856, 46.978764806474956, 46.5371789932251, 48.486794880458284, 50.35917459215437, 49.18531812940325, 43.13021666663033, 34.03492743628365, 27.47090690476554, 36.34589828763689, 47.4699399130685, 51.4066606930324, 47.3675651550293, 45.81780767440796, 43.43854297910418, 46.78946113586426, 46.513516902923584, 39.20422737939017, 30.03855984551566, 24.10221004486084, 22.62652383531843, 25.29616069793701, 27.997554302215576, 31.684129510607036, 37.599662508283345, 41.77432434899466, 42.38158648354666, 41.913298743111746, 36.829079491751536, 41.648693970271516, 49.10283258983067, 47.726887771061485, 44.39230135508946, 46.4268867628915, 46.34057623999459, 40.23814364842006, 34.402052879333496, 32.30096973691668, 36.718637875148225, 37.30696964263916, 35.213418347494944, 32.682005473545615, 25.633693763187953, 24.797335624694824, 29.09631289754595, 35.2149087360927, 39.53648328781128, 40.44232341221401, 42.27356284005301, 40.157614026750835, 40.71004097802298, 37.39196000780378, 39.403810909816194, 36.48031118937901, 30.432050228118896, 26.25315867151533, 24.18542514528547, 18.736580065318517, 17.501273734228953, 33.398041657039094, 36.47823715209961, 30.730124473571777, 26.752847058432444, 22.573257207870483, 28.750336033957346, 31.85856056213379, 32.8718615259443, 34.529041630881174, 32.54795387813023, 31.600653852735245, 27.69880781854902, 25.71613413946969, 26.396156072616577, 18.398690904889786, 12.643831525530134, 7.091509529522487, 2.0514324009418488, 0.7569165070142064, 1.5727262709821974, 8.274138961519514, 4.060008312974658, 3.9935418452535356, 6.327750512531825, 13.920244268008641, 42.85309818812779, 45.9156174659729, 42.473163740975515, 46.28580011640276, 50.4846625328064, 58.42246873038155, 46.91211073739188, 45.756302220480784, 11.140229191098895, 7.076170078345707, 73.41129643576485, 60.36501135144915, 32.72363907950265, 13.882871644837515, 21.20063362802778, 24.991774014064244, 36.40894276755196, 24.91722331728254, 15.581053938184466, 29.003332104001725, 23.1953798021589, 36.61275427682059, 49.797864368983674, 9.105401464870997, 0.10271401197782584, 0.06866017822176218, 0.02199016814120114, 0.0639314880328519, 0.07903076495443072, 0.001381556033655735, 0.01958013219492776, 0.08325328159012965, 0.055998758878558874, 0.027468195085280707, 0.03055289840059621, 0.004951337460494999, 0.06526888055460793, 0.019084645568260124, 0.05464161080973489, 0.09206656260149819, 0.027964092225634625, 0.09288606327027082, 0.08518684854997055, 0.040022831676261764, 0.03688719243343387, 0.08387061953544617, 0.08447280579379626, 0.05858713588012116, 0.0715948421774166, 0.0670476465352944, 0.038262640591710806, 3.535691167627062, 55.0354129927499, 60.248198236737935, 30.290015152522496, 33.876067297799246, 40.87515102113996, 28.572931153433665, 32.27516760144915, 34.32478543690273, 23.934584753853933, 27.443517105919973, 34.36621754510062, 58.08373015267508, 14.931473800114222, 4.038519271782466, 25.4562280859266, 50.92638383592878, 63.82561724526541, 60.76476900918143, 60.019685881478445, 51.37264231273106, 52.07600498199463, 20.929931810923986, 10.253482716424124, 3.8358568208558217, 1.5814403976712907, 12.053665433611188, 36.19018220901489, 29.571488039834158, 7.465700422014509, 14.642095225197927, 12.563227210726057, 15.638213293892996, 18.482307263783046, 26.537833315985544, 32.01308502469744, 37.66618456159319, 36.517515318734304, 34.16423341206142, 39.346523012433735, 47.11036368778774, 49.91529239927019, 50.035937445504324, 49.25136423110962, 50.778324672154014, 52.039891719818115, 51.525895254952566, 47.33750377382551, 36.766601290021626, 28.94264132635934, 36.918381214141846, 45.097609519958496, 49.759406089782715, 49.00215319224766, 50.36655705315726, 47.31759718486241, 50.33433130809239, 52.81978184836251, 44.38557897295271, 36.668979099818635, 29.951370375497, 30.274204526628765, 34.049740995679585, 36.72928598948887, 40.56365980420794, 43.70962347303118, 46.84191656112671, 47.72781188147408, 48.51542145865304, 42.427423749651226, 46.87372541427612, 53.23016677583967, 52.230216775621685, 48.588429655347554, 52.55848789215088, 52.20103434153965, 46.33612591879708, 37.84542029244559, 36.41757590430123, 40.57434613364083, 41.80499022347586, 44.00276102338518, 41.19122110094343, 37.11617905752999, 37.845847606658936, 39.50238847732544, 40.82448475701468, 43.037221976688926, 41.71216923849923, 42.7159720148359, 43.26239224842617, 43.03045095716204, 39.311156681605745, 40.32688256672451, 38.22979463849749, 34.37058796201433, 30.373122555868967, 28.515818698065623, 23.35247336115156, 19.964227744511195, 34.835474559238975, 37.993708746773855, 32.60696840286255, 27.293264048440115, 25.66930501801627, 31.7231262751988, 35.22971534729004, 36.21899291447231, 38.1020450592041, 35.47336087908064, 35.864283902304514, 30.16668462753296, 28.192638874053955, 26.18534599031721, 19.976157801491873, 12.993485723223005, 8.801409091268267, 2.6782059456620897, 1.7766539454460144, 3.3013738095760345, 14.025354879243032, 4.787224582263401, 6.696616045066288, 8.009568929672241, 18.723651204790386, 45.93189014707293, 51.84973342078072, 46.433477129255024, 51.38422148568289, 52.856840065547395, 60.26235171726772, 49.97999055044991, 52.16248573575701, 14.152968968663897, 11.849612474441528, 63.68817492893764, 60.32724789210728, 32.4624354498727, 19.708898816789898, 23.287351369857788, 26.720871448516846, 26.287507091249736, 26.29033327102661, 18.242931400026592, 28.409528630120413, 26.472631420407975, 39.38320255279541, 67.84555312565395, 11.212691954204015, 0.06682493777147361, 0.2393243493778365, 0.21027874866766588, 0.04644864311973963, 0.07321498702679362, 0.03089013709021466, 0.07660597256783928, 0.031662845984101295, 0.05519900018615382, 0.043988095330340524, 0.013518638077325054, 0.14250828591840609, 0.23525927322251455, 0.06426782427089554, 0.2926232750926699, 0.13443921533014092, 0.1751875230776412, 0.13118443212338857, 0.19646159080522402, 0.15640120900103024, 0.3153758570551872, 0.1441409225974764, 0.15500569316957677, 0.15866020135581493, 0.1726095106984888, 0.13074299081095628, 0.21974193730524608, 4.9132188728877475, 71.29615361349923, 67.36463356018066, 40.519316400800435, 40.03404726300921, 46.185686997004915, 54.53796713692801, 51.21935115541731, 39.32706110818045, 25.38387128284999, 27.724297285079956, 33.60913487843105, 70.78705215454102, 15.616342101778303, 5.383150730814252, 29.68560525349208, 55.4479866027832, 67.45291042327881, 65.36621352604458, 64.24269676208496, 55.62112528937203, 57.07329184668404, 21.912288972309657, 13.628127234322683, 6.058546466486795, 2.0532567373343875, 18.860813856124878, 50.87031882149832, 38.12372343880789, 6.981278530188969, 16.613954033170426, 14.542994805744716, 18.32911859239851, 19.664654425212316, 29.10401323863438, 36.66219765799386, 42.01240784781319, 41.07682595934187, 40.049774510519846, 43.31967319761004, 51.589426108769004, 52.90904882975987, 53.505364077431814, 53.254565375191824, 55.875641277858186, 56.712562220437185, 56.215116364615305, 51.76601457595825, 41.04694870540074, 35.330881118774414, 43.26956973757063, 54.13324499130249, 56.74187667029244, 54.19152648108346, 52.15457173756191, 49.945794991084504, 51.88617672239031, 52.5514042036874, 48.99642787660871, 47.86724138259888, 45.07489933286394, 46.045159680502756, 47.4456524848938, 48.3406742640904, 48.42995514188494, 50.3792097227914, 50.95928703035627, 51.50490127290998, 49.31121253967285, 42.053899015699116, 47.07958664212908, 52.53906767708914, 51.76238414219448, 46.587393624441965, 50.4865802356175, 54.07368155888149, 48.40103326525007, 41.3995280947004, 40.525260584695, 46.01154429571969, 46.08592128753662, 51.08383001599993, 48.80712073189871, 45.76033564976284, 46.560931410108296, 45.91848359789167, 46.137365749904085, 47.564647333962576, 45.15405321121216, 46.378089564187185, 46.409217493874685, 46.4371839932033, 41.713812487465994, 42.00491074153355, 42.15364735467093, 37.78251825060163, 33.77450895309448, 33.651654379708425, 27.06778458186558, 24.065483604158672, 39.06652797971453, 43.35208306993757, 36.787282603127615, 31.48364966256278, 28.23327715056283, 36.139581952776226, 38.56532662255423, 41.685026100703645, 41.24002177374703, 41.644507680620464, 42.238436222076416, 40.024347577776226, 34.43590102876936, 33.908789839063374, 26.07466639791216, 19.492115020751953, 13.386902281216212, 4.571870812347957, 2.018038707120078, 4.074899171079908, 13.922812495912824, 8.616429805755615, 13.316724606922694, 15.31268845285688, 17.65982641492571, 49.21107857567923, 54.84497676576887, 52.02115937641689, 53.87711354664394, 58.309372901916504, 66.277435030256, 56.14849703652518, 53.27002164295742, 16.897075755255564, 9.770329305103846, 80.81770093100411, 66.13129356929234, 39.97197205679757, 20.74479705946786, 30.944962774004253, 33.964073181152344, 47.72286128997803, 36.830132143838064, 20.640435116631643, 39.50178050994873, 35.17127752304077, 49.98511137281145, 76.51238168988908, 22.7786511693682, 0.4238438052790505, 0.27548209631017273, 0.2644965872168541, 0.1654940667961325, 0.1915084073053939, 0.1333124672195741, 0.18136981848095143, 0.16553355753421783, 0.14861852090273583, 0.14927984827331134, 0.2122820554567235], [0.012408959363321108, 0.018468863164473857, 0.03303530519562108, 0.03934766897665603, 0.036483019656900845, 0.0946075948221343, 0.03625573756705437, 0.02042455206226025, 0.03485740581527352, 0.025229244958609343, 0.07662091390894991, 0.08470806745546204, 0.03129170768495117, 0.01636406619633947, 0.043509463513536115, 0.025245775768001164, 0.3651072084903717, 20.371225425175258, 59.73838111332485, 33.732354232243125, 32.00743613924299, 23.509905644825526, 38.482042040143696, 41.799334389822825, 35.16299874441964, 22.047869171415055, 21.58044821875436, 23.75939461163112, 58.35878849029541, 55.73889030729021, 5.646352401801518, 17.92866437775748, 51.23587049756731, 57.65171548298427, 51.412066391536165, 55.539810521262034, 57.03299924305507, 56.404051780700684, 30.17214243752616, 16.62756208011082, 1.6463594798530852, 1.7314180242163795, 2.155641483409064, 4.875345979418073, 6.663828364440373, 16.62159878867013, 16.982510805130005, 25.335117510386876, 28.027452400752477, 30.564965793064662, 37.92825671604702, 41.54204954419817, 41.84131193161011, 38.85910340717861, 36.458142961774556, 36.2422832761492, 41.79387310573033, 44.77017913545881, 42.501915386744905, 47.592162200382774, 46.79308462142944, 51.23747900554112, 48.6864652633667, 41.32675266265869, 31.969311373574392, 32.14732769557408, 43.2518344606672, 46.431830406188965, 47.358980655670166, 48.325881549290244, 43.88578462600708, 45.209232330322266, 44.20824357441494, 47.68277365820748, 43.362984793526785, 35.33313233511788, 27.48928836413792, 27.790933983666555, 27.424890722547257, 30.20055362156459, 34.8736549104963, 38.367598261152, 41.85185929707119, 43.30998740877424, 40.64978967394148, 37.8403376851763, 43.49146393367222, 48.81410714558193, 48.642212186540874, 47.08620827538626, 47.26668425968715, 47.21629939760481, 41.47112580708095, 34.81428255353655, 33.793074539729524, 39.055223260607036, 37.81195081983294, 39.70790229524885, 32.66810212816511, 29.639622075217112, 25.354357072285243, 29.715294906071254, 34.99729463032314, 35.84506171090262, 38.84180586678641, 42.333543164389475, 42.72374357495989, 43.83863067626953, 40.38562611171177, 39.70575530188424, 34.73652178900582, 29.41198171888079, 27.92400414603097, 25.590941497257777, 17.93773177691868, 14.245707443782262, 22.148819548743113, 33.069940771375386, 38.32045473371233, 34.91179009846279, 19.121263606207712, 21.333186149597168, 22.345377138682775, 26.674471378326416, 23.180272681372507, 17.8110956464495, 12.23232272693089, 7.163417739527566, 6.987937944275992, 5.876906658921923, 6.963979687009539, 7.265169331005641, 19.695346355438232, 9.739084993089948, 7.271603797163282, 8.519743016787938, 1.5227756713117873, 0.44196457149727003, 0.09193410578050784, 6.5007558805601935, 25.466594798224314, 43.662104742867605, 48.45503119059971, 40.46240023204258, 45.0200572013855, 50.22013071605137, 44.62308924538748, 50.74602597100394, 37.94504008974348, 3.484203061887196, 18.55992385319301, 59.31947422027588, 41.75913558687483, 22.040438073022024, 8.26551364149366, 25.31536030769348, 27.516669477735245, 39.54486281531197, 16.103046042578562, 29.12799494607108, 33.92599357877459, 19.179968936102732, 44.16878128051758, 31.334336348942347, 2.816637294633048, 0.146958213565605, 0.01806351143334593, 0.0798773527411478, 0.036647611896374395, 0.10956578395728554, 0.08042401447892189, 0.04817553509825042, 0.03641003643029502, 0.03917752632072993, 0.029644370544701815, 0.043780460221959014, 0.03461583377793431, 0.05438651556947401, 0.014518155782882656, 0.038165789895824025, 0.026959687371605208, 0.16286270799381392, 0.04785032004916242, 0.06416797784290143, 0.07383713578539235, 0.042713904952896495, 0.036498100097690306, 0.15229295087712152, 0.04130788879202945, 0.06134622211435011, 0.044255950421627076, 0.07033868386809315, 0.3024780734309128, 26.97096143450056, 71.81132084982735, 38.47251605987549, 27.937056337084087, 30.552333968026296, 36.95873287745884, 27.26141176904951, 34.15183435167585, 26.534062181200298, 26.56280514172145, 25.586961916514806, 53.751945223127095, 51.46257979529244, 9.159033741269793, 17.97409691129412, 58.8380126953125, 62.47246251787458, 58.7583863394601, 60.45870086124965, 60.851392201014924, 58.51014110020229, 37.25862407684326, 16.606062616620743, 1.2670512390988213, 1.8565425957952226, 2.8140176066330502, 4.45258457320077, 5.522452124527522, 17.45364556993757, 21.847054072788783, 27.506500789097377, 34.68153027125767, 33.30401168550764, 40.93304688589913, 42.8638505254473, 42.81321900231497, 38.1237963948931, 40.00079665865217, 40.40955918175833, 42.459896155766074, 46.73797498430525, 46.76808500289917, 49.8260497365679, 48.87478576387678, 53.04775224413191, 49.01645258494786, 43.852283886500764, 35.73533228465489, 34.872230529785156, 43.50436326435634, 48.27408272879464, 47.56192364011492, 49.17896400179182, 45.82116712842669, 47.819236278533936, 47.912109375, 50.1012088230678, 48.15895455224173, 40.873865604400635, 35.97869988850185, 35.858419622693745, 39.583668504442485, 42.079854011535645, 44.23005396979195, 46.671241010938374, 49.4681966645377, 49.04476302010672, 47.88441038131714, 41.51534414291382, 45.77369008745466, 52.58881330490112, 51.41077055249895, 49.32805149895804, 53.028370244162424, 51.555546692439485, 47.48020935058594, 40.90069259916033, 38.27540608814785, 41.67686196735927, 43.86001375743321, 46.66731180463518, 42.73319659914289, 38.703870228358674, 36.36700691495623, 39.543132713862825, 41.773240430014475, 41.87520524433681, 42.10112592152187, 46.35477140971592, 43.60931927817208, 45.35606861114502, 41.65811572756086, 41.46215220860073, 35.768009662628174, 31.198773520333425, 31.045346873147146, 31.072694982801163, 23.574146951947892, 15.75784911428179, 23.7931124823434, 35.38239853722708, 40.510189941951204, 35.82912949153355, 23.70484777859279, 22.98975828715733, 24.83088673864092, 29.293167522975377, 25.426915373120988, 19.384907790592738, 15.157177346093313, 8.57009834902627, 9.480774419648306, 6.784621059894562, 9.18981773512704, 10.410697868892125, 22.91147814478193, 16.554605994905742, 11.572703310421534, 12.643198370933533, 2.1114201077393124, 1.2696174042565482, 3.2842015538896834, 9.630257964134216, 30.996688638414653, 49.98655659811837, 51.843834400177, 45.431432247161865, 48.06288528442383, 56.2723000390189, 49.37497615814209, 59.40056664603097, 39.18461956296648, 5.468256609780448, 24.13934816632952, 49.628661836896626, 40.551215580531526, 30.070365224565776, 15.158162253243582, 26.556669882365636, 28.19534867150443, 28.910495485578263, 23.430873359952653, 28.039160115378245, 35.02162374768938, 20.729882751192363, 53.02474675859724, 43.955752985818044, 3.490262325320925, 0.13654909282922745, 0.09225958545825311, 0.06577998027205467, 0.04537194035947323, 0.036819420355771265, 0.08889342751353979, 0.025587187447984303, 0.04064892950866904, 0.03501232893073133, 0.07115256626691137, 0.032733014452138116, 0.15418538504413196, 0.13825163218591893, 0.07567792665213346, 0.1215446615325553, 0.15535112177687033, 0.37625423605952946, 0.2181722686759063, 0.14103572922093527, 0.10659733574305262, 0.2467294463089534, 0.1496375719351428, 0.23335980943271092, 0.1604403786893402, 0.1263512136148555, 0.25307977412428173, 0.10995349886694125, 0.45271761449319975, 43.40931190763201, 82.50206238882882, 48.661997182028635, 46.51690762383597, 32.90892669132778, 58.356426102774485, 52.09997974123274, 43.448287827628, 28.365848779678345, 29.53114332471575, 27.75899485179356, 65.86055006299699, 62.33823721749442, 11.177425503730774, 22.896049669810704, 59.89940561567034, 66.72937365940639, 61.94514288221087, 64.7702248437064, 66.32963684626988, 62.88271195547921, 38.5908716746739, 18.90173700877598, 2.5837962116513933, 4.901802548340388, 4.3230293307985574, 6.468867123126984, 10.297413570540291, 22.374936512538365, 28.393733637673513, 32.018330914633616, 41.35711976460048, 38.773776054382324, 48.06845773969378, 47.15072577340262, 47.44663565499442, 43.807898793901714, 43.68868507657732, 46.42008100237165, 47.320862838200156, 52.35144894463675, 50.98462363651821, 55.13806915283203, 53.19739212308611, 57.51450245720999, 55.541200160980225, 47.438575744628906, 41.063891887664795, 41.1150792666844, 51.27706636701311, 53.586939402988975, 55.11227396556309, 52.62144551958357, 50.786325522831504, 53.646683488573345, 49.44856105531965, 49.74969598225185, 50.43558740615845, 48.82446343558175, 44.93733194896153, 48.94520228249686, 49.14743307658604, 50.54623746871948, 50.905633040836875, 48.856953212193076, 52.31922319957188, 51.43590566090175, 47.29272263390677, 41.56496122905186, 47.00757898603167, 52.25067227227347, 51.20171662739345, 49.064808573041645, 52.54450811658587, 52.204887117658345, 49.29785810198103, 43.60042210987636, 40.6851282119751, 44.080042362213135, 48.00944321496146, 51.73035989488874, 47.17836223329817, 49.12725550787789, 44.80758823667254, 48.04785980497088, 48.10121502195086, 45.13976771490914, 42.59304448536464, 48.39592286518642, 46.94777584075928, 47.66505227770124, 43.802927357809885, 45.25915166309902, 39.1769939150129, 35.15452194213867, 35.075976031167166, 34.82393707547869, 27.347173384257726, 21.406802313668386, 30.065296513693674, 40.23034429550171, 46.93424422400338, 41.497900690351216, 28.218878746032715, 26.024665423801967, 29.420093740735734, 35.03526306152344, 29.468748501368932, 22.42869646208627, 17.758702754974365, 11.888710856437683, 12.122247627803258, 8.772912791797093, 11.605979101998464, 13.446482215608869, 23.92048338481358, 20.719536883490427, 12.62084254196712, 14.853521960122244, 3.231825815779822, 0.8572539772306169, 3.5999943571431294, 11.452843410628182, 30.042961529323033, 54.477191243852886, 55.677905968257356, 49.655516624450684, 52.40109382356916, 60.55077838897705, 51.846822125571116, 60.59380858285086, 44.2593024117606, 6.579313516616821, 24.436541727610997, 72.13906737736293, 44.99915354592459, 29.801945890699113, 13.574396814618792, 38.813401630946565, 36.657094206128804, 53.26536634990147, 25.999189853668213, 35.42543567929949, 44.4190936088562, 30.38280487060547, 58.518041202000205, 64.67544446672711, 5.530492493084498, 0.2955588347145489, 0.20047250629535743, 0.18202130709375652, 0.12797962980610983, 0.1910924653389624, 0.17230650410056114, 0.11221551070255892, 0.10693186707794666, 0.10976836737245321, 0.19855142437985965, 0.08507119225604193], [0.06000844282763345, 0.10722936397152287, 0.07097305304237775, 0.033137726664010964, 0.07168039187256779, 0.01937394915148616, 0.04077027192605393, 0.04756757789956672, 0.0072118221682363325, 0.016397560381197503, 0.05545211749683533, 0.11571542147014822, 0.13409708440303802, 0.06058184563049248, 0.06865177117288113, 0.10117795118795973, 0.17730071182761872, 6.166810691356659, 63.85869067055838, 38.80250685555594, 30.057469367980957, 33.832067830221995, 25.93027762004307, 47.892320905412944, 36.36715282712664, 26.37318011692592, 22.20681963648115, 33.64950738634382, 47.687098911830354, 71.04557377951485, 25.15129770551409, 10.60337141581944, 32.10107006345476, 58.90550054822649, 53.63959632601057, 54.73379864011492, 51.03210762568882, 51.64537647792271, 28.882770436150686, 17.303387301308767, 6.633347920009068, 1.2508438059261866, 2.258249440363475, 2.342538905995233, 0.7699935595904077, 7.124069222382136, 18.305048295429774, 18.37706289972578, 30.19614498955863, 28.313513210841588, 35.042909554072786, 39.209327357155935, 41.49577801568167, 42.71848726272583, 43.868355069841655, 41.2692563193185, 38.76241227558681, 39.32192291532244, 37.87433522088187, 44.83888987132481, 49.854711055755615, 49.059541838509695, 39.328798157828196, 32.498962129865376, 27.19072253363473, 34.18910796301705, 43.09643105098179, 44.906287397657124, 44.59258665357317, 47.83172219140189, 45.347084590366904, 46.797142369406565, 46.620748451777864, 48.51024157660348, 43.71628679547991, 38.203242097582134, 31.122093200683594, 29.700168677738734, 31.743713787623815, 32.864100388118196, 35.28569003513881, 41.280613149915425, 43.05823680332729, 42.21832118715559, 40.75495760781424, 39.25928837912423, 46.424559116363525, 49.52973338535854, 48.835128920418875, 46.35922520501273, 48.60455642427717, 47.84455551419939, 45.09128665924072, 38.04007060187203, 36.19409057072231, 39.34809677941458, 39.961952754429404, 39.25860398156302, 34.683847495487754, 28.166815893990652, 28.05880962099348, 31.220111438206263, 33.22516005379813, 38.09399904523577, 38.90047992978777, 42.45057167325701, 44.7356778553554, 42.629970686776296, 40.35383115495954, 37.9807642527989, 33.98135682514736, 32.912077699388774, 28.49392318725586, 29.35585764476231, 20.306794779641287, 15.975880111966815, 12.868648307664053, 22.084500074386597, 28.433675357273646, 34.26030962807791, 32.23332207543509, 21.32930210658482, 18.640238080705913, 21.491714511598857, 15.850510290690831, 13.381432311875479, 18.03596019744873, 11.851818527494158, 15.424498864582606, 20.69945137841361, 41.332405022212434, 37.58620384761265, 41.01348965508597, 15.024432012013026, 17.69821694919041, 4.489295380456107, 1.1954226940870285, 2.1161157871995653, 0.7220210794891629, 8.38226248536791, 37.319945403507774, 50.62412677492414, 46.992629936763215, 50.69261516843523, 47.43445546286446, 48.478915623256135, 49.833046572549, 48.98628350666591, 18.253082718167985, 5.100142351218632, 29.465837206159318, 38.49332938875471, 13.713541439601354, 7.141306400299072, 13.614977768489293, 24.997250931603567, 29.66119623184204, 30.51391737801688, 19.116912296840123, 30.51037379673549, 28.560096093586512, 27.59935998916626, 52.263550758361816, 19.79841419628688, 0.6266648162688527, 0.11918188046131815, 0.13436634066913808, 0.056116393102066855, 0.041983261837490966, 0.03077531878703407, 0.18298243837697165, 0.01083893874394042, 0.055112598929554224, 0.04326097720435687, 0.04745865606569818, 0.07975111130092825, 0.011148356649625515, 0.08041679486632347, 0.09711552131921053, 0.04502066278031894, 0.03600935132375785, 0.013469493482261896, 0.020811003200443726, 0.0429306256451777, 0.02802799835002848, 0.00844340563552188, 0.03046102136639612, 0.026243580172636678, 0.06387393469257013, 0.11883569189480372, 0.06954402436635324, 0.07135495969227382, 0.05053622288895505, 8.175854086875916, 77.08785234178815, 47.59669589996338, 31.175038473946707, 31.781511987958634, 31.880207674843923, 32.549656186785015, 34.56281335013253, 30.071403980255127, 26.070685080119542, 29.64098392214094, 49.336639472416465, 73.65627602168492, 31.847540719168528, 12.92028992516654, 33.35982656478882, 64.80369431631905, 59.67814023154122, 61.75737476348877, 55.452079091753276, 57.60171972002302, 33.545322622571675, 19.966532809393748, 8.839549490383693, 1.1888685886348997, 1.842913487127849, 3.108528728996004, 0.7147662916353771, 7.456005947930472, 21.037734849112375, 21.760239805494034, 34.06916468484061, 31.675944532666886, 37.06185456684658, 40.94911112104143, 43.92685195377895, 45.18702936172485, 44.503236293792725, 43.313701220921104, 40.021481445857454, 43.37996619088309, 42.250609466007774, 47.14802639825003, 50.7038608278547, 50.56707511629377, 43.75476591927664, 35.97569131851196, 31.243495600564138, 35.81542764391218, 47.317552021571565, 46.6174167905535, 47.6015214238848, 51.33398600987026, 48.15331261498587, 48.83788735525948, 47.77585867473057, 52.89327641895839, 47.62103891372681, 44.17083099910191, 39.58762897763933, 37.6363594191415, 39.94834123338972, 42.459458419254844, 43.7931547164917, 49.04667724881853, 49.97072165352957, 49.42584044592721, 46.126328536442344, 42.39367287499564, 49.810770647866384, 53.21591602052961, 53.097365856170654, 50.01303965704781, 50.80678449358259, 52.45262166431972, 47.72055448804583, 42.217570781707764, 39.48154388155256, 41.058017185756135, 44.54349068232945, 45.57038232258388, 43.969687598092214, 37.69880287987845, 36.32444225038801, 39.25044332231794, 40.44635336739676, 42.22666597366333, 42.05215154375349, 42.97732155663626, 45.8442907333374, 44.727082933698384, 40.60343476704189, 40.26109702246529, 37.0200958933149, 35.503123487745015, 34.495290756225586, 33.769193581172395, 25.956694671085902, 20.640103340148926, 14.206031492778234, 22.016020366123744, 28.76291401045663, 35.976671014513286, 35.217080048152376, 24.29262716429574, 21.299459593636648, 25.557409490857804, 19.678866965430124, 17.227973290852137, 22.094785145350865, 15.574046679905482, 19.139321974345616, 26.66847160884312, 46.51267964499337, 40.93171283176967, 43.56250579016549, 21.48192276273455, 17.651276656559535, 4.42794235263552, 3.2392838384423936, 6.034971662930079, 2.0118571988173892, 12.406732065337044, 41.00545058931623, 55.442799772535054, 50.93134137562343, 55.04206241880144, 51.17649119240897, 54.21451807022095, 54.07308053970337, 52.708113874707905, 22.72472620010376, 7.170471898147038, 28.21786778313773, 50.103390557425364, 15.528162513460432, 14.708301135471888, 17.530681984765188, 31.042605808803014, 27.07663311277117, 28.136316776275635, 24.673647267477854, 30.694733824048722, 34.35008730207171, 28.009828295026505, 67.91099820818219, 27.913750341960363, 0.5890614911913872, 0.19703814201056957, 0.10114103888294526, 0.1557181142270565, 0.0639321394264698, 0.04672780938978706, 0.1546972311500992, 0.008888086104499442, 0.05570470215752721, 0.05575365845912269, 0.07707151544413396, 0.02783938936356987, 0.17132441965597017, 0.1295484841934272, 0.35578601009079386, 0.0762380233832768, 0.17791231615202768, 0.17696966816272053, 0.16050635943455355, 0.12837129378957407, 0.146134187068258, 0.0785149290625538, 0.11701362180922713, 0.16069717705249786, 0.24046597097601208, 0.20379001327923366, 0.19122327331985745, 0.15977936344487326, 0.43958864041737145, 13.462336267743792, 94.71060316903251, 53.60453919001988, 46.57203115735735, 44.78305067334856, 42.47300393240792, 64.86040551321847, 46.35922173091343, 34.03249556677682, 28.448287418910436, 39.83629805701119, 55.51017298017229, 80.61016518729073, 32.434576647622244, 14.437434298651558, 39.20993185043335, 69.0212994984218, 64.71738379342216, 62.92394951411656, 60.86594867706299, 60.699310030256, 34.399933678763254, 24.23145522390093, 10.971849152020045, 3.1876695794718604, 6.3887808833803446, 8.269847580364772, 1.5541801175900867, 10.06676117011479, 24.398090396608623, 26.974951437541417, 38.21351500919887, 33.652022634233745, 40.36674785614014, 47.54506383623396, 51.20072650909424, 51.51062658854893, 49.14494562149048, 48.77387012754168, 45.901755809783936, 49.162694794791086, 48.312978744506836, 51.67356184550694, 55.08609315327236, 55.981709003448486, 47.26245628084455, 42.073628425598145, 35.50071593693325, 40.45767545700073, 52.650360448019846, 52.14386108943394, 53.189179352351594, 54.253660746983115, 51.73220811571394, 51.42227676936558, 50.05673687798636, 52.96010766710554, 47.864170278821675, 49.77996580941336, 46.58191844395229, 47.44292531694685, 48.439710412706646, 50.72686283929007, 49.022334235055105, 52.28287717274257, 52.50516046796526, 51.391590050288606, 45.44140986033848, 41.71436834335327, 49.31028495516096, 52.25581046513149, 51.07019417626517, 49.23894085202898, 50.28478717803955, 51.54386329650879, 51.33117198944092, 44.84856523786272, 40.98178155081612, 46.08374997547695, 48.7086751801627, 49.85769183295113, 51.22594846997942, 45.14490590776716, 46.453310762132915, 47.03403772626604, 46.17107146126883, 45.20030736923218, 43.11986037663051, 46.34627028873989, 48.428958075387136, 47.5272000176566, 43.62210396357945, 43.35016189302717, 40.276115553719656, 40.649709769657676, 38.56513554709298, 37.621125493730815, 31.17233215059553, 22.65800264903477, 18.802671330315725, 27.326208932059153, 35.223159721919465, 39.53365537098476, 40.573029450007844, 29.39893995012556, 23.41678762435913, 29.647442272731237, 24.526484421321324, 23.456060579844884, 28.21494780267988, 19.743050949914114, 22.368273190089635, 28.61248551096235, 52.8282482283456, 45.50416946411133, 50.82083722523281, 31.18262938090733, 20.921771151678904, 5.4096298813819885, 5.064748227596283, 6.501684333596911, 2.8336736261844635, 12.618223071098328, 42.45405966894967, 59.501753262111116, 54.240396635872976, 58.80038125174386, 56.98153741019112, 57.99542897088187, 57.81454651696341, 56.896470614842, 23.364325250898087, 8.9452828339168, 37.39873797552926, 61.03275408063616, 24.212745462145122, 11.456168123653956, 23.16901659965515, 37.59396845953805, 39.1039822442191, 43.815514019557405, 26.75054373059954, 38.4466826575143, 41.748404094151084, 39.38857003620693, 73.9911722455706, 43.6510397366115, 1.3509024253913333, 0.3911457455583981, 0.25256023343120304, 0.22873790029968533, 0.11954112404159137, 0.10669422375836543, 0.27037563174963, 0.11119082104414701, 0.21466459546770367, 0.25649041682481766, 0.12914448444332394, 0.18280354940465518], [0.005955421706728105, 0.05973322902406965, 0.007397415066537048, 0.06633824495864765, 0.06010640971362591, 0.02991498388083918, 0.021553211945242116, 0.04714444006926247, 0.05141206910567624, 0.030595398441489254, 0.04461139081312077, 0.021983255565698658, 0.036772262171975205, 0.10221452877989837, 0.17338716611266136, 0.06901869576956544, 0.2181535003972905, 1.7160850869757789, 49.41023826599121, 57.88415009634835, 26.871984345572336, 48.3119295665196, 27.17926495415824, 33.209130559648784, 43.20576095581055, 36.03423336574009, 19.743089165006364, 31.161023957388743, 40.778828144073486, 66.55745438167027, 46.01648793901716, 9.27981948852539, 10.338057926722936, 41.71041134425572, 50.31262513569423, 37.00741195678711, 57.064985275268555, 52.19939456667219, 39.973170621054514, 28.27402833529881, 10.503240057400294, 0.7408140024968556, 3.662288648741586, 0.3365706583218915, 0.3458726134683405, 1.2093422157423837, 6.802389340741294, 15.203945670809064, 17.695145845413208, 25.271541493279592, 25.632651533399308, 35.41161223820278, 37.759443283081055, 45.0529464994158, 46.139724663325715, 43.97855002539498, 39.394020898001536, 39.089488301958355, 39.53769227436611, 46.87184245245797, 44.82806805201939, 40.01167058944702, 31.990315777914866, 25.447570630482264, 18.121737446103776, 31.01848861149379, 41.31679589407784, 41.54040282113211, 47.70611613137381, 47.441240378788535, 45.235086577279226, 44.73930134092058, 50.33930969238281, 50.631186144692556, 44.06105988366263, 36.76209538323538, 32.585689544677734, 30.27504873275757, 30.140816484178814, 32.540387289864675, 37.57781389781407, 42.25910016468593, 42.65521001815796, 41.93367780957903, 40.822928360530305, 41.17167581830706, 48.909287043980186, 53.38035208838326, 47.6983619417463, 46.46937847137451, 46.97064583642142, 49.225916453770225, 48.16969994136265, 39.50635242462158, 36.55535173416138, 37.97079011372158, 40.484672682625906, 38.61472136633736, 37.128043106624055, 33.75468226841518, 30.01042311532157, 34.266879149845664, 34.90341057096209, 35.334688731602256, 39.28207499640328, 43.03008617673601, 48.46862881524222, 46.01328829356602, 29.913367203303746, 25.067895003727504, 32.34538957050869, 30.61030626296997, 32.146615505218506, 29.48873152051653, 24.291439022336686, 16.010275432041713, 15.026879514966692, 8.716427411351885, 15.531502859933035, 22.203203099114553, 30.21110098702567, 29.78407859802246, 14.123254997389656, 14.148912957736425, 12.687228236879621, 17.387219054358347, 26.320257425308228, 26.66288525717599, 27.576604638780864, 29.794459206717356, 32.247406073978965, 24.0856385912214, 21.953901733670914, 4.690677191529955, 5.718872053282602, 0.24761916856680596, 1.0864613694804055, 4.336460198674883, 4.8759031380925855, 14.541187405586243, 44.05643585750035, 43.61351251602173, 50.937963008880615, 45.34934275490897, 44.41980579921177, 45.505760601588655, 48.04667166301182, 49.79538038798741, 19.892138447080338, 9.598084330558777, 30.483261925833567, 26.645057916641235, 35.15444551195417, 12.239815490586416, 21.737604311534337, 24.314944778169902, 34.42798703057425, 23.384787695748464, 20.679902621677943, 25.03686955996922, 22.721154826028005, 36.33678225108555, 51.173805713653564, 8.5374869789396, 0.3442445365445954, 0.10812591907701322, 0.08273608862821545, 0.05631098337471485, 0.048698478644447665, 0.06618039057190929, 0.07385825179517269, 0.01352426567713597, 0.054860363714396954, 0.025527169329247305, 0.08304284752479621, 0.03944861802405544, 0.04379483498632908, 0.040972784095044644, 0.028388395439833403, 0.039802928654743094, 0.10862159569348608, 0.07315574413431541, 0.05457384551742247, 0.06383872551045247, 0.061569080155875, 0.04155944547216807, 0.06759890195514474, 0.08905812831861631, 0.0716547771756138, 0.09373316674360208, 0.0843634463048407, 0.02125166928661721, 0.11021033794220005, 1.5062091031244822, 59.64765848432268, 65.37349523816789, 32.461726733616416, 49.23990317753383, 32.25786658695766, 30.620947429112025, 29.70179455620902, 36.523209367479595, 24.103064673287527, 32.86750153132847, 46.49910633904593, 69.66588388170514, 60.36219733101981, 14.722051620483398, 10.547212600708008, 46.98335409164429, 55.45908982413155, 42.2790275982448, 61.205812862941194, 55.98819167273385, 46.11457913262503, 32.42098944527762, 16.027604239327566, 1.7279560842684336, 2.809742510318756, 0.5312890112400055, 0.430447090949331, 2.110971514667783, 9.140304003443037, 19.953998259135656, 24.512572390692576, 28.29084644998823, 27.689082077571324, 36.83390848977225, 40.973638262067524, 47.14691816057478, 49.79856266294207, 44.77366018295288, 40.78523785727364, 42.024570669446675, 42.51412337166922, 47.93623352050781, 45.62360552379063, 43.00817155838013, 35.357944352286204, 27.968592473438807, 23.36940959521702, 33.430739879608154, 43.81453432355608, 46.312790393829346, 48.57057278496878, 49.21977424621582, 47.42423466273716, 49.155437401362825, 50.72723109381539, 51.055279867989675, 48.40287801197597, 43.8013014793396, 41.17516033990042, 41.7457081930978, 42.397032329014365, 45.691440786634175, 45.955864906311035, 49.29198340007237, 49.74103505270821, 48.10354961667742, 44.74087163380214, 44.35650423594883, 51.399615219661165, 56.650768416268484, 51.183599199567524, 49.14512627465384, 52.80233492170061, 53.35494947433472, 50.36071014404297, 43.7486515045166, 40.823786463056294, 42.45313903263637, 45.4252552986145, 47.06091683251517, 45.25468397140503, 40.26534237180437, 38.22869334902082, 41.96234955106463, 43.01804494857788, 40.815177645002095, 41.826790196555, 44.33395733152117, 48.13924946103777, 47.31055865968977, 34.05415310178484, 29.014774050031388, 33.62964596067156, 32.16485105242048, 35.64904955455235, 33.49251283918108, 27.64685787473406, 24.201854160853795, 17.56392216682434, 11.230965716498238, 18.816713639668055, 22.338058948516846, 32.217035497937886, 31.5582628931318, 16.29411976678031, 16.411554745265416, 15.806660209383283, 19.943082639149257, 27.91711848122733, 30.05130284173148, 31.50377859388079, 31.053594384874614, 36.29158074515206, 26.82498151915414, 22.42143212045942, 6.446318915912083, 6.162941413266318, 0.3429135222520147, 2.6302017101219723, 4.735074443476541, 5.213604262896946, 20.388283252716064, 47.28214747565133, 52.33696889877319, 55.54396901811872, 52.299205439431326, 51.145783628736226, 53.77109098434448, 51.88243164334978, 58.974586486816406, 23.098704304013932, 11.836305805615016, 28.86089403288705, 38.38458660670689, 40.13506017412458, 20.17073862893241, 23.700757026672363, 27.740345886775426, 25.785143647875103, 25.152110644749232, 25.824355806623185, 26.88509907041277, 22.525156566074916, 41.97911902836391, 64.86613082885742, 10.410900235176086, 0.16411517507263593, 0.1131918750969427, 0.10559328033455781, 0.06479389247085367, 0.03911984066611954, 0.04728124290704727, 0.024686924148617045, 0.028689285008502857, 0.03614022715815476, 0.0744527977492128, 0.02566716806696994, 0.0607469060591289, 0.24116279929876328, 0.1324433045727866, 0.18954623330916676, 0.23202819802931376, 0.21426591543214663, 0.1745372965399708, 0.2719527914055756, 0.22607949509152345, 0.19516355331454957, 0.11709960576679025, 0.23337910696864128, 0.3195901023490088, 0.3143125655395644, 0.1716592088341713, 0.26110412925481796, 0.13221537108932221, 0.3584489886249815, 3.509903145687921, 73.94175665719169, 75.44792461395264, 41.089086055755615, 61.0218870980399, 40.04997600827898, 47.871955735342844, 54.507888385227744, 44.17284945079258, 25.08589083807809, 37.38406685420445, 48.49209288188389, 73.87429659707206, 51.797986711774556, 13.362392510686602, 14.441766500473022, 50.850057874407085, 60.01878261566162, 47.65363638741629, 67.86483437674386, 59.336045673915315, 50.18240199770246, 34.48589331763131, 15.509035859789167, 2.065337917634419, 4.640634093965803, 0.8000847420522145, 0.7603862094027656, 3.603638253041676, 12.539374044963292, 23.815803561891826, 29.03814605304173, 32.5384452683585, 29.063883917672293, 39.33635432379586, 44.09533882141113, 52.7496953691755, 54.521308830806184, 50.0261925969805, 44.23178059714181, 48.465693201337544, 49.58492987496512, 52.86461162567139, 49.93028661182949, 47.0191581589835, 38.9137544631958, 31.590578964778356, 26.34588064466204, 37.06989710671561, 48.25060823985508, 51.64174951825823, 53.76973608561924, 52.05891241346087, 50.35205963679722, 51.717276436941965, 53.89622804096767, 53.24115882601057, 50.29552214486258, 49.463468415396555, 47.370719637189595, 49.17450325829642, 49.89723750523159, 51.36043085370745, 51.639018876211985, 52.250599316188264, 52.9715895652771, 48.778431619916645, 45.01242807933262, 45.582423550742014, 51.39319855826241, 55.87380347933088, 49.78680631092617, 48.217055388859336, 50.06961188997541, 52.25770384924752, 50.72218322753906, 44.43394190924508, 42.355006149836946, 44.429609707423616, 48.81173086166382, 49.26094927106585, 49.174861090523855, 47.64370741162981, 45.938438824244905, 53.60803065981184, 50.26018360682896, 45.86213023321969, 45.99606370925903, 47.60778522491455, 50.795365129198345, 50.549607345036094, 34.73882859093802, 31.66460507256644, 37.024858883449006, 36.52704129900251, 40.23770591190883, 36.31363780157906, 33.97069134031023, 26.988601173673356, 21.13252912248884, 13.038185221808297, 20.421737091881887, 26.273827825273784, 36.166808468954905, 37.03574671064104, 19.771267584392003, 19.169072423662456, 19.28879509653364, 24.398606300354004, 33.595565046582905, 34.09281635284424, 35.12310913630894, 34.31290054321289, 41.39497702462332, 33.190360001155305, 26.48647744315011, 10.794936725071498, 8.133310266903468, 0.586570561996528, 4.499580451420375, 9.108479516846792, 10.756193569728307, 19.40220011983599, 48.981068883623394, 55.16463211604527, 60.49611691066197, 56.43210513251168, 53.48799705505371, 55.40406009129116, 56.70914718082973, 58.18719230379377, 25.35953000613621, 12.381859251431056, 36.65472834450858, 39.05532053538731, 48.832248892102925, 18.680310079029628, 33.28409120014736, 35.3185133252825, 42.39447886603219, 34.312396798815044, 28.41951319149562, 36.149299008505686, 32.85947983605521, 49.005578654153005, 75.25377110072544, 20.5297920022692, 0.6189573641334261, 0.3384496032127312, 0.19204727267580374, 0.23493246361613274, 0.10960650284375463, 0.111272252031735, 0.13356036320328712, 0.19220710838479654, 0.16189803475780146, 0.1397993027099541, 0.10528806171246938, 0.20750591531395912], [0.047154913257275305, 0.019597463675641587, 0.0545521459675261, 0.010709330921859612, 0.04969678346865943, 0.029870054684579372, 0.040872985164501836, 0.041438941045531204, 0.023033210475529944, 0.035252024818743975, 0.052936041794185124, 0.03346553371687021, 0.05219472532293626, 0.07923033567411558, 0.1334185493843896, 0.11273520067334175, 0.05591042379715613, 0.12758954002388886, 29.210351943969727, 67.38361603873116, 36.25961208343506, 55.09836367198399, 32.74459832055228, 30.362161772591726, 45.920661858149934, 35.33002649034773, 27.03874284880502, 18.547422306878225, 33.91265998567854, 65.47653007507324, 41.990072863442556, 33.14321647371565, 12.755146009581429, 29.630933352879115, 61.30616569519043, 58.66106292179653, 55.07394422803606, 55.73555169786726, 51.336244174412315, 35.151162488119944, 20.631984370095388, 5.3312168547085355, 2.5499895342758725, 0.4092305494206292, 0.36255165562033653, 1.8055302245276315, 4.019278841359275, 7.480902212006705, 10.618767755372183, 23.105834892817906, 26.71210629599435, 34.78064979825701, 38.81656306130545, 43.268999985286165, 44.836294719151084, 44.335652691977366, 39.87036854880196, 38.345968518938335, 45.57356112343924, 47.05695635931832, 38.131564480917795, 30.093846661703928, 26.040324926376343, 16.82749649456569, 21.63536330631801, 34.44173056738717, 38.53136035374233, 39.1135116985866, 46.17224918093, 45.97995778492519, 45.828771931784495, 49.144504410879954, 52.1657201222011, 50.286951541900635, 43.40803343909127, 34.03196750368391, 31.821179253714426, 30.79988091332572, 33.59645094190325, 33.43248735155378, 37.46775790623256, 42.48511116845267, 44.77199608939034, 43.40231507165091, 40.45174516950335, 41.145637444087434, 49.44259255273001, 51.81425591877529, 48.18585797718593, 46.23145130702427, 49.258701528821675, 49.17569834845406, 46.55914224897112, 40.35274723597935, 38.570072242191856, 37.99708557128906, 41.40628521783011, 41.37403167997088, 39.104315757751465, 32.6750294821603, 32.40576941626412, 32.71763236182076, 34.54389687946865, 35.30618722098214, 36.46334021432059, 43.26173564365932, 48.07621540342058, 45.33812141418457, 30.757364886147634, 24.735592194965907, 27.643057210104807, 27.93683225767953, 28.336080959865026, 32.37316152027675, 29.446642807551793, 18.77126373563494, 17.71764758655003, 12.495622975485665, 4.543447468961988, 20.492886645453318, 22.610186883381434, 28.789067029953003, 17.21663383075169, 12.306948985372271, 10.440463951655797, 14.28303142956325, 8.464652487209865, 3.119178363255092, 5.0763795120375494, 10.385014721325465, 14.947508505412511, 5.919778347015381, 0.8792817752276147, 0.72125286928245, 3.377969882317952, 0.9569746319736753, 1.9549907531057085, 6.623244370732989, 2.8477478538240706, 17.572970458439418, 38.222228050231934, 49.609998975481304, 43.27383245740618, 50.08207695824759, 46.510567392621724, 49.40191432407924, 44.673213550022666, 32.544785499572754, 11.29742523602077, 13.35681050164359, 48.34975208554949, 31.870667798178538, 16.082359518323624, 9.914394991738455, 27.560111352375575, 23.030436515808105, 39.68553951808384, 21.343747411455425, 23.696994577135357, 27.291535684040614, 31.949088641575404, 45.996056761060444, 48.070368494306294, 1.5892051181622913, 0.08768306353262492, 0.09157144916909081, 0.0768414649314114, 0.10174769668706826, 0.057098748960665295, 0.03738477573330913, 0.10671284275927714, 0.06862401909061841, 0.0567673558502325, 0.04339417362851756, 0.01978058840281197, 0.029773902879761796, 0.08876343377466712, 0.007437181459473712, 0.01348110067192465, 0.02014077514676111, 0.06305420332189117, 0.031042308746171848, 0.027595574767994027, 0.03354728700859206, 0.012864751691397811, 0.09220767074397632, 0.02938770449587277, 0.03203717679051416, 0.04449483206761735, 0.05219455908185669, 0.04581903386861086, 0.22387215282235826, 0.045708263026816506, 0.019047911378688047, 35.178184032440186, 76.82341085161481, 41.335295472826274, 61.91347994123186, 39.96447147641863, 33.45263712746756, 35.02913475036621, 33.544419356754844, 30.02089752469744, 25.587401390075684, 35.96612364905221, 69.23215648106166, 42.90606778008597, 33.43498870304653, 15.994701044900076, 31.51704270499093, 64.57429953983852, 59.463162967136924, 61.36535045078823, 56.431757722582134, 57.78756318773542, 39.12777982439314, 23.81798529624939, 6.814208660806928, 4.824356189795902, 1.2993077082293374, 0.8391319896493639, 2.6400405764579773, 6.281353047915867, 9.836046235901968, 12.426327722413198, 26.938237156186783, 28.700793640954153, 34.46280445371355, 41.10312836510794, 46.688844272068565, 50.3822078704834, 45.398605482918875, 42.084707328251426, 42.717427662440706, 47.17414467675345, 48.43072986602783, 38.99543401173183, 33.8056229863848, 27.99066342626299, 20.814742837633403, 24.89746264048985, 37.62243870326451, 40.562739167894634, 43.715758732386995, 49.69447864804949, 48.637539522988455, 48.87225661958967, 49.64843988418579, 53.709557737622944, 52.352216720581055, 46.87817920957293, 42.18053688321795, 41.37039777210781, 42.01411015646798, 44.32340996606009, 44.58128193446568, 47.02755158288138, 49.447602203914094, 49.318278857639854, 48.96825293132237, 44.73780747822353, 43.637872900281636, 52.40303584507534, 56.18899113791329, 52.25486551012312, 50.424199308667866, 53.98484536579677, 52.72888551439558, 51.432518414088655, 44.83571107046944, 40.82898718970162, 42.53889717374529, 45.90900278091431, 47.07636267798287, 45.661862305232454, 41.8825112751552, 40.74258634022304, 40.68664639336722, 42.622140066964285, 39.914156096322195, 40.43328033174787, 45.2835294178554, 48.79432562419346, 45.90501798902239, 32.74360820225307, 27.030999081475393, 29.267181260245188, 28.589254208973475, 31.74138961519514, 34.84893321990967, 33.007288864680696, 23.410829544067383, 23.105897426605225, 13.039024216788155, 8.453072445733206, 23.569304057529994, 20.838816608701432, 32.9653252192906, 19.708579199654714, 14.757794891084943, 13.009675025939941, 16.916878121239797, 9.237058537346975, 3.2057060173579623, 6.040487664086478, 11.519263846533638, 20.295566490718297, 6.356854345117297, 1.0584518781730106, 0.769243914101805, 3.5785997680255344, 0.2917871028184891, 0.5613053920013564, 4.067759462765284, 4.9973980358668735, 20.034008502960205, 43.512245995657786, 53.755058016095845, 49.51754624502999, 54.1007274218968, 50.78077391215733, 54.42640338625227, 50.04782928739275, 36.98314537320818, 11.512125441006251, 16.62045407295227, 45.18893664223807, 32.76969173976353, 26.65503031866891, 15.136334487370082, 27.849865130015782, 23.451101303100586, 27.840648344584874, 26.58531904220581, 25.219992807933263, 28.12386213030134, 31.130906990596227, 53.46436275754656, 55.079554898398264, 1.721807797040258, 0.11451704720301287, 0.0502272485755384, 0.023316232520820837, 0.027735332625785043, 0.0400291895493865, 0.10813689098826476, 0.020427563061405505, 0.04944667546078563, 0.024479833564588, 0.012480746671956564, 0.023672624557678188, 0.019752858372937356, 0.1824095919728279, 0.15795410424470901, 0.18146102715815815, 0.08750493451952934, 0.11010023885007415, 0.10283715929836035, 0.07876621093600988, 0.18992406874895096, 0.10459647846541234, 0.1664935081665005, 0.13568032373275074, 0.27504479406135424, 0.12295320523636681, 0.18657978677323886, 0.1877445871276515, 0.33550182996051653, 0.1280736747596945, 0.3691159390977451, 50.46468298775809, 87.85052858080182, 50.91012852532523, 68.20150933946881, 44.578287260872976, 40.37881687709263, 62.887151854378835, 41.74880361557007, 35.38881172452654, 22.56205150059291, 41.65064641407558, 72.36193084716797, 48.32206698826381, 37.774013655526296, 19.0562093598502, 36.43160431725638, 68.73113577706474, 65.19721943991524, 64.9057286126273, 64.19080066680908, 60.91341182163784, 45.5512261390686, 23.840592997414724, 8.048363327980042, 6.567193686962128, 1.0473300921065467, 0.9795782076460975, 3.74921669278826, 8.315304432596479, 13.5580199105399, 16.142075811113628, 28.90903636387416, 30.806346212114605, 38.26175287791661, 43.22649090630667, 49.67804268428257, 53.792745045253206, 48.31599773679461, 47.142294134412495, 49.64706414086478, 55.33870186124529, 54.00074284417288, 42.976473876408164, 37.43748460497175, 33.06492069789341, 23.67505737713405, 29.662259306226456, 42.76430368423462, 45.086794648851665, 47.29336881637573, 52.25508090427944, 51.565030983516145, 51.50833020891462, 52.84067508152553, 55.00123132978167, 52.86236040932791, 49.429724488939556, 45.52264472416469, 46.77394233431135, 50.118353503090994, 53.656004496983115, 52.02097872325352, 50.453635351998464, 52.69814320972988, 53.39825759615217, 51.6399256161281, 45.428045000348774, 45.24846880776541, 51.10171815327236, 55.213748931884766, 50.24505043029785, 49.11647537776402, 52.486435072762625, 52.45515775680542, 51.62382663999285, 45.21239376068115, 41.209668568202424, 44.118108068193706, 47.66410732269287, 49.69913394110543, 49.69042784827096, 46.295089857918875, 48.698464802333284, 49.77124582018171, 47.70064442498343, 44.45074265343802, 44.06291157858712, 49.75351749147688, 51.9897153036935, 50.163648809705464, 35.495362349918906, 30.86242859704154, 31.260091372898646, 32.96814966201782, 34.101550238473074, 37.81519215447562, 36.30919790267944, 28.100299051829747, 25.11279947417123, 16.805090291159495, 8.399700726781573, 26.08355314391, 26.3687766960689, 36.1359098298209, 24.48030843053545, 19.160489661352976, 15.685881410326276, 20.642538683755056, 11.924110191208975, 5.396455228328705, 7.865635258810861, 14.294409104755946, 25.103367294584, 7.53307797227587, 2.8426057526043484, 1.7184993688549315, 5.19499568428312, 3.000928057091577, 5.0156800491469244, 13.861737830298287, 5.412344889981406, 20.908425399235316, 46.26988179343087, 56.27991873877389, 52.74010338102068, 58.29042516435896, 54.29223714556013, 56.827811990465435, 53.44187491280692, 38.04680688040597, 16.62769409588405, 17.854836293629237, 56.23893826348441, 35.55191721235003, 23.989412988935197, 17.022254501070293, 41.01648085457938, 32.07189457757132, 53.542460509708945, 31.744728224618093, 32.21185908998762, 37.99241638183594, 45.32620177950178, 60.16443075452532, 71.59371716635567, 3.27040981394904, 0.1945281188402857, 0.2581530176103115, 0.15052966906556062, 0.17848907091787883, 0.09961476935339825, 0.20282415939228876, 0.20488720440438815, 0.13239288942090102, 0.07991882480148758, 0.05551335867494345, 0.10296171797173363, 0.09888195831860815], [0.05524348154930132, 0.06143475736358336, 0.04420494833695037, 0.02958748895408852, 0.05613452695044024, 0.09440296901656048, 0.03711810129295502, 0.018204020768670098, 0.04849079603861485, 0.029074821820748702, 0.09668871600713048, 0.0292296499413039, 0.03494403438110437, 0.14440336637198925, 0.11921635004026548, 0.06441879152719464, 0.07407345596168723, 0.1278814593596118, 12.818155748503548, 61.539715494428364, 39.87933867318289, 44.158921786717, 34.79738106046404, 25.141877685274395, 37.66411747251238, 42.391348702566965, 33.10107217516218, 15.616210086005074, 36.94849818093436, 71.46427917480469, 75.12704985482353, 59.35968344552176, 10.808192150933401, 31.81732300349644, 56.21641220365252, 57.90570340837751, 51.65109831946236, 58.41504805428641, 50.06436947413853, 41.91706466674805, 33.19767645427159, 8.149040119988577, 2.789330222776958, 0.6816811412572861, 1.0990946058716093, 2.1341632987771715, 4.799034348555973, 6.768903800419398, 14.776546342032296, 22.032110657010758, 24.39487338066101, 28.801123891557964, 34.61951412473406, 41.34748956135341, 41.17544869014195, 38.03220871516636, 37.807295526777, 42.443672112056184, 44.824256965092246, 36.312602519989014, 25.359587328774587, 21.120157854897634, 17.740694761276245, 13.481461184365408, 23.014308009828838, 31.66155481338501, 34.17725086212158, 41.12334762300764, 45.01744467871529, 49.41735669544765, 46.13021605355399, 52.32466016496931, 52.111854212624685, 49.96119567326137, 41.154694420950754, 33.06904445375715, 28.962087597165787, 32.85545335497175, 31.825337750571116, 34.313571044376914, 40.78054434912545, 42.922736508505686, 44.41030413763863, 44.781869479588096, 42.25729363305228, 44.23190219061715, 48.34520448957171, 53.20017140252249, 47.392509187970845, 46.6282525062561, 50.038570812770296, 47.33477660587856, 46.25329991749355, 38.66586010796683, 37.45682838984898, 38.75719765254429, 41.13185569218227, 41.81437723977225, 41.858880451747346, 36.153294222695486, 30.93105595452445, 31.966004031045095, 33.55662734167916, 32.68355144773211, 34.16642556871687, 40.41325214930943, 46.14274365561349, 46.62138768604824, 31.857733726501465, 21.767792497362407, 18.44709379332406, 24.12015724182129, 25.387786592755997, 29.990082263946533, 32.20169734954834, 30.71587371826172, 16.576986142567225, 23.325106143951416, 9.368847625596182, 4.2840859804834635, 23.26272174290248, 25.3737199647086, 22.239500488553727, 7.407847114971705, 6.573316786970411, 12.069385732923235, 3.2466461062431335, 0.7733651729566711, 1.352555228131158, 1.4646146893501282, 1.949937241418021, 0.5411043731229646, 0.3081316000648907, 0.4918594498719488, 4.5770832640784125, 1.0861010402441025, 1.2430278424705778, 3.7544187222208296, 6.260124998433249, 26.361653055463517, 41.84136751719883, 45.02324295043945, 45.88030672073364, 48.29529905319214, 43.96626213618687, 46.69709873199463, 38.357238497052876, 18.364101035254343, 12.156827075140816, 30.43397487912859, 62.291656494140625, 54.41439342498779, 10.395279816218785, 22.131240606307983, 24.474742923464092, 29.42582253047398, 33.3511552129473, 18.540500164031982, 29.927458150046213, 28.817651918956212, 34.81475155694144, 51.51936742237636, 20.146315710885183, 0.014830064760254962, 0.10545167007616588, 0.03619608755356499, 0.03910040742318545, 0.023161166913009117, 0.02172799238802067, 0.1178724571530308, 0.0746277580037713, 0.055265964807144234, 0.056843070180288384, 0.017064925017101423, 0.05415301809885672, 0.01379279506259731, 0.022059829938890677, 0.04082736386252301, 0.039419946526842456, 0.014966024518279093, 0.06406444018440587, 0.10027735879910843, 0.05157534159453852, 0.02423933021990316, 0.07119983301631042, 0.03744757414928504, 0.015914122840123515, 0.05866886542311736, 0.02912046347877809, 0.05506255018657871, 0.018400348090965832, 0.07590425879295383, 0.15045636014214583, 0.09934575057455472, 14.977682794843401, 74.10654708317348, 47.579568590436665, 48.1794239452907, 41.61936214991978, 29.786659853799, 32.27486188071114, 32.25421183449881, 34.63215984616961, 21.132706301552908, 38.992863178253174, 70.60239682878766, 65.0609791619437, 56.7986295563834, 12.21626022883824, 34.28558022635323, 58.34314809526716, 61.612706320626394, 57.76527336665562, 62.119097982134136, 53.27897092274257, 47.31795849118914, 35.734078134809224, 11.098716310092382, 3.6599523169653754, 1.137178550873484, 0.8164814050708498, 3.125864484480449, 7.133505744593484, 8.879030891827174, 21.17094918659755, 26.867304733821324, 25.35907142502921, 32.71620798110962, 36.35713699885777, 46.15933247974941, 46.27255684988839, 41.423346519470215, 40.52764729091099, 44.4309333392552, 45.952981403895784, 36.8968939099993, 29.15408890587943, 25.559521743229457, 21.006980385099137, 16.77093815803528, 27.12293243408203, 35.70222064426967, 39.40889004298619, 41.946663992745535, 45.22945853642055, 48.76619931629726, 46.13969687053135, 51.04625415802002, 54.04388073512486, 51.906788553510395, 46.55897201810564, 40.388012817927766, 40.73327922821045, 42.04211139678955, 46.8966440473284, 46.293373652866904, 48.16017048699515, 49.407531942640034, 49.894208090645925, 47.50117206573486, 46.85455880846296, 45.240367208208355, 51.792299611227854, 55.97533403124128, 50.715162072862896, 48.81359992708479, 52.71174430847168, 51.32659312656948, 49.86221511023385, 43.11797741481236, 41.9234048979623, 43.215867110661094, 47.35820940562657, 46.99190385001046, 48.85122094835554, 43.202293804713655, 40.192625999450684, 42.440628801073345, 42.709975719451904, 39.592440605163574, 38.781766482761924, 44.758606910705566, 49.319293294634136, 49.49950177328927, 33.855830669403076, 23.050657510757446, 21.2027701990945, 26.16907157216753, 27.246650321143015, 33.24941968917847, 34.584821769169395, 32.18970128468105, 21.59790904181344, 26.07548975944519, 9.038656200681414, 11.14025958946773, 25.4103456565312, 25.429255178996495, 24.31614507947649, 9.412553531782967, 10.577610101018633, 16.42849792752947, 4.194632700511387, 1.2279260413987296, 1.5954511144331522, 1.4894241009439741, 3.179664386170251, 0.6489792274577277, 1.0235228495938438, 0.8023803617273058, 4.3131893788065225, 0.6124811002186367, 0.5151602881295341, 2.0741910082953314, 8.238340105329241, 30.57053824833461, 49.748945576804026, 50.08679131099156, 50.90503549575806, 52.288074425288606, 50.87035356249128, 51.77958788190569, 45.5544570514134, 19.303502695901052, 16.478997434888566, 32.19603109359741, 59.50894464765276, 47.79132536479405, 16.35639820780073, 21.907025711877004, 29.536701883588517, 21.338188852582658, 26.501938922064646, 23.13050447191511, 26.048843417848857, 30.736412593296595, 35.09826932634626, 63.576211656842915, 21.63570897919791, 0.03153871478778975, 0.03796342021918722, 0.08365309477916785, 0.09246446232178382, 0.07807397629533495, 0.051397402571248155, 0.0756924201601318, 0.0558215764218143, 0.046229374528463395, 0.01954860406528626, 0.0471940749058766, 0.024181559748415436, 0.02236786957031914, 0.11386967051242079, 0.2579534740320274, 0.241201394370624, 0.12352730014494487, 0.23450390089835438, 0.16401293341602596, 0.1486543882638216, 0.12403130238609654, 0.23480764031410217, 0.1745961255260876, 0.16536472445087774, 0.20292161059166702, 0.1335552063371454, 0.34683702886104584, 0.23059149512222835, 0.2154412737914494, 0.23050944666777337, 0.388454187129225, 22.734924418585642, 92.58310644967216, 56.368654182979036, 58.127691405160085, 48.07096951348441, 34.78222703933716, 50.05749075753348, 51.908355372292654, 39.34353181294033, 18.19240583692278, 43.01024906975882, 78.52483013698033, 82.15454823630196, 67.4846497944423, 14.453066876956395, 37.752026081085205, 63.676300457545686, 65.85357407161167, 62.73463889530727, 67.64190837315151, 59.41303171430315, 51.458098207201274, 40.45291594096592, 11.313208069120135, 4.679150564329965, 2.9237676603453497, 1.5659543829304832, 4.1637023602213175, 10.160174489021301, 12.754571046148028, 27.700270414352417, 32.319465841565815, 27.38013563837324, 34.64166498184204, 39.50271504265921, 47.82892901556832, 48.11429500579834, 46.156268324170796, 47.29758289882115, 51.514045102255686, 51.80832215717861, 42.32319729668753, 31.765749999455043, 31.856052262442454, 24.456797463553293, 19.13121168954032, 32.680720056806294, 38.64992788859776, 42.763588019779746, 47.188906124659944, 49.87186963217599, 53.44913925443377, 51.498258795057026, 55.5298433303833, 57.023438521793906, 53.82251112801688, 49.940087045942036, 44.95201696668352, 46.226601464407786, 52.1133029120309, 54.52089541299002, 53.802837303706575, 54.12393093109131, 53.38767548969814, 53.280582904815674, 48.896887983594624, 48.27433286394392, 46.387007577078684, 51.60297162192208, 56.77440813609532, 50.11735643659319, 49.77050583703177, 52.57031372615269, 50.615733351026265, 49.49968242645264, 42.68182509286063, 40.258491447993684, 43.02696296146938, 48.50266804013933, 48.84833744594029, 52.12572281701224, 48.339903014046804, 47.98817825317383, 50.667202132088796, 49.76453038624355, 44.3529189654759, 41.8723669052124, 48.53321579524449, 52.34386845997402, 55.99241617747715, 36.65039266858782, 26.097360951559885, 23.60869860649109, 27.651164020810807, 31.8766119820731, 36.9602232660566, 37.697771072387695, 40.79273496355329, 25.72605095590864, 28.351974964141846, 14.515922886984688, 8.829269630568367, 28.675391026905604, 29.57533734185355, 30.587154865264893, 14.049008284296308, 13.893309576170784, 20.953173535210745, 6.763763001986912, 2.3135966190270016, 3.3051625319889615, 4.165637867791312, 6.5604986633573255, 2.105296573468617, 2.459987129483904, 2.0307460938181197, 6.524639878954206, 2.4987424441746304, 4.133291832038334, 7.811033708708627, 8.64001372882298, 32.00479929787772, 51.16834442956107, 56.297643593379426, 56.11657701219831, 58.64950111934117, 53.96318783078875, 54.84202030726841, 47.54275356020246, 23.742911747523717, 16.819552966526576, 36.11886937277657, 68.47126620156425, 62.341676575796946, 14.106012174061366, 32.879250935145784, 35.591730390276226, 37.94000611986433, 44.98552118028913, 25.664465597697667, 38.16243532725743, 42.07532378605434, 46.838414669036865, 70.18419170379639, 36.0320759500776, 0.0927656911579626, 0.1820802039333752, 0.16453813309116022, 0.18611812511725084, 0.16406288716409886, 0.16500245460442134, 0.3070173098572663, 0.2414230310491153, 0.23386273958853313, 0.14546117532466138, 0.10684035305998155, 0.14671582728624344, 0.1547683280493532], [0.02688526056174721, 0.029785292090049813, 0.03653111761169774, 0.045103311738265414, 0.05172528426295944, 0.05203071323090366, 0.04388933116570115, 0.0016220185602183587, 0.08446033432015351, 0.01861773883657796, 0.01955617481975683, 0.10265288954334599, 0.0475607077325029, 0.049745709236179075, 0.031827618035354784, 0.029594779812863896, 0.061552856383579116, 0.07238727608429533, 0.8820512837597302, 25.346394436700002, 51.46641172681536, 50.850068296704976, 39.44325930731637, 41.463760716574534, 39.76009021486555, 43.82986899784633, 38.916502475738525, 27.57586291858128, 17.588935681751796, 66.3592778614589, 64.70669746398926, 48.69470930099487, 19.503857476370676, 29.078808648245676, 65.93069212777274, 53.70118168422154, 57.38244846888951, 48.05256026131766, 57.97723511287144, 46.97994252613613, 35.14560045514788, 16.895865031651088, 4.51877007314137, 0.7166997907417161, 1.0274407650743211, 2.6696390339306424, 5.286108715193612, 6.288597413471766, 12.99537910733904, 20.517135858535767, 21.28029646192278, 22.6608236176627, 27.67682545525687, 31.855433872767858, 36.48048489434378, 35.99860995156424, 38.48540844236101, 38.027202538081575, 33.54078197479248, 20.723231588091167, 8.513130068778992, 13.60472309589386, 9.164759925433568, 15.347266163144793, 21.420278344835552, 31.243349688393728, 34.186926228659495, 39.44555916104998, 46.41228512355259, 45.401197160993306, 49.81965739386422, 52.911942754473, 51.46760334287371, 47.48186649594988, 41.91980225699288, 34.04427623748779, 30.056302070617676, 31.957120759146555, 31.14772163118635, 34.13878910882132, 37.93208169937134, 44.30096728461129, 44.37823820114136, 42.827233518872944, 42.15970965794155, 43.30121183395386, 50.979714734213694, 52.967573506491526, 48.52128921236311, 47.75177621841431, 48.256132057734895, 49.291802746909006, 46.1959216935294, 40.83018922805786, 39.41359397343227, 39.74174002238682, 42.41146373748779, 42.49974407468523, 41.53632075445992, 35.87959425789969, 31.349823883601598, 33.29431200027466, 33.3452353477478, 32.42282029560634, 34.548447949545725, 41.46041515895298, 46.73820080075945, 45.69330985205514, 32.383931228092735, 19.00747295788356, 15.790333679744176, 16.831027916499547, 18.33697874205453, 23.99438442502703, 25.982378687177384, 32.27649123328072, 25.444482156208583, 17.86883865083967, 22.303595883505686, 6.0831465635980875, 8.379657779421125, 30.546876158033097, 29.43522344316755, 12.33679757799421, 0.7708701182688985, 2.306644946336746, 3.196457965033395, 1.9094162157603671, 1.2034303843975067, 1.9087932663304465, 1.6899194738694598, 1.4629681834152766, 0.8869545949356896, 0.27068526084933964, 0.4142492658325604, 0.34493387384074076, 0.06456989449049745, 1.9168032365185874, 9.715020775794983, 25.368126664842876, 45.6099523135594, 47.232617241995676, 47.29473066329956, 45.17666959762573, 52.02239268166678, 43.84367854254586, 39.13048962184361, 21.664120163236344, 18.814825466700963, 54.66568544932774, 51.44279479980469, 23.52753496170044, 9.41016856261662, 25.81648870876857, 22.550404582704815, 38.65365212304251, 24.94510817527771, 22.871407883507864, 44.37892607280186, 25.88948995726449, 43.193684986659456, 48.60907622746059, 4.723718915666852, 0.044422876821564775, 0.11299381751034941, 0.0233408022738461, 0.0480089717145477, 0.11449875389891011, 0.06313031459493296, 0.053253382444381714, 0.06652570382824965, 0.027379848129515136, 0.06243973557970353, 0.029448453736092364, 0.006868282432800957, 0.07339059188961983, 0.031662862947476764, 0.056827389236007414, 0.08964827058038541, 0.002595099799301741, 0.03112622656460319, 0.03938330563583544, 0.05717500951141119, 0.017721300778378333, 0.009810309341576482, 0.022149684938735197, 0.024743527539872696, 0.039924919073070796, 0.10702834797224828, 0.047018422545599084, 0.043033111574394364, 0.07947931052850825, 0.05204707610287836, 0.028472147017185177, 1.6299032143184116, 35.13863836015974, 63.65939549037388, 56.776739256722585, 37.88757848739624, 39.305351461683, 37.955608299800325, 30.84348085948399, 35.84278270176479, 29.51676402773176, 24.80590101650783, 66.90482262202671, 66.33457006726945, 51.626189027513774, 22.479878629956925, 32.006425176348, 70.87286935533795, 59.44072723388672, 61.923617362976074, 55.44945614678519, 59.939406394958496, 52.20570700509207, 38.8348194531032, 19.395277976989746, 6.892478380884443, 1.6850319589887346, 1.6862204266445977, 3.9354627217565263, 6.079679846763611, 7.962414979934692, 15.250123398644583, 26.124210527965, 23.60139431272234, 25.551461832863943, 30.00956153869629, 34.14293023518154, 37.677774156842915, 38.36512817655291, 44.28020259312221, 40.224768366132466, 34.766635281699045, 21.92372570719038, 15.767965691430227, 17.254107202802384, 10.731319887297493, 18.11063596180507, 24.923711197716848, 34.72153452464512, 37.329586029052734, 41.81663193021502, 48.02592781611851, 48.705499853406636, 51.63251536233084, 54.24689320155552, 52.636870520455496, 50.75077159064156, 46.30290310723441, 40.864054747990195, 39.32940265110561, 41.878241607121055, 44.23664433615548, 45.667094298771445, 48.676171507154194, 49.81279952185494, 50.09190171105521, 48.94385780606951, 46.300064768110005, 46.26252365112305, 54.46928766795567, 55.77897099086216, 51.76887028557913, 48.54075459071568, 51.40935659408569, 51.21728754043579, 49.91344765254429, 42.56369876861572, 43.15507732118879, 44.413934571402415, 45.94969490596226, 49.03614377975464, 49.714996678488596, 44.182549136025564, 39.83986595698765, 42.656398160117014, 40.96541506903512, 38.23081949778965, 36.945072719029014, 42.87763227735247, 49.59652294431414, 47.09373664855957, 34.34400068010603, 21.38706942967006, 18.122039692742483, 19.82039655957903, 22.732692309788295, 25.518558638436453, 28.134359121322632, 36.134436811719624, 27.520473616463796, 24.03147390910557, 19.054951735905238, 6.473243185452052, 16.645399842943462, 27.657558100564138, 29.494026047842844, 11.103244798524038, 2.1848041585513522, 4.760389336517878, 4.793404570647648, 3.4569934819425856, 1.2991131586687905, 1.8911635151931216, 3.2749947564942494, 2.080641325031008, 0.6608870827725956, 0.5397205959473337, 0.5985967538186482, 0.342485529503652, 0.11149000748991966, 2.2582129623208727, 10.483259643827166, 29.321085384913854, 52.140272344861714, 51.6003452028547, 51.10304873330252, 50.91280010768345, 54.75770391736712, 50.190006801060264, 40.1102933202471, 21.42003515788487, 21.546042476381572, 49.404394830976216, 53.90465273175921, 28.660610471452983, 15.373151676995413, 24.258551461356028, 27.36031069074358, 26.67071066583906, 29.51341847011021, 19.966449431010656, 41.68030827386038, 27.22395576749529, 49.412993226732524, 55.45320469992501, 5.3907798528671265, 0.11642552193786417, 0.11691018593098436, 0.05713553912937641, 0.08133092402879681, 0.06844617506223065, 0.05781893924410854, 0.07531236591083662, 0.03649397460477693, 0.04967746896935361, 0.024659253490556563, 0.07783791396234717, 0.030205844701933007, 0.022441665342609798, 0.150804285758308, 0.13107099463897093, 0.10059934402150766, 0.1635224747338465, 0.118625902437738, 0.11668865781809602, 0.1972487728510584, 0.09316536863999707, 0.21142925907458576, 0.09628717255379472, 0.13986064227563993, 0.19138219979192528, 0.13123803638986178, 0.1474714438830103, 0.14364104584923812, 0.1527976452239922, 0.20235356821545533, 0.19090387331587927, 2.820719144174031, 56.66272279194423, 74.4924430847168, 66.46524483816964, 52.87771940231323, 52.02013104302542, 54.21396221433367, 56.832477705819265, 47.21465962273734, 32.91529471533639, 23.584570986883982, 74.97542626517159, 71.5618040902274, 58.97842884063721, 22.674278804234095, 36.81577369144985, 75.01282146998814, 64.51273155212402, 66.50468976157052, 60.22858347211565, 68.08719757625035, 57.039912700653076, 42.18886429922921, 22.226842607770646, 8.344600643430438, 3.4991762127195085, 1.6162848536457335, 5.5510613322258, 8.51440680027008, 10.038300480161395, 18.36930349894932, 30.602652822222026, 25.75322536059788, 29.000650099345616, 32.519591331481934, 37.29529319490705, 41.1870938709804, 44.18607187271118, 48.32725381851196, 44.694874559129985, 41.94760547365461, 28.39834029333932, 18.65186067989894, 23.099836860384258, 13.908441884177071, 21.641677481787546, 29.126066820962087, 39.38049970354353, 42.77709879193987, 44.81501933506557, 52.63900709152222, 50.28761509486607, 53.68234164374215, 54.466900961739675, 53.8556991985866, 52.25735296521868, 48.902932916368755, 45.99880824770246, 46.4263448034014, 51.28954880578177, 52.316923345838276, 52.214559010096956, 53.372663906642366, 53.62806926454817, 52.327133723667686, 49.37418058940342, 46.11743484224592, 47.207079138074604, 53.926536083221436, 56.37831565311977, 52.93521574565342, 48.594304357256206, 51.70877531596592, 52.82676131384713, 49.71820674623762, 43.48681558881487, 43.58039740153721, 44.26332541874477, 47.48301989691598, 51.769148213522776, 53.85882936205183, 48.24433749062674, 47.480994497026714, 49.46536527361189, 49.71663645335606, 43.89962543760027, 39.972708565848215, 45.31426477432251, 52.98806721823556, 51.65170281273978, 39.338796615600586, 22.19954834665571, 22.212748186928884, 21.63886867250715, 26.1217508656638, 29.86013010569981, 33.58507326671055, 40.69133642741612, 34.41808237348284, 25.526472636631556, 25.832667589187622, 10.656254155295235, 13.929556591170174, 36.878224100385395, 32.54284347806658, 17.25140609060015, 3.5850841743605475, 8.570655073438372, 4.560861825942993, 4.47806578874588, 3.0359263505254472, 3.4157179253441945, 5.15576832635062, 3.4984392694064548, 1.927532123667853, 1.4952071734837122, 0.9865805804729462, 1.1513162893908364, 0.22308199879314217, 3.8417445506368364, 12.251324313027517, 30.964921474456787, 53.96520280838013, 57.92672518321446, 56.382168429238455, 55.02301393236433, 57.70739834649222, 53.3441276550293, 45.9132342338562, 28.14439579418727, 24.60971862929208, 63.13703686850411, 57.035306044987266, 31.654571873801096, 14.63477008683341, 40.565466335841585, 31.515646117074148, 48.906997612544465, 36.135979311806814, 31.158793585641043, 54.89838409423828, 37.808733803885325, 56.235029901777, 73.3121873310634, 9.190245917865209, 0.4662528410553932, 0.3316090745585305, 0.136471794119903, 0.24809077754616737, 0.23303544255239622, 0.3198718029473509, 0.1837184453116996, 0.19884441580091203, 0.11767774474407945, 0.06179460484002318, 0.22912721655198506, 0.2538889949875218, 0.15980958539460385], [0.028548444887357097, 0.029521067161113024, 0.030155890953860114, 0.03564392628946474, 0.07807143178901502, 0.07120228252772774, 0.03349662419142468, 0.055095408244856765, 0.013371321339426296, 0.03158012917265296, 0.030822405724653175, 0.022435322736522982, 0.05451874847390822, 0.0383180192272578, 0.024612724647990296, 0.021475034533068538, 0.04852082121319004, 0.03534442771758352, 0.18331988741244587, 7.279274174145289, 44.03107840674264, 62.63659981318882, 62.77482727595738, 52.56325088228498, 43.96905531202044, 40.79964147295271, 40.569524083818706, 30.76734597342355, 10.641096660069056, 43.08065169198172, 73.2241119657244, 58.98054109300886, 25.109705788748606, 17.353353534426006, 43.27671248572213, 46.75764880861555, 53.07530879974365, 44.860460553850444, 45.766054017203196, 47.285916873386924, 36.62470517839704, 25.518902574266704, 8.593246272632054, 0.3342486029224736, 1.492764338850975, 3.2164249164717535, 8.618486472538539, 5.259335134710584, 8.495769126074654, 11.560552648135594, 11.2416398865836, 11.748209595680237, 17.614600590297155, 21.31574617113386, 27.304330791745866, 24.967305932726177, 20.51578790800912, 15.544780867440359, 7.817148991993495, 1.9827635713985987, 10.909938965524946, 10.432981610298157, 8.15202350275857, 19.26316145488194, 22.0693165234157, 29.29626989364624, 35.5825309753418, 34.715850898197715, 43.60517120361328, 45.152239731379915, 50.045334884098594, 51.374542645045686, 54.21516077859061, 50.327115603855674, 39.57894720349993, 34.375142506190706, 29.22134052004133, 30.31265238353184, 31.354614666530065, 35.71405342647007, 39.10101883752005, 46.181125504629954, 44.70922606331961, 43.43655579430716, 41.90478025163923, 44.4213239806039, 50.88489614214216, 51.92917217527117, 48.83842584065029, 46.571280751909526, 48.69485868726458, 46.82732881818499, 45.444053649902344, 41.69152266638619, 38.77444308144705, 40.9044828414917, 42.0711270741054, 42.86371156147548, 41.154746532440186, 35.674893379211426, 31.59382724761963, 32.3220123563494, 32.834688663482666, 32.39320012501308, 33.77529409953526, 41.30761384963989, 47.986288343157085, 46.94034474236624, 29.460243906293595, 13.946831549916949, 9.712454284940447, 12.864277022225515, 13.778772865022932, 21.33684090205601, 18.987449986594065, 26.874143498284475, 31.387226036616735, 27.72975335802351, 17.603994165148052, 16.70395404951913, 5.60603243964059, 17.9818754196167, 25.807226760046824, 18.212885652269634, 2.6333837679454257, 0.6586309809769902, 2.227996115173612, 4.139459661075047, 3.515823010887418, 1.9139579491955894, 0.7333146163395473, 0.08461725232856614, 0.3116466285926955, 0.15774495261056082, 0.5335146061011723, 0.39604737396751133, 0.43428222515753334, 2.682704035724912, 12.714838641030447, 24.654755115509033, 44.265781606946675, 43.859315463474815, 46.991841316223145, 49.126668385096956, 46.188132762908936, 48.349088532584055, 44.471517767224995, 27.134449073246547, 55.183882100241526, 54.97279930114746, 34.0179842540196, 9.989491990634374, 14.802708046776907, 29.034911666597637, 24.45872732571193, 33.213890075683594, 15.779596975871495, 45.65070349829537, 39.32063749858311, 28.114801679338726, 56.284574031829834, 17.58123012951442, 0.20964938029646873, 0.07428091804363898, 0.10639766324311495, 0.02990723161825112, 0.04802531083779676, 0.13539532545421804, 0.05040421729375209, 0.11621905730238982, 0.1173666092966284, 0.029784749262034893, 0.03799645130389503, 0.06686553452163935, 0.018376882653683424, 0.04087671032175422, 0.05167181231081486, 0.03689029673114419, 0.09017904781337295, 0.04397562385669776, 0.05390209584896054, 0.03505154146945902, 0.009639270171257002, 0.08957518557352678, 0.01949156810795622, 0.026097622201112763, 0.03145185212737747, 0.04238454405484455, 0.08042079143758331, 0.013335418355252062, 0.10319180919655732, 0.07843343700681414, 0.059153325855731964, 0.02438004650840802, 0.2640301079622337, 8.342596956661769, 64.80195031847272, 64.66659940992082, 65.19900512695312, 50.31396613802229, 41.20112575803484, 30.776326520102366, 35.016190256391255, 33.14400856835501, 19.00572896003723, 51.360694885253906, 77.38670131138393, 60.36038385118757, 29.9134019442967, 21.066318001065934, 47.53275162833077, 54.14670017787388, 56.71033879688808, 51.7207088470459, 53.92322874069214, 54.98230791091919, 41.02901193073818, 27.872611795152935, 9.726801446505956, 0.5396472055997167, 1.8545386918953486, 4.529333940574101, 11.293006181716919, 7.442631534167698, 10.216173495565142, 12.677611930029732, 14.867079632622854, 12.960260306085859, 19.680454628808157, 25.537989275796072, 31.514120987483434, 29.10203126498631, 23.786800043923513, 17.863432952335902, 10.692122493471418, 4.823814230305808, 9.802357026508876, 12.388288940702166, 11.15844910485404, 20.672676495143346, 25.643817288534983, 33.514451776232036, 39.076436110905235, 36.894156319754465, 45.47715139389038, 47.491962228502544, 50.12425252369472, 52.7274055480957, 54.7632485798427, 52.62831381389073, 44.40677097865513, 41.671616077423096, 38.86144495010376, 40.18589666911534, 44.02440118789673, 45.97166163580758, 47.66527114595686, 51.99328667776925, 49.887777532849995, 48.12886537824358, 44.363657406398225, 45.92106832776751, 52.82256460189819, 52.66287415368216, 50.470821721213206, 50.937233448028564, 53.49174213409424, 49.92056608200073, 48.26578310557774, 44.001697949000764, 40.560296876089915, 43.51118639537266, 45.76654733930315, 47.32233238220215, 47.690680708204, 44.02432475771223, 40.48478037970406, 42.51276847294399, 42.246426650456016, 37.92043651853289, 38.015335014888215, 42.719213349478586, 51.12642594746181, 51.65622956412179, 35.60017939976284, 15.279377051762172, 10.87948761667524, 15.003578730991908, 17.328916719981603, 24.942153453826904, 20.97410672051566, 28.803983075278147, 34.4622347014291, 30.492155620029994, 23.165295839309692, 13.546007343700953, 8.83550477027893, 24.458470242364065, 22.569828271865845, 17.497598137174332, 3.339258210999625, 3.368535965681076, 3.988575186048235, 5.829925545624324, 4.398588819163186, 3.022555410861969, 0.8504195553915841, 0.8195846442665372, 0.4018389146242823, 0.5079032746808869, 1.383990507040705, 0.5330498367547989, 0.09179138272468533, 3.024004544530596, 15.875838211604528, 27.7685329914093, 47.16866602216448, 46.768439361027305, 51.4949688230242, 53.0929468018668, 49.50113112585885, 52.46128954206194, 47.127251284463064, 31.54086807795933, 52.21740082332066, 57.82288088117327, 36.41820124217442, 17.237473215375626, 18.114881311144146, 32.40444231033325, 22.17569170679365, 28.667414494923182, 19.85977373804365, 33.54454789842878, 41.697845527103965, 27.651565279279435, 66.33044978550502, 22.776624032429286, 0.33366622988666805, 0.19368395342358521, 0.08258869046611444, 0.033572908490896225, 0.014484380005991884, 0.027532572791512524, 0.021212634863331914, 0.08188629815621035, 0.006584468621960176, 0.09680614327745778, 0.0421978621078389, 0.08765199341412101, 0.056014887655952146, 0.021016577258706093, 0.16911342686840466, 0.06985006401581423, 0.16450386707271847, 0.1768268093998943, 0.2560646225299154, 0.10704683126615626, 0.1763364185712167, 0.17097254496599945, 0.19658597984484263, 0.09224393844072308, 0.15890186838805676, 0.12546181705381187, 0.27917780514274326, 0.11627974547445774, 0.22217699592666967, 0.14836071830775055, 0.2083036960767848, 0.17056204485041754, 0.8423185529453414, 20.24780978475298, 85.30973216465541, 74.25074304853166, 75.2816264288766, 63.87777737208775, 58.95559011186872, 52.705994674137656, 50.02844033922468, 35.958028997693745, 14.002988627978734, 53.2462796483721, 81.06440367017473, 64.05950055803571, 30.830209800175258, 23.060886996132986, 54.114717619759695, 56.85430547169277, 62.354655810764854, 55.19132014683315, 56.59738540649414, 59.9804494040353, 44.91482325962612, 30.85161372593471, 11.637262497629438, 0.6621472037264279, 2.971703065293176, 6.397629414285932, 14.004974944250923, 10.289076600755964, 13.127056155885969, 15.96900486946106, 20.4658043043954, 15.669513191495623, 22.232484545026505, 28.759234939302715, 34.84753315789359, 32.24959475653512, 28.821754830224172, 24.087825536727905, 16.882637398583547, 7.347133755683899, 17.236950363431657, 14.84934435571943, 13.856489334787641, 26.8479540007455, 30.326871871948242, 38.20587199074881, 43.73342105320522, 39.26789719717843, 48.220630237034385, 50.755346979413716, 52.88889557974679, 54.57670681817191, 56.87094293321882, 55.781552246638704, 48.118217263902935, 46.16015584128243, 44.963603087833945, 47.96955360685076, 51.39045054571969, 52.010323660714285, 52.7875144141061, 55.781552246638704, 52.53098692212786, 49.16883700234549, 45.32425628389631, 48.09379087175642, 53.87877416610718, 52.74566541399275, 51.38178266797747, 50.11536577769688, 52.78415496008736, 49.02889680862427, 48.7728522164481, 43.83731746673584, 41.32649557931082, 44.76920291355678, 46.63446766989571, 47.30418368748256, 50.009655884334016, 49.451760700770784, 48.19191680635725, 51.302667004721506, 52.20770113808768, 45.54681750706264, 41.23262889044625, 45.399651186806814, 53.46381037575858, 56.056311811719624, 39.688697474343435, 17.285632916859218, 12.39947988305773, 19.547499111720494, 21.324349778039114, 29.659580775669642, 26.33361186300005, 35.7111108643668, 39.601462841033936, 36.04378366470337, 24.598620619092667, 23.163273913519724, 9.286151034491402, 24.930070536477224, 30.21417556490217, 25.015641076224192, 4.913953644888742, 4.994346039635794, 5.908667308943612, 6.03417262009212, 5.899779260158539, 3.8720638837133134, 3.008326585803713, 1.5016003847122192, 0.9806850339685167, 1.4593796559742518, 2.841720074415207, 1.1073755558047975, 1.0008201535258974, 4.835760789258139, 17.6651383127485, 31.640036242348806, 53.807655879429404, 53.7128199168614, 58.250865595681326, 56.95258774076189, 55.80941799708775, 55.15191691262381, 52.63431358337402, 35.81376007625035, 62.51948792593819, 61.58612251281738, 40.58677993501936, 14.652135372161865, 25.29454176766532, 42.4521141733442, 33.049016271318706, 43.56625434330532, 24.34717399733407, 53.682546615600586, 53.389488969530376, 37.11562320164272, 73.71986593518938, 36.76259912763323, 0.6935578382440976, 0.30814970337918823, 0.1906198521277734, 0.09660429946546044, 0.17454595464680875, 0.136580441147089, 0.2186529700245176, 0.19559123393680367, 0.2595486284366676, 0.15151738535080636, 0.18401751640651906, 0.1718736259000642, 0.13882354221173696, 0.1560565267822572], [0.03720691813422101, 0.07188131287693977, 0.07558776291885547, 0.02064094366505742, 0.01912800395595176, 0.023540839486356293, 0.03755536961502262, 0.041259295506668944, 0.02794991254008242, 0.03184595883690885, 0.06024191315685, 0.10254191514104605, 0.09116020945033856, 0.08516195310013634, 0.05417277703859976, 0.01484823423171682, 0.0823527095573289, 0.006311846822167614, 0.06538072348173175, 3.2922373626913344, 43.68712173189436, 56.769631249564036, 71.33975355965751, 47.62979016985212, 52.521843092782156, 44.595421518598286, 40.360921791621614, 37.70880481175014, 17.300621918269567, 22.876704147883824, 61.25214345114571, 49.76798711504255, 58.15145424434117, 20.309040784835815, 30.82512719290597, 52.339918409075054, 52.263189452035085, 56.12045758111136, 38.111532824380056, 48.08862836020333, 39.27300064904349, 28.14222274507795, 6.806424941335406, 1.708756040249552, 1.7805825003555842, 2.9141444052968706, 3.14176869392395, 3.8640886545181274, 5.263676021780286, 6.096913984843662, 4.826607840401786, 4.4463333657809665, 6.9830129742622375, 11.239467705999102, 6.24648003918784, 5.963899842330387, 4.841120455946241, 6.021826973983219, 2.325696038348334, 7.067651586873191, 13.135482583727155, 8.874554514884949, 11.862087965011597, 22.612267868859426, 21.749624695096696, 30.37119095666068, 29.99654061453683, 30.599237782614573, 32.396813188280376, 43.7233670098441, 49.31306076049805, 52.357070037296836, 53.56871427808489, 51.42127275466919, 45.42137125560215, 37.76345934186663, 28.355308362415858, 30.78218732561384, 32.86520515169416, 35.23325545447213, 39.37021289552961, 46.36337675367083, 44.86359766551426, 43.10996961593628, 41.173266955784385, 44.383689062935964, 49.644156319754465, 50.225585051945274, 48.963979789188926, 46.54523890359061, 49.231937067849294, 46.61392184666225, 48.21481806891305, 41.75983040673392, 38.646141120365684, 40.18750517708914, 40.875856263296946, 43.19106551579067, 42.24464096341814, 34.36752380643572, 30.59630216870989, 32.04936851773943, 33.9501941544669, 34.202677794865195, 34.07980932508196, 41.2976153918675, 47.244012287684846, 47.3896986416408, 26.16961005755833, 9.155659522329058, 4.057040129389081, 5.93513777426311, 7.810438769204276, 13.34908584186009, 12.80133329119001, 23.637141057423182, 29.91039684840611, 34.97777019228254, 22.68620365006583, 14.79337661606925, 14.202784078461782, 9.002529042107717, 17.962998901094707, 17.983570780072892, 4.259327811854226, 2.7560533455439975, 1.0977035548005785, 3.3794761214937483, 3.9648805260658264, 4.307124469961439, 1.0441832095384598, 1.2267900109291077, 0.5022362587707383, 0.16305611761552946, 0.13588218790079865, 0.30002981051802635, 0.5632879084774426, 2.059070859636579, 17.79113868304661, 35.097935812813894, 47.84899541309902, 42.46299157823835, 43.2089467048645, 46.73232957295009, 47.55500670841762, 49.84842293603079, 46.898954323359895, 54.24364144461495, 50.74966335296631, 43.96696390424456, 22.351439441953385, 5.882862567901611, 23.499375649860927, 17.646322590964182, 37.13235446384975, 24.904450791222708, 25.058650425502233, 61.49879060472761, 28.225241558892385, 35.944240297589985, 54.33120264325823, 8.2437127998897, 0.35248558861868723, 0.017931247994835888, 0.08528946340084076, 0.005904187647891896, 0.1797062541757311, 0.041869159388755045, 0.1461670281631606, 0.036626512849969525, 0.058374157308467796, 0.06919310641075883, 0.0650857100263238, 0.0966034648673875, 0.056054005199777227, 0.01465935043857566, 0.06580073665827513, 0.07569556856261832, 0.07009722039635692, 0.054306058279637776, 0.00804078670418156, 0.046470556408166885, 0.03379854513332248, 0.06140763631888798, 0.0434851210697421, 0.060059746860393455, 0.08654787444642612, 0.0659288712111967, 0.06060217453965119, 0.06869633056755577, 0.11700807139277458, 0.027265601492087756, 0.10181206251893725, 0.01976735018459814, 0.12523686912442955, 5.702614137104579, 63.76263877323696, 61.89275346483503, 78.74649156842912, 48.668392998831614, 50.88953406470162, 37.06926482064383, 29.65640197481428, 36.68748562676566, 22.27509958403451, 33.59967838014875, 66.07439477103097, 53.59535019738333, 53.20591756275722, 25.161817278180802, 33.28646053586687, 58.104873520987375, 56.82298994064331, 58.64957754952567, 43.081238814762656, 53.46672861916678, 42.72505331039429, 31.93403536932809, 8.489555699484688, 2.9379126727581024, 3.883388578891754, 3.835405622209821, 5.938199324267251, 4.1713336535862515, 6.282635859080723, 6.948046599115644, 7.049346123422895, 4.982940571648734, 8.463717085974556, 14.458787849971227, 9.655207208224706, 8.043231214795794, 5.448492893150874, 6.657952794006892, 2.4592443236282895, 7.325090595654078, 13.797656331743513, 10.693636332239423, 15.371299982070923, 25.58976204054696, 25.065272058759415, 33.63621548243931, 32.39243582316807, 31.551811490740093, 37.11003337587629, 47.95734214782715, 50.44383144378662, 53.23194204057966, 55.16533388410296, 55.21444722584316, 48.17011335917881, 43.60419845581055, 38.49009847640991, 40.97978741782052, 42.91885246549334, 45.90538624354771, 49.72603736604963, 51.96468094417027, 49.3110214642116, 48.11956174033028, 44.90298352922712, 47.61828395298549, 53.02651507513863, 52.82473938805716, 52.12749808175223, 48.12630149296352, 52.204525811331614, 50.46765334265572, 49.39754043306623, 44.179429394858225, 40.74360425131661, 42.91789013998849, 45.821712562016074, 47.03692470278059, 50.080607414245605, 43.31832524708339, 40.59923110689436, 40.755305017743794, 41.62702601296561, 39.502812317439485, 38.939681666237966, 43.97586802073887, 48.63394383021763, 50.66078894478934, 31.351745060512, 11.794176271983556, 5.298750094005039, 9.208411114556448, 13.503659810338702, 17.666053737912858, 16.47599928719657, 24.783069235937937, 31.858907972063335, 38.044114453451975, 27.07383472578866, 17.901621988841466, 12.750593202454702, 15.664993388312203, 21.33116943495614, 21.319423505238124, 6.104857512882777, 4.137969706739698, 5.901468975203378, 7.161732801369258, 7.304629019328526, 7.250236783708845, 2.169136187859944, 1.4353867662804467, 0.5521422379783222, 0.12603246500449522, 0.09175594284066133, 0.6537592081086976, 0.6440264646496091, 3.08463083420481, 18.42611197062901, 39.85331072126116, 48.00458295004708, 46.98823520115444, 46.918874808720176, 50.57594796589443, 53.3707948412214, 55.19399867738996, 51.80984728676932, 59.008827209472656, 54.488905906677246, 47.9741324697222, 26.585430213383265, 11.376801456723895, 23.129476138523646, 23.005702665873937, 24.027600288391113, 26.921073368617467, 22.940439973558696, 54.75339950834002, 31.93364974430629, 37.42838593891689, 65.36968762534005, 9.24009142603193, 0.2877180097358567, 0.15815211433385098, 0.07344560750893184, 0.025923130135717135, 0.013551690366252192, 0.030467450485697815, 0.0594904220529965, 0.008598160813562572, 0.05848783228014197, 0.023527808221323148, 0.018578085250088146, 0.03589722001925111, 0.10335660499653646, 0.042186720562832694, 0.19382791141314165, 0.13255024169172558, 0.2068765198013612, 0.1537859993321555, 0.09453096107712813, 0.12126564793288708, 0.14342090194778784, 0.2453602169241224, 0.15819820043231758, 0.13293155123080524, 0.17440632571067127, 0.19733234122395515, 0.2544824688562325, 0.13652348491762364, 0.1667796599545649, 0.05396963043936661, 0.3778262117079326, 0.06507674657872745, 0.3007579328758376, 12.959247606141226, 81.26992443629673, 66.93882710593087, 89.41674286978585, 58.08854178019932, 65.96068055289132, 60.765331813267295, 50.89490154811314, 45.69560623168945, 20.511146511350358, 30.194869995117188, 70.45258671896798, 56.33009515489851, 65.97689070020402, 25.172651256833756, 38.333586829049246, 64.07211153847831, 64.08561188834054, 67.97646413530622, 47.24667344774519, 58.60260772705078, 47.92562709535871, 34.382121971675325, 9.729977641786848, 4.035287490912846, 4.847293496131897, 5.090894298894065, 7.720316290855408, 6.644812447684152, 9.302297779491969, 9.247436540467397, 10.399063110351562, 6.167334411825452, 10.503755961145673, 16.1172342641013, 12.101469908441816, 11.605086258479528, 9.81798005104065, 10.831295779773168, 5.325439427580152, 11.592628138405935, 18.632136481148855, 14.45294267790658, 18.535839659827097, 30.221280097961426, 30.866305691855295, 38.07209832327706, 36.39447314398629, 34.94283464976719, 38.69368764332363, 50.90009880065918, 51.006305490221294, 54.20422431400844, 54.14892360142299, 57.941472734723774, 52.22319909504482, 49.31360271998814, 44.34056159428188, 48.976681096213206, 52.24896648951939, 51.461589676993235, 52.95426423209054, 54.660623686654226, 49.643426758902415, 48.62617574419294, 46.15060554231916, 47.67283426012312, 51.8865692956107, 52.95585536956787, 51.124952929360525, 48.752111843654085, 51.47235243661063, 51.64327117374965, 51.003296920231406, 45.33496345792498, 40.03966835566929, 43.91425139563424, 47.28787279129028, 48.866694586617605, 53.22835329600743, 49.68187461580549, 49.506738322121755, 48.53127724783761, 48.68233803340367, 46.87932218824114, 42.92494256155831, 46.135163170950754, 51.028963565826416, 53.79729264123099, 36.7948248726981, 13.253030470439366, 6.142290498529162, 10.030716521399361, 15.122031620570592, 21.843623399734497, 21.36426717894418, 32.16616426195417, 38.34064619881766, 43.22961759567261, 31.758176462990896, 22.42437641961234, 19.927181686673844, 16.163559641156876, 22.269330842154368, 23.461829321725027, 7.793061324528285, 3.327541376863207, 5.66767338344029, 7.293739455086844, 5.969425397259848, 7.366077150617327, 2.655966933284487, 2.8825153367859975, 1.5796029248407908, 0.3294997534581593, 1.5643533659832818, 1.2992478885820933, 1.2647540995052882, 3.800847887992859, 22.43418206487383, 42.59575775691441, 56.38530554090227, 50.64324474334717, 53.88345725195748, 52.9014961378915, 57.33881030763899, 57.33071218218122, 57.40100710732596, 62.46639674050467, 62.68940612248012, 50.4813551902771, 29.09445251737322, 8.700024451528277, 36.169921261923655, 27.126684461321148, 44.509520939418245, 35.30691678183419, 35.017124789101736, 71.24448680877686, 41.5469445501055, 46.35684197289603, 77.30212088993618, 16.760243143354142, 0.6139977074095181, 0.2761429894183363, 0.1989213481013264, 0.2231427819601127, 0.16535591706633568, 0.086078932109688, 0.3097713477909565, 0.13800243341497012, 0.11228936245398861, 0.26082370430231094, 0.26742614858916824, 0.22172606869467668, 0.32111992740205353, 0.17158216796815395], [0.033528606939528666, 0.03738727952752795, 0.09018421825021505, 0.007272082863242498, 0.055791388398834636, 0.11205074882933072, 0.03257199130686266, 0.09948859576668058, 0.06703296982284103, 0.03810794817815934, 0.02821742327484701, 0.04645763710141182, 0.0711129398218223, 0.05617452319711447, 0.042655910564852614, 0.03308499092236161, 0.05817223207226821, 0.033944063753421815, 0.04510311496311, 1.2314683198928833, 24.5864543233599, 59.787435395377024, 37.7657869883946, 42.0777348109654, 50.76094722747803, 47.460921151297434, 43.486912863595144, 41.488638741629465, 29.428719929286412, 13.100859710148402, 31.44229745864868, 48.6595583643232, 74.92084121704102, 42.10272053309849, 40.55381073270525, 61.50567626953125, 55.80813952854702, 53.02690070016043, 53.79553822108677, 38.97846303667341, 37.31576953615461, 24.89403544153486, 6.652245283126831, 1.136194837944848, 2.2078676181180135, 2.4355485779898505, 4.915617738451276, 3.4744087074484145, 3.4900755924837927, 3.190779549734933, 1.6707955343382699, 2.4139818038259233, 4.956604293414524, 3.139825586761747, 2.566683449915477, 3.7811975138528005, 2.835680569921221, 1.9045917774949754, 0.9433003600154604, 13.002968277250018, 11.756398047719683, 11.015859041895185, 19.72922577176775, 23.24078801700047, 22.530461515699113, 27.435241801398142, 27.516033717564174, 24.262914930071148, 29.187367303030832, 35.944924695151194, 38.11888401848929, 48.98938935143607, 52.11398383549282, 51.51100526537214, 49.59541470663888, 41.07895558220999, 30.38725519180298, 29.554079328264507, 33.29572595868792, 35.492294720241, 39.08515610013689, 46.977899755750386, 46.911627837589805, 45.49484150750296, 43.95772280011858, 45.17333793640137, 52.69963707242693, 52.02663803100586, 50.65347943987165, 43.19159010478428, 50.47672421591622, 47.350781781332834, 48.03472076143537, 41.5755398614066, 39.18148939950125, 41.24589647565569, 42.90349694660732, 43.44053363800049, 41.59885106767927, 33.381525788988384, 28.84259942599705, 32.01907089778355, 35.17506429127285, 33.84816680635725, 37.32447215488979, 45.099864210401265, 48.548477513449534, 45.84103897639683, 19.151726245880127, 5.84968535389219, 4.190913242953164, 9.101758871759687, 13.36006920678275, 17.00536690439497, 12.924025450434003, 18.226297412599834, 30.627332823617117, 31.037995679037913, 37.69833387647356, 20.14332798549107, 19.166668346949987, 23.301942586898804, 9.593137213162013, 12.665105172566005, 8.49804379258837, 4.606113272053855, 3.78412617955889, 0.8689426928758621, 2.4804176560470035, 5.08403251852308, 2.9073577523231506, 0.4831416319523539, 0.12069329007395677, 0.16038387029298715, 0.2840544363217694, 0.4984658296619143, 0.8343933182103294, 2.2658297078950063, 12.721342154911586, 33.464733941214426, 45.03359924043928, 42.17710099901472, 43.79124396187918, 40.64417552947998, 45.20358344486782, 52.891518524714876, 51.50615542275565, 45.872403144836426, 44.22481850215367, 44.65206323351179, 16.924611466271536, 13.241218532834734, 23.70785113743373, 23.749458687646047, 40.24609586170742, 19.978487185069493, 47.37933540344238, 44.544713565281455, 25.54114896910531, 51.9346855708531, 42.72342048372541, 0.7144000998565129, 0.06379700239215579, 0.029163414745458534, 0.039329141577971835, 0.02125520445406437, 0.07520475025687899, 0.08324440635208573, 0.06766004474567515, 0.023867735605952994, 0.05017494370362588, 0.029911560671670095, 0.0075083105891410795, 0.055488660000264645, 0.02160352362053735, 0.011767976168942238, 0.08062981415007796, 0.030085340275296142, 0.013148604093917778, 0.015246924445299166, 0.055940221662500074, 0.02780451435994889, 0.02270260955473142, 0.016122673970780203, 0.025015901674383452, 0.05125789237873895, 0.04097684173445616, 0.042064916741635115, 0.060513388232461045, 0.052059242235762734, 0.0887520479570542, 0.06775605745081391, 0.03313324833288789, 0.045521947488720925, 0.047105526085942984, 1.4467250321592604, 40.49980238505772, 67.68328489576066, 46.14868783950806, 50.17342839922224, 53.823973723820274, 45.7976405279977, 30.719921043940953, 37.160970619746614, 32.50567061560494, 20.787695237568446, 41.58885955810547, 52.517503942762104, 71.33614744458879, 42.60679497037615, 44.71404116494315, 62.71147360120501, 59.71090793609619, 59.87189769744873, 56.06796046665737, 45.41721623284476, 42.9444009917123, 29.935632705688477, 7.774680733680725, 1.966824620962143, 3.002588893686022, 3.290376113993781, 5.1772317460605075, 4.27156880072185, 5.374736896583012, 4.348268662180219, 3.015019872358867, 3.133558528763907, 8.12227131639208, 5.5780133945601325, 4.493075634752001, 5.834450559956687, 5.615680447646549, 5.150825551577976, 4.584102247442518, 13.215355600629534, 12.06705287524632, 13.741950018065316, 23.441453729357036, 27.82820064680917, 23.94418716430664, 33.440206800188335, 28.631891829626902, 26.576062304633005, 32.76669359207153, 40.917583669934956, 42.1602064541408, 51.339204107012065, 55.19733381271362, 54.496691363198416, 53.930771010262625, 45.90031058447701, 38.08425072261265, 37.36537272589547, 45.18595239094326, 47.30188035964966, 48.50806679044451, 52.63639109475272, 49.48468473979405, 48.815663542066304, 44.78098358426775, 46.786240645817344, 53.73145151138306, 52.468453134809224, 53.49613686970302, 45.90375689097813, 53.73415783473423, 50.85612712587629, 50.60500533240182, 42.93118551799229, 41.874812671116416, 42.828571047101704, 44.86360461371285, 49.82865531103951, 47.197045939309255, 42.68276309967041, 39.65147597449166, 41.10552896772112, 41.931923389434814, 39.93388203212193, 41.148510524204795, 47.493813923427034, 50.438210351126536, 48.97423185620989, 26.709012610571726, 7.75040112222944, 3.5154955770288194, 8.239265084266663, 12.19027657168252, 19.74967779432024, 15.678980112075806, 20.173957381929668, 32.63299635478428, 35.152090072631836, 39.49462733949934, 23.28917874608721, 18.244922058922903, 24.34372247968401, 20.24600499016898, 21.680120127541677, 13.696632129805428, 6.401034900120326, 5.77904258455549, 4.119211307593754, 6.832123722348895, 9.378237247467041, 7.819108383996146, 1.7275977092129844, 0.6291834839752742, 0.8535299599170685, 0.6466947900397437, 0.5248620361089706, 1.2561080434492655, 3.1908824699265614, 15.268506595066615, 35.615990025656565, 49.13967193875994, 46.26875965935843, 50.979527132851736, 46.26410436630249, 49.68173565183367, 56.147364480154856, 57.241514682769775, 50.94145795277187, 49.173780645642964, 46.19372606277466, 22.53798120362418, 16.23323965072632, 24.771505696432932, 23.72278455325535, 24.668036597115652, 23.527300459997996, 35.81046315601894, 52.717744077954976, 28.698900256838115, 58.35681520189558, 48.11475706100464, 1.1626458700214113, 0.06254368035921029, 0.08133553128157343, 0.03846690338104963, 0.09493309485593013, 0.08906895773751394, 0.025573445417519127, 0.051812170672097375, 0.07733849861792155, 0.08536948982094016, 0.03403803746082953, 0.0626561271825007, 0.12533011340669223, 0.01605146680958569, 0.01867532610361065, 0.08611346954213721, 0.15391357748636178, 0.15212158007281168, 0.11845829071743147, 0.20046331893120492, 0.17275507003068924, 0.12968079852206366, 0.16745894136173384, 0.1287231141967433, 0.08610344757991177, 0.15726408841354506, 0.1444800001169954, 0.2084726241550275, 0.12174183023827416, 0.10144388941781861, 0.1590315635715212, 0.11733908791627203, 0.10603784290807587, 0.16751796033765587, 2.1018815338611603, 59.501572608947754, 78.37607615334647, 59.246796063014436, 59.13858481815883, 60.132441248212544, 64.64139134543282, 55.737271377018516, 49.03565393175398, 37.233964920043945, 16.67318742615836, 40.73366832733154, 55.52952023914882, 84.0723900113787, 51.06472246987479, 49.70243433543614, 69.74189022609166, 67.44501032148088, 64.63219887869698, 63.92294761112758, 50.061715262276785, 46.24128648212978, 31.637486253465923, 11.45512068271637, 3.3004045358725955, 5.027743424688067, 4.0539208224841525, 7.932928562164307, 7.865516270909991, 6.880992574351175, 6.228652264390673, 5.584924680846078, 3.6151720455714633, 8.47810159410749, 5.164364550794874, 6.027976563998631, 8.58240360873086, 8.987305538994924, 5.840786014284406, 6.548083969524928, 19.48863571030753, 14.573469604764666, 16.334094490323746, 28.52504243169512, 30.828031539916992, 29.84450360706874, 36.747931480407715, 33.75938619886126, 28.747416053499492, 37.28754595347813, 41.81413057872227, 42.0074850491115, 51.381890365055625, 56.199482917785645, 56.31331525530134, 56.41830601011004, 52.179109300885884, 45.527022089277, 44.12462200437273, 51.68879229681832, 54.153099468776155, 53.0713518006461, 56.29090731484549, 50.63942323412214, 51.06311048780169, 47.66440609523228, 47.07405935014997, 56.10780143737793, 53.6827654838562, 53.29420484815325, 45.143099376133506, 52.55210597174508, 51.39472368785313, 52.21537889753069, 43.39621455328805, 43.03299052374703, 44.31509992054531, 47.150215080806184, 51.89561237607683, 51.43353632518223, 51.26090138299124, 46.88055201939174, 51.05699954714094, 50.23433630807059, 45.945925508226665, 46.118706362588064, 50.44772243499756, 52.754434040614534, 50.9515050479344, 30.40167270387922, 10.056686282157898, 5.301846819264548, 13.839548758098058, 21.630150420325144, 25.428532566343033, 22.0115578855787, 24.613831962857926, 37.19473539079939, 38.841743332999094, 44.60342584337507, 26.986528873443604, 26.53493070602417, 29.879317556108745, 17.901125192642212, 20.64112298829215, 17.036545208522252, 10.81292474269867, 5.507884791919163, 3.8301540868622914, 5.445529920714242, 7.721245612416949, 6.333716409546988, 2.255739837884903, 1.504288143345288, 1.9801215188843864, 1.618584924510547, 1.197589446391378, 1.99178689292499, 4.29213069166456, 17.281721081052506, 41.42194645745413, 54.65156670979091, 50.68904032026018, 52.50106797899519, 50.3864289011274, 52.880338873182026, 61.4669748033796, 61.51451437813895, 55.90987852641514, 54.15766096115112, 51.136469568525044, 22.293527943747385, 18.409667321613856, 38.33140509469168, 34.197678565979004, 48.02452775410244, 29.645545414515905, 55.793329443250386, 57.62676797594343, 38.824685505458284, 66.89152376992362, 63.488949230739046, 2.646292869533811, 0.29501367253916605, 0.19053173757025174, 0.19483770722789423, 0.1966546747301306, 0.16125042736530304, 0.25481104265366283, 0.2725584789046219, 0.3310360924473831, 0.09822140447795391, 0.1407801250794104, 0.20563584566116333, 0.158356638359172, 0.1396012654794114, 0.08276761336518185], [0.04995055556563394, 0.059028380417398045, 0.014979026945573943, 0.027647852498505796, 0.038029316147523265, 0.07615757627146584, 0.07254827208817005, 0.04246822099334427, 0.03245625698140689, 0.10208433148052011, 0.03455076226964593, 0.056737578340939114, 0.0852003785382424, 0.020245130439954143, 0.0046846566588750905, 0.09313331464571611, 0.05213804729282856, 0.14865753666630813, 0.07620660042656319, 0.17047558591834136, 11.075583151408605, 67.48299612317766, 50.736770970480784, 36.337094920022146, 38.05463055201939, 39.52185385567801, 48.01743711744036, 42.05276645932879, 37.25636938640049, 16.87904691696167, 15.745816571371895, 59.27904960087368, 55.756702014378135, 73.61605290004185, 51.71599102020264, 42.77471208572388, 58.88385690961565, 55.16973556791033, 50.220373903002056, 36.69742849894932, 28.731468200683594, 27.525573594229563, 5.330998854977744, 0.31663635798863, 2.1926460691860745, 1.9547516916479384, 4.096635741846902, 2.663346354450498, 4.681316665240696, 3.708037759576525, 5.646740632397788, 4.813183052199228, 1.630608347909791, 1.2059078514575958, 1.7317247220448084, 1.8060575276613235, 0.8812935501337051, 1.0603519933564323, 10.899319512503487, 19.869529008865356, 12.60732308455876, 20.169793673924037, 24.506070613861084, 19.820653642926896, 17.420514822006226, 26.125822510038102, 19.831468514033727, 20.981136560440063, 28.52019953727722, 28.875268118722097, 26.635290486471995, 31.599913869585308, 45.14894281114851, 50.77160576411656, 52.31907033920288, 45.08327886036464, 34.5307856287275, 29.71246698924473, 35.613752705710276, 38.136768681662424, 41.208845206669395, 43.98912865774972, 47.12897096361433, 44.91823135103498, 41.56788642065865, 44.47572490147182, 50.92324672426496, 50.91630547387259, 54.5166083744594, 47.33160127912249, 48.313961914607454, 49.222470147269114, 47.98562479019165, 42.91313757215227, 38.74207489831107, 41.62059892926897, 43.63653884615217, 43.91195501599993, 39.07227413994925, 31.974856036049978, 29.854053906032018, 30.735551016671316, 34.57148470197405, 34.684149742126465, 38.39731918062483, 47.531212602342876, 48.4591896874564, 43.44831562042236, 13.288088474954877, 3.480971715279988, 4.918975021157946, 5.6710962397711615, 16.166017566408428, 15.006750583648682, 16.498699051993235, 16.553869485855103, 28.361176116125925, 31.63941785267421, 33.645154339926584, 31.446059908185685, 24.39086948122297, 41.61487013953072, 21.232571022851126, 11.064640607152667, 12.753754632813589, 11.05386221408844, 15.570649010794503, 10.204610824584961, 4.115680754184723, 3.6304087936878204, 4.869057425430842, 2.9488319839750017, 0.3882312205220972, 0.5775255273495401, 1.6787399309022086, 1.600201728088515, 2.0307065759386336, 2.479648143053055, 14.059914350509644, 35.14952271325247, 41.74825470788138, 49.90841020856585, 41.413559981754844, 48.18253673825945, 51.33040768759591, 50.80505439213344, 51.21598475319998, 45.78868430001395, 46.42422907693045, 37.29690170288086, 8.770565169198171, 28.689462866101945, 31.235074383871897, 32.05921758924212, 31.40747308731079, 24.298672097069876, 54.38223716190883, 29.065732138497488, 35.42347976139614, 58.417806489127024, 12.853488206863403, 0.10123472421297006, 0.10738530488950865, 0.031215844077191184, 0.05615243009690728, 0.02334504311771265, 0.0718333540218217, 0.05509047868794628, 0.04820612684956618, 0.08279579970985651, 0.03639057943863528, 0.06713940482586622, 0.03230632109833615, 0.06539704224893025, 0.057931196077593734, 0.03891679923981428, 0.03629384748637676, 0.06349928158202342, 0.025692938826978207, 0.038428593293896744, 0.03745514999276825, 0.037834552848445516, 0.07823497229920966, 0.111091123893857, 0.09350400511175394, 0.0736636615225247, 0.045725450318838866, 0.04508105578965374, 0.06594208907335997, 0.07525008996682507, 0.031513015273958445, 0.13744477262454374, 0.08271820244512387, 0.20265012873070581, 0.04233778281403439, 0.2929896025785378, 16.52790059362139, 79.07941450391496, 54.53645242963518, 43.558559213365825, 41.69865499223982, 45.25241538456508, 36.103489535195486, 33.309160300663535, 37.578866549900596, 24.317741428102764, 23.182596853801183, 59.74637848990304, 64.73177351270402, 68.32005255562919, 56.93158333642142, 45.980628286089214, 61.21498448508126, 60.691541944231304, 55.088945388793945, 42.69602721078055, 33.56536817550659, 31.568959644862584, 8.326879262924194, 0.7380441682679313, 3.078511642558234, 2.4240953411374773, 5.6903392757688245, 4.051149359771183, 6.508406715733664, 6.498655353273664, 7.8478617668151855, 9.139768992151533, 5.0243266480309625, 4.237474858760834, 5.097550238881793, 6.899745328085763, 6.406598235879626, 6.075248198849814, 13.410524419375829, 23.391857487814768, 17.264635460717336, 23.27379890850612, 30.069093704223633, 24.912623609815324, 19.863704681396484, 30.259463923318044, 23.07476602281843, 25.801765475954326, 34.66040774754116, 33.27069159916469, 30.360285758972168, 38.72996766226632, 50.416573660714285, 55.67869806289673, 53.51760332924979, 50.23715727669852, 42.51369605745588, 37.90519911902291, 44.56684357779366, 48.3405214037214, 50.64092404501778, 49.97379275730678, 51.235297271183555, 49.86951419285366, 45.491089480263845, 49.17258208138602, 55.41959626334054, 52.85028444017683, 55.35757316861834, 48.59858097348894, 53.02488572256905, 52.947823251996724, 50.80287265777588, 43.6475830078125, 40.694497857775005, 43.9130528313773, 47.7333322252546, 48.52664279937744, 47.82807438714163, 41.88351876395089, 40.9090165410723, 41.37483072280884, 41.79668712615967, 39.29063170296805, 42.12390559060233, 47.620087010519846, 50.19684730257307, 47.069199085235596, 18.34188069616045, 4.661889501980372, 4.947234213352203, 8.05984001500266, 15.15245257105146, 17.093270301818848, 20.836959702628, 19.255853687013897, 32.20463991165161, 35.49089813232422, 35.82435260500227, 33.19375419616699, 28.750421149390085, 41.56663227081299, 25.90634454999651, 23.181704010282242, 18.400174345288956, 16.72757966177804, 19.047482422419957, 12.710960677691869, 7.69568145275116, 7.3311989307403564, 10.235595447676522, 6.509996116161346, 1.5019874210868562, 1.8623773455619812, 2.582635428224291, 2.2980465505804335, 3.4136810175010135, 2.66231997523989, 14.873845441000801, 37.370319843292236, 46.919475827898296, 51.49525022506714, 45.544941493443076, 51.67164414269583, 53.489477021353586, 53.6170528956822, 55.949111529758994, 48.65225233350481, 50.544413566589355, 41.76241166251046, 14.470172473362513, 24.963467053004674, 35.96116263525826, 23.657850163323538, 25.023254564830236, 21.397335393088206, 50.68489919389997, 37.88889169692993, 36.4387401172093, 68.12810856955392, 14.989387035369873, 0.15240298211574554, 0.0849603128486446, 0.050888470773186, 0.09242155855255467, 0.03655243378930858, 0.06569901747362954, 0.04278561592634235, 0.0150488312356174, 0.13049840607813426, 0.06851244757750205, 0.001797973398684657, 0.07665484744523253, 0.02779541690168636, 0.0678047559091023, 0.04353146840419088, 0.10688057661588703, 0.1715327977601971, 0.09034967901451246, 0.11551240379256861, 0.08618793876043387, 0.16728830337524414, 0.22362268263740198, 0.21621351449617318, 0.1814358127968652, 0.21035117549555643, 0.15635962837508746, 0.17635000284229005, 0.11390217233981405, 0.2333840195621763, 0.09430796054324933, 0.19124284226979527, 0.17579582972185953, 0.2592556912984167, 0.13764305412769318, 0.418207866272756, 26.167027064732142, 95.46139076777867, 62.93387154170445, 55.59820318222046, 49.2974203654698, 57.08414145878383, 64.2118467603411, 50.82004860469273, 45.12200811931065, 20.281317472457886, 21.895929438727244, 66.24404893602643, 67.95502894265312, 80.72454643249512, 64.95221206120083, 51.97006579807827, 65.88989925384521, 66.98229503631592, 58.668580872671946, 47.735670294080464, 35.40701947893415, 36.86403587886265, 9.085124884332929, 1.5639335427965437, 4.743621596268245, 6.369683759553092, 6.392248468739646, 6.800148546695709, 9.83315144266401, 8.96038474355425, 10.086009417261396, 8.207710708890643, 4.478120505809784, 4.097316665308816, 5.84897837468556, 7.942223514829363, 6.901466744286673, 6.120894389493125, 18.16125532558986, 27.97479374068124, 19.11133984157017, 28.418642929622106, 33.86545739855085, 31.461008957454137, 23.930778878075735, 34.92481449672154, 25.23740499360221, 29.24657985142299, 39.30586562837873, 33.16588844571795, 28.02899490083967, 34.3872184753418, 45.335508891514365, 53.627867766789024, 55.46104921613421, 53.96375410897391, 47.164347716740195, 44.89880418777466, 50.0716164452689, 53.66496072496687, 56.10856573922293, 53.21518298557827, 54.22645507540022, 51.51654992784773, 45.885455335889546, 49.04056978225708, 56.9854006086077, 53.77101108006069, 56.83916882106236, 51.72943231037685, 54.70228508540562, 52.34007821764265, 53.42585236685616, 45.83598416192191, 43.40380546024868, 44.47847638811384, 47.97594594955444, 50.511527742658345, 51.7932619367327, 47.54935434886387, 48.10850715637207, 49.83126088551113, 50.471318517412456, 44.82600096293858, 45.963855334690635, 51.63132374627249, 53.84396021706717, 48.72214426313128, 21.497391189847672, 6.809420917715345, 5.827716886997223, 8.87783145904541, 22.94530544962202, 23.82008191517421, 25.135299478258403, 23.364490270614624, 35.33245141165597, 38.42657109669277, 38.95509624481201, 39.461470535823274, 33.45586109161377, 47.46193906239101, 29.170434543064662, 19.931767497743877, 21.254968541009085, 17.026703085218156, 21.005236387252808, 14.075337614331927, 6.791340836456843, 6.310160279273987, 8.068863119397845, 6.620806855814798, 0.8645315638610295, 1.236547670194081, 3.6353020625455037, 3.2857764065265656, 4.077189905302865, 4.0123202204704285, 18.31282159260341, 43.88669484002249, 53.488660608019146, 59.477761132376536, 48.59670148577009, 53.57912962777274, 59.10497638157436, 61.42495904650007, 60.54072434561593, 54.73916264942714, 52.982261998312815, 46.71364934103829, 11.043857676642281, 38.20109510421753, 45.21616663251604, 42.30302667617798, 41.013402802603586, 33.46069703783308, 65.75367287227085, 43.92337090628487, 47.07630014419556, 78.82839693341936, 24.67477982384818, 0.2736725519810404, 0.1642603272838252, 0.19444716961256095, 0.18592950595276697, 0.20443709141441754, 0.17566012271812984, 0.22773068291800364, 0.21254065872303077, 0.14841103846473352, 0.17119450734129973, 0.20528378098138741, 0.1269753708371094, 0.15445469559303351, 0.13479977526835032, 0.19414865491645678], [0.13519034002508434, 0.0901063292154244, 0.042775787346597226, 0.04763352811070425, 0.021285889503945197, 0.028300374180876782, 0.028852231800556183, 0.0266778510662594, 0.05219976683812482, 0.007827093974421067, 0.04456320125609636, 0.027456754984866296, 0.04842329537495971, 0.010894861903839877, 0.03284092187615378, 0.07937703494514738, 0.027220368651407104, 0.117842737319214, 0.037052408925124576, 0.07203206978738308, 1.0653637072869708, 53.26275035313198, 55.2198702948434, 40.542109966278076, 39.95639419555664, 33.43842111315046, 46.746531690870015, 45.468483516148154, 43.745799268995015, 24.039064816066197, 19.590932301112584, 66.28388990674699, 59.721510887145996, 57.984047821589876, 65.56250013623918, 60.112402643476216, 57.44622598375593, 58.30989401681082, 48.05088227135794, 32.76740230832781, 20.541284322738647, 28.956063508987427, 7.9441976717540195, 0.5270941449063165, 1.205404324190957, 2.1232804656028748, 2.246288985013962, 2.1364872540746416, 2.9848629534244537, 6.443009836333139, 4.20635735137122, 1.9526437819004059, 2.768634796142578, 3.775222063064575, 5.693437738077981, 2.848773798772267, 3.0338271260261536, 5.720520079135895, 24.194099971226283, 20.483692441667827, 19.863167933055333, 29.35403721673148, 28.7639353956495, 20.036141599927628, 17.251446042742046, 20.88136911392212, 17.197977917534963, 21.25920867919922, 14.685490199497767, 17.615769624710083, 8.719596658434186, 12.233798350606646, 38.69723122460501, 46.180371625082834, 55.436258043561665, 48.371847357068745, 37.37861599240984, 29.726940086909703, 33.58706739970616, 40.14909553527832, 41.7190375328064, 47.099065916878835, 47.81873600823538, 46.49216161455427, 41.78322499138968, 44.1583867754255, 50.296956947871614, 52.8435412134443, 50.36511877604893, 52.32948221479143, 49.257944175175254, 47.239450795309885, 47.9199469430106, 43.441148553575786, 40.57317883627755, 42.533293451581685, 43.67940923145839, 44.440501008714946, 38.98257289613996, 31.219343662261963, 29.14901324680873, 31.976151875087194, 31.087696143559047, 32.120021275111604, 40.62352895736694, 48.26300730024065, 49.132567405700684, 36.220188004629954, 5.661694892815181, 1.1664592368262154, 0.7661467545798847, 2.218746325799397, 5.606838430677142, 15.973222426005773, 17.385827677590505, 20.973658561706543, 25.36123752593994, 35.64061791556222, 31.539051124027797, 30.951577459062847, 27.592109543936594, 43.30178158623831, 40.97190816061837, 16.74712494441441, 13.865615793636866, 10.454952682767596, 13.462181670325142, 15.33365637915475, 17.05943431173052, 11.405481014932905, 7.588404740606036, 5.157009448323931, 4.999227583408356, 1.3537677973508835, 0.8917690994484084, 0.36215384410960333, 5.485986241272517, 3.6020449442522864, 9.204895326069423, 32.78576987130301, 37.26021868841988, 54.09370974131993, 42.48694201878139, 42.03629922866821, 54.340245723724365, 53.802253655024934, 48.27079275676182, 46.610579763139995, 50.159695284707205, 24.601106337138585, 11.72134438582829, 49.52435895374843, 34.652413845062256, 32.75509010042463, 23.879942383084977, 40.563475676945274, 44.965711866106304, 25.518159117017472, 41.05122184753418, 55.43267624718802, 1.6681332886219025, 0.1089359609676259, 0.11198102257081441, 0.03152901173702308, 0.021080083047438945, 0.13679583530340875, 0.08061603310384921, 0.04674809419416955, 0.01252812537963369, 0.055717621464282274, 0.06520112883299589, 0.043621781415172985, 0.034766600866402896, 0.06877181080303021, 0.08433351612516812, 0.06977028186832156, 0.060948430959667475, 0.04114720491426332, 0.02657301740587822, 0.009039634356408246, 0.03163885637851698, 0.024665370483749678, 0.06806388843272414, 0.040326852684042284, 0.022627712859373008, 0.07258122174867562, 0.060464771198374886, 0.09848011630986418, 0.011765527505693691, 0.0225872772612742, 0.04315844038501382, 0.09861677326261997, 0.026430592905463915, 0.09021520015916654, 0.07237671807940517, 0.14155399426817894, 1.5500388826642717, 65.08852876935686, 65.35090664454869, 46.264330182756694, 45.621482849121094, 39.07848235539028, 42.11732564653669, 32.90191943304879, 38.74750491550991, 27.557964359010967, 25.27828472001212, 64.47160516466413, 68.51462296077183, 62.18592575618199, 68.76537649972099, 61.11292239597866, 61.624754496983115, 61.40055002485003, 54.76559707096645, 38.03728437423706, 24.762479986463273, 30.975854464939662, 9.526021957397461, 1.1339088806084223, 1.5263678899833133, 2.0783486366271973, 4.231277934142521, 3.843705245426723, 5.393838797296796, 8.332037431853157, 9.807524749210902, 5.675496186528887, 5.263418069907597, 6.829950673239572, 9.455983247075762, 7.874557614326477, 6.272591803755079, 7.499819551195417, 25.655538899557932, 28.44090669495719, 23.499856812613352, 34.500856263296946, 31.40066385269165, 18.073556900024414, 19.993788855416433, 23.22519452231271, 20.4490122454507, 28.035484518323624, 18.973659549440654, 22.39771270751953, 13.866640652929034, 16.185705287115915, 41.97070475987026, 47.38172210965838, 59.127961022513254, 51.9432874407087, 43.47931500843593, 39.86889205660139, 44.673703398023335, 49.85961995806013, 48.526601110185894, 49.919593334198, 52.24323075158255, 49.20140668324062, 45.46509974343436, 46.45692035130092, 54.112066881997244, 54.28453506742205, 54.90281704493931, 52.81043304715838, 52.69417231423514, 52.17926910945347, 50.47997597285679, 44.92556517464774, 40.8348445211138, 41.47508628027779, 46.65428393227713, 49.527628081185476, 48.05219200679234, 41.87660183225359, 38.592650413513184, 43.18050077983311, 38.61424888883318, 38.72628511701311, 43.86719472067696, 49.737609590802876, 53.00343663351876, 41.887263842991416, 10.109127811023168, 1.4370320779936654, 1.3598663615328925, 3.3542504693780626, 9.378516043935504, 17.78505379813058, 20.14309695788792, 22.212994847978862, 24.944588797433035, 37.38630764825003, 36.300255571092876, 36.174225670950754, 30.84195225579398, 47.749879360198975, 34.99238920211792, 24.209901911871775, 20.886943306241715, 10.025470631463186, 16.061905758721487, 17.765781232288905, 19.78327407155718, 14.066557696887426, 13.2589225428445, 10.369322214807783, 7.326914497784205, 1.0634694546461105, 1.0894744992256165, 0.7929455222828048, 6.350691727229527, 4.531245563711439, 10.458731634276253, 37.19447830745152, 44.247361932482036, 56.78571285520281, 44.81801748275757, 45.9316017968314, 56.569012437547954, 58.3182943889073, 53.946095262254985, 50.254871709006174, 54.10834959575108, 29.62231411252703, 14.723361355917794, 38.07129233224051, 35.681709562029155, 21.817421742847987, 28.683107001440867, 31.19801616668701, 49.99986934661865, 28.18274811335972, 45.24161440985543, 62.174183300563264, 3.545064938919885, 0.20312014993812355, 0.08592479609485183, 0.023281934271965708, 0.07391534373164177, 0.012063160954442407, 0.019271256269088814, 0.060556787332253795, 0.01662923937796482, 0.10959314248923745, 0.1211060429258006, 0.07436808943748474, 0.060859834642282555, 0.0513879437930882, 0.08609987848571368, 0.07575201589081969, 0.15506705987666333, 0.2640942973749978, 0.10896797424980573, 0.12381271911518914, 0.09278652896838528, 0.11598615694258894, 0.13382561611277716, 0.1565121223351785, 0.14830594696104527, 0.10702536920351641, 0.13975515722164086, 0.15496445181114332, 0.13179215522749083, 0.11511015466281346, 0.12108818388410977, 0.16390267147549561, 0.06879575630383832, 0.24750788882374763, 0.10513139476201364, 0.23852603935769626, 2.5929969293730597, 81.83572319575718, 74.27310235159737, 59.23985481262207, 57.02049943378994, 49.00272989273071, 64.26900959014893, 55.25088357925415, 53.073700291769846, 27.533805472510203, 22.34954605783735, 75.67232363564628, 69.58481924874442, 71.35333728790283, 76.92169312068394, 69.1554205758231, 66.82480716705322, 67.59257616315568, 61.14604445866176, 39.97247232709612, 26.07735882486616, 36.51440947396414, 11.06597900390625, 2.613795493330274, 2.7161365960325514, 3.2349548935890198, 5.236523764474051, 4.728511435644967, 7.612977913447788, 11.055111152785164, 9.35317509514945, 5.923925987311772, 4.929790326527186, 7.104705461433955, 10.561518941606794, 7.708163891519819, 4.603244968823024, 9.82354816368648, 33.89768314361572, 29.675120421818324, 26.131487028939382, 37.256751537323, 38.97672251292637, 27.69163727760315, 24.807033572878154, 27.32249164581299, 25.175368002482823, 31.908570221492223, 20.27049912725176, 23.064168282917567, 12.323047092982701, 14.724011012486049, 39.65131269182478, 48.389047622680664, 60.452725410461426, 53.23534318378994, 50.46908467156546, 46.306665556771414, 49.400868620191304, 56.96732139587402, 51.46072810036795, 52.635849135262625, 56.48772198813302, 51.30149275915963, 46.434786864689414, 47.66118560518537, 54.42654235022408, 57.10739360536848, 56.080974442618235, 52.579579148973735, 54.61639492852347, 52.679859025137766, 53.402489049094065, 45.08374786376953, 44.474696568080354, 44.176691804613384, 48.010075501033235, 51.572149412972585, 53.0487562588283, 47.41587250573294, 47.69248029163906, 52.45189905166626, 45.98990065710885, 43.25718804768154, 47.73538889203753, 51.65766784123012, 54.55224221093314, 43.80599498748779, 11.846081921032496, 2.267787579979215, 1.8759823526654924, 2.8775727791445593, 10.138866969517299, 24.824263368334087, 26.414250918797084, 29.434858662741526, 31.455061299460276, 43.21365410940987, 39.68742595400129, 40.285891669137136, 36.38612835747855, 50.44095836366926, 48.619533266339985, 24.407308919089182, 23.141687597547257, 16.290642193385533, 15.022835663386754, 21.944149936948502, 23.585922411509923, 14.189363632883344, 12.197285567011152, 9.344640101705279, 8.977268866130284, 3.629991033247539, 1.7335574179887772, 1.6040959762675422, 7.96208233492715, 6.657649678843362, 12.520108427320208, 45.44871589115688, 48.27363804408482, 64.36071191515241, 47.42266089575631, 50.44366468702044, 61.09988757542202, 63.216440882001606, 58.03788593837193, 55.8336637360709, 56.90567697797503, 30.47473301206316, 15.461970499583654, 61.53540761130196, 40.12045506068638, 39.593093735831125, 35.335974148341585, 49.55833217075893, 57.992743492126465, 37.44427299499512, 53.21454375130789, 76.20181110927037, 7.083790080887931, 0.397941165204559, 0.30544829262154444, 0.13839354099971907, 0.147218879578369, 0.21276259395693028, 0.19687780418566295, 0.10087376393909965, 0.1272468255566699, 0.14235382420676096, 0.2624119919325624, 0.1591575268123831, 0.25787375973803656, 0.2354256228676864, 0.1757587409977402, 0.20647037588059902], [0.06152935193053313, 0.021516725420951843, 0.09384180020008769, 0.11184179397033793, 0.023522357888785855, 0.058942192899329324, 0.02189896285666951, 0.019133793555998375, 0.015575888400365199, 0.028912495888237442, 0.03305194965962853, 0.03674414707347751, 0.056702223273792436, 0.006603806021822882, 0.027887884261352674, 0.043186606373637915, 0.08908135457230465, 0.01896595791913569, 0.2617556042969227, 0.0017708865988035022, 0.19970977865159512, 17.187239476612636, 49.88489750453404, 51.5801294190543, 35.538375173296245, 45.12541968481881, 35.60221174785069, 52.52356972013201, 38.23989731924874, 45.802146434783936, 12.454352412905012, 47.33513791220528, 73.82298415047782, 54.481436593191965, 58.21870585850307, 65.09223910740444, 63.35303551810128, 62.943703242710654, 57.897869314466206, 40.91143798828125, 36.619285583496094, 37.63237810134888, 14.79969252858843, 0.43047862925699776, 0.704049075288432, 1.4370726815291812, 2.4970507749489377, 2.5831600172179083, 2.2987135776451657, 9.481306825365339, 1.7607275886195046, 2.69141685962677, 7.177892574242183, 10.518422739846365, 10.317193354879107, 7.2122587987354825, 8.308573365211487, 16.50396752357483, 33.00284201758248, 27.312199626650127, 30.678193637302943, 34.57637275968279, 27.978354692459106, 17.264998504093715, 16.327134132385254, 15.763256549835205, 21.25150486401149, 8.418162958962576, 7.467969008854457, 9.557711822646004, 4.153521512235914, 15.413772583007812, 43.72037581035069, 53.768607003348215, 55.46732343946184, 48.77713925497872, 37.283682755061555, 31.419399670192174, 35.123001439230784, 40.69023861203875, 42.738341740199495, 48.13819333485195, 44.20679487500872, 45.39495073046003, 42.1177008492606, 42.4290565763201, 48.843199253082275, 52.243543420519146, 53.298599583762034, 46.79323053359985, 47.79923241479056, 49.3801143510001, 48.339440958840505, 42.109026023319785, 37.35220241546631, 42.6990635735648, 45.818207195826936, 46.045517512730186, 39.46854032788958, 31.234643595559255, 30.603267737797328, 30.125151770455496, 28.475847448621476, 31.59785372870309, 44.60627113069807, 50.45609154020037, 50.82059056418282, 26.47017523220607, 0.41154117829033304, 1.026927575469017, 1.926912865468434, 4.438428052834102, 4.8784414018903455, 13.182309099606105, 23.314560515539988, 24.079854215894425, 29.719512462615967, 33.01427527836391, 34.799889360155376, 26.45384349141802, 34.57837731497628, 39.52567883900234, 42.594555718558176, 20.624629701886857, 5.901015170982905, 14.881024667194911, 14.875031845910208, 12.604102594511849, 20.14809618677412, 18.29986146518162, 16.17394198690142, 8.048882705824715, 8.030326672962733, 3.910100494112287, 0.9021569277559007, 1.512289211153984, 0.8174979590943882, 2.792235872575215, 8.576037321771894, 28.134616204670497, 43.807419368198936, 42.19736542020525, 41.246945653642925, 55.281431334359304, 54.07716260637556, 48.606463704790386, 47.08078520638602, 47.09130130495344, 55.56067943572998, 20.66158890724182, 18.089501278741018, 46.14032220840454, 29.980396475110734, 29.10136250087193, 20.71512825148446, 41.35908957890102, 41.24992643083845, 34.15573576518467, 52.044307300022666, 23.951706852231705, 0.40043041163257187, 0.149850835491504, 0.054614588152617216, 0.041507320412035496, 0.15314436304782117, 0.025952519183712344, 0.04501215734386018, 0.056413353952978335, 0.021838010055944324, 0.04461235772552235, 0.11064363683440856, 0.06645793853593723, 0.05256263379539762, 0.014839660941756197, 0.07790691418839352, 0.036269304874752245, 0.14637816111956323, 0.05212202029568808, 0.07055905847144978, 0.05662631895393133, 0.027661543638844575, 0.03187721555254289, 0.05521218751424125, 0.054001216244484694, 0.020232560578733683, 0.053957274316677024, 0.023328987282833884, 0.027404146468532935, 0.06737345869519881, 0.027768180506037812, 0.058688814352665625, 0.014998880880219596, 0.19847848186535494, 0.0148863984338407, 0.09744373549308095, 0.027088410553655455, 0.19308374848748955, 24.8005040032523, 66.24408367701939, 56.67040055138724, 43.56473616191319, 51.27136537006923, 43.789652824401855, 37.653667381831575, 32.30205018179757, 42.93947124481201, 19.462267296654836, 53.87520279203142, 77.36642646789551, 64.44321482522147, 60.4793370110648, 69.99559674944196, 66.943954876491, 67.62355818067277, 61.37156214032854, 46.74217517035348, 37.84962395259312, 40.618154525756836, 16.996959584099905, 0.7725520708731243, 1.1015685988324029, 2.9261409044265747, 3.5887124368122647, 3.067381714071546, 3.9791234646524702, 14.770767177854266, 4.805742400033133, 5.236166366509028, 11.415881599698748, 11.718828269413539, 13.556513888495308, 9.94694209098816, 9.322943483080183, 11.435349583625793, 35.716978618076865, 32.50324222019741, 34.22892114094326, 39.278170108795166, 26.97740067754473, 18.98284159387861, 19.674932547977992, 18.586059502192906, 24.284850393022808, 11.539533478873116, 8.098660469055176, 12.482308489935738, 6.146338692733219, 14.78792575427464, 44.252788475581575, 54.78512150900704, 57.56587396349226, 52.19791112627302, 45.08550575801304, 38.98970522199358, 43.96883644376482, 51.855114800589426, 50.510096413748606, 52.45269809450422, 50.442288943699424, 50.496905258723665, 44.171032496861045, 46.33458341870989, 52.19970376150948, 56.42564330782209, 55.74386869158064, 50.417240687779014, 52.36134317943028, 53.707824162074495, 51.220858914511545, 45.3533935546875, 38.914779322487966, 45.18481636047363, 46.7797406060355, 49.431916645595, 48.218632629939485, 41.6172707421439, 40.10043382644653, 41.06395442145211, 35.4972939491272, 38.638331345149446, 47.03239100319998, 52.8191808291844, 52.26514884403774, 34.09370919636318, 2.1953419702393666, 1.1729092278650828, 1.5043261413063322, 4.830321218286242, 7.436009900910514, 16.36140959603446, 20.7861944266728, 22.736142090388707, 27.26228724207197, 30.8777528490339, 36.3153783253261, 32.183659826006206, 37.06760767527989, 45.404188360486714, 43.61657319750105, 18.957873242241995, 12.901026913097926, 12.245237691061837, 15.566092729568481, 13.726208874157496, 21.99180589403425, 21.428065538406372, 20.146630116871425, 14.27244758605957, 15.82935128893171, 6.895004485334669, 1.9149322169167655, 0.8316656074353627, 1.7814020620925086, 4.251345200198037, 9.026771306991577, 34.21810279573713, 49.00095810209002, 47.43182209559849, 45.540678773607524, 58.30740656171526, 55.92389651707241, 53.372809818812776, 50.231282574789866, 53.180435044424875, 54.15778602872576, 25.692918470927648, 14.26757081917354, 44.35127224240984, 31.09643350328718, 24.105725833347865, 22.330497571400233, 34.63545329230172, 47.856099946158274, 36.34417860848563, 57.84039381572178, 34.91380855015346, 0.3618450563933168, 0.06699341123125382, 0.06484229237373386, 0.027135877470885004, 0.062055040150880814, 0.030540369251476865, 0.10157270250575882, 0.06813577243259974, 0.04794313685436334, 0.10324972216039896, 0.028797107615641186, 0.04131441290623375, 0.08227024719651256, 0.09116966822849852, 0.025229068539504493, 0.062370450368949344, 0.3326840368764741, 0.14138419766511234, 0.22776268262948307, 0.18080877858613217, 0.09789792647851364, 0.16950657005820954, 0.09359834183539663, 0.15027909965387412, 0.06349164127771344, 0.14683641652975762, 0.1835440889533077, 0.27573201432824135, 0.14578562362917832, 0.0861238646986229, 0.1487222146242857, 0.11774266697466373, 0.2804279923439026, 0.09620479840253081, 0.3970622995070049, 0.11260166498167173, 0.24500632019979612, 34.73578527995518, 88.97763756343296, 68.53214631761823, 58.46289334978376, 60.246336119515554, 56.72745221001761, 65.0180184500558, 47.234948362622944, 54.224540846688406, 15.68484091758728, 56.201018469674246, 84.08809988839286, 65.74678025926862, 69.54923752376011, 76.96637003762382, 73.28439453669957, 73.22694683074951, 67.32180486406598, 49.15239061628069, 44.04146943773542, 47.973753792899, 20.126535926546367, 1.3150707823889596, 1.5913275757006236, 3.944614802088056, 4.173032488141741, 5.317350421633039, 6.3363271951675415, 14.781264168875557, 5.06261773620333, 6.147544639451163, 10.645232575280325, 14.670092991420201, 15.216926642826625, 11.032010998044695, 11.658492718424116, 21.97104467664446, 41.98195389338902, 38.014091287340435, 38.760477202279226, 44.786698477608816, 38.583947794778005, 25.944398096629552, 25.20349257332938, 22.08470504624503, 29.42958845411028, 13.291044064930507, 11.401212215423584, 13.606855324336461, 7.992843747138977, 18.678298575537546, 47.6267329624721, 58.30616978236607, 57.35760171072823, 53.61556945528303, 48.26675932747977, 43.95812232153756, 51.77188580376761, 58.43793542044503, 55.272297927311485, 57.090255873543875, 52.941031387874055, 50.97282212121146, 44.755716460091726, 46.01344462803432, 53.26260791506086, 56.61493655613491, 59.590037073407856, 50.844818932669504, 52.16348280225481, 56.09361668995449, 53.13078669139317, 47.400364126477925, 40.334004470280235, 45.789163725716726, 49.26924542018345, 53.09821006229946, 52.58058316367013, 48.64489071709769, 49.08424963269915, 49.23292718614851, 40.733334813799175, 43.893875803266255, 52.3220545904977, 55.12204660688128, 59.28915922982352, 35.10937254769461, 3.590299014534269, 1.6896027880055564, 3.2804649429661885, 6.614605588572366, 7.90975284576416, 21.844578777040752, 30.749999795641216, 28.08522319793701, 34.432750020708355, 37.96528366633824, 43.3064820425851, 36.75385134560721, 42.921867983681814, 47.28973838261196, 49.67466933386666, 27.073086057390483, 12.091761537960597, 23.73641344479152, 22.801027842930385, 19.915854385920934, 26.022568804877146, 23.0621463571276, 21.05986312457493, 12.649323207991463, 13.92869588306972, 7.988548023360116, 3.8522046293531145, 2.812233005251203, 1.8521276669842857, 4.439990528992244, 12.283955659185137, 40.82084390095302, 55.84568759373256, 52.79380253383091, 45.535207067217144, 62.32267325265067, 63.230253900800435, 57.182798930576865, 59.0403789792742, 55.871100630079, 62.5766716003418, 24.122465780803136, 23.924475124904088, 58.33062744140625, 36.38818155016218, 36.65972062519619, 29.01151360784258, 49.7229072025844, 57.967900208064485, 44.85940442766462, 69.89861379350934, 46.78641782488142, 0.8973017654248646, 0.34991646504827906, 0.16048639693430491, 0.09840380826166698, 0.27143995463848114, 0.09640958705650908, 0.29062384952391895, 0.2050992873098169, 0.1363366435148886, 0.18018144581999096, 0.2561131242130484, 0.22980385167258127, 0.1595091572297471, 0.2748079853398459, 0.22711166899119103, 0.2159504328987428], [0.03778739805732455, 0.03315049669306193, 0.06254465066428695, 0.04267678569470133, 0.01996985387190112, 0.01011815813503095, 0.02482379144722862, 0.03788598580285907, 0.019768865014027272, 0.030286261279668127, 0.058424090700490136, 0.1049583140494568, 0.03404736053198576, 0.034431998285331895, 0.0460144553466567, 0.08274476030575377, 0.06633210421672889, 0.06121436918952635, 0.02404546258705003, 0.05217478657141328, 0.14287670329213142, 2.040528506040573, 39.97169065475464, 50.638002327510286, 33.35400744846889, 46.32203497205462, 29.1419677734375, 49.18395280838013, 46.402898107256206, 45.514164447784424, 26.405496188572474, 20.933570929936, 75.80031640189034, 52.83649574007307, 61.43693774087088, 61.105383600507466, 63.096549715314595, 59.860127449035645, 59.98618861607143, 55.91471447263445, 55.204785755702424, 46.221327781677246, 13.348543882369995, 0.26662004898701397, 0.49196437852723257, 0.5062459664685386, 2.885365835257939, 2.5680639701230183, 4.895976918084281, 2.4685718459742407, 5.237870846475873, 7.486970594951084, 12.322866439819336, 14.54444524220058, 13.099936468260628, 12.132957407406398, 14.409564205578395, 20.067611728395732, 29.844093663351877, 35.405633313315256, 38.248158727373394, 38.89436551502773, 21.992964506149292, 21.37778663635254, 13.979497637067523, 19.975351810455322, 8.898471082959857, 1.8155099004507065, 5.063951356070382, 2.4117961611066545, 8.177685805729457, 32.37261608668736, 48.306520393916536, 54.75143664223807, 50.92428200585501, 48.56642471040998, 38.37845482145037, 29.887926374162944, 35.52900205339704, 38.56192895344326, 41.217599936894004, 44.62342275891985, 46.067230633326936, 46.774348803928916, 43.20287050519671, 46.53207901545933, 53.39063542229788, 51.351801191057476, 53.2734123638698, 44.88926778520857, 46.881041867392405, 51.76325961521694, 46.47113636561802, 41.436141627175466, 39.85886580603463, 44.73446192060198, 48.808076109204976, 47.69901507241385, 40.319249970572336, 32.13553660256522, 30.045772075653076, 29.11899355479649, 26.578890221459524, 33.65583372116089, 45.786752700805664, 48.48376546587263, 41.18129212515694, 9.173856854438782, 2.5148711672851016, 1.6249805241823196, 2.5666610854012624, 5.742495494229453, 6.484507952417646, 7.050212042672293, 18.996863058635167, 25.488719599587576, 29.548378331320627, 34.82618829182216, 31.232343741825648, 29.119580677577428, 33.00949839183262, 45.87227807726179, 29.99663094111851, 21.28707790374756, 12.047131521361214, 7.099019663674491, 18.118410996028356, 18.829934324537003, 24.92096492222377, 25.33497507231576, 21.300477504730225, 11.126562084470477, 6.0616744586399625, 4.845741442271641, 2.5860129041331152, 2.033468267747334, 2.0552884340286255, 0.5831862464547157, 4.2982207877295355, 26.97863745689392, 49.56757327488491, 33.71304866245815, 33.32046849387032, 49.51952648162842, 53.161904198782786, 51.29808814185006, 50.74378865105765, 46.342417512621196, 59.7167444229126, 16.68856726373945, 25.554720538003103, 35.335699694497244, 28.68276653970991, 26.547025782721384, 28.78348067828587, 53.76087018421718, 41.985629490443635, 36.35448626109532, 50.300437995365684, 8.488095709255763, 0.20948830965374196, 0.07671825654272522, 0.05244286897193108, 0.011666087350541992, 0.015806668338232806, 0.03446229487391455, 0.03116537124982902, 0.057865235688430924, 0.044765041675418615, 0.042617614048400095, 0.09621507820806333, 0.02636770627993558, 0.03928802914119192, 0.04212253115006855, 0.009939324293684746, 0.0552208490137543, 0.03176088411627071, 0.028308140014165213, 0.038863978681287596, 0.08698592308376517, 0.020912990406421677, 0.09329641410814864, 0.04445959574409893, 0.02531172089012606, 0.03023656876757741, 0.028892719985118935, 0.07342532609722444, 0.09559324836092335, 0.035527459146188836, 0.03546216032866921, 0.02748110760668559, 0.07289400603622198, 0.03402964058997376, 0.0272388960500913, 0.06624664951648031, 0.08268413320183754, 0.2292124405503273, 4.22503410918372, 56.28384099687849, 61.2426244190761, 43.03525563648769, 50.27853379930769, 39.48815509251186, 41.21212823050362, 31.088366644723074, 42.2063946042742, 27.521606172834122, 32.0018185206822, 76.66458198002407, 60.9599369594029, 62.30625465938023, 67.02321297781808, 65.04933398110526, 66.91481413160051, 63.37805598122733, 53.27274186270577, 52.82761941637312, 50.797981125967844, 13.59073724065508, 0.020761675400925533, 0.5212044066616467, 1.0940583561147963, 3.4207091203757694, 4.781260856560298, 7.122826797621591, 6.732272028923035, 7.679049202374049, 12.53310763835907, 12.159935525485448, 16.415899106434413, 16.20009674344744, 14.652260439736501, 11.570348739624023, 18.068526404244558, 36.38208450589861, 37.66632005146572, 43.92057425635201, 38.45248440333775, 24.88304165431431, 23.778314556394303, 17.847512892314366, 20.747975860323223, 13.924944724355425, 2.53949037194252, 3.6362780673163275, 3.774018721921103, 9.224104489598956, 32.18483059746878, 49.16024555478777, 57.50789124625069, 52.06414788109915, 53.979599475860596, 45.306552273886545, 37.862328733716694, 46.40011535372053, 49.01043544496809, 47.18608168193272, 53.61125462395804, 51.48571729660034, 49.92507546288626, 46.49877977371216, 47.9421568598066, 54.31735140936715, 55.514008385794504, 57.028215408325195, 47.718014921460835, 50.88826254435948, 52.86856515066964, 49.397884368896484, 43.55375105994088, 39.71674387795584, 44.72293138504028, 48.96440710340227, 49.70267057418823, 46.852623735155376, 42.325448513031006, 42.646358013153076, 38.45325912748064, 33.510762282780235, 40.31504283632551, 50.84881067276001, 53.205868925367085, 47.5592485836574, 16.42335626057216, 2.625286511012486, 1.1952242361647742, 2.251911163330078, 4.726618920053754, 8.998950719833374, 13.589234692709786, 20.023370810917445, 26.07020218031747, 31.685314178466797, 34.73614658628191, 31.629061562674387, 30.855042661939347, 37.666872433253694, 46.01922900336129, 36.08444104875837, 16.205726521355764, 14.91329036440168, 9.097799267087664, 14.874420404434204, 19.949415922164917, 25.023192031042917, 25.82033106258937, 21.93104042325701, 15.390303305217198, 10.963570373398916, 11.052621960639954, 6.772775249821799, 2.2352237616266524, 1.3646752749170576, 1.7903802203280585, 3.6787141902106146, 31.123052052089147, 55.42078787939889, 37.283762659345356, 38.42030382156372, 53.01069402694702, 55.62483562741961, 55.875307764325825, 54.773736885615754, 48.870707171303884, 60.60196576799665, 21.370385067803518, 20.254348039627075, 42.81704051154, 27.583974940436228, 25.312096391405376, 24.374063525881084, 52.84940896715437, 44.8498888696943, 40.34782791137695, 61.71562303815569, 16.5739688873291, 0.3969441529895578, 0.06487894005009107, 0.12352320179343224, 0.012633836046526474, 0.027358246967196465, 0.07740933767386846, 0.034885371636067114, 0.0852609242179564, 0.0259096188071583, 0.1336147409996816, 0.06062429478125913, 0.0806748213778649, 0.042496855171131234, 0.07439728001398699, 0.042747163346835544, 0.058886593739901266, 0.18909436969884805, 0.10990545180227075, 0.13424937480262347, 0.14774848973112448, 0.09677790943533182, 0.16244259982236794, 0.17643302838717187, 0.06906710245779582, 0.06350042152085475, 0.09761462453752756, 0.13225492968090943, 0.2700422267828669, 0.10666976257094316, 0.17964362539350986, 0.13984154830021517, 0.24537614892636025, 0.22586222817855223, 0.10923417032297168, 0.12101712769695691, 0.115897268855146, 0.21016110426613263, 4.224908173084259, 75.29740578787667, 75.59516389029366, 61.305047035217285, 63.30318914140974, 46.62001889092581, 64.96691444941929, 57.413103921072825, 53.54880768912179, 31.96505560193743, 29.019081933157786, 84.58114406040737, 63.96182973044259, 71.90920012337821, 73.1954367501395, 74.177168573652, 72.5325369153704, 71.21915367671421, 60.602945463997976, 62.28953034537179, 57.135516439165386, 18.15950264249529, 0.35558662936091423, 1.9406935317175729, 1.3679641612938471, 5.876084165913718, 7.323450820786612, 6.650635038103376, 8.758431008883885, 7.865402494158063, 11.888157606124878, 14.814123937061854, 19.847834995814733, 17.339361599513463, 19.070908273969376, 19.51042526108878, 28.44764644759042, 39.245822770254954, 45.18340587615967, 45.7354610988072, 49.05403539112636, 30.189964566911968, 29.81947272164481, 22.337614263807023, 27.014405046190532, 15.966593844549996, 5.60915869474411, 7.381933808326721, 4.613691585404532, 14.243206960814339, 37.306448527744834, 52.01397493907383, 57.987476757594514, 54.170654092516216, 56.05681208201817, 48.206052916390554, 41.756554331098286, 49.42504140308925, 55.41930096490042, 53.714883531842915, 55.65975727353777, 54.796943868909565, 51.631351539066856, 47.878448826926096, 49.00192042759487, 55.39508996691023, 57.09949697766985, 59.22873074667794, 47.332316943577354, 53.03975139345442, 55.56320858001709, 51.20018802370344, 43.86262280600411, 41.757957867213655, 45.53313650403704, 52.067305837358745, 52.00322607585362, 51.31363821029663, 48.351138251168386, 51.16227170399257, 48.79012196404593, 38.59294918605259, 47.70759957177298, 54.9693877356393, 53.33623450142996, 45.71992145265852, 14.991546188082014, 3.9032261201313565, 2.8469672671386173, 3.934797866003854, 6.853642727647509, 9.175764134952, 14.25498936857496, 27.079626049314225, 33.36537817546299, 36.020128522600444, 39.965280941554475, 40.33732223510742, 39.36887884140015, 42.04350798470633, 50.81941284452166, 38.98730114528111, 28.632581438337052, 19.93549346923828, 13.425066999026708, 26.489340100969585, 24.360465901238577, 33.26556035450527, 32.36173868179321, 27.88580642427717, 15.055023193359375, 9.5209766966956, 8.742787139756338, 5.516048056738717, 5.159622405256544, 3.7825667432376315, 2.2447267259870256, 6.368397908551352, 35.08192368916103, 64.47660091945103, 38.32160466057913, 39.3709841455732, 55.864982741219656, 63.88231454576765, 57.84141867501395, 61.90649005344936, 53.5763190814427, 71.46369552612305, 19.134628466197423, 34.68277399880545, 44.839185169764924, 35.065668378557476, 33.7774932043893, 36.36636768068586, 67.93250983101981, 56.101040840148926, 48.09286676134382, 73.34980487823486, 23.284478289740427, 0.5441754226173673, 0.28165315517357414, 0.23587988849197114, 0.1694815456867218, 0.07594073005020618, 0.2212222564433302, 0.12821711706263678, 0.24080971681645938, 0.10030636617115565, 0.37859591469168663, 0.29612817987799644, 0.20169414074293204, 0.15768965200654098, 0.16787003858813218, 0.18574798426457814, 0.18419082782098226], [0.035335484626037736, 0.07545074634253979, 0.060407950675913265, 0.04422147745000465, 0.07838891153889042, 0.07542700440223728, 0.08576751846287932, 0.04580647757809077, 0.04499328728499157, 0.03964634991383978, 0.043460670060345104, 0.036659510007926395, 0.04031553811260632, 0.038101040691669495, 0.037258150920804055, 0.1191224136522838, 0.06653628218919039, 0.03192343057266303, 0.0946331484509366, 0.10955046942191464, 0.0808970280257719, 0.15186953145478452, 2.6535378864833286, 36.95549501691546, 44.16905920846121, 46.58502776282174, 81.78978170667375, 52.648977756500244, 48.887351581028526, 43.06903082983834, 41.68529708044869, 12.573803237506322, 53.52463143212454, 74.91135692596436, 67.20130920410156, 70.89347076416016, 64.11341163090297, 61.844699723379954, 62.13229955945696, 67.11284473964146, 54.74627065658569, 44.978354113442556, 15.253019060407366, 0.14796943430389675, 0.15695630492908613, 0.850597005869661, 1.2742861594472612, 4.464588020529066, 4.058862294469561, 2.3790384445871626, 9.096352304731097, 12.980006217956543, 19.038908345358713, 15.72020377431597, 17.74743972505842, 16.348376512527466, 14.450502123151507, 17.617982625961304, 33.88076775414603, 39.635918957846506, 44.79099941253662, 32.525716168539866, 24.798971925462993, 22.41129990986415, 13.667968205043248, 14.425699659756251, 4.505605408123561, 2.7395161986351013, 1.8168732672929764, 1.1561586409807205, 13.635197026388985, 35.06876032693045, 49.159425667354036, 53.86471101215908, 49.9773884500776, 47.378470352717805, 39.86936453410557, 32.53963688441685, 33.2463937486921, 37.660219533102854, 39.22013875416347, 46.198523793901714, 42.46047633034842, 43.22368383407593, 45.006032262529644, 48.76268352781023, 52.975126198359895, 52.850753443581716, 54.13496814455305, 41.98257923126221, 49.046114444732666, 51.236506257738384, 45.760926246643066, 39.633174419403076, 40.573571409497944, 49.808297089168, 48.03350135258266, 47.886689390454976, 38.37633562088013, 31.87326295035226, 29.27976097379412, 28.644756419318064, 24.781994002205984, 36.953504358019146, 46.98271485737392, 49.78524991444179, 34.21602528435843, 10.602769528116498, 5.616515100002289, 5.011528066226414, 2.562475012881415, 7.697767649378095, 9.676487803459167, 7.002018468720572, 11.874719790049962, 19.84811466080802, 27.01259330340794, 30.38402427945818, 29.585860388619558, 26.013352019446238, 38.87615776062012, 41.61118412017822, 26.66630377088274, 11.400597299848284, 17.637673820768082, 10.029093248503548, 21.622641154697963, 18.36838459968567, 22.305424996784755, 26.29638167790004, 25.032440083367483, 18.46567153930664, 13.308206983975001, 7.983616539410182, 6.484007682119097, 1.942663997411728, 5.20638074193682, 3.6318883257252828, 1.5640840147222792, 24.65737111227853, 52.9835022517613, 37.474462917872835, 53.08431713921683, 61.37702342442104, 52.01124082292829, 47.374544620513916, 50.60259778159005, 58.67688396998814, 46.070075920649934, 12.531431385449, 29.896389280046733, 28.082152094159806, 28.48569652012416, 25.42868195261274, 40.14060831069946, 55.342134271349224, 52.43130111694336, 38.760126318250386, 50.63514314379011, 7.263769268989563, 0.3941406634237085, 0.07552299675132547, 0.10602062168930258, 0.04386654595977493, 0.050412278289773634, 0.07373594585806131, 0.033400981287871084, 0.10604154092392751, 0.04223609755613974, 0.04151219568614449, 0.009153960721700318, 0.09497289093477385, 0.03841198275664023, 0.005564090205423001, 0.04061333695426583, 0.054504882610802136, 0.0870521209601845, 0.007818456223633672, 0.13384604001683847, 0.09360516111233405, 0.01094074104912579, 0.020741000438907316, 0.05569585406088403, 0.056066218830112896, 0.07721861505082675, 0.013333158833639962, 0.04958687097366367, 0.026964416760685186, 0.04970796572576676, 0.028368127598826374, 0.0689956255789314, 0.06849659021411623, 0.09605507965066604, 0.06594920690570559, 0.11785040476492473, 0.08714470706347908, 0.10800093292657818, 0.03140706542347159, 13.048130699566432, 62.71069540296282, 52.415733678000315, 53.96820443017142, 69.11766406467983, 43.305616991860525, 29.062930277415685, 37.81298957552229, 38.196999141148154, 20.409141744886124, 61.31900596618652, 71.64141654968262, 73.82465866633824, 77.47994613647461, 70.56965691702706, 67.95095729827881, 68.3584760938372, 67.79271207536969, 55.1928174836295, 52.52750587463379, 16.603823559624807, 0.22510722226330213, 0.9699017554521561, 2.034723720380238, 1.4791427212102073, 6.550954878330231, 8.368311371122088, 5.012216806411743, 12.317547593797956, 15.10086567061288, 17.818161964416504, 18.63068778174264, 20.34581412587847, 16.46610505240304, 10.90088893686022, 19.74685161454337, 37.446235861097065, 44.47255999701363, 46.75379603249686, 32.102365902491975, 26.961041143962316, 28.682002237864904, 14.643321582249232, 18.495983055659703, 5.603721295084272, 2.1477287880011966, 2.764438735587256, 1.7624966651201248, 13.106381790978567, 34.15826838357108, 50.74038750784737, 56.31238419669015, 51.03221532276699, 53.55489083698818, 44.83923033305577, 40.55276502881731, 44.239437511989046, 48.187744413103374, 48.999961035592214, 52.23160988943917, 49.57243701389858, 48.77415500368391, 47.70334727423531, 50.69773599079677, 56.66745798928397, 54.730758803231375, 56.21783658436367, 47.42294577189854, 51.92280762536185, 52.288262026650564, 50.00898538316999, 41.59952504294259, 42.89761529650007, 49.07576935631888, 50.76916694641113, 52.55462121963501, 47.95159598759243, 40.87282337461199, 41.97746188299996, 35.36831453868321, 31.869615146092006, 42.403282233646934, 52.224814551217214, 54.19881861550467, 40.43055663790022, 11.775615896497454, 5.975784736020224, 5.172453556741987, 3.873877363545554, 7.641362173216684, 10.402940205165319, 12.014941385814122, 17.929699659347534, 22.830066101891653, 29.4960549218314, 32.888068199157715, 31.13382523400443, 27.381883110318864, 40.51280941282, 41.11093814032418, 30.520632811955043, 9.608836667878286, 16.44523092678615, 12.90008977481297, 12.698602437973022, 17.215546437672206, 22.002914326531545, 26.015842948641094, 23.699516773223877, 20.911821331296647, 17.48852378981454, 13.16554570198059, 11.449426633971077, 5.227805946554456, 1.3505403591053826, 3.266076526471547, 1.6178537351744515, 25.568363325936453, 57.383372579302105, 41.016546862465994, 51.33952372414725, 61.298967361450195, 55.846698556627544, 55.206800733293804, 55.03016710281372, 59.16441127232143, 51.42232193265642, 16.99953736577715, 26.41543732370649, 33.41552332469395, 27.27293709346226, 24.537533794130596, 33.772702421460835, 61.75254576546805, 54.77654048374721, 42.542089870997835, 63.764598165239605, 11.914583342415945, 0.47088028703417095, 0.07841278240084648, 0.12256515105920178, 0.003154501668177545, 0.03668331980173077, 0.11910578954432692, 0.02512751898861357, 0.1547342791621174, 0.040289309341460466, 0.041630963063133616, 0.0035859409503505696, 0.03389850691226976, 0.05477070209703275, 0.03110668814874121, 0.03523891891485878, 0.07309530023485422, 0.16762035127196992, 0.2607058291988713, 0.11380155916724886, 0.19966955509568962, 0.21207920062754834, 0.13921767606266908, 0.25159782650215284, 0.09200625440904073, 0.20105922195528234, 0.06242290112589087, 0.1521419496940715, 0.07194476947188377, 0.09125230700841971, 0.15612134044723852, 0.16597736014851502, 0.24293844401836395, 0.21989661614809716, 0.21655891596206597, 0.13141065569860594, 0.3128569450761591, 0.2170829621276685, 0.2662002800830773, 21.717607395989553, 90.29584285191127, 68.71029812949044, 70.6542442866734, 91.2000675201416, 78.09056077684674, 61.69321509769985, 50.6531355040414, 50.958251748766216, 15.778558220182147, 65.82548250470842, 80.41225269862584, 73.6406147820609, 79.81034415108817, 75.68661608014787, 72.95234707423619, 72.50710650852749, 75.2046125956944, 62.78460339137486, 57.41308307647705, 18.391900777816772, 0.26159717994076864, 0.9788108659642083, 2.753104269504547, 5.152191306863513, 6.8785507168088635, 7.820324318749564, 6.103804860796247, 14.148681930133275, 15.758361543927874, 24.7057774748121, 22.27371515546526, 21.89257866995675, 21.817616292408534, 21.43528471674238, 27.801787069865636, 40.33776344571795, 47.57801219395229, 54.55141190120152, 41.10052973883492, 33.22337784085955, 31.767507893698557, 20.69062716620309, 23.637797662190028, 9.201451625142779, 5.745630868843623, 3.626198185341699, 3.26206220473562, 17.959505694253103, 36.92488125392369, 50.580558095659526, 56.10754435403006, 51.3777631350926, 53.85269062859671, 46.2302006312779, 45.05415201187134, 48.61053534916469, 53.47994409288679, 56.52658673695156, 58.1252178464617, 50.38046039853777, 49.762432030269075, 50.30598613194057, 52.28255755560738, 58.66765676225935, 57.82627855028425, 57.20586347579956, 48.86020844323294, 53.54116814477103, 56.639286518096924, 50.82823705673218, 42.414013726370676, 44.34538017000471, 52.93199872970581, 52.675492082323345, 55.44029842104231, 52.480852195194785, 47.48878342764718, 49.772242886679514, 43.19270529065813, 39.942678451538086, 51.29707717895508, 55.96582194737026, 54.99562413351876, 41.22362402507237, 13.775147642408099, 7.412129810878208, 6.966568325247083, 5.104179688862391, 10.321489078657967, 14.702817269733973, 10.988928692681448, 21.219082832336426, 25.818291766302927, 30.427763189588273, 36.52547100612095, 36.721090589250835, 33.826210498809814, 46.26382991245815, 47.6208130972726, 33.72900867462158, 19.48199323245457, 27.634627308164323, 16.82962785448347, 31.726280757359095, 25.385851519448416, 29.342781135014125, 33.97859839030674, 31.300519466400146, 24.105411427361624, 20.037536450794764, 11.928253054618835, 10.065441012382507, 3.3514518652643477, 8.534672089985438, 6.233638899666922, 3.500923901796341, 30.594641549246653, 62.48840863364083, 44.06243215288435, 56.854937757764546, 68.42768710000175, 58.68021215711321, 55.63535520008632, 58.93081283569336, 65.17844540732247, 56.693138531276155, 15.843252897262573, 38.708098207201274, 35.01481451307024, 36.39035633632115, 32.9196686063494, 51.70233086177281, 67.52640846797398, 64.30452183314732, 48.61466605322701, 77.7092992237636, 17.01716841970171, 0.728152973311288, 0.17176544027669088, 0.274620601109096, 0.1190441514232329, 0.1882589573838881, 0.4524198461856161, 0.09789981280586549, 0.31282415826405796, 0.2038551526410239, 0.15953017824462482, 0.14623585875545228, 0.1706617759274585, 0.1368106680789164, 0.1160799576235669, 0.12733380017536028, 0.19260582913245472], [0.06229229670550142, 0.047379820474556515, 0.06262415461242199, 0.04733493199039783, 0.02847220129998667, 0.01409345308119165, 0.017806294074814235, 0.12048287636467389, 0.01370721059252641, 0.023770526982843876, 0.019418220168777874, 0.05089136811771563, 0.02036539907567203, 0.152536897787026, 0.04790848407096096, 0.03923417042408671, 0.045056370685675314, 0.041150078510067294, 0.0833029503534947, 0.06193498016468116, 0.0823945819533297, 0.19079548413200037, 3.3116024264267514, 2.0317807240145545, 40.630150590624126, 28.339462995529175, 104.03873348236084, 103.0412153516497, 49.10506296157837, 44.61158997671944, 49.19660895211356, 18.50177264213562, 31.03328480039324, 77.91985048566545, 55.18051222392491, 51.26346179417202, 54.82614367348807, 69.60620580400739, 55.488831588200156, 57.82065398352486, 41.079309940338135, 53.01044041769845, 12.010523200035095, 0.155372468488557, 0.4307497718504497, 1.2951201157910484, 2.8732288522379736, 6.368410502161298, 4.533888919012887, 8.928670559610639, 17.790317058563232, 17.405098506382533, 20.608966725213186, 21.531284502574376, 22.267902987343923, 18.691310814448766, 15.597757407597133, 19.389597824641637, 30.788499764033727, 39.20453657422747, 43.19949715478079, 28.659187827791484, 30.77924476351057, 17.594370910099574, 19.43530133792332, 9.67566009930202, 3.271052522318704, 4.174538944448743, 2.0415257896695818, 0.6284415466444833, 12.34412966455732, 31.4728730065482, 46.18330029078892, 50.204073429107666, 51.872547830854145, 48.24533108302525, 42.09005396706717, 34.14428513390677, 31.993074212755474, 36.39732885360718, 40.22910404205322, 43.557982512882774, 43.83331877844674, 43.4598947933742, 49.59838506153652, 55.19333165032523, 51.2667031288147, 54.815540722438264, 47.4936853817531, 48.63432250704084, 50.784338338034495, 51.64156886509487, 44.29092018944876, 39.34249305725098, 45.62580810274397, 47.920457635607036, 49.26252998624529, 43.696574756077354, 34.54432766778128, 30.151179722377233, 30.23486382620675, 25.746876444135392, 27.071672098977224, 39.072510378701345, 48.45311001368931, 48.83132825578962, 33.415974957602366, 20.540047543389456, 13.516803196498326, 7.509379403931754, 1.4626031858580453, 6.044117663587842, 13.598533987998962, 10.464295404297964, 7.600980980055673, 16.370695863451274, 23.00166228839329, 23.10674684388297, 24.535998242241995, 25.251223223549978, 31.684105191911968, 35.76623092378889, 20.73187688418797, 10.094461900847298, 16.368750367845806, 12.433331506592886, 13.089345676558358, 23.130198751177105, 25.02131428037371, 25.826916217803955, 22.40068827356611, 21.73687127658299, 15.835740157536097, 14.210935183933803, 9.3872230052948, 6.270105217184339, 3.106827071734837, 6.5928486074720105, 0.037640291665281565, 15.503449508122035, 52.4789205959865, 44.969846044267925, 53.733532496861045, 52.88430282047817, 44.29581866945539, 43.15113074438912, 56.357943534851074, 57.51951905659267, 30.56942653656006, 13.338277918951851, 37.14927332741873, 20.8205497946058, 30.982184273856028, 31.814015660967144, 59.789846420288086, 47.09981632232666, 70.09360109056745, 56.986574854169575, 29.373787471226283, 3.6548766578946794, 0.34991749642150743, 0.004075707102726612, 0.06507108081132174, 0.025645256474880234, 0.0700039489726935, 0.03174393091882978, 0.02985220242823873, 0.064568713839565, 0.12176461544420038, 0.13305079697498254, 0.02174018057329314, 0.07259480601974896, 0.05375216675123998, 0.0431083475372621, 0.03296894447079726, 0.029998006033045903, 0.061078411127839766, 0.06062233381505523, 0.04942300815933517, 0.08053488710096904, 0.014644515966730458, 0.17086894623935223, 0.03455290983297995, 0.07767981530300208, 0.03906822789992605, 0.07916748297533818, 0.012295213993638754, 0.06918025495750563, 0.036614346717085154, 0.11017305244292531, 0.051350335989679606, 0.018169924383983016, 0.01323820379496153, 0.04109911374481661, 0.18040458884622368, 0.10531295716230359, 0.16777532867022923, 0.09026450929897172, 5.613655047757285, 18.764610835484095, 62.457954679216655, 38.824421473911826, 100.34375095367432, 100.78480870383126, 37.82322774614607, 33.64451510565621, 45.75346735545567, 22.696236848831177, 44.859612873622346, 76.08023153032575, 64.40717451913017, 53.26263918195452, 64.89939880371094, 72.93141910008022, 63.2681702205113, 60.127320425851, 49.09697873251778, 55.022402490888325, 14.316321986062185, 0.2953772858849594, 0.5291409322193691, 2.117159971169063, 4.102382770606449, 10.66925857748304, 9.322546567235674, 11.880401679447719, 20.462010587964738, 18.81739456312997, 20.211574929101126, 23.38824963569641, 23.451155151639664, 18.72613344873701, 12.95211614881243, 22.940589359828405, 37.319657053266255, 42.408250195639475, 44.25741250174386, 30.266710894448416, 33.295691217694966, 20.77857746396746, 18.01335597038269, 13.107246841703143, 4.54638568844114, 5.574905378477914, 3.792484862463815, 0.5316074884363583, 14.14626829964774, 37.052856649671284, 50.83240597588675, 52.93470505305699, 52.66688673836844, 53.41972058159964, 44.992233140128, 41.806563990456716, 42.04503658839634, 48.25030599321638, 48.19649566922869, 52.56714187349592, 49.088654790605815, 48.22303778784615, 50.787666525159565, 57.22726740155901, 55.47901030949184, 55.440475600106375, 49.90271615982056, 51.30004405975342, 55.125767367226736, 54.660623686654226, 48.52220984867641, 41.118952887398855, 45.66587141581944, 49.72794117246355, 49.464941433497835, 51.087668895721436, 43.28595706394741, 41.215175015585764, 39.22314037595476, 34.06370687484741, 32.50380849838257, 44.128738812037874, 53.83446897779192, 52.977519852774485, 37.03209890638079, 20.19300239426749, 12.899436644145421, 8.592449835368566, 2.970271736383438, 5.434718089444297, 13.133504952703204, 14.846662351063319, 16.511315243584768, 23.019823142460414, 28.324338504246303, 29.146473680223735, 27.887890883854457, 30.077369008745464, 35.34884221213204, 37.96363694327218, 24.129704066685267, 8.63982265336173, 10.955948199544634, 14.578138794217791, 16.144318342208862, 22.444232634135656, 21.20314540181841, 24.01291527066912, 20.864821978977748, 20.353439773832047, 17.650343860898698, 19.9222571509225, 13.966743350028992, 11.336455004555837, 5.300715131419046, 7.1063778059823175, 0.24107258128268377, 15.578307662691389, 58.84249428340367, 44.74287966319493, 54.518873487200054, 54.363647256578716, 49.51244626726423, 44.6717266355242, 58.58984388623919, 57.10606302533831, 39.919335978371755, 15.557245935712542, 30.533275059291295, 27.563632352011545, 29.70599126815796, 25.300510270254954, 53.587165219443186, 52.18521329334804, 73.5167145047869, 61.77474525996617, 48.36438846588135, 5.400407016277313, 0.38488384442670004, 0.06295071316084691, 0.018149922867970805, 0.0518587962059038, 0.011666704817408962, 0.0574588542804122, 0.07404161231326205, 0.025883020234427283, 0.03902810612427337, 0.08080539187150342, 0.032153114676475525, 0.025749051976682882, 0.057793378829956055, 0.12693084536918572, 0.0178261666691729, 0.021073942305520177, 0.1686688642948866, 0.19876665568777493, 0.21549229962485178, 0.29284871156726566, 0.1079910805981074, 0.20165523354496273, 0.14996455796062946, 0.20328578033617564, 0.09415507303284747, 0.2212293946317264, 0.08560183378202574, 0.1828451571719987, 0.12542271986603737, 0.21655028499662876, 0.1500245811683791, 0.08331541504178729, 0.13987434868301662, 0.14053932657199247, 0.2446421097431864, 0.1502777968666383, 0.2543077596596309, 0.5175546482205391, 4.995800818715777, 37.679848194122314, 83.15313638959611, 51.32786464691162, 116.33081940242222, 111.43892628805978, 68.27875941140312, 51.131984506334575, 62.053909982953755, 21.386451039995464, 40.29686287471226, 84.14805589403424, 64.34634304046631, 60.758300236293245, 67.93831852504185, 82.35894339425224, 67.94518334524972, 66.27455152784074, 52.81397662843977, 62.53766441345215, 16.872296742030553, 0.28007594123482704, 0.5387454054185322, 3.0350170050348555, 4.547990722315652, 10.197775534221105, 9.564366459846497, 13.220426048551287, 23.588732957839966, 22.46880841255188, 30.54877301624843, 26.82780769893101, 29.52546317236764, 26.90812192644392, 25.18736754144941, 27.96553005490984, 40.20024817330496, 47.42862592424665, 50.739275796072825, 38.93879577091762, 38.942947319575715, 26.82114785058158, 27.180209909166607, 18.086214780807495, 7.775104573794773, 6.537758946418762, 3.8029644829886298, 2.5748836270400455, 19.084754296711512, 38.033445494515554, 50.06360517229353, 53.69699192047119, 52.96739632742745, 52.61639417920794, 48.62762791769845, 45.61052901404244, 48.68002775737217, 56.289229324885774, 55.03148378644671, 57.26646913800921, 51.69845724105835, 48.33221483230591, 53.99676152638027, 56.850939069475444, 55.95105355126517, 56.39842026574271, 51.482006958552766, 49.894003118787495, 56.15395484651838, 57.78422805241176, 47.6828396660941, 40.790247508457725, 47.49895906448364, 50.67340339933123, 53.22831508091518, 51.74864060538155, 48.096358231135774, 47.74222591945103, 47.6337263243539, 41.249311515263145, 40.059272697993684, 51.56453766141619, 55.894703660692485, 52.15763936723982, 36.82643222808838, 24.281965153557913, 16.557981082371303, 11.602088979312352, 6.017825680119651, 7.875050067901611, 19.154517684664043, 16.03186869621277, 15.142030273165021, 25.109867334365845, 30.049006462097168, 33.02491297040667, 33.6120913369315, 35.83701222283499, 39.8034747668675, 44.836822782244, 26.993760211127146, 18.0282199042184, 25.751802716936382, 20.23755250658308, 22.893456254686626, 34.01916197368077, 34.753506660461426, 34.289391313280376, 29.579530579703196, 30.884774003710064, 22.627357619149343, 21.623836244855607, 13.622022373335701, 9.19921691077096, 6.190582650048392, 9.653457130704608, 0.5603946894407272, 22.998247248785837, 60.67902823856899, 48.73052379063198, 58.91659682137625, 64.7181897844587, 52.27346236365182, 50.82999842507498, 60.725629806518555, 66.89017581939697, 37.54126984732491, 19.625478744506836, 43.77996703556606, 26.776840925216675, 37.82954018456595, 43.83524342945644, 69.11356462751115, 61.529015268598286, 76.21949427468437, 72.1885107585362, 56.471240861075266, 8.24789822101593, 0.611622997692653, 0.10272359289228916, 0.2473788857460022, 0.13857749184327467, 0.16085442075771944, 0.10454661971224205, 0.16308309616787092, 0.215013145336083, 0.2535348268491881, 0.30874803555863245, 0.09084792049335581, 0.13137227775795118, 0.14197655873639242, 0.2665637848632676, 0.12857421647225106, 0.06680965716285364], [0.015302043541201522, 0.07743881323507854, 0.05297624160136495, 0.019100272229739597, 0.04540104951177325, 0.0238262160481619, 0.055963329172560146, 0.07680377909647566, 0.006956573409427489, 0.015690800002110854, 0.06632852155183043, 0.026036343703578626, 0.08432236100946154, 0.05304787793595876, 0.05120703957176634, 0.09151470328548125, 0.08825929582651172, 0.04651615056874497, 0.07731666336102144, 0.058792908409876485, 0.09432562959513494, 0.042625210247933865, 1.5316253964390074, 5.483505300113133, 32.926734924316406, 34.37009463991438, 51.94679280689785, 59.36286572047642, 38.893837451934814, 48.76326717649187, 40.45827995027815, 37.01475967679705, 14.709847109658376, 58.22432347706386, 66.62488664899553, 72.34702696119035, 50.00678627831595, 69.2829339163644, 57.002034596034456, 64.34321635110038, 46.81290783200945, 54.86220482417515, 7.773470878601074, 1.1935661137104034, 0.6487732785088676, 1.9105828617300307, 2.090732063565935, 5.815069428512028, 5.926659669194903, 18.70371334893363, 18.082770211356028, 24.084750958851405, 21.669975757598877, 21.311332327978953, 22.705703769411357, 22.291964599064418, 12.476802911077227, 18.076297964368546, 28.70489134107317, 42.48651817866734, 35.96425805773054, 31.31568043572562, 28.183785131999425, 19.32684169496809, 23.229608365467616, 8.643328888075692, 6.753762807164874, 7.491221155439105, 5.497884162834712, 1.3544616401195526, 9.217273541859218, 27.600284099578857, 40.171840463365825, 47.58695452553885, 52.98563882282802, 50.881779875074116, 44.03071710041591, 36.362441948481965, 30.223170007978165, 37.09428528376988, 38.88409955160958, 41.07691281182425, 42.926756041390554, 46.60846403666905, 48.73830229895455, 52.38689170564924, 52.83317450114659, 53.45643833705357, 52.13724987847464, 50.59100471224104, 48.8248108455113, 49.99638135092599, 46.22376659938267, 39.22773660932268, 47.27777705873762, 49.23003673553467, 50.94768006461007, 39.61056498118809, 34.88844762529646, 31.59739167349679, 30.344853809901647, 26.902613742010935, 30.527181489127024, 43.79524612426758, 50.426606859479634, 48.188456603458945, 34.50809628622872, 26.875654731478008, 21.52676296234131, 13.04203712940216, 5.177703355039869, 6.17767767395292, 11.76568170956203, 15.221776485443115, 7.894049048423767, 14.78101577077593, 17.555976901735576, 18.5806850705828, 20.221469163894653, 25.11315209524972, 28.098132950919016, 27.415184089115687, 17.246582303728374, 9.41140968458993, 14.205136043684822, 18.072040455681936, 10.962831258773804, 17.82474364553179, 20.648161513464792, 21.58714280809675, 22.52568289211818, 23.90564376967294, 27.304306473050797, 18.166909422193253, 15.132782220840454, 9.395889145987374, 3.4344129221779958, 3.8593838555472235, 0.07322661033166306, 3.9662823251315524, 39.768525327954976, 53.978852544512065, 59.11988026755196, 56.798844950539724, 37.88638687133789, 64.58879348209926, 53.63112299782889, 48.409020219530376, 15.459239857537405, 22.429990564073833, 27.9886189188276, 19.68921283313206, 33.20361368996756, 46.570429597582134, 57.794563497815815, 56.50185809816633, 55.980343682425364, 45.00568832669939, 27.17580301421029, 1.0240300680909837, 0.14267502911388874, 0.06512282589184386, 0.07982868142426014, 0.09277570633483784, 0.09039195174617426, 0.02942770752789719, 0.051349080699895105, 0.038456525187939405, 0.055505647124456506, 0.03814982057416013, 0.06812206602522305, 0.1512580221252782, 0.02013351651839912, 0.04115970352930682, 0.012666851016027587, 0.07293394460741963, 0.02873410903183477, 0.08354115685714142, 0.10636757700038807, 0.08682553776140724, 0.02608130343391427, 0.03424803387107594, 0.0429751578984516, 0.09033795392939023, 0.048268881160765886, 0.023566114915800945, 0.04971519212371536, 0.04961334062474115, 0.057442555869264264, 0.0902712471517069, 0.07097405048885516, 0.10071373145495142, 0.06458422515009131, 0.07353289425373077, 0.06869658162551266, 0.033294410577842166, 0.06181669794023037, 0.15872217874441827, 1.6654931902885437, 4.7184500098228455, 63.788729258946006, 42.397720200674875, 70.92254202706474, 66.52088601248605, 42.14864117758614, 34.86511557442801, 36.44560841151646, 28.571060350963048, 23.03157080922808, 67.38615213121686, 69.37836742401123, 69.00068419320243, 56.439167976379395, 73.85186086382184, 62.10893971579415, 72.00851072583879, 50.11209317616054, 58.60148211887905, 9.018022656440735, 1.92608385852405, 2.3339578807353973, 2.0217683698449815, 3.7534503170422147, 9.84431198665074, 10.213366423334394, 21.633777379989624, 22.880129609789165, 19.895614283425466, 20.761926106044225, 24.10711373601641, 23.09444853237697, 18.018641812460764, 12.430358546120779, 23.890097175325664, 32.05450323649815, 44.540228503090994, 39.437245641435894, 35.25250196456909, 30.088722365243093, 19.567287581307546, 24.02864251817976, 11.96629444190434, 8.164411272321429, 9.014054366520472, 6.0014826485088895, 1.3440572555576051, 9.337508644376483, 31.39779077257429, 43.90180022375924, 52.96864700317383, 57.70224973133632, 52.319570609501426, 47.161113330296104, 42.805117402757915, 38.75484568732125, 46.00174733570644, 47.82659442084176, 49.746638774871826, 47.90857969011579, 49.02023935317993, 50.989344937460764, 53.465172222682405, 55.951126507350374, 57.09091247831072, 55.04066583088466, 55.77964496612549, 53.55941758837019, 55.76625231334141, 50.11320488793509, 42.762431144714355, 49.2563738822937, 51.60947513580322, 52.99127728598458, 49.200055258614675, 43.46335499627249, 40.645579065595356, 38.451511655535015, 32.18176644189017, 36.44563620431082, 47.26090335845947, 55.32525362287249, 54.5015481540135, 42.73375940322876, 29.51661811556135, 22.445033414023264, 12.110554678099495, 4.150493834699903, 5.701610122408185, 12.877475125449044, 17.28632426261902, 15.254997559956141, 22.534927470343455, 21.381425755364553, 22.849354301180156, 24.192013774599346, 28.345174414770945, 31.744894981384277, 27.891622066497803, 19.210106747491018, 10.780582615307399, 7.729484438896179, 15.87783408164978, 13.031447206224714, 20.438470091138566, 23.924591507230485, 18.36074331828526, 20.513847623552593, 20.05737008367266, 21.147872482027324, 19.68428134918213, 22.956983634403773, 14.280922651290894, 9.760000807898384, 4.799535921641758, 0.45527612577591625, 2.589998781681061, 46.53137377330235, 55.410428115299766, 61.44901371002197, 58.616802896772114, 44.53182118279593, 60.14014680044991, 56.23961918694632, 52.457356861659456, 26.38732143810817, 17.320974928992136, 28.84818056651524, 25.939454453332083, 26.793596506118774, 37.7544892174857, 61.46265997205462, 65.30567387172154, 64.52807317461286, 59.00496401105608, 34.17972789491926, 1.0641630802835738, 0.27968369371124674, 0.05711448418774775, 0.04911114328673907, 0.04623442282900214, 0.06589368238512959, 0.024779774880568897, 0.0690861421504191, 0.021460074532244886, 0.04045130279181259, 0.04863409245652812, 0.06318367458879948, 0.12302401715091296, 0.06927337031811476, 0.07826880405523948, 0.053007230295666626, 0.05667731425325785, 0.2418522723019123, 0.1534415613859892, 0.15864739061466285, 0.11506230437329837, 0.1339105958385127, 0.11785310533429895, 0.15879514840032372, 0.1407859061977693, 0.08890121031020369, 0.0838468572390931, 0.19087811612657138, 0.09234210210187094, 0.13713643274136952, 0.11699175941092627, 0.1820084284991026, 0.1382801170860018, 0.1394712988819395, 0.130147712039096, 0.1726825346371957, 0.1325531458216054, 0.25517248468739645, 0.28585895949176376, 2.0802092339311327, 20.622826644352504, 87.32295186179024, 52.93049097061157, 84.23270579746791, 70.1056214741298, 57.173384121486116, 59.33225195748465, 49.391221046447754, 43.36150482722691, 19.940140077045985, 72.10677215031215, 76.25231061662946, 81.0733390535627, 63.55659689222063, 79.65922777993339, 69.30049201420375, 77.38193484715053, 56.51277024405343, 64.70545373644147, 12.091236080442156, 2.349964358976909, 3.6885767238480702, 4.745336064270564, 3.2232141750199452, 9.609316962105886, 10.159271223204476, 24.56487669263567, 26.54183895247323, 32.76483842304775, 30.924719197409495, 29.91417666843959, 32.72103003093174, 30.064556530543737, 23.536555460521154, 28.044388634817942, 38.08343430927822, 50.13698162351336, 45.36892972673689, 40.64943184171404, 36.989238943372456, 29.516923836299352, 33.54489183425903, 17.153537239347184, 9.902963468006678, 13.045269778796605, 8.00996584551675, 4.376752368041447, 11.944026333945137, 32.34971135003226, 43.42864874431065, 51.126957484654014, 56.13978746959141, 54.33059467588152, 49.02537407193865, 45.96806941713606, 45.402079582214355, 53.76970134462629, 50.644262654440745, 53.51542159489223, 51.3868270601545, 51.176300116947715, 52.339174951825825, 54.55162729535784, 54.892307894570486, 56.58187355313982, 56.02362053734915, 52.41791193825858, 56.53717926570347, 55.64091375895909, 50.619985648563926, 44.10146713256836, 49.779350893838064, 52.844013690948486, 56.19932310921805, 52.41810996191842, 48.92297846930367, 47.43423659460885, 46.05133662905012, 41.334180286952424, 45.86637210845947, 50.84564576830183, 56.76278032575335, 55.16679995400565, 44.19287763323103, 35.09004613331386, 24.05355875832694, 17.043236323765345, 9.071053045136587, 10.735294256891523, 17.221221378871373, 21.071574313299998, 11.529034750802175, 23.48861983844212, 28.23743564741952, 29.207485812050955, 29.328321933746338, 35.15787444795881, 37.61316633224487, 33.75425495420183, 23.79190696988787, 15.303294488361903, 23.23488552229745, 27.917408568518503, 19.154177222933086, 25.147849661963328, 31.856754030500138, 30.013567175183976, 30.405063424791607, 34.19358260290963, 36.913183961595806, 27.891196489334106, 20.655429329190934, 13.318162884031024, 7.053536321435656, 8.071486064365931, 0.24848544065441402, 5.228752204350062, 52.49446024213518, 57.86204092843192, 65.24339021955217, 61.492849894932334, 46.484157289777485, 67.61379596165249, 60.54034219469343, 58.863811356680735, 22.286480733326503, 30.467600686209543, 32.630519321986604, 25.037359407969884, 45.78614820752825, 60.4533576965332, 71.1965581348964, 66.40703977857316, 66.8979994910104, 65.78544698442731, 43.090087345668245, 0.7674275029982839, 0.46852441344942364, 0.15839954891375133, 0.1535953309919153, 0.19498690350779466, 0.2074145573590483, 0.10243187711707183, 0.34451187934194294, 0.14049771880464895, 0.10695106283362422, 0.13835977709719113, 0.16385028857205594, 0.2196073838110481, 0.13389921002089977, 0.3558140742991652, 0.14498397521674633, 0.21411127730139665], [0.10724234434642962, 0.042766060547104905, 0.02590243481764836, 0.09392027956034456, 0.1661007720977068, 0.017376815334760716, 0.12203894715223994, 0.009480535385331937, 0.0469027967857463, 0.024129024174596583, 0.025071626362789954, 0.011306583382455366, 0.06059435103088617, 0.0163274778917964, 0.037258547863789966, 0.0030700615898240358, 0.035500365242894204, 0.02152940384777529, 0.04741176251055939, 0.050752030951636176, 0.1262755976723773, 0.0607710008376411, 0.2884825829948698, 2.763877885682242, 32.140403815678184, 49.06700767789568, 31.840894767216273, 72.75025177001953, 44.4004932812282, 43.542779854365754, 31.385634899139404, 38.8781727382115, 15.793823412486486, 28.506541115897043, 72.54140976497105, 60.827622413635254, 62.41886411394392, 64.4643998827253, 60.15518965039934, 51.355942317417686, 55.17847292763846, 40.14016362598964, 3.0117175238473073, 0.4398379884660244, 1.4995616312537874, 1.5382570177316666, 4.335178256034851, 7.687322769846235, 13.059375490461077, 20.732969488416398, 24.413383381707327, 28.801936830793107, 15.722776344844274, 23.46041362626212, 23.6068833896092, 19.519483975001744, 12.396904706954956, 17.05436733790806, 27.728634698050364, 34.92193446840559, 33.54919971738543, 31.72095843723842, 22.99357111113412, 23.292303698403494, 20.07314944267273, 7.391569222722735, 6.362442868096488, 6.4977768404143195, 7.49184649331229, 1.666478965963636, 4.3718686529568265, 23.38109472819737, 32.659462043217246, 44.21320458820888, 54.41448722566877, 52.553853443690706, 47.48426015036446, 38.46905933107649, 33.34657982417515, 38.86228915623256, 39.1582407270159, 43.96054029464722, 45.71650641305106, 46.124553271702354, 49.50485188620431, 50.087663309914724, 51.76580613000052, 55.43766852787563, 50.94383771078927, 43.586796692439485, 50.348821776253835, 52.04029471533639, 46.28132200241089, 42.25877012525286, 50.022645541599815, 51.88568687438965, 47.348527090890066, 39.672612394605366, 36.46127312523978, 34.69462415150234, 31.835551602499827, 30.08320549556187, 37.28130299704415, 43.815093653542654, 50.14124434334891, 46.71648073196411, 38.12996986934117, 30.979992117200577, 22.00806815283639, 14.314788171223231, 4.41094879593168, 7.56401743207659, 12.918259314128331, 20.305749075753347, 15.187096289225988, 12.370353903089251, 15.888232060841151, 19.049073559897288, 17.293843950544083, 23.353183814457484, 26.974286147526332, 21.176012686320714, 17.671403850827897, 10.143628222601754, 12.29772959436689, 14.768123388290405, 14.58438696180071, 20.987450735909597, 16.681207384381974, 20.933574404035294, 16.218981947217667, 17.557271003723145, 27.314638444355555, 24.30024412700108, 15.032903603145055, 15.338558333260671, 7.642426116125924, 4.021264723369053, 0.523122815149171, 0.4604306848985808, 25.801119293485367, 50.09995814732143, 60.266180174691335, 71.27150835309709, 44.60305411475045, 53.0937944820949, 57.67857027053833, 34.89962032863072, 14.103316273008074, 21.624753407069615, 13.8646491255079, 26.358121633529663, 37.6421194757734, 63.401096207754954, 59.60109860556466, 44.4618250301906, 37.82699019568307, 39.21339552743094, 11.28699859551021, 0.10667695504214082, 0.03436416853219271, 0.07550538876759154, 0.04972480357225452, 0.006971365048749638, 0.0797951617943389, 0.07471808458545379, 0.005449222284369171, 0.0366411318869463, 0.08487678518784897, 0.05658084014430642, 0.07602984205420528, 0.06817181621279035, 0.07257791049778461, 0.10635322598474366, 0.03895307032923613, 0.009852296240361673, 0.08165478200784751, 0.038352003653666804, 0.044852460734546185, 0.06235001967953784, 0.06437483602868659, 0.10331277163433177, 0.023654746856274347, 0.03335721238649317, 0.0350151041389576, 0.04026114674551146, 0.09002847410738468, 0.061285730717437606, 0.13092363040362084, 0.026385114095839005, 0.03334808948316744, 0.06480535292731864, 0.041818055523825545, 0.05447910167276859, 0.024882963093529855, 0.06078636965581349, 0.10453089127050978, 0.17741025452102932, 0.3939735809607165, 8.519315702574593, 64.4607103892735, 56.850949491773335, 50.52416998999459, 73.90949617113385, 39.66632080078125, 40.50962018966675, 31.889382771083287, 30.629938398088726, 17.59708939279829, 41.26334687641689, 73.52784551892961, 66.30624226161412, 65.6029942376273, 72.7278299331665, 65.66464560372489, 56.16221278054373, 55.06106921604702, 45.31353521347046, 2.911564669438771, 2.2929698058537076, 2.5407571153981343, 4.4902737736701965, 8.198418361800057, 12.995438167027064, 13.885073355266027, 21.694548061915807, 22.558681624276296, 24.894308158329554, 19.1052862235478, 20.74621101788112, 23.678606169564382, 16.7182708127158, 12.60658049583435, 21.95696415219988, 30.77128212792533, 38.95693751743862, 38.593227113996235, 36.9015839440482, 25.561481135232107, 21.609003577913555, 21.419875349317277, 12.144611273493085, 11.850761532783508, 8.6072564465659, 6.432197136538369, 1.867335970912661, 5.065816078867231, 26.371463911873953, 39.30434397288731, 49.1523107119969, 59.53561183384487, 55.528988701956614, 49.570915358407156, 43.42167970112392, 39.94367551803589, 46.15820687157767, 49.580691473824636, 50.53371334075928, 49.31629862104143, 48.482921259743826, 51.317053249904085, 51.78275626046317, 54.74463782991682, 56.75887196404593, 54.13821642739432, 47.12234238215855, 55.28663900920323, 54.925475120544434, 49.01154368264334, 41.92180333818708, 51.8493651662554, 52.28917918886457, 52.18221514565604, 44.824857984270366, 44.691918100629536, 40.99175568989345, 39.23863138471331, 34.57973568780081, 42.179300103868755, 48.61543730327061, 52.75620583125523, 52.885508332933696, 41.429829188755576, 32.88553558077131, 22.61019730567932, 12.907258578709193, 3.0127808153629303, 5.503536088126046, 13.03580720084054, 18.547639438084193, 19.729229245867046, 22.90759583881923, 19.59938304764884, 22.456953048706055, 21.21865725517273, 27.43369061606271, 28.10811230114528, 23.862052508762904, 17.446455921445573, 12.775156821523394, 7.540336234228952, 9.688336219106402, 14.67365220614842, 18.742248058319092, 18.22375784601484, 20.20171022415161, 17.594301428113663, 15.200673069272723, 27.330257994788035, 21.175213643482753, 20.466155188424246, 19.58782993044172, 11.593042424746923, 5.973999917507172, 1.4504088801997048, 0.21614897224519933, 27.45231178828648, 55.965947014944895, 57.700356347220286, 71.80776337214878, 46.69486141204834, 54.99753141403198, 59.222741399492534, 42.000981535230366, 21.49092936515808, 16.663475581577845, 20.589602095740183, 28.269154173987253, 29.4929838180542, 57.51984909602574, 68.36905125209263, 55.85397332055228, 51.43389068331037, 51.9969344820295, 16.832575627735682, 0.02326265030673572, 0.0623691679377641, 0.04041523526289633, 0.09675516494150672, 0.05188647364931447, 0.006184715652904872, 0.010736271306606275, 0.041430415253021886, 0.032332498979355605, 0.05835962987371853, 0.0481656047382525, 0.03143297528315868, 0.020686853344419172, 0.05324297371719565, 0.05686957715079188, 0.011198663235908108, 0.05585814606664436, 0.19701927873705113, 0.1485876747007881, 0.15766302629240922, 0.13162762405616896, 0.22198486195078918, 0.15006005497915403, 0.19531785217779024, 0.08027112696852003, 0.1231963921870504, 0.14792321249842644, 0.27030981385282105, 0.09204876462795905, 0.16827056423893996, 0.0718956096097827, 0.10279433695333344, 0.13651144770639284, 0.093538718963308, 0.0848701491153666, 0.2191279309668711, 0.13979392871260643, 0.19389493710228375, 0.3244122878781387, 0.6098798140883446, 17.00832336289542, 91.56925310407365, 69.3120677130563, 60.35331058502197, 85.27828461783272, 59.211749349321636, 56.87221792766026, 40.00180067334856, 48.130720547267366, 19.61336977141244, 37.725039277757915, 82.00612081800188, 74.79270253862653, 74.88794149671281, 79.83075101034981, 74.34496062142509, 62.22721195220947, 61.13957568577358, 49.975953647068565, 4.735452251774924, 2.2471299341746738, 4.304791612284524, 4.8240218077387125, 7.471257243837629, 11.993619101388113, 17.603759663445608, 27.099270343780518, 32.13717637743269, 36.979761600494385, 26.5060453074319, 33.339621203286306, 31.990955012185232, 29.198171751839773, 23.121028866086686, 25.73857855796814, 37.22409847804478, 43.80057539258684, 45.58833646774292, 40.711875302451, 31.489472252982004, 31.772719042641775, 29.776720455714635, 12.410952227456228, 11.974540216582161, 12.114910330091204, 11.198198880468096, 5.018902276243482, 8.270386934280396, 28.250274181365967, 37.69123976571219, 49.40003483636038, 55.69981016431536, 56.001445361546104, 50.305471965244834, 49.197609492710654, 44.693915707724436, 51.295941148485454, 53.512312276022776, 55.82043784005301, 52.080854824611116, 52.048201765332905, 54.08567762374878, 53.97119215556553, 53.58655377796718, 59.68684632437569, 53.222040857587544, 46.88234118052891, 55.61621291296822, 58.51444203513009, 50.04288911819458, 43.87171104976109, 53.242235796792166, 55.49986185346331, 54.23162453515189, 48.99327686854771, 53.44676991871425, 50.32962390354702, 49.21155105318342, 41.74820607049124, 47.44221312659127, 50.89087854112898, 56.129500661577495, 57.267893518720356, 44.11520372118269, 33.67097731998989, 22.88357765333993, 19.184301137924194, 9.485855289867946, 12.913616180419922, 16.90622479575021, 24.71685811451503, 20.578293902533396, 19.937289578574045, 27.325666972569056, 28.844659566879272, 29.037798643112183, 34.18152053015572, 36.07167373384748, 27.409168686185563, 22.335913692201885, 14.312397122383118, 22.369119133268082, 26.043168476649694, 27.608825172696793, 30.85179090499878, 24.76369939531599, 29.575240067073278, 24.04889304297311, 23.465473651885986, 37.00668587003435, 36.110708713531494, 25.11700313431876, 22.15022655895778, 11.679725544793264, 6.9494827049119134, 2.2676670721599033, 0.6423483661242894, 32.672639301845, 56.430104051317485, 67.49140344347272, 72.13189683641706, 49.02465145928519, 59.68151705605643, 65.62498528616769, 41.83708047866821, 22.95972990989685, 27.201224735804967, 17.22461904798235, 31.75603641782488, 53.03846945081438, 74.18756307874406, 71.61896692003522, 61.13667828696114, 56.556338923318044, 61.29610470363072, 16.272837434496196, 0.14792948216199875, 0.13402685602860792, 0.135421666183642, 0.18055397511592933, 0.19232644912387642, 0.11608781505908285, 0.10430559050291777, 0.1894541018243347, 0.15165620004492147, 0.17653666782592023, 0.19851676481110708, 0.10279677967940058, 0.12413650245538779, 0.17123254601444515, 0.11017673688807658, 0.13750769996217319, 0.10746985713818244], [0.04877717513591051, 0.06377433253718273, 0.1245820556900331, 0.11472138123852865, 0.09924824509237494, 0.018528620047228675, 0.003175164755832936, 0.03596607096759336, 0.08049492817372084, 0.08969156111457519, 0.14051854982972145, 0.03332765879375594, 0.015013019853670682, 0.04394311185127922, 0.05481534291590963, 0.045100427964436154, 0.0167961759559278, 0.009602892212569714, 0.028539383052183048, 0.05163898139393755, 0.15699414004172596, 0.09986604444150414, 0.09971701779535838, 1.9246740256037032, 14.428847193717957, 53.28431061335972, 37.524927684238975, 47.383452211107524, 69.58030986785889, 38.349689279283794, 30.477081503186906, 28.489384276526316, 21.263718060084752, 20.381083181926183, 57.3322685786656, 68.30475262233189, 63.93314061846052, 64.09654835292271, 61.94270406450544, 75.47886494227818, 66.63118866511753, 34.957345962524414, 3.5438427073614935, 2.113120896475656, 4.065479150840214, 4.987392629895892, 4.554517686367035, 10.643291422298976, 21.486201116016932, 27.870697566441127, 26.94895475251334, 19.943497794015066, 16.535668679646083, 21.32683549608503, 23.50916392462594, 15.158160516193934, 12.884627427373614, 18.817307710647583, 28.420673540660314, 33.810267857142854, 30.97463158198765, 29.796258790152415, 21.78188865525382, 25.266696861812047, 12.433830908366613, 9.268882155418396, 12.891717195510864, 5.216165976864951, 9.248542172568184, 3.103374251297542, 1.1725646406412125, 13.492930054664612, 25.80930600847517, 38.10397318431309, 44.80721998214722, 54.58028861454555, 48.54418700081961, 44.96061883653913, 36.674176352364675, 34.522284507751465, 42.87720843723842, 45.90296132223946, 45.913786615644185, 49.61307355335781, 48.133541515895296, 49.95239577974592, 48.26567888259888, 55.096129826136995, 47.540498869759695, 41.92905378341675, 51.99215064729963, 51.084556102752686, 44.5070994922093, 45.15605081830706, 51.375821113586426, 51.54137931551252, 45.838763441358296, 41.73688050678798, 38.86627394812447, 36.534976141793386, 33.209491865975515, 32.51833718163626, 39.849072320120676, 45.79475702558245, 46.95041615622384, 47.713984966278076, 34.57352747235979, 22.862064293452672, 18.210905415671213, 12.961006368909564, 5.1729594724518915, 8.98553374835423, 15.025825125830513, 20.329970496041433, 23.899056877408707, 11.891262582370214, 14.218587756156921, 16.247627632958547, 27.031916243689402, 17.164958340781077, 22.718997410365514, 17.545248883111135, 19.85540679522923, 12.17556549821581, 8.459927712168012, 14.228152820042201, 9.719750761985779, 17.913187265396118, 21.816224915640696, 24.185352189200266, 18.7988498210907, 25.56432294845581, 18.11584884779794, 21.73735417638506, 26.185340779168264, 18.04977321624756, 14.938206604548864, 5.765036753245762, 3.874283398900713, 0.06536702385970525, 14.468816706112452, 48.907160895211355, 46.288607188633506, 55.073002747126985, 65.33478682381767, 47.012894357953755, 63.840361322675435, 28.43323588371277, 14.479351912225995, 15.256736346653529, 14.426235539572579, 33.53630386080061, 48.13666125706264, 59.984604426792686, 41.149490220206125, 34.02849687848772, 53.4718633379255, 29.306518486567906, 0.2894622789961951, 0.09801242926291057, 0.033489733668310304, 0.02728146224814866, 0.058619284869304726, 0.009212702346433486, 0.09100998858255999, 0.10685730965009757, 0.05137334171948688, 0.08524404905204262, 0.06461727659084968, 0.04690747189202479, 0.0430304822511971, 0.04546788860378521, 0.008391845455792333, 0.023180215087320124, 0.1011158177363021, 0.039580552373081446, 0.13111132676047937, 0.04602797854957836, 0.09398286763046469, 0.0982131806335279, 0.13547250202723912, 0.014593376478712474, 0.02079580571236355, 0.050628859882376025, 0.04176904493942857, 0.04410736821591854, 0.08856708609632083, 0.020426546955215077, 0.024532952678522894, 0.09006509464234114, 0.031168770710272447, 0.05539027920791081, 0.02914591532732759, 0.03657929699069687, 0.035822964539485316, 0.01633389344039772, 0.16863780096173286, 0.07723186683974095, 0.27557673837457386, 3.3760133130209784, 37.95898859841483, 71.80264254978725, 43.18432228905814, 69.85324900490897, 66.66611725943429, 33.07220588411604, 33.530752250126426, 27.196354048592703, 21.20907047816685, 28.559482915060862, 63.863477979387554, 76.0556835447039, 68.60691588265556, 71.82105527605329, 63.56729711805071, 77.5809451511928, 66.84340749468122, 41.165113244737896, 4.13833839552743, 2.206474070038114, 4.481678852013179, 6.782165305955069, 10.429369415555682, 15.538687297276088, 16.48033148901803, 25.400911739894322, 25.149901117597306, 22.132162979670934, 18.835619688034058, 17.036779710224696, 19.910839523587907, 12.145017743110657, 15.685064996991839, 22.471481731959752, 28.961981637137278, 36.88516187667847, 35.839954784938264, 34.6116418157305, 21.90642121859959, 26.817736285073416, 21.655474867139542, 13.439104097230093, 16.136004822594778, 8.911152413913182, 6.665446860449655, 4.365750764097486, 1.6976029872894287, 14.569847856249128, 30.581189836774552, 43.05140325001308, 53.074023383004324, 56.33456632069179, 53.24334750856672, 48.68872342790876, 40.27121359961373, 44.902017729622976, 50.287688050951274, 51.55213860103062, 50.967829840523855, 50.95431906836373, 49.80733476366316, 52.22550937107631, 51.74258177621024, 56.799060344696045, 53.533045700618196, 48.192615100315635, 56.02651793616158, 54.261223861149375, 45.966009276253835, 47.74605437687465, 54.46097067424229, 58.04791566303798, 48.85808229446411, 48.00768532071795, 44.96653870173863, 42.328714166368755, 38.58228022711617, 39.785194056374685, 42.642317635672434, 49.010765484401155, 54.24451691763741, 53.35648502622332, 44.983120577675955, 31.165842533111572, 21.406260354178293, 13.36469236442021, 2.7880636964525496, 7.466922436441694, 14.560185517583575, 20.411985295159475, 23.760836362838745, 18.82689275060381, 20.946581431797572, 17.443273646490915, 27.3920031615666, 21.26584073475429, 23.7414265700749, 19.907415798732213, 19.711460965020315, 15.764033011027745, 9.946761437824794, 7.362045458384922, 8.6804644039699, 13.605123485837664, 19.164710691996984, 20.758788994380406, 17.313027926853724, 22.831879581723893, 23.42520362990243, 22.296925612858363, 24.442942755562918, 21.723040887287684, 16.96265459060669, 10.848582029342651, 2.6770128096852983, 0.014612351710508977, 13.057370066642761, 56.4240209034511, 47.667438983917236, 57.921739850725444, 63.29106453486851, 52.71043109893799, 64.88653768811906, 34.469214166913716, 18.527130092893326, 16.902283430099487, 18.230309997286113, 28.869127648217336, 41.58507973807198, 65.48256805964878, 50.33019712993077, 43.66292463030134, 59.96082074301583, 39.99801390511649, 0.9536043213946479, 0.1386905764894826, 0.07820730842649937, 0.01505267683283559, 0.046638846663492065, 0.09149159238274608, 0.007208817954441267, 0.05202921027583735, 0.05854987073689699, 0.05873086316777127, 0.02582847450061568, 0.054629383608698845, 0.006373022267195795, 0.05394527781754732, 0.01072803304331111, 0.07818972758416619, 0.0571037158370018, 0.023775972226368527, 0.1999653149396181, 0.18082295996802195, 0.28237419362579075, 0.21408109606376716, 0.2025342620909214, 0.15610756618635996, 0.07410356934581484, 0.14710202227745736, 0.10020244853304965, 0.12319597149533884, 0.2197719964065722, 0.10108782816678286, 0.11562182434967586, 0.14009700316403592, 0.14489294295864447, 0.13385328677083763, 0.1466538906097412, 0.19983841532043048, 0.1691657690597432, 0.09587603461529527, 0.2956259553985936, 0.13315139657684735, 0.33673546090722084, 3.4689498117991855, 57.766607420785085, 86.57827867780412, 58.21773311070034, 75.09540775844029, 83.40907328469413, 54.02572161810738, 37.54104750497, 37.48589270455496, 26.329489844185964, 27.569581747055054, 69.2043706348964, 83.57565634591239, 74.11330768040249, 78.75909560067313, 72.7475072315761, 85.7346909386771, 72.59054047720772, 47.762382643563406, 4.288706532546452, 3.7143341302871704, 8.723427721432277, 8.228352069854736, 8.550629496574402, 15.188763856887817, 30.140017441340856, 38.77398797443935, 35.82651696886335, 26.192565168653214, 26.465054409844534, 31.70420285633632, 30.576308727264404, 26.79330120767866, 23.136525085994176, 29.105223962238856, 36.2286057472229, 43.26352480479649, 43.786161354609895, 44.186589513506206, 31.53828682218279, 36.0218551499503, 20.740339790071758, 14.379279613494873, 19.78086825779506, 9.171322499002729, 16.180947508130753, 7.65543748651232, 5.611938842705317, 17.492970636912755, 30.453377723693848, 44.66051919119698, 49.44543089185442, 53.27943992614746, 52.338591303144185, 51.137251240866526, 44.25390018735613, 48.17599153518677, 56.10587331226894, 56.13536841528756, 52.90630429131644, 55.11861767087664, 52.759016377585276, 55.03581946236746, 52.29555763517107, 57.95356954847063, 54.91365276064192, 51.21179151535034, 56.529713426317485, 57.02563067844936, 46.91214200428554, 50.46506861277989, 55.52075161252703, 58.727800369262695, 52.151344299316406, 53.28877483095442, 51.21355983189174, 50.56119346618652, 44.61898980821882, 44.4804288319179, 47.60160827636719, 55.70870385851179, 57.701547963278635, 55.92537300927298, 45.13446971348354, 32.24426201411656, 23.400612218039377, 17.122070584978374, 11.71439184461321, 14.483715380941119, 18.02626051221575, 25.619932855878556, 32.15619012287685, 16.63050811631339, 25.7483685697828, 26.09618670599801, 35.21159791946411, 28.695532117571148, 31.552304812840053, 22.82482021195548, 22.101877519062587, 18.51520872116089, 15.688268116542272, 28.269159385136195, 19.548598664147512, 28.612850291388376, 30.58223554066249, 32.15058987481253, 25.90566710063389, 33.17820412772042, 23.799193893160137, 29.86007799421038, 39.13614545549665, 26.380838768822805, 21.484382425035747, 10.379648974963597, 9.78857353755406, 0.10965446848422289, 16.38701891899109, 58.29121725899832, 54.07381010055542, 62.88030093056815, 68.47396210261753, 57.443543979099815, 72.26371806008476, 32.97217614310128, 21.298276662826538, 17.643076045172556, 18.39903310367039, 46.59149653570992, 61.87732151576451, 72.11171231951032, 54.299598761967246, 50.80051721845354, 69.28440693446568, 46.870588302612305, 0.67709923854896, 0.3142729662358761, 0.08788597264460155, 0.05029486459014671, 0.1810648034193686, 0.1517130612794842, 0.14329754428139754, 0.22226781105356558, 0.1669880516294922, 0.18290614389947482, 0.10304665698536805, 0.10343618358352355, 0.11347937038434402, 0.1296759537820305, 0.08272736266787563, 0.1694595068693161, 0.16645916072385653, 0.1807463669351169], [0.06219705753028393, 0.028589472507259676, 0.08856802247464657, 0.033480268104800155, 0.08142190200409719, 0.02673784882894584, 0.11325807975871222, 0.01180934560086046, 0.10660764947533607, 0.012738601005237018, 0.03986016647624118, 0.028298655790942054, 0.03459889075851866, 0.022425482282415032, 0.13423448774431432, 0.051174110267311335, 0.04981408181733318, 0.03022573595600469, 0.06813362826194082, 0.04948870391984071, 0.3536212391086987, 0.11433296065245356, 0.13888961795185292, 0.08194228408059903, 10.918508699962072, 58.20765822274344, 52.65491846629551, 50.45056077412197, 63.443028586251394, 53.52993638174874, 32.19337688173567, 17.13927606173924, 20.048448596681865, 21.856053727013723, 53.44981670379639, 62.66053635733468, 66.32528032575334, 58.02734204701015, 67.28349249703544, 69.58289459773472, 60.758216857910156, 35.99536166872297, 1.230408393910953, 1.6789459884166718, 6.9023687073162625, 6.828938841819763, 9.554351500102452, 22.471061365944998, 25.462537050247192, 16.99074442046029, 22.342677763530187, 25.49581892149789, 16.958079201834543, 16.155131476266043, 24.13625274385725, 12.146866832460676, 13.640018207686287, 16.818875517163956, 27.051063741956437, 29.570883546556743, 28.259138345718384, 22.851407493863785, 24.449668611798966, 20.43709782191685, 8.804859740393502, 17.717030933925084, 17.459073850086757, 6.764185539313725, 5.803266176155635, 4.867523610591888, 2.6828953283173695, 1.9834351582186562, 17.440890414374216, 21.561311142785208, 31.211262907300675, 50.62168100902012, 53.53766277858189, 50.69537707737514, 44.396730831691194, 35.881769044058665, 44.988470690590994, 46.208661215645925, 47.52480983734131, 47.232832636152, 49.455682958875386, 50.607638699667795, 48.61442286627633, 54.34952851704189, 43.2796550478254, 39.855766909463064, 54.70375462940761, 49.789040156773154, 45.38807201385498, 44.10488217217581, 55.17819847379412, 50.66837985174996, 48.32506513595581, 43.23006575448172, 42.74245854786464, 37.651079177856445, 33.83579901286534, 39.19500017166138, 44.900103500911165, 34.118632384708945, 32.71990442276001, 31.176744256700786, 14.63217146056039, 5.352847465447017, 9.552242721830096, 6.950070261955261, 5.497940182685852, 13.806770631245204, 19.446915251868113, 17.04444009917123, 27.08628589766366, 15.501891374588013, 10.85463651588985, 23.240306854248047, 21.33694859913417, 23.159243958336965, 12.949110184397016, 20.6184857572828, 15.646294048854283, 15.96890412058149, 5.606258690357208, 6.834941651139941, 9.377396515437535, 12.20167074884687, 16.931321689060756, 15.869800227028982, 21.387616600309098, 23.12715196609497, 30.873781953539165, 21.705547060285294, 24.34831002780369, 22.864400625228882, 15.508139542170934, 11.624142561640058, 3.4093386105128696, 0.22029072285762855, 4.35725919689451, 42.19623286383492, 45.80307401929583, 45.631217275347026, 60.63230160304478, 42.73929711750576, 59.64735276358468, 28.67279761178153, 15.510804176330566, 19.01877420289176, 24.404029369354248, 41.09175763811384, 60.86561516353062, 36.837462493351524, 32.646573134831016, 41.41965355191912, 50.895582471575054, 2.835303847278867, 0.031275148037821054, 0.1125237148787294, 0.026895648932882717, 0.09712476296616451, 0.050702752345906835, 0.025145495077595115, 0.06493194720574788, 0.12429222624216761, 0.02245877799578011, 0.01670127435188208, 0.04296557359131319, 0.016351099392133098, 0.03566602956769722, 0.035380681843629906, 0.14041387901774474, 0.03317137860826083, 0.012950809439644217, 0.019499914088685597, 0.04598238438900028, 0.034262527379074266, 0.07007533085665532, 0.021353042418403283, 0.1146610187632697, 0.10197964709784303, 0.054172804180000506, 0.031542507798544, 0.07423540191458804, 0.07253756480557577, 0.08391536891992603, 0.0210651705440666, 0.02717811457945832, 0.08567514270544052, 0.05718517396599054, 0.040102247414844375, 0.06946651531117302, 0.0416752985412521, 0.06997057862047638, 0.1515170732246978, 0.33736180301223484, 0.05947757738509348, 0.15749556384980679, 0.27552234700747896, 21.267688955579484, 79.58369391305106, 57.032526765550884, 57.497868469783235, 69.32706192561558, 39.83901827675955, 28.768799134663173, 22.99125736100333, 22.68239951133728, 30.227484839303152, 60.22034290858677, 71.79653508322579, 72.06481892721993, 66.24771063668388, 72.30497646331787, 72.97214944022042, 65.5547181538173, 41.008299350738525, 1.154471097247941, 1.0506104018007005, 6.490875542163849, 10.90877079963684, 15.234517744609288, 22.173096554619924, 22.270591940198624, 18.590469871248516, 23.166966881070817, 21.16162817818778, 17.745973655155726, 15.919955798557826, 14.233299698148455, 10.93456424985613, 17.067330939429148, 21.332932540348597, 28.894947154181345, 34.74726717812674, 33.9301347051348, 30.031132221221924, 26.382495914186748, 27.58959082194737, 15.157137393951416, 21.66559144428798, 20.67277898107256, 10.529505116598946, 8.954446639333453, 4.123766720294952, 2.3480375366551534, 4.499084523745945, 19.889798641204834, 29.123958042689733, 40.95209189823696, 56.07092734745571, 57.45791285378592, 54.57828058515276, 44.48088046482631, 43.44923278263637, 52.20096485955374, 54.883431570870535, 52.188704763139995, 51.02411024911063, 51.70211894171578, 51.874465533665244, 52.17626748766218, 56.922317913600374, 48.73957034519741, 42.11582136154175, 58.913247789655415, 53.60378878457205, 48.038622174944194, 47.58749648502895, 56.71441738946097, 52.86330189023699, 53.41725744519915, 47.12375634057181, 46.59346982410976, 44.16530023302351, 41.47700745718819, 38.47051845278059, 51.977413518088206, 46.10329873221261, 40.99203709193638, 42.29692268371582, 20.84219864436558, 12.663818018777029, 12.720391988754272, 8.440681202071053, 1.7056750570024763, 12.216903805732727, 16.325782707759313, 19.46690000806536, 27.16733316012791, 22.310722998210363, 18.146188156945364, 24.128668785095215, 24.496223279408046, 24.322813613074167, 15.177622420447213, 22.23922950880868, 20.310710089547293, 16.79191129548209, 9.898398501532418, 6.942668693406241, 8.365492139543806, 13.073273624692645, 14.268572228295461, 16.87587332725525, 22.266893761498586, 21.14259011404855, 26.713754756110056, 22.56621868269784, 20.585143089294434, 23.560787303107126, 14.371602722576686, 16.126999957220896, 5.8241099034036905, 0.6654245821493012, 2.1452834563595906, 42.479389326913015, 50.32208858217512, 52.073892729622976, 59.852255140032085, 43.316723687308176, 65.80687522888184, 30.78494576045445, 21.68194576672145, 17.91721200942993, 23.287300995418004, 33.451858929225374, 60.83693994794573, 48.14465168544224, 40.678513526916504, 50.08918843950544, 65.22535964420864, 5.725852387292044, 0.10751158025647913, 0.10137788831655468, 0.014705874192129289, 0.04497891930597169, 0.041010537783482244, 0.052607311933700523, 0.00912969630943345, 0.011110124593999769, 0.042549875897488425, 0.06141407561621495, 0.06950376009834663, 0.034417107834347656, 0.019112638530454466, 0.07161985976355416, 0.17472478933632374, 0.10161892431122915, 0.07651656200843197, 0.0394819748055722, 0.16981648414262704, 0.19382472229855402, 0.295888819864818, 0.1317978956337486, 0.21847877651453018, 0.21019474603235722, 0.1911163090595177, 0.08729580324143171, 0.18404779263905116, 0.1302951169865472, 0.17178654271577085, 0.09537480079701968, 0.11467555298336915, 0.11988769258771624, 0.1445034367165395, 0.11837924138775893, 0.2616193816065788, 0.16076189572257654, 0.2388331171657358, 0.24175391186560902, 0.43816398829221725, 0.2275284387703453, 0.22351927390055998, 0.37244390909160885, 31.453240871429443, 97.19063758850098, 69.08971840994698, 71.50696195874895, 78.01772281101772, 75.03156770978654, 40.46550955091204, 25.59812593460083, 25.700660501207622, 29.693682534354075, 63.77664634159633, 75.65910121372768, 79.67398575374058, 73.49079772404262, 79.08765506744385, 80.50687326703752, 67.94331427982875, 44.17610468183245, 3.132865011692047, 5.3561504653521945, 8.452653816768102, 10.650757261684962, 17.041120597294398, 31.523601804460796, 37.432575702667236, 24.780734641211374, 28.693980932235718, 32.72360781260899, 28.793076140539988, 25.523715938840592, 31.757269723074778, 22.74651575088501, 24.17955044337681, 29.103561605725968, 36.82210002626692, 40.47155795778547, 41.77545690536499, 36.96054288319179, 35.99586541312081, 30.750652926308767, 14.207596574510847, 24.13768580981663, 23.070960147040232, 11.591212442943029, 12.648328747068133, 9.656331947871617, 4.254710299628122, 5.9542370694024225, 20.059532710484095, 29.95758901323591, 39.18922274453299, 52.71771975925991, 56.48625244413103, 54.06125817980085, 49.545266083308626, 46.17726925441197, 55.84266512734549, 57.627862317221506, 54.452459130968364, 54.18172952107021, 53.590927668980186, 53.12294912338257, 53.967533929007395, 57.21708829062325, 49.03631748471941, 45.34450680868966, 59.29214000701904, 54.37719971793038, 48.04941272735596, 47.13501589638846, 57.62224122456142, 54.64057118552071, 52.24405411311558, 51.9462890625, 55.106413160051616, 47.86433356148856, 47.47636004856655, 44.581914220537456, 56.855955668858115, 50.65171807152884, 43.76182181494576, 47.692195415496826, 29.601671014513286, 20.992825167519705, 17.961442504610332, 12.94786558832441, 10.385781628744942, 17.765810762132915, 25.080224582127162, 22.78446160043989, 37.39520481654576, 25.51499421255929, 16.729528631482804, 34.31123644965035, 30.41900498526437, 33.038878849574495, 19.015861170632498, 27.26877338545663, 20.456373861857823, 23.125348908560618, 11.889179859842573, 18.49503983770098, 19.970752102988108, 21.74644763129098, 27.22156732422965, 26.014076369149343, 34.25951058523995, 31.91958659035819, 37.23585830415998, 29.719373498644146, 33.46122162682669, 29.61238166264125, 20.453896829060145, 17.34498964037214, 8.738864013126918, 0.9201153069734573, 5.166825081620898, 48.2207796233041, 53.651623657771516, 56.815336499895366, 66.08204473767961, 50.126868520464214, 72.12393420083183, 35.22961112431118, 20.485168933868408, 20.737775904791697, 35.68569435392107, 53.81171710150582, 77.93890939440045, 52.64074761526925, 50.638714517865864, 57.33774028505598, 74.51094613756452, 6.843835345336369, 0.3913700692355633, 0.18826233648828097, 0.033514761432473145, 0.1255536364125354, 0.14571306109428406, 0.2114088080291237, 0.2070327592747552, 0.2915585722242083, 0.16383678572518484, 0.14042356849781104, 0.14635590517095157, 0.12012166503284659, 0.0921979880492602, 0.10822967386671475, 0.23113920858928136, 0.26851565869791166, 0.12758764012583665, 0.1384303175977298], [0.08745814952999353, 0.08860910777002573, 0.017140250885859132, 0.011935009438145374, 0.08597002723919493, 0.08320482061909777, 0.10608082131615706, 0.09985807165503502, 0.03918228963656085, 0.018833747067089592, 0.03382285704304065, 0.04311633728710668, 0.036566856051129956, 0.046351127459534576, 0.12711205493126596, 0.1731869304286582, 0.01816106610931456, 0.09344390726515225, 0.018444622500932643, 0.03580992648910199, 0.0998915641435555, 0.08859610025371824, 0.040654568134674, 0.027339475295905556, 2.7832551087651933, 59.235560825892854, 60.22442150115967, 63.15346935817173, 65.3845567703247, 62.055084228515625, 50.98440129416329, 21.044165406908306, 22.296300274985178, 22.056107997894287, 42.496283871786936, 75.15163952963692, 65.5484230858939, 56.19500132969448, 59.491310119628906, 62.97089154379708, 41.52520363671439, 20.528496163231985, 0.22150550410151482, 6.097618358475821, 6.5760539429528375, 8.786396639687673, 18.310952527182444, 25.7384934425354, 19.72208649771554, 27.974734680993215, 29.25145401273455, 20.215855019433157, 16.196379457201274, 14.844807182039533, 17.98686248915536, 12.224094322749547, 18.31699572290693, 18.241284676960536, 24.445887054715836, 23.46526173182896, 22.56257435253688, 17.807506901877268, 25.29226449557713, 17.159017630985804, 16.190032277788433, 21.98744589941842, 21.159116404397146, 14.816566228866577, 6.940968990325928, 8.392501524516515, 3.356452831200191, 1.2772684565612247, 6.865557585443769, 9.991228171757289, 15.098301785332815, 38.18071256365095, 58.43480178288051, 51.609725270952495, 47.371199062892366, 40.97702203478132, 40.345566272735596, 48.77640274592808, 50.58500494275774, 49.72329977580479, 49.66651562282017, 50.0553229195731, 50.19240045547485, 54.02737181527274, 43.36823068346296, 41.0935502733503, 56.679676396506174, 48.616976329258506, 46.00358166013445, 46.82096774237496, 54.17990561894008, 54.04693446840559, 47.6601676940918, 49.07144062859671, 42.56421640941075, 38.98013060433524, 33.42061635426113, 46.39723879950387, 33.644098213740754, 36.72053820746285, 37.863940715789795, 16.14351408822196, 6.522916725703648, 4.726070880889893, 0.9538590162992477, 1.0500101425818034, 4.2138766050338745, 17.16376151357378, 22.00114253589085, 21.319685799734934, 22.910635675702775, 20.97586461475917, 10.015133449009486, 20.38377387183053, 22.458615405218943, 19.99740365573338, 14.168114304542542, 19.109587158475602, 21.553782769611903, 14.823260818208967, 7.7317547627857754, 5.707102673394339, 6.6786258561270575, 7.054202914237976, 13.328358496938433, 12.125867639269147, 14.790112699781146, 17.282184873308452, 30.58595630100795, 26.115690299442836, 26.3255432673863, 22.085083723068237, 19.41434904507228, 19.428481681006296, 8.425098998206002, 0.382684549582856, 0.24250548439366476, 27.251922266823904, 51.561018398829866, 37.955420698438374, 53.81842906134469, 44.620792865753174, 59.233135904584614, 26.175700153623307, 19.658934320722306, 32.87743050711495, 26.741846323013306, 52.07096058981759, 53.92486156736101, 27.052005222865514, 32.1901216506958, 53.00765071596418, 10.162298032215663, 0.15652619515146526, 0.06767256371676922, 0.039329497808856625, 0.024243776320612857, 0.04042845991040979, 0.023315475954275047, 0.03541435753660543, 0.0909175585423197, 0.06152173198227372, 0.06885788297014576, 0.0419307805464736, 0.10200651708458151, 0.010998078106370355, 0.022832016360812953, 0.04770418396219611, 0.034564316006643434, 0.074207310564816, 0.06198502890765667, 0.052022462245076895, 0.033694037169750245, 0.05365784020562257, 0.05217827084873404, 0.0978882641398481, 0.10918028785714082, 0.05015173102063792, 0.03927777986973524, 0.04297237590487514, 0.03351983687441264, 0.0565698546623545, 0.05792566601719175, 0.026352507095517855, 0.03234311126704727, 0.07814271867807422, 0.044629524661494155, 0.09719508633549724, 0.025768972068492855, 0.017664653282346468, 0.028131395212507675, 0.135437313201172, 0.05314251321500965, 0.23668332823685237, 0.046678486679281504, 0.06394109608871595, 6.467079264777047, 75.88830144064767, 69.03377846309117, 70.26985604422433, 76.15614754813058, 56.46831914356777, 37.82808106286185, 22.170914820262364, 22.76438651766096, 29.430060931614467, 56.440832069941926, 79.01617200034005, 73.54532718658447, 62.629151344299316, 68.1082992553711, 67.78711877550397, 56.28688778196062, 20.677894592285156, 0.34685974621347015, 6.435785012585776, 9.961824263845172, 10.562374438558306, 20.15243533679417, 25.723179612840923, 24.71969297954014, 25.290169613701956, 23.387808425085886, 18.043855088097708, 15.312186445508685, 12.626724192074366, 15.562074933733259, 14.266913345881871, 22.387554441179546, 24.687288318361553, 26.860776901245117, 28.25683675493513, 29.151125499180385, 23.307226691927227, 29.171695641108922, 23.50453989846366, 19.24122425488063, 24.169604097093853, 22.754718099321636, 14.78558247429984, 12.094090053013392, 8.122602224349976, 5.366300046443939, 0.544261135160923, 8.553220306124006, 14.629371336528234, 21.366697311401367, 44.5242372240339, 61.185628346034456, 55.086843558720176, 53.228318555014475, 44.53788348606655, 48.08898619243077, 52.269029412950786, 56.43813269478934, 54.722966398511616, 50.95791823523385, 53.78113807950701, 52.32504578999111, 58.56346157618931, 47.705167702266145, 43.89863184520176, 58.960162026541575, 53.14015981129238, 47.489922932216096, 51.83042090279715, 58.16428409303938, 55.717076437813894, 53.78211777550833, 53.44770097732544, 48.27543415342058, 44.23051255089896, 38.329873016902376, 49.02761486598423, 48.689720494406565, 35.1757104737418, 41.25989362171718, 23.818881613867624, 7.783091528075082, 8.283271500042506, 2.4462581404617856, 2.767297919307436, 1.6004112597022737, 14.515248911721365, 17.14706151826041, 22.6639016696385, 26.660343953541346, 22.700683695929392, 16.123770781925746, 24.7599230493818, 21.63716983795166, 21.80886503628322, 15.782716717038836, 19.555367946624756, 24.166757072721207, 17.008002008710587, 10.985603979655675, 10.443009597914559, 6.095259879316602, 7.4658741269792825, 14.482704418046133, 12.648822937692914, 14.919389145714895, 18.220672845840454, 29.550462790897914, 24.244493518556865, 21.4877644606999, 21.28421524592808, 19.063155821391515, 21.487927743366786, 10.161662272044591, 0.4695779340607779, 0.21016345199729713, 20.07574806894575, 58.66943550109863, 45.75757721492222, 54.69560439246041, 48.0527582849775, 66.31407288142613, 31.943526608603342, 23.614674057279313, 20.199585812432424, 25.993269988468715, 42.02057545525687, 63.7300169808524, 36.67312370027815, 37.95206124441964, 63.67678683144705, 16.989443370274135, 0.14365372088338646, 0.08006916780556951, 0.04394210422677653, 0.04197181834440146, 0.032384997233748436, 0.0015318466633159134, 0.010191331351441997, 0.06576373614370823, 0.010693589757595743, 0.08268245043499128, 0.04037037731281348, 0.042712066122995954, 0.03735355294442602, 0.023583817894437482, 0.023453780050788606, 0.092065354809165, 0.07032422428684575, 0.10585484201354639, 0.05851716534899814, 0.1880053345646177, 0.2642656410379069, 0.12157009302505425, 0.1662553423749549, 0.19301270587103708, 0.18286264980477945, 0.24781814217567444, 0.18563722020813397, 0.13037625620407717, 0.09324922199760165, 0.08954493648239545, 0.12202140023665768, 0.12556027248501778, 0.19944544854973043, 0.17353626739765915, 0.25908242059605463, 0.12252002848046166, 0.2798866571060249, 0.08458833995142154, 0.2499846773488181, 0.19731551355549268, 0.2953852654567787, 0.12030339028154101, 0.12773185595870018, 7.759426832199097, 94.4224613734654, 81.39342866625104, 81.85224601200649, 81.47199889591762, 80.73371805463518, 65.78940050942558, 25.95980225290571, 28.16048434802464, 31.116020475115093, 52.48794630595616, 88.51713180541992, 81.90562207358224, 71.26702676500592, 74.48225702558244, 73.20799214499337, 55.59947122846331, 26.595906359808787, 1.265651394213949, 10.362136040415082, 11.47945327418191, 11.655148897852216, 26.697461230414255, 36.961727551051546, 28.070124762398855, 34.71293265478951, 35.40885727746146, 27.456619671412877, 27.907536915370397, 23.696466514042445, 29.080458845411027, 24.121437447411672, 30.09209224155971, 30.147365161350795, 33.68253217424665, 35.65092556817191, 37.090262276785715, 33.315239974430625, 39.28941576821463, 26.827090297426494, 21.009099585669382, 28.363934550966533, 28.0568710735866, 22.63286927768162, 12.773783683776855, 16.123503276279994, 6.0664374487740655, 2.1953031037534987, 9.971576929092407, 18.473528214863368, 26.915370634623937, 46.311588355473106, 59.717446190970286, 53.19330658231463, 53.07663590567452, 48.88043812343052, 46.99781676701137, 55.63294070107596, 58.31209659576416, 57.191793373652864, 52.145271573747905, 54.6845463344029, 52.10383251735142, 58.269611835479736, 49.108669076647075, 45.9646509034293, 60.44146932874407, 54.29078844615391, 48.01984814235142, 52.41352762494768, 57.09368133544922, 54.384026323046, 53.16210222244263, 57.38696479797363, 53.11988844190325, 46.47412061691284, 43.0308643749782, 56.715622901916504, 54.67836938585554, 45.237924916403635, 49.441849095480784, 30.729617255074636, 12.836551104273115, 8.769712277821132, 5.059611771787916, 7.707111239433289, 6.622260766369956, 22.73702277456011, 26.933633974620275, 29.13967660495213, 31.575859206063406, 31.543737683977398, 16.333549056734356, 31.47998101370675, 29.977009228297643, 28.893686056137085, 20.48201618875776, 25.444120849881852, 26.18335359437125, 21.424037320273264, 15.890634400503975, 16.21934151649475, 18.540237869535172, 13.898518988064357, 23.354821852275304, 22.002476590020315, 27.468650477273123, 25.89882833617074, 40.42002316883632, 33.00082009179251, 34.57088368279593, 31.112000942230225, 26.26309633255005, 25.111496686935425, 12.478338462965828, 1.0973098959241594, 0.45380063780716484, 30.9331682068961, 62.21699810028076, 46.54718787329537, 63.16252980913435, 56.62768997464861, 70.27911104474748, 32.07016447612217, 23.96994239943368, 40.62061766215733, 40.675077642713276, 61.88665294647217, 72.59284033094133, 43.55713135855538, 48.57414068494524, 72.08647646222795, 24.143814120973857, 0.2753821616726262, 0.5234073655945914, 0.1577987332961389, 0.23746049510581152, 0.15227520040103368, 0.08317107028727021, 0.09998638262706143, 0.15357520564326219, 0.19391703020249093, 0.18212928915662424, 0.11056591064802238, 0.1930934108261551, 0.08042533083685807, 0.2133146364774023, 0.13075800000556878, 0.18767511871244225, 0.1766783595085144, 0.17979579365679196, 0.16943890654614993], [0.03519836966214435, 0.05187902333480971, 0.057162843378526826, 0.04288160149008036, 0.03978237922170332, 0.07418038629527603, 0.04039159171017153, 0.011977360201334315, 0.025461246259510517, 0.07444951363972255, 0.04080336068623832, 0.016732851675312434, 0.02565878815948963, 0.06864082640303032, 0.011622008867561817, 0.10917606736932482, 0.033976524868713956, 0.03468571270682982, 0.06152811699679919, 0.09974580803619963, 0.052806794443832974, 0.11209967120417527, 0.09981932730547019, 0.10408444915499006, 0.016735869459807873, 28.018016747065953, 69.74997098105294, 40.02157872063773, 41.69641767229353, 73.66364806038993, 45.72209971291678, 38.83629247120449, 27.051583119801112, 24.29863214492798, 28.616652693067277, 76.56351348331997, 75.14187036241803, 57.54500504902431, 64.0834857395717, 52.746075357709614, 41.46697425842285, 10.797746402876717, 0.5012061883296285, 3.3775964166436876, 9.082562736102513, 18.19729563168117, 16.489543063299998, 21.205568586077007, 22.0718161378588, 38.004547936575754, 25.162682328905376, 20.700846229280742, 19.92809190068926, 18.32206964492798, 14.459006718226842, 18.496432951518468, 22.24471684864589, 20.288298674992152, 23.98858962740217, 18.56156189101083, 16.855369193213328, 18.90018582344055, 22.208579267774308, 16.888003144945415, 22.17686595235552, 26.33818030357361, 25.55397186960493, 19.6355744770595, 8.793733937399727, 8.657117588179451, 5.012066117354801, 1.7107656981263841, 0.8249881714582443, 5.724758046013968, 15.922623906816755, 31.850445066179546, 51.90705953325544, 57.58379684175764, 47.08584696905953, 46.78713696343558, 40.087426798684255, 44.53068515232631, 48.09996434620449, 49.308693817683626, 49.47635037558419, 51.99431153706142, 53.15337528501238, 51.61857380185808, 40.30844552176339, 44.29585688454764, 54.55533415930611, 47.00259712764195, 43.15702976499285, 49.65359544754028, 54.41923631940569, 53.72238758632115, 52.719508920397075, 53.49837071555001, 44.19465984616961, 39.912321771894185, 43.828413350241526, 43.029846463884624, 38.249763761247905, 47.41559457778931, 29.488804476601736, 9.67010588305337, 5.914974101952144, 1.9808971115521021, 0.6647126632077354, 0.5592999139002391, 3.8682488884244646, 16.376660891941615, 22.40689648900713, 24.352122851780482, 24.335841485432216, 25.17898801394871, 21.886113371167863, 15.675115176609584, 25.075645719255718, 18.88655866895403, 18.62353461129325, 13.034777130399432, 22.744476454598562, 14.559222323553902, 10.521079557282583, 7.836560521806989, 6.7756465928895135, 11.904454605919973, 7.847428372928074, 9.896669268608093, 11.81778451374599, 15.078457730157034, 25.716177565710886, 27.414338145937236, 24.13564130238124, 19.98851864678519, 15.093929631369454, 21.34384642328535, 10.262802856309072, 2.467777362891606, 0.12450692829276834, 8.666317871638707, 44.617270129067556, 45.400147983006065, 58.82570048740932, 50.36879437310355, 56.265254565647666, 17.740239654268535, 34.02764572416033, 33.60887432098389, 28.107000589370728, 63.589218684605186, 33.98134640284947, 26.198915822165354, 50.553811005183626, 34.42228255953108, 0.15550258436373302, 0.040887275111994574, 0.03403007824506078, 0.044223380740731955, 0.14469820340829237, 0.026171918392979672, 0.04859955841675401, 0.02726181357034615, 0.06565884820052556, 0.05798568922494139, 0.06900067387947015, 0.06006936848695789, 0.03853683998542173, 0.03433934772121055, 0.0901029161842806, 0.04710681190980332, 0.06511405921940293, 0.06306942964770965, 0.06255596184304782, 0.10726561131221907, 0.03049185060496841, 0.047518462142241855, 0.03088286319481475, 0.07150415597217423, 0.0649307801255158, 0.07396570460072585, 0.02488644058550043, 0.019370592099481394, 0.015692004401768957, 0.12789337443453924, 0.017221430815490227, 0.03545857087842055, 0.06993640081158706, 0.08015929761209659, 0.060507498548499176, 0.027024073559524756, 0.021579106537891284, 0.05732369689004762, 0.05514405920569386, 0.19007148726710252, 0.038888290591005764, 0.09990367599363838, 0.0613925185586725, 0.09860884797360216, 0.08198087236710958, 42.15187208993094, 85.40837574005127, 47.03352703366961, 58.776576723371235, 81.10085391998291, 36.52918829236712, 36.17115109307425, 23.358733688082012, 28.964300598417008, 42.21319341659546, 82.67112595694405, 78.50787653241838, 63.776278087071006, 71.77680914742606, 59.37993744441441, 47.98168863568987, 8.132630211966378, 0.23578397078173502, 8.043708903448922, 12.318752237728663, 20.459245204925537, 19.765469312667847, 23.127648762294225, 27.824919360024587, 34.89614970343453, 22.821662255695887, 19.45678343091692, 18.363944700786046, 16.699125051498413, 13.535064799445015, 20.746508053370885, 25.461798804146902, 22.966011081423076, 26.193925278527395, 22.585769176483154, 21.573037964957102, 20.665307930537633, 24.859610591615947, 20.93373942375183, 23.301202603748866, 26.005193097250803, 27.295748029436382, 20.990688596452983, 13.807256136621747, 11.400077053478785, 5.659396341868809, 1.5398230765547072, 0.2763492912054062, 6.223843242440905, 21.079085315976823, 35.705576624189106, 54.239726134708945, 58.900768824986045, 53.23730952399117, 50.85160384859358, 44.73174170085362, 52.39381211144583, 55.16485793249947, 54.311639990125386, 54.6355858530317, 55.752501828329905, 55.637995515550884, 57.927503381456646, 46.88502665928432, 49.471973010471885, 58.077723434993196, 51.16058676583426, 48.042971747262136, 52.41883952277047, 57.45395238058907, 54.9323399407523, 55.28094148635864, 56.59278917312622, 48.42225653784615, 45.685413224356516, 48.03413363865444, 51.94109180995396, 43.972279276166645, 50.603931835719514, 32.79151255743844, 13.293758205005101, 10.003335407802037, 6.904406700815473, 2.435507757323129, 0.36513785113181385, 3.109166009085519, 14.51036432811192, 18.377634389059885, 21.529993874686106, 28.774852752685547, 25.778449058532715, 24.996693338666642, 23.838315725326538, 26.187730959483556, 19.954927580697195, 20.140685932976858, 14.52447177682604, 22.285612208502634, 18.794338703155518, 13.138588428497314, 13.084602662495204, 7.660276906830924, 7.086744802338736, 10.259291410446167, 12.001383713313512, 13.83812437738691, 17.79393880707877, 27.013805764062063, 26.964827912194387, 23.56746104785374, 20.19869123186384, 20.936133078166417, 24.504088640213013, 13.84192591054099, 2.147678413561412, 0.11246494017541409, 4.474698952266148, 48.23602744511196, 50.10183416094099, 63.9484474999564, 54.13626050949097, 59.336733545575825, 27.78341429574149, 22.682771239961895, 25.63066782270159, 29.130536249705724, 57.61316687720162, 49.83025687081473, 32.14693512235369, 58.86917536599295, 47.65740578515189, 0.31734928116202354, 0.11355628911405802, 0.04141476823549185, 0.09759112008448158, 0.09753048619521515, 0.07689525240233966, 0.02094988914073578, 0.018176224581631165, 0.02164934339400913, 0.03428455941112978, 0.039322254447532554, 0.008683297450521162, 0.03860262395547969, 0.07998135858880621, 0.04533481092325278, 0.0835527665913105, 0.0954176095713462, 0.03823628289891141, 0.038651885597833564, 0.06953144432710749, 0.1571478417941502, 0.07629672344774008, 0.12297604472509452, 0.11373912037483283, 0.11588747080947671, 0.1997069288045168, 0.1517520770430565, 0.11418015456625394, 0.12058549800089427, 0.19214095122047833, 0.16097142733633518, 0.10629054291972093, 0.11935292556881905, 0.12130792066454887, 0.15297243584479603, 0.11093077928360019, 0.08958708707775388, 0.11718506046703883, 0.18785012646445207, 0.3448429230068411, 0.19410719642681734, 0.23505280858704022, 0.29201310926250046, 0.23263687108244213, 0.2710040366011006, 48.00479139600481, 102.61040619441441, 57.73961019515991, 64.00284494672502, 92.25220543997628, 63.43777574811663, 51.884033203125, 32.98685073852539, 30.261478900909424, 39.05351052965437, 88.46838324410575, 88.764710017613, 70.82247407095772, 78.58750983646938, 67.30636596679688, 50.53489453451974, 12.178816386631556, 0.472246205168111, 9.04849398136139, 14.127700975963048, 24.84589832169669, 25.8581257888249, 31.559583050864084, 34.19309970310756, 43.437375681740896, 31.270221846444265, 29.87734079360962, 30.79905755179269, 28.8966737815312, 25.797700779778616, 29.24195929936, 32.24603033065796, 32.57266167231968, 34.52888182231358, 32.53624963760376, 28.647761515208654, 31.21992383684431, 33.89153398786272, 24.51966302735465, 26.6204890864236, 31.767209121159144, 33.76086269106184, 30.89433819907052, 16.53666922024318, 15.587623459952217, 9.103453363691058, 4.035241024834769, 1.4176718997103828, 8.390423144612994, 24.575503962380544, 39.541051728384836, 52.20319523130144, 62.04638508387974, 54.82534463065011, 50.96600593839373, 46.679738657815115, 51.922206606183735, 55.04523427145821, 53.453766754695344, 55.50698723111834, 57.58314718518938, 56.55208315168108, 59.49272755214146, 48.53370911734444, 48.65900250843593, 58.886045592171804, 51.406056199754985, 48.33530330657959, 55.41394737788609, 58.663383620125906, 52.90261479786464, 55.21742800303868, 58.87581784384591, 50.164583342415945, 49.71661908285958, 54.548340797424316, 60.8286576952253, 53.59003135136196, 59.550307273864746, 35.56671340124947, 18.008839641298565, 14.573641572679792, 12.168982080050878, 2.796350508928299, 0.9963628841297967, 7.705765894481114, 21.537016766411917, 27.800810847963604, 35.03739963259016, 35.663255146571565, 37.48252977643694, 32.05645568030221, 23.702367271695817, 34.573478834969656, 24.638772521700176, 25.98680990082877, 19.24273201397487, 29.285382066454204, 21.983309984207153, 19.712345123291016, 18.199887309755596, 18.883089780807495, 22.648745911461965, 16.521159103938512, 19.309222800391062, 22.87444772039141, 24.478076321738108, 36.85027844565255, 35.94265958241054, 34.97625548498971, 30.452193055834087, 25.01336554118565, 28.69296475819179, 15.838013955524989, 3.5847061489309584, 0.15905432163604669, 10.229907478604998, 57.28125490461077, 52.25800609588623, 72.49546132768903, 55.31653363364083, 67.50933674403599, 21.83176977293832, 41.02662175042288, 44.37793595450265, 39.972048486982075, 80.17581244877407, 55.56858648572649, 43.5182318687439, 72.10683468409947, 63.217219080243794, 0.9072446918913296, 0.2251236563814538, 0.20772931618349894, 0.18864398529486998, 0.3034258782863617, 0.26191435434988564, 0.11379284677760941, 0.12073229226682868, 0.19679716708404676, 0.15023671835660934, 0.22568377346864768, 0.13265738237117017, 0.08702182437160186, 0.16412031836807728, 0.09140062119279589, 0.2755436258656638, 0.115181672253779, 0.17302022794527666, 0.13758943629051956, 0.3537400913025652], [0.045224966281758885, 0.0490224723305021, 0.013764300832657941, 0.037115621247461865, 0.02328713015387101, 0.06608523960624423, 0.1246537904122046, 0.040253781247884035, 0.03364593582227826, 0.03286212609548654, 0.06451527920684644, 0.03326004956449781, 0.11937605004225459, 0.04308219340496829, 0.04414126443277512, 0.016476986297805394, 0.0771068399772048, 0.12115968790437494, 0.08145645979259696, 0.049803184544933696, 0.11313163475798708, 0.06636227866900818, 0.052803914062678814, 0.026311542240104506, 0.31245584945593563, 1.6910938279969352, 62.7765782220023, 62.99105521610805, 25.944736821310862, 55.20706129074097, 65.65891333988735, 30.13324294771467, 39.807584626334055, 27.72707482746669, 27.94405143601554, 68.49356991904122, 81.43695218222481, 61.92335333142962, 64.2548839024135, 46.27580165863037, 50.513765062604634, 1.667200492961066, 0.4363527883376394, 8.445851530347552, 13.211661764553615, 13.8236825466156, 18.529560225350515, 25.53699220929827, 28.88953103337969, 32.10451636995588, 18.57727176802499, 15.047911712101527, 10.813514471054077, 7.733421461922782, 11.838799340384346, 25.96149066516331, 24.60792773110526, 24.08240941592625, 16.003130946840557, 17.40836763381958, 16.314929621560232, 14.730999163218907, 18.007488216672623, 24.663839885166713, 43.15584509713309, 23.428107976913452, 24.396209171840123, 24.070540155683243, 17.026857682636805, 15.626378774642944, 9.004062856946673, 3.7892943365233283, 0.8434090944273132, 2.120620391198567, 15.688089200428553, 26.9708502633231, 46.95702041898455, 53.80633919579642, 55.26120860236031, 50.12556920732771, 44.50751985822405, 42.6585625239781, 47.124190602983745, 52.02676657267979, 52.109488351004465, 55.30584035600935, 55.22060332979475, 46.050579275403706, 30.690842832837784, 45.33072853088379, 55.024903842381065, 47.645149162837434, 43.8266658782959, 50.21463816506522, 54.821537017822266, 52.96267850058419, 55.78010702133179, 54.212767124176025, 46.03885071618216, 44.61547401973179, 45.65172140938895, 41.95970923560006, 39.82318680627005, 36.5670142854963, 20.649028301239014, 7.232787685734885, 2.619139526571546, 1.1386444036449705, 0.601129372205053, 0.7290731210793767, 4.468617107186999, 10.687781606401716, 20.579383032662527, 23.267625434058054, 25.168610879353114, 25.667755569730485, 36.06349917820522, 11.717290980475289, 16.002750532967703, 12.651127134050641, 15.24287816456386, 14.350845847811017, 18.926635878426687, 17.608090128217423, 11.704640916415624, 13.192578537123543, 8.844385436603002, 8.89294900212969, 10.090451921735491, 9.23751711845398, 8.062220641544886, 10.466713377407618, 16.881539583206177, 21.633575882230485, 22.390629019056046, 21.09941053390503, 14.214744533811297, 16.258091620036534, 15.135401691709246, 0.9447695783206395, 0.11807791755667754, 0.8520710010613713, 31.30986131940569, 59.62588977813721, 53.567064080919536, 61.43467957632882, 45.888978072575156, 16.38472080230713, 50.20353146961757, 21.79728933743068, 50.13828093664986, 56.73359094347273, 28.286799124308995, 25.737315722874232, 37.7673225402832, 6.264477610588074, 0.20451681927910872, 0.05985279367970569, 0.02754069655202329, 0.09539997444621154, 0.052309604694268534, 0.0398412285638707, 0.07402175159326621, 0.0741228668817452, 0.026630170410498977, 0.02946619742683002, 0.01814015196370227, 0.08645634685776063, 0.01309536793269217, 0.026332145955945765, 0.0626105431999479, 0.015928769018501043, 0.05184613813513091, 0.04979048576205969, 0.08242074626364879, 0.012837344813825828, 0.004379316324567688, 0.004512835052862231, 0.05245211740423526, 0.03246053514469947, 0.025193319922047, 0.043826610781252384, 0.09060683700123004, 0.06110770348459482, 0.043831604798989635, 0.049948570850704394, 0.047168103978037834, 0.04393280490434595, 0.09142716548272542, 0.01840784420658435, 0.0914864151605538, 0.03719676385766693, 0.11521559900471143, 0.038548883982002735, 0.1496488084750516, 0.06619713003081934, 0.03979345291320767, 0.02635403549564736, 0.040384470485150814, 0.08106975590011903, 0.26068292185664177, 5.130576763834272, 84.21207659585136, 70.86259991782052, 30.247714519500732, 71.92340224129813, 56.28277792249407, 31.245802402496338, 36.45193822043282, 26.085908583232335, 44.45991774967739, 77.45899731772286, 84.00417954581124, 70.34830120631626, 71.63614981515067, 52.648738043648855, 46.53904458454677, 0.8081317873937743, 0.66659833916596, 9.198336226599556, 16.96548077038356, 19.526161193847656, 17.407101324626378, 23.385941096714564, 32.24375132152012, 32.80686460222517, 18.36914369038173, 17.35965555054801, 12.542627538953509, 9.804434537887573, 13.698202422686986, 29.7991874558585, 25.86190560885838, 27.2615350995745, 20.84226986340114, 21.445370026997157, 21.279577323368617, 14.610269001552037, 23.068545648029872, 29.255320685250418, 33.75248316356114, 23.340722220284597, 27.694600684302195, 24.583113976887294, 21.491349731172832, 16.634385211127146, 9.366407070841108, 3.7707370008741106, 2.2757235084261214, 2.1348828715937476, 18.804172141211374, 32.01845598220825, 50.36680024010794, 55.6302204813276, 58.61393329075405, 54.01246792929513, 47.17468316214425, 47.79990986415318, 54.03376415797642, 56.05226101194109, 54.19075870513916, 56.39055837903704, 56.58488212312971, 52.538376331329346, 35.91223342078072, 48.47690759386335, 57.80353362219674, 53.274701254708425, 47.355291162218364, 52.832305976322715, 58.088923931121826, 56.55193029131208, 58.57279300689697, 60.047923360552105, 51.99390854154314, 48.82558209555489, 52.13091312135969, 50.25236688341413, 49.20944227491106, 41.50222246987479, 20.151096071515763, 9.143171003886632, 2.65033780676978, 1.4782440151487077, 1.0145615190267563, 1.9890304122652327, 3.5825932451656888, 8.612875802176339, 19.409740652356827, 23.294961384364537, 31.105657236916677, 25.353971447263444, 36.124327182769775, 19.9595741885049, 21.06907296180725, 17.09737147603716, 15.895310538155691, 15.158714635031563, 17.81463749068124, 18.466315984725952, 15.7608767918178, 16.605656147003174, 12.360569102423531, 7.406103117125375, 6.971039491040366, 9.561240639005389, 13.170059425490242, 16.01227651323591, 20.47194651194981, 24.119776827948435, 28.07102802821568, 24.522289446422032, 17.356733833040508, 18.566462108067103, 18.14627500942775, 1.3816073834896088, 0.15713817945548467, 0.3933405892125198, 30.688261577061244, 62.850646018981934, 56.419716494424, 64.62652220044816, 54.03749534061977, 21.12160655430385, 27.275309903281077, 25.203652381896973, 41.5537120955331, 64.66329206739152, 35.64960888453892, 33.99689299719674, 56.72724028996059, 8.982504333768572, 0.2681317978671619, 0.12869764199214323, 0.044653524445103746, 0.07329626873667751, 0.07756255766642944, 0.027670781893123473, 0.025159829129864062, 0.05523655031408582, 0.03904180235362478, 0.03394140050347362, 0.013197610437470888, 0.07785368311618056, 0.0282894955681903, 0.029672017454036644, 0.03815366108236568, 0.01866134997856404, 0.01623846427537501, 0.017551156426114694, 0.07488302287778684, 0.031782553132091246, 0.13390796312264033, 0.24791609549096652, 0.10943545095090355, 0.19003134513539927, 0.03730373151068177, 0.18108799574630602, 0.15093262387173517, 0.09340675747288124, 0.17134598349886282, 0.11020120486084904, 0.2211994305253029, 0.1630103165017707, 0.24099126564604895, 0.1368695513478347, 0.1683492200183017, 0.11285859226648297, 0.24743894966585295, 0.16059326619974204, 0.2551640708531652, 0.20781672506460122, 0.2919273424361433, 0.09233254154345819, 0.12005704135767051, 0.1296903658658266, 0.4772212782076427, 7.205569854804447, 102.16312980651855, 85.83214637211391, 44.89206443514143, 73.24970218113491, 81.72936017172677, 41.694889068603516, 51.461742537362234, 34.80654226030622, 38.1192626953125, 79.75648866380963, 93.95593847547258, 75.81332342965263, 81.72589302062988, 57.845969745091026, 61.70515905107771, 2.288562693766185, 1.6970103276627404, 16.588959625789098, 19.180932998657227, 23.196837186813354, 26.937392950057983, 36.66820090157645, 37.42219509397234, 39.08295004708426, 29.664837087903702, 23.352143321718486, 20.312197004045757, 17.716014759881155, 23.279343570981705, 34.66858925138201, 35.67885732650757, 34.25587667737688, 28.82354051726205, 31.215536049434117, 30.68950183050973, 24.45615996633257, 31.47053493772234, 30.584156717572892, 45.4360910143171, 31.44359677178519, 33.691304274967735, 36.404864174979075, 29.488272939409526, 25.821949992861065, 14.75179512160165, 8.216528841427394, 3.7946583458355496, 2.475364361490522, 27.682185990469797, 38.06888478142874, 51.844831466674805, 54.34730509349278, 59.11600317273821, 53.62325416292463, 47.75501755305699, 47.60488782610212, 56.3357058252607, 58.883919443402974, 56.71342379706246, 58.845426423209055, 57.32731103897095, 53.369106428963796, 40.64776079995291, 49.151681900024414, 58.96565110342843, 55.082883085523335, 49.780174255371094, 55.58507456098284, 56.63689981188093, 56.504449776240754, 59.01612976619175, 59.01214844839913, 53.76796429497855, 52.262967109680176, 53.95654535293579, 55.05280780792236, 54.86173234667097, 43.25918218067714, 21.401516471590313, 6.777630737849644, 2.0777875695909773, 1.4039457333939416, 0.9117434876305717, 1.65609900866236, 7.241348734923771, 18.046161890029907, 29.223786285945348, 35.46825395311628, 38.04890176228115, 38.17591483252389, 47.7284893308367, 17.32892714227949, 23.60431603022984, 21.39232747895377, 23.601545436041697, 21.549858774457658, 24.808657714298793, 25.444482156208583, 22.242957217352732, 24.671614919389995, 18.502651589257376, 23.978236811501638, 21.787514959062847, 16.559902259281703, 18.557292222976685, 20.17652300425938, 26.843039887292043, 32.696721758161274, 34.08210570471627, 33.874660287584575, 24.49896608080183, 22.873066765921457, 21.440949235643657, 1.5218702341829027, 0.4644848502108029, 0.9191706776618958, 39.427900314331055, 67.46587576184953, 63.584778785705566, 69.46188477107457, 57.549156597682405, 19.35520945276533, 60.1805088860648, 31.403703689575195, 62.86511216844831, 76.2149293082101, 47.067371709006174, 45.86825507027762, 74.1660236631121, 15.347768170492989, 0.4689321315714291, 0.3613634593784809, 0.2857246638408729, 0.22402057557233743, 0.17303352723164217, 0.18810130655765533, 0.3201118143541472, 0.17160529244158948, 0.12877096448625835, 0.12317480120275702, 0.12603121650006088, 0.16433796526065894, 0.10575547734541552, 0.14007590072495596, 0.11591249518096447, 0.09224243887833186, 0.14550628433270113, 0.09671995575938906, 0.25913727336696213, 0.11341106904936687], [0.04366187944210001, 0.027789113311363117, 0.10111794155091047, 0.07566236105880567, 0.04694512380020959, 0.04477347247302532, 0.012606047493006502, 0.07095498365483113, 0.014299345202744007, 0.044272303115576506, 0.06013524066656828, 0.06734691440526928, 0.09593485003071171, 0.020946674581084932, 0.04797496693208814, 0.05393721342885068, 0.058121531935674806, 0.06244582203882081, 0.17313910728054388, 0.08839245832392148, 0.043709689019513984, 0.03548309313399451, 0.13033546267875604, 0.030631255624549728, 0.07676487868385655, 0.4224788099527359, 18.149599722453527, 70.72737407684326, 43.630539076668875, 39.06775781086513, 74.4224191393171, 49.49239376613072, 31.020857947213308, 48.31174891335623, 23.19340477670942, 61.93061419895717, 69.61294555664062, 69.1994582584926, 60.577237129211426, 61.549602781023296, 33.56287029811314, 0.3448929988912174, 1.1929349132946558, 12.739827837262835, 11.469661525317601, 17.014446462903702, 21.5199294090271, 27.07332750729152, 37.25575794492449, 29.96980742045811, 18.66001786504473, 13.358739495277405, 10.692900691713605, 7.808779886790684, 17.442945344107493, 27.889975343431743, 27.942745174680436, 25.405876227787562, 15.912161656788417, 16.785619701657975, 17.807241133281163, 13.817888617515564, 15.36619826725551, 39.9985419682094, 61.92172050476074, 36.36959859303066, 22.873504502432688, 25.17692266191755, 21.905740295137676, 22.777905975069316, 10.950523393494741, 6.137396361146655, 0.4156774734812123, 1.4606582330805915, 9.457412838935852, 26.344035897936138, 42.92496688025338, 57.86258288792202, 52.92225040708269, 50.652228764125276, 45.209385190691265, 43.32721894127982, 41.75699554170881, 43.49912084851946, 48.78313207626343, 53.12071180343628, 52.57166167667934, 53.15126998083932, 30.018034866877965, 44.91825219563076, 54.97277845655169, 47.096859863826204, 41.959045682634624, 46.56934567860195, 53.61683055332729, 50.86067124775478, 54.38306399754116, 52.48743561335972, 44.70814561843872, 47.64611496244158, 46.21962547302246, 42.98832055500576, 35.6767554964338, 24.898525714874268, 12.855805431093488, 5.477476000785828, 1.0849046472992216, 0.18188881634601525, 1.4251869193145206, 1.2015558906963892, 3.196873119899205, 11.528367723737444, 19.0557473046439, 17.831273215157644, 25.37665731566293, 39.57838787351336, 45.33243778773716, 16.206918137414114, 5.161574849060603, 9.39676114491054, 9.062555398259844, 13.232938885688782, 10.155285562787737, 17.387795754841395, 13.838445731571742, 14.524495226996285, 12.088320442608424, 7.680589096886771, 10.113697120121547, 10.861835718154907, 8.184393422944204, 9.792057190622602, 19.735065732683452, 15.16485163143703, 14.445819037301199, 20.048313106809342, 23.994179453168595, 18.742001397269114, 19.265402248927526, 1.480993656175477, 0.4205191736774785, 0.09302671679428645, 13.076052035604205, 54.3312999180385, 59.630357469831196, 71.82085377829415, 29.708721910204204, 29.404988356998988, 38.39286885942732, 28.07392716407776, 65.20223603929792, 41.52456092834473, 22.014083555766515, 29.92470666340419, 6.337160978998456, 0.5955280927675111, 0.36660291680267876, 0.06219405162015131, 0.07340602856129408, 0.0642085135249155, 0.07862248364835978, 0.08551574125885963, 0.13796922591115746, 0.10099403427115508, 0.029263552943510667, 0.0744355358183384, 0.011443612681302642, 0.02279444078781775, 0.059038721291082244, 0.06455167582524673, 0.10331033569361482, 0.03469528005059276, 0.01855161559901067, 0.057985431381634304, 0.031561238757733784, 0.1087213878386787, 0.04608082964218088, 0.07231077126094274, 0.022516307587336217, 0.08018550263451678, 0.06999558263591357, 0.040536716779960055, 0.04334908836920347, 0.01325811625325254, 0.040437844049717696, 0.09139948803931475, 0.042441632598638535, 0.04398346432883825, 0.06818974310798304, 0.04856450190501554, 0.051383224582033496, 0.07545833236404828, 0.04406102427414485, 0.022530967336414114, 0.05135073632534061, 0.12538993305393628, 0.020613636023231914, 0.025455795926973224, 0.04831262970609324, 0.046207956570599756, 0.025088791602424214, 0.3663234146577971, 29.128780092511857, 90.16535568237305, 41.29174416405814, 51.451650278908865, 77.32229151044572, 34.799778188977925, 31.58937692642212, 32.52559110096523, 31.63835825238909, 77.96265138898576, 77.93026583535331, 74.20597580501011, 67.37679290771484, 66.01138850620815, 29.277019909449987, 0.39475731604865616, 2.323423760277884, 12.207568900925772, 16.030651024409703, 18.713961941855295, 21.428385155541555, 26.27201608249119, 33.283066340855186, 30.915373870304652, 23.421050344194683, 15.776447704860143, 13.329155802726746, 8.608543600354876, 19.54889222553798, 30.080030168805802, 31.03628294808524, 29.444172722952707, 20.57032952989851, 20.547740936279297, 20.22868660518101, 15.888150419507708, 21.792788641793386, 39.88603326252529, 46.859988825661794, 29.112126997538976, 25.77932279450553, 25.638465438570293, 27.43599741799491, 19.99495788982936, 11.56449053968702, 6.3588250279426575, 0.6847800921116556, 0.6818200509463037, 12.656255773135594, 29.593743119921, 43.712579931531636, 59.29280703408377, 57.01951626368931, 55.42279938289097, 48.69838489804949, 46.42539984839303, 47.016882623944966, 50.47710984093802, 52.76004123687744, 58.9517616544451, 59.08637605394636, 56.4400087084089, 33.8729510307312, 50.468153612954275, 59.52381379263741, 52.262081214359824, 45.47546992983137, 52.60652773720877, 58.64612429482596, 55.82040657315935, 58.336109570094514, 56.04383979524885, 48.886656761169434, 49.95457751410348, 54.58033377783639, 51.53089100973946, 43.73216690335955, 27.99393081665039, 18.001106296266826, 6.608025644506727, 1.0464970682348524, 0.5050173838223729, 2.1771155425480435, 1.99835923739842, 4.2279679860387525, 8.5908282995224, 17.941150290625437, 18.522473062787736, 24.802100351878575, 31.56846284866333, 36.60932534081595, 23.791010652269634, 12.384592499051776, 12.359442625726972, 10.432911259787423, 12.370938420295715, 9.374133467674255, 17.521063940865652, 16.26543412889753, 18.032673699515207, 16.537421362740652, 9.178456561905996, 5.190534940787724, 5.948429243905204, 7.535804271697998, 16.36233196939741, 19.99410673550197, 18.222302198410034, 21.1329060622624, 22.886240550449916, 30.359820229666575, 23.007512671606882, 21.756267172949656, 1.7572436098541533, 0.9836306359086717, 0.07154798254902874, 11.370578476360865, 58.86502729143415, 66.70989091055733, 66.91786439078194, 44.239454882485525, 23.168266194207327, 29.68441711153303, 29.15033687864031, 60.784765924726216, 59.19426073346819, 33.925726073128835, 44.15783439363752, 23.057605709348405, 0.8392849043011665, 0.4834936559200287, 0.023054273898846338, 0.09629620385489293, 0.02381832298955747, 0.023947473648669462, 0.10396652655409915, 0.07301353676510708, 0.12755114851253374, 0.037166226389152665, 0.04124508698337844, 0.00915737375284412, 0.028779163757073026, 0.03621848260185548, 0.06358319600777966, 0.03990723305780973, 0.03613274630957416, 0.009860276660349752, 0.01916148796278451, 0.03726714490247624, 0.06872314627149276, 0.12655591405928135, 0.16026040406099387, 0.22572049578385694, 0.16293209498482092, 0.15509779751300812, 0.09610683151653834, 0.07122343246425901, 0.210926708898374, 0.1033643674371498, 0.22875179669686727, 0.12488093679504735, 0.2138716730156115, 0.19676941500178405, 0.15753969576741966, 0.21911342388817243, 0.2378741843359811, 0.1725428378475564, 0.24767166003584862, 0.273885611976896, 0.2690403291157314, 0.24654909170099668, 0.14483761521322386, 0.1831633493836437, 0.1375090977443116, 0.16318274582070963, 0.5710020916802543, 38.754070963178364, 109.79239082336426, 60.979961667742046, 64.40344333648682, 90.6356167112078, 65.40175356183732, 42.55754266466413, 57.14253759384155, 28.103060960769653, 73.86497906276158, 82.43162849971226, 79.98897538866315, 75.20313957759312, 74.34783717564174, 40.77552774974278, 0.2442516806934561, 3.876928925514221, 19.745550564357213, 17.271710463932582, 29.22626679284232, 30.623719760349818, 39.12063012804304, 45.58337197984968, 39.91265181132725, 29.71324518748692, 24.282189232962473, 18.865623746599468, 17.817767654146465, 28.837773902075632, 35.38646323340279, 36.73984725134713, 37.018219879695344, 30.002575125013077, 30.98422704424177, 34.92592968259539, 22.085615260260447, 26.284168481826782, 45.336780411856516, 63.679892676217214, 44.00112124851772, 33.8471280506679, 36.63392196382795, 36.87472915649414, 35.99376358304705, 16.261841910226003, 9.331812858581543, 1.0868902036121912, 1.9495605187756675, 10.676231094769069, 36.16460936410086, 45.38549075807844, 60.3734256199428, 54.92466218130929, 55.69070107596261, 48.79154634475708, 46.54282093048096, 46.27903604507446, 50.40322617122105, 53.71355642591204, 58.55966785975865, 57.219200542994905, 60.63105092729841, 37.638475145612446, 52.426631927490234, 59.33519799368722, 54.378412178584504, 45.248969078063965, 52.750869614737375, 59.040107999529155, 56.76045615332467, 58.1556579044887, 54.18174341746739, 47.50633110318865, 53.31529263087681, 56.46617215020316, 55.416063104357036, 47.29309436253139, 27.837572029658727, 19.305015666144236, 9.955156598772321, 1.2361705132893153, 0.30357922720057623, 2.263180924313409, 3.578062802553177, 8.427644644464765, 17.95940147127424, 27.796457801546367, 29.663596834455216, 37.59685543605259, 51.21955960137503, 52.79239899771554, 26.065739699772426, 16.68525297301156, 19.93498625074114, 16.867309672491892, 22.027755873543875, 17.867982285363333, 26.95284574372428, 23.581253222056798, 23.941788298743113, 20.990483624594553, 21.74804745401655, 22.94560422216143, 23.4639242036002, 14.23507148878915, 20.072828088487896, 29.53696938923427, 25.593055486679077, 22.81261396408081, 32.369388648441856, 34.48780059814453, 29.899908542633057, 24.91381001472473, 2.148275090115411, 1.0683609864541461, 0.18077059063528264, 14.308784059115819, 70.01550333840507, 68.60596397944859, 78.43487875802177, 39.91819994790213, 38.825098923274446, 48.00984273638044, 39.46140800203596, 79.57774625505719, 70.06203542436872, 43.43440185274397, 63.58814866202218, 40.1012293951852, 1.0613124732460295, 0.46826993567602976, 0.18143901548215322, 0.2319694911795003, 0.121245305453028, 0.20917566785854952, 0.21723005494901113, 0.3046446900282587, 0.2207341862044164, 0.16107913798519544, 0.1406548810856683, 0.06326847111007997, 0.19752907566726208, 0.14837005494960717, 0.21395055949687958, 0.2731582767197064, 0.15453706974429743, 0.07600255137575523, 0.14605243716921124, 0.09155430937451975, 0.18859802133270673], [0.043432571925222874, 0.10871459570314203, 0.08458993450871535, 0.061132327520421574, 0.0913245574172054, 0.009612750478221901, 0.05969482394201415, 0.06219625685896192, 0.05986717862210103, 0.05540366331115365, 0.03364371701276728, 0.04258820294801678, 0.07395262244556632, 0.061988163739442825, 0.0336414982032563, 0.07521648212735142, 0.034758485587579865, 0.07277625985443592, 0.0497684910494302, 0.05027591310707586, 0.05445449460031731, 0.10691040501530681, 0.019153940957039595, 0.04135783914742725, 0.05179169248523457, 0.09051611686923675, 0.6011875633682523, 31.12968758174351, 52.482207093920024, 36.250106947762625, 55.88962452752249, 78.94057559967041, 38.766907760075156, 48.85027599334717, 36.223200048719136, 37.99078702926636, 55.45643213817051, 71.50259849003383, 67.8509657723563, 49.05161394391741, 5.243114565099988, 0.7365609449999673, 2.9316202104091644, 10.461557814053126, 21.955713476453507, 20.50772452354431, 17.131553139005387, 26.064125980649674, 32.56654725755964, 28.70455261639186, 16.40086841583252, 12.176414046968732, 9.380377292633057, 11.358760459082466, 27.40923121997288, 28.342574051448278, 29.610495226723806, 21.385181256702968, 15.054498604365758, 15.879838636943273, 12.324049370629446, 12.963917664119176, 15.398265940802437, 51.926073278699604, 72.4486791065761, 45.899987493242534, 23.99979359763009, 27.4542954989842, 28.360446555273874, 28.208849021366664, 16.18993500300816, 6.062738835811615, 3.8580354707581654, 0.9541679940053395, 1.1674451210669108, 17.56482890674046, 37.84224843978882, 50.954270430973594, 59.046368326459614, 55.12709099905831, 50.16833189555577, 44.80408634458269, 44.19987794331142, 44.385988916669575, 48.25950540815081, 54.326154776981895, 54.06317588261196, 62.18049921308245, 31.605666978018625, 37.76070090702602, 56.48766987664359, 49.50986153738839, 42.936070101601736, 44.6141608101981, 50.75446803229195, 50.948030948638916, 55.44321666445051, 53.22649465288435, 43.89995200293404, 47.25627933229719, 47.483183179582866, 44.71773760659354, 35.95484324863979, 26.372792754854473, 20.33786886078971, 12.678232925278799, 3.316051879099437, 0.29209084223423687, 1.2917572962386268, 1.7321606129407883, 3.1409789877278462, 8.376967089516775, 20.620523316519602, 18.27895086152213, 32.918456145695274, 44.15799420220511, 47.76968172618321, 27.980272395270212, 6.994500083582742, 7.509757212230137, 3.9480198536600386, 7.776491607938494, 6.635165308203016, 9.21555038860866, 14.861039910997663, 14.69182174546378, 13.756605505943298, 10.886032819747925, 5.6968466980116705, 9.765676617622375, 16.47860312461853, 14.085407291139875, 18.737594502312795, 15.237399509974889, 18.46465710231236, 23.562494822910853, 16.32791927882603, 14.071162615503583, 14.04271147932325, 2.2393978919301714, 0.1849347057619265, 0.05841315271598952, 2.784475169011525, 44.9714024407523, 56.45340830939156, 66.17430986676897, 24.49010365349906, 34.3563163621085, 28.272273915154592, 46.74261638096401, 59.18561717442104, 25.85190715108599, 16.179632561547415, 22.879643235887798, 2.155777624675206, 0.14826317211346968, 0.06987502731915031, 0.04380435483264072, 0.055905724942151985, 0.04556175713826503, 0.038268927218658585, 0.07254204992204905, 0.08090168956135001, 0.045113974916083474, 0.06420904278223004, 0.04124418792447873, 0.03045804938301444, 0.04406931936474783, 0.052403999093387804, 0.05455737068716969, 0.0501978781872562, 0.09525754316044704, 0.006149880513216236, 0.03197389661467501, 0.017128756502643228, 0.11485516120280538, 0.07009142570729766, 0.10531532524951867, 0.07491555184658084, 0.08554491826466151, 0.07449856493622065, 0.029533942363091877, 0.0042528946484838214, 0.07452040697847094, 0.049897260032594204, 0.018523936459262456, 0.026002637476527264, 0.06351052490728241, 0.07851243883903537, 0.08536066886569772, 0.03549240602712546, 0.05226134049839207, 0.011423981815044369, 0.04602698788845113, 0.01947285920115454, 0.06847327575087547, 0.10796245320567063, 0.01838253654672631, 0.05814851048801627, 0.059443684560911994, 0.04518362992842283, 0.14718636418027536, 1.5346313608544213, 58.929103578839985, 66.85298211233956, 39.09054790224348, 71.78354890005929, 63.88814408438546, 33.2794463293893, 30.53732933316912, 31.215376240866526, 56.788460867745535, 64.83345345088414, 79.74641377585274, 70.3332097189767, 52.91630274908883, 4.374945402145386, 0.42155127972364426, 2.960858230079923, 12.96138504573277, 24.957955394472393, 24.239921603884014, 19.476189749581472, 25.982951913561138, 33.318936416081016, 25.918040105274745, 19.173100641795568, 15.726604802267891, 11.491494502340045, 9.771724155970983, 29.23229088102068, 30.81295394897461, 34.3022072655814, 25.845440115247452, 20.506838628223964, 18.91330749647958, 14.169394510132925, 16.807508264269146, 20.461291449410574, 47.61352791104998, 56.3921251978193, 34.6384722845895, 23.328934601375035, 26.572548253195627, 27.166539328438894, 20.759603670665197, 9.265484486307416, 4.571323207446507, 4.1392950756209235, 1.9313534157616752, 3.3743859146322523, 25.110273803983414, 42.051974364689414, 56.13494110107422, 62.08505180903843, 59.27838257380894, 52.21893637520926, 50.64309883117676, 46.88028103964669, 51.28213160378592, 49.556695869990754, 57.4649201120649, 56.132922649383545, 64.99715300968715, 35.23958873748779, 44.10549708775112, 58.565344538007466, 52.39863763536726, 47.16019269398281, 49.59696415492466, 55.11621012006487, 54.80316250664847, 61.48274026598249, 57.96310942513602, 48.073248522622244, 52.7520820753915, 52.63966717038836, 51.36453723907471, 43.70214373724801, 32.34280831473214, 19.75149474825178, 10.469272920063563, 1.9772929506642478, 0.7569056504539081, 2.1642099150589535, 1.3895316954169954, 3.923921763896942, 8.144569822720118, 21.920706714902604, 19.09338222231184, 32.05314833777291, 36.18151780537197, 37.07054328918457, 30.696661949157715, 12.61740665776389, 11.78793157849993, 6.5937635983739575, 6.1833764995847424, 6.964968936783927, 11.562474693570818, 16.62670224053519, 17.73236734526498, 19.59290211541312, 16.359736817223684, 8.427450094904218, 5.60539494241987, 8.915277906826564, 11.813559140477862, 17.511294773646764, 20.31377945627485, 26.078350680215017, 29.599805423191615, 22.32067108154297, 20.42437219619751, 16.62725635937282, 1.6461139044591357, 0.6101288092987878, 0.037382614599274736, 2.7561953493527005, 44.9547232900347, 63.28141348702567, 68.4221910749163, 38.672665868486675, 25.24295834132603, 26.90406938961574, 41.54800762448992, 71.1942582811628, 42.048861571720664, 24.779179981776647, 45.46468979971749, 5.218339025974274, 0.17849800043872424, 0.24434303864836693, 0.09092445245810918, 0.09932479741317884, 0.0768696784174868, 0.06072302162647247, 0.06788822928709642, 0.027170754170843532, 0.039735102294279, 0.0535539056041411, 0.061733699536749294, 0.007042167209354895, 0.0498384751512536, 0.06057499921215432, 0.05021473299711943, 0.038998521997460296, 0.08419115947825567, 0.020787754894367287, 0.04666842400495495, 0.044018948317638466, 0.02041359881072172, 0.17371290363371372, 0.2078691893922431, 0.3014517213617052, 0.30182646268180435, 0.1448718812316656, 0.0865514978234257, 0.0999501013596143, 0.16285440272518567, 0.17913108718182358, 0.11200129719717161, 0.18244250092123235, 0.174140991376979, 0.2431124203971454, 0.14115888332681997, 0.2415150132562433, 0.1796148419380188, 0.11524329680417265, 0.1984187165009124, 0.08013796447111027, 0.17985110783151217, 0.21136626388345445, 0.20660663928304399, 0.14401774135019096, 0.1831832711717912, 0.09162905679217406, 0.20246783351259573, 3.035372883081436, 81.19281332833427, 86.64527320861816, 56.477671418871196, 79.66465432303292, 96.6116303035191, 55.04353543690273, 58.656497955322266, 46.126040186200825, 48.915186064583914, 67.86670344216483, 83.83360821860177, 77.27795505523682, 60.36085632869175, 7.591707740511213, 0.49778007503066746, 5.7250728862626215, 15.617139407566615, 30.244421073368617, 32.137704440525596, 25.023367473057338, 35.364041396549766, 44.56659344264439, 39.26278332301548, 29.376000472477504, 23.856940371649607, 18.635049513408116, 23.099994931902202, 37.56092282703945, 38.24960742677961, 37.98709406171526, 33.40028592518398, 27.84010464804513, 30.767596108572825, 26.246920926230295, 23.656255551746913, 24.319223131452286, 57.50037676947457, 72.6867174421038, 51.7114052091326, 34.761900084359304, 37.54257958275931, 38.32164287567139, 37.385915075029644, 24.059608902250016, 9.332078627177648, 4.336256095341273, 3.029342932360513, 3.216242960521153, 25.988503524235316, 43.77205651147025, 56.863734177180696, 59.82260022844587, 62.36063820975167, 51.43077094214303, 51.01249980926514, 48.24466405596052, 53.4891608783177, 52.086455072675435, 56.60312114443098, 58.165583406175884, 65.7323557989938, 39.19612577983311, 44.87912688936506, 59.674610546657014, 56.58238771983555, 48.770969254629954, 50.77448231833321, 55.84852940695626, 55.76192705971854, 62.30626160757882, 61.03963279724121, 47.280670983450754, 52.63081863948277, 53.3717919077192, 53.11354126249041, 53.24903113501412, 36.56311287198748, 27.547022683279856, 16.927427223750524, 5.003181976931436, 0.836596168577671, 2.95451865025929, 3.292225637606212, 7.0531011904988965, 18.356482335499354, 34.644729137420654, 28.919955457959855, 45.12138625553676, 53.881463118961875, 55.67336532047817, 38.5266112600054, 17.958341870989116, 22.192516769681657, 13.595257912363325, 15.2758195740836, 14.121266944067818, 17.91174725123814, 23.143502814429148, 23.327605758394512, 23.317982503346034, 24.338591235024587, 20.678922925676616, 22.719792979104177, 29.494700023106166, 24.970507315226964, 30.229496342795237, 23.08119136946542, 27.63104030064174, 32.335439750126426, 25.632192952292307, 21.85693441118513, 21.260963099343435, 3.140085058552878, 0.4426182178514344, 0.16653654085738318, 3.7094122001102994, 52.56797913142613, 64.59860433850969, 78.03512804848808, 31.87895699909755, 39.790578910282676, 37.8756171635219, 60.94626290457589, 83.19679192134312, 50.28047929491316, 37.086822918483186, 68.1127461024693, 9.799659388405935, 0.4220960076366152, 0.3903841035706656, 0.18583873153797217, 0.2875197689448084, 0.11759409494698048, 0.14489344507455826, 0.2758841961622238, 0.2944450059107372, 0.16249260785324232, 0.12856097146868706, 0.1429992060043982, 0.08206036274454423, 0.10435374613319125, 0.15501946743045533, 0.1277540304831096, 0.14691177462892874, 0.1928533994193588, 0.13883123679884843, 0.1718730695013489, 0.11726938879915647, 0.10557567913617406], [0.06575331384582178, 0.047010979016444514, 0.022709488203482966, 0.030473659081118445, 0.06583149465067045, 0.01244097773451358, 0.09153205342590809, 0.03259450849145651, 0.0636642538011074, 0.05662622735170381, 0.02535129474875118, 0.02556574234871992, 0.02445750806613692, 0.09800233266183309, 0.02313492457116289, 0.019959382380225828, 0.06001420358994177, 0.07555171913866486, 0.025422807250704085, 0.009241547718245004, 0.08219187640185867, 0.08927901182323694, 0.06467421924961464, 0.05168545425736478, 0.08165786934218236, 0.03979610937780567, 0.14295957955930913, 1.5697056502103806, 33.72160884312221, 38.07789659500122, 34.34056479590279, 75.64668478284563, 54.576790196555, 42.432388237544465, 41.03218725749424, 29.222813538142614, 59.466303552900044, 66.00236974443708, 78.6741052355085, 24.403699329921178, 0.50981326933418, 0.077387780616326, 2.5340373388358524, 13.39846408367157, 19.34190365246364, 20.41591623851231, 21.512724127088273, 26.57581911768232, 29.72415038517543, 27.80411297934396, 19.711554765701294, 12.514875565256391, 13.955993618283953, 17.441451481410436, 34.69707339150565, 26.56647900172642, 28.121091536113195, 16.059895992279053, 9.002830420221601, 9.220355067934308, 7.054622411727905, 11.003310595239912, 14.578441040856497, 44.122249194553916, 60.292360986982075, 46.0961594581604, 27.742899349757604, 23.848555632999965, 30.01012086868286, 29.251051017216273, 13.336647697857448, 4.900691270828247, 5.853699675628117, 2.8960284973893846, 0.35988544725946015, 0.7899129592946598, 21.302389996392385, 46.22455174582345, 51.72949137006487, 54.337431703295024, 51.39778784343174, 48.89891338348389, 47.22517572130476, 44.080626010894775, 47.30457626070295, 54.727482727595735, 54.19983652659825, 62.5498446055821, 34.854286806924, 25.155206067221506, 59.92466231754848, 47.22102069854736, 48.75464793613979, 42.04852110998971, 51.786793163844514, 52.452117919921875, 55.937483719417024, 51.434095655168804, 44.884970324380056, 46.70205627168928, 45.20676919392177, 48.901022161756245, 46.22633048466274, 40.33813170024327, 29.913030215672084, 13.543198534420558, 3.4343883863517215, 0.31357309807624134, 4.259512807641711, 2.387954503297806, 3.1368302617754256, 12.1437166929245, 21.9718975680215, 16.777594532285416, 37.74947609220232, 46.057979106903076, 45.11427130017962, 29.229702677045548, 10.820765784808568, 5.76401059116636, 2.0105546287127902, 2.817077419587544, 3.7212323887007575, 3.6588254060064043, 11.85991404737745, 12.86588031905038, 19.213485309055873, 12.711839624813624, 5.118484726973942, 5.499419280460902, 11.829683303833008, 27.208735738481792, 25.760547024863108, 15.56816850389753, 22.52051864351545, 20.96646022796631, 23.835868222372874, 7.652935266494751, 8.426309721810476, 2.28501780969756, 0.9260522169726235, 0.06259355268308095, 0.5698943425502095, 25.449194771902903, 71.6130678994315, 49.328801904405864, 18.453800542013987, 29.76672199794224, 39.11897645677839, 56.09797668457031, 44.191956996917725, 15.04691117150443, 21.658295835767472, 17.115646975381033, 1.1403189195053918, 0.19327818948243344, 0.0608765808865428, 0.10259051181908165, 0.015088649366849234, 0.04350794020241924, 0.05904764402657747, 0.08611306920647621, 0.06315160023846797, 0.0026411928951607217, 0.06165873498788901, 0.04282789883602943, 0.06769806306277003, 0.01728301465378276, 0.013571842856306051, 0.08611178677529097, 0.06321909411677293, 0.07398029988897697, 0.06112394082759108, 0.04384183371439576, 0.02701026028288262, 0.016277373169681857, 0.018056771884273206, 0.04542166340563979, 0.02615561998183174, 0.0671724426959242, 0.10714432996298585, 0.048615829686501195, 0.05185249600825565, 0.013569804706743785, 0.023236816782238226, 0.024922743905335665, 0.06873005375798259, 0.02892079097884042, 0.042316605736102374, 0.024283913363303457, 0.05043602701542633, 0.0814987528803093, 0.10698188867952142, 0.11803033868116991, 0.13031752221286297, 0.04592983524448105, 0.013929926989866155, 0.026800036563404968, 0.029111720555062805, 0.04771164784740124, 0.024593627279890434, 0.03672815061041287, 0.02466391841880977, 7.061061220509665, 65.72967379433769, 43.47106054850987, 51.18002782549177, 74.84017263139997, 46.9218555859157, 36.33999579293387, 26.842947823660715, 46.1637932232448, 66.94337122780937, 69.72142083304269, 82.99155603136334, 27.86442855426243, 0.39303937394704136, 0.1293573815907751, 3.2891013366835455, 15.559523207800728, 25.75706250326974, 27.933524915150233, 22.11380410194397, 32.206512451171875, 35.32198395047869, 29.559769902910503, 21.413038321903773, 14.286271895681109, 9.43715797151838, 19.06957595688956, 38.56411068780081, 29.66759899684361, 33.459939684186665, 20.29288796016148, 13.112269520759583, 12.765107989311218, 10.92656513622829, 14.07883255822318, 18.77901792526245, 43.08915628705706, 54.459775584084646, 38.517446586063926, 25.54038987840925, 25.635000024523052, 29.276008946555002, 19.97584339550563, 6.998992962496621, 6.786321197237287, 5.706789570195334, 2.928463339805603, 0.6541948275906699, 3.727720703397478, 29.65090594972883, 51.5846665927342, 53.87238877160208, 60.11049883706229, 55.090230805533274, 50.62130928039551, 49.526377405439106, 50.57624326433454, 51.712756633758545, 59.32942404065813, 56.708650384630474, 67.79321234566825, 37.21797711508614, 30.888800484793528, 62.9462045942034, 53.134479658944265, 52.73542029517037, 49.597325461251394, 57.312671184539795, 58.20846768787929, 61.97233813149588, 55.81237098148891, 47.367151737213135, 50.75716740744454, 51.225437777382986, 52.603460107530864, 45.68069192341396, 42.582781996045796, 32.23008074079241, 13.24446073600224, 4.265433975628444, 1.3155926572425025, 4.5265138404709955, 0.8135765152318137, 4.0828552927289685, 13.630909987858363, 26.723768847329275, 16.488655430930002, 33.36878626687186, 36.46082149233137, 37.26817784990583, 29.53743839263916, 15.201842103685651, 9.158316339765276, 4.938346598829542, 3.4196586396012987, 4.708776814596994, 6.819584395204272, 16.837793724877493, 18.36742922237941, 25.72605095590864, 18.0738365650177, 10.704040391104561, 9.121736679758344, 13.061622364180428, 18.134857382093156, 19.5468008177621, 19.059843267713273, 25.917670113699778, 24.545399154935563, 24.76826957293919, 11.327425820486885, 11.130707553454808, 2.9013849071093967, 1.4226408387933458, 0.06628293078392744, 0.3050907046667167, 23.782113483973912, 73.28902898515973, 63.071612630571636, 25.604542595999582, 18.227421283721924, 34.60931069510323, 55.43700497491019, 63.698493003845215, 32.21745933805193, 38.79609366825649, 31.447790009634836, 2.5193531896386827, 0.22345104041908467, 0.057728409101920466, 0.05273618269711733, 0.017335728343044008, 0.03928290620180113, 0.060793555341660976, 0.10603919997811317, 0.04586737270333937, 0.04926181198762996, 0.015310723700427582, 0.02157331015249448, 0.026502755104697177, 0.05085949732788971, 0.11330609968198196, 0.04078394779935479, 0.06525100794221673, 0.06510814917939049, 0.08785288049174206, 0.03360958330865417, 0.04616804174812777, 0.040612814482301474, 0.14677909389138222, 0.15951214278382914, 0.16757350521428244, 0.14978581826601708, 0.24761346887264932, 0.11318939844412462, 0.19659496364848955, 0.0674181877236281, 0.16812059442911828, 0.13200298962848528, 0.20193370431661606, 0.12321509261216436, 0.25093598344496315, 0.13091399520635605, 0.11577319194163595, 0.11465583475572722, 0.15010819025337696, 0.16455382082079137, 0.1608749803687845, 0.08053858511682067, 0.2569275562252317, 0.20036693981715611, 0.16225011300827774, 0.16527445215199674, 0.1656225813286645, 0.14735062393758977, 0.32184859258787973, 14.24816015788487, 85.04774338858468, 63.49278463636126, 62.23773847307478, 98.44644110543388, 70.88806506565639, 56.56923825400216, 51.01973983219692, 35.870877742767334, 73.29716532570976, 78.42521381378174, 91.0307399204799, 31.906162670680455, 0.977950917822974, 0.1377572515713317, 4.301417827606201, 20.375641005379812, 27.569519213267736, 31.34295211519514, 34.38763536725725, 40.01345975058419, 40.62307037625994, 41.30496311187744, 32.90743630273001, 21.250636339187622, 24.926985536302837, 30.47206837790353, 46.76048367364066, 36.43833712169102, 37.86604601996285, 28.416666167122976, 25.72102393422808, 24.951620374407085, 18.987762655530656, 18.695099319730485, 22.708392722266062, 50.30773707798549, 63.54683467320034, 52.83012771606445, 38.0370203426906, 32.157496384211946, 40.30643054417202, 38.562561239515034, 18.293701887130737, 7.76588431426457, 9.001767345837184, 3.943649002483913, 1.1776259690523148, 4.784320669514792, 27.44237412725176, 55.95685182298933, 51.21345213481358, 62.91237381526402, 54.893721852983745, 54.36300802230835, 49.963710921151296, 53.317095688411165, 51.8446820804051, 60.86107798985073, 58.638335364205496, 65.1446007319859, 38.83896752766201, 32.364142758505686, 63.76161738804409, 53.798088209969656, 56.24845034735543, 50.95940167563302, 60.286614826747346, 59.974126543317524, 62.505925042288645, 53.859253202165874, 47.05768592017037, 51.72619792393276, 48.34647600991385, 56.8446683202471, 56.04592078072684, 49.73333992276873, 36.20794875281197, 18.136387722832815, 5.7954993929181775, 1.7431181392499377, 7.566755890846252, 4.636116027832031, 6.6459245937211175, 22.54088728768485, 31.777516773768834, 24.62710302216666, 47.55727876935686, 54.58323812484741, 51.001504284994944, 38.91101687295096, 21.92242291995457, 19.625747987202235, 12.161657810211182, 12.888898832457405, 12.44000438281468, 13.91657735620226, 23.869629519326345, 25.112634454454692, 31.540749958583287, 23.81225998061044, 18.1636837209974, 15.476709365844727, 26.738168988909038, 41.30083588191441, 37.980760778699604, 25.406164578029088, 32.08026020867484, 25.73911530630929, 31.730453150612966, 13.68434945174626, 12.785645127296448, 3.5875182151794434, 3.5519849104540686, 0.1499333724911724, 0.9916613421269825, 30.29719958986555, 83.91931424822126, 59.55453177860805, 21.957295928682598, 37.89086498532976, 55.59202970777239, 71.9097420828683, 74.71985067640031, 39.09505728312901, 61.4200953074864, 45.816536154065815, 2.4262041194098334, 0.3766511247626373, 0.1727045734546014, 0.19886904662208899, 0.14081948011049203, 0.12234654064689364, 0.2068815002483981, 0.21032131995473588, 0.1736996043473482, 0.1169549421008144, 0.14179587843162672, 0.14015874985073293, 0.13190635267112935, 0.09750515648296901, 0.1961605248174497, 0.2427000068128109, 0.09628569334745407, 0.1988225398319108, 0.19122429112238543, 0.1411355688635792, 0.14486675150692463, 0.07467932666518859], [0.05020441247948578, 0.1505015098622867, 0.051614255577858, 0.10112997876214129, 0.008989807833651347, 0.056414124090224504, 0.08628266903438739, 0.03737579532233732, 0.09456981399229594, 0.06926250697246619, 0.05782399432999747, 0.03151915262320212, 0.030434673851622, 0.03587837710178324, 0.022367861088631407, 0.024578602818240012, 0.01874637550541333, 0.04869995785078832, 0.06521684370402779, 0.017366438837988035, 0.10057612455316953, 0.02675309551081487, 0.051843040622770786, 0.010858479704308723, 0.06721658818423748, 0.01015002722851932, 0.1168097627482244, 0.4976415996040617, 12.313698291778564, 42.489773409707205, 33.90515940529959, 67.98058441707066, 73.02138437543596, 35.38636943272182, 51.01811395372663, 27.926277944019862, 51.188897200993125, 66.78432001386369, 69.01756831577846, 7.90805401120867, 0.15186714301151888, 0.7719525173306465, 0.7640459558793476, 18.454945257731847, 13.677921499524798, 19.99661156109401, 26.021464041301183, 17.613593101501465, 22.150735514504568, 20.208309275763376, 15.487088237489973, 14.151288373129708, 14.05082436970302, 22.52830583708627, 41.64264556339809, 30.51754433768136, 25.202587570462907, 9.133144753319876, 7.806849156107221, 7.4546284675598145, 5.127828317029135, 7.252981322152274, 8.91445541381836, 33.540570054735454, 48.80899327141898, 39.102384158543174, 25.07948807307652, 20.42331259591239, 26.30700547354562, 20.08131010191781, 7.404366067477635, 5.41578164270946, 9.491403426442828, 4.361732968262263, 1.3916657694748469, 2.062200588839395, 3.0612223531518663, 20.175289699009486, 43.596187182835166, 51.01128734861101, 54.932996545519146, 54.635137694222585, 47.14752265385219, 51.61852169036865, 46.94393001283918, 51.42191546303885, 53.93945278440203, 61.049103191920686, 41.792712756565635, 16.53313258716038, 59.67113644736153, 49.31787933622088, 50.17293855122158, 43.323710100991384, 49.11145877838135, 50.57028865814209, 53.1697348185948, 48.07115364074707, 43.17345183236258, 49.72273349761963, 50.06976475034441, 54.679032938820974, 56.21239267076765, 47.49005494798933, 33.69361802509853, 11.159758840288434, 2.7634340694972446, 0.06199642829596996, 1.4066921174526215, 0.4390070544821875, 3.955543884209224, 22.0885717187609, 18.54392910003662, 17.81091151918684, 37.02626589366368, 44.21176631110055, 39.38152456283569, 28.13473779814584, 11.551636372293745, 5.310854724475315, 2.9111171620232716, 2.0961805369172777, 2.062940789120538, 2.6376803602491106, 6.724346305642809, 11.967509508132935, 14.69352752821786, 24.10320016316005, 15.124765736716133, 7.007816740444728, 9.994949800627571, 15.666320494243077, 28.657244069235666, 37.98963015420096, 36.972327028002056, 32.07891225814819, 28.548787900379725, 13.267642532076154, 4.8055265716144016, 0.35896630372319904, 2.061491438320705, 0.14557104371488094, 0.24598406202026776, 13.10830123083932, 65.98865400041852, 38.89155844279698, 20.626366751534597, 41.217242104666575, 44.32177366529192, 55.55930369240897, 29.53127534048898, 14.427001578467232, 32.051025663103374, 7.758430634226118, 0.16402929968067578, 0.06311926804482937, 0.04837408462273223, 0.16615200149161474, 0.07745433133095503, 0.08626965473272971, 0.06294687265264136, 0.03980865888297558, 0.03278484774221267, 0.00693471822056121, 0.028802580000566583, 0.036045361177197525, 0.05565913174567478, 0.020702758205256293, 0.0327342765272728, 0.055961944961122105, 0.04108608926513365, 0.03951312634827835, 0.032790147100708315, 0.03227990912273526, 0.026593673708183423, 0.039451016645346365, 0.03352530925933804, 0.08215981562222753, 0.016934159444645047, 0.0786828121968678, 0.022477376640641263, 0.07051830565822975, 0.03081575608147042, 0.037328436970710754, 0.08843450713902712, 0.09306894881384713, 0.06908878165164165, 0.038057139475962946, 0.02505055785046092, 0.051520631315984895, 0.07429277883576495, 0.024927240896171758, 0.03899076973487224, 0.030089004364396845, 0.043895926526082416, 0.02417059801518917, 0.03100848038281713, 0.031807139848491976, 0.08873042304600988, 0.011914494780025311, 0.09207754808345012, 0.025729759529765164, 0.0863090165491615, 1.5927917999880654, 33.98118659428188, 59.756231035505024, 44.1290271622794, 89.85249914441789, 65.1809606552124, 42.42947694233486, 26.143493516104563, 37.511920656476704, 68.26882348741803, 70.13407434735979, 75.76702758244106, 8.323346103940692, 0.10815344724271979, 0.6237055893455232, 1.1341281831264496, 20.165145329066686, 19.621222972869873, 27.669882467814855, 33.568571295057026, 26.832207645688737, 28.63149230820792, 27.608818224498204, 17.458976575306483, 10.852324502808706, 14.312403202056885, 29.198321138109478, 44.57330887658255, 37.3555132320949, 30.99775866099766, 11.491147092410497, 11.629681144441877, 10.913816928863525, 9.903548853737966, 10.53454864025116, 12.089862074170794, 31.181198051997594, 45.78375455311367, 35.34751163210188, 26.987251486097062, 23.234506845474243, 22.49551033973694, 11.07642388343811, 6.232384315558842, 7.576001337596348, 10.723370279584612, 4.28292042016983, 1.376622159566198, 2.490588733128139, 2.34298597914832, 30.04013361249651, 50.05060856682913, 54.8117470060076, 56.08389268602644, 57.25406660352434, 50.27933284214565, 54.74295636585781, 50.7886392729623, 56.77348402568272, 54.34951114654541, 64.93718310764858, 44.04068776539394, 19.022416796003068, 64.59573473249162, 54.130649839128765, 55.5526716368539, 49.42086206163679, 53.94376414162772, 55.16442019598824, 58.61346081324986, 53.739827564784456, 46.9054091998509, 53.26825680051531, 55.435563223702566, 55.596483503069194, 57.8429924419948, 52.30119957242693, 36.60419062205723, 13.129466312272207, 5.201648150171552, 1.6012413523026874, 2.0561391540936063, 1.7443005272320338, 5.497965369905744, 32.131134918757844, 22.12700046811785, 19.349718638828822, 33.94813748768398, 36.64692899159023, 35.14886263438633, 25.55342469896589, 16.80092658315386, 8.183403304644994, 4.185538377080645, 2.1915714868477414, 4.387651486056192, 5.757231754916055, 11.233886565480914, 15.895647525787354, 21.4438761643001, 29.149270330156597, 22.026229006903513, 14.86132652418954, 15.322528839111328, 18.37532585007804, 30.283643654414586, 33.83230406897408, 33.824803488595144, 32.910226004464285, 24.31806104523795, 9.889516966683523, 4.787008319582258, 2.146563010556357, 3.2460324934550693, 0.34534273190157755, 0.19342665294451372, 14.817007439477102, 66.4258485521589, 61.432456152779714, 17.142024074281963, 31.40580551964896, 47.75812687192644, 66.20602839333671, 46.854989596775596, 29.566388062068395, 48.64927503040859, 17.489110912595475, 0.687963452722345, 0.29519484138914515, 0.048620769421436956, 0.10918347018637828, 0.02829684579877981, 0.10684980505279132, 0.09929622430354357, 0.1793066513325487, 0.011303713179326482, 0.03459835471585393, 0.08035563850509268, 0.0929441594385675, 0.06747876054474286, 0.03647717747039028, 0.0452647691459528, 0.0950243238891874, 0.03116133396646806, 0.04766511730849743, 0.01562506183316665, 0.1569195826138769, 0.007521562378055283, 0.016259554840092148, 0.11833425451602254, 0.2310970579939229, 0.08372552160705839, 0.21752692759037018, 0.21366359346679278, 0.16459366439708642, 0.1834370568394661, 0.13246706686913967, 0.23180585567440304, 0.27962992659636904, 0.13246978100921425, 0.12611876108816691, 0.09254142176359892, 0.2151043675839901, 0.164203086069652, 0.09545778562980038, 0.10096936952322721, 0.166956024776612, 0.1358755382576159, 0.1062894436929907, 0.20062798580953053, 0.15301599779299327, 0.2319383599928447, 0.07736194200281586, 0.16100310135100568, 0.14488591333585127, 0.18605546919362886, 3.3243458569049835, 59.14242022378104, 80.12021296364921, 60.8175961630685, 98.06465148925781, 89.03792708260673, 54.66098846708025, 61.437688146318706, 35.17706189836775, 66.18061188289097, 81.2444314956665, 79.36167117527553, 10.964948722294398, 0.2557800178016935, 1.8281001448631287, 2.6773704247815266, 24.176428965159825, 25.04718589782715, 34.95875644683838, 40.11420515605381, 30.47468090057373, 34.55183867045811, 31.9598514011928, 29.04106429644993, 27.019107239586965, 30.212970052446636, 34.57485457829067, 50.96948003768921, 43.12606859207153, 38.20674051557268, 21.90911190850394, 23.858745166233607, 22.06716431890215, 17.2432975428445, 16.661392859050206, 17.68317062514169, 40.22946187428066, 56.83153969900948, 46.71320465632847, 35.887744494846885, 29.403317315237864, 34.959430422101704, 30.120218549455913, 13.903284583772932, 8.175077625683375, 11.420887776783534, 4.6248239023344855, 1.540017300418445, 4.6057940891810825, 5.011882858616965, 28.543854679380143, 51.340326241084504, 59.57140895298549, 59.70273685455322, 62.05484104156494, 51.896942956107004, 59.95001629420689, 51.1775403703962, 55.957706451416016, 55.71784768785749, 62.29285853249686, 44.25531414576939, 21.004685742514475, 64.30641869136265, 55.60349770954677, 56.460373878479004, 50.77468729019165, 57.124145712171284, 57.21064383643014, 59.72857025691441, 53.41497496196202, 46.88374471664429, 52.21839788981846, 55.71200425284249, 56.542053427015034, 59.39673124040876, 48.5422032901219, 35.28736455099923, 18.44996166229248, 6.187538470540728, 2.0506735273769925, 4.129178498472486, 2.4053899220057895, 7.931917599269322, 36.31078209195818, 27.441769633974346, 29.439951692308696, 46.14424099240984, 48.261791365487234, 47.114331109183176, 37.18382324491228, 24.591705424445017, 19.428525107247488, 14.39565564904894, 9.947969555854797, 14.024015613964625, 13.22550778729575, 18.266602175576345, 23.668718882969447, 28.858785254614695, 35.47601856504168, 27.260935817446025, 17.67442458016532, 21.873530183519634, 29.13664719036647, 43.222387995038716, 46.2527232170105, 45.99266256604876, 42.39659111840384, 36.916074412209646, 17.30990297453744, 7.439206940787179, 1.599006746496473, 4.459889735494341, 0.3395170202212674, 0.3452478455645697, 15.012434210096087, 78.52988842555455, 48.86467613492693, 27.497885022844585, 54.720760345458984, 63.46565192086356, 80.82769244057792, 58.85818331582205, 39.69769886561802, 72.24145603179932, 22.91010934965951, 0.587663437638964, 0.3602645583450794, 0.15833603803600582, 0.29952799315963474, 0.15814747315432343, 0.1491362838340657, 0.25130353229386465, 0.4118013557578836, 0.07630492693611554, 0.11154177971184254, 0.11418636994702475, 0.15494469287140028, 0.17010906844266824, 0.12647022865712643, 0.11941214810524668, 0.283927360283477, 0.07192018614815814, 0.1027141883969307, 0.0834052191515054, 0.19563803928239004, 0.21265994517930917, 0.20570752610053333], [0.016489975154399872, 0.03634949753593121, 0.04239578738010355, 0.040111902968159745, 0.048118056396820715, 0.05857129887278591, 0.03681417188740202, 0.048537272294717174, 0.04574251547455788, 0.12146114744246006, 0.07513819275689976, 0.10056248599929468, 0.024046015593090227, 0.040567505306431224, 0.03092355833255819, 0.018108723917976022, 0.05219833852191057, 0.07275505563510315, 0.14341715643448488, 0.12232930585741997, 0.024590032740629146, 0.13699992506631783, 0.047616954892873764, 0.028563596574323516, 0.044669218960085084, 0.07792336866259575, 0.025020888906770518, 0.2587981144232409, 11.00678903715951, 28.188584600176128, 31.691154139382498, 35.126673562186106, 73.84291853223527, 46.422398226601736, 40.49934727805001, 45.15605429240635, 30.63278021131243, 63.907925605773926, 47.68633113588606, 1.560470734323774, 0.35317975708416527, 0.5904946114335741, 1.2973960850919997, 15.744086469922747, 26.230655193328857, 18.845750161579677, 23.610390492847987, 23.98342537879944, 22.654052598135813, 26.399909836905344, 27.57447154181344, 12.921804632459368, 7.412395579474313, 35.80883380344936, 38.122337273189, 30.769076074872697, 15.168145077569143, 4.212077455861228, 8.158190029008047, 4.606858032090323, 5.060389535767691, 3.5801225091729845, 9.486101082393102, 26.58016869000026, 31.41402176448277, 27.8635322366442, 26.36548846108573, 25.31626878465925, 23.47137267248971, 13.977512189320155, 7.863410098212106, 8.605816432407924, 7.375657847949436, 3.467397106545312, 0.24854794730033192, 0.03538432218400495, 1.3626959068434579, 3.9810845937047685, 16.771063225609915, 38.57929597582136, 52.78363037109375, 56.06338855198452, 50.98250443594796, 49.473776068006245, 48.259116309029714, 50.80617305210659, 55.70442376817976, 58.52148750850132, 49.251350334712434, 8.301108394350324, 55.423077310834614, 51.197276728493826, 49.70016574859619, 47.709413051605225, 47.76102079663958, 46.696563720703125, 51.016981397356304, 45.30561426707676, 46.56214387076241, 51.72376605442592, 55.09833587918963, 56.2370275088719, 56.29723364966256, 52.21425328935896, 26.970422949109757, 11.550321425710406, 0.7793093025684357, 1.1866997735840934, 0.8801643050142697, 0.7221356704831123, 6.167548503194537, 17.973881517137798, 20.682384865624563, 18.818296091897146, 34.166807719639365, 47.111791542598176, 36.820022514888215, 25.22010919025966, 14.227765457970754, 4.53732567174094, 2.4665388464927673, 2.54212287068367, 0.9312867075204849, 4.020544282027653, 4.146182477474213, 6.794718529496874, 13.45361019883837, 19.568696328571864, 20.11522947038923, 14.317959155355181, 14.718157155173165, 13.295533469745092, 20.408990621566772, 41.19680745261056, 38.09770590918404, 32.28409603663853, 25.8178905078343, 13.555981482778277, 4.263055520398276, 1.6030334447111403, 2.885059028863907, 0.3190827210034643, 0.03870013961568475, 7.75659544127328, 59.05339295523507, 20.2919499533517, 36.46691506249564, 38.54724046162197, 42.98496804918562, 46.0837847164699, 15.19497207232884, 29.90239599772862, 29.397539888109478, 3.1655004833425795, 0.21478337980806828, 0.24781328386494092, 0.04145236925355025, 0.055469817082796774, 0.058737641732607565, 0.06811842229217291, 0.09994551446288824, 0.033582896526370726, 0.020364150571237718, 0.01755711735625352, 0.06363257300108671, 0.09382830413856677, 0.007818468946165271, 0.04790560029713171, 0.01332169583266867, 0.05515667995704072, 0.06679683963635138, 0.06821431964635849, 0.061046587835465155, 0.05504238073314939, 0.08512949198484421, 0.061307321701731, 0.011779825086705387, 0.07295040586697203, 0.05880436208099127, 0.11776668711432389, 0.06881026338253703, 0.04257156526935952, 0.043968472097601206, 0.02617774361611477, 0.07744407188147306, 0.049627834132739475, 0.06370742219899382, 0.0890730493036764, 0.004426809959113598, 0.03923560552565115, 0.012367529711419982, 0.07413512800953218, 0.02439367149158248, 0.04735631262883544, 0.05183223495259881, 0.12189521986458983, 0.05021752856139626, 0.05485991248860955, 0.08046423803482737, 0.03155477571168116, 0.049055835897369046, 0.024825207889080048, 0.05632658628746867, 0.9775011305298124, 24.820325476782664, 62.01065744672503, 44.751530170440674, 55.307157039642334, 81.49192632947648, 44.5455265045166, 29.1172582421984, 32.700845514025005, 51.14166334697178, 68.8017225265503, 55.29002973011562, 1.4102341788155692, 0.4774087167211941, 0.7560442366770336, 1.8096967552389418, 17.85529487473624, 30.408429827008927, 33.39293473107474, 30.570760590689524, 30.619470936911448, 24.446263994489396, 29.708176476614817, 27.963324001857213, 14.770834922790527, 15.09550166130066, 40.810734272003174, 43.477345194135395, 35.82999454225813, 19.38093342099871, 6.5879974620682855, 11.820960709026881, 8.136093888963972, 9.276173421314784, 7.253406465053558, 9.49550894328526, 25.88873781476702, 33.33297872543335, 29.130035979407175, 27.669444731303624, 24.16002947943551, 22.673583984375, 7.54416903427669, 7.583102396556309, 9.09869384765625, 7.400934525898524, 7.001180776527949, 0.673798952783857, 0.6616197920271328, 1.358593755534717, 2.1953576036861966, 19.87433021409171, 42.85360540662493, 59.37314905439104, 57.866824763161794, 54.43142693383353, 54.747649874006, 51.99269608088902, 54.44063329696655, 60.38015147617885, 62.08748367854527, 53.0787307875497, 10.644432663917542, 60.107761246817454, 59.591586521693635, 56.11116783959525, 53.6359589440482, 55.19762216295515, 53.671210629599436, 56.352162633623394, 50.312298570360454, 50.29387194769723, 54.31019476481846, 59.37073108128139, 61.5276186806815, 58.29895755222866, 56.87706429617745, 31.794178553989955, 14.23158609867096, 3.8881698080471585, 0.139691632773195, 0.15223283267446927, 0.9573055399315697, 8.55653807095119, 23.804147958755493, 18.287224428994314, 18.92552764075143, 31.795800958360942, 41.06041431427002, 31.56811891283308, 24.093830517360143, 14.088904840605599, 4.366680085659027, 4.246252170630863, 1.992735973426274, 2.38563033086913, 8.459952899387904, 9.27443550314222, 10.2183005128588, 18.211289303643362, 24.23007948057992, 26.82314372062683, 19.693951504571096, 20.083347661154612, 19.482934713363647, 27.101509400776454, 46.2140599659511, 38.297921725681846, 29.82990196772984, 20.738191059657506, 9.607050112315587, 5.340698974473136, 2.7118339240550995, 2.9366956523486545, 0.5548798282231603, 0.025763694762385318, 7.2532305887767246, 70.91660826546806, 30.437278747558594, 21.83380385807582, 44.48971509933472, 49.84098488943917, 61.241908754621235, 35.135351862226216, 41.508705139160156, 47.732529708317344, 5.257290193012782, 0.044274209798978906, 0.05669465421565941, 0.027048494034845914, 0.0031163993823741165, 0.051197906490415335, 0.02800204947457782, 0.07490705658814736, 0.023288777297628776, 0.03278518022437181, 0.014294576797900456, 0.06390296920601811, 0.02751892914862505, 0.01676392857916653, 0.03699247731960245, 0.017311382506574904, 0.06563374919018575, 0.02168495800080044, 0.022302599590537802, 0.06248386071196624, 0.0734575225838593, 0.028708233098898615, 0.04139047668182424, 0.07499656892780747, 0.15447214751371316, 0.15393012017011642, 0.18808494029300554, 0.1593582917537008, 0.22986996812479837, 0.10531541345907108, 0.13999847987932817, 0.15093464590609074, 0.21412459015846252, 0.15394864417612553, 0.2791689027632986, 0.15973263952348912, 0.1389098111540079, 0.12213438988796302, 0.17814285520996365, 0.15435101544218405, 0.22436239437333175, 0.24170022617493356, 0.24984327065093176, 0.16028835970376218, 0.24622437198247227, 0.1883886797087533, 0.11001285032502242, 0.17623332196048327, 0.25426951742597986, 0.13708080644054071, 1.20734341442585, 40.83303451538086, 92.42867578778947, 61.588234765189036, 61.99144567762102, 100.14224624633789, 65.51696164267403, 52.94975485120501, 55.456998416355674, 38.470678261348176, 81.82801764351981, 53.34573268890381, 2.9629819904054915, 0.733787148126534, 2.5954494263444627, 3.8543563996042525, 23.926078421728953, 41.00801794869559, 37.82017401286534, 39.669513498033794, 37.14392668860299, 34.12163053240095, 41.87527820042202, 44.696590764181956, 26.953050715582712, 22.08702400752476, 49.183914593287874, 52.08967556272234, 44.75821781158447, 30.149112633296422, 16.441468477249146, 22.169236830302648, 18.063909326280864, 18.595227650233678, 13.56778473513467, 18.6253776209695, 35.68391561508179, 42.55850499016898, 34.199214117867605, 32.886421476091655, 35.413005352020264, 32.69866725376674, 24.05600799833025, 13.22889416558402, 10.393974423408508, 11.612227269581386, 6.8706202166421075, 0.6218724591391427, 1.8601502307823725, 2.015780108315604, 2.989204926150186, 20.68530832018171, 44.50729751586914, 62.81849670410156, 61.08189868927002, 57.8413040297372, 55.57830354145595, 50.979690415518625, 54.81169836861746, 57.431565284729004, 58.79840101514544, 52.57356200899397, 11.517788222857885, 59.37128693716866, 59.8947433744158, 57.3271164894104, 56.815447671072825, 57.86261762891497, 54.00578376225063, 57.347252368927, 48.93060411725725, 51.01353856495449, 52.539936201913015, 56.74143198558262, 60.55342565264021, 56.504845823560444, 52.09417104721069, 30.769155979156494, 17.73670128413609, 5.396050930023193, 2.0203518058572496, 1.2605166754552295, 1.0718116355793816, 14.396623185702733, 28.720123529434204, 27.58720758983067, 28.818183456148418, 40.37052420207432, 53.15104069028582, 41.3065299306597, 39.19942617416382, 26.56135991641453, 14.580671412604195, 13.905431577137538, 8.793204137257167, 8.67008032117571, 17.79519816807338, 17.099228382110596, 18.28051594325474, 26.231384754180908, 32.97512912750244, 34.22828538077218, 25.161523716790335, 27.20844391414097, 26.922834736960276, 31.567045416150773, 52.28543063572475, 48.29654972893851, 41.74089656557356, 33.607707023620605, 17.744980062757218, 5.04416766336986, 3.7660764966692244, 5.96476445879255, 1.2122704471860613, 0.10476689932069608, 9.474519303866796, 74.19555350712368, 25.422091586249216, 45.036124910627095, 60.06039537702288, 64.5392597743443, 77.37577874319894, 45.53145851407732, 57.517274788447786, 65.63832582746232, 5.77207440989358, 0.22597676488970006, 0.3535702946994986, 0.1709448064544371, 0.1941567294831787, 0.21969648902969702, 0.14204761492354528, 0.2744597883096763, 0.09428948403469153, 0.14744241615491255, 0.17479390491332325, 0.18204554436462267, 0.3115276406918253, 0.09162184396492583, 0.14645912391798838, 0.21372354882104055, 0.2081811119403158, 0.2371029614337853, 0.16015603180442536, 0.17471801755683763, 0.23703464652810777, 0.07655194760965449, 0.13119469157287053], [0.037471590896270106, 0.018668137025088072, 0.0635687703532832, 0.06999854783394507, 0.04845871490293315, 0.06766645690160138, 0.04916638621528234, 0.01936083985492587, 0.08682106621563435, 0.02165091929158994, 0.0346349650727851, 0.02316700740318213, 0.057482399445559294, 0.056126588090722046, 0.0407826382267688, 0.03355731575616768, 0.09644493194563047, 0.040687850277338705, 0.04278934447626982, 0.06654247042856046, 0.02996074767517192, 0.013401615383502628, 0.05774988473526069, 0.006634390139619687, 0.024494255826409374, 0.044620357653392215, 0.11913776211440563, 0.11327222042850085, 8.083124297005789, 10.4347551379885, 36.39008188247681, 30.99807480403355, 57.73728949683053, 71.17960453033447, 34.807330880846294, 48.99188028063093, 29.700498717171804, 58.70901938847133, 29.934621742793492, 0.1587333067187241, 0.1488528461860759, 0.5307624137827328, 0.5484820029565266, 13.324458820479256, 23.44092219216483, 23.004207066127233, 23.105004583086284, 18.95216703414917, 25.479601825986588, 33.91536978312901, 16.02226628576006, 6.1969471999577115, 18.269044467381068, 37.534842763628276, 42.89035095487322, 28.247955220086233, 10.97019374370575, 3.5669231031622206, 3.8606080412864685, 4.367391841752188, 4.447716491562979, 4.4017137714794705, 5.40375474521092, 15.671060902731758, 19.375770909445627, 17.35005487714495, 28.063369376318796, 27.288365568433488, 18.262551375797816, 11.0287983247212, 8.509892208235604, 14.99172510419573, 6.7370154772486, 3.624873467854091, 0.14469945191272668, 0.04355259798467159, 0.12352054193615913, 0.7634767464229039, 5.277943713324411, 23.769768272127422, 46.85429130281721, 54.571339334760395, 54.31532948357718, 53.20012971333095, 53.278713839394705, 56.351384435381206, 58.06177384512765, 55.909829889025005, 44.216567516326904, 8.309833594730922, 52.663186822618755, 52.69135134560721, 48.95818151746477, 43.90504503250122, 42.17599970953805, 38.79729570661272, 40.31319808959961, 42.10531568527222, 47.47936167035784, 56.68052407673427, 59.77594307490757, 58.00676843098232, 56.24122074672154, 41.12836422239031, 15.668926068714686, 9.773884177207947, 2.2891024819442203, 0.4473467112651893, 0.4889844155737332, 0.809492711509977, 5.250939539500645, 14.338084612573896, 21.503583771841868, 22.440829753875732, 26.86879164831979, 31.509806156158447, 33.19632155554635, 27.464278323309763, 14.808838094983782, 7.986771021570478, 1.2106075478451592, 2.998648830822536, 2.380158624478749, 3.0140968476022993, 5.552249039922442, 6.058611171586173, 8.313708083970205, 14.887913806097847, 14.124760150909424, 15.669996091297694, 20.420489890234812, 14.510668311800275, 15.600864989416939, 24.0608526297978, 28.948934657233103, 34.67414433615548, 20.169010264532908, 10.251167229243688, 1.3771465314286095, 2.5882022380828857, 1.6766077024596078, 0.2562859335115978, 0.06840189386691366, 6.032931063856397, 29.30250937598092, 34.295797552381245, 46.87633098874773, 44.62784876142229, 46.075933252062114, 34.00627653939383, 24.371067115238734, 40.08624907902309, 28.95842068535941, 0.5691057220101357, 0.04067405226773449, 0.12517377893839562, 0.058045983846698485, 0.0804476003561701, 0.030556911935231516, 0.014836307282426527, 0.03729922603815794, 0.12207486879612718, 0.05687757029331156, 0.08731978266899075, 0.008585283915246171, 0.06156810985079833, 0.03920627924214516, 0.02681506272139294, 0.05883786135486194, 0.018940051452123692, 0.006997305442512567, 0.17391624700810226, 0.0790697264352015, 0.02453786357572036, 0.039370518643409014, 0.031318326613732746, 0.034254364602799924, 0.012037080612831881, 0.08177875035575458, 0.08817967652742352, 0.07824033272585698, 0.04735933889501861, 0.07613240940762417, 0.02265130721830896, 0.025950207075636302, 0.019847756584307978, 0.033060173504054546, 0.04943282316837992, 0.027533765316807797, 0.1361917627177068, 0.04740546570558633, 0.035768691916018724, 0.05530137076441731, 0.006002363607486976, 0.047386385300861936, 0.06482951555933271, 0.02851260806034718, 0.04187255206384829, 0.014539348127852594, 0.10283688788435288, 0.0669923662873251, 0.07223741484007665, 0.06174090557864734, 0.14426550162690027, 12.243264402662005, 34.42035443442208, 54.863472870418, 47.6499468939645, 77.71130725315639, 72.83298397064209, 34.43438284737723, 27.48025049482073, 38.42710263388497, 71.12250423431396, 31.57635600226266, 0.28645921871066093, 0.1573458518832922, 1.7236083575657435, 0.5898519573467118, 17.12394138744899, 29.21914141518729, 26.179504292351858, 29.9279271534511, 28.89185346875872, 30.846600600651332, 36.299602440425325, 28.267875705446514, 12.038144026483808, 24.713187728609356, 42.36979191643851, 48.34000028882708, 33.467982224055696, 15.51045502935137, 6.0340540664536615, 7.393968088286264, 7.364023957933698, 8.225835953439985, 5.148262969085148, 7.629535470690046, 15.598276785441808, 21.10273698398045, 21.085455077035085, 29.93481629235404, 26.718771355492727, 18.60192745072501, 6.535624980926514, 3.423542465482439, 6.028766921588352, 5.116530980382647, 5.609143495559692, 0.11313369750444378, 0.130620325250285, 0.0943607369969998, 0.7664619205253465, 4.3712815301758905, 25.485400097710745, 50.233863830566406, 60.694349016462056, 57.71628161839077, 56.01239572252546, 55.98758370535714, 57.99811097553798, 59.30860028948103, 58.57458564213344, 49.546405587877544, 12.080798149108887, 60.372967038835796, 56.32466513769967, 56.32470335279192, 51.24497611182076, 50.58753408704485, 45.48225484575544, 46.987529958997456, 45.634885924203054, 53.82075323377337, 60.186206408909385, 64.5568595613752, 64.87601116725376, 60.04478972298758, 45.03060456684658, 19.359946387154714, 13.906489440373011, 1.9872922769614627, 0.5576594876391547, 1.209239404116358, 0.7320067808032036, 6.457356129373823, 18.75754972866603, 21.591733830315725, 20.66796909059797, 26.07899338858468, 35.170259611947195, 28.18082172530038, 21.326832021985734, 15.342753308159963, 11.044744440487452, 4.631986626556941, 0.8033956672464098, 2.6414551862648556, 6.007893664496286, 8.54923985685621, 8.654729144913809, 12.011494210788182, 20.939725296837942, 20.040677036557877, 19.20319676399231, 25.40246639932905, 22.738118852887833, 24.825152737753733, 33.037763663700645, 32.30287701742989, 29.203115395137242, 12.620442152023315, 5.10514201436724, 1.8479274809360504, 4.17858236176627, 5.370989646230425, 0.5967053781662668, 0.04441435442173055, 5.656205381665911, 42.08177171434675, 19.397178309304373, 40.0687917300633, 54.04794890539986, 59.83243192945208, 53.62757246834891, 35.3847713470459, 51.478466851370676, 42.18496635981968, 1.0715121030807495, 0.3219482015286173, 0.07087835669517517, 0.09175786988011428, 0.02831573112468634, 0.07036080410970108, 0.042286003806761334, 0.12737752497196198, 0.05028478495244469, 0.04036272004512804, 0.00809248089457729, 0.035788817264671834, 0.03100427007302642, 0.07911841810813972, 0.017449486435257962, 0.04169470803546054, 0.09758022281208209, 0.05158381310424634, 0.10351453402212688, 0.048517350506569655, 0.09359695762395859, 0.03643216345725315, 0.04778679220804146, 0.1277675469006811, 0.11241672347698893, 0.15670547767409257, 0.18066800971116337, 0.16389265629862035, 0.18288540786930493, 0.13585590145417623, 0.10090819959129606, 0.1653326568858964, 0.20388665023658956, 0.07689325750938483, 0.10726992679493767, 0.10674712913376944, 0.16694025562277862, 0.13161948163594517, 0.19069841291223252, 0.15296825606908115, 0.06746218393423728, 0.13896178693643638, 0.14666480145284108, 0.0697374272027186, 0.12392146113727774, 0.10781204913343702, 0.2426845904971872, 0.17118405790201255, 0.1710458267480135, 0.29980323410459925, 0.29037165162818773, 16.596463680267334, 60.047624588012695, 74.7077886036464, 61.87292330605643, 93.82688958304269, 96.61404827662876, 53.686944825308665, 59.434925488063264, 38.075388295309885, 79.8523529597691, 36.095794405256, 0.35921187911714825, 0.20508039689489774, 2.522102939231055, 0.7305523274200303, 19.605150052479335, 36.076683385031565, 34.066402775900706, 39.682728971753804, 32.58263233729771, 40.72346837180001, 47.79575136729649, 36.06545509610857, 21.27789412225996, 34.205130508967805, 51.99518701008388, 56.80291312081473, 44.248560496738975, 25.07052489689418, 15.553891692842756, 17.461090564727783, 15.88004013470241, 20.005720649446758, 14.883993285042898, 19.55914602960859, 23.573485136032104, 30.269976547786168, 22.758112294333323, 37.657082421439036, 36.940914222172324, 26.022674764905656, 18.534041813441686, 14.01547714642116, 20.532784938812256, 11.258842757769994, 7.828973088945661, 0.2730453142098018, 0.21121801755258016, 0.3456055963678019, 1.2182572973626, 6.485026027475085, 26.04653835296631, 54.352266107286724, 65.91992936815534, 62.10625771113804, 60.12656307220459, 57.636474609375, 58.84287643432617, 60.91260583060128, 56.94147062301636, 48.05287293025425, 14.591493231909615, 59.463225500924246, 56.30378232683454, 58.366535731724326, 52.29504346847534, 50.82091018131801, 47.884021282196045, 48.23504774911063, 44.990735803331646, 54.927139214106965, 60.97910009111677, 61.566820417131694, 62.13684368133545, 57.55463177817208, 43.76928765433175, 17.93095554624285, 15.277136257716588, 3.2458131909370422, 0.4728485814162663, 1.7851644030639102, 0.5742869611297334, 10.679672190121241, 27.532990796225413, 29.00077169282096, 33.02091775621687, 31.17961733681815, 41.81120886121477, 38.842987060546875, 38.00172001974923, 23.802648884909495, 21.534220116479055, 13.150265744754247, 8.695356130599976, 10.368020296096802, 15.440340757369995, 16.75955353464399, 18.450727701187134, 20.543568543025426, 28.8041341985975, 27.91568715231759, 28.68603914124625, 30.71766287939889, 29.837624890463694, 26.504681723458425, 36.170796734946116, 38.84593309674944, 45.3298773765564, 26.325881992067607, 11.013056312288557, 1.61102409022195, 5.499222559588296, 6.6611272522381375, 3.163567147084645, 0.13022881054452487, 8.064449276242938, 39.562684944697786, 43.440109797886436, 61.22974245888846, 67.52740900857108, 75.89933518001011, 67.41725226811, 47.79177699770246, 71.9193514415196, 46.803461756025044, 0.9741924852132797, 0.2874082720705441, 0.20842637520815643, 0.2195522053433316, 0.14189666802329676, 0.12082692076052938, 0.1248301552342517, 0.20530856108026846, 0.2019719872623682, 0.1841747872531414, 0.11475230886467866, 0.10257137034620557, 0.11769222468137741, 0.16812337642269476, 0.08781870946820293, 0.15807914467794554, 0.20389876887202263, 0.166444260094847, 0.2020136086004121, 0.11723542133612291, 0.29224834378276554, 0.204094974058015, 0.09145380476755754], [0.07558130326547793, 0.04862523078918457, 0.07913629750588111, 0.03925362741574645, 0.05326298371489559, 0.027908199599811008, 0.02834061809283282, 0.04675495418320809, 0.049905246389763694, 0.09904974645801953, 0.005686675614145185, 0.060691686879311285, 0.020797731055478965, 0.02330985598798309, 0.01676417963712343, 0.04991447107334222, 0.04014588739456875, 0.038376790537898026, 0.0776749841336693, 0.07514899503439665, 0.06156625745019742, 0.039153048169932196, 0.055080127636236806, 0.1673715596220323, 0.03753033506550959, 0.06444494226681334, 0.10118468904069491, 0.07927271018603019, 0.9293128762926374, 20.24860187939235, 44.08794246401106, 43.05889688219343, 45.36144651685442, 69.77212183816093, 57.400197642190115, 47.068083899361746, 34.65646464484078, 47.06277200153896, 21.49716189929417, 0.48245267463581903, 0.5977645441889763, 0.5915964437382562, 0.5921468170625823, 7.7383103881563455, 19.635185377938406, 39.65470688683646, 30.191291672842844, 21.058899062020437, 25.534105232783727, 23.880699736731394, 12.612944177218846, 15.802729266030447, 19.122648034776958, 32.31521006992885, 37.75558008466448, 24.850374698638916, 9.3926990543093, 1.4669352791139056, 2.4774631517274037, 4.977369853428431, 7.045459474836077, 6.163917200905936, 7.304103561810084, 14.830992426191058, 11.708777700151716, 15.754180465425764, 29.05680022920881, 26.322171654020035, 25.33482047489711, 16.136154208864482, 10.82481050491333, 17.399270704814366, 8.474201917648315, 3.67094349861145, 0.12363305661295142, 0.05439733820302146, 0.08739083207079343, 0.2210146247276238, 1.4175409695931842, 12.687193495886666, 39.41112388883318, 49.867110116141184, 54.48212446485247, 51.9073166166033, 50.36555651256016, 55.56488309587751, 58.623542649405344, 55.525997502463206, 38.506583077566965, 13.44488673550742, 49.20842088971819, 49.42871700014387, 44.67439821788243, 43.49517774581909, 39.942549909864155, 36.791937896183555, 36.22997801644461, 43.233036109379356, 53.65275968824114, 53.71967084067208, 57.78710113252912, 58.00528151648385, 50.975667408534456, 28.151321411132812, 17.92440860612052, 8.906256539481026, 1.356388462441308, 2.032692240817206, 1.3630522191524506, 0.9584972645555223, 4.53735042469842, 15.909521341323853, 22.873169251850673, 26.077237231390818, 24.325803075517925, 20.576935529708862, 32.76522752216884, 27.03156188556126, 11.990612268447876, 8.01448825427464, 3.3981958712850298, 1.6184025342975343, 1.5447948383433479, 3.7876888683864047, 6.878548979759216, 3.9128102915627614, 6.262859983103616, 11.03211782659803, 11.439194543021065, 20.84698074204581, 22.554858378001622, 15.793668815067836, 15.83258741242545, 23.605410371507915, 28.29741597175598, 27.378464596612112, 19.20651626586914, 5.548497446945735, 1.6509306345667158, 4.627054274082184, 1.794638271842684, 0.8607364360775266, 0.044253198962126455, 2.71021151968411, 18.4649715082986, 43.422513484954834, 34.93941266196114, 39.364220074244905, 39.46986395972115, 27.300544023513794, 34.628171580178396, 49.01469816480364, 4.28307979447501, 0.6644728417907442, 0.12959294180784905, 0.06988616886415652, 0.17192604951560497, 0.03302521877256887, 0.08244392501988582, 0.06013636024934905, 0.017457396457237855, 0.047780030606580634, 0.040146552358887026, 0.09437438233622483, 0.02620035918828632, 0.04118954549942698, 0.032149464158075194, 0.052415903990289996, 0.019227724854967425, 0.03579594866771783, 0.08249764463731221, 0.09215159661003522, 0.042534683498420885, 0.031135892295943837, 0.030496647847550254, 0.011157608474604785, 0.015784096870837466, 0.03377793802480612, 0.010414950200356543, 0.019590971791850667, 0.015628880288984095, 0.0492086250201932, 0.11049870853977543, 0.031066647797290767, 0.11023198999464512, 0.12127639592758246, 0.029664465359279087, 0.06867868865707091, 0.004488559190316924, 0.0511301513761282, 0.041467643076820035, 0.007816768367774785, 0.11453608689563614, 0.020729334725599204, 0.04081888896014009, 0.05495093456868615, 0.012983536031762404, 0.1231877612216132, 0.11409604336534228, 0.18444705621472426, 0.052025569935462306, 0.1258971651217767, 0.17687765881419182, 0.15909313383911336, 2.390270207609449, 37.738980838230674, 72.2093345097133, 59.91455963679722, 62.28778634752546, 80.01866504124233, 57.77316304615566, 32.27941642488752, 33.76420130048479, 65.78013856070382, 23.07109911101205, 0.34433163329958916, 0.599052295088768, 1.5787494906357356, 0.6571012916309493, 7.420724732535226, 25.24243896348136, 47.7410204069955, 39.46039009094238, 24.611344507762364, 32.21697643824986, 33.6093294279916, 21.93598232950483, 23.06354120799473, 27.56280551637922, 40.30120897293091, 43.54823766435896, 29.113593067441666, 13.752002324376788, 4.806679104055677, 4.789384603500366, 6.481115060193198, 7.244044635977064, 6.146646150520869, 6.844844136919294, 11.429801447050911, 13.44181215763092, 20.001174790518625, 30.151346479143413, 22.37737533024379, 24.736377341406687, 15.246364423206874, 8.179098027093069, 9.302132759775434, 8.518017257962908, 4.463478480066572, 0.06973378346966845, 0.10156632427658353, 0.13911987202508108, 0.4062001577445439, 1.7658942256655012, 14.073075107165746, 39.008170059749055, 52.96234498705183, 59.155350821358816, 55.409410204206196, 55.324805464063374, 60.439245905194966, 65.0016484941755, 62.36370931352888, 44.06821652821132, 19.58324064527239, 56.34603084836687, 57.39102949414934, 54.146978105817524, 51.07884120941162, 46.1888553755624, 42.60588475636074, 42.40583569662911, 51.17473677226475, 60.33595398494175, 60.92482771192278, 63.724930899483816, 64.3764843259539, 57.639059339250835, 32.239106450762065, 20.77828390257699, 11.182007840701512, 0.600709331887109, 2.7552512628691535, 1.753123436655317, 0.6577099104012761, 4.08100620337895, 17.658931834357126, 24.20665536608015, 21.908092260360718, 21.35420618738447, 21.752214636121476, 29.723507676805767, 15.551301751817975, 7.954299483980451, 10.476142082895551, 7.417574592999049, 4.207370919840677, 3.6408367369856154, 8.344092556408473, 12.279455832072667, 8.126982195036751, 8.803311160632543, 18.285150391714915, 21.255029337746755, 26.988401412963867, 28.24442379815238, 23.17065463747297, 24.41224561418806, 31.252833979470388, 27.46883634158543, 21.202403681618826, 6.520185649394989, 4.0707966940743585, 1.8307980000972748, 6.582271712166922, 1.118581154516765, 1.0543504868234908, 0.06657470762729645, 2.883900199617658, 15.050873381750923, 26.29002755028861, 44.96853283473423, 53.89303534371512, 53.872294970921104, 47.47152410234724, 47.44363750730242, 63.24777030944824, 11.216658507074628, 0.657651502106871, 0.23219587760312216, 0.026999503806499497, 0.07900063121425253, 0.07762524073145219, 0.0880921251539673, 0.2923277052385466, 0.07051580186401095, 0.08344147327755179, 0.03537855802902153, 0.051767736806401184, 0.0743550547797765, 0.04266546433791518, 0.0012765743678236114, 0.05540453862132771, 0.03617733623832464, 0.10510271308677537, 0.1445433074342353, 0.06439289863088302, 0.03977475588076881, 0.03017814350979669, 0.017067104810848832, 0.06577626190015248, 0.15605480330330984, 0.16346494853496552, 0.16742202905671938, 0.12690280830221518, 0.10476399519081626, 0.1436417515256575, 0.1820270882121154, 0.12300158478319645, 0.18777242063411645, 0.1802514570632151, 0.1333357681121145, 0.20565921440720558, 0.0785831625440291, 0.12941507063806057, 0.10556355371539082, 0.1317094825208187, 0.2835256675524371, 0.04917121399194002, 0.182126805718456, 0.2994064539670944, 0.12104512405182634, 0.26067724930388586, 0.14032230393162795, 0.20304072062884057, 0.2073571261550699, 0.31295590262327877, 0.31240835200463024, 0.2627497666648456, 1.7390852527959006, 61.877356256757466, 98.36964961460659, 79.20491286686489, 75.20030471256801, 95.61794757843018, 81.04323945726667, 59.061306953430176, 44.669020312173025, 63.81023393358503, 28.972584588187082, 0.5568717356239046, 1.0752419829368591, 1.4649644877229417, 1.2557151445320673, 9.836092267717634, 30.799085344587052, 55.148369857243125, 45.646722180502756, 31.435269355773926, 41.688361236027305, 41.68286868504116, 33.042540550231934, 32.49941028867449, 37.36742244447981, 51.09075389589582, 52.69948073795864, 36.33731378827776, 21.647112710135325, 12.59144037110465, 14.455296380179268, 15.57024427822658, 18.497197253363474, 19.484850679125103, 22.221013069152832, 24.641857521874563, 21.76497847693307, 22.08564826420375, 36.84088795525687, 30.755742481776647, 31.913993290492467, 25.298325061798096, 16.607294184820994, 24.71460168702262, 15.198432275227137, 4.251584913049426, 0.19319228694907256, 0.24817933993680136, 0.20747576121773037, 0.4570783962096487, 2.046977085726602, 15.881919622421265, 44.99521391732352, 58.77426297324044, 64.96496895381382, 59.056554385593955, 56.35764823641096, 60.80873026166643, 63.466138294764924, 60.69401550292969, 46.301461356026785, 23.41434359550476, 57.78095545087542, 58.14951569693429, 56.90411363329206, 51.27099016734532, 49.36329623631069, 46.81562457765852, 43.86793122972761, 51.24876635415213, 62.91882174355643, 58.22927754265921, 62.11718027932303, 62.88291345323835, 55.80485650471279, 32.00625841958182, 22.254711832318986, 12.468570164271764, 0.9037681498697826, 4.052527708666665, 3.9272968513625006, 0.9037844889930317, 9.658778582300458, 31.97620051247733, 32.39292567116873, 32.53743430546352, 31.249147960117885, 26.48990637915475, 39.25576216833932, 39.82850912639073, 21.47154562813895, 19.478979451315745, 15.033164160592214, 10.361220615250723, 11.651836344173976, 16.541063955851964, 21.765926906040736, 14.170841472489492, 18.095285654067993, 24.76649604524885, 29.271384920392716, 33.73222916466849, 34.306258065359934, 27.964484351021902, 31.959708963121685, 35.09492376872471, 41.75022452218192, 32.94470296587263, 27.374191454478673, 6.273686145033155, 2.9787934848240445, 6.084620450224195, 6.963646173477173, 2.644872614315578, 0.16616694283272537, 3.239201979977744, 28.48312394959586, 52.458256653376985, 59.50330965859549, 69.66894803728376, 76.46760054997036, 59.664598192487446, 58.82388005937849, 79.41435936519078, 11.3045688526971, 0.8955369772655624, 0.5155674634235246, 0.1370420078081744, 0.20615648558097227, 0.1717768260943038, 0.20158219603555544, 0.4012409895658493, 0.0804349999608738, 0.2039817672755037, 0.15065827859299524, 0.24487286593232835, 0.22318508183317526, 0.10832514374383859, 0.09043256206704037, 0.2168054955878428, 0.1377539946032422, 0.25019244477152824, 0.19220694553639206, 0.1512331606021949, 0.14372935039656504, 0.16191726444022997, 0.08240946901163884, 0.1440328319690057], [0.0370095221192709, 0.039232626756919284, 0.09420611922230039, 0.002022409882296675, 0.09804936870932579, 0.05343931461019175, 0.03291434615052172, 0.023503162133108293, 0.006625715069406266, 0.03569342541907515, 0.04116424971393176, 0.06817098161471741, 0.05814204404928854, 0.05386340238952211, 0.08985543410692896, 0.013689923216588795, 0.01940660025658352, 0.06322969283376421, 0.021285470508571182, 0.0038476196766298798, 0.13827873287456377, 0.08813352936080524, 0.039442545135638545, 0.06615732038127524, 0.09715962609542267, 0.03135497768276504, 0.07748548287366118, 0.055028810032776425, 0.11169744243047067, 12.608662349837166, 39.66162381853376, 53.10105882372175, 37.835710184914724, 50.357055391584126, 66.24840545654297, 48.729457242148264, 43.3064820425851, 35.95773369925362, 13.262049232210432, 0.2502610039498125, 0.7800024939434869, 3.5878662765026093, 0.6192459315061569, 0.7983353702085358, 11.519649471555438, 19.332068477358135, 27.446958201272146, 29.07203241756984, 29.89653866631644, 24.243621519633702, 16.109275102615356, 11.614606159073965, 18.013062408992223, 27.046669006347656, 25.41016674041748, 22.890564067023142, 8.254070826939174, 2.4974850373608724, 1.8408876529761722, 3.617341620581491, 3.783571626458849, 8.3338109595435, 10.010947159358434, 12.16207035950252, 7.175488497529711, 20.37117678778512, 26.04366179874965, 31.993758610316686, 22.101931367601665, 20.001120941979543, 15.94610013280596, 10.833300335066658, 6.697584884507315, 2.485336329255785, 0.3831950250480856, 0.08462281631571905, 0.2760586068034172, 0.4052101751523358, 1.5963521003723145, 6.646009274891444, 25.224528244563512, 47.670343330928254, 56.83953012738909, 52.219610350472585, 52.67692688533238, 55.05560793195452, 57.22738552093506, 53.26688800539289, 42.18105104991368, 28.692870957510813, 43.09128243582589, 45.57599299294608, 40.752063683101106, 38.27235582896641, 33.8099239213126, 35.46597146987915, 37.06842408861433, 42.658534731183735, 49.40719148090908, 55.75703205381121, 51.698967933654785, 47.98055607931954, 30.970434870038712, 21.09674416269575, 12.619875873838152, 3.037604123353958, 2.2881861882550374, 1.9490797902856554, 0.3114308001739638, 2.2857614840779985, 4.359560353415353, 15.009868587766375, 20.331335817064556, 24.327788523265294, 21.61588055746896, 15.575561387198311, 22.553404467446462, 35.574606554848806, 12.026948741504125, 7.722280894007001, 9.394871234893799, 1.486152042235647, 0.9895952301365989, 4.547945124762399, 4.633176939828055, 2.6473483443260193, 2.9910498900072913, 11.964483567646571, 18.90057839666094, 23.416221346173966, 18.552895750318253, 15.531018223081317, 24.681767974581035, 22.758023704801285, 29.69747625078474, 24.327039854867117, 11.281303678240095, 2.104668195758547, 0.8706511354872158, 4.90288690158299, 5.126023088182722, 0.21476571075618267, 0.18146200424858502, 0.4532137321574347, 9.642895000321523, 8.884031857763018, 24.002058710370743, 33.412962913513184, 32.53818818501064, 18.639591898236954, 46.836990288325715, 38.87680046898978, 0.24533318408897944, 0.10787159058132342, 0.04421403052817498, 0.06595043505408935, 0.10911921292011227, 0.03212716071201222, 0.06293237235929285, 0.06906058173626661, 0.09853281133941241, 0.03389122623151966, 0.03228935433019485, 0.013900609188047903, 0.05414131676246013, 0.08596789663923637, 0.11284094357064792, 0.08250557671168021, 0.03329566926030176, 0.055647728964686394, 0.06163560372910329, 0.02404501984295036, 0.07590058791850295, 0.005541828743714307, 0.0042316815233789384, 0.020907760597765446, 0.06595650115715605, 0.05879695247858763, 0.07209497676896197, 0.08396285280053105, 0.009710931102745235, 0.03939190606719681, 0.07012438215315342, 0.0068185195227020556, 0.03430712070049984, 0.14444055009101117, 0.023823568065251623, 0.0618514728599361, 0.055170762951352766, 0.05898953428758042, 0.03357537157301392, 0.05621446516098721, 0.07239484174975327, 0.018067326496488283, 0.18532079218753747, 0.03155231262956347, 0.16050786578229495, 0.12225392061684813, 0.13364869489201478, 0.019970931046243225, 0.12990033174199717, 0.040508479545159, 0.11506721696683339, 0.10422487197709934, 0.24597418255039624, 29.730487142290386, 71.14010402134487, 66.71868732997349, 57.61827727726528, 70.90433079855782, 77.63466167449951, 43.85331221989223, 26.606922728674753, 45.1666259765625, 17.742968559265137, 0.202576019135969, 0.3662956218634333, 0.7123733428972108, 0.4812145382165909, 2.438738452536719, 13.429574642862592, 27.208497762680054, 40.51865632193429, 31.738530431474956, 33.89869063241141, 33.50044073377337, 29.772707871028356, 25.142831325531006, 25.612769263131277, 34.16862119947161, 32.76008932931082, 31.111431189945765, 12.171071750777108, 6.490082144737244, 4.747513021741595, 3.2369861560208455, 5.274768386568342, 10.964847104890005, 9.048084037644522, 14.33666023186275, 10.417327318872724, 22.291851690837316, 24.981825930731638, 23.974990265710012, 23.3787271295275, 18.212284633091517, 12.426160965647016, 7.259605126721518, 3.498773000070027, 2.1139030030795505, 0.27491437963077, 0.3897943209324564, 0.11882165979061808, 0.24748685423816952, 2.5814755133220126, 9.89078848702567, 30.26444230760847, 46.04625749588013, 56.487694195338655, 58.885962213788716, 56.58115094048636, 60.89919580732073, 63.15406690325056, 62.364209583827424, 51.37428903579712, 34.53475999832153, 51.893437589917866, 52.722545283181326, 50.09089074816023, 46.199037960597444, 41.588255064828054, 41.11923081534249, 46.10589388438633, 49.4790358543396, 56.73351798738752, 61.49421174185616, 58.346907070704866, 58.1542752129691, 37.26203564235142, 24.965214524950298, 15.074228014264788, 4.864434267793383, 3.4355222455092838, 2.966524920293263, 1.2971779767956053, 0.9652936884335109, 3.362991954599108, 11.279110653059822, 15.746000698634557, 22.482567582811626, 16.27730338914054, 17.233061109270366, 27.71399484361921, 28.972673177719116, 14.970421927315847, 12.875462753432137, 14.64645869391305, 6.081980134759631, 5.585599958896637, 7.546887516975403, 10.545719606535775, 7.741213866642543, 8.641816786357335, 17.764638253620692, 25.1106698513031, 33.7496656690325, 25.472094297409058, 24.866268702915736, 35.6942788532802, 30.10250759124756, 26.277857780456543, 13.211202314921788, 3.7232369439942494, 2.347354224749974, 2.4900843373366763, 3.0886008611747195, 3.01849918280329, 0.21165745040135725, 0.18839148884373053, 0.8833103190575327, 6.816783402647291, 17.71608771596636, 42.73052501678467, 47.641515254974365, 51.36945308957781, 34.83370624269758, 55.29086351394653, 53.998276233673096, 0.4186242696430002, 0.08209795358457736, 0.07513541754867349, 0.19692010405872548, 0.0725023081260068, 0.044825329511825523, 0.0565676969209952, 0.03773515425356371, 0.07006923761218786, 0.03945048060268164, 0.16333015076816082, 0.03420083836785384, 0.027539734728634357, 0.10152845523719277, 0.021524776238948107, 0.1156354086207492, 0.0321052338528846, 0.06737306514488799, 0.0664400862795966, 0.0406009502975004, 0.048439247733248134, 0.045091281312384775, 0.034335710773510594, 0.05907568109354802, 0.1269796048956258, 0.13506316899188928, 0.21920869020479067, 0.21007715591362544, 0.1699056707854782, 0.09467377912785326, 0.23394055398447172, 0.057328799473387856, 0.1192826157701867, 0.18063850700855255, 0.18837707675993443, 0.19612532242068223, 0.13112142336155685, 0.1668813723538603, 0.16847379904772553, 0.10345917234995536, 0.1440626196563244, 0.12553295466516698, 0.2487339744610446, 0.10748597234487534, 0.293436024338007, 0.2037821151316166, 0.28094408607908655, 0.08758086937346629, 0.19118325332445757, 0.2250687764691455, 0.24840705628905976, 0.26264215101088795, 0.2694332008915288, 39.972691195351736, 95.395188331604, 95.22380406515938, 75.58046845027378, 83.3844905580793, 95.9150664465768, 63.79353741237095, 58.46842411586216, 47.28315496444702, 21.62345061983381, 0.2081438467970916, 1.1898968134607588, 5.898114732333592, 3.0627922117710114, 1.8671049433095115, 17.11024648802621, 29.93855094909668, 35.49374689374651, 39.66573715209961, 44.537751470293315, 44.35061911174229, 37.846601486206055, 29.886950152260916, 33.32838944026402, 42.13374771390642, 44.75733886446272, 39.98859909602574, 19.591865096773418, 12.530032191957746, 15.039136137281146, 13.668403335980006, 18.177184070859635, 24.159973893846782, 24.059694017682755, 24.442491122654506, 17.189105067934307, 26.236819982528687, 32.51443229402815, 38.18686171940395, 32.179841790880474, 25.872546775000437, 25.337816885539464, 17.706256014960154, 12.408991966928754, 4.154240650790078, 0.5648377910256386, 0.4944066160491535, 0.3935370386711189, 0.6983033493161201, 2.7391768225601743, 10.531509671892438, 33.99924496241978, 51.22431911740984, 60.58233710697719, 65.23611545562744, 60.32395444597517, 62.0720100402832, 60.040516580854145, 60.15046487535749, 52.09564406531197, 40.93020854677473, 55.04319150107247, 57.454153878348215, 56.04342985153198, 49.209873063223704, 44.94438089643206, 45.48171983446394, 49.02755580629621, 54.60902983801705, 59.204683031354634, 62.21387141091483, 56.60534456798008, 57.19876936503819, 36.5047619002206, 25.716889756066458, 15.89866304397583, 4.11350987638746, 3.0330041987555365, 3.7001993230410983, 2.9288344170366014, 2.105256404195513, 9.091851609093801, 27.30557973044259, 29.055782318115234, 32.58592925752912, 28.744591610772268, 20.386827605111257, 31.888347489493235, 41.12745748247419, 26.42372305052621, 18.887936149324688, 22.899138144084386, 13.681902817317418, 12.815019505364553, 17.656149080821447, 17.556353841509136, 12.069069589887347, 14.518049035753522, 26.991510731833323, 36.585003171648296, 37.78461313247681, 29.067259005137853, 31.28888123376029, 39.977106775556294, 35.15328516278948, 38.805855887276785, 32.97494152614048, 15.04657939502171, 2.9734731188842227, 1.950065131698336, 10.479392971311297, 8.588279179164342, 0.4833136541502816, 0.4392631064568247, 1.191611498594284, 11.515548297337123, 22.520042691911968, 61.4262444632394, 66.73954582214355, 68.98266056605748, 39.65223332813808, 72.22383540017265, 58.88835934230259, 0.24698777816125325, 0.1684331412294081, 0.1534269457416875, 0.2182339203677007, 0.1895952099668128, 0.16283378883131913, 0.13212233036756516, 0.16066509591681616, 0.2557978497019836, 0.16062507592141628, 0.16377393981175764, 0.07444108623479094, 0.1014306376289044, 0.26550969428249765, 0.2051035077976329, 0.2933384510023253, 0.1456511922712837, 0.17382601542132242, 0.1776661572179624, 0.1815698098923479, 0.1869628740740674, 0.10022275030080761, 0.13151508223797592, 0.12962834776512214], [0.031725793677781305, 0.015744460247723118, 0.0846306262537837, 0.17401615450424807, 0.03381431767983096, 0.06029150728136301, 0.004944525817076543, 0.04331974512232201, 0.0639611060864159, 0.0500576114282012, 0.03441885845469577, 0.12105053876127515, 0.013249593005249543, 0.020576565958825604, 0.032725940724568706, 0.042792737151363065, 0.06265536722327981, 0.0778585821390152, 0.057930429333022664, 0.058975882163005214, 0.03285845182836056, 0.048700317474348206, 0.12715088070503303, 0.027075523477313772, 0.015980256255716085, 0.18434294180146285, 0.24930215254426003, 0.09325700479426555, 0.04529602246891175, 10.22791074003492, 56.41792038508824, 56.93362610680716, 30.215690272194998, 41.61578035354614, 58.5665465763637, 51.119071279253276, 54.181639194488525, 33.13131420952933, 4.606710382870265, 0.1537777619170291, 0.23057312039392336, 1.6546320702348436, 0.5503972630415643, 0.3216333884213652, 6.83049350125449, 22.688036237444194, 27.652602297919138, 35.61260625294277, 35.19222286769322, 24.554376227515085, 14.000468168939863, 14.713586977549962, 24.792353766305105, 16.59448344366891, 22.469574451446533, 21.9107186794281, 9.777545877865382, 3.880597140107836, 3.083262039082391, 2.7880912721157074, 7.6689430475234985, 10.397503239767891, 10.478277785437447, 15.245912790298462, 12.919291121619088, 23.40214776992798, 24.80208819253104, 26.242956978934153, 16.82966259547642, 8.326207024710518, 3.7220900569643294, 3.1251557682241713, 0.7544425140534128, 0.41028434144599096, 0.4798770642706326, 0.17647946732384817, 0.38791776448488235, 0.050126879675579925, 0.8064045629331044, 5.983919773783002, 20.052999666758947, 40.17640890393938, 54.12688391549246, 54.10422236578805, 53.19481781550816, 55.58795806339809, 57.68729720796858, 54.509493419102256, 42.020565032958984, 24.73455170222691, 38.98499434334891, 39.74202489852905, 34.487494877406526, 28.951887641634258, 30.052452768598283, 33.170276233128135, 34.87315116609846, 40.70379454748971, 42.71654871531895, 45.890461512974326, 40.045605591365266, 30.878593581063406, 23.156978845596313, 20.01730850764683, 10.79713235582624, 2.1403170142854964, 3.031352264540536, 1.6312068700790405, 2.6254743295056477, 2.5788764527865817, 4.5041957923344205, 15.488187789916992, 23.535919700350078, 28.206545693533762, 28.670739207948955, 13.16841357094901, 9.602326205798558, 23.47833824157715, 14.633627108165197, 5.37320351600647, 12.787733929497854, 5.780980697699955, 3.664852099759238, 3.1994396107537404, 2.123264397893633, 2.391011710677828, 7.008065572806767, 11.625011954988752, 14.33449673652649, 20.03304444040571, 24.506975616727555, 17.619886432375225, 20.7292035647801, 24.344966207231792, 26.415256670543126, 16.277183532714844, 4.547926017216273, 0.8831696723188672, 1.918388511453356, 4.420165581362588, 0.09898645949683019, 0.20377294133816445, 0.09781036831970726, 0.24673872866800853, 3.147285346473966, 13.727756585393633, 19.72585936955043, 42.62760482515608, 19.906460421425955, 20.934958832604543, 54.807213306427, 6.2466871823583325, 0.4266766346991062, 0.06908717352364745, 0.05062357748725584, 0.041727114867951186, 0.043805318352367194, 0.008980779925228229, 0.06577552229698215, 0.14216698280402593, 0.11730233845966202, 0.07768798486462661, 0.025418605422601104, 0.07087810563721827, 0.06746561053608145, 0.1839459173913513, 0.18241947144269943, 0.017760109588769928, 0.04902876913547516, 0.035710887517780066, 0.047857515913035185, 0.024469619916219796, 0.02687773051937776, 0.036172067413904836, 0.012855513437118913, 0.0011765332850960217, 0.022567070488418852, 0.07371773397816078, 0.1550327802875212, 0.029764752835035324, 0.03240371122956276, 0.04784541763365269, 0.048439081492168565, 0.05701023406748261, 0.03624267576794539, 0.04110190930909344, 0.015254637692123652, 0.06455039339406149, 0.02092360608678843, 0.020900216984695623, 0.012140319715919239, 0.08309906415109124, 0.064247719278293, 0.028212990744837692, 0.11481491050549916, 0.09791193822664873, 0.08700419603181736, 0.09910415139581476, 0.09183426613786391, 0.12782675586640835, 0.0424178058414587, 0.1372211274823972, 0.11586278570549828, 0.2915492627237524, 0.06056623932506357, 17.37989217894418, 71.77758734566825, 79.90849440438407, 53.9502329145159, 65.17907769339425, 75.02307006290981, 62.591506004333496, 40.46763569968087, 27.444769518715994, 6.573395388466971, 0.2252043206244707, 0.7076134468827928, 1.1697930693626404, 1.4711830168962479, 0.6067113269652639, 7.002239508288247, 15.618914672306605, 29.254094328199113, 34.250630787440706, 43.79794202532087, 37.9500949042184, 28.151126861572266, 32.238755566733225, 37.13214949199131, 27.823559250150407, 30.22573389325823, 28.22860448701041, 16.249904905046733, 10.566316672733851, 9.61081690447671, 7.984903693199158, 12.418932233537946, 15.492176055908203, 12.39180212361472, 18.860068661826, 13.745682937758309, 23.626348767961773, 20.674496923174175, 18.775462184633525, 11.031122497149877, 6.268093713692256, 1.3768991104194095, 0.996100481067385, 0.8059186775769506, 0.8224486048732484, 0.7409264221787453, 0.11819967388042382, 0.36714913749269074, 0.6726669392415455, 0.4232355122055326, 7.441766483443124, 24.758000135421753, 43.04075860977173, 53.18573651994978, 57.25000885554722, 59.643190792628694, 62.39765821184431, 65.28680256434849, 61.61780629839216, 49.028816904340474, 33.343067509787424, 47.77688005992344, 48.54160574504307, 46.056071826389854, 38.674534933907644, 40.02016128812517, 42.20911829812186, 44.093591349465505, 46.534382343292236, 51.72725057601929, 53.69402156557356, 47.593194007873535, 39.77872180938721, 28.656031608581543, 26.03538302012852, 14.959311757768903, 4.75454546724047, 4.744937411376408, 3.8784714256014143, 3.4176408393042426, 2.178150389875684, 2.5324598806244984, 8.292542134012495, 12.879394565309797, 15.080352851322719, 15.205536808286395, 7.96326960836138, 15.920412642615181, 31.582168170383998, 18.84310289791652, 10.467827694756643, 16.971671615328106, 11.632619363921028, 10.905768309320722, 8.524387887545995, 9.341469117573329, 10.09871767248426, 14.6414247240339, 16.74218303816659, 21.583196231297084, 30.92416681562151, 39.11741311209542, 29.20810420172555, 32.597907951899934, 27.801019293921335, 17.830413375582012, 7.0964127864156445, 2.422446881021772, 2.2934025483472005, 4.842140972614288, 5.696632606642587, 0.34637288376688957, 0.3524530732205936, 0.2742260465664523, 0.550572813621589, 6.681675681046077, 31.706054551260813, 40.78075974328177, 53.42047446114676, 40.6765958241054, 31.250099863324845, 67.6340777533395, 15.441647018705096, 0.346074464065688, 0.10571576947612421, 0.04967593548021146, 0.03388705324115498, 0.036081859575850625, 0.07245447819254228, 0.0204307538723307, 0.09415915102830955, 0.09542597590812615, 0.0993372756721718, 0.11011454236826726, 0.06358236140970673, 0.058902607166341374, 0.09896087194127695, 0.06678444958691086, 0.12694271973201207, 0.060417884428586276, 0.05017833298604403, 0.024377322190308144, 0.06352381062294755, 0.048600186061646254, 0.032212846114167144, 0.06268531775900296, 0.05724607248391424, 0.17419874827776635, 0.21666308465812886, 0.25123201470289913, 0.2443098718566554, 0.15349971183708735, 0.10865816194564104, 0.18956766144505569, 0.11542643340570585, 0.1574851144105196, 0.08908722390021596, 0.1248829181173018, 0.12645215248422964, 0.14885618457836763, 0.11326584219932556, 0.12150180526077747, 0.1920181228114026, 0.145604956895113, 0.1465502240295921, 0.2689519567149026, 0.1407413671591452, 0.2015806489757129, 0.15060037241450377, 0.29053561283009394, 0.22203455785555498, 0.09720316090221916, 0.2546108476817608, 0.2766049089176314, 0.29361103209001677, 0.40350813791155815, 15.753205980573382, 93.38761751992362, 101.95913069588798, 68.3596989767892, 85.48261029379708, 95.77993093218122, 84.83599008832658, 65.93517371586391, 45.97476748057774, 5.94722763981138, 0.24179228980626377, 1.1268391971077238, 2.7394556190286363, 2.0324835777282715, 1.0027450216667992, 10.005680424826485, 37.03091076442173, 37.96580130713326, 47.074524879455566, 47.8739081791469, 41.247366019657676, 31.84417084285191, 36.49351624080113, 45.435726233891074, 34.715944698878694, 36.2223801612854, 35.10580464771816, 21.917630399976456, 15.567630018506732, 17.454133680888585, 22.10034544127328, 23.947859287261963, 27.63766540799822, 25.142652409417288, 26.75762047086443, 19.019528082438878, 34.18650933674404, 29.85296998705183, 30.920036111559185, 21.294536794934952, 13.493868929999215, 9.180616583142962, 6.768545533929553, 3.8986572452953885, 1.699999138712883, 1.5427244922944476, 0.29557302966713905, 0.6815356090664864, 0.7580223019633974, 2.7171043498175482, 10.067330922399249, 27.785917384283884, 44.880012784685405, 54.02235174179077, 59.72666645050049, 61.416808809552876, 65.53492273603166, 66.14548179081508, 62.19866875239781, 52.9757376398359, 43.526778153010774, 53.560494559151785, 56.64021062850952, 51.50649241038731, 44.73507683617728, 44.95777007511684, 49.783888067517964, 50.9554967880249, 51.38497189113072, 54.140050751822336, 55.231379985809326, 48.12930311475481, 43.29355839320591, 30.14439480645316, 31.265469278608048, 20.609159537724086, 4.874166522707258, 4.457911670207977, 5.894118215356555, 6.8826223611831665, 3.52561845098223, 7.240818066256387, 23.02715870312282, 32.41473259244646, 35.83294752665928, 35.578414167676655, 21.31153382573809, 16.655582427978516, 37.902030740465435, 24.794384377343313, 12.031504154205322, 22.08455044882638, 16.439849546977452, 15.582592964172363, 14.84561664717538, 15.128825221742902, 15.664870057787214, 19.72537473269871, 25.553120715277537, 28.08893527303423, 36.08520187650408, 40.20638690676008, 31.14695038114275, 32.53945623125349, 35.09592430932181, 37.16872133527483, 20.544781003679546, 6.183284001691001, 3.26322255390031, 4.902654571192605, 9.799169540405273, 1.3154915826661246, 0.6014253763215882, 0.5817308702639171, 0.5466394818254879, 9.016860570226397, 48.357808521815706, 56.88390827178955, 79.30443886348179, 45.22202396392822, 42.77057443346296, 84.63942555018834, 13.012393508638654, 0.7664061178054128, 0.18615406033183846, 0.13610979568745407, 0.20723159717661993, 0.2163675826575075, 0.21392427305025713, 0.28678980097174644, 0.2749992779323033, 0.23042091141854013, 0.275505465056215, 0.13474887157125132, 0.09372628639851298, 0.17486489324697427, 0.25874448301536696, 0.32530078877295765, 0.1795701536216906, 0.11771229574722902, 0.15273564069398812, 0.15533459266381605, 0.12287556725953307, 0.15125628507563046, 0.10062970846359219, 0.23549887750829968, 0.19336292493556226], [0.08312785439193249, 0.02848608073379312, 0.04158206104433962, 0.0639522240630218, 0.09663222796682801, 0.07095138741923229, 0.06468135065266065, 0.06609026755073241, 0.017468831468639628, 0.1331507180418287, 0.01634081619392548, 0.07666870991566352, 0.06100927519478968, 0.049340294740561924, 0.031008812864976268, 0.06985214711832148, 0.02038178569637239, 0.09302225203386374, 0.020509526698983142, 0.05337009386026433, 0.020074002211913466, 0.24017732217907906, 0.12418040367109434, 0.11006601354373352, 0.10623157822660037, 0.17374631469803198, 0.14730347932449409, 0.3785080036946705, 0.029510091857186387, 1.1649205365351267, 18.452178137642996, 53.0107113974435, 43.524721486227854, 34.95125239236014, 46.19136714935303, 44.78215088163103, 21.779222284044536, 13.729566591126577, 1.4709646914686476, 0.11780677496322564, 0.21643972450069018, 0.9574517777987889, 0.9224503359624318, 0.3239033594727516, 1.141994086759431, 15.160364832196917, 33.63851533617292, 38.08161040714809, 41.457458700452534, 28.17899261202131, 26.150306224822998, 20.11518951824733, 21.551015649523052, 15.769763537815638, 18.28275500025068, 22.720164707728795, 10.436268976756505, 9.432510495185852, 7.779762472425189, 2.9136630254132405, 9.710342032568795, 10.532375591141836, 9.691737362316676, 19.132153170449392, 18.03749574933733, 27.162688289369854, 24.23443947519575, 21.48892307281494, 20.603486333574565, 7.312753200531006, 1.64422963985375, 1.4745163066046578, 0.6371326574257442, 0.6763800999947956, 1.17612743803433, 0.16382287575730256, 0.0940794503050191, 0.5833643483264106, 2.1409575513431003, 6.003153690270015, 18.513740914208547, 32.46764659881592, 55.404376234327046, 58.38002913338797, 53.7534738268171, 59.10541411808559, 55.883968693869456, 51.82372978755406, 31.49955061503819, 17.516759531838552, 33.232473032815115, 27.45765495300293, 25.354464769363403, 22.572300093514578, 23.93170472553798, 26.22802530016218, 29.839153494153702, 34.27920525414603, 43.04075860977173, 37.93108810697283, 27.317980527877808, 23.855679273605347, 21.371356078556605, 14.453759959765843, 6.171275777476175, 1.1732914873531886, 3.2430195808410645, 2.17920760171754, 2.2684491787637984, 2.560732752084732, 3.1264720175947462, 14.977910348347255, 18.778118133544922, 19.46904526438032, 18.027393068586075, 10.917602828570775, 3.0084575159209113, 22.35937081064497, 13.539571574756078, 7.48076411655971, 21.752261536461965, 17.60289808682033, 7.576047369412013, 4.662621234144483, 7.20101009947913, 6.167273615087781, 7.870120321001325, 10.273668101855687, 11.651687826429095, 18.887908356530325, 11.408365385872976, 15.76937096459525, 26.127936499459402, 30.881536143166677, 20.69769695826939, 7.237175038882664, 0.40827842908246176, 0.6200562651668275, 2.1389464821134294, 0.9771011748484203, 0.7320397847465107, 0.13968401961028576, 0.2788040137716702, 4.546010485717228, 22.79118398257664, 14.660280397960118, 41.574542794908794, 32.00496258054461, 13.435774173055377, 42.44721916743687, 30.475427831922257, 0.7749771550297737, 0.21977051720023155, 0.07226407448095934, 0.11578034370073251, 0.024636636222047464, 0.048193278788988075, 0.004263813549187034, 0.10675696110618965, 0.05953836055206401, 0.05665932289723839, 0.035057312409792624, 0.045167141527469666, 0.03765414395768728, 0.15194512025586196, 0.07960000833762543, 0.1069826554240925, 0.06970163448048489, 0.039172952994704247, 0.04314462201935904, 0.12063204550317355, 0.014299837140632527, 0.09452317828046423, 0.06395991865013327, 0.029017655245427574, 0.05890722120446818, 0.03785702253558806, 0.052235393319278955, 0.08005830445992095, 0.08682817047727959, 0.13078959259603704, 0.06741808594337531, 0.08235829390053238, 0.043603372760117054, 0.03315192161660109, 0.07243036305797951, 0.025138853916100094, 0.016507167535434877, 0.014245642548693078, 0.02340949546279652, 0.020258673998926367, 0.10524825884827546, 0.06761878303119115, 0.051088950729795864, 0.0708562500242676, 0.07824556423085076, 0.025256435553144132, 0.23027084661381586, 0.14637339780373232, 0.11032456252723932, 0.12908676825463772, 0.1333630316491638, 0.1863816138356924, 0.22922196718198912, 0.08657479871596609, 2.1155894611563, 48.38462162017822, 82.19876657213483, 52.51632622310093, 60.64442620958601, 71.95965099334717, 63.901630537850515, 33.96010575975691, 13.387912375586373, 2.033382066658565, 0.06635004468262196, 0.11338204810661928, 0.6562461746590478, 0.4034063576587609, 0.1928120902074235, 1.4590998824153627, 8.195561783654348, 16.26992266518729, 34.362802505493164, 46.02112586157662, 37.19351250784737, 34.270801407950266, 38.06897510801043, 38.84272650309971, 28.60113910266331, 30.1560469354902, 33.42229781832014, 20.669426475252422, 18.01578610283988, 15.424337318965367, 11.054159249578204, 19.966539757592336, 21.68091917037964, 16.448871782847814, 21.625046968460083, 19.262805359704153, 20.936855690819876, 17.989334310804093, 14.528723205838885, 15.916973284312657, 9.351493631090436, 1.3408472963741846, 0.4124171127166067, 1.842994477067675, 1.4649998801095145, 0.295279468276671, 0.3137558682688645, 0.4930624653186117, 0.46447307084287914, 2.2024701706000736, 8.94218827996935, 22.20124023301261, 37.46363762446812, 56.543463911329, 57.184216363089426, 60.898452350071494, 67.36502960750035, 66.0349428994315, 60.503780773707796, 40.27701187133789, 28.973701511110576, 44.1864401272365, 37.720227650233674, 32.988692011152, 31.332540239606583, 32.95741122109549, 36.824267864227295, 37.71548203059605, 44.059875215802876, 52.87425919941494, 45.343905789511545, 37.25151259558541, 30.417570182255336, 24.819469111306326, 19.589742422103882, 11.024028386388506, 2.4960458917277197, 4.979989758559635, 2.8507212485585893, 2.69160532951355, 1.6176889325891222, 3.3036532529762814, 6.957548260688782, 8.499238014221191, 10.311045936175756, 7.487325821604047, 8.049588816506521, 8.434236747877938, 23.777850764138357, 17.561089038848877, 11.622873646872383, 18.930926391056605, 19.11499285697937, 13.39567003931318, 9.368293506758553, 14.605643238340106, 14.02212222984859, 14.663886513028826, 18.239709172930034, 23.52353627341134, 34.01219640459333, 25.685904264450073, 28.00688920702253, 30.953057425362722, 20.214534861700876, 10.712973168918065, 4.9613794428961615, 1.4130723008087702, 1.1049754960196358, 3.3807763031550815, 0.3412741816469601, 1.329797055040087, 0.20875323909733975, 0.6696322592241424, 6.3228941559791565, 37.44777488708496, 34.097607135772705, 51.85974924904959, 55.673730100904194, 26.63170174189976, 51.103378772735596, 51.598465715135845, 1.0412651832614626, 0.2784718301679407, 0.03285384118290884, 0.05865167134574481, 0.05130841609622751, 0.05280564771965146, 0.009489827922412326, 0.07809898709612233, 0.04869882469730718, 0.0618390217423439, 0.10722481778689794, 0.11431451807064669, 0.010169692021528525, 0.16311010186161312, 0.06983240174927882, 0.03312353849677103, 0.0968880628102592, 0.12558624680553163, 0.0611549566632935, 0.1087504562788776, 0.12006998780582633, 0.011475747251617057, 0.040711086709052324, 0.01623788073525897, 0.10498670395463705, 0.2697346604296139, 0.1315118931233883, 0.24471311164753778, 0.18897588391389164, 0.29994070529937744, 0.21748070578489984, 0.11409248784184456, 0.13801908466432775, 0.08324283893619265, 0.20744304225913116, 0.17672212501721724, 0.07594086575720992, 0.18613639127995285, 0.11723519063421659, 0.11699471782360758, 0.20985897976372922, 0.1364729476294347, 0.13641630352607795, 0.1597608801509653, 0.14423247054219246, 0.09964802435466222, 0.26122827402182985, 0.20270130384181226, 0.30681681632995605, 0.15320697825934204, 0.4961858434336526, 0.3336155568914754, 0.39149396972996847, 0.22021733251001152, 1.2135768170867647, 52.452930859157014, 111.47847543443952, 79.15250955309186, 79.30752386365617, 91.45841544015067, 85.88240269252232, 43.02623687471662, 17.097423587526592, 3.6726927076067244, 0.3141215443611145, 0.3192131354340485, 1.0223558779273714, 2.394499272108078, 1.5056751774890083, 1.8265936885561262, 18.51895032610212, 46.27068778446743, 45.943695136478965, 52.385932854243684, 40.70757436752319, 43.055023261478965, 37.80288342067173, 40.249316351754324, 32.3728905405317, 34.207822935921804, 38.73694712775094, 22.831339359283447, 23.107087305613927, 20.555337054388865, 17.921641486031668, 30.183832781655447, 30.707428182874406, 25.763140439987183, 29.73466648374285, 28.28593581063407, 32.24354634966169, 30.371937888009207, 30.087256295340403, 30.132082598549978, 18.602945361818584, 4.051864155701228, 2.267449289560318, 3.229135343006679, 1.824491641351155, 1.6767265817948749, 0.47265799450022833, 0.9100465529731342, 1.3956500185387475, 3.7705094473702565, 9.011931691850934, 21.64026873452323, 38.25235891342163, 56.420473848070415, 61.334493500845774, 64.08597319466728, 71.59389781951904, 66.7833889552525, 61.996239934648784, 44.070763042994905, 36.56392233712332, 54.76590626580374, 45.539872782570974, 48.83553539003645, 43.441482067108154, 45.634774753025596, 45.605800764901296, 47.878730228969026, 52.27314274651663, 57.56965030942644, 51.72294616699219, 43.42732858657837, 34.802487986428396, 27.158627067293438, 23.273326431001934, 13.260629194123403, 2.8040204516478946, 5.612631056989942, 4.008334560053689, 4.712490192481449, 3.4301745210375105, 9.602117759840828, 19.788212503705704, 26.802648271833146, 32.91538504191807, 31.75812782560076, 23.972398587635585, 8.183450204985482, 27.05691933631897, 19.300129345485143, 9.269467541149684, 18.821862254823955, 19.89408220563616, 14.702332632882253, 11.664720041411263, 18.503587859017507, 18.60861509186881, 19.275775909423828, 24.53936811855861, 27.495025839124406, 35.87339299065726, 26.209817545754568, 29.124701499938965, 38.644796643938335, 37.65768691471645, 26.640866415841238, 7.342604398727417, 0.9264104834624699, 2.099070553268705, 7.558091487203326, 2.5482579129082814, 2.6032796118940627, 0.6861023668731961, 0.9198482355901173, 10.236750585692269, 53.82759026118687, 38.916304452078684, 81.06313214983258, 64.93218735286167, 35.94672427858625, 66.66575595310756, 55.22140237263271, 0.9618886368615287, 0.3333664531154292, 0.1444599697632449, 0.16531487926840782, 0.18903346439557417, 0.16882719365613802, 0.09033764180328165, 0.23436189708965166, 0.15394506151122705, 0.1484313809445926, 0.18664830523942197, 0.1302778007728713, 0.12173740618995257, 0.2873353702681405, 0.3026890978217125, 0.19261421582528523, 0.30215148095573696, 0.2784633891923087, 0.10842923780104943, 0.21954555570014886, 0.20395082607865334, 0.1894323615623372, 0.175318249634334, 0.11445695614176137, 0.20310796344918863], [0.04791655863768288, 0.0076071400627759946, 0.06554192983146225, 0.04151416004502347, 0.04067191488242575, 0.12097056662397725, 0.03732895265732493, 0.12281744394983564, 0.01741494221745857, 0.08951083331235818, 0.040671178671930514, 0.006940757606311568, 0.038598349184862206, 0.07368481145905596, 0.011447205524226385, 0.0629416818597487, 0.031882603120590956, 0.10230087236102138, 0.12556357016520842, 0.06370395488504853, 0.03684878395870328, 0.026518793976200477, 0.1386806834489107, 0.15121684862034662, 0.10541524631636483, 0.04643906559795141, 0.12349696962961129, 0.14739205528582844, 0.09531051638935294, 0.1361009068787098, 14.036030786378042, 41.007399559020996, 58.03209114074707, 37.09422622408186, 44.47189991814749, 46.99382502692086, 21.95412060192653, 5.2245442015784125, 0.9432472714356014, 0.08681443692850214, 0.2531875254852431, 0.35590434659804615, 0.07966835717005388, 0.3574426397681236, 0.07730161345430783, 1.9155810049601962, 21.104215213230678, 34.506060464041575, 44.99723236901419, 42.19424915313721, 40.90106085368565, 23.465214831488474, 18.636435679027013, 17.88218787738255, 15.377119098390851, 12.143057482583181, 12.037131326539175, 14.910144567489624, 9.38241137777056, 4.343297226088388, 15.658241476331439, 13.307068347930908, 5.999904538903918, 13.985561677387782, 9.929427419389997, 18.53242983136858, 13.76747943673815, 13.379430362156459, 11.06116737638201, 1.6961127072572708, 2.6451144984790256, 0.5823194586804935, 0.8933106767279761, 1.9090824850967951, 0.25184120344264166, 0.40852169745734757, 0.6464707106351852, 1.3139368146657944, 0.997109055519104, 3.976379360471453, 10.652899043900625, 27.017462253570557, 45.688550336020334, 57.73624031884329, 55.506281988961355, 56.4467693056379, 56.11386374064854, 47.89283159800938, 27.51330828666687, 25.78426817485264, 27.915014914103917, 20.276293924876622, 12.609650731086731, 9.16808898108346, 14.670153788157872, 16.438930647713796, 19.014916215624126, 31.979768412453787, 38.52941138403756, 29.93808194569179, 23.554896967751638, 18.795886414391653, 18.753611837114605, 10.67151153087616, 2.1299372741154263, 1.4034262469836642, 0.7065674172980445, 0.8770212765250887, 1.2128039385591234, 0.9596661904028484, 4.401413696152823, 11.65063430581774, 12.830158761569432, 11.039035626820155, 4.456364827496665, 5.4479652643203735, 4.712031177112034, 17.258481093815394, 17.170138222830637, 6.871160004820142, 22.049828563417705, 22.077591827937535, 11.083674328667776, 10.961088129452296, 11.372290338788714, 9.537699273654393, 6.38553911447525, 4.955533402306693, 10.110478367124285, 15.176988397325788, 21.316223859786987, 27.152396270206996, 27.241536446980067, 22.549874782562256, 7.334915348461696, 1.2710981305156435, 0.2549189840044294, 0.43161639677626745, 4.564603865146637, 2.566998941557748, 0.40468387625047136, 0.45155077853373116, 3.237616705042975, 30.884127821241105, 14.929735013416835, 35.65740128925869, 45.54957594190325, 16.42507941382272, 30.26669004985264, 52.845135825020925, 2.0307586874280656, 0.3566381686500141, 0.047322552118982585, 0.10286055518580334, 0.1150812626417194, 0.15764151673231805, 0.00617503041368244, 0.14318990148603916, 0.047580717730202844, 0.05425417070676174, 0.010171003290452063, 0.06627721751907042, 0.06726869288831949, 0.05526989013222711, 0.04823603667318821, 0.056022612777139456, 0.1411988761808191, 0.06428906920232944, 0.04715812272791352, 0.023658293898084333, 0.049908038561365435, 0.03018018590020282, 0.03805248811841011, 0.06330085080116987, 0.10269301131899868, 0.039694424119911025, 0.03941575318042721, 0.042207222498421154, 0.055632841906377246, 0.03556907709155764, 0.07075221024985824, 0.09644780214875937, 0.015070778450795581, 0.01669340504200331, 0.10408693259315831, 0.05304372190896954, 0.1047885717291917, 0.03185670683160424, 0.050799263774284294, 0.09004868088024003, 0.01406255514094872, 0.034747425466775894, 0.04424651199951768, 0.05155731291909303, 0.09651001023926906, 0.03262267108740551, 0.12209666334092617, 0.03319186018779874, 0.10052747359233243, 0.16481318404631956, 0.16875319262700422, 0.04736275192616241, 0.09848514425435237, 0.04559432342648506, 0.21019180119037628, 0.1871035343834332, 20.779578004564556, 72.12412875039237, 77.22448866707938, 54.05897569656372, 70.92845494406563, 64.19974994659424, 41.36383867263794, 13.771964498928615, 1.378580248781613, 0.09132019443703548, 0.20385132570351872, 0.16770200617611408, 0.9449921378067562, 0.21143257032547677, 0.43085774034261703, 3.4934841181550707, 7.299651503562927, 14.190587384360176, 36.69769253049578, 49.1369343485151, 48.23027433667864, 33.28740201677595, 35.443507943834575, 37.7774703843253, 31.242140701838903, 25.250427654811315, 22.27484597478594, 25.021256957735332, 18.139347655432566, 16.282769884381974, 23.220655611583165, 23.3360721383776, 14.33270149571555, 21.826027086802892, 14.087553415979658, 16.892800876072474, 15.513711997440883, 13.71218306677682, 14.40481424331665, 11.710512144224984, 4.344502738543919, 1.6393448391130991, 2.0160441398620605, 1.3780906179121561, 0.12723284773528576, 0.11810227696384702, 0.3054497039743832, 1.1027345934084483, 2.494094750710896, 5.390234853540148, 12.956944278308324, 31.01098803111485, 48.60836056300572, 59.2903265271868, 61.481121335710796, 64.26575783320835, 61.66190651484898, 56.69374302455357, 37.70879091535296, 35.906455993652344, 41.403391293116975, 27.769481420516968, 22.24076679774693, 22.778315918786184, 23.53150933129447, 27.58469581604004, 32.08775036675589, 43.11040735244751, 44.30568858555385, 34.79186419078282, 29.965186868395122, 21.37180597441537, 20.71039479119437, 14.511023538453237, 6.107195581708636, 3.230792271239417, 2.3268383656229292, 1.5538127315895898, 2.543851452214377, 0.832248007612569, 1.4416526300566537, 4.757682144641876, 5.233063995838165, 3.29658128959792, 5.327653731618609, 7.368840796606881, 7.509498391832624, 25.255152429853165, 26.963215930121287, 17.93518873623439, 28.558588334492274, 28.486294065202983, 17.934504338673182, 18.653144359588623, 19.798652172088623, 16.135056393487112, 18.72405593735831, 17.72032264300755, 24.03920725413731, 26.9842654977526, 32.659180641174316, 31.55558088847569, 22.008064678737096, 13.332816634859357, 7.549801417759486, 1.1113692500761576, 0.8715611866542271, 2.5684048661163876, 2.7248014339378903, 1.8659691299710954, 0.3109406536178929, 0.42943770225558964, 3.4882790488856177, 44.41004010609218, 31.878175326756068, 44.23860720225743, 62.766892433166504, 35.67742599759783, 37.18454238346645, 63.52384308406285, 10.763606429100037, 0.357715655118227, 0.17153009719082288, 0.06450544723442622, 0.10928815456905536, 0.019851057657173703, 0.05960746934371335, 0.06472139100411109, 0.061957751799907, 0.028345852990501692, 0.02328230407355087, 0.061838573909231594, 0.04058193096092769, 0.06940577285630362, 0.07542530127934047, 0.030788475581045662, 0.02074778070008116, 0.055065213436526914, 0.12768730334937572, 0.042122144385107925, 0.020061352622828314, 0.12502744607627392, 0.022679558023810387, 0.050714911693441014, 0.029574081102120023, 0.020107959496921728, 0.1580500490963459, 0.247407004237175, 0.15814645535179547, 0.14875547641089984, 0.13402905448206834, 0.1493691299110651, 0.12986218450324877, 0.1430354940571955, 0.13461672009101935, 0.21635190849857672, 0.16554615114416393, 0.09830132233245031, 0.1516499575227499, 0.19736431379403385, 0.0828346119129232, 0.11606839538684913, 0.11354737994926316, 0.21389916725456715, 0.19434439869863646, 0.11936310359409877, 0.19810812388147625, 0.17688136361539364, 0.32509085003818783, 0.5563094200832503, 0.49027178649391445, 0.3326292112469673, 0.24622095216597828, 0.21706392243504524, 0.28977706496204647, 0.15805207113070147, 21.167761700493948, 85.51157038552421, 105.99593680245536, 81.40002250671387, 97.17660222734723, 88.6033797945295, 65.19831725529262, 20.696588720594132, 1.5262622556516101, 0.2962112868470805, 0.3560981090579714, 2.3429631803716933, 1.1823829880782535, 0.4631603498544012, 1.0094753290925707, 4.555078753403254, 31.877101830073766, 45.209968839372905, 54.013763768332346, 54.604120935712544, 52.545348848615376, 38.73687069756644, 33.99997104917254, 36.86912543433053, 33.900590964726035, 26.676218850272043, 23.754346745354788, 26.866674184799194, 24.001688718795776, 22.952363082340785, 35.509623527526855, 30.326368127550396, 19.44105965750558, 27.80928417614528, 18.36101082393101, 25.794395174298966, 21.096775429589407, 21.467031036104473, 17.08487687792097, 15.273733377456665, 5.172340648514884, 1.4258159484182085, 3.1401237079075406, 2.7889786873544966, 0.29743642253535135, 0.5516446275370461, 1.0559366302830833, 3.4406856255871907, 3.4974699957030158, 5.2349647624152045, 11.446945258549281, 31.98274224145072, 48.07270656313215, 60.50091116768973, 64.7420151574271, 68.45450714656285, 66.94213444846017, 60.09745012010847, 45.10061461584908, 43.604083810533794, 52.12508705684117, 47.0696576663426, 40.20416348321097, 41.94519097464425, 43.70712559563773, 42.34749514716012, 46.052712372371126, 54.60660491670881, 52.69038554600307, 40.876464230673655, 33.2493189402989, 24.60363027027675, 22.091278042112076, 17.2846097946167, 7.0464222346033365, 3.2649624262537276, 1.7322796008416583, 1.4794535445315498, 1.7811654976436069, 1.3441537703786577, 7.744949391910008, 19.58533205304827, 22.384144612721034, 20.977038860321045, 18.24816860471453, 12.16991834981101, 5.331984630652836, 24.27896179471697, 26.04270121029445, 10.32541481086186, 22.103960241590226, 22.7925215108054, 13.006702933992658, 15.042770045144216, 18.32186119897025, 20.78424198286874, 23.55973638807024, 21.118672677448817, 26.072755643299647, 28.779417719159806, 37.39443704060146, 37.14537191390991, 34.48319394247872, 30.93561397280012, 11.359741023608617, 1.6655614780528205, 0.8908433062689645, 2.827864497900009, 10.975608127457754, 7.268263450690678, 1.4124945146696908, 1.1358362457581928, 6.914065131119319, 59.477837562561035, 31.734622069767543, 69.25389739445278, 78.18219361986432, 39.71073368617466, 54.49220282690865, 78.98591259547642, 8.822774801935468, 0.6961838230490685, 0.28481862960117205, 0.11954850650259427, 0.16116440269563878, 0.311701698494809, 0.18620547971555165, 0.25103513098188807, 0.281216775732381, 0.1700970855142389, 0.111554095122431, 0.14633974246680737, 0.14908881352416106, 0.22531095918800148, 0.16370690055191517, 0.2719768115452358, 0.2149481281105961, 0.4226035518305642, 0.2711073639137404, 0.09435625866587673, 0.11692087964287826, 0.2383704377072198, 0.1959793016846691, 0.12857062023665222, 0.1500104269278901, 0.08365727455488273], [0.025843612616881728, 0.055890478260282955, 0.034420140885881016, 0.028716636755104576, 0.08611246531030961, 0.0105665730911174, 0.03372530745608466, 0.031979806654687436, 0.04915287319038596, 0.011356867916349853, 0.04648217971303633, 0.06941495343510594, 0.008717842516489327, 0.022416876762041023, 0.021038541437259743, 0.015937785052561333, 0.034101565301950486, 0.004751144184930516, 0.13638122326561383, 0.06365546677261591, 0.041744023960615904, 0.08243551797100476, 0.05271340088386621, 0.01863733832059162, 0.07932406850159168, 0.10363128275743552, 0.09856864477374724, 0.11596392813537802, 0.09155812952667475, 0.12083705807370798, 0.302007685814585, 29.196327005113872, 82.92016329084123, 47.95119646617344, 42.04667288916451, 49.260039057050435, 41.659609590257915, 28.67892418588911, 13.301212753568377, 0.4827294083578246, 0.05312274070456624, 0.10944800384874855, 0.4598011129668781, 0.21664658268647535, 0.4383008080933775, 0.4759499207139015, 3.012775169951575, 22.099918127059937, 37.18235717500959, 41.945524488176616, 38.88768482208252, 41.704251766204834, 33.36441237585885, 23.614550726754324, 19.69387854848589, 15.925811392920357, 14.244983094079153, 15.082656179155622, 18.050266538347515, 20.287836619785853, 30.540584564208984, 24.688478197370255, 3.3702825691018785, 8.84595399243491, 11.222425511905126, 17.924780334745133, 9.419951626232692, 7.739921501704624, 5.64918509551457, 0.09292091282882861, 0.2973820040268557, 0.934746693287577, 1.707239704472678, 2.323887118271419, 0.0998812232698713, 0.12463829267237868, 0.1460795649992568, 0.2459919330264841, 0.4934459190283503, 2.1918613570077077, 8.367722511291504, 19.93619350024632, 42.86879069464547, 49.27126039777483, 50.34666436059134, 54.87889787128994, 51.764475549970356, 36.073330879211426, 18.56352823121207, 11.31505628994533, 19.26786538532802, 9.337235059056963, 4.263570555618831, 6.690262785979679, 5.446273812225886, 9.03864404133388, 19.026121922901698, 27.0706559249333, 27.123514345714025, 17.867075545447214, 20.22300818988255, 12.262872219085693, 9.216978243419103, 4.695471014295306, 1.9107248655387332, 1.361906743475369, 1.0326355206114906, 0.41358725992696627, 1.2345888210194451, 0.6497815272637776, 3.1270254850387573, 4.751409224101475, 5.563683603491102, 1.9697263623986925, 1.7509573357445853, 3.041686624288559, 0.4267141712563378, 18.908514976501465, 16.548971005848475, 6.4510423881667, 11.732586571148463, 10.151956507137843, 13.553177016122, 12.589299457413809, 6.415085026196071, 7.591222235134669, 7.748795219830104, 8.335453339985438, 11.305895958627973, 23.621439865657262, 25.39952383722578, 22.59007011141096, 16.009566715785436, 6.690727881022862, 1.9358187190123965, 0.2529339976608753, 0.8129985662443298, 0.9304714884076799, 0.9159464963844844, 0.2053959292492696, 0.7931776898247855, 4.085495608193534, 32.82441922596523, 19.352562189102173, 31.25181954247611, 58.736040932791575, 20.80540793282645, 15.234276294708252, 55.214502811431885, 31.68819420678275, 0.07449494155922107, 0.10988958765353475, 0.1209978030196258, 0.036287079099565744, 0.09082202081169401, 0.023306694014796188, 0.09865619614720345, 0.1674223140414272, 0.11633020133844443, 0.014092065477078515, 0.039794731951717816, 0.018087258462661078, 0.0027043282461818308, 0.08550244197249413, 0.12370769546500274, 0.07107692318303244, 0.08636028665517058, 0.05751814467034169, 0.012800092393133258, 0.025662820353837948, 0.045329898329717774, 0.082172131032816, 0.09770941587963275, 0.09330157775964056, 0.07162595300802163, 0.02602698331299637, 0.04658127635983484, 0.05885920806654862, 0.025283353037333915, 0.01849839979383562, 0.03271199682993548, 0.028067801214222397, 0.038401557066078694, 0.05083992159260171, 0.05758578104100057, 0.044054673186370304, 0.031216393690556288, 0.01181407498994044, 0.008588025196721511, 0.05555663224575775, 0.022398842997582893, 0.05288788616391165, 0.09771919356925146, 0.13252436236611434, 0.06800841819494963, 0.022616613722805465, 0.008429928233713975, 0.053697090063776286, 0.0778976861121399, 0.03272993390315345, 0.13139628432691097, 0.14259255996772222, 0.09802401864102908, 0.21685059102518217, 0.10501700732856989, 0.24069205884422573, 1.8382080367633273, 48.078275544302805, 88.2598261151995, 60.78086103711809, 69.24193954467773, 68.07828998565674, 56.23153843198504, 46.2201326915196, 13.48111116886139, 0.6380859177027429, 0.07530935321535383, 0.339117200246879, 0.26877513048904283, 0.7997297868132591, 0.131980530119368, 0.6653634054320199, 2.727781125477382, 9.06640991142818, 17.456164291926793, 37.05196033205305, 47.58013834272112, 50.18650838306972, 43.111953326633994, 38.93767711094448, 32.40452568871634, 28.47170111111232, 23.882575750350952, 26.57720180920192, 23.3748448235648, 29.98940134048462, 44.35526745659964, 33.14481108529227, 13.19839244229453, 16.718083211353846, 16.77208113670349, 13.937471457890101, 15.947296960013253, 16.44623667853219, 13.350252270698547, 6.516842697347913, 0.9774588985102517, 3.713548115321568, 2.5069990754127502, 0.5793481809752328, 0.24497043926801, 0.2429317400923797, 0.8889226179037775, 0.7340560651251248, 1.552896763597216, 3.463596007653645, 10.934127381869725, 23.68449476787022, 46.00445018495832, 55.550889423915315, 58.07367263521467, 63.73470006670271, 60.4279203414917, 47.06652055467878, 31.881475721086773, 12.899120501109532, 21.487144333975657, 22.6088684626988, 8.561892526490347, 14.93944685799735, 15.911463362830025, 25.091298273631505, 35.9766605922154, 36.63093076433454, 31.742588179452078, 20.337391172136577, 22.611746753965104, 15.511973210743495, 12.743519936289106, 6.6812518409320285, 3.591595070702689, 1.403128668665886, 1.1857725147690092, 0.3654568711561816, 1.34277520435197, 2.0116066294057027, 1.5929507400308336, 2.192354679107666, 4.4421257972717285, 6.760113026414599, 5.13867141519274, 5.981799704687936, 7.344184245382037, 34.03034162521362, 25.615428686141968, 19.081377472196305, 29.280372415270122, 25.99972833905901, 28.123382704598562, 26.594353437423706, 22.58226728439331, 24.3609105859484, 21.962163141795568, 22.384610142026627, 23.42222285270691, 34.35472869873047, 26.63646820613316, 19.211586713790894, 9.350335018975393, 5.006858008248465, 2.297768622636795, 1.1428173397268568, 2.135709924357278, 1.6639986761978693, 2.2492302443299974, 0.4550813048013619, 0.5875417898808206, 3.027070871421269, 46.534622056143625, 32.92356654575893, 36.447112696511404, 69.37927068982805, 43.06580686569214, 27.777084486825125, 63.57088933672224, 50.10457869938442, 0.21919999138585158, 0.057432961384100575, 0.07992436843258993, 0.03467174845614603, 0.03482279035129717, 0.033557675379727564, 0.07220678576933486, 0.07067421943481479, 0.04748151930315154, 0.07306904771498271, 0.051682994567922184, 0.05696039567036288, 0.027399703760498335, 0.07478766835161618, 0.13579002927456582, 0.10499650878565651, 0.06373975439263241, 0.07920268537210566, 0.034100856232856, 0.057990649315927706, 0.06335927945162569, 0.05833721107670239, 0.035254420047359805, 0.048466860715832026, 0.043036534783563445, 0.09469053894281387, 0.17435804115874426, 0.20323512091168336, 0.0881751167720982, 0.12312556670180388, 0.137967353154506, 0.13605771133942263, 0.12933978039239133, 0.2175000168915306, 0.1628242621996573, 0.09980182788733925, 0.09467143139668874, 0.12461225049836294, 0.09268540689455611, 0.10639013150440794, 0.15547595864960126, 0.2103094727333103, 0.2410814565207277, 0.25198920550090925, 0.3121867153261389, 0.1762491182557174, 0.25545513523476465, 0.2106463789407696, 0.25081808120012283, 0.18686136523527758, 0.3041482466672148, 0.22674223381493772, 0.24235009987439426, 0.2755851522088051, 0.21965736470052175, 0.3482808970979282, 0.5420259322438921, 55.15057591029576, 116.54277420043945, 85.2868378502982, 91.70869650159563, 94.5218414579119, 80.77526133401054, 71.99293286459786, 29.901836667742046, 0.698852148439203, 0.126679285296372, 0.5717560797929764, 1.6917986358915056, 0.8751906976103783, 0.6950846506016595, 0.8668496023331369, 5.2442488585199625, 31.701948165893555, 50.514706543513704, 54.15058422088623, 51.1649363381522, 52.4949084009443, 46.981363432747976, 38.55357027053833, 34.5473119190761, 32.00232573917934, 29.948705741337367, 26.7539153439658, 30.104140417916433, 35.20978791373116, 51.28613029207502, 41.50741624832153, 15.510930980954852, 18.4342656816755, 22.214478288378032, 22.191764627184185, 15.546424116407122, 13.824540649141584, 10.18347179889679, 3.508188460554395, 0.25131504024778095, 2.9739106382642473, 4.512950088296618, 2.226882666349411, 0.20310037742768014, 0.43493980701480595, 1.0163227788039615, 1.0116586919341768, 1.7509577700069971, 3.8002681476729254, 10.757910643305097, 22.933323281151907, 44.91611215046474, 54.86696086611067, 58.78568581172398, 61.52285916464669, 64.153822353908, 54.189167567661826, 45.234193733760286, 23.782073531832012, 38.00499956948416, 38.60687337602888, 27.13246362549918, 31.979938643319265, 33.255155427115305, 37.70649453571865, 47.09709957667759, 45.76003687722342, 35.259175709315706, 23.79779383114406, 27.327464818954468, 18.14345404079982, 13.602867926870074, 7.009478662695203, 5.7573268583842685, 1.9803138971328735, 1.610810975943293, 0.401545488940818, 1.5404701275484902, 3.8426191551344733, 4.147093994276864, 8.061174069132123, 17.667344365801128, 18.673794405800955, 6.229317554405757, 4.790847199303763, 4.26944134916578, 28.36768136705671, 22.825259685516357, 11.062755039760045, 17.616780587605067, 17.650076355252946, 19.189981290272303, 18.441587345940725, 14.178117973463875, 21.484894854681833, 22.805459056581768, 23.537865195955547, 24.655442987169536, 34.478618553706575, 33.22404486792428, 33.154086930411204, 23.478308711733135, 9.161804335457937, 2.6652147684778487, 1.8152205731187547, 3.6570062807628085, 6.213782685143607, 4.546291019235339, 0.8728823757597378, 2.1364622839859555, 7.106989681720734, 60.69290379115513, 33.6740380014692, 57.163041727883474, 92.62214142935616, 46.908362184252056, 35.61605255944388, 82.1827301297869, 50.46788610730852, 0.19390668932880673, 0.17397686732666834, 0.2651259963001524, 0.11306958273053169, 0.17120149625199182, 0.14814892038702965, 0.159282472250717, 0.2565704568156174, 0.32963176923138754, 0.23492366980229104, 0.17075221107474395, 0.13125869099582943, 0.175502906154309, 0.16952585402343953, 0.1856519037059375, 0.16229431277939252, 0.12350598057465893, 0.1323712170124054, 0.0889020041961755, 0.19886564037629537, 0.14643484593502112, 0.18377252455268586, 0.11547351016529969, 0.15911621760044778, 0.24086902077708924, 0.11793235822447709], [0.0385703867567437, 0.057798786754054685, 0.03800544867824231, 0.1123996718919703, 0.031218076457402537, 0.08503031052116837, 0.06970084737986326, 0.028903145675680468, 0.031102579619203295, 0.01683681850720729, 0.01945694416229214, 0.03266135776149375, 0.04014077802587833, 0.03307127433695963, 0.02753923091638301, 0.060797802970877717, 0.06582766771316528, 0.04359281475522688, 0.03297860680946282, 0.059616921336523125, 0.12153742834925652, 0.05081362836062908, 0.02791241160593927, 0.05178699702290552, 0.05693950357713869, 0.10138880594500474, 0.0973593732342124, 0.08498311841062137, 0.09153908983405147, 0.12209105864167213, 0.054359150252171924, 4.731663312230792, 59.16566889626639, 59.161361013139995, 47.493053095681326, 54.522778374808176, 50.434711933135986, 36.12763105119978, 34.12302017211914, 19.84622996194022, 0.44526105746626854, 0.1724396055298192, 0.4070016975913729, 1.0677377113274165, 0.035828257112630775, 0.7719651109405926, 0.30515931812780245, 2.7652303959642137, 18.86131933757237, 35.010530948638916, 33.695695536477224, 37.20446981702532, 40.208919525146484, 36.34715591158186, 32.73061159678868, 19.477289302008494, 25.743582998003276, 19.645159517015728, 22.22302109854562, 38.44681814738682, 26.750547204698833, 23.41086254801069, 11.084562829562596, 10.924018621444702, 18.742232424872263, 13.237666266305105, 11.824536425726754, 12.172074028423854, 9.59898064817701, 3.648760940347399, 1.495409214070865, 1.6240040851490838, 0.7593522848827499, 1.0409391607557024, 0.1901788315070527, 0.21695851880524838, 0.6439589368445533, 1.2009713734899248, 0.48243296997887747, 1.6931410495723997, 5.093082112925393, 20.43680947167533, 25.085479157311575, 40.254642145974294, 39.41461535862514, 44.42306797845023, 36.17216205596924, 16.184444189071655, 8.996334723063878, 2.572624376841954, 1.031489176409585, 6.418739778654916, 3.69670090505055, 3.946292357785361, 1.307218340890748, 11.430089797292437, 19.42193647793361, 18.837360211781093, 10.923085825783865, 5.405550854546683, 4.796185152871268, 6.257175488131387, 2.075606486627034, 1.1912065488951546, 0.6200896490897451, 0.6070085253034319, 0.13539014144667558, 0.14573448923017296, 0.2298650283898626, 0.9464832863637379, 1.4343640783003397, 2.6549205780029297, 1.2860204726457596, 0.5252274136458124, 1.2487003952264786, 1.2350154838391711, 7.684140494891575, 23.803960357393535, 13.408627561160497, 5.433982014656067, 2.6808184683322906, 1.6187406075852258, 6.524365425109863, 8.428216133798871, 5.700821501868112, 5.791109868458339, 8.653787664004735, 16.961812121527537, 25.187838281903947, 28.22006688799177, 18.377443313598633, 13.961723276547023, 6.354683467320033, 2.094349903719766, 0.5253885792834418, 0.1610050962439605, 1.263841062784195, 1.0779390782117844, 0.3908481943820204, 0.6982895614845412, 3.7204012104443143, 33.56063992636544, 23.464837891714915, 31.111806392669678, 65.48259585244315, 39.13293538774763, 19.130629777908325, 39.554444381168906, 44.50227744238717, 2.0040274475302016, 0.09500719087996654, 0.08693857491016388, 0.003379804980275886, 0.06800899494971548, 0.01557396475358733, 0.021557140663000088, 0.058688027252043994, 0.021318403205701282, 0.038908120776925764, 0.06404587546629564, 0.02322483215747135, 0.033827817134026966, 0.03926689616803612, 0.022711201504405056, 0.04308483629886593, 0.017267866359491433, 0.060922856974814615, 0.08197906067860977, 0.014153226927321936, 0.1204993376242263, 0.08070739784411021, 0.02712805905113263, 0.09059956989118031, 0.12300622596272401, 0.027096276470859135, 0.05075614626652428, 0.06279381550848484, 0.053584415931254625, 0.058140944822558334, 0.05821006718490805, 0.03400563741368907, 0.11829564587346145, 0.15696002330098832, 0.057334159900035174, 0.005891133058217487, 0.023389644920825958, 0.07391391880810261, 0.0855074767023325, 0.034634995606860945, 0.06787813268601894, 0.04461426101624966, 0.057947847326951366, 0.0560830872106765, 0.015434159398345011, 0.1069890743653689, 0.04667391674593091, 0.07139341905713081, 0.02454484230838716, 0.027176435205287168, 0.020972306241414378, 0.11044891085475683, 0.06568194553256035, 0.00992564672404634, 0.07444238902202674, 0.04075777670368552, 0.017825091191168343, 0.13002214234854492, 16.260179553713115, 93.42101056235177, 76.60411180768693, 69.33020945957729, 75.82706001826695, 67.46547971452985, 55.132677350725444, 53.24633870806013, 16.010152101516724, 0.5006070147667612, 0.16732609777578286, 0.592115658734526, 1.195492067507335, 0.04287737421691418, 1.3850109151431491, 0.7194753789475986, 1.3802794090339114, 10.86382724557604, 19.27150103024074, 27.67278334072658, 36.167913232530864, 45.74440343039376, 47.16540731702532, 43.09884902409145, 34.35356487546648, 35.82038170950753, 30.64393901824951, 40.19654825755528, 44.63495329448155, 40.96283033915928, 34.906776973179404, 24.05524890763419, 21.51671413012913, 28.7999062197549, 20.306264979498728, 11.751165185655866, 16.93298751967294, 16.110313858304703, 9.241044197763715, 3.787032263619559, 3.4518631058079854, 2.8050433567592075, 0.9352101598467145, 0.018217608432418535, 0.18070668620722635, 0.47268974993910107, 0.5166759725127901, 0.7258810209376472, 2.2642848193645477, 5.798992165497371, 22.009977170399257, 29.06583115032741, 43.46349048614502, 45.99296828678676, 49.815297399248394, 43.9731582232884, 25.527858802250453, 19.226895332336426, 5.835045499461038, 1.4138843715190887, 16.759834936686925, 10.441352452550616, 14.007105435643878, 12.664090735571724, 24.816556079047068, 26.214700392314366, 20.662280253001622, 12.543339729309082, 5.248958434377398, 6.792745241097041, 6.279959499835968, 2.3457876230989183, 1.1738005514655794, 0.5608641813908304, 0.33002762656126705, 0.9147063515016011, 0.032130197156220675, 0.12416762007134301, 0.5879852803690093, 0.5616306002650941, 1.3199826159647532, 1.7261056921311786, 1.078770256468228, 3.2196725479194095, 4.131388459886823, 18.953108515058243, 32.91912317276001, 22.25041263444083, 11.446326868874685, 11.470029779842921, 16.00260635784694, 25.90056712286813, 25.908908435276576, 22.50504674230303, 25.030261823109218, 28.253263643809728, 29.4743834904262, 27.622518335069927, 23.786777462278092, 12.274425336292811, 10.416000212941851, 4.043457703930991, 1.7022351558719362, 0.7225537023374012, 0.45637456540550503, 2.305699339934758, 0.6530202020491872, 0.6545276354466165, 0.41445887887052124, 2.8398336384977614, 51.93930264881679, 39.74989373343331, 32.83511945179531, 66.73552281515938, 55.99354873384748, 32.21261296953474, 43.56140797478812, 66.23414775303432, 7.055054068565369, 0.24406220657484873, 0.14274981724364416, 0.09830666240304708, 0.0932026541392718, 0.07170291923518692, 0.07402193479772125, 0.07363264568682228, 0.012824126951662558, 0.0478346153561558, 0.08900919915842158, 0.023220526852778027, 0.030587941341634308, 0.0726148160174489, 0.06222892153475966, 0.08067188332123415, 0.02061338326893747, 0.05520268123862999, 0.07972019724547863, 0.04128921550831624, 0.0445167453560446, 0.09083626326173544, 0.019203016002263342, 0.02474676924092429, 0.029388735869101117, 0.029779833275824785, 0.07826509246868746, 0.12540917630706513, 0.16640763277454035, 0.08832735288888216, 0.19929765005196842, 0.0956763146179063, 0.2006011429641928, 0.2684691111956324, 0.14066153072885104, 0.14666405506432056, 0.04886097421071359, 0.10861373825797013, 0.1223656889051199, 0.19353468929018292, 0.11515352662120547, 0.15250253677368164, 0.181013696161764, 0.19383806229702064, 0.13400606571563653, 0.439461347247873, 0.11626104504934379, 0.24818482249975204, 0.2744862511754036, 0.2977318838238716, 0.17763566385422433, 0.2217516494648797, 0.1797148444290672, 0.2929528531219278, 0.20737647797380174, 0.32237784990242546, 0.11931152136198112, 0.25106650644115036, 10.892222796167646, 96.54895060403007, 102.540785244533, 88.9752265385219, 97.87792560032436, 92.30159323556083, 70.33578055245536, 70.5463387625558, 37.77472584588187, 0.4429727116865771, 0.39311108152781216, 2.7757525742053986, 3.5314321390220096, 0.1079718577010291, 1.9097230221543993, 0.8265288802129882, 4.407358748572213, 25.85279130935669, 52.19135202680315, 51.6420830317906, 48.08705806732178, 49.77823918206351, 45.87015887669155, 43.176293645586284, 32.48743159430367, 37.04652336665562, 30.77003492627825, 39.221462385995046, 51.653988770076204, 41.854676791599815, 38.90814726693289, 25.05860005106245, 20.166239670344762, 26.13424893787929, 25.187786170414515, 12.618219596999031, 12.202968324933734, 11.394146765981402, 5.6278806158474515, 2.027010134288243, 3.725760442870004, 5.329011670180729, 1.3449522703886032, 0.1606284821672099, 0.38752217856901033, 0.8854978073920522, 2.2378388898713246, 1.920813649892807, 2.4705616363457272, 5.48936002595084, 24.056565591267177, 29.240618297031947, 41.25376878465925, 51.215147495269775, 52.742653369903564, 56.10714830671038, 36.63441181182861, 30.685131413596018, 8.177322762353079, 4.752679875918797, 38.077239990234375, 20.250118323734828, 28.50432985169547, 25.799936362675258, 37.95760243279593, 38.00986678259713, 27.869002205984934, 18.119965655463083, 9.857868790626526, 9.958610721996852, 7.072897042546954, 3.0392845017569403, 1.7659276638712202, 1.1840420876230513, 1.4695568127291543, 1.9040053061076572, 0.23182298189827374, 0.504860126546451, 3.45206047807421, 5.93995200736182, 4.456043039049421, 3.675260501248496, 1.336884217602866, 2.069908312388829, 1.5972375614302499, 14.17134608541216, 32.57460369382586, 16.994532925742014, 7.932516012872968, 6.5449346985135755, 10.331933089665004, 21.0500487940652, 17.069594315120153, 16.005894592830114, 16.295087303434098, 23.697083166667394, 27.41808843612671, 33.83057744162423, 32.654306479862754, 28.633623668125697, 24.76314353942871, 9.399287683623177, 2.0859482288360596, 2.64827766588756, 0.4749130649226052, 5.180061399936676, 6.8132823790822705, 2.1249645352363586, 1.3212382857288634, 7.615750244685581, 66.49528884887695, 39.71350254331316, 50.72652585165841, 89.6671837397984, 65.23684501647949, 41.61925792694092, 63.36222103663853, 77.39862442016602, 4.261265924998692, 0.2788610921374389, 0.20992939812796457, 0.2097977894757475, 0.17595646610217436, 0.16879290049629553, 0.09711356035300664, 0.2434260935655662, 0.12011253195149557, 0.1811512080686433, 0.31882259781871525, 0.14395475972976002, 0.2075046668095248, 0.1547190256948982, 0.1411753717277731, 0.15093533801180975, 0.09547232663525002, 0.2423104734293052, 0.22976034400718554, 0.1409653244274003, 0.27190257981419563, 0.14513809766088212, 0.15118828229606152, 0.2926479737673487, 0.16721892995493753, 0.09442778304219246, 0.10963596483426434], [0.047539822424628904, 0.07810455108327524, 0.023954325156020265, 0.0428827855336879, 0.09677398071757384, 0.08464234455355577, 0.11690800104822431, 0.058611067810228894, 0.048005477259201665, 0.08758248428681067, 0.014159527124970086, 0.06592100699033056, 0.04283337461362992, 0.012249579969128328, 0.04323181037658027, 0.05200683558359742, 0.06281891451882464, 0.09931454474904708, 0.014670437700780374, 0.029480467018272196, 0.05843009573540517, 0.10334089691085474, 0.02232942377616252, 0.015639336513621465, 0.09574164396950177, 0.12729558508310998, 0.16633825935423374, 0.21170865265386446, 0.06873046766434397, 0.23027860905442918, 0.02190265408717096, 0.25002050399780273, 17.283011708940776, 63.91092027936663, 57.34798540387835, 34.250304222106934, 56.3496230670384, 59.062953676496235, 35.130710465567454, 39.48431273869106, 21.773927756718226, 0.5898933751242501, 0.15145288381193364, 1.2480067695890154, 0.5345213349376405, 0.2547398507595062, 0.22977057631526673, 0.19060799133564743, 1.5524508846657616, 15.809451648167201, 31.824670723506383, 38.725722312927246, 41.51729311261858, 36.31008727209908, 43.598289012908936, 36.429589339665, 20.22843647003174, 25.8898286819458, 19.589686836515153, 50.44041987827846, 35.191458565848215, 19.611368690218242, 9.407003658158438, 6.334635743073054, 31.090465000697545, 28.038004977362498, 18.80602557318551, 12.65167430468968, 15.277759858540126, 6.591283525739398, 3.2968596518039703, 1.2824621264423643, 2.1185941227844785, 0.8866093020353998, 0.2612619293587548, 0.1360732497913497, 0.07399674757782902, 1.5225703737565448, 0.22926808042185648, 0.5841219733868326, 2.899067682879312, 5.586656953607287, 11.095267398016793, 24.630580595561437, 24.28254532814026, 26.53589824267796, 17.22744001661028, 8.232272590909686, 6.853036063058036, 2.9480976462364197, 0.2921161380197321, 1.3149939179420471, 2.789081173283713, 3.9082917911665778, 8.55747868333544, 11.831890225410461, 10.134045788219996, 5.344630352088383, 1.4097512790134974, 1.0394370470728194, 0.2557900601199695, 0.6655428100909505, 0.19813018984028272, 0.08356831182858773, 0.020107131684198976, 0.09826069165553365, 0.04868103350911822, 0.08926710353365966, 0.5163209629910332, 0.06643395232302801, 0.08360306639224291, 0.08088332840374537, 0.23069750943354198, 0.28293895189251217, 0.5280534848570824, 4.996500415461404, 19.845088720321655, 26.35675457545689, 11.210875000272479, 6.937222608498164, 4.615388248647962, 2.561274060181209, 1.7721172060285295, 10.672301019941058, 17.93419861793518, 21.260452406747, 17.264390536717006, 17.404441901615687, 25.671467644827707, 20.078364065715245, 11.937214493751526, 5.094067454338074, 0.7928245802010808, 0.8016147570950645, 2.236966673816953, 0.6689332595893315, 1.006907969713211, 0.39187090950352804, 0.6531377785972187, 7.292047568729945, 30.611786229269846, 17.059267554964336, 24.756452424185618, 66.91458484104702, 52.43743290219988, 23.01196472985404, 35.9062614440918, 54.151796681540354, 6.154390786375318, 0.2866401161466326, 0.11491245669978005, 0.14182306054447377, 0.07052294683775731, 0.07797332919601883, 0.03313021528135453, 0.0694720046594739, 0.07873731891491584, 0.041508385712014775, 0.012443301716952451, 0.048218052102518935, 0.032035819720476866, 0.025871027127972672, 0.05922786971288068, 0.07485779494579349, 0.053356217819132974, 0.05908535700291395, 0.08319909378354039, 0.03294096847197839, 0.01579269390952374, 0.033636324373739104, 0.01470493442112846, 0.04443257308698126, 0.030818022388432707, 0.06734084830220256, 0.040002740254359584, 0.010892462434380181, 0.04551034793257713, 0.048909011097358804, 0.0627911217244608, 0.030995852846120085, 0.05235041518296514, 0.02474559028632939, 0.11118305181818348, 0.014635415115792836, 0.018719827822808708, 0.06839897616633347, 0.0601893470489553, 0.08591314564858164, 0.06080471724271774, 0.04872245128665652, 0.08821356256625482, 0.0431622164323926, 0.011458872085703271, 0.08122877736708947, 0.06468839384615421, 0.017267693333061676, 0.07017921456801039, 0.10049879191709415, 0.031492978134857755, 0.01378116921322154, 0.04006914508395961, 0.1137246268668345, 0.016389563846002733, 0.0917636781398739, 0.07542745902069978, 0.17406623038862432, 0.03274430866752352, 0.9884945920535496, 42.85220187050955, 84.97277927398682, 74.5304080418178, 68.79530239105225, 77.41634232657296, 65.07530634743827, 51.0750162260873, 61.52912643977574, 17.30593729019165, 0.4471176921256951, 0.26006325653621126, 0.7312861766133989, 0.7181672719972474, 0.11046261047678334, 0.4454569098140512, 0.39265117049217224, 0.9998157045670918, 10.725264532225472, 16.78596190043858, 29.641595363616943, 34.124566146305625, 33.59735768181937, 47.79170751571655, 44.76553079060146, 38.16517986570086, 36.19188451766968, 36.31416239057268, 55.20708213533674, 42.564678464617046, 39.722337177821565, 20.298074790409633, 22.133854866027832, 43.29170669828142, 42.700689452035085, 25.122480051858084, 13.829414810453143, 17.25500178337097, 10.473250763756887, 5.552433601447514, 1.959695769207818, 4.688108963625772, 0.7715476219143186, 0.13869008794426918, 0.09185108023562602, 0.4431477737213884, 1.7750520599739892, 0.3758131611560072, 1.1163495885474342, 4.81170916557312, 8.810473016330175, 13.120639494487218, 26.945272207260132, 27.605008874620708, 30.357812200273784, 26.27968863078526, 19.748413222176687, 12.91900016580309, 3.575621162142072, 0.2989424988627434, 1.7977472650153297, 8.532558100564138, 12.746815987995692, 17.796216079166957, 15.44845277922494, 9.691696541649954, 5.86986813374928, 1.8977862341063363, 1.40610770881176, 0.615491624389376, 0.5547388557876859, 0.3685053932879652, 0.032332329345600944, 0.044863439431147914, 0.19993772570575985, 0.09733575343021325, 0.09772164986601897, 0.6997380437595504, 0.186319052906973, 0.10811592425618853, 0.07936694512942008, 0.13758643716573715, 0.49854790525777, 1.6243727739368166, 15.756737402507238, 39.0049843106951, 35.35337591171265, 16.311924525669642, 5.745152311665671, 4.814229624611991, 10.946268490382604, 11.984902586255755, 21.658514704023087, 29.82688992364066, 26.639999628067017, 20.452757324491227, 15.860474007470266, 14.209451743534633, 9.744513273239136, 6.435572224003928, 3.618966196264539, 1.7086469318185533, 0.47888933441468645, 0.9556987690074104, 0.10994582463588033, 0.4204703191561358, 0.15434519361172402, 0.44384853754724773, 5.266779260975974, 48.91777426855904, 36.21376786913191, 29.752561569213867, 65.53105953761509, 66.32257052830288, 43.924277646201, 43.6943895476205, 67.97305951799665, 20.396266732897075, 0.4107295961252281, 0.11729297467640468, 0.07041007932275534, 0.027524947754240463, 0.030822320907775844, 0.10293645611298935, 0.026032152053500925, 0.015862404901002134, 0.03167119196483067, 0.12384113616177014, 0.03048216112490211, 0.05655845527404121, 0.020350245692368065, 0.08260865296636309, 0.08656667665179286, 0.05935077276080847, 0.04980492498725653, 0.08233210923416273, 0.034454464579799345, 0.03346974063398583, 0.08630305901169777, 0.05262555434767689, 0.037411496442343505, 0.0474236029466348, 0.06484511507941143, 0.050642478080200296, 0.036134822626731226, 0.1212593646986144, 0.16596944843019756, 0.19988676772585937, 0.15439031619046414, 0.2748229131102562, 0.17742280741887434, 0.2658410907856056, 0.09794256051204034, 0.11600719152816705, 0.27859347792608397, 0.24586122004049166, 0.14919047164065496, 0.2463687370930399, 0.13623414401497158, 0.27750399495874134, 0.12250702774950437, 0.3094733623521668, 0.3113774401800973, 0.18222410764013017, 0.2436750073518072, 0.32155060714909006, 0.22069811528282507, 0.25128876737185885, 0.11966558093471186, 0.18185843154788017, 0.24478324502706528, 0.3789792055530207, 0.3031550885311195, 0.16803477331995964, 0.38696607840912683, 0.1741759359304394, 0.5575303488544056, 40.118415764399934, 101.85209369659424, 91.66704205104283, 75.49202483040946, 93.97488621303013, 95.53107425144741, 63.33182961600167, 76.985748563494, 43.43606942040579, 0.6558290113295827, 0.44613710045814514, 4.068597154957907, 3.230191686323711, 0.4616764751928193, 0.47083816358021324, 0.27143634483218193, 2.332047994647707, 18.025131429944718, 47.35625001362392, 58.37210818699428, 53.80766977582659, 42.8390211377825, 51.39424426215035, 47.71070541654314, 33.87092563084194, 34.22409214292254, 28.92969856943403, 61.72431523459298, 46.507326057979036, 35.573064054761616, 23.9597042288099, 18.06197599002293, 40.192011083875386, 41.00507886069161, 32.11316340310233, 17.957046031951904, 17.12105441093445, 9.053071107183184, 5.786203137465885, 2.4566120420183455, 6.434022341455732, 1.9876935354300906, 0.45266189319746836, 0.43814821913838387, 1.0402819045952387, 2.848511287144252, 2.3851393972124373, 2.3136489476476396, 7.101269142968314, 10.097026654652186, 16.39145186969212, 32.2619104385376, 34.225162165505544, 37.56041213444301, 37.32243980680193, 31.963818822588237, 18.636769192559377, 5.785930854933603, 0.8163827732205391, 4.307910484927041, 15.392069884708949, 21.544166462762014, 26.734430858067103, 25.63435905320304, 14.422870005880084, 9.348737801824297, 3.4726575442722867, 2.6205128814492906, 1.161352745124272, 1.0064436346292496, 0.8429714121988842, 0.4383799795593534, 0.11575678496488503, 0.21667118636625154, 0.2671442851424217, 0.3487704465431826, 1.9090655488627297, 0.5357710878763879, 0.20421141066721507, 0.4895220867225102, 0.2652928887733391, 0.26981855449931963, 0.47290362417697906, 10.342138256345477, 39.64454167229788, 44.60576391220093, 16.09299894741603, 7.814024908202035, 5.802682093211582, 15.634169442313057, 13.63244640827179, 20.01092311314174, 30.291057382311138, 25.66491723060608, 23.48148056438991, 23.86309126445225, 32.32413155691964, 25.942435230527604, 16.372827223369054, 7.419797148023333, 2.7444389973367964, 1.882851732628686, 3.1039231589862277, 3.742469991956438, 5.162316569260188, 1.088068466101374, 1.9296600094863345, 14.759193216051374, 60.13114888327462, 33.19041906084333, 42.201245989118306, 90.14669282095772, 74.80247170584542, 47.78007623127529, 59.9612306867327, 86.14917182922363, 16.647604158946447, 0.4771663982953344, 0.18759685648339136, 0.24030374682375363, 0.17986980825662613, 0.2069069588822978, 0.18700575748724596, 0.17772844673267432, 0.2075389056865658, 0.16596087174756186, 0.20545650885573455, 0.22002519853413105, 0.14962770603597164, 0.13298985095960753, 0.21040625896837029, 0.17180451032306465, 0.19433769477265223, 0.13872940226324967, 0.3803579072867121, 0.1424833701125213, 0.10781215091368981, 0.13678951135703496, 0.09475824995232479, 0.17734162748924323, 0.18095152878335544, 0.16357723250985146, 0.1753971225449017, 0.14873269120497362], [0.01876968827231654, 0.05297445705426591, 0.027294702162700038, 0.029120008860315596, 0.05325215768867305, 0.028700148354151418, 0.05423724465072155, 0.04442821689216154, 0.017703718239707605, 0.09770344477146864, 0.028807926856513535, 0.07867423551423208, 0.03938167715179069, 0.05020648879664285, 0.047416742957596264, 0.03429195883550814, 0.009948043468674379, 0.0385141599524234, 0.04140213052076953, 0.06188153874661241, 0.042116566827254634, 0.15287684383136885, 0.05807183603090899, 0.020336764897885065, 0.12058514516268458, 0.06938082312366792, 0.11122077157987015, 0.10353662033698388, 0.03161873781521406, 0.036283879806952815, 0.0016046841109138249, 0.09803150966763496, 0.46641981495278223, 52.8503817149571, 76.24856553758893, 45.218775681086946, 22.959472826548986, 66.2063410622733, 55.835723876953125, 30.11084542955671, 40.6427754674639, 29.92934458596366, 0.6341618139828954, 0.3721649497747421, 0.7757726694856371, 1.8938383545194353, 0.27969151043466156, 0.3546542136796883, 0.0732710272339838, 1.0682742425373621, 7.639956031526838, 18.51688497407096, 25.686625140053884, 33.636295386723106, 29.36607497079032, 31.49488489968436, 26.89522954395839, 23.47468522616795, 19.13269512993949, 25.465118306023733, 33.16780267442976, 13.160529971122742, 7.9589530399867465, 7.846902046884809, 27.951974119458878, 49.35899182728359, 51.38369689668928, 38.827266761234824, 13.32055914402008, 3.3632155997412543, 0.82760851085186, 0.40601277351379395, 3.3260138588292256, 0.7115432502967971, 0.16127561458519526, 0.5674433654972485, 0.289982118244682, 0.24327592019523891, 1.1913685287748064, 2.1774329883711676, 2.696362239973886, 1.7732802693332945, 1.649786787373679, 4.055676979678018, 6.454864331654139, 13.952042698860168, 12.41166615486145, 6.7225376026971, 4.572163505213601, 0.8249621157135282, 0.11512071266770363, 0.1784447490104607, 1.3127825451748711, 1.737832948565483, 6.636488940034594, 7.055373251438141, 3.1879327424934933, 1.5653711685112544, 0.21475276430802687, 0.07803566620818206, 0.20103148344372, 0.0141736398051892, 0.04241369052657059, 0.05564867212836232, 0.0641028859785625, 0.13388958839433535, 0.10119397818510022, 0.03664350336683648, 0.16988437835659298, 0.566104317350047, 0.22717794829181262, 0.6924975865653583, 0.25062925847513334, 0.1111421836540103, 0.7705004523907388, 4.023462525435856, 15.92342642375401, 13.044582775660924, 3.7997613634381975, 4.0120110256331305, 5.424169855458396, 4.140645197459629, 4.235713490418025, 6.931753507682255, 15.81955259186881, 23.905437060764857, 25.231571980885096, 22.680038860866002, 16.824243000575475, 8.550142254148211, 3.2469259883676256, 0.8264842597501618, 0.9404363994087491, 0.11522214008229119, 0.49857162684202194, 0.18692493039582456, 0.49356756678649355, 0.563031476523195, 11.413763267653328, 30.92895065035139, 13.745385902268545, 23.278938838413783, 63.88835253034319, 58.32349164145333, 23.461184876305715, 32.544021197727744, 63.542783873421804, 20.257884672709874, 0.3731871763510363, 0.10582111882311956, 0.12395758634167058, 0.010208237899600394, 0.042117784797613106, 0.023209845015246953, 0.07364943942853383, 0.00962248067038932, 0.032242983247020414, 0.04436898757038372, 0.014172855249073888, 0.10086283952529941, 0.03786327184310981, 0.05879184989524739, 0.03723581015531506, 0.04341797663697174, 0.025301402068829963, 0.015163298396925842, 0.0984026954642364, 0.03804332111030817, 0.13983143812843732, 0.07791095147175447, 0.048893974761345556, 0.08171175180801324, 0.04195217475561159, 0.019292514771223068, 0.05485730691413794, 0.15758062499974454, 0.04447868632684861, 0.033372513351163695, 0.012896779392446791, 0.041989843627171855, 0.03132951565619026, 0.05114489933475852, 0.10931595414876938, 0.09197400363960437, 0.03042912682784455, 0.01991287219737257, 0.0539825395680964, 0.11636224176202502, 0.06277085388345377, 0.10062356093632323, 0.025648360772590553, 0.017280008743650148, 0.047244001512548754, 0.050087517859148126, 0.042487823870033026, 0.11274387235088007, 0.02708726213313639, 0.09777686904583659, 0.024953593499958515, 0.01298821622705353, 0.04215520939656666, 0.10509108299655573, 0.11601736955344677, 0.052573771947728734, 0.014587306982970663, 0.06811103983117, 0.0155024403772716, 0.16551461283649715, 5.850310257502964, 74.80968393598283, 86.492753301348, 55.976536069597515, 63.4707727432251, 83.46361664363316, 61.69368757520403, 49.18001665387835, 63.68673665182931, 23.488211631774902, 0.8807064816355705, 0.12270096662853446, 1.0216600809778487, 0.8720111367957932, 0.36524644387619837, 0.18508569337427616, 0.06836081535688468, 0.7512840692486081, 6.5016500268663675, 12.454682452338082, 16.4704806804657, 22.361427477427892, 23.82751301356724, 27.373753717967443, 30.001143796103342, 31.06772702080863, 27.22394708224705, 38.83647312436785, 28.934953144618444, 26.951318877083914, 26.00334140232631, 17.58597574915205, 43.35577951158796, 58.07926593508039, 52.353981563023154, 30.799630778176443, 10.64475314957755, 5.219664394855499, 1.8115818883691515, 3.439247782741274, 4.155379721096583, 0.7009849197098187, 0.19626165367662907, 0.4711266223873411, 0.5210605572376932, 0.3703772271318095, 1.570658096245357, 2.9646525979042053, 3.5145855801446095, 2.0164293306214467, 0.506777069398335, 2.6182112906660353, 5.990306036812918, 15.133002826145717, 15.051019293921334, 7.917355912072318, 4.0324239645685465, 0.9974144505602973, 0.33313113717096193, 0.5294391076479639, 3.316573428256171, 3.6642324072974066, 10.248146499906268, 8.23316022327968, 3.8990797826222012, 2.566712111234665, 0.39598475875599043, 0.4247497852359499, 0.16196567112846033, 0.07625182478555612, 0.060693973542324135, 0.11915131924407822, 0.08102601074746676, 0.07511460009430136, 0.026539041461156945, 0.025333328837794915, 0.13622689726097242, 0.24503747852785246, 0.14001726172864437, 0.25039926224521225, 0.4696557755981173, 0.34872881163443836, 2.368769875594548, 19.499801465443202, 33.27920661653791, 21.37360382080078, 4.096832896981921, 0.6176283583045006, 4.372173505170005, 4.528510579041072, 4.732124064649854, 16.50834662573678, 19.92767674582345, 15.1933878830501, 10.383361050060817, 10.119368587221418, 7.47888810294015, 7.696343268666949, 4.02561559847423, 1.6919752721275603, 0.7540852789367948, 1.129275192107473, 0.1964642642331975, 0.4522070033209664, 0.30746690716062275, 0.6172838253634316, 9.657005923134939, 49.786726406642366, 32.341106006077354, 26.655325617109025, 55.28536401476179, 74.98309012821743, 46.94210263660976, 41.02077831540789, 70.34271485464913, 44.218891688755576, 0.41620675793715883, 0.0767407635492938, 0.046844222250261476, 0.0418080369542752, 0.02412644404518817, 0.05469967305128064, 0.02203013894281217, 0.08964797881032739, 0.039478778905634365, 0.048728147588138065, 0.02702664351090789, 0.05761812680533954, 0.01900133503867047, 0.10753997694700956, 0.04670377567942653, 0.0912821829052908, 0.022558860214693204, 0.03992491228772061, 0.06528038172317402, 0.12302477711013385, 0.04488782597971814, 0.034388728107192686, 0.06932027065860373, 0.017268166611237184, 0.037183936153139384, 0.07117286803466932, 0.06273181097848074, 0.1239936708339623, 0.08002099181924548, 0.17581125960818358, 0.07497234522764172, 0.13023749579276356, 0.15434835558491095, 0.13335452282002994, 0.2344415842422417, 0.18584145924874715, 0.18602868063109262, 0.1708892344364098, 0.1860803442874125, 0.24833920278719493, 0.08006796001323632, 0.17950601849172795, 0.21366075719041483, 0.0699533981138042, 0.14323790105325834, 0.21701979051743234, 0.1754330713301897, 0.31551891937851906, 0.26811347742165836, 0.3798750346260411, 0.14554022465433392, 0.08527389780751296, 0.2301562556198665, 0.15764446157429898, 0.2686545955283301, 0.32289475787963184, 0.10632626778845276, 0.14683413665209497, 0.19962204407368386, 0.13465231603809766, 2.839040675333568, 87.37554972512382, 110.65326568058559, 78.24751363481793, 60.377399989536826, 103.0731006349836, 90.3961262021746, 58.736117362976074, 74.49748747689384, 58.70691408429827, 0.9870929015534264, 0.6519817177738462, 2.232994258403778, 5.989939519337245, 0.830221142087664, 0.5288521477154323, 0.19487801220800194, 1.4002427778073718, 8.539303064346313, 26.16943982669285, 38.76408331734793, 50.31153426851545, 42.11428928375244, 43.02461099624634, 36.88879925864083, 34.20324754714966, 29.101348604474747, 32.61796045303345, 38.68864325114659, 20.6826263155256, 20.633556400026592, 19.79016147341047, 43.89842339924404, 63.071800231933594, 68.89724636077881, 48.03297676358904, 19.220292806625366, 3.9633810179574147, 1.0401461975915092, 3.413965459380831, 6.3493633185114176, 1.3647027420146125, 0.724939974290984, 0.833871063377176, 0.8797386192849704, 0.35077356334243504, 1.2672159331185477, 3.538864105939865, 4.874648553984506, 3.6134866731507436, 2.4629392453602383, 5.4877067889486035, 10.279720851353236, 21.463794912610734, 22.988401651382446, 14.409499066216604, 9.443290625299726, 1.2700348390000207, 0.4871507968221392, 0.8024989696485656, 5.08766382081168, 11.284908056259155, 17.71473455429077, 11.749973569597516, 5.815174085753305, 3.6798528262547086, 0.8880139238068036, 0.8364479222467968, 0.71233838477305, 0.17913992170776638, 0.2604203830872263, 0.3309016339480877, 0.127212043851614, 0.3724384808114597, 0.1667403592062848, 0.09785704474364008, 0.4972672654049737, 2.2241854625088826, 0.620491124689579, 3.48827948314803, 0.8758595702903611, 0.16496102325618267, 0.7150144726037979, 14.690687452043806, 30.751823697771343, 20.511962924684795, 3.3836769589356015, 3.6112986419882094, 5.9524426971163065, 16.81122555051531, 9.691382135663714, 23.561353581292288, 30.79031671796526, 31.500714438302175, 32.43241228376116, 32.62275471006121, 20.334690059934342, 13.0382399388722, 6.189437065805707, 2.3678494564124515, 1.6007578011069978, 1.2428610857043947, 0.8817928976246289, 1.0429287339959825, 2.1218543478420804, 0.9668978537831987, 26.685362679617747, 56.24089765548706, 25.57304641178676, 41.71439266204834, 83.23090062822614, 83.85883017948696, 45.83932277134487, 52.023375851767405, 92.38151836395264, 45.54556335721697, 0.43003676725285395, 0.11368083421673093, 0.22128664941659995, 0.14025546823229107, 0.16370018305523054, 0.22254911810159683, 0.24052831477352551, 0.13588659837841988, 0.13684000793312276, 0.16919130911784513, 0.11261153088084289, 0.23895302787423134, 0.22319701047880308, 0.22184072754212789, 0.14352019876241684, 0.138193671724626, 0.11010440505508866, 0.08463310290660177, 0.24561594320195063, 0.2255140311483826, 0.16870579017060144, 0.11982095188328198, 0.18539566174149513, 0.24442782838429722, 0.12473681595708642, 0.2804063063647066, 0.14527232545827115, 0.2437359940792833], [0.029537704839770283, 0.019344375202698365, 0.038388932922056744, 0.04895453740443502, 0.10090405374233212, 0.02883305979360427, 0.03631015946822507, 0.028706309452120746, 0.03273508398394499, 0.018896201126543537, 0.02315318734118981, 0.056082174581076415, 0.048591809546841044, 0.10877587420067616, 0.06881387997418642, 0.03886751724140985, 0.01742162578739226, 0.06062901059963873, 0.07299361497695957, 0.04000115587509104, 0.01559422241656908, 0.07888049658920084, 0.026157292570652704, 0.05823288631758519, 0.03227473868589316, 0.07673579667295728, 0.02548377531846719, 0.030413741046296697, 0.023997245888624872, 0.08287254880581583, 0.04041003429197839, 0.016096772592780844, 0.04028158761294825, 15.381044830594744, 74.71593884059361, 67.41861411503383, 39.23885025296892, 30.595725468226842, 75.37369700840541, 53.51735666819981, 25.755389724458965, 45.56865916933332, 39.27962228230068, 2.872364887169429, 0.2050639492060457, 0.29098417876022203, 0.8141784029347556, 0.24270779639482498, 0.027629123235653554, 0.2357337320489543, 0.5148558158959661, 4.349069007805415, 8.074950609888349, 18.12969660758972, 23.394225086484635, 23.878545795168193, 28.117038999285015, 26.637640714645386, 24.69585371017456, 9.281909159251622, 17.009072031293595, 21.434973784855433, 6.263464042118617, 7.226885191031864, 21.6471300806318, 32.96541901997158, 42.053013120378765, 42.261785643441335, 25.374117749077932, 4.3067193031311035, 0.5470418259501457, 0.02559496515563556, 0.8232745719807488, 0.04771018899711115, 0.08311606823865857, 0.24415131179349764, 0.164858537326966, 0.05213815925110664, 0.21568580424146994, 1.0600089260510035, 1.8004327437707355, 0.6801009146230561, 0.4465466099125998, 0.16540080894316944, 0.5774533312235559, 4.207622792039599, 5.970688666616168, 1.7824991175106593, 0.25403800127761705, 0.12923369822757586, 0.09389532304235867, 0.22455555972244057, 0.33017486866031376, 0.5565165632537433, 3.3737881524222235, 2.263641676732472, 0.7427377849817276, 0.22943806701472827, 0.0871024207611169, 0.03342971046056066, 0.07670635503849813, 0.06351724240396704, 0.01603864419407078, 0.020144963404163718, 0.02533649929266955, 0.030824159737676382, 0.045887067182255645, 0.02728197623842529, 0.08207370274301086, 0.137910519061344, 0.4625797410096441, 0.2729584888688156, 0.0694304376042315, 0.2883804499038628, 1.9865266723292214, 2.9794587748391286, 3.104649462870189, 1.9702798298427036, 2.221640250512532, 6.0710462757519315, 2.9863062245505194, 5.090655888829913, 2.597089635474341, 5.033741022859301, 15.357099601200648, 13.720692873001099, 12.165747693606786, 8.483592408043997, 3.7689356803894043, 1.1565134333712714, 0.0979104522349579, 0.13042038812169007, 0.3819809630513191, 0.024818461554657136, 0.18459351121314935, 0.9941621507917131, 0.46751296200922554, 22.86516319002424, 29.491257190704346, 11.733410801206317, 28.27492638996669, 64.29524598802838, 68.0790125983102, 25.914958579199656, 29.229608876364573, 57.07492814745222, 34.97040510177612, 1.1603523130927766, 0.25881787336298395, 0.05492627999878355, 0.11130856722593307, 0.04086548735254577, 0.05611132105280246, 0.09759432276976959, 0.09405969815062624, 0.0423944065613406, 0.1395341990781682, 0.06264250898467642, 0.025416093146694557, 0.008006705586532397, 0.053879524381565194, 0.06148583069443703, 0.028135418925168257, 0.03004064517361777, 0.05558780753718955, 0.06567858678421803, 0.03720443808872785, 0.02029118430800736, 0.04837412194215825, 0.03754151053726673, 0.0474882164437856, 0.031137727733169283, 0.028463879067982947, 0.036799596955201457, 0.03142912798960294, 0.07545175057436738, 0.032921175605484417, 0.04957928495215518, 0.012279438902623951, 0.04846045195258089, 0.0478224152965205, 0.033360031699495654, 0.06653593613633088, 0.11965562004063811, 0.019770970168922628, 0.012769551531943892, 0.03173104214615055, 0.04461316178951945, 0.046719799283891916, 0.04031236256871905, 0.08580381330102682, 0.0414450173266232, 0.04845128494447895, 0.07516206361885581, 0.014629043671967728, 0.03551671454416854, 0.11317837903542177, 0.05337113880419305, 0.056816654812012396, 0.04551277708794389, 0.038301435831402025, 0.031079048024756566, 0.05590471053229911, 0.10834081790276937, 0.021205225260928273, 0.05803115785654102, 0.07304400977279459, 0.07923577073961496, 0.2359733906175409, 33.7419809613909, 97.00646863664899, 76.44118349892753, 45.88208545957293, 70.47536986214774, 87.27466188158307, 58.98870522635323, 50.02934013094221, 75.504364831107, 33.87527520315987, 1.0094274516616548, 0.5034960540277618, 0.20041203525449547, 0.8111319435494286, 0.4808682139430727, 0.31848677726728575, 0.27832806216818945, 1.0081677649702345, 3.798644006252289, 6.856083282402583, 13.186531867299761, 13.54767838546208, 10.693445256778173, 13.538390380995613, 22.632851907185145, 19.590221847806657, 19.00725930077689, 22.558012860161917, 14.226246408053807, 10.52330732345581, 17.595218590327672, 28.272235700062343, 48.06962851115635, 56.80196816580636, 41.04542704990932, 18.238672154290335, 2.5742582891668593, 0.8461287170648575, 2.6234289535454343, 2.448557125670569, 0.06552334475730147, 0.1841924020222255, 0.12760947538273676, 0.07841458730399609, 0.0894991692953876, 0.12430617692215101, 1.3253914628710066, 1.8081621804407664, 1.7165157667228153, 0.8923309264438493, 0.3809788211115769, 0.8715491901550974, 3.6772872039249966, 5.135513024670737, 1.0275914541312625, 0.13022404722869396, 0.021049459065709795, 0.17800505831837654, 0.218085877597332, 0.6319798624941281, 0.42621379239218576, 2.1325265637465884, 3.2472890317440033, 1.112575739622116, 0.42656397074460983, 0.09201702954513685, 0.05613485603992428, 0.05470895880301084, 0.05464684570740376, 0.06637975773108856, 0.01747368469036051, 0.039906194899231195, 0.039203371719590256, 0.01375485138435449, 0.02090122121652322, 0.029157620056399276, 0.1577955306108509, 0.11182949213044983, 0.5753332078456879, 0.3908014026071344, 0.8235178674970354, 4.080181973321097, 6.6522986974034986, 5.438697670187269, 3.2266954396452223, 1.1418788986546653, 4.5649347731045316, 6.764619367463248, 10.263582791600909, 7.784911956105914, 8.422714897564479, 8.507313558033534, 5.322706179959433, 9.094887971878052, 5.916517904826573, 4.217920890876225, 2.4254977915968214, 0.5475653292877334, 0.4621920532413891, 0.6082688633884702, 0.18342508748173714, 0.2756470888853073, 0.48537108089242664, 0.4889806700604302, 16.228153569357737, 52.985485962459016, 28.61304657799857, 20.770265681403025, 49.98127596718924, 81.78892013004848, 47.66471529006958, 32.708273138318745, 59.28323936462402, 62.77829442705427, 4.800970724650791, 0.48593404782669886, 0.08164067526480981, 0.13263284654489585, 0.02310509277906801, 0.11407207750848361, 0.05165926619832005, 0.0599136311294777, 0.020111353868352513, 0.08436813498181955, 0.0747543726382511, 0.08440854852753026, 0.02384762043532516, 0.052320739453924556, 0.021403873172987784, 0.033186635468155146, 0.008901102102494665, 0.037684627143400054, 0.02406780674521412, 0.046443330190543614, 0.08094022356505905, 0.02027635322883725, 0.023636996380186508, 0.03362323543322938, 0.03154496070263641, 0.054555392757590325, 0.03089753312191793, 0.007978213052930576, 0.0599264350852796, 0.09587242480899606, 0.14029031779084886, 0.27070523692028864, 0.08516858238726854, 0.17475479415484838, 0.12271106322961194, 0.1289466643439872, 0.17784550759409154, 0.11714699465249266, 0.1427951298121895, 0.12633053186748708, 0.15971345055316175, 0.1441359014383384, 0.12856257281133107, 0.15417640124048504, 0.2573100599859442, 0.08611140679568052, 0.13733954541385174, 0.15727262438407966, 0.1446717269718647, 0.20568277314305305, 0.19652864363576683, 0.251314605985369, 0.161451857270939, 0.0856092840965305, 0.21101394136037144, 0.1507413719913789, 0.1972008275666407, 0.13482676739139215, 0.1442303942250354, 0.1484047280890601, 0.09176605979778937, 0.3140269565795149, 26.56675692967006, 115.13515949249268, 105.5410521371024, 72.88083621433803, 69.16078458513532, 113.0029102052961, 93.08282089233398, 55.28103181294033, 80.20625250680106, 68.57606588091168, 3.856776544025966, 1.6806353777647018, 0.7749629872185844, 1.882632430110659, 0.7891806843025344, 0.2724235590015139, 0.43726957057203564, 0.9005933659417289, 6.570694710527148, 11.882282904216222, 25.22343216623579, 34.855884892599924, 38.45035825456892, 43.28184373038155, 41.53620263508388, 35.24005774089268, 18.35122776031494, 25.53968116215297, 27.48549117360796, 9.584148849759783, 20.189453601837158, 36.35753652027675, 53.527567046029226, 62.951422691345215, 56.436930656433105, 30.94605016708374, 4.503261693886348, 0.4060524271002838, 3.044798331601279, 3.720828090395246, 0.3338933491281101, 0.48858777114323204, 0.44138610682317186, 0.27974649891257286, 0.22521646640130452, 0.2711777687072754, 1.8461639412811823, 3.18573819739478, 2.8997030087879727, 2.585601006235395, 0.6686898555074419, 1.4966889853988374, 5.795700890677316, 6.943412150655474, 1.995386276926313, 0.5371209925838879, 0.18511936228190148, 1.1963630893400736, 1.467128417321614, 1.111460770879473, 0.34736023364322527, 4.6236183898789545, 5.207485939775195, 1.9930990168026514, 1.0137429343802589, 0.22245180260922226, 0.14364116798554147, 0.23614918547017233, 0.15555116747106823, 0.2375297871019159, 0.12420579445149217, 0.11323230899870396, 0.09814413969538041, 0.15282443378652844, 0.1372837291232177, 0.1965801173022815, 0.44421662922416416, 0.9322564154863358, 0.7940781872187341, 0.43998962747199194, 0.9227808096579143, 2.2886263132095337, 2.7158729987485066, 1.698469340801239, 1.952782528741019, 3.262667349406651, 9.361915928976876, 8.809873734201703, 15.531167609351021, 17.968857969556534, 22.687275409698486, 26.689357893807546, 19.88977258546012, 18.852649722780498, 11.117641466004507, 5.842080984796796, 1.9910286707537515, 0.519959919154644, 0.580903274672372, 1.7769138514995575, 0.3599740367914949, 1.3246481141873767, 2.1855552153927937, 0.8540497177413532, 40.667323453085764, 50.42045770372663, 22.44549720627921, 42.21475676127842, 78.77531964438302, 90.16205528804234, 43.54777560915266, 47.44243894304548, 77.74079540797642, 67.27029091971261, 3.205935307911464, 0.5725535484296935, 0.08039930223354272, 0.2682535270495074, 0.16370523135576928, 0.2056554960353034, 0.2896640481693404, 0.15873420238494873, 0.15951265847044332, 0.26761396708233015, 0.1803939358464309, 0.12674215835119995, 0.09718483367136546, 0.12311317665236336, 0.15075898676046304, 0.12990424010370458, 0.12776917538472585, 0.13403315283358097, 0.15358994342386723, 0.16240542967404636, 0.14381504936942033, 0.20169207799647534, 0.13177194845463547, 0.14762655698827334, 0.13275118305214814, 0.17243697281394685, 0.15030119275408133, 0.12825115237917217, 0.21593617009265081], [0.07460984467927899, 0.04088082902931741, 0.08440925420394965, 0.03682616838653173, 0.0643357252702117, 0.04312207090801426, 0.04977420770696231, 0.017835421886827265, 0.08149212359317712, 0.08292730658182076, 0.010698675377560514, 0.01238932934523161, 0.0644136346610529, 0.06979585585317441, 0.014916934206017425, 0.020409083160172616, 0.013943282255370702, 0.07163097416715962, 0.04997556297374623, 0.039902602056307454, 0.010911164555831679, 0.05540470825508237, 0.058916374641869745, 0.02253489605417209, 0.06693804277373211, 0.03229623806795903, 0.013611100347978728, 0.14388185792735644, 0.025731823972559402, 0.05083122955901282, 0.06101251180682864, 0.0704135127099497, 0.01522832240776292, 0.13959657001708234, 22.16856459208897, 77.4166966847011, 65.69578048161098, 33.83076504298619, 38.6546630859375, 83.30353709629604, 60.29585593087332, 25.737869841711863, 36.53736284800938, 48.472332205091206, 5.5867021168981275, 0.9221052059105465, 0.1848357075027057, 0.453767932419266, 0.21625284238585404, 0.039614146641854725, 0.31321029897247044, 0.20167249547583715, 1.537673369050026, 3.336588582822255, 6.564410933426448, 10.799913372312274, 20.17756870814732, 15.162242582866124, 22.155979667391094, 17.73997735977173, 11.737162828445435, 31.357227189200266, 34.45345565250942, 14.090535930224828, 21.73628067970276, 25.8617353779929, 25.568069764545985, 16.844276394162858, 8.201550262314932, 3.8082255721092224, 2.234690704516002, 0.45609929731913973, 1.2468676992825098, 0.652153631406171, 0.059655828534492424, 0.16341226707611764, 0.10271535547716276, 0.08384301673088755, 0.05754035312150206, 0.10825729702732392, 0.18220839276909828, 0.19355854658143862, 0.26131439368639675, 0.6081147002322334, 0.7532773880021912, 0.3894075559718268, 0.4994188185249056, 0.23390233889222145, 0.4118118594799723, 0.07571187375911645, 0.008388549471939248, 0.1198349432753665, 0.16562165852103913, 0.16757233813405037, 0.40265076820339474, 0.7147465869784355, 0.38688261860183304, 0.0607363141274878, 0.032896551569657664, 0.02097671671903559, 0.08997218284223761, 0.002934366460457178, 0.025116603056501065, 0.010255530094062644, 0.02415572792025549, 0.05980632760162864, 0.048743306060454676, 0.08450249848621232, 0.008991575417374926, 0.03798280596467001, 0.1641160843095609, 0.03502655441739729, 0.17304331170661108, 0.11729195687387671, 0.38956855876105173, 0.7589443496295384, 0.26908478673015324, 1.1555384056908744, 4.153448121888297, 4.406682167734418, 2.5784380648817335, 3.8688355769429887, 5.424086477075305, 8.336980206625801, 6.568277171679905, 7.535261443683079, 4.22749160017286, 1.797711438366345, 0.13611176343900816, 0.2607363632747105, 0.16769078320690564, 1.1212472000292368, 0.6301855987736157, 0.46214200449841364, 0.4703503240432058, 5.741441973618098, 28.0207473891122, 22.22168357031686, 12.177255647523062, 39.91579934528896, 68.13772487640381, 77.20239339556012, 29.674050399235316, 26.499020678656443, 63.712709018162315, 59.11280700138637, 2.548660474164145, 0.20106184110045433, 0.07222708075174264, 0.07753255284790482, 0.04918134791244354, 0.06244533349360738, 0.06958933014954839, 0.04817520261609128, 0.02073979264657412, 0.03209063517195838, 0.054066867900214026, 0.006753343689654554, 0.03562411306692021, 0.006913478378139968, 0.06373881801430668, 0.04068370782104986, 0.0561666725469487, 0.0653890355357102, 0.009386728767172565, 0.06237978022545576, 0.020301085830266987, 0.022605825016008954, 0.14267112075218133, 0.06431223438786608, 0.05496201504554067, 0.09620080861662116, 0.03476123365440539, 0.07862477031137262, 0.028782919448401247, 0.0349873418786696, 0.11818138057632105, 0.12683808963213647, 0.033562805104468546, 0.04120978959170835, 0.0811560180570398, 0.0592897113944803, 0.0223785836382636, 0.02162950811907649, 0.09948399529925414, 0.06319835130125284, 0.03446921593110476, 0.01831499856364514, 0.03972046968660184, 0.05515295479978834, 0.06821771910680191, 0.06331379724932568, 0.03493057903168457, 0.058396643958985806, 0.04519333976453968, 0.04036698124504515, 0.004739178219876651, 0.06960104166397027, 0.028084203101960675, 0.012706770079343446, 0.046432989316859415, 0.050407772817249806, 0.04695785990250962, 0.08385073845939976, 0.04803989255534751, 0.050748662025268586, 0.03759090110127415, 0.04901582607999444, 0.09488452531929527, 0.9916045623166221, 51.689473220280235, 93.08114637647355, 70.15774685995919, 49.8175173486982, 72.07050950186593, 88.56097493852887, 56.11537844794137, 46.660770075661794, 66.04476765223912, 44.935990946633474, 4.026529720851353, 0.5816593255315508, 0.12948075282786572, 0.28015926533511704, 0.262249442083495, 0.10774350352585316, 0.4801801251513617, 0.5076593277709824, 2.156758189201355, 4.9591629675456455, 5.847720750740596, 9.555722900799342, 11.964692882129125, 5.6338890705789835, 10.125557695116315, 12.057505181857518, 16.082974433898926, 19.440826892852783, 9.446005633899144, 7.220330434186118, 16.787554774965557, 21.242661544254847, 32.98262970788138, 26.680851561682566, 12.676560146468026, 3.792637288570404, 0.26760503756148474, 2.053755270583289, 2.658438320670809, 0.7483111087765012, 0.18062674121132918, 0.16413904593459197, 0.0769039715773293, 0.029803649854979346, 0.12233047293765204, 0.14437796202089104, 0.3921277214373861, 0.1775025488542659, 0.210177782656891, 0.35915805771946907, 0.3038200799907957, 0.2996628044971398, 0.444406157625573, 0.35760893513049397, 0.2077651156910828, 0.02309516241907009, 0.04738337599805423, 0.2492338376385825, 0.22771168393748148, 0.15424582894359315, 0.40419481535043034, 0.30062114021607805, 0.23098271127258027, 0.07976098398544959, 0.05823591258376837, 0.06205922671194587, 0.09437917279345648, 0.01340123710022973, 0.06713785098067351, 0.006153807110552276, 0.04046232220051544, 0.07255360537341662, 0.04545324921075787, 0.06346717330494098, 0.14942196064761706, 0.025310703087598085, 0.21260931289621762, 0.42716406711510246, 0.5021370298096112, 0.27961757725902964, 0.9074250193578857, 3.098108168159212, 1.3176585521016801, 3.366048727716718, 7.637208018984113, 8.63778509412493, 7.600161961146763, 9.789724332945687, 8.796837176595416, 5.264171949454716, 3.8008969596454074, 3.6551402551787238, 4.413494876452854, 1.584330739719527, 0.31470717436500956, 0.9834269668374742, 1.8519815376826694, 0.24238329380750656, 0.26338742673397064, 0.7712958039981979, 1.0742043129035403, 1.4697101073605674, 30.693733283451625, 53.65856490816389, 24.67735586847578, 23.861592190606252, 50.77146680014474, 86.98384502955845, 51.07150738579886, 35.78779465811593, 60.28691359928676, 74.01235035487584, 11.777993048940386, 0.6229084464056152, 0.1692184233771903, 0.10073534958064556, 0.03946203266137412, 0.08818434484835182, 0.08388030223016228, 0.07742288123284068, 0.08654575741716794, 0.052539970725774765, 0.04670126170718244, 0.014551397213446242, 0.08704325250749077, 0.007444395983059491, 0.02979839120858482, 0.03777365093784673, 0.0701569246926478, 0.07368613460234233, 0.07246304808982781, 0.03615266809772168, 0.045422386045434644, 0.002332289403836642, 0.043255226620073826, 0.06330810434051923, 0.038771094022584815, 0.03197350645703929, 0.037378197336303334, 0.0737671245421682, 0.005316962238534221, 0.04801586223766208, 0.2644988128117153, 0.20494417420455388, 0.13503195638103144, 0.16144542475896223, 0.16329946741461754, 0.11195820343813725, 0.09275885831032481, 0.12255999419306006, 0.15815443492361478, 0.2738811879285744, 0.212516543588468, 0.10956499007131372, 0.16898123467607157, 0.16992266130234512, 0.14779053176087992, 0.18251287857336657, 0.0911177738702723, 0.20944960601627827, 0.18951371791107313, 0.1941273082047701, 0.13774487509259156, 0.17260258964129857, 0.17902355295206818, 0.20768221228250436, 0.16421698246683392, 0.11170805471816234, 0.20482731690364225, 0.38649674930742806, 0.16194980697972433, 0.19576951222760336, 0.20917165093123913, 0.1618751816983734, 0.16761210028614315, 0.27007067097084864, 43.56138365609305, 115.61379310062954, 103.02923665727887, 72.6383649281093, 70.27288545880998, 120.74889401027134, 90.13415827069963, 51.48070764541626, 61.357158524649485, 87.31106349400112, 13.447894436972481, 1.7670746594667435, 1.5719029094491686, 1.089937965784754, 0.9327926209994725, 0.1448923187064273, 0.295190905886037, 0.3837275936135224, 2.6652208481516158, 5.934154604162488, 9.447743552071707, 15.989814724240984, 29.913968222481863, 26.337622710636683, 32.96729850769043, 26.612679311207362, 21.83355024882725, 42.69346332550049, 42.39163357870919, 18.949988773890905, 32.99467788423811, 40.945595332554404, 47.94241394315447, 39.989325182778494, 21.340259415762766, 9.129799195698329, 2.923925731863294, 3.3782428162438527, 2.913727513381413, 1.2797843558447701, 0.18980961346200534, 0.5353875798838479, 0.3270775191485882, 0.10230581209595714, 0.23973860857742174, 0.3341719556067671, 0.605507877256189, 0.37495250733835356, 0.39687855222395485, 0.9509012550115585, 0.6438357148851667, 0.6881853065320424, 1.3599269411393573, 0.9911493467433112, 0.7534731860671724, 0.14997280894645623, 0.0812553691544703, 0.3089713007211685, 0.4610724704606192, 0.3917853869497776, 0.6808828583785466, 1.5137142432587487, 0.7308324809585298, 0.32040795417768614, 0.2617657823222024, 0.0877952321565577, 0.33640189309205326, 0.11436487893973078, 0.14773167563336237, 0.1884885872048991, 0.14487174552466187, 0.12220631459993975, 0.1947623219873224, 0.18994722036378725, 0.2974615011896406, 0.15540649023439201, 0.39118328211562975, 0.6341642024261611, 0.43527448762740406, 0.20657291609261716, 0.7444809685860361, 1.976736443383353, 1.7362196637051446, 2.8099663725921085, 14.622124365397863, 7.868168745722089, 12.944060581071035, 17.940566641943796, 16.201330048697336, 12.727136952536446, 8.178236450467791, 7.589321902820042, 6.309217061315264, 2.7619326072079793, 0.9917959634746824, 0.734512094940458, 1.117171538727624, 2.9094307039465224, 1.4996701968567712, 3.4137022963591983, 1.5840355498450143, 9.646544541631426, 46.350015367780415, 38.212128843579976, 20.37425136566162, 52.842134203229634, 80.56309809003557, 99.96508107866559, 47.900485038757324, 47.387819153921946, 79.79321684156145, 88.4579748426165, 8.174401044845581, 0.5470482856035233, 0.20670943733836922, 0.25611944815942217, 0.09143829345703125, 0.23245312379939215, 0.124873282920037, 0.24499627788152012, 0.12459911406040192, 0.13567870881940636, 0.13962799975914614, 0.15660039974110468, 0.16643128650529043, 0.1378417427518538, 0.1280893896307264, 0.26913684393678394, 0.18633304429905756, 0.1813292285161359, 0.15368466691247054, 0.13572816045156547, 0.19283815952283995, 0.09551813453435898, 0.19580413108425482, 0.33748364076018333, 0.08842795249074697, 0.16333769607756818, 0.15903625903385027, 0.13058494643441268, 0.1688827249620642, 0.17077590551759514], [0.027269000952531184, 0.06540222625647273, 0.03873778473851936, 0.008143770508468151, 0.013766661286354065, 0.012746889310489808, 0.01418767190937485, 0.04503129203138607, 0.07850990111806563, 0.041194848250597715, 0.05070121885676469, 0.0629236056868519, 0.11576114115970475, 0.06149807825152363, 0.04367771305676017, 0.09331072441169194, 0.035624754282512834, 0.04282823810353875, 0.011560956831090152, 0.020245043926739266, 0.055988842089261324, 0.03898108025480594, 0.04603009218616145, 0.011443186052409666, 0.056714267270373445, 0.06886026462806122, 0.03581452017117824, 0.020296305551060607, 0.046024266963026354, 0.0518534256012312, 0.03299343619229538, 0.08591716936124222, 0.04154023275311504, 0.011698984424583614, 0.3350647991257054, 42.46106692722866, 85.63465772356305, 60.89670140402657, 35.14414133344378, 52.70580359867641, 90.0580963407244, 74.16012464250836, 34.86551856994629, 36.10551840918404, 59.28061989375523, 23.71372757639204, 0.19217103746320519, 0.2053291206913335, 0.5603074026959283, 0.8952446643795285, 0.21672772190400533, 0.13556139011468205, 0.15481202570455416, 0.25791050919464653, 1.3183939754962921, 1.5918562901871545, 2.739396559340613, 9.575402804783412, 11.102113110678536, 12.885088614055089, 10.200864008494786, 10.029619574546814, 25.694018023354666, 25.902790546417236, 23.389995370592388, 17.565110308783396, 22.918706008366176, 15.411823613303048, 6.127072206565312, 4.858607769012451, 1.982187956571579, 0.4403625231768404, 0.4980522489973477, 0.12039282119699887, 0.06666242184915713, 0.03899685958666461, 0.1094264400058559, 0.007300571156000453, 0.06511545021619115, 0.01433355184937162, 0.1451493070593902, 0.030431935962821757, 0.05062503294487085, 0.06739310906933886, 0.09836975258908101, 0.045837395026215484, 0.1466426947819335, 0.09421867212014538, 0.05995553745222943, 0.08013850051377501, 0.07816362434199878, 0.15388315197612557, 0.017658551556191275, 0.06861631093280655, 0.20657150473977837, 0.06236157513090542, 0.018753430573269725, 0.0509521309286356, 0.041123588502939255, 0.022505766545821513, 0.016496699436434677, 0.04735471807154162, 0.03284416188086782, 0.02261166550618197, 0.08761494540210281, 0.031623616481998136, 0.09538060227142912, 0.08723668248525687, 0.07533718672181879, 0.0397136639803648, 0.08384084541882787, 0.22580030507275037, 0.6599263314689908, 1.211363055876323, 1.7891646112714494, 0.8864276174988065, 1.4714550822973251, 1.8990065114838737, 2.09211888057845, 1.4189881490809577, 1.6468660469566072, 3.218647037233625, 4.065459609031677, 3.132285922765732, 1.8656393076692308, 1.5504920354911258, 0.6852711886167526, 0.26981717028788155, 0.05174755038959639, 1.3775448586259569, 2.33794766664505, 0.36914270051888054, 0.7760579798902784, 1.7809165567159653, 16.755723340170725, 31.976711205073766, 19.232038736343384, 18.62290927342006, 49.915045738220215, 70.35128893171037, 77.93390669141496, 26.660199778420584, 25.44776518004281, 60.51896258762905, 64.17060920170375, 6.808952782835279, 0.25246966257691383, 0.024132961374042288, 0.05453047016635537, 0.04448274057358503, 0.11609075990106378, 0.022309101652354002, 0.04027961307604398, 0.043793596659920046, 0.026761734957939813, 0.03472993622667023, 0.005802127499399441, 0.045873163999723535, 0.023683404782786965, 0.03782111106972609, 0.034704677760601044, 0.04537310404703021, 0.03430050498406802, 0.03477641248277255, 0.033787651253598075, 0.01771282248332032, 0.03263480668621404, 0.027549967036715577, 0.026669269294611046, 0.05285448527761868, 0.10962237377784081, 0.038566318939306905, 0.06301325373351574, 0.015530445213828768, 0.034014217488999875, 0.0832087764782565, 0.06508619857153722, 0.06383172302906003, 0.014903229494978274, 0.024282556293266158, 0.029954932630062103, 0.025125327320503335, 0.015645772418273345, 0.05545277567580342, 0.054733036618147574, 0.10718334572655813, 0.030218356887676885, 0.029831734419401203, 0.035770001488604715, 0.07723707120333399, 0.05628041197944965, 0.024295285610216003, 0.03881422170837011, 0.03013231186196208, 0.01521386282651552, 0.04072200773017747, 0.011045670552578355, 0.015383279449971659, 0.039074511134198735, 0.04797872940876654, 0.01006319425401411, 0.05777355203671115, 0.039784669277391264, 0.03814081641446267, 0.03814623451658657, 0.039678770317030806, 0.032270056794264486, 0.07478658269558634, 0.026577399045761143, 0.08166010172239371, 4.511203919138227, 72.55939865112305, 94.55371979304722, 67.19416645595005, 57.151313168661936, 80.18533148084367, 91.75126116616386, 55.84629556110927, 44.22919586726597, 63.530291012355256, 57.1568717275347, 7.884227769715445, 0.3881892870579447, 0.8782030131135667, 0.39227941472615513, 0.6074659664716039, 0.6258409661906106, 0.4309304521552154, 0.18461464079363005, 0.485659159719944, 1.5012734936816352, 1.5163990706205368, 4.154498168400355, 7.8791590588433404, 7.481746418135507, 2.856107188122613, 7.637933237212045, 17.368273053850444, 17.864942448479788, 8.484597291265215, 9.826566287449428, 12.19442812034062, 13.670892528125218, 7.942815848759242, 3.4252960171018327, 0.7976692116686276, 1.8824417889118195, 0.37127273050802095, 0.3296437385891165, 0.11448907798954419, 0.08581802182431732, 0.017806736818913902, 0.03423359125320401, 0.03807139549670475, 0.04118086703653846, 0.06883364569927965, 0.05438810334141765, 0.0871735108750207, 0.07624795035059963, 0.0309630626413439, 0.01820113699484084, 0.05646757229364344, 0.13653246872127056, 0.23311366406934603, 0.04008549438523395, 0.029453810770064592, 0.10622821269290787, 0.08733962303293602, 0.04276632856843727, 0.14437037599938257, 0.12615142576396465, 0.03672673925757408, 0.06794690899550915, 0.06366444379091263, 0.04197976738214493, 0.016967143031901548, 0.028005274212253944, 0.06772490590810776, 0.03096901678613254, 0.03043238040325897, 0.04880098153703979, 0.027510747712637697, 0.06721641855048281, 0.09874308934169156, 0.12089068948158196, 0.05128215000565563, 0.14746315218508244, 0.29790504596063067, 0.7227004287498338, 0.40578318440488403, 0.8111044221690723, 2.4276803944792067, 4.927623791354043, 7.504650286265782, 3.65826564175742, 3.3510992441858565, 3.3208011899675642, 4.3112855723926, 9.54531102521079, 6.988739592688424, 1.8076412826776505, 1.426387112055506, 0.9841115815298898, 0.1732764970511198, 0.14228242875209876, 0.28884996899536675, 0.8478442164404052, 0.44915042019316126, 0.8550745770335197, 1.265242536153112, 12.181749394961766, 45.43866184779576, 42.0263945715768, 23.85819799559457, 27.959047385624476, 55.24024936131069, 87.29409599304199, 53.74591071265084, 37.25140837260655, 53.34154292515346, 75.58062825884137, 27.218628236225673, 0.28385836684278076, 0.07551261516554014, 0.07043171780450003, 0.049909005473767004, 0.051887918928904195, 0.06683060353887932, 0.07052597310394049, 0.0602875446368541, 0.08892958664468356, 0.01656181674583682, 0.03184469676177416, 0.06753424435321774, 0.02750227111391723, 0.02016151965861874, 0.026295530510001948, 0.04818282934970089, 0.027494778390973806, 0.04243593629715698, 0.04958511696064046, 0.05216902241642986, 0.04692015710419842, 0.024255635416401283, 0.07262185242559228, 0.04766433360055089, 0.04918694243367229, 0.048444377457989116, 0.051082050028656206, 0.08613435485001121, 0.0869384188471096, 0.08879692626318761, 0.12875059486499854, 0.2182340153626033, 0.12448963922049318, 0.09942157686288867, 0.09413622333002941, 0.11051258458090679, 0.06839871832302638, 0.10776196646371058, 0.23559650512678282, 0.15529331059328147, 0.126813730224967, 0.15457018225320748, 0.17095260960715158, 0.21193889315639222, 0.1502834287072931, 0.1773336207760232, 0.17358567831771715, 0.10910931309419018, 0.12780139222741127, 0.12882889780615056, 0.1919626457882779, 0.14155848617000238, 0.154732080708657, 0.18575922080448695, 0.12176500899451119, 0.16232397833040782, 0.10394093221319572, 0.16037901198225363, 0.14085701666772366, 0.19665436260402203, 0.09344119312507765, 0.2498644409435136, 0.10258448642811605, 0.09893599006214313, 1.748554018991334, 74.3059742791312, 120.6793703351702, 94.06847149985177, 71.73477949414934, 81.37188925061906, 123.57282257080078, 99.86742414746965, 59.03766223362514, 54.01623732703072, 90.19476740700858, 42.47214930398123, 0.4057607656078679, 3.481954885380609, 1.7779872396162577, 3.0468054924692427, 1.5912490827696664, 0.3364208106483732, 0.1349576703671898, 0.6413017937115261, 1.6372177132538386, 2.8948416582175662, 5.7674173797879895, 15.310428551265172, 17.206708329064504, 18.385949645723613, 16.83926500592913, 20.66715615136283, 36.95998007910592, 37.885636465890066, 30.48286587851388, 28.6235123021262, 30.873917443411692, 22.733024086271012, 12.45479188646589, 9.267668826239449, 2.8966768511704037, 0.5260141342878342, 0.74307189562491, 0.20865250378847122, 0.164750908102308, 0.1458685677498579, 0.3221629171499184, 0.14003685781998293, 0.13121341913938522, 0.22461300449711935, 0.2665525483233588, 0.19706851323800428, 0.17488332225808076, 0.20656675499464783, 0.14103804981069906, 0.2714548281260899, 0.2265811496015106, 0.4645087889262608, 0.21459778690976755, 0.3052796630987099, 0.23912928413067544, 0.4305085933634213, 0.1916274766304663, 0.276970205030271, 0.6587884011013168, 0.2143713597740446, 0.3329143316618034, 0.2578318805566856, 0.09851967490145139, 0.16069381151880535, 0.073227845265397, 0.1945859164531742, 0.1332841587385961, 0.16398499134395803, 0.19643793707447393, 0.10916781638349805, 0.1061955208757094, 0.16569173761776515, 0.24005100610000746, 0.287195374923093, 0.2017369834440095, 0.46215253536190304, 1.3134031061615263, 3.8675692677497864, 3.6758758510862077, 4.118753160749163, 6.342779900346484, 9.307622705187116, 1.5055186258895057, 4.333073820386614, 4.418544479778834, 5.835397252014705, 12.052026527268545, 8.938420619283404, 3.1816387602261136, 3.051432124205998, 1.4132457886423384, 0.4603303702814238, 0.3871283568441868, 1.3323607231889452, 4.612169929913112, 3.488711791379111, 2.5723399349621365, 3.248912738902228, 26.393364633832658, 50.849988392421174, 31.71011229923793, 29.694554533277238, 65.97955186026437, 84.46801349094936, 100.5108551297869, 43.40168973377773, 47.617127077920095, 72.86742619105748, 86.84004511151994, 20.67542450768607, 0.4162677175232342, 0.10624610566134964, 0.20002623381359236, 0.09837164570178304, 0.21226149584565843, 0.1173355866755758, 0.17078867554664612, 0.17111874212111744, 0.17599819600582123, 0.19993311166763306, 0.09739729655640465, 0.19343060201832227, 0.14230357190327986, 0.18634930199810437, 0.10638240977589573, 0.15979472547769547, 0.08093012017863137, 0.2190186054046665, 0.13995354729039328, 0.1557662087891783, 0.10756157471665315, 0.10442859533109836, 0.16275711437421186, 0.17025237503860677, 0.2628450872642653, 0.23838837817311287, 0.17574883438646793, 0.18440514989197254, 0.20195805015308516, 0.1938815971038171], [0.005851626629009843, 0.04482664247708661, 0.07047185993620328, 0.05186755609299455, 0.06744847752686058, 0.008410339775894369, 0.07365415524691343, 0.06954276907656874, 0.0627522145264915, 0.01649549842945167, 0.03178253956139088, 0.017907234640525918, 0.06377486179449729, 0.04434028553909489, 0.022308552038988898, 0.02559852916082101, 0.13317685521074704, 0.00929139629339001, 0.012711775123274751, 0.046037098060228994, 0.009593898230897529, 0.0822605916431972, 0.05894279001014573, 0.018370090518146753, 0.05153196963614651, 0.07151936872729234, 0.09043768500643116, 0.0750571485342724, 0.03644393943250179, 0.06670135618852717, 0.009834368497000208, 0.020401257955070053, 0.021224049518683126, 0.02646431270321565, 0.08808363668088402, 1.0703102818557193, 66.63342598506382, 82.57121780940464, 57.80298124040876, 48.36382218769619, 64.30955927712577, 88.43123122623989, 89.11094570159912, 46.25929273877825, 23.096251589911326, 47.39598328726632, 46.03592552457537, 10.58084796156202, 0.4518299549818039, 0.6302124144775527, 1.7236550407750266, 0.5274457888943809, 0.4868369336639132, 0.1836958093834775, 0.057913479528256824, 0.16868554268564495, 0.611837740455355, 1.9301485546997614, 3.2450764647551944, 6.138334367956434, 5.2470585363251825, 6.509654785905566, 12.114288466317312, 7.4837153639112195, 4.531526097229548, 3.7090969255992343, 3.9580738970211575, 1.9849722300257002, 1.6254092497485024, 1.3099888265132904, 0.027522747604442493, 0.17422780314726488, 0.6788420964564595, 0.18616623325007303, 0.052291029798133035, 0.03287638890157853, 0.06120478827506304, 0.010482929231199836, 0.07746702672115394, 0.041499985448483906, 0.014831966354644724, 0.057928800848977904, 0.06663506331720523, 0.09490912221372128, 0.03942124592140317, 0.028487244421350102, 0.056922709835427146, 0.009516003258925463, 0.08032547762351376, 0.0873009329661727, 0.03215066177238311, 0.09401347634515592, 0.04557278333231807, 0.03390636434778571, 0.04209177655034831, 0.09639136839125838, 0.08347200056804077, 0.0825643174882446, 0.08902616253388779, 0.060987813132149835, 0.05395654149885688, 0.07605635920273406, 0.0854928610580308, 0.03633573345307793, 0.07348019922418253, 0.04555181660024183, 0.03543017418789012, 0.05619252473115921, 0.02457393449731171, 0.06438162816422326, 0.1989776122250727, 0.1655996332743338, 0.03660753422549792, 0.1416599950087922, 0.5302878192492894, 0.6958367388163293, 0.7086727214711053, 0.5429284923842975, 0.48265694081783295, 1.4234461784362793, 1.0329251736402512, 0.5807938948273659, 1.8105273906673705, 5.953712914671216, 1.1564569792577197, 0.36334280031067984, 0.48060472522463116, 0.5310134174568313, 0.17701921478978225, 0.3853261406932558, 1.9762785136699677, 1.9102912545204163, 12.542140296527318, 25.478373731885636, 26.553897551127843, 26.247402088982717, 40.57499926430838, 71.3718820299421, 82.95414693014962, 75.31370626177106, 29.216150215693883, 29.743667875017437, 52.23778683798653, 76.13117572239467, 13.993937730789185, 0.674580950822149, 0.0388963074822511, 0.0666202644684485, 0.06634661808077778, 0.023486112244427204, 0.08596928763602461, 0.08353641389736108, 0.04271021372239504, 0.05888967428888593, 0.020451630698516965, 0.023840093785630803, 0.04894456633233598, 0.016673520573281815, 0.05517911232475724, 0.07238535583019257, 0.061619094972099574, 0.07470810333532946, 0.02316552141149129, 0.03174021254692759, 0.035530678794852326, 0.08915380175624575, 0.05256708498511996, 0.056826276438576837, 0.04884868933420096, 0.022747626960543648, 0.05200389074161649, 0.06206251760678632, 0.03242124457444463, 0.049982382250683646, 0.058529351837933064, 0.06445193796285562, 0.0302153882969703, 0.018623874489484087, 0.037770254870078394, 0.08168463076331786, 0.0623126391853605, 0.03819504154047795, 0.037154888068991046, 0.05826931007738624, 0.04551634278946689, 0.02761320141144097, 0.027392163540103605, 0.04960458752300058, 0.09946030085640294, 0.08628613634833268, 0.040789006277918816, 0.03914393883730684, 0.0510285373644105, 0.02449128553936524, 0.009931676355855805, 0.041577552179140706, 0.027266510729012743, 0.08638907689601183, 0.04312282068920987, 0.0197990733930575, 0.06444524082222156, 0.02966176139722977, 0.03362881977643285, 0.09038384325270142, 0.03491492183612926, 0.08795142413250037, 0.021807121445557902, 0.02207920211367309, 0.025877997378951738, 0.14756991288491658, 0.1309205498546362, 13.463496616908483, 95.86431680406842, 90.11461298806327, 67.05673108782086, 67.81086077008928, 88.39969335283551, 95.867109979902, 66.37938594818115, 46.63044466291155, 57.33028139386858, 69.29844924381801, 26.267894063677105, 2.8351768255233765, 0.3385537990501949, 0.5450041581477437, 0.06880834312843424, 0.14378416245537146, 0.6648102636848177, 0.4116954771535737, 0.36819120443293024, 0.8354737630912236, 0.7709068134427071, 1.6362976197685515, 4.088905002389636, 4.137415587902069, 2.9640098895345415, 7.829036491257804, 15.089027677263532, 10.111648270062037, 10.46669600691114, 5.202071121760777, 7.027188752378736, 3.529679673058646, 1.8921338745525904, 1.9192522593906947, 0.21256110976849282, 0.22957127700958932, 1.3592093225036348, 0.6003555708697864, 0.11564915574022702, 0.0667008947847145, 0.022230128657871058, 0.032489942852407694, 0.04393309328172888, 0.09693281219473907, 0.0510767845969115, 0.049832439582262716, 0.0051655098296967995, 0.11491811568183558, 0.03682073671370745, 0.10265893529036216, 0.024203588387795856, 0.020437864919326136, 0.08093064943594591, 0.054852560561682494, 0.2918999839041914, 0.09356108347752265, 0.041877410374581814, 0.0418117994309536, 0.16916861890682153, 0.04870677034237555, 0.09575891947107655, 0.021697188594511578, 0.02215360178213034, 0.046779340731778314, 0.03529622798253383, 0.10442022899431841, 0.025420452734189372, 0.050921556140695295, 0.04620270810223051, 0.07520043477416039, 0.01942400128713676, 0.06202451286039182, 0.0033605417951808442, 0.03520700402025666, 0.18955026380717754, 0.12104706466197968, 0.12573699014527456, 0.741959803870746, 1.1657324986798423, 1.7626675473792213, 1.702944632087435, 0.9215832224914006, 1.5744880735874176, 0.3343004701392991, 0.7780397364071437, 1.0577936449221201, 4.133660955088479, 9.955711586134774, 1.160130079303469, 0.2375545400593962, 0.28466134518384933, 0.17413985143814767, 0.2895790141608034, 0.16291514518005507, 0.7425058345709528, 1.0675913648945945, 10.275600569588796, 34.17055279867989, 46.287029947553364, 43.729769774845664, 31.529236793518066, 40.99441684995379, 66.27730996268136, 83.77857848576137, 59.397940226963584, 34.251231806618826, 50.55346359525408, 80.5635427747454, 37.67999758039202, 0.844061193721635, 0.05774301117552178, 0.03783559100702405, 0.04169178354953017, 0.04084047994443348, 0.10744235611387662, 0.04123144503682852, 0.0147914900444448, 0.042807607246296744, 0.028888682701757977, 0.020896286570600102, 0.07091256164546524, 0.01618617636683796, 0.03500452917069197, 0.09620426235986607, 0.04745557890938861, 0.0914535808510014, 0.0143065529409796, 0.034618402032979896, 0.05226770854954209, 0.042615405416914394, 0.03323910997382232, 0.03510774791772876, 0.05273777046906097, 0.08707952698958771, 0.01729892290729497, 0.05464898987806269, 0.04101731974099364, 0.004842793061730585, 0.03842974341075335, 0.016970522136294415, 0.10615333635360003, 0.1365709009447268, 0.1564524383949382, 0.10321136457579476, 0.1583256157381194, 0.13743209759039537, 0.1802874058485031, 0.1579223216644355, 0.12308089195617608, 0.17118958117706434, 0.07177305261471442, 0.11238052363374404, 0.1898815788860832, 0.16503574353243622, 0.1624716818332672, 0.1484716045004981, 0.18304854125848838, 0.06238303040819509, 0.15856836842639105, 0.13021822539823397, 0.06907406422708716, 0.24527567146079882, 0.1211243633713041, 0.15150051697024278, 0.16943170050425188, 0.1444172899105719, 0.1601741894015244, 0.1534283978066274, 0.0999367477904473, 0.19382875279656478, 0.10004053650689976, 0.08817880800259964, 0.11164077118571315, 0.2067477609962225, 0.18844984285533428, 5.880460662501199, 104.6041361945016, 116.8402543749128, 89.9757740838187, 80.87239020211356, 91.9572057723999, 115.96871403285435, 109.6468677520752, 72.83071885790143, 41.121311800820486, 65.90614414215088, 70.01051453181675, 19.391440834317887, 0.3732338867017201, 2.5513720086642673, 2.790239134005138, 1.415098134960447, 1.2378587084157127, 0.3475967166679246, 0.2561020776629448, 0.9765588896615165, 1.1677494304520744, 2.0967965381486073, 4.163166914667402, 9.243147764887128, 8.563049401555743, 9.177255392074585, 19.102586848395212, 13.93668804849897, 14.512218628610883, 6.901393353939056, 7.463834830692836, 4.27872587953295, 2.1816236206463406, 2.246599916900907, 0.32646925321647097, 1.0700610152312686, 2.544259876012802, 1.8714160834039961, 0.19475645944476128, 0.1314559546964509, 0.15480019205382892, 0.19144417718052864, 0.1425856796226331, 0.15864667136754307, 0.1355292411254985, 0.15566330216825008, 0.11344331303345305, 0.22991054451891355, 0.11489622614213399, 0.21675099565514497, 0.07166257354297809, 0.1283862487013851, 0.26867139605539186, 0.29490757680365015, 0.37864710337349344, 0.26047349880848614, 0.10949216290776219, 0.14515333755740098, 0.2076297208134617, 0.16578617612166063, 0.2772022911480495, 0.2046213543840817, 0.1382534642304693, 0.14949452318251133, 0.16974127532116004, 0.20869181810745172, 0.16199764369853906, 0.15769312610583647, 0.11623015813529491, 0.2806696593761444, 0.1831235329487494, 0.12559704908302852, 0.20050040765532426, 0.15654022725565092, 0.4788804320352418, 0.3186307352568422, 0.34843267181089943, 0.6136658223611968, 1.511413412434714, 1.8467851536614555, 1.9467521437576838, 0.37134074685829027, 0.8121990891439574, 3.7255259411675588, 3.469026893377304, 2.5810030358178273, 6.241557674748557, 16.823325838361466, 1.5669131257704325, 0.46999515167304445, 1.0093978132520403, 1.421964366521154, 0.8979944682547024, 3.247605391911098, 3.945723908288138, 2.519517992224012, 19.840721777507238, 42.13543265206473, 41.31609412602016, 38.785025187901084, 54.84070709773472, 85.64309283665249, 95.20892797197614, 90.21325656345913, 46.83673667907715, 48.92843280519758, 65.52157524653843, 96.99461500985282, 30.898778097970144, 0.8066225626638958, 0.23307420047266142, 0.17883972424481595, 0.17527561049376214, 0.11929674286927495, 0.19286156898098333, 0.1771950096424137, 0.21065992249974183, 0.152739820469703, 0.23996130377054214, 0.09269937114523989, 0.1299825973276581, 0.21655390837362834, 0.1655978419418846, 0.2111331463924476, 0.21399393145527157, 0.1547620583857809, 0.09443495515733957, 0.05092700816957014, 0.1576459136392389, 0.1020943263013448, 0.0759896184982998, 0.1873349148247923, 0.17529455519148282, 0.23112129526478903, 0.08678165690175124, 0.14070780681712286, 0.16205150580831937, 0.1302786964390959, 0.1565406479473625, 0.1773721751357828], [0.030676184820809534, 0.017178133495950272, 0.052970582619309425, 0.01560486523833658, 0.04479174202840243, 0.0500068570088063, 0.036865258788956065, 0.029518098570406437, 0.12079728235091482, 0.01615745567583612, 0.03751217407573547, 0.08994210338486092, 0.015567698482690113, 0.019984654416995387, 0.044372478633054664, 0.031653261676962884, 0.06118477149201291, 0.03226907631116254, 0.039824960686798604, 0.0452248102187046, 0.024707709372575794, 0.05589531960764101, 0.0429331871148731, 0.04318654530548623, 0.023021612615723695, 0.019433415960520506, 0.01822412576127265, 0.041263295470603874, 0.01902276317455939, 0.0648075310247285, 0.03573155908712319, 0.04857514811945813, 0.022408121963962913, 0.07912638410925865, 0.050621945610536, 0.015176173598904694, 4.705519412245069, 66.34875134059361, 81.96871171678815, 63.76461206163679, 56.57101351874215, 69.67487485068185, 86.32621887751988, 94.16090338570731, 75.85104519980294, 24.854362964630127, 25.43950203486851, 40.616671085357666, 35.74571636744908, 9.968127148491995, 1.5546241509062904, 0.5522543319634029, 0.7352150029369763, 1.217789162482534, 0.683608669255461, 0.17172247543931007, 0.11494212225079536, 0.29399947981749264, 0.23971640691161156, 1.114327228495053, 2.466640029634748, 4.96416653905596, 3.909726159913199, 2.7828820773533414, 3.3888121119567325, 4.298871747085026, 1.2053972674267632, 0.1676060613244772, 0.3453171918434756, 0.1935126640434776, 0.14818602268184933, 0.7266111789005143, 0.3685251250863075, 0.19749900299523557, 0.06081790117813008, 0.06540824486208813, 0.034220431066517315, 0.06658652092197112, 0.050551350827195814, 0.01979645255154797, 0.043530413282236884, 0.142858749255538, 0.04872025961854628, 0.0474697399352278, 0.04295092062758548, 0.09562430490872689, 0.029453654707010304, 0.07205770484038762, 0.03861279519540923, 0.015703030595821992, 0.11524993287665503, 0.040887800976634026, 0.08127430706684079, 0.01819439066041793, 0.08364076579787902, 0.0856490462486233, 0.010811134923382528, 0.016793833313775913, 0.04676232646618571, 0.037024663628212044, 0.05900494381785393, 0.01769169290283961, 0.026361699548682997, 0.008916224103554018, 0.06758161288286958, 0.02582027779759041, 0.04628210687743766, 0.042098999555621824, 0.05880563772682633, 0.060588013513811996, 0.0912048231278147, 0.19684889859386853, 0.14115953472043785, 0.14111662416585855, 0.4236020839640072, 0.2968565193670136, 0.059899232616381984, 0.16396409246538365, 0.5155562268836158, 0.8537626160042626, 0.5253512869988168, 0.3733105611588274, 0.10243110358715057, 2.7007521986961365, 3.80280293737139, 0.6311776712536812, 0.1615985022591693, 0.022493566486186216, 0.22284297804747308, 2.9918044209480286, 12.115171756063189, 25.118005411965505, 23.325997250420706, 25.328575781413488, 35.34314816338675, 46.24291583469936, 60.34417370387486, 76.06370176587785, 54.779816559382844, 24.40348740986415, 30.83715452466692, 57.836151940482004, 74.2909939629691, 21.924118280410767, 0.15363818726369313, 0.042799264658242464, 0.019011358697233454, 0.05818843548851354, 0.016005246700452905, 0.05053767156121986, 0.03864542255178094, 0.028869252851498977, 0.06379996759018727, 0.06574219944221632, 0.03157382897500481, 0.03667940804734826, 0.013912086607888341, 0.06734612051929746, 0.04921004994373236, 0.0761199447193316, 0.0920188140922359, 0.03323718971971955, 0.05011763802862593, 0.028255465340667536, 0.04389341933918851, 0.04523338350866522, 0.07841968988733632, 0.021743834484368563, 0.032950634203319035, 0.052134257674749405, 0.037765427093420706, 0.026045646418684294, 0.030583544434713464, 0.030932138407868997, 0.013053644814395478, 0.04693682531693152, 0.0165148349811456, 0.04771861979471786, 0.020660804385053258, 0.04115600212078009, 0.0796256773173809, 0.01718539890966245, 0.04679085207836969, 0.020507580999817168, 0.03867080993950367, 0.00514580008374261, 0.0266231051646173, 0.026947980946195976, 0.029615780471691062, 0.04732091684958764, 0.050073974300175905, 0.06569234068904604, 0.08775584998407535, 0.03711938711681536, 0.027552382621381964, 0.049590423104486296, 0.06948246766946145, 0.056944653657930236, 0.040773644245096614, 0.029873094521462917, 0.01974244455673865, 0.09327763225883245, 0.053316350494112284, 0.04620197189173528, 0.04693017228107367, 0.05545082149494972, 0.044471985793539455, 0.04591508389317563, 0.007542519780275012, 0.09326527613614287, 0.055136249267629216, 0.09046424286706106, 25.59173706599644, 96.15277821677071, 82.84467111315045, 74.63807732718331, 76.53814561026437, 89.14025320325578, 103.4578640801566, 76.40035588400704, 44.320679324013845, 46.33840840203421, 58.18251616614205, 52.21638291222708, 23.65463662147522, 4.533044278621674, 0.5957093430416924, 0.4072494985801833, 0.1346887940807002, 0.17439115366765431, 0.6495772067989621, 0.438430978251355, 0.14933045341500215, 0.42306435853242874, 0.44604878234011786, 0.6972385921648571, 2.801945762974875, 5.047512786728995, 7.1530718718256265, 5.2305022818701605, 6.163923714842115, 3.995631515979767, 2.254089206457138, 0.3455266963158335, 0.7934091516903469, 0.7197043438042913, 0.6483282681022371, 0.3991296057190214, 0.2860848030873707, 0.0986493904409664, 0.042173590910221846, 0.017199062908600484, 0.035757672507315874, 0.026868056306349378, 0.05495207790019257, 0.031915101555309126, 0.06211815747831549, 0.08650228367852313, 0.043649675989789624, 0.037492520308920314, 0.047079826572111676, 0.08833834515618426, 0.011316060820328338, 0.06337645995829787, 0.008714745004129196, 0.060744483689112325, 0.3968175926378795, 0.08734233038766043, 0.011444784850547356, 0.04636099675138082, 0.03083905018866062, 0.0380335162792887, 0.024251016289261833, 0.01673410357242184, 0.0859714996601854, 0.009667466693956937, 0.05715787650219031, 0.047024166344531944, 0.02331875667109021, 0.04414098962609257, 0.02697087132505008, 0.010989467496983707, 0.013942808977195194, 0.0586225621934448, 0.03866643338863339, 0.09213366292949234, 0.02061937134047704, 0.5242195448705128, 0.2751750185021332, 0.24573023564049176, 1.4196146811757768, 0.9262131111962455, 1.014783101422446, 1.5908594408205576, 0.7200788951345852, 0.16443308229957307, 0.6336243056825229, 0.5479094279663903, 0.48262746525662287, 6.161742849009378, 4.195593288966587, 0.846562382365976, 0.2510348324264799, 0.176779569791896, 0.23667458870581218, 2.116785202707563, 14.501230052539281, 32.941277503967285, 40.41551031385149, 38.20903689520699, 38.51126963751656, 35.85111706597464, 46.378228528159006, 77.97394915989467, 80.82879720415387, 50.973225116729736, 32.68512174061367, 53.76980904170445, 77.01258945465088, 50.74623441696167, 0.8150668495467731, 0.1893567999026605, 0.04283017871369209, 0.05724729384694781, 0.03845269825043423, 0.02995074606899704, 0.027627956155421476, 0.046281268886689625, 0.049762879564825974, 0.028228938014113476, 0.03035587557990636, 0.027634229211668884, 0.02430180972442031, 0.05040835635736585, 0.021208310898925577, 0.01675154022606356, 0.07472020840006215, 0.03485821666462081, 0.022194195139620985, 0.009249871646586274, 0.027807433756866624, 0.057864787855318615, 0.06777273584157228, 0.023913043085485697, 0.004630333569366485, 0.05455551489389368, 0.060058701916464736, 0.05129184287839702, 0.06726269463875464, 0.01893374277278781, 0.010376502709862376, 0.07307349890470505, 0.116328912121909, 0.13487544549363, 0.1350028607994318, 0.09923118672200612, 0.13880737950759275, 0.10939252004027367, 0.18903134736631597, 0.15887615191084997, 0.4516028900231634, 0.05274278823552387, 0.1454809478351048, 0.3514950360570635, 0.09842155873775482, 0.11198548733123712, 0.1972589237349374, 0.09440778661519289, 0.20378640347293445, 0.20164585619100503, 0.07995311117597989, 0.10484813353312866, 0.11948062585932867, 0.13628774828144483, 0.1152419668755361, 0.08343956659414939, 0.15054379616464886, 0.1881967085812773, 0.1721581627747842, 0.20237017875271185, 0.1091494687965938, 0.18795761998210633, 0.11695325933396816, 0.12765702711684362, 0.07272918988019228, 0.1320137104817799, 0.12276112554328782, 0.15821016979004654, 12.297713960920062, 107.37066568647111, 107.90434987204415, 96.51208346230644, 87.74849428449357, 96.45960371834892, 114.6597567967006, 105.76764678955078, 95.67108740125383, 41.48403903416225, 38.552990095955984, 60.26290757315499, 57.41567128045218, 18.146186419895717, 1.4256917493683952, 1.029532932809421, 1.8583530357905795, 2.4025372522217885, 1.9034698605537415, 0.44084800141198294, 0.26474959935460773, 0.45292014362556593, 1.451470977493695, 1.0844721219369342, 3.5818595588207245, 7.9794076681137085, 8.299671854291644, 6.920718899794987, 6.066157783780779, 4.7874243429728915, 2.048850928034101, 0.3395611249974796, 0.6237054264971188, 0.6314914801291057, 0.8949980033295495, 0.9076888337731361, 0.4188446578170572, 0.4710747280291149, 0.18200922917042459, 0.16713526658713818, 0.10310501778232199, 0.19890962301620416, 0.12076879745083195, 0.23599358381969587, 0.14835891340460095, 0.23248992753880365, 0.1811133051025016, 0.15650847181677818, 0.08979705973927464, 0.3164977468550205, 0.12972984303321156, 0.2103594671934843, 0.12388353102973529, 0.13038947406624044, 0.5495978945067951, 0.19464703888765403, 0.16904456913471222, 0.11711496779961245, 0.16260229982435703, 0.16740341005580767, 0.08573202429605381, 0.08277746569365263, 0.11327917541244201, 0.0992168899891632, 0.11921979699816022, 0.20552799930529936, 0.06326510557638747, 0.12173775902816228, 0.17784854743097508, 0.08516601073954787, 0.17653684424502508, 0.10687447658606938, 0.1953692172787019, 0.16006163401263102, 0.1852140857705048, 0.8065106315272195, 0.6079107597470284, 0.3504428725157465, 1.5972206251961845, 1.3963337647063392, 0.6730796513812882, 1.0743985367672784, 2.0688960467066084, 2.196143618651799, 3.978180680956159, 1.0395498467343194, 0.25366293426070896, 8.624751142093114, 6.472321680613926, 2.2506055533885956, 1.0457101847444261, 0.6313971366201128, 0.3329468199184963, 5.0431163140705655, 23.440088408333914, 42.424380438668386, 35.407877581460134, 36.25492899758475, 47.375152587890625, 56.825960295540945, 72.96632684980119, 90.80475670950753, 70.93616049630302, 42.33366128376552, 49.94432544708252, 68.90535490853446, 96.91018050057548, 40.80652018955776, 0.29898877495101517, 0.19210982003382274, 0.16009385085531644, 0.20261038014931337, 0.14083614493055002, 0.10222608423126595, 0.1353003712637084, 0.1252660189888307, 0.15273737774363585, 0.16561124979385308, 0.11464421823620796, 0.1476500614413193, 0.1555568535945245, 0.2187827466321843, 0.10561350746346371, 0.12397024780511856, 0.22763448022305965, 0.1267951519361564, 0.1642362257199628, 0.12278062663972378, 0.10859633383474179, 0.16270247873451027, 0.11537684606654303, 0.059757167739527564, 0.0807056472237621, 0.26917704035128864, 0.17256620659359864, 0.14572797529399395, 0.215499003550836, 0.0954508984993611, 0.17531075860772813, 0.16118747288627283], [0.04302137291857174, 0.03472404654270836, 0.02729420004678624, 0.010035180935769208, 0.07619549959365811, 0.010017203150450118, 0.03782454106424536, 0.05255919023017798, 0.04377113715080278, 0.011230370329160775, 0.02041648597722607, 0.08997430665684597, 0.03637080692819186, 0.06315835166190352, 0.02304633503912815, 0.016958142264879177, 0.023431410447561314, 0.04448244541085192, 0.08640472391354186, 0.022288029747349874, 0.04573522122310741, 0.036567714397928545, 0.0645587733015418, 0.03786205726542643, 0.004966169811918267, 0.04351685615256429, 0.025748465043891753, 0.024078939808532596, 0.10593031546367065, 0.0309588964363294, 0.030793154079999243, 0.022567966154643467, 0.01714522285120828, 0.1012494077107736, 0.011162870513674403, 0.08131464597369943, 0.14131232723593712, 8.972203629357473, 83.84812995365688, 76.50942870548793, 70.36198220934186, 51.58208533695766, 59.92871311732701, 93.21854700360979, 100.25643989018032, 107.19416754586356, 42.7584741456168, 13.82736769744328, 19.6625908102308, 32.894137450626914, 27.04736382620675, 13.051280839102608, 4.076451224940164, 0.787713420178209, 2.474383579833167, 1.7133036362273353, 0.5698345229029655, 0.3303454252226012, 0.3399681917258671, 0.12395141167300087, 0.17362162710300513, 0.5870261032666478, 3.2086464081491743, 3.7324472154889787, 2.298936354262488, 3.2634036413260867, 1.0887851076466697, 0.39149443113378113, 0.501193431871278, 0.5069126678364617, 0.04360051273501345, 0.03365652436124427, 0.06219473694052015, 0.050736428038882356, 0.03501762489655188, 0.07622840175671236, 0.06839602453900234, 0.12261605475630079, 0.03814629219206316, 0.0310814907508237, 0.06473319072808538, 0.14041227767510073, 0.008687696901948323, 0.06036919275564807, 0.0260409238149545, 0.05082566217918481, 0.015881748238046254, 0.054220267704554966, 0.03816048375197819, 0.07701487812612738, 0.5456134283116886, 0.1079912773732628, 0.05182572101641979, 0.01656049699522555, 0.06621995594884668, 0.059508430372391424, 0.05228503494124327, 0.07204929100615637, 0.05951906301613365, 0.04412536635728819, 0.05248080586482372, 0.015640725814072148, 0.08708316393728767, 0.055253377982548306, 0.03827822993376425, 0.03493199377719845, 0.0383685191960207, 0.04066709389111825, 0.031600122206977437, 0.04296242518882666, 0.03184787569833653, 0.09058041484760386, 0.02698751918173262, 0.09031288884580135, 0.07893832812884025, 0.10971785044031483, 0.5105691573449543, 0.7721781166536468, 0.07243213403437819, 0.6876558320862907, 0.3272338807582855, 0.05902926929827247, 0.12701191673321383, 1.7923088882650648, 7.389324954577854, 1.7029006630182266, 5.09703346661159, 10.354849117142813, 19.6904513495309, 21.872213499886648, 21.163413865225657, 16.684375762939453, 28.675022772380284, 42.63472672871181, 52.73706701823643, 78.47781862531389, 81.33125618525914, 35.662921633039204, 25.231933287211827, 39.128686564309255, 61.76155063084194, 76.64409174237932, 25.560242618833268, 0.39567751809954643, 0.05641824619046279, 0.05209618168217795, 0.05394800552832229, 0.029525223188102245, 0.03161737395982657, 0.026385412651247213, 0.014245939407763737, 0.021723269784290875, 0.0733290555487786, 0.03273024942193713, 0.07485349981912545, 0.02329281118831464, 0.06305694460336651, 0.09720613967095103, 0.0823826329516513, 0.08658469854188816, 0.057497049016611915, 0.031939511852605004, 0.045421568410737176, 0.042284992789583545, 0.05590317025780678, 0.03582173299842647, 0.02573046859885965, 0.07594382416989122, 0.05918605159968138, 0.06217132069702659, 0.02236729281555329, 0.009941862862823265, 0.02979882207832166, 0.014659341956887926, 0.022786803876182864, 0.10875407287052699, 0.0513599270821682, 0.03145257815984743, 0.02449786732904613, 0.11617374473384448, 0.047511110215314796, 0.014170404889487793, 0.09100207686424255, 0.0026298607242227134, 0.03838188972856317, 0.05075740494898387, 0.049601534115416665, 0.07689479099852697, 0.03971428483990686, 0.05333121041102069, 0.04077709798834153, 0.04341641600642886, 0.020256470456453304, 0.016671562999753014, 0.07685784476676158, 0.01861041914006429, 0.017547553405165672, 0.06744321209511586, 0.03401286381163767, 0.04165659472346306, 0.012052397692709096, 0.028140993090346456, 0.020938744203054478, 0.039020859370274205, 0.05088901360120092, 0.033047322050801346, 0.05648998769798449, 0.05825753749481269, 0.10545353604746716, 0.04154919620071139, 0.01784928096458316, 0.039097160633121214, 0.5980401379721505, 31.00523144858224, 107.18892860412598, 88.85163893018449, 83.73947402409145, 78.36640426090786, 85.97986507415771, 100.11237594059536, 91.0205191203526, 54.683149746486116, 40.21483244214739, 40.431953225817, 53.41957466942923, 43.22703286579677, 25.91979626246861, 9.39254185131618, 1.9010840228625705, 0.9913278285946164, 0.7247217574289867, 0.23777234980038234, 0.3045135427798544, 0.7026048813547406, 0.6832848180617604, 0.22492798045277596, 0.14006412135703222, 0.7391224961195673, 4.44473397731781, 5.917263967650277, 5.944717168807983, 8.81546355996813, 2.8607742062636783, 0.188890863476055, 0.15195797170911515, 0.20239362892295631, 0.22038393999849046, 0.14515480319304125, 0.06519850290247373, 0.03953461894499404, 0.02879296176667724, 0.00735198290619467, 0.07766131165304355, 0.05135256836989096, 0.042495158833584616, 0.016572873473965695, 0.06620029878935643, 0.04548795966963683, 0.03801091427781752, 0.020265523809939623, 0.031313220637717416, 0.05425875081813761, 0.06623415768678699, 0.022419718127431612, 0.08532934768923692, 0.10987292961882693, 0.20394389145076275, 0.16526793821581773, 0.03785385038437588, 0.06200154445001057, 0.009565486273329173, 0.07107244485190936, 0.07440162263810635, 0.0627062302082777, 0.029638596211693118, 0.01946865058770137, 0.07460071159792797, 0.034568801123116694, 0.12334507278033666, 0.07394021882542542, 0.06488001213542052, 0.038445465067135434, 0.02460077734264944, 0.04691091884991952, 0.07904394210449286, 0.029740403605891124, 0.022156838394169296, 0.2114948191280876, 0.07872338859098298, 0.09878435105617557, 0.22168490876044544, 0.45857171607869013, 0.5650350004434586, 0.7939494284135955, 0.2938344601009573, 0.9025167141641889, 0.5151405834725925, 0.07012426680220024, 0.07588376025004046, 2.9578036282743727, 9.544102038655963, 1.4960277123110635, 2.873734550816672, 8.848412786211286, 21.653435570853098, 35.2240560395377, 37.18900660106114, 32.53138937268938, 31.672894273485454, 39.126122679029194, 41.034685134887695, 54.373517172677175, 78.28845936911446, 67.11270577566964, 41.62135280881609, 36.03757197516305, 57.65890686852591, 78.24771513257707, 51.29997110366821, 1.359835420336042, 0.1699213178030082, 0.033982567223055024, 0.021603243724842156, 0.0148881812846022, 0.06243249561105456, 0.01785645816874291, 0.06981736541326557, 0.006835773820057511, 0.08488803529845816, 0.02588768346634294, 0.01994872429142041, 0.02612922666594386, 0.017724739254585335, 0.04783787571692041, 0.04272850363382271, 0.010419211400273656, 0.070253717713058, 0.0699870330946786, 0.01615669741295278, 0.0641335014786039, 0.07493614538439683, 0.06721267982253007, 0.048578510260475535, 0.016946739483890787, 0.03422120798911367, 0.0250919349158981, 0.03205529028283698, 0.041241222726447244, 0.06538977513888053, 0.07945400795766286, 0.050871144381484816, 0.0368249266674476, 0.1537806253348078, 0.14941109051661833, 0.15588134261114256, 0.2230517632727112, 0.1646605408085244, 0.14536122711641447, 0.16043638890343054, 0.1700919693601983, 0.13714772356407984, 0.13934157655707427, 0.14639844931662083, 0.14407525397837162, 0.13193064422479697, 0.19489010370203427, 0.22450110050184385, 0.10618943441659212, 0.09664629399776459, 0.07791188106473003, 0.15689394756087235, 0.1235988720187119, 0.11796336727482931, 0.1953152058912175, 0.17377600739044802, 0.11772436009986059, 0.1075803701366697, 0.09605592781943934, 0.11460613885096141, 0.1266732191933053, 0.14899866336158343, 0.11827803110437733, 0.17579722750399793, 0.09432613171104874, 0.22010141158742563, 0.25296659448317116, 0.12756062086139405, 0.28374271733420237, 0.30729143800480024, 16.780273062842234, 128.80916568211146, 109.30342524392265, 104.98994881766183, 84.27370711735317, 85.19489928654262, 118.8382088797433, 122.45920698983329, 119.19269207545689, 64.82781151362828, 27.345408541815623, 37.09932620184762, 53.947811467306956, 51.09119858060564, 21.42533142226083, 4.69847480739866, 1.699245042034558, 3.717254545007433, 3.726887353828975, 0.85874990267413, 1.3259669691324234, 1.2328699018274034, 0.7477427678448814, 0.570702559181622, 1.1118580124207904, 6.261607136045184, 8.01414692401886, 7.617206760815211, 9.531458922794886, 2.474522978067398, 1.140544518828392, 0.5782119333744049, 1.2203191752944673, 0.3387646877339908, 0.3881432552422796, 0.12878388379301342, 0.15719677773969515, 0.11593172486339297, 0.17862374654838017, 0.12682403038655007, 0.20920255141598837, 0.09610637689807586, 0.13874925619789533, 0.22434232330748013, 0.16740551351436547, 0.12119897508195468, 0.11766485257872514, 0.09933966411543743, 0.12248103985829012, 0.15508156695536204, 0.11495954703007426, 0.18801923096179962, 0.30124037127409664, 1.0206198053700584, 0.22960810789040156, 0.17377971219164984, 0.16296158411673137, 0.1912013702094555, 0.15384922522519315, 0.12532513295965536, 0.13383088154452188, 0.21527310567242758, 0.18703004904091358, 0.2276659778186253, 0.10080955417028495, 0.20236074711595262, 0.1987757073449237, 0.1637780245925699, 0.11235114985278674, 0.1022724485290902, 0.20347811787256173, 0.1857359470533473, 0.07151126701916967, 0.14235705403344973, 0.24956550555569784, 0.17427059156554087, 0.14954903668590955, 0.43922934255429674, 0.9856313914060593, 2.2709264286926816, 3.1961615809372494, 1.4410285949707031, 2.5649038425513675, 1.746183923312596, 0.11916035733052663, 0.39437378091471537, 3.501423737832478, 8.51730419908251, 3.1761724821158817, 9.321584241730825, 16.825868879045757, 32.24941062927246, 36.83801140104021, 32.28636462347848, 28.367799486432755, 41.08377415793282, 58.082781723567415, 66.1648394720895, 89.67410414559501, 95.4256978716169, 53.577430793217246, 43.57431077957153, 56.309931482587544, 75.35608332497733, 99.3000134059361, 42.0870349747794, 0.46445190055029734, 0.15682617548320973, 0.13731537599648747, 0.07105186488479376, 0.11984573198216301, 0.1673569032656295, 0.08050034966851984, 0.19919681974819728, 0.07873014679976872, 0.18064808792301587, 0.12724101729691029, 0.13125361555388995, 0.19141172963593686, 0.16089066809841565, 0.1742322136248861, 0.1781061328947544, 0.13587561968181813, 0.16230462651167596, 0.19760623866958277, 0.07146824111363717, 0.18265465168016298, 0.20212514618677752, 0.15403971714632853, 0.10488139531974282, 0.16575284648154462, 0.13047391096396105, 0.12498815889869418, 0.12810753365712507, 0.08749542824391808, 0.0973961159054722, 0.11694741036210742, 0.19023870543709823, 0.08293568648930107], [0.032096134698284526, 0.030016004174415554, 0.05850634950080088, 0.04196398465761116, 0.06260558310896158, 0.008246093589280332, 0.026470073465523974, 0.07835465909114905, 0.037972743290343454, 0.026265859869973998, 0.048918615760547776, 0.01376333985743778, 0.013732779488366629, 0.003780531222998564, 0.03573094840560641, 0.041801909783056805, 0.02946471143513918, 0.06441896794629948, 0.043536550631480556, 0.03530660956831915, 0.02312242765245693, 0.041640893423131535, 0.021640342626986758, 0.048039668638791354, 0.06945850859795298, 0.07886436102645737, 0.03702020565313952, 0.06559384454573904, 0.07553609926253557, 0.027777313587388823, 0.10383447685411998, 0.05726318513708455, 0.023743188806942532, 0.01836357149295509, 0.006605977333882558, 0.036305243482014964, 0.03946277904989464, 0.0474025208636054, 5.971355693680899, 64.05846527644566, 96.10254274095807, 77.52639484405518, 54.30921854291643, 53.530033656529014, 77.50024877275739, 92.25554752349854, 99.28157983507428, 71.59474549974713, 26.36396333149501, 11.277478694915771, 17.957030398505076, 32.35700001035418, 24.377744334084646, 11.669661947659083, 7.840734652110508, 4.720409836087908, 2.7074515649250577, 1.1489774606057575, 1.4542848893574305, 0.6724931799939701, 1.0026297249964304, 0.3620069277073656, 7.775002956390381, 5.491407138960702, 1.7010111872638976, 5.238223033291953, 1.7121763995715549, 0.8610649555921555, 0.5266914750848497, 0.4905066681759698, 0.09901808601404939, 0.1873240175523928, 0.28356635251215523, 0.08202656491526536, 0.06061927362212113, 0.022012966917827725, 0.025058125212256397, 0.01816173785898302, 0.04339136788621545, 0.05466636376721518, 0.03827653020354254, 0.002887816837755963, 0.0506185800768435, 0.025359868038711802, 0.042483165727130005, 0.045319326754127226, 0.009903078649326094, 0.08037194370159081, 0.08481427854193108, 0.0054758959200366265, 0.6006808334163257, 0.21844798459538392, 0.07606788072735071, 0.02544051531835326, 0.03817093997661557, 0.028079008916392922, 0.03823506832122803, 0.05768528820148536, 0.03218941290729812, 0.09221767913550138, 0.012388621124305894, 0.02360162265332682, 0.07140810255493436, 0.005477511257465396, 0.01566517343079405, 0.035202094819396734, 0.00781764367794884, 0.014936874653877956, 0.01092101858064, 0.04771070468372532, 0.04156742165131228, 0.02982155978679657, 0.07631987506257636, 0.09831785144550459, 0.08997038472443819, 0.19972701344106877, 0.24143282909478458, 0.4039614807282175, 0.10791380224483353, 0.0814258171511548, 0.14278763878558362, 0.19277468935719558, 0.8913831487298012, 2.6275014664445604, 4.321311388696943, 4.6946841308048795, 12.553087183407374, 28.923750911440166, 21.36556475503104, 22.17607385771615, 31.592152731759207, 42.7042920930045, 53.930986404418945, 65.30684116908482, 83.34781796591622, 63.762617928641184, 35.97346442086356, 30.175710337502615, 53.43242188862392, 71.19430691855294, 70.06647532326835, 13.097474200384957, 0.1460818720183202, 0.07716334158820765, 0.04520903767219611, 0.06965604371258191, 0.02741574602467673, 0.04561628760503871, 0.108015881053039, 0.08914410549082927, 0.03149237084601607, 0.042189902892070155, 0.016979684055383717, 0.07675882615149021, 0.03886543753157769, 0.02847961090239031, 0.04637871330071773, 0.023765241195048605, 0.028312218009627292, 0.04431758175737091, 0.036960813482957225, 0.038109929500413794, 0.06441210117191076, 0.04408357199281454, 0.02837768815723913, 0.026472200672807436, 0.06650793978146144, 0.06477074085601739, 0.03373057288782937, 0.07892050301390034, 0.04210735571437648, 0.015165937898148383, 0.04435785620340279, 0.02635861560702324, 0.013705141060719532, 0.07463439407625369, 0.029184693603643348, 0.015126647327893546, 0.04019118978508881, 0.04989452214379396, 0.042601451344255886, 0.021168396076453582, 0.04471382924488612, 0.08041611633130483, 0.0384467882104218, 0.02121476546329047, 0.03803124997232642, 0.03714146664632218, 0.02409298887609371, 0.032529118071709356, 0.03259282911728535, 0.033906483091413975, 0.047413828649691174, 0.02485641371458769, 0.05908621874238763, 0.02463956070797784, 0.0396143094902592, 0.0905669459274837, 0.05932174503271069, 0.013943098202746893, 0.04597948704447065, 0.027137874060177376, 0.06636761195425477, 0.013470396782005472, 0.02399112719909421, 0.07124001586011477, 0.0723120876188789, 0.06687261164188385, 0.013625803353664066, 0.07582377096904175, 0.05093333890129413, 0.029188635892101696, 0.02394532778167299, 0.4171538571161883, 34.27896901539394, 91.77101489475795, 96.81555298396519, 76.07129614693778, 73.25853334154401, 87.90048612867082, 99.90703582763672, 100.52718339647565, 61.48397009713309, 28.72288543837411, 27.41583374568394, 37.801910672869, 43.79116405759539, 46.53890214647566, 32.29815571648734, 16.996198756354197, 8.226397020476204, 5.466569934572492, 3.32021233013698, 1.444334743278367, 2.0295759737491608, 2.6536577429090227, 1.6729286313056946, 1.376728770988328, 8.204376442091805, 9.801537139075142, 10.89436023575919, 7.027199608939035, 1.2909600990159171, 1.1219720925603593, 1.0793717099087579, 0.7489386722445488, 0.021547218784689903, 0.1017462649781789, 0.14491625742188521, 0.06609006399022681, 0.03385162692783134, 0.033025374835623164, 0.018940746950517808, 0.03621107978480203, 0.02242876130289265, 0.010912582694020654, 0.03865162775452648, 0.014056657823467893, 0.026538054192704812, 0.003522189404715651, 0.030909112322011163, 0.03725544695875474, 0.049094125628471375, 0.12019966941859041, 0.08211643009313516, 0.03661953750997782, 1.2445242021765028, 0.11823164645050253, 0.09952907716589314, 0.01822049729526043, 0.07044157013297081, 0.07554593123495579, 0.04594213029901896, 0.04388154158368707, 0.10216962333236422, 0.13265819661319256, 0.013108865690550633, 0.021326766149806123, 0.04964556764545185, 0.03868628053792885, 0.04522269658212151, 0.01706479779178543, 0.03733926638960838, 0.013303421188278921, 0.03382187995261379, 0.046377485152333975, 0.3283072145921843, 0.06053759157657623, 0.06955039581017834, 0.049651684638644965, 0.36406587436795235, 1.0514907602752959, 0.610251108450549, 0.6250703132578305, 0.2849718970911843, 0.27627858785646303, 0.17455507415745938, 0.07274312020412513, 0.510464065841266, 3.460650839975902, 4.206033391611917, 6.424152859619685, 21.87731695175171, 38.373108182634624, 38.81066056660244, 31.617822851453507, 30.76293386731829, 30.73507159096854, 43.52385990960257, 51.28359767368862, 68.66502366747174, 83.43312794821603, 65.86551802498954, 36.12411873681204, 44.43996252332415, 66.2920331954956, 80.28578853607178, 41.77486630848476, 0.8900956149612154, 0.19838606539581502, 0.024430024005206566, 0.0679211246648005, 0.020481165631541183, 0.0578581178560853, 0.07045117818883487, 0.0977347388065287, 0.02661726128176919, 0.021671490777017813, 0.022678031320018426, 0.03843743121251464, 0.019356695702299476, 0.08896092817719493, 0.07269120548984834, 0.06512007103966815, 0.06324745009520225, 0.0855618477133768, 0.06481558523539986, 0.07459591435534613, 0.024995448932583843, 0.05402839496465666, 0.025158879180837954, 0.04593088697375996, 0.046446773755763254, 0.02550358514833663, 0.09746601858309337, 0.038524694208587916, 0.06609969918749162, 0.03188227063843182, 0.02192996851434665, 0.01931203792004713, 0.025276204670912454, 0.005767158349044621, 0.12222304727349963, 0.10486584329711539, 0.20844078729195253, 0.10916721248733145, 0.12158595717379025, 0.17209980876318046, 0.11492875511092798, 0.20391185102718218, 0.17470371403864451, 0.08877794085336582, 0.15184232220053673, 0.06716048012354545, 0.11089400947093964, 0.11868815124034882, 0.0854316164872476, 0.09284683037549257, 0.16642933232443674, 0.16745824925601482, 0.19307762810162135, 0.173896298078554, 0.16312061915440218, 0.2135733211679118, 0.14956367947161198, 0.12051556818187237, 0.1368012364421572, 0.14196590573659965, 0.22533724563462393, 0.09814095736614295, 0.14296019024082593, 0.17817375569471292, 0.2138146489326443, 0.13202000728675298, 0.09317862721426146, 0.19797977219734872, 0.12289095643375601, 0.11326058355293103, 0.18837319553962775, 0.16589010054511683, 16.23126983642578, 104.97998510088239, 121.8012820652553, 99.94545936584473, 85.81034292493547, 77.94153581346784, 103.88540758405412, 114.58354200635637, 112.34810502188546, 93.42232377188546, 42.03433983666556, 27.86752050263541, 35.35395956039429, 60.92908000946045, 51.204541070120676, 28.149606943130493, 16.275974546160015, 7.259795333657946, 5.077267578669956, 3.3197622171470096, 4.89949357509613, 4.416968975748334, 2.249393961259297, 2.170945542199271, 11.963868652071271, 12.245055300848824, 13.865710462842669, 10.16441375868661, 1.15940822660923, 2.9598891735076904, 3.251417998756681, 3.0166746292795454, 0.6936333456209728, 0.6975369847246579, 0.6174396712865148, 0.3727743827870914, 0.12802175326006754, 0.09217088736061539, 0.11832520285887377, 0.18281963068459714, 0.13804584608546325, 0.17806744282799108, 0.10590531144823347, 0.11967205415878977, 0.0958061930058258, 0.12172260055584566, 0.19450013605611666, 0.1028585195807474, 0.07971375794815165, 0.32010011641042574, 0.2093506756105593, 0.11449489982000419, 1.6892357277018684, 0.2712252932999815, 0.2259927104626383, 0.11494708912713186, 0.20140702543514116, 0.20554477269096033, 0.11548565594213349, 0.2452019825577736, 0.24312200131160872, 0.1713144044790949, 0.12419480218419007, 0.11556841007300786, 0.21543328064892972, 0.07315508595534734, 0.13250819966197014, 0.11422782843666417, 0.12206074169703893, 0.25518738531640595, 0.1291003796671118, 0.0943451781890222, 0.12325974021639143, 0.21993392200342246, 0.10700090123074395, 0.2089791912585497, 0.32884418006454197, 0.9436889163085392, 1.0537027844360896, 1.5104406646319797, 0.496634273656777, 0.24278183813605989, 0.2486580056803567, 0.48911274011646, 1.9639207082135337, 5.70559925692422, 16.553021805627004, 30.560928889683314, 37.74256610870361, 48.49290929521833, 35.41476672036307, 32.9992949622018, 47.88571664265224, 60.23932538713728, 66.2795820236206, 74.85670934404645, 97.23037433624268, 79.8422155380249, 56.685662269592285, 48.60035971232823, 67.92160810743059, 86.04816586630685, 99.56184932163784, 28.145154884883336, 0.24247663308467182, 0.15949873493186065, 0.14453188090452126, 0.16240354334669455, 0.12174515505986554, 0.19724911211856774, 0.1665487273463181, 0.2340070775577, 0.11672395520976611, 0.16375667788088322, 0.09543915984353848, 0.09335951786488295, 0.1271346908594881, 0.24321911324347767, 0.186881029180118, 0.1433071116251605, 0.12493701092898846, 0.1950246707669326, 0.19433606628860745, 0.16883119701274804, 0.3522530953798975, 0.14904417949063437, 0.1360983827284404, 0.09413321063454662, 0.09637033380568027, 0.12675255350768566, 0.1322355642914772, 0.15191660821437836, 0.16887063346803188, 0.11869708076119423, 0.13293290830084256, 0.07969637388097388, 0.09694475441106729, 0.12501110695302486], [0.03744432396654572, 0.06554292049258947, 0.05835261382162571, 0.06689982768148184, 0.05750562569924763, 0.08523256823952709, 0.06044799102736371, 0.06656083158616509, 0.08145159469651324, 0.044072318489530256, 0.06389697774180345, 0.0486182350931423, 0.05275376353945051, 0.021824495334710394, 0.04275767046159931, 0.012511135710935508, 0.011700947935293828, 0.044100772855537276, 0.02560052914278848, 0.020654287056199143, 0.02285476085463805, 0.0514698735039149, 0.01065601927361318, 0.04438985252220716, 0.026536948180624416, 0.06561679260006972, 0.052674829560731135, 0.03515260586781161, 0.025789138129247085, 0.052034472314906974, 0.043188740366271565, 0.008255391215373362, 0.07062403498483555, 0.02806484789055373, 0.022737231804057956, 0.01321867386078728, 0.13078638991074903, 0.20016350144786493, 0.14746726410729544, 9.707062482833862, 104.50212274278913, 93.33101054600307, 79.38833141326904, 55.58290672302246, 46.29621199199131, 65.94212886265346, 76.4451231275286, 97.12293434143066, 83.7110697882516, 45.92723832811628, 18.441373688834055, 13.24858101776668, 15.356524637767247, 25.553645304271154, 29.22370638166155, 21.866981506347656, 14.66469771521432, 7.659747106688363, 5.865460804530552, 5.606770251478467, 6.0359092354774475, 6.062892130443028, 20.26505868775504, 6.376749643257686, 3.531136840581894, 3.9095971839768544, 2.2674167198794226, 1.3991275919335229, 1.1704264410904475, 0.34659272911293165, 0.31900401094130104, 0.23398655865873608, 0.38935623158301624, 0.15297197444098337, 0.032124341399009736, 0.051093724223652055, 0.005389438684297991, 0.01875629059837333, 0.032811900933406184, 0.0039704709862624955, 0.02453298321259873, 0.013402021656345044, 0.10442407628787415, 0.10913113478038992, 0.04033060159002032, 0.02522969279172165, 0.03720604282404695, 0.005078402048509035, 0.01782812933171434, 0.07624377057488475, 0.32113789500934736, 0.25168161200625555, 0.04792633293462651, 0.04371604349996362, 0.03516158627878342, 0.035411768925509284, 0.013845959129477186, 0.03846801957115531, 0.02374206413514912, 0.07736013709966626, 0.029120731500110457, 0.0542644301562437, 0.07379125324743134, 0.13440013171306678, 0.0586132255515882, 0.05221781247694578, 0.09121472973908697, 0.062493774108588696, 0.015721569868869016, 0.0331098490527698, 0.6380992169891084, 0.045734763211969814, 0.05326111774359431, 0.1535286581409829, 0.16243797221354075, 0.23939404849495205, 0.4535025166613715, 0.7805699120674814, 1.1395661256143024, 2.548627035958426, 1.9988549479416438, 4.392919957637787, 6.826798362391336, 2.6577676023755754, 8.30338740348816, 14.358612196786062, 22.30314598764692, 35.68299150466919, 42.89423499788557, 57.94253928320748, 66.09362738473075, 68.28123297010148, 79.29208496638707, 77.40917873382568, 33.908685616084504, 24.30766306604658, 37.44176469530378, 55.56901379993984, 68.28018379211426, 65.49172578539167, 10.105262875556946, 0.644929187638419, 0.06648364822779383, 0.06523672478007418, 0.11407893071217196, 0.04383278884259718, 0.015070345884721194, 0.04207244169499193, 0.039579778843160184, 0.04590659881276744, 0.02148852380923927, 0.01578703153479312, 0.03315747542572873, 0.017770633666909168, 0.09590578159051281, 0.03451695086966668, 0.033778993146760125, 0.0506035199921046, 0.06808019362922225, 0.0348992849966245, 0.07130299748054572, 0.07066915077822548, 0.10069883761129209, 0.024119451741821, 0.06972268942211356, 0.01853311703806477, 0.028853381917412792, 0.03671666640522225, 0.03508926462382078, 0.0676166999286839, 0.01942218281328678, 0.09316716675779649, 0.02094792478185679, 0.05797141284814902, 0.08143793578658785, 0.046899482142180204, 0.039566330279090574, 0.03480905680251973, 0.038271858489939144, 0.02576215618423053, 0.05774233264050313, 0.029095961579254696, 0.07126928786081926, 0.01985226375316935, 0.07525990158319473, 0.028919878349240338, 0.06311191272522722, 0.029205232858657837, 0.013891028273584587, 0.0778389046234744, 0.04345280923215406, 0.07377476484647819, 0.0278071453794837, 0.056901437762592516, 0.04547950851597956, 0.03204918007499405, 0.03683905376653586, 0.05760652385652065, 0.050258766527154615, 0.019721693259530833, 0.025449977489188313, 0.032338242778288465, 0.033404784476650615, 0.005809534133212375, 0.039058124513498375, 0.05010813853836485, 0.01416511316451111, 0.019894377029101764, 0.06728607017014708, 0.03484584357855575, 0.03185089857184461, 0.0560631586371788, 0.01651808007487229, 0.05902638552444322, 0.7548842674919537, 33.80925689424787, 121.08200454711914, 96.69024222237724, 78.69320583343506, 67.54615524836949, 79.62820407322475, 89.83430876050676, 100.081143787929, 81.29117202758789, 43.86237614495413, 23.229309592928203, 28.531250647136144, 39.72531795501709, 40.456827776772634, 41.66424751281738, 45.551709038870676, 30.269778524126323, 18.905786071504863, 11.755036200795855, 7.299501248768397, 6.349583055291857, 6.226473135607583, 9.367576105254036, 18.834139721734182, 13.859662924494062, 11.103234376226153, 9.28622659615108, 2.870308437517711, 1.138808663402285, 0.4547274080770356, 0.4760693428771836, 0.3347327783703804, 0.023340384974809628, 0.5409750172070095, 0.13295426858322962, 0.09000855231923716, 0.024661440069654157, 0.07455475442111492, 0.010727059345559349, 0.018938348329226886, 0.013532987396631922, 0.053563106538993974, 0.026308054570108652, 0.0266540548431554, 0.0479730263219348, 0.049514094700238535, 0.08197753397481782, 0.037985146910484345, 0.028612169503633465, 0.04303521164027708, 0.04609527565272791, 0.9989962513957704, 0.4804936626127788, 0.05344875303230115, 0.06675724711801324, 0.01995210848482592, 0.09800214267202786, 0.04205345628517015, 0.11037820750581366, 0.04300095919253571, 0.0692518607580236, 0.01792860510093825, 0.03580202155613473, 0.07946687298161642, 0.18212410514908178, 0.06497245574636118, 0.02340146669718836, 0.03281482541933656, 0.09552120829799346, 0.03639203150357519, 0.05216167727485299, 0.35609838047197884, 0.11145694247846093, 0.06350855715572834, 0.055322988890111446, 0.04458384568403874, 0.0854745881099786, 0.59990415509258, 0.9037944227457047, 1.186614983848163, 0.6663190541522843, 0.7086812438709396, 1.2849809569971902, 4.865337099347796, 2.427169919013977, 9.22451182774135, 22.29054890360151, 34.34883662632534, 42.776449135371614, 34.96401275907244, 40.071657861982075, 51.4320250919887, 62.45215293339321, 68.39445386614118, 79.91481726510185, 67.19226264953613, 46.33884613854544, 39.707759857177734, 51.10664095197405, 73.0912971496582, 90.22807012285504, 30.9063446862357, 1.6271584587437766, 0.11705894794847284, 0.030751580239406655, 0.04357549514887588, 0.02914890766675983, 0.07742904911616019, 0.10110219275312764, 0.08157520342086043, 0.05597219083990369, 0.03799128086705293, 0.04843487457505294, 0.07036118408931152, 0.04829464513542397, 0.01800748479685613, 0.037480656124119244, 0.026717180652277808, 0.046022265284721336, 0.09008156947259392, 0.09180215107543127, 0.030038131201373677, 0.06594602457646813, 0.06230496495429959, 0.07246770284005574, 0.03699764436376946, 0.06715875664459807, 0.05111296069143074, 0.0469222775261317, 0.016237397279058183, 0.06752458201455218, 0.04042918933555484, 0.03551781377089875, 0.05438847653567791, 0.0433555989127074, 0.06198396360767739, 0.08112504971878869, 0.097599140368402, 0.18414926076573984, 0.14613352210393973, 0.12056240066885948, 0.20289091366742337, 0.293647754405226, 0.13931617220597609, 0.2042657613222088, 0.16701893854354108, 0.12555487134626933, 0.17749664559960365, 0.17369752803019115, 0.16905809912298406, 0.2072454664324011, 0.13239709633801663, 0.12591647622840746, 0.07797075754829816, 0.18268001531916006, 0.17633203523499624, 0.1732470350606101, 0.08510505115347249, 0.10965986962297133, 0.17529866711369582, 0.11425943459783282, 0.17518890728907927, 0.1245404886347907, 0.13011022976466588, 0.1274412665516138, 0.11476959793695382, 0.15200279573244707, 0.14053464468036378, 0.16639182290860585, 0.1686947707618986, 0.15616088546812534, 0.15636797435581684, 0.1255805335406746, 0.34956756234169006, 0.32992788191352573, 0.2706216685473919, 19.992628506251744, 146.92202159336634, 116.854095186506, 101.6672716140747, 83.9671664919172, 71.45954050336564, 85.6350120816912, 104.43754618508476, 116.67535972595215, 104.48326533181327, 67.56617995670864, 40.887199197496685, 30.999377591269358, 32.40100990022932, 44.682534558432444, 57.77501474108015, 45.992617402757915, 31.24364151273455, 16.298351219722203, 10.498128788811819, 7.629244514874049, 9.148982303483145, 13.486654962812151, 25.57759748186384, 17.670886210032872, 16.33875846862793, 11.658256479672023, 3.4052843366350447, 1.9204764451299394, 1.801559871860913, 1.2769543762717928, 0.9585224517754146, 0.8479347058704921, 1.209941606436457, 0.5512708904487746, 0.21753046954316752, 0.14046232641807624, 0.08537511487624475, 0.07316530469272818, 0.1112212533397334, 0.12278324578489576, 0.17752582260540553, 0.06428318630371775, 0.2296644262969494, 0.3039161062666348, 0.10132304233099733, 0.17009405924805573, 0.12226538785866328, 0.10056302882730961, 0.1428219319454261, 0.18967657988624914, 1.4590794720820017, 0.8573304074151176, 0.17129715611892088, 0.21300063761217253, 0.08816681150346994, 0.19691981907401765, 0.05217534636280366, 0.22460563560681684, 0.17024615965783596, 0.21195707789489202, 0.10321730854255812, 0.15729817801288196, 0.14895081307206834, 0.30871389167649405, 0.1674317999609879, 0.12678871942417963, 0.27427148127130097, 0.20829469870243753, 0.15044383438570158, 0.19462238092507633, 1.6911513677665164, 0.0924257654696703, 0.109325582560684, 0.23184187231319292, 0.23544147344572203, 0.4311410151422024, 1.1783545528139387, 1.715536613549505, 2.315803757735661, 4.149826373372759, 4.785510548523494, 10.6583377463477, 9.59822416305542, 1.811731708901269, 18.940726825169154, 38.461235659463064, 45.85318442753383, 54.00427600315639, 58.00384323937552, 75.42812919616699, 74.98127664838518, 80.71343626294816, 92.67428071158272, 92.35453156062535, 52.797200202941895, 46.46843351636614, 55.82839700153896, 72.35911682673863, 90.3599955695016, 98.08613531930106, 18.43156804357256, 1.1413678803614207, 0.19405998396021978, 0.16260893589683942, 0.24639435857534409, 0.14322817086109094, 0.1351750051336629, 0.20183180192751543, 0.13853676617145538, 0.14748050911085947, 0.10408321422125612, 0.12302042091531412, 0.13544943183660507, 0.08048888921205487, 0.1486758163997105, 0.10143417279635157, 0.10316830474351134, 0.11382665817758866, 0.1343378693397556, 0.16156891813235624, 0.13794952125421592, 0.3106023089161941, 0.29728592346821514, 0.2245036789349147, 0.1647488453558513, 0.14392788974302156, 0.0809597789442965, 0.17663364405078547, 0.09188915283552238, 0.11802444899720804, 0.11228791038904871, 0.2053681771670069, 0.11888274151299681, 0.1754702279078109, 0.14767148957720824, 0.20756722773824418], [0.008182957602132643, 0.01730933502715613, 0.03297180449590087, 0.06681718890156065, 0.003151782863174698, 0.03365693487493055, 0.015915373040895377, 0.023797641242189065, 0.04889725887083581, 0.05134205107710191, 0.03980216530284711, 0.05173098395711609, 0.043222185357340744, 0.031218744814395905, 0.0422556970401534, 0.023633286489972045, 0.02085076704887407, 0.004490678339997041, 0.018026811170524785, 0.031447855556117635, 0.02399646387701588, 0.06137136862214122, 0.04098642264891948, 0.027652712505576865, 0.12267112465841429, 0.07445089785116059, 0.05352313743372049, 0.053543032080467255, 0.05741739579077278, 0.02473598053412778, 0.06662194044994456, 0.10234193730034999, 0.061823537573218346, 0.02314454280505223, 0.01829806572225477, 0.04363303152578218, 0.11543971912137099, 0.1289194958018405, 0.1671466931168522, 0.041434075949447494, 8.331403408731733, 76.1669728415353, 94.39518274579729, 88.18948255266461, 73.42887537819999, 45.93516622270857, 36.958625180380686, 67.62866510663713, 90.9165323802403, 84.72756344931466, 73.79953398023332, 57.45275034223284, 37.097352913447786, 25.371737991060527, 25.907503162111553, 34.84771728515625, 32.16302020209176, 35.88274526596069, 29.423397609165736, 25.702559096472605, 20.2502155985151, 17.5978866985866, 13.733215263911656, 8.136793051447187, 3.8729172093527655, 3.6157461404800415, 5.842612956251417, 2.265872265611376, 1.204650227512632, 0.3097326712948935, 0.2628859079309872, 0.1857820874346154, 0.3148191597844873, 0.11209193590496268, 0.08210670668631792, 0.008197293350739139, 0.01178395566863141, 0.03782531798684171, 0.05935868447912591, 0.043273221368768384, 0.04592325345480016, 0.03512232963527952, 0.02789782819205097, 0.04778291777308498, 0.01962809274638338, 0.024023691790976694, 0.062352401337453296, 0.031382244612489424, 0.08617360810084002, 0.03985181710283671, 0.9401623798268182, 0.44987897681338446, 0.02478628881674792, 0.01817778860484915, 0.08965306103761707, 0.02741117269865104, 0.04027464959238257, 0.09229869621672801, 0.06956571034554924, 0.08690652770123311, 0.07117174166653838, 0.04694857415077942, 0.03474778509033578, 0.0348939652820783, 0.003819686934418444, 0.028940953646919558, 0.10269818854119096, 0.023104258180995072, 0.03729980279292379, 0.019111559659774815, 2.0566787251404355, 0.7849054794226373, 0.10169478452631406, 0.08827653740133558, 0.714686278785978, 1.4124973373753684, 1.1769357089485442, 1.525996487055506, 2.9920984166009084, 2.243327532495771, 5.556510456970759, 9.428853137152535, 9.552787286894661, 13.529722503253392, 15.289246967860631, 17.239241531917028, 43.52659402574812, 58.07423196520124, 66.05238287789481, 64.38753196171352, 69.21347972324916, 71.49561555044991, 47.630717754364014, 31.20064605985369, 33.918607643672395, 44.42866127831595, 63.027561051504954, 72.58366176060268, 24.079685722078594, 0.25493236471499714, 0.1579377922628607, 0.13657574568475994, 0.04044279735535383, 0.16464536876550742, 0.06048524259988751, 0.04314899517755423, 0.032868677351091585, 0.0209449595838253, 0.031861276764954836, 0.03649799831743751, 0.08461343896176134, 0.010379064179557775, 0.0058863099464880565, 0.08287599576371056, 0.04911783364202295, 0.021571508642019968, 0.032922071271709034, 0.05846906400152615, 0.06895996856370143, 0.004752322715441031, 0.051340286886053424, 0.06367319689265319, 0.08127565735152789, 0.03437609378514545, 0.006345150593136038, 0.10397147307438509, 0.04750758861856801, 0.08341065421700478, 0.030004964409662143, 0.08342710190585681, 0.04508873002071466, 0.012844712007790804, 0.025595044883500253, 0.026960333676210473, 0.053489682264626026, 0.03206315789637821, 0.05531290925240942, 0.05377406986164195, 0.05389901529997587, 0.06169580335595778, 0.017245021781751087, 0.01850127847865224, 0.030496291616665464, 0.021374891246003763, 0.030553543008863926, 0.031064428987779787, 0.024010923458263278, 0.03392494942194649, 0.04555311260212745, 0.01053605173780982, 0.03438891131164772, 0.040935427349592955, 0.04442847812814372, 0.02452715459678854, 0.02498828529912446, 0.025510731818420545, 0.027382586018315384, 0.03801063268578478, 0.048656596070421596, 0.018383082767416323, 0.012605178968182631, 0.06082566361874342, 0.07576899283698627, 0.04293005567576204, 0.05381207800071154, 0.02640126153294529, 0.06053813440459115, 0.03087596588635019, 0.011320528973426138, 0.0022564406390301883, 0.0303844724382673, 0.08506673428096942, 0.044813115881489854, 0.05344851215236953, 0.18645258859864303, 0.4728826167328017, 47.01979044505528, 107.67667824881417, 99.43401636396135, 79.24131447928292, 68.24424076080322, 75.54801341465541, 71.16945321219308, 95.66513974325997, 91.1301964351109, 64.58480521610805, 41.93217699868338, 30.961714880807058, 34.795379979269846, 39.4039602960859, 44.81943144117083, 45.982473032815115, 45.786745752607075, 40.8844199180603, 31.147509711129324, 25.344843251364573, 22.085667371749878, 20.825549023491995, 22.11930533817836, 15.308029685701642, 10.008622118404933, 5.281509441988809, 7.532298036984034, 3.3513337458883012, 0.5773875947509493, 0.18387845743979725, 0.045729080481188636, 0.2978023700416088, 0.29526122925536974, 0.20875330695084163, 0.14186093636921474, 0.01673902295130704, 0.04432018733184252, 0.06613893208226987, 0.04671974160841533, 0.01698398936007704, 0.04814337253836649, 0.036530900480491776, 0.02038445064265813, 0.08361333941242524, 0.024106240665007914, 0.09169564821890422, 0.07860435997801167, 0.04597847602729287, 0.14435873233846255, 0.06785590387880802, 0.6247906482645443, 0.4062374500291688, 0.0755614832575832, 0.034663297302488766, 0.08803286190543856, 0.022897920770836726, 0.02652297035924026, 0.13068851801965917, 0.044616710527666976, 0.05670466260718448, 0.056416220763432126, 0.053740998064833026, 0.01900752667071564, 0.07033200029815946, 0.05447374124612127, 0.01510246264349137, 0.09128663409501314, 0.03665813258183854, 0.06056307735187667, 0.050666460900434425, 0.29029557428189684, 0.1748589085681098, 0.21085942536592484, 0.13810956052371434, 0.4162989572754928, 1.4158032685518265, 1.5778415564979826, 1.3279244069542204, 2.8664977848529816, 1.8000400619847434, 4.142833880015782, 9.806853379522051, 15.620234830038887, 6.912017149584634, 13.954185349600655, 32.02593224389212, 51.117372444697786, 59.13772324153355, 66.70720195770264, 72.61387252807617, 78.45431981767926, 76.83725166320801, 75.65787138257707, 59.881882258823936, 34.99112115587507, 39.519439356667654, 63.41686167035784, 82.72261210850307, 58.747651372637065, 9.609792913709368, 0.4722900113889149, 0.274818977607148, 0.04827412623646004, 0.08048622256943158, 0.056337066260831695, 0.10925105227423565, 0.02959699522969978, 0.06389261476163353, 0.06319387297012977, 0.021779939332710843, 0.03982322702982596, 0.013610856923540788, 0.037343551338251145, 0.06301139454756464, 0.1402413547039032, 0.06367862517280237, 0.05527764239481517, 0.0503130425432963, 0.07835474730070148, 0.06060535008353846, 0.1063478859141469, 0.10262096447071858, 0.14538688931081975, 0.058811310279582224, 0.04913244589364954, 0.04166222656411784, 0.08173690510115453, 0.027186387617673193, 0.035954959956662993, 0.041124894682850154, 0.022357566016060964, 0.025440006417089274, 0.0327936686974551, 0.06785154089863811, 0.05611750589949744, 0.03920889838731714, 0.20259850578648703, 0.13803687585251673, 0.10008493305316993, 0.12231254604245935, 0.12846713007560798, 0.11519185027905873, 0.21934218518435955, 0.07578468735196761, 0.18551627812641008, 0.0800660601151841, 0.13509685147021497, 0.21927815861999989, 0.22411814890801907, 0.12404830647366387, 0.18482862359711102, 0.07934179183627878, 0.06936478255582706, 0.06887752655893564, 0.12268215763781752, 0.14264547212847642, 0.14156727998384408, 0.11759550629981927, 0.17275441863707133, 0.09458989862884794, 0.3284065792603152, 0.1631003309573446, 0.17389408605439322, 0.096795890613326, 0.16559976898133755, 0.05779411843312638, 0.11414773416306291, 0.10041028380926166, 0.211418606074793, 0.1118379466767822, 0.14243807111467632, 0.1827285305729934, 0.18331091717949935, 0.31008770795805113, 0.26199610424893244, 0.15912948974541255, 22.627241236822947, 124.87987600054059, 121.26360266549247, 105.56116717202323, 97.16403988429478, 73.29657472882951, 56.53335428237915, 89.28608894348145, 115.00207369668144, 105.8162008013044, 95.3854261125837, 82.82685593196324, 67.89065388270787, 48.253568172454834, 46.88379682813372, 53.14546823501587, 55.46834135055542, 55.487518378666465, 47.96189669200352, 36.50374746322632, 29.91837338038853, 26.928652116230555, 27.49048866544451, 15.45376467704773, 11.144731623785836, 7.782304644584656, 14.925986460277013, 7.330850652285984, 2.7105115950107574, 0.8800150815929685, 0.8326928008879934, 0.5256067961454391, 0.4423943284366812, 0.3170184003455298, 0.21251070818730763, 0.07490257825702429, 0.11640717435095992, 0.11263268081737415, 0.2345418445765972, 0.13359209150075912, 0.14479378185101918, 0.16106768431408064, 0.15193946127380642, 0.19680938071438245, 0.1320829481950828, 0.1499673399542059, 0.16429829810346874, 0.16397002286144666, 0.3433110623487404, 0.10026487375476531, 1.6032059554542815, 1.6436053876365935, 0.12577490668211663, 0.09529403477374997, 0.23934250697493553, 0.09322184310959918, 0.2606108614376613, 0.1353802891182048, 0.14435312763920852, 0.29265950886266573, 0.15838205628097057, 0.15377751764442238, 0.12881880120507308, 0.14456145146063396, 0.30921964453799383, 0.1143924817442894, 0.17260469309985638, 0.14067640421645983, 0.1384931227990559, 0.1456099237714495, 3.5112799746649603, 1.5569829557623183, 0.17908155412546226, 0.23567385811890873, 1.733370576586042, 3.615167268684932, 4.792800945895059, 5.302626754556384, 8.633460709026881, 8.095881189618792, 13.378851924623762, 18.930160352161952, 17.34489757674081, 15.453323466437203, 32.7409678867885, 48.91268123899187, 70.14992318834577, 82.11840370723179, 84.48508521488735, 80.74249362945557, 92.74064295632499, 86.73737158094133, 65.2551326751709, 51.02183818817139, 50.39036505562918, 62.050950050354004, 80.49875082288469, 101.48647253853935, 50.94570677621024, 3.2397272203649794, 0.37138436308928896, 0.27250862015145166, 0.1479257502193962, 0.2660630803023066, 0.07104811937149082, 0.2104581668972969, 0.14566145172076567, 0.2001067894910063, 0.09329354390501976, 0.17316729362521852, 0.17692166859550135, 0.08665236205394779, 0.14016401528247766, 0.2121982563819204, 0.23416737467050552, 0.19653732888400555, 0.19854743459395, 0.1407776823533433, 0.16856610695166246, 0.19023137725889683, 0.23211114214999334, 0.17609779137585843, 0.15439148327069624, 0.26750719281179564, 0.24744562645043644, 0.19589177066726343, 0.1460078709891864, 0.17361975434635366, 0.11221216552491699, 0.12462367702807699, 0.08696332786764417, 0.10781892947852612, 0.13412722492856638, 0.17015919860984596, 0.17282403632998466, 0.13199958338269166], [0.02395590444627617, 0.0877626489049622, 0.05015777676765408, 0.01786992878520063, 0.01506725515771125, 0.07781548837998084, 0.03941872516380889, 0.0309654714406601, 0.08120795991271734, 0.06954690135483231, 0.030448207232568945, 0.02510813663580588, 0.056217562673347335, 0.11127804672079426, 0.041770405402140956, 0.060292185816381655, 0.04130785147260342, 0.058901168672101836, 0.0546059096897287, 0.05763497482985258, 0.04128583301124828, 0.053500196164739985, 0.06277198703693491, 0.07249334467841045, 0.005006790310809655, 0.0766580772719213, 0.03981626865320972, 0.026377068366855383, 0.02344834159261414, 0.022067687374406626, 0.0641477574993457, 0.0740819512201207, 0.011820980780092733, 0.0534881385974586, 0.022768737881311348, 0.02131146009612296, 0.009173614488515471, 0.06319949802543436, 0.05860821796315057, 0.09766821523330041, 0.2062454686633178, 4.254442359719958, 53.448889119284495, 121.30181775774274, 79.80536229269845, 62.5183345249721, 52.81566504069737, 37.78382451193673, 58.19376529966082, 88.17357117789132, 90.04527691432408, 86.26519284929547, 75.48440265655518, 70.02890641348702, 62.63852446419852, 64.70018700190953, 54.15231779643467, 52.3962995665414, 56.980630670275005, 46.109215123312815, 42.965884821755544, 24.728868075779506, 11.960989492280142, 10.927062800952367, 11.10208444935935, 10.006084288869586, 7.131310982363565, 2.1172222878251756, 1.7416996210813522, 0.47109014434473856, 0.09017931922738041, 0.2198029783155237, 0.08340983318963222, 0.10415501001157931, 0.04544177518359252, 0.07024367539478199, 0.08600506000220776, 0.12561496240752085, 0.032681320261742385, 0.10762239859572478, 0.05014799568536026, 0.0964279549994639, 0.01973655996178942, 0.10253723324941737, 0.07060634557689939, 0.036605108462806256, 0.053075830186051984, 0.047513912564941814, 0.04679237538948655, 0.08006468268909625, 0.511443056166172, 0.5588607660361699, 0.07227061555853911, 0.050478486344218254, 0.014309609741238611, 0.023785900890028903, 0.02801499083372099, 0.07118921394326858, 0.08248385680573327, 0.07035018503665924, 0.02717413836424904, 0.00220134380755813, 0.06945580124322857, 0.09810667099165064, 0.0626817825915558, 0.045517160424164364, 0.052555587209228954, 0.030579079674290757, 0.09725558451775994, 0.22247941898448126, 0.02459658569257174, 0.6460335712347711, 0.282861626041787, 0.3014428461236613, 0.7383296958037785, 1.4000155500003268, 1.3703147151640482, 2.5791860818862915, 4.671760720866067, 6.828396882329669, 10.50998502118247, 11.98381953580039, 15.907660961151123, 15.778714554650442, 15.589622804096766, 35.35581472941807, 50.58951084954398, 52.51626021521432, 55.095164026532856, 57.91378763743809, 45.44182675225394, 30.639863899775914, 31.204307760511124, 49.23382350376674, 64.32128088814872, 72.14376435961042, 52.8599146434239, 8.017567174775259, 0.239122390214886, 0.05904344389481204, 0.04896694102457591, 0.11193385081631796, 0.10032531086887632, 0.007578258219707225, 0.01558269071392715, 0.028355354177100316, 0.0429927285627595, 0.1183098272553512, 0.026830216104696904, 0.05465715604701212, 0.07101787028035947, 0.04111868608742952, 0.020887804882866994, 0.05074558147628393, 0.09093872204955135, 0.05517497665381857, 0.09208345133811235, 0.019243456689374785, 0.01951306070467191, 0.05354399560019374, 0.019054871451641833, 0.045574198077831946, 0.10941222469721522, 0.04701119954032557, 0.029867849445768764, 0.07377228819366012, 0.08574478753975459, 0.04051640483417681, 0.058382421864994934, 0.012841000421238797, 0.14465529285371304, 0.0508093535900116, 0.06955482664385013, 0.033005205382193835, 0.04973707827074187, 0.09006474180413143, 0.05336602943550263, 0.04419523850083351, 0.06700232039604868, 0.08787717204540968, 0.06859431282750197, 0.04788143087976745, 0.021193878459078924, 0.06024126854858228, 0.06194312937025513, 0.05404745501333049, 0.04065897861229522, 0.013275454519316554, 0.09482642236564841, 0.10506433514612061, 0.04192537601505007, 0.01994889053249998, 0.058538817401443205, 0.06017648881035192, 0.12330581274415765, 0.023868940005611097, 0.03510665547634874, 0.07927296802933727, 0.020600647166637436, 0.05518457792433245, 0.011672639454315816, 0.13275277082409176, 0.06153930603925671, 0.04006248526275158, 0.025560057921601192, 0.025541757832148244, 0.02578127051570586, 0.02610910131729075, 0.018252824399886385, 0.03504043724387884, 0.04792444660727467, 0.028965031462056295, 0.027741933075178946, 0.060454966367355416, 0.10297646932303905, 0.06390434663210597, 1.2859085415090834, 23.547088929585048, 93.25214849199567, 113.11305304936, 84.99984945569719, 62.17514215196882, 56.530776500701904, 65.66120624542236, 87.01388209206718, 97.19495241982597, 89.65032046181815, 75.9422333581107, 59.37260709490095, 50.618992056165425, 48.08596025194441, 58.43660136631557, 54.3302264213562, 60.20482063293457, 64.38847691672188, 58.86301926204136, 54.516052518572124, 40.06375428608486, 24.955876146044048, 17.609634365354264, 7.133963891438075, 5.3645821043423245, 9.253482341766357, 3.2587383602346693, 1.4585679109607423, 1.0409309097698756, 0.4451530346912997, 0.5003366864153317, 0.09400264692625829, 0.10121603057320629, 0.04785537852772644, 0.052622192206659486, 0.05718461756727525, 0.07212434376456908, 0.061537663984511576, 0.09922533775014536, 0.004663279413112572, 0.08126956410706043, 0.04249752013544951, 0.055434713073607, 0.0009990143173906419, 0.06866008322685957, 0.03550535926063146, 0.04845447066639151, 0.047731125195111544, 0.030306379842971052, 0.5762352794408798, 1.2284214262451445, 0.06751580855676106, 0.18634525792939322, 0.023101851078016416, 0.12110354591693197, 0.13229428471199103, 0.055782428343913386, 0.06285598288689341, 0.08378221320786647, 0.02196820905166013, 0.01512950735299715, 0.10135417351765291, 0.059053540495889525, 0.06375679919230086, 0.0734674631218825, 0.07040057304714407, 0.026361178773056184, 0.1310393206243004, 0.08144469399537359, 0.057650187584970675, 0.17589741998485156, 0.2552513304565634, 0.24463144317269325, 1.5871735300336565, 1.7193363010883331, 1.498963869043759, 0.687970292355333, 3.933307477406093, 4.507417150906154, 9.927663445472717, 15.398067917142596, 14.957866532461983, 14.394635132380895, 28.62137746810913, 51.48355640683855, 65.37095914568219, 69.98708520616803, 69.83982508523124, 68.50891154153007, 72.71205752236503, 62.36988626207624, 43.975364276341026, 44.9588748386928, 58.22438601085118, 73.68985666547502, 75.9187206540789, 33.506398814065115, 1.249077986393656, 0.13953274701322826, 0.10097611416131258, 0.07433762321514742, 0.09082513528742961, 0.035702205662216456, 0.05783084753368582, 0.03582712395914963, 0.06260437531662838, 0.13083533942699432, 0.11021221069885151, 0.08126895342554365, 0.01983108837157488, 0.05189928099779146, 0.07241061768893685, 0.04889220378494688, 0.035192591936460564, 0.048183660555098734, 0.0729758780715721, 0.05609833389254553, 0.09144556056708097, 0.051185876064534695, 0.0450060233872916, 0.045055118788565905, 0.0629086439896907, 0.07125134060957602, 0.036595062751855166, 0.12152313840176378, 0.055061695232455216, 0.030667072095509087, 0.05197194870561361, 0.026451649543430125, 0.07779800253255026, 0.052759056112595966, 0.051182788730199845, 0.01819007857037442, 0.09333573521247931, 0.06010147676404033, 0.08676085301807948, 0.2049661451684577, 0.1638724630964654, 0.1881419236638716, 0.20850855936961515, 0.24924415137086595, 0.19310718508703367, 0.08606597209083182, 0.2666055554790156, 0.20583750626870564, 0.07132082259548561, 0.144065116665193, 0.16052674262651376, 0.22057869311954292, 0.110773840919137, 0.19128993260008947, 0.1828548059399639, 0.2450433410704136, 0.2799810548978192, 0.20883990158992155, 0.13936622094895157, 0.09202884283981153, 0.2877246322376387, 0.13268092753631727, 0.11501420981117658, 0.1976261604577303, 0.1877143651779209, 0.20658170990645885, 0.17240375173943384, 0.14538904705217906, 0.07639899224575077, 0.19130154911960873, 0.13504399359226227, 0.10924299127821412, 0.09633701095091445, 0.07329960712896925, 0.21279991338295595, 0.16713662365717546, 0.2130702824464866, 0.1267923428011792, 0.3343408836850098, 8.101118394306727, 91.83785656520298, 145.80015155247278, 99.64094761439732, 84.64194774627686, 76.33140196119035, 58.027998651777, 77.76065335954938, 108.68441023145402, 112.84087126595634, 109.2441154207502, 93.60841737474713, 92.02663217272077, 84.46093327658517, 88.56680447714669, 75.58146204267229, 74.97259834834507, 77.66474737439836, 66.38683441707066, 66.97037192753383, 52.684840883527485, 29.639052322932653, 24.0721504007067, 17.02308828490121, 17.954761811665126, 19.55737771306719, 8.709479212760925, 3.1994923736367906, 1.9721150227955409, 0.7111685361180986, 0.5321029275655746, 0.2072487234004906, 0.5023737571069172, 0.10496855314288821, 0.2007102785365922, 0.18297715937452658, 0.23023947115455354, 0.19971184139805181, 0.27446117252111435, 0.18680271266826562, 0.2556946580963475, 0.1729564592242241, 0.15986932361764566, 0.10241466946899891, 0.16397262843591826, 0.08711854953851018, 0.12241641618311405, 0.1254955538149391, 0.16155551028038773, 1.1712932288646698, 1.981427128825869, 0.21051553024777345, 0.2728026700871331, 0.10618958369429622, 0.15852790059787886, 0.2605331556073257, 0.30789362426315037, 0.13125350698828697, 0.1626789199986628, 0.11613751096384865, 0.29231636013303486, 0.24000646706138337, 0.142978822812438, 0.12133379999016013, 0.14284234227878706, 0.10932071746460029, 0.09092688839882612, 0.32353825334991726, 0.6237490155867168, 0.12907008986387933, 1.7701845211642129, 0.47894757986068726, 0.3272161845649992, 2.120232594864709, 4.179657161235809, 5.0111967240061075, 8.366722839219229, 11.85356513091496, 12.997278571128845, 19.613440990447998, 20.252119404929026, 13.20904837335859, 27.090461765016826, 53.11728286743164, 75.99928501674107, 79.17712007250104, 76.99831785474504, 77.97403253827775, 79.78577532087053, 64.29958861214774, 52.172421659742085, 49.62413855961391, 65.47603675297329, 78.71457154410226, 96.22712394169399, 83.89452307564872, 21.377135242734635, 0.341321516249861, 0.21565623368535722, 0.1810682096651622, 0.1747217902115413, 0.1730494185217789, 0.0698210159316659, 0.08727225129093442, 0.20216178707778454, 0.19578281151396887, 0.2849171800272805, 0.19607074106378214, 0.08437761411603008, 0.17555237135716847, 0.0777399470763547, 0.12256805518908159, 0.12818015047482081, 0.1559901660574334, 0.1864781557981457, 0.17106080880122526, 0.1427546619836773, 0.15468074274914606, 0.09517989161291293, 0.10676752589643002, 0.12456768431833812, 0.2697337647633893, 0.14709223780248845, 0.13941865813519272, 0.22208755144051143, 0.12984322623482772, 0.1357872744223901, 0.1260304701115404, 0.11908946399177824, 0.19541584620518343, 0.12233058150325503, 0.14331871457397938, 0.10073957685381174, 0.18191394928310597, 0.1989141556301287], [0.02072039163405342, 0.11636650296194212, 0.03527637404788818, 0.07910817901470832, 0.04616176190653017, 0.10089097837252275, 0.029411578750503913, 0.06974659421082054, 0.07964103256485291, 0.01607409255978252, 0.04010589114789452, 0.054040896972375255, 0.048726295187537155, 0.019537669473460743, 0.053912206020738394, 0.042244002489106994, 0.07326145989022084, 0.068600826763681, 0.06665142279650484, 0.0755537004609193, 0.014294446179909366, 0.07513078315449612, 0.11277416215411254, 0.04251181686829243, 0.045155932128961594, 0.056499972340783904, 0.018291841859796217, 0.02381731027604214, 0.08099234862519161, 0.09169541751699788, 0.016035524629322544, 0.027885438142610446, 0.053719179771308384, 0.0439109933961715, 0.040719205380550454, 0.011691216046788862, 0.04230914185089724, 0.037854718909199746, 0.05573895799794367, 0.0883085574688656, 0.09609601566834108, 0.1202538436544793, 0.09046158300978796, 25.414566687175206, 103.11180210113525, 103.83909089224679, 86.17491490500313, 75.17713247026715, 46.10433748790196, 34.132292543138774, 54.06049735205514, 78.36111668178013, 88.22229194641113, 72.85975537981305, 68.1204308101109, 62.78159482138497, 80.05401747567313, 85.9525169645037, 74.16283443995884, 66.1808203288487, 52.482644830431255, 46.77308075768607, 39.69228274481637, 37.0719780921936, 25.753913232258387, 14.170435871396746, 6.6024084602083475, 5.033939046519143, 1.9698707546506609, 0.6110896691679955, 0.15984463851366723, 0.1807779459548848, 0.2666575312614441, 0.6666262405259269, 0.6201751987848962, 0.38276768369334085, 0.0838646280712315, 0.062194472311862876, 0.04311131952064378, 0.05263514883284058, 0.1078801808346595, 0.042637410307569165, 0.032583499260778935, 0.03457656017105494, 0.048194571398198605, 0.07643540243485145, 0.0483683747505503, 0.0802175701994981, 0.045926445962062905, 0.025517948038343872, 0.6435420449290956, 0.9042012180600847, 0.1249025956328426, 0.06240579525807074, 0.05277335623811398, 0.057948220521211624, 0.060178694049162526, 0.00415613894749965, 0.06380601333720343, 0.024325024103745818, 0.061696922938738546, 0.09443405270576477, 0.04078478918277791, 0.08145338602896247, 0.06968638779861586, 0.1280789944742407, 0.07245179119386844, 0.34976178620542797, 0.31703064111726625, 0.12588244091187203, 0.46018413241420475, 0.47485020543847767, 2.267468831368855, 0.5460837887866157, 0.5606644206813404, 2.2559871503285, 1.7983809624399458, 3.0139802481446947, 5.075860568455287, 3.56828972697258, 6.522103352206094, 9.712396962302071, 9.628403663635254, 8.223358052117483, 22.733461822782242, 30.88094207218715, 38.703640937805176, 43.072602203914094, 32.06962946483067, 22.56980221612113, 34.95356266839163, 42.17792088644845, 62.83578382219587, 73.73017011369977, 68.09242956978935, 25.09160225731986, 1.3624455545629774, 0.12534889525600842, 0.23961715080908366, 0.0471561210496085, 0.025953134954241768, 0.1350321328001363, 0.07426442964268581, 0.014176613484908427, 0.02610820734740368, 0.051356714218854904, 0.08967389884803977, 0.037373464554548264, 0.025941358978993127, 0.06257031285869223, 0.04712794827563422, 0.04619924078828522, 0.056318355657692463, 0.10012504804347243, 0.04289138935772436, 0.1003105052347694, 0.07135905125843627, 0.023124714315469776, 0.07239033627722945, 0.0031474890087598135, 0.09871143568307161, 0.039499229951096435, 0.07005469660673823, 0.08446033432015351, 0.027779953088611364, 0.0770746570612703, 0.05551568265738232, 0.03897215412663562, 0.01678157557866403, 0.026878816175407598, 0.04571548942476511, 0.03764494641550949, 0.0768185236624309, 0.041816593280860355, 0.13026631996035576, 0.1316209744129862, 0.14743948488363198, 0.18632514615144047, 0.0816337474222694, 0.05097263964957424, 0.09260891564190388, 0.01655524004516857, 0.023312081582844257, 0.09275267685630492, 0.07150849859629359, 0.03429960592516831, 0.13021548411675862, 0.07771518054817404, 0.08782707580498286, 0.08979509198772055, 0.04192620382777282, 0.0666379878031356, 0.1291759277560881, 0.07867469013269458, 0.12484896422496863, 0.013094839523546398, 0.07623393860246454, 0.08017556209649358, 0.08111738227307796, 0.07541295194200107, 0.08207633545888321, 0.08479521849325725, 0.016274167091718743, 0.03482499559010778, 0.07409925386309624, 0.044452549157930274, 0.0479603241463857, 0.026100690875734602, 0.02241512614169291, 0.06507549807429314, 0.018307407453124012, 0.044806062509971004, 0.012456360971555114, 0.09538866326745067, 0.09922320036483662, 0.09229856729507446, 0.10318545810878277, 0.44811101311019486, 2.6963183794702803, 72.09199333190918, 108.30483014242989, 95.71981511797223, 70.31143406459263, 62.56513064248221, 66.13552502223423, 75.52263164520264, 83.38914585113525, 93.58192389351981, 88.46013573237828, 83.44839314052037, 75.9120225906372, 75.33764975411552, 81.4158296585083, 84.27477713993618, 82.30250317709786, 70.33667687007359, 67.26477405003139, 56.181664262499126, 39.54004771368844, 33.983548981802805, 21.10415267944336, 13.370997854641505, 10.415980236870901, 3.543808617762157, 1.8757348230906894, 0.5121833107301167, 0.17974659986793995, 0.3186033224420888, 0.24927609679954393, 0.02463907385910196, 0.223731913204704, 0.20053646500621522, 0.15763592560376438, 0.16393308341503143, 0.10798183895115342, 0.04747794342360326, 0.028203752490558794, 0.08604264405689069, 0.026083579918901836, 0.05588163694898997, 0.07072287718100206, 0.08530490007251501, 0.05332232499495149, 0.09003190749457904, 0.01823571853206626, 0.0665612251364759, 0.30923739501408165, 1.9369868849005019, 0.17396622789757593, 0.0679385019466281, 0.0193713673257402, 0.030999303196689913, 0.039509872772863934, 0.011812320976917232, 0.04896256108103054, 0.14561807976237365, 0.13484975615782396, 0.2143187868807997, 0.0178109539140548, 0.1588092076459101, 0.038539435381868055, 0.09593506716191769, 0.04871973375390683, 0.0600650462188891, 0.08515504561364651, 0.15093402165387357, 0.16598227274205002, 0.19637536257505417, 0.9946276800973075, 0.8081044288618224, 1.2083078026771545, 2.2747340415205275, 2.674296064036233, 6.040745181696756, 7.503717490604945, 9.695610983031136, 13.645741786275591, 13.116508790424891, 13.512106214250837, 29.463012763432094, 49.63886179242815, 60.75960649762835, 65.07670293535504, 62.00682898930141, 58.030962058476035, 55.70598016466413, 48.47850915363857, 44.30504240308489, 53.6096704346793, 73.91263675689697, 79.87290573120117, 50.59580591746739, 9.045497570719037, 0.7694694048592022, 0.24483972628201756, 0.20881839202983038, 0.04381167622549193, 0.06915234002683844, 0.038134302478283644, 0.049929816142788956, 0.027484232260446464, 0.06400531942823104, 0.06667245059673275, 0.06462489653910909, 0.016350680396759083, 0.012608374019951692, 0.054817354772239923, 0.013225544027851095, 0.06051557990057128, 0.07267610130033322, 0.04928243945219687, 0.0677071622173701, 0.02265767696579652, 0.03039545113486903, 0.07693010196089745, 0.03227010429171579, 0.07922021871698753, 0.023443659700985466, 0.05270106850990227, 0.0651095537468791, 0.022568846553830162, 0.04566204122134617, 0.021278239021609937, 0.016957806390044943, 0.08884932273732764, 0.02625196686546717, 0.11109208741358348, 0.11341654482696738, 0.1159750289682831, 0.03164658149970429, 0.024745917679475884, 0.09904340894094535, 0.20094651728868484, 0.29045652278832024, 0.3469722473195621, 0.22075807063707284, 0.15830867950405392, 0.21696716334138597, 0.17305479251912662, 0.12124515617532389, 0.17574291756110533, 0.20082721726170608, 0.37844921542065485, 0.2258631916982787, 0.21099065403853143, 0.23421229368874005, 0.18422185044203485, 0.19059512631169387, 0.2351166180201939, 0.1910337313477482, 0.23880706142101968, 0.15029324032366276, 0.15536972720708164, 0.18023697712591716, 0.18816671733345303, 0.10334018444908516, 0.11605513681258474, 0.12936593113201006, 0.10434707613395793, 0.11444677811648164, 0.17419105369065488, 0.3270130311804158, 0.10298656592411654, 0.09702771888779742, 0.16559771980558122, 0.2336137443780899, 0.11643662277076926, 0.11987427116504737, 0.13904587099594728, 0.1712048617856843, 0.2302614828305585, 0.15131242706307343, 0.13579552540821688, 0.08324701192655734, 0.28798613963382586, 45.98528010504586, 137.2364273071289, 129.06674930027552, 101.81685243334088, 95.91339193071637, 74.33182157788957, 59.35725852421352, 72.76509312220982, 96.89535999298096, 106.4711171558925, 95.17358943394252, 87.51663289751325, 83.63073471614292, 100.7506583077567, 103.94447422027588, 93.81738444737026, 85.43965653010777, 78.20121083940778, 75.79624475751604, 62.32527187892369, 56.3500851222447, 43.89515079770769, 36.658181599208284, 23.723274401256017, 10.76701191493443, 3.603577673435211, 1.313017372574125, 0.34029586985707283, 0.7095640450716019, 0.3758255647761481, 1.4790424065930503, 0.8322390509503228, 0.4223055121089731, 0.2091064572866474, 0.24909313661711557, 0.20896164434296743, 0.16499636135995388, 0.19852536863514356, 0.1800789734614747, 0.1269082094409636, 0.1457307572875704, 0.14344638772308826, 0.16784801334142685, 0.23474008536764554, 0.1711374968290329, 0.09985324727105242, 0.16872351350528852, 0.8254722654819489, 2.194478222302028, 0.31596748530864716, 0.1553333034472806, 0.2540678025356361, 0.13765633984335832, 0.11637526963438306, 0.11929253595215933, 0.09010871765869004, 0.3081895469554833, 0.21909031298543724, 0.30533125890152796, 0.17113957314618997, 0.24642831246767724, 0.17341350684208529, 0.2600459131811346, 0.12206908767776829, 0.5222183551107134, 0.5135188847780228, 0.315738031906741, 0.9467958467347282, 1.840915662901742, 6.7486636979239325, 0.6333013772964478, 2.5472076492650166, 4.70070127078465, 7.429837294987269, 11.72591803755079, 15.022153002875191, 14.298645768846784, 17.42916532925197, 18.325922421046666, 24.65350443976266, 45.30252231870379, 64.08700847625732, 62.63645390101841, 70.56014483315604, 70.10291167667934, 55.800583362579346, 45.84735836301531, 53.89951801300049, 62.622647830418174, 78.71739251273019, 94.30041626521519, 93.2125437600272, 39.264242444719585, 3.262747470821653, 0.6831151843070984, 0.2757322314594473, 0.19120008099292005, 0.12414917748953615, 0.24997140520385333, 0.3293043353727886, 0.13464900478720665, 0.13754648502383912, 0.1536090781113931, 0.20206535368093423, 0.22196268742637976, 0.09881126854036536, 0.20968211282576832, 0.19157111751181738, 0.14600495328860624, 0.16106140107980796, 0.1524014486266034, 0.13806844130158424, 0.14605288500232355, 0.16787009287093366, 0.09069724500711475, 0.1958299968391657, 0.2538355807108538, 0.1295556223818234, 0.2717222252062389, 0.13418396402682575, 0.18270128060664448, 0.1124912401927369, 0.128877779468894, 0.1308162725929703, 0.1725060883909464, 0.20333543552884034, 0.09328355586954526, 0.23614079877734184, 0.20630078283803804, 0.21421137478734764, 0.1671160776168108, 0.2740692235529423, 0.22642273881605693], [0.11971918520118509, 0.09031775394188506, 0.08592132199555635, 0.0455488208681345, 0.06486662463950259, 0.04239204525947571, 0.07094384889517512, 0.03894099919125438, 0.030585488437541893, 0.02129965867581112, 0.06399050700877394, 0.09365219037447657, 0.07701728014009339, 0.10350485132741076, 0.0741555994110448, 0.05355176482615726, 0.03902954801118799, 0.06211169103958777, 0.06966344652963535, 0.035554997489920685, 0.032409275216715674, 0.058078051411679814, 0.01426667204525854, 0.04593741787331445, 0.08417301545185701, 0.029937124478497674, 0.05221201778788652, 0.029893328435719013, 0.04297225037589669, 0.03462132991158536, 0.040542884663279564, 0.018484466077227677, 0.023255605416904603, 0.015039363975769706, 0.08747730457356998, 0.03784609133643763, 0.054471865096794705, 0.02440303866751492, 0.06464690142976386, 0.040498701855540276, 0.1428591970886503, 0.09073578579617397, 0.022489703925592557, 0.28641413684402195, 3.2458155793803076, 44.26343658992222, 102.99319635118756, 93.6374955858503, 68.73182364872524, 58.411247389657156, 46.555748053959434, 26.91938148226057, 47.42211546216692, 61.40719250270298, 79.17434774126325, 87.84943771362305, 77.76985277448381, 75.17873750414167, 65.4696444102696, 53.03195898873465, 49.84831871305193, 48.98642247063773, 38.70004524503435, 37.28427335194179, 21.172668865748815, 5.495400181838444, 3.4856984445026944, 4.31357022694179, 2.8222299431051527, 1.0824183864252908, 0.1415178690637861, 0.060022610638822825, 0.587535981621061, 0.9922752806118557, 1.252933150955609, 1.3069859019347598, 0.20254532221172536, 0.0403004882058927, 0.031852126720228364, 0.04185463534668088, 0.12051900156906672, 0.07939467685563223, 0.04825891008866685, 0.08625146320887975, 0.035421502510351796, 0.06656568989689861, 0.05580711344789181, 0.015165279719180294, 0.047550695948302746, 0.07562415953725576, 0.18725199784551347, 1.8989554856504713, 0.23901944288185664, 0.07501805813184806, 0.08992125200373785, 0.057098219703350744, 0.03896279712872846, 0.042367587464728525, 0.041109821027410884, 0.11227901479495422, 0.04093817202374339, 0.057221821642347744, 0.015837955587942685, 0.0465336058820997, 0.02395497485330062, 0.08984914408730608, 0.07169224587934357, 0.3385842245604311, 0.24677222115652903, 0.21186721271702222, 0.8419786340423993, 1.8092962567295348, 0.4586574286222458, 0.6419025957584381, 1.7745220427002226, 1.4757593827588218, 0.6241728014179638, 3.7459905573299954, 7.6660517283848355, 7.151011296680995, 4.302118727139064, 2.9940132967063358, 4.88767295224326, 17.034459011895315, 25.795977626528057, 33.37620346886771, 22.518173626491002, 17.57743293898446, 27.42893283707755, 48.62715891429356, 59.60519804273333, 65.29184695652553, 60.50450338636126, 29.197747911725724, 3.7570295078413825, 0.06835365681243794, 0.09332327730953693, 0.24423409306577273, 0.03452571414943252, 0.1480400562286377, 0.11331186722964048, 0.013048381927157087, 0.021325695760814205, 0.02262136516427355, 0.038573148394269605, 0.03851031265886767, 0.0345786907710135, 0.02636903790490968, 0.0020058977326178657, 0.006919320988734918, 0.15691905335656234, 0.054626411625317166, 0.009582314789960427, 0.05778936868799584, 0.043275765875088315, 0.02758638740384153, 0.019060372674305524, 0.06246265649263348, 0.017380401392334273, 0.028609007530446564, 0.059451636991330555, 0.1525192694472415, 0.06702144151287419, 0.056017337167369466, 0.06476132957530872, 0.022438657736139636, 0.079797821651612, 0.022295566575069512, 0.1075734965769308, 0.0690619388063039, 0.0892892237752676, 0.07126750331372023, 0.042885129872177324, 0.17056010424026422, 0.044716940327946625, 0.13447002081998757, 0.03831257398373314, 0.07457483227231673, 0.10968220699578524, 0.08925624697336129, 0.08180225480880056, 0.023574981672157134, 0.009344160872777658, 0.08862572509263243, 0.07592167678688254, 0.06869447138160467, 0.11604930141142436, 0.10143151293907847, 0.06949091543044363, 0.03769276277827365, 0.02785960292177541, 0.0737635622333203, 0.0218289092050067, 0.11356379371136427, 0.08111851542655911, 0.062060373436127386, 0.067420949361154, 0.04288781687085118, 0.02888824843934604, 0.04816441730196987, 0.026942751137539744, 0.011861624179541, 0.04877338551783136, 0.026280828352485384, 0.024637428411681737, 0.025577913570616926, 0.07674776603068624, 0.045516726161752424, 0.006561089697892645, 0.008856742875650525, 0.028596953355840275, 0.03682356620473521, 0.10535605770668813, 0.11146294751337596, 0.10722747085882084, 0.03294643407155361, 0.04202143282496503, 0.04566807000498686, 0.05536199447565845, 3.3276169385228838, 25.813513142721995, 86.21652071816581, 113.04748984745571, 95.14467103140694, 64.98098455156598, 53.085567814963206, 65.32726192474365, 67.62706007276262, 81.4146762575422, 77.35120296478271, 79.71657821110317, 80.81470625741142, 86.03883443559918, 83.63047068459647, 79.27586092267717, 78.8395904813494, 70.78281375340053, 68.55025332314628, 63.30560711451939, 53.09930787767683, 38.58237055369786, 18.833575180598668, 8.521766679627554, 6.405702352523804, 3.842334713254656, 1.830341373171125, 0.6398439205118588, 0.10548206165965114, 0.6523150141750063, 0.7979473024606705, 0.7129600314157349, 0.7240452308739934, 0.17002161884946482, 0.24096206149884633, 0.09907380052443061, 0.06932483041392905, 0.15066032776875155, 0.02984976988019688, 0.010244352077799184, 0.044692662344979386, 0.03819719249648707, 0.09041827211954764, 0.031062658011381115, 0.03109743632376194, 0.06226221724812474, 0.08719901022102151, 0.1906440622572388, 3.101468707833971, 0.7573383386645998, 0.06326311746878283, 0.10421421897730657, 0.12288787588477135, 0.12916910169380053, 0.17050863057374954, 0.041494954111320634, 0.11253640348357813, 0.02963063699592437, 0.04774424806237221, 0.08875844654228006, 0.030999608537448303, 0.041157450793044906, 0.035778099804052284, 0.14158756818090165, 0.07979945692100696, 0.7589315388883863, 0.9375173960413251, 0.1278243131403412, 1.0625827993665422, 0.7742755498204912, 1.0901724674871989, 1.5260262340307236, 3.468105605670384, 3.3404776198523383, 6.584275833198002, 11.989965217454092, 10.343573927879333, 9.213776860918317, 16.335751635687693, 29.774191311427526, 39.75627217973982, 46.90666682379586, 47.81352138519287, 45.956507614680696, 48.419987951006206, 46.51853002820696, 45.2314943586077, 57.07891641344343, 68.7070255279541, 79.52543326786586, 57.84316267286028, 17.556831530162267, 0.5603292243821281, 0.18791840065802845, 0.1404595851366009, 0.10822451700057302, 0.053450561328125853, 0.11942270611013685, 0.047262108219521384, 0.11233390827796289, 0.08272458067429916, 0.030068587245685712, 0.0364950432974313, 0.09094526991248131, 0.04018749176923718, 0.03579926670395902, 0.0444594634297703, 0.16200958591486725, 0.07105665534202542, 0.045746868276702504, 0.024290184723213315, 0.07179473859391042, 0.05170629546046257, 0.07659159441079412, 0.09459595116121428, 0.0313564534964306, 0.11637142912617751, 0.03959797715236034, 0.08369838699166264, 0.051607789139130285, 0.06615722538637263, 0.03865506453439593, 0.031000551701124226, 0.0654273388375129, 0.03730147198906966, 0.07535987014749221, 0.04834942326747945, 0.06965870356985501, 0.04862302215769887, 0.017825265913935642, 0.042253244136060984, 0.09721251111477613, 0.0886592243665031, 0.28358697997672216, 0.20024609273033483, 0.17275007601295198, 0.3036899912570204, 0.26408004813960617, 0.11815343850425311, 0.17022573575377464, 0.20420390606990882, 0.16725588297205313, 0.14013413260025637, 0.2145211531647614, 0.30144447460770607, 0.2042084793959345, 0.21463769833956445, 0.2973637378641537, 0.14447896874376706, 0.22564737685024738, 0.24788767844438553, 0.19306546875408717, 0.16088965029588767, 0.12535831332206726, 0.13804835666503223, 0.08268614166549274, 0.1765552054026297, 0.21472463224615368, 0.08328913538051502, 0.11687619132655007, 0.07388175624821867, 0.10593524841325623, 0.13325099194688456, 0.1595285769019808, 0.10829626529344491, 0.17362693324685097, 0.179905024224094, 0.1693221985229424, 0.07600191355283771, 0.20476848791752542, 0.16896589978465013, 0.18396054660635336, 0.0979023708828858, 0.23011698201298714, 0.10029305331408978, 0.09065519619200911, 0.6887823630656514, 7.8026993444987705, 72.77359771728516, 144.15948731558663, 119.64463070460728, 86.54470498221261, 79.82295513153076, 69.08735602242606, 47.84378426415579, 67.10807132720947, 79.80407687595913, 96.0600197655814, 102.61413737705776, 98.16508769989014, 93.28020531790597, 88.11162798745292, 82.99851812635148, 80.14923558916364, 95.51179300035749, 87.82576520102364, 76.2980089187622, 61.90778241838728, 42.34631742749895, 19.490369285855973, 9.390534690448217, 6.665950170585087, 3.731764989239829, 1.1945405985627855, 0.13131815780486378, 0.8555094365562711, 1.789595833846501, 1.9449781818049294, 1.6706890314817429, 1.0433994744505202, 0.6175446542246001, 0.24587924193058694, 0.16619202148701462, 0.30066711774894167, 0.19723841840667383, 0.18114887390817913, 0.2573443938578878, 0.11833912639745645, 0.21950994618237019, 0.1454334096716983, 0.11674276420048305, 0.20690861450774328, 0.2561861617224557, 0.40683760068246294, 3.8579364589282443, 0.4906073084899357, 0.14552364125847816, 0.14872046400393757, 0.17788934095629624, 0.23235386769686425, 0.22619758732616901, 0.0721572662836739, 0.22148742792861803, 0.06930180772074632, 0.2073811734361308, 0.12905231224639074, 0.12231984707926001, 0.1703861414321831, 0.12881957473499434, 0.28488775874887196, 0.7264439878719193, 1.0721245216471809, 2.4937996694019864, 3.470343359879085, 3.1919110204492296, 2.2708050523485457, 1.8051971452576774, 7.612605316298349, 11.706953798021589, 20.353827135903494, 18.04512139729091, 20.77096744946071, 27.24258736201695, 30.66155617577689, 35.29932934897286, 42.66720608302525, 55.69822597503662, 62.14932264600481, 63.89955302647182, 43.24912118911743, 43.221210275377544, 52.592648710523335, 66.96828746795654, 77.26221738542829, 89.34590598515102, 88.69133009229387, 50.52316944939749, 7.3522676059177945, 0.24701586951102528, 0.24833171176058905, 0.32600654661655426, 0.14601393709225313, 0.18323672616056033, 0.27247876461063114, 0.14857316762208939, 0.12727989735347883, 0.17336438090673514, 0.22429397090205125, 0.13518909152065003, 0.1507707525576864, 0.20638447334723814, 0.09615122806280851, 0.06016006147755044, 0.2701190098055771, 0.1505277148847069, 0.16429433545895986, 0.19069864361413888, 0.25066671360816273, 0.15965530010206358, 0.15956950613430568, 0.15517322346568108, 0.16120785607823304, 0.11870659382215568, 0.18236617930233479, 0.28601323121360367, 0.16712929547897407, 0.21532893553376198, 0.24587031240974153, 0.12377857523305075, 0.18161338541124547, 0.17515236139297485, 0.16630712816757814, 0.1404096856713295, 0.16302462001996382, 0.22282537684908935, 0.1313440099890743, 0.25797743988888605, 0.2766306389655386, 0.18529335223138332], [0.10000257925795657, 0.02075017592869699, 0.052203342717673094, 0.052373271635068316, 0.0532479168448065, 0.027164662622713616, 0.0402554029465786, 0.08161162718066148, 0.0736142573878169, 0.04890696531427758, 0.12463001454515116, 0.05311119882389903, 0.05100335692986846, 0.058726459475500245, 0.07087995803781919, 0.04700958801965628, 0.012915851315483451, 0.04797750465305788, 0.04316290175276143, 0.06894791099642004, 0.08628085734588758, 0.03677969891577959, 0.018823121208697557, 0.030441279390028546, 0.01658483943901956, 0.057907026660229476, 0.03225235042295285, 0.08847677308533873, 0.1452431891645704, 0.014235267748257943, 0.042526357873742066, 0.047511371451296976, 0.008470187412707933, 0.08908408906842981, 0.046638551500758955, 0.031257540054087124, 0.009448170961279954, 0.04505031815330897, 0.044060963205993176, 0.06482205845947776, 0.04561650473624468, 0.06909573663558279, 0.12531312288982527, 0.11698743035750729, 0.2723380907305649, 0.23368819324033602, 9.01663909639631, 58.78601237705776, 101.2994965144566, 92.85665702819824, 82.67048672267369, 63.612502098083496, 51.329883098602295, 44.861568791525706, 38.203596455710276, 44.77329192842756, 54.56772627149309, 58.16239070892334, 54.99564150401524, 45.34689351490566, 36.30670697348458, 35.80812161309378, 37.450658389500205, 23.08136854852949, 10.932264396122523, 10.172917485237122, 8.786644169262477, 2.5174109510013034, 3.9828494361468723, 2.564673683473042, 1.3105338258402688, 0.7401345989533833, 0.6895488905055183, 1.576729301895414, 1.5272305522646223, 3.4379423899309973, 3.035759376628058, 0.5901613693152155, 0.3399467228778771, 0.2153761072882584, 0.0268222365328776, 0.11674766322331769, 0.04887940661449518, 0.09435716790280171, 0.04302496915417058, 0.06780949886888266, 0.02095775505793946, 0.021511538020734276, 0.02570218556294484, 0.22651594238621847, 0.09922761084245783, 2.8176599826131548, 0.458806109215532, 0.052152985241264105, 0.2152084819972515, 0.13295468927494117, 0.04695056225838406, 0.008679879330364721, 0.04587660077959299, 0.11532317394656794, 0.0985793045588902, 0.20590944455138274, 0.01214520092720964, 0.12153343856334686, 0.02272221412775772, 0.2571571453341416, 0.3978376750435148, 0.677907400897571, 1.1240542722599847, 0.9442287044865745, 1.485556994165693, 1.4656690784863062, 0.9707141518592834, 1.4774800390005112, 2.8612616658210754, 1.09200852896486, 3.3003228945391516, 4.848198064735957, 2.326691367796489, 0.6856182728494916, 4.74720686674118, 11.063356927462987, 15.887969766344343, 17.607668025153025, 18.935967309134348, 12.036542466708593, 21.259972981044225, 42.489113330841064, 51.60270759037563, 59.370140484401155, 66.35302448272705, 36.03286109651838, 5.032937637397221, 0.14873788878321648, 0.15838432258793286, 0.20975504176957266, 0.07537722707326923, 0.0222802113275975, 0.0768922668482576, 0.019043268502822945, 0.039765215678406615, 0.032155452229614766, 0.03800264632861529, 0.05834322289696761, 0.03981081323165979, 0.012395429375049258, 0.006400247636650289, 0.03484742117247411, 0.03667184238189033, 0.0367566490811961, 0.08055544671203409, 0.05752231766070638, 0.11597517824598721, 0.02423168482658054, 0.001659254971725334, 0.04390779410355857, 0.039685894934726615, 0.030308581689106565, 0.13049156644514628, 0.016362951702571342, 0.09295922970133168, 0.04889742850459047, 0.0697868720495275, 0.039826422929763794, 0.031046396919659207, 0.03670933822702084, 0.02614708910030978, 0.0029556718239161584, 0.03484973158421261, 0.024581893713080456, 0.02664467748919768, 0.04356739004807813, 0.030799895325409513, 0.10158636141568422, 0.002070582263903426, 0.03186002826052053, 0.015161303503971015, 0.022715890181383917, 0.08604823518544436, 0.19453752333564417, 0.1560076858316149, 0.03365136070975235, 0.03178260402221765, 0.07758234374757324, 0.031875956870083294, 0.0563813406707985, 0.04529486895938005, 0.009914503482702588, 0.11516261899045535, 0.11460313972617898, 0.09549483364181859, 0.031630890377398045, 0.07331617016877447, 0.023004303187397972, 0.01218960849967386, 0.07103174632149083, 0.1317220897014652, 0.09560032548116786, 0.04160281064520989, 0.033851070529116054, 0.04502342102516975, 0.14613531343638897, 0.03770335131723966, 0.044657280136431964, 0.09402521500097853, 0.060839329314018996, 0.033902425452002456, 0.07246429659426212, 0.02553288429044187, 0.04382054467818566, 0.049860371476305385, 0.03303326619789004, 0.008520900271832943, 0.06854345662785427, 0.0704054788553289, 0.034165730965988975, 0.11150982749781438, 0.1022475462939058, 0.04416847029434783, 0.21420722215303353, 0.911867795245988, 3.8482845425605774, 43.24136699948992, 96.0731657573155, 104.02125181470598, 81.63760920933315, 68.77266516004289, 49.99704837799072, 60.4349936076573, 71.79989801134381, 77.79544298989433, 85.49116352626255, 79.67628560747418, 81.50003487723214, 73.27862753186906, 66.85070310320172, 67.86662701198033, 71.2940205165318, 64.16727406638009, 50.41672304698399, 33.974123750414165, 11.968827060290746, 9.346931270190648, 8.716892940657479, 6.375312668936593, 2.837746790477208, 0.7761978666697229, 1.716797711593764, 0.760923826268741, 0.7752662652305194, 1.8081108289105552, 2.001865472112383, 0.5731162982327598, 0.6786262137549264, 0.7130822220018932, 0.5289366660373551, 0.11485574474292141, 0.026338105189747045, 0.06623930098222834, 0.0723355852865747, 0.0640197450827275, 0.1214458668338401, 0.09711058836962495, 0.11745781797383513, 0.011736016321395124, 0.1816972116274493, 0.03868361728798066, 1.6312591986996787, 1.0405181433473314, 0.1208645116005625, 0.07301542987780911, 0.05373861301424248, 0.01685538831433015, 0.04127747345981853, 0.03697912375043545, 0.07731264643371105, 0.18264550502811158, 0.2528318917112691, 0.12099396251142025, 0.07102483883500099, 0.02807423033352409, 0.25489165261387825, 0.27811307513288086, 0.4749158333454813, 0.7311710970742362, 0.8960158601403236, 1.7868902704545429, 2.418444935764585, 1.7770930933100837, 4.545699988092695, 3.458491470132555, 2.653821894100734, 6.713028992925372, 7.1164348891803195, 9.086095026561193, 13.374815021242414, 16.072805745261057, 17.114184379577637, 20.417481320244924, 29.87945999417986, 40.62943492616926, 42.11367436817714, 38.44412224633353, 40.71899373190743, 50.48484318596976, 66.2990300314767, 78.0457101549421, 64.9991818836757, 21.88918968609401, 1.7725031567471368, 0.18655352746801718, 0.16711910388299397, 0.055639216742877445, 0.05376151357112186, 0.029675260851425782, 0.08052344700055462, 0.07482979859092406, 0.06844230741262436, 0.051917794825775285, 0.03808653700564589, 0.05118520092219114, 0.039430816657841206, 0.020255069281639795, 0.013903490417370839, 0.06884995089577776, 0.028675707522779703, 0.10041934225176062, 0.06003319578511374, 0.028994361138237373, 0.026955717941746116, 0.1359312052705458, 0.09023415842758757, 0.021990349649318626, 0.04091983800753951, 0.05274587556985872, 0.10861418609108243, 0.06849040876009635, 0.09771442346807037, 0.06483796332031488, 0.027054661918165426, 0.09429415914097003, 0.05235379428735801, 0.029937555348234515, 0.0805766237899661, 0.029669130287532295, 0.025486796495637724, 0.05222310505009123, 0.04705681066427912, 0.04838789959571191, 0.05110091330217464, 0.058987654745578766, 0.09778131345020873, 0.21839223615825176, 0.24798826447554997, 0.21916104347578116, 0.269770758492606, 0.20686066922332558, 0.15911579690873623, 0.13929983308272703, 0.22470141761004925, 0.21471841686538287, 0.2029313272131341, 0.2755776068993977, 0.20234078461570398, 0.2078920424516712, 0.2710926261331354, 0.2812837335680212, 0.13618446168090614, 0.10173822433820792, 0.11069595188434635, 0.214057075924107, 0.21173677114503725, 0.19168276366378578, 0.1642143904630627, 0.1261145541710513, 0.0816152776990618, 0.08433745841362647, 0.19620357107903275, 0.18298992940357753, 0.2254407765077693, 0.2619118301996163, 0.12853487501186983, 0.20685868790107115, 0.18714502001447336, 0.10083369644624846, 0.16227155471486704, 0.21721438079008035, 0.14232346655002662, 0.13041210999446257, 0.14123566634953022, 0.09337361103722028, 0.13410734385252, 0.18340729629354818, 0.22562168751444134, 0.15079532909606183, 0.3522491870181901, 0.5848329152379717, 0.5971535369753838, 20.417858260018484, 97.30571365356445, 138.568021774292, 112.2456190926688, 98.50409030914307, 84.14765984671456, 71.70726462772915, 67.71896389552525, 63.21639919281006, 69.10099533626011, 76.45424611227853, 85.25768320901054, 80.8996410369873, 72.31288351331438, 70.47500160762242, 70.22282368796212, 80.76566587175641, 69.5905237197876, 64.18068408966064, 44.78588901247297, 21.365839208875382, 14.097372957638331, 9.66923909527915, 9.904296653611318, 6.339233713490622, 3.8899937101772855, 0.8239980531590325, 2.0902411299092427, 4.9381129656519205, 5.971534175532205, 3.688138553074428, 2.344682208129338, 1.9904882311820984, 0.44856584870389526, 0.22185824731630938, 0.20204882456787995, 0.14119648773755344, 0.19278505737228052, 0.11284985952079296, 0.20424562240285532, 0.09877472264426095, 0.21293456187205656, 0.14405803275959833, 0.44051777198910713, 0.13739460174526485, 5.1985470822879245, 1.0813380501099994, 0.25485604309609955, 0.29345209204724854, 0.22155772415655, 0.11619861982762814, 0.10299046071512358, 0.13159935628729208, 0.30734436373625484, 0.5094827956386975, 0.6327257081866264, 0.28637681741799625, 0.1756501075412546, 0.2593815459736756, 0.652210139802524, 0.9039566197565624, 1.9992609832968031, 2.9369242915085385, 3.2198445158345357, 5.214415899344853, 3.83195367029735, 6.249851652554103, 14.545155695506505, 15.09190423148019, 19.357102836881364, 21.65589870725359, 21.94539713859558, 23.75785037449428, 28.82293254988534, 29.149909564426967, 34.23051922661917, 40.99505608422415, 44.224825450352256, 47.758463859558105, 39.95444522585188, 45.89646475655692, 63.6676082611084, 72.77149936131069, 82.11384568895612, 93.33472088405064, 62.06146962302071, 11.738596762929644, 0.44109900508608135, 0.6263564356735775, 0.3298439607024193, 0.1309385717447315, 0.10176338441669941, 0.2113731306578432, 0.18051740207842418, 0.23278918862342834, 0.17019531024353846, 0.10419586460505213, 0.19258509310228483, 0.08477958504642759, 0.10285916418901511, 0.09061105070369584, 0.15191299840807915, 0.19440681034965174, 0.08850692718156747, 0.14849044063261577, 0.1548854974763734, 0.2700021117925644, 0.11297384822475058, 0.2590425770197596, 0.16262820629136904, 0.103261949361435, 0.12109138656939779, 0.20984055075262273, 0.16736119160694735, 0.25677987986377304, 0.2307437855218138, 0.2485898807644844, 0.1651637288076537, 0.25049547851085663, 0.14256281299250467, 0.12008798255452088, 0.14707965776324272, 0.15202380317662442, 0.13320700930697577, 0.13901013934186526, 0.24182279674070223, 0.190612632515175, 0.25984818807670046, 0.18618505581149034, 0.21211567867015088], [0.016561835405549834, 0.026935429744688526, 0.03418407516021814, 0.02714714454486966, 0.006055398328628923, 0.04885771045727389, 0.08207031006791762, 0.07292559862669025, 0.014568884757214358, 0.03872154061017292, 0.07981296655322824, 0.04086993854226811, 0.03262923252103584, 0.010104045454811836, 0.03238594039742436, 0.038708757010421584, 0.03482273267582059, 0.029469607065298727, 0.048668507752673965, 0.0446932085656694, 0.01721117815135845, 0.053745014992143424, 0.028657577067081417, 0.056792878944958956, 0.06103814007448299, 0.076401984585183, 0.017511752201244235, 0.03218754354332175, 0.07423764786549977, 0.02129921253903636, 0.03778732681114759, 0.08372016118041106, 0.0182925034314394, 0.035657344319458516, 0.04953909532300063, 0.04405450015994055, 0.047685856731342416, 0.026838540033038174, 0.06042900561754193, 0.03197747927957347, 0.0793341990294201, 0.026989424168797474, 0.01534729334525764, 0.06616687415433781, 0.06184425324733768, 0.06765186161335025, 0.2937532530299255, 0.23884090674774988, 13.86624026298523, 65.97809273856026, 109.84453705378941, 100.18024594443185, 71.1912705557687, 67.10705689021519, 54.4418283871242, 39.518772329602925, 34.751609802246094, 26.22643416268485, 37.27239540645054, 48.287312098911826, 47.69061122621809, 29.901683807373047, 17.50015160015651, 14.376788684300013, 7.807339872632708, 3.188750458615167, 5.324986057622092, 6.060630926064082, 2.961613412414278, 2.9797942425523485, 2.876318846430097, 3.197754672595433, 1.4355551515306746, 2.786377889769418, 5.7019636120115, 5.53562547479357, 5.249281959874289, 2.0619882345199585, 0.3937060481735638, 0.07183476537466049, 0.028925591614097357, 0.03702957961442215, 0.2626964880951813, 0.12831838162881987, 0.07940641551145486, 0.014629386332152145, 0.049917843392384906, 0.03936295297795108, 0.16949309435273918, 0.06184935583067792, 0.15300602332821914, 0.6042378225496837, 1.5945270040205546, 0.14845800665872438, 0.06179020114775215, 0.04646394408441015, 0.061737614683806896, 0.04643813261230077, 0.0367492191227419, 0.03829897953463452, 0.03914956728528653, 0.16881214374942438, 0.22274951663400444, 0.05043389302279268, 0.14566542793597492, 0.33964477479457855, 0.06412298418581486, 0.29214987478085924, 0.9376336698021207, 0.8976811479244913, 1.2763315354074751, 1.3572623069797243, 0.814856612256595, 1.8122672630207879, 4.412290666784559, 5.099665531090327, 4.413735892091479, 1.416914003235953, 6.611066349915095, 8.726053271974836, 13.611683453832354, 15.789201123373848, 12.505861146109444, 9.356065545763288, 17.161921977996826, 41.17382628577096, 46.496674469539094, 51.153329372406006, 57.35457229614258, 46.29017400741577, 10.318124413490295, 0.4538204510297094, 0.08666893187910318, 0.07890558202884027, 0.10374483559280634, 0.1076223443129233, 0.03323582586433206, 0.04503181789602552, 0.028582307177462747, 0.027407174431053654, 0.08292408354048218, 0.028553672999675785, 0.02444879398015993, 0.04514994405742202, 0.027702006378344128, 0.0036567923047446777, 0.027214641815849712, 0.004881831725859749, 0.04945489591253655, 0.045371991249599626, 0.046080727861928086, 0.03915082257507103, 0.07606717505093132, 0.009892641932570508, 0.05554341099091938, 0.028056866622396877, 0.05065917004165905, 0.05253231685076441, 0.038414825818368366, 0.061244930406766276, 0.02122541337407061, 0.06624787087951388, 0.05800047450299774, 0.014018794721258538, 0.05078464812998261, 0.04759017311568771, 0.031289549943591864, 0.0649414195546082, 0.04985681256013257, 0.04632614719282303, 0.013217704403879387, 0.02588192779304726, 0.03541225068537252, 0.04773147124797106, 0.03334281726607254, 0.050718334902610095, 0.09666873315083128, 0.018265353549005728, 0.006750593502407095, 0.08703136457396404, 0.04411685074280415, 0.06680039515984909, 0.08039786373930317, 0.042646404289241345, 0.027913904382980297, 0.049148771446198225, 0.05082136705251677, 0.03892129114163773, 0.013127908775849002, 0.036425608808973005, 0.030332343985459635, 0.058131255342492034, 0.04400500442300524, 0.029341835528612137, 0.06934503040143422, 0.026681613542937806, 0.08791456611028739, 0.0463810338904815, 0.03407293112416353, 0.048422206326254776, 0.03720999189785548, 0.12289992666670255, 0.05591553995119674, 0.0918533465425883, 0.06925433741084167, 0.04793177478547607, 0.017881167021446993, 0.06958062454525914, 0.12448039757353918, 0.046598046352820735, 0.04720845984827195, 0.025830214942938516, 0.014164366775990596, 0.05301928107759782, 0.024890616968540207, 0.03574509246807013, 0.10135580200169768, 0.09290481119283608, 0.05589035273130451, 0.18514229676553182, 0.07297134545764752, 0.2350619009562901, 1.4482882682766234, 5.245090893336704, 52.83698558807373, 97.12155164991105, 109.24333722250802, 90.09358773912702, 69.95262214115688, 64.19540037427629, 57.808831623622346, 58.539976664951865, 66.92413166591099, 62.43837465558733, 64.97568307604108, 63.86741065979004, 62.02556133270264, 52.52248232705252, 54.75959382738386, 52.887624059404644, 41.80436488560268, 21.858426536832535, 7.505033305713108, 5.800337076187134, 6.637015700340271, 5.903466582298279, 4.468187187399183, 5.2366505690983365, 8.327373453548976, 4.817454891545432, 4.287010303565434, 6.969818779400416, 7.981159482683454, 2.584827584879739, 1.1175743171146937, 0.24340332193034037, 0.06375641921269042, 0.05133662958230291, 0.0643691091931292, 0.06530976907483169, 0.17847054691186973, 0.052705794506307156, 0.10562520540718522, 0.013193127017335167, 0.054322299015309126, 0.02655252395197749, 0.18799928203225136, 1.1278643820966994, 0.9045778864196369, 0.12032868606703621, 0.12114522153777735, 0.0750543868967465, 0.18388814691986355, 0.06035146263561078, 0.022284043354115317, 0.08083721516387803, 0.06793363685054438, 0.28484245975102696, 0.32623722138149397, 0.0853219245161329, 0.1794862595519849, 0.21065152223621095, 0.21146332153252193, 0.7744961551257542, 1.1144877970218658, 1.5538536608219147, 2.1468871874468665, 2.867904360805239, 2.1575203197343007, 0.9522547423839569, 3.5037663664136613, 5.156398006847926, 6.266898189272199, 15.022920778819493, 17.405996561050415, 16.250349589756556, 13.507967693465096, 22.00123459952218, 31.51225539616176, 36.09480776105608, 39.12767560141427, 39.6809606552124, 50.23583017076765, 64.08028956821987, 73.61739390236991, 66.05382810320172, 34.85286242621285, 3.9439464722360884, 0.37751845536487444, 0.04308839521503874, 0.09658162961048739, 0.04594183513628585, 0.021530847431027463, 0.05547847518963473, 0.11654731897371155, 0.013367487616570932, 0.04708823701366782, 0.011714494886941143, 0.04343432254557099, 0.05907462936426912, 0.021925223858228753, 0.032741092411535125, 0.01308681330244456, 0.025339294856946384, 0.06277103030255862, 0.07856668771377631, 0.03477297231022801, 0.09012315688388688, 0.07685666411582913, 0.036695088991629224, 0.024841168729056205, 0.043006302655807564, 0.04560903745836445, 0.046353034142936976, 0.052042346713798385, 0.038611831675682745, 0.10013569425791502, 0.122840052736657, 0.09632722647594553, 0.006726226885803044, 0.06523296569607087, 0.017467730545571873, 0.06333841449980225, 0.03858146044824805, 0.03409442032820412, 0.014344885080520595, 0.029075038951954672, 0.05085620982572436, 0.021698891717408384, 0.0840528401147042, 0.063317556333329, 0.08653499585177217, 0.27490596579653875, 0.26594401097723414, 0.12160031497478485, 0.19415157261703694, 0.1105431593688471, 0.16051364690065384, 0.17652136007589952, 0.27188672923616, 0.14107614276664598, 0.20754495821893215, 0.24857177745018685, 0.2323215151471751, 0.12770544737577438, 0.10675315452473504, 0.10954875951366765, 0.15943040645548276, 0.15815812615411623, 0.17512498929032258, 0.2581672668457031, 0.17342407841767582, 0.16234314015933446, 0.12491943687200546, 0.08024503051170281, 0.12204760525907789, 0.12710567670209066, 0.23558795558554785, 0.23997259459325246, 0.2159063552639314, 0.17153695039451122, 0.13838902195649488, 0.13384856416710786, 0.2177592579807554, 0.18710913908268723, 0.1410531268588134, 0.17041968820350512, 0.0846558338297265, 0.1344591506889888, 0.10148209093936852, 0.14836117971156323, 0.12256399754967008, 0.31393258592912127, 0.21229931738759789, 0.19272977033896105, 0.29037319868803024, 0.2882176286407879, 0.24769779720476695, 0.567102523786681, 0.6771087923220226, 29.526713848114014, 99.64336558750698, 141.03069959368025, 123.40737206595284, 93.64475645337785, 86.53973702022007, 75.51778180258614, 64.18050343649728, 60.00154413495745, 49.455853189740864, 62.240684509277344, 74.81652791159493, 79.46605396270752, 68.96293463025773, 63.964949471609934, 70.72330938066754, 66.11887019021171, 47.66149827412197, 24.13636565208435, 16.453026805605205, 13.660262652805873, 14.293750762939453, 17.965498515537806, 24.3544157573155, 15.464313779558454, 4.218554479735238, 8.3529680115836, 12.442245176860265, 11.283599189349584, 4.825407104832785, 1.0539317492927824, 0.3374210526900632, 0.11262790393084288, 0.2539285128670079, 0.4458995317774159, 0.14619772508740425, 0.19166641096983636, 0.14646063026572975, 0.09905250131019525, 0.13594154614423, 0.22709845112902777, 0.17466021994394915, 0.22319044225982257, 4.970099866390228, 2.661049974816186, 0.15168471208640508, 0.2444907964340278, 0.1477349597428526, 0.2962955337549959, 0.19750197497861727, 0.2817324623465538, 0.10554139954703194, 0.24180922604032926, 0.2778056987694332, 0.3965288352753435, 0.23700962215662003, 0.313164728560618, 0.5451595155256135, 0.5693660080432892, 0.7754793795091766, 1.5479177279131753, 2.6888929264886037, 4.416136494704655, 5.858890414237976, 16.465750694274902, 21.744714055742534, 19.869327511106217, 20.676126275743755, 29.918564455849783, 42.47296224321638, 42.66455881936209, 43.72934593473162, 43.95286948340279, 46.90121596200125, 41.905322211129324, 39.82331187384469, 46.683667864118306, 68.01618003845215, 72.37963485717773, 76.58560180664062, 85.08165059770856, 66.27860232761928, 20.43853783607483, 0.8380704351833889, 0.22028885010097707, 0.18489583927605832, 0.21302707333649906, 0.18748290331235953, 0.06471548096409865, 0.20216608898980276, 0.1847381205963237, 0.14363705606332847, 0.3382023721933365, 0.10563890502921172, 0.20935060775705747, 0.2467085745717798, 0.10754288786223956, 0.1300739688532693, 0.19841807867799485, 0.17952185549906322, 0.18756453107510293, 0.17200926505029202, 0.15089347240115913, 0.20692109955208643, 0.2850777214126927, 0.12678342685103416, 0.18822952253477915, 0.12356650589832238, 0.18959530496171542, 0.20353678401027406, 0.20546509910907063, 0.19853463742349828, 0.153861954542143, 0.24437549976365908, 0.1715118581695216, 0.12903806301099913, 0.1289440587695156, 0.16929341506745132, 0.17262779043189116, 0.1858020092227629, 0.14862173715872423, 0.1720320638269186, 0.13125603113855633, 0.15606443850057466, 0.12316906079649925, 0.19619716570845672, 0.21574411754097256, 0.28458632635218756], [0.04419872277815427, 0.05909917876124382, 0.02525167732632586, 0.03949691953935793, 0.01787054116305496, 0.09880389965006284, 0.019596108301941837, 0.044895544315555265, 0.024308735870623162, 0.041745896717267375, 0.02371358941309154, 0.03307886375114322, 0.0751020268404058, 0.037304674674357684, 0.07116724297936473, 0.009923032667886997, 0.03230630413496068, 0.031229421562914337, 0.009668619355319865, 0.03335219122735517, 0.04080310623560633, 0.04649100745362895, 0.021294647694698403, 0.03696001281163522, 0.04042202061308282, 0.06353888088571173, 0.02694527359147157, 0.06720105651766062, 0.07079777387636048, 0.07693981858236448, 0.0850771769349064, 0.0515749989343541, 0.05643043267939772, 0.05579285064179983, 0.025597051650817906, 0.024303533203367676, 0.009359094580369336, 0.010788915446028113, 0.025048939544441443, 0.10329295162643705, 0.06722467632165977, 0.06769373400935105, 0.1181228230042117, 0.11529160849750042, 0.034291032635207684, 0.08558751669313226, 0.02772959561220237, 0.09693870187870093, 0.4363996072539261, 0.5390918925404549, 8.806443929672241, 49.251867975507466, 104.55376870291573, 97.07736805507115, 79.09601375034877, 59.36806297302246, 51.44257593154907, 37.85966757365635, 27.94483310835702, 17.784391982214792, 26.73651705469404, 38.78437205723354, 40.033609526497976, 29.53972087587629, 12.357897520065308, 3.3775579844202315, 12.30102390902383, 7.653095943587167, 5.708536607878549, 3.8963313358170644, 5.771534621715546, 1.3897381871938705, 2.4381415588515143, 4.759322788034167, 9.022057822772435, 10.913704889161245, 8.014859114374433, 0.05036249078278031, 0.409915136971644, 0.0009084129290256117, 0.05926353351346084, 0.12027751095592976, 0.25996945585523334, 0.13226399490875856, 0.06600325900529112, 0.04210670432075858, 0.014771318894677928, 0.054434732267899175, 0.06600409360336405, 0.31083691918424194, 0.02514514732839806, 0.723119926239763, 0.36753807376538006, 0.09579713456332684, 0.35003208741545677, 0.14728150836059026, 0.024010918369250636, 0.11810709456247942, 0.08971037010529212, 0.04250955395400524, 0.05642113335696714, 0.20213859475084714, 0.018128292867913842, 0.1493252015539578, 0.22281772297407898, 0.0604914715513587, 0.1686885418104274, 0.6508753257138389, 1.1534535118511744, 0.3782748862036637, 0.3391561752983502, 4.171693222863333, 4.213484031813485, 4.009280817849295, 3.929634051663535, 1.57171411386558, 5.7881434219224115, 9.668769223349434, 16.600198337009974, 16.85982472555978, 10.893196412495204, 6.808908488069262, 9.208292126655579, 23.515604904719762, 35.968541622161865, 37.58718006951468, 56.74452740805489, 50.50584759031023, 14.761268990380422, 0.6779952304703849, 0.023541351780295372, 0.05334450291203601, 0.06968779915145465, 0.07941581322146313, 0.09511883703193494, 0.04949109575578144, 0.05768924406064408, 0.06127876216279609, 0.015998228952022533, 0.12026813360197203, 0.04165349381842783, 0.018974191941586987, 0.01670901134743222, 0.04822984504114304, 0.03989570474784289, 0.047197755958352766, 0.03192335593381098, 0.1044600997120142, 0.041557925553726296, 0.04275970267398017, 0.0876575777573245, 0.03218339090900762, 0.028105181708399738, 0.05175889888778329, 0.04562908477549042, 0.03373415216005274, 0.02679001120850444, 0.05007130087220243, 0.010581925794083093, 0.04082820185327104, 0.0628476029794131, 0.035018741086657555, 0.04140978439577988, 0.03260801133832761, 0.015205199630664927, 0.023936042029942785, 0.04146229961354818, 0.07813023363373109, 0.012451615467268442, 0.04935439809092453, 0.021672230380188142, 0.023822346702218056, 0.059549970286233087, 0.041221311116325, 0.10559332783200912, 0.007788445467927626, 0.03759462286585143, 0.04216330771201423, 0.046008874396128316, 0.0900117957166263, 0.09290538794760193, 0.03167933438505445, 0.1122911809278386, 0.02777292176948062, 0.0440432296932808, 0.03955912762986762, 0.02872001925217254, 0.04756265173533133, 0.13982121939105646, 0.004943723873501378, 0.02618905309853809, 0.024196440021374395, 0.017456904519349337, 0.06228840869984456, 0.013769125216640532, 0.061813189914183955, 0.03788746161652463, 0.015181795261534197, 0.027080140908115675, 0.041011043292071135, 0.02952382879863892, 0.061178908949451785, 0.04217996574672205, 0.06978288904896804, 0.10275152817900692, 0.09092524634408099, 0.06726259964385203, 0.13131978628890856, 0.07791276994560446, 0.035797858743795326, 0.020419994003272483, 0.007817916788293846, 0.012890255278242486, 0.03562438787360277, 0.05478560611871736, 0.12254445574113301, 0.1449752492564065, 0.040620339435658286, 0.09480287041515112, 0.06939514699791159, 0.12439332795994622, 0.14400710192109856, 0.054898812901228666, 0.09411292922283922, 3.3375897748129706, 8.52579663481031, 40.974777766636436, 84.40409006391252, 103.87933485848563, 94.63219274793352, 75.89829295022147, 62.585586139133994, 56.021692412240164, 51.94842563356672, 59.93487616947719, 62.09552274431501, 59.31917544773647, 54.55704689025879, 49.034854888916016, 45.730312483651296, 35.99323204585484, 29.807209151131765, 23.599586044039043, 15.18744717325483, 5.267048937933786, 1.450942805835179, 4.959502995014191, 3.2113959406103407, 5.398602221693311, 12.968858701842171, 11.927339366504125, 10.740527987480164, 8.895701357296534, 1.760791859456471, 0.5410156207425254, 0.06584562174975872, 0.12042605584221226, 0.23783634922334126, 0.16177768978689397, 0.12870259529777936, 0.14702849622283662, 0.2982938193849155, 0.07919163203665189, 0.17115896567702293, 0.06132799666374922, 0.2989039309322834, 0.039122741403324265, 0.43148777367813246, 0.8787670657038689, 0.39584405773452347, 0.4776253050991467, 0.2784870022109577, 0.2416432835161686, 0.13787058049014636, 0.009688344368311976, 0.11120379463370357, 0.21787755377590656, 0.4240406890000616, 0.7982450436268533, 0.575268665594714, 0.4024912310498101, 0.08385372401348182, 0.14511517674795218, 0.5506886531199727, 0.7736211163657052, 0.8522146333541188, 0.9332411055053983, 2.8781944257872443, 3.045900055340358, 4.582407321248736, 6.263291205678668, 15.601983649390084, 19.79534309250968, 16.824571302958898, 21.002248661858694, 28.219245263508387, 31.864063535417827, 35.96856246675764, 33.448447363717214, 34.25022084372384, 41.345356464385986, 57.61059604372297, 66.89245482853481, 66.67287785666329, 36.21506718226841, 6.494198952402387, 0.4785977272050721, 0.0066297731329021704, 0.06911130901426077, 0.14137392464493, 0.07024102232285909, 0.02411502430082432, 0.02535650929036949, 0.049445063940116336, 0.05470332356968096, 0.13741830975881644, 0.020183068234473467, 0.019627124137644256, 0.03732120378741196, 0.07320508720087153, 0.0036340015857214375, 0.03773754948217954, 0.035991627989070754, 0.038579597869621854, 0.022125176253861616, 0.043180150112935474, 0.02082427534540849, 0.01823139117498483, 0.07869136852345296, 0.045909384199018986, 0.03923185322699802, 0.07377272924142224, 0.08763334727180855, 0.017726067486884337, 0.0637535150828106, 0.03369758590789778, 0.029772488134247915, 0.013725216367415019, 0.02177921330024089, 0.03719747971211161, 0.08045162406883069, 0.04166349203192762, 0.06412571868194, 0.057825405682836256, 0.05096780848024147, 0.024123935161956718, 0.04928921462435808, 0.060721956326493194, 0.015519568297479833, 0.041564134149146933, 0.059856695256062915, 0.03080886895103114, 0.2228074770952974, 0.21724670619836875, 0.16813473509890692, 0.32852505147457123, 0.1640728209167719, 0.21029728624437535, 0.20685399243874208, 0.1614743032093559, 0.13720063572483404, 0.10463220333414418, 0.12271688506007195, 0.19172856477754457, 0.2750413199620587, 0.09886765480041504, 0.18657377495297364, 0.07460236722337348, 0.08792165001588208, 0.1666077191808394, 0.05188261278505836, 0.21025330360446656, 0.1968518162944487, 0.14888563299817698, 0.16584535794598715, 0.13238144932048662, 0.10863032843917608, 0.21872496258999619, 0.10218301082828216, 0.1527901134852852, 0.1809846412922655, 0.20240823099655764, 0.19651045889726707, 0.12502889814121382, 0.24782392329403333, 0.19551154678421362, 0.1276141301329647, 0.14737186208367348, 0.12797102598207338, 0.15100929832884244, 0.22426996433309146, 0.31419205772025244, 0.18233598449400493, 0.16916933815394128, 0.1908031515777111, 0.24042748446975434, 0.13700267991849355, 0.3333548365959099, 0.24562009583626473, 0.22209903225302696, 1.118721529841423, 1.3821026597704207, 17.33116446222578, 74.8861141204834, 137.41261972699846, 127.73747553144182, 101.89549214499337, 85.2514089856829, 75.6999705178397, 64.39409800938198, 57.61160005841936, 53.57067019598824, 60.4886337007795, 68.43451717921666, 82.34870869772774, 74.59084347316197, 64.33592074257987, 51.59683288846697, 40.132857595171245, 36.05472707748413, 30.206692355019705, 26.310825245721, 20.816981894629343, 19.41169309616089, 25.552934850965226, 23.159396818705968, 20.37408287184579, 17.06384120668684, 14.922805922372, 5.147563806601933, 1.0252226612397601, 0.10830612440726586, 0.1263694390654564, 0.2535575713430132, 0.4337170869112015, 0.27538308448025156, 0.16515427002949373, 0.29003311693668365, 0.12147057907921927, 0.2705510194812502, 0.1409730732973133, 1.0758614582674844, 0.1368314583918878, 1.888690173625946, 1.3539280401808875, 0.6002854917730603, 0.6864200841103281, 0.28472754306026865, 0.22599721593516214, 0.2525405287742615, 0.15062106773257256, 0.14691780001989432, 0.7914271780422756, 1.2972661320652281, 0.9858880404915128, 1.106737407190459, 0.32573013859135763, 0.12514168423201355, 0.37539740917938097, 1.2936024772269386, 1.8799923317773002, 4.589108858789716, 6.229428725583213, 13.139903375080653, 13.69500538281032, 18.797166619982036, 26.689965861184255, 40.91369962692261, 36.41522741317749, 40.56219373430525, 54.06488513946533, 56.069912910461426, 40.64951869419643, 38.324317932128906, 38.696223735809326, 52.81079435348511, 63.886907305036274, 64.72519356863839, 83.99766213553292, 72.25665869031633, 23.81288184438433, 1.5963436322552818, 0.19612997717091016, 0.11225403792091779, 0.19726501697940485, 0.1550581982093198, 0.18883647210896015, 0.17586238043648855, 0.0928686995591436, 0.16906633653811046, 0.12206074169703893, 0.2224958666733333, 0.12293145140366894, 0.17999621933060034, 0.1479493360966444, 0.2708178465919835, 0.09915970305779151, 0.2509006996239935, 0.08354290069213935, 0.2809074180466788, 0.1930829749575683, 0.12560721353760787, 0.13981119064348085, 0.11041744040059191, 0.20165839551814965, 0.16022043834839547, 0.19971211281205925, 0.2360249049961567, 0.2160596363246441, 0.17140323828373635, 0.10815983225724526, 0.1381925589271954, 0.14261231890746526, 0.09148095295365367, 0.07946234715304204, 0.16542325488158635, 0.23074093567473547, 0.17961499121572289, 0.11297335289418697, 0.14958814744438442, 0.3414776607283524, 0.18783236241766385, 0.26920722158891813, 0.2673310451209545, 0.23866796174219676, 0.3309550753661564, 0.22180897210325512, 0.15016775205731392], [0.01907091710849532, 0.0068728718740333405, 0.03814691983695541, 0.01884318040018635, 0.11446112234677587, 0.018024974036961794, 0.06017600026513849, 0.06462965985494, 0.04725820664316416, 0.04681024800187775, 0.015909781912341714, 0.027151465116600906, 0.027454546353380595, 0.02641939029230603, 0.017501801485195756, 0.05210201708333833, 0.04582893369453294, 0.06554418935307435, 0.02075430142161037, 0.11229882123214857, 0.061320973826306205, 0.059771335550716946, 0.06640150477843625, 0.009043356120985533, 0.03728175036875265, 0.04129123075732163, 0.01895620906725526, 0.024454729465235556, 0.09634347738964216, 0.10684497388345854, 0.057552817809794626, 0.1411037998540061, 0.025700423068233898, 0.05279266055939453, 0.025716514526201145, 0.028363700157829692, 0.03585459105670452, 0.06451444460877351, 0.06560182411755834, 0.016367362180192555, 0.0473608011379838, 0.05642117067639317, 0.042996111059827466, 0.013605478685349226, 0.10652461714510407, 0.033120016900024245, 0.05814686843327113, 0.06307489863995995, 0.010521833884662815, 0.026387448256303157, 0.3575007766485214, 0.24922854506543704, 6.2337431226457864, 34.704455852508545, 70.37673323495048, 89.51797812325614, 70.07620974949428, 50.33321959631783, 42.46333203996931, 28.414117915289744, 23.953876427241735, 11.08321922166007, 18.35074486051287, 19.313798189163208, 19.875709431512014, 16.529849563326152, 7.58944262777056, 8.59954307760511, 9.610104714121137, 9.225409013884407, 8.698715584618704, 11.472229753221784, 10.51592833655221, 10.553398234503609, 10.312670946121216, 16.865860973085674, 16.94682138306754, 6.679965121405465, 1.3070072893585478, 0.13107931347829954, 0.1214964176927294, 0.15072233229875565, 0.2507156766951084, 0.14368671125599317, 0.06301946232893638, 0.014986273699573107, 0.13047701865434647, 0.24009443234120095, 0.40412989311984604, 0.7894278881805283, 0.2301616296172142, 0.3040204920939037, 1.1299966105393, 0.1933452965957778, 0.08702998714787619, 0.1256653368473053, 0.1550970918365887, 0.013163373256767434, 0.021524014583389674, 0.014105985622986086, 0.35764454464827267, 0.4905428205217634, 0.7567131636398179, 0.3910645384873663, 0.6619675819362912, 2.061630836554936, 2.147692309958594, 1.8866489231586456, 2.5360401570796967, 2.162962930543082, 2.2095773092338016, 3.156202707971845, 2.119103729724884, 2.8827109720025743, 4.471962230546134, 8.607028024537222, 11.00496426650456, 15.602530820029122, 13.01486359323774, 9.091916748455592, 11.138461743082319, 26.2464154447828, 27.69235815320696, 29.909271240234375, 38.515758173806326, 55.34352738516671, 28.38628169468471, 1.7148247488907404, 0.009802891257485109, 0.11675210084233965, 0.011060190353808659, 0.04822129549990807, 0.04369685792231134, 0.061336817618991644, 0.08693489046501261, 0.027515095425769687, 0.028820975084922144, 0.02434603833327336, 0.03598471371723073, 0.10135894361883402, 0.07976056329373803, 0.04313134987439428, 0.0020099127515485244, 0.04973403504118323, 0.04626283648290804, 0.04075861130175846, 0.04807285578655345, 0.04862079995551279, 0.02682400411660118, 0.13450742167021545, 0.09847796535385506, 0.02761004283092916, 0.007919984570305263, 0.03750607404591782, 0.07993399005915437, 0.013031353242695332, 0.014497358684561082, 0.05079822900838085, 0.08276670412825686, 0.0557272464835218, 0.10263994309519019, 0.07750750133501631, 0.0386932830193213, 0.0197836859151721, 0.028981808240392377, 0.03519175394571253, 0.018124065594747663, 0.07248163316398859, 0.03926326600568635, 0.053426188350256, 0.16872895535613808, 0.05911542967494045, 0.03657804848626256, 0.029543421497302394, 0.053026253024914434, 0.03926377151427524, 0.035096155146935155, 0.03679637052118778, 0.022585759039169977, 0.04287453454786113, 0.08820905709373099, 0.03457645160545196, 0.08398553622620446, 0.06933365815452167, 0.028289368342874304, 0.03251479419746569, 0.035661368032119105, 0.025871756553117718, 0.041524660374437056, 0.044134645323668203, 0.002153576214498441, 0.02993302951966013, 0.05175504141620227, 0.09558053940002408, 0.019084140059671233, 0.05224879099322217, 0.046637577803007195, 0.06895741727203131, 0.03418939487476434, 0.02187526671748076, 0.03832368499466351, 0.020425252649667006, 0.05863018214170422, 0.08900089388979332, 0.016957916651985476, 0.07917666355414049, 0.0908475744404963, 0.09437757823616266, 0.04958058773939099, 0.03488515789753624, 0.01251768781470933, 0.034939868176089864, 0.057415183766611984, 0.10219240175294024, 0.09612319099583796, 0.0846781712025404, 0.04825412641678538, 0.1151692686336381, 0.021156574300091182, 0.057324246503412724, 0.07024472712406091, 0.08187977064933095, 0.12736354715057782, 0.09842607778097902, 0.3795492835342884, 0.05629696144855448, 2.1615172709737505, 4.3948889034135, 32.78441149847848, 69.21142305646623, 94.32036454336983, 94.85005351475307, 83.37101800101144, 62.75207192557198, 48.84923723765782, 41.89349985122681, 56.227637018476216, 57.21310349873134, 53.62115233285086, 47.868620600019185, 39.63143042155674, 28.515191623142787, 24.137164694922312, 29.045254060200282, 30.93675000326974, 22.196798597063335, 13.195304836545672, 4.044725750173841, 4.586380822317941, 4.335893051964896, 18.821688549859182, 21.028997489384242, 19.0703159400395, 8.451774869646345, 1.9860967525414057, 0.17566594454858983, 0.6098674918924059, 0.2777457434151854, 0.21091088546173914, 0.5202123341815812, 0.28109822209392277, 0.2709802878754479, 0.5680316824998174, 0.7191451766661235, 1.0029225264276778, 1.7676344237157275, 0.6979017108678818, 0.3136439914149897, 0.4708140620163509, 0.32815153151750565, 0.48979154654911583, 0.3047710061073303, 0.2944495385246617, 0.2604529527681214, 0.03843262718458261, 0.3510703274181911, 1.0237469289984023, 0.5579967466848237, 1.69126829292093, 1.0694269921098436, 0.9347338825464249, 1.3810656411307198, 1.1797179196562086, 1.3738260524613517, 2.813911429473332, 5.6557515774454385, 4.050781105245862, 1.983950627701623, 2.9645716079643796, 6.792414333139147, 15.124004908970424, 17.10503707613264, 13.487179551805768, 26.721057312829153, 36.28598744528634, 35.702307496752056, 34.96698311397007, 36.30301053183419, 31.532749107905797, 43.1802020072937, 58.329988207135884, 67.08620534624372, 52.37806054524013, 12.564864380019051, 0.5808904639312199, 0.20034509098955564, 0.12746901863387652, 0.016776942880824208, 0.08873540349304676, 0.015457736793905497, 0.10267752714987312, 0.08312744048557111, 0.013758542614855936, 0.05650977038645318, 0.04418204438739589, 0.0662950019219092, 0.07113661390862294, 0.029016525484621525, 0.04161119733804038, 0.08567696796464068, 0.009928482152255518, 0.05096166095297251, 0.08951236001615014, 0.08170145843178034, 0.02015770798815148, 0.0635290082011904, 0.12141206221921103, 0.05424401643020766, 0.03283049279291715, 0.08838798677814858, 0.0012023645831504837, 0.06689501008284943, 0.023630345040666204, 0.07172320064689432, 0.10354271358145134, 0.014340018288099339, 0.06628934972520385, 0.01513437244908086, 0.015371764710705196, 0.020934018206649592, 0.030158696696162224, 0.06568162662110158, 0.03355684417432972, 0.08343478292226791, 0.006536296028311231, 0.026584055474294082, 0.06949981780988829, 0.14319728394704206, 0.1272754461637565, 0.046796480526349375, 0.03573919939143317, 0.03589630060430084, 0.11966332819844995, 0.1196117459663323, 0.14677336705582483, 0.13101741751389845, 0.25521791939224514, 0.2569209880062512, 0.22109106848282473, 0.10991685119058404, 0.1777875471327986, 0.18374261472906384, 0.11542456064905439, 0.14495242333837918, 0.204006411667381, 0.1427110050405775, 0.10088065785488912, 0.12007430328854493, 0.12037786628518786, 0.16148963810077735, 0.10151299142411777, 0.2365833664579051, 0.13320190672363552, 0.16089543141424656, 0.11550191364118031, 0.11289338754223925, 0.20279684157243796, 0.1680940365684884, 0.1459254561258214, 0.15950676878648146, 0.23938932589122228, 0.23602951903428349, 0.23935252215181077, 0.26867701432534624, 0.09607983939349651, 0.10758954393012182, 0.1704306397587061, 0.135369744684015, 0.16245668620935508, 0.18685208287622246, 0.21606738519455704, 0.2118227415319, 0.1046832495235971, 0.1907342259905168, 0.16195799011204923, 0.2228463842932667, 0.2763685615999358, 0.19828508581433976, 0.19991860458893435, 0.17797227150627545, 0.2951080160481589, 0.12183708298419203, 0.827404570366655, 0.5311270313603538, 11.331355026790074, 50.56455986840384, 96.84600693838937, 124.18515341622489, 105.4636561529977, 82.73717553274972, 70.10180691310337, 56.78949267523629, 58.93653815133231, 52.67048937933785, 47.46487815039498, 50.45216580799648, 57.1987624168396, 56.02358232225691, 53.45546211515154, 52.513387135096956, 49.890212876456125, 44.82164444242205, 42.47154481070382, 34.922712666647776, 36.264263902391704, 42.26900829587664, 43.78501142774309, 38.71333367483956, 27.80886381013053, 14.843214307512556, 4.87586144890104, 0.1840945572725364, 0.8825367348534721, 0.3931622159268175, 0.2355949037841388, 0.2518870181271008, 0.13879979348608426, 0.13663795377526963, 0.30719136766024996, 0.43620812467166353, 0.45032572426966255, 2.0759217611380985, 0.9017234795859882, 2.098602852651051, 2.6201398500374387, 0.4379734013761793, 0.36924847055758747, 0.6529123421226228, 0.5145391300320625, 0.3298201034111636, 0.07821863996131079, 0.24180952459573746, 1.1338556834629603, 1.7592453424419676, 2.4254092020647864, 0.7581934013536998, 2.1443966925144196, 3.4896448041711534, 4.91205244404929, 5.894492549555642, 7.8136462313788275, 15.465835435049874, 24.19428062438965, 25.033237389155797, 27.623006446020945, 29.56895889554705, 29.766753264835902, 32.104005677359446, 47.78871979032244, 53.84037494659424, 44.859129973820274, 38.925170353480745, 46.156719957079204, 63.234610421316965, 59.34261866978237, 62.37225559779576, 72.47137192317417, 81.05564893995012, 41.14648859841483, 4.156768926552363, 0.15710460554276193, 0.26580599695444107, 0.29463627136179377, 0.17386558758360998, 0.19048143098396914, 0.17853576769786222, 0.23925275036266871, 0.21661439298519067, 0.08466821709381682, 0.1523971874266863, 0.08759601427508251, 0.1844741433326687, 0.2804466113448143, 0.13726569366242203, 0.1248589251190424, 0.15610546272780212, 0.06527885501938206, 0.14803378656506538, 0.1980230627315385, 0.14325406375740254, 0.12271569083843913, 0.17768390769405024, 0.27035999830280033, 0.1761158268366541, 0.09385858037109886, 0.17599639110267162, 0.14319185566689285, 0.10155646516276257, 0.14560224275503839, 0.20092892966100148, 0.23895224077360971, 0.24197378435305186, 0.29259879354919704, 0.1452308262565306, 0.11050292902759143, 0.1123895752908928, 0.11262524407356977, 0.1315729884164674, 0.13730834637369427, 0.20251986357782567, 0.12578009068965912, 0.20358620850103243, 0.4338669345847198, 0.27299534689102856, 0.3418866273547922, 0.241790878453425, 0.20426547633750097, 0.237403932426657], [0.02898935354979975, 0.03246209577524236, 0.0185691726926182, 0.014916277723386884, 0.033562805104468546, 0.014826974033245018, 0.04950048328776445, 0.01714528731203505, 0.051469201754246435, 0.03590735733242972, 0.02670407135571752, 0.01859268223467682, 0.05460473921682153, 0.03200144174375704, 0.01603337706598852, 0.09185398436550583, 0.0159793945162424, 0.11058095376938581, 0.026561341514544826, 0.022749201161786914, 0.018098973369758044, 0.027058176729562025, 0.08864167745092086, 0.02324168018198439, 0.03550125412376864, 0.05475505847217781, 0.07072396962238209, 0.03015148386891399, 0.08787055632897786, 0.05634664038994482, 0.05526655513261046, 0.027971115063077638, 0.04369658311562879, 0.0373038638250104, 0.01973293997746493, 0.03276742635560887, 0.07173001313848154, 0.0628642677994711, 0.06379809483353581, 0.06897642303790365, 0.07377241032996348, 0.031126874565546, 0.024783500037821274, 0.049040287267416716, 0.05558497465348669, 0.043082892296037505, 0.06806086895189115, 0.07287398246782166, 0.0389948579083596, 0.024849015986546874, 0.09248237564627614, 0.1199744093630995, 0.2785061368984835, 0.5397304754172052, 1.0057756304740906, 13.297742996897016, 41.78588615145002, 72.9577944619315, 62.481898171561106, 32.58768367767334, 25.687670843941824, 23.27666677747454, 23.058934552328928, 7.749344996043614, 8.849301287106105, 13.947156378201075, 23.496856927871704, 22.892325435365947, 12.159262418746948, 14.824278729302542, 13.656430721282959, 6.857746941702707, 8.039705872535706, 7.412834184510367, 17.74082851409912, 19.781057596206665, 29.275359289986746, 30.632776737213135, 17.478019850594656, 4.0269001466887335, 0.15762790531984397, 1.1282937590565, 1.0557871354477746, 0.5378664040139743, 0.18814755550452641, 0.011107130558229983, 0.09736849953021322, 0.8699420392513275, 5.943782201835087, 3.4228645818574086, 0.1602408079696553, 0.345262664769377, 0.4166960359684059, 0.16234485006758145, 0.36718835681676865, 0.35575300614748684, 0.042004639083253484, 0.09474283363670111, 0.23775598353573255, 0.019854981285919036, 0.20584452232079847, 0.19165061467460223, 1.0734896255390984, 3.073468770299639, 2.387571483850479, 2.0569653383323123, 2.57280872123582, 3.277082690170833, 2.4137140810489655, 2.682926595211029, 2.8355594107082913, 3.2019190319946835, 6.405470456395831, 6.54316030229841, 4.679402870791299, 14.06981292792729, 9.546065773282733, 3.9669519577707564, 8.436972601073128, 18.198827709470475, 36.37893002373831, 34.73743200302124, 33.86023235321045, 47.90968445369175, 35.77869599206107, 5.483306407928467, 0.03821251042453306, 0.04874161650825824, 0.046315470444304604, 0.0470951241441071, 0.05391518139679517, 0.06000969811741795, 0.060836764451648505, 0.033683974495423694, 0.05113758811993258, 0.05344093291621123, 0.04046617627942136, 0.029444816788392406, 0.004350348816452814, 0.02314358437433839, 0.05599866388365626, 0.023934109901477183, 0.03534031579537051, 0.01606914773583412, 0.056775179358997514, 0.04436644306406379, 0.013326733107013362, 0.04334331742886986, 0.03520422541935529, 0.07071512152573892, 0.003574592028079288, 0.07362132772271122, 0.08098505437374115, 0.04455320304259658, 0.011724767058954706, 0.052777386736124754, 0.031449110845902135, 0.03677931215081896, 0.047334993058549504, 0.04419066517480782, 0.04230583060000624, 0.03189306613057852, 0.043069942455206595, 0.02976771124771663, 0.04467600431027157, 0.05463111048032131, 0.04044540971517563, 0.06732847182346241, 0.025380922980340462, 0.06312690834913935, 0.17254918893533094, 0.08576335225786481, 0.05863111173467977, 0.04088066957358803, 0.056376068453703604, 0.04808370895417673, 0.05621576116287282, 0.06310653872787952, 0.04014926989163671, 0.057119138937975676, 0.030613304980631386, 0.10071356860654694, 0.09023651294410229, 0.034462997157658846, 0.05580984115866678, 0.008314523845911026, 0.04695277428254485, 0.022484840525846397, 0.09068376930164439, 0.008839240913013262, 0.016374381624960473, 0.02162274142860302, 0.04833088908344507, 0.03557154695902552, 0.03753310348838568, 0.009558987604188067, 0.04544896086944001, 0.02844724478200078, 0.051623592219714604, 0.05122017261705228, 0.056327281785862784, 0.046632746633674414, 0.028998272892619883, 0.0606644708397133, 0.09543393512389489, 0.05959796306810208, 0.008926541228512568, 0.036813978504921706, 0.021119704403515373, 0.06099189112761191, 0.01830122939177922, 0.029990671069494317, 0.11995615677109786, 0.02668749983422458, 0.03806333110800811, 0.033658624427126985, 0.05815152318349906, 0.04833256506494113, 0.07397130929997989, 0.0759533711576036, 0.022183665972469107, 0.030673029632972817, 0.12159580950226102, 0.07320374370153461, 0.09336304624697991, 0.0265421762929431, 0.2336212354046958, 0.1256987750530243, 1.590763034565108, 4.061894314629691, 11.742223722594124, 44.268123149871826, 71.8858402797154, 87.0175507409232, 82.98920059204102, 57.01201568331037, 41.099984305245535, 38.03971971784319, 49.331237248011995, 45.64983149937221, 38.85047721862793, 37.05377728598458, 37.89930009841919, 34.872845445360454, 32.50960677010672, 36.848510129111155, 40.712889739445274, 33.75132628849575, 24.69364070892334, 22.029378277914866, 22.923326560429164, 26.77944823673793, 33.47710173470633, 36.66432728086199, 29.68907240458897, 11.935378432273865, 0.538108722439834, 1.510111493723733, 0.710882845733847, 0.35034871899655884, 0.2309953048825264, 0.23054394338812145, 0.6007845678499767, 2.616475543805531, 3.9434092896325246, 1.9008384474686213, 0.67033587289708, 0.46594739173139843, 0.6096383099045072, 0.2354904908154692, 0.5180789115173476, 1.1903583258390427, 0.8953440561890602, 0.8065898301345962, 0.3347267529794148, 0.07232678468738284, 0.6065698117017746, 0.9097760617733002, 1.59287420128073, 0.5583380226578031, 3.89527998651777, 5.039511067526681, 6.3184108308383395, 4.513845103127616, 2.060339774404253, 3.565810088600431, 5.409590363502502, 12.644660098212105, 19.815011705671036, 29.364192008972168, 20.524422781808035, 20.82890500341143, 34.92660365785871, 32.72526148387364, 34.132164001464844, 34.48922150475638, 41.05879538399832, 50.39067077636719, 53.753633635384695, 62.29592268807547, 53.95201860155378, 22.987790209906443, 0.7506829957876886, 0.1259905993938446, 0.06437550099300486, 0.018962690773020898, 0.10177876002022199, 0.0506904708620693, 0.019024171134723083, 0.04143285119373884, 0.05339562374034098, 0.07201888585197073, 0.09879300916301352, 0.07177706275667463, 0.00937010974822832, 0.08424635151667254, 0.07683262362011842, 0.040561893821827004, 0.04781481231163655, 0.019990847745378102, 0.018370821639629345, 0.10581973461168152, 0.06636624809886728, 0.03606479102745652, 0.031691073040877066, 0.06519435026815959, 0.055078197204108746, 0.018338764252673303, 0.05541984297867332, 0.09377640978034053, 0.038149851108235974, 0.05075682480154293, 0.007401267449105424, 0.08644939187381949, 0.04325547767803073, 0.06737968764667, 0.03758122179923313, 0.017491084024576203, 0.050844220111944845, 0.04017351734052811, 0.029645598693085567, 0.06915093545934983, 0.027829080720299056, 0.06946598605385848, 0.06933327817491122, 0.06876436048852545, 0.053568701060222726, 0.11372064386627503, 0.18889527395367622, 0.03666333355275648, 0.0652001720986196, 0.051951914959188016, 0.1915551990802799, 0.23111244716814586, 0.14749416123543466, 0.11745328535991055, 0.13020571321249008, 0.1615346928260156, 0.2649536212640149, 0.09313094655850104, 0.18135304509529046, 0.0853422059278403, 0.13025052366512163, 0.12188998157424585, 0.19645620323717594, 0.1424398488764252, 0.11388496469174113, 0.18996349163353443, 0.22098687264536107, 0.19424168206751347, 0.1222570011658328, 0.10740376104201589, 0.13507486693561077, 0.1048217588769538, 0.0954410122441394, 0.10922579041549138, 0.23004977990474018, 0.1503614873758384, 0.18526938637452467, 0.15934663452208042, 0.172199743400727, 0.2685487712068217, 0.16005502508154937, 0.13580984249711037, 0.08097147688801799, 0.09756889806262084, 0.10285885206290654, 0.10048440697469882, 0.22846920043230057, 0.11454456858336926, 0.1649706448827471, 0.27592683530279566, 0.31522609080587116, 0.1535791140049696, 0.1899912165743964, 0.1634651928075722, 0.12083397752472333, 0.13771554880908557, 0.2735049266900335, 0.1805454527160951, 0.1986859371619565, 0.06170067523739167, 0.25038932849253925, 0.19810786603816918, 0.4265556111931801, 0.5809388299073491, 2.1252954431942532, 22.021604980741227, 62.799771308898926, 107.30582509722028, 108.58776078905377, 73.83082171848842, 59.74515560695103, 59.67948818206787, 65.27071053641183, 47.99605751037598, 31.392121042524064, 32.22241687774658, 50.03344651630947, 56.80924640383039, 52.54616526194981, 52.91518061501639, 53.44318117414202, 49.842318943568635, 52.76163584845406, 56.861514227730886, 60.647879464285715, 67.9826966694423, 66.10508496420724, 53.3917019707816, 33.884537151881624, 9.41884252003261, 0.17195336733545574, 1.7774490799222673, 1.2439922307218825, 0.8089420667716435, 0.23274977930954524, 0.18004279397428036, 0.1985410563647747, 1.1185697551284517, 6.675448792321341, 6.31823365177427, 1.396060287952423, 1.0338306107691355, 0.7743380836078099, 0.8814804458192417, 0.5683811008930206, 1.0064057452338082, 0.9150554984807968, 0.6497392409614154, 0.320302102714777, 0.1566708588174411, 0.8364052016820226, 1.8587538599967957, 6.543991914817265, 12.607836382729666, 16.19584444590977, 11.902295453207833, 19.848554134368896, 21.491089173725673, 27.709018196378434, 21.559687001364573, 24.261572190693446, 36.20019456318447, 39.7728853225708, 50.87273332050869, 56.65134164265224, 50.526636600494385, 40.21578434535435, 28.164257219859532, 40.510568618774414, 54.57437917164394, 71.27751159667969, 68.55308818817139, 67.8319832938058, 81.25409643990653, 56.07173333849226, 9.822385208947317, 0.13376401870378427, 0.17530516747917446, 0.15512052843613283, 0.14006098652524607, 0.1626258992723056, 0.26644569262862206, 0.1301769840398005, 0.1591926206435476, 0.2270041076200349, 0.21584834051983698, 0.19413220722760471, 0.12438604049384594, 0.1062006913125515, 0.18342705523329123, 0.22997945653540747, 0.1133855018498642, 0.14593741191284998, 0.1468944177031517, 0.18675037047692708, 0.1472883615642786, 0.1150069630571774, 0.10429960582405329, 0.15882333474499838, 0.15498060094458715, 0.18790160013096674, 0.24503883559788975, 0.19655765779316425, 0.12462506123951503, 0.09946424993021147, 0.11279012808310133, 0.11408476611333233, 0.10856677006397929, 0.16836401208170823, 0.16987470244722708, 0.12294917473835604, 0.18239306285977364, 0.0685032873547503, 0.10623723042330571, 0.22943285586578505, 0.13457855928157056, 0.061239705687122684, 0.1402061523071357, 0.1460743538503136, 0.18506558159632341, 0.30841533626828876, 0.2715531885623932, 0.40844049038631575, 0.20079946517944336, 0.1735041726912771, 0.2843498976102897], [0.04968059701578958, 0.013615988344619316, 0.06433520958359752, 0.04993333773953574, 0.07710977803383555, 0.05081569789243596, 0.025009067130408118, 0.028940373499478613, 0.03334375364439828, 0.02045564932216491, 0.020644329554800476, 0.020245579969403998, 0.03857364711750831, 0.034101477092398066, 0.005952691875531205, 0.01699131753827844, 0.015740382252261043, 0.0710005812080843, 0.009263692556747367, 0.016811587182538848, 0.05239802459254861, 0.04785296294306006, 0.043325003768716536, 0.0631975642006312, 0.02938546533031123, 0.058461803676826615, 0.03951461233996919, 0.04052959216226425, 0.056107843560831885, 0.03313173859247139, 0.07837358343281917, 0.036563371773809195, 0.02196311155733253, 0.02087654629057007, 0.0819182503702385, 0.02432535488956741, 0.07258326413908175, 0.037809413126004596, 0.04154158303780215, 0.03565756484333958, 0.029093827586621046, 0.0300145249680749, 0.03596355699534927, 0.055321061850658486, 0.007022169086017779, 0.0178628906807197, 0.03558061897222485, 0.0198148357615407, 0.022831100338537778, 0.09840080913688455, 0.052432307574365816, 0.0857201363625271, 0.07502909789660148, 0.07212620973587036, 0.13455668331256934, 0.2807628358049052, 0.07037609150367123, 6.9249125719070435, 33.70943212509155, 66.85062667301723, 55.14715739658901, 37.59086261476789, 33.91792324611119, 29.686925411224365, 22.945097003664287, 6.581471800804138, 8.184137208121163, 18.127665996551514, 22.84976598194667, 19.094431400299072, 11.172180482319423, 9.860240731920515, 20.917237452098302, 19.167866911206925, 19.65794246537345, 28.906184128352574, 25.629054103578838, 29.41061987195696, 41.084034715379985, 31.74790702547346, 12.715895635741097, 5.775721779891422, 2.1409744875771657, 0.5981482150299209, 0.12647164000996522, 3.0270517638751437, 5.3705988100596835, 4.356805392674037, 0.2778268147792135, 0.6200190271650041, 0.2421686053276062, 0.06203177318509136, 0.11688881207789693, 0.4588503496987479, 1.0017111514295851, 0.9148698512996946, 0.9614621911730085, 0.4830394174371447, 0.5717662306768554, 1.0803149278674806, 0.2813780770770141, 1.2258210629224777, 2.0673650545733313, 6.285457696233477, 7.850342273712158, 7.313834513936724, 4.613408012049539, 1.6014555522373743, 2.457644283771515, 3.460776993206569, 7.93836031641279, 7.805872934205191, 6.127973735332489, 12.616754395621163, 13.789863058498927, 5.1126486744199475, 4.9666856953075955, 15.822069576808385, 18.197398117610387, 26.597342899867467, 38.25968926293509, 53.97711549486433, 39.9163030896868, 13.607093300138201, 0.3977704457938671, 0.03325559837477548, 0.07946547519947801, 0.05437100425894771, 0.04455942860139268, 0.04549062970493521, 0.04418077552691102, 0.09427034934716565, 0.09824107520814453, 0.04516406776383519, 0.12177589269621031, 0.11883030432675566, 0.018338591226243546, 0.04300278445173587, 0.03264704406527536, 0.10055865906178951, 0.08723244842674051, 0.03015204705297947, 0.06557319672512156, 0.012552419477807624, 0.07929041316466671, 0.027913802602727498, 0.037452768334852796, 0.03808126478855099, 0.026456801320559213, 0.050052437598684, 0.04040026678038495, 0.021108084491321018, 0.015151815888072764, 0.07907232522432293, 0.09147604036011867, 0.03251469920256308, 0.08647235349885055, 0.010743718228435941, 0.08780750006969486, 0.08418197889945336, 0.016052055438714366, 0.05084654409438372, 0.07990323885210923, 0.030443810325648104, 0.03583160229027271, 0.04634877294301987, 0.0756362374605877, 0.07620664792401449, 0.05393460785437908, 0.05985399468668869, 0.08678296647433724, 0.049164259007998874, 0.12800989246794156, 0.04388072394898959, 0.045276619760053496, 0.027389742866424576, 0.027563783706032803, 0.01814755647709327, 0.011916950228624046, 0.0435153939095991, 0.08858400875968592, 0.06493897004319088, 0.017750033343743, 0.08307439261781317, 0.004190839652437717, 0.08231806355927672, 0.018356238225741044, 0.01727035827934742, 0.08249199244060687, 0.07889952271112374, 0.07540951855480671, 0.05451815814844199, 0.09004033489951066, 0.0795718152076006, 0.023994552104600837, 0.014759792281048638, 0.07247465782399688, 0.011495272096778666, 0.05977517605892249, 0.08529225896511759, 0.03882937000266143, 0.06849416784409966, 0.062369873614183495, 0.125822621264628, 0.03778263474149363, 0.04307225625962019, 0.0340129011310637, 0.10296428283410412, 0.021142491305779134, 0.039758593176624606, 0.06298019550740719, 0.03317352617159486, 0.05139924479382379, 0.04358910316867488, 0.06628930901310273, 0.03422665323263832, 0.03360155623938356, 0.0032933000350437525, 0.03720827181158321, 0.022503973517034735, 0.06857136477317129, 0.08625610438840729, 0.03852756101904171, 0.08357778417744807, 0.12901979684829712, 0.06669412979057857, 0.04912387938903911, 0.05470997660553881, 0.09919194025652749, 0.13803714726652416, 0.8142708465456963, 2.930896294968469, 2.348039925098419, 30.18590681893485, 61.90637193407331, 77.25335148402623, 73.56353841509137, 56.252073832920615, 43.48051009859358, 37.235285077776226, 35.17895180838448, 33.27158096858433, 43.67915562220982, 41.68827090944563, 36.60379804883684, 38.64329235894339, 35.70635134833199, 40.75951910018921, 51.37329544339861, 49.44950948442732, 44.10958957672119, 44.56178528921944, 42.82085854666573, 50.780075618198936, 68.2023014341082, 55.52706405094692, 29.092340265001567, 16.21814295223781, 7.977033121245248, 2.4307862392493655, 6.855674641472953, 9.24637954575675, 10.95668123449598, 9.863264066832405, 4.879853623253958, 1.6628883757761546, 0.9774336027247565, 0.19422351089971407, 1.0877019486257007, 2.189099665199007, 3.7696821774755205, 2.962972653763635, 3.137012869119644, 2.205066191298621, 2.0582140598978316, 3.038605749607086, 4.600418789046151, 7.076129257678986, 10.062091980661664, 13.45976196016584, 13.331217680658613, 7.723463824817112, 6.9406875882829935, 12.37269457748958, 16.79602462904794, 20.161910942622594, 27.929048538208008, 30.024434157780238, 23.61482170649937, 27.416130781173706, 36.266938958849224, 35.19230972017561, 29.923508099147252, 23.872902120862687, 31.338574750082834, 37.14177622113909, 61.97864014761788, 68.32670198168073, 56.874642848968506, 33.14960534232003, 5.0734482407569885, 0.2881340874092919, 0.07652149495801755, 0.06829114338116986, 0.021160743897780776, 0.03099472987066422, 0.07066292861210448, 0.05002656505842294, 0.028692307882010937, 0.059666847943195274, 0.06585018150508404, 0.20589025558105536, 0.033940474303173165, 0.033499260299972126, 0.017768245223643522, 0.06934351048299245, 0.052424897971962175, 0.04554464787776981, 0.010491780720518103, 0.026421084933515106, 0.0412895887025765, 0.035289106757513115, 0.1203525433582919, 0.04535946888583047, 0.021447504671024423, 0.13413612730801105, 0.05333806700738413, 0.018502681349803294, 0.05453621396528823, 0.14273013972810336, 0.04118282800274236, 0.04568466018619282, 0.14043758703129633, 0.09533707424998283, 0.08798187678413731, 0.0507581411594791, 0.12309579258518559, 0.10725282092711755, 0.07117995872561421, 0.16136841103434563, 0.12274147516914777, 0.08169908355921507, 0.01964878467177706, 0.07835327487971101, 0.04533576426495399, 0.08148785560790982, 0.09403450414538383, 0.11851743182965688, 0.092241061452244, 0.03472056905073779, 0.10699598863720894, 0.121214377826878, 0.09510910005441733, 0.06489297215427671, 0.13515193494302885, 0.14613747117774828, 0.23006044647523335, 0.17085787254784787, 0.08643810105110918, 0.14772094120936735, 0.08326051477342844, 0.1806727594562939, 0.11881996345307146, 0.10367424759481635, 0.10845112734075103, 0.16025398511971745, 0.14861636316137655, 0.13822937623730727, 0.1827473667051111, 0.13069481482463224, 0.11732557149870054, 0.07183160340147358, 0.20085342228412628, 0.19809776943709168, 0.1663912529391902, 0.13609927839466504, 0.12753156599189552, 0.20208055286535195, 0.12182664711560522, 0.1728519241192511, 0.1462074417088713, 0.13569029819752487, 0.1939996350556612, 0.15712904637413366, 0.07733625266700983, 0.13766430584447725, 0.22550518305173942, 0.19659775921276637, 0.15850215697927134, 0.2127653080970049, 0.15587904916277953, 0.13475176213043077, 0.08760940177100045, 0.10010109575731413, 0.11814389830189091, 0.1153882590255567, 0.12662820518016815, 0.18625064300639288, 0.10389232196445976, 0.1386543427194868, 0.2449538287307535, 0.2217451219580003, 0.24116507917642593, 0.22375404701701232, 0.19468154917870248, 0.09612631904227392, 0.433805160756622, 0.5254368366939681, 0.21498961374163628, 11.176904388836451, 49.38784074783325, 103.73439543587821, 101.76981312888009, 79.08022744315011, 68.84373828342983, 66.39165646689278, 59.949557713099885, 35.98144095284598, 40.261826583317344, 41.21233320236206, 46.167062350681846, 57.96539885657174, 54.707339899880544, 56.826363291059224, 70.98824419294084, 84.87839494432721, 65.32048743111747, 69.12140914372036, 77.8151272365025, 78.44555119105748, 82.95592566898891, 56.9276784488133, 27.836312668664114, 12.49396322454725, 3.4198468923568726, 0.4844087011047772, 3.283921020371573, 7.732966354915074, 11.549331307411194, 8.176550643784658, 2.2956791690417697, 0.4261111707559654, 0.1739912386983633, 0.1274491511285305, 0.18158912099897861, 1.1151997702462333, 2.4471933245658875, 2.0746669598988126, 2.78096741437912, 2.6974993560995375, 2.6671993477003912, 3.243102307830538, 4.062531377588, 5.866823085716792, 9.038984503064837, 13.056937541280474, 18.56413619858878, 20.831382036209106, 25.684985365186417, 30.942523956298828, 39.166769640786306, 48.900438513074604, 55.01162583487374, 58.220123291015625, 49.96803617477417, 50.95459699630737, 39.57410083498274, 29.298684392656597, 37.758963857378276, 49.20995991570609, 54.86919123785836, 57.30771017074585, 80.03172070639474, 93.78720842088971, 62.47368540082659, 19.83065036364964, 1.025591458593096, 0.2047553514795644, 0.20426101157707827, 0.169216265635831, 0.08141577483287879, 0.11313136334397964, 0.10298731231263705, 0.18843365300978931, 0.09998170073543276, 0.19045560594115937, 0.22588273350681576, 0.3111625074275902, 0.1647742497069495, 0.18959027023187705, 0.12594272196292877, 0.12010048116956439, 0.13377271752272332, 0.1685738693922758, 0.12817170949918882, 0.08954823416258607, 0.14542671931641443, 0.12816246785223484, 0.1854734897081341, 0.12706970077540192, 0.15047822254044668, 0.23946735741836683, 0.11482480354607105, 0.12475728057324886, 0.16219937215958322, 0.2995864285954407, 0.27463471463748385, 0.1591652078287942, 0.14342068481658185, 0.12730275041290692, 0.20569029131105968, 0.13046458789280482, 0.21368138465498174, 0.21276920288801193, 0.13232804861451897, 0.32586950968418804, 0.22706020889537676, 0.2938673826200621, 0.20602343843451568, 0.16987791870321545, 0.10241287135119949, 0.19804822281002998, 0.20214020966419152, 0.3547992030424731, 0.38809206656047274, 0.3795947996633393, 0.25631125643849373, 0.1258479849036251], [0.0720432045470391, 0.0633578680987869, 0.01644089162748839, 0.03276867825271828, 0.05828940149928842, 0.020508627640083432, 0.00018324732731603684, 0.02472049297232713, 0.03901371778920293, 0.0354542825371027, 0.07126761866467339, 0.01090272527653724, 0.08088255487382412, 0.09460955578833818, 0.07680730747857265, 0.024808822964717234, 0.027438636403530836, 0.03268541522057993, 0.04589222065572228, 0.0224484150697078, 0.03242096298241189, 0.08076876455119678, 0.07161393615284137, 0.16469673386641911, 0.04930553339155657, 0.09332403726875782, 0.0418213396333158, 0.02960332596142377, 0.0395035623971905, 0.05927808130426066, 0.019100609800911376, 0.042413178232631514, 0.10836350132844277, 0.02889049778293286, 0.04707292926364711, 0.040530704959694824, 0.0316878466068634, 0.054456112906336784, 0.02070184048664357, 0.02689129443440054, 0.1124365638409342, 0.03657988053081291, 0.03439595789781638, 0.039634685896869214, 0.042339784492339404, 0.01569019440960671, 0.07637896189200026, 0.03951495500015361, 0.08431611848728997, 0.11522333430392401, 0.03608102837045278, 0.06975776968257767, 0.032054228375532796, 0.1342986093035766, 0.03210199724084564, 0.17335664560752256, 0.07833876780101232, 0.01569822826422751, 0.06782715435006789, 4.903116192136492, 26.465752703802927, 62.61683218819754, 58.33096095493862, 40.33020033155169, 31.620706353868755, 35.471387590680806, 34.504420689174104, 21.031802824565343, 7.276097110339573, 9.97243068899427, 20.57870384625026, 20.100884914398193, 26.04672769137791, 37.72903796604702, 29.189291954040527, 29.424158436911448, 34.399839878082275, 40.39643056052071, 47.62374176297869, 60.07445853097098, 56.09554481506348, 42.00704383850098, 27.625823940549576, 24.157337052481516, 23.434496845517838, 24.980603047779628, 24.72828790119716, 22.867647171020508, 23.878571850912913, 24.528035606656754, 27.86556805883135, 22.420518432344707, 16.220362901687622, 10.521896839141846, 7.388115099498203, 2.7555804337774004, 1.3082871692521232, 4.796634614467621, 6.015177982194083, 9.781498534338814, 14.197614618710109, 14.67135408946446, 11.671241794313703, 9.993746893746511, 10.386994089399066, 9.55746863569532, 15.971405472074236, 10.724394270351954, 16.02713176182338, 16.343458924974712, 16.0197753565652, 5.248604944774082, 4.310116972242083, 12.07589532647814, 11.432065691266741, 12.49245546545301, 17.648839575903757, 22.77417826652527, 33.203273228236604, 43.99442318507603, 39.53539936883109, 18.56367588043213, 1.5156270606177193, 0.07173407756324325, 0.043230534730745215, 0.10606678921197142, 0.1209923747394766, 0.05169237870723009, 0.0468487786129117, 0.04664133010166032, 0.052379612544817586, 0.055213938134589365, 0.051228871435991356, 0.049485599622130394, 0.010487027582712471, 0.02138415494534586, 0.08201080254678215, 0.02084060598696981, 0.07594615833035537, 0.06787897406944207, 0.09568290997828756, 0.03971732467679041, 0.04419128942702498, 0.054147348938775916, 0.1374435376908098, 0.0670812272333673, 0.04987519407378776, 0.08578163877661739, 0.10457861942372151, 0.039318346085825136, 0.016952239010216932, 0.04599782445334962, 0.044398276534463675, 0.09319962108773844, 0.04558460680501802, 0.15450131094881467, 0.08373675814696721, 0.09352222377700464, 0.05986892245709896, 0.09811388381889888, 0.039803132215248685, 0.04522821646449821, 0.05879747495055199, 0.09809665581477539, 0.17339258082211018, 0.16930982204420225, 0.11899982951581478, 0.022645278434668268, 0.03720269086105483, 0.019223823278610195, 0.026336775261110494, 0.03449830472735422, 0.03167628776282072, 0.034535417200199196, 0.05052405675607068, 0.08912411584917988, 0.04939044526379023, 0.0055000462536034835, 0.02495462487318686, 0.025398483466623083, 0.10231126073215689, 0.040108669748795886, 0.027184764222641076, 0.025178639816918542, 0.014407259412109852, 0.07387681651328291, 0.03539898871843304, 0.03621558865000095, 0.12154648000640528, 0.03365683648735285, 0.011240522909377302, 0.04765901727867978, 0.046958826814911196, 0.13363255932927132, 0.024062293648187603, 0.016573938773944974, 0.11131221095898322, 0.052085599928562126, 0.07517659783895526, 0.09774594820503678, 0.023326271446421742, 0.15675197089357035, 0.027504898740776947, 0.11268072109669447, 0.04880871344357729, 0.034647677426359484, 0.03471206022160394, 0.03866429261064955, 0.04376404306718281, 0.0519263172256095, 0.026358561324221746, 0.021904321586979286, 0.06962444433676344, 0.0855459767792906, 0.038052365982106755, 0.023758844306160296, 0.042746084476155896, 0.1140360880110945, 0.04639455030805298, 0.10334652196615934, 0.07084494563085691, 0.042956525326839516, 0.03419034482379045, 0.04870918931971703, 0.0376550837286881, 0.09470433355974299, 0.06536051670887641, 0.04102242910968406, 0.05229908740147948, 0.12420044759554522, 0.09524144830980472, 0.05760420326675687, 0.21671408335013048, 1.612125705395426, 2.0719072222709656, 24.16327428817749, 55.558539390563965, 82.77204854147774, 83.30070917946952, 64.63440145765031, 46.86490815026419, 33.74797030857631, 38.493530886513845, 44.08873803274972, 37.67814588546753, 36.44973911557879, 42.16253410066877, 42.579314844948904, 51.023946966443745, 68.82960564749581, 54.32358046940395, 56.53887462615967, 67.85815020969936, 68.23171315874372, 67.18238231113979, 76.21416500636509, 74.36549254826137, 73.83980573926652, 66.50306388310024, 61.58942290714809, 57.71830701828003, 54.03259686061314, 53.75552354540144, 56.122048718588694, 49.490660190582275, 47.380537441798616, 50.5473769732884, 45.382225104740684, 38.853114059993196, 33.151463985443115, 39.03441687992641, 33.730408736637656, 24.507114580699376, 27.351251976830618, 28.943812097821915, 35.59948457990374, 41.35371862139021, 46.37237467084612, 41.623826367514475, 35.484849725450786, 22.728459119796753, 27.602351188659668, 36.78653914587838, 36.61444616317749, 40.86995029449463, 42.99250684465681, 38.46984447751726, 27.771981034960064, 34.42935235159737, 40.50662899017334, 30.937767914363317, 20.03950105394636, 30.136143820626394, 37.73126138959612, 49.13344635282244, 63.193087986537385, 60.98062869480678, 41.639456340244834, 8.860580818993704, 0.7773100669894899, 0.01603053739693548, 0.03863723263410585, 0.15545731250728878, 0.0655967758170196, 0.028687659917133193, 0.06819555815309286, 0.05478480884007045, 0.027191474933975508, 0.026908573328650424, 0.023375894408673048, 0.019257711013779044, 0.033492654761565585, 0.06159929532025542, 0.03592026985383459, 0.03597211671460952, 0.030940182440515076, 0.08671144209802151, 0.13685503069843563, 0.051392649433442524, 0.037710241840354035, 0.10274029163909809, 0.10115429745720965, 0.0607790821897132, 0.06594190586890493, 0.11932134654905115, 0.03447109208043132, 0.041387084006730995, 0.060585672567997656, 0.02148334149803434, 0.07623389789036342, 0.07393102467592273, 0.06318332853593997, 0.031024931464344263, 0.13988584306623253, 0.08009104377457074, 0.10712413676083088, 0.07967510859348945, 0.03186827924634729, 0.03203559919659581, 0.058405824537788115, 0.019252523613561476, 0.11325518919953279, 0.19702245428093842, 0.003104496605893863, 0.036791152586894374, 0.021531531055058752, 0.043130895255931785, 0.05060101619788578, 0.05648799959037985, 0.031086807072694813, 0.07553705599691186, 0.06092056352645159, 0.19386220457298414, 0.14723547654492514, 0.1886068151465484, 0.13618294176246437, 0.16537988292319433, 0.15345157656286443, 0.10344894682722432, 0.11045295492346797, 0.13107184959309442, 0.08995086327195168, 0.21773104449468, 0.17566518458936894, 0.1863723314766373, 0.1294637080281973, 0.15738428410674843, 0.09967980693493571, 0.09183035777615649, 0.1516696350382907, 0.09271559491753578, 0.10043904012335197, 0.17338209067072186, 0.16259571803467615, 0.2757894726736205, 0.23994667455554008, 0.15968915899949415, 0.4274613468774727, 0.17434087422277245, 0.22206058645887033, 0.2087143183286701, 0.31909121626189774, 0.16480429523757525, 0.19390027038753033, 0.15991064640028135, 0.13864772021770477, 0.11877385021320411, 0.1629594128046717, 0.08603825393532004, 0.19495989781405243, 0.1194042092455285, 0.14503550316606248, 0.24280040285417012, 0.26428352722099846, 0.10630018490233592, 0.20178214673485073, 0.14036651727344307, 0.19065979069897107, 0.1361459344625473, 0.11398333869874477, 0.1923474022852523, 0.2111388596573046, 0.18489075026341847, 0.12350992964846746, 0.2418040691741875, 0.31783855919327053, 0.24010466464928218, 0.224572020981993, 0.12861832124846323, 0.2778727651706764, 0.2192388985838209, 7.865824597222464, 42.645902906145366, 105.12687696729387, 114.32249123709542, 90.54695074898856, 67.4520627430507, 65.01580892290387, 66.46714864458356, 55.819044726235525, 32.91523218154907, 31.032048021044048, 42.59595578057425, 48.15718970979963, 59.91262108939034, 75.39625780923026, 67.45704460144043, 70.03265149252755, 83.72095707484654, 88.07234982081822, 93.74298313685826, 101.41032028198242, 95.03429194859096, 90.0636271068028, 72.31546129499162, 65.08167784554618, 61.928494998386924, 55.946575437273296, 53.73390422548567, 54.451191084725515, 48.10992806298392, 39.92764949798584, 45.928596700940815, 38.14150387900216, 30.171468462262833, 24.316864218030656, 31.019339765821183, 28.489526714597428, 19.790111098970684, 25.00847922052656, 30.39183405467442, 39.429522718702046, 50.13022102628435, 59.95540809631348, 63.795274462018696, 63.4498656136649, 45.989761693137034, 45.30595472880772, 55.55460671016148, 56.29880741664341, 61.28550175258091, 64.77485929216657, 50.83940281186785, 33.582273142678396, 34.61532436098371, 50.51715925761631, 49.765391962868826, 44.05023111615862, 53.20960358210972, 55.29550838470459, 75.34784970964704, 89.81322792598179, 72.80387101854596, 29.363702160971506, 2.449742010661534, 0.2025106219308717, 0.19277532718011312, 0.19453813401716097, 0.24197199302060263, 0.13967040819781168, 0.11296788390193667, 0.11380160666470017, 0.1663687527179718, 0.10777460078575782, 0.1482178188328232, 0.12002012905265604, 0.11261431287441935, 0.18734540497618063, 0.133632111496159, 0.12320686876773834, 0.190299352897065, 0.20917722848909243, 0.18670754134655, 0.2034792442406927, 0.1805707620722907, 0.14895006668354782, 0.3823239489325455, 0.1670666259846517, 0.15715162801955426, 0.12309405553553786, 0.16507811125900063, 0.09541293446506773, 0.1589763443917036, 0.13012617533760412, 0.1818625706114939, 0.19655967982751982, 0.24629331114036696, 0.28920055446880205, 0.23595143322433743, 0.2263510176645858, 0.21067038550972939, 0.23458613934261457, 0.11187199556401797, 0.09860529245010444, 0.19346394522913865, 0.3098279376115118, 0.4410713479987213, 0.26256775643144337, 0.2748908208949225, 0.12319475013230528, 0.1633278980318989, 0.10903698126120226, 0.13038224088294165, 0.14418519022209303, 0.16112298491810048, 0.12614616033221993, 0.22647003270685673, 0.22013795748353004], [0.07190701578344617, 0.06365457110639129, 0.0068508012502986404, 0.053660856293780465, 0.08264323111091341, 0.0866949740531189, 0.03042559844574758, 0.0975617938009756, 0.049579047464898655, 0.07233494067830698, 0.0922689763829112, 0.04432753586609449, 0.0357505784236959, 0.01362627832817712, 0.03520198625379375, 0.019231273593114953, 0.037333390276346884, 0.03116327796929649, 0.0504346835160894, 0.02293446327426604, 0.05639905382746032, 0.10483161120542459, 0.0451203870720097, 0.08000674258385386, 0.06889865613941636, 0.016572445996903946, 0.018525261298886368, 0.053174794518521855, 0.17231175596160547, 0.1456934514322451, 0.03261740904833589, 0.15176369356257574, 0.06538134094859872, 0.023448908169354712, 0.027900464300598418, 0.03529001260176301, 0.05700961660061564, 0.025729477937732424, 0.05010696806545768, 0.049979908990540674, 0.09335123295230524, 0.051172817658100805, 0.03993690200150013, 0.061198328621685505, 0.08828086645475455, 0.05854191152112825, 0.07232209601040397, 0.02682756812178663, 0.024919692194089293, 0.056400054666612826, 0.03214136244995253, 0.06871524812387568, 0.1365995622639145, 0.033170320093631744, 0.027624246265207018, 0.015045099293014832, 0.04603239920522485, 0.08745430902178798, 0.04940562748483249, 0.05213322290884597, 0.05852381499218089, 2.746503697974341, 16.615461792264664, 40.251803806849885, 60.564938817705425, 69.50649220602853, 63.987475531441824, 54.23582819529942, 33.79125411169869, 35.84001384462629, 36.371669156210764, 37.21088995252337, 39.77195773805891, 32.7895462172372, 39.3778315952846, 37.08288328988211, 35.157155309404644, 40.12870257241385, 53.650859355926514, 60.70903056008475, 80.97473021915981, 81.79887689862932, 77.44932542528424, 75.6836769921439, 66.50133378165108, 66.32497460501534, 59.92053508758545, 67.13377271379743, 76.42497335161481, 86.57090663909912, 81.95024340493339, 63.80145141056606, 43.773213386535645, 47.693824768066406, 20.73459189278739, 8.043351071221487, 28.902550220489502, 35.50891828536987, 41.578993116106304, 43.11618477957589, 39.712811197553364, 35.01206302642822, 36.08248513085501, 31.285240377698624, 13.204726593835012, 11.809775846345083, 9.531161887305123, 17.519066333770752, 17.262036834444316, 26.270551749638148, 27.162408624376567, 15.453439848763601, 16.24100078855242, 21.108160052980693, 21.664014203207834, 21.02044599396842, 34.81897953578404, 47.351278577532085, 39.03944737570626, 14.066270215170723, 1.9321062096527644, 0.06389658419149262, 0.028868947510740588, 0.03953916512961898, 0.01661342103034258, 0.00988599653023162, 0.11013024366859879, 0.03456917092470186, 0.07000758592039347, 0.04064764368480869, 0.07795393666518585, 0.015030917911125081, 0.05436250560783914, 0.008350035824280764, 0.06498963625303336, 0.11889556582484927, 0.05534017618213381, 0.021355030526007925, 0.03780520281621388, 0.0808168523279684, 0.022359567694365978, 0.024677918292582035, 0.020681223200101937, 0.034070138952561786, 0.01193275161287082, 0.056011203210800886, 0.14113685808011464, 0.030297066949840103, 0.058546674836959155, 0.12526789174548217, 0.008285250148868986, 0.12535584345459938, 0.020126625995284746, 0.03619903239554592, 0.08827199121671063, 0.02948815142735839, 0.10006704687007836, 0.08162815629371575, 0.04391324952510851, 0.019924909408603395, 0.106661606580019, 0.10117019553269659, 0.15887753612228803, 0.06263687714402165, 0.20919473469257355, 0.14229044903601917, 0.14361679500767163, 0.0482880022775914, 0.014540153888187237, 0.06222517602145672, 0.09100262647760765, 0.04916538876880493, 0.08335378619709186, 0.030984802903341394, 0.013686354122390705, 0.06158799771219492, 0.03409710054152778, 0.011021361187366503, 0.021155522570812275, 0.034903166216931174, 0.06172874623111316, 0.03156799018116934, 0.0061839281281988534, 0.027053482963570526, 0.07549829129129648, 0.06199040969035455, 0.050030945001968315, 0.013781125108445329, 0.08485767085637365, 0.04930193715595773, 0.07765095042330877, 0.05699045477168901, 0.003784747894055077, 0.05669295787811279, 0.07548323459923267, 0.048990004429859776, 0.06567635440400668, 0.1074844388557332, 0.10727597254195384, 0.05025817959436348, 0.05360507392989738, 0.07153044920414686, 0.07418619455503565, 0.018973594830770577, 0.19433141153837952, 0.08111697515206677, 0.038345750953469954, 0.08620756877852337, 0.05034051981887647, 0.0548391052122627, 0.0454530320795519, 0.0542463030932205, 0.04084814739014421, 0.083538157732359, 0.028374132633741413, 0.03900044225156307, 0.032933874388358424, 0.10064810354794775, 0.022207945651773895, 0.21433177404105663, 0.018072088115981648, 0.10001897944935731, 0.11142307679568018, 0.032851093116083314, 0.024973176020596708, 0.05055381051663842, 0.03729110397398472, 0.06116824916430882, 0.11523237239037241, 0.051890422723123004, 0.04932015582120844, 0.11910844940160002, 0.07347481844148465, 0.06889140938541718, 0.12486972739653927, 0.9707809197051185, 2.3015532195568085, 19.757916620799474, 48.673402650015696, 66.62494918278286, 78.44220215933663, 78.00925990513393, 65.59391294206891, 52.094719954899375, 33.72650037493025, 32.82513836451939, 40.267760344914024, 44.93682820456368, 51.40067829404558, 53.446359974997385, 63.54657064165388, 65.37769889831543, 68.46308817182268, 72.24495097569057, 86.50246688297817, 85.02646105630058, 94.30362633296421, 107.6656653540475, 105.11418260846818, 116.7960638318743, 96.45887415749687, 90.56780229296002, 79.52881009238106, 81.75763239179338, 96.12207412719727, 110.72771562848772, 107.9844834463937, 105.04556914738247, 86.16167163848877, 100.75969791412354, 73.08682945796421, 61.1962035042899, 90.15730272020612, 92.75662381308419, 90.7731146131243, 94.31699466705322, 87.7581592287336, 76.6217393875122, 75.9038028717041, 78.30155672345842, 50.51113516943795, 47.76428992407662, 44.665591376168386, 49.152918679373606, 50.75088276181902, 53.91747563225882, 43.366441522325786, 26.797510078975133, 24.22354643685477, 36.60760913576399, 36.30402149472918, 38.498220920562744, 50.48745918273926, 61.1340240750994, 61.36519759041922, 36.05603681291853, 10.031210712024144, 1.3917566388845444, 0.09476381393947772, 0.019075851754418442, 0.018644644446404915, 0.019121065935386077, 0.07509267662784883, 0.06393135911119835, 0.10955238967601742, 0.038536236089255126, 0.046519475390336344, 0.022189340221562555, 0.01438331900031439, 0.01349671630721007, 0.020702323942844356, 0.0994204572801079, 0.012180658622777887, 0.03862781796072211, 0.03914283621790154, 0.009407118744482952, 0.041887700358139615, 0.0611539999289172, 0.08426081788327013, 0.04282146632405264, 0.021394977578893304, 0.005632746074947396, 0.06642872081803423, 0.06380564014294318, 0.028715466282197406, 0.08461442962288857, 0.03314079024962016, 0.04730157860155616, 0.010838810670455652, 0.009887255212691213, 0.05969312081911734, 0.032060379295476844, 0.15710259707910673, 0.1640633214265108, 0.03960151910515768, 0.08037657809576818, 0.04120167092021022, 0.08018346024411065, 0.022881395050457547, 0.10088925489357539, 0.11340019891836814, 0.17454182915389538, 0.1261576818568366, 0.014263467663632972, 0.054598031898162196, 0.10120053283338036, 0.10402135896895613, 0.050038615840354135, 0.008790028464448239, 0.029157806653529406, 0.02806590640518282, 0.024500284610050063, 0.1477112788707018, 0.2109953495008605, 0.1995199109826769, 0.1413381387080465, 0.16298251013670648, 0.18581673343266758, 0.1090616120823792, 0.17313571460545063, 0.15650848538747855, 0.19821725945387567, 0.21664000089679444, 0.1270614226481744, 0.09072767051735095, 0.14710329792329244, 0.1151566207408905, 0.13065374988530362, 0.09559833058821303, 0.1378535492611783, 0.11870330971266542, 0.1230232979037932, 0.21990622420396122, 0.1893360638724906, 0.16003095065908773, 0.16037367869700703, 0.20201212939407143, 0.09499072283506393, 0.16673414382551396, 0.13230933461870464, 0.493267220045839, 0.25831339614731924, 0.09456966471459184, 0.22952206965003694, 0.20055844954081944, 0.17479169288916246, 0.18071826201464447, 0.18267525200332912, 0.16888516768813133, 0.1967217954141753, 0.14142409552420887, 0.18954362773469516, 0.14696704809154781, 0.25780946175966946, 0.19349561924380915, 0.35156318811433657, 0.1755655077951295, 0.22137811593711376, 0.22741848895592348, 0.25020539121968405, 0.14743155959461415, 0.15301396218793734, 0.17175151673810823, 0.14120899992329733, 0.17322164428021225, 0.1262623933809144, 0.17787710018455982, 0.19271111062594823, 0.14444863822843346, 0.14134641683527402, 0.1502274088561535, 0.2671875756766115, 0.36269341515643255, 5.7951836841447015, 33.033931732177734, 74.43588474818638, 104.01471355983189, 115.13879340035575, 100.81626319885254, 87.15556280953544, 66.0038913999285, 68.63834953308105, 67.33791773659843, 68.66304343087333, 75.99840259552002, 71.65093558175224, 86.09997163500104, 77.48405252184186, 75.28512832096645, 78.30676787240165, 83.80641296931675, 82.24268613542829, 93.91948127746582, 109.44965703146798, 114.79720606122697, 119.41400609697614, 104.64071151188442, 105.49988406045097, 96.64358506883893, 100.40811211722237, 111.81048120771135, 125.47961671011788, 119.53853171212333, 108.71900531223842, 89.80206217084611, 112.65149116516113, 105.53744602203369, 85.91772733415876, 98.24415125165666, 106.08523505074638, 98.58325113568986, 100.3038682937622, 101.00653961726597, 91.55495371137346, 87.10310391017369, 81.97711208888462, 47.99424055644444, 52.26441928318569, 49.3051815032959, 61.728602273123606, 65.16361100333077, 78.84300204685756, 68.43096664973667, 51.388432094029014, 45.69268798828125, 61.80420562199184, 57.205926009586875, 60.442476817539756, 84.01686695643834, 87.87220001220703, 67.79758276258195, 23.815980740955897, 3.0115420818328857, 0.22810173300760134, 0.14999225576009068, 0.13987117313912936, 0.09734262698995215, 0.1600306656743799, 0.1653398900691952, 0.13369600235351495, 0.2135080596698182, 0.1286077903849738, 0.1923976953008345, 0.1296615552689348, 0.12936412622886045, 0.21002718859485217, 0.09185376044894968, 0.20493479685059615, 0.12274604849517345, 0.1084525522642902, 0.25695887740169254, 0.33481292692678316, 0.1205912519778524, 0.15701833660049097, 0.13538794299321516, 0.11860498998846326, 0.0819231765344739, 0.19455933145114354, 0.2469847383243697, 0.200174710846373, 0.13210842039968285, 0.20801374449261598, 0.09646929135279995, 0.18204372589077267, 0.09293551490242992, 0.1418079970670598, 0.1664677509771926, 0.10656602813729218, 0.16330196442348616, 0.15467030688055924, 0.12833974191120692, 0.1860526329172509, 0.14016355387866497, 0.340313050363745, 0.2439898747418608, 0.20641286325241837, 0.2676965312233993, 0.3364690952003002, 0.2107420116662979, 0.1865891641271966, 0.15753649308213166, 0.11543228237756661, 0.27573543414473534, 0.2090186412845339, 0.21707899948315962, 0.14304099019084657, 0.12000233786446707, 0.17996791084962233], [0.06572798413357564, 0.008662412142647164, 0.1271446788949626, 0.07588004187813827, 0.030146276112645864, 0.05225470781858478, 0.03816296040479626, 0.08900769959603037, 0.06753097381442785, 0.08245506656489202, 0.03333497679393206, 0.02300779933908156, 0.029841491752969365, 0.029399870628757135, 0.08168850519827434, 0.044615607908261676, 0.04443567738469158, 0.022413969239486114, 0.044418259390762875, 0.011919944264393832, 0.027093433409131, 0.06820465730769293, 0.0652707058138081, 0.04726617264428309, 0.028005494736135006, 0.015155300165393522, 0.036534147270556004, 0.022285564968894635, 0.05094702495262027, 0.017970850691199303, 0.06073011910276754, 0.005630614626820066, 0.023030548921919296, 0.01671119623019227, 0.05790241262210267, 0.1007567166483828, 0.020622229669243097, 0.0209994289824473, 0.08887430639671427, 0.054942028796566386, 0.027469803213274906, 0.06015898260687079, 0.040103875898889134, 0.014979286485218575, 0.07006523425557784, 0.06473362499049731, 0.02152607393717127, 0.0673473079555801, 0.12220847234129906, 0.05832015949168375, 0.039185729809105396, 0.041599380650690625, 0.03600621988464679, 0.06441480174128499, 0.01708821573161653, 0.09462004593972649, 0.11645207979849406, 0.05371128501636641, 0.0724456843787006, 0.042552590037563016, 0.08662818585123334, 0.0981778357444065, 0.021495678961010914, 0.29241740756801193, 7.077537136418479, 31.515885829925537, 63.32564571925572, 73.61011219024658, 68.61182131086076, 59.38671888623919, 53.38299935204642, 57.653139863695415, 57.71676104409354, 55.33048561641148, 57.7772798538208, 58.163054261888774, 61.21142700740269, 58.562245641435894, 61.93488039289202, 58.20213093076433, 70.65413311549595, 65.18112046377999, 66.5718857901437, 53.968339920043945, 51.96661949157715, 71.49496936798096, 79.4444659096854, 65.15011065346854, 69.25370979309082, 60.62394986833845, 62.97832611628941, 45.27264853886196, 40.9141651562282, 55.535318510872976, 72.11535317557198, 83.19251877920968, 37.208881923130576, 38.0450177192688, 33.516636984688894, 34.499900885990684, 49.780518191201345, 53.77892507825579, 53.674424171447754, 41.19887454169137, 36.78750147138323, 39.437839712415425, 38.369609764644075, 33.98478923525129, 30.524103437151226, 33.63990844999041, 29.041918924876622, 33.904468059539795, 28.04426530429295, 33.40866545268467, 39.43821838923863, 40.93891116550991, 21.10534255845206, 4.649465688637324, 0.735200509428978, 0.27333371873412815, 0.07551988227558987, 0.00987506702741874, 0.023659958005217568, 0.0896934067298259, 0.10384103150240012, 0.031477456646306176, 0.11327564703034503, 0.02130695801627423, 0.05905740136014564, 0.03399501494797213, 0.0652930974694235, 0.025663856816078936, 0.06436142139136791, 0.016607741692236493, 0.09799287388367312, 0.05037933202194316, 0.06335945587073054, 0.048935694486967156, 0.07599540640200887, 0.07136486630354609, 0.02134331561891096, 0.06158249479319368, 0.015473424523536648, 0.05247927576835666, 0.06280830901648317, 0.06055954218442951, 0.023452160048431585, 0.023827858102907027, 0.04940594978896635, 0.0309387134121997, 0.02983518476997103, 0.025508738621803265, 0.12588510076914514, 0.01516212962035622, 0.04490378851603184, 0.037748158377196105, 0.005181682711866285, 0.039291272538581064, 0.11137222059603248, 0.026460104089762484, 0.05590469017624855, 0.1000601461689387, 0.05785390415361949, 0.08555205645305769, 0.09931921306997538, 0.02278756892441639, 0.12111153905945164, 0.03450379068297999, 0.0549896619548755, 0.07907215559056827, 0.13129359483718872, 0.07172999956778117, 0.12027699526931558, 0.004368755351086813, 0.020904283105794872, 0.026941765565425158, 0.05333378205874136, 0.022928331014035002, 0.0599677510825651, 0.026471959792875817, 0.056329836470208, 0.04305496040199484, 0.0424162961010422, 0.04622066213882395, 0.07909950733716999, 0.027664700523018837, 0.08659857458301953, 0.04904425669727581, 0.052511757239699364, 0.04178232726241861, 0.06990372935043913, 0.01662552948775036, 0.06155207606830767, 0.0651701537093946, 0.04077105902667556, 0.027393739437684417, 0.03653725156826632, 0.03815860081730144, 0.018264259411288158, 0.04703027655237487, 0.012049027070003961, 0.016758303523861935, 0.02966105572081038, 0.04732213142727103, 0.059463239940149445, 0.05474371336666601, 0.012160515462580537, 0.0367913900741509, 0.040394536552152464, 0.09063925061907087, 0.05673141385029469, 0.0735892601577299, 0.04921830432223422, 0.01799216856514769, 0.054505612035947185, 0.03336376364209822, 0.029111706984362433, 0.025647154676594903, 0.08106157955314432, 0.017562867940536568, 0.012277773099153169, 0.11874235261763845, 0.060149279556104114, 0.01791715482249856, 0.17175523511001042, 0.04560313081102712, 0.009236602894296604, 0.08186117878982, 0.01411106700210699, 0.07052252614604575, 0.016905915424493805, 0.09024592422481094, 0.057559460667627196, 0.05363134680581944, 0.07022081555000373, 0.12579105581556047, 0.04682938947475382, 0.581948707146304, 0.44552234773124966, 6.32780088697161, 30.008095468793595, 66.65015029907227, 92.81039592197963, 92.5203503199986, 80.47384847913469, 72.4340739931379, 61.598302704947336, 62.23805809020996, 62.01609788622175, 59.88482134682791, 67.01784896850586, 69.86043344225202, 68.61130019596645, 70.92794077736991, 71.78320843832833, 66.44731848580497, 80.6211016518729, 64.11168152945382, 63.91319234030587, 53.40988540649414, 53.396246092660085, 69.92406504494804, 77.55732127598354, 65.87034702301025, 75.04080186571393, 59.422099113464355, 60.347481046404155, 50.97058480126517, 43.38817548751831, 63.76758589063372, 109.7277934210641, 129.3488322666713, 55.21073688779558, 58.87497016361782, 45.55582584653582, 45.89447757175991, 62.81561320168631, 71.00635119846889, 66.53571346827916, 61.073755400521414, 51.6710535458156, 65.57276957375663, 51.61131988252912, 52.82152584620884, 47.72174263000488, 49.39552198137556, 49.23525135857718, 49.68911116463797, 52.37368665422712, 57.67497110366821, 58.040557520730154, 56.13563939503261, 43.46802071162632, 20.95988723209926, 5.848528044564383, 1.4536027716738837, 0.28492038271256853, 0.09274359127240521, 0.011176610847802033, 0.04062053621081369, 0.06058620182531221, 0.033377185064767084, 0.0340420170687139, 0.06259407515504531, 0.02266765821592084, 0.015707340989527956, 0.08422481481518064, 0.03228117798322013, 0.05803035718521901, 0.028856537105249505, 0.03652566897549799, 0.039621875155717134, 0.055687182383345704, 0.05353740363248757, 0.021773793501779437, 0.07330140524676867, 0.08094531257769891, 0.01564443570428661, 0.04818745695852807, 0.0019039111627664948, 0.05306697191138353, 0.005260609481151083, 0.04443453066051006, 0.03079178004658648, 0.024565585123907243, 0.03860987749482904, 0.051954985330147405, 0.040094298377100906, 0.07639631203242711, 0.01796002296863922, 0.046382275609565635, 0.02681735616975597, 0.04778101448235767, 0.04397234653255769, 0.08619395736604929, 0.10855281259864569, 0.0467670456772404, 0.031594565005174706, 0.09751279678727899, 0.061084232958299775, 0.1188492083123752, 0.05993623313094888, 0.07509541112397398, 0.07859509118965693, 0.03228304395452142, 0.06031593454203435, 0.12416790505605084, 0.05448991412829075, 0.06443650807653155, 0.07997807447931596, 0.04654270503669977, 0.05010178066524012, 0.14970854669809341, 0.12275067610400063, 0.2489068651837962, 0.1414471792855433, 0.15126476676336356, 0.19162249618342944, 0.0847741567662784, 0.11535009821610791, 0.1955161608223404, 0.16373386553355626, 0.1987944891942399, 0.09698490332812071, 0.06558118308229105, 0.17815034623656953, 0.15964121371507645, 0.11087184173188039, 0.10287287059639182, 0.10275492763945035, 0.13873683900705405, 0.12847468895571573, 0.12807773239910603, 0.20186943347964967, 0.08304037765732833, 0.1161213211183037, 0.10820346884429455, 0.15072839840182237, 0.10282067768275738, 0.091034585476986, 0.13259144233805792, 0.12989498488605022, 0.15415115973779134, 0.1252795218357018, 0.14827564358711243, 0.18722124663846834, 0.1988548245280981, 0.14461489287870272, 0.1341846968446459, 0.17023746083889688, 0.1888379648860012, 0.15430015245718615, 0.10827844696385519, 0.18348473070987634, 0.18769489122288568, 0.15598876827529498, 0.3316481853170054, 0.19815893258367265, 0.13065100860382828, 0.199351485020348, 0.3457493915089539, 0.13606470025011472, 0.15597852239651339, 0.177131091643657, 0.2681555194514138, 0.15197166454579147, 0.10829201766422816, 0.18180402661008493, 0.1881110503205231, 0.1474234171743904, 0.14532674396676676, 0.1965554729104042, 0.1965587298784937, 0.2015148853617055, 0.12449723881270204, 1.0236639848777225, 12.06198763847351, 49.88445629392351, 102.42664023808071, 124.18340247017997, 123.52882657732282, 112.29868248530796, 98.4898465020316, 95.58550643920898, 93.4587253843035, 89.1103481565203, 91.20542458125523, 95.10007749285016, 97.47873769487653, 90.83636406489781, 97.14131927490234, 87.58502401624406, 102.46493870871407, 88.47428226470947, 84.85195704868862, 74.3106712613787, 71.42705072675432, 94.70293235778809, 96.14988776615688, 84.27536078861782, 99.27291543143136, 82.49273790631975, 89.69610909053257, 64.69556644984654, 52.54229164123535, 70.46562153952462, 128.41127014160156, 134.91941152300154, 63.09276294708252, 76.83020618983677, 69.43026351928711, 68.96768024989537, 84.91833318982805, 88.54730088370187, 93.94880267551967, 82.2945613861084, 77.77753053392682, 88.32511833735875, 77.93131501334054, 76.07199096679688, 70.37142481122697, 70.1874920981271, 70.75342982155937, 78.83942372458321, 77.0069614137922, 90.64498288290841, 94.07082693917411, 75.6591567993164, 37.64438806261335, 9.471066917691912, 1.224942984325545, 0.3447426626724856, 0.21505870217723505, 0.1665402999413865, 0.1126572098582983, 0.1263958476483822, 0.13284111608351978, 0.07198505409594093, 0.13820986157017096, 0.19235470332205296, 0.16994540579617023, 0.12596265732177667, 0.28797042476279394, 0.09184562481407609, 0.1364123137401683, 0.09944768689040627, 0.14699257457894938, 0.13093652256897517, 0.1677967296647174, 0.14022265427878924, 0.16405019855925015, 0.20752632564732007, 0.16818862435008797, 0.2094004936516285, 0.09340995337281909, 0.1620687134563923, 0.1954593810119799, 0.14644186198711395, 0.10389753989875317, 0.1356949665184532, 0.08739189058542252, 0.2779253380639212, 0.09947155775236231, 0.11527934058436326, 0.2546347863972187, 0.1451682788985116, 0.1243074932800872, 0.15358946844935417, 0.0961244802123734, 0.09156325246606555, 0.16137286222406796, 0.13439473057431833, 0.2264766687793391, 0.2180553028093917, 0.23171208213482583, 0.19971949527306215, 0.19165919135723794, 0.1947460507175752, 0.2261684238910675, 0.28553242129938944, 0.2121487097548587, 0.2011931919093643, 0.2212559524923563, 0.16460712653185638, 0.24683939612337522, 0.18185210760150636, 0.1312696018389293, 0.15294838856373513], [0.024522681354678104, 0.012834866464670216, 0.09562794864177704, 0.030959941380258118, 0.12146280306790556, 0.03222498171297567, 0.01906464744492301, 0.02744739968329668, 0.029127272577690225, 0.11516298539936543, 0.08347489112722022, 0.035813217383942435, 0.04646023928320833, 0.024762400991416404, 0.04268238700128027, 0.011338738308820342, 0.014182976447045803, 0.009076493226790001, 0.04550442771453943, 0.02091618630635951, 0.07404149696230888, 0.10189096257090569, 0.037728837092540095, 0.02861836113567863, 0.042703309628580294, 0.00759408759352352, 0.06189518408583743, 0.04079418010743601, 0.04889544718233602, 0.011299125434431647, 0.03208822976531727, 0.04237934986927679, 0.045704609115741084, 0.041457054537854025, 0.01932638045400381, 0.06623885993446622, 0.10143791152430431, 0.055171248103891096, 0.06371492679630007, 0.0231351688437696, 0.03931139110188399, 0.11766411976090499, 0.0442491616787655, 0.050939910512949736, 0.05187638383358717, 0.007500679614687604, 0.005989287813593234, 0.04215096855270011, 0.034274476380752664, 0.08491970931312867, 0.03608591721526214, 0.04159651384023683, 0.08032795427633183, 0.061945436389318535, 0.13096749090722629, 0.08362506449754749, 0.04004686538662229, 0.02433189596714718, 0.014055364366088594, 0.013831564857225333, 0.15711433573492936, 0.10767798418445246, 0.07431596437735216, 0.026302017304780226, 0.1895983719399997, 0.053188131124313386, 1.0267902399812425, 7.152867334229605, 26.556732416152954, 46.810931069510325, 61.42279815673828, 72.89796352386475, 74.53378486633301, 80.74821894509452, 72.58550998142788, 72.6794079371861, 79.34910883222307, 73.22471645900181, 69.91827719552177, 65.33293860299247, 70.00893729073661, 65.76726354871477, 82.14500835963658, 72.25793715885708, 67.18721825735909, 76.35830538613456, 85.23773493085588, 77.32453577859062, 71.5777085168021, 71.74482658931187, 60.98213645390102, 64.99624974387032, 69.01178741455078, 59.681704657418386, 51.99229655947004, 61.830893652779714, 56.74965865271432, 56.457990646362305, 58.600613594055176, 58.6683029447283, 60.688568115234375, 55.5439064843314, 56.13116822923933, 42.267580441066194, 45.45474345343453, 47.492743900844026, 50.11420890263149, 59.42874159131731, 58.45286015101841, 54.968540055411204, 59.684532574244905, 48.416600704193115, 31.589057309286936, 12.346775191170828, 5.368094852992466, 1.7930033824273517, 0.1064401598913329, 0.19427592094455445, 0.09928623626806907, 0.022066343875069703, 0.050161037128418684, 0.06705662355359111, 0.009244296633239304, 0.03644889273813792, 0.02707132334554834, 0.05611610472468393, 0.0233652753356312, 0.020939568623102138, 0.012595679477921553, 0.04078097242329802, 0.05018650594034365, 0.04383655131927558, 0.0547576742246747, 0.08317033068409987, 0.060397080544914515, 0.05574634385162166, 0.061960045248270035, 0.06488060924623694, 0.0028624578636871384, 0.030858527536370924, 0.05072248075157404, 0.030880997223513465, 0.03955189444656883, 0.08792411988334996, 0.03005106747150421, 0.01264311246840017, 0.0843785097822547, 0.03610374911555222, 0.030569637859506265, 0.03243589075282216, 0.050002792584044595, 0.03486112418717571, 0.05358941673434206, 0.01573965621979109, 0.00838649011815765, 0.038742710902754746, 0.014285932261762875, 0.11888968971158777, 0.06440399267843791, 0.02526461529279394, 0.0664115199553115, 0.09035470695900065, 0.060074878191309314, 0.05591780625815902, 0.10591825111103909, 0.20339279887931688, 0.029697510014687265, 0.11373494059911796, 0.08224491748426642, 0.09699337823050362, 0.08707187311457736, 0.050371895278138776, 0.027333689088534032, 0.014613939482452614, 0.036756021436303854, 0.053328591265848706, 0.07205807803464787, 0.05872254432844264, 0.050728641849543364, 0.045540885401091406, 0.004541711382833975, 0.03382924545024123, 0.012349020124280026, 0.04666874630908881, 0.031611548736691475, 0.03171377003725086, 0.026449298419590508, 0.021906913590750525, 0.04699185111426881, 0.021466742835140655, 0.04162414717887129, 0.09963437901543719, 0.0187489505458091, 0.021405374431716542, 0.05328896142808454, 0.03101209018911634, 0.076983136257955, 0.0508640740465905, 0.01738617572534297, 0.049330537406993766, 0.02558005095592567, 0.0704240503587893, 0.02248508988746575, 0.05399733502417803, 0.002590024993488831, 0.02110060703541551, 0.03552093503198453, 0.031700667526040754, 0.028005569374987056, 0.04116081293406231, 0.04916634889585631, 0.02583128024291779, 0.027848273083301525, 0.04717082829613771, 0.03910280265180128, 0.0656180139631033, 0.09026932689760413, 0.06619311988885913, 0.03225631985281195, 0.11115846849445786, 0.013762666411431772, 0.02454595680215529, 0.1016302490606904, 0.028251221104125892, 0.05560547998175025, 0.027278936401541744, 0.021820179851991788, 0.03187202136697514, 0.07441700502697911, 0.04849747282319835, 0.06207564047404698, 0.0308633587057037, 0.0062749968575579775, 0.048244467470794916, 0.060693369646157534, 0.036430433192955594, 0.01985296094790101, 0.06764810252934694, 0.025695719124217118, 0.20026696446750844, 1.3716034974370683, 0.6624862541045461, 10.900161113057818, 32.207919461386545, 56.05972337722778, 76.88171318599156, 85.0101397378104, 93.3205326625279, 92.81913675580705, 93.64054584503174, 85.2670841217041, 82.42973164149693, 87.97162873404366, 77.33695220947266, 81.84064252035958, 74.63526330675397, 79.30515452793666, 85.66192245483398, 85.99367809295654, 77.73839133126395, 74.74323831285749, 88.69565882001604, 99.60318415505546, 92.26037652151925, 89.32702078138078, 82.50613403320312, 67.6337581362043, 64.33501052856445, 65.84285994938442, 54.89595569883074, 50.07412127086094, 54.7157506942749, 54.403846059526714, 65.27618571690151, 73.1103630065918, 81.06754425593785, 82.26185621534074, 72.53048024858747, 77.61613082885742, 66.88124738420758, 66.94680363791329, 65.3612733568464, 73.0990652356829, 77.95492499215263, 76.6970717566354, 77.46737684522355, 75.3821668624878, 71.06584862300328, 55.4090245791844, 34.121300492967876, 20.322270154953003, 8.54471136842455, 0.7535948881081173, 0.46056210356099264, 0.0803804321746741, 0.06495469848492316, 0.03995083571810808, 0.011778667336329818, 0.031683032400906086, 0.04173790696742279, 0.02302819101272949, 0.0900018008958016, 0.023425717538754855, 0.04622266720980406, 0.03257297857531479, 0.027829815234456743, 0.04669342123504196, 0.006994768145627209, 0.023061025322281888, 0.04728460844073977, 0.04943737613835505, 0.014347192099584, 0.015025301337508219, 0.0481153524347714, 0.04748944119949426, 0.028758627894733633, 0.04698775276275618, 0.00869045514679913, 0.02394279514971588, 0.0160937327558973, 0.019564220548740456, 0.02281106150309954, 0.012665006248945636, 0.029529179047260965, 0.11251148089234318, 0.009032268010612046, 0.01793343627027103, 0.005067263472093535, 0.02191405008280916, 0.03668993551816259, 0.018811570846342614, 0.030405656301549504, 0.09250431268342904, 0.06319004603262458, 0.06721247626202446, 0.05242352054587432, 0.05975517963192292, 0.08696329394089324, 0.0424609267418938, 0.052683921929981024, 0.12156196417553083, 0.141348927414843, 0.025566929785002555, 0.039856783979173215, 0.04379804106429219, 0.02110918371805123, 0.07036402036568948, 0.04664951662666031, 0.0710375342251999, 0.05560074041464499, 0.10112010607761995, 0.0805144699822579, 0.18463729029255255, 0.18139256297477654, 0.18351093573229654, 0.14440301353377955, 0.1587121228554419, 0.1224498272474323, 0.11446052523595945, 0.1507151669689587, 0.12479056950126376, 0.26669661487851826, 0.22248300164937973, 0.16676554642617702, 0.11897438445261546, 0.12203821433441979, 0.1473741555320365, 0.18528439556913717, 0.17298992457134382, 0.09803417631025825, 0.08704754084880863, 0.2130524098340954, 0.20177309507770197, 0.18139276653528214, 0.16374784335494041, 0.20806862440492424, 0.12622109773967946, 0.1497514165405716, 0.21449850366583892, 0.2215942700526544, 0.1203725737120424, 0.0937937938475183, 0.12235099183661596, 0.114051097205707, 0.15631063814674104, 0.1785436658454793, 0.11181353977216141, 0.1368879396468401, 0.12736092800540583, 0.16431638784706593, 0.19004829494016512, 0.1809829313840185, 0.17865110508033208, 0.3432495599346501, 0.19998596954558576, 0.3193778023123741, 0.1859529289816107, 0.09766699387026684, 0.1437459880752223, 0.16761895348983152, 0.13242369491074765, 0.15199620037206582, 0.15348373912274837, 0.2327774092555046, 0.20163091484989437, 0.18410679804427282, 0.21145591193011828, 0.23937157541513443, 0.13277282831924303, 0.12210114167204925, 0.14482578156249865, 0.30769912898540497, 0.4335129021533898, 0.1696450590555157, 0.0999210329194154, 0.15406168811023235, 0.3629196658730507, 0.13069446198642254, 2.1764406987598965, 14.428891488483973, 41.86376503535679, 78.53068052019391, 108.75355870383126, 131.51975522722518, 134.87990406581332, 132.08676992143904, 115.88847623552594, 107.9405152457101, 111.39506925855363, 103.2386553628104, 97.73714814867292, 90.61072826385498, 92.8331721169608, 89.66716984340123, 102.11611829485211, 86.63840144021171, 84.90286649976457, 102.0091438293457, 121.40911184038434, 104.86880002702985, 98.59304114750454, 91.09514277321952, 73.8254646573748, 76.04401057107108, 81.40190546853202, 72.93648433685303, 62.95287486485073, 73.45110266549247, 65.92083958217076, 69.8297085080828, 76.15892682756696, 85.74069418225969, 93.17645481654576, 89.36807073865617, 95.04529094696045, 82.71669224330357, 85.31546442849296, 90.36828477042062, 103.9307723726545, 112.48892416272844, 114.5538523537772, 111.1077959878104, 107.6453696659633, 82.25050980704171, 59.05517169407436, 27.318751777921403, 12.11111661366054, 2.674501035894666, 0.21218582562037877, 0.27461172587105204, 0.14526207957948956, 0.12860815679388388, 0.08884229989988462, 0.13060480036905833, 0.11582762402083192, 0.14952585792967252, 0.1260840743780136, 0.1733488967376096, 0.14711347594857216, 0.11235304975083896, 0.14531328183199677, 0.21779547818005085, 0.3505237267485687, 0.062460288405418396, 0.1784851082733699, 0.1619504719440426, 0.14454353813614162, 0.15412111420716557, 0.2340165227651596, 0.1989991082144635, 0.20314955764583179, 0.08467141299375466, 0.13076356399272168, 0.07610146142542362, 0.11481482908129692, 0.1350046657025814, 0.0643971259040492, 0.09081640932708979, 0.1888284518250397, 0.1416394489684275, 0.16238109740827764, 0.10771197878888675, 0.13364629287804874, 0.08756515450243439, 0.17932605743408203, 0.1670644682432924, 0.08163825968014342, 0.08117236396563904, 0.16486969244267258, 0.13741997895496233, 0.1834871055824416, 0.09243001309888703, 0.14411454115595135, 0.2405297261263643, 0.16231537450637135, 0.15951515547931194, 0.16067706527454512, 0.2612029239535332, 0.19288157219333307, 0.20234105602971145, 0.16630216129124165, 0.14919653774372169, 0.1791631140347038, 0.13291465570884092, 0.25723020998494966, 0.31643233607922283, 0.1512086247759206, 0.12535038803304943], [0.07093409834695713, 0.071673959360591, 0.01847000649598028, 0.057380931318870614, 0.025388062865074192, 0.03695864895624774, 0.02312657350142087, 0.02312809511620019, 0.0582286183323179, 0.04107394348829985, 0.06093580342297043, 0.03595734839992864, 0.04438075336760708, 0.04681337604831372, 0.014626258285716176, 0.01757105446553656, 0.030186743941158056, 0.04556028810994966, 0.04558360596586551, 0.0903318946116737, 0.05004211029570017, 0.051106521394103765, 0.06782097289604799, 0.06526884662785701, 0.06009418929794005, 0.05506625838045563, 0.0395367970424039, 0.029468104110232422, 0.019036328785919716, 0.014678252727857657, 0.035791907991681776, 0.02345963241532445, 0.03127094790605562, 0.03896216269848602, 0.03126485126891306, 0.03678949696144887, 0.013999610839943801, 0.034064205163823705, 0.01857954410037824, 0.01934277725272945, 0.06453936720000845, 0.020622266988669122, 0.03717411435874445, 0.022268664357917647, 0.10614507858242307, 0.0702379485592246, 0.08320992320243802, 0.04550633779061692, 0.028843465128115246, 0.03211892668956092, 0.020084115776366422, 0.03649213577487639, 0.11821290531328746, 0.005247927661652544, 0.029842431523970196, 0.03503665101847478, 0.02085110462004585, 0.006011745626372951, 0.04800153836341841, 0.080500573585076, 0.03968473124716963, 0.016610135224514773, 0.07641761803201266, 0.053630546134497435, 0.06564536570970501, 0.10881021485796996, 0.08597564550914935, 0.1033165714304362, 0.09858100768178701, 0.6572874273572649, 2.8989790933472768, 6.603986135550907, 14.374057173728943, 22.60085892677307, 46.8775087084089, 78.43960353306362, 84.0426447732108, 88.4179254259382, 102.67545522962297, 101.81988879612514, 103.75890868050712, 105.52882330758231, 111.28082002912248, 107.85376003810337, 110.2320658820016, 98.85581507001604, 55.04788153512137, 72.75822830200195, 95.38457843235561, 115.50314998626709, 109.87988254002163, 97.56688949040004, 87.15398556845528, 78.16767883300781, 79.38987391335624, 86.68875503540039, 90.74386964525495, 102.5939667565482, 108.01038633074079, 101.28231361934117, 74.66340351104736, 69.9687419618879, 65.90664441244942, 76.13781125204903, 63.11597687857491, 58.03473493031093, 48.37876428876604, 37.78778498513358, 27.10845238821847, 17.153697047914775, 9.515716910362244, 1.61310898406165, 0.1979960027549948, 0.277536293225629, 0.10942425512309585, 0.07185777449714285, 0.08487462744648967, 0.006018363887311092, 0.015026685548946261, 0.1475215061966862, 0.017760956061205695, 0.04439610182972891, 0.04505061670871718, 0.02552836185454258, 0.027606163306960037, 0.07988855535430567, 0.03264090332335659, 0.09041491337120533, 0.020154997240751982, 0.047298118072961054, 0.06683657464704343, 0.05874763655343226, 0.05535055098256894, 0.03750323437686477, 0.053795338541801484, 0.053585742467216084, 0.045190371173833094, 0.02449596573465637, 0.008269741382849003, 0.0168810165819845, 0.05301671621522733, 0.022713863058015704, 0.03553899424150586, 0.08153905786041703, 0.04048387247270771, 0.014408401047278727, 0.011949019489942916, 0.021282366210860864, 0.04840101907029748, 0.056396611101393185, 0.09920302073338202, 0.031244057563266585, 0.04771045362576842, 0.05618006343554173, 0.023131587875208685, 0.02064154077587383, 0.012245708926846939, 0.026032808536131467, 0.05796820337751082, 0.014457579569092818, 0.018538960920912877, 0.053718138220054765, 0.018688547358449017, 0.03954419307410717, 0.017967770142214637, 0.03355751592399819, 0.013787928270176053, 0.04243387694337538, 0.06830322130450181, 0.029372125331844603, 0.04355313742001142, 0.02580254089220294, 0.0687000285834074, 0.1179521307349205, 0.03488687798380852, 0.015950376966169903, 0.07664865920586245, 0.0649637637127723, 0.01774900027417711, 0.051116153198693476, 0.06914892021034445, 0.028030656510964036, 0.022046588328001753, 0.018613469154973115, 0.010055597206311566, 0.07153109381241457, 0.07632900135857718, 0.0030408324216425952, 0.029656801306243454, 0.01976687351374754, 0.010507028250555907, 0.04715715242283685, 0.0024938212383338915, 0.03467326158923762, 0.031026838147746663, 0.034340382487113984, 0.07038529243852411, 0.03094116292361702, 0.028764090101633753, 0.010080635996668466, 0.07279470243624278, 0.02135008909473462, 0.00047660665482648516, 0.028087587295366184, 0.01891661824525467, 0.0237073587652828, 0.11150182078459434, 0.009813947137445211, 0.05593972633193646, 0.019214613862069588, 0.012640482297034135, 0.05259165134547012, 0.008795236220716365, 0.052219810762575695, 0.0134097866414647, 0.03650637822491782, 0.021233336966750876, 0.04602733054863555, 0.0505550250943218, 0.022913125044267093, 0.05282552879569786, 0.0705173285678029, 0.026658344880810807, 0.0525606863998941, 0.045421809290668795, 0.016358469978773167, 0.030676395166665316, 0.039035709109157324, 0.0391365292349032, 0.03844386372449143, 0.009983380724276816, 0.061022873036563396, 0.03701307425009353, 0.032436009496450424, 0.05326519913173147, 0.07917672462229218, 0.04468002463025706, 0.042472332915557284, 0.09825828964156763, 0.058674076572060585, 0.042034124822488854, 0.030528084374964237, 0.12935799227229186, 1.808979679431234, 1.3889021234852927, 4.9138937166758945, 15.27701119014195, 29.73437465940203, 48.35485553741455, 60.33047185625349, 80.12117876325334, 99.99898133959088, 105.77110004425049, 109.19691630772182, 120.34438378470284, 119.99968365260533, 115.25664179665702, 118.74595069885254, 129.4626576559884, 130.19178771972656, 132.50111879621232, 123.34325408935547, 76.42247894832066, 98.32852322714669, 121.80497850690568, 138.3312827519008, 133.35086958748954, 123.73140825544084, 111.95988832201276, 105.03106130872453, 112.70667375837053, 114.29659530094692, 112.32323741912842, 122.1512211390904, 127.63151550292969, 127.89708954947335, 101.42320224217006, 105.42270347050258, 98.42548533848354, 104.86344991411481, 94.88409273965019, 89.46150316510881, 79.26161016736711, 66.19737788609096, 52.14843647820609, 37.1775872366769, 23.629244429724558, 7.8883888721466064, 1.801445335149765, 1.1508832212005342, 0.2735909920717989, 0.025754785597590462, 0.10260803837861333, 0.0829408365700926, 0.0312552941031754, 0.10370752973748104, 0.039520128829670806, 0.022670229863641516, 0.017424804723954627, 0.00744979627363916, 0.030608874146959612, 0.032012841132070334, 0.024295431495245014, 0.07029746965106044, 0.042134415690920184, 0.01140569444812302, 0.08669774926134519, 0.034634211898914406, 0.051882996157343896, 0.005260933481622487, 0.04045599825414164, 0.02951326061572347, 0.04378625151834317, 0.05454007482954434, 0.03395537832485778, 0.0368268842409764, 0.03416024161768811, 0.025367674584101354, 0.030235707028103725, 0.05179460679313966, 0.1001461436972022, 0.020827781675117354, 0.04819916168759976, 0.02300822681614331, 0.039296829740383794, 0.061043391935527325, 0.024958399224228094, 0.058209456503391266, 0.03646931664219924, 0.03219899721443653, 0.017611556220799685, 0.03798622238848891, 0.015446398473743881, 0.0730814513351236, 0.014305221316005503, 0.025141081207298806, 0.02060740198274808, 0.028310911829716394, 0.09225826910031693, 0.03896032047591039, 0.10963510309479066, 0.054120760544070175, 0.037860255754951916, 0.02995575705010976, 0.09865217921989304, 0.06186536925711802, 0.06265411193349532, 0.04137576264994485, 0.07847915669637066, 0.1040051012699093, 0.0891184297257236, 0.02004286423990769, 0.1754004880785942, 0.24170209893158504, 0.13552981109491416, 0.14621444419026375, 0.15814397191362722, 0.0760418792654361, 0.27322642877697945, 0.08654465819043772, 0.17361343039997987, 0.1391088254749775, 0.175060419897948, 0.12793053101216043, 0.1267513321446521, 0.08671140817127057, 0.10071445748742137, 0.09236224780657462, 0.11867441769157137, 0.09106678874897105, 0.0776538545531886, 0.14097348041832447, 0.22815408876964025, 0.09510057765458312, 0.11312358054731574, 0.1817764373762267, 0.1819220781326294, 0.1828511282801628, 0.10603290317314011, 0.19976324721106462, 0.08944381440856627, 0.09483589471450873, 0.15549221634864807, 0.143109847924539, 0.13778744637966156, 0.14167402711297783, 0.18286464469773428, 0.13583996945193835, 0.1262298779828208, 0.18092657226536954, 0.11413317280156271, 0.13401112758687564, 0.15810127849025385, 0.15792350231536798, 0.06945246285093681, 0.15415372460016183, 0.2540491021105221, 0.1440060841185706, 0.1780992661203657, 0.19342051898794516, 0.1252010017633438, 0.11042986437678337, 0.10333987910832677, 0.15253697921122822, 0.2500390415745122, 0.11876293937010424, 0.10038496766771589, 0.1514084804803133, 0.09880535171500274, 0.11808633139090878, 0.23698505918894494, 0.15882796235382557, 0.21511066438896315, 0.10067647988242762, 0.29454374632665087, 0.11845453163342816, 0.09713237612907376, 0.17649489721017225, 0.13413064474506037, 0.7219385696308953, 0.2619898345853601, 0.8735374606081417, 5.407077286924634, 15.56113692692348, 35.67389283861433, 49.41153410502842, 75.01480170658657, 103.33068425314767, 111.44727802276611, 116.29479994092668, 139.21666390555245, 139.93838718959262, 142.7337030683245, 149.6410184587751, 157.0822195325579, 158.63216808864047, 152.93299157278878, 140.14437348502022, 84.69642857142857, 113.64102581569126, 142.38987840924943, 169.96458271571566, 162.18858964102608, 147.90934671674455, 130.57732936314173, 116.55824783870152, 126.96448843819755, 128.15895325796944, 131.54695047651018, 149.0092326572963, 152.34691102164132, 155.48217446463448, 117.2377747126988, 122.87914221627372, 114.1557970046997, 119.35118048531669, 106.15068013327462, 96.16194983891079, 80.38972663879395, 59.765166418892996, 41.58519785744803, 27.34045273917062, 12.727370585714068, 2.9506076829774037, 0.5048425932015691, 0.5844864823988506, 0.2533430999943188, 0.14077984009470257, 0.1424805066947426, 0.19538466073572636, 0.14926079500998768, 0.15352427480476244, 0.1056994099968246, 0.10235308563070637, 0.13678876496851444, 0.0922201286469187, 0.13051884355289595, 0.12014647227312837, 0.08920194381581885, 0.18045603537133761, 0.12265823249305997, 0.1412330200629575, 0.17162415571510792, 0.15327833300190313, 0.1524485932396991, 0.07619200513831206, 0.18579563099358762, 0.19955111002283438, 0.09009523516786949, 0.1791787203401327, 0.23462033750755446, 0.07192807751042501, 0.17716139501758985, 0.1353742637272392, 0.19496983156672545, 0.1452910801661866, 0.17606416318033422, 0.1261388592954193, 0.10687821531402213, 0.060080360754259994, 0.2510387950709888, 0.17203636573893683, 0.13947870848434313, 0.1449642569891044, 0.14781271985598973, 0.1298462525010109, 0.166779809232269, 0.11206315244947161, 0.09635558923972504, 0.14783262807343686, 0.1437831310821431, 0.10634483929191317, 0.17802333805177892, 0.08930893521755934, 0.12694599027080194, 0.13348862848111562, 0.13706229600523198, 0.14310740519847187, 0.08992144877889327, 0.17810582076864584, 0.14166166420493806, 0.17130721200789722, 0.10688386751072747, 0.11415715222912175, 0.14055339938827924, 0.20997743840728486, 0.19216866259063992, 0.09196100969399724], [0.012564209871925414, 0.015704279100256305, 0.04001186315768531, 0.05469986643376095, 0.06042874777423484, 0.012927755364216864, 0.024928377442327992, 0.03331244943131294, 0.04525442148691841, 0.03648097726649471, 0.021631034822868447, 0.01893288272965167, 0.0761516255193523, 0.027085131533177834, 0.03505689850343125, 0.01858617169117289, 0.0344445986806282, 0.039316900806235414, 0.04046664446858423, 0.02651092127364661, 0.03071746349866901, 0.04150754093591656, 0.049654039155159674, 0.03880365691812975, 0.01336027987833534, 0.06837264222225972, 0.013738953308867556, 0.027988633140921593, 0.01382759542736624, 0.09442623598234993, 0.025663826282003095, 0.05230297879981143, 0.0872061416240675, 0.022150070007358278, 0.04025391356221267, 0.07804017168070589, 0.017530556102948527, 0.08405281975865364, 0.11504186689853668, 0.04248321322458131, 0.01583559767875288, 0.06419286650738545, 0.027250748360529542, 0.05642183224803635, 0.05790243976350341, 0.05182442840720926, 0.01626967010088265, 0.02643816196359694, 0.027887117516781603, 0.03549699292385152, 0.0339348865672946, 0.02294385589526168, 0.024372677618105496, 0.03787498675020678, 0.028069422912916968, 0.05267622395019446, 0.020741902890482118, 0.03238233059112515, 0.10313633217343263, 0.047772268165967295, 0.02716007233331246, 0.04821746177705271, 0.02881854253688029, 0.09237153016562973, 0.022729762829840183, 0.0355303904174694, 0.027107516403443048, 0.12153368283595357, 0.1707543416747025, 0.09076546491788966, 0.09734470330710922, 0.15536792230393204, 0.2557328189057963, 0.12032636547727243, 0.07943425580327, 0.45623136737516945, 1.4603433928319385, 2.0190900564193726, 4.87252414226532, 6.508342444896698, 8.372756481170654, 13.460533210209437, 15.200270073754446, 10.902788400650024, 5.942268797329493, 1.3586840821163995, 0.28029562373246464, 0.3974266456706183, 1.95755854674748, 15.465936183929443, 34.78115006855556, 43.79510716029576, 54.86404262270246, 66.53378881726945, 85.37410027640206, 68.62915706634521, 38.79449905667986, 20.775323969977244, 11.400045786585126, 3.7864551288740973, 0.6674215378505843, 0.653141686958926, 0.8842519628150123, 2.0067889222076962, 0.7015341530953134, 0.28796931196536335, 0.04728718348113554, 0.09073735999741725, 0.14404523558914661, 0.13815523950116976, 0.26033597333090647, 0.05140723454366837, 0.1795464048960379, 0.07961389794945717, 0.11321063659020833, 0.0386238553162132, 0.04368304294933166, 0.033407664857804775, 0.03300613836784448, 0.026954065708975707, 0.0157407045563949, 0.059547602199018, 0.027720954468739883, 0.04346584728253739, 0.035124215962631364, 0.0035657244235543267, 0.08690706374389784, 0.009466093615628779, 0.007586516839052949, 0.0004787200263568333, 0.02476436026128275, 0.03982112017859306, 0.03253649374736207, 0.02528681356592902, 0.043851940493498526, 0.06052416336855718, 0.04456380515226296, 0.003979029433269585, 0.033021296840161085, 0.02850273876850094, 0.010128140233324041, 0.012262101484728711, 0.016816784760781696, 0.06179692542978695, 0.020819427212700248, 0.009343635856306978, 0.040003568067082336, 0.028035742130928805, 0.01415427865660084, 0.01478773944212922, 0.04932873250384416, 0.024490632449409792, 0.042935511097311974, 0.03441109262140734, 0.0630459998335157, 0.01762059091457299, 0.031027072242328098, 0.018101768934034874, 0.022021311202219555, 0.0651204985167299, 0.023058826868821467, 0.055653415088142665, 0.060481714217790535, 0.05427976844034024, 0.10554148775658437, 0.043536964537841935, 0.037005525548011065, 0.02188319031016103, 0.027948684391698668, 0.09108200828943934, 0.004806693302400942, 0.013236102032741266, 0.07939380833080836, 0.034278496700738154, 0.05741761292197874, 0.01709730301185378, 0.00889249488578311, 0.02366952195630542, 0.015226320729457905, 0.03926641780084797, 0.05390519675399576, 0.10053447607372488, 0.011836561640458447, 0.08481353215341057, 0.007689176642868135, 0.028413168753364255, 0.029226409936589853, 0.015521544530721647, 0.029797621071338654, 0.04300711350515485, 0.020918077722723995, 0.038075147795357873, 0.038803402467497757, 0.025800389936193824, 0.03440998660932694, 0.05215437284537724, 0.03737141877146704, 0.012878767680376768, 0.07308795848595244, 0.042303418408014944, 0.028358697658404708, 0.04642303181546075, 0.030972161795943975, 0.004755061028325664, 0.029269622439252477, 0.08330647195024149, 0.08032283133694104, 0.015836249072370783, 0.02180806460923382, 0.0573355033993721, 0.031853008815752606, 0.0447151964929487, 0.053600911117557964, 0.06175408951405968, 0.021745585104716674, 0.013506946070784969, 0.02756605001299509, 0.03667886182665825, 0.05869794064866645, 0.03589669415461166, 0.07512027943240744, 0.09617306331970862, 0.011241251486353576, 0.05907542325024094, 0.0683756684884429, 0.0063445653566824535, 0.03354831498914531, 0.05359882801505072, 0.016010708907353025, 0.02611345242309783, 0.021671472117304802, 0.018380304166514958, 0.03736840268330915, 0.017904942888500433, 0.08342993818223476, 0.06417870548154626, 0.01558634462500257, 0.028815404312419038, 0.02964095412088292, 0.09010589495301247, 0.03250844310969114, 0.10953033728791134, 0.05140875106943505, 0.22686867203031266, 0.20042439816253527, 0.11007137397038085, 0.16249746616397584, 0.34928852160062107, 0.9131195566483906, 0.6620977520942688, 0.6631434559822083, 4.047688722610474, 5.9887557200023105, 7.685421569006784, 14.645102058138166, 17.78059479168483, 20.750235761914933, 26.084152426038468, 26.311872686658585, 20.047180550439016, 10.66950784410749, 2.909466096333095, 0.29145700910261696, 0.8562097932611192, 3.9283816388675143, 21.961897373199463, 46.19329527446202, 61.856240681239534, 82.16588769640241, 94.33539349692208, 102.58514949253627, 92.13647624424526, 60.74494579860142, 40.83278785433088, 25.24050736427307, 11.586124624524798, 2.76140866960798, 2.4715161451271603, 3.4840682234082903, 5.781220844813755, 3.275198642696653, 1.2443727531603404, 0.3623683697410992, 0.4130092023738793, 0.5452953853777477, 0.37867964591298786, 0.1964460387825966, 0.04336769040673971, 0.23544014351708548, 0.15950470604002476, 0.12515028805605002, 0.0626794212896909, 0.039839630613901784, 0.04418079249028649, 0.06354147967483316, 0.03548896585458091, 0.02237805098827396, 0.0604380572746907, 0.02915820698919041, 0.03259243217429944, 0.030826358191136802, 0.06813934831214802, 0.053005934293781004, 0.010421699927454548, 0.04962500464171171, 0.04334302905148693, 0.048145109588014226, 0.10499509064746754, 0.02875798667914101, 0.020250660500356128, 0.05420806085956948, 0.022524310907881175, 0.04196523994739566, 0.01659358405907239, 0.018428415692012225, 0.017725947046918527, 0.029273649544588158, 0.025654377681868415, 0.06574004170085702, 0.006543806986883283, 0.07676766067743301, 0.04545969868611012, 0.04197045448901398, 0.01829489187470504, 0.03284203467358436, 0.0329645102444504, 0.04315353457682899, 0.06274358356105429, 0.020275082672014832, 0.03170962418828692, 0.06904205094490733, 0.05181587886597429, 0.015159678412601352, 0.040846678361828835, 0.036889088938810995, 0.07802511498864208, 0.052846604093377075, 0.02640116144903004, 0.09713182651570865, 0.033700639315481694, 0.026226788127262677, 0.051970140409788916, 0.01530651847964951, 0.08136457936572176, 0.03434827045670577, 0.05939870447452579, 0.00273721683853572, 0.07007707469165325, 0.06231832530881677, 0.06680880220873014, 0.03924182429909706, 0.0337198147151087, 0.10583127649234873, 0.0984406459278294, 0.1853868950690542, 0.10890182387083769, 0.19463489311082022, 0.1338489848588194, 0.1714137555765254, 0.2128604929894209, 0.1313114267374788, 0.11263107268937997, 0.16066946568233625, 0.11143697997821228, 0.19586009665259294, 0.12037707918456622, 0.0550550795160234, 0.08713539077767304, 0.12174322802041258, 0.07827979632254158, 0.11172164577458586, 0.17564489639231137, 0.11563030603740897, 0.0841702605996813, 0.12631500698626041, 0.1312879222844328, 0.09106988965400628, 0.1074072690680623, 0.13473794715745108, 0.12646379614514963, 0.09812781414283173, 0.22304974123835564, 0.17512004955538682, 0.2318025715649128, 0.1544731653162411, 0.14911537138479097, 0.11471660435199738, 0.15064097595001968, 0.1004199529332774, 0.23714082368782588, 0.26815788075327873, 0.06429035163351468, 0.10934858489781618, 0.23216786767755235, 0.19257855202470506, 0.13219667066420826, 0.2212552468159369, 0.1783665953470128, 0.12162607216409274, 0.1104539455845952, 0.13627865591219493, 0.07435623543070895, 0.12320605452571597, 0.13176975000117505, 0.1077585873593177, 0.13022838985281332, 0.06500913056411914, 0.21004141068884305, 0.08976226446351834, 0.15436565822788648, 0.13767609878310136, 0.10219628297324691, 0.12784305427755627, 0.16717690149588244, 0.14621322282723018, 0.15976527705788612, 0.09853164425918035, 0.1297941952943802, 0.14380896969565324, 0.2846016069608075, 0.276234998766865, 0.27172610642654554, 0.2744547128677368, 0.4228082522749901, 0.5315910950303078, 0.3041547606033938, 0.19179312059921877, 1.0564152960266386, 1.7566694063799722, 3.0655636744839803, 7.379131078720093, 10.648239408220563, 12.611771668706622, 17.69445971080235, 18.993385485240392, 14.826637642724172, 7.40066180910383, 1.9793452748230524, 0.6086402663162777, 0.680358812212944, 3.5696552651269093, 21.248445919581822, 45.75548233304705, 66.88347775595528, 94.46018314361572, 108.31769820622036, 110.82663713182721, 98.0890952519008, 61.911020278930664, 34.64487157549177, 18.64561598641532, 6.970867523125239, 1.1260239779949188, 0.8589430951646396, 1.6270590126514435, 2.582391155617578, 1.2481118610927036, 0.25720662410770145, 0.1251829391611474, 0.17510818876326084, 0.25505686232021874, 0.2819801004869597, 0.4647338997040476, 0.16804111083703382, 0.37338821270636147, 0.3982340752014092, 0.24012320222599165, 0.11004922658737216, 0.13220805648182118, 0.16367296023028238, 0.15884584853691713, 0.11166791937180928, 0.1213957095252616, 0.13749627343245915, 0.08818129822611809, 0.162592366071684, 0.1005861736567957, 0.13082674917365822, 0.21977576906127588, 0.08918200167162077, 0.12177640838282448, 0.12515912258199283, 0.10525829438120127, 0.20481067922498497, 0.15381072514823504, 0.09393299530659403, 0.12195957212575845, 0.1816040351986885, 0.13175058817224844, 0.18043052245463642, 0.10530360016439642, 0.1499813991997923, 0.08312530310026237, 0.14264570283038275, 0.2559590424810137, 0.2408945879765919, 0.19486125239304133, 0.17215920771871293, 0.08905757870525122, 0.1505085394850799, 0.08130043066505875, 0.1019296119255679, 0.22958837609205926, 0.13229026778468064, 0.094477105752698, 0.1809171134872096, 0.17209287413528987, 0.10546325266893421, 0.13440250658563205, 0.10463996577475752, 0.0676183555541294, 0.22683897933789662, 0.09779393420155559, 0.11737639377159731, 0.19758348060505732, 0.1824736049664872, 0.13809719761567457, 0.1419984618467944, 0.1725411279393094, 0.14486970991960593, 0.12552344160420553, 0.20377349773687975, 0.11200392991304398, 0.1077649180910417, 0.18568420197282517, 0.11070081698043005, 0.11713915078767709, 0.08147285998399768], [0.04388416072885905, 0.020402486103453805, 0.025332460312971046, 0.03282196021505764, 0.009865208761766553, 0.03643067407288721, 0.022835298773965666, 0.04174283991700836, 0.008025400074464934, 0.016014661373836652, 0.04672582128218242, 0.05013792961835861, 0.06713178487760679, 0.031810488418809006, 0.06001710771982159, 0.012882821927113193, 0.014081827231815882, 0.039436339932893, 0.016709184373861978, 0.014322269508349044, 0.0726497537855591, 0.013905016272994024, 0.01847615571958678, 0.028141481635559882, 0.007123678772976356, 0.01977720420940646, 0.018528886372223496, 0.04182336166767137, 0.009481547250678497, 0.008173264729391252, 0.021801652453307594, 0.009794571569987705, 0.04151459430743541, 0.010516100263755237, 0.0276196610648185, 0.021144316564979296, 0.035102869250944684, 0.007516391941213182, 0.038246270934385915, 0.018795547241877233, 0.05795668185289417, 0.08604120556265116, 0.016221923287957907, 0.04264724227998938, 0.032287827626402886, 0.04919887786465032, 0.034250910859555006, 0.029379382263869047, 0.0249735068064183, 0.06283621037644999, 0.08090844777013574, 0.03687407295884831, 0.042688778801155944, 0.04248682642355561, 0.01181953719684056, 0.030588850578559295, 0.011039969162084162, 0.027359878843916313, 0.12456613725849561, 0.020184433786198497, 0.0381917574309877, 0.02271104883402586, 0.03058829078716891, 0.014616221056452819, 0.0054905484596799526, 0.08633169318948473, 0.04748080005603177, 0.06346437774066414, 0.13504449570817606, 0.020666577021724412, 0.027508223562368324, 0.05312300533322351, 0.08010629045643977, 0.02133339543693832, 0.017714286422623054, 0.036502683601741276, 0.014623768062197735, 0.05335358849593571, 0.16571343716766151, 0.14905994864446775, 0.3241829701832363, 0.3346748314797878, 0.3351641637938363, 0.30633711921317236, 0.11376300480748926, 0.03178836139185088, 0.25933643696563585, 0.13050498786781514, 0.03471699656386461, 0.38001313007303644, 0.8400336269821439, 0.9593825084822518, 0.4663877338171005, 0.43849679614816395, 0.1187752615660429, 0.5107514389923641, 0.9156117886304855, 0.4773047108735357, 0.47772105996097836, 0.3020101285406521, 0.10181753829653774, 0.0629609590396285, 0.0447120345197618, 0.059265161997505596, 0.04765146518392222, 0.026217171589710882, 0.037249095870980194, 0.08976281407688345, 0.12431254158062593, 0.06771623423056942, 0.05941850412636995, 0.020095610159582326, 0.05366354329245431, 0.1051075646121587, 0.09013146215251513, 0.046969934433166466, 0.03682070617963161, 0.0301536382175982, 0.032692119146564176, 0.07805642259440251, 0.04386388610250183, 0.054397897994411845, 0.03074237930455378, 0.034356738573738506, 0.048152905955378494, 0.026468943704717925, 0.031765718678278584, 0.027765793759109716, 0.0237761859648994, 0.022974252567759583, 0.031054732722363303, 0.038352831466389556, 0.02345484365443034, 0.05657068926042744, 0.03155000900317516, 0.03728797932022384, 0.005279624576879931, 0.034494199590491395, 0.015531410429892796, 0.009097951896754759, 0.0032835342197878553, 0.0864260909812791, 0.010564830104288245, 0.03298613515549472, 0.028837857036186115, 0.08088711462914944, 0.027605717170185277, 0.04200006914990289, 0.00381625524356163, 0.014416087152702468, 0.028161064156198075, 0.01638398289547435, 0.04290899394878319, 0.03429311573771494, 0.009911601049160319, 0.019089775293001106, 0.0627535240990775, 0.03831802601260798, 0.02332288386034114, 0.006189026046610836, 0.046274687097008736, 0.004080557779941175, 0.02233754753667329, 0.01701952423900366, 0.03669212040092264, 0.05256669482748423, 0.031017643998243978, 0.054684436547436883, 0.029772382961320024, 0.014692608832514711, 0.062259272406143804, 0.030238584016582797, 0.0387645224109292, 0.05135659886790173, 0.06376037507184915, 0.005701235279307834, 0.028520679234394004, 0.01832678302058152, 0.03663452634853976, 0.06120892733867679, 0.05346295137756637, 0.05226450586425407, 0.05796534674508231, 0.06303821025150162, 0.020745633136747137, 0.037448225542902946, 0.03220904631806271, 0.03367880745125668, 0.01993471084694777, 0.010298956335256142, 0.05228130299864071, 0.08975719580692904, 0.029762130297188247, 0.02607560882877026, 0.025618769860427295, 0.037098871610526524, 0.0233733821327665, 0.033135894619460614, 0.02286073535547725, 0.04200715305549758, 0.034025409924132485, 0.011240226050306643, 0.016112916637212038, 0.01870165835134685, 0.006526447940684322, 0.04381659560437713, 0.011851399504978741, 0.054308752063661814, 0.05119738741112607, 0.024120301606931856, 0.04827330181641238, 0.02922901211838637, 0.05912032869777509, 0.0648558766448072, 0.0347035446071199, 0.022452102907534157, 0.028872126447302953, 0.06144659101430859, 0.025894358554588895, 0.027972806311611618, 0.023417217191308737, 0.08071431211595025, 0.07644403340028864, 0.0435280451950218, 0.05554674259786095, 0.05020953541887658, 0.08148828308497157, 0.1237523430692298, 0.03166652025122728, 0.02097679135788764, 0.023144439328461885, 0.018042880576103926, 0.012972479303633528, 0.026535577539886748, 0.02528864561047937, 0.0719660958275199, 0.008619147901689368, 0.021642493582995873, 0.04503477970138192, 0.024499136189531003, 0.024602582245799046, 0.04024042428604194, 0.038923292819942744, 0.0829461087871875, 0.07580028008669615, 0.06523992746536221, 0.013901070591860583, 0.05476150455485497, 0.09091774853212492, 0.09043543227016926, 0.020959590495164906, 0.14493505284190178, 0.022056985180824995, 0.16361077928117343, 0.24632284098437854, 0.2027709215347256, 0.3321729914418289, 0.16777741855808667, 0.17954533281070845, 0.10154727101325989, 0.0534995345930968, 0.047020183343972476, 0.37182269671133583, 0.1041072682876672, 0.05025299219414592, 0.2547082853104387, 0.25483427569270134, 0.3364785404077598, 0.36712367885879105, 0.5134738843355859, 0.2091151832469872, 0.24604179177965435, 0.42557835791792187, 0.34614598165665356, 0.19944278869245732, 0.16779450406985624, 0.07917131669819355, 0.09127040353736707, 0.022512007371655533, 0.1246790454855987, 0.0702569271836962, 0.015050055991326059, 0.14411483971135958, 0.07531301730445453, 0.048475260979362896, 0.11707635915705136, 0.10739212416644607, 0.03333126860005515, 0.028328948986849616, 0.10206105094403028, 0.04391624525721584, 0.09789447273526873, 0.021098944624619823, 0.029398062332932438, 0.05724591642085995, 0.08774130219327551, 0.021892082511580417, 0.07430830371699162, 0.03801768944997873, 0.02731444583540516, 0.05019356270453759, 0.047150445104177506, 0.06833292078226805, 0.03756526604826961, 0.03387792355247906, 0.04904096919511046, 0.023371897837413207, 0.04496939267430987, 0.01341354233279292, 0.01269875658077321, 0.0432981643160539, 0.053086418725017986, 0.038540354796818325, 0.04653183151302593, 0.019900090293958783, 0.03968840551429561, 0.04110668958829982, 0.04315238445997238, 0.012830740971756833, 0.011162748377371048, 0.04332233373341816, 0.04511277390910046, 0.06893398745783738, 0.041369404776820114, 0.014440380402707627, 0.06863422425729887, 0.02142036666295358, 0.024518674605392983, 0.06892399942236287, 0.07060701732656785, 0.022634764534554312, 0.03747244245771851, 0.022489142437864627, 0.04169900994747877, 0.022091139240988662, 0.035151866264641285, 0.0738007595230426, 0.038027263579091856, 0.027043271011539867, 0.027059360773169568, 0.011073635525203176, 0.0387362105372761, 0.03494721331766673, 0.04581370058336428, 0.04841418264965926, 0.009029928761135255, 0.032226559306894026, 0.04268127420384969, 0.03244823330481138, 0.03903281854997788, 0.01369931414124689, 0.03902714938989707, 0.15574659912713937, 0.08965242321469954, 0.09573782381734677, 0.1123918890953064, 0.2506708391010761, 0.14345345805798257, 0.15187995375267097, 0.22459446692040988, 0.06073811224528721, 0.06275178704942976, 0.14852795004844666, 0.16964250776384557, 0.15237471434686864, 0.09380209233079638, 0.12255859641092164, 0.12092237706695284, 0.0893449993538005, 0.09686113854071923, 0.10937903754945312, 0.08013556924249444, 0.17670179610805853, 0.08352016976901463, 0.1070570025060858, 0.18770494711186203, 0.10177374564643417, 0.1025308957323432, 0.08311742530869586, 0.14123795979789325, 0.08483702303575617, 0.13904608812715324, 0.11471588510487761, 0.15822048352233, 0.06909971285079207, 0.13702220815633023, 0.10935617091932467, 0.13977815955877304, 0.14787936556552136, 0.07865633576044015, 0.10865688629980598, 0.0829207587188908, 0.11737176616277013, 0.3029376044869423, 0.11379630052085433, 0.12387327158025332, 0.07557945765022721, 0.19424679822155408, 0.15452130059046404, 0.06924956052431039, 0.1464629101433924, 0.14930384127157076, 0.15162599166589125, 0.20240219203489168, 0.17006889916956425, 0.13893601617642812, 0.09378041992230074, 0.1481184677353927, 0.0887302059148039, 0.14326715948326246, 0.21999448803918703, 0.11713893365647111, 0.08089647841240678, 0.08987347635307483, 0.1668553708919457, 0.1227509475180081, 0.058167821594647, 0.1647251916251012, 0.13029223999806813, 0.16759654826351575, 0.16304167839033262, 0.17933004721999168, 0.12004005084080355, 0.1417657650474991, 0.2237036454358271, 0.21549083398921148, 0.07636159139552287, 0.1821477317384311, 0.14067769343299524, 0.2606672341270106, 0.46988718318087713, 0.3932411702615874, 0.40758252356733593, 0.47759344109467095, 0.30271146233592716, 0.2313621480550085, 0.1216243893972465, 0.12718465817826136, 0.5332110566752297, 0.2749115840664932, 0.09314146385129009, 0.4176961694444929, 0.5270488730498722, 0.9409961636577333, 0.37425559759140015, 0.2982995462204729, 0.11196317031447377, 0.4473008151565279, 1.1019918961184365, 0.7273832431861332, 0.4115166424640587, 0.31280160376003807, 0.1321133601346186, 0.22746173877801212, 0.08576688063996178, 0.13141381767179283, 0.14523453105773243, 0.08709839704845633, 0.2532365971377918, 0.45393194790397373, 0.20301729759999684, 0.20203130479369844, 0.15403351533625806, 0.09126534845147814, 0.10580941409404789, 0.25508150671209606, 0.1709028458488839, 0.13861724042466708, 0.10415834161852087, 0.18373682004000458, 0.1955739584352289, 0.21549164823123387, 0.10691548724259649, 0.24103409477642604, 0.11288049537688494, 0.11407608086509363, 0.2079530427498477, 0.14354458531098707, 0.1437757486211402, 0.25110458582639694, 0.13245935871132783, 0.07925468151058469, 0.10081807657011918, 0.16328839372311318, 0.08148971479386091, 0.12461994508547442, 0.10794042117361512, 0.09438620241624968, 0.0876234881579876, 0.1288276900138174, 0.1011157159560493, 0.10373207234910556, 0.17256417098854268, 0.26589833199977875, 0.04127477289044431, 0.14185876505715506, 0.13361646447862896, 0.14665497626577104, 0.13149976091725485, 0.10531780868768692, 0.06729536609990255, 0.10088050179183483, 0.09214359668216535, 0.06905544522617545, 0.11081983202270099, 0.19586164371243545, 0.09474271150039774, 0.11232861570481743, 0.15897896353687557, 0.11841789074242115, 0.09730962983199529, 0.08397498500666448, 0.11358360014855862, 0.1059668885011758, 0.17638074047863483, 0.0749756700492331, 0.11319607522870813, 0.14016789650278433, 0.17463847968195165, 0.13242684331323418, 0.09970730795924153, 0.14666967333427497, 0.1198902710207871, 0.20522287567811354, 0.15447357243725232, 0.07355584230806146, 0.19579456374049187, 0.07355582873736109], [0.1312208558831896, 0.03188174816646746, 0.03512856876477599, 0.03803649504802056, 0.03708811004513076, 0.06477623020431825, 0.08044359699956008, 0.06747519823589496, 0.060286818604384146, 0.03126325331894415, 0.0022662115432987256, 0.021863466993506466, 0.011265911145268806, 0.013658136395471436, 0.03173575457185507, 0.09244998238448586, 0.08790134824812412, 0.024512213255677904, 0.031175376248678992, 0.050741740968078375, 0.04022088926285505, 0.0207877226639539, 0.046718394716403315, 0.06771930120885372, 0.009378231812401541, 0.03469155489334038, 0.026531577575951815, 0.04240348196721502, 0.037418570169912915, 0.02210684902300792, 0.02710179296056075, 0.06524503683405262, 0.0339523554513497, 0.03521252390263336, 0.004255427704525313, 0.025665816085945283, 0.046909175014921596, 0.0839106666722468, 0.029979885755372897, 0.07831209458942924, 0.03025640913152269, 0.036934995225497654, 0.006463168613013944, 0.036603052501699755, 0.033838141044335704, 0.04446204864819135, 0.02454863192646631, 0.03211715232048716, 0.021761995474142686, 0.027356146901313747, 0.030144345680517808, 0.021278021890403967, 0.030838931445032358, 0.0134386421913015, 0.03854128099711878, 0.020101635550547923, 0.012877148526188518, 0.029539211187511683, 0.024593566211738756, 0.008396017597988248, 0.045730427373200655, 0.04846301681495138, 0.03886084724217653, 0.059432237675147395, 0.015165232221728988, 0.02668349478127701, 0.00977283639700285, 0.014006881342668618, 0.032967753641839535, 0.05199769910957132, 0.04143267816730908, 0.08068716392985412, 0.09688242418425423, 0.04276068315708211, 0.15839668549597263, 0.035526709364993234, 0.04630314146301576, 0.07635857870004006, 0.01879693314965282, 0.020935178501531482, 0.14705333060451917, 0.07155617246670382, 0.21041984323944363, 0.04991546512714454, 0.08331111991511923, 0.09636638473187174, 0.18233641875641687, 0.07939224091491529, 0.04428644717804023, 0.12946117030722754, 0.31426509522965973, 0.4078652283975056, 0.2781469204596111, 0.20091853450451577, 0.23099489776151522, 0.3132838521684919, 0.2141144121331828, 0.22108137900275843, 0.15730273776820727, 0.14378952288201877, 0.14260824769735336, 0.039565061418605704, 0.04252187954261899, 0.043922358857733865, 0.017386574364666427, 0.06934798202876534, 0.1199391662542309, 0.09924673874463354, 0.0681504016476018, 0.0514139486476779, 0.03561305633879133, 0.030092417395540645, 0.08412217960825988, 0.06393087056598493, 0.012235287477129271, 0.0458351253265781, 0.0160302761609533, 0.032676254997828176, 0.040516472687678676, 0.1297512033155986, 0.02066958462819457, 0.024360377474554946, 0.012944191178706075, 0.05256373302212783, 0.048842436634004116, 0.027305146512974585, 0.046424667084855695, 0.022720422795308486, 0.03631168956469212, 0.030735593954367296, 0.02222830679134599, 0.062005072832107544, 0.02000520724271025, 0.03513958478080375, 0.05894465598144701, 0.049985269417188, 0.07226931277130332, 0.012861404817418327, 0.024002964242494533, 0.034527485125831196, 0.03527257425178375, 0.03488271517146911, 0.03719981047990067, 0.02925330027937889, 0.02444421386878405, 0.019666153471916914, 0.028895067716283456, 0.09070975040750844, 0.030615418617214476, 0.05752374936959573, 0.031534114320363314, 0.032467663155070374, 0.028447572175147276, 0.013608370940866215, 0.03860174525263054, 0.044058696899030886, 0.028066400039408888, 0.07882649877241679, 0.023981700651347637, 0.056849916598626545, 0.03800625952758959, 0.0551446902432612, 0.0250733854648258, 0.004663437596588794, 0.015891134073691707, 0.04813773051968642, 0.028184158095557774, 0.046411696887974224, 0.03758665347205741, 0.04213829351855176, 0.04699889770043748, 0.04524605854281357, 0.08672335038759879, 0.023265864866386567, 0.02948074521762984, 0.022834525244044404, 0.025624250727040426, 0.038666837116969485, 0.06085325963795185, 0.014628392278349825, 0.031692158696906905, 0.0671428314277104, 0.06574039453906672, 0.06467122012483222, 0.03070164006203413, 0.023104527898664986, 0.032087680151952166, 0.09593970155609505, 0.003927337787380176, 0.09923416549073798, 0.031044137398047105, 0.05349539552948304, 0.010506912051433963, 0.039120756688394716, 0.04222308325448206, 0.04595797748437949, 0.021432760105069195, 0.05608993023633957, 0.04472547969115632, 0.016305235513885106, 0.04518011850970132, 0.033380238472351005, 0.01859725725704006, 0.03132207891238587, 0.05608214743967567, 0.016689684973763566, 0.05936901178210974, 0.041760807524302175, 0.05489209879721914, 0.017193308931642344, 0.023683528615427867, 0.0681151110412819, 0.02515670786877828, 0.021795783125396286, 0.030133607863847698, 0.03551933368934052, 0.0781816326613937, 0.02998306808461036, 0.07247691056025879, 0.038127734259303124, 0.028038327349349856, 0.06666838617197104, 0.030958862509578466, 0.018421051890722344, 0.09004825340317828, 0.0009051938104676083, 0.039054399356245995, 0.01996832207909652, 0.0641952006678496, 0.07384111200060163, 0.05101852218753525, 0.03124882766444768, 0.01989898088920329, 0.011238787556067109, 0.0365296825101333, 0.06510420689093215, 0.048001059996230264, 0.06175847285028015, 0.01361202570011041, 0.03802440694666334, 0.023645491638619984, 0.052458515989461114, 0.004456018771244479, 0.013380766546885883, 0.03853593074849673, 0.0023550453479401767, 0.01785905526152679, 0.08387044311634131, 0.07309785152652434, 0.07910190256578581, 0.07118541414716414, 0.037993190943130424, 0.06089256038623197, 0.06629616221679108, 0.023282439780554602, 0.021305463542895656, 0.20000366573887213, 0.045189889413969855, 0.050750046236706634, 0.020508938069854463, 0.021199666362787997, 0.13202000728675298, 0.2531714306346008, 0.09195936085390193, 0.02480111819958048, 0.03899772132613829, 0.15397617912718228, 0.18654450295226915, 0.13952231114464148, 0.0220136573272092, 0.11526871472597122, 0.15129413375897066, 0.2921653725206852, 0.2758427512432848, 0.11624560159231935, 0.0816750702049051, 0.0794077522254416, 0.08088357946170227, 0.01593066213120307, 0.08779898445521082, 0.10106664430350065, 0.04458407299326999, 0.0433329053090087, 0.021956952155700753, 0.04538517179233687, 0.10206628244902406, 0.04146040989352124, 0.025968047457614114, 0.026734868363876427, 0.018991331736158048, 0.019744105271196792, 0.06185599868851049, 0.009920948717210974, 0.031318628561816046, 0.01441676908039621, 0.061547034553119113, 0.02960834712056177, 0.044760010338255336, 0.05069157008879951, 0.03244786011055112, 0.028258964885026217, 0.00903230278553175, 0.03344176463516695, 0.025176383687981536, 0.007638375574190701, 0.03274847147986293, 0.02230780734680593, 0.020850317519424216, 0.01343553704542241, 0.0037904611589120968, 0.031061860732734203, 0.02292822584110711, 0.018430690480662242, 0.037320708456848345, 0.02638535327943308, 0.046137599274516106, 0.013483054852778358, 0.08778816182166338, 0.06866893132350274, 0.024318849435076118, 0.019524473663685576, 0.02362171746790409, 0.013098499371803232, 0.03836253112448113, 0.04520470861877714, 0.045871874783188105, 0.10094550544662134, 0.03670615929045847, 0.015409056995330113, 0.027718672894739678, 0.012118808459490538, 0.028911925918821777, 0.07876535598188639, 0.020705804827490022, 0.01845997096305447, 0.0655146459383624, 0.02810385008342564, 0.03638281699802194, 0.035889094562402794, 0.04285986122808286, 0.02752980267229889, 0.05486372585541435, 0.009542986900279564, 0.04781520586194737, 0.04218731088829892, 0.034185150638222694, 0.10524433013051748, 0.028525608791304485, 0.08898648180599723, 0.05428157334348985, 0.0180638523971928, 0.03238675803212183, 0.17790316949997628, 0.17447776187743458, 0.2112157376749175, 0.09003956815493958, 0.1677060095327241, 0.31296198229704586, 0.18615978716739587, 0.14936030895582267, 0.1891536329473768, 0.11235273083938019, 0.15878722311130591, 0.21292465526078427, 0.14133689020361218, 0.16527143945651396, 0.11757403745182923, 0.20247018124376023, 0.14467467181384563, 0.1162274032831192, 0.1745715896998133, 0.0958426846191287, 0.13468962189342293, 0.12902506228004182, 0.321980282664299, 0.12877906619438104, 0.1229582806783063, 0.09370098382766757, 0.1025599098897406, 0.11305662949702569, 0.16165365358548506, 0.08517639232533318, 0.13667891014899525, 0.1656304251934801, 0.236700888723135, 0.12846934209976876, 0.15822060565863336, 0.16678656744105474, 0.1857361506138529, 0.1720804162323475, 0.1646651548466512, 0.1050138860674841, 0.12164489472551004, 0.09972551305379186, 0.15718712897172996, 0.12741934987051146, 0.09387432916888169, 0.19586118230862276, 0.20899918090019906, 0.0643701134249568, 0.15332308917173318, 0.1772867747183357, 0.1413067089659827, 0.11923777817615441, 0.20699923964483397, 0.1418047808110714, 0.10580119024962187, 0.12131481458033834, 0.08545598267976727, 0.07708060102803366, 0.10866540191429001, 0.17911269888281822, 0.11531908916575567, 0.1337073610297271, 0.12411537287490708, 0.09226577369762318, 0.10200842376798391, 0.252134846257312, 0.09693930577486753, 0.07216175818549735, 0.11298391768442732, 0.15699215871947153, 0.18328123805778368, 0.2543251301561083, 0.22765229855264935, 0.3467593773135117, 0.3636182312454496, 0.15231076920671122, 0.1348749433777162, 0.25162868627480095, 0.07700271199324302, 0.0992628268099257, 0.20097504290086882, 0.16130888994250978, 0.22792821803263255, 0.08048914705536195, 0.12800890180681432, 0.2473169762109007, 0.49631704496485846, 0.2976651159780366, 0.06991211604326963, 0.12321649039430277, 0.37287741154432297, 0.4156757364315646, 0.3499417065509728, 0.21680350069488796, 0.20930582444582665, 0.2336995383458478, 0.4835763829095023, 0.31534828139202936, 0.3359926279102053, 0.28328847885131836, 0.26693266364080565, 0.15931182567562374, 0.14699541085532733, 0.17601183455969605, 0.11536470028970923, 0.3353648744523525, 0.24205111020377704, 0.1980441923120192, 0.2527477262275559, 0.21849637771291391, 0.2893988224012511, 0.08141553734562226, 0.19789055841309683, 0.13440648280084133, 0.048351306202156205, 0.2022352452789034, 0.14638899053846086, 0.11673004845423357, 0.08183949959597417, 0.17401867865451745, 0.12385123276284762, 0.17404487010623726, 0.0655042032844254, 0.15554424641387804, 0.2718020480658327, 0.12759882238294395, 0.10910104853766305, 0.10616819627050843, 0.09964112365352255, 0.15534105231719358, 0.1421981275613819, 0.11771849755729948, 0.10751947840409619, 0.10019150376319885, 0.22568137145468167, 0.15583000465163163, 0.15470985190144607, 0.11549713675464902, 0.1765345779380628, 0.07903070388627903, 0.14018409991902964, 0.16695071863276617, 0.10728860686400107, 0.07667295754488025, 0.13755489885807037, 0.11328789458743163, 0.14708636168922695, 0.1794620222811188, 0.12643547409347125, 0.15531073537256035, 0.2820359303482941, 0.14924840496054717, 0.15933869566236222, 0.08885834725307566, 0.10031478679073708, 0.10554165739033904, 0.19052421940224512, 0.17342369843806538, 0.17006794922053814, 0.1439881029405764, 0.12888370986495698, 0.09726223416094269, 0.1188966514808791, 0.12439583853951522, 0.14085665025881358, 0.11993926124913351, 0.1092409828145589, 0.11659231941614832, 0.10339135956019163, 0.1266874141458954, 0.20638621039688587, 0.13013297425849096, 0.23530666210821696, 0.10704771336168051, 0.09006348651434694, 0.10220152804894106], [0.031869904337716956, 0.019971651989700537, 0.00532047068866502, 0.046888337204498906, 0.010288001387380064, 0.03492620248081429, 0.020073274483105967, 0.022824886654104506, 0.02297256640823824, 0.08622546853231532, 0.02927896925913436, 0.032650792971253395, 0.02115272361386035, 0.030907117429056337, 0.00641563129777621, 0.02652793893191431, 0.013816330897887903, 0.05709288641810417, 0.0912214404504214, 0.08026161390755858, 0.014853150217926927, 0.07319206611386367, 0.040941266143428426, 0.05129281318347369, 0.030391291715204716, 0.04179197603038379, 0.09132547343948058, 0.048955650201865604, 0.026626611494326165, 0.032500701025128365, 0.0403954220403518, 0.02638924298142748, 0.0407610506351505, 0.09248525942010538, 0.02858551325542586, 0.06256504742694752, 0.05321195788149323, 0.05176962652642812, 0.03371255099773407, 0.05702582001686096, 0.03926225159583347, 0.020811389965404357, 0.03402239383597459, 0.01606028776482812, 0.011527471127919853, 0.016600986876125847, 0.01610946119762957, 0.04410418588668108, 0.08640065270342998, 0.046178246914808235, 0.04290003050118685, 0.044060230388173034, 0.024438286865396158, 0.023874648181455474, 0.05569061916321516, 0.02361164122287716, 0.07787867356091738, 0.0179124661455197, 0.028441831768889512, 0.011308529929790114, 0.033435895307255645, 0.048131599955792935, 0.024874004734946147, 0.07766803593507834, 0.06970390757279736, 0.06741288157978229, 0.009661921366517032, 0.07601593887167317, 0.02373304301207619, 0.028209314781374166, 0.05721567411507879, 0.04163730058020779, 0.048516247887164354, 0.03838661911764315, 0.09544334640460354, 0.040187909068273645, 0.03943793109751173, 0.04932173002245171, 0.03970891762790935, 0.05485239771327802, 0.05925178128693785, 0.10815582211528506, 0.09474026198898043, 0.03519479038992098, 0.022054394873391305, 0.055982144948627265, 0.10033202158021075, 0.022338845234896456, 0.05756506536688123, 0.06764546981347458, 0.1736093863312687, 0.27941882078136715, 0.23684647519673618, 0.18037744744547776, 0.09742002747952938, 0.21584816410073213, 0.15257135379527295, 0.02482444284084652, 0.012081338907591999, 0.055653679716799936, 0.018194775729041015, 0.028252437378146818, 0.012578867076496993, 0.013266611511686018, 0.013500784124646868, 0.05768889800778457, 0.04094894715983953, 0.005133395615432943, 0.03011299736265625, 0.027267087483778596, 0.05946716187255723, 0.023953266641391174, 0.09928492669548307, 0.05480778742847698, 0.034191549223448546, 0.022794695238449743, 0.05992874888969319, 0.04308926034718752, 0.04456249557967697, 0.013980125010545765, 0.02038629456157131, 0.04741868696042469, 0.052916567839149914, 0.025213531783914993, 0.04751332902482577, 0.054365827036755424, 0.038576364650257995, 0.058063198280121596, 0.040737132275743146, 0.03874883807397314, 0.028239199159932987, 0.046378292609006166, 0.008934887209241944, 0.06162252835929394, 0.022798971705404774, 0.0687205610530717, 0.022571285887222205, 0.010016440646722913, 0.08438289311847516, 0.0448010447435081, 0.016507198069510714, 0.03085671245519604, 0.031841429615659375, 0.029493661131709814, 0.05181720879461084, 0.03060228217925344, 0.049295921943017414, 0.028970344391252314, 0.003721369330638221, 0.04446456940578563, 0.04663354391232133, 0.03529454182301249, 0.024841136498642818, 0.025664954346471598, 0.03077516272397978, 0.009445552664276744, 0.03436812439135142, 0.08046504549149956, 0.0963062597438693, 0.017067630675488284, 0.024448997540665523, 0.06829017986144338, 0.018421889881470373, 0.05514997263838138, 0.025844297937250564, 0.024982304012935077, 0.04805502727893846, 0.014510235582877482, 0.019595550206889, 0.01662826907288815, 0.04765506820487125, 0.08297739603689738, 0.05020714358293584, 0.012535602835539197, 0.029489756162677492, 0.032751887903681824, 0.04333993832447699, 0.04218718535932047, 0.06044453728411879, 0.08606793305703572, 0.023854823084548116, 0.03529698454907962, 0.025609521428123116, 0.0349675116927496, 0.03368422555338059, 0.015581036784819194, 0.024854072768773352, 0.030628266677792584, 0.008722245360591581, 0.014578614949381776, 0.03487752437857645, 0.00735976400652102, 0.006158900788120393, 0.0356040894985199, 0.05268989982349532, 0.031560271845332215, 0.03446006927905338, 0.02532588191596525, 0.02078364636482937, 0.08244184870272875, 0.018398046160915067, 0.024213488213717937, 0.09545360585408551, 0.05159822179536734, 0.013552691205404699, 0.04687524147863899, 0.005572034154153828, 0.07900972358350243, 0.026201794289850762, 0.008786662930755742, 0.018201357518721904, 0.01973080768116883, 0.052909650174634795, 0.06450732677642788, 0.014704895405364888, 0.03132350044324994, 0.012250301760754414, 0.028620491735637188, 0.01592684367538563, 0.019670038084898676, 0.025091783941856453, 0.015999051675732647, 0.039677080764834366, 0.05774092807301453, 0.014620896162731307, 0.07523244127099003, 0.013194830988400748, 0.030461832215743403, 0.020310571749827692, 0.029224513431212733, 0.0724343867706401, 0.017996065052492276, 0.06962853590292589, 0.01534552576153406, 0.04636988556012511, 0.03309743864727872, 0.02585366172050791, 0.02982359199917742, 0.023941684048622847, 0.013058251219003328, 0.012735275335476866, 0.0363430785946548, 0.05794267010475908, 0.04311045778117009, 0.05435553026784744, 0.0694248600463782, 0.057757518254220486, 0.052984458660440784, 0.03758954742391195, 0.008630164765885897, 0.03217788120465619, 0.11825687438249588, 0.03305438560034547, 0.03766237458746348, 0.11700793568577085, 0.14894056719328674, 0.08719006034412555, 0.06188776091273342, 0.036420407838055065, 0.02510033517942897, 0.03473254519381693, 0.042696531063744, 0.11913324307118144, 0.02651058879148747, 0.0029521341119626804, 0.021101078617253473, 0.042788404705269, 0.19561935242797646, 0.11649750093264238, 0.06021627810384546, 0.011655921199625092, 0.11121270379849843, 0.2349476899419512, 0.1541702537132161, 0.0585308378296239, 0.0761478121525475, 0.07533161594931569, 0.039238876064441035, 0.03580777892576797, 0.05113958979823759, 0.03980755626357027, 0.08079110192401068, 0.06663891739611115, 0.1488467258002077, 0.03298912749492696, 0.056471239775419235, 0.035549528497670374, 0.07803820392915181, 0.05466211613799844, 0.07025464052068335, 0.012118883098342588, 0.06776367739907332, 0.012652475403488746, 0.035829417407512665, 0.04488556306543095, 0.03346295528379934, 0.026777210645377636, 0.018258627570633377, 0.03568373933168394, 0.005815147314154143, 0.016298299189656973, 0.06259759675179209, 0.022541618639869348, 0.06653618719428778, 0.022297970285373073, 0.051529367454349995, 0.06773824590657439, 0.03281017406178372, 0.03910170342507107, 0.02053092260445867, 0.07922025264373847, 0.019318185447316085, 0.02409213561830776, 0.038184127304703, 0.07912675730351891, 0.0415198224197541, 0.05100867664441466, 0.03064314355807645, 0.06874070675777537, 0.06139759400061198, 0.07222552012119975, 0.014817532218460525, 0.027852496963792613, 0.028321702232850448, 0.06032390732850347, 0.048227348032274416, 0.013427258070026125, 0.052862559844340594, 0.024678025161847472, 0.01130421699157783, 0.02820945218471544, 0.08394365704485349, 0.011677905734229301, 0.0431127173027822, 0.1189457502748285, 0.05862180223422391, 0.05401078358824764, 0.007361056615731546, 0.02025629743002355, 0.012000723010195153, 0.04261111707559653, 0.03427959932014346, 0.04635719356260129, 0.019397592704210962, 0.05053897434845567, 0.014314420554520828, 0.0289753214456141, 0.060104190904114924, 0.015110325168019958, 0.015281806234270334, 0.025727165829656378, 0.03086397617257067, 0.07306942769459315, 0.14287724612014635, 0.17325893656483718, 0.16675253212451935, 0.04170701326802373, 0.12223037545170103, 0.1498824009405715, 0.11461456625589303, 0.06089100654103926, 0.15122758304434164, 0.12335259094834328, 0.12786802436624253, 0.10070285453860249, 0.08548125810921192, 0.0802756052996431, 0.09048814765576806, 0.07380951262478318, 0.1544145941734314, 0.1241867547588689, 0.14107170514762402, 0.08513263360198055, 0.18781211493270739, 0.11441275637064661, 0.17896091059914657, 0.1698086131364107, 0.0606340996122786, 0.26383357707943234, 0.148849684212889, 0.095352653414011, 0.15914436323302134, 0.09553210557039295, 0.15987348982266017, 0.10049018130770751, 0.20453632037554467, 0.14499872656805174, 0.13717312791517802, 0.15009018193398202, 0.17444545003984654, 0.12087387538381986, 0.16548610079501355, 0.12343624074544225, 0.11872772340263639, 0.04688486310520342, 0.17126223870686122, 0.1916973657373871, 0.07507770814533744, 0.11513169136430536, 0.17241363120930536, 0.15338273239987238, 0.13060427111174377, 0.13366956662918839, 0.1569513923355511, 0.08558368975562708, 0.10219337205801692, 0.20155202836862632, 0.11746199774955, 0.13165849739951746, 0.1564058908926589, 0.11850995437375136, 0.10717533901333809, 0.12931101050760063, 0.1503917228962694, 0.13501565796988352, 0.23147538197892054, 0.12739921095115797, 0.10700442282749073, 0.14715886994131974, 0.16940644543085778, 0.12890289883528436, 0.2160768982555185, 0.2243499636117901, 0.19630472707961286, 0.21166061237454414, 0.13901070931128093, 0.1679894607514143, 0.1114906860249383, 0.15306714576269898, 0.23984041597161973, 0.17137092644614832, 0.2429803774825164, 0.10457324542637382, 0.19219697107161793, 0.22708304838410445, 0.21726584088589462, 0.11375082510390452, 0.13693414788161004, 0.215809664023774, 0.23514954053929873, 0.08386441772537571, 0.14368672482669353, 0.22272943199745246, 0.3581223690084049, 0.4066044017672539, 0.33410399353929926, 0.2688766936106341, 0.22774343937635422, 0.4673015847802162, 0.23770335635968617, 0.15564815726663384, 0.13709475712052413, 0.1476485143814768, 0.1763652427388089, 0.11859929029430662, 0.19492157415619918, 0.11580042833728449, 0.1886877372328724, 0.13898606491940363, 0.2549505223120962, 0.13253368543727057, 0.1234936990908214, 0.1328531125826495, 0.13477153464087419, 0.18758750627083437, 0.1961774339101144, 0.1093172976481063, 0.1151080783456564, 0.06303810847124883, 0.11992446918572698, 0.1564030817576817, 0.07369281817227602, 0.07272042999310152, 0.1656225813286645, 0.0869472465877022, 0.11180901394358703, 0.1408998050859996, 0.1911646207528455, 0.11337603628635406, 0.1364500131458044, 0.11813619014407907, 0.1476446060197694, 0.10776943034891572, 0.09227955474385194, 0.07779561408928462, 0.09848448607538428, 0.14756323610033306, 0.25234749913215637, 0.08224860871476786, 0.09605171411697354, 0.10198502109519073, 0.12806435168853827, 0.14269921210195335, 0.12636281656367437, 0.13118379430047103, 0.10527353427772011, 0.15565895954413073, 0.1058273274185402, 0.10237374702202422, 0.12072697255228247, 0.16160276345908642, 0.1922027114778757, 0.1313974649778434, 0.10207391596798386, 0.11782212342534747, 0.16593263112008572, 0.13300841567771776, 0.12469672810818468, 0.11251597279416663, 0.11819558909961156, 0.17944318614900112, 0.1031674158626369, 0.13639167270490102, 0.10331053246877023, 0.07589401291417223, 0.09964785472090755, 0.1719659880868026, 0.1717248095997742, 0.15132720555577958, 0.09215861944747822, 0.1306449832128627, 0.09873565938323736, 0.1755824847412961, 0.2567991773997034, 0.15092777913170202, 0.0718822560406157, 0.17040383762546948, 0.1788256514285292], [0.041828939225524664, 0.03104307209806783, 0.025233536692602292, 0.04837535009054201, 0.06742829789540597, 0.048140858566122394, 0.01234224664845637, 0.06965611835143395, 0.028573241949613606, 0.0377147269568273, 0.016939170425757766, 0.0731086130919201, 0.03577766893431544, 0.04149756647114243, 0.030511548476559774, 0.030341049589748894, 0.012980899075046182, 0.08536124562046357, 0.04552777610453112, 0.012601346093496042, 0.06886462082288095, 0.039306542969175746, 0.037863624681319506, 0.028009204626349465, 0.018805833832759942, 0.10173356958798, 0.06316204967775516, 0.029147123119660785, 0.051450979696320634, 0.026060050020792654, 0.056333792329366715, 0.03939408077193158, 0.03790632149736796, 0.015931013273075223, 0.038948103452899625, 0.04136672456349645, 0.04290730439658676, 0.013773968260336136, 0.031137293470757346, 0.07763033652944223, 0.03650014588077154, 0.022043765622324178, 0.032269252730267386, 0.059181668263460906, 0.07019161818815128, 0.013006501897637333, 0.022610313525157313, 0.027372696370418583, 0.05492777956117477, 0.02293079748882779, 0.033853072207421064, 0.048136685575757704, 0.08348036690482072, 0.023964659244354283, 0.023639637577746595, 0.053142411434756856, 0.042177441596452675, 0.015153373125940561, 0.03404073463752866, 0.03912100435367652, 0.027518254006281495, 0.060571043352995596, 0.03618374500157578, 0.0314539996907115, 0.006542797241958657, 0.07100309178765331, 0.06449554062315396, 0.02499923006897526, 0.0095054545838918, 0.019146721344441175, 0.018238385174689547, 0.04231087890054498, 0.022753389419189522, 0.07306213344314269, 0.07717339747718402, 0.07872701875333275, 0.07063132245093584, 0.03011927381157875, 0.04337297958721008, 0.023580839125705615, 0.00852583661409361, 0.06388251816055604, 0.0767604885622859, 0.052060561986374, 0.07307417743972369, 0.03666797812495913, 0.05363147572747298, 0.057180369938058515, 0.0908886461651751, 0.0543168402010841, 0.08309020248374768, 0.0601440684071609, 0.010418707588022309, 0.10733059461095504, 0.033686854876577854, 0.028560706015144075, 0.059055243618786335, 0.01864613891978349, 0.02097212982230953, 0.07430991863033601, 0.04702276177704334, 0.047107273313616, 0.027671426501391188, 0.034713885480804105, 0.02002648270821997, 0.017445067475949014, 0.01237994181324861, 0.028147744513782005, 0.03424250041799886, 0.08840454981795379, 0.015612948286746229, 0.03235863954094904, 0.02493745624087751, 0.07369332707354001, 0.027936173902292336, 0.09007196141672985, 0.021865852044097016, 0.039017504014606984, 0.039122944963829856, 0.0753629303404263, 0.0770017077614154, 0.04043681946183954, 0.04986330953293613, 0.019535272548507367, 0.07373336742499045, 0.06656617165676185, 0.06332850788852998, 0.010578598427985395, 0.07748101811323847, 0.04356114752590656, 0.023622533406264017, 0.006884071518600519, 0.044875846443963904, 0.024373451148026755, 0.04111241642385721, 0.05013038091627615, 0.039702878666243384, 0.05798106840146439, 0.043650893960148096, 0.024307378800585866, 0.02609848733326154, 0.09969774740082876, 0.0318818295906697, 0.021868706980187978, 0.058579549858612676, 0.013806414108590355, 0.059608521072992256, 0.045453235640057495, 0.022405122839180485, 0.013155705811056708, 0.053571581441376886, 0.025623502642182366, 0.07278713677078485, 0.07781852143151419, 0.15934216976165771, 0.0542234161070415, 0.045800360584897656, 0.009559993532353213, 0.009060827549546957, 0.03712662708546434, 0.006907217620339776, 0.01884996914304793, 0.016439432777198296, 0.01316998473235539, 0.036721792737288136, 0.024919832990105664, 0.09048985756401505, 0.0407026151993445, 0.05807512692574944, 0.04623855171459062, 0.021355466484757404, 0.058716356089072566, 0.054561492787407975, 0.06252413855067321, 0.03360447393996375, 0.0322529305703938, 0.13388410583138466, 0.01605900194096778, 0.02841099235229194, 0.0075086871760764295, 0.0442820943758956, 0.023519572502534305, 0.03403045143932104, 0.03749513266874211, 0.03319850304563131, 0.054457704070955515, 0.03437202936038375, 0.03726556730855789, 0.03469670497413192, 0.007499517623468169, 0.08379600782479558, 0.014041626576467283, 0.04143931423979146, 0.0302160396905882, 0.05594367879842009, 0.011426226917787321, 0.05727870323296104, 0.028133346000686288, 0.05971199766333614, 0.06706135972802128, 0.04531549981662205, 0.03476213610598019, 0.064300224318036, 0.014262153002034341, 0.026150992373004556, 0.018646015087142587, 0.04922888607585004, 0.02176112525298127, 0.08628314400890044, 0.04888168309948274, 0.012994433304161897, 0.015935299918055534, 0.03096194305856313, 0.044945291110447476, 0.04709093079769185, 0.053160609743957005, 0.04469578360606517, 0.016871871626270667, 0.01044505340645888, 0.06427326612174511, 0.06062354160738843, 0.01939795402410839, 0.03363102162256837, 0.007247669173271528, 0.026106687428961908, 0.04785234208351799, 0.01455756340042821, 0.016274886338838508, 0.046362031517284255, 0.04292996407353452, 0.019005845600206937, 0.05797215923666954, 0.01703766148005213, 0.053645772460315905, 0.061710127230201445, 0.01087666189830218, 0.027090503834187984, 0.017093482859698788, 0.08103652125490562, 0.07795268137540136, 0.0585634210812194, 0.027383898983576467, 0.055771025562925, 0.09902674412088734, 0.004661800206771919, 0.08547209788646017, 0.07807486517620937, 0.03477770509198308, 0.06609075609594584, 0.050126710041825256, 0.05527035492871489, 0.051307981833815575, 0.05125040813748326, 0.07358929408448082, 0.005331336154735514, 0.04624238543744598, 0.1445196537034852, 0.05051206025694098, 0.004569448622143162, 0.0158929457621915, 0.022714193843837296, 0.0954277061724237, 0.13979280234447547, 0.05998696040894304, 0.02641428092361561, 0.03743208658748439, 0.011073909483716955, 0.09211425682795898, 0.0411277852420296, 0.04834930791652628, 0.04426892401118364, 0.06550193697746311, 0.11162623018026352, 0.10788168039705072, 0.03663609376443284, 0.0562804357281753, 0.04409101552196911, 0.03441393229046038, 0.0405322248781366, 0.07509390477623258, 0.01259756665344217, 0.08831490177128996, 0.005956887766452772, 0.04258503758215478, 0.0336033950692841, 0.026162620766886642, 0.021164177284975137, 0.026180057420528362, 0.016330885833927562, 0.03073720886771168, 0.043842172981905084, 0.023446804710796902, 0.05441715481824108, 0.05445037589275411, 0.022966805645929914, 0.013008281355723739, 0.01530660838553948, 0.03125291923061013, 0.05262476385438016, 0.03489597035305841, 0.030088641348161867, 0.03984858388347285, 0.06441093409167868, 0.03904948676271098, 0.0177795784547925, 0.06992665704871927, 0.030347760301083326, 0.03200777926083122, 0.054434487995292456, 0.04067414386996201, 0.1280717070081404, 0.0663846635392734, 0.09549285231956414, 0.07208709897739546, 0.030294430841292654, 0.030486195015587976, 0.012109686404333582, 0.028002232679032853, 0.04341219551861286, 0.007451949774154595, 0.028125636146536896, 0.02193392946251801, 0.042417327474270544, 0.010995485254430344, 0.06411171371915511, 0.03226696267457945, 0.03322958673483559, 0.02318503098961498, 0.03248699801042676, 0.04078384941177709, 0.05583112680220178, 0.02538740129343101, 0.0811606388805168, 0.03277569769748619, 0.024619050290701643, 0.030208684370986054, 0.03921897802501917, 0.0651996156999043, 0.01626011123880744, 0.05195432036582913, 0.08388728435550417, 0.004452815661872072, 0.05755271602954183, 0.011428433004766703, 0.02564480864176793, 0.04158259369432926, 0.030690719040908983, 0.02024421272134142, 0.03781437660966601, 0.0665070576859372, 0.05133555071162326, 0.059290566348603795, 0.30199042388371056, 0.18915416220469133, 0.10201246783669506, 0.12381740100681782, 0.1752032515193735, 0.1033400148153305, 0.08759670638080154, 0.16004701836832932, 0.09001541909362588, 0.10166435901607786, 0.16491347152207578, 0.14568796886929444, 0.05689704424834677, 0.1450687920940774, 0.15818557968097074, 0.08547154827309505, 0.07446044483887297, 0.25745331229908125, 0.16809281520545483, 0.10123055800795555, 0.25905568631631987, 0.16124034433492593, 0.11515735355871064, 0.19387489317783288, 0.12497587741485663, 0.243654515594244, 0.1357716681169612, 0.20671572057264193, 0.15584687303219522, 0.15284571264471325, 0.08867986540177039, 0.17416517436504364, 0.1460115486489875, 0.09909530329917159, 0.12715261775468076, 0.10599680511014802, 0.12474985740014485, 0.08161424632583346, 0.16619538702070713, 0.1263642143458128, 0.144185298787696, 0.15888224515531743, 0.1368574598538024, 0.14587170258164406, 0.2046100092785699, 0.07173926835613591, 0.09828152946595635, 0.1132852550862091, 0.06110466364771128, 0.14618737064301968, 0.12967067477958544, 0.17338019077266964, 0.10594954514609915, 0.10030452734125511, 0.0735220851908837, 0.11828424648514815, 0.10030333311962229, 0.12134072104735033, 0.15513240279895918, 0.053228320753467936, 0.11135680428040878, 0.10718427531953369, 0.2181846722960472, 0.13947220811886446, 0.11699941328593663, 0.20667413994669914, 0.16929646847503527, 0.1528928436871086, 0.13261242264083453, 0.12800351423876627, 0.14757762104272842, 0.17027448170951434, 0.11774572038224765, 0.1723895160747426, 0.13807521308107035, 0.17526854015886784, 0.17982454997088226, 0.1358792023467166, 0.21648572917495454, 0.10009827983698674, 0.13992609376353876, 0.18164769214178833, 0.23575061400021824, 0.09905158528792006, 0.24346395581960678, 0.15932915546000004, 0.23028311452695302, 0.24542454204389028, 0.15005401601748808, 0.12851450539061002, 0.15895320634756768, 0.27777467614838053, 0.1315588884587799, 0.16431104099111898, 0.20259997142212732, 0.1305863442165511, 0.1552045310714415, 0.1645342247294528, 0.14027977335665906, 0.16602750388639315, 0.16261926319982323, 0.13676057862383978, 0.12449897586234979, 0.14367428049445152, 0.1081372709678752, 0.15112559923103877, 0.1547117925115994, 0.12227684152977807, 0.09113983982907874, 0.16957297149513448, 0.09647425144378628, 0.1054718429222703, 0.28109629505446976, 0.21388406306505203, 0.13140053195612772, 0.10917076122547899, 0.14914093858429364, 0.10139054299465247, 0.14246076132569993, 0.09368416972990547, 0.09927263164094516, 0.07978204571242843, 0.1826793367841414, 0.18344650204692567, 0.1818927111370223, 0.09425916030470814, 0.25326124152966906, 0.1325265879609755, 0.1231851013643401, 0.14512369914778642, 0.10091391964150326, 0.07124496238040072, 0.1355971217687641, 0.15345822620604718, 0.20252434190894875, 0.1235992248569216, 0.165118402668408, 0.1749938963247197, 0.19084184164447443, 0.10710701053696019, 0.11488561385444232, 0.164301690778562, 0.137477966557656, 0.1039872354428683, 0.13578479098422186, 0.09938931252275195, 0.14366745443216392, 0.060064035201711316, 0.19371916939105305, 0.22009633614548615, 0.17119990848004818, 0.12007400473313672, 0.14216471649706364, 0.20512883072452887, 0.34067137113639284, 0.11875571975750582, 0.1340610406228474, 0.11646372345941407, 0.09611861088446208, 0.10698115586170129, 0.11286604936633791, 0.16052088008395263, 0.10637753110911165, 0.10101949290505477, 0.2915386775774615, 0.07685591772730861, 0.11868189514747687, 0.08890965807118587, 0.10534630715847015, 0.131147153409464, 0.11571916698345117, 0.12436309243951525, 0.10009150127215044, 0.12208075848008905, 0.1665781079126256, 0.15102018203054154], [0.02561384199985436, 0.010928109271584876, 0.03886454186535307, 0.008045627203370844, 0.03888938981773598, 0.04655394496928368, 0.051357986472014866, 0.03444405245993819, 0.053226237650960684, 0.020348177856898735, 0.06378356739878654, 0.04547668581030198, 0.005959705807202096, 0.056684472797704596, 0.003878509983353849, 0.02066833951643535, 0.04294229644749846, 0.012600424982208227, 0.026329382622082318, 0.02852848917245865, 0.10092642504189696, 0.05050141064982329, 0.011470659087145967, 0.013926099204192204, 0.008562436792999506, 0.07187914835023028, 0.014768906702686633, 0.025942658373553838, 0.0262837579274284, 0.01596180010320885, 0.026516335983095423, 0.038725011316793304, 0.004290396006711359, 0.01823726898458387, 0.054207511246204376, 0.017883555464712635, 0.06128706743142434, 0.011796035288300897, 0.02527376533752041, 0.005062287689984909, 0.02108722293217267, 0.03147723272975002, 0.038156717882624695, 0.05730504396238497, 0.03898007941565343, 0.04708368743636778, 0.029582674748131206, 0.035569565636771064, 0.055759449755506854, 0.03610429194356714, 0.0212185398143317, 0.040946467114346366, 0.03148116484018309, 0.05790781376085111, 0.07866003377629177, 0.006260059757291206, 0.032989680500967164, 0.07499448582530022, 0.033605403532939296, 0.028903077822178602, 0.050884738830583434, 0.04334547856290426, 0.02876818845314639, 0.027104418891082917, 0.014989747798868587, 0.05776465644261666, 0.01245751787376191, 0.03394931222179106, 0.03412556169288499, 0.0720655962026545, 0.03347704506346157, 0.019220394980428473, 0.025660855994958962, 0.03705629353810634, 0.01572673182402338, 0.07011875031249863, 0.006236958184412548, 0.011173081617536289, 0.035373265455876074, 0.022009296043376838, 0.032803480313824754, 0.026570791811017052, 0.03152768859373672, 0.01570023672788271, 0.033470707546387396, 0.09531555790454149, 0.0549243970641068, 0.030427857967359678, 0.04794896886284862, 0.05269695658768926, 0.11384498540844236, 0.05186242297557848, 0.08504829169916255, 0.04340476216748357, 0.031138419838888303, 0.08247088321617671, 0.092264057004026, 0.02653473276378853, 0.08224654596831117, 0.06456678001476185, 0.030611696852637187, 0.03624944415475641, 0.022777504553752284, 0.07937725886170353, 0.05937952907489879, 0.005062225773664457, 0.03612149280628987, 0.0466287398843893, 0.022655541276825324, 0.02446305169723928, 0.0580338787819658, 0.04009503458759614, 0.05325964871527893, 0.028598150970148187, 0.055703609716147184, 0.0390653916235481, 0.07023488158094031, 0.03244854203824486, 0.1164165245635169, 0.05113457203177469, 0.03021799387144191, 0.03135586656363947, 0.051550225620823245, 0.07162914212260928, 0.04447101888113788, 0.014913304043667657, 0.06102788062500102, 0.020477204683369825, 0.044420820860458274, 0.0037496248010679013, 0.04395694039495928, 0.02342394825869373, 0.030809021621410335, 0.01898829698828714, 0.0288194890932313, 0.08291659929922648, 0.0790958364627191, 0.019786659594891325, 0.062179225629993846, 0.0220087125032608, 0.06325272909764733, 0.03691113454156688, 0.008915164740756154, 0.023006866353430917, 0.0030698387334788485, 0.04498961301786559, 0.017711896283019866, 0.03561214370919125, 0.028081327809819152, 0.058636994633291445, 0.08613776788115501, 0.04207673003630979, 0.04369102591382606, 0.046982714640242715, 0.09181589140955891, 0.02243175873133753, 0.010131379389869315, 0.023197532997333577, 0.021592534745910337, 0.022704889432394078, 0.0094940076981272, 0.05773857355649982, 0.07965729026389973, 0.023270767281896303, 0.06576816019202981, 0.038383039845419784, 0.023153731865542274, 0.0347370303102902, 0.03349569120577403, 0.020190666130344783, 0.019562722682686787, 0.01190788924161877, 0.06214597062872989, 0.012522028742491134, 0.039223140837358575, 0.030896349078310386, 0.027387897251173854, 0.042104448191821575, 0.038025329754288704, 0.024213223585060666, 0.03370473088164415, 0.008012825124231833, 0.046656227337994745, 0.024256794014945626, 0.012338751344941556, 0.06411735913051025, 0.07131840701081923, 0.04210767462583525, 0.048451692065490146, 0.04599006540541138, 0.04710791452920862, 0.08298197614827327, 0.025138195737132003, 0.024108764815277288, 0.01579172699712217, 0.05606960811253105, 0.025578726116301756, 0.03291956069214003, 0.020526172859328132, 0.06410291311996323, 0.06231510905282838, 0.08911319822072983, 0.02286019252746233, 0.02978045752804194, 0.03721004278798189, 0.03790999237181885, 0.04412249615415931, 0.015585837420076132, 0.03763511783576437, 0.04752794127645237, 0.11610795397843633, 0.018416492135397027, 0.023857864617769207, 0.011268930626101792, 0.062165268164660246, 0.03249830918918763, 0.04204189404845238, 0.007700973822336111, 0.03555083467758127, 0.029611590517950908, 0.014496203478691834, 0.05743695117001023, 0.01563927883814488, 0.04678303535495486, 0.04784183496875422, 0.047104494712714634, 0.04368613028366651, 0.031654130201786757, 0.024509563576430082, 0.044119982181915214, 0.05138644762337208, 0.04810242973534124, 0.0142096106428653, 0.026595497271046042, 0.020940092791404043, 0.04464004873963339, 0.053711532681648216, 0.04716265194916299, 0.037689960428646634, 0.03204954309122903, 0.020094225948144282, 0.018144879656444703, 0.012440520571544766, 0.04095658067879932, 0.028250020097142885, 0.04362004097285015, 0.04173307240541492, 0.011355098636288728, 0.029091971793345044, 0.012208812737039157, 0.028281022362144928, 0.06371724738606385, 0.02747240030605878, 0.06353084703109094, 0.05793589153992278, 0.03402171530095594, 0.05614360235631466, 0.0225511825909572, 0.0195271487879966, 0.07406850265605108, 0.06402587903929607, 0.03696733081181135, 0.14273194463125297, 0.018366692754040872, 0.05529829700078283, 0.04561173463506358, 0.039611327328852246, 0.06030214671045542, 0.02534336267438318, 0.018663696013391018, 0.009692625924279647, 0.12613721724067414, 0.130611192168934, 0.07932966641549553, 0.0783121692282813, 0.09893152530172042, 0.056028672094855986, 0.060630069114267826, 0.011948549604442502, 0.08823307044804096, 0.07093202202980008, 0.03276389118816171, 0.030967222061008215, 0.02127061059166278, 0.05760087165981531, 0.07522139472088643, 0.042901241686195135, 0.013467570683652801, 0.016401002250079597, 0.032472714848284207, 0.012727183805379485, 0.05042441728125725, 0.029430998422737633, 0.04424614219793251, 0.11442202515900135, 0.13846136736018316, 0.034784134211284776, 0.04262005338179214, 0.01120353172466691, 0.03579040164394038, 0.04031850331063781, 0.041537796812398095, 0.11359111831656524, 0.04103698029315897, 0.017388469173706005, 0.04945841072393315, 0.020033690446455563, 0.0252655381004193, 0.014086036693437822, 0.023576308208118592, 0.04511589517018624, 0.04110701528510877, 0.06856421301407473, 0.04316072704802666, 0.0520388251170516, 0.052744742416377575, 0.03796439730961408, 0.04417430230283311, 0.03567676738436733, 0.08938094813908849, 0.054210238956979344, 0.0034818246287094162, 0.031194236129522324, 0.031842752758945735, 0.040047109659229, 0.02345325079347406, 0.035190793818661144, 0.03723743524668472, 0.03694470506161451, 0.010580384671421987, 0.03203537188736456, 0.05759258674723761, 0.0037012032698839903, 0.0832686164815511, 0.029083466356886283, 0.020921295675049936, 0.06448490797941174, 0.015948205654110228, 0.04067948394055877, 0.039063135494611094, 0.040981930747096024, 0.04987815248646906, 0.05119755365220564, 0.03925359009632042, 0.09108406425054584, 0.03204063053375908, 0.024582879285195043, 0.023426960954176526, 0.0251599105540663, 0.11824525786297661, 0.012311425043403037, 0.03463557914697698, 0.1003690967336297, 0.1429119056888989, 0.12291287311485835, 0.06093357104275908, 0.09585357510617801, 0.10840915316449744, 0.12894177889185293, 0.1575849133410624, 0.2384232005902699, 0.1250282060354948, 0.15541138925722667, 0.11617597032870565, 0.10329523828944989, 0.16463204233774117, 0.09201808805976595, 0.1831789556890726, 0.13999720423349313, 0.13655806306217397, 0.12633798218199185, 0.10058739501982927, 0.17379598346139702, 0.12502393126487732, 0.11913328378328256, 0.1233851606292384, 0.11302987486124039, 0.17728673400623457, 0.09254638185458523, 0.0744153494015336, 0.1590435736413513, 0.08722237896706377, 0.14179487419979914, 0.08751587928938014, 0.11160266465906586, 0.1896932175649064, 0.15037689012076172, 0.11907756248755114, 0.10256484283932618, 0.09032956723655973, 0.1437298660831792, 0.08701275235840253, 0.12251370453408786, 0.09131739208740847, 0.19771062449685164, 0.141835694866521, 0.1280986719897815, 0.1697535025221961, 0.10045554209500551, 0.11566761189273425, 0.104585805109569, 0.16481095845145838, 0.04985440376081637, 0.08954071599457945, 0.16278318368962832, 0.12362289215837206, 0.1778666236038719, 0.10546452152941908, 0.0764527457899281, 0.13010533074183123, 0.09800802557063953, 0.22840623238257, 0.10676144622266293, 0.09247211619679417, 0.1289898870246751, 0.08349052457404987, 0.11620118468999863, 0.176250923158867, 0.15166519741926873, 0.0826769746573908, 0.1077637577961598, 0.2982557399996689, 0.16616029318954262, 0.1271937641182116, 0.1574800525392805, 0.1499307533460004, 0.10154645677123751, 0.09758501326931374, 0.1985499316028186, 0.1901658714881965, 0.19022318055587156, 0.0950498775179897, 0.22784459537693433, 0.12549232398825033, 0.12408836718116488, 0.22738547144191606, 0.0999933783231037, 0.23777582389967783, 0.3133270341370787, 0.12981072440743446, 0.1511609780469111, 0.24139911947505815, 0.19579118463609899, 0.16149434713380678, 0.2291339747607708, 0.12343514151871204, 0.12540401944092341, 0.27233095254216877, 0.16416040621697903, 0.17557070537337235, 0.11935912737888948, 0.21292912002120698, 0.20772561138229712, 0.16026974070285047, 0.14144138459648403, 0.19001430033573083, 0.1436983413462128, 0.13273567174162182, 0.17567175280834946, 0.12247751147619315, 0.12292068983827319, 0.18680259053196224, 0.08670954898531948, 0.15208572628242628, 0.1537274689014469, 0.10555955035878078, 0.10822402167000941, 0.17278628264154705, 0.12626742811075278, 0.15848458292228834, 0.25343155381934984, 0.15657016422067369, 0.2333840195621763, 0.13431293996317045, 0.15705068915018014, 0.12015047562973839, 0.10247651115059853, 0.14939629845321178, 0.23734522557684354, 0.13041240854987077, 0.1413175519555807, 0.12150849561606135, 0.11443706149501459, 0.1217051622058664, 0.10947181364255291, 0.08226014381008488, 0.13607262553913252, 0.1507728017334427, 0.22037521403815064, 0.10904322378337383, 0.10270462105316774, 0.21271523221262864, 0.19054171203502587, 0.1796990345631327, 0.1361652184277773, 0.11641976796090603, 0.1740320593650852, 0.14326022485537188, 0.11587698065808841, 0.13456601995442594, 0.14115930401853152, 0.22601749056151935, 0.10608242944415126, 0.0728729103824922, 0.12284651239003454, 0.14532377198338509, 0.1456152434859957, 0.14393065816589765, 0.09100204293749162, 0.17895480378397874, 0.15965573436447553, 0.08385957298534256, 0.13346325127141817, 0.09578523984444992, 0.14797662677509443, 0.09326117778463022, 0.09353932285947458, 0.128031049189823, 0.11156869041068213, 0.1702192761003971, 0.17612443066069058, 0.08494491688907146, 0.16416230611503124, 0.12958159670233727, 0.16865380081747258, 0.22037019287901266, 0.18921118628765854, 0.07958414418888943], [0.07991137448698282, 0.07361051865986415, 0.056244446230786185, 0.05284964732293572, 0.0361472873150238, 0.012967359756917825, 0.03179729091269629, 0.011413843653696989, 0.017625691801575676, 0.019159844211701835, 0.03744560979040606, 0.0649406188832862, 0.01373199323591377, 0.05470163401748453, 0.007843163380000209, 0.01900683286865907, 0.01874438570147114, 0.010004740158495094, 0.023849834155823504, 0.059265067002602985, 0.03603895241394639, 0.06701281054743699, 0.04088319033118231, 0.02264462534471282, 0.05692316445388964, 0.0968439376779965, 0.05458692767258201, 0.02339769064980958, 0.009914638341537543, 0.0048167339243393925, 0.040315626322158744, 0.026417288530085768, 0.04311286997316139, 0.022674277325027754, 0.023325716744043996, 0.059378022727157385, 0.011973227923070746, 0.008286781941673585, 0.006686703493219933, 0.10050044075718947, 0.024152313192774142, 0.05346858321822115, 0.06597413628229074, 0.024569342511573007, 0.017902079470721737, 0.03828600933775306, 0.009341529005074074, 0.04447958877842341, 0.014002581126987934, 0.0575914400230561, 0.08144008674259696, 0.02649424457922578, 0.0538620487121599, 0.05043225436072264, 0.04302038565011961, 0.014396996569952794, 0.006535753200296313, 0.047304296134305854, 0.04281187183888895, 0.015550657075696757, 0.053659353338714154, 0.020876763421776037, 0.06405542245400803, 0.0184355318280203, 0.0184733109615211, 0.029470597726425955, 0.12383375370076724, 0.01584758230351976, 0.04436375606538994, 0.021033985074609518, 0.015591615145759923, 0.03209923899599484, 0.05495972838252783, 0.0353874095183398, 0.02135452162474394, 0.07011855353734323, 0.04726058151572943, 0.07161061133124999, 0.055445237151746235, 0.04295093419828585, 0.12369989231228828, 0.075299826583692, 0.0338998436262565, 0.02194877920140113, 0.022682911683140055, 0.0089498819849853, 0.0039095546567945606, 0.020926817253764187, 0.049381943220006566, 0.00931671413127333, 0.044071792624890804, 0.1337672621011734, 0.11007475986012391, 0.08352360315620899, 0.08658012521586247, 0.11624064828668322, 0.038323681601988416, 0.006509538848019604, 0.10463461213346038, 0.012393003612357591, 0.012297220760956407, 0.058580852645848475, 0.03567394128601466, 0.027938487706705928, 0.0319549247755536, 0.050859035924077034, 0.08495065729532923, 0.03663122866834913, 0.04078767295660717, 0.02074379600318415, 0.01189680113124528, 0.04935607746509569, 0.041438045379306586, 0.012973932216742208, 0.07654263810919863, 0.047206023907555, 0.036276544843401225, 0.044463585530008586, 0.007558722348351563, 0.045758657822651524, 0.061471649312547276, 0.02671497710980475, 0.035705164074897766, 0.006986769490010504, 0.0258035145899547, 0.05190519103780389, 0.050970743144197125, 0.02220465136425836, 0.060395268856414726, 0.05475264967286161, 0.02535498089023999, 0.03201974183320999, 0.06170763700668301, 0.020841683161311915, 0.0571789178731186, 0.039021137569631846, 0.004736172309744039, 0.03450432672564473, 0.07451576579894338, 0.041961786204150746, 0.07482218542801482, 0.027648011954235177, 0.06847214938274451, 0.0631044420546719, 0.02489877974481455, 0.0290993237202721, 0.04134504197697554, 0.08342664050204412, 0.02936829160898924, 0.05794900083648307, 0.017417098262480328, 0.0681033181026578, 0.017464812844991684, 0.024162923784128258, 0.010779377788172236, 0.04492019549278276, 0.033177824690937996, 0.07422528495745999, 0.03944657563364931, 0.024216234584205916, 0.019715572873662626, 0.0241323540852006, 0.041178122362388034, 0.00229876404877619, 0.04613006075045892, 0.02920371972556625, 0.021508876467123628, 0.06506504863500595, 0.040790516018335304, 0.028459565281601887, 0.0178901762701571, 0.0355644291266799, 0.046912557511989555, 0.0672029224889619, 0.01810438129385667, 0.0549968442480479, 0.02641352605340736, 0.037770685739815235, 0.024426923100171343, 0.03249366122430988, 0.020870319035436426, 0.047376074961253574, 0.007073221212652112, 0.01098080599747066, 0.018472632426502447, 0.01815767852323396, 0.04723108559846878, 0.014078794180282524, 0.026993581892124245, 0.027238577138632536, 0.04281198040449193, 0.01808790646360389, 0.057723523649786196, 0.04649933307830777, 0.02771785356370466, 0.09255058877170086, 0.04974965152463742, 0.08349364583513566, 0.03144733647682837, 0.024076766800135374, 0.035806608452860794, 0.044734768835561614, 0.04153570692454066, 0.018042013747617602, 0.04794335398556931, 0.03941898300711598, 0.023478039374042834, 0.024933819293177555, 0.04957409755193761, 0.012411330843211284, 0.01927156839519739, 0.06917260786784546, 0.027420061507395337, 0.0238556339338954, 0.060941828813936026, 0.008081374124490788, 0.08640868655805077, 0.01964549208059907, 0.025130273840789284, 0.06469138618558645, 0.08292360856596913, 0.029595353174954653, 0.053904765884258916, 0.03678936464712024, 0.0075743922664384756, 0.025790449398170625, 0.04666626965627074, 0.05830251758119889, 0.05071041300626738, 0.0331832936831883, 0.04471289625923548, 0.048576993734708855, 0.014902209996112754, 0.025444393145984838, 0.06079681230975049, 0.08431013380842549, 0.03969364719731467, 0.02214890462346375, 0.0243750355272953, 0.09271822084805795, 0.07854386858109917, 0.031052296781646352, 0.07337702118924685, 0.013327382804293717, 0.017728583155465976, 0.09665430071098463, 0.015492252173966594, 0.024832217155822685, 0.008770715661479958, 0.04634939380256193, 0.06697962339967489, 0.0472819316200912, 0.0412961162094559, 0.043708583007433584, 0.042181394062936306, 0.05860750550138099, 0.0847561823736344, 0.0718098088566746, 0.016595670554254736, 0.015450924302318265, 0.036870456367198906, 0.019839101870145117, 0.08613304527742521, 0.022928763580109392, 0.033538656043154855, 0.04257830651476979, 0.024509019052077616, 0.08146452757396869, 0.029789563467992202, 0.01347982757059591, 0.04570899584463664, 0.0460041619704238, 0.11418839198138032, 0.04751073023570435, 0.01743999881935971, 0.03239561630679028, 0.018198555169094886, 0.03215878722923143, 0.01574718626216054, 0.023676337840567743, 0.04562041309795209, 0.03178796444886497, 0.02713017099137817, 0.02074950926804117, 0.03024301485025457, 0.015052612372008818, 0.03205589757167867, 0.012823520510989641, 0.07452784372227532, 0.09127472580543586, 0.031683595584971566, 0.0995676518817033, 0.01170847034414432, 0.05242996323587639, 0.06022349771644388, 0.04961311670818499, 0.07207227298723799, 0.03207494744232722, 0.05854819475540093, 0.04583937295579484, 0.013912395341321826, 0.009749469347298145, 0.0605476474655526, 0.019797986040690115, 0.0066945431171916425, 0.013402712065726519, 0.048121856192925146, 0.025524020926760774, 0.042779695708304644, 0.0644612813900624, 0.011477437651982265, 0.03433829599193164, 0.030695075235728706, 0.03902043189321246, 0.08392827465598073, 0.054718712743903906, 0.023130235894184028, 0.029038995171764066, 0.08158250445766108, 0.007339462238763059, 0.023872565078948225, 0.05511691780494792, 0.02706783397921494, 0.029020033510667936, 0.03601502048383866, 0.025855471712670157, 0.01933757119279887, 0.03186105624107378, 0.05424461693369916, 0.054094850684383085, 0.02466462239889162, 0.07320569788238832, 0.020532330564622368, 0.019212742801755667, 0.07226566903825317, 0.000706822242396551, 0.029966050426342657, 0.045510029021118364, 0.04277514273832951, 0.014414139757198947, 0.05126519002286451, 0.016626796651897684, 0.01220237768055605, 0.07321079368037836, 0.04417982557788491, 0.02533810063531356, 0.010640468099154532, 0.03011109067925385, 0.014074428655606295, 0.041832250476415665, 0.03979859620864902, 0.06852766711797033, 0.19467694871127605, 0.1696969534137419, 0.0909942194287266, 0.11675173443342958, 0.2237269463283675, 0.07342048135719129, 0.05905680424932923, 0.05473073299175926, 0.09977294265159539, 0.0769428244924971, 0.1257384286395141, 0.11811202072671481, 0.12743159064224788, 0.11920120513864926, 0.0799329722566264, 0.11485483550599643, 0.11768448938216482, 0.08295795600861311, 0.0916348582665835, 0.20106896571815014, 0.14931377502424376, 0.1469978400106941, 0.14022373993481907, 0.07022050342389516, 0.16098022115017685, 0.17944121839744703, 0.12307760784668581, 0.07204120965408427, 0.15764523510422024, 0.11091091177825417, 0.1763240285217762, 0.12182637570159775, 0.11530710623732635, 0.11326533329806157, 0.07416692416050605, 0.09149511397949286, 0.13093948098165648, 0.09510688803025655, 0.1338019080992256, 0.13777550416333334, 0.13712776106383118, 0.16872686546828064, 0.11163046423877988, 0.1403542086482048, 0.112834178576512, 0.065982332985316, 0.10316778227154698, 0.12111794443002769, 0.0781900193542242, 0.1537067193005766, 0.18886976103697503, 0.0714456323268158, 0.14138510690203734, 0.13268594869545527, 0.08490987055535827, 0.08369840056236301, 0.0624456252636654, 0.11069629115185567, 0.1961404944636992, 0.24934728869370051, 0.09570818540773221, 0.10824319706963641, 0.16798578309161322, 0.11505629255303315, 0.1235277344073568, 0.15517304704657622, 0.20701791292854718, 0.1198616504137005, 0.24409347346850804, 0.15410173524703297, 0.20370166801980563, 0.18341166605906828, 0.10439059737005404, 0.19569316346730503, 0.16844224716935838, 0.15240110935909407, 0.19749087414571218, 0.20661835079746588, 0.23327691959483282, 0.16623869112559728, 0.24199186052594865, 0.15233174950948783, 0.10146489686199597, 0.1381185171859605, 0.10800343672079699, 0.09258824746523585, 0.18218923094017164, 0.1964899128569024, 0.15960259150181497, 0.0843081253447703, 0.17973448123250688, 0.21822229027748108, 0.21010075536157402, 0.22896974214485713, 0.13808467185923032, 0.2773572956877095, 0.2162840414260115, 0.07604934993599143, 0.11132327107978718, 0.11877192317375115, 0.11472116410732269, 0.11867116072348186, 0.1836008144808667, 0.0909223829263023, 0.10428583156317472, 0.14789227130157606, 0.1801754475704261, 0.10761209164879151, 0.16906027043504374, 0.13154299716864312, 0.10968701780906745, 0.10937721229025296, 0.1350797252463443, 0.21669090459389345, 0.11841867784304277, 0.22716002139661992, 0.24044887189354214, 0.15663721705121653, 0.17481403026197637, 0.15624532236584596, 0.21854460798203945, 0.17442859522998333, 0.20702532253095082, 0.14582769280033453, 0.08862399482833487, 0.11054654525859015, 0.14828781650534698, 0.15333594062498637, 0.11643819697201252, 0.16075608746281692, 0.17146830979202474, 0.10366429348609277, 0.28962287466440884, 0.15080371578889235, 0.09242959240717546, 0.12348550238779613, 0.11023448700351374, 0.16331248171627522, 0.22421806997486524, 0.11887235992721149, 0.28437769040465355, 0.08245027610766036, 0.15628557306315216, 0.16542239992746285, 0.08113119046070746, 0.14273516088724136, 0.09214223282677786, 0.21678724299584115, 0.12307516512061868, 0.14511631668678351, 0.08707538792597395, 0.11274224386683532, 0.07889458976153817, 0.14473128877580166, 0.1342195464032037, 0.14131250365504197, 0.09994214892919574, 0.09554728439876012, 0.13544717910034315, 0.1195768014128719, 0.11242186677243028, 0.13728235848248005, 0.13452169804700784, 0.12377195273126874, 0.1453943531960249, 0.09142819007060357, 0.09765990317932197, 0.2286652156284877, 0.13916487246751785, 0.11644308242414679, 0.1004273353942803, 0.09458446356334857, 0.08913049407835517, 0.17520999615745886, 0.08455937329147543, 0.1793360590402569], [0.05305257000561271, 0.032740797248802016, 0.033146618865430355, 0.024042030896193216, 0.04563718648361308, 0.08498877060732671, 0.045302865494574816, 0.0230510779989085, 0.019087064545601606, 0.09737546808485474, 0.035242562647908926, 0.0625669676810503, 0.030224623158574104, 0.006335680364697639, 0.11165263876318932, 0.00039480175733582916, 0.03644038390900407, 0.030650580301880836, 0.043308715535593886, 0.02506507171450981, 0.014381746495408671, 0.03224712570330926, 0.016314107359253933, 0.014374409835519535, 0.03220150100865534, 0.050607360500310145, 0.03961668097014938, 0.04822853546855705, 0.03698631622163313, 0.012752888408223433, 0.009663671986865146, 0.019991448248869607, 0.016612070745655468, 0.06587999633380345, 0.03517653440524425, 0.015474150556006601, 0.08730079725916896, 0.07254738320729562, 0.04908420205382364, 0.06326976711196558, 0.06815063913485833, 0.023266770710636462, 0.03637484081887773, 0.01344390507853989, 0.024995549016499093, 0.012540939513460865, 0.012034885552046555, 0.06282409174101693, 0.02894067544756191, 0.05016330343538097, 0.03582905439127769, 0.030636962104056562, 0.03709329065999814, 0.01705282673771892, 0.0395024563851101, 0.031591175722756555, 0.04482443045292582, 0.031060595264924423, 0.015273292316123843, 0.06356794254056045, 0.03364004613831639, 0.02352303303112941, 0.01715694454365543, 0.0222347257326224, 0.025785068615472743, 0.08883401498730693, 0.05015159531363419, 0.03664150508120656, 0.05438703125608819, 0.0724838859002505, 0.009710172839861895, 0.05170599011970418, 0.035628459083714654, 0.030378579361630336, 0.024610275136572973, 0.024653704770441567, 0.01973586107072021, 0.05062277342325874, 0.03320401953533292, 0.02799317762920899, 0.09823448663311345, 0.07075645109372479, 0.055192391255072186, 0.04801729055387633, 0.022995992829757075, 0.049344790035060475, 0.04293864592909813, 0.04714483022689819, 0.03891138453036547, 0.0470663101545402, 0.03307882982439228, 0.03994372806378773, 0.024374153431771056, 0.08158272837421723, 0.06968638101326567, 0.011207313709227102, 0.0410177879301565, 0.020132403720968535, 0.02616704481520823, 0.05150901818914073, 0.04651838634163141, 0.014141584114570702, 0.0005143467725637102, 0.11421361991337367, 0.034656878361212354, 0.03841721426163401, 0.04102694136755807, 0.036663645678865056, 0.0758254062384367, 0.032345543815089126, 0.03022217025448169, 0.022299310392034904, 0.02043275555063571, 0.04789628740400076, 0.051734756611819775, 0.03766104465882693, 0.0209596922754177, 0.02653215093804257, 0.02643013489432633, 0.025803277102698172, 0.027960238146728704, 0.022422009879457097, 0.036088292087827406, 0.050159059198839326, 0.0325912990208183, 0.02738882345147431, 0.028691354540309737, 0.005165773610185299, 0.027525222560923015, 0.01681894589481609, 0.04576131428724953, 0.010221652536919075, 0.023029714323846356, 0.04508008548457708, 0.03665018015141998, 0.03435447905212641, 0.030381181543426852, 0.09155688102224044, 0.03999255544372967, 0.03419782227969595, 0.044860694756997485, 0.05425469657140119, 0.030886361042835882, 0.04861976858228445, 0.014568925469315477, 0.02578170477811779, 0.042658753626580746, 0.016302168535600816, 0.10022345597722701, 0.05493803222530654, 0.04366212710738182, 0.07122888788580894, 0.041414866623069556, 0.04507707278909428, 0.025606442575476, 0.018350390950217843, 0.03747945850981133, 0.05764881694423301, 0.03190404482718025, 0.07058310575251069, 0.042871386145374606, 0.04095853485965303, 0.021474763119061078, 0.014476210444367357, 0.031076123538826193, 0.03370499890297651, 0.04024522831397397, 0.02348240913956293, 0.011895997915416956, 0.006728250616496163, 0.037085853916193755, 0.030590316214199578, 0.030650956888816187, 0.03877133150984134, 0.0027160482422914356, 0.04535463771649769, 0.03767592493178589, 0.031046030510749136, 0.019923162180930376, 0.04970241191663912, 0.029939095622726848, 0.04107463559401887, 0.032746985488172085, 0.028395151952281594, 0.00977606452735407, 0.03230832277664116, 0.05452139136780586, 0.026085140549444726, 0.012865192739159932, 0.04363288903342826, 0.030787915789655278, 0.04271989641711116, 0.008412434752764446, 0.019682443401377116, 0.03523924461166773, 0.034183790175510306, 0.032317985115306716, 0.01594362045372171, 0.037619358859956264, 0.013521173253788479, 0.015036844914512975, 0.04920901857050402, 0.013724830450623162, 0.03946422432948436, 0.007733442571147212, 0.026615249425438896, 0.0336684055094208, 0.023907299286552837, 0.017308875319681, 0.030267798341810703, 0.012886088225059211, 0.13054895693702356, 0.06345886125096253, 0.01974385930225253, 0.04983031237497926, 0.04537220838080559, 0.02975745519090976, 0.03189823656742062, 0.0329408124089241, 0.0500594163313508, 0.017801406926342418, 0.031582700820373635, 0.023672928202099035, 0.03623727462919695, 0.0450675224087068, 0.03934991153489266, 0.016111834373857294, 0.06478419620543718, 0.011807488959415682, 0.05059686695624675, 0.020717468844460588, 0.03701638889365962, 0.01643109188548156, 0.033701168572796245, 0.038017926937235255, 0.03124980814754963, 0.025351281178050807, 0.060862731986812184, 0.03176692986328687, 0.051125191285141876, 0.0274334065948746, 0.018754238029941916, 0.06765169876494578, 0.05817852209189108, 0.09463717894894735, 0.034698000976017544, 0.028289007022976875, 0.030523131069328104, 0.09883332771382161, 0.04269074655271002, 0.02566636061029775, 0.07580616298530783, 0.07344369404017925, 0.06611699504511696, 0.0486374647755708, 0.02161169996751206, 0.09170155147356646, 0.07326478471181222, 0.040797233515019925, 0.011704177761982595, 0.057029755519969125, 0.05810025307748999, 0.09708175741668258, 0.019907113131401793, 0.011263028219608324, 0.04675654874050191, 0.04238633538729378, 0.059560887914683135, 0.01993064472584852, 0.04857915147606816, 0.032463005012167354, 0.044473183407847366, 0.0658053642671023, 0.03881579930228846, 0.05379574566281267, 0.02542156383528241, 0.034541137250406403, 0.052778828623039384, 0.05015425517090729, 0.08100500330328941, 0.05073286573003445, 0.09684822601931435, 0.023467903757201772, 0.0036372059673470047, 0.03410552116110921, 0.0202908874489367, 0.03888896234067423, 0.02712257988085704, 0.019991153086136495, 0.03545160232377904, 0.01737779242518757, 0.06717017638896193, 0.043931132315524986, 0.02896890589701278, 0.0795741154413138, 0.030545770390225307, 0.018562870798632503, 0.0254078133231295, 0.0501524943725339, 0.016736963597525443, 0.10495038876043898, 0.018336039934573427, 0.03173809212499431, 0.06808472624314682, 0.04780185568545546, 0.008532250466357385, 0.07071591541171074, 0.03418852974261556, 0.027949644518750053, 0.036433781763272624, 0.01303056868658002, 0.010310284477392477, 0.045791899253215106, 0.04385389806702733, 0.014116374842290367, 0.06067873364580529, 0.01046447392686137, 0.05050538686503257, 0.10536239522376231, 0.04885093867778778, 0.00916753227024206, 0.024662971862458756, 0.04554070219663637, 0.014118077117018402, 0.03415811101772955, 0.010120254808238574, 0.03971919064809169, 0.047135815889175446, 0.0379539919751031, 0.02211036892341716, 0.03893131310386317, 0.03180048002728394, 0.05783464054444006, 0.039278349839150906, 0.035438655875623226, 0.07165364402213267, 0.043508116621524096, 0.04219246096909046, 0.022604927653446794, 0.03559133304016931, 0.019811339609857117, 0.053911944784756215, 0.008783731659475182, 0.043848595315856595, 0.03738619387149811, 0.029249076398887804, 0.021644658109705363, 0.01180474937427789, 0.024778872428994094, 0.033042117687208314, 0.04990289526592408, 0.03281091366495405, 0.06611221815858569, 0.15384534400488648, 0.09373712938811098, 0.20203540314521107, 0.19128856195935182, 0.137489718784179, 0.17612500063010625, 0.09649903832801751, 0.13195423010204518, 0.16932970312024864, 0.18382502959242888, 0.10600631138575928, 0.1577721211527075, 0.10300086265695946, 0.1634562632867268, 0.09112416567014796, 0.10511001412357603, 0.16515728272497654, 0.1553750197802271, 0.10781791846134833, 0.08373340618397508, 0.11359266537640776, 0.1258577558078936, 0.06564385257661343, 0.11601977156741278, 0.12815731098609312, 0.09160370672387735, 0.11586092651954719, 0.13925373341356004, 0.06825682986527681, 0.14182643964886665, 0.14306346327066422, 0.10655281706047909, 0.13239956620548451, 0.13870051024215563, 0.1951521403555359, 0.10652473928140742, 0.11715394285108362, 0.18144356166677816, 0.12550095495368752, 0.1024587538891605, 0.17324509445045674, 0.12173326712633882, 0.091057981364429, 0.15549448265561036, 0.1340770133371864, 0.12292892725339957, 0.09658804855176381, 0.08526856452226639, 0.15856545072581085, 0.0924458976036736, 0.24284526758960315, 0.07897480617144279, 0.14037149772047997, 0.1603231414088181, 0.1615267132541963, 0.07838016522250005, 0.1498620177486113, 0.11817288531788758, 0.15547172459108488, 0.08622911905071565, 0.1509382285709892, 0.09697493564869676, 0.12675173926566327, 0.1324884407222271, 0.1596225540020636, 0.18748160052512372, 0.19465872326067515, 0.16391303949058056, 0.11945242594395365, 0.07913783778037344, 0.14357969271285193, 0.14077517177377427, 0.1092640326491424, 0.1379057014627116, 0.19550634920597076, 0.1492087785154581, 0.2429818431181567, 0.18303396632628782, 0.09113957520042147, 0.1523502463740962, 0.18455415618206772, 0.11915392481854983, 0.10176881948219878, 0.15991336054035596, 0.16826341247984342, 0.22896214255264827, 0.14414397600506032, 0.07576484698802233, 0.11601633818021842, 0.0696810002305678, 0.15885827929845878, 0.14779961055942945, 0.18103918193706445, 0.20326348367546285, 0.18401923988546642, 0.13719627953001431, 0.12776751975928033, 0.13221100132380212, 0.1639465591205018, 0.08030717753406082, 0.1166802846959659, 0.11129049783838646, 0.15990006125399045, 0.13544793905956404, 0.3028621513928686, 0.1257096180426223, 0.19780647435358592, 0.20907704957893916, 0.13829805755189487, 0.09568226537001984, 0.09319374497447695, 0.12585919430213316, 0.12588709566209996, 0.08566337690821715, 0.12761716996984823, 0.11980853469244071, 0.08844773178654057, 0.09546347175325666, 0.09986547447208848, 0.08978459505098206, 0.12392289963151727, 0.1524621910814728, 0.18248841060059412, 0.16801718569227628, 0.1407936414969819, 0.08211958528097187, 0.1551548894494772, 0.11916708839791161, 0.13765931182674, 0.18106413845505032, 0.14036378956266812, 0.13558669947087765, 0.12679995596408844, 0.12083490033234869, 0.11215511430054903, 0.07948270998895168, 0.17370082571038178, 0.12937129155865737, 0.1529623121023178, 0.13807836148355687, 0.13038419506379537, 0.23475246184638568, 0.18299538482512745, 0.1139528996178082, 0.08028272313198873, 0.15892033811126435, 0.12157755691025939, 0.19564633098031792, 0.10864630793886525, 0.08163678725915295, 0.1784570033528975, 0.1446725819259882, 0.10494309450898852, 0.14008367673626967, 0.14298855300460542, 0.1875946173178298, 0.13637313512819155, 0.08695042213158947, 0.11910668521055154, 0.12454641903085367, 0.1526131515524217, 0.08731581323913165, 0.12237936817109585, 0.14732166406299385, 0.11482732769634042, 0.17768544118319238, 0.09292092639952898, 0.11386260017752647, 0.09991027135401964, 0.08455284578459603, 0.15176947468093463, 0.11094838048198394, 0.09868035877921752, 0.12312137335538864, 0.12585095688700676], [0.05586883977853826, 0.013825178146362305, 0.10309916881046124, 0.050593274113323004, 0.03523201482104404, 0.04394348165286439, 0.015021487970703414, 0.06845002235578639, 0.013230102086838866, 0.050999272149056196, 0.036012933988656314, 0.027398355172148774, 0.030347210687718222, 0.036851206328719854, 0.016904751736936823, 0.07761604658194951, 0.023100697568484714, 0.0376270738031183, 0.015388358284586241, 0.016548649773799946, 0.05895211986665215, 0.05679010712940778, 0.04344911800165262, 0.0832453698718122, 0.05973094914640699, 0.011651213862933218, 0.06455652735063008, 0.04908562358468771, 0.067558413770582, 0.05017471978706973, 0.01821370515972376, 0.016959346664537276, 0.021883933306006447, 0.05439622540559087, 0.03395684396049806, 0.011013263720087707, 0.053726986316697936, 0.024501940235495567, 0.030140990324850594, 0.043655864229159694, 0.040084174634622674, 0.060420069311346324, 0.03991013379501445, 0.059743122064641545, 0.0015351129612619324, 0.03335430486393826, 0.04715939837374857, 0.037055190918701034, 0.011782694441665496, 0.024638083197974732, 0.04858119047379919, 0.025654252152889967, 0.061283762965883525, 0.019121815716581683, 0.02460974587925843, 0.06356604264250823, 0.036665267377559624, 0.048801836491163285, 0.014013998326845467, 0.02593127764495356, 0.050310362329972644, 0.03404459210910967, 0.04201159067451954, 0.03422158457604902, 0.02684534404293767, 0.014723097107240131, 0.03890255678977285, 0.01784130648177649, 0.02559909234488649, 0.025760400474869778, 0.041234603617340326, 0.04891336729217853, 0.04028754515041198, 0.044757316554231305, 0.02782263633395944, 0.030337880831211805, 0.05629557723711644, 0.021197035343253186, 0.030313460355890647, 0.046001403725572994, 0.01422462153381535, 0.04468262341937848, 0.09885782961334501, 0.08508979090090309, 0.0894943041993039, 0.030709511068250452, 0.005465400679635682, 0.018613956003848995, 0.017638816365173886, 0.0023949427829523173, 0.026553504435079436, 0.1389529388397932, 0.06291033354188715, 0.03925540517749531, 0.0373088815914733, 0.04449105602023857, 0.05910930928907224, 0.041686294201229296, 0.024213562852569988, 0.01462778668584568, 0.03176989845399346, 0.016292087201561247, 0.049455143577818356, 0.014850071365279811, 0.03347621385806373, 0.04066368764532464, 0.04863847579274859, 0.023293981661221812, 0.019241298948015486, 0.026589068151744347, 0.007401433690184993, 0.11720381517495428, 0.029489321900265555, 0.06158122593270881, 0.07201908941247634, 0.04008834423231227, 0.03987682790362409, 0.01603539740400655, 0.012163772430670048, 0.04441816100318517, 0.01719245737019394, 0.02923002652823925, 0.021801969668428813, 0.058419313813958845, 0.030124342468168055, 0.04903760026874287, 0.07454831512378794, 0.009189767014634396, 0.025884860760665367, 0.03821363679266401, 0.04709620301478675, 0.08398810108857495, 0.04066505489338722, 0.027325538186622516, 0.02533472322725824, 0.003939355490729213, 0.04966399326388325, 0.02116802627486842, 0.020589989077832018, 0.01360382475624127, 0.07182848214038781, 0.05698497899408851, 0.03435309144801327, 0.007222745733867798, 0.01218912673981062, 0.05036883169252958, 0.00490767161162304, 0.031635026048336706, 0.023768733954057097, 0.08568175842187234, 0.06166172732732125, 0.02216691124652113, 0.022625792605270232, 0.008967086240383131, 0.04036741550745709, 0.009584944961326463, 0.05387633865965264, 0.03346916727189507, 0.017363402393779585, 0.12728200081203664, 0.06930864735373429, 0.02317906666680106, 0.02654661560830261, 0.032232605053910186, 0.029045838197427135, 0.030565943236329725, 0.03610985593072005, 0.008488864937265004, 0.026495978236198425, 0.06656426497335945, 0.059327417585466585, 0.017434606162299002, 0.06480540721012013, 0.06720079867435352, 0.008371778630784579, 0.08066441265067884, 0.027368989872879217, 0.026394672957914214, 0.06025979933994157, 0.018732555443421006, 0.007496656750195793, 0.019853882059188824, 0.02421775959166033, 0.0827978081735117, 0.07773764684264149, 0.0037993317320277648, 0.058230626795973094, 0.030519972488816296, 0.022174492179016982, 0.03566883870267442, 0.07096047978848219, 0.03963031952402421, 0.01531206550342696, 0.01790480887783425, 0.040938141489667554, 0.021588541567325592, 0.03705483468781624, 0.04480722280485289, 0.06711009211306061, 0.04237204883247614, 0.009762241920855428, 0.05168266547843814, 0.06994495713817221, 0.07787408666419131, 0.03804483763607485, 0.0295232384731727, 0.03264054369979671, 0.07789966064904418, 0.019163097787116255, 0.05627861386165023, 0.018808285040514808, 0.041422255869422636, 0.06955807004123926, 0.037616668468607325, 0.010381939471699297, 0.03335173321621759, 0.021487977588549256, 0.030845855894897665, 0.05224937453333821, 0.005456646729726344, 0.039053690287151506, 0.021895410725846887, 0.03060714727533715, 0.02565307998364525, 0.0561646674759686, 0.016639247769489884, 0.0384129496690418, 0.03735539855967675, 0.01824328419752419, 0.08641079001660858, 0.005638104805257171, 0.044738609343767166, 0.03676318676610078, 0.03838778619787522, 0.014592141544978534, 0.047309758341205974, 0.02340539711128388, 0.0330252560919949, 0.02986807675500001, 0.059586427972785065, 0.040170382508741956, 0.029190810596836463, 0.03709886482517634, 0.015646216858710562, 0.04560151929035783, 0.052185256366751025, 0.03206162779991116, 0.06024426767336471, 0.05216863565146923, 0.07912599734429802, 0.07388345258576529, 0.026300673805443302, 0.06867827475070953, 0.0035142923173095498, 0.049254276856247864, 0.029081206835274185, 0.03256486668916685, 0.02808544651738235, 0.01896397490054369, 0.013746639414291297, 0.11503122746944427, 0.03921898481036935, 0.06355101987719536, 0.016755182262776152, 0.0175335569240685, 0.04969241709581443, 0.007932216860353947, 0.034123359846749475, 0.05012922062139426, 0.00839678688706564, 0.0314011350274086, 0.04505730027865086, 0.03653058835438319, 0.08330188505351543, 0.0069992871888514075, 0.018431620073637793, 0.031092052148388963, 0.018016611092856953, 0.10647566084350858, 0.013783519488892384, 0.025059400858091455, 0.02377426910347172, 0.07594212104699441, 0.02205214722614203, 0.006585280743560621, 0.0195437406655401, 0.024704479545887028, 0.0407424248488886, 0.10669292097112962, 0.042907806512500556, 0.049653988265033276, 0.07827637650604759, 0.01042670921222972, 0.02717497126598443, 0.026717343500682285, 0.047869210464081595, 0.016696404166785733, 0.043002424828175984, 0.019286628479936292, 0.009508205195223647, 0.0317092306379761, 0.02784710261039436, 0.02164000166313989, 0.017625824115904312, 0.011497924320532807, 0.0670036163979343, 0.09734063888234751, 0.023123937392873422, 0.02020744969403105, 0.021675046300515532, 0.02845727013690131, 0.023675165671323026, 0.024786556838080287, 0.019034260950450386, 0.01339993770566902, 0.03192021431667464, 0.03688945534772106, 0.04311711420970304, 0.007815789581010384, 0.03183089875216995, 0.009818893657731158, 0.010370069349716817, 0.03532043132664902, 0.013396300757969064, 0.05189756769686937, 0.04328697527359639, 0.02320206900393324, 0.030203832845602716, 0.03691751616341727, 0.04751109325193933, 0.036154123555336676, 0.059753205095018656, 0.013936765774685358, 0.017934827267059257, 0.07408176123031548, 0.0852924082428217, 0.06471516883799008, 0.023576939245685935, 0.0608095076999494, 0.03701471969751375, 0.015207745833322406, 0.023968452255108526, 0.05490815293576036, 0.08341729028948716, 0.01317991000334067, 0.0592352386031832, 0.03915919230452605, 0.014202917743075107, 0.041633572030280314, 0.03440144046076706, 0.027131740103608797, 0.029049132484942675, 0.1284938643553427, 0.12156121778701033, 0.12040370489869799, 0.09974802006036043, 0.075702761033816, 0.09209711024803774, 0.07796694418149334, 0.158388366656644, 0.1863592764628785, 0.1325365352843489, 0.11876783839293889, 0.059757337373282225, 0.056596616083489995, 0.1390235743352345, 0.08239063966487135, 0.2066326814570597, 0.0783312903451068, 0.10085813727762018, 0.1089154217126114, 0.0857723428468619, 0.09128928038158587, 0.16690057489488805, 0.15921258314379624, 0.114627227719341, 0.14411991515329906, 0.08350538449095828, 0.14551058624471935, 0.2580121265990393, 0.10145046442214932, 0.1726810825722558, 0.10413220444960253, 0.13601096027663775, 0.08718600270471402, 0.2141589511718069, 0.08130078350326844, 0.11755057371088437, 0.20566225424408913, 0.12477120411183153, 0.09675746517521994, 0.12898425518402032, 0.0922090345993638, 0.12467449930097375, 0.14291042648255825, 0.17068572821361677, 0.10315400801066842, 0.0948914328057851, 0.14984974983547414, 0.09935608466288873, 0.245033895862954, 0.05554836090388043, 0.19909300389034407, 0.24428017916423933, 0.07692313340625592, 0.18741225424621785, 0.05559202802500554, 0.16028340639812605, 0.2011403611728123, 0.19700234250298568, 0.07930049619504384, 0.11547317089779036, 0.11264050432613917, 0.08102956627096448, 0.12168946090553488, 0.08650229046387331, 0.15026318122233662, 0.0893576947439994, 0.1381755412689277, 0.047193711889641624, 0.17633305303752422, 0.12096302131456987, 0.09319013516817774, 0.18430825509130955, 0.12990535290113517, 0.22106048012418406, 0.1800396998545953, 0.05866194436592715, 0.18523399398795196, 0.07479265558400325, 0.14311723038554192, 0.1566467708242791, 0.13700278848409653, 0.1167499702423811, 0.09105988126248121, 0.21773352793284825, 0.1935730129480362, 0.10483386394168649, 0.17849652123238358, 0.09505770102675472, 0.10941069799342326, 0.07916330319962331, 0.1485933336828436, 0.13073822749512537, 0.15359891365681375, 0.12457288189658097, 0.14891812125486986, 0.12034984278891768, 0.16357807389327458, 0.1593974975070783, 0.12109809049538203, 0.10733465903571673, 0.10900451336055994, 0.1348602327385119, 0.19607941274132046, 0.18007175384887628, 0.14073063273515019, 0.1124601632888828, 0.13202855682798795, 0.11386771633156709, 0.09868937650961535, 0.14129273114459856, 0.07958191859402827, 0.26267311934913906, 0.25185425845640047, 0.10113620771361248, 0.1421080995351076, 0.1533295488251107, 0.08775373974016734, 0.10533662446375404, 0.11218754148909024, 0.15430241876414844, 0.07803772216928856, 0.17873566411435604, 0.11664893637810435, 0.14161495385425432, 0.14997198113373347, 0.14209541093025888, 0.16869440435298852, 0.16251635657889502, 0.11649695810462747, 0.18746503069996834, 0.1858292727598122, 0.11613304620342595, 0.12674583601100103, 0.068231730854937, 0.11527715570160321, 0.05927850878132241, 0.11490596990500178, 0.07715389638074807, 0.10284061304160527, 0.14341844565102033, 0.12768167150872095, 0.18487369189304964, 0.1297021045216492, 0.09902945826096193, 0.06904661748558283, 0.16018541237073286, 0.1044110484155161, 0.1556921670479434, 0.10196571677391018, 0.17774256026106222, 0.11334954627922603, 0.182513258552977, 0.09493914060294628, 0.09841710754803248, 0.1157414365027632, 0.16822035264755997, 0.15350406803190708, 0.07070376284952674, 0.1171145471079009, 0.21399747340806893, 0.160519183746406, 0.1819562084440674, 0.15594395782266343, 0.09734611465994801, 0.06010742073080369, 0.1510496847331524, 0.15372748247214726, 0.15943972952663898, 0.09816049238932983, 0.15764686358826502, 0.14110415269221577, 0.11777101616774287, 0.19778311917824404, 0.17845180577465466, 0.08779349510690995, 0.15789892577699252], [0.024650949918265854, 0.04037439424012389, 0.08994373865425587, 0.010592179306383644, 0.016331452410668135, 0.0904275341225522, 0.03914801004741873, 0.006870632284387414, 0.01638594555801579, 0.025073645004470433, 0.02966775625411953, 0.0712350829105292, 0.03609000878142459, 0.0038333064044958776, 0.02373530762270093, 0.039482487099511285, 0.03805144317448139, 0.02256120794585773, 0.02776308131537267, 0.06425011450690882, 0.019191840530506203, 0.037968387095523734, 0.023783526017463634, 0.04511463648772665, 0.053106323549790044, 0.05774990509131125, 0.04101188128281917, 0.012073805472547454, 0.033433238842657635, 0.019658849042441164, 0.04119577105822308, 0.01141045946029148, 0.01566080196893641, 0.006550322619399854, 0.05096575251913496, 0.01909009929347251, 0.011613434729432421, 0.020612268775169338, 0.027459279135135666, 0.018262539325015884, 0.03895430526297007, 0.11431711007441793, 0.03048814580376659, 0.025569107882412415, 0.025069741731775657, 0.04889261429863317, 0.014956131477707198, 0.0387563392786043, 0.05902403100792851, 0.061533789549555094, 0.04776758288166352, 0.01757121561760349, 0.05135014260719929, 0.07729137436087642, 0.04438674822449684, 0.05521839610966189, 0.042544939555227757, 0.043427204713225365, 0.028637824912688563, 0.055814903029905896, 0.03969310776197484, 0.06062891560473612, 0.012507007673515804, 0.020117263908364942, 0.021987740682171922, 0.017235417118562118, 0.038044288022709746, 0.026569962301956754, 0.061908951561365805, 0.08986012278390781, 0.01141406417757805, 0.029398225181336914, 0.06716370316488401, 0.024665969290903637, 0.0027926569663187756, 0.0043427360776279655, 0.041834065557590554, 0.04459823741178427, 0.020090619534520165, 0.06111349817365408, 0.05272028801430549, 0.025860830442979932, 0.08345238412065165, 0.04321107095373528, 0.015436369726168258, 0.002816375369937824, 0.02405400703927236, 0.0079649095257212, 0.039467423622097285, 0.07211563816027981, 0.020913473862622465, 0.030159734854740754, 0.1079970042088202, 0.060547023213335445, 0.05643905685948474, 0.0584524738203202, 0.05396761519036122, 0.02775058100399162, 0.04413634505388992, 0.034036073101950545, 0.03751739201002887, 0.06583750647093568, 0.07413780822285584, 0.024713073191898208, 0.007883902622519859, 0.02117369543494923, 0.025519389925258498, 0.0415295593972717, 0.004339500737842172, 0.056479806280029674, 0.0509406331527446, 0.022556678724608252, 0.013474109216726251, 0.10657215530851058, 0.022914896020665765, 0.013627027261203952, 0.023656916471996477, 0.029482712969183922, 0.034662140400281975, 0.0329635569027492, 0.02516603602894715, 0.026484251454738632, 0.028100353931742053, 0.020750503321843486, 0.0512670017113643, 0.0452053294783192, 0.026290611131116748, 0.02318337875684457, 0.0053984352104764965, 0.014808126026764512, 0.04665582700233374, 0.014996058174542018, 0.048085147448416264, 0.025117486848362854, 0.015348024466740233, 0.07625727342175585, 0.01688761024602822, 0.03687877859920263, 0.02993321611679026, 0.043525249630744965, 0.018135439537997757, 0.0015347151701072498, 0.08203282779348747, 0.08895357285759278, 0.05393004131370357, 0.04721982191715922, 0.04461753834038973, 0.09039105607994966, 0.03285201592370868, 0.03982543905398675, 0.013296758822564567, 0.025767435186675618, 0.05266846150958112, 0.11197742633521557, 0.04685065136956317, 0.024274176385785853, 0.05096590179683907, 0.0853741852832692, 0.08386848215013742, 0.03933124164385455, 0.044776522487934144, 0.02379367350866752, 0.023553293996623585, 0.027362704942268983, 0.025351488131231496, 0.06642137228378228, 0.05944386776536703, 0.02439563924313656, 0.04421684305582728, 0.01635540639316397, 0.03456789188619171, 0.009562650845119995, 0.0332021705274071, 0.051724113790052276, 0.02602908168254154, 0.01906846250806536, 0.06345588926758085, 0.03162227298266121, 0.03938132770625608, 0.005136749274762613, 0.026877435356644646, 0.0430490062572062, 0.04458886684317674, 0.017949081591463516, 0.02750047299611781, 0.04883417207747698, 0.0537471863042031, 0.05205990041473082, 0.04904252643297825, 0.004705888443692986, 0.018955978365348916, 0.024905298770006214, 0.027512291379805123, 0.030779094834412848, 0.023742610355839133, 0.010987801693512924, 0.07322040852159262, 0.047698236602757654, 0.03091138202164854, 0.03456916753202677, 0.03851819723578436, 0.015337245937969004, 0.04295976193887847, 0.027884500067947165, 0.06711578502186707, 0.0018189214710478804, 0.005162112913759691, 0.018428235880232284, 0.01132122362365148, 0.003378613939275965, 0.04218360269442201, 0.07088960002043418, 0.04149801769692983, 0.01695837127044797, 0.05365484786619033, 0.06221111677587032, 0.04526428060073938, 0.018242727798808898, 0.04219611148749079, 0.01960141783846276, 0.003170336767133059, 0.05665186579738345, 0.04385453588994486, 0.02965579368174076, 0.015256780166445034, 0.08096166527164833, 0.056549546109246354, 0.07753620336630515, 0.057178571820259094, 0.014989371211933238, 0.03051476812522326, 0.04440907541928547, 0.0064260154280678505, 0.011165148694999516, 0.03743416629731655, 0.0377935964747199, 0.014139673190324433, 0.035045719638999016, 0.05042438335450632, 0.012042798966701542, 0.025375543893980126, 0.023075542579005872, 0.02830881515650877, 0.02189482718573085, 0.08252856547811202, 0.01366148581395724, 0.04351257120392152, 0.04448117655036705, 0.07341081223317555, 0.045925509583737166, 0.03576699218579701, 0.04334557016513177, 0.044981528273118396, 0.033756038307079246, 0.025712484028190374, 0.05206727269770844, 0.009726361837238073, 0.07369379526270287, 0.04255205399489828, 0.02237661079769688, 0.039854409106607945, 0.01069240486581943, 0.017190638896343962, 0.06297382406358208, 0.04968717202012028, 0.03611123335680791, 0.045157696320010085, 0.0381886429552521, 0.07607435395142861, 0.09546056083802666, 0.023341280641034245, 0.0994525926985911, 0.022324904732938324, 0.027248597404520427, 0.042451919189521244, 0.021881212380581667, 0.027521723016564335, 0.05305339103298528, 0.01988867394227002, 0.0321669330421303, 0.04236503617305841, 0.01715859677642584, 0.01747871093851115, 0.028617947229317257, 0.03223459994686501, 0.06401729557131018, 0.04455872971032347, 0.04760950118569391, 0.04276489685954792, 0.023375458449923565, 0.03991014397303973, 0.005093153823898839, 0.016094898139791827, 0.051625539615218125, 0.03024818528709667, 0.05771871962185417, 0.038901820579277616, 0.026022523641586304, 0.050931700239224095, 0.017625939466857483, 0.0056859504298440045, 0.03517739614471793, 0.013416192012040742, 0.04332443719197597, 0.0302891857655985, 0.008812811974036907, 0.03999239598800029, 0.019391457051304833, 0.019695277891254852, 0.027171317354909012, 0.07742037065327168, 0.06476897666496889, 0.01996854429931513, 0.033957254474184344, 0.02118127976012017, 0.01150524232070893, 0.031501958545829566, 0.016499116717438613, 0.05276005355907338, 0.020697021191673617, 0.06182854516165597, 0.02021545301457601, 0.012389315774531236, 0.02749249172796096, 0.041145813917475085, 0.05357417683782322, 0.012279004640212017, 0.0102336388580235, 0.024165383473570858, 0.06971954780497722, 0.035874763902808936, 0.012205169003989016, 0.01580229857271271, 0.016380724231047288, 0.07814741414040327, 0.04526336118578911, 0.04189823800697923, 0.02003284906303244, 0.05498156363942793, 0.0534290517680347, 0.021044526116124222, 0.044735084354345284, 0.03151760895603469, 0.028558046157870973, 0.0411879305860826, 0.02433987893164158, 0.022467028981606876, 0.01077294273168913, 0.004925039139509733, 0.015034895822671908, 0.03346424789300986, 0.03456426172384194, 0.17751054199678556, 0.08003147518528358, 0.15930851442473276, 0.13266325848443167, 0.12245038364614759, 0.14932571724057198, 0.09259687843067305, 0.06962808806981359, 0.07496364640870265, 0.1588135774114302, 0.15630411063986166, 0.11610473772244793, 0.15460082489464963, 0.1068691433008228, 0.10005118272134236, 0.09098144261432545, 0.12514946024332727, 0.10715649609587022, 0.1197012583059924, 0.12191489738013063, 0.14943160941558226, 0.08787316190344946, 0.13163044676184654, 0.162809660126056, 0.07943226091031517, 0.11370794169072594, 0.14860421738454274, 0.10854183390204396, 0.19192200154066086, 0.12152792885899544, 0.10050812177360058, 0.1303454100021294, 0.13969490331198486, 0.18923216659043515, 0.1098093441022294, 0.258528681738036, 0.12120599113404751, 0.06260978324072701, 0.1472423161779131, 0.14499565958976746, 0.20090625302067824, 0.20750917228204863, 0.14081611457679952, 0.2202051053089755, 0.10619624690817935, 0.14421915768512658, 0.10156147953655038, 0.10432718827256135, 0.10692039305078131, 0.10942321017916713, 0.14030383420842035, 0.10012271388300828, 0.20511554500886373, 0.18861433331455502, 0.16754326969385147, 0.12716548277863435, 0.08754751937729971, 0.09411993848958186, 0.20653934217989445, 0.15839897894433566, 0.1364705049033676, 0.10270278222326722, 0.09134270144360405, 0.1472969382469143, 0.08589417380946023, 0.06510163524321147, 0.16351548582315445, 0.11649842374026775, 0.11618127647255148, 0.1706698504941804, 0.2706756256520748, 0.11565045852746282, 0.17126373148390225, 0.1820851300976106, 0.12386206218174525, 0.08151005727371999, 0.26687718661768095, 0.08402361561145101, 0.106828180141747, 0.2201725627694811, 0.14575856365263462, 0.16396139189600945, 0.14217463667903626, 0.11402080740247454, 0.06430538796952792, 0.14537870617849485, 0.18082838824817113, 0.09288947630141463, 0.1502299601478236, 0.1904897362525974, 0.18840366176196507, 0.15441786471222127, 0.2527561400617872, 0.2566791852670056, 0.10737170704773494, 0.28245119377970695, 0.1438870012227978, 0.13289543959711278, 0.1863578108272382, 0.1128480817590441, 0.12913227081298828, 0.09266830102673598, 0.17565256383802208, 0.1263871488294431, 0.12334155796894006, 0.07942688012761728, 0.15903023364288466, 0.15265178733638354, 0.2875941092414515, 0.24767545983195305, 0.12446595834834234, 0.1691706816532782, 0.23156948121530668, 0.19146913369851454, 0.10450178890355996, 0.17720767110586166, 0.13980637304484844, 0.11341590021869966, 0.15290427021682262, 0.12854976207017899, 0.10860630151416574, 0.1782973033509084, 0.1982105148157903, 0.12081630847283772, 0.10901686269789934, 0.11268224780048643, 0.11648482589849404, 0.08632053128842797, 0.2096376959234476, 0.14243002368935517, 0.1272948794066906, 0.09107833741498844, 0.19129883497953415, 0.1113008251413703, 0.10253095680049487, 0.15430596071694577, 0.09293404248143945, 0.1076537129868354, 0.07815612653004271, 0.08723832454000201, 0.09516952359782797, 0.07388785627803632, 0.17576160441551889, 0.1252988465130329, 0.13948341751737253, 0.14906344988516398, 0.07893024677676813, 0.14934045502117702, 0.11131975626839058, 0.13270527337278637, 0.12544337447200501, 0.06517037762595074, 0.24360568821430206, 0.12478461196380002, 0.11399343529982225, 0.10918932594358921, 0.0995010333135724, 0.13806430223797048, 0.20674786956182548, 0.17195789994938032, 0.1722049681203706, 0.07867181314421551, 0.11974775152547018, 0.11967805240835462, 0.0757452305406332, 0.11072228582842009, 0.18536040506192616, 0.18435805956167833, 0.13455980457365513, 0.11116947433246033, 0.17049758402364595, 0.09094273897686175, 0.04998347129938858, 0.1026086558454803, 0.2416233074452196, 0.09521337053073303], [0.027672995613621812, 0.056331363173999956, 0.016164787246712616, 0.03413807387862887, 0.04782370451305594, 0.0324634324892291, 0.026648558709504347, 0.04847753407167537, 0.007122583787090012, 0.039258536616606374, 0.026447627527107085, 0.004354467948100397, 0.07545628997364215, 0.0521384781625654, 0.013918915214682264, 0.05399366754240223, 0.020308710867539048, 0.12817868483918055, 0.030715292186609337, 0.01977389126217791, 0.022315293284399167, 0.05767242317753179, 0.018249526719695756, 0.03624265880456992, 0.05502214003354311, 0.016746405412309935, 0.019982101428987722, 0.07372156770101615, 0.03647020552307367, 0.04544108986322369, 0.014877056702971458, 0.043513276880340915, 0.03711828449741006, 0.03736517624929547, 0.01118946060471769, 0.009535236334029053, 0.009629113350196608, 0.059592656924256256, 0.022387224781726087, 0.01942226423748902, 0.07707500989948, 0.07327815863702979, 0.028971402905881405, 0.008879400008091969, 0.0636415160926325, 0.029611146077513695, 0.05721189467502492, 0.017050399278689708, 0.029815069599343196, 0.020795306989124844, 0.04428783817482846, 0.06931042511548315, 0.030779993893312554, 0.024190719971167188, 0.05858086621654885, 0.023421237511294227, 0.09151585000966277, 0.02114679491413491, 0.05007840174117258, 0.025470282649621367, 0.043894766231200526, 0.02610168492953692, 0.033262010530701706, 0.03057156829163432, 0.014144207500586552, 0.04841297485732606, 0.07590915781578847, 0.09334960446826049, 0.007028952739866716, 0.03528442147320934, 0.0571398613974452, 0.055795147482837947, 0.03541967725115163, 0.03027684660628438, 0.0592586344906262, 0.007547193190215954, 0.035200557937579494, 0.044478475980992825, 0.04754940333909222, 0.06862478583518948, 0.0344069433797683, 0.030730331915297678, 0.03967700951865741, 0.06516642176679202, 0.03716447237612946, 0.06731752026826143, 0.025275655057547346, 0.03859451546200684, 0.04802183673850127, 0.028266347346029112, 0.04195725019755108, 0.0574180878964918, 0.03949930119727339, 0.032897264031427245, 0.08795512893370219, 0.030387973678963523, 0.02797032117710582, 0.025360263285360167, 0.07157999583120857, 0.10402773041278124, 0.04974379916010158, 0.017702429023172175, 0.06028364984584706, 0.062446032384676595, 0.03378996845068676, 0.0685090549024088, 0.005879201868083328, 0.019716466843549694, 0.033579062803515365, 0.014759659966720002, 0.036953142644571405, 0.04802565349798117, 0.05736079239951713, 0.05593196049864803, 0.031468415167182684, 0.06955477236104862, 0.05238427747307079, 0.0022611791459244807, 0.02757274715362915, 0.08199972885527781, 0.04435827010976417, 0.08602684776165656, 0.15377322930310452, 0.04477808651115213, 0.016710760271442787, 0.04587195620739034, 0.012556724782500948, 0.019944899050252776, 0.046468066184648445, 0.04969381148527775, 0.05170817839513932, 0.03780045307108334, 0.054659971967339516, 0.007392585593541818, 0.039074063301086426, 0.048533591242241006, 0.021008015843108296, 0.042084241418966224, 0.02797036019286939, 0.008487960789352655, 0.07728491470749889, 0.02778540681382375, 0.04197524833892073, 0.019465592091104815, 0.035089810844510794, 0.03187812818214297, 0.016188897292262742, 0.043474010058811734, 0.023221509032217518, 0.017799853081149713, 0.011876341604095484, 0.02108943834900856, 0.05159017097737108, 0.0411185469877507, 0.008222990320064127, 0.0034580653009470552, 0.03109999779345734, 0.030222075259579078, 0.019543547283059785, 0.026221347972750664, 0.01499362223382507, 0.02024184463412634, 0.014432378778500217, 0.00828613733340587, 0.004942507175396064, 0.02495176824075835, 0.048005270306020975, 0.05021282631371703, 0.05580159356551511, 0.014366964610027415, 0.021237189349319254, 0.041703413639749796, 0.03028492456568139, 0.00966884327187602, 0.06383834553084203, 0.02949402414794479, 0.04701074492186308, 0.06672921683639288, 0.055845111408936124, 0.034034855131592066, 0.02673830684008343, 0.03375752429877009, 0.023093220112579207, 0.04539340581478817, 0.043737529311329126, 0.023604677757248282, 0.01057201748647328, 0.02773285936564207, 0.019218942915488566, 0.02698947166624878, 0.005953837751543948, 0.028526772478861467, 0.016613543166645935, 0.041318331445966444, 0.07685859794063227, 0.04644357107047524, 0.03973417609397854, 0.05934702046215534, 0.0035215081131484893, 0.054311171041003296, 0.014661021331059081, 0.026340810848133903, 0.04085572662630251, 0.01628310339791434, 0.031884849071502686, 0.0115676225894796, 0.014607478132737535, 0.09544800794018166, 0.10359219914036137, 0.009383618532280837, 0.03866668105391519, 0.03130860659959061, 0.01223493633525712, 0.02950791036710143, 0.024252412375062704, 0.02820584237841623, 0.04100760311952659, 0.005182230204809457, 0.027294980362057686, 0.03901497647166252, 0.01899097889794835, 0.005665515923673021, 0.04896836934079017, 0.01067423539435757, 0.021881119082016603, 0.03506784666595714, 0.00569704659782084, 0.019325986903692995, 0.03724267014435359, 0.03211383767692106, 0.12545115048331873, 0.03102861251682043, 0.043246473518333266, 0.019645800814032555, 0.08783812235508646, 0.06506889592856169, 0.1302377943481718, 0.06764449272304773, 0.060968542737620215, 0.014831834040316088, 0.04025493475741573, 0.02191757337589349, 0.09389482771179505, 0.012316809218776013, 0.024478873437536613, 0.042120176633553844, 0.07018251224820103, 0.03481216788558023, 0.04440111281084163, 0.03901723599327462, 0.024938653855185424, 0.04363634616934827, 0.03065905859693885, 0.0026265821278294815, 0.06380441877990961, 0.036271048709750175, 0.06225054644580398, 0.037365440877952745, 0.020692729457680668, 0.07843896706721612, 0.027546170633286238, 0.08836228387164217, 0.052489233269755325, 0.00915426351795239, 0.033651014656892846, 0.030271883122622967, 0.0732201642489859, 0.034087441595537324, 0.019134124341819967, 0.012805247562937438, 0.05019646004906722, 0.08593263317431722, 0.06620909260319811, 0.03908181556367448, 0.04094967319230948, 0.023050258667873483, 0.04757826482611043, 0.03953687846660614, 0.0743284969191466, 0.09322557505220175, 0.05034440443185823, 0.0203003258710461, 0.015830764813082557, 0.03429874079301953, 0.03847711533308029, 0.03082210716924497, 0.008241979122561003, 0.007815251842008104, 0.029998406368706907, 0.04525885910594037, 0.030118849727192094, 0.06855568382889032, 0.07272865383752755, 0.026849086163565516, 0.07177474216691085, 0.028100616864061782, 0.013162500491099698, 0.05150544909494264, 0.028245255084974424, 0.04672138366316046, 0.03700425668752619, 0.04143485965739403, 0.030738627005900656, 0.05353381757491401, 0.03497382206842303, 0.019070903537794948, 0.014950723553608571, 0.03974853050229805, 0.10401439041431461, 0.01999149744265846, 0.04316882197079914, 0.029649730971349136, 0.032606192864477634, 0.011243611091880925, 0.06377226979072605, 0.01941093779169023, 0.060304161959460804, 0.04706175039921488, 0.016125367754804235, 0.04854560809742127, 0.0292157433660967, 0.012791385092506451, 0.04040697070636919, 0.061636987940541337, 0.00922018489135163, 0.032981113996356726, 0.06392113358846732, 0.08945769044969763, 0.04000933900741594, 0.05488251449008073, 0.020158018417922512, 0.020864395424723625, 0.04706227965652943, 0.017170576312180077, 0.05378337936209781, 0.021421861136332154, 0.019533588085323572, 0.01822006981819868, 0.04021352037255253, 0.012626831868796476, 0.029297045432031155, 0.00937617924397013, 0.07192741254610674, 0.017509467234568935, 0.006594455809265907, 0.007344772623452757, 0.021781048737466335, 0.041446537245064974, 0.0008880807862234567, 0.04238030660365309, 0.033675777792398415, 0.05641054142532604, 0.11191154058490481, 0.12179453883852277, 0.12362720764109067, 0.11897435731121472, 0.12772703836006777, 0.11806396687669413, 0.08753961444433246, 0.05778710238103356, 0.09236977275993143, 0.11761500739625522, 0.12493239689086165, 0.13467014793838772, 0.1377181408128568, 0.11321588166590248, 0.11064214405736753, 0.14392326213419437, 0.04732764791697264, 0.1608988105186394, 0.14951026519494398, 0.10656651668250561, 0.11554300572190966, 0.1238542590290308, 0.07903491080339466, 0.10660636025880064, 0.16076511197856494, 0.14862941817513534, 0.13322945524539265, 0.10168037922786814, 0.11388358048030309, 0.14807931626481668, 0.07113677675702743, 0.16308567460094178, 0.14454296816672596, 0.10597539054495947, 0.07870153297803231, 0.13237960370523588, 0.13940606452524662, 0.10229622439614364, 0.16879086489123957, 0.11178306676447392, 0.13931081177932875, 0.15461653976568154, 0.0878671704392348, 0.10863041664872851, 0.15481985599866935, 0.08775464219174214, 0.20443501509726048, 0.06975338634635721, 0.10806793147431952, 0.06533281890941517, 0.08296231220343284, 0.14169082764003957, 0.10953148401209287, 0.11323066694395882, 0.2998829483985901, 0.08788058507655348, 0.13376388299678052, 0.13961187776710304, 0.11941267736256123, 0.18404507849897656, 0.19778491051069327, 0.14063972261335167, 0.1303002331405878, 0.10927511991134711, 0.14684704238814966, 0.11149890986936432, 0.16713775002530643, 0.1522458062640258, 0.08596524356731347, 0.15976444924516336, 0.1676580642483064, 0.21622979933662073, 0.1644030503396477, 0.09541448152491025, 0.15531522727438382, 0.1954310725310019, 0.10319626038627965, 0.13007057617817605, 0.12635851465165615, 0.11096405464091472, 0.14044843002089433, 0.23123545199632645, 0.12502572259732656, 0.15156815334090165, 0.16166031679936818, 0.1782013177871704, 0.21806079894304276, 0.16366027162543365, 0.17622816509434155, 0.10462036289806877, 0.2094918108944382, 0.14928592794707843, 0.11896384001842567, 0.0701873977003353, 0.326419041625091, 0.1258257832378149, 0.21986997686326504, 0.12957418709993362, 0.11090116123003618, 0.16822598448821477, 0.08581060543656349, 0.13784745601671083, 0.1558460859315736, 0.20993899261312826, 0.14092544013900415, 0.11011330743453332, 0.11555851703243596, 0.13527472264000348, 0.2042389184768711, 0.1845021125461374, 0.08638828301004, 0.16317381629986422, 0.12214857126985278, 0.17312708364001342, 0.12141132940139089, 0.14810717691268238, 0.09313192364892789, 0.1126718187172498, 0.12297590901809079, 0.2162906639277935, 0.12590074778667518, 0.17359360360673495, 0.3072449719267232, 0.12707778891282423, 0.11792977979140622, 0.22718545288911887, 0.13302685825952462, 0.11038896907120943, 0.13455824394311222, 0.15717518675540174, 0.1288313948150192, 0.11968506846044745, 0.23988775057452066, 0.08971357279058013, 0.13670606512044156, 0.14361781281019959, 0.0923526668921113, 0.12095247688038008, 0.12999873289040156, 0.07578039901064974, 0.14759420443858418, 0.1726639699190855, 0.12908915669790336, 0.19331765307911805, 0.1338920718325036, 0.06824448052793741, 0.13786215308521474, 0.14295911815549645, 0.14558367803692818, 0.09370470898491995, 0.10592495503702334, 0.18343873960631235, 0.15928380217935356, 0.14177556309316838, 0.060734285307782035, 0.11705653236380645, 0.07564053258725575, 0.07736002174871308, 0.10592792023505483, 0.09047201887837478, 0.13489965562309536, 0.09608251960682017, 0.1564639327781541, 0.06088827204491411, 0.08625314597572599, 0.11661860586277076, 0.19847187293427332, 0.10040862139846597, 0.10512644824172769, 0.08458707109093666, 0.09988560660609178, 0.12254094092973641, 0.09309133368411235, 0.2057188440646444, 0.09099845348724298, 0.13602276678596223], [0.052369916279401095, 0.022073185204395225, 0.012919457729107566, 0.03958516641120825, 0.04324034634711487, 0.0191866700936641, 0.022260014732767428, 0.05535645084455609, 0.06990780734590121, 0.04956329527444073, 0.04790109482460788, 0.030469815180237805, 0.05745994672179222, 0.0678277514608843, 0.04618516118664827, 0.06026252026536635, 0.007706794804627342, 0.05904988319213901, 0.023833924205973744, 0.07897654322109052, 0.04890080760898335, 0.03422348786677633, 0.026174624051366533, 0.01615233443278287, 0.020161019239042486, 0.03501684458128043, 0.019834328376288925, 0.02901807932981423, 0.0778151558978217, 0.009497521661355026, 0.05787417877997671, 0.036643157313976965, 0.02683304050671203, 0.044918010610022714, 0.026883325040606514, 0.01214101945515722, 0.01744145936598735, 0.011443091905675828, 0.019982413555096303, 0.08342251500913075, 0.03025665001145431, 0.03385096874886325, 0.009584120541278805, 0.03205124960680093, 0.03459173221407192, 0.04244340018236211, 0.029349431728145907, 0.010535128082015684, 0.013203323702327907, 0.04669639661109873, 0.02242636607427682, 0.048731930420867035, 0.051529930638415475, 0.05790666025131941, 0.028445076862616197, 0.08032364557896342, 0.009983321352462684, 0.030379173079771653, 0.03990721270175917, 0.026503588006432568, 0.026185492486027733, 0.08200175088963338, 0.03191884367593697, 0.018039267377129624, 0.004822572294090475, 0.017554164032584856, 0.02502927559960101, 0.049333712950881035, 0.05546095880812832, 0.026108790887519717, 0.019301020207681825, 0.042465859691479375, 0.0014589801659375162, 0.024914460689095513, 0.05828154406377247, 0.027825667689155256, 0.05936173788670983, 0.02588839253543743, 0.04906377475708723, 0.02931535230683429, 0.052070617875350375, 0.03746912442147732, 0.04178119071626237, 0.02552062994800508, 0.023882154475099275, 0.02070078536468957, 0.05040433264470526, 0.028553483009870564, 0.012953386176377535, 0.044167276072715006, 0.06515181969319071, 0.08641455588596207, 0.01808190482136394, 0.06612226047686168, 0.03788009272622211, 0.08207405558122055, 0.01660228118167392, 0.05190158123150468, 0.05482731227363859, 0.009034564003481396, 0.0201017729538892, 0.0288899753109685, 0.04030392498576215, 0.03559006417968443, 0.018651170256946768, 0.07470270898193121, 0.05012063715340836, 0.06339075669114079, 0.05445386017007487, 0.03318256086536816, 0.04041485528328589, 0.059747498615511825, 0.05235541598605258, 0.06230619988803353, 0.05159740416066987, 0.04000566474028996, 0.04265366800661598, 0.06614843835788113, 0.04639982931049807, 0.028051926887461116, 0.005515775967588914, 0.04237169938694153, 0.019429376980822, 0.03684237180277705, 0.05098307551816106, 0.040966012315558534, 0.07989144591348511, 0.036982723378709385, 0.03379478265664407, 0.03631065140611359, 0.05807499800409589, 0.03529231283547623, 0.006190501860276396, 0.02822320269686835, 0.05405828443222812, 0.04759353186403002, 0.002997563515756545, 0.018060999157439386, 0.034676864610186646, 0.04309495325599398, 0.0426944717099624, 0.054812808587614975, 0.05634632487116115, 0.02389338083698281, 0.026953120848962238, 0.0329710343586547, 0.05408476086865578, 0.019521074203242148, 0.020747868909633586, 0.0048472429791997585, 0.015258552839181252, 0.03845982626080513, 0.008532336979572262, 0.06669969377773148, 0.042446687684527466, 0.09589157306722232, 0.020648232827495252, 0.026584240375086665, 0.0639885663986206, 0.018942565424367785, 0.018453602911904454, 0.03214722499251366, 0.008511030131817927, 0.01219060764248882, 0.033036764045911174, 0.02347535067903144, 0.07266331770058189, 0.030664995778352022, 0.006885088048875332, 0.03340123573850308, 0.08927695586213044, 0.042690030698265345, 0.07464043303791966, 0.041950912680476904, 0.017989434069022536, 0.003165885365368532, 0.041273622773587704, 0.027486661415813223, 0.02783188476626362, 0.016738027201167176, 0.03305709634774497, 0.020195353110986095, 0.04885140347427555, 0.029519832227379084, 0.00734081761246281, 0.012181342246809175, 0.006800503569788167, 0.018496065633371472, 0.03392070518540485, 0.11250833927520684, 0.01107087473584605, 0.09345509630760976, 0.05486510667417731, 0.05874805724514382, 0.031157184724829028, 0.07022851692246539, 0.032793305681220124, 0.0713748000562191, 0.04634201134155903, 0.03372966025822929, 0.04299871663429907, 0.03998759874541845, 0.03440053461651717, 0.026923743675329855, 0.028530263541532413, 0.04202038788103631, 0.07443183101713657, 0.03530150019962873, 0.022832542225452404, 0.04219477816617914, 0.02262017094264073, 0.009749535504462463, 0.04500183004087635, 0.06232356359916074, 0.015065672474780252, 0.04477084993517824, 0.02651650900952518, 0.012004018145879465, 0.019186805800667832, 0.03265219075339181, 0.005198400966557009, 0.027283284114673734, 0.009818899594912571, 0.06255188384758574, 0.05389188050425478, 0.06681393193347113, 0.04874308892924871, 0.026542724209970663, 0.026325949234887958, 0.03087072420333113, 0.02194122032129339, 0.0359887442152415, 0.024045243759506514, 0.016399599378928542, 0.03946537783901606, 0.05427984647186739, 0.01683321887893336, 0.04938462343333023, 0.027474480015890937, 0.035291501986128945, 0.010837783538071173, 0.027350627018937042, 0.01978061384787517, 0.017224779385807257, 0.03252274323520916, 0.048307282850146294, 0.05164150554420693, 0.020487906876951456, 0.030382501294038126, 0.035828318180782456, 0.023928696888365915, 0.055601992311754396, 0.02149738378024527, 0.018542949010484984, 0.04174302651413849, 0.011233365213099335, 0.01041408846088286, 0.03316749060260398, 0.03705009172803589, 0.008687275362067988, 0.009459479595534503, 0.010444569950258093, 0.07774966369782176, 0.030520033556967974, 0.02356564672663808, 0.03690026101789304, 0.016880694277850643, 0.013543537768003131, 0.024105365354833857, 0.10320841973381382, 0.02723299109909151, 0.06092839382056679, 0.026069844673786844, 0.010929714855072754, 0.032599967305681536, 0.03368952491187623, 0.042779437864997556, 0.029148531079824482, 0.04401547761101808, 0.0820195149364216, 0.02455479302443564, 0.041998148895800114, 0.005777813893343721, 0.015111275117046066, 0.05211796944162675, 0.021620442891227346, 0.01773542957380414, 0.04390435393101402, 0.017324730986729264, 0.005646756550829325, 0.016223663730280738, 0.039650142924594026, 0.055317146703600883, 0.05970962279077087, 0.038918695745191405, 0.021833982950608646, 0.07688791065343789, 0.03309295013813036, 0.052898257571671686, 0.05335512877042804, 0.05755281102444444, 0.02350699924863875, 0.005594670930544713, 0.010593843413516879, 0.013674455162669932, 0.03328157948063953, 0.02855260091434632, 0.03594445623457432, 0.030576993179108416, 0.06055032767887626, 0.0454361636989883, 0.02540370648992913, 0.019311125290447047, 0.024695741711184382, 0.017639915591904094, 0.048784367607108185, 0.012227570837629693, 0.07442480817969356, 0.05597091858674373, 0.022934375064713613, 0.02958371290670974, 0.01847204888638641, 0.07816679310053587, 0.012044037293110574, 0.049256410848881514, 0.04050695284136704, 0.01616867016335683, 0.044897719020290036, 0.05255115298288209, 0.0504155081164624, 0.031260990404656956, 0.043094753088163476, 0.04412120354494878, 0.04951002009745155, 0.040660878510347435, 0.04136946923764689, 0.04272926698571869, 0.026604989975956932, 0.020950956137052605, 0.03345894853451422, 0.009933272609487176, 0.0173985623821084, 0.06353678421250411, 0.020822370358343636, 0.015578560132001127, 0.06172975046294076, 0.010095123567485383, 0.03729565694395985, 0.015267448433275734, 0.07074358606977121, 0.0284401065936046, 0.004251746227964759, 0.09537563539509263, 0.06684752620224442, 0.0799843780696392, 0.10008890926837921, 0.14682843695793832, 0.11981257876115185, 0.16955636095787796, 0.1241377509598221, 0.17762948918555463, 0.19543409879718507, 0.09262266276138169, 0.09074472210236958, 0.10842884425073862, 0.1905813113387142, 0.13740761604692253, 0.17848624821220124, 0.11992924607225827, 0.14108256170792238, 0.0942849310647164, 0.15444222411939076, 0.1001040270285947, 0.21026335949344294, 0.101230429086302, 0.15269283870501177, 0.12452830214585577, 0.08521873969584703, 0.09903395694813558, 0.11487844852464539, 0.1767725401691028, 0.13742816208728723, 0.1674484104982444, 0.08022089502108948, 0.1039983294904232, 0.1567462304873126, 0.05766434861080987, 0.07823098929865019, 0.12820714259786264, 0.11657938653869288, 0.10833960332508598, 0.18454867361911706, 0.057402596942016056, 0.1304313668182918, 0.10801478861165897, 0.19705811808151857, 0.09722441261900322, 0.09086111799946853, 0.09558747402791466, 0.1568077193307025, 0.06879296073956148, 0.1844832357019186, 0.13577616001878465, 0.12499873047428471, 0.1338736428213971, 0.09324330517223903, 0.08211357346070663, 0.18341196461447648, 0.06227733500834022, 0.07795982634914772, 0.13012255196060452, 0.19322109754596437, 0.14858752542308398, 0.17232217825949192, 0.09508957860193082, 0.13588876969047956, 0.03859536363078015, 0.09258310416979448, 0.1515039639281375, 0.09111137528504644, 0.1992269331323249, 0.1127096199031387, 0.1316855845174619, 0.19166035843747004, 0.17013296644602502, 0.10679766642195837, 0.12076412912990366, 0.16190817207098007, 0.15545235920165265, 0.14916390020932468, 0.12215648298817021, 0.13223002744572504, 0.09605051989534072, 0.07535433330174003, 0.10001330011125122, 0.08708169830164739, 0.1022701415100268, 0.21422115926231655, 0.20217519492975303, 0.11909075320831367, 0.08336931107831852, 0.13988281680004938, 0.15596690587699413, 0.14805638178118638, 0.2075712853776557, 0.2534322052129677, 0.1172545560236488, 0.1174624455826623, 0.09329918253102473, 0.09582089007432971, 0.13093516549893788, 0.09204415058983223, 0.14405307945396217, 0.1546211809452091, 0.13535145137991222, 0.12319466870810304, 0.07595626850213323, 0.1460327867950712, 0.07683894756649222, 0.10838598797896079, 0.1380990975137268, 0.1508846650166171, 0.10955126330788646, 0.08812780252524785, 0.16465500396277222, 0.18945566245487758, 0.2210738065519503, 0.15707305366439478, 0.13917175281260694, 0.15973372517951898, 0.15225165523588657, 0.09458734055182763, 0.16529450964714798, 0.10835082629429442, 0.07567764845277582, 0.16415447582091602, 0.19859544773186955, 0.10275110748729535, 0.14034867180245264, 0.06892356515995093, 0.08635357594383614, 0.14194746315479279, 0.11889657005667686, 0.09871326094227177, 0.09981016708271843, 0.11424143984913826, 0.10129106297556843, 0.0852776433208159, 0.08365833306951181, 0.08323587716690131, 0.07702152098395995, 0.14353439371500695, 0.14801598180617603, 0.159070525052292, 0.12785909484539712, 0.14313511656863348, 0.0526493980682322, 0.0887284552944558, 0.15530546994081565, 0.0801267550726022, 0.11999362547482763, 0.15988932682999543, 0.09334448152886969, 0.1037979716701167, 0.1417909251259906, 0.1412685074444328, 0.11847289279103279, 0.1852702684700489, 0.12843736952969007, 0.1471977499978883, 0.11881126463413239, 0.12050262173371655, 0.08635943170104708, 0.0996584737939494, 0.08714704800929342, 0.10742851399949618, 0.08318575378507376, 0.10840187248374734, 0.155664645667587, 0.0882317948022059, 0.04685534343921712, 0.160633544038449, 0.2958469678248678, 0.06865151332957403, 0.11813681439629622, 0.1277890293193715, 0.10875598633927958, 0.06354039401880332], [0.022839872099991356, 0.05701315176806279, 0.054932373243251016, 0.024998485376792293, 0.04444258487118142, 0.031516041540141614, 0.05001841924552407, 0.025648194531510984, 0.05705639480480126, 0.04343965243814247, 0.027417410131809965, 0.056514621911836524, 0.08423562387802772, 0.04674957340051021, 0.029417522717267275, 0.040261825280530114, 0.05505800400195377, 0.07300742316458907, 0.023732227073716264, 0.0325795501869704, 0.027711962183405246, 0.07028094053800617, 0.016576306861160055, 0.01793027768975922, 0.034557245671749115, 0.03908762043075902, 0.0531076975832028, 0.04243970216651048, 0.027500822441652417, 0.03924847733495491, 0.07367193286440202, 0.018321422593934194, 0.03385844620476876, 0.0628869105130434, 0.05627833226961749, 0.04502194181882909, 0.04156937922484108, 0.06608623705272164, 0.03879289874540908, 0.04720429364325745, 0.05182012988786612, 0.01473979585404907, 0.0577185024906482, 0.029210518646453108, 0.014057042892090976, 0.017087353992142847, 0.02256962686910161, 0.04908812398623143, 0.04583838229466762, 0.02927987849605935, 0.037138613406568766, 0.023825077805668116, 0.06951100006699562, 0.02287996164523065, 0.09160047689718859, 0.02158685031879161, 0.04131002617733819, 0.06563140824437141, 0.011951261200010777, 0.09071608113923244, 0.04252416281295674, 0.0671224957332015, 0.04630207955571158, 0.03553573388074126, 0.011929412372410297, 0.02721056721306273, 0.07124811078288726, 0.03734681848436594, 0.01614883997743683, 0.04645023089168327, 0.04997447053236621, 0.018483015708625317, 0.017363361681678464, 0.06994138125862394, 0.023330279892044406, 0.04837775210450802, 0.011410575659413422, 0.011618743417784572, 0.03877279714548162, 0.015306065557524562, 0.013087861639048372, 0.023859347216784954, 0.04338133913863983, 0.034092472932700596, 0.03488611802458763, 0.04563367506489158, 0.018381988629698753, 0.046419628962342224, 0.04084562323987484, 0.02200530795380473, 0.031943050412727256, 0.07510606412376676, 0.04798781838534134, 0.00777949219835656, 0.018117258192173073, 0.025179006225828613, 0.03560870014397161, 0.012847845991408187, 0.010523084933603448, 0.05454747764659779, 0.08974085668367998, 0.02933632243158562, 0.027435147037197436, 0.03869771385299308, 0.016918044237952148, 0.04125738882326654, 0.0050638059120891345, 0.034816025357161245, 0.04828229579808457, 0.03787753125652671, 0.07827639686209814, 0.03429613182587283, 0.035870875897152085, 0.05355101504496165, 0.04319039259904197, 0.06871931933398757, 0.01450402189844421, 0.05186514050832816, 0.06655281808759485, 0.04955323599278927, 0.11139725175287042, 0.024505792618063942, 0.04472664677138839, 0.052181378539119444, 0.0788707731823836, 0.04173593582319362, 0.07901534863880702, 0.02836237022919314, 0.006326423874790115, 0.009245793651124197, 0.012108142737166157, 0.01132853314213987, 0.03435035355921302, 0.03366444625758699, 0.03228397694017206, 0.024797050382143686, 0.02749042898150427, 0.042361412796058824, 0.060344453368868144, 0.029567523061164787, 0.025250357575714588, 0.008205042220652103, 0.02530920522154442, 0.004493641841690987, 0.016474982923162833, 0.034515620941030126, 0.013186540138641638, 0.06032236705401114, 0.06204034986772707, 0.01123643558405872, 0.05279589717143348, 0.008011237352288194, 0.008215165114961565, 0.02276108570263854, 0.03141441395772355, 0.03242330392822623, 0.03704329959249922, 0.01724257905568395, 0.07681654912552663, 0.018276099847363572, 0.026758474597175206, 0.038044522117291174, 0.025337993766048124, 0.05615554117996778, 0.015393749245309403, 0.031678781379014254, 0.048951779159584215, 0.04999080626294017, 0.03262728512553232, 0.021036315842398574, 0.0334626736917666, 0.026069027039089372, 0.053013014806700606, 0.03541039489209652, 0.0557796599210373, 0.05226230401811855, 0.06400480374161686, 0.03811080141791275, 0.10118989340428795, 0.00864648777392826, 0.013828101784123905, 0.03271158292357411, 0.040859098945345194, 0.023207169890935932, 0.061173467098602226, 0.017182952790920223, 0.05551704990544489, 0.04755534730585558, 0.040648624167910645, 0.015182378801650234, 0.024735264679683105, 0.04584430590538042, 0.043391154147684574, 0.01846182336365538, 0.004225988190488091, 0.045648823359182904, 0.057124933627034934, 0.0238053307402879, 0.01014656330724912, 0.010943490812288863, 0.023493586307657615, 0.06626410822251014, 0.03413285594433546, 0.02351377442079995, 0.035630874668381045, 0.022921532093148147, 0.12332747158195291, 0.03260231842952115, 0.02916037490857499, 0.025605646993166635, 0.020021210491125072, 0.039259262649076324, 0.026877252152189612, 0.06125191253210817, 0.06855583310659442, 0.038472073817891736, 0.11969603358634881, 0.02396606041916779, 0.002224180963821709, 0.025317481652434384, 0.020340997260063887, 0.011185600588630353, 0.009610378998331726, 0.035052996927074025, 0.010939374649231988, 0.04195185245147773, 0.04584877405847822, 0.05152686366013118, 0.039084499169673236, 0.03515286710379379, 0.03919449308887124, 0.010025542345829308, 0.016167165511952977, 0.00551803464103224, 0.044209046688463004, 0.025098048516416123, 0.010549011756666005, 0.04803331076566662, 0.038075975608080626, 0.019061989283987453, 0.029289361022944962, 0.08445365075021982, 0.04482174345425197, 0.02676397412350135, 0.02971885333369885, 0.005434178314836962, 0.020077493274584413, 0.0627918274008802, 0.02168574170874698, 0.011898798568706428, 0.05259441637567111, 0.04420052768130388, 0.015000894432887435, 0.07757544983178377, 0.03284573608211108, 0.020198007879246558, 0.06901030229138476, 0.037573673097150664, 0.03774229583463498, 0.041169664423380575, 0.03719528804400137, 0.040770237999303, 0.013698082600188042, 0.057088550579335005, 0.02302553115545639, 0.029276065129254545, 0.10029974366937365, 0.07591338508895465, 0.07182921495820795, 0.050505485252610276, 0.0569661089352199, 0.050331240852496455, 0.008292626672690468, 0.014075910406453269, 0.03774407020370875, 0.018432778672182133, 0.069973075629345, 0.05112415312656334, 0.027380864235705564, 0.012722801317327788, 0.01272710831835866, 0.032252486129956584, 0.05288642731362155, 0.012955174964320446, 0.03366168462006109, 0.04335016384720802, 0.050074015012277026, 0.009509293395759804, 0.02560394556660737, 0.045869252245341025, 0.0407203351413565, 0.01871418919680374, 0.04022078408992716, 0.019088572589680552, 0.01729874818452767, 0.054768456146121025, 0.08844808462475028, 0.08030069073928253, 0.057652101053723266, 0.03421638360513108, 0.06648621987551451, 0.025419007454599653, 0.030955320556781123, 0.035227689160300155, 0.026405717811680267, 0.04118314012885094, 0.03711725651685681, 0.02580348405587886, 0.028357825740905743, 0.0364650724056576, 0.0448345304466784, 0.05226769497884171, 0.028818298264273574, 0.06493838650307485, 0.01995436122108783, 0.021341261354142, 0.028916139621287584, 0.013161588709668388, 0.0435265388472804, 0.01955204932684345, 0.04104087847684111, 0.036330814074192724, 0.05150087916159204, 0.03872908931225538, 0.008649202762171626, 0.06982014062149183, 0.05275153794458934, 0.009215203596145978, 0.009103095192196113, 0.009535311821049877, 0.019412427176056162, 0.04800281740192856, 0.027445803429665308, 0.043152727120156796, 0.079177918843925, 0.015634576590465646, 0.01420035881788603, 0.023125696494909267, 0.015363316949723023, 0.023721597822649137, 0.03279503933819277, 0.011455140143100704, 0.07427346772913422, 0.02295625103371484, 0.0197028333786875, 0.034023028266217024, 0.04240119191152709, 0.006374390787511531, 0.028014129094247307, 0.037320152058133056, 0.024466546152585318, 0.04391919009919677, 0.24154087901115417, 0.1568502906177725, 0.17314549908041954, 0.1402023389403309, 0.14498060968305382, 0.16456365957856178, 0.1679507978260517, 0.1301430980009692, 0.1939311030187777, 0.08673444443515368, 0.07435895635613374, 0.10903192617531333, 0.1837651285209826, 0.07739674406392233, 0.1303251760878733, 0.12958842276462487, 0.1477767982121025, 0.12054066040686198, 0.1109394102490374, 0.0911824314721993, 0.133135301726205, 0.11294980772903987, 0.07951158843934536, 0.0883893370628357, 0.1611083828444992, 0.13227323655571255, 0.13505825639835425, 0.12489563386355128, 0.1285645134214844, 0.10984800702759198, 0.20865975054247038, 0.12552078174693243, 0.0780959404738886, 0.12677233958882944, 0.156727652198502, 0.08971224964729377, 0.1362334790506533, 0.10033020989171096, 0.27119025375161854, 0.13451027151729378, 0.1850972691816943, 0.10849597850548369, 0.11176627302276236, 0.09818222586597715, 0.06811213227255003, 0.0987173660791346, 0.07229504281921045, 0.16693006402679852, 0.11822757524039064, 0.18284401723316737, 0.17043880932033062, 0.1274483368865081, 0.1332533396780491, 0.16267729151461804, 0.16749463230371475, 0.12637623798634323, 0.07858764766050236, 0.1434772474957364, 0.0883013785683683, 0.14667526446282864, 0.09529450974826302, 0.09640990596796785, 0.08484526723623276, 0.14065087772905827, 0.16373752962265695, 0.2688060716858932, 0.12661479732819966, 0.10690553991922311, 0.1561781745404005, 0.16193353570997715, 0.08656945864536933, 0.15799686552158423, 0.10089268149541956, 0.10991947712110621, 0.13592655052031788, 0.11720366589725018, 0.12177781973566328, 0.14058546695326055, 0.08900746889412403, 0.10389276301222188, 0.15727052092552185, 0.14218584607754434, 0.17808547828878674, 0.15835449418851308, 0.12314748338290624, 0.20632046035357884, 0.1343571940170867, 0.17823874577879906, 0.1698483752885035, 0.09013676151101079, 0.16760300791689328, 0.240152542080198, 0.17867432454867022, 0.12214756703802518, 0.14848869001226767, 0.1310542348240103, 0.1402147425604718, 0.08814136644027062, 0.0915091053715774, 0.12235286459326744, 0.16085968618946417, 0.16558045787470682, 0.13775270538670675, 0.12032249782766614, 0.08678958897611924, 0.10649523657879659, 0.10936586718474116, 0.08300567737647466, 0.07080067122089011, 0.1676134844975812, 0.08638413037572588, 0.09295640021030392, 0.10856151141758476, 0.13689111519072736, 0.15160921828023025, 0.12225141003727913, 0.10287464157279048, 0.1770295828048672, 0.20687569198863848, 0.19081761794430868, 0.21945921890437603, 0.12255330383777618, 0.11463055254093238, 0.11261447572282382, 0.1780957920210702, 0.16352943650313786, 0.24262933060526848, 0.13583344194505895, 0.14041412329035147, 0.0947983106598258, 0.18149882155869687, 0.16444437312228338, 0.09321743263197796, 0.12553679517337255, 0.12814553161816938, 0.12358608841896057, 0.09488843368100268, 0.14306169907961572, 0.08250511530786753, 0.12063684953110558, 0.13331751552011284, 0.0805187379675252, 0.11135470082185098, 0.17846511863172054, 0.07605388254991599, 0.08589260639356715, 0.17275486647018365, 0.1485736561673028, 0.15841902286878654, 0.1799053227795022, 0.1675473137625626, 0.06429248223347322, 0.08100024677280869, 0.08552125096321106, 0.14021899018968853, 0.1598372831940651, 0.11572589805083615, 0.13038827984460763, 0.29195649230054443, 0.16635045941386903, 0.11707977897354535, 0.0982429954622473, 0.10538322624883481, 0.15379216043012484, 0.1216616409697703, 0.18751060111182077, 0.22925719672015735, 0.11190404277294874, 0.1272514938775982, 0.07875147315540484, 0.11290903455976929, 0.08373941800424031, 0.08556747955403157, 0.09963075563843761, 0.1278804008449827, 0.12562679605824606], [0.007277593415762697, 0.028026590389864783, 0.04303131006391985, 0.0685833544869508, 0.07081610110721417, 0.017850005300715566, 0.037616400447274954, 0.04442835259916527, 0.01888854555519564, 0.05889949947595596, 0.028077254903369715, 0.017290671921468208, 0.018847461956154023, 0.03713682546679463, 0.029077335792992796, 0.030190350354782174, 0.012138296833394893, 0.03372529388538428, 0.01522416977344879, 0.06988407897629909, 0.04022162886602538, 0.02792934444732964, 0.03684715886733361, 0.13962106513125555, 0.061530858278274536, 0.018142754145498787, 0.013774165035491543, 0.0524722766796393, 0.020702205199216093, 0.009756043503460075, 0.04291797096707991, 0.024050091892214756, 0.026227490411006978, 0.039275564452899356, 0.013602007978728839, 0.05847288415368114, 0.017710159233372127, 0.02683879618000771, 0.0988755054505808, 0.02723504027484783, 0.01431310419658465, 0.05432580704135554, 0.12401640175708703, 0.1322693417647055, 0.008462855841831436, 0.046109891297029595, 0.06510293124509708, 0.036005453140075715, 0.08424604617591415, 0.05250664787100894, 0.05132495877998216, 0.030872369650751352, 0.040568594355136156, 0.01825335874621357, 0.045198398243103705, 0.03289658888908369, 0.03282186522015503, 0.044087809444006, 0.021042534615844488, 0.06201325596443244, 0.02651238690928689, 0.016392367891967297, 0.010996686261413353, 0.054110338246183734, 0.08250250973339592, 0.035981361754238605, 0.05330989084073475, 0.03743696864694357, 0.05446033000147768, 0.039718817453831434, 0.011983982703116323, 0.039653101337275336, 0.012784347836194294, 0.04404935686449919, 0.06205460588846888, 0.07017937063106469, 0.016555850726685355, 0.025725939377610172, 0.02646695390077574, 0.05059543185468231, 0.05069727996098144, 0.011208611407450267, 0.022426249026986103, 0.02047897905244359, 0.050921237229236534, 0.034101361741444895, 0.048167687840759754, 0.039311591269714494, 0.017619367855201875, 0.023760060580181222, 0.06299631749945027, 0.061972835633371554, 0.011625106379921948, 0.034144296044749875, 0.09376484754362277, 0.03966861604047673, 0.03881629463285208, 0.030433014833501408, 0.03522844911952104, 0.026991627711270536, 0.03034347535244056, 0.002147771559456097, 0.0345050934702158, 0.023611512301223617, 0.03529396167557154, 0.04551253620801227, 0.04017054196447134, 0.028809117685471262, 0.03814002252849085, 0.04852964895378266, 0.002144952882580193, 0.019855527506609048, 0.0926640737535698, 0.019219545115317618, 0.02804118737445346, 0.013984931582984115, 0.027172745671123266, 0.02422160349254097, 0.036630587452756505, 0.020629634182634096, 0.01852452678472868, 0.04983573726245335, 0.0949000705565725, 0.026370819059333632, 0.006894543010275811, 0.030590031229491745, 0.027470178103872707, 0.10929888220770018, 0.05430484709462949, 0.0914940961769649, 0.0709862301924399, 0.06300186791590281, 0.11833098397723266, 0.018219876435718367, 0.0308703374383705, 0.034855034335383346, 0.08195073862693139, 0.02883247286081314, 0.03677197040191718, 0.014071705185675194, 0.025927956216037273, 0.04142987921035715, 0.015131398769361632, 0.023059125424229672, 0.03587687414671693, 0.016404230380430818, 0.05243944915543709, 0.027451854265694107, 0.051098141486623457, 0.029491048771888018, 0.014087442957263972, 0.09143407296921525, 0.028795105937336172, 0.06630993647766964, 0.04006736732221075, 0.0551894226643656, 0.05631884420290589, 0.022898390656337142, 0.012486657560137766, 0.012038319787409688, 0.0690693212673068, 0.025725947859297906, 0.07652279774525336, 0.02119769691489637, 0.03763789304399064, 0.022257690750328556, 0.03728547552600503, 0.05151394774605121, 0.06708676407911948, 0.03267457562365702, 0.0192814800954823, 0.01669785792806319, 0.008542794900547181, 0.0618426383339933, 0.040374967602214644, 0.04144184856808611, 0.04548789860148515, 0.017440105688625147, 0.02410796414395528, 0.006787362042814493, 0.04044831045238035, 0.05107977015099355, 0.07077017107180186, 0.016272282460704446, 0.05123093757512314, 0.09944229253700801, 0.051304646834198914, 0.027700988575816154, 0.03779763715075595, 0.04496166416044746, 0.0129737863317132, 0.030201776884496212, 0.02798342877732856, 0.0017846141043784364, 0.013226187787950039, 0.04700492987675326, 0.024070721053119217, 0.04508364779342498, 0.0580134955900056, 0.10738281466599021, 0.03020685911178589, 0.008358551438764801, 0.03777738627312439, 0.07470635271498136, 0.005281316249498299, 0.02076360922572868, 0.008669537608511746, 0.06702223539884601, 0.04676941715713058, 0.042908702178725174, 0.006655772898479232, 0.04197062073009355, 0.007513790607585439, 0.02662152417802385, 0.03016298164480499, 0.04628194063635809, 0.026582961336576512, 0.04725252051970788, 0.12981380495641912, 0.029976102922643934, 0.009491156154711331, 0.027447974741724983, 0.0779790628169264, 0.08408345561474562, 0.02071278864916946, 0.054655422390039475, 0.022606571404529468, 0.011731861990743449, 0.05074931341888649, 0.05820735304483345, 0.0454019282146224, 0.05340814949678523, 0.03966864996722766, 0.007720312070367592, 0.03575145712654505, 0.03392726322636008, 0.006219189048611692, 0.03697155808497753, 0.016681557820577706, 0.04944325903696673, 0.0266615865818624, 0.03694604856095143, 0.00600518292048946, 0.046720508352986405, 0.04888648034206458, 0.02383875028629388, 0.021224034251645207, 0.037387707004589696, 0.06329642675284829, 0.024661638541147113, 0.043976346496492624, 0.007363815708751125, 0.04716158325650862, 0.03433848937441196, 0.007503378487724278, 0.06465939325945717, 0.03372622008568474, 0.01799702348320612, 0.025543094546134983, 0.04159752485741462, 0.014791617269760795, 0.021505731457312192, 0.02396799424397094, 0.04525874036231211, 0.013944785210437008, 0.021778312545003634, 0.02248695755510458, 0.027372774401945726, 0.02613109433358269, 0.013435674448763686, 0.007511116331443191, 0.04920068276779992, 0.03181878011673689, 0.06271502402211938, 0.020996719931385348, 0.035129325331321785, 0.03427828974755747, 0.011650109547190368, 0.003742171517972435, 0.02514816341655595, 0.051526938298983235, 0.04778697880517159, 0.06363500215645347, 0.012161225379843797, 0.036793473176658154, 0.037083048173891645, 0.02814235694573394, 0.01735951778079782, 0.03479835291260055, 0.0814757641138775, 0.024844335791255747, 0.038395348470658064, 0.04694116794105087, 0.043959040460841994, 0.054533510003238916, 0.011977227038836904, 0.01787530617522342, 0.013757661367500467, 0.06643982843628951, 0.0037414420928273883, 0.018326070558811938, 0.029789909520851712, 0.01606787208999906, 0.032751026164208136, 0.046847550464527946, 0.05544988511662398, 0.0863895450851747, 0.05741955353213208, 0.11583378511880126, 0.02554511488415301, 0.02221007625173245, 0.05105637087087546, 0.09819948101150137, 0.028617726705436195, 0.03591375591765557, 0.03640685070838247, 0.011791160862360681, 0.02434893398146544, 0.017995021804901104, 0.013000893805708204, 0.015625826881400177, 0.023089237112019743, 0.07871141923325402, 0.04580943938344717, 0.07160702866635152, 0.10659680648573808, 0.028099756820925643, 0.06729046029171773, 0.02961506800992148, 0.022058863026489104, 0.0838218057262046, 0.011056957982613571, 0.05165257923571127, 0.059110354233000956, 0.0199911242483982, 0.014903142981763397, 0.014358308199527008, 0.05041774728202394, 0.06164967654539006, 0.015773564311010495, 0.05429149352546249, 0.03425609486709748, 0.01190375441884888, 0.047859273318733485, 0.004885358411619174, 0.0503764482481139, 0.03449191292747855, 0.03694533270650676, 0.018517565015437346, 0.03975390110697065, 0.056733591947704554, 0.040607555835906944, 0.11845217033156327, 0.08464284666946956, 0.10150092028613601, 0.08318305321569953, 0.22627723376665795, 0.07953513360449246, 0.11507085391453334, 0.11764839131917272, 0.11699984754834857, 0.21115595873977455, 0.16738378682306834, 0.076068036790405, 0.1261141470500401, 0.14557206151740892, 0.1438811793923378, 0.11118969467601605, 0.1677206251770258, 0.08988882481519665, 0.08857547957450151, 0.14875895051019533, 0.125558752566576, 0.10745519399642944, 0.1060580157541803, 0.13483507266002043, 0.11648861212389809, 0.12051064201763698, 0.1162181616361652, 0.16421319624142988, 0.08316277858934232, 0.042737904736506085, 0.16960563617093222, 0.14573516776519163, 0.11817721437130656, 0.0989533741293209, 0.08660791801022631, 0.1711868941783905, 0.1172108312270471, 0.06749944907746144, 0.15191504758383545, 0.15847561268934182, 0.10662363576037542, 0.18499844734157833, 0.22429015753524645, 0.2391842726085867, 0.03999897099233099, 0.15173705427774362, 0.14033354047153676, 0.20270951411553792, 0.21776034363678523, 0.12595868110656738, 0.10601525447730507, 0.10348429171634571, 0.1575975748045104, 0.11231277869748217, 0.11777415099952902, 0.1409354688865798, 0.10443536032523427, 0.12033766987068312, 0.147976938901203, 0.13586872576602868, 0.08213333918579988, 0.10712560239647116, 0.09176762042833225, 0.166278195434383, 0.12696515209972858, 0.14590092029954704, 0.1017432590680463, 0.10875702449785811, 0.14742268435657024, 0.11603887911353793, 0.1396159761186157, 0.13089296062077793, 0.09754357513572488, 0.17460303301257746, 0.1302640400826931, 0.1582181222204651, 0.14115159586071968, 0.08958977407642774, 0.11963857524096966, 0.13204860075243882, 0.1020906622122441, 0.12286700414759771, 0.16048647835850716, 0.14548571115093573, 0.12951995858124324, 0.06593383130218301, 0.1596997712871858, 0.077193590679339, 0.06859543919563293, 0.08777657244354486, 0.13014564929263933, 0.1341395606952054, 0.06892288662493229, 0.10835431396429028, 0.1677739308880908, 0.12638642958232335, 0.09370187270854201, 0.14679015401218617, 0.13090406145368302, 0.1130953806319407, 0.2006825671664306, 0.10728530918381043, 0.14148786424526147, 0.12526166279401096, 0.13453183536018642, 0.11614398418792657, 0.13286791821675642, 0.0774158923221486, 0.1444674607898508, 0.23102182203105517, 0.11257613170892, 0.1123230585030147, 0.14155507992420877, 0.14561672269233636, 0.07914184113698346, 0.11948298716119357, 0.14249999422047818, 0.11285936579640422, 0.15946475389812673, 0.08913382568529674, 0.08534156131957259, 0.23307487900768006, 0.1393935659102031, 0.14330119479979786, 0.05952018938426461, 0.09767367744020053, 0.09505809457706553, 0.2328113088650363, 0.11826192268303462, 0.28642990599785534, 0.2410654973770891, 0.15913942349808557, 0.18950523622334003, 0.11205684885914836, 0.16108843391495092, 0.11757776939443179, 0.1900034709168332, 0.09913770495248692, 0.08819232442017112, 0.13081153641854013, 0.1467800574111087, 0.14498902351728507, 0.11063572511609111, 0.10979315425668444, 0.10132826026529074, 0.09139983409217425, 0.1760524245245116, 0.14021030494144984, 0.22124923499567167, 0.2455923573247024, 0.11903934739530087, 0.23578109379325593, 0.06016009540430137, 0.1671427304723433, 0.18709920533001423, 0.13222949818841048, 0.1996175114597593, 0.09207663884652512, 0.07777659475271191, 0.09185824556542294, 0.1449257569121463, 0.13892309686967305, 0.1629818044602871, 0.09784652745085103, 0.11556086476360049, 0.11483085607843739, 0.07638623578740017, 0.11329706838088376, 0.21555602763380322, 0.1778531614691019, 0.08670283148863486, 0.12336454673537187, 0.09524851864469902, 0.22500484489968844, 0.173373690407191, 0.1223953544561352], [0.04905045172199607, 0.04077973070421389, 0.06513678335717746, 0.014580446993932128, 0.07327914929815701, 0.051071203646383116, 0.031670306476631334, 0.019607063249817917, 0.019199735285448175, 0.01023719268518367, 0.011212222910087024, 0.015199047014383333, 0.037836086337587664, 0.03184236599398511, 0.032182281504252126, 0.05307983014998691, 0.07986314421785728, 0.052093959479991875, 0.056266033822404485, 0.0707175371104053, 0.0649733989100371, 0.022491033854229108, 0.0334964613430202, 0.015911020238750746, 0.0624968343015228, 0.04282650105389101, 0.0341598446747022, 0.03730196053428309, 0.04483833024278283, 0.007628552931626993, 0.01594706910795399, 0.03479123508025493, 0.03709798951500228, 0.03822023554572037, 0.02822580996767751, 0.020155190623232296, 0.045562506919460635, 0.0073057305666485006, 0.03115577676466533, 0.03688831201621464, 0.057442739073719294, 0.009739626348683876, 0.04600396519526839, 0.07225311614040818, 0.07369793432631663, 0.02346296402226601, 0.059840770039175234, 0.023691260521965365, 0.035822418318795304, 0.03702431418267744, 0.05611067305185965, 0.02294042081172977, 0.029007891126509224, 0.044765713425087075, 0.02554284518451563, 0.032535462374133725, 0.007451483281329274, 0.07463449585650649, 0.05067284591495991, 0.030079138465225697, 0.03847256236310516, 0.06129153897719724, 0.0369421503772693, 0.06150178305272545, 0.04902933231954064, 0.015264425559767654, 0.021736131415569356, 0.009982174628281167, 0.027000414739762033, 0.012818975174533469, 0.06791235120700938, 0.03831220418214798, 0.023384727238278304, 0.017506015187661563, 0.05099644265802843, 0.01078431582677045, 0.07806128769048623, 0.01935787804956947, 0.02568849272626851, 0.027763792080804706, 0.01355255295389465, 0.02130545166853283, 0.06251349233623062, 0.044456047005951405, 0.057129785152418275, 0.0636973459539669, 0.04821422516501375, 0.02056470516669963, 0.05912707333586045, 0.04987507872283459, 0.03937532267134104, 0.05924255321068423, 0.02348208174641643, 0.036101496379290304, 0.034896282479166985, 0.06919282821140119, 0.07445607507335288, 0.01969876216857561, 0.06204176800591605, 0.06924124847033195, 0.06693547112601143, 0.10071310720273427, 0.0059045353970889536, 0.02139208193070122, 0.015061161913243788, 0.054938900750130415, 0.05297057583395924, 0.021990364916356545, 0.049396463869405646, 0.060062983472432406, 0.03705523502347725, 0.05858722408967359, 0.04684065315606339, 0.0171484000914331, 0.023921136311920624, 0.030042368652565137, 0.03596219313996179, 0.017864965301539217, 0.025816971635712043, 0.028197752544656396, 0.037589516889836104, 0.014994833418833358, 0.028794366334165846, 0.03486762794532946, 0.039667367536042414, 0.013746870116197636, 0.06867089228970663, 0.03394831477531365, 0.045495270884462764, 0.05771342704870871, 0.119584482429283, 0.01366256214013057, 0.027993823933814253, 0.027342080870377164, 0.04187404823356441, 0.024057423463091254, 0.03628000197932124, 0.04793205637750881, 0.03566087270155549, 0.012714497745037079, 0.03622083033302, 0.007182653644122183, 0.03080120150532041, 0.02666889440401324, 0.09969811380973884, 0.01194044535181352, 0.018665058172440956, 0.0163478865288198, 0.035552619224680324, 0.05875577897365604, 0.013168000017425843, 0.1114382827654481, 0.0351884087680706, 0.03823800637785878, 0.022150117504809583, 0.030784536685262407, 0.023072763978104507, 0.00887464262944247, 0.036045449386749945, 0.06734309425311429, 0.003607661704466279, 0.0024742170893919785, 0.046976614610425065, 0.039171192196330855, 0.028281163158161298, 0.023002298116417866, 0.05251573684758373, 0.030947425801839148, 0.03164149587973952, 0.07106806830103908, 0.03191625845751592, 0.019516212499833534, 0.02399812459147402, 0.023457505208040987, 0.02489446595843349, 0.040738642016159635, 0.06625880886401449, 0.037445172135319026, 0.036254098904984336, 0.020514829450153878, 0.07846804907811539, 0.027058884102318968, 0.004880616300007594, 0.032233653390514, 0.05752029562635081, 0.02689673119623746, 0.04145629118595805, 0.013216978371409433, 0.023115616857207248, 0.08437616205109016, 0.04188080644235015, 0.06467761871005807, 0.0566461627105517, 0.040722085761704614, 0.015624780241133911, 0.012782572618951755, 0.03274162506152477, 0.05474982696718403, 0.0857192814084036, 0.05815364021275725, 0.01082697362705533, 0.02036979598259287, 0.05640876705625227, 0.07277759656842266, 0.0368004790507257, 0.014566162135452032, 0.030297121232641593, 0.035282497826431475, 0.09252371878496238, 0.03179813568879451, 0.026644426431240778, 0.02154992105040167, 0.03280539717525244, 0.029743029536413293, 0.014328177852023925, 0.034624817581581216, 0.08106989160712276, 0.0032788828622350203, 0.016315591654607227, 0.07302446796425752, 0.044706222867327075, 0.016030096349173358, 0.05227629541020308, 0.045894341077655554, 0.0564606139170272, 0.04365411021613649, 0.012079729083260255, 0.024395109985822012, 0.06132771846439157, 0.014978599468512195, 0.04088496130758098, 0.05069226219451853, 0.01279393129516393, 0.03997904581150838, 0.012471448197694761, 0.026304232721616114, 0.02517192910558411, 0.011099879563386952, 0.06170988295759473, 0.04165354131587914, 0.06767757809055702, 0.0488759291225246, 0.06199013149099691, 0.02188482049054333, 0.015641685941123536, 0.03427204044003572, 0.09297320073736565, 0.043885317631065845, 0.043479231385780234, 0.041006049274333885, 0.03646190364712051, 0.033990126103162766, 0.08570439435009446, 0.011842252852927362, 0.024870596792814986, 0.013004408617104803, 0.02840340293810836, 0.026395572016813924, 0.02437945787927934, 0.030983547613556896, 0.041694660538009236, 0.024198548568944846, 0.05254376034385391, 0.006576440704520792, 0.04512451256492308, 0.05384203532178487, 0.048175789548882415, 0.032459693761276345, 0.037336633673736026, 0.029051405577255145, 0.008339426929264196, 0.04750933923891612, 0.054770831018686295, 0.024572821699881127, 0.06250356536890779, 0.07221461606345006, 0.0535766975954175, 0.02894712831558926, 0.06941928248852491, 0.06823985970446042, 0.051901577838829586, 0.02613829867914319, 0.027853993133508732, 0.024525733065924475, 0.05206363575000848, 0.05541193126035588, 0.058452107411410124, 0.01792997065266328, 0.009875000870254422, 0.029494834997292076, 0.056150272355547974, 0.020994836996708597, 0.03545201962281551, 0.03912951657548547, 0.012384380280439342, 0.03443506865629128, 0.050395033322274685, 0.027357934841087887, 0.044929460888462405, 0.027162287750148346, 0.022729245446888462, 0.03458870255521365, 0.05770038560565029, 0.09570110150213752, 0.029144317377358675, 0.04044990161699908, 0.08806849177926779, 0.08588732060577188, 0.10136678069829941, 0.0699195663577744, 0.006257533486599901, 0.04307579142706735, 0.05880015516387565, 0.031210341158189943, 0.04615221491881779, 0.05405350415302174, 0.012878539522976747, 0.014334639201739004, 0.01963484416981893, 0.04868321499920317, 0.021075862559622953, 0.030482897335397344, 0.03540030846904431, 0.035681476417396746, 0.04708382314337151, 0.03509464540651866, 0.028528706303664615, 0.012979166266242308, 0.05990569226975952, 0.012021228338458707, 0.05108358012512326, 0.015481209016538091, 0.025515435762437325, 0.011391607212967106, 0.05941483325191906, 0.11261130017893654, 0.025664065465597168, 0.03170226886868477, 0.05611164335693632, 0.019371543744845048, 0.030040855519473553, 0.020795932937679545, 0.0905148344380515, 0.015433058475277253, 0.0329625492782465, 0.05182407896167465, 0.06042865277933223, 0.031149395142814944, 0.026399030849071484, 0.027591746134151305, 0.10167012656373636, 0.040365573284881454, 0.19890134488897665, 0.12379635285053935, 0.1595562882721424, 0.07811545514102493, 0.1659292791570936, 0.10645223781466484, 0.08531320534114327, 0.19729895730103764, 0.13350423478654452, 0.10298438104135649, 0.2131154185959271, 0.08142990193196706, 0.10854760823505265, 0.1554700689656394, 0.14298920439822332, 0.18716814448790892, 0.1625889598258904, 0.13932187190013273, 0.1297541752989803, 0.1582764626613685, 0.1274297721683979, 0.1668573250727994, 0.143750235704439, 0.16660383796053274, 0.13913200423121452, 0.16417709817843779, 0.14047859768782342, 0.19956966117024422, 0.1390694568731955, 0.09459823103887693, 0.05534924480265804, 0.1943141631782055, 0.1359926126897335, 0.11837172321975231, 0.12829134879367693, 0.07646284917635576, 0.13221286050975323, 0.12020812396492277, 0.10270740983209439, 0.07030412607959338, 0.19109900641654218, 0.07437613007745572, 0.1009561245196632, 0.22634568437933922, 0.17485259819243634, 0.14667922710733755, 0.11963796455945287, 0.11996609052377087, 0.19655102172068187, 0.09593510787401881, 0.09038705272333962, 0.13746626861393452, 0.15605295768805913, 0.08602563318397317, 0.1645490982170616, 0.17397912006293023, 0.06647838279604912, 0.17738076538911887, 0.11463889852166176, 0.06334611587226391, 0.08965998209480729, 0.09157279945377793, 0.1309174693056515, 0.08636250546468155, 0.18846159508185728, 0.17701563212488378, 0.1542189996689558, 0.10612142485167299, 0.09991156735590526, 0.08995184036237852, 0.16800540632435254, 0.11217151449194976, 0.14302002345877035, 0.1074387530929276, 0.13225733169487544, 0.11361293321741478, 0.21073640696704388, 0.12937336787581444, 0.06288468491818223, 0.14347967665110314, 0.1251259015074798, 0.10529574951423065, 0.14095566208873475, 0.09041273527379547, 0.10687862243503332, 0.11019568158579723, 0.1847885221775089, 0.12291607580014638, 0.13190380137945923, 0.10121084656566381, 0.15801388317985193, 0.15112800124500478, 0.10115848401827471, 0.1355658955872059, 0.1493559256196022, 0.12837844554867062, 0.1458858839635338, 0.12137204222381115, 0.17958941044551985, 0.11401996601905141, 0.16942201102418558, 0.20033014964844498, 0.18650989766631806, 0.2707933379071099, 0.08309821598231792, 0.09569076062845332, 0.09234253636428288, 0.0994451559547867, 0.15889573443148816, 0.0860133720561862, 0.15093098181699002, 0.13356663286685944, 0.14933075197041035, 0.0603423702663609, 0.09776656209890332, 0.12819490182612622, 0.13459679830287183, 0.1062130406498909, 0.1288087046039956, 0.15360082712556633, 0.09949700960091182, 0.11494980326720647, 0.13686819427779742, 0.0931521032803825, 0.1336407017494951, 0.07141520681657962, 0.1124421888962388, 0.1304028004940067, 0.17522064915725163, 0.12039126056645598, 0.18523680312292917, 0.154482257685491, 0.15787462065262453, 0.26367794828755514, 0.16662788524159364, 0.1399427992956979, 0.13275433145463467, 0.10279575509152242, 0.11030068487993308, 0.13984154830021517, 0.10486823174038104, 0.05648970949862685, 0.09701737801411323, 0.1119828342593142, 0.20974353381565639, 0.08554362904812608, 0.19844945413725718, 0.12732294361506188, 0.16720560352717126, 0.08785643601523978, 0.09155565287385668, 0.11865129321813583, 0.1256326043180057, 0.16627145079629763, 0.18525353579648904, 0.10131565308464424, 0.12264890942190375, 0.1361399090715817, 0.21415825906608785, 0.18628797600311892, 0.0660877637565136, 0.10662715057177202, 0.11826965798224721, 0.11968231360827174, 0.13193106491650852, 0.11672327667474747, 0.26229786234242575, 0.11762954161635467, 0.11249812732317618, 0.1998993613358055, 0.12539461494556495, 0.11827668760504041, 0.1486126176480736, 0.23801382684281894, 0.22160554730466434, 0.09691371143396411], [0.04285486721034561, 0.042038168891199997, 0.04758325884384768, 0.014483660758872117, 0.05046430156965341, 0.011619370214508047, 0.01758570912560182, 0.04448630288243294, 0.05109388367938144, 0.019811387107308422, 0.005528410713720534, 0.03885650461805718, 0.03643582754635385, 0.012047821822177087, 0.01730214085962091, 0.0660038764721581, 0.017305842268147638, 0.02851147490686604, 0.032572727517357895, 0.010273031208531132, 0.017777581865500127, 0.00963040256673204, 0.012750805305716182, 0.04092646390199661, 0.03243758709036878, 0.05299029406160116, 0.036627652788800855, 0.03502152647290911, 0.029001098990972553, 0.02318954324748899, 0.011039285538052874, 0.05634491691099746, 0.025193277513608336, 0.030896766377346854, 0.02349262109159359, 0.02951045148074627, 0.06056495010852814, 0.03647433780133724, 0.02671024263171213, 0.03655530399243746, 0.017873991513624787, 0.027914316593004123, 0.05598075055916395, 0.03520413042445268, 0.020642840170434544, 0.02246354640062366, 0.050246043995554955, 0.05789496230759791, 0.013879354078588741, 0.021303059832592095, 0.03424729087523051, 0.03437772226919021, 0.027004631834902933, 0.07646185172987835, 0.03459379156785352, 0.0021487950871232897, 0.09260285632418734, 0.01995018483804805, 0.05338170359443341, 0.018316537141799927, 0.03444160973387105, 0.03132630957822714, 0.029081122018396854, 0.027812726330012083, 0.03040998535496848, 0.03429035070751395, 0.06597094716770308, 0.023226082358243208, 0.06429881296519722, 0.017785166190671067, 0.012171529782270747, 0.028881921100297143, 0.03199427302128502, 0.07071199347930295, 0.06406925778303828, 0.02684082160703838, 0.026892592132623707, 0.06840652147574083, 0.01999691724111991, 0.01643151936254331, 0.08561054617166519, 0.07073291271392788, 0.0076455985794642144, 0.031187518632837703, 0.020938269228541424, 0.0027143578419262277, 0.030013364673193012, 0.03218640699716551, 0.028898005772914206, 0.09641009595777307, 0.02729511946173651, 0.09806460182049445, 0.03808328343023147, 0.03427955860804234, 0.024648822710982392, 0.015120588010177016, 0.007014495703125638, 0.018883853485541682, 0.010127469331824353, 0.03585930348240903, 0.05212973863152521, 0.013832094114539879, 0.025774720956438353, 0.016488316136279275, 0.009619997232221067, 0.06376600012715374, 0.052965846444879255, 0.04710418937195625, 0.022520037833601236, 0.025926258182153106, 0.0016515732131665573, 0.04246405139565468, 0.0845879599718111, 0.008631931501440704, 0.03282657764585955, 0.03587768499606422, 0.05006952650312867, 0.019951711541840007, 0.04996286079819713, 0.016076202803690518, 0.07873894739896059, 0.033255849432732375, 0.019507154057334577, 0.02236447180621326, 0.04308946390769311, 0.013528643076175025, 0.028715944649385552, 0.04911867841812117, 0.04034492207158889, 0.040344233358544965, 0.030884562925036465, 0.04255222362865295, 0.052472432742693594, 0.030137227848172188, 0.03349296010232397, 0.045133801709328375, 0.013137276799950217, 0.055516557967556376, 0.015102868068165012, 0.03829162082235728, 0.0253201092792941, 0.050524080504796336, 0.02116287110506424, 0.02596036304852792, 0.0081421640768115, 0.038682735192456415, 0.043786373654646535, 0.008520363380999436, 0.039808971009084156, 0.02821618494843798, 0.026565117561923604, 0.057120129599102905, 0.04592779963942511, 0.02759950009307691, 0.14446452951857022, 0.0116206492530182, 0.012854236094946308, 0.10638115448611123, 0.04913289033408676, 0.00865581423775958, 0.06867444781320435, 0.03400463318186147, 0.016344023968226144, 0.05361002723553351, 0.06404675077646971, 0.031371513581169505, 0.029566661321691105, 0.02193086757324636, 0.04361788323149085, 0.023796779502715384, 0.02190221643208393, 0.022582364667739187, 0.013549846447339016, 0.059330525275851996, 0.07744749848331724, 0.028422320494428277, 0.034374506013201814, 0.03673664926152144, 0.03394441319895642, 0.021977247138108526, 0.03419941005163959, 0.01775274069846741, 0.04053425709051745, 0.009709137225789683, 0.0077209091811840025, 0.04428237257525325, 0.02325005330411451, 0.02862102777830192, 0.029873226835791553, 0.021875080120350634, 0.0129041041779731, 0.039143161914710484, 0.011776422233586865, 0.02834015499268259, 0.04315258462780288, 0.019633468440068618, 0.03666416475815432, 0.014051517072532858, 0.053621552152825255, 0.041007491161248515, 0.05001632935766663, 0.03153513212289129, 0.017347373700301563, 0.0566480727866292, 0.0215610015272562, 0.036881156864442995, 0.050942227710038424, 0.03559808785627995, 0.020907921749832373, 0.032191814921264134, 0.04472273162433079, 0.024856651201844215, 0.02542380808985659, 0.011024147421786827, 0.021233705071998493, 0.0637806293421558, 0.03840499723862324, 0.01786776595482869, 0.024317314249596426, 0.01593042803662164, 0.03458118438720703, 0.02187157718331686, 0.020341952298102633, 0.051667507006121535, 0.014373816117378218, 0.08750211181385176, 0.026292327824713926, 0.02526515133545867, 0.0671881100695048, 0.02901726508779185, 0.037207532208412886, 0.0508222525407161, 0.05629689359505262, 0.06072142028382846, 0.04191120820386069, 0.029585768867816244, 0.019556819428024546, 0.08232331542032105, 0.0296104912912207, 0.027510517010731355, 0.03950790162863476, 0.010585995307857437, 0.023410129893038954, 0.03351787590820875, 0.021112912267978703, 0.03355963973860655, 0.026621120449687754, 0.02628770700123693, 0.048865822343421836, 0.04106837950114693, 0.046811259019055536, 0.02274983050301671, 0.043220071720757654, 0.059634651456560404, 0.07641991148037569, 0.03468685943101134, 0.016446928892816817, 0.04386537887954286, 0.02010690776764282, 0.052061708710555515, 0.02789470523462764, 0.033663621837539334, 0.018134406468431865, 0.010031021516104894, 0.025147376315934316, 0.03301761578768492, 0.015306191086503012, 0.013026367706645812, 0.0288478552496859, 0.02814357152341732, 0.03656546166166663, 0.02285719509901745, 0.03349046648613044, 0.045417018833437135, 0.007129993389493653, 0.0004786521728549685, 0.02490949211642146, 0.05127407543893371, 0.03804754499079926, 0.02765496015282614, 0.0333616669688906, 0.053336167109331915, 0.04291853754382048, 0.0021892171145217226, 0.006878052912985108, 0.07931545789220504, 0.039075654465705156, 0.02598548071858074, 0.03639013160552297, 0.025564334388556223, 0.05995785125664302, 0.06100303267261811, 0.04288717904793365, 0.02669363379079316, 0.05905803918306317, 0.023992908353518163, 0.05132305209657975, 0.048201997963977714, 0.00939770576743675, 0.03332483608807836, 0.020426670787855983, 0.013490510256295758, 0.013057482778094709, 0.0701228825907622, 0.048855081134076626, 0.06704823686076061, 0.027756686122821908, 0.040641177246080976, 0.002224352930040498, 0.009963215511691357, 0.015787567577457855, 0.016960632488397614, 0.014580263789477093, 0.028518993074872663, 0.052427646038787704, 0.03688546216913632, 0.019724356509479027, 0.046087370719760656, 0.0043247201247140765, 0.03723919265238302, 0.057305091459836276, 0.03765874103243862, 0.00959857418534479, 0.03902965318411589, 0.04005018003018839, 0.017904157484216348, 0.018327583691903522, 0.0382228818322931, 0.050186539867094586, 0.02763482801882284, 0.040095363677080186, 0.04439291610781636, 0.011191014449910393, 0.04510028547208224, 0.05400425947404333, 0.055253934381263595, 0.016629729619515792, 0.0024794549556515577, 0.012715156772173941, 0.027537928129147207, 0.039024710056505034, 0.017977491852694323, 0.10752577520906925, 0.03312465129420161, 0.053992110304534435, 0.038767277263104916, 0.12196365690657071, 0.04122471057676843, 0.04061675677075982, 0.030364116387707845, 0.03853538113513163, 0.037450810761324, 0.12105345646185534, 0.22118801756628922, 0.12593736153628143, 0.14109518245926925, 0.16689617798796721, 0.0925214456926499, 0.10345835132258278, 0.07343290533338274, 0.12239527303193297, 0.15394331089087895, 0.07583410505737577, 0.07778061846537249, 0.11233660206198692, 0.10182618283267532, 0.12236921728721686, 0.09435599403721945, 0.05564875015988946, 0.12167495382683617, 0.16297277994453907, 0.1058467063786728, 0.12937969182218823, 0.07796266941087586, 0.13387662837547915, 0.11069377378693648, 0.11753103190234729, 0.07896567987544195, 0.11749599235398428, 0.14951971040240356, 0.13037020367171082, 0.08404638046132666, 0.092375106045178, 0.13213800452649593, 0.08750864610608135, 0.09394712240568229, 0.11591892769294125, 0.16188921380255902, 0.14157227400158132, 0.06383757878627096, 0.09425939100661448, 0.16266689635813236, 0.0858966436769281, 0.15243255267185823, 0.14335422909685544, 0.16364238544234208, 0.10821176054222242, 0.1253373058778899, 0.13946329216871942, 0.09363232286913054, 0.07918530130492789, 0.1875513946371419, 0.18266781525952475, 0.06084633179541145, 0.11452043987810612, 0.10085472424647637, 0.0854749952309898, 0.12932919524610043, 0.1596713135285037, 0.1197098892714296, 0.11998667727623667, 0.15379737157906803, 0.08303389086255006, 0.17008932307362556, 0.12350405353520598, 0.09709918219596148, 0.19718043080398015, 0.12592233877096856, 0.13412980336163724, 0.19550301081367902, 0.14444377991769994, 0.15285162947007588, 0.10461846300001655, 0.09567649103701115, 0.08452137533043112, 0.09928288430507694, 0.13671179195599897, 0.14267348205404623, 0.13378562325877802, 0.22095431653516634, 0.16769972629845142, 0.09229168694998537, 0.1331570012761014, 0.1626152191311121, 0.12247634439596108, 0.1141326299735478, 0.06916958838701248, 0.15650060081056186, 0.0825176274936114, 0.08392220176756382, 0.11701964720019273, 0.20067441117550644, 0.15375158403600964, 0.19966966366129263, 0.17093095076935633, 0.21802555583417416, 0.20570652186870575, 0.08079293396856103, 0.10885067590113197, 0.11521128352199282, 0.08018141106835433, 0.05422392161563039, 0.11744059675506183, 0.15797789368246282, 0.08775829949549266, 0.11657019917454038, 0.11221212481281587, 0.145814502079572, 0.14894884532051428, 0.1011804278407778, 0.07874788370515619, 0.1271051610154765, 0.1288416271231004, 0.1617914776184729, 0.24288983376962797, 0.15055945675287927, 0.17526934083018983, 0.07731129614902393, 0.1169931029102632, 0.17509091326168605, 0.20058936359626905, 0.1281919569841453, 0.2171843759715557, 0.11329288860516888, 0.08577366599014827, 0.06690065549420458, 0.10653887995119606, 0.11955096279936177, 0.07272839599422046, 0.0988392581098846, 0.11249060915516955, 0.14158072854791368, 0.11706111926053252, 0.13403786186661037, 0.13954756621803555, 0.06026978059006589, 0.14241551661065646, 0.1362433856619256, 0.13206553698650428, 0.10991871716188532, 0.12081317364105157, 0.0732765437236854, 0.1701276060193777, 0.11332502402365208, 0.05035247899858015, 0.1760697407381875, 0.09987199519361768, 0.2033808838043894, 0.12929492922765867, 0.15118472677256378, 0.1467231690351452, 0.06407633490328278, 0.06933943248753037, 0.16668999833720072, 0.10226939512150628, 0.11420650886637823, 0.2609419865267617, 0.14198182416813715, 0.11939815671316215, 0.2060536468135459, 0.11789858075124876, 0.10867680130260331, 0.12197952105530671, 0.09798633959144354, 0.09676815210176365, 0.09253288579306432, 0.19747621778930935, 0.13125460621501717, 0.12505874011133397, 0.12590874092919485, 0.10032875104142086, 0.09068813906716448, 0.22321846575609275, 0.11578816042414733, 0.137782113094415, 0.12290554493665695, 0.15133616221802576, 0.10442141643060104], [0.042399078274944, 0.04096151702105999, 0.031094440591654608, 0.01464589000014322, 0.041425512837512155, 0.028633485681244304, 0.014831951087606805, 0.05049672197284443, 0.05205736608643617, 0.0993755721886243, 0.016439227520355155, 0.058982755722744126, 0.048107637491609366, 0.04524029778050525, 0.013435428479819425, 0.025582441095528857, 0.07723378709384374, 0.06039128585585526, 0.07078381641102688, 0.021890440456835285, 0.040558131345148594, 0.021137007046490908, 0.05766405684075185, 0.06798741075077228, 0.05631299183837005, 0.026883781355406557, 0.030134903865733316, 0.018768733234277794, 0.039962350457374535, 0.03549643652513623, 0.007720341756274658, 0.022758888945515667, 0.012107651647446411, 0.030980270289416825, 0.09782176770802055, 0.03496109275147319, 0.09617334151906626, 0.024520506649943333, 0.05294532754591533, 0.06581237353384495, 0.05910929571837187, 0.046620828166071854, 0.01559530128724873, 0.05357335241777556, 0.050203242006578615, 0.04458539274388126, 0.09895163029432297, 0.03025790530123881, 0.05087067958499704, 0.058770591393113136, 0.026501945951687436, 0.03146331258384245, 0.01957439348500754, 0.03584098642958062, 0.03064478561282158, 0.057853822729417255, 0.035523116522069485, 0.026307148725858757, 0.050072291533329656, 0.022644045197271874, 0.0479236764700285, 0.13615889448140348, 0.032018920805837424, 0.028227333278794373, 0.02725999679283372, 0.027491222867476087, 0.05594902226169195, 0.009522737718985548, 0.010632266307116618, 0.026624121270807724, 0.020421123764078532, 0.08999988742704902, 0.052024253577526124, 0.06859585310199431, 0.026184986977438842, 0.04262966483033129, 0.02831549703010491, 0.024065489548125436, 0.037488123401999474, 0.01390787460176008, 0.0659969418442675, 0.09051584545522928, 0.020952944244657244, 0.02644170052371919, 0.06487557451639857, 0.04304196645638772, 0.022985300814200724, 0.02346749324351549, 0.02012711962951081, 0.040605554157601934, 0.019441366694601517, 0.03889717939975006, 0.002485718682042456, 0.041426937761051316, 0.02632895005600793, 0.01684083034550505, 0.01939213219364839, 0.030195775242256265, 0.0006029440441385045, 0.00989902694709599, 0.01190412337226527, 0.03785413197640862, 0.038175462412514856, 0.020501920321424092, 0.048919843908931525, 0.04607938775526626, 0.017272512628031627, 0.05195149426747646, 0.011918209759252412, 0.05399239868191736, 0.033825907057949474, 0.028304952595915114, 0.008640768571889825, 0.02424545230210892, 0.036607574937599044, 0.02319705463014543, 0.043037973277802975, 0.027682803837316375, 0.020964299528194324, 0.018508693170068518, 0.032249829665358574, 0.014577201900205441, 0.059359166238989146, 0.07904312786247049, 0.009097722891185964, 0.03857879041294966, 0.055447350788329325, 0.06061563667442117, 0.013238951031650816, 0.06492733995297126, 0.020236891328490207, 0.05862836366785424, 0.034189869849277396, 0.03355155838653445, 0.057417633278029304, 0.05882690979966095, 0.04363589494356087, 0.020036389319492236, 0.02856991712802223, 0.0119996695845787, 0.0175770595004516, 0.024557469845084206, 0.013119527172031147, 0.05721865966916084, 0.019083152791219096, 0.012915877608715423, 0.10565943749887602, 0.03207180243251579, 0.01678439828434161, 0.058646053075790405, 0.03546877604510103, 0.010948416128355478, 0.06734339959387269, 0.056936382316052914, 0.04370990954339504, 0.021888601626934748, 0.04344730631315282, 0.05692905413785151, 0.04265437029036028, 0.026190773184810365, 0.03726710419037512, 0.014214627561159432, 0.0975124914465206, 0.0421226600717221, 0.07333868396069322, 0.020270387209685783, 0.034373216796666384, 0.03526516464938011, 0.06710161721067769, 0.007041234647788639, 0.02420438397010522, 0.012444052346316832, 0.03593701270541974, 0.06568510750574724, 0.01042105192651174, 0.02798038045875728, 0.014923427786145891, 0.08637204566704375, 0.037861975841224194, 0.03702931159308978, 0.04966054291331342, 0.06702662552041666, 0.018914952441783886, 0.04223106961165156, 0.06822932205562081, 0.05953428934195212, 0.015325948329908507, 0.0513324192725122, 0.06128156451242311, 0.032370795495808125, 0.028264447447976897, 0.037584468589297364, 0.08298139260815722, 0.023558583177093948, 0.03280313426096525, 0.04459271413673248, 0.02541854265811188, 0.03726443415507674, 0.01875528975922082, 0.0594098935169833, 0.05463671517957534, 0.03410911061135786, 0.03563866425039513, 0.00978895923721471, 0.0474847525225154, 0.06697526041950498, 0.08442794784371342, 0.10109907827739205, 0.0236108931380191, 0.02432240156589874, 0.06850475299039058, 0.016014620661735535, 0.04131411774350064, 0.06762465235910245, 0.007403336980912302, 0.061136724427342415, 0.06416795070150069, 0.029775850275265317, 0.09637056450758662, 0.11070347683770315, 0.05883865524083376, 0.03350925172812172, 0.050014724622347524, 0.026782884894471084, 0.06498838096324887, 0.020025390266839947, 0.023961666904922043, 0.05100744171068072, 0.004888441929194544, 0.027826826287699596, 0.019523584782811146, 0.0715130108541676, 0.061723467228668075, 0.04927455148260508, 0.03790892707183957, 0.04012747873951282, 0.03578766714781523, 0.06377615101103272, 0.030224626551249197, 0.02497042965010873, 0.060680484266153405, 0.08025547995099, 0.009636206585647804, 0.031502894924155304, 0.025185923890343735, 0.02735442342236638, 0.03536735541586365, 0.015633823416594948, 0.03393661343891706, 0.04657254361414483, 0.035202413730855496, 0.023399090128285543, 0.06771061596061502, 0.01434524470408048, 0.015660924105239764, 0.02808716321097953, 0.03205113425584776, 0.06789314188063145, 0.04599509334989956, 0.05955174804798194, 0.045190863111721616, 0.025184431113302708, 0.01703855036092656, 0.061477070807346275, 0.025769837200641632, 0.02605757676064968, 0.04928517394832202, 0.04901417384722403, 0.02080003128919218, 0.038186963581080945, 0.038152677206588645, 0.010863843523631138, 0.019824830582365394, 0.048176295057471306, 0.03253889576132808, 0.022665788851944462, 0.002561592043743336, 0.04236158582248858, 0.02648500632494688, 0.048597682267427444, 0.05075671623593994, 0.04464199274246182, 0.02100209053605795, 0.015306416699396712, 0.023800748932574476, 0.09293685161641665, 0.04513225464948586, 0.009603282370205437, 0.014459784807903426, 0.018833358605791415, 0.033229437457131486, 0.018994810924466168, 0.024194182196099843, 0.016643736278638244, 0.05156868855868067, 0.005805508300129856, 0.0651394228584, 0.029366222077182362, 0.03148243370066796, 0.010132196176398014, 0.014499901494543468, 0.03405096694560988, 0.05901183094829321, 0.06691691319325141, 0.023497387800099592, 0.049524062379662476, 0.06893754298133509, 0.0823081840894052, 0.03660527809656092, 0.03960928154577102, 0.10236288367637567, 0.008306310179510286, 0.04924752204013722, 0.007400226746020573, 0.024479004055527703, 0.052518060830022605, 0.07905268842088324, 0.019417302450165153, 0.03359332560960736, 0.053934149843241484, 0.04727817592876298, 0.03418274523158159, 0.029519425106367896, 0.07439208922109433, 0.03690282588026353, 0.07734835773174252, 0.023721372209755436, 0.03227223149899926, 0.020040753995999694, 0.03664305553372417, 0.04348859177636249, 0.03423705178179911, 0.037596777214535644, 0.02273948454031987, 0.06572914442845754, 0.07815692041601453, 0.03133401773603899, 0.057437799338783534, 0.047214892360248735, 0.010632217113327767, 0.06053900971476521, 0.03581077126520021, 0.035268061993909736, 0.07664518510656697, 0.042781290265598466, 0.01855124579742551, 0.005117656995675394, 0.024541978890608464, 0.05729084222444466, 0.028853616011994224, 0.04127429113058107, 0.05026431015825697, 0.12281766108104161, 0.19992429071239062, 0.10551357961126737, 0.08743606321513653, 0.13745173439383507, 0.06611439625599555, 0.082340814838452, 0.14389544219842978, 0.2099897334618228, 0.2529024864946093, 0.06690820080361196, 0.13429889428828443, 0.15046119131147861, 0.11325997287141425, 0.12100221349724702, 0.15050278550812177, 0.18785358699304716, 0.12057717916156564, 0.12012907463525023, 0.08873132549758468, 0.2542217757020678, 0.08188441182885851, 0.11299632130456821, 0.14595618019146578, 0.1878486472581114, 0.09249209226774317, 0.09656121249177627, 0.12190891270126615, 0.12527938612869807, 0.11837427451142243, 0.16116624831088952, 0.15835616338465894, 0.145986388570496, 0.10034081539405243, 0.21108858021242277, 0.10262247760381017, 0.254158509096929, 0.2516207881271839, 0.10134575289807149, 0.09205086808651686, 0.23120969480701856, 0.11489119141229562, 0.2207656702292817, 0.21848944308502333, 0.15576106549373694, 0.19435218828065054, 0.2643384342747075, 0.07015716217990432, 0.12893382646143436, 0.12564481794834137, 0.15326405662511075, 0.1733998954296112, 0.06861673162451812, 0.11839499697089195, 0.13408978336623736, 0.19313634852213518, 0.27480630257299965, 0.07066551383052554, 0.1486096592353923, 0.08460172066198927, 0.11478536709078721, 0.1631561065358775, 0.11544186329202992, 0.15520305186510086, 0.1650986708700657, 0.1402069665491581, 0.11386209806161267, 0.11762122277702604, 0.08575440238096885, 0.07938356923737697, 0.08477935434452125, 0.16633794722812517, 0.18768997862935066, 0.08564778417348862, 0.07083789565201316, 0.09532097939934049, 0.19466127455234528, 0.13654899783432484, 0.08985237391399485, 0.19052039246473992, 0.08759317121335439, 0.21553512875522884, 0.1818307608898197, 0.15357696983431066, 0.16271269747189113, 0.140055490391595, 0.11927568114229611, 0.1268333127456052, 0.182340462825128, 0.10698815834309373, 0.1502229848078319, 0.10216196945735387, 0.12088365985878877, 0.14125573741538183, 0.12914263882807323, 0.07962413025753838, 0.19048369729093143, 0.1956076951963561, 0.0916569581521409, 0.07586154501352992, 0.095426952998553, 0.11388245411217213, 0.0802637580782175, 0.15306835355503218, 0.1776299505893673, 0.1694022249430418, 0.07994359811501843, 0.1685364685420479, 0.09994529733168227, 0.2095814182290009, 0.11561953090131283, 0.0785436514498932, 0.08157947140612773, 0.0974053100549749, 0.11756593574370656, 0.078858525625297, 0.07510412351361342, 0.16398944253368036, 0.12213052223835673, 0.10685748606920242, 0.10827974296574082, 0.07250203671199934, 0.11865659936198167, 0.1491091288626194, 0.15616722298519953, 0.1169358209839889, 0.10438632259943656, 0.16760348289140634, 0.12574790098837443, 0.22018058305340155, 0.14744358323514462, 0.1391436614628349, 0.13909186209951127, 0.17190702339368208, 0.2564142037715231, 0.08810811822435685, 0.2736951879092625, 0.08842913314167943, 0.11236597584294421, 0.12484368522252355, 0.14155920541712216, 0.1308380535670689, 0.1471129466912576, 0.12264061772397586, 0.11283293685742787, 0.11032845731824636, 0.11896461354834692, 0.19210052410406725, 0.23084722140005656, 0.1419088409415313, 0.08963799756020308, 0.10794441774487495, 0.11136149295738765, 0.1109576831970896, 0.12119923292526177, 0.11496724161718573, 0.12220510680760656, 0.20730958799166338, 0.20774942796145165, 0.21339867982481206, 0.15640361101499625, 0.07606690363692385, 0.11657904727118355, 0.10733562255544321, 0.10324392068598952, 0.10572705351348434, 0.23751027243477957, 0.16181502278362, 0.14767461083829403, 0.07863590507102863, 0.07494109869003296, 0.14298980150903973, 0.12634716954614433, 0.15921221673488617, 0.1358774381556681, 0.11613433541996138], [0.044225789540048153, 0.019110183930024505, 0.02271072822622955, 0.03676596536700215, 0.018890479379998784, 0.02703546446615032, 0.06071143224835396, 0.04242039445255484, 0.017618273717484305, 0.024063937399270277, 0.025376739811950495, 0.0468384852366788, 0.03558024577796459, 0.07465308093066726, 0.024150048582149402, 0.051748042327484915, 0.08627246386770691, 0.04356618904109512, 0.039816787732498984, 0.031197764511619295, 0.11438797627176557, 0.05314149880515678, 0.08594427004988704, 0.05586144374683499, 0.020250411138736775, 0.016409251539568816, 0.018238751583599618, 0.0378707085869142, 0.05052617717800396, 0.013945827609859407, 0.021120272676593492, 0.025102565863302777, 0.03941082362351673, 0.04199947543176157, 0.02159012933926923, 0.04550226318782993, 0.06764069971229349, 0.012548420362041464, 0.0884401932624834, 0.02874053136578628, 0.035773126142365594, 0.04497846808018429, 0.04922229071546878, 0.05588283117062279, 0.057303089781531265, 0.032796447298356464, 0.03796466872362154, 0.033964698003338914, 0.04044759459793568, 0.013145567649709327, 0.034527573335383616, 0.03745547229690211, 0.05363632046750613, 0.02965014487771051, 0.03769010292100055, 0.04852278557206903, 0.012117734677823526, 0.03449908843530076, 0.07671493172113385, 0.005072258337999561, 0.038081678694912365, 0.03963498105960233, 0.026742369568507587, 0.007685688972872282, 0.05518368225810783, 0.019019757264426777, 0.06958301977387496, 0.04245694374133434, 0.0021913960601003574, 0.04908764222636819, 0.015900141626064266, 0.03861663909628987, 0.0367774360014924, 0.03705743347693767, 0.04482027781861169, 0.01719828598600413, 0.012677677042250122, 0.012707690342462488, 0.04370157374069095, 0.07019963847207171, 0.02330501633696258, 0.05238353447722537, 0.029045671956347566, 0.025614744451429163, 0.03000645718670317, 0.013651436710331057, 0.04030817261497889, 0.010122178455016442, 0.0755839291960001, 0.01377795634990824, 0.040831153480602164, 0.04192904010415077, 0.011275956856219896, 0.02827599611399429, 0.022144171841708676, 0.08446996951741831, 0.00666573633705931, 0.031570334519658766, 0.0315882410588009, 0.03654991642438939, 0.08254255687019654, 0.022848170583269427, 0.029045804270676205, 0.036697843843804936, 0.025825494035546268, 0.00892212735821626, 0.011289656478246408, 0.06680768262594938, 0.05407593652073826, 0.011003933015412517, 0.0404532060825399, 0.01613542534011815, 0.03380617525960718, 0.06990917798663888, 0.022105417314118574, 0.006422643957193941, 0.028315269720873663, 0.038514197271849425, 0.023463579792795435, 0.05020403249987534, 0.08282589273793356, 0.01799018893923078, 0.017383999324270656, 0.02667849906720221, 0.11725925148597785, 0.06817883226488318, 0.028393213038465807, 0.03728645940178207, 0.009166533975595874, 0.030308652935283523, 0.026508850045502186, 0.027290676753701906, 0.03487451507576874, 0.021343880499313985, 0.008201424780833935, 0.01680730901924627, 0.0300432914601905, 0.03436362909685288, 0.06802959527288165, 0.010637341749056109, 0.08529218432626554, 0.07796815875917673, 0.03282404671023999, 0.017687402865184203, 0.01711140975489148, 0.05657267736803208, 0.037539105130625625, 0.021862328751012683, 0.03595358931592532, 0.025120658999575034, 0.018524677758770328, 0.046964584184544425, 0.04792103357613087, 0.050252832738416534, 0.021287467097863555, 0.040778078471443484, 0.07626642007380724, 0.05747294745274952, 0.013589519541710615, 0.016101400201608027, 0.03511181573516556, 0.03875118241246257, 0.03027007482679827, 0.06459516313459192, 0.022000676952302456, 0.023786533623933792, 0.03447360944535051, 0.026383341423102787, 0.005991385334969631, 0.0341617547507797, 0.027837715078411356, 0.010937138028176767, 0.024653002486697266, 0.02798006493997361, 0.006833007093518972, 0.021552163608638302, 0.0012327883970491321, 0.02620708177398358, 0.04910692958427327, 0.0034757254470605403, 0.01594526250846684, 0.018948648490809968, 0.07870390785059758, 0.013971714568989617, 0.021355866820418408, 0.046954463834741285, 0.011622413444066686, 0.0627902667703373, 0.018674544092001658, 0.03289429883339575, 0.046558270630027564, 0.04534604746316161, 0.1314095157597746, 0.01660530235884445, 0.0261938418594322, 0.008592467904756112, 0.06738396920263767, 0.08279246810291495, 0.04289380494239075, 0.034053664122309, 0.04207209903480751, 0.025274275935121944, 0.03895538752632482, 0.0295276048460177, 0.035882492416671345, 0.030838799130703722, 0.04086372994684747, 0.04739397132237043, 0.020707155112177134, 0.013401948713830538, 0.056708900058375936, 0.05185193282419017, 0.028642445736165558, 0.05938849252249513, 0.03550881639655147, 0.020168213406577706, 0.04320460790768266, 0.05120406419570957, 0.06299829203635454, 0.0513751907274127, 0.08249510013099227, 0.01770432892122439, 0.045243581889995506, 0.009638883406296372, 0.02524222363717854, 0.06909299535410744, 0.016456221429897205, 0.05590126696707947, 0.03952743325914655, 0.05408069644389408, 0.05959912336298397, 0.04687909555754491, 0.010632546202811812, 0.026183407687182938, 0.09606060292571783, 0.033471925516745875, 0.034072096526090584, 0.006573501375636884, 0.024681889418778673, 0.04974716469379408, 0.02605464888204421, 0.010585997004194983, 0.027132447476365736, 0.027271710003593137, 0.029553005804440806, 0.020013999360214387, 0.07055639861417667, 0.0449476897317384, 0.025045260188302824, 0.03194427516843591, 0.06107361388525792, 0.03684434973235641, 0.025773329959650124, 0.01820446690544486, 0.11522332073322364, 0.01165421977306583, 0.02143288224137255, 0.03379106767741697, 0.020909965836576054, 0.021533583623490164, 0.1198319848626852, 0.029133484565785954, 0.04311524145305157, 0.025741778081282973, 0.0642985754779407, 0.0368944086533572, 0.04835242239226188, 0.03811249775545938, 0.048598052069012604, 0.03730844732906137, 0.03220572488914643, 0.021816678611295562, 0.03437709462429796, 0.043110932755683146, 0.02192162592629237, 0.035753580941153426, 0.031008232717535326, 0.047847616087113104, 0.032820263877511024, 0.0513577184506825, 0.011805678119084664, 0.0531900310223656, 0.03758180533934917, 0.0026067786592258407, 0.02810580935329199, 0.020415232383779118, 0.0366772299499384, 0.01275055848860315, 0.03237168098400746, 0.05783186533621379, 0.030554842403424636, 0.06222710306090968, 0.022259168260331665, 0.04946529106902225, 0.03234455654663699, 0.06357175590736525, 0.07121845201722213, 0.016576311950172697, 0.06849618987845522, 0.011190550501591392, 0.09737019586775984, 0.04987779625558427, 0.034086620568164756, 0.05879536470664399, 0.02390718223926212, 0.03966962366497942, 0.013159747335261531, 0.021008073518584882, 0.02192630442524595, 0.02092903436693762, 0.03642468600134764, 0.011667738735143627, 0.035807381982782056, 0.03204622505498784, 0.02464786428026855, 0.02310640744066664, 0.05137728740062032, 0.07354305192295994, 0.03393700698922787, 0.0410950018226036, 0.05261772405356169, 0.038636282685079744, 0.01947648257815412, 0.06655600041683231, 0.027721746658374156, 0.02610002251874123, 0.004377609808995787, 0.033412618163440905, 0.03844324965029955, 0.02417892194353044, 0.01666524414239185, 0.02979525298412357, 0.05985840516430991, 0.0094529173137354, 0.024065514993188635, 0.018845840257459452, 0.00850664934010378, 0.0575817505429898, 0.07999855266617877, 0.05804047414234706, 0.016481603728607297, 0.04905170361910548, 0.05902938464922564, 0.008917480241507292, 0.06315949838608503, 0.07027868780174426, 0.020921506020905714, 0.037297777365893126, 0.005146041811843003, 0.06333351547696761, 0.06304964356656585, 0.047714361987475834, 0.06817396716879946, 0.13290443697146007, 0.12710011271493776, 0.12398136220872402, 0.17249562538095883, 0.13077188283205032, 0.14949165976473264, 0.08062092534133367, 0.12229689902492932, 0.09196732685502086, 0.08130974016551461, 0.10815816306109939, 0.1458351295441389, 0.18790132871695928, 0.12047735308962208, 0.14594680283750805, 0.2340300663241318, 0.13408793775098665, 0.09723011909851006, 0.22141878732613154, 0.16516602225601673, 0.1595906764268875, 0.12326668841498238, 0.15434406724359306, 0.14140987343021802, 0.1106706221721002, 0.09397256068353142, 0.10204373473035437, 0.1562988587788173, 0.14784575094069752, 0.1306259570909398, 0.13068045702363762, 0.14010643480079515, 0.0685917886772326, 0.11140149259673697, 0.15213901842279093, 0.1916996320443494, 0.11243972581412111, 0.11835091933608055, 0.08010021756802287, 0.09647611062973738, 0.13244130967983178, 0.12053048238158226, 0.148933917550104, 0.12264194765261241, 0.0836653762630054, 0.05814145372382232, 0.08430193710540022, 0.10087195225059986, 0.1392747408577374, 0.12435926550201007, 0.11095001575137887, 0.21966322724308285, 0.13910442856805666, 0.09929083673549549, 0.11658454340483461, 0.12797416081385954, 0.12774107046425343, 0.18642824276217393, 0.12624882268054144, 0.15922428108751774, 0.1357775442302227, 0.08827933296561241, 0.14257898926734924, 0.10561153971190963, 0.11538447280015264, 0.157528282808406, 0.09861817104475838, 0.13153888524643012, 0.10227016865142755, 0.23109898503337586, 0.19010407051869802, 0.0924498602481825, 0.0942797674132245, 0.1238589273499591, 0.2510043797748429, 0.07761361064123255, 0.14758940041065216, 0.2565658156360899, 0.12750760013503687, 0.086956081113645, 0.140577623088445, 0.10586233982550246, 0.1015161941094058, 0.19258452313286917, 0.10871638703559126, 0.09675224724092654, 0.2075143020067896, 0.11514262934880597, 0.1721254845282861, 0.14013038708695344, 0.15863318209137234, 0.09028774912336043, 0.11086763481476478, 0.12550551470901283, 0.16457161200898035, 0.10889186297676393, 0.11089996022305318, 0.17628163365381105, 0.17031257466546126, 0.12512563009347233, 0.18752129482371466, 0.12692848406732082, 0.11439237317868642, 0.12168206487383161, 0.17967441731265613, 0.09143114848328487, 0.1320539747497865, 0.07259386285607304, 0.1343651328768049, 0.1373364512941667, 0.11056787839957646, 0.05951134128762143, 0.23075906613043376, 0.15807799116841384, 0.1320337408355304, 0.07947465577828032, 0.11308446300349065, 0.16021107456513814, 0.1580379440316132, 0.13111115034137452, 0.09429215067731482, 0.19461136151637348, 0.09742350157882486, 0.24196865462831088, 0.07330945267208985, 0.1346685601664441, 0.18159435928932258, 0.05575482553935476, 0.07006527496767895, 0.1395305214183671, 0.1477046427982194, 0.11444311402738094, 0.10301336805735316, 0.1387069970369339, 0.11834683455526829, 0.08710138938788857, 0.09165161129619394, 0.17864886591477053, 0.09369626122393779, 0.12690769375434943, 0.18820220471492835, 0.11781518879745688, 0.12217377206044537, 0.13944782157029423, 0.20793841353484563, 0.11077592402164425, 0.1574591672314065, 0.11663084663450718, 0.07259727588721684, 0.11549590182091508, 0.11288671754300594, 0.10568710815693651, 0.1508862663592611, 0.09760353727532284, 0.24703020017061914, 0.16114505087690695, 0.11243643491928067, 0.08921199970479522, 0.06457281897642783, 0.10284123050847224, 0.12106470657246453, 0.23300469134535107, 0.12783132919243403, 0.06193967562701021, 0.15607829418565544, 0.14887624207351888, 0.06863132012741906, 0.18361920277987206, 0.11675655203206198, 0.08398462698927947, 0.1608061090643917, 0.09225069664950881, 0.13906455785036087, 0.21287384655858788, 0.0876034510188869], [0.02004904399759003, 0.014595108439347573, 0.013587278679811528, 0.06032421945461205, 0.05072618555277586, 0.05351458789248552, 0.05868724015142236, 0.007783534570730158, 0.03486437097723995, 0.03529765969142318, 0.013179714924522808, 0.019009655574336648, 0.023628436660926257, 0.014900927564927509, 0.024933306999238472, 0.010425547221010285, 0.0405802719428071, 0.022839441230254512, 0.045747808047703335, 0.029216859556202377, 0.04076221093003239, 0.014985678285094244, 0.06468405122203486, 0.05013936132724796, 0.06448830065450498, 0.07988773432693311, 0.03853628697938152, 0.03139906549560172, 0.010202412676465298, 0.031123098518167223, 0.03500117042234965, 0.033431776599692445, 0.013344565855472215, 0.033375359805566926, 0.02927406345094953, 0.028346679106886898, 0.04091122739815286, 0.021431760962254236, 0.01901151136761265, 0.02373198789012219, 0.03803778087188091, 0.06633620935359172, 0.0666657534560987, 0.07950546126812696, 0.026003102273015038, 0.08728185934679848, 0.013997723664423185, 0.0510944061513458, 0.009322267092232193, 0.024967494986153076, 0.032368926131831746, 0.043536608306957145, 0.01678019984891372, 0.055915848684630225, 0.06871431174554996, 0.04981117768745337, 0.03941193302827222, 0.07351534733814852, 0.027757381621216024, 0.034011822260384045, 0.03376694915017911, 0.04776044808594244, 0.06903014944068023, 0.0505633575043508, 0.04720092810956495, 0.03683909787131207, 0.046539546456187963, 0.022312131311212267, 0.02109941790279533, 0.023437327272923927, 0.025534466973372867, 0.04950605745294264, 0.057836051897278855, 0.06519334603633199, 0.006157153560447374, 0.030048926693520377, 0.03892269231645124, 0.033427213451692035, 0.039963738061487675, 0.03255210344546607, 0.05020879242303116, 0.040048992593905756, 0.036532013277922354, 0.023020430268453698, 0.07437720216278519, 0.014958513135622655, 0.02083139487409166, 0.04278599590595279, 0.020403397036716342, 0.16449967372630322, 0.019572568225807378, 0.013234892544070525, 0.06361428648233414, 0.042626428218292337, 0.05103409117353814, 0.0277622636806752, 0.048090850535248, 0.027441893371620348, 0.06557792611420155, 0.05732657387852669, 0.03590446677325027, 0.0736306236524667, 0.07268614361860923, 0.01221435297546642, 0.03776598009946091, 0.02672169460648937, 0.014483257030536021, 0.10178183378385645, 0.0340924220425742, 0.03901306639558502, 0.038611872387783866, 0.02821785244824631, 0.049593093139784675, 0.03276260197162628, 0.025732375282262052, 0.04980955259608371, 0.043568224646151066, 0.022663045874131576, 0.024992858625150154, 0.04155351507610508, 0.025230237316074114, 0.1258365855153118, 0.07761511020362377, 0.024352014530450106, 0.03192588347675545, 0.0946673262598259, 0.03405769122764468, 0.04139046650379896, 0.04766258976555296, 0.02440489615712847, 0.1201693524739572, 0.030699271974819045, 0.04718816486586418, 0.047250305102871995, 0.05724066455981561, 0.04432843492499419, 0.0820110807461398, 0.02831863864724125, 0.015112871370677437, 0.008772713098941105, 0.03939913246514542, 0.017280677100643516, 0.03452051317851458, 0.03300238946186645, 0.026727368855582814, 0.056960443167814186, 0.03805890366701143, 0.0298957949105118, 0.018240188381501606, 0.04044324518846614, 0.02093078159461064, 0.05663825099223426, 0.05611926330519574, 0.0221038465055504, 0.025777547054791024, 0.037835601185049327, 0.008874249927300428, 0.03598762463246073, 0.010187956487892993, 0.024203288136050105, 0.026246424930702363, 0.01884293443124209, 0.02302824699186853, 0.011801833370035248, 0.05160605548215764, 0.01611770879078124, 0.0357661440170237, 0.049583790424679, 0.11585157630699021, 0.01932928797655872, 0.06598339828529529, 0.018820390105247498, 0.028549320197531154, 0.04810697591996618, 0.02551744761876762, 0.0342984558083117, 0.06359570819352355, 0.026611011974247437, 0.03090856270864606, 0.06985431843038116, 0.056775308280651055, 0.035960055754653046, 0.04525828913652471, 0.053475592484963794, 0.042462080251425505, 0.02586626211580421, 0.04165161766910127, 0.024204735111977373, 0.04530356438564403, 0.03334285458549857, 0.0056758525565133566, 0.026455562994150177, 0.01786662601599736, 0.019097804058609263, 0.07385912710534674, 0.03544433182105422, 0.06516750742282186, 0.03306199197790452, 0.08485884472195591, 0.05433105890239988, 0.044921644165047576, 0.032668679154344966, 0.02217401720450393, 0.034320111253431866, 0.04178038325959018, 0.039519565645605326, 0.07211980436529432, 0.027274849924391935, 0.03371447464451194, 0.08412631188652345, 0.006562425987794995, 0.056769679832671366, 0.005982518154529056, 0.012700458855501242, 0.014856073007519757, 0.010645565593482127, 0.026534172972398143, 0.041565552287335904, 0.016117632455591644, 0.03096494557602065, 0.06281172883297716, 0.09486850510750498, 0.06740139398191657, 0.03293270730812635, 0.04845413818423237, 0.034472422009067874, 0.016168176529130766, 0.02665256885146456, 0.035483903983341794, 0.028850372614605085, 0.013904232565047485, 0.07307106974933829, 0.03948665330452578, 0.04011346699137773, 0.06687141742025103, 0.02974161139822432, 0.0507332423169698, 0.0030400605880588826, 0.01391622906417719, 0.0404800150011267, 0.08523543844265596, 0.023735093884170055, 0.009707923496275075, 0.028127741301432252, 0.03460705014211791, 0.019462504756769965, 0.047924117517790625, 0.02119039587809571, 0.028146981161886027, 0.012102027440310588, 0.053333195125950236, 0.01830820133909583, 0.03754301009965794, 0.010718206159903534, 0.02557310275733471, 0.008717093583462494, 0.045852831697889736, 0.03055003498281751, 0.03735563943960837, 0.004232134445503886, 0.01096222601232252, 0.05065781297162175, 0.01844495498309178, 0.0596598590325032, 0.03694236072312508, 0.07740124275109597, 0.07552782792065825, 0.02030105868886624, 0.05485341551580599, 0.09039692540786096, 0.02565732252384935, 0.06455045446221318, 0.04056196167532887, 0.03400319468762193, 0.05500039637887052, 0.04315456934273243, 0.022533562732860446, 0.047128538601100445, 0.0375529743864068, 0.007417348729047392, 0.07396203372627497, 0.063500794715115, 0.03314006421715021, 0.05429081838311894, 0.07715238324765648, 0.06193264600421701, 0.012621025305374392, 0.0178821933056627, 0.06546114345214196, 0.027552201113264476, 0.041793601121753454, 0.03547755628824234, 0.06143820432147809, 0.01404624231093164, 0.019012875223000134, 0.03165765179853354, 0.031030074759785618, 0.0647893598569291, 0.01050813341446753, 0.014244495824511563, 0.04473102332225867, 0.05926137577210154, 0.039623015094548464, 0.07286282735211508, 0.04575664596632123, 0.019934168018932854, 0.04885847041649478, 0.04199523458789502, 0.013365731907210179, 0.13025380777461187, 0.024591427130092467, 0.016066827146070342, 0.02708689233155123, 0.005886500784462052, 0.034574460105172226, 0.05507737278406109, 0.021713872074282596, 0.07174641332988228, 0.03573557262175849, 0.023641856387257576, 0.04104475969714778, 0.013843250078415232, 0.06554859304534537, 0.02799077222256788, 0.05065044068864413, 0.0404274522859071, 0.07451946381479502, 0.0825883647693055, 0.06581070433769907, 0.04223000091899719, 0.10353121241288525, 0.03205909347161651, 0.012026154502694095, 0.01011024896121983, 0.040432361486767016, 0.03630035802988069, 0.027579164398568015, 0.05746698991528579, 0.018727133948622004, 0.005346176563762128, 0.01946128678641149, 0.043720535401787074, 0.019574376521632075, 0.04112943068944982, 0.05534789791064603, 0.039344724134675095, 0.031131485210997716, 0.02807460692045944, 0.05388612313462155, 0.043364962695964744, 0.044707624042140584, 0.041954261250793934, 0.14963830475296291, 0.15428503469697066, 0.10487662521856171, 0.10005737774606262, 0.1698272999908243, 0.07744682673364878, 0.1093408428132534, 0.1259109258119549, 0.14289153606763907, 0.10854064646576132, 0.10574874627803053, 0.05906095688364335, 0.11182439633245979, 0.15273570854748997, 0.07531942267503057, 0.13376557933432714, 0.16828091868332454, 0.2072812116571835, 0.07894370891153812, 0.112137757374772, 0.1421808927719082, 0.10846686256783349, 0.19774265134973185, 0.1084228256451232, 0.16977326146193913, 0.13319341146520206, 0.06589478839720998, 0.11579171594764505, 0.16994820136044705, 0.1686449120087283, 0.12396879574017865, 0.13039229677191802, 0.11752432797636304, 0.14182854310742446, 0.17333399610860006, 0.16158442944288254, 0.0928404860730682, 0.10052805713244847, 0.0716929379850626, 0.12543227363909992, 0.12901898260627473, 0.12980084493756294, 0.10840559085564953, 0.1661651786416769, 0.17473156111580984, 0.15719371076141084, 0.17397092335990497, 0.1627895212067025, 0.10311102960258722, 0.07151280050831181, 0.16261630478714192, 0.12766749012683118, 0.09867873708052294, 0.12821623496711254, 0.12535128369927406, 0.0959644273721746, 0.15536037699452468, 0.10793640424630471, 0.1845621086124863, 0.09873178494828087, 0.09873788497809853, 0.10129474742071969, 0.12542708963155746, 0.18425899344895566, 0.1622752459453685, 0.09502731622861964, 0.0968169251989041, 0.13794284446963243, 0.17687223053404263, 0.14028516092470714, 0.1836682880031211, 0.09841376237039055, 0.14885752807770455, 0.17648500416960033, 0.21327623139534677, 0.2202743837343795, 0.054463542864790986, 0.1177473081541913, 0.17989864599491867, 0.09792642494929688, 0.1540629230439663, 0.11094716590430055, 0.11491913348436356, 0.09278324485889503, 0.13096336541431292, 0.17056345620325633, 0.08659769248749528, 0.14576396479138307, 0.09947792241083724, 0.31773346768958227, 0.12161160579749516, 0.11434190374399934, 0.07830716163984366, 0.1109377546235919, 0.21215037895100458, 0.13933537474700383, 0.14892299313630375, 0.10440377452011619, 0.11278622650674411, 0.08509926324976341, 0.10857253082628761, 0.166982039809227, 0.19409347644874028, 0.11889737072799887, 0.23135262142334664, 0.09059663861989975, 0.0884944082104734, 0.1718271869633879, 0.16049141809344292, 0.13429552875459194, 0.13632528483867645, 0.09139088421527829, 0.19982080055134638, 0.11032133948590074, 0.14981461529220852, 0.1013765244611672, 0.12411398866346904, 0.07333810042057719, 0.08977695474667208, 0.1437658012977668, 0.11164537165313959, 0.24156066509229795, 0.16262184163289412, 0.18997586811227457, 0.1359284639890705, 0.23949862431202615, 0.10958185845187732, 0.15769529741789612, 0.12815667316317558, 0.14674239871757372, 0.18150809034705162, 0.09164403884538583, 0.08657625756625618, 0.20012430926518782, 0.1969364160405738, 0.17970492424709456, 0.2044967482132571, 0.08832115107881171, 0.09688757426504578, 0.13641334511339664, 0.12940382052745136, 0.19704222679138184, 0.15569750033318996, 0.09153100848197937, 0.12047334973301206, 0.2223489774124963, 0.11279687950653688, 0.1252201907336712, 0.10517757585538284, 0.09123300947248936, 0.11993863699691636, 0.09021186855222497, 0.1557157936372927, 0.09722281127635922, 0.23003262653946877, 0.11710412481001445, 0.12482602974133832, 0.15977816922324045, 0.07917553718600955, 0.10213615798524447, 0.15924961758511408, 0.06127311675144093, 0.10507941897958517, 0.08133802829044205, 0.11696771212986537, 0.10497693305036851, 0.19626738051218645, 0.183760012366942, 0.15913057540144238, 0.08547638622777802, 0.14846057152109488, 0.09355035583887782, 0.12690287615571702, 0.1526842484516757, 0.13850330082433565, 0.12358095869421959], [0.007503498927690089, 0.04011681556169476, 0.03539015758516533, 0.026063849816897085, 0.037116147112101316, 0.014769832902987088, 0.013915752393326588, 0.04477065655269793, 0.06198217227522816, 0.04145388577931693, 0.05288677675915616, 0.01256491385200726, 0.0056305153910735884, 0.015893415647691915, 0.027951581736228297, 0.04963721827204738, 0.06418401841074228, 0.020715141469346623, 0.020285727190119878, 0.0221420768648386, 0.008995767067452627, 0.02780347620137036, 0.03494726760046823, 0.04583080645118441, 0.0269888100946056, 0.05653015018573829, 0.017384077355797802, 0.022629139479249716, 0.03966079253171172, 0.030307614776704992, 0.04594168585858174, 0.10014878319842474, 0.05857407408101218, 0.050826130368347676, 0.04704992692651493, 0.0370179563095527, 0.018718463967421224, 0.015244483415569578, 0.012374402422990118, 0.07385480483727795, 0.048844882752746344, 0.03760737932420202, 0.015092248995123165, 0.03139608333419476, 0.032514675453837426, 0.016209034515278678, 0.019755540282598565, 0.03198689395295722, 0.014061626396141946, 0.06972902693918773, 0.017183955326410275, 0.03832925237449152, 0.026983380118118863, 0.04165467107668519, 0.08454378734209708, 0.04292606249717729, 0.0044041108423178744, 0.052314452826976776, 0.017893260211816857, 0.011221352598762937, 0.006671913550235331, 0.05144399757097874, 0.03998648255531277, 0.020440745300480297, 0.014662712579593062, 0.033248521254530976, 0.020723009082887853, 0.031481361615338495, 0.08411998794014965, 0.049994433032614846, 0.014020208618603647, 0.07063131566558566, 0.02378479148527341, 0.0402603223254638, 0.06908529398164578, 0.03367309079372457, 0.003620103916286358, 0.06456694964851652, 0.05712970372821603, 0.013282774215830224, 0.01845233405141958, 0.015782149475333945, 0.049034580787909884, 0.029890576976218393, 0.038277120529008765, 0.06741118524223566, 0.040232475248298476, 0.10039902691330228, 0.05420414571251188, 0.05290977909628834, 0.01818882497692747, 0.048806511597441773, 0.022346733204488243, 0.03835104013394032, 0.041047005648059506, 0.012917884376033075, 0.037729926141245027, 0.022957253569204892, 0.06764306779950857, 0.007284270200346197, 0.007432907537025, 0.06632578705570527, 0.012185904546640813, 0.01312111918481865, 0.06933928320982627, 0.02631831741226571, 0.031181191293788806, 0.03921382115887744, 0.03621978199641619, 0.03902145308841552, 0.014053816458077302, 0.053938794415444136, 0.07211994007229805, 0.0292886892732765, 0.045270407771957774, 0.046192580967077186, 0.03080094026933823, 0.05254736336480294, 0.03987462605748858, 0.020852577041036317, 0.031880730363939486, 0.0031809605051031603, 0.014564072247594595, 0.021648842974432876, 0.01590734427528722, 0.01129277519482587, 0.03714300013546433, 0.027442015507923703, 0.014808546718476074, 0.026025870515565788, 0.013576612957487149, 0.08727062959223986, 0.04538095808987107, 0.06470123172870704, 0.05133965924116118, 0.040188848839274476, 0.03416089640398111, 0.046054030901619365, 0.05763508339545556, 0.025448722199403813, 0.02866184844502381, 0.055752006226352284, 0.03510251302005989, 0.006697772095711636, 0.06770372204482555, 0.032132083483572514, 0.04255902933488999, 0.027207907355789627, 0.04990875441581011, 0.04978762573695608, 0.011398299264588525, 0.04342585442853825, 0.0207621690351516, 0.018207661109045148, 0.029088952312512056, 0.029144487011113336, 0.03298573821250882, 0.022117897269449065, 0.002064703182051224, 0.02226689168518143, 0.03292578285826104, 0.005049291199871472, 0.05054114566051534, 0.023772511697773422, 0.038481576700827906, 0.03745320598993983, 0.03204647611294474, 0.04860171276543822, 0.016845354477741888, 0.04439310609762158, 0.04992662363552621, 0.04468530363270214, 0.019764390075579286, 0.015438973604302322, 0.023615469856719886, 0.0526855436286756, 0.04313916659780911, 0.030256365026746477, 0.06152190161602838, 0.011488249259335654, 0.04231370160622256, 0.02647339489444026, 0.05407411465421319, 0.014406116080603429, 0.08430102108312504, 0.05451336769121034, 0.03090985192518149, 0.03073235394965325, 0.062060115592820306, 0.05981305866901364, 0.03749701560341886, 0.026945083601666347, 0.05446145297693355, 0.018153658203248466, 0.023209704219230583, 0.037532241748911996, 0.0014318240282591432, 0.023342968496893133, 0.08615097217261791, 0.0847017163676875, 0.016813190221520405, 0.03823229650567685, 0.010248858398491783, 0.050480640692902465, 0.01222771841899625, 0.012581900976199125, 0.047997819991516213, 0.07425426518810646, 0.008757977862842381, 0.06016559832330261, 0.005827540756269757, 0.02218710444867611, 0.029937039661620344, 0.05268308733190809, 0.02195137459784746, 0.04200567724183202, 0.04904366297913449, 0.008832890673407486, 0.034078834378825765, 0.021750646975955794, 0.03809932399807232, 0.03266161221212574, 0.021508515147226195, 0.013767481465557856, 0.01868067804857024, 0.04063934859420572, 0.028704599543873752, 0.0450004017246621, 0.032772600185126066, 0.012401080723585827, 0.0038233052224053866, 0.042292232758232524, 0.023029149443443333, 0.04719145576070462, 0.016373572471950735, 0.03426752478948661, 0.024200964153611233, 0.03283630783802696, 0.09863451695335762, 0.029467021846877675, 0.027249494767082588, 0.036873676015862396, 0.008161920472048223, 0.0062912893315245, 0.032481525625501356, 0.03429743800578373, 0.010460444277019372, 0.05708213842340878, 0.047621412867946286, 0.004194767946111304, 0.0669799219550831, 0.019181608222424984, 0.05277066584676504, 0.05570281922285046, 0.04057377836267863, 0.040089229720511606, 0.05273798760026693, 0.007141868600488773, 0.039918727441025634, 0.01215834669502718, 0.10993053045656, 0.024044290417805314, 0.0203726933271225, 0.020142736112965003, 0.07825779143188681, 0.026632224675267935, 0.015327861798661096, 0.053878740673618655, 0.03189366663407002, 0.053724024511341534, 0.06992621600095715, 0.011505505253028656, 0.018858403333329728, 0.03711971281362431, 0.08387377472328288, 0.08923874076988016, 0.018037438725254366, 0.045780503257576904, 0.027255074021273425, 0.04947388132235833, 0.04375820766602244, 0.05043192866391369, 0.029594688210636377, 0.028738862169640403, 0.04427996038326195, 0.025212379970720837, 0.07555384295327322, 0.014429922481732709, 0.019428761210292578, 0.02463428000919521, 0.06066470154161964, 0.0314928559985544, 0.08021328864353043, 0.03373939045039671, 0.035908490485910854, 0.011450851801782846, 0.06219741715384381, 0.01345606697058039, 0.007398005392003272, 0.034460605321718116, 0.026920971859778677, 0.03196196457637208, 0.02411577577835747, 0.02276708564854094, 0.035391606257430146, 0.04222398231338177, 0.036364119965583086, 0.017145920045939938, 0.05427476085190262, 0.04689582823110478, 0.011979547628600682, 0.08244589277143989, 0.015629908269537345, 0.020563448180577586, 0.043530189365680726, 0.03931694491101163, 0.04797164550317185, 0.03130647599963205, 0.05423198939700212, 0.015393540595791169, 0.060110182368329594, 0.0012190432919721517, 0.06675130993660007, 0.013969393131057066, 0.007805318089335093, 0.04468448939067977, 0.04814339967976723, 0.04843716123806579, 0.047870197732533724, 0.042564074242753644, 0.020915894536301494, 0.05284485686570406, 0.04954246085669313, 0.013761557854845055, 0.02356762295987989, 0.020349326277417795, 0.04696343746036291, 0.04236292253647532, 0.0171888136371438, 0.024224198888987303, 0.03255179471203259, 0.08100245201161929, 0.05001376788797123, 0.02267557502325092, 0.08340926322021655, 0.01635321133237864, 0.04999891136373792, 0.045047970422144444, 0.010386486504493015, 0.00474542286247015, 0.06004716003579753, 0.0017729652484246928, 0.15103128286344664, 0.11178741617394344, 0.17558253902409757, 0.13995874486863613, 0.09477332700043917, 0.11106027090655905, 0.1488661454724414, 0.11987090563135487, 0.20345427415200643, 0.18485045885401113, 0.16088308207690716, 0.10567541021321501, 0.15752963987844332, 0.09953409832503114, 0.09544671872364623, 0.10694930542792593, 0.14601369281964643, 0.10838160464274031, 0.1198006094034229, 0.10651000150080238, 0.06578154768794775, 0.0781500129295247, 0.2389209195971489, 0.12484342737921647, 0.1202960078205381, 0.18065145345670836, 0.06876280664333276, 0.09644841283027615, 0.13671917441700185, 0.2033779796745096, 0.12962990839566502, 0.23925318462508066, 0.09760345585112061, 0.1006165991670319, 0.1256036308727094, 0.11954157187470368, 0.09021157678216696, 0.1117909038439393, 0.09196730649897031, 0.18683985567518643, 0.12350372783839703, 0.11615793486790997, 0.14153644735259668, 0.13427224143275193, 0.07848885296178715, 0.12679447340113775, 0.045724157709628344, 0.10605633298733405, 0.08650836335229022, 0.15031432919204235, 0.12096258705215794, 0.14345119175102028, 0.1127943146441664, 0.16652928053268365, 0.1329504552164248, 0.14822818684790814, 0.09599407935248953, 0.1091297369982515, 0.046175838115492036, 0.08373061740504843, 0.07722648605704308, 0.08128280911062445, 0.14728112838097981, 0.12717652932873794, 0.1459941781525101, 0.17258758044668607, 0.08988089274082865, 0.10640636206205402, 0.16627008015555994, 0.07999239835355963, 0.0653817548549601, 0.09915646644575254, 0.12343500581170831, 0.17342905886471272, 0.13662415237299033, 0.07798979724092142, 0.12341737747192383, 0.19097241892346314, 0.18618143243449076, 0.060255429574421475, 0.15794079138764314, 0.12595040297933988, 0.19973974275801862, 0.16912227496504784, 0.2528838946350983, 0.12062961634780679, 0.08043780231050082, 0.16380137976791176, 0.18627812367464813, 0.11460172837334019, 0.11840286797710828, 0.14036066830158234, 0.0995861283902611, 0.24129364799175942, 0.14149711946291582, 0.07792005062635456, 0.21789759770035744, 0.18917675742081233, 0.11474047521395342, 0.17384994056607994, 0.11637205337839467, 0.23431008415562765, 0.0899093776409115, 0.12577126973441669, 0.14506121964326926, 0.13409764080175332, 0.13297508603760175, 0.17323273154241697, 0.10187999744500432, 0.09650771679090601, 0.13401673228612968, 0.10567066725343466, 0.14028531020241125, 0.11210602229194981, 0.13423868109072956, 0.20013950844960554, 0.18618755282035895, 0.1409827492066792, 0.13814975693821907, 0.12184033995228154, 0.0947897746892912, 0.12284660738493715, 0.061709550475435596, 0.1266232111624309, 0.07629605169807162, 0.16054671869746276, 0.1652533904250179, 0.09996605371790272, 0.12119551455335957, 0.10895198796476636, 0.11434429218726498, 0.18120173178613186, 0.1968685489680086, 0.1132116543927363, 0.099719223034169, 0.11504141906542437, 0.0680871486131634, 0.13950187366987976, 0.17563568188675813, 0.15623538861317293, 0.1344241247113262, 0.16198906701590332, 0.11455742003662245, 0.09292323341859238, 0.24553177771823748, 0.15295883800302232, 0.11036369364176478, 0.0910601866032396, 0.14780893363058567, 0.1596513238868543, 0.13689815838422092, 0.10463447642645665, 0.15465712973049708, 0.13010231804634842, 0.10017868623669658, 0.11849242102886949, 0.13848911944244588, 0.12117606773972511, 0.17202286289206573, 0.16518454626202583, 0.17370605043002538, 0.08019023880894695, 0.10767747528318848, 0.10748387567166771, 0.13574000767299108, 0.22769705472247942, 0.12686536673988613, 0.1273237442863839, 0.14415887663406984, 0.11432407184370927, 0.10446780108447586, 0.12542065711958067, 0.1213085584874664, 0.08234449249825307, 0.14167481421359948, 0.08974549786320754], [0.037289886003626246, 0.03144612529182008, 0.013315214126903032, 0.021464647858270576, 0.011049372809273856, 0.03786119891862784, 0.020017439532758932, 0.06483062835676329, 0.015557316896904792, 0.05274950573220849, 0.022029909937243377, 0.057033813159380636, 0.05071400245651603, 0.018170155085889355, 0.014932291149826986, 0.05967703953917537, 0.014971527437280332, 0.026062955847010016, 0.03662906414163964, 0.028814919159880707, 0.013999090912485761, 0.04051139385306409, 0.07333250929202352, 0.04335938513811145, 0.0854085734380143, 0.03497334370123489, 0.028414810808109384, 0.0364971535413393, 0.009559303971140512, 0.021774563639025604, 0.02691120095551014, 0.04908168808157955, 0.03603339521214366, 0.048516549835247655, 0.029746228829026222, 0.01028605823272041, 0.02048547941792224, 0.031272902086909325, 0.023531820059620907, 0.048413863738200495, 0.026300982538876787, 0.05205930330391441, 0.014914710307493806, 0.04396055359393358, 0.009059255892810012, 0.02009173233195075, 0.005312872368709317, 0.011322070944256015, 0.05072320678404399, 0.049773006699979305, 0.032124958865876706, 0.010174791212193668, 0.07372131664305925, 0.01597876687135015, 0.05667175705145512, 0.06824534905276128, 0.04375232816008585, 0.01922557220262076, 0.0397804827163262, 0.05771690793335438, 0.057842918671667576, 0.006984457806018847, 0.030829204645540034, 0.01753955856630845, 0.05197045253589749, 0.05660652269476226, 0.00799271249811032, 0.0379334120079875, 0.01810849321606968, 0.07986408059618302, 0.003268195511606921, 0.01453636257377054, 0.06761728346879993, 0.05227031412401369, 0.008871738499562656, 0.03530458753396358, 0.05182388557919434, 0.04453681981457131, 0.05774770663785083, 0.04924661619588733, 0.02095318173191377, 0.024304031926606382, 0.019858029604490315, 0.05095336925504463, 0.08537738118320704, 0.060278791535113535, 0.019439843383484652, 0.04008231205599649, 0.04501187235915235, 0.03318322922236153, 0.029264876086797034, 0.019404764819358076, 0.03456677230341094, 0.029784586413630416, 0.04897796043327876, 0.012341397631514286, 0.010947696033066936, 0.006113691696165395, 0.007702009436408324, 0.04579967526452882, 0.05423535153801952, 0.02123180347760873, 0.012665128385248994, 0.065465038243149, 0.017290444612236958, 0.023163585890350596, 0.05577582959085703, 0.023490878952933208, 0.017945346256185855, 0.07419606723955699, 0.01933026167431048, 0.020787659899464676, 0.030929444623844962, 0.011081651568279734, 0.004616259904910943, 0.0377178889300142, 0.03686496362622295, 0.05020510119252971, 0.05649878490450127, 0.02551963589420276, 0.027101920185876743, 0.08680806548467704, 0.038207845496279855, 0.03234740639371531, 0.07801022114498274, 0.056246451301766295, 0.038994427038622756, 0.02509763969906739, 0.04560360239286508, 0.03365933349622147, 0.004283625923562795, 0.04870625465576138, 0.09288057392196995, 0.0022073842535194543, 0.04739865999934929, 0.01838684524409473, 0.0325038935323911, 0.005497933041104781, 0.023889075532289486, 0.013659038847046239, 0.012070348336627441, 0.03674928358356867, 0.05586634955501982, 0.10633557728890862, 0.03054872201755643, 0.03370200656354427, 0.04053977358021906, 0.09471445051687104, 0.07727567306054489, 0.04579500015825033, 0.00739238881838641, 0.03348947921767831, 0.019426829081826975, 0.054730125702917576, 0.04081563877740076, 0.02948275368128504, 0.05121454416907259, 0.03562031666349087, 0.03374042182362505, 0.04660580200808389, 0.03986533012773309, 0.07906462385186128, 0.03510792772950871, 0.0003462542730890813, 0.01578937078426991, 0.022645354769857864, 0.030957502046866075, 0.04143569425546697, 0.03880764331136431, 0.07061498332768679, 0.0432670908048749, 0.030224287283739874, 0.031196234415152242, 0.04861192811014397, 0.0431948980715658, 0.05234356876462698, 0.04848509295178311, 0.0060240440735859525, 0.025798435755340115, 0.038079096869166405, 0.034197686572692225, 0.029233789004917656, 0.05758389471364873, 0.010053031495772302, 0.022147009814424173, 0.057121303464685164, 0.021898319944739342, 0.060493127176804204, 0.0321223532914051, 0.02613298574994717, 0.006507078734492617, 0.04350086986752493, 0.023318563288609897, 0.04795507228534136, 0.019920054490544965, 0.04486046405509114, 0.031065460361008133, 0.04797877012086766, 0.05656124744564295, 0.024050912919587324, 0.020582587957116108, 0.01633542014418968, 0.02732674258628062, 0.04156182373740843, 0.04435211240446993, 0.00841026344070477, 0.011780607946483153, 0.01297252595291606, 0.04286718262093408, 0.022517552699095437, 0.016456341869863014, 0.03728761969666396, 0.050260428937950304, 0.04059314375211086, 0.02835195810933198, 0.032140096982142756, 0.008723354765347071, 0.00647908534821389, 0.041864932115588865, 0.03169998559834702, 0.01968387171759137, 0.009654654256467308, 0.024938387530190603, 0.02720090657073472, 0.09268657397478819, 0.023841298185288906, 0.05525871805314507, 0.02409765719702201, 0.013627067973305072, 0.04224092872547252, 0.06263882453952517, 0.04916629461305482, 0.020717708028054664, 0.029915092446442162, 0.028504184048090662, 0.01845370469215725, 0.017951899208128452, 0.015298537211492658, 0.029301978381616727, 0.07276615646800824, 0.004861399764195085, 0.11203046063227312, 0.033446029227759154, 0.05094757117331028, 0.03336440485769084, 0.02758431787203465, 0.04844240631375994, 0.030959910846182277, 0.04217410320416093, 0.05034942559099623, 0.024277336662635207, 0.015675037633627653, 0.016609929967671633, 0.003961601685399988, 0.017605442620281662, 0.09248131713164703, 0.028743951182280267, 0.0662494111540062, 0.02817579684779048, 0.0388190460923527, 0.06622107553162745, 0.02741935583097594, 0.037519851699471474, 0.0616084894697581, 0.0031678049833447275, 0.025748051137530377, 0.010282001441477664, 0.05441976039271269, 0.03692020655476621, 0.023283752745815685, 0.029120700966034616, 0.03243030301694359, 0.025705057462411265, 0.034402159707886834, 0.002852739333840353, 0.027481504549671496, 0.027567875272195255, 0.05845028215220996, 0.018691524430843334, 0.05105274070852569, 0.034484730634306154, 0.00945260773213314, 0.025612042185717394, 0.08963761758059263, 0.016078338492661715, 0.05882157651441438, 0.036421680091215033, 0.021220909597884332, 0.010965855326503515, 0.0313105675657945, 0.020605693770838634, 0.010163845594174095, 0.021653606290263788, 0.06741395366511174, 0.0279225132960294, 0.04044785922659295, 0.024652571616960422, 0.10186366510710546, 0.04039616503619722, 0.05463767530662673, 0.04572444608701127, 0.015841952159202526, 0.03706454113125801, 0.06179573120815413, 0.0486548861621746, 0.04599877440237573, 0.03944893015016403, 0.0539952417436455, 0.05881592431770904, 0.015912838712600724, 0.05546109790780714, 0.013199657068720885, 0.029081047379544804, 0.02611263478840036, 0.03719122361923967, 0.0161319631151855, 0.03814433461853436, 0.0312407361343503, 0.022993076825514436, 0.017311994884429232, 0.07993764736290489, 0.011852731978121613, 0.025258058948176246, 0.0634224239204611, 0.09764662424900702, 0.10650253083024706, 0.0417593384959868, 0.02000487136787602, 0.08521994748818022, 0.018219138528885584, 0.022185706666537693, 0.03396120694066797, 0.010294402517112238, 0.03420010215735861, 0.02600485798237579, 0.06609506479331426, 0.010520716846388365, 0.018729211962116615, 0.029387711281222955, 0.015324072180581945, 0.02074374002404511, 0.017948535370773504, 0.023092563629948666, 0.022069285324375545, 0.012006398107457374, 0.04776035987639001, 0.012923720625362225, 0.01877667548667107, 0.016892249729218226, 0.0877007461552109, 0.028793406207114458, 0.017857089206310253, 0.17702680081129074, 0.11554523131677083, 0.10141411530120031, 0.16210192096020493, 0.11257693238024201, 0.1771863108234746, 0.22454508314175264, 0.17714511017714227, 0.07830119731702975, 0.15327381395867892, 0.11253211514226028, 0.12304357253015041, 0.12419956550002098, 0.20856457922075475, 0.16154865707669938, 0.19240549845354898, 0.08065620237695319, 0.1427551776702915, 0.13124708804701055, 0.18827064175690922, 0.11920805834233761, 0.20641833224466868, 0.15239716028528555, 0.09540472419134208, 0.11215107023183789, 0.14045146985777787, 0.09742149311516966, 0.1037255244861756, 0.161311699077487, 0.177846688245024, 0.13517070322164468, 0.11512075337980475, 0.07789853428091321, 0.12051209408257689, 0.0811087309515902, 0.09595751988568477, 0.11253888692174639, 0.11378842272928782, 0.090417885354587, 0.1292476217661585, 0.09395974315702915, 0.10778709940080132, 0.06155605228351695, 0.1476995266441788, 0.108778669764953, 0.12585002050868102, 0.16205966179924353, 0.13444665207394532, 0.19528601531471523, 0.1590368425739663, 0.1530039334403617, 0.08273707928934268, 0.2597389710800988, 0.1662669996065753, 0.11424845590123109, 0.22770175018480845, 0.15407433600297996, 0.08569633335407291, 0.14005995515201772, 0.1032819322177342, 0.12111362894730908, 0.2008816764823028, 0.07504587806761265, 0.13041205571166106, 0.1631128295723881, 0.17721278725990228, 0.09916332643479109, 0.10757292660751513, 0.11901064536401204, 0.13904587099594728, 0.15153069820787224, 0.06622089232717242, 0.14032777292387827, 0.08077111906771149, 0.1624611916818789, 0.1714969982526132, 0.10822326171078853, 0.11981732850628239, 0.18726345151662827, 0.1920700850231307, 0.06311035888003451, 0.23964537786585943, 0.17584028733628138, 0.14874611262764248, 0.1551711064364229, 0.14577549988670008, 0.11252076325139829, 0.13894498640937464, 0.12851716524788312, 0.1623132846185139, 0.12007426257644381, 0.1281218643167189, 0.10288313004587378, 0.12322875830743994, 0.1297839494155986, 0.09112788404205016, 0.08167816432459013, 0.09084719446088586, 0.13172759940581663, 0.10613322457564728, 0.1236768356923546, 0.1530084524835859, 0.07504903325544936, 0.21740347492907727, 0.18464274571410247, 0.1629350126854011, 0.1315376367419958, 0.13587139919400215, 0.06391252297908068, 0.21781340507524355, 0.13162723050585814, 0.10892418159970216, 0.21804507050131047, 0.10395858090903078, 0.16663373421345437, 0.14297240387116159, 0.10696927471352474, 0.14197126616324696, 0.12379685496645314, 0.10977882359709058, 0.10206162091344595, 0.22667119119848522, 0.11713807870234762, 0.1137217159516045, 0.19380722966577324, 0.1678578249577965, 0.12272337185485022, 0.10697690144713436, 0.12367868130760533, 0.1342162215816123, 0.07130246143788099, 0.10789933587823596, 0.16870648227632046, 0.12097085160868508, 0.15578009161565984, 0.09010952511536223, 0.179928311545934, 0.12303500941821507, 0.1138017423717039, 0.06785550354314701, 0.14061019276934011, 0.126841238034623, 0.13128575097237313, 0.16493556462228298, 0.16276755024279865, 0.1525171117058822, 0.07986686258975949, 0.2943325862288475, 0.1571083374853645, 0.22858832404017448, 0.10401046848190681, 0.17191878919090542, 0.17550439893135003, 0.17108818090387753, 0.10796055330761842, 0.1589835775750024, 0.1281453687697649, 0.18107677277709755, 0.08870413659938745, 0.17092355473765306, 0.11583872485373702, 0.1158750264772347, 0.11049140750297479, 0.09483995913927044, 0.14073033417974198, 0.0927183497697115, 0.08887332252093724, 0.14461245015263557, 0.15051258355379105, 0.20866513811051846, 0.12542387337556907, 0.14258627673344954, 0.08458819067371742, 0.16104457341134548, 0.122022648741092, 0.10621931031346321], [0.01911662662002657, 0.041420817375183105, 0.0033457616061371353, 0.03929388489840286, 0.014697713112192494, 0.017624302501124994, 0.023558764685211436, 0.012155715675492371, 0.02543343650177121, 0.014691981187622462, 0.014158755291386374, 0.04436317591794899, 0.0636787133823548, 0.016492545105783, 0.07572607549705676, 0.07755438810480492, 0.02755290678968387, 0.014084984115990145, 0.046551407248313935, 0.026957957107307653, 0.05940753900046859, 0.047756627933787446, 0.020540242282939807, 0.02979648791785751, 0.022132350065346276, 0.04445347196555563, 0.008666135603561997, 0.014472235925495625, 0.05846545419522694, 0.04889025978211846, 0.0374340916584645, 0.07233403822673218, 0.057544532897216935, 0.04220552955354963, 0.015139702341652342, 0.07139840628951788, 0.043625089273388894, 0.008930228218170149, 0.05088746314868331, 0.031964451407215426, 0.01787936720731003, 0.0550855525237109, 0.01961127695228372, 0.026752617143626724, 0.04998695896938443, 0.018664413564173237, 0.04702163201623729, 0.0355494674295187, 0.012337927773062671, 0.068572918618364, 0.04008740785398653, 0.02115368882992438, 0.04106098007676857, 0.03915507359696286, 0.037167810768421204, 0.009288487922666329, 0.051247554897729836, 0.021929239089201604, 0.049731527854289324, 0.08077865080641848, 0.029695698326187472, 0.02123549810078527, 0.022753905105803694, 0.029930067714303732, 0.02173022646456957, 0.07186354204480137, 0.009783902454988232, 0.030769327322819402, 0.013107899626317834, 0.02182018494100443, 0.05507933375026498, 0.07227156550756522, 0.05367129894771746, 0.031905367970466614, 0.04007853600861771, 0.027992161523018564, 0.04916443203442863, 0.04585619044623204, 0.03895041047196303, 0.05437840707600117, 0.003890183330180922, 0.061370323678212504, 0.0363243510281401, 0.04449916112103632, 0.01355725180889879, 0.020940459200314114, 0.008097027079202235, 0.03301219768556101, 0.05969588245664324, 0.011379819363355637, 0.0437191172635981, 0.03979169211483427, 0.010035888308526149, 0.056616856783096275, 0.044297011968280585, 0.04659693355539015, 0.026202209892549684, 0.013945903945049005, 0.05412656880382981, 0.03162805749369519, 0.03541644063911267, 0.03791958007163235, 0.01713292270765773, 0.03760159481316805, 0.046121266936617236, 0.022787333133497407, 0.05566223943606019, 0.04102510932300772, 0.018795837315597703, 0.02538812902223851, 0.03274825095598187, 0.05231758765876293, 0.01241793214077396, 0.013493375370412, 0.004311955184675753, 0.034198789192097526, 0.016664248392251984, 0.0910576828090208, 0.052063472901604006, 0.030026993049042563, 0.034085029403546026, 0.005858318680631263, 0.047622440848499537, 0.08332082296588592, 0.051839447779847045, 0.06763033169720854, 0.024843504585857903, 0.025219765824398825, 0.008190373141717697, 0.025172755221969316, 0.044421496002801826, 0.017694558016955853, 0.05573712256071823, 0.03385334022875343, 0.015076035400852561, 0.02245543451447572, 0.05198385699519089, 0.04588655488831656, 0.048263941425830126, 0.03914948586108429, 0.010163123802548009, 0.011127066765246647, 0.060330706249390326, 0.006440651428420097, 0.04905670102951782, 0.057981394098273346, 0.03209570722122278, 0.016238235269806216, 0.0762817549652287, 0.07349075044372252, 0.025775153522512743, 0.03972815748836313, 0.06230814728353705, 0.04195376931290541, 0.011139190489692348, 0.07666423158454043, 0.04826313057648284, 0.0036824727347785874, 0.015143108587445957, 0.03315437112801841, 0.05189767626247235, 0.028439606174028347, 0.0306006469098585, 0.06704567878374032, 0.01866669683451099, 0.021402054699137807, 0.024174796450617056, 0.04914190127913441, 0.03624845349362918, 0.007280886855109462, 0.034579410018133264, 0.02048691112681159, 0.024717843293079307, 0.01738976687192917, 0.0651659807190299, 0.029163886327296495, 0.06920591715191092, 0.042978648961122544, 0.025392512358458977, 0.021230130888787762, 0.033841116420392475, 0.013966240487726671, 0.021670276199334433, 0.025091576988675764, 0.06298393423535995, 0.037205116623746495, 0.05848719445722444, 0.04300962408472385, 0.01571725438615041, 0.026201000403878943, 0.01759725439894412, 0.06490954876478229, 0.005446707888040692, 0.03624984109774232, 0.030201793847871677, 0.025415477376165133, 0.052230467155043564, 0.030588219540991952, 0.03151266922109893, 0.03612675823803459, 0.01900701268043901, 0.019906902785546014, 0.042723797993468385, 0.05251213043395962, 0.029532989021390676, 0.023531545252938355, 0.040125426171081405, 0.035744373220950365, 0.04899153791900192, 0.04550835982497249, 0.0480842789235924, 0.04684941304315414, 0.050029543827154806, 0.032243828023118634, 0.033105669277054925, 0.03824427943410618, 0.02063074358738959, 0.06834009968276535, 0.04557674936950207, 0.005613496460552726, 0.02405034125383411, 0.013897025674980665, 0.028738624682383876, 0.08559840039483138, 0.028597122989594936, 0.043695867261184115, 0.028936912970883504, 0.035378205190811834, 0.025176631353263344, 0.020593452999102216, 0.07289075585348265, 0.006351209910852569, 0.03706560643123729, 0.016238038494650806, 0.03606594114431313, 0.06137070365782295, 0.04491783419091787, 0.05970454734883138, 0.06253615540585347, 0.06160178554377385, 0.05199049646034837, 0.04283265197383506, 0.033791132138243744, 0.007624826926205839, 0.06711034317101751, 0.01616383220867387, 0.034488272587103505, 0.034502789843827486, 0.00960429253921445, 0.004694217641372234, 0.025612208426796963, 0.02474822978755193, 0.06927651872060128, 0.029354958395872797, 0.03571119964388864, 0.027584826773298637, 0.06597085895815066, 0.016783078533730338, 0.029065875336527824, 0.013795663569388645, 0.01531852685314204, 0.04350213533533471, 0.033555850120527406, 0.03558066986235125, 0.01508807939743357, 0.03524149734792965, 0.04159887514210173, 0.02323797538078257, 0.027286617417952845, 0.022540331119671464, 0.00894839090428182, 0.044287363200315406, 0.030214204253362756, 0.019191843923181295, 0.04376402271113225, 0.016663556286532964, 0.08139248751103878, 0.018770102178677917, 0.04459741638441171, 0.003437561456978853, 0.05565019204680409, 0.022693766547100883, 0.07745740509458951, 0.046252064739487, 0.05478376728881683, 0.02709713312132018, 0.04058415316311376, 0.06999105680733919, 0.03065062440665705, 0.04678153579256364, 0.05130573927557894, 0.004489155028880174, 0.026367555305893933, 0.029658802984548465, 0.004737746086902916, 0.024103908200881312, 0.042497323360294104, 0.023556657833978534, 0.07134195217596632, 0.012093104704815363, 0.08444325559373413, 0.03938435736511435, 0.014924111410177179, 0.014675296011513897, 0.0427711325963693, 0.0409434883456145, 0.0025233877656449166, 0.01916961681230792, 0.02989662272323455, 0.013120420293749442, 0.020136157715959207, 0.01808869865323816, 0.036367502462651045, 0.01878563384525478, 0.04866071817065988, 0.006290355497705085, 0.009916407621598669, 0.006556275067850947, 0.04209111837138023, 0.03856043264802013, 0.04575140428330217, 0.025444087805226445, 0.040595864677535634, 0.04836441549871649, 0.03629016982657569, 0.017031600465998054, 0.02075847441197506, 0.012157997249492576, 0.08363096775220973, 0.016541341951649104, 0.02416492546243327, 0.10426789788263184, 0.03768580100898232, 0.01140686237652387, 0.007653841083603246, 0.01922227452243013, 0.04288368119991251, 0.06227922133569207, 0.08723203452037913, 0.09540221361177308, 0.026660673952262317, 0.017645910448793854, 0.039886564881141694, 0.04147735969828708, 0.04350392666778394, 0.0456825601203101, 0.02505294799006411, 0.02884904607864363, 0.06956146950168268, 0.056064871938100884, 0.036877340104963095, 0.08371543857668128, 0.13842635495322092, 0.13107924562479767, 0.1503494908767087, 0.15032875484653882, 0.1103987739022289, 0.1437083293816873, 0.06560398185891764, 0.09611425468964235, 0.130045904644898, 0.13232750578650407, 0.13283582351037435, 0.0975222827068397, 0.13396871914821012, 0.11932876972215516, 0.09838557602571589, 0.16286534070968628, 0.1209593436547688, 0.11409931390413217, 0.06836804854018347, 0.19538160732814244, 0.16414281858929566, 0.1411900416548763, 0.1567188719553607, 0.17046159452625684, 0.09962476417422295, 0.13276165963283607, 0.10728535668126174, 0.11171304873589959, 0.13328001967498235, 0.09052056127360888, 0.12405358547610895, 0.12840361919786247, 0.23801189980336598, 0.12679140642285347, 0.11212838002081428, 0.07120921037026814, 0.0861609669934426, 0.10435829231781618, 0.09458841942250729, 0.10970594893608775, 0.12034035686935697, 0.12807812594941684, 0.12280928795891148, 0.0901109975363527, 0.15283343116087572, 0.08940111419984273, 0.13024634388940676, 0.16234185094279902, 0.09644094215972082, 0.14098718682570116, 0.11809041617172104, 0.16620902557458195, 0.20580912993422576, 0.09596155038369553, 0.27464141856346813, 0.05916184825556619, 0.16228906091834816, 0.11116574238985777, 0.1937603700373854, 0.15162221901118755, 0.13023490378899233, 0.1280561007027115, 0.10266460784311805, 0.10576045100710221, 0.07738523611000606, 0.10214507393538952, 0.08208641170391015, 0.11452292331627437, 0.16896049864590168, 0.15494001097977161, 0.10135530667113406, 0.10624050774744578, 0.1124551964125463, 0.10170989550117936, 0.07844687200018338, 0.07148333173245192, 0.1234659877206598, 0.10297005038176264, 0.14060032687016896, 0.10863086448184081, 0.11642226496977465, 0.14165760656552656, 0.15703341364860535, 0.09254974060292755, 0.14173003339341708, 0.16361373769385473, 0.26138436421751976, 0.13663340759064468, 0.11497110926679202, 0.17422109922128065, 0.15133792640907423, 0.11686747893691063, 0.0996176056297762, 0.10526608396321535, 0.16895798806633266, 0.1647133986864771, 0.1232027161334242, 0.07873750211937086, 0.161831796169281, 0.08850413840264082, 0.1567787051733051, 0.12080452910491399, 0.1114329087681004, 0.21773873908179148, 0.12878180747585638, 0.07750124524214438, 0.13983544148504734, 0.16928755252489022, 0.14825219341686793, 0.08796189392783813, 0.10366114508360624, 0.1009270560794643, 0.1159203661871808, 0.10536314161228282, 0.10670140265886273, 0.13125890812703542, 0.12935362250677176, 0.23937095116291726, 0.08657576223569256, 0.11561391263135842, 0.18974095928881848, 0.09099441620388202, 0.188898503780365, 0.15798442118934222, 0.1503378472157887, 0.17452239591096128, 0.13800332908119473, 0.06980511107082878, 0.12398547413093702, 0.14715390306498322, 0.19725116129432405, 0.10536211702440466, 0.15527834211077007, 0.10826911710734878, 0.07975832412817649, 0.11411363099302564, 0.07218071645391838, 0.16309894674590655, 0.11111103889665433, 0.11720779139016356, 0.12843097772981438, 0.09554094688168593, 0.126205070742539, 0.10436199033366782, 0.13323873760444777, 0.14926684754235403, 0.11916778050363064, 0.13673639563577517, 0.1318595337548426, 0.20663570772324288, 0.1756372968001025, 0.0926571934084807, 0.10030442556100232, 0.0899580828845501, 0.12223393097519875, 0.2892961193408285, 0.1412704616252865, 0.061134926309542995, 0.06896382264260735, 0.14213442669383117, 0.08948643319308758, 0.2531781888433865, 0.3392555671078818, 0.1357967196298497, 0.13659277691372804, 0.07761854359081813, 0.12838843358414515, 0.10567819899214165, 0.12735533687685216, 0.0598658894055656, 0.11114407676671233, 0.1618801485747099, 0.12155015766620636, 0.16051345691084862, 0.11533899738320283, 0.135949987119862]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.030824197057102407, 0.02037208603828081, 0.06367905943521432, 0.03175842781950321, 0.04222448103662048, 0.08283184349004712, 0.0420604044837611, 0.03882966177271945, 0.031640203270528994, 0.029964479617774487, 0.03165628794314606, 0.060889018433434625, 0.01419051073025912, 0.07352105381765536, 0.007489038498273918, 0.0014250216086760961, 0.019019099085458686, 0.03045180007549269, 0.05124577035063079, 0.047158862331083844, 0.0826314449576395, 0.06323438151074307, 0.038056908774056604, 0.03717375134250947, 0.09149294266743319, 0.030933037466768707, 0.04488022638750928, 0.022236505190708807, 0.04036573274061084, 0.0177085392310151, 0.007524851576558181, 0.025058176102382795, 0.13047376168625696, 0.025731751030044894, 0.0013763331163707854, 0.01943972463985639, 0.018219847597980073, 0.040002519730478525, 0.005839002909072275, 0.04916690190189651, 0.034658941107669046, 0.05275042514715876, 0.004433636445485587, 0.015427197629053677, 0.056265582596617084, 0.012327906659006007, 0.0343514188591923, 0.06560213624366693, 0.019121513768498386, 0.0340826816723815, 0.0464945460137512, 0.04672356854592051, 0.057385233230888844, 0.02784533502667078, 0.03772399913785713, 0.026438584351646047, 0.06748251962874617, 0.009504826938999551, 0.048036584697131596, 0.04148330705772553, 0.005942645740495729, 0.03604099141167743, 0.0248713177362723, 0.014808305838544453, 0.07780754952026264, 0.023747397420395697, 0.04373347167191761, 0.008821913673143302, 0.023848125943914056, 0.035691074295235534, 0.051758067682385445, 0.06113044797841992, 0.029802218146089996, 0.06826676361794982, 0.08658832191888775, 0.0397630647223975, 0.03143869533336588, 0.028450825750561695, 0.046796253217118125, 0.05742973155741181, 0.029784857827637876, 0.0672232039006693, 0.00954872476203101, 0.054600254100348265, 0.02256105188280344, 0.0742771386035851, 0.021954283816739917, 0.025313534274963394, 0.045780991802790334, 0.016861505307523266, 0.023864739873845662, 0.034101738328380246, 0.037926877715757916, 0.052565636312855143, 0.021338072239554355, 0.02725712998237993, 0.026258999880935465, 0.021952767290973237, 0.023311314838273183, 0.03160929260775447, 0.07758568213986498, 0.02749001677148044, 0.04300857914079513, 0.027942416424463903, 0.012278689969597118, 0.01781593945010432, 0.04047926861260619, 0.02319672384432384, 0.05083973499547158, 0.01618904826630439, 0.01160666040543999, 0.08762387492294822, 0.032772389839270284, 0.04211459907570055, 0.09141199343970843, 0.016752273043883697, 0.06850941452596869, 0.03146006579377821, 0.06860531188015427, 0.029267675043748956, 0.022569886408746243, 0.046582409513315985, 0.002242461545392871, 0.03190198886607375, 0.07233554457447358, 0.02220105003964688, 0.017636249806465845, 0.026125267414110045, 0.10008728078433446, 0.0076347954537985575, 0.13011149183980056, 0.018319687240624, 0.027628906104447584, 0.022328232947204794, 0.018673019084547247, 0.03564305776464088, 0.004547209212822574, 0.017764375877699683, 0.032977704357888014, 0.0686873264078583, 0.028584047619785582, 0.017165477121514932, 0.09600136003323964, 0.011718460924125143, 0.03809067267658455, 0.01795534786236073, 0.008490717337865914, 0.04466980589287622, 0.017319653848452226, 0.027083360556779162, 0.02744828347515847, 0.013036622067115136, 0.013839047402143478, 0.015279848660741533, 0.035878037834273915, 0.01078245324814426, 0.01442345095399235, 0.0139369328639337, 0.09614736041320221, 0.0780210844906313, 0.022980021811755638, 0.03207036733095135, 0.024365039010133063, 0.019007913435676267, 0.06627127355230705, 0.02800066356680223, 0.03906074705134545, 0.008675862403054322, 0.07141036886189665, 0.019893942766689827, 0.047641215912465534, 0.059522408193775585, 0.014184960313806576, 0.02896747418812343, 0.021917485166341066, 0.02335552648375077, 0.0392229779889541, 0.0059357255314742875, 0.07176114432513714, 0.013494042031067823, 0.022946714224027734, 0.03976193156891635, 0.06266047659197024, 0.030395739512251954, 0.005986946867778897, 0.02417408738152257, 0.13829788113279, 0.08087796797709805, 0.06848401696022068, 0.04579262528568506, 0.03341979027858802, 0.03368012380919286, 0.0248910240895514, 0.03075333425242986, 0.027146545737715702, 0.019686334799709063, 0.07287360248821122, 0.04116763899634991, 0.04716295389724629, 0.06074010713824204, 0.04056896076404622, 0.03493781900033355, 0.0410078507848084, 0.018416917916121225, 0.03802356217056513, 0.043197530787438154, 0.0067752730932884985, 0.035401383947048864, 0.06864417836602245, 0.06404626223125628, 0.07121207378804684, 0.03717066061549953, 0.024451085732185414, 0.019990072519119297, 0.09060716948338918, 0.031102226780993596, 0.019707143772393465, 0.05217344985742654, 0.01538475017462458, 0.039239435855831416, 0.025208344383697425, 0.028358658642641137, 0.034159485051142316, 0.04139849018039448, 0.014369524383385266, 0.05714968658451523, 0.020359911423708712, 0.0244600797138576, 0.06500702032021113, 0.028858033274965625, 0.006217791266473276, 0.021591506765357087, 0.019878314408872808, 0.009938409119578344, 0.02419665884891791, 0.021575618867895434, 0.04947482109335916, 0.010714147672323244, 0.0395473923667201, 0.06643864100000688, 0.037384823230760436, 0.022567584478695477, 0.057783635067088265, 0.009405477537906595, 0.05701275821775198, 0.07870234722005469, 0.05923198842044387, 0.0710074140557221, 0.018237725299383913, 0.036634312610008886, 0.0806972130334803, 0.018660813935899308, 0.03452209755778313, 0.01153696552916829, 0.04742029508841889, 0.11851733683475427, 0.008774923426764352, 0.04665837150865367, 0.04812183244419949, 0.030965542686837058, 0.040326343782778294, 0.01442541361653379, 0.02039396539995713, 0.055598979616271596, 0.13938973897269794, 0.023184997062864046, 0.03658082369448883, 0.03611871420538851, 0.034753841015377214, 0.036015726160258055, 0.057278092551444254, 0.04953230318746396, 0.01463303345787738, 0.041782228874840906, 0.0046591051504947245, 0.023865011287853122, 0.014969607183177556, 0.06618904189339705, 0.035335199641329904, 0.06580923870205879, 0.014741692359426191, 0.02759800392336079, 0.02934158107798014, 0.03584811783262661, 0.04326759631346379, 0.03716617549902626, 0.03298840146245701, 0.05800225905009678, 0.010503968057621802, 0.019014525759432997, 0.06294532559279885, 0.07778517143534762, 0.07368985297424452, 0.042883589597685, 0.03762965902153935, 0.05260902523462262, 0.03449762958501067, 0.025415275511997085, 0.015086880086788108, 0.056254827816571505, 0.044721245632639954, 0.020176586528707827, 0.08167343493551016, 0.015550736803561449, 0.030629501611526524, 0.029863978403487375, 0.017742993542924523, 0.06496869666235787, 0.07593407362167325, 0.006199388548598758, 0.02802441907780511, 0.014526678182716881, 0.018166411268923963, 0.0035114619781130125, 0.02490163468090551, 0.02639433877941753, 0.01257264321403844, 0.03540246621040361, 0.0581947797909379, 0.033539477070527415, 0.033070219215005636, 0.008010302670300007, 0.04162517515942454, 0.0331939365049558, 0.026006232015788555, 0.0431536295717316, 0.0449258476894881, 0.030521312595478127, 0.05304695852100849, 0.054758861660957336, 0.037627195939421654, 0.028801148291677237, 0.03990495318014707, 0.04722661405269589, 0.06740357886467661, 0.009920192998833954, 0.012314469969299222, 0.05226425141362207, 0.04799618132944618, 0.028894708092723573, 0.03993934133489217, 0.04477086350587862, 0.04413031627024923, 0.023024016326027255, 0.03477082135421889, 0.04002902330830693, 0.05722290729837758, 0.0281333392153361, 0.01913336438259908, 0.017305309618158, 0.05840365322572844, 0.028769939073494503, 0.12066438448216234, 0.1250926125794649, 0.17906286727104867, 0.11424236265676362, 0.1321690950010504, 0.1507096029818058, 0.11372279482228415, 0.168437321005123, 0.11619982761996132, 0.14650335083050386, 0.23883580416440964, 0.16490764969161578, 0.12907348253897258, 0.09505232702940702, 0.09194716079426662, 0.13503165782562324, 0.21546302762414726, 0.13604937892939362, 0.12242283512439046, 0.11718952522746154, 0.19274141399988107, 0.19862515399498598, 0.1571689849453313, 0.12015936443848269, 0.17356563439326628, 0.16479761845299176, 0.10476437517042671, 0.0569106861948967, 0.09719438065907784, 0.09585161413997412, 0.08898257344428982, 0.08024110857929502, 0.2857336476445198, 0.12562515400350094, 0.12214634567499161, 0.1568978423518794, 0.10044298919716052, 0.08696541097015142, 0.16497634457690374, 0.15386118101222174, 0.09553221413599593, 0.1293776969292334, 0.12637427023478917, 0.09665624132113797, 0.1447337179311684, 0.08964647924793617, 0.13824130488293512, 0.14977990144065448, 0.10655663721263409, 0.16851233983678476, 0.23671429657510348, 0.1181926035455295, 0.19392517262271472, 0.08683610255164759, 0.11815182359090873, 0.14441733062267303, 0.1354188841900655, 0.09584689832159451, 0.16509264547910008, 0.178335857710668, 0.12045285797544888, 0.1361979373863765, 0.13194962963461876, 0.12197250500321388, 0.19310414525015013, 0.10079831084502594, 0.17209337625120366, 0.08939701584833008, 0.14467260906738894, 0.14290722379727022, 0.15409125866634504, 0.1794812383928469, 0.13227418650473866, 0.13467337776507649, 0.16046454810670444, 0.13715834942247185, 0.14093652740120888, 0.10912570650024073, 0.14022140577435493, 0.21033369643347605, 0.10801716348422424, 0.20156481196837767, 0.1092932028695941, 0.18144581440304006, 0.15990345392908367, 0.15381706266530923, 0.07929945125111512, 0.14704172765570028, 0.2248272451439074, 0.1069671441135662, 0.06747890982244696, 0.169279722230775, 0.19024756710444177, 0.1372407235737358, 0.10172132203089339, 0.1237906531563827, 0.09559191164693662, 0.08209247780697686, 0.10615216927336794, 0.06548609997012786, 0.11742807099861757, 0.17785282220159257, 0.11294695109661136, 0.2499982751905918, 0.1047973180455821, 0.07418867120785372, 0.14052483306399413, 0.09255346576017992, 0.18256458294178757, 0.11299725768289395, 0.0992015754537923, 0.1330519233431135, 0.11900160727756363, 0.07817539013922215, 0.18855269519346102, 0.13652352562972478, 0.13526254972176893, 0.10631356561290366, 0.22163357080093452, 0.11585988157561847, 0.07866517028638295, 0.14604805383299077, 0.1292323682989393, 0.07120932572122131, 0.1746576957936798, 0.08504706355077879, 0.13387658766337804, 0.1184115396546466, 0.1904411395745618, 0.10874911277954068, 0.3204883470066956, 0.10834910960069724, 0.13026946836284228, 0.08278893293546778, 0.08201616297342948, 0.10907930827566556, 0.11063782178929873, 0.11220930889248848, 0.12394868396222591, 0.12214574856417519, 0.1519735101610422, 0.07100444885769061, 0.17671349405178002, 0.09789867965238434, 0.105222481302917, 0.0626264073486839, 0.09285786335489579, 0.1133910794077175, 0.1251474789210728, 0.11554426779704434, 0.1597256777541978, 0.09777859931013413, 0.08507263753563166, 0.11288038681128196, 0.14328383787402085, 0.084029546007514, 0.1907602274524314, 0.0965299659541675, 0.19964496498661383, 0.18580772248761995, 0.12195303104817867, 0.2940349807696683, 0.12989959892417702, 0.11226656367736203, 0.10931979465697493, 0.06337561857487474, 0.2053432342197214, 0.09562477988323995, 0.1440905345869916, 0.11711498137031283, 0.16886124254337379, 0.11053678792502199, 0.07135731420878853, 0.1115969717502594, 0.08528214200798954, 0.18868192897311278], [0.06572736666670867, 0.06858917631741081, 0.047044091525354555, 0.015380349875028645, 0.01801273156888783, 0.015481643278950026, 0.02863468668822731, 0.0098998878384009, 0.03538682937089886, 0.03550440931160535, 0.036534897051751614, 0.032083537695663314, 0.01214574629973088, 0.0038826846700560835, 0.015507727861404419, 0.04131754434534481, 0.031138453765639236, 0.0602403050288558, 0.010843895442251648, 0.01975889903094087, 0.056250339307423146, 0.015120857727846928, 0.049962609740240235, 0.03423257345067603, 0.03882432509479778, 0.027823755916740214, 0.03802936703764966, 0.01958706682281835, 0.020336227158882787, 0.0159600918912994, 0.025732388852962425, 0.09486158405031477, 0.03762900423524635, 0.025648126678009118, 0.03545131055372102, 0.03646263646494065, 0.022981285583227873, 0.05720304657838174, 0.019091229054278562, 0.014500973579872931, 0.035267329176089594, 0.09208898139851433, 0.030033188073762825, 0.04196591508973922, 0.06661474797874689, 0.08857085875102452, 0.006566927219474954, 0.029402937607041428, 0.024085701409993426, 0.016458362207881043, 0.02799334217395101, 0.024127997890380875, 0.015518869406410625, 0.02075211823518787, 0.03485872895855989, 0.01933492490622614, 0.04968582173543317, 0.044328937040908, 0.037062169651367834, 0.01578619015137, 0.0970528314688376, 0.06879285895930869, 0.025796281406655908, 0.023336775168510418, 0.04884227717827473, 0.026243310454966765, 0.07743954605289868, 0.05743031509752784, 0.016331918903493454, 0.03536840035979237, 0.057623419378484995, 0.013009294917407845, 0.02497665860157992, 0.03086212377196976, 0.022105753188952804, 0.06438846779721123, 0.09599924978933164, 0.004139055556152016, 0.029511130015764917, 0.046079082414507866, 0.06394231745174953, 0.028831176858927523, 0.020735090398894887, 0.03791672004652875, 0.08861824763672692, 0.031045687850564718, 0.013177599591602172, 0.01785235812089273, 0.05105102401492851, 0.0119325361780024, 0.016885547499571527, 0.03705225625474538, 0.026250229815819433, 0.019695866520383527, 0.022171684740377322, 0.023116521005119597, 0.05278603805761252, 0.02087040724498885, 0.02754831819662026, 0.055874424121741734, 0.1024744144773909, 0.026866090251132846, 0.05775717220136097, 0.021914845665118525, 0.01843263109081558, 0.012559368524567356, 0.0706548879721335, 0.026173540091674243, 0.06447038054466248, 0.06089921681476491, 0.01857406153742756, 0.036241525651088784, 0.006064148461778781, 0.04901662675131645, 0.10895880045635359, 0.0570152077291693, 0.03687407295884831, 0.025943464133888483, 0.023876030696555972, 0.015051187448469656, 0.10688588954508305, 0.079005923787398, 0.04337681331006544, 0.02174626533607287, 0.0537264027765819, 0.028592756616749933, 0.031304335221648216, 0.02332944529397147, 0.022964692009346824, 0.024998860267390097, 0.023181002187941755, 0.006774840951298496, 0.08195426022367817, 0.03401231419827257, 0.04592425090127757, 0.008213640107507152, 0.014968930344496454, 0.022641029109113982, 0.04476699924894741, 0.0365746625965195, 0.04447762102686933, 0.017464879002156, 0.05367635742628148, 0.04141148751867669, 0.011897839289823813, 0.1021992074591773, 0.049616031016090086, 0.061321218098912916, 0.01036563512336995, 0.04494361173627632, 0.03618887472631676, 0.071385493768113, 0.02779360521318657, 0.04093687602185777, 0.05220338682244931, 0.02318399622371154, 0.014614967463005866, 0.07038300577551126, 0.013634011082883393, 0.006905224423722497, 0.016740783749680434, 0.03524766523124916, 0.02710247488825449, 0.022647738124110868, 0.04070948536640831, 0.05535148396821959, 0.009596078024644936, 0.06522966801588025, 0.056581766344606876, 0.02363510666015957, 0.058293547348252366, 0.023678354785910675, 0.042905750551394055, 0.12394234644515173, 0.05374920155320849, 0.018490220054185817, 0.035899269195007424, 0.0232057534490845, 0.011917102899003242, 0.005989868809202952, 0.008868920882897717, 0.011607598480103272, 0.011349110564749156, 0.015725289937108755, 0.013837018582437719, 0.03992996398093445, 0.02397610613011888, 0.030589851417711804, 0.05997270438820124, 0.04069832007267645, 0.033148902135768106, 0.014803259234343256, 0.058915777531053336, 0.03306444488199694, 0.0443036310773875, 0.019918378509048904, 0.01916052953207067, 0.009630828347456242, 0.06549006261463676, 0.040579457700784714, 0.030686162678258758, 0.045056034810841084, 0.02778919303922781, 0.034979514977229495, 0.06270016410521098, 0.06134449185005256, 0.0511573572377009, 0.006938635488040745, 0.008057207251632852, 0.01893611764535308, 0.0598971155871238, 0.020847109745123556, 0.02115829777903855, 0.08364508128059761, 0.042851365969649384, 0.03621330877233829, 0.06774268352559634, 0.02134117653726467, 0.01911943745134132, 0.06783062166401319, 0.03629974056301372, 0.009953274973668158, 0.030682128787572895, 0.038293992302247455, 0.052022818475961685, 0.04522240481206349, 0.02696657789471958, 0.023036209600312368, 0.036418073677590916, 0.003132913016348279, 0.02315508384656693, 0.039356883482209275, 0.05539292210180845, 0.059073333362383504, 0.04824604845738836, 0.06774152323071446, 0.03653606752465878, 0.03523789432698062, 0.04696953070483037, 0.03286468077983175, 0.013810300417909665, 0.04680932180157729, 0.04909590678289533, 0.08428091609052249, 0.03508848770122443, 0.03176107071340084, 0.015637862396293452, 0.04152462984036122, 0.029327257203736475, 0.0327889494864004, 0.03590150157521878, 0.020628841992999827, 0.04174187978995698, 0.03208203474059701, 0.020376306526096802, 0.01921333821623453, 0.05716033958430801, 0.061638853911842616, 0.01791887660510838, 0.027492965006136467, 0.012208887375891209, 0.04541663885382669, 0.01807378784620336, 0.025270747553024973, 0.046318686700292995, 0.025350304087623954, 0.006470607901324651, 0.028604366350919008, 0.021353670063295534, 0.016602893559528247, 0.027004319708794355, 0.15486356722457068, 0.00657923669288201, 0.03326617334304111, 0.03562539549810546, 0.06116218984659229, 0.05162482376077345, 0.02171828255190381, 0.02192850796771901, 0.01316301363320755, 0.04524773113163454, 0.06056439370981284, 0.015140891474272524, 0.03551572049036622, 0.035654240021748204, 0.025503071158060005, 0.03369174711406231, 0.01629599556326866, 0.022835485371095792, 0.034800500475934575, 0.07550223357975483, 0.062172338499554565, 0.03756833641922899, 0.016021392441221645, 0.10242190943764788, 0.031743601829345734, 0.023922673193737864, 0.07151931444449083, 0.02225991464885218, 0.009706692803385002, 0.007473176045875464, 0.018274325478289808, 0.032882183590637784, 0.015249043170894896, 0.034176994647298536, 0.03747878676014287, 0.020818329682307582, 0.017445221842665757, 0.047814004854964356, 0.020967643009498715, 0.03878189630008169, 0.019019892971430506, 0.030440611033035175, 0.032059744865234406, 0.09556304676724331, 0.02472639622698937, 0.02213280468380877, 0.04746002670643585, 0.04104023386857339, 0.04985170319144215, 0.02956745181498783, 0.04040022606828383, 0.0047137149210487094, 0.008856560519364263, 0.031156977771648338, 0.018352674220555594, 0.07466175939355578, 0.07302229665219784, 0.03559415235317179, 0.03994651345003929, 0.020242874311017137, 0.07006612992180244, 0.05217224206509335, 0.027623158912839632, 0.06852801995618002, 0.022297083100836192, 0.09035068324634007, 0.03336144983768463, 0.010988400500666882, 0.05769983599228518, 0.021203352504276803, 0.043087360449135303, 0.041378982298608334, 0.0725970451853105, 0.03992936008476785, 0.019531367579475045, 0.04376594975058522, 0.02906122397897499, 0.02550128661096096, 0.024492260933454548, 0.021407052109550153, 0.06183608368571315, 0.15952042091105664, 0.17969287346516336, 0.09538797116173164, 0.05351404845714569, 0.05814208476138966, 0.11505630612373352, 0.0975537056635533, 0.10310558096638747, 0.13786334730684757, 0.11473738109426838, 0.13689460286072322, 0.082240208451237, 0.10159442919705595, 0.09346927090414933, 0.1713800730981997, 0.1555105232234512, 0.12158056960574218, 0.1758706449930157, 0.19028382801583835, 0.08358413526522261, 0.11721646306770188, 0.09024802768336875, 0.10671325666563851, 0.095234873305474, 0.1766768124486719, 0.06628043377505881, 0.13091084680386952, 0.09371855109930038, 0.11342708247580699, 0.10337789742542164, 0.17823052193437303, 0.12964531114058836, 0.07071053462901286, 0.23459173047116824, 0.18931912763842515, 0.1803062962634223, 0.10388719223971878, 0.1625840879444565, 0.10222092057977404, 0.10247103537299804, 0.14673493483236857, 0.13806833273598126, 0.1533282053257738, 0.12595747331423418, 0.22961475753358432, 0.16154852136969566, 0.0985336730788861, 0.10896021180919238, 0.1727562371109213, 0.1679848331425871, 0.23366026473896845, 0.11832529785377638, 0.10301915596106223, 0.08429766233478274, 0.07077270200742142, 0.11040783913007804, 0.191400710227234, 0.15558455139398575, 0.14388641768268176, 0.16966998843210085, 0.17458225627030644, 0.17030866630375385, 0.09819867355482918, 0.09223025238939694, 0.0993252723876919, 0.20133377079452786, 0.1136027348360845, 0.18542270814733847, 0.0919318123321448, 0.1285354042691844, 0.13347200437315873, 0.18211950468165533, 0.08545449668807642, 0.14412542485765048, 0.08996280548827988, 0.14296352863311768, 0.16643561555870942, 0.10247031612587826, 0.08472502404557807, 0.09478002414107323, 0.08219248708337545, 0.1119042124067034, 0.10813192411192826, 0.09661028414432492, 0.1730697067188365, 0.12342465136732374, 0.15317309222051076, 0.06943581838692937, 0.13217142916151456, 0.07020054092364651, 0.08668656700423785, 0.16002739513559, 0.1538972519338131, 0.12566266341933183, 0.1393359447164195, 0.11573328051183905, 0.124342234273042, 0.09211340187383549, 0.12169593412961278, 0.12074525228568486, 0.20124406846506254, 0.1408286810453449, 0.23542014030473574, 0.048496909639132876, 0.09765526199979441, 0.15702757824744495, 0.16788662198398793, 0.09523391657109771, 0.11741284467279911, 0.12130314377801758, 0.09630914351769856, 0.11706106497773103, 0.15688211391014711, 0.1611660040382828, 0.18438354533697876, 0.1340218891522714, 0.1668402124196291, 0.1275727530675275, 0.14160759853465216, 0.13844198840005056, 0.23377235872404917, 0.182784658989736, 0.11903790890106133, 0.11088782801691975, 0.1927330680191517, 0.11299965291150979, 0.11253720415490014, 0.08902180633906807, 0.10244024345385176, 0.14941653236746788, 0.11790573251034532, 0.15302784501441888, 0.13237918301352433, 0.07652967130499226, 0.1313282951180424, 0.0782300325642739, 0.11784619784780911, 0.07735581483159747, 0.20749743362622602, 0.07696146384945937, 0.05829858207809074, 0.1565949578902551, 0.12835466968161718, 0.11807413133127348, 0.13863142180655683, 0.1597783320716449, 0.07913585645811898, 0.11393741544868265, 0.07666850635515791, 0.1458978940333639, 0.11938169545360974, 0.12726506457797118, 0.051498724812907834, 0.11598570910947663, 0.08799924049526453, 0.12853701918252877, 0.10943589878401586, 0.08749750456107513, 0.1535005939326116, 0.19420126852180275, 0.18823334947228432, 0.09846043200897318, 0.0867778096081955, 0.15613278054765292, 0.11284447873809508, 0.22381069112036908, 0.08949984104505607, 0.184117356049163, 0.09886741731315851, 0.11709033697843552, 0.15310641936957836, 0.1455934625118971, 0.08646820086453642, 0.17303276727242128, 0.08985420595854521, 0.11467131892485277], [0.02338235066937549, 0.024204115948772857, 0.02065348468853959, 0.02580256972994123, 0.04070304946175643, 0.09073009967271771, 0.0204203112183937, 0.010946040407621434, 0.0401303998327681, 0.03872420386012111, 0.048298190480896404, 0.04757706381912742, 0.03558327882949795, 0.017548499961516688, 0.048906005187226195, 0.008089017821475863, 0.023916222022048066, 0.04594544154990997, 0.027068665184612786, 0.03068750278492059, 0.05104567715898156, 0.06722738367638417, 0.06486619037709065, 0.12763105279632977, 0.03158774572823729, 0.009476403107068368, 0.08492188062518835, 0.03298516145774296, 0.05967428468699966, 0.04999451445681708, 0.016370485137615885, 0.06715041744921889, 0.04222121049783059, 0.0047905997240117616, 0.05688376531803182, 0.04173219709524086, 0.03128592317391719, 0.03830624325200915, 0.08556372047002826, 0.04703856485762766, 0.04091454543439405, 0.014319864101707935, 0.0964769452278103, 0.006757944581165377, 0.02754804338993771, 0.013725425865102028, 0.027603676476116692, 0.0529906774338867, 0.017474359832704067, 0.0395632022326546, 0.03152849605040891, 0.03994964488915034, 0.023737036190660935, 0.008052729768678546, 0.00849286066035607, 0.05568848517058151, 0.05947856804622071, 0.05673307286841529, 0.018639160187116692, 0.021155405523521558, 0.012403587062310959, 0.019102862537173287, 0.026744530702541982, 0.00547996670606413, 0.0755189119705132, 0.0005071955965831876, 0.03980415001777666, 0.0341970453570996, 0.041699149047157595, 0.02868350389014397, 0.005201482787794832, 0.030295231512614658, 0.05626984718920929, 0.02486751794016787, 0.01711355901456305, 0.02460409198621554, 0.020932630602536455, 0.01453983667306602, 0.05086611304432154, 0.015169680018776228, 0.06175043221030917, 0.014216222118453255, 0.03900765168613621, 0.025550307373383215, 0.02816434656935079, 0.06785958832395927, 0.03526779057990227, 0.05827696395239659, 0.0576936545382653, 0.030025177967867682, 0.06662957396890436, 0.047464620388512097, 0.04271879719038095, 0.06575169214712721, 0.04265110653692058, 0.03384248706113015, 0.02184925677387842, 0.013890325141671513, 0.034920207623924525, 0.02303175162523985, 0.04029417783021927, 0.007235277427493462, 0.04939707115824733, 0.005037184438801238, 0.017529984437195317, 0.020664364997563616, 0.026491817120196562, 0.011885466203758759, 0.029197558627596924, 0.020446207507380416, 0.08671578472214085, 0.030778592718499045, 0.05202302882181747, 0.010793971380085816, 0.0483101394825748, 0.052771249386881075, 0.03199686502505626, 0.030218190646597316, 0.04797839014125722, 0.03809530707076192, 0.02159059074308191, 0.018177737714722753, 0.05063041372756873, 0.0459771528840065, 0.03927401739305683, 0.020488376762451868, 0.03808120032772422, 0.050775155425071716, 0.03939145484140941, 0.023369261728865758, 0.043076476747436185, 0.005753646596401397, 0.02484226456311132, 0.031573347215141566, 0.024687297342877303, 0.02206382990282561, 0.029049502286527838, 0.010894202876703014, 0.047633022602115355, 0.026322858507878015, 0.02923172286578587, 0.04535447147541812, 0.007901441056414374, 0.08138475899717637, 0.04594424393560205, 0.01797393293652151, 0.04067801830491849, 0.017595904114257013, 0.06241045679364886, 0.07988207534487758, 0.023473801922851374, 0.04282794972615583, 0.014284188426764948, 0.04127460664936474, 0.012672103725240698, 0.025669344468042254, 0.0377795406218086, 0.12271562298493725, 0.03239724139815994, 0.041070608488683186, 0.044782266286867004, 0.05460842366197279, 0.03733093397957938, 0.07433521441583123, 0.022955280728638172, 0.011611170966976454, 0.06656603594975811, 0.04843781602435878, 0.010591907044207411, 0.007413646472351891, 0.01942564164554434, 0.05414155424971666, 0.08810768396194492, 0.0024420602546472636, 0.06373708096465894, 0.042465469533843656, 0.04494810024542468, 0.02228883890035961, 0.010762523826477783, 0.03849316607894642, 0.03699702011155231, 0.0651788321722831, 0.027763848059943745, 0.0243488050598119, 0.04115073668903538, 0.05680797295644879, 0.027891239617019892, 0.08932608858283077, 0.05359318260369556, 0.058803384990564415, 0.05344348081520625, 0.009303089148098869, 0.031404154508241584, 0.045124115621937175, 0.04058826169265168, 0.021355817626629556, 0.05750025848725012, 0.10125891398638487, 0.039547999655561786, 0.0822133995326502, 0.007073464213005666, 0.01267528859898448, 0.08373491253171648, 0.04041362713490214, 0.12389727814921311, 0.03659058442073209, 0.01135756426291274, 0.0710387352321829, 0.007848545859035636, 0.03759962706161397, 0.001675206481844985, 0.012196370949303465, 0.05831444622682674, 0.04195545547242675, 0.07541311479040555, 0.033876661477344375, 0.01079087217138814, 0.06739036778786353, 0.12157660696123328, 0.012116264801339378, 0.006257431706347103, 0.012519302728053714, 0.051444513257592916, 0.043906847547207556, 0.03599133621901274, 0.0256308901921979, 0.009661023155786097, 0.015729366236233285, 0.037151800734656196, 0.037376049772969315, 0.07118392137012311, 0.06356178144259111, 0.049936533639473576, 0.025828730647585223, 0.032514376898429224, 0.024305823259055614, 0.03592368967032858, 0.07617266689028059, 0.015104594939787473, 0.02167154336348176, 0.06264786941132375, 0.015369742676349623, 0.03669046138280204, 0.02461667881081147, 0.021781130161668574, 0.021613104535000663, 0.019978091287027513, 0.04562812464843903, 0.029245090005653243, 0.018053136632910798, 0.02774588723800012, 0.01669798854605428, 0.07020455785095692, 0.03776184782119734, 0.07089829883937325, 0.07362985012254544, 0.04695996336106743, 0.00856896345171013, 0.03301559714600444, 0.011972386539647622, 0.03277627784492714, 0.04634316824376583, 0.03073658122281943, 0.0226496312368129, 0.015077536659581321, 0.0099254287446716, 0.03642710837136422, 0.04057033479745899, 0.029260777735284398, 0.08565270355237381, 0.10724570988012211, 0.06781838089227676, 0.027935736247205308, 0.02371012888449643, 0.04858285627726998, 0.06423232331871986, 0.065961047341781, 0.028013822057151368, 0.01817091504511024, 0.01574853654684765, 0.06446934917143413, 0.052849562506058385, 0.02366120820598943, 0.05465650465339422, 0.014969378177608763, 0.017516522302425334, 0.08944355656525918, 0.011941852463808442, 0.03938917835642185, 0.0630627732191767, 0.006894239789939353, 0.06625049681003604, 0.029431198590568135, 0.03494850253420217, 0.03385886689648032, 0.04698738296117101, 0.02118249942681619, 0.029795049423617975, 0.09149779419281653, 0.05222588704366769, 0.049395690339484384, 0.06907753154103245, 0.035703135255192, 0.03165767554725919, 0.04373442501361881, 0.05921800381370953, 0.030744129924901893, 0.012061082092779023, 0.04024450567417911, 0.041199733702731986, 0.01465214609301516, 0.04457899076598031, 0.03307307245475905, 0.015427531807550361, 0.04038192258615579, 0.11307163190628801, 0.0073565265463132945, 0.05480580949889762, 0.031983134868953905, 0.048038253893277476, 0.06940303836017847, 0.04554290743544698, 0.010783891742383795, 0.02686852788818734, 0.013788973214104772, 0.035852199220763784, 0.03682105223249112, 0.019355089270642827, 0.05678001392100539, 0.08796243675585304, 0.0658257474590625, 0.03621287790260144, 0.0306434692548854, 0.02159706735983491, 0.05477546202018857, 0.013638741320132144, 0.027247779769822955, 0.019356012078268186, 0.03172049431928566, 0.01829568067166422, 0.0036987486694540295, 0.026167665674750294, 0.02411889534310571, 0.045068774305816205, 0.033769822745983086, 0.024548007674249153, 0.08811773985092129, 0.07490510240729366, 0.039063620647149425, 0.016281172965786288, 0.032789621236068864, 0.027176939017538513, 0.19496041350066662, 0.08329305052757263, 0.10670254938304424, 0.11988070367702416, 0.16795655180300983, 0.16254978121391364, 0.09766354012702193, 0.06920223270675965, 0.12898490657763823, 0.18331357703677245, 0.16509611957839557, 0.1500168051570654, 0.18011990269379957, 0.13805653979735716, 0.10407180126224246, 0.18165291686143192, 0.12268583529761859, 0.18460404207663877, 0.09626947636050837, 0.16123733163944312, 0.170309181990368, 0.19691325085503714, 0.16511077593479837, 0.1698342210480145, 0.05757014759417091, 0.06856396195611783, 0.184866974396365, 0.1629521389092718, 0.34163763214434895, 0.05799657292664051, 0.1398405304976872, 0.1899229966636215, 0.3724101451890809, 0.11355394138289349, 0.0859715471576367, 0.20248253058109963, 0.14141441961484297, 0.16244055064661161, 0.21161922173840658, 0.09614631546927349, 0.12284128767039094, 0.11418314012033598, 0.2580716205494744, 0.14438881858118943, 0.10937218434576478, 0.0776256410671132, 0.10902000431503568, 0.18290032206901483, 0.12373985802488667, 0.17898277299744741, 0.1145807887826647, 0.14702918832855566, 0.15454990762685025, 0.10226454359612294, 0.09931279412869896, 0.1418898148196084, 0.19539163607571805, 0.17592996252434595, 0.059661419663046084, 0.09208191784897021, 0.05500223520877106, 0.15428489898996695, 0.1426580250263214, 0.08233506764684405, 0.18953921725707396, 0.1037982702255249, 0.12541574452604565, 0.11861394665070943, 0.09861739751483713, 0.15111352130770683, 0.1499043990458761, 0.18098103148596628, 0.15350496369813169, 0.14482777645545347, 0.13407809899321624, 0.1483011565038136, 0.13368757494858333, 0.1393862920148032, 0.16844504273363523, 0.17703396614108766, 0.12476464946355138, 0.06120533110307796, 0.1725425257214478, 0.12078301954482283, 0.09826958724962813, 0.13978623412549496, 0.13679080057357038, 0.07499204309923307, 0.17658856218414648, 0.08549683727324009, 0.11715954755033765, 0.12121405213006906, 0.12904475336628302, 0.13504472641008242, 0.18585124372371606, 0.15173978198851856, 0.14041333618972981, 0.10859583850417819, 0.15247287122266634, 0.09846545995346137, 0.21149998956492969, 0.06426209743533816, 0.12601447025580065, 0.1391324656350272, 0.2064980058265584, 0.09225164659853492, 0.1661188346999032, 0.2229005042463541, 0.11326990662408726, 0.12739687679069384, 0.13046579568513803, 0.09284515439399652, 0.10632693953812122, 0.16451104597321578, 0.10657014684485537, 0.14899262439991745, 0.10485541421387877, 0.13348861491041525, 0.1112845063741718, 0.1253981026155608, 0.06419295471693788, 0.1330276182187455, 0.1510340648570231, 0.17701583568538937, 0.17322973241763456, 0.17459825612604618, 0.10109572631439992, 0.10038866568356752, 0.15083719470671245, 0.19124244871948445, 0.2136525876287903, 0.06828287882464272, 0.12735707392649992, 0.08732163506959166, 0.1010352959856391, 0.08431513461151294, 0.07619727735540696, 0.1162746428911175, 0.19381978256361826, 0.1720790455916098, 0.13277352042496204, 0.14819474864218915, 0.07500206506145851, 0.16259831003844738, 0.16004598699510098, 0.10844849462487868, 0.16154170887810843, 0.17742614581116609, 0.1478770856878587, 0.17082805771912846, 0.11326629681778805, 0.2044930841241564, 0.08829130910869155, 0.14008719154766627, 0.1886150932737759, 0.10213147609361581, 0.10151143757892506, 0.18799510225653648, 0.16420694014855794, 0.21447102299758367, 0.13813120579080923, 0.10867326613515615, 0.12679307561899933, 0.14407001568802766, 0.06895274216575281, 0.08980990440717765, 0.12905020878783294, 0.15343690663576126, 0.10059008880385331, 0.09807206570569958, 0.15489577049655573, 0.14638707706970827, 0.21571203640529088, 0.07930038084409066, 0.17154108945812496, 0.14443292335740157], [0.024675614666193724, 0.012454050559816616, 0.03003817530614989, 0.011851431735392128, 0.020745093701407313, 0.01770859181747905, 0.014066470288006323, 0.02204517018981278, 0.05927795238260712, 0.024039525405636857, 0.02941815714750971, 0.025271061375471096, 0.02472433856954532, 0.01902997600180762, 0.06213837103652103, 0.015255886196557964, 0.04529872303828597, 0.04335270156817777, 0.045453703829220364, 0.06878724747470447, 0.005962195606636149, 0.027199544411684786, 0.01638500239433987, 0.03541204373219183, 0.042716313752212694, 0.022846738874380077, 0.06068353767373732, 0.06382628117821046, 0.026222823786416223, 0.012927000494008618, 0.019138448306226304, 0.024412716273218393, 0.033404913398304155, 0.017038395994209816, 0.01900423747221274, 0.03199236973055771, 0.03029622556641698, 0.06957892142236233, 0.047958498887185536, 0.04165332079199808, 0.016963670628943613, 0.04407588079837816, 0.015552511172635215, 0.02506671376925494, 0.10091265756636858, 0.030555392016789744, 0.025827122519591024, 0.017878142451601367, 0.058302707571004114, 0.07773988600820303, 0.03740553890487977, 0.0789288557799799, 0.010742646991275251, 0.032665048991995196, 0.03692889180300491, 0.0037295253215623753, 0.03466333801458989, 0.023363429720380476, 0.07364360402737345, 0.013264419843575783, 0.02873069600069097, 0.027129346571330513, 0.023800704827798263, 0.013257367320225706, 0.04977018399430173, 0.04608705859365208, 0.04707407598782863, 0.053653280450297255, 0.03142548764922789, 0.049354462551751306, 0.06751516394849334, 0.013559909969834345, 0.012483942571894398, 0.046702645918620486, 0.02245721227622458, 0.08634318078735045, 0.013728274864011576, 0.05251121101900935, 0.04805105445640428, 0.01846384539801095, 0.024751135613769293, 0.013734161155298352, 0.10671881386744124, 0.06579453484820467, 0.05512667853119118, 0.08122136097933565, 0.0540717974571245, 0.03488940552675298, 0.09388274300311293, 0.05523858252646668, 0.027680725823821764, 0.0502672075027866, 0.042574197985231876, 0.09111033034111772, 0.03281308158433863, 0.0354202438278922, 0.04275002676461424, 0.03225134958380035, 0.05507689102419785, 0.03286630926387651, 0.018190975932936584, 0.05743494949170521, 0.045982435279126675, 0.027598962354074632, 0.04069387227562921, 0.04285330997247781, 0.0414612343135689, 0.045860631457929096, 0.04480483775426235, 0.029988713495965515, 0.024395444164318696, 0.057463067982878, 0.04542579907657845, 0.017477652423882058, 0.05512028673131551, 0.07170906676245586, 0.04284316248127392, 0.03421705535479954, 0.011437133520043321, 0.03577584706779037, 0.02479179173574916, 0.05815836960183723, 0.011433991054738206, 0.016498202391500984, 0.040049535421920676, 0.01513087799373482, 0.022381448752379844, 0.023824718182108233, 0.010202006403622883, 0.021833521546795964, 0.01795153788823102, 0.013797062199695833, 0.024654732750994817, 0.050168185494840145, 0.04548400381047811, 0.055658728017338684, 0.06726371244128261, 0.0326188102231494, 0.02554717593427215, 0.04789617205304759, 0.02935541301433529, 0.09631542675197124, 0.023534809006378055, 0.012705580946723265, 0.0893915400707296, 0.02348644981559898, 0.008157347994191306, 0.04714794470263379, 0.0438050164042839, 0.023493435333615968, 0.048117272688874176, 0.03745391166635922, 0.012142372284350651, 0.04917392134666443, 0.01637268528741385, 0.02649230057639735, 0.029347087389656475, 0.008358902580636953, 0.019010415533557534, 0.0392370847319918, 0.05676680962954249, 0.009221825249759215, 0.01719640474766493, 0.01653314694496138, 0.0259167468175292, 0.03322038579998272, 0.06475224399140903, 0.033292609067367654, 0.042714485100337436, 0.02082387331340994, 0.03459193916725261, 0.11418371008975164, 0.041465699073991606, 0.03307659744418093, 0.03321597871503659, 0.009363103025992001, 0.005387602398903775, 0.05397909939555185, 0.033241803757846355, 0.014466568461752363, 0.014770309573837688, 0.05306117043697408, 0.043213734203683477, 0.013022974183383797, 0.014275813608297279, 0.0535036024105336, 0.013650770049675234, 0.05713478595550571, 0.011354979892660464, 0.015900277333067994, 0.029394856254969324, 0.05301342871306198, 0.030423220180507218, 0.05078857684774058, 0.06732043796884161, 0.06034121675682919, 0.024658327290256108, 0.04346198981095638, 0.03697691172627466, 0.060662184176700454, 0.03524997225031257, 0.03966052111770425, 0.05446094407566956, 0.07279532668845994, 0.030712374486029148, 0.03795711662886398, 0.06891231504934174, 0.024514586431905627, 0.04247758138392653, 0.03477008853639875, 0.036170435537184985, 0.04495310444118721, 0.026936162562508668, 0.07375057507306337, 0.020399553135835698, 0.05676146616627063, 0.01770221019562866, 0.037433345269943984, 0.029880846784050976, 0.028114173993734375, 0.006685259485883372, 0.0321686395577022, 0.019039938592218926, 0.10079593597246067, 0.016685422077508907, 0.03414278630433338, 0.0400695555976459, 0.0276104991457292, 0.05763493411775146, 0.014420728332230022, 0.04893774366272347, 0.01632287403169487, 0.010401699259611112, 0.03786881547421217, 0.02600972816747214, 0.013021706171067697, 0.025344411010986993, 0.019864450242104273, 0.05293747350307448, 0.035426513491464515, 0.049629632250538895, 0.022067270075370158, 0.04626254132017493, 0.023468275255124484, 0.013066268958417433, 0.040979762827711444, 0.04843729015971933, 0.021575366113600985, 0.053688988355653625, 0.028826807093407427, 0.04515685493658696, 0.049615203203367333, 0.06400374522698776, 0.03304800397849508, 0.01666202279739082, 0.023537494308714355, 0.02349004435486027, 0.06257261309240546, 0.04084460883002196, 0.05658751692888992, 0.06451266006167446, 0.02122094013196017, 0.049720942707998414, 0.01758434357387679, 0.04227029232840453, 0.05653745461521404, 0.04132425166400416, 0.025546894342239414, 0.02027820054042552, 0.018913675099611282, 0.00706452239371304, 0.031466281174549034, 0.07225609490914003, 0.0387878674082458, 0.036871335070048056, 0.06467027696115629, 0.03743003062637789, 0.012168844479934444, 0.017629537398793867, 0.03191715751641563, 0.03062266537121364, 0.05736655316182545, 0.028204634586083036, 0.028354597610554526, 0.03983597670282636, 0.0186113436440272, 0.031033430115452836, 0.10415213302310024, 0.021780992758327296, 0.01621850347146392, 0.07848846619682652, 0.049472541215696504, 0.011611098872630723, 0.03542242871065225, 0.02979342433224831, 0.03384505192350064, 0.04937646744240608, 0.03548898281795638, 0.04227842457060303, 0.021011053983654295, 0.11502052018685, 0.023537970979564955, 0.05148305743932724, 0.04387076984026602, 0.01445422082075051, 0.028841080077524697, 0.05828556777643306, 0.02674242215497153, 0.03751799590619547, 0.015906285760658126, 0.05546698419909392, 0.04786794499627181, 0.05810304185641663, 0.042835369506584745, 0.010420076532422431, 0.02759339497424662, 0.06994514712797743, 0.03243970411962696, 0.061070295849016736, 0.011819956192214574, 0.05786945617624691, 0.02330419870226511, 0.019440353981086185, 0.044857790627117665, 0.014209149239052619, 0.061420372421188016, 0.005009046863831047, 0.04646323840799076, 0.0751034381932446, 0.01878047189010041, 0.010962514389705445, 0.05479148901732905, 0.0511784427134054, 0.07207586243748665, 0.04016554794673409, 0.010739963385276496, 0.014437622157856822, 0.04154916905931064, 0.01334418248318668, 0.016255208823297704, 0.045728405338845084, 0.0406330314331821, 0.04695984122476407, 0.046117019307400496, 0.04311712099505322, 0.024226658578429903, 0.026367031137592027, 0.059696947756622515, 0.06231772141265018, 0.04202212153800896, 0.017820706158610325, 0.027733398800981895, 0.09437593618141753, 0.09308539650269917, 0.1197362978543554, 0.09681767158742462, 0.05899660462247474, 0.1815175898373127, 0.10907229222357273, 0.11867158141519342, 0.12415812058108193, 0.13604232216519968, 0.14505162515810557, 0.21682311035692692, 0.15874336260770047, 0.12623797969094344, 0.16765286667006357, 0.09524038979517561, 0.13553913416607039, 0.14370501813079628, 0.10927021410316229, 0.1567221696355513, 0.13997996944401944, 0.11158266823206629, 0.18966125856552804, 0.14985387532838754, 0.08795287619744029, 0.09242423198052815, 0.2071004906403167, 0.10792689797069345, 0.13208494308803762, 0.06033614810023989, 0.110914107678192, 0.12973873184195586, 0.11882278615874903, 0.14459111701164926, 0.1978468064750944, 0.14946560402001652, 0.12453610529857022, 0.1871696644063507, 0.11815459201378481, 0.10513607665364232, 0.04868676034467561, 0.24798128913555825, 0.15853970710720333, 0.10465745162218809, 0.13485354238322803, 0.08479464852384158, 0.16771440979625496, 0.2748764359525272, 0.12385421831692968, 0.11545134921159063, 0.11437990170504365, 0.12283013255468436, 0.09712629645530667, 0.06472415264163699, 0.12139147546674524, 0.11027924995869398, 0.09498426996703659, 0.18071758347962583, 0.1659258593405996, 0.11545615323952266, 0.10554823918001992, 0.09062981898231165, 0.11231504500444446, 0.07572763612759964, 0.149766385023083, 0.13874115448977264, 0.07898392568209342, 0.07842963042535953, 0.2267018745520285, 0.11129240452178887, 0.12192845450980322, 0.08204348079328026, 0.2595867621047156, 0.12927949934133462, 0.14435425400733948, 0.1535529496946505, 0.14238283836415835, 0.12533199973404408, 0.1226264906248876, 0.07176195856715951, 0.08205125001924378, 0.0982253196250115, 0.21546257979103497, 0.12405059992202691, 0.12783431474651608, 0.12774347247821943, 0.18884968997112342, 0.10269949811377696, 0.11730221632335867, 0.14124915562570095, 0.1253025648849351, 0.13843090113784584, 0.1108062748930284, 0.21461242969546998, 0.08546367048152856, 0.17414337982024464, 0.2168236124728407, 0.12007329905671732, 0.12880079288567814, 0.14291605832321302, 0.17336082538323744, 0.13113468193582126, 0.13684703755591596, 0.1720871880118336, 0.0941300011639084, 0.17201690535460198, 0.1498555988073349, 0.12224370187946729, 0.1148959140160254, 0.13719302256192478, 0.10735364444553852, 0.1884233664189066, 0.13404908483581884, 0.2220336350479296, 0.14730157942644187, 0.14148966914841107, 0.0812834876456431, 0.09604907461575099, 0.06864571864051477, 0.15283249478254998, 0.1764210183173418, 0.10375634354672261, 0.10785355512052774, 0.06818367021956614, 0.14470600656100682, 0.1644345207938126, 0.11790126774992261, 0.13061188427465303, 0.09460663808775799, 0.10890073821480785, 0.17360211243586882, 0.0637392590620688, 0.1241625582001039, 0.13889182997601374, 0.19475841362561497, 0.3264479200754847, 0.131434635126165, 0.09036464749702386, 0.10559136008045503, 0.16120233280318125, 0.11738821385162217, 0.13088488605405602, 0.13924774873469556, 0.06339392544967787, 0.16680643494640077, 0.07029725251985447, 0.07605647455368723, 0.19423567024724825, 0.10413291012602192, 0.1232635128710951, 0.13639245980552264, 0.10865447071513959, 0.20759457269949572, 0.19364828962300504, 0.10016938352159091, 0.12335496582090855, 0.14107672630676202, 0.1684870711926903, 0.07098559915487256, 0.11188534234783479, 0.09957774169743061, 0.15245718349303516, 0.07547205912747554, 0.1181695604962962, 0.10355682710983924, 0.09836259404463427, 0.2273422759026289, 0.16817261092364788, 0.15566978896302835, 0.09340782955821071, 0.08670141335044589, 0.23979728828583444, 0.1107104861044458, 0.15589289127715997, 0.12643582693168096, 0.0956546286387103], [0.03913315352318542, 0.019621387124061584, 0.0325616266844528, 0.036140393399234326, 0.008988376124761999, 0.008514200586692562, 0.04463076298790319, 0.027848588602085198, 0.04437897221318313, 0.025218529194327335, 0.016477988833295446, 0.08121547129537378, 0.02214031606646521, 0.0083779303988974, 0.036574204585381916, 0.09219006276024239, 0.035571848907108815, 0.025783509681267396, 0.007884865294077566, 0.00901890850426363, 0.024115421243810227, 0.013766117610170372, 0.036147518016930134, 0.03723305530313935, 0.05370517141584839, 0.023652268507118736, 0.039133760812027116, 0.022999156499281526, 0.04574830677094204, 0.012592268991284072, 0.0876425617773618, 0.013578054844401777, 0.025029535139245645, 0.0248983522677528, 0.04467554969180908, 0.026083608756640127, 0.02819171527932797, 0.024500537364344512, 0.013150884819749211, 0.020239006661410843, 0.049158125051430294, 0.045082470535167625, 0.07391810536916767, 0.06732319960636751, 0.018227757619959966, 0.06065697981310742, 0.0151653526616948, 0.01506102959891515, 0.05231717375240155, 0.05395237190116729, 0.038933284248092344, 0.03930275674377169, 0.027511036090020622, 0.025539874897471497, 0.019826401390933564, 0.07072056337658848, 0.05341259390115738, 0.05648864419864757, 0.06874177205775465, 0.018316789896094372, 0.07458974647202662, 0.0287844495448683, 0.03428230667486787, 0.023612711611869078, 0.02742496901191771, 0.009742062289400824, 0.05655553078811083, 0.011049150589055248, 0.027486274650852596, 0.04442469868808985, 0.062369256147316525, 0.025870370645342127, 0.04543175661404218, 0.042657556012272835, 0.015490454056167176, 0.066284952818283, 0.02332151830861611, 0.026086105765508752, 0.033104434343320985, 0.011470883003702121, 0.02376268820704094, 0.05523040617949196, 0.0422227643430233, 0.05441541098324316, 0.015299331097464477, 0.052897582429328134, 0.006648207657105688, 0.015457044688186474, 0.0445546483221863, 0.03985954900937421, 0.06368922388979367, 0.013450703151257975, 0.006787436681666544, 0.08183127575154815, 0.020127694687939117, 0.05276658785130296, 0.06118787918239832, 0.04039747460878321, 0.055764705009226284, 0.012883147623922144, 0.011341011401132813, 0.05907099920191935, 0.026042192675439373, 0.000986613453798262, 0.04420215955802372, 0.04872999659606388, 0.021699247948293175, 0.03578191317085709, 0.04166633848633085, 0.005084484266782445, 0.03808612309928451, 0.04103644425049424, 0.03184769927923169, 0.019208364554547837, 0.024719828008008853, 0.035835944914392064, 0.06423913581030709, 0.034416544650282176, 0.06274447244192873, 0.03739420058471816, 0.02598685644833105, 0.018238405530740107, 0.028453487304172347, 0.005138989712577313, 0.02286083883206759, 0.09990628835346017, 0.027293092338368297, 0.05216328540284719, 0.015104011399671435, 0.012469325231255164, 0.04179754001753671, 0.052765227388590574, 0.11117605612214122, 0.04702176772324102, 0.01715621511851038, 0.04295905965513416, 0.024973157360883694, 0.08878115032400404, 0.05912812506513936, 0.004429289580522371, 0.045414582892720184, 0.03840823385066219, 0.04647728069020169, 0.03636864579415747, 0.044841027419481955, 0.03965179855003953, 0.05125993137646999, 0.004648221872879991, 0.016529944259673357, 0.05815775213497026, 0.03459201719877975, 0.061884992489857335, 0.05962513839559896, 0.019269230842058147, 0.10079810049917017, 0.009116994133884353, 0.048841815774462054, 0.07452709054840462, 0.026661366057981337, 0.0378215589028384, 0.035249721192355664, 0.02961319186059492, 0.08764688404543058, 0.05398964722241674, 0.04025338091222303, 0.018270939588546753, 0.012940555927343667, 0.009440917421930602, 0.05138738060902272, 0.03513464843854308, 0.08546462721590485, 0.016264163789206317, 0.029066574227597033, 0.022286784635590653, 0.040097497669713836, 0.026258004130795598, 0.027433118217491677, 0.09009446163794824, 0.013075399495262121, 0.03798953363937991, 0.012231960111031575, 0.021575671454359378, 0.008278630191593297, 0.027982465257602077, 0.02949685024629746, 0.0318376501756055, 0.008349944222053247, 0.08704917611820356, 0.02555293500024293, 0.022727172522406493, 0.019641999321590577, 0.06207150819578341, 0.038517888502350876, 0.03495973568143589, 0.028874501319868223, 0.013506231064509069, 0.01530257279851607, 0.03131707810929843, 0.008680234713080739, 0.060183572715946605, 0.04035331215709448, 0.028997594357601235, 0.03854986785777977, 0.054398966687066216, 0.0431320419801133, 0.014921120767082487, 0.024072617558496337, 0.015189216738300664, 0.009948018871779953, 0.039627734305603166, 0.04912422883457371, 0.04572931457577007, 0.03466394191075649, 0.030664924532175064, 0.03000375661732895, 0.06451734873865332, 0.04916830986206021, 0.004847717529628426, 0.030751257935272794, 0.04163947867761765, 0.04636647252898131, 0.03660774117867861, 0.012566956242413392, 0.02326357820337372, 0.04265604627185634, 0.0259477982763201, 0.01817404478788376, 0.015701198551271642, 0.0037010429659858346, 0.03590357449970075, 0.04557349579408765, 0.024785654386505485, 0.0820877416325467, 0.07005690863089901, 0.03411784674972296, 0.03512813789503915, 0.035408515350094864, 0.03214322502857872, 0.020396196083830934, 0.0335662927744644, 0.030655051847653728, 0.020761254709213972, 0.02029226826769965, 0.03707751472081457, 0.08724595805896179, 0.03394388394164188, 0.0600409989378282, 0.014479950868657656, 0.05221661486263786, 0.07231193155582462, 0.007395437985126461, 0.04293663068009274, 0.03345075522416404, 0.03095212804951838, 0.032305442395487, 0.04401579652247684, 0.026998007636783377, 0.012243172054045966, 0.014641545679686325, 0.05685909717742886, 0.04512022083093013, 0.02984893528212394, 0.025463958703247563, 0.0776535492124302, 0.03422570328361221, 0.0329127990906792, 0.037122111434915235, 0.03420109281848584, 0.01639957563020289, 0.08114559575915337, 0.03841929057879107, 0.044294318184256554, 0.03723323850759438, 0.030657046740608554, 0.0337231259659997, 0.06719163166625158, 0.008729710942134261, 0.041969290801457, 0.02693749588382031, 0.05712081491947174, 0.05164743254759482, 0.023925655355144824, 0.01114802756014147, 0.024262271488883665, 0.01815789395810238, 0.04035886596622212, 0.08197593263217381, 0.03781295168612685, 0.060907386376389434, 0.03177713163729225, 0.025389567516478043, 0.007044999244888979, 0.013814817764796317, 0.014362467619191324, 0.04404042734365378, 0.028383925590398054, 0.025539968196036558, 0.08292383926787547, 0.062159595611904345, 0.046998592359679084, 0.014468147752008267, 0.05965970975479909, 0.056133546467338286, 0.02315341804309615, 0.08140122025672879, 0.021877052960917354, 0.03574054967612028, 0.023793503874912858, 0.07796280511787959, 0.06163332385144063, 0.022595482445987206, 0.02584315460574414, 0.01612659590318799, 0.0893482631072402, 0.04514562857470342, 0.015764256506892185, 0.02943166338705591, 0.028331296718014137, 0.08179422773952995, 0.026085724089560763, 0.05653378374076315, 0.010658464544186634, 0.06804149677710873, 0.061101942722286494, 0.03883568377100995, 0.05465494063017624, 0.028713247472686425, 0.015965927292459776, 0.038240299826221805, 0.019618152208360176, 0.05944336564945323, 0.02879024762660265, 0.03195643451597009, 0.03732041668679033, 0.017298760058890496, 0.058623586781322956, 0.07371659403932945, 0.029179322998970747, 0.024162229982071688, 0.040187630868916, 0.03660348676411169, 0.07088554238102265, 0.04467081351737891, 0.04369529050641826, 0.040251613328499455, 0.05982374559555735, 0.03175711824691721, 0.03699855360069445, 0.013349391087623579, 0.02627760191847171, 0.04167225870436855, 0.03180547743769629, 0.11331629127796207, 0.12179995354797159, 0.103709965678198, 0.06056188991559403, 0.17868960515729018, 0.10444406592952353, 0.06743868626654148, 0.10240920726209879, 0.10964779848498957, 0.10310902792428221, 0.08227881709379808, 0.12335454512919698, 0.11017898962433849, 0.08642633525388581, 0.1319579891860485, 0.18094485199877194, 0.11346559612346546, 0.08427265153399535, 0.11457370487707001, 0.052474675300930224, 0.05199140230459826, 0.1366482132247516, 0.08363220268594367, 0.22082075370209558, 0.1537848322519234, 0.07873560222131865, 0.1332123697336231, 0.13051942709301198, 0.10765519219317607, 0.09225138196987764, 0.11823716972555433, 0.0701044060822044, 0.13289047272077628, 0.18028603520776543, 0.10342829222125666, 0.09543298517486878, 0.2059414442628622, 0.117244011589459, 0.13190834756408418, 0.13181954090084347, 0.10692550920482193, 0.09023929493767874, 0.2422187626361847, 0.13282336560743196, 0.11813771006252084, 0.17881507985293865, 0.16144399983542307, 0.09167513610529048, 0.08911330678633281, 0.10524217917450837, 0.09609720988997392, 0.1052186204386609, 0.08487054266567741, 0.09513282163866929, 0.13073487553213323, 0.22959928693515913, 0.22709245287946292, 0.1738423274031707, 0.19830673108143465, 0.08417243191174098, 0.11756795777806214, 0.14935448712536267, 0.05578129179775715, 0.18633624698434556, 0.07392634956964425, 0.10122029855847359, 0.15973614076418535, 0.07569348546011107, 0.17129832319915295, 0.12847410541559967, 0.128095415021692, 0.07293443315263305, 0.10867546458861657, 0.16758799872228078, 0.1304662435182503, 0.15229254375611032, 0.06035243972603764, 0.08011387647794825, 0.10876488193337407, 0.10670047985123736, 0.11082847655883857, 0.10893404071352311, 0.12876195354121073, 0.1184342841484717, 0.11067577903824193, 0.13727975290800842, 0.07050758480493512, 0.12548142671585083, 0.05995402431913784, 0.16795041784644127, 0.11829553730785847, 0.11909688716488225, 0.07672627682664565, 0.21881234432969773, 0.15305923404438154, 0.2277335599064827, 0.09464572170483214, 0.09380344940083367, 0.25168359332851, 0.17648091938878807, 0.07358752989343234, 0.0885709673166275, 0.11377349495887756, 0.14502984418400697, 0.08692015268440757, 0.19780017754861287, 0.0767449229689581, 0.13698811855699333, 0.12061211014432566, 0.06975705722080809, 0.14725694539291517, 0.1326765442000968, 0.10675622828836952, 0.11874236618833882, 0.1725879604262965, 0.14389702997037343, 0.1392475858862911, 0.10695647754307304, 0.20450566416340216, 0.13616563911948884, 0.13418422187013285, 0.1307531145534345, 0.16676524787076882, 0.09966738295874425, 0.09397767683757202, 0.16327326239219733, 0.15961426230413572, 0.11477756393807274, 0.1464038233139685, 0.12699412554502487, 0.12835105987531797, 0.1730298495718411, 0.20185066520103387, 0.1828988292919738, 0.0622260377609304, 0.2600411634360041, 0.0945303300395608, 0.2500874346920422, 0.11065712611057929, 0.05665339928652559, 0.07803542872092553, 0.10517156403511763, 0.24439373878496035, 0.14551123763833726, 0.16407208809895174, 0.13575060638998235, 0.143544218902077, 0.13934578347418988, 0.11216734828693525, 0.22604217566549778, 0.12809033957975252, 0.12530248346073286, 0.09896151654954467, 0.08890321877385889, 0.20112550125590392, 0.05933160414653165, 0.16674425399729184, 0.23587003616350039, 0.1406763635043587, 0.11395649585340704, 0.13756671893809522, 0.15286585156406673, 0.17786389589309692, 0.10529568844607898, 0.12107244187167712, 0.1155942893986191, 0.09039095429969685, 0.11723797262779304, 0.14226503111422062, 0.08031622919120959, 0.15120519138872623, 0.1363180245139769, 0.17692914605140686, 0.13626469166151114, 0.17465034047407763, 0.11873448161142212], [0.01777827736389424, 0.03961565298959613, 0.035442079084792306, 0.03970378451049328, 0.025618605315685272, 0.026354223789115037, 0.013361643733722823, 0.042219402202005894, 0.0073854134783947045, 0.05993157159537077, 0.00859405058768711, 0.01659171299875847, 0.03174503014555999, 0.042679404839873314, 0.04291236287515078, 0.01778767677024007, 0.023451741053057567, 0.013372723362408578, 0.04218443389981985, 0.03918897999184472, 0.026750562878857766, 0.04509830414982779, 0.04642884686057057, 0.008390903140285184, 0.018904852448031306, 0.0164186967470284, 0.06583659044866051, 0.0052061706166049194, 0.028262425413621322, 0.022158801056710736, 0.01844675649356629, 0.018048066279983947, 0.06051191581147058, 0.06171279387282474, 0.016562943113967776, 0.06899650767445564, 0.031175362677978616, 0.02103441933702145, 0.022327749491004006, 0.022548368366967355, 0.05425989075696894, 0.06084105957831655, 0.00880080699321947, 0.06374979671090841, 0.029082889602120434, 0.03298931748473218, 0.015110097858788711, 0.02682912366331688, 0.015430507183607136, 0.0436024465598166, 0.04026421372379575, 0.005740789205966783, 0.04618064553609916, 0.09637856443545648, 0.032505715398916175, 0.00891948870516249, 0.05764302225517375, 0.011481073751513447, 0.023966340314862982, 0.021253197686746716, 0.04782368415700538, 0.02705454656721226, 0.0718832059896418, 0.10394710688186543, 0.03918654065845268, 0.03195425981123533, 0.03571358808715429, 0.1157874276063272, 0.057265675360602994, 0.03812230937182903, 0.019894670495497327, 0.019362020505858318, 0.049238453419612985, 0.10430267280233757, 0.054874416174633164, 0.028889361236776625, 0.037011062393763235, 0.04702271767226713, 0.014836023994056242, 0.01132387584740562, 0.026285445783287287, 0.029417838236050944, 0.041745055333844254, 0.014641165700075882, 0.016706729773432016, 0.0566736264154315, 0.041894994609590085, 0.01753933634608984, 0.0025300492831904975, 0.039597651455551386, 0.04367011346455131, 0.04145375685766339, 0.03201004217511841, 0.07648563438228198, 0.05680216808936425, 0.037378353399357626, 0.023012642382777164, 0.08963892036782843, 0.018881254696420262, 0.041194620941366465, 0.02442062120618565, 0.03411322253357087, 0.03470749028825334, 0.033019814241145334, 0.042827959904181104, 0.030638929855610644, 0.00936437867182706, 0.01784793576890869, 0.023765375205714787, 0.03595356556719967, 0.024622386986655847, 0.05547673135463681, 0.007484986796043813, 0.05483310357002275, 0.042567962248410494, 0.06541514556322779, 0.05783945814307247, 0.023947855324617455, 0.06809265153216464, 0.04222510868151273, 0.010628517401138586, 0.04626490940739002, 0.027270520870972956, 0.039177156519144773, 0.023593249531196694, 0.05585086877856936, 0.011906612747614937, 0.042950778135231564, 0.029602935803788047, 0.027654206978955438, 0.062158157117664814, 0.0668167071416974, 0.04403038163270269, 0.04156544032905783, 0.08238232082554273, 0.051135630546403785, 0.07345733259405408, 0.06052157815013613, 0.06959844287484884, 0.03648212059800114, 0.0410164817502456, 0.04822552616574934, 0.04362580512783357, 0.0925285770956959, 0.08016478696039744, 0.030103884637355804, 0.06649615362818752, 0.04436475011919226, 0.06759695455964122, 0.02978225564584136, 0.08857636845537595, 0.0982812512665987, 0.02281166539926614, 0.014113750608105744, 0.012055007508024573, 0.009038843863111521, 0.050549688416400125, 0.040303446618574004, 0.030147765497011796, 0.018022919772192836, 0.07640087178775243, 0.017743178443717103, 0.06952917802014522, 0.009059892019389995, 0.056958366850657124, 0.05087645731068083, 0.03872371531490769, 0.03306644995297704, 0.015960916311347058, 0.019447632965498736, 0.017680086561345627, 0.019193793015022362, 0.025062249008832232, 0.055053311932299814, 0.04091025030772601, 0.012993986319218363, 0.042618197588516135, 0.03603661825348224, 0.010938877622330827, 0.014252566998558385, 0.02079868270084262, 0.03191504727250763, 0.013475165186849023, 0.021699222503229976, 0.030741042590567043, 0.03781052931611027, 0.0596520762358393, 0.020198766142129898, 0.018708347010293176, 0.02853081315489752, 0.02754574315622449, 0.01559502987324127, 0.04788784303569368, 0.024940786151481525, 0.005244652457934405, 0.003918208946873034, 0.016327542352623174, 0.03638639287757022, 0.0636471818600382, 0.04591210512444377, 0.05263467046565243, 0.045644317886659076, 0.06354697580848422, 0.030073391273617744, 0.008116544290844883, 0.03644243647743549, 0.08551365815635238, 0.019332007205645953, 0.02300721749530307, 0.09139938625906195, 0.042264677451125214, 0.030514025129377842, 0.04833406802000744, 0.05278577682163034, 0.023948096204549074, 0.06682270539126225, 0.05191767608214702, 0.04988166390519057, 0.035955360292324, 0.029915513138153722, 0.0784373182271208, 0.06763709669134446, 0.04176141820581896, 0.0193560307379812, 0.03552389005199075, 0.06843700805412871, 0.019595114248139516, 0.03182727876784546, 0.03586061984034521, 0.05494517719905291, 0.04506582946383527, 0.03116777665647013, 0.016095744612227594, 0.021437777871532098, 0.047893583441951444, 0.08616410861057894, 0.08821468214903559, 0.041807015759072134, 0.04856601503810712, 0.06247571150639227, 0.008548678647327636, 0.053400146176240275, 0.030273932298379283, 0.04542720025139196, 0.02575438017291682, 0.03074119526094624, 0.0415350317821971, 0.01648464865450348, 0.057253814568477016, 0.07123181915708951, 0.05988216067531279, 0.028608210251799653, 0.04020302004313894, 0.029390116687864065, 0.008820758467274053, 0.10237888353211538, 0.04368488517190729, 0.012085567877095724, 0.0395592361954706, 0.019591263561908687, 0.020770520104893615, 0.07862179154264075, 0.03598649487165468, 0.043915851706905026, 0.03315049330038684, 0.022344763756596615, 0.008510299010335334, 0.01855347308862422, 0.009028743021190166, 0.06432649040860788, 0.0297586901246437, 0.025876143282013278, 0.02892954068790589, 0.053204504174313376, 0.05259673696543489, 0.037912879538323195, 0.01095580283020224, 0.016200337392677153, 0.027537269950179116, 0.08554238054369177, 0.08555882144719362, 0.03568062824862344, 0.027521091978996992, 0.01113302430271038, 0.03513360349461436, 0.07710876701665775, 0.05242892507729786, 0.036776808356600146, 0.02368994416402919, 0.01996095149245645, 0.052080717869102955, 0.009792545294788266, 0.037729006726294756, 0.014024638604106647, 0.009959776187315583, 0.031726994684764316, 0.028829565338258232, 0.041672486013599803, 0.07138073045228209, 0.08533939000751291, 0.04763476982978838, 0.036114110345286984, 0.017412696266546845, 0.02815846197440156, 0.019434766245207617, 0.07759524948362793, 0.05454894667491317, 0.09747306177658693, 0.01943699692908142, 0.01795987708361021, 0.04899844201281667, 0.08333948946424893, 0.043830787164292166, 0.01694071409292519, 0.0901956379945789, 0.006891765257543219, 0.011679480783641338, 0.011389311220097755, 0.054060425210211954, 0.02081825165078044, 0.02415372454561293, 0.06416496514741864, 0.01506080398602145, 0.016392172813149433, 0.016585957325462784, 0.02012812895035105, 0.04275432867663247, 0.05736694671213627, 0.030325996290360178, 0.04268231575510331, 0.04418019198679498, 0.05903938625540052, 0.011703986075839825, 0.0375705959408411, 0.06250309039439474, 0.021605689843584384, 0.04883146811542766, 0.06530661388699498, 0.051597187029463906, 0.012205696564966013, 0.02401373259324048, 0.043878545851579735, 0.04577703933630671, 0.02782763204803424, 0.02218923165595957, 0.06752871429281575, 0.02056252028393958, 0.0379561531091375, 0.010329358096766685, 0.05887328766818557, 0.008806437137536705, 0.019412020055044974, 0.08097076442624841, 0.08081968181899615, 0.07613419395472322, 0.08924352444176163, 0.09374470183891909, 0.12061102448829583, 0.07212597903396402, 0.07891037927142211, 0.145300918923957, 0.08026941027492285, 0.14883805412266934, 0.10247374272772244, 0.09438175801187754, 0.14168838491397245, 0.12034913711249828, 0.07317288392888648, 0.1414028980902263, 0.07306435225265366, 0.152835697467838, 0.07889550578381334, 0.12082360950963837, 0.1602273594055857, 0.21320209465920925, 0.06682408281735011, 0.11511775425502233, 0.11739681767565863, 0.22355402846421513, 0.15908504570169107, 0.15464043776903832, 0.13682597582893713, 0.12243021758539335, 0.11164423171430826, 0.10142415083412613, 0.1633986420929432, 0.10617487305509192, 0.17831128117229256, 0.09041744430682488, 0.16570244490035943, 0.15685168839991093, 0.15645083705229418, 0.2716538831591606, 0.17427992820739746, 0.07266760604189974, 0.11625020205974579, 0.12275182961353234, 0.16204425905432018, 0.11145571433007717, 0.0587220625685794, 0.08306426887533494, 0.22043103032878467, 0.11532014768038477, 0.12814744508692197, 0.12028654904237815, 0.13682250172964164, 0.13526359466569765, 0.22543941943773202, 0.08045473854456629, 0.11315518670848437, 0.10583242321653025, 0.1907293133969818, 0.1481587320033993, 0.15560983360878058, 0.12543335929512978, 0.278775189604078, 0.08662183476345879, 0.1405592890722411, 0.11161900378231492, 0.1815011150070599, 0.12284759804606438, 0.09733365675700562, 0.12697661934154375, 0.1299041858209031, 0.08693204740328447, 0.11657593958079815, 0.13362403692943708, 0.14994489401578903, 0.11277862012918506, 0.08267548866569996, 0.12615131719836167, 0.18844313892935002, 0.11922431604138442, 0.12053664347955159, 0.11681801373405115, 0.11554111939455781, 0.08730632731957094, 0.1531749785478626, 0.14867478502648218, 0.09873932347233806, 0.08486525009253196, 0.18477273945297512, 0.1146261284926108, 0.13121502048202924, 0.12661927565932274, 0.20915506753538335, 0.25510096709643093, 0.1393268523471696, 0.19677959302706377, 0.15087091789713927, 0.08235563404325928, 0.1457023945237909, 0.20421090855130128, 0.14606680854090623, 0.12396000192633697, 0.13117338557328495, 0.1728565517280783, 0.09982542733528785, 0.12031541392207146, 0.10710141262305634, 0.14910944098872797, 0.13009599409997463, 0.17969121783971786, 0.09361689298280648, 0.13604290570531571, 0.1573966063026871, 0.1411655465407031, 0.14401596358844213, 0.09736803812640053, 0.1662415816847767, 0.13683756520705564, 0.10268684343567916, 0.11923921667039394, 0.18244039746267454, 0.12280508104179587, 0.19819313074861253, 0.21004404340471539, 0.08979716830487762, 0.17645634285041265, 0.13094364718667098, 0.11188015834029232, 0.15019608767969267, 0.20237918969775948, 0.10735296591051988, 0.08197918960026332, 0.10348205933613436, 0.17534263618290424, 0.18125533605260508, 0.12491400859185628, 0.131871190986463, 0.27549232861825396, 0.11651914619973727, 0.10112009250691958, 0.12971213326922484, 0.09221620671451092, 0.13463375131998742, 0.20955146769327776, 0.15743473997073515, 0.1242538754429136, 0.09522007445671729, 0.1596211019371237, 0.08351381868124008, 0.12420821003615856, 0.1623978300818375, 0.12801272874431951, 0.1580630498273032, 0.07930848933756351, 0.14330608025193214, 0.11093814817390271, 0.1766979013170515, 0.12669964134693146, 0.09556356245385748, 0.11637007205614022, 0.10895504137235028, 0.15947342557566507, 0.17508889122733048, 0.15755291362958296, 0.10404549445956945, 0.14423914732677595, 0.1237503888883761, 0.08164632746151515, 0.15396243200770446, 0.13128610381058284, 0.10898757712649447, 0.08640696986445359, 0.15526927688292094, 0.16415964625775814, 0.09918050694146327], [0.06063400461737599, 0.020821678252624612, 0.02155980560928583, 0.04668568932850446, 0.05236973646762116, 0.01070933261819716, 0.07260129959987742, 0.035849905772400756, 0.014723085232877305, 0.05363646635253515, 0.018172511298741614, 0.07921073279742684, 0.09665331004985742, 0.03359547995829156, 0.03613214919875775, 0.02395102577949209, 0.01717362123807626, 0.045493398127811294, 0.04241666590262737, 0.025347145507112145, 0.01910961904962148, 0.01431883272847959, 0.029062431771308184, 0.05199186031573585, 0.0346156912855804, 0.04846868597503219, 0.03064948446782572, 0.008316310937516391, 0.019416754533137594, 0.03355277974956802, 0.05698693996029241, 0.036469119867043834, 0.038624513495181284, 0.04763675454471793, 0.005557390944367009, 0.058048358719263754, 0.049773281506661854, 0.12127084551112992, 0.03787777213645833, 0.038052552579236884, 0.06130001387958016, 0.0377040332449334, 0.01392995158676058, 0.04612335343179958, 0.029135781406824077, 0.05700095849377768, 0.008357939060910471, 0.01986287264818592, 0.02740623296371528, 0.00787180773581245, 0.028349115047603846, 0.018281029404274056, 0.04635513760149479, 0.037144089184169254, 0.028120840600292598, 0.04979731182434729, 0.01999544651646699, 0.028612013440579176, 0.030195958446711302, 0.007974416649501239, 0.005905801713067506, 0.02986932186675923, 0.07182900461235217, 0.0586564482322761, 0.0166049766620355, 0.0550352493301034, 0.028675551459725414, 0.022037616398717676, 0.06203604117035866, 0.059703685609357696, 0.01950569690338203, 0.048495935941381116, 0.024380962530683194, 0.011761994882752853, 0.009046676701733043, 0.024892817118338177, 0.035445030712123425, 0.012890546200131732, 0.03661922199119415, 0.010889924713410437, 0.017429825883092623, 0.0063577204543565, 0.04059287573077849, 0.06391229227717433, 0.029990878022675003, 0.05007521941193512, 0.034037403030587096, 0.054760693705507686, 0.03760820035157459, 0.03715259462062802, 0.04004455836755889, 0.025340188826833452, 0.0155552287053849, 0.03393836405926517, 0.08264640665480069, 0.08129882932241474, 0.0010347274177807517, 0.049062794273985286, 0.05960306565144232, 0.03727915157963123, 0.04216383357665368, 0.04940159359414663, 0.029418750865651027, 0.03128112593133535, 0.038769519821341546, 0.021567221997039657, 0.02179353717448456, 0.016415326124323264, 0.04617225545059357, 0.011698268570138939, 0.06582306046038866, 0.05185332042830331, 0.01662895778593208, 0.028423932015097568, 0.032663474790751934, 0.04968472929405315, 0.02379287114100797, 0.019428181062851633, 0.0431791323104075, 0.04184643864365561, 0.02362247064177479, 0.03400672985506909, 0.016942949865811636, 0.027553595502727797, 0.026192540768533945, 0.024500025070405433, 0.026176035404205322, 0.011686012531364602, 0.03774705236511571, 0.04429669305682182, 0.05912153649010828, 0.06695917913956301, 0.04932234748931868, 0.027219513697283607, 0.013550051704182156, 0.0030174034556174384, 0.009256884306004005, 0.00799308399603303, 0.04690957195790751, 0.013304267660714686, 0.01600846804545394, 0.08180641422846488, 0.0751240656578115, 0.014705850443403636, 0.013086737815423735, 0.0682987565440791, 0.00786548972662006, 0.05134394418980394, 0.019679264464814748, 0.017811444155605774, 0.048742943044219694, 0.021726994941543256, 0.06106663175991603, 0.029084395949861834, 0.018785119854978154, 0.042020710185170174, 0.022414130391553044, 0.03732745309493371, 0.020129167108929584, 0.026488728089524165, 0.014845355546900203, 0.05127845198980399, 0.055248753766396215, 0.040587186214647124, 0.024096564755641987, 0.031309926350201876, 0.04548957458298121, 0.008609600913976985, 0.01453275785648397, 0.01388334556083594, 0.0328952318190464, 0.028108111283342754, 0.09561574858214174, 0.034867471882275174, 0.03553468215146235, 0.02162165746891073, 0.04464968732957329, 0.06219883529203279, 0.0420650253072381, 0.03540642885491252, 0.07782417362821953, 0.013926040680546845, 0.02012440548943622, 0.0223770772905222, 0.030543904418924024, 0.07571750559977122, 0.030950217973440886, 0.06778862034635884, 0.10285205992736987, 0.03864998909245644, 0.05021228348570211, 0.04474880433242236, 0.03542010812088847, 0.03903035207518509, 0.05274765333160758, 0.05627046126340117, 0.010829361222152199, 0.020822024305484126, 0.03077654693541782, 0.026819832822574035, 0.0627428778846349, 0.03941235711265888, 0.043540591307516606, 0.03363132017797657, 0.04206814656832388, 0.012995607169744159, 0.030270977278373072, 0.020572620277692164, 0.005336595225214426, 0.0450908674060234, 0.04951608959319336, 0.030403454455413988, 0.025484837225771377, 0.077064967581204, 0.03952502445983035, 0.01232385665311345, 0.01816705587719168, 0.03967086199138846, 0.02146263769827783, 0.06865585595369339, 0.048407258199793954, 0.029289462803197757, 0.04682382209492581, 0.051937228068709373, 0.04945942513378603, 0.060903118391122134, 0.03062126419640013, 0.09902414533176593, 0.02768783178180456, 0.03473037727443235, 0.06830677004264933, 0.04428913417671408, 0.03973886816363249, 0.03836760317374553, 0.007795884756238333, 0.02758630089062665, 0.03841077496430703, 0.02041109332016536, 0.01998236436130745, 0.02069854111011539, 0.03247449600270816, 0.01649006166761475, 0.08240666666201182, 0.0585610122819032, 0.06322809827647038, 0.009103574407553034, 0.013454398622603288, 0.014761617540248802, 0.06133738758840731, 0.021038985877696956, 0.0005269293033052236, 0.01983709171015237, 0.01882251222351832, 0.05592908351016896, 0.02020465412975422, 0.00527719287700685, 0.06074496544897556, 0.06976106057741813, 0.06676779833755322, 0.02753631830481546, 0.013756238988467624, 0.03712930051343782, 0.022222890385559628, 0.034079095614807944, 0.04676344944164157, 0.02312452262932701, 0.02081449595945222, 0.025301826153216616, 0.05639323199700032, 0.038458584541721005, 0.020104661816731095, 0.04544964279713375, 0.022963270478482758, 0.08115495954241071, 0.05320884679843273, 0.02788341441191733, 0.0266474798388247, 0.0710583177528211, 0.024103382336241857, 0.07395684293338231, 0.07689112012407609, 0.03723461932635733, 0.041285934791501076, 0.045964986751122136, 0.009117972920648754, 0.03760399343445897, 0.01624837258298482, 0.08160070276686124, 0.059486303345433304, 0.02467250867214586, 0.04186911189130374, 0.014106374932453036, 0.0709483272262982, 0.03811045875772834, 0.04317584141556706, 0.02446670051930206, 0.03490413312933274, 0.03594183708940234, 0.04877692407795361, 0.03485485113092831, 0.04526480646537883, 0.03336049649598343, 0.05192822390901191, 0.023269031928586106, 0.0009922458245585272, 0.041783555410802364, 0.05916044368807759, 0.04579741235024162, 0.06976562033274344, 0.07899493830544607, 0.05339386972731777, 0.029545823511268412, 0.040642524138092995, 0.004051223862916231, 0.03889256196894816, 0.049841738904693296, 0.018986057822725604, 0.030247374437749386, 0.04000365288395967, 0.10511783763234105, 0.027737408942942108, 0.024018455196970274, 0.02774252848965781, 0.032210020015814474, 0.026401831502360956, 0.04254496330395341, 0.03263306285121611, 0.045731319646750174, 0.03771470320810165, 0.10230904192264591, 0.02236728772654065, 0.016222807079819695, 0.023788324956383024, 0.03334632868479405, 0.011035578192344733, 0.03552659062136497, 0.027106883669538156, 0.06485133046018225, 0.044107266435665746, 0.03583889654172318, 0.05324923998809286, 0.03296592838263937, 0.07270605862140656, 0.014327255044398563, 0.03991527030510562, 0.04315791452037437, 0.031118182531957115, 0.038887076013322384, 0.05328312263424907, 0.020789001702464054, 0.0800326286948153, 0.013052884007005819, 0.1407565934849637, 0.17972925651286328, 0.07855366662676845, 0.17442125348108156, 0.13855326814310892, 0.07415756716259889, 0.19295097275504045, 0.20643231006605284, 0.11480701235788209, 0.25759043065564974, 0.11090736982545682, 0.18669912751231874, 0.22192770216081822, 0.13017117578004087, 0.10856512800923415, 0.16780257863657816, 0.16814052978796618, 0.11528285539575986, 0.13773363855268272, 0.12101152299770288, 0.10947249896292176, 0.052135384042880366, 0.10358670300671033, 0.13131638004311494, 0.2027295580399888, 0.13881415128707886, 0.10892293988061802, 0.11306534867201533, 0.1000372048999582, 0.10934591146984271, 0.10869257724178688, 0.1350254017327513, 0.11746951591755662, 0.18442942787493977, 0.17279162949749402, 0.1330773819770132, 0.09838644455053977, 0.23476638538496836, 0.1386844968157155, 0.13234573123710497, 0.15075616405478545, 0.20020345358976296, 0.12896119856408664, 0.2329096964427403, 0.10271661755229745, 0.10848202782550029, 0.10345088065202747, 0.10212682134338788, 0.14916099607944489, 0.18954930028745107, 0.12226458718734128, 0.16567742052887166, 0.13042521929102285, 0.13317289256623813, 0.12717608149562562, 0.10233576263168029, 0.16261177217321737, 0.11439119252775397, 0.09217938940439906, 0.06547740115118877, 0.11471802927553654, 0.07300786421235118, 0.11578319354781083, 0.1292607310627188, 0.1135193496676428, 0.11286567617207766, 0.22615314328244754, 0.07694193561162267, 0.1847070436924696, 0.09124572521873883, 0.08191547516201224, 0.14677817108375685, 0.08635036647319794, 0.09847061003425292, 0.07320035102644137, 0.12041621708444186, 0.10719563399574586, 0.11843697114714555, 0.21472205381308282, 0.15558866331619875, 0.12238806699003492, 0.1422145888209343, 0.145554745303733, 0.1751398356365306, 0.059121787548065186, 0.10487867439431803, 0.1281688189400094, 0.1301213577389717, 0.13281658025724546, 0.15094056273145334, 0.08888068462588958, 0.06385285939489092, 0.10908590363604681, 0.11723751122398035, 0.16511705916907105, 0.21004846745303699, 0.09636430841471468, 0.2114723189068692, 0.09830496606550046, 0.13150152510830335, 0.07949126631553684, 0.1645231374672481, 0.09624535444059543, 0.13499308989516326, 0.1631868848843234, 0.17990954326731817, 0.0974194642954639, 0.13242890605969088, 0.1002904816663691, 0.11104319896548986, 0.21370231067495687, 0.18079268373548985, 0.17351026593574456, 0.08842337916472129, 0.12261093860226017, 0.11064026451536588, 0.10578487148242337, 0.1335834605353219, 0.1488415010805641, 0.08319820490266595, 0.1869008695440633, 0.10794185966785465, 0.10544582788965531, 0.11693402965153966, 0.09069256990083627, 0.1412406467965671, 0.17014484080885137, 0.12671041648302758, 0.05180223352674927, 0.15511805856866495, 0.192893867247871, 0.1535159152533327, 0.12612094597092696, 0.10614753487919058, 0.08969183931393282, 0.12533954504345143, 0.07974033616483212, 0.06299648713320494, 0.14527900224285467, 0.07683009268449885, 0.10027644277683326, 0.10727488010057382, 0.13300836139491626, 0.2058078542883907, 0.11080408322491817, 0.14395554683038167, 0.07046049447464091, 0.2255685039396797, 0.07881221561027424, 0.09574936569801398, 0.17426759244075843, 0.14802009372838906, 0.1559077783354691, 0.15582939397011483, 0.12711380555161408, 0.0806701055594853, 0.06272887292185, 0.2227122379200799, 0.11514425783285073, 0.2564386310321944, 0.09212862141430378, 0.1158349657697337, 0.13012967657830032, 0.1158666397844042, 0.17162723626409257, 0.07744909982596125, 0.20368106769663946, 0.1291618685105017, 0.10892192886344024, 0.11080155907464878, 0.13121716465268815, 0.09264221135526896, 0.1702327382351671, 0.11719161511531898, 0.11526749336293765, 0.07520223967730999], [0.020477248788146035, 0.008723347979996885, 0.03702807326668075, 0.017964955918224793, 0.017550472802083408, 0.01421977170476956, 0.06188316044530698, 0.03717929158093674, 0.06712542700448207, 0.04970236781186291, 0.023233106892023767, 0.00894170394167304, 0.05525905732065439, 0.04092714243701526, 0.025736560146989565, 0.036875843935246976, 0.057956491863088946, 0.0323569024913013, 0.06500398726867777, 0.025459712770368372, 0.011511404266847032, 0.03561331757477351, 0.04599726466195924, 0.04643307074106165, 0.03860604037929859, 0.02150059664355857, 0.0398754674409117, 0.04991348719756518, 0.04862850132797446, 0.013208834254848105, 0.08891113727752652, 0.024534638838044236, 0.050383080927921195, 0.003757476299402437, 0.03452030961800899, 0.018186455193374838, 0.051572936187897406, 0.02772368896486504, 0.04021697072312236, 0.055179102146731954, 0.040312406673495255, 0.026094765568684255, 0.0591637006561671, 0.06344795040786266, 0.030467674402253966, 0.057027394218104224, 0.031303415806697946, 0.03275039851931589, 0.029526627755590847, 0.038289072923362255, 0.08323082886636257, 0.0350079761285867, 0.01422831361248557, 0.05210516209314976, 0.019672433313514506, 0.028465144535792724, 0.04215708215321813, 0.02251663158780762, 0.05129207018762827, 0.018711240962147713, 0.07830064091831446, 0.017098755076793686, 0.029332783871463368, 0.04043918076370444, 0.03935155698231288, 0.014115772642461317, 0.06356926568384681, 0.0155627349990287, 0.030127433195177997, 0.06736970639654569, 0.0119925542967394, 0.01117077375030411, 0.014739173298169459, 0.013480635027268102, 0.027721739873023968, 0.04736037366092205, 0.06324367065514837, 0.030124868332807506, 0.027350150348086442, 0.040742533414491584, 0.032983563507774045, 0.0373148085948612, 0.03686928589429174, 0.015693827964631573, 0.054110548592039516, 0.03534186624788812, 0.035890516093266864, 0.07434753661176988, 0.025992160895839334, 0.0729476103026952, 0.07510325498878956, 0.016121959812673073, 0.03327651421672531, 0.009837612742558122, 0.04460803545745356, 0.03112168377265334, 0.04132506251335144, 0.06751168306384768, 0.026182489968570213, 0.017963637863951068, 0.03933923478637423, 0.006634720501356891, 0.06944826271917139, 0.0006524539879007664, 0.07167364723448243, 0.05949540250003338, 0.029141416640153954, 0.034096174341227324, 0.02345421600953809, 0.02185977915568011, 0.04349857981183699, 0.051729053524988036, 0.06174769092883382, 0.04600399912201932, 0.028159518792693104, 0.03352424395935876, 0.12217459987316813, 0.031551047161753686, 0.04718687564932874, 0.014971666536959154, 0.028352970822847316, 0.04799117034833346, 0.08671113675726311, 0.028552410924541097, 0.03067460044154099, 0.008819169847161641, 0.06667148029165608, 0.021474920878452913, 0.04523498824398432, 0.03383871779910155, 0.05243850938443627, 0.015465858858078718, 0.014075028310929025, 0.015878145217097232, 0.00570955581497401, 0.07049548652555261, 0.010552329792907196, 0.11527558150035994, 0.06776175714497056, 0.058409848250448704, 0.021846920917076722, 0.0023343822602847858, 0.03863478312268853, 0.01718678481743804, 0.012234665769418436, 0.03632014411102448, 0.047588595521769354, 0.014030363743326493, 0.04049771458708814, 0.01720047935045191, 0.009242353478579648, 0.03550971884812627, 0.045738881919533014, 0.028592098437781845, 0.0340638557182891, 0.029853155769939934, 0.022642377697463547, 0.01711229354675327, 0.026720077996807437, 0.03882044726716621, 0.0876553114503622, 0.012016545598661261, 0.036910266016743014, 0.03255956733067121, 0.008294019365816243, 0.017779429177088395, 0.02747359961670424, 0.0558981898107699, 0.025611735148621455, 0.02378288480187101, 0.020193305631567324, 0.009810865740291774, 0.034879464988729784, 0.0039226478381481555, 0.04363725879894836, 0.03692902072465845, 0.053709402081689665, 0.03850744924108897, 0.05060133510934455, 0.060453880711325576, 0.049577551295182536, 0.0477837625491832, 0.06501378531434707, 0.03754961224538939, 0.03648311125912836, 0.03907785291916557, 0.028004030796832273, 0.028427285674427236, 0.029100053145417144, 0.06986444895820958, 0.024346587946638465, 0.03407971647435001, 0.037491346443338056, 0.06324964176331248, 0.02426953350992075, 0.03346280261342015, 0.07017992702977997, 0.03496360672371728, 0.05521018583593624, 0.02074419124983251, 0.03497168807578938, 0.028806064277887344, 0.02633929092969213, 0.05587108912212508, 0.0050407925487629, 0.02553721673653594, 0.06869593023189477, 0.04006574223084109, 0.048176783602684736, 0.058323083977614126, 0.04303907589720828, 0.048490578907408884, 0.0061663260816463405, 0.016068503127566407, 0.02146377254809652, 0.1382470317184925, 0.03928778486858521, 0.018778846798730747, 0.11114552883165223, 0.09615366400352546, 0.04938758184601154, 0.04512868555528777, 0.05288606769006167, 0.041594797146639655, 0.018902175627382736, 0.03292496183088847, 0.111741954327694, 0.05481306643092206, 0.024176297709345818, 0.054695513631616316, 0.05320985442293542, 0.030820102098264864, 0.03001415855916483, 0.07369144753153835, 0.05307945017037647, 0.03537842232201781, 0.008363416534848511, 0.02702650271489152, 0.019771236493917446, 0.05179188586771488, 0.040078512259892056, 0.05432761872985533, 0.005353810082721923, 0.03457581378253443, 0.040605910388486724, 0.0468362799978682, 0.015353023573490126, 0.012456389809293407, 0.07000773519809757, 0.05844643485865422, 0.026003119236390506, 0.04457943859909262, 0.05038040071459753, 0.01931105913328273, 0.006632430445668953, 0.03760590351053646, 0.015351814084819384, 0.04280522898105638, 0.08273468406072684, 0.03874488560748952, 0.026837288135928766, 0.0430393167771399, 0.055672200330133946, 0.01726663651477013, 0.06100769420819623, 0.029873101306813102, 0.07500762226326124, 0.01599601692786174, 0.013138937514408358, 0.012333323912961143, 0.06520752063287155, 0.004131412283251328, 0.05861171241849661, 0.028726146423390934, 0.008059224196975785, 0.01932312178957675, 0.0645300576995526, 0.028951416656907116, 0.016407388960942626, 0.056395980063825846, 0.006918501233615513, 0.05622263811528683, 0.03437670785933733, 0.04420651575284345, 0.017149467087749923, 0.013820737982834024, 0.030698420413370644, 0.011944761682700897, 0.040231124963611364, 0.03420280611940792, 0.017664456507191062, 0.013501207360864749, 0.05702771312956299, 0.01982389420403966, 0.05303067368056093, 0.021728441917470524, 0.042335879523307085, 0.025691893883049488, 0.04261379050357001, 0.02003054882931922, 0.014995075995102525, 0.17038422796343053, 0.02802176770221974, 0.07238391733595304, 0.04549190874344536, 0.04985884816518851, 0.0794102560196604, 0.0124285927740857, 0.05869633930602244, 0.024857029485117112, 0.014183709264865943, 0.10115042980760336, 0.004211691881729556, 0.043185300193727016, 0.02459519469578351, 0.021135526143812707, 0.05370875747342195, 0.04614436087597694, 0.015044271480292082, 0.04199669683086021, 0.028331580006384423, 0.04488996336502688, 0.051377290793295415, 0.025798018456303647, 0.02474328496360353, 0.01778651986803327, 0.027997893447588598, 0.07324408260839325, 0.057786159217357635, 0.00466706182175715, 0.08447864798030683, 0.01903532794676721, 0.013665004018028932, 0.014934740661244308, 0.022533114899748137, 0.04005100784291114, 0.0257133254116135, 0.0325972735216575, 0.005629436520393938, 0.06097803544253111, 0.05228696198069623, 0.022833987505042126, 0.03552484339369195, 0.0030631986321947935, 0.02369001880288124, 0.053887310570904186, 0.02096419096259134, 0.021715471720589057, 0.06100851523556879, 0.026852044576246823, 0.05908688370670591, 0.09363912857536759, 0.11712939345410892, 0.07746111668114151, 0.15678011652614388, 0.13889803178608418, 0.08374583694551672, 0.11977095742310796, 0.19328778396759713, 0.09560571983456612, 0.1452331468462944, 0.13377928574170384, 0.08769953836287771, 0.1180123710738761, 0.10199247140969549, 0.12570397263126715, 0.15088690418217862, 0.18035520506756647, 0.13957618682512216, 0.15582533633070333, 0.13615035851086887, 0.07044115622660943, 0.16961680485733918, 0.12139465101063251, 0.13368604145944118, 0.1959035907472883, 0.09643815338079419, 0.09353785043848412, 0.1855971866420337, 0.1676980299609048, 0.18434553380523408, 0.08127596947763648, 0.17036483543259756, 0.16579473923359597, 0.1715421208313533, 0.2119186728128365, 0.17588131156350884, 0.15669088917119162, 0.11448621457176548, 0.10357051994651556, 0.20693590518619331, 0.23637188066329273, 0.09539645963481494, 0.12525379178779467, 0.21185494480388506, 0.15259027135159287, 0.1326368770429066, 0.1240622028708458, 0.1650914376867669, 0.16192299127578735, 0.14599777438810893, 0.16211376818163054, 0.1779370555388076, 0.10649832391313144, 0.12796581483313016, 0.19494644924998283, 0.17921019079429762, 0.14892725433622087, 0.0995853209335889, 0.12877298652061395, 0.1599175538867712, 0.11302043643913098, 0.17870396295828478, 0.07382603495248727, 0.09904657769948244, 0.08645364628838641, 0.13898173586598464, 0.13693705201148987, 0.11076295721743788, 0.1708669513463974, 0.1952513557459627, 0.1477961771722351, 0.11262994632124901, 0.08575816146497216, 0.09771468131137745, 0.07377855107188225, 0.08156210769500051, 0.11200357707483427, 0.15865081043115684, 0.09491898811289243, 0.12565259395965508, 0.17833359140370572, 0.1345538470361914, 0.13483566977083683, 0.10954855595316206, 0.17798398302069732, 0.1816711558827332, 0.21534317119845323, 0.11770730172949177, 0.12228644958564214, 0.07015511978949819, 0.14222108918641294, 0.1621907954769475, 0.08847523959619658, 0.10175271784620625, 0.06797477642872504, 0.12704665772616863, 0.1327821785318, 0.24490852973290853, 0.1418054729167904, 0.0857033154794148, 0.06733834450798375, 0.13833357207477093, 0.10315201311771359, 0.1823967540902751, 0.15607511864176818, 0.12065757199057511, 0.2045914852725608, 0.15488110056945256, 0.20298466006559984, 0.10687257668801717, 0.12907645452235425, 0.10347120956118618, 0.12279189032103334, 0.1627501526049205, 0.131717570658241, 0.17388242882277283, 0.08179583586752415, 0.21554922871291637, 0.12486325417246137, 0.2250642031431198, 0.11673874727317265, 0.1099494547982301, 0.17162030163620198, 0.28104765766433304, 0.08437425536768776, 0.07985181268304586, 0.27744618377515246, 0.11319047731480428, 0.1556250327931983, 0.14713132141956262, 0.07465546258858272, 0.15022844022938184, 0.10385456149067197, 0.1464075009737696, 0.05919251125305891, 0.20203517244330474, 0.20301823397832258, 0.14143260435334273, 0.15543781141085283, 0.18340861265148434, 0.17862186022102833, 0.1253266664487975, 0.15979236417583056, 0.1379664032054799, 0.06881631591490336, 0.0773752752159323, 0.11825382097491197, 0.15702673686402185, 0.15705083842788423, 0.15664952567645482, 0.11160584698830332, 0.15036550430314882, 0.09289147797971964, 0.17197459191083908, 0.1226562104587044, 0.23066670394369534, 0.10873059555888176, 0.11025158608598368, 0.06371337973645755, 0.08565505806888853, 0.1291352835084711, 0.17092664885733808, 0.09789663047662803, 0.14431430186544145, 0.11263589028801237, 0.11994144613189356, 0.09041183960757085, 0.08891307788767985, 0.20039478689432144, 0.07976648690445082, 0.1187084394374064, 0.0734434701236231, 0.12665468161659582, 0.10452949348837137, 0.10257413876908165, 0.14267752612275736, 0.16289913175361498], [0.02610976288893393, 0.05037625486563359, 0.06104875236217465, 0.06304386923355715, 0.06313942732023341, 0.05500329711607524, 0.04296079670478191, 0.04465698158102376, 0.015301342953794768, 0.027791438990139535, 0.059096695323075564, 0.020204535386125957, 0.02604121219233743, 0.04723009493734155, 0.013941338252542275, 0.01749186433984765, 0.060351455850260596, 0.03182592848315835, 0.02236745736029531, 0.016673978584419404, 0.018530728594799126, 0.05275920878297516, 0.061074801321540556, 0.04357434842469437, 0.052307474094309976, 0.04828087765989559, 0.05154714507183858, 0.039138680190912316, 0.04850454994344285, 0.029908517442111458, 0.023274232899504047, 0.031228000032050268, 0.057875807264021466, 0.03648428512471063, 0.0663442499935627, 0.014136294085931565, 0.06862610897847585, 0.04119623585471085, 0.03192473335989884, 0.030879524802522998, 0.009195627860857971, 0.046113185584545135, 0.0317083281864013, 0.016729572654834816, 0.01322900879729007, 0.016954096499830484, 0.06082043211374964, 0.050706830341368914, 0.01757620963534074, 0.02183354359918407, 0.021640157726194178, 0.08555214466261012, 0.06463827046432666, 0.029563343285449913, 0.05455839866772294, 0.0267874700948596, 0.08492032677999564, 0.02698392464247133, 0.018716435147715465, 0.009692488520938371, 0.0792780706126775, 0.07631539673145328, 0.05015950703195163, 0.03181710752791592, 0.03202557384169527, 0.01697744658615972, 0.06145017367920705, 0.01697247801348567, 0.05349302404959287, 0.010619429272732564, 0.01603323287729706, 0.03827787370287946, 0.019028725801035762, 0.006274989648123405, 0.0471792149889682, 0.011534683955168086, 0.006621853356981384, 0.03181745358077543, 0.02520362177996763, 0.044010375027677844, 0.02218908068191792, 0.05136892445651548, 0.030815125043903078, 0.05256913076820118, 0.014571195168952857, 0.05901679103927953, 0.01568934115182076, 0.03170086769387126, 0.01070335557285164, 0.054180346096732786, 0.03813328128308058, 0.05541734936247979, 0.0423556011436241, 0.0125084029111479, 0.04963446681254676, 0.011267107063239174, 0.04891556913831404, 0.03436049087239163, 0.03422895007367645, 0.06802945278052773, 0.0453140206102814, 0.06470448869679656, 0.07991569675505161, 0.04127977369353175, 0.052155641705862114, 0.0337469730792301, 0.04019835850756083, 0.03585737644295607, 0.08839438536337443, 0.00815867622649031, 0.06171925352620227, 0.050870170683733056, 0.03049620001443795, 0.017656760223742043, 0.03718352224677801, 0.059531351285321374, 0.01298655042358275, 0.06354616835181202, 0.003498324267898819, 0.0021236479432055993, 0.013899956098092454, 0.015584461690325822, 0.017549565261495963, 0.0698990746002112, 0.042617278173565865, 0.028438018402084708, 0.011335328670351632, 0.020081272714638283, 0.007817600421341402, 0.04400499763765505, 0.0020217902950077716, 0.015694611672578112, 0.029897925510470356, 0.0425904014014772, 0.01726958474942616, 0.03879676300234028, 0.05643450388950961, 0.01602263585664332, 0.07039314308868987, 0.09294874633529357, 0.052666358051023314, 0.030714851138847213, 0.06453712124909673, 0.11153578824762787, 0.03492742045117276, 0.028385270786072527, 0.03719454165548086, 0.07987502536603383, 0.02331608663579183, 0.02184066143152969, 0.011973949714696832, 0.010864047932305505, 0.06007425393909216, 0.021807747394112603, 0.04318323066192014, 0.06995242780872754, 0.04362755235550659, 0.08211726469120809, 0.06335634139499494, 0.06630635381277118, 0.030219819130642072, 0.059949708836419244, 0.025477185047098568, 0.0141845972975716, 0.007292067415879241, 0.023450752088267888, 0.02845309205752398, 0.012469483838815774, 0.055501121295882125, 0.030403705513370887, 0.054627907795033286, 0.03994417928957513, 0.03878810150282724, 0.03123578961406435, 0.025091459941385046, 0.048623442849410434, 0.014526259187342865, 0.06844603256987673, 0.0687392343367849, 0.04170937117721353, 0.030429581446307044, 0.05856573488563299, 0.029690097019608532, 0.04872513149998017, 0.016349762678146362, 0.02539006623971675, 0.031065843733293668, 0.019052756118721197, 0.06849369965493679, 0.05270332803151437, 0.007558948809414038, 0.024510466028004885, 0.0465517770498991, 0.07364712562412024, 0.0354490612101342, 0.036631693464836905, 0.020919504342600703, 0.026746520506484166, 0.05351068970880338, 0.05585731825392161, 0.02842741459608078, 0.03721498591559274, 0.046347568543361764, 0.07252157173518624, 0.03766862728766032, 0.05421891063451767, 0.02601756524693753, 0.046377692105514665, 0.03680455365351268, 0.016680119326338172, 0.035713150432067256, 0.026487191207706928, 0.09995780951742615, 0.10994168557226658, 0.03344892657228878, 0.02136083708943001, 0.0186408378649503, 0.023155197501182556, 0.017118480089785795, 0.01502660582108157, 0.03719244498227324, 0.017501918532486473, 0.06352701330823557, 0.04493598500266671, 0.02674846620565014, 0.0071871056820132905, 0.015929171050499593, 0.08230096447680678, 0.050419691284852367, 0.05544600389631731, 0.032610705122351646, 0.031075268584702696, 0.06666786370000669, 0.053666203149727414, 0.04316957853734493, 0.02751613188801067, 0.01767694155153419, 0.021385713879551207, 0.00783406337723136, 0.047197752565677674, 0.046927091732089005, 0.039302295339959006, 0.05135113326832652, 0.06803921011409589, 0.03880269679107836, 0.029960401622312408, 0.002835312222097335, 0.02382212957101209, 0.0114874977818025, 0.024835620008941208, 0.044704183869596036, 0.0076032427272626334, 0.021793123268123184, 0.022427930097494806, 0.04522780255813684, 0.04602349343310509, 0.04213572187083108, 0.029110770606036698, 0.01819505732107375, 0.06475951788680893, 0.008484392543323338, 0.09978293747242008, 0.026310629610504423, 0.07047050965151616, 0.013960169295647314, 0.00936937184139554, 0.03083689244730132, 0.03885028923728636, 0.019448326767555306, 0.03885346478117364, 0.006647524881243173, 0.03295176735680018, 0.03409217776996749, 0.03313759774235742, 0.04011540420885597, 0.06850166565605573, 0.02625996509699949, 0.058717909934265275, 0.04660147295466491, 0.06872784851917199, 0.023863990092650056, 0.034236112010798285, 0.04712078633851238, 0.07471740605043513, 0.014685387523578746, 0.021275797991880348, 0.022488896468920366, 0.06741709528224808, 0.06803584458040339, 0.012087026727385819, 0.006805069262294897, 0.03223105460139258, 0.003181025814098705, 0.036749439646622965, 0.037140089220234325, 0.011051861336454749, 0.04630177082227809, 0.002260073345886277, 0.037687975713717084, 0.09565687458962202, 0.016970528921644603, 0.07008575993989195, 0.02524034070250179, 0.02541925342354391, 0.05257062354524221, 0.01760807533615402, 0.017444784187578728, 0.011606785086249667, 0.015548631648666092, 0.03908866537468774, 0.07683095442397253, 0.051483925964151106, 0.03374512067862919, 0.027464385111150996, 0.02014363686820226, 0.07044287292020661, 0.04309591677572046, 0.018017749335350733, 0.06375363043376378, 0.02498651432272579, 0.04676548165402242, 0.05458065461633461, 0.05409589223563671, 0.009039452000121986, 0.0180311198678932, 0.01810782485907631, 0.0320260623869087, 0.020661655946501663, 0.027982165005856326, 0.0760053333693317, 0.05232216437746372, 0.017119560656802993, 0.05191975239930408, 0.06302444956132344, 0.04116206822384681, 0.04899385172341551, 0.00925402682540672, 0.07942692762506859, 0.041428878371204646, 0.01069125983797546, 0.0457164970492678, 0.014737755159980484, 0.04229642949732287, 0.011186379207564252, 0.03467693246368851, 0.004653577210514673, 0.05387897476820009, 0.039762348867952824, 0.023885526794141958, 0.014575056033208966, 0.022312994747023498, 0.040966500860771964, 0.1675752829760313, 0.1963391966585602, 0.16728619991668633, 0.12426249283765044, 0.10968435795179435, 0.16970049536653928, 0.09149761777371168, 0.15740104392170906, 0.08139073010534048, 0.09084377464439188, 0.1429491572614227, 0.09361589553632907, 0.1369097749037402, 0.12676449572401388, 0.07631698450339691, 0.11189596820622683, 0.13375008159450122, 0.11682432410972458, 0.13603379976536545, 0.12645074113139085, 0.12982664283897194, 0.1980835066309997, 0.1546946255756276, 0.15061801432498864, 0.08563624229282141, 0.12068513408303261, 0.11701626809579985, 0.20308124274015427, 0.11485915098871503, 0.15611184095697744, 0.123148202630026, 0.06556578712271792, 0.17290901605572018, 0.16142930276691914, 0.0858820416033268, 0.12733366446835653, 0.21705986479563372, 0.15723192585366114, 0.13001385065061705, 0.14372920111886092, 0.07189938226448638, 0.15979605540633202, 0.06882665000323739, 0.07352510467171669, 0.09441904351115227, 0.1917723709983485, 0.11319462994911841, 0.11830443968730313, 0.08985679796231644, 0.17357532387333258, 0.056576765541519435, 0.14676302618214063, 0.156263371397342, 0.23108259162732533, 0.24508739156382425, 0.1577382351138762, 0.10490162244864873, 0.11094978504947253, 0.13200018049350806, 0.08078804851642676, 0.1614259643746274, 0.14479029418102332, 0.15182896863136972, 0.10266642631696803, 0.16472251819712774, 0.10195701116962091, 0.17307966761291027, 0.16142642577844007, 0.1461320836097002, 0.09595863268311534, 0.05566374578380159, 0.12276115268468857, 0.06361278013459273, 0.1304702197334596, 0.09396722739828484, 0.05008913277249251, 0.10012251710785286, 0.09936236789716141, 0.09402277906026159, 0.14186173704053673, 0.09588897427810089, 0.10470090500478234, 0.1033557296863624, 0.10926892488662686, 0.09825876461608068, 0.17834503150412015, 0.08647909813693591, 0.14311895386448928, 0.12782895431986876, 0.1080421403582607, 0.09305019410593168, 0.15233461292726652, 0.08872627719704594, 0.12310378572770528, 0.1308973032448973, 0.14053133342947277, 0.09528742584266833, 0.11583333728568894, 0.15539950132369995, 0.1432682994220938, 0.17021072655916214, 0.2634422523634774, 0.18919279798865318, 0.24060735053249768, 0.11382285159613405, 0.12017057383699076, 0.18800358394426958, 0.13522889438484395, 0.1561377609946898, 0.1193795105708497, 0.1389968671969005, 0.17983977629670075, 0.11418099594967705, 0.11709371608282838, 0.11695992254785129, 0.16235548949667386, 0.1287164781242609, 0.19274814506726606, 0.09091489189969641, 0.07049748141850744, 0.07835964632353612, 0.05091965284996799, 0.11368666961789131, 0.16706164553761482, 0.14461251800613745, 0.09774600248783827, 0.11238521231072289, 0.14059424719640187, 0.11772746779024601, 0.17892129772475787, 0.08975839681391205, 0.18198378410722527, 0.07214629437242236, 0.2191619255713054, 0.1881481661860432, 0.1685170895819153, 0.18640856524663313, 0.08731393369713, 0.16913718916475773, 0.25204237550497055, 0.18194444264684403, 0.09067393054387399, 0.16843574680387974, 0.15380881167948246, 0.0953655998621668, 0.14259797467717103, 0.12353447904544217, 0.18493413579251083, 0.11151381049837385, 0.1129640501790813, 0.0957738065293857, 0.0935171754764659, 0.08797494894159691, 0.13603354192205838, 0.12934172100254468, 0.14698912762105465, 0.11800521931477956, 0.22839800853814396, 0.19143361917563848, 0.20476090189601692, 0.12155293965978281, 0.30542617237993647, 0.20727802254259586, 0.1322825053440673, 0.11398407151656491, 0.13201067064489636, 0.11809481307864189, 0.11737317751560893, 0.13551404194108077, 0.16680965120238916, 0.18932531587779522, 0.19861025336597646, 0.1181865781545639, 0.18619683517941407, 0.08929458420191493, 0.09836927761456796], [0.07917439046182803, 0.01108129957823881, 0.00975126407242247, 0.049669326549129825, 0.026301026643653, 0.05975380899118526, 0.006585000847865428, 0.02478816666241203, 0.045380462759307454, 0.049393994001937766, 0.02721993947800781, 0.042294030876031945, 0.009309384256734379, 0.01849029299670032, 0.03080475702881813, 0.08230205013283662, 0.00275466897125755, 0.04643543543560164, 0.055103374245975695, 0.058747351568724425, 0.013368206015521926, 0.04753805484090533, 0.0752443563459175, 0.047790113636957746, 0.033612249951277456, 0.013786114037169941, 0.014526079375562924, 0.05231600667216948, 0.06558870125029768, 0.02722281137747424, 0.03363465178491814, 0.034039998427033424, 0.004709880350024572, 0.04683661926537752, 0.02355969088551189, 0.02988042269966432, 0.06515054404735565, 0.013371242459730377, 0.08356558411781277, 0.09174708117331777, 0.07078834223960127, 0.029006472988320247, 0.023376864713749716, 0.04514181520789862, 0.0186582083614277, 0.03719606835927282, 0.03687585072059717, 0.021784553370837654, 0.017409556345748048, 0.09307972394994327, 0.05814753339758941, 0.04956663027405739, 0.01225146884098649, 0.0443385722381728, 0.02177074857588325, 0.009881993173621595, 0.015131514120314802, 0.07854941899755172, 0.03128720560510244, 0.04004474835736411, 0.023515275679528713, 0.05266464814277632, 0.03225056587585381, 0.031397216487675905, 0.03194756945595145, 0.03274858004546591, 0.046494294955794296, 0.006581409701279232, 0.04882731208843844, 0.03448801813647151, 0.019731323367783, 0.03564982954412699, 0.027633170697039793, 0.037692023175103326, 0.10674997898084776, 0.03622029768303037, 0.0464626175484487, 0.0683898770117334, 0.043528655876538584, 0.047050303513450284, 0.009747695826393152, 0.05753928782152278, 0.029326768658523048, 0.07257441604243857, 0.04715974103393299, 0.036965281636055024, 0.013145416675667678, 0.06119399278291634, 0.033885438327810595, 0.10153378173708916, 0.07529960266713585, 0.0906253813632897, 0.019640613413814987, 0.02640479161137981, 0.03304049598851374, 0.06184024310537747, 0.005758995996854667, 0.008313068388296025, 0.06931886609111514, 0.060317705518433025, 0.05260765120120985, 0.04049765012626137, 0.09050126373767853, 0.02928710150133286, 0.05609156550573451, 0.032688380418611426, 0.08296005946717092, 0.024876086141115854, 0.01395921256127102, 0.03207082873476403, 0.022315681745697345, 0.02430225586119507, 0.026458904779117023, 0.021137946817491735, 0.04237770442185657, 0.026071792069290365, 0.052044165187648365, 0.02928809216246009, 0.04817606096288987, 0.04018789889024837, 0.03424465815935816, 0.0737951887505395, 0.038995828213436265, 0.02227428093153451, 0.049377057767872296, 0.005709004929355744, 0.05119887340281691, 0.02717408238511, 0.029827764989542108, 0.010047163016029766, 0.010606542196390885, 0.025327456117208515, 0.039285416781370125, 0.0036299774489764658, 0.02119464859632509, 0.042216786449509006, 0.040399310046008656, 0.0758436316890376, 0.026872772124728987, 0.025555610124553953, 0.0255104790641261, 0.018445784492152076, 0.04526489467493125, 0.014092271582090428, 0.03558095145438399, 0.04459488544879215, 0.006230814049818686, 0.024913802510127425, 0.0029416140626251164, 0.014625620462798646, 0.03527737149436559, 0.02015587255092604, 0.04891940286116941, 0.0169366174377501, 0.012037115387751587, 0.02587220268989248, 0.02611992564717574, 0.024523035889225345, 0.05552090059167572, 0.023697360551783016, 0.010941024337496077, 0.05757370990301881, 0.030690447626901523, 0.025023002543353608, 0.020359458501583765, 0.0510198012260454, 0.03526412649080157, 0.07037748928580966, 0.04318385830681239, 0.027356760975505625, 0.0045650445057877475, 0.013573371256435556, 0.028491726145148277, 0.0057221719013926175, 0.0460194731131196, 0.014057852893269487, 0.059396879215325625, 0.06988192802028996, 0.07931764277496509, 0.012951923933412348, 0.031590948413525305, 0.06098841702831643, 0.006858106952027551, 0.0303397400171629, 0.005747458781115711, 0.1290683935263327, 0.03080669085362128, 0.04008624755910464, 0.044657246209681034, 0.025881848065182567, 0.03182481907840286, 0.02475949516519904, 0.036480984051844904, 0.05145027741257634, 0.03771507979503699, 0.03276453579642943, 0.026000668028635637, 0.03548844338261655, 0.04331378419218319, 0.06324726689074721, 0.03573186442788158, 0.026791548090321676, 0.029028043616563082, 0.07535171415656805, 0.01299817203211465, 0.059389679958777766, 0.029115632309445312, 0.004677668596351785, 0.04370579083583184, 0.07566045437540327, 0.03420878401292222, 0.03993018450481551, 0.043049009649881294, 0.015518518264538475, 0.0648419191794736, 0.03114095755985805, 0.03018342929759196, 0.012237405354556228, 0.039949146165911636, 0.023233181530875818, 0.06433920615485736, 0.06229778605380228, 0.01907367704968367, 0.028159934395392026, 0.03043847025505134, 0.07259666520570006, 0.0264237736285265, 0.04243823313819511, 0.02535993419587612, 0.02748380647972226, 0.04950175554092441, 0.052589585206338336, 0.015141176458980356, 0.02262984006665647, 0.03506695778508272, 0.04088136846465724, 0.022292994927348833, 0.012511765900334077, 0.06452456156590156, 0.019787614632930075, 0.07274362910538912, 0.043093999914292774, 0.057994896945144446, 0.042958767885076146, 0.024273884615727832, 0.051472743707043786, 0.042776218216334067, 0.052563485356846025, 0.01988917775452137, 0.022171684740377322, 0.08478052142475333, 0.05170752700152142, 0.012918847047590783, 0.03175381378137639, 0.0068733460003776205, 0.023716851470193694, 0.02145493123680353, 0.018799175707889453, 0.016070621853162135, 0.04431740873094116, 0.0013011169794481248, 0.022138804629711167, 0.01873335102573037, 0.04217533813789487, 0.01698986716967608, 0.0053085615509189665, 0.00483776638949556, 0.061911326433931074, 0.019280448722253953, 0.022274927236139774, 0.0273642045046602, 0.08000539908451693, 0.004395306850450912, 0.015701283368148973, 0.03419563400426081, 0.015586312394589186, 0.043402078561484814, 0.04528100988162415, 0.03331174375489354, 0.059007576533726284, 0.013871320223967944, 0.026074036323864545, 0.05745884070971182, 0.027024032847423638, 0.04094922535919717, 0.004907827250592942, 0.022566035722515414, 0.018256915966048837, 0.014694062593792166, 0.0404593298610832, 0.00671383089918111, 0.07918644124375922, 0.046009223841662915, 0.049857528414577246, 0.0324606708517032, 0.039318312159074206, 0.051759021024086645, 0.02884198592177459, 0.01894861626039658, 0.02448533648358924, 0.0369889387594802, 0.02161975926719606, 0.09112927503883839, 0.027197189895170074, 0.029990735530321087, 0.06139903249485152, 0.00803212435649974, 0.014734772998573524, 0.06158174161932298, 0.012424159395907606, 0.05305340460368565, 0.05246507063774126, 0.039540925927992375, 0.040223040218864164, 0.025968890537374785, 0.0660993599199823, 0.04170811588742903, 0.03505603676395757, 0.03255393888269152, 0.011572300240264406, 0.02573167299851775, 0.006867027567100844, 0.03497110453567334, 0.025096681268353547, 0.03416967325444732, 0.021674544184601734, 0.027615323529711792, 0.0518550337292254, 0.044171689943011315, 0.033245583197900226, 0.03660149187115686, 0.014844700760607208, 0.027309404320216606, 0.045302845138524256, 0.02029759476759604, 0.07753153504537684, 0.01624343284804906, 0.034387343895754645, 0.05408403144351073, 0.02156487087320004, 0.02565307998364525, 0.05957562569528818, 0.03642363427206874, 0.05514865967312029, 0.054098294249602726, 0.04019764943846634, 0.051039139474076886, 0.06574157518999917, 0.03839612878592951, 0.029652387435947145, 0.05169260262378624, 0.01242300249370081, 0.1622701162206275, 0.16981967325721467, 0.18696071633270808, 0.16692295297980309, 0.09059830781604562, 0.13505409019333975, 0.06797299188162599, 0.14037514823888028, 0.0767851397395134, 0.20583750626870564, 0.10115386319479772, 0.14976200168686254, 0.09198262781969138, 0.10321902523615531, 0.133222262774195, 0.13139143958687782, 0.11931798101535865, 0.15671224945357867, 0.11354988374348197, 0.11458943331880228, 0.07274478261492082, 0.19117399810680322, 0.15478060953319073, 0.20640340447425842, 0.11273373503770147, 0.1669351937515395, 0.07944552626992975, 0.12301804604274885, 0.08408765574651104, 0.12189728261104651, 0.1609434988349676, 0.08322294428944588, 0.17549415305256844, 0.14615861432892935, 0.18938110502702848, 0.15968910471669265, 0.1917975717889411, 0.08574606997093984, 0.14571504241653851, 0.16333656970943722, 0.17536357577357972, 0.11941085888871125, 0.09856337934200253, 0.17445095974419797, 0.1296281034925154, 0.12461436752762113, 0.07345062188271965, 0.17523538693785667, 0.10947591199406556, 0.18871863771762165, 0.12689153105020523, 0.09685696555035454, 0.11230418844414608, 0.14047426863440446, 0.16359157674014568, 0.16466161289385386, 0.176969138905406, 0.11062188978706088, 0.1880446353128978, 0.14035074811960968, 0.1323982769889491, 0.14501354577285902, 0.10525759549013206, 0.12698511459997722, 0.13692274849329675, 0.08832482873861279, 0.1576845765646015, 0.09870156978390046, 0.15248701189245495, 0.18149055700216973, 0.10220996902457305, 0.11164773295500449, 0.10460285669458763, 0.13416869698890618, 0.13214291712003096, 0.111843870287495, 0.15255126915872097, 0.2228646097438676, 0.099223614271198, 0.12838600442877837, 0.08541430027357169, 0.1721336812313114, 0.08847715985029936, 0.2140805668064526, 0.11654254208718028, 0.14396303785698755, 0.08920945519847528, 0.12558085923748358, 0.0890701858858977, 0.14464620048446314, 0.1639612561890057, 0.12131785441722188, 0.1155706492385694, 0.07865807959543807, 0.10979014834655182, 0.1243933415306466, 0.1177889702043363, 0.10633811500987836, 0.12156129921121256, 0.10470415518752166, 0.09267409571579524, 0.09862428464527641, 0.1324920505285263, 0.15944867261818477, 0.1626759615859815, 0.12178822846284934, 0.18755800356822355, 0.09159825130232743, 0.0849763262750847, 0.13283434430403368, 0.0989093372066106, 0.10635666615728821, 0.1131530153964247, 0.16452959712062562, 0.1042090349697641, 0.15431672228234156, 0.15918536031884806, 0.10748924288366522, 0.1197237992393119, 0.11349030158349446, 0.2247593780713422, 0.11976608554167406, 0.10322089120745659, 0.08484480583242007, 0.07877405480082546, 0.0842809093051723, 0.19167022433664116, 0.08978917516235795, 0.1394475501562868, 0.09905119173760925, 0.059076759964227676, 0.037473629894001145, 0.12849645635911397, 0.056923700496554375, 0.11784166523388453, 0.09406566925879035, 0.1833676698484591, 0.1249356810003519, 0.0779911135988576, 0.18515282762902124, 0.08590255371694054, 0.10307657359434025, 0.16677074400441988, 0.07597368649606194, 0.1287954053176301, 0.13584269716271333, 0.16670149272041662, 0.24849086893456324, 0.10288426319935493, 0.09948105724262339, 0.1180219655590398, 0.12108880813632693, 0.13290135642247541, 0.10932820170585598, 0.11145567361797605, 0.14950536617210933, 0.1693461372384003, 0.10333846775548798, 0.1392039018017905, 0.11000702849456243, 0.05719268534864698, 0.21656666483197892, 0.14577487563448294, 0.08620204550347157, 0.11901406518050603, 0.14063759201339313, 0.08053593204489776, 0.16089602852506296, 0.17875713296234608, 0.08573397847690753, 0.08309699461928435, 0.10497265149440084, 0.06854504439979792, 0.1286356917449406, 0.15288772753306798, 0.13829523484621728], [0.02586906446543123, 0.043170596339872906, 0.07295160008860485, 0.008773965844219285, 0.0064188339830642295, 0.02599866295765553, 0.010498644102231731, 0.04216087855664747, 0.058645564530576975, 0.011098838012133325, 0.016352507352296795, 0.02680595338876758, 0.018377023449699794, 0.05336787844342845, 0.037967545712100606, 0.01776111382059753, 0.02729766396805644, 0.015193762922925609, 0.01399133525722261, 0.016438221592190008, 0.01854605500453285, 0.03309689921193889, 0.020532079506665468, 0.019878216021295105, 0.03945967475218432, 0.024183396881978427, 0.00674497608062146, 0.031156574043312242, 0.05023426802030631, 0.07848873761083398, 0.02708972691159163, 0.024098108422809413, 0.021653971002836312, 0.15739698628229754, 0.0534496317351503, 0.0656038529372641, 0.04885645516748939, 0.04738153038280351, 0.03228533061753426, 0.0035122416572578785, 0.028943684750369618, 0.051966584886291196, 0.03462272430104869, 0.04840636931891952, 0.029506156354078224, 0.01994194572658411, 0.008972941997594066, 0.0044848085880013445, 0.024279954111469642, 0.024959052314183543, 0.040814369916915894, 0.04877339908853173, 0.046238782416496954, 0.017542863031849265, 0.02268266910687089, 0.01021990955008992, 0.05967028133038964, 0.030389239146773304, 0.029180334016148533, 0.010795247874089649, 0.04564753414264747, 0.06449976111096994, 0.05224242294207215, 0.06914470650787864, 0.02933443271155868, 0.007102627648107175, 0.029737407873783792, 0.03334147037406053, 0.01974606793373823, 0.004165872108257774, 0.05016999379066484, 0.050683017154889445, 0.003442005649308807, 0.037030631343701055, 0.017231256002560258, 0.025532685818948915, 0.06815067306160927, 0.024919419083744287, 0.044006615943674526, 0.020566460876060382, 0.026146551361307502, 0.036688988961811574, 0.017179694126493165, 0.047832671353327375, 0.04317357510860477, 0.032066367367016416, 0.03442304501576083, 0.027750623412430286, 0.01726011579324092, 0.01893124746025673, 0.049285896588116884, 0.014187457322675203, 0.051215528044849634, 0.010329805929878992, 0.013002442561888268, 0.037250612396746874, 0.003689512111512678, 0.028234714043459723, 0.021675553505441973, 0.027330856204831173, 0.05096835130825639, 0.05125638942367264, 0.02352701603168888, 0.0169840351611908, 0.03079656032579286, 0.0501262384599873, 0.04336974976052131, 0.08182429362620626, 0.03770675417035818, 0.008002398585501527, 0.044471595635903735, 0.027058012184820006, 0.020744082684229528, 0.00632898704082306, 0.034496951049992015, 0.05476249860865729, 0.03906434328694429, 0.047659702599048615, 0.0375718987280769, 0.03177636828539627, 0.06125278105693204, 0.07055616791227035, 0.02487580624542066, 0.04642840242013335, 0.04381025130195277, 0.06009121052920818, 0.04857772994520409, 0.005169975862372667, 0.012689246912486851, 0.03223109531349369, 0.04639455030805298, 0.01843163025166307, 0.05977710988372564, 0.026763305766507983, 0.05766211623059852, 0.03966689595420446, 0.053598634632570405, 0.039370538999459574, 0.06661641717489276, 0.05346747720614076, 0.05074299286518778, 0.036513889607574256, 0.03973364683666399, 0.03044473652594856, 0.01509663402768118, 0.03808126139587589, 0.03746337044451918, 0.06925961641328675, 0.053475012337522845, 0.03264404833316803, 0.002438165887724608, 0.03236002714506217, 0.04334524107564773, 0.019793282096673335, 0.0018567536150970096, 0.024061837333387563, 0.015141190029680729, 0.03178187120439751, 0.031178378766136508, 0.049068249695535214, 0.04549504018255642, 0.024674734267007028, 0.009346770688093134, 0.033059250696429184, 0.05443274416029453, 0.01731919583731464, 0.004600710850874228, 0.04004226831187095, 0.044702965899237564, 0.0725144131907395, 0.05156656813674739, 0.02086983897191073, 0.006989819504919329, 0.007836719841829367, 0.04232597630470991, 0.021750636797930514, 0.051917045044579675, 0.008824630357724215, 0.036972823552787304, 0.044196890733603916, 0.01658966382300215, 0.05516137541936977, 0.015785664286730543, 0.03236013571066516, 0.017166243866086006, 0.007050994101778737, 0.059910720214247704, 0.03511715241308723, 0.03130072541534901, 0.02862793526479176, 0.020122816021155034, 0.04881827060931495, 0.03299816218870027, 0.0393364392220974, 0.01836297438213868, 0.01969149675486343, 0.017066660370411615, 0.023364189679601362, 0.06372855856482472, 0.058121192668165476, 0.01534613305037575, 0.05904149649930852, 0.01117110877696957, 0.010134620242752135, 0.07181805984250136, 0.04866051800282938, 0.03687748259731701, 0.07847732465182032, 0.08598802877323967, 0.04577617420415793, 0.01935891281547291, 0.028244216926395893, 0.04216143834803786, 0.02234475697124643, 0.04992852692625352, 0.015954078374696628, 0.047566051195774756, 0.017561919687848006, 0.06347217410802841, 0.058944214933684895, 0.04469338837744934, 0.008643427580994154, 0.04318474379501172, 0.04116552535976682, 0.010810668430557209, 0.05583591725943344, 0.047359559418899674, 0.030885163428527967, 0.0434980234131217, 0.018409186009583727, 0.029977673731212105, 0.015449197430695807, 0.02443122840486467, 0.015339364663564732, 0.05819583830556699, 0.01947969544146742, 0.010062600535872792, 0.026598487914140736, 0.037941652815788984, 0.07812840158918075, 0.017443123473120586, 0.06414411376629557, 0.021946870821661184, 0.04429255060053297, 0.017396235006994436, 0.007833972623172616, 0.030991812170084034, 0.01790664770773479, 0.024632756698078344, 0.0530538795781987, 0.05438134513263192, 0.021438459799225842, 0.03881080189187612, 0.02427570817859045, 0.022898455117163912, 0.028560203899230276, 0.004622966799485896, 0.032681656136576615, 0.004740555645964507, 0.029887146981699125, 0.055755636388702054, 0.03884080671040075, 0.051489259249397686, 0.07032007843788181, 0.023372247282947813, 0.00655715207436255, 0.0003643819722388538, 0.014856515751619424, 0.051370183138975074, 0.019446262324761068, 0.011207935416937938, 0.09825465269386768, 0.04592999130753534, 0.05023423070088029, 0.04282840773729341, 0.03700039243059499, 0.009327169507741928, 0.018876223359256983, 0.022624822300193564, 0.012647148055423583, 0.028988491810326065, 0.07551667959030185, 0.020509640353598764, 0.0644322604473148, 0.04352726487975035, 0.012933212482104344, 0.007854588213376701, 0.030607299945716347, 0.025811022579936043, 0.047056379794542275, 0.06219306095902409, 0.034704419917293956, 0.04990572814962693, 0.04603481478989124, 0.03772463696077466, 0.02215879427136055, 0.026957824792979018, 0.025488869420119693, 0.039741158219320435, 0.019503869947844317, 0.10005955584347248, 0.04174669399591429, 0.014493139893082636, 0.04737512840490256, 0.034259850558425696, 0.00745485899304705, 0.049773454533091614, 0.029775198881647418, 0.007280353356951049, 0.03987636649981141, 0.07825902636562075, 0.02102918443935258, 0.01961330577198948, 0.011911235267429479, 0.07893028070351907, 0.04564856890855091, 0.024671275434749465, 0.0729292423597404, 0.031178989447653294, 0.030010138239179338, 0.020751332830903784, 0.04312153486534953, 0.015367084515414067, 0.04790078948384949, 0.0625734409051282, 0.07753485308161803, 0.01729215452048395, 0.09133081351007734, 0.030961033821638142, 0.07575252479208366, 0.05133132004578199, 0.023977358027228286, 0.01886198090921555, 0.04002556956506201, 0.015000860506136502, 0.01669452801745917, 0.09533402084239892, 0.012612973639209355, 0.0051165229940254775, 0.04947578800576074, 0.029426984888102328, 0.024225959687360694, 0.06419779267162085, 0.006811262166593224, 0.047276832429426055, 0.054201000702700446, 0.022234759659373333, 0.05220108658873609, 0.0634571716987661, 0.007658644263366503, 0.05492699585322823, 0.02329625644987183, 0.1488881300070456, 0.17932624742388725, 0.21190168229596956, 0.13262926387999738, 0.12271194532513618, 0.19837527668901853, 0.09485487333898034, 0.145186667197517, 0.10609340135540281, 0.15409387781151704, 0.1585432897721018, 0.14583310750978334, 0.19370335952511855, 0.17542891869587557, 0.12760252718414578, 0.09439189532505614, 0.2478223219513893, 0.09624060469546489, 0.07247207939092602, 0.14236948479499134, 0.05484348176313298, 0.14026167004236154, 0.11709093408925192, 0.09449583331921271, 0.19716285674699716, 0.09705456173313515, 0.07822136767208576, 0.11463588582617895, 0.14091459714940616, 0.1536514458379575, 0.10722931647407156, 0.15500406468553202, 0.09728904986487967, 0.3018042610159942, 0.1315922045281955, 0.13850060025496141, 0.10625731505985771, 0.20388290472328663, 0.11728130387408392, 0.09401448057698351, 0.16275274460869177, 0.11918359036956515, 0.19016600719520024, 0.12670150053288254, 0.06546102131583861, 0.13914452998765878, 0.15269153591777596, 0.10053954473031418, 0.0934314290061593, 0.16538389985050472, 0.2041760997048446, 0.08473155155245747, 0.13199612285409654, 0.10955460170017821, 0.14415295980870724, 0.08050696538495165, 0.07084125440035548, 0.09716177026608161, 0.09899555186608008, 0.11478514995958124, 0.10207137824701411, 0.19828072961952004, 0.11190544734043734, 0.24439547583460808, 0.0715164170999612, 0.09213210908429963, 0.1313548529786723, 0.0892156705792461, 0.08578135379190956, 0.08290718123316765, 0.18975062162748405, 0.14340106158384255, 0.06142462005040475, 0.12648056953081063, 0.07863850386015006, 0.10151546129158565, 0.1244435938341277, 0.07005396378891808, 0.14066273852118424, 0.14598942840737955, 0.055226284079253674, 0.13687502034008503, 0.08578385758612837, 0.23064379660146578, 0.11534192865448338, 0.15196481134210313, 0.07813061361334153, 0.23381944905434335, 0.10081971183951412, 0.08654136729559728, 0.14834488130041532, 0.09650563368839876, 0.10498213741396155, 0.12212585391742842, 0.14623834219362053, 0.24065978771873883, 0.1943909597716161, 0.11120947397180966, 0.11945579147764615, 0.16671751971755708, 0.16256423400981085, 0.1098651671782136, 0.061917372180947235, 0.1414250861853361, 0.10250270260231835, 0.2441652353320803, 0.13383005373179913, 0.28139305913022583, 0.11689067126384803, 0.09832002954291445, 0.18957040272653103, 0.10997137147933245, 0.07796784663306815, 0.14830107507961138, 0.09734764136373997, 0.21094851701387338, 0.130719730630517, 0.12007745169103146, 0.16656300372311048, 0.09748486828591142, 0.13743050981845173, 0.16898948566189834, 0.20345316135457583, 0.10809623316994735, 0.16977806548987115, 0.15508071200123855, 0.1237445127751146, 0.08765921302671943, 0.10807722061872482, 0.11606260069778987, 0.15520515532365867, 0.08363381081393786, 0.1257860753685236, 0.09426335365112339, 0.11848467215895653, 0.1065022119187883, 0.07707968500575849, 0.1393124402633735, 0.17505987706993306, 0.22705777974000999, 0.11468749519969736, 0.13721588919205324, 0.16377730534545012, 0.14877645671367645, 0.12703776891742433, 0.18270809309823172, 0.14171555345611914, 0.10768949213836874, 0.1820369405405862, 0.16718006346906933, 0.2319849617779255, 0.1767620500177145, 0.11919663181262356, 0.10056899993547372, 0.18236312589475087, 0.08219817999218192, 0.07512840828193085, 0.10304935755474226, 0.08069655485451221, 0.09494371392897197, 0.14706173086805002, 0.1466153905327831, 0.048385236345763714, 0.10779411545289413, 0.14713151140936784, 0.08699312234031302, 0.07581655135644333, 0.1051568126838122, 0.15553163923323154, 0.15477387846580573, 0.15274884498545102, 0.19479657443506376, 0.09168815719229834, 0.07648463015045438, 0.13098905475011893, 0.08442668576857873], [0.015194052996646081, 0.047891995670007806, 0.05589227298540728, 0.013102542592345603, 0.04855289217084646, 0.036145821679383516, 0.016162619327328036, 0.011313370428979397, 0.05578713059159262, 0.06976159662008286, 0.014528713787772825, 0.03145523462444544, 0.01107067202350923, 0.05278016194435103, 0.0708162910970194, 0.03766129571678383, 0.05562443485749619, 0.017315065255388618, 0.020079730743808404, 0.11628788789468152, 0.020743280316569974, 0.04443650859008942, 0.021724458916911056, 0.03260847952749048, 0.014493642008996435, 0.01940803026913532, 0.05430705572611519, 0.009362944418431392, 0.03836009179108909, 0.0347816100610154, 0.02239982008800975, 0.03034224720405681, 0.03382959828845092, 0.05240001609282834, 0.009359384654089808, 0.03544252013255443, 0.02837897907011211, 0.08221913993890796, 0.02656113795403923, 0.04080631570624454, 0.03543267798210893, 0.010286968317814171, 0.019266509916633368, 0.023679192776658704, 0.011308122808778924, 0.015367466191362058, 0.030971137208065817, 0.02069717555839036, 0.02407493645192257, 0.0015447138076914208, 0.07866120764187404, 0.02249782598976578, 0.028010566785399402, 0.00949149118137679, 0.04185491015336343, 0.03970209835097194, 0.056777218356728554, 0.026657917403749058, 0.06038592542920794, 0.04114386312929647, 0.013311641640029848, 0.04676037567800709, 0.012748460967226751, 0.02350384575713958, 0.08816366310098342, 0.05641084676608443, 0.01514846901409328, 0.06715591358286993, 0.021352396113798022, 0.014121984630557043, 0.04961317777633667, 0.009820232916224216, 0.007970503198781183, 0.026604491252718226, 0.01381694242757346, 0.043741247683231316, 0.04104374867996999, 0.016452311371852244, 0.02487490718652095, 0.009111211319187922, 0.05167647384639297, 0.03566235190789614, 0.026402192822258388, 0.03842278164146202, 0.025942081618787985, 0.08461135585925408, 0.019074616820684502, 0.0486987127390291, 0.02841860381886363, 0.02406306378543377, 0.029765295663050244, 0.02646074191268001, 0.027569396886974573, 0.07175655742841107, 0.04247069425348725, 0.048367635147379975, 0.03857336552547557, 0.023610465660957352, 0.05170992223013725, 0.006525250750460795, 0.03600786533206701, 0.009036049147003462, 0.027346036729535887, 0.03525907479758773, 0.039394443788166554, 0.03816207491659692, 0.0313874286200319, 0.07240700109728745, 0.02101898775435984, 0.05186987329008324, 0.09805406417165484, 0.06300841577883277, 0.036644337964909415, 0.019961935368233492, 0.045529075499091826, 0.06210599813078131, 0.014674354544175523, 0.06847686520112412, 0.04633888668779816, 0.043541768565773964, 0.032993198705038855, 0.026702844903671315, 0.039177024204816134, 0.029931326396763325, 0.003948427928012929, 0.041404169518500566, 0.027272924581276517, 0.04663376782887748, 0.031152909954211543, 0.03656911896541715, 0.031917676595704894, 0.01764581206121615, 0.035037858810807974, 0.020599434285291603, 0.008520097904173391, 0.05736317405743258, 0.012716909937028373, 0.05521771418196814, 0.021963642510984625, 0.035840752334999185, 0.009279443899036517, 0.023225108660491448, 0.055542539073420424, 0.0456265843739467, 0.011860195015157973, 0.03670613214905773, 0.048714604029165845, 0.058545609536979876, 0.017619834348027195, 0.06110207164394004, 0.01214707113935479, 0.04868903343698808, 0.005684709558928651, 0.004957038426904806, 0.033354912152779956, 0.03731052025354334, 0.04360921833930271, 0.04038172581100038, 0.04209517940346684, 0.03781782017488565, 0.016007570682891777, 0.021560831893501536, 0.013614405661688318, 0.02384342539257237, 0.028184706012585332, 0.0509149268535631, 0.03343278083152004, 0.02828019454942218, 0.03842533632580723, 0.029298429643469195, 0.023541506147012115, 0.04232132833983217, 0.04956055399296539, 0.05675421262692128, 0.04368129911433373, 0.014623805381623762, 0.05347442201205662, 0.017146274580487182, 0.054272925414677174, 0.019526248032759343, 0.01237914283826415, 0.05228070928049939, 0.0230625248846731, 0.010542982973025312, 0.05460087495989033, 0.01292042464150914, 0.006307707334469471, 0.03647118939885071, 0.03846140724739858, 0.01760792775478746, 0.10104188456067018, 0.025044049003294537, 0.06233932596764394, 0.020533762273511717, 0.027704036894387433, 0.06824210565537214, 0.031201906967908144, 0.024245133390650153, 0.0320594971999526, 0.009939464241532343, 0.031996902344482284, 0.06983191320406539, 0.06410944741219282, 0.022857447853311896, 0.06422519191567387, 0.003979703303359981, 0.04382987114201699, 0.034853460134140084, 0.07448833941348962, 0.03867841631706272, 0.014130526538273054, 0.07089759994830404, 0.013994154570225095, 0.03949319098943046, 0.006182024413387158, 0.06760867285941329, 0.01803458039648831, 0.06116855450506721, 0.06256749015301466, 0.052723494092268605, 0.007833817408287098, 0.009465203038416803, 0.034643372121666155, 0.022430153996018425, 0.056800532819969315, 0.02432303429980363, 0.05090803972312382, 0.04236709552684, 0.07141790738595383, 0.040872964808451276, 0.018002477208418504, 0.023515345229368125, 0.011183276606191481, 0.019742933101952076, 0.064058550500444, 0.038121118542871306, 0.024072464888117144, 0.04107434382396085, 0.02020410112371402, 0.039815440840486965, 0.05928065973733153, 0.06065662697489772, 0.048103427181818655, 0.027110613915803175, 0.046337037679872344, 0.03241424887840237, 0.02066461435918297, 0.022575715024556433, 0.04037718641172562, 0.05775297885494573, 0.033923918048718145, 0.011323308422496276, 0.056672008109412024, 0.04706393867465002, 0.03651520596551044, 0.02597456139379314, 0.02216713685941483, 0.031280382935489924, 0.06178659812680312, 0.02959801981757794, 0.06701048995767321, 0.030945206992328167, 0.02493299656946744, 0.03556429681235126, 0.05437758944130369, 0.08283797066126551, 0.08127594912158591, 0.009771504772028752, 0.02111311922115939, 0.05324169807136059, 0.05072006855958274, 0.04085687335048403, 0.0497429374206279, 0.05277305768270578, 0.03914354189432093, 0.0435243811059211, 0.024776670582858578, 0.0751838106662035, 0.049446539753781896, 0.03443736210465431, 0.04902619748775448, 0.013429984932632318, 0.022110502934083343, 0.0919647009244987, 0.03307626835469689, 0.01822258039776768, 0.02378124274712588, 0.03347244120336004, 0.01550838434403496, 0.025926775565104823, 0.042037917833243094, 0.04187069966324738, 0.010133683016257626, 0.04740920104086399, 0.024354335120213882, 0.017466811130621603, 0.029183692764490843, 0.01853136981039175, 0.03627814279337015, 0.01505633583292365, 0.00844547092648489, 0.020171711254598837, 0.010896298701741865, 0.02599713795020112, 0.04084534504051719, 0.08822420878069741, 0.05507582911689367, 0.007526022897634123, 0.042429663240909576, 0.013066571754669505, 0.013458135654218495, 0.04193672451323696, 0.04727965174242854, 0.016166091730285968, 0.0656503461567419, 0.04118223428460104, 0.037391316810888905, 0.012886676854187889, 0.031073758844286203, 0.016986650913687687, 0.017676829593256116, 0.051472306051956754, 0.09248039432402168, 0.038663597112255435, 0.012416458023445947, 0.051466623321175575, 0.011315423845579582, 0.0193795759031283, 0.0955048148919429, 0.013198618910142353, 0.03589675183008824, 0.05813700931945017, 0.07943622355482408, 0.02126104155156229, 0.0474316368012556, 0.03808169565828783, 0.0351836386668895, 0.05617043502362711, 0.028242213551753333, 0.03044933020802481, 0.047268900355058055, 0.030564450459288697, 0.051504410936364105, 0.014452841698325105, 0.023396382773561136, 0.03717215678521565, 0.04846890989158835, 0.01698777049646846, 0.025034802267327905, 0.02908550196194223, 0.026110368481438075, 0.08121925752077784, 0.11203694064170122, 0.14286218264273234, 0.14519247545727662, 0.06595806178769895, 0.11908463282244545, 0.16146773499037537, 0.13104576670697757, 0.06254848438714232, 0.08467226794787816, 0.08813541568815708, 0.10734518989920616, 0.10433018061199359, 0.08954384404101542, 0.09654654256467309, 0.19738131788160118, 0.07521534897387028, 0.19429414639515535, 0.10272813229156391, 0.11741116190595285, 0.2731755386505808, 0.11022788485778229, 0.14430026976125582, 0.06250779264207397, 0.161715033863272, 0.09436372255108186, 0.14516709824757917, 0.1307797809796674, 0.11550721978502614, 0.13515838102570601, 0.16876300424337387, 0.19717163699013845, 0.12430621763425213, 0.16959403322211333, 0.11993657425045967, 0.09209810769451515, 0.08790600978370224, 0.16310100949236325, 0.2669206400002752, 0.10381462970482451, 0.18258704245090485, 0.09434031309293849, 0.12455555211220469, 0.09566366672515869, 0.12323900418622152, 0.06453887186944485, 0.11432678598378386, 0.20799448766878673, 0.09940794509436403, 0.11397854824151311, 0.09055501728185586, 0.2825203500688076, 0.11784261518291064, 0.09887049786214318, 0.16758867725729942, 0.12974521863673413, 0.09702518795217786, 0.2029596764062132, 0.10699671466967889, 0.1764498289142336, 0.1222208488200392, 0.08875453139522246, 0.08907723586474146, 0.11761147901415825, 0.14163608343473502, 0.21028110996953078, 0.19443522739623273, 0.13432841056159564, 0.17443390137382916, 0.11791812255978584, 0.16207976000649588, 0.0856056675048811, 0.15066988154181413, 0.10479128586926631, 0.1437506563961506, 0.13296612937535557, 0.07586050685495138, 0.14750589989125729, 0.1592018080077001, 0.16270178662879126, 0.1457454136439732, 0.15974523313343525, 0.11504584311374597, 0.21169519051909447, 0.138662865119321, 0.16945622275982583, 0.21428035465734346, 0.10434195997991733, 0.2921288130538804, 0.08252994968955006, 0.17889896035194397, 0.13513147032686643, 0.06639941489057881, 0.1054649150797299, 0.1678729291473116, 0.1491259429603815, 0.1333403414381402, 0.17131984632994446, 0.10466602151947361, 0.13239791058003902, 0.1377028330628361, 0.13211200306458132, 0.13210012870175497, 0.10624764593584196, 0.09467514976859093, 0.11209319798009736, 0.09274196278836046, 0.14261894140924725, 0.12280574600611414, 0.09049681933330637, 0.09865580938224282, 0.19209965557924338, 0.11723657484565463, 0.08210162445902824, 0.05102997925132513, 0.11722113138863019, 0.1340854950249195, 0.0814100004998701, 0.22054596059024334, 0.13092515032206262, 0.15087576263717242, 0.11484247259795666, 0.12680121803922312, 0.1468723246029445, 0.15605723245867661, 0.06038116889872721, 0.11928955039807729, 0.2181031530989068, 0.13043667296213762, 0.1185828833175557, 0.17622912861406803, 0.16533763733293327, 0.06268096156418324, 0.16149079161030905, 0.07959422043391637, 0.07599330972880125, 0.1323284285941294, 0.06843935578529324, 0.15137585651661667, 0.07397882068263632, 0.14819606500012533, 0.12505982576736382, 0.07701789082161017, 0.10035979401852403, 0.13787932002118655, 0.08392290744398322, 0.09499644967062132, 0.16539547565792287, 0.14371544042868273, 0.08779033313372306, 0.19923001368130955, 0.13643412185566767, 0.1370487388755594, 0.16128204709717206, 0.10911561668451343, 0.10464358236640692, 0.23234200690473827, 0.13421821647456714, 0.08248666594071047, 0.1390739759164197, 0.12559718479003223, 0.1326776977096285, 0.11191439721733332, 0.11395680797951561, 0.08860886349741902, 0.11684054109667029, 0.12223467736371926, 0.14051423434700283, 0.16562496977193014, 0.0917924480246646, 0.11139242058353764, 0.16651205931391033, 0.11121452905769859, 0.10420995099203927, 0.15824790990778378, 0.14680432182337555, 0.18233512953988143], [0.0908491350710392, 0.04329156556299754, 0.07227131444960833, 0.04827451978677085, 0.04475773385326777, 0.04609022395951407, 0.003997752758940416, 0.03365820712809052, 0.03942581246207867, 0.04513066348486713, 0.05003817139991692, 0.01495017733291856, 0.01620961127004453, 0.004127997131685593, 0.02963226887264422, 0.02605796352561031, 0.017569578651871, 0.030330084463847534, 0.058276984308447154, 0.061204985050218444, 0.016242150416863815, 0.08365605319184916, 0.06959470414689609, 0.018833555380946825, 0.06216946829642568, 0.023559953817831616, 0.04458021552168897, 0.01590861483210964, 0.02336738388320165, 0.03836998822433608, 0.006070778597079749, 0.011996902009871389, 0.053015739124800475, 0.016567390911015015, 0.04343566604490791, 0.047112019666071446, 0.04576242708468011, 0.016048508396904384, 0.07226677505033356, 0.03476689602913601, 0.002793488383758813, 0.024822446251554147, 0.04755425486447556, 0.02567538003703313, 0.023137735402477638, 0.006112837166126285, 0.011565110313573053, 0.06154105665960482, 0.034219593075769286, 0.06881115226341145, 0.034389084338077476, 0.03851942199149302, 0.03953439163576279, 0.03959882192845855, 0.03705160825380257, 0.06843949827764716, 0.04196084304047482, 0.025811819858582954, 0.012504284203584706, 0.04730755649507046, 0.0231651906256697, 0.05747955638383116, 0.06315209556903158, 0.06991550871836287, 0.03110887642417635, 0.041915615288806815, 0.07978921104222536, 0.06553627084940672, 0.028481039218604565, 0.04326065490022302, 0.03068949089252523, 0.0669057716482452, 0.009280304790341427, 0.041888901365122626, 0.015530653863347002, 0.008579501948718513, 0.01608544445064451, 0.08307064031916005, 0.05868755906288113, 0.07593457573758704, 0.024274536009345735, 0.052874298500163217, 0.047431653764631064, 0.08209106645413808, 0.04132240944142852, 0.02673337049782276, 0.07632562225418431, 0.013419963818575655, 0.01614859400849257, 0.018459093956542865, 0.07731996104121208, 0.04909661245931472, 0.035617575382015536, 0.03420519795534866, 0.04223709160994206, 0.050226648072046895, 0.061067846337599416, 0.03022763246138181, 0.0214885068458638, 0.011454734718427062, 0.031305064646793265, 0.053852922416159084, 0.08365308120846748, 0.020815676610384668, 0.035045665356197526, 0.08959336352667638, 0.0039829666327152935, 0.05489439903093236, 0.0232250085765762, 0.020876944929893528, 0.049122244119644165, 0.039948304782488515, 0.04603622953540512, 0.05102252554414528, 0.03204173993851457, 0.07148186609681163, 0.030808071672384228, 0.02793615184990423, 0.01106193334063781, 0.024876311754009554, 0.0662506732291409, 0.045865136930452924, 0.0462710433639586, 0.06532375368156604, 0.010894627809258444, 0.0657828776165843, 0.025811422915597047, 0.022973166911729744, 0.0062783861399761266, 0.05233267827757767, 0.038140310905873775, 0.023657656075166802, 0.05314965479608093, 0.058246124535799026, 0.008959849664409245, 0.023627276366044368, 0.05525848056588854, 0.01581427132311676, 0.048856109114629884, 0.0702234889779772, 0.01332392736471125, 0.0029183445523293422, 0.05748710169323853, 0.03690064778285367, 0.026886066322081854, 0.007836303390961672, 0.05734227517885821, 0.05930619301008327, 0.03496066527441144, 0.038239387196621726, 0.010286028546813344, 0.01620422370199646, 0.010829786154707628, 0.024516905325331857, 0.01438101367758853, 0.02634535194374621, 0.10554532147943974, 0.018314862856641412, 0.029197816470904008, 0.06872920558920928, 0.07376043418688433, 0.031165469637406722, 0.04498490737751126, 0.020755359936239462, 0.028101570205762982, 0.05626147406707917, 0.08289924915879965, 0.007773371812488351, 0.06851262399660689, 0.05988772466246571, 0.04337825858965516, 0.06788499267505747, 0.02689373546413013, 0.02609666037772383, 0.06429249580417361, 0.03372738038056663, 0.01665707627710487, 0.03340932387592537, 0.08278202544897795, 0.06712845327066523, 0.014766090782359242, 0.08279383874365262, 0.038260096085390875, 0.023581824697820202, 0.015109639847651124, 0.05814269544290645, 0.08040211136851992, 0.04558457966361727, 0.04406673075365169, 0.027948048265118684, 0.016029882610642483, 0.018211233595918332, 0.008540252938733568, 0.03938648457239781, 0.06588773841836623, 0.03140253280954702, 0.042690013734889884, 0.10068840852805547, 0.03472397190385631, 0.029609018870230232, 0.0124647765021239, 0.025310682731547525, 0.039304198630686314, 0.034024188561098914, 0.0455532381311059, 0.022296178952923844, 0.03400732357321041, 0.014851435220667293, 0.01896558472487543, 0.026355957446087683, 0.04856338232223477, 0.06436870885746819, 0.022373138394738947, 0.021643943951598237, 0.03254096529313496, 0.021706170701820935, 0.05139522447383829, 0.06743168378514902, 0.032613436225801706, 0.06769363901444844, 0.08427136231745992, 0.03318170251856957, 0.030663316404180865, 0.017856229163174118, 0.03476150846108794, 0.04138958440827472, 0.05591846104445202, 0.021093999800671424, 0.09629490106765713, 0.06597870960831642, 0.0231047467262085, 0.060443980885403495, 0.06757072239582028, 0.05427168030291796, 0.035172147676348686, 0.053164053309176645, 0.03797028699357595, 0.02272605972497591, 0.02392502092490239, 0.03417311003431678, 0.005435769903540079, 0.03836712480655738, 0.03952873604638236, 0.01640119563255991, 0.054364225694111416, 0.009475833137652703, 0.03462263269882117, 0.06578137805419308, 0.02474632140781198, 0.007644858976293887, 0.04097063313903553, 0.03806833530377064, 0.031178270200533525, 0.05775629010583673, 0.06633286417594977, 0.03543022168534143, 0.01676352315449289, 0.033733080074723275, 0.05062074799622808, 0.03324252639764121, 0.020911870823640908, 0.04986313311383128, 0.02813522215001285, 0.020101525288607393, 0.05529238356809531, 0.02683298452757299, 0.06889061549944536, 0.005143781866146517, 0.04116037188630019, 0.017003363231197, 0.07930087617465428, 0.04194635292515159, 0.07220200888280358, 0.024406326169680272, 0.01576384429686836, 0.06746369028197867, 0.025541540700942278, 0.02215855339142893, 0.07588055077940226, 0.032365703090493164, 0.03889539824532611, 0.04534623406029173, 0.009236515532912952, 0.05752056704035827, 0.04561461162354265, 0.038086431832717996, 0.044231943852667294, 0.043650629331490824, 0.0058011215712342945, 0.04101572518369981, 0.06486849739615407, 0.059891999433083196, 0.026957609358110597, 0.09344710995044027, 0.05477400995524866, 0.031493744879428826, 0.050692557357251644, 0.029718792265547172, 0.024083686160988042, 0.04051313090271183, 0.07061049142586333, 0.0182076848577708, 0.034000802851681194, 0.028224001671852808, 0.050084447488188744, 0.015188036087368215, 0.06620907903249774, 0.012070610420778394, 0.01901302450070424, 0.058044640347361565, 0.016485591818179404, 0.06246724338935954, 0.04838970110618642, 0.0023410548040244195, 0.03479328425601125, 0.08619024577949728, 0.034409664305193086, 0.04200195547725473, 0.03519863768347672, 0.0292655953339168, 0.04175505354734404, 0.026162354441891824, 0.036049140617251396, 0.011622381213653301, 0.04412069803635989, 0.044537274433033805, 0.011021632601373961, 0.029395480507186482, 0.023620781089578356, 0.0393222815889333, 0.04736686045570033, 0.02387349636826132, 0.04850908934271761, 0.015599747387958425, 0.041088813583233526, 0.029594057173069035, 0.028790149239024947, 0.012094683146902492, 0.01503725373186171, 0.022378933083798205, 0.01656952659998621, 0.024633996720824922, 0.047853889143360515, 0.019970462857080356, 0.046645170609865866, 0.024358321513448442, 0.0219246725485261, 0.017834091958190714, 0.04012976540252566, 0.06799860657857996, 0.04146081022918224, 0.02300260345717626, 0.2361116489129407, 0.12638425827026367, 0.1993380364562784, 0.21728401205369405, 0.10193071115229811, 0.15974963004035608, 0.07927237770387105, 0.1483833406652723, 0.11052062522087779, 0.11642333705510412, 0.19986894939626965, 0.10388054259653602, 0.07059525831469468, 0.062028441578149796, 0.10883386180336986, 0.08039787052465336, 0.09345800722283976, 0.13784696747149738, 0.12703664254929337, 0.14669929817318916, 0.17309106700122356, 0.1522345290120159, 0.07408850586840085, 0.14485468715429306, 0.0878748039581946, 0.07295316071914774, 0.09823654937957015, 0.15827799615051064, 0.09716384658323866, 0.13752569471086773, 0.07987967333091156, 0.12794217467308044, 0.09927686569946152, 0.10542479330407721, 0.07493949056203876, 0.17130067093031748, 0.14350240757422789, 0.09063114212559802, 0.09675036769892488, 0.07351130326943738, 0.13495743966528348, 0.129257826932839, 0.14225094472723349, 0.12831654958426952, 0.1935320430036102, 0.13713450570191654, 0.079223801381886, 0.1373806782066822, 0.20954476376729353, 0.10424917031611715, 0.08230761411998953, 0.10660103375890426, 0.11368012175496135, 0.1743202738996063, 0.07282387944204466, 0.19534028454550675, 0.15109511943800108, 0.16012939251959324, 0.13304888350622995, 0.1047549910311188, 0.1676213147916964, 0.18571428821555205, 0.11676682505224432, 0.2049364253346409, 0.07255181404096739, 0.13089807677481854, 0.10345791706017085, 0.14982819956328186, 0.08266037090548448, 0.13085606188646384, 0.16978565151137964, 0.20996701610939844, 0.10033008775540761, 0.11285540993724551, 0.15044268087616988, 0.11189024137066943, 0.06942803559026547, 0.2016117801623685, 0.1324931497552565, 0.15321744126932962, 0.13441887285028184, 0.08629595475005251, 0.14275395630725793, 0.13810338585504464, 0.10101732837834529, 0.11615589926285402, 0.13782634000693048, 0.12425448612443038, 0.16844782472721168, 0.08291013964584895, 0.19787765267704213, 0.16783657324101242, 0.132411264149206, 0.11042575923992054, 0.20684803490127834, 0.16975813013102325, 0.17571644112467766, 0.14155612486813748, 0.09853535584573235, 0.09556570662451641, 0.10627844464033842, 0.11153610715908663, 0.14675757076059068, 0.12701368092426232, 0.11939703034503119, 0.1740874821054084, 0.15706008007483824, 0.21971816143819264, 0.12448438735944883, 0.12958175955074175, 0.08270134763526064, 0.10700641093509537, 0.12406995174075876, 0.0913328898272344, 0.16012889040367945, 0.16304186838013784, 0.0865279051608273, 0.12676731842969144, 0.18278668102409157, 0.1191223186573812, 0.11537426763347217, 0.10250480606087617, 0.14914107429129736, 0.17648929251091822, 0.14805577109966958, 0.15715905119265827, 0.10690513279821191, 0.12252614886632987, 0.10844751074910164, 0.1511499314968075, 0.1815924865326711, 0.13553070676113876, 0.15306163605834755, 0.15324649613882813, 0.08935834613761731, 0.12623582194958413, 0.09340940375945397, 0.13757051873419965, 0.16521505319646426, 0.19246769297335828, 0.21039832010865211, 0.11591978264706475, 0.17690766363271646, 0.12691570046756948, 0.12490264991564409, 0.08959509379097394, 0.17814200025584015, 0.12362993535186563, 0.11033839785626956, 0.1804646799074752, 0.11919165136558668, 0.12375561360801969, 0.11293857118913106, 0.11484487461192266, 0.13171070388385228, 0.1640540933502572, 0.15828494434910162, 0.07152873929589987, 0.09523229487240314, 0.13828386259930475, 0.13067563942500524, 0.17602323394800934, 0.08567020297050476, 0.08790123289717094, 0.062233440577983856, 0.09727070227797542, 0.26457252885614124, 0.10771193807678563, 0.1209615013961281, 0.22200282955808298, 0.12702885296727928, 0.09937692925866161, 0.1287020660404648, 0.12738858509276593, 0.16502008294420584, 0.14039194876594202], [0.024764753811593567, 0.014276198676920362, 0.0191650825020458, 0.03177098411002329, 0.014417293248698115, 0.019399361984272088, 0.029930169494556527, 0.03252767279211964, 0.012846614450349339, 0.015450690207736833, 0.041378989083958526, 0.06943176074751786, 0.009948388673365116, 0.01730045978911221, 0.04787805177537458, 0.07886581987674747, 0.0322791864829404, 0.010965411734235073, 0.022286287608689496, 0.0180177917437894, 0.008062040117303175, 0.03165193174832633, 0.0340432248610471, 0.04394295918090003, 0.013596421939187815, 0.03877338407827275, 0.033945634561989985, 0.024309336374114667, 0.04910972175587501, 0.031122962811163495, 0.041450337041169405, 0.05055375623383692, 0.0052670076422925505, 0.030283323223037378, 0.020097638979288082, 0.03562967026872294, 0.01951380370051733, 0.023876434424892068, 0.03620432836136647, 0.022417202458849976, 0.05960744898766279, 0.04817836119660309, 0.010167949882868146, 0.011969484954274126, 0.021169956706996475, 0.025613594334572554, 0.05199934794966664, 0.018869127579299465, 0.022016429142760377, 0.05332465237006545, 0.038214892082448514, 0.014358138565772345, 0.016473149182274938, 0.03485580107995442, 0.014112759098809744, 0.015556105711896504, 0.04157486518046685, 0.024469660628320913, 0.07465209705489022, 0.06119076295622757, 0.0685774851590395, 0.02807893936655351, 0.04311448488650577, 0.010104462753848305, 0.05368595869679536, 0.05090339175824608, 0.050432936288416386, 0.042918602004647255, 0.012806365449380661, 0.025750948482060006, 0.04060384764203003, 0.03468809097207018, 0.025307079710598503, 0.007147972871150289, 0.07021872566214629, 0.035849098315728564, 0.04506008227222732, 0.07026836728411061, 0.008788050534868879, 0.018351485087935413, 0.025236155837774277, 0.033412808153246126, 0.03981890815443226, 0.03135621940184917, 0.006441691707420562, 0.020543668884783983, 0.05602212423192603, 0.019177369074895978, 0.02873257893536772, 0.023174635833129287, 0.06282696194414582, 0.017924245513443435, 0.011509272818719702, 0.013997856826920594, 0.03738034489963736, 0.04368194711527654, 0.033325857283281426, 0.025206712506977574, 0.03237907023036054, 0.050033173989504576, 0.04008378108431186, 0.025678219706086174, 0.06932718493044376, 0.03844951592119677, 0.027588102401101162, 0.06546670743929488, 0.02618518884160689, 0.05088629946112633, 0.01349114638287574, 0.016547650630984987, 0.010685027493829173, 0.024046185226844888, 0.0575491672913943, 0.026392623782157898, 0.01737993998852159, 0.02859459544665047, 0.02632652429331626, 0.10742229861872536, 0.07753773685544729, 0.039309196041098664, 0.020763673686555455, 0.01417813594785652, 0.012880089127325585, 0.04619117300691349, 0.029331352162574018, 0.07505290090505566, 0.0509382209607533, 0.049854118776108534, 0.03361899458936282, 0.07561929444117205, 0.008178166296732212, 0.02873438723119242, 0.022383114555850625, 0.038316438240664344, 0.020082015710483705, 0.017949222387479882, 0.051932346009250195, 0.041860368967588456, 0.031649577231811624, 0.022849376679265072, 0.10954240164054291, 0.022307763242029717, 0.039910832686083655, 0.026975945070652024, 0.016234589840418527, 0.017246119312143753, 0.03547651134431362, 0.044823704420455864, 0.018548287384744202, 0.0493452785802739, 0.04923029403601374, 0.0018356359089791241, 0.03060847381129861, 0.03980439089770828, 0.04893614571275456, 0.07149832057101385, 0.021789101251800145, 0.022291264663051282, 0.02454047932821725, 0.02053977918278958, 0.035377740394324064, 0.008948308631910809, 0.03620756497340543, 0.045716530976018736, 0.018430894041167836, 0.03962188194106732, 0.01166773194979344, 0.04515611194074154, 0.055888870132288763, 0.04561049970132964, 0.03795093856751919, 0.06049307289400271, 0.0363103969554816, 0.053896158667547364, 0.05576106806152633, 0.0071424224546977454, 0.06380388273724488, 0.05282903682174427, 0.04647266665207488, 0.013567984536556261, 0.03503445935036455, 0.04447266093588301, 0.04997990559786558, 0.03028679732233286, 0.04648162331432104, 0.008276107737661471, 0.053970258084258864, 0.07543584571353026, 0.03240811831450888, 0.03178204083815217, 0.013167095869513494, 0.005139747975460652, 0.054544207107807906, 0.09596200500215803, 0.08986755274236202, 0.059841991402208805, 0.02317006081076605, 0.04067341783749206, 0.03645051782950759, 0.06840671146554606, 0.01657875637257738, 0.06192789625908647, 0.03399413624512298, 0.013673439904648279, 0.01592319824599794, 0.030311584206564084, 0.030704299919307232, 0.07674817993704762, 0.025497407086991837, 0.09817260423941271, 0.024951607088691423, 0.0049914036810930285, 0.033188077355069776, 0.02211073363598968, 0.04273581824132374, 0.08706905040889978, 0.005998373821577323, 0.056209555960127285, 0.023602250298219066, 0.04400301292272551, 0.01891732052899897, 0.03693169754530702, 0.04659957305661269, 0.05472220041389976, 0.024106681712770035, 0.0179379688841956, 0.02687286542329405, 0.006137122782612485, 0.036372347202684195, 0.05136349617636629, 0.03682013960289104, 0.007272683366734002, 0.02405683653030012, 0.03622178028204611, 0.009700798030410494, 0.04473242449707218, 0.020955629546993544, 0.04488898966727512, 0.0488050425691264, 0.0575100090354681, 0.04644311305933765, 0.02163815265521407, 0.017318154286061014, 0.021908428420179656, 0.03904247749596834, 0.016054828950603093, 0.047569304771189175, 0.014012364753788071, 0.022807636597592915, 0.030945081463349716, 0.04124601996902909, 0.032289079523512294, 0.03232619199635727, 0.04468084226495453, 0.041348434652068784, 0.03559639830408352, 0.07396852730640344, 0.013420214028363782, 0.04295020138046571, 0.054769840357559066, 0.01915045328704374, 0.02421102173892515, 0.016896085148411136, 0.022581211158207486, 0.01631482151736106, 0.03249830240383744, 0.019810477870383432, 0.029487930903477327, 0.0677520405235035, 0.06607547548732587, 0.03664725227281451, 0.05387455750522869, 0.036507660656103065, 0.03021115084577884, 0.02065826496774597, 0.05399077698322279, 0.03151996007987431, 0.032625185059649606, 0.04789949348196387, 0.029507655916469436, 0.05671502722959433, 0.03536926209926605, 0.014650103702609028, 0.02757300160426114, 0.044763229986918826, 0.022447373518454175, 0.026925572327205112, 0.06517036405525037, 0.03309369991932597, 0.017204681178554893, 0.04949080737839852, 0.026755382173827717, 0.030368323304823468, 0.07638629007020167, 0.0481685190461576, 0.04284982230248196, 0.011481396903816079, 0.024597111557211195, 0.01575395295263401, 0.03621893043496779, 0.027288614007245218, 0.006397557669385735, 0.03525188911174025, 0.03453152580186725, 0.06451094336807728, 0.011392999057924109, 0.061692132481506894, 0.03231650930164116, 0.035462652266557725, 0.04364365738417421, 0.041930448064314466, 0.053852888489408154, 0.07318169809877872, 0.07976424773888928, 0.022496494364791682, 0.04994237243330904, 0.046956611398075304, 0.015132606561694826, 0.03375961079395243, 0.05571729576747332, 0.03537771664559841, 0.011966645285221083, 0.025907230363892655, 0.014303842193580099, 0.021251472511461804, 0.0462738016088094, 0.030614187076155628, 0.04522740900782602, 0.011661257877546762, 0.07325124115284, 0.044003677887043784, 0.06739268159227711, 0.02581854583695531, 0.05341341832120504, 0.058088568704468865, 0.033553811122796366, 0.03708155878952571, 0.03609970165416598, 0.013001562162701572, 0.025132365424984267, 0.05004496692812868, 0.04922930337488651, 0.012177202335026647, 0.023689453922478215, 0.02167958909246538, 0.02733194694987365, 0.03970058182520526, 0.05334642995148897, 0.0262926178984344, 0.080036292783916, 0.046936787997505496, 0.028217513180736984, 0.15360229276120663, 0.08996057310806853, 0.11513911453740937, 0.08321394691509859, 0.06295198202133179, 0.13384871344481195, 0.06466712177331958, 0.09732318696166788, 0.1027333095137562, 0.06856410444847175, 0.11210695867027555, 0.1532271850321974, 0.14011163237903798, 0.0935501047809209, 0.1343252078763076, 0.1523276511579752, 0.16692576211478027, 0.13501115249735968, 0.1973634995520115, 0.15092168588723454, 0.11276246421039104, 0.16624757993434156, 0.056808800769171545, 0.1859929354063102, 0.18382154192243302, 0.07412627312753882, 0.12415265158883163, 0.10897364680256162, 0.11411413310893945, 0.10656731735382761, 0.1477887268577303, 0.13663168411169732, 0.09812204659517322, 0.16569264685469015, 0.09805032544370208, 0.04811965773946472, 0.09003995491990022, 0.11520968217934881, 0.10214215623480932, 0.1149414030036756, 0.10964186808892659, 0.10960242484829255, 0.066381847618946, 0.14068947280091898, 0.09716922058058636, 0.10484881206814732, 0.12056690614138331, 0.11579326300748757, 0.1518167414303337, 0.11038731344576393, 0.08788747899234295, 0.09900531598499843, 0.09767651371657848, 0.13905147569520132, 0.09540923644921609, 0.15043145790696144, 0.18682538930858883, 0.09367668548864977, 0.13245572176362785, 0.11579411796161107, 0.15476758166083268, 0.12668166016893728, 0.1830020344683102, 0.10655710540179696, 0.11415962209658963, 0.13072122340755804, 0.16142026468047074, 0.14940722286701202, 0.08957135863602161, 0.15086927584239415, 0.14325200101094587, 0.06845768301614694, 0.11164367531559297, 0.10885479460869517, 0.15281946691019194, 0.13771720443453106, 0.18060553020664624, 0.155495161190629, 0.15204924823982374, 0.10623959172517061, 0.2512284591794014, 0.09336723959339516, 0.1231577428323882, 0.19295991584658623, 0.06286888183759791, 0.11009405739605427, 0.14332716912031174, 0.13690512015351228, 0.15435815363058022, 0.11724646788622652, 0.14697339917932237, 0.27126312841262135, 0.11901426874101162, 0.1537639062319483, 0.16250856699688093, 0.16069624067417212, 0.12559035872774466, 0.06909197755157948, 0.17222210791494164, 0.15137428231537342, 0.12995329818555287, 0.09547333086707763, 0.19746241638703005, 0.11034790413188082, 0.1907501851341554, 0.12573758725609097, 0.09052896832248994, 0.09281020984053612, 0.13139255238430841, 0.09100193437188864, 0.07822029558675629, 0.17632637625294073, 0.08431259689054318, 0.1261883380689791, 0.17936980937208447, 0.1473552786878177, 0.10002201250089066, 0.20924182502286776, 0.1509613666151251, 0.1412588179643665, 0.13508736555065426, 0.09456045699438878, 0.1282302535005978, 0.11019302851387433, 0.09717990072177989, 0.16857350298336574, 0.13954861116196426, 0.12817530573478766, 0.12574643535273416, 0.1300668849476746, 0.08929583949169942, 0.057597601121025424, 0.08610126948250191, 0.14262579461293562, 0.0928030920081905, 0.0939459146133491, 0.12905224439288887, 0.13589204022926943, 0.12267397450549261, 0.08819598850927182, 0.28550970394696507, 0.08583788254431315, 0.06792754360607692, 0.12070359023553984, 0.08682755979576282, 0.1089419252904398, 0.12970336659678391, 0.1313473755227668, 0.11059788321810109, 0.17656904751701014, 0.14692264475992747, 0.13388069958559104, 0.06213232528950487, 0.13595412618347577, 0.16950274312070437, 0.15525907171624048, 0.13633307442069054, 0.10525429102459125, 0.09859794391585247, 0.0946331891630377, 0.09313057336424078, 0.07802246870206934, 0.14601711263614042, 0.12120409123599529, 0.08801294011729104, 0.11191124881484679, 0.13489842068936142, 0.059194519716714106, 0.1290830634534359, 0.14054672260369572, 0.10496853278683764, 0.11668312097234385, 0.15134689664202078, 0.15748746214168413, 0.14522876351007394, 0.07251366680221898], [0.03394283221236297, 0.018055324908345938, 0.0371304133108684, 0.04229620558076671, 0.04227406159043312, 0.026624306171600307, 0.04975621295826776, 0.024962906393089464, 0.022276250379426137, 0.02445529604197613, 0.030895867318447148, 0.020850368409550617, 0.03649566076429827, 0.035320539892252, 0.006921824358869344, 0.006361685643371726, 0.015986707427405884, 0.03827278129756451, 0.08539635302232844, 0.024590775736474564, 0.01712139948670353, 0.0013188274855825252, 0.05179020310086863, 0.028339223703369498, 0.01266990611994905, 0.036987585082117996, 0.05142536839204175, 0.022022249276882837, 0.023951526199068342, 0.017107928870245814, 0.024112037050404718, 0.10113167509968791, 0.010035919690770763, 0.049316264422876496, 0.02459903690032661, 0.016725131643137763, 0.017595681894038404, 0.02382321692337947, 0.03337179410404392, 0.055314229003020694, 0.02586096614998366, 0.05028458817728928, 0.06586110591888428, 0.04862030123227409, 0.023529300998364176, 0.05643006966316274, 0.03136611583509615, 0.07063784317246505, 0.07704474723764829, 0.040339928053851636, 0.07201543889407601, 0.030919622829450027, 0.005282987141981721, 0.03719846698056374, 0.024777632406247512, 0.05845793602722032, 0.041188222356140614, 0.03273633248837931, 0.08160372224769422, 0.021878432083342756, 0.057832476017730575, 0.01860868717942919, 0.025930193685261265, 0.03086967925940241, 0.035580907349607775, 0.05894777045718261, 0.03488435044086405, 0.0705716520813959, 0.02081073517911136, 0.011507064187234002, 0.020384820444243293, 0.017326563031279614, 0.04526153253391385, 0.012433242435300989, 0.03421626825417791, 0.01524659026680248, 0.013725342744562243, 0.014298089912959507, 0.02284883724392525, 0.050831141349460394, 0.05180551763623953, 0.04204101534560323, 0.06008435054016965, 0.0415650535640972, 0.0462536694748061, 0.016410315143210546, 0.04635545651295355, 0.07030066555099827, 0.06097716013235705, 0.06629300702895437, 0.07918018515088729, 0.09353487845510244, 0.020406981397952353, 0.0017452696754064942, 0.047454479682658396, 0.03246004320681095, 0.01577155075834266, 0.01527721424853163, 0.052283884824386666, 0.0404040055083377, 0.03149387380108237, 0.06649045393403087, 0.06815722770988941, 0.022304411279037595, 0.01916726738480585, 0.06960254801171166, 0.02008158653708441, 0.05196242546662688, 0.015137251133897474, 0.0320643690813865, 0.014716449160394924, 0.011739834777212568, 0.020530389954469035, 0.048854032797472816, 0.027645433521164314, 0.0276253081725112, 0.05037307932174631, 0.03132394827636225, 0.02076896625970091, 0.015876384418723837, 0.019479476613923907, 0.03956038970500231, 0.038125830968575816, 0.03819599827485425, 0.03784982667171529, 0.013501651801301964, 0.026135766047186086, 0.02280013369662421, 0.05354896926188043, 0.04511866020038724, 0.10283319665385143, 0.06623330951801368, 0.03873035478006516, 0.03308102488517761, 0.03312914998137525, 0.01463875690075968, 0.011428643350622483, 0.03848122386261821, 0.0181539431879563, 0.00973792068128075, 0.03707858680614403, 0.06286721942680222, 0.07375033080045666, 0.008316450037195213, 0.014898237173578568, 0.05106808577797242, 0.028455870658425347, 0.04899344460240432, 0.03403956416462149, 0.002282978991778301, 0.04416676038610084, 0.06943619158118963, 0.02030652089576636, 0.051322329456784894, 0.04007448176188128, 0.03287596481719187, 0.021201294846832752, 0.04232835456995027, 0.035321656082357676, 0.0632719180679747, 0.06601444126239844, 0.052316881982343535, 0.01925382809713483, 0.020987120357209017, 0.049234076868742704, 0.03569366969168186, 0.06113800685852766, 0.026698707536395107, 0.04103302104132516, 0.057370400455381186, 0.047385913719023974, 0.024824605689250996, 0.023525441830445613, 0.04823742088462625, 0.02931531498740826, 0.09958910037364278, 0.06496479508600064, 0.037070498668721745, 0.03472818560632212, 0.04402140800708106, 0.025385662547445724, 0.02691624077436115, 0.025991833502692834, 0.037177727557718754, 0.029671932637159313, 0.015404149490807737, 0.037442614058298726, 0.0364668298113559, 0.06803712022623845, 0.011554202014979507, 0.05535676636333976, 0.021759199909865856, 0.020137947352070893, 0.10451861657202244, 0.11398103167968136, 0.08666893866445337, 0.01763122864732785, 0.0434182005535279, 0.042480359984827895, 0.023083800350182822, 0.028818070955042328, 0.04108934284054807, 0.018030505793701326, 0.02544876969685512, 0.07393151322113616, 0.012034988180468125, 0.029594674639936005, 0.05373363595988069, 0.0456450574898294, 0.01914854490730379, 0.02578388966087784, 0.04136697222877826, 0.0420671864412725, 0.01819659929190363, 0.02970785428104656, 0.04936035562838827, 0.03147811143259917, 0.039399329240300825, 0.025466859440452287, 0.03726592353944268, 0.030169118994048665, 0.027878868227292384, 0.016319513587015014, 0.08673970308154821, 0.09840790661317961, 0.06498387549072504, 0.0202851894511176, 0.0061304638095732245, 0.047278382881943665, 0.028020480182021856, 0.0497445930460734, 0.023619054217955897, 0.028461188676634004, 0.0627809844112822, 0.08775519859045744, 0.017873813398182392, 0.08173356670886278, 0.011410145637845355, 0.0439937305636704, 0.005378540987814111, 0.033127294188099246, 0.01982177378210638, 0.044567733870020936, 0.050075300836137364, 0.025000461610034108, 0.015131722769833036, 0.010199121781624854, 0.03978853692699756, 0.0226725979508566, 0.03442404246223824, 0.04192031414381095, 0.049001393640147786, 0.0771380118759615, 0.012215936506566192, 0.006000462013097214, 0.014968753925391605, 0.06571036257914134, 0.03638522919001324, 0.0326872404797801, 0.039802253512399535, 0.01995806602228965, 0.04870509775355458, 0.04059241432696581, 0.05358268905963216, 0.04710587892415268, 0.008759513896490847, 0.0667374881782702, 0.05924403241702488, 0.0719779905463968, 0.035659515631518195, 0.07012987150145428, 0.16269812253969057, 0.017197064622970562, 0.030611578109008924, 0.014305083912664225, 0.05136075150221586, 0.013041985886437553, 0.014855336797024523, 0.04123238141515425, 0.013677687533865017, 0.04178769447441612, 0.01789540098980069, 0.03247556808803763, 0.0256869931638773, 0.044409336655267646, 0.029470757182155336, 0.00842917590801205, 0.11445072719029017, 0.10875006272856678, 0.0062838716715175125, 0.040410665329545736, 0.022394286634932672, 0.021036724659747312, 0.06707940197416715, 0.024278312056724514, 0.03883828256013138, 0.01246656189739172, 0.05038630736193486, 0.0415661086860512, 0.03342253834541355, 0.019091312174818346, 0.04168213478156498, 0.01916928093747369, 0.03178078894104276, 0.014331792747335774, 0.02276215948430555, 0.039383882390601296, 0.037185829265841415, 0.028186622874013016, 0.05650130566209555, 0.05902028549462557, 0.020804718269833496, 0.015570701000147631, 0.02741642964870802, 0.027300445961632898, 0.022518144720899205, 0.02937938904921923, 0.032208581521574936, 0.06398014577903918, 0.044183438776859214, 0.016616033390164375, 0.05047528026625514, 0.015807267145386765, 0.06585327562476907, 0.03671141115150281, 0.0193170726498855, 0.02789421160040157, 0.04540056775191, 0.008265830476635268, 0.01661328023432621, 0.025403589442638413, 0.04207529154207025, 0.03421697053792221, 0.06200689809130771, 0.019761482553024377, 0.03475801061306681, 0.032087469806096384, 0.05524802773392626, 0.01909240970521101, 0.018226178329704062, 0.028325410426727364, 0.01443273331304746, 0.02110884614687945, 0.0786061038130096, 0.023565422810081924, 0.03255111278433885, 0.019576310346435224, 0.018216076639613936, 0.015361149030338441, 0.03562755323946476, 0.056825764144637754, 0.026087591757199595, 0.1828293880181653, 0.09645101840474776, 0.12725871349019663, 0.12092210565294538, 0.12278567494026252, 0.13870527355798654, 0.08319683426192828, 0.11123191991022655, 0.16571039733077797, 0.08451062733573572, 0.09424000526113169, 0.1428574871804033, 0.15690574049949646, 0.26124369033745354, 0.10372648122055189, 0.05932927677141769, 0.12122128531336784, 0.3363279870578221, 0.28867536836436813, 0.09961774812213012, 0.06576560211500951, 0.11923175278518881, 0.10629089575793062, 0.12393915733056408, 0.06783014668950013, 0.238983616232872, 0.13419878323163303, 0.06928104454917566, 0.1645335326237338, 0.1589813655508416, 0.06706383638083935, 0.1876323710062674, 0.10489970897989613, 0.13814693423254149, 0.07909283055258648, 0.1344121146414961, 0.09374962800315448, 0.12692933902144432, 0.13409080116876534, 0.15542532636650971, 0.07729481453342096, 0.14323925812329563, 0.12071201764047146, 0.15037496308130877, 0.15375288682324545, 0.13959486010883534, 0.07984939709837947, 0.135774680812444, 0.16250533717019217, 0.12372536451688834, 0.22440370358526707, 0.07307258966778006, 0.1431402327226741, 0.14004519023001194, 0.15178527097616876, 0.12587664622281278, 0.15605041996708938, 0.12329938023218087, 0.19485684191542013, 0.08423752377607993, 0.12588458508253098, 0.14021578750440053, 0.21114252374640533, 0.17267796131117003, 0.09968433276351009, 0.14071706203477724, 0.1259514479232686, 0.1489731233034815, 0.14607066261981214, 0.07321708370000124, 0.1855761520564556, 0.0909970828465053, 0.16705336741038732, 0.04107365171824183, 0.12012018582650594, 0.10202536000204937, 0.13080439823014395, 0.05302201896639807, 0.09838679060339928, 0.13733054803950445, 0.12368443528456347, 0.11300981736608914, 0.15283545319523129, 0.21014431730977126, 0.18487062491476536, 0.14746415641691002, 0.1464073924081666, 0.1797926045422043, 0.12457821518182755, 0.17577764498335974, 0.17061581196529524, 0.21632448211312294, 0.12753406300076417, 0.1576822559748377, 0.1276860005621399, 0.18723367740000996, 0.15372119923787458, 0.16387418657541275, 0.10167711547442845, 0.18122203355388983, 0.0812804206673588, 0.17407202507768357, 0.14413925340133055, 0.10399837020252432, 0.07258733534919364, 0.1630491694169385, 0.12039944369878088, 0.10204204517815794, 0.12141013517975807, 0.0897834754682013, 0.07249466782169682, 0.15294663794338703, 0.14085785805114678, 0.1501709140305008, 0.18884605302342347, 0.08467589811022792, 0.12680386432579585, 0.20971093699336052, 0.08284782298973628, 0.09299375356308051, 0.08149565197527409, 0.11787880824080535, 0.16482910247785704, 0.12105041662497179, 0.10103726373719317, 0.12103121408394404, 0.12546044641307422, 0.09803002367594413, 0.13705366503979477, 0.0967663743400148, 0.1842985248991421, 0.22425982701991284, 0.0866614408524973, 0.13910825550556183, 0.16275245962398394, 0.08817462144153458, 0.1181685019816671, 0.09051030182412692, 0.10244944438870464, 0.21310779186231749, 0.0674401315461312, 0.18628930593175547, 0.197450297751597, 0.06382438128015824, 0.13069196497755392, 0.12142124958336353, 0.09929279091634921, 0.13066865051431314, 0.09848310864929642, 0.11412345618009567, 0.14083155803382397, 0.1929025932082108, 0.10383955908140965, 0.15530038092817577, 0.09512102870004517, 0.09349475667944976, 0.1296689784420388, 0.11829347456140177, 0.08341104776731559, 0.17618680159960473, 0.16182684286364488, 0.11533238845212118, 0.09361278784594365, 0.12062026613524982, 0.15065666367965086, 0.1448052083807332, 0.0985814623002495, 0.1739779801240989, 0.13598567806184292, 0.10942867917141744, 0.1109498461176242, 0.07575893016265971, 0.0919959203207067, 0.10221675437475954, 0.23097942716309003, 0.14724199048110417], [0.023576131789013743, 0.031823411118239164, 0.010401041080643023, 0.011386364681779273, 0.032676160002925565, 0.06589828963790621, 0.020729638370020047, 0.03769486623683146, 0.05141607585496136, 0.020262614591047168, 0.016193740335958343, 0.0309769692165511, 0.01878638193011284, 0.05196895297350628, 0.04318569374403783, 0.01310454257431307, 0.040677882597914765, 0.06488769315183163, 0.030300700504864966, 0.01832781100113477, 0.034657967409917285, 0.041325310178633244, 0.008202675829774566, 0.01823073299601674, 0.05490119795181921, 0.02743849391117692, 0.024717712675088217, 0.030941929668188095, 0.051467295070844035, 0.017563819585900222, 0.04809533904439636, 0.04799473265718136, 0.07130024262837001, 0.06284244611327137, 0.024011771627036587, 0.015477356633969715, 0.046033939479717186, 0.029199088724063973, 0.032726972097797055, 0.02229157000380967, 0.019013954093679786, 0.041821960492857864, 0.06257960878844772, 0.01619020856118628, 0.027266300383156965, 0.00880568566000355, 0.028023301191361885, 0.034134338543351204, 0.0408595467784575, 0.005873797336659793, 0.03135367828820433, 0.04852186276444367, 0.01899842412344047, 0.02126495839495744, 0.04761477340278881, 0.037113636532532315, 0.021822620881721377, 0.09400375293833868, 0.022304460472826446, 0.02126918566812362, 0.03615338055949126, 0.014258507572646652, 0.04554644260289414, 0.023125318211636374, 0.04595425232712712, 0.023059603791417818, 0.024744548735075762, 0.028484486176499298, 0.059058500586875846, 0.014241790166124701, 0.018319419219291637, 0.04495057011289256, 0.01125716058803456, 0.059220521178628714, 0.014224318737563277, 0.03547819071848478, 0.04129930193136845, 0.029654836947364465, 0.03354583494365215, 0.04794118267350963, 0.02483959622415049, 0.037333319030169926, 0.06616972400141613, 0.013813597249931522, 0.043126457636909823, 0.021324131737596223, 0.02276489058775561, 0.03981471820069211, 0.01673544367908367, 0.014626085259286421, 0.021969617011823823, 0.029646816663444042, 0.02452754645076181, 0.060273851800177775, 0.03161666828340717, 0.04080246502001371, 0.014259901962109973, 0.06357205446277346, 0.0158663624564984, 0.03420601559004613, 0.01625893567688763, 0.02439743566459843, 0.025408106789525067, 0.012771734718366392, 0.027120993805250952, 0.05857685607458864, 0.05001730305541839, 0.018648596912888542, 0.05227876867034605, 0.018031806884599582, 0.028266812142516886, 0.10408404203397886, 0.05725826575819935, 0.053671142884663174, 0.04703966069168278, 0.042110286985657046, 0.027304936167118803, 0.03386134694197348, 0.0043495218518988365, 0.028862297867557833, 0.09529535113168613, 0.01390542509034276, 0.045130025661949597, 0.0545042990706861, 0.015476635690512401, 0.035511445719748735, 0.07844943686255387, 0.014938050215797765, 0.02959927510736244, 0.10272408143750258, 0.03736692347696849, 0.011538528704217501, 0.02989723001207624, 0.02240574369872255, 0.06107582590941872, 0.00815794849768281, 0.04444944146754486, 0.056902581094098945, 0.06217761750199965, 0.04829014984092542, 0.03050200148884739, 0.042115352249571254, 0.03903776167758873, 0.047007908645485125, 0.05650691036134958, 0.022418242313766053, 0.02202477173081466, 0.008570635192362326, 0.020996216119134, 0.04249254986643791, 0.05415223439091018, 0.024730436903025423, 0.03869907431570547, 0.07268965164465563, 0.02986939650561128, 0.0669550197198987, 0.0326346743718854, 0.019027994679553167, 0.02028021070041827, 0.03540674776637128, 0.03671199129894376, 0.01236923537882311, 0.0487994717966233, 0.030027132148721387, 0.03741210712386029, 0.034435835400862355, 0.05826934400413718, 0.013094080412494285, 0.038802174319114, 0.022693359426089695, 0.041591920158160586, 0.04560156000245895, 0.01841219700872898, 0.030819705155278956, 0.06065583308892591, 0.05096364227522697, 0.005057113860467715, 0.03962811428521361, 0.0068234372052497095, 0.04373460143272366, 0.024624772037246397, 0.0023928972119132853, 0.05551594728603959, 0.04015965147742203, 0.030199140775948763, 0.0007023236612440087, 0.042480359984827895, 0.0216185090664242, 0.03572915368048208, 0.017515151661687663, 0.02649067378869014, 0.021689587305965166, 0.036939619441649744, 0.008521540639256793, 0.021656566399282644, 0.03481556395334857, 0.0632906931319407, 0.019050294732941047, 0.027039837624345506, 0.0516846909054688, 0.05110957140901259, 0.031073029419141154, 0.05983217978583915, 0.05731507949531078, 0.037110454203294854, 0.056630342666591914, 0.03314945174913321, 0.02187879679591528, 0.09924057086131402, 0.055449807085096836, 0.015379851151789938, 0.031808636018208096, 0.008764406133975302, 0.03324801913861718, 0.013991052817021097, 0.006068936798588506, 0.033158215028899055, 0.04194897546299866, 0.07250498155398027, 0.01548709870049996, 0.05234085462455239, 0.06589018792978354, 0.07900937074529273, 0.04012006913710918, 0.014927890850231051, 0.057419017489467344, 0.02570527289727969, 0.03192871296778321, 0.043929412229252715, 0.034606595523655415, 0.028581852559000254, 0.036236192365842204, 0.005338990453830255, 0.06340015440114907, 0.024570221214422157, 0.02942242513277701, 0.009123932154450034, 0.016262206215677515, 0.0332410777253764, 0.021621151960321834, 0.050804580096155405, 0.02984593276466642, 0.06930881020213876, 0.05697517416306904, 0.03163727878459862, 0.04119002725929022, 0.01570838932613177, 0.034983067108052116, 0.02509017411752471, 0.05738880232508693, 0.02566421983231391, 0.005614801792294851, 0.04594243563977735, 0.03983221422614796, 0.09899447299540043, 0.07889290020934173, 0.03267919644713402, 0.029153721872717142, 0.027229600120335817, 0.008229105616919696, 0.031397928949445486, 0.049326418699430566, 0.028219450398215225, 0.058478190297526975, 0.0519321458414197, 0.013241643967506076, 0.04379299615642854, 0.031979528455329795, 0.05140406239245619, 0.07048215331243617, 0.05416521476581693, 0.017712121895913566, 0.055231352735842974, 0.007130910259937602, 0.009287505743226834, 0.17934939903872354, 0.06455733480730227, 0.004902159362765295, 0.017358365967603664, 0.01642983320302197, 0.013233464227856269, 0.01828354676919324, 0.06467466029737677, 0.026701430158157433, 0.04510745419455426, 0.012633154967001506, 0.0545644919121904, 0.03890626498364976, 0.01735509542881378, 0.0327858859007912, 0.03252089083460825, 0.051540050988218615, 0.09255575242319278, 0.050866520165332725, 0.01593091997451016, 0.01169032631774566, 0.039540308461125405, 0.04730796700875674, 0.056780081774507246, 0.03670241377715554, 0.02755427743042154, 0.06021813050444637, 0.05901656712272337, 0.02477808702471001, 0.0068913488066755235, 0.05144104255097253, 0.02678991451726428, 0.025040454464033246, 0.02236088065962706, 0.004772367063976292, 0.05613754643127322, 0.017852495524234006, 0.03432492206671408, 0.0801105380856565, 0.004649949592671224, 0.027563517381037985, 0.041414232192827125, 0.05380015953310898, 0.051377124552215846, 0.026423011972968067, 0.046066135966352055, 0.01703393632279975, 0.060238907246717384, 0.07488568273505994, 0.06298289607678141, 0.016030210003788983, 0.029545966003622328, 0.026619491965642998, 0.00531810090511239, 0.07397925494504826, 0.01761418893667204, 0.03683412081695028, 0.05883567647210189, 0.021791545674204826, 0.02310525393113494, 0.0505418208028589, 0.04839832528627344, 0.01630031443866236, 0.0411024792785091, 0.033828641554074626, 0.039495616752122126, 0.03712296299636364, 0.06556020956486464, 0.023650344860340868, 0.03045353712514043, 0.04461863756711994, 0.044001340333904536, 0.014194090002482491, 0.01810962806588837, 0.03743606619536877, 0.07465832600636141, 0.03128553640895656, 0.06672891828098468, 0.16568291666252272, 0.1271773978535618, 0.08753724635711738, 0.16732421144843102, 0.13568595557340554, 0.1886160567935024, 0.14295520979378903, 0.14516133069992065, 0.10627142180289541, 0.06182254691209112, 0.11677314899861813, 0.12202072170163904, 0.1334031873515674, 0.09988184752208845, 0.09324985303516899, 0.16699167500649179, 0.16924617545945303, 0.11263063164161784, 0.16388152832431452, 0.15294674650899, 0.09846435394138098, 0.10091518171663795, 0.11981413939169475, 0.1381787575249161, 0.09986387312944446, 0.17049877824527876, 0.1102984728557723, 0.10564306444887604, 0.1122715509097491, 0.11085203529468604, 0.1409809443035296, 0.14309523228023732, 0.14137977361679077, 0.1314262348626341, 0.10055513746504273, 0.09089347054915768, 0.10036820785275527, 0.10473133730036871, 0.09135785991592066, 0.06401996221393347, 0.16922529015157903, 0.11109761068863527, 0.06700142472982407, 0.05636706429400614, 0.12747593969106674, 0.15100171230733395, 0.1119205786713532, 0.14262643243585313, 0.14475579746067524, 0.07233552421842303, 0.10867492176060166, 0.07066338323056698, 0.08800328456397567, 0.1757667205695595, 0.1366831170661109, 0.09024896406169448, 0.14509174014840806, 0.1714316281889166, 0.12885370504643234, 0.25528387299605776, 0.1414940253432308, 0.1546532077980893, 0.10359688781734024, 0.13669301010668278, 0.10678111016750336, 0.10848804643111569, 0.1509210616350174, 0.19578644846166882, 0.2300808568085943, 0.10984897733266864, 0.13891781786722796, 0.11347096333546297, 0.19804557652345725, 0.08109359962067433, 0.11647508213562624, 0.13975092316312449, 0.1590970829129219, 0.13669180231434958, 0.19099747043635162, 0.09786999797714607, 0.13067445877407277, 0.21817365288734436, 0.0807173451674836, 0.101455438083836, 0.24278197384306363, 0.11721507885626384, 0.13770862775189535, 0.13657673634588718, 0.12933760908033165, 0.11601430257516247, 0.10126787743398122, 0.19438197596796922, 0.2097867022135428, 0.1896180630262409, 0.17699609031634672, 0.08409783377179078, 0.13929264061152935, 0.1169206625116723, 0.2742750367947987, 0.14470265459801468, 0.15003485418856144, 0.12405856592314583, 0.07018675309206758, 0.1324844645070178, 0.1434303064431463, 0.12112113354461533, 0.0936716575441616, 0.1685409875852721, 0.07859398517757654, 0.13843428024223872, 0.18291221000254154, 0.08551133078123842, 0.11804840128336634, 0.1157023257442883, 0.21439377857106073, 0.14032211394182273, 0.1132902694599969, 0.0762860161651458, 0.12419507359819752, 0.21066472652767385, 0.15675959762717995, 0.1450205346835511, 0.14250705098467215, 0.10245545620896987, 0.11445825892899718, 0.1339684748756034, 0.08912549327526774, 0.16211174614727497, 0.1874747880335365, 0.11592336531196322, 0.1187872037823711, 0.053204073304576535, 0.08298530775521483, 0.19782098143228463, 0.16810992785862514, 0.14245926854865892, 0.12145943753421307, 0.13991218379565648, 0.14986429762627396, 0.10118915380111762, 0.11092417713786874, 0.12690360897353717, 0.16084808324064526, 0.11203518323600292, 0.0543556456188006, 0.23596969938703946, 0.1525086300181491, 0.1368529543812786, 0.06500974124563591, 0.09335769260568277, 0.11189235161457743, 0.1569428699357169, 0.20127849733190878, 0.06550982833972999, 0.15132017593298638, 0.13433177609528812, 0.08873104729822703, 0.12258603636707578, 0.11449306777545384, 0.09071703108825854, 0.0972023398748466, 0.15207575181765215, 0.15023363780762466, 0.1078181830900056, 0.061706931330263615, 0.1134324903999056, 0.07180198534790959, 0.1323338161621775, 0.111543652468494, 0.1638059802353382, 0.07479437906295061, 0.09162248857319355, 0.0855031544342637, 0.11179112776049546, 0.06651230954698154], [0.10537452742989574, 0.0414551580324769, 0.027746406317289387, 0.009292360661285264, 0.03055227075570396, 0.02495171226161931, 0.04488730011507869, 0.05127702367358974, 0.017781442729756236, 0.0407209899276495, 0.016685218517003313, 0.03456370532512665, 0.1076663676649332, 0.06606978936386959, 0.026910449477976987, 0.04056159865909389, 0.05024661057229553, 0.10201978244419609, 0.03374613508848207, 0.04207826352545193, 0.03030947396265609, 0.05566202909020441, 0.03674034049202289, 0.03153098288125225, 0.02704760685030903, 0.08169347885996103, 0.07817701183791671, 0.028740969020873308, 0.06688933074474335, 0.05933592641460044, 0.025135184737986753, 0.04260659124702215, 0.032356597150542905, 0.021985778019630482, 0.01254601834807545, 0.022586125448080044, 0.04529217517535601, 0.06409633133028235, 0.021327052830851505, 0.0237014860446964, 0.010214448191358574, 0.041374344511755874, 0.03848577343991824, 0.06283158276762281, 0.041905060676591735, 0.009437903030110257, 0.06963010331881897, 0.04772180551663041, 0.01777752927903618, 0.08027605313275542, 0.011794280427108918, 0.008787122638230878, 0.01809014393282788, 0.023797727755403945, 0.09411400809351887, 0.04458681766742042, 0.015076793663735901, 0.02205813699401915, 0.0430957946394171, 0.033046684227883816, 0.010511197848245502, 0.033117374006126604, 0.012526343377040965, 0.02774176004874919, 0.09726671927741595, 0.035028773226908276, 0.016484073596075177, 0.010196910605632832, 0.04794248206807034, 0.06178651670260089, 0.03195416820900781, 0.026397130951019268, 0.017970521601715257, 0.023657696787267923, 0.06949559053672211, 0.00790085836446711, 0.045448967654790194, 0.014734503280903612, 0.019217051499124085, 0.028622476450566734, 0.06937935070267745, 0.03519013563969305, 0.05809352879545518, 0.05056218024609344, 0.021942161788631762, 0.005808412430009672, 0.02458680291394038, 0.08950950338372163, 0.06936316764248268, 0.06689959019422531, 0.05451155600271054, 0.025873875278713446, 0.026077680056914687, 0.030963035499943153, 0.010323256370611489, 0.019388603811551417, 0.005105284757779113, 0.017265686565744023, 0.04472222272306681, 0.04629022554893579, 0.03363917422081743, 0.053445546954338036, 0.052914064044931104, 0.009261150594933756, 0.017565821264205233, 0.031059967620032172, 0.046948255239320655, 0.03474284874807511, 0.029907614990536655, 0.04783915136275547, 0.03351049344720585, 0.058740654428090365, 0.011859602993354201, 0.052235298324376345, 0.023984331670882444, 0.009652619499580135, 0.03734088469562786, 0.02751644401411925, 0.003089023250920166, 0.020634333037638238, 0.066734679043293, 0.050427681034696956, 0.033639337069221904, 0.020437808940187097, 0.017518011686791266, 0.02573025316399123, 0.0441083928037967, 0.03888342549492206, 0.09172853681125812, 0.07751377099858862, 0.03605392089645777, 0.016444816952571273, 0.04330078006855079, 0.020310682011768222, 0.017143049842811058, 0.04127260836373482, 0.05206798855215311, 0.009753314096347561, 0.05289492257205503, 0.019461303749786954, 0.02174840441771916, 0.042606628566448174, 0.021705658407881856, 0.04802812336544905, 0.062148521920400004, 0.0064907090771677235, 0.007241043278814426, 0.03885631462825196, 0.01801670778409711, 0.042537004088184664, 0.02622812144857432, 0.04181301061596189, 0.031240627568747317, 0.06400040004934583, 0.009761101982024099, 0.02835336946217077, 0.004166761413216591, 0.028494494568024362, 0.04467368372050779, 0.013887204728754503, 0.03225667269102164, 0.06098592680479799, 0.025261309130915573, 0.016483510412009697, 0.027623661028753434, 0.05068341409787536, 0.0523855293701802, 0.04538212177742805, 0.024004487553611398, 0.01059376198931464, 0.0762337079005582, 0.04814794586439218, 0.040726441956524334, 0.020652293859581863, 0.009184550776678537, 0.06611690683556454, 0.013522991727638458, 0.025597543588706424, 0.07780655207378523, 0.022659307146178823, 0.045928915829530785, 0.037518413205231936, 0.06164293869265488, 0.04019647218020899, 0.018919746291690638, 0.027162805133100067, 0.012978625134564936, 0.015599068852939775, 0.06470159135226693, 0.054932705725410154, 0.05142111058479973, 0.021888002819780792, 0.010181585892236658, 0.08262010663747787, 0.04603199886956385, 0.07529994871999536, 0.005873534404340067, 0.058754632249474525, 0.002904965962183529, 0.009837753538574492, 0.008528211486658879, 0.034141972062311, 0.07759837074471371, 0.03321977172579084, 0.031249770828123604, 0.02912841590919665, 0.018196276987769773, 0.008481101648482894, 0.0393140950639333, 0.021121511003002524, 0.03788213172395315, 0.013328309004594172, 0.07787352348012583, 0.026241005132240907, 0.04093602106773427, 0.03497752008427467, 0.03361586993560195, 0.04126201982476881, 0.03913881589791604, 0.007180223640586648, 0.014703796178634678, 0.022739722027576396, 0.06594926797385726, 0.015053114487922617, 0.05414171709812113, 0.0305609865380185, 0.026507372535499077, 0.034197177671428235, 0.008551730358574008, 0.019610293076506684, 0.07113657319652182, 0.019668945643518652, 0.022029087213533263, 0.05518556180010949, 0.018023890077269504, 0.0454254699870944, 0.026209661903391992, 0.045911738715533695, 0.015722163587010334, 0.09498316395495619, 0.06869985894965273, 0.06467900292149611, 0.07600220532289573, 0.0739756722801498, 0.011418844456784427, 0.017158457676747015, 0.03700086401243295, 0.056207968188183646, 0.05923270766756364, 0.03206696108515773, 0.03949029364490083, 0.009274810353027923, 0.03507773970652904, 0.05925667352442231, 0.04271612036973238, 0.024740253608407717, 0.030604473847363676, 0.07781572586723737, 0.026967892556318214, 0.020662032533437014, 0.06290847435593605, 0.03742056506286774, 0.004018255118613264, 0.10447217084999595, 0.050530024471559694, 0.0469606317180608, 0.04716174949758819, 0.014467352169698902, 0.028136926969247203, 0.02384817344136536, 0.025101123976388147, 0.06445619916277272, 0.035683349174048216, 0.043809735615338595, 0.02291316575636821, 0.07437435231570687, 0.03289931659985866, 0.0357128247352583, 0.04138866160064936, 0.015805168775841594, 0.05959302333316632, 0.009504770111691738, 0.001178100488946906, 0.04451289806248886, 0.04615849815309048, 0.037445172135319026, 0.03891013941860624, 0.050254498541887314, 0.025583650584199598, 0.028864886478653977, 0.023081298252301555, 0.011810617854020425, 0.04306066348882658, 0.008696884266100824, 0.02557104340355311, 0.01616786779569728, 0.022459157975390553, 0.06378340455038206, 0.016371314646676183, 0.09099922023181405, 0.036062378835465224, 0.025304072104128342, 0.003569664591590741, 0.08495036552527122, 0.08251346807394709, 0.023644010735941783, 0.023186362614589076, 0.024921573432428495, 0.02350669730055545, 0.046099845586078506, 0.026902983896434307, 0.015126594741429602, 0.044353360908904245, 0.07098270181034293, 0.03161056825358953, 0.03617017090852771, 0.018806234168420945, 0.04883387691474386, 0.03826414354677711, 0.01937598136386701, 0.03532959154940077, 0.0782533266714641, 0.06478258807744298, 0.021564521427665437, 0.02085207322878497, 0.05498431509892855, 0.02497607675780143, 0.005502587367248322, 0.03830763424879738, 0.019165094376408627, 0.04512781024511371, 0.03821611005280699, 0.07831691218806164, 0.03850174615425723, 0.0068926316619451556, 0.02451090537942946, 0.018551890405693224, 0.051039756940943856, 0.06228483960564647, 0.03287824808752962, 0.019623303985489265, 0.01986041126240577, 0.027627384489668266, 0.03543682722374797, 0.07737284606056553, 0.027666790410876274, 0.02769194370401757, 0.040873110693480284, 0.01629009230860642, 0.03262450313195586, 0.024558353636945997, 0.026166766615850583, 0.1907169640596424, 0.11144979750471455, 0.11160939572645084, 0.07405920672629561, 0.0816263717466167, 0.11780136025377683, 0.1546643900551966, 0.11246831249445677, 0.07674031571618148, 0.14163307073925221, 0.09370575392884867, 0.1214772422931024, 0.13604202360979148, 0.22479550327573503, 0.13014769846839563, 0.09667439213288681, 0.11971746172223773, 0.25375011243990486, 0.16056174146277563, 0.1878610508782523, 0.09912393747695855, 0.14020117186009884, 0.13516674057713576, 0.1372132021933794, 0.04969089039202247, 0.16584435371415956, 0.17694241819637163, 0.06549279032541172, 0.12182573787868023, 0.08637627294020993, 0.10438431413578135, 0.11750999731676919, 0.11284874672336237, 0.12309104284005505, 0.2013112705733095, 0.06578970367887191, 0.21834568865597248, 0.11621820234826633, 0.15096147518072808, 0.13235873196806225, 0.1205895963524069, 0.07870973646640778, 0.11369896467242922, 0.12149274003292833, 0.10131807545466082, 0.10241209782127823, 0.12122178742928164, 0.11093862314841577, 0.08736390780125346, 0.12880717111485346, 0.07621527210410152, 0.08588160055556468, 0.14754848474902765, 0.11866532532232148, 0.27974107063242365, 0.09804733988962003, 0.19313963263162545, 0.1396832867924656, 0.09888658592743532, 0.09146567234503371, 0.10780876502394676, 0.10262528673878737, 0.14081747164683683, 0.17607659394187586, 0.26252186032278196, 0.11174641230276652, 0.15599343659622328, 0.07764907088130713, 0.11454014453504767, 0.32190724515489166, 0.18895113095641136, 0.12205159504498754, 0.2222577008817877, 0.12796201503702573, 0.14338438319308416, 0.14949384464749269, 0.13429130826677593, 0.11495690074350152, 0.12782999926379748, 0.09909462476415293, 0.2709790665124144, 0.09827913423734051, 0.14480595476925373, 0.2267737314105034, 0.17791313039405005, 0.15101981562163147, 0.11668663578374044, 0.15008032960551126, 0.18891028314828873, 0.20735249854624271, 0.2152525053492614, 0.04587427340447903, 0.14150634753916944, 0.18638754423175538, 0.0975416616669723, 0.11671966686844826, 0.12113938613661698, 0.12415559643081256, 0.1683173831552267, 0.14384983107447624, 0.16377461834677629, 0.10186912731400558, 0.11875685969633715, 0.1506736677672182, 0.12453895514564854, 0.07336855307221413, 0.12284666166773864, 0.15097968706062861, 0.17758195102214813, 0.13223282301000186, 0.2726014708834035, 0.20177513068275793, 0.09219087021691458, 0.10250143374183349, 0.12343587433653218, 0.08236584599528994, 0.12688450142741203, 0.07632992416620255, 0.08420895066644464, 0.12585011550358363, 0.14477752415197237, 0.1287528340305601, 0.11923825315066747, 0.16326016666633741, 0.11581862664648465, 0.16818382032215595, 0.07530559413135052, 0.10866844853652374, 0.1324470229446888, 0.16417428904346057, 0.09711954503187112, 0.11650404201022216, 0.1281360728400094, 0.12011971085199288, 0.09625189551817519, 0.10530471974717719, 0.11344912807856287, 0.14623602160385676, 0.12405501039964811, 0.17690209964556353, 0.0615342373826674, 0.19750719969826086, 0.18230303483349936, 0.09719770548066922, 0.13119748713714735, 0.14060462878218719, 0.18205565453640052, 0.09321646911225148, 0.12358724192849227, 0.20147866516241006, 0.09468815049954823, 0.10722226649522781, 0.0993857705699546, 0.11580061832708971, 0.12494857316570622, 0.12053354935986654, 0.07421636222196476, 0.09406961833259889, 0.12328833368207727, 0.11022563890687057, 0.06077526203755822, 0.1644934719162328, 0.10068730930132525, 0.16521039844623633, 0.12493460891502244, 0.06963690902505602, 0.1518707528178181, 0.12582564753081116, 0.0982262763593878, 0.13993509113788605, 0.21961150930396148, 0.1850279364734888, 0.14523291614438805, 0.13789005444518157, 0.13498952080096516, 0.1742176522633859], [0.03837992197700909, 0.02224752799208675, 0.08098390764955964, 0.030369795725813935, 0.026170093133779507, 0.13226972174431595, 0.024677068427471176, 0.055718554449932914, 0.0849430373470698, 0.05130629567429423, 0.032264930462198596, 0.055210362255041084, 0.010541334132929998, 0.048556223777788024, 0.02259732806123793, 0.054255208865340264, 0.03338568371587566, 0.02201344189234078, 0.05782476785991873, 0.030717273508863788, 0.03224206383207014, 0.03957492731777685, 0.02870556984895042, 0.01729021391033062, 0.041978769935667515, 0.08070946059056691, 0.021155056077986956, 0.03895003388502768, 0.0211884450899171, 0.011832876347138413, 0.0299391193714525, 0.023913657159677575, 0.025823231121259074, 0.09460003594202654, 0.04297866253182292, 0.02589766471646726, 0.058306934844170294, 0.05444809940776654, 0.07034268043935299, 0.030872434111578122, 0.040272060981286426, 0.059231262387973924, 0.032657378153609376, 0.0680509012724672, 0.03922981422926698, 0.03996730715568576, 0.048188732604363134, 0.017653074082253233, 0.02597668520840151, 0.018030595699591295, 0.02711898025258311, 0.03110460504623396, 0.012965630340789045, 0.019370018737390637, 0.03728461378653135, 0.07444869939770017, 0.057736266537436416, 0.04045047837176493, 0.044814954711390395, 0.04212430891181741, 0.020216609916782806, 0.0497226051187941, 0.020775320740150552, 0.005868754973302462, 0.010549624982689108, 0.04418378482971873, 0.033215578379375596, 0.05487126098679645, 0.038099581841379404, 0.043866569708500586, 0.07277289432074342, 0.013956871615456683, 0.03759796125814319, 0.054226381305072985, 0.022085654981700436, 0.07485483653311219, 0.042061378181512864, 0.04126221320724913, 0.0598084582015872, 0.015489895961114337, 0.05811161853905235, 0.0370085687775697, 0.09406701954347746, 0.08702487099383559, 0.00668583412022729, 0.10380717260496956, 0.03546337829902768, 0.002448069318363975, 0.03457230914916311, 0.05707146506756544, 0.007426852460152337, 0.019156336185655425, 0.046953978682202954, 0.013820550537535121, 0.056453092356345484, 0.012947362481749483, 0.02842123314206089, 0.03490242322108575, 0.0529165271270488, 0.023335095794339265, 0.024469178868457675, 0.0180170131248555, 0.030878564675471613, 0.03605933899858168, 0.0756849902016776, 0.026167735224589705, 0.024979094542296867, 0.027534725443859185, 0.0414748355480177, 0.026186939461955, 0.04955139716288873, 0.003207457509623574, 0.0564271791039833, 0.0299982604836779, 0.022166746701779108, 0.04606938614909138, 0.018300119987023727, 0.008575567293779125, 0.07741465060306446, 0.05161396720047508, 0.06155998778662511, 0.07991946940975529, 0.044699898920953274, 0.014663486109514321, 0.049678191609148464, 0.015899459698370526, 0.08425067378474133, 0.010649591002480259, 0.013995882290016328, 0.01978007101986025, 0.002926548252746995, 0.04944888409227133, 0.04150419236559953, 0.04481779777311853, 0.04310316352971962, 0.02963558690888541, 0.0436732822230884, 0.01601717704241829, 0.02524012526763337, 0.04899889323860407, 0.044406022011701546, 0.0430172779597342, 0.04186463016750557, 0.006267150448236082, 0.045458375542823753, 0.010094443336129189, 0.05803750894431557, 0.027808743329452615, 0.022314406099862287, 0.046002713298158984, 0.015307841622935874, 0.05206299792709095, 0.052923305691885095, 0.05228194760690842, 0.029978447261133363, 0.04559556853824428, 0.013648070328469788, 0.017136103340557644, 0.021878649214548723, 0.027507575561425517, 0.04049253057954567, 0.03269725565665534, 0.030036149879119227, 0.020282415939228873, 0.024964366939717104, 0.008448397108752812, 0.0581942776750241, 0.06599278242460319, 0.005353624333760568, 0.01799012956741665, 0.018906007653900554, 0.026251171283157806, 0.02635973010079137, 0.08013854122587613, 0.018532657330589633, 0.035969517925488095, 0.08535114223403589, 0.018232755030372312, 0.03481092616649611, 0.06824047038597719, 0.02110484448660697, 0.042903189081698656, 0.038498652034572194, 0.040295124386570284, 0.025180100363546183, 0.06961330279175725, 0.056944612945829115, 0.051731380900102, 0.03110102577401059, 0.02450547201026763, 0.031229692976921797, 0.024022923350068073, 0.01803203589016838, 0.08295925879584891, 0.005870117556436786, 0.06134603212454489, 0.033269189431199005, 0.034950609385435066, 0.005175325262825936, 0.05282343551516533, 0.01340251020155847, 0.008126489917880722, 0.02124974563983934, 0.024287092299865823, 0.05380998472017901, 0.013933689466544559, 0.048641213681548834, 0.022970863285341432, 0.06025821156799793, 0.022967814966770153, 0.04632188938558102, 0.012255648616701365, 0.05280606162601283, 0.04088959570175835, 0.04053768708503672, 0.020946172465171133, 0.035784053948840926, 0.03321365812527282, 0.04981850925832987, 0.010852113349496253, 0.0688288484566978, 0.014472734648734331, 0.016245795846251503, 0.042556739279202054, 0.05091769866911428, 0.011956169552701925, 0.021896224967869263, 0.04945771522553904, 0.05418307041483266, 0.047873359705720625, 0.06972954941115209, 0.01242289223176028, 0.04842797387391329, 0.0019562385111515012, 0.004448311461601406, 0.041874814978135486, 0.03402651593621288, 0.02678847941569984, 0.025203625172642723, 0.019986615383199284, 0.03260433367852654, 0.038955027902764935, 0.028509452872510468, 0.06378896175218479, 0.02149861871397921, 0.025929099547543695, 0.05883359336959464, 0.035655529238283634, 0.08738843005682741, 0.038898013997823, 0.049172632130129, 0.047347885223903825, 0.006471247844664114, 0.013101428098577474, 0.07715256645211152, 0.009313338419555553, 0.060689237367893965, 0.0499406862737877, 0.049385488565479, 0.024981822253071835, 0.034112435432949235, 0.06873633699225527, 0.042539117724767754, 0.05481014533766678, 0.03414276594828282, 0.06407102197408676, 0.03179955382698348, 0.025066817245845283, 0.0337160997358816, 0.016372167904462134, 0.07778205695961203, 0.005882902428441281, 0.06304546379085098, 0.035119897087237666, 0.016877323655145507, 0.06053003269646849, 0.012217920373326965, 0.013876497446160232, 0.034412822885704894, 0.013908257974045617, 0.06426665719066348, 0.020563458358602862, 0.11420585747276034, 0.0360863887971001, 0.04409996200618999, 0.034281509396220954, 0.02134702550912542, 0.04061357444152236, 0.018896854216498987, 0.01608972091759954, 0.013822864341948713, 0.07483114887561117, 0.03995626399825726, 0.054419468622654676, 0.0823539173496621, 0.012811228849126824, 0.0448558160902134, 0.07436320398535047, 0.056652442552149296, 0.027733083282198225, 0.03408378089911171, 0.016283878624173145, 0.020336328939135586, 0.03261471187163677, 0.0062947574936385664, 0.038138665458453555, 0.02905516805393355, 0.029415870484496866, 0.028929201420396566, 0.02390446131383734, 0.020252182115135447, 0.010002696919920189, 0.02510255907795259, 0.020690615821097578, 0.05134089417489512, 0.07394215943557875, 0.05573826589222465, 0.038160344652299366, 0.011857601315049189, 0.05374851623283965, 0.01716800975347204, 0.03096285229548812, 0.004178464021866343, 0.008040073394243206, 0.039566184394061565, 0.060333325394562314, 0.01733755529858172, 0.05431329485561166, 0.044018045866063664, 0.050241982963468344, 0.05099276499822736, 0.007547587588695543, 0.03456079101722155, 0.040168716705271175, 0.04185710521414876, 0.035820440389215946, 0.03785137373155781, 0.10629221890121698, 0.023162445951519266, 0.0323878267247762, 0.03019136137195996, 0.0694799367338419, 0.01555844665771084, 0.0720222649563636, 0.0305492377041706, 0.007251490173595292, 0.05030517153707998, 0.05426952595423375, 0.0070944428194447285, 0.013205746072344482, 0.10762070225817816, 0.06729907768645457, 0.1543319621788604, 0.13312508298882417, 0.14903579279780388, 0.12259013471858841, 0.12028447272522108, 0.17781861046595232, 0.1326832752674818, 0.12408243678510189, 0.2125890925526619, 0.11799333138125283, 0.17793056874402932, 0.16877007457826818, 0.1316524448671511, 0.10294462567461388, 0.17481952639562742, 0.13416628140423978, 0.2157347673284156, 0.16326919118208544, 0.14538629220000335, 0.09257443927760635, 0.10969153685229165, 0.2026450125766652, 0.11393676405506474, 0.14816517808607646, 0.09092562632369143, 0.11875052217926298, 0.07244301773607731, 0.10741186953548874, 0.07290068282080547, 0.08284255077264138, 0.12195137542273317, 0.03523360598566277, 0.10895052911447627, 0.1382473302739007, 0.10607166109340531, 0.06561447879565613, 0.15149222527231487, 0.1350964850613049, 0.1750785367829459, 0.1672482155263424, 0.07155250837760312, 0.1934422863913434, 0.1274861448577472, 0.1468824619161231, 0.1005737225392035, 0.09826615386243377, 0.07794730737805367, 0.10112370909856898, 0.09438620920159987, 0.10327310447714158, 0.07150751472051654, 0.1401518830763442, 0.1828469213630472, 0.12153068371117115, 0.14130597614816257, 0.1160968260041305, 0.11809170538825647, 0.14497014667306626, 0.12471352863524642, 0.13192753653441155, 0.13840161556644098, 0.14309205673635006, 0.14098299347928592, 0.08257698573704277, 0.15322761929460935, 0.15181653786982807, 0.16269517769770964, 0.18170753893043312, 0.14966335626585142, 0.09507052533860717, 0.10688082088849374, 0.1074581795505115, 0.09603418077209167, 0.14169517026415893, 0.08762317603187901, 0.1267955590571676, 0.13855936138757638, 0.14372331143489905, 0.17662105044083937, 0.0827650281467608, 0.13071062469056674, 0.1591787649584668, 0.17903070471116475, 0.17308498732745647, 0.11473995952733926, 0.18389521725475788, 0.08415160088666848, 0.16323063682232583, 0.07636997130300317, 0.17669811844825745, 0.08941431849130563, 0.08680179582110473, 0.10530349159879343, 0.14171212006892475, 0.25357287909303394, 0.07789444271475077, 0.0596731108214174, 0.08428443768726927, 0.13726614149553434, 0.16606323554047517, 0.12231292602206979, 0.09196924032377345, 0.08911606163850852, 0.1583622159170253, 0.23496693319508008, 0.07863412730927978, 0.22432872546570642, 0.14604570610182627, 0.13004036779914582, 0.12365624893988882, 0.10166806381727968, 0.09250589367002249, 0.11662008506911141, 0.17646817650113786, 0.1226635929197073, 0.10320676410836832, 0.1524516059351819, 0.07665521385414259, 0.1720500314342124, 0.1410856693983078, 0.14777495259685175, 0.14275972385491642, 0.13049003295600414, 0.07267374678381852, 0.1786758987499135, 0.13805177648152622, 0.13864261763436453, 0.13523046858608723, 0.07446636166423559, 0.07684582791158132, 0.14338815584778786, 0.12292562957320895, 0.12029916979372501, 0.07246642719422068, 0.09348090777971915, 0.11466032665755067, 0.15403256538723195, 0.09369221715522663, 0.12739608969007218, 0.17067219822534493, 0.1402355328734432, 0.12956399550395353, 0.13511715323797294, 0.10658768018973724, 0.09032690737928663, 0.0824996056035161, 0.15181952342391014, 0.07635858548539025, 0.09457974774496895, 0.11995812452265195, 0.08643362950533628, 0.15342416374811105, 0.11308544687926769, 0.13029073365032673, 0.12457167410424777, 0.13157263557825769, 0.09568493201264314, 0.1337420477398804, 0.1221664303115436, 0.10007474824254002, 0.1552634143403598, 0.16745348594018392, 0.08022803999483585, 0.161015301410641, 0.09909223632088729, 0.133890049798148, 0.11210982887340443, 0.10765397761549268, 0.12033328653446265, 0.0966248997886266, 0.09450405037828855, 0.1531951581793172, 0.1663046447294099, 0.17419577629438468, 0.15825906502349035, 0.12523488780217512], [0.03391722769343427, 0.04034279825698052, 0.018806011948202337, 0.026823865016922355, 0.032334297097155025, 0.05865420228136437, 0.027738503080659678, 0.056628646329045296, 0.035245049478752274, 0.014725287079012819, 0.04788392449596098, 0.03136269262592707, 0.03218731962676559, 0.027333555077867847, 0.019228040373751094, 0.02408700419722923, 0.055928116597767384, 0.020216776157862375, 0.055838906206190586, 0.021032588988808647, 0.035702297264443975, 0.055231111855911355, 0.04297884573627796, 0.04275641517181482, 0.03404228848272136, 0.019942033936136534, 0.029788582984890257, 0.02683051466010511, 0.058531000678028376, 0.026288168405049613, 0.022750310566542403, 0.02459455348019089, 0.032853844575583935, 0.010872539798063892, 0.028355003035228168, 0.009134596180436867, 0.07433356557573591, 0.014060298163842942, 0.01651067386514374, 0.018344340114189044, 0.034815224685839245, 0.0319703885886286, 0.03044395281800202, 0.021362409594335725, 0.012605669209733605, 0.04864219755732587, 0.06968498323112726, 0.03393575848479356, 0.05948019653026547, 0.037244010251015425, 0.09522550952221666, 0.018132727094260708, 0.01649936268638287, 0.10365948945816074, 0.040474247453468185, 0.009746619500219822, 0.052622524688818624, 0.0373980444855988, 0.059523588844708035, 0.02110403702993478, 0.03672801151073404, 0.03654013194942048, 0.013100108347966202, 0.037458888720721006, 0.02584476612641343, 0.030388207773544958, 0.0020609918075414108, 0.03005924721115402, 0.033956745572920354, 0.0742031918572528, 0.05904980855328696, 0.02927470127386706, 0.0025127975303413613, 0.03819382357011948, 0.05221055215224624, 0.019930375008178607, 0.004530203428917697, 0.035461739636957645, 0.017309955886698196, 0.02315472422300705, 0.012927006431190031, 0.06682875113827841, 0.00670927920145914, 0.058274724786835055, 0.09591933872018542, 0.0236630300725145, 0.02258203218558005, 0.032691501679697206, 0.03842903094898377, 0.03216421550938061, 0.029155292681285312, 0.0337546065981899, 0.013461674214340746, 0.0387816927395761, 0.03671500399442656, 0.05036795298968043, 0.013875562764172043, 0.044348366891166995, 0.034286004690719504, 0.03443085156115038, 0.04229335234101329, 0.08122834989002772, 0.020547522963689904, 0.018119052917297398, 0.07040089874395303, 0.03237544346068587, 0.034791913615273576, 0.0354783773156149, 0.06756330600806645, 0.05625316540577582, 0.01873917455252792, 0.03377670987642237, 0.03863666945004037, 0.05950131932539599, 0.030278872033315044, 0.008375093274350678, 0.022269600736243383, 0.03703892304162894, 0.035179835478109975, 0.06815458820866686, 0.03148062201216817, 0.03505169413983822, 0.03818966754313026, 0.023238524994147674, 0.03404092123465879, 0.024497126029538255, 0.034107719614569626, 0.07565248158893415, 0.0350259505212307, 0.008838109455869665, 0.035356583672442606, 0.08058513940445014, 0.020380391306909065, 0.00892473802170051, 0.02616232051514089, 0.017164481371375065, 0.05734876197363649, 0.025478862724932175, 0.03311679385868566, 0.06180862337350845, 0.008779047223340188, 0.023005192068272402, 0.08793387043156795, 0.015869383633668934, 0.01838062477431127, 0.04082633927464485, 0.057979385634618144, 0.04883748332836798, 0.08072616612272603, 0.01728804429460849, 0.05988858640193939, 0.03836006125701325, 0.01908303065491574, 0.029687715361693075, 0.07600073290190526, 0.014185363193973899, 0.03406779122139726, 0.01618920941837132, 0.03748474090493151, 0.04255194203662021, 0.06527518414493118, 0.04588659220774259, 0.058871760964393616, 0.07559902660016503, 0.04795713163912296, 0.019032320340297053, 0.09114290002201285, 0.03242674749344587, 0.06668210615004812, 0.021390473802707026, 0.04018921185550945, 0.05627813210178699, 0.01754123454780451, 0.021445971181882278, 0.051762858139617104, 0.023127435240894556, 0.016060766132016267, 0.026028849284297655, 0.01458173621046756, 0.08462523190038544, 0.022860172171411768, 0.07309364460940872, 0.05500281874888709, 0.08868954131113631, 0.02992252240489636, 0.04904734403161066, 0.02280962809787265, 0.0894725639373064, 0.03616259167236941, 0.021895646516765867, 0.011390461336954363, 0.06879976644579854, 0.021895928108798604, 0.04181684433881726, 0.08021980936505965, 0.012056697060221007, 0.02635694301820227, 0.01276118095432009, 0.015540146568257893, 0.04715336959010788, 0.03136100646640573, 0.01755843710686479, 0.003144008124114147, 0.03291219180183751, 0.016757205993469273, 0.028486511603529965, 0.027344940895480768, 0.015526535155783807, 0.03202372483376946, 0.009407563184920167, 0.009705423094731356, 0.0519055336979883, 0.024310106511360834, 0.012035503867082298, 0.05004025789509926, 0.06097188791526215, 0.051226058908339055, 0.025509959984836832, 0.03808536992541381, 0.020597159496641586, 0.01163551680344556, 0.05175356560253671, 0.09992433059960604, 0.014535526279360056, 0.04710194342104452, 0.0168327981872218, 0.026237397022279244, 0.04256118707624929, 0.04580520193225571, 0.04598464730328747, 0.006925890904052981, 0.007966140218611275, 0.054427231063268015, 0.02357295454878892, 0.047294718612517626, 0.027072851745677844, 0.035699270998260806, 0.10250880941748619, 0.01358095049259386, 0.012527206812852194, 0.02221657152819846, 0.043847971063639433, 0.009982824325561523, 0.04171815142035484, 0.018777488032355905, 0.06355346260326249, 0.03428184187838009, 0.03460895682552031, 0.0320590968642916, 0.0491516450420022, 0.007678131789102086, 0.04074353764631918, 0.025594490181122507, 0.06243183743208647, 0.028526361965175186, 0.04606481960841587, 0.05410960542836359, 0.053914421437574286, 0.03151440627074667, 0.07621104483093534, 0.04635631825242724, 0.03486972461853709, 0.010362582563954805, 0.02495656717967774, 0.05210081946903041, 0.03381247206458023, 0.09344569859760148, 0.04839612344013793, 0.052344247299645624, 0.03301405008616192, 0.0314828136802784, 0.04109343779938562, 0.025199905104402984, 0.015579583023541739, 0.01764911483041942, 0.05402115499600768, 0.039824143052101135, 0.010998585311296796, 0.036203605721571615, 0.00783318467438221, 0.017739373558600034, 0.0490928058778601, 0.04341499786823988, 0.014150763845204242, 0.011250681426775242, 0.06883384925978524, 0.008863087178074887, 0.04028934666088649, 0.028383594804576466, 0.03441612056589552, 0.025294190937919275, 0.018011557703305568, 0.03742596620161619, 0.028190497308969498, 0.03062670604724969, 0.06484727960612093, 0.02717586693220905, 0.048811736317085366, 0.032161402981728315, 0.06443517136254481, 0.0401792950662119, 0.021251189223091518, 0.10247016006282397, 0.008845862566626497, 0.013158241835688906, 0.03942907960819347, 0.026404720365202854, 0.08346353923635823, 0.07752363011240959, 0.016320187033021023, 0.03815612755715847, 0.013572257610836198, 0.03239729228828635, 0.018215218292815343, 0.03194183583504387, 0.007660567061975598, 0.029582233700369085, 0.024067874598715986, 0.015926560387015343, 0.05552530428394675, 0.025158892751538327, 0.0231408922866519, 0.028932102157601287, 0.016062806826084852, 0.04518783684553845, 0.04906104026096208, 0.08191807395113365, 0.04433629914586033, 0.028406963550618718, 0.032767714732991796, 0.08579655297632728, 0.06397935867841754, 0.0564919384861631, 0.010163217101113071, 0.06856465406183686, 0.012900482497311063, 0.051204953076584, 0.09450350076492343, 0.017354822318468775, 0.04271492954077465, 0.04925906052812934, 0.030097007684941803, 0.02266632828728429, 0.0472413687966764, 0.03892953534211431, 0.013563040560776634, 0.03029560809955001, 0.011138578111838018, 0.009578058679055954, 0.0263843643146434, 0.03598814371174999, 0.023402374237775803, 0.12490156425961427, 0.11332959056432758, 0.07752730777221066, 0.13946283076490673, 0.20223772871707166, 0.15337530922676834, 0.09997799593423094, 0.1630949026771954, 0.06469363213649817, 0.12744662697826112, 0.13047821287597927, 0.2049551121890545, 0.09566272356148277, 0.143926559814385, 0.104411699809134, 0.1542671892259802, 0.1998153179883957, 0.13296216673084668, 0.15150359751922743, 0.0874346722183483, 0.13846245301621302, 0.12009539215692452, 0.08108601359916584, 0.1538647636771202, 0.0924925875983068, 0.10782797435032469, 0.10901380250496523, 0.0933764608842986, 0.11631422862410545, 0.101819112497781, 0.08283806565616812, 0.09653282258659601, 0.18238084922943795, 0.1352451385131904, 0.12223368670259203, 0.12901786980884417, 0.10496292130223342, 0.1677557054374899, 0.08880529938531773, 0.18732409897659505, 0.2044779256518398, 0.12932701036334038, 0.09949987980404071, 0.0900614984067423, 0.11529339982994966, 0.1914578971586057, 0.24018728307315282, 0.08968410401472024, 0.08523001016250678, 0.14650271300758633, 0.11773409029202801, 0.17457773722708225, 0.09283902722277812, 0.18116312314357075, 0.09999244873012815, 0.07538648907627378, 0.17483900035066263, 0.08106394085500922, 0.10287620220333338, 0.10900064571095364, 0.0891562376969627, 0.15693388613207, 0.11139541292296988, 0.1059334027980055, 0.17728970598961624, 0.10825686955026217, 0.1257735224706786, 0.15142271614500455, 0.10935072228312492, 0.16280606389045715, 0.14130137568073614, 0.0969180879848344, 0.15771764836141042, 0.12389285410089151, 0.17380591721407004, 0.08792530053428241, 0.08563559768455369, 0.14332115730004652, 0.17762703288878712, 0.14201983569988183, 0.1624165712190526, 0.25675889956099646, 0.1435368771531752, 0.20561094342597894, 0.1881815501089607, 0.23307952018720762, 0.09661451820284128, 0.13097362486379488, 0.16983187331684999, 0.055217361343758445, 0.29149886114256723, 0.14243102792118276, 0.1252286181386028, 0.08931188684489046, 0.09023183783782379, 0.13809438848069736, 0.15115124785474368, 0.11340716747300965, 0.1424086091241666, 0.10399610389556203, 0.10175438025700194, 0.12615005512322697, 0.14106491979743752, 0.1274055756096329, 0.1916206098560776, 0.12219186180404254, 0.07852784836930887, 0.1100320867928011, 0.12129551704440798, 0.1072541033583028, 0.09862929901906423, 0.10017488644059215, 0.16008456849626132, 0.14893661811947823, 0.1239515473800046, 0.09141043280916554, 0.09958496809537921, 0.1062225808522531, 0.08871773444116116, 0.12008579767176084, 0.1220316868275404, 0.15253250088010514, 0.10525732407612459, 0.09007616154849529, 0.06577658081161124, 0.11561429261096887, 0.13991614644016537, 0.1254949024213212, 0.12881034665874072, 0.1669630951115063, 0.11399093829095364, 0.12950579077005386, 0.22096905431577138, 0.09118818544915744, 0.14992045318441732, 0.20509699386145386, 0.2410669901541301, 0.08984695241919585, 0.1383415245051895, 0.07916133544806923, 0.07356830021100384, 0.09528685587325267, 0.1459469385445118, 0.12936137137668474, 0.08543466310948133, 0.09122859220951796, 0.12528276523309095, 0.08313504007777997, 0.13740084426743643, 0.09060488282037632, 0.12243070613060679, 0.1392693668603897, 0.10486975165882281, 0.12652744272989885, 0.14431958086788654, 0.20811084285378456, 0.1114356704056263, 0.12046258816761629, 0.1565651973443372, 0.16712769413633005, 0.10581032333097287, 0.18579401608024324, 0.12244709953665733, 0.24088256433606148, 0.11865562227155481, 0.12304564884730748, 0.2693227625318936, 0.18645157079611505, 0.1562199451561485, 0.09063450087394033, 0.19153530443353312, 0.09444338256227118, 0.21822994415249142, 0.18367614543863706, 0.1848184862839324, 0.12160651678485529], [0.022130967550245777, 0.05301690281235746, 0.05099675478413701, 0.00932351390032896, 0.009414239121334893, 0.038372057756142955, 0.06038449372031859, 0.05848792727504458, 0.04914599623797195, 0.03587357985920139, 0.03442143688776663, 0.02707467191586537, 0.04762054095044732, 0.01452850513825459, 0.045718186601464234, 0.05468029409114804, 0.033013832954955954, 0.06644930078514985, 0.006691574950569442, 0.01209850245088871, 0.08372938925666468, 0.032370642825428925, 0.0969695887927498, 0.011067288678272494, 0.05794815945305994, 0.009233519800805619, 0.0295648564185415, 0.005469376470760575, 0.023801016953906844, 0.05330511395420347, 0.07640858673091445, 0.011597439962705331, 0.013998107884877493, 0.059327119030058384, 0.06159121396818331, 0.042338101725493155, 0.056041452301932235, 0.06384145322122745, 0.08342125971934625, 0.028478348827255622, 0.026062935490959456, 0.0074801751345928225, 0.028703503709818636, 0.0168788079504988, 0.03426472583253469, 0.06642511779708521, 0.014943139228437628, 0.02972672094724008, 0.026920215293232883, 0.06306529736944608, 0.06285064960164682, 0.04784562797950847, 0.03241190793258803, 0.008962835218491299, 0.01787808647246233, 0.0581676180341414, 0.03542538373065846, 0.0779795174353889, 0.024805202980392745, 0.00798016893012183, 0.006976957025472075, 0.027778972605509416, 0.047576941682824066, 0.02442120304996414, 0.03407327039167285, 0.0037451002447466764, 0.016555358788796833, 0.05314979050308466, 0.06435738410800695, 0.059596918124173365, 0.015157839582700814, 0.01881114506561841, 0.029153565809662853, 0.014998407602044088, 0.04280002122478826, 0.08810354489833117, 0.012172902967514736, 0.022749667654612234, 0.021425599864284908, 0.014136462871517454, 0.01267862190226359, 0.03300067616094436, 0.0763582665739315, 0.047207822025354416, 0.016981758676203232, 0.00568179101017969, 0.024487241470654095, 0.019404001467462097, 0.04274645088506596, 0.06740105471440724, 0.0012141186120321176, 0.045709864369460514, 0.024301972572824786, 0.012641679063173277, 0.04862835205027035, 0.02749740262515843, 0.04382798820734024, 0.05297257072691407, 0.006198930113376784, 0.06513723119028977, 0.023473201419359872, 0.021852194830509167, 0.04297973122447729, 0.021090193219216805, 0.017201663394059454, 0.06124590749719313, 0.003385167527345142, 0.08394960779696703, 0.04620121871786458, 0.022719659443412508, 0.03178385252665196, 0.03339814501149314, 0.046728630417159626, 0.03364823266331639, 0.05020233616232872, 0.03775663667225412, 0.02412512938358954, 0.030057025008967946, 0.04523343100611653, 0.03806820298944201, 0.040035238689077754, 0.021139241123039807, 0.030417483166924546, 0.010906391061975487, 0.006127113967003035, 0.015116011291476232, 0.021385885209643414, 0.03206133942252823, 0.006948958974265094, 0.0418480501643249, 0.021232956987140433, 0.04415957809292844, 0.030297494426901852, 0.04960614476086838, 0.01955248528559293, 0.020874061156064272, 0.05662782530167273, 0.08969646692276001, 0.03492827879797135, 0.026190001351226653, 0.035390666486429315, 0.05673736799508333, 0.026350306945719888, 0.012746828242338129, 0.05140562641567417, 0.05801326488809926, 0.024309672248948897, 0.026240223120631914, 0.039738332120967765, 0.019273242680355906, 0.02752509872828211, 0.007223086697714669, 0.026734652929008007, 0.03587238224489348, 0.003346512659585902, 0.022344960531752025, 0.04375153088143893, 0.028620196572904075, 0.06424921205533402, 0.025521384818213325, 0.03407673092026796, 0.07383257603006703, 0.02060055386807237, 0.03182810658056821, 0.032387182116508484, 0.05709305605185883, 0.033163565277521095, 0.04194248866822038, 0.011082996763954205, 0.02840627314123724, 0.02536163222976029, 0.036330647833113155, 0.019605551813063875, 0.04816161155966776, 0.043316030143094916, 0.05581609046618853, 0.00941772763949952, 0.03982356290466019, 0.0343688402457961, 0.010629545381691839, 0.005240371750135506, 0.02390737222906734, 0.10131118832422153, 0.026009259978309274, 0.013078071226898049, 0.022608355951628516, 0.020101623676185097, 0.038268550631723235, 0.03287617177037256, 0.03779647346319897, 0.06840836709099156, 0.03606743052867906, 0.03557047487369605, 0.04024928595338549, 0.013305210824390607, 0.07694215952817883, 0.008021318686327763, 0.031549194761152775, 0.04748743612851415, 0.028043222979509404, 0.050433869274067025, 0.09262241848877498, 0.017463398099477802, 0.039470287039875984, 0.010054157015734484, 0.018445865916354314, 0.058498600630887916, 0.020518481664891754, 0.04655936307140759, 0.02615982011359717, 0.03141186945140362, 0.052311155146786144, 0.05206013111663716, 0.011386500388783003, 0.0359080155113978, 0.016491635868858014, 0.033461448936057944, 0.03530379704066685, 0.02535058737599424, 0.028511264561010257, 0.027179327460804155, 0.053427667556596656, 0.007724000756362719, 0.03866588716794338, 0.05075903682570372, 0.06803483356322561, 0.04173666185566357, 0.01842028514615127, 0.038882421263094456, 0.037912865967622826, 0.03761265154129692, 0.1060916507350547, 0.026743445046512142, 0.0350427171215415, 0.04328600836119481, 0.03472264876056995, 0.03511356296283858, 0.023863589756989052, 0.0064146147675013965, 0.031647802862737856, 0.05149851107437696, 0.076279692218772, 0.012433864991180599, 0.049929809357438765, 0.019798871528889452, 0.024687365196379166, 0.028299342807648436, 0.008960084607159453, 0.038310439991099496, 0.0009998985333368182, 0.012761654232495596, 0.02977800801662462, 0.006059966565641973, 0.031846908785934956, 0.0254422778130642, 0.01051834027748555, 0.03729585711179035, 0.023342379867764454, 0.09630620546106781, 0.025767791417560408, 0.06882642608668123, 0.05146097790982042, 0.04561469644041998, 0.06958240909235817, 0.05656974270407643, 0.028977815061807632, 0.06184672311480556, 0.04475459223613143, 0.06893632161830153, 0.03541581638689552, 0.031397325053278885, 0.06789872622383492, 0.05512020191443818, 0.05079426636387195, 0.01688356278464198, 0.01132503868679383, 0.028836537285574844, 0.08322528523526021, 0.071640629720475, 0.024050690699368715, 0.03511363760169063, 0.0899960808455944, 0.015896759128996303, 0.0812333846198661, 0.08291220239230565, 0.01704526107226099, 0.09815159679523536, 0.03222684768427696, 0.051258913573942015, 0.01478303549811244, 0.03294720420879977, 0.051030155670429976, 0.025721691748393432, 0.02681315773432808, 0.016800016464133347, 0.0677129840478301, 0.04560334454955799, 0.04736549999298794, 0.03544111217239073, 0.024086127190717628, 0.055385322509599585, 0.032773064981613836, 0.00920663115435413, 0.023355034545862248, 0.02293488905499024, 0.02584472711064986, 0.01501318100573761, 0.019023657144446458, 0.09426443252180304, 0.029710246116987298, 0.04074898628251893, 0.055733353298689635, 0.031166182099176303, 0.009407726881493415, 0.07772487681359053, 0.026306320913136005, 0.014581132314300962, 0.0481953279647444, 0.032521990061338456, 0.04557252209633589, 0.029118295559393506, 0.016573618166148663, 0.00931395758276007, 0.013657864981463977, 0.008269671833009591, 0.04636908149612801, 0.01124992994924209, 0.05091524237234678, 0.0505272085512323, 0.025416430717866336, 0.003175351140920871, 0.060819801076182296, 0.031892723470394096, 0.07858951363180365, 0.037026176761303625, 0.019510205768580948, 0.01036030353446092, 0.07296462117561273, 0.019242484687960575, 0.0841573616489768, 0.043660227209329605, 0.08420819070722375, 0.05806049771074738, 0.05065805045887828, 0.045817982139331956, 0.06858889811805316, 0.021070659892367463, 0.06485214470220463, 0.006559127883519977, 0.04312136523159487, 0.048893995117396116, 0.02968488247799022, 0.09076683555862733, 0.18461151953254426, 0.15250082686543465, 0.09617692418396473, 0.07917074672877789, 0.09075004860226597, 0.18913538035537514, 0.1510971143309559, 0.055065342358180454, 0.0767570755311421, 0.10229746611522776, 0.24581765809229442, 0.1337178104690143, 0.10758469240473849, 0.12087014344121728, 0.15502229013613292, 0.13102021307817527, 0.1989915900464569, 0.10203819109925202, 0.16349933668971062, 0.19141261173146112, 0.07013444482747998, 0.2279683601643358, 0.08659052037234817, 0.19467078761330672, 0.13709675201347896, 0.11556269680815083, 0.0932705279971872, 0.1503556112625769, 0.12920438551477023, 0.16511680132576398, 0.13807606803519384, 0.1452748631792409, 0.10561232002718107, 0.14163611057613576, 0.0993008790537715, 0.1878383063844272, 0.08055339075092759, 0.15086448538516248, 0.1018296569319708, 0.09891502333006688, 0.0939246764672654, 0.11738378980330058, 0.08002914102481944, 0.10408048651048116, 0.12928348912724427, 0.08644601276942662, 0.12342066158141408, 0.1325434563415391, 0.12522665038704872, 0.11685531958937645, 0.07465510296502284, 0.14149816440684454, 0.14101658096270903, 0.12694018201104232, 0.19003215937742166, 0.11589603392141205, 0.14745707251131535, 0.0729377715449248, 0.11844956475709166, 0.13201669603586197, 0.10570812238646404, 0.16501127555966377, 0.1096479341919933, 0.21913889609277248, 0.16823441189314636, 0.09721872649554696, 0.1085025060123631, 0.13565648001219544, 0.149844905095441, 0.09075021145067044, 0.10881728519286428, 0.09824980116848435, 0.16481809663985456, 0.09309444137449775, 0.18130900817258017, 0.14252944264028752, 0.10630513820797205, 0.09789644727217299, 0.11614422846053328, 0.1250248540725027, 0.14929610597235815, 0.29012349780116764, 0.11669209120529038, 0.2667549146073205, 0.10999265712286745, 0.2095876878925732, 0.17490103202206747, 0.16565403821212904, 0.09522114654204675, 0.16042774436729296, 0.16662565964673245, 0.15674735685544355, 0.26579299622348374, 0.1451640176985945, 0.20101533431027616, 0.12646083773246833, 0.13911841996014118, 0.07814877799579076, 0.24900926968881062, 0.08303877631468431, 0.1938240709049361, 0.23420206138065883, 0.1261814305824893, 0.12038944209260599, 0.21155846571283682, 0.15989954556737626, 0.21021556348672935, 0.17926101306719439, 0.07492572987186057, 0.2099411774958883, 0.18448166150067533, 0.1668619933937277, 0.14241899070995195, 0.10568721672253949, 0.1087226974112647, 0.10992117345865283, 0.1560775206557342, 0.14434172825089522, 0.1418860557356051, 0.09899488011641161, 0.14430336388094084, 0.1576632841357163, 0.07373696366058928, 0.13359107369823114, 0.0945010037560548, 0.1356543494122369, 0.07956163039697067, 0.14655491949192115, 0.11521808244287968, 0.11389940391693797, 0.13609793489532812, 0.1916925481387547, 0.1732641884258815, 0.1516599455582244, 0.11849722505680152, 0.08033863441752535, 0.09680159030748264, 0.149939981422254, 0.056886028232319016, 0.12832914319421562, 0.11519740069551127, 0.1207138089729207, 0.09813258424401283, 0.22400568851402827, 0.15844753491027014, 0.08745538789246764, 0.10545424172388655, 0.08056720572390727, 0.1602712334798915, 0.13773156223552568, 0.1435922048985958, 0.1341298712151391, 0.10097504207598311, 0.13973638894302504, 0.13395292285297597, 0.11713786157114164, 0.17232312820851803, 0.09203823376446962, 0.07128614267068249, 0.09080324574772801, 0.1854247030402933, 0.053818351056958945, 0.11618093720504216, 0.12885565922728606, 0.14681436414165155, 0.1873363668897322, 0.08900116530380078, 0.18763205888015883, 0.1055471467386399, 0.10673712752759457, 0.11674865388444491, 0.09274283809853451, 0.14243033581546374, 0.10742265145693507, 0.10796781363231794], [0.0503419108156647, 0.056389187928289175, 0.03697601606005004, 0.029748149083128998, 0.059499677270650864, 0.011426946164907088, 0.01296806034432458, 0.008847099196697985, 0.0056510135099025706, 0.05332252855545708, 0.04222012144912567, 0.04443604040092655, 0.022947029742811407, 0.019690048082598617, 0.019431298931262324, 0.013432938256300986, 0.09751156185354505, 0.043572299248938046, 0.06603292455630642, 0.010737028721320842, 0.08885625057986804, 0.025273476960137486, 0.037605978149388514, 0.04167909833735653, 0.05785794822233064, 0.01766816300473043, 0.02541152321334396, 0.0314525442330965, 0.0898017959137048, 0.01758282195909747, 0.04201964827786599, 0.03449918682287846, 0.008517609376992499, 0.012942058882409973, 0.058644573869449754, 0.013777220139413007, 0.013095459534919687, 0.029411945159413984, 0.017542824016085694, 0.03345866694248148, 0.04943761023293648, 0.026773376922522272, 0.06229412875005177, 0.029864053042339425, 0.023668716195970774, 0.030570000875741243, 0.006330779221441064, 0.03245964965650013, 0.03824247792363167, 0.020655074156820774, 0.04729777880545173, 0.02773262866373573, 0.007043097650499216, 0.048315628830875666, 0.045058002562395165, 0.1046014656977994, 0.02158350683748722, 0.04422617969768388, 0.02606152244178312, 0.027857911673241427, 0.02450867978456829, 0.04052615538239479, 0.03847581593851958, 0.020732347421082, 0.031177506848637546, 0.016411758726462722, 0.07484250076647316, 0.06272624699132782, 0.032949775856520445, 0.018210685678890774, 0.07757073401340417, 0.02125440039006727, 0.05303966087688293, 0.024909035801621418, 0.0273820516719882, 0.04736789182892867, 0.056413099502346346, 0.028681736306420395, 0.02400337136350572, 0.03293988620862365, 0.050610451227320094, 0.049260699190199375, 0.05877512400703771, 0.06167534552514553, 0.013205269401493882, 0.022205260349437594, 0.07270877276148115, 0.034353892119335275, 0.0445828143108104, 0.036870622608278475, 0.031297933243747265, 0.007217716093042067, 0.03140852766643677, 0.019405463710427284, 0.01613669080792793, 0.011864178863886212, 0.011465985677205026, 0.03948535730264016, 0.05365882408139961, 0.023615213709750345, 0.033464627872620306, 0.020738413524148718, 0.03620318163718496, 0.05328525662688272, 0.03787351432921631, 0.05395058396139315, 0.04640020929010851, 0.01741714067091899, 0.026953816347356354, 0.04697091830894351, 0.05145637744239398, 0.07005736324936152, 0.032081746363214085, 0.06370977671550852, 0.04706261553136366, 0.0585784845586334, 0.02989751160410898, 0.04289143346250057, 0.03849663000021662, 0.026455693612141267, 0.025684133138773695, 0.03727475128003529, 0.06056814600846597, 0.02972373878583312, 0.007393638170989496, 0.03567955955596907, 0.059241833963564465, 0.029429685457476547, 0.03836767441992249, 0.0648592421784997, 0.03700531180948019, 0.06757511930274111, 0.024809072326336588, 0.06396947920854602, 0.02287905240830566, 0.04601208047409143, 0.03893250732549599, 0.020182591563622867, 0.033807220203535895, 0.04975400432678206, 0.0853078177730952, 0.06437402178666421, 0.04575142124667764, 0.03978134784847498, 0.0305450206090297, 0.01639932457224599, 0.03678788204810449, 0.029342056052493196, 0.047203516720661094, 0.09747487346508674, 0.031710550388587375, 0.045340283308178186, 0.029579156544059515, 0.0701071745050805, 0.039047715786312304, 0.023825328863625015, 0.03426718891465238, 0.004478629254403391, 0.0211844536076699, 0.013576492517521339, 0.08409870229661465, 0.005816463672090322, 0.004932248149998486, 0.03007897561682122, 0.04596392484381795, 0.010088526510766574, 0.03815042107765164, 0.03406591167939561, 0.06225488906992333, 0.02467982327964689, 0.013363046604873878, 0.04044358106330037, 0.02663906939726855, 0.017693823502798165, 0.03423781852637019, 0.048583181974078925, 0.03465431349884186, 0.03230417014232703, 0.05235417426696845, 0.07009820427213397, 0.07898193757448878, 0.003896664611862174, 0.04620110336691141, 0.04012699358697448, 0.020392957775454437, 0.015991285842444216, 0.058285499922931194, 0.05561256728002003, 0.03817063802853227, 0.06082079852265971, 0.03077345620840788, 0.031479750094669204, 0.035941776021250656, 0.04562960046210459, 0.004602022119797766, 0.021856780030897686, 0.014255376133535589, 0.03287890287382262, 0.02340094592156155, 0.003856988548899868, 0.060030359508735795, 0.015419121365994215, 0.026101281201200824, 0.05446482868865132, 0.025829110627195666, 0.033963612347309075, 0.013630066249918724, 0.047546407606984885, 0.062406724851046286, 0.022269405657425523, 0.017019575129130056, 0.018645633411194597, 0.0429462421286319, 0.03435019749615874, 0.03338793305946248, 0.041325371246784925, 0.014200644650762635, 0.020669847560514296, 0.024662340824891413, 0.03114813646035535, 0.06027411642883505, 0.018350428269643868, 0.011843505598205541, 0.024559744633734226, 0.04188142390921712, 0.025217190784003054, 0.051220542418637445, 0.0059174267142745, 0.01803352527453431, 0.021816927972914915, 0.023803861711972525, 0.09048881940543652, 0.03796491638890334, 0.06283184061092989, 0.03904888965189457, 0.04493788829339402, 0.03385133176509823, 0.027897348128525273, 0.004275190036943448, 0.05627177422866225, 0.011571251055491822, 0.01224378019105643, 0.051657627536250014, 0.03345691292945828, 0.04032143797459347, 0.013547658171903874, 0.015924446750432253, 0.030176335213971988, 0.055344630764531236, 0.02428252067017768, 0.02042628402289535, 0.04462207434698939, 0.015839982711310898, 0.015414848291714276, 0.04070505792541163, 0.012730342385891293, 0.07182513017739568, 0.01318856980651617, 0.019948088164840425, 0.011575105134397745, 0.03266535433275359, 0.032878631459815164, 0.13634956282164368, 0.054030739303146086, 0.17420374229550362, 0.03748674597591162, 0.023228989880798117, 0.06238685056035008, 0.018678186128714254, 0.02895010369164603, 0.04861012999234455, 0.014611011603847146, 0.025132355246958987, 0.05415165424346924, 0.028798223805746863, 0.013468096548292254, 0.06373819376208953, 0.018087668976347362, 0.028017448826826045, 0.027088425820693374, 0.03068082600033709, 0.035469464758144956, 0.03543163303818021, 0.0330280177295208, 0.04021384267668639, 0.11047409807464906, 0.02632424102297851, 0.03487474238499999, 0.0367155841418675, 0.0806833098509482, 0.026869002862700393, 0.03286081991557564, 0.010896105319261551, 0.036006664325084, 0.09965027030557394, 0.016256253767226423, 0.05857216739760978, 0.060756344481238296, 0.03617938541408096, 0.03443773869158966, 0.039319974569869895, 0.020949855213984847, 0.02680147166496941, 0.09167210983910731, 0.038465631127889664, 0.012775899227043348, 0.06109063154352563, 0.011856073763088455, 0.015251404472759791, 0.10122790493603263, 0.03554035470421825, 0.03738369007727929, 0.02886302050735269, 0.05194851549874459, 0.024751999049580524, 0.043371083081832955, 0.020963271547641073, 0.0189643463984664, 0.051805809406297545, 0.039653097944600244, 0.06365237943828106, 0.04411635880491563, 0.02616183027358992, 0.08404110145888158, 0.046676278047795804, 0.032267396936991384, 0.02918081238333668, 0.007678645779378712, 0.01214152920458998, 0.031047994869628122, 0.052103805023112466, 0.03827696107327938, 0.04557865944557956, 0.00990596496766167, 0.01022694171738944, 0.0026714165412288693, 0.0382998955569097, 0.04248105548322201, 0.009248210932128131, 0.010152049262874892, 0.03440755406128509, 0.020196698306660568, 0.0588684022160513, 0.012171137928297477, 0.022987502660336237, 0.010446821838351232, 0.03866820775770715, 0.0695803938433528, 0.006037982879206538, 0.0667399987578392, 0.033637094510985274, 0.052087862842849324, 0.12343765209828104, 0.12366607412695885, 0.13094891261841568, 0.07802094199827739, 0.1701645590364933, 0.07294893344598156, 0.112657162360847, 0.08938223057027374, 0.17189517617225647, 0.14831811987927981, 0.1593223022563117, 0.19861512524741037, 0.07110520452260971, 0.16957238795501844, 0.10940419762794461, 0.08783595104302679, 0.26797638620649067, 0.1275992566453559, 0.1297540260212762, 0.10828213140900646, 0.1407559828034469, 0.11028857981520039, 0.1362636602882828, 0.13523422767009052, 0.1202701556363276, 0.1552803912865264, 0.09450812837375061, 0.13016866520047188, 0.12589078689260141, 0.20520189537533692, 0.13631836378148623, 0.1408424281648227, 0.15387981358383382, 0.13453590657029832, 0.12084173996533666, 0.11970900717590537, 0.17669079027005605, 0.06528150809130498, 0.10888110819671835, 0.11937495081552438, 0.1891536736594779, 0.12087690165000302, 0.16413728174354347, 0.1795187478086778, 0.09252231421747378, 0.08073956040399415, 0.1271873451769352, 0.10264668094792537, 0.1470737952206816, 0.17766823353511946, 0.17388750426471233, 0.13745687768927642, 0.06890791135707072, 0.139034363042031, 0.11751964608473436, 0.16574315700147832, 0.16207270324230194, 0.12498578402612891, 0.18586324022284575, 0.12124096282890864, 0.14706376647310598, 0.1700052254434143, 0.13117637112736702, 0.10991730580904654, 0.0670469883563263, 0.06501737476459571, 0.21634182546819958, 0.14683375667248452, 0.14044104755989142, 0.09812105593404599, 0.16060561553708144, 0.08735448294984442, 0.180153720879129, 0.10604311512517077, 0.12370077440781252, 0.18119585567287036, 0.11508846868361745, 0.15407768796597207, 0.14392251574567386, 0.14878055506518909, 0.09864425393087523, 0.12942488225443022, 0.14230380260518619, 0.16335679005299295, 0.1539132110774517, 0.14660699026925222, 0.19006924810154097, 0.14383988375110285, 0.3234273264450686, 0.10033134983054229, 0.05319346101688487, 0.22546315459268435, 0.11050885942365442, 0.09031498551900898, 0.10364430384444338, 0.11467794142663479, 0.09667798158313547, 0.20435631860579762, 0.11896138372165815, 0.10566124918737582, 0.13275046380502836, 0.16682809378419602, 0.1659045669117144, 0.19045304107878888, 0.18906193572495664, 0.17696613978062356, 0.12064546692584242, 0.0987700271819319, 0.08990146592259407, 0.21071899575846537, 0.10681902670434543, 0.15116989399705613, 0.13685991615056992, 0.2985790755067553, 0.16035713601325238, 0.10925655519323689, 0.09764494148216077, 0.17215757923466818, 0.16966001396732672, 0.11644585084702287, 0.1941044144332409, 0.10577980282583407, 0.15871600407574857, 0.12393845165414469, 0.08705199203853096, 0.13334996306470462, 0.14494468803916657, 0.14240840556366102, 0.06990687096757547, 0.11611255444586277, 0.13703043200075626, 0.09026746092630283, 0.1416476863835539, 0.24094268253871373, 0.11595547358904566, 0.11660716576235634, 0.09443423591021981, 0.1657669735806329, 0.1326331179589033, 0.15251363760658673, 0.2741465765450682, 0.16506641331527913, 0.1530213446489402, 0.13503988167004927, 0.17224456742405891, 0.09279367394213166, 0.10073345646794353, 0.1468091801341091, 0.10990036957498107, 0.19399192689784936, 0.12060239352285862, 0.11412410757371358, 0.178501230265413, 0.18954714254609176, 0.0751083032893283, 0.16956303774246148, 0.19506857198263916, 0.11694635184747831, 0.1403306227709566, 0.07069649573947702, 0.19578397859420094, 0.10567625838198832, 0.09004197695425578, 0.06320987961121968, 0.12188915376152311, 0.08515967322247368, 0.1282625924795866, 0.11292264597224337, 0.14954432765288012, 0.11331671196967363, 0.16369529760309628, 0.17844856237726553, 0.08550392796418496, 0.09775597016726222, 0.06886035283761364, 0.15009634303195135], [0.03459383567262973, 0.028516275542122976, 0.06066003322069134, 0.014685904906530465, 0.008849565671490771, 0.03224333608523011, 0.014794767368584871, 0.02742622260536466, 0.04814576776698232, 0.06813055449830634, 0.0074683109497917545, 0.04612661039988909, 0.03329987957009247, 0.023933836791132177, 0.009448289704908217, 0.041963336656668355, 0.030455169001860277, 0.03901346333857093, 0.060016646316008906, 0.01958295998961798, 0.06450662788535867, 0.01794691536841648, 0.054055658501705954, 0.03428483082513724, 0.03646071621083787, 0.06701753993651696, 0.03068576573527285, 0.0588692571701748, 0.06322596089116164, 0.04000538993360741, 0.0256765759550035, 0.022922366691221083, 0.04282825167423912, 0.09068483460162367, 0.014699938707053661, 0.040907125653965135, 0.011097321486366647, 0.025814493286556432, 0.006711912341415882, 0.02947607689670154, 0.08406124037823506, 0.01987538653026734, 0.028522226294236522, 0.014348574614684497, 0.07444560527801514, 0.03810110515249627, 0.04818487174010702, 0.012948876463009842, 0.032678504341415, 0.014241523841129882, 0.05104099866002798, 0.02318792324513197, 0.013758836929420275, 0.036932640708982944, 0.08547486630933625, 0.04623267220865403, 0.0051255988239842865, 0.018129490482221757, 0.035207109193184545, 0.01152979171768363, 0.058861956133374145, 0.007257591899750488, 0.03196414606645703, 0.030571486867432083, 0.025139981980568597, 0.017874422383361628, 0.05183543424521174, 0.04737186465146286, 0.010365415447657662, 0.017456873985273496, 0.07281248683908156, 0.018885393760034015, 0.02728617297751563, 0.0215814576617309, 0.026345489347087483, 0.05793313668774707, 0.07704824169299432, 0.06573866427476917, 0.05332298317391958, 0.021194691004763757, 0.029615889037294046, 0.05289123812690377, 0.05536796897649765, 0.04516005762187498, 0.06274841473038707, 0.02481251080254359, 0.013072283323188978, 0.03133807537545051, 0.04954506303848965, 0.059210044597940784, 0.019613787531852722, 0.01552045378567917, 0.03982139498527561, 0.03150163624169571, 0.05362180321078215, 0.027902818817113127, 0.03188701020553708, 0.02327476894216878, 0.041872138157486916, 0.041032464642609866, 0.06263694499752351, 0.04870265502748745, 0.013225031733912016, 0.04086916161967175, 0.0864659481282745, 0.04487865557894111, 0.08025412966630288, 0.02296140620351902, 0.04157731808455927, 0.014179804295833622, 0.013748534223330873, 0.07402486606900181, 0.020315265515819192, 0.0376917856878468, 0.01715964511302965, 0.055010289419442415, 0.027043944457545877, 0.033779322236244164, 0.022151611978188157, 0.002139625958599416, 0.03694984157170568, 0.021787489731130854, 0.012270974178266312, 0.01932315910900278, 0.026557187183893154, 0.045946815583322725, 0.05810439892645393, 0.007941826612555554, 0.02889894215123994, 0.02064779177973313, 0.023355794505083134, 0.02700411105927612, 0.05366629135927983, 0.0745804641129715, 0.038458418300641437, 0.010365914170896369, 0.02129166553329144, 0.02963842997061355, 0.05445002305454441, 0.022686300965558206, 0.01464342522168798, 0.048201115868453465, 0.03168092215699809, 0.035254233450229676, 0.043461908386754136, 0.06860021608216421, 0.1020157587315355, 0.013201573930148567, 0.04596360253968409, 0.04600656398438981, 0.05626409999760134, 0.035139103020940504, 0.036828458442219665, 0.027121032821014524, 0.006250521251266556, 0.07679200651390211, 0.0306931719450014, 0.050967336898403506, 0.025517593503796628, 0.022089897521904538, 0.018274332263639996, 0.021933963389268944, 0.006502886660330529, 0.04757224961317011, 0.044656666062240086, 0.02452256091471229, 0.045032879803329706, 0.0561626590123134, 0.022998539032414556, 0.10800468522523131, 0.025956354602905254, 0.01335216629584985, 0.08696168581289904, 0.043840717524290085, 0.06371698954275676, 0.05236006734360542, 0.033394660734172375, 0.04057202774233051, 0.01603546695384596, 0.007520956785551139, 0.047130224760621786, 0.029503530423556055, 0.006813835510651448, 0.0396222958474287, 0.018588526207687597, 0.04913881394479956, 0.03896764186876161, 0.05482073726930788, 0.01936370157636702, 0.03856808313035539, 0.03463272590722356, 0.02963680148656879, 0.044547170866280794, 0.039005551620253494, 0.03616669002388205, 0.041543557574706416, 0.0336950142601771, 0.031268861410873275, 0.03449265253064888, 0.05291453901944416, 0.026644575708944882, 0.049340467766991684, 0.04006616970790284, 0.026768360852396915, 0.05841691858534302, 0.04615762284291642, 0.050778894153024466, 0.08004526980221272, 0.03058634339166539, 0.04404963167118175, 0.04252300591074994, 0.05967277833925826, 0.032055252963410955, 0.014089707567888712, 0.04122364188411406, 0.0302173458704991, 0.05989893406097378, 0.015687559997396808, 0.02426058702569987, 0.044512043108365366, 0.023517504667064974, 0.060293122194707394, 0.044309083106262345, 0.04597912063556058, 0.058851594903639386, 0.016571765765547752, 0.08945999746876103, 0.03286849075396146, 0.04263531363436154, 0.0015201241226999887, 0.07869703429085867, 0.05868660232850483, 0.06043495636965547, 0.019795926686908518, 0.03216782531567982, 0.016206547684435333, 0.01766568635191236, 0.012150593584270349, 0.04032461351848074, 0.02969085697882942, 0.02794180404660957, 0.03777957454855953, 0.053348496090620756, 0.02276950971489506, 0.038802839283432276, 0.0227646463151489, 0.057223992954407416, 0.015724180532353263, 0.025644513479034816, 0.03764122465093221, 0.03041422619883503, 0.05801482551864215, 0.028101743232192736, 0.03667197469621897, 0.013160589566853429, 0.04450526793620416, 0.02047059914496328, 0.0381520970591477, 0.049911200534552336, 0.06913000943937472, 0.03493700136563607, 0.01246220146172813, 0.044373733922839165, 0.010300293897411652, 0.04825023841112852, 0.08358805041228022, 0.01781784782984427, 0.02811432327143848, 0.10938196882073369, 0.046674130484461784, 0.035933508072048426, 0.07042381287153278, 0.031942300631531646, 0.057000381739011834, 0.015381175991413849, 0.050290549107428105, 0.0714813300541469, 0.037447377374129634, 0.034571030110652955, 0.04874336712860635, 0.10964384262583085, 0.011554107020076896, 0.04115635495898979, 0.018665996247104237, 0.051805246222232065, 0.04497661567958338, 0.014559597309146608, 0.04682009354499834, 0.031152339984795878, 0.05739224249763148, 0.03396742232143879, 0.08442382913615022, 0.03597891902817147, 0.024104462903259054, 0.036161014078451056, 0.03121579997241497, 0.03606887241559369, 0.03679671657404729, 0.008478427372340645, 0.00396586542982342, 0.033216718318206925, 0.03511794629905905, 0.029139364071722542, 0.05611975524308426, 0.03339303903547781, 0.07143387331494264, 0.0376579980365932, 0.00639613316993096, 0.024681056517043283, 0.046295077074319124, 0.03039792100233691, 0.021672986946733933, 0.04350472055375576, 0.05824800407780068, 0.03557730093598366, 0.05160765343212655, 0.038552697348807535, 0.016247629587139403, 0.05674636197675552, 0.02061401939551745, 0.04029895132407546, 0.08498806493090731, 0.05274348034124289, 0.01266550921302821, 0.010199349939024873, 0.041536711156368256, 0.03382462801943932, 0.030927615971969705, 0.06440752106053488, 0.04947773879393935, 0.011095642112195492, 0.09236245136708021, 0.0235866202440645, 0.02094975343373205, 0.015033893287181854, 0.03924253676086664, 0.04303300300879138, 0.020013700804806182, 0.021869721390040855, 0.029005689280373708, 0.02353864612190851, 0.02562592501219894, 0.03719656029716134, 0.013638240900555891, 0.03615132459838476, 0.007987665045740349, 0.022324597695842385, 0.038290813365685086, 0.06942722813359328, 0.05968600298677172, 0.04400742340034672, 0.03470951232260891, 0.14463063489113534, 0.14826208645743982, 0.24556470023734228, 0.15925975489829267, 0.2017941296632801, 0.12268730093325887, 0.139298340305686, 0.097129946973707, 0.16160410695842334, 0.16184272058308125, 0.10439550317823887, 0.12535303431962216, 0.1984673538910491, 0.1464161319392068, 0.10029206265296255, 0.08670494851789304, 0.08620759591992412, 0.10248573244150196, 0.11710527831954615, 0.13025075436702796, 0.18295577195073875, 0.11892840691975184, 0.1299728671354907, 0.15806062067193644, 0.11685104481875896, 0.19091722688504628, 0.11463641508349351, 0.20304650174719946, 0.19132024954472268, 0.13162187007921083, 0.12436436808535031, 0.0955655709175127, 0.09619669669440814, 0.25109272503427094, 0.11614847608975001, 0.16390491064105714, 0.12189441919326782, 0.0831321698746511, 0.10005792057407753, 0.11451693863740989, 0.22002739698759147, 0.1876388578010457, 0.11671179586223193, 0.09099660787199225, 0.10177620194320168, 0.14501803767468247, 0.14253255033067294, 0.13879588512437685, 0.15428343335432665, 0.1580304122929062, 0.11151789527918611, 0.05926354708416121, 0.12717342163835252, 0.10037307973418917, 0.14865277335047722, 0.1576396846877677, 0.17644904181361198, 0.0947255174230252, 0.18740343329097542, 0.0821710250207356, 0.1675379364086049, 0.10138276019798857, 0.19234571951840604, 0.12364711585853781, 0.16817411727138928, 0.11136736907064915, 0.14942095641578945, 0.10043339471199683, 0.1657252979597875, 0.1119095321212496, 0.1330365613102913, 0.17271681422633783, 0.1375392654112407, 0.11335902541343655, 0.14198763242789678, 0.13805358138467583, 0.1210862568446568, 0.10938992803650242, 0.17709029811833585, 0.05915548359709127, 0.07731438348335878, 0.1473468377121857, 0.09731601484652076, 0.12007462898535387, 0.18560823319213732, 0.14236457220145635, 0.0941020930185914, 0.12023845448025636, 0.17811899791870797, 0.20614011931632245, 0.12601149827241898, 0.1076316809547799, 0.11219605031822409, 0.187448135178004, 0.11302789353898593, 0.14153556525707245, 0.14885307688798222, 0.1731544557426657, 0.1687388891088111, 0.13124509315405572, 0.24795346919979366, 0.15519877709448338, 0.11473207495042256, 0.17400601719106945, 0.16061618711267198, 0.10110162956906216, 0.20756629135991844, 0.1379557637763875, 0.15080561568694456, 0.12175416600491319, 0.10636643706155674, 0.14171838973249706, 0.13912008915628704, 0.12518827244639397, 0.12269825248845986, 0.19917292174484047, 0.1320281768483775, 0.08244271722755261, 0.11824934264378888, 0.14884052399013722, 0.15859838681561605, 0.14322119552109921, 0.0980215487735612, 0.13390860094555787, 0.1991885280502694, 0.1585412270256451, 0.15146459532635553, 0.097942329810134, 0.13304612865405424, 0.2061927736337696, 0.13034408007349285, 0.1545979343354702, 0.1199886721691915, 0.14203025799776825, 0.09417171749685492, 0.06324800649391753, 0.12209553697279521, 0.0897882387840322, 0.15312345059854643, 0.1607027817517519, 0.10082455657954727, 0.14386147473539623, 0.1672720049640962, 0.2063293627330235, 0.10398590551423174, 0.2507221906312874, 0.1450293692094939, 0.1326414639396327, 0.14534287952951022, 0.12577433671270097, 0.12124389410018921, 0.149987573868462, 0.20762262333716663, 0.08449802015508924, 0.0748071898041027, 0.12092024646699429, 0.12661025114357471, 0.09559098205396108, 0.09683117443429572, 0.09065040573477745, 0.08052796604377882, 0.10593649013234036, 0.0554672454350761, 0.11879858959998403, 0.09665910473891667, 0.19659129955938884, 0.14359744318893977, 0.17137843104345457, 0.12005204733993326, 0.18040281108447484, 0.14431936373668058, 0.19812238668756826, 0.2986003000821386, 0.14547123121363775, 0.2164486947336367, 0.08185918389686517], [0.025610934477299452, 0.07990648224949837, 0.050289371849170754, 0.029899095983377526, 0.09832374791481666, 0.048632497899234295, 0.027551934788269655, 0.059255452161388736, 0.04701988139588918, 0.021483955572226217, 0.016781149797939827, 0.03687263446460877, 0.08547663728573493, 0.07372807485184499, 0.028529384838683263, 0.015280332116942321, 0.013201985292003622, 0.02243575021358473, 0.019656297750771046, 0.02156160881609789, 0.05145886427323733, 0.051575667291347466, 0.019548312295228243, 0.03725633583962917, 0.04252436976613743, 0.03908160182514361, 0.015015250537544489, 0.01597675501501986, 0.03998628917283245, 0.04192277044057846, 0.015889390238693783, 0.048200498401586495, 0.014385598877977048, 0.015469008956902792, 0.017911689222923348, 0.022261571970635226, 0.03459488061655845, 0.04886093010593738, 0.04463374175663505, 0.014685854016404067, 0.013724498816632798, 0.03894579643383622, 0.043262934777885675, 0.010327785591860967, 0.022986354239817177, 0.03028794065383928, 0.03010019679952945, 0.025234116840043237, 0.09575997120035545, 0.009891591051460376, 0.019432752692539777, 0.018375651112624576, 0.03954989276826382, 0.1337524971791676, 0.02764578296669892, 0.03485830148149814, 0.015582987572997808, 0.02679986014430012, 0.04671509703621268, 0.0354940921866468, 0.031889110271419795, 0.051417422746973376, 0.05560201606048005, 0.026918603772563592, 0.008869647763536444, 0.03493513539433479, 0.037056113726326396, 0.054747787969452996, 0.006839141050087554, 0.04019888437220028, 0.060096917008715015, 0.02638947537967137, 0.021865852044097016, 0.015396310715004802, 0.06633375305682421, 0.041665547993034124, 0.08858512834246669, 0.022968817502260208, 0.08173637584383998, 0.04763651027211121, 0.04798069376764553, 0.017531808000057936, 0.10088934310312782, 0.06218594312667847, 0.017881121220333234, 0.042457666381129196, 0.02228720363096467, 0.053260028694889376, 0.13772565898086342, 0.03407389125121491, 0.044279461660023244, 0.009812480653636158, 0.05573205051145383, 0.012391232635958918, 0.0075163766741752625, 0.02787618462129363, 0.02921760594472289, 0.02782779828911381, 0.057076954415866306, 0.04683029531900372, 0.0445507331751287, 0.026713954218264137, 0.023771146146048392, 0.07574778861765351, 0.08235424304647104, 0.025689021983583058, 0.04358144590098943, 0.033553380253059525, 0.02113910541603608, 0.05435105532939945, 0.003958510110221271, 0.059195978567004204, 0.020398672736649002, 0.04290405760652252, 0.1292004907237632, 0.011218024384496468, 0.02149283929195787, 0.029576523828187158, 0.02653463607254837, 0.024534794901098524, 0.05911191486354385, 0.0622334677193846, 0.07235472675945077, 0.061896805784532, 0.026991283354748572, 0.039655584775443585, 0.006741504101747913, 0.00849790811272604, 0.054349029902368784, 0.055778557301632, 0.04283579019829631, 0.0560000989852207, 0.06276685731219393, 0.052889765705913305, 0.02898474968969822, 0.04528687581686037, 0.0511398883536458, 0.017780194225321923, 0.02790516145926501, 0.03538026115191834, 0.0807805507044707, 0.039089496580085585, 0.04046852061791079, 0.023852505887459432, 0.03797941668225186, 0.028799448561455523, 0.02445422565298421, 0.0554324026618685, 0.06855936827404158, 0.023895511436941366, 0.028573872987180948, 0.023650431373555745, 0.0481958300806582, 0.05050497295867119, 0.036346698578979285, 0.04677213808255536, 0.05766224515225206, 0.047372390516102314, 0.04014769569039345, 0.04834827654329794, 0.04728242355797972, 0.05860284396580287, 0.004795065756687629, 0.035323172608124356, 0.017094429416049804, 0.06492703461221286, 0.011326727390821491, 0.03698508807324937, 0.04703512807775821, 0.03548474197408982, 0.004837757907807827, 0.04419355234131217, 0.00591061803944675, 0.002233768451593018, 0.023419349487604837, 0.030942201082195555, 0.0037445480868752512, 0.043011147395840714, 0.04947542498952576, 0.03098417186577405, 0.04270568789382066, 0.03296501575303929, 0.015160434979147144, 0.05923256517520972, 0.046383398585021496, 0.01811700713421617, 0.013828052590335054, 0.03289249732292124, 0.06757440005562135, 0.07119380083999463, 0.016584963271660463, 0.023758442274161747, 0.02944400254637003, 0.047095073253980706, 0.03928943370868053, 0.11780779276575361, 0.03687074135190674, 0.038023820013872216, 0.040411710273474455, 0.006260532611382327, 0.013014029395500464, 0.08209665079734155, 0.027938633591734936, 0.053664822330964465, 0.035945385827549865, 0.03402606810310057, 0.03036714604656611, 0.010751916627798761, 0.0614480430792485, 0.029513240259672915, 0.034480771382472346, 0.039349602801459174, 0.09058322398258106, 0.05173158785328269, 0.054150517697313, 0.02054367058112153, 0.05065137028161969, 0.018291351618245244, 0.07811740253652845, 0.07619944188211646, 0.11688632863972868, 0.054200827676270685, 0.02890982585293906, 0.0348208667045193, 0.03371476980724505, 0.034311802592128515, 0.03321580229593175, 0.016187609772064855, 0.005141104621413563, 0.01650941009367151, 0.03582070501787322, 0.06539860966482333, 0.025802647761468376, 0.04907790185617549, 0.04544986332101481, 0.10302562918514013, 0.05177978080298219, 0.04183459820758019, 0.02792116979669247, 0.004237763741652348, 0.01043893810960331, 0.04898685263469815, 0.06889538560062647, 0.011376642971299589, 0.04245450780061739, 0.028790288338703767, 0.025165917285318886, 0.03136003276865397, 0.05056099959516099, 0.02257744189617889, 0.06574264727532864, 0.03261630982160568, 0.040496211632021835, 0.03104798469160284, 0.018555413698777556, 0.043081114534288645, 0.013477615546435118, 0.10494417337966816, 0.04441766567262156, 0.025171842592369233, 0.11135934200137854, 0.05106634533564959, 0.06458168064377137, 0.04284296909879361, 0.13112333683030947, 0.08351494504937104, 0.07618880923837423, 0.04053941056398409, 0.08261958416551352, 0.02831097798688071, 0.042160959980849705, 0.03752926976553031, 0.0864203166482704, 0.0062224379590978575, 0.057918887452355454, 0.08557387135390725, 0.03305514216689127, 0.028793453704565763, 0.07675835796232734, 0.02306833484077028, 0.016104290760787468, 0.06463592951851231, 0.03406928739111338, 0.025555757705920508, 0.009566752589307725, 0.02316151126953108, 0.024385963333770633, 0.05887227665100779, 0.08667538474713053, 0.024806314081485783, 0.06721061029072319, 0.011396723367007715, 0.023671465959133844, 0.041468369109289985, 0.02488802496476897, 0.08714269181447369, 0.040142806845584085, 0.052425722392009835, 0.026407480306391205, 0.057969099043735435, 0.0014238334302457847, 0.01802985609642097, 0.034696263926369805, 0.025299910988126482, 0.009031523318429078, 0.04503449471667409, 0.009800512992244746, 0.028925350734165738, 0.03650512293513332, 0.0008898370787002412, 0.039667649128075154, 0.04941715579479933, 0.055734849468405755, 0.02798267899613295, 0.03875092796183058, 0.020539931853168776, 0.007402008748613298, 0.027591366154540862, 0.025223048237551535, 0.0036041172071626143, 0.05949729561273541, 0.02192953085925962, 0.01849880861118436, 0.04810276221750038, 0.05060917218880994, 0.1059360151578273, 0.031220651497798305, 0.027391520628173436, 0.007677957914503557, 0.05080538076747741, 0.06912306802613394, 0.02818658385824944, 0.0359243308859212, 0.04292066814377904, 0.06917110830545425, 0.06805052807820694, 0.036126327368297746, 0.08207168070865528, 0.056483287164675336, 0.03831931183646832, 0.03788406554875629, 0.02440079102026565, 0.019953680989731635, 0.04063718067482114, 0.03890075867197343, 0.06807071449501173, 0.04279049798580153, 0.023746874948431338, 0.02705411909015051, 0.017361568652891686, 0.01605369579712195, 0.02695472558428134, 0.10858306168977704, 0.27006885249699863, 0.09461494335638625, 0.0712525551872594, 0.11095034144818783, 0.2732250445655414, 0.08522935198353869, 0.18457528576254845, 0.09396224695124797, 0.08351125381886959, 0.16648911125957966, 0.0727688434666821, 0.13403585340295518, 0.24720534362963267, 0.15932889761669294, 0.08574767809893404, 0.14475574317787374, 0.14328736625611782, 0.06111647694238594, 0.16140062787703105, 0.10149207897484303, 0.13271762271012577, 0.08695528044232301, 0.09437227209231683, 0.10329283627548388, 0.11637947655149869, 0.10603970209402697, 0.1003564963383334, 0.12690180407038756, 0.12836482056549617, 0.16384173903082097, 0.13017049724502222, 0.21878559647926263, 0.10788957854466778, 0.11838673241436481, 0.09571383081908737, 0.17232401030404226, 0.10101407819560596, 0.19752577798707144, 0.1729570563350405, 0.14006317140800612, 0.10077904723584652, 0.11076872476509639, 0.10755370371043682, 0.15343112551740237, 0.13594549521803856, 0.17103792860039643, 0.10892701109072991, 0.17856586751128944, 0.060072469391993115, 0.16463441721030644, 0.08543604732091938, 0.1302012755934681, 0.32700141466089655, 0.06990027560719422, 0.14091873621301992, 0.12231341456728322, 0.1466789964054312, 0.1468417498150042, 0.11278153782976524, 0.1519291339708226, 0.1337103330131088, 0.09754777526749031, 0.08304583986422845, 0.11205382937831537, 0.19654400566858904, 0.13514304613428457, 0.16211553237267903, 0.12159472384623118, 0.08881615594561611, 0.18233310750552587, 0.11312974843063525, 0.15362031465130194, 0.06565264639045511, 0.11355214326509408, 0.14233150040464743, 0.25346317355121883, 0.09922681695648602, 0.1876677091100386, 0.13064088486135006, 0.12895623168775014, 0.26718863419124056, 0.17992311396769115, 0.11805289318518979, 0.18961779161223344, 0.2079431904213769, 0.17356620436268194, 0.23060634146843637, 0.26176225394010544, 0.29922973630683763, 0.20647809760911123, 0.09926087262907199, 0.20983605885079928, 0.07924198612038579, 0.10302098122026239, 0.19731064167405876, 0.2026953055922474, 0.11384148416774613, 0.16094975492783956, 0.11810942872294358, 0.0987040125099676, 0.10924065711774997, 0.13734797281878336, 0.14513747340866498, 0.33878830075263977, 0.2280893022460597, 0.17227743566036224, 0.09227695595473051, 0.11566596983798913, 0.15117099322378635, 0.07105662141527448, 0.13102710699396475, 0.12296003129865442, 0.1279079629374402, 0.15118480819676602, 0.0961833634812917, 0.160185235951628, 0.16173055874449865, 0.09574437846562692, 0.17892649530300073, 0.2365073433944157, 0.16150612650173052, 0.13184371031820774, 0.16055338191134588, 0.054731750794287236, 0.14388130152864115, 0.12917098802115234, 0.07305644053433623, 0.09011082111724786, 0.11925449727901391, 0.23085940788899148, 0.11058148302670036, 0.14060207749051706, 0.10865103054259505, 0.14602397941052914, 0.100795874904309, 0.09890257221247468, 0.12183317462248461, 0.10918138029852084, 0.12884332346064703, 0.13646925639893326, 0.10693448622311864, 0.11451520158776216, 0.10694773801203285, 0.21811329041208538, 0.0926895798849208, 0.10949605769876923, 0.22555384758327687, 0.19053640589118004, 0.11980937607586384, 0.06514975694673401, 0.13214591624481337, 0.12613750222538198, 0.12600858057183878, 0.16430882896695817, 0.07502870434629065, 0.09056750911154918, 0.1401511366878237, 0.16635714976915292, 0.149973419627973, 0.11341319286397525, 0.11686380127710955, 0.0910395048558712, 0.06628533279789345, 0.11804445220955781, 0.10546876915863582, 0.0945345437420266, 0.09351624588349036, 0.2087050766817161, 0.25981271426592556, 0.1394503050084625, 0.14984961412847042, 0.1569653701569353, 0.09406456324670996, 0.16414300857910089, 0.10663937098745789], [0.05929275123136384, 0.01495840965903231, 0.024032124284920946, 0.020302607445046306, 0.02070359280332923, 0.04686637981129544, 0.03987318756324904, 0.021259794743465524, 0.04799014236778021, 0.03435095067002943, 0.022489541077188084, 0.01800174099792327, 0.024362511467188597, 0.032893128360488584, 0.01381717058497348, 0.051261061137276034, 0.024116796973560537, 0.032425193648253164, 0.029844629977430617, 0.052559560031763146, 0.006689388795556235, 0.056509980732308965, 0.04312263069940465, 0.03532001402761255, 0.027906430319749882, 0.04535916354507208, 0.07527585394148316, 0.04204588383436203, 0.026393112327371324, 0.034079251677862236, 0.03443292448563235, 0.02488721072274659, 0.01824117564995374, 0.023319421635408486, 0.042936936020851135, 0.014786540131483759, 0.0350073756250952, 0.04079597483256033, 0.023405922975923334, 0.02884120899917824, 0.03195870082293238, 0.00325905267631502, 0.028545971627214124, 0.030875959101, 0.06194814374404294, 0.0290335567135896, 0.05843662324228457, 0.01888902222604624, 0.05288210165287767, 0.041449699218251874, 0.0949439989136798, 0.00980642727310104, 0.013345123950525053, 0.049221052389059744, 0.025262584776750634, 0.05261793100674238, 0.036032954164381535, 0.01470367404233132, 0.06477578237120594, 0.04107930730762226, 0.02844634572310107, 0.06910138883228813, 0.021134432006095136, 0.014036418820199157, 0.010756698603342687, 0.05915686102317912, 0.03807895776948758, 0.04320328476439629, 0.025832462590187788, 0.036093028262257576, 0.042758820578455925, 0.0413747821668429, 0.018230877184708203, 0.052657303001199446, 0.01474488147401384, 0.048800099441515546, 0.008820671105890401, 0.0968906276726297, 0.03407070892197745, 0.018715961869539957, 0.015691722809736217, 0.022110957552545836, 0.05273429976244058, 0.08718830293842725, 0.10670747554727963, 0.021493025889088, 0.0912578370688217, 0.036683886378471336, 0.1275190809475524, 0.12207554733114583, 0.06441814691892692, 0.008957708038256636, 0.057484387553163936, 0.04907604267022439, 0.03305149164849094, 0.019140075093933513, 0.035796508459108214, 0.046179519167968204, 0.05207236849569848, 0.029119506744401794, 0.022728461738941923, 0.019962720772517577, 0.03164193353482655, 0.02621984332134681, 0.05648258827360613, 0.022173470983813916, 0.04291948749284659, 0.040918762529534955, 0.007281265986551131, 0.04900563448401434, 0.05680966250864523, 0.05137887177988887, 0.05559386346223099, 0.05057371534141047, 0.043589286373129914, 0.05170425307005644, 0.020715260212974887, 0.013557621610483952, 0.02471972962043115, 0.03412731909858329, 0.019144202283184444, 0.041885735999260626, 0.022129732616511837, 0.04579772447635021, 0.031470080970653465, 0.051028489866959195, 0.027307733427733183, 0.027420729864388704, 0.015939111588522792, 0.017981948131429296, 0.030198567413858006, 0.033043294945465665, 0.03372972811173115, 0.044804400099175315, 0.009777693011398827, 0.057077605809484205, 0.013662536695067371, 0.03463448331292186, 0.013848479887071465, 0.04304288587133799, 0.03834132690514837, 0.05311597910310541, 0.016867545965526785, 0.01527064772588866, 0.023299450653472116, 0.05327920748719147, 0.04571389486747129, 0.0766590272209474, 0.04229845153167844, 0.02511664546493973, 0.04964697899829064, 0.037191403431019614, 0.012314016199005502, 0.05140382151252457, 0.03982628383008497, 0.01678890545320298, 0.04263994463586381, 0.1180314514786005, 0.0023984283325262368, 0.04948274638237698, 0.03477577465985503, 0.01652383235549288, 0.011243372756455625, 0.03141995080347572, 0.030748557365898575, 0.03756883174979261, 0.040980516001582146, 0.013008975157780307, 0.04367299384570547, 0.052653021445231776, 0.06905788795224257, 0.061241632726575644, 0.015124638864238347, 0.010619102727754839, 0.046172340267470906, 0.012462072540074587, 0.02385250079844679, 0.024642469926870296, 0.027892540707918148, 0.021554416344900216, 0.013489300767625017, 0.06536058456237827, 0.03568685380741954, 0.012760843383148313, 0.027984200610912273, 0.04907807827528034, 0.02706606639549136, 0.03317908337339759, 0.02542389290673392, 0.03625191402222429, 0.04234888364693948, 0.020103684726304243, 0.03342559514567256, 0.035310093845639906, 0.02781262624609683, 0.039951955300888846, 0.04513453791982361, 0.007882982359400817, 0.012488109625077673, 0.03566924921636071, 0.052033929486892054, 0.04420780157670379, 0.05595106804477317, 0.047905220317521265, 0.021476379728743007, 0.05099164880812168, 0.01234770376634385, 0.020259383068020855, 0.01764938115541424, 0.03813749498554638, 0.00947609098095979, 0.0008753418743643643, 0.08674730945910726, 0.06223141175827809, 0.026492860367787734, 0.0046992884183834705, 0.028468944331897155, 0.04356601940734046, 0.038021384073155265, 0.003013540682981589, 0.01680793666413852, 0.07770273621593203, 0.0035293848445040305, 0.03017723766554679, 0.030680873497788395, 0.050026778796953816, 0.1235090611236436, 0.07075929415545293, 0.015737529012507627, 0.09390264443520989, 0.040885029161082845, 0.035099819236035855, 0.06264345214835235, 0.0562082429948662, 0.037889778813613315, 0.016784635771598135, 0.04074395155268056, 0.027584297515984093, 0.036748353990593126, 0.050983944042984924, 0.012185348147925521, 0.050791728642902205, 0.049376070499420166, 0.0421250179809119, 0.05665664268391473, 0.04275501060432621, 0.03534246335870453, 0.038303742850465436, 0.0581830818472164, 0.021992419181125503, 0.07209996400134903, 0.04340912175497838, 0.04520891892856785, 0.06208166586501258, 0.06802430269973618, 0.08139710833451577, 0.08462961523660592, 0.12029060668178967, 0.06614431965031795, 0.10810683867228882, 0.04438322662775006, 0.14102232136896678, 0.033195670161928446, 0.03328491108758109, 0.08715469509895359, 0.1799576242587396, 0.0962644891281213, 0.07977574890745537, 0.10150706102805478, 0.006998250726610422, 0.01496229087933898, 0.008520872282263423, 0.02057852522869195, 0.0696852682158351, 0.026952630607411265, 0.017592051731688634, 0.026350586841415082, 0.011812853626906872, 0.10250455500291926, 0.04199376216690455, 0.11281847049083028, 0.015321848282058324, 0.068853452136474, 0.01245849666052631, 0.005492077283893845, 0.07369280460157565, 0.045786121527531316, 0.03727520929117288, 0.050652785027133565, 0.010499343841469713, 0.0763571537765009, 0.05368230139304485, 0.0131022058693426, 0.015373498367677842, 0.018124983313360384, 0.11035826536161558, 0.03720401739701629, 0.03796136765075581, 0.04304690958399858, 0.05648279861946191, 0.02019716310314834, 0.039693094191274474, 0.05631229294730084, 0.036215072963386774, 0.03136826339843018, 0.011866683506273797, 0.03987850049244506, 0.013712915375695696, 0.05822496781391757, 0.025818196391420703, 0.043512713696275435, 0.03639963109578405, 0.02395359064186258, 0.005432489186724914, 0.024812953546643257, 0.0367091109177896, 0.029184388262884955, 0.0286546729372016, 0.031373535615525076, 0.01831159062151398, 0.03566560209063547, 0.0162300589228315, 0.03491295747725027, 0.01689937095423894, 0.0347106217273644, 0.037496747582086494, 0.011860285769216716, 0.04646417817899159, 0.03153031113158379, 0.047386364944811375, 0.0011171332693525723, 0.04558480358017342, 0.02350048700879727, 0.049475180716919046, 0.03477908591074603, 0.06738757900893688, 0.033369514226381264, 0.0757735458069614, 0.018757488212681243, 0.0660672312868493, 0.021528737187119465, 0.0530965051480702, 0.00829985476697662, 0.08640805552048342, 0.06694704693342958, 0.05064625073490398, 0.02470314283190029, 0.033375956916383336, 0.050309853428708654, 0.043305808013038974, 0.025005915335246494, 0.027823749131390026, 0.17766679504087993, 0.07519512863031455, 0.17682443452732904, 0.20149043095963343, 0.055043116943644624, 0.1257708626134055, 0.13487467196370873, 0.07876353072268621, 0.1412906548274415, 0.13957941665181092, 0.15173416371856416, 0.11841357525970254, 0.11993402295878955, 0.11746262200176716, 0.1701236976576703, 0.15832465221839293, 0.0688870871173484, 0.2403183217559542, 0.09098062837230307, 0.15575271951300756, 0.06785876729658671, 0.10601812468043395, 0.09364206663199834, 0.11572178612862315, 0.12428853501166616, 0.11247426324657031, 0.14410092974347727, 0.14298663953585283, 0.12349188061697142, 0.12978582217225007, 0.14593199720340116, 0.18131207515086445, 0.1317951272108725, 0.08917115868202277, 0.07825986774904387, 0.15285454717065605, 0.1534250322729349, 0.166250470493521, 0.10262718663683959, 0.10457539638238293, 0.10108516152415957, 0.09177810379437037, 0.1571078353694507, 0.10387972835451365, 0.13176193327776023, 0.1922602512474571, 0.10816511125969035, 0.10905485387359347, 0.10436206497251987, 0.14406101831368037, 0.22207746841013432, 0.16496185106890543, 0.13727619738451072, 0.11785165326935904, 0.0946887679664152, 0.12146030605903693, 0.15176172581102165, 0.1552134741629873, 0.16040947820459092, 0.10537709907761642, 0.11865707433649472, 0.11456856158162866, 0.10636321402021817, 0.11872715343322073, 0.24004639206188066, 0.14930568688682147, 0.15196382068097591, 0.10475186977003302, 0.13785196148923465, 0.22939409794551985, 0.07465057035109826, 0.13902262438620838, 0.14092694648674556, 0.13820497611803667, 0.1531524918973446, 0.1494823909763779, 0.2112850161003215, 0.1724186795098441, 0.11842637243015425, 0.14799599216452666, 0.19819995681090014, 0.22591326758265495, 0.16537445464304515, 0.2908977333988462, 0.19023828474538668, 0.2391162562583174, 0.26595356475029674, 0.16187313252261706, 0.2167844067194632, 0.3398160641746861, 0.22789030149579048, 0.12231431023350783, 0.15232155791350774, 0.17288910783827305, 0.11395565446998392, 0.060504051590604443, 0.14967243506440095, 0.12583890610507556, 0.2278988781784262, 0.12192907876202039, 0.12428785647664752, 0.11574871039816312, 0.21333670243620872, 0.29190679639577866, 0.19316134575222219, 0.135827402983393, 0.13998326712421008, 0.11651001311838627, 0.12246920620756489, 0.13774813206068107, 0.14235516770609788, 0.14413458508040222, 0.09928036015480757, 0.15355191832142218, 0.2147468203412635, 0.12540636717208795, 0.13050884194672108, 0.07776446254657847, 0.12088707967528275, 0.18414347964738095, 0.08206114305981568, 0.12921646343810217, 0.1593559304518359, 0.1488541489733117, 0.12954486081642763, 0.147838490615998, 0.09804206767252513, 0.13786934555641242, 0.08116538862564734, 0.13472270726093225, 0.20163410396448203, 0.15822357764201506, 0.14764411747455597, 0.13204812577792577, 0.15922482391553267, 0.13516811121787342, 0.10003267907138381, 0.19963801678802284, 0.07417835747557026, 0.12408766150474548, 0.11391431811664786, 0.130597037928445, 0.1274237467774323, 0.0751996273174882, 0.1176514175853559, 0.16385008501155035, 0.10588440578430891, 0.14510011327053818, 0.12164444689239774, 0.11970949572111879, 0.12658376113644668, 0.1541314415101494, 0.12047743451382432, 0.1752270409571273, 0.09459591723446335, 0.11963858881167003, 0.12348581451390471, 0.16447022530649388, 0.10876628650086266, 0.154438085055777, 0.1317215333027499, 0.12053630421204226, 0.10952072923204728, 0.12278690987399646, 0.100692357601864, 0.14513779910547392, 0.09824779270482914, 0.10111749371779816, 0.0962394918980343, 0.11994789221457072, 0.12965234076338156, 0.2140533575522048, 0.10432865390820162, 0.10197988458509956, 0.1205945225166423, 0.14111753340278352], [0.023849776480346918, 0.02555136419167476, 0.03439156099089554, 0.021122966460617523, 0.03239823205928717, 0.007471042053241814, 0.018812128941395452, 0.10137071620140757, 0.06330566839980227, 0.04337496090946453, 0.01159327884670347, 0.020104495575651526, 0.05221676074766687, 0.05792813588465963, 0.08258774051708834, 0.01071352172376854, 0.016161487870184437, 0.06326096651277371, 0.017790038072104965, 0.07575859089515039, 0.05105897644534707, 0.053978844944919856, 0.034711283299007585, 0.02857675336833511, 0.08995088362800223, 0.04718349315226078, 0.05512358441150614, 0.05392316096861448, 0.09225902905953781, 0.04510657549170511, 0.0200955982852195, 0.012936683188724731, 0.015833933571619645, 0.006923604665124523, 0.04248631073694144, 0.031664678028651645, 0.03167396038770676, 0.03920865750738552, 0.09128894111407654, 0.05231126031971403, 0.0168678156831967, 0.07036092624600444, 0.05159243389165827, 0.018693566821249466, 0.02217667706177703, 0.02577478202459003, 0.04066861720223512, 0.024851967613877993, 0.06436169959072556, 0.029421587142028978, 0.022403039736673236, 0.0037074449438867824, 0.06351769023707934, 0.027723929844796658, 0.01778112381829747, 0.0672590509057045, 0.04379881459421345, 0.02065741170996002, 0.09270361198910645, 0.05396778482411589, 0.03786665773285287, 0.0562747631754194, 0.06262432424617664, 0.01071462603951139, 0.0240635998280985, 0.010407489707826503, 0.03319711883419326, 0.01328719571964549, 0.025324397620611956, 0.0327653534311269, 0.028318989789113402, 0.04744796235380428, 0.03272806793185217, 0.013774249004200101, 0.01506059364016567, 0.0356175414552646, 0.0352846962798919, 0.047110299579799175, 0.013485426332668533, 0.04602391751749175, 0.006203422863369009, 0.08002587048602955, 0.03237861221922295, 0.18549149802752904, 0.18316245371741907, 0.0779755005080785, 0.11432795306401593, 0.06138153986207076, 0.16113605350255966, 0.09660079143941402, 0.08272423462143966, 0.07737195717969111, 0.11460144338863236, 0.023930160827668648, 0.024660773408998336, 0.020592933919812952, 0.03100159325237785, 0.01915367123936968, 0.09544650837779045, 0.11027340777218342, 0.030186408066323826, 0.0277644723121609, 0.04640622450304883, 0.03559069521725178, 0.04010959594909634, 0.03258393691586597, 0.018218108851994787, 0.029847211803176572, 0.030891687542732273, 0.017624049746830548, 0.06911744975617953, 0.05311400456620114, 0.020717451881085123, 0.05315008566581777, 0.031043645460158587, 0.046502674863274605, 0.010528860962949693, 0.010324431932531297, 0.03509257248203669, 0.0364935844471412, 0.02095274407682674, 0.016388262755104473, 0.035536978992500474, 0.009266835870221257, 0.0179502673314086, 0.03581170425085085, 0.043615735668156824, 0.05244000216147729, 0.029563200793095996, 0.05459863579432879, 0.048346268079642735, 0.04121359956583806, 0.011208941345103085, 0.06228736375591584, 0.021099616374288286, 0.03775093697809747, 0.02114052864323769, 0.030499294134122983, 0.015434571608368839, 0.03636047283985785, 0.02137203291723771, 0.09369796434683458, 0.0603363448753953, 0.00426692293590999, 0.045955412622009, 0.0345108169130981, 0.07226188281284911, 0.02523738907517067, 0.05378941832376378, 0.05603947097967778, 0.04404800318713699, 0.041372831378664286, 0.10295093605028731, 0.03257537380393062, 0.009242616410899376, 0.020025973806955984, 0.039575293726686916, 0.010350333310530653, 0.050907737775040526, 0.028363031800836325, 0.05229292969618525, 0.05401279205190284, 0.016735470820484415, 0.04569513337420566, 0.010537876997009983, 0.037316236911075454, 0.03971020345176969, 0.012904966765615557, 0.021032758622563312, 0.0447242345793971, 0.025477337717477764, 0.04383999149182013, 0.07784694526344538, 0.0042615425772964954, 0.04532155574166349, 0.016697752755135298, 0.010698414989747107, 0.04641791905409523, 0.017282809396939616, 0.08766677190682717, 0.016965984433357204, 0.012666873916584467, 0.02697737169052873, 0.07071972199316535, 0.03704205108806491, 0.010328135037395571, 0.037788626205708296, 0.014111688709817827, 0.03701004459123526, 0.025762626069730947, 0.024974422828693475, 0.025306002536256398, 0.01638308722924973, 0.051159521764410396, 0.03936561283522418, 0.017166433855891228, 0.04906298087111541, 0.04906927089073828, 0.04576476803049445, 0.027669009220387255, 0.020066141383722425, 0.027153173328510354, 0.008157839932079827, 0.045364730924900086, 0.037614754999854734, 0.01961292409604149, 0.049016355337308984, 0.03615224740601011, 0.020368915583406175, 0.04407307505607605, 0.05972758361271449, 0.055848259811422656, 0.04465044050344399, 0.027124917433996285, 0.10518187776740108, 0.01251082104032061, 0.03227311698719859, 0.017968686164489815, 0.041238138784787486, 0.025223660615405867, 0.04149987009753074, 0.06805033808840172, 0.03258696996739932, 0.027798008905457597, 0.03091615890817983, 0.02030869390416358, 0.010127333624820625, 0.04145109700039029, 0.049487472378781865, 0.023130851664713452, 0.046236502538834295, 0.03411888151562639, 0.014885373845962542, 0.02521710766346327, 0.0444986182930214, 0.021077526666756188, 0.014515370396631104, 0.03848349695493068, 0.03274123151121395, 0.025002420879900455, 0.06439125657613788, 0.011684184727658118, 0.01772991138776498, 0.016378593631088734, 0.03223579416849783, 0.07060004877192633, 0.016477071114682725, 0.052714676529701264, 0.04459539435005613, 0.09304861990468842, 0.09290097746998072, 0.022422724037564228, 0.019833115494943092, 0.08374552481940814, 0.02564530906134418, 0.07816340721079282, 0.032201826705464294, 0.19706552768392221, 0.11814203911593982, 0.10801806593579905, 0.17180214902119978, 0.11329763835029942, 0.07767857358391796, 0.05317811594743814, 0.1695158795586654, 0.09071139246225357, 0.09724462617720876, 0.06962848840547459, 0.1896865272096225, 0.05309026941124882, 0.04758278726200972, 0.040640318899282386, 0.08784973208925553, 0.013569920905865729, 0.030718566118074313, 0.12793372012674809, 0.011085558233649602, 0.0378149805058326, 0.08239812390612704, 0.014968056730659944, 0.11111071998519556, 0.047328577509948185, 0.059616995975375175, 0.029937504458108118, 0.018636215345135758, 0.016841692084978734, 0.06589385201888424, 0.015511698987601059, 0.039614333238984854, 0.021660135493480732, 0.044661887389208586, 0.038900266734084914, 0.05196338559367827, 0.03232719962085996, 0.024106617251943265, 0.021035179296242337, 0.033865346905908415, 0.03471591769318495, 0.08367018707628761, 0.033676792202251296, 0.076974003176604, 0.04921674369169133, 0.04485480507303562, 0.04436470601441605, 0.030092356327388967, 0.01710285003563123, 0.05237636914742844, 0.0272803392726928, 0.01915839553943702, 0.011938453003365015, 0.03221027785912156, 0.06064911559224129, 0.022288767654182653, 0.02018404532490032, 0.059629786360476694, 0.013662619815607156, 0.04865782082613025, 0.07667982431926898, 0.03440600021609238, 0.039816943795553277, 0.03641730693301984, 0.06049502028950623, 0.04848856705107859, 0.037177218656454764, 0.01799696750406708, 0.04313062384192433, 0.04403980987678681, 0.04467856238729187, 0.07164305887584176, 0.024302861453699212, 0.014416302587570888, 0.04801457980647683, 0.04611087856548173, 0.037885792420378754, 0.04686877503991127, 0.05231574882886239, 0.031530375592410564, 0.039303136723382134, 0.02415422157251409, 0.053099032691014666, 0.048911823625011105, 0.03347614939723696, 0.05405123106070927, 0.01094904716592282, 0.04066622197361929, 0.03654551273211837, 0.020576694880479147, 0.0188686593901366, 0.09960602303700787, 0.043178521628890715, 0.03342632117814251, 0.017347592527845075, 0.08296608485813652, 0.19372987667364733, 0.1147253303123372, 0.20466696550803526, 0.14768824939216885, 0.11229863802769355, 0.11840769914644104, 0.25791292477931294, 0.23221810641033308, 0.1281187566263335, 0.13397416099905968, 0.12117636629513331, 0.1359846331179142, 0.09827210461454731, 0.17106519213744573, 0.12660866337163107, 0.07622279027210814, 0.09529353944318635, 0.08926474901714496, 0.16922173462808132, 0.08202395255544356, 0.09280497833554234, 0.09023556978042636, 0.09015012186552797, 0.14190110564231873, 0.20052966608532838, 0.14903625420161656, 0.12079910082476479, 0.18779929062085493, 0.09776408544608525, 0.15763540991715022, 0.1251494059605258, 0.10491437212164913, 0.15509984668876442, 0.12303708573537213, 0.09783123327153069, 0.12733437014477594, 0.13420042528637818, 0.21627062000334263, 0.08569437238786902, 0.07724618392863444, 0.22729894465633801, 0.1264960536999362, 0.1426884098244565, 0.08794820109116179, 0.12268730093325887, 0.11745148045676095, 0.15157529152929783, 0.14930199565632002, 0.11415987993989672, 0.13270854391157627, 0.16047608320202145, 0.11760409655315535, 0.16292112985891954, 0.11282351200601884, 0.12472997632409845, 0.16950012397553238, 0.07692830384309803, 0.16225137508341245, 0.08816021614308868, 0.21740985315825256, 0.17052678817084857, 0.1978490592113563, 0.08050902134605817, 0.10522802493401937, 0.19904558786324092, 0.13899677220199788, 0.0909975849624191, 0.08443485533020326, 0.15230597874947957, 0.13860840589872428, 0.18381585579897675, 0.1724019604069846, 0.2351835487144334, 0.1834232554371868, 0.13328905776143074, 0.14408984248127255, 0.21071260395858968, 0.10588755418679544, 0.11639661634606974, 0.12631096291754926, 0.2913146253143038, 0.20627626058246407, 0.36796894350222176, 0.3677083046308586, 0.33243485167622566, 0.20226900918143137, 0.17624966108373233, 0.30512653131570133, 0.2606917699532849, 0.33003867311137064, 0.18735251602317604, 0.428499804011413, 0.20743301351155552, 0.1632322110235691, 0.11349447457385914, 0.18097872446690286, 0.1231955915157284, 0.16367699072829314, 0.26308488153985565, 0.08927540201693773, 0.17545743073735917, 0.2177619178380285, 0.14585509204438754, 0.12346947539065566, 0.15154626380120004, 0.14260423077004297, 0.10223838607115404, 0.15468956370438847, 0.1053517015118684, 0.14236693350332125, 0.1040429160264986, 0.16280374330069336, 0.13781024515628815, 0.1422581643398319, 0.11617454540516649, 0.09190396525497947, 0.14847676136663981, 0.08045044341789824, 0.1172730800296579, 0.10434531872825963, 0.10154921840876341, 0.17219113957669052, 0.08460593436445508, 0.1410673489528043, 0.14130247490746634, 0.26857319846749306, 0.1312830096908978, 0.1023818419447967, 0.10299139709344932, 0.13345216400921345, 0.12068419770470687, 0.061118614327694686, 0.13686169391231878, 0.08598553176437106, 0.16447908697383745, 0.09645625669509172, 0.14913745091429778, 0.15105458375598702, 0.16115415681685719, 0.16455428222460405, 0.20343368739954062, 0.07795221997158867, 0.12309801818004676, 0.08849990434412446, 0.14847780631056853, 0.1524516059351819, 0.09016895799764565, 0.1465683002024889, 0.11849124037793704, 0.16241829469799995, 0.20803186137761387, 0.17510642457221234, 0.0819211205733674, 0.09937476473195211, 0.121039872190782, 0.10670324827411345, 0.05404339058856879, 0.11417916390512671, 0.10053916475070374, 0.21050195954740047, 0.11249223763921432, 0.07113408297300339, 0.17471663334539958, 0.10664409359118768, 0.08752976211586169, 0.09445434768817254, 0.1276542315525668, 0.09479835137192692, 0.11433716756956917, 0.12232881731220654, 0.09913566256208078, 0.14681961600269589, 0.09906837902963161, 0.12732286219085964, 0.1130173151780452], [0.06986531069768326, 0.05430951541555779, 0.05346230337662356, 0.03251319285482168, 0.015534533387316125, 0.04162139571937067, 0.020890057619128908, 0.07670869598431246, 0.01934424797738237, 0.07857732035751853, 0.024102203381646956, 0.031304911976414065, 0.01918792199077351, 0.034547345845827034, 0.017843301374731318, 0.04581187871683921, 0.05764112235712154, 0.02139261118801577, 0.005974875729797142, 0.02843567236725773, 0.03652572325829949, 0.035281527521354814, 0.027472442714497447, 0.00814505124331585, 0.04355705935241921, 0.030132871653352464, 0.04377987328916788, 0.014536981736975057, 0.09036012166844946, 0.042431848123669624, 0.015518236672505736, 0.05562751540648086, 0.06021267508289643, 0.014325445052236319, 0.01782059759300734, 0.0183193377950894, 0.0662055845771517, 0.004768549880412008, 0.04276810633018613, 0.013571143965236843, 0.04312890036297696, 0.05381071075264897, 0.0709501321294478, 0.023884074729202048, 0.029502926527389457, 0.008715922262386551, 0.04432887936543141, 0.04624818691185542, 0.05547606639031853, 0.031807435011225085, 0.048892814466463666, 0.03465426600139056, 0.0464175322891346, 0.03482497184138213, 0.06895834686500685, 0.06585801858454943, 0.054134249820240905, 0.10537295322865248, 0.04090677960110562, 0.014186837311301912, 0.02610162046871015, 0.054151216588382206, 0.026821493537032177, 0.04938291691775833, 0.041130624911082644, 0.015204614394211342, 0.06290489169103758, 0.04979611421003938, 0.034960315828876834, 0.03855188649946025, 0.015476635690512401, 0.057394698794398985, 0.04510483844205737, 0.11733083693044526, 0.03501103292884571, 0.030989189632236958, 0.0031246340409519947, 0.03916837288332837, 0.1030378428154758, 0.06384228103395019, 0.11160835078252213, 0.2951137428837163, 0.2628211485488074, 0.3644352416907038, 0.45731468924454277, 0.43785644908036503, 0.41569237411022186, 0.22905168203370913, 0.7017910735947746, 0.49022266055856434, 0.45282531157135963, 0.3523463803742613, 0.5714142067091805, 0.17234243931514875, 0.15361617558768817, 0.01457301533914038, 0.005111031525302678, 0.038109831112836084, 0.04208072321489453, 0.05685376049950719, 0.014205909234338572, 0.05224584615124123, 0.039552993673299036, 0.09675037448427506, 0.10493546099002872, 0.026473773177713156, 0.027140810420470576, 0.03242486795144422, 0.0254324136102306, 0.054903060530445406, 0.014025840459258428, 0.010695644870533474, 0.03484362137636968, 0.009164992852934768, 0.004823993400870157, 0.03827699500003031, 0.0361477894309376, 0.04664898058399558, 0.031181493241872107, 0.02820486868066447, 0.04022470262965985, 0.009441794428442205, 0.010230740665325096, 0.034832249129457135, 0.031080004759132862, 0.024711512561355318, 0.03462108563897865, 0.05207096392820988, 0.05599285223122154, 0.058398340296532424, 0.030382735388619558, 0.0282626866496035, 0.041132063405322175, 0.030813008014644896, 0.03000425873324275, 0.03690258160765682, 0.02976534655317664, 0.056821781144078286, 0.032271780273211856, 0.012999598651991358, 0.06886969626482044, 0.043192350172570775, 0.023537740277658616, 0.021652988823396817, 0.019452744030526707, 0.028441302511574965, 0.05825774784066847, 0.030930699913629463, 0.023166221998898045, 0.05485660463039364, 0.022902234557217786, 0.001318117992403651, 0.054259833081492355, 0.07816603992666517, 0.028439565461927226, 0.009987183064887566, 0.03743203569735799, 0.11868994257279805, 0.025472789836515273, 0.040200312688414536, 0.013309732412121125, 0.06126422115734645, 0.018998025484117012, 0.04532950817208205, 0.02742392915700163, 0.019674791222704307, 0.00704543647589162, 0.030962818368737186, 0.0072214285277628475, 0.011980846174992621, 0.06296180042305163, 0.027366691335503544, 0.03216644110424178, 0.0327714806023453, 0.04041952360421419, 0.0789317734805601, 0.06508682960910456, 0.030661793093064, 0.0668288597038814, 0.03376372950151563, 0.04031970431762082, 0.10868070966431073, 0.024989864589380364, 0.07799742397453104, 0.0118685392995498, 0.03936961619183421, 0.04982734717694776, 0.06983825072113957, 0.02664489801307874, 0.036817995432232103, 0.06703473401388951, 0.08166033920965024, 0.038533918892166445, 0.015869154628100138, 0.015993092441931367, 0.04220046089696033, 0.009471702555726682, 0.06059612200728484, 0.011119060900195368, 0.029466112609952688, 0.07434733305126429, 0.022754773630627563, 0.049237690067717006, 0.04070856934413314, 0.016923029774001667, 0.004425425323591168, 0.04125583158539874, 0.05607503978535533, 0.017792341698493277, 0.036684500452663214, 0.035631936575685225, 0.019108497770503163, 0.08071237150579691, 0.07363241498491593, 0.020226150119145, 0.028156875898795466, 0.02925669973982232, 0.025333713906418, 0.04356500839016267, 0.012898706431899751, 0.019293610605278184, 0.0382036046524133, 0.010232969652861357, 0.04173159659174936, 0.024194049881771207, 0.030529899456139122, 0.05399286687108023, 0.024345629515924623, 0.02225597236039383, 0.03604910329782537, 0.02083221250878913, 0.046191451206271134, 0.07744633140308516, 0.06509556914014475, 0.04597455748756017, 0.040430600688393624, 0.13208513307784284, 0.05056181722985847, 0.03343134233728051, 0.05354981064530356, 0.06241792067885399, 0.028351418673992157, 0.16596136029277528, 0.01612554587024663, 0.02203364866519613, 0.03146733290382794, 0.02233499115599053, 0.03427638645683016, 0.04912126363654222, 0.09899093782795326, 0.07954744222973074, 0.028740327805280685, 0.07625881369624819, 0.02823890738987497, 0.14848529733717442, 0.10182749240526132, 0.20183037700397627, 0.4451066500374249, 0.29504607937165667, 0.30163251023207394, 0.3735734799078533, 0.3749456948467663, 0.5225836240819522, 0.3036441494311605, 0.7466243250029427, 0.3915034420788288, 0.3499740319592612, 0.3675032784896237, 0.5604630314878055, 0.18472297569470747, 0.20965860837272235, 0.03660477598064712, 0.09560973676187651, 0.022722463489377072, 0.05791277385183743, 0.09439958312681743, 0.05414106909717832, 0.05526058402444635, 0.03261869826487132, 0.02536207836653505, 0.11542527989617415, 0.062156603272472105, 0.030644398847860948, 0.026753288893295184, 0.04445377052096384, 0.06027601632688727, 0.026925862400925586, 0.06375352186816079, 0.10314529562102896, 0.034704134932586124, 0.03589163228337254, 0.04522828431800008, 0.02225676115735301, 0.019403065089136362, 0.00788783303661538, 0.044649107182132344, 0.046438434560384066, 0.012464770564942487, 0.021194645203649998, 0.027303896312202727, 0.014487511445102947, 0.028081969025411775, 0.04500303444053445, 0.02405443281999656, 0.04347479037408318, 0.0998114902260048, 0.01318456560173737, 0.01683112559840083, 0.03564792625339968, 0.04327049365799342, 0.05111312014716012, 0.040454064429338486, 0.020785198513684527, 0.019094645478097454, 0.06435370644820587, 0.014830985871542777, 0.051879013156784434, 0.03389027288981846, 0.059269782820982594, 0.014521524709250246, 0.021605498157441616, 0.022548665226038014, 0.01833399584782975, 0.01703992100166423, 0.03641744264002357, 0.020011870456593375, 0.013431956076861491, 0.006488521225816969, 0.06389576316412006, 0.020248643555013195, 0.005302515803902809, 0.13273993294153894, 0.06522020245237009, 0.07160493877849408, 0.08969886893672602, 0.03772517639611449, 0.008170438631038581, 0.04968720255419612, 0.017617978554751192, 0.01540110117223646, 0.049158030056527684, 0.0512707675807178, 0.05915664389197316, 0.014925288668434535, 0.031764035911432335, 0.02960548031010798, 0.04719501806955252, 0.04902767330142004, 0.0012692196843480425, 0.04277002319161381, 0.021738887964082614, 0.022837127425840924, 0.2139592854572194, 0.10728740585701806, 0.13918756267854146, 0.2237513464476381, 0.14968668429979257, 0.20211749231176718, 0.11851516552269459, 0.15122790874115058, 0.18584656183208736, 0.1320649127342871, 0.1430075384144272, 0.1034472504896777, 0.10413996689021587, 0.1535036066280944, 0.14552494404571398, 0.10177063117069857, 0.12233349920383521, 0.062140121656869135, 0.06710928465638842, 0.07790539426995174, 0.11479181317346436, 0.12662558603499616, 0.15600406245461532, 0.13303002023271152, 0.15040955479655946, 0.1044048737468464, 0.1700919693601983, 0.1261571254581213, 0.151508930804474, 0.08018199460847036, 0.0839735668684755, 0.196469122543931, 0.12924219348600932, 0.14684932226581232, 0.09607334581336804, 0.08856608864984342, 0.15602768904396466, 0.14689751182283672, 0.09925346302666835, 0.11677997506090573, 0.08961438454155411, 0.09660332916038376, 0.11954150402120181, 0.06351726954536778, 0.12417948086346899, 0.1189928948879242, 0.09572065009602479, 0.14607100188732147, 0.13928886795682566, 0.06887898540922574, 0.1016527357112084, 0.10112590076667921, 0.15346722358039447, 0.20107336262507097, 0.1537772598011153, 0.1940028920237507, 0.193489064595529, 0.1780155213283641, 0.20631853331412586, 0.11639205659074442, 0.20378647132643632, 0.19906616104500635, 0.15550049447587558, 0.15974504314363003, 0.24693205686552183, 0.10139972357345478, 0.25231362666402546, 0.11609960799770695, 0.1463448314794472, 0.15850563107856683, 0.10115282503621918, 0.11935680678912572, 0.1530785858631134, 0.257478228104966, 0.16804500562804087, 0.14141744588102612, 0.1373278067580291, 0.11694521190864698, 0.20732872267918928, 0.20486907394868986, 0.3206847964652947, 0.6039711854287556, 0.4046735353767872, 0.4625611220087324, 0.5283360811216491, 0.6350397297314235, 0.6609586275049618, 0.49738902172871996, 0.8544066271611622, 0.6163679116538593, 0.49027840899569647, 0.5711263992956707, 0.8239056095480919, 0.46566083282232285, 0.36892250233462875, 0.07331631944647857, 0.14840468737695897, 0.07033525048089878, 0.15753343967454775, 0.19319812235023293, 0.20673397316464356, 0.16979669806148323, 0.1972387305327824, 0.1790141620274101, 0.21647185991917337, 0.19884517576013291, 0.14713575903858456, 0.14034389491592134, 0.2516113157783236, 0.07265765193317618, 0.08697673571961266, 0.08203258352088076, 0.20003539403634413, 0.06348297638552529, 0.09737927466630936, 0.10543909682227032, 0.1525941797133003, 0.22538752507950577, 0.10017729523990836, 0.13448764915977204, 0.1344601142087153, 0.08298128404255424, 0.1636675726622343, 0.06928316157843385, 0.06980213908744709, 0.1295784075877496, 0.16921246583972657, 0.14320025593042374, 0.114812576345035, 0.1645494917673724, 0.11852835624345712, 0.11806149700922625, 0.16612163026418003, 0.1298800299742392, 0.14404670122478688, 0.1163383030465671, 0.1179491723222392, 0.09975915482001645, 0.1362379030989749, 0.14831695279904775, 0.1505673277590956, 0.13192931429616042, 0.1518686357885599, 0.08145073295703956, 0.08446865994483232, 0.0987198291612523, 0.114443589001894, 0.13776491901704244, 0.1459596271493605, 0.11770370549389295, 0.09533484186977148, 0.06791492285473005, 0.13589273233498844, 0.2616797983646393, 0.12278480641543865, 0.17499772326222487, 0.36096456221171785, 0.12012934604925768, 0.14680031846676553, 0.10920035892299243, 0.0960273818512048, 0.16928253136575222, 0.13125262489276274, 0.08654522815985338, 0.17193069069513253, 0.13031144253909588, 0.15734206565788814, 0.09235868549772672, 0.11111153422721795, 0.10633496660739183, 0.18025864953441278, 0.15489676115768297, 0.08328456205448934, 0.18787961559636251, 0.13267631349819048, 0.186269859118121], [0.004070355157767023, 0.035710700920649936, 0.03869045692096863, 0.042216389506523094, 0.042234201050762615, 0.0422216074408165, 0.04127434202070747, 0.10333896987140179, 0.044360488919275146, 0.015342882867636425, 0.07034803408065013, 0.007415162998118571, 0.06244890258780547, 0.0043249245333884445, 0.023031317362827913, 0.026056209512587105, 0.04398118784385068, 0.04193592044923987, 0.00809399233133133, 0.032954230438917875, 0.01812819278399859, 0.015078690169113023, 0.021190780946718793, 0.06967510376125574, 0.049344362557998726, 0.04724853073379823, 0.04804510370429073, 0.03655696301055806, 0.04497773186968906, 0.04704865128067987, 0.013641960120626857, 0.10855716879346541, 0.05477445100301078, 0.0014966736343922094, 0.021049430227971504, 0.011336859614987458, 0.07187372685543128, 0.026084589239742075, 0.02142563209469829, 0.0066276230250618285, 0.04127937335787075, 0.03904935784105744, 0.05372771913451808, 0.03939349723181554, 0.027757973643019795, 0.02462385262229613, 0.034213231809969456, 0.02786528056354395, 0.017905394114287834, 0.027505103997620087, 0.020147143197911124, 0.06441058803881917, 0.026603802539674298, 0.012313438596070876, 0.023318675246887972, 0.07225105339395148, 0.03242917664881263, 0.027019963333649293, 0.051654648767518144, 0.011538706819659897, 0.08820743539503642, 0.03264450295163052, 0.0822499454287546, 0.058229602208094935, 0.00538888355783586, 0.05655553078811083, 0.13598886717643055, 0.0653234211994069, 0.03923214499705604, 0.022187533622075404, 0.009613289913561727, 0.10702137263225657, 0.22009216994047165, 0.19793815085930483, 0.17174387643379824, 0.05687570771468537, 0.10992256445544106, 0.16457349833633217, 2.784900963306427, 4.1598851936204095, 6.084825856345041, 9.942146096910749, 16.32730610030038, 22.275268077850342, 20.30134912899562, 15.803281647818428, 8.420307346752711, 16.07233500480652, 16.60478241103036, 23.79513440813337, 20.483244282858713, 12.244478600365774, 13.487641607012067, 3.496474014861243, 2.0997271580355505, 0.8005936975990022, 1.4671883455344608, 0.07824812230787107, 0.1125042884211455, 0.4241883653615202, 0.08459891831236226, 0.031671599085841856, 0.02719242318666407, 0.17267188163740294, 0.14199855684169702, 0.14946259132453374, 0.0217881462137614, 0.011662445313829397, 0.018788249597751668, 0.07228773499705962, 0.06653517617711, 0.07877285379384245, 0.018974493889670287, 0.018275626569188068, 0.03854198328086308, 0.048140651612941704, 0.042311163885252814, 0.018766154801206927, 0.04616541921028069, 0.031750455033034086, 0.04424204384641988, 0.023453211777710488, 0.062357619271746705, 0.024659382412210107, 0.03489254375121423, 0.011136135385770882, 0.0038872664777695066, 0.04474946929674063, 0.035182695503213575, 0.02645139000378549, 0.039843165781348944, 0.029203712940216064, 0.05330468986981681, 0.016439263143443635, 0.03734238425801907, 0.007246167066373995, 0.06095527059265545, 0.04173780518716999, 0.03709172324410506, 0.024971856269985437, 0.010926229729583221, 0.06832367234996387, 0.01577104185707867, 0.047402680319334776, 0.02074168236660106, 0.0372291096220059, 0.0340352385038776, 0.020561777288094163, 0.026111009697030698, 0.04696817024211798, 0.01281035693162786, 0.030467430129647255, 0.03340440110436507, 0.030945919454097748, 0.045079026969947984, 0.06198062521538564, 0.028839278567050184, 0.05515684959079538, 0.048817968661231656, 0.0377544382187937, 0.03440575594348567, 0.008024601947649248, 0.038576948190374036, 0.057928855131779394, 0.020107247035152147, 0.023927232949063182, 0.09605852660856076, 0.09317704622766801, 0.05438473441505006, 0.025454338773020675, 0.00246858291627307, 0.0424088152524616, 0.057668521601174555, 0.03129580603646381, 0.07828187942504883, 0.02724347955414227, 0.02082503360829183, 0.0256621418188193, 0.07225673273205757, 0.05158808448218873, 0.024263640433283787, 0.05344370473176241, 0.05067464742543442, 0.07952546448047672, 0.07117375691554376, 0.02715643708195005, 0.035432501563004086, 0.013237087604855853, 0.03503540590671556, 0.04766386201871293, 0.011604048045618194, 0.0078077056844319615, 0.04307469559301223, 0.06774752148027931, 0.03587471640535763, 0.023862300540453622, 0.028466430359653065, 0.042871311506522555, 0.030847945782755102, 0.019800766337929026, 0.05186092002051217, 0.0109899857281042, 0.03794166299381426, 0.02390780988415437, 0.025642411716814553, 0.04433347983285785, 0.036915416097534556, 0.0669060702036534, 0.0172170525682824, 0.008778920846192964, 0.02062660113110074, 0.018738229692514454, 0.02636141117130007, 0.016718069789931178, 0.04818419999043856, 0.014188485303228455, 0.02781458381962563, 0.0226829133794776, 0.018836206756532192, 0.014689791215849774, 0.021695180130856376, 0.01829552460860993, 0.06568495822804314, 0.061500826318349154, 0.030099389342857257, 0.06607023041163172, 0.00795987225137651, 0.042536831061754904, 0.026380952979837145, 0.03730683920106717, 0.03944103200254696, 0.0538874055658068, 0.021187758073210716, 0.0183352019438254, 0.051908346225640604, 0.021753060864284635, 0.08811694596494947, 0.0466416422277689, 0.020409917758245553, 0.02625342401941972, 0.00651588908762538, 0.06268567738256284, 0.09054696985653468, 0.051521360741129944, 0.03718235516654594, 0.020905648657519902, 0.07507434261164495, 0.19223538972437382, 0.1727520301938057, 0.07785846000271184, 0.05744801129081419, 0.025777189127568687, 0.14501815981098584, 1.7459598439080375, 5.9318855830601285, 7.278214139597757, 12.350446445601326, 17.710412774767192, 25.395238535744802, 34.026165757860454, 31.779139178139822, 23.571247816085815, 15.23141016278948, 24.19959773336138, 27.39576039995466, 37.96313667297363, 32.44937631062099, 19.31967636517116, 22.505203076771327, 9.832038862364632, 5.6555405259132385, 2.3996724230902533, 3.409048957484109, 0.6380272922771317, 0.05611472051324589, 0.27852358881916317, 0.036429018447441716, 0.050391403159924915, 0.052737132646143436, 0.10076012289417641, 0.1686166985226529, 0.10383684494133506, 0.009920304957112032, 0.0267497672965484, 0.058927224416817935, 0.06586348757679973, 0.06264276682798352, 0.10590190520243985, 0.05156246299988457, 0.015355915829007114, 0.01730930618941784, 0.10335296804883651, 0.06851073088390486, 0.035700037742831876, 0.04375493034188237, 0.02452768724677818, 0.030708350773368562, 0.030749266434993063, 0.07747116578476769, 0.022889352569888746, 0.04411102891234415, 0.0070293717352407315, 0.034209303092211485, 0.04728740739769169, 0.0232831675093621, 0.007016798905429563, 0.016751648791666542, 0.022742237696158032, 0.0212397525153522, 0.06407560208546263, 0.08900012035987206, 0.02022266753816179, 0.021557739470154047, 0.05622475175186992, 0.08330786294702973, 0.031283962207713296, 0.052254290519548316, 0.010685784060374966, 0.0265915770349758, 0.04132581568722214, 0.015110277670568653, 0.03833248220118029, 0.03306001404832516, 0.056845896278641055, 0.03306588676891156, 0.011400163539552262, 0.04857690552515643, 0.050723803894860406, 0.03584894225267427, 0.047285195373530896, 0.018943393237090538, 0.04094251125518765, 0.04608939275411623, 0.027614052972889373, 0.03669375227764249, 0.027763585127624016, 0.016751511388325264, 0.03549829910376242, 0.040668227044599395, 0.06710620410740376, 0.014843355564932739, 0.022613417822867632, 0.01507867150940001, 0.022526063224566833, 0.02639925985464028, 0.010102172698160368, 0.06612158872719322, 0.04843064730188676, 0.03312899391832096, 0.034183335557047806, 0.04704275820404291, 0.013612326800024934, 0.11137825277234827, 0.07255492851670299, 0.16213956608303956, 0.11641634814441204, 0.1575927436351776, 0.17244301177561283, 0.18688421829470567, 0.23323623463511467, 0.17610471243304865, 0.09633618992354188, 0.1531409296606268, 0.0879494563809463, 0.17040997158203805, 0.21971193248672144, 0.10012243568365063, 0.06822722538241319, 0.142243250140122, 0.22110451704689435, 0.12018523019339357, 0.10569713011916194, 0.12979268894663878, 0.23413236226354325, 0.0785747826365488, 0.17731696952666554, 0.14464340492018632, 0.12116431551320211, 0.18828881292470864, 0.08646216190287045, 0.10166374154921089, 0.14922738394566945, 0.13658403738268785, 0.14975889399647713, 0.11124205722340516, 0.06985355168581009, 0.06619411733533655, 0.07927330729684659, 0.18656629749706813, 0.17580125800200871, 0.12810624444058963, 0.07166321136589561, 0.11261161230504513, 0.12625209321933134, 0.11108701875699417, 0.15812618072543824, 0.1566162367484399, 0.21032780674951418, 0.10300237579005105, 0.2028369294213397, 0.13362647965550423, 0.2237113264522382, 0.0925885188792433, 0.173902228474617, 0.11516005412808486, 0.14336172012346132, 0.10269879922270775, 0.26015836000442505, 0.13883239030838013, 0.13320828495281084, 0.2633931264281273, 0.15642297640442848, 0.2869630716741085, 0.16172380053571292, 0.12416467522936207, 0.15983650966414384, 0.1576815095863172, 0.19212340430489608, 0.27311829743640764, 0.17105284280010633, 0.1898175116096224, 0.13107815996876784, 0.1734627956258399, 0.3417692950793675, 0.44480649328657557, 0.27871840979371754, 0.28590300998517443, 0.09902115977768387, 0.2258505845176322, 1.4858198314905167, 6.192571137632642, 8.006072248731341, 14.69004648072379, 19.98429240499224, 27.406146219798497, 36.41597434452602, 34.462043625967844, 26.707621233803884, 16.17430329322815, 26.475202253886632, 29.785589831215994, 43.14176457268851, 37.14846386228289, 20.985076189041138, 22.63312288693019, 11.22054602418627, 6.0970664109502515, 2.884928967271532, 2.857424306018012, 0.5386315201010022, 0.11408776523811476, 0.7031769135168621, 0.3786159450454371, 0.14801999873348645, 0.12590659675853594, 0.22541481575795583, 0.36450610788805143, 0.27812982137714115, 0.0956359960670982, 0.1332668425249202, 0.0897199170930045, 0.19359180836805276, 0.173357826258455, 0.14668565961931432, 0.14314291972134793, 0.12371190238211836, 0.15927591760243687, 0.16500805930367538, 0.11763620483023779, 0.10309944022446871, 0.2448238485625812, 0.12291737858738218, 0.17456538788974285, 0.0766802653670311, 0.17063268034585885, 0.0740345623344183, 0.10073049805526223, 0.0368701103143394, 0.11465926814292159, 0.06955351707126413, 0.158590488667999, 0.06612819087292467, 0.10471411608159542, 0.06992388862584319, 0.10593750114951815, 0.12941637342529638, 0.1523192101823432, 0.08267419944916453, 0.1542482173868588, 0.18537742272019386, 0.11955932235079152, 0.10897750088146754, 0.09699736801641327, 0.1560476922563144, 0.0848515233291047, 0.18046180291899613, 0.08130220164145742, 0.13403528343353951, 0.11485137497740132, 0.16265299996095045, 0.16971407963761262, 0.20701848289796285, 0.08259662932583264, 0.16058947997433798, 0.19591406732797623, 0.09343934072447674, 0.059884847673986635, 0.17459489059235367, 0.08461014128157071, 0.1618389750697783, 0.15408497543207236, 0.09193367830344609, 0.11246891639062337, 0.19523443308259758, 0.19397564205740178, 0.17454134060868196, 0.08174787022705589, 0.08267438265361957, 0.13297884512160504, 0.18542496088360036, 0.13133066999060766, 0.11205908123935972, 0.09081324735390288, 0.14662536499755724, 0.15335297185395444, 0.08334102295339108, 0.09735892540110008, 0.14804278393941267], [0.024165023850010972, 0.016023032799629227, 0.06291558540293149, 0.020911193984959806, 0.057736863648252826, 0.03684466185846499, 0.031684213051838536, 0.07832328363188676, 0.050147327328366895, 0.02734413174247103, 0.0627693882478135, 0.07073503652853624, 0.03860443903665457, 0.011864932885925685, 0.041888731731367965, 0.018475997960194945, 0.05320595623925328, 0.02978332433849573, 0.012856648286937602, 0.10097856367272989, 0.024626699076699357, 0.05168065701478294, 0.08650915723826204, 0.10085234258856092, 0.08702506098364081, 0.03415807709097862, 0.033763970381447246, 0.04015684573511992, 0.045360951484846215, 0.034102837555110455, 0.04079148632341197, 0.07011562905141286, 0.06295316945761442, 0.04124712598110948, 0.017173680609890392, 0.0676994744156088, 0.004513512739712107, 0.025214251031034758, 0.014829028298013976, 0.04441053426957556, 0.018512119771912694, 0.07205511283661638, 0.0030193044138806207, 0.04940855197076287, 0.06087121367454529, 0.01911861981664385, 0.00792361727716135, 0.04404125176370144, 0.08050695859960147, 0.003901943190222872, 0.04382583725133112, 0.03490362762074385, 0.040542630212647576, 0.016696583978565674, 0.021286719013005495, 0.04247123029615198, 0.09433893566685063, 0.0980788781972868, 0.021908302891201208, 0.022709535700934272, 0.09580711581345115, 0.058233870193362236, 0.010486213340690094, 0.03228727462036269, 0.10330995571400438, 0.06801462679037026, 0.2570942315672125, 0.252401700509446, 0.06401625062738146, 0.34221281270895687, 1.9564644226006098, 3.7638087783541, 11.627067753246852, 30.514772006443568, 27.96053430012294, 42.06298378535679, 49.37321131569998, 72.50072806222099, 82.10386112758091, 85.3380252293178, 100.18291405269078, 104.45645918164934, 111.42639868600028, 112.48136452266148, 113.0989898954119, 107.54839365822929, 106.86192553383964, 124.92249625069755, 120.3641722542899, 118.89197404044015, 118.15211595807756, 115.46068259647915, 113.15795925685337, 96.13207953316825, 90.24321719578334, 76.81806073869977, 75.62823731558663, 60.755722454616, 43.76404871259417, 14.731384788240705, 1.8965716021401542, 0.3725369769547667, 0.2030571276055915, 0.36283278624926296, 0.5071444011160305, 0.16932947241834231, 0.058099744176226, 0.03422259220055171, 0.06398112965481621, 0.10889341003660645, 0.027219766451578056, 0.06566057167947292, 0.06902892807764666, 0.0773950545117259, 0.04083575734070369, 0.03436451119237712, 0.028526762300836186, 0.05036763747089675, 0.018460130418783853, 0.10621466234858547, 0.01333078311290592, 0.024755381546648483, 0.030792811419814825, 0.041585277300328016, 0.04398821746664388, 0.024900202972016165, 0.019990820603977357, 0.043802851877574406, 0.023244816710108092, 0.006933146987908653, 0.0320326407839145, 0.024887784084837352, 0.06921492809695856, 0.08486377088619129, 0.045519925454365354, 0.03563454893550702, 0.059429394613419256, 0.030916277651808093, 0.029234783058719974, 0.027438478644139, 0.08257081785372325, 0.03650130278297833, 0.01174795938589211, 0.06580600209001984, 0.03346883139706083, 0.046258714382669756, 0.048310801054217985, 0.01873562581438039, 0.07809260886694704, 0.023097074191485132, 0.030869350169918368, 0.022515413617449145, 0.04412037573222603, 0.0441184351220727, 0.07267716660031251, 0.057811828197113106, 0.042510045891893763, 0.052823611934270175, 0.02806875964493624, 0.008947192441805132, 0.02598704134912363, 0.05585479749632733, 0.021713541288461004, 0.042648938617536, 0.03694898661758218, 0.08305285591632128, 0.06768687402031251, 0.015479510982653924, 0.029933789478881017, 0.03847293895004051, 0.0396159685083798, 0.02252508104512734, 0.03909575267295752, 0.012386091885023882, 0.05247431907004543, 0.04484921394448195, 0.02931469752054129, 0.04474196809210947, 0.05829565759216036, 0.06305426439004284, 0.03950481090162482, 0.051808686394776614, 0.0118534537697477, 0.08443347111876522, 0.02201945031993091, 0.031545551028102636, 0.08350705368710415, 0.04669601323881319, 0.0663933487875121, 0.030204602982848883, 0.07350673672876187, 0.06799165159463882, 0.02808925140249942, 0.025536994516317333, 0.012185849415670549, 0.053857787512242794, 0.04831159154751471, 0.02853280465517725, 0.02928352222910949, 0.009264821469384645, 0.07816337328404188, 0.026267620668347393, 0.04578428269763078, 0.02106049034877547, 0.043432290333190134, 0.048932607152632306, 0.04463310732639261, 0.055717285589448044, 0.021592302347666452, 0.0414890949614346, 0.026092879241332412, 0.035926207035247765, 0.03452556487172842, 0.015995609806850553, 0.03240776886897428, 0.0330939306212323, 0.0164941786788404, 0.06163694044309003, 0.03259625232645443, 0.038080107886344194, 0.028888092376291752, 0.06061548061136689, 0.016875542500721555, 0.02884512414623584, 0.04841342608311346, 0.014551198741953288, 0.0448255466430315, 0.02667851772691522, 0.02032964876187699, 0.05387387218485985, 0.09613528248987027, 0.06679863775415079, 0.04455967965934958, 0.006004763501031058, 0.04276523951973234, 0.03753758181950875, 0.05186857050284743, 0.03151792447481837, 0.05611412340242948, 0.039823016683970175, 0.06203415484300681, 0.062146242042737346, 0.2406759639935834, 0.11484203833554472, 0.09172439774764435, 0.9756320651088441, 4.122065714427403, 7.9928533009120395, 18.494497878210886, 44.003636496407644, 41.10303109032767, 59.43786457606724, 68.00951671600342, 97.01557077680314, 108.38950089045933, 112.91396631513322, 124.46623584202358, 125.53514671325684, 135.99764687674386, 140.50099672589982, 136.49359539576938, 130.71751621791293, 129.62820543561662, 148.78423609052385, 141.56744793483188, 139.31234060014998, 141.89130347115653, 135.66021456037248, 134.92848587036133, 124.06593622480119, 117.79588181631905, 104.87785352979387, 102.3723053250994, 86.83393069675991, 63.529491969517295, 25.830381631851196, 4.790711709431239, 2.224429735115596, 0.3846219570509025, 0.12293214350938797, 0.2583805982555662, 0.2118973803839513, 0.07466392392026526, 0.06674288253166846, 0.07269603665918112, 0.1593828004385744, 0.027061415037938526, 0.019204831083438227, 0.07426171550261122, 0.043576563841530254, 0.04457530632082905, 0.008057433712695326, 0.024886506742664745, 0.05636897437008364, 0.027358503114166002, 0.08073888865432569, 0.03967531657378588, 0.03926470110725079, 0.018149056039484482, 0.08420198211180312, 0.019359009506713067, 0.043905052822083235, 0.01809523973081793, 0.03757113876885601, 0.05226680949064238, 0.026928435744983808, 0.032055609194295745, 0.042892671788909605, 0.05887938091265304, 0.08491071872413158, 0.04748045739584735, 0.04460500579859529, 0.054819190209465365, 0.012390516781514245, 0.03490567679650017, 0.04382924349712474, 0.03314050526491233, 0.02642026560248009, 0.0756804168756519, 0.08739431974078928, 0.04204244026914239, 0.08784441237470933, 0.04237180455986943, 0.02752001989366753, 0.06783617208046572, 0.01473640657163092, 0.005978091137616762, 0.016822192684880326, 0.08839269581117801, 0.06609553976782731, 0.07350850770516054, 0.02513032473091568, 0.008798089460469782, 0.02545530059640961, 0.028063606171469604, 0.10139567950474364, 0.02754559727119548, 0.04148283886856266, 0.09421075361647777, 0.06627474086625235, 0.005954167265112379, 0.09551196665103946, 0.028781077225825617, 0.03747906495950051, 0.047353045482720645, 0.01161248393223754, 0.03136424986379487, 0.02713036776653358, 0.009780213768993105, 0.003951047497269298, 0.11620514733450753, 0.030170761048793793, 0.18094724044203758, 0.14810649837766374, 0.16520155034959316, 0.1191746744194201, 0.20419770425983838, 0.10326093834425722, 0.11235862052334206, 0.16580806566136225, 0.10662873834371567, 0.1090472542813846, 0.22589319651680334, 0.1466923499745982, 0.09752394511763539, 0.14617200861019747, 0.16778393249426568, 0.19155286491981574, 0.09269452640520674, 0.18257645730461391, 0.09103396122476884, 0.1945427887673889, 0.22078822473330156, 0.07899525721690484, 0.15384606325200625, 0.09629730308162314, 0.2530442460307053, 0.17981864671622003, 0.11187835343714271, 0.12238808056073529, 0.15161377803555556, 0.12964282770242008, 0.10691442194261722, 0.09267755624439035, 0.16358772266123975, 0.07941339085144655, 0.12297228564109121, 0.118752014956304, 0.15588415174611978, 0.07044916972517967, 0.1465326635433095, 0.16385507902928761, 0.11991047779364244, 0.13530755016420568, 0.10291029180267028, 0.15499715719904217, 0.14327565474169596, 0.17444264090486936, 0.0917525908776692, 0.09944465383887291, 0.12311069321419511, 0.16319584154656955, 0.14525772338466986, 0.169150407026921, 0.08912503187145505, 0.096185921558312, 0.24593813877020562, 0.14037977584770747, 0.1530207475381238, 0.19523785289909157, 0.13490668524588856, 0.10855562173362289, 0.22242170279579504, 0.0933372008481196, 0.1292120258190802, 0.41868970756019863, 0.22026682485427174, 0.22804761305451393, 0.360123694475208, 0.24944315212113516, 0.15822956232087954, 0.9289905450173787, 4.386084233011518, 8.807604278836932, 19.717101165226527, 49.43503638676235, 49.49910920006888, 67.18368162427629, 76.6989060810634, 109.99078968593052, 122.54918616158622, 124.75501687186105, 140.45693125043596, 142.06243760245187, 149.4381866455078, 151.09608241489954, 152.79206820896692, 145.76414598737443, 144.65014130728585, 161.97069413321358, 157.53950827462333, 154.02982030596053, 157.86860275268555, 153.07076045445032, 152.8252944946289, 142.63948549543107, 129.9186123439244, 119.83057839529855, 113.52206570761544, 95.08447183881486, 67.87818881443569, 28.330562353134155, 5.120280836309705, 1.9100022528852736, 0.5984016614300864, 0.3723582779722554, 0.661073869892529, 0.4168066100350448, 0.13606227109474794, 0.23019248938986234, 0.17380264667528017, 0.18758363862122807, 0.14864222891628742, 0.13644638976880483, 0.13808787454451832, 0.15270972065627575, 0.2457422592810222, 0.11237734130450658, 0.10000435023435525, 0.08876019716262817, 0.15942609097276414, 0.19475099045251096, 0.11098853618438755, 0.20110521305884632, 0.21257094852626324, 0.16374259149389608, 0.1324491671153477, 0.09093740569161517, 0.10663292490478073, 0.11949498366032328, 0.102006971703044, 0.07781561730163437, 0.16644929482468537, 0.10389210483325378, 0.19968189086232865, 0.15771048303161347, 0.1311529345278229, 0.1852758324572018, 0.14272330009511539, 0.16649931642626012, 0.1867409116987671, 0.10740517239485468, 0.08997711579182319, 0.0938579086214304, 0.19317621923983097, 0.1362734990460532, 0.1419865603425673, 0.09133174310305289, 0.10891479067504406, 0.08926632321838822, 0.1438533594565732, 0.12354989536106586, 0.07177066417144877, 0.11746587896985666, 0.17832801384585245, 0.14089844801596232, 0.1344813116426979, 0.14088973562632287, 0.11420782522431441, 0.21828019645597252, 0.14375688534762177, 0.13591519184410572, 0.13294670970312186, 0.13539649253445013, 0.15111751109361649, 0.1972654919539179, 0.14712141480829033, 0.24780063597219332, 0.20646986019398483, 0.1019244414887258, 0.17601175313549383, 0.10453035522784505, 0.1078205443918705, 0.10887162906250783, 0.12084787392190524, 0.09934674802103213, 0.2091633320919105, 0.10090610970343862], [0.01578589329229934, 0.056170251819172075, 0.0338068164751998, 0.052329994671578915, 0.025612549390643835, 0.059424828072743754, 0.024491926754957864, 0.011942592915147543, 0.03737108289663281, 0.003851265530101955, 0.07199783769569226, 0.028025652315201502, 0.05558250139334372, 0.03291229358209031, 0.07407317776232958, 0.05150203267112374, 0.060456079164786, 0.05255427424396787, 0.007596740665446434, 0.03469969731356416, 0.030569030570664575, 0.08301346017313854, 0.045930727518030574, 0.01436321740038693, 0.04805721216169851, 0.032645720921988995, 0.0836828892518367, 0.04360300974388208, 0.04017220098259194, 0.05172806625653591, 0.03926437541044184, 0.07587932941636868, 0.03763832052105239, 0.014172832348517008, 0.057398912496864796, 0.007591980742290616, 0.007335822746556784, 0.033531975865896256, 0.0103044745212953, 0.02441610216296145, 0.011700522154569626, 0.02193012457740094, 0.07990338812981333, 0.02322819429848875, 0.03041398531890341, 0.061065356114080975, 0.08534343407622405, 0.036604959185102155, 0.019356247869187167, 0.015422966963212405, 0.035482648693557294, 0.0529008631461433, 0.01752469186404986, 0.06161649618297815, 0.04710733438176768, 0.055830987702522955, 0.05798388432179179, 0.0931035540997982, 0.13227445791874612, 0.00439636070015175, 0.08105002410177674, 0.05082073262227433, 0.23633393698504992, 0.15536381038171904, 0.07129929946469409, 1.1859226609979356, 8.804140601839338, 19.71681455203465, 40.64342859813145, 64.58675765991211, 71.35366385323661, 86.85756846836635, 93.70678997039795, 102.23671817779541, 104.61696951729911, 100.10662283216203, 98.32141521998814, 84.64832619258335, 89.449065889631, 81.71774278368268, 80.29626641954694, 79.24492059435163, 78.27732835497174, 83.68108136313302, 89.18087237221854, 93.58370958055768, 88.44325160980225, 81.83347197941372, 95.03973238808769, 83.7923081261771, 92.60139410836356, 97.98154408591134, 93.40236159733364, 98.36592538016183, 100.22395706176758, 111.88133893694196, 100.33412769862584, 115.07376520974296, 120.5740634373256, 109.57712868281773, 89.73877797807965, 80.14289883204869, 56.3117310660226, 35.86488839558193, 19.57914294515337, 5.204740532806941, 0.0996430099808744, 0.16865803487598896, 0.17144738377204963, 0.14478733576834202, 0.007611676917544433, 0.03563858282619289, 0.033757588759596856, 0.022177065523075204, 0.05257623502984643, 0.02379150898195803, 0.0004747756174765527, 0.040185778468315086, 0.04867695212098105, 0.10625858392034258, 0.10007023598466601, 0.04634449817240238, 0.03542300207274301, 0.03230136100734983, 0.009585824512344385, 0.02693764346518687, 0.07195447930800063, 0.032207909771906476, 0.01715056292180504, 0.03945867730570691, 0.029138417515371526, 0.02836863141107772, 0.013535564981534012, 0.026496487137462412, 0.0053915608025688145, 0.02125847838552935, 0.11061412734644753, 0.033589614023055346, 0.04418517582650695, 0.03830847563222051, 0.03274703298562339, 0.061203940106289725, 0.050428427423217466, 0.04214847493650658, 0.03882753456543599, 0.010766813864133187, 0.03362254672018545, 0.09990799147635698, 0.04052595182188919, 0.04322193769205894, 0.06824352379356112, 0.03794203958074961, 0.025649499015084336, 0.057418813928961754, 0.03392906812950969, 0.013820905072082366, 0.03069602179207972, 0.020842994430235455, 0.05394394449623568, 0.04032003001442977, 0.033653912001422474, 0.015643110864662697, 0.046374323179147074, 0.017940045201352665, 0.0057990333797144035, 0.09464300756475755, 0.025115452939644456, 0.004174282973898309, 0.017329519747623374, 0.057361701636442115, 0.05475452582218817, 0.00772432390866535, 0.035171299507575374, 0.03833723194631083, 0.03454385817583118, 0.014009532718253987, 0.02464187960140407, 0.06069622627858605, 0.019437210667612295, 0.029180683461683135, 0.053036543008472235, 0.012550785056581455, 0.02310308940442545, 0.03139747433098299, 0.028820863126644065, 0.010923920166013497, 0.00785633035203708, 0.043423126717763286, 0.05192163533398083, 0.030559045927865163, 0.05251483778868403, 0.09219654955502067, 0.07883221203727381, 0.0308775672289942, 0.020923758757167628, 0.01358151961384075, 0.009660744108259678, 0.04781483945303729, 0.023896206935335482, 0.115535704685109, 0.02893467041264687, 0.04089995693149311, 0.06490078209234135, 0.03396141728652375, 0.05924029368907213, 0.03847288127456393, 0.028392481916983212, 0.014267632172309926, 0.04717225321967687, 0.015000266787995185, 0.05015870975330472, 0.07445428374090365, 0.03885748510115913, 0.013677815607349788, 0.019008390106526867, 0.026445030434323207, 0.043840005062520504, 0.010001724918505974, 0.039497204524065764, 0.040588926656969955, 0.028922504279762506, 0.022547498145805936, 0.011982097223933254, 0.06374671616192375, 0.03827072872913309, 0.04989763322685446, 0.012712934569987868, 0.010967726386817438, 0.02682339513142194, 0.06658644628311906, 0.03655752958729863, 0.05012776855645435, 0.03251298590164099, 0.05146164965948888, 0.09872222438986812, 0.029536554722913673, 0.027592190574588518, 0.07199884192751986, 0.12842021616441862, 0.15110592171549797, 0.2515020716403212, 3.0080312873635973, 13.991669143949236, 30.727828093937465, 55.99085283279419, 83.64778559548515, 92.58391938890729, 111.99932629721505, 114.88598319462368, 120.70580128261021, 124.49762780325753, 122.2188549041748, 111.54132189069475, 105.1163226536342, 104.47826262882778, 103.80102171216691, 101.83929511478969, 104.82668699537004, 96.59578146253313, 100.42512825557164, 110.30701610020229, 116.46932479313442, 113.46768910544259, 104.02970082419259, 111.5563577924456, 99.90655640193394, 105.33052866799491, 112.62002277374268, 111.4567484174456, 110.43925421578544, 117.6211485181536, 122.88075419834682, 116.03896032060895, 126.5471796308245, 139.25457327706474, 131.6504647391183, 118.1850643157959, 105.17280455998012, 80.4522395815168, 53.1760368347168, 34.07798194885254, 11.856525932039533, 1.486624954002244, 0.063769684572305, 0.06332028404410396, 0.12067997721689087, 0.0566502814181149, 0.05621804104053548, 0.02733696810901165, 0.017954682898042456, 0.05490917752363852, 0.05350439968918051, 0.04688931429492576, 0.020889682728531103, 0.030357867080186094, 0.005733113278568323, 0.04054107976012996, 0.030221430651311363, 0.0385611993925912, 0.060847688865448744, 0.08069455996155739, 0.030589715710708072, 0.015409934001841714, 0.009384532010049691, 0.056667668877967765, 0.04737574926444462, 0.04115063151610749, 0.040042346343398094, 0.054012367967516184, 0.05655903881415725, 0.03150090681655066, 0.006197639200503805, 0.04149334259065134, 0.02944939350709319, 0.08208075950720481, 0.032552259508520365, 0.024712599913722703, 0.014773252719481076, 0.007230626069940627, 0.014023062706525837, 0.0747697346710733, 0.015478611923754215, 0.004690994175949267, 0.051329362472253184, 0.043918837260987074, 0.006226133006358785, 0.023856882438329712, 0.019771655489291464, 0.030408285624746765, 0.05056326250944819, 0.07720551253961665, 0.06580661277153663, 0.019536953619016067, 0.0032361659021782024, 0.07681487314403057, 0.05475558094414217, 0.017384937398933938, 0.03942751219230039, 0.02834778342262975, 0.02151537174358964, 0.02877536735364369, 0.07909812991108213, 0.01935068897104689, 0.048163759123001776, 0.03843831670071397, 0.02695321075485221, 0.07757397062544312, 0.06092831239636455, 0.06414526049047709, 0.02565857272462121, 0.032987658466611586, 0.023754832467862537, 0.12475310079753399, 0.15263976369585308, 0.12040218498025622, 0.244895339012146, 0.15524091411914143, 0.12980760314634868, 0.11876059163893972, 0.09062859083392791, 0.12084623186716012, 0.11076497925179345, 0.10470687611294643, 0.14646012814981596, 0.10219298529305629, 0.10288533528468438, 0.13296078251940863, 0.17443179791527136, 0.20178685576788016, 0.1842796073428222, 0.06841047733489956, 0.14130246133676597, 0.10900921560823917, 0.12652954618845666, 0.08488915488123894, 0.19692011762942585, 0.20828046303774628, 0.10657770572496311, 0.133969479107431, 0.17018692355070794, 0.1184566215212856, 0.19830196776560374, 0.12837205374879496, 0.192278368132455, 0.12095046841672488, 0.07698395049997739, 0.18577374145388603, 0.10275957560432808, 0.08248408750763961, 0.147802650396313, 0.14362569738711628, 0.14258677884936333, 0.1335239258727857, 0.05261105405432837, 0.13998694478401116, 0.09010476179953132, 0.10271220707467624, 0.1655664529119219, 0.14953588667724813, 0.10327611038727419, 0.15513730182179383, 0.08506572326379162, 0.07957104167767934, 0.09501210347350154, 0.11161551611231905, 0.1519868773009096, 0.1133100012583392, 0.15274725721350738, 0.16182264951722963, 0.16479771344789437, 0.24798595745648655, 0.18859857773142202, 0.1736855586724622, 0.16039889305830002, 0.4485153385571071, 0.22672077853764805, 0.30038894553269657, 3.3032572056565965, 15.25651226724897, 34.31370653424944, 62.439785139901296, 94.74689361027309, 105.7127490724836, 124.03433581760952, 127.71753420148576, 131.81658227103097, 134.31673867361886, 130.01752689906527, 124.63491031101772, 112.36639268057687, 114.24408776419503, 109.9915053503854, 105.13028158460344, 103.6304017475673, 102.68571077074323, 106.8364325932094, 113.92166355678013, 119.62081227983747, 115.5999870300293, 108.04175049918038, 122.48206656319755, 110.31959928785051, 117.00998497009277, 122.75722912379673, 121.85483877999442, 123.05144364493233, 125.90076092311314, 138.79381043570382, 129.17156982421875, 141.14590072631836, 156.15167508806502, 146.85538836887903, 131.34036663600375, 118.12503187997001, 88.19745213644845, 57.66353089468819, 33.70409590857369, 11.15901712008885, 1.131386467388698, 0.17501906997391156, 0.3095766625234059, 0.3250710910984448, 0.109611537573593, 0.15022354120654718, 0.13047838929508412, 0.1626201452953475, 0.14574269950389862, 0.1894596250993865, 0.13529296166130475, 0.18086190787809237, 0.13027484236019, 0.2521258353122643, 0.14586104958185128, 0.15914418681391648, 0.10290600346135241, 0.14023845057402337, 0.18097838519939355, 0.15679452860993998, 0.1455480685191495, 0.13920337254447596, 0.15689975582063198, 0.1176652189876352, 0.1961887925863266, 0.09102606986250196, 0.1162706802466086, 0.19039592200091907, 0.24107005713241442, 0.12919404464108603, 0.21026817709207535, 0.17449631302484445, 0.12929895972566946, 0.11013683902898005, 0.11136473635477678, 0.11714167493794646, 0.1600077176200492, 0.17273624746927194, 0.18001031928828784, 0.07825823247964893, 0.07662168743887118, 0.25458139926195145, 0.23038435195173534, 0.14445462290729794, 0.1980369184166193, 0.1032729959115386, 0.10819351473557097, 0.15074439825756208, 0.20557935083551065, 0.12454384059778281, 0.05963602888264826, 0.12747317126819066, 0.15562453067728452, 0.14206802525690623, 0.12237488983997277, 0.13436454933668884, 0.1328753006777593, 0.13104126123445375, 0.06615174960877214, 0.25998785772493904, 0.10478211207581417, 0.12099439677383218, 0.11261623312852212, 0.10042766787643943, 0.12879106269351073, 0.20607506137873444, 0.1842438078352383, 0.14333529796983513, 0.15829334461263248, 0.20783704040305956], [0.09872034484786646, 0.07324725815228053, 0.026001081934997013, 0.021317319246008992, 0.0176918235208307, 0.012783378379286399, 0.01859985774249903, 0.021256374926971536, 0.09002279476927859, 0.06127909464495523, 0.05485238414257765, 0.06580676883459091, 0.016712585530642952, 0.04427606559225491, 0.056394650135189295, 0.014292849926277995, 0.008656519914178975, 0.04804200279925551, 0.03548789716192654, 0.03875100599335773, 0.030292100073503594, 0.024735110312966362, 0.025151603589100496, 0.018524274030434232, 0.11011886463633605, 0.027295703001852547, 0.06890428119472095, 0.011128788547856467, 0.05287243592153702, 0.02772489675719823, 0.026595159699874263, 0.12972845882177353, 0.04720013761626823, 0.01645882361169372, 0.02216873989839639, 0.04000084714165755, 0.05978377988295896, 0.05824414999889476, 0.03662960696965456, 0.04699059582448431, 0.027796338012974178, 0.03146980616397091, 0.05087498488969036, 0.026947073405608535, 0.011563357996887394, 0.05679575254076293, 0.033837961232555766, 0.07510472740978003, 0.021707073153395737, 0.06400903780013323, 0.032555360413555584, 0.06272428602512393, 0.03081952195082392, 0.08015348256698676, 0.01909643511420914, 0.06978534534573555, 0.057421005597071986, 0.09562246607882635, 0.0416949285593416, 0.14745642111769744, 0.10653051361441612, 0.6423417436225074, 6.5288504873003275, 22.471806560243877, 50.83085305350167, 71.60435485839844, 84.86258084433419, 99.23217119489397, 96.5362354006086, 81.16753578186035, 86.45765795026506, 65.0795794895717, 66.85461493900844, 60.11188847678048, 60.641876220703125, 60.25733511788504, 62.10493060520717, 51.04485409600394, 49.42784152712141, 60.96719087873186, 58.79384994506836, 56.13058458055769, 52.919422490256174, 89.07518332345145, 50.28247690200806, 55.01579475402832, 60.54737377166748, 47.21183518001011, 77.4809466770717, 62.88209356580462, 66.9734638759068, 70.20056165967668, 66.92844649723598, 87.00736468178886, 75.73277296338762, 96.16058104378837, 82.76730987003872, 89.92345414842877, 81.80616555895124, 86.80958420889718, 97.78233228410993, 101.67947265080043, 100.65730231148856, 108.57945074353898, 106.76238564082554, 92.78982925415039, 69.11557960510254, 35.2502681187221, 13.612889834812709, 4.989786718572889, 0.10858556548399584, 0.10813843804810729, 0.22930035154734338, 0.045228725365762196, 0.025105011982045004, 0.013313614480596567, 0.02551538996132357, 0.018408112227916718, 0.030236897857061455, 0.05880323571286031, 0.06336246856621333, 0.0068830269987561876, 0.0592298171083842, 0.011786473033550595, 0.01838232111185789, 0.0172500616006021, 0.036932905337640216, 0.057692412819181166, 0.08929588698915072, 0.04051146849191614, 0.054660714963184934, 0.07832614704966545, 0.028981692889439206, 0.030775033802326237, 0.06317215306418282, 0.02034687846233802, 0.05335323565772601, 0.006950852935135896, 0.01731608305791659, 0.09646237029560975, 0.02095621308710958, 0.04271823739899056, 0.060313349323613305, 0.04054987696664674, 0.04603009557883654, 0.011228923353233507, 0.05313177200566445, 0.07098023872822523, 0.0347014886460134, 0.03775999542059643, 0.05602208351982491, 0.0662161290113415, 0.08177452986793858, 0.04970529569046838, 0.049883102399430106, 0.11643317581287452, 0.04540400792445455, 0.01373821116119091, 0.00982047718883093, 0.0032842263255068766, 0.020932457576106702, 0.04125574676852141, 0.04354248781289373, 0.022523267660290003, 0.05639315735814827, 0.07210653222032956, 0.05420711091054337, 0.028125890597168888, 0.10814835823007993, 0.02910162734666041, 0.06681150956345455, 0.04598189923646195, 0.10357661319098302, 0.016491618905482546, 0.03983058913477829, 0.05322635978726404, 0.0037604550681343035, 0.02829562104307115, 0.02168246099193181, 0.006400124228093773, 0.07185134198516607, 0.0313385808840394, 0.021518606659291045, 0.055508320552429984, 0.034115577050085576, 0.022037151602229903, 0.04402477354077356, 0.04311121774039098, 0.01983965657252286, 0.049239125169281445, 0.04543979386133807, 0.021636985574981997, 0.009397160394915512, 0.034138888120651245, 0.011605830896379692, 0.002405969189047547, 0.026430659062628235, 0.020832402498594353, 0.01768841388236199, 0.04266699443438223, 0.01641473749519459, 0.03041636019146868, 0.054068289431078095, 0.035390350967645645, 0.03525560748364244, 0.03332805234406676, 0.02890006173402071, 0.06399592850357294, 0.10179183539003134, 0.00913574205644961, 0.0596153267792293, 0.03951965046248265, 0.10407119058072567, 0.05065832865823593, 0.05595091537439397, 0.028484584564077, 0.056569081132433245, 0.04736480788726892, 0.037526833824813366, 0.03078952052497438, 0.012675856023893824, 0.012793667514675429, 0.03682371208976422, 0.03330571497125285, 0.03402799514255353, 0.009577428489657385, 0.06382417771965265, 0.03960674721747637, 0.0434830617159605, 0.053692920466086695, 0.014283375881080116, 0.06347319191055638, 0.021687349836741174, 0.07214049289801291, 0.049944123053657155, 0.16447053743260248, 0.06614828229482685, 2.0154650509357452, 10.973277006830488, 32.2464576448713, 68.93950530460903, 90.7004086630685, 105.58511066436768, 115.38881737845284, 109.98163196018764, 98.98002801622663, 102.22831780569894, 91.21479770115444, 92.45051397596086, 91.77798393794468, 89.09315136500767, 82.94968618665422, 91.86409991128104, 79.45744514465332, 79.03949710300991, 85.6443782533918, 84.38045924050468, 82.76112597329276, 83.73944623129708, 115.92031288146973, 86.73514120919364, 87.48597049713135, 100.008423941476, 78.96747207641602, 108.86429214477539, 99.67474365234375, 94.45045566558838, 104.8288687297276, 96.14717102050781, 112.84930637904576, 104.24593571254185, 120.5464096069336, 107.45603820255825, 108.5166459764753, 104.0048610142299, 100.02985218593052, 115.60031359536308, 111.00571305411202, 117.45839391435895, 124.3682940346854, 127.09968648638043, 117.35368456159318, 96.7639765058245, 53.633210931505474, 25.385528428213938, 9.80308745588575, 0.1713256003069026, 0.09016814375562326, 0.16336676451776708, 0.07099186881844487, 0.04225295915135315, 0.0454146269974964, 0.0806988211614745, 0.07245884117271219, 0.0772924396608557, 0.036298118864319155, 0.03595342307484575, 0.036133770897452316, 0.016330570315143893, 0.07276765603039946, 0.06668512563088111, 0.01828013713072453, 0.04249013428177152, 0.009622333089022763, 0.02559880566384111, 0.030300490159009184, 0.03748882907841887, 0.11391457595995494, 0.016526482034740702, 0.03321274210299764, 0.04552877355100853, 0.03536152680005346, 0.005955886927300266, 0.055060219418789656, 0.04989867138543299, 0.008811231835612228, 0.08648124230759484, 0.011831921309099665, 0.027405125255297338, 0.014761770210627998, 0.035329116574887715, 0.03405556741303631, 0.07529035423483167, 0.08412147393184048, 0.08979549910873175, 0.03276348067447543, 0.03364926403654473, 0.036275143668587716, 0.007376702785092805, 0.16069355367549829, 0.04467567861346262, 0.039732245661850484, 0.04831123531662992, 0.019763446911903362, 0.051941774253334315, 0.028312862617895007, 0.030176613413329636, 0.03043715389711516, 0.023045363037713935, 0.02960790946547474, 0.035631994251161814, 0.10127464921346732, 0.009305847392949675, 0.016106748753892522, 0.043002937122115066, 0.002805767111047836, 0.05163513410038181, 0.04618332574942282, 0.038814252242445946, 0.05149690294638276, 0.018018982572747127, 0.03122442415250199, 0.20763582762862953, 0.1539540724562747, 0.07945633533277682, 0.12142757352973733, 0.07582468020596675, 0.06580278583403144, 0.11285488067993096, 0.1250125454472644, 0.10080196136342627, 0.1606839999024357, 0.15656859001943044, 0.21191131749323436, 0.1371095220425299, 0.16101942690355436, 0.10372611481164183, 0.08056560438126326, 0.15408292625631603, 0.090759073118014, 0.07780062846307244, 0.12175218468265873, 0.11750475902642522, 0.07164786290377378, 0.10102520616991179, 0.11087597401014396, 0.1839877830020019, 0.16010229183094843, 0.12630580605140754, 0.1468138484550374, 0.146357194387487, 0.1103747741186193, 0.08717368729412556, 0.20799536976431096, 0.12431159163159983, 0.10068152818296637, 0.1016928507015109, 0.09078659449837037, 0.2640978257570948, 0.22527403331228665, 0.09985609033278056, 0.0726260118452566, 0.17294708187026636, 0.09891457549695458, 0.08250289649835654, 0.18771725573710032, 0.07002585886844567, 0.17634735655571732, 0.13124313897320203, 0.14181965429868015, 0.07712849202964987, 0.16831384120242937, 0.09006830411297934, 0.14240627496370248, 0.17508425004780293, 0.17901511197643621, 0.09961945803037711, 0.13757954324994767, 0.10358495238636221, 0.24169178519930157, 0.31590408299650463, 0.29936061214123455, 0.23161358599151882, 1.819093868136406, 12.383705735206604, 34.76820904867989, 76.85371889386857, 101.91988727024624, 118.67414801461356, 129.47630391802107, 123.13088934762138, 105.90199020930699, 111.2002626146589, 87.33820315769741, 90.25852407727922, 83.40737097603935, 84.05779184613908, 85.5522312436785, 88.90326404571533, 76.18414184025356, 77.06035137176514, 91.53410911560059, 86.33759307861328, 76.39386626652309, 80.35613209860665, 116.60978262765067, 73.22304889133999, 80.29137488773891, 85.9580477305821, 70.62033707754952, 105.89684854234967, 88.89316831316266, 95.92218835013253, 100.84621688297817, 98.18482753208706, 121.30180386134556, 107.36363410949707, 123.45557866777692, 110.72668729509626, 116.29170799255371, 106.98702090127128, 109.81445830208915, 120.96991620744977, 126.22756249564034, 129.4406874520438, 138.25603376116072, 140.94583429609025, 130.25612803867884, 103.05048424857003, 56.87862416676113, 26.860500710351126, 9.487612315586635, 0.21654083978916916, 0.2648385688662529, 0.3089838671897139, 0.21891751725758823, 0.19326453735785826, 0.12973584128277643, 0.12223764934710094, 0.18298889803034918, 0.12277431626405035, 0.12823983441506112, 0.1580846815236977, 0.11175528754081045, 0.15854487754404545, 0.15977834564234528, 0.13197894234742436, 0.10430540729846273, 0.13142456566648825, 0.1199946975601571, 0.1752063049269574, 0.10742893469120775, 0.16653907857835293, 0.1812680246574538, 0.08127418493053742, 0.124637831268566, 0.18722259013780526, 0.08154088990496737, 0.2869465154196535, 0.1767629999667406, 0.09093597398272582, 0.1849663933472974, 0.12294143943914346, 0.1477151329496077, 0.14528789105159895, 0.105841692004885, 0.21739743596741132, 0.10883832656379257, 0.3070879317820072, 0.16352734661528043, 0.18798124657145568, 0.124264623437609, 0.12968158562268528, 0.09935530434761729, 0.1427674184420279, 0.22237461246550083, 0.22463369981518813, 0.13397642730602197, 0.13953457905777863, 0.070492880951081, 0.13356545221592697, 0.11904265864619187, 0.11636866070330143, 0.13276471304041998, 0.14817205843116554, 0.09805584871875388, 0.1649518766041313, 0.22902310213872365, 0.11369055083819798, 0.14015302301517554, 0.14139761908778123, 0.07317702299250023, 0.11268013755657844, 0.15209833346307278, 0.13628412490444525, 0.12785026031945432, 0.12274764983781747, 0.0987804698358689], [0.05486361050446119, 0.11642949815307345, 0.012384558395881737, 0.015697456430643797, 0.036649786601109166, 0.048892088433993716, 0.05613493067877633, 0.011654280841217508, 0.02965859942404287, 0.06282166258565017, 0.004974082802488867, 0.05320638710899012, 0.020759069826453924, 0.022259454941377044, 0.09121299268943922, 0.031101270046617304, 0.036123165395110846, 0.036646953717406304, 0.06402164498077971, 0.032785041124692986, 0.06399765876787049, 0.09165794881326811, 0.08840636829180376, 0.040527753332363706, 0.01846718548664025, 0.05926858859934977, 0.0686099191329309, 0.017031447795618857, 0.024296522240287492, 0.011647451386254812, 0.022473797368417894, 0.017980397678911686, 0.01926886782582317, 0.05538105113165719, 0.038770208534385474, 0.05110209395310708, 0.006945285979392273, 0.03955495124682784, 0.056558078687105856, 0.029897162158574377, 0.02271655005668955, 0.03601556331185358, 0.025392244337126613, 0.03031818974497063, 0.03470209254217999, 0.07654442265629768, 0.034331425824867826, 0.07039492085043873, 0.041696696143065176, 0.029086000685180937, 0.015612926234358122, 0.01327979120625449, 0.009499546240216919, 0.05154559801199606, 0.022662299485611062, 0.051307625602930784, 0.06683210988662072, 0.28687803766557146, 0.09042591242385761, 4.1028022680963785, 31.055133410862513, 61.76302364894322, 78.81987844194684, 86.41734450204032, 88.61557388305664, 73.07387106759208, 84.42965248652867, 68.67022092001778, 62.38773618425642, 64.58368655613491, 59.970034054347444, 68.90254783630371, 55.6409068107605, 50.08842066356114, 51.59962953839983, 53.76618555613926, 36.00630160740444, 49.87045567376273, 29.023487091064453, 37.952512877328054, 37.871479511260986, 35.8399269921439, 37.56363957268851, 41.8888966696603, 40.7405435698373, 42.77456617355347, 43.18300560542515, 39.92855971200125, 56.41132654462542, 44.263252462659565, 26.404106548854283, 32.1082649230957, 55.42450516564505, 49.18988309587751, 45.66116401127407, 43.054887771606445, 55.589340754917686, 60.51908070700509, 70.18375396728516, 60.86392675127302, 53.22101599829537, 87.28784956250871, 50.51141309738159, 78.27361106872559, 84.14112854003906, 84.11708777291435, 98.11196872166225, 98.5928327015468, 99.45152582441057, 83.77182483673096, 45.48618057795933, 23.66935290609087, 9.474086778504507, 0.8685991913080215, 0.16358745124723229, 0.09346435152526412, 0.09361267928034067, 0.01501899435450988, 0.009143936214968562, 0.025028156016820242, 0.054863339090453725, 0.03960151231980749, 0.06674920647804226, 0.029850271996110678, 0.1291788997394698, 0.0625777088903955, 0.029500025790184736, 0.026049322382147824, 0.060482874512672424, 0.01114749999916447, 0.021478045532213788, 0.026432292635685632, 0.025006717702906047, 0.08222602028399706, 0.02146545022593013, 0.006411491385993681, 0.0707642271050385, 0.008239334532325822, 0.016177747265568802, 0.03763974205191646, 0.024445199440898638, 0.035108314494469335, 0.028136950717972856, 0.029246552248618433, 0.027105989699651088, 0.0288741620523589, 0.03777829211737428, 0.05597661828090038, 0.05191360487203513, 0.040094149099396806, 0.0331632633294378, 0.03975473909771868, 0.030418867378362587, 0.026317004447004626, 0.021568333098132695, 0.06150225802723851, 0.011730090166176004, 0.039023644756525755, 0.03397241973185113, 0.04588045146582382, 0.0238970517114337, 0.017001458244132142, 0.030186808401984826, 0.06364803002881152, 0.026703011144750884, 0.06783604315881218, 0.04957537998312286, 0.028460309973784854, 0.009483744855970144, 0.05224605988977211, 0.0073236396502969515, 0.04516185913234949, 0.03216263113011207, 0.04351127180936081, 0.05952638440898486, 0.02730770967900753, 0.025469364931008646, 0.034187043750924725, 0.030258862035615102, 0.032881735757525475, 0.01867400635299938, 0.05335007029186402, 0.01786733847776694, 0.02992202707433275, 0.03838809493130871, 0.04309816272663219, 0.03325903515464493, 0.028429803039346422, 0.0392473781082247, 0.06033912008362157, 0.05875666106918028, 0.04355577692123396, 0.010926581719624144, 0.029042163930301155, 0.13606889359652996, 0.011087068822234869, 0.056552002406013865, 0.05669809778087905, 0.03452046228838818, 0.01532786010232355, 0.04959200069840465, 0.04170494034354176, 0.006896144777004207, 0.030921994309340204, 0.0403878903016448, 0.02062499978845673, 0.029036013010357107, 0.04829434658001576, 0.01986885054170021, 0.06049193295517138, 0.04685418992968542, 0.022815738305715576, 0.033758002665958235, 0.01940682078046458, 0.017010835598089864, 0.01886257293101932, 0.0605327400511929, 0.02701719999978585, 0.02850047585421375, 0.05896156507411173, 0.0638621621099966, 0.04742595407047442, 0.02730671562520521, 0.027500069267781715, 0.012011291193110602, 0.05503495416737028, 0.08616459715579237, 0.1300293348197426, 0.03308994422799774, 0.04166820106495704, 0.01734326856343874, 0.09628624296081917, 0.028874762555850402, 0.30551696036543163, 0.2668285220861435, 8.081335135868617, 43.72987747192383, 78.1501693725586, 97.37517479487828, 102.96489633832658, 100.22718797411237, 84.26150608062744, 99.67932946341378, 83.19322749546596, 91.62037794930595, 90.30879429408482, 96.57649326324463, 91.94998659406389, 67.65733337402344, 66.48953574044364, 66.07356793539864, 83.08792754581997, 57.280351638793945, 63.385136195591514, 43.823549611227854, 56.36821297236851, 59.25398744855608, 52.275039604731965, 56.49121693202427, 58.12640251432146, 51.390877859933035, 51.31217214039394, 57.72887175423758, 46.941220215388704, 79.1677747453962, 59.4428950718471, 47.101004464285715, 52.941055706569124, 76.63215473720005, 82.71102946145194, 78.94243771689278, 83.12146650041852, 89.64182976314, 92.73895454406738, 108.29110050201416, 95.65391840253557, 89.28016213008335, 119.23406164986747, 72.97991057804653, 98.1200842176165, 101.1996647971017, 99.79562841142926, 113.16580377306256, 115.26500047956193, 120.82899284362793, 105.37776252201625, 66.33512592315674, 39.36234058652605, 18.017540522984095, 3.0820198314530507, 0.030732998557920967, 0.06864833778568677, 0.08162884839943477, 0.06179279315152338, 0.02850124259878482, 0.0283037549816072, 0.06377011883471694, 0.015851751901209354, 0.04470677587336727, 0.030103772679077725, 0.086947748703616, 0.02771396386171026, 0.0451684816341315, 0.042759061458387544, 0.027199077918859463, 0.01606315457528191, 0.03732095272945506, 0.024041011397327696, 0.024803808590929424, 0.014628292194434574, 0.048859847842582634, 0.017425847971545796, 0.10128684927310262, 0.01770967916984643, 0.050501084953014336, 0.04527032634775553, 0.0317665634543768, 0.05231749605653541, 0.04232853438173022, 0.010463708878627844, 0.023901833686977625, 0.025432213442400098, 0.07006909511983395, 0.02658852532372943, 0.01407140154125435, 0.006807083663131509, 0.02104763380650963, 0.009333061736210116, 0.020201130836669887, 0.03212187831689205, 0.01926377202783312, 0.021309519485969628, 0.012083790115346866, 0.015062859947127956, 0.043667036308241744, 0.03971554691504155, 0.055870142565774064, 0.049563834709780555, 0.04053296448130693, 0.045815994031727314, 0.07321618803377662, 0.015149551277448024, 0.03936111414805055, 0.021866900380700827, 0.032051005334194214, 0.07387975456991366, 0.05029920042891588, 0.0601190643917237, 0.019361686327361634, 0.046628953622920175, 0.07148992709283318, 0.07153026599969182, 0.0936752198530095, 0.1971516880605902, 0.14813752099871635, 0.0948807390938912, 0.11216839323086397, 0.1669083916183029, 0.10941512882709503, 0.12607528056417192, 0.10025233442762069, 0.12938564935965197, 0.10787366689848048, 0.16783828314925942, 0.09717951395681926, 0.22297238824622972, 0.13233224196093424, 0.10709552293909447, 0.16055927159530775, 0.17857935678746018, 0.2506945606853281, 0.08057192832763706, 0.1357693068150963, 0.15380138850637845, 0.09309738621647869, 0.1425224808709962, 0.1500462128647736, 0.10307215633136885, 0.1700899473258427, 0.06729578000626393, 0.09219828660466842, 0.0566508344241551, 0.1185906593288694, 0.12114319950342178, 0.08498832955956459, 0.11660242958792619, 0.10989036796880619, 0.1094826702028513, 0.15064620066966328, 0.10102959629148245, 0.11849128109003816, 0.09151558538100549, 0.1769621499947139, 0.10248350684664079, 0.1296541185251304, 0.1868067838783775, 0.15480382900152886, 0.10765359763588224, 0.15113068824367865, 0.23933311605027743, 0.11547908772315298, 0.14228308014571667, 0.16388474458030292, 0.15923228780073778, 0.14772957217480454, 0.1287553853222302, 0.10367975051381759, 0.17879211822790758, 0.15492831303605012, 0.38758115683283123, 0.2574520909360477, 7.618508679526193, 46.6161904335022, 88.07085595812116, 106.32222420828683, 114.5777541569301, 113.94838632856096, 94.65970761435372, 106.69458511897496, 87.10693236759731, 85.96891471317836, 87.39519923073905, 84.96503898075649, 90.3548469543457, 76.0416898727417, 70.73159163338798, 72.31342547280448, 73.75993619646344, 49.57611608505249, 69.13431194850376, 43.98841994149344, 60.287247112819124, 58.879007066999165, 55.584609031677246, 56.09181710651943, 59.50979927607945, 57.89404085704258, 62.96187973022461, 60.91446794782366, 56.709852422986714, 75.24102810450962, 62.81256294250488, 42.26521805354527, 47.697493416922434, 75.30755710601807, 71.8825329371861, 65.94980662209647, 59.83470399039132, 76.24926035744804, 79.8735658100673, 97.46182577950614, 84.28187819889614, 82.06377002171108, 117.35927091326032, 76.39900793348039, 105.02853911263603, 105.61878163473946, 107.30123928615025, 121.08208792550224, 126.36310795375279, 132.61276245117188, 116.67148263113839, 71.26277446746826, 40.99055365153721, 17.14716747828892, 2.7641690586294447, 0.2749745792576245, 0.1661360152065754, 0.20061039818184717, 0.19229074461119516, 0.05310717171856335, 0.11300904383616787, 0.1863128782383033, 0.25050679647496765, 0.13218544769499982, 0.12661405093967915, 0.21979807929268905, 0.2307161284344537, 0.20562152857226984, 0.11760822204606873, 0.12717727571725845, 0.13459583478314535, 0.14933111837932042, 0.13526352681219578, 0.10695315950683185, 0.21986506426973002, 0.14501734556896345, 0.05894329212605953, 0.16950703146202223, 0.08076359411435467, 0.12398750973599297, 0.18095897909786018, 0.14155332930386066, 0.15038934802370413, 0.11857361452920095, 0.10222348544214453, 0.08390344705964838, 0.09695509528475148, 0.20685631302850588, 0.12820339708455972, 0.10864400770515203, 0.09788281550364834, 0.10157008336058684, 0.0890751052647829, 0.09380902695868697, 0.11284660255270344, 0.12353954091668129, 0.15168805047869682, 0.11085335165262222, 0.1540588925459555, 0.12116373197308608, 0.11063917885933604, 0.10518126030053411, 0.0904050881841353, 0.12969660838799818, 0.1791950866047825, 0.14308424001293524, 0.13229458326739924, 0.1894261868936675, 0.06936809380671807, 0.1504648554005793, 0.14395477330046041, 0.09352719065334116, 0.09894756586956126, 0.12096459551581315, 0.13465702507112706, 0.19003796763718128, 0.11480442035411086], [0.02559953848166125, 0.03389103963438954, 0.03072678656982524, 0.0624248417360442, 0.03571209531011326, 0.06990352578993354, 0.07953590713441372, 0.024692004679569175, 0.011065047816373408, 0.032462034707090685, 0.0068085157961052445, 0.04407071375421115, 0.010874025789754731, 0.11439306528440543, 0.023667523670675497, 0.03800407464482954, 0.041357116507632394, 0.03854995946000729, 0.019950383309541003, 0.07062930041658026, 0.02944879639627678, 0.021956585746790682, 0.017891197465360165, 0.031790692159639936, 0.0650321396866015, 0.02550185827671417, 0.021572580727349435, 0.048408584735755406, 0.014980380622936147, 0.06556196697056293, 0.0871429360870804, 0.030620809577937638, 0.10612121450581721, 0.022498278911890726, 0.03631754192922797, 0.03068806936166116, 0.11306638004524366, 0.050106092755283625, 0.01445581198536924, 0.018144084074135338, 0.0710463212536914, 0.04368505480566195, 0.05016628559678793, 0.02330481616913208, 0.07987191767564841, 0.03763528407684394, 0.03865411119269473, 0.036394012825829644, 0.0397324899344572, 0.04375966651631253, 0.06330963782966137, 0.0838185962555664, 0.0602601861049022, 0.06305412189768893, 0.020909297479582683, 0.27483572385140825, 0.037629177261676104, 9.395541736057826, 46.61932407106672, 77.14577947344098, 73.49231243133545, 77.85560049329484, 76.83520889282227, 57.76300130571638, 73.48645509992326, 62.47610337393624, 64.71828705923897, 70.74119404384068, 49.04229293550764, 51.29958895274571, 25.56173300743103, 52.04169477735247, 49.45220191138131, 49.82388537270682, 44.014955111912315, 24.096762657165527, 38.19918087550572, 40.157766887119834, 46.259973662240164, 28.932773147310527, 29.517934799194336, 40.844367027282715, 53.2809476852417, 42.61386823654175, 66.37373011452812, 49.50683907100132, 57.906467710222515, 55.26258781978062, 46.86450515474592, 51.27049337114607, 33.71091556549072, 54.711234365190776, 29.62553460257394, 27.012298004967825, 38.53872544424874, 23.46202039718628, 26.150422607149395, 28.485724312918528, 33.38317946025303, 39.509277616228374, 30.163488456181117, 38.24863120487758, 47.13408483777727, 36.259730202811106, 53.49426085608346, 47.049869196755544, 57.08211605889456, 78.59455530984062, 75.29920537131173, 79.22366605486188, 96.91708700997489, 94.99310302734375, 99.96559524536133, 69.56453745705741, 19.15290743964059, 1.9280554098742348, 0.17886077240109444, 0.23110596037336759, 0.08460379697914634, 0.05504984801102962, 0.0478742282305445, 0.02230618055909872, 0.061374530595328124, 0.03146412343318973, 0.02832384640350938, 0.019502129505521486, 0.07180635511342968, 0.0627129612756627, 0.04007808478283031, 0.02360912725063307, 0.01706472484927092, 0.03677759884989687, 0.04257491383967655, 0.0072286396586735335, 0.02735725969874433, 0.050731997205210586, 0.020312351207914095, 0.03526030294597149, 0.029601571948400567, 0.0262589065823704, 0.03675197736759271, 0.02250541201127427, 0.02338139902401183, 0.018457745368193303, 0.023666125888537084, 0.032192568095134835, 0.0076679537638223595, 0.0061265656258910894, 0.04966019346777882, 0.051919063686260154, 0.02213486743026546, 0.010223674571274646, 0.044255129394254515, 0.02441678917966783, 0.03173974096508963, 0.0272778032480606, 0.024299087102657983, 0.022044635843485594, 0.007292192096688918, 0.03479463114802327, 0.07599254976958036, 0.05739270390144416, 0.016574123674737554, 0.0018260923139418342, 0.04739862607259836, 0.08421251976064273, 0.05709411456648793, 0.05437358269201858, 0.020286475274977938, 0.0755244827430163, 0.022900533130658523, 0.035044542380741665, 0.03332229497443352, 0.03976614187870707, 0.008770561294763215, 0.036941119004040956, 0.022047327931172082, 0.028646588192454407, 0.013607050342086171, 0.0455848137581987, 0.040055197796651294, 0.05572474268930299, 0.05940244998782873, 0.07095785385796002, 0.035594898741692305, 0.05429632469479527, 0.024778875821669186, 0.009440531505138745, 0.02819740479545934, 0.08729639356689793, 0.049021240789443254, 0.022438147138538103, 0.009697779397746282, 0.056115103885531425, 0.012684340256133249, 0.05690498310806496, 0.037790288616503985, 0.023458049732393453, 0.026535623341000507, 0.031812897218125205, 0.09556547592261008, 0.058800779416092804, 0.044419080418135436, 0.009549290490602809, 0.01974312139541975, 0.04394496085920504, 0.04966644277530057, 0.06029154120811394, 0.02206531080550381, 0.04048976894201977, 0.016114640116159405, 0.01488173520192504, 0.01907663546236498, 0.0457086192577013, 0.05175486499709742, 0.03413390428093927, 0.02573015308007598, 0.04994541905554278, 0.016682397507663285, 0.032912564996097765, 0.02706763381138444, 0.04593147051387599, 0.05812069055225168, 0.05475006106176546, 0.0525233839372439, 0.05334732561771359, 0.060816991941205094, 0.04977737307282431, 0.06039190332272223, 0.03851701319217682, 0.06733801202582461, 0.21643920881407602, 0.23238611168095044, 15.717719793319702, 64.04988425118583, 92.32565484728131, 88.908586365836, 86.85617188044957, 91.40929167611259, 75.75370788574219, 103.86855125427246, 86.20536191122872, 93.51462364196777, 96.85164192744664, 54.22757026127407, 60.44143458775112, 27.329610075269425, 41.73272895812988, 47.89013222285679, 36.80806119101388, 30.989841188703263, 14.377709320613317, 19.501415184565953, 25.121333599090576, 24.19450991494315, 17.005266155515397, 14.323875546455383, 18.175337587084087, 24.94575262069702, 22.46745698792594, 29.546818460736954, 27.562840257372173, 26.763748782021658, 27.006419828959874, 33.737457684108186, 29.200850282396587, 17.66603810446603, 26.401224783488683, 24.266515833990915, 19.370221035821096, 26.49784643309457, 16.974141699927195, 23.705532176154, 27.630251680101665, 34.940444469451904, 39.7872576713562, 38.480575970241, 60.59549699510847, 61.868907247270855, 67.38985552106584, 80.93365246909005, 80.04317133767265, 93.78652054922921, 98.84030669076103, 89.09115723201207, 94.3038695199149, 106.84308896745954, 115.85808481488908, 117.71742275782994, 94.50552708762032, 35.461687905447825, 6.429520777293614, 0.31295017578772133, 0.098080886660942, 0.09597767237573862, 0.019019511295482516, 0.05535211839846202, 0.09179853448378188, 0.06351061990218503, 0.005432401401256877, 0.10991007262574774, 0.007768864643626979, 0.15212239431483404, 0.05427144281566143, 0.07376198124672685, 0.038939197680779865, 0.02514816341655595, 0.054771689365484884, 0.04619214331199016, 0.04381281616432326, 0.045220640621015, 0.031361613755247424, 0.060851400452000756, 0.047922824908580096, 0.02665985801390239, 0.05518235232947128, 0.020607305291507925, 0.08261593364711318, 0.01675467675418726, 0.04920866233961923, 0.017881258623674512, 0.03316795539909175, 0.01866338219094489, 0.006669084483291954, 0.033504607155919075, 0.04400500103033014, 0.043957283055143695, 0.022962072864174843, 0.017099421737449508, 0.017320958332025578, 0.024501911397757273, 0.06254435210887875, 0.06887542988572802, 0.011789847048930824, 0.025220581762758747, 0.00407877577734845, 0.05246142011934093, 0.05254769923963717, 0.022409706343231455, 0.04324309441394039, 0.07576066721230745, 0.07934912001448018, 0.0080251532573519, 0.03615038822005902, 0.020173339738643596, 0.03908846859953233, 0.041299722623080015, 0.06344910391739436, 0.011510214286058076, 0.049544978221612315, 0.006967167037406138, 0.011560291866771877, 0.12243873998522758, 0.09196726578686919, 0.11652352953595774, 0.14691634795495442, 0.05849383052970682, 0.23616658310805047, 0.2588923493666308, 0.15442399866878986, 0.10827762593648263, 0.15692855284682342, 0.19769413609589848, 0.13869155357990945, 0.07188422379216977, 0.2301803571837289, 0.09619778235043798, 0.10027052595147065, 0.10960908127682549, 0.10239034398858037, 0.0882962556289775, 0.1355977188795805, 0.12613150397581713, 0.11646346561610699, 0.07778763451746531, 0.15717050486377307, 0.2761613098638398, 0.11621954584760325, 0.1090452458177294, 0.08816628903150558, 0.08609421950365816, 0.07406739664397069, 0.22555481110300335, 0.13545069391173975, 0.23829577171376773, 0.14187164365180902, 0.11201739204781395, 0.14892045541533402, 0.12862757646611758, 0.15537841245532036, 0.09646608866751194, 0.09139229556811707, 0.14859889766999654, 0.12330571774925504, 0.07709421244050775, 0.0958942397098456, 0.24000994116067886, 0.14620418474078178, 0.15121341523315224, 0.1374659157757248, 0.15476809734744684, 0.1312279805008854, 0.13508471926408155, 0.1731596261795078, 0.18340550496109895, 0.14301493444613048, 0.1325716291155134, 0.4490676117794854, 0.17424662570868218, 16.54876603399004, 69.82696396963937, 107.48886844090053, 97.730623790196, 97.65497875213623, 97.85266889844621, 77.32212475367955, 94.55564444405692, 85.09793022700718, 83.66993645259312, 91.8114812033517, 65.73710836683, 67.35279382978166, 37.722065448760986, 70.7304173878261, 79.7200106212071, 78.11564377376011, 72.09614140646798, 40.42838532584054, 62.067834172930034, 71.00528117588588, 71.67149530138288, 50.494831221444265, 47.01202583312988, 63.702113015311106, 82.49794210706438, 62.07154451097761, 98.54354218074253, 74.70243849073137, 83.55294268471854, 83.6832492010934, 72.17361382075718, 76.89012745448521, 53.00044195992606, 87.43325451442173, 50.355450357709614, 45.933790479387554, 56.07463073730469, 37.551605292728965, 39.82825551714216, 44.569720132010325, 48.03827823911394, 53.61515951156616, 45.88613625935146, 53.83346496309553, 69.69703265598842, 56.35622385569981, 76.52846676962716, 67.4445378439767, 79.09715325491769, 99.63383960723877, 93.2633420399257, 98.8612277167184, 121.06842776707241, 124.80847631181989, 132.7215712411063, 102.82518890925816, 39.65130226952689, 5.30472901889256, 0.41609906085899895, 0.33318162017634934, 0.1712997481226921, 0.16726440537188733, 0.2933014844145094, 0.19116935692727566, 0.2125594677137477, 0.1580197728638138, 0.19804044679871627, 0.07348631282470056, 0.2342693991959095, 0.16753735286848886, 0.19340966242764676, 0.11742519401013851, 0.12429260622177805, 0.1420274760041918, 0.1403572077729872, 0.20436680875718594, 0.11891265133661882, 0.10142425939972911, 0.13364500366151333, 0.14641363493033818, 0.12371720852596418, 0.11251270904072694, 0.1315642895975283, 0.14146140137953417, 0.10039089806377888, 0.10815291798540524, 0.12705940061381885, 0.06988361078713622, 0.10078068929059164, 0.250335941357272, 0.13805879253361905, 0.15674811681466444, 0.0966329268578972, 0.11527076390172754, 0.0972126739631806, 0.07072509599051305, 0.11017478949257306, 0.16593367606401443, 0.10204408756856408, 0.12502684896545752, 0.08426275170807328, 0.11213813735438244, 0.1900070807231324, 0.19693142202283653, 0.08171649476779358, 0.13331098801323346, 0.10670278687030077, 0.17280826717615128, 0.12807649746537209, 0.1429560783186129, 0.15841639015291417, 0.20566857819046291, 0.11877595367176191, 0.11302849743515253, 0.07693488563277892, 0.1439419218472072, 0.10133522203458206, 0.16179420532924788], [0.042405639708574326, 0.021746775933674405, 0.02175654683794294, 0.03793635684996843, 0.08025385825229542, 0.014589900683079447, 0.03837159635233028, 0.04292406760422247, 0.024045164031641822, 0.03142349275627306, 0.0701662138370531, 0.042449544316955974, 0.011607972522532302, 0.027666810766926835, 0.07701836579612323, 0.033013666713876386, 0.015216330997645855, 0.03394724268998418, 0.05980212746986321, 0.02288760194954063, 0.09967783239803144, 0.008251219921346222, 0.04132334242707916, 0.05414989344509585, 0.054611049592494965, 0.05908827470349414, 0.014545892598107457, 0.01682281693709748, 0.035022839438170195, 0.04884134419262409, 0.007674343867360481, 0.038849193403231244, 0.003845551417076162, 0.004173666355200112, 0.049029040549482615, 0.03054935984047396, 0.09658585009830338, 0.06767690634088856, 0.028478908618646007, 0.008012509605448161, 0.0494462344130235, 0.06452721463782446, 0.03793297435290047, 0.031874165537634065, 0.037458712301616154, 0.04000911169818469, 0.02011657689165856, 0.026500370054106628, 0.0191519036556461, 0.019530619494616985, 0.043018309332962544, 0.06383596387292657, 0.05696120312703507, 0.14188099386436598, 0.5392365019236292, 13.225662384714399, 42.780051776341026, 78.99332632337297, 71.4376745223999, 64.26478508540562, 61.70951557159424, 71.16686153411865, 58.96362917763846, 62.08546870095389, 39.89335666384016, 33.420216832842144, 30.669345106397355, 21.770293848855154, 51.631858757564, 36.56384938103812, 61.439494677952354, 48.4288330078125, 33.7513610294887, 42.19585766111101, 45.43697690963745, 76.7893785749163, 74.66232654026577, 63.00978755950928, 70.777998651777, 82.29777145385742, 93.03978375026158, 91.72002206529889, 82.52510261535645, 72.79643644605363, 77.1639907019479, 70.20573111942836, 89.61548219408307, 73.02999319349016, 71.16142804282052, 73.37673609597343, 78.21181379045758, 71.63931819370815, 75.26668085370744, 77.76851177215576, 91.69912883213588, 106.52598708016532, 91.24222918919155, 100.07272257123674, 82.27443245479039, 76.2435211454119, 80.19387081691197, 33.173218795231406, 38.2077306338719, 40.81896441323416, 39.83147600718907, 33.30489758082798, 42.23444448198591, 46.5617721421378, 55.364062786102295, 55.48805686405727, 56.82072830200195, 60.33425167628697, 72.71465614863804, 81.68525995526994, 96.84320681435722, 72.1240245274135, 44.053434235709055, 20.66039729118347, 0.9609242486102241, 0.1558435753520046, 0.23147345493946755, 0.12376477383077145, 0.028186197093288814, 0.05904374923557043, 0.038018612257604084, 0.03621091015104737, 0.10027047166866915, 0.02569553252708699, 0.02185349931408252, 0.03154097770207694, 0.050270084491265674, 0.0217820953777326, 0.10453925082193953, 0.05129719312701907, 0.046569069514849355, 0.0432330520956644, 0.013080519041977823, 0.04120904320318784, 0.047306277456560304, 0.02227359391482813, 0.028406722670687095, 0.03274652408435941, 0.021096454401101385, 0.07144987995603255, 0.04736177144306047, 0.03525600442662835, 0.02060752242271389, 0.07512990105897188, 0.025320772547274828, 0.06174695811101368, 0.014814275250371014, 0.01246032616057034, 0.01946216548926064, 0.028706017682062726, 0.048136973953140635, 0.020558247209659646, 0.008982618755128766, 0.049579814209469726, 0.020091009692155888, 0.05345842894166708, 0.07105382585099765, 0.014961802334125553, 0.020495971265648092, 0.03231506741472653, 0.02587087615393102, 0.08465665485709906, 0.016895488037594726, 0.026615305404577936, 0.10619020116116319, 0.08018035933907543, 0.020957358114953552, 0.030579734460583756, 0.030893017471368824, 0.0511155425171767, 0.012914786863672947, 0.04892115008884242, 0.045927847136876414, 0.012738959780628127, 0.0417155119191323, 0.00526652206566983, 0.05028893080140863, 0.016825953465221182, 0.058392749167978764, 0.05354840947049005, 0.034693139272608926, 0.0489371261958565, 0.04628987271072609, 0.008353337745315262, 0.026637725897931626, 0.027302505315414498, 0.07515834524695363, 0.028642846071826558, 0.028375942625903657, 0.011105358733662536, 0.020593982256416763, 0.06095762510917016, 0.06629790605178901, 0.012324670046967055, 0.03278853897271412, 0.013557272164949348, 0.025743131758645177, 0.00436115703113111, 0.038924507397626124, 0.03533948798264776, 0.009631882621241468, 0.024832765072850243, 0.0084994220939864, 0.03946700632306082, 0.01099119521677494, 0.011049354997729617, 0.011161247966811061, 0.05753533874771424, 0.018087382295301983, 0.025604613923600743, 0.051448794813560586, 0.013320009673147329, 0.021736945657591735, 0.005932577977156532, 0.019672870968601534, 0.029010740973587548, 0.0027557531429920346, 0.08746768973235573, 0.030716839246451855, 0.058090285398066044, 0.0363861519976386, 0.07782181232635464, 0.004567820562182793, 0.047023382636585405, 0.18115845482264245, 0.07550146683518376, 1.6859345734119415, 20.159524236406597, 57.80106701169695, 97.50387627737862, 82.16830566951207, 83.2918085370745, 83.40915666307721, 93.81523745400565, 88.8141325541905, 78.72858606066022, 60.98372064317976, 48.54435723168509, 26.864780800683157, 25.435647521700176, 37.63479954855782, 25.06791411127363, 34.35071611404419, 37.8265038217817, 34.439687797001426, 36.0158623286656, 39.733812127794536, 49.91112348011562, 57.142051219940186, 54.28594207763672, 57.79436200005667, 63.04144355228969, 66.15821089063371, 60.199602535792756, 60.211025374276296, 58.49469525473458, 59.45028795514788, 56.30103778839111, 62.62853990282331, 58.70416259765625, 51.39783648082188, 52.24430077416556, 51.30515445981707, 65.761704989842, 47.639413424900596, 51.691095624651226, 59.52898325238909, 52.13625628607613, 44.3643661226545, 67.49293899536133, 42.227569239480154, 49.540781021118164, 44.25335127966744, 18.862936530794414, 32.310245582035606, 28.94012607846941, 29.151719570159912, 36.77226407187325, 57.686737877982004, 83.23290170942033, 91.61561148507255, 87.18539142608643, 88.52410084860665, 80.82058443341936, 85.85040623801095, 91.7924917766026, 113.44014644622803, 91.54940904889787, 64.15740067618233, 33.40721675327846, 3.9000460164887563, 0.050073037921850166, 0.27809198626450127, 0.10323819385043212, 0.14608385334057467, 0.13628443703055382, 0.02076913758979312, 0.04700333871213453, 0.13451521125222954, 0.054436323432517905, 0.018418329268960015, 0.025820647599175572, 0.09603568033448287, 0.02310379677718239, 0.09818574067737375, 0.07246615578021322, 0.024658525761749064, 0.02991364038150225, 0.03150106966495514, 0.013760585853430842, 0.05158949922770262, 0.02675891903761242, 0.04265603609383106, 0.03361419056143079, 0.005098498559423855, 0.019645302090793848, 0.04459302287016596, 0.020672975606950264, 0.07115052387650524, 0.040232563457850895, 0.016904310689174702, 0.02378408920152911, 0.022876170330813954, 0.013375226308458617, 0.04925150504069669, 0.036591503835682354, 0.04698152720396008, 0.026571780775806735, 0.027100970236850635, 0.047372621218008656, 0.02998951416728752, 0.08491250327123062, 0.05582955599363361, 0.03778488069240536, 0.0903850035475833, 0.06053208865757499, 0.029967929968344312, 0.03285875716911895, 0.028132090710901787, 0.04497358602072511, 0.02006786995168243, 0.03177547601184674, 0.01656769455543586, 0.007623423206886011, 0.03438894523839865, 0.046168628680918894, 0.02391653075548155, 0.029419768668179, 0.0652832044288516, 0.10994274408689567, 0.16792204151196138, 0.11189192413751568, 0.1588505847113473, 0.07975407649895974, 0.13626720224108013, 0.17165443194764002, 0.14094772322901658, 0.15115720539220742, 0.14941623381205968, 0.1812832374125719, 0.1038251741390143, 0.11598501700375762, 0.20456314965018205, 0.0903844064367669, 0.12401328049600124, 0.11832748273653643, 0.1361392576779638, 0.14402012979345663, 0.2099638134241104, 0.09457054002476589, 0.115558191335627, 0.09766546716647488, 0.224892723773207, 0.10566016353134598, 0.1313865812761443, 0.11937211453914642, 0.24812095878379686, 0.15871251640575273, 0.11346488366169588, 0.1330713837274483, 0.12559016873793943, 0.08891767835510628, 0.15281193517148495, 0.12256878800690174, 0.11211959977767297, 0.1894712551896061, 0.13041216427726404, 0.10809307119676045, 0.1537514076169048, 0.15714155855987752, 0.1705506590328046, 0.11332670679049832, 0.099424026374306, 0.280390021524259, 0.15312051932726586, 0.10909031411366803, 0.09400047561419861, 0.19390899634787015, 0.13706372092877114, 0.10149726976773568, 0.24408809947116034, 0.18884441096867832, 1.2215981866632188, 20.111922127859934, 61.375911712646484, 107.42188085828508, 91.10248701913017, 83.72726603916713, 79.25307777949742, 92.98974282400948, 77.1658319745745, 81.84873022351945, 51.623677253723145, 48.45077889306204, 44.8126916885376, 32.27044630050659, 75.14223861694336, 55.357785088675364, 95.88922609601701, 71.16668088095528, 58.595527512686594, 63.014046805245535, 68.34617083413261, 109.23868192945207, 107.4363122667585, 91.26952866145542, 100.73083509717668, 114.56089087894985, 128.73009518214633, 119.52367646353585, 111.97741862705776, 101.4860486984253, 108.38730525970459, 97.05728081294468, 125.81968934195382, 101.37570435660226, 101.46755954197475, 99.71591172899518, 106.79422228676933, 109.39983149937221, 101.7749547958374, 112.99211270468575, 137.70784868512834, 148.34452629089355, 124.99987139020647, 131.85497801644462, 108.45857988085065, 110.13331113542829, 114.27058124542236, 53.37745468957083, 60.152764729091096, 63.56847831181118, 56.72855349949428, 45.80549199240548, 57.652976581028526, 66.65593120029995, 79.4211060660226, 75.69562789372036, 78.187363079616, 78.3114926474435, 87.89390618460519, 98.78517968314034, 127.39384542192731, 102.51422922951835, 67.32297910962785, 32.639541557856965, 2.8749426688466753, 0.22728229340698036, 0.5567036217876843, 0.28767944180539673, 0.19365371790315422, 0.18199123442173004, 0.11738140136003494, 0.09315413210008826, 0.16252987299646648, 0.08548280516905443, 0.128575451405985, 0.09271078410425357, 0.20771864961300576, 0.17465640657714435, 0.23804579941289766, 0.21955824430499757, 0.15061033330857754, 0.10993944640670504, 0.13145081140100956, 0.13366617395409516, 0.11260947491973639, 0.1873697643833501, 0.09678291023841926, 0.10573521628975868, 0.13091771357825824, 0.1899226438254118, 0.13358905166387558, 0.13745997180896147, 0.11938359535166196, 0.1647964378020593, 0.1944578361830541, 0.1793298843715872, 0.054392300080507994, 0.13117764677320207, 0.11930280897234168, 0.106957495345601, 0.1418564851794924, 0.12316845011498247, 0.17910490930080414, 0.21636313146778516, 0.11108287290803023, 0.1680735448109252, 0.13776225915976933, 0.11786833166011743, 0.12769171382699693, 0.16714933940342494, 0.17735774948128633, 0.12242313367979867, 0.07232601794281177, 0.28559082959379467, 0.1813133643673999, 0.11705107694225651, 0.07996649188654763, 0.11680714360305242, 0.08240328755761896, 0.22679357177444867, 0.21489669515618257, 0.13897989025073393], [0.009642826542923493, 0.06324445775577, 0.013987764466686972, 0.07451559616518871, 0.09172601266098873, 0.02479497406498662, 0.009657955329333032, 0.01678327700522329, 0.03279252875862377, 0.02615021205773311, 0.015297212371868747, 0.06396706362387963, 0.021076457974101816, 0.03946582567212837, 0.02247446572541126, 0.0657427626262818, 0.05758625601551362, 0.032134298900408406, 0.04253307876310178, 0.00597777180207361, 0.05049911380878516, 0.031065860696669136, 0.029973412531294992, 0.049683826842478344, 0.0660310857264059, 0.05734766274690628, 0.012195724644698203, 0.03052446778331484, 0.05489896217893277, 0.05539248783939651, 0.016018335640962635, 0.042624161911330054, 0.07462126442364284, 0.0514384437618511, 0.03836513330627765, 0.00760186106033091, 0.025064399964841347, 0.05850517563521862, 0.06889405567198992, 0.04350095468440226, 0.0366696982112314, 0.04569073307460972, 0.08544786061559405, 0.060006807558238506, 0.0218327005194234, 0.030433418561837504, 0.016465829485761266, 0.09576630193207945, 0.10033863051129238, 0.014792083762586117, 0.038496297518057485, 0.08736510880823646, 2.2103524676391055, 22.558412381580897, 65.7089056287493, 81.26091262272426, 77.61887536730084, 63.00743212018694, 69.77765260423932, 52.94902876445225, 45.50287709917341, 39.408622537340435, 28.865789038794382, 44.26786606652396, 32.98390122822353, 51.22959974833897, 74.24604606628418, 52.88225310189383, 30.92976358958653, 52.74929584775652, 50.398779324122835, 46.693270274571006, 49.11154563086373, 40.03018059049334, 33.68791355405535, 33.90652125222342, 32.1134170123509, 33.030381202697754, 33.83986718314034, 32.29455654961722, 26.014899730682373, 19.077526433127268, 15.033952781132289, 12.157473257609777, 10.966478194509234, 12.01370894908905, 16.178149121148245, 20.09749071938651, 22.801795618874685, 26.422467163630895, 29.880769729614258, 22.051807062966482, 43.22821058545794, 43.76308291299002, 46.13660492215838, 50.0079778943743, 67.46919700077602, 72.12808227539062, 70.94225406646729, 56.07717030388968, 68.93973459516252, 85.90331677028111, 60.12504141671317, 71.77902562277657, 61.73473753247942, 53.43510389328003, 59.10765143803188, 21.736483914511545, 21.43201732635498, 25.130505221230642, 28.374619143349783, 57.93480246407645, 58.846524238586426, 79.9125452041626, 58.40951728820801, 78.34373923710415, 87.62072386060441, 86.86609390803746, 58.25255053383963, 27.289948020662578, 6.80255001783371, 0.6922926689897264, 0.25656766125134056, 0.12030515447258949, 0.049006109458527396, 0.024751971908179776, 0.12768809044999735, 0.08427415109638657, 0.011045584039363478, 0.026362445937203507, 0.03770682202386005, 0.028151050675660372, 0.038369442003646066, 0.020196866244077682, 0.04255969769188336, 0.05702371655830315, 0.020150325527148585, 0.01740542576382203, 0.03953728898029242, 0.03215491618695004, 0.013890445581637323, 0.0698997327791793, 0.03610106211687837, 0.08304047943758112, 0.07909000106155872, 0.01851549548363047, 0.037406410822378736, 0.0194663011601993, 0.011754562379792333, 0.00261758899432607, 0.003981533651572785, 0.010543397727555462, 0.03246039265234556, 0.03819192706474236, 0.03522296316389527, 0.0034754453393231544, 0.023565597532849227, 0.03767148731276393, 0.029708268187407936, 0.01735062218670334, 0.07485167455992528, 0.034477290497826676, 0.02142712487173932, 0.012994042298357402, 0.013900986623152025, 0.0602332279086113, 0.021845370464559113, 0.01057754160969385, 0.027840844821184874, 0.04853384230019791, 0.05476348926978452, 0.0496517694555223, 0.02068361164336758, 0.03283772936889103, 0.03309544714699898, 0.016574824262144308, 0.0920372906007937, 0.05393111679170813, 0.03299314442223736, 0.036797306899513514, 0.0701642528708492, 0.0871989695089204, 0.029160425798701387, 0.04791742716250675, 0.02921947870137436, 0.020184515210400735, 0.05148822109081915, 0.023629149122695838, 0.07082406032298293, 0.08895179509584393, 0.02621864740337644, 0.06164027883538178, 0.05022392375394702, 0.03055849631450006, 0.02220043766179255, 0.04734093702531286, 0.023839094642815844, 0.022388771841568605, 0.004055340874141881, 0.038073034158774784, 0.01618337571354849, 0.06035722339791911, 0.06808176104511533, 0.0472315266462309, 0.01636305687549923, 0.027203790344563977, 0.04122237302362919, 0.026709652306245904, 0.04250339285603591, 0.02807006921752223, 0.0543902882241777, 0.02980666933581233, 0.038275583647191525, 0.06916650783802782, 0.045784306446356435, 0.04654019106445568, 0.08397725131362677, 0.03022586487765823, 0.03797638702339359, 0.010905938988019313, 0.024302885202424865, 0.026265513817114488, 0.056479433085769415, 0.058180734116051874, 0.030662916068519865, 0.0254522437961506, 0.020812034573672072, 0.029681062325835228, 5.0289250527109415, 35.31012684958321, 84.55055809020996, 99.1763493674142, 87.54106971195766, 79.45190743037632, 88.51444285256522, 76.8899815423148, 71.0370900290353, 64.45300483703613, 30.453433309282573, 41.8784431048802, 18.624283279691422, 35.35504347937447, 56.26104743140084, 30.341734068734304, 34.19621249607631, 48.53682191031319, 57.519161224365234, 49.495881761823384, 50.04616519383022, 39.75924253463745, 36.29986299787249, 33.050746372767854, 35.170996120997835, 32.7745554787772, 34.564209938049316, 32.638461112976074, 28.38690529550825, 19.383134262902395, 15.17563349860055, 10.62405446597508, 9.884426542690822, 10.81796566077641, 16.56270064626421, 19.393009390149796, 21.301782029015676, 24.706119673592703, 28.51804906981332, 23.398453065327235, 42.23930127280099, 45.21579837799072, 46.61566584450858, 51.182296412331716, 66.43269947596959, 69.0084661756243, 73.30951227460588, 57.160429205213276, 68.80899034227643, 73.74509484427315, 56.69214493887765, 63.45372881208147, 52.95984710965838, 33.03006158556257, 28.385091815676006, 15.630869047982351, 29.17994315283639, 39.68539013181414, 43.35552242824009, 87.48502554212297, 93.87809085845947, 107.23689201899937, 71.47360365731376, 87.11570794241769, 102.41459206172398, 102.54237638201032, 80.04736804962158, 41.484872817993164, 15.356693131583077, 1.7360742943627494, 0.37866754084825516, 0.033155619632452726, 0.041718643358243365, 0.05107486095013363, 0.1241930787052427, 0.08934215629207236, 0.008396657965412098, 0.10666541316147361, 0.007827339943365326, 0.017411164473742247, 0.04447199257888964, 0.010629619172375118, 0.02749561977439693, 0.02206646601137306, 0.03189120015927723, 0.022419672326317856, 0.07684654715870108, 0.03572519103597317, 0.05432746945215123, 0.05744917158569608, 0.09682642468916518, 0.022238157423479215, 0.04655410103233797, 0.050049930411790094, 0.02713940415664443, 0.025307067836235677, 0.014164030901156366, 0.010024226836061903, 0.053538353581513674, 0.019000478388209428, 0.03467849987958159, 0.008202534185589423, 0.11505253346902983, 0.0556408961170486, 0.0178662528217371, 0.01179684528947941, 0.041431775715734274, 0.033587703946977854, 0.013902052771300077, 0.043620217391955, 0.04892112294744168, 0.032735331649226804, 0.06817853370947496, 0.04941904212215117, 0.0615376029163599, 0.07022720056452922, 0.014169567746908536, 0.047301863586263995, 0.0840686024831874, 0.040011741021381955, 0.0432337034892823, 0.01567613346768277, 0.019965558745233074, 0.04472342033737472, 0.1706038290368659, 0.15146630523460253, 0.10065823407577616, 0.11754709961158888, 0.21617365734917776, 0.14564465119370393, 0.06108219735324383, 0.15241222376269953, 0.0911605419324977, 0.10742449707218579, 0.16206454725137778, 0.11352654892419066, 0.1202764795827014, 0.08805960975587368, 0.07725784116025482, 0.16241898680371897, 0.1448195661817278, 0.1229705350207431, 0.12138763495853969, 0.1729337011596986, 0.11283613954271589, 0.10913700410830122, 0.10392160075051443, 0.10919830296188593, 0.1661673906658377, 0.29208953944700106, 0.11246586298303944, 0.12594266768012727, 0.1254135189311845, 0.12327092247349875, 0.12543458065816335, 0.08289557828434876, 0.17845907967005456, 0.1145900304296187, 0.10818451057587351, 0.11769944429397583, 0.11035150715282985, 0.23261822494012968, 0.16307275529418672, 0.0880358067474195, 0.12814882929836, 0.1170387818877186, 0.1950874895389591, 0.12965699551360949, 0.0951986802475793, 0.11132385461990323, 0.08495371748826333, 0.1370986790529319, 0.1853623456720795, 0.09070105837391955, 0.14447147771716118, 0.18127623493117945, 4.861095658370426, 36.41694361822945, 93.43687329973493, 107.5450724193028, 98.40580804007394, 79.43067373548234, 91.73268168313163, 69.71206855773926, 59.49089322771345, 53.79555559158325, 40.52621596200125, 63.3135905947004, 50.97568130493164, 65.95867947169712, 96.980801991054, 79.42780412946428, 48.43998486655099, 81.65377071925572, 77.96314471108573, 71.36402361733573, 73.08134038107735, 62.535489627293174, 52.9805840083531, 48.46471003123692, 45.722850118364605, 47.50566060202462, 47.00407361984253, 48.81288773672921, 38.32697909218924, 28.808916296277726, 22.428006853376115, 17.770054374422344, 15.484505244663783, 17.7250109400068, 24.84209418296814, 29.92126383100237, 34.220642362322124, 38.451563767024446, 42.66120283944266, 32.658836705344065, 62.58226490020752, 62.951429639543804, 67.4717469896589, 74.7847260066441, 97.30217007228306, 94.6634874343872, 101.4698177065168, 80.85421371459961, 99.08920506068638, 117.88373483930314, 86.15938568115234, 111.57150486537388, 96.17670781271798, 84.73292745862688, 84.79245267595563, 35.44888584954398, 31.29258462360927, 34.794942242758616, 39.21416677747454, 79.02361352103097, 82.34460926055908, 102.89590072631836, 76.12763214111328, 94.5884677342006, 111.98276179177421, 114.61048712049211, 87.16456072671073, 41.431020804813926, 14.588535036359515, 1.6363773069211414, 0.768796515251909, 0.21810669505170413, 0.1451283131859132, 0.09837746074689285, 0.19502324584339345, 0.1900483492229666, 0.09113642679793493, 0.20742276763277395, 0.24058096909097262, 0.10150693889175143, 0.10192013279135738, 0.1216966805181333, 0.14392926038375922, 0.17369214046214307, 0.07016617991030216, 0.13998796258653912, 0.19460089850638593, 0.12940673822803156, 0.13867009830261978, 0.22350476682186127, 0.11365565378218889, 0.21114586213869707, 0.18278935445206507, 0.15943768035088265, 0.11444445752671786, 0.12240987510553428, 0.09478142192321164, 0.10907700804195233, 0.30446479682411465, 0.07613207014011485, 0.16028346068092755, 0.08797831447528941, 0.14442068258566515, 0.12953241648418562, 0.14412041726921285, 0.13319391358111585, 0.13147304020822048, 0.22523421687739237, 0.13929014360266073, 0.14266935656113283, 0.12829179662678922, 0.12122127174266747, 0.1643206083348819, 0.09938618447631598, 0.1284792758524418, 0.12450760682778698, 0.13875794144613401, 0.1334409817521061, 0.1176685302385262, 0.17051142613802636, 0.21585703933877604, 0.0679792615451983, 0.10368216609848396, 0.12494600830333573], [0.03577509389391967, 0.07286090709801231, 0.0335490240582398, 0.06118255268250193, 0.04871971679053136, 0.03774814819917083, 0.024162062044654573, 0.07178348848330122, 0.06420261027025324, 0.023942527128383517, 0.03573799838445016, 0.046506640900458605, 0.009778153567042733, 0.014881158447159188, 0.05230199492403439, 0.03157187140147601, 0.02671346397671316, 0.008099088129321379, 0.026487418516938175, 0.08495857579899685, 0.025315018570316688, 0.06809650561107056, 0.03627172724476882, 0.03283308479668839, 0.012694508103387696, 0.08238641239170517, 0.05766981081770999, 0.026326537864016633, 0.03181296846430216, 0.009821286341840667, 0.017157095517697077, 0.037174850569239686, 0.020030285896999494, 0.04002136604062148, 0.01746724878570863, 0.014423216859410917, 0.013987163115026695, 0.025154175236821175, 0.017250970837527087, 0.0602040101907083, 0.04600117980901684, 0.014505136392212339, 0.008963262695553047, 0.025284995092079043, 0.06384179248873677, 0.04633214544238789, 0.06582823089723076, 0.11503690002220017, 0.03576617794377463, 0.05632477459896888, 0.20721516305846827, 16.81393187386649, 62.08978353227888, 92.59322997501918, 70.18651240212577, 76.5963020324707, 64.35084547315324, 50.69565847941807, 51.19235045569283, 43.0004312651498, 44.04993234361921, 26.563750096729823, 58.43558692932129, 31.47172655378069, 69.00783388955253, 84.1520024708339, 48.890638078962056, 45.01248366492135, 33.242652143750874, 25.57360053062439, 15.354924815041677, 6.787574044295719, 4.909970590046473, 4.130690600190844, 2.467808412654059, 1.7764260662453515, 1.352888850229127, 1.3343181610107422, 0.7448564970067569, 0.45794290410620825, 0.05857748032680579, 0.20357404915349825, 0.2445072169814791, 0.12927510243441376, 0.13458260335028172, 0.3042255182351385, 0.26540970536214964, 0.15021754295698234, 0.19014110496001585, 0.3838788526398795, 0.18729262852243014, 0.5254358596035412, 0.34581086678164347, 1.2588803746870585, 3.6284646008695876, 3.6646288888795033, 3.332123279571533, 3.488693335226604, 5.501267501286097, 12.236030459403992, 15.37427728516715, 22.901960849761963, 31.927559648241314, 29.807771955217632, 33.54348829814366, 51.14539105551583, 64.74159131731305, 95.52634252820695, 68.8969475882394, 45.05825144904, 46.974783488682334, 30.50702476501465, 28.66581814629691, 35.12424169267927, 60.17742388589041, 66.28861468178886, 61.34260204860142, 65.93795994349888, 75.39106750488281, 81.58848544529506, 76.94367722102574, 43.58615745816912, 3.8658031225204468, 0.2694196573325566, 0.2315356358885765, 0.021215581401650394, 0.03062612929248384, 0.10588589856134993, 0.02881755187575306, 0.07211735485387699, 0.022774902371955768, 0.01590885910471635, 0.06514232698827982, 0.025021407986059785, 0.027720413337062513, 0.042709993198513985, 0.03244249289855361, 0.04074703210166522, 0.06109915394335985, 0.05708874735449042, 0.04128769898254957, 0.0518608555596854, 0.029580652713775635, 0.03766473249665328, 0.06304092439157621, 0.027798000423769866, 0.024479986234967197, 0.06032877242458718, 0.024350436936531748, 0.06282012909650803, 0.029570793599954674, 0.043226375311080895, 0.021878182721723403, 0.03216140637440341, 0.05496586912444659, 0.036867542059293816, 0.035875754563936164, 0.07632410233574254, 0.048743265348353555, 0.028441826679876873, 0.011455293661648673, 0.01774931070394814, 0.056583673028009276, 0.01615032257645258, 0.04443575880889382, 0.051552132304225645, 0.046307110892874856, 0.017022867720308046, 0.03744465984137995, 0.04691357870719262, 0.040768426310803206, 0.049963373092136214, 0.019204839565125958, 0.07281604914792947, 0.004590771585104189, 0.026499401445367506, 0.02778824817921434, 0.026300310789208328, 0.029238769451954534, 0.03205791960603424, 0.07631717449320213, 0.014411127061716147, 0.054365212962563546, 0.08721705246716738, 0.024316907128585235, 0.006781918495627386, 0.02431128716229328, 0.06053922684597118, 0.026494095301521674, 0.008126740975837623, 0.024173398668478643, 0.03396270311038409, 0.020448699427236403, 0.03669253430728402, 0.06106090492435864, 0.018018975787396942, 0.052637119977069755, 0.06021084303834608, 0.02277922464002456, 0.044577531915690215, 0.04915704618075064, 0.012751294699098383, 0.06180409075958388, 0.008481268737731236, 0.015317351291222232, 0.031211789830454757, 0.028877693827130964, 0.006658448870959026, 0.03060573252982327, 0.006802517970624779, 0.024193383221115385, 0.030207106777067696, 0.03427780120234404, 0.0670012550960694, 0.06006471373672996, 0.0059389697770322, 0.04546124913862773, 0.04820926507402744, 0.03223965842542904, 0.03421589505991765, 0.0500511348114482, 0.06724300355251346, 0.06530584035707371, 0.08597758611930267, 0.11240368881928069, 0.03303900321147271, 1.5160219137157713, 27.41932347842625, 78.63413224901471, 105.04590266091483, 79.20806734902519, 93.11399745941162, 86.13540744781494, 82.31542682647705, 75.90478256770542, 48.344481876918245, 36.39253807067871, 17.433320352009364, 41.21282652446202, 28.97269402231489, 54.09693717956543, 76.79789706638881, 56.88835859298706, 49.90152454376221, 33.686735834394185, 23.59702042170933, 14.94461110660008, 6.817541190556117, 4.3621624537876675, 3.027135793651853, 1.9791641873972756, 1.0861918010881968, 1.0185214493955885, 0.9220222617898668, 0.5873268299869129, 0.16235246323049068, 0.15569158350782736, 0.5844320367489542, 0.3878382673220975, 0.1426987371274403, 0.16871862805315427, 0.2653697260788509, 0.4469797323857035, 0.1836091468908957, 0.16448701226285525, 0.37080673979861395, 0.18569697200187615, 0.41412943654826706, 0.16807096637785435, 0.6522693080561501, 2.7599749522549764, 2.6642889210156033, 2.368961602449417, 2.3668219915458133, 3.3261300240244185, 10.15488430431911, 16.16041384424482, 23.740766491208756, 32.79522289548601, 31.789835929870605, 38.64732926232474, 50.385438782828196, 58.7952812739781, 57.14077622549874, 32.21637889317104, 20.016075202396937, 29.918300424303325, 26.200475692749023, 35.5879853112357, 60.25925976889474, 95.60976954868862, 95.48231179373605, 80.38795484815324, 82.8436358315604, 86.48889705113002, 91.65776620592389, 92.18334184374127, 62.4961211340768, 9.956210119383675, 0.0258899633440056, 0.4213111868926457, 0.05751106755009719, 0.16587051802447864, 0.06628028449735471, 0.02082249758365963, 0.03276296498786126, 0.043237937547798665, 0.009487653217677559, 0.03930412059915917, 0.011793193074741533, 0.04007595757554684, 0.022462199508611645, 0.0142006488916065, 0.02569398546724447, 0.038363192696124315, 0.06825592062835183, 0.029306015664977685, 0.021832826048401848, 0.037315996031143835, 0.0316511446477047, 0.011191358806432357, 0.06360805074551276, 0.06809885334223509, 0.042357239805694134, 0.03836701963362949, 0.02086329789433096, 0.08451712770121438, 0.05680177114637835, 0.018850189666928988, 0.01716325491932886, 0.03688285320198961, 0.027373493649065495, 0.02798114381065326, 0.02839955055553998, 0.09493999555706978, 0.008131826595802392, 0.01757450820878148, 0.01231999324435102, 0.03714705777487584, 0.10191817182515349, 0.046155068158571205, 0.013697238672258598, 0.02227536998023944, 0.022778564764718925, 0.04017982093085136, 0.06675564577536923, 0.06454938237688371, 0.025070002967757837, 0.02206524464833949, 0.06269915987338338, 0.022038344127525176, 0.049508758022316864, 0.09965081313358885, 0.11458648847682135, 0.13191691067601952, 0.10970348585397005, 0.19066600607974188, 0.07513674747731004, 0.1538115936730589, 0.17011742799409799, 0.11805411454822336, 0.09613146912306547, 0.12077069734888417, 0.15926136981163705, 0.19342041042234215, 0.14071267869855675, 0.27565721262778553, 0.13725418570850575, 0.16972032215978416, 0.11678963739957128, 0.0947932895006878, 0.17620550202471869, 0.14820985283170426, 0.1880850081465074, 0.09106336214712688, 0.15482693990426405, 0.13835721223482064, 0.13968087120779923, 0.1603379063308239, 0.07122476917824574, 0.06901155079581908, 0.08980197911815983, 0.0778570757912738, 0.1363669197474207, 0.06161574300910745, 0.125302307041628, 0.09751168398984841, 0.06932793810431447, 0.1426161187035697, 0.15280197427741118, 0.1532259772398642, 0.09626279279057469, 0.13289637597543852, 0.1293254361620971, 0.09763823755617652, 0.07705025015664951, 0.18228410370647907, 0.14077369256743363, 0.15108054450580052, 0.19436508044600487, 0.21543919747429235, 0.12423000458095755, 1.139108955860138, 28.071307693208965, 89.25971358163017, 116.12736919948033, 88.40345232827323, 95.89673709869385, 83.44637121473039, 69.308607510158, 64.75024877275739, 56.29164382389614, 60.63279492514474, 40.72835990360805, 90.90326826913017, 50.40318100793021, 94.75570392608643, 112.24957956586564, 70.64105660574776, 70.58709689549038, 52.79560906546456, 38.37623834609985, 24.22599741390773, 11.989905289241246, 7.505598715373448, 6.536114394664764, 3.853863077504294, 3.3413591725485663, 2.765096426010132, 3.244509752307619, 1.8413731583527155, 0.9548034284796033, 0.3164255235876356, 0.6278413959911892, 0.52689015013831, 0.3593481832316944, 0.1721832278583731, 0.44849880944405285, 0.5526930455650602, 0.30438486539891785, 0.3031184747815132, 0.6652327467288289, 0.340896020510367, 1.6418608469622475, 0.4619311158146177, 2.7672612241336276, 6.4973838329315186, 6.328705889838083, 4.787083012717111, 7.058823466300964, 8.39308169909886, 20.741288219179424, 24.50458369936262, 38.54902267456055, 50.24905606678554, 44.84616116115025, 54.173252718789236, 80.65250056130546, 95.56421715872628, 135.48452241080147, 97.04063987731934, 66.3448464529855, 66.38859925951276, 41.83307831627982, 35.99238436562674, 47.834421566554475, 82.19268689836774, 88.99517481667655, 79.53505652291435, 84.51779038565499, 95.09702723366874, 106.21851539611816, 102.83978707449776, 69.16611385345459, 9.986204624176025, 0.3879906934286867, 0.6110834266458238, 0.13798343443444797, 0.3445985961173262, 0.2106679563543626, 0.1552039339606251, 0.1273878522749458, 0.12240018562546798, 0.1504983886012009, 0.12334299646317959, 0.1529475607510124, 0.14720026057745728, 0.10662518960556813, 0.13748068069773062, 0.15046732526804718, 0.1265947534037488, 0.1466341180992978, 0.19705868805093424, 0.13648206714008534, 0.08746502308973245, 0.12743381623710903, 0.23701855167746544, 0.14218984943415436, 0.11850050916629178, 0.19518179233585084, 0.18363639685724462, 0.13304859852152212, 0.12176162989011832, 0.12514670539115155, 0.12385374334241663, 0.10562630463391542, 0.08424247708171606, 0.28884635918906754, 0.16259408955063137, 0.10443382005074195, 0.21356869355908462, 0.05888799152203968, 0.07545991335064173, 0.13079873924808844, 0.19252779760531016, 0.18327637974705013, 0.11946902291050979, 0.08172573641474758, 0.14880131823675974, 0.08880276166434799, 0.13472607279462473, 0.09841895316328321, 0.13739361108413764, 0.14745984093419143, 0.05985282760645662, 0.2293487446648734, 0.09347129972385508, 0.12476162319736821], [0.043168737153921805, 0.06120944981064115, 0.04111203983692186, 0.024820826249197125, 0.05566992384514638, 0.07423367165029049, 0.011881990408125733, 0.010196910605632832, 0.004087411831798298, 0.025862056895026138, 0.0497917376591691, 0.03334791984941278, 0.03147936672238367, 0.05912046440477882, 0.016799665322261195, 0.04421880741470626, 0.03110554481723479, 0.022186147714299814, 0.025003996777481267, 0.03073741582089237, 0.015790127350815704, 0.03866296946736319, 0.011926173215865024, 0.03724639869428106, 0.037161690382553, 0.05196046110774789, 0.04046926361375621, 0.019302385759406855, 0.02188785863108933, 0.02855016497362937, 0.039300161347325356, 0.05327834574771779, 0.019495712260582616, 0.05378580851746457, 0.048731943991567404, 0.045513492942388566, 0.02382196163359497, 0.05684472580573388, 0.03264919502128448, 0.07624723788883005, 0.06118378761623587, 0.051309834234416485, 0.07520885539374181, 0.014189167230922197, 0.08076541258820466, 0.07826225619230952, 0.05754863124872957, 0.13508575063730988, 0.1994697129619973, 5.461787836892264, 47.34045328412737, 84.62515395028251, 76.10188906533378, 65.07831491742814, 66.38778632027763, 49.280789852142334, 46.48470967156546, 32.04653712681362, 42.663780621119905, 47.149249281202046, 67.16915988922119, 72.10131781441825, 59.28178719111851, 49.254216466631206, 44.55333627973284, 24.81094193458557, 15.83338645526341, 8.400055953434535, 3.85433338369642, 1.258664003440312, 0.16956415053989204, 0.18356983257191523, 0.07045622648937361, 0.05628827620031578, 0.055718011621917994, 0.009318854061088391, 0.021038931594895463, 0.09428901584552866, 0.06282084155827761, 0.10799429006874561, 0.10302347144378082, 0.15926620098096983, 0.14009142560618265, 0.17642325748290333, 0.28529946665678707, 0.3263350932725838, 0.4101464902716023, 0.23579241175736698, 0.20803901313671044, 0.23422659720693315, 0.219730727906738, 0.09493432300431387, 0.15212741547397204, 0.11468307115137577, 0.047466214945805926, 0.0205844250906791, 0.021317258177857314, 0.06244001377906118, 0.07010217370199305, 0.09999198732631547, 0.10780919250100851, 0.3560122065246105, 0.27991534556661335, 2.4553750455379486, 3.708538898399898, 9.455597622053963, 20.45082572528294, 32.15325798307146, 68.55674988882882, 83.85527965000698, 59.699061257498606, 60.28323800223214, 60.60960183824812, 44.5221597126552, 17.044144800731114, 27.125920159476145, 53.26348338808332, 52.614591121673584, 64.37260028294155, 63.10485976082938, 64.22944654737199, 79.18549265180314, 60.25678621019636, 19.556752375194005, 3.3500565801348006, 0.08761867734470538, 0.3195569355572973, 0.07293910825891153, 0.03530596835272653, 0.11038531176745892, 0.07627235046987023, 0.0768793204001018, 0.0199450127048684, 0.046049613638647964, 0.06143711866544826, 0.0187601938710681, 0.02431734648000981, 0.002200609293400443, 0.04157457001773374, 0.053719651353146346, 0.008384588523767889, 0.037312013030584366, 0.02256071600796921, 0.037103309229548485, 0.0539632589955415, 0.000997467787653607, 0.043280240813536305, 0.034198975789227655, 0.054016764874437025, 0.09022818053407328, 0.040579610371163914, 0.04804447266672339, 0.02464640373364091, 0.0376897772241916, 0.02930430575673069, 0.03412175850410547, 0.019863115224455084, 0.027058363326692154, 0.04337026883981057, 0.027750964376277158, 0.04062264984739678, 0.023725087188982537, 0.01584905811718532, 0.050713164465768, 0.02360584823015545, 0.020466244646481106, 0.03385261080360838, 0.007508725343671228, 0.04168930011136191, 0.04717054670410497, 0.0686212574530925, 0.05341439541163189, 0.018427813492183174, 0.0652335085240858, 0.025284939112940004, 0.029662392434797118, 0.035397102391081195, 0.014220306899265518, 0.07717246109885828, 0.0582022097493921, 0.057223714755049775, 0.03897818291027631, 0.02525517687068454, 0.05912632694733994, 0.04978653329557606, 0.031088181106107574, 0.08731796419514076, 0.036716846217002184, 0.08390344705964838, 0.04266549487199102, 0.039710637714181624, 0.06433186440595559, 0.02209545302736972, 0.035289028725985966, 0.03110172805775489, 0.03454867238178849, 0.006507127504197082, 0.051207799530987225, 0.03228101174214056, 0.052311077115259, 0.01896076712624303, 0.017716354258092384, 0.03511012957564422, 0.03374263045511075, 0.025606664795694605, 0.017141619830259254, 0.06450344555612121, 0.05218378733843565, 0.04538469681782382, 0.03554350649937987, 0.011375830425614757, 0.02484970130691571, 0.005075736678138907, 0.0767095305823854, 0.029640655565474714, 0.0340669701940247, 0.0701960761632238, 0.01064796930378569, 0.14245056972971984, 0.007047964867004859, 0.11336384301206895, 0.0286143102816173, 0.051173696360949955, 0.07686664536595345, 0.5862335743648666, 12.077416113444738, 65.55261284964425, 100.61979593549455, 85.15389796665737, 80.1888542175293, 90.00440761021206, 77.5824112210955, 73.65856892721993, 36.17173474175589, 35.07402358736311, 34.3939790725708, 47.072895526885986, 50.44755220413208, 63.93480123792376, 51.25697912488665, 47.14177301951817, 24.71349171229771, 17.558860404150828, 6.782194835799081, 3.14410719701222, 0.8470284002167838, 0.11220058971749884, 0.18522752076387405, 0.049947899101035934, 0.051399872438716035, 0.04158209157841546, 0.07079046605420963, 0.045530066160219054, 0.07183951511979103, 0.06497464062912123, 0.14387205988168716, 0.23337926981704576, 0.3019097867820944, 0.33996384910174776, 0.2132271733134985, 0.340872624622924, 0.40081321394869257, 0.5170202883226531, 0.3908650220504829, 0.268961103366954, 0.387694743594953, 0.21627789389874252, 0.022297865112445185, 0.45043979957699776, 0.12307200314743177, 0.036579215566494634, 0.05595020969797458, 0.10052684934011527, 0.05151758808642626, 0.14313247028206075, 0.24218521586486272, 0.11716114889298167, 0.0980641675580825, 0.04025667180706348, 1.4194899392979485, 2.2255431839397977, 7.788393872124808, 19.54656457901001, 34.34964609146118, 62.98230743408203, 63.43578161512102, 44.098420347486226, 34.940958636147634, 29.868169171469553, 30.027640751429967, 23.58987593650818, 49.74601343699864, 86.8608341217041, 86.41923441205705, 89.9357385635376, 80.20401518685478, 79.66603701455253, 91.55452987125942, 77.66594246455601, 33.77131278174264, 9.179524847439357, 0.05116763025788324, 0.41763805970549583, 0.030540525314531157, 0.06815620990736143, 0.0872843631410173, 0.0879904195400221, 0.08113903432552304, 0.11711427569389343, 0.025632058968767524, 0.05308700905048421, 0.030202428278114115, 0.08302033373287745, 0.018862696763660227, 0.022957492752798965, 0.0694280763023666, 0.026104297289358716, 0.021375088021159172, 0.03443308733403683, 0.06589782144874334, 0.030660788861236403, 0.024975713741566454, 0.05249242238434298, 0.06143545625465257, 0.04757359989785722, 0.004902239514714373, 0.024750136470954334, 0.10482805568192687, 0.044136168634785075, 0.07746384439191648, 0.029881830659828017, 0.007718631848027664, 0.00783376906266702, 0.06703779420682363, 0.01899909078409629, 0.02761192067659327, 0.07918648874121052, 0.006763680746579277, 0.03198720947174089, 0.04380524371351514, 0.020967252851862992, 0.04638178027900202, 0.037141812699181695, 0.023993169589500343, 0.07035051751881838, 0.020640117548672215, 0.02636864435459886, 0.013004069349595478, 0.04054694230269108, 0.023696222309289233, 0.06238845190299409, 0.035633171509419165, 0.09650897208069052, 0.19554114448172705, 0.10016882712287561, 0.13222766614386014, 0.23105547736798013, 0.13782836204128607, 0.1156546383031777, 0.1198405751160213, 0.1687381970030921, 0.14035412722400256, 0.1737440483910697, 0.10060596652328968, 0.10402630548924208, 0.10610573712204184, 0.17246434491659912, 0.14706140517124108, 0.10337376514715807, 0.11257082556507417, 0.1037223625129887, 0.12245335562952928, 0.10967651408697877, 0.10909639378743512, 0.07370500466121094, 0.2161952211920704, 0.11165301195744957, 0.1098714911245874, 0.14804860576987267, 0.07223956579608576, 0.09435627902192728, 0.07178552408835717, 0.11153266698654209, 0.07936366101992981, 0.18260385654866695, 0.15964350716343947, 0.16665470094553061, 0.10466503085834639, 0.11202273211841073, 0.2048725751893861, 0.17731261333184584, 0.1403523087501526, 0.2995006617690836, 0.17756597830780915, 0.23571134039333888, 0.07748798666787998, 0.3076698434140001, 0.1724228457148586, 0.12042372168174811, 0.31618923055274145, 0.4164001132760729, 10.823792593819753, 73.68999562944684, 113.43166269574846, 95.82554585593087, 83.68525723048619, 90.49925136566162, 67.77661309923444, 56.6917210987636, 42.753624303000315, 56.094078745160786, 66.21861158098493, 94.17218031202043, 98.28112261635917, 82.22870635986328, 73.2381751196725, 67.1090440750122, 37.19170250211443, 27.373298610959733, 12.019288352557592, 6.026598215103149, 2.3911163679191043, 0.43222876105989727, 0.550516413790839, 0.11093713037137475, 0.16183624735900334, 0.17201377052281583, 0.19786660612693854, 0.18398653449756758, 0.20086343746100152, 0.1749247128942183, 0.3280536596264158, 0.40723345801234245, 0.45229760131665636, 0.7626150612320218, 0.7235880611198289, 0.6949777134827205, 0.750447082732405, 1.156209449682917, 0.5841034086687225, 0.8432617166212627, 0.8014618967260633, 0.542277098766395, 0.24816020524927548, 0.7934910101549966, 0.455760301223823, 0.16401063996766294, 0.13801893538662366, 0.25733522006443565, 0.20187365396746568, 0.26573692208954264, 0.41650639900139397, 0.6345035242182868, 0.822084150144032, 0.6713034638336727, 4.662110975810459, 6.478491246700287, 16.226701395852224, 31.41349717548915, 52.598412241254536, 100.015184538705, 120.94391604832241, 87.15059484754289, 89.42701925550188, 87.09245926993233, 61.16718087877546, 23.939125401633127, 37.894707339150564, 73.41871016366142, 74.18048286437988, 82.82566779000419, 81.2223014831543, 83.7452757699149, 100.06956808907645, 88.59579930986676, 35.959804262433735, 8.054367440087454, 0.1740189500685249, 0.5294734143785068, 0.13780662177928857, 0.1521066523024014, 0.17823618091642857, 0.22557523500706467, 0.16613620519638062, 0.17665534360068186, 0.11268182032342468, 0.16952005933438027, 0.10869001237941639, 0.22810442000627518, 0.0882053862192801, 0.16092737684292452, 0.14820765437824385, 0.08999453378575188, 0.07864395249634981, 0.1105461652789797, 0.11615465075841971, 0.1850072547261204, 0.10037392111761229, 0.15392011856394155, 0.0968267707420247, 0.15031979818429264, 0.1674390331442867, 0.05526782738577042, 0.1683966089040041, 0.20657929432179245, 0.09481184743344784, 0.06597061468554394, 0.1271577610501221, 0.11454048380255699, 0.14931723555283888, 0.11533506188009467, 0.12163802795112133, 0.126404682174325, 0.08121667230235678, 0.12006989281092371, 0.1885160950145551, 0.15401048585772514, 0.09810724096106631, 0.11278981595699276, 0.12448619226259844, 0.12494758250457899, 0.14386473170348577, 0.12004003727010318, 0.07474335322954825, 0.10046136392546551, 0.10113253005381141, 0.1380830705165863, 0.16668049884693964], [0.01944826400306608, 0.05680724692397884, 0.05554132449573704, 0.020321277336084416, 0.007398641518583255, 0.021150372490020733, 0.044705920919243775, 0.05294772616720625, 0.04061349301732012, 0.04219067642199142, 0.06311641141240086, 0.08950427866407804, 0.01467124855012766, 0.05742539571864264, 0.01079444635459887, 0.04486980748229793, 0.06887175222592694, 0.049672305317861695, 0.022195168837372745, 0.027878506907394955, 0.0880013643098729, 0.026152354532054493, 0.009943701692723801, 0.055073576380631754, 0.02511849786554064, 0.03157168480434588, 0.009322071165245558, 0.09562492916094405, 0.08007220085710287, 0.0418969487904438, 0.056162580980786254, 0.03142831035490547, 0.013830900741075831, 0.049898254086396525, 0.011488308631149786, 0.05009411661220448, 0.02638402165445898, 0.028972702300442115, 0.05559262513582196, 0.07308913913688489, 0.0635916641248124, 0.04936603496649435, 0.08466528582253627, 0.04931843912761126, 0.16794895221080097, 0.009360427901680981, 0.20297915036124842, 6.483386252607618, 34.224484716142925, 79.1955258505685, 84.92485754830497, 58.1361334664481, 64.21090875353131, 51.632543155125205, 38.04108851296561, 38.87688384737287, 29.000382593699864, 57.16152007239205, 70.57805034092495, 67.86813477107457, 47.72101654325213, 40.83906555175781, 18.610902786254883, 8.688908202307564, 2.5313060453959872, 0.6843552206243787, 0.29718479460903574, 0.0507859068124422, 0.04059869756123849, 0.036403756588697433, 0.04232276344139661, 0.04117289085739425, 0.12324606095041547, 0.14987006517393248, 0.0218595348830734, 0.01304190106956022, 0.05344552659828748, 0.06980770307460002, 0.07511704960571867, 0.04534637315997055, 0.15461652619498117, 0.26749820900814875, 0.14613878753568443, 0.1029924148959773, 0.08776936640164681, 0.18048884932483944, 0.1276893796665328, 0.05587439698034099, 0.10687946381845645, 0.07585240514682871, 0.08925320035112755, 0.10055556494210448, 0.13054449217660086, 0.056927351014954705, 0.22962759541613714, 0.0465646285031523, 0.06543279425906283, 0.06582939797746283, 0.0443934453651309, 0.1773105234439884, 0.108422126754054, 0.08908882524285998, 0.05604284329872046, 0.27651748646582874, 0.15784025963928017, 0.10634112092001097, 0.20881835131772927, 2.8252780309745242, 7.695786544254847, 22.90467585836138, 41.46884332384382, 46.84936155591692, 45.626329217638286, 76.08820806230817, 66.11568096705845, 37.77909973689488, 18.905549832752772, 18.906308923448833, 27.430133138384136, 43.43737915584019, 53.784212657383506, 63.15374033791678, 65.8989041192191, 75.3255181993757, 70.03623676300049, 31.324952806745255, 4.606371658188956, 0.38727711886167526, 0.03149291706670608, 0.053629497797893624, 0.05415062287024089, 0.013233030813613107, 0.03731499179931624, 0.019177752447181513, 0.028856191052389995, 0.08918453939259052, 0.03557314830166953, 0.05017714894243649, 0.04188984452879854, 0.008477258595771022, 0.04646614932322076, 0.0381628382684929, 0.059365042352250645, 0.024318998712780218, 0.045196138721491606, 0.056383535731583834, 0.04442831188706415, 0.0800162556448153, 0.015941301560295478, 0.02787864431073623, 0.006907754511173282, 0.03294162325827139, 0.03841262057955776, 0.054704867236848385, 0.07423141891402857, 0.023552128612729054, 0.03834326072995152, 0.025527123528133546, 0.039273257433835945, 0.06357408328247921, 0.06826279418809073, 0.017289615103176663, 0.01581943327827113, 0.036853374248104434, 0.020847883275044814, 0.032774225276495726, 0.10478036145546607, 0.056076953254107914, 0.043125473761132786, 0.0374826374463737, 0.039284388800816875, 0.0329619996648814, 0.01134326244105718, 0.03919088328257203, 0.008784595943455185, 0.032156853404428275, 0.07962959924978869, 0.026701816923118064, 0.0120426445999848, 0.007684732238495988, 0.01496696428927992, 0.03124205249228648, 0.019894449971616268, 0.049867085580314906, 0.07434846620474543, 0.02072930079884827, 0.04737172894445913, 0.027647482696920633, 0.06588507177574293, 0.062110096482293944, 0.026134980642901998, 0.03972514818555542, 0.02186960434275014, 0.057226910654987605, 0.047954624452229054, 0.022118950695065514, 0.029629802397851433, 0.05282154579513839, 0.05353277263098529, 0.028300569259694645, 0.021454261183472614, 0.0610079113394022, 0.0339270528805043, 0.06902398155736071, 0.02423366784517254, 0.025863663326682787, 0.10508004323180233, 0.05775241567088025, 0.0371129919242646, 0.02889015173007335, 0.029051768593490124, 0.06860003287770919, 0.03098679779629622, 0.07627443357237748, 0.01894732195484851, 0.07435925491154194, 0.016218276162232672, 0.0796493242627808, 0.04155200533568859, 0.05832049197384289, 0.11469542048871517, 0.05551849179235952, 0.43849223639283863, 12.011284027780805, 49.256384304591585, 97.05010332380022, 94.77964047023228, 68.61715752737862, 86.85371221814836, 76.71002319880894, 63.00023378644671, 43.92637252807617, 17.901922498430523, 30.263521671295166, 52.69968223571777, 60.33075673239571, 48.23273747307913, 44.9630263873509, 20.158728667667933, 10.03400388785771, 2.0427844992705753, 0.6111415635262216, 0.16101125734192984, 0.07985988724976778, 0.07095929913754974, 0.022861001680472066, 0.05847314199698823, 0.15896774056766713, 0.06580532355500118, 0.17186332573848112, 0.014303840497242553, 0.0750089996893491, 0.12696678058377334, 0.16958544296877726, 0.13902653274791582, 0.10282373109034129, 0.21077758047197545, 0.47311945259571075, 0.4231637774833611, 0.07776259657527719, 0.2517410788152899, 0.2653809626187597, 0.3828071744314262, 0.18463404689516338, 0.15920596064201423, 0.2719179689884186, 0.07521040245358433, 0.10020812108580555, 0.17284337457801613, 0.09039349880601678, 0.2574701671089445, 0.20036115869879723, 0.08589007545794759, 0.09650904671954257, 0.04778838337266019, 0.08434480694787842, 0.11242172428007637, 0.03744044274623905, 0.12269929743238858, 0.16417511685618333, 0.12966394371220044, 0.16708447145564215, 0.1757800741387265, 1.1902057911668504, 6.3666591218539645, 20.346472467694962, 39.88876390457153, 48.37983431134905, 48.380737577165874, 58.909370694841655, 33.8397490637643, 20.563935450145177, 23.67193763596671, 33.790726048605784, 51.88580846786499, 73.62586375645229, 73.15954235621861, 78.75223772866386, 74.74505874088833, 86.97226933070591, 87.78126198904855, 49.118455614362446, 9.873390197753906, 0.11940103370164122, 0.12862818714763435, 0.022750844912869588, 0.0811665624912296, 0.05339448040883456, 0.01704499644360372, 0.03161091769912413, 0.023380649242816225, 0.05603731663099357, 0.07993983903101512, 0.015346387501007744, 0.03135209051626069, 0.032211892772465944, 0.06817892725978579, 0.05614305613562465, 0.030062351508864334, 0.02300518867559731, 0.009633429681083985, 0.054866653734019825, 0.015838885180918232, 0.04733888106420636, 0.01637488374087427, 0.04470366818298187, 0.01851735127690647, 0.023551134558926736, 0.02668015469264771, 0.02361542235926858, 0.07012212263154131, 0.06226877189640488, 0.007677295494691602, 0.030391763297042677, 0.05653754621744156, 0.02017648983746767, 0.01826053255769823, 0.012617786996997893, 0.027050427859649062, 0.019311810610815883, 0.04449391604534217, 0.037530555589390655, 0.05564400380743401, 0.026452370486887436, 0.032474207625325234, 0.03086643246933818, 0.037584936778460226, 0.024421861228932227, 0.043375683549259386, 0.051175494478749375, 0.05351151412885104, 0.03305374438475285, 0.1560230885765382, 0.14968688786029816, 0.09753682371228933, 0.08610424825123378, 0.06138720562947648, 0.11110972932406835, 0.18419644609093666, 0.1357786434569529, 0.15378390944429807, 0.14835921196000917, 0.14891733415424824, 0.2096355381820883, 0.133828303111451, 0.12823459612471716, 0.09509894917053835, 0.1221104511725051, 0.16457849235406943, 0.11721725016832352, 0.13657407648861408, 0.08150015744779791, 0.228984072804451, 0.1124313459066408, 0.09200128753270422, 0.1363197344222239, 0.10872029539729867, 0.1024147712492517, 0.13026148879102298, 0.1710726288812501, 0.18697092149938854, 0.12892834389848368, 0.14002088510564395, 0.13278572048459733, 0.1302197588873761, 0.15484961654458726, 0.12577401101589203, 0.2179292988564287, 0.09920207078435592, 0.20109882125897066, 0.14980949913816793, 0.1577444640653474, 0.1920247995959861, 0.14995125867426395, 0.19223894524787152, 0.1618707983621529, 0.2775067633816174, 0.14649349850203308, 0.5913320864949907, 11.63972910812923, 52.95929472787039, 108.8892570223127, 105.47181333814348, 72.53029959542411, 85.06168842315674, 72.20907047816685, 49.337146690913606, 50.94171503611973, 42.040707860674175, 79.83071626935686, 93.54095036642892, 91.98005144936698, 66.88334574018205, 60.73008360181536, 32.48675414494106, 16.357466493334087, 5.490314534732273, 1.883873769215175, 0.6180018782615662, 0.408298595143216, 0.09026249404996634, 0.06268782833857195, 0.28824903124145096, 0.3106935311641012, 0.37213845976761406, 0.43312410158770426, 0.28567331231066156, 0.273543223206486, 0.4288408357117857, 0.5135534086397716, 0.339119235851935, 0.34518243478877203, 0.4326981173029968, 0.7222603580781392, 0.48368701125894276, 0.26245737235460964, 0.20882121473550797, 0.35810681698577745, 0.4525572088147913, 0.3535080866089889, 0.3148814764406, 0.2256924994289875, 0.19729764094310148, 0.3238091788121632, 0.35712413543037, 0.3708894396466868, 0.7566575237682888, 0.6328772114855903, 0.1960151419043541, 0.42870246885078295, 0.2827663868665695, 0.4428348605121885, 0.26103285593645914, 0.22700262841369423, 0.34348395307149204, 0.5226123939667429, 0.34198658913373947, 0.4236154375331742, 1.3238109648227692, 4.793280805860247, 11.481559446879796, 36.28628969192505, 64.48181206839425, 71.35679054260254, 70.66279057094029, 109.33398342132568, 95.44267926897321, 53.26856599535261, 27.935753549848283, 27.115798371178762, 37.31904213769095, 60.68521213531494, 73.07929066249302, 79.4735302243914, 84.49620928083147, 98.3495762688773, 97.81669807434082, 52.486282212393625, 9.060154795646667, 0.3616388088890484, 0.290488061095987, 0.1076474976060646, 0.19150095699088915, 0.20033297235412256, 0.22831810425434793, 0.08983819931745529, 0.15366774424910545, 0.15880806770707878, 0.14006622481559003, 0.17583247061286653, 0.13066478286470684, 0.166167146393231, 0.17762587937925542, 0.09318524293069329, 0.19221758496548447, 0.1342436479670661, 0.09175446363432066, 0.17715606173234327, 0.15987344911055906, 0.138210227979081, 0.08949327961142574, 0.1244937511427062, 0.08449983184358903, 0.14243053937596933, 0.1345510243305138, 0.11296276096254587, 0.18196721428206988, 0.12660236656665802, 0.12311110033520631, 0.10150117812944309, 0.139674750821931, 0.1636720917054585, 0.09065488406590053, 0.15081951208412647, 0.08733872736671142, 0.1697328614869288, 0.09427845105528831, 0.11308144352265767, 0.17103324670876774, 0.14569300359913281, 0.08730377602790083, 0.09283073552485023, 0.16924015006848744, 0.19006182492843696, 0.10230070951261691, 0.11548830222870622, 0.11793698583330427, 0.08030074502208404], [0.02735773297691984, 0.04828946791323168, 0.01410341143075909, 0.03180029682282891, 0.05775964206882885, 0.017070597569857324, 0.050324659062815566, 0.0470767494158021, 0.010078328129436289, 0.027215625691626753, 0.03820359447438802, 0.07812123625938382, 0.047726826675768406, 0.021640534313129525, 0.039385171607136726, 0.037060225648539405, 0.05213537047217999, 0.08627259957471065, 0.07628858781286649, 0.04647878703794309, 0.08173226392162697, 0.020491799971620952, 0.012447617199671055, 0.029125732303197895, 0.0744200652199132, 0.033187252935022116, 0.06906292946743113, 0.060624511912465096, 0.015919366219480122, 0.01239572199327605, 0.09426167088427714, 0.0643914465659431, 0.025649309025279114, 0.04248064496953573, 0.05683980642684868, 0.010221014714001544, 0.03390201833099127, 0.03737898782960006, 0.020095440525827662, 0.06731242447027139, 0.031317916100046465, 0.029262572460408722, 0.1958559847303799, 0.01683030796370336, 0.164390144603593, 1.3353602822337831, 27.205247742789133, 79.016359601702, 90.54927144731793, 63.9282351902553, 60.83826010567801, 65.37483624049595, 43.31615046092442, 28.704813173839025, 36.97610337393624, 44.26182460784912, 65.03683417184013, 57.55357565198626, 37.56859711238316, 28.993022714342388, 16.05503920146397, 2.8897462402071272, 0.8038735730307442, 0.07383683722998415, 0.06861561204173736, 0.035827212168702056, 0.03433920183618154, 0.047406368157161136, 0.13215225376188755, 0.10072023860578026, 0.09292879062039511, 0.0695978118372815, 0.050890129791306596, 0.06738689368856804, 0.09813223819115333, 0.05388386361300945, 0.04805692717699068, 0.1290587583290679, 0.12290108017623425, 0.05981519605432238, 0.05560072684394462, 0.16181751979248865, 0.20891701030944074, 0.08180106737251792, 0.08856312345181193, 0.16138692146965436, 0.05528523859434894, 0.42533850935953005, 0.4583359658718109, 0.030432590749114752, 0.057463549742741246, 0.08585775683500937, 0.131212319912655, 0.08397254228059735, 0.021715641354343722, 0.019757097520466362, 0.07277117762714624, 0.05094975944874542, 0.056632853246160915, 0.10622931191963808, 0.03707503467532141, 0.15129578938441618, 0.02481193235144019, 0.13667409255036286, 0.11892833906624999, 0.19852000820849622, 0.06249249167740345, 0.045228331815451384, 0.08270638236509902, 0.3953241913446358, 4.436613270214625, 18.426492384501866, 31.751791068485804, 41.050412382398335, 55.28525979178292, 81.50972761426652, 67.34629726409912, 54.12840904508318, 25.594219309943064, 23.30188873835972, 45.163311685834614, 52.477826254708425, 69.99744497026715, 58.94234684535435, 68.80368886675153, 82.38572869982038, 68.50075435638428, 21.109810250146047, 1.3619218340941837, 0.21565776717449936, 0.035656523292085955, 0.06630256080201694, 0.07340114310915981, 0.08593813609331846, 0.09659395859177623, 0.03619067623679127, 0.03139403076576335, 0.02005726784201605, 0.04574980294065816, 0.061741502689463754, 0.016317756181316714, 0.016324030933901668, 0.03654747709099736, 0.030225505254098346, 0.027137867274827192, 0.08273205813020468, 0.09638725646904536, 0.0453887748132859, 0.050903395150921175, 0.04356361400069935, 0.049171553259449344, 0.08356683262224708, 0.0628151757908719, 0.02721695222758821, 0.039016496390104294, 0.033943527710757086, 0.045365684266601286, 0.02319252540889595, 0.11004342511296272, 0.05791472124734095, 0.012481463374570012, 0.047739399929663966, 0.031570951986525736, 0.046144367661327124, 0.030247537286153862, 0.05412445855992181, 0.07702175847121648, 0.04250302644712584, 0.038660207829837284, 0.05531888036057353, 0.06783801091036626, 0.03185062037248697, 0.0184125396689134, 0.04172724039692964, 0.07619691094649689, 0.04778995078855327, 0.07588952101234879, 0.05475433922505804, 0.012718295844803964, 0.01159499299579433, 0.025629122608474324, 0.028411338405151452, 0.07158649619668722, 0.06538585320647274, 0.050420831223683696, 0.034257363727582354, 0.14077878158007348, 0.048947361896612814, 0.05187622098518269, 0.023867749176653366, 0.030848376652491943, 0.0465126696840993, 0.020933550017486726, 0.015018970605784228, 0.010023427861077445, 0.039817198246185265, 0.063051577391369, 0.05862626020929643, 0.027995094490636672, 0.04620589043146797, 0.0326639429799148, 0.05795195246381419, 0.059655645330037387, 0.02957352131072964, 0.029906037396618297, 0.05097832577303052, 0.0275530679417508, 0.049022770885910304, 0.04790141712874174, 0.03818295343912073, 0.025923661089369228, 0.031595080691788874, 0.06469059229961463, 0.03890546431232776, 0.03378576153357114, 0.07408818695694208, 0.0515274064881461, 0.004865728817614061, 0.1144617058868919, 0.12892212851771287, 0.0991828003898263, 3.839763011251177, 43.86382137026106, 96.62036418914795, 104.5823883329119, 71.27310643877301, 83.82114315032959, 91.2378101348877, 66.86910888126918, 44.07135016577584, 31.42614984512329, 31.85823052270072, 40.89315380368914, 52.186182567051475, 38.364072050367085, 31.835864271436417, 16.659914629799978, 3.0048299048628127, 0.4153998983757836, 0.12899117624121054, 0.10252636990376882, 0.08221388129251343, 0.11651392148009368, 0.14373074817870343, 0.07540179682629448, 0.21198967471718788, 0.07402202300727367, 0.16060170717537403, 0.033993433961378675, 0.056923306946243556, 0.34242568271500723, 0.26097526188407627, 0.2890140659042767, 0.20247696659394673, 0.4171735346317291, 0.5813111013599804, 0.4875202455690929, 0.9351769387722015, 1.0491534514086587, 0.6903674751520157, 0.8749644468937601, 1.1807729601860046, 1.041789555123874, 0.7204568662813732, 1.5976257920265198, 0.7562372120363372, 0.7457531403217996, 0.17834181524813175, 0.6504441574215889, 0.4062537077282156, 0.13049814823482717, 0.2099488042294979, 0.3063047123806817, 0.19637591897376946, 0.17738423948841436, 0.4184581371290343, 0.22138473843889578, 0.07347255213452236, 0.06989574977861983, 0.28963606538517134, 0.3201023962880884, 0.13938749980713638, 0.08238107910645859, 0.059144233486482074, 0.04677180220772113, 0.1621730721422604, 3.186098635196686, 16.06427162034171, 31.433063302721294, 42.763852051326204, 59.37074497767857, 61.877724511282786, 37.77638646534511, 32.10706288473946, 20.749096257346018, 32.57372127260481, 72.9117487498692, 75.47786440168107, 83.34678268432617, 73.67948995317731, 79.36137935093471, 93.24950122833252, 85.60022939954484, 37.860209533146445, 3.116173050233296, 0.3234802521765232, 0.06039194403482335, 0.060534416032688956, 0.08527190291455813, 0.056946431419679096, 0.02513093371609492, 0.008780255015673382, 0.028136396015595113, 0.03374476105506931, 0.017920386345524873, 0.11052062522087779, 0.061784080761883936, 0.010516312305948563, 0.012278773938305676, 0.03572655828403575, 0.030181519221514463, 0.05404073751664587, 0.12423176877200603, 0.03324779522206102, 0.04265387835247176, 0.030110846406647136, 0.06602398825011083, 0.04198624060622283, 0.021762724899287735, 0.008099014338638102, 0.06207506371928113, 0.003001831501023844, 0.020812706323340535, 0.022583195873137032, 0.004108006217783051, 0.09873967631054775, 0.017490612442738245, 0.030212518093841415, 0.07232678468738284, 0.053196215869060585, 0.04787289830190795, 0.06870348232665233, 0.010925040596963038, 0.013528680395601051, 0.05466906094391431, 0.03056572610512376, 0.024570377277476445, 0.09267896759722914, 0.015050454630649515, 0.012843349848740866, 0.06397778447717428, 0.0226465422061405, 0.12498927169612475, 0.20015662110277585, 0.17431450635194778, 0.10562521897788558, 0.16372386392738136, 0.11931439835046019, 0.1713401209563017, 0.1901404128542968, 0.1034551350665944, 0.0870495153857129, 0.26712859741279055, 0.17148030629115446, 0.15086255834570952, 0.07511622179299593, 0.13935904204845428, 0.1484630685299635, 0.14633166790008545, 0.10656944116843597, 0.16279235748308046, 0.1508818423109395, 0.13519738321857794, 0.15096048451960087, 0.11352487294269459, 0.10585561554346766, 0.12924302129873208, 0.1763078115348305, 0.2136751421328102, 0.10709787745560918, 0.21385142553065503, 0.11195237482232706, 0.1399609161806958, 0.17768962095890725, 0.13849120933030332, 0.12086856923997402, 0.176393809063094, 0.13105454695011887, 0.14416898680584772, 0.1132469924965075, 0.1595953040357147, 0.25366711403642384, 0.20091919946883405, 0.17770997700946672, 0.2872580715588161, 0.18443849310278893, 0.28661254048347473, 3.5780421750886098, 48.62885774884905, 105.82938153403146, 116.37444714137486, 79.17732851845878, 79.60045296805245, 87.6123651776995, 55.56518881661551, 38.66465112141201, 53.40234661102295, 64.69952692304338, 90.65204920087541, 82.14787796565464, 57.61466073989868, 45.24432420730591, 26.596012319837296, 5.900354223591941, 1.4105501047202518, 0.49352967739105225, 0.18511291619922432, 0.20615953898855618, 0.20507868698665074, 0.25810801716787474, 0.3456341491213867, 0.46541960005249294, 0.24292256629892758, 0.2520691097847053, 0.30538738731827053, 0.21117693904255116, 0.3777251642729555, 0.3431320105280195, 0.24477572685905866, 0.34597222240907805, 0.41051091785941807, 0.47353363037109375, 0.23811813124588557, 0.5259739107319287, 0.5153542405792645, 0.33753955204571995, 0.3311493263712951, 0.3798291656587805, 0.3459199752126421, 0.9138507459844861, 1.4392638610942023, 0.2876124025455543, 0.3740412619497095, 0.1542447568582637, 0.5161632171698979, 0.33124223138604847, 0.13235073882554257, 0.22666686214506626, 0.5726193934679031, 0.29133104586175507, 0.3891579365091664, 0.3630185148545674, 0.4280644016606467, 0.31715538299509455, 0.1765596837337528, 0.7666856199502945, 0.5706332943269184, 0.6744005690727914, 0.2355499304831028, 0.17031348390238626, 0.3432710016412394, 1.3695798345974513, 9.041619607380458, 31.449877943311417, 49.23472329548427, 61.37827410016741, 81.96388271876744, 114.38804054260254, 92.07761110578264, 73.52626132965088, 38.62577247619629, 32.91909190586635, 59.21238163539341, 68.14736202784947, 87.79176766531808, 76.77665642329625, 87.83231040409633, 103.17414828709194, 96.28938674926758, 40.1398092678615, 2.6568862668105533, 0.5306643790432385, 0.17261584821556294, 0.11487319666360106, 0.14827146381139755, 0.16958099177905492, 0.15789865436298506, 0.20141204659427914, 0.13396520433681353, 0.11897008254059724, 0.1360757060881172, 0.1885609326085874, 0.15299778591309274, 0.14922327202345642, 0.11577372119895049, 0.1254575422831944, 0.13443719329578535, 0.20886736868747643, 0.29702113196253777, 0.129524898316179, 0.11265758983790874, 0.11550093655075346, 0.16433568538299628, 0.19262011907994747, 0.16685987636446953, 0.12887199835053512, 0.14839807844587735, 0.09963492184345211, 0.0935555330610701, 0.08862930775753089, 0.2366560511291027, 0.16770843868809088, 0.11252585904938833, 0.17040290124714375, 0.1541688423603773, 0.2748827870403017, 0.08515264359968049, 0.12575668123151573, 0.1564167881650584, 0.11013916640409402, 0.11839169929070131, 0.14722639774637564, 0.12589757224278791, 0.16293182357081346, 0.0863146891019174, 0.15954387108130114, 0.1716962568461895, 0.07071341161749192], [0.06755042062806231, 0.0528142108315868, 0.020098305639943907, 0.04240943950467876, 0.05241658591798373, 0.05205993094880666, 0.04214989646737065, 0.03545112395659089, 0.01219889594774161, 0.014537529654002615, 0.043900940899870226, 0.004041688325482288, 0.06785439753106662, 0.04522309013243232, 0.06551275282566037, 0.015213873004540801, 0.04558138037100434, 0.035928663332015276, 0.046267409808933735, 0.013077119581534393, 0.060848401327218325, 0.03629057355491178, 0.006004517956171185, 0.0540903248558087, 0.0578427558232631, 0.03476302159417953, 0.027806860394775867, 0.05476429333378162, 0.05105457614575114, 0.028007620247080922, 0.03650655125134757, 0.06374705542943307, 0.06332640442997217, 0.043822644744068384, 0.014743427712736385, 0.04717673494347504, 0.05907038173505238, 0.06362390132354838, 0.004980417350972337, 0.06225634792021342, 0.08058006396251065, 0.011533599995475794, 0.2110831926443747, 0.8414804264903069, 19.08204276221139, 68.1012190410069, 86.28547464098249, 81.37550231388637, 56.24390275137765, 73.58438995906285, 42.04571403775896, 35.629702295575825, 34.73754664829799, 47.96679517201015, 66.45129285539899, 40.520379475184846, 40.26561335154942, 24.203559943607875, 9.439845187323433, 0.8897769749164581, 0.2989813382072108, 0.054496560378798416, 0.004546969605144113, 0.020803719127018536, 0.1105255378144128, 0.014894898781286818, 0.030335098837635348, 0.106826979134764, 0.04853810350011502, 0.032527509943715165, 0.1969194933772087, 0.18003143529806817, 0.18046633553292069, 0.08536875021776982, 0.027079774499205605, 0.07307714942310538, 0.019760028791746924, 0.14161153403776033, 0.09200664117400136, 0.280433502048254, 0.038459297003490586, 0.7149483018687793, 0.4703106975981167, 0.10794709795819861, 0.4835946762136051, 0.6850194249834333, 0.35213223472237587, 0.25427011453679627, 0.19159273563751153, 0.6019000251378331, 0.3135853388479778, 0.11540277967495577, 0.1459252525653158, 0.016014966714595045, 0.20682856094624313, 0.05854764514203582, 0.10619744112981216, 0.17543782107532024, 0.1507701961589711, 0.029699101179305996, 0.12906588294676372, 0.056870041947279654, 0.07540722510644368, 0.08034090750983783, 0.03920503073771085, 0.10230077058076859, 0.04237271718946951, 0.10437807161360979, 0.03959289153239556, 0.016937840497121215, 0.13630871501352104, 0.31398993570889744, 3.314389956848962, 19.480193649019512, 43.89405645642962, 55.746894632067, 44.82892268044608, 63.4403326851981, 68.93646199362618, 44.46250595365252, 18.822350365774973, 24.539126668657573, 44.763512338910786, 44.166505745479036, 54.21433046885899, 59.660470962524414, 72.69868918827602, 78.68107427869523, 52.36618259974888, 3.265898261751447, 0.05181514944082924, 0.06254159725670304, 0.14816536807588168, 0.05687034050268786, 0.02729809483779328, 0.010371367896108754, 0.0055521980310524145, 0.022603370415578996, 0.055580537034464736, 0.046484734397381544, 0.08289631788751908, 0.03995557189253824, 0.012069963268004358, 0.06310784830046551, 0.00630155811086297, 0.04399932508489915, 0.024635742252160395, 0.012551009821306382, 0.052581524210316796, 0.025013972938592945, 0.02280508360958525, 0.032753926901412864, 0.03692284944866385, 0.027787452596904974, 0.04387778249968376, 0.00953307859266975, 0.005246893319833491, 0.01554026361554861, 0.029590773063578775, 0.02918681063290153, 0.0399257706345192, 0.048328256367572715, 0.01798175135627389, 0.02235337606232081, 0.06506754564387457, 0.04094191414437123, 0.029997890682092736, 0.01881234607260142, 0.030428777382309948, 0.02916886338165828, 0.02596027823165059, 0.04244403461260455, 0.05227344556312476, 0.050687302103532214, 0.00420569914526173, 0.030091996703829085, 0.06506510291780744, 0.029089657988931452, 0.011192270587863666, 0.016870156629011035, 0.03855101458196129, 0.029904296954295466, 0.06221286061086825, 0.042603303744856796, 0.06110682138907058, 0.032605449868632216, 0.024681884329766035, 0.010872715368999966, 0.021619380983923162, 0.06329389581722872, 0.01330500896022256, 0.023749151433418905, 0.034342275599816015, 0.005633169311165277, 0.033675553875842264, 0.01939904476915087, 0.05871350624199424, 0.012025370794747556, 0.05791632937533515, 0.043476948115442476, 0.022927937463724186, 0.02356696647724935, 0.02113974154261606, 0.017859363994960274, 0.03553614439442754, 0.018695144415167824, 0.04694002800221954, 0.043654934636184146, 0.07478039445621626, 0.10521050515983786, 0.03530267406521099, 0.056050520922456465, 0.025318073674238155, 0.056476030232650895, 0.09102758978094373, 0.014014672621020248, 0.13637123523013933, 0.03283516111384545, 0.12810207823557512, 3.9483468532562256, 32.34419795445034, 87.86305618286133, 103.03998552049909, 89.91734668186733, 69.60332230159214, 100.74133382524762, 68.11698450360979, 53.944990498679026, 33.22069583620344, 26.864108562469482, 44.754041944231304, 32.92676271711077, 47.14921106610979, 27.425578594207764, 9.349897282464163, 0.7300390292491231, 0.1633365289973361, 0.036012842386428795, 0.018202105603579963, 0.17706618298377308, 0.1446793537054743, 0.18009557042803082, 0.09260635756488357, 0.18112029401319368, 0.17486942586089882, 0.0658731906275664, 0.44861416039722307, 0.41560275320495876, 1.0569358680929457, 0.9835708162614277, 0.5965488808495658, 0.7770227481211934, 0.6363640129566193, 2.203235775232315, 2.294803044625691, 1.3979398842368806, 2.1585058782781874, 4.072604094232831, 2.9791595680373053, 2.2339683089937483, 3.713294506072998, 4.220232903957367, 3.279675671032497, 3.3088746070861816, 3.3772546521254947, 2.682350763252803, 1.8830037244728632, 1.493425829069955, 1.8402360422270638, 0.9508254762206758, 1.8667358202593667, 1.026833014828818, 1.0428999641111918, 1.2294025335993086, 1.3340525009802409, 0.8873953712838036, 0.32308762467333246, 0.8193564936518669, 0.907131946512631, 0.23739717421787127, 0.29052345348255976, 0.1724129526742867, 0.13845395775777952, 0.17304827858294758, 0.04070690354066236, 0.007768305700405368, 0.12320050410926342, 0.06613769714853593, 2.0816994053976874, 15.518723385674612, 37.77198130743844, 56.772667612348286, 41.927327156066895, 40.7628299168178, 31.35646983555385, 23.170711960111344, 19.560403653553553, 35.325246129717144, 73.59866850716728, 69.94178989955357, 78.71138232094901, 74.15635177067348, 82.83472129276821, 89.91171864100865, 71.29837008884975, 11.315626910754613, 0.10511895721512181, 0.10877956543117762, 0.13251802484904016, 0.07675314002803393, 0.059886591508984566, 0.034228967037051916, 0.042789894089634926, 0.027693221046190177, 0.06489228683390788, 0.033462327638907094, 0.1520333976617881, 0.04290484809981925, 0.07518696585404021, 0.01850455071377967, 0.07012584100344352, 0.008320295634413404, 0.02466528905954744, 0.02555371361917683, 0.03777789178171328, 0.057409328009401045, 0.0706707521208695, 0.045226062115814, 0.013173999963328242, 0.03831572238621967, 0.04023461602628231, 0.04041693499311805, 0.015506357220666749, 0.03565610599304948, 0.0697643379015582, 0.01860094170219132, 0.022850409748830965, 0.058705302753618786, 0.018984123997922455, 0.03545634528355939, 0.03606482156153236, 0.02469814881416304, 0.026339679390990307, 0.0681978990989072, 0.0766145967479263, 0.05127534090674349, 0.03454034336443458, 0.04545863677880593, 0.025797331439597265, 0.027416651868926625, 0.03708395062546645, 0.02315441209689847, 0.1985061660941158, 0.12024032723690782, 0.114451921411923, 0.21578382541026386, 0.1361256462654897, 0.08274764407958303, 0.13356588647833892, 0.12979015122566903, 0.15699198230036668, 0.13396649355334894, 0.10556281411222049, 0.15734598759029592, 0.15255965585155146, 0.1793309971690178, 0.09461192387555327, 0.12143437245062419, 0.13840906588094576, 0.10028655294861112, 0.1140095301504646, 0.123169888609222, 0.13862694347543375, 0.14923767053655215, 0.14769549614616803, 0.08933869576347725, 0.11530049730624471, 0.15454221303973878, 0.17686149611004762, 0.17336158534245832, 0.24432526103087834, 0.09854110982269049, 0.18606897204049996, 0.14385018391268595, 0.15499422592776163, 0.18287368278418267, 0.1109301686020834, 0.13077181497854845, 0.08503620699048042, 0.1607082507440022, 0.17099208677453653, 0.10715653002262115, 0.17536964187664644, 0.10436464340559073, 0.2763483683977808, 4.192584718976702, 32.519181387765066, 96.21419334411621, 110.32283020019531, 97.88822283063615, 72.01443059103829, 96.15554359980992, 57.09718670163836, 44.10153661455427, 46.09642348970686, 65.45001574925014, 94.74624742780412, 61.92040034702846, 63.190190587724956, 38.73346608025687, 16.625920568193706, 2.5051009144101823, 0.561809353530407, 0.17257858307233878, 0.10596372652798891, 0.2958932981959411, 0.38766393810510635, 0.3397959795381342, 0.16976078998829636, 0.30860019634876934, 0.25050465230430874, 0.1895645401839699, 0.39223251438566614, 0.45980209005730494, 0.5106120950409344, 0.4763386941381863, 0.31991805189422196, 0.4469988942146301, 0.2788456215390137, 0.9294269787413734, 0.6016895164336477, 0.9058863733495984, 0.7444293456418174, 2.29861695425851, 1.3074830238308226, 0.9025549292564392, 0.9398840176207679, 1.971246063709259, 1.421602951628821, 1.5384911937373025, 1.9812714457511902, 0.9510275168078286, 0.6097840592265129, 0.41352163201996256, 0.40163516412888256, 0.3533145141388689, 1.1212233155965805, 0.6485117439712796, 0.4760915988257953, 0.4591249121086938, 0.49775070803506033, 0.20567027452800954, 0.2849917917379311, 0.30272782860057695, 0.3848665010716234, 0.14166760817170143, 0.22031889563160284, 0.1643981241754123, 0.39864575596792357, 0.28271617527518955, 0.22197997649865492, 0.09347373566457204, 0.2985061737043517, 0.5102773872869355, 7.720435278756278, 32.21213354383196, 60.39968981061663, 73.9448208127703, 64.17301327841622, 90.58845928737095, 95.3931941986084, 63.27148451123919, 26.298172576086863, 33.34949459348406, 62.90113857814244, 58.92365619114467, 72.0439395904541, 75.71447140829903, 88.96283790043422, 100.89893286568778, 79.56357192993164, 11.094205192157201, 0.16860827111772128, 0.21615358628332615, 0.21172054058739118, 0.14946725964546204, 0.14171296145234788, 0.12750707087772234, 0.21670490955667837, 0.1264398167175906, 0.245291033493621, 0.12138603361589567, 0.26209696169410435, 0.1043649623170495, 0.16671686832393917, 0.11494911116148744, 0.17499722114631108, 0.12242738130901541, 0.17406340768294676, 0.12200911875282015, 0.17555353843740054, 0.10474557296505996, 0.11944182722696237, 0.0952348258080227, 0.06572269834578037, 0.13636857537286623, 0.12788615482194082, 0.08135544628437076, 0.10610387793609075, 0.1221697415624346, 0.1238404983388526, 0.11114136262663774, 0.12079017130391938, 0.1136963658833078, 0.11753777654043265, 0.16493568675858633, 0.17371440998145513, 0.20204476692846843, 0.09320304768958262, 0.12017761703048434, 0.13985165847199305, 0.1317586898803711, 0.10764391494116612, 0.11110530527574675, 0.08532687782176904, 0.16556634434631892, 0.08943682549787418, 0.16480937067951473], [0.027850215389792408, 0.06436700573457138, 0.025840123250548328, 0.04271554700764162, 0.06837047091020004, 0.021227971451090913, 0.051449035693492205, 0.013047230962131704, 0.03053037782332727, 0.05170627171173692, 0.05663452583498188, 0.014680313777976801, 0.012169623947037118, 0.04458259378692933, 0.06123900001070329, 0.030521095464272157, 0.035425207311553616, 0.14708522175039562, 0.08532727815743003, 0.017027821025944183, 0.027414460200816393, 0.035616581328213215, 0.04259638947301677, 0.07764010064836059, 0.035399799567780325, 0.004008706858647721, 0.031110939170633043, 0.06543071115655558, 0.013020185404457152, 0.07461658253201417, 0.04730879482147949, 0.04780165212494986, 0.018214490564007844, 0.011488577500650925, 0.045533133138503344, 0.02666003952201988, 0.01821348293950515, 0.017089443880000284, 0.06006672898573535, 0.050777381019932885, 0.3695170075765678, 0.09926984964736871, 17.446978773389542, 64.82342720031738, 79.55483109610421, 73.9886222566877, 51.04489925929478, 68.67355605534145, 75.33323069981166, 28.400164195469447, 38.42175599506923, 40.199702739715576, 64.45282418387276, 70.243668283735, 46.885704108646934, 30.179167066301616, 8.149259856769017, 0.8341455715043204, 0.3658057195799691, 0.09474264364689589, 0.07202421235186712, 0.08638704129095588, 0.1740687952509948, 0.06568727203245674, 0.01852161586949868, 0.01817194132932595, 0.06502057744988374, 0.06701192166656256, 0.07309060477252517, 0.17753730341792107, 0.07762655030403819, 0.352922646594899, 0.20904453418084554, 0.1023880166134664, 0.6954481825232506, 0.8472066106540816, 0.6290471255779266, 0.6462561850036893, 1.3258771853787559, 1.6250742162976946, 2.964379229715892, 3.0705481384481703, 4.43410062789917, 4.349586648600442, 7.306478977203369, 8.720099534307208, 6.934504125799451, 1.5142461061477661, 3.008623404162271, 3.755743222577231, 2.391065124954496, 1.0539833179541995, 1.6453491683517183, 1.0458088708775384, 0.9921873424734388, 0.8354265913367271, 0.4161595861826624, 0.5561695875866073, 0.19325282584343637, 0.6739113181829453, 0.4690720726336752, 0.12857885765177862, 0.03697084901588304, 0.10169806185045413, 0.31912731432488983, 0.15548237759087766, 0.06354325065123183, 0.00493012518355889, 0.012051451984526855, 0.03384712484798261, 0.06631556153297424, 0.08545347888554845, 0.053107487237347026, 0.2510131464472839, 2.366597912141255, 20.051978281566075, 52.61132199423653, 58.28062473024641, 53.098463671548025, 52.99407393591744, 65.57743876320976, 40.11036627633231, 12.542802112443106, 23.839099134717667, 30.76227378845215, 50.5903376851763, 61.252490861075266, 68.91427639552525, 74.76629243578229, 71.36997822352818, 25.94196101597377, 1.0881633524383818, 0.2558491469493934, 0.04325929783018572, 0.042324632805372985, 0.0283051595490958, 0.044305547938815186, 0.03867391084453889, 0.02024900317857308, 0.04148405005357095, 0.02370121971970158, 0.014430224429816008, 0.018530270583661537, 0.04490494202556355, 0.009184856965605701, 0.05135990672611764, 0.039375271781214645, 0.034334116216216765, 0.04308437828772834, 0.10887914044516427, 0.06650453353566782, 0.02491570240817964, 0.013413870574108191, 0.07557446363248996, 0.006675483916686582, 0.010575280391744204, 0.05031486440982137, 0.07020197263253586, 0.01551844023301133, 0.04382244457623788, 0.028567230129348378, 0.05716687387653759, 0.005111113373589302, 0.08366123719939164, 0.013028867260020758, 0.05524818718965564, 0.06891158901687179, 0.014162219212656575, 0.053457706301872215, 0.034188088694853444, 0.019183223135769367, 0.0234192935084658, 0.026686624524050524, 0.02588805157159056, 0.052660207131079266, 0.012605372350662947, 0.020349182088726332, 0.03269003265138183, 0.04037693874644382, 0.0812323803880385, 0.03552720469555684, 0.02323561068624258, 0.011401902285537549, 0.02976568921336106, 0.03240911576098629, 0.0186367446024503, 0.038868334876107316, 0.01952525058628193, 0.024629114661365747, 0.01741676578032119, 0.11694356985390186, 0.024467989735837494, 0.048085357794272046, 0.026807478396221995, 0.00471801556081378, 0.038644479388105016, 0.05929807773126023, 0.061629388348332474, 0.02222573005461267, 0.032835775188037326, 0.012733600202149578, 0.020887838809617927, 0.0028608811179375543, 0.07643525994249753, 0.022494540183937976, 0.03800285328179598, 0.00015029432714592464, 0.06764808217329638, 0.005586201965343207, 0.06463989216302123, 0.05165483536464827, 0.011334321894017714, 0.029676132768924748, 0.06535014190844127, 0.03682906912373645, 0.0619992713576981, 0.34184583382947104, 1.0943494204963957, 30.167525359562465, 85.66550077710832, 92.66506740025112, 83.47478934696743, 66.53662368229458, 104.16200842176164, 106.19266809735979, 42.61761678968157, 35.394227845328196, 27.664353438786097, 38.01799617494856, 54.153829029628206, 45.07544476645333, 29.234948566981725, 7.870824694633484, 0.5254309198686055, 0.32963255633200916, 0.10551077726164035, 0.0881026763735073, 0.042636063415557146, 0.11807068437337875, 0.20367246387260302, 0.27676216619355337, 0.15790309198200703, 0.2509351149201393, 0.18981035985052586, 0.9607049460921968, 1.076518280165536, 0.5143528857401439, 2.090279996395111, 1.7751775618110384, 2.404291238103594, 3.0012235726628984, 4.966641400541578, 4.727343704019274, 5.293607558522906, 5.735111730439322, 3.2338360164846693, 6.9811873350824625, 5.228541587080274, 10.47636616230011, 7.029121220111847, 13.927994115012032, 11.672344820840017, 9.972131047930036, 10.906846148627144, 5.279035883290427, 6.638292866093772, 6.181023231574467, 5.257275862353189, 6.21310784135546, 5.439001219613211, 3.760412846292768, 3.898771890572139, 3.7800805909293036, 2.761942160981042, 2.9335967557770863, 2.38648213659014, 3.1750965969903127, 2.758841093097414, 0.48130367057664053, 0.6554636880755424, 0.4852348853434835, 0.2685563979404313, 0.20197167513625963, 0.0918053537607193, 0.14665135288877146, 0.16657110543123313, 0.06084511721772807, 0.02398512894952936, 0.04155396969456758, 0.3001043408044747, 1.2766271595443999, 14.298401713371277, 42.7039064679827, 53.14115340369088, 50.86389173780169, 38.62001936776297, 29.10508152416774, 23.670570577893937, 24.24115664618356, 39.04504067557198, 54.500120299203054, 76.29763371603829, 82.59206935337612, 79.72392245701381, 84.7547378540039, 91.93491595132011, 46.104625838143484, 4.014671751431056, 0.39266807958483696, 0.020436519723651663, 0.05925334870283093, 0.048686410899141004, 0.040577364420252185, 0.034140197693237236, 0.01721179222555033, 0.05779318205480065, 0.004259957773943565, 0.02860974713361689, 0.006389710835979453, 0.04921853841681566, 0.029884385344173228, 0.008079000948263066, 0.09194974601268768, 0.021690152186368192, 0.06812447482453925, 0.022795482339071374, 0.062013887001999786, 0.017414774280041456, 0.037104527199906964, 0.02785265981219709, 0.0253054749752794, 0.014426780864596367, 0.029237113826509033, 0.043227966475699625, 0.045213631354272366, 0.012512710760347545, 0.05702457829777684, 0.03489904411669288, 0.014095921252321984, 0.03282184486410447, 0.03907773417553731, 0.034343904083860774, 0.06370182428508997, 0.06016732858760016, 0.06939833611249924, 0.02842080736133669, 0.01532212139240333, 0.05869336732264076, 0.05447787691705993, 0.028757501526602676, 0.06083689337330205, 0.06655023965452399, 0.07713371674929347, 0.1721671194370304, 0.2348041119320052, 0.20263199827500752, 0.11324045141892773, 0.12991232824112686, 0.18681198145662034, 0.11584089616579668, 0.1143336934702737, 0.12554663393114293, 0.1569592904831682, 0.062038802807884555, 0.08194663349006857, 0.15913020899253233, 0.31393681998763767, 0.10350050191794123, 0.08478854170867375, 0.1820884413485016, 0.2159229250890868, 0.10259875601955823, 0.09998155824307885, 0.14904253743588924, 0.09751336675669466, 0.26267594205481665, 0.11842326473976884, 0.11722091425742422, 0.2290031532091754, 0.15768047821308884, 0.14675606441284927, 0.10048186925372907, 0.173219160842044, 0.145159742927977, 0.07028769196144172, 0.15612238539116724, 0.12965453921684197, 0.07737146184912749, 0.13416428651128495, 0.10039764948721443, 0.14936056679912976, 0.1874747744628361, 0.5026077159813472, 0.8643404341169766, 33.32446370806013, 97.26442745753697, 106.64607279641288, 92.80390630449567, 68.48017379215786, 87.92527730124337, 94.89066573551723, 35.311596393585205, 48.3949362209865, 58.48391859872, 85.35693822588239, 96.62300450461251, 66.61439486912319, 46.28354542595999, 13.025514313152858, 2.204029824052538, 0.4901137692587716, 0.204329625038164, 0.29001115954348017, 0.25779635246310917, 0.41433025577238625, 0.22639862368149416, 0.3348082314644541, 0.1156680868672473, 0.19851852900215558, 0.18518551944621972, 0.2244651245751551, 0.5316028743982315, 0.23474830921207154, 0.9034178629517555, 0.38523896251405987, 0.8854434160249574, 1.8139668575354984, 2.5016398429870605, 3.1837080206189836, 3.2379554297242845, 3.5881693916661397, 6.757093599864414, 7.750686866896493, 10.25343234198434, 15.44454094341823, 13.74406053338732, 19.682424443108694, 22.021884645734513, 16.41488640648978, 10.826642223766871, 10.684194598879133, 10.761290073394775, 9.510191355432783, 4.5060175231524875, 6.277087722505842, 3.2865385370595113, 1.451997846364975, 2.427544253213065, 2.3207089688096727, 1.8821156578404563, 0.8105106226035527, 1.148953684738704, 1.5895820579358508, 0.8956773525902203, 0.328738518591438, 0.8765869598303522, 0.7454956769943237, 0.3782601755644594, 0.20682117848524026, 0.1787088212690183, 0.22481188311108521, 0.2189464092786823, 0.45517003004040035, 0.1696906023259674, 0.19312683546117373, 0.4727135258061545, 5.075119716780526, 30.717336314065115, 69.58672305515834, 79.23729842049735, 73.264071055821, 72.79844447544643, 91.52336720057896, 59.28255844116211, 18.988738877432688, 32.57608366012573, 41.902577672685894, 67.02460956573486, 80.33407156808036, 83.7494238444737, 92.85972118377686, 105.05554676055908, 48.27280078615461, 3.375627253736768, 0.5491597237331527, 0.15159127781433718, 0.10803542964692626, 0.14170906666134084, 0.16459606641105243, 0.13860958654965672, 0.11829394953591482, 0.11454626492091588, 0.11995283194950648, 0.1313021443784237, 0.0987944747986538, 0.2531468133841242, 0.11615271014826638, 0.19588703449283326, 0.2601895183324814, 0.12757496509168828, 0.16354850333716187, 0.24444414036614553, 0.12916561402380466, 0.1012820452451706, 0.16935034415551595, 0.19699388795665332, 0.12810792720743588, 0.1588893019195114, 0.11583881984863963, 0.22476116940379143, 0.12692647560366563, 0.15322987203087124, 0.12796783686748572, 0.16964035002248629, 0.1047073985849108, 0.14041605032980442, 0.07818054022001368, 0.15750438480504922, 0.22929058064307484, 0.12741834563868387, 0.14778021802859648, 0.1304174568504095, 0.07704711532486336, 0.10823525820991822, 0.07043017074465752, 0.1863994457359825, 0.1487075039850814, 0.12237279995211534], [0.07229657630835261, 0.04527583944478205, 0.07467960486454622, 0.057802790110664706, 0.022168225908119763, 0.014941522618755698, 0.024639380896197896, 0.024674859795985476, 0.02353464955064867, 0.049097474198788404, 0.06139199608670814, 0.023812813285206045, 0.035155381076037884, 0.03782461231042232, 0.01553236716426909, 0.051190812406795363, 0.018413102852978876, 0.06086584646254778, 0.01506761647760868, 0.07742233840482575, 0.012468921502919068, 0.060089079929249625, 0.04637598558994276, 0.04879733780398965, 0.010174859913864305, 0.05246984073892236, 0.05474459206951516, 0.017674500521804606, 0.09050475140767437, 0.04234638324539576, 0.046269129895206006, 0.04506815344627414, 0.015020091884902545, 0.04698644658284528, 0.026936053996905684, 0.041351430384176116, 0.018024000339210033, 0.13817457774920122, 0.13812812524182455, 0.7070858723350933, 12.815659608159747, 48.46778808321272, 92.61924403054374, 81.31367724282401, 70.13771520342145, 64.20288358415876, 60.414343561444966, 27.473776510783605, 22.919475521360123, 50.180915083204, 68.17495332445417, 67.96813324519566, 61.24681418282645, 31.457142284938268, 10.751493981906346, 0.23983680616532052, 0.38330755329557825, 0.04459366747843368, 0.2441749248121466, 0.0335997275875083, 0.06365291548094579, 0.0751405337027141, 0.016590864829985157, 0.02386975594397102, 0.08044788534087793, 0.4129684902727604, 0.3264711531145232, 0.32096782699227333, 0.3334699161350727, 0.5894992277026176, 1.9923803125108992, 1.0967312412602561, 5.921388157776423, 4.606348642281123, 2.5992655072893416, 2.327779846532004, 3.060288906097412, 8.393711379596166, 15.271542957850865, 2.184826305934361, 9.658643960952759, 10.623356172016688, 8.041264006069728, 8.617562362125941, 26.11445525714329, 10.968839713505336, 10.259172422545296, 11.544586556298391, 5.718192866870335, 10.349383490426199, 9.097902621541705, 7.399108018193926, 11.346582004002162, 5.129485028130667, 5.7637300576482495, 2.0483693310192654, 5.9005201118333, 3.0527900627681186, 6.409163423946925, 4.717743899141039, 0.6542944365314075, 5.457493415900639, 3.1556996149676184, 1.4686807968786784, 1.279938844697816, 1.2572970539331436, 0.33461406188351767, 0.5773067133767265, 0.23084013749446186, 0.21804110785680159, 0.11832764558494091, 0.11084657308778592, 0.1342148780822754, 0.11559625715017319, 0.20396998790757997, 0.4137054607272148, 2.0957621250833784, 24.517674105507986, 53.34444727216448, 61.9544951575143, 52.68456295558384, 46.731447151729036, 43.27506923675537, 37.36075217383248, 24.08728357723781, 20.682075670787267, 38.40419789722988, 54.65665626525879, 61.348181452069966, 66.36519772665841, 78.8478032520839, 58.50989096505301, 6.140987277030945, 0.18458215253693716, 0.15049376099237374, 0.09100131690502167, 0.15941167888896807, 0.05302307069567697, 0.06956306405897651, 0.03306879768414157, 0.05347436772925513, 0.012907403554501278, 0.048690638172307184, 0.01663056930660137, 0.04453193436243704, 0.045932257614497624, 0.0428909652733377, 0.05474620019750936, 0.06421267972992999, 0.0612301586994103, 0.06460494082421064, 0.09199520107358694, 0.03757287242582866, 0.02583726152910718, 0.024343951838091016, 0.015770061373976723, 0.09132796366299901, 0.019899963068642786, 0.02799706733120339, 0.03252109778778894, 0.017424066817121844, 0.026818804842020785, 0.0738308864778706, 0.03883695263149483, 0.04137555569676416, 0.057533140294253826, 0.05928956211677619, 0.02650309946121914, 0.028507044073194265, 0.04256313107907772, 0.03368984043065991, 0.015235367297594036, 0.05803211459091731, 0.03315428631114108, 0.03142435449574675, 0.05876210292002984, 0.010420221569282668, 0.08635948598384857, 0.037796334363520145, 0.021123407508379648, 0.02645972411015204, 0.0438192724250257, 0.009928663660373007, 0.03467640659904905, 0.06471687196088688, 0.019106392615607808, 0.08915158294673477, 0.038558909336903265, 0.043882976685251505, 0.037856852901833396, 0.04240230470895767, 0.0260354259849659, 0.020824568811804056, 0.04545358847826719, 0.021249206204499518, 0.0244278238554086, 0.020664526149630547, 0.010728172142989933, 0.027257956098765135, 0.04240220632137997, 0.02399151396405484, 0.021895110474101136, 0.02837818518414029, 0.1224970668554306, 0.1306374921862568, 0.021333397133275867, 0.04876425243648035, 0.04106493593592729, 0.04159089896295752, 0.017689319726611887, 0.026948082726448774, 0.03613102961597698, 0.011118853098845907, 0.07977600675076246, 0.19781946151384286, 2.0740097037383487, 24.232811859675817, 70.55032702854702, 105.27815314701625, 93.60563809531075, 87.43545709337506, 91.30991159166608, 81.10919175829206, 32.09099517549787, 29.58154903139387, 28.777810948235647, 37.48367970330374, 45.85799258095877, 60.71696540287563, 33.82252447945731, 10.23730296748025, 0.16025550503815922, 0.2791302262672356, 0.020481525255101066, 0.16056601623339312, 0.09716941735574178, 0.09302774138216462, 0.5140023274081094, 0.09707787619637591, 0.40941663086414337, 0.34253299981355667, 1.710399072085108, 0.9041863445724759, 0.570138832288129, 1.0202962798731667, 2.1998255125113895, 3.3929957960333144, 2.171494232756751, 3.213517529623849, 1.8893665373325348, 5.445059614522116, 4.776166524205889, 7.612405555588858, 9.97582575253078, 16.52715539932251, 8.506965279579163, 12.225960782596044, 10.978514211518423, 10.721743532589503, 12.129180192947388, 16.83964889390128, 12.582798549107142, 10.364791120801653, 6.614517867565155, 5.098484771592276, 4.499649499143873, 4.271249617849078, 5.181086693491254, 4.925701311656407, 10.088537693023682, 12.94267007282802, 9.642529351370674, 6.240918874740601, 6.513083287647792, 6.753305528845106, 7.135470347745078, 3.787275016307831, 1.3208420212779726, 1.5488061202423913, 0.9529116728476116, 0.4654553181358746, 1.0669946883405959, 0.367790407368115, 0.2917906583419868, 0.7465205362864903, 0.2962172308138439, 0.20020611344703607, 0.07913762064916746, 0.04362999847424882, 0.13045451843312808, 0.17406088353267737, 0.4023952590567725, 1.0544223572526659, 18.112729106630596, 49.74063900538853, 61.32612092154366, 48.709519386291504, 30.725007125309535, 15.259684119905744, 24.12007733753749, 19.013048887252808, 32.91262660707746, 65.19230011531285, 79.4631426674979, 81.05784457070487, 74.73115539550781, 89.42618547167096, 78.95561844961983, 14.97219545500619, 0.10211005474307708, 0.22379093218062604, 0.05876069835254124, 0.09384919623179094, 0.06256863687719617, 0.05526357975655368, 0.02315911095190261, 0.05389573458316071, 0.015298231870734265, 0.07994068719978843, 0.02413901899542127, 0.015061043169615524, 0.017804231328357543, 0.04281494560252343, 0.009906235533500356, 0.013652495224960148, 0.033325368738068004, 0.0633035988679954, 0.12283896708062716, 0.017662853468209505, 0.028873371559062173, 0.012337900631661926, 0.055338517164013216, 0.05640979842948062, 0.037831974415374656, 0.009392067989600556, 0.04570552174534116, 0.02599014903950904, 0.05745462700724602, 0.029498119106782333, 0.04512439042861972, 0.045916885403650146, 0.03129230479576758, 0.021338813539062227, 0.05150760005095175, 0.01992427497836096, 0.056819273957184384, 0.0057983688394805145, 0.04591995577460953, 0.026228928905246512, 0.055894637679947276, 0.038014612293669155, 0.04490404635933893, 0.08448187102164541, 0.24508709300841602, 0.28234680795243805, 0.1677633457417999, 0.10637637081422976, 0.22939160093665123, 0.09266445373318025, 0.10774008370935917, 0.24647027307323047, 0.12883758305438928, 0.1815251215760197, 0.09572065688137497, 0.12530493975750037, 0.1806568545954568, 0.15040627068706922, 0.11184490844607353, 0.11882623311664377, 0.0943600381059306, 0.11336443333753518, 0.18355262492384228, 0.08668139656739575, 0.15606063870447023, 0.15551098462726387, 0.10698013127382312, 0.08370173895465476, 0.0963490820888962, 0.22516119293868542, 0.176786992965, 0.34660703263112475, 0.0990845960165773, 0.17115465019430431, 0.20212266274860927, 0.15465628834707396, 0.10210544749030045, 0.15954080410301685, 0.13096616097858974, 0.17829764261841774, 0.19868392869830132, 0.22910534058298382, 2.0238721540996005, 24.45105825151716, 77.95645359584263, 123.1560001373291, 99.27484703063965, 88.43508052825928, 82.7523295538766, 77.84659562792096, 34.49848345347813, 28.46189546585083, 69.57422324589321, 95.56211185455322, 91.82804570879254, 84.98535551343645, 46.19682843344552, 17.639525515692576, 0.8712265331830297, 0.5407053945319993, 0.10760285678718771, 0.3699853595878397, 0.2873881874339921, 0.27124060105000225, 0.3161561180438314, 0.09053519048861094, 0.2923584835869925, 0.37704288374100414, 1.5530105403491428, 0.7536351659468242, 1.2318950912782123, 1.2667681000062396, 1.5521116171564375, 6.322638809680939, 4.520799815654755, 12.56309345790318, 11.006039500236511, 10.038430758884974, 8.7585916859763, 12.662252937044416, 19.735433987208776, 28.141545295715332, 13.157567432948522, 22.41682025364467, 26.548347677503312, 31.024297305515834, 19.43448145048959, 47.032137393951416, 36.230985505240305, 31.299668312072754, 28.85291576385498, 19.890012298311504, 26.241384949002946, 29.99272952760969, 29.96931062425886, 23.692068304334367, 15.664298568453107, 16.633511475154332, 10.281684585980006, 12.641887766974312, 10.477787068911962, 12.971871614456177, 17.62324067524501, 6.208916340555463, 14.003375121525355, 10.903150575501577, 4.978054250989642, 2.2828206590243747, 2.576731196471623, 1.2316407220704215, 1.0672430864402225, 0.5564965871827943, 0.65668543108872, 0.28804025958691326, 0.37922103543366703, 0.2596237558339323, 0.4213008460189615, 0.31731600580470903, 0.8781299484627587, 4.118850001267024, 34.08464527130127, 71.44573443276542, 83.95536845070976, 74.96206487928117, 72.00311197553361, 60.82195963178362, 52.57698399680001, 32.06757627214704, 29.33371720995222, 50.436195373535156, 69.85049057006836, 78.99675178527832, 79.78927721296037, 99.25198745727539, 87.98507349831718, 14.263989022799901, 0.4678800765957151, 0.24948674121073314, 0.11457707041076251, 0.33867997942226274, 0.1280859833849328, 0.22534963568406446, 0.16585849438394817, 0.18064587589885506, 0.17227060959807464, 0.24070527670638903, 0.1385909268366439, 0.2812026622039931, 0.20934326600815567, 0.08781719633511134, 0.15365194795387133, 0.14337269882006304, 0.1568634949092354, 0.14604916663042136, 0.26083168387413025, 0.08732643909752369, 0.13326737178223474, 0.09106438673500504, 0.1562189002122198, 0.3427151186125619, 0.08312078405703817, 0.06869027803518943, 0.15141909276800497, 0.09419096074998379, 0.11038249584713153, 0.1936267257801124, 0.13093159640473978, 0.13737773336470127, 0.15918124839663506, 0.09406385757029057, 0.0952290039775627, 0.09267035698784248, 0.08631120821727173, 0.1406074786292655, 0.09358388903949942, 0.168070735675948, 0.11549089423247746, 0.15930483676493168, 0.11752644500562123], [0.03337257102664028, 0.07092371676117182, 0.09995955335242407, 0.04073734262159892, 0.0974905544093677, 0.03942778699898294, 0.032537162104355435, 0.01281609564154808, 0.012030794834052878, 0.0404581729588764, 0.0231728716420808, 0.05665847133578999, 0.07201284010495458, 0.025788295049486414, 0.04338885052129626, 0.04704496005017843, 0.0660651210429413, 0.048559097373592, 0.05639624808515821, 0.05079182703047991, 0.006884984572284988, 0.035911995119282177, 0.0515790124689894, 0.04403124676485147, 0.07693421388311045, 0.022028206814346567, 0.06920322336788688, 0.02705385785416833, 0.016556798979373913, 0.06810237493898187, 0.08155140719775643, 0.01159163679195834, 0.03199642397729414, 0.03680072332333241, 0.045806267232234986, 0.02566054047617529, 0.01395685550024999, 0.0764534989637988, 11.791402203696114, 57.200464725494385, 94.33012676239014, 85.03654289245605, 73.11580344608852, 65.93015016828264, 59.885752405439106, 38.58182512010847, 46.754212924412315, 56.57592936924526, 50.60468224116734, 62.12804726191929, 55.331649439675466, 42.76156609398978, 11.578345247677394, 0.9426132483141763, 0.39319019871098654, 0.026509246988488094, 0.14632307764674934, 0.13628381277833665, 0.10135804116725922, 0.0532803983161492, 0.09329450063939605, 0.0790714363434485, 0.4350916360105787, 0.25613049470952576, 0.5565577639000756, 0.2891243685569082, 1.3203011474439075, 0.7177574911287853, 6.786018950598581, 3.6833851167133878, 2.3565545082092285, 5.720103187220437, 14.02124501977648, 9.344310930797032, 5.283687702247074, 10.921589357512337, 9.224487509046282, 8.607059291430883, 11.84704077243805, 1.2922203285353524, 8.249005590166364, 3.220488961253847, 7.9088287353515625, 4.073804829801832, 10.933882457869393, 8.92945831162589, 6.814782755715506, 12.26254391670227, 3.181399915899549, 3.735974294798715, 6.4430458801133295, 8.961146439824786, 7.684198686054774, 9.186844774654933, 10.595113481794085, 7.009031806673322, 7.594445330756051, 4.8752908280917575, 15.642964124679565, 8.532535518918719, 9.897502183914185, 14.609377895082746, 2.1756792196205685, 7.78685918876103, 6.774005080972399, 4.82782290663038, 1.8683258720806666, 1.1739134596926826, 1.355220622250012, 0.135818269902042, 0.07710968303893294, 0.049445976569716416, 0.049576014413365295, 0.12301740821983133, 0.13968900005732263, 0.09711192508361169, 0.26264722645282745, 0.609696121088096, 2.229661728654589, 20.053876876831055, 49.10144642421177, 66.66646466936383, 64.77594321114677, 78.82305376870292, 96.91465514046806, 41.262801442827495, 19.85509065219334, 18.648423058646067, 41.967682293483186, 61.0138966696603, 53.092067854745046, 66.24866253989083, 69.10414981842041, 22.02878073283604, 0.5219328818576676, 0.378827050860439, 0.04410140050042953, 0.026425911013835242, 0.002668214067983042, 0.11103712607707296, 0.09031667507120542, 0.060852540390832086, 0.07722283553864275, 0.03827909506591303, 0.06636480960462775, 0.06659329948680741, 0.0629791302074279, 0.05114963211651359, 0.023417658239070858, 0.059657219531280656, 0.07445986808410712, 0.027919593899111663, 0.021540547089119042, 0.04095123382285237, 0.042697854207030365, 0.021596687380224466, 0.0541953518986702, 0.03365760662459901, 0.011030112592769521, 0.014591934591797846, 0.01126497985595571, 0.0460707296484283, 0.03784703789278865, 0.0217748910321721, 0.004322287152587835, 0.04519470361992717, 0.01788716696734939, 0.0466917418608708, 0.04620304397706475, 0.03703370171466044, 0.03082334210297891, 0.01622250343539885, 0.03818227490410209, 0.01634057531399386, 0.02663800579362682, 0.014922929062907184, 0.026158318854868412, 0.06046939880720206, 0.08355504646897316, 0.02580812693174396, 0.07648866064846516, 0.030387200149042264, 0.03141274136890258, 0.04961491482598441, 0.03600078481914742, 0.049174962897918055, 0.01138364545269204, 0.02798960174966071, 0.027055281081369946, 0.02917688027290361, 0.05155390328062432, 0.033062996209732125, 0.045268999811794074, 0.03168154301654015, 0.031740704484816105, 0.057765429972537925, 0.05596685076930693, 0.04004286881536245, 0.0452581432514957, 0.05620179691218904, 0.07235457069639649, 0.04529458397467222, 0.06573626226080315, 0.05258906612704907, 0.03844521740185363, 0.07843442766794137, 0.08257384411990643, 0.008698815546397651, 0.03176585438528231, 0.03798031574115157, 0.04245210239397628, 0.017993961593934467, 0.06163782932396446, 0.1019140463322401, 21.79845837184361, 79.77731241498674, 110.52498803819928, 95.05805478777204, 91.55215358734131, 83.38034248352051, 93.08844198499406, 61.8706442969186, 55.86200196402413, 40.18196746281215, 21.19369237763541, 54.454758984701975, 56.23244169780186, 42.95266587393624, 11.807799083845955, 0.46451644280127113, 0.5731246035013879, 0.04280871665105224, 0.15916015952825546, 0.4220546712832791, 0.24675417212503298, 0.17503369918891362, 0.26102256934557644, 0.14418665585773333, 0.22852793442351477, 0.1317643488624266, 0.26284204742738176, 1.0243003964424133, 0.6719454122441155, 0.38167792931199074, 0.47005757689476013, 1.6992868397917067, 1.2895563457693373, 1.755867975098746, 2.2253675247941698, 2.5142512576920644, 2.12153668488775, 2.4837788471153806, 6.06696594612939, 9.749979768480573, 15.471048321042742, 7.373014058385577, 10.621210047176906, 8.442310554640633, 11.327728935650416, 9.804785421916417, 12.495979939188276, 4.985322935240609, 2.445279964378902, 0.6674803261246, 0.49412814527750015, 1.0793512995753969, 0.9830655519451413, 0.5408846363425255, 1.4398848563432693, 4.762525473322187, 8.05171149117606, 6.920252936226981, 4.35304685149874, 2.3494662599904195, 5.488580959183829, 1.6961977141244071, 1.5227131375244685, 2.761552844728742, 7.137367640222822, 14.128458329609462, 13.204202004841395, 9.81167369229453, 3.726187757083348, 1.6782886236906052, 1.7901377933365958, 0.22550881999943936, 0.10413269978016615, 0.049557829674865515, 0.08152799095426287, 0.0845644080213138, 0.022334316013646976, 0.07991327438503504, 0.4276041920695986, 0.6778413930109569, 0.800772233733109, 16.554583413260325, 44.91758516856602, 65.70926693507603, 43.31244707107544, 44.80460745947701, 47.64897067206246, 25.572982140949794, 23.16288307734898, 34.38448783329555, 65.43211024148124, 85.98074749537876, 72.27719756535122, 72.6809434890747, 84.02653190067836, 37.13855225699288, 2.4509536027908325, 0.26353852291192326, 0.06450883990951947, 0.046544950987611494, 0.036587463159646304, 0.03451540720249925, 0.102735521537917, 0.04048938896240933, 0.01861475158615836, 0.06729857557054077, 0.03356716808463846, 0.038044508546590805, 0.037378760520368814, 0.062318895278232436, 0.015001966518216898, 0.015741186316258142, 0.02760413957626692, 0.009919438128625708, 0.08451351789491517, 0.06985763646662235, 0.04427023358376963, 0.031127264723181725, 0.03022142725863627, 0.01806684473662504, 0.026109988501827632, 0.0024664868791920264, 0.047943157210413895, 0.011185609070318086, 0.06645204885197536, 0.015294250566512346, 0.03192829566874674, 0.018146212977756346, 0.029565657089863504, 0.03720093006268144, 0.030921543083552803, 0.074608026205429, 0.03656669320272548, 0.048504254780709743, 0.037919315442975075, 0.06229024074439492, 0.07320526361997638, 0.05805283705038684, 0.09292238524981908, 0.15506644919514656, 0.18174925526337965, 0.11073912028223276, 0.14553632986332687, 0.09659653023949691, 0.08476700500718184, 0.10114684714270489, 0.08111168257892132, 0.10914100746491126, 0.1366148293018341, 0.15619979266609463, 0.11649636099381105, 0.1127205646729895, 0.13710182745541843, 0.09893820208630391, 0.16441964730620384, 0.13745913042553834, 0.10258724806564194, 0.15433620980807713, 0.1644942183047533, 0.06886253772037369, 0.16665737437350409, 0.07812944653310946, 0.18675373601061956, 0.13213729885007652, 0.17437286036355154, 0.1715599934437445, 0.1973887546254056, 0.09201729417379413, 0.14316836478454725, 0.1378456646842616, 0.20908650835709913, 0.1165405200528247, 0.18262394118521894, 0.07661074266902038, 0.09387721294271094, 0.23870628540005, 24.155593054635183, 88.61827673230852, 124.91479764665876, 105.6362771987915, 89.50427627563477, 85.60022939954484, 78.97977038792202, 51.22028568812779, 59.59421294076102, 73.84990842001778, 81.64974076407296, 88.53180640084403, 75.19910267421177, 58.56776251111712, 17.276864290237427, 1.4614197122199195, 0.6622582663382802, 0.1553493304444211, 0.3495001973850386, 0.4595458209514618, 0.23458046678985867, 0.3475615685539586, 0.3531820098204272, 0.20803148139800343, 1.331715083548001, 1.4875562297446387, 1.9941798959459578, 1.9803529807499476, 7.383209671292986, 7.437520265579224, 16.868412699018204, 12.80530071258545, 18.334970712661743, 23.286171913146973, 27.79289858681815, 24.488720961979457, 17.716721739087784, 31.392628261021205, 25.877143008368357, 25.43038947241647, 25.924774646759033, 8.978379709380013, 21.100913081850322, 15.835542133876256, 24.485325029918126, 18.0172278540475, 29.363226209368023, 24.99651963370187, 24.439939396721975, 34.59877027784075, 14.567157166344778, 13.09864410332271, 16.268998554774694, 24.93021297454834, 20.595680032457622, 22.145397560937063, 32.621722902570454, 21.00507484163557, 21.86326595715114, 19.606819357190812, 29.62904691696167, 19.65253676686968, 23.14270724569048, 28.875348023005895, 7.385013597352164, 11.630349040031433, 8.608105863843646, 5.759073027542659, 3.342971806015287, 2.334613616977419, 3.8393322229385376, 1.3735023098332542, 0.22783694150192396, 0.2823278089719159, 0.19448564254811831, 0.2998183790062155, 0.3089441864618233, 0.31698664490665707, 0.6558851940291268, 0.9176851745162691, 3.845032785620008, 30.60203790664673, 66.51671014513288, 85.82719925471714, 88.62639917646135, 102.04248128618512, 114.98576627458844, 53.268708433423726, 26.193956545421056, 26.31334744180952, 51.508993761880056, 80.00476169586182, 70.63715866633824, 83.08787196023124, 95.38717705862862, 35.57120541163853, 1.4680517677749907, 0.33455177236880573, 0.1558748558163643, 0.139207267335483, 0.1306274634386812, 0.17076640602733406, 0.1282635424286127, 0.1964595416294677, 0.10435871300952775, 0.1873703207820654, 0.15287824161350727, 0.13930204510688782, 0.09299247113189527, 0.12476910065327372, 0.09286567329296044, 0.10716389891292367, 0.11416582390666008, 0.12893333791622094, 0.1667197317417179, 0.13453127896147116, 0.16179457173815795, 0.09222701577735798, 0.12441950584096567, 0.08826614903020007, 0.09982582088559866, 0.13398494970585617, 0.13496457785367966, 0.11470345434333597, 0.267211134412459, 0.07102812294449125, 0.12612580428166048, 0.09888891330254929, 0.06914240627416543, 0.1006229773962072, 0.23738197503345354, 0.12694578671029635, 0.09887401267353978, 0.13387236717556203, 0.154648648042764, 0.09208822822464363, 0.1571563777646848, 0.21687227700437817], [0.03842430155990379, 0.014883160125464201, 0.03679502362917576, 0.06972717453858682, 0.025926037658272044, 0.061435483396053314, 0.028139240773660795, 0.017420994749824916, 0.06650325110448257, 0.037251022910433154, 0.007728352710338575, 0.024857188940846493, 0.03053703425186021, 0.01333840815017798, 0.04953937352235828, 0.035971617991370816, 0.043444117198565176, 0.04657639430037566, 0.029051269870251417, 0.014003709191456437, 0.019966853050781146, 0.0817245761198657, 0.05282155258048858, 0.02042722888290882, 0.0860131209982293, 0.01124020230158099, 0.02476603115376617, 0.07712136741195406, 0.05628735678536551, 0.053146414791366885, 0.003532347922113591, 0.20849796065262385, 0.025823533069342375, 0.028824462754917995, 0.011075225841653134, 0.06638085017246859, 1.4042389690876007, 40.79931490761893, 84.62310423169816, 88.80491924285889, 75.04270567212785, 59.30413954598563, 60.70766176496233, 64.60219655718122, 37.26926176888602, 38.752931458609446, 40.2353435243879, 48.84881339754377, 70.23466341836112, 50.88975293295724, 23.753565073013306, 2.02784326672554, 0.25831469893455505, 0.08869825370077576, 0.22836022770830564, 0.02209650306031108, 0.0880488006930266, 0.11528502670781952, 0.14639177253203733, 0.1706369686871767, 0.4270863341433661, 2.9928731407438005, 1.4215125164815356, 4.168025876794543, 5.822478813784463, 8.889683348791939, 10.156524079186575, 8.775260414396014, 5.790691239493234, 14.398269040243965, 10.05456621306283, 9.098937903131757, 11.740558760506765, 7.822364483560834, 11.726281949451991, 4.611901121480124, 5.183095157146454, 6.348400124481746, 11.767449157578604, 6.635514455182212, 6.3778318251882276, 4.2016929388046265, 3.432993535484586, 8.226239817483084, 5.901339130742209, 6.23604862179075, 4.213073653834207, 2.9286277081285204, 1.5369623729160853, 1.9212548605033328, 0.4222129870738302, 0.8248826456921441, 2.404547018664224, 8.588773369789124, 12.59036774294717, 9.975566063608442, 4.837644619601114, 4.505251918520246, 3.259660299335207, 3.362429367644446, 9.020897473607745, 24.46737262180873, 51.90652104786464, 66.87714099884033, 72.94198036193848, 63.93567671094622, 43.768710953848704, 16.554899556296213, 2.94331294298172, 0.14506272599101067, 0.10806680510618857, 0.14856060115354403, 0.11100338931594576, 0.05745440309068986, 0.030211924375700097, 0.05221317469009331, 0.21610303542443685, 0.19088912196457386, 0.2053287678531238, 0.3278046372745718, 0.7779253082615989, 14.85702211516244, 47.12282528196062, 66.88265092032296, 62.39861706324986, 52.124889033181326, 61.234779902866904, 38.770044871738975, 20.151226350239344, 25.30579263823373, 40.91733700888497, 66.78140177045549, 65.22514425005231, 75.7179594039917, 45.614055224827354, 5.217697620391846, 0.2541072389909199, 0.1317147072404623, 0.03792217546807868, 0.051706434560141394, 0.07311922537961177, 0.0773735653076853, 0.053596144409051964, 0.014520260937778013, 0.041449834925255606, 0.08251197529690606, 0.0477065486567361, 0.02827240666374564, 0.005945125361904502, 0.047481984099639316, 0.06227372520204101, 0.03213671448507479, 0.03369078698701092, 0.07674521473901612, 0.09828764985182456, 0.014551254721092326, 0.047286487982741425, 0.031102352309972048, 0.05230086516322834, 0.04913278855383396, 0.0368730721196958, 0.013745150029925364, 0.02989036323768752, 0.01203702633003039, 0.040387951369796476, 0.11764611144151006, 0.06003173693482365, 0.014418161773521985, 0.03409958058702094, 0.02838251763023436, 0.055728135364396233, 0.056859813031873534, 0.06205151855413403, 0.05780591137175049, 0.03247610752337745, 0.033631218397723775, 0.03787917670394693, 0.009724802054863955, 0.08468804388706173, 0.04443153492840273, 0.022344027546101382, 0.058366924125169, 0.035409729927778244, 0.0021705052391293323, 0.020592296096895422, 0.017595882061868906, 0.020315460594637052, 0.041648584617567916, 0.019813544848667722, 0.06453119085303374, 0.007600057853518852, 0.02102112683600613, 0.035996085964143276, 0.00938930720024343, 0.055654222544814856, 0.06524586464677538, 0.05724067813051598, 0.050935401647750816, 0.0399314940774015, 0.07308641821146011, 0.02340607564630253, 0.04127997725403734, 0.0440883590573711, 0.048064686224928925, 0.05913484934717417, 0.014108195950809335, 0.038486194131629806, 0.06383090200168745, 0.02206007421149739, 0.02151581957670195, 0.09593535214662552, 0.01971535913513175, 4.108465484210423, 61.57871573311942, 102.0884644644601, 99.9783799307687, 87.55781487056187, 88.46290806361607, 94.24513639722551, 103.40397385188511, 46.07841375895909, 26.779116460255214, 26.48673973764692, 42.661063875470845, 73.19845226832798, 55.888238361903596, 23.010668890816824, 1.5625141561031342, 0.318672098751579, 0.028701339183109145, 0.1621202685471092, 0.08640295972249337, 0.22397557512990066, 0.1192210183611938, 0.05367394523429019, 0.15490248799324036, 0.13502347469329834, 1.4630629611866814, 3.1512987996850694, 8.127504178455897, 11.451624870300293, 15.573278903961182, 17.672755275453838, 16.634291410446167, 11.670368926865713, 18.00856692450387, 14.145600404058184, 14.69152992112296, 16.08002839769636, 11.94377533027104, 12.684329101017543, 5.9505358508655, 3.3642923533916473, 4.394218836511884, 6.406748056411743, 6.438890857355935, 8.636134028434753, 7.812990495136805, 9.49311442034585, 8.996022922652108, 5.835222244262695, 2.3334745466709137, 0.40753160629953655, 0.728580504655838, 1.3138741723128726, 1.5265157563345773, 1.729765112910952, 1.3066485886062895, 0.256797196077449, 0.5606385820678302, 1.6962888006653105, 0.463528930076531, 2.6488771651472365, 2.333118885755539, 0.6750007197260857, 3.7195709007126943, 13.847357664789472, 36.57818004063198, 67.76664243425641, 78.50967611585344, 84.07380744389125, 78.56970855167934, 59.044721603393555, 25.851841143199376, 5.653657998357501, 0.6928778918726104, 0.5648259030921119, 0.30937418767384117, 0.17112688454134123, 0.029611739795655012, 0.05678661267406174, 0.09211427718400955, 0.06118956194924457, 0.1639594648565565, 0.20644547364541463, 0.5831215956381389, 0.3148150071501732, 13.549063682556152, 44.28511496952602, 64.3269784109933, 61.279130254473, 33.137821197509766, 26.662852253232682, 24.47386223929269, 31.98884275981358, 46.521073068891255, 61.91188185555594, 86.15929535457066, 80.51943561008999, 84.60403837476457, 66.53966004507882, 13.090557268687657, 0.025568610855511258, 0.05506087081240756, 0.044761075638234615, 0.023104689050731913, 0.05647260023813162, 0.06177618261426687, 0.050981908437928984, 0.018613503081724048, 0.03373441678871002, 0.027184092472972612, 0.006110919032445443, 0.044732393962996345, 0.00894977935656373, 0.023194262458543693, 0.054873235523700714, 0.031434071117213795, 0.012942398149919297, 0.035647373247359476, 0.035246454046240876, 0.026662748573081832, 0.044537610307868035, 0.039437137211539915, 0.02196775104052254, 0.014261900247739894, 0.020357565388881733, 0.033569407250199995, 0.03389859512182219, 0.02143187800954495, 0.057782040509794436, 0.08468891919723578, 0.0942904068423169, 0.013653631771116384, 0.012205680449759322, 0.04830610898456403, 0.014305601295615946, 0.03360865032300353, 0.02835016168787011, 0.0315471252293459, 0.06396049540489912, 0.07088466028549842, 0.18483519181609154, 0.14109568457518304, 0.19059260216142448, 0.11974319177014486, 0.0925097545342786, 0.1453082606728588, 0.12031888802136693, 0.07889744639396667, 0.09920392997030701, 0.07917824454073395, 0.15993344517690794, 0.15725500961499556, 0.10985663799302918, 0.12613398741398538, 0.14309361736689294, 0.15684244675295694, 0.14811640498893602, 0.1598344604883875, 0.08501710622970547, 0.14035111452851975, 0.23622908975396836, 0.16681081828262123, 0.1200944014957973, 0.14299696683883667, 0.17483361278261456, 0.22927060457212584, 0.18238224701157638, 0.12849340295153006, 0.26769302998270306, 0.14831464577998432, 0.10229652973690204, 0.24271382178579057, 0.11710166851324694, 0.12770783581904002, 0.2417317373411996, 0.12507463140147074, 3.528779447078705, 66.83488205501011, 116.91649000985282, 110.35130391802106, 92.05017961774553, 79.80235372270856, 80.79595306941441, 80.95154408046177, 50.31693301882063, 51.853148460388184, 58.92877006530762, 70.27922916412354, 95.37020260947091, 67.10238770076207, 33.333187171391074, 3.2406728267669678, 0.5199739784002304, 0.11604658727134977, 0.6222981991512435, 0.1621924103902919, 0.2571865123297487, 0.12116340627627713, 0.21069147437810898, 0.36721012422016686, 1.261963963508606, 6.035263921533312, 4.850648173264094, 8.753056577273778, 9.055860808917455, 13.57216123172215, 13.902524624552045, 13.072553617613655, 11.964268173490252, 20.76902195385524, 14.135974543435232, 14.821676628930227, 16.406260217939103, 10.869166936193194, 15.32218142918178, 11.39511169706072, 18.92452015195574, 19.50798123223441, 30.88756717954363, 18.50498444693429, 18.543632064546856, 16.733640227999004, 17.524765593664988, 25.310515676225933, 17.424134833472117, 17.615146023886545, 12.439716032573156, 6.774426315511976, 4.533915409020015, 5.532901780945914, 4.361776394503457, 2.6565167094979967, 7.4342719827379495, 20.12672005380903, 25.049779312951223, 21.858179875782557, 14.92631128856114, 15.116587706974574, 17.388103212629044, 12.88428349154336, 12.444439070565359, 26.326161657060894, 57.25103718893868, 72.25107233864921, 82.87823091234479, 76.99953378949846, 51.2909870828901, 20.014937434877666, 4.774345661912646, 0.5152935524071965, 0.5937967970967293, 0.29548435871090206, 0.2860166238886969, 0.11819850680019174, 0.17135835997760296, 0.2248449684785945, 0.6094549968838692, 0.21369513177445956, 0.4422851385814803, 0.7725291635308946, 2.15933010833604, 22.519870723996842, 65.11452198028564, 84.72228976658413, 80.53386007036481, 72.37133175986153, 79.94559778485979, 47.13957391466413, 27.10388742174421, 32.565751688820974, 53.53554705211094, 85.20027024405343, 80.99128777640206, 98.69816739218575, 70.19503089359829, 11.809945208685738, 0.21441660448908806, 0.21403500996530056, 0.12779235414096288, 0.09981997191373791, 0.15014655462333135, 0.16033310230289186, 0.1355581467172929, 0.16059817879327706, 0.11767114938369819, 0.18101494466619833, 0.1580207228128399, 0.15350237169436046, 0.12120242203984942, 0.11378513861979757, 0.11029631511441298, 0.12220156485480921, 0.12042399309575558, 0.14882691257766315, 0.16265757328697614, 0.12710881153387682, 0.12783831810312613, 0.20476755153919968, 0.12067135982215405, 0.07338857664061443, 0.09958382815654789, 0.14213890502495424, 0.08336973177003008, 0.12795958588165895, 0.11869197817785399, 0.203538928180933, 0.16914535872638226, 0.16077018742050442, 0.2745865929339613, 0.12060632902596678, 0.12348918004759721, 0.14805345050990582, 0.1753189145986523, 0.18665342139346258, 0.13026212661394052, 0.20432301610708237], [0.012641383052271391, 0.04229218865345631, 0.02872574608772993, 0.0619396281295589, 0.057654978042202334, 0.02720487430425627, 0.044037014312509976, 0.07048442640474864, 0.05562562229377883, 0.02068429526739887, 0.0036711759748868644, 0.049724630545824766, 0.04352374328300357, 0.049920123270047564, 0.03156155427651746, 0.11719285004905292, 0.04256481723859906, 0.018289597605222037, 0.05921046528965235, 0.031454311816820076, 0.09309043801788773, 0.060101822816899846, 0.02142639714293182, 0.055153080328766785, 0.04046147403174213, 0.006761895775395844, 0.02285056241921016, 0.10795329298291888, 0.04602433142385312, 0.0485186872205564, 0.044166991088007174, 0.013668262682455991, 0.011414390722555774, 0.0607865121481674, 0.08656890224665403, 3.7160907217434476, 60.02119364057268, 90.3374000276838, 76.51165907723563, 69.54850101470947, 76.22758892604283, 49.64964887074062, 38.77383858816964, 24.390153816768102, 62.11094079698835, 79.88693414415631, 68.8570510319301, 78.40742642538888, 38.596423285348074, 8.189726165362767, 0.41625354971204487, 0.1485159806907177, 0.08476235025695392, 0.018020826491660306, 0.05932591123772519, 0.016727430180513432, 0.053360407772873125, 0.8098276906779834, 1.0281217971018382, 0.300920482724905, 2.3460127881595065, 10.114893078804016, 24.02792337962559, 51.2292697089059, 72.8758613041469, 87.58937358856201, 91.31765883309501, 89.46111406598772, 72.84531007494245, 62.72230584280831, 60.413620948791504, 55.42937237875802, 53.26694359098162, 39.55085563659668, 28.278322322028025, 11.936871426446096, 3.9863026908465793, 4.56531822681427, 11.291038972990853, 4.385446301528385, 7.448523606572833, 5.05661232130868, 7.865201864923749, 5.460419910294669, 7.738775048937116, 2.5764537027903964, 0.38832390840564457, 3.363838332039969, 6.533864915370941, 11.065496972629003, 15.637660912105016, 13.326274037361145, 7.35548027924129, 2.9932830844606673, 3.1776891435895647, 3.37589475938252, 3.4026948298726762, 3.197844999177115, 10.354182090078082, 22.16559944834028, 63.410184451511924, 91.78479317256382, 99.64053767068046, 93.08740670340401, 86.63092517852783, 89.687319619315, 87.66376795087541, 77.4303846359253, 43.622159549168174, 22.841945784432546, 26.27812007495335, 26.920034612928117, 15.539215360369, 2.176101105553763, 0.08082905917295388, 0.12036434986761638, 0.05924437168453421, 0.07575380043791873, 0.07274081997041192, 0.1719166450202465, 0.07636385770248515, 0.36239304127437727, 0.7775198157344545, 22.40266851016453, 59.689431054251536, 66.90868582044328, 56.3239529473441, 61.67045974731445, 46.991876057216096, 28.643215656280518, 29.11407596724374, 38.51845407485962, 51.51154375076294, 53.73165648324149, 75.23923546927315, 72.9093655177525, 20.922592776162283, 0.11643522498863083, 0.09347950999758073, 0.054591334757528136, 0.14150754176080227, 0.02437083878820496, 0.016094502893143466, 0.04643799690529704, 0.020252078638545105, 0.06304726869400058, 0.035465569967137914, 0.038603831747812886, 0.026240061968564987, 0.0182156169321388, 0.046290849801152945, 0.07913308124989271, 0.05320121667214802, 0.07719869326267924, 0.03296539233997464, 0.022539186091827493, 0.03421366946505649, 0.06836970416562897, 0.0311232613665717, 0.06036940310150385, 0.01774351771122643, 0.049223132098891904, 0.07094519239451204, 0.04223404838038342, 0.03830622968130878, 0.03864251502922603, 0.03886438240962369, 0.04794264491647482, 0.05066334303202374, 0.03669274465313979, 0.019637994268643003, 0.028767157079918042, 0.017830482151891505, 0.011858924458335553, 0.011815177609345742, 0.06742381277893271, 0.020025196884359633, 0.0468355743214488, 0.03452402798991118, 0.023719781045136706, 0.08241364200200353, 0.0316636466554233, 0.08290144761226007, 0.04133235676480191, 0.0312302425902869, 0.01279834601362901, 0.03568218887916633, 0.015194482170045376, 0.003575612375113581, 0.01900132486064519, 0.0491877431049943, 0.042791671851383786, 0.022192212121028985, 0.02501486860481756, 0.018023337071229304, 0.009373449836857617, 0.08780083007046155, 0.07548223715275526, 0.05949069346700396, 0.03125839161553553, 0.03141665990863528, 0.08500593754329852, 0.057598992117813656, 0.07424784624683005, 0.008748411367248212, 0.027714566061539308, 0.04176130624754088, 0.06390886567533016, 0.058393651619553566, 0.041440566136900864, 0.10293695144355297, 8.858996629714966, 83.46813297271729, 101.63240555354527, 92.65599305289132, 94.41778523581368, 101.69814246041435, 72.23559870038713, 51.53334719794137, 27.088740348815918, 41.9695930480957, 56.213323729378835, 59.20537090301514, 78.71202850341797, 39.63039861406599, 6.755993178912571, 0.46580701640674044, 0.12585601875824587, 0.09246093393968684, 0.08699084924800055, 0.09402590710669756, 0.11377371887543372, 0.10763742136103766, 0.6929712582911763, 1.0252286323479243, 0.7619058021477291, 4.808261556284768, 15.12961905343192, 35.92759936196463, 65.49789578574044, 87.20489501953125, 98.75090421949113, 104.53845487322126, 100.36695793696812, 89.5616614477975, 75.41152300153459, 74.5943523134504, 68.86787632533482, 63.90418747493199, 48.33817638669695, 34.83028425489153, 16.465015922273906, 6.128745419638498, 1.7218799931662423, 2.4894498799528395, 2.878506226199014, 4.973217436245509, 5.921736001968384, 6.6363712549209595, 4.211522034236363, 1.0579982910837447, 0.18516472913324833, 0.9366625504834312, 5.778473266533442, 11.544470173971993, 17.891408136912755, 23.99253794125148, 21.97805540902274, 13.36157957145146, 4.538855578218188, 0.9262075743504933, 1.285349102956908, 2.609649372952325, 5.634176986558097, 14.505888819694519, 33.437479632241384, 77.57560893467495, 99.08430658067975, 103.57401016780308, 99.2051010131836, 93.7345688683646, 95.8061534336635, 97.20579160962785, 87.61828504289899, 58.13570615223476, 34.1305832862854, 39.26171677453177, 41.3883831841605, 26.019224984305247, 5.699497435774122, 0.19484807524297917, 0.02156192433488156, 0.251210980117321, 0.23484124136822565, 0.09369138934250389, 0.0839624253234693, 0.18612333626619407, 0.6985977249486106, 0.6866641938686371, 20.576749665396555, 62.19628552028111, 64.29858112335205, 51.40515988213675, 31.614762169974192, 21.89689871243068, 27.70517757960728, 43.40564325877598, 65.36050905500139, 74.3083644594465, 71.94897856031145, 85.02812167576381, 91.81803335462297, 38.178985936301096, 0.7971431570393699, 0.11048994865268469, 0.05109880305826664, 0.13755982502230577, 0.009943249618767627, 0.021707220734762292, 0.024828088270234208, 0.0348969270874347, 0.03882290017125862, 0.04592083447745868, 0.053253538507436, 0.0718415439394968, 0.01757574823152806, 0.07792346365749836, 0.0913344911698784, 0.0340479949622282, 0.019117903962199177, 0.03818340127223304, 0.02304351911880076, 0.07006855907716922, 0.040243850887886116, 0.06919050083628722, 0.07337567768990993, 0.0755619378760457, 0.0775848204003913, 0.10072914777057511, 0.03344119805842638, 0.03578724306342857, 0.05765244032123259, 0.03581926652363368, 0.01644722405554993, 0.06449487565883569, 0.009652229341944414, 0.04280256912378328, 0.04280496435239911, 0.02652504328372223, 0.04663976268576724, 0.09811491519212723, 0.07110442420733826, 0.09173262837742056, 0.1806301881692239, 0.09854087912078414, 0.1766341325959989, 0.12168473830180508, 0.09989549286131348, 0.12455008311995439, 0.1441171738718237, 0.10837711274091687, 0.09206236925508295, 0.07246650861842291, 0.151888069031494, 0.10491194975163255, 0.21727703671370233, 0.08862957917153835, 0.1777507569640875, 0.14288308152130672, 0.14806546057973588, 0.21983116466019834, 0.32268340779202326, 0.1757410719458546, 0.14697641187480517, 0.07624138213161911, 0.11526804976165295, 0.15442048385739326, 0.15664093542311872, 0.17266540841332503, 0.18759938063366072, 0.13900606813175337, 0.19066762099308626, 0.10681787998016391, 0.12814508378505707, 0.08707213095788445, 0.21718320889132364, 0.13990682336900914, 9.411571230207171, 94.78637327466691, 115.53013678959438, 99.52661500658307, 92.85623318808419, 98.31631524222237, 64.27265044621059, 48.189641271318706, 31.262936660221644, 78.56221839359829, 106.59859575544084, 94.81396457127163, 102.04400294167655, 49.51917559759957, 13.15236062662942, 0.6551163867115974, 0.24568564231906617, 0.18571218475699425, 0.39932130543248995, 0.10679160031889166, 0.14169538739536489, 0.13215114096445696, 2.422513323170798, 2.9565284167017256, 1.4379873467343194, 4.4073609198842725, 12.697818160057068, 30.239018848964147, 57.958957876477925, 82.68539060865129, 97.19131851196289, 103.76769120352608, 98.61387184688023, 84.3150280543736, 72.14053344726562, 72.1939650944301, 67.75421905517578, 62.037984711783274, 47.129551138196675, 34.458972522190635, 15.777093887329102, 7.624819380896432, 11.174849459103175, 23.238024371010916, 20.455892699105398, 21.883068323135376, 16.313270739146642, 16.156849418367656, 17.982938494001115, 20.099740198680333, 6.41032247032438, 1.8707664268357413, 5.281310984066554, 10.995645863669258, 17.319866691316875, 25.89495645250593, 20.52677995818002, 12.14012360572815, 6.388403943606785, 8.615226030349731, 13.308305995804922, 7.217822568757193, 8.202959878104073, 14.859179530824933, 26.945008175713674, 70.83982372283936, 101.57554844447544, 112.31062643868583, 109.61824117388043, 100.93379892621721, 106.898848261152, 101.87998376573834, 87.75314262935093, 50.127615451812744, 28.607644353594097, 29.540634563991002, 32.70795004708426, 18.399576800210134, 3.6515271919114247, 0.17702640726097993, 0.15369783049183233, 0.3396348681833063, 0.20385102714811051, 0.22442278398999146, 0.43530401747141567, 0.41270991414785385, 0.8296194172331265, 1.957799562386104, 31.98040417262486, 77.13375214168003, 86.69994858333042, 83.8151329585484, 89.29259940556118, 59.40989112854004, 37.554273400987896, 36.488009793417795, 49.31670161655971, 67.8746452331543, 69.01449026380266, 95.51894269670758, 102.50041621071952, 39.6901079586574, 0.6492270284465381, 0.21101453847118787, 0.22998276778629848, 0.35544348561338013, 0.07270400944565024, 0.11966719584805624, 0.1800266041287354, 0.14531822156693253, 0.13491256135915006, 0.09190608906958785, 0.12018437523927007, 0.14061720882143292, 0.12431619209902627, 0.10697477763252598, 0.1304700704557555, 0.07935283160103218, 0.0970690959532346, 0.14817451472793305, 0.10758999176323414, 0.12084978739065783, 0.1176853986190898, 0.12835251194025787, 0.14939946042639868, 0.1890401683215584, 0.18554225244692393, 0.15980251505970955, 0.1164732500910759, 0.16919018274971417, 0.14393859702561582, 0.1566437174166952, 0.16489753951983793, 0.14214474042611464, 0.08776423667690583, 0.08070010359265975, 0.11305872617023331, 0.06504757635827575, 0.08457546814211778, 0.2329824353967394, 0.15686797324035848], [0.014448731472449643, 0.03226120869762131, 0.024822456429579427, 0.04024633771872946, 0.06791438681206532, 0.024459053429641893, 0.028693346040589467, 0.04709901214976396, 0.013982995213674647, 0.028822182877255336, 0.07856753588254962, 0.030825055403900996, 0.015413579431229403, 0.05970331920044763, 0.025318611413240433, 0.08382806860442672, 0.04046628823769944, 0.028920838476291726, 0.009162554367711502, 0.13913022646946566, 0.12935670305575642, 0.02597204233253641, 0.04966294153460434, 0.08687438549739973, 0.09006065702331917, 0.04959641456870096, 0.05559580407238432, 0.012898870128473001, 0.033224484151495356, 0.02324337312685592, 0.03909053473866411, 0.018954137839110832, 0.01517308796090739, 0.08636950116072382, 3.286655353648322, 68.91711126055036, 82.71672698429653, 75.11872591291154, 63.416660172598704, 55.31357717514038, 37.924018314906526, 35.49920122964041, 45.28658315113613, 65.75380488804409, 59.288978576660156, 63.55902181352888, 71.8898424421038, 23.995117459978374, 1.3472102177994592, 0.4376738688775471, 0.09411397416676794, 0.15185365373534815, 0.06086324767342635, 0.03872506559959479, 0.08872104569205216, 0.3367711789906025, 0.061863347222762446, 1.0509707310370036, 0.9885012145553316, 3.957121125289372, 21.79983411516462, 48.43445062637329, 82.74875123160226, 99.46609619685582, 101.49046080453056, 93.71704551151821, 95.84830120631626, 93.28117111751011, 99.09647287641252, 98.15597166333879, 89.85169315338135, 88.44239698137555, 81.59581579480852, 73.99332618713379, 59.49668107713972, 35.86226545061384, 16.60634228161403, 7.33342843396323, 1.625619432755879, 3.172201152358736, 4.563473914350782, 4.654028918061938, 6.422021499701908, 4.829013219901493, 2.0159245005675723, 1.0703886662210738, 6.784922003746033, 20.864801134381974, 30.339284828730992, 37.96090630122593, 45.483613218579976, 43.51598065240042, 47.846504483904155, 33.4617531640189, 8.443106991904122, 1.8421754581587655, 8.73501557963235, 20.616024357931956, 32.627837317330496, 70.78668390001569, 90.46426023755754, 90.54028742653983, 86.84686824253627, 86.74347904750279, 85.05296148572648, 87.8681422642299, 89.17320850917271, 94.09635462079729, 97.5807580947876, 85.97653688703264, 96.16773074013847, 92.48425442831856, 85.40324796949113, 55.81517457962036, 9.666921871049063, 0.08752763830125332, 0.27495612310511724, 0.17928503320685454, 0.10070472050990377, 0.032950430642813444, 0.017808056569525173, 0.12662990151771478, 0.06967897141086203, 0.29430549911090303, 6.648815912859781, 45.67657164164952, 67.26786599840436, 58.88555921827044, 65.95487880706787, 67.25239930834088, 28.816119841166906, 20.566782474517822, 34.8746589251927, 44.28590359006609, 52.108355794634136, 57.51793139321463, 70.9724370411464, 32.41389186041695, 0.816199351634298, 0.15782968806368963, 0.18433330660419806, 0.009494212954970343, 0.03953292939279761, 0.05198307667991944, 0.03863701211022479, 0.06689715425350837, 0.08199894854000636, 0.03907695725294096, 0.002138069144816005, 0.06178756843187979, 0.04212611720764211, 0.02815391239710152, 0.03834438709808247, 0.047131849851991446, 0.06253909346248422, 0.062165417442364354, 0.09734461509755679, 0.05166186838011656, 0.03230405818404896, 0.04084193879472358, 0.0548907620832324, 0.08088198490440845, 0.05382476321288517, 0.0767922168597579, 0.05123483236613018, 0.015446230536326766, 0.04300702190292733, 0.08304804510303906, 0.00587887574718999, 0.060737203008362224, 0.018218585522845387, 0.007477867267360645, 0.07479012464838368, 0.02216185107161956, 0.024304774922451804, 0.07083292199032647, 0.06362055614590645, 0.013307499183740999, 0.010625752370937594, 0.0856403067175831, 0.08018078681613718, 0.12781657784112863, 0.021862710426960672, 0.029126933310180902, 0.03195435141346284, 0.03989780142105051, 0.018235338552455817, 0.03297174342774919, 0.031097151339054108, 0.08600627457989113, 0.02181803059232022, 0.02701716437669737, 0.0678143978917173, 0.043258296991033215, 0.09209585495825325, 0.04290643926443798, 0.06668349036148616, 0.02321635895142598, 0.05265822580882481, 0.07268280522631747, 0.05747455558074372, 0.03284728992730379, 0.030047128575720956, 0.07674792887909071, 0.08124879415013961, 0.05690511542239359, 0.034945856247629435, 0.029729384197188274, 0.03757575959233301, 0.07007406878152064, 9.970106516565595, 95.97791290283203, 96.15517534528459, 96.79838398524693, 87.17248167310441, 81.63979094369071, 66.69513988494873, 44.74510308674404, 27.562645707811626, 32.78719425201416, 48.92635529381888, 71.79198401314872, 76.33138806479317, 24.16685782160078, 0.8228246761219842, 0.34582351467439104, 0.06315909805042402, 0.11254696148846831, 0.07595761200147015, 0.09691216437412159, 0.4822705015540123, 0.11139263092939343, 0.21236366964876652, 0.7214771115354129, 0.38350744971207207, 5.23509156703949, 25.184734174183436, 58.57573904309954, 91.54752608707973, 104.42071069989885, 105.39066532679966, 97.02914755684989, 98.72045026506696, 97.72320311410087, 101.12761197771344, 103.61046736580985, 96.4607640675136, 95.34224305834088, 90.31870937347412, 82.98530960083008, 69.11886610303605, 42.937028953007285, 22.34076006071908, 9.092676707676478, 1.7400550693273544, 1.2057453287499291, 1.3271769327776772, 3.3768742382526398, 4.4003623468535285, 3.329812352146421, 1.2967466456549508, 1.0477436184883118, 10.428320237568446, 29.3022175516401, 40.45677219118391, 50.39169216156006, 56.851453236171174, 54.986386503492085, 62.91082436697823, 52.047882148197715, 16.058355229241506, 3.565383208649499, 12.640454701014928, 28.986215216772898, 45.39744513375418, 82.74056625366211, 95.06883144378662, 94.87534495762416, 91.44956343514579, 92.99855313982282, 89.67536871773856, 91.85542855943952, 94.65530940464565, 99.74319035666329, 102.02302633013043, 94.69188472202846, 101.89048944200788, 99.34775447845459, 96.61565331050328, 72.51534012385777, 15.298371689660208, 0.5626303809029716, 0.3650349852229868, 0.05872031194823129, 0.2620409418429647, 0.10463730591748442, 0.06280920468270779, 0.08294023267392601, 0.11460931439484869, 0.4947009916816439, 4.978184963975634, 46.3228166443961, 69.84556429726737, 57.95842286518642, 38.817577498299734, 28.629508597510203, 15.761861698968069, 31.494937011173793, 56.126405239105225, 73.2380153111049, 69.96900599343437, 65.59852654593331, 81.32885210854667, 51.57802758898054, 3.926199035985129, 0.1138054064608046, 0.13758113102189132, 0.06177143286913633, 0.01385839413186269, 0.07141889126173087, 0.044942967128008604, 0.022743033278467398, 0.060255463501172404, 0.05849931987800768, 0.06338659727147647, 0.04715967657310622, 0.023726905662832514, 0.03431356339050191, 0.006502514314239046, 0.012749090308456548, 0.018428492027201822, 0.06877656054816075, 0.021077228111347983, 0.02851140366068908, 0.04383177782541939, 0.016028756242511526, 0.03920574319948043, 0.06616462820342608, 0.0795933451237423, 0.03801811692704048, 0.0373305234658931, 0.04630496672221592, 0.07750570321721689, 0.05080587270536593, 0.04221103247255087, 0.054095074600939236, 0.073887008109263, 0.03657091708321657, 0.05482516471030457, 0.047141837887465954, 0.07319017978651182, 0.10402668546885252, 0.2048312524067504, 0.148356986365148, 0.15719588207347052, 0.11420388972120625, 0.14786913325744017, 0.18008555525115558, 0.13955076890332357, 0.07090152188071183, 0.1162887971316065, 0.17154431928481373, 0.10184417079601969, 0.12240868088390146, 0.12621929283652986, 0.13503768321658882, 0.14022241000618252, 0.12621416311178887, 0.20694760312991484, 0.17365535029343196, 0.13462782092392445, 0.22487626251365456, 0.32712653651833534, 0.08347469435206481, 0.10212064667471818, 0.20773041541022913, 0.12497636596007006, 0.12802448097084249, 0.14097840658255986, 0.11958186328411102, 0.10215519767786775, 0.11869146249123982, 0.13049178357635224, 0.14482228032180242, 0.10138883987175566, 0.23559892071144922, 9.719263519559588, 112.5359217779977, 105.63713877541679, 102.01458426884243, 85.79812799181256, 71.24076952253068, 49.7618761743818, 50.589545590536936, 63.79272447313581, 90.04569380623954, 85.60086168561662, 84.72367245810372, 90.86357321058, 33.06257220676967, 2.526717845882688, 0.703748348568167, 0.15363537812871592, 0.40499765798449516, 0.1992950173360961, 0.1274687743612698, 0.383812247642449, 0.5832784729344505, 0.44478480730737957, 2.4747887466635023, 1.4325685117925917, 5.570123715060098, 24.908763885498047, 56.291664668491904, 94.51426792144775, 111.76988288334438, 113.20986230032784, 105.85237312316895, 104.84538459777832, 104.1133918762207, 107.39784703935895, 108.30631010872978, 101.21567344665527, 100.37708146231515, 93.5687917981829, 85.3051324571882, 70.70854445866176, 43.96045344216483, 22.568358727863856, 12.963528564998082, 7.0420935068811685, 9.415768810680934, 13.672180550439016, 14.900712387902395, 16.334125757217407, 16.061600037983485, 8.247150421142578, 2.22528566632952, 10.835358738899231, 31.77673510142735, 46.79355362483433, 57.63689150129046, 71.36389854976109, 70.04682581765312, 78.81293719155448, 60.93363107953753, 13.412816456386022, 2.3229328266211917, 12.5349098273686, 26.00557698522295, 44.96732037408011, 85.44650745391846, 100.89088685171944, 102.47848074776786, 97.53408704485211, 99.18246378217424, 96.69796861921037, 99.83961745670864, 100.90547112056187, 104.77902930123466, 106.63182898930141, 95.66302054268974, 106.05109855106899, 105.41392789568219, 100.35569490705217, 67.22865036555699, 11.572812744549342, 0.6268981780324663, 0.6361544270600591, 0.20230216240244253, 0.27140000249658314, 0.15258295674409184, 0.18667497166565486, 0.2571879508239882, 0.5173418053558895, 0.506883789386068, 11.797612156186785, 63.50087928771973, 81.79718153817313, 76.63493401663644, 98.78873716081891, 85.9183040346418, 37.17434242793492, 26.771513393947057, 44.00266374860491, 59.8490172794887, 67.17033413478306, 71.27708080836705, 94.7984561920166, 56.21753781182425, 3.0073080233165195, 0.20973369505788597, 0.3101552629045078, 0.19017778656312398, 0.10440934529261929, 0.12653432307498796, 0.10728433209338359, 0.10234778627221074, 0.15522438500608715, 0.11215193875666175, 0.13799182112727845, 0.10865866406155483, 0.08275657360042844, 0.13396616785654, 0.10469914759908404, 0.18045355193316936, 0.19293631639863762, 0.1753265413322619, 0.17339912189968995, 0.12127754943711416, 0.17701503501406737, 0.09439350345305034, 0.18328070880046912, 0.21718215037669453, 0.17812397836574487, 0.17201438120433263, 0.15179310127028398, 0.15593581540243967, 0.1880688997251647, 0.14509110232549055, 0.17011740085269722, 0.1068946426468236, 0.19351468607783318, 0.13911495943154606, 0.18931597923593863, 0.1138637401163578, 0.10352955000208956, 0.16845131239720754], [0.06922031566500664, 0.022809502568894198, 0.021451394373018826, 0.0762983180050339, 0.05285253109676497, 0.09563802488680397, 0.031113361540649618, 0.019694533199071884, 0.04337466235405632, 0.06781417397516114, 0.03387405590287276, 0.03027947253680655, 0.03168554637315018, 0.06417605240962335, 0.0856459317728877, 0.015450057473831942, 0.08712166401424579, 0.012791216306920563, 0.03309901624119707, 0.08891638913857085, 0.05498681210779718, 0.06597598868289165, 0.014258629708950008, 0.02934871587370123, 0.11083697181727205, 0.1047969109245709, 0.03942878783813544, 0.14115703771156923, 0.19186908937990665, 0.15125362521835736, 0.022178789002022574, 0.05299646194492068, 0.02824414737655648, 4.504558401448386, 71.64359133584159, 81.78148555755615, 72.4154806137085, 60.63102313450405, 55.12278311593192, 33.88082333973476, 24.14070306505476, 43.16061156136649, 60.685385840279714, 64.57266671316964, 94.76301343100411, 59.726638657706125, 8.967394607407705, 0.07440739697111504, 0.07011653150298766, 0.10835424611078841, 0.07773808789040361, 0.18708815877991064, 0.011222658778673835, 0.10994884411671332, 0.28568438600216595, 0.5745019753064428, 0.10181580803224019, 2.726280531712941, 14.526681303977966, 36.46188109261649, 69.63135828290666, 97.17143971579415, 96.88697351728166, 89.47841508047921, 92.36842100960868, 92.39386531284877, 92.71298912593296, 90.44841834477016, 90.19653919764927, 89.71650205339704, 88.63983699253627, 83.27178382873535, 84.65413488660539, 85.22822979518345, 89.74186297825405, 65.23889473506382, 46.98448664801461, 22.830727917807444, 7.418211221694946, 1.0689324757882526, 1.0690657943487167, 3.813784565244402, 4.393063264233725, 2.469084058489118, 0.5973004262362207, 4.7462727682931085, 24.923638241631643, 40.17619003568377, 52.278829847063335, 62.23157542092459, 69.78710215432304, 68.50682708195278, 64.5489455631801, 65.26513808114188, 66.19568947383335, 55.38436542238508, 54.07021788188389, 53.04496949059622, 72.49835872650146, 87.01709910801479, 84.37389319283622, 88.55066381181989, 91.609879221235, 88.91959231240409, 84.58267266409737, 79.85194301605225, 86.672301701137, 92.42838396344865, 90.39636938912528, 91.6058770588466, 91.41224466051374, 82.86411217280796, 81.45681013379777, 87.65016337803432, 65.19059780665806, 9.327915787696838, 0.16738475034279482, 0.0883990740403533, 0.31027536360280855, 0.10487592632749251, 0.01737205032259226, 0.08280759264848062, 0.06404124107211828, 0.030702858032392602, 0.20950790574508055, 0.3272462843784264, 22.739407743726456, 69.02817126682827, 83.01084423065186, 66.49775545937675, 79.26702976226807, 50.28003808430263, 24.6847539629255, 16.892623697008403, 39.303207942417686, 53.808479240962434, 52.96577739715576, 69.23301110948834, 52.300404003688264, 5.1843870878219604, 0.7806676211101669, 0.030442745025668825, 0.042834677400865724, 0.03343385291684951, 0.09421703006540026, 0.047956388643277545, 0.09832782591027872, 0.023856670396136384, 0.032821817722703726, 0.03695124274651919, 0.04988454767901983, 0.04878732601978949, 0.031281885890556235, 0.010487089499032922, 0.01748427322932652, 0.055477362392204146, 0.0494097902971719, 0.07319073618522712, 0.05888406280428171, 0.052461301375712664, 0.02431411834965859, 0.01151925661335034, 0.028918148084942783, 0.06217277954731669, 0.04872464295476675, 0.031272450861121924, 0.009736375317775776, 0.040732694656721184, 0.03645740495994687, 0.10997279640287161, 0.04520876286551356, 0.018891483611826385, 0.04668341623619199, 0.042711262058998854, 0.02525490545667708, 0.024202911549114754, 0.08434764322425638, 0.04568546764286501, 0.044625239712851386, 0.018796247829283987, 0.07625535995300327, 0.024668900562184196, 0.007718561450019479, 0.016135851120842353, 0.029642222981367792, 0.07056291255035571, 0.03316322601001177, 0.03957847944859948, 0.010393975834761347, 0.06227139782692705, 0.014184463286905416, 0.014012145926244557, 0.04767443359430347, 0.01935975589523358, 0.11796685494482517, 0.09200810680964164, 0.03131504250424249, 0.06169194249170167, 0.030435450774218355, 0.0381852299241083, 0.13146763906947204, 0.07653469246413026, 0.04015959380194545, 0.1490618349718196, 0.15581910737923213, 0.09666530654898711, 0.06802778358438186, 0.11066102768693652, 0.14752465459917272, 13.596419130052839, 97.81116036006382, 90.60299491882324, 88.65592902047294, 86.91006905691964, 83.40070070539201, 56.91473742893764, 25.201750312532695, 18.950579370771134, 39.088157721928184, 58.764063017708914, 103.72504316057477, 62.17361354827881, 7.44950156552451, 0.2855915624116148, 0.08238677880061523, 0.10479108909411089, 0.028764846668179547, 0.25697402230330874, 0.047596602234989405, 0.06534263731113502, 0.7493433505296707, 0.4200476732637201, 2.8781084418296814, 6.626288984503065, 23.235743624823435, 50.254621573856895, 83.6133086340768, 101.7981617791312, 100.71270029885429, 94.7617141178676, 95.81111444745744, 97.47742448534284, 97.4297181538173, 95.82218987601144, 96.03620828901018, 93.79671355656215, 93.93255778721401, 89.11677524021694, 91.24602290562221, 92.6332654953003, 95.04196275983537, 75.10543400900704, 57.80254002979824, 32.98868158885411, 12.317482454436165, 2.335361416850771, 0.4491239844688347, 0.5288634385381425, 1.6318370934043611, 0.8347927310637066, 0.8839050957134792, 8.26758073057447, 30.424111911228724, 48.06930889402117, 64.57195799691337, 76.77404390062604, 84.71903106144497, 84.48681531633649, 78.70678956168038, 83.14511122022355, 89.66223662240165, 73.76207624162946, 68.5520806993757, 63.9518312726702, 83.38128743852887, 92.18259143829346, 90.03057452610561, 92.45307786124093, 95.43511962890625, 90.99315016610282, 87.7855976649693, 83.81686305999756, 91.36143248421806, 94.89976787567139, 96.91866425105503, 95.84778009142194, 96.67123195103237, 89.3755053111485, 87.49047987801688, 91.51600211007255, 80.28935296194894, 14.983743361064366, 0.2664909102022648, 0.07375574550990548, 0.28536221757531166, 0.0874524430504867, 0.031992098316550255, 0.13134083444518702, 0.0949659902336342, 0.028918314326022352, 0.5957033719335283, 0.4638534869466509, 20.04614179474967, 72.15727860586983, 83.70244707380022, 51.98203754425049, 42.430748462677, 16.428523983274186, 23.68409698350089, 29.19445446559361, 64.52001326424735, 84.150404385158, 67.52421978541783, 77.69734137398856, 72.63566902705601, 11.763803090367999, 0.6033142549651009, 0.04384641721844673, 0.047215435188263655, 0.01770101936667093, 0.047274437200810225, 0.02378263883292675, 0.04457057014639888, 0.04709505629060524, 0.028235835322578038, 0.02774949025894914, 0.03521482752902167, 0.02800571865269116, 0.04858985197331224, 0.05838939041963645, 0.08374185394495726, 0.04411788550870759, 0.06876896774130208, 0.085234820975789, 0.012174654436031622, 0.04141008634386318, 0.053964307332145314, 0.012468722183257341, 0.08673341984727553, 0.06653870455920696, 0.09292700607329607, 0.0081228360068053, 0.04097773740068078, 0.020534430630505085, 0.021894318284466863, 0.09380113559642009, 0.01850447098591498, 0.04381563547732575, 0.06306868325918913, 0.0639010693079659, 0.030389517346130948, 0.017906729131937027, 0.20973028881209238, 0.10271773713507823, 0.13485859068376677, 0.25153808827911106, 0.1874314160751445, 0.1361971367150545, 0.1015800985374621, 0.08726504524903637, 0.09179879911243916, 0.15838711815220968, 0.14434288176042692, 0.1278210018894502, 0.15403969000492776, 0.13033277568008217, 0.10441723665488617, 0.07272522723568337, 0.14843527573559964, 0.10573303819234882, 0.27896914205380846, 0.2603043535990374, 0.15013333676116808, 0.1585981696844101, 0.12765898129769734, 0.12550916522741318, 0.2575946647141661, 0.13025809611592973, 0.15887996527765477, 0.4454180161867823, 0.40472882241010666, 0.1994963251054287, 0.14318538244281495, 0.1768971056278263, 0.24550509772130422, 13.507390124457222, 110.57446616036552, 103.71842847551618, 95.44741794041225, 80.55241176060268, 68.44407095227922, 45.803028856004985, 31.986956323896134, 58.706087248665945, 86.70133822304862, 91.42089516775948, 121.00439316885812, 74.73378876277378, 11.83478501864842, 0.28885094608579365, 0.18589666485786438, 0.4091942070850304, 0.24490779691508838, 0.22695868648588657, 0.10931746049651078, 0.6269237995147705, 1.4497435901846205, 2.3727637869971137, 3.0154897442885806, 3.5824392991406575, 18.880982739584788, 45.472284180777415, 82.94623988015312, 105.96003546033586, 103.92693696703229, 96.82794857025146, 99.76746041434151, 101.13827746255058, 101.17644391741071, 98.45734282902309, 100.52236134665353, 98.32034519740513, 101.45945794241769, 97.05786446162632, 97.97315066201347, 97.81744847978864, 95.76676409585136, 74.66627311706543, 56.097928047180176, 31.69735540662493, 11.936532701764788, 4.945425944668906, 6.062293282576969, 8.78021274294172, 12.540088840893336, 5.147332778998783, 1.5304902344942093, 8.372496792248317, 35.86740711757115, 56.15619911466326, 72.10083144051688, 81.68425246647426, 91.72167573656354, 88.43632425580705, 82.27352224077497, 92.22196687970842, 105.78671959468296, 81.99871403830392, 69.59955637795585, 71.61399895804269, 93.54174940926688, 100.6515144620623, 98.88098839351109, 102.13669885907854, 105.2399241583688, 101.72336442129952, 97.93335832868303, 90.07205527169364, 94.902984891619, 98.56881972721645, 99.35056155068534, 102.0029877253941, 104.70876911708287, 94.97560051509312, 91.20461164202008, 97.2622457231794, 76.48910522460938, 11.9815240246909, 0.9729475634438651, 0.5418587412152971, 0.5170452584113393, 0.23740846504058155, 0.23530481649296625, 0.4119599429624421, 0.18973744447742188, 0.1292023363390139, 1.1432733152593886, 1.0618137206350053, 34.860206672123496, 85.788421358381, 96.4334715434483, 93.84599018096924, 109.91430391584123, 62.3579284123012, 30.591764995029994, 20.665690081460134, 50.83505323954991, 73.83103711264474, 68.53102765764508, 89.31919710976737, 80.80640316009521, 11.466346366064888, 0.6804977761847633, 0.07084824331104755, 0.09472831298730203, 0.15436386689543724, 0.24225648918322154, 0.10121991857886314, 0.15767859188573702, 0.12543905898928642, 0.08620862729315247, 0.1873087640851736, 0.14427695529801504, 0.13730736928326742, 0.13428976120693342, 0.12308697162994317, 0.1556316688656807, 0.16799571684428624, 0.11401715688407421, 0.17703421041369438, 0.1064552708661982, 0.1386169282985585, 0.12234105808394295, 0.07873515438820634, 0.2502762031342302, 0.1713654167417969, 0.25326501418437275, 0.13003135685409817, 0.12567244789430074, 0.18889751311923775, 0.10220998259527342, 0.20216133924467222, 0.13188677015049116, 0.13672382916722978, 0.1291548388877085, 0.2373183827315058, 0.09604069470827069, 0.08780715401683535], [0.05870297537850482, 0.08063774622444596, 0.0009981291472545958, 0.04536774701305798, 0.01511769914733512, 0.02556466856705291, 0.05179000971838832, 0.010257006755896976, 0.026523511490917633, 0.017928019864484668, 0.02479549144793834, 0.019919267389923334, 0.024385700401450907, 0.029007704529379095, 0.03469074743666819, 0.060271870477923324, 0.05849409515836409, 0.0500471178841378, 0.007518288446590304, 0.0880300799118621, 0.035007575792925696, 0.039482677089316506, 0.018979666022849933, 0.09407522981720311, 0.07616689255727188, 0.09911727426307541, 0.11294356520686831, 0.012084098848780351, 0.09882671878273998, 0.14693857676216535, 0.08719225201223578, 0.08297621538596493, 1.7917213312217166, 78.1673036302839, 82.45669065202985, 73.1199654170445, 76.54124450683594, 50.86336367470877, 30.128358364105225, 38.468103953770225, 82.33449963160923, 81.85116904122489, 62.380065373011995, 88.47246183667863, 33.277844769614084, 2.022711370672498, 0.1154840953115906, 0.02882921589272363, 0.07351324387959071, 0.16129544137844018, 0.016258194377379756, 0.1258864849805832, 0.07496517989784479, 0.36231509117143496, 3.8931855389050076, 17.60075977870396, 54.549094676971436, 88.88642856052944, 104.45777239118303, 104.22727285112653, 100.8275123323713, 96.93732711247036, 94.72145625523159, 86.96080480303083, 80.05902712685722, 74.06913103376115, 74.66033240727016, 76.72760908944267, 78.42367131369454, 77.95910085950578, 76.14400209699357, 78.13382720947266, 82.60675784519741, 90.29482841491699, 89.82510934557233, 88.28372097015381, 79.27695873805455, 59.790437017168315, 35.473753452301025, 14.872283833367483, 3.349425813981465, 1.2916571987526757, 1.4111349476235253, 0.8189923646194595, 8.385958058493477, 19.0140529019492, 41.60094594955444, 59.15903336661202, 75.00763811383928, 85.94726412636894, 99.37527629307338, 102.15614686693463, 101.11121422903878, 91.58295495169503, 81.9356938770839, 80.02969878060478, 95.65218830108643, 87.72844178336007, 99.28391442980084, 97.28874615260533, 91.56114455631801, 84.4804299218314, 86.22042560577393, 80.23706776755196, 81.65004648481096, 80.9934834071568, 83.20829119001115, 91.01489802769252, 97.71407318115234, 95.11043725694928, 94.63397148677281, 83.436525617327, 83.80435630253383, 85.886960710798, 93.23835631779262, 51.31709146499634, 7.820156693458557, 0.2044750079512596, 0.28871263350759235, 0.025333661319954053, 0.11369652194636208, 0.03343433467671275, 0.04477205094216125, 0.032696736577366076, 0.26433601869004114, 0.10714146654520716, 0.19248887683664048, 5.252758664744241, 59.39224965231759, 81.5063785825457, 63.01995972224644, 80.70415346963065, 67.35354423522949, 45.885410172598704, 24.25195935794285, 15.763940947396414, 52.35467638288225, 51.11189726420811, 67.18441813332694, 51.64314610617501, 18.791368348257883, 1.7427275202104022, 0.2859617439763886, 0.08711572683283261, 0.06647241847323519, 0.06703953125647136, 0.12253100717706339, 0.041282993342195234, 0.033355207315513065, 0.01309264191825475, 0.03401464496606162, 0.06350025188710008, 0.09147756027856044, 0.04324751167691179, 0.08664844012154, 0.08647023646959237, 0.03156551013567618, 0.1463316407586847, 0.07695275824517012, 0.038930536181266816, 0.04874615251485791, 0.08491750407431807, 0.07214252850306885, 0.03659516113943287, 0.031507458072155714, 0.010334820303666805, 0.0361658079283578, 0.02620508348835366, 0.11364948589886938, 0.0634558078433786, 0.0269723929398294, 0.012647853731842977, 0.06966525821813516, 0.021302613695817332, 0.07545215769537858, 0.03685117579464402, 0.09974318210567747, 0.00776747619134507, 0.013549450352521879, 0.001552171225609657, 0.035967193943049224, 0.04668549933869924, 0.030159151314624717, 0.15935207637292997, 0.0654224194586277, 0.04696749170709934, 0.037760487358484945, 0.05907492791967733, 0.020191225921735168, 0.051407187046217065, 0.045854195553277216, 0.09333928395062685, 0.08080607719187226, 0.0360841801656144, 0.07780085237962858, 0.04011928882183773, 0.08610411254423005, 0.017553605937532017, 0.053570780770054886, 0.13994624625359262, 0.07931520004889794, 0.1919399012944528, 0.07523656676390342, 0.15514266224844114, 0.18912100898368017, 0.18034552915820054, 0.1547181164579732, 0.09855263134730713, 5.3865557823862344, 103.65251786368233, 90.06576020377022, 99.55276802607945, 103.8778965813773, 75.73052174704415, 45.4000472341265, 22.7539381640298, 28.42085419382368, 55.49037061418806, 63.97867911202567, 96.10386984688895, 35.01385218756539, 0.7974544689059258, 0.024968524663043872, 0.054858796298503876, 0.14855992261852535, 0.1413218674382993, 0.0832983838128192, 0.1331097073853016, 0.21133731757955893, 1.11696472125394, 7.549927353858948, 28.331552471433366, 69.75334085736955, 104.10893808092389, 116.73055621555874, 110.1764941896711, 103.92142704554966, 99.18352685655866, 96.71907724652971, 89.46753420148576, 81.05286271231515, 77.06632682255336, 78.21004894801548, 79.26641137259347, 79.48570346832275, 80.68341309683663, 79.2665433883667, 86.60470962524414, 90.85869557516915, 94.98270157405308, 94.38999938964844, 94.03361238752092, 85.96095207759312, 69.95221219744, 45.688334941864014, 21.016353504998342, 5.7931951965604505, 1.918402190719332, 0.37571987616164343, 1.2839237451553345, 12.511512637138367, 25.748125382832118, 49.63371317727225, 67.36907345908028, 84.93275765010289, 93.26646178109306, 104.80393164498466, 105.40697969709123, 110.26243645804269, 102.26836027417863, 94.65090424673897, 92.54074328286308, 98.06404699598039, 94.30705179486955, 101.67335823604039, 97.50525896889823, 90.82130731855119, 88.30592046465192, 88.01842485155377, 82.22396074022565, 85.92997700827462, 85.36680466788155, 86.98053073883057, 93.88939557756696, 100.14425427573067, 99.77590942382812, 96.64045143127441, 85.4376346043178, 90.01340552738735, 94.71469565800258, 97.4316497530256, 60.66272776467459, 14.9908652646201, 1.510172724723816, 0.3278521347258772, 0.201720372906753, 0.10740196292421647, 0.07659154691334281, 0.09335244074463844, 0.23635084607771464, 0.1555763411202601, 0.03680828559611525, 0.3329631861831461, 3.3233305513858795, 57.70025907244001, 88.67615522657121, 69.51241901942662, 55.677770478384836, 28.080639123916626, 22.562688997813634, 24.288281066077097, 28.779817240578787, 81.13808931623186, 69.12326431274414, 76.05847672053746, 71.89223957061768, 35.21089615140642, 5.1350105830601285, 0.3632602904524122, 0.07589105450149093, 0.11657072843185493, 0.04390740394592285, 0.10162475292703935, 0.06069368177226611, 0.04347237478941679, 0.034213811957410405, 0.0815054839476943, 0.04228209883772901, 0.05551844768758331, 0.043061114714613984, 0.12947049337838376, 0.22442176618746348, 0.055096025711723735, 0.054898171685636044, 0.00799024263064244, 0.06878151385379688, 0.05794213406209435, 0.09701281147343771, 0.06598865014633962, 0.06683249665158135, 0.03358215353052531, 0.04500248482716935, 0.06774538409497056, 0.02943107984693987, 0.028026069614237974, 0.01778083204823945, 0.060884865799120495, 0.035698049635227234, 0.09203697168933493, 0.04405584705195256, 0.0507188879086503, 0.017198036624384776, 0.2173234485089779, 0.131813447656376, 0.08087742514908314, 0.13337776942976884, 0.19005635593618664, 0.14828120757426533, 0.20359602011740208, 0.34373547243220465, 0.15895860748631613, 0.21510816738009453, 0.14356315002909728, 0.1749935977693115, 0.13494073413312435, 0.1322147739785058, 0.18090879464788095, 0.1540115579430546, 0.13915613293647766, 0.09397874892290149, 0.11039667722902127, 0.23261654217328342, 0.1737569948392255, 0.14670311153999396, 0.15848834200629167, 0.20628375160906995, 0.1803129594773054, 0.30736433980720385, 0.1714684862111296, 0.2626623713544437, 0.255372408245291, 0.2579045923692839, 0.2949835184429373, 0.17618072192583764, 5.078539099012103, 117.43378339494977, 106.25962788718087, 97.84135723114014, 98.55668817247663, 63.36033112662179, 37.38758611679077, 50.04775980540684, 103.74834741864885, 110.207003729684, 83.40429987226213, 108.21309307643345, 45.3791435786656, 2.5943663758890967, 0.1997430268675089, 0.13086332221116337, 0.2696119270154408, 0.21801051949816092, 0.2875719347170421, 0.35605416713016375, 0.35900880715676714, 2.424451002052852, 7.166754177638462, 19.7340304510934, 60.323454175676616, 104.12441866738456, 119.10446384974888, 112.32207706996373, 108.2856948035104, 102.97922352382115, 100.82548345838273, 94.71477903638566, 87.67332172393799, 83.39111913953508, 83.76639829363141, 86.39925834110805, 84.39732251848493, 86.947144644601, 86.78978879111153, 90.40071896144322, 93.92066247122628, 96.95983232770647, 99.76434067317417, 99.87833281925747, 90.02661405290876, 69.13495813097272, 44.575497559138704, 20.20577665737697, 5.7822582977158685, 4.547303284917559, 3.196029999426433, 2.703832204852785, 11.880755169051033, 28.126318318503245, 59.158616474696565, 76.46974059513637, 89.79142447880336, 98.00548063005719, 110.83200808933803, 109.15968091147286, 111.66516658238002, 101.27433013916016, 93.09160341535295, 103.07048116411481, 108.17435686928886, 104.69424738202775, 113.55620220729283, 107.65325587136405, 98.59832177843366, 95.7139230455671, 94.09570843832833, 89.00393649509975, 91.1034528187343, 89.30146530696324, 93.0286944253104, 101.67659609658378, 106.46860885620117, 106.06565502711705, 106.84978703090123, 92.3066793169294, 97.7076530456543, 98.45288903372628, 101.13322612217495, 60.15584972926548, 10.253468820026942, 1.0740986785718372, 1.0125569637332643, 0.31714553066662377, 0.17466995013611658, 0.3079850636422634, 0.29130670002528597, 0.41112081227558, 0.3679799900523254, 0.17097405131374085, 0.7802888357213565, 8.963738117899213, 75.10230731964111, 93.86982250213623, 85.40561730521065, 116.5517304284232, 86.54442705426897, 57.44387401853289, 30.969774791172572, 19.422527074813843, 67.21987479073661, 68.57277243477958, 84.39011028834751, 84.19964626857212, 35.13343415941511, 3.92599276133946, 0.45206065688814434, 0.14888157535876545, 0.22222865958298954, 0.20550928530948503, 0.2538507256124701, 0.15112337363617762, 0.15248496271669865, 0.13353379177195684, 0.15937775213803562, 0.13945747033825942, 0.14347263345760958, 0.16761295524026665, 0.1816929911396333, 0.20330943406692573, 0.13318659897361482, 0.22631067197237695, 0.14004964141973428, 0.09991494646029812, 0.10495245150689568, 0.1596438328602484, 0.12017243302294187, 0.20852823688515595, 0.1025893786656005, 0.12331289664975234, 0.165997444785067, 0.08161877893975802, 0.16563294934374945, 0.11994848932538714, 0.16314477500106606, 0.19000534367348465, 0.2411078651036535, 0.12064809964171477, 0.1361819782427379, 0.09942973285381283], [0.03774112196905272, 0.02126371837221086, 0.017267818862040128, 0.04714175307058862, 0.007556773256510496, 0.02829598236296858, 0.03347953189430492, 0.06197856246892895, 0.06360727721559149, 0.09959787383143391, 0.037473463652921576, 0.03495587142450469, 0.07878227864525147, 0.031682469216840606, 0.025326523131557872, 0.07786217837461404, 0.05755090434104204, 0.0464588516790952, 0.038442398088851144, 0.023084421209724884, 0.016078306262248328, 0.02194155958880271, 0.017273608462086747, 0.04518177752782192, 0.042457269438143284, 0.03499559286449637, 0.04302628890478185, 0.122373369921531, 0.10982363404972212, 0.08319766886000123, 0.09034697844513825, 0.455269204718726, 52.58768769672939, 84.73703384399414, 83.12619127546037, 56.78001880645752, 38.84749296733311, 33.37451505661011, 51.88574593407767, 87.68873282841274, 77.4389100755964, 70.54983370644706, 84.30038819994245, 24.497414895466395, 0.5613573949251855, 0.024066977236153822, 0.07924888003617525, 0.07233105267265014, 0.040324121580592225, 0.11968057655862399, 0.060406736098229885, 0.02794216706284455, 3.7592468517167226, 23.15261537688119, 57.302492073604036, 93.45919786180768, 94.93730899265834, 89.84797586713518, 84.53658526284354, 93.81460516793388, 94.88749735695976, 94.4236842564174, 82.89931174686977, 72.83577714647565, 70.5259041104998, 74.61407824925014, 77.68436213902065, 73.58875342777797, 69.6679197038923, 68.21471091679165, 75.86073793683732, 83.08949089050293, 92.01444503239223, 88.25920077732631, 84.56434331621442, 80.22833388192313, 81.51978860582624, 85.70004722050258, 77.95780154636928, 49.9381102834429, 29.704966408865793, 12.86371682371412, 4.433632927281516, 8.425759945596967, 35.516526562826975, 41.342858586992534, 55.10706976481846, 75.51636437007359, 86.02286052703857, 100.06211962018693, 102.20569447108677, 102.20940480913434, 104.20751217433384, 112.77812208448137, 113.96221324375698, 93.315995488848, 81.73230620792934, 82.02456828526088, 96.59353719438825, 95.26855741228376, 86.23579502105713, 86.51316710880825, 80.15284170423234, 76.0119376863752, 75.546950340271, 77.2286158970424, 75.79347937447685, 82.39651230403355, 88.66780349186489, 87.02846636090959, 77.14066559927804, 71.24940613337925, 76.91118049621582, 89.24187755584717, 85.55701855250767, 79.11377334594727, 65.27482386997768, 28.126754317964824, 4.234938766275134, 0.28556428530386513, 0.06337946586843048, 0.1420701965689659, 0.12974646714116844, 0.06404435554785387, 0.05303247519103544, 0.10295616755528109, 0.17160795229886258, 0.1454303969762155, 0.8861696113433156, 39.478219168526785, 83.86265168871198, 61.73086043766567, 70.57295036315918, 96.14831747327531, 62.55927331107003, 37.73456873212542, 21.42869782447815, 37.50005660738264, 55.771376609802246, 62.7501403263637, 66.65672329493931, 55.41112640925816, 4.20426116670881, 0.07040729054382869, 0.14088333025574684, 0.2015635906053441, 0.01802201392794294, 0.04280509327405265, 0.06591865925916604, 0.02356426081886249, 0.06366383989474603, 0.012466334588160473, 0.10623044507311923, 0.052920876536518335, 0.009551863834661032, 0.028620142290102582, 0.10261240135878325, 0.07783498947641679, 0.07251368037291936, 0.07351821754127741, 0.024094035516359975, 0.04318617211122598, 0.014108793909794517, 0.06396972348115273, 0.09193428219961268, 0.11265950330666133, 0.08133879503501312, 0.043272156068789105, 0.060283581992345195, 0.02752705290913582, 0.03556504998622196, 0.012848248023406734, 0.006913142927390124, 0.03755247566316809, 0.05571480554395488, 0.061602654068597724, 0.023320668443505253, 0.04766258637287787, 0.04416842618957162, 0.06535331745232854, 0.06837551242538861, 0.05147479966815029, 0.028717077802866697, 0.048447519075125456, 0.10073677450418472, 0.06559047222669635, 0.1118337329743164, 0.07788022740611009, 0.07561830378004483, 0.08958320585744721, 0.040391920799655576, 0.04518114649025457, 0.03249331856412547, 0.07585727024291243, 0.04409449640661478, 0.02816366633799459, 0.053952935085232766, 0.02458730502985418, 0.017249837684045945, 0.09514875364090715, 0.03656166525823729, 0.0312777366489172, 0.05696127098053694, 0.1561703442462853, 0.14109838514455728, 0.0835157660767436, 0.09096533419298274, 0.4457077777811459, 74.36813286372593, 93.16159261975969, 101.5509101322719, 82.905440058027, 64.21164526258195, 41.8692923273359, 21.56872139658247, 38.3511449268886, 71.36532987867082, 82.36785793304443, 92.60307557242257, 25.745669194630214, 0.1222125164100102, 0.012462745137911822, 0.03798965916835836, 0.027910048607736826, 0.028875980526208878, 0.24483416229486465, 0.04018698626064828, 0.2525035893278462, 7.340642401150294, 32.78501599175589, 69.8333215713501, 100.38200078691754, 98.86081082480294, 90.65584291730607, 87.13784490312848, 96.34276975904191, 99.0276231765747, 97.14823968069894, 86.36510099683488, 74.5584579195295, 74.53838457380022, 82.06124782562256, 83.86699431283134, 80.07344463893345, 74.38883154732841, 73.62746184212821, 82.92191423688615, 88.90568896702358, 95.3462313243321, 91.7406165259225, 88.93685858590263, 84.72490923745292, 86.37094443184989, 91.6244843346732, 86.6609136036464, 61.899514062064036, 39.796248640332905, 18.968034982681274, 8.564573662621633, 13.902236274310521, 48.44338948386056, 50.349499225616455, 64.1780229296003, 83.91773700714111, 92.0297658102853, 103.05895410265241, 105.29172992706299, 104.60234355926514, 106.90152331760952, 115.6317264011928, 120.77200371878487, 102.36899798257011, 89.83280100141252, 89.80445235116142, 96.80973734174455, 95.2487689426967, 86.21902901785714, 86.65771743229458, 79.42991638183594, 79.76847430637905, 77.60167857578823, 80.73580251421247, 78.99962139129639, 84.55020373208183, 90.92371681758335, 89.47034127371651, 79.96950653621128, 77.09291063036237, 81.78218037741524, 91.30955028533936, 92.76800496237618, 90.88916342599052, 74.40456226893834, 37.95509760720389, 8.720556378364563, 0.7338424623012543, 0.2686124992157732, 0.2774179024355752, 0.10371912590094975, 0.10260848621172564, 0.1040544511218156, 0.06197310026202883, 0.13272514087813242, 0.16931979650897638, 0.295783918350935, 36.076631273542134, 89.54201889038086, 68.52460752214704, 65.4892383302961, 61.42935030800955, 30.581610202789307, 14.006611245019094, 31.377634048461914, 66.74107442583356, 79.86646475110734, 73.21103545597622, 77.20836189814976, 76.02465983799526, 10.335561786379133, 0.14507462749523775, 0.17171931346612318, 0.03313046633931143, 0.017787342591743385, 0.06478707319391624, 0.07062856759876013, 0.0157194698029863, 0.05423835405547704, 0.025509627502677695, 0.16667266855282442, 0.06514153988765818, 0.07029048752571855, 0.016045209020376205, 0.16014752297529153, 0.004593476395322276, 0.04670797920386706, 0.04188716431547489, 0.0847299298537629, 0.07906474598816463, 0.043463536870798895, 0.04538766201585531, 0.017687714991292784, 0.13434914659176553, 0.07326118847621338, 0.06273910522993122, 0.06467512170118944, 0.03777786464031253, 0.010929981180067574, 0.01632839221773403, 0.014716871548444033, 0.09377172110336167, 0.048374647806797705, 0.026902919435607534, 0.19364052718239172, 0.06399773340672255, 0.1001945910975337, 0.16159966933940137, 0.17239882557519845, 0.12559968179890088, 0.10948631393590144, 0.14988146456224577, 0.2474830544420651, 0.1896331129329545, 0.29057898478848593, 0.14325326308608055, 0.2322191106421607, 0.18886383064091206, 0.1143896183265107, 0.08674559955086027, 0.17682177467005594, 0.22838104516267776, 0.15287212122763905, 0.15002531398619923, 0.1147530416824988, 0.10456383414566517, 0.12474026291498116, 0.1443628849727767, 0.19464561396411487, 0.08168653744672026, 0.14594928627567633, 0.35338565175022396, 0.19074502826801368, 0.17625411227345467, 0.13680091074534825, 0.6507573149033955, 84.30439731052944, 108.28588240487235, 104.3079205921718, 74.03509180886405, 49.43244123458862, 43.62027658735003, 65.86048752920968, 123.50899641854423, 108.59268011365617, 89.09447847093854, 104.168185370309, 34.85783386230469, 1.3246106590543474, 0.14189043907182558, 0.22962235712579318, 0.1728238056280783, 0.14724946793700966, 0.3147322530192988, 0.3397490249148437, 0.4640385370169367, 5.9822856443268915, 27.664688689368113, 63.79071644374302, 108.81083965301514, 108.74812521253313, 99.54197747366769, 91.24926771436418, 102.59361934661865, 104.30361270904541, 105.53556306021554, 91.8309292112078, 82.2363841193063, 77.38656234741211, 82.90949780600411, 86.44484547206334, 83.3520563670567, 79.04030309404645, 77.20007964542934, 85.93003259386334, 94.50752816881452, 99.7321149281093, 96.89715957641602, 97.70940399169922, 94.19699927738735, 91.68207100459507, 99.0237877709525, 89.13044234684536, 63.47972897120884, 38.09354393822806, 16.552929741995676, 7.851734519004822, 11.675665191241674, 47.218550613948274, 60.53788948059082, 71.02903011866978, 88.71434252602714, 94.54909229278564, 107.37825311933244, 106.74983719417027, 106.49874319349016, 109.47217614310128, 116.98945999145508, 121.70032473972866, 105.23002297537667, 93.75863742828369, 97.33668177468437, 106.053238596235, 99.92669922964913, 93.0887199129377, 95.23510183606828, 87.29433223179409, 85.64785930088588, 85.75334685189384, 86.07769571031842, 82.27863611493791, 89.70302254813058, 97.90293216705322, 96.6916527066912, 86.83379868098667, 81.69158976418632, 85.62356839861188, 96.36726910727364, 97.15664005279541, 92.501284463065, 70.86988162994385, 31.925259794507706, 6.670039619718279, 1.3600271471909113, 0.5277745798230171, 0.32644422884498325, 0.19571654578404768, 0.07784547284245491, 0.41688369161316324, 0.2834083895598139, 0.2560910311128412, 0.42254240225468365, 1.71115414585386, 54.129656246730256, 94.4741907119751, 73.29852022443498, 98.90809331621442, 129.89251491001673, 83.37486035483224, 48.917468547821045, 27.83192835535322, 49.31120559147426, 74.72203241075788, 75.02521705627441, 93.91814722333635, 83.99269417354039, 9.608455385480609, 0.35171083733439445, 0.27960970625281334, 0.2727403262896197, 0.1558332344783204, 0.1707044422094311, 0.13510645952607903, 0.10693012324294873, 0.16536210530570575, 0.1747975011489221, 0.2136400347309453, 0.12116063785340105, 0.12133309431374073, 0.08492990090910878, 0.2476286409156663, 0.21264268324843474, 0.21540259729538644, 0.11508453318050929, 0.18519803163196358, 0.19142667097704752, 0.1299611556210688, 0.23411485606006213, 0.18785365484654903, 0.2650655524006912, 0.19155967741140298, 0.22515883163682052, 0.11419044115713664, 0.16293508053890296, 0.09178109613380261, 0.06637488584965467, 0.07666707464626857, 0.18046587412910803, 0.1940022949129343, 0.07619375575866018], [0.0633454169811947, 0.0549759080500475, 0.04945580514946154, 0.06255092711320945, 0.042792866073016605, 0.03567200746121151, 0.00592338976483526, 0.0837653787540538, 0.03834815975278616, 0.09659162443131208, 0.0606742621000324, 0.036237091424741914, 0.006950809678528458, 0.04558713434796248, 0.08820360167218105, 0.03168072198916759, 0.028434003171111857, 0.03590741840058139, 0.033580202742346694, 0.029984771207507168, 0.09072852547147445, 0.006819650555761265, 0.050676021458847184, 0.006446042813227645, 0.04987083787896803, 0.05293999765334385, 0.05474274306158934, 0.12255137679832322, 0.07948175325457539, 0.2314331228179591, 0.12808355422956602, 42.30253682817732, 82.28263827732631, 83.73587485722133, 74.85542392730713, 42.48152242388044, 46.39270509992327, 66.62873595101493, 83.69011402130127, 70.60831669398716, 74.86948013305664, 92.60946096692766, 17.318244286945887, 0.4083374887704849, 0.04414703876578382, 0.0059620823761049125, 0.0424347217194736, 0.05915916804224253, 0.033479335119149516, 0.14407327265611716, 0.15068319439888, 12.490546447890145, 48.33294786725725, 80.06769847869873, 86.55477292197091, 77.07733971732003, 72.99575941903251, 77.36293152400425, 80.49037824358258, 82.56646524156842, 82.99158382415771, 73.3822112764631, 69.08931541442871, 72.78188691820417, 83.2203254699707, 88.46309566497803, 91.89549882071358, 86.07682718549455, 82.40760857718331, 77.21572698865617, 83.22329929896763, 87.17131437574113, 85.59624808175224, 84.77631895882743, 82.998288835798, 73.0576400756836, 77.44687965938023, 83.26382119315011, 87.21911103384835, 83.49425819941929, 73.64369978223527, 59.36048248835972, 41.1847870690482, 51.97048616409302, 78.89910875047956, 66.37053394317627, 70.9373277936663, 78.27275644029889, 90.24644115992955, 97.3813031060355, 101.31323310307094, 97.57582487378801, 95.23491423470634, 95.16643278939384, 100.1161140714373, 94.46032210758754, 96.4865140914917, 89.75554398127964, 94.44494574410575, 96.28656578063965, 89.38268974849156, 82.09982422419957, 76.45633057185582, 71.92321463993618, 73.13728032793317, 71.18369007110596, 76.58620629991803, 72.03710951123918, 72.26892920902797, 71.77273055485317, 71.23269571576799, 74.71106815338135, 81.5352622440883, 82.33297797611782, 88.31904561179024, 92.1661797932216, 82.21267686571393, 65.69641971588135, 39.10025453567505, 4.644393937928336, 0.4884357792990548, 0.05014681164175272, 0.12597658086035932, 0.030815311641033207, 0.02070044948985534, 0.06431049055286817, 0.07282922629799161, 0.07864110943462167, 0.23888626002839633, 0.23239078000187874, 24.618284021105083, 90.6179335457938, 68.13378524780273, 110.1070955821446, 118.74293518066406, 114.20212064470563, 37.60398428780692, 15.852622543062482, 34.503291606903076, 49.73983301435198, 58.247030190059114, 72.06749398367745, 57.50695323944092, 2.774086309330804, 0.21239621218826088, 0.20831136352249555, 0.056731722583728175, 0.13112778802003178, 0.06492113135755062, 0.014945588739854949, 0.06103404850832053, 0.06341735526387181, 0.047564035946769376, 0.03151987865567207, 0.016033405903726816, 0.08777741382696799, 0.019473624249388064, 0.02297533313477678, 0.09099360874720983, 0.042016150429844856, 0.05407794498439346, 0.04892278875091246, 0.07535213484827961, 0.07323948214096682, 0.009797344233707657, 0.04869532006393586, 0.13396272089864525, 0.030477574228176048, 0.006274382359281714, 0.04788631293922663, 0.059088654683104584, 0.020134683598631194, 0.04730428256360548, 0.033273677940347364, 0.03588049752371652, 0.020382645739508525, 0.01907799592507737, 0.015956745017319918, 0.027606275265238116, 0.017656843344281827, 0.038514142989047935, 0.004128871593690876, 0.0382230820001236, 0.06161991599947214, 0.024200913263484836, 0.05584604100191167, 0.1363112120223897, 0.05714058064456497, 0.022330000530928373, 0.03346186623509441, 0.06204614455678633, 0.034536496070878844, 0.005135781090107879, 0.022338090364688208, 0.06764131039381027, 0.04682731655027185, 0.10581857431679964, 0.04208926257810422, 0.007864067347587218, 0.05401488533243537, 0.07272412122360297, 0.1177557355591229, 0.08695654251745769, 0.14139198724712643, 0.12324089051357337, 0.4188810544354575, 1.2449799605778284, 67.90854549407959, 93.10356821332658, 100.34491130283901, 96.3635379246303, 66.30954265594482, 42.09914915902274, 23.44751603262765, 52.444641658238, 77.95420237949916, 85.7102471760341, 96.28457164764404, 16.34372295652117, 0.7204615346023014, 0.03198836976662278, 0.05423660682780402, 0.04081503827390926, 0.016597266807886105, 0.0649416706125651, 0.11167700495570898, 0.7680658144610268, 20.828630549567087, 61.88361658368792, 87.99264008658272, 92.84121813092912, 82.79096153804234, 78.63065120152065, 84.91781902313232, 85.69017383030483, 86.24238191332135, 82.75227396828788, 76.5229776927403, 71.05649634769985, 77.81307056971959, 91.57231031145368, 92.99165357862199, 97.91536944253104, 92.47370706285749, 85.93285356249127, 82.8847622190203, 86.89743723188127, 92.30792304447719, 87.96238762991769, 88.10838317871094, 86.80867399488176, 75.96412713187081, 80.50280857086182, 86.45322499956403, 89.54531233651298, 85.90110029493059, 75.85014193398612, 68.91602039337158, 54.73463937214443, 64.48709964752197, 90.03493799482072, 76.85533782414028, 77.10271453857422, 85.46589987618583, 92.13135542188371, 99.33434445517403, 101.81757504599435, 102.81445394243512, 99.89752374376569, 101.33418192182268, 107.48655469076974, 101.45826285226005, 97.88847296578544, 95.82020963941301, 98.23256860460553, 95.23734610421317, 90.34360476902553, 85.41083540235246, 80.45175320761544, 76.5810854775565, 76.59542655944824, 75.83375808170864, 80.00207969120571, 74.91388607025146, 75.43047073909214, 74.36331081390381, 76.18125138963971, 76.57022544315883, 83.18521622249058, 86.64443942478725, 90.62830025809151, 93.2744174684797, 88.16879776545933, 75.53978674752372, 46.42133167811802, 7.6719620398112705, 0.4828563758305141, 0.49564241830791744, 0.888525593493666, 0.2712653268660818, 0.03281059136082019, 0.09477368662399904, 0.14347656896071775, 0.05819733786795821, 0.1294472331979445, 0.3089032300880977, 21.10547457422529, 93.20027324131557, 71.32752473013741, 103.63704422542027, 115.57611301967076, 88.83637373788017, 14.303939427648272, 20.684090648378643, 60.76615864889962, 73.06986890520368, 81.19652366638184, 80.0445123400007, 78.34997871943882, 8.79559692314693, 0.37244667751448496, 0.14034164217965944, 0.10964519291051797, 0.08448340451078755, 0.0706603094669325, 0.074086619541049, 0.08683239775044577, 0.07890681017722402, 0.05453198669212205, 0.024551888894555823, 0.010397795986916338, 0.047843582196427245, 0.03762329775573952, 0.00874483463953116, 0.016895428665780594, 0.028343642662678446, 0.07725412957370281, 0.016180934683818902, 0.06844792568257876, 0.02219774218143097, 0.019950634367497902, 0.021449638663658073, 0.061258677526244094, 0.05032738677359053, 0.0373982955435557, 0.04118874482810497, 0.09082316753587552, 0.04065558593720198, 0.06466350518167019, 0.05662811367905565, 0.05220901866310409, 0.039727482346019576, 0.14836027047463826, 0.14017426116125925, 0.14655339957347938, 0.22073155348854406, 0.12089339005095617, 0.1978300873722349, 0.12149303858833653, 0.20855505258909293, 0.18711379383291515, 0.14758138012673172, 0.24733849934169225, 0.17011748227689946, 0.15142042269664152, 0.1274526659399271, 0.18540317990950175, 0.12439632708472864, 0.11958412959107331, 0.16502514481544495, 0.10676701699516603, 0.18624555399375303, 0.19894196199519293, 0.12873364506023272, 0.12805521860718727, 0.11595985692526613, 0.22714003175497055, 0.1687970802720104, 0.10765690888677325, 0.3315915683550494, 0.2307138214153903, 0.35322942584753036, 0.7487033563000816, 72.95188154493059, 109.41355419158936, 100.47737176077706, 95.92858069283622, 52.16724872589111, 59.96147387368338, 82.5574951171875, 121.9485421861921, 101.26187201908657, 90.75891944340297, 110.79833711896623, 24.857277733939036, 0.9021094303045953, 0.10347304839108672, 0.16553676021950586, 0.1841577153120722, 0.12869517212467535, 0.2809532327311379, 0.37315582803317476, 0.8610964396170208, 17.645912647247314, 56.21771846498762, 93.94337613242013, 103.72997638157436, 90.05612305232457, 80.80534703390938, 89.16062532152448, 91.90343366350446, 94.77036462511334, 91.26973015921456, 84.38757419586182, 77.02631909506661, 81.45298862457275, 94.49568843841553, 98.46236637660435, 103.55514580862862, 95.37115451267788, 91.63551112583706, 85.45044013432094, 92.73614052363804, 97.55722454616001, 93.89765698569161, 94.3950993674142, 95.30191571371896, 82.28047043936593, 87.29999501364571, 93.041152545384, 98.52969442095075, 95.02586378370012, 89.33822127750942, 74.82870115552629, 55.652506828308105, 69.72348444802421, 97.87203352791923, 84.20565646035331, 84.74694892338344, 89.35174247196743, 96.12502711159843, 104.24417781829834, 104.01179531642369, 104.66206332615444, 102.73840590885708, 102.2877596446446, 107.47558348519462, 106.40827069963727, 106.88604273114885, 101.066314969744, 105.08900233677456, 102.91176346370152, 98.17122295924595, 88.77828679765973, 84.13536153520856, 78.995772089277, 81.2254559653146, 78.99684211186, 86.23462077549526, 78.85186100006104, 80.31795869554792, 79.89345850263322, 78.57380104064941, 81.77647590637207, 89.75785773141044, 91.63307925633022, 96.90137713296073, 98.64205374036516, 95.16971928732735, 77.601852280753, 45.05259561538696, 5.780282403741564, 1.4650814128773553, 0.9942107881818498, 0.9308323604719979, 0.24223054200410843, 0.1144196909985372, 0.15449007440890583, 0.338522803570543, 0.2903215486024107, 0.3502937305186476, 0.6349833841834749, 36.396536758967805, 104.56031390598842, 75.44898768833706, 120.26627213614327, 140.6183101109096, 146.93944767543246, 50.75949157987322, 21.58085642542158, 43.071907384055, 67.44872760772705, 74.92921379634312, 88.8290433883667, 88.96871607644218, 9.376060724258423, 0.6304274829370635, 0.1941940760506051, 0.29800799329366, 0.2333195587354047, 0.16136197852236883, 0.14576336768056664, 0.2239974375282015, 0.19561791393373693, 0.16861466291759694, 0.07362559570797853, 0.08241351308034998, 0.1857895648905209, 0.12468007685882704, 0.1275539712182113, 0.33153367574725834, 0.1545119232365063, 0.12018797147486891, 0.1657348788742508, 0.20065926627389022, 0.18569461070001125, 0.12259450448410851, 0.20374212227761745, 0.22839988129479544, 0.15955544688871928, 0.14221502308334621, 0.14536280131765775, 0.17731007561087608, 0.1421912336455924, 0.1859507169574499, 0.18926138430833817, 0.1300655278776373, 0.15428108562316212], [0.04901736635448677, 0.05351254889475448, 0.0364686856046319, 0.07520977141601698, 0.025924716211323227, 0.03167245403996535, 0.016756953239174824, 0.05077421904674598, 0.051411319324480634, 0.07843889921371426, 0.031844645871647766, 0.02814994296724243, 0.02807498350739479, 0.034359710557120185, 0.07649621274322271, 0.052319311137710295, 0.07529155524181468, 0.044219448630298884, 0.042898117032434256, 0.01716147206856736, 0.050804505457303355, 0.017817025106134157, 0.18525392934679985, 0.03339486090200288, 0.06331582606903144, 0.022208534280902574, 0.06885906362107821, 0.12410694546997547, 0.34508993689502987, 0.8254988640546799, 53.5883012499128, 90.14328820364815, 81.11347879682268, 67.93180806296212, 68.07476724897111, 32.20729759761265, 96.89028780800956, 104.27616732461112, 73.4392420904977, 93.5717030933925, 102.46810013907296, 16.44100989614214, 0.2343539446592331, 0.07881704677960702, 0.21599681755261763, 0.04254922789654561, 0.0342556334632848, 0.013774435601330228, 0.1383116418229682, 0.29320002985852106, 20.930991411209106, 62.27509893689837, 78.4438419342041, 80.22825050354004, 78.07019560677665, 75.52091544015067, 70.99194758278983, 68.67947592054094, 67.92595767974854, 68.04326411655971, 63.62326485770089, 69.96610859462193, 75.5985198702131, 86.73151424952916, 90.534152167184, 95.93215206691197, 88.7957684653146, 91.06031840188163, 87.18799700055803, 80.85270595550537, 81.3829368863787, 88.17820562635148, 88.17832374572754, 85.3544785635812, 78.62546784537179, 72.58742073604039, 75.75380516052246, 81.89207308632987, 86.43892560686383, 85.0741673878261, 78.98280675070626, 76.94376754760742, 85.06894929068429, 72.32586969648088, 79.46154458182198, 78.40121473584855, 76.29231834411621, 78.01877198900495, 82.9228036063058, 93.27559171404157, 93.14691802433559, 87.80855451311383, 88.62191064017159, 91.68000044141496, 103.318448475429, 98.44778210776192, 80.42862265450614, 75.23716490609306, 89.12789235796247, 87.65147658756801, 83.72655732291085, 87.3021628516061, 88.85283402034214, 86.779283114842, 78.24175357818604, 72.64549377986363, 70.12598664419991, 70.97564710889543, 74.67037950243268, 75.69971343449184, 77.20181669507707, 77.4016329901559, 74.21757234845842, 72.46700150626046, 73.68315860203334, 75.52759960719517, 79.64740194593156, 76.17787456512451, 63.74659538269043, 28.031593527112687, 2.0071467544351305, 0.23444530261414392, 0.457397036254406, 0.37320308121187346, 0.14721946311848505, 0.0598118237352797, 0.06464805493929557, 0.04267060763335653, 0.06943884465311255, 0.12796514986881188, 0.2855966921363558, 17.087538037981304, 91.53456769670758, 80.11652347019741, 83.5369826725551, 79.82785361153739, 84.79914379119873, 65.16008131844657, 25.83476768221174, 16.79275550161089, 35.60690525599888, 59.285567011152, 62.24923774174282, 54.13522522790091, 6.989360587937491, 0.7103080451488495, 0.042214262299239635, 0.07465041428804398, 0.03514346939378551, 0.013300646828221423, 0.01789903115215046, 0.07901948091707059, 0.041687060945800374, 0.09124878541167293, 0.030896857979574373, 0.018618890649772117, 0.10393312227513109, 0.02211203981590058, 0.0452605011606855, 0.018960526246311407, 0.014616170166326421, 0.06318891287914344, 0.03609523010839309, 0.08033649024686643, 0.01989439399247723, 0.0661158279648849, 0.020890245912596583, 0.032118427966322215, 0.08267214348805801, 0.015783353874992048, 0.0356043880539281, 0.00403975831743862, 0.02984684200159141, 0.015451699528577072, 0.007534826041332313, 0.047537040431052446, 0.026183105739099637, 0.031011822167783976, 0.040919804080788574, 0.017084315851596848, 0.020235992269590497, 0.036700015155864615, 0.03155973580266748, 0.021600875637627075, 0.06826725216316325, 0.11964720620640687, 0.04937340724947197, 0.04055645875632763, 0.02778980541708214, 0.08038167389375822, 0.05496549932286143, 0.01726906736647444, 0.02897950800667916, 0.028115836404530064, 0.03347717059244003, 0.007361530742075826, 0.06583994919700281, 0.010973406573092299, 0.11719916042472635, 0.026324719390166656, 0.14110742323100567, 0.07925933626081262, 0.010071480862929352, 0.13744159708065645, 0.6131706546459879, 5.395478572164263, 83.53735787527901, 99.26583521706718, 103.31041635785783, 98.99589075360979, 103.48742866516113, 28.061180693762644, 51.54810517174857, 85.48575782775879, 77.70609610421317, 105.6816211427961, 105.63021142142159, 16.462043830326625, 0.41718240986977306, 0.28843665974480764, 0.10805247444659472, 0.012380046138007725, 0.18211748264729977, 0.04222655396110245, 0.13583445974758693, 1.7393173660550798, 30.756336552756174, 71.17671407972063, 86.48627063206264, 87.58449595315116, 83.3579762322562, 82.2059440612793, 75.51580156598772, 72.59029729025704, 71.19319520677838, 74.73075239998954, 70.23520537785122, 73.62835121154785, 81.40519196646554, 93.2916351045881, 97.7167134966169, 99.90345055716378, 92.43606172289167, 94.66134738922119, 93.98088250841413, 86.04235022408622, 87.54423809051514, 91.46391146523612, 90.86620657784599, 87.33493750435966, 82.54485634395054, 73.7576571873256, 80.1953090940203, 85.71902275085449, 88.06030859266008, 85.76107324872697, 81.15766933986119, 79.73973655700684, 89.80363941192627, 80.36314977918352, 89.38057054792131, 84.30029787336076, 81.54719230106899, 83.8065241404942, 87.24573653084892, 97.14284093039376, 96.99544184548515, 92.4021475655692, 95.00001648494175, 99.74371147155762, 105.91600472586495, 103.0607328414917, 87.05445957183838, 80.13802119663784, 92.80934674399239, 93.93089021955217, 86.82113211495536, 89.25086852482387, 92.06000437055314, 89.40116500854492, 82.78395775386265, 78.37953635624477, 74.09326907566616, 75.629640851702, 77.92392213003976, 79.89634895324707, 82.21429579598563, 81.56119292122978, 77.92244911193848, 75.39152608598981, 76.90518420083183, 79.3173416682652, 82.25069740840367, 80.00683920724052, 69.39558506011963, 35.07408264705113, 3.4697217132364, 0.1335587618606431, 0.37086197254913195, 0.6346197436962808, 0.38029363644974573, 0.069477575431977, 0.01973182039468416, 0.10414219248507704, 0.024608622903802564, 0.08509030658751726, 0.41043516620993614, 13.116850120680672, 93.5202864238194, 82.04645511082241, 84.89580712999616, 84.80071408408028, 71.32448836735317, 26.49989788872855, 26.485562017985753, 29.107800006866455, 51.97763238634382, 79.92756720951625, 68.40157576969692, 73.22709274291992, 17.245446273258754, 0.2799960912338325, 0.16976954309003695, 0.07289775154952492, 0.039232399447688034, 0.030259778057890277, 0.017410353624394963, 0.027416472057146684, 0.020237152564472387, 0.02252716923664723, 0.042379505932331085, 0.03355176194704004, 0.06342301424592733, 0.05166064023173281, 0.05114908589582358, 0.0400482665614358, 0.01607294413926346, 0.009100186821472431, 0.06112238019704819, 0.028793636909020797, 0.01166660473349371, 0.01085804374555924, 0.013055385256718312, 0.02350168631944273, 0.08188605388360364, 0.02636465965770185, 0.019801341396357332, 0.040506050389792235, 0.028613143201385225, 0.030124939578984464, 0.013728131523488887, 0.06300340819039515, 0.22835300809570722, 0.1800578845930951, 0.16113519854843616, 0.12271151106272425, 0.09340850809322936, 0.10791028064808675, 0.08097123940076147, 0.08955523664397852, 0.2478880855653967, 0.16988649538585118, 0.11981658211776189, 0.21382587190185273, 0.12844624476773397, 0.1050335703683751, 0.16140241920948029, 0.10988664281155382, 0.16271376955722058, 0.10847821445869547, 0.16208802456302301, 0.08942323444145066, 0.07945398081626211, 0.09778359332787138, 0.19982837300215447, 0.14587646589747497, 0.1929020503801959, 0.14598813919084414, 0.11903002432414464, 0.41314526221581865, 0.6736479923129082, 4.624718376568385, 93.47157260349819, 117.4473740713937, 101.62724999019078, 90.13948059082031, 79.08923230852399, 43.420411654881065, 112.5535979952131, 135.9816243307931, 94.83824157714844, 108.23699487958635, 126.27514375959123, 25.862569161823817, 0.683227821120194, 0.49806918523141314, 0.38127851645861355, 0.13430631746138844, 0.25029064235942705, 0.2554571165570191, 0.5594124421477318, 1.4492067332778658, 27.687926939555577, 72.01222801208496, 94.34957477024624, 95.21069281441825, 87.35898521968296, 87.50138854980469, 83.71557916913713, 79.145644732884, 77.82090813773019, 75.66449996403286, 73.24515111105782, 79.94306169237409, 85.6346994127546, 96.44058649880546, 101.26920931679862, 104.56072384970528, 94.99466637202671, 101.12577765328544, 96.59765747615269, 90.65079852512905, 93.74397672925676, 99.00135203770229, 95.89107431684221, 93.31634984697614, 87.29303291865757, 79.54427678244454, 85.50070340292794, 92.21293422154018, 96.5466160093035, 96.71214989253453, 91.708265713283, 88.02874292646135, 97.0042313167027, 86.01733670915876, 92.13678891318185, 91.96699578421456, 86.58467102050781, 89.11301626477922, 93.34171077183315, 101.3860502243042, 100.0779893057687, 93.34542110988072, 97.43142046247209, 101.1477131162371, 111.24894169398716, 109.07512828281948, 93.1555129459926, 89.27182429177421, 97.57648495265416, 99.22978101457868, 91.1329687663487, 96.17608942304338, 98.34560884748186, 96.59105668749127, 88.4708776473999, 83.03603145054409, 78.67448738643101, 78.49153436933244, 82.315308707101, 83.13803100585938, 83.62600299290249, 86.10632923671177, 82.79487337384904, 80.79125608716691, 82.96352005004883, 83.97494847433907, 87.51634107317243, 83.06365053994315, 73.37816047668457, 33.602228369031636, 3.2587646331105913, 0.759918671633516, 2.40525530065809, 1.0713250445468085, 0.4042442398411887, 0.17730756503130707, 0.16444582518722328, 0.22836828870432718, 0.1692379109029259, 0.1922436407102006, 0.7125022102679525, 26.64981743267604, 110.29631587437221, 86.3390452521188, 85.21521581922258, 88.24377577645438, 112.9499579838344, 86.24252782549176, 32.28028842381069, 22.610209465026855, 50.03825119563511, 75.65092318398612, 76.57793794359479, 86.00519820622036, 19.128769397735596, 0.7126834062593324, 0.2611381917127541, 0.1435554147298847, 0.08178976297910724, 0.09293983717049871, 0.12699527905455657, 0.1324373741767236, 0.11207802593708038, 0.17344439375613416, 0.11415090970695019, 0.09103236666747502, 0.17634582306657517, 0.12034225676740919, 0.10782353673130274, 0.09449738037905522, 0.054644162101405006, 0.11821519876165049, 0.12214981977428709, 0.19843087584844657, 0.11838785878249578, 0.14396469348243304, 0.085842279451234, 0.17654000621821198, 0.17720167285629682, 0.06080299376377037, 0.13696652757269995, 0.07876562739589385, 0.13899327096130165, 0.054601173515298536, 0.10274191333779267, 0.1350935266486236], [0.021793257278789366, 0.01704793280389692, 0.04582464874589017, 0.0480462232870715, 0.012152503660347844, 0.061667175963521004, 0.023960761060672145, 0.07892907291118588, 0.07735832541116647, 0.02475779882765242, 0.05118925856160266, 0.011798668004173254, 0.04609300256041544, 0.03274351138887661, 0.02595233258658222, 0.07075983019811766, 0.029493681487760375, 0.06644186404134546, 0.04316158878750034, 0.032443324103951454, 0.07373923675290175, 0.04126735989536558, 0.06647893919476441, 0.035831195169261525, 0.16111265761511667, 0.05548689580921616, 0.11602541697876793, 0.2579033710062504, 3.4394523203372955, 61.511144501822336, 83.15214279719761, 71.5924734388079, 62.31458554949079, 44.03707817622593, 26.039008242743357, 81.96192332676479, 73.8643467766898, 77.90095833369664, 105.17366613660539, 97.56240790230888, 15.3668600831713, 0.13480236727212155, 0.11153807491064072, 0.13963938557675906, 0.11748443011726652, 0.16472672511424336, 0.1481698328363044, 0.2034851067832538, 0.5364783384970256, 31.842871529715403, 74.97311251504081, 83.38262149265834, 85.13340078081403, 82.03198896135602, 81.43367263248989, 75.03520161764962, 78.24110044751848, 80.30456256866455, 80.2739349092756, 90.98972470419747, 85.61819049290249, 84.75748934064592, 83.32026835850307, 90.44010829925537, 90.96544769832066, 92.83722291673932, 91.30539526258195, 86.51317405700684, 93.53459276471818, 86.20126942225865, 86.84636102403913, 88.10665307726178, 91.52321434020996, 78.07886001041958, 72.34697137560163, 79.71917683737618, 85.75484766278947, 85.96134117671421, 83.35195214407784, 87.3290662765503, 74.64622756413051, 76.09920706067766, 85.5247928074428, 99.82310158865792, 95.77108587537492, 88.94242409297398, 87.01381261008126, 80.74955994742257, 88.78646482740129, 83.60516534532819, 94.36141450064522, 83.96378271920341, 93.09789848327637, 89.45716748918805, 86.32012530735561, 83.671722139631, 91.52033083779472, 74.48894119262695, 77.60871710096086, 92.84615135192871, 92.36053480420793, 89.06910364968437, 88.28846658979143, 84.64473397391183, 82.67792129516602, 73.62637097494942, 70.05486488342285, 70.9701371874128, 80.96369647979736, 85.37689345223563, 86.41462080819267, 86.65771048409599, 85.58771569388253, 79.71655736650739, 77.44094589778355, 77.00425856454032, 77.8250423158918, 83.39931106567383, 79.23037801470075, 50.25859941755022, 9.743926150458199, 0.26774128739322933, 0.45522604989154, 1.065356976219586, 0.3767806163855961, 0.08703257236629725, 0.1601599265954324, 0.059039474464952946, 0.048965811263769865, 0.09508990429873977, 0.03618440996589405, 0.2766319146113736, 11.139856593949453, 79.88815007890973, 82.39699867793492, 76.56354822431291, 38.976382051195415, 86.74958651406425, 72.73457663399833, 41.16117361613682, 27.791656596320017, 32.61562933240618, 55.69291407721383, 61.13480922154018, 63.400582041059224, 21.199377741132462, 1.7416655314820153, 0.27894846030644005, 0.05988129215048892, 0.10404455129589353, 0.04026999823482973, 0.03181249348978911, 0.04083900413076792, 0.03929090952234609, 0.04302740848756262, 0.08819618528442723, 0.08590959691043411, 0.051175104321113656, 0.01665025530382991, 0.0746756015079362, 0.012122117165875222, 0.030891592547829663, 0.11285203083285264, 0.07809115001665694, 0.06887018481003386, 0.03711689350062183, 0.08344059796737772, 0.022526867288563932, 0.054808564351073334, 0.05355232801022274, 0.03832389534051929, 0.03448710889954652, 0.0905780331896884, 0.0062172463180364245, 0.02506556365239833, 0.046231810469180346, 0.016413292215604867, 0.03070962641920362, 0.05641490101282086, 0.022712813025074344, 0.010590262444955962, 0.0455055947947715, 0.036598000808485916, 0.01234045870868223, 0.050158567260950804, 0.11866254332874503, 0.06629074750734226, 0.050691553125424046, 0.060588576697877476, 0.023944505057962875, 0.03780299757740327, 0.06363872731370585, 0.04529478074982762, 0.034586276792521985, 0.03359933742987258, 0.04741765558719635, 0.07693994071866785, 0.061017817950674465, 0.05500877628635083, 0.025418926030397415, 0.16057418579501764, 0.05849071605397122, 0.12594394332596234, 0.16935053414532117, 12.652779936790466, 92.4950727735247, 92.436124256679, 93.7739998953683, 93.73212310246059, 71.7092170715332, 21.324664184025355, 30.3796295438494, 65.32310690198625, 85.42537103380475, 113.60297053200858, 101.48991189684186, 14.914332594190325, 0.2949258158249514, 0.12750157474407128, 0.14501586636262281, 0.10416258924773761, 0.3620133602193424, 0.30116388680679457, 0.13888104126921721, 1.8082007212298257, 41.868844168526785, 85.22794491904122, 90.28415598188127, 92.40151527949742, 85.62217181069511, 85.39519500732422, 80.54745074680874, 84.2839835030692, 87.47234507969448, 87.81482178824288, 93.65946578979492, 90.50309371948242, 90.08662564413888, 85.8409149987357, 97.71236392429897, 95.05806868416923, 93.32242257254464, 92.90669795445034, 88.81302779061454, 95.83906010219029, 92.25037806374687, 92.76262010846818, 89.64688110351562, 93.08222334725517, 83.35322366441999, 73.61624050140381, 82.63010379246303, 89.95158045632499, 89.8757130759103, 87.7301162992205, 88.96626336233956, 74.58559758322579, 80.13531834738595, 87.86379269191197, 103.28673689705985, 102.8055533000401, 95.70714855194092, 93.68855789729527, 87.79797240665981, 93.75341933114188, 88.48196697235107, 97.05159718649728, 90.7649713243757, 97.86918476649693, 95.20906693594796, 88.85086768014091, 87.44418403080532, 92.69857161385673, 82.62209251948765, 82.13910933903286, 93.12510068075997, 93.10490921565464, 92.01418794904436, 91.99439253125871, 87.1646649496896, 87.27603762490409, 77.61200359889439, 74.03032534463065, 75.43914209093366, 84.19731167384556, 88.48865808759416, 90.52259036472866, 90.47814273834229, 90.98857825142997, 87.7130515234811, 83.38446971348354, 79.37071078164237, 79.8428269795009, 86.392379624503, 84.52737195151192, 56.30082239423479, 12.961702925818306, 0.684664252613272, 0.6728994867631367, 0.7642845287919044, 0.39594068112117903, 0.26319474993007524, 0.3061768492417676, 0.04116172556366239, 0.03382616150858147, 0.08066543045320682, 0.09584416382546936, 0.4304724953004292, 8.491808652877808, 80.06145204816545, 89.83201585497174, 82.23250702449253, 47.18638045447213, 72.14645331246513, 27.25610508237566, 19.484181915010723, 42.949000699179514, 58.61789376395089, 75.43814155033657, 68.27598708016532, 81.54414899008614, 36.78741461890084, 6.074689303125654, 0.21526965871453285, 0.05205309810116887, 0.037913571644042215, 0.07757907999413353, 0.015962895937263966, 0.05108886591291853, 0.031952644897890944, 0.0337897988169321, 0.045291225226329904, 0.031154670752584934, 0.059651546978524754, 0.03172190227944936, 0.04912656978038805, 0.056647312827408314, 0.06315349335116999, 0.059125356642263274, 0.05280559343684997, 0.03206012823751994, 0.027401415365082876, 0.027516576328447888, 0.028951582897986685, 0.016752049127327542, 0.04639183956065348, 0.030603435688785145, 0.013104272856643158, 0.045299829050366364, 0.08704036873366151, 0.02427261066623032, 0.009647126758604177, 0.07826549280434847, 0.08349954230444771, 0.23002882674336433, 0.09770308514790875, 0.10936157884342329, 0.14386967143842153, 0.0654237222458635, 0.15388009856854165, 0.11329723122928824, 0.18457702281219618, 0.11531413586011954, 0.18118193213428768, 0.10198878017919404, 0.09687783050217799, 0.08456412303660597, 0.19732977636158466, 0.16490717471710273, 0.10553507560065814, 0.08731091421629701, 0.16089381650090218, 0.2589353956282139, 0.1093105733660715, 0.19823784620634147, 0.1218886516456093, 0.2722119917826993, 0.2103667003767831, 0.25065471710903303, 0.37455977126955986, 13.615245274135045, 109.20224557604108, 106.30194241659981, 93.57627500806535, 84.38178634643555, 51.74953344890049, 34.75538962227957, 108.60235895429338, 100.09417166028703, 93.65695054190499, 123.57087707519531, 116.79313169206891, 24.337038312639507, 0.6530652567744255, 0.3090958526091916, 0.24421094145093644, 0.38133654477340834, 0.30124894795673235, 0.46876021793910433, 1.1608863472938538, 1.902985006570816, 38.11406544276646, 87.69406904493059, 98.80587141854423, 96.5191706248692, 91.4968181337629, 94.08083234514508, 84.05588109152657, 86.29088033948625, 89.85953072139195, 92.17381586347307, 98.48401696341378, 92.23984459468296, 95.75900990622384, 91.50905391148159, 101.8098486491612, 101.08515848432268, 100.4706598009382, 99.21106256757463, 94.54231779915946, 102.02473558698381, 94.84574563162667, 94.56346811567033, 92.92600005013603, 99.96189185551235, 86.14676775251115, 79.76827280861991, 86.733640398298, 95.60949162074498, 94.25960949489048, 93.2614243371146, 94.59223365783691, 83.36663368770054, 87.79659666333879, 94.6989232472011, 107.91397312709263, 108.961733681815, 96.39546489715576, 94.58800915309361, 91.98806967054094, 93.88162054334367, 92.6824517931257, 101.39561789376395, 94.21995612553188, 98.72958714621407, 97.35760974884033, 91.92600836072648, 95.59440013340541, 95.5565880366734, 85.90280260358537, 91.17338643755231, 102.78693212781633, 100.10613645826066, 96.78917762211391, 97.29002462114606, 91.86814376286098, 91.71522780827114, 81.17638778686523, 78.24148259844098, 80.39958613259452, 89.72518035343715, 92.5441062109811, 95.2853581564767, 95.10970769609723, 95.53311007363456, 91.2040627343314, 87.41722502027238, 82.81959506443569, 86.8187905720302, 93.18993432181222, 89.66701698303223, 59.685338565281455, 14.057535461017064, 1.3409466339009148, 3.0175555305821553, 3.595490404537746, 0.7601488307118416, 0.27557483847652164, 0.38681902629988535, 0.1363720087600606, 0.21427654129053864, 0.24227836515222276, 0.12777587931071008, 0.5394229090639523, 18.344024215425762, 94.28597096034459, 95.51569093976701, 91.16976642608643, 54.79610661097935, 117.18141092572893, 91.09856823512486, 54.675604002816335, 38.0822948047093, 45.09585509981428, 74.82244777679443, 75.29962226322719, 95.6001671382359, 45.069000312260215, 7.408038190432957, 0.3231339821858065, 0.1959654459995883, 0.21671009356422083, 0.33806137261646135, 0.0970695505716971, 0.14268379578632967, 0.10232404433190823, 0.11906103337449686, 0.1946983632764646, 0.15146702448172228, 0.12037683491195951, 0.1664985700377396, 0.16437774098345212, 0.14366829581558704, 0.14399043710104056, 0.23082952520677022, 0.12385838452194418, 0.08503291609563998, 0.13902961329690047, 0.09973709564656019, 0.09057310024010283, 0.09016052380736385, 0.21968948654830456, 0.2818857298365661, 0.1617336935762848, 0.17780829673366888, 0.11141747888177633, 0.07506776082196406, 0.13097494122173103], [0.03197492798790336, 0.02374176388340337, 0.010406695821854686, 0.05582611582108906, 0.07065429764666728, 0.06503897931958948, 0.021492345657731806, 0.038134305870958736, 0.045111488085240126, 0.026371273677796125, 0.055362031795084476, 0.02580768588398184, 0.03253344033977815, 0.0731215188279748, 0.028871291849230016, 0.01361408335755446, 0.0965606357370104, 0.060428232087620666, 0.037554406095296144, 0.028186324318604808, 0.06905264287654843, 0.1729573548904487, 0.13186022586056165, 0.061301988416484425, 0.12325124495795794, 0.13342471048235893, 0.2060978872967618, 19.844576290675572, 83.73460333687919, 82.89590018136161, 94.06742232186454, 50.94660309382847, 33.21391439437866, 41.94773401532854, 90.95635945456368, 89.36085850851876, 92.93703378949846, 119.17206982203892, 87.09553037370954, 8.98041205746787, 0.02981038431503943, 0.025807224480169158, 0.07484210721616234, 0.047311651453908, 0.15533217707914965, 0.11532082621540342, 0.27492010646632736, 0.43027558443801744, 33.84946959359305, 93.91063622065953, 92.10702283041817, 90.93714073726109, 82.49129962921143, 85.53692436218262, 87.26152283804757, 92.85448224203927, 90.95403180803571, 93.23163046155656, 88.74417809077671, 90.10467706407819, 87.38000352042062, 90.07013756888253, 88.72163118634904, 94.87128026144845, 91.24381337847028, 82.40674005235944, 85.67397063119071, 83.36599445343018, 84.32437338147844, 91.05204309735979, 87.78062275477818, 88.56877081734794, 85.01305103302002, 79.03126348767961, 66.44103036608014, 83.20106506347656, 90.41605363573346, 88.8454897744315, 85.05338532584054, 82.28225612640381, 82.26768575395856, 76.55305644444057, 78.85386208125523, 103.74934795924595, 95.17850181034633, 86.35384491511753, 91.47100557599748, 83.8554047175816, 83.64008004324776, 85.66479206085205, 85.4272609438215, 88.75661536625454, 83.64763273511613, 88.18905871255058, 78.77675097329276, 73.7964003426688, 73.75223064422607, 75.5170452935355, 70.86214828491211, 74.36540916987828, 78.96846566881452, 86.39340795789445, 87.18757316044399, 86.94651235852922, 83.92954894474575, 79.64125279017857, 70.63788822719029, 69.85716778891427, 74.88341127123151, 82.91953795296806, 87.87989861624581, 86.73516205378941, 85.76777131216866, 90.71736921582902, 86.70395074571881, 85.85629831041608, 83.77643844059536, 87.12419864109584, 87.97401196616036, 75.96534306662423, 33.87670653206961, 4.567892968654633, 0.42089331788676126, 0.33126687577792574, 0.7966781705617905, 0.21797716271664414, 0.06679875989045415, 0.03546348347195557, 0.023206340381875634, 0.07563635959689106, 0.0357476166183395, 0.1640481222420931, 0.1316500428531851, 6.952638924121857, 67.54905959538051, 83.97650487082345, 73.16960334777832, 33.83989497593471, 60.847688811165945, 59.57200649806431, 26.31707341330392, 23.90322753361293, 36.785851274217876, 52.876117842538015, 65.17513806479317, 72.64899567195347, 66.08330236162458, 19.28506738798959, 0.6387916484049388, 0.04511306228648339, 0.07232115963207823, 0.07193594173129116, 0.034645638428628445, 0.04532940299915416, 0.023853639040940573, 0.0739477098520313, 0.053554224515599866, 0.04005905866090741, 0.05827405982251678, 0.06980486679822206, 0.035775314417800734, 0.050283346458205154, 0.0008048130361463077, 0.08669183243598257, 0.04281854862347245, 0.027274173085710833, 0.04311554340113487, 0.0540544303533222, 0.034156095768724165, 0.02868433848821691, 0.09044969507626124, 0.023251571526218737, 0.03626649573977504, 0.033431067530597956, 0.00691529897241188, 0.02817813609726727, 0.034655721459005556, 0.03901773810918842, 0.009705296717584133, 0.07969589212111064, 0.030666838000927652, 0.03036818081246955, 0.07640216100428786, 0.06683461368083954, 0.07194790430366993, 0.037321984102683406, 0.08322842006704637, 0.049694680010101626, 0.008281425755870129, 0.04423303629404732, 0.022972065988661985, 0.062333911258195124, 0.04025278040873153, 0.01448367432957249, 0.030570733693561385, 0.027962609626618878, 0.0492009948939085, 0.035342381934502294, 0.050087870697357824, 0.006685628015215376, 0.2686998945261751, 0.022674901577244912, 0.5649312117270061, 37.11289950779506, 111.22957706451416, 90.56956713540214, 113.31025682176862, 80.49065617152623, 56.00873402186802, 19.522864273616246, 48.81845324380057, 84.25006934574672, 103.3819966997419, 120.83623286655971, 91.97128282274518, 8.540595429284231, 0.23282417388898985, 0.007526489390459443, 0.0749393684257354, 0.11526411425854478, 0.1859015774513994, 0.3016984366944858, 0.6524210827691215, 0.7183390227811677, 44.54595034463065, 101.72445528847831, 97.77664170946393, 94.97834505353654, 88.38492843082973, 91.13214193071637, 92.22250883919853, 98.69094126565116, 95.48758547646659, 95.31841768537248, 90.71114362989152, 93.16442053658622, 92.25999437059674, 93.32396507263184, 92.8226316996983, 96.72702598571777, 93.42886202675956, 88.38623469216483, 88.09164496830532, 86.66040638514927, 88.70596994672502, 94.03420993259975, 90.59835352216447, 89.73189231327602, 90.30779375348772, 81.32661478860038, 69.30163846697126, 84.68274756840297, 91.8984865461077, 92.34676347460065, 87.78567409515381, 84.8942368371146, 83.64145578656877, 77.02053819383893, 82.13337707519531, 105.37109225136894, 99.0884199142456, 88.12221704210553, 92.53705378941127, 92.18896988459996, 85.10949897766113, 90.7440641948155, 85.60928985050747, 92.58502415248326, 87.37122099740165, 93.45813478742326, 83.98597526550293, 79.13183171408517, 76.11223493303571, 78.32365894317627, 77.26870005471366, 78.99395166124616, 78.61196749550956, 87.4237493787493, 90.80374922071184, 91.46051379612514, 87.79554053715297, 80.88674518040249, 73.60954243796212, 73.12029198237828, 77.35139056614467, 86.97794600895473, 91.35744421822685, 91.81827654157365, 89.36800820486886, 94.1771274294172, 92.89228044237409, 92.09070151192802, 87.80119637080601, 86.87123557499477, 89.74002170562744, 79.93785749162946, 42.200523376464844, 7.810916457857404, 0.5992245344179017, 0.7034634181431362, 0.2895476929843426, 0.31895732773201807, 0.03781234100461006, 0.3411491412137236, 0.10504673394773688, 0.0235994716973177, 0.07946083401995045, 0.15101872996560164, 0.20241621056837694, 4.667651729924338, 65.13050978524345, 89.0848969050816, 76.0108676637922, 42.33817066465105, 57.65859072549002, 44.11397736413138, 18.46467273575919, 34.622355937957764, 54.50701986040388, 74.23089899335588, 73.7801901953561, 83.06357410975865, 83.80816391536167, 32.24865327562605, 0.4879475597824369, 0.0405941242352128, 0.051646238325962, 0.035057414190045426, 0.008670742008169847, 0.04444437959630575, 0.0183867604272174, 0.020451388122247796, 0.03882625552692583, 0.06006550083735159, 0.0245703755811389, 0.05833948416901486, 0.008123063316036547, 0.026273985326822315, 0.04722010011651686, 0.06078963340925319, 0.09379036724567413, 0.030503154998379092, 0.056117868915732415, 0.04555587423965335, 0.014604158400158797, 0.032332539691456726, 0.02515888766252569, 0.00943540602124163, 0.06548491253384522, 0.01813357017402138, 0.06610655239117996, 0.01605499179900757, 0.09431010471390826, 0.10123355713273798, 0.05992853854383741, 0.2051850269947733, 0.09767227965806212, 0.24436681451542036, 0.12697250741933072, 0.15249571071139403, 0.07460045375462089, 0.07586554158478975, 0.23584007205707685, 0.10968791347529207, 0.12654507106968335, 0.1129601350320237, 0.14688559674790927, 0.1158231185483081, 0.17648906180901186, 0.07875637217823948, 0.07174754648336343, 0.0750231539298381, 0.17174162369753632, 0.21945579908788204, 0.16668812558054924, 0.1261402570775577, 0.48436674049922396, 0.23228832121406282, 0.6280863199915204, 37.41755369731358, 132.7618430001395, 99.1203260421753, 123.35980469839913, 66.8630222593035, 42.92722851889474, 57.180450439453125, 121.19082723345075, 120.3885326385498, 110.38096577780587, 137.21139989580428, 104.28253187452043, 15.711912836347308, 0.4586981407233647, 0.18564286561948912, 0.3733462521008083, 0.26716917380690575, 0.42892551688211306, 0.2607334591448307, 1.9877890731607164, 1.7859370644603456, 39.46043178013393, 106.65607820238385, 100.85042749132428, 99.90332548958915, 92.21596363612584, 96.32900537763322, 94.4224613734654, 104.35515444619315, 100.92838627951485, 103.51366506304059, 93.91890457698277, 99.77393613542829, 96.17981365748814, 98.17224434443882, 96.31162098475865, 104.0395325251988, 101.03378350394112, 93.44992201668876, 96.77830369131905, 91.16943291255406, 92.66125978742326, 99.56647682189941, 93.73750795636857, 92.1485105242048, 94.26341015951974, 84.83924879346574, 74.25997720445905, 92.08638668060303, 98.18916320800781, 96.14343983786446, 92.65987014770508, 90.92643356323242, 92.21779101235526, 87.28465339115688, 89.93636390141079, 110.59902804238456, 106.09865897042411, 97.61647183554513, 93.78069101061139, 95.12923908233643, 90.06935242244175, 93.8873597553798, 92.45466205051967, 96.75034414018903, 91.20363889421735, 94.18720926557268, 91.25013623918805, 87.6663943699428, 84.49634824480329, 82.94822011675153, 80.87356444767543, 85.64826229640416, 86.13634545462472, 92.71530982426235, 95.17633397238595, 96.36872128077916, 93.34198869977678, 87.55044283185686, 78.6038589477539, 79.3111160823277, 83.76714175088065, 92.73340293339321, 96.24501555306571, 95.83762877328056, 91.68894277300153, 98.21842902047294, 95.53266538892473, 95.80100481850761, 92.17577525547573, 92.50023528507778, 92.84806905473981, 84.30182647705078, 42.25349644252232, 7.1409633329936435, 1.241743185690471, 3.460209846496582, 4.315821009022849, 1.5168756736176354, 0.2251126505434513, 0.5458771884441376, 0.27038418129086494, 0.08521593056086983, 0.2711782572524888, 0.27872888637440546, 0.485461841736521, 12.267762882368904, 80.03594521113804, 93.93029267447335, 86.23264748709542, 47.253093583243235, 88.52812385559082, 71.85116182054792, 36.12247896194458, 30.08477578844343, 49.2114120892116, 71.38662610735211, 78.73446423666817, 93.81202738625663, 97.09509985787528, 37.599575655800955, 0.6790565135223525, 0.11752085387706757, 0.09932295179792813, 0.10540200131280081, 0.10222068309251751, 0.1681134562407221, 0.13446546106466226, 0.1493349995996271, 0.1573714462241956, 0.10811599889504057, 0.1304221251713378, 0.19541754254273005, 0.09985577142132179, 0.10998820593314511, 0.12454975742314543, 0.2102008664182254, 0.1206246901835714, 0.1315114317195756, 0.16421802741076263, 0.12278878263064794, 0.10737610395465579, 0.11789037047752313, 0.1907574726002557, 0.08963149040937424, 0.15997038462332316, 0.08345446043780871, 0.14860746078193188, 0.14496672685657228], [0.03297880358461823, 0.04425395892134734, 0.11857252887317113, 0.0736195838877133, 0.05113478237763047, 0.01465476184551205, 0.0158024037456406, 0.009730392335248845, 0.03645785279305918, 0.03963711844491107, 0.017919933423399925, 0.022380510677716563, 0.018773264151864817, 0.03440377801390631, 0.034859818007264814, 0.07137869484722614, 0.0372144532656031, 0.04060113350195544, 0.05365947547501751, 0.04333468985610774, 0.081952543530081, 0.05504487095666783, 0.1658144574612379, 0.3089315657104765, 1.518060775739806, 11.736103228160314, 49.41073158809117, 84.61010415213448, 86.92297186170305, 54.60717466899327, 46.60917970112392, 41.77403252465384, 41.03962530408587, 109.64435250418526, 84.30079119546073, 89.7508122580392, 107.43679169246128, 82.66424724033901, 7.201413094997406, 0.2416952864399978, 0.044596649639840634, 0.06942794059536286, 0.061110587258424075, 0.3336861516748156, 0.13489714504352637, 0.5382870414427349, 1.6348875697169984, 14.967856304986135, 99.82078089032854, 83.6571239743914, 89.00352655138288, 82.26000799451555, 89.13136645725795, 87.59739180973598, 92.36617674146379, 88.49699592590332, 91.6901934487479, 91.32853971208844, 97.83686174665178, 91.3518648147583, 92.0962461744036, 90.37932545798165, 94.42856884002686, 85.76615238189697, 84.1782180241176, 82.98678261893136, 78.67853123801095, 78.21022265298026, 79.42886025565011, 81.98002338409424, 85.22440828595842, 87.8294894354684, 87.43761103493827, 72.4491376876831, 66.79404054369245, 71.97879328046525, 89.16997759682792, 86.84958498818534, 85.1336578641619, 78.46676404135567, 76.59790706634521, 68.50916167667934, 74.96583080291748, 89.51486533028739, 94.5106895991734, 50.35819489615304, 64.71361786978585, 91.42436926705497, 74.31938430241176, 87.08409363882882, 81.35047490256173, 84.67969730922154, 79.84823962620327, 77.28682095663888, 63.23968955448696, 65.3377606528146, 74.09893185751778, 75.64516312735421, 71.79126140049526, 70.98246329171317, 76.17733260563442, 79.07187570844377, 82.29313700539726, 87.43124648502895, 84.93818419320243, 79.76154000418526, 71.4660370690482, 68.48488467080253, 67.70242023468018, 76.32614912305559, 84.98493167332241, 85.88592542920793, 85.35570839473179, 89.96144689832414, 87.0507561819894, 89.03310503278459, 88.97703307015556, 87.26481628417969, 83.50986385345459, 81.97508321489606, 79.65711552756173, 47.8882840020316, 10.861189535685948, 1.0547776924712318, 1.5959105640649796, 1.7082436106034686, 0.3117886052599975, 0.08573576302400657, 0.03509094060531684, 0.13372330660266535, 0.0676931029717837, 0.10304044838994741, 0.0226158181404961, 0.24125915127141134, 3.4993095312799727, 61.63421794346401, 89.659512928554, 86.0056984765189, 46.34105566569737, 58.85721056801932, 78.37618037632534, 47.75175884791783, 29.592124189649308, 34.70290987832205, 56.86923367636544, 62.804475239345, 62.61525494711739, 75.87070165361676, 35.58386502947126, 0.8670379093715123, 0.03502726009381669, 0.05351316296894636, 0.07412911618926696, 0.07904586235859565, 0.04124031348952225, 0.047571832314133644, 0.0276830192721848, 0.0483681270852685, 0.04198177923847522, 0.027874228744102374, 0.022982277940692644, 0.04422030697709747, 0.03348897710176451, 0.016740968650473014, 0.032463829432215006, 0.04687606589868665, 0.029142797458916903, 0.021793323435953686, 0.02325737469696573, 0.06819070662770953, 0.03645190543362072, 0.046069759343351634, 0.010719179009486521, 0.03779283990817411, 0.07554236892610788, 0.04812717251479626, 0.009227337498616959, 0.025159372815064023, 0.08950240590742656, 0.03416957825954471, 0.03274312123124089, 0.025447952062157646, 0.01709472288244537, 0.09159698244184256, 0.030519860530538217, 0.04230579328058021, 0.03162326703646353, 0.02936864783987403, 0.03161131124943495, 0.01050285526019122, 0.06165992920952184, 0.05558663367160729, 0.06034068071416446, 0.03313122629853232, 0.06878571398556232, 0.06359279727829353, 0.026838750378893952, 0.03476706566289067, 0.28673657668488367, 0.30289624099220547, 4.952611684799194, 19.448252780096873, 72.99080535343715, 102.9144593647548, 100.94669478280204, 89.2668285369873, 83.46193517957414, 58.5318055834089, 17.04419343812125, 71.23188972473145, 83.32607705252511, 98.8998944418771, 111.92099230630058, 91.08064883095878, 6.542747318744659, 0.27843377792409485, 0.04805648273655346, 0.08683357161602803, 0.08597556408494711, 0.1344373154320887, 0.29919228117380825, 0.8204451895185879, 1.4169974901846476, 20.832745620182582, 108.10758468082973, 86.70395074571881, 93.86780752454484, 83.4074821472168, 94.61233479636056, 90.69412749154228, 95.65464101518903, 90.30818980080741, 94.23160130637032, 93.99615464891706, 101.51584952218192, 93.92242731366838, 94.0913519178118, 92.92513152531215, 96.11996882302421, 86.97661195482526, 87.65565245492118, 84.19686698913574, 81.39140674046108, 81.50840745653424, 82.71265533992222, 84.38325241633824, 90.46357931409563, 91.45089748927525, 89.82614462716239, 76.89745780399868, 70.33247320992606, 76.25194931030273, 90.94945989336286, 88.86249896458217, 90.21596636090959, 80.98662553514752, 81.53800678253174, 72.30669266836983, 77.49335615975517, 88.90213148934501, 95.42211260114397, 56.499613830021445, 64.47199426378522, 97.06692491258893, 84.82766614641461, 88.35484967912946, 86.82635021209717, 88.42349093300956, 87.30974333626884, 82.11805629730225, 71.49904796055385, 73.57014615195138, 79.4075848715646, 78.78178146907261, 73.18686267307827, 75.43522330692836, 81.17670045580182, 81.77250848497663, 82.19399315970284, 88.89361994607108, 86.93824400220598, 83.90158939361572, 76.86785847800118, 71.3103279386248, 70.3582649230957, 77.81287602015904, 87.91513987949916, 89.90822369711739, 89.11221027374268, 91.48404039655412, 88.94842733655656, 89.83538573128837, 91.97399262019566, 90.18641567230225, 86.10295936039516, 83.224244253976, 85.69612843649728, 58.53580774579729, 19.568512201309204, 3.5702289257730757, 0.3071566809500967, 1.1834139270441872, 0.39067139529756134, 0.1525565210197653, 0.2390736442591463, 0.2706979630248887, 0.04071306463863168, 0.10634441181485142, 0.07609677274844476, 0.40727004462054794, 1.7615811313901628, 59.508527755737305, 93.694762638637, 91.17095456804547, 48.63484014783587, 57.64412110192435, 48.28723219462803, 24.741494689668926, 48.58609506062099, 58.009995869227815, 77.86866310664585, 77.80557346343994, 72.18476567949567, 85.52942725590297, 54.8352701323373, 0.9526892219270978, 0.021807933991242732, 0.0653888862580061, 0.08122033639145748, 0.00852225988637656, 0.0072624162837330785, 0.04633715642350061, 0.04752652653093849, 0.052223359500723224, 0.034199552543993504, 0.060887837782502174, 0.018831343356786028, 0.09581034564013992, 0.02796563589280205, 0.012088154791854322, 0.01599022902415267, 0.014653136754142386, 0.043260539549269846, 0.030425449168043475, 0.03641079638951591, 0.06866879561649901, 0.055648831584091694, 0.0031072908979175346, 0.014354160654225519, 0.022102097581539835, 0.03766837962237852, 0.037768517820430655, 0.12412363743143422, 0.1775322686880827, 0.3883153317230088, 0.19361726700195245, 0.14845797951732362, 0.14609584983970436, 0.07137585857084819, 0.2723964718835694, 0.08984661315168653, 0.0913187830841967, 0.09147628463272538, 0.10381057885076318, 0.0632665508559772, 0.12840850464999676, 0.12352860293218068, 0.21313341334462166, 0.10743515007197857, 0.14104259599532398, 0.13569827776934418, 0.11755978821643762, 0.12189870753458568, 0.1044153638982347, 0.5616766863635608, 0.705417870410851, 8.280021480151586, 26.530883380344935, 84.08293737683977, 126.6985113961356, 105.35900933401925, 84.67029639652797, 64.77715914590019, 47.81685652051653, 57.84417016165597, 139.60927881513322, 108.86468124389648, 108.07950701032365, 126.22447749546596, 103.55745261056083, 12.94688241822379, 0.5647088693720954, 0.14108891279569694, 0.2424508487539632, 0.1713084333709308, 0.5622251055070332, 0.22482633590698242, 1.336002230644226, 3.6710933191435675, 18.68788535254342, 115.30449404035295, 92.96017129080636, 101.97668879372733, 91.434492792402, 98.93049430847168, 96.67793001447404, 103.93252331869942, 94.64500522613525, 100.04890414646694, 100.7252973828997, 109.62622465406145, 97.17786679949079, 99.76991312844413, 99.2538982118879, 101.74103369031633, 94.45318630763462, 94.15221118927002, 93.2242236818586, 86.68504469735282, 89.17468847547258, 87.51574352809361, 92.76579543522426, 94.62766252245221, 93.63268048422677, 91.8486818586077, 80.02015890393938, 73.50666740962437, 80.68921484266008, 96.19842788151333, 94.34939411708287, 92.06627164568219, 87.56607627868652, 87.46790518079484, 81.83215182168144, 89.54149777548653, 103.01687581198556, 103.1380523954119, 74.79394626617432, 75.26895986284528, 92.74948801313127, 90.78727504185268, 92.54828902653286, 92.08768599373954, 92.38627093178886, 89.61717060634068, 85.73637240273612, 76.39865357535226, 84.95558943067277, 83.24511664254325, 79.83054256439209, 77.8744787488665, 72.08960315159389, 84.23369938986642, 84.22397886003766, 85.1089848109654, 92.38810525621686, 90.79706505366734, 88.68809223175049, 81.96904523032052, 74.8578280040196, 76.71644333430699, 84.04743903023856, 94.56268991742814, 94.08027648925781, 93.57003552573067, 95.68377481188092, 92.06973184858049, 95.55373927525112, 97.70912606375558, 94.99369362422398, 91.3455558504377, 89.99841826302665, 92.64712020329067, 58.33418491908482, 16.324214151927404, 3.058347535984857, 2.966166002409799, 4.5301008479935785, 2.2452309046472823, 0.15488139912486076, 0.25509420888764517, 0.5747878828219005, 0.10506204169775758, 0.3138308328177248, 0.09933423583528825, 0.9070340746215412, 7.6376188312258035, 76.06852381569999, 102.7788096836635, 97.52670110974992, 59.88299397059849, 70.85384518759591, 93.91814722333635, 66.85900620051792, 38.45681313105992, 45.39383554458618, 76.46082605634416, 80.37671961103166, 77.38612461090088, 100.63512366158622, 66.85892977033342, 1.4738181212118693, 0.25502404836671694, 0.12339537936661925, 0.1733041541384799, 0.18144657436226094, 0.20277911823775085, 0.13449222248579773, 0.09747115509318453, 0.08325334265828133, 0.10948524863592216, 0.11843114931668554, 0.1807397444333349, 0.25046882565532413, 0.10269612579473428, 0.0925423310005239, 0.1084985840799553, 0.10770245894257512, 0.07931344942854983, 0.09283034197453942, 0.09447355022920029, 0.19201885562922272, 0.07409173569508962, 0.2137512466205018, 0.08102390050355877, 0.19868942483195237, 0.19302842074206897, 0.1677695204104696], [0.02974934669743691, 0.03397260632898126, 0.061071320436894894, 0.04755224979349545, 0.014594636857509613, 0.02678488826911364, 0.033244046316082985, 0.05828753552798714, 0.045542452816984484, 0.013169150982451226, 0.030353680519121032, 0.030707947045032467, 0.04022581542709044, 0.07030713877507619, 0.05247653109420623, 0.025102112941177826, 0.04974669311195612, 0.010468568885698915, 0.005235524889680424, 0.05545674849833761, 0.06423814514917986, 0.2550705687275955, 5.984635003975459, 36.21101638248989, 74.03352846418107, 91.32826178414481, 96.95519093104771, 81.25369344438825, 65.71045507703508, 48.88834864752633, 40.39557940619332, 46.98328460965838, 139.00844029017856, 68.78385870797294, 89.46554006849016, 107.79547854832241, 89.72842516217912, 8.957111273493085, 0.5627851954528263, 0.15726997809750692, 0.0607808395954115, 0.04098248375313623, 0.14526425089154923, 0.036270108938749344, 0.09891507761286837, 0.6311053122792925, 0.08612168660121304, 50.12399544034685, 91.9056362424578, 85.01043156215123, 81.40010588509696, 72.11547824314663, 77.72401550837925, 81.4500981739589, 84.44622394016811, 88.09730080195835, 87.77816309247697, 85.81195490700858, 87.96090766361782, 88.76942089625767, 92.7450203214373, 93.82058061872209, 87.85544790540422, 83.38798550197056, 74.60121713365827, 68.07430171966553, 64.79382787431989, 66.09589944566999, 69.76805019378662, 76.90840816497803, 82.8544819695609, 89.56363473619733, 84.76875237056187, 77.79519285474504, 65.86424650464738, 67.56551987784249, 78.59432601928711, 85.67095511300224, 83.94470296587262, 76.95591299874442, 78.7255358014788, 75.67984158652169, 67.00708620888847, 64.12144374847412, 75.07134614671979, 53.49117933000837, 40.37778854370117, 70.25813443320138, 87.89802646636963, 79.22737639290946, 81.29520893096924, 77.83945982796806, 75.6945856639317, 60.99799224308559, 65.67125334058488, 60.74502222878592, 73.93243217468262, 85.0714784349714, 71.76118264879499, 85.57669585091728, 85.46009118216378, 83.75924859728131, 81.21028109959194, 82.82994093213762, 81.64446708134243, 79.20748370034354, 76.64880956922258, 72.89066791534424, 67.65823663984025, 66.38042817796979, 65.86521230425153, 73.43094594138009, 78.65028681073869, 79.0570204598563, 83.8773888179234, 84.61830302647182, 83.36049148014614, 83.26470361437116, 82.80689375741142, 80.73364857264927, 80.54236466544015, 80.03985704694475, 73.983487537929, 57.49063886914934, 20.40122948374067, 2.234577144895281, 1.4920649592365538, 0.7129871728164809, 0.053979760967195034, 0.06900036175336156, 0.05250384212870683, 0.06087973607437951, 0.04736883838527969, 0.16448394528457097, 0.22444115871829645, 3.2732164519173756, 52.673418045043945, 80.69147300720215, 87.64231191362653, 40.0505005972726, 45.40311138970511, 63.07338442121233, 25.573482411248342, 22.667752708707535, 31.262273107256206, 31.43578699656895, 52.90461935315813, 63.7925785609654, 74.42871420724052, 31.311601843152726, 0.40287913594927105, 0.02760958481979157, 0.02807197759726218, 0.054015289060771465, 0.027055186086467335, 0.02135481169846441, 0.01338579533954284, 0.05277145973273686, 0.014125010896740215, 0.045245132342513115, 0.01569846914415913, 0.02031871417005147, 0.037828439247927496, 0.06133454452667918, 0.014705499301531484, 0.0025548669135397567, 0.06447455353502717, 0.06699129420199565, 0.018671086956081644, 0.014825069046180164, 0.06675484510404722, 0.050105682241597345, 0.021310274356177876, 0.11824475574706282, 0.03151671328981008, 0.05385110054963401, 0.09704975770520312, 0.03983779178400125, 0.031221530200647454, 0.018562216012339507, 0.053966963796743324, 0.013215533091819711, 0.06220632631863866, 0.10972239662493978, 0.03990770803232278, 0.014122999888578696, 0.07439443695225886, 0.00921083043795079, 0.008011699604269649, 0.05286957250375833, 0.0349732860257583, 0.06613874887781483, 0.05015420428078089, 0.09905306449426071, 0.054508142971566746, 0.027223355901826705, 0.04706658496122275, 0.07324687817267009, 9.065541386604309, 49.30616119929722, 96.29101262773786, 108.77008846827916, 115.4526365825108, 93.32100514003209, 102.14707251957485, 55.55340467180525, 29.26209170477731, 30.976212297167095, 97.70895235879081, 78.78528336116246, 95.5207770211356, 113.68614046914237, 96.58900696890694, 8.421974914414541, 0.8642081469297409, 0.11132010910660028, 0.011992539877870252, 0.07154360599815845, 0.05529614943744881, 0.12131818011403084, 0.049394886275487285, 0.045819549555225034, 0.3602896641407694, 59.39129080091204, 96.32651097433907, 90.82835974012102, 82.74665287562779, 73.4543127332415, 79.85983616965157, 85.58433192116874, 86.1780207497733, 90.4798936843872, 90.42061860220772, 86.9965741293771, 90.32553945268903, 90.48814119611467, 94.9118994304112, 94.28893784114292, 90.30208233424595, 85.2566340310233, 78.01234490530831, 70.2557373046875, 68.0134493964059, 67.66395500728062, 72.68965653010777, 81.31838117327008, 87.92266477857316, 92.83995355878557, 89.55486610957554, 79.99612508501325, 69.12721783774239, 69.01077992575509, 79.84226417541504, 88.68768923623222, 86.52866853986467, 81.058351789202, 81.84988362448556, 78.7689550944737, 73.91685431344169, 70.14311395372663, 77.8195879799979, 64.77117674691337, 48.54794250215803, 68.39794881003243, 91.86975574493408, 86.36911010742188, 86.90315559932164, 82.06234564099992, 79.14739567892892, 68.26914310455322, 74.15508025033134, 68.8901730946132, 76.90683787209647, 84.64662388392857, 75.04326847621373, 86.0037738255092, 86.81496906280518, 88.7866871697562, 85.68382317679269, 84.48716967446464, 84.4860371180943, 84.50622858319963, 82.77618271963937, 77.8228188923427, 70.95426750183105, 70.61646693093437, 69.96892261505127, 76.4531135559082, 80.47460583278111, 82.6066814150129, 85.25201347896031, 88.19539546966553, 86.30702100481305, 85.9907876423427, 87.42634105682373, 85.05235004425049, 83.07819311959403, 86.37967831747872, 82.52927153451103, 70.2913954598563, 31.58710833958217, 5.878524720668793, 0.5100751295685768, 0.3365624344774655, 0.12917786836624146, 0.14892656223050185, 0.2359688308622156, 0.05072929324316127, 0.163433274520295, 0.061259423914764605, 0.2634126953780651, 1.5895450370652335, 55.484544549669536, 85.13954298836845, 94.51780455453056, 46.926448345184326, 50.7210749898638, 35.2977660042899, 18.21401126044137, 35.8641414642334, 52.098426818847656, 54.62799494607108, 69.73552567618233, 70.93761266980852, 82.20319257463727, 47.26425586427961, 0.3220218632902418, 0.04730542928778699, 0.061024515091308525, 0.02240055799484253, 0.018707203678786755, 0.059466958312051635, 0.03816783907158034, 0.027215367848319665, 0.047040875269366164, 0.025175294639276605, 0.08779025170952082, 0.018609672751543776, 0.08099194828953062, 0.04307203573573913, 0.029114397375711372, 0.03346697221110974, 0.09305874364716665, 0.0962200111576489, 0.019691520503589084, 0.07701966858335904, 0.0352742536259549, 0.06140304942216192, 0.04832250917596476, 0.11776241234370641, 0.02462478560794677, 0.031502803321927786, 0.19821260470364774, 0.09378276086811509, 0.18121693097054958, 0.09392351617238351, 0.13116832370204584, 0.09196962030338389, 0.08944688138685056, 0.17219588932182106, 0.20118086971342564, 0.06530282087624073, 0.14768352678843907, 0.11590683619890894, 0.08534344764692442, 0.09529829597366707, 0.12234132949795042, 0.13881801893668516, 0.12217807397246361, 0.2307480467217309, 0.15025474024670465, 0.1771359092422894, 0.24517405405640602, 0.3063483828944819, 13.122797778674535, 63.38723455156599, 112.60139465332031, 128.8782307761056, 124.93343271527971, 99.12105560302734, 90.77640805925641, 59.68194784436907, 48.854827063424246, 62.4333997453962, 164.64762660435267, 88.25670637403215, 106.90624809265137, 123.50907979692731, 110.65803214481899, 16.911354303359985, 1.2463941361222948, 0.4244522340595722, 0.18907564213233335, 0.21058068318026407, 0.4394564889371395, 0.34950356291873114, 0.46677824429103304, 2.970285198518208, 0.6305266033325876, 63.64797960008894, 104.79275894165039, 96.01902539389474, 91.47158922467912, 80.16108226776123, 88.22740582057408, 92.22607326507568, 93.28668798719133, 97.82827377319336, 98.1122327532087, 92.93039131164551, 97.17399665287563, 97.17744295937675, 101.3860502243042, 102.7672061920166, 98.76115976061139, 89.50386633191789, 82.39982659476144, 75.24972030094692, 72.78802217755998, 70.33433532714844, 78.78018338339669, 84.98429243905204, 94.31131104060582, 96.82166739872524, 92.84722137451172, 83.61229419708252, 72.33891146523612, 73.68409660884312, 85.49993910108293, 92.99636445726667, 89.43785844530377, 83.2868127822876, 85.82607364654541, 82.75230176108224, 83.39545481545585, 85.88786397661481, 90.22721549442836, 70.07627923148019, 57.92071499143328, 75.15914358411516, 90.70140920366559, 90.33328669411796, 88.54286098480225, 83.8367279597691, 87.01657799312046, 75.21001829419816, 84.70445374080113, 74.81927245003837, 85.71570151192802, 90.35099765232631, 74.31409672328404, 91.88370077950614, 91.51194436209542, 92.09999820164272, 89.45668111528668, 87.4816973549979, 89.97075053623745, 88.63400745391846, 85.85663182394845, 81.44792338779995, 75.11980983189174, 73.95564610617501, 75.34948253631592, 81.58203056880406, 86.65044266836983, 87.96051856449672, 92.3730832508632, 92.98185661860875, 91.89010007040841, 91.30256039755685, 94.63238034929547, 90.89704963139125, 90.80368668692452, 94.86966133117676, 89.22469466073173, 70.09408746446881, 25.458213533673966, 3.4677699208259583, 2.3723119369574954, 1.705790027976036, 0.43020965797560556, 0.12147998357457773, 0.3429247316505228, 0.1406696867197752, 0.23786718185458863, 0.35832609236240387, 0.7824535252792495, 5.678283282688685, 69.4376494543893, 90.20523834228516, 103.8956492287772, 55.355016231536865, 69.06529549189976, 84.44677284785679, 33.63411365236555, 29.80706671306065, 41.01457704816546, 46.99624300003052, 73.42260810307094, 77.11772264753068, 94.6602704184396, 60.045651299612864, 0.6810780050499099, 0.14390376103775843, 0.1379220677273614, 0.17784811316856317, 0.13546697875218733, 0.1448791144149644, 0.07082554631467376, 0.19326605727630003, 0.20018178118126734, 0.07623995720807995, 0.16100426843123777, 0.16068744686033043, 0.14903619991881506, 0.15102825659726346, 0.14460850107882703, 0.13826893482889446, 0.20917479933372565, 0.20745966636708804, 0.07527606428733893, 0.20459456582154545, 0.14350417176527636, 0.08859864476003818, 0.12757713640374796, 0.16678606532514095, 0.11699273650135313, 0.18841757172984736], [0.044974206880267174, 0.030287452108625854, 0.06134998798370361, 0.02932776271232537, 0.025795334850304892, 0.06604011024215392, 0.13827006119702542, 0.04537684616765805, 0.03584513906389475, 0.005775144282129726, 0.011698038716401373, 0.008082532723035132, 0.007166051588553403, 0.06647486119930233, 0.029927082160221677, 0.019720619477863823, 0.029965880792587996, 0.05259149867509093, 0.03885617892124823, 0.017984599507014667, 0.08114523613559348, 39.2221919468471, 89.29806763785226, 101.61912754603794, 99.46107264927456, 73.78677708762032, 59.97419602530343, 73.0384908403669, 42.09320150102888, 154.5791448865618, 178.0508267538888, 135.48161806379045, 78.42473438807896, 97.18291119166783, 109.7633751460484, 83.89020129612514, 8.943551863942828, 0.803892192031656, 0.187617511089359, 0.20146987134856836, 0.19080620498529502, 0.13673362721289906, 0.012953088469138103, 0.2515586886022772, 0.22836554742285184, 0.7027786406023162, 0.7777120311345372, 68.41131019592285, 90.56717000688825, 82.6254415512085, 76.22890908377511, 71.85293361118862, 65.08782005310059, 65.0370843069894, 68.68768869127545, 66.5838714327131, 66.38310323442731, 70.2984756742205, 73.30271693638393, 78.29331615992955, 77.82515348706926, 80.2022225516183, 74.70835140773228, 67.65277535574776, 62.26878997257778, 63.1560332434518, 63.24021066938128, 65.1082547051566, 64.07947662898472, 76.78156185150146, 82.36984511784145, 88.05864102499825, 85.93023409162248, 74.20653860909599, 66.35335104806083, 61.73822552817208, 74.52865709577287, 85.36159351893834, 82.44159916469029, 77.13204288482666, 79.06783880506242, 78.42791666303361, 73.39182758331299, 68.46381078447614, 68.80587754930768, 78.90525790623256, 58.27587216241019, 44.47559288569859, 78.02253791264125, 83.82176848820278, 84.81562491825649, 78.49678720746721, 68.42655454363141, 68.08697523389543, 59.740847723824636, 64.86205918448312, 66.07503400530133, 72.85245977129254, 85.01073728288922, 79.01421955653599, 79.2882217679705, 77.55820369720459, 79.1023644038609, 79.4477732522147, 86.38364573887416, 80.79033197675432, 80.66597311837333, 79.01517145974296, 77.8235901423863, 72.66755431038993, 71.34247725350517, 68.40238870893205, 65.89383888244629, 66.12877832140241, 67.90167372567313, 71.62531757354736, 73.4259432383946, 76.74070644378662, 76.50471782684326, 75.16436168125698, 75.22096865517753, 74.30615493229458, 77.17054980141776, 83.33098942892892, 91.0890839440482, 66.89782578604562, 23.383990389960154, 0.46439566356795176, 0.7391317784786224, 0.25775061920285225, 0.12087863869965076, 0.14129680235471043, 0.06040047322000776, 0.13451778968530043, 0.13036739453673363, 0.4884920705642019, 5.385375022888184, 46.55180842535836, 72.20039217812675, 87.4973863874163, 42.13852112633841, 47.839969703129356, 83.00020653860909, 42.628879819597515, 25.519456693104335, 32.00659540721348, 41.65352644239153, 48.87486914225987, 61.229096276419504, 70.80514526367188, 22.482439041137695, 1.4094915900911604, 0.05326205412192004, 0.05556636243792517, 0.12550600325422628, 0.10573449025728873, 0.03573832068858402, 0.06632314755448274, 0.03413433515067611, 0.019465680300657238, 0.0521638316235372, 0.039847189494009526, 0.04814274828614933, 0.04844934772700071, 0.045552199972527366, 0.0762543421504753, 0.0652308486668127, 0.052753980670656474, 0.034644702050302706, 0.033083572784172635, 0.024966048010225807, 0.05023939095969711, 0.055428948918623586, 0.0711592769782458, 0.02049163881955402, 0.15749715162175043, 0.01238868643330144, 0.029158559827400104, 0.04874129420412438, 0.01716334991423147, 0.018830235648368086, 0.04211498244798609, 0.07010542388473238, 0.05217820978058236, 0.028152063389175704, 0.01916209016261356, 0.11001067222761256, 0.07077498188508408, 0.039354990369507244, 0.06874768209776708, 0.026420708346579756, 0.07796864730439015, 0.041896341501602104, 0.0339617429833327, 0.12246767271842275, 0.05553092933925135, 0.26704758033156395, 53.14745889391218, 109.25999205453056, 116.23633779798234, 105.33140414101737, 89.9682422365461, 87.23051997593471, 109.77303314208984, 65.0666697365897, 152.47523035321916, 137.5304194859096, 92.98792239597866, 88.92176015036446, 106.09193311418805, 117.93105207170758, 91.83889184679303, 9.715008616447449, 1.3477644452026911, 0.1363456001771348, 0.16282555141619273, 0.062421618694705625, 0.3367439018828528, 0.0461700332484075, 0.3457357936671802, 0.7618687812771116, 0.5979812411325318, 1.0665882187230247, 75.17451994759696, 96.0630908693586, 88.04126358032227, 80.87620476314, 77.52977861676897, 69.49127565111432, 68.72407640729631, 71.0138830457415, 69.7836697442191, 71.83602169581822, 71.75886195046562, 75.99415029798234, 79.74660832541329, 79.63092776707241, 81.41803223746163, 76.18391254970005, 68.37735434940883, 66.90486431121826, 66.04956885746547, 65.76474135262626, 67.69107382638114, 67.62414877755302, 78.24995940072196, 85.8295407976423, 91.20235347747803, 89.52199418204171, 76.72910295213971, 69.22895336151123, 64.25089563642229, 78.62600980486188, 86.71636717660087, 84.60644939967564, 81.68557262420654, 82.92511735643659, 84.26970495496477, 77.88644354684013, 76.39183739253453, 72.97973687308175, 80.37827600751604, 69.57161767142159, 52.40854229245867, 78.39596884591239, 87.72159780774797, 89.28777735573905, 81.71302495683942, 75.0007107598441, 74.94814068930489, 69.45813969203404, 72.6545889718192, 73.39060470036098, 75.72822189331055, 85.09144755772182, 81.38259642464774, 83.53143801007951, 81.70518738882882, 82.90457153320312, 82.75000190734863, 87.215226990836, 84.68219866071428, 87.1658114024571, 85.64602497645787, 81.07141440255302, 78.07659489767892, 73.66292544773647, 73.04969828469413, 69.8588353565761, 71.27011176518032, 70.33762182508195, 75.3800824029105, 78.87533201490129, 80.66106769016811, 80.07173538208008, 77.72294548579625, 81.60618945530483, 80.89497879573277, 79.4969595500401, 84.43265410831997, 94.81133815220424, 77.1678191593715, 34.55793571472168, 2.73201670391219, 0.3796927258372307, 0.24394897265093668, 0.1427182246531759, 0.5192609195198331, 0.06913300177880696, 0.17428277805447578, 0.1392688783151763, 0.34396229311823845, 2.922873079776764, 49.49025024686541, 75.65636362348283, 97.50423063550676, 46.51946803501674, 47.91013956069946, 41.09504413604736, 25.15475617136274, 30.072081429617747, 39.704407351357595, 61.31594181060791, 64.50572776794434, 72.4866510118757, 80.746461050851, 37.241211891174316, 1.0670715527875083, 0.020755529569994127, 0.04780608635129673, 0.04666567254545433, 0.06314406849976097, 0.02581176727211901, 0.03225962431835277, 0.02953511622867414, 0.015088523837870784, 0.0565962123551539, 0.020251233862446885, 0.03547307117176907, 0.0056188823322632486, 0.014081503231344479, 0.05290267822731819, 0.057938734601650915, 0.01772720572937812, 0.05900040441857917, 0.036515256855636835, 0.049301122913935354, 0.022461241077897803, 0.021662420460156033, 0.06673482153564692, 0.06768349491591964, 0.0792640181524413, 0.19351794304592268, 0.14616048708558083, 0.13505995273590088, 0.0926947028243116, 0.06340936890670232, 0.20575235012386525, 0.16654503611581667, 0.14961949576224598, 0.14272536284157208, 0.0854952766426972, 0.15205196237989835, 0.14441958335893496, 0.11365755368024111, 0.20396157407334872, 0.15085548801081522, 0.233773444380079, 0.08629593439400196, 0.10055903904139996, 0.17201777387942585, 0.14923251367041043, 0.8136739528604916, 66.48027379172188, 127.46111788068498, 133.90494673592704, 116.5835462297712, 93.98038223811558, 80.57938466753278, 100.41097477504185, 48.48802471160889, 159.6493704659598, 179.08641406467981, 161.08796719142367, 103.78026744297573, 113.306886945452, 121.60610716683524, 106.47031116485596, 17.675041232790264, 2.329001860959189, 0.5557319053581783, 0.3034603207239083, 0.3315340828682695, 0.6467977645141738, 0.16953262580292566, 0.7417572204555783, 2.9630073947565894, 2.8465788194111417, 1.3902057792459215, 82.66664436885289, 102.10567515236991, 92.90537779671806, 84.42957605634416, 82.39339256286621, 72.4398409979684, 74.08237430027553, 78.50798075539726, 77.32006113869804, 78.0155063356672, 77.62763009752545, 81.9978107724871, 85.81745093209403, 84.0604738507952, 87.70187882014683, 82.74977261679513, 75.41735254015241, 70.11932332175118, 73.14691053118024, 70.35094152178083, 72.84576170785087, 71.54389163425991, 84.27910586765834, 91.04039096832275, 93.43599782671247, 93.33078125544957, 80.93926661355155, 72.38076741354806, 67.17073713030133, 82.70224693843296, 92.92637525285993, 89.78713049207414, 84.60437188829694, 87.20303985050747, 85.77677617754254, 82.84030764443534, 84.26659216199602, 90.26550701686314, 93.51204586029053, 77.09045096806118, 61.26327446528843, 81.7939784186227, 88.01911967141288, 87.62131445748466, 85.14007105146135, 81.53392124176025, 80.91888754708427, 75.00641523088727, 72.34650584629604, 72.87549304962158, 78.49637726375035, 86.02734906332833, 86.10109724317277, 86.05544757843018, 85.20373739515031, 87.66313566480363, 87.67532975333077, 89.18819577353341, 87.50204862867082, 90.32506002698625, 89.67505604880196, 84.40500027792794, 80.23777648380825, 77.21567140306745, 77.35756751469204, 74.48947620391846, 75.1046280179705, 73.33444241115025, 81.50227219717843, 81.06587668827602, 84.05761814117432, 84.09962694985526, 83.25444112505231, 84.61267498561314, 84.94629274095807, 84.91262871878487, 92.54121576036725, 103.28630610874721, 78.7588871547154, 29.759742532457622, 2.1181453125817433, 1.5078413869653429, 1.0275784262589045, 0.2602320489074503, 0.5889270869748933, 0.18258303909429482, 0.3238193839788437, 0.3563387447169849, 0.5215523051364082, 9.137746197836739, 64.50371973855155, 82.85867173331124, 103.58453668866838, 55.02056816646031, 69.85720252990723, 111.10792105538505, 51.29998847416469, 34.58162907191685, 42.00006089891706, 52.49334158216204, 68.48286969321114, 76.66082300458635, 91.53315721239362, 50.580589362553184, 1.3191956239087241, 0.12241028222654547, 0.09081806495253529, 0.26306742961917606, 0.20322427792208536, 0.09816048560397965, 0.29582118349415915, 0.14152793852346285, 0.061081946295286925, 0.18250702960150583, 0.1938575091106551, 0.12039085344544478, 0.2627855933138302, 0.12007255266819682, 0.22617016094071524, 0.12239093040781361, 0.09022439430866923, 0.20067437046340533, 0.14326832656349453, 0.09946154936083726, 0.13782030104526452, 0.16203718871942588, 0.17594312610370771, 0.06539822289986269, 0.19309809271778378], [0.07736946017082248, 0.01205686414946935, 0.019919170698683177, 0.05963186946298395, 0.11202541911708457, 0.03326289941157613, 0.06966888838048492, 0.05295451830274292, 0.01853151060640812, 0.06867377606353589, 0.023343389188604693, 0.07132873431380306, 0.0906558000881757, 0.0419494097254106, 0.0425566171428987, 0.01310727876677577, 0.04825694572978786, 0.026458806391539316, 0.05357131342004452, 0.6374435893126896, 65.9478541782924, 105.64739431653703, 94.3370749609811, 80.38876778738839, 73.24741622379848, 75.7448558807373, 59.561667578560964, 36.97907025473458, 32.51419952937535, 71.12202480861119, 89.95529079437256, 74.19836752755302, 102.86934471130371, 115.14739527021135, 93.14832156045097, 13.549559610230581, 0.2834843583405018, 0.2194723824837378, 0.5008530787059239, 0.1026084590703249, 0.018312964654926742, 0.0799295592254826, 0.10830624654356923, 0.22899699211120605, 0.6557187086769513, 0.24661461104239735, 2.987391012055533, 73.2525439943586, 87.22455147334507, 89.80839197976249, 83.42164257594517, 84.70461354936872, 78.93258517129081, 69.3632481438773, 64.16307040623256, 64.60404477800641, 61.650240489414756, 58.81505584716797, 58.9600647517613, 62.883316448756624, 65.94637421199253, 68.07724775586809, 64.39129093715123, 64.1200819015503, 67.71388476235526, 63.22774560110909, 64.02101448604039, 59.69528143746512, 68.21571145738874, 75.02256284441266, 85.4538516998291, 92.55609880174909, 75.4091328212193, 73.49391051701137, 62.87853608812605, 64.72853565216064, 72.19151932852608, 82.59680802481515, 81.83636937822614, 83.57512133462089, 76.77080604008266, 82.6784702028547, 75.35107367379325, 74.79548181806291, 60.74147169930594, 62.9180018561227, 66.53922230856759, 55.93614271708897, 63.74410792759487, 82.87655639648438, 94.50121225629533, 79.52626010349819, 69.8108719417027, 75.51292501177106, 79.06181471688407, 76.51319462912423, 82.12704031808036, 74.80254118783134, 78.43284293583461, 81.4878477369036, 77.87757069723946, 68.85522365570068, 71.08853449140275, 77.4159184864589, 81.76221125466483, 80.57149151393345, 79.76700823647636, 82.94771984645298, 79.45288017817906, 81.83434050423759, 77.09865679059709, 77.50514725276402, 71.67468452453613, 68.87449101039341, 66.07176835196358, 64.27980709075928, 62.85794162750244, 64.9254128592355, 65.56027671269008, 66.20915508270264, 66.33718258993966, 69.20209857395717, 68.98439066750663, 74.0583335331508, 75.2793960571289, 83.0733710697719, 87.68795463017055, 50.48824085508074, 2.769637725182942, 0.7577807434967586, 0.11161898342626435, 0.012598085732731436, 0.0655465235135385, 0.01987669779919088, 0.11965966410934925, 0.13179394655994006, 0.2783997154661587, 8.112049647739955, 41.08452803747994, 67.45319529942104, 92.77484893798828, 70.2381375176566, 66.44400419507707, 78.74214199611119, 77.26443386077881, 52.434212412152974, 22.47338727542332, 46.78353432246617, 50.063636439187185, 56.06804037094116, 66.87743282318115, 35.82882377079555, 1.0385323699031557, 0.06659411372882978, 0.09273016984973635, 0.03068716012473617, 0.07378089201769658, 0.04774135071784258, 0.07990006330822196, 0.05630216920482261, 0.10465269509170737, 0.10881186369806528, 0.020986894744315317, 0.12170840560325555, 0.07492086477577686, 0.03564790250467403, 0.11174335889518261, 0.02861997944169811, 0.1031639010512403, 0.03854766601164426, 0.05411786659221564, 0.06387991937143461, 0.05448510670768363, 0.04238907327609403, 0.0866688233135002, 0.09628152035708938, 0.05232903793720262, 0.03647547774016857, 0.06828393055392162, 0.046381505472319465, 0.017205481849876896, 0.05325885143663202, 0.03924771398305893, 0.0316869407626135, 0.02790398250467011, 0.049197127244302204, 0.044066727360976596, 0.05064570112153888, 0.09330714174679347, 0.045050369043435366, 0.022643236044262136, 0.060231612995266914, 0.11302631933774267, 0.021745405292936733, 0.0469842752707856, 0.8078151558126722, 82.69109507969448, 123.76054900033134, 100.60758795057023, 93.52779742649624, 101.90262794494629, 103.45973314557756, 89.04995441436768, 63.868557112557546, 48.06910044806344, 79.63873059409005, 102.71827002934047, 86.46591935838971, 110.14255918775285, 118.27725301470075, 100.68991715567452, 13.975178463118416, 0.5202507664050374, 0.16683045508606092, 0.4042187269244875, 0.22793921029993466, 0.26804592247520176, 0.3079430487539087, 0.18752499962491648, 0.4348962993494102, 0.7756309913737434, 0.13806400368256228, 5.488210533346448, 80.11486979893276, 90.61980261121477, 96.75825813838414, 87.12288543156215, 90.54401166098458, 82.2742587498256, 76.12023230961391, 68.84963035583496, 68.5666024344308, 65.2522839137486, 64.47506536756242, 60.13843754359654, 65.66267926352364, 67.00826740264893, 70.4222856249128, 65.9179630279541, 66.64034639086042, 69.31385340009416, 68.25291906084333, 66.69636971609933, 62.00602994646345, 73.1613141468593, 81.08101681300572, 86.95086193084717, 95.59093993050712, 79.11634417942592, 77.48765863691057, 66.69414629255022, 67.91397898537772, 75.13916751316616, 86.41354383741105, 84.00858470371791, 85.93973227909633, 78.8637285232544, 84.29913752419608, 81.89595712934221, 79.73766599382672, 68.56827000209263, 65.98235893249512, 72.86753041403634, 66.59609331403459, 68.22042233603341, 88.12696960994175, 94.11320400238037, 83.10152517046247, 76.09373188018799, 81.1150074005127, 82.87664672306606, 83.79281534467424, 86.12888308933803, 79.93789223262242, 81.46081229618618, 85.60585744040353, 80.55995055607387, 73.85100623539516, 73.94293785095215, 80.58944565909249, 83.47991711752755, 82.76380102975028, 81.97691059112549, 86.17508166176933, 82.34949384416852, 85.64310673304966, 81.15393120901925, 82.68852424621582, 74.61214665004185, 72.79472024100167, 72.18257004874093, 68.60507461002895, 65.42066655840192, 67.33229664393834, 68.195679800851, 71.42035266331264, 69.5236542565482, 70.64894975934709, 73.81026199885777, 78.57459313528878, 78.5951042175293, 85.31190695081438, 91.80975110190255, 64.79755210876465, 7.617382202829633, 0.4642932862043381, 0.09670552331954241, 0.09714703927082674, 0.2249851402427469, 0.03552276368385979, 0.37356539177043097, 0.07425252813845873, 0.2930304503866604, 5.974867573806217, 45.244560446058, 69.36406108311245, 101.17406068529401, 77.95268767220634, 64.34175722939628, 40.63032776968819, 42.87729181562151, 60.823745318821494, 39.63220167160034, 59.172644887651714, 67.02252510615757, 63.71045085362026, 80.29267420087541, 51.89645310810634, 0.48310455679893494, 0.16984367982617446, 0.1413802078792027, 0.04847275379246899, 0.06556658779403993, 0.03926122022260513, 0.06104723922908306, 0.057327598466404846, 0.044732529670000076, 0.10072482550250632, 0.02989022753068379, 0.05750918122274535, 0.034212855223034105, 0.0060676467338843, 0.031335103392068825, 0.02578104320647461, 0.013118449149520268, 0.04973904262962086, 0.023528939678466747, 0.04267048888972827, 0.05335647226976497, 0.014219378154458744, 0.03224011643656662, 0.05794670060276985, 0.2781612511192049, 0.09973411009247814, 0.1301331099654947, 0.12917428570134298, 0.2688217322741236, 0.18791272810527257, 0.20035005786589213, 0.17884405329823494, 0.10901320539414883, 0.12064724468759128, 0.18623323179781437, 0.1548100443822997, 0.42438714898058344, 0.17427467634635313, 0.1161175077514989, 0.16233796972249234, 0.1980892334665571, 0.1412967752133097, 0.3193525879510811, 1.3343738551650728, 100.52116625649589, 140.11412102835519, 114.2727004459926, 98.5054452078683, 95.56817068372453, 95.07653699602399, 76.71916007995605, 40.9220791544233, 44.46994400024414, 74.88833754403251, 103.61339255741665, 107.81950541904995, 113.49479402814592, 122.51108224051339, 116.08187934330532, 24.074429409844534, 0.9385193479912621, 0.5440532863140106, 0.7729735768267086, 0.41841498230184826, 0.5809153797371047, 0.29425338762147085, 0.19540684883083614, 0.42217691615223885, 1.4025221126420158, 0.4546758122742176, 5.905613141400473, 89.02077198028564, 92.47817475455147, 102.79345648629325, 89.93091651371547, 97.27011108398438, 86.34251935141427, 79.28040504455566, 69.62488951001848, 73.88090433393205, 70.19751834869385, 67.15627098083496, 64.53313146318708, 70.89178235190255, 71.4158432824271, 77.02838965824672, 70.31682586669922, 69.9377668925694, 72.72691971915108, 70.67372008732387, 70.37312017168317, 67.04960223606655, 75.89180333273751, 85.00285107748849, 89.4949517931257, 97.24771009172711, 83.4959466116769, 78.28859833308628, 68.15791634150914, 71.01830904824394, 78.62110437665666, 89.21924727303642, 87.28889874049595, 87.28421565464565, 81.48152487618583, 87.56487424033028, 84.46265642983573, 87.54216752733502, 80.397828238351, 79.97744832720075, 81.40776974814278, 73.94237504686627, 75.39037963322231, 85.81768717084611, 88.34491375514439, 83.20308698926652, 82.54154900142125, 86.64271627153668, 83.38940293448312, 82.91591099330357, 85.37133489336286, 78.75303677150181, 83.87725680215019, 87.97278213500977, 84.29287719726562, 77.99166011810303, 78.3459974016462, 85.48127623966762, 91.90888105119977, 84.98971203395298, 86.89777074541364, 91.03738239833287, 88.74348327091762, 91.10409205300468, 86.4630150113787, 88.31673186165946, 78.90965611594063, 75.97278458731515, 75.3336545399257, 71.31731782640729, 67.26079968043736, 69.54614557538713, 71.88283865792411, 73.22813497270856, 73.48128564017159, 74.68440791538784, 78.91747978755406, 83.5997735432216, 84.56494780949184, 91.88260296412876, 99.72849491664341, 61.22365583692278, 5.108871025698526, 2.6804719269275665, 1.0945333306278502, 0.45657888587032047, 0.6483853193266051, 0.12434369990868227, 0.3387797512114048, 0.21568196373326437, 0.41484168118664194, 12.76423077923911, 60.5531199319022, 76.1224696295602, 115.00703471047538, 84.06264863695417, 87.7835271017892, 111.77204377310616, 88.97102287837437, 63.3026054927281, 32.71101072856358, 56.75025619779314, 70.72772148677281, 75.18857615334647, 92.82538318634033, 70.188631602696, 1.3892450822251183, 0.5105559666241918, 0.17607447691261768, 0.15799816830882005, 0.16663579695991107, 0.15845535163368496, 0.2357947187764304, 0.23621581760900362, 0.22717285927917275, 0.21409064983682974, 0.12616648924137863, 0.2688985695796353, 0.15759230937276567, 0.0885051494198186, 0.12555279502911226, 0.08352785078542573, 0.0826644217595458, 0.10501473423625741, 0.11280695575156383, 0.16839553681867464, 0.19617134066564695, 0.12026332957404, 0.1356089147073882, 0.24726459330746106], [0.00531362893525511, 0.012005424409705614, 0.03293300925620964, 0.007711153543953384, 0.04001938471836703, 0.003085806146762999, 0.08243481229458537, 0.040938531647303274, 0.050964395449097664, 0.06130564572023494, 0.05791728610971144, 0.02579371484794787, 0.03724311458479081, 0.07645185690905366, 0.0834936797618866, 0.052366940903344324, 0.06583800858684949, 0.10063084840242352, 0.18032046407461166, 53.775020190647666, 94.10417829241071, 81.45559419904436, 77.36479364122663, 68.91115665435791, 53.66540888377598, 31.85681309018816, 30.486058575766428, 34.29782295227051, 51.80980907167707, 64.11772646222795, 63.77077511378697, 101.28876154763358, 109.61147362845284, 92.7072777066912, 18.28516776221139, 0.7185489886573383, 0.15284857606249197, 0.1523613336363009, 0.025861305417492986, 0.06871602165379695, 0.04932578766186323, 0.07249305969370262, 0.0800039063074759, 1.3161654493638446, 0.01836959518758314, 3.9546879529953003, 60.79732826777867, 85.6568363734654, 99.7546409879412, 91.06217357090541, 91.59300204685756, 88.41272817339215, 88.99626568385533, 84.39878858838762, 78.82247012002128, 65.60095841544015, 66.42659895760673, 65.92343820844377, 66.21504715510777, 64.67588915143693, 68.2542392185756, 66.9175864628383, 69.80429894583565, 73.11264896392822, 70.86285700116838, 68.21247359684536, 64.6458659853254, 61.28191648210798, 69.5111336026873, 76.08450467245919, 85.44025407518659, 76.38841887882778, 73.94622434888566, 73.6555256162371, 64.80832876477922, 60.28355067116873, 71.10199315207345, 78.33728436061314, 82.15274170466832, 82.10307598114014, 73.03359930855888, 71.6695637021746, 70.59651865277971, 67.87697287968227, 64.00303254808698, 50.80776766368321, 71.94146060943604, 59.12058898380825, 65.25640419551304, 99.97282137189592, 89.77147620064872, 72.02963324955532, 60.726588657924104, 69.87154361179897, 73.0435699735369, 82.49755995614188, 77.70704800742013, 72.54942798614502, 78.48577431270054, 76.31975678035191, 69.0573537009103, 68.49555710383824, 62.26817853110177, 67.84535162789481, 70.5853112084525, 81.15907982417515, 77.7491124016898, 73.47432354518345, 81.85512951442173, 81.61446475982666, 78.2570743560791, 80.74926812308175, 79.73485197339738, 78.80282061440604, 74.96687303270612, 71.67554610116142, 70.2257558277675, 66.64285469055176, 66.072067124503, 65.5986099243164, 65.76184395381382, 59.78507995605469, 63.71181270054409, 70.7933680670602, 79.41394247327531, 77.02165685381208, 78.93323135375977, 88.23053250994, 76.43955762045724, 10.436769247055054, 0.30365587451628273, 0.08856913527207715, 0.017023337605808462, 0.11061151498662573, 0.02889923731397305, 0.18028102761932782, 0.1092941053211689, 0.20568050683609077, 11.00102984905243, 33.28032527651106, 48.52133437565395, 77.08039692470005, 67.57641465323312, 70.37247398921421, 55.917924540383474, 30.7913624218532, 30.59736176899501, 22.720180341175624, 39.29599918637957, 61.5588230405535, 67.91812011173793, 69.39829485757011, 26.63059871537345, 1.0860205931322915, 0.025010458127196347, 0.06277665535786323, 0.02124007142681096, 0.027619606782017008, 0.03212128459875073, 0.06592632670487676, 0.0215617038110005, 0.01125831579390381, 0.0881668318595205, 0.06015579349228314, 0.00802498362359724, 0.013413625453332705, 0.07477263880095311, 0.012830046321531492, 0.09064581883805138, 0.09227513748088054, 0.012009062205574341, 0.11990336674664702, 0.07579844804214579, 0.09681132728500025, 0.046382611484399865, 0.07418544816651515, 0.08372795076242515, 0.03987452766991087, 0.006896333918640656, 0.08261551295540162, 0.015535498603380151, 0.03515091631561518, 0.05297339175428663, 0.010628081442389106, 0.07587602495082788, 0.032595214167875905, 0.05151378829032183, 0.10155939643404313, 0.041797943745872805, 0.07681135833263397, 0.07180725756500449, 0.03752182962905083, 0.019406924257054925, 0.0948217608300703, 0.05854410318923848, 68.89382784707206, 108.41366672515869, 86.96778774261475, 105.81372724260602, 94.0357037952968, 77.86452892848423, 58.90547275543213, 50.19997746603829, 31.2999392918178, 11.493955901690892, 45.79122386659895, 76.06347247532436, 108.94416168757847, 111.41014684949602, 101.38275677817208, 18.500725201198033, 0.8666882195643016, 0.08195618047778096, 0.2711766559098448, 0.15770527188267025, 0.22499810026160308, 0.2039675044694117, 0.3535751530102321, 0.43806915623801096, 1.5855729473488671, 0.07073609504316535, 6.788604548999241, 73.1340285709926, 88.86397893088204, 100.28241225651333, 94.55788176400321, 97.71743610927037, 94.17101996285575, 94.41307435716901, 88.38607488359723, 84.09933512551444, 69.8611421585083, 70.85273347582135, 68.7631322315761, 71.09494073050362, 69.1261408669608, 71.97442981175014, 69.13716070992606, 73.5165546962193, 77.66521985190255, 75.88372257777623, 72.7605767931257, 68.91217109135219, 64.90321336473737, 73.78822231292725, 78.16087654658726, 89.8633313860212, 79.73012719835553, 80.39286027635846, 76.59250831604004, 69.88144479479108, 65.12560435703823, 72.70980630602155, 80.96671199798584, 84.792633329119, 83.93477399008614, 77.838883127485, 75.75490992409843, 72.95664800916398, 73.12325886317662, 72.62705326080322, 60.566397939409526, 77.23416055951799, 65.62658337184361, 73.4387070792062, 99.16962351117814, 90.59831183297294, 73.45508398328508, 63.90615381513323, 74.1485767364502, 75.1948573248727, 85.83641256604875, 81.08781909942627, 77.18808010646275, 79.11377334594727, 79.9847856249128, 71.29244327545166, 71.18235601697648, 64.7558559690203, 71.93847983224052, 75.41637979234967, 85.02984482901437, 80.98206056867326, 76.35868058885846, 84.61100046975272, 84.90354742322648, 83.35330704280308, 85.30646651131767, 84.3800492967878, 84.411878994533, 80.018602507455, 77.50775282723563, 74.41978577205113, 70.96206338065011, 69.14695766993931, 69.36508246830532, 69.42998559134347, 64.30405630384172, 67.39835316794259, 71.0838097163609, 82.60301971435547, 82.46807874952043, 80.74555778503418, 89.36700071607316, 86.08610997881208, 20.831996951784404, 0.19387399751160825, 0.05984634081167834, 0.3869546518794128, 0.19286838147257054, 0.04850929968857339, 0.1301526924861329, 0.10426186570631606, 0.4004655326051371, 8.542390670095172, 37.8281957081386, 51.13119241169521, 81.25818198067802, 76.58642864227295, 69.52437686920166, 39.60150453022548, 15.37073196683611, 35.903489112854004, 49.73015069961548, 56.13474307741438, 81.00764383588518, 70.08397088732038, 81.12866755894252, 40.42370571408953, 0.771841997546809, 0.01875439578933375, 0.043092096623565466, 0.018367693593193377, 0.04390624365104096, 0.014639852734814798, 0.03555556406666126, 0.021578880924997584, 0.069376568709101, 0.02845457974555237, 0.0582203334197402, 0.01989167306705245, 0.031179389783314297, 0.06817413001720395, 0.04794064323816981, 0.07080251005079065, 0.01697178590776665, 0.015538048198712724, 0.039975242622728856, 0.03532754237364445, 0.013343799110901142, 0.025900387338229587, 0.0346895905344614, 0.11023993563971349, 0.13681635420237268, 0.11457548263881888, 0.1564951046769108, 0.11716129817068577, 0.1385360469243356, 0.09156936606658356, 0.17711966511394295, 0.19175935669669084, 0.15807306500417845, 0.23633974524480955, 0.2710145131817886, 0.1470541177051408, 0.1313954158020871, 0.16146253741213254, 0.18208080104419164, 0.1654828166855233, 0.11966682943914618, 0.24355580231973104, 86.72803320203508, 122.02650097438267, 98.97039086478097, 105.35762664249965, 93.44422449384416, 68.71035371507917, 41.834183079855784, 37.0868889263698, 47.27705444608416, 65.09794357844761, 94.68440846034459, 99.4268388748169, 110.65539182935441, 115.4086753300258, 112.98516450609479, 30.333017553601945, 1.2105745439018523, 0.26275818049907684, 0.26555257769567625, 0.34200406819581985, 0.8191600441932678, 0.17918707989156246, 0.263924310782126, 0.46876282351357595, 3.5066311955451965, 0.09416582781289305, 7.2675347583634515, 75.18806198665074, 86.85078007834298, 104.96305234091622, 96.12795230320522, 101.37002073015485, 96.62439414433071, 97.32762132372174, 93.72160352979387, 90.56352915082658, 75.36289255959647, 75.27767290387834, 73.5181805746896, 74.5277190889631, 72.80436434064592, 76.64277158464704, 74.16660731179374, 77.36252852848598, 82.61287920815604, 80.28937380654472, 75.49032252175468, 71.5500407900129, 70.3939300264631, 78.74086352757045, 85.21211692265102, 90.36484541211809, 83.78107288905552, 82.46548012324742, 79.81324849809918, 74.32868099212646, 69.36006586892265, 77.28615392957414, 85.2188914162772, 87.99633652823312, 90.00472722734723, 77.96967601776123, 80.68208599090576, 77.5077041898455, 81.15561267307827, 81.96871171678815, 71.21300452096122, 86.73933097294399, 77.25758988516671, 76.15199947357178, 90.24336310795375, 89.55396284375871, 80.39392335074288, 74.10133593423026, 77.18061774117606, 79.67133154187883, 88.11184338160923, 86.54131426130022, 78.94941370827812, 83.7367503302438, 83.75735868726457, 75.56902476719448, 74.30115917750767, 69.9773507799421, 74.74831744602749, 79.22791140420097, 90.05364254542759, 83.2071864264352, 78.65207249777657, 89.6375288282122, 87.88278906685966, 87.50357028416225, 88.6134477342878, 88.82185200282505, 87.68887179238456, 82.9988933290754, 79.83894293648856, 77.19776589529855, 74.82230881282261, 72.90536335536412, 71.90745612553188, 72.19709178379604, 67.15635435921806, 69.50859751020158, 77.45573166438511, 90.20432812826974, 87.46377100263322, 83.63930184500558, 98.52054364340646, 87.07921600341797, 16.297936064856394, 0.9359944377626691, 0.7949681537491935, 0.5596757680177689, 0.5189884741391454, 0.0837536808103323, 0.22356373151498182, 0.203867054145251, 1.2909706298794066, 20.502471685409546, 52.776456356048584, 60.02490397862026, 93.70800590515137, 80.77569212232316, 96.5083314350673, 81.06441061837333, 39.471170221056255, 37.317256450653076, 33.73984439032418, 51.48864596230643, 83.12942218780518, 82.61752755301339, 93.51723616463798, 55.50653559820992, 1.5724295611892427, 0.11492589169314929, 0.15210176685026713, 0.11924240578498159, 0.1049773944541812, 0.08762243642870869, 0.1599239321159465, 0.10132844346974577, 0.11233639171613113, 0.15185954341931002, 0.19343300403228827, 0.15833654015191964, 0.17163166031241417, 0.16828583127685956, 0.12326648485447679, 0.0720081649986761, 0.1469829258109842, 0.13805093509810312, 0.16795222274959087, 0.1248989858265434, 0.170918058604002, 0.0860862195757883, 0.16517634955900057], [0.051911341957747936, 0.11409213500363485, 0.0551743082968252, 0.01706161206987287, 0.05459543650171586, 0.06306658658598151, 0.06253921559878758, 0.01905259327031672, 0.08287258951791696, 0.10903698126120226, 0.011016172090811389, 0.07682754817817893, 0.07356146736336605, 0.07842225474970681, 0.03927931675155248, 0.07320180987673146, 0.23824827426246234, 0.749001260314669, 18.26111830983843, 100.99866036006382, 89.50267124176025, 89.78127316066197, 41.66789879117693, 32.42407097135271, 31.985650062561035, 42.14479187556675, 48.087603500911165, 93.71459279741559, 163.23897661481584, 107.31630992889404, 119.0329668862479, 113.6197087424142, 93.14088003976005, 26.660015651157924, 0.5831270782010896, 0.18025152491671698, 0.10624213623149054, 0.08987000903912953, 0.10342390888503619, 0.1494430359452963, 0.46858797860997065, 0.15624039620161057, 0.9430786690541676, 0.41421580048544065, 6.419569654124124, 70.75484725407192, 98.87506852831159, 97.62127304077148, 92.04626778193882, 97.30180181775773, 97.28878784179688, 96.70783506120954, 93.52496256147111, 86.5982894897461, 79.28724902016776, 68.12947736467633, 66.17269093649728, 61.864474296569824, 66.00601060049874, 68.43831784384591, 69.89901678902763, 74.46725586482457, 73.41347122192383, 77.60579885755266, 78.75989464351109, 72.11907741001674, 67.78543731144497, 64.28621332986015, 66.93118408748082, 73.82501302446637, 88.03330789293561, 76.79802908216203, 84.36350563594273, 74.74792834690639, 65.77742181505475, 60.07871777670724, 65.26982116699219, 75.43898228236607, 81.18965189797538, 81.23198727199009, 84.18197005135673, 78.35790661403111, 67.4945787702288, 64.40837655748639, 64.22163677215576, 54.267407757895334, 64.76681327819824, 60.62665966578892, 81.66490868159703, 95.6365270614624, 78.20080089569092, 59.50306647164481, 58.04081112997872, 77.86824621473039, 75.01756708962577, 76.58642864227295, 71.29029628208706, 69.03000559125627, 66.22577517373222, 70.76621450696672, 68.15749944959367, 64.40415900094169, 60.30440221514021, 59.019819259643555, 64.34700311933244, 78.36002581460136, 79.36522170475551, 81.2706470489502, 77.57952771868024, 80.95594923836845, 79.8949454171317, 81.36360004970005, 76.83396516527448, 79.29589257921491, 79.62631416320801, 78.86147730691093, 74.96886021750313, 75.16473688398088, 69.61977563585553, 73.90440314156669, 67.81611360822404, 66.30438014439174, 61.216825757707866, 62.31792068481445, 62.8302252633231, 71.56857858385358, 78.20704732622418, 78.56799234662736, 80.46052878243583, 92.78878702436174, 12.661953295980181, 0.48053551465272903, 0.26811654439994265, 0.4610285013914108, 0.34435931752835003, 0.08823469214673553, 0.10671158068414245, 0.25355569858636173, 1.0611831716128757, 10.771523901394435, 16.91567608288356, 37.2709675516401, 73.21643420628139, 78.33655479976109, 70.69044440133231, 75.16635581425258, 51.7569124358041, 19.833146503993444, 18.450281279427664, 30.0941732270377, 69.70160457066127, 60.575117928641184, 73.94354929242814, 30.943104130881174, 0.5782594308257103, 0.07112891932151147, 0.057234883441456726, 0.03110894767035331, 0.011938712543009647, 0.12831114844552108, 0.03587010915258101, 0.032661697029003074, 0.03392945150179522, 0.02521507884375751, 0.03364997649831431, 0.04646462940477899, 0.061221656655626636, 0.07978248676019055, 0.06207631900906563, 0.060687459606145105, 0.05901282160942044, 0.0707266837624567, 0.11167830774294478, 0.02580870877552245, 0.08631992060691118, 0.026915228060845817, 0.038737828843295574, 0.03593458015737789, 0.03616609630574073, 0.09078251650290829, 0.01760965971542256, 0.02208829957193562, 0.02231178865102785, 0.04255820491484233, 0.027236002098236765, 0.018046746529372673, 0.0595322401661958, 0.033836590591818094, 0.06807604099490813, 0.023856982522244965, 0.14901497534343175, 0.09508119869445052, 0.2367379367351532, 0.7588513089077813, 24.690522704805645, 118.96155330113002, 96.72769301278251, 112.18293244498116, 55.25863429478237, 49.2188675062997, 52.24194186074393, 50.46219205856323, 20.832320043018886, 35.27753632409232, 106.8215981892177, 110.66080447605678, 125.32914652143205, 114.41421440669468, 103.0687997000558, 27.418109280722483, 0.4566179152045931, 0.21990280438746723, 0.11603487575692789, 0.022712858826188103, 0.13628487129296574, 0.15492276261959756, 0.9945097778524671, 0.6806301719376019, 0.46652821770736147, 0.34180107765964096, 10.344636133738927, 86.70300579071045, 104.08677332741874, 99.38579586574009, 95.33403028760637, 101.18710245404924, 98.30889456612724, 99.77795914241246, 96.74074172973633, 89.81404781341553, 82.52249704088483, 71.9774522781372, 69.91868713923863, 63.946898051670615, 68.01404694148472, 72.00423758370536, 72.15037904466901, 77.61000946589878, 78.67048522404262, 83.34179387773786, 79.09581920078823, 75.63196155003139, 71.55531447274345, 68.58473723275321, 70.91873441423688, 78.02584525517055, 91.8326940536499, 80.53734806605748, 89.25886590140206, 79.38990865434918, 69.18003109523228, 62.350035258701865, 66.49039036887032, 78.36849566868374, 82.68191650935582, 83.49334103720528, 84.65668487548828, 79.81834847586495, 74.76458317892892, 73.08964347839355, 73.03911617824009, 65.18451813289097, 67.41666167122978, 66.90158476148332, 84.80748162950788, 93.42561026981899, 80.23479570661272, 63.357398986816406, 63.80911527361189, 78.4379220690046, 76.90590681348527, 79.89116559709821, 74.17914881025041, 73.38572706495012, 70.97472994668144, 74.15234266008649, 72.86527919769287, 69.96416309901646, 64.15539264678955, 61.90228639330183, 68.75503063201904, 81.26217719486782, 81.78401470184326, 83.51008619580949, 81.68739305223737, 82.20461695534843, 83.63095011029924, 83.55621528625488, 79.64144733973912, 82.35661574772426, 82.66840921129499, 82.64830807277134, 77.78843920571464, 78.65619277954102, 75.1302946635655, 77.14847537449428, 70.06768430982316, 68.39278629847935, 65.52012307303292, 66.83201244899205, 65.47136756352016, 73.76146480015346, 81.13822828020368, 81.32880347115653, 79.26158932277134, 99.22659873962402, 21.420436416353496, 0.19902824450816425, 0.38472968127046314, 0.5258038427148546, 0.6244719539369855, 0.10232241584786347, 0.08258977612214428, 0.11131901666522026, 0.9991684364421027, 10.45589850630079, 19.726354428700038, 44.584665707179475, 78.23912021092006, 85.65518270220075, 74.66801016671317, 45.40159320831299, 16.97730139323643, 20.13787886074611, 36.23796844482422, 45.161974157605854, 82.18184076036725, 73.4502202442714, 84.77739592960903, 44.822585923331125, 0.438031972518989, 0.027105674180867415, 0.027838191749261956, 0.06584218836256436, 0.044389282552791495, 0.08590535606656756, 0.02326023641840688, 0.036196460747825246, 0.016679615514086824, 0.052723042866481204, 0.030641966299819093, 0.05390508479571768, 0.06791303652737822, 0.07015579832451684, 0.019916293710204105, 0.036201101927352805, 0.02652760305708008, 0.0073301010000120315, 0.1000144671914833, 0.02090442050913615, 0.04285975605515497, 0.008442522691828864, 0.06723556002335888, 0.24404076486825943, 0.15848067456058093, 0.16611754548336777, 0.16487959905394486, 0.16379329163048947, 0.29291602224111557, 0.13777600627924713, 0.196595235062497, 0.15118742734193802, 0.1234388327492135, 0.17206561059824058, 0.15715233369597367, 0.13115636791501725, 0.3539995902350971, 0.41212276422551697, 0.4563084489532879, 1.1267856742654527, 35.13206883839199, 137.2043961116246, 107.81658717564174, 116.18407344818115, 57.818135261535645, 43.682796478271484, 48.73761095319475, 58.070486886160715, 64.31866141727993, 111.29766246250698, 200.59101922171456, 141.00389344351632, 126.31480407714844, 125.1576371874128, 112.77780941554478, 41.43123272487095, 0.765693873167038, 0.4009935956980501, 0.29182349943688934, 0.5318798795342445, 0.2837126718035766, 0.47035043260880877, 0.9921102608953203, 1.732076148901667, 7.758296012878418, 0.9809412487915584, 10.900382586887904, 90.01606668744768, 106.32869298117501, 104.40981592450822, 97.51560483660016, 104.69264234815324, 102.32324409484863, 102.67177963256836, 100.11147962297711, 93.73285961151123, 89.28938933781215, 73.9544927052089, 74.39578669411796, 69.5517805644444, 72.02215698787144, 77.27657931191581, 76.08605412074498, 81.84617328643799, 81.49486541748047, 86.4324220929827, 85.77941649300712, 79.81930037907192, 75.85656206948417, 72.71179349081856, 74.63836220332554, 82.27899742126465, 93.82776505606515, 80.62611825125558, 91.20552880423409, 82.40311309269497, 72.90625967298234, 64.29568372453961, 70.33680193764823, 82.59280586242676, 88.30342606135777, 86.67108576638358, 89.27956458500454, 82.46370138440813, 75.46853991917202, 77.79367119925362, 78.03232792445591, 72.51778588976178, 75.7926664352417, 78.14292240142822, 81.71568611689976, 90.34860747201103, 79.9118503843035, 68.99502141135079, 71.81446143559047, 84.8889353615897, 81.16370732443673, 81.8647597176688, 77.10144301823208, 76.12217085702079, 74.78430911472866, 77.521454674857, 77.86288915361676, 72.53045245579311, 69.59631156921387, 66.07868875776018, 74.7124022075108, 86.09027889796666, 87.43524169921875, 86.92276341574532, 86.93410982404436, 88.5481207711356, 87.27512741088867, 89.58170005253383, 82.65191418784005, 86.72480923788888, 89.05212225232805, 86.03902203696114, 81.28669738769531, 81.59656620025635, 78.04738467080253, 79.32461643218994, 71.9354226248605, 71.71083600180489, 66.9710111618042, 68.88282190050397, 69.36968912397111, 78.2636820929391, 85.85810484204973, 85.30734198434013, 87.21943759918213, 104.65459401266915, 16.985132013048442, 1.4486212389809745, 0.702976501413754, 0.7258553451725415, 1.2695486822298594, 0.18836461885699204, 0.3059431346399443, 0.2094004936516285, 5.07025945186615, 23.482891048703873, 39.03449331011091, 60.04298319135393, 89.91745785304478, 96.05759484427315, 88.55475630078996, 114.26198632376534, 70.21233885628837, 26.57009380204337, 26.610780715942383, 42.8930572782244, 89.804765020098, 78.98141016278947, 96.44551971980503, 60.32651833125523, 0.706377101796014, 0.12198484076985291, 0.1941135068024908, 0.2388963566294738, 0.10603047401777335, 0.4031190387904644, 0.11580467596650124, 0.16514794608311995, 0.25020625974450794, 0.14589280502072402, 0.1092136310679572, 0.11892719912741866, 0.27488598972558975, 0.15916718915104866, 0.1946339431617941, 0.16957257794482367, 0.12785496935248375, 0.15281074094985211, 0.2646232289927346, 0.15195858239063195, 0.13660223569188798, 0.14524105856461184], [0.06722492737961666, 0.02245139723111476, 0.03467584680765867, 0.1039654001859682, 0.07284471046711717, 0.07162790718887534, 0.051810297915445905, 0.06163149859224047, 0.029689974883305173, 0.04752839928758996, 0.025938057906127403, 0.05569813393854669, 0.03184089018031955, 0.06091569843036788, 0.10311099567583629, 0.14273533730634622, 0.14048353742275918, 1.0959143936634064, 60.084463936941965, 94.67267295292446, 79.17798859732491, 45.52354104178292, 68.74458054133824, 100.12153366633824, 80.95919404711042, 79.20022283281598, 103.11380318232945, 112.6114695412772, 100.99999441419328, 117.08562305995396, 108.07897894723075, 91.02008138384137, 30.733852182115825, 0.5918365365692547, 0.02951743360608816, 0.30129533261060715, 0.09524507847215448, 0.44666076664413723, 0.08699464904410498, 0.5485605501702854, 0.7956706274832998, 1.771660036274365, 0.5450624578765461, 7.064818024635315, 69.63035079411098, 91.26340729849679, 94.6203669139317, 88.11356653485979, 91.56889179774693, 90.73562213352749, 93.11004393441337, 88.9829112461635, 92.21949332101005, 85.87397452763149, 78.66366209302629, 67.34599154336112, 63.775215012686594, 67.69054576328823, 69.5515443256923, 74.32392842429024, 76.65169307163784, 76.34909902300153, 80.47480733054024, 80.18087768554688, 76.76908983503068, 74.18998105185372, 67.77432714189801, 60.982970237731934, 66.60422270638603, 75.07163102286202, 76.0289260319301, 81.9544540132795, 77.77820450919015, 72.98451723371232, 66.37054089137486, 66.33008847917829, 61.69965607779366, 69.26047039031982, 73.9726483481271, 78.98924773080009, 68.43945734841483, 67.17629568917411, 80.51770550864083, 64.60627514975411, 66.26884705679757, 69.55549090249198, 60.29409108843122, 76.77612141200474, 78.33707591465541, 72.3015718460083, 75.48643847874233, 52.85928235735212, 61.58455221993582, 69.44020639147077, 72.17230061122349, 70.09906932285854, 65.88163089752197, 68.48038223811558, 70.38926778520856, 69.5994313103812, 66.75558921269008, 62.82932199750628, 64.347809110369, 57.60645144326346, 61.21040562220982, 63.497113364083425, 67.63605798993791, 73.7087835584368, 74.93234048570905, 73.2726868220738, 76.63671970367432, 74.59674944196428, 77.74046884264264, 79.3058146068028, 77.85314083099365, 78.53211184910366, 76.18009798867362, 77.85380785805839, 79.30338273729596, 76.68008341108049, 72.83759757450649, 68.42961869921002, 66.01215975625175, 64.45378998347691, 64.49301951272147, 63.013539586748394, 66.11814062935966, 74.40110901423863, 78.04411206926618, 79.14287934984479, 84.84498105730329, 3.0514086740357533, 0.8483265734144619, 0.3402119757873671, 0.27455453893968035, 0.16651532985270023, 0.06407686416059732, 0.030567870275782685, 0.0862730677638735, 1.5415834678070885, 2.8117739898817877, 3.8824440581457953, 33.65681341716221, 72.11838259015764, 82.09415449414934, 64.03202043260846, 94.42614391871861, 85.80595861162458, 27.354922362736293, 29.370851857321604, 35.011962277548655, 59.30452864510672, 53.26502936226981, 67.69426304953438, 16.499232326235088, 0.20222219026514462, 0.07125940160559756, 0.0617562879675201, 0.02762882468024535, 0.1402502299419471, 0.029123835797820772, 0.1498428966317858, 0.025749844166317155, 0.020334761523242508, 0.01764241768978536, 0.013151277521891254, 0.02523446798191539, 0.017435333891106502, 0.11250318919441529, 0.05262453993782401, 0.051038705211664946, 0.033819135278463364, 0.037318245374730656, 0.04170002435733165, 0.16457615819360527, 0.1144077894943101, 0.08645200423364129, 0.022589168677638684, 0.008337805230569626, 0.07684575327272926, 0.04098297569102474, 0.05090219753661326, 0.06508813239634037, 0.030862357866551195, 0.06530503968575171, 0.027705434676525847, 0.04888736243758883, 0.052408996503800154, 0.038697418690259965, 0.056392214194472344, 0.10195128433406353, 0.049713495786168745, 0.2060282967452492, 1.190235321010862, 72.8876176561628, 106.92678001948765, 90.61266681126186, 62.628942898341585, 85.9585132598877, 72.05243028913225, 48.909467697143555, 49.966281754629954, 56.57467869349888, 103.81115218571254, 111.12574318477085, 117.44050925118583, 109.34543405260358, 100.1977206638881, 35.56379863194057, 0.6716310062578746, 0.021330406490181173, 0.14435873233846255, 0.11419147253036499, 0.6124659553170204, 0.20446839902017797, 1.4455684827906745, 0.6360506926264081, 0.8282436739121164, 0.43389999281082836, 11.578460761478969, 83.51041276114327, 99.6519535609654, 96.2429449898856, 91.92942687443325, 95.79263223920549, 94.40341636112758, 96.90548351832798, 93.08497483389718, 93.7182753426688, 88.12975583757672, 83.58134692055839, 70.58867413657052, 66.21508884429932, 73.84376621246338, 75.34550816672188, 77.1787417275565, 79.51699815477643, 79.78551823752267, 83.19697257450649, 83.06681891850063, 80.9745843069894, 76.33710643223354, 69.6226452418736, 63.31662000928606, 71.92039367130825, 77.04778208051408, 80.27697127205985, 85.37181431906563, 80.39073412758964, 76.63510077340263, 68.8331492287772, 67.59853771754673, 65.85707596370152, 70.35936968667167, 75.75035885402134, 81.58795043400356, 75.05855451311383, 68.67598792484829, 84.60868671962193, 72.28690419878278, 75.3143732888358, 77.79925755092076, 67.11152458190918, 79.27418640681675, 81.66734749930245, 76.96749564579555, 76.9922103881836, 58.915596280779155, 63.756614685058594, 74.14923681531633, 77.83125400543213, 73.87369905199323, 69.98917661394391, 71.7163667678833, 74.54512432643345, 71.60486207689557, 71.26729079655239, 64.80372905731201, 67.73868288312639, 61.5117837360927, 64.06831087384904, 65.45727661677769, 70.28696250915527, 73.4843567439488, 78.09492424556187, 75.41949258531842, 78.27752985273088, 78.35250091552734, 82.88957732064384, 81.13995143345424, 79.43129212515694, 81.3841667175293, 80.67281709398542, 81.48606899806431, 83.22772530147007, 79.4613778250558, 79.04284613473075, 71.8418720790318, 70.65176377977643, 65.84926618848527, 68.11546979631696, 64.68958405085972, 69.21202060154506, 76.04216235024589, 82.56114986964634, 77.25064863477434, 93.38026632581438, 6.057579364095416, 0.6402971276215145, 0.7541113889643124, 0.3104804983096463, 0.06496485615415232, 0.04499721600274954, 0.03182923973404935, 0.03658533255968775, 0.9669272750616074, 3.2473111791270117, 4.712616128580911, 38.353104318891255, 76.52388790675572, 87.67010470799038, 72.72241728646415, 62.166707038879395, 32.46376255580357, 22.581734010151454, 46.035828249795095, 55.48594113758632, 72.44092491694859, 60.68903364453997, 80.05886731828961, 25.57035051073347, 0.230702204895871, 0.08636380825191736, 0.06982823554426432, 0.05495838149051581, 0.07368618209979363, 0.0606156231037208, 0.034490104631653855, 0.04035408907969083, 0.025878083892166615, 0.05099379976413079, 0.022021183976903558, 0.06946403187300478, 0.031170256701963286, 0.012412791389838924, 0.041851408912667205, 0.05022143692310367, 0.075159159488976, 0.02580297685095242, 0.041553372583751164, 0.058198247104883194, 0.04108347011996167, 0.215178409325225, 0.10321846883744001, 0.09094467958701508, 0.2423914633691311, 0.21725092668618473, 0.18089628246213707, 0.17228306750101702, 0.10018842321421419, 0.20387059609804833, 0.09537391191614525, 0.21039879508316517, 0.20429682465536253, 0.13271446073693888, 0.1491370845053877, 0.28665450108902796, 0.2054996094001191, 0.4609178187591689, 2.5032720182623183, 92.5215870993478, 117.38078253609794, 101.26506124223981, 61.33272865840367, 87.35259287697929, 114.52714347839355, 95.26240130833217, 98.5970711026873, 132.94659560067313, 143.68610654558455, 109.07690702165876, 120.69710213797433, 122.03863252912248, 108.62211963108608, 48.544739382607595, 1.4897288445915495, 0.0903241593124611, 0.3865499735942909, 0.1372266643281494, 1.0145871405090605, 0.4358721412718296, 1.3784705975225993, 2.178017722708838, 5.246244294302804, 3.00765369619642, 10.761752997125898, 86.27309989929199, 101.21705613817487, 99.85627923692975, 97.88678455352783, 99.85248552049909, 98.31886523110526, 100.69179316929409, 97.60827990940639, 98.32730729239327, 94.21502290453229, 88.39389160701207, 75.67784745352608, 69.78271089281354, 77.15802219935826, 76.80047484806606, 82.4430513381958, 84.21509211403983, 84.9932417188372, 87.75659588405064, 86.63952010018485, 85.02134023393903, 83.09529263632638, 73.45406259809221, 68.83187076023647, 76.05572523389543, 81.1583502633231, 82.22844927651542, 87.75251034327916, 84.51884651184082, 81.61827932085309, 71.3857228415353, 73.29595633915493, 68.52965191432408, 74.33705357142857, 81.62759685516357, 85.55405861990792, 78.10526316506522, 75.83156939915249, 88.03281457083565, 76.77279322487968, 77.11155264718192, 81.44802761077881, 70.26775768824986, 83.15421336037772, 81.37782301221574, 75.54970877511161, 78.02594947814941, 65.03946059090751, 71.93088545118059, 77.9302727835519, 79.00106661660331, 73.75852571214948, 71.66701371329171, 76.2100864137922, 75.85455404009137, 75.3895458493914, 75.06434931073869, 67.03073787689209, 72.1555485044207, 64.37177344730922, 68.08025632585797, 70.92047146388462, 77.04011821746826, 81.78523063659668, 84.74507985796247, 80.3396440233503, 87.08814443860734, 83.49897602626255, 87.18826103210449, 89.20139735085624, 83.32194287436349, 84.05849361419678, 84.66485595703125, 85.64966583251953, 85.81952844347272, 83.11474064418248, 82.79840305873326, 75.62666702270508, 71.60050555637905, 69.22663266318185, 73.74392754690987, 67.65174007415771, 71.72527435847691, 81.27519811902727, 87.29412378583635, 86.34790420532227, 98.02553313119071, 4.703880940164838, 2.630450542484011, 1.6984665180955614, 0.3584510785128389, 0.35990577616861885, 0.17497780147407735, 0.17690230320606912, 0.20625032697405132, 4.015069101537977, 6.218803192887988, 15.210784435272217, 53.744389057159424, 87.64069993155343, 93.97553934369768, 81.19950444357735, 133.75084958757674, 117.3256972176688, 37.1380033493042, 42.80959899084908, 48.82049601418631, 79.7904167175293, 70.18645681653703, 91.4562406539917, 40.7038049697876, 0.35167188942432404, 0.1405589769461325, 0.2585679010621139, 0.19365605206361838, 0.1456177540655647, 0.1456179983381714, 0.2809206630502428, 0.22135070312236035, 0.13315943043146813, 0.13477901209677967, 0.06477507669478655, 0.12983740440436772, 0.11449755967727729, 0.09802192196782146, 0.21459071657487325, 0.10128108172544412, 0.2627139128744602, 0.17577647790312767, 0.17374697966235025, 0.1532430084688323, 0.24214966062988552], [0.08771615568548441, 0.0016948057538164513, 0.03215568293152111, 0.018090132058465054, 0.07067870455128805, 0.028603161951260905, 0.03326486377045512, 0.03584780909919313, 0.01071480245861624, 0.05196373503921287, 0.07315204611846379, 0.10396058258733579, 0.04798294311123235, 0.09743536915630102, 0.07851429802498647, 0.05596543602379305, 0.6539805733731815, 10.473272476877485, 99.77452673230852, 78.7887018748692, 79.78416333879743, 78.85137462615967, 35.520024980817524, 95.37376703534807, 154.7569214957101, 95.74648230416435, 74.40267235892159, 60.55324499947684, 90.22338008880615, 104.26284067971366, 90.94931398119245, 42.475616455078125, 1.8085113274199622, 0.030537203885614872, 0.10816085005977324, 0.15186615235039166, 0.010493610220562135, 0.09410397934594325, 0.1607157824827092, 0.1391427522259099, 1.524554193019867, 0.8311135513441903, 1.4956884448017393, 57.17968961170742, 89.92049421582902, 97.31627491542271, 91.74953801291329, 89.68183054242814, 84.99331814902169, 86.18208544594901, 85.49809088025773, 81.93538120814732, 77.80200903756278, 75.09099565233502, 71.64912210191999, 66.7971533366612, 66.9947601045881, 71.28392478397915, 76.05776105608258, 76.52604184831891, 77.68700245448521, 79.90350559779576, 81.53604044233049, 77.58577414921352, 78.42102405003139, 71.40122427259172, 61.51436151776995, 64.1438238961356, 67.33837631770542, 76.13470540727887, 73.39168861934117, 79.29496846880231, 79.76934977940151, 73.94643974304199, 66.97001756940568, 60.870068958827424, 60.28637163979666, 63.78882653372628, 67.4385415485927, 76.51896163395473, 70.98392241341728, 55.22177757535662, 68.62742696489606, 66.4715885434832, 65.40776375361851, 73.20332295554024, 74.40677179609025, 77.63683646065849, 66.79551356179374, 60.92302118028913, 56.36817823137556, 44.115697043282644, 56.46972267968314, 72.92204598018101, 74.58117852892194, 68.54015759059361, 68.95926598140171, 65.81276730128697, 68.84647587367466, 73.97451741354806, 71.0927312033517, 66.63084820338658, 63.5158873966762, 60.84301962171282, 59.40086541857038, 59.33170304979597, 59.90383856637137, 59.7416467666626, 61.24099159240723, 66.04351697649274, 65.80655561174665, 70.61288860866001, 68.2434139251709, 70.66947473798479, 77.03483758653913, 75.57636206490653, 79.53089455195835, 76.48583957127163, 78.0771438053676, 76.54783139910016, 74.73114844730922, 71.61600698743547, 71.04243319375175, 62.02936199733189, 60.14558029174805, 60.53957094464983, 65.74194431304932, 61.12215655190604, 77.15647969927106, 73.9308271408081, 87.73730768476213, 41.52063867024013, 0.46186983053173336, 0.9844401010445186, 1.140344215290887, 0.1042775127238461, 0.21940499038568564, 0.06560347295765366, 0.12204889447561332, 0.6515408328601292, 0.26336859060185297, 0.20781493373215199, 1.7892393044063022, 30.626509462084087, 73.22415365491594, 85.49495029449463, 75.70806516919816, 82.05286829812187, 57.031352519989014, 16.300791774477275, 24.965909344809397, 29.309891836983816, 62.47492912837437, 58.24937173298427, 69.5692274911063, 8.064738495009285, 0.34149486837642534, 0.058436412896428785, 0.053315305550183566, 0.019528114004060626, 0.12518325128725596, 0.16005046532622405, 0.025485018733888865, 0.033274685564850054, 0.028252749504255395, 0.035434184329850335, 0.030295635240950754, 0.04525107291660138, 0.05268844097320523, 0.04994111375084945, 0.03499144023018224, 0.039406779554805586, 0.03616634397102254, 0.0459150024689734, 0.10250604099461011, 0.0621580621227622, 0.04748167536620583, 0.04125293084819402, 0.011637582942577345, 0.08195141716195004, 0.06902152526059321, 0.032177714963576624, 0.04700416313218219, 0.06246858688869646, 0.032787765442792854, 0.02289679949171841, 0.05671791100342359, 0.08067229722759553, 0.11806575820914336, 0.038312903073217185, 0.03305883339739271, 0.2084892075508833, 0.8170331354652132, 14.594776255743843, 113.85018048967633, 87.16783332824707, 92.78901631491524, 81.64412661961147, 45.272335869925364, 109.54765442439488, 119.28282410757882, 56.59940733228411, 78.89056246621269, 68.45829391479492, 96.86698354993547, 110.96355138506208, 99.36536121368408, 50.20440346854073, 1.221805329833712, 0.05597159033641219, 0.08151184182081904, 0.14814464561641216, 0.3562855747129236, 0.30447739043406075, 0.9620645131383623, 1.0226383656263351, 1.0316197808299745, 0.8546378176127161, 3.753468556063516, 71.38899544307164, 97.80360071999687, 99.9477105821882, 96.74495233808244, 92.33899538857597, 87.15625068119594, 89.23788928985596, 89.19157954624721, 85.17428398132324, 79.66945552825928, 79.65884562901088, 73.97166865212577, 69.22207464490617, 71.22326701028007, 76.07699366978237, 76.71830545152936, 82.25901440211705, 81.95390510559082, 84.81128229413713, 85.25022779192243, 83.7022316796439, 82.86168725149972, 73.40721784319196, 62.783074787684846, 67.5955638885498, 71.69365310668945, 79.2125906263079, 79.16844177246094, 82.86140932355607, 82.50832271575928, 79.73314271654401, 70.05377401624406, 64.36766706194196, 63.18219321114676, 65.71055930001395, 70.43019267490932, 78.578122820173, 76.38506289890834, 64.62677928379604, 73.59552097320557, 76.04710946764264, 71.4656479699271, 79.24997193472726, 79.53241620744977, 77.09885134015764, 71.53541483197893, 67.3229513168335, 62.05909333910261, 49.288241795131135, 61.13100855691092, 76.86819199153355, 78.59178992680141, 74.23501927512032, 72.93269062042236, 69.34116676875523, 71.6419654573713, 77.98405184064592, 74.07343891688755, 70.35544395446777, 66.20258903503418, 64.60655307769775, 61.53918743133545, 64.74704565320695, 62.30647005353655, 62.09773227146694, 63.312645639692036, 67.47596454620361, 70.06829575129917, 73.20614392416817, 73.05711896078927, 72.3916482925415, 78.93148735591343, 78.48641354697091, 81.74418067932129, 80.38840648106166, 80.97675909314836, 79.59538078308105, 79.17625154767717, 74.6832753590175, 73.7077830178397, 66.85439259665353, 61.81956114087786, 62.981640407017295, 68.58051272800991, 66.49542086465019, 77.37384714399064, 78.48144558497837, 87.13050065721784, 52.126379421779085, 0.33819984804306713, 1.2603767343929835, 1.2891688751322883, 0.7092468163796833, 0.1580759012805564, 0.05423962291596191, 0.07012584100344352, 0.8488203840596336, 0.2758330889046192, 0.31392099655100275, 1.8124617040157318, 35.551889419555664, 77.93498366219657, 88.54563331604004, 88.20311491830009, 68.28166375841413, 22.96769254548209, 25.901374850954326, 41.64312498910086, 43.51760653087071, 74.04308223724365, 65.54132897513253, 81.87696075439453, 12.994959609849111, 0.24775311137948716, 0.10248226512755666, 0.031095278582402637, 0.05145186518451997, 0.19584557600319386, 0.04511808005294629, 0.017755039235843078, 0.03232624288648367, 0.01848289187598441, 0.057024306883769374, 0.022437829923416888, 0.05109604820609093, 0.02178986121102103, 0.013872001303492911, 0.027081184155706848, 0.024156745722783462, 0.045357602914529185, 0.0714034138779555, 0.0025679514011634247, 0.08376159931399993, 0.11732447227197033, 0.102517643943429, 0.0947278787248901, 0.11942679089094911, 0.1498078028006213, 0.3594574545110975, 0.13210429490676948, 0.10063335219664232, 0.2620607279241085, 0.1993996745773724, 0.25299506581255365, 0.23763479718140193, 0.2084016493920769, 0.17006591361548218, 0.11976580055696623, 0.3674663390432085, 1.12343772820064, 19.952528715133667, 131.90458815438407, 98.13430718013218, 97.2869952065604, 99.57215350014823, 47.86826276779175, 103.60372066497803, 167.35875810895647, 122.9349501473563, 97.86261871882847, 78.26243141719273, 111.80900818961007, 123.50417436872209, 105.87120274135044, 68.03698294503349, 4.18609162739345, 0.24421851390174457, 0.2772167575146471, 0.21876912164900983, 0.4374238151524748, 0.7871746090906007, 1.3178900139672416, 1.9768947320325034, 7.196480308260236, 4.079137572220393, 3.414428165980748, 76.21932751791817, 100.4714241027832, 104.32441561562675, 102.20426314217704, 99.1479798725673, 93.10319995880127, 94.97091742924282, 93.48535782950265, 89.50422069004604, 86.24414675576347, 85.05013356889997, 80.15765680585588, 73.23457595280239, 75.23212051391602, 80.91711575644356, 82.68735694885254, 84.60904107775006, 85.28819969722203, 87.71331555502755, 89.12856633322579, 87.18737861088344, 88.128171648298, 78.2314007622855, 67.54865659986223, 71.66943863459996, 74.9719591140747, 83.45293031420026, 83.38909026554653, 85.89540972028459, 86.38142231532505, 82.75714465550014, 74.13306140899658, 67.16963236672538, 66.7037695475987, 69.22599342891148, 74.51835291726249, 84.62406308310372, 78.03530870165143, 65.2360737664359, 75.44260229383195, 78.70217595781598, 74.99964768545968, 82.79393536703927, 83.46015644073486, 85.50144686017717, 74.74112606048584, 67.17876229967389, 66.59883090427944, 55.98467935834612, 68.81084551130022, 79.22912733895438, 81.38698768615723, 74.7719065802438, 75.62555531093052, 70.88348620278495, 76.13984707423619, 80.82451711382184, 76.26664475032261, 74.66451522282192, 68.5811380658831, 68.10989734104702, 66.3701170512608, 66.68269566127232, 66.15293720790318, 66.34046908787319, 69.86706897190639, 75.5994439806257, 74.86463029044015, 78.661271912711, 78.690030506679, 78.34037630898612, 84.20867892674038, 83.88143266950334, 87.55320821489606, 83.38431685311454, 84.12591198512486, 83.86918299538749, 81.11749485560826, 77.14605045318604, 76.74653598240444, 69.0220707484654, 65.39105333600725, 66.62433774130685, 72.19418048858643, 67.89852619171143, 83.29062734331403, 80.61025551387242, 93.71862275259835, 53.656407492501394, 0.8191162379724639, 3.8584975259644643, 1.3715498660291945, 1.904160989182336, 0.25325945019721985, 0.25771785953215187, 0.17757165086056503, 2.531326021466936, 0.51402127210583, 1.0011519300086158, 4.7031492080007276, 46.68399095535278, 88.33024610791887, 97.93278857639858, 91.21001039232526, 111.8375791822161, 84.13835620880127, 22.102054698126658, 35.45846741540091, 45.448615142277305, 84.07166739872524, 74.79253578186035, 98.11403928484235, 24.047840390886577, 0.5297885803239686, 0.22220340450959547, 0.22690770136458532, 0.2702229070876326, 0.3961817239012037, 0.3283706440457276, 0.18197014555335045, 0.16387247666716576, 0.13384009605007513, 0.15611422940024308, 0.1676749869116715, 0.15092117020062037, 0.19368281348475389, 0.19617007859051228, 0.17452186665364675, 0.16511526783662184, 0.1572427824139595, 0.14135248293834074, 0.19334411594484532, 0.1778982976185424], [0.04688097849222166, 0.041680662360574515, 0.002182355005061254, 0.07991269763026919, 0.031478481234184334, 0.08131052048078605, 0.07838028057345323, 0.058130848221480846, 0.05882845685950347, 0.019802272685670426, 0.09399449093533413, 0.015959830655317222, 0.02623960904644004, 0.0148115458432585, 0.03443441726267338, 0.0411348623622741, 0.06404426733830146, 31.85348837716239, 92.23521709442139, 74.06159223828996, 65.81699875422886, 59.390748841421946, 57.053624970572336, 10.246847186769758, 33.870432308741975, 67.92327567509243, 88.02883325304303, 114.5307148524693, 98.84541361672538, 91.2550277709961, 36.61948013305664, 4.1339050105639865, 0.19170313328504562, 0.020373304008639286, 0.11212604586035013, 0.09303772263228893, 0.20709970353969506, 0.2571932433971337, 0.07568532946918692, 1.964405996458871, 1.006040639110974, 1.8050396165677478, 45.86421469279698, 90.48199204036167, 92.30456706455776, 92.50111770629883, 83.75302301134381, 80.58027403695243, 74.13620199475969, 72.81384863172258, 68.01171234675816, 67.08354418618339, 65.03616714477539, 67.69754954746791, 69.50040558406285, 66.77648244585309, 71.33918380737305, 78.29527555193219, 80.57969038827079, 82.90166023799351, 81.91002028329032, 82.74190725599016, 75.9021144594465, 80.26001071929932, 73.78162152426583, 63.21023614065987, 58.254037448338096, 65.47436223711286, 70.71387372698102, 75.19457939692906, 75.37653187343052, 80.80182429722377, 77.83791732788086, 71.71399048396519, 68.45026874542236, 64.54637472970145, 61.298890931265696, 56.70045498439244, 64.83295318058559, 71.74819646562848, 73.37069811139787, 81.60617555890764, 67.02761813572475, 68.36898871830532, 64.66708578382219, 71.90621239798409, 70.19791439601353, 65.57942594800676, 50.314949308122905, 43.532618113926475, 44.83063541139875, 41.98886040278843, 57.60029533931187, 65.48937729426792, 69.29603821890694, 68.5966464451381, 69.62706429617745, 65.45171110970634, 67.84438582829067, 76.40929126739502, 71.79594448634556, 70.86323915209088, 62.928493635995046, 61.22735227857317, 63.24030794416155, 71.2814164842878, 65.01738616398403, 59.99217101505825, 54.89970077787127, 55.11589397702898, 60.70612621307373, 63.17104830060686, 60.236775398254395, 68.24853474753243, 70.76772921425956, 73.62441158294678, 74.41781248365129, 74.79783030918666, 72.79148238045829, 75.7888240814209, 73.15223285130092, 72.50967039380754, 64.5987571988787, 64.0478275844029, 59.59579018184117, 59.46862425122942, 56.59517935344151, 66.86066681998116, 67.22805282047817, 73.33192716326032, 77.13826152256557, 77.79865305764335, 2.4380924871989658, 0.685930073261261, 2.263755887746811, 0.1280713134578296, 0.021933690278923938, 0.04121559445879289, 0.055954107881656716, 0.37393375486135483, 0.7440339497157505, 0.0904233136347362, 0.16692839483065264, 0.6536644846200943, 24.469696794237407, 64.9243358884539, 74.69801943642753, 61.256597246442524, 60.57156045096261, 53.70527069909232, 20.885119404111588, 25.21628073283604, 43.222652026585166, 53.676018783024375, 67.31490530286516, 43.50500249862671, 2.4189380407333374, 0.08851505603109087, 0.04570162695433412, 0.07470869366079569, 0.053071243289325915, 0.21180022773998125, 0.09614532480814628, 0.012748633145487734, 0.0489308022494827, 0.0384422216697463, 0.03851570701226592, 0.006459586372199867, 0.023511669265904596, 0.04452207185594099, 0.06699691925730024, 0.026904480066150427, 0.01729314009259854, 0.09059441981038877, 0.06848053607557501, 0.1449103405965226, 0.02380182101790394, 0.03359130018257669, 0.03926191911367433, 0.03112254211945193, 0.027961542630302053, 0.16917051880487374, 0.11002502324325697, 0.01761775803087013, 0.03359123572174992, 0.029364498598234992, 0.007968118996359408, 0.03324090809162174, 0.018699381866359284, 0.03152860461601189, 0.08511896790670496, 0.09117442475897924, 0.07351095043122768, 41.53027582168579, 105.76930046081543, 79.88924094608852, 81.85849939073834, 63.027456828526084, 37.293615204947336, 21.824020794459752, 40.138364042554585, 70.57320049830845, 90.74156979152134, 112.15717547280448, 107.31573322841099, 98.5198140825544, 42.90018612997872, 4.958515916551862, 0.10626739809023482, 0.0807560555902975, 0.11297402464385543, 0.12988775170275144, 0.3515619938927037, 0.4446109937770026, 0.5498960156525884, 1.6479054540395737, 0.246850741228887, 3.7608392919812883, 55.88912773132324, 99.38880443572998, 97.57797881535122, 95.35873113359723, 87.85660825456891, 81.54199504852295, 75.49385915483747, 76.32070173536027, 70.65159702301025, 71.85492774418422, 67.88081523350307, 70.25599438803536, 73.78827095031738, 70.90065520150321, 75.85760429927281, 82.74809810093471, 85.04223346710205, 87.67962374005998, 84.96137033190045, 85.975188936506, 80.53713962009975, 83.48631640842983, 75.3920819418771, 63.91670118059431, 59.90651362282889, 67.03412164960588, 74.65406513214111, 79.22976657322475, 79.59855610983712, 83.67936515808105, 80.19979763031006, 75.31662450517926, 70.39175524030412, 67.26409312656948, 63.37891755785261, 61.10173579624721, 67.33127525874546, 75.80010795593262, 75.94875076838902, 84.6068662915911, 70.60687146868024, 75.17997428349086, 70.71968242100307, 78.12731674739292, 73.09273542676652, 67.69132396153041, 57.14520917619978, 52.633851528167725, 51.80052975245884, 53.149751799447195, 61.50819846561977, 70.56876059940883, 74.508423941476, 73.19293539864677, 73.49066570826939, 68.24407400403703, 70.9594647543771, 79.17049149104527, 75.75604248046875, 72.17016751425606, 67.68561254228864, 63.25104291098458, 67.28380516597203, 76.1121654510498, 68.17375128609794, 64.20772647857666, 57.328579085213796, 57.933659485408235, 64.25735746111188, 64.43983105250767, 64.90522139413017, 72.7465900693621, 73.17594705309186, 75.32220390864781, 77.15381159101213, 78.3152585710798, 76.64961556025914, 78.94254193987165, 76.44053731645856, 76.88125460488456, 68.72549383980888, 65.33372374943325, 60.994066510881694, 63.045397077287944, 60.41810948508126, 69.1174625669207, 70.16678646632603, 77.19013677324567, 78.18308993748256, 82.14659949711391, 4.382475512368338, 0.7047432980367115, 2.1908288981233324, 0.10097190724419695, 0.11029876462583031, 0.05740868340113333, 0.06178277797464814, 0.6187595033219883, 1.556804473911013, 0.09255404930029597, 0.21859221399894782, 0.43076545958008083, 28.087703704833984, 73.51143387385777, 78.62808731624058, 66.4439069202968, 46.54594414574759, 22.03453036717006, 29.247802734375, 41.90735455921718, 58.324610301426475, 62.9692656653268, 74.99144881112235, 55.93872397286551, 4.3687767045838495, 0.12923800013959408, 0.055328837861972194, 0.0405216295538204, 0.035074733796396425, 0.10692824370094708, 0.04851579666137695, 0.003189533158937203, 0.046370299466486485, 0.004288972355425358, 0.10505106300115585, 0.032974301504769495, 0.050824389926024845, 0.00418477227711784, 0.0450909691862762, 0.06873907827373062, 0.0185488403907844, 0.0537033088372222, 0.011167577002197504, 0.12498876958021096, 0.2017329122338976, 0.10169487952121667, 0.17576160441551889, 0.20054846150534494, 0.12018618014241968, 0.26714602219206945, 0.15026719814964704, 0.17167771926948003, 0.1412649383502347, 0.07547546537326914, 0.1277956518211535, 0.0929322172222393, 0.12441957369446754, 0.19542154589934008, 0.13036978297999927, 0.13784121349453926, 0.12536950914987496, 55.90585551943098, 115.5863060270037, 91.92901693071637, 85.42221655164445, 76.7821524483817, 79.09401266915458, 18.5571254662105, 47.62715680258614, 88.72689097268241, 108.52147497449602, 130.2230407169887, 115.77467863900321, 111.05182824816022, 63.79271057673863, 12.957137090819222, 0.4730506220034191, 0.24650235420891217, 0.34938286510961397, 0.30620206360306057, 0.8833678588271141, 1.1568398901394434, 0.7873232896838869, 6.073054305144718, 3.554389855691365, 3.3968440123966763, 54.31064639772688, 106.47854478018624, 103.34577574048723, 101.51494625636509, 89.8955362864903, 88.91516630990165, 79.74426678248814, 80.12406921386719, 74.30301434653146, 75.3480303628104, 71.18292576926095, 74.8343847819737, 78.72401414598737, 74.55471978868756, 78.87281676701137, 85.80899497440883, 89.00463131495884, 92.08975655691964, 87.72381428309849, 90.1902858189174, 83.5873223713466, 87.21552576337541, 80.99351814814976, 70.7098159790039, 63.32572909763881, 71.81085532052177, 80.27561637333461, 83.55136544363839, 83.07669230869838, 87.53524712153843, 83.43641444614956, 81.03725011008126, 74.4919775554112, 74.49292945861816, 68.3492488861084, 65.62374155861991, 72.07155173165458, 79.4645253590175, 79.7366168158395, 88.2167889731271, 73.10240731920514, 77.16576944078717, 73.20337159293038, 80.39258234841483, 77.45901816231864, 75.58336584908622, 59.10197475978306, 56.83785561152867, 54.388118812016074, 58.32268565041678, 68.19717366354806, 74.0395039149693, 77.29685415540422, 74.82486574990409, 77.67867851257324, 71.18630954197475, 74.19969463348389, 82.3933300290789, 75.60906723567417, 77.18730190822056, 69.9501485824585, 67.02661759512765, 70.2734065737043, 79.01120403834751, 73.37980025155204, 67.26462118966239, 62.206297874450684, 62.534815652029856, 68.24469239371163, 70.80839702061245, 68.35495335715157, 77.42237336294991, 78.63158920833042, 80.1869295665196, 82.67817143031529, 82.73522308894566, 78.31061717442104, 83.19037178584507, 78.8119227545602, 80.03510447910854, 71.30467210497174, 70.77239840371269, 64.35381235395158, 66.2001154763358, 61.94403811863491, 74.97723974500383, 72.59864902496338, 81.6973637172154, 82.99594034467424, 89.40709182194301, 4.223455999578748, 1.3405631801911762, 6.221879073551722, 0.19924787272300037, 0.39980675652623177, 0.15532559528946877, 0.17482172484908784, 0.6757450997829437, 2.118877479008266, 0.219163038368736, 0.3959197279598032, 1.165280974337033, 37.89297028950283, 82.72507871900285, 89.64427552904401, 75.1811832700457, 89.43926198141915, 69.27023260934013, 29.57765109198434, 37.39800494057791, 59.161979402814595, 72.71480900900704, 83.86689008985246, 77.37960720062256, 12.615237082753863, 0.31238378903695513, 0.17808322555252484, 0.10046314168721437, 0.18570135533809662, 0.2948363577680928, 0.17154341004788876, 0.06851645093411207, 0.18801521403448923, 0.1265604059611048, 0.19369692701314176, 0.12325653753110341, 0.1215862285877977, 0.10185396884168897, 0.16010716371238232, 0.1506032765443836, 0.11624185607901641, 0.24203151411243848, 0.12682992007051194, 0.21636169297354563], [0.06789895692574126, 0.08395353651472501, 0.06689060639057841, 0.11659317437027182, 0.008284709865360387, 0.03236221542049732, 0.006507549892246191, 0.014220272972514587, 0.019515729043632746, 0.016452847414516976, 0.05520852681781564, 0.045503016361700635, 0.024448995844327977, 0.0076153817187462535, 0.027524152171931097, 0.045300039396222146, 1.086164442556245, 71.29441656385148, 80.18736730303083, 81.37764235905239, 69.72417231968471, 69.0013234274728, 39.42094169344221, 40.659649167742046, 49.636520249503, 79.86180945805141, 111.35659708295549, 96.31133610861642, 92.35405908312116, 25.411813463483536, 1.9497020883219582, 0.395927544683218, 0.035352858515190225, 0.1166389212012291, 0.07721937501004764, 0.09107909058885914, 0.12556541578045913, 0.23820767072694643, 0.8285257273486683, 1.101749251995768, 1.6458740830421448, 31.122847080230713, 87.95605782100132, 97.349258014134, 90.61728736332485, 89.717148235866, 78.21034772055489, 69.40937028612409, 66.32597514561245, 64.48716218130929, 63.40763446262905, 62.52370548248291, 66.06887790134975, 69.8320083618164, 73.87784712655204, 74.50863238743374, 78.54373618534633, 81.54581655774797, 85.28562886374337, 82.91870416913713, 81.68770572117397, 76.96066556658063, 76.68964413234166, 72.52125998905727, 64.29707336425781, 59.74312673296247, 59.23818724496024, 63.918618883405415, 70.15200764792306, 76.93370655604771, 79.00142097473145, 79.74690014975411, 78.9293612071446, 70.13110051836286, 66.64572429656982, 60.04267747061593, 61.18442630767822, 60.740575381687705, 65.76827103751046, 69.30901745387486, 71.47320760999406, 68.03206362043107, 60.96896266937256, 60.50945050375802, 66.87572356632778, 68.25428090776715, 67.56902871813092, 59.89564664023263, 34.90172215870449, 27.864734275000437, 40.81933266775948, 54.04570811135428, 56.91338947841099, 69.35392366136823, 70.50091144016811, 65.36819376264299, 66.12743731907436, 66.57875755855015, 65.568176814488, 71.75645787375313, 75.73690714154924, 71.91625949314663, 64.72117056165422, 61.168230056762695, 67.53086921146938, 73.00664029802594, 71.00775473458427, 67.50866276877267, 58.04610913140433, 56.13755709784371, 55.794878891536165, 56.277122088841026, 57.79806191580636, 59.638278416224885, 60.85395608629499, 66.9493327822004, 65.6562591280256, 69.65214034489223, 70.05255808149064, 71.67437185559953, 68.54595933641706, 68.81974615369523, 61.702900886535645, 57.95105777468, 53.49539688655308, 62.10484027862549, 64.67283194405692, 65.93989154270717, 62.57548345838274, 73.86916882651192, 68.9457517351423, 94.61339092254639, 15.395339012145996, 1.0322825738361903, 0.13132706018430845, 0.314467298665217, 0.11693826371005603, 0.06707492364304406, 0.2843240318553788, 0.4267524134899889, 0.5641393885016441, 0.3769795357116631, 0.16443343513778277, 0.3974028969449656, 0.441595692719732, 30.71070773260934, 52.28826550074986, 71.46250738416398, 72.58170931679862, 91.85230881827218, 44.53492702756609, 18.250162737710134, 23.915562323161534, 44.2134234564645, 66.16994639805385, 53.11125530515398, 41.568025384630474, 2.297868937253952, 0.07864775229245424, 0.02458301668853632, 0.12994069100490638, 0.03663033639479961, 0.05900607697133507, 0.04794258384832314, 0.07217648239540202, 0.11667367576488427, 0.02800541161559522, 0.10102109424769878, 0.0396229947384979, 0.04420393392709749, 0.011750648080903505, 0.046926755857254775, 0.016479630888040577, 0.1158491742930242, 0.08266722410917282, 0.0839640334514635, 0.03373833193576761, 0.039492179972252676, 0.04392470319622329, 0.03647633608696716, 0.043603040277957916, 0.021364704739036303, 0.023447905633864657, 0.012771988320829613, 0.02188016234764031, 0.036734114933226786, 0.10146913092051234, 0.06245904668633427, 0.053087168506213596, 0.07197903549032551, 0.052535085273640494, 0.06861475030226366, 2.2049441635608673, 84.20224489484514, 88.5892471585955, 94.4112330845424, 78.93846334729875, 74.67755699157715, 55.59245007378714, 34.76956047330584, 46.478306906563894, 89.49555628640312, 118.12518474033901, 101.36626870291573, 97.49589279719761, 30.98798601967948, 1.0384010055235453, 0.6158022848623139, 0.047253802950893126, 0.14396499203784124, 0.0960397311885442, 0.08860443944909743, 0.7740719893148967, 0.3081210149185998, 1.8974642285278864, 0.5676849782466888, 2.7156784491879598, 39.897115639277864, 94.02050808497837, 101.07825892312187, 94.10927132197789, 93.09001227787563, 82.19297872270856, 72.38508919307164, 68.18175561087472, 68.69376141684396, 67.30104364667619, 66.97684070042202, 69.66195814950126, 74.48577976226807, 75.79459108625139, 79.6883407320295, 81.33937862941197, 84.84211145128522, 86.83294405255998, 86.61002499716622, 84.218503679548, 80.47075653076172, 78.67606462751115, 73.86115060533795, 66.81149441855294, 60.578744888305664, 61.626248359680176, 65.58965369633266, 75.32483727591378, 80.53670883178711, 81.2951602935791, 81.43282495226178, 80.16873223440987, 74.3160491670881, 70.01414843967983, 64.78654616219657, 65.38018635341099, 65.30020563943046, 68.67062391553605, 72.90277167728969, 75.8364817755563, 72.38246277400425, 64.15835952758789, 64.11736515590123, 68.15435886383057, 70.11128425598145, 72.04317528860909, 65.73915808541435, 44.940277985164094, 38.23437697546822, 46.69369411468506, 59.12901714869908, 64.36470712934221, 74.0173739024571, 77.5735731124878, 70.80800097329276, 71.33277756827218, 70.56538377489362, 68.60984802246094, 73.58644662584577, 80.76948738098145, 75.27035645076207, 70.29848262241909, 64.59080845969063, 70.69157695770264, 75.34352793012346, 75.80243560246059, 73.38690825871059, 61.79306765965053, 59.50301783425467, 58.937851360866, 59.89177649361746, 61.44836752755301, 60.6173768724714, 64.97557885306222, 70.628584589277, 69.5151149204799, 72.96473571232387, 72.07508141653878, 75.22328240530831, 71.20403439658028, 71.63907500675747, 65.4886199406215, 61.08978489467076, 58.08227103097098, 65.49063491821289, 67.6578197479248, 69.90520763397217, 64.51685878208706, 77.78210244859967, 71.76457336970738, 95.6660430090768, 18.590786014284404, 1.0994583006416048, 0.16153279292796338, 0.3083910989974226, 0.24850069412163325, 0.2542350749884333, 0.38741130594696316, 0.7112853527069092, 0.2280423476227692, 0.16863252195928777, 0.11956226719277245, 0.26616640761494637, 0.19418860705835478, 34.92306007657732, 60.603869574410574, 75.92989335741315, 79.32899379730225, 60.81288528442383, 33.70886237280709, 28.247418471745082, 35.878440856933594, 58.03073276792254, 71.94027246747697, 63.999412536621094, 52.1508127621242, 3.127347490617207, 0.08962456935218402, 0.055251973415059705, 0.12767538827444824, 0.005940873067759509, 0.044628123486680646, 0.02475953078828752, 0.015626966820231507, 0.05162257102451154, 0.03685699423242893, 0.02756982945304896, 0.0474620114213654, 0.05299229573990617, 0.06409065877752644, 0.030134137121162245, 0.02488171967810818, 0.019350661829646145, 0.07231473390545164, 0.09768711243356977, 0.13160459457763604, 0.13543869741261005, 0.19899002941591398, 0.2053981548441308, 0.09883868135511875, 0.09451073394822222, 0.05646449174465878, 0.0844373387683715, 0.25240639597177505, 0.12370333927018301, 0.15206264252109186, 0.18808160190071377, 0.173136637413076, 0.18428697623312473, 0.1502919103950262, 0.3169914760759899, 5.074155654226031, 102.64755126408168, 99.20675468444824, 104.36148425510952, 85.777651650565, 87.67210578918457, 48.87534856796265, 54.25818749836513, 77.92659023829869, 100.50688076019287, 131.47149303981234, 106.56759984152657, 112.93960516793388, 39.230001722063335, 5.636564561298915, 2.3465419369084493, 0.1356025364782129, 0.3498362350676741, 0.4412349563624178, 0.8398170386041913, 1.2847867331334522, 0.5781560763716698, 3.3147605998175482, 4.675289102963038, 2.8014226938996996, 37.8945232118879, 97.76912375858852, 104.59796619415283, 99.74412836347307, 99.12606525421143, 86.4835330418178, 77.64520903996059, 72.07782595498222, 70.92519623892647, 69.74328681400844, 68.51462990897042, 71.4568932397025, 77.14452879769462, 78.10987676892961, 82.1235523223877, 85.84541048322404, 89.17712034497941, 90.80568081992013, 91.54222461155483, 86.92999649047852, 84.31520870753697, 83.88049466269356, 80.7553825378418, 70.79088061196464, 65.6631031036377, 65.70964213779995, 68.2622435433524, 78.45840535845075, 85.28389181409563, 84.10310104915074, 87.54322365352085, 84.12471689496721, 78.09463242122105, 74.47202232905796, 70.17045511518205, 69.76392991202218, 69.8241707938058, 73.48477363586426, 78.69013472965786, 79.98744678497314, 76.73932375226701, 69.34505081176758, 69.07756601061139, 73.33727727617536, 78.4675074986049, 76.70103917803083, 71.85661615644182, 47.51972375597273, 41.526798248291016, 51.32290710721697, 68.80693367549351, 72.56622873033795, 80.56112480163574, 77.75660950796944, 73.40241663796562, 74.58581297738212, 73.7473669052124, 71.47212369101388, 81.12649972098214, 79.98299298967633, 78.1147266115461, 73.0316468647548, 66.77653108324323, 73.7314624786377, 80.83287579672677, 77.40407875605992, 75.99754101889474, 67.06094169616699, 62.89053562709263, 65.34007440294538, 63.68598624638149, 65.22262205396379, 66.87878772190639, 69.78521919250488, 77.23826694488525, 71.67610195704869, 77.42943273271833, 76.08676978519985, 80.63321931021554, 75.93890517098563, 76.46748937879289, 69.65624673025948, 64.13938399723598, 59.345752307346885, 69.45891094207764, 71.56211675916398, 71.8572484425136, 68.9502124786377, 80.51022229875836, 74.50126034872872, 102.31301634652274, 21.013973746980938, 1.7429308635847909, 0.6054589141692434, 0.5353603842003005, 0.30817611196211403, 0.48709510266780853, 0.5904210582375526, 1.0794902635472161, 1.7086402007511683, 0.700541863484042, 0.31341771355697085, 0.4617954630936895, 0.6523423184241567, 46.061460154397146, 69.47958183288574, 86.93107346126011, 88.76550906045097, 130.5183947426932, 61.37145791734968, 25.31434760774885, 36.37907246180943, 61.92733464922224, 84.78942326136998, 71.14963694981166, 74.832765851702, 8.04441327708108, 0.2764832611594881, 0.14182072638400964, 0.29391585716179436, 0.14328096088554176, 0.12503336290163652, 0.0935826405350651, 0.12943045981228352, 0.16600912915808813, 0.10299274737813643, 0.19113089756241866, 0.1573523793901716, 0.13189872593751975, 0.15267648601106235, 0.13139599934220314, 0.13670522373701843, 0.1466368729514735, 0.16440454311668873, 0.20561295188963413], [0.05216594186744519, 0.062103568975414546, 0.019929760933986733, 0.07712655141949654, 0.02039105278838958, 0.05393185978755355, 0.04801178763487509, 0.026904795584934096, 0.06096363692943539, 0.047032960158373625, 0.026856490676956515, 0.053925736009010246, 0.06281911807933024, 0.06676530811403479, 0.15737949364951678, 0.4171653107873031, 24.32212574141366, 89.03280626024518, 71.65590354374477, 57.76332439695086, 50.93644482748849, 28.01168520109994, 16.817732538495743, 61.82204164777483, 69.50812503269741, 109.73850754329136, 95.96143872397286, 95.67227554321289, 17.957290955952235, 0.22743497735687665, 0.1302764844149351, 0.11608173538531576, 0.06242147620235171, 0.07492419638271842, 0.12079728235091482, 0.026604350456701856, 0.5538590401411057, 0.0731946649029851, 0.5986232438257763, 0.8487457994903836, 19.46607838358198, 74.4148872920445, 94.97355079650879, 89.75399453299386, 84.07973425728935, 77.4216229575021, 65.5660298211234, 68.23823056902204, 69.94866166796002, 66.52103192465646, 67.53098038264683, 70.34069987705776, 73.76788493565151, 78.14126178196499, 77.92390823364258, 79.00634029933384, 81.72328049795968, 84.1275726045881, 80.86925656454903, 82.55782863071987, 79.30696105957031, 76.11049093518938, 71.32371711730957, 61.066174915858674, 59.47245270865304, 59.36217090061733, 58.35370240892683, 66.47240843091691, 75.55004923684257, 77.74331065586635, 75.54672104971749, 74.81158079419816, 78.867098399571, 72.1338701248169, 65.61640426090786, 60.8027617590768, 61.34583990914481, 62.31259141649519, 64.26509080614362, 69.95044040679932, 74.80916976928711, 73.67421627044678, 57.8344635282244, 50.7576642036438, 62.986177580697195, 55.573596136910574, 67.03138405936105, 48.94642516544887, 26.337250982012065, 21.941368920462473, 43.46726335797991, 61.314906529017854, 67.98530919211251, 64.08522278921944, 66.36475304194859, 71.26203101021903, 69.45202527727399, 64.68889617919922, 67.74046162196568, 64.8985789162772, 71.87718282427106, 79.46009935651506, 70.00185707637242, 64.2596573148455, 63.940783636910574, 73.7496737071446, 73.29398999895368, 71.07823031289237, 66.18700422559465, 55.84310286385672, 54.17822068078177, 56.17689432416643, 57.75832516806466, 57.237731388636995, 56.854764052799766, 59.19173158918108, 59.161208152770996, 60.359563963753835, 59.43750326974051, 58.84849057878767, 61.00708048684256, 60.788170542035786, 57.83113881519863, 55.66482598440987, 62.07541465759277, 68.25949900490897, 66.61479786464146, 68.31935773577008, 62.11447048187256, 68.29093265533447, 69.54284518105644, 86.5653828212193, 34.19621249607631, 0.5921319435749735, 0.17562211118638515, 0.11800185378108706, 0.12262600207967417, 0.15146242401429585, 0.0070807868781100425, 0.23461963183113507, 0.32271236766661915, 0.32903946244290894, 0.06939879073096172, 0.03037897291194115, 0.21676078013011388, 1.0282555499247141, 63.60491466522217, 66.7968476159232, 78.29966681344169, 63.28859097617013, 72.7041574205671, 32.44584315163748, 20.949504886354717, 33.87666136877877, 49.42913041796003, 65.59740788596017, 61.20331151144845, 41.96800191061837, 7.155608398573739, 0.12063709380371229, 0.043247688096016645, 0.08633827497916562, 0.07609747163951397, 0.041264214885554144, 0.03480833077004977, 0.049033569770732095, 0.009975942284134882, 0.022494307785694088, 0.05585158124033894, 0.017055330531937734, 0.00453532043112708, 0.05411422625184059, 0.02735526650212705, 0.05331160753433194, 0.06602924689650536, 0.0196036061138979, 0.022458730498328805, 0.0737916739391429, 0.0355686937192721, 0.029291050575141395, 0.07255092516009297, 0.04474058048799634, 0.045474521283592494, 0.03194334218278527, 0.05203988702435579, 0.022154565301856825, 0.06542818022093602, 0.09873966273984738, 0.07245260543589081, 0.10139764047094754, 0.26436731272510117, 0.43384682280676706, 28.970731156212942, 101.77721296037946, 77.15449946267265, 72.72455733163017, 57.774094104766846, 50.518013886043, 23.073517084121704, 47.15533242906843, 78.38863154820034, 117.09993634905133, 98.60857037135533, 103.36741937909807, 22.527433838163102, 0.3100820896880967, 0.1801382095686027, 0.2156399352742093, 0.01892617710732988, 0.3324077102754797, 0.09268007360930954, 0.0438316726524915, 0.12161381782165595, 0.8282164239457676, 1.3525034423385347, 1.513337412050792, 25.377980947494507, 78.61663668496269, 100.5469718660627, 94.46230929238456, 87.53681741441999, 81.12948744637626, 68.46507535661969, 73.69990376063755, 72.98871394566127, 70.85571425301688, 73.0094473702567, 75.40125356401715, 79.29035486493791, 82.3825603212629, 84.18117100851876, 82.44788033621651, 83.91134466443742, 89.34957463400704, 85.02566201346261, 85.16607815878731, 82.34771510532924, 78.52539988926479, 73.67109652927944, 61.71027292524065, 63.01570742470877, 61.95958818708147, 60.3803460257394, 70.21841158185686, 80.5622365134103, 80.93257549830845, 77.52187851497105, 75.79076262882778, 80.91765771593366, 78.39091750553676, 69.40930080413818, 64.36768790653774, 65.02073519570487, 65.92554351261684, 67.48714419773647, 74.0212162562779, 76.19283403669084, 77.7267461504255, 62.96791076660156, 59.55511542728969, 67.84072412763322, 61.091751234872, 68.60945892333984, 54.10748107092721, 32.718202114105225, 31.04666703087943, 48.82278891972133, 71.02706377846854, 73.20824922834123, 63.84462751661028, 65.80329690660749, 74.98789828164237, 74.64298970358712, 67.00229890005929, 69.62535503932408, 67.32270118168422, 74.54773684910366, 80.80418668474469, 71.39983463287354, 66.12113530295235, 66.72263390677315, 76.75849383217948, 75.98251901354108, 75.96368939535958, 69.59180218832833, 59.50494943346296, 58.77714647565569, 60.42004108428955, 60.99078001294817, 60.433541434151785, 60.40066255841936, 62.23444502694266, 62.17218221936907, 62.19950253622872, 62.20279598236084, 59.027767998831614, 63.497259276253835, 64.04955768585205, 60.50786631447928, 59.82437201908657, 66.50519003186906, 72.41550145830426, 69.76831422533307, 72.99851090567452, 65.90066201346261, 70.24789278847831, 71.34065682547433, 88.51089232308524, 38.95670475278582, 0.6121235394052097, 0.11030312082065002, 0.16582938523164817, 0.20332267907048973, 0.0947658291884831, 0.037860964824046404, 0.5797025933861732, 0.8018447533249855, 0.1663282848894596, 0.2661007254251412, 0.05430681484618357, 0.31631264250193325, 1.1221101880073547, 67.17562171391079, 73.51687431335449, 85.46353054046631, 68.64845221383231, 40.38907241821289, 25.66397053854806, 32.98516927446638, 45.936955383845735, 63.21908119746617, 69.2372078214373, 69.93345206124442, 51.83397838047573, 7.352786983762469, 0.02630502830392548, 0.07324729207903147, 0.14217218038226875, 0.032930542781416855, 0.049897260032594204, 0.049159804425601444, 0.007734665630518326, 0.027481197512575557, 0.01430779805273882, 0.07823656685650349, 0.018449467240965793, 0.050493505716856034, 0.07280877525252955, 0.06707584645066943, 0.09463227314076253, 0.020294459935809885, 0.032574203331023455, 0.12132249559674944, 0.2700493378298623, 0.08771469004984413, 0.13214845396578312, 0.23591115538563046, 0.12568871916404792, 0.18258762599102088, 0.12313228419848851, 0.14408730476030282, 0.13760557185326303, 0.12286233582666942, 0.1812216942863805, 0.13787725727472985, 0.13834687136113644, 0.3858513267976897, 0.7141141923410552, 40.904632227761404, 117.03091294424874, 86.66815362657819, 81.14897714342389, 69.37002958570207, 38.609253134046284, 22.96439388820103, 95.93568175179618, 91.72867952074323, 127.10612051827567, 108.40160465240479, 117.32949093409947, 27.455174446105957, 0.3976878545113972, 0.5402544130172048, 0.570847114281995, 0.1908835715481213, 0.24980652119432176, 0.32423060334154535, 0.2533698342740536, 1.1341839858463831, 1.3167142484869276, 3.459334156342915, 3.7884262459618703, 24.898244312831334, 81.37712124415806, 104.5933803830828, 99.86106654575893, 92.29996040889195, 86.43095602308, 70.2595032283238, 75.66070624760219, 76.18439892360142, 73.98237582615444, 73.96506091526577, 77.84040478297642, 81.6834534236363, 87.19690459115165, 86.73325824737549, 85.47430719648088, 87.84783962794712, 92.39429610116142, 88.70780427115304, 88.15952886853898, 85.37471171787807, 83.4047931943621, 78.8527364730835, 68.34769248962402, 65.78079863956997, 64.10918712615967, 63.79291902269636, 76.07088620322091, 83.53937980106899, 82.67630931309291, 80.48965563092912, 84.15150914873395, 86.21530478341239, 81.87878813062395, 73.25904056004116, 68.65922886984688, 70.97871126447404, 70.39339501517159, 73.64704186575753, 78.2337006160191, 81.68965121677944, 81.69746794019426, 66.92551435743059, 64.39325727735246, 74.89408370426723, 70.28425965990338, 76.65996837615967, 61.486693790980745, 37.874463762555806, 30.980627877371653, 53.628187383924214, 79.19308008466447, 78.82608318328857, 76.0120905467442, 74.56489195142473, 75.88207585471017, 75.74879550933838, 71.90057046072823, 75.81822885785783, 73.89375155312675, 76.9589979989188, 80.74878174918038, 76.03326865604946, 69.09695843287876, 70.72483103615897, 80.73379448481968, 80.65524509974888, 79.5526841027396, 74.07394613538469, 62.80225876399449, 61.390419551304404, 65.1485959461757, 66.5266947065081, 64.720885685512, 65.250901222229, 66.9586294719151, 67.4987268447876, 67.06687545776367, 67.22641999380929, 65.1215466090611, 68.8047936303275, 69.64523383549282, 63.45536163875035, 63.698715346200125, 68.33176721845354, 75.87965788160051, 70.21649387904576, 77.20731966836112, 67.60165051051548, 77.06087248665946, 74.12618964059013, 94.94303430829729, 41.67487130846296, 0.9339214861392975, 0.4294040197772639, 0.4782981404236385, 0.35987681629402296, 0.357635316572019, 0.12534421336437973, 1.210274142878396, 2.2817510707037787, 0.9072463203753743, 0.6240416541695595, 0.4659765958786011, 0.33939496534211294, 1.805573325072016, 78.01199749537876, 84.06089769090924, 90.38240350995744, 81.77478054591587, 98.51565905979702, 41.86257341929844, 31.169875962393625, 47.6660041809082, 69.95223304203579, 82.99411296844482, 77.53723403385708, 73.82249777657645, 15.712597233908516, 0.22261557382132324, 0.1494949303035225, 0.2548339771372931, 0.1319445949047804, 0.09519492794892617, 0.18295377705778393, 0.08178354759833642, 0.16951526887714863, 0.10522220988890954, 0.21954812056251935, 0.08705772565943853, 0.09214168999876295, 0.13653744916830743, 0.18627663089760713, 0.12539747836334364, 0.15848999763173716, 0.10676893046391861], [0.010046702460385859, 0.037886111331837516, 0.0033820676825208856, 0.11379239215914692, 0.06303761314068522, 0.03103407472372055, 0.05768625172121184, 0.024891142833179662, 0.03342021775564977, 0.02266976676349129, 0.09086667520127126, 0.07738734635391406, 0.06586654098438365, 0.0700021915669952, 0.1283635992024626, 0.7497506886720657, 68.84975542340959, 83.26297351292202, 76.09004933493478, 50.931504658290315, 42.573853560856406, 15.84240174293518, 54.53749465942383, 73.9864752633231, 95.76554816109794, 99.28663117544991, 99.46362958635602, 22.228857585362025, 0.5206433939082282, 0.21359032525547914, 0.171798118523189, 0.044258362613618374, 0.08350776614887373, 0.058452182050262175, 0.04098237858020833, 0.08090605254151992, 0.8381185840283121, 0.31582597004515783, 1.2601070574351718, 4.646052820341928, 44.358779770987375, 78.75419017246791, 89.91163526262555, 82.4511946269444, 79.10212816510881, 72.70467158726284, 72.68284034729004, 69.00989750453404, 71.38723060062954, 74.96783883231026, 79.8458286012922, 81.87746797289167, 80.94730567932129, 82.76690687452043, 83.32298510415214, 81.27668503352574, 84.58321462358747, 81.1362133026123, 80.42056274414062, 78.823137147086, 72.05436188834054, 67.5488372530256, 59.00175394330706, 59.99209458487374, 60.49105862208775, 61.72995717184884, 58.01886871882847, 68.31418132781982, 74.37893731253487, 77.47335229601178, 78.27368749891008, 69.56414140973772, 70.11716938018799, 78.37670843941825, 65.16039398738316, 61.66337258475167, 62.424374035426546, 60.321189062935964, 63.18475014822823, 69.5299632208688, 68.55310208456856, 67.11337280273438, 56.68382099696568, 58.482841627938406, 59.980942726135254, 49.73854412351336, 53.88591691425869, 47.91427721296038, 30.722780227661133, 23.132976293563843, 34.00832973207746, 66.00705977848598, 67.60600008283342, 47.79718269620623, 50.86112288066319, 57.981473514011924, 67.03071008409772, 70.99147510528564, 59.10531684330532, 66.26030077253068, 60.432547841753276, 72.05251366751534, 72.54762145451137, 66.52457550593785, 62.724411146981375, 68.59952299935478, 72.64992673056466, 71.91776030404228, 68.94802379608154, 63.873177664620535, 55.07503162111555, 55.2966548374721, 52.94992855616978, 53.53025599888393, 52.91749436514718, 54.20411661693028, 56.03964308329991, 54.90527670724051, 57.33232069015503, 54.331376348223, 54.59870828901018, 56.87788765771048, 55.78772224698748, 56.9601925441197, 66.02727208818708, 73.1542478288923, 75.71404756818498, 68.15550531659807, 62.653546469552175, 64.59408106122697, 70.71902234213692, 81.13461521693638, 51.508031436375205, 0.40111369639635086, 0.16797251094664845, 0.2073323324854885, 0.2332499681838921, 0.24808100664189883, 0.06547275997166123, 0.6382595683847154, 0.3616658145827906, 0.28176370209881235, 0.09279213366763932, 0.3018433174916676, 0.34240141830274035, 0.7234663047960826, 16.338807106018066, 57.14936767305647, 71.23862252916608, 80.80793176378522, 76.68531540461949, 69.04271384647915, 20.42651571546282, 21.995043754577637, 25.89225534030369, 47.18802717753819, 58.44317436218262, 59.34379291534424, 56.18107713971819, 22.66470766067505, 0.32619371371609823, 0.05920566126172032, 0.027567829471081495, 0.05119460541754961, 0.031261607871523926, 0.02540473616681993, 0.05550200339140637, 0.06101921573281288, 0.027334998661120023, 0.017365556742463793, 0.029981178364583423, 0.09426326544157096, 0.026517630288643495, 0.08155816540654216, 0.053717181485678465, 0.03677842326994453, 0.019616508457277502, 0.04863738674404366, 0.01417031922444169, 0.05473222576880029, 0.06102374156138726, 0.03890526753717235, 0.012507187485295748, 0.007381894426154239, 0.006291076865246785, 0.025053246545472314, 0.04566314384075148, 0.04468928663326161, 0.02630734210833907, 0.0332146691424506, 0.10765975873385157, 0.7778433955141476, 80.8455284663609, 88.49595369611467, 89.48598166874477, 66.7068475995745, 54.97174664906093, 22.768216712134226, 33.84564808436802, 71.45640686580113, 104.3605045591082, 105.30684920719692, 108.36391067504883, 28.387478521892003, 0.7060450538992882, 0.04086027620360255, 0.38079393388969557, 0.07661676805998598, 0.13152564024286612, 0.15983247916613305, 0.17380646004208497, 0.1423652914485761, 0.30698403449995176, 0.7601051330566406, 0.9726157869611467, 6.466484325272696, 48.23580510275704, 84.94345092773438, 89.68237945011684, 87.0606712613787, 83.09595271519252, 75.94611740112305, 76.37923336029053, 72.90825380597795, 74.4124276297433, 81.09596933637346, 84.20810917445591, 86.33403560093471, 86.44458144051688, 86.57613168443952, 86.38165855407715, 85.36363628932408, 89.58080373491559, 83.01982825142997, 81.8456243787493, 79.25020122528076, 73.1553178514753, 69.69450351170131, 61.56295721871512, 63.76762063162667, 63.44796180725098, 63.45094953264509, 61.65923145839146, 71.81539944240025, 78.99741881234306, 79.20407908303397, 81.63132803780692, 74.42952714647565, 78.68837683541435, 80.8072508403233, 66.98283004760742, 65.05207851954869, 65.06634317125592, 64.15667806352887, 68.13617542811802, 71.40448297773088, 72.62655299050468, 71.66592979431152, 61.42595958709717, 66.53263541630336, 63.56097425733294, 56.38586834498814, 57.94199384961809, 55.70929792949131, 38.51563310623169, 29.194965158190044, 39.85216774259295, 67.59322929382324, 67.91796725136894, 54.99786145346505, 57.95164837156023, 60.14781066349575, 68.27647345406669, 74.10092599051339, 63.78409481048584, 69.56711523873466, 63.464227540152415, 74.57900374276298, 74.3027572631836, 71.4042397907802, 63.68489537920271, 71.62587342943463, 74.46276038033622, 77.41103390284947, 72.75109945024762, 67.29424830845424, 59.81459590366909, 60.39411735534668, 56.45701789855957, 57.393159117017476, 58.196996212005615, 58.43078572409493, 57.67909138543265, 58.49439648219517, 61.541688782828196, 56.84904568535941, 57.62104613440377, 60.10712201254708, 56.80538320541382, 61.23533575875418, 69.15214797428676, 74.64201695578438, 78.88306535993303, 70.3720293045044, 66.92256832122803, 67.2642181941441, 74.0113081250872, 84.00361674172538, 54.80432285581316, 0.5093729272484779, 0.16035049994077, 0.1877399188067232, 0.27073327398725916, 0.2569994809372084, 0.16945580206811428, 1.314773095505578, 0.21543361991643906, 0.6031980897699083, 0.07992205462817635, 0.5703008121677807, 0.36149897639240536, 1.0243912658521106, 17.86929896899632, 68.32996763501848, 76.52684089115688, 90.6941066469465, 59.43910830361502, 39.094831466674805, 27.53313844544547, 32.12215437207903, 36.46542814799717, 61.818623134068076, 69.51151575360979, 70.06671156202043, 66.53564398629325, 23.574223382132395, 0.19007217937282153, 0.035507666279694865, 0.06940284158502306, 0.057782976888120174, 0.08757573964872531, 0.021524089222241725, 0.06176846767110484, 0.029574596788734198, 0.022644803460155214, 0.09480091623429741, 0.0313674457637327, 0.0891787243474807, 0.07009652150528771, 0.0555257826511349, 0.027722791602302874, 0.06968171269233737, 0.12815986227776321, 0.13126756623387337, 0.13112242759338447, 0.20714357761400087, 0.19679582358470984, 0.14227018798036234, 0.20622174707906588, 0.11808912695518561, 0.13070161374551909, 0.19404720036046846, 0.14575080121202127, 0.14019976050726005, 0.14113985720489705, 0.2539142636316163, 0.5096380987337658, 2.2036255257470265, 100.73026534489223, 99.05586065564836, 99.04847472054618, 71.1160910470145, 60.281681605747764, 27.34904244967869, 77.40298788888114, 100.29483563559396, 110.76265811920166, 115.80015768323625, 119.36050496782575, 32.95696306228638, 0.917960062623024, 0.43307975253888537, 0.7631441014153617, 0.48541694985968725, 0.4279276632836887, 0.6559877885239465, 0.43319507635065485, 0.3732775572155203, 1.6224651677267892, 2.211972917829241, 4.1752320272581915, 7.819757172039576, 52.45176008769444, 90.30892630985805, 96.02791213989258, 92.8837411063058, 88.26118796212333, 81.15032509395054, 79.42877687726701, 76.48374121529716, 77.99125712258476, 81.91081237792969, 88.22785745348249, 90.98260280064174, 89.44255542755127, 89.45625032697404, 89.4823408126831, 87.33562537602016, 93.25997911180768, 87.41491821834019, 86.37211867741176, 84.1910652433123, 79.25441183362688, 74.59463718959263, 65.47543225969586, 69.03586292266846, 67.59283324650356, 68.307434626988, 63.78777040754046, 74.50588090079171, 82.64181150708879, 83.98159790039062, 81.33714130946568, 76.86617006574357, 81.43215097699846, 85.98492336273193, 71.33329173496791, 70.3545754296439, 69.42735917227608, 68.04274994986397, 72.55626501355852, 76.51372964041573, 77.46209621429443, 77.8094436100551, 65.0915025983538, 71.08494227273124, 71.49560860225132, 63.886288915361675, 66.08972249712262, 61.1050500869751, 42.54138462884085, 33.86913994380406, 46.47329725537981, 76.29963479723249, 74.78645610809326, 62.26639979226248, 67.69474247523716, 69.05318478175572, 70.66565322875977, 75.86704690115792, 70.13252489907401, 74.09648609161377, 69.29013225010463, 75.05133533477783, 76.10825361524309, 76.29114409855434, 67.2336391721453, 76.07610430036272, 81.46450178963798, 80.53506905691964, 77.04730265481132, 70.69641985212053, 61.876376560756135, 64.04682009560722, 60.45090498243059, 61.976458413260325, 61.40599046434675, 61.29560443333217, 61.55218751089913, 61.652512550354004, 65.36413601466587, 59.849587031773154, 60.19179970877511, 62.98838710784912, 59.953504289899556, 63.547647612435476, 72.33009420122418, 78.12716388702393, 82.47314398629325, 73.35489790780204, 71.01068687438965, 70.89092772347587, 78.47095380510602, 87.99994264330182, 63.5497807094029, 0.9504754607166562, 0.3953383591558252, 0.6084190639001983, 0.7187108056885856, 0.41178284532257486, 0.24062257685831615, 1.448290005326271, 1.1410479375294276, 1.9981136620044708, 0.3849189653992653, 0.9869207165070942, 0.6480407863855362, 1.064896006669317, 20.225042275020055, 76.90364170074463, 88.18286786760602, 97.42584105900356, 103.17251546042306, 92.9184056690761, 29.37017093385969, 33.39810766492571, 40.2980649130685, 65.27528245108468, 77.84008516584123, 78.51422718593052, 84.57683617728097, 36.317087582179475, 0.27225473948887413, 0.20777986704238824, 0.10594642388501338, 0.12175726012459823, 0.15317951116178716, 0.15561627969145775, 0.17027824079351767, 0.15296133501189096, 0.10527928146932806, 0.1312157940119505, 0.08363419079354831, 0.16642702530537332, 0.09052532458943979, 0.15938596241176128, 0.1128488349329148, 0.13778725638985634], [0.09123507221894604, 0.042336927859910896, 0.04976599064788648, 0.02290214125865272, 0.06200143588440759, 0.06430161531482424, 0.02721920666018767, 0.09935300411390406, 0.025153031905314753, 0.007296660249786717, 0.004185592880406017, 0.05183643169168915, 0.08236284687050752, 0.15037481380360468, 0.343744836215462, 20.667774541037424, 84.65257849012102, 78.25489956992013, 48.71547399248396, 42.09451471056257, 23.919071163449967, 40.686642919267925, 69.4567847933088, 64.50492872510637, 104.09653554643903, 99.14594405038017, 41.74411358152117, 0.4079205154308251, 0.17405113976980957, 0.19287234411707946, 0.19681453758052417, 0.12603764901203768, 0.06337733526847192, 0.3516958009983812, 0.339534906404359, 0.10529591914798532, 0.09952263786856617, 0.30811832791992594, 0.7832247210400445, 9.189577153750829, 54.07908378328596, 87.48082883017403, 86.76805482591901, 80.52782903398786, 83.92743669237409, 81.32270295279366, 82.27654470716203, 81.22993060520717, 78.61321817125592, 79.7204692023141, 79.90818173544747, 84.21186814989362, 81.59684412819999, 86.70677171434674, 84.50824356079102, 82.595230783735, 81.28142370496477, 81.06420217241559, 73.94322272709438, 71.69026238577706, 65.93546554020473, 59.748101643153596, 58.75803892953055, 59.40758432660784, 60.20775972093855, 59.77975763593401, 58.832245690482004, 62.57285009111677, 71.15277753557477, 73.89279270172119, 78.67485564095634, 75.32772772652763, 74.31153978620256, 70.81219073704311, 61.16474206107003, 63.68594455718994, 61.85170350755964, 65.54457378387451, 66.53231579916817, 65.15937260219029, 66.3436861038208, 63.542637961251394, 59.541448320661274, 62.86575835091727, 58.76038047245571, 56.43820565087454, 62.985816274370464, 59.54003088814871, 47.52365296227591, 39.4485399382455, 34.63497039249965, 42.27632474899292, 54.38563135692051, 52.41856506892613, 49.1498510496957, 48.77110127040318, 53.279846395765034, 68.6554490498134, 60.23153645651681, 61.87604999542236, 59.55036285945347, 65.38977486746651, 73.1964442389352, 65.6451142174857, 62.24897371019636, 61.12141309465681, 70.41900607517788, 72.14879485539028, 71.15831524985177, 67.58153547559465, 60.96387658800398, 58.95239394051688, 58.06650904246739, 54.97900751658848, 56.24607406343733, 55.27829074859619, 54.09039197649275, 54.92446068355015, 58.33469908578055, 56.61529438836234, 55.07887397493635, 56.21582160677229, 55.54911068507603, 66.84523487091064, 72.45460591997418, 69.93274334498814, 73.34751197269985, 67.00402205330985, 64.6031276157924, 60.97172110421317, 70.22140625544957, 75.37606634412492, 76.28002003261021, 6.361593016556331, 0.40801190052713665, 0.15983655037624495, 0.8258642958743232, 0.11779025942087173, 0.06351526108171258, 0.43221527178372654, 0.5095819703170231, 0.07628370236073222, 0.07126813435128757, 0.23410038969346456, 0.07376392864223037, 0.09581373152988297, 0.4488461379493986, 12.087366802351815, 46.60582719530378, 81.17659623282296, 65.58801392146519, 84.24189131600517, 53.05239711488996, 19.899071012224468, 22.20853063038417, 40.04981967381069, 49.64260687146868, 55.70102609906878, 60.55475275857108, 65.10669830867222, 23.702546187809535, 0.17070621997117996, 0.036598638631403446, 0.019371399556153586, 0.10014919031943594, 0.040364284068346024, 0.021640992324267114, 0.08694665626223598, 0.058810156770050526, 0.05676576468561377, 0.049165809460516484, 0.07801750861108303, 0.07607931404241494, 0.08814079647085496, 0.015359620630208935, 0.08563284961772816, 0.021067335070776086, 0.025720592521663223, 0.04039344071809735, 0.015661777363025715, 0.11049511908952679, 0.031348986218550375, 0.06462291521685463, 0.15327960864773818, 0.05345996582348432, 0.02187991637869605, 0.02377266776082771, 0.027012597836021866, 0.09747646123703037, 0.14033089418496403, 0.3845049504722868, 23.51604437828064, 100.84691865103585, 83.82971027919224, 67.74715273720878, 49.021913869040354, 43.08580725533621, 40.00482313973563, 55.88816540581839, 77.28203364780971, 109.41078880855015, 109.45644542149135, 51.2812248638698, 0.190055677401168, 0.10260134802332946, 0.19689446900572094, 0.19403601810336113, 0.0976904643965619, 0.046229825754250796, 0.08380003832280636, 0.036951140966266394, 0.142297465088112, 0.2319801306085927, 0.3391565281365599, 0.8371255344578198, 10.50660993371691, 58.102497237069265, 89.79910918644497, 90.64365577697754, 82.38214342934745, 90.13333838326591, 85.97705105372837, 86.47618184770856, 85.3286521094186, 81.91878890991211, 84.49361065455845, 84.25587109157017, 86.12059388841901, 86.88274874005998, 88.52763053349086, 87.23785727364677, 83.78524875640869, 83.1346263885498, 83.96728461129325, 77.96160221099854, 71.38146359579903, 68.52481596810478, 61.352405956813264, 62.28288786751883, 60.99718625204903, 63.56811005728585, 64.76795973096574, 62.05513286590576, 64.39440373011998, 75.02398722512382, 76.8067490713937, 80.31354658944267, 77.81006894792829, 77.80219663892473, 73.97407272883824, 64.77343491145542, 68.11310046059745, 66.29722349984306, 69.77761786324638, 68.39472484588623, 69.29407187870571, 71.15492452893938, 68.49872548239571, 66.6778666632516, 67.34372643062046, 64.51889460427421, 61.734911237444194, 64.00449166979108, 62.6450766154698, 52.58482503890991, 44.8852447782244, 45.44406407220023, 48.508063316345215, 58.52801186697823, 59.4091476712908, 57.174978733062744, 56.29220315388271, 58.94680758884975, 67.95484134129116, 62.3445531300136, 67.03354494912284, 63.09251281193325, 70.54156535012382, 74.76353400094169, 69.65498910631452, 66.43854291098458, 67.31820569719586, 72.81555094037736, 71.93066310882568, 73.61401012965611, 70.39349228995187, 64.3924651827131, 62.624176434108186, 61.44833973475865, 61.71713774544852, 60.77257183619908, 59.20008332388741, 58.55439417702811, 59.38439818790981, 59.53340230669294, 58.984591892787385, 57.82058102743966, 60.05609444209507, 58.758566992623464, 68.60440758296421, 76.19129848480225, 75.27907643999372, 76.41097967965263, 71.69578620365688, 68.24224662780762, 62.53011866978237, 75.12785584586007, 75.98460347311837, 82.9351783479963, 7.460187894957406, 0.6314262322017125, 0.17431918824357645, 1.266413307615689, 0.21493770581270966, 0.47949589043855667, 0.1109831350456391, 0.20212743963514054, 0.09795010582144771, 0.10047876834869385, 0.07052410034728901, 0.09767624230257102, 0.07258597827915635, 0.6303140318819455, 13.65440445286887, 55.623247964041575, 87.4521814073835, 75.23738724844796, 60.54348972865513, 33.41105563299996, 30.488740580422537, 36.43970939091274, 49.92261232648577, 55.976688929966514, 63.46432481493269, 66.9037595476423, 76.19280624389648, 23.642727409090313, 0.05521310692919152, 0.005936767930896687, 0.012577018068571175, 0.0376512669692082, 0.028555464332125018, 0.07736625070018427, 0.036018772782491784, 0.13913028075226716, 0.07973100630832569, 0.02105337251642985, 0.02213217194990388, 0.07799462162490402, 0.02223985715370093, 0.10028953171734299, 0.07614789357674973, 0.12590263411402702, 0.07792144840849297, 0.2186379065471036, 0.10734318143555097, 0.1664891926837819, 0.17844393476843834, 0.11080567778221198, 0.2750015306685652, 0.10260487640542643, 0.14754612344716275, 0.13364294091505663, 0.16533047200313636, 0.27721602469682693, 0.35737771753753933, 0.8368311045425278, 35.91752447400774, 112.33428505488804, 95.90210110800606, 69.50629765646798, 55.836324896131245, 33.82316371372768, 58.48462731497628, 92.80656746455601, 81.15520967755998, 123.37271445138114, 116.78359876360211, 59.592934472220286, 0.5195660974298204, 0.18210469904754842, 0.5701267272233963, 0.251302745193243, 0.43810102024248665, 0.09696717320808343, 2.5577122398785184, 0.8570553021771568, 0.2014634252658912, 0.43055752930896624, 2.655371993780136, 2.220637538603374, 13.117998310497828, 62.96078886304583, 95.23451123918805, 97.27917153494698, 86.93033695220947, 96.59793540409633, 87.469482421875, 90.13745866503034, 88.66140420096261, 86.89324051993233, 87.22315488542829, 88.29376111711774, 90.88450118473598, 89.2814336504255, 92.71611581529889, 92.63708005632672, 88.58737114497593, 87.93345533098493, 88.43392017909459, 81.57548536573137, 77.00637081691197, 74.65093844277519, 65.6700999396188, 64.78950609479631, 65.08475589752197, 67.3761328288487, 68.31197180066789, 65.06226457868303, 69.82028675079346, 79.4116495677403, 81.70406178065709, 82.18074989318848, 78.96244852883476, 80.97618239266532, 79.47773388453892, 70.22592258453369, 73.27270766666958, 71.29033102308, 73.5533732005528, 73.42004421779087, 72.90619019099644, 77.41564055851528, 74.48658575330461, 68.6120297568185, 73.69469261169434, 70.00479616437639, 66.30273342132568, 66.79101807730538, 65.36520603724888, 55.70488582338606, 46.313182967049734, 48.48816714968, 54.96359641211373, 66.49653952462333, 62.91134548187256, 61.088110378810335, 59.99392196110317, 63.869953700474326, 76.00421823774064, 65.2806464603969, 69.44281196594238, 66.46099254063198, 70.66983604431152, 78.04992771148682, 73.85930933271135, 69.34216036115373, 69.18281037466866, 77.43468557085309, 77.06626428876604, 77.53471183776855, 73.94602979932512, 68.42206600734166, 66.07403346470424, 63.95185211726597, 64.0379194532122, 63.13933672223772, 63.05174078260149, 63.05438804626465, 61.905225481305806, 66.10207639421735, 62.9618102482387, 61.568897928510395, 62.16435159955706, 63.43873459952218, 70.77965232304165, 80.67540182386125, 77.57085636683873, 81.238358770098, 74.94953727722168, 72.35188375200543, 65.76069750104631, 79.9030956540789, 77.85181372506278, 87.87455545152936, 8.775268231119428, 0.7872846946120262, 0.4557270258665085, 1.946442948920386, 0.783328292625291, 1.7738125664847237, 1.5949567066771644, 1.164719581604004, 0.2203908881970814, 0.41827694113765446, 0.38344426453113556, 0.17082469218543597, 0.18008817439632757, 0.8251479257430349, 20.821260247911724, 65.47078391483852, 95.73519842965263, 85.20004095349992, 109.94090162004743, 70.60350159236363, 27.933585711887904, 35.93427658081055, 56.55823578153338, 66.61912659236363, 74.37960433959961, 73.99627222333635, 86.80692304883684, 34.28336375100272, 0.24292457476258278, 0.12301166781357356, 0.1652171023722206, 0.2419033795595169, 0.13014769846839563, 0.253214884017195, 0.10516891096319471, 0.22626419232359954, 0.12742184687938007, 0.12033433147839137, 0.10541982642774071, 0.1470224436904703, 0.16636610643139907, 0.20945392149899686, 0.19808729285640375], [0.0650199396269662, 0.03826085604461176, 0.02667112848056214, 0.01655147078313998, 0.04230651252769998, 0.03529261478355952, 0.017220092405165945, 0.032332498979355605, 0.043411377883915386, 0.035286986335579834, 0.06224848369934729, 0.02973666148526328, 0.0374430279646601, 0.10915264434048108, 0.030988901254854033, 42.577018465314595, 83.5959311894008, 70.2609623500279, 58.238001005990164, 35.89562027794974, 36.08900601523263, 54.19263819285801, 61.7353698185512, 98.17786543709892, 101.46257768358502, 66.12654794965471, 2.663161792925426, 0.13656953030398913, 0.035373401162879806, 0.04686211182602814, 0.10921129012214285, 0.014030681806616485, 0.07482685374894313, 0.08763887733221054, 0.15059121219175203, 0.09582294603543622, 0.19612235043730053, 0.7535948338253158, 0.4502820266144616, 7.852688159261431, 56.67784902027675, 89.5446800504412, 86.31278106144497, 86.7134906223842, 88.50634125300816, 90.97551563807896, 89.16805294581822, 84.60084220341274, 79.81073325020927, 83.40215287889752, 84.37357357570103, 86.20834268842424, 84.40698051452637, 83.88405214037213, 83.72931575775146, 80.53827217647007, 76.71270520346505, 70.95769296373639, 68.03708716801235, 60.41386413574219, 57.25104761123657, 57.085548468998496, 58.13951029096331, 59.915824208940776, 57.304190908159526, 57.58975492204939, 56.4031936781747, 60.55803230830601, 61.66629082815987, 68.34366948263985, 69.28410121372768, 71.28529357910156, 67.53291893005371, 61.98193359375, 61.37461934770857, 64.7176547731672, 64.62907218933105, 66.67987469264439, 69.00852870941162, 63.567387444632395, 62.314509119306294, 61.85389219011579, 61.84438705444336, 60.456727572849815, 58.40274279458182, 63.12889357975551, 61.38641044071743, 58.55026694706508, 59.849948338099885, 58.37556838989258, 52.98660462243216, 44.49495751517159, 44.61572068078177, 59.430193764822825, 60.40257331303188, 59.162424087524414, 57.10913412911551, 49.03982285090855, 56.084368637629915, 65.23125171661377, 66.8108343396868, 62.71221011025565, 66.20155375344413, 67.45966407230922, 63.30267497471401, 62.84671333857945, 63.27820341927664, 69.07732282366071, 67.907315662929, 70.47027683258057, 65.19455133165631, 66.07591642652238, 62.86577224731445, 64.84133270808628, 62.60765361785889, 61.64363970075335, 59.55763067517962, 57.48924922943115, 52.58517244883946, 54.19181135722569, 53.347924845559255, 56.98512962886265, 55.11173548017229, 68.90358311789376, 71.62460885729108, 76.01324394771031, 71.57891055515834, 70.07916968209403, 64.52587059565953, 63.45857865469796, 65.16263130732945, 74.88799013410295, 84.19483116694859, 36.064152308872764, 0.3292326277920178, 0.20356359971421106, 0.0670079318806529, 0.31614026746579577, 0.318411541304418, 0.22932306889976772, 0.30386337052498547, 0.13488642419023172, 0.07226657827517816, 0.14507872584675038, 0.05507762723469308, 0.06602590171886341, 0.009174577160073178, 0.19855780260903494, 14.97435634476798, 63.759255000523154, 78.88127967289516, 74.92825494493756, 83.56045368739537, 34.042598247528076, 18.558251074382238, 35.43016045434134, 45.63559464045933, 57.41529260362898, 68.25899178641183, 49.09745468412127, 67.81377901349748, 15.82266538483756, 0.21100817381271295, 0.055950474326631854, 0.07837890314736537, 0.07820671131568295, 0.04880403494462371, 0.056943364441394806, 0.026945436439876045, 0.05115525717181819, 0.03213599184527993, 0.08558120631745883, 0.0365738619251975, 0.06356885856283562, 0.04906737438536116, 0.05197747198066541, 0.044751460797020366, 0.010024805287165301, 0.07289554631071431, 0.014691986276635101, 0.07618028005318982, 0.029219682261879956, 0.01750487694516778, 0.020446124386840632, 0.041963764133730104, 0.0072689437906124765, 0.03914363688922354, 0.0541101550417287, 0.003944193869496563, 0.04186535619997552, 0.083673002996615, 53.10428278786795, 90.73316247122628, 80.2052311216082, 60.68043177468436, 48.18229702540806, 31.725898606436594, 27.091205222266062, 66.83645929609025, 103.46481227874756, 107.01465388706752, 78.9133803503854, 4.078448832035065, 0.11939845526857035, 0.09921634716114827, 0.05716195449765239, 0.24443187245300838, 0.3317292295396328, 0.10090455585824591, 0.10678436035024268, 0.24015658614890917, 0.21211253026766436, 0.3638514573020594, 1.1637196924005235, 0.2628985829651356, 9.122488822255816, 57.47088166645595, 92.5699326651437, 91.81436470576695, 90.93636948721749, 95.11435604095459, 95.17160224914551, 92.65297753470284, 87.82079723903111, 85.5704424721854, 87.28482014792306, 89.51307269505092, 88.40918459211076, 88.93844972337995, 85.29721845899309, 84.93792710985456, 82.27520370483398, 79.54268564496721, 73.36956555502755, 70.9823660169329, 62.69458253043038, 59.15377358027867, 60.39620181492397, 59.462926728384836, 63.15281622750418, 61.14844158717564, 60.67687429700579, 59.73067556108747, 64.38728877476284, 65.32057775769914, 70.67565863473075, 73.23741776602608, 73.71336936950684, 69.25168786730084, 65.65352153778076, 64.21586976732526, 68.16358607155937, 68.4573837007795, 68.39414119720459, 70.93883555276054, 67.49842807224819, 67.24819564819336, 68.2437960760934, 66.14437702723912, 67.27947643824986, 62.27420956747872, 65.18015466417584, 62.40912968771798, 61.1282570702689, 64.80818980080741, 63.586946623665945, 55.81440332957676, 50.35316787447248, 50.01641648156302, 63.642386300223215, 62.43205179486956, 62.64734867640904, 61.78010926927839, 52.61436183112008, 58.79743521554129, 67.70164203643799, 67.42704227992466, 68.14367948259626, 69.8337801524571, 70.19041728973389, 66.2820486341204, 65.51400865827287, 66.72523948124477, 71.65796021052769, 68.97366959708077, 75.7913601739066, 68.38324642181396, 71.17549814496721, 66.41744818006242, 68.96414361681256, 67.1454109464373, 67.20341450827462, 63.6938168661935, 61.73108278002058, 56.140767165592735, 57.01155015400478, 56.06496926716396, 58.75762898581368, 58.6912875856672, 73.32114355904716, 74.58192198617118, 80.38785062517438, 76.12134402138847, 76.1269998550415, 67.65299769810268, 65.8905245917184, 69.42706039973667, 76.2390604019165, 87.22642053876604, 39.790631021772114, 0.2662192519221987, 0.1293115397649152, 0.17848927447838442, 0.2667579815856048, 0.4213904397828238, 0.06841383608324186, 0.12649888997631414, 0.16934999131730624, 0.022269877239263484, 0.2828720211982727, 0.2396157665976456, 0.0809143917368991, 0.03540057309770158, 0.02652379817196301, 19.139770133154734, 73.11793654305595, 86.73518289838518, 76.55460589272636, 51.001094341278076, 22.034351451056345, 26.464625358581543, 52.947719029017854, 61.269159589494976, 66.89100960322789, 78.19202532087053, 59.3952373777117, 81.3893848146711, 16.30200249808175, 0.22959451004862785, 0.043079564081771035, 0.03331104486382433, 0.03847120190039277, 0.032756284810602665, 0.09002322224634034, 0.02295925185483481, 0.0957658269575664, 0.032526101983551464, 0.024323432939127088, 0.05962336741920028, 0.08874740677752666, 0.056078941361712556, 0.061284645061407766, 0.1189242135733366, 0.14184638857841492, 0.26029094574706896, 0.1262903083115816, 0.1095237826396312, 0.19137905138943875, 0.05993405503353902, 0.08724485883223158, 0.14991666695901326, 0.0752771906554699, 0.14330266043543816, 0.18318320331828936, 0.1996878076876913, 0.1949145852455071, 0.0821403009550912, 68.72721004486084, 103.21011216299874, 89.02454485212053, 73.8171615600586, 52.26618759972708, 48.19561324800764, 77.43958405085972, 79.90711171286446, 117.09760175432477, 112.8748688016619, 89.74486460004533, 5.369662540299552, 0.2422181655253683, 0.24450341718537466, 0.11896952614188194, 0.32155608971204075, 0.7675899171403476, 0.735130213201046, 0.2117811201938561, 0.6743045970797539, 0.7156132119042533, 0.44984670568789753, 3.311215498617717, 1.5424306052071708, 10.654180986540657, 63.232525961739675, 100.17846720559257, 98.42401926858085, 96.29550811222622, 99.02052211761475, 100.64336422511509, 98.23336069924491, 91.93604155949184, 89.3859623500279, 90.09050968715123, 93.4239149093628, 91.25325598035539, 93.63822514670235, 89.39106927599225, 88.41416645050049, 87.40080642700195, 86.82312624795097, 78.47908319745744, 75.7992741721017, 66.30944538116455, 62.57674108232771, 62.748875754220144, 63.3997552054269, 65.65888554709298, 64.6627779006958, 63.78107929229736, 62.840793473379954, 69.2437391281128, 68.76596014840263, 75.79487596239362, 77.92933477674211, 78.35571793147496, 75.01075090680803, 70.08595807211739, 69.41914640154157, 72.17660849434989, 72.33920328957694, 73.63437529972622, 77.11772264753068, 72.33390876225063, 72.10723767961774, 72.19222804478237, 69.93352154323033, 69.77681187220982, 67.6759614944458, 64.78478826795305, 66.06472287859235, 64.56823376246861, 64.40208843776158, 64.31420067378453, 58.730920110430034, 54.34628370829991, 55.55598592758179, 68.00546591622489, 65.04289994921002, 65.21523611886161, 66.90492684500558, 63.62145137786865, 62.11211504255022, 71.69740513392857, 71.30711787087577, 72.66068254198346, 70.34691156659807, 74.16425882066999, 68.74690818786621, 69.97392531803676, 71.59891441890171, 76.77181352887834, 72.95034599304199, 78.37723650251115, 72.18340383257184, 74.59040573665074, 69.78555965423584, 72.5823346546718, 70.49782643999372, 68.34143216269356, 67.06763281141008, 64.1293716430664, 60.026133809770855, 59.827345848083496, 59.360058648245676, 63.300868443080354, 61.25322042192732, 75.96338367462158, 78.7543499810355, 80.76419980185372, 79.39401503971645, 76.42536939893449, 72.12301703861782, 70.35547174726213, 73.38157899039132, 79.50192751203264, 92.05172906603131, 43.047967365809846, 0.5034062159912926, 0.8139645829796791, 0.29281988739967346, 0.8277846585427011, 0.9046907403639385, 0.5750886638249669, 0.6264683125274522, 0.6827466040849686, 0.5314274866666112, 0.6296612811940057, 0.3035499687705721, 0.18772480104650768, 0.12744053373379366, 0.5164101496338844, 27.675508771623882, 83.86799485342843, 94.8082253592355, 95.09100314549038, 110.14200333186558, 45.81953082765852, 26.848918063299998, 45.55175072806222, 61.59938662392752, 73.0530959538051, 87.13100787571499, 66.91306318555559, 93.67828151157924, 23.611783606665476, 0.262670133795057, 0.22989162696259363, 0.18077888233321054, 0.21883168257772923, 0.11654506623744965, 0.19637747960431234, 0.1506191814052207, 0.23818829176681383, 0.08183865821255104, 0.13345789084477083, 0.09298387409320899, 0.17090452861573013, 0.16418123724205153, 0.2156195520822491], [0.029976900201290846, 0.028384549842615212, 0.08428113322172846, 0.015635324675323706, 0.0554621224956853, 0.02565438616355615, 0.027401562946449434, 0.04558032524905034, 0.07823653971510273, 0.032459035582308254, 0.030413747831646885, 0.03058434171336038, 0.0478523386908429, 0.03649122314527631, 1.3264991577182497, 59.0403025490897, 79.91891670227051, 62.946260179792134, 62.87094170706612, 26.25484882082258, 44.72381380626133, 54.50255911690848, 69.45750045776367, 100.3237054007394, 79.30008234296525, 21.0290687084198, 0.384737063731466, 0.15252636692353658, 0.07365688974303858, 0.08179090970328876, 0.44145550738487926, 0.023125674442521164, 0.1469267431114401, 0.03929410542228392, 0.18936574299420628, 0.21746724365012987, 0.10347781170691762, 0.5244012294071061, 0.21514681673475675, 6.923797820295606, 52.21474313735962, 88.73691722324916, 90.6136256626674, 90.04945972987584, 87.74004527500698, 87.25725664411272, 89.17053345271519, 86.02864142826625, 84.99817493983677, 84.45631967272077, 84.76934991564069, 83.37138625553676, 81.31846455165318, 78.39539909362793, 76.27811622619629, 71.24447291237968, 67.88458810533795, 62.16017573220389, 60.593252726963584, 56.79072598048619, 56.2088942527771, 57.01996442249843, 55.33281326293945, 56.888292585100444, 57.30060911178589, 54.403092179979595, 59.668892179216655, 59.501016753060476, 57.2298139163426, 60.804540497916086, 63.384093965802876, 60.3937977382115, 64.53110953739711, 62.56634657723563, 64.59015532902309, 64.61893476758684, 68.35543973105294, 67.03278759547642, 64.17927360534668, 62.05570956638881, 61.48440088544573, 63.240175928388325, 61.604166984558105, 59.644684655325754, 57.00146484375, 66.53141948154995, 52.07620300565447, 59.16675281524658, 72.30890219552177, 69.92660808563232, 66.95060430254254, 62.04997730255127, 56.192673683166504, 57.5146518434797, 64.59551933833531, 59.31684085300991, 58.289633069719585, 51.395071097782676, 59.6876870564052, 61.762335777282715, 64.60318320138114, 61.26640810285296, 63.211327007838655, 67.3738260269165, 62.941424233572825, 65.96198681422642, 59.803728921072825, 64.95153113773891, 66.27396093096051, 63.71265343257359, 66.32880306243896, 65.07844693320138, 66.71927097865513, 68.34291212899345, 63.65458038875035, 67.73349952697754, 68.8360674721854, 64.63347734723772, 55.194471154894146, 53.997734274183, 55.39884894234793, 54.21538312094552, 60.2051055090768, 67.47817407335553, 76.02136639186314, 66.00825486864362, 70.05281516483852, 71.95100743430001, 65.76154518127441, 59.07041604178292, 63.320858410426546, 72.22337681906563, 71.87092249734062, 70.90066909790039, 4.8483370287077765, 0.1327055176453931, 0.07061097318572657, 0.26219480644379345, 0.18782675771840981, 0.11121775888438735, 0.05222823138215712, 0.2153225573045867, 0.07919479400983878, 0.15258743507521494, 0.1551945973187685, 0.17309785235141004, 0.09889113889741045, 0.17157219350337982, 0.6116546445659229, 28.01510545185634, 72.89662946973527, 76.92502825600761, 80.33635752541679, 85.2506377356393, 33.577659538814, 9.90393795285906, 12.115410600389753, 25.810025147029332, 38.60267318998064, 56.62426103864397, 53.65136310032436, 64.35962104797363, 8.339370386941091, 0.271131872598614, 0.08328009729406663, 0.0870202908824597, 0.03189507120155862, 0.06268370284565858, 0.03554546746558376, 0.023926076046856384, 0.024189803948892013, 0.06988810947430985, 0.06242802406528166, 0.07362044562718698, 0.09677563634301935, 0.03254796438185232, 0.08440803284091608, 0.026596996833437254, 0.06642927043139935, 0.009624190578636314, 0.010637735299366926, 0.03465501917526126, 0.05655825510621071, 0.044559795010302744, 0.021961598424240947, 0.013017296541615255, 0.04803362628445029, 0.03711181466600724, 0.058934505097568035, 0.19484306765454157, 1.6898327299526759, 69.38835893358502, 89.04368019104004, 73.20262813568115, 75.7660687310355, 39.96014622279576, 49.67429413114275, 50.670134271894185, 79.93409851619175, 106.88875947679792, 95.00116988590786, 27.079594782420568, 0.22953729597585543, 0.1326736264995166, 0.12378439706351076, 0.08671368804893323, 0.3575107104011944, 0.03204760926642588, 0.07269310538790055, 0.043310204919959815, 0.11000312691820519, 0.25625526372875485, 0.08204832553331341, 0.5236211312668664, 0.5478847292917115, 7.5468883855002264, 53.837369850703645, 90.44194262368339, 94.14321327209473, 92.94483661651611, 90.70960807800293, 90.04785469600132, 91.18610164097377, 90.64036233084542, 90.5136410849435, 87.95912197657994, 89.25167451586042, 87.14893422807965, 84.15353107452393, 80.56659303392682, 77.01552854265485, 73.16013295309884, 70.09292016710553, 64.98022719791958, 62.42076792035784, 60.629348618643625, 60.526230403355186, 58.38486507960728, 60.00847148895264, 58.5479462487357, 60.15277167728969, 58.83723449707031, 64.02858802250454, 62.398297446114675, 62.64766134534563, 64.77795124053955, 65.76175362723214, 64.63097599574498, 69.1492783682687, 65.4302898134504, 67.66208594185966, 68.32690347943986, 71.61120578220913, 69.37822846003941, 68.20655373164585, 66.39874362945557, 67.60522883278983, 67.14224951607841, 66.99995735713414, 62.60237298692976, 59.913190841674805, 67.84585884639195, 56.69624785014561, 64.69958945683071, 76.28930977412632, 71.8028370993478, 68.55950137547084, 65.27541446685791, 61.34875120435442, 59.58589594704764, 67.04171603066581, 62.25099563598633, 62.557133265904014, 61.874757630484446, 67.67056274414062, 67.18136092594692, 66.17401804242814, 62.871365547180176, 68.46954999651227, 67.86040142604283, 68.86295700073242, 67.8316706248692, 65.35791042872837, 67.92685399736676, 70.47129126957485, 64.72973074231828, 70.25079018729073, 69.80545929500035, 70.80144882202148, 71.83884961264474, 67.41423674992153, 69.12973308563232, 71.77530833653041, 68.64834799085344, 58.32087217058454, 55.51298005240304, 57.778346402304514, 58.35732242039272, 65.67388670785087, 70.20307690756661, 78.1628428867885, 70.93718882969448, 74.17710603986467, 74.56215436117989, 69.13776520320347, 61.89761025565011, 66.74329090118408, 74.5430120740618, 75.2590308870588, 78.71422413417271, 6.097353892666953, 0.10637175677610294, 0.3504418140011174, 0.613443697137492, 0.2656110131314823, 0.11416017849530492, 0.21069369997297013, 0.5849931037851742, 0.1271421547446932, 0.15814409404993057, 0.13497205530958517, 0.21327286586165428, 0.10476359485515527, 0.08010940493217536, 0.6817747790898595, 34.91756752559117, 80.81775651659284, 87.4605609348842, 76.19564805712018, 41.267105851854595, 28.783140216554912, 22.7592830657959, 25.627859013421194, 42.20213883263724, 49.26199844905308, 65.96407127380371, 62.12709535871233, 76.2362255368914, 9.340641413416181, 0.23143420847398893, 0.03017698660758989, 0.07283856293984822, 0.04206359699102385, 0.05364284458171044, 0.05354421951674989, 0.004533139789210898, 0.022128273766221743, 0.022245804513139383, 0.021779313384156142, 0.04615749392126288, 0.05492471258289047, 0.03201005235314369, 0.19478860843394483, 0.12244361186666147, 0.20238494367471763, 0.13808586608086312, 0.12578580395451613, 0.13542694518608706, 0.1379757398473365, 0.1528174720172371, 0.15897255816629954, 0.16621168543185505, 0.20344970082598074, 0.18583559670618602, 0.20595192084355013, 0.34681363297360285, 3.657305487564632, 87.1648178100586, 100.08947467803955, 81.82545375823975, 82.98393385750907, 39.09505033493042, 57.529527936662944, 78.84185559409005, 89.71397985730852, 114.88767855507987, 101.66884885515485, 30.899851594652446, 0.45003501272627283, 0.36321596854499405, 0.24931512613381657, 0.3779365415019648, 1.0074617628540312, 0.26104048267006874, 0.6612436664955956, 0.26896740017192705, 0.4505154426608767, 0.6637747106807572, 1.014910883137158, 1.7462270238569804, 0.753392250410148, 9.645081945828029, 60.453531401497976, 98.57871396200997, 99.60688059670585, 97.38567352294922, 94.93476595197404, 91.9512025288173, 94.46840981074742, 93.68460437229702, 92.79779188973563, 93.11824975694928, 92.76289108821324, 90.82409354618618, 88.51770155770438, 85.23150934491838, 81.6627061026437, 77.52121148790631, 75.29731546129499, 67.02014187404087, 68.86208152770996, 65.05587223597935, 63.70748397282192, 62.162232398986816, 62.148474965776714, 63.57989420209612, 65.01561437334333, 62.11732619149344, 67.81011036464146, 67.51404067448208, 64.96095289502824, 68.92833260127476, 69.73403876168388, 68.4624558857509, 74.20708751678467, 70.51477309635708, 70.72127355848039, 72.57848535265241, 77.63154888153076, 75.1242149897984, 74.55949320111955, 70.74434852600098, 73.4397771017892, 70.57311711992536, 70.9828940800258, 67.56757654462541, 61.437979970659526, 68.04405621119908, 60.203854833330425, 64.79798289707729, 77.16105161394391, 75.29307011195591, 70.05562223706926, 66.72578838893345, 63.94625881740025, 63.99947507040841, 71.37505040849958, 64.48618943350655, 69.31870324271065, 61.869351931980674, 67.60388088226318, 69.95488030569894, 70.71724360329765, 66.06584848676408, 68.9441328048706, 74.81597900390625, 72.74113573346818, 71.5034600666591, 68.15628351484025, 72.08937386104039, 73.80698244912284, 69.3757757459368, 75.1031619480678, 71.58941623142788, 76.4522728238787, 76.21777806963239, 69.82377474648612, 72.77374362945557, 77.29406792776925, 71.25162955692836, 60.671683992658345, 59.43039526258196, 60.276428767613, 60.523555346897666, 66.09053543635777, 73.73713220868791, 80.74037442888532, 74.02917889186314, 75.70890590122768, 77.58975546700614, 69.74149417877197, 66.02547250475202, 69.68002346583775, 80.82134178706578, 78.28940432412284, 85.9216947555542, 8.099728754588536, 0.4752628632954189, 1.181833646127156, 1.1255368441343307, 0.8652858233877591, 0.27994053278650555, 0.37584182247519493, 0.779433935880661, 0.4376974276133946, 0.9444300936801093, 0.7681895792484283, 0.2852972410619259, 0.2864993879837649, 0.2520241364836693, 1.3688416970627648, 45.17606510434832, 90.5589085987636, 93.09967027391706, 102.56736210414341, 118.5207039969308, 46.09712873186384, 17.707937479019165, 21.58254657472883, 43.3632800919669, 53.25422143936157, 77.95803778512138, 67.90729481833321, 91.19160461425781, 12.50562230178288, 0.3514519626540797, 0.2605732705976282, 0.1970986266221319, 0.15264117504869187, 0.1295633033982345, 0.11626021723662104, 0.10360638052225113, 0.10549987998924085, 0.11431755790753023, 0.21047610736318997, 0.09090512099542788, 0.1623254982488496, 0.13011359529835836], [0.04182611991252218, 0.03333289369142481, 0.09461545904300042, 0.04940711008384824, 0.020262556915570582, 0.01354914331542594, 0.012150069415968443, 0.00934536018342312, 0.09332550968974829, 0.025017820232148682, 0.03531178679051144, 0.08348571376076766, 0.14722278794007643, 0.41614661259310587, 9.349918127059937, 76.48466532570976, 65.0715195792062, 69.14140605926514, 35.75503042766026, 30.538138798304967, 28.272447620119365, 36.265191486903596, 88.32035187312535, 96.18248871394566, 50.65146098818098, 1.0248410531452723, 0.07802129483648709, 0.07052305540336029, 0.052208414766937494, 0.04210145245971424, 0.1873988735356501, 0.10282033162989787, 0.33410782047680443, 0.07537021780652658, 0.05794331471302679, 0.1056213988257306, 0.3312819392553398, 0.4282988762216908, 0.2070606742054224, 9.284205538885933, 56.96140153067452, 88.44049317496163, 86.58440698896135, 90.79376465933663, 87.58808817182268, 87.2731054850987, 84.39851066044399, 81.51954541887555, 81.58825615474156, 84.52822657993862, 80.82611519949776, 81.083406993321, 77.83501992906842, 69.9297764641898, 67.11950806209019, 61.10475826263428, 59.99698611668178, 57.47895547321865, 57.57404504503523, 54.31107371194022, 55.07140118735177, 53.823949405125205, 54.75664431708199, 57.416696139744346, 59.449600083487375, 57.90366758619036, 55.4608268737793, 58.10432461329869, 57.776039600372314, 60.46180670601981, 61.090417180742534, 61.19564764840262, 61.4389249256679, 60.86653232574463, 65.3237669808524, 65.24077074868339, 65.83985832759312, 62.236661502293174, 59.60897091456822, 64.44487544468471, 64.11544050489152, 60.280354499816895, 58.40743977682931, 56.75685698645455, 61.452237674168174, 63.46893841879708, 53.60209689821516, 68.99737685067313, 69.1750978742327, 66.93613120487758, 70.7583977835519, 69.79343891143799, 66.61893899100167, 60.78708662305559, 60.3109404700143, 59.73251683371407, 60.70444474901472, 65.8555543082101, 67.33766760144914, 65.34345122746059, 66.03459548950195, 61.57683971949986, 60.77514961787632, 61.336404255458284, 66.31449672154018, 65.85099628993443, 63.01531832558768, 63.02665778568813, 59.48561259678432, 55.25202655792236, 59.11138262067522, 57.75755044392177, 60.731633050101145, 63.79120976584298, 62.23722430637905, 64.93381323133195, 65.09931237357003, 64.73030049460274, 58.756558963230674, 52.460855279650005, 51.94689702987671, 53.85949291501726, 62.199335779462544, 67.69499261038644, 65.30591011047363, 68.5516082218715, 75.9115709577288, 67.74139962877545, 66.71207959311349, 60.196378571646555, 60.030490330287385, 67.22254289899553, 71.97536781855992, 67.19400664738247, 33.4645220211574, 0.3419434614479542, 0.20426382071205548, 0.6720350331493786, 0.17373805014150484, 0.1023132624104619, 0.08491903077811003, 0.24934015050530434, 0.16176844813993999, 0.16403931485755102, 0.3577619854893003, 0.07605702416705233, 0.049221147383962355, 0.006877376074304006, 0.2149880938231945, 4.681766126837049, 45.16792181559971, 75.76026003701347, 68.40339619772774, 71.58020986829484, 52.967785426548545, 35.41388429914202, 23.06621105330331, 17.904772996902466, 29.07483080455235, 45.48491253171648, 63.84865052359444, 63.50953674316406, 53.64397369112287, 0.6116030759045056, 0.10348879040351935, 0.10274507531097957, 0.024519200470032435, 0.01658516513582851, 0.03287077063162412, 0.04711760400927492, 0.04568690613710454, 0.025503035534971526, 0.0612955219777567, 0.01934978143045945, 0.03875424939074686, 0.04288490256294608, 0.036294990817883184, 0.04470145955149617, 0.04110156325623393, 0.03834907238238624, 0.061415446256952624, 0.03910180181264877, 0.031364870723336935, 0.06064653715917042, 0.03381001916048782, 0.070008624078972, 0.1123175352279629, 0.0506374569210623, 0.14141832797655038, 0.5276695968849319, 11.384775383131844, 89.2666826248169, 72.16352503640312, 81.21708338601249, 47.333418233054026, 39.524105072021484, 29.549378871917725, 43.78420196260725, 95.09250395638603, 103.24633312225342, 63.651432854788645, 1.4841563893215997, 0.11257797053882054, 0.04963892478761928, 0.26777952962688034, 0.06868310592004231, 0.23730554484895297, 0.4428108132311276, 0.3057457352323191, 0.3588058980447905, 0.09343285392969847, 0.03131388560203569, 0.321861810450043, 1.4054143003055026, 0.6586524769663811, 9.996051090104238, 61.24186706542969, 90.1813017981393, 92.11387375422886, 93.22078432355607, 89.8236780166626, 91.02791895185197, 87.21947234017509, 82.60418006352016, 85.93352058955601, 87.7321868624006, 85.71093504769462, 84.06551824297223, 78.06697164263043, 72.29158033643449, 68.41904354095459, 64.13073348999023, 61.78809969765799, 59.91540731702532, 60.69497435433524, 57.84605312347412, 56.89680412837437, 58.094770840236116, 58.881716864449636, 61.52335248674665, 62.78005232129778, 61.40142549787249, 59.285872731889995, 61.55745424543108, 61.36940125056675, 62.73267950330462, 65.49424798148019, 65.40190642220634, 66.3627450125558, 64.39211777278355, 67.71844972882951, 66.47609097617013, 68.7481449672154, 66.05548872266496, 63.5517817905971, 68.22828769683838, 69.46517821720668, 63.677724838256836, 62.545481136866975, 59.226799147469656, 64.94548620496477, 63.82041999271938, 58.11237062726702, 71.62641538892473, 70.6250479561942, 69.75404957362584, 74.06323896135602, 71.29674421037946, 68.9083217893328, 64.5508007322039, 63.99898174830845, 62.27280603136335, 65.29079777853829, 64.5124397277832, 66.55971949441093, 66.5717190333775, 68.71150016784668, 63.67812088557652, 66.70274121420724, 65.74083260127476, 68.26728793552944, 65.8382602419172, 65.47439697810582, 68.26759365626744, 65.13201059613908, 56.20700086866106, 59.71702929905483, 58.04545947483608, 61.049499239240376, 65.79981585911342, 67.7071728025164, 68.44488389151437, 69.64560903821672, 68.23679229191372, 62.0845376423427, 56.15258952549526, 54.62885652269636, 55.47324330466134, 64.78269686017717, 70.90118326459611, 67.92777810777936, 71.4192201069423, 81.1934734072004, 71.43158095223563, 67.68867669786725, 66.23772607530866, 62.72807284763881, 70.53631251198905, 73.48414829799107, 75.83945560455322, 43.50480794906616, 0.5794558780533927, 0.09486971968518836, 0.7539419723408562, 0.31135377287864685, 0.29478693327733446, 0.020599200190710168, 0.11303400713950396, 0.19872567217264855, 0.11278505264116184, 0.3139815761574677, 0.21653914345162256, 0.2183178687202079, 0.11988884609724794, 0.14220826487456048, 5.858183869293757, 53.956805910382954, 85.35755661555699, 79.69428144182477, 69.89192962646484, 31.7781594821385, 25.666115794863018, 30.44769757134574, 27.430650779179164, 37.31759343828474, 56.77705192565918, 70.44607625688825, 72.40995679582868, 62.846240861075266, 0.6351611603583608, 0.04066748744142907, 0.045943226133074076, 0.020729926747402976, 0.058205039240419865, 0.024388663903144852, 0.026096126031396643, 0.05976466555148363, 0.06353614638958659, 0.036821411856051, 0.015385099620159184, 0.013605786570613938, 0.06764941888728312, 0.11493701966745512, 0.06724066260669913, 0.23463925506387437, 0.18695215322077274, 0.14146366768649646, 0.18082803540996142, 0.10110752603837422, 0.1951807745333229, 0.26405236391084536, 0.12820691189595632, 0.21103322532560143, 0.2941662094422749, 0.2621209818337645, 0.7396532190697533, 16.259797402790614, 103.18430655343192, 82.99913651602608, 90.92890017373222, 49.25301790237427, 44.42372805731637, 38.6865587915693, 56.11498587472098, 105.24795627593994, 113.75381592341832, 72.27853856767926, 1.9204104372433253, 0.2418040691741875, 0.12174214236438274, 0.5572541579604149, 0.22251785120793752, 0.8324060791305133, 1.4841373903410775, 1.4656925286565508, 1.00469713977405, 0.2929756518985544, 0.32084563640611513, 1.0104954114982059, 2.0785414491380965, 1.382580239857946, 11.475095885140554, 66.55200699397496, 98.08688572474888, 96.14268248421806, 98.2421293258667, 92.37819712502616, 94.81757763453892, 87.64087363651821, 85.27355289459229, 87.88538074493408, 92.29431847163609, 90.84980882917131, 87.71453148978097, 84.21829523359025, 77.24378381456647, 73.16775512695312, 67.57793630872453, 67.0952102116176, 65.00593553270612, 64.8560003553118, 60.07170704432896, 60.479538508823936, 61.0891387122018, 61.68783024379185, 65.15018013545445, 65.97228404453823, 65.2760398047311, 62.156020709446494, 65.06785787854875, 65.50649070739746, 68.06318460191999, 69.69730363573346, 69.98844010489327, 69.3039105279105, 68.64021165030343, 73.57494735717773, 71.81938076019287, 77.23649515424455, 72.04364081791469, 69.28443472726005, 73.20127323695591, 72.84874248504639, 68.10601329803467, 65.86679649353027, 61.4248548235212, 65.7164444242205, 64.67092813764299, 56.94687979561942, 72.75324644361223, 73.22313921792167, 72.31736510140556, 76.80941023145402, 73.80119459969657, 71.86665630340576, 65.75585460662842, 67.43326786586216, 66.15748132978166, 66.87082508632115, 69.49397850036621, 72.60675757271903, 70.71981443677629, 73.54286057608468, 67.01708466666085, 68.61796351841518, 68.46064935411725, 71.13482339041573, 71.32698277064732, 69.371169090271, 71.53996590205601, 70.03984982626778, 61.15495204925537, 67.91170692443848, 63.47885349818638, 66.74096325465611, 68.45584814889091, 71.71535233088902, 70.92723900931222, 70.96431459699357, 70.26736164093018, 64.88006891523088, 58.21094124657767, 57.320800576891216, 58.61393329075405, 68.4104277747018, 73.36757837023053, 70.39425659179688, 72.20089939662388, 83.61094624655587, 75.0977006639753, 70.68380887167794, 68.75724015917096, 64.4129832131522, 75.205230985369, 75.45295510973249, 79.24881158556256, 51.355066844395225, 0.635811522603035, 0.3062705413571426, 1.2290780310119902, 0.9803877813475472, 0.7322882914117405, 0.31095802411437035, 0.6775592852916036, 0.30609822060380665, 0.6715826402817453, 1.0735030876738685, 0.40784468235714094, 0.24077888418521198, 0.1750410409378154, 0.3083869463631085, 9.522876160485403, 64.66830866677421, 94.19626276833671, 86.31364263807023, 95.68898596082414, 73.35156277247837, 46.92235933031355, 31.808724607740128, 28.291160855974468, 42.73460360935756, 63.194074630737305, 83.40329933166504, 80.33477333613804, 73.92178058624268, 0.8227904236742428, 0.23525012657046318, 0.2593649625778198, 0.10551454991634403, 0.11636772432497569, 0.14155479493950093, 0.23712413172636712, 0.16706267691084317, 0.1397891246846744, 0.17839388602546283, 0.0865897536277771, 0.12058133179587976, 0.18884361029735633], [0.03236723657963531, 0.03358318490375366, 0.05801673898739474, 0.07822680952293531, 0.02377984835766256, 0.014986746977748615, 0.028307943239009807, 0.023570121665086066, 0.037976149536137066, 0.05003350647166371, 0.10838281243507351, 0.015349539296169366, 0.08710921289665358, 0.05733519805861371, 32.34753656387329, 71.0755899974278, 62.74669401986258, 57.91154336929321, 42.326254504067556, 33.13043178830828, 58.367306981767925, 68.55096203940255, 92.32457092830113, 75.13393551962716, 8.5402158839362, 0.03744312295956271, 0.058765705940978866, 0.030435433810842887, 0.06552263908088207, 0.037761793538395844, 0.043760036317897696, 0.1363859051572425, 0.2609089825834547, 0.3336506778640406, 0.16261724116546766, 0.031210846666778837, 0.3823762775531837, 1.1280853130987711, 0.432748518884182, 21.694671392440796, 77.50848933628627, 86.57602746146065, 87.03438622610909, 85.09733963012695, 86.63537897382463, 84.40456254141671, 89.35132558005196, 82.48756149836949, 85.7419101170131, 80.26572213854108, 77.24716063908168, 71.7604044505528, 66.32794843401227, 61.87232576097761, 59.54443604605538, 60.07961409432547, 59.82203047616141, 60.09717914036342, 60.92605059487479, 58.51417800358364, 59.47958156040737, 62.40295968736921, 64.20632989065987, 64.1408222743443, 65.29586996350969, 61.548727308000835, 58.85324314662388, 57.21200220925467, 57.23999302727835, 59.69765772138323, 59.24860954284668, 63.901331765311106, 60.666785512651714, 63.17174312046596, 64.90750735146659, 63.074002810886924, 57.7009573663984, 54.686338969639365, 61.183210372924805, 66.11446503230503, 63.403729575020925, 59.489406313214985, 60.545595032828196, 61.30866009848458, 62.07132911682129, 62.12026527949742, 63.54882880619594, 68.08659308297294, 68.32383237566266, 65.2157850265503, 68.80785778590611, 66.84171908242362, 68.36274228777204, 69.71281201498849, 67.55947494506836, 61.2199524470738, 57.7151768548148, 52.64011532919747, 58.124707153865266, 64.09281022208077, 64.94556958334786, 62.77664770398821, 58.978032793317524, 68.6656767981393, 67.01509053366524, 64.35438905443463, 61.05952548980713, 60.50940186636788, 57.115363189152305, 52.9145622253418, 53.1711105619158, 59.285657337733674, 60.319396427699495, 65.67333780016217, 66.39588791983468, 69.40737615312848, 64.39217335837228, 64.39611993517194, 57.6225643157959, 53.83021320615496, 52.04932737350464, 53.13150930404663, 58.53937911987305, 63.14816093444824, 67.65779890332902, 73.47012683323452, 70.61960056849888, 71.68740667615617, 62.98626790727888, 60.63324655805315, 59.21313204084124, 63.526559829711914, 71.41465514046806, 62.79795088086809, 57.76419292177473, 12.841252429144722, 0.07690882988806282, 0.010110581443378968, 0.2662504645330565, 0.83303651958704, 0.26076863440019743, 0.14395428475524696, 0.10034018435648509, 0.07345763114946229, 0.14502216316759586, 0.45503975131681984, 0.053870116493531635, 0.04401319773335542, 0.024810280118669783, 0.0939145866515381, 14.267702834946768, 58.70910276685442, 77.2951032093593, 64.82813807896206, 85.77800600869315, 76.65607043675014, 38.71687030792236, 24.6545501436506, 20.942511524472916, 24.03179005214146, 48.579087802342, 53.15210723876953, 71.13894367218018, 13.316965188298907, 0.5134285581963403, 0.1894452672983919, 0.11874976222004209, 0.13137234561145306, 0.08066166458385331, 0.03391144657507539, 0.039161445040787966, 0.07247958398823227, 0.06679550292236464, 0.041848643882466216, 0.05366646438570959, 0.048480051436594555, 0.028507223884974207, 0.017829026694276502, 0.024769637567390288, 0.03555405432624476, 0.0012560787935009493, 0.015415842345516597, 0.03988244278090341, 0.021955072613699094, 0.08467945363372564, 0.012149276378165399, 0.016672818289537514, 0.014867925317957997, 0.06476714462041855, 0.10481815585600478, 38.79826845441546, 81.83887767791748, 71.39713178362165, 66.94407994406563, 43.82492535454886, 40.31538677215576, 37.60271276746477, 69.29278646196637, 101.98398440224784, 87.98086983816964, 13.787878479276385, 0.06936568500740187, 0.051398355912949355, 0.28345705409135136, 0.1405694806682212, 0.1642406497682844, 0.05984201854360955, 0.8072357954723495, 0.21611864172986575, 0.3356364241668156, 0.43182649835944176, 0.3116395989699023, 0.7352817165000098, 1.5037743023463657, 0.6661953979304859, 25.436569895063126, 81.22277396065849, 91.00550406319755, 91.06341729845319, 88.37017045702252, 90.98144939967564, 88.93915843963623, 92.63499559674943, 84.10980606079102, 89.14696516309465, 82.99831662859235, 81.27161284855434, 74.23046125684465, 68.8652012688773, 66.64657197679792, 63.955673626491, 63.236743518284385, 63.03153542109898, 63.98046479906355, 62.85717037745884, 62.393718583243235, 61.83893966674805, 65.40444946289062, 68.02478885650635, 70.60196604047502, 69.63107340676444, 67.05550820486886, 63.07298142569405, 60.70996856689453, 60.34379850115095, 63.68722997392927, 62.30985382625035, 67.99587740216936, 65.29778071812221, 66.94150911058698, 68.33050959450858, 66.93768760136196, 61.77398790631975, 62.087789399283274, 65.67687443324498, 70.37776851654053, 66.25175448826381, 64.0979449408395, 63.973627771650044, 63.69755499703543, 64.45035757337297, 62.092729568481445, 67.83508913857597, 72.40544046674455, 71.47843960353306, 68.17479351588658, 70.29605770111084, 69.30355616978237, 70.45025907244, 71.2243161882673, 70.89769526890346, 66.1244843346732, 61.273926053728374, 57.89611142022269, 59.81716673714774, 64.34629440307617, 64.5567900793893, 65.90279511043003, 65.26110117776054, 72.8066155569894, 67.34456716264997, 67.1957506452288, 66.60011632101876, 63.445439611162456, 62.180249077933176, 55.90521975925991, 58.53224331992013, 64.9626829964774, 66.51427132742745, 69.16628061022077, 67.44339139120919, 70.1397510256086, 67.33420045035226, 66.12559604644775, 60.919950076511924, 55.418515818459646, 54.05096789768764, 57.59702621187483, 61.545322690691265, 65.86460086277553, 70.64605930873326, 75.61054720197404, 74.14678410121373, 74.78631019592285, 68.01114954267229, 63.1137604032244, 62.20934813363211, 65.8091264452253, 74.19844395773751, 70.05064732687813, 70.77460098266602, 16.491896765572683, 0.1024179875052401, 0.2509223041789872, 0.5285224339791706, 1.5218997640269143, 0.5517465706382478, 0.45190288392560823, 0.10933620841907603, 0.0923160192157541, 0.28525946023208754, 0.03126841697043606, 0.5212697631546429, 0.1446660544191088, 0.045564861435975344, 0.05415220046415925, 18.1211416380746, 68.7699692589896, 84.44309030260358, 75.67504038129533, 60.979961667742046, 30.510839326041086, 16.634001323154994, 25.96949325289045, 30.86268220629011, 29.211897918156215, 66.00269630977085, 59.609241894313264, 84.2346304484776, 15.064738512039185, 0.3910442367196083, 0.14004669657775334, 0.07079207418220383, 0.11898270329194409, 0.07901982018457991, 0.041195238408233435, 0.011578720877878368, 0.039392839052847455, 0.014968122887824262, 0.07055275488112654, 0.06346242355981044, 0.0592703324343477, 0.14992228522896767, 0.0937198945986373, 0.16851219055908068, 0.19201603292354516, 0.10353735315480403, 0.08632542352591242, 0.11249172195260014, 0.12179305963218212, 0.12896144283669336, 0.17314970599753515, 0.19352502695151738, 0.1263731438666582, 0.13206774901066506, 0.24571753346494266, 50.34020601000105, 93.65695054190499, 80.96601717812675, 76.72437122889927, 59.82663018362862, 46.45014238357544, 77.84654699053083, 92.98551831926618, 106.74270139421735, 100.001051902771, 16.793459006718226, 0.17412667428808554, 0.18529394934219973, 0.43764140776225496, 0.21989337275070803, 0.39242299273610115, 0.42306110156433924, 2.372957685164043, 0.7807198954480035, 2.060058589492525, 1.2291106006928851, 0.5662039262907845, 1.2205834239721298, 3.07540123803275, 1.2787447316305978, 28.178242206573486, 91.22347600119454, 98.59887763432094, 97.10443128858293, 93.79384395054409, 96.39438792637416, 95.3489272253854, 95.68902765001569, 87.98633112226213, 92.08369772774833, 87.13812283107212, 84.17131151471818, 79.10458782741001, 73.15062086922782, 69.83790738242013, 66.91473075321743, 66.19698183877128, 65.36377470833915, 66.89779104505266, 66.44510201045445, 65.8987512588501, 64.00495025089809, 68.36090101514543, 71.42178399222237, 74.24357945578438, 72.50977461678642, 70.90845108032227, 66.53458091190883, 65.03087956564767, 63.70370415278843, 66.86281381334577, 65.8498637335641, 71.60231903621128, 68.26959473746163, 70.95295429229736, 73.44421005249023, 74.96565014975411, 69.48088809422084, 67.39298221043178, 70.38389682769775, 73.95132432665143, 70.08179610116142, 65.78908089229039, 66.06359727042062, 65.09354536873954, 66.65549346378872, 61.03037084851946, 69.41570704323905, 75.64073712485177, 75.68316282544816, 71.30956363677979, 74.3824600492205, 71.16655581338065, 72.51853629520961, 74.69070993150983, 71.16110842568534, 66.70989091055733, 63.800624574933735, 59.12048476082938, 63.18597303118025, 69.53823852539062, 70.85947322845459, 67.64147063664028, 65.29159682137626, 74.04670224870954, 72.33752877371651, 69.87171731676374, 69.8920338494437, 67.63457802363804, 68.00042847224644, 59.898953982761924, 61.95095157623291, 68.20711653573173, 69.80284677233014, 73.2131129673549, 72.41164520808628, 75.02491133553642, 71.5905487877982, 69.98701572418213, 63.93750408717564, 59.878213609967915, 58.48609338487898, 59.317403657095774, 63.73479734148298, 70.53652790614537, 74.00239358629499, 77.3349858692714, 77.20902197701591, 77.5919441495623, 71.55075645446777, 66.05564158303397, 65.59734535217285, 68.17745467594692, 78.53105572291783, 72.79744393484933, 82.1957927431379, 18.880176748548234, 0.2600571768624442, 0.5864459286843027, 1.4252674749919345, 2.586884034531457, 0.7125247919133731, 0.7314778491854668, 0.35290106918130604, 0.15927916099982603, 0.6395329343421119, 1.0648131711142403, 0.3941449789064271, 0.13911626221878187, 0.1142146105745009, 0.2367165493113654, 26.84757011277335, 76.54976994650704, 95.22759083339146, 81.71437290736607, 117.52720887320382, 105.34937913077218, 53.141389642442974, 36.96935319900513, 35.03756638935634, 39.20675999777657, 66.84692328316825, 70.52903079986572, 94.640134538923, 18.07124662399292, 0.7921994594591004, 0.25518936663866043, 0.27653550835592405, 0.2703994618994849, 0.1416155645357711, 0.2711266614496708, 0.10131327821207897, 0.16216974732066902, 0.13301034271717072, 0.13408090812819345, 0.15435424526887281, 0.11954872363380023], [0.03544187552428671, 0.05164783288325582, 0.07347571410770927, 0.042217085004917214, 0.05527484004518815, 0.03568962223029562, 0.06023203368697848, 0.011070673719846776, 0.07336109597235918, 0.033646034209855964, 0.02125487197190523, 0.08041129873267241, 0.07390454145414488, 0.13088875370366232, 39.28772735595703, 75.76183727809361, 59.86894471304757, 71.93859100341797, 33.27537815911429, 38.72424234662737, 53.67903430121285, 71.16146278381348, 95.90398406982422, 39.53158828190395, 1.0147639938763209, 0.027327602629416754, 0.08832172783357756, 0.03196365412856851, 0.07573988368468625, 0.06860497939799513, 0.1006719744099038, 0.10686353181621858, 0.1679715881390231, 0.3614736263241087, 0.43991105311683243, 0.10264892689883709, 0.5631566526634353, 0.6499004065990448, 2.711575537919998, 62.08557987213135, 88.81664085388184, 81.88754286084855, 84.70826135362897, 82.89797074454171, 78.40381336212158, 81.82193102155412, 84.63435336521694, 85.06293909890312, 84.78109931945801, 79.27889728546143, 75.25748143877301, 66.49178695678711, 63.008258955819265, 61.39274719783238, 60.02128396715437, 64.2348244530814, 66.36400263650077, 71.28291034698486, 70.12957886287144, 68.01641627720424, 68.21466227940151, 70.68534442356655, 71.77986635480607, 69.79875428336007, 67.53051485334123, 69.3074471609933, 62.02298355102539, 60.585693086896626, 61.40419782911028, 60.47313921792166, 59.998813492911204, 62.41174915858677, 61.69529260907854, 65.28747653961182, 62.46265860966274, 59.811934743608745, 53.95156002044678, 59.41124602726528, 63.83301707676479, 65.62062181745256, 64.21426473345075, 65.02207619803292, 69.15489251273019, 61.504634039742605, 63.70331505366734, 66.10231263296944, 65.586777142116, 66.63655267442975, 69.79837908063615, 67.73957920074463, 66.86999130249023, 66.64432770865304, 67.23404911586216, 67.48095335279191, 68.83656079428536, 69.85979420798165, 63.587023053850444, 63.29255839756557, 53.090848445892334, 61.97624996730259, 54.776130540030344, 59.846786907741, 57.07476486478533, 63.95962715148926, 62.795935903276714, 62.49180630275181, 61.026104654584614, 59.7735389981951, 51.90035799571446, 46.963002817971365, 60.13864598955427, 58.91034344264439, 59.683288846697124, 61.68628774370466, 62.33067757742745, 62.22780949728829, 62.80952657972063, 63.0501982825143, 56.97207743780953, 52.849527086530415, 50.75161232267107, 52.59015083312988, 55.61574043546404, 62.349882398332866, 68.45003945486886, 69.81781319209507, 68.65644264221191, 69.97199371882847, 65.66353389195034, 61.10238197871617, 58.84691333770752, 60.90071051461356, 65.28189713614327, 67.30798489706856, 57.71944999694824, 40.95085164478847, 4.356804958411625, 0.3383948047246252, 0.3115200139582157, 0.26212361454963684, 0.5720592492393085, 0.16292822733521461, 0.05270186239587409, 0.1737461518496275, 0.09205260513616459, 0.14489124662109784, 0.6943943904978889, 0.29734167190534727, 0.10327904165855475, 0.14492733111338957, 1.2476973576205117, 28.69927372251238, 70.70639746529716, 76.51718984331403, 73.0856830051967, 64.19705404554094, 91.22030762263707, 35.437598500932964, 51.30176026480538, 75.3771641595023, 26.505854231970652, 51.097649982997346, 66.82708617619106, 30.25971405846732, 0.3340660227196557, 0.04503262196002262, 0.09539951982774905, 0.024259458961231366, 0.025699781852641275, 0.08724793938121625, 0.06243717750268323, 0.03577754679801209, 0.011451618546353919, 0.00969391514081508, 0.03206436229603631, 0.0353246585998152, 0.023272159975022078, 0.034513398738844056, 0.07706615501748663, 0.0799774502270988, 0.04474804437320147, 0.019566173033256615, 0.09261533458318029, 0.011184453864448836, 0.013537025528161653, 0.03587821425337877, 0.04715616515438471, 0.04133874177932739, 0.07759010618818657, 0.027181849914735982, 50.75060830797468, 84.27441583360944, 68.6712839944022, 77.56531865256173, 46.96848494665963, 31.91594226019723, 31.946496963500977, 80.43046392713273, 103.3047605242048, 50.278478213718955, 0.915314427443913, 0.024745522432827523, 0.18218913594526903, 0.3222839135144438, 0.24699524204645837, 0.08480025322309562, 0.12653378024697304, 0.12634741381875106, 0.3366439129625048, 0.5700925290584564, 0.7731036927018846, 0.6305871829390526, 1.5264514854976108, 0.9457582852670124, 4.9456630519458225, 66.59713554382324, 95.60196672167096, 90.34475122179303, 88.96299770900181, 87.88943154471261, 81.85332298278809, 86.10588455200195, 86.36494813646588, 87.12758936200822, 87.7842149734497, 85.7617472239903, 78.0980509349278, 70.46269634791783, 63.367480822971885, 64.30960791451591, 62.68887805938721, 68.07268973759243, 70.89863327571324, 73.505722454616, 74.06297492980957, 73.524169921875, 71.9206577028547, 75.79217311314174, 74.38657338278634, 72.30403150830949, 72.89206450326103, 70.84636197771344, 67.13300841195243, 65.51186166490827, 63.015109879629954, 64.39808627537319, 63.636098180498394, 66.46979590824672, 66.22045285361153, 67.11374105725969, 66.27287006378174, 63.696269580296104, 60.734460966927664, 64.43329279763358, 67.94152164459229, 68.7972548348563, 68.58240263802665, 67.1382612500872, 71.46332727159772, 63.10788917541504, 64.00014904567173, 68.41292217799595, 68.45593847547258, 68.49434811728341, 73.50208854675293, 70.3180765424456, 70.7547082901001, 67.74143436976841, 68.67863518851144, 71.1419175011771, 70.56969165802002, 70.67350469316754, 67.5559800011771, 65.40883377620152, 59.545992442539756, 62.49676731654576, 60.27649824959891, 59.83844212123326, 60.93416609082903, 66.16174057551792, 65.41773441859654, 64.0961731501988, 62.413340296064106, 64.16665567670549, 56.912743295942036, 54.02506848743984, 66.05815683092389, 63.24082905905587, 65.26679870060512, 65.62140696389335, 67.28572286878313, 65.73199449266706, 64.50472722734723, 65.12633391789028, 59.87355136871338, 56.07359198161534, 54.59225688661848, 55.790369510650635, 57.79463645390102, 64.8040417262486, 69.64411517551967, 73.9425904410226, 72.83744471413749, 73.22946902683803, 69.01758221217564, 62.82591043199812, 60.62392207554409, 63.94695363725935, 68.79484380994523, 72.06918934413365, 68.18716130937848, 51.61837230409895, 5.591487688677652, 0.22412604705563613, 0.6726226987583297, 0.9826613622052329, 1.770217742238726, 0.44410716795495575, 0.10556258341031415, 0.09524052550217935, 0.07107390370219946, 0.24574923462101392, 0.21503564555730137, 0.13193681889346667, 0.5389665535518101, 0.1701919175684452, 1.3583645735468184, 35.38413558687483, 79.3385545185634, 86.45312077658517, 82.10076917920793, 62.9874004636492, 56.858519554138184, 22.521397590637207, 43.89224992479597, 78.00117220197404, 34.79944814954485, 55.034551416124614, 76.13800580160958, 34.96960605893816, 0.23160585069230624, 0.10979544091969728, 0.10084737571222441, 0.03463551468615021, 0.0511504327878356, 0.07680907845497131, 0.05166416861382978, 0.05807642971298524, 0.01195370392607791, 0.04590249028322952, 0.009572119801305234, 0.005374978678966207, 0.12280141695269517, 0.13363269503627503, 0.1566252884055887, 0.08647390734404325, 0.10554813061441694, 0.179610811440008, 0.17939433162765844, 0.12109378858336381, 0.12649005545037134, 0.17058512861175196, 0.10502525152904646, 0.20976990168648108, 0.1808348207601479, 0.2302488349378109, 62.152866227286204, 94.69688047681535, 77.72854573386056, 86.21412358965192, 49.389959948403494, 54.859925815037315, 77.99071516309465, 88.82433945792062, 112.42504242488316, 59.283677101135254, 1.4161955160754067, 0.1499095151999167, 0.40669527117695126, 0.45286982346858295, 0.5734867783529418, 0.2223534828850201, 0.27101663021104677, 0.6673523815614837, 0.954024253146989, 0.9658264198473522, 1.6344115095479148, 1.5248590452330453, 3.0739418991974423, 2.3203830548695157, 5.169805858816419, 73.01811872209821, 103.04461996895927, 97.18273748670305, 95.33212648119245, 90.4669839314052, 85.13932064601353, 90.29944201878139, 90.69498211996896, 90.65977559770856, 91.44504710606166, 86.46324430193219, 81.48211547306606, 73.4535345349993, 68.00327723366874, 68.57465539659772, 65.27245453425816, 71.02197074890137, 74.28572028023856, 78.62612097603935, 76.17253834860665, 74.74774074554443, 75.5626254762922, 77.54985196249825, 79.17293725694928, 76.17262172698975, 76.2253029687064, 75.66034494127545, 70.05145331791469, 67.90938622610909, 66.95919227600098, 69.57628686087472, 67.52950736454555, 70.38514055524553, 71.1355390548706, 72.90108326503209, 73.46470723833356, 73.405807358878, 68.50395747593471, 70.22364357539585, 73.58320876530239, 73.05652141571045, 71.61586107526506, 69.48778765542167, 75.68874222891671, 63.78251756940569, 63.60439355032784, 69.73740863800049, 70.65541853223527, 72.23288890293666, 76.33766228812081, 72.31732341221401, 72.4863452911377, 71.11951650891984, 70.08179610116142, 74.24245384761265, 74.14691611698696, 72.76034750257219, 69.14718696049282, 66.4294546672276, 65.88445881434849, 69.74550328935895, 62.915771484375, 65.46672616686139, 63.63493088313511, 69.11767101287842, 69.37749195098877, 69.60200214385986, 70.36305223192487, 70.02735696520124, 62.308387756347656, 55.57232461656843, 69.5069716317313, 66.98976434980119, 67.31965092250279, 70.4587984085083, 70.27339962550572, 70.3532691683088, 69.20646204267229, 68.66264738355363, 63.26835782187325, 59.25845514025007, 58.201213768550325, 60.342096192496165, 62.743886947631836, 67.75326020377022, 73.46380397251674, 75.9675873347691, 75.07237448011125, 74.65627465929303, 72.80357224600655, 64.80347197396415, 64.59547764914376, 65.46913719177246, 71.51651573181152, 72.88169084276471, 74.55141939435686, 62.22529424939837, 5.303238196032388, 0.5036534198692867, 1.1610493042639323, 2.8868093235152106, 3.5935842096805573, 1.0272292792797089, 0.16381279272692545, 0.39076302466647966, 0.3887872392577784, 0.6344102120825222, 1.600321801645415, 0.5805744294609342, 0.8111446457249778, 0.30578058479087694, 3.598536321095058, 45.40823221206665, 87.6478704724993, 92.10388919285366, 91.50765037536621, 92.07586015973772, 121.45799936567033, 54.06501368113926, 67.46477099827358, 91.98301833016532, 39.75015776497977, 67.41727311270577, 86.72132819039481, 39.93565034866333, 0.44334441316979273, 0.4138478716569287, 0.23640179048691476, 0.1618505237357957, 0.1269664548869644, 0.22492970393172332, 0.1380003978099142, 0.12253114288406712, 0.08543531450309924, 0.15766973021839345, 0.11847522695149694, 0.10782564697521073], [0.045825500307338576, 0.006980543083045632, 0.03757065361631768, 0.05109403295708554, 0.07894228398799896, 0.11071119856621538, 0.05970161607755082, 0.08145519093211208, 0.01563101597795529, 0.09272509440779686, 0.052219620772770474, 0.02654614402646465, 0.04370060343561428, 0.2044994623533317, 42.303544316973, 67.93007101331438, 58.348553793770925, 45.59354414258684, 31.748376028878347, 51.22562885284424, 61.125832148960654, 89.29801900046212, 78.76154831477574, 10.390960642269679, 0.03348817303776741, 0.09641568030097655, 0.12409334762820176, 0.2053260537130492, 0.16106339597276279, 0.15646161218839033, 0.04269116385174649, 0.05105199432000518, 0.05365877319127321, 0.3324398456939629, 2.11818048783711, 1.5819370853049415, 0.2652140701455729, 0.2789191747350352, 32.867737770080566, 93.65852083478654, 82.37511880057198, 84.12732246943882, 81.61540971483502, 76.98078754970005, 69.08215182168144, 79.78102970123291, 82.43176746368408, 85.9395238331386, 82.56737545558384, 80.31514467511857, 73.25357927594865, 67.37701525006975, 57.71545478275844, 59.38601016998291, 58.31542478288923, 65.8897602898734, 71.24615437643868, 73.90786334446499, 73.3131878716605, 74.64635957990373, 72.34520653315953, 73.68291541508266, 66.8388981137957, 72.8970672062465, 71.2698199408395, 68.22076279776437, 68.03860882350376, 65.84820311410087, 62.41178389957973, 60.12065710340227, 60.9663154057094, 64.4591817855835, 60.83147866385323, 63.223180634634836, 61.31487873622349, 54.17780378886631, 53.84632955278669, 64.85269301278251, 63.19578388759068, 69.36083017076764, 67.57377433776855, 69.58217893327985, 66.92263780321393, 68.76196493421281, 69.51434367043632, 72.59172861916679, 67.35741438184465, 64.58694526127407, 69.0584306716919, 66.84809752873012, 70.17062187194824, 67.09644004276821, 60.98335933685303, 68.8542925970895, 67.73019218444824, 65.5541136605399, 66.2542210987636, 64.19729028429303, 56.46479640688215, 54.3252341406686, 59.03111703055245, 54.364640848977224, 50.70305831091744, 56.49655662264143, 62.90453624725342, 58.775847162519185, 53.6809971673148, 52.33169869014195, 49.85969638824463, 59.63792405809675, 64.54016998835972, 62.277009691510884, 59.688333238874165, 58.42471994672503, 59.74819891793387, 58.00033439908709, 57.002222197396414, 57.971235343388145, 57.47373390197754, 55.61763729367937, 56.489111627851216, 52.61776644842965, 56.227223600660054, 59.17463902064732, 64.46917329515729, 69.94605609348842, 71.01114545549665, 69.73765877314976, 65.47815595354352, 60.31361552647182, 60.10992213657924, 59.48268045697893, 61.43701417105538, 67.84621320452008, 65.47716236114502, 56.28673492159162, 30.265571389879497, 1.1757098947252547, 0.16380786656269006, 0.5247220950467246, 0.23456361197999545, 0.23635516156043324, 0.1046389751136303, 0.12391278945973941, 0.34391365572810173, 0.05421565366642816, 0.2734426643167223, 0.26860473677515984, 0.18016620592347213, 0.03142545032980187, 0.07711735726999384, 6.113472844873156, 50.09836006164551, 68.6882653917585, 78.37035778590611, 21.37255985396249, 48.60132203783308, 60.07115813664028, 50.205862590244834, 45.63897493907383, 36.650535106658936, 55.55769518443516, 59.653620038713726, 43.77054180417742, 0.14741750034902776, 0.07031595973031861, 0.052327507840735574, 0.047372560149856975, 0.14601955536220754, 0.0877306627641831, 0.0341828368338091, 0.05404310221118586, 0.03820679715967604, 0.053819290827959776, 0.06318669406963245, 0.05816579277494124, 0.024129740029041256, 0.018505546463919536, 0.03590307916913714, 0.03803600989548223, 0.12219397883330073, 0.09994405561259814, 0.038689266092010906, 0.09310071782342025, 0.03171370896909918, 0.022660803315894942, 0.019875037084732736, 0.016806954484699026, 0.03037942074505346, 0.23117587662168912, 54.28924594606672, 76.02850219181606, 67.36773940495083, 56.894733565194265, 41.47311994007656, 34.85965429033552, 49.94224793570382, 100.47141020638603, 92.2266013281686, 15.213647093091692, 0.019302607979625463, 0.19121229462325573, 0.24089670500585011, 0.1768524173114981, 0.06058790494820901, 0.13081283920577594, 0.17529078253677913, 0.04312338726595044, 0.054460832117391486, 0.8058345935174397, 3.780672924859183, 2.416629718882697, 1.9489436490195138, 0.08708398496466023, 38.95654147011893, 96.12683364323208, 91.46843474251884, 92.13969326019287, 86.45007746560233, 80.50282941545758, 73.05488858904157, 82.1428335734776, 84.17340292249406, 88.06228188105992, 85.96754591805595, 83.62919221605573, 78.97089059012276, 72.24108777727399, 61.63047981262207, 61.51406969342913, 62.249175207955496, 69.31373528071812, 75.36018971034459, 79.80772468021938, 77.51639638628278, 79.38264778682164, 76.95714977809361, 76.2537419455392, 71.44550514221191, 76.35195473262242, 76.41593374524797, 73.29162066323417, 70.79595974513462, 69.88345282418388, 67.69310964856828, 64.78732436043876, 66.57815306527274, 66.93787520272392, 64.55688040597099, 66.63108444213867, 62.86024842943464, 59.21698134286063, 60.15088871547154, 69.25762162889752, 67.10869666508266, 71.95628806522915, 70.88723823002407, 72.38515867505754, 69.03379235948834, 70.81984070369175, 72.66742924281529, 74.70772606985909, 70.45139162881034, 66.78199931553432, 70.77874905722481, 68.89538424355644, 72.3147942679269, 66.05702427455357, 60.62925134386335, 68.18894699641636, 71.48565183367047, 66.5319892338344, 66.77956744602749, 66.3099456514631, 61.82238210950579, 58.749965122767854, 62.79795088086809, 58.05576712744576, 53.46293837683541, 59.0250859941755, 61.37072835649763, 63.18003926958357, 59.478574071611675, 55.65597745350429, 53.620572158268516, 62.19324915749686, 68.50556945800781, 66.49546950204032, 63.03340448651995, 62.29560307094029, 62.61838163648333, 60.236594745091026, 61.718173027038574, 61.821034158979145, 58.263539109911235, 58.41931424822126, 60.23011902400425, 57.598481859479634, 59.68879181998116, 61.296452113560264, 67.11010714939663, 72.14628655569894, 73.70751203809465, 73.20714446476528, 68.55110795157296, 62.405148369925364, 64.32109328678676, 61.70230334145682, 63.975608008248464, 69.59423405783517, 72.47483212607247, 67.40134089333671, 36.824413776397705, 1.573830274598939, 0.14320919902196952, 0.9859866180590221, 0.24343917572072574, 0.32254628943545477, 0.23204725129263742, 0.2537635202918734, 0.1045911723215665, 0.14162612254066126, 0.8378788168941225, 0.2534771242312023, 0.2714105605014733, 0.15864809629108223, 0.21741936621921404, 7.925441009657724, 58.60130146571568, 75.61451462336949, 85.83046490805489, 30.15782914842878, 54.546186855861116, 42.85089560917446, 45.82563134602138, 62.245617730276926, 36.74357843399048, 64.91822147369385, 66.89045374734062, 50.95358255931309, 0.08788998278656177, 0.05633319182587521, 0.1041544603982142, 0.03550755771409188, 0.028216517430597117, 0.04878579253064735, 0.07232089500342097, 0.05761374346911907, 0.028039139895034686, 0.012113046000844665, 0.032532636275781054, 0.04151171053360615, 0.14919881762138434, 0.0990735087543726, 0.08493554632046393, 0.06068713390933616, 0.2087121063045093, 0.14924896135926247, 0.11848022096923419, 0.16242756348635468, 0.1773555510278259, 0.09886171083365168, 0.12198688994560923, 0.08837877227259533, 0.07766269586448159, 0.25913105798619135, 65.66429819379533, 86.7907406943185, 76.02859251839774, 62.22300134386335, 45.79174845559256, 67.896698815482, 82.06085872650146, 104.8065858568464, 103.70572022029332, 18.64355410848345, 0.12980948947370052, 0.20711396634578705, 0.2185449879616499, 1.1672794499567576, 0.7220946326851845, 0.4018138088285923, 0.292036559432745, 0.13359504991344043, 0.3305763985429491, 3.135619103908539, 7.572570664542062, 3.282972591263907, 4.873346635273524, 0.40835654203380856, 41.798886231013704, 101.04227420261928, 96.61627864837646, 96.33996963500977, 90.87816442762102, 84.95596463339669, 78.31353541782924, 85.96037537711007, 88.14901624407086, 92.12351090567452, 88.64194229670933, 88.3949477331979, 79.69130066462925, 76.03158719199044, 64.87800530024937, 65.88942677634103, 65.29586996350969, 74.46287155151367, 78.51565156664167, 82.61818763187954, 80.83370958055768, 81.04021004268101, 79.50794465201241, 81.30511706215995, 74.77884088243756, 81.01061766488212, 76.85449014391217, 75.48042133876255, 74.92257131849016, 74.13945375170026, 70.46917901720319, 68.91618020193917, 70.24120167323521, 73.73148332323346, 69.89170728410993, 73.82486016409737, 72.01601478031704, 67.05980913979667, 65.85948004041398, 71.51971885136196, 70.89757020132882, 74.98006071363176, 74.96322522844586, 75.29190976279122, 71.84183038984025, 71.94705390930176, 75.07061658586774, 78.25116838727678, 71.5847817829677, 69.42191178458077, 73.92057854788644, 72.85890769958496, 76.51934378487724, 69.55220440455845, 62.55381202697754, 71.43648638044084, 73.65574101039341, 70.12021963936942, 70.54155840192522, 68.0763166972569, 63.665725299290244, 62.87219933101109, 66.33555671146938, 63.708206585475374, 58.18842213494437, 61.76384353637695, 67.14289569854736, 70.14353084564209, 64.63791724613735, 61.22039713178362, 57.751686164310996, 64.859530040196, 76.21688175201416, 72.28243650708879, 66.92478479657854, 65.98440170288086, 66.03032234736851, 63.39616298675537, 65.88103335244315, 65.90369142804826, 62.635932786124094, 61.048227718898225, 63.8823492867606, 61.140444210597444, 62.82890510559082, 65.13549859183175, 71.17069693974086, 75.65824658530099, 75.95628956386021, 75.55423900059291, 71.52097647530692, 66.064542225429, 67.33967563084194, 65.32647677830288, 66.74324226379395, 73.97607381003243, 76.32120200565883, 78.66586467197963, 44.50344821384975, 1.5918698608875275, 0.8114852160215378, 2.2735391684940884, 0.5549072953207153, 0.6521442404815129, 0.43675312399864197, 1.3114495767014367, 0.9261151850223541, 0.31096223103148596, 3.472675783293588, 1.2172270097902842, 0.5391725567834718, 0.18021075853279658, 0.32808324375322884, 12.455825431006295, 69.06416293552944, 84.54704924992153, 91.99397563934326, 42.872122355869834, 75.3038328715733, 86.55329295567104, 62.43599837166922, 54.53959648949759, 53.9593037877764, 70.93288789476667, 78.44541222708565, 57.26115724018642, 0.19191959952669485, 0.20635540490703924, 0.13275279796549252, 0.18230623751878738, 0.21059691373791012, 0.15022535968039716, 0.1277804390660354, 0.21588711201080255, 0.17587662967188017, 0.09280016073690993, 0.19415314681828022, 0.22687916218170098], [0.08714016766420432, 0.07291980393763099, 0.05302575769435082, 0.021914228198251555, 0.08167065972728388, 0.01094184790937496, 0.009781731142928558, 0.008591340688456382, 0.0632857737530555, 0.023602087449814593, 0.04487894395632403, 0.06793958760265793, 0.11413223642323699, 0.11406356867934976, 34.91802263259888, 68.60541507175991, 55.2779746055603, 52.75289848872593, 53.58409758976528, 49.3577550479344, 59.38391181400844, 88.8940646307809, 47.20909064156668, 1.1273737741368157, 0.039906754690621576, 0.21049894685191767, 0.207291308258261, 0.31486538158995764, 0.272036929747888, 0.10402195607977253, 0.05341435469953077, 0.05443869151973298, 0.09687652771494218, 0.10596120916306973, 0.32769688591361046, 0.5074009959186826, 0.5897986516356468, 18.928449358258927, 94.61054910932268, 85.12583419254848, 80.02202102116176, 83.63251345498222, 82.85433605739048, 80.53738975524902, 69.03250694274902, 71.95004858289445, 81.41722624642509, 82.15973159245083, 79.80537618909563, 80.6275634765625, 77.78904369899205, 67.46522263118199, 59.94242191314697, 57.340359755924766, 60.16816193716866, 62.30903393881661, 72.88222585405622, 72.42175483703613, 77.05848230634416, 74.35073457445417, 77.18851089477539, 68.99717535291398, 68.47681086403983, 75.68610886165074, 72.13696207318986, 73.66681643894741, 68.3276538848877, 68.51109327588762, 66.16716017041887, 65.33972004481724, 64.74751813071114, 59.69205052512032, 61.61064965384347, 64.17978082384381, 54.576071058000835, 49.152703285217285, 64.52375834328788, 66.62733241489956, 69.16876111711774, 69.67547934395927, 68.92678315298897, 68.14266504560197, 68.92154421125139, 69.07839284624372, 67.21820722307477, 68.17506449563163, 63.99251992361886, 59.905096190316335, 62.362924167088096, 62.58815697261265, 63.64175401415144, 61.14386967250279, 60.05428096226284, 59.959514481680735, 69.44239507402692, 66.42183944157192, 68.38619940621513, 68.14816801888603, 69.39129802158901, 57.896708965301514, 56.694264139447895, 60.48463153839111, 55.01309885297503, 50.67933368682861, 52.40549898147583, 52.07426445824759, 55.20391723087856, 47.5912971496582, 54.80622666222708, 64.35700852530343, 61.327503613063264, 61.81394004821777, 57.520182609558105, 57.8933356148856, 53.214623655591694, 52.93647684369768, 54.60136597497122, 53.75382818494524, 57.51422105516706, 58.924385751996724, 59.53618853432791, 60.00732503618513, 58.917020661490305, 62.1211268561227, 65.96035398755754, 66.76603235517229, 73.01010744912284, 68.7937320981707, 68.58568913596017, 66.3107099533081, 60.66449955531529, 59.26590360913958, 61.861688068934846, 62.6560617174421, 66.36275890895298, 58.26698194231306, 52.101383277348106, 17.853602988379343, 0.1417797835809844, 0.09092441853135824, 0.17488105595111847, 0.11269371504230158, 0.054626696610025, 0.1279515791684389, 0.024140247143805027, 0.15968905043389114, 0.26930577201502665, 0.11076353397220373, 0.7015549976910863, 0.06496860166745526, 0.11943255843860762, 0.5480233132839203, 19.496263095310756, 69.90668065207345, 58.42925017220633, 65.47860758645194, 73.09765475136894, 60.18418448311942, 29.097184896469116, 17.255842515400477, 42.26449544089181, 46.51220369338989, 61.185739517211914, 42.9014333316258, 0.05448069283738732, 0.006983165620892707, 0.01893017198225217, 0.01339077833108604, 0.028651568639491285, 0.002882938170971881, 0.09711740086121218, 0.02251031612312155, 0.06709711173815386, 0.005610705561204148, 0.0807110144357596, 0.03383816818573645, 0.03814889098118458, 0.021818200226074884, 0.05604598152318171, 0.032698158108230145, 0.0678193104852523, 0.0350208784719663, 0.007058842631522566, 0.05354676402306982, 0.0384494989578213, 0.033217274716922214, 0.05198127856212003, 0.009900955682886499, 0.06727799560342516, 0.16511726272957666, 43.62840945380074, 75.83491843087333, 63.00591046469552, 46.364825453077046, 37.448309898376465, 39.349385670253206, 63.14078194754464, 99.45612553187779, 55.60392502376011, 1.6744914331606455, 0.07988124753215484, 0.31661491628204075, 0.8062033908707755, 0.09073470014014415, 0.32212763332894867, 0.17103714149977478, 0.059461964294314384, 0.0905479673030121, 0.020411612399454628, 0.12433876017374651, 0.43966376781463623, 1.1159210801124573, 0.16408453243119375, 23.20454273905073, 97.86040224347795, 90.73385729108537, 88.47654737745012, 88.75099427359444, 87.2718061719622, 84.54576383318219, 72.29082298278809, 75.8042699268886, 82.95438316890171, 84.46900013514927, 83.27428518022809, 84.54672268458775, 82.25234413146973, 71.95345320020402, 65.70199217115129, 60.585039956229075, 63.21984549931118, 65.03729275294712, 74.89606394086564, 76.19811466761998, 78.41480541229248, 77.80355848584855, 77.76974855150495, 73.22047805786133, 72.4807380948748, 77.21895790100098, 74.7126384462629, 76.67733887263707, 73.27163764408657, 71.87596688951764, 70.82115391322544, 70.3152972630092, 70.73145961761475, 61.13266222817557, 66.11489582061768, 65.73348835536412, 59.13467993055071, 55.067086356026785, 69.70789269038609, 72.1759067262922, 71.49672726222447, 71.14118099212646, 70.16107504708427, 70.76290716443742, 72.43141978127616, 71.38712637765067, 69.2710872377668, 70.44879300253731, 63.67291668483189, 60.68896416255406, 64.93142305101667, 62.571224212646484, 62.372290338788716, 62.850784982953755, 62.609272548130576, 61.584580012730186, 69.71034540448869, 67.36927495683942, 68.20660236903599, 68.04071412767682, 69.35862759181431, 62.41996887751988, 60.209566252572195, 64.34354291643415, 61.547337668282644, 54.30768299102783, 56.756502628326416, 55.60852473122733, 59.848885263715474, 51.515483379364014, 55.67839929035732, 67.25369167327881, 64.63581194196428, 64.03063079289028, 60.554099627903526, 60.92882292611258, 55.8754050391061, 55.725143296378, 56.4769001688276, 57.238999434879844, 59.85549300057547, 61.810208865574424, 63.57156331198556, 65.22587381090436, 63.78752722058977, 66.23102106366838, 68.95609065464565, 70.06949778965541, 75.31631878444126, 70.77623380933488, 71.38580621991838, 70.53776468549455, 63.55828530447823, 61.72766426631382, 64.0880298614502, 67.2982713154384, 70.84675107683454, 66.94527503422329, 65.07222134726388, 24.317063978740148, 0.44088247099093025, 0.08386152038084609, 0.3761892595461437, 0.30785063228436876, 0.17823407745787076, 0.19398641719349793, 0.029113267614905323, 0.02870810417724507, 0.1522431056946516, 0.09527329195822988, 0.8311809705836433, 0.7414638219135148, 0.16330058021204813, 0.5343526239906038, 24.147854498454503, 77.7107583454677, 71.02208192007882, 75.05392006465367, 82.7076804297311, 64.06945037841797, 33.28869785581316, 19.50858572551182, 40.67203780582973, 55.39780323845999, 68.30250140598842, 51.16229602268764, 0.03673527862078377, 0.009055437436992568, 0.04037974788142102, 0.033413873453225405, 0.10729982983320951, 0.05040267362658467, 0.13158911040851048, 0.013756377239977675, 0.05092723547880139, 0.026403163127335053, 0.013920429195942623, 0.04659567826560565, 0.20957170160753386, 0.17248869075306825, 0.18708549892263754, 0.1468333631221737, 0.2852104700037411, 0.10886965452560357, 0.10705566579209906, 0.14383688462632044, 0.1330068821885756, 0.08062324593109743, 0.20503832772374153, 0.1391248253307172, 0.20556997348155293, 0.30137062285627636, 54.62746688297817, 86.84454754420689, 73.14327662331718, 65.89323438916887, 68.39555862971714, 67.57785293034145, 78.53150040762765, 102.31657382420131, 67.05744675227574, 2.1312452725001743, 0.23475490457245282, 0.6176720016769001, 0.8167517877050808, 0.9436939103262765, 0.6280469106776374, 0.8109114468097687, 0.2281693693782602, 0.46693327597209383, 0.436442463525704, 0.4750722763793809, 0.9125445932149887, 2.870094129017421, 0.940978793161256, 23.51052577154977, 100.5337563923427, 94.20368344443185, 91.75131675175258, 90.74661418369838, 91.10233415876115, 88.00992720467704, 75.08996037074498, 77.49134813036237, 87.18831661769322, 89.4389145714896, 87.12558828081403, 88.1578265598842, 87.5222748347691, 75.00902080535889, 68.82029506138393, 62.97239235469273, 65.45292704445976, 69.15776906694684, 77.19232545580182, 80.31679834638322, 80.18837479182652, 82.16964667184013, 79.34391157967704, 79.90948104858398, 75.95401750292096, 75.37284932817731, 77.07311521257672, 79.82606792449951, 76.90180042811802, 75.46580232892717, 71.70893914358956, 72.5073983328683, 72.21890912737165, 67.40077114105225, 73.04709271022251, 72.74345643179757, 67.68770395006452, 63.958577973502024, 72.18838569096157, 75.75859941755022, 76.47103296007428, 75.10709462847028, 75.02527959006173, 72.41407012939453, 76.25346401759556, 76.32149382999965, 71.54608031681606, 73.73977252415249, 66.43526336124965, 65.40144784109933, 65.85950088500977, 66.17944458552769, 66.01647458757672, 65.44382490430559, 61.91865634918213, 62.759749685014995, 73.0996766771589, 71.77390480041504, 71.00667081560407, 71.07238687787736, 71.88183116912842, 65.20988600594657, 63.29519871303013, 67.5642830984933, 63.57359218597412, 57.80303335189819, 59.56731646401541, 61.02217197418213, 62.5510744367327, 54.00711781638009, 58.62616906847273, 71.13863795144218, 69.89323588779995, 68.23873778751918, 63.118346214294434, 64.87503147125244, 60.28336306980678, 60.82224450792585, 60.92295169830322, 58.81709861755371, 64.0739667075021, 65.18371909005302, 66.54660129547119, 68.07512160709926, 64.9922684260777, 69.51874188014439, 71.35232285090855, 75.70220783778599, 78.1397957120623, 72.64547988346645, 73.83631774357387, 73.61400318145752, 65.68874890463692, 64.7629987171718, 66.20025444030762, 69.3574116570609, 74.2764583315168, 69.79932403564453, 76.79310975755963, 28.849467720304215, 0.5491494642836707, 0.5050880057471139, 0.6566669749362128, 0.6584167810423034, 0.6891316728932517, 0.3503923352275576, 0.1113287332866873, 0.5449236567531313, 1.2057116734130042, 0.6054526716470718, 1.0989412026745933, 0.5354033761790821, 0.19332427558090004, 1.4429755019290107, 34.50696720395769, 85.54358073643276, 81.85474736349923, 86.18366963522774, 84.63028172084263, 86.62615871429443, 41.704706873212544, 26.230886220932007, 59.318869726998464, 63.33252443586077, 78.17550250462124, 58.34838703700474, 0.15996670696352208, 0.08018156713140862, 0.13168783725372382, 0.12347330232816082, 0.12141531918730054, 0.1737465046878372, 0.21335543000272342, 0.10273749607482127, 0.16549960364188465, 0.1182505911482232, 0.19844479938702925, 0.2003212065568992], [0.026229515838037645, 0.03255166918305414, 0.02126979804597795, 0.03476063654358898, 0.044575330069554706, 0.01935637679084071, 0.03888357137995107, 0.033184803423604796, 0.06942012387194804, 0.05537006225703018, 0.02702975968298103, 0.0342272673068302, 0.03391658987051674, 0.0541150269231626, 32.22982713154384, 67.10209587642125, 63.432842527117046, 70.20480700901577, 57.57792908804757, 47.554218087877544, 66.11052540370396, 84.11068153381348, 18.35216576712472, 0.11435759147363049, 0.03127420148147004, 0.24118011551243917, 0.2517980214740549, 0.18233641875641687, 0.04729313084057399, 0.37398600205779076, 0.5022154684577669, 0.20563811196812562, 0.35051799991301125, 0.12067321900810514, 0.30719123195324627, 0.35875850915908813, 6.939227598054068, 86.9044132232666, 78.96576976776123, 67.54317447117397, 78.05912017822266, 91.35089901515416, 83.55324840545654, 85.19157109941754, 69.7593718937465, 69.71322195870536, 75.72549819946289, 80.36598464420864, 81.0172392981393, 80.1318164552961, 77.63627365657261, 74.0886207308088, 64.64468479156494, 59.71119976043701, 55.58969511304583, 63.84543350764683, 67.71073028019497, 75.90776334490094, 72.9953008379255, 77.51017774854387, 70.98685455322266, 84.85618155343192, 87.94491985866001, 71.16365146636963, 72.84560189928327, 73.68708433423723, 74.6290933064052, 69.93810040610177, 66.74827970777238, 68.35220881870815, 64.25117356436593, 56.30164922986712, 63.1905379976545, 60.567162241254536, 47.46884904588972, 57.72559220450265, 68.28968892778668, 65.22165625435966, 67.82754339490617, 66.9141332081386, 70.5498753956386, 70.17206709725517, 67.21092551095145, 66.07963371276855, 68.73490170070103, 66.07873044695172, 59.159304346357075, 58.87747846330915, 66.72271728515625, 64.40147699628557, 63.298485210963655, 63.120326450892854, 68.96109335763114, 65.41457993643624, 62.35580226353237, 59.25773252759661, 62.919488770621165, 62.71052169799805, 69.28012684413365, 62.33643763405936, 56.60027585710798, 61.06932939801897, 62.23557758331299, 55.578574521201, 59.27376202174595, 52.47305631637573, 49.9070587839399, 46.93733964647566, 55.641170842306956, 64.2355123247419, 58.89143739427839, 60.78359167916434, 55.87331015723092, 56.147072655814036, 55.69375133514404, 55.77314840044294, 52.013822078704834, 51.47503791536604, 56.3610771724156, 58.70257840837751, 62.90071473802839, 61.63592720031738, 64.36883435930524, 65.74667603628976, 68.31856564113072, 68.54443073272705, 63.313979693821494, 67.18480723244804, 69.62901673998151, 66.7405116217477, 64.84800992693219, 62.83041286468506, 61.23423099517822, 63.71381378173828, 63.08930969238281, 66.47922461373466, 59.960021700177876, 49.699064459119526, 6.209711475031717, 0.2289815486541816, 0.3143053730683667, 0.1953766540225063, 0.3178502842783928, 0.17936378398111888, 0.33653062475579126, 0.23086972162127495, 0.3362715058028698, 0.06551966709750039, 0.4221693979842322, 0.28824989976627485, 0.12247561157814094, 0.01602952807609524, 3.0897920429706573, 53.653808866228374, 65.46319648197719, 96.51022829328264, 90.62226922171456, 86.04765169961112, 34.63116972787039, 24.867371729442052, 56.775710923331125, 54.04403706959316, 58.12639209202358, 34.18628699438912, 0.034814827742853334, 0.03268039066876684, 0.03429016750305891, 0.05700430367141962, 0.056440033949911594, 0.051918446219393184, 0.04822408767150981, 0.0038890980982354707, 0.043438519284661324, 0.019344999454915524, 0.04358456037672503, 0.012140680187647896, 0.024278824350663593, 0.010461249189185244, 0.05232678180826562, 0.046081416574972014, 0.017754728806072047, 0.04373222995283348, 0.011209414623278593, 0.10765345514352832, 0.04258479670222316, 0.021046995983592102, 0.05000465516267078, 0.09742952696979046, 0.04621901669140373, 0.04282466900934066, 38.80401461465018, 77.31218882969448, 73.00573703220913, 77.09603037152971, 51.51314531053816, 42.34692192077637, 74.02787263052804, 95.36087812696184, 23.262327432632446, 0.07324584679944174, 0.0980995667300054, 0.638623805982726, 0.8817501227770532, 0.1979466054056372, 0.08886679501405784, 0.333446384540626, 0.25204416683741976, 0.07755881215312652, 0.5803073580775941, 0.4611711565937315, 0.62506993327822, 0.1245795451104641, 8.952198897089277, 90.42419692448208, 83.4290771484375, 77.26456587655204, 82.7216602052961, 94.52554484776088, 87.08863776070731, 87.00120857783726, 72.12657451629639, 72.64873858860561, 79.92386381966728, 85.75117206573486, 82.46484783717564, 83.84373869214738, 80.5736871446882, 77.43524142674038, 67.22039590563092, 62.43371936253139, 57.77665451594761, 64.35777977534703, 70.22827107565743, 78.96354634421212, 76.06755801609584, 79.755140713283, 73.44328594207764, 85.77025876726422, 87.9542304447719, 71.9914390019008, 75.20006847381592, 74.93120792933873, 78.01303277696881, 73.37324115208217, 73.49843379429409, 72.70132950374058, 67.95880876268659, 61.08977099827358, 67.00085367475236, 63.287757192339214, 57.275178704942974, 65.03134509495327, 71.88132395063127, 67.65089934212821, 69.99759783063615, 71.0691351209368, 72.87818895067487, 70.83523791176933, 69.28604670933315, 68.8276115145002, 71.21399116516113, 67.180680002485, 59.871084758213584, 63.67100593021938, 69.3888383592878, 67.94878251211983, 67.93071024758476, 63.89267430986677, 70.2528190612793, 67.82427774156842, 62.28871045793806, 62.58864334651402, 63.090393611363, 61.804268155779155, 68.76511246817452, 65.06502996172223, 61.22787339346749, 63.22552912575858, 63.41224806649344, 59.277263913835796, 61.585163661411826, 55.47514363697597, 52.039961201804026, 50.554050718035015, 59.06712259565081, 67.83796569279262, 63.12230668749128, 62.67699663979666, 57.89626775469099, 59.361601148332866, 60.12612533569336, 57.654394013541086, 54.8269670350211, 55.983661447252544, 61.038090297154014, 62.74416487557547, 64.75840595790318, 66.76646314348493, 69.34152807508195, 67.58669103894914, 69.51944364820207, 70.55351625170026, 64.46052973611015, 68.17143753596714, 72.90347344534737, 72.5859477179391, 69.50485937935966, 65.70240211486816, 63.258310726710725, 67.8607279913766, 67.52171843392509, 73.2389463697161, 67.91743918827602, 60.259363991873606, 8.28492864540645, 0.26482890652758734, 0.25522196346095627, 0.7415142506361008, 0.831162840127945, 1.0618332624435425, 0.7575461332287107, 0.20461775814848288, 0.642884897334235, 0.1722441195909466, 0.6234794471945081, 0.5557948734079088, 0.2898150900644915, 0.18219934111194952, 4.091148836272104, 59.82598400115967, 73.34496893201555, 100.11012472425188, 97.22614288330078, 96.59900542667934, 49.17563581466675, 23.5667245388031, 53.77974149159023, 58.498266628810335, 67.14666162218366, 39.59145743506295, 0.0839115691238216, 0.043814936586256535, 0.01079126656986773, 0.04662768815511039, 0.030322552725140537, 0.03628331323021224, 0.0405562721591975, 0.028198144398629665, 0.028564627947551862, 0.060901347414723465, 0.0496079937687942, 0.019381105999595354, 0.20082315962229455, 0.09568533234830413, 0.12542259772973402, 0.12485815158912114, 0.07787099932985646, 0.19962384897683347, 0.1563546886401517, 0.16213991892124924, 0.2349222313080515, 0.15744548796543054, 0.14159518134381088, 0.21224092266389302, 0.13962381998343126, 0.12126153601067406, 48.0665157181876, 89.47897788456508, 78.18638338361467, 86.98333781106132, 70.73170975276402, 71.27221706935337, 84.23308794839042, 107.05377224513462, 29.66458695275443, 0.179313721667443, 0.18734020739793777, 0.5102681592106819, 3.4215014321463446, 0.5791883181248392, 0.5112177825399807, 1.675938938345228, 1.3845686188765933, 0.4213167780211994, 0.8588604224579675, 0.7807869889906475, 2.129504097359521, 0.48378097478832516, 9.254427296774727, 95.5033300944737, 88.93571213313511, 82.4046972819737, 87.64293725149972, 100.91200242723737, 90.22950145176479, 90.16013063703264, 77.64151954650879, 75.80714648110526, 83.48271724155971, 90.3505390712193, 85.3682359967913, 87.80966622488839, 87.66673483167375, 80.92879567827497, 70.1105477469308, 67.55053956168038, 62.48209272112165, 69.66972623552594, 74.05553340911865, 83.38113457815987, 79.55028002602714, 85.05280862535749, 75.88591820853097, 88.28457559858049, 86.33714144570487, 75.4926015308925, 78.85022817339215, 83.14005293164934, 80.02716963631767, 76.51700224195207, 74.83931800297329, 74.5553103855678, 73.55843148912702, 66.09582996368408, 72.89648355756486, 72.99771881103516, 64.92176505497524, 69.35626520429338, 77.68809332166398, 71.36930424826485, 73.95659106118339, 72.53913075583321, 75.35401276179722, 74.66118008749825, 72.19174861907959, 71.00545488085065, 74.08698790413993, 69.4025193623134, 62.33526338849749, 63.68458271026611, 72.32441752297538, 69.11062553950718, 69.21566840580532, 66.75961916787284, 74.00243527548653, 70.17866093771798, 64.06088324955532, 63.328286034720286, 65.69116687774658, 64.72747952597481, 71.52328327723912, 69.57846164703369, 66.62674181801933, 66.00149427141461, 65.26484625680106, 63.02653271811349, 63.75380761282784, 57.47550221851894, 53.149838651929585, 53.67249257223946, 61.441148349217, 73.20576872144426, 65.57128960745675, 68.17604419163295, 61.429044587271555, 63.262521335056846, 63.379084314618794, 60.14700467245919, 58.40177699497768, 60.29607827322823, 62.36587020329067, 64.37972218649728, 69.63135133470807, 68.09529917580741, 74.17099857330322, 71.80023847307477, 73.62728118896484, 72.90278557368687, 65.36991691589355, 73.12029893057687, 75.89606257847377, 74.46444184439522, 69.73900672367641, 66.77844183785575, 66.24988542284284, 69.45415837424142, 70.72642912183488, 77.684237071446, 74.05237892695835, 71.40406608581543, 9.747042417526245, 0.538372808269092, 0.7724247234208244, 1.2111488559416361, 1.0152505849088942, 2.4444594255515506, 1.1780292902673994, 0.35166485980153084, 1.8937951454094477, 0.3524648797299181, 2.696968687432153, 0.752153462597302, 0.2281781089093004, 0.1535994429141283, 8.903565849576678, 70.98961993626186, 80.95690808977399, 98.21958242143903, 96.70580618722099, 99.3854762486049, 49.245211601257324, 36.98386798586164, 73.87906306130546, 69.31334618159703, 77.43612384796143, 48.447120666503906, 0.20980967740927423, 0.2558089776762894, 0.0828782349292721, 0.15700566156634263, 0.13175478151866368, 0.15002611465752125, 0.12533688518617833, 0.11040604101227862, 0.1166656283395631, 0.14243769113506588, 0.15390040033629962, 0.09981291514954396], [0.030692710541188717, 0.062268269780491076, 0.03911128433953438, 0.04984273635117071, 0.04317560392831053, 0.02901060865925891, 0.038808393092559915, 0.011821980771076466, 0.08934529112385851, 0.04503901715257338, 0.06298352032899857, 0.015117622812145522, 0.0330280652269721, 0.10073524780039277, 21.979622227805002, 67.09064524514335, 47.74160058157784, 48.83752257483346, 39.79482078552246, 45.30755281448364, 72.82772418430874, 56.42006390435355, 2.5465241202286313, 0.09306295734963246, 0.13721217082015105, 0.544866008417947, 0.791614942252636, 0.26123144956571714, 0.10983523699854102, 0.2630921554352556, 0.34523785752909525, 0.2951112730162484, 0.38685957555259975, 0.08607031471495118, 0.07661823369562626, 1.836807974747249, 62.114741461617605, 78.7992422921317, 59.27216393607003, 79.18589564732143, 82.07619340079171, 82.43091283525739, 86.84424182346889, 85.46712970733643, 70.72324684688023, 66.08471284593854, 76.12396349225725, 80.40122590746198, 81.41703864506313, 78.82156685420445, 77.79353918348039, 72.14890602656773, 64.5909126826695, 56.71957295281546, 56.46209355763027, 55.04098197392055, 59.18255301884243, 66.57007231031145, 68.51112106868199, 75.4250511441912, 73.59627832685197, 78.7517374583653, 80.57699448721749, 71.49410779135567, 73.7418291909354, 67.62809535435268, 69.96765804290771, 71.21472072601318, 71.64041600908551, 68.85097830636161, 60.81192643301827, 57.82515294211251, 64.23895168304443, 51.697904859270366, 51.44011626924787, 63.85126304626465, 63.4215794972011, 67.5040978022984, 66.55890655517578, 70.18722806658063, 64.44216564723423, 68.40840584891183, 66.17901379721505, 64.09766006469727, 67.64053262983049, 56.60975667408535, 63.73850073133196, 67.447845186506, 63.42231600625174, 65.00776985713414, 65.80450589316231, 63.64716666085379, 59.97177110399519, 62.76409230913435, 62.46587562561035, 65.02979564666748, 63.65676212310791, 64.33623341151646, 64.53098446982247, 63.33779117039272, 56.89714111600603, 63.40780816759382, 61.55511270250593, 62.78108760288784, 59.116454805646626, 57.98388106482369, 54.972229548863, 53.318804945264546, 59.362261227199006, 59.22426305498396, 60.399592535836355, 58.38983998979841, 57.17867170061384, 59.20279312133789, 59.53839806147984, 59.607657705034526, 53.60195098604475, 52.72398356028965, 57.626316343035015, 62.65423434121268, 63.082813126700266, 64.946535382952, 64.01842280796596, 66.18857451847622, 66.99104281834194, 63.98763534000942, 61.978299685886924, 63.44117341722761, 69.52863611493791, 68.59584740230015, 69.04888384682792, 66.92477090018136, 62.73508358001709, 65.08795901707241, 62.082550457545686, 60.96866389683315, 64.78876263754708, 64.21667575836182, 32.06826761790684, 1.083158695272037, 0.11903936096600123, 0.5824616253376007, 1.524726920894214, 1.3398983244385039, 0.05940951353737286, 1.3001891523599625, 0.1898802760988474, 0.16348204761743546, 0.9358503712075097, 0.9637291495289121, 0.11743164009281568, 0.044820997065731456, 0.21603515478117125, 17.32439170564924, 71.77291120801652, 83.94781575884137, 102.25752803257534, 72.98432268415178, 25.17449947765895, 43.11659819739205, 56.511998994009836, 50.23531600407192, 58.78135708400181, 27.357482773917063, 0.16178604933832372, 0.0993560439507876, 0.011957532559920634, 0.03087303800774472, 0.01505728917462485, 0.05051793637020247, 0.012492705003491469, 0.06230818799563816, 0.016740627686626146, 0.037365966742592197, 0.033869234911565266, 0.039599578495004346, 0.05284885682963899, 0.037915366369166544, 0.021759104914963245, 0.05686646267505629, 0.042047983900244744, 0.013293463686880256, 0.0604543217590877, 0.012013853510974773, 0.010336536997263985, 0.023669823904388716, 0.014468203731147307, 0.01824783207848668, 0.0045231610835929, 0.1047128200797098, 27.78241549219404, 76.69766930171421, 56.13141141619001, 53.69733238220215, 43.27084820611136, 41.966754708971294, 82.53683117457798, 66.56242929186139, 2.624700039625168, 0.08419527140046869, 0.18232325517705508, 1.876432248524257, 0.3481371019567762, 0.27771211521966116, 0.015261039670024599, 0.4559679329395294, 0.49679381081036156, 1.0239691627877099, 1.4606513934476035, 0.43330888024398256, 0.15031213073858193, 2.4048698927674974, 67.71383612496513, 81.72418376377651, 69.90655558449882, 85.4907396861485, 86.21176815032959, 87.463486126491, 87.82819707053048, 88.66025774819511, 74.09300504411969, 67.1638514654977, 80.03434712546212, 83.24433149610246, 83.42513751983643, 82.89457307543073, 80.87947736467633, 76.58653286525181, 69.18048272814069, 60.29468863351004, 59.31873771122524, 56.98045001711164, 62.707193510872976, 68.25104999542236, 71.788225037711, 74.5732089451381, 75.64888041360038, 78.43511499677385, 81.08859729766846, 76.03686782291958, 75.23775550297329, 72.87472874777657, 72.21610205514091, 73.28891086578369, 71.19844804491315, 68.11168302808488, 65.97401414598737, 63.518027441842214, 67.16950729915074, 56.19094010761806, 60.32596942356655, 67.72158336639404, 69.40622275216239, 69.29326588766915, 70.89603464944022, 71.6673333304269, 66.63246713365827, 68.86141450064522, 67.25822189876011, 69.15141146523612, 67.17788682665143, 56.94141503742763, 66.80374022892543, 67.95355592455182, 64.71247836521694, 66.41651712145124, 63.962788581848145, 65.49082946777344, 62.89259229387556, 64.23142678397042, 65.61254106249127, 68.91397762298584, 65.53648608071464, 66.01664134434291, 66.32175064086914, 65.4192977632795, 60.85959802355085, 65.37325205121721, 64.07787159511021, 61.773105485098704, 62.15820939200265, 61.3246340070452, 57.23952749797276, 55.56738792146955, 63.306128229413716, 62.532585280282156, 65.05204377855573, 60.04158660343715, 60.37406485421317, 61.006225858415874, 64.22436046600342, 63.61314133235386, 57.563984053475515, 55.380272933415, 62.11560998644148, 64.08557019914899, 66.71182945796421, 65.93690381731305, 67.34864575522286, 69.38424560001918, 69.81558976854596, 63.22684233529227, 65.08883449009487, 66.4732700075422, 71.7350435256958, 70.60957431793213, 72.30475412096295, 68.5538524900164, 66.58150209699357, 68.6098688670567, 66.51960059574672, 67.3928918838501, 72.64965575081962, 70.00160694122314, 41.0586633682251, 1.8347013677869524, 0.07129591357495103, 0.7988573536276817, 3.144648070846285, 1.926165065595082, 1.1876946687698364, 2.0368186022554124, 0.5885639350329126, 0.17821123796914304, 0.5116622501185962, 1.102196216583252, 0.9651674266372408, 0.05532091935830457, 0.12729067248957499, 21.224603176116943, 79.47583702632359, 92.13287707737514, 100.46625464303153, 85.9841729572841, 34.52698843819754, 30.205393041883195, 58.80614825657436, 55.23836292539324, 67.80505902426583, 32.30280406134469, 0.09303819760680199, 0.09616218640335969, 0.011657522542269101, 0.015779374267107675, 0.017028798116371036, 0.059660306865615506, 0.00725441805220076, 0.009946368335347091, 0.05286658355700118, 0.016213317767583897, 0.02546465420164168, 0.02093213696831039, 0.16068155717636856, 0.21904700888054712, 0.10961068940481969, 0.11622224641697747, 0.06881397496908903, 0.07764640423868384, 0.16928189354283468, 0.1019107350813491, 0.2679431379905769, 0.10105289718402283, 0.1020551205479673, 0.13943053249801907, 0.12552402514432157, 0.1833336345319237, 34.25284031459263, 89.87591457366943, 60.64741393498012, 61.104438645499094, 47.1346789087568, 67.40088926042829, 90.51708044324602, 77.15530545370919, 4.215363953794752, 0.17011993857366697, 0.29110028967261314, 1.8603886408465249, 1.5989167456115996, 0.932548348392759, 0.2313189118036202, 0.773722299507686, 0.9919234194925853, 1.7838877801384245, 3.8643995864050726, 1.270038855927331, 0.2580192376460348, 2.8899455666542053, 71.61884185246059, 87.98166888100761, 76.15388243538993, 89.10261481148856, 89.10337216513497, 88.65836783817836, 92.44853373936245, 94.13434737069267, 79.23111452375139, 71.35992418016706, 83.86383288247245, 88.62401594434465, 88.30450998033795, 87.24923147474016, 84.94802979060582, 78.34216894422258, 73.09177657536098, 65.61090823582241, 62.642227854047505, 59.85549994877407, 66.79775782993862, 73.34956863948277, 75.50332260131836, 81.83902359008789, 81.66960566384452, 83.55425589425224, 88.4475108555385, 80.50009877341134, 80.80256080627441, 72.40405777522496, 75.43313189915249, 77.20553398132324, 77.97048200879777, 75.60653114318848, 70.41395473480225, 70.1898683820452, 76.59548214503697, 67.48706776755196, 66.65905094146729, 74.15025125231061, 72.19592448643276, 73.87214265550885, 72.35693509238106, 75.12389537266323, 69.02687890189034, 72.30071026938302, 71.0578373500279, 72.0412506375994, 69.67568778991699, 57.92251457486834, 68.26304953438895, 73.63179751804897, 67.64512538909912, 72.02529062543596, 71.08213520050049, 67.90182658604213, 64.95905603681291, 67.6546722139631, 66.82545334952218, 71.14002064296177, 67.35696274893624, 67.18161106109619, 68.145263671875, 68.10111481802804, 66.03533199855259, 69.68030834197998, 68.93551703861782, 66.39569337027413, 67.07535920824323, 65.32127257755825, 58.5620094026838, 56.9567288671221, 66.69852365766252, 69.16186155591691, 70.4569501876831, 64.65199429648263, 65.36244065420968, 64.02979006086076, 67.59795406886509, 66.04036944253104, 60.76834038325718, 59.60350963047573, 65.54771436963762, 68.38275309971401, 70.79655729021344, 70.6687729699271, 72.1389353615897, 71.48896612439836, 73.04516111101422, 67.5805835723877, 64.43978241511753, 67.36208357129777, 73.15803459712437, 73.65261432102749, 75.85447066170829, 69.776520047869, 67.65911211286272, 70.68692861284528, 70.25099168504987, 70.76137161254883, 76.67510155269078, 75.66691098894391, 47.13358456747872, 2.4388874045440128, 0.39789754897356033, 1.5128882761512483, 7.485260469572885, 4.257908642292023, 3.7184952327183316, 4.384436641420637, 1.3546554297208786, 0.32379406105194775, 2.6760170459747314, 5.207677015236445, 0.704225765807288, 0.13302293632711681, 0.4697998964360782, 30.363805021558488, 88.47050244467599, 95.15913023267473, 106.63300323486328, 82.53933252607072, 38.06528214045933, 56.99334587369646, 71.24670328412736, 63.25642776489258, 77.99907384599958, 40.29341309411185, 0.20841155600334915, 0.22015502942459925, 0.16046414098569325, 0.10436068076108183, 0.09833374952099153, 0.18543600743370398, 0.16770317325634615, 0.09471673717988388, 0.4245485317494188, 0.14965682875897202, 0.1280053462833166, 0.10827567854097911], [0.022072009642475417, 0.023355305959869708, 0.043212536589375565, 0.1203666026038783, 0.061513555635299, 0.011679238207372171, 0.038653792281235964, 0.06277439583625112, 0.06274169044835226, 0.016645507255036916, 0.039686546328344514, 0.09051988952394042, 0.06693327267255102, 0.2237300540187529, 13.429376619202749, 61.6505948475429, 47.40603038242885, 71.30064214978898, 46.55684586933681, 62.585141454424175, 82.62114061628068, 30.03446388244629, 0.08636288544429199, 0.11994113400578499, 0.1812008089785065, 1.1676756058420454, 0.5756234579852649, 0.10020852820681674, 0.07488681588854108, 0.13489991346640245, 1.2920991693224226, 0.0679021528256791, 0.036790870994861634, 0.35507113273654667, 0.25672261150819914, 37.71137564522879, 72.70349039350236, 61.352906227111816, 81.25861276899064, 85.9946369443621, 89.17163126809257, 84.1210412979126, 83.58682904924665, 80.08212988717216, 73.23760536738804, 66.00860922677177, 73.60992458888462, 76.92183903285435, 78.41591712406704, 79.96185656956264, 78.15267072405133, 72.01429857526506, 66.81871359688895, 59.734045437404085, 54.21934706824166, 58.05451645169939, 56.12795121329171, 55.97028269086565, 59.43170152391706, 64.39054053170341, 67.86898245130266, 69.05833339691162, 67.3660579408918, 66.69787747519356, 67.16794395446777, 68.61384323665074, 64.36913313184465, 68.48984568459647, 56.68179907117571, 47.19299513953072, 53.18580947603498, 59.651236806597026, 57.473560197012766, 43.57729503086635, 60.03137275150844, 64.88231318337577, 64.35106086730957, 68.67844063895089, 67.2960478918893, 63.65005711146763, 66.5954818725586, 67.47030871255058, 65.2116230555943, 71.72631658826555, 60.59070273808071, 60.85927145821707, 66.05343205588204, 57.538147177015034, 61.04512882232666, 57.72479316166469, 57.87732696533203, 58.72176933288574, 65.03766795567104, 61.43213653564453, 60.766311509268625, 66.51206180027553, 65.5895494733538, 63.277862957545686, 61.329511642456055, 65.45102323804582, 58.45235293252127, 57.18380641937256, 63.519493511744905, 61.18922751290457, 58.40388229915074, 56.97535003934588, 59.15250205993652, 53.244994231632774, 57.94591958182198, 60.04226057870047, 58.54831450326102, 56.04183176585606, 56.425448758261545, 60.913196427481516, 61.54508645193917, 61.24917657034737, 59.816986083984375, 55.482022353581016, 55.79486152103969, 61.28990691048758, 62.883302552359446, 61.29313087463379, 62.806434631347656, 63.62427234649658, 63.94329193660191, 66.2496005467006, 68.23479815891811, 68.01955686296735, 67.26189749581474, 67.26830373491559, 67.58697591509137, 67.49332114628383, 66.21492208753313, 66.75596441541398, 63.4253454208374, 63.16097341264997, 60.28253623417446, 59.120783533368794, 57.45552962166922, 21.50494040761675, 0.16017969910587582, 0.1281338201037475, 0.4193891685988222, 0.1988327314278909, 0.1418640712010009, 0.09081336270485606, 0.4065147808619908, 0.12463008239865303, 0.2824631359960352, 0.8240374081901142, 1.9585126212665012, 0.09133805347872631, 0.12707174995115825, 3.1529483454568044, 41.518512521471294, 69.68909781319755, 67.58393260410854, 30.006438323429652, 38.377996240343364, 46.60170691353934, 45.69333764484951, 45.51630449295044, 56.495028018951416, 16.781329189028057, 0.13899036683142185, 0.060761711693235805, 0.02914943013872419, 0.02483044787576156, 0.03751217746841056, 0.0769741999517594, 0.03364168140771134, 0.05281766118215663, 0.018594091891178062, 0.03230620574738298, 0.025501870151076998, 0.054004398573722155, 0.019122633351279155, 0.049550535423415046, 0.04261409245165331, 0.09663130515920264, 0.0073581669047208765, 0.06348860822618008, 0.03767494105600885, 0.023406715165557604, 0.06288437279207365, 0.07629578706941434, 0.07451922632753849, 0.060528594202228954, 0.06327695958316326, 0.2662828985069479, 17.29452313695635, 72.70931298392159, 49.283739362444194, 72.67031274523053, 39.01317276273455, 55.601715496608186, 95.60927622658866, 35.29104362215315, 0.09539428153740508, 0.08616271761379071, 0.4834926245468003, 1.8447949290275574, 1.0733012642179216, 0.08285527330424104, 0.12989626053188527, 0.033294220588036945, 1.9639934471675327, 0.4488210321537086, 0.07977766237620797, 1.5344578730208533, 0.4073260373302868, 42.5460329736982, 78.81177684238979, 73.9456615447998, 86.69234030587333, 86.60276412963867, 89.26115185873849, 86.54176589420864, 85.77501133510044, 82.93320505959647, 75.67977210453579, 69.86264296940395, 74.34595421382359, 79.93828133174351, 81.30756977626255, 83.56729766300747, 80.1046976361956, 76.34148379734584, 70.86155768803188, 63.714056968688965, 57.980858598436626, 58.93165356772286, 58.01010356630598, 59.19245420183454, 62.97021756853376, 65.9894391468593, 70.14724118368966, 72.41779436383928, 69.64268384660993, 69.53629302978516, 71.97716045379639, 72.82362474714006, 69.84245150429862, 72.10877323150635, 60.93610463823591, 52.97403185708182, 55.25470508847918, 64.88999094281877, 60.43950298854283, 51.46319818496704, 65.69636413029262, 66.85283620016915, 68.86447170802525, 70.97076947348458, 66.97067764827183, 66.7800955091204, 70.14563614981515, 68.42615849631173, 68.21122986929757, 74.10651234218052, 59.81191389901297, 65.89224079677037, 65.51423100062779, 60.36221817561558, 63.45436109815325, 60.429546219961985, 61.111546652657644, 62.52269104548863, 67.64985711233956, 63.99677916935512, 62.690684591020855, 65.55862998962402, 65.48629229409354, 65.36199596949986, 65.62272712162563, 67.2427899496896, 62.643325669424875, 58.37882014683315, 65.39725112915039, 64.40592384338379, 61.545989717756, 61.521740504673545, 62.76550279344831, 56.77327905382429, 61.14737851279122, 63.94723156520298, 61.447644914899556, 59.66479969024658, 59.03304168156215, 63.067117146083284, 63.71278544834682, 65.08544376918248, 65.01364803314209, 59.93530695778983, 60.090321268354145, 63.05006626674107, 65.48611858912876, 66.62811061314174, 63.61041069030762, 66.88540935516357, 66.61582619803292, 69.60728972298759, 69.88850416455949, 70.28767817361015, 68.41666030883789, 69.88468265533447, 71.54970032828194, 69.84078393663678, 68.2938370023455, 70.87340436662946, 68.1778507232666, 68.4231012889317, 66.91199316297258, 67.44063990456718, 65.87939357757568, 26.616643258503505, 0.5028954148292542, 0.0806723650810974, 0.35787391662597656, 0.2869208667959486, 0.40431830872382435, 0.3276791625789234, 0.2791206453527723, 0.23704661588583673, 0.5201538716043744, 1.3283709372792925, 2.9863724495683397, 0.5826782137155533, 0.17107922424163136, 3.069105952978134, 48.62688446044922, 76.1343857901437, 74.84097167423793, 36.59927477155413, 32.27290596280779, 46.2100647517613, 53.017822878701345, 51.87220389502389, 66.17844404493059, 23.08761497906276, 0.1383429765701294, 0.044142061711422036, 0.020293391243155514, 0.04863941217107432, 0.021936119434290698, 0.03464617107861808, 0.08796770218759775, 0.01897290102871401, 0.014260141145704048, 0.05584244476631284, 0.033065635710954666, 0.07197304402611085, 0.14048615656793118, 0.12724563133503708, 0.15140755767268793, 0.3287258706986904, 0.14443278765039785, 0.15016628642167362, 0.1938959549048117, 0.10862531406538826, 0.21285602822899818, 0.23024785784738405, 0.22822376074535505, 0.22797240423304693, 0.23283698463014194, 0.42730406246015, 23.44188278062003, 83.34205790928432, 61.7048533303397, 81.72491332462856, 58.6940529687064, 82.65358870370048, 99.9437153679984, 45.41597945349557, 0.1983609731708254, 0.3544869140854904, 0.3695834497255938, 4.684878919805799, 2.444228615079607, 0.5777956385697637, 0.6707264919366155, 0.28577704674431254, 3.7020796792847768, 1.0513323630605425, 0.5924408669982637, 2.947542441742761, 0.6525383879031453, 45.73286247253418, 83.12131364004952, 79.9735642841884, 89.60527529035295, 91.09735230037144, 92.43694414411272, 89.1486952645438, 88.80385616847447, 87.42769595554897, 79.49385370526994, 73.95313780648368, 78.74761717660087, 82.75560910361153, 83.90104743412563, 87.05922603607178, 83.12559373038155, 79.75675964355469, 73.80789961133684, 67.86768313816616, 60.62142072405134, 65.06691292354039, 62.70432390485491, 61.6568968636649, 66.9051491873605, 71.54767840249198, 74.3416393824986, 76.34977994646344, 73.13471644265312, 71.72350256783622, 75.18090534210205, 75.73918615068708, 72.0776800428118, 74.0547204698835, 64.02289744785854, 58.62327861785889, 60.47044331686837, 69.28575488499233, 71.23017351967948, 59.29414108821324, 70.35185868399483, 70.46305070604596, 72.14404923575265, 74.70848342350551, 70.83154147011894, 67.20540864127022, 72.94136892046247, 71.92844663347516, 69.82362188611711, 77.39441381181989, 62.25456701006208, 65.36047431400844, 71.37761429377964, 62.17594814300537, 66.48384516579765, 65.26775755201066, 64.98972538539341, 65.2446756362915, 71.39768763950893, 67.75807530539376, 66.18810204097203, 70.88145732879639, 69.85994012015206, 68.35158348083496, 66.05584308079311, 69.81408200945172, 62.84080042157854, 62.144625663757324, 67.39579623086112, 67.54070786067417, 64.94481917790004, 65.84880760737828, 65.98819541931152, 58.35466820853097, 64.976211139134, 69.27511719294957, 66.35979897635323, 64.51917253221784, 61.89301054818289, 67.20010716574532, 66.21977887834821, 68.1070694242205, 68.33672823224748, 62.26182092939104, 63.64842428479876, 68.22356292179653, 68.50938401903424, 70.48197065080915, 68.3705312183925, 70.6066004889352, 70.49796540396554, 71.89864580971854, 74.72380420139858, 71.9879926953997, 71.08460181100028, 71.0834275654384, 75.17284543173653, 72.43476881299699, 72.1483154296875, 73.47626904078892, 69.96348912375313, 71.4419754573277, 69.4122120993478, 70.66403429848808, 73.19907760620117, 30.39224747249058, 0.797579862177372, 0.34118681347795893, 1.2761234151465553, 0.7853387647441455, 0.8363725234355245, 0.5831388575690133, 0.8828087459717477, 0.65066069151674, 0.9241400510072708, 4.560587806361062, 3.3215120775359015, 0.38712178862520624, 0.15907458269170352, 6.2275257876941135, 61.64771829332624, 79.23123264312744, 80.94088554382324, 42.91936315808977, 54.79803821018764, 59.52448081970215, 62.53703212738037, 58.73470687866211, 77.083982195173, 31.732853753226145, 0.2578930029911654, 0.2672222895281655, 0.10058343237532036, 0.2975982395665986, 0.11992221644946507, 0.28404841093080385, 0.09262408768492085, 0.15503124679837907, 0.07952571553843361, 0.12311879492231778, 0.16097790056041308, 0.15353992182229245], [0.02887319853263242, 0.10738138974245105, 0.02258294990419277, 0.023973619299275533, 0.015092606922345502, 0.07116927858442068, 0.05520616890862584, 0.042305145279637406, 0.028459139500877688, 0.028068349131249955, 0.06058743675904615, 0.14710507568504128, 0.10872661255832229, 0.37922241964510506, 15.008758613041469, 58.99636908939907, 55.821049281529014, 35.04948949813843, 39.23887457166399, 70.40024593898228, 64.32877104622978, 6.697704306670597, 0.2872745192476681, 0.17469500164900506, 0.23857736374650682, 1.275230354496411, 0.23366270746503556, 0.05113204448883023, 0.21675506686525686, 0.028265692559736114, 0.03869145776012114, 0.1864145499254976, 0.06977438021983419, 0.20449726389987127, 23.36763780457633, 71.88966873713902, 72.95552934919084, 86.69555037362235, 81.12759753635952, 85.02246584211076, 82.89029993329729, 84.51269040788922, 81.30342864990234, 75.86226654052734, 71.01219463348389, 67.65084375653947, 73.69516508919853, 75.57989174979073, 76.80435889107841, 76.54769938332694, 76.0334701538086, 74.0593410219465, 67.72847597939628, 58.538587025233674, 56.969732420785085, 55.319222586495535, 57.38747896466936, 54.51877621241978, 53.00213732038225, 57.273309639522004, 60.0879727772304, 61.65973172869001, 62.38301835741316, 60.31631142752511, 62.83754171643938, 66.16972405569894, 68.68493025643485, 69.07293851034981, 60.747704233442036, 45.99218314034598, 55.462935652051655, 61.30221217019217, 44.35035160609654, 50.73772634778704, 66.440676007952, 64.06193937574113, 69.32649217333112, 65.43250628880092, 66.66481794629777, 65.90542152949742, 65.3838758468628, 60.58641569955008, 69.9825827734811, 58.71768379211426, 62.07647773197719, 63.1711733681815, 55.532073702131, 61.38427734375, 63.03526660374233, 63.960558210100444, 65.19842842647007, 64.56674684797014, 62.36158316476004, 61.112491607666016, 59.93923963819231, 60.36205836704799, 60.91377312796456, 61.44503934042794, 66.62209347316197, 63.02633816855294, 63.379855564662385, 55.01498876299177, 59.62854398999895, 62.35549654279436, 58.753661564418245, 58.45619528634207, 58.40219388689314, 56.697668756757466, 61.238476344517295, 59.937648500714985, 58.48923397064209, 56.50537388665335, 56.308302130017964, 57.987528869083945, 61.05504390171596, 63.835094588143484, 62.38191359383719, 61.24310384477888, 59.11295986175537, 59.883751324244905, 63.328987802777974, 63.2435735974993, 57.83009311131069, 62.6117183140346, 62.501603262765066, 60.946339334760395, 63.79412800925118, 62.9498940876552, 65.24351528712681, 67.89623328617641, 67.00955281938825, 69.55214187077114, 67.51967566353935, 64.9629122870309, 69.25115980420793, 69.15753977639335, 65.44790349687848, 60.26887607574463, 50.63117224829537, 58.66644082750593, 17.058968782424927, 0.2922273634799889, 0.24752018387828553, 0.36424158779638155, 0.0890671256929636, 0.09051974703158651, 0.016593767263527428, 0.039043193350413015, 0.10938605360154595, 0.7648966759443283, 2.1073988378047943, 0.6196796510900769, 0.06961373705416918, 0.12308632023632526, 13.064820272581917, 58.341306822640554, 57.1332791192191, 35.18802962984358, 45.10232039860317, 31.891272681100027, 50.41114364351545, 43.85475744519915, 59.84864207676479, 7.179853269032069, 0.07244495156088046, 0.04141525338803019, 0.07016493140586785, 0.002306773094460368, 0.024251940793224742, 0.022579295993117348, 0.03510793451485889, 0.049291810020804405, 0.03582007737298097, 0.006540318468718657, 0.024138340460402623, 0.08194675562637192, 0.028121524224323884, 0.06427048412816865, 0.032248991674610546, 0.015979246934875846, 0.04274242038705519, 0.04291640694386192, 0.05896709513451372, 0.03205675252580217, 0.04472303696508918, 0.009445360978133976, 0.048795234345431836, 0.17847339675894805, 0.12543941182749613, 0.5108616330793926, 19.058712448392594, 69.62009525299072, 58.101854528699604, 41.14375448226929, 32.92999015535627, 76.960540499006, 77.0588436126709, 8.545051830155508, 0.2419047909123557, 0.11693941721958773, 2.0556139137063707, 1.1781884474413735, 0.5449273479836327, 0.03193188511899539, 0.48886439629963463, 0.33711940316217287, 0.312597039022616, 0.3507292685764176, 0.07504347605364663, 0.10775995121470519, 29.696211678641184, 78.56102330344063, 80.2767002923148, 89.70160511561802, 86.04035609109062, 89.26090172358921, 87.17350305829729, 86.80861840929303, 83.22389684404645, 81.5849974496024, 74.32476915631975, 71.17464351654053, 77.89464936937604, 79.66361904144287, 77.49177197047642, 79.41159398215157, 78.8883112498692, 77.69272777012416, 70.7369556427002, 64.64553247179303, 59.60489232199532, 57.825225898197715, 58.90452780042376, 58.21327584130423, 56.152902194431846, 59.18075343540737, 62.10315186636788, 63.9505250113351, 62.10449981689453, 63.425748416355674, 66.1167162486485, 68.20239870888847, 70.19288390023368, 71.84090627942766, 65.45578970227922, 51.29687915529524, 61.20263058798653, 63.49525819505964, 51.66532128197806, 60.42901120867048, 69.79953942980084, 67.47471387045724, 71.38053948538644, 66.72764355795724, 69.18691676003593, 68.34565666743687, 69.5781420298985, 64.6514870779855, 73.53289685930524, 60.82029206412179, 66.4360693522862, 64.39217335837228, 58.20952033996582, 66.55186108180455, 64.06394045693534, 67.83503355298723, 68.29437896183559, 65.22056538718087, 63.41609736851284, 62.81855923788888, 62.22345297677176, 63.5221894127982, 61.11320032392229, 62.46367999485561, 66.84287248338971, 65.81902068001884, 64.28888143811906, 61.137553759983604, 61.54541996547154, 64.8397137778146, 61.47930090767996, 61.148205348423545, 61.043419565473286, 59.618135588509695, 65.07803698948452, 62.642783709934776, 63.33750629425049, 60.06751728057861, 59.169886452811106, 60.9135924748012, 63.41038594927107, 64.22855022975376, 65.77422564370292, 66.03490121023995, 62.44013254983084, 63.03296675000872, 66.13615036010742, 65.8557905469622, 61.47403417314802, 64.80425712040493, 65.01952620915004, 64.80995464324951, 65.2034797668457, 66.15696021488735, 67.60030950818742, 70.64551734924316, 69.66071442195347, 70.42846257346017, 70.81956277574811, 69.16637788500104, 71.27937371390206, 72.27579402923584, 67.77304867335728, 66.44012015206474, 60.92998327527727, 65.47272941044399, 22.028341259275162, 0.22776015847921371, 0.20298193235482487, 0.3399995671851294, 0.1386045789612191, 0.15335062412278994, 0.08873074874281883, 0.10889541171491146, 0.03563203835593803, 0.7564540175454957, 0.6991837620735168, 1.9533131974084037, 0.1358731905264514, 0.1574568466416427, 17.556729044233048, 66.97340134211949, 66.15373625074113, 38.13151931762695, 30.10568639210292, 32.29267706189837, 57.07331963947841, 51.80795737675258, 67.4769720349993, 9.768172757966177, 0.10605104041418859, 0.09629435145429202, 0.03855385425101433, 0.05206106070961271, 0.047424943053296635, 0.058924550988844464, 0.05085364496335387, 0.019663605572921888, 0.03295073598357184, 0.015109049522184899, 0.09008325902479035, 0.050066262749688964, 0.19607678002544812, 0.21675147062965802, 0.10575439847473588, 0.11681591027549335, 0.12456984205969743, 0.09563370940408536, 0.14270655385085515, 0.14075709560087749, 0.3320639915764332, 0.162300297458257, 0.3012688968862806, 0.32294502375381334, 0.29049096522586687, 0.8669751584529877, 24.555145740509033, 78.60752064841134, 70.38612719944545, 42.75437123434884, 59.63945266178676, 91.9050873347691, 83.65872900826591, 11.58311344896044, 0.5747610671179635, 0.46982307519231525, 2.180578133889607, 6.374670394829341, 0.7693796211055347, 0.15803852757172926, 0.8977666976196426, 0.9296719027417046, 0.5936793291143009, 0.888778551348618, 0.3426653141421931, 0.5669368526765278, 32.854796750204905, 83.51951490129743, 84.47736576625279, 95.97757244110107, 88.13881628853935, 92.72801807948521, 89.100891658238, 91.13564382280622, 86.4775367464338, 85.09359455108643, 78.2395509992327, 74.62807192121232, 81.05307810647147, 83.11731147766113, 79.81628486088344, 84.06369086674282, 80.96830313546317, 82.85150119236538, 75.17344297681535, 67.19771698543003, 62.28034482683454, 62.32347924368722, 63.50855009896414, 62.321137700762065, 59.271802629743306, 63.77747317722866, 66.75620760236467, 68.84782382420131, 68.04695361001151, 68.56126621791294, 68.05301938738141, 72.99619020734514, 75.46323149544853, 76.34130314418248, 66.99217537471226, 54.40241125651768, 63.8838848386492, 72.14552920205253, 62.08491979326521, 64.13288048335484, 73.39050047738212, 69.60346126556396, 76.18637916019985, 69.20669133322579, 70.8035888671875, 70.70035253252301, 73.79172420501709, 67.12832532610211, 74.22811276572091, 62.502450942993164, 65.74651622772217, 68.46482522147042, 60.58638095855713, 68.79692826952252, 67.88289274488176, 69.00231007167271, 71.2002615247454, 69.86030837467739, 65.81936808994838, 65.40380328042167, 64.80097757066999, 65.22500528608049, 66.1131031853812, 65.47320883614677, 70.2850934437343, 67.789870262146, 68.23666722433907, 63.59307493482317, 65.78735773903983, 67.79328877585274, 64.28481674194336, 64.58262348175049, 64.5310400554112, 62.52777712685721, 68.7392999104091, 67.1051252910069, 67.15315123966762, 64.11125074114118, 63.3046760559082, 65.07486861092704, 67.82612596239362, 70.23886707850865, 66.93171215057373, 68.7263137272426, 64.54083701542446, 68.01482513972691, 71.60455635615757, 69.39732210976737, 63.72868292672293, 67.45694732666016, 67.12530285971505, 69.21455669403076, 69.59253174918038, 69.52477291652134, 69.33807482038225, 73.95083795275006, 71.61844580514091, 73.73124013628278, 71.67576149531773, 71.8241194316319, 73.04540429796491, 74.98156152452741, 69.16308443886894, 68.67309052603585, 63.35137489863804, 73.90575109209333, 25.282922642571585, 0.386360228061676, 0.5473077573946544, 0.86333267390728, 0.35564932599663734, 0.3901580428438527, 0.14199406493987354, 0.318752328732184, 0.2820832378097943, 2.313920578786305, 5.169994762965611, 1.777672290802002, 0.20766940154135227, 0.5291337126067707, 25.28929761477879, 79.71989250183105, 73.11397606985909, 52.07485505512783, 58.82472773960659, 41.38679552078247, 64.0604385648455, 57.773673738752095, 80.43886429922921, 14.6772027356284, 0.20040952467492648, 0.17282946461013385, 0.219215543408479, 0.16059408044176443, 0.18519341759383678, 0.15102495891707285, 0.26717981323599815, 0.1472230457833835, 0.11835759612066404, 0.13232209107705525, 0.1773528775998524, 0.1452665850520134], [0.02370731296416904, 0.010558919216107045, 0.07686987519264221, 0.05803505264754806, 0.03203119889699987, 0.030672907496669462, 0.07431543512003762, 0.07542901286589247, 0.05383586743846536, 0.06579298100301198, 0.06620612740516663, 0.08190041846994843, 0.15638025583965437, 0.5837225605334554, 19.7892929485866, 63.11458723885672, 37.120737075805664, 44.34818376813616, 40.461931228637695, 79.6451507295881, 44.585892064230784, 0.5791402778455189, 0.03695088990830949, 0.006079956207291356, 1.147069962961333, 0.5997380497200149, 0.3614841029047966, 0.09340979730976479, 0.11962903503860746, 0.4850188397935459, 0.8084071097629411, 0.3525748566857406, 0.592332409960883, 36.582439286368235, 80.2603372846331, 84.55648490360805, 85.94870240347726, 84.36848054613385, 83.6734869820731, 84.36146981375558, 80.28160572052002, 82.5835508619036, 76.4379803793771, 73.85892023359025, 67.5319183894566, 67.50682844434465, 70.65503638131278, 77.6162975856236, 76.91851084572929, 74.6282525743757, 72.05876704624721, 74.81272724696568, 66.3430677141462, 59.66260405949184, 53.83468784604754, 57.08456877299717, 56.339534282684326, 53.96559190750122, 56.47079965046474, 55.829574721200125, 55.617133549281526, 57.61621366228376, 57.81482444490705, 60.17173331124442, 61.1178834097726, 64.8079674584525, 64.33758136204311, 64.4255038670131, 60.04280253819057, 55.90697070530483, 63.50459657396589, 52.24492611203875, 45.73796592439924, 62.966729572841096, 64.7267986025129, 66.6427504675729, 66.8773147038051, 65.0304765701294, 64.13572924477714, 63.22673116411482, 62.93727615901402, 69.48479298182896, 60.76172569819859, 63.08654430934361, 67.54110390799386, 55.32168572289603, 61.08910397120884, 63.29343387058803, 66.08030768803188, 59.789082118443076, 67.84616456712995, 65.00648444039481, 60.76722867148263, 61.10732214791434, 62.36828122820173, 63.88359301430838, 62.82994038718087, 59.119129862104145, 58.27990559169224, 60.78951154436384, 63.24935449872698, 61.594168526785715, 59.62257548740932, 58.19428641455514, 61.13715076446533, 59.85296385628836, 59.81239332471575, 57.54718678338187, 58.89129843030657, 63.12484972817557, 60.18325342450823, 57.52941676548549, 53.57601683480399, 53.63492366245815, 57.996738706316265, 60.931074142456055, 63.57869216373989, 63.25257846287319, 62.44332177298409, 62.82113701956612, 63.22129767281668, 61.568203108651296, 62.883740288870676, 64.66916329520089, 59.544707025800435, 58.8653747013637, 60.96985898699079, 62.45101342882429, 64.47045871189663, 65.37911633082798, 66.03562382289341, 64.32804843357631, 65.11987904139927, 64.94960648672921, 66.78833607264927, 63.31863498687744, 63.515873500279014, 64.0432209287371, 55.26710762296404, 42.621615477970664, 53.89299018042428, 16.91516191618783, 0.39808672453675953, 0.32463834860495155, 0.3110117098050458, 0.10441761663449661, 0.4835554840309279, 0.015027564251795411, 0.10677616364721741, 0.6097060548407691, 3.3130906437124525, 1.7181825744254249, 0.4508297400815146, 0.11591389296310288, 4.0352566582815985, 35.683133942740305, 67.16060665675572, 38.83170666013445, 32.19787584032331, 53.77486385617937, 55.039053848811555, 40.94299670628139, 51.08809273583548, 1.8611260184219904, 0.11344754030661923, 0.07646533261452403, 0.03434899648917573, 0.022240707018811787, 0.012233033044529813, 0.043542294430413415, 0.05775534015681062, 0.02701040107889899, 0.0503628470136651, 0.02908324244033013, 0.021462434137772237, 0.1093315536688481, 0.011188017869634288, 0.07517762242683343, 0.04511862288096121, 0.10363108598228012, 0.02872063671903951, 0.02828963127519403, 0.08460089963461671, 0.03987393395176955, 0.055043361216251335, 0.04948091773050172, 0.008756874395268304, 0.024847579188644886, 0.06776660867035389, 0.4725280414734568, 26.531150885990687, 71.33511911119733, 43.07171630859375, 37.91995709283011, 38.36921371732439, 88.68488216400146, 51.97243513379778, 0.8866825838174138, 0.014733290399557777, 0.1693847594516618, 0.6603246043835367, 0.590785295835563, 1.045171047960009, 0.009254165925085545, 0.1287371055888278, 0.6074807313936097, 1.634877581681524, 0.34076400473713875, 1.879819278206144, 45.92044298989432, 87.144529070173, 90.26841831207275, 87.0930985042027, 86.34015001569475, 87.35537215641567, 88.75718511853898, 84.75664860861642, 85.55567060198102, 79.99591663905552, 76.29372882843018, 69.608811378479, 70.96704523903983, 72.86146463666643, 79.33591420309884, 79.7026401247297, 78.4200929914202, 75.11204174586705, 76.40859644753593, 69.46107183183942, 64.18711812155587, 56.606675148010254, 59.34939316340855, 59.45192773001534, 58.06814881733486, 59.4093839100429, 59.36981391906738, 58.85880865369524, 58.89044380187988, 61.91049916403634, 62.01295730045864, 64.4536440713065, 67.18862874167306, 68.17966420309884, 68.93493338993618, 63.1110714503697, 60.94038472856794, 65.90400409698486, 55.96939679554531, 54.38357469013759, 68.10940401894706, 68.19080911363874, 69.19196115221295, 67.13468987601144, 70.55781718662807, 68.57061849321637, 67.09181949070522, 65.30396461486816, 71.01244476863316, 63.07596220288958, 68.20871462140764, 66.84321294512067, 57.83642986842564, 66.42976038796562, 66.17132908957345, 67.36241708483014, 61.66691616603306, 68.90392357962472, 66.48657580784389, 63.6115779876709, 62.46317277635847, 62.9352125440325, 66.23696177346366, 66.4066298348563, 62.476624488830566, 59.85065010615757, 62.68302072797503, 62.73110226222447, 64.2418907710484, 62.831204959324424, 61.39032922472273, 62.695881843566895, 62.35482256753104, 62.64264474596296, 59.77020386287144, 61.85164097377232, 65.92723887307304, 61.811522075108115, 62.18089526040213, 57.47101368222918, 58.67911434173584, 60.692264556884766, 63.55597850254604, 65.22943128858293, 66.75300448281425, 65.82362038748605, 67.4008128302438, 67.62088312421525, 63.135334559849326, 66.00199454171317, 65.64548942020961, 62.681999342782156, 61.475222315107075, 60.948576654706685, 63.53839956011091, 67.71466296059745, 68.99395833696637, 70.57002517155239, 68.38376058850969, 65.86272484915597, 67.65435954502651, 68.57232080187116, 66.54039655412946, 65.90402494158063, 67.27926104409354, 61.97640282767159, 51.73132916859218, 60.03773035321917, 22.16459890774318, 0.4065769889525005, 0.2976062734212194, 0.34281258338264053, 0.2667456051068646, 1.1134405732154846, 0.06288486812263727, 0.02590097257468317, 0.5789264578904424, 1.7047780879906245, 2.2148616313934326, 1.6524276456662585, 0.2727710503552641, 4.348559617996216, 43.1453081539699, 77.89302349090576, 42.750733852386475, 33.32105214255196, 59.653626986912315, 55.55227558953421, 47.52037341254098, 58.38947173527309, 2.948969428028379, 0.12768164436732019, 0.05388763626771314, 0.026538961733292257, 0.06386518837617976, 0.02023201435804367, 0.047754195385745594, 0.035866682550736835, 0.05522975139319897, 0.028510769230446646, 0.05405618097367031, 0.05625956059832658, 0.03655075780781252, 0.11569726387304918, 0.19304564196084226, 0.1748237061713423, 0.1807581191616399, 0.1522700163934912, 0.1582048772169011, 0.16637746510761126, 0.1490098320479904, 0.10546372085809708, 0.20490228145250253, 0.12594891020229884, 0.12479283580822603, 0.22260683429028305, 0.6391152824674333, 33.178054741450715, 82.68052686963762, 49.10907902036394, 52.84322507040841, 57.54830196925572, 97.24645246778215, 63.00251279558454, 1.4739197386162621, 0.07955457363277674, 0.26168259392891613, 4.229559123516083, 3.533119899885995, 1.385331617934363, 0.3478676149887698, 0.274917908012867, 1.1402521516595567, 3.1792411974498203, 0.9142564556428364, 2.4460655450820923, 46.38749047688076, 88.6488835471017, 91.19281360081264, 90.56734371185303, 90.79004737309047, 91.52340194157192, 90.30351366315568, 87.78059496198381, 89.38293293544224, 84.51908275059291, 81.4119873046875, 73.30182756696428, 73.07801219395229, 76.13833931514195, 82.30936799730573, 82.30547700609479, 79.9650318963187, 77.42383248465401, 81.90453815460205, 73.02023097446987, 68.33378219604492, 61.13024425506592, 62.499157496861045, 62.94839327675955, 59.11402988433838, 62.04100717817034, 61.84869493756975, 60.73293931143624, 63.11851991925921, 66.17909022739956, 65.82036168234688, 68.67283344268799, 70.69363362448556, 71.46048545837402, 72.74511010306222, 69.11960261208671, 66.79624312264579, 75.49757644108364, 70.7740034375872, 60.630231039864675, 72.73722389766148, 72.35134179251534, 72.24021230425153, 71.11070619310651, 71.74723066602434, 71.22888115474156, 68.85115895952497, 66.71931266784668, 73.87975093296596, 65.76100322178432, 66.39096164703369, 74.52463408878872, 63.38524736676897, 66.96099185943604, 68.01052420479911, 71.76173850468227, 62.30902699061802, 72.40628119877407, 69.03676618848527, 66.29652173178536, 64.78747027260917, 64.03420911516461, 68.98058305467877, 69.31927299499512, 64.41486617497036, 62.098510469709126, 64.66086714608329, 66.3790385382516, 66.86918531145368, 65.25366660526821, 65.08308832986015, 66.95113236563546, 66.29279054914201, 66.16650009155273, 63.31233991895403, 66.34700734274728, 70.62298434121269, 66.72524642944336, 65.92501544952393, 60.97918346949986, 63.68800122397286, 64.46607439858573, 67.14139488765171, 69.35921124049595, 69.47741399492536, 68.26140975952148, 67.80314132145473, 70.7488648550851, 67.45285483769008, 68.68469401768276, 69.69476754324776, 65.32360717228481, 65.43988527570451, 67.198974609375, 68.21772643498012, 71.03532518659318, 69.58839062282017, 70.80546488080705, 69.19334384373256, 68.89575249808175, 69.33943666730607, 70.30090754372733, 66.13412843431745, 66.78349317823137, 69.26968370165143, 64.0688111441476, 54.32500485011509, 67.03444821493966, 26.731783594403947, 0.5149040190236909, 0.8004107645579747, 1.852526102747236, 1.0640448523419244, 1.4704217548881258, 0.22610578153814587, 0.47587164491415024, 2.6635927983692715, 11.359716704913549, 4.9171337485313416, 1.1550648425306593, 0.3978455460497311, 7.126934051513672, 51.45126117978777, 82.15919658115932, 53.81429835728237, 47.3036139351981, 64.83730275290353, 66.39457471030099, 54.58566999435425, 71.40455940791539, 4.819295729909625, 0.23075770906039647, 0.21584543638995715, 0.17744708540184156, 0.1477119709764208, 0.062044807842799594, 0.1095900008721011, 0.20034985430538654, 0.11113989699099745, 0.14621582840170178, 0.12945488707295486, 0.12315254525414535, 0.28015329422695295], [0.052633527134146006, 0.007676170822898192, 0.08350277213113648, 0.021040191973692605, 0.0272811433366899, 0.04239718855491706, 0.021039036767823354, 0.017363707734537975, 0.019946758236203874, 0.0421468566304871, 0.07880171867353575, 0.07955595784421478, 0.03101069579965302, 0.03820469709379332, 33.822121483939036, 58.91861179896763, 47.73138325554984, 36.01454564503261, 48.5461186000279, 84.93088163648332, 17.778232404163905, 0.08822479232081346, 0.10871033450322491, 0.3477141303675515, 1.9381398516041892, 0.6436655383024896, 0.4423198795744351, 0.15440117275076254, 0.1593604494950601, 0.22153192625514098, 0.5402122895632471, 4.795939360346113, 65.85319886888776, 95.01007747650146, 85.27239254542759, 81.43354061671666, 85.11399446214948, 82.05382020132882, 78.56275340488979, 77.32723862784249, 77.90427262442452, 74.9337648664202, 71.08041899544853, 67.73694583347866, 65.46881757463727, 67.01109531947544, 71.54391942705426, 76.94530309949602, 79.19126660483224, 78.31006131853376, 77.5933963230678, 73.11162063053676, 67.58729553222656, 57.4671504838126, 55.898938587733674, 58.321636472429546, 61.327649525233674, 62.81192370823452, 61.671328272138325, 58.23170246396746, 57.126195430755615, 58.07531935828072, 60.26304653712681, 58.31429917471749, 63.1229042325701, 61.341664041791645, 65.39987060001918, 59.34740597861153, 57.70409795216152, 58.24331637791225, 55.34601136616298, 45.24382046290806, 57.07307645252773, 64.03762762887138, 66.59903240203857, 68.79613617488316, 66.36737946101597, 69.87996482849121, 62.43035643441336, 64.68690204620361, 64.55451801845005, 60.1298634665353, 66.5778751373291, 70.00381646837506, 52.842408657073975, 64.53222124917167, 66.3779685156686, 63.14187281472342, 58.95063604627337, 58.80248655591692, 61.902842249189106, 64.57258333478654, 61.048887797764365, 59.82565743582589, 62.467404229300364, 62.645750590733115, 62.368857928684776, 65.41164084843227, 62.47786126817976, 60.1072609765189, 58.68752861022949, 59.509326798575266, 65.30115754263741, 61.56017793927874, 60.99308681488037, 57.63733966009957, 61.13867241995675, 58.92744295937674, 59.67338766370501, 60.2426118850708, 59.79434190477644, 58.210632051740376, 54.343956061771934, 54.33480181012835, 53.42829813276018, 57.518209321158274, 62.14142254420689, 61.651074273245676, 61.29927308218819, 62.349743434361045, 65.0761331830706, 62.98696272713797, 64.18920952933175, 62.90091623578753, 59.11596148354666, 53.894147055489675, 51.30241686957223, 55.77991941996983, 61.175483976091655, 62.83358819144112, 67.66180801391602, 67.47763906206403, 62.5976482118879, 56.71868358339582, 59.70199339730399, 62.21854060036795, 64.01586587088448, 61.32915728432791, 60.562708445957725, 61.689275469098774, 43.72076838357108, 60.92951774597168, 22.537463562829153, 0.087494261163686, 0.07384698811386313, 0.26551251698817524, 1.3849304680313383, 0.3915408429290567, 0.10448978561908007, 0.4288836105593613, 0.39659155905246735, 3.068178368466241, 0.7843845816595214, 0.03301345297534551, 0.5607144151415143, 23.161555971418107, 57.15253257751465, 43.24003641945975, 11.58202952998025, 24.247769594192505, 53.59841087886265, 41.822444098336355, 44.00346279144287, 1.0530448768820082, 0.15117049110787256, 0.034545381486948044, 0.031192926556936333, 0.032175530080816576, 0.018289142986759543, 0.010846007382497191, 0.07334886198597294, 0.02846546344725149, 0.05352650296741298, 0.04527858072625739, 0.007110002899675497, 0.028634690080902407, 0.08835960365831852, 0.010815905872732401, 0.04600198048033884, 0.02016373168277953, 0.06819105946591922, 0.07371470771197762, 0.031085416075906584, 0.061676010489463806, 0.03349017132339733, 0.03295801666432193, 0.052497487648257186, 0.02325972242813025, 0.028082309989258647, 0.016554520798048804, 43.1531457219805, 64.96910313197544, 55.303665569850374, 36.478567191532676, 50.607551847185405, 98.21166842324394, 22.096961668559484, 0.08260127729071037, 0.4217618427106312, 0.3552646780652659, 0.9507563199315752, 1.4916503471987588, 1.0384861209562846, 0.03337874569530998, 0.6443728432059288, 0.48549017735889977, 0.40531895788652555, 7.645242742129734, 72.41250678471157, 99.35926764351981, 89.15862424033028, 87.9293350492205, 89.33289895738874, 84.26953125, 81.62982722691127, 80.87655912126813, 80.88031114850725, 79.20765045710972, 74.32954951695034, 71.08402511051723, 66.88204642704555, 70.65979589734758, 75.2325929914202, 78.52953406742641, 81.66879967280796, 81.44048186710903, 79.63094861166817, 76.41095188685826, 70.17943218776158, 61.177505901881624, 59.432312965393066, 62.12105042593819, 64.8075783593314, 65.60126413617814, 63.73857716151646, 59.96004949297224, 61.00187628609793, 60.13563741956438, 61.83468736921038, 61.42719636644636, 64.70576640537807, 63.87587356567383, 68.67164530072893, 62.03717177254813, 63.36277689252581, 63.7476167678833, 60.245682988848, 54.22968251364571, 64.15890148707798, 66.11848109109062, 69.45949459075928, 69.36777142116001, 71.30567959376744, 69.95134367261613, 66.2467656816755, 67.82455566951207, 66.67745671953473, 60.58257334572928, 68.65128707885742, 66.36503791809082, 55.143843105861116, 67.81794098445347, 65.93004594530377, 62.85014574868338, 59.84932994842529, 58.84145900181362, 63.184367997305735, 66.95776094709123, 64.14128085545131, 60.58544989994594, 64.2570378439767, 63.06697818211147, 64.02852548871721, 68.17890684945243, 65.53879983084542, 63.710728781563894, 60.91841452462332, 62.4970382962908, 65.95379488808769, 65.04927839551652, 62.17896366119385, 61.45944990430559, 63.78707558768136, 62.662071909223286, 62.202413831438335, 62.33396407536098, 62.13752460479736, 61.075763429914204, 58.58518859318325, 57.05840533120291, 56.083871841430664, 60.00503213065011, 64.43831634521484, 65.08114283425468, 64.70978941236223, 64.204238482884, 68.13437584468296, 66.35250336783272, 65.57957186017717, 64.83823381151471, 61.977917534964426, 55.80462026596069, 53.18846716199602, 58.339576721191406, 62.35015337807791, 65.85613795689174, 68.83458055768693, 67.12423283713204, 63.90476417541504, 58.318051201956614, 60.303172383989605, 64.5691578728812, 65.96712153298515, 62.912936619349885, 63.58839879717146, 65.82717786516461, 54.708507197243826, 67.33759117126465, 29.648102351597377, 0.16245228930243424, 0.07865617291203567, 0.4981390471969332, 1.7700282952615192, 0.2781952592943396, 0.11144288323287453, 0.5796900540590286, 0.5187788339597839, 2.041745743581227, 3.254412455218179, 0.07404226370687995, 0.25797450861760546, 25.597198350088938, 66.94185652051652, 47.24783032281058, 15.405386107308523, 28.130384751728602, 55.846347672598704, 46.51684161594936, 52.6782922063555, 1.7694318358387267, 0.15258466665233883, 0.05825106427073479, 0.08049859226282154, 0.027988380386627147, 0.035536161357803006, 0.04748709346832974, 0.03174713021144271, 0.04650386908490743, 0.035032454279384444, 0.05186057396765266, 0.02592556777277163, 0.02532865203517888, 0.13780508829014643, 0.1895362317029919, 0.1645865940621921, 0.12659260923308985, 0.20647231649075234, 0.19632205686398915, 0.12953795332993778, 0.10669898707419634, 0.13983267306217126, 0.11376040601836783, 0.13786342873104981, 0.11372984480112791, 0.1469087755041463, 0.16260350761669023, 52.30224527631487, 76.77963720049176, 61.62972245897566, 47.9587595803397, 64.97514111655099, 105.10975660596574, 29.124854360307964, 0.3253741519791739, 0.5024809113570622, 0.6321340799331665, 2.856242460863931, 2.15818104999406, 2.8010437999452864, 0.4699552538139479, 0.8946548274585179, 1.3183802962303162, 0.9653494911534446, 7.524741002491542, 74.12170805249895, 101.53315748487199, 92.26804038456508, 91.0915366581508, 94.72830023084367, 88.43164116995675, 85.87825461796352, 85.38864285605294, 85.67185143062046, 82.43688828604562, 77.12570612771171, 76.15863500322614, 70.60056945255825, 74.03538363320487, 78.60021114349365, 82.2572912488665, 85.81551238468715, 86.63089043753487, 82.81222997392926, 79.94334656851632, 74.95797933850969, 63.643115861075266, 61.910506112234934, 66.08671392713273, 69.4092104775565, 69.84967763083321, 66.21644374302456, 62.15932805197579, 64.39136041913713, 63.785581724984304, 67.28283936636788, 65.1576008115496, 69.87860298156738, 67.50190911974225, 72.21380220140729, 67.81635679517473, 68.38738059997559, 67.95430632999965, 70.37221690586635, 63.214599609375, 70.9192555291312, 71.5285222189767, 71.8004538672311, 72.25406006404332, 72.01664011819022, 75.14310019356864, 66.84913975851876, 70.32963834490094, 69.40785557883126, 63.00422205243792, 70.6992894581386, 74.88385595594133, 56.79189675194876, 69.94973863874162, 70.48212351117814, 67.30798489706856, 63.63992663792202, 62.45288249424526, 65.76644366128104, 69.80787726811, 67.0436406816755, 65.65502234867641, 67.21699823651994, 63.67039448874337, 67.35774789537702, 70.07438932146344, 66.76648398808071, 64.80976009368896, 64.28518499646867, 67.43918773106166, 70.48878683362688, 66.34534672328404, 65.70259666442871, 63.27756418500628, 68.72021320887974, 66.90926252092633, 65.58886854989188, 65.19150802067348, 65.85321276528495, 65.42077078138078, 61.44667911529541, 59.74528067452567, 61.10272938864571, 64.42303030831474, 69.45145552498954, 68.29098129272461, 68.80849702017647, 68.72226292746407, 69.91852733067104, 69.7214138848441, 69.46642194475446, 69.35366657802037, 66.01546709878104, 61.27092443193708, 58.0459041595459, 62.05170045580183, 67.24494389125279, 68.93662180219377, 71.95050716400146, 69.52947684696743, 65.06939343043736, 59.28710951123919, 60.7717866897583, 64.70479365757534, 66.59510666983468, 64.27542972564697, 64.00748634338379, 67.75250285012382, 57.04644053322928, 71.46476554870605, 31.75209331512451, 0.24314382299780846, 0.5726681937064443, 1.0331415448869978, 2.5207304528781345, 0.7985958733728954, 0.4922847556216376, 1.3163540278162276, 1.1303592196532657, 6.442862621375492, 3.757067722933633, 0.08792949388069765, 0.9111005621297019, 37.344267572675435, 72.18166678292411, 60.162207330976216, 19.36846661567688, 32.853775365012034, 66.4726585660662, 53.086151463644846, 62.903667722429546, 2.3015408430780684, 0.214448658483369, 0.1979991104453802, 0.1268138795026711, 0.10933400318026543, 0.14996919914015702, 0.1327121401471751, 0.21017257150794777, 0.12191872431763581, 0.12743290700018406, 0.12495105660387448, 0.12625539089952195, 0.18660353549889155], [0.04760273958423308, 0.008998208097182214, 0.012753670419832426, 0.02714928362651595, 0.05999690094696624, 0.14580865310771124, 0.021769109913813214, 0.048561855618442805, 0.010833440913951822, 0.03574763358171497, 0.05525273337428059, 0.0580364911417876, 0.02498068061790296, 0.4910544359258243, 43.979095458984375, 52.902409826006206, 32.442431586129324, 35.528084891183035, 62.43435164860317, 69.62751592908586, 4.837770555700574, 0.23722002229520253, 0.03382971363940409, 0.6560980368937764, 0.30017444704260143, 0.7830955822552953, 0.8000029921531677, 0.11498531779008252, 1.1140285645212447, 0.40339278695838793, 11.567676288740975, 86.30731282915387, 92.95605100904191, 80.06889356885637, 84.18700749533517, 81.08394200461251, 79.11063276018415, 77.24734129224504, 77.20560346330915, 72.36362620762416, 69.59422016143799, 69.39750276293073, 66.56917599269322, 63.256914138793945, 64.72807707105363, 66.40643528529576, 71.72186279296875, 76.4635705947876, 77.3722699029105, 73.8657294682094, 73.9863988331386, 68.21124376569475, 65.39395073481968, 56.459029402051655, 58.82700674874442, 62.19134535108294, 65.23214108603341, 64.81154578072685, 66.09883158547538, 63.77410330091204, 61.34768812997, 58.81399277278355, 60.602368763514924, 60.52978788103376, 63.61660153525216, 64.10311440059117, 57.974580901009695, 58.554289954049246, 59.318056787763325, 57.11886855534145, 48.55569321768624, 47.38881622041975, 62.04036794389997, 66.97026770455497, 65.97034549713135, 64.9038109098162, 66.21477617536272, 62.15933500017439, 64.57344491141183, 62.51240076337542, 61.158308029174805, 67.47048936571393, 64.67552784511021, 54.68552255630493, 62.2075138092041, 64.91861752101353, 62.95213140760149, 56.03379617418562, 56.0770765032087, 56.436166354588096, 60.72121770041329, 55.63633837018694, 64.28697068350655, 60.14863749912807, 59.58809157780239, 64.63174724578857, 65.09538664136613, 60.75974546160017, 62.910303252083914, 64.05141980307442, 60.08133724757603, 57.57593495505196, 59.042637143816265, 62.08711542401995, 58.945918219430105, 59.7332672391619, 58.30628095354353, 59.24456569126674, 59.11497483934675, 61.3989588873727, 59.80028261457171, 58.77601391928536, 57.950519289289204, 54.07369892937796, 53.62305613926479, 52.98759126663208, 54.70732947758266, 58.40702288491385, 60.68980489458357, 62.694228172302246, 58.8491576058524, 61.50077778952462, 60.34366648537772, 58.792286600385395, 54.055942807878765, 49.00249712807791, 48.869206360408235, 54.45555107934134, 56.48149292809622, 61.055516379220144, 63.01540865216936, 60.6358243397304, 59.193482535226, 62.262689454214915, 65.46440546853202, 67.31173692430768, 67.84020301273891, 66.47667462485177, 68.557833807809, 63.12224415370396, 70.75185258047921, 53.84242466517857, 63.02048083714077, 29.845983573368617, 0.018083808112091253, 0.01540567449826215, 0.021369120305670158, 0.07936605624854565, 0.10982610391719, 0.09565528003232819, 0.509031379861491, 1.2744669211762292, 4.197442812579019, 0.0748415711734976, 0.09858144872954913, 5.973424519811358, 48.992022718702046, 45.74281924111502, 27.895216022218975, 37.08567646571568, 36.91887106214251, 45.390528202056885, 36.722000803266255, 2.019241831132344, 0.28936750122479027, 0.03709940765319126, 0.06011963436113937, 0.04477262430425201, 0.0716437849083117, 0.0338592774101666, 0.04851093156529324, 0.03185357878516827, 0.03538144858820098, 0.06796654579894883, 0.0576521824779255, 0.018729741219431162, 0.0361466834188572, 0.02082704546462212, 0.046496727503836155, 0.012663394728276347, 0.04510955086776188, 0.11420721454279763, 0.018107721382485967, 0.0767525089904666, 0.05754104522722108, 0.050387793353625705, 0.0689214752720935, 0.011518199795058795, 0.07261093479714223, 0.8022035083600453, 54.14121457508632, 62.24030930655343, 44.55867944444929, 27.250522204807826, 64.48921189989362, 81.25518730708531, 6.654614618846348, 0.4071207397750446, 0.19227049712623867, 1.0309005337102073, 0.22429216599890164, 1.620515872325216, 1.2128764603819167, 0.320242065936327, 1.7095272902931486, 0.2232364605047873, 16.098477602005005, 94.33797822679792, 93.97989586421421, 82.91043581281389, 90.95442785535539, 84.33445521763393, 81.55131258283342, 80.57926654815674, 79.38342598506382, 75.20291028703961, 73.63404873439244, 71.68102822984967, 67.86240945543561, 65.98515905652727, 68.24219799041748, 70.3318200792585, 75.2800213950021, 79.29243237631661, 79.52799020494733, 77.37197807856968, 74.36174052102226, 70.97724519457135, 65.82316180637905, 59.466776030404226, 61.89532429831368, 65.54875659942627, 67.73962088993618, 69.44439615522111, 70.36499772753034, 67.45295211247036, 63.41147681644985, 63.73624951498849, 62.904140199933735, 64.22723702022007, 67.66356590815953, 67.66879790169853, 62.74451923370361, 63.270094871520996, 63.06677668435233, 58.88583714621407, 54.17763703210013, 57.14954137802124, 67.22621849605015, 68.52821363721574, 66.48286546979631, 69.44000489371163, 67.71906811850411, 64.4989115851266, 64.3062241418021, 62.825736727033345, 62.04152134486607, 70.06878212520054, 64.71856498718262, 59.21396582467215, 66.02743189675468, 66.51814842224121, 65.0316160746983, 57.84887409210205, 58.778494426182334, 60.68943664005825, 60.86554568154471, 56.84608575275966, 67.31022221701485, 63.13056114741734, 61.49859605516706, 65.68653242928642, 65.6177591596331, 62.48452459062849, 64.4625586100987, 64.2443573815482, 63.78545665740967, 60.764602252415244, 60.83122158050537, 63.21200793130057, 62.7141695022583, 61.52193505423409, 60.67078767504011, 61.38928699493408, 60.79241589137486, 64.08343710218156, 62.330218996320454, 61.26296179635184, 60.3559022630964, 57.72458471570696, 56.11013950620379, 56.849174227033345, 56.7275390625, 60.18530314309256, 62.56255286080496, 66.21739564623151, 63.27049091884068, 64.29948438916887, 63.73733343396868, 62.19519465310233, 55.64291136605399, 51.51399646486555, 53.032924788338796, 56.31259611674717, 60.30734825134277, 62.37739726475307, 65.29999024527413, 63.872371673583984, 60.35453346797398, 63.419654846191406, 69.0119958605085, 68.41574314662388, 71.53847898755754, 70.99185030800956, 70.1541268484933, 67.00786440713065, 74.95870889936174, 64.43685722351074, 69.87535122462681, 35.45700829369681, 0.19174012701426232, 0.030396323052367995, 0.026450496033898423, 0.17040539825601236, 0.30534491102610317, 0.8406759010893958, 2.5396940410137177, 1.3947922417095728, 3.3156352043151855, 0.17650472239724227, 0.06692889612168074, 5.237502157688141, 55.47318424497332, 55.65301057270595, 26.12980730193002, 33.60196433748518, 47.070227418627056, 49.955664907182964, 46.13294322150094, 2.341140581028802, 0.23347958443420275, 0.08491436245718173, 0.09582398419401475, 0.020409851601081233, 0.0703663748822042, 0.01983551581257156, 0.06015643810055085, 0.0012316609687072092, 0.03543172124773264, 0.01478191082631903, 0.054055807779410055, 0.010139034961217215, 0.1533365784479039, 0.13418141273515566, 0.1797529916678156, 0.06361438147723675, 0.21505543163844518, 0.24237827264836856, 0.15999414691967623, 0.12589384030018533, 0.13957197990800652, 0.13596920323159012, 0.22564608763371194, 0.13638802218650067, 0.27075713127851486, 1.3420580199786594, 67.2280250276838, 70.15833745683942, 44.18216003690447, 52.25122465406145, 81.02368027823312, 88.65683228628976, 10.211340154920306, 0.5373461576444762, 0.24561974299805506, 1.5072289683989115, 0.38833443926913397, 2.197477021387645, 3.66091160263334, 0.6818503407495362, 5.045001447200775, 0.8365594734038625, 16.12979313305446, 95.64412144252232, 98.9340934753418, 87.40195287976945, 96.7214604786464, 86.86899825504848, 85.90679086957658, 83.05673013414655, 82.76129273005894, 79.70858083452497, 77.13855334690639, 77.0039667401995, 72.52007184709821, 68.68153258732387, 71.14831679207938, 73.67457062857491, 77.40500286647251, 83.609924861363, 83.26530115944999, 81.0776538848877, 78.22887856619698, 74.83068139212472, 71.62572056906563, 62.92781271253313, 66.49146733965192, 68.72912774767194, 70.79347229003906, 70.49073232923234, 72.77112415858677, 71.31987476348877, 66.48852130344936, 69.24104322705949, 66.87452847617013, 67.11563096727643, 72.45810781206403, 70.58862549918038, 68.21535015106201, 68.80091653551374, 71.20562553405762, 71.33208274841309, 62.92111464909145, 64.63761152539934, 69.69191878182548, 73.97005667005266, 70.09999343327114, 69.51653235299247, 71.60574449811662, 68.6145658493042, 67.04577377864292, 64.18974454062325, 64.35220732007707, 72.40951211111886, 71.25086525508335, 62.456627573285786, 68.25060531071254, 69.72701413290841, 68.7423015322004, 57.92526258741106, 60.925439153398784, 63.89908749716622, 62.65605476924351, 58.230274609157014, 69.25710051400321, 63.56836714063372, 66.86045837402344, 71.1108729498727, 67.51176166534424, 65.06771196637834, 66.25111525399345, 66.43740340641567, 65.12880747658866, 61.858693395342144, 64.78615706307548, 67.57121740068708, 64.6248059953962, 64.94242204938615, 64.13394355773926, 65.27486555916923, 63.70762293679373, 66.2466823032924, 66.1664514541626, 64.51753275735038, 64.30129092080253, 61.02008751460484, 59.43537712097168, 59.28706087384905, 61.20725808824812, 63.92852006639753, 66.57501942770821, 70.24508571624756, 67.21867970057896, 66.84640216827393, 68.90496580941337, 66.3403787612915, 59.499342237200054, 55.42147922515869, 55.59303372246878, 59.08000455583845, 62.87138639177595, 65.57344354901994, 69.15335696084159, 64.92873409816197, 60.09656769888741, 63.547758783612935, 69.73297568729946, 69.78026512690953, 73.58516120910645, 73.08944198063442, 73.97468417031425, 70.08247007642473, 78.82770211356026, 65.89070524488176, 71.84321308135986, 36.78213398797171, 0.2961019884262766, 0.4051623520042215, 0.49898211338690346, 0.23517774045467377, 0.31992263879094807, 1.1904066375323703, 4.658310745443616, 2.9592868515423367, 8.47378328868321, 0.3303474336862564, 0.14377032034099102, 8.780258774757385, 68.905243737357, 58.56814466203962, 44.65927198954991, 49.91828012466431, 50.13194070543562, 58.27045256750924, 57.37255423409598, 3.6679010561534335, 0.5260255879589489, 0.2119690743940217, 0.17301611602306366, 0.17111262173524924, 0.14619358602379048, 0.10932807278420244, 0.142323371555124, 0.12105011806956359, 0.11863450626177446, 0.17910543855811867, 0.11980710976890155, 0.11902553242232118], [0.08125421564493861, 0.03849963251767414, 0.07150461059063673, 0.02577772008122078, 0.0684828498799886, 0.01695772326950516, 0.07366575141038213, 0.10669343665774379, 0.018885895875947814, 0.036696924428854666, 0.048991049373788495, 0.10159448347985744, 0.3510022296437195, 5.637695814882006, 55.514050074986045, 37.97843313217163, 36.13789006641933, 34.623658725193565, 72.41952446528843, 42.31787845066616, 0.8450370356440544, 0.091992256231606, 1.3823609373399188, 0.4467946823154177, 0.1903599596449307, 1.9816253696169173, 1.0963833970682961, 1.127785997731345, 0.5978787552033151, 9.126664689608983, 88.36666161673409, 85.93532712118966, 83.21531581878662, 83.8971425465175, 82.83412374768938, 81.26804147447858, 80.05079351152692, 76.54602486746651, 75.13504723140171, 70.78646155766079, 65.36712374005998, 64.30757904052734, 59.006923403058735, 61.44624137878418, 62.935490471976145, 65.59615721021379, 71.9070600782122, 74.0202921458653, 75.25393090929303, 76.27477414267403, 72.75442068917411, 67.59466757093156, 60.81442778451102, 56.52083362851824, 56.95712491444179, 60.76845850263323, 67.38686779567173, 71.17169053213937, 69.37986128670829, 67.25588730403355, 64.39379923684257, 60.14581653050014, 62.30708844321114, 61.38886315482003, 64.27835491725376, 57.179189341408865, 58.74264866965157, 60.978940282549175, 56.16997044427054, 48.06008863449097, 45.335578373500276, 56.730217593056814, 65.73225852421352, 65.94809736524309, 66.07708372388566, 65.39185237884521, 63.00576455252511, 64.41508156912667, 58.3694817679269, 64.88168784550258, 66.85127285548619, 59.274074690682546, 51.96867615836007, 58.6338746207101, 62.643763405936106, 60.80975859505789, 58.61474622998919, 59.99133723122733, 61.91354942321777, 61.15176977430071, 65.56982353755406, 56.87978104182652, 54.49288027627127, 64.28780446733747, 59.06467682974679, 54.309691020420615, 60.01888683864048, 65.30434676579067, 64.19596317836216, 58.206181730542866, 59.736428669520784, 59.76889760153634, 61.47865472521101, 59.00103827885219, 58.90547970363072, 58.94373648507254, 59.65605885641915, 57.16828761781965, 57.42944261005947, 58.16872746603829, 59.20811544145857, 60.048076220921104, 56.19979906082153, 53.8330272265843, 53.471397808619905, 49.96953003747122, 51.17449358531407, 52.52604675292969, 54.17528159277779, 55.80187920161656, 55.41629934310913, 55.13458810533796, 53.70947783333914, 48.73629079546247, 48.48467220578875, 46.62821429116385, 48.79774413790022, 53.20395817075457, 58.420078550066265, 61.02558353969029, 63.08545344216483, 62.078200885227744, 65.70079013279506, 65.87986605507987, 65.0905715397426, 65.7638658796038, 64.95754827771867, 66.58253043038505, 64.07489081791469, 67.41604328155518, 60.84595176151821, 69.89410441262382, 62.29647854396275, 71.88115719386509, 34.75144304547991, 0.06183170034949269, 0.054662105959973166, 0.15569976664015225, 0.10255120428545134, 0.21961331420711108, 0.49840492435864037, 0.7115767427853176, 3.805687742573874, 0.3806268242853028, 0.14204057173005172, 0.4008151138467448, 24.435605457850865, 50.881699970790315, 37.07589340209961, 34.687606470925466, 23.652748448508127, 38.152409076690674, 35.92100552150181, 0.48522701433726717, 0.06943643585379634, 0.0695242111438087, 0.030829404813370535, 0.08779177841331277, 0.03265272340338145, 0.06507894503218786, 0.03162519407591649, 0.03311939264780708, 0.049440948625228236, 0.019979278723310148, 0.05339891802785652, 0.05573464251522507, 0.014302865103153246, 0.05652841652876564, 0.009245193995801466, 0.04102166236511298, 0.03300310531631112, 0.021220348110156398, 0.08785081774528537, 0.04372311722753303, 0.04778710772682514, 0.06748109470520701, 0.08126316552183457, 0.061904072894581726, 0.4312862759189946, 8.50949616091592, 64.28905514308384, 45.54940571103777, 36.01395157405308, 30.768409047807964, 85.94972378867013, 49.51517343521118, 0.8114684969186783, 0.15474962762423924, 2.5687577043260847, 1.007969741310392, 0.5803368879216058, 1.722688915474074, 0.7205979472824505, 1.7730641152177538, 0.6199146413377353, 13.099520444869995, 98.71214021955217, 88.38716575077602, 87.8052819115775, 86.83748817443848, 85.70489011492047, 84.64189216068813, 84.13509750366211, 80.33500957489014, 78.89579445975167, 72.95535564422607, 69.1762443270002, 65.7812363760812, 63.09425680977957, 63.181109292166575, 65.71649306161063, 68.76914242335728, 74.17443793160575, 75.99393490382603, 77.93663733346122, 79.83182798113141, 77.42927292415074, 71.49134240831647, 65.47819764273507, 59.12252753121512, 59.04238700866699, 64.99613857269287, 72.64473642621721, 75.4729311806815, 73.3179543358939, 70.15778160095215, 67.09978907448905, 63.00852298736572, 64.27121216910226, 63.953853198460166, 68.11894389561245, 62.33796623774937, 63.26203496115548, 62.54493222917829, 58.916506494794575, 55.1381699017116, 54.935320717947825, 64.74289757864815, 69.97974790845598, 68.59648663657052, 70.89964076450893, 65.15364033835274, 64.48783615657261, 66.7208273751395, 59.4815548488072, 67.43859018598283, 68.59816115243095, 60.60556493486677, 58.18309981482369, 61.94187722887312, 64.82811028616769, 63.40001923697335, 60.59125859396798, 60.91179983956473, 65.18585913521903, 64.64162758418492, 67.71888746534074, 58.817890712193076, 55.90981946672712, 67.12408692496163, 63.75159113747733, 55.41781405040196, 59.72622871398926, 66.51955890655518, 64.45942497253418, 59.43270901271275, 61.924930572509766, 62.80203642163958, 65.3603492464338, 61.830525398254395, 62.234417234148296, 62.800653730119976, 61.68204239436558, 59.85534014020647, 60.5056220463344, 60.77516351427351, 61.8870142527989, 61.006802558898926, 60.73748343331473, 57.30376359394619, 59.25693348475865, 53.52152211325509, 54.4349114554269, 55.47362545558384, 57.42308848244803, 57.75049802235195, 60.32870006561279, 58.08044712884085, 55.87958090645926, 51.50204903738839, 51.4353289604187, 50.2830605506897, 50.691083090645925, 55.581392015729634, 61.55026980808803, 63.22584874289376, 66.4998607635498, 64.0589794431414, 66.53945854731968, 67.9806330544608, 67.26457950047084, 67.80620547703334, 67.7465899331229, 68.63539654867989, 68.37729876382011, 70.6697804587228, 65.04997321537563, 73.95060171399797, 69.90538828713554, 77.46640409742082, 43.69163806097848, 0.3372646096561636, 0.1792806362999337, 0.10555938072502613, 0.2983878371970994, 0.9470447876623699, 0.9801878035068512, 1.4070464755807603, 3.4019730857440402, 1.6737256113971983, 0.1426921689084598, 0.373720613441297, 25.805649518966675, 62.669471740722656, 30.689314229147776, 33.80215930938721, 40.124849796295166, 41.3471873147147, 46.67158147266933, 1.0434780759470803, 0.045430918623294146, 0.012062780974831964, 0.04260239450793181, 0.07777536660432816, 0.01972093669298504, 0.05374239245429635, 0.04168778019292014, 0.02544594699117754, 0.03680397350607174, 0.023077574791386724, 0.02154136642015406, 0.07048855189766202, 0.15237765918884957, 0.08723925413297755, 0.07403224174465452, 0.10695866242583309, 0.17903492519898073, 0.14826296855296406, 0.12432377812053476, 0.12313624684299741, 0.1265405248850584, 0.23346878215670586, 0.19611312236104692, 0.2371622382530144, 0.6525987503784043, 10.475726928029742, 79.68847969600132, 51.80310753413609, 46.947748047964915, 52.86657101767403, 90.97341728210449, 61.235766547066824, 1.029606106025832, 0.10437577816524676, 3.370554634502956, 2.727407442671912, 0.4520855726940291, 4.605978216443743, 3.9180548787117004, 2.8971903664725165, 1.207395851612091, 14.319912467684064, 100.26674406869071, 90.48055376325334, 91.92900998251778, 88.64668791634696, 90.13921655927385, 89.21722534724644, 86.9095618384225, 85.19538566044399, 83.91693796430314, 77.00225748334611, 71.53626251220703, 70.50528185708183, 65.63833972385952, 68.14647265842983, 69.01888847351074, 71.64498097555978, 78.37561757223946, 79.37424046652657, 80.5157252720424, 82.81184087480817, 80.49037824358258, 74.47300897325788, 67.47286564963204, 63.33351108006069, 61.64719023023333, 69.0628914151873, 72.97388648986816, 78.50831426892961, 77.78540284293038, 73.67072132655552, 68.45251996176583, 66.09179306030273, 67.17973504747663, 68.45478507450649, 72.99605124337333, 64.38267517089844, 68.24103764125279, 72.11949430193219, 71.60006781986782, 64.72404711587089, 61.55214582170759, 68.17146532876151, 72.69515255519322, 72.64308970315116, 73.36793967655727, 70.3127750669207, 67.79528290884835, 70.09747123718262, 60.50434357779366, 69.84031145913261, 71.45768533434186, 66.96973269326347, 58.846385274614605, 62.65187195369175, 66.36968626294816, 65.36377470833915, 63.04062366485596, 62.320470673697336, 66.33787740979875, 66.40170356205532, 70.7666244506836, 59.52965027945382, 58.831703730991904, 69.34239659990583, 63.78698526109968, 58.345593861171174, 65.3712718146188, 70.85989012037004, 66.0985745021275, 61.16930702754429, 65.98873043060303, 65.79473672594342, 69.58963435036796, 65.46206392560686, 64.0655107498169, 65.71909863608224, 64.25905976976667, 63.46736117771694, 63.65532384599958, 62.61149597167969, 65.5750207901001, 66.27125113351005, 62.68491758619036, 60.34308283669608, 62.16160706111363, 55.813777991703574, 58.34981141771589, 60.2792775290353, 61.705978938511436, 62.76202869415283, 63.845009667532786, 63.045681953430176, 60.14009121486119, 54.9523264339992, 54.99184431348528, 53.024072783333914, 54.413889680589946, 59.905165672302246, 65.34101240975517, 66.24034554617745, 68.12887981959751, 64.52315385001046, 70.6673972266061, 71.22744287763322, 70.96610723223004, 69.75688443865094, 70.12438855852399, 70.4680186680385, 70.02312551225934, 74.23690223693848, 68.88097367967877, 79.78698430742536, 72.2130240031651, 79.24542086465019, 41.98760625294277, 0.42507808761937277, 0.2776126419859273, 0.5791537942630904, 0.3795924112200737, 1.0669104414326804, 1.0245882038559233, 1.5140485167503357, 8.212141054017202, 2.444016260760171, 0.3160699712378638, 0.9719950088432857, 39.53852258409773, 64.61985887799943, 55.40757935387747, 44.412287848336355, 35.28247649329049, 51.02914769308907, 55.466510500226704, 1.9179735737187522, 0.19646600128284522, 0.13063313599143708, 0.15917963348329067, 0.13468922834311212, 0.10589885179485593, 0.18801942095160484, 0.1137057025251644, 0.10503921577973024, 0.10111501706498009, 0.08271769354385988, 0.11903134068208081, 0.14721594830708845], [0.028238769986533692, 0.017138440893696885, 0.09198590514383145, 0.06457080372742244, 0.019881861450682794, 0.0371050089597702, 0.04364766074078424, 0.04181187067713056, 0.017152098107284734, 0.035310548464102406, 0.03935748398570078, 0.03435773602021592, 0.2662399879523686, 23.137991155896867, 55.58588055201939, 31.27300112588065, 37.948361328669954, 32.78287942068917, 77.21749183109829, 16.488252435411724, 0.329161137342453, 0.14434376385595116, 0.6522954723664692, 0.8910336760537965, 0.41546444062675747, 0.79016803417887, 0.343894928161587, 0.44756682802523884, 1.8050749003887177, 72.2974168232509, 88.92183658054897, 86.40279497419084, 86.29544530596051, 80.07976055145264, 80.34040832519531, 82.00739928654262, 78.70783873966762, 75.57149832589286, 73.70399624960763, 68.69583892822266, 65.97442408970424, 60.30172715868269, 55.86132798876081, 57.95602921077183, 60.843985421316965, 65.06941427503313, 71.41841411590576, 75.19603157043457, 74.7091018131801, 78.59037944248745, 71.61865425109863, 65.35301194872174, 57.879946436200825, 54.84711333683559, 54.59207623345511, 60.57861982073103, 68.0433405467442, 70.96126433781215, 68.5643720626831, 70.40977191925049, 66.28702354431152, 65.04297637939453, 60.843770027160645, 64.44874559129987, 61.54428046090262, 64.18492943899972, 60.849078450884136, 55.11113098689488, 51.307072162628174, 46.51346826553345, 54.96120623179844, 67.7293028150286, 65.61071368626186, 66.00899137769426, 65.63802705492292, 62.76968560900007, 66.96511908939907, 58.804557119097026, 62.26124422890799, 68.44850390298026, 57.27082218442644, 56.580511706215994, 62.675551414489746, 66.44271877833775, 64.94748728615897, 64.16954612731934, 57.59363201686314, 61.17612321036202, 57.634094851357595, 59.07260472433907, 56.80295133590698, 58.85101972307478, 53.83531665802002, 55.83625888824463, 67.22352259499687, 65.25614711216518, 57.57980857576643, 53.39673941476004, 62.30547646113804, 61.75555433545794, 56.68347358703613, 59.925350189208984, 58.80578000204903, 61.160246576581685, 59.33291203635079, 62.9918612071446, 58.320913859776084, 59.72961943490164, 55.599290575299946, 58.083966391427175, 58.22533443995884, 57.921826703207834, 57.88525833402361, 53.82736097063337, 52.466917582920615, 53.697620732443674, 50.89217438016619, 50.40121119362967, 49.260674817221506, 48.99079288755144, 48.48849024091448, 47.21658427374703, 50.16730356216431, 47.3985402243478, 46.20643431799752, 45.95049742289952, 49.585888726370676, 55.97473301206316, 57.04863963808332, 60.889690671648296, 63.97869995662144, 64.6862906047276, 62.53789370400565, 63.412922041756765, 65.2218508039202, 62.37451376233782, 65.58712455204555, 62.39196068899972, 65.5644178390503, 62.55411079951695, 70.27710996355329, 59.200646127973286, 68.52107783726284, 62.349375179835725, 80.75194317953927, 31.906329427446636, 0.06670480314642191, 0.29843712598085403, 0.26354484685829704, 0.45362685141818865, 0.8126367713723863, 0.5427986479231289, 1.6668360382318497, 0.4455860214573996, 0.09826977045408317, 0.1104689072817564, 8.179045915603638, 46.6243337222508, 39.96092789513724, 32.60950102124895, 25.059776033673966, 34.30320085797991, 46.93685327257429, 3.005993510995592, 0.20714971157056944, 0.03509597194248012, 0.032764773283685954, 0.014593982071216618, 0.023038679467780248, 0.028046610565590005, 0.06350281674947057, 0.025069979219032184, 0.07535562930362565, 0.03623238917706268, 0.04653525472219501, 0.07845392876437732, 0.040097460350287814, 0.012749864686546581, 0.031633004013981135, 0.06481217220425606, 0.06772195428077664, 0.030078280118427107, 0.02593691966363362, 0.08103848222110953, 0.028302998415061405, 0.0394124453222113, 0.04374704576496567, 0.16846546663769654, 0.1811345296778849, 28.091761452811106, 65.7776163646153, 38.14376899174282, 45.293208258492605, 37.267027923039024, 90.01610142844063, 21.575841563088552, 0.29266268440655296, 0.04550085522766624, 2.230423207793917, 1.4064288458653857, 0.6074177090610776, 1.932831427880696, 0.20515305442469461, 0.09302909166685172, 4.016094395092555, 79.99775791168213, 90.31507546561105, 90.34886455535889, 90.38444628034318, 83.38201005118233, 83.91231741224016, 85.21879414149693, 81.54086249215263, 80.16128376552037, 76.52470084599086, 71.8644050870623, 68.08313982827323, 61.92067132677351, 60.39695916857038, 60.533741406032014, 63.09812695639474, 68.39658001491001, 74.0136844090053, 77.22629519871303, 78.19776453290666, 80.14245414733887, 74.11218207223075, 68.27713353293282, 60.35686111450195, 58.47945090702602, 58.0366005216326, 63.42331654684884, 70.76934814453125, 72.8423431941441, 71.78435489109584, 73.71138218470982, 68.28321320669991, 68.56734589168003, 64.87972150530133, 67.83786146981376, 64.2420575278146, 67.30776255471366, 63.85151318141392, 59.897446223667686, 57.49837916237967, 52.73989840916225, 63.03241784232003, 71.22295434134347, 71.26093319484166, 69.29905373709542, 64.73058537074498, 67.26671259743827, 68.48272378104073, 57.167700495038716, 65.19046579088483, 69.62459073747907, 58.757608141217915, 60.72633157457624, 67.76593371800014, 66.95844881875175, 67.75253759111676, 64.71294389452252, 58.8784373147147, 62.31643377031599, 60.17936243329729, 58.43232127598354, 58.92137023380825, 58.78387928009033, 55.56114843913487, 55.25344746453421, 65.86833204541887, 68.34967967442104, 60.57523604801723, 54.178543772016255, 61.24736309051514, 63.73367173331124, 59.591621262686594, 60.22314303261893, 61.67305142538888, 64.09899411882672, 61.905121258326936, 63.13215923309326, 61.34620816367013, 61.67727593013218, 58.079463958740234, 59.01656750270298, 62.09602996281215, 60.256911277770996, 61.036436625889365, 57.589115687779014, 54.51863030024937, 56.84919854572841, 52.765832560403005, 53.13258974892752, 53.428402355739046, 52.69200447627476, 51.82144035611834, 51.17760290418352, 52.68804747717721, 51.26190539768764, 48.54268271582467, 48.22304473604475, 52.99860068729946, 57.458586829049246, 60.751046316964285, 65.6206635066441, 64.5344933101109, 66.27937357766288, 64.79299409048897, 66.79288019452775, 67.24054568154472, 65.45663043430874, 67.96616690499442, 66.06040804726737, 67.068772315979, 65.13588769095284, 73.76810727800641, 65.55479458400181, 72.61977154867989, 68.77371433803013, 83.89392553056989, 41.76028898784092, 0.15460127272776195, 0.4107057388339724, 0.04497247322329453, 1.4208732822111674, 2.072418131998607, 1.6388236156531741, 1.5750292731182916, 1.445590847304889, 0.6349650365965707, 0.07590168714523315, 8.941088727542333, 55.55047600609915, 44.07788494655064, 23.284288951328822, 33.912673882075715, 42.981980323791504, 55.21897745132446, 4.90523669549397, 0.2810340055397579, 0.1475399894905942, 0.03843445244378277, 0.052112408847148926, 0.029754527312304293, 0.07969653672937836, 0.10502931595380817, 0.03377353772521019, 0.045065686971481354, 0.030091348702886274, 0.038489766618502994, 0.03968364559113979, 0.10647483981613602, 0.08754849646772657, 0.13028540036508016, 0.12051931369517531, 0.2024769801646471, 0.12378403065460068, 0.13633527287415095, 0.20396963506937027, 0.10277024896017142, 0.12373039924672671, 0.14532084071210452, 0.277626131262098, 0.35514015331864357, 33.57300077165876, 78.85424423217773, 45.87470299857003, 55.06486988067627, 49.898074763161794, 101.683488709586, 27.245714051382883, 0.524365674172129, 0.1444601733237505, 2.7247569220406667, 4.241957749639239, 1.087259326662336, 2.7951117753982544, 2.600826246397836, 1.1594314596482684, 4.771918569292341, 86.68601744515556, 91.38696711403983, 95.63285146440778, 92.77851063864571, 88.10066373007638, 86.45712988717216, 91.12555503845215, 84.30505738939557, 84.99252605438232, 79.27893202645438, 76.37806606292725, 71.35963930402482, 66.45752538953508, 61.328775133405415, 62.92893137250628, 65.85367829459054, 71.07310949053083, 76.52431869506836, 79.31623690468925, 82.05620343344552, 85.54472718920026, 77.73549393245152, 72.20270592825753, 63.67718982696533, 61.20703574589321, 60.15626662118094, 66.1978781563895, 73.24177428654262, 76.44652666364397, 74.62057481493268, 77.39653301239014, 71.58788762773786, 72.68307658604213, 67.34033570970807, 70.822724206107, 67.84583800179618, 72.84201662881034, 72.29223346710205, 70.01051453181675, 67.60713263920375, 61.177283559526714, 67.35610812050956, 74.73788125174386, 73.44002028873989, 72.37122058868408, 69.920090675354, 70.04412991659981, 73.2323386328561, 60.10412039075579, 66.52324840000698, 74.72134453909737, 64.40720231192452, 64.61467552185059, 68.76942035130092, 72.83061463492257, 70.87972027914864, 69.13622965131486, 61.918781416756765, 66.03653403690883, 64.09745161873954, 62.51558303833008, 60.51262583051409, 62.48887416294643, 55.53164291381836, 56.58663306917463, 70.48015022277832, 70.94450528281075, 61.57774298531668, 58.0399877684457, 67.85277925218854, 66.48021820613316, 60.81987517220633, 64.57313224247524, 64.8012693950108, 66.70913355691093, 64.28329508645194, 67.87231758662632, 64.42753968920026, 66.39544323512486, 60.556913648332866, 63.57548904418945, 65.53716005597795, 63.72794641767229, 65.1279250553676, 60.23342636653355, 58.33981990814209, 60.913898195539204, 55.63238831928798, 57.52323981693813, 56.77602359226772, 55.636856010981965, 54.054827622004915, 54.25972305025373, 56.84323351723807, 53.21287618364607, 50.67785024642944, 51.836677755628315, 56.65198087692261, 60.953885078430176, 64.32030119214738, 68.24619320460728, 67.25588730403355, 70.38207639966691, 66.65033790043422, 69.10445553915841, 69.90124716077531, 68.08206285749162, 71.18876920427594, 66.47094236101422, 71.06572355542863, 67.48059204646519, 78.09796060834611, 68.38601875305176, 76.38920402526855, 71.1114149093628, 89.4535961151123, 40.766922405787874, 0.27980908698269297, 1.1464605842317854, 1.2986526233809335, 1.3646093755960464, 3.4371618032455444, 4.350410878658295, 4.595300137996674, 2.7795189321041107, 0.6794719940849713, 0.42883217760494774, 15.776345218930926, 63.19862570081438, 55.29782560893467, 47.13381385803223, 34.198536668504985, 47.65505381992885, 63.535710607256206, 6.024541114057813, 0.5017896741628647, 0.3026535425867353, 0.141181953517454, 0.1894332165164607, 0.22673867829144, 0.13329736303005899, 0.21046028392655508, 0.14141333395881311, 0.24982144896473202, 0.10033934297306196, 0.15620687657168933, 0.20342435075768403], [0.0558137495203742, 0.04748016901846443, 0.0473240007912474, 0.04445090371051005, 0.02719970895642681, 0.04962917084672621, 0.04474110635263579, 0.04892669711261988, 0.05971124448946544, 0.02745403066676642, 0.02095819271302649, 0.005770132028763848, 0.08920860024435179, 31.77735001700265, 52.44837631498064, 38.923026834215435, 24.441756350653513, 36.25910486493792, 71.55845505850655, 4.163181245326996, 0.05099238162594182, 0.9407108532530921, 2.7916289908545355, 1.6387856176921298, 0.9227530168635505, 0.6182136897529874, 0.3034212371068341, 0.1695906948298216, 25.447678327560425, 94.75755214691162, 84.32759734562465, 87.58259909493583, 78.59290858677456, 85.96191092899868, 77.86910779135567, 81.60325036730084, 73.05033057076591, 79.65951960427421, 74.13957187107631, 69.34231322152274, 62.20092691693987, 60.03556251525879, 56.96543148585728, 60.878379004342214, 60.16600799560547, 64.98352064405168, 71.20541013990129, 73.67286137172154, 73.02582427433559, 72.74401923588344, 69.55109964098249, 63.51446301596505, 55.89911229269845, 54.46883603504726, 55.23280436652047, 59.66999694279262, 65.29259041377476, 70.74617590223039, 69.82362883431571, 68.07655988420758, 69.33155046190534, 65.83750983646938, 63.581374168395996, 60.9072904586792, 65.76855591365269, 63.24196856362479, 56.068589278629844, 49.18121174403599, 44.548298835754395, 48.06697082519531, 63.09168597630092, 66.70680591038295, 63.53096498761858, 67.07486588614327, 60.761225427900044, 67.6423739024571, 59.152279717581614, 63.869807788303916, 66.97374875204903, 55.60104152134487, 57.79858997889927, 62.530723163059776, 62.64646625518799, 60.126771518162315, 56.565343788691926, 53.89291722433907, 52.445444175175254, 56.18127863747733, 52.52957991191319, 52.81146832874843, 55.52444805417742, 52.45037044797625, 53.62268788473946, 53.328365666525706, 51.39276776994978, 57.48224197115217, 64.41631140027727, 61.77993556431362, 53.61767823355538, 58.3488803591047, 61.61404037475586, 60.47083241598946, 56.25519009998867, 56.20050777707781, 59.17861339024135, 60.253145354134695, 58.45267949785505, 59.818709237234934, 54.22733749662127, 56.157731192452566, 58.81144973209926, 57.05935723440987, 57.40838609422956, 54.60303701673235, 52.96677793775286, 52.15156316757202, 49.709590979984824, 52.213495935712544, 50.8332189151219, 50.43072714124407, 51.324970722198486, 52.3613258089338, 50.547036511557444, 49.341555322919575, 46.33756072180611, 47.37053550992693, 49.10068212236677, 56.89549091884068, 58.62271581377302, 61.24819687434605, 61.436374936785015, 62.56769452776228, 60.79022026062012, 63.500309535435264, 62.56711087908064, 61.76666450500488, 58.94056115831648, 59.73584502083914, 59.61008262634277, 62.589060238429475, 57.78575318200247, 65.59455217633928, 62.69681985037667, 69.46494892665318, 61.85618509565081, 74.1066860471453, 19.09799930027553, 0.8045337604624885, 0.385156262665987, 2.1080526198659624, 0.5884128117135593, 2.544039704969951, 1.2009915666920798, 1.7006773480347224, 0.16312859872622149, 0.14558723356042588, 1.4924724059445518, 32.45875290461949, 53.707765102386475, 35.041975021362305, 44.83721882956368, 40.39564888817923, 46.940706048692974, 5.19649258681706, 0.2678346538117954, 0.04955664563125797, 0.027626855232353722, 0.01940448662000043, 0.06250046446387257, 0.015123314024614436, 0.02847138705796429, 0.02052260037245495, 0.02182519592211715, 0.06622678201113429, 0.026184549322351813, 0.004357723219852362, 0.04856689374095627, 0.08072515510554824, 0.03615939237975648, 0.036281094420701265, 0.03648448868521622, 0.019418374535494616, 0.031280257406511476, 0.0569254443315523, 0.023371796057160412, 0.03955707506143621, 0.0011179118882864714, 0.023497559130191803, 0.02114535472355783, 39.905852999006, 59.91801289149693, 51.21281290054321, 29.909410204206193, 44.62186288833618, 85.71968977791923, 5.651498411382947, 0.03392796890277948, 1.703666484781674, 2.649974980524608, 1.5425741289343153, 2.286418523107256, 0.628142774105072, 0.1281518419938428, 0.1070447549489992, 29.98540265219552, 97.46721758161272, 87.47050380706787, 91.50930404663086, 81.51860741206578, 87.75465733664376, 80.59982626778739, 84.50731250217983, 78.0832999093192, 82.5464266368321, 75.23861013139997, 71.8829150881086, 65.5313583101545, 62.76664924621582, 58.423198291233604, 64.86777060372489, 63.34930433545794, 67.70217704772949, 73.1128921508789, 76.86163289206368, 76.28562722887311, 76.58450399126325, 71.9530224118914, 65.88943372453961, 61.239386558532715, 56.787338733673096, 57.53683049338204, 62.753086362566265, 66.95973423549107, 71.72917924608502, 71.46532835279191, 70.08260904039655, 71.70513153076172, 69.10840211595807, 66.1144858769008, 65.5793981552124, 70.04987607683454, 65.73236969539097, 59.334350313459126, 56.35983691896711, 52.334345953805105, 58.736992835998535, 65.34458378383091, 69.20881748199463, 67.63935143607003, 68.21426623208183, 63.283504894801546, 70.77884633200509, 59.4581116267613, 68.66018077305385, 67.21555995941162, 58.72799491882324, 61.227157729012625, 66.44543552398682, 64.48089490618024, 58.540886878967285, 54.05050931658064, 53.83565017155239, 53.14722612925938, 57.22191728864397, 53.89218766348702, 54.6345922606332, 55.39671931947981, 54.00508894239153, 56.73766606194632, 56.59671490533011, 51.31040382385254, 57.89114693232945, 65.80600670405796, 66.02112293243408, 56.3116511617388, 58.97322463989258, 61.78847490038191, 63.064574105399, 57.82925932747977, 58.14176845550537, 61.34850106920515, 62.822700364249094, 60.87400163922991, 63.1097651890346, 56.65684461593628, 58.01752771650042, 59.51205049242292, 59.1212351662772, 60.01209844861712, 58.77541637420654, 56.76559434618269, 54.59035308020455, 53.1007079396929, 53.956340381077354, 54.49782739366804, 55.11674165725708, 55.45139816829136, 55.05049753189087, 54.03910384859358, 52.628636905125205, 49.17800862448556, 49.70591538293021, 52.936997958592, 59.41454642159598, 61.081662450517925, 64.33470480782645, 66.23213972364152, 65.32746342250279, 64.8441606249128, 67.40070860726493, 63.48120893750872, 63.279370716639924, 63.32424218314034, 61.32498836517334, 61.677553858075825, 64.73367731911796, 61.988138335091726, 69.51140458243233, 66.12598514556885, 72.77873243604387, 67.0985245023455, 78.35873344966343, 27.251154490879603, 0.891714545232909, 0.47219023959977285, 3.202387818268367, 2.7152847903115407, 4.466380221503122, 2.680401359285627, 3.0717464855739047, 1.0597733386925288, 0.1452631109527179, 1.4785532099860055, 33.95186867032732, 64.00781985691616, 26.054884876523698, 43.81173072542463, 48.56026513235909, 53.72500010899135, 8.250051294054304, 0.3001795767673424, 0.08069146584187235, 0.08260528064732041, 0.1258348756070648, 0.09866649630878653, 0.036349314331476174, 0.05877499508538416, 0.10227972242449011, 0.028190894251955406, 0.0348124834043639, 0.048798358999192715, 0.019293225536655103, 0.15889781074864523, 0.13916445177580627, 0.07569945656827518, 0.22361398381846292, 0.10151324926742486, 0.1296510515468461, 0.12156478688120842, 0.14116431160696916, 0.12881150016827242, 0.12022267175572258, 0.11254717861967427, 0.13355129797543797, 0.14716199120240553, 46.69584805624825, 72.56322710854667, 53.61107397079468, 37.61582749230521, 51.78176266806466, 97.69264493669782, 8.736302733421326, 0.16369641040052685, 2.3781451668058122, 8.006850446973528, 3.5724026262760162, 4.308226193700518, 4.8612372279167175, 0.42767155702625004, 0.2925027401319572, 32.36702626092093, 98.40984494345528, 92.91523034232003, 95.40158067430768, 86.55103479112897, 90.86874267033168, 85.54570688520158, 87.46227019173759, 81.55837195260185, 87.593994140625, 81.43444388253349, 75.37502411433628, 68.48749024527413, 66.9133550098964, 61.97529806409563, 68.90604972839355, 66.74733475276402, 69.80422946384975, 75.44893210274833, 79.64609568459647, 78.29023115975517, 78.89092377253941, 76.36674049922398, 70.42156301225934, 62.37269333430699, 60.63225991385323, 59.702479771205354, 67.08995042528424, 69.87330150604248, 76.55090250287736, 74.68780558449882, 72.47708334241594, 75.95017514910016, 72.32717595781598, 70.85173293522426, 68.16183512551444, 73.13532093593052, 70.50712312970842, 66.6538953781128, 64.48398685455322, 59.29157025473458, 63.08942781175886, 69.66796139308384, 74.44036633627755, 70.2029309953962, 74.55668612888881, 65.5006959097726, 74.76076861790249, 61.07189328329903, 71.10816315242222, 71.40059893471854, 62.36839239937918, 64.9761347089495, 68.44002710069928, 68.3378677368164, 63.4933682850429, 58.18761266980852, 54.02152143205915, 53.896443435123985, 58.31622382572719, 54.82475055967058, 53.713837827954976, 56.468444211142405, 54.0190235546657, 56.53599459784371, 57.80608013698033, 52.409421239580425, 60.54289218357631, 69.46432358877999, 67.13613510131836, 59.380354336329866, 62.492744309561594, 64.99136516026088, 66.81809520721436, 60.695683070591514, 61.828065735953196, 64.16487693786621, 66.13366985321045, 62.23284694126674, 66.42399338313511, 60.68044567108154, 60.22622108459473, 63.401936939784456, 61.60466030665806, 62.84007780892508, 61.72440556117466, 58.658221108572825, 58.86567347390311, 58.05861241476876, 58.394432749067036, 57.67369610922677, 58.50572204589844, 59.590259415762766, 60.37398147583008, 57.32670307159424, 57.06067739214216, 54.18153497150966, 54.263301372528076, 55.85565825871059, 64.04113646915981, 63.81399985722133, 68.2976654597691, 66.58534445081438, 67.95742607116699, 65.19300188337053, 69.0343690599714, 65.64479460035051, 67.29404681069511, 64.84210395812988, 65.14083480834961, 65.0831995010376, 68.07807459150041, 64.63738223484584, 74.29619816371373, 69.38656629834855, 77.41572393689836, 68.50153950282505, 81.17752729143415, 25.8689250264849, 2.0350824211324965, 2.015893885067531, 6.287203865391867, 4.607507254396166, 7.956165075302124, 3.7580257058143616, 3.7114419426236833, 1.3073629502739226, 0.22162356919475965, 2.7680055499076843, 48.14054877417428, 66.86741352081299, 51.30245508466448, 58.231038911002024, 51.651108741760254, 66.50949096679688, 10.723913976124354, 0.4893557642187391, 0.15108313650957175, 0.15166917363447802, 0.1854118380163397, 0.2947399243712425, 0.10969691084963934, 0.14903852050857885, 0.21867343464068004, 0.06529463095856564, 0.11359737440943718, 0.1045570420101285, 0.14749521975006374], [0.06527122828577246, 0.07118757867387362, 0.010277013360921825, 0.025026025416861688, 0.06850454264453479, 0.10366212895938329, 0.023463274452037046, 0.014284283421667559, 0.017681199358776212, 0.035822007805109024, 0.01667706252607916, 0.020809944685814635, 0.5498644773449216, 46.3501022202628, 41.78128644398281, 25.207951579775127, 27.938980988093785, 46.157390458243235, 47.82397494997297, 1.126630642584392, 0.02422101316707475, 0.21529526662613663, 2.857276222535542, 0.5662472982491765, 0.41079060999410494, 1.7949736309903008, 0.05185240440602813, 1.0666495582887103, 60.650957516261506, 92.58325931004116, 82.22742789132255, 83.3447607585362, 83.01536750793457, 74.90796620505196, 75.44356114523751, 76.48321315220424, 77.82229777744838, 75.46420424325126, 75.76209436144147, 68.58432034083775, 62.972774505615234, 58.833565848214285, 60.50930459158761, 59.69325951167515, 61.609260014125276, 67.35680988856724, 71.16760499136788, 74.28855514526367, 74.73149585723877, 70.99416405814034, 66.90284933362688, 61.17118304116385, 55.40680810383388, 55.54056440080915, 55.63559143883841, 56.59309836796352, 59.56607273646763, 66.00254344940186, 67.00817012786865, 71.5279872076852, 68.50395052773612, 66.1809801374163, 64.25687108721051, 60.57473577771868, 62.43668624332973, 58.2733291217259, 53.31308657782418, 49.218019826071604, 48.46421670913696, 61.70467267717634, 64.92748342241559, 63.824943270002095, 64.04257474626813, 59.67107391357422, 65.4293657030378, 59.53597314017159, 59.85933535439627, 66.28386906215123, 56.97229630606515, 59.04393645695278, 61.917718342372346, 63.93058368137905, 53.06461204801287, 56.76453821999686, 55.867056778499055, 52.79362882886614, 56.76067502158028, 59.14585958208357, 56.81249816077096, 56.535786151885986, 57.77638701030186, 63.12853922162737, 60.444741930280415, 62.90226418631417, 60.31128787994385, 55.03267192840576, 54.06633383887154, 60.47556413922991, 61.96224934714181, 56.240439074380056, 53.313374928065706, 56.789721965789795, 58.32296357836042, 57.670565945761545, 57.186658654894146, 59.85258865356445, 58.41101115090506, 57.556229863848, 57.185046672821045, 54.65155976159232, 55.92087057658604, 59.160561970302034, 57.84954111916678, 54.13396412985665, 55.224553380693706, 53.11201613289969, 51.93353911808559, 50.36053991317749, 50.54165513174874, 51.52281025477818, 52.18384102412632, 50.486969334738596, 49.305726936885286, 47.674658162253245, 48.00742128917149, 46.80168996538435, 50.731987135750906, 54.98901292255947, 58.18474653788975, 60.2538332257952, 62.96481187002999, 62.4996577671596, 62.84682450975691, 63.11592129298619, 60.16233934674944, 56.21985503605434, 58.06993103027344, 57.528697626931326, 59.476156098502024, 56.174650056021555, 59.218377930777415, 56.060282707214355, 60.483339173453196, 63.30215385981968, 67.07306630270821, 66.3922609601702, 68.51931299482072, 4.546473409448351, 0.35458000909004894, 1.6236775198153086, 1.5469915547541209, 1.277159456695829, 0.8458592572382518, 0.7495162955352238, 0.8147954898221152, 0.06487391210560288, 0.01605680348750736, 14.543073841503688, 48.630396774836946, 39.557084696633474, 34.60171978814261, 32.15650279181344, 46.39350414276123, 7.312924299921308, 0.2651180167283331, 0.10123236291110516, 0.06152921622352941, 0.10069615061261825, 0.027678883601246134, 0.05775378631161792, 0.024178918550855348, 0.03805949059980256, 0.03280341924567308, 0.08668486388134104, 0.04153169338990535, 0.04405026610142418, 0.041631746771080155, 0.0275596175010183, 0.039128888930593214, 0.02622669652503516, 0.04897597571834922, 0.05292685103735753, 0.08428265314017024, 0.06819695593523127, 0.047404678604964695, 0.007959544858230012, 0.06906725173549992, 0.03463093118209924, 1.0191408161606108, 58.81274209703718, 48.49361106327602, 36.442620686122346, 27.37391005243574, 52.56095450265067, 59.268224307468955, 1.1800335198640823, 0.11456519604793616, 1.3165343552827835, 1.2326508164405823, 1.5171943136623927, 2.3016921835286275, 0.6712565634931836, 0.0703689261738743, 1.3595185173409325, 67.59342384338379, 93.73437431880406, 84.11199474334717, 85.77680397033691, 85.6047943660191, 78.24030835287911, 79.19886098589215, 79.36543015071324, 80.03104673113141, 77.17961025238037, 78.28226852416992, 69.33799839019775, 65.66225542340959, 62.13414083208357, 63.51925032479422, 62.98029245649065, 67.39414950779506, 69.82675552368164, 73.10039234161377, 75.82145282200405, 75.5311918258667, 75.01038265228271, 71.20284625462124, 62.46940531049456, 58.85551520756313, 57.20936189379011, 57.50397246224539, 57.55892923900059, 63.1259058543614, 68.60669354030064, 70.38026291983468, 75.27742971692766, 70.94852134159633, 69.18618719918388, 65.5737840107509, 63.95265116010393, 64.3355941772461, 63.97385706220354, 59.020111083984375, 55.7909323147365, 55.20122480392456, 64.7964334487915, 67.98974909101213, 66.63705294472831, 66.54029927934918, 63.38851302010672, 68.08608586447579, 60.01862975529262, 64.45058686392647, 68.09582029070172, 58.19560309818813, 62.965958322797505, 65.28544071742466, 66.78548731122697, 53.96126665387835, 57.608549799237935, 57.291298525674, 56.02920341491699, 58.561036654881065, 61.68932410648891, 59.04989801134382, 60.10789326259068, 58.9921098436628, 63.20596299852644, 62.72570351191929, 64.11620480673653, 60.98298413412911, 56.38864415032523, 54.41350752966744, 61.33056082044329, 63.290022305079866, 61.00409276144845, 55.8365090233939, 59.45970971243722, 62.12011241912842, 60.86469105311802, 58.77828598022461, 60.64459296635219, 59.41665867396763, 60.80715996878487, 59.29750401633126, 56.24871785300118, 58.91044766562325, 61.00057002476284, 59.96332904270717, 58.42744364057268, 59.00690950666155, 56.9405187198094, 54.713360513959614, 53.47642830439976, 53.64807660239083, 55.55790363039289, 55.24913958140782, 54.54867778505598, 51.6719012260437, 49.596800872257774, 51.76631334849766, 50.30968952178955, 53.86322062356131, 58.323616709027974, 61.062992640904014, 62.249863079616, 65.55630234309605, 65.77840151105607, 65.86143248421806, 63.41923795427595, 63.461184229169575, 60.13809708186558, 60.72996548243931, 59.745829582214355, 61.9975392477853, 59.90313679831368, 62.94946329934256, 58.85850988115583, 65.48579897199357, 66.74324226379395, 74.2570937020438, 69.0707984651838, 76.22717203412736, 6.299059229237693, 0.6884532464402062, 0.7988809666463307, 2.982322084052222, 3.484493149178369, 2.2630360977990285, 1.5560518971511295, 1.9677715301513672, 0.25053228225026813, 0.007276048052257725, 17.200243030275615, 56.334284918648855, 39.68748153959002, 29.867898191724503, 37.57777220862252, 54.67126832689558, 10.036265526499067, 0.37086642373885426, 0.20897588000765868, 0.04901056743359991, 0.08226951437869243, 0.059098534152976105, 0.05786214156874588, 0.015664725597681742, 0.014761656556012375, 0.02033648330585233, 0.03309989155137113, 0.028606269641646316, 0.00852061528712511, 0.17075535947723047, 0.1384773536452225, 0.13811241037079267, 0.0890980533191136, 0.2276310875479664, 0.21617684646376542, 0.12406792970640318, 0.1587099651140826, 0.14560473976390703, 0.13562644805227006, 0.29376201970236643, 0.1410112205360617, 1.360991969704628, 71.09705993107387, 58.28902857644217, 36.20250136511666, 42.59748438426426, 65.66137300218854, 71.04762349809918, 2.1728949461664473, 0.1390909935746874, 1.35602140213762, 7.251246878079005, 2.671930202416011, 2.8303927736622945, 4.931044910635267, 0.17326296706284794, 1.9120194017887115, 70.89057336534772, 95.81148965018136, 87.90812219892229, 91.17615182059151, 90.43335465022496, 83.12948472159249, 83.44885866982597, 82.53254413604736, 83.86531979697091, 82.06860596793038, 82.28927380698067, 74.28021730695451, 68.7698928288051, 65.67845167432512, 65.56100627354213, 64.86456748417446, 70.08429050445557, 74.9581252506801, 77.31944969722203, 79.17110988071987, 78.74342741285051, 77.77642577035087, 73.8833292552403, 65.96150044032505, 61.609148842947825, 60.95201601300921, 61.695945739746094, 61.31855433327811, 65.49270548139299, 71.90675435747418, 73.01823684147426, 78.30668449401855, 74.00026743752616, 71.6392765045166, 69.96552494594029, 66.13720648629325, 67.9907774244036, 67.50484820774624, 62.65059348515102, 62.64854376656668, 63.00427763802664, 70.05417006356376, 72.81523132324219, 69.23164231436593, 69.85616030011857, 66.40844331468854, 71.06342370169503, 64.79597486768449, 64.52303573063442, 72.42741761888776, 61.992091860089985, 65.41229397909981, 66.56974574497768, 71.13435786111015, 55.72396905081612, 60.57667432512556, 60.32934624808175, 56.488757269723074, 58.71131924220494, 64.17388875143868, 61.05191026415144, 62.34795774732317, 61.78964914594378, 66.74362441471645, 64.64093971252441, 65.12532642909459, 62.20253889901297, 57.0482679094587, 56.6852696963719, 65.84129660470145, 66.41145188467843, 62.27760028839111, 59.560201508658274, 63.24806213378906, 64.51577486310686, 62.62252276284354, 62.81753090449742, 63.7057260785784, 62.4745261328561, 63.469251087733674, 64.11088943481445, 58.474086897713796, 60.49672835213797, 64.8562296458653, 64.74822684696743, 60.805318696158274, 64.38680934906006, 59.21787071228027, 57.98891156060355, 56.552308968135286, 57.29177795137678, 59.10180105481829, 58.24699544906616, 57.82933228356497, 54.695993491581504, 54.72319916316441, 55.36130435126168, 53.28297308513096, 57.4440199307033, 61.094586099897114, 64.44098445347377, 66.41394628797258, 67.08679594312395, 67.57142584664481, 68.08803136008126, 66.76351710728237, 65.96406432560512, 64.65305042266846, 62.46019894736153, 62.09425122397286, 63.5456326348441, 62.285208565848215, 65.66342272077287, 62.60644463130406, 69.26703643798828, 72.6777125767299, 77.85277952466691, 74.03131893702916, 78.88677569798061, 5.4304041266441345, 2.212814952645983, 7.77846576486315, 4.514814376831055, 6.155104713780539, 2.2660075383526936, 1.7763261858906065, 2.983329789979117, 0.21987032970147474, 0.17425810652119772, 25.82734179496765, 66.65629945482526, 55.723500047411235, 48.57402951376778, 41.7932825088501, 66.00749751499721, 11.371089168957301, 0.4024914481810161, 0.3643106626612799, 0.15204471562589916, 0.14959282933601312, 0.1360650530883244, 0.20412727232490266, 0.0668760993118797, 0.09070604560630662, 0.13182636696313108, 0.1424267938626664, 0.10171784114624773, 0.10460168961435556], [0.015075843714709793, 0.009518010026243116, 0.018280430597120097, 0.052623332145490816, 0.10911819511758429, 0.05051005518596087, 0.06172587602798428, 0.035945063523416004, 0.03499788970553449, 0.07602805750710623, 0.03463961643033794, 0.15418679639697075, 3.7579323393957953, 54.95855549403599, 36.93616165433611, 25.542752265930176, 23.46061164992196, 56.97048282623291, 24.577548469815934, 0.29165940252797945, 0.04358838392155511, 1.4201800908361162, 1.4710252710751124, 0.7089574347649301, 1.9810169679777963, 0.29214686208537644, 0.5003277297530855, 8.994540350777761, 83.49928869519914, 84.54529135567802, 85.39409719194684, 78.78838225773403, 77.55443082536969, 69.64083562578473, 66.60766206468854, 67.25642926352364, 69.80477837153843, 73.42394910539899, 69.82400403703961, 65.21987056732178, 62.63912895747593, 60.52739770071847, 61.034887177603586, 63.35910824366978, 67.41722447531563, 68.89311913081578, 72.83060073852539, 72.90275083269391, 73.3343312399728, 70.76204558781215, 66.31610175541469, 58.10035024370466, 54.65686123711722, 53.43407208578927, 52.32598032270159, 52.54911824635097, 56.79269232068743, 64.18413734436035, 66.21023205348423, 68.57678849356515, 67.92569364820207, 67.62333583831787, 64.16784381866455, 61.90549646105085, 62.24605546678816, 61.67094612121582, 55.129995346069336, 53.187181745256694, 55.73940447398594, 57.695089612688335, 65.00842298780168, 64.99549239022392, 61.569161960056846, 66.6919367653983, 63.113072531563894, 64.96045957292829, 66.73204176766532, 57.00931283405849, 61.60121400015694, 63.116511889866416, 60.779645102364675, 54.7710861478533, 53.63100487845284, 60.574499538966585, 58.883078711373464, 62.628873416355674, 62.80469063350132, 59.739527566092356, 59.97707257952009, 58.03207377025059, 64.16861506870815, 60.447090421404155, 56.174545833042686, 59.90417902810233, 60.7484963280814, 60.360988344464985, 57.90075281688145, 55.369548388889854, 56.93453632082258, 60.530684198652, 61.69397245134626, 55.56955228533064, 54.232336725507466, 59.49191461290632, 59.3844051361084, 55.59546906607491, 57.750022070748464, 58.69863183157784, 57.15728514535086, 55.074684211185996, 54.39995854241507, 59.63975143432617, 54.53127949578421, 58.30975505283901, 55.52340929848807, 53.40523011343819, 51.70869541168213, 50.63907235009329, 50.19130611419678, 52.162318978990825, 51.83923816680908, 52.22065952845982, 49.77257987431118, 46.33767189298357, 45.640573024749756, 46.98645298821585, 51.9805714743478, 55.10215738841465, 57.59378835133144, 60.21845299857003, 62.34492833273751, 62.143194334847585, 64.23162828172956, 61.117661067417686, 59.55623408726284, 56.87924950463431, 57.35639272417341, 55.88054323196411, 56.09315810884748, 57.15453365870884, 55.79552507400513, 56.89753021512713, 58.004232338496614, 57.62526716504778, 65.63748509543282, 63.80076353890555, 76.0244722366333, 34.15084423337664, 0.20165307580360345, 1.9106245509215762, 1.9367293672902244, 1.4518255527530397, 3.8412542683737616, 3.0162125740732466, 2.7713650039264133, 0.14104146962719305, 0.11485123927039759, 6.674672331128802, 40.38178028379168, 39.62363454273769, 36.798986843654085, 31.96674054009574, 54.80151925768171, 10.12334816796439, 0.2631004607038838, 0.07216348844979491, 0.04669910057314804, 0.09677531743156058, 0.026863282812493186, 0.03610353198434625, 0.055115068797022104, 0.027788538252934813, 0.05137710080349019, 0.04638849099033645, 0.022223497674401318, 0.06002607795276812, 0.022668479243293405, 0.025348200629066144, 0.09049004076847009, 0.03827197044821722, 0.0973446083122066, 0.03901835896873048, 0.059864159141268046, 0.043266524228134325, 0.08430634758302144, 0.018608086675937687, 0.11149361051086869, 0.30349381321242874, 5.5127845747130255, 66.80523409162248, 43.83646978650774, 38.59914003099714, 21.981110879353114, 68.67461912972587, 30.45751190185547, 0.1756672201944249, 0.007645795354619622, 2.5604691548006873, 0.8056211535419736, 1.0798872879573276, 3.918731459549495, 0.4655467303735869, 0.33378391500030247, 10.669722369738988, 85.75163759504045, 86.84549249921525, 88.3764168875558, 82.06632695879254, 81.31185681479317, 72.44719914027623, 69.19694995880127, 68.42724241529191, 73.96056543077741, 75.32173143114362, 72.98744242531913, 67.35178634098598, 65.79630007062639, 64.15218257904053, 65.03144236973354, 66.73218073163713, 70.23398249489921, 70.99665846143449, 75.29091617039272, 74.89028998783657, 74.50876440320695, 72.19022001538957, 69.40165778568813, 59.8239620753697, 57.51576008115496, 56.223690441676546, 55.40036712374006, 55.64000701904297, 58.788187163216726, 68.16773414611816, 67.82673045567104, 71.36909580230713, 69.82074533190045, 70.30712618146623, 67.63800348554338, 64.38306427001953, 65.79388904571533, 64.3927709034511, 62.88262162889753, 60.15352208273751, 62.78652804238455, 61.0699199948992, 65.96359184810093, 68.93250152042934, 68.26580102103097, 68.34169619424003, 63.792238099234446, 68.27143601008824, 67.3317129952567, 60.095567158290315, 63.89820507594517, 65.68487875802177, 61.859277044023784, 55.83885056631905, 59.54673589978899, 63.80200031825474, 61.10584912981306, 65.41093213217599, 64.22064317975725, 60.52678625924246, 62.082661628723145, 62.63719735826765, 65.42033304486955, 60.75130340031215, 58.04829433986119, 62.76640605926514, 61.96827343532017, 63.28421361105782, 62.1586332321167, 58.498843329293386, 58.66090311322893, 62.34932654244559, 62.754670551845, 60.11439677647182, 56.872009481702534, 60.227221625191824, 62.73116479601179, 58.61954048701695, 58.89276450020926, 59.617294856480186, 60.18468475341797, 55.12278311593192, 54.88333429609026, 62.39733164651053, 59.31882803780692, 60.921520369393484, 59.17533384050642, 57.0730938230242, 56.05148976189749, 53.28634990964617, 54.50513342448643, 55.11838143212454, 54.87251942498343, 54.330160413469585, 51.95055178233555, 51.08859648023333, 48.77757699148995, 49.67151485170637, 54.53095293045044, 58.82070473262242, 60.841088022504536, 62.32340976170131, 64.80371516091483, 65.38005433763776, 66.48405361175537, 62.83449840545654, 61.15076923370361, 59.60965183803013, 59.525335448128835, 57.28921406609671, 59.42553152356829, 58.99848134177071, 59.64178030831473, 58.47230121067592, 61.79315798623221, 61.55888557434082, 70.46310629163469, 67.14826665605817, 80.48946802956718, 40.70789398465838, 0.1229356447500842, 0.6348482742905617, 0.8628208413720131, 1.8961219234125954, 2.579014982495989, 1.236520637358938, 1.5073083298546928, 0.10395358010594334, 0.16589449745203766, 7.1421584231512885, 51.152839524405344, 42.78633294786726, 31.30885383061, 39.86410822187151, 62.34888185773577, 13.443213956696646, 0.3601458418582167, 0.04854223577837859, 0.06976803591740982, 0.11161394869642598, 0.06076205774609532, 0.01740622813148158, 0.06595510337501764, 0.06901815972690072, 0.02778572402894497, 0.13285911083221436, 0.052116527554712126, 0.08340454061648675, 0.19825988502374717, 0.08549183647015265, 0.13377435957746847, 0.10005173233470746, 0.13507877529731818, 0.13237032134618076, 0.1049892891730581, 0.1841363686003855, 0.1598200484045914, 0.1409784744360617, 0.2390935117644923, 0.503935419023037, 6.924610325268336, 81.14956774030412, 50.822299821036204, 37.746116638183594, 37.13621766226632, 80.45635986328125, 40.973405497414724, 0.866562120616436, 0.1260912668492113, 5.791786015033722, 3.5282251111098697, 2.5110972097941806, 5.39906210558755, 0.8599388588752065, 2.0602559617587497, 13.764747926167079, 89.28963252476284, 92.17291259765625, 93.96992519923619, 87.33110209873745, 83.85197925567627, 74.39387593950543, 73.69460923331124, 74.68817383902413, 78.82165023258754, 80.01916531154087, 76.17066928318569, 72.31681619371686, 69.12468869345528, 68.21903269631522, 67.75759587969098, 68.48301560538155, 75.41022368839809, 75.21449293409074, 79.37255900246757, 78.9033054624285, 81.0892643247332, 77.21792956760952, 73.2222567967006, 61.76309313092913, 61.24949618748256, 59.099431719098774, 57.782848834991455, 58.186893531254356, 64.29614925384521, 71.54333577837262, 70.90066909790039, 74.69566399710519, 74.88225092206682, 72.78972448621477, 69.49605601174491, 69.01383713313511, 71.19191673823765, 68.41904354095459, 65.45989608764648, 63.38401753561837, 65.97427817753383, 63.1242104939052, 70.9752093723842, 71.83774484906877, 69.12115206037248, 72.30352428981236, 67.094133240836, 68.16915157863072, 73.98136833735875, 62.52187810625349, 67.02520016261509, 68.569214957101, 64.4046940122332, 57.635661670139854, 60.33611379350935, 66.70085825238908, 64.39877414703369, 66.82302842821393, 67.40343924931118, 63.53852462768555, 66.82035337175641, 64.00198337009975, 69.19544219970703, 65.56213188171387, 58.73249735151018, 64.51401696886334, 66.31637273515973, 64.91892324175153, 61.61257430485317, 57.352442673274446, 62.101414816720144, 65.57891872950962, 65.30807100023542, 62.04890727996826, 59.06499644688198, 63.35997676849365, 65.8151227406093, 61.02158832550049, 62.819295746939524, 63.36076191493443, 62.86288179670061, 58.23004879270281, 59.07425839560372, 65.65392453329903, 62.121515955243794, 65.17560359409877, 62.4793620790754, 59.727896281651084, 59.876900400434224, 55.963487352643696, 57.43393462044852, 58.534591811043875, 59.34184741973877, 58.52232824053083, 56.57647132873535, 53.05608313424246, 52.388229233878, 53.25645875930786, 58.963316508701865, 61.603944642203196, 62.68730776650565, 66.439300264631, 68.35594000135148, 69.00200435093471, 69.42164775303432, 66.63386372157505, 65.42372376578194, 61.48955644880022, 63.97481591360909, 61.24778693062918, 61.34206703730992, 62.434921400887625, 61.993127141680034, 64.03300707680839, 65.69443253108433, 65.44547857557023, 73.69263594491142, 74.03903838566372, 84.11010483333042, 40.78443186623709, 0.6146012235965047, 4.6545374393463135, 7.175522369997842, 4.272706133978708, 10.006449937820435, 5.503574737480708, 4.93405956029892, 0.760533478643213, 0.226199405800019, 11.343467473983765, 59.810899462018696, 50.68873459952218, 53.018389156886506, 42.30748394557408, 73.27962112426758, 15.02017797742571, 0.48752952792814797, 0.13292258099785872, 0.3399785597409521, 0.18629871042711393, 0.17539675613599165, 0.1866877009826047, 0.2212765392448221, 0.27618011885455673, 0.09250847210309335, 0.19311739025371416, 0.16802076835717472, 0.23308386281132698], [0.004847614053038082, 0.024080500439075486, 0.02823283619779561, 0.06959269568324089, 0.08157594980938093, 0.06452351662197284, 0.12550904309110983, 0.04494200360828212, 0.05020040233752557, 0.08371827485305922, 0.029737194135252918, 0.17021136438207968, 8.322983060564313, 54.30050202778408, 31.14831222806658, 28.939462525503977, 32.760964802333284, 58.08800676890782, 9.940409915787832, 0.08781489610139813, 0.10840132287038223, 1.7042025817292077, 0.3995486418051379, 1.0789060720375605, 2.7984694923673357, 0.4402703781213079, 0.05011907991554056, 29.264099734170095, 86.64528015681675, 80.56245190756661, 84.58563259669712, 79.15361431666783, 78.24186474936349, 65.76544312068394, 66.79929338182721, 59.7634710584368, 61.318311146327424, 61.29402024405343, 63.707838330950054, 60.865844454084126, 60.68605286734444, 60.61377770560128, 64.44147777557373, 66.56620216369629, 69.27288682120187, 70.71472835540771, 73.57603127615792, 75.33079883030483, 72.5681186403547, 70.4319714137486, 66.86042363303048, 59.754445348467144, 53.612887450626914, 54.62103632518223, 52.37993655885969, 53.51751300266811, 53.12301165716988, 61.5321558543614, 66.28470979418073, 68.69967433384487, 67.5875804083688, 64.1598117010934, 66.0458654676165, 62.61174610682896, 63.31964247567313, 62.97715881892613, 63.4380328314645, 59.09847286769322, 59.88131250653948, 62.39665767124721, 60.438627515520366, 66.13479546138218, 65.29086726052421, 60.71588148389544, 62.41750226702009, 64.16705172402519, 53.64045442853655, 60.21138668060303, 63.02103669302804, 60.940155438014436, 57.52572727203369, 60.807291984558105, 63.383329663957866, 64.9764404296875, 59.48099899291992, 61.11309610094343, 60.49913937704903, 59.946771485464915, 61.593480655125205, 60.670176233564106, 56.72842148372105, 58.39317512512207, 60.69557884761265, 60.77628217424665, 62.64345073699951, 60.171114921569824, 60.164590563092915, 59.29147297995431, 59.95594310760498, 57.505535806928364, 60.06024251665388, 58.978435788835796, 57.55179691314697, 55.19768817084176, 59.361642837524414, 57.39647340774536, 52.68913834435599, 54.634477615356445, 56.61610732759748, 52.57972853524344, 50.47064106804984, 55.23696286337716, 60.82940115247454, 58.8493104662214, 56.29765054157802, 54.48274632862636, 54.603186403002056, 52.18081855773926, 50.502856390816824, 51.18210881096976, 50.50462123325893, 48.902349267687114, 47.4158308165414, 46.54188987186977, 46.11449922834124, 45.50954042162214, 51.752931118011475, 54.901354449135916, 57.83728102275303, 61.834736006600515, 60.946672848292756, 59.89365945543562, 61.77366134098598, 62.76439108167376, 57.424287046704976, 54.31108413423811, 54.019325801304404, 56.174434661865234, 53.740675245012554, 54.97764219556536, 57.822721072605674, 55.21213347571236, 52.7586863381522, 57.385224274226594, 60.50783157348633, 66.89071083068848, 67.31635052817208, 63.496606145586284, 3.2882725468703677, 0.9972398770706994, 2.158427276781627, 3.5441321432590485, 4.0412942085947305, 1.8190637954643794, 1.699030516403062, 0.4742624855467251, 0.1337776436869587, 1.4383009927613395, 27.903440952301025, 46.22163002831595, 45.30564900806972, 23.64229314667838, 57.05005707059588, 11.880167177745275, 0.2273596871112074, 0.10933641876493182, 0.04731407382392457, 0.06521246715315751, 0.09901170099952392, 0.022011877869122794, 0.008807692427321203, 0.05618928133377007, 0.02015393872612289, 0.07088257039764098, 0.006161102210171521, 0.01219735058423664, 0.003707675221708736, 0.0053998181496613794, 0.03007079926984651, 0.05787537978695972, 0.05799744145146438, 0.012214865269405501, 0.07408834980534655, 0.022152195518304194, 0.09901970771274396, 0.050525183124201636, 0.051292419633162875, 0.29311624435441835, 12.748858758381434, 64.74995694841657, 43.00582306725638, 31.912600176674978, 26.987532888139995, 72.4759577342442, 11.085774421691895, 0.11205036884972028, 0.28631944049681934, 1.3614020219870975, 1.2196517139673233, 3.26943467770304, 4.149717373507364, 0.2176452912390232, 0.04457726050168276, 33.456354413713726, 91.14094529833112, 84.32392869676862, 86.55181298937116, 82.94319656917027, 80.9319154194423, 69.67158835274833, 68.44923346383231, 61.6543607711792, 65.22982733590263, 65.30405494144985, 67.97096811022077, 64.47177192143032, 62.61387920379639, 63.91337994166783, 66.74957207271031, 69.25984505244664, 73.37747955322266, 73.37669440678188, 78.49691922324044, 77.34502601623535, 75.5991382598877, 73.26034682137626, 69.43024267469133, 61.282785006931846, 58.017628465379985, 54.87076847893851, 54.63375500270298, 55.973645618983674, 55.90546294621059, 64.09676374707902, 68.89550236293248, 71.20987088339669, 69.69648374829973, 68.67362553732735, 68.20284339359829, 65.17859826769147, 65.63097463335309, 65.09446947915214, 66.15352780478341, 61.09541988372803, 66.71431691305978, 66.08977113451276, 62.70673492976597, 67.77551528385708, 67.76992198399135, 60.66584055764334, 65.68288462502616, 65.23425333840507, 56.74122701372419, 64.54177502223423, 65.04072516305106, 61.29330457959856, 57.7435428755624, 63.94263880593436, 66.13244002205985, 68.03839342934745, 62.272944995335166, 61.53318418775286, 62.31177152906145, 62.44790758405413, 61.342914717538015, 59.83267511640276, 57.7761994089399, 59.84645339420864, 62.46258912767683, 61.35171113695417, 63.899476596287315, 62.75594902038574, 63.22343076978411, 64.44106088365827, 61.125158173697336, 60.25020626613072, 60.148700032915386, 62.77858625139509, 60.09030737195696, 57.997711454119, 59.27216393607003, 58.427367210388184, 55.95567062922886, 56.646960803440635, 57.87426975795201, 55.938439096723286, 52.99659265790667, 56.35316317422049, 61.76703970772879, 62.034329959324424, 60.45531708853585, 58.05135154724121, 57.68733889716012, 55.66330780301775, 54.250565324510845, 53.97011865888323, 55.4535243170602, 51.56342247554234, 51.50291061401367, 50.589535168239046, 48.69656794411795, 50.12769535609654, 54.84273944582258, 57.64681700297764, 61.037193979535786, 63.11205809456961, 64.51021630423409, 63.28693035670689, 64.4947635105678, 64.13423538208008, 61.28618267604283, 57.37152937480381, 57.780017444065635, 58.684304646083284, 56.33217961447579, 56.8327556337629, 60.281167439052034, 59.86037758418492, 56.40590000152588, 59.74683707101004, 65.35492965153286, 71.72954055241176, 70.51516914367676, 71.43470069340297, 4.895933057580676, 0.544191273195403, 0.9577934337513787, 3.3735130471842627, 2.4735104952539717, 2.076841963188989, 1.4175401010683604, 0.6008173003792763, 0.05074871630807008, 1.2791994043758936, 35.213856084006174, 51.57921225684029, 38.23596463884626, 26.716606991631643, 64.47734437670026, 14.875893422535487, 0.2211219553968736, 0.10109240827815873, 0.04931356046082718, 0.0420163268489497, 0.07706357658441577, 0.0381660036343549, 0.07267289182969502, 0.005188840832228639, 0.04469436886055129, 0.08779361045786313, 0.027283066983467767, 0.0414933120565755, 0.13013316424829618, 0.11993540717022759, 0.11729142761656217, 0.15752464586070605, 0.21385289116629533, 0.11137293984315225, 0.37366073951125145, 0.17691966013184615, 0.15213299303182534, 0.15326265884297235, 0.149369889870286, 0.6087685365762029, 16.115323509488785, 79.59213597433907, 43.39524875368391, 39.95527900968279, 43.723829065050396, 85.16837106432233, 16.968397276742117, 0.2691858613065311, 0.5585136275206293, 4.823294418198722, 3.4600756594112942, 4.217539174216134, 5.963119472776141, 1.7653155710015977, 0.1696193018662078, 38.10039486203875, 93.78513090951103, 88.34555993761334, 90.94511032104492, 86.53435911451066, 87.23903151920864, 72.92137895311627, 73.74963896615165, 63.93482208251953, 69.58067117418561, 69.36805629730225, 71.40852682931083, 68.21100057874406, 67.20019054412842, 66.99695573534284, 71.29589653015137, 72.5367544719151, 77.57629680633545, 76.43993282318115, 82.13503074645996, 80.75397900172642, 79.3057381766183, 77.14591148921421, 72.39635222298759, 64.79607909066337, 60.68926293509347, 59.771315574645996, 58.12450565610613, 59.46419130052839, 58.36646624973842, 66.75793770381382, 72.9913890021188, 74.16758700779506, 72.09796183449882, 69.45072596413749, 71.10912200382778, 70.18102332523891, 69.29221670968192, 70.45872892652238, 71.98285797664097, 66.16035788399833, 70.02527945382255, 67.52975749969482, 65.51718398502895, 71.79190758296421, 71.89381681169782, 63.830842290605815, 66.91763510022844, 69.01926367623466, 61.004433223179404, 65.73051452636719, 67.91831466129848, 63.998495374407085, 61.44286455426897, 65.49418544769287, 68.57310594831193, 69.25567613329206, 65.20236805507115, 66.55549498966762, 64.86654772077287, 63.76810700552804, 66.27749061584473, 62.518452644348145, 60.227548190525596, 61.39921597072056, 65.81173201969692, 65.98962674822126, 67.60192149026054, 63.479061944144114, 65.27390670776367, 65.96688529423305, 62.95049163273403, 62.65082972390311, 64.14642252240861, 64.94875880650112, 63.12243175506592, 60.35104547228132, 65.07623740604946, 61.17270469665527, 57.43563345500401, 59.96551077706473, 62.02541542053223, 58.00045599256243, 54.38448143005371, 61.79971708570208, 64.81012140001569, 67.29039900643485, 61.630945341927664, 60.29175649370466, 60.51901817321777, 58.87679753984724, 54.90344933101109, 57.549688134874614, 57.83098248073033, 54.93849604470389, 55.91268212454659, 55.05279391152518, 52.475606305258616, 53.751875741141184, 59.748289244515554, 62.17836611611502, 66.11180387224469, 68.71635001046317, 67.90293134961809, 67.61729785374233, 67.36552987779889, 68.66202204568046, 63.67969812665667, 60.74966362544468, 61.19953863961356, 63.32948807307652, 60.67725644792829, 60.5508200781686, 63.805217334202354, 61.95291791643415, 60.87047890254429, 64.5421849659511, 68.64152485983712, 75.9330061503819, 76.800509589059, 73.59269305637905, 4.606757283210754, 3.0278427728584836, 6.6647980724062235, 8.016371216092791, 9.713751861027308, 6.677141981465476, 4.418498882225581, 1.5782314155782973, 0.1917005412812744, 3.1901275047234128, 44.622481278010774, 61.33051218305315, 63.66066006251744, 33.06890548978533, 77.67623274666923, 17.87998182432992, 0.3835609182715416, 0.25640266867620604, 0.12667271707739147, 0.10136034140097243, 0.16719490981527738, 0.15036283087517532, 0.1680135623152767, 0.10464877315929957, 0.12790237180888653, 0.15978076122701168, 0.10150320694914886, 0.08261957738016333], [0.020850719551422765, 0.047828800311045985, 0.021524570982104967, 0.04036444013140031, 0.09289512171276978, 0.06302239360021693, 0.05111475202387997, 0.0165881846166615, 0.05235681716086609, 0.018826003286189268, 0.041303949896246195, 0.21122508788747446, 20.929438488824026, 58.886406898498535, 33.06450380597796, 51.55709266662598, 35.02720662525722, 49.66991329193115, 2.2925728900091986, 0.04346305850361075, 0.643226119024413, 1.1504280056272234, 0.5108924114278385, 1.092936439173562, 2.562977020229612, 0.5129409357905388, 0.5005241792116846, 41.08769294193813, 87.6041385105678, 78.64693777901786, 84.65762983049665, 79.38485731397355, 74.77679811205182, 63.92072418757847, 64.40119212014335, 64.60375295366559, 63.202648707798545, 59.272400174822124, 56.92306137084961, 56.3944319997515, 56.885711329323904, 60.57337393079485, 65.46576731545585, 65.60842078072685, 69.30759307316372, 71.27391937800816, 70.11883694784981, 71.17859009334019, 74.31862000056675, 70.42249407087053, 69.13161604745048, 64.15076514652797, 54.7880744934082, 52.756115504673545, 54.1299341746739, 52.557959829057964, 52.21566724777222, 56.44209664208548, 63.98334830147879, 67.37568119594029, 68.05790397099086, 66.34597206115723, 65.92245156424386, 60.45339938572475, 61.11668831961495, 62.99030481066023, 60.54661641802107, 61.71720722743443, 62.29819474901472, 63.8192457471575, 56.0003788130624, 61.934491293770925, 62.16438634055001, 62.27025604248047, 64.6735406603132, 52.67814629418509, 62.687780244009836, 61.626693044389995, 58.73710400717599, 60.06794112069266, 63.25203650338309, 64.39495263780866, 54.819007873535156, 58.30355725969587, 59.58658381870815, 58.59832068852016, 56.501851149967735, 56.31517389842442, 54.87004239218575, 55.47371925626482, 55.80301523208618, 57.251572200230186, 59.4933112008231, 55.67892387935093, 53.26350770677839, 56.61989756992885, 58.49985776628767, 60.1117217200143, 59.93792642865862, 62.48708152770996, 59.06571211133684, 56.50303929192679, 61.17972237723214, 59.359252657209126, 54.30841602597918, 55.74600178854806, 61.743214334760395, 55.1464695249285, 54.51591008050101, 57.719418730054585, 57.9615877696446, 53.69566828863961, 51.27842473983765, 59.18378284999302, 58.06905208315168, 56.76686586652483, 56.59202834538051, 52.97728361402239, 53.065904412950786, 51.692801407405305, 51.000535011291504, 49.78292226791382, 47.94725683757237, 46.82158613204956, 44.42345012937273, 45.77328014373779, 49.79368850163051, 53.964848450251985, 57.52630744661604, 59.54829229627337, 61.61290781838553, 61.161712646484375, 62.7662809916905, 57.55990546090262, 56.21338626316616, 55.09863117762974, 53.13461514881679, 52.15934862409319, 52.468196051461355, 55.57951947620937, 55.85509198052542, 55.95545176097325, 54.36546768460955, 53.449010712759836, 57.025727953229634, 66.73185416630336, 65.10807405199323, 71.79638222285679, 24.447518144335064, 0.4430667837815625, 0.7705351933836937, 1.4942380083458764, 0.9308889231511525, 1.0213484976972853, 0.2239535634538957, 0.2898300178349018, 0.09089254774153233, 0.12750430245484623, 22.678822926112584, 37.33924055099487, 53.38658114842006, 27.86277140889849, 50.48994663783482, 15.569193363189697, 0.10574812881116356, 0.0647425137992416, 0.08560644782015256, 0.045604392886161804, 0.007263311949957694, 0.04889682460842388, 0.04669096493827445, 0.059320442245474884, 0.024146935802751353, 0.030466480180621147, 0.08548740563648087, 0.0699924070920263, 0.031076211748378615, 0.06023185048252344, 0.015752222688336457, 0.03277530414717538, 0.017875082258667265, 0.02501532661595515, 0.01174456755896764, 0.028637010670666183, 0.07760235374527318, 0.01606122075047876, 0.02729728738112109, 0.21728136576712132, 27.47997256687709, 69.87460776737758, 39.27902473722185, 38.68026024954659, 34.51807042530605, 59.389248030526296, 3.500228864806039, 0.16992275629724773, 1.3822347841092517, 1.738334413085665, 1.2622661015817096, 1.6032504673515047, 3.8484678012984137, 0.11708656432373182, 0.634582342846053, 46.51840148653303, 88.54336820329938, 83.42185797010148, 88.30757413591657, 83.15347685132707, 77.49975545065743, 67.16541481018066, 66.4386818749564, 66.60916287558419, 66.67560155051095, 63.62230600629534, 58.65246105194092, 59.87400300162179, 58.36669554029192, 64.39390345982143, 66.48820168631417, 71.09558691297258, 73.1208895274571, 73.92334393092564, 74.30696787152971, 72.73737675803048, 74.58816841670445, 72.61188534327916, 71.63668482644218, 68.05187293461391, 59.567302567618235, 54.51334619522095, 56.12945897238595, 55.56444535936628, 54.483382088797434, 59.42947810036795, 65.92102718353271, 68.92112037113735, 70.11887863704136, 69.14849322182792, 69.45806326184953, 66.08705438886369, 64.74372441428048, 63.784331049237935, 64.4579519544329, 64.5044492994036, 65.52801622663225, 64.91801302773612, 60.75402709415981, 63.44965716770717, 63.451672145298545, 64.82740156991142, 65.07966981615338, 56.48521716254098, 66.7058470589774, 63.97365556444441, 58.373824392046245, 63.065901211329866, 64.75812802995954, 64.6577057157244, 55.69092689241682, 57.4719933782305, 61.072463035583496, 59.46686635698591, 58.852541378566194, 58.97193227495466, 56.35128368650164, 57.1617875780378, 56.69890901020595, 60.51111807141985, 59.666766030447825, 56.246810572487966, 53.42222540719168, 55.56548064095633, 61.13908931187221, 61.64886474609375, 61.74452059609549, 62.80551052093506, 60.420152255467, 58.03605508804321, 60.96464783804757, 61.091035570417134, 59.05616528647286, 58.60745756966727, 64.10189846583775, 58.4770815713065, 58.11594547544207, 62.13189656393868, 59.232302120753694, 58.355766023908345, 56.376800945826936, 59.610256331307546, 62.319532666887554, 58.615371567862375, 60.1920359475272, 57.72203125272478, 56.737978730882915, 54.71272822788784, 53.29353782108852, 54.32490062713623, 51.370933055877686, 47.64970023291451, 47.450922693525044, 48.532065868377686, 53.15391377040318, 57.53485025678362, 59.93158272334507, 61.65933568137032, 64.48409107753209, 63.155588558741975, 64.04362392425537, 60.04188537597656, 58.80498095921108, 56.84109694617135, 55.68375982557024, 53.46180929456438, 55.4515996660505, 58.525461878095356, 58.476171357291086, 58.81485434940883, 56.782759870801655, 57.68480280467442, 60.56785011291504, 70.30604921068463, 70.82428755078996, 74.88384205954415, 29.953843934195383, 0.3680361456104687, 0.3097624182701111, 1.9194867610931396, 1.6361037216016223, 2.743766324860709, 1.4925145293985094, 0.38209606973188265, 0.04838146369106003, 0.14182464831641742, 23.754332848957606, 46.7961175101144, 46.53382996150425, 32.145816462380544, 60.557115146092, 18.74248082297189, 0.2009147482791117, 0.10619895426290375, 0.054918693977275064, 0.033235849613057714, 0.04593671219689505, 0.03673777902232749, 0.1279750700507845, 0.0088938299034323, 0.013831006762172495, 0.06256197366331305, 0.05019846851272242, 0.0729280820648585, 0.07513187559587614, 0.1440601905009576, 0.13494806231132575, 0.08353960979729891, 0.1203618800001485, 0.10167258286050387, 0.08120056388101407, 0.14882084647459642, 0.17276663226740702, 0.09085906203836203, 0.12512130104005337, 0.31784648448228836, 32.07731417247227, 83.73661136627197, 43.02486113139561, 64.30782917567662, 49.97748225075858, 73.07148783547538, 6.264319973332541, 0.17399758978613786, 2.8248750354562486, 4.261547761304038, 2.703224454607282, 4.928674706390925, 6.949513537543161, 1.362561502626964, 0.9179633195911134, 48.956545216696604, 93.87256009238106, 87.48110675811768, 91.52511814662388, 86.32903984614781, 82.04712908608573, 69.84411212376186, 70.35909175872803, 70.29895509992326, 70.22921603066581, 66.79409612928117, 63.02906881059919, 62.98494774954659, 62.463749476841514, 67.50166593279157, 70.94986234392438, 73.35502297537667, 77.41018622262138, 75.66035188947404, 79.2145917075021, 76.31547669001988, 76.27259240831647, 76.17053031921387, 76.72070258004325, 70.3522616795131, 61.454391615731375, 58.61391939435686, 58.81911359514509, 58.80336897713797, 57.19121667316982, 63.73897320883614, 69.46491418566022, 73.01285198756626, 71.34694494519914, 72.4014105115618, 70.22882693154472, 69.77969537462506, 66.34117780412946, 67.62865121023995, 66.62646389007568, 67.06481184278215, 69.58320031847272, 68.38992364065987, 64.22748020717076, 67.8580459867205, 66.07003825051444, 66.3241616657802, 71.19589110783168, 57.426583426339285, 69.17627906799316, 67.82856478009904, 60.58137130737305, 63.64975833892822, 71.34076104845319, 70.23922143663678, 60.05053588322231, 63.97134181431362, 64.34468936920166, 62.183660643441335, 58.184597151620046, 61.902230807713096, 59.011801038469585, 59.16518947056362, 57.39310005732945, 61.18860217503139, 64.79188932691301, 59.450996671404155, 57.12740789140974, 59.772858074733186, 63.6045047215053, 63.79086235591343, 63.48612131391253, 68.51691586630685, 62.25732544490269, 60.736656597682405, 65.51266070774624, 62.9548898424421, 59.40707015991211, 60.300136021205354, 66.61516611916679, 61.97759791782924, 61.25957802363804, 62.66671330588204, 62.15222699301583, 60.45339938572475, 61.589450699942454, 62.686265536717, 65.49317101069859, 64.29483604431152, 63.442625590733115, 60.86459377833775, 61.29758466993059, 58.12612458637783, 58.24752698625837, 57.51306765420096, 55.13875355039324, 52.310920102255686, 50.16818598338536, 51.95367152350289, 56.70488098689488, 59.96867915562221, 63.664217540196006, 65.51263986315045, 67.23843342917306, 65.72345515659877, 68.80252851758684, 62.231707436697825, 62.41482721056257, 59.9905937739781, 59.00317137581961, 57.43864549909319, 58.63531289781843, 61.82054778507778, 60.79470879690987, 62.05393082754952, 60.939752442496165, 60.48773043496268, 64.06084850856236, 74.96255125318254, 74.87706756591797, 80.89516639709473, 33.089010102408274, 0.8311030747635024, 2.690295159816742, 6.489092026438032, 3.823659258229392, 2.929169233356203, 2.639433260474886, 0.592145677123751, 0.3865107814116137, 0.17714087611862592, 34.30330508095877, 51.18998111997332, 67.81074959891183, 41.594977446964805, 65.81676251547677, 23.692594630377634, 0.4190352718744959, 0.31969253399542397, 0.21774899853127344, 0.19006186564053806, 0.15694823036236422, 0.14119097803320202, 0.19007629129503453, 0.12536148886595452, 0.12336062480296407, 0.11487827210554055, 0.15233653996671948, 0.1573276807154928], [0.04953949226598654, 0.010556616437887507, 0.11644971849662916, 0.034809368928628306, 0.027448978973552585, 0.016498662098976116, 0.03790942918775337, 0.08782004618218966, 0.0471367963722774, 0.0620787413790822, 0.02921529553298439, 0.043416205660573075, 35.21697929927281, 45.61442000525338, 35.3171306337629, 39.0715445790972, 39.36323690414429, 35.49778727122715, 0.5811559611133167, 0.05803380414311375, 0.5154171543461936, 0.544441896889891, 0.3034737557172775, 3.317129067012242, 3.779309775148119, 0.26945130420582636, 1.5723832036767686, 57.164268084934776, 83.43884631565639, 81.96896185193742, 80.89997455051967, 79.97254984719413, 76.0452265058245, 65.42022882189069, 60.73261274610247, 66.3550672531128, 66.93990407671247, 67.4921885899135, 59.23656136648995, 56.19854143687657, 53.83844334738595, 58.21964039121355, 61.10753754207066, 65.5503477369036, 68.34088325500488, 71.487562588283, 71.26904174259731, 69.87357248578752, 70.25823170798165, 72.72288281576974, 70.3927835736956, 69.26715455736432, 59.485529218401226, 53.58203050068447, 52.73488180977957, 52.39103283200945, 50.98778854097639, 57.011157580784385, 61.767130034310476, 63.84444686344692, 67.7339928490775, 64.22069181714738, 65.28393295833042, 61.89804799216134, 59.24563571384975, 62.996724946158274, 62.96464511326381, 63.37639536176409, 63.08675275530134, 64.5715480531965, 55.994716031210764, 58.2247542653765, 62.6094115121024, 63.92439978463309, 56.855597836630686, 63.615038190569194, 61.61792441776821, 56.5469970703125, 64.93976088932583, 64.28059918539864, 54.508482456207275, 49.75068262645176, 50.71032612664359, 52.269182273319785, 51.42197799682617, 55.10507910592215, 60.027301107134136, 56.22125162397112, 54.57964938027518, 55.43999964850289, 56.81897040775844, 58.8061968939645, 51.83067103794643, 48.39511340005057, 52.3580184664045, 50.610963412693565, 47.51142760685512, 53.14113255909511, 58.13380234582083, 59.21744687216622, 59.50019686562674, 56.70050362178257, 51.48155532564436, 55.74246168136597, 59.10189832959856, 56.34520401273455, 54.893284116472515, 56.22610494068691, 56.27724368231637, 50.56909704208374, 53.33988925388881, 57.18199641363961, 58.04539346694946, 49.8767785344805, 60.57374218532017, 57.449095589774, 57.79770755767822, 55.121469906398225, 52.945474760872976, 51.204023429325645, 51.46076284136091, 48.66300467082432, 45.532076903751914, 43.84265715735299, 43.92464590072632, 44.60067088263375, 50.16862371989659, 53.52434308188302, 57.32774182728359, 58.96897234235491, 62.135363715035574, 60.543698174612864, 61.14101396288191, 58.11137008666992, 57.08197362082345, 52.71873072215489, 52.72290658950806, 49.42552430289132, 50.817147731781006, 52.35906764439174, 60.21638938358852, 55.211501189640586, 55.19207750047956, 50.21885919570923, 63.849261965070454, 61.269236019679475, 69.2835384096418, 63.821357999529155, 53.05119507653372, 2.24535380090986, 0.7713215883289064, 1.9720492320401328, 0.9181450584105083, 0.44744062051177025, 0.23543517664074898, 0.8376643455454281, 0.1740798960838999, 0.5307193132383483, 10.270763754844666, 39.79226732254028, 44.97995914731707, 27.509608370917185, 47.689836502075195, 23.09381624630519, 0.4182524595941816, 0.2606879701571805, 0.08634162694215775, 0.06992634492261068, 0.042291167458253245, 0.019015811583293334, 0.011256598252137857, 0.05679572879203728, 0.04179507354274392, 0.03465797080259238, 0.009887240793822067, 0.06340738758444786, 0.02356574511421578, 0.02768773169788931, 0.0672574902751616, 0.03343601065820881, 0.04523977870121598, 0.04823481870282974, 0.053960307368210385, 0.021011956435229098, 0.0674187441223434, 0.036490079813769886, 0.06313532218337059, 0.04376402610380735, 44.45003046308245, 53.35115575790405, 42.29622091565813, 37.568336554935996, 44.38291086469378, 43.60206535884312, 0.2550884277692863, 0.038581680972129107, 2.1630636794226508, 1.0926983548062188, 1.6525229662656784, 1.5282888497625078, 0.7289344828043665, 0.23070481047034264, 2.0942059457302094, 63.63962091718401, 87.25215666634696, 85.54511628832135, 82.73537594931466, 84.0662408556257, 79.29494067600795, 67.7753415788923, 63.26477255140032, 69.54959883008684, 68.3880615234375, 70.34701578957694, 62.13201468331473, 58.73783356802804, 56.8528915132795, 61.042370387486045, 63.931361879621235, 67.02160099574498, 71.46713488442558, 73.80598885672433, 74.79777472359794, 73.38554641178676, 72.18401527404785, 74.4049652644566, 72.55153329031808, 72.56861196245465, 62.82233905792236, 55.65402848379952, 55.08042342322213, 55.75890459333147, 52.87485327039446, 60.592814990452354, 64.88971996307373, 66.0520076751709, 71.48167746407645, 67.8189137322562, 67.03389930725098, 66.115416935512, 60.55075059618269, 66.30633953639439, 67.32329177856445, 66.9053645815168, 66.8156772341047, 66.65269333975655, 58.76238850184849, 63.47636604309082, 66.27475997379848, 64.49855722699846, 60.011306353977744, 66.47960676465715, 61.65311009543282, 59.27208055768694, 68.10249750954765, 63.869696617126465, 55.021645137241904, 51.02068131310599, 55.56539031437465, 54.705359663282124, 53.32393271582467, 56.715219906398225, 62.4347893851144, 59.01899937220982, 56.82711717060634, 56.937857559749055, 59.63471399034773, 60.634768213544575, 55.042166641780305, 50.62493276596069, 57.0008499281747, 55.343749727521626, 51.399031570979524, 53.661938258579795, 60.125083105904714, 62.924060685294016, 60.93666049412319, 59.09271281106131, 54.35249539784023, 56.54036848885672, 62.89947101048061, 59.20185511452811, 56.44978134972708, 54.819171156202046, 57.692303385053364, 53.57348074231829, 56.01368113926479, 56.28787095206124, 64.36359541756767, 54.84796101706368, 61.23197977883475, 61.87668922969273, 57.86826304027012, 57.50441714695522, 57.32685593196324, 55.63714436122349, 52.13991798673357, 49.65105588095528, 48.53239243371146, 46.94592761993408, 46.07571785790579, 48.77146257672991, 52.40941776548113, 56.05915362494332, 61.79942526136126, 61.08558818272182, 64.70423780168805, 62.19773769378662, 63.17695426940918, 60.32571234021868, 58.53958061763218, 53.283886773245676, 54.87658412115914, 52.82764026096889, 54.924936635153635, 56.03894131524222, 62.78299835750035, 58.771747725350515, 57.24242489678519, 53.82347692762102, 67.85184819357735, 64.41316386631557, 74.26875972747803, 66.92085211617606, 61.12408120291573, 3.2323428051812306, 1.3020191341638565, 0.37122984709484236, 1.3267668804952075, 2.5244436136313846, 0.6281447825687272, 0.9243689072983605, 0.2601126810269696, 0.5398493547524724, 9.610470363071986, 49.302940709250315, 47.244474342891145, 29.458062171936035, 57.095060552869526, 27.525172335760935, 0.3670523783990315, 0.1660964023321867, 0.08164402722780194, 0.03543518177632775, 0.011309350108993905, 0.015722131356596947, 0.043168201111257076, 0.07198516266154391, 0.018209659394675067, 0.09053231350013188, 0.020818589221952215, 0.0701896572219474, 0.1513760465064219, 0.13361807939197334, 0.1705491119729621, 0.09340646570282322, 0.1542953619999545, 0.10512660430478198, 0.13122413999267987, 0.10657222994736262, 0.21170441859534808, 0.09623772092163563, 0.22694063745439053, 0.20932552910276822, 52.40964705603463, 63.13663387298584, 49.59305231911795, 55.149846349443706, 54.651660510471885, 55.97850588389805, 1.1389985446419035, 0.08329157132123198, 2.6916127119745528, 1.3509074194090707, 3.578275156872613, 5.770022085734776, 8.124041369983129, 0.6506441895450864, 3.0793289244174957, 69.14037772587368, 90.39928763253349, 89.85434736524309, 86.3952214377267, 87.98972879137311, 82.71119621821812, 71.93200411115373, 66.38459014892578, 72.98370429447719, 71.92405537196568, 75.0884734562465, 65.01069504874093, 62.745610100882395, 59.932902881077354, 66.96254825592041, 68.11348955971854, 70.59066132136753, 72.43658229282924, 78.89450904301235, 78.2765223639352, 77.02669429779053, 73.9774078641619, 77.66699859074184, 76.26175321851457, 76.36232839311872, 64.30573081970215, 58.01950100490025, 58.755384717668804, 59.430819102696006, 54.76215423856463, 63.13810689108712, 68.24993133544922, 67.58448151179722, 73.22730118887765, 69.50228159768241, 69.21669673919678, 66.92422199249268, 65.11804471697126, 69.18550627572196, 70.62144878932408, 74.533326285226, 67.50100585392543, 71.98866667066301, 61.807158606392996, 65.40685353960309, 69.58073370797294, 70.2805562700544, 65.03981494903564, 70.34807886396135, 66.5532090323312, 59.710053307669504, 70.39866174970354, 69.38151495797294, 59.27677059173584, 55.085325377328054, 56.22514261518206, 57.40296997342791, 57.560888631003245, 60.086478914533345, 66.83154691968645, 60.107274872916086, 58.639843123299734, 58.73053795950753, 61.431650161743164, 63.96306650979178, 56.27101462227957, 52.82305792399815, 57.758676052093506, 55.71147966384888, 54.31506545203072, 58.52585097721645, 62.97836085728237, 65.12933553968156, 62.33498546055385, 58.79223796299526, 56.62974664143154, 58.86087226867676, 63.83436502729143, 61.704693521772114, 59.50851385934012, 58.32758413042341, 59.73555319649832, 54.75069318498884, 59.742577825273784, 59.116975920540945, 64.89305509839738, 58.88735185350691, 64.42278712136405, 64.89516735076904, 64.16871234348842, 59.99923733302525, 59.60112639835903, 58.685652596609934, 57.186745507376536, 53.470953123910085, 51.91879504067557, 50.533591747283936, 49.529924460819785, 52.264766693115234, 54.63310882023403, 58.761860438755576, 64.10107163020542, 62.90287562779018, 67.05148519788469, 64.65287671770368, 66.23920604160854, 62.013263021196636, 62.640254565647666, 57.720721517290386, 59.28295448848179, 56.3179531778608, 57.87852552958897, 58.6352573122297, 66.9972892488752, 61.547990798950195, 61.768123626708984, 57.09795100348336, 73.42442853110177, 66.33232579912458, 79.661374773298, 72.00721141270229, 66.62426131112235, 2.8069597567830766, 2.1099427470139096, 6.0388800246374945, 2.994525726352419, 1.7113433756998606, 1.2032206356525421, 2.175026088953018, 0.3928906390709536, 0.6042474848883492, 15.760536330086843, 58.872051920209614, 61.21729128701346, 37.938706806727815, 61.85184941973005, 34.420917238507954, 0.8595774982656751, 0.4855086877942085, 0.27712754373039516, 0.32337611062186106, 0.31065876302974565, 0.167678352445364, 0.1607754257108484, 0.18077832593449525, 0.22423700110188552, 0.1605522826846157, 0.09060601597385746, 0.25503398211938993], [0.03969496016257575, 0.029362351034900973, 0.06420134140976838, 0.005666722867837442, 0.02382781739080591, 0.06012481836868184, 0.07580927746104342, 0.03210490815607565, 0.031147641129791737, 0.02907799057928579, 0.12884548120200634, 0.8058113061955997, 47.71729230880737, 45.87054797581264, 37.63101972852434, 28.90357334273202, 48.71034969602312, 18.268377440316335, 0.16344178334942885, 0.1792579460889101, 0.7216215580701828, 1.186120901788984, 0.5589808938758714, 0.8573122769594193, 1.9617391909871782, 0.13538370893469878, 6.790718104158129, 65.35279655456543, 79.45718111310686, 81.83764089856828, 79.66860089983258, 81.3453471320016, 75.77842262813023, 67.66332272120884, 62.65795857565743, 69.51759542737688, 70.2797850200108, 73.0921448298863, 67.39406612941197, 57.277322224208284, 54.60387774876186, 56.040129457201274, 56.25175768988473, 60.75058078765869, 63.98906666891915, 68.34803295135498, 68.57646887642997, 68.59857109614781, 70.21390220097133, 70.57798085893903, 71.20181097303117, 69.61002731323242, 62.99153464181082, 53.77145229067121, 50.370534896850586, 51.876994677952354, 57.23495210920061, 58.58653654370989, 62.20148972102574, 64.49663952418736, 66.11627851213727, 64.826949937003, 60.776907512119834, 64.16377912248883, 62.32347229548863, 61.73880917685372, 63.4497127532959, 59.9553872517177, 61.656799588884624, 56.96063028063093, 58.59233134133475, 65.3023248400007, 60.751108850751606, 55.155377115522114, 65.39736230032784, 61.198781285967144, 55.56966693060738, 65.83582142421177, 63.02685233524868, 47.79795742034912, 53.38926315307617, 58.572973660060335, 63.23426301138741, 63.30033343178885, 56.34061820166451, 49.146046910967144, 54.847860268184114, 57.296009404318674, 56.77572134562901, 53.1186968258449, 54.48575837271554, 55.217452321733745, 48.31788764681135, 53.65253039768764, 59.61988653455462, 62.279427664620535, 59.319856371198384, 51.639772755759104, 49.44753967012678, 57.11247968673706, 59.120095661708284, 60.669238226754324, 57.72007533482143, 49.33178268160139, 53.80746132986886, 57.305160181862966, 58.26078414916992, 55.404681955065044, 52.40695115498134, 48.122275011880056, 55.63692201886858, 51.65232467651367, 59.32875006539481, 59.673721177237375, 50.13209356580462, 59.72684710366385, 56.74727889469692, 58.096476622990195, 56.51569890975952, 53.89869465146746, 49.91099146434239, 46.478154046194895, 45.92009210586548, 45.05957508087158, 44.52640158789498, 44.7350629397801, 50.515592438834055, 52.421340874263215, 57.84035907472883, 58.402867862156455, 59.86839580535889, 60.32190472739083, 60.906171798706055, 56.88205657686506, 55.09944411686489, 51.376710483006065, 50.79020609174456, 48.255781173706055, 50.14808137076241, 57.46779319218227, 58.38136318751744, 54.88681534358433, 54.18617984226772, 50.039171831948416, 64.44118595123291, 63.243406840733115, 68.47760990687779, 57.825535093035015, 62.68464660644531, 16.00147553852626, 0.6169635568346296, 0.9078024476766586, 0.5115395167044231, 2.121520617178508, 1.927246596132006, 0.2480710728892258, 0.2889932213085038, 0.0653478145333273, 1.5958294655595506, 42.82117468970162, 34.621591636112754, 37.85107612609863, 39.75816208975655, 32.561944075993125, 0.0764794529282621, 0.11226298779781375, 0.09504571809832539, 0.16860441703881535, 0.07163252801235233, 0.023334978747048547, 0.13068588530378683, 0.08428337238729, 0.025961243447714617, 0.02295275148935616, 0.03264652837866119, 0.06735253267522369, 0.019127043828900372, 0.028962690516241958, 0.023146624211221933, 0.04299430615667786, 0.04472720656277878, 0.03449116314628294, 0.010705460727746998, 0.043150070655558787, 0.010572318586387804, 0.07434493782264845, 0.0555920483810561, 1.638498461672238, 60.12250532422747, 53.315243993486675, 44.81495680127825, 22.767403772899083, 54.503233092171804, 23.827320201056345, 0.1177344024181366, 0.2331778263407094, 1.761373445391655, 1.5754441022872925, 1.0012066470725196, 0.9316797150032861, 1.1123740247317722, 0.2534483000636101, 7.661376459257943, 69.80733530861991, 81.51496655600411, 86.75834124428886, 82.90063190460205, 84.80988570622036, 78.91088594709123, 68.56413582393101, 64.75080462864467, 72.79441452026367, 74.96432304382324, 76.63640008653913, 71.63864421844482, 61.31038325173514, 57.07675552368164, 58.61513532911028, 59.50649193355015, 63.354842049734934, 65.61468110765729, 69.7253326688494, 71.12798636300224, 72.35338456290108, 72.51641014644078, 71.46705150604248, 72.31506524767194, 73.17087486812046, 66.77427986689976, 55.06410905293056, 52.100448744637625, 53.57083347865513, 60.15118748801095, 61.45462090628487, 64.18196255820138, 66.98493535178048, 68.21463448660714, 67.51306097848075, 64.53175571986607, 65.16266604832241, 64.83595480237688, 65.01311997004917, 66.3308458328247, 64.7178076335362, 63.76883656638009, 61.39897278376988, 64.77233014787946, 69.3160629272461, 62.34254510062081, 59.630183764866416, 70.02357019696916, 61.605778966631206, 59.345529964991975, 68.77076830182756, 63.15118340083531, 49.71741812569754, 55.70285694939749, 62.97199630737305, 64.14424773624965, 65.83386203220913, 60.42156968797956, 50.46975517272949, 56.005735874176025, 60.66335310254778, 58.132374491010395, 56.555901186806814, 57.041173798697336, 56.523849146706716, 49.73740809304373, 57.18726314817156, 62.29545715876988, 65.16802310943604, 62.057022775922505, 54.91259663445609, 50.76369524002075, 56.51249231610979, 59.50373349870954, 61.254797663007466, 60.52092892783028, 53.504259313855854, 57.02258389336722, 58.974586486816406, 61.37242371695382, 58.288090569632395, 55.96279600688389, 52.475752217429026, 58.1109254019601, 55.63919407980782, 57.96071229662214, 65.58050986698696, 54.93683542524065, 59.88090256282261, 60.37118135179792, 60.180522782461985, 59.11633668627058, 58.41410309927804, 54.39128024237496, 50.21492651530674, 49.14138119561331, 48.18984624317714, 46.55018949508667, 46.28579664230347, 52.72110005787441, 54.21762391499111, 61.207959856305806, 61.573337827410015, 62.425061907087056, 61.7883289882115, 62.835888045174734, 59.18765994480678, 57.444652216775076, 53.87997620446341, 53.79926940373012, 50.09130416597639, 54.12426791872297, 61.247849464416504, 61.069058418273926, 59.61833013807024, 56.86378976276943, 54.03295816693987, 67.61494936261857, 66.58945778438023, 72.96123382023403, 61.98617199489048, 67.28516006469727, 20.71430836405073, 1.2351854975734438, 0.5101012938788959, 1.7346103957721164, 2.3211230380194525, 1.1139013256345476, 0.6800598225423268, 0.2566739469766617, 0.04861213845599975, 0.9066929072141647, 46.57674898420061, 38.6773350579398, 34.62283188956124, 48.63910286767142, 41.14396640232631, 0.07624005220298256, 0.05236739891448191, 0.1202874311379024, 0.08294080942869186, 0.14927467783646925, 0.06347618424998862, 0.018745147357029573, 0.024827467410692146, 0.026703850831836462, 0.0380507341053869, 0.0550847484597138, 0.08464645647576877, 0.10900625719555787, 0.09380473183201891, 0.1278234174741166, 0.14654037170112133, 0.12399225948112351, 0.11897563295704977, 0.13942872759486946, 0.12520796353263514, 0.10546928484524999, 0.1552099457808903, 0.21524310085390294, 2.1295410096645355, 70.43809972490583, 60.54378850119454, 50.890447752816335, 40.83672400883266, 70.14845711844308, 33.21821532930647, 0.34533304242151125, 0.3578652856605393, 3.789277834551675, 4.1191014392035346, 2.5268435648509433, 1.1244501024484634, 3.8690748555319647, 0.6667330690792629, 9.967244727270943, 75.64866501944405, 85.80807781219482, 92.19374329703194, 86.49987520490373, 91.11404187338692, 83.8342752456665, 72.83955696650914, 69.1748685836792, 76.20495169503349, 78.17150729043144, 78.6931710924421, 73.76710673740932, 64.32623495374406, 60.869693756103516, 60.938397543770925, 62.99671104976109, 67.63844817025321, 70.5346588407244, 75.50196075439453, 76.27045236315045, 75.64742129189628, 76.64532157352993, 74.79068756103516, 76.11782823290143, 76.31082139696393, 69.67507634844098, 59.17178331102644, 54.65412017277309, 56.46485199247088, 61.59443255833217, 64.37154415675572, 67.05107525416783, 70.08909170968192, 70.4579576764788, 68.79832485743931, 67.92811856951032, 69.58373532976422, 68.68178967067173, 69.81193501608712, 69.18411663600376, 67.26974896022251, 67.75834628513881, 63.787124225071494, 64.19868687220982, 71.06185340881348, 66.16119166782924, 63.02684538705008, 71.0018835067749, 67.63690567016602, 59.979504449026926, 70.63742269788469, 70.72199617113385, 52.39262396948678, 58.60451848166329, 63.54405539376395, 64.20594079153878, 68.2670100075858, 60.8381141935076, 54.84235034670149, 59.78235626220703, 62.77939919063023, 61.384777614048545, 57.47564465659005, 58.17889615467617, 60.943414143153596, 54.23123543603079, 56.21384137017386, 65.08374840872628, 67.47070475987026, 63.268628801618306, 55.958891119275776, 54.47562442507063, 63.54361765725272, 63.33137103489467, 63.987475531441824, 60.19606590270996, 53.856595516204834, 59.037613596235005, 61.94838074275425, 62.23165185110909, 60.22280951908657, 56.95569358553205, 54.12787055969238, 59.59149619511196, 60.66456208910261, 60.51748956952776, 64.86138520921979, 58.67830835069929, 62.41440337044852, 62.01124109540667, 64.69742161887032, 62.320470673697336, 61.651956694466726, 57.91395786830357, 52.857225690569194, 53.345694473811555, 51.95909111840384, 49.754038606371196, 49.39569916043963, 58.19799675260271, 58.46910503932408, 63.667434556143625, 64.37877723148891, 64.83928993770054, 64.93499442509243, 65.06667668478829, 63.166281836373464, 59.82971518380301, 58.239401068006245, 57.88608169555664, 53.5753150667463, 56.78038706098284, 64.92446095602853, 63.57728862762451, 62.68432004111153, 60.767867905753, 56.78182881219046, 73.22060312543596, 70.2113035746983, 78.69557516915458, 65.27352455684117, 74.0124545778547, 20.47856640815735, 1.5658644906112125, 4.143734105995723, 4.610902752195086, 7.649248378617423, 3.8977835093225752, 1.598960823246411, 0.6744746650968279, 0.1301558951714209, 2.4707247018814087, 54.29023606436593, 47.43459095273699, 50.32833848680769, 53.1799521446228, 46.930221217019216, 0.2154331856540271, 0.2654012643865177, 0.24979658744164876, 0.21769310081643717, 0.2838235987084252, 0.14346723231886113, 0.22767626440950803, 0.2463023763682161, 0.0949172917753458, 0.15348158138138907, 0.1753881794533559, 0.19359701951699598], [0.03141192373420511, 0.025882511333163296, 0.049651515004890304, 0.09249572921544313, 0.051008866634219885, 0.07690361873911959, 0.03163477499037981, 0.02937771306772317, 0.07782516428934676, 0.06205618008971214, 0.23251069071037428, 6.650146492889949, 59.678487641470774, 36.17703621728079, 30.06866291591099, 38.4298471723284, 49.89408997126988, 9.171313813754491, 0.06710583769849368, 0.5733225728784288, 2.1613511656011855, 1.9561306919370378, 0.4538587475461619, 0.2479726853115218, 0.13424623997083732, 0.24636759715420858, 9.831947667258126, 78.57909556797573, 77.37306894574846, 82.48676245553153, 77.48490020206997, 80.7858156476702, 75.98529134477887, 64.70241042545864, 63.25795636858259, 69.64022418430874, 72.28821740831647, 74.06469808306012, 75.26882089887346, 67.64457648141044, 55.82829277856009, 54.86780507223946, 56.047623089381624, 54.148940971919465, 55.549277441842214, 56.00331095286778, 60.65828786577497, 65.748948097229, 65.33740629468645, 71.71228122711182, 68.5140323638916, 70.42874050140381, 63.65517793382917, 51.88391855784825, 51.609485558101106, 50.62113210133144, 61.02689674922398, 60.86298179626465, 60.62347044263567, 64.55337156568254, 64.45822293417794, 61.40094607216971, 61.897874287196565, 60.209121567862375, 64.25275080544608, 60.38334764753069, 60.673004150390625, 62.284041268484934, 53.79709461757115, 62.49002061571394, 69.11644118172782, 58.30610030038016, 57.942028590611045, 62.39603928157261, 59.34792014530727, 57.389288970402305, 64.97579424721854, 58.988767760140554, 49.342722620282856, 58.739077295575825, 64.02767086029053, 63.034189632960725, 61.3486886705671, 60.87000642504011, 61.632029260907856, 47.671732970646445, 49.68360819135393, 55.32023354939052, 55.31391068867275, 53.43984603881836, 50.72515705653599, 50.244529315403526, 56.690428733825684, 60.50248840876988, 60.2125609261649, 58.41232436043875, 59.79645415714809, 61.4270851952689, 56.88483933040074, 49.58949831553868, 53.46044397354126, 56.2952812058585, 57.64406204223633, 58.429271016802105, 54.97771167755127, 55.55856718335833, 57.32796764373779, 58.39127826690674, 57.41781479971749, 54.039565903799875, 55.34290204729353, 54.9459479876927, 53.719247000558035, 63.082153047834126, 56.22834920883179, 52.67703458241054, 58.21126781191145, 55.87127086094448, 55.922572885240825, 53.94335767201015, 52.140699659075054, 47.22925431387765, 48.33276373999459, 44.335308756147114, 43.619487966809956, 44.51787962232317, 47.18232618059431, 53.0514486857823, 54.315110615321565, 58.66014575958252, 59.26344394683838, 60.478586605616975, 58.17703056335449, 56.04713324138096, 54.29760810307094, 49.12308658872332, 49.65083701269967, 48.281944615500315, 50.67864581516811, 58.76960073198591, 58.14608676092965, 57.98684447152274, 50.919783047267366, 54.487130641937256, 62.58799021584647, 63.84678145817348, 64.17908600398472, 60.36133575439453, 63.05552755083357, 37.84900903701782, 3.53586574111666, 0.6415600712810243, 1.001884096435138, 2.9764497705868314, 1.3898164629936218, 0.17080633102783135, 0.08602652885019779, 0.31213710084557533, 0.48919606421675, 30.863460404532297, 42.45086349759783, 35.49482039042881, 44.58850458690098, 37.48174810409546, 0.05530818664867963, 0.046525480425251384, 0.036712713938738616, 0.08863847476563283, 0.02937793019892914, 0.054073449689894915, 0.046904106358332295, 0.04697134917868035, 0.033462236036679575, 0.020285372655572634, 0.04843075247481465, 0.07836125445153032, 0.01705673340308879, 0.04314154147037438, 0.026207300601527095, 0.0931839265727571, 0.015585147010694658, 0.10678421107253858, 0.03328186785802245, 0.051527308100568395, 0.04792514210566878, 0.07797847927681037, 0.37249545061162537, 9.126107965196882, 68.84000710078648, 42.658892563411165, 37.45562635149275, 31.713287625994, 61.0405638558524, 11.914261988231114, 0.050841933448932, 0.5401124634913036, 1.5004249449287141, 1.821704762322562, 0.7679271219032151, 0.2661777798618589, 0.20332126771765097, 0.2600736788340977, 11.034139752388, 84.8819385256086, 80.33002771650041, 82.83585384913853, 79.61279991694859, 83.41072000776018, 79.4969734464373, 67.46048395974296, 64.81442928314209, 70.78027071271623, 76.02449308122907, 78.40218748365129, 76.84459590911865, 71.57122584751674, 60.050007820129395, 58.23591307231358, 58.90154702322823, 56.59144122259957, 55.99709926332746, 59.422251973833355, 63.71403612409319, 67.23364612034389, 69.17668206351144, 72.98258563450405, 68.96453966413225, 74.21855899265834, 66.98804814474923, 53.84734746388027, 53.15149579729353, 54.75858633858817, 65.17514501299176, 63.882432665143696, 63.1601813180106, 66.63504491533551, 65.38301427023751, 64.51309980664934, 63.937705584934776, 64.45128863198417, 66.42866952078683, 62.562142917088096, 65.35993235451835, 64.02998461042131, 57.97371932438442, 64.55178042820522, 70.07119315011161, 60.77098764692034, 60.6907776423863, 66.19845485687256, 59.570193018232075, 58.156161648886545, 68.03316143580845, 58.96772166660854, 53.45939132145473, 61.49353081839425, 66.62159320286342, 63.44004780905587, 63.283289500645225, 62.703316416059224, 62.116971833365305, 50.433551583971294, 50.72798497336251, 55.14222070149013, 55.547939913613455, 55.069684982299805, 53.187310286930625, 52.251408781324116, 58.482105118887766, 62.019050870622905, 60.54301725115095, 61.57415771484375, 60.50954777853829, 62.42383902413504, 59.71148463657924, 54.0152576310294, 55.97600105830601, 58.487385749816895, 60.03050422668457, 61.02292932782854, 58.890582765851704, 58.20636933190482, 58.697846685137065, 59.74935926709856, 59.378450529915945, 57.362389019557405, 56.9584242275783, 57.667904785701204, 56.44322225025722, 60.96983119419643, 64.31197030203683, 53.793749059949604, 59.960403851100374, 59.091774804251536, 59.06701142447335, 55.9319737979344, 56.32983807155064, 51.663268089294434, 50.6956376348223, 47.29761069161551, 48.4681077003479, 47.780837059020996, 49.56712164197649, 57.209125655038015, 57.65014866420201, 62.03246784210205, 62.56513064248221, 62.07257284436907, 62.48101575034005, 57.81260449545724, 56.574769020080566, 51.443124839237754, 50.517291273389546, 49.797103541237966, 53.87308011736189, 60.08463764190674, 61.317213330950054, 61.016988618033274, 54.736616134643555, 58.23173720496041, 64.43018000466483, 67.66090474809918, 66.65574359893799, 67.16023840223039, 67.82962785448346, 43.26025915145874, 4.495054568563189, 0.38478599967701094, 2.727552052055086, 2.1072255671024323, 1.6948722366775786, 0.1735809828553881, 0.05107966497806566, 0.29640817056809154, 0.5665134468248912, 31.792062827519008, 51.09337336676461, 33.27004541669573, 53.620742389133994, 46.01093980244228, 0.4596306106873921, 0.013952495912755174, 0.05924436489918402, 0.04256496312362807, 0.00947113343447979, 0.04319639763395701, 0.029597887503249303, 0.05166820928986583, 0.02642815187573433, 0.06280787475407124, 0.019280323193275502, 0.03841590808172311, 0.11848404790673937, 0.10909371357411146, 0.16906017544014112, 0.21929463345025266, 0.12063215406877653, 0.10753043674464736, 0.13065855391323566, 0.13650045543909073, 0.16115810589066573, 0.19220761050071034, 0.38598630098359926, 10.042985303061348, 79.93313271658761, 48.85057476588658, 41.50145469393049, 55.467590945107595, 70.27036326272147, 18.457943405423844, 0.1801901582096304, 1.6299027800559998, 6.773945152759552, 3.8714150956698825, 1.5046049377747943, 0.6637221106461116, 1.0052006670406886, 0.479176653282983, 15.123096432004656, 89.74222428458077, 84.83474636077881, 87.11395004817417, 84.38026469094413, 87.49998501368931, 84.61088235037667, 71.57574217660087, 70.4645584651402, 74.15477452959333, 78.45188099997384, 82.86207635062081, 80.84481975010463, 75.07926709311349, 62.34956278119768, 61.728831563677105, 61.41773986816406, 59.59865978785923, 59.25694043295724, 62.629526547023225, 67.00924709865025, 72.10270745413644, 72.16548442840576, 77.01765469142369, 73.31742627280099, 78.05464553833008, 70.91292572021484, 56.50609302520752, 56.97506863730294, 57.43086004257202, 67.92179570879254, 65.17540904453823, 67.01006698608398, 69.55580357142857, 69.30230549403599, 66.97643770490373, 67.22030557904924, 68.27741840907505, 69.38485009329659, 64.7426335471017, 68.67910071781704, 68.91941806248256, 62.46339511871338, 68.77554171425956, 73.10385949271065, 64.79080540793282, 61.76756082262312, 66.75742353711809, 62.749237060546875, 58.199122360774446, 71.65470845358712, 64.72709737505231, 54.57665123258318, 63.713362148829866, 69.62406267438615, 67.67867129189628, 67.14901011330741, 66.52488122667584, 66.28168732779366, 53.145464760916575, 53.5596364566258, 58.115170751299175, 59.659261975969585, 57.631951332092285, 56.55177048274449, 54.20909152712141, 61.400626455034526, 64.89933626992362, 64.43955312456403, 62.957425934927805, 64.38885906764439, 66.09232807159424, 59.7618590763637, 55.88717876161848, 59.45504052298409, 61.674878801618306, 64.72351210457938, 63.180525643484934, 61.06101240430559, 62.13462025778634, 63.303529603140696, 63.25129304613386, 62.241490500313894, 57.60278626850673, 59.734003748212544, 60.166723660060335, 62.849284172058105, 64.5939073562622, 61.892850739615305, 57.89523942129952, 63.268191065107075, 62.70854146139962, 62.010330881391255, 59.90629128047398, 58.831481388636995, 54.89543110983712, 53.74609136581421, 51.30998345783779, 50.340126105717246, 51.304664611816406, 52.550518308367046, 61.78475066593715, 60.01062543051583, 64.28909683227539, 65.61874580383301, 64.18367181505475, 64.81659712110246, 61.26979882376534, 60.15543283735003, 54.87205736977713, 54.376185280936106, 53.05920287540981, 55.636084760938374, 63.49685628073556, 64.56240422385079, 64.08835642678397, 58.127055644989014, 61.97650705065046, 70.08606229509626, 71.30436638423375, 71.6148327418736, 71.14284855978829, 73.4868997846331, 47.5853078024728, 4.767585498946054, 1.1433273809296745, 6.350295679909842, 9.43118599482945, 4.304329557078225, 2.077965182917459, 0.15013286178665503, 1.0747932812997272, 0.5219714769295284, 38.72163677215576, 60.79620960780552, 48.816521644592285, 58.69570663997105, 54.60651459012713, 0.47082567853587015, 0.12809367797204427, 0.19052203451948507, 0.1272542623004743, 0.17791877580540522, 0.13335307075509004, 0.1306636564965759, 0.09842159944985594, 0.1117133405059576, 0.12818036760602677, 0.10070873743721417, 0.230341658528362], [0.0462917760014534, 0.03925805485674313, 0.038280767654733996, 0.03601632666374956, 0.012219463192325617, 0.022754707473463247, 0.027649689632068788, 0.10590734705328941, 0.05992306276623692, 0.11960945251796927, 0.3082881516643933, 11.430328641619, 62.58862945011684, 25.104546751294816, 24.653014591762, 41.48228461401803, 42.91528109141758, 5.166011273860931, 0.0541842035683138, 0.34369234474641935, 1.266298445207732, 0.45142462530306404, 0.9225979851824897, 0.8386532153402055, 0.6224942686302322, 0.7219907896859306, 28.895947694778442, 85.26083074297223, 76.89253153119768, 81.2956188746861, 75.84101894923619, 79.06902694702148, 71.0689058303833, 62.658160073416575, 63.70830386025565, 72.45357063838414, 73.08356380462646, 76.71749251229423, 72.87495109013149, 75.40259456634521, 68.04160349709647, 54.40108415058681, 53.15142978940691, 54.810920170375276, 55.80194868360247, 53.23693779536656, 53.86988047191075, 61.45240443093436, 65.67702729361397, 66.79204641069684, 68.06260095323834, 68.84764317103794, 61.64593955448696, 49.54142025538853, 48.47223493031093, 58.342036383492605, 63.22047083718436, 61.15891947065081, 61.13617106846401, 61.08269773210798, 62.24018423897879, 62.2546295438494, 60.771960394723074, 60.83108261653355, 62.90848282405308, 65.39420086996896, 62.84264169420515, 54.1222425188337, 53.98711395263672, 64.28512246268136, 61.5991017477853, 58.0936313356672, 63.929569244384766, 57.79261800221035, 57.96147312436785, 63.925254413059776, 56.53648444584438, 51.01788813727242, 59.22495092664446, 63.219935825892854, 59.30537632533482, 58.60695035117013, 61.36516979762486, 63.50511768886021, 54.009681701660156, 49.180881704602925, 48.13375343595232, 48.33805479322161, 48.67283984592983, 48.85909673145839, 47.024150439671104, 47.59648050580706, 54.4248435156686, 60.05813026428223, 57.0941538129534, 57.237543787275044, 55.62290402821132, 56.914198943546836, 58.089761189052034, 59.27271284375872, 52.27419192450387, 54.84180838721139, 52.59346859795706, 53.646228381565635, 56.24737337657383, 55.90286431993757, 56.2776814188276, 53.44854518345424, 52.5377197265625, 54.5193008014134, 55.99045678547451, 55.175262859889436, 55.19589900970459, 53.622055598667686, 63.017736298697336, 58.59535380772182, 56.03237874167306, 58.89887891496931, 56.07912622179304, 54.009869303022114, 53.03931713104248, 51.53138085774013, 49.14205517087664, 46.001055989946636, 43.46930612836565, 44.844649927956716, 45.351965699877056, 51.90581580570766, 55.6887868472508, 60.14051505497524, 58.79194613865444, 61.3702072416033, 56.80563334056309, 55.1374055998666, 51.273800713675364, 50.30441583905901, 45.943104539598735, 47.04843091964722, 52.89749050140381, 58.96832615988595, 56.23500905718122, 59.24999223436628, 52.83978223800659, 54.87760550635201, 62.0914580481393, 62.61075946262905, 62.96959917885916, 65.55982507978166, 63.10393565041678, 49.455905301230295, 8.163607018334524, 0.6494495336498533, 1.156135082244873, 0.6401365048119, 0.864965446293354, 0.14314247188823565, 0.0865665545154895, 0.35915564213480267, 0.5595159594501767, 11.912644795009069, 52.52170760290963, 31.685255118778773, 25.938341004507883, 48.88191114153181, 2.0339583328792026, 0.13841073507709162, 0.1599846745708159, 0.012171911458218736, 0.06769534892269544, 0.03476073832384177, 0.04039098442132984, 0.025971119524911046, 0.09940101046647344, 0.008738108661158808, 0.06354871964348213, 0.06437483602868659, 0.07082214685423033, 0.07233827228524856, 0.02612122504173645, 0.07048232973154102, 0.03520435094833374, 0.04959979706576892, 0.07495351588087422, 0.053176891191729476, 0.11737699088241373, 0.11424017777400357, 0.3241557202168873, 16.217983143670217, 69.56659412384033, 33.07711478642055, 29.005520786557877, 41.353843688964844, 51.08155795506069, 6.976905507700784, 0.003914999052150441, 0.2213912523750748, 1.1031281437192644, 1.0927389583417346, 0.6122697772724288, 0.5430941092116492, 0.25962180165307863, 0.6043303747262273, 33.33818987437657, 89.7990813936506, 78.53981045314244, 86.64976174490792, 79.4353220803397, 81.11957236698696, 74.54901531764439, 64.46544211251395, 65.85412992749895, 74.51146725245884, 76.24029718126569, 79.63663918631417, 77.54127788543701, 77.80983270917619, 71.25787598746163, 59.725916045052664, 56.5004962512425, 58.51962539127895, 56.388119561331614, 54.97771862574986, 55.08420671735491, 64.12527915409633, 69.55165549686977, 71.10311181204659, 72.05530684334892, 70.30821010044643, 63.79954065595354, 52.13486317225865, 51.064771107264924, 61.236162594386506, 64.40410341535295, 65.26331765311105, 63.05598613194057, 62.88881247384207, 65.78664902278355, 64.23777743748256, 62.788348470415386, 62.15804263523647, 64.30243042537144, 68.26504366738456, 65.22526931762695, 58.389937264578684, 59.38034043993269, 66.44964613233293, 64.5337220600673, 62.20968164716448, 65.32218973977226, 58.649695668901714, 60.74649524688721, 64.96644892011369, 57.93555634362357, 52.21242938722883, 63.37842423575265, 61.85445499420166, 61.56247084481375, 61.30094064985003, 64.93320178985596, 64.11149392809186, 56.287137917109895, 49.82040779931204, 50.50478104182652, 48.70720216206142, 52.54450811658587, 50.885646547589985, 47.42309168406895, 48.062478814806255, 55.30738285609654, 62.340578760419575, 60.93724414280483, 59.48181193215506, 56.16306046077183, 57.41237783432007, 59.143344334193635, 61.888758250645225, 56.6559795652117, 56.515348025730674, 54.05010979516165, 54.910015378679546, 59.315055165972026, 57.11457109451294, 59.90768092019217, 56.70593711308071, 53.98733976909092, 55.68141828264509, 59.39389637538365, 58.16825498853411, 58.26552282060896, 56.533778122493196, 62.67739963531494, 64.1436710357666, 58.92120347704206, 63.5710699898856, 59.305209568568635, 59.22212995801653, 56.32237918036324, 56.58786637442452, 51.574831417628694, 50.10842800140381, 46.39199638366699, 49.30729375566755, 48.308003834315706, 54.86716931206839, 59.297302518572124, 63.251494543892996, 61.68361268724714, 62.88959067208426, 60.60564831324986, 58.316550391060964, 52.648439271109446, 52.56982387815203, 47.7328006880624, 49.05604689461844, 55.503700733184814, 61.795145171029226, 59.09073952266148, 61.85739408220564, 54.788984707423616, 59.93737057277134, 65.70612634931291, 66.60106822422573, 67.15208121708461, 68.78558186122349, 67.42135865347726, 56.358954497746055, 10.352123686245509, 1.094406200306756, 1.2441465024437224, 0.4059401974081993, 0.28764309946979794, 0.1686692171330963, 0.11550887541047164, 0.6533076837658882, 0.5365487432905606, 11.235489862305776, 61.065869195120676, 32.52159241267613, 31.07992458343506, 61.06824547903878, 4.184739334242685, 0.2978731548147542, 0.05516840164948787, 0.058783775328525474, 0.025839242851361632, 0.038642925542912314, 0.041244625579565763, 0.11044688882040125, 0.07084749013717685, 0.024428629615743245, 0.0597106609493494, 0.0433038877589362, 0.14103819908840315, 0.10918971949390002, 0.077022396294134, 0.10827752415622983, 0.12307170459202357, 0.16072293424180575, 0.18187072660241807, 0.1558698889400278, 0.19393890617149218, 0.37002381895269665, 0.4528145364352635, 17.450819390160696, 82.78213037763322, 35.12357119151524, 38.53466074807303, 56.906396116529194, 62.45898996080671, 11.151332412447248, 0.14460930175014905, 1.4904201903513499, 3.626476113285337, 2.878386152642114, 1.6103105970791407, 2.1543875506946017, 0.9600171829972948, 0.9167598698820386, 36.30862815039498, 94.41081619262695, 81.95604515075684, 93.1333065032959, 84.39755875723702, 85.5994998386928, 77.36760766165597, 67.08862331935337, 69.47618416377476, 79.57939297812325, 79.71250656672886, 84.0180412020002, 80.13459573473249, 81.73603739057268, 73.268844468253, 62.59000519343785, 59.815415791102815, 61.943246023995535, 61.11082404000418, 58.572452545166016, 58.95072637285505, 67.21944400242397, 73.30738612583706, 73.58063098362514, 75.2275972366333, 73.45955862317766, 68.24799973624093, 54.172453675951274, 52.208222252982004, 63.11886732918875, 66.72032015664237, 67.13303620474679, 64.73843683515275, 67.59982313428605, 68.5978901726859, 66.19075625283378, 66.09166799272809, 65.66322122301374, 66.79936981201172, 72.10816873822893, 65.94309466225761, 61.444907324654714, 61.420804023742676, 67.51695196969169, 68.67168004172188, 64.19966656821114, 68.6048800604684, 60.671941076006206, 60.35192094530378, 68.89935861315045, 61.442815916878835, 55.43752261570522, 65.25454207829067, 67.91759204864502, 64.4988351549421, 63.684464590890066, 65.41328062329973, 67.31236226218087, 59.26051180703299, 52.612430231911794, 53.995625495910645, 52.650718280247276, 54.08423587254116, 51.98273583820888, 52.3839248248509, 51.24398946762085, 58.64546421595982, 65.48019177573067, 62.2839856828962, 60.81869397844587, 58.36244324275425, 59.75035980769566, 61.430663517543245, 62.31867803846087, 58.27191516331264, 60.47835036686489, 55.50603185381208, 59.70512703486851, 61.962985856192454, 61.05090972355434, 60.48509011949812, 59.076516560145784, 57.573537826538086, 59.16978222983224, 61.946803501674104, 64.09325490679059, 63.41441590445382, 60.1236309323992, 66.43777860913957, 64.88201441083635, 59.24625410352434, 65.32427419934953, 62.788536071777344, 61.22242600577218, 58.06068297794887, 58.56656742095947, 55.72819355555943, 52.68934679031372, 48.05235528945923, 52.836235182625906, 53.54537875311715, 58.2302120753697, 60.71174035753523, 67.00928183964321, 64.7209551674979, 66.33874593462262, 62.55966935838972, 61.03403949737549, 56.61956753049578, 55.53188957486834, 50.43740783418928, 52.67349794932774, 57.886762619018555, 66.14978967394147, 62.43888882228306, 66.75341442653111, 58.95352649688721, 63.30842113494873, 69.22486087254116, 72.5439875466483, 70.34849575587681, 75.94250433785575, 72.06231757572719, 63.80195862906319, 10.664637156895228, 2.086886452777045, 4.056813444410052, 4.088329604693821, 2.8748471311160495, 1.4186638636248452, 0.271783211933715, 1.1789148598909378, 0.8008567520550319, 14.68757118497576, 67.13293198176792, 44.84376055853707, 35.36937066486904, 64.491379737854, 3.6643010207584927, 0.46253794325249536, 0.30528365288461956, 0.24335368030837604, 0.19695548287459783, 0.17261255053537233, 0.17215410513537271, 0.18312928692570754, 0.18093459254928998, 0.09790631317134414, 0.18427768030336925, 0.12079760804772377], [0.09277942470674004, 0.11545911165220396, 0.025170792559427873, 0.05121088347264698, 0.007283088701244975, 0.05930896821830954, 0.014449684814150845, 0.1852440634476287, 0.02019400621897408, 0.0647193214723042, 0.11000641102769546, 24.453936542783463, 57.56474835532052, 25.51412742478507, 38.14011771338326, 47.617290360586985, 32.7308235168457, 2.999217063188553, 0.03458417672663927, 0.07545040028968028, 0.9967929124832153, 0.5200028568506241, 1.2497447963271822, 0.5875750652381352, 0.20497058278747968, 5.5377160140446255, 67.81887899126325, 78.16098076956612, 80.1806970323835, 76.85356603349958, 76.91166687011719, 75.26365143912179, 70.81216294424874, 59.22256769452776, 64.18219879695347, 66.72377341134208, 74.25843470437187, 76.80301094055176, 73.30375916617257, 72.32461207253593, 71.50852530343192, 65.01657322474888, 55.59334986550467, 53.93143456322806, 52.739707333701, 50.51962586811611, 55.88105739865984, 57.17006288255964, 62.279948779514854, 66.83572278703961, 67.0907564163208, 65.37489877428327, 55.76213550567627, 48.187369210379465, 52.90052686418806, 64.27936935424805, 63.86602102007185, 65.40069048745292, 61.95097936902727, 57.8177809034075, 59.44837720053536, 59.53317996433803, 58.242187295641216, 60.05519812447684, 61.79322746821812, 56.346583230154856, 54.56783744267055, 55.78414045061384, 62.1615514755249, 63.27789075034005, 58.3252842766898, 63.65848527635847, 56.60808563232422, 57.91809204646519, 61.96609170096261, 54.41022103173392, 51.14508186067854, 55.30239404950823, 63.54586887359619, 58.185368401663645, 62.28518077305385, 62.38861860547747, 61.686461448669434, 53.50615964617048, 54.34310838154384, 43.68383870806013, 49.503854819706504, 52.23984350476946, 55.83055441720145, 51.770117487226216, 49.93709584644863, 43.183762959071565, 46.817191396440776, 57.21596268245152, 62.86712714603969, 60.11191626957485, 57.37577472414289, 56.40429496765137, 56.44728694643293, 56.95093754359654, 58.01220539637974, 51.692363670894075, 57.39526094709124, 53.78339971814837, 52.76049286978585, 56.72318949018206, 57.265687465667725, 57.2889152935573, 52.570240770067485, 52.61619962964739, 54.67577075958252, 54.33850867407662, 53.6966792515346, 51.946077142442974, 53.998773029872346, 60.041850634983604, 57.985197748456685, 56.94359677178519, 57.670572893960134, 56.215029512132915, 57.919509478977744, 54.12307630266462, 52.10325581686837, 49.87697308404105, 45.400801113673616, 42.25092560904366, 44.216824599674766, 51.38087592806135, 54.605802399771555, 58.57218156542097, 57.61766236168997, 59.967067173549104, 56.64455672672817, 52.874412059783936, 50.209079606192454, 49.41108594621931, 44.68385819026402, 48.1704295022147, 54.26970761162894, 60.142363275800435, 58.268409797123496, 55.990401199885774, 50.2193420955113, 56.770291328430176, 61.51322201320103, 62.28507655007498, 66.15468120574951, 64.15926279340471, 61.75723579951695, 58.11224208559309, 18.540283032826014, 0.7959282536591802, 1.1434755729777473, 0.8458168623702866, 0.5998399928212166, 0.09514036016272646, 0.09983842128089496, 0.22558343171008996, 0.2666091652853148, 3.691879289490836, 56.78270428521292, 41.535837854657856, 27.72254807608468, 48.499471868787495, 12.153528417859759, 0.34358939741339, 0.17593433228986605, 0.022896190506539175, 0.1117791109053152, 0.036356299849493165, 0.011363226637643362, 0.030619815524135317, 0.10118325054645538, 0.031817633392555375, 0.08753189271582024, 0.008146399831665414, 0.0671315338196499, 0.03200351806091411, 0.021123297246439115, 0.06638303505522863, 0.019555243530443737, 0.08084693857069526, 0.01597946067340672, 0.1027424018830061, 0.10242927154260022, 0.07966444202299629, 0.11092298970158611, 32.339170932769775, 62.370581081935335, 34.07208292824881, 40.28437001364571, 50.03433588572911, 41.549049854278564, 5.088794205869947, 0.049272088400487385, 0.14027414151600429, 0.9951750678675515, 0.5683639475277492, 1.8067513704299927, 1.5119266020400184, 1.7560879290103912, 7.291566405977521, 77.82949611118862, 81.08015523638043, 85.11819812229702, 79.49790450504848, 80.89875166756767, 77.18019390106201, 73.40198584965297, 62.05829429626465, 65.13003035954067, 70.41526099613735, 76.1041819708688, 76.21114253997803, 77.5677157810756, 76.52435343606132, 74.69099480765206, 68.76454271589006, 58.42187813350132, 55.43927356175014, 56.26418454306466, 53.34063271113804, 56.49718196051461, 60.272225107465474, 65.82369681767055, 69.88234806060791, 70.00367750440324, 67.48452472686768, 57.56687797818865, 49.74150405611311, 57.41226666314261, 65.58820152282715, 64.33185604640416, 66.46252809252057, 63.45438889094761, 60.67416449955532, 61.17096764700753, 61.438014711652485, 60.09775584084647, 61.32418237413679, 64.2283695765904, 62.05859306880406, 60.70634160723005, 60.55232088906424, 64.36301176888603, 65.75690378461564, 62.966069493974956, 64.59020396641323, 58.93114634922573, 60.829088483537944, 63.24814551217215, 57.96068797792707, 56.14273350579398, 60.29370893750872, 65.6268960407802, 60.746613366263254, 62.46602848597935, 64.28592150551933, 62.4193365914481, 56.08687693732125, 55.78634302956717, 44.57189144407, 53.57241766793387, 54.98240865979876, 59.89891924176897, 53.8601564679827, 52.584793772016255, 44.90675640106201, 47.2028546333313, 58.26163877759661, 62.04359885624477, 60.68977015359061, 59.93568216051374, 57.99877452850342, 59.19243335723877, 58.64849363054548, 61.57940360477993, 52.88082524708339, 57.65700306211199, 57.51779590334211, 56.14493955884661, 59.02681609562465, 57.98364135197231, 60.036236490522114, 56.016026156289236, 57.01485749653408, 56.25054175513131, 58.3326632635934, 56.44185692923409, 55.72294766562325, 57.04666287558419, 59.46665791102818, 60.94784014565604, 61.52351924351284, 58.87500490461077, 60.57155350276402, 59.345154762268066, 57.64163712092808, 57.0003878729684, 52.48942279815674, 48.180035386766704, 46.33506284441267, 46.85668843133109, 54.88672501700265, 58.140802655901226, 60.860542978559224, 59.08660534449986, 63.227842875889365, 59.830236298697336, 56.84073911394392, 52.02786438805716, 51.52196952274868, 46.66768700735909, 51.14309467588152, 57.88083927971976, 61.407470430646626, 61.105605942862375, 58.07537841796875, 52.62274135862078, 60.12144224984305, 63.89333438873291, 66.50428676605225, 67.50224958147321, 70.68901307242257, 66.81583704267229, 64.69825540270124, 21.899292366845266, 1.7394849913460868, 0.7457491776772908, 0.5350350130881582, 0.2535346911421844, 0.07434915831046444, 0.027990232787228057, 0.6786531923072678, 0.27686427214315956, 3.602936267852783, 64.46264893668038, 42.84919677461897, 27.76484523500715, 57.61430638177054, 16.76880853516715, 0.49137790713991436, 0.22842837976557867, 0.11748048104345798, 0.058315565809607506, 0.0589979277657611, 0.06968103415731873, 0.03823851188644767, 0.04485688817554286, 0.026005519554018974, 0.027908867956804376, 0.023313285982502357, 0.15629429902349198, 0.15321214869618416, 0.08453729376196861, 0.17947247172040598, 0.11675264367035457, 0.21283868487392152, 0.1246622313878366, 0.2592124821884291, 0.2069825612540756, 0.15499322169593402, 0.28380356835467474, 33.73387936183384, 73.7441359928676, 36.16147920063564, 52.277527059827534, 61.606842041015625, 54.2323853628976, 8.977655359676906, 0.2825402175741536, 0.28752109887344496, 2.5503217450210025, 1.300164399402482, 4.556399345397949, 1.2581213925565993, 2.5260186833994727, 10.193534527506147, 86.24593939099992, 86.27565683637346, 91.82003443581718, 83.72558457510812, 84.10952118464878, 81.09630979810441, 78.81498691013881, 66.46982370104108, 69.67578506469727, 73.94947610582624, 81.43190084184918, 81.94066878727504, 79.61501639229911, 81.82468945639474, 78.1287897654942, 72.94619097028459, 61.64099938528878, 58.497168813432964, 58.637897627694265, 56.19386182512556, 60.753943715776714, 62.215413911002024, 68.90653610229492, 72.73277010236467, 73.40344497135708, 69.9576665333339, 61.118286405290874, 52.20378930228097, 59.07194464547293, 70.47266006469727, 67.00226415906633, 70.87816388266427, 67.03760964529855, 64.2811758858817, 65.01844923836845, 65.92822551727295, 63.513851574489046, 65.5652516228812, 70.29689148494175, 66.2650533403669, 65.74666908809117, 62.468133790152415, 64.47241115570068, 69.51567772456578, 66.54432228633335, 69.15697002410889, 59.7601637159075, 61.05834429604666, 67.88437965938023, 60.09559495108468, 57.53030613490513, 61.33777305058071, 69.67729977199009, 63.76263877323696, 64.82128715515137, 67.50960077558244, 67.60932132175991, 58.214481353759766, 59.97734355926514, 48.50459269114903, 54.573788574763704, 54.793598311288015, 60.38437598092215, 55.99465002332415, 53.98029429571969, 47.23695639201573, 49.74964039666312, 60.99830491202218, 66.22191197531563, 63.986954416547505, 62.0615599496024, 60.97895417894636, 60.79281888689314, 62.02519307817732, 62.785089765276226, 54.785288265773225, 60.76354612622942, 58.71837166377476, 59.4263653073992, 62.514936855861116, 61.524109840393066, 64.92473888397217, 54.63302544185093, 59.64408016204834, 59.549028805324006, 62.321214130946565, 61.02476365225655, 60.21636853899275, 58.77771622794015, 62.91028935568673, 64.61587756020683, 63.00475706372942, 63.53544657570975, 63.08950424194336, 64.59885447365897, 62.083314759390696, 59.931610516139436, 55.41658074515206, 50.72231176921299, 50.2988920211792, 50.60788188661848, 57.40867097037179, 61.02167865208217, 66.18430832454136, 60.67275401524135, 68.38364941733224, 62.64042132241385, 59.78323173522949, 54.53827633176531, 54.40113626207624, 49.78508315767561, 54.52522414071219, 59.8918251310076, 65.43514660426548, 63.02863107408796, 60.63629681723458, 56.43969256537301, 65.35620812007359, 67.60265105111259, 70.55874129704067, 71.82859407152448, 77.31389808654785, 72.1822156906128, 72.95767634255546, 22.14601595061166, 2.3271169449601854, 3.771209044115884, 4.683917897088187, 2.22838716847556, 0.5120398412857736, 0.2157178853771516, 2.1908160873821805, 0.4715691900679043, 6.072830660002572, 71.24272891453334, 56.08193676812308, 36.58251224245344, 63.31876005445208, 19.13461630684989, 1.036618901150567, 0.5699034620608602, 0.3062068947723934, 0.35874591554914204, 0.12509882796023572, 0.18830199007477078, 0.16057115952883447, 0.24123247127447808, 0.18075106239744596, 0.13944520242512226, 0.22544229642621108], [0.06389677418129784, 0.04900105097996337, 0.03277292927461011, 0.03236289395551596, 0.06437543992485319, 0.03469042852520943, 0.07119143275277955, 0.03994853548439486, 0.034683280158787966, 0.019885467864306908, 0.05768065380730799, 37.671076093401226, 55.15551955359322, 29.908638954162598, 47.88540744781494, 47.4252074105399, 22.30583667755127, 2.320479678256171, 0.24450336290257318, 0.08900154528341123, 1.0276591990675246, 0.34234580557261196, 0.29782082619411604, 6.883414455822535, 3.6464515328407288, 36.682475975581575, 87.30735315595354, 72.82251303536552, 80.62850148337228, 73.90640422276088, 78.21784482683454, 69.51075145176479, 62.55864102499825, 59.55354513440813, 61.10376467023577, 64.24977697644914, 69.8216277531215, 73.57902594975063, 74.98636967795235, 71.98055117470878, 71.8427961894444, 70.28344672066825, 61.261099679129465, 54.6075325012207, 52.96518332617623, 52.478100708552766, 50.15306322915213, 56.98028326034546, 60.167161396571565, 64.404680115836, 62.95049858093262, 60.85115596226284, 51.52992868423462, 49.966024671282085, 56.68514115469796, 61.77978965214321, 62.158390045166016, 62.469092641557964, 58.84241090502058, 56.298790046146934, 56.18249804633004, 57.68740143094744, 56.93462317330496, 57.343267577035085, 58.7305588041033, 59.02169527326311, 52.81741598674229, 50.114778654915945, 56.25482531956264, 58.877443722316194, 61.922484806605745, 62.06930719103132, 60.637596130371094, 61.17166246686663, 54.90918159484863, 54.24673686708723, 57.40528719765799, 62.52038424355643, 57.94503716060093, 59.9182630266462, 56.83612551007952, 58.43679591587612, 60.45371205466134, 57.90091609954834, 43.4663531439645, 47.723861830575125, 58.13616125924246, 58.248951366969514, 58.07922771998814, 57.63925041471209, 58.03961951392037, 50.87293481826782, 40.43261677878243, 46.38977296011788, 52.31739929744175, 57.021183831351145, 59.3895537512643, 60.04078756059919, 57.29624216897147, 59.345752307346885, 57.57601833343506, 56.11171327318464, 53.12957770483834, 58.48670482635498, 54.51486785071236, 57.15713575908116, 53.45382234028408, 53.500837326049805, 53.86726794924055, 49.085576738630024, 55.3387713432312, 53.80730846949986, 55.01246656690325, 52.44489526748657, 51.50559261866978, 51.36919948032924, 54.71432283946446, 56.6263941356114, 57.37115069798061, 57.13640233448574, 55.24177796500069, 54.67091396876744, 54.388473170144216, 51.971118450164795, 45.21109792164394, 41.6041316986084, 46.75245155606951, 49.22161899294172, 55.547425746917725, 59.20913682665144, 59.28838797977993, 60.15358461652483, 55.60688495635986, 52.62906421933855, 49.440879821777344, 46.96233926500593, 44.764950616019114, 53.40694979258946, 58.157249041966026, 59.70234080723354, 57.20645407267979, 56.96274253300258, 52.181006159101216, 57.82289825166975, 62.19854368482317, 64.36167771475655, 63.41224806649344, 63.70609433310372, 61.80378178187779, 55.16225930622646, 34.380555152893066, 4.823404286588941, 0.3079950788191387, 0.0315248353539833, 0.06078519579023123, 0.09918662054198128, 0.04305556769083653, 0.31095742700355394, 0.2503969280847481, 1.2161161665405547, 54.46800919941494, 42.01554495947701, 25.511540957859584, 46.440870012555806, 19.854088374546595, 0.4191803698028837, 0.15315083627189907, 0.20116500556468964, 0.09273917400943381, 0.09028553031384945, 0.051387601132903776, 0.053127392062119076, 0.024314578057133725, 0.06687284234379019, 0.05791869067720004, 0.01490664082978453, 0.04213006967412574, 0.06863559489803654, 0.0741382289145674, 0.06094855309597083, 0.01735503605699965, 0.03544099682143756, 0.047301727879260264, 0.04842086961226804, 0.029586681497416327, 0.0415934197205518, 0.1474257649055549, 46.76182467596871, 61.467787742614746, 36.22939436776297, 39.2781457901001, 52.385317938668386, 26.89269345147269, 3.075871978487287, 0.3650281455899988, 0.2718327449900763, 2.4614542850426266, 0.9180126083748681, 2.085103154182434, 8.586469173431396, 9.351816722324916, 39.86238506862095, 95.01206466129848, 73.49817671094621, 83.11129433768136, 76.54159191676548, 82.67015320914132, 69.52188246590751, 64.34878185817173, 61.06575107574463, 63.70348181043352, 67.13550281524658, 72.19286033085415, 74.61307076045445, 77.27233396257672, 74.70361968449184, 73.31321566445487, 71.3798794065203, 65.06108338492257, 58.37175382886614, 53.92134230477469, 55.1671438898359, 52.646584102085654, 58.161991187504356, 62.583418301173616, 67.30174541473389, 65.88363892691476, 63.62708636692592, 53.78131873267037, 52.08799409866333, 58.55797944750105, 64.07316766466413, 66.03177452087402, 65.51215348924909, 60.971470969063894, 59.386510440281455, 59.16828836713518, 60.071686199733186, 60.37801143101284, 60.252624239240376, 62.217685971941265, 63.49827371324812, 58.33962535858154, 55.15880952562605, 58.34871360233852, 62.44807434082031, 63.927561214991975, 65.63328838348389, 62.39922850472586, 62.150816508701865, 58.46806280953543, 56.388310636792866, 60.459611075265066, 65.7648594720023, 59.274151120867046, 61.59575271606445, 59.538745471409385, 61.26690837315151, 62.256866863795686, 58.69786752973284, 44.825705664498464, 52.03451728820801, 60.25347191946847, 58.899580683027, 58.407557896205354, 58.67281232561384, 59.0340005329677, 53.75100374221802, 43.13896792275565, 49.08622292109898, 51.40480899810791, 56.40187004634312, 61.97795922415597, 62.87573596409389, 58.86057349613735, 59.962634222848074, 59.625201906476704, 59.19357981000628, 54.178901604243684, 61.654631750924246, 57.62655258178711, 58.12525953565325, 58.30682291303362, 57.606972558157786, 54.61457797459194, 52.85136488505772, 57.76595776421683, 56.76002883911133, 57.26439510072981, 54.81077078410557, 53.278404644557405, 54.75057853971209, 56.767341818128315, 60.7275197165353, 57.802915232522146, 61.28404263087681, 59.74765001024519, 58.49771077292306, 56.652578422001426, 56.55894449778965, 48.54297454016549, 45.4235634122576, 46.94024746758597, 52.16095018386841, 57.75213432312012, 61.782367433820454, 61.4000358581543, 61.77806649889265, 58.38275282723563, 55.70570918491909, 51.32094424111502, 49.11331394740513, 48.677036557878765, 56.1996739932469, 59.99556173597063, 62.082696369716096, 60.03477736881801, 59.688625063214985, 56.01777710233416, 60.233732087271555, 65.73744188036237, 68.4384776524135, 67.38554068974086, 68.23720223563058, 67.48385769980294, 63.039901052202495, 39.949331351688926, 6.680066304547446, 0.8336678828511919, 0.07203028524028403, 0.040913466563714404, 0.13539664181215422, 0.09559425937810115, 0.4782698590840612, 0.3712879296924387, 1.1762275355202811, 59.043762751988, 47.89250503267561, 23.478397301265172, 54.258111068180625, 27.436865942818777, 0.3398779465683869, 0.1534110815929515, 0.021024614506001984, 0.1037660873095904, 0.0423943081737629, 0.05793088395148516, 0.05422767052160842, 0.08528264412390334, 0.05276694068951266, 0.1766516930822815, 0.04588916724813836, 0.2231113657887493, 0.18565379003328936, 0.2711021527647972, 0.10175807827285357, 0.14609971748931067, 0.08403877408376761, 0.15587857418826648, 0.15031305354620728, 0.12446853678141322, 0.11208510984267507, 0.21776520194751875, 51.799178327832905, 71.076673916408, 42.73742110388619, 61.50245925358364, 65.11394527980259, 37.401875087193076, 7.895281485148838, 0.5550565187420163, 0.4786506529365267, 3.789966574737004, 0.7369488498994282, 2.6312628303255354, 19.306238549096243, 13.284100208963666, 41.72643736430577, 99.13654313768659, 77.53157125200543, 92.0725736618042, 81.62843063899449, 86.49645669119698, 73.17833723340715, 68.61503832680839, 65.97166565486363, 68.70998546055385, 70.26579134804862, 74.97870581490653, 78.03723335266113, 82.17407962254116, 78.10875116075788, 78.64998803819928, 75.67095484052385, 68.37473487854004, 60.02629361833845, 56.729995250701904, 57.217710154397146, 55.68950251170567, 62.37946087973458, 66.36193902151925, 71.12134388514927, 70.26135839734758, 66.52686841147286, 57.01274871826172, 55.44716324125017, 61.44781861986433, 65.5650987625122, 68.8722675868443, 67.63900402614048, 64.33774811880929, 61.363307680402485, 62.58778176988874, 64.93801689147949, 64.66916329520089, 63.02052252633231, 66.75068378448486, 67.65850761958531, 62.79641532897949, 57.113289151872905, 60.07726560320173, 64.093247958592, 68.02904115404401, 66.64272267477853, 64.87346117837089, 66.36299514770508, 61.57554735456194, 58.66143812452044, 64.15133489881242, 68.0052991594587, 62.01211656842913, 62.94272354670933, 62.596925599234446, 62.40925475529262, 66.01574502672467, 62.70813846588135, 48.78987877709525, 51.94898843765259, 63.11443437848772, 60.26585360935756, 60.789358683994834, 62.542368343898225, 60.96745491027832, 54.99827487128121, 43.08069338117327, 50.73483937127249, 56.1704602922712, 61.24899591718401, 62.98643466404506, 64.91221823011125, 60.86012608664376, 62.78208119528634, 61.996969495500835, 61.01275021689278, 58.49213136945452, 64.24622644696916, 61.28302819388253, 61.39778464181082, 59.74254308428083, 60.290207045418875, 57.50789124625069, 56.23878192901611, 60.090404646737234, 60.103654861450195, 62.514568601335796, 57.87730264663696, 56.90788650512695, 58.602850914001465, 59.814609800066265, 63.63497257232666, 62.28588948931013, 64.12671048300606, 63.19178172520229, 62.30976349966866, 59.59862504686628, 59.475975445338655, 51.8680453981672, 47.56644344329834, 52.60868515287127, 55.63015794754028, 60.60811492374965, 64.15237712860107, 65.59049442836216, 65.26771586281913, 61.59430749075753, 59.001427377973286, 54.74415840421404, 52.830454281398225, 50.25276640483311, 59.18715967450823, 63.00543103899275, 66.14327921186174, 62.41627243586949, 65.45031452178955, 58.171201024736675, 64.8510740825108, 70.11180537087577, 73.49992765699113, 70.72369153159005, 74.53038024902344, 74.97585705348423, 71.31267642974854, 41.6725297655378, 7.535162431853158, 1.0149354189634323, 0.6110546567610332, 0.14275553050850118, 0.202758165076375, 0.19753811375371047, 1.5055845252105167, 0.661846151309354, 2.63918160540717, 64.30265276772636, 58.962211745125906, 35.3697041784014, 60.164152826581685, 31.835489068712505, 0.6420623500432286, 0.26709002948233057, 0.400760505348444, 0.2655453309416771, 0.16612678713032178, 0.18388172797858715, 0.18131189873175962, 0.22039806709757873, 0.09615346044301987, 0.27417295798659325, 0.21968150697648525], [0.040630378361259184, 0.11529616825282574, 0.07325132936239243, 0.0504643049623285, 0.006091415815587554, 0.027419257443398237, 0.08872342056461743, 0.005260760879277119, 0.042143379138516526, 0.029832613122250353, 1.238810937319483, 45.24490785598755, 42.93931838444301, 21.758690357208252, 52.81885426385062, 36.546628270830425, 8.216117160660879, 1.4431899189949036, 0.15633171344442026, 0.05448061141318508, 0.38403260867510525, 0.7356502424393381, 2.323994598218373, 6.292594364711216, 8.758799263409205, 88.00190203530448, 77.42213712419782, 81.83917645045689, 72.73707798549107, 74.97068064553397, 67.32188129425049, 63.6432409286499, 59.06685161590576, 60.40467861720494, 60.091349601745605, 63.415743010384695, 66.4881044115339, 73.14726488930839, 72.24702153887067, 73.23391587393624, 70.4000027520316, 69.99766036442348, 68.38213471003941, 65.87350150517055, 54.26912743704659, 51.52998774392264, 52.93748780659267, 54.55207545416695, 58.2866244997297, 59.81137193952288, 58.63326317923409, 54.7859275000436, 48.54480191639492, 50.40140226909092, 58.6626193182809, 63.64655521937779, 66.11774458203996, 64.2301274708339, 59.390352794102256, 58.15343795503889, 53.158266816820415, 54.778847285679404, 55.26722574234009, 56.46120071411133, 59.25916385650635, 59.51280089787075, 56.459001609257285, 58.35639830998012, 57.92007923126221, 58.873663902282715, 61.93415778023856, 62.93638678959438, 58.8389368057251, 56.06485114778791, 58.46621458871024, 57.07226351329258, 59.307919366019114, 59.2099289212908, 57.57957928521292, 58.32657664162772, 60.32556642804827, 59.30770397186279, 55.56014442443848, 45.69897263390677, 43.52815737043108, 57.50182546888079, 56.0232001713344, 57.246169975825715, 55.93566329138619, 58.62122195107596, 57.05367708206177, 58.642476490565706, 49.129430294036865, 45.294768129076274, 50.86322471073696, 51.629961899348665, 52.654397351401194, 55.34037290300642, 60.49604742867606, 55.26443951470511, 50.707546847207205, 57.941462312425884, 56.52775750841413, 53.031840869358604, 57.97168697629656, 54.99592638015747, 55.98972027642386, 56.70384917940412, 49.31571844645909, 49.70047494343349, 54.17290530885969, 55.60602685383388, 53.73529733930315, 52.57338482992989, 51.37506723403931, 50.99943024771554, 53.23089633669172, 53.82793419701712, 55.34662280763899, 57.988275800432476, 55.673413957868306, 56.74297448566982, 54.865501744406565, 54.336462429591585, 48.513611452920095, 40.894546917506624, 44.64915541240147, 46.580181394304546, 54.50870827266148, 56.56791462217058, 59.22250516074044, 57.30380875723702, 54.444235937935964, 52.24693761553083, 49.883824007851736, 45.91624627794538, 51.42093229293823, 55.54085622514997, 60.02611991337368, 58.24057183946882, 57.366849763052805, 55.88634845188686, 53.00682388033186, 58.90195001874651, 63.02699129922049, 64.27727099827358, 64.4753085545131, 62.44639982495989, 58.07305424554007, 58.10320247922625, 49.01696327754429, 13.772422211510793, 2.3044582179614475, 0.1251438284026725, 0.11579320872468607, 0.04054366158587592, 0.03817603238193052, 0.047853811111833365, 0.1350602920034102, 0.10779695851462227, 48.909922804151265, 49.71602848597935, 30.193056515284947, 42.72512626647949, 33.15850945881435, 0.027457263886130283, 0.016482663939573934, 0.048147704984460554, 0.028769124831472124, 0.028669963723846843, 0.03744491429201194, 0.023545114256973778, 0.057965170325977464, 0.0187763854129506, 0.028491098500256027, 0.04355745629540511, 0.13164346106350422, 0.06250097336513655, 0.030694980240826095, 0.01815213998114424, 0.1563468447753361, 0.030922981577792337, 0.08229172282985278, 0.05470227523307715, 0.21032330127699034, 0.14146533688264235, 2.7500737692628587, 54.590599741254536, 54.014851161411826, 28.462072644914898, 42.90701273509434, 45.73237262453352, 8.30323280606951, 2.7646115720272064, 0.1403503002864974, 0.07892541560743536, 0.43866697273084093, 1.7312043671097075, 2.704939139740808, 9.939175742013113, 9.708847301346914, 92.57624162946428, 79.34183406829834, 86.04376765659877, 74.63854285648891, 79.1121266228812, 70.29127734048026, 68.04611982618059, 61.55248628343855, 62.859581402369905, 62.146605900355745, 67.54593290601457, 68.83504608699253, 74.42291940961564, 74.47011852264404, 77.44303730555943, 74.28299658639091, 74.45372772216797, 71.03834765298026, 68.3811480658395, 57.124642508370535, 53.05447810036795, 56.07928950445992, 57.858671052115305, 60.23286356244768, 61.92787660871233, 61.63608700888497, 58.72161647251674, 51.5712183543614, 52.35487788064139, 61.93494292667934, 66.57403973170689, 68.01100363050188, 67.78310966491699, 63.16223798479353, 59.72952216012137, 57.04818105697632, 58.90386077335903, 57.80964456285749, 59.41947269439697, 61.342907769339426, 62.953771182468955, 60.47122846330915, 63.56832545144217, 61.949902398245676, 64.36297007969448, 64.12129783630371, 65.33370290483747, 60.58958407810756, 60.92452893938337, 60.817359924316406, 60.165584155491416, 63.06319836207798, 59.24036203111921, 59.13233143942696, 60.02958706447056, 62.79225335802351, 61.57287924630301, 54.42446483884539, 46.06509753635952, 45.07928712027413, 60.084533418927876, 57.475220816476, 56.97854273659842, 56.771764346531455, 59.66707869938442, 58.9695907320295, 59.58549989972796, 53.23533623559134, 46.05401168550764, 51.53480631964547, 52.83359486716134, 52.39011219569615, 55.769736834934776, 61.13297489711216, 58.272672516959055, 51.980053833552766, 59.65414810180664, 57.9840269769941, 54.324091162000386, 58.16205372129168, 57.854613304138184, 58.84767069135393, 59.671198981148855, 52.99561643600464, 51.99865068708147, 57.14594568525042, 57.00406347002302, 56.070083141326904, 55.785464082445415, 55.3383092880249, 54.74116025652204, 55.72712005887713, 55.935034479413716, 57.558693000248496, 59.650208473205566, 56.029463972364155, 60.55815042768206, 59.90367875780378, 57.13272326333182, 51.77522441319057, 45.11593886784145, 45.186935561043875, 50.119882106781006, 56.2244165284293, 60.14809553963797, 59.03829451969692, 58.45086601802281, 57.159845556531636, 54.4890170778547, 51.3963599886213, 48.498356682913645, 53.00700453349522, 58.16550350189209, 61.74693162100655, 60.98060785021101, 59.981637545994346, 56.65578848975045, 55.214502811431885, 61.96211038316999, 65.83960819244385, 65.91938740866524, 68.26326492854527, 67.37409700666154, 65.39619500296456, 64.63798672812325, 51.33792563847133, 17.42726673398699, 3.8806158133915494, 0.07939221377351455, 0.22892886719533376, 0.05330745490001781, 0.027368207861270224, 0.03797299774097545, 0.22492602627192224, 0.10875088375593935, 51.82909379686628, 60.28785855429513, 29.702089854649135, 49.60364137377058, 42.817801339285715, 0.08114219629870993, 0.03317248462034123, 0.07248063571751118, 0.015317641364942704, 0.0015805163898871147, 0.047540836834481785, 0.02597694474804614, 0.018589386250823736, 0.009773126470723321, 0.04754478590829032, 0.04341968993789383, 0.23932692781090736, 0.1491895488330296, 0.11990194182310786, 0.11489845173699514, 0.161084579836045, 0.13841283853564942, 0.2230871013764824, 0.12254482215004307, 0.29164480045437813, 0.23415934081588471, 2.7728058866092136, 66.21895204271588, 55.97209964479719, 33.07598917824881, 71.22975662776402, 51.762554373059956, 20.306852102279663, 4.633331102984292, 0.32385914613093647, 0.3311101070472172, 0.43753276073506897, 1.3879858297961098, 2.0369725482804433, 15.130155801773071, 10.670300807271685, 99.72586154937744, 83.48176533835274, 92.6063620703561, 78.2925796508789, 83.86805738721574, 74.62021350860596, 70.37139007023403, 66.13042504446847, 67.94306414467948, 64.92147323063442, 71.69504274640764, 72.38201808929443, 78.65544237409318, 76.9402448109218, 79.70382826668876, 77.08141830989292, 78.35573877607072, 72.92250456128801, 73.59985664912632, 61.4955666405814, 56.15526805605207, 59.398447445460725, 60.122484479631694, 64.39189543042863, 64.88268838609967, 65.76003742218018, 62.48202323913574, 54.17276634488787, 55.755760533469065, 65.72548403058732, 70.33832359313965, 72.1757538659232, 69.41792351858956, 66.40345450810024, 64.56923430306571, 59.74537794930594, 62.25076634543282, 62.85768454415457, 63.521063804626465, 65.75510420118059, 67.80336366380963, 63.28524889264788, 65.42963668278286, 66.383957862854, 65.30927998679024, 67.17093167986188, 68.80132647923061, 65.03806400299072, 63.55795873914446, 64.36076055254254, 63.83613681793213, 64.64262117658342, 63.704100200108115, 62.077645029340474, 63.940380641392295, 63.90462521144322, 63.15256609235491, 59.93818351200649, 51.0244402885437, 49.882854734148296, 63.27909973689488, 61.25194195338658, 61.5991017477853, 59.329750605991904, 62.85873372214181, 62.314335414341514, 63.44868441990444, 52.91601092474801, 47.2332877431597, 54.207587242126465, 56.056732177734375, 55.157211439950125, 60.019470487322124, 63.575523785182405, 59.188208852495464, 53.42615808759417, 63.066158294677734, 60.34263120378767, 54.74799033573696, 61.48426192147391, 59.82813794272286, 62.138872555324006, 62.03023052215576, 56.75954246520996, 53.60558141980852, 58.61543410164969, 61.2705978666033, 60.52378463745117, 58.553782735552105, 57.605343205588206, 58.86181027548653, 59.04585415976388, 60.08088561466762, 61.263336999075754, 63.54696668897356, 60.22871548788888, 63.406689507620676, 63.2059143611363, 59.45397744859968, 55.484287466321675, 47.28790405818394, 49.60218225206648, 52.44064991814749, 59.31306798117501, 63.7080328805106, 62.98592744554792, 60.46504456656319, 58.95234530312674, 58.47165502820696, 55.765828473227366, 52.27484852927071, 55.962087290627615, 61.12729821886335, 63.41880021776472, 64.25108323778424, 63.585807119097026, 61.067668778555735, 59.29681614467076, 65.90777696881975, 70.09947231837681, 71.01646082741874, 73.68261664254325, 73.97923524039132, 71.72155012403215, 72.78892544337681, 56.232584135872976, 17.717951570238384, 5.035848932606833, 0.32661416115505354, 0.4790030026010105, 0.48984148672648836, 0.2214940640011004, 0.2931860520371369, 0.6087781989148685, 0.7175483937774385, 58.02724824632917, 67.80380140032086, 41.88201795305525, 56.90851184300014, 43.69655391148159, 0.17369526172322886, 0.10610514679657561, 0.11130161902734212, 0.13167571861829075, 0.09976238464670521, 0.15973061748913356, 0.13796964660286903, 0.1766833263848509, 0.10037548853350536, 0.1904332007148436, 0.1787194606981107], [0.04715533055631178, 0.0948285326095564, 0.014858715901417392, 0.05697794258594513, 0.07623353148145334, 0.10523123440465756, 0.10380293176110302, 0.09415653866848775, 0.10257330417100873, 0.17544938331203802, 6.333229601383209, 59.085847990853445, 25.909778697150095, 21.796248844691686, 54.785983085632324, 21.01092869894845, 0.7295807195561272, 0.972660733120782, 0.06435666486088719, 0.0736830404826573, 0.868619330227375, 2.236072961773191, 1.9491864017077853, 0.9164342816386903, 44.65700340270996, 89.82510239737374, 72.67274461473737, 79.30324377332414, 71.30799334389823, 67.192519732884, 60.28545447758266, 63.2722418648856, 60.74992070879255, 62.60139329092843, 63.40070710863386, 68.23876558031354, 68.26767008645194, 74.63821629115513, 71.03829901559013, 70.27635955810547, 69.31631306239537, 70.88970484052385, 68.33305958339146, 69.17181832449776, 65.44004508427211, 53.87226717812674, 49.757262570517405, 52.44597918646676, 54.92416191101074, 56.643094130924766, 56.320958273751394, 54.5109212739127, 50.68144246510097, 52.14505965369088, 61.38399941580636, 62.36418179103306, 62.94755949292864, 61.870915276663645, 58.90709168570382, 56.72696236201695, 52.88441399165562, 53.359535285404746, 54.74714265550886, 55.77609443664551, 59.18755572182791, 59.92678846631731, 55.02459117344448, 55.83844409670149, 60.42336927141462, 59.91722079685756, 64.16247286115373, 58.76220784868513, 56.51768956865583, 61.65601444244385, 56.200855187007356, 58.621895926339285, 58.0007860319955, 56.7698119027274, 58.28299406596592, 59.598652839660645, 61.30430357796805, 48.563218116760254, 44.14946528843471, 44.39718246459961, 54.431263651166645, 55.267472403390066, 57.92384515489851, 58.16485037122454, 59.7072114944458, 58.91987637111119, 57.34091908591134, 60.13023172106062, 58.12481485094343, 50.69305985314505, 46.386114733559744, 55.079537527901785, 56.162848540714805, 48.18410703114101, 55.15488031932286, 61.15682806287493, 50.61146020889282, 52.34075914110456, 57.95063393456595, 53.65938479559762, 53.495323930467876, 56.02894980566842, 55.2225592476981, 51.607230867658345, 51.768779958997456, 51.360872064317974, 52.96768815176827, 53.958939007350374, 53.46424116407122, 51.42724820545742, 49.85440533501761, 48.255016871861045, 48.59844895771572, 51.25413383756365, 54.00089570454189, 54.937669209071565, 54.60884918485369, 55.5880240712847, 55.11410828999111, 55.74802024023873, 52.338410649980815, 43.191402503422324, 42.49255616324288, 43.52414131164551, 52.76082638331822, 56.53550474984305, 58.57828208378383, 57.56537021909441, 54.18228537695748, 49.75000517708914, 48.07699012756348, 47.032797472817556, 53.844179085322786, 58.74986784798758, 61.03356007167271, 60.454233169555664, 56.62587996891567, 52.409403869083945, 53.893066610608784, 59.57406316484724, 63.51032883780343, 63.622215679713655, 64.0343758719308, 62.4091157913208, 57.87899105889456, 55.694154330662315, 58.36568110329764, 27.719395330974034, 6.076084153992789, 0.059233467626784525, 0.12101980112493038, 0.093238100808646, 0.2864601415182863, 0.24522722406046732, 0.07866586917745215, 0.18472321996731417, 36.97652721405029, 57.238384519304546, 29.267698901040212, 31.935894012451172, 41.51252317428589, 0.4213770590722561, 0.09135214665106364, 0.09712346017892871, 0.09397095934088741, 0.07436029985547066, 0.05979306224201407, 0.03711016243323684, 0.015839752009404556, 0.0614858917625887, 0.019632150385794894, 0.006039273792079517, 0.09011730791202613, 0.0928850726091436, 0.019121613852413635, 0.04486334104357021, 0.03657396709812539, 0.04545556301517146, 0.10095600916871003, 0.14138799746121677, 0.2517339677682945, 0.3226638117006847, 11.881132108824593, 66.7211469922747, 39.33661140714373, 21.20927718707493, 54.02237606048584, 25.8175048828125, 1.1209747003657478, 1.4729558931929725, 0.30965982377529144, 0.0804342467870031, 0.9529948340994971, 1.905931477035795, 1.5086530234132494, 0.9554981397730964, 48.761905329568044, 92.1302159173148, 76.64534936632428, 83.09894738878522, 74.70022201538086, 71.10643305097307, 64.02683707645961, 66.22105734688895, 62.481238092694966, 63.50529139382498, 65.21766798836845, 71.73683616093227, 71.54054260253906, 75.27665846688407, 71.77692031860352, 71.23072242736816, 69.76770278385708, 73.31903825487409, 73.43856116703579, 72.20117732456752, 68.42044012887138, 58.090716566358296, 53.0691249029977, 56.24144656317574, 55.869356632232666, 60.69925444466727, 56.36288717814854, 56.14366109030587, 53.409048148563926, 55.85137469427926, 65.19889395577567, 67.05762045724052, 65.43592480250767, 63.96248286111014, 60.68525382450649, 58.63210283006941, 56.962836333683555, 56.73536273411342, 57.5961194719587, 60.501029287065776, 61.62228788648333, 64.8427015032087, 58.82555457523891, 60.41926288604736, 63.31126989637102, 63.311117036002024, 63.980985913957866, 61.610469000680105, 60.88542447771345, 62.68143653869629, 58.410594258989605, 62.6918796811785, 59.47986643654959, 58.23139674322945, 61.229645184108186, 62.75701904296875, 62.27598830631801, 49.90487357548305, 45.66821295874459, 47.66297476632254, 57.12510803767613, 57.17171655382429, 60.316936765398296, 60.66269997188023, 60.2629770551409, 61.600685937064036, 58.80729470934187, 61.602249281747, 59.79082611628941, 53.75991480691092, 45.97568811689104, 56.915460041591096, 59.19697053091866, 51.580174582345144, 55.153497627803254, 61.91541848863874, 53.19553347996303, 52.825378622327534, 59.04247038705008, 55.2054180417742, 54.50956984928676, 58.727654457092285, 58.53996276855469, 55.167004925864084, 54.40000370570591, 53.0203971862793, 54.88108307974679, 56.81848750795637, 54.911241735730854, 54.53823811667306, 53.438452925000874, 51.44267668042864, 51.89457014628819, 53.66856336593628, 56.210065024239675, 58.321198735918315, 59.02561405726841, 57.48397902079991, 57.63007879257202, 58.760401317051475, 54.71857166290283, 45.331993103027344, 45.49122149603707, 47.38452223369053, 53.6508697782244, 59.23788847242083, 60.131079401288716, 60.358209065028596, 56.11510746819632, 51.843125683920725, 48.72407933643886, 49.1707547051566, 57.02069050925118, 59.55971513475691, 62.78648635319301, 61.909734862191335, 58.912928172520225, 55.35981396266392, 56.143907751355854, 61.341559818812776, 65.64578819274902, 66.4261612210955, 68.82472801208496, 65.6948355266026, 63.60776342664446, 62.72941384996687, 61.427918979099815, 30.910513605390275, 8.541428344590322, 0.13298672969852174, 0.041827293778104443, 0.1450089453054326, 0.39256507796900614, 0.40135737189224785, 0.2765337441648756, 0.2189004317458187, 39.31783390045166, 68.94753047398159, 27.064352171761648, 38.873291628701345, 51.14887210300991, 1.2059886242662157, 0.13192693942359515, 0.030997807026973793, 0.03277942964008876, 0.04097830397742135, 0.008906991786456533, 0.05021450908056327, 0.04532762863008039, 0.029450248461216688, 0.006966888838048492, 0.026132609163011824, 0.16481635959020682, 0.25212445110082626, 0.0978958365906562, 0.10989160968789033, 0.17002518794366292, 0.20767990526344093, 0.17092545463570527, 0.26207706704735756, 0.317246252404792, 0.47451408633163994, 11.129676614488874, 81.44530391693115, 37.2044871875218, 33.33078309467861, 73.14481912340436, 30.689811025347026, 3.1909769220011572, 5.715106998171125, 0.9733112582138607, 0.16276554177914346, 2.2866914570331573, 4.748138793877192, 3.2912869794028143, 1.8294239938259125, 51.047949518476216, 97.14508519853864, 80.69530146462577, 88.18227727072579, 80.37760898045131, 77.56039932795933, 69.22046266283307, 70.86804730551583, 67.80169609614781, 67.37476403372628, 70.40073231288365, 76.52590288434709, 72.4359986441476, 79.4184240613665, 75.42505809238979, 76.00062601906913, 71.55580084664481, 76.88188689095634, 75.8018866947719, 76.94633838108608, 71.74690410069057, 60.45000866481236, 55.123495306287495, 59.77580411093575, 61.00637871878487, 64.1639597756522, 60.741339683532715, 60.61172798701695, 55.89795889173235, 59.98552853720528, 67.26312037876674, 70.63338579450334, 65.53544385092599, 66.44581072671073, 64.99307441711426, 63.35896927969796, 61.308020864214214, 60.235781805855886, 61.16191414424351, 62.89815780094692, 66.2429997580392, 68.24107238224575, 62.050491469247, 63.342425618852886, 64.5311859675816, 62.2547824042184, 67.94724696023124, 65.4306719643729, 61.98021738869803, 66.19787120819092, 61.06324972425188, 65.63625526428223, 62.47136470249721, 60.472215107509065, 64.2620405469622, 63.62471008300781, 66.16126809801374, 54.31961652210781, 47.23468085697719, 49.20306035450527, 59.52129854474749, 58.905299050467356, 61.525763511657715, 63.42208671569824, 61.632807459150044, 63.14424909864153, 59.77401842389788, 64.5119047164917, 61.13513578687395, 53.106301239558626, 49.19192934036255, 59.07018675122942, 59.807321139744346, 53.95614930561611, 59.10392720358712, 64.27447782244, 53.087780816214426, 56.11645541872297, 60.9080617087228, 58.632721219744, 56.97161190850394, 61.27794211251395, 60.771661622183665, 56.70215034484863, 57.64038297108242, 56.99552065985543, 58.22089801515852, 61.664776120867046, 58.896780558994834, 58.53365380423409, 57.2511796270098, 55.29424033846174, 54.047333989824565, 57.94335569654192, 60.17308126177107, 60.20486927032471, 62.164768491472515, 62.22220924922398, 61.234105927603586, 61.94920757838658, 58.35070078713553, 48.131029742104666, 48.324689933231895, 49.26203319004604, 60.66408266339983, 61.66174670628139, 64.19975689479283, 64.77985504695347, 61.14393220629011, 55.33314330237252, 53.37045785358974, 52.95501463753836, 60.07089410509382, 62.50038037981306, 67.58097267150879, 65.55489880698067, 61.638338225228445, 58.18845340183803, 59.58560412270682, 64.98091506958008, 72.96900885445731, 71.07545798165458, 74.85627160753522, 73.45615400586809, 71.20524338313511, 70.32665756770542, 67.85052803584507, 32.78770841870989, 10.080908570970808, 0.43591111632330076, 0.5189186664564269, 0.3647738849478108, 0.7815782693879945, 0.7685087078383991, 0.9171267130545208, 0.23703711639557565, 44.97781910215105, 75.665771484375, 40.5430896622794, 44.55572993414742, 58.31459099905831, 1.258382492831775, 0.27041751093098093, 0.18042484990188054, 0.24748840129801206, 0.244938710970538, 0.15923553119812692, 0.12338974752596446, 0.1389539430716208, 0.22307414135762624, 0.11479973846248218, 0.13577511507485593], [0.0764480706836496, 0.022905511881357858, 0.01872741723699229, 0.08344283034758908, 0.04497185575642756, 0.03704016476071306, 0.07156824360468558, 0.0764552020866956, 0.04789842139663441, 0.21321767382323742, 27.143773555755615, 50.03870977674212, 25.811357464109147, 32.39374555860247, 43.59459604535784, 8.213598438671657, 0.44503760231392725, 0.5193679109215736, 0.29462023079395294, 0.020152484964845434, 1.6577608223472322, 1.5885350512606757, 0.34475009941629, 1.182619335395949, 63.94069331032889, 80.54633903503418, 76.27444062914167, 74.48356328691754, 66.46403585161481, 63.845600264413015, 62.68454933166504, 63.233804430280415, 62.861818722316194, 60.58667973109654, 64.945159639631, 67.98054272787911, 71.88321386064801, 74.26222147260393, 72.89433656420026, 71.45371791294643, 70.48947470528739, 69.99490887778146, 71.71078736441476, 70.3884687423706, 66.71588025774274, 62.227385657174246, 50.44868128640311, 50.07175888334002, 49.34075975418091, 51.90358543395996, 49.014274324689595, 51.55143335887364, 47.13530772072928, 57.53638233457293, 61.202693121773855, 63.3367280960083, 63.54339531489781, 61.43946688515799, 56.72554840360369, 54.14195108413696, 50.702874183654785, 52.13194840294974, 52.04369933264596, 57.68068599700928, 57.4061279296875, 58.056395939418245, 59.175347736903596, 57.83142369134085, 57.48932565961565, 57.869346959250315, 58.4796176637922, 57.56365401404244, 60.119448116847444, 56.93614135469709, 59.299421719142366, 58.08268444878714, 55.70237752369472, 57.79877758026123, 58.77884183611189, 62.101887294224326, 51.90953656605312, 50.777195589882986, 49.763324873788015, 53.16622250420706, 59.76269980839321, 59.79233387538365, 59.80108165740967, 58.81238079071045, 59.14651966094971, 57.750167982918875, 60.79628603799002, 61.00469725472586, 61.12694386073521, 59.58035128457205, 49.066959040505544, 46.121374470846995, 59.49483980451311, 58.866701807294575, 50.17623547145298, 53.390850816454204, 56.98987177440098, 50.275313309260774, 54.56642001015799, 52.779715061187744, 53.03335905075073, 55.56929520198277, 55.03111553192139, 52.74740941183907, 50.770469733646934, 53.043326241629465, 55.83353866849627, 54.77623476300921, 52.13459914071219, 51.75940683909825, 50.55760472161429, 48.00921392440796, 47.20059994288853, 47.29071807861328, 52.41762358801705, 52.84347173145839, 53.28429324286324, 54.12605707986014, 54.09630836759295, 57.073055607931956, 52.74172578539167, 44.67606578554426, 42.85218102591378, 44.78068828582764, 43.94869361604963, 49.69770608629499, 52.56318487439837, 51.63971717017037, 49.23655761991228, 46.94728946685791, 45.38048110689436, 51.28927435193743, 60.37162603650774, 58.89028399331229, 62.77684225354876, 58.20989554268973, 56.80232947213309, 51.6659848349435, 54.79024927956717, 59.55255849020821, 63.327195167541504, 63.431668281555176, 64.44395133427211, 59.94337381635393, 57.60060453414917, 55.45752647944859, 64.28684561593192, 43.12590183530535, 11.896876726831708, 0.24571669208151953, 0.03653310911197748, 0.14336184225976467, 0.3457002927150045, 0.19288701404418263, 0.10479648344750915, 0.23393802983420237, 30.837422030312673, 67.00615515027727, 30.872579915182932, 24.260590757642472, 43.80159330368042, 2.877809452159064, 0.23157053972993577, 0.03261201808761273, 0.08902672571795327, 0.03856964376089828, 0.04761479036616428, 0.048469669850809236, 0.03766279527917504, 0.010036479482161147, 0.023651260882616043, 0.02788992834809635, 0.049427381317530356, 0.05104657282520618, 0.04585501318797469, 0.009705783566460013, 0.1254808838878359, 0.05177749074729426, 0.06935197860002518, 0.13424822129309177, 0.03678557163636599, 0.1568515391222068, 39.706241675785606, 57.639375482286724, 34.07342045647757, 28.715426547186716, 52.6146571295602, 9.391284227371216, 0.6030921297413963, 0.9275738724640438, 0.1578628955675023, 0.049824765351201804, 0.7409101373382977, 0.2245276447917734, 0.2453859741134303, 1.5545100484575545, 64.79623195103237, 82.64746039254325, 78.96764578138078, 78.05583368028913, 70.56452914646694, 65.3516570499965, 65.63844394683838, 65.7142835344587, 64.29926204681396, 63.402631759643555, 66.60160323551723, 70.25658498491559, 73.33904906681606, 76.15748855045864, 74.3604759488787, 73.0474053791591, 70.83559226989746, 72.64346490587506, 72.35430172511509, 71.04972185407365, 69.32426180158342, 65.98261601584298, 52.45892368044172, 52.468143939971924, 51.47917209352766, 55.02124908992222, 51.79351207188198, 54.139387198856895, 49.95612696238926, 60.61354146684919, 63.1263644354684, 65.05139759608677, 63.97275924682617, 63.98542581285749, 57.634702818734304, 57.128741945539204, 53.444445746285574, 55.638631275721956, 57.25577586037772, 58.63907882145473, 61.570655822753906, 61.99562849317278, 62.38278211866106, 60.324732644217356, 61.417990003313335, 61.25440856388637, 59.7360326222011, 59.30298614501953, 62.78814002445766, 60.80538122994559, 60.76480375017439, 59.35493087768555, 58.25150482995169, 61.863188879830496, 62.47978591918945, 61.72592026846749, 56.983392579214915, 53.95373133250645, 51.972945826394216, 56.642100538526265, 61.32562065124512, 62.018098967415945, 63.629136085510254, 60.34281880514962, 61.09126486097063, 57.33068438938686, 62.091562271118164, 60.19705949510847, 63.539733614240376, 60.76900046212332, 52.84100859505789, 47.73872402736119, 57.90137815475464, 62.53188351222447, 53.32907785688128, 53.123504979269846, 58.929701123918804, 50.420947551727295, 55.469904695238384, 55.67277819769723, 56.52309874125889, 56.97062179020473, 55.68518420628139, 58.529867036002024, 53.0553639956883, 56.126686641148154, 58.849129813058035, 59.493033272879465, 55.852257115500315, 55.98414782115391, 53.469348090035574, 52.1869329724993, 49.82286746161324, 51.2504096031189, 54.3319148336138, 56.14191014426095, 56.44844382149832, 56.002032484327046, 56.55219084875924, 58.915999276297434, 54.86409820829119, 47.24276508603777, 46.28596339906965, 45.97354807172503, 46.776801518031526, 50.78894846779959, 54.23889582497733, 51.07942485809326, 50.13974353245327, 49.30824218477522, 47.76620415278843, 53.71978548594883, 61.92606312888009, 61.416447503226145, 63.09862722669329, 60.98935563223702, 58.86146286555699, 52.367325578417095, 57.95742927278791, 61.75119086674282, 66.58851282937187, 66.96835000174386, 67.05258301326207, 64.77790260314941, 63.497697012765066, 62.99436950683594, 67.39996515001569, 45.71123273032052, 15.457513230187551, 0.9287150055170059, 0.1599547647471939, 0.2218702302447387, 0.7586360775998661, 0.3512821931924139, 0.3033449154879366, 0.18143503926694393, 32.88821758542742, 76.83775888170514, 32.374450411115376, 26.275945288794382, 56.06233589989798, 5.267240013395037, 0.3336698125515665, 0.04452701159087675, 0.06735003566635506, 0.012258817375238453, 0.0454513221713049, 0.01980785363619881, 0.062031902106744904, 0.02214243818473603, 0.040365261158772876, 0.03008654128227915, 0.14724094553717545, 0.09241653060806648, 0.18155771839831555, 0.1242942347058228, 0.2306442308638777, 0.2208005062171391, 0.17156774231365748, 0.19653066567012242, 0.13459402987999575, 0.27984689495393206, 45.78027350561959, 69.05441461290631, 36.789933340890066, 44.76587472643171, 64.19246128627232, 12.316973498889379, 1.1313149226563317, 2.342636832169124, 0.9403208856071744, 0.11547394442771163, 4.021701157093048, 4.459368186337607, 1.1824757031032016, 2.2304507834570746, 69.60215500422886, 88.49341760362897, 85.38930293491909, 84.51972198486328, 76.14011805398124, 69.738707951137, 71.2458347593035, 71.63448919568742, 69.67125483921596, 67.87745230538505, 72.827515738351, 73.67775290352958, 75.38987936292375, 80.7525337764195, 78.07212720598493, 76.79326956612724, 75.60045146942139, 76.50934532710484, 75.14455236707414, 75.9798231124878, 72.00730173928397, 67.93363543919155, 55.916750294821604, 56.31017814363752, 54.079927989414756, 58.83303083692278, 53.71928521565029, 57.88529307501656, 50.54931204659598, 63.97525365012032, 65.61305522918701, 69.89140156337193, 65.81110668182373, 65.15244524819511, 62.64126205444336, 59.11166054861886, 55.105777399880544, 59.232670375279014, 60.59490639822823, 63.57924107142857, 64.76266520363944, 64.83703872135708, 67.08758803776333, 63.43865816933768, 65.14571939195905, 63.00597994668143, 60.98290075574602, 62.79320526123047, 65.1753465107509, 61.92228330884661, 63.360080991472515, 63.85593223571777, 60.605029923575266, 65.86518451145717, 62.62082740238735, 67.55611896514893, 59.5710893358503, 55.599905490875244, 52.65802778516497, 57.97700582231794, 65.01405102866036, 63.43901947566441, 64.08112335205078, 65.3676518031529, 64.04789706638881, 60.19350201742989, 64.09274074009487, 63.43624019622803, 65.82159151349748, 62.704817226954866, 52.135505880628315, 52.50132506234305, 60.983296803065706, 65.20090198516846, 54.725485120500835, 56.866263321467805, 60.102855818612234, 52.958158697400776, 59.25853851863316, 57.57720300129482, 57.72204862322126, 58.73554066249302, 58.53721128191267, 60.197622299194336, 56.98969806943621, 59.073320388793945, 61.86782332829067, 63.837290218898225, 58.48939377920968, 58.946216991969514, 58.7625344140189, 55.81894745145525, 54.256822177342, 55.47457388469151, 58.59009402138846, 59.56321702684675, 60.93273476191929, 59.04524966648647, 59.280487877982004, 62.740037645612446, 58.241197177342, 49.8425795010158, 48.88543387821743, 50.29245104108538, 49.871028900146484, 54.246854986463276, 58.53440420968192, 56.07379000527518, 53.765185015542166, 52.06909499849592, 51.114113739558626, 57.76141711643764, 65.96073613848004, 63.09817559378487, 67.55731405530656, 63.45231137956892, 62.65741661616734, 57.260038580213276, 60.21368653433663, 65.36533110482353, 70.82539926256452, 71.99025085994175, 74.51398944854736, 69.93349375043596, 70.11648845672607, 71.17294815608433, 75.9004190989903, 47.449164799281526, 17.761414289474487, 1.9864118099212646, 0.441224995468344, 0.39316902841840473, 2.0291425798620497, 0.7884529147829328, 0.9463328144380024, 0.3358246497809887, 40.03616646357945, 85.46858882904053, 44.235133102961946, 33.13000794819423, 60.7342803137643, 5.2714093668120245, 0.6051289290189743, 0.1374381094106606, 0.1940897987889392, 0.19245941484613077, 0.12623010868472712, 0.14814152435532638, 0.15729664452373981, 0.17118202229695662, 0.13963112102023192, 0.09446800659809794], [0.01884340601308005, 0.00549894872321082, 0.03496220554890377, 0.022818722163460085, 0.07915609037237507, 0.04161698863442455, 0.03258881897532514, 0.036924488110733886, 0.05619169691843646, 2.6159759249006, 47.10860579354422, 37.57255411148071, 26.632935047149658, 33.87456996100289, 37.34747764042446, 6.762436330318451, 0.5830599846584457, 0.38792384415864944, 0.3314276342945439, 0.15842789810683044, 0.9689084887504578, 0.5707619445664542, 0.11453266707914216, 1.8261843962328774, 67.0295080457415, 81.80547073909214, 75.60780961172921, 70.70869037083217, 67.78265803200858, 69.32718004499162, 69.37940270560128, 65.48964132581438, 61.931969097682405, 61.85291944231306, 61.03315012795584, 68.69360855647496, 70.17172663552421, 72.74105930328369, 70.70730767931256, 70.4946928024292, 68.12646879468645, 66.46522399357387, 65.64762251717704, 68.06383773258754, 67.04630878993443, 68.11658150809151, 54.98659494944981, 48.56514971596854, 49.97278526851109, 49.84514338629586, 49.746430328914094, 48.27579198564802, 49.85794544219971, 60.65873255048479, 62.374312264578684, 62.475088936941965, 63.69993128095354, 58.47381591796875, 55.23455531256539, 52.8624472618103, 50.879281997680664, 50.39153235299246, 54.224711077553884, 55.49132946559361, 57.37059484209333, 57.657228878566194, 54.68876041684832, 58.05634035382952, 60.00553240094866, 52.65959460394723, 55.18199913842337, 58.606325013296946, 59.61179883139474, 58.6937472479684, 57.42992550986153, 56.7567458152771, 59.118289130074636, 54.77836785997663, 61.02441624232701, 48.96742262159075, 51.343782969883506, 53.764094148363384, 48.30607918330601, 57.73290170942034, 56.33421196256365, 58.509578296116416, 58.88244642530169, 55.61479548045567, 54.14160714830671, 56.03336191177368, 58.77044841221401, 58.07438135147095, 55.45576163700649, 53.651210239955354, 58.729044096810476, 46.817823682512554, 45.42978204999651, 58.59419345855713, 58.461934498378206, 50.48138298307146, 57.34930903570992, 50.70229748317173, 52.09453582763672, 56.0524069241115, 54.6181424004691, 55.54794338771275, 50.92280203955514, 53.66365098953247, 52.73826558249337, 52.3175938470023, 54.831226280757356, 52.241768155779155, 54.41685308728899, 50.39529480252947, 48.63876935413906, 45.45490673610142, 43.97656284059797, 46.98091527393886, 49.25395243508475, 50.956698826381135, 53.52271025521414, 54.93297222682408, 53.67965963908604, 55.349287441798616, 51.36619438443865, 42.88763073512486, 41.797256878444124, 44.964478560856406, 46.93651281084333, 43.960991927555625, 45.11792605263846, 44.68741914204189, 43.74494464056832, 43.56629603249686, 51.393330574035645, 54.6116076196943, 58.75932434626988, 56.98287493841988, 60.342978613717214, 56.75950077601841, 55.10654170172555, 50.78448077610561, 55.44956731796265, 61.893066133771626, 62.661717551095144, 63.757524899074006, 62.68516077314104, 58.040182318006245, 54.27976165499006, 52.31580121176583, 64.17923191615513, 54.871133259364534, 23.470399924686976, 0.9698571349893297, 0.0033098280878870612, 0.12274113590163843, 0.39851534153733936, 0.07705123403242656, 0.06047622486948967, 0.16723011221204484, 24.75181450162615, 65.8281158719744, 37.44765329360962, 22.67931972231184, 30.000080721718923, 7.562344653265817, 0.3104366106646401, 0.07127747099314417, 0.08279469369777612, 0.04911372171980994, 0.055651047000927586, 0.07357202536825623, 0.04247228202543088, 0.035000580096883435, 0.023337275588086674, 0.061460107431880066, 0.016627098599980985, 0.04952220658638647, 0.01802180358208716, 0.018692075740545988, 0.04270785242053015, 0.04041564238390752, 0.03449667624330946, 0.04953818947875074, 0.038616174299802096, 5.427601831299918, 58.90645245143345, 47.091151918683735, 34.902635846819194, 34.033652441842214, 47.14514984403338, 7.004161987985883, 0.6479970344475338, 0.9105381923062461, 0.7133751862815448, 0.1925574495856251, 0.5423938067896026, 0.2162652731473957, 0.17362875172070094, 1.9362019555909293, 68.90167236328125, 82.2305337360927, 77.92832728794643, 74.17820385524205, 70.19035475594657, 71.127242905753, 70.42703124455043, 68.51530388423375, 64.38082695007324, 64.92333534785679, 64.90786170959473, 72.5457454408918, 71.9839835848127, 75.63142653873989, 71.49633121490479, 73.56489331381661, 68.3008199419294, 69.20585754939488, 67.41903795514787, 70.79101957593645, 68.48317541394914, 71.54182801927838, 58.988330023629324, 50.078856468200684, 53.65985727310181, 52.05010904584612, 53.028266021183555, 49.88204179491316, 52.59466368811471, 62.13270255497524, 65.05865846361432, 64.97158363887242, 64.9556861604963, 60.62335927145821, 59.2349076952253, 54.854884896959575, 52.85972704206194, 53.55695097787039, 56.177804538181846, 58.01043013163975, 61.0195038659232, 60.24723938533238, 57.353884424482075, 62.410595757620676, 61.83207484654018, 56.62862798145839, 57.38050992148263, 62.01322133200509, 61.826419012887136, 60.09123148236956, 59.17737661089216, 58.94491767883301, 58.93989413125174, 60.73168863568987, 62.15793146405901, 52.296572072165354, 53.85786356244768, 54.3903352873666, 51.37935427256993, 58.515185492379324, 58.27688659940447, 59.09465830666678, 60.081427574157715, 56.96673774719238, 56.42585175377982, 59.2725738797869, 60.18455968584333, 59.48246506282261, 55.12914766584124, 55.083105427878245, 59.76056671142578, 48.88067436218262, 46.544481549944194, 58.71616908482143, 60.42895562308175, 52.68784597941807, 56.52035420281546, 54.359276839665, 53.45731381007603, 56.96108538763863, 54.43787486212594, 56.52172647203718, 54.57996899741036, 54.01067181995937, 55.98702784946987, 52.97957304545811, 56.22147396632603, 56.104452405657085, 55.731716292245046, 52.65757615225655, 50.4533747945513, 49.10232189723423, 48.44610275541033, 48.48497445242745, 50.947464670453755, 53.05391877038138, 55.73731306621006, 57.54757588250296, 56.68932744434902, 56.95098270688738, 54.549539361681255, 44.42679221289498, 44.7479692186628, 47.9072699546814, 49.33154296875, 45.45094973700387, 46.215803963797434, 46.35557740075247, 46.35991655077253, 46.10233293260847, 54.81399474825178, 57.19290508542742, 61.03543608529227, 59.39079053061349, 62.18839931488037, 58.10045099258423, 55.37125069754464, 53.317113058907644, 57.624662671770366, 63.48632975987026, 65.89993245261056, 66.0367841720581, 66.82700974600655, 65.50002888270787, 60.97671685900007, 60.82309218815395, 67.67170919690813, 59.21639769417899, 28.234381914138794, 2.455018950360162, 0.13577515578695706, 0.08383578354758875, 1.451370662876538, 0.39880059765917913, 0.10631518731159822, 0.1331734625356538, 27.20997772897993, 74.54328305380685, 42.68929788044521, 23.918854032244, 40.90004989079067, 11.79206575666155, 0.23028403733457836, 0.0406801726536027, 0.03471839434600302, 0.010393797719318951, 0.0363298743031919, 0.1235127252127443, 0.05619820746194039, 0.06965829644884382, 0.011580910001482283, 0.0505584856229169, 0.19900996477476188, 0.0679110891318747, 0.15077242175383226, 0.09853950848004647, 0.17503387560801847, 0.104957411597882, 0.16757640934416226, 0.11752810063106672, 0.1886009526039873, 5.069876866681235, 72.08011191231864, 51.793216773441856, 40.56239175796509, 43.9261988231114, 57.01232835224697, 9.218096903392247, 0.9259639531373978, 3.2516470721789767, 1.5239397117069788, 0.6311478157128606, 2.2837908012526373, 1.5943360371249062, 0.33543514353888376, 2.797185378415244, 73.91001033782959, 87.1068559374128, 83.19395010811942, 78.7771748134068, 76.07667405264718, 74.6995827811105, 76.99451719011579, 72.08024392809186, 69.20786557878766, 68.77530547550747, 68.86711202348981, 76.15541798727853, 73.98688520703996, 78.45343044825962, 75.44581236158098, 77.51548617226737, 73.85448033469063, 71.58096027374268, 70.35522856031145, 72.55534090314592, 71.39779881068638, 74.20065348488944, 62.71417645045689, 53.12972709110805, 57.00896889822823, 54.63386617388044, 54.83601358958653, 52.38978215626308, 54.50974008015224, 66.65188734872001, 69.20808792114258, 67.58483586992536, 68.11216245378766, 62.84497628893171, 61.07174737112862, 58.21467242922102, 56.864349092756, 56.795561926705496, 60.547755922589985, 60.90530327388218, 63.90545204707554, 64.32080146244594, 59.98703629629952, 65.332521711077, 65.82541302272251, 58.401770046779085, 61.38336018153599, 63.68526363372803, 63.51126684461321, 64.71682098933628, 61.92549337659563, 64.36575630732945, 61.718603815351216, 60.69020789010184, 68.48748329707554, 55.227607113974436, 55.194478103092735, 57.04075343268258, 53.31865208489554, 62.550018310546875, 59.5695537839617, 61.09504468100411, 61.00546155657087, 59.066657066345215, 57.13933447429112, 61.16513810838972, 62.986316544669016, 60.614889417375835, 57.82432263238089, 57.88316345214844, 64.27859115600586, 50.826562540871755, 49.82279103142874, 60.056636401585166, 62.285569872174946, 55.941051619393484, 60.75832108088902, 54.39085292816162, 56.34519706453596, 59.35784217289516, 58.32144887106759, 60.812933921813965, 55.170683997017996, 58.46717344011579, 57.80613224846976, 56.498533385140554, 60.560436385018484, 58.64359515053885, 59.94502748761858, 55.42094421386719, 55.739296776907786, 52.79452167238508, 52.37790073667254, 52.34402132034302, 56.77205269677298, 57.62427009854998, 61.80403886522566, 59.83425235748291, 61.25905690874372, 61.93842397417341, 58.861574036734446, 48.69795410973685, 47.105350562504356, 50.982150077819824, 52.47654431206839, 47.619492939540315, 50.97430208751133, 48.587317943573, 49.20816380637032, 48.59358869280134, 57.38762140274048, 58.019532271793906, 63.59864044189453, 61.08695697784424, 66.32709380558559, 60.533671924046104, 58.831516129629954, 56.84760740825108, 61.961665698460166, 68.34137657710484, 70.01748357500348, 70.14453833443778, 73.22573784419468, 73.90384033748082, 69.12527929033551, 69.1836302621024, 76.63092490604946, 61.931593894958496, 32.10818154471261, 4.703538307121821, 0.4456356902207647, 0.30511961025851114, 3.251650329147066, 0.8168882546680314, 0.427458008485181, 0.14036165896270955, 34.04446036475045, 84.48702376229423, 54.386569363730295, 31.465344633374894, 54.2860358783177, 17.01313672746931, 0.8433230561869485, 0.38201980239578653, 0.26294437050819397, 0.20887062565556594, 0.21799259260296822, 0.2361691886825221, 0.186597184411117, 0.14677291922271252, 0.07585762308112212, 0.11301589703985623], [0.07891584826367241, 0.05897813489926713, 0.01103619226653661, 0.038172354722129445, 0.06332019583455153, 0.006405069052042174, 0.024335432830931883, 0.08947193968508925, 0.12519702554813453, 17.58662019457136, 54.47087185723441, 24.678573540278844, 23.867810828345164, 40.06107228142874, 39.38798986162458, 6.553751962525504, 0.40559642442635124, 0.4663618409207889, 0.21802782214113645, 0.09121951341096844, 0.11823279996003423, 0.0758985998108983, 0.19569205066987447, 2.045752248593739, 56.89634902136666, 80.19665704454694, 73.90356240953717, 73.66910239628383, 71.03715256282261, 72.93344797406877, 73.87855584280831, 73.17170170375279, 66.76462187085832, 61.130285944257466, 62.47594356536865, 64.60721315656389, 71.8793784550258, 70.87780952453613, 69.86563069479806, 67.976637840271, 66.75763198307583, 67.08985315050397, 68.79407255990165, 67.48554611206055, 67.49014581952775, 68.08727400643485, 60.86400318145752, 50.5797312600272, 48.92210299628121, 49.81573166166033, 50.21138293402535, 47.15171936580113, 51.83248799187796, 61.1662289755685, 61.59139619554792, 61.09438460213797, 59.93668270111084, 57.24040991919381, 55.64841781343733, 50.53645787920271, 50.68362767355782, 50.578491006578716, 52.56433827536446, 53.88323490960257, 54.672498158046174, 57.955320494515554, 58.51223250797817, 60.08073970249721, 59.064503124782014, 56.47909927368164, 54.417686871119905, 62.09417479378836, 57.425110408238, 56.179340090070454, 57.54597084862845, 56.02156039646694, 57.048281805855886, 58.52872058323452, 51.81646892002651, 51.549401010785786, 54.583814825330464, 48.1786596434457, 53.96155500411987, 56.38026114872524, 57.56771871021816, 58.17651987075806, 56.55997977937971, 55.65048142841884, 58.95988409859793, 58.623507908412385, 57.46587201527187, 58.33465044839041, 54.82472276687622, 53.81384672437395, 55.79802642549787, 53.148056438991, 47.583786146981375, 48.453811781747, 57.53883504867554, 55.53101757594517, 51.897248676845, 58.89793395996094, 52.66518095561436, 53.74864135469709, 53.818915435246055, 53.03490849903652, 55.48707716805594, 51.78785276412964, 49.65502677645002, 53.98802416665213, 55.26991816929409, 53.44757243565151, 53.17063808441162, 50.314521993909565, 48.104060309273855, 46.00195230756487, 45.89436987468174, 44.53202268055507, 47.438231808798655, 50.80652046203613, 53.43562848227364, 53.41615615572248, 53.570649351392476, 51.82532787322998, 50.343186787196565, 41.8848945072719, 44.64199876785278, 45.69913591657366, 45.453843661717, 44.01560476848057, 44.35366242272513, 42.984648432050435, 44.91453838348389, 48.15411165782383, 55.91350548607962, 60.040224756513325, 61.30708980560303, 59.59918785095215, 61.805734225681846, 55.396125248500276, 52.46572249276297, 52.00036341803414, 56.98146792820522, 60.24159049987793, 63.93419674464634, 63.708262171064106, 60.31223283495222, 54.561914103371755, 50.244991370609824, 51.05895893914359, 62.6832708631243, 62.540061541966026, 39.337618895939414, 6.087747573852539, 0.15023148006626538, 0.11207813450268336, 0.5975735772933278, 0.34029614127108027, 0.06355745917452232, 0.3050758040377072, 22.82580164500645, 67.13147286006382, 40.24005440303257, 28.250802244458878, 16.814868143626622, 7.829670514379229, 0.11727329716086388, 0.07297906040080956, 0.0819764890308891, 0.05672227737626859, 0.03623858420178294, 0.05160130912970219, 0.05411324916141374, 0.08421994971909694, 0.11818322619157177, 0.06039372179657221, 0.019800835887768438, 0.020643652716119374, 0.004398503174473132, 0.04148243174755147, 0.06279177311807871, 0.0323812483277704, 0.011841892381198704, 0.07552501878568105, 0.1254308351448604, 26.548552649361746, 67.04960918426514, 33.692499365125386, 24.91126697404044, 38.82510587147304, 49.42259563718523, 6.875497852052961, 0.18835710068898542, 0.3030628620513848, 0.2591982329530375, 0.11943395622074604, 0.16522987240127154, 0.06108661461621523, 0.30971625074744225, 2.351702711411885, 58.973565101623535, 81.74955858503068, 76.83012975965227, 75.29529353550502, 74.31913416726249, 73.71395301818848, 76.73620401109967, 76.65506294795445, 69.34031214032854, 63.58460508074079, 64.87542751857212, 66.15431989942277, 73.84443323952812, 73.64808409554618, 71.23026384626115, 70.73827580043248, 69.7878942489624, 69.29194572993687, 69.84480694362095, 69.46811035701207, 68.75075054168701, 70.49426896231515, 63.48896312713623, 53.01719754082816, 51.11172355924334, 52.449390751974924, 52.75360025678362, 51.45006261553083, 53.81044210706438, 65.418304170881, 63.645568575177876, 62.56827122824532, 62.65256677355085, 61.19523770468575, 56.002692563193186, 52.51490879058838, 53.034279687064036, 54.74667712620327, 55.54309701919556, 56.465862955365864, 58.94431318555559, 61.02005277361189, 60.880352292742046, 61.68719795772007, 60.15305655343192, 59.9972779410226, 60.022506850106375, 63.49177714756557, 59.429721287318635, 59.09607573917934, 60.38233321053641, 58.556603704180034, 59.360885483878, 60.90036310468401, 52.81668642589024, 55.500341279166086, 54.471795967647004, 51.940271922520225, 57.85967854091099, 58.141883100782124, 60.30045563834054, 59.69894313812256, 57.31469311032976, 59.21356977735247, 59.670538902282715, 60.51413358960833, 58.812061173575266, 58.07646581104824, 56.701816831316265, 54.95253487995693, 58.962510517665315, 55.682133947099956, 52.150142260960166, 49.17869302204677, 58.39732319968087, 57.39966263089861, 52.91505207334246, 60.4301507132394, 54.52266025543213, 55.242080211639404, 56.74348170416695, 56.08984381811959, 58.07140057427542, 54.609102794102256, 51.463948590414866, 55.59760563714163, 57.74276120322091, 56.053403990609304, 55.0766818182809, 53.01450163977486, 50.52658796310425, 49.91379853657314, 50.237799985068186, 49.489381722041536, 50.613332748413086, 53.85622031348092, 56.05742699759347, 55.586648327963694, 57.58560684749058, 53.20695979254586, 52.68518829345703, 44.24356474195208, 47.80271346228463, 46.06437839780535, 48.61205005645752, 46.77237898962838, 46.56503432137625, 43.89634588786534, 46.562345368521555, 50.35086107254028, 57.832712582179475, 60.16038690294538, 63.422927447727744, 61.427766118730815, 61.168598311288015, 57.25166252681187, 54.63341801507132, 53.77333525248936, 58.93973432268415, 61.89129434313093, 66.20900222233364, 66.87257603236607, 64.64642184121269, 64.44860662732805, 58.07837309156145, 60.089480536324636, 66.762877873012, 65.5545722416469, 43.598132678440635, 9.894604785101754, 0.19498884411794798, 0.3337823136576584, 1.5624442398548126, 0.17056919660951408, 0.13350122209106172, 0.2871784386890275, 26.78336180959429, 75.25178391592843, 48.4545830317906, 28.285824639456614, 23.46105980873108, 16.962600742067607, 1.0725721376282829, 0.017216070388842906, 0.049084188483123264, 0.03641684213653207, 0.06368540373763867, 0.06706439956490483, 0.031083451717027595, 0.07221756769078118, 0.07791519910097122, 0.06460789923689195, 0.24456388822623662, 0.15050790166216238, 0.07602948243064539, 0.11258107144385576, 0.1576297373643943, 0.08583894784429244, 0.0878259019394006, 0.14531378394791059, 0.2695903496018478, 29.548656259264263, 83.45666149684361, 40.03124713897705, 35.17372676304409, 52.534363746643066, 61.216971669878276, 8.7572854246412, 0.39568403203572544, 1.699437745979854, 1.2944305070808955, 0.3947065073464598, 0.4017849846610001, 0.33878433810813086, 0.5361085097704614, 2.8308520061629157, 62.825118337358745, 86.89122554234096, 85.10530921391079, 82.10523687090192, 80.14861025129045, 78.0282562800816, 81.1756373814174, 79.29780333382743, 72.78608363015312, 67.60374886648995, 68.4284027644566, 71.40632425035749, 80.51612826756069, 75.9043448311942, 74.68731921059745, 73.20628288814, 73.3967399597168, 74.42439242771694, 75.70422976357597, 73.52807480948312, 69.58971078055245, 74.34293869563511, 65.04441465650285, 56.5665145601545, 53.289382798331125, 56.20959254673549, 56.01961490086147, 53.47269712175642, 56.253129959106445, 66.51544557298932, 67.42968259538922, 67.35095950535366, 64.14209379468645, 63.664773396083284, 59.11366857801165, 56.89869056429182, 56.52637481689453, 57.31942135947091, 59.907694816589355, 59.42534392220633, 60.32541356767927, 64.24253695351737, 65.87765652792794, 66.56949560982841, 64.2504301071167, 61.99710151127407, 62.39072390965053, 66.33800942557198, 60.96318176814488, 61.559358051845, 64.94835581098283, 62.50682135990688, 60.14765085492815, 63.61186981201172, 56.69593170710972, 56.17470564161028, 56.730888094220845, 52.93900598798479, 57.24631936209542, 61.32331384931292, 61.497241156441824, 61.41323743547712, 59.206406184605186, 59.98534788404192, 61.19621740068708, 64.52974769047329, 60.92992074148995, 62.47035026550293, 57.514290537152974, 56.02447516577584, 60.65573787689209, 56.72183806555611, 51.69704328264509, 53.434516770499094, 60.10642719268799, 59.55886745452881, 57.430502210344585, 62.53735869271414, 56.79361990519932, 57.28780358178275, 57.671542167663574, 57.475342409951345, 59.45970971243722, 58.84122276306152, 52.95853042602539, 59.30052648271833, 60.01407868521554, 60.68594864436558, 60.02090876443045, 57.01361376898629, 54.39103010722569, 54.72195543561663, 52.58307409286499, 51.994905608040945, 53.95645155225481, 57.19921752384731, 58.740112577165874, 58.76513998849051, 60.93430505480085, 57.624148505074636, 56.57402556283133, 47.446239607674734, 50.121448925563264, 48.69515398570469, 51.38444035393851, 48.85804060527256, 48.83493089675903, 47.04722540719168, 48.68302937916347, 52.533939906529014, 61.57071835654122, 62.874255997794016, 65.86989539010185, 63.753613063267295, 66.28689847673688, 61.403815678187776, 59.3848637172154, 58.161786215645925, 62.25314957754952, 66.64680126735142, 70.5545654296875, 71.20538234710693, 72.15773023877824, 70.42911570412772, 67.7598123550415, 68.61798436301095, 78.14095606122697, 70.45040498461042, 48.270136151994976, 11.912303464753286, 0.6068617446081979, 0.5929361432790756, 3.090836444071361, 0.5420647987297603, 0.7695107683539391, 0.3214806637593678, 34.11753109523228, 84.13014343806675, 58.6939001083374, 39.24620492117745, 33.944857937949045, 34.28573656082153, 1.3824951244252068, 0.17559665255248547, 0.254586040441479, 0.12280498604689326, 0.2222023867070675, 0.1778019049337932, 0.10202649315553051, 0.34303820984704153, 0.20897916411714895, 0.15462689421006612], [0.3638975705419268, 0.02468492416664958, 0.028467997775546143, 0.029274283974830593, 0.10835549461522273, 0.052928320065672906, 0.05793697041060243, 0.08636522639010634, 0.4879582534943308, 41.78319372449602, 49.16213893890381, 22.994010584694998, 41.21673836026873, 29.856044564928325, 41.077656269073486, 5.726753916059222, 0.36118676885962486, 0.19078593035893782, 0.3177765682339668, 0.06121850825314011, 0.18881707957812718, 0.11372299159743957, 0.07585963154477732, 0.5862111555678504, 51.105463232312886, 83.42394937787736, 72.65971674237932, 77.28815501076835, 72.95411886487688, 78.07569858006069, 72.60203974587577, 73.83155822753906, 72.63546752929688, 68.0295970099313, 60.823953764779226, 64.91313539232526, 64.69653919764927, 70.76551968710763, 69.57409123011998, 69.09939725058419, 59.51640701293945, 62.650954791477744, 64.95050975254604, 69.85318647112165, 65.48315170833042, 66.87140873500279, 64.86679090772355, 50.72611590794155, 48.87259708132063, 46.987793990543906, 48.863727705819265, 48.97960976191929, 55.85117667061942, 60.25857884543282, 63.407578877040315, 60.236226490565706, 59.46946498325893, 56.24022715432303, 53.07869952065604, 49.61698886326381, 50.25818599973406, 52.14650140489851, 52.26702833175659, 53.74853713171822, 55.84455851146153, 57.035538809640066, 58.18080343518938, 57.19819266455514, 57.31810120173863, 53.47707101276943, 58.56592123849051, 55.559800488608225, 54.87576075962612, 58.624855858939036, 53.178649357386995, 55.90408720288958, 59.745252881731304, 55.6484351839338, 52.957616737910676, 60.93343652997698, 46.39331306729998, 52.067100865500315, 58.07606628962925, 60.02263191768101, 55.66713973454067, 55.02474403381348, 55.2104172706604, 53.33880533490862, 52.67244529724121, 52.428191798073904, 52.43405260358538, 51.108780997140066, 53.247071743011475, 56.32599919182913, 56.18306085041591, 55.784359318869456, 53.72905090876988, 47.36593232836042, 48.764212131500244, 56.026135785239084, 51.45491245814732, 55.07343353543963, 51.351363454546245, 51.68292106900896, 53.411886487688335, 55.950511591775076, 54.34223985671997, 51.33366639273507, 50.662845611572266, 52.33400201797485, 54.49064643042428, 49.68767983572823, 52.346703324999126, 47.86225257601057, 48.136018548692974, 46.7693704196385, 46.93997301374163, 48.23566266468593, 48.970438139779226, 52.131722586495535, 53.04460818426949, 51.83053207397461, 52.59326362609863, 52.054555892944336, 45.77654579707554, 41.810267380305696, 45.59363446916853, 44.07590470995222, 45.25863054820469, 44.94985260282244, 46.99781329291207, 44.37976680483137, 46.34551640919277, 52.51389782769339, 57.33403689520699, 60.3213141305106, 59.26259626661028, 60.78181988852364, 55.770730427333284, 54.24358238492693, 49.87274163109915, 52.52115522112165, 57.6101895741054, 60.783570834568565, 62.45094394683838, 61.44542843954903, 58.26498086111886, 52.73157099315098, 46.60463210514614, 48.56734882082258, 58.159048625401084, 67.07158633640834, 49.51076132910592, 16.967645134244645, 0.26395655476621216, 0.13097870030573436, 0.33318379148840904, 0.144217244216374, 0.09380476575876985, 0.3257335584078516, 18.118756668908254, 66.5080040522984, 40.368710722242085, 33.711912631988525, 17.182667561939784, 7.318496755191258, 1.945035070180893, 0.4265191060091768, 0.10971688013523817, 0.0730653904112322, 0.10182431007602386, 0.04907899769023061, 0.2336023449897766, 0.3161213499094759, 0.7901837219085012, 0.6334548890590668, 0.00969697703008673, 0.007002170538596276, 0.024043633935174773, 0.026557585823216608, 0.07674705356891666, 0.036037524097732136, 0.08254263829439878, 0.10334175865032844, 1.7627601538385664, 54.511602197374614, 54.23613044193813, 34.116190092904226, 37.31961188997541, 30.98140607561384, 51.16115651811872, 5.915819610868182, 0.30667635958109585, 0.21424690288092407, 0.31160803352083477, 0.26466171549899237, 0.23573221213051251, 0.10423426290175744, 0.16606057568320207, 1.0980771290404456, 53.39617313657488, 87.85741424560547, 75.50847816467285, 79.71522331237793, 75.0142319543021, 78.96574892316545, 73.92619269234794, 76.79967580522809, 75.81636674063546, 69.24420465741838, 62.74984155382429, 65.53937653132847, 67.58109079088483, 72.31109087807792, 70.90758950369698, 69.96353081294468, 61.35651234218052, 64.97700323377336, 66.86116709027971, 72.58168847220284, 66.6485035760062, 70.49756240844727, 67.09291730608258, 54.15726491383144, 50.96030841554914, 49.84332643236433, 52.093872274671284, 51.21696792330061, 59.65523896898542, 63.210958753313335, 64.5318877356393, 61.54999882834298, 60.89235183170864, 59.111778667994905, 56.199034758976524, 51.75312566757202, 54.14210047040667, 56.49026502881731, 55.918945925576345, 56.207612310137065, 59.41333048684256, 61.04925605228969, 59.46515710013253, 60.13572774614607, 61.16282435825893, 57.320810999189106, 62.45193753923689, 59.13546507699149, 59.1145509992327, 60.527064187186106, 56.722723960876465, 58.23386335372925, 60.354623794555664, 56.28632150377546, 55.80546794618879, 61.77701037270682, 48.607217584337505, 54.66115869794573, 58.68834154946463, 61.42152663639614, 57.67823675700596, 55.63215208053589, 57.48850577218192, 54.4793312890189, 54.383772713797434, 55.59015369415283, 53.34524284090315, 51.57593618120466, 53.67382662636893, 58.79671260288784, 57.34629004342215, 57.97678347996303, 54.95531415939331, 50.95221029009138, 50.48297412054879, 57.952662808554514, 53.60870810917446, 55.23116111755371, 53.119610513959614, 52.042000498090474, 55.42020075661795, 57.21228361129761, 56.997660705021445, 53.55526603971209, 52.321818351745605, 53.09246390206473, 56.34335926600865, 54.25656509399414, 55.29566819327218, 50.12199435915266, 50.37863997050694, 50.59378399167742, 49.98971108027867, 51.305366379874094, 52.934197834559846, 54.76977988651821, 53.3971597807748, 55.78243466785976, 55.06675631659371, 54.9750783102853, 48.63682038443429, 44.04982117244175, 47.324798992701936, 46.98359033039638, 46.51324939727783, 47.006429059164866, 47.67521054404122, 45.36252348763602, 47.74885450090681, 55.161404677799766, 60.07126930781773, 60.917629378182546, 60.52400697980608, 61.58958966391427, 57.96122646331787, 55.52440289088658, 53.01277848652431, 53.726115294865195, 60.99482386452811, 62.172237804957796, 65.45829105377197, 64.61543287549699, 63.82572146824428, 61.61599281855992, 56.26881551742554, 56.65515620367867, 64.96581663404191, 69.00649288722447, 53.66303954805647, 20.837659733636038, 0.8028710782527924, 0.43063026826296535, 1.0875763382230486, 0.06319715707962002, 0.34289826878479546, 0.37569553032517433, 22.670127255576, 75.17828587123326, 49.50438983099801, 36.71320785794939, 29.5194217136928, 12.101269279207502, 4.910628497600555, 0.3989175499549934, 0.08258902973362378, 0.048821819347462485, 0.042930126921938996, 0.03152952742363725, 0.12193984032741614, 0.11600664870015212, 0.3258349315396377, 0.3936794767422335, 0.690027827663081, 0.14812139900667326, 0.1205536068550178, 0.10240082056926829, 0.15704155606882914, 0.11048795375972986, 0.1212838055299861, 0.18404342287353107, 2.3376860235418593, 63.75002779279436, 68.2703104019165, 37.41065066201346, 51.6687467438834, 39.70558507101876, 59.80895396641323, 7.921803627695356, 0.45199454043592724, 1.0359580623252052, 1.0939583671944482, 0.600679313497884, 0.4045982179897172, 0.319261691399983, 0.33207685660038677, 2.047155784709113, 59.01719978877476, 94.73884759630475, 81.29264504568917, 82.82316643851144, 80.65813555036272, 84.13078962053571, 79.06792218344552, 81.5061423437936, 79.97484970092773, 73.62721170697893, 68.50587517874581, 69.09892477308, 70.05363505227226, 76.47561182294572, 75.36533832550049, 75.13147585732597, 65.38504314422607, 69.09993921007428, 71.88772324153355, 77.23741231645856, 68.85587678636823, 73.8687310900007, 69.58801542009626, 57.320665087018696, 53.15117270605904, 51.05434186117989, 53.00431210654122, 54.64639377593994, 62.320470673697336, 65.4600350516183, 68.42059298924038, 65.27408041272844, 63.78611673627581, 61.26214190891811, 58.89507825034005, 55.81247867856707, 56.738176754542756, 60.001703943525044, 58.32722977229527, 59.04549980163574, 61.41335555485317, 65.30404799325126, 64.22070571354458, 64.1670308794294, 62.50584166390555, 61.040014948163716, 64.16836493355888, 61.512256213596885, 62.16372626168387, 64.63331753867013, 57.58742380142212, 61.378552028111045, 63.69171156202044, 59.90252535683768, 59.211603437151226, 66.36569799695695, 50.063549586704795, 56.54562480109078, 60.66356154850551, 64.9476957321167, 59.5569497517177, 57.657920224326, 60.29989978245327, 56.560695443834575, 56.66974394662039, 57.10594490596226, 56.091837951115195, 53.93961954116821, 57.845969745091026, 60.33486311776297, 59.62756429399763, 61.026215825762065, 57.972326210566926, 52.846466405051096, 52.919703892299104, 59.17891911097935, 54.98119272504534, 60.11678000858852, 54.47464125497, 53.763194356645855, 58.04980557305472, 60.93976633889334, 61.031114305768696, 57.435226985386436, 56.83078234536307, 55.84938056128365, 60.21900190625872, 56.92540291377476, 59.86764539991106, 53.802031312670024, 52.96714619227818, 55.25677912575858, 55.168384143284385, 55.37787927900042, 55.14466299329485, 58.34014647347586, 58.81664003644671, 57.526345661708284, 56.62990992409842, 58.815834045410156, 50.82155636378697, 47.604391029902864, 51.04086235591343, 48.449229444776265, 50.00163418906075, 49.392471722194124, 50.6998621395656, 47.55604199000767, 50.318447726113455, 57.28044196537563, 61.617715971810476, 63.78522041865757, 63.00599384307861, 65.52894728524345, 60.81433745792934, 60.16530622754778, 56.6101006099156, 56.48172221864973, 64.85636166163853, 66.23179926191057, 70.49401187896729, 71.20238767351422, 72.01028251647949, 70.32279436928886, 66.20612566811698, 66.48796544756208, 72.96582657950265, 77.20458207811627, 58.70018127986363, 23.982511690684728, 1.335775111402784, 0.8910962641239166, 2.311533655439104, 0.23971811681985855, 0.6252780535391399, 0.5102287498967988, 28.414460114070348, 86.25454820905412, 60.27631064823696, 51.620529719761436, 40.30397088187081, 33.1371784891401, 6.011947504111698, 0.7597247734665871, 0.22210858602608952, 0.1654450222849846, 0.19967487481023583, 0.23335980943271092, 0.3801209628582001, 0.9511005814586366, 1.5436540309871947, 1.09166904432433], [3.195008614233562, 0.7659286462834903, 0.05728036564375673, 0.10221767718238489, 0.22236817995352404, 0.0499576055444777, 0.05072608716519816, 0.045973872167191336, 11.230140617915563, 60.84928689684187, 44.846748283931184, 12.823306100709097, 27.558214494160243, 41.60528857367379, 46.576947007860454, 9.42268921647753, 0.8297684778060231, 0.31120188960007256, 0.40839554422668045, 0.17390091211668082, 0.02425321813539735, 0.14484106217111858, 0.14262764022818633, 1.17277449795178, 51.711926324026926, 76.13082831246513, 70.62463106427873, 74.92703901018415, 72.31214700426374, 76.1346081324986, 72.51734815325055, 77.21237100873674, 70.07914883749825, 70.20586313520158, 62.029737200055806, 58.845940589904785, 60.458436829703196, 66.27780328478131, 65.30086571829659, 62.18398026057652, 53.65235321862357, 58.75259849003383, 66.36018112727574, 66.7057775769915, 65.32152966090611, 64.76553480965751, 65.60849026271275, 54.450228759220664, 50.07865497044155, 49.67804615838187, 47.68944392885481, 53.297383649008616, 59.871689251491, 61.19918428148542, 61.18908854893276, 58.28479017530169, 56.427831990378245, 54.16150678907122, 51.295565945761545, 46.24747037887573, 49.08401686804635, 52.66606337683541, 53.45150859015328, 53.66328273500715, 57.37819617135184, 55.13039486748831, 57.42700726645333, 57.59190886361258, 53.69358035496303, 54.23364993504116, 55.7925477709089, 54.55381597791399, 59.272983823503765, 54.17001485824585, 54.817531381334575, 51.615203925541465, 55.933995723724365, 52.15258802686419, 58.46433162689209, 52.13381052017212, 46.762609822409495, 57.75747053963797, 59.16122899736677, 54.997413294655935, 54.86769390106201, 52.54774250302996, 48.833020142146516, 50.3103461265564, 51.69976697649275, 53.53468547548567, 50.486514227730886, 49.92177506855556, 52.48332575389317, 55.688814640045166, 53.89223977497646, 58.20751231057303, 52.243946416037424, 54.64871794836861, 47.76673568998064, 49.25353901726859, 55.63408367974417, 53.93745517730713, 54.29931388582502, 52.9694356237139, 55.24490812846592, 51.726743357522146, 48.53062064307076, 53.3710241317749, 50.35829564503261, 52.912654944828574, 52.921850885663716, 52.864764486040386, 51.66129132679531, 48.54517364501953, 46.95068713596889, 47.204042775290354, 47.001085894448416, 45.16428443363735, 49.88242047173636, 51.903887680598665, 50.1986642565046, 52.89360645839146, 53.10889291763306, 49.72092696598598, 41.12275355202811, 43.09967238562447, 45.63349628448486, 43.939049516405376, 43.133385045187815, 44.67528411320278, 43.278126444135395, 45.54353448322841, 48.500302178519114, 56.24314192363194, 58.785220282418386, 60.076369285583496, 59.05170454297747, 59.539579255240305, 54.92698287963867, 50.991307803562705, 49.15264075142996, 54.89558049610683, 57.079434054238455, 58.68233135768345, 63.49306951250349, 57.55987766810826, 56.015355655125205, 51.34835488455636, 44.542563097817556, 44.222991125924246, 54.82357631410871, 64.39265278407505, 60.33314691271101, 35.35899700437273, 1.9873398286955697, 0.309110020420381, 0.3361693455704621, 0.3318174390920571, 0.22540364707154886, 0.41592592586364063, 18.48196506500244, 66.9365758895874, 43.86823695046561, 35.78970888682774, 11.501433900424413, 5.81876847573689, 8.84693889958518, 3.547867234264101, 0.3094353915325233, 0.061985171400010586, 0.0750844052859715, 0.100994176763509, 1.6610469945839472, 1.4599947886807578, 4.518579866204943, 4.141378232410975, 1.0918805301189423, 0.06166674170110907, 0.06800900173506566, 0.044812576446150026, 0.11363730619528464, 0.118598394628082, 0.05861265558217253, 0.07389766789440598, 16.00993149621146, 67.21539320264543, 54.63045808247158, 25.06848212650844, 35.19482844216483, 44.88097858428955, 58.191222258976524, 9.759233900478907, 0.8337526725871223, 0.3806978261896542, 0.4520305570747171, 0.11689612668539796, 0.002830502256983891, 0.28089544868894983, 0.15540749446621963, 1.3812071021114076, 51.5610705103193, 83.28301906585693, 73.62141690935407, 77.98201601845878, 76.48998069763184, 79.36935588291713, 75.25461878095354, 79.3299526487078, 73.82709053584507, 73.09932231903076, 65.09609535762242, 62.425068855285645, 62.65151759556362, 68.87705489567348, 68.52187688010079, 65.669161932809, 55.41644178118025, 60.32471179962158, 69.73706122807094, 70.50796386173793, 65.02343109675816, 68.04697445460728, 66.06662668500627, 55.96151059014456, 51.47071960994175, 51.272317273276194, 50.89199720110212, 55.68646614892142, 62.201017243521555, 63.82404695238386, 61.68351541246687, 59.662659645080566, 58.865868023463655, 57.31810120173863, 53.34476688929966, 50.903103896549766, 51.8165488243103, 53.874570505959646, 56.47998864310128, 56.62329176494053, 59.1656619480678, 58.378868784223286, 59.27406079428536, 62.20091996874128, 54.751106602805, 58.21770879200527, 58.13091884340559, 58.537781034197124, 61.290956088474815, 56.60328442709786, 56.556262493133545, 54.99827139718192, 59.11722605569022, 54.64056076322283, 63.439290455409456, 55.74429600579398, 49.95896182741438, 59.16140965053013, 59.542907442365376, 55.66905743735177, 56.299401487622944, 54.35791151864188, 51.50052738189697, 52.76355355126517, 54.40151841299874, 55.25818961007254, 52.259322779519216, 52.582348006112234, 55.5761912890843, 56.96102632795061, 56.22041089194161, 59.69620554787772, 55.01072951725551, 56.067623479025706, 52.09769378389631, 50.53152118410383, 56.27893904277256, 55.48836953299386, 54.227545942579, 54.32627984455654, 57.97787434714181, 53.10880606515067, 51.98849242074149, 55.416532107761924, 50.47144358498709, 54.896473339625764, 55.781013761247905, 55.46569061279297, 53.63865484510149, 51.743120261601035, 48.78977108001709, 49.85052476610456, 49.71613270895821, 49.524977343423025, 53.475754329136436, 55.2978047643389, 54.007896014622276, 55.65262147358486, 55.75841474533081, 51.188452516283306, 43.53192329406738, 45.8857957976205, 46.92219604764666, 45.12003483091082, 45.87871905735561, 45.80908421107701, 46.33957917349679, 47.786812509809224, 50.65970849990845, 57.43815565109253, 59.436572211129324, 61.75806263514927, 60.53784779139927, 60.439252853393555, 56.22441305433001, 52.70883648736136, 51.29266159875052, 56.852287020002095, 60.66556262969971, 61.81629548754011, 65.11607142857143, 61.474312101091655, 62.083835874285015, 59.93749564034598, 54.46285711015974, 54.55590738568987, 63.03520406995501, 69.65027822766984, 63.61070251464844, 39.859609263283865, 4.728959160191672, 0.7343792106424059, 1.1869234187262399, 0.27588772454432076, 0.4804811232856342, 0.5146320079054151, 23.9337283883776, 76.56235313415527, 53.4767062323434, 43.68201480593, 17.823718786239624, 14.513713359832764, 10.395789640290396, 4.223853783948081, 0.20765766288552964, 0.09286753926426172, 0.019566997453304272, 0.041511473046349626, 0.34601646289229393, 0.91931528704507, 2.5929537202630724, 1.5255383402109146, 4.012766642229898, 1.6057383567094803, 0.16796436852642468, 0.13800704745309694, 0.34804948951516834, 0.1515534698430981, 0.1621430130409343, 0.18261164613068104, 19.199224131447927, 75.69714954921177, 67.0721630368914, 24.29218074253627, 40.276046071733745, 57.841005257197786, 66.67039040156773, 12.240735258374896, 0.9660598358937672, 1.291842737368175, 0.7644853751574243, 0.6315892434545926, 0.16548544940139565, 0.5032985731959343, 0.24555137380957603, 2.264101126364299, 57.9907180922372, 88.4619700568063, 79.5613762991769, 83.79396874564034, 81.79085867745536, 84.48802430289132, 79.64789526803153, 83.0038890838623, 78.05197743007115, 77.38816043308803, 70.61124883379254, 65.42005511692592, 66.88480486188615, 72.66784613473075, 71.53171839032854, 69.69451740809849, 58.12078489576067, 64.06577478136334, 73.07357924325126, 72.96631295340401, 67.62129306793213, 70.06844166346959, 69.94748047419957, 60.578710147312705, 55.486868722098215, 54.162104334150044, 53.986731801714214, 58.95067078726632, 63.74348258972168, 67.27363995143345, 64.79685034070695, 61.6007137298584, 60.07176957811628, 62.2413306917463, 57.23435456412179, 53.05962324142456, 54.218280519757954, 58.38603237697056, 59.89094965798514, 60.70467403956822, 63.75392573220389, 61.2744471686227, 64.3441196169172, 64.38676765986851, 60.77100849151611, 62.21396173749651, 61.38131741115025, 63.3133613041469, 64.39379923684257, 59.2940160206386, 58.7477833884103, 57.66642481940133, 61.193215778895784, 56.746212346213206, 63.768739291599815, 57.5224164554051, 51.6093361718314, 63.752987725394114, 61.213970048086985, 58.0676520211356, 57.99346957887922, 58.26021787098476, 52.58081245422363, 52.655846050807405, 55.61267975398472, 57.58342163903372, 53.747571332114084, 54.9009827205113, 56.67214454923357, 60.799051421029226, 58.75828211648123, 61.73545319693429, 56.39168051310948, 58.16428409303938, 52.445121083940776, 53.185715675354004, 58.41187967572893, 58.699132101876394, 56.8652732031686, 55.911758014133994, 60.12184524536133, 58.227092334202354, 56.54017741339547, 56.87453167779105, 54.15316200256348, 57.11825711386544, 57.70166955675398, 59.51255076272147, 58.540740966796875, 54.33395412990025, 52.4143579346793, 54.01270416804722, 54.040465695517405, 52.276019300733296, 55.595128604343955, 59.80226979936872, 56.61081280027117, 59.25806604112898, 60.74354921068464, 54.58812270845686, 47.0568972996303, 49.2713611466544, 51.667992864336284, 48.964744091033936, 47.50266940253121, 49.10555280957903, 48.741015570504324, 50.444494996752056, 52.034162930079866, 61.356755529131206, 62.47116320473807, 64.0939427784511, 62.50544561658587, 62.6136360168457, 61.22652544294085, 55.72253772190639, 55.428701877593994, 60.782028334481375, 63.41931438446045, 65.9522454398019, 71.55669021606445, 67.30071708134243, 71.71084295000348, 70.29958043779645, 66.79265090397426, 67.416793687003, 73.37071200779506, 78.49600900922502, 69.03111730303083, 45.327244009290425, 6.073498555592128, 1.2162497022322245, 2.5148592250687734, 0.3763469510844776, 0.9167235004050391, 0.7210774815508297, 30.41180317742484, 86.36972849709647, 62.69122655051095, 58.00794267654419, 31.79786457334246, 36.741990770612446, 11.729446853910174, 6.40130718265261, 0.33086521018828663, 0.30475284851023127, 0.14941935507314547, 0.1956623579774584, 3.172263903277261, 4.5444510493959696, 5.787442088127136, 6.209321941648211], [7.9914263146264215, 3.967249861785344, 0.363747342888798, 0.08975869536932025, 0.030101279062884193, 0.07144114721034255, 0.03968372701534203, 0.4161478339561394, 31.55670302254813, 53.141744000571116, 26.875682524272374, 13.20844909123012, 50.48675046648298, 38.44126306261335, 47.32900265284947, 13.873655727931432, 0.7145757047193391, 0.45778917521238327, 0.9566243993384498, 0.7183928170374462, 0.25930042032684597, 0.6069145617740495, 0.2684542105666229, 3.089547336101532, 60.52174186706543, 59.47723306928362, 76.33585575648716, 77.45817048209054, 76.11579241071428, 72.8481866291591, 70.67232349940709, 73.12787246704102, 73.73100389753068, 71.62920161655971, 66.34382506779262, 62.44895676204136, 59.643037932259695, 60.6173004422869, 61.88191427503313, 56.4138765335083, 52.3264354297093, 58.32937676565987, 63.44315365382603, 68.7393138068063, 62.967278480529785, 63.327994210379465, 64.19362163543701, 52.27768686839512, 48.52423177446638, 49.2224770954677, 47.480859007154194, 54.094025884355815, 56.27839013508388, 58.72664696829659, 58.81182493482317, 56.761157921382356, 53.748050757816856, 51.884748867579866, 50.99995136260986, 45.98912245886666, 48.215981892177034, 49.450569084712434, 51.29691737038748, 51.3064364024571, 55.32471513748169, 56.2346373285566, 54.84707859584263, 55.35114261082241, 53.43398175920759, 53.29432644162859, 56.828465121132986, 57.547176361083984, 54.91439969199044, 58.8261729649135, 54.73529945101057, 53.66458204814366, 54.56958491461617, 51.535567147391184, 58.531326157706125, 48.24869748524257, 53.42016526630947, 59.663257190159385, 57.196090834481375, 56.674274172101704, 51.88093778065273, 50.558254378182546, 48.2741938999721, 53.570930753435405, 52.992166655404226, 55.70265892573765, 51.35266624178205, 52.90797185897827, 53.745712688991, 50.51679447719029, 53.756371225629536, 56.481176785060335, 53.94940955298287, 53.3392048563276, 54.60812657220023, 52.340432575770784, 52.55756378173828, 55.36423649106707, 53.08082219532558, 50.72573723111834, 52.016333852495464, 50.77881452015468, 50.768757002694265, 49.373788016183035, 46.66510227748326, 52.74155902862549, 52.38213218961443, 51.05571065630232, 49.10092183521816, 48.68914031982422, 46.408762386866975, 45.30232776914324, 45.79560123171125, 48.36816133771624, 48.45478105545044, 49.47225093841553, 50.2235700743539, 50.46471425465175, 45.733074392591206, 42.321769441877095, 40.63734197616577, 45.729961599622456, 43.877874101911274, 42.91112606866019, 43.17792994635445, 45.8172413962228, 47.704601424080984, 53.397232736860005, 54.611805643354145, 57.51577050345284, 58.923392159598215, 59.18005166734968, 59.10760974884033, 59.306995255606516, 53.38922841208321, 49.48961796079363, 50.39824431283133, 53.11458696637835, 59.52535629272461, 59.35068552834647, 62.32298592158726, 56.3986565044948, 54.94014624186924, 45.95990875789097, 44.700669356754844, 40.66480473109654, 50.63395847593035, 56.4362427847726, 66.06078324999127, 44.366617338997976, 13.312018939426967, 0.20257569343916007, 0.2519182307379586, 0.12901434142674717, 0.0741227651014924, 0.6903756718550409, 20.368268966674805, 64.76067107064384, 47.250776359013145, 34.81518929345267, 8.798358832086835, 10.065110972949437, 14.38804737159184, 9.07768075806754, 0.1567980841334377, 0.13854626566171646, 0.0271970270467656, 0.7989189103245735, 3.930368389402117, 4.531175647463117, 10.342292853764125, 10.154887778418404, 4.295859268733433, 1.6282156705856323, 0.10769230805869613, 0.09095602469252688, 0.02666201745159924, 0.09107158599155289, 0.014151655270584991, 0.6753392815589905, 41.32266364778791, 60.213846342904226, 37.66704961231777, 13.995845879827227, 45.347101960863384, 47.21983255658831, 56.58283935274397, 15.076635565076556, 0.5491415932774544, 0.460275978914329, 0.9099337533116341, 2.992641244615827, 0.20886720583907195, 0.5920892230101994, 0.14364755978541716, 3.374682298728398, 62.38711084638323, 70.42218140193394, 74.23255266462053, 79.24569184439522, 75.41595595223563, 76.50234849112374, 73.27790491921562, 76.10485594613212, 73.73511028289795, 73.11779757908413, 68.64053126743862, 64.45536027635846, 60.76050281524658, 62.44059113093785, 62.93735258919852, 58.6148157119751, 54.89357246671404, 61.763544763837544, 65.63705430712018, 69.37751974378313, 65.6814671925136, 65.17843845912388, 65.69020107814244, 55.334692750658306, 49.507200377328054, 50.554248741694856, 49.277746541159495, 55.01449891499111, 59.12321540287563, 62.40132686070034, 63.345607893807546, 58.3312041418893, 55.91845955167498, 52.95916271209717, 53.67624112537929, 49.55748449053083, 49.788602420261924, 52.742920875549316, 54.208007608141216, 54.681030545915874, 57.051571777888704, 60.03775119781494, 58.528004918779644, 59.99644415719168, 55.6143924849374, 55.686233384268625, 61.008275577000205, 59.14885425567627, 56.88600662776402, 60.80970300946917, 56.09827198301043, 58.03184447969709, 56.34555489676339, 55.44901493617466, 60.49375452314104, 52.02141298566546, 54.16122538702828, 61.5658963067191, 59.71135262080601, 58.61052867344448, 55.14476374217442, 53.341793060302734, 52.63520295279366, 56.95758349554879, 56.980717522757395, 57.880099296569824, 54.049418449401855, 55.93737949643816, 55.9433445249285, 54.18810796737671, 57.01722683225359, 57.370973518916536, 56.38170984813145, 55.37907436915806, 55.589795861925396, 56.13124813352312, 53.27851234163557, 57.18675940377371, 54.32801342010498, 51.881104537418906, 54.11016307558332, 53.15665830884661, 53.5637845311846, 50.869926248277935, 49.41459131240845, 54.132209709712434, 54.86800309589931, 53.26668650763375, 52.32851988928658, 51.76971449170794, 48.1506028175354, 47.355635098048616, 47.558814321245464, 52.0464369228908, 51.465063776288716, 52.6429397719247, 51.066626276288716, 53.01752758026123, 46.98207909720284, 43.480378082820344, 42.77793604987008, 46.90196636744908, 45.49367421013968, 45.08396325792585, 44.29445334843227, 48.19845853533064, 49.882639339991975, 54.80814783913748, 56.1099762235369, 58.16108444758824, 60.13443538120815, 61.034157616751536, 60.6076146534511, 58.339222363063264, 55.202034269060405, 50.71505437578474, 52.675502504621235, 56.090295451028005, 62.41996887751988, 63.48899091993059, 65.02433436257499, 61.560219628470286, 62.6491482598441, 57.18537323815482, 56.77249043328421, 51.39555399758475, 61.11118534633091, 63.44568279811314, 70.48599365779332, 48.17126676014492, 17.184705121176584, 0.5844159690397126, 0.4830427829708372, 0.10602291513766561, 0.23994056774037226, 0.9025308819753783, 24.779372794287546, 72.50784996577671, 59.044137954711914, 42.154390811920166, 23.638101645878383, 21.11624080794198, 13.764948555401393, 12.49998470715114, 0.25328273751905983, 0.18867080099880695, 0.0972544988617301, 0.7935472471373421, 3.290515512228012, 4.520732939243317, 6.176496045930045, 5.702910738331931, 9.769816875457764, 6.764043969767434, 0.5933529266289302, 0.18256123097879545, 0.14998825240348065, 0.13499384985438415, 0.12194391153752804, 1.1222198392663683, 48.52892180851528, 70.74481405530656, 48.82701342446463, 20.53035306930542, 65.16316631862095, 53.432185649871826, 64.11471789223808, 17.92089455468314, 0.5890815758279392, 0.6991485325353486, 1.5475876884801048, 4.683821925095149, 0.5370782177363123, 1.2480812455926622, 0.23046186779226574, 5.122542909213474, 70.30821704864502, 76.37312589372907, 78.02967371259416, 84.22149835314069, 79.95894527435303, 79.92129298618862, 74.02210562569755, 79.39738491603306, 76.39804908207485, 77.54404326847622, 72.95816271645683, 71.12135778154645, 64.21239566802979, 65.92147186824253, 66.63337734767369, 60.19575323377337, 58.86026777539934, 64.4885309764317, 68.01866054534912, 70.71187959398542, 66.96491759163993, 67.9362062726702, 68.7991725376674, 58.45854377746582, 53.006702286856516, 52.949393544878276, 53.199608598436626, 59.51073728288923, 60.177625383649556, 66.54540620531354, 66.10556438991001, 60.95999949319022, 59.343772070748464, 57.31574576241629, 57.9884877204895, 51.65221697943551, 53.644925594329834, 56.51139450073242, 57.85174022402082, 58.56863103594099, 60.532858984810964, 61.8356740134103, 62.267706053597585, 64.32461602347237, 57.55095965521676, 60.849078450884136, 64.98303427015031, 61.72705282483782, 59.590189933776855, 63.613530431474956, 58.245915004185264, 58.962135314941406, 59.232065882001606, 56.21567569460188, 62.36301449366978, 55.37412377766201, 57.985413142613, 66.51011630467006, 62.309860774448936, 60.438523292541504, 57.57708488191877, 55.831238814762656, 54.1181708744594, 58.11478165217808, 57.20456068856375, 57.858678000313894, 54.423829078674316, 56.85312080383301, 57.04239668164934, 56.201251234327046, 56.95420319693429, 58.68875844138009, 58.921085357666016, 58.55871595655169, 59.3284512928554, 59.1915648324149, 56.87527860913958, 57.343059131077354, 56.65885264532906, 54.477663721357075, 55.12119892665318, 56.7414493560791, 55.4655099596296, 55.780996390751426, 51.424743379865376, 58.61316204071045, 56.12695067269461, 57.30108853748867, 55.49357373373849, 55.5665784563337, 49.998934813908164, 50.62213959012713, 51.83418335233416, 55.945606163569856, 54.81777456828526, 57.278499943869456, 54.634494985852925, 57.59891264779227, 50.660848004477366, 46.90735469545637, 44.54526942116873, 49.28026873724801, 48.48792743682861, 46.608891350882395, 47.1080881527492, 50.326372146606445, 51.06643520082746, 58.75516932351248, 58.975468908037456, 62.4147299357823, 64.01392037527901, 63.5367945262364, 63.539587702069966, 63.04209668295724, 57.60675368990217, 54.04118830817086, 55.32675095966884, 58.99190139770508, 66.78636973244804, 66.90384987422398, 70.14089747837612, 66.62519236973354, 70.88447979518345, 67.27649566105434, 65.08945287976945, 62.17444733210972, 70.08569404057094, 71.89945180075509, 80.60266808101109, 55.30577087402344, 20.57266412462507, 1.183634640915053, 1.73735146011625, 0.3229980580508709, 0.7724220635635513, 0.9854069863046918, 30.748648371015275, 83.14042118617466, 69.44382640293666, 53.79234552383423, 33.32185465948922, 36.5435710634504, 23.870930569512502, 16.95680594444275, 0.31784724444150925, 0.4603380241564342, 0.21183642079787596, 1.3296070652348655, 9.14152341229575, 13.293503727231707, 13.211676529475621, 13.929346408162798], [14.139078651155744, 7.545698506491525, 1.4454067200422287, 0.20975434966385365, 0.01634185265616647, 0.10706829332879611, 0.03301924427172967, 6.212864654404776, 44.319557189941406, 49.7180677822658, 29.812653064727783, 38.34705243791853, 90.15045179639543, 33.96743263517107, 53.366747515542166, 22.335559334073746, 0.5749233726944242, 0.4767503206218992, 0.5112253278493881, 0.9567151601825441, 0.22420025164527552, 0.33299532160162926, 0.0970514811841505, 6.561397152287619, 66.25444344111851, 53.1955577986581, 85.57286739349365, 71.60966328212193, 77.9335801260812, 72.41534859793526, 73.23832103184291, 67.61284405844552, 69.2302109854562, 69.5977428981236, 69.29014614650181, 64.35363170078823, 61.66941751752581, 57.194968700408936, 54.102464471544536, 54.805233069828574, 54.41445248467581, 59.34985869271414, 64.36569377354213, 65.27035617828369, 63.81116499219622, 63.9693546295166, 63.03202179500035, 53.4882367679051, 46.53121049063546, 48.20922129494803, 46.34685046332223, 51.41455384663173, 55.45756816864014, 54.548938342503135, 55.70256512505667, 52.05450030735561, 52.888798304966514, 48.55606494631086, 46.71401064736502, 45.5975011416844, 47.84148441042219, 48.34177902766636, 50.25196041379656, 52.598565101623535, 54.23242705208914, 54.87342963899885, 56.34054871967861, 56.756433146340505, 50.81239863804409, 52.57802970068795, 55.089681897844585, 55.039217131478445, 56.38079616001674, 50.64651039668492, 55.06349761145455, 53.68005221230643, 52.57064723968506, 58.8639920098441, 53.6006030355181, 47.17093808310372, 53.49167612620762, 52.80286993299212, 55.109894207545686, 54.913812569209504, 54.92206702913557, 53.33091912950788, 57.762181418282644, 59.16185433523995, 57.205429213387625, 55.607006549835205, 54.60938767024449, 53.883186272212434, 54.26728963851929, 54.514100074768066, 54.916796820504324, 51.65693480627877, 53.633047648838584, 51.25445345469883, 53.08686017990112, 54.288005692618235, 52.97928122111729, 54.427678380693706, 53.47425351824079, 51.10800974709647, 53.32896668570382, 53.2997008732387, 50.84372459139143, 48.472408635275706, 47.2074647630964, 55.85059997013637, 60.051876885550364, 51.78945084980556, 50.18609496525356, 48.01209395272391, 46.661294664655415, 45.95083441053118, 44.77707174846104, 45.06434849330357, 46.68218789781843, 48.93370648792812, 48.26471308299473, 43.57220547539847, 39.98600741795131, 41.38521480560303, 43.53802381243025, 44.711560658046174, 42.36560910088675, 42.91652829306466, 45.17756938934326, 53.00965527125767, 52.33464125224522, 57.297989640917095, 57.63402189527239, 58.57510675702776, 57.825451714651926, 58.50834151676723, 60.19054208483015, 55.21422140938895, 51.92674725396292, 47.17626735142299, 53.20106772014073, 55.62452643258231, 59.04031644548689, 60.144572802952354, 60.66224833897182, 54.57308333260672, 54.642787660871235, 47.058686460767476, 44.75000156675066, 41.54055915560041, 48.97455842154366, 53.80170474733625, 66.93800721849713, 50.753801005227224, 29.326848915645055, 0.6051073244639805, 0.08488016429224185, 0.24692000608359063, 0.27177449954407557, 0.36732892213123186, 24.31292458942958, 64.08522973741803, 48.89811086654663, 38.52129588808332, 17.645957810538157, 13.484744208199636, 13.464071580341884, 21.4868038722447, 0.380675950220653, 0.2444602352167879, 0.23834229207464627, 5.147310197353363, 9.830885461398534, 9.72418805531093, 13.508096235139028, 13.064034257616315, 10.322639874049596, 6.256391644477844, 0.9890710754053933, 0.079543194600514, 0.0576507779104369, 0.09564449811088187, 0.04530509448211108, 8.322772877556936, 55.27197136197771, 57.18373693738665, 41.84829139709473, 45.17756591524397, 80.14171763828823, 41.21623114177159, 61.566820417131694, 24.63058580671038, 0.35271059083087103, 0.661014158810888, 0.6508705488273075, 2.9283530371529713, 0.41943954303860664, 0.45797558235270636, 0.08064619398542813, 6.837555910859789, 71.5589553288051, 61.36677483149937, 82.8465610231672, 76.61027485983712, 79.7651947566441, 76.04697050367082, 72.95234707423619, 71.14484964098249, 73.75908156803676, 71.71870136260986, 73.06371974945068, 64.94550704956055, 64.64758913857597, 58.35193061828613, 57.6448506627764, 55.47122137887137, 55.01721566064017, 59.935411180768696, 66.98083591461182, 68.04997607639858, 66.95830985477993, 64.55045332227434, 64.45100375584194, 55.037382807050435, 49.29791368756975, 50.056889738355366, 49.11746549606323, 52.29714182444981, 56.4083422933306, 58.145193917410715, 58.37827818734305, 55.97380542755127, 54.82647718702044, 52.402914251599995, 50.56145402363369, 49.66988549913679, 50.46059397288731, 52.280511311122346, 52.444638184138704, 55.31713465281895, 56.110070024217876, 60.59838049752371, 59.3595792225429, 60.29831559317452, 52.864041873386924, 56.6853461265564, 57.34093645640782, 58.26269490378243, 56.680617877415244, 51.01132903780256, 57.566110202244346, 56.13848468235561, 55.371455669403076, 60.914919580732075, 54.0852815764291, 50.651662485940115, 56.143873010362896, 56.51732131413051, 58.17373364312308, 56.77559627805437, 57.197410992213655, 53.84179237910679, 59.28266266414097, 61.16311618259975, 57.76309510639736, 58.46904945373535, 56.31732783998762, 56.95074299403599, 55.86128977366856, 58.43236296517508, 56.6218569619315, 53.121976375579834, 53.97962726865496, 53.74344757625035, 54.87679951531546, 56.755825178963796, 54.305258069719585, 55.85911498750959, 56.143383162362234, 54.718762738364084, 54.24799449103219, 54.874906131199424, 52.01636511938912, 52.08892168317522, 49.58603811264038, 58.80812849317278, 61.2911992754255, 54.68649877820696, 51.957465239933555, 51.41996301923479, 49.355309282030376, 47.975595065525596, 46.6746039390564, 46.50828490938459, 48.69286802836827, 52.093125343322754, 47.82424592971802, 46.41948693139212, 43.3289212499346, 43.38234942299979, 44.58263683319092, 45.6909578868321, 43.42200626645769, 44.93831511906215, 47.51800755092076, 54.61185775484358, 54.85096958705357, 58.77600697108677, 59.06829684121268, 59.45392186301095, 59.86763150351388, 59.88917786734444, 60.54785319737026, 57.089467253003804, 54.33864763804844, 49.189094475337434, 54.91330535071236, 58.03365101133074, 63.405529158455984, 62.81730161394392, 64.21468162536621, 59.9929770060948, 62.32787050519671, 56.26933315822056, 56.004037039620535, 51.25158732278006, 57.57342318126133, 62.84527506147112, 73.87251091003418, 56.496792861393516, 33.09947756358555, 1.1499031995024, 0.10385213233530521, 0.2774211051208632, 0.20845543007765496, 0.3678326393876757, 27.736831835338048, 74.0870087487357, 60.1455386025565, 47.9586866242545, 31.260932104928152, 20.876715557915823, 24.83046463557652, 28.782949141093663, 0.2536907541964735, 0.1379444593829768, 0.1347968711384705, 2.3950581678322385, 9.896373970167977, 10.191682832581655, 12.265932032040187, 12.200093507766724, 19.22695960317339, 12.736760207584926, 3.2829374160085405, 0.1904403253325394, 0.1670052321361644, 0.19982713806842053, 0.23326752867017472, 10.127099326678685, 63.323790550231934, 68.56805460793632, 50.117471081869944, 52.66255801064627, 99.78575502123151, 49.80004262924194, 69.54666669028146, 29.525296415601456, 0.6739000816430364, 1.1953709082944053, 1.2428773705448424, 6.863996412072863, 0.8131727597543171, 0.9938501332487378, 0.14591128831463201, 8.72375168119158, 79.30833680289132, 68.34064701625279, 89.31667491367885, 83.22235434395927, 85.10489927019391, 80.21818951198033, 77.03467777797154, 72.87275545937675, 73.835602079119, 77.14757905687604, 76.8691508429391, 69.93158299582345, 67.42452703203473, 62.14220074244908, 61.026841163635254, 59.51751872471401, 58.470974104745046, 64.55449717385429, 69.9589797428676, 69.38418306623186, 71.43702833993095, 66.49882548195976, 68.17136110578264, 57.41980198451451, 51.39792333330427, 53.43356834139143, 52.15978636060442, 56.20291185379028, 61.132641383579795, 61.59719099317278, 60.9602426801409, 57.64221034731184, 58.71994195665632, 54.94207436697823, 53.71383087975638, 53.03433527265276, 54.330914293016704, 54.0565299306597, 56.400622844696045, 58.576628412519185, 61.320763860430034, 61.84078788757324, 63.09337438855852, 63.155845642089844, 57.4108110155378, 60.422806467328755, 60.75450651986258, 60.92794745309012, 59.51243264334542, 53.465276445661274, 61.47180380140032, 59.189737456185476, 57.59520925794329, 64.32935469491142, 58.73078114645821, 53.81830399377005, 58.777389662606375, 59.064496176583425, 60.284863880702424, 59.140961102076936, 60.03292914799282, 56.53047425406319, 61.50845554896763, 64.45689582824707, 60.669884409223286, 60.7195223399571, 57.63042620250157, 58.905973025730674, 57.652257442474365, 59.970534324645996, 59.04064301082066, 53.970740522657124, 55.9461099079677, 54.67551367623465, 57.32279470988682, 59.12182576315743, 55.99158934184483, 57.206457546779085, 58.69716576167515, 56.151651518685476, 54.90446376800537, 59.86944498334612, 57.082331453050884, 53.92538963045393, 52.277398518153596, 58.80703067779541, 62.88815239497593, 58.60811764853341, 56.012044838496614, 54.356382914951865, 51.447724546704976, 54.265761034829275, 51.0194480078561, 52.07892669950213, 51.884620325905935, 57.130079473767964, 53.052133083343506, 48.39392178399222, 44.89983252116612, 46.22276258468628, 48.34199789592198, 49.06840773991176, 47.46407215935843, 47.79888153076172, 50.36349637167794, 56.0155918938773, 56.32403285162789, 62.411040442330496, 61.17615100315639, 62.54900387355259, 61.85602528708321, 62.14163793836321, 63.92840889522007, 60.48716763087681, 57.863465309143066, 51.47540964399065, 58.9042637688773, 61.41068744659424, 67.56187902178083, 68.25022315979004, 68.1159770148141, 65.88229792458671, 72.04380062648228, 65.19827556610107, 67.66746384756905, 61.88160855429513, 67.54839256831578, 70.78872667040143, 82.57130813598633, 62.29226793561663, 37.08100380216326, 2.068089838538851, 0.13704179067696842, 0.4749967690025057, 0.7887155349765504, 0.4113543911703995, 34.360530444553916, 86.1731014251709, 70.70603615897042, 59.74611445835659, 42.718980584825786, 35.26158673422677, 40.42766618728638, 35.8296332359314, 0.3254854045808315, 0.3762125740093844, 0.3149555724646364, 5.0013715369360785, 15.973616736275808, 21.575895411627634, 21.158279146466935, 21.5375691481999], [16.26378914288112, 12.39407765865326, 3.775168214525495, 0.1830540916749409, 0.015167381481400557, 0.0912948375833886, 0.09913285342710358, 14.884627308164324, 56.14496040344238, 50.847546100616455, 16.28072190284729, 17.733725718089513, 62.05341666085379, 37.27791575023106, 52.92633942195347, 35.20887075151716, 0.30771343250359806, 0.42692856118083, 0.18452311999031476, 0.4782947206071445, 0.5408687314816883, 0.0643157899113638, 0.04002418874629906, 8.520942449569702, 53.37330314091274, 55.930521624428884, 76.99715750558036, 71.43589578356061, 76.1276182447161, 73.67933014460972, 73.54953779493059, 73.31179128374372, 72.10620239802769, 72.2325553894043, 69.5941298348563, 67.92185824257987, 62.90771852220808, 58.53597450256348, 51.50144107001168, 52.15828207560948, 50.15361908503941, 56.57977172306606, 61.32414068494524, 64.19443457467216, 64.00310897827148, 63.75264726366316, 61.1245675768171, 51.37682512828282, 47.51264006750924, 47.39997155325753, 46.084371839250835, 50.27104711532593, 50.46931048801967, 53.09511463982718, 50.97015748705183, 49.22498539515904, 50.92278119495937, 47.72269453321184, 45.80659328188215, 48.837400981358115, 47.46277979442051, 51.06373929977417, 49.853443009512766, 53.009606633867534, 51.99754939760481, 55.24289662497384, 53.43441949571882, 57.0740943636213, 50.423744201660156, 48.31888818740845, 54.19909306934902, 53.215645040784565, 48.24208280018398, 45.956455503191265, 55.345076833452495, 54.56105252674648, 55.77485418319702, 54.77559552873884, 49.888350759233745, 49.01313829421997, 55.011698790958945, 55.55893891198294, 54.59957333973476, 53.76888493129185, 54.53243637084961, 52.85836172103882, 52.44273437772478, 53.07001427241734, 52.51453358786446, 49.43547412327358, 52.04818092073713, 52.73122705732073, 54.335486207689556, 53.752740791865754, 53.043187277657644, 54.096040861947195, 56.194466318402974, 52.29249695369175, 52.81509528841291, 52.70330572128296, 53.13970123018537, 52.72260781696865, 56.18847002301897, 50.94082219260079, 52.986396176474436, 49.47620446341378, 50.43238081250872, 47.159306798662456, 51.941310678209575, 60.07609830583845, 52.44939770017351, 53.815194674900596, 49.93047768729073, 47.90806204932076, 44.50458424431937, 44.22213997159685, 43.40921115875244, 42.26576001303536, 40.58918401173183, 42.049017906188965, 40.95056676864624, 39.400451455797466, 41.4221271106175, 41.27499205725533, 41.82649489811489, 41.70157323564802, 40.78953184400286, 45.44866030556815, 52.75143241882324, 57.29678760256086, 56.332064969199045, 57.395396436963765, 59.04359599522182, 56.19429956163679, 57.483343260628835, 56.243284361703054, 56.997163908822195, 52.8385454586574, 51.92472880227225, 47.89096948078701, 52.22718388693673, 54.93312856129238, 59.489079747881206, 59.4366694859096, 58.045591490609304, 56.76731055123465, 53.607975074223106, 49.086744035993306, 44.43232297897339, 44.87464182717459, 46.777117661067415, 53.76808588845389, 65.84021963391984, 61.26895114353725, 49.501780782427105, 5.587038670267377, 0.05710560216435364, 0.22728959444378102, 0.01843481258090053, 0.6172516356621469, 21.29712847300938, 60.10359927586147, 49.093619278499055, 41.09966468811035, 19.75161460467747, 21.80029443332127, 19.641433545521327, 37.79389245169503, 1.3299504582371031, 0.2875229444886957, 0.5119131452270916, 8.617183685302734, 16.871895483561925, 8.457324743270874, 12.197360260146004, 13.64983948639461, 15.404696498598371, 10.929665769849505, 3.347720682621002, 0.05318006673561675, 0.007726393440472228, 0.10583443168018546, 0.14178457403821604, 21.217017480305262, 66.3542890548706, 55.61072383608137, 29.9931047303336, 25.28095977646964, 71.68316827501569, 42.53588512965611, 59.9959716796875, 39.642676080976216, 0.3081051100577627, 0.8042439988681248, 0.1389237211218902, 0.7079480460711888, 0.4387309178709984, 0.14328204654157162, 0.09653846121260098, 11.203985861369542, 69.4018245424543, 67.94544042859758, 79.20671939849854, 75.71553448268345, 79.5279346193586, 75.62189361027309, 75.90201023646763, 72.81862204415458, 74.19152355194092, 73.6165531703404, 72.12045315333775, 69.70434216090611, 65.44030216761998, 60.161443029131206, 53.63514947891235, 54.09138209479195, 52.77980538776943, 58.66845580509731, 63.153392927987234, 67.36961541857038, 65.30706351143974, 65.04034996032715, 63.18780735560826, 54.11639560971941, 48.13270078386579, 47.95555646078927, 47.8483179637364, 51.50718723024641, 52.65616914204189, 55.04670034136091, 53.89427212306431, 52.804308210100444, 51.53400032860892, 50.96182312284197, 49.07739176068987, 51.65569455283028, 51.060150555201936, 53.987760135105674, 53.346820081983296, 56.483236925942556, 54.00582545144217, 58.76356969560896, 56.618799754551475, 60.39382553100586, 54.611802169254844, 51.75059999738421, 55.89324801308768, 54.215553351810996, 49.468193190438406, 49.21467079435076, 56.863821029663086, 57.33657646179199, 56.908890519823345, 54.85239396776472, 52.07275669915335, 52.29275056294033, 57.33514513288225, 57.71232461929321, 58.9717446735927, 54.98854391915457, 55.67613765171596, 56.1850654057094, 56.07728147506714, 54.59583173479353, 53.69358382906233, 53.72753620147705, 54.7174391065325, 54.602766036987305, 56.86816017968314, 56.148503984723774, 54.76546852929251, 56.80128376824515, 57.872664724077495, 53.50015640258789, 53.15512275695801, 54.451552391052246, 54.83937651770455, 54.4324483190264, 57.136277266911094, 56.72473199026925, 51.98183952059065, 51.265337807791575, 53.57970632825579, 48.825147833142964, 57.519592012677876, 60.683516774858745, 52.74197939464024, 54.6308228628976, 52.59316635131836, 51.18500968388149, 47.60753508976528, 47.53435666220528, 44.59977109091622, 44.247462681361604, 42.75718872887747, 44.32943752833775, 42.534905433654785, 42.82274498258318, 42.44423839024135, 44.136201177324565, 46.27052102770124, 44.63287925720215, 43.25561080660139, 47.96420349393572, 53.5056072643825, 59.053031648908345, 58.57013879503523, 58.30861554827009, 58.78699902125767, 56.773386750902446, 59.416464124407085, 57.426875250680105, 59.742133140563965, 54.006815569741384, 53.66917133331299, 50.304051058632986, 55.02498027256557, 57.21335015978132, 63.19255992344448, 60.77013996669224, 64.80333300999233, 61.182842118399485, 61.626248359680176, 58.26539775303432, 56.46574831008911, 54.09120838982718, 57.1120662689209, 59.75380611419678, 70.49660355704171, 64.88080542428153, 54.75626911435808, 7.932812179837908, 0.04652204364538193, 0.2571557339813028, 0.12970338016748428, 0.5194169825741223, 26.58768664087568, 70.83488355364118, 60.309099197387695, 51.71976736613682, 34.34231226784842, 27.11567677770342, 29.704969882965088, 49.38094118663243, 1.0721536172287804, 0.17819690730954918, 0.14476259638156208, 6.572024856294904, 18.7075001171657, 16.25820279121399, 15.949247666767665, 17.424034084592545, 25.852223294121877, 17.877904312951223, 6.358650888715472, 0.32562982397420065, 0.07544735366744654, 0.14104148319789342, 0.2872862714741911, 27.213823556900024, 77.07085009983608, 69.59915338243756, 33.36933517456055, 23.47299681391035, 76.57699993678501, 53.49318388530186, 71.12695802961076, 45.69526924405779, 0.26824044489434784, 1.2725621376718794, 0.38158334153039114, 1.070207035967282, 2.7347677562917982, 0.3981762368764196, 0.17482407258025237, 13.733406339372907, 82.17185619899205, 81.9007374899728, 86.2393524987357, 80.98133100782121, 84.25598921094621, 79.67461803981236, 81.42696067265102, 78.18776607513428, 76.98581109728131, 76.35349723270961, 75.14238452911377, 72.10008798326764, 69.99473517281669, 63.58923258100237, 56.233869552612305, 56.56933552878243, 56.93978221075875, 62.7757374899728, 64.53675147465297, 70.15569714137486, 68.33686024802071, 69.13362407684326, 64.84528623308454, 56.32489790235247, 52.372627053942, 53.08168377195086, 50.846483026232036, 55.101215907505576, 57.63463681084769, 59.635311535426546, 57.031637396131245, 54.39637327194214, 56.05619716644287, 54.27437332698277, 51.72397450038365, 53.830800328935894, 53.29825564793178, 57.042056219918386, 56.32297672544207, 60.52356229509626, 58.29355880192348, 62.812229428972515, 58.4869966506958, 65.76684665679932, 54.469044481004985, 55.884868485586985, 58.908717564174104, 58.248645646231516, 51.36670855113438, 49.21926007952009, 60.62328978947231, 61.01306288582938, 60.54990986415318, 58.26519972937447, 56.15836695262364, 55.60210459572928, 58.790938649858745, 60.95341954912458, 60.47805159432547, 58.79388468606131, 58.542721203395296, 56.99752174104963, 57.838385786329, 56.11795622961861, 54.37005002158028, 55.15910134996687, 57.526929310389924, 55.44511352266584, 57.96001400266375, 58.74621309552874, 56.25878231866019, 57.17537825448172, 59.750116620744976, 56.06574051720755, 56.18019471849714, 57.12313822337559, 58.1293728692191, 57.316082750047954, 60.32603195735386, 57.81498425347464, 58.37542247772217, 54.524029050554546, 56.20847041266305, 52.45362567901611, 52.331386021205354, 61.726163455418174, 60.48910617828369, 58.35912895202637, 56.03364331381661, 54.36821917125157, 51.40188380650112, 50.619349888392854, 50.62849371773856, 49.05394853864397, 45.6034904888698, 48.89873273032052, 46.734705856868196, 45.40875332696097, 46.47325209208897, 48.279088905879426, 49.36434194019863, 47.471614428928916, 46.775488308497835, 50.214481830596924, 55.343440532684326, 59.76707022530692, 62.73905100141253, 60.851246288844514, 63.744003704616, 58.22746753692627, 62.59457015991211, 60.192209652491975, 62.02672863006592, 57.51759787968227, 57.07910054070609, 53.47243309020996, 58.94052641732352, 60.172428131103516, 67.9298347745623, 65.2420631136213, 67.35347475324357, 66.75369235447475, 70.09414999825614, 66.69074167524064, 64.97109031677246, 63.76889910016741, 68.4872817993164, 68.85485540117536, 79.4642196382795, 72.44005639212472, 62.43272577013288, 8.965878163065229, 0.1113279326153653, 0.4919555847133909, 0.24518689193895885, 0.5315220473068101, 31.142277717590332, 83.1426168169294, 69.37961809975761, 64.88409887041364, 46.49084145682198, 39.92319222858974, 40.78415046419416, 63.75898402077811, 1.0919096257005418, 0.3649795081998621, 0.484045929142407, 11.866975154195513, 29.569351468767437, 23.361950704029628, 25.38245906148638, 25.014697858265468], [17.897362743105205, 9.304686222757612, 5.083931335381099, 0.10744637304118701, 0.06034841601337705, 0.02936426450365356, 0.8119010222809655, 29.692741053444998, 57.782609122140066, 47.184556552342, 15.363712549209595, 31.609401634761266, 41.97578041894095, 46.01719318117414, 51.8950982093811, 45.37360239028931, 0.09494064016533749, 0.46614302694797516, 0.07704934770507471, 0.40179358848503655, 0.461842092020171, 0.20592156318681581, 0.4327406478779656, 4.9996271048273355, 22.981783492224558, 43.93658638000488, 66.67082813807896, 71.7643232345581, 69.48188168661935, 70.63576207842145, 68.94942038399833, 73.35156972067696, 71.22386455535889, 73.02728339603969, 68.84897027696881, 71.72949191502163, 64.76448563167027, 58.890117236546104, 53.53447355542864, 52.526008537837434, 50.07339865820748, 53.82596785681588, 60.69103472573416, 65.4302203314645, 58.74624783652169, 65.84564617701939, 58.98916380746024, 51.833735193525044, 47.72079767499651, 47.024574279785156, 45.88651841027396, 48.80575541087559, 47.33372047969273, 49.87411042622158, 49.494749205453054, 47.68758528573172, 46.91035284314837, 46.28466408593314, 50.46709401266915, 53.545076506478445, 52.29173960004534, 51.50490822110857, 53.944559710366384, 53.94394132069179, 55.272815568106516, 55.042482784816194, 59.064899172101704, 59.6956080027989, 48.56176246915545, 50.30822345188686, 51.819689410073416, 48.170697007860454, 48.12023571559361, 47.284700938633506, 54.374861649104524, 56.326798234667095, 56.32792384283883, 53.08777734211513, 50.916771003178184, 53.14956072398594, 55.39597586223057, 56.00711509159633, 55.45725202560425, 53.0429927280971, 53.994583266122, 56.16794157028198, 53.97199467250279, 54.81056581224714, 49.91694607053484, 52.2551851272583, 53.84588834217617, 53.71444926943098, 53.480788299015586, 54.32686696733747, 51.26328461510794, 55.912025519779746, 55.736027649470735, 54.080563749585835, 51.76279756001064, 52.27271890640259, 51.43358843667166, 51.48126350130354, 51.65854331425258, 53.53160742350987, 50.13862834657942, 49.257037435259136, 49.342361313956125, 51.296441418784006, 52.87023619243077, 47.24221617834908, 49.72689894267491, 51.572646209171836, 47.5236633845738, 47.603268895830425, 45.090577942984446, 42.77877330780029, 40.41131707600185, 40.077668053763254, 38.143498011997764, 38.39225394385201, 40.53327880586897, 41.886919907161165, 41.263795035226, 41.341583592551096, 42.75666413988386, 41.19653647286551, 42.25040796824864, 49.825136048453196, 55.58938244410923, 55.62594039099557, 56.03226062229702, 53.82305308750698, 54.34918458121163, 54.658351625714985, 58.36643845694405, 55.139632497514995, 58.6873688016619, 51.0586393220084, 46.86957386561802, 46.52731949942452, 52.25333343233381, 53.53845487322126, 58.544367926461355, 57.05805097307478, 59.88325800214495, 55.2716725894383, 53.63729994637625, 51.22140434810093, 46.853797980717246, 45.258008684430806, 46.32238585608346, 52.017244066510884, 62.81714875357491, 61.4452269417899, 67.35712255750383, 21.42170098849705, 0.08794864213892392, 0.1738766205630132, 0.12772334712956632, 0.20172425412705966, 21.288097551890782, 60.89538124629429, 52.81926768166678, 41.863209179469514, 27.8890859740121, 24.95727273396083, 25.76114978109087, 46.66347292491368, 3.7323473351342336, 0.10022051792059626, 0.07566724651093994, 11.668213248252869, 18.648515122277395, 8.488385796546936, 9.715106759752546, 9.793741260256086, 20.2451069355011, 13.210974761417933, 4.566999690873282, 0.0993734687300665, 0.06630395858415536, 0.029729852386351143, 1.0896387589829308, 42.03086921146938, 67.65963322775704, 54.705119950430735, 20.014188766479492, 29.571797234671457, 53.078466756003245, 53.145652362278526, 58.74094636099679, 52.42912980488369, 0.1821494959294796, 0.32337087233151707, 0.051528095201190026, 0.6658796891570091, 0.6138925616230283, 0.12341209846947875, 0.3908478415438107, 11.239362614495413, 56.19616515295846, 61.88274111066546, 72.6563468660627, 74.33642823355538, 72.08625411987305, 73.2821433203561, 71.6958487374442, 76.369644846235, 73.66708047049386, 73.84370367867606, 69.546402658735, 71.8344166619437, 67.21799877711705, 61.03674234662737, 57.560732296534944, 55.31518220901489, 52.30213410513741, 56.66688476290022, 63.28779888153076, 67.90211841038295, 61.658550534929546, 67.01133850642613, 60.888439995901926, 52.96523196356637, 50.942430700574604, 49.08778626578194, 48.76527867998396, 47.7551634652274, 48.92731761932373, 52.5845262663705, 51.87448985236031, 48.85915231704712, 49.05140897205898, 50.44730206898281, 53.584264346531455, 57.11073221479143, 57.228917598724365, 55.97998237609863, 58.16962725775582, 54.31027119500296, 57.97766590118408, 56.04091807774135, 61.05564839499337, 61.50878211430141, 49.32919100352696, 54.29128871645246, 53.79268945966448, 52.404825006212505, 49.802821908678325, 50.15706886563982, 56.16569035393851, 59.5550320489066, 58.65520559038435, 56.01533828462873, 54.46667167118618, 54.49207081113543, 56.89891638074602, 57.72710343769619, 57.8350749697004, 54.286737646375386, 56.444844654628206, 57.78331436429705, 58.00056716373989, 56.66152770178658, 53.84615932192121, 56.357325145176475, 57.33976221084595, 56.526833398001536, 55.03949853352138, 55.70329468590872, 53.1028618812561, 57.02119772774832, 57.03138378688267, 55.777497972760884, 50.604070799691335, 54.288467747824534, 53.27112988063267, 53.32040303094046, 54.58323117664882, 53.73292800358364, 50.49385847364153, 50.553974287850515, 49.607480253492085, 56.99244955607823, 56.65846702030727, 51.565427030835835, 51.63399532863072, 54.414515018463135, 50.712733677455354, 49.20610019138881, 48.821923868996755, 45.332396098545615, 43.465845925467356, 41.298018387385774, 40.47085966382708, 41.0933244568961, 41.81313351222447, 45.31138474600655, 44.085065909794395, 42.75572613307408, 43.87789494650704, 42.9729893548148, 43.4841023172651, 50.69870873859951, 56.87298222950527, 56.38886649268014, 56.937273911067415, 55.906400953020366, 55.93400614602225, 58.098046915871755, 58.03763232912336, 56.334705284663606, 59.48555701119559, 52.05109569004604, 49.17422880445208, 47.91986009052822, 54.39810337339129, 57.17489535467965, 62.784367152622764, 60.566147804260254, 63.23415878840855, 59.52031190054757, 62.5843563079834, 58.79564258030483, 57.811902727399556, 54.46681758335659, 56.48163536616734, 59.54554775782994, 70.39099788665771, 67.9025491986956, 70.6616302217756, 25.59593551499503, 0.04800395734075989, 0.1594440857214587, 0.717732521040099, 0.32087598049214905, 26.24088294165475, 71.16076796395438, 63.600794383457725, 55.230323859623496, 41.51410041536604, 34.16099207741873, 28.230492659977504, 59.7333436693464, 3.967787044388907, 0.21009515066231998, 0.5375817992857524, 9.366253341947283, 26.86938050815037, 15.652580431529454, 17.488612379346574, 17.656341893332346, 30.457720347813197, 14.832114560263497, 8.86205210004534, 0.17608810189579213, 0.27442667580076624, 0.1948659885674715, 1.23042793571949, 49.43086746760777, 78.07040405273438, 62.31573895045689, 29.431384563446045, 42.672184467315674, 61.24375697544643, 62.97696426936558, 71.08497701372418, 59.231774057660786, 0.2507167352097375, 0.5678485866103853, 0.23241968559367315, 1.305055714079312, 0.8005812668374607, 0.42643868603876656, 0.6705420932599476, 17.055359193256923, 77.10029656546456, 78.76966381072998, 82.06278337751115, 81.61975928715297, 73.46079540252686, 77.8298087801252, 74.71999658857072, 80.24712181091309, 75.78983157021659, 78.41736929757255, 72.20038522992814, 75.75536155700684, 68.95249148777553, 64.46942343030656, 60.48924514225551, 59.659588541303364, 54.544342109135215, 60.32862363542829, 66.44249643598283, 71.23922007424491, 63.950490270342144, 70.00155135563442, 63.34831074305943, 56.699006284986226, 53.57618359157017, 52.83206278937203, 50.63324975967407, 52.49927881785801, 50.48780311856951, 55.32868603297642, 54.73785638809204, 52.457304750170024, 52.31126403808594, 51.65695912497384, 55.72012322289603, 58.73821571895054, 58.362394605364116, 57.984485558101106, 59.41724927084786, 59.2419879095895, 63.07561479296003, 60.672163418361116, 63.70678220476423, 59.84532083783831, 52.43844039099557, 55.903329849243164, 58.941158703395296, 54.270725522722515, 52.43387195042202, 53.48852859224592, 60.298294748578755, 62.36126354762486, 61.771528244018555, 57.10934604917254, 55.79864134107317, 57.25896855763027, 62.35589953831264, 60.92557116917202, 59.884293283735005, 58.140107836042134, 57.47070796149117, 57.91324915204729, 58.8575371333531, 58.59253978729248, 55.817158290318076, 59.05909047807966, 58.68310260772705, 59.30042920793806, 57.5266444342477, 59.16588429042271, 56.35056802204677, 59.17903028215681, 60.28162602015904, 57.05261400767735, 53.45395088195801, 56.43592316763741, 54.15594128199986, 57.346825054713655, 56.445445673806326, 57.20719405582973, 56.00956433159964, 52.101411070142476, 55.44075700214931, 54.55735955919538, 57.13184779030936, 58.708678926740376, 54.16389002118792, 57.7466904095241, 53.21065970829555, 54.61019713538033, 51.956513336726594, 49.40873050689697, 46.81592682429722, 44.41414301736014, 43.23688541139875, 44.443474837711875, 45.111637932913645, 47.89648635046822, 46.81636803490775, 46.8774322782244, 47.89144543239048, 45.77861983435494, 47.70140872682844, 52.56296253204346, 59.41339996882847, 58.00732428686959, 58.808580126081196, 56.76319374356951, 57.977186475481304, 60.294598306928364, 61.156772477286204, 58.69576917375837, 64.12812791551862, 55.46603454862322, 51.08919402531215, 50.55455098833357, 58.47809600830078, 61.131536620003835, 66.52807739802769, 64.03196484701974, 69.3919928414481, 65.20220129830497, 69.35768958500454, 66.43326228005546, 65.2610455921718, 64.84490408216203, 68.09990583147321, 66.2966537475586, 80.86310740879604, 74.33100169045585, 77.93693610600063, 28.93583903993879, 0.10665677541068622, 0.21486294482435497, 1.2692156029599053, 0.2819260076752731, 32.13838883808681, 83.04721110207694, 74.4590847832816, 69.75865622929165, 55.02790546417236, 46.87767546517508, 40.58214896065848, 75.06422424316406, 4.3228495461600165, 0.2597045286425522, 0.6109423456447465, 18.500138078417095, 34.49638857160296, 23.385055201394216, 24.275616237095424, 24.36239923749651], [21.866983243397303, 8.129373243876866, 4.258428888661521, 0.010858634919194239, 0.09175784273871354, 0.07679293610687767, 0.7774955513221877, 35.89130892072405, 58.8468508039202, 38.61303642817906, 24.48565854345049, 38.07232066563198, 54.80168948854719, 38.95839316504342, 59.46924958910261, 56.1647002356393, 0.267958934285811, 0.09132065584084817, 0.043042427860200405, 0.09102639555931091, 0.2426290049084595, 0.1184741412954671, 0.3065177452351366, 3.6554190516471863, 8.483473420143127, 33.15553215571812, 61.21255956377302, 72.1377124786377, 66.6449669429234, 67.34479645320347, 69.59364346095494, 70.27224622453961, 69.02582972390312, 70.88670321873256, 69.61315400259835, 69.11815738677979, 64.72561740875244, 60.66225528717041, 52.298837184906006, 52.49818100248064, 50.61292627879551, 51.049957547869, 57.325507981436594, 62.282616887773784, 61.39038481031145, 58.90440273284912, 55.77572618212019, 52.21305819920131, 46.39166981833321, 47.66613619668143, 45.15220846448626, 46.03212833404541, 47.543997287750244, 46.74493360519409, 46.82068634033203, 46.82096426827567, 50.573679379054475, 51.202550411224365, 53.969660077776226, 55.02735308238438, 55.43057441711426, 54.46095677784511, 55.314240728105815, 55.05634444100516, 54.0752066884722, 56.86060053961617, 57.906766482761924, 65.01304353986467, 54.43056535720825, 48.85735273361206, 51.67419760567801, 49.68795428957258, 43.2573687008449, 47.43429218019758, 55.969275202069966, 55.7767927306039, 54.89176593508039, 51.2497946875436, 55.089622838156565, 52.11149638039725, 52.18029049464634, 55.67746128354754, 53.03589514323643, 52.02467169080462, 57.26195975712368, 56.08975696563721, 52.957564626421245, 54.45998750414167, 54.13726799828665, 53.66986962727138, 54.61310148239136, 52.70301389694214, 52.09338937486921, 54.57072441918509, 55.110672405787874, 54.21849591391427, 54.00590535572597, 53.746216433388845, 52.18000561850411, 50.594200883592876, 49.57416364124843, 52.78900132860456, 50.87451900754656, 49.95389659064156, 46.20662191935948, 45.729197297777446, 46.602794306618826, 52.24723291397095, 42.56649194444929, 52.08913707733154, 51.18825796672276, 52.35444014413016, 49.908399786267964, 47.36064822333199, 45.4622231892177, 41.75704417909895, 40.754669257572715, 40.90424312864031, 40.13468844549996, 41.79417882646833, 41.13542011805943, 42.02202068056379, 45.392748151506694, 40.909596715654644, 40.930357933044434, 40.18166521617344, 44.33413451058524, 51.675420488630024, 53.508247579847065, 54.33432585852486, 55.17754186902727, 56.64954553331648, 60.66791112082345, 59.71058137076241, 57.36771133967808, 55.54780789784023, 54.33650759288243, 51.972515038081575, 44.60620859691075, 44.72986568723406, 53.01490463529314, 56.6928744997297, 59.179447174072266, 58.873524938310894, 58.829758235386436, 54.75641850062779, 54.51266874585833, 51.84671442849295, 48.10919850213187, 46.59456763948713, 45.33919838496617, 47.83422701699393, 55.7213009425572, 60.46088259560721, 69.35151958465576, 51.772097723824636, 1.1232275451932634, 0.3069678039423057, 0.16598737532539026, 0.8131739539759499, 14.292772803987775, 55.56687722887312, 51.802186897822786, 42.825131688799175, 23.96734724725996, 22.428859744753154, 24.884083884102957, 53.01466839654105, 7.188878979001727, 0.29357354981558664, 0.4483459490750517, 17.234278781073435, 23.098448957715714, 8.7385322366442, 5.915918622698102, 9.350198660578046, 23.782709292003087, 13.479604278291974, 5.9546765429633, 0.05182881513610482, 0.06279555255813257, 0.07117824203201703, 1.5841700626271111, 46.90578440257481, 67.92984172276088, 47.53684064320156, 29.31514467511858, 41.97575610024588, 59.594073976789204, 46.86662782941546, 64.37633146558488, 61.208849225725444, 0.15142788658184664, 0.12755621038377285, 0.032664411169077666, 0.2607791924050876, 0.5518278862748827, 0.10286383250994341, 1.1105672759669167, 11.441577775137764, 30.22515024457659, 57.01916190556118, 67.85591983795166, 77.6078416279384, 70.62017032078334, 71.4512721470424, 72.67159121377128, 73.55515888759068, 73.14284583500454, 71.61872373308454, 71.26991721561977, 70.96050698416573, 65.75718866075788, 63.93811552865164, 55.37419673374721, 54.72086109433855, 54.08029971803938, 52.068445341927664, 60.263977595738, 63.6301018851144, 63.33717972891671, 61.42442403520857, 59.71830081939697, 55.01070867265974, 49.73824535097395, 49.30281216757638, 46.87654638290405, 48.19547775813511, 48.67005014419556, 48.67997217178345, 48.733042512621196, 50.15784706388201, 53.14050374712263, 54.505352292742046, 55.4575959614345, 55.33064889907837, 58.008564540318076, 56.48564795085362, 57.59731803621565, 58.94728701455252, 56.12445279530117, 56.866923400333945, 61.604097502572195, 66.5458995274135, 55.10019799641201, 48.45003196171352, 55.01671886444092, 52.26721593311855, 46.21580048969814, 49.64053978238787, 58.48729542323521, 57.212075165339876, 57.96639244897025, 56.128531387874055, 56.051920550210134, 54.00076021466936, 56.15803343909127, 56.830761500767295, 55.36071375438145, 55.56451831545149, 58.84366158076695, 56.58267259597778, 55.25165830339704, 56.365728991372244, 55.20874970299857, 56.27159479686192, 56.43308482851301, 56.2489367212568, 52.47442511149815, 55.31534896578108, 57.254719734191895, 54.84922906330654, 54.31576027188982, 54.20032637459891, 55.550667081560405, 52.793993609292166, 53.65754699707031, 55.08970274244036, 53.323793751852854, 51.11083766392299, 50.643369810921804, 48.07985625948225, 54.00290025983538, 55.55264036996024, 41.5507869039263, 55.19559676306588, 52.97516788755144, 55.92260415213448, 51.7648264339992, 50.14468717575073, 46.85601098196847, 44.67898055485317, 41.36688545772007, 42.3391364642552, 42.95528187070574, 45.15005799702236, 45.39665303911482, 45.079926354544504, 47.57128633771624, 43.49642842156546, 42.33623211724417, 41.617274216243196, 44.53590324946812, 52.85843120302473, 54.61066266468593, 55.55791057859148, 56.16882051740374, 56.64012377602713, 60.31558186667306, 58.72834232875279, 58.39839322226388, 55.98247677939278, 55.36142247063773, 53.98867382322039, 47.267267908368794, 46.75077704020909, 54.98417697634016, 58.23155655179705, 61.638254846845356, 61.876668385096956, 62.883816719055176, 59.72916085379464, 61.70464488438198, 61.13152272360665, 57.44382190704346, 54.77704422814505, 56.04566022327968, 58.89015197753906, 63.094430514744346, 68.46644415174211, 71.91285487583706, 57.02462318965367, 2.437724449804851, 0.4555146172642708, 0.19170446321368217, 0.6910776027611324, 22.53666451999119, 65.93470818655831, 65.37860216413225, 53.50229297365461, 41.072313104357036, 29.697823660714285, 32.77834224700928, 64.29768480573381, 8.200970087732587, 0.40523663801806314, 1.2713464200496674, 16.843393972941808, 29.26964439664568, 15.044199637004308, 12.66000953742436, 16.41432360240391, 35.078136920928955, 16.365569829940796, 6.754325611250741, 0.1407759181622948, 0.1664897897945983, 0.4052557998469898, 2.1277238386017934, 60.78735760280064, 77.55223519461495, 56.880448068891255, 38.253203119550435, 50.779648303985596, 71.2102530343192, 54.96748740332467, 76.14830998011998, 71.8373418535505, 0.5461679814117295, 0.1766052541456052, 0.16199126546936377, 0.4743708340185029, 0.9454219490289688, 0.4120290178273405, 2.032358075891222, 19.674996818814957, 51.5520795413426, 75.89294283730644, 75.63841642652238, 84.10123198372978, 72.39815180642265, 76.3714166368757, 76.86889375959123, 76.89991746629987, 74.95337268284389, 78.22643280029297, 73.99404879978725, 75.14659513745988, 68.51169776916504, 68.65066174098423, 58.72643157414028, 59.08627183096749, 57.823092801230295, 56.708848408290315, 63.26407078334263, 67.25793007441929, 64.37684563228062, 65.15167399815151, 62.659111976623535, 59.45113563537598, 52.540373938424246, 50.209739685058594, 49.84122460229056, 50.26720128740583, 53.389145033700125, 52.38509907041277, 51.81504453931536, 52.01717805862427, 56.96267999921526, 57.073997088841026, 57.12221758706229, 59.50010653904506, 60.81021022796631, 61.1554662159511, 61.2529216493879, 62.299966539655415, 58.546167509896414, 59.05631814684187, 66.64997659410749, 68.13555703844342, 51.972747802734375, 52.65337944030762, 59.2910213470459, 54.450548376355854, 51.467085702078684, 54.949974468776155, 59.380131993974956, 61.772591318402974, 60.016642570495605, 58.012372153145925, 56.9620338167463, 58.23555524008614, 56.851779801504954, 59.65382153647286, 57.8340744291033, 58.72646631513323, 62.10524327414376, 60.0551494870867, 56.468847206660676, 57.56793410437447, 57.47308771950858, 58.641663551330566, 58.96150997706822, 57.98308202198574, 54.32211439950125, 57.468884059361045, 59.402143887111116, 57.57728637967791, 58.18964501789638, 57.016903741019114, 58.692357608250205, 55.33602333068848, 54.345595836639404, 58.362068040030344, 54.68996940340315, 54.27657243183681, 52.8496139390128, 52.7853569984436, 52.13833032335554, 53.965355668749126, 52.162009784153526, 60.32246058327811, 55.361248765672954, 59.60435731070382, 56.84694038118635, 55.4834189414978, 52.269199643816265, 48.30501610892159, 45.50708770751953, 46.083128111703054, 46.610725675310405, 48.41073295048305, 47.39570883342198, 49.84592853273664, 51.99992568152291, 45.20692205429077, 46.52993549619402, 44.46735232216971, 49.58904668263027, 54.88564109802246, 57.29512350899832, 59.495082991463796, 58.57396725245884, 59.3305218560355, 64.98340947287423, 61.090931347438264, 61.77605152130127, 61.05460616520473, 57.934354305267334, 58.772254943847656, 48.772640296391074, 49.282686710357666, 59.70630128043038, 62.44537843976702, 67.92618002210344, 66.08148888179234, 69.11471108027867, 65.92429283687046, 67.0964469909668, 67.84018216814313, 65.35620812007359, 63.716766766139436, 66.43231037684849, 66.51834992000035, 72.6810963494437, 77.21150943211147, 80.37400286538261, 63.52006326402937, 2.9234022285257066, 0.4259985882256712, 0.6431183676634515, 0.8517955701266016, 29.80078901563372, 76.30887590135846, 74.90423502240861, 67.79275376456124, 51.96045643942696, 42.340797083718435, 46.01836395263672, 82.633042880467, 9.38344579083579, 0.3625156661229474, 1.549556742821421, 26.8685519354684, 43.20484726769583, 23.79384204319545, 18.87348563330514, 21.06194758415222], [13.464047261646815, 12.216376611164637, 3.9286200489316667, 0.09750502756131546, 0.14836081330265316, 0.03141622564622334, 1.3230147446904863, 38.60091529573713, 59.93400069645473, 30.555026394980295, 10.36074640069689, 39.560273919786724, 38.389495509011404, 35.05299139022827, 69.4419503893171, 61.78149890899658, 1.0421073266438075, 0.12199769222310611, 0.2187099398246833, 0.03859194381428616, 0.19010556329573902, 0.17236223896699293, 0.7965767702886036, 5.560401448181697, 5.622510092599051, 27.305908032826014, 59.745023591177805, 70.24079867771694, 65.8625511441912, 69.92589242117745, 65.26286602020264, 68.90840516771588, 68.30273069654191, 67.59558473314557, 67.08451693398612, 65.38092286246163, 61.817851884024485, 55.789382866450715, 51.980568000248496, 50.72100550787789, 50.8339832169669, 50.11385801860264, 51.721341133117676, 56.53266988481794, 58.93965094430106, 55.3280085836138, 55.10734074456351, 53.54633413042341, 47.68724829810006, 46.32890674046108, 44.994147368839805, 46.15617452348982, 45.426842961992534, 47.82979754039219, 46.20284904752459, 51.23342820576259, 52.542698110852925, 53.42631789616176, 54.65627758843558, 55.819979258946006, 55.28173705509731, 53.3784830229623, 53.18414190837315, 56.02674375261579, 55.3505346434457, 53.12926851000105, 54.56417574201311, 44.26739706311907, 49.26718527930123, 58.053818157741, 48.12835815974644, 49.44617434910366, 46.459390435900005, 46.509556429726736, 56.12904902866909, 53.566883427756174, 52.8709831237793, 53.7945168358939, 52.38211481911795, 51.877286502293174, 53.706573486328125, 52.42940773282732, 55.61573348726545, 54.12953117915562, 55.53595427104405, 46.37480306625366, 50.65747465406145, 60.10145228249686, 53.810160705021445, 58.21528039659773, 56.28853450502668, 51.79575286592756, 41.559416566576274, 52.836318561008994, 58.04086324146816, 54.617885317121235, 56.82539749145508, 53.64468240737915, 51.986022336142405, 48.46831962040493, 53.659718309129985, 52.640445368630544, 53.556944029671804, 48.73535278865269, 48.84620434897286, 44.38625989641462, 51.479245049612864, 34.51109095982143, 41.73506702695574, 51.663594654628206, 52.21565335137503, 50.229034832545686, 49.23128046308245, 47.36314262662615, 43.644258294786724, 41.873739174434114, 40.96703052520752, 40.52061571393694, 43.621923310416086, 42.279562609536306, 43.32083354677473, 40.31908321380615, 42.86117894308907, 40.951761858803884, 40.40179109573364, 39.423519475119456, 46.36685085296631, 49.805660247802734, 49.82487549100603, 57.54880918775286, 54.83200100490025, 55.76922961643764, 54.08974231992449, 54.472758293151855, 55.709589753832134, 52.14679322923933, 51.00524588993618, 51.45173018319266, 48.67143283571516, 48.50647217886788, 53.1336076600211, 55.66916513442993, 59.5019200188773, 60.4014824458531, 58.38146046229771, 56.88789306368147, 56.841687543051584, 55.22198602131435, 49.36925779070173, 49.25225012642996, 44.24076114382063, 43.63999210085188, 48.580387115478516, 56.36938026973179, 61.99003519330706, 73.1036718913487, 9.887343049049377, 0.8428073695727757, 0.9198822166238512, 0.15995944663882256, 38.344408648354666, 51.573761395045686, 52.19945362636021, 44.288384096963064, 30.35892391204834, 24.909547294889176, 23.3919860294887, 45.38523367473057, 8.111667496817452, 0.37625247186848093, 2.33308436189379, 19.833570344107493, 27.926375218800136, 6.856286082948957, 3.1734448799065182, 8.631329349109105, 24.13265531403678, 14.348575523921422, 4.641358877931323, 0.06173955529396023, 0.09039075073919126, 0.06525221573454992, 2.4765635771410803, 51.045194557734895, 67.98583030700684, 41.97626331874302, 17.43707585334778, 42.02537318638393, 43.29124811717442, 44.52177061353411, 71.78272901262555, 70.22815295628139, 1.0524458118847437, 0.13391773402690887, 0.1353882144072226, 0.036477723691080294, 0.47521574582372395, 0.022403736931404898, 1.7296413481235504, 4.405226520129612, 17.05626940727234, 54.159470966884065, 68.74595628465924, 71.44966711316789, 72.44762992858887, 70.436279296875, 69.93321582249233, 69.87364196777344, 71.3578883579799, 67.5500601359776, 69.545179775783, 66.2656717300415, 66.32894897460938, 58.61084829057966, 54.27710049492972, 53.091796875, 53.93238994053432, 52.76246615818569, 53.635406562260215, 57.57777622767857, 59.57860728672573, 59.20466218675886, 58.87673500605992, 54.99109043393816, 49.8185248374939, 50.2810559953962, 47.408861773354666, 49.10161665507725, 46.31689330509731, 49.17461442947388, 48.87935420445034, 55.06578356879098, 54.020965576171875, 54.54278918675014, 56.587272303445, 57.01018483298165, 55.70034170150757, 56.752111366816926, 54.59284053530012, 58.8690641948155, 60.655216761997764, 57.361746311187744, 57.81208338056292, 49.81779180254255, 53.3492762701852, 61.91192354474749, 49.81863253457205, 50.087138720921104, 47.95592818941389, 50.00683838980538, 60.10109792436872, 56.56972115380423, 56.47988789422171, 57.81796155657087, 54.204318114689414, 55.31306995664324, 54.93173892157418, 54.450669969831196, 57.32705742972237, 56.195710045950754, 57.65651668821062, 49.453007902417866, 52.299976689474924, 61.084809984479634, 55.02062027794974, 60.976341656276155, 59.536535944257466, 51.493909222739084, 41.5067526953561, 52.74291392735073, 56.373260838644846, 57.47798272541591, 57.52726977212088, 55.44235856192452, 54.38734061377389, 51.11512817655291, 54.703035490853445, 54.80296100888933, 55.32345403943743, 50.787357330322266, 50.67060327529907, 51.33237402779715, 53.826402119227815, 37.42209434509277, 48.15963200160435, 53.38019922801426, 54.221890108925955, 52.905241216932026, 51.476260798318044, 50.267597334725515, 46.799508231026785, 45.96704108374459, 45.510502747126985, 44.35992622375488, 45.94803776059832, 44.77766234534127, 43.59975160871233, 44.04013538360596, 43.764114720480784, 41.687617778778076, 41.83975206102644, 41.23871203831264, 47.07706444604056, 52.28026465007237, 52.094351700374055, 56.58927338463919, 54.84965637751988, 54.918016229357036, 54.23421968732561, 54.79281663894653, 55.35956730161394, 53.344905853271484, 53.46448087692261, 52.25060279028756, 50.72096381868635, 49.74195916312081, 56.23969909123012, 58.872197832380024, 61.36025047302246, 63.610236985342844, 61.92556285858154, 62.08799089704241, 61.846200534275596, 62.27909415108817, 56.38879006249564, 58.79646941593715, 53.533285413469585, 54.753045150211875, 58.84038897923061, 67.82438196454729, 66.2997179031372, 78.55755615234375, 13.230348944664001, 0.8069902743612016, 0.235431648258652, 0.09617267655474798, 48.756642069135395, 61.52080249786377, 66.07670852116176, 55.62994602748326, 43.93335199356079, 32.96301146915981, 31.40109464100429, 64.92144543784005, 9.228411504200526, 0.46020589981760296, 2.2981987595558167, 24.63026966367449, 29.61388942173549, 11.629611662455968, 8.61224091053009, 11.164110149656024, 28.955943652561732, 24.40757989883423, 4.732292992728097, 0.1370567727301802, 0.25547972534384045, 0.19068482864115918, 2.9625364371708462, 66.75459562029157, 74.53313173566545, 52.93243646621704, 21.47077090399606, 53.13991315024239, 54.590228012629915, 53.912841183798655, 82.0855039869036, 80.12922477722168, 1.619667540703501, 0.17241154132144793, 0.28108405428273336, 0.173359536166702, 0.654955981033189, 0.11495789140462875, 3.3369123254503523, 15.03210629735674, 41.77531099319458, 75.22729846409389, 75.60164655957902, 79.35465349469865, 74.41175365447998, 76.4730201448713, 73.7953998020717, 73.7309969493321, 73.8251519884382, 71.1891860961914, 70.35765348161969, 71.38850906917027, 69.45019790104458, 61.76704665592739, 57.25208289282662, 56.99874462400164, 58.12751422609602, 55.2108028956822, 56.269506863185335, 59.6521817616054, 63.27579934256417, 61.31507328578404, 61.891607012067524, 58.661855016435894, 51.70281376157488, 52.29624898093087, 49.70374059677124, 51.35059567860195, 49.06486068453108, 52.803665501730784, 52.33422088623047, 58.10476234980992, 56.44038043703352, 56.57134008407593, 60.182468278067454, 58.89422362191336, 58.84983852931431, 59.51710878099714, 59.01606028420584, 61.97456850324358, 61.638859340122764, 60.08241421835763, 56.320051533835276, 54.00313997268677, 58.18194988795689, 56.08483764103481, 54.00032942635672, 53.934092249189106, 51.262954575674875, 54.24690362385341, 61.92275578635079, 60.76656859261649, 58.14246327536446, 58.33268410818917, 56.5985700743539, 59.0834230695452, 57.700939995901926, 56.16126087733677, 59.444409779139924, 57.99301447187151, 61.8069293158395, 49.479685510907856, 54.517226764133994, 62.84458718981062, 57.2343476159232, 62.09728063855852, 59.85429791041783, 52.16865921020508, 42.0826541355678, 57.18159689222063, 60.485208238874165, 61.28370911734444, 62.91287408556257, 57.58234466825213, 55.602538858141216, 51.53925664084298, 55.40813520976475, 57.229080881391255, 58.11440644945417, 54.96081018447876, 56.42815508161272, 51.91292381286621, 53.0934088570731, 41.56129605429513, 49.867016315460205, 56.33845383780343, 56.95666285923549, 57.228309631347656, 56.02932848249163, 54.519088881356375, 51.510588373456685, 47.87810141699654, 49.49728182383946, 47.10891498838152, 48.870630741119385, 47.702381474631174, 48.2525189944676, 47.0580472264971, 48.79107734135219, 45.366285937173025, 44.399603911808555, 44.907920224326, 49.20789630072457, 54.73953785215105, 53.89350782121931, 58.79721982138497, 57.73087630953108, 59.15947110312325, 56.967665331704275, 58.0011751311166, 59.04702145712716, 55.455834593091694, 56.737096309661865, 55.89795889173235, 54.522410120282856, 53.378854751586914, 59.78393350328718, 62.14286082131522, 64.40823759351457, 67.38629804338727, 65.94989694867814, 66.10507801600865, 67.61171845027378, 68.79888071332658, 64.50817353384835, 67.59826673780168, 62.37073394230434, 64.95956325531006, 69.64597729274205, 78.88530962807792, 75.09451838902065, 87.61601993015834, 15.122689962387085, 0.8391919721450124, 1.5709986665419169, 0.23166434041091374, 62.29954269954136, 71.97470079149518, 76.6189045224871, 68.72149167742047, 59.739131518772666, 45.2364935874939, 43.076659951891216, 82.23473044804165, 11.750197649002075, 0.5172499588557652, 3.2352894927774156, 34.78735828399658, 55.791251931871685, 17.762965474809917, 10.879154103142874, 13.780149476868765], [14.918645688465663, 14.268227423940386, 1.9981210444654738, 0.052871374014232836, 0.07693567951875073, 0.0902840511075088, 1.8019619988543647, 41.54285553523472, 60.05969360896519, 35.10109029497419, 13.182693856103079, 36.144254616328645, 40.66110134124756, 39.610964502607075, 69.88398088727678, 69.6560869216919, 4.290729326861245, 0.19929880356150015, 0.18562040611037187, 0.021551854875204817, 0.05270198453217745, 0.3347753089453493, 1.7211434841156006, 3.866977802344731, 9.695332186562673, 33.50436299187796, 63.7097282409668, 72.64806461334229, 67.09055491856166, 69.60785252707345, 64.07644026620048, 64.15986728668213, 62.4343238558088, 64.1695669719151, 62.53450298309326, 61.000660351344514, 55.3695900780814, 52.249470233917236, 51.41283416748047, 50.28462389537266, 49.556987694331575, 50.53587423052107, 47.834129742213655, 51.107384409223286, 53.607273306165425, 53.94801296506609, 54.51646246228899, 48.598205770765034, 46.330810546875, 46.18096569606236, 45.80922317504883, 43.30140290941511, 45.016968727111816, 49.26841511045183, 50.62466526031494, 50.816185406276155, 53.9006609916687, 54.555817059108186, 56.153760296957834, 57.33880683353969, 55.16085924421038, 60.254722595214844, 55.976605551583425, 55.282254695892334, 58.99251978737967, 61.92662593296596, 54.2453750201634, 52.0412848336356, 35.020484243120464, 40.08637762069702, 52.41666126251221, 47.02073540006365, 41.32968132836478, 46.23114211218697, 53.51147154399327, 53.7337965284075, 55.32983595984322, 52.45646401814052, 53.109955992017476, 51.95330326897757, 50.65298611777169, 55.99926710128784, 54.065274238586426, 52.500275884355815, 45.86141456876482, 42.08336632592337, 44.24394341877529, 51.30302136284964, 51.95250422613961, 48.11692489896502, 45.635386194501606, 41.99406460353306, 47.59684181213379, 45.62094783782959, 44.18941395623343, 47.957706928253174, 53.35653018951416, 57.229671478271484, 53.10866710117885, 48.93468270983015, 52.558380195072715, 54.04581233433315, 52.01782424109322, 47.9078049659729, 41.64533451625279, 47.99499443599156, 37.06284121104649, 39.33174419403076, 49.928869179316926, 51.324043137686594, 51.716786588941304, 48.7635555267334, 49.41273266928536, 45.9398249898638, 42.324479239327566, 42.08174392155239, 45.01491206032889, 41.87601818357195, 45.68397147314889, 43.326531069619314, 40.769951820373535, 40.69289629799979, 41.459077630724224, 38.324043478284565, 41.70886537006923, 38.28926427023751, 44.40537786483765, 50.016670090811594, 50.931667940957205, 49.79394211087908, 52.150691168648855, 51.27388061795916, 50.76718323571341, 47.59922851834978, 46.99472481863839, 47.138896465301514, 45.82297018596104, 46.30428579875401, 43.4986310005188, 49.05090870176043, 51.82128749574934, 57.59517799104963, 59.92159816196987, 57.368572916303364, 58.60304546356201, 59.1467558997018, 57.89886290686471, 54.254331248147146, 52.35344655173165, 48.98293447494507, 42.801215989249094, 40.472829478127615, 42.966683864593506, 51.29588903699602, 53.74972179957798, 65.05758149283272, 21.91389226913452, 0.47089505195617676, 0.16809987196964876, 0.13802439080817358, 19.38350772857666, 56.88876853670393, 50.271231242588584, 46.308638845171245, 29.030831336975098, 26.852517230170115, 20.337907075881958, 36.05723885127476, 9.837232640811376, 0.674798244876521, 4.218384683132172, 24.8098041670663, 19.944764103208268, 5.373456690992628, 5.690588976655688, 6.996479885918753, 26.85125092097691, 15.113052810941424, 3.337841864143099, 0.1066960965150169, 0.15324815176427364, 0.10396160717521395, 2.491336098739079, 52.998760495867046, 68.93537112644741, 42.440347399030415, 22.316568170275005, 38.700465611049104, 49.16402537482125, 48.93343550818307, 74.63256740570068, 78.08123629433769, 3.801441090447562, 0.19646346356187547, 0.086142897605896, 0.15368982377861226, 0.07115678675472736, 0.27411490253039766, 3.305839764220374, 2.042392360312598, 15.83304078238351, 55.45963873182024, 72.83765316009521, 72.54178496769497, 71.68566267830985, 70.17753532954625, 69.38690676007951, 65.11451503208706, 66.8715546471732, 66.91309792654855, 65.3079389844622, 62.93471227373396, 57.82966579709734, 55.37867832183838, 55.00249937602452, 54.320582321711946, 52.15205648967198, 55.792599882398335, 51.39216327667236, 54.17611190250942, 54.20684378487723, 56.276420320783345, 55.016656330653596, 52.124468667166575, 49.10555975777762, 49.25262532915388, 47.24348769869123, 46.40465600149972, 48.648489883967805, 50.385942527226035, 53.753849029541016, 53.82729148864746, 56.45478752681187, 56.74731363568987, 57.71091760907854, 60.567676407950266, 57.74240337099348, 60.80726419176374, 60.43466704232352, 58.01366799218314, 60.36001559666225, 63.19159412384033, 56.136473178863525, 55.090480940682546, 39.807212897709434, 44.169705390930176, 57.74709687914167, 51.95615897859846, 44.31422792162214, 46.99630205971854, 56.39125667299543, 57.557706356048584, 57.84292990820748, 56.56177241461617, 54.97418199266706, 53.59004177365984, 53.08428587232317, 58.921092305864605, 56.202981335776194, 53.85724517277309, 46.682312965393066, 42.16012307575771, 44.32258660452706, 53.793679577963694, 53.13104724884033, 48.868469851357595, 46.069401945386616, 42.78080218178885, 49.099219526563374, 47.34996884209769, 46.38249819619315, 47.69392899104527, 53.106721605573384, 57.30811664036342, 56.19302109309605, 52.42172997338431, 53.20802634102957, 54.54545382090977, 54.83240400041853, 50.591789858681814, 46.14297294616699, 54.92316484451294, 37.178389753614155, 41.21128055027553, 49.645938532693044, 52.46590314592634, 53.177242347172324, 51.32267434256417, 51.60019929068429, 48.62025587899344, 44.55850573948452, 47.681839125497, 45.9461304800851, 43.797799587249756, 47.73974541255406, 46.36861569540841, 43.910245759146555, 44.68474408558437, 42.8424083845956, 40.8011839730399, 43.03185101917812, 40.63628932407924, 46.97145530155727, 50.143214157649446, 51.534820216042654, 50.465391704014365, 53.31612294060843, 51.81662178039551, 51.56743853432791, 49.50272921153477, 49.19087668827602, 48.98327146257673, 48.402245725904194, 47.655620098114014, 46.485998562404085, 51.64128398895264, 55.11427157265799, 60.12989125932966, 62.03008460998535, 61.69006061553955, 64.05798585074288, 64.1682676587786, 63.1600284576416, 60.838864598955425, 57.87763268607003, 55.82602071762085, 50.41786255155291, 50.46872683933803, 53.55797931126186, 63.14237308502197, 63.37510994502476, 78.2025796345302, 31.47739280973162, 0.42083105551345007, 0.34939963849527494, 0.14694579637476377, 25.44470623561314, 67.44628879002163, 62.35476698194231, 59.2917856488909, 44.73523664474487, 37.18415675844465, 27.36620797429766, 56.77305671146938, 11.77420801775796, 0.5061477145978382, 3.592236476285117, 27.998921360288346, 33.65999221801758, 9.146158729280744, 5.477923725332532, 8.431740607534136, 31.174795286996023, 23.821353435516357, 2.6472951471805573, 0.1457252882953201, 0.1981014742382935, 0.23676377534866333, 4.176233870642526, 66.98804119655064, 76.9733668736049, 53.36108473369053, 25.782675300325664, 49.30373280388968, 56.132794107709614, 58.819092750549316, 81.11278397696358, 88.01757717132568, 4.8603973644120355, 0.32275579390781267, 0.38169285708240097, 0.32476767737950596, 0.2102568048451628, 0.6100503706506321, 6.097887601171221, 13.283272504806519, 48.68570443562099, 76.33987876347133, 74.01340648106166, 81.51557799748012, 74.02519062587193, 76.16161578042167, 72.60384627750942, 68.5267058781215, 69.74827562059674, 69.46342032296317, 69.60027204241071, 67.21766526358468, 60.01321710859026, 56.89850296292986, 59.43241718837193, 58.61293275015694, 54.590373924800325, 58.66168825966971, 53.35345908573696, 55.69375480924334, 57.90539073944092, 60.058171953473774, 59.48199953351702, 53.24019997460501, 52.389629295894075, 52.42537777764456, 49.2864283152989, 47.341554573604036, 50.44950117383684, 54.87626450402396, 56.3127316066197, 56.01502561569214, 59.261706897190635, 59.638966287885395, 61.4831918988909, 61.61634022848946, 60.783383233206614, 63.87778432028634, 61.12123244149344, 60.357840810503276, 62.9024726322719, 63.41623633248465, 59.21528598240444, 53.59659392493111, 42.59055355616978, 49.68845108577183, 53.85619946888515, 54.27914326531546, 48.52955756868635, 52.201809065682546, 59.65491935185024, 61.47023350851876, 62.7429906300136, 58.800638335091726, 55.858086654118125, 56.56407921654837, 54.68994508470808, 60.9622437613351, 58.26062434060233, 56.10171134131295, 50.43157829557146, 42.553033283778596, 43.73306669507708, 56.36181368146624, 56.84795829227993, 52.54482078552246, 48.571416991097585, 44.26427384785244, 50.15210090364729, 48.649320193699424, 49.69507966722761, 49.76704216003418, 57.79375403267996, 61.29627840859549, 59.00012806483677, 55.35576663698469, 55.746345724378315, 56.68679135186331, 58.7497010912214, 54.815592833927695, 49.69570500510079, 51.016957078661235, 43.35214212962559, 44.30094991411482, 53.21367870058332, 56.82506397792271, 56.68394953863961, 54.89331538336617, 54.902459212711875, 53.38904775891985, 48.65584455217634, 49.925037247794016, 50.85706165858677, 46.313106536865234, 52.61952434267317, 50.87368174961635, 44.82362815311977, 46.38620506014143, 46.51168257849557, 43.394703320094514, 45.98983464922224, 41.744262967790874, 49.7304425239563, 53.086412021092, 54.251235825674875, 53.05492625917707, 56.62014423097883, 54.84751285825457, 54.91724497931344, 52.10785552433559, 52.546213899339946, 52.07728692463466, 50.61021300724575, 51.24051884242466, 48.478787081582205, 56.749512740543906, 58.6644675391061, 64.24073042188371, 65.47803783416748, 65.7713212966919, 68.35338306427002, 68.67221505301339, 68.32579871586391, 65.58795138767788, 64.36347729819161, 62.52619293757847, 58.7726857321603, 60.478510175432476, 62.69380433218819, 72.75638008117676, 71.9396401814052, 87.31513513837541, 37.18331602641514, 0.43661692844969885, 1.2478535835232054, 0.22423176281154156, 35.24952813557216, 78.99395166124616, 73.79866545540946, 72.90908064161027, 57.030219963618684, 52.806469099862234, 43.23464114325387, 78.75448894500732, 13.92523741722107, 0.6028207157339368, 4.83775839635304, 35.86569438661848, 44.68501159123012, 12.159575956208364, 8.443787915366036, 10.630248785018921], [17.55025679724557, 9.521345819745745, 0.25817551783152987, 0.08867377215730292, 0.08955797114010368, 0.06997811035918337, 1.495896565062659, 39.39576142174857, 54.06749071393694, 32.672924177987234, 25.925118582589285, 34.11669036320278, 35.180789606911794, 46.32370948791504, 73.67171491895402, 70.41101564679826, 8.218066998890468, 0.7964812868407795, 0.6225032252924783, 0.13706818568919385, 0.12928867313478673, 0.4730296145592417, 1.2667708141463143, 4.63203352689743, 11.979578529085432, 44.05848210198538, 67.45288957868303, 69.09322030203683, 69.4979806627546, 69.9621342250279, 64.12518187931606, 65.76212188175747, 60.51731586456299, 55.14173085348946, 54.34407070704869, 51.65711545944214, 50.831183092934744, 48.799310956682476, 50.82608658926827, 49.666998522622244, 49.053403105054585, 49.60747330529349, 50.514133317129954, 48.38906151907784, 47.99061707087925, 48.541855880192344, 50.90853043964931, 47.92881284441267, 45.682831968579976, 44.154002462114605, 46.193336963653564, 45.47801644461495, 45.41477394104004, 48.83147069386074, 51.899652753557476, 53.381085123334614, 52.145632880074636, 57.24547515596662, 56.81687552588326, 56.391138553619385, 56.24502835954939, 59.401553290230886, 55.37950168337141, 55.09139462879726, 50.59415919440133, 53.60127353668213, 56.83772359575544, 55.97491019112723, 55.37876864842006, 36.51979085377285, 33.69832195554461, 41.91329179491316, 45.361099106924875, 41.54320641926357, 51.12622792380196, 51.252862317221506, 53.166542121342246, 51.05479349408831, 49.21268013545445, 51.40626117161342, 50.602382387433735, 50.433235440935405, 54.86857632228306, 44.48646681649344, 40.398473330906455, 43.21990748814174, 43.39518621989659, 42.120740686144146, 42.40713153566633, 40.5419397354126, 42.54145063672747, 41.94289806910923, 43.806220803942, 44.96536098207746, 48.283410685403005, 44.441265310559956, 44.330841064453125, 54.220483098711284, 53.80213900974819, 51.72384943280901, 52.45168713160923, 50.937132699149, 53.0563645362854, 46.30935103552682, 46.730418818337576, 40.30983516148159, 37.94883728027344, 42.91787624359131, 46.24486827850342, 54.631680965423584, 48.14691679818289, 49.26924542018345, 49.12062692642212, 46.90532234736851, 45.16989857809884, 43.726820264543804, 42.89894240243094, 47.561395577022004, 44.070926325661794, 44.65683317184448, 42.32511152539934, 40.291533606392996, 39.181819438934326, 38.34344284875052, 42.42138923917498, 40.77111216953823, 42.68920407976423, 48.053519112723215, 51.19220454352242, 51.730755942208425, 49.495829650333945, 46.237225260053364, 46.08056770052229, 44.81191349029541, 44.36565848759243, 44.4287759235927, 44.693929604121614, 45.06949710845947, 45.51715912137713, 50.25350638798305, 54.10527154377529, 56.8412115914481, 57.67791713987078, 59.01979841504778, 57.971836362566265, 60.22035680498396, 56.2860609463283, 55.231661387852256, 49.9544107573373, 49.802290371486116, 43.2194766998291, 44.37696320669991, 42.77873509270804, 50.92728362764631, 50.577264649527415, 59.53933606828962, 34.6772015435355, 0.30683532676526476, 0.27153969928622246, 0.5376156174710819, 21.024152857916697, 57.1780880519322, 47.18486227308001, 51.3537814276559, 32.16726207733154, 25.568700313568115, 20.645507301603043, 30.559963090079172, 9.113940800939288, 0.6822521420461791, 4.836788688387189, 20.315797907965525, 25.36365897314889, 6.879087465150016, 3.8609558854784285, 9.009871550968715, 18.15993516785758, 15.84128829411098, 0.8455656958477837, 0.03038894398404019, 0.08939318212547473, 0.09001529017197234, 2.498236745595932, 50.05871016638619, 63.18375655582973, 42.35192462376186, 29.292691571371897, 35.69684968675886, 35.49803393227713, 54.73741865158081, 77.35045255933488, 81.53876413617814, 8.66476321220398, 0.4380661706839289, 0.32647484434502466, 0.1729357231940542, 0.02872428045208965, 0.27708208188414574, 2.634809668575014, 2.3991630332810536, 21.714991399220057, 62.52713789258684, 73.69829177856445, 69.68345587594169, 75.42127132415771, 69.95032228742326, 69.2735538482666, 66.33140863691057, 65.28352301461356, 57.5855894769941, 58.38483033861433, 54.580528327396934, 52.36193030221121, 51.740684917994905, 52.604929651532856, 53.43474606105259, 49.96602119718279, 52.26084443501064, 53.31795726503645, 50.470331873212544, 49.41863863808768, 53.43831048692976, 50.95349918093, 50.955302238464355, 49.23254156112671, 47.34714092527117, 47.579130853925435, 49.99816008976528, 47.44476658957345, 51.34300477164132, 53.450285707201274, 54.55797447477068, 54.6770909173148, 58.482994488307405, 59.23485210963658, 58.19726024355207, 57.63443531308855, 61.70959894997733, 57.642926011766704, 59.2875611441476, 53.99977357046944, 55.82530505316598, 56.963138580322266, 57.13906349454607, 59.868882179260254, 43.1040358543396, 36.041824272700715, 47.85140643801008, 53.207036222730366, 44.74695130756923, 52.14110612869263, 54.772725922720774, 56.096382072993684, 54.8879965373448, 52.64297103881836, 54.30788448878697, 52.03546224321638, 51.475593771253315, 54.31507587432861, 46.49147721699306, 43.48956707545689, 45.027807916913716, 46.143893582480295, 41.89583444595337, 41.653460434504915, 41.65754944937569, 43.08355951309204, 44.44343662261963, 46.719107151031494, 46.88294219970703, 51.09815372739519, 45.69525882175991, 46.025280884334016, 56.144130093710764, 55.538240228380474, 53.92508390971592, 55.571351868765696, 51.94100495747158, 54.299317359924316, 47.01794222423008, 53.394710540771484, 45.77799449648176, 40.11133902413504, 44.053038188389365, 48.57689911978585, 55.942965848105295, 51.810952050345286, 53.43454108919416, 51.11320005144392, 48.99739020211356, 48.02269690377371, 46.28751284735543, 46.520069054194856, 48.73342118944441, 46.01519557407924, 47.86179052080427, 46.05120808737618, 42.40754495348249, 41.458229950496126, 40.49377482278006, 41.772500446864534, 41.187573296683176, 42.57305104391915, 49.31515564237322, 52.57636560712542, 52.94492585318429, 51.02857099260603, 47.71884175709316, 47.94942814963204, 46.24717855453491, 47.14859962463379, 46.2287415095738, 47.018216678074424, 46.630594049181255, 47.634327343532014, 52.63860409600394, 57.04084375926426, 59.36118425641741, 59.7843017578125, 61.1005129132952, 63.56324631827218, 63.84354359763009, 60.98642349243164, 61.08828408377511, 56.563002245766775, 57.55275229045323, 52.89759125028338, 53.96762078148978, 53.19404656546456, 60.67697157178606, 62.11085047040667, 70.32580988747733, 45.3046658379691, 0.48061123916081017, 0.25327983338918003, 0.4652013289076941, 28.074205092021398, 69.66365350995744, 59.36071177891323, 64.0283795765468, 44.553239004952566, 37.070890699114116, 27.302472148622783, 49.04295301437378, 12.429250308445521, 0.5446132134113992, 3.934100874832698, 29.8995680809021, 33.26189170564924, 6.8215572493416925, 5.316422402858734, 8.450050847870962, 27.664680004119873, 18.354583740234375, 0.39306768242801937, 0.17890148450221333, 0.25833030523998396, 0.14889593315976007, 3.8897774474961415, 64.56197343553815, 73.70595564161027, 50.39294631140572, 36.1904080254691, 47.0220034463065, 46.424781458718435, 67.47788224901471, 83.23374244144985, 93.02868747711182, 11.827703067234584, 0.9522802553006581, 0.8495407168354306, 0.2834523043462208, 0.2526356322424752, 0.9642389736005238, 2.6100725616727556, 22.527683973312378, 60.43296473366873, 75.06685761043003, 72.23397977011544, 78.60879911695207, 76.56568132128034, 74.91211427961076, 69.09371362413678, 69.02455820356096, 67.81377206529889, 57.7531418119158, 61.204992975507466, 57.57575082778931, 54.27569695881435, 54.39467791148594, 56.974627426692415, 56.55582823072161, 53.972078050885884, 56.16866765703474, 57.96060807364327, 52.73200525556292, 52.38629763466971, 56.47301265171596, 55.86652871540615, 52.836026736668174, 52.691056047167095, 47.895426750183105, 51.674725668770925, 51.49414546149117, 51.30985491616385, 53.08101674488613, 56.783343519483296, 58.48635046822684, 56.55176700864519, 62.633035387311665, 62.05392387935093, 61.85474681854248, 60.7146030153547, 64.8545412336077, 62.091930525643484, 61.067960602896555, 57.210164410727366, 58.60140568869454, 58.93469687870571, 60.38607134137835, 58.79231439317976, 44.248772416796, 40.958855969565256, 46.06757456915719, 55.98342868259975, 47.46492678778512, 56.63833461488996, 56.98977449962071, 58.92513615744454, 58.04033865247454, 54.60078580038888, 57.06949118205479, 55.44179228373936, 55.66269983564104, 56.94119616917202, 50.25695269448416, 44.47752448490688, 45.46692017146519, 46.80575466156006, 42.651089736393516, 43.45457247325352, 41.712106704711914, 44.2771349634443, 44.76616655077253, 47.300831181662424, 49.13792446681431, 51.521820136478965, 45.348210198538645, 46.09079197474888, 59.421515464782715, 57.13663509913853, 57.33665984017508, 57.80312367847988, 57.313838481903076, 57.74405704225813, 52.258224964141846, 50.7710360118321, 49.92852871758597, 45.00720303399222, 46.746597698756624, 51.16375514439174, 58.43550355093819, 56.315041882651194, 55.11067587988717, 55.94959095546177, 52.6795220375061, 50.91862964630127, 48.01012066432408, 49.409494808741975, 52.610946791512625, 50.093656131199424, 51.47690698078701, 50.068833691733225, 45.916374819619314, 45.861880098070415, 43.46457787922451, 46.497199058532715, 44.78814370291573, 45.2115078653608, 51.64044673102242, 56.68809066499983, 55.901221070970806, 52.851385729653494, 50.660785470690044, 51.86971296582903, 50.784459931509836, 49.26681702477591, 48.46928194590977, 50.16530248097011, 49.18587398529053, 52.09053019114903, 57.64975956508091, 60.65318788800921, 63.44539792197091, 63.40788459777832, 63.93412031446184, 67.16458102634975, 66.3878071648734, 66.01893424987793, 64.83692060198102, 61.451647077287944, 63.42631816864014, 60.31299018859863, 63.44468225751604, 64.42991597311837, 70.47137464795793, 70.87764276776994, 78.53379331316266, 54.03940609523228, 1.0900151559284754, 0.6075773004974637, 0.4155026828604085, 32.51183019365583, 80.41277381352016, 69.11539895193917, 77.96350601741246, 57.314943245479036, 52.30393716267177, 44.95607818875994, 72.74661091395787, 16.078277451651438, 0.760630047747067, 8.33199313708714, 30.208113261631556, 55.53582225527082, 11.463354298046657, 6.5157288142613, 15.81225003514971], [10.750344055039541, 4.759146043232509, 0.024172116237293397, 0.0225246247303273, 0.11837377239550863, 0.1340746520353215, 4.0784952981131415, 39.429494925907676, 55.34103993007115, 29.222893442426408, 28.66644695826939, 40.81580645697457, 56.94907890047346, 48.504120213644846, 69.95175361633301, 74.08850261143276, 16.4261702810015, 0.18709205357091768, 0.18805258774331637, 0.12545667375837052, 0.048717555656496964, 0.3609859496355057, 4.781818015234811, 10.481941223144531, 21.276243925094604, 56.60655702863421, 71.87421594347272, 65.88461862291608, 68.03809465680803, 64.69692134857178, 68.23136574881417, 63.2077625819615, 61.905670166015625, 59.5103759765625, 55.727050576891216, 57.21961743491036, 50.97773102351597, 50.64408547537667, 46.35422945022583, 50.92458425249372, 46.88464798246111, 48.98515442439488, 48.188011918749126, 48.448395660945344, 47.3292875289917, 48.48188597815377, 45.89192063467843, 49.122013092041016, 45.995601654052734, 45.83569581168038, 45.29933309555054, 45.73943199430193, 47.96809448514666, 51.67469787597656, 52.344507694244385, 52.798940726688926, 55.05330807822091, 56.07160479681832, 54.79389360972813, 55.42151049205235, 55.111464500427246, 57.058957712990896, 57.01748391560146, 58.53567573002407, 57.9528295653207, 50.34591742924282, 54.56021874291556, 53.30287619999477, 53.96105473382132, 59.54080213819231, 44.40053497041975, 36.49160896028791, 39.81441470554897, 46.96861696243286, 51.90874099731445, 54.808304173605784, 55.37425231933594, 49.55906173161098, 53.766282830919536, 50.25949226106916, 45.58469908578055, 48.045431409563335, 42.63654020854405, 40.797049794878276, 41.11664955956595, 46.09701408658709, 48.82649578366961, 39.984551770346506, 34.13944223948887, 36.596999236515586, 39.26675074441092, 47.80461032049996, 43.073185852595735, 42.34239169529506, 44.72825370516096, 40.097373144967214, 41.58260270527431, 49.888649531773154, 52.995512213025776, 54.81393568856375, 55.19729559762137, 49.565975189208984, 46.02958876746041, 45.942899567740305, 44.44541685921805, 35.6284168788365, 42.38093682697841, 43.91496011189052, 51.97801801136562, 51.29215785435268, 47.827535901750835, 48.76524741309029, 48.77844551631382, 48.95258126940046, 46.534809657505576, 43.03990398134504, 44.236411571502686, 45.193400859832764, 46.24397543498448, 46.76647996902466, 44.846286228724885, 41.782801151275635, 41.48590809958321, 41.60104322433472, 40.99313143321446, 40.4970508984157, 41.66727692740304, 47.54224286760603, 48.799679211207796, 49.62084511348179, 49.50795078277588, 46.43244879586356, 46.93763147081648, 44.1437087059021, 42.875992502485005, 44.577179023197715, 44.67290782928467, 44.524622849055696, 46.913747038160054, 49.50181204932076, 56.82854502541678, 58.16681323732649, 59.41119738987514, 58.759671756199424, 60.9703939982823, 58.69270501817976, 57.40169150488717, 55.44263996396746, 51.54632295880999, 48.114882128579275, 45.8280736378261, 47.18113456453596, 47.10724394662039, 52.07939917700631, 54.87125137874058, 62.93914522443499, 52.04098606109619, 0.8468594721385411, 0.6769408956170082, 0.05477974357615624, 30.955697740827286, 62.7867225919451, 44.5924129486084, 52.13161488941738, 30.468903473445348, 18.279438972473145, 16.849621295928955, 35.94403185163225, 4.86366605758667, 0.21458387694188527, 5.112467586994171, 20.455234357288905, 25.955169541495188, 5.167877299445016, 4.902920339788709, 11.732974801744733, 15.47877298082624, 10.296499013900757, 0.07084432816398994, 0.025512036301993897, 0.15065650083124638, 0.17467152433735983, 6.217627210276468, 51.123160294124055, 64.56343255724225, 34.06607273646763, 32.52573353903634, 45.00792564664568, 57.93916940689087, 59.403213909694124, 73.56747109549386, 85.47664873940604, 16.10761274610247, 0.4341372629361493, 0.9699713460036686, 0.10916523116507701, 0.02239031550873603, 0.27674973543201176, 2.8625229809965407, 4.45528872523989, 30.423173904418945, 68.03272369929722, 73.91073295048305, 70.754013470241, 72.95453575679234, 67.21607412610734, 72.05548054831368, 64.80230467660087, 66.45169585091728, 59.747226170131135, 59.814095633370535, 56.798098019191194, 54.3860239301409, 51.81309904370989, 49.76386335917881, 51.95921618597848, 49.54819474901472, 50.738435064043315, 50.013102190835134, 51.745187350681846, 49.26703241893223, 49.52610295159476, 47.97654349463326, 49.91630336216518, 48.4627297946385, 48.718256746019634, 45.50307164873396, 48.0694374356951, 49.73237759726388, 53.972283022744314, 53.9789776120867, 56.90532956804548, 58.26492180143084, 59.900628498622346, 56.15088374274117, 58.567991801670615, 55.410754680633545, 59.468172618321006, 58.42148903438023, 59.98839119502476, 58.743732588631765, 56.817170824323384, 55.54007455280849, 56.08234323774065, 56.57372331619263, 62.97301074436733, 48.99662937436785, 40.178357873644146, 40.662616048540386, 51.130355153764995, 53.58359037126814, 57.312952586582725, 55.54396554401943, 52.74042647225516, 55.96437324796404, 52.94143785749163, 46.13383606501988, 50.03780998502459, 47.009607860020225, 46.12434829984392, 41.9028069632394, 48.490637234279085, 51.23868451799665, 39.66138757978167, 32.827802998679026, 35.558399881635395, 40.691746371132986, 49.9899125780378, 43.8147497177124, 43.158631324768066, 42.122043473379954, 40.25815793446132, 42.49699606214251, 49.601400579724995, 54.072681018284385, 55.52919019971575, 54.03806856700352, 54.23497009277344, 49.366204057421, 50.8908611706325, 50.35598189490182, 38.8548823765346, 44.52918781552996, 45.93211248942784, 54.1551387650626, 51.22555589675903, 51.29271718433925, 51.987780230385916, 51.8827234676906, 49.70712784358433, 48.93791709627424, 48.33043956756592, 45.87501914160592, 46.67086580821446, 48.52819224766323, 48.35647794178554, 48.25572558811733, 44.507384368351524, 42.47028718675886, 42.953391960689, 42.569893087659565, 42.18407351630074, 43.47731045314244, 48.35934059960501, 50.91643054144723, 52.485319886888774, 52.651843888419016, 48.48954289300101, 48.59878247124808, 45.8994768006461, 44.01592785971505, 46.132995332990376, 46.19045693533761, 46.815270219530376, 48.43410669054304, 53.61544091360909, 57.78581918988909, 60.62146241324288, 63.01588807787214, 62.100678307669504, 65.1838858468192, 62.946670123508994, 63.35146522521973, 60.23116820199149, 57.997860840388704, 55.43444108963013, 53.722557817186626, 54.97266033717564, 55.527856145586284, 61.31466334206717, 64.75287519182477, 71.76981231144497, 62.42767442975725, 2.3862452464444295, 0.1657893109534468, 0.01639182336761483, 36.53770678383963, 74.14822932652065, 54.714920384543284, 65.35021877288818, 41.286150864192415, 32.824158668518066, 27.080586637769425, 53.10140970775059, 8.297934804643903, 0.16295550444296428, 3.6593708395957947, 26.442856652396067, 33.56953362056187, 6.698429524898529, 6.356153879846845, 11.681600689888, 21.732056174959453, 8.372606226376124, 0.10300164297223091, 0.13623877162379877, 0.2946412925209318, 0.2966526874474117, 7.891345330647059, 66.24497999463762, 74.18645136696952, 45.14669506890433, 37.99078702926636, 53.3901629447937, 69.16984503609794, 67.97818728855678, 77.00038146972656, 91.81480244227818, 21.426764488220215, 0.4792316960436957, 1.3979254450116838, 0.18237297822322163, 0.22535160343561852, 0.4916437843016216, 9.959520067487444, 42.421969413757324, 66.54765047345842, 73.21298789978027, 75.71105984279087, 74.1923017501831, 74.41898672921317, 73.50946058545793, 73.62672533307756, 68.15962559836251, 68.12362003326416, 62.97065530504499, 62.242372921534944, 64.27439444405692, 57.96238333838326, 56.26612309047154, 54.26356887817383, 55.1806755065918, 54.46081781387329, 53.31834636415754, 55.04880911963326, 56.40429149355207, 54.613296031951904, 52.333522592272075, 50.73812934330532, 54.304872444697786, 51.8790409224374, 52.2262875693185, 48.23634358814785, 51.48460905892508, 54.24749769483294, 57.39539296286446, 56.07379000527518, 58.78772163391113, 59.72756276811872, 62.238877977643696, 58.727286202566965, 59.609895024980815, 56.434033257620676, 62.05481324877058, 61.182188987731934, 62.526839120047434, 58.90294361114502, 55.39552422932216, 58.98427922385079, 57.273841176714214, 60.693223408290315, 62.56954274858747, 49.93032135282244, 44.37865856715611, 45.5712126323155, 52.294779436928884, 54.925322260175435, 59.60774803161621, 56.89498022624424, 56.14764935629708, 59.19027246747698, 56.8259950365339, 47.76966782978603, 49.163677964891704, 48.18318639482771, 47.81467826025826, 43.488302503313335, 49.90751736504691, 50.46843154089791, 43.21767711639404, 33.46239587238857, 37.469182286943706, 39.953010422842844, 50.18246453148978, 45.24771492821829, 47.738018785204204, 45.23241152082171, 41.5899886403765, 43.181046213422505, 49.77883325304304, 58.75035422188895, 59.650138991219656, 59.902573994227815, 57.21312434332711, 52.73839412416731, 51.33012628555298, 50.971234457833425, 42.6291959626334, 48.30268498829433, 49.28725862503052, 58.342481068202424, 55.898476532527376, 52.897994245801655, 53.220237800053184, 56.21707228251866, 53.970122132982524, 54.47155278069632, 50.72137376240322, 49.23142637525286, 50.14568771634783, 55.087854521615164, 52.37373876571655, 51.319926330021445, 46.75161082404, 46.175841399601524, 46.82910755702427, 45.21825456619263, 44.58780629294259, 46.28896154676165, 53.49181856427874, 53.53682899475098, 57.0468886920384, 55.69541890280587, 50.36219705854143, 52.11380318232945, 48.09677512305123, 47.130655901772634, 49.37898874282837, 48.42594950539725, 51.51306888035366, 52.2255163192749, 56.56787988117763, 63.870794432503835, 62.80172375270298, 67.14473002297538, 63.952790124075754, 69.17857197352818, 64.86522756304059, 66.79826504843575, 62.611211095537456, 64.27948747362409, 60.42548847198486, 59.44892610822405, 62.010699135916575, 65.23620578220913, 69.43986592973981, 74.9670467376709, 76.35771478925432, 71.016099521092, 3.2306294228349413, 1.4553134398800986, 0.15334568438785418, 42.540331976754324, 83.29901381901333, 64.25940023149762, 78.62572492871965, 52.549041816166465, 42.499264648982454, 43.71466786520821, 80.11113861628941, 12.985955613000051, 0.21973935887217522, 9.771162220409938, 26.218384674617223, 49.46607051576887, 10.123765059879847, 8.991996441568647, 20.622857911246165], [6.545154001031603, 0.7314553218228477, 0.1320786327123642, 0.026301844278350472, 0.05113281801875148, 0.07571936478572232, 4.593602606228419, 35.29724488939558, 54.3161632674081, 36.53851624897548, 23.34128155027117, 28.519575936453684, 50.82792786189488, 50.30970689228603, 68.78202438354492, 71.45863028935024, 20.911670207977295, 0.3357951742197786, 0.7307113217456, 0.02843640179240278, 0.08872721357537167, 0.7190884511385645, 10.069231254713875, 18.027370486940654, 41.34476934160505, 64.81915405818394, 67.39196082523891, 68.35578714098249, 71.13403129577637, 65.45982660566057, 66.19363975524902, 63.44392490386963, 65.38081169128418, 58.31756482805525, 57.02229554312569, 52.82118191037859, 52.60584333964756, 48.301118169512065, 48.88150814601353, 46.34454018729073, 48.48848329271589, 48.64690569468907, 47.142370564596995, 48.417851379939485, 46.54858793531145, 46.465831415993826, 47.62689971923828, 46.06000450679234, 46.24392679759434, 46.553872040339876, 44.590738432747976, 47.23249912261963, 50.30877583367484, 49.19990587234497, 52.400940963200156, 57.5543920653207, 56.75274017878941, 55.729836804526194, 56.667798451014924, 56.088012967790874, 57.72385515485491, 55.94222239085606, 55.31384468078613, 52.1092312676566, 55.81769330160958, 60.257675579616, 60.086916651044575, 53.89360509599958, 57.51819889886038, 53.3006979397365, 62.886998994009836, 55.068441254752024, 34.43403543744768, 37.23242589405605, 48.575120380946565, 53.09240484237671, 52.574843951633994, 51.200035163334434, 55.00599084581648, 43.13066482543945, 45.72519513538906, 45.24220848083496, 44.10771008900234, 43.63443006787981, 39.64366967337472, 48.68434606279646, 53.82743392671858, 36.411593505314414, 28.39940857887268, 27.565645592553274, 38.70718451908657, 53.341174670628135, 42.04375464575631, 38.142024993896484, 42.49714197431292, 41.751082624707905, 37.68496554238455, 43.11895016261509, 51.965851715632844, 54.36861521857125, 50.7977031980242, 52.067545550210134, 46.808221272059846, 51.482545443943565, 36.49374205725533, 36.45509965079171, 45.12957123347691, 45.52686922890799, 50.98182003838675, 49.9599415234157, 49.714864662715364, 49.69738299506051, 49.5625010899135, 48.453481742313926, 47.27541814531599, 45.17813914162772, 44.63926117760794, 48.27662229537964, 44.91970089503697, 46.692102977207725, 44.82036944798061, 45.186414446149556, 42.889927114759175, 42.21785218375069, 41.51122038705008, 42.32173122678484, 40.29930864061628, 45.227332387651714, 46.532329150608604, 46.75471666881016, 47.49309131077358, 47.433413233075825, 46.984413691929404, 46.359343324388774, 46.81787926810128, 42.941427162715364, 44.38077776772635, 43.22829743794033, 46.35768617902483, 49.26101180485317, 58.03324106761387, 57.5171149798802, 59.91735281263079, 58.28186845779419, 60.936458996364046, 56.84083638872419, 57.47715588978359, 55.57768862588065, 52.877316406794954, 50.0668499810355, 51.75061041968209, 50.737483160836355, 54.01515340805054, 54.1014917237418, 62.994890621730256, 56.87174545015608, 67.48882566179547, 8.341430527823311, 0.6460938251444271, 0.08395498857966491, 28.42277363368443, 67.70988954816545, 42.05205774307251, 51.60465656008039, 32.09003284999302, 17.656183821814402, 12.108761174338204, 36.083329336983816, 2.91621800831386, 0.03789263544604182, 5.975485963480813, 17.20443105697632, 19.997136150087627, 7.216017774173191, 5.8586993387767246, 13.345456276621137, 13.623582243919373, 3.5802352002688815, 0.09358517825603485, 0.027138818920190846, 0.1400598601571151, 0.04436586630929794, 5.162923233849662, 49.871841839381624, 65.12674386160714, 41.29606246948242, 24.816196509769984, 39.292917660304475, 57.25765534809658, 60.6045366014753, 75.5868330001831, 80.54749938419887, 29.48586538859776, 0.36908537788050516, 0.8753026287470544, 0.07886839152446815, 0.40396517195871895, 1.6439905783959796, 10.579695429120745, 15.963991744177681, 50.72682115009853, 77.14309746878487, 72.50336837768555, 74.41289315904889, 73.70426722935268, 67.94716358184814, 68.69445623670305, 66.90904712677002, 68.59476348331997, 59.81703472137451, 60.647816930498394, 53.63725478308541, 55.841150420052664, 51.26379530770438, 53.713476521628245, 50.55338716506958, 53.516161578042166, 50.071199553353445, 49.26753963742937, 49.67695181710379, 51.07673243113926, 50.63338524954659, 48.141646589551655, 48.52045890263149, 47.97107178824288, 47.11287546157837, 47.646035058157786, 49.01939862115042, 50.88492740903582, 52.890472820826936, 54.02388729367937, 58.03163603373936, 57.31504052025931, 57.991628306252615, 58.49239540100098, 59.048348563058035, 58.14975888388497, 58.455305916922434, 56.61620807647705, 56.86544690813337, 55.598825045994346, 61.38743877410889, 58.92367008754185, 55.07792901992798, 60.46195956638881, 55.21542692184448, 61.094516617911204, 57.021559034075054, 38.72396789278303, 40.30986990247454, 51.43322018214634, 56.82571016039167, 53.44859034674508, 55.073732307979036, 58.26205219541277, 46.70451940808977, 46.04503113882882, 47.63400772639683, 44.89896052224295, 43.43058034351894, 42.490443910871235, 51.45786196844918, 57.82592419215611, 38.21128116335188, 28.60518295424325, 27.922749996185303, 40.9948684828622, 58.81959996904646, 44.379315171922954, 42.64462791170393, 43.62807594026838, 44.0473232950483, 37.99060985020229, 45.540817737579346, 53.17101328713553, 55.5210851260594, 53.638682637895855, 54.62587921960013, 48.22941970825195, 56.66438341140747, 42.42211185182844, 41.661016600472585, 47.73681674684797, 49.3864198412214, 50.71158722468785, 53.70870310919625, 50.94147184916905, 54.06109837123326, 53.19526250021798, 50.98078128269741, 50.12491955075945, 48.616924217769075, 46.38528094972883, 51.05642979485648, 47.42104196548462, 48.88438122613089, 46.39015858513968, 48.13790498461042, 46.22691413334438, 44.8917760848999, 43.618765354156494, 43.002543517521445, 42.141526222229004, 47.614837646484375, 48.16307830810547, 47.1581985609872, 48.75684009279524, 49.49151829310826, 50.13086026055472, 46.543470587049214, 48.61641352517264, 46.06658445085798, 45.959620407649446, 44.683410031454905, 49.33939790725708, 53.544673510960166, 60.46601731436593, 61.215401376996724, 63.7532309123448, 63.28296988351004, 63.40463284083775, 62.25700582776751, 63.25405148097447, 59.15155710492815, 59.57235390799386, 57.05604641778128, 60.46586445399693, 56.01007502419608, 64.29696914127895, 62.637398856026785, 71.79973820277623, 62.49133382524763, 76.13672038487026, 11.534972855022975, 0.5890365753855024, 0.13726479799619742, 33.289361408778596, 78.63220759800502, 52.40277876172747, 64.98648057665143, 44.45013468606131, 26.148119279316493, 18.706176485334122, 50.06652341570173, 5.213954278400966, 0.02363159354510052, 7.147370874881744, 24.850576196398052, 32.78501599175589, 6.030470533030374, 6.126928465706961, 17.33731188092913, 16.703999212809972, 1.7168498230831963, 0.23539688012429646, 0.12774691943611416, 0.279356449842453, 0.14971967467239924, 8.282025166920253, 66.33806501116071, 75.93185274941581, 53.30585697719029, 32.85637746538435, 40.59282486779349, 63.909065110342844, 69.48304203578404, 79.68560314178467, 86.50692067827497, 36.30082532337734, 0.3699559383094311, 1.6889698505401611, 0.16077292870197976, 0.6862112581729889, 3.456163389342172, 39.32619258335659, 55.16695628847395, 73.52603203909737, 74.4550061907087, 75.5939826965332, 77.83382483891079, 75.77103669302804, 69.01061316898891, 68.0649494443621, 68.84088257380894, 71.51639761243547, 64.04194940839494, 62.4611508505685, 56.8948586327689, 58.53273664202009, 55.09002235957554, 55.951772689819336, 53.38371501650129, 56.922689642224995, 52.76741327558245, 52.8445382799421, 54.604068824223106, 53.66027069091797, 53.45529883248465, 53.10087817055838, 51.92757756369454, 50.36539670399257, 51.17926352364676, 49.68604006086077, 50.57631969451904, 55.41499655587332, 55.628650188446045, 57.49682971409389, 60.53579112461635, 62.15003831045968, 60.439176423209055, 63.48688561575753, 60.158066204616, 61.14951855795724, 62.49846267700195, 61.214407784598215, 58.13896138327462, 59.566753659929546, 62.93125901903425, 63.82614530835833, 58.239109243665425, 62.26812294551304, 59.359919684273855, 63.81855092729841, 57.26448195321219, 43.53001601355416, 47.10506568636213, 52.598162106105256, 59.55590057373047, 56.583402156829834, 56.63710478373936, 60.37215409960066, 47.904403822762625, 46.65086194447109, 51.820957456316265, 48.62367786679949, 45.515477657318115, 45.25504527773176, 52.34048816135952, 57.9559770992824, 37.04216684613909, 28.769193444933208, 26.695661646979197, 39.73897116524832, 58.39633655548096, 45.36350665773664, 42.87910876955305, 46.63925150462559, 42.65715203966413, 38.679544585091726, 47.130485670907156, 52.43359749657767, 61.15306213923863, 55.92106165204729, 59.43771171569824, 50.69835785457066, 55.746713978903635, 45.190357548849924, 45.1903714452471, 49.5339162009103, 53.1656562260219, 55.17586040496826, 56.53767258780343, 56.042057582310264, 57.107424872262136, 54.0499187197004, 55.3717440196446, 52.53577423095703, 53.35615151269095, 49.24596895490374, 54.23160021645682, 50.14512143816267, 51.971872329711914, 51.275034018925254, 51.92682368414742, 50.7314521244594, 48.84975140435355, 46.69265535899571, 46.431135586329866, 44.6219983782087, 48.88088628223964, 51.25561727796282, 50.467114857264924, 52.33571822302682, 50.66341188975743, 53.66910879952567, 50.49924680164882, 53.985814639500205, 50.47504275185721, 49.64805425916399, 49.26264810562134, 52.41264867782593, 56.33096020562308, 65.2133184160505, 62.90763514382498, 67.35094560895647, 67.27753789084298, 67.96918937138149, 63.64536707741873, 67.37055342538017, 62.44272422790527, 63.54615374973842, 61.84100328172956, 65.86997182028634, 61.53201689038958, 71.14540549686977, 68.73859814235142, 77.90348747798375, 65.76275416782924, 78.5578966140747, 12.82312718459538, 1.0126138521092278, 0.2497956646340234, 37.32738692419869, 87.29404040745327, 62.37513215201241, 77.60500676291329, 57.638347148895264, 39.05130795070103, 31.27886540549142, 78.91781330108643, 8.902509723390851, 0.19331702882690088, 9.735511013439723, 27.493912390300206, 39.31639909744263, 18.920620475496563, 12.299186979021345, 27.225446156093053], [5.32701449734824, 0.056183910729097467, 0.03140573549483504, 0.06875537668487855, 0.026766879949718714, 0.19861306250095367, 7.366199612617493, 39.54170485905239, 50.945508752550396, 28.37832600729806, 32.886848790305, 33.21892057146345, 55.741773809705464, 51.423273835863384, 72.1759831564767, 67.80604566846574, 38.96485151563372, 0.3634360581636429, 0.4462781814592225, 0.24508869435106004, 0.05094548807080303, 2.0478892539228712, 20.064512831824167, 24.395976407187327, 50.592752184186665, 63.55851459503174, 63.141122409275596, 67.07005773271833, 67.43519946507045, 65.57415921347481, 65.38478606087821, 62.84776946476528, 62.40931728907994, 61.90998499734061, 60.77688666752407, 55.87483876092093, 52.144628865378245, 49.198186193193706, 50.12498903274536, 46.891029902866904, 48.33289575576782, 47.09794725690569, 44.82555627822876, 48.61696590696062, 44.14677286148071, 48.26309415272304, 44.376726967947825, 46.22356162752424, 46.34462703977312, 45.08381734575544, 44.2218724659511, 45.32578141348702, 49.093285764966694, 52.86999647957938, 56.74254022325788, 55.69127082824707, 56.0086020060948, 56.15897492000035, 55.196347168513704, 54.897519043513704, 51.70356069292341, 53.28292097364153, 51.369328022003174, 53.375484875270296, 53.959894384656636, 54.95100280216762, 54.22024685995919, 52.46733447483608, 51.241043431418284, 56.66252129418509, 51.690213203430176, 53.655566760471885, 42.743000507354736, 39.00802762167794, 45.51904903139387, 48.15772819519043, 51.226646763937815, 52.4064439364842, 54.57576533726284, 49.88886145183018, 42.17044462476458, 42.0611320904323, 43.538631779806956, 38.79557602746146, 40.86848075049264, 47.20818042755127, 55.613075801304404, 51.55560575212751, 32.7551908493042, 34.70083236694336, 52.087990624564036, 51.62228413990566, 46.26646327972412, 36.02921329225813, 43.697905336107524, 43.75055878502982, 42.611557960510254, 37.92864234106881, 44.581177711486816, 51.01069327763149, 57.89685835157122, 52.739676066807334, 54.89953402110508, 45.45599412918091, 30.966019289834158, 45.22729417255947, 47.162513392312185, 49.522156374795095, 48.87459816251482, 47.48994377681187, 49.68888187408447, 48.904030731746126, 52.81215272630964, 50.31224298477173, 49.21211038316999, 48.42159298488072, 50.46750395638602, 51.8930206980024, 47.4804664339338, 47.12612567629133, 44.58869913646153, 49.23472329548427, 45.23667424065726, 43.81868587221418, 43.408252307346885, 41.483243465423584, 41.19749532427107, 41.154590197971885, 46.69402762821743, 46.00126443590437, 45.37869194575718, 47.23443419592721, 48.424153396061485, 46.34598888669695, 47.00291327067784, 42.81101294926235, 42.438123975481304, 43.360830851963584, 45.7887225151062, 50.81466722488403, 57.55350964409964, 59.57712732042585, 58.91165665217808, 59.855298451014924, 58.751201902117046, 57.71815068381173, 57.76209109170096, 54.035053048815044, 54.95798921585083, 52.77364928381783, 55.85324723379952, 55.586624009268625, 59.12205505371094, 59.13924489702497, 66.16268553052629, 60.18815885271345, 77.75697081429618, 33.19952814919608, 0.161968643111842, 0.12476893780486924, 31.223269394465856, 68.78308745792934, 43.9224294253758, 45.93573944909232, 31.936105932508195, 18.670764991215297, 15.307567630495344, 38.6867880821228, 3.059747598000935, 0.30926893332174843, 5.607794676508222, 14.64644479751587, 17.36151419367109, 10.889678886958531, 8.475178139550344, 12.049193399293081, 7.592049939291818, 0.2539561970957688, 0.017554499907419086, 0.13227751132633003, 0.03186719698299255, 0.210835853059377, 11.03131878376007, 53.542839186532156, 60.95237731933594, 37.083692755017964, 32.76122883387974, 33.50010027204241, 64.70714214869908, 61.63822705405099, 77.45121533530099, 75.70548043932233, 43.67782851627895, 0.4146526413304465, 0.4808877014688083, 0.46740890187876566, 0.08540715529982533, 0.7318794876337051, 18.83106688090733, 34.48568834577288, 66.41387680598667, 72.71514252253941, 70.9201796395438, 73.0683125087193, 72.12611593518938, 69.26919732775006, 67.3893552507673, 66.97780650002616, 64.79918493543352, 63.73088550567627, 64.48742621285575, 58.769989831107004, 54.9182003566197, 53.352152824401855, 52.979739802224294, 50.2201897757394, 51.07933453151158, 51.15708139964512, 48.275555746895925, 50.87480388368879, 49.50980595179966, 49.656093324933735, 46.571913037981304, 47.92570005144392, 46.98658847808838, 45.277644293648855, 45.82323769160679, 48.09791810171944, 51.09602757862636, 54.694965158190044, 59.358745438711985, 57.82374593189785, 60.061111041477744, 57.91561501366751, 56.682094369615825, 56.89290966306414, 55.71023941040039, 57.66757822036743, 57.41139119012015, 57.68001896994454, 55.86860622678484, 55.59283569880894, 55.06810079302107, 57.00505358832223, 55.540154457092285, 59.12967027936663, 53.93116358348301, 54.95797879355294, 45.7818820135934, 42.613555567605154, 45.91985239301409, 51.5442384992327, 52.44943591526577, 56.76371485846383, 55.02137415749686, 52.598408767155235, 45.10941798346383, 44.32528945377895, 46.7237138066973, 42.39991930552891, 42.547116892678396, 50.26343536376953, 56.04436091014317, 53.51143332890102, 35.112513133457725, 38.713285037449424, 53.754509108407156, 53.23316144943237, 50.46294593811035, 37.97250631877354, 42.751769133976524, 45.43206453323364, 45.160233633858816, 40.99374982288906, 46.769700459071565, 51.43818467003958, 58.320531708853586, 54.23929534639631, 57.22576311656407, 50.98379332678658, 33.67224189213344, 46.40724767957415, 49.792548997061594, 52.05387149538313, 49.226142270224436, 49.31214359828404, 50.32081706183297, 50.40543222427368, 52.47774635042463, 52.937345368521555, 52.923633098602295, 52.135717800685335, 52.8766632761274, 51.77591923304966, 50.55487755366734, 49.63063512529646, 47.974712644304546, 50.364351000104634, 47.071863719395225, 44.480091844286235, 45.34290177481515, 42.76058292388916, 42.60538796016148, 42.437276295253206, 48.61156368255615, 47.48747369221279, 48.134587219783235, 49.698522499629426, 50.90823514120919, 49.66483415876116, 48.246588706970215, 45.92142268589565, 46.592493602207725, 46.348212310246055, 49.23063428061349, 53.80438675199236, 61.49605996268136, 63.10158021109444, 63.698604175022666, 63.251640456063406, 64.02475956508091, 62.58983843667166, 64.15599714006696, 57.55248131070818, 61.12258734021868, 58.750652994428364, 62.20096860613142, 61.17938191550118, 69.75678716387067, 66.4306914465768, 72.44711576189313, 66.67255823952812, 81.98184381212506, 37.646979740687776, 0.018973740715799586, 0.06839764623769692, 34.65008619853428, 78.70157146453857, 55.06825017929077, 57.210393701280864, 44.12193652561733, 25.042254413877213, 21.07317761012486, 49.29894202096121, 3.403710352522986, 0.3888591096869537, 6.070480866091592, 20.999603135245188, 23.207466193607875, 11.668122921671186, 10.43840902192252, 17.242804220744542, 9.211160864148821, 0.11354689818939992, 0.1798393013221877, 0.2085153175784009, 0.19004395231604576, 0.4196083354098456, 17.458806344441005, 69.02995695386613, 70.44515214647565, 48.55958420889718, 44.86907284600394, 44.402879987444194, 73.12279333387102, 66.38932882036481, 84.1624664579119, 78.41960661751884, 60.5331369127546, 0.9916127047368458, 1.352148215685572, 0.6743799416082246, 0.19612159047807964, 9.24412659236363, 55.163575989859446, 60.33389731815883, 71.607300894601, 73.76426492418561, 73.77194963182721, 74.22713306971959, 73.12653841291154, 69.17106097085136, 67.53789384024483, 69.17722402300153, 67.07512296949113, 69.00561046600342, 68.64818818228585, 61.5119365964617, 56.657494272504536, 56.44359745298113, 56.25597524642944, 53.536012581416536, 54.55180100032261, 54.76295675550188, 50.62366124561855, 55.7193728174482, 49.077447346278596, 54.125761781420024, 50.30031292779105, 51.83449602127075, 50.06383793694632, 50.22953510284424, 49.4429086957659, 51.591930934361045, 53.58110291617257, 57.00988258634295, 60.95470496586391, 60.31768022264753, 62.087608746119905, 60.3642053604126, 61.023985454014365, 58.4908390045166, 57.5101945740836, 60.672413553510395, 58.18880775996617, 59.039705004010884, 58.19465814317976, 60.197636195591514, 58.52198083060128, 59.516066551208496, 57.82305458613804, 62.20913968767439, 57.45629044941494, 58.00320053100586, 48.66856322969709, 44.23169721875872, 48.10861137935093, 52.46184887204851, 54.895934854234966, 58.235155718667166, 57.53057711465018, 49.017001492636545, 45.72776249476841, 46.22668831689017, 47.752307755606516, 44.82917628969465, 42.94230958393642, 51.21784687042236, 58.12482527324131, 53.64927864074707, 32.56029387882778, 36.65702819824219, 54.17702211652483, 54.08406216757638, 51.95855263301304, 39.88847208023071, 47.422410760607036, 46.92601408277239, 45.298183168683735, 41.70608956473214, 48.442857946668354, 53.785515444619314, 60.675644465855186, 57.43281943457467, 54.278299059186665, 51.672974722726, 39.83028786523001, 49.413191250392366, 54.08680323192051, 53.08693661008562, 53.59639590127127, 53.35551922661917, 56.264490263802664, 56.05549192428589, 58.57263319832938, 56.63901553835188, 57.70812790734427, 55.60218450001308, 55.49180541719709, 56.438115324292866, 52.91959272112165, 53.82650981630598, 50.99258974620274, 57.45143713269915, 50.42384147644043, 47.97929845537458, 47.84530939374651, 45.5180206980024, 44.220100675310405, 45.48317200796944, 51.84913240160261, 50.55616644450596, 49.88888924462454, 52.896809577941895, 55.76168039866856, 52.67248003823416, 51.60208920070103, 50.33371639251709, 49.47853905814034, 49.627553599221365, 52.135127203805105, 57.33893190111433, 63.861970220293315, 64.21160357339042, 64.87301649366105, 66.05656569344657, 66.43560382298061, 65.17998095921108, 66.08315644945417, 61.625379834856304, 64.80939878736223, 62.75603934696743, 67.84973594120571, 66.14917128426688, 73.83586611066545, 70.25457000732422, 75.92345932551792, 69.67447880336216, 83.58773926326207, 38.688264574323384, 0.2521040950502668, 0.2216574823749917, 38.45692082813808, 86.77712917327881, 62.005064146859304, 71.49315588814872, 55.9793188231332, 43.24460138593401, 35.216822964804514, 76.37196554456438, 6.8575067945889066, 0.5311560183763504, 7.849509358406067, 20.90104988643101, 28.29822369984218, 26.358442987714493, 24.80779266357422, 27.937798057283672], [1.2911770130906786, 0.02135429940452533, 0.04079447527016912, 0.03513338975608349, 0.0600318115736757, 0.16354479853596005, 9.241805025509425, 42.953159196036204, 56.38953351974487, 24.756619180951798, 23.199566091809952, 53.46089908054897, 45.56949642726353, 55.66321052823748, 69.87612247467041, 66.17403193882534, 66.25046212332589, 6.8728870664324075, 0.600448340177536, 0.39834312934960636, 0.20525061418967588, 5.281388717038291, 16.15154446874346, 20.48989544595991, 49.803902353559224, 63.15696430206299, 65.7471902029855, 66.13036945887974, 63.958105495997835, 65.63879830496651, 62.426569666181294, 63.00387464250837, 63.115156991141184, 61.94168267931257, 59.17629964011056, 57.55078942435128, 57.38355670656477, 50.58079086031233, 49.66152681623186, 45.636362416403635, 46.282089778355186, 46.26145710263933, 46.960935728890554, 44.64056396484375, 45.173157283238, 44.96501357214791, 46.16450193950108, 44.21391677856445, 45.477248668670654, 41.255693435668945, 42.593207768031526, 46.258326939174104, 52.50553914478847, 58.38318361554827, 56.506773948669434, 57.415914467402864, 55.6411326272147, 54.60367972510201, 55.85150671005249, 55.645371028355186, 53.7970564024789, 55.07106767381941, 54.07141644614083, 54.50425100326538, 51.4568510055542, 53.58102996008736, 53.15759631565639, 52.504983288901194, 50.24881287983486, 53.09335674558367, 55.67516490391323, 54.55225958142962, 43.94426761354719, 36.90575286320278, 46.673075335366384, 47.84411082948957, 52.94521420342581, 56.29662568228585, 54.18818439756121, 46.181434699467246, 42.27178757531302, 42.71230336597988, 40.05086537769863, 39.963377135140554, 41.763071741376606, 46.64357328414917, 50.909732478005544, 55.7159994670323, 50.54569203513009, 49.65154572895595, 53.10471705027989, 51.79017693655831, 46.32923330579485, 39.86800963538033, 40.49923958097185, 39.24759456089565, 38.41657958711897, 40.99508040291922, 39.36938258579799, 41.007767813546316, 51.81374870027815, 49.72764239992414, 56.68534960065569, 40.936256953648154, 36.47191081728254, 42.742364747183665, 45.564997468675884, 45.95759153366089, 43.527483395167756, 45.36442034585135, 43.59204953057425, 47.91569464547293, 47.74775321143014, 50.58770431791033, 55.10468305860247, 51.388588428497314, 50.93654210226876, 48.48518637248448, 47.60662487574986, 47.41583776473999, 50.35295942851475, 48.9582371030535, 49.012353147779194, 46.889153889247346, 41.20829977308001, 44.29114948000227, 40.20768274579729, 42.36643941061837, 42.40311895098005, 43.991365977696006, 43.62518548965454, 46.74832085200718, 47.28830010550362, 48.08556073052542, 48.518447399139404, 44.77550492967878, 43.80660990306309, 44.25156211853027, 45.37292494092669, 52.55191837038313, 55.914641516549246, 60.904830796378, 61.332589694431846, 62.06785501752581, 61.92722347804478, 57.70757205145699, 59.22089317866734, 55.39215087890625, 53.00433642523629, 55.395534651620046, 57.57274573189871, 59.12452861240932, 60.63408729008266, 62.857420512608115, 65.18640109470913, 65.65927464621407, 74.49726513453892, 60.99193341391427, 0.6571434693677085, 0.12414532341063023, 31.327391624450684, 63.57245962960379, 47.7819869858878, 44.32499415533883, 33.43052448545183, 22.522757700511388, 15.764210190091815, 35.06147861480713, 3.962048266615186, 0.6258662619761058, 2.870724678039551, 12.728258218084063, 9.065794127328054, 17.654130629130773, 9.458147610936846, 11.063106792313711, 3.251151578766959, 0.0911934237395014, 0.06088621608380761, 0.04554849177865045, 0.1131292191733207, 0.22279054086123193, 17.084946359906876, 58.48865032196045, 65.1297732761928, 36.322336946214946, 25.58047751017979, 48.09742825371878, 53.74097401755196, 64.03134645734514, 79.19886793409074, 71.63018131256104, 76.44455337524414, 7.070370069571903, 0.6163651432309831, 0.33822308108210564, 0.11543703212269715, 7.313957844461713, 30.440259524754115, 42.00080435616629, 66.08565085274833, 72.41985103062221, 72.57867295401437, 72.45623874664307, 69.27374144962856, 69.2950029373169, 66.39482484545026, 66.93433162144252, 63.43205043247768, 65.15018013545445, 62.37484727587019, 60.446499824523926, 58.707810401916504, 56.820978437151226, 52.7422399520874, 50.316297258649556, 48.82029799052647, 49.12755080631801, 50.10007626669747, 48.1542957850865, 47.4541049684797, 48.505336148398264, 49.56826114654541, 46.97106620243618, 47.14750180925642, 44.23912484305245, 46.18840374265398, 47.3379693031311, 56.32017312731062, 60.297565187726704, 58.044247014181956, 58.28448098046439, 57.187388215746196, 58.00127240589687, 58.54882866995675, 57.159765652247835, 56.40168939317976, 55.03072990689959, 56.157953534807476, 58.51596369062151, 53.96147509983608, 55.05449969427926, 55.437279428754536, 53.32000698362078, 53.67132527487618, 54.201792444501606, 58.2731727872576, 57.345796721322195, 49.31200810841152, 40.252766132354736, 47.29509196962629, 51.58660166604178, 55.5417560168675, 57.986354623522075, 56.252890246255056, 46.823809555598665, 44.662152017865864, 44.119831221444265, 41.92364113671439, 40.2888377053397, 45.3341018812997, 46.911339487348286, 54.26981183460781, 56.43358857291085, 54.02085093089512, 53.09972129549299, 54.03880855015346, 52.42125054768154, 47.00023474012102, 42.145069803510395, 42.776751382010325, 41.54381786073957, 41.8848945072719, 44.26475327355521, 42.05040059770857, 41.59740931647164, 52.79663739885603, 48.59471082687378, 61.122455324445454, 46.5331038747515, 43.05655186516898, 45.07215132032122, 46.65462439400809, 48.02579927444458, 45.93697622844151, 50.54805094855172, 45.88925947461809, 50.901870591299875, 50.85464368547712, 51.017582416534424, 54.90895925249372, 52.91338797977993, 52.577237606048584, 52.793031283787315, 50.080176625932964, 50.47792625427246, 53.82840667452131, 52.32003961290632, 50.68794250488281, 48.032473019191194, 43.856727259499685, 45.15598828451974, 41.09854602813721, 43.8792359488351, 44.5155485016959, 46.384454114096506, 45.13398681368147, 49.75739458629063, 50.82399518149239, 51.543088572365896, 49.79160056795393, 47.12711926868984, 47.47903510502407, 46.370766162872314, 49.65024641581944, 56.761981282915386, 60.74789183480399, 63.89509923117501, 63.91634682246617, 66.95131301879883, 65.11964280264718, 62.34594276973179, 62.69782733917236, 59.03869751521519, 59.22494397844587, 60.517656326293945, 62.448331424168174, 64.48152024405343, 67.87962014334542, 70.03306143624442, 71.18882478986467, 71.61146286555699, 78.43901293618339, 66.57581847054618, 1.0713243931531906, 0.10651621009622302, 36.294509410858154, 72.09971278054374, 57.75058487483433, 56.54747302191598, 46.16319567816598, 28.80111173221043, 19.291765451431274, 45.93882097516741, 6.400598466396332, 0.8803468580756868, 4.547103958470481, 17.630466801779612, 17.693341050829204, 13.579454234668187, 10.267444252967834, 12.80978056362697, 1.7542555587632316, 0.10301087104848453, 0.11585798167756625, 0.0903189345928175, 0.20661202685109206, 0.23913047835230827, 27.0522449357169, 72.93140520368303, 76.87907981872559, 44.42030954360962, 33.04164770671299, 68.88569845472063, 63.31263869149344, 69.01390661512102, 84.12634972163609, 73.9305978502546, 86.72517054421562, 8.458310518945966, 0.6101995940719331, 1.1281034435544695, 0.34333470250879017, 21.0951669216156, 49.90500211715698, 58.091161251068115, 71.3172274998256, 73.25627517700195, 75.44806357792446, 72.00575229099819, 70.77790137699672, 71.39421354021344, 68.41403388977051, 70.20017256055559, 65.98916121891567, 69.02480139051164, 63.594381196158274, 63.211611883980886, 62.224710600716726, 58.739674840654644, 55.9944554737636, 51.62572002410889, 51.252216134752544, 52.620319911411826, 55.243254457201274, 51.46985803331648, 49.61233009610857, 52.81642239434378, 52.83238935470581, 50.69452244894845, 51.083833490099224, 46.41783326012747, 48.52548592431204, 50.73039599827358, 59.09183733803885, 61.920101574489046, 61.55650929042271, 60.30729266575405, 60.8115998676845, 60.218355723789756, 62.75752626146589, 60.37218884059361, 59.40439510345459, 59.94496495383126, 59.50089168548584, 59.88268824986049, 57.28904730933053, 58.78217697143555, 59.44013663700649, 55.14652511051723, 54.046597480773926, 59.418840408325195, 61.45826176234654, 57.31297690527779, 51.55213860103062, 43.22258949279785, 47.69844879422869, 52.980330399104524, 56.328580447605674, 61.933824266706196, 54.59530019760132, 47.29324722290039, 45.52178314753941, 44.72959123338972, 44.81677375520979, 43.82335506166731, 45.81482342311314, 49.53528847013201, 56.93996286392212, 59.307988848005024, 53.47353090558733, 53.848045757838655, 58.20411811556135, 55.10098314285278, 51.27470745359148, 44.28967646190098, 44.99171897343227, 43.38319362912859, 42.37474945613316, 43.59810835974557, 41.97258077348982, 43.96181181498936, 54.838369028908865, 50.22998326165335, 54.54993193490164, 48.926959787096294, 45.75351251874651, 46.95322322845459, 49.4592821257455, 53.863248416355674, 51.53172826766968, 49.830913475581575, 50.01009362084525, 53.5547206061227, 54.247230189187185, 54.410655294145855, 59.969658851623535, 56.077166829790386, 56.505686555589946, 56.33811685017177, 52.81654051371983, 54.02176809310913, 55.39274147578648, 55.173206193106516, 55.207898548671174, 52.81634596415928, 45.291731766292024, 48.064622334071565, 43.515657561165945, 47.3300587790353, 47.22496032714844, 50.02407339641026, 47.456453459603445, 52.73503119604928, 52.644520487104145, 55.24986219406128, 54.81196934836251, 51.49392311913626, 49.911488260541645, 50.16086605616978, 52.670082909720286, 58.655629430498394, 64.05441447666713, 65.75260979788644, 65.64940125601632, 70.46090371268136, 66.83131762913295, 63.18468761444092, 66.4170868737357, 61.159107072012766, 61.23585687364851, 61.897367068699424, 65.5053789956229, 67.78082370758057, 68.83426094055176, 75.10448210580009, 72.08163356781006, 74.06977721623012, 82.44203690120152, 66.89072472708565, 0.942334560411317, 0.1824553795158863, 39.7436021396092, 80.20081206730434, 64.82146780831474, 70.4264475958688, 57.476311683654785, 49.786299092429026, 35.88868250165667, 73.29126630510602, 10.254913176809039, 1.0395675429276057, 4.710157769066947, 18.201240471431188, 18.458857093538555, 28.09114827428545, 22.448929616383143, 18.520529304231914], [0.09678520368678228, 0.07592271494546107, 0.015722850603716712, 0.08578197125877653, 0.07194035220891237, 0.16397192275949887, 9.260138716016497, 54.36279262815203, 58.47864491598946, 24.905798741749354, 29.495054381234304, 43.20304421016148, 47.49105896268572, 56.73118339266096, 67.94129930223737, 65.33481461661202, 43.791563579014365, 1.7689448105437415, 0.32582912327987806, 0.4340884084148066, 0.557571006672723, 13.831059796469551, 16.154791014535085, 22.821705681937082, 51.24897132601057, 65.9713112967355, 65.02129799979073, 68.07986027853829, 66.46451527731759, 63.07537855420794, 61.94477462768555, 64.28609521048409, 59.717015402657644, 61.315712520054404, 60.03375598362514, 60.11810711451939, 58.816723414829795, 55.071279593876426, 49.23125614438738, 46.064795289720806, 46.121631554194856, 45.45206144877842, 46.20229319163731, 47.14099482127598, 44.846355710710796, 43.807617391858784, 44.97939286913191, 43.93893139702933, 43.05217797415597, 42.638579504830496, 44.09506089346749, 47.397094999040874, 54.90215696607317, 57.95320129394531, 56.358363900865825, 55.94252116339547, 54.78009448732649, 55.53300476074219, 55.86526761736189, 52.07286787033081, 51.937735830034526, 51.85771690096174, 48.721192359924316, 51.485960483551025, 49.035084179469514, 48.354146821158274, 48.49974284853254, 46.60669572012765, 47.030584471566335, 53.32282795224871, 51.30026640210833, 56.35902050563267, 49.23741224833897, 44.17324897221157, 44.524588108062744, 54.93314593178885, 54.68467140197754, 57.15989419392177, 47.645440987178254, 41.18521785736084, 45.27802644457136, 41.123111384255544, 41.22688273021153, 37.085502760750906, 40.89749295370919, 40.49194049835205, 47.6672340120588, 46.16841377530779, 48.4098470551627, 48.24374341964722, 46.97150393894741, 46.73037365504673, 42.728704588753835, 41.96299920763288, 40.08533539090838, 41.42857503890991, 40.576958656311035, 41.03278480257307, 41.49570505959647, 43.42258644104004, 47.11671086720058, 46.41620738165719, 46.8593704359872, 32.63241270610264, 48.94851657322475, 54.5851662499564, 47.840862546648296, 45.27931186131069, 44.989492075783865, 49.89259958267212, 50.03037888663155, 51.74926594325474, 50.83972937720162, 47.80770921707153, 46.24241556440081, 46.15955482210432, 49.771471636635916, 48.65387126377651, 49.51555558613369, 49.819921425410676, 50.871899536677766, 51.64427866254534, 50.562781129564556, 49.29451254435948, 42.42615570340838, 41.99339062826974, 41.95320919581822, 43.09578486851284, 42.992392199380056, 44.731550625392366, 41.85601084572928, 45.89877503258841, 48.390454632895334, 47.7243412562779, 46.99146611349923, 44.29217781339373, 41.47481182643345, 43.52633694240025, 46.2696281841823, 55.83523402895246, 57.01112978799002, 61.17217663356236, 60.80141380855015, 61.52556896209717, 59.9196526663644, 59.7433351789202, 56.895254680088584, 55.68521547317505, 52.14447947910854, 53.51291676930019, 56.684863226754324, 59.228306906563894, 62.31259836469378, 66.39076709747314, 63.361067635672434, 66.87305545806885, 67.76045853751046, 73.73470033918107, 7.096772355692727, 0.4801122716494969, 39.812222548893516, 62.54248646327427, 51.38849810191563, 43.3432970728193, 31.291549342019216, 14.148765308516365, 18.63130964551653, 34.32247863497053, 4.614304763930185, 0.2378804539995534, 0.14728453462677343, 6.836318697248187, 5.3594096047537665, 9.727284346308027, 7.145193483148303, 1.6043230955089842, 0.3861234736229692, 0.02682347994829927, 0.024318097957542965, 0.10701873313103404, 0.025943584573854293, 0.10583451988973788, 19.10541476522173, 67.85282788957868, 65.58321966443742, 33.16017007827759, 32.92614780153547, 44.80282872063773, 52.59821769169399, 65.19094521658761, 74.51382269178117, 73.84776142665318, 55.83298281260899, 2.0681078604289462, 0.5731525591441563, 0.5649552047252655, 0.7672525495290756, 19.721014738082886, 28.401055301938737, 40.341654436928884, 63.34736578805106, 75.44460337502616, 72.32161739894322, 72.18587044307164, 70.72172519138881, 67.57664394378662, 65.3247675214495, 66.91293116978237, 63.023968832833425, 65.06587069375175, 62.40332099369594, 61.15083176749093, 59.90208762032645, 59.22356823512486, 51.7675153868539, 50.238776206970215, 50.23539243425642, 49.96557651247297, 49.43275737762451, 48.686305454799104, 47.55968632016863, 48.470014980861116, 49.19170004980904, 46.16555111748831, 45.096536023276194, 44.47574574606759, 46.74038600921631, 48.87421253749302, 58.0511292048863, 59.23282323564802, 59.37397589002337, 58.39801107134138, 58.0457512991769, 56.15215526308332, 58.24371937343052, 53.4935417175293, 54.64955868039812, 54.36790997641427, 52.586635044642854, 52.83702727726528, 50.98520033700125, 50.60765259606497, 50.49243409293038, 49.030119691576274, 49.335044860839844, 53.8304876599993, 55.808070046561106, 57.51277582986014, 54.7072947365897, 47.88570622035435, 45.29762036459786, 57.54091256005423, 56.51429189954485, 58.72627176557268, 49.501120703560964, 43.2453031539917, 48.96730102811541, 44.10521568570818, 42.93813024248396, 40.15213884626116, 42.95673404421125, 43.49161679404122, 49.81568997246878, 48.593960421425955, 50.425449984414236, 50.094674042293, 49.31475264685494, 48.17854152406965, 44.56898362295968, 41.94905764716012, 43.94052948270525, 42.67899022783552, 43.13592113767351, 44.609679222106934, 44.32127339499337, 42.91477387292044, 48.48335552215576, 45.579814502171104, 57.51105267660958, 38.063433919634136, 48.4016238621303, 58.96856239863804, 51.02575697217669, 49.40490204947335, 48.41927228655134, 51.62500088555472, 51.16659000941685, 51.70846264702933, 52.692324093409944, 50.93532964161464, 49.73303420203072, 50.201269830976216, 53.631668431418284, 52.368937560490195, 50.70854391370501, 52.582966395786826, 53.35985490253994, 53.024632113320486, 51.42270755767822, 51.517515727451865, 44.09608575275966, 43.28499821254185, 43.668705531529014, 44.32285063607352, 45.92318752833775, 47.15062502452305, 44.09672498703003, 49.149906635284424, 50.26299067905971, 51.4101174218314, 49.03034898212978, 49.42488506862095, 46.104671001434326, 45.74639408929007, 50.0052090372358, 59.81078829084124, 62.23254816872733, 65.89735467093331, 63.478401865277974, 64.0902463368007, 65.03283895765031, 63.274750164576936, 59.55323246547154, 60.330819266183035, 58.47681753976004, 57.23463944026402, 61.42944758278983, 67.08965165274483, 69.2069901057652, 73.28809792654855, 67.56945950644356, 73.87445640563965, 70.54132216317313, 80.23263481685093, 9.05788447175707, 0.524127969784396, 44.28278732299805, 70.37405123029436, 61.84306689671108, 55.40323672975813, 43.58449336460659, 20.912311179297312, 21.92778171811785, 43.17953150612967, 5.185694217681885, 0.6809176536543029, 2.110559182507651, 11.49244293144771, 9.246145912579127, 15.65963806424822, 9.193700909614563, 6.029518195561, 0.2110112543616976, 0.14307548691119465, 0.10640107627425875, 0.22658748711858476, 0.15744943703923905, 0.14645274568881306, 31.110468864440918, 82.56832735879081, 73.78827789851597, 40.086464473179404, 40.79490974971226, 55.39192853655134, 61.90787969316755, 72.07509531293596, 79.06174523489815, 74.49963447025844, 63.29000146048409, 2.046159152473722, 0.6256069530333791, 0.8623009749821254, 1.8198538273572922, 33.39498444965908, 50.89015940257481, 59.24448926108224, 70.13651316506522, 75.85924407414028, 70.57089369637626, 71.50737190246582, 70.60895592825753, 71.39121191842216, 67.91642475128174, 70.79783575875419, 65.53499916621617, 67.50104059491838, 64.67926597595215, 66.5491999217442, 62.781170981270925, 63.880285671779085, 54.336104597364155, 52.5008282661438, 51.4430136680603, 52.836481843675884, 51.62279830660139, 52.30457639694214, 49.186787673405235, 51.00724349703108, 52.206995895930696, 48.51359755652291, 48.13700866699219, 46.655652727399556, 49.55334683826992, 52.21909965787615, 58.851881299700054, 61.840294565473286, 62.42128903525216, 59.981811250959126, 60.64466939653669, 58.37450531550816, 60.51643344334194, 57.04000997543335, 56.58281850814819, 56.761963912418906, 53.61802216938564, 57.4094352722168, 54.17307553972517, 54.725870745522634, 55.737194946834016, 50.82235540662493, 52.80020877293178, 55.11518178667341, 59.237089429582866, 61.85359341757638, 58.198708942958284, 48.28750664847237, 44.370859214237754, 59.16050638471331, 60.47468171800886, 58.23530510493687, 49.727308886391775, 45.11125578199114, 50.14713988985334, 46.703560556684224, 45.12144531522478, 42.50862734658377, 44.71231453759329, 45.353139945438926, 51.07341119221279, 50.784765652247835, 52.472722802843364, 52.23606021063668, 51.72342906679426, 50.14035497392927, 46.71245772497994, 45.46639905657087, 46.90649659293038, 44.728291920253206, 44.51394346782139, 44.039669854300364, 43.063486167362754, 42.324666840689524, 48.59171267918178, 48.35326092583792, 52.58079855782645, 42.98712199074881, 50.95891877583095, 62.478493554251536, 52.69939388547625, 52.40707969665527, 50.9381297656468, 55.29087393624442, 53.8177307673863, 54.59505353655134, 54.16810062953404, 55.81121063232422, 52.11314310346331, 54.700582776750835, 56.51486165182931, 56.0724698475429, 52.893748896462576, 55.467993940625874, 56.03392818995884, 57.117610931396484, 54.44792890548706, 53.64371313367571, 47.67788907459804, 48.598188400268555, 45.7392270224435, 50.32782779421125, 45.53510284423828, 49.26757090432303, 46.321614606039866, 53.1628144127982, 54.30088070460728, 54.77347980226789, 50.622514792851035, 51.5442384992327, 48.555432660239084, 49.28176259994507, 52.61498022079468, 62.77395180293492, 62.511031968253, 68.71527303968156, 65.0567546572004, 66.24684211186, 67.44938768659318, 66.27008383614677, 62.26455157143729, 63.25352341788155, 60.425669125148225, 61.219500814165386, 63.769468852451865, 69.95351151057652, 69.83471121106828, 76.87055437905448, 69.07283428737095, 76.84183052607945, 72.09833008902413, 81.2009357724871, 8.943609186581202, 0.4844528873051916, 47.60205296107701, 79.42906175340924, 68.46411650521415, 69.204836164202, 55.1508503641401, 38.82404279708862, 42.20695740836007, 70.96178545270647, 9.825787220682416, 0.9121873038155692, 1.4265848100185394, 10.100853375026158, 8.906528387750898, 15.708824362073626, 11.896551898547582, 3.8899576663970947], [0.11174450561936412, 0.052925270050764084, 0.0572598467447928, 0.037938151575092754, 0.04861588736197778, 0.2495398297905922, 23.9396847316197, 54.01145349230085, 58.55035032544817, 25.847998789378575, 23.344225849424088, 57.77575472423008, 46.73315640858242, 54.83911943435669, 70.24532195499965, 59.89072036743164, 65.31071826389858, 1.7614701773439134, 0.4474751443735191, 0.8606211394071579, 1.3151473211390632, 20.65519482748849, 24.863534586770193, 35.241023540496826, 55.907762799944194, 66.15762724195207, 64.9524621963501, 68.20292677198137, 64.56972067696708, 65.11394527980259, 64.0934841973441, 66.17802715301514, 61.82655797685896, 63.029166085379465, 60.255299295697895, 60.97921821049282, 57.552338872637065, 54.03171443939209, 48.84918165206909, 47.29389687946865, 43.57294545854841, 44.35390213557652, 46.23022494997297, 44.76181697845459, 43.958591324942454, 42.636057308741975, 42.00289576394217, 42.43227359226772, 42.19332504272461, 41.70348399026053, 43.024128096444265, 46.961658341544016, 55.663749013628276, 56.774870191301616, 57.083259037562776, 54.36716999326433, 54.93200990131923, 51.97996003287179, 51.98052978515625, 51.20404774802071, 50.45262091500418, 49.70535257884434, 48.1220874105181, 48.594526699611116, 47.21936355318342, 47.34264891488211, 45.407874379839214, 44.62104647500174, 48.461062226976665, 48.1439916065761, 48.93350151606968, 55.21690341404506, 52.12534761428833, 43.37139211382185, 52.592707770211355, 54.30392401559012, 50.318155901772634, 51.63429757526943, 38.868240288325715, 47.0209264755249, 46.658223560878206, 43.92115443093436, 38.959636892591206, 38.54410334995815, 40.646621295383994, 44.85330043520246, 49.1049622126988, 45.07186297007969, 45.96354266575405, 46.54071910040719, 43.8121337209429, 45.548036915915354, 40.252053941999165, 41.498123032706125, 37.48569815499442, 38.5622763633728, 41.55987862178257, 45.851040908268516, 42.802220003945486, 38.67368377958025, 38.31533738545009, 46.69397551672799, 36.596613611493794, 36.809673173086985, 45.66194568361555, 55.56300360815865, 55.22993128640311, 51.207865783146445, 49.192867347172324, 46.91399369921003, 45.98872293744768, 48.419386931828086, 47.74080848693848, 48.22609499522618, 50.73586770466396, 50.73186901637486, 52.23211363383702, 52.52918039049421, 51.393681458064485, 50.3717543057033, 50.49379593985421, 48.94718599319458, 51.14813559395926, 50.29322576522827, 44.545477867126465, 39.62017086574009, 40.237243856702534, 43.18889767783028, 43.84290729250227, 44.00529364177159, 45.06707566125052, 46.579083578927175, 46.934987681252615, 48.461593764168875, 47.648484298161094, 45.04758596420288, 43.86538471494402, 43.912097454071045, 47.54992062704903, 56.223106792994905, 57.93456275122506, 60.28744166237967, 63.16146673474993, 61.88855675288609, 58.110650948115754, 55.32420097078596, 55.06359141213553, 53.19149310248238, 53.10627344676426, 50.98654481342861, 53.52256434304373, 56.44805472237723, 59.38414805276053, 60.82637173788888, 60.10849775586809, 69.98706436157227, 65.23801231384277, 80.91676834651402, 14.428956627845764, 0.39511943661740845, 42.86529575075422, 62.68015807015555, 49.195757797786165, 35.564476081303184, 34.212103026253835, 16.358868292399816, 14.588548932756696, 18.432309763772146, 1.6989199966192245, 0.23668704660875456, 0.5987365863152913, 3.3277402690478732, 2.9814027505261556, 1.9954974481037684, 1.7896535907472884, 0.24536301248839923, 0.15586152938859804, 0.05253181473485061, 0.037965920620730946, 0.05040082122598376, 0.1359798155192818, 0.18372803979686328, 31.87832123892648, 65.50781086512974, 67.21248885563442, 34.966170174734934, 20.681128978729248, 54.96787997654506, 56.59065955025809, 61.919448443821494, 78.92793682643345, 67.44657366616386, 70.24392536708287, 1.8358727906431471, 0.5935372710227966, 1.392233676144055, 1.4988926500082016, 29.908020564488, 32.3407655443464, 48.51881217956543, 65.491788319179, 73.96424102783203, 69.73434448242188, 72.21834632328579, 68.18156106131417, 69.59606838226318, 66.86802496228898, 68.88127940041679, 64.19159276144845, 67.04069464547294, 63.83393423897879, 62.23377105167934, 59.67858491625105, 58.24983031409127, 50.316894803728374, 48.78659922736031, 46.379805769239155, 48.61657680783953, 49.51196684156145, 47.6367974281311, 47.93283585139683, 47.43433386938912, 43.88770580291748, 46.47818531308855, 46.20220981325422, 43.79191098894392, 45.71331024169922, 48.32963357652937, 59.173701013837544, 59.333808353969026, 59.129948207310264, 57.53405816214425, 58.12344258172171, 55.683249132973806, 54.09155232565743, 52.375541823250906, 51.432303019932334, 51.21409484318325, 50.13517509187971, 52.46963432856968, 50.70019217899868, 47.93367658342634, 47.23364904948643, 45.49995190756661, 51.658553736550466, 50.875672408512656, 52.69726078850882, 56.665630613054546, 53.23450592585972, 47.04719761439732, 53.950014046260286, 52.08357504435948, 52.571064131600515, 54.02949101584298, 39.80122355052403, 48.952369349343435, 48.35611663545881, 46.30720404216221, 41.665261949811665, 39.755924769810264, 42.13979264668056, 45.61305121013096, 48.77908822468349, 47.448393549237935, 49.31478043964931, 48.2957889011928, 45.46442229407174, 46.641339438302175, 42.87720496313912, 42.52112715584891, 40.02054691314697, 39.64040054593767, 43.13444464547293, 47.97364262172154, 43.42287131718227, 36.73508426121303, 37.624384198869976, 44.01971115384783, 46.6487010547093, 43.8311196735927, 47.867891039167134, 55.42081567219326, 54.810729094914024, 54.94134828022548, 52.059176445007324, 50.73181690488543, 47.73989132472447, 51.9310690334865, 51.127089500427246, 53.31800242832729, 53.08863197054182, 52.285809312547954, 54.20013182503836, 53.92094278335571, 52.91906813212803, 53.790479932512554, 53.06741564614432, 50.41803625651768, 53.08853122166225, 50.98347718375069, 46.69229057856968, 41.413115297045024, 43.18194253104073, 44.09408119746617, 46.49378054482596, 46.85569483893258, 46.23809378487723, 49.39198187419346, 50.44386271068028, 53.05960239682879, 51.526141916002544, 49.01148809705462, 48.84382111685616, 46.936557974134175, 51.48929909297398, 59.539544514247346, 60.645864486694336, 64.98980876377651, 66.38251263754708, 64.7724552154541, 62.545731272016255, 60.4350700378418, 58.52594130379813, 60.08951527731759, 56.25630528586251, 56.08003296170916, 58.173712798527305, 61.440620286124094, 63.6209511075701, 66.67292649405343, 65.43331922803605, 74.26227010999406, 69.15041787283761, 84.57270894731793, 15.932544197354998, 0.3850472628005913, 47.94729505266462, 69.45335933140346, 60.86726188659668, 46.84809350967407, 49.415293080466135, 22.32364664758955, 19.14317648751395, 23.267331872667583, 4.388117449624198, 0.28312812745571136, 1.2193238458463123, 7.16504578930991, 6.234201269490378, 7.891317537852696, 4.710532537528446, 1.1613074732678277, 0.2197396709982838, 0.2116503936371633, 0.16852756616260323, 0.21324176181639942, 0.32155636112604824, 0.2956586607864925, 41.514722279139924, 78.82826491764614, 76.46074267796108, 39.64856815338135, 35.22668940680367, 68.01426233564104, 62.976033210754395, 69.34513419015067, 83.24096856798444, 69.55115522657121, 80.23970808301652, 3.018240362405777, 1.0326556052480425, 6.213241594178336, 1.8634161012513297, 41.51011562347412, 57.67682974679129, 65.23644896915981, 71.22250270843506, 74.54515211922782, 71.24955899374825, 71.73718357086182, 69.42098767416817, 70.35761874062675, 70.86900615692139, 73.5037978036063, 66.54426670074463, 69.43375846317836, 65.29803085327148, 67.19115788596017, 64.00803525107247, 59.745169503348215, 52.013061250959126, 53.252390589032856, 50.57046931130545, 50.68256459917341, 52.14543833051409, 50.876916136060444, 49.243418966020855, 50.07848126547677, 46.94433648245675, 49.86838163648333, 47.36032165799822, 46.86156259264265, 48.122532095227925, 50.43168599264962, 60.422118595668245, 61.949360438755576, 61.158752713884624, 58.40925325666155, 61.16106646401541, 59.026489530290874, 58.03028113501412, 56.33866228376116, 54.048080921173096, 55.15505402428763, 52.78455448150635, 56.697880676814485, 54.23605401175362, 53.86871664864676, 49.08038296018328, 49.11737169538225, 54.19126244953701, 53.389506340026855, 55.21900871821812, 58.305634771074565, 56.93649223872593, 49.83663879122053, 53.460798331669395, 56.27673298971993, 53.55498463766915, 54.61763865607125, 42.16866588592529, 49.245614596775596, 51.00359569277082, 49.44374247959682, 44.96060841424124, 42.55442987169538, 44.77463640485491, 48.86939396177019, 53.02525050299508, 50.3078030858721, 49.45630134854998, 50.0000638961792, 47.255699157714844, 48.6431884084429, 44.01920740944998, 44.56922333581107, 39.98325940540859, 41.64637674604143, 44.62635489872524, 48.40182188579014, 44.11631195885794, 39.61843034199306, 37.96061447688511, 45.69370242527553, 43.99358940124512, 43.51479945863996, 51.93225370134626, 56.82994161333357, 58.84753867558071, 57.41428164073399, 55.826830182756694, 53.332197598048616, 50.75967223303658, 54.74054881504604, 54.0321660723005, 55.82360274451119, 56.20626435961042, 53.92797088623047, 57.26751136779785, 55.903465339115684, 55.60007224764143, 55.06713499341692, 56.053602014269146, 53.22893694468907, 54.94574301583426, 55.23553500856672, 49.904814515795024, 43.37609951836722, 46.15447916303362, 47.562510762895855, 47.922326701028005, 49.94662530081612, 48.75913299833025, 52.891226700374055, 54.116621426173616, 55.60025984900338, 53.84341825757708, 51.07757316316877, 51.55952453613281, 50.10237264633179, 54.216463565826416, 61.250739915030344, 64.73185689108712, 69.04545838492257, 68.95416600363595, 68.18142209734235, 64.62644577026367, 62.31559303828648, 62.86357661655971, 61.57538059779576, 59.549661091395784, 58.12412003108433, 59.46726240430559, 65.15320260184151, 65.25422940935407, 69.39828096117292, 67.94632284981864, 75.6197327205113, 70.7331827708653, 86.87801701681954, 16.374109166009085, 0.3803639326776777, 53.1011699948992, 77.87296404157365, 67.8146892275129, 59.67048331669399, 63.72397204807827, 39.97569976534162, 36.96854720796858, 60.350232533046174, 10.576218724250793, 0.6649239318711417, 1.109343090227672, 6.467741514955248, 4.845260713781629, 4.356626042297908, 2.599943390914372, 0.4596193198646818], [0.07311934751591512, 0.10740066013698067, 0.02195499967118459, 0.048886941745877266, 0.08419970901949064, 0.03513384098187089, 22.612530163356237, 55.46992901393345, 60.12073353358677, 17.86041569709778, 47.06925119672503, 50.17316089357649, 40.68448550360543, 55.82086862836565, 68.64731270926339, 59.52493245261056, 66.40313489096505, 2.577984694923673, 0.13769741835338728, 0.712238070155893, 1.8832115190369743, 30.991300310407365, 43.843213013240266, 43.77804585865566, 60.316214152744834, 65.91157763344901, 64.65241813659668, 66.12081568581718, 62.45666231427874, 66.01559911455426, 61.513055256434846, 64.09576320648193, 60.43668896811349, 64.49789019993374, 60.490961347307476, 62.13034016745431, 54.189931869506836, 55.51972675323486, 45.68801532472883, 48.2073244367327, 41.93253830501011, 44.830242838178364, 45.34153297969273, 45.93068463461739, 42.525104999542236, 41.52806976863316, 42.820191519601, 41.9047246660505, 42.9703004019601, 41.766406876700266, 41.41909074783325, 45.561269760131836, 55.61996146610805, 53.609038148607524, 56.20113658905029, 53.50731652123587, 53.15239906311035, 49.75129754202706, 50.85209369659424, 47.824131284441265, 47.49064554486956, 46.17738389968872, 49.094168186187744, 45.38185337611607, 46.00914021900722, 42.26225117274693, 45.007661615099224, 42.36915268216814, 43.97602782930647, 43.30775008882795, 48.764031478336875, 49.012061323438374, 48.79669843401228, 46.35814823423113, 49.79597793306623, 47.18068640572684, 53.25203970500401, 40.60492862973894, 39.256627219063894, 45.03645495006016, 47.65450143814087, 40.89053085872105, 37.018942492348806, 39.33483266830444, 38.32975837162563, 43.444441999707905, 45.59243243081229, 45.21618052891323, 48.75731951849801, 48.30294207164219, 44.90540497643607, 45.96410894393921, 39.94218165533883, 39.93293707711356, 39.961369105747764, 39.24737221854073, 40.39201498031616, 45.66033022744315, 43.77449532917568, 35.64417539324079, 29.05158908026559, 40.46190690994263, 31.566597257341655, 38.5452880178179, 46.49381528581892, 48.70727859224592, 46.78664364133562, 49.88643305642264, 49.67594085420881, 50.65126643862043, 50.54740129198347, 52.13139602116176, 52.30628565379551, 51.15438549859183, 50.94864933831351, 49.39445195879255, 51.411705085209434, 51.92388112204415, 52.20962231499808, 53.616962569100515, 53.778383118765696, 51.55754777363369, 52.927055086408345, 51.7925705909729, 43.94932590212141, 40.577250480651855, 40.83313526426043, 45.37121220997402, 46.29657677241734, 48.33359752382551, 47.67296280179705, 48.74280820574079, 48.33219051361084, 50.403108051845, 45.55087872913906, 45.58517851148333, 43.22245747702462, 43.687368392944336, 48.44117300851004, 55.84435701370239, 57.842558179582866, 60.95883914402553, 58.20515687125069, 58.08822911126273, 55.626412868499756, 54.95814902441842, 53.64128821236746, 52.48163734163557, 52.09135702678135, 52.46246378762381, 52.62570823941912, 53.29822785513741, 51.56934928894043, 55.30659423555647, 58.717072350638254, 72.51576396397182, 63.36272130693708, 82.72992856161935, 14.881111519677297, 0.1114477144022073, 51.71538652692522, 58.881570952279226, 48.45848791939871, 35.55026354108538, 34.567406109401155, 12.277559842382159, 8.820653864315577, 4.185859731265476, 8.143541489328657, 0.05107150898714151, 0.13533603506428854, 1.3692898558718818, 1.3979291362421853, 0.7087818299021039, 0.09786919052047388, 0.008923486972759877, 0.014607016728924853, 0.03432129190436431, 0.03020777174138597, 0.01911449771640556, 0.136449416034988, 0.02133903236660574, 29.486459459577286, 65.27663734980992, 66.45878301348004, 25.206139836992534, 39.475200176239014, 55.72005374091012, 49.58899804524013, 61.843553270612446, 78.60655484880719, 66.89137785775321, 74.78965227944511, 3.086461467402322, 0.39670731712664875, 1.9662876554897852, 2.193144819566182, 39.797002519880024, 51.722696031842915, 58.73868819645473, 67.76402991158622, 73.83073139190674, 67.70195470537458, 70.54824256896973, 65.70442404065813, 68.93792806352887, 65.21901593889508, 68.4287918635777, 63.144158772059846, 67.89234229496547, 63.05185195377895, 65.62017018454415, 57.77010236467634, 58.085835456848145, 48.984518664223806, 48.67510148457119, 46.324897629874094, 49.41953148160662, 47.1977789742606, 50.02184649876186, 44.95564045224871, 47.59631027494158, 45.396239621298655, 45.438710485185894, 45.69650254930769, 44.73914153235299, 42.75103609902518, 48.635385581425254, 55.95536838259016, 58.54945400782994, 57.099354539598735, 56.71223912920271, 54.69603518077305, 53.69069685254778, 52.50039747783116, 50.60193770272391, 50.35121890476772, 47.646024635859895, 53.21929979324341, 49.70840631212507, 48.00432586669922, 46.04862335750035, 46.84814214706421, 43.09969323022025, 46.66264956338065, 46.16447067260742, 50.97283601760864, 50.94511270523071, 52.8851192338126, 50.06687082563128, 50.677085944584434, 48.36360331944057, 55.43994753701346, 41.615867206028526, 37.94705506733486, 46.23032569885254, 49.74202517100743, 43.70377656391689, 41.26762696674892, 40.54242263521467, 40.68415546417236, 45.51529353005545, 47.22940370014736, 47.10346065248762, 50.75346401759556, 50.218900884900776, 45.71688161577497, 44.94494717461722, 43.48865686144148, 40.79152945109776, 39.733707904815674, 39.83393219539097, 43.21148974554879, 47.34441375732422, 44.836058480399, 35.246047088078086, 31.26652193069458, 39.59950344903128, 38.753539425986155, 49.467404569898335, 47.78047922679356, 53.478509289877756, 49.36654451915196, 52.434271471840994, 52.454640116010395, 54.75958340508597, 54.977749892643516, 54.60532297406878, 53.518235615321565, 53.717200756073, 52.57773092814854, 52.384133270808626, 52.49697896412441, 54.96253333772932, 53.842706067221506, 56.87401056289673, 55.5309168270656, 53.85365642820086, 52.57877663203648, 54.03426442827497, 46.48641198022025, 42.16771745681763, 43.13152640206473, 45.64942850385393, 47.15405396052769, 50.09094285964966, 49.92646510260445, 52.42169870649065, 50.781979424612864, 53.31724854878017, 47.40655149732317, 49.55106088093349, 46.57523080280849, 48.338548115321565, 53.800530501774375, 60.38844762529646, 62.03537218911307, 63.80473096030099, 62.08583000728062, 64.42209230150495, 60.41337776184082, 61.04089042118618, 57.33417585917881, 58.643164362226216, 55.688453333718435, 56.99098348617554, 56.200667585645405, 59.23367786407471, 56.381800174713135, 60.7540340423584, 63.99078982216971, 77.44548307146344, 68.77980095999581, 87.03158610207694, 16.082112857273646, 0.023923692692603384, 58.8841278893607, 66.22802639007568, 59.076426233564106, 43.46712439400809, 50.575770786830354, 16.446033443723405, 15.599299907684326, 15.740603685379028, 8.929922103881836, 0.09390231195305075, 0.2473993775035654, 3.0066677033901215, 2.789148049695151, 2.358835037265505, 0.6187938100525311, 0.06945747043937445, 0.3180298517857279, 0.17352653720549174, 0.20327944281910146, 0.12802890501916409, 0.22353659011423588, 0.1276339976383107, 36.237124238695415, 78.90419483184814, 77.62762314932687, 30.330783707754954, 61.291129793439595, 64.11986650739397, 55.82328312737601, 69.84204156058175, 78.26814283643449, 68.95417295183454, 76.86705943516323, 4.328555754252842, 0.6462965171251978, 4.486451395920344, 2.2654130331107547, 52.0655722618103, 66.21408830370221, 69.24914482661656, 71.20985698699951, 73.92058549608502, 69.65867859976632, 70.07939202444894, 64.96210629599435, 70.04592255183628, 66.6448974609375, 70.34221458435059, 65.35908467429024, 70.18657493591309, 65.59879057747978, 68.45824527740479, 61.86539840698242, 61.52401951381138, 51.60209614889962, 51.919614928109304, 48.26015159061977, 51.91243396486555, 50.818724972861155, 53.262858050210134, 46.84644678660801, 48.4711058480399, 47.99261467797415, 48.28027704783848, 49.154957975660054, 47.616929054260254, 45.37296315601894, 50.62235151018415, 58.563482420785085, 60.062570163181846, 59.37382302965437, 57.38734694889614, 57.10526398250035, 55.04268775667463, 54.915580885750906, 52.99320541109358, 53.15460859026228, 50.080013343266074, 57.26207440240042, 52.18185383932931, 50.79278039932251, 50.21782738821847, 50.96650620869228, 47.48657390049526, 50.98444993155343, 48.50887972967965, 52.77014739172799, 56.10171134131295, 53.99413858141218, 52.04018007005964, 52.84232875279018, 49.45861162458147, 53.72083118983677, 42.949052810668945, 40.25981160572597, 47.634758131844656, 50.322005203792024, 45.98134742464338, 40.59100096566336, 42.94681896482195, 41.97909818376814, 46.15617452348982, 50.011215754917686, 49.82637282780239, 50.30120577130999, 51.32701349258423, 48.16221325738089, 48.1193984576634, 44.963842800685335, 43.70252241407122, 41.372280733925955, 42.77643176487514, 44.397008759634836, 49.62527111598423, 45.29438945225307, 35.73606531960623, 29.392453806740896, 38.99888379233224, 33.87090826034546, 46.90092761175973, 52.164872441973, 57.21719946180071, 52.8948849269322, 53.78759295599801, 55.0471693447658, 55.70788744517735, 57.6404698235648, 58.02744279588972, 57.90577289036342, 56.12617942265102, 55.06595727375576, 55.87176070894514, 55.59167534964425, 58.329508781433105, 58.32381125858852, 59.429610116141184, 60.0131128856114, 54.62184231621878, 57.33381455285208, 57.11972665786743, 48.59972742625645, 44.39517443520682, 45.98334503173828, 49.760351044791086, 51.65081344332014, 51.1142909186227, 53.252929074423655, 55.332848003932405, 53.097487449645996, 55.93856416429792, 49.050554343632285, 51.89435127803257, 49.37862743650164, 50.59026820319039, 56.01157236099243, 61.746994154793875, 64.06696292332241, 67.79465757097516, 63.553359031677246, 65.54706818716866, 62.5286317552839, 61.50703811645508, 59.4238292149135, 60.453864915030344, 58.44217382158552, 58.45162337166922, 57.97446972983224, 62.18749604906355, 57.299903869628906, 61.01338250296456, 63.27495166233608, 79.00793143681118, 69.02163301195417, 88.66483661106655, 17.253196988786968, 0.15449950604566506, 64.21148545401437, 72.46777275630406, 67.05633504050118, 55.09848526545933, 64.87418379102434, 33.443903241838726, 38.728095122746055, 49.53625774383545, 14.521880967276436, 0.15860184734421118, 0.3271151099886213, 2.1617558981691087, 2.4803060506071364, 1.3827472137553352, 0.26479134282895495, 0.10132919664361648], [0.05576718505471945, 0.08526676640446697, 0.03815167297476104, 0.07330262660980225, 0.050875612534582615, 0.11056066557232823, 19.17159288270133, 53.200859274183, 61.11338792528425, 30.523033414568218, 31.831563336508616, 47.32553897585188, 50.11619956152779, 49.07753767286028, 68.47016143798828, 59.349768366132466, 68.78155885423932, 4.614045075007847, 0.32793920433947016, 0.8094157927802631, 2.1683225972311835, 43.81520482472011, 52.40411976405552, 55.70679657799857, 62.378154618399485, 62.98054953983852, 64.53940568651471, 66.76673412322998, 62.753524099077495, 65.63283675057548, 63.45617457798549, 65.68286378043038, 60.74839210510254, 62.23432690756661, 62.02775696345738, 60.74033914293562, 58.11600800922939, 52.96500614711216, 46.46087735039847, 46.758871691567556, 43.62152031489781, 43.964757851191926, 45.42761073793684, 45.12479434694563, 43.58238806043352, 42.570699078696116, 39.91381910869053, 43.39098950794765, 42.54835714612688, 43.44970873423985, 41.046552658081055, 46.6441638810294, 51.672669001988, 54.32608182089669, 53.26944841657366, 53.62827771050589, 52.26869589941842, 50.00954123905727, 48.09366580418178, 47.76096868515015, 46.53137377330235, 47.89625358581543, 45.88932548250471, 45.59502758298601, 44.960000446864534, 43.90687240873064, 44.16482080732073, 42.59951325825283, 41.97661072867257, 43.19409840447562, 45.439012731824604, 48.38482659203665, 52.78310578210013, 52.90714154924665, 47.0103235244751, 50.14556264877319, 45.87623855045864, 34.65755551201956, 41.042230878557476, 39.038766452244346, 47.597505365099224, 39.67865037918091, 39.825205257960725, 38.37875706808907, 39.460751397269114, 44.074921539851594, 44.22247001102993, 42.69710070746285, 50.234635080610005, 47.21822057451521, 43.9328864642552, 41.6780674798148, 43.81209550585066, 38.99948133741106, 38.83106395176479, 39.16430997848511, 40.8311585017613, 44.92037834439959, 39.42736530303955, 40.20987490245274, 31.6209043775286, 36.86528308050973, 34.49468278884888, 43.766876629420686, 50.624675682612825, 52.226676668439595, 52.734343324388774, 45.437887123652864, 47.3310558455331, 48.79400600705828, 49.800317083086284, 51.32243462971279, 46.991525173187256, 49.24626077924456, 50.14439882550921, 46.78451749256679, 47.49974768502371, 49.42962721415928, 49.82888460159302, 52.009948457990376, 53.12141357149397, 53.47973912102835, 52.523875440870015, 53.786158152988975, 44.8993878364563, 41.5010655948094, 40.763493469783235, 45.46500941685268, 44.93790170124599, 48.07730279650007, 48.57260513305664, 49.84578262056623, 49.59298631123134, 48.923822675432476, 46.308263642447336, 44.26215117318289, 44.698115893772666, 46.39616877692086, 50.84642744064331, 59.696983746119905, 58.58046381814139, 58.200921944209504, 56.72188670294625, 59.233170645577566, 57.712376730782644, 56.305661814553396, 54.33254711968558, 52.723042079380576, 51.52278593608311, 51.5841315814427, 51.82856225967407, 54.50345890862601, 53.43308891568865, 59.67659773145403, 62.7864933013916, 71.7953747340611, 63.68210915156773, 82.94441945212228, 11.444987603596278, 0.04640059605506914, 55.3081818989345, 56.281951086861746, 46.71585886819022, 35.5682315826416, 31.260355404445104, 12.717693482126508, 4.390337399074009, 5.70632404088974, 4.339471808501652, 0.33405180062566486, 0.04865169704758695, 0.2545966255877699, 0.003324462179859568, 0.053796783821391206, 0.019591857280050005, 0.06775670205908162, 0.03338479483500123, 0.059943812367107184, 0.07401125465652772, 0.049750740573342354, 0.0865567157577191, 0.09254398662596941, 24.550163882119314, 65.6757071358817, 72.5126233782087, 28.336947747639247, 33.86416850771223, 58.03642681666783, 54.91943366186959, 55.7854015486581, 77.50380625043596, 66.37601607186454, 77.16775662558419, 6.082767452512469, 0.6313177208815302, 1.010963654943875, 2.534861134631293, 52.04177468163626, 61.1314115524292, 66.3477646963937, 70.07259668622697, 70.25557749611991, 69.9711251940046, 70.18457385471889, 65.10361330849784, 69.40593787602016, 65.97861385345459, 67.92682620457241, 64.10607433319092, 63.8183285849435, 63.61893612997872, 65.2796459197998, 60.76301111493792, 56.90937689372471, 47.4871506009783, 49.50807932444981, 47.44934892654419, 47.85526268822806, 48.29753984723772, 47.82662916183472, 45.72083861487252, 45.246002197265625, 44.060535294669016, 44.17404454095023, 46.768824986049104, 44.44530916213989, 43.46687078475952, 48.529397760118755, 53.56445503234863, 57.53798042024885, 55.3997209412711, 56.5107205254691, 53.638904980250764, 53.36333247593471, 50.817224161965505, 49.761396748679026, 50.42432090214321, 51.47853980745588, 49.48009545462472, 49.82384368351528, 48.25529827390398, 46.62163782119751, 47.65451533453805, 46.04149450574602, 44.997201102120535, 45.67226723262242, 47.587027481624055, 50.60301814760481, 55.14232839856829, 54.24828284127371, 49.70794078281948, 51.667829581669395, 48.97873428889683, 38.15574768611363, 42.10745920453753, 40.1711664881025, 48.60098852430071, 43.63931117738996, 40.95418330601284, 40.58461209705898, 40.198611872536794, 44.02177824292864, 45.078932762145996, 45.8714998790196, 50.146729946136475, 49.184206417628694, 45.907164982386995, 42.91509696415493, 45.60284778050014, 41.640880720955984, 41.027893270765034, 40.703269958496094, 42.34061643055507, 47.03489930289132, 41.82364961079189, 39.31499556132725, 32.49062776565552, 37.960430349622456, 35.85539368220738, 54.52738503047398, 56.59343882969448, 56.143734046391074, 55.13811431612287, 49.76182753699166, 50.45442744663784, 50.74440704073225, 54.621220452444895, 51.68402235848563, 50.7097806930542, 51.47325570242745, 52.91929394858224, 50.211480208805625, 50.462518623897004, 50.61197784968785, 51.409023080553325, 52.735243116106304, 54.54454708099365, 54.759632042476106, 53.775131361825125, 55.60969202859061, 44.488033635275706, 43.96712023871285, 41.23849664415632, 47.80126476287842, 47.41284309114729, 49.802821908678325, 52.470287459237234, 52.255463055201936, 52.94517946243286, 52.71808801378523, 49.35972138813564, 47.764095374516074, 48.050343785967144, 49.68178081512451, 53.225685187748496, 64.3010060446603, 62.20806271689278, 63.57200799669538, 60.43428489140102, 63.18966947283064, 60.66834190913609, 61.64161777496338, 55.924716404506135, 58.042256355285645, 54.45265368052891, 57.31502662386213, 54.42286327907017, 58.410149574279785, 57.80104269300188, 66.54264777047294, 65.5949273790632, 78.09583445957729, 67.28279767717633, 86.01345961434501, 11.312819838523865, 0.31904366452779087, 61.48019027709961, 65.6082192829677, 54.184595652988975, 45.43915169579642, 46.67771325792585, 19.290521723883494, 12.48736069883619, 14.885374239512853, 10.796290755271912, 0.25341708745275227, 0.13344866276851722, 1.026353046298027, 0.3529572790222508, 0.026847732486203313, 0.1030471862426826, 0.043872031915400705, 0.185994346759149, 0.18237734798874172, 0.19693271123937198, 0.15913946421018668, 0.16810459457337856, 0.21674457671386854, 31.898238250187465, 78.30973475319999, 81.36601802280971, 43.60323960440499, 44.71676138469151, 57.51709066118513, 64.23285116468156, 64.64754744938442, 79.61798327309745, 71.2696601322719, 82.58476679665702, 8.299517256872994, 0.7247214317321777, 1.8358504261289323, 2.721978076866695, 58.67980221339634, 61.97256742204939, 73.42057922908238, 70.05277347564697, 71.95330033983502, 71.05810138157436, 73.06680474962506, 65.43107495989118, 71.17614432743618, 67.14938531603131, 70.59907558986119, 65.30130345480782, 67.28057425362724, 65.37502384185791, 70.71251882825578, 64.82178047725132, 61.02784170423235, 49.91722399847848, 52.34105443954468, 48.847364698137554, 50.00768607003348, 49.73919030598232, 50.93771982192993, 48.94979851586478, 48.40995127814156, 47.15021855490548, 47.557084219796316, 47.98768493107387, 48.16406842640468, 45.44270569937569, 52.60459961209978, 56.367205483572825, 58.96622780391148, 58.265852860042024, 61.07064955575125, 55.65482405253819, 55.931473527635845, 53.564267430986675, 51.789099965776714, 52.06200088773455, 54.62765448434012, 52.25740507670811, 52.72355277197701, 50.39686509541103, 49.10756083897182, 50.66168526240757, 49.253563335963655, 44.52461590085711, 48.887216091156006, 51.01751640864781, 54.17172758919852, 58.12019082478115, 55.41422530582973, 51.67533016204834, 53.04623753683907, 45.6300812448774, 37.90445218767439, 43.881938798086985, 42.85331358228411, 51.292658124651226, 46.028803621019634, 43.64815623419625, 44.23533460072109, 41.80679675510952, 47.04566206250872, 46.43077080590384, 49.372537340436665, 53.719385964529856, 51.04397514888218, 48.315869195120676, 45.59762620925903, 47.936285631997244, 43.2595226424081, 42.009281158447266, 43.059431893484934, 46.03299685886928, 49.90117365973336, 43.59381089891706, 43.36154304231916, 31.382167748042516, 40.06473398208618, 31.907976150512695, 45.53065947123936, 59.330876214163645, 56.78035926818848, 60.47500133514404, 51.517988204956055, 52.1485024860927, 54.82968725476946, 58.19509935379028, 56.386535372052876, 52.45028359549386, 55.59503827776228, 57.07922560828072, 53.10826757975987, 52.190549509865896, 53.89168391908918, 55.6618139403207, 55.65499428340367, 57.32372576849801, 57.69661821637835, 59.64301013946533, 59.181837354387554, 47.70639753341675, 47.417411531720845, 46.32359136853899, 51.353541714804514, 49.543379647391184, 53.2326785496303, 54.96312393460955, 55.192386695316856, 54.816784449986045, 54.616176060267854, 52.42392907823835, 50.88960354668753, 49.939871651785715, 54.38923747198922, 56.385222162519185, 67.14406994410923, 65.08668054853166, 66.97331796373639, 61.44229480198452, 67.28421510968889, 62.90181950160435, 66.2518448148455, 58.17601612636021, 61.75249712807791, 56.313336099897114, 59.09197630201067, 56.99875157220023, 60.28212629045759, 59.75307655334473, 67.28921086447579, 66.3403787612915, 79.57598141261509, 68.6228619984218, 87.57073851994106, 13.413790941238403, 0.3816205523908138, 67.46638992854527, 71.7420403616769, 65.98967538561139, 58.024239676339285, 60.71832724979946, 32.0428580556597, 36.19426427568708, 45.23670550755092, 17.49628840173994, 0.5124464194689478, 0.16965150513819285, 0.6106209914599146, 0.11975982944880213, 0.1309583442551749, 0.13528507708438806, 0.10933745013816015], [0.07027808390557766, 0.05009411661220448, 0.0923059768974781, 0.09551327622362546, 0.0799896502867341, 0.1725301899548088, 12.45142548424857, 55.21590287344796, 54.347593443734304, 34.04388019016811, 33.197589601789204, 23.108388355800084, 43.868570463997976, 51.616680417742046, 67.58847672598702, 56.094592911856516, 70.23148809160504, 7.5737188543592175, 0.4502717400235789, 0.7359357699751854, 3.254095660788672, 48.14997747966221, 58.86918926239014, 63.49345861162458, 66.76747063228062, 66.37864249093192, 63.37629113878523, 66.77767058781215, 65.40872260502407, 64.73454584394182, 62.07188497270857, 61.925632340567454, 60.35389423370361, 63.27327019827706, 59.00813238961356, 61.29711219242641, 54.64684540884835, 48.421203885759624, 44.88692624228341, 47.1975496837071, 45.363034180232454, 45.804786750248496, 44.73709181376866, 46.02535036631993, 43.08003677640642, 41.887597356523784, 40.0993047441755, 42.44912644795009, 43.73195150920323, 41.658133098057334, 42.45863158362252, 43.976993628910606, 47.447347845349995, 53.57311248779297, 53.97806739807129, 53.91667658942086, 49.75279140472412, 49.94391550336565, 49.73133189337594, 49.59030430657523, 46.262530599321636, 48.44368825639997, 47.370778696877615, 46.71747432436262, 46.62591443743025, 44.26341921942574, 42.18073838097708, 40.18099124091012, 41.65297058650425, 42.912887437003, 43.77127136502947, 43.981100014277864, 50.49623128346035, 53.98300061907087, 45.41223437445504, 47.50672715050833, 39.947146143232075, 43.90156398500715, 41.895146574292866, 39.837003299168174, 47.156999996730256, 42.50446537562779, 39.17981488364083, 37.95317643029349, 40.00472933905465, 39.76273053033011, 39.988546984536306, 39.62581280299595, 41.07851437159947, 41.17599412373134, 40.50554854529244, 39.072055271693635, 40.06079435348511, 40.55274418422154, 40.445311137608115, 39.942522117069785, 40.794510228293284, 46.3223545891898, 35.76628303527832, 39.93079355784825, 33.78435455049787, 33.10106175286429, 25.229834931237356, 34.334686619894846, 56.536522660936626, 49.008802618299214, 47.9878899029323, 42.86995799200875, 44.28784908567156, 44.78894969395229, 45.28315074103219, 45.382708004542756, 48.40372569220406, 43.67479910169329, 45.01079872676304, 44.598756653921946, 45.22636658804757, 44.524126052856445, 46.24247809818813, 48.68505825315203, 50.82139655521938, 52.5179694720677, 49.907096999032156, 54.347954750061035, 43.46646778924124, 38.46460553577968, 40.71452604021345, 42.69004828589303, 42.92104809624808, 49.01615728650774, 48.792140415736604, 48.027268818446565, 47.4196731703622, 48.07622929981777, 44.55640390941075, 43.92242247717721, 45.88979796000889, 43.17319474901472, 51.76076521192278, 59.88357761928013, 59.106018611363, 59.94649355752127, 57.81710345404488, 57.74111100605556, 54.643249716077534, 57.99322291782924, 55.70422921861921, 54.74663891111101, 49.95538003104073, 51.0770138331822, 50.125385080065044, 54.99258082253592, 58.019650391169954, 63.219199316842214, 63.04882253919329, 74.5433247429984, 62.78144196101597, 80.38386930738176, 4.431822921548571, 1.078635417989322, 60.50783157348633, 54.84575843811035, 48.207074301583425, 35.426005431583945, 29.83027717045375, 9.328139867101397, 6.338899765695844, 7.062608063220978, 3.855206685406821, 0.30397793437753406, 0.12707028431551798, 0.059747892165822644, 0.05113427008369139, 0.05180169748408454, 0.07787241068269525, 0.056932263608489714, 0.038890875809426816, 0.04235100067619767, 0.07440696949405329, 0.09657770089272942, 0.11893122962542943, 0.16254585928150586, 15.80378018106733, 65.64898436410087, 66.43486731392997, 34.88665151596069, 36.793740953717915, 29.93503863470895, 49.8753194127764, 56.82931627546038, 72.00037438528878, 63.33970192500523, 79.51766518184117, 11.138248085975647, 0.9981140473059246, 0.9888031354972294, 3.8514034152030945, 59.08051177433559, 65.87423801422119, 73.12935243334088, 72.11854239872524, 73.4023471559797, 69.74045194898332, 70.02347292218889, 67.6531366620745, 68.04945496150425, 64.8351001739502, 67.25171143668038, 61.88096932002476, 68.36889839172363, 61.753442083086284, 64.84434127807617, 57.63938243048531, 52.92098583493914, 47.87511716570173, 49.15324177060808, 48.80615840639387, 48.0285507610866, 47.26969630377633, 47.43001208986555, 44.692130020686555, 42.815887110573904, 43.30217068535941, 43.30848659787859, 46.356386865888325, 44.7149201120649, 44.2921257019043, 47.078474930354524, 51.674426896231516, 55.67444576535906, 56.591368266514365, 56.223415987832205, 53.363280364445274, 54.348924023764475, 52.07216610227312, 52.803255558013916, 51.14039877482823, 50.57282822472708, 49.1967305455889, 51.41722890308925, 50.625415665762766, 48.31818641935076, 46.23603016989571, 44.380861146109446, 43.36346421922956, 45.76290300914219, 46.782822132110596, 47.60292843409947, 52.29052366529192, 55.25063691820417, 46.63135140282767, 46.83776501246861, 42.14231136866978, 43.58712673187256, 43.75701018742153, 42.102449553353445, 47.7620004926409, 45.91974817003523, 42.59629276820591, 42.11386891773769, 40.5726056098938, 42.21243258884975, 42.89749370302473, 42.33266421726772, 41.565840176173616, 42.798738956451416, 42.70748479025704, 40.47263492856707, 41.039924076625276, 42.83855560847691, 42.5461163520813, 42.133261340005056, 44.36253874642508, 46.27167442866734, 37.55962003980364, 40.24281283787319, 33.56298494338989, 34.017702851976665, 26.63599051748003, 41.31108794893537, 63.49595301491873, 50.18268687384469, 50.558803285871235, 43.69879470552717, 47.541579314640586, 46.67901951926095, 48.09912708827427, 47.00185019629342, 47.419888564518516, 46.52434914452689, 46.705978529793875, 46.472553798130576, 47.17005218778338, 47.016417094639365, 47.84608064379011, 52.4967531476702, 55.46363047191075, 53.483487674168174, 52.013412134987966, 53.90761613845825, 46.081001962934224, 41.4152831350054, 42.311538219451904, 44.357595103127615, 45.48323106765747, 51.943249225616455, 50.33986554827009, 51.882313523973735, 50.279155663081575, 51.30875015258789, 46.33790118353707, 48.0544501713344, 47.92284434182303, 48.13297176361084, 53.297682421548025, 63.55273369380406, 62.71423898424421, 63.40862805502755, 61.27731677464077, 63.30707318442208, 57.978124482291086, 61.853190422058105, 57.7282394681658, 59.13303320748465, 53.59100409916469, 57.17269624982561, 52.454862458365305, 60.58022485460554, 60.91978331974575, 69.14303193773542, 66.85219696589878, 80.07063061850411, 67.1719183240618, 85.83036763327462, 3.603177934885025, 1.8003265666110175, 68.81919724600655, 63.86587510790144, 56.37979561941964, 46.15268305369786, 41.497751304081504, 17.27494137627738, 13.571732180459158, 12.055782897131783, 8.38897705078125, 0.3199961648455688, 0.13759415889424936, 0.12555622841630662, 0.11068235404257264, 0.009294029009262366, 0.06023248152009078, 0.030978468778942312, 0.24564989709428378, 0.16176684679729597, 0.27827524500233786, 0.21535242641610758, 0.2769767461078507, 0.3240899294614792, 19.704919236046926, 75.36811760493687, 75.34294428144182, 49.87144579206194, 49.12354864392962, 31.905301094055176, 59.03376429421561, 63.51039137159075, 77.66155815124512, 66.28650937761579, 83.88886724199567, 12.86243748664856, 1.304266767842429, 3.186275814260755, 4.578037338597434, 65.27599811553955, 64.82598413739885, 76.28218092237199, 70.46944999694824, 74.96867956433977, 68.60558877672467, 71.96224267142159, 67.76014586857387, 71.91104834420341, 66.49267632620675, 68.19681235722133, 63.44682230268206, 68.25684479304722, 63.57864352634975, 67.78529834747314, 59.74377291543143, 54.76482234682356, 50.004621914454866, 51.618754455021445, 50.99716166087559, 52.419586454119, 50.11997938156128, 51.16328961508614, 49.03875630242484, 44.989499023982454, 45.384747300829204, 45.54204409463065, 48.44119732720511, 47.52740151541573, 46.261054107121055, 50.29399354117257, 53.877492223467144, 56.54862642288208, 57.69796964100429, 57.96357842854091, 52.48603902544294, 55.20727668489729, 55.705493790762766, 55.1225642476763, 52.91460738863264, 56.047265257154194, 51.069325651441304, 55.98419298444475, 51.860534395490376, 49.42071614946638, 49.46093579701015, 46.22819260188511, 47.90263550622122, 49.39676570892334, 47.96574599402291, 50.65168680463518, 52.480278968811035, 58.288243430001394, 49.206006390707834, 43.703460420881, 41.30047457558768, 46.73012351989746, 44.82343012945992, 45.90492418834141, 50.468504496983115, 47.716753823416575, 44.571109771728516, 42.49076352800642, 42.88633142198835, 43.418698923928396, 45.885625566755024, 44.63825716291155, 45.73527349744524, 44.266226291656494, 45.19993216650826, 41.885589327131, 42.53623948778425, 45.487479891095845, 45.42430339540754, 46.72195243835449, 45.31275701522827, 50.95570523398263, 39.538612910679404, 40.713407380240305, 32.85205915996006, 34.782119342258994, 28.422791004180908, 34.5630704334804, 62.7167820249285, 54.134141308920725, 53.20628234318325, 47.977335589272634, 51.12935808726719, 50.17449494770595, 51.868771484919954, 51.049825532095774, 52.58217430114746, 50.86700800486973, 48.47253370285034, 50.35011414119175, 48.59800427300589, 49.60898801258632, 50.02270112718855, 53.85009895052229, 57.63584927150181, 56.9095401763916, 54.697768756321494, 59.55808925628662, 49.10193974631173, 42.733266081128804, 46.72438430786133, 46.387434891292024, 48.57170186723982, 54.0340907233102, 53.11043889181954, 54.35470839909145, 52.32923207964216, 54.53350291933332, 48.39860486984253, 50.35869516645159, 51.0697078023638, 48.50317873273577, 55.942364828927175, 66.85804040091378, 64.05650588444301, 66.97759110586983, 61.628930364336284, 65.72490733010429, 60.47708579472133, 63.16467680249895, 60.08160822732108, 60.590897287641255, 54.63279962539673, 58.25940145765032, 54.163691997528076, 62.68909345354353, 62.47447749546596, 70.98024681636265, 66.14188957214355, 81.51561273847307, 68.08354977199009, 86.65067890712193, 5.948346299784524, 1.4830622651747294, 75.43513298034668, 70.72073854718889, 66.01842703138078, 55.06460932322911, 57.54874317986624, 27.499924319131033, 37.907776900700156, 38.34485680716378, 14.420974016189575, 0.4260474427470139, 0.22126657835074834, 0.21169128215738706, 0.10594516180987869, 0.20775634901864187, 0.1727386223418372, 0.09597812020885092], [0.09731857292354107, 0.052557497285306454, 0.03163777072248714, 0.09730853060526506, 0.12095391537461962, 0.2299163799200739, 5.682655002389636, 50.94513007572719, 60.706112316676546, 32.63002252578735, 20.87852556364877, 34.108505385262625, 47.241587366376606, 48.22881521497454, 65.42374461037772, 55.027700492313926, 76.12317139761788, 12.045407499585833, 0.4300442039966583, 0.34104027705533163, 4.689140336854117, 53.410542011260986, 64.30382006508964, 65.88950320652553, 66.3350772857666, 64.12328502110073, 63.83716515132359, 65.16839136396135, 62.734256744384766, 64.71509783608573, 62.21752616337368, 64.65015302385602, 62.87736184256417, 61.5572874886649, 59.826609339032856, 59.57814175742013, 50.05704607282366, 46.66042961393084, 46.14390400477818, 46.181983607155935, 42.172098296029226, 43.40919378825596, 42.26485327311924, 45.34607015337263, 42.22693000520979, 39.56548159463065, 39.48901319503784, 41.91904837744576, 43.57770150048392, 42.44533620561872, 44.74595076697213, 44.265163217272075, 45.95107759748186, 52.72961507524763, 54.67268228530884, 51.302253586905344, 51.444653442927766, 49.09021813528878, 48.51113789422171, 48.14582940510341, 46.26088040215628, 48.52676091875349, 46.302524430411204, 48.92008454459054, 47.01579523086548, 47.59501096180507, 44.218547752925325, 42.83631134033203, 42.15724999564034, 41.69437142780849, 43.35648822784424, 52.325761454445974, 80.56503663744245, 45.946081842694966, 39.203171253204346, 42.810158320835654, 38.10418163027082, 42.82125111988613, 44.98743540900094, 40.00990922110421, 43.967596190316335, 41.537620067596436, 40.37801783425467, 39.88789190564837, 39.49609340940203, 40.09639344896589, 38.706736360277446, 39.17639636993408, 37.822925499507356, 38.28642593111311, 38.9782406943185, 40.17236157826015, 39.04405403137207, 41.04242542811802, 38.769461223057334, 39.55968679700579, 42.28600706372942, 41.22340515681675, 35.491631167275564, 40.83127314703805, 38.711304800851, 39.15942192077637, 34.36506067003523, 22.477787222181046, 51.06812708718436, 50.66222374779837, 48.56753989628383, 41.16403974805559, 41.25277171816145, 41.09454386574881, 43.08162791388375, 42.803342138017925, 42.79003981181553, 43.50246293204171, 40.7350822857448, 43.54819597516741, 43.79987015042986, 46.21295172827584, 43.86460651670183, 48.11906841823033, 49.4300024168832, 51.29479122161865, 50.07397188459124, 51.892190388270784, 44.00514772960118, 40.96810402188982, 40.26276111602783, 41.15732431411743, 43.320743220193044, 47.92141301291329, 46.03811420713152, 47.01374898638044, 46.25225073950631, 42.92900378363473, 42.02592209407261, 44.23226349694388, 44.02362993785313, 45.31282302311489, 50.28200789860317, 58.870926312037874, 59.49506214686802, 61.738531248910085, 57.89181048529488, 58.37072549547468, 58.86319991520473, 58.81791155678885, 57.63170119694301, 58.65348243713379, 55.02483088629586, 55.39853279931204, 53.28890337262835, 58.077723434993196, 59.43625954219273, 66.69746058327812, 66.51108210427421, 70.23385047912598, 65.85661043439592, 70.76029464176723, 0.6515751938734735, 3.927776711327689, 64.939927646092, 56.16955007825579, 44.26008408410208, 32.05929749352591, 35.01783697945731, 12.63181027344295, 5.488134103161948, 11.91025287764413, 1.5425465532711573, 0.20609453533376965, 0.11747278645634651, 0.044231875999165435, 0.11506343074142933, 0.06483461135732276, 0.08851284400693007, 0.08855273508067642, 0.008683232989694391, 0.0373753033844488, 0.05497459847746151, 0.10408938210457563, 0.018918530017669712, 0.11476028843649796, 7.0946535893848965, 64.71092891693115, 70.19113990238735, 37.769080434526714, 19.52322905404227, 28.933860540390015, 56.70918192182268, 53.423076561519075, 73.93276568821499, 59.695733070373535, 85.55605275290353, 14.63528425352914, 0.8306988307407924, 1.5994366662842887, 6.337107564721789, 62.88820798056466, 65.99622753688267, 74.0876271384103, 69.88398783547538, 71.83944020952497, 66.80725601741246, 69.45423480442592, 66.07340812683105, 66.36177921295166, 65.3359819139753, 68.5803529194423, 64.242203439985, 65.32157829829625, 61.572385924203054, 63.83924961090088, 52.9948729787554, 50.305027280535015, 49.45054824011666, 48.524287360055105, 45.77739347730364, 47.57627861840384, 45.427145208631245, 48.478255544389995, 44.895962374550955, 41.38975197928292, 42.37619815553938, 45.8787260055542, 45.071591990334646, 44.27404996326992, 45.930559567042756, 46.77304949079241, 48.95551688330514, 56.55103744779314, 56.433817863464355, 54.18913977486746, 51.841392108372276, 50.64391524451119, 50.55240746906826, 52.37749079295567, 48.475219181605745, 53.72293301991054, 51.195449352264404, 51.67621953146798, 51.47626774651663, 49.86795779636928, 48.427808148520334, 46.434206690107075, 43.91849327087402, 44.39289542606899, 47.240882124219624, 57.33730602264404, 85.12492397853306, 47.21443380628313, 38.52158076422555, 46.3573248726981, 40.67280905587332, 45.67298289707729, 45.71676697049822, 42.319924695151194, 43.83549703870501, 43.769721916743684, 42.87381076812744, 43.05878571101597, 41.13210582733154, 42.26881374631609, 39.30006735665457, 40.235958439963206, 38.95781299046108, 40.50777196884155, 40.12857403073992, 40.24999380111694, 39.6253160067967, 41.34386954988752, 40.27686595916748, 41.7598477772304, 42.86524363926479, 43.2600611277989, 36.79351166316441, 43.44220815386091, 39.005512373788015, 39.23885720116751, 38.27572570528303, 27.628278391701834, 62.34165573120117, 53.32577051435198, 49.41142293385097, 43.53440727506365, 43.39344917024885, 42.281070368630544, 43.84363685335432, 46.38509334836687, 44.7763352394104, 45.43012598582676, 45.0603289604187, 45.246655327933176, 46.30692264011928, 48.35234028952462, 46.298494475228445, 49.81369931357247, 50.069160257067, 54.21346194403512, 52.36749233518328, 54.25772196905953, 46.61473478589739, 43.10567215510777, 41.97432129723685, 44.00982386725289, 46.60192230769566, 52.02041244506836, 47.92273664474487, 49.0961970601763, 48.93874740600586, 46.32550212315151, 45.16658776147025, 48.33879477637154, 46.34241056442261, 48.990674768175396, 52.344215869903564, 62.695256505693706, 62.65786130087716, 66.95837238856724, 61.365218435014995, 63.83059215545654, 61.45950548989432, 63.72258240836007, 61.74746663229806, 63.17327172415597, 58.66762202126639, 60.29831559317452, 55.700466769082205, 62.41263157980782, 63.083785874503, 71.43445750645229, 68.22623797825405, 76.31155790601457, 69.76188714163644, 76.26405307224819, 0.6791404347334589, 5.3814414739608765, 72.71883201599121, 65.38188866206578, 53.98957708903721, 43.28790603365217, 49.35931839261736, 20.80577618735177, 16.308709246771677, 17.21748845917838, 5.2504931177411756, 0.36151078290172983, 0.12769688426383904, 0.06973734577851635, 0.09597716347447463, 0.04665041229288493, 0.05800348719848054, 0.06490499579480716, 0.15613358121897492, 0.14329331022288117, 0.15007296071520873, 0.2645614823060376, 0.20555803126522473, 0.30382339124168667, 8.757531217166356, 75.03491674150739, 81.09328038351876, 50.08615902491978, 31.31432901109968, 42.391296591077534, 67.69383920942033, 59.58820274897984, 81.22066865648542, 62.46527113233294, 91.5902853012085, 16.086733409336635, 1.913599031312125, 2.7575502480779375, 8.021258405276708, 66.01930250440324, 65.11306980678013, 72.9009929384504, 69.0251488004412, 72.92347730909074, 65.84265150342668, 70.02518217904228, 68.11793640681675, 68.88981873648507, 66.17710999080113, 69.67254720415387, 65.61269392286027, 69.06908920833042, 64.9393092564174, 65.11749580928257, 55.26219524656023, 52.125701972416465, 53.31750563212803, 50.71718052455357, 48.62656136921474, 48.12879242215838, 48.376964705330984, 52.08721590042114, 48.303518772125244, 45.56257254736764, 43.76860325677054, 47.45997272218977, 46.458501066480366, 46.76807805470058, 48.76349994114467, 48.229384967258994, 51.25854941776821, 57.72360154560634, 56.44683183942522, 55.80923039572579, 54.39887114933559, 52.464534350803916, 52.927423340933665, 56.0790046283177, 50.552619389125276, 57.68518148149763, 52.166845730372835, 54.21465356009347, 52.29509905406407, 52.55842188426426, 50.45699828011649, 46.91198219571795, 49.45838580812727, 45.94524458476475, 51.39685331072126, 59.8565491267613, 74.22035162789481, 49.91568149839129, 39.1856027330671, 44.188552379608154, 41.4775389943804, 47.135467529296875, 49.05932297025408, 46.24026509693691, 47.323117528642925, 46.248630728040425, 44.352915491376606, 46.3489488192967, 43.38886335917881, 44.885731152125764, 42.0882682800293, 43.36139713014875, 41.94893952778408, 45.908221108572825, 43.49353102275303, 43.81695229666573, 42.33815676825387, 44.71540648596627, 42.8549359866551, 45.23714671816145, 45.489689418247764, 45.14221000671387, 39.23209660393851, 45.09446546009609, 41.78437491825649, 39.72395610809326, 38.24931560243879, 28.1555962903159, 53.92319399969918, 55.77783843449184, 53.1017119543893, 46.22614288330078, 46.09420006615775, 44.80957889556885, 49.21149546759469, 48.038108008248464, 46.9336119379316, 48.6442688533238, 46.33377742767334, 49.3841095651899, 48.233623368399485, 50.86232839311872, 49.588956356048584, 53.166500432150706, 54.72218820026943, 56.6001056262425, 55.218258312770296, 56.11379425866263, 49.944818769182476, 44.71068171092442, 44.13958147593907, 45.401461192539756, 48.346910272325786, 55.21202577863421, 51.00694819859096, 52.621598379952566, 51.75764199665615, 49.941730294908794, 48.275100639888215, 49.933302130017964, 49.21836028780256, 50.313858440944124, 55.16769279752459, 65.58613095964704, 66.22542081560407, 70.33558600289481, 62.395921162196565, 65.03185926164899, 63.33022458212716, 64.72985580989292, 62.68274280003139, 64.25382777622768, 59.33194623674665, 63.81072725568499, 56.45431852340698, 64.42115429469517, 64.37222508021763, 71.17462267194475, 68.50764696938651, 78.12254333496094, 68.6646067755563, 79.77634661538261, 1.1617675742932727, 5.240595408848353, 79.93870517185756, 70.88488973890031, 62.21499701908657, 53.80799981525966, 58.90815476008824, 33.585240023476736, 45.61512872150966, 33.01256602151053, 10.230687413896833, 0.6361507358295577, 0.36136777486119953, 0.11817976566297667, 0.22658094604100498, 0.16777984771345342, 0.17378903526280606, 0.3167951894657952], [0.07010439929685422, 0.01730395424445825, 0.035444504847483974, 0.09639586029308182, 0.06316551020635025, 0.07842773052730731, 1.8840622391019548, 38.753383091517854, 52.10983228683472, 48.64401176997593, 34.738540240696494, 35.62701334272112, 45.08249371392386, 46.206587178366526, 53.47760949816023, 56.1080515725272, 72.7069228036063, 18.7598808492933, 0.879788016634328, 0.5883391499519348, 5.321597073759351, 55.21342236655099, 61.52549253191267, 69.20717770712716, 68.07538563864571, 66.10619667598179, 64.60967281886509, 64.22857802254813, 62.653546469552175, 66.24054704393659, 61.96328462873186, 63.92361463819231, 61.42159611838204, 60.462147167750764, 58.86539554595947, 54.97362961087908, 44.75615072250366, 46.507652623312815, 44.288599491119385, 46.52591596330915, 43.591017723083496, 44.29521765027727, 41.58269650595528, 43.139377866472515, 41.11403008869716, 40.84056636265346, 38.57591567720686, 44.191682543073384, 43.39917795998709, 42.369566099984304, 44.12660224097115, 43.01571382795061, 46.29685122626168, 52.599225180489675, 52.03350632531302, 52.30977017538888, 47.46421807152884, 47.796588625226704, 47.06414427076067, 48.94298928124564, 46.692627566201345, 48.36025776181902, 48.74252332959856, 49.83927910668509, 47.806493282318115, 45.54912083489554, 47.12887716293335, 45.110967431749614, 43.37322643824986, 47.59523330415998, 40.75221654347011, 61.7696452822004, 77.46035916464669, 41.269634996141704, 42.702593258449006, 42.45970508030483, 38.596114090510774, 41.18442923682076, 38.58007764816284, 42.605144773210796, 41.05161094665527, 39.663280963897705, 42.29459156308855, 39.96763638087681, 38.50815337044852, 37.294584478650776, 37.23383985246931, 37.49976478304182, 37.180310930524556, 37.487799985068186, 37.98456144332886, 35.476744651794434, 39.0724652154105, 39.363052776881624, 39.37440613337925, 39.69960962023054, 40.91852862494332, 40.08987603868757, 39.08297783987862, 39.75700174059187, 39.48403133664812, 42.3955523627145, 47.35945313317435, 25.26976101739066, 37.96659687587193, 61.557259695870535, 44.06673308781215, 42.86019924708775, 40.81275619779314, 39.506811005728586, 42.062969888959614, 44.70662743704659, 43.96713413511004, 44.02700676236834, 43.454954624176025, 44.78317921502249, 46.13793897628784, 45.067148617335725, 43.581533432006836, 45.69680479594639, 45.454687867845806, 48.65539639336722, 49.26393004826137, 49.608852522713796, 41.90882062911987, 40.239300523485454, 39.65402596337454, 39.146331514631, 41.08675493512835, 43.98000219890049, 42.06222643171038, 44.713808400290354, 44.639292444501606, 42.3093113218035, 43.03871931348528, 43.04080377306257, 41.543647629874094, 44.908757482256206, 48.02130378995623, 59.10882568359375, 58.20927020481655, 59.71388871329171, 60.51182678767613, 59.26036589486258, 60.884271076747346, 59.99391501290457, 61.78053310939244, 60.46541282108852, 57.71503094264439, 58.01489782333374, 56.57703760692051, 60.580391611371724, 59.68444224766323, 66.46564088548932, 66.80925709860665, 68.94757911137172, 68.97105012621198, 57.24408899034773, 0.12522758676537446, 7.108353265694209, 63.991234506879536, 56.3703738621303, 36.22096272877285, 35.18788024357387, 35.216746534620015, 9.663609317370824, 5.202721646853855, 8.468217781611852, 1.7571186508451189, 0.09991356903421027, 0.09256069215812854, 0.08578664636505501, 0.08193393131451947, 0.0517632075851517, 0.04632988592077579, 0.0632110263354012, 0.042488736499633105, 0.04169727289783103, 0.03235123672389558, 0.0475181873355593, 0.038029020984790156, 0.043993632176092694, 2.3600909241608212, 47.87408535821097, 65.85880606515067, 54.315711634499685, 27.69500367982047, 40.36281517573765, 55.962747369493755, 50.50230400902884, 61.78907939365932, 60.71350519997733, 79.8698832648141, 21.74698611668178, 0.6684493284140314, 1.1905649261815208, 7.450553349086216, 63.78538717542376, 65.47065884726388, 77.10408333369664, 72.53744929177421, 72.91479900905064, 67.85159805842808, 68.65134961264474, 65.90083571842739, 71.16278988974435, 65.51034000941685, 67.94562802995954, 63.416104316711426, 64.79606519426618, 62.213475363595144, 59.79856640951974, 47.84657049179077, 49.497914109911235, 46.28764486312866, 50.494487285614014, 47.38267401286534, 47.396872656685964, 46.2289708001273, 46.81672586713518, 44.376219749450684, 41.655621324266704, 40.767627647944856, 46.95347683770316, 45.463512080056326, 45.724781717572895, 46.12503269740513, 45.025594915662495, 47.26298434393746, 56.378600529261995, 54.47968217304775, 53.885322843279155, 51.17994792120797, 50.70490305764334, 50.26296288626534, 51.457389490945, 48.69330923897879, 51.25434923171997, 53.11034509113857, 51.55917712620327, 51.293043749673025, 50.82024662835257, 48.3931679044451, 47.09421607426235, 45.25774812698364, 48.70532962254116, 47.199936389923096, 62.88262857709612, 78.57568400246757, 44.458851201193674, 44.06874459130423, 44.6575106212071, 40.2755423273359, 41.464688301086426, 41.149121965680806, 44.941841329847065, 42.62988036019461, 44.02240705490112, 42.696735927036826, 43.08041197913033, 40.862880502428325, 38.89778402873448, 39.03769295556204, 40.181178842272075, 37.78562409537179, 41.00571114676339, 37.638617583683555, 36.81104891640799, 39.7462910924639, 41.35972533907209, 40.14704234259469, 42.573982102530344, 42.16062682015555, 41.46005385262625, 40.02994435174124, 41.12054402487618, 41.19498702457973, 41.90120192936489, 45.54174184799194, 27.215254885809763, 42.12334278651646, 67.83483900342668, 46.17484433310372, 45.73764978136335, 42.80463450295584, 43.03522784369332, 44.04764291218349, 45.903986181531636, 44.69880723953247, 45.57550661904471, 45.59578841073172, 47.77034180504935, 47.1657304082598, 48.00545147487095, 46.31694541658674, 47.151948656354634, 45.93773705618722, 50.73151813234602, 48.682952948978965, 51.3472501209804, 44.567284788404194, 42.65367446626936, 41.305359159197124, 43.36483301435198, 43.46786437715803, 47.42997734887259, 46.14064877373831, 47.425172669546946, 45.081135341099326, 44.6519763810294, 45.47688388824463, 45.412616525377544, 45.75658362252371, 48.074176107134136, 52.68522998264858, 62.91397190093994, 60.46347427368164, 64.68995230538505, 63.508105414254324, 63.75619779314314, 65.02753053392682, 65.48194966997418, 65.54716546194894, 64.70886530194963, 60.42857347215925, 61.45935262952532, 58.91490146092006, 65.13490799495152, 62.19720268249512, 70.65361200060163, 70.38476535252163, 74.49379798344204, 70.41781793321881, 62.53485039302281, 0.16642684888626846, 8.646688342094421, 72.48039763314384, 66.90799100058419, 43.505402020045686, 44.91746704918997, 44.97943108422415, 16.939940929412842, 18.14023528780256, 15.12131074496678, 3.2501464784145355, 0.21603381128183433, 0.30838341798101154, 0.0655473241848605, 0.09391690724130188, 0.028811248285429816, 0.07384892193866627, 0.08970814451043095, 0.10671147211853947, 0.17094951548746654, 0.15285101878855908, 0.12920104712247849, 0.13168213755956718, 0.15900752986116068, 2.258108739342008, 55.38480315889631, 80.03921086447579, 62.13639899662563, 50.560752255576, 45.874921866825645, 61.89807578495571, 58.037427357264924, 67.12904099055699, 65.2262212208339, 85.03322165352958, 25.02098945208958, 1.9341587509427751, 1.6801944928509849, 10.447046501295906, 64.23594311305455, 67.04369626726422, 77.76667049952916, 73.59030982426235, 75.14454541887555, 69.82235036577497, 68.93521826607841, 68.03687872205461, 73.03104931967599, 66.16461018153599, 69.25386265345982, 67.3658355985369, 66.88186577388218, 64.8202657699585, 61.30162852151053, 48.28339678900582, 52.92491156714303, 50.26751743044172, 52.95920787538801, 50.226933002471924, 51.288652488163535, 47.302741936274934, 48.82728093011038, 47.82165425164359, 46.11618069240025, 42.17302935464041, 49.11804567064558, 48.34432206835066, 47.80390855244228, 47.67354645047869, 47.22704478672573, 49.4590493610927, 57.68001202174595, 56.504845823560444, 56.06982258387974, 53.006948947906494, 53.38591412135533, 51.59219149180821, 54.252642835889546, 52.6168840272086, 53.594238485608784, 55.90913506916591, 57.04641621453421, 52.715822901044575, 50.57847363608224, 49.10448278699602, 49.604923316410606, 48.089371817452566, 51.274127279009136, 51.02823053087507, 63.23932129996163, 72.28472246442522, 46.723088468824116, 41.70140995298113, 44.287724018096924, 43.973008837018696, 43.5472023827689, 44.112497397831504, 50.087604250226704, 45.92062364305769, 44.3895776612418, 45.399609497615266, 45.98936217171805, 42.97746746880667, 41.08310713086809, 42.379196303231375, 41.42841175624302, 41.85942588533674, 42.203980105263845, 41.38935245786394, 40.6996534211295, 42.474278926849365, 42.87934848240444, 43.48570735113961, 44.952798639025005, 42.8868282181876, 42.56999731063843, 42.95167228153774, 44.0508634022304, 44.61396973473685, 45.127861976623535, 51.39861120496477, 28.61841927255903, 41.60992997033255, 61.7517397744315, 51.22597973687308, 49.32095391409737, 44.77265616825649, 44.15002114432198, 46.8565216745649, 48.99736588341849, 50.43290887560163, 48.99293293271746, 47.907311643872944, 49.217919077192036, 51.34673248018537, 50.687970297677175, 49.015069893428254, 50.65335437229702, 50.911420890263145, 53.63122027260916, 52.91328723090035, 54.90940393720354, 47.54336847577776, 44.79856252670288, 43.7770105770656, 43.444792883736746, 45.96650259835379, 50.5108711378915, 47.852851663317, 50.43789073399135, 49.3912627356393, 47.45720386505127, 47.68640756607056, 47.39431571960449, 45.44814266477312, 49.785517420087544, 54.79600586209978, 65.17871638706752, 62.55820328848702, 66.27394703456334, 65.07215186527797, 65.6948355266026, 66.83513219015938, 65.6595595223563, 66.99012565612793, 67.68392413003104, 61.48417854309082, 63.77388095855713, 59.288179533822195, 67.90267426627022, 62.98022297450474, 72.66598401750836, 70.41032777513776, 75.3302777154105, 71.78168678283691, 67.08154310498918, 0.3070681728422642, 9.616109694753375, 77.33126858302525, 72.1882884161813, 49.84014763150896, 52.869385038103374, 59.02013887677874, 27.558157171521867, 39.7204715864999, 33.84508180618286, 7.189193384987967, 0.24903133564761706, 0.326661224343947, 0.2936259055776255, 0.3207555540970394, 0.12982991337776184, 0.17504877623702797, 0.41695026946919306], [0.05129048580835972, 0.02740109814996166, 0.052365987561643124, 0.0512976782795574, 0.060622489878109524, 0.13447825823511395, 0.23958061848367962, 19.27216979435512, 47.44747291292463, 52.90327835083008, 39.47194494519915, 23.922778027398245, 46.525634561266216, 51.727625778743196, 47.58709001541138, 55.45292329788208, 75.00963919503349, 27.928473574774607, 0.1141859492553132, 1.956931688955852, 6.378104541982923, 58.330502373831614, 56.69971152714321, 68.8582044328962, 65.11607142857143, 65.94337259020124, 63.90568828582764, 67.47094794682094, 64.5820676258632, 64.1030935559954, 59.900079590933665, 62.787472997392925, 58.37003762381417, 61.11682728358677, 57.70560918535505, 50.34973199026925, 45.69312572479248, 46.75350073405674, 43.076548780713765, 43.45081697191511, 42.665548937661306, 43.068683419908794, 45.30685452052525, 44.501589570726665, 40.249712399074006, 37.28209509168352, 36.904137407030376, 40.80513749803816, 43.664401122501914, 43.94808564867292, 44.27793748038155, 43.29929065704346, 44.01785251072475, 50.6940221786499, 51.50354290008545, 52.464919975825715, 48.84351887021746, 47.510107449122835, 46.07628413609096, 46.48007869720459, 48.445199489593506, 49.41054398672921, 50.581096581050325, 50.179469857897075, 49.08197062356131, 48.945646967206685, 46.319186210632324, 44.474415166037424, 44.11720132827759, 47.13478313173567, 50.72355202266148, 53.00547592980521, 50.64464480536324, 36.909685543605256, 44.3666798727853, 41.630514008658274, 36.82456316266741, 39.06928988865444, 40.164961746760774, 40.609347684042795, 39.99786799294608, 42.43664748328072, 41.89554262161255, 39.955522196633474, 38.33975682939802, 37.55418654850551, 35.922072069985525, 37.517159598214285, 35.94516788210188, 37.35822302954537, 36.06467342376709, 35.87623480388096, 36.54274770191738, 38.605678285871235, 38.876095226832796, 41.40128598894392, 43.209061350141255, 42.46131706237793, 40.031525066920686, 39.78177901676723, 35.67314938136509, 39.05675533839634, 34.39738368988037, 34.533689975738525, 22.774232115064347, 53.112106459481375, 63.14126137324742, 40.29216241836548, 40.16456569944109, 38.595978600638254, 41.46623427527291, 40.77322442190987, 41.721358231135774, 43.42119680132185, 45.479461669921875, 47.80917181287493, 45.21488468987601, 44.60683740888323, 42.9327905518668, 43.014848777226035, 45.16074432645525, 45.48223400115967, 47.676725251334055, 45.21402311325073, 42.08298764910017, 40.29928432192121, 39.65489101409912, 39.13071543829781, 38.599167823791504, 42.10943249293736, 41.75871522086007, 41.0522050176348, 40.5264869417463, 43.48831639971052, 43.476254326956614, 41.679262569972444, 43.7288248198373, 44.16704075677054, 49.425281115940635, 56.25286245346069, 58.43264089311872, 59.59217711857387, 58.55064909798758, 59.79122216360909, 59.073695591517854, 60.05972834995815, 62.13316113608224, 61.141396113804404, 62.36455699375698, 58.18995073863438, 55.092495918273926, 59.522583961486816, 59.670761244637625, 66.10856601170131, 70.03947462354387, 68.63635540008545, 66.60837772914341, 49.361038071768625, 0.2495850202228342, 7.650595460619245, 67.29119110107422, 59.52855246407645, 45.87753438949585, 36.048855849674766, 36.928893838609966, 22.502076387405396, 9.089183500834874, 9.945112977709089, 0.6204539952533585, 0.17033757189554827, 0.05281317267300827, 0.04690314283860581, 0.11241585495216505, 0.07210273920957531, 0.09233426502240555, 0.020303348744554178, 0.035746279904352765, 0.047673283477446864, 0.08831977365272385, 0.046558759175240993, 0.07371653975652796, 0.12377618678978511, 0.1587051882275513, 27.840731722967966, 61.047122955322266, 59.082728249686106, 37.66354424612862, 28.791610070637294, 60.84301962171282, 57.899641105106895, 54.36613818577358, 61.21706894465855, 82.27755219595772, 32.38511937005179, 0.20472412529800618, 2.111269635813577, 7.991159677505493, 65.52697399684361, 60.021117210388184, 73.42868082863944, 70.1643476486206, 70.80834838322231, 66.52043437957764, 73.05428409576416, 68.50084468296596, 69.56087575639997, 63.666635513305664, 65.5916200365339, 64.4698611668178, 64.64852714538574, 60.99662344796317, 52.93211684908186, 49.52085706165859, 49.19758864811489, 46.88376208714077, 47.76900775091988, 45.45619910103934, 46.41142007282802, 46.90520770209176, 47.91793196541922, 44.19771357945034, 41.36735446112496, 40.52523626599993, 43.429312297276084, 45.8402156148638, 46.10669640132359, 44.60598972865513, 46.30794402531215, 47.0238481930324, 52.83628034591675, 53.402110372270855, 53.49659545081002, 51.432587896074565, 49.57009547097342, 48.208936418805806, 50.49333735874721, 51.415401526859824, 53.00872768674578, 52.864351068224224, 52.79746076038906, 52.06070852279663, 53.26912879943848, 48.625029291425435, 49.35225207465035, 46.65606614521572, 49.86058575766427, 54.767427921295166, 53.59846646445138, 57.080094133104595, 39.118670736040386, 44.98652866908482, 44.30021340506417, 35.457373074122835, 39.18959794725691, 42.37599318368094, 41.82138797215053, 41.72124011175973, 44.85908828462873, 43.6329014641898, 42.163277557918, 39.90872607912336, 41.3870004926409, 37.451988969530376, 39.12363174983433, 37.034593309674946, 40.12990461077009, 36.88102075031826, 37.26037849698748, 37.73003503254482, 38.96389613832746, 40.244994572230745, 45.20500087738037, 43.97919273376465, 42.30542033059256, 42.08615950175694, 40.49821819577898, 37.57367277145386, 41.88201447895595, 33.98285068784441, 37.153039251055034, 26.16856782776969, 56.83533688953945, 64.73137746538434, 44.45930283410208, 41.90024307795933, 41.063676493508474, 41.90945291519165, 43.35372631890433, 43.568668842315674, 45.919921875, 48.74883229391915, 51.117535727364675, 47.17194904599871, 49.19764770780291, 46.12564066478184, 45.062191077641074, 45.69138172694615, 48.74639695031302, 49.46518462044852, 48.546170711517334, 44.65998765400478, 43.83830063683646, 40.70732423237392, 42.64860922949654, 40.73178883961269, 44.271277632032124, 43.39944199153355, 44.053399494716096, 44.042525563921245, 45.201214109148296, 45.18378802708217, 45.206307138715474, 46.68656178883144, 47.687640871320454, 52.56700985772269, 60.74669674464634, 62.8669673374721, 64.13124070848737, 62.859664780753, 65.15189634050641, 62.314029693603516, 64.24726867675781, 65.08479758671352, 64.99600655691964, 65.53582600184849, 62.411339214869905, 59.05645711081368, 63.66680921827044, 61.49836676461356, 71.04536533355713, 71.65797410692487, 75.22856303623745, 66.72980444771903, 53.879260540008545, 0.22991100592272623, 9.069005063601903, 74.3228097643171, 67.36262553078788, 54.198968001774375, 45.886327334812705, 45.141452653067454, 29.214770998273575, 24.949737412588938, 12.477919834000723, 1.7414989918470383, 0.20010167333696569, 0.0779543641422476, 0.02287802951676505, 0.029357540221618753, 0.032901864498853683, 0.028983555468065397, 0.023968638852238655, 0.13193272054195404, 0.14799995480903558, 0.230086122240339, 0.2564439507467406, 0.09057854887630258, 0.233808483928442, 0.13837390419627937, 32.443369592939106, 75.74365384238106, 68.82112884521484, 54.73332616261074, 34.73797743661063, 63.04625170571463, 64.7576972416469, 61.81215436117989, 66.02358954293388, 87.02570792606899, 35.205959456307546, 0.6556525379419327, 6.040664843150547, 10.446832844189235, 68.20227364131382, 61.00201525006975, 72.45589828491211, 69.8302504675729, 72.9133607319423, 69.00664574759347, 75.6108946119036, 68.81557028634208, 72.93510859353202, 64.22493716648647, 67.47552680969238, 64.33044556209019, 66.67131451198033, 64.41588756016323, 54.46800919941494, 51.15983983448574, 52.50464282717024, 49.331306729997905, 48.73267078399658, 49.25903851645333, 49.38447434561593, 51.02752876281738, 49.73869350978306, 47.71518005643572, 44.09755182266235, 43.221126896994456, 46.399476119450156, 48.83600091934204, 48.93468965802874, 47.69837931224278, 48.424601554870605, 46.709400517599924, 53.90131064823696, 56.28786400386265, 56.34495040348598, 53.52227251870291, 50.92754765919277, 51.150977407182964, 53.82075323377337, 51.899221965244834, 55.23203311647688, 55.45584154129028, 55.69864634105137, 52.50158561979021, 55.55801827566964, 50.60542222431728, 51.186034543173655, 50.75587156840733, 52.858188016074045, 56.657348360334126, 52.56494624274117, 56.254596029009136, 41.81297370365688, 40.419748714991975, 49.71836655480521, 39.81021451950073, 43.098918506077354, 44.27095454079764, 44.28467723301479, 44.30969769614083, 46.626522404806956, 45.30805308478219, 43.83171721867153, 42.55382885251726, 43.36568764277867, 40.11214848927089, 41.27097599846976, 39.90187862941197, 43.373601640973774, 40.72270059585571, 40.70507301603045, 41.08728299822126, 41.40061896187918, 42.909691265651155, 46.296924182346885, 47.585339069366455, 45.25330127988543, 44.84329155513218, 43.0289431980678, 39.13821601867676, 44.82333285467965, 36.81711121967861, 38.91642951965332, 31.08764750616891, 53.32157380240304, 59.26695278712681, 49.187388692583355, 43.26467473166329, 44.01577499934605, 46.6956604548863, 47.9708286012922, 45.90012993131365, 49.63763196127755, 49.60816465105329, 53.88004221235003, 49.04652091435024, 50.29849944795881, 48.02026850836617, 48.84291785103934, 49.24098709651402, 50.8459723336356, 51.84672137669155, 49.66451801572527, 46.878064564296174, 45.3792200088501, 43.79031637736729, 44.616762910570415, 43.53725256238665, 48.18704959324428, 45.1693878855024, 46.216533524649485, 45.61510092871529, 46.59744071960449, 46.89765848432268, 47.27588020052229, 48.153726032802034, 49.10440983091082, 54.970607144492014, 63.14206736428397, 64.37343406677246, 67.45624555860246, 64.29837962559291, 66.46093000684465, 63.25169604165213, 64.97354303087506, 65.47144399370465, 66.66474151611328, 68.19001701899937, 63.93969971793038, 59.23326792035784, 67.50830841064453, 61.797820227486746, 74.02648299080985, 71.55081898825509, 76.83689730507987, 69.61564145769391, 58.604643549237935, 0.3177734741142818, 10.369829433304922, 81.36163370949882, 71.50289726257324, 61.84654099600655, 56.87824896403721, 55.083841936928884, 45.613673073904856, 50.740672383989605, 31.602269308907644, 2.928169127021517, 0.24753218037741526, 0.43401214107871056, 0.07142357993870974, 0.17157618328928947, 0.14442032974745544, 0.2216762506536075, 0.11338706926575728], [0.0535313646708216, 0.03186191458787237, 0.08551140542009047, 0.015935128587963324, 0.07171872231577124, 0.037153877051813264, 0.24719131152544702, 9.051589403833662, 38.13130739756993, 59.08106763022286, 28.91753053665161, 27.13796659878322, 40.52140086037772, 51.398124831063406, 44.89651128223964, 55.53685058866228, 72.87119906289237, 35.19221591949463, 0.02686057036875614, 0.5835285538009235, 4.841606829847608, 56.355087825230186, 58.63406917027065, 64.8069599696568, 64.80086639949253, 65.52920436859131, 66.98917375292096, 65.11174964904785, 59.943075043814524, 65.21569469996861, 64.074953351702, 62.36902468545096, 61.354559898376465, 61.366719245910645, 51.45531892776489, 48.288684368133545, 43.56176928111485, 43.80363259996687, 43.082850796835764, 46.02346740450178, 43.69742243630545, 43.91056537628174, 43.54399578911917, 43.171690464019775, 40.39487068993704, 38.730540888650076, 38.40347181047712, 40.63440983636038, 42.46343278884888, 43.00029577527727, 44.641303947993684, 43.88071938923427, 45.16452414648873, 48.99962057386126, 48.87206554412842, 49.90483883449009, 46.427373136792866, 49.932444027491975, 48.601120540073936, 51.86844144548689, 54.169257504599436, 52.03124121257237, 51.40190812519619, 53.909214224134175, 49.56369270597185, 47.675307818821494, 46.91576896395002, 47.229931763240266, 47.29941027505057, 50.05515616280692, 49.306637150900706, 46.81604841777256, 51.55419526781355, 48.89147881099156, 43.38178314481463, 37.538580894470215, 35.51683228356497, 38.65772724151611, 39.75158214569092, 37.649613107953755, 40.05314786093575, 41.03874635696411, 40.122216429029194, 40.706639834812705, 35.95658377238682, 36.52586357934134, 36.63494682312012, 35.963379110608784, 35.6721453666687, 37.40431390489851, 34.28613608224051, 35.54493079866682, 36.55148506164551, 38.29510770525251, 40.47275652204241, 42.944585118974956, 40.97349582399641, 41.4488707269941, 38.38448585782732, 39.42683029174805, 35.55161149161202, 36.950547899518696, 38.34583650316511, 39.51380784170968, 31.008153166089738, 32.546817847660606, 65.82179995945522, 48.84273024967739, 44.72671467917306, 39.965419905526296, 43.09431185041155, 40.451237951006206, 44.70953178405762, 44.81373044422695, 49.2499989100865, 47.48424972806658, 46.10812425613403, 46.88920252663748, 46.30638762882778, 46.86210107803345, 44.61897243772234, 44.36829532895769, 46.4567049571446, 44.27691609518868, 40.880581038338796, 42.112586975097656, 41.34889309746878, 38.148243631635395, 39.30983304977417, 39.69979722159249, 39.02994571413313, 40.82994256700788, 40.75313717978341, 43.12888608660017, 42.57391609464373, 43.10829857417515, 42.63663748332432, 44.988849367414204, 47.24844871248518, 55.67511626652309, 58.69619301387242, 57.76857723508562, 57.88790212358747, 57.10908201762608, 58.63927337101528, 60.40568610600063, 60.25946821485247, 60.961215427943635, 62.851083755493164, 58.113412857055664, 57.47046477454049, 58.020296573638916, 57.79773882457188, 65.7794645854405, 69.04444394792829, 71.05825424194336, 62.05876677376883, 44.96262686593192, 0.2852200780596052, 6.219017718519483, 67.40370328085763, 54.38741704395839, 48.44353887013027, 36.055331570761545, 43.815093653542654, 16.459636279514857, 12.351189034325735, 5.314721396991184, 0.2699304042117936, 0.042774552412863286, 0.07435204886964389, 0.06546944872077022, 0.07032496389001608, 0.061140259594789574, 0.08109063442264285, 0.0392149441343333, 0.10272860048072678, 0.07598879747092724, 0.07214189068015132, 0.033612942056996484, 0.07294649071991444, 0.04841748372252498, 0.2738801565553461, 12.787600176674978, 55.25091484614781, 67.4594486781529, 28.528212547302246, 24.644984211240494, 49.77695376532418, 58.09803649357387, 51.25759056636265, 62.358275822230745, 77.75018242427281, 41.048668384552, 0.0587264798315508, 1.0221100854022163, 5.285462532724653, 62.58624621800014, 61.82707214355469, 69.48892021179199, 68.32125459398542, 70.47448744092668, 70.62535367693219, 70.95966625213623, 63.95071261269705, 67.5777278627668, 66.70162950243268, 65.83293792179653, 63.58024161202567, 66.0791264942714, 53.943600858960835, 52.240249974387034, 46.396672521318706, 48.0664392880031, 46.576123646327424, 47.202687876565115, 45.615448338644846, 46.52843468529837, 46.30793012891497, 47.55363096509661, 42.0205511365618, 40.57949127469744, 40.78106893811907, 43.41336270741054, 45.094246591840474, 46.324418204171316, 47.656332288469585, 45.68031324659075, 47.94518280029297, 52.06736142294747, 51.80987160546439, 50.57582637241909, 50.73012154442923, 52.8894236428397, 51.164449964250835, 54.36787870952061, 55.320928369249614, 56.456069469451904, 54.62919698442732, 55.35436657496861, 52.07001216070992, 50.9574943951198, 49.05537291935512, 49.66447980063302, 49.316402844020296, 54.63723257609776, 49.915935107639854, 49.0442419052124, 51.21979236602783, 52.68359020778111, 47.31682940891811, 39.10431923185076, 36.7567800113133, 40.16783830097744, 41.01476117542812, 40.81727947507586, 42.95693554197039, 44.34281281062535, 42.87091336931501, 41.665578092847554, 40.02157524653843, 38.817827633449006, 38.54020888464791, 37.65225689751761, 38.7412028993879, 39.18132264273507, 36.572037833077566, 37.69699287414551, 37.10062551498413, 38.46749946049282, 41.86266721997942, 44.541249888283865, 43.1034973689488, 43.67914172581264, 41.681322710854666, 40.31057167053223, 37.68653583526611, 38.8657945224217, 38.81131717136928, 40.74191583905901, 35.671120507376536, 37.89219903945923, 63.46189989362444, 51.95596095493862, 47.09565087727138, 41.80561556134905, 44.471816539764404, 42.97946507590157, 47.06832013811384, 45.52090767451695, 51.30991050175258, 50.55951547622681, 47.70910038266863, 48.73162855420794, 49.81495346341814, 48.958601883479524, 48.1055645942688, 48.19419928959438, 47.377594879695344, 46.99952949796404, 44.11483546665737, 44.779889242989675, 42.66848802566528, 42.10664626530239, 42.02959769112723, 42.56789895466396, 41.3753205708095, 42.758039883204866, 42.59295415878296, 45.7506741796221, 44.514589650290354, 47.286726338522776, 46.09302582059588, 47.48654610770089, 51.157915183476035, 59.97106238773891, 60.21506922585623, 61.03262901306152, 61.271549769810264, 61.451501165117534, 60.709225109645296, 63.7895838873727, 62.823506355285645, 65.27603285653251, 64.7168835231236, 62.93650490897042, 60.03929369790213, 62.33664608001709, 59.786004066467285, 69.30590466090611, 69.78638648986816, 76.36838722229004, 64.7669244493757, 54.111372062138145, 0.23918489686080388, 7.310150231633868, 73.21949836186, 63.89382076263428, 53.63120985031128, 46.74885933739798, 50.72605684825352, 25.89463336127145, 34.759826047079905, 5.330622349466596, 0.7163771880524499, 0.10427692918373005, 0.22052720588232788, 0.07170986064842769, 0.03146977562989507, 0.07900449886385884, 0.04207296755963138, 0.053177674899676015, 0.221175274678639, 0.11454785269285951, 0.27219103862132343, 0.11278567010802881, 0.2718057121549334, 0.14126811389412197, 0.3455658884985106, 14.669118506567818, 69.93950394221714, 74.31433991023472, 43.35261460712978, 38.64165953227452, 51.37188148498535, 67.46123436519078, 57.128981658390586, 67.41527203151158, 81.96750967843192, 43.68133735656738, 0.27789939088480814, 3.1049352075372423, 6.654599853924342, 64.66006810324532, 62.40348775046212, 70.60120173863002, 68.7687463760376, 70.6985251562936, 72.28018529074532, 71.43328326089042, 64.05977153778076, 70.35404736655099, 68.51018306187221, 67.44596222468785, 65.31250395093645, 66.9919182913644, 55.48857797895159, 53.70477737699236, 48.20167555127825, 48.969621726444785, 48.55353232792446, 51.60761301858084, 48.96858297075544, 48.145752974918906, 48.37334469386509, 48.153632232121055, 46.369154180799214, 43.751399517059326, 44.47613137108939, 45.32962376730782, 45.479145526885986, 47.379609857286724, 49.1221798488072, 47.86602892194475, 49.45685373033796, 53.78479978016445, 53.233891010284424, 53.83360045296805, 53.40289551871163, 55.4342291695731, 51.940907682691304, 57.53014980043684, 56.601623807634624, 57.931818212781636, 58.3734769821167, 59.56505829947335, 53.32395703451974, 53.96792997632708, 51.59000628335135, 51.92446824482509, 52.77404533113752, 55.83511243547712, 52.7251786504473, 53.36998190198626, 51.6003417287554, 51.56424931117466, 48.94161353792463, 42.70000158037458, 38.55003016335623, 44.29451240812029, 45.149213790893555, 44.554413250514436, 45.944587979997905, 46.71252373286656, 45.824064527239116, 44.98761258806501, 41.26454891477312, 40.82119131088257, 41.230516638074604, 39.912019525255474, 41.03971215656826, 42.15931361062186, 40.69066245215279, 40.446742466517854, 41.247418131147114, 40.38512931551252, 44.020729064941406, 45.04592881883894, 44.70140586580549, 46.927330766405376, 45.093603883470806, 43.01102726800101, 37.98364428111485, 40.18487180982317, 43.3376064981733, 40.30032655170986, 37.23297132764544, 40.34546899795532, 60.884236335754395, 54.7222854750497, 50.79564653124128, 44.609206744602744, 48.35126331874302, 46.5495537349156, 50.06181253705706, 48.67208596638271, 53.83805077416556, 52.57998561859131, 50.05277640478951, 50.38975708825247, 51.75431380953108, 52.60755259650094, 50.54635558809553, 48.25713259833199, 52.442890712193076, 48.24024500165667, 45.26188925334385, 47.70344107491629, 45.99779033660889, 44.173846517290386, 43.23893165588379, 44.62992279870169, 45.447896003723145, 47.62116745540074, 46.15920046397618, 48.1087920325143, 45.64723287309919, 48.40122781481062, 47.99079772404262, 49.83414438792637, 53.48870924540928, 63.86262335096087, 64.9599176134382, 63.346198490687776, 62.59313883100237, 64.49133804866246, 63.22387545449393, 66.45478779929024, 64.47161906106132, 67.08769920894078, 65.85550567081997, 64.44944735935756, 62.34206567491804, 63.18346473148891, 61.061887877328054, 72.1084258215768, 71.108489717756, 77.2692003250122, 65.46604524339948, 57.69697257450649, 0.4936343346323286, 8.768474629947118, 81.13447625296456, 67.79699911390031, 61.43755613054548, 56.84970229012625, 61.422304834638325, 35.85294444220406, 53.97615664345877, 18.09913148198809, 1.2497371967349733, 0.27318338251539637, 0.38808994953121456, 0.24206953921488353, 0.1694987669054951, 0.15083773753472737, 0.25332521381122725, 0.38192353184734074], [0.10363269411027431, 0.05748263693281582, 0.01650075537950865, 0.058460561957742484, 0.09960366852049317, 0.06057162689311164, 0.5293541550636292, 2.2609483812536513, 18.75600549152919, 44.08193574632917, 39.39863797596523, 25.558283226830618, 38.509911264692036, 54.24372134889875, 44.91897480828421, 48.537200587136404, 70.27765887124198, 41.52897303444998, 0.33868844753929545, 0.3762921525963715, 2.670669104371752, 49.711821351732524, 58.45531286512102, 68.58407020568848, 62.788494382585796, 64.68915326254708, 62.78866113935198, 63.61667101723807, 61.046136311122346, 62.9415215083531, 58.82730552128383, 62.31679507664272, 60.70081778935024, 55.38937854766846, 47.99786751610892, 45.82488094057356, 42.827223096575054, 43.86944246292114, 44.09809030805315, 42.91555207116263, 42.91432918821062, 43.66064214706421, 44.46224192210606, 44.51878636223929, 40.570826871054514, 36.96172407695225, 39.43392092841012, 41.56733751296997, 43.08079065595354, 44.77744000298636, 44.5545973777771, 45.89392171587263, 45.61299909864153, 48.50367552893502, 47.14870037351336, 44.793778691973, 48.106384481702534, 50.9363614491054, 51.516376222882954, 53.371576513562886, 54.09573514120919, 53.09278351919991, 52.800493649074006, 52.31758689880371, 52.681436266217915, 49.88083975655692, 48.683956963675364, 46.261147907802034, 48.870596000126426, 48.48763561248779, 48.69967378888811, 42.451940468379426, 40.325319222041536, 69.55285058702741, 43.44926404953003, 36.65838309696743, 37.712066990988596, 35.54407269614083, 40.62522431782314, 38.282597473689485, 42.622115748269216, 45.21365485872541, 40.264703137534006, 41.12595667157854, 38.88988045283726, 38.63128587177822, 37.60685389382498, 38.20469079698835, 38.987460953848704, 39.32847506659371, 36.22394003186907, 36.56765004566738, 37.13156236921038, 38.41990777424404, 41.21028000967843, 41.3994516645159, 41.36926868983677, 40.33915308543614, 42.576090880802695, 37.704166889190674, 37.83610275813511, 37.54776988710676, 35.211101123264854, 35.90882880347115, 37.48443358285086, 42.073413031441824, 60.22353907993862, 43.77714259283883, 42.58543273380825, 43.25268908909389, 42.746276582990376, 40.68032700674874, 42.90715864726475, 48.063868454524446, 48.8065162386213, 49.25121137074062, 51.20861618859427, 48.74823822293963, 51.16922337668282, 48.35096802030291, 46.17304474966866, 48.29045615877424, 45.858774253300254, 43.316497870853965, 40.95533323287964, 43.07700388772147, 40.337075574057444, 40.48784800938198, 37.14450338908604, 39.37490292957851, 37.889631680079866, 35.92089435032436, 39.21083511625017, 43.705332960401265, 42.25130081176758, 42.69139971051897, 43.418938636779785, 43.3309188570295, 44.991920471191406, 52.49337979725429, 55.66417632784162, 56.744881766183035, 55.4561368397304, 54.920614855630056, 55.15405695778983, 55.86412811279297, 59.92093113490513, 59.87285654885428, 62.15168503352574, 60.355867522103445, 56.56149101257324, 56.81029905591692, 57.95403160367693, 63.454451424734934, 65.67531108856201, 70.20433453151158, 60.97502844674246, 46.34279618944441, 0.14880404594753469, 3.7415445787566046, 67.34649876185826, 57.94005530221121, 51.18671894073486, 37.68786294119698, 40.44431407111031, 22.364562852042063, 29.71863351549421, 1.6333832847220557, 0.16129453214151518, 0.12747764959931374, 0.037598504086158106, 0.1062225808522531, 0.045694149498428614, 0.028208254570407525, 0.04695662157610059, 0.12207649728017193, 0.10629624939922776, 0.048646360369665284, 0.08470242204410688, 0.02366528789778905, 0.06096141133457422, 0.15324703896684305, 0.4999078522835459, 2.971956240279334, 29.59209987095424, 60.33549540383475, 39.51825816290719, 13.652336495263235, 39.98156404495239, 66.05247320447648, 49.73049463544573, 60.1149456841605, 76.70158113752092, 48.44046081815447, 0.23384314349719457, 0.10104742140642234, 3.4863656886986325, 57.56696135657174, 60.8856120790754, 72.98755359649658, 67.10056727273124, 70.6692454474313, 66.52264390672956, 69.39406340462821, 65.09305204663957, 66.99080657958984, 61.431024823869976, 66.31064741952079, 63.19845199584961, 58.95188672201974, 49.273150307791575, 50.09136322566441, 46.666755948747905, 47.996234689440044, 45.521171706063406, 46.849809714726035, 44.72862195968628, 47.78511714935303, 45.87127753666469, 48.38800539289202, 43.05099330629621, 40.66300514766148, 41.61041981833321, 45.23107051849365, 45.759022440229145, 46.46141236168997, 46.54942519324166, 48.313656193869456, 48.12684345245361, 51.303486892155235, 50.575968810490195, 46.759830542973106, 50.957678522382466, 54.11825425284249, 54.84143665858677, 56.676539284842356, 55.46124029159546, 54.12787055969238, 56.381939138684956, 55.05222068514143, 53.20871421269008, 53.25117465427944, 50.378671237400596, 52.08533293860299, 49.79153803416661, 51.05162858963013, 50.244477203914094, 45.860653741019114, 44.75393424715315, 62.51305389404297, 45.446019990103586, 39.53058426720755, 38.65037604740688, 38.43385280881609, 40.185663904462544, 39.96685470853533, 44.358411516462056, 45.5621452331543, 43.38281147820609, 43.128556047167095, 41.842392376491, 41.34514454432896, 39.70843383244106, 40.029989515032085, 41.09530816759382, 41.82095718383789, 36.81063897269112, 36.88618673597063, 38.884043966020855, 38.2121079989842, 43.638890811375205, 43.44243049621582, 42.839101042066304, 42.35992200034005, 44.486685684749055, 37.94942440305437, 41.27023948941912, 37.34164810180664, 37.9892167363848, 37.38749231610979, 38.757517269679475, 42.521175793239046, 65.16987133026123, 51.7820405960083, 40.80773959841047, 46.316931520189556, 43.44936827250889, 42.90354905809675, 44.53226586750576, 49.96348857879639, 50.56358017240252, 53.19808694294521, 53.341483865465435, 53.78295850753784, 52.794285433632986, 50.62056582314627, 49.86883326939174, 50.63280160086495, 48.39842421667916, 46.12918424606323, 42.74135378428868, 45.04165915080479, 42.038925647735596, 43.73032563073294, 40.534348828451975, 40.761502810886924, 39.11159746987479, 40.59017760413033, 42.09693963187081, 46.76219640459333, 44.991857937404085, 45.529429640088765, 44.15153585161482, 47.08126810618809, 47.88642883300781, 56.33535494123186, 58.202335902622764, 62.02980668204171, 58.06140906470162, 57.649151597704204, 57.49292482648577, 60.24320248195103, 61.975325856889995, 64.70909459250313, 65.26064954485211, 64.34482833317348, 59.64298929486956, 61.64202077048165, 60.42505768367222, 69.14492184775216, 67.78924492427281, 75.1362840107509, 65.21934250422886, 55.777824538094656, 0.11655485071241856, 4.678703708308084, 69.95988300868443, 67.10443047114781, 53.78331286566598, 49.88558190209525, 47.45144380841936, 30.832089287894114, 53.746449198041645, 4.712308236530848, 0.26474102267197197, 0.1814496141991445, 0.1436403537435191, 0.0643142360661711, 0.029280652025980607, 0.04087371798232198, 0.07958077186984674, 0.10883677271859986, 0.1902169380337, 0.13930017235023634, 0.1780702383922679, 0.24945224449038506, 0.2396045300577368, 0.20600050395088537, 0.7328119033149311, 2.431383784328188, 42.878125599452424, 77.18653065817696, 53.200894015175955, 39.36329596383231, 47.339230401175364, 71.6738646371024, 55.28539528165545, 63.71972669873919, 80.37050097329276, 51.19034937449864, 0.6243920496531895, 0.9302703163453511, 4.588366704327719, 62.809408460344585, 61.69410446711949, 71.79792472294399, 67.24326242719377, 72.98518426077706, 68.22320161546979, 69.32925755637032, 66.0397093636649, 70.46239062717983, 63.248895917619976, 69.0724868774414, 65.96992860521588, 61.13166168757847, 52.37817866461617, 51.28669309616089, 47.90701287133353, 49.71519817624773, 49.31551694869995, 49.22530153819493, 48.36945717675345, 49.950933183942524, 49.51667424610683, 51.52720151628767, 45.9455155645098, 43.894139834812705, 43.24628632409232, 47.566797801426475, 47.99443858010428, 50.47976752689907, 48.72740404946463, 50.52595567703247, 49.10973909923008, 52.9055677822658, 52.9211699622018, 48.854913915906636, 52.0419796534947, 55.67554358073643, 57.267323766435894, 59.94914776938302, 59.46254457746233, 58.603768076215474, 58.055666378566194, 57.40660735539028, 55.54677956444876, 55.45934343338013, 53.2465158871242, 53.42082187107631, 53.70008386884417, 55.08351884569441, 51.52624266488211, 48.73131588527134, 48.27012572969709, 64.90925829751151, 54.135391984667095, 41.790895802634104, 41.01330900192261, 40.585438932691304, 45.075458662850515, 42.82771989277431, 47.31246941430228, 49.58081306729998, 45.100868225097656, 45.228037629808696, 45.55759416307722, 42.926773411887034, 43.75073248999459, 41.7928968838283, 44.54263257980347, 43.452741622924805, 40.4392523084368, 39.63008941922869, 40.26958424704415, 41.56956788471767, 45.96420274462019, 44.17359985624041, 46.42372533253261, 46.351318155016216, 47.84683799743652, 41.064089911324636, 41.56402669634138, 40.11807530266898, 39.56557192121233, 39.215782233646934, 40.51056514467512, 42.091412339891704, 64.46873555864606, 54.536497592926025, 46.57254184995379, 47.590998377118794, 47.15468972069876, 46.43939699445452, 48.35957336425781, 51.65438481739589, 55.05291550500052, 53.91984844207764, 56.7510587147304, 52.24997050421578, 54.40217154366629, 52.195840563092915, 52.513543469565256, 52.29022141865322, 49.98124817439488, 46.715532302856445, 44.47962284088135, 46.9190867287772, 44.17723376410348, 47.12024402618408, 42.46703542981829, 44.16711718695504, 41.32719039916992, 41.870362349918906, 44.34288229261126, 51.292126587459016, 47.49036066872733, 47.609675134931294, 47.299101080213276, 48.9881352015904, 48.99204356329781, 57.47580099105835, 61.77997030530657, 63.503415380205425, 59.8925963810512, 60.18262113843645, 60.17152486528669, 62.99501568930489, 63.84646184103829, 66.70771612439836, 65.88222844260079, 66.38358960832868, 61.00409970964704, 64.08659853254045, 61.53523390633719, 73.02167619977678, 68.50317232949394, 76.77142442975725, 67.32766914367676, 59.920590673174175, 0.47869299352169037, 5.763303177697318, 78.38632474626813, 70.21954413822719, 64.32271916525704, 59.50121825081961, 55.77311365944998, 35.495911257607595, 70.26878602164132, 9.565595422472272, 0.37382269224950243, 0.283847021737269, 0.27568869665265083, 0.1883585120418242, 0.21323581784963608, 0.19050959018724306, 0.21212221974773066, 0.1823534092732838], [0.07253708304571253, 0.0371204727728452, 0.015898781163351874, 0.06545906034963471, 0.05891636785651956, 0.042866894243551154, 0.09206192820732083, 0.28939768246241976, 7.773803523608616, 28.313177960259573, 42.911980697086875, 34.16182586124965, 43.96527549198696, 50.82513121196202, 45.53483533859253, 40.38543503625052, 67.7858750479562, 42.61458042689732, 0.18519906300519193, 0.4224887437054089, 5.513077701841082, 47.45312179837908, 62.491097586495535, 65.48299189976284, 61.72871344430106, 61.21696472167969, 62.73867579868862, 62.61334419250488, 63.89289665222168, 62.263940129961284, 60.47921889168875, 61.511158398219514, 59.02563490186419, 49.59940644672939, 45.18809243610927, 45.862196241106304, 42.942010811397004, 42.5486489704677, 44.22450583321707, 44.862930638449534, 40.97017805916922, 43.48094783510481, 43.406067098890034, 43.594936507088796, 40.353883266448975, 37.0992671421596, 37.616966996874126, 39.848478249141145, 42.442265101841514, 46.08528552736555, 45.4393184525626, 45.598922048296245, 46.1926907811846, 49.8021514075143, 47.2012357030596, 45.04139859335763, 48.34119537898472, 50.83399363926479, 53.02794292994908, 50.7435975755964, 53.09934261866978, 48.9666166305542, 49.083638191223145, 49.777620792388916, 52.16912473951067, 47.88597025190081, 50.22257995605469, 45.188686507088796, 47.58904593331473, 49.8222108568464, 46.62163782119751, 55.904274804251536, 46.42765801293509, 48.97189378738403, 40.09616763251168, 36.65815380641392, 37.97503546306065, 35.865201064518516, 38.52664600099836, 38.2635281426566, 41.2471193586077, 42.220596722194124, 40.642316886356895, 42.432551520211355, 40.48153557096209, 38.9422663961138, 38.164707388196675, 41.040327072143555, 41.21319825308663, 40.4857566016061, 36.88418912887573, 35.908189569200786, 38.10059983389718, 38.19732223238264, 42.12820652553013, 41.76935638700213, 43.98134320122855, 40.26768044063023, 37.99176672526768, 37.13581466674805, 37.49651302610125, 38.293968200683594, 38.04971817561558, 34.231012548719136, 38.24009186880929, 53.19390412739345, 65.02448722294399, 63.40514700753348, 44.63044391359602, 48.00239774159023, 43.61042056764875, 43.12230266843523, 43.69540051051548, 48.6434211730957, 49.51622608729771, 49.3870347567967, 55.68874168395996, 52.319132872990195, 51.693339892796104, 51.70805270331246, 48.08919811248779, 49.45733315604073, 47.84809562138149, 45.69595711571829, 40.72544860839844, 44.718012060437886, 42.714631012507844, 41.13455159323556, 37.28757722037179, 37.59634821755545, 38.00076116834368, 37.820198331560405, 39.335485798971995, 42.87523167473929, 41.591138567243306, 41.421915190560476, 43.534164088112966, 43.49640410287039, 43.597326687404085, 47.496079036167686, 51.387379441942485, 51.76726177760533, 53.48169503893171, 52.254212379455566, 50.22632156099592, 52.45262166431972, 55.86891194752285, 60.505865233285085, 61.594606263296946, 60.534033230372835, 55.57613570349557, 57.599468503679546, 58.103028774261475, 62.788529123578755, 63.84910215650286, 69.81920283181327, 62.089839117867605, 50.9015405518668, 0.29339577364070074, 3.6384658813476562, 64.0190759386335, 56.732652936662944, 46.17991304397583, 46.976055009024485, 28.938762494495936, 22.532818692071096, 41.841933795383994, 3.4390651753970554, 0.1959197534514325, 0.16918103609766277, 0.16603751906326839, 0.07415443911616292, 0.04263419405158077, 0.0259986544759678, 0.0830568592729313, 0.05071789724752307, 0.0646685738382595, 0.03288977639749646, 0.03306761703320912, 0.04273221522037472, 0.043886043663535795, 0.07899759816271917, 0.19323842733034066, 0.2944460101425648, 12.958103758948189, 43.9827641078404, 49.429602895464214, 22.950910908835276, 39.155475343976704, 60.70346505301339, 51.055338927677695, 49.351765700748985, 71.98542186192104, 50.64044114521572, 0.12894348880009993, 0.10065894653754574, 8.770420125552587, 55.365417684827534, 63.683213915143696, 70.99039118630546, 65.48165089743478, 66.03869492667062, 65.82182775224958, 67.16087763650077, 64.43103463309151, 65.6974549974714, 64.8311049597604, 65.41552489144462, 61.67230796813965, 53.329710142953054, 48.160167012895855, 48.626179218292236, 46.82725238800049, 48.982767718178884, 46.56455489567348, 46.22339834485735, 45.91164309637887, 47.797874041966026, 45.98624243055071, 46.61845554624285, 43.180556365421836, 40.814319542476106, 40.579185553959434, 42.16753332955496, 43.78735644476754, 48.912632601601736, 48.86268547603062, 46.54700027193342, 46.66325405665806, 52.22043718610491, 49.7599549974714, 47.682916096278596, 50.58018636703491, 54.10943004063198, 53.89098562513079, 53.47247130530221, 53.70008734294346, 52.66797413144793, 51.63096243994576, 53.368237904139924, 52.638360909053254, 52.97533811841692, 53.27900913783482, 49.59807586669922, 49.397592544555664, 50.50134515762329, 48.78047439030239, 54.81349795205252, 49.64850589207241, 49.45241730553763, 40.77407210213797, 40.57202543531145, 38.753223282950266, 40.02426419939314, 38.41671855109078, 39.81527280807495, 44.77510888235909, 43.243190901620046, 43.137887477874756, 43.989093916756765, 42.883673736027305, 40.802948815482004, 40.142050061907085, 41.86169794627598, 42.31266382762364, 42.5967687198094, 38.46504674639021, 38.83887025288173, 39.30538967677525, 41.37812416894095, 44.19579587663923, 42.90012012209211, 45.39547184535435, 42.417939458574565, 38.59921646118164, 38.10605764389038, 38.52658346721104, 39.313592025211875, 40.34177950450352, 39.367760181427, 40.16537863867623, 51.01401104245867, 57.28593451636178, 67.48140498570034, 54.786531993321006, 49.83752816064017, 43.968179838997976, 44.59851694107056, 46.962040492466514, 51.47756011145455, 52.2612578528268, 52.372540201459614, 56.82377161298479, 55.81723472050258, 54.96797725132534, 54.36792387281145, 49.87998512813023, 51.9337614604405, 49.747969354902, 48.50809110913958, 42.701366901397705, 47.668192863464355, 43.68973078046526, 44.29591594423567, 40.237004143851145, 40.87628010341099, 40.41761909212385, 40.604021889822825, 40.81585162026541, 44.33152198791504, 43.701035499572754, 45.312322752816335, 46.13603169577462, 46.79736123766218, 47.321137292044504, 51.64223936625889, 53.467624936785015, 56.09077835083008, 55.06590516226632, 55.99781492778233, 51.59672866548811, 57.072531018938335, 57.94735091073172, 64.25475883483887, 63.13117953709194, 65.15603051866803, 58.68036501748221, 61.27156366620745, 60.319542339869905, 69.03515420641217, 66.48875059400285, 75.77763748168945, 66.30622836521694, 60.38529314313616, 0.2952822638409478, 5.405650300639016, 71.57005160195487, 62.38468592507498, 47.7613091468811, 54.28876999446324, 37.058258874075754, 25.158320597239904, 58.18331173488072, 2.9098897193159377, 0.37232744534100803, 0.13596021942794323, 0.03525602139000382, 0.047353985253721476, 0.09016663740788187, 0.03790632489004305, 0.08794828930071422, 0.07086168508976698, 0.18723176393125737, 0.16120135571275437, 0.09066957434905426, 0.15285164304077625, 0.15867644548416138, 0.14312573921467575, 0.2134352528623172, 0.26298920810222626, 16.67246307645525, 65.07338864462716, 61.41310541970389, 52.81505012512207, 57.14223187310355, 67.66337135859898, 56.632814271109446, 52.90691225869315, 75.07424354553223, 54.8800755909511, 0.334830785968474, 1.1011291252715247, 10.116869841303144, 58.95080280303955, 63.380772726876394, 71.55687086922782, 66.45284230368478, 67.00730855124337, 67.54381370544434, 67.31537083217076, 68.84149401528495, 65.49585996355329, 65.44486018589565, 66.36548260280064, 64.1552745274135, 55.260010038103374, 50.67561640058245, 51.677171434674946, 48.74192578451974, 50.180001395089285, 49.30826302937099, 49.793038845062256, 47.79312147412981, 51.67232854025704, 48.733435085841585, 49.75275666373116, 47.06865017754691, 42.73041384560721, 43.17370891571045, 42.80086510522025, 45.25205060413906, 51.72783422470093, 50.691315855298726, 48.328334263392854, 49.17900916508266, 53.60008192062378, 51.52511010851179, 50.342655250004356, 51.0975318636213, 55.24767003740583, 57.5534644808088, 55.25149849482945, 56.79127141407558, 54.67335973467146, 55.21134832927159, 53.730763639722554, 56.73744371959141, 53.93420342036656, 54.935682024274556, 50.1211119379316, 51.396717820848735, 53.970174244471956, 52.60415840148926, 61.88396399361746, 53.70882817677089, 50.91928972516741, 46.16468606676374, 44.55737665721348, 41.53831141335623, 42.797939913613455, 42.59561531884329, 44.666748251233784, 46.99622910363333, 44.72962250028338, 44.94154603140694, 47.331125327519004, 47.01934576034546, 43.57261194501604, 42.69354670388358, 44.91336761202131, 43.57819482258388, 45.297575201307026, 41.23590496608189, 40.728721209934776, 40.22899634497506, 43.3183148247855, 46.402203287397114, 44.545203413282124, 47.02618278775896, 46.447137287684846, 41.92207779203142, 40.19279623031616, 39.78592014312744, 41.920406750270296, 42.30535779680525, 39.617110184260774, 42.214048045022146, 52.99281283787319, 64.18615927015031, 63.60487297603062, 55.89310210091727, 53.373195443834575, 46.556331702641074, 47.12312405450003, 49.027427264622276, 53.53087438855852, 54.759496552603586, 54.33111579077584, 60.48542363303048, 56.49255446025303, 56.995482444763184, 55.67223971230643, 52.546238218035015, 53.988361154283794, 52.636509214128765, 50.91819538388933, 43.0928179877145, 48.27183151245117, 46.17976018360683, 46.84816299165998, 41.29847696849278, 42.92276777539934, 44.172533307756694, 44.81512703214373, 42.49759013312203, 46.7579163142613, 45.26232351575579, 47.045290333884104, 47.54043286187308, 48.83162008013044, 49.12657111031668, 52.899033001491, 55.20185361589704, 57.55802597318377, 56.93639496394566, 57.79300362723214, 53.28700304031372, 59.41955607278006, 59.56057671138218, 67.20820876530239, 64.86925057002476, 68.01957075936454, 59.593670981270925, 62.98733098166329, 61.39921597072056, 71.93622861589704, 66.53978511265346, 77.76574638911656, 66.83148438589913, 64.61493955339704, 0.46869947548423496, 6.215174496173859, 78.98843479156494, 67.75586577824184, 57.37843241010393, 64.54209463936942, 41.21409109660557, 31.931978702545166, 77.85089656284877, 5.836769086974008, 0.6682628669909069, 0.23411184336457933, 0.37836591846176554, 0.10200302941458565, 0.19781628596995557, 0.13154397425907, 0.313560531607696, 0.15479880784239086], [0.01931935592022325, 0.06667628431958811, 0.04123131950785007, 0.03789988220004099, 0.00430821518446984, 0.05612669665632503, 0.022444252257368395, 0.10510014822440487, 1.301855742931366, 23.26968036379133, 44.24034077780587, 30.919869354793004, 31.484521661485942, 50.05056687763759, 46.75974369049072, 45.77833495821272, 64.60673373086112, 50.203944887433735, 1.0203135418040412, 0.2164708421166454, 6.962409394127982, 46.477612086704795, 55.69175372804914, 61.61049679347447, 62.31325844355992, 68.44436972481864, 65.90025206974575, 66.53476851327079, 64.58349895477295, 63.221394947596956, 61.963242939540315, 60.27832562582833, 54.70528323309762, 46.353402614593506, 43.00525678907122, 43.92180061340332, 42.71230684007917, 41.86183343614851, 43.41578762871878, 41.936804498944966, 42.32088354655674, 42.62288005011422, 42.33267116546631, 43.25671557017735, 40.215443883623394, 39.04224402563912, 39.01053592136928, 40.520706040518625, 41.1537355695452, 45.66036149433681, 48.07012183325631, 43.52114316395351, 45.92890242167881, 46.71898208345686, 48.91523470197405, 45.98816360746111, 48.16824776785714, 50.98235157557896, 53.00907857077462, 51.698092460632324, 53.443254130227224, 50.50688287190029, 51.3286497933524, 49.72737489427839, 51.83575364521572, 49.432701792035786, 47.66119255338396, 46.329914229256765, 45.51026998247419, 45.480215549468994, 39.89033767155239, 36.87413855961391, 31.63916424342564, 48.67396892820086, 39.90115254265921, 36.75084277561733, 37.34530285426548, 35.99996485028948, 36.213489941188264, 38.75822598593575, 40.19331387111119, 45.85501527786255, 45.72836003984724, 40.80911534173148, 43.01465770176479, 40.08126722063337, 36.649729115622385, 38.79750067847115, 41.66003690447126, 44.76754576819283, 38.07229634693691, 39.5476837839399, 40.534418310437886, 42.16865198952811, 43.53850323813302, 43.06834643227713, 49.118410451071604, 44.71633754457746, 37.62420701980591, 36.39764152254377, 36.84264932359968, 38.265296459198, 38.17921870095389, 35.783403396606445, 38.027358872549875, 47.196677684783936, 32.03111212594168, 50.27514655249459, 55.09706783294678, 47.23910338538033, 46.65180342538016, 46.53982278278896, 49.724710260118755, 50.414558683122905, 50.53026703425816, 48.88106346130371, 51.446703161512104, 52.85149342673165, 53.452609879629954, 53.359861850738525, 51.630347524370464, 51.65187651770455, 50.670433044433594, 47.206179346357075, 41.966000829424175, 44.35363115583147, 43.907998016902376, 38.17928123474121, 39.75491728101458, 36.2073199408395, 38.23572492599487, 37.60320608956473, 41.29106324059622, 40.950459071568076, 43.51040472303118, 42.13269853591919, 42.509950978415354, 44.95970862252371, 44.386450971875874, 46.57860762732369, 47.312347820826936, 49.57623767852783, 46.9670536177499, 47.79179784229824, 47.033106667654856, 50.35822268894741, 52.306751183101106, 58.87046773093087, 59.41518565586635, 59.01122433798653, 56.49347857066563, 57.86824219567435, 58.00818586349487, 62.87043448856899, 62.860526357378276, 71.82063143593925, 65.11370209285191, 54.55973931721279, 0.6330122128129005, 4.646119696753366, 71.85124519893101, 50.62370293481009, 47.80925866535732, 41.74790729795183, 30.526517936161586, 34.42305380957467, 47.57282536370413, 1.4970678793532508, 0.19340313492076738, 0.11923761532774993, 0.09984948818704911, 0.0369897428234773, 0.01264626595989934, 0.014184519266044455, 0.11848965260599341, 0.018433562380128672, 0.04908045314784561, 0.08436263884816851, 0.03866313910111785, 0.033401357874806435, 0.05259925093767898, 0.05428036555115666, 0.13521866207676275, 0.12096714680748326, 1.3725183797734124, 35.40824931008475, 57.46837336676461, 26.13015992300851, 32.29613726479666, 61.041112763541086, 53.30794838496617, 53.2132305417742, 70.48947470528739, 55.29629005704607, 1.3741182024989809, 0.2149427134011473, 7.92222659928458, 54.84343426568167, 59.52532849993025, 64.50665882655552, 64.88641956874302, 70.49957043784005, 69.47702489580426, 69.84528636932373, 67.73192923409599, 65.73766422271729, 64.45359543391636, 63.08389009748186, 57.58249058042254, 48.66175052097866, 45.172375610896516, 46.7211012840271, 45.23040001732962, 44.30151619229998, 46.70909479686192, 45.867438656943186, 45.33921922956194, 46.95825719833374, 44.33207436970302, 45.81139101300921, 43.08261455808367, 42.5159090587071, 43.225069999694824, 43.31154033115932, 44.11743756702968, 48.05964394978115, 49.71255438668387, 47.004566941942485, 45.22539036614554, 49.32364634105137, 49.87581273487636, 48.42613710675921, 50.474900313786094, 53.66810131072998, 54.92771938868931, 54.11744826180594, 55.02915613991873, 54.083596638270784, 54.644031388419016, 53.85989243643624, 54.607994556427, 52.90790932519095, 50.273906299046104, 48.47620235170637, 49.88328899656023, 46.96830429349627, 40.10274410247803, 39.792757170540945, 34.90918452399117, 52.71243218013218, 42.47378213065011, 38.30170849391392, 39.38433510916573, 38.61744853428432, 38.74856798989432, 40.61283915383475, 40.956563064030235, 48.07003150667463, 48.35834353310721, 44.518577916281565, 45.670954023088726, 43.680343764168875, 39.62630959919521, 41.632511615753174, 45.82473850250244, 46.51584454945156, 41.67732402256557, 41.417395387377056, 42.649647985185894, 43.4536657333374, 45.20768983023507, 46.30722836085728, 50.85886819022042, 45.93017741612026, 39.95945487703596, 37.70558432170323, 40.13571677889143, 38.46972288404192, 39.36488710130964, 39.08325229372297, 39.183584281376426, 45.40953499930245, 32.02935423169817, 43.524558203560964, 53.43192509242466, 50.09954472950527, 48.21020099094936, 49.021743638174875, 52.24699320111956, 50.917580468314036, 50.534852845328196, 50.777056625911165, 52.411120074135916, 55.79263809749058, 54.92433909007481, 54.808648109436035, 53.4099166733878, 52.87240055629185, 53.08196169989449, 49.98696306773594, 43.99486092158726, 47.72368465151106, 45.473757198878694, 41.516309942517964, 42.29745422090803, 39.38046843664986, 40.70924540928432, 39.72565841674805, 42.89211927141462, 44.161628110068186, 44.60237666538784, 44.67289045878819, 44.71821355819702, 48.36022302082607, 45.693824018750874, 49.14942026138306, 50.205067021506174, 52.02925402777535, 50.667525223323274, 49.926666600363596, 49.3919540813991, 53.034203256879536, 55.96757984161377, 62.39405904497419, 62.63152762821743, 62.67412008558001, 58.50095558166504, 61.94874899727957, 60.125367982046946, 65.52487564086914, 64.49532631465367, 76.70761217389787, 68.51201043810163, 64.73027965000698, 0.6369048867906842, 5.799743873732431, 77.09532860347203, 56.528177874428884, 49.95514726638794, 50.51741286686489, 37.058766092572895, 39.59295129776001, 61.981732095990864, 1.742730777178492, 0.1332285324377673, 0.08145143863345895, 0.07398164338831391, 0.03602023163278188, 0.039843301488352675, 0.049357726305191, 0.08702830438102994, 0.029049522642578398, 0.11617531893508774, 0.18437169811555318, 0.13925870028989656, 0.10639615011002336, 0.15788215239133152, 0.2252921230558838, 0.19880059600940772, 0.2432129250041076, 2.105804226228169, 52.76855278015137, 64.4123787198748, 44.18142352785383, 44.137691565922324, 65.84067821502686, 59.950947352818076, 58.892347608293804, 74.7071146283831, 59.59969506944929, 1.577750904219491, 0.3063071279653481, 10.767180408750262, 59.205238887241904, 60.725699288504465, 64.71138054983956, 65.07131113324846, 72.35735893249512, 71.12875066484723, 71.34942545209611, 67.93630354745048, 65.94027369362968, 65.66038635798863, 67.04097952161516, 58.205990655081614, 51.65252270017351, 48.792904717581614, 50.69318839481899, 46.832539967128206, 46.16416147777012, 49.520235197884695, 46.79968193599156, 47.45692246300833, 49.551356179373606, 47.62117787769863, 47.457825728825156, 44.77423340933663, 44.846998419080464, 45.93809488841465, 45.635486943381174, 46.07698243004935, 50.3964968408857, 53.38902691432408, 47.95544876371111, 48.37827444076538, 50.40333734239851, 52.46059124810355, 48.78132207053048, 52.48500026975359, 57.92693362917219, 56.71091897147042, 54.59202412196568, 58.44657897949219, 56.18031631197248, 56.15598372050694, 56.62286792482649, 57.73975958142962, 55.59179694311959, 52.42185851505825, 52.47287218911307, 50.669095516204834, 48.609746728624614, 42.24422754560198, 42.375628403254915, 42.1496764591762, 51.92050082342965, 46.00784090587071, 41.543192522866384, 43.726194926670615, 40.47189841951643, 41.3272841998509, 42.66049412318638, 43.18923813956124, 50.276147093091694, 50.400933265686035, 44.69134834834507, 49.44985689435686, 46.254762513296946, 41.4995995249067, 42.605829170772004, 48.15863840920584, 49.42776509693691, 43.05834102630615, 44.1610757282802, 45.787617751530235, 45.96901089804513, 47.38493912560599, 47.76318516050066, 53.90283925192696, 49.72393206187657, 40.892618792397634, 40.14002466201782, 40.4801459312439, 41.348219122205464, 40.66458933694022, 40.977546623774934, 39.361638818468364, 52.19954742704119, 44.31101785387312, 46.65441247395107, 54.60753597532, 51.80647393635341, 52.30461113793509, 50.396792139325825, 54.81902871813093, 55.39730296816145, 53.06009919302804, 50.85860068457467, 53.9776748248509, 58.294753892081125, 56.956318923405235, 58.317134039742605, 55.74793686185564, 55.43723773956299, 55.88088369369507, 50.16476746967861, 43.5281399999346, 48.039515018463135, 48.41785485403878, 44.467717102595735, 44.564745221819194, 41.64565413338797, 44.53824826649257, 42.64776502336775, 46.755852699279785, 46.230537618909565, 47.543149607522146, 46.75635644367763, 47.54089839117867, 51.32153136389596, 47.806493282318115, 52.60227196557181, 52.32579272133963, 55.91378688812256, 52.434730052948, 52.46740048272269, 52.71988412312099, 56.04501404081072, 57.49269553593227, 65.90216977255685, 65.43666131155831, 65.32693535940987, 60.56684957231794, 66.47383975982666, 62.949199267796104, 69.55368437085832, 64.64204447610038, 81.70128944941929, 70.97948946271623, 65.08278955732072, 0.9404287998165403, 6.627318186419351, 83.08834443773542, 63.46966103145054, 59.94033745356968, 61.59744112832205, 42.11917386736189, 51.08941984176636, 70.36262144361223, 3.3035105977739607, 0.35219164724860874, 0.2166671965803419, 0.22730620498103754, 0.09146970962839467, 0.16241707333496638, 0.14892258601529257, 0.16827399762613432, 0.15556868724524975], [0.06603619509509631, 0.039607018631483824, 0.0490013868547976, 0.06256070480282817, 0.05243890293474708, 0.18209389677005156, 0.0035952538434815195, 0.1976781226694584, 0.25392284031425205, 11.508982249668666, 47.651916708265034, 29.449210166931152, 20.99511981010437, 43.205868652888704, 45.4237961769104, 46.376769406454905, 60.0731383732387, 56.30884061540876, 2.899566433259419, 0.7369189400758062, 4.584617282663073, 37.86246074948992, 56.71150609425136, 63.58311816624233, 67.95716203962053, 63.13850293840681, 65.53180994306291, 65.1026336124965, 62.738112994602744, 59.90362317221505, 60.86018167223249, 56.82279886518206, 49.372311523982454, 43.074353149959016, 42.377035413469585, 43.87518514905657, 43.04171398707798, 41.543974195207866, 42.415101119450156, 42.55538872310093, 42.92804840632847, 44.544883796146934, 41.49855729511806, 42.04203496660505, 41.132724217006135, 37.30565990720476, 38.11035510471889, 40.199796540396555, 43.400081225803916, 45.86324194499424, 47.3890837260655, 46.37193693433489, 45.234294482639854, 45.725657190595356, 47.580836636679514, 46.295749936785015, 48.78214543206351, 49.76097985676357, 51.83871010371617, 51.91579341888428, 52.78903954369681, 53.458158016204834, 49.32979202270508, 50.717913559504915, 50.00888116019112, 50.39511414936611, 46.48018292018345, 46.49354778017317, 45.84472499574934, 52.54434135981968, 43.96066536222185, 44.65419633047921, 33.196252073560444, 35.630140032087056, 41.66350752966744, 35.54610851832798, 39.645059313092915, 36.18613140923636, 38.63496841703142, 39.22084747041975, 41.102582931518555, 44.000721727098735, 49.59929527555193, 46.82944107055664, 45.23940140860421, 40.391605036599294, 39.19890505926949, 42.19491965430123, 45.80287946973528, 46.48648146220616, 44.150667326790945, 38.60072769437517, 44.069237913404194, 42.834977286202566, 44.73608432497297, 48.79238012858799, 48.32546465737479, 42.95644221987043, 41.64404909951346, 35.930493286677766, 36.75444541658674, 36.623402391161235, 37.77568122318813, 35.093502862112864, 38.94438559668404, 33.15850598471505, 28.824226651872905, 32.16672011784145, 39.789936201913015, 47.694210393088206, 42.91062579836164, 49.9218237059457, 49.60366569246565, 53.255270617348806, 48.60701608657837, 51.00048637390137, 49.90445320946829, 52.47736072540283, 52.35422474997384, 51.40864092963082, 51.015584809439524, 53.079658372061594, 52.99615839549473, 50.31903484889439, 43.344370569501606, 43.347309657505576, 45.60735368728638, 40.181505407605854, 38.99094894954136, 33.99929707390921, 35.77211952209473, 39.26060506275722, 41.031374318259104, 41.104511056627544, 43.25031280517578, 42.41025822503226, 41.76864767074585, 43.36847039631435, 41.188170841761995, 45.63253395898001, 43.84105559757778, 45.3904378754752, 44.98148080280849, 45.64439800807408, 47.35589565549578, 46.83260597501482, 50.762805870601106, 58.26677697045462, 57.255164418901714, 60.31638090951102, 55.33965376445225, 57.04497446332659, 55.6804906981332, 59.97043704986572, 63.87986183166504, 70.17169884272984, 61.63490581512451, 64.7712323325021, 1.0795961150101252, 5.877462080546787, 74.70575278145927, 47.49155575888497, 47.979899474552695, 38.45815413338797, 35.95341886792864, 36.054146902901785, 55.99109949384417, 1.560130164027214, 0.10574227305395262, 0.05529040903119104, 0.04528925747477582, 0.06959265497113977, 0.06792079218264137, 0.05107633676379919, 0.019243885862774084, 0.05865793422396694, 0.038383487678532086, 0.04819710911916835, 0.09597118558096034, 0.03302874376199075, 0.013696250555637692, 0.11076582063521657, 0.07764691992529801, 0.1395457884562867, 0.23123936035803386, 10.794981019837515, 65.50710214887346, 29.201850822993688, 28.48185416630336, 59.408557074410574, 50.875766209193635, 50.96658263887678, 66.63908876691545, 60.462737764631, 3.3075351246765683, 0.8282922570194516, 6.069392170224871, 45.34197071620396, 61.54782404218401, 67.24726458958217, 72.74838270459855, 66.27824796949113, 68.34396825517926, 66.81314808981759, 66.93798637390137, 63.5112737928118, 63.43411404745919, 60.60723945072719, 52.13344921384539, 47.68726566859654, 45.4061929157802, 47.62705257960728, 45.901283332279746, 44.220847606658936, 46.42012269156319, 45.47631066186087, 46.72273758479527, 46.70617307935442, 45.28083004270281, 45.14252962384905, 43.264129298073904, 40.11534466062273, 39.356177534375874, 42.902899401528494, 45.43401002883911, 47.65920884268624, 48.119040625435964, 47.46820286342076, 46.3287365095956, 48.62008217402867, 49.73922157287598, 47.64934240068708, 50.920641149793354, 52.14848511559622, 54.8486384664263, 54.41848243985857, 54.9229598726545, 54.49480145318167, 51.40736593518938, 52.749014445713584, 54.48806517464774, 53.24175289699009, 48.760731084006174, 49.72292109898159, 49.43256630216326, 53.179799284253804, 48.54567738941738, 45.57263353892735, 36.39367757524763, 41.02441222327096, 45.32477739879063, 37.944359166281565, 41.063273497990195, 39.18557841437203, 39.784586088997976, 40.77710846492222, 43.830702781677246, 47.33211891991751, 52.04127441133772, 49.14641516549246, 48.11227308000837, 44.119685309273855, 41.768539973667686, 44.66635567801339, 48.13996512549264, 48.599216733660015, 46.140617506844656, 41.69378430502755, 45.70270381655012, 45.26720462526594, 47.775063105991904, 51.38217871529715, 52.11564792905535, 44.17272438321795, 42.76351158959525, 36.9350152015686, 37.59363842010498, 36.754150118146626, 40.05137607029506, 38.529776164463584, 41.68085370744978, 34.9254606791905, 29.946965217590332, 35.18222093582153, 39.694572176252095, 50.883287634168354, 45.883138111659456, 51.372545037950786, 50.83574111121041, 54.09314693723406, 51.65777901240757, 51.658852509089876, 51.03810739517212, 54.75493506022862, 55.45608125414167, 55.09948928015572, 55.04168026787894, 54.94073336465018, 52.38514423370361, 51.63518347058977, 44.79998343331473, 45.86733790806362, 48.41151114872524, 43.11128977366856, 41.18577023914882, 39.09817355019705, 38.11789390019008, 41.518418720790315, 42.5630247933524, 44.11046157564436, 46.019329752240864, 45.835039206913535, 45.008769852774485, 46.07966790880476, 44.42784833908081, 47.0446788924081, 46.68985176086426, 49.281057357788086, 47.30349928992135, 49.59083931786673, 48.927758829934255, 51.094929763248985, 52.9465308870588, 62.016014507838655, 58.94477871486119, 62.88534532274519, 57.45674555642264, 59.71541731698172, 59.0692070552281, 64.17062309810093, 66.78130449567522, 73.6604310444423, 64.7197322845459, 72.13921328953334, 1.280125034706933, 7.206246869904654, 82.65297726222447, 53.01378597532, 52.60549940381731, 46.88445690699986, 39.827512059892925, 38.34482554027012, 63.54620933532715, 1.7645479036228997, 0.13914339004882745, 0.05389807552897504, 0.09804090737764325, 0.041186410667640824, 0.07546204395060029, 0.06722956855914422, 0.01552889306497361, 0.07605238298752479, 0.14807582859482082, 0.1922238953411579, 0.11661160338137831, 0.12423001815165792, 0.11469901672431401, 0.2856250549001353, 0.14719430303999356, 0.3636828820620264, 0.44100675146494595, 21.244221414838517, 76.93366486685616, 45.33117321559361, 33.224902970450266, 57.534433364868164, 62.18147890908377, 56.81747307096209, 71.89155864715576, 65.57711219787598, 4.060056950364794, 1.0338842421770096, 7.52565382208143, 51.431788853236604, 61.13433674403599, 67.82221412658691, 74.05743026733398, 67.847658429827, 68.36593845912388, 70.68794999803815, 67.57103674752372, 65.07415294647217, 64.24533707754952, 63.642163957868306, 54.2829578263419, 48.7126738684518, 48.264073848724365, 49.255022457667756, 49.72466509682791, 48.951101303100586, 49.1276341847011, 48.159249850681846, 47.68359701974051, 50.976351806095664, 46.520986216408865, 47.65975080217634, 46.57174628121512, 40.276046071733745, 43.7251353263855, 45.53289679118565, 48.41113247190203, 51.1052235194615, 50.87485599517822, 49.27616582598005, 48.66920593806675, 50.69081905909947, 50.55563490731375, 50.09464277539934, 54.185641356876914, 53.69978509630476, 56.31038311549595, 54.301631110055105, 58.30466202327183, 58.01078448976789, 53.8355598449707, 55.98720155443464, 56.368946007319856, 56.33657782418387, 51.87058843885149, 51.014761447906494, 49.48490013395037, 56.27652106966291, 48.716912269592285, 46.100220680236816, 39.433378968920024, 40.63430561338152, 47.5032183102199, 39.93591785430908, 45.22948980331421, 41.519457476479666, 42.89549957002912, 43.850081307547434, 47.24811519895281, 50.80482162748064, 55.083157539367676, 52.152115549360005, 50.13630764825003, 46.0780211857387, 42.09324666431972, 46.83601754052298, 50.25744949068342, 50.883767059871126, 48.67906890596662, 43.89613744190761, 48.5593375478472, 47.491653033665244, 49.78125817435128, 54.7502623966762, 54.36456789289202, 45.85878814969744, 45.19987310682024, 39.8141576222011, 40.57342897142683, 40.243743896484375, 42.33764607565743, 38.99314110619681, 42.72544240951538, 41.427557127816335, 35.64361258915493, 33.63880368641445, 40.82086474554879, 52.02865995679583, 49.24602454049246, 53.52390187127249, 54.555917807987754, 57.565106187547954, 54.217064585004536, 54.407167298453196, 54.18262236458914, 54.730098724365234, 58.312041010175435, 55.726244585854666, 54.98454523086548, 57.87585047313145, 57.06327254431588, 52.089679036821636, 45.658280508858816, 45.09917286464146, 49.71618482044765, 43.78984389986311, 42.73617042813982, 41.68264981678554, 40.98275777271816, 45.07127584729876, 46.02073328835623, 47.24286930901663, 48.53980268750872, 47.93170329502651, 47.052825655256, 48.23255681991577, 46.58761944089617, 50.18546962738037, 48.587356158665244, 51.60251304081508, 49.09633949824742, 52.04920230593, 49.546124185834614, 53.41876867839268, 53.28749636241368, 64.23187841687883, 60.387662478855674, 67.04457868848527, 58.775742939540315, 62.73101888384138, 59.60452406747, 65.9151142665318, 68.27863434382847, 76.62506062643868, 67.86040142604283, 75.55005618504116, 1.6371637561491557, 7.976836834635053, 87.73673793247768, 59.173013142177034, 61.529793466840474, 53.50725051334926, 51.09793138504028, 49.93501486097063, 75.11279909951347, 2.267649267401014, 0.2407008255166667, 0.1556455245507615, 0.17752437054046563, 0.1545873356184789, 0.19199043858264173, 0.2009928748011589, 0.19916937979204313, 0.1587004791945219], [0.08098611967372042, 0.030277403004999672, 0.03593852583851133, 0.07686830777674913, 0.06479695266378777, 0.021340864411156093, 0.029206562787294388, 0.1389666045350688, 0.10898802495960679, 0.9636357831103461, 44.91724123273577, 43.17601919174194, 19.87685935837882, 28.799557072775706, 53.030694416591096, 44.074546337127686, 60.2433761869158, 57.38067667824881, 3.9162288052695136, 0.8447885832616261, 6.329336438860212, 55.293344020843506, 64.0657400403704, 65.16381250108991, 65.98858451843262, 65.31837517874581, 62.4931195122855, 64.18030193873814, 62.126525606427876, 60.308522496904644, 57.56249713897705, 51.97810138974871, 46.24221754074097, 45.02493483679635, 44.35482277188982, 41.189449310302734, 42.207759925297324, 41.83138990402222, 42.14800541741507, 42.06301852634975, 42.26095533370972, 42.60385240827288, 41.73429230281285, 42.428615365709575, 39.78093481063843, 40.33642244338989, 38.61347416469029, 40.63535131726946, 41.83323812484741, 44.09609964915684, 47.20754814147949, 46.540993554251536, 43.76447950090681, 44.52459505626133, 43.735707010541645, 46.99902922766549, 49.99327550615583, 52.57074104036604, 52.87607962744576, 54.297764437539236, 51.56826536996024, 51.63999162401472, 51.25911569595337, 51.57962220055716, 50.483186040605815, 47.974135943821494, 43.797841276441304, 51.69263812473842, 51.3647700037275, 53.59834139687674, 52.99986525944301, 43.55282347542899, 39.611040932791575, 36.42747013909476, 41.3218229157584, 35.7586122240339, 38.09509686061314, 36.082874229976106, 38.142247336251394, 38.25786883490426, 40.55806997844151, 42.888787610190256, 49.982481479644775, 47.736844539642334, 48.026309967041016, 43.37447016579764, 42.014975207192556, 44.49713577542986, 47.64760535103934, 43.384260177612305, 47.258339473179404, 44.15015663419451, 45.797077723911826, 46.12435872214181, 48.317529814583914, 46.93038102558681, 46.546256814684185, 41.993786675589426, 38.95478010177612, 37.085905756269185, 35.43546540396554, 35.75037860870361, 38.665033272334504, 33.84823281424386, 38.57126733234951, 31.610749585287913, 29.68380219595773, 39.679873262132915, 44.82357256753104, 45.1331148147583, 45.443265029362266, 49.12167610440935, 49.77676616396223, 48.24220439365932, 50.236709117889404, 50.860949175698416, 49.975081648145405, 51.50846569878714, 51.90826504571097, 53.75633995873587, 52.369323185511995, 52.32839829581124, 54.77981308528355, 50.49020024708339, 46.7011912209647, 42.551369190216064, 47.97995853424072, 41.707201276506694, 40.33630779811314, 37.45917688097273, 35.61668831961495, 39.93356588908604, 39.87111895424979, 41.11480481284005, 42.68413536889212, 41.58445092609951, 42.61817959376744, 44.154433250427246, 43.08926745823452, 42.9698418208531, 44.67002432686942, 44.4498359135219, 43.95975167410714, 45.522088868277415, 44.55855437687465, 45.475004400525776, 49.842166083199636, 55.927315030779155, 56.861479486737935, 57.42331082480294, 55.08064923967634, 55.60405356543404, 55.463397707257954, 62.759826115199495, 62.172168322971885, 70.80752154758999, 64.18221269335065, 69.08189473833356, 1.4052580744028091, 7.936481697218759, 77.02998774392265, 43.00800132751465, 48.69583143506731, 39.68236071722848, 30.321917806352886, 42.08495051520211, 53.44879879270281, 2.2237570626395087, 0.1225528424339635, 0.12339167456541743, 0.03824136173352599, 0.006784817536494562, 0.040917527595801015, 0.04519811325839587, 0.044544402443404706, 0.026938142188425575, 0.016996192812387432, 0.0036327725891689105, 0.035380247581217966, 0.09516813260103975, 0.03895873948931694, 0.028588322390403067, 0.040474810637533665, 0.23657891526818275, 0.1439177795712437, 1.122108450957707, 56.373583929879324, 45.60154499326433, 17.426146336964198, 40.63449321474348, 60.87930311475481, 52.04402937207903, 68.25825527736119, 61.81786578042166, 4.5389085582324435, 0.8444509442363466, 9.379530480929784, 61.80595656803676, 68.47851317269462, 69.23456750597272, 70.84903703417096, 67.12669944763184, 66.57102421351841, 66.58077253614152, 66.47112301417759, 63.09320763179234, 61.61421407972063, 53.78625890186855, 47.70018931797573, 47.28725092751639, 48.7737763268607, 44.77332319532122, 45.68863371440342, 45.81325660433088, 46.295673506600515, 44.768320492335725, 44.91430214473179, 44.318528856549946, 44.3098019191197, 44.412082876477925, 43.85713720321655, 42.93890149252755, 41.824021339416504, 41.686380999428884, 43.73530401502337, 45.2278048651559, 51.789162499564036, 49.47684022358486, 44.1157352583749, 44.879978043692454, 46.49372843333653, 48.85673781803676, 52.27769381659371, 55.17842081614903, 54.49522876739502, 55.93916170937674, 54.683955737522666, 54.07740926742554, 54.65468645095825, 53.36043160302298, 52.700387477874756, 50.526921476636616, 47.228535175323486, 52.757376602717805, 55.50187335695539, 57.33976568494524, 56.34388732910156, 47.404633794512065, 41.3361987386431, 42.97112723759243, 45.39658008302961, 37.27171100888933, 40.41148383276803, 38.275197642190115, 39.227104323250906, 39.68054723739624, 40.81759909221104, 46.194441727229524, 51.46436200823103, 50.13555029460362, 49.145577907562256, 47.15615579060146, 45.54829747336251, 45.85903133664812, 48.41635404314314, 45.047005789620535, 48.624271937779014, 47.84432969774519, 47.07350696836199, 48.54341227667672, 50.06900044849941, 49.95880201884678, 47.87128523417881, 43.43312685830252, 40.43546206610543, 37.99507059369768, 37.074826853615896, 37.0117233140128, 38.77615581239973, 37.494400773729595, 39.6285469191415, 34.128905296325684, 31.9103559085301, 38.909255504608154, 47.006581919533865, 47.97831528527396, 47.525879859924316, 51.53273228236607, 52.25812074116298, 50.91640622275216, 50.94822897229876, 53.431146894182476, 51.727730001722065, 54.86177403586251, 53.00131048474993, 56.272921902792795, 52.20283392497471, 53.42436892645699, 57.062730584825786, 53.95043093817574, 47.46819244112287, 44.68327801568167, 49.68443850108555, 43.08337191173008, 43.158294337136404, 41.03837810243879, 40.091894490378245, 43.15523712975638, 41.765684264046804, 43.316275528499055, 45.62795509610857, 45.20448671068464, 44.44733803612845, 47.829620361328125, 44.830138615199495, 46.82713079452515, 46.18196276256016, 47.98780305044991, 46.824761458805625, 49.41436897005354, 47.49651329857962, 48.944653374808176, 52.8973445892334, 59.483660152980256, 59.37774876185826, 60.89032990591866, 57.29780203955514, 58.682678767613, 58.09882164001465, 65.90657493046352, 64.67543057032994, 75.14451067788261, 65.63544232504708, 73.88049439021519, 1.9285760905061449, 9.386651515960693, 83.48375947134835, 47.20250722340175, 54.776780196598594, 49.38730921064104, 37.409980160849436, 44.97362586430141, 64.27011435372489, 1.463466499532972, 0.06394771180514779, 0.12123005198580877, 0.05509386457768934, 0.019558537817959274, 0.05019975094390767, 0.03682076385510819, 0.09938070191336529, 0.08478473512721912, 0.1336377840489149, 0.14977853079991682, 0.11762670533997671, 0.1579907587064164, 0.13786676712334156, 0.13215969050569193, 0.1604199819266796, 0.29359531721898485, 0.5505322100860732, 3.738536443029131, 67.69074726104736, 56.703626837049214, 29.919408661978586, 37.00177696772984, 72.57348959786552, 55.5972512790135, 73.0121293749128, 66.62666538783482, 5.088058131081717, 0.9759575447865895, 11.13713811125074, 65.62172658102853, 69.32018320901054, 70.69949790409633, 72.81054823739188, 70.11300046103341, 66.53105817522321, 68.62833023071289, 67.51297065189907, 64.95988982064384, 62.21467740195138, 56.48955283846174, 51.32131596973964, 49.87871013368879, 52.02704102652413, 46.79638501576015, 48.555714062282014, 48.14217812674386, 48.21343190329415, 45.597945826394216, 48.5502736227853, 48.73269510269165, 46.576134068625315, 46.21187823159354, 45.902474948338096, 44.84419134684971, 44.10416303362165, 45.53656891414097, 45.97091817855835, 48.608562060764854, 54.50778416224888, 50.04498052597046, 45.84649331229073, 46.94250215802874, 45.80877154214041, 51.3159693309239, 53.597677843911306, 55.86050115312849, 56.757419790540425, 57.84700502668108, 54.725478172302246, 54.2128643989563, 55.22615146636963, 56.156452723911826, 53.61556945528303, 54.97046818052019, 48.47819995880127, 53.135233538491384, 56.86504738671439, 59.9086606161935, 59.42043154580252, 47.72608872822353, 47.815557207380024, 41.929533209119526, 47.72609567642212, 40.918344497680664, 43.815454959869385, 39.166064398629324, 43.1230912889753, 41.81387349537441, 44.5312305859157, 47.68221432822091, 56.75020061220442, 53.74942650113787, 53.561908517565044, 49.178616591862266, 47.977328641074045, 47.59348930631365, 52.208281312670024, 47.317145551954, 51.22382926940918, 51.13235970905849, 50.032824652535574, 49.242963859013145, 54.10860320499965, 52.71909202848162, 51.562817982264924, 45.4872783933367, 41.97316789627075, 39.76519019263131, 38.39547790799822, 40.10480771745954, 43.05506842476981, 38.29391608919416, 42.748520851135254, 38.84713166100638, 37.70038706915719, 37.611213888440815, 45.97313117980957, 49.6484294618879, 49.77680090495518, 54.49473197119576, 56.63731322969709, 52.15318904604231, 53.585740838732036, 52.57567078726632, 53.83024099894932, 55.52195712498256, 54.5679520879473, 59.20920630863735, 55.75540964944022, 56.954352583204, 58.49136011941092, 53.17225701468331, 49.141975266592844, 44.19634478432791, 51.959042481013704, 45.67829132080078, 45.56994458607265, 44.228487151009695, 42.37281090872628, 47.53224440983364, 43.48219503675188, 46.56156022208077, 48.16330759865897, 48.27401672090803, 46.33153315952846, 50.937250818525044, 47.85783699580601, 49.26365212031773, 47.49698577608381, 50.4578355380467, 48.495851857321604, 51.3566267149789, 48.639665671757285, 49.65754549843924, 54.50341027123587, 62.620181219918386, 60.98401941571917, 64.00474875313895, 59.70270906175886, 61.014091219220845, 61.07258810315813, 69.58175509316581, 66.78595284053257, 79.58422197614397, 67.4715107509068, 78.09147793906075, 2.6856765619346072, 10.18318952832903, 91.2041461127145, 52.489273411887034, 63.291453633989605, 54.26844303948538, 45.33846535001482, 56.74715730122158, 75.76686777387346, 3.2409616112709045, 0.3431280750249113, 0.22970481270125934, 0.19316386990249157, 0.07669254006551844, 0.14444392919540405, 0.12778494453855924, 0.2482289815587657, 0.17411314429981367], [0.06668715445058686, 0.09777460952422448, 0.036536885159356255, 0.03740660759753414, 0.0159407638212932, 0.03567846372191395, 0.04777917565245714, 0.1229170121784721, 0.03538908210716077, 0.22507518183972153, 32.500581060137065, 52.428389821733745, 38.22601134436471, 22.08195182255336, 47.33233778817313, 42.504670347486226, 54.47896303449358, 60.889801842825754, 5.878787449428013, 0.8087399176188877, 25.578936747142247, 73.21940803527832, 60.723753792899, 64.96557344709123, 63.648827280317036, 63.534758704049246, 63.00743212018694, 61.16078853607178, 59.60803290775844, 58.29060581752232, 51.87255825315203, 46.4487110546657, 44.970523493630544, 43.70050743647984, 42.30145985739571, 42.78585352216448, 42.97821092605591, 43.10904203142439, 41.01132876532418, 43.34025376183646, 41.68230240685599, 42.02509525844029, 42.4282888003758, 40.250424589429585, 42.684489727020264, 40.34752566473824, 37.14709159306118, 38.31044932774135, 40.350975445338655, 44.088178702763145, 46.96134567260742, 46.00171259471348, 43.81069196973528, 44.79177761077881, 44.152390480041504, 48.85703311647688, 52.09524801799229, 50.21248074940273, 53.759206090654644, 53.57742037091936, 51.90078183582851, 53.48422418321882, 52.59816905430385, 51.94347504207066, 51.14510270527431, 46.121777466365266, 47.327088424137656, 51.17457696369716, 49.62454502923148, 52.53847360610962, 53.85808590480259, 41.745232241494314, 42.88409757614136, 34.197824478149414, 38.4217004094805, 35.80104487282889, 37.334894452776226, 34.554902826036724, 37.01101112365723, 37.190531730651855, 40.952560901641846, 46.27747617449079, 49.033163002559114, 47.41348927361624, 50.00345114299229, 43.65792540141514, 45.60034990310669, 43.55316046306065, 41.910314491816926, 39.9829397882734, 42.66105692727225, 47.47220502580915, 49.3921069417681, 47.31130906513759, 46.656472614833284, 44.567128453935894, 44.0942097391401, 42.28143514905657, 37.6352789742606, 37.31084326335362, 36.485247884477886, 34.45619671685355, 38.08662005833217, 36.748362268720356, 38.268159117017476, 32.78581850869315, 35.494212423052105, 44.12023074286324, 42.54482051304409, 48.59457533700125, 44.56355013166155, 44.5431467464992, 44.50049522944859, 48.07736880438668, 51.520774432591026, 51.448117119925364, 51.8788081577846, 51.41739913395473, 52.08881746019636, 52.715496335710796, 52.73594488416399, 50.577452250889365, 53.42265966960362, 52.759752886635916, 44.09416804994856, 45.45893669128418, 47.58260842732021, 40.629928248269216, 40.063622270311626, 37.439916474478586, 35.676015513283865, 39.72261510576521, 41.65292542321341, 41.40586832591465, 41.64414984839303, 43.00382546016148, 42.252266611371724, 43.42110994883946, 43.597635882241384, 44.36036743436541, 43.2520637512207, 45.812238693237305, 43.09299169267927, 46.08619226728167, 46.657049315316335, 48.36325938361031, 47.91070931298392, 54.20910542351859, 54.39974314825875, 56.270024503980366, 53.21833051953997, 56.39139911106655, 53.93488086972918, 61.305568150111604, 62.016153471810476, 70.5736243384225, 65.46456527709961, 69.29379395076207, 0.9111679813691548, 10.00218026978629, 75.39395795549665, 39.69316864013672, 48.453200340270996, 42.91561460494995, 31.23084987912859, 41.54565218516758, 47.60898378917149, 0.4862821634326662, 0.06898869773639099, 0.026771020709670017, 0.02280025922560266, 0.040905799118003676, 0.04009252740070224, 0.009357839290584837, 0.06009260152599641, 0.05838527171207326, 0.06390693185052701, 0.04203429784891861, 0.019275035709142685, 0.08167171824191298, 0.01003183999897114, 0.027844419004395604, 0.025117897362049137, 0.07184318599424191, 0.03413167529340301, 0.12091643310018949, 38.872683661324636, 59.44933605194092, 25.3970468044281, 28.086935928889684, 54.69178983143398, 48.83855438232422, 62.238891874040874, 66.02859919411796, 7.379930121558053, 0.9523013170276369, 34.40812907900129, 77.09106935773576, 65.36371217455182, 69.25712830679757, 68.33831242152623, 64.67595863342285, 65.53062874930245, 64.07685715811593, 62.47358117784773, 60.90072441101074, 54.757787295750205, 48.787519863673616, 48.99319001606533, 47.10052503858294, 45.74513299124581, 46.76312746320452, 46.38614252635411, 43.83608416148594, 44.85754925864083, 45.680045740945, 46.564290864127024, 45.34831442151751, 45.56440339769636, 43.43985966273716, 45.35728454589844, 44.05717584065029, 39.99134363446917, 41.823232718876426, 43.26153414590018, 45.93441929136004, 48.54160227094378, 47.29122182301113, 44.17939117976597, 46.18467950820923, 47.33325842448643, 52.22666277204241, 54.81292125156948, 52.332487310682026, 55.085506030491416, 55.544312953948975, 56.62750932148525, 55.61790827342442, 53.649299485342844, 54.221650396074565, 54.92630195617676, 48.236725739070344, 52.42510679789952, 53.92277363368443, 52.39974934714181, 54.15225873674665, 56.628235408238, 47.147995131356375, 44.70396280288696, 40.24886471884591, 43.8010687146868, 37.78252867289952, 37.56253480911255, 37.42731591633388, 39.8359888621739, 39.52277101789202, 42.346234049115864, 47.415625844682964, 50.28652422768729, 48.365441117967876, 51.575039863586426, 48.04466363361904, 47.97326047079903, 43.73749964577811, 42.71861580439976, 40.18967996324812, 44.99039881569998, 49.74386991773333, 50.367644446236746, 50.00942311968122, 47.81666544505528, 48.10983773640224, 45.99502147947039, 44.824135371616904, 40.421412808554514, 39.25145775931222, 39.42605209350586, 37.65629032679966, 40.211337498256135, 39.13924435206822, 38.94790138517107, 35.353393282209126, 37.19106674194336, 43.0638370513916, 43.39776400157383, 51.403200490134104, 46.74440901620047, 45.60521016802107, 44.565714495522634, 50.41833850315639, 53.66014562334333, 52.84909977231707, 54.77873611450195, 55.354654925210134, 55.205678599221365, 54.28414944240025, 53.67642872674124, 54.14462961469378, 55.42102064405169, 55.10077122279576, 45.561790875026155, 46.47165748051235, 50.96005828039986, 44.66927392142159, 44.56825753620693, 39.62694188526699, 38.05414417811802, 41.650674206869944, 44.512710162571494, 43.36769914627075, 43.97886964253017, 44.5987149647304, 44.46561179842268, 47.006873743874685, 45.671270166124614, 48.11894335065569, 46.72030918938773, 48.92727593013218, 45.66686153411865, 49.111875670296804, 48.87205859592983, 50.68638263429914, 50.11314582824707, 58.247467926570344, 58.23825808933803, 58.86907114301409, 55.9592558997018, 59.48599474770682, 58.18572275979178, 63.7780568259103, 63.18343693869454, 74.8726624080113, 67.19064371926444, 74.92062582288469, 1.2062515701566423, 11.827266199248177, 84.26734951564244, 47.111791542598176, 55.239405155181885, 51.76835264478411, 37.661077635628835, 44.3692124911717, 51.04910639354161, 0.30812611750194, 0.09888547313000474, 0.04749912728688546, 0.008265991628702198, 0.046028908142553907, 0.07202246173151902, 0.015836690120132904, 0.02888557840404766, 0.09676861350557633, 0.19589413196912833, 0.2047272737004927, 0.085337137271251, 0.18262892163225583, 0.12139321251639298, 0.19102405543838227, 0.10101472280387368, 0.20139597888503755, 0.17593978771141597, 0.2404741948204381, 56.06251655306135, 67.35740743364606, 54.19346502849034, 30.81959990092686, 61.88950865609305, 55.3302389553615, 64.88900429861886, 70.85602692195347, 7.519159861973353, 0.9101974048784801, 33.40759890420096, 77.94512108394078, 67.15317208426339, 70.59704671587262, 69.66847555977958, 68.18793255942208, 68.56403854915074, 65.65788500649589, 62.828522954668315, 62.1235865184239, 56.94344391141619, 52.768156732831685, 50.361203466142925, 47.853477001190186, 48.50349140167236, 49.319671971457346, 48.43311309814453, 46.8144850730896, 47.042222704206196, 48.089601108006065, 49.54346997397286, 48.360570430755615, 46.88551650728498, 45.12229299545288, 47.79148864746094, 45.544976234436035, 42.31934799466814, 43.232917990003315, 46.558784416743684, 48.612182072230745, 50.92144366673061, 49.69596208844866, 46.956256117139546, 47.2653397832598, 48.296848501477925, 55.214742524283274, 54.9830687386649, 53.003912585122244, 57.435390268053325, 58.85532760620117, 57.886231081826345, 57.78210537774222, 55.36249596732003, 56.718548093523296, 56.152995995112825, 51.01868718011038, 52.47113861356463, 53.635698386601035, 52.969268866947715, 58.09468746185303, 58.182623863220215, 46.65837642124721, 47.73257139750889, 38.77297701154436, 43.38067838123867, 40.042200974055696, 39.88049554824829, 39.938492161887034, 40.94570302963257, 42.879876545497346, 44.33079937526158, 50.97505944115775, 55.409545694078716, 54.917543751852854, 57.567979267665315, 52.036434991019114, 52.28081703186035, 47.878730228969026, 44.429036481039866, 41.860843317849294, 47.39836999348232, 53.6294276373727, 55.064487729753765, 54.11249072211129, 51.64918409075056, 52.42214339120047, 49.25449786867414, 47.695683411189485, 42.66105692727225, 42.92201042175293, 40.259822028023855, 39.2722988809858, 43.42943736485073, 42.339879921504426, 42.725814138139995, 38.67480591365269, 36.99869891575405, 44.012665680476594, 46.644674573625835, 51.95772232328142, 49.17551074709211, 47.825298581804546, 49.05173553739275, 54.385315213884624, 55.51365402766636, 54.49097299575806, 56.505043847220286, 58.0567433493478, 57.876840591430664, 54.351161343710764, 56.57524149758475, 54.74805981772286, 57.93675838197981, 56.273057392665315, 45.58553286961147, 46.62581368855068, 52.48626831599644, 46.608873980385916, 46.33749123982021, 42.61929825374058, 41.353312151772634, 44.888194288526265, 47.2956200327192, 46.11379746028355, 45.75177894319807, 47.30681358064924, 46.53953095844814, 49.27546753202166, 48.45870678765433, 49.849107333592, 49.7262145451137, 52.39150530951363, 47.7669997215271, 52.33149719238281, 50.251817975725444, 53.94327081952776, 52.9849648475647, 62.66176618848528, 60.5974702835083, 62.14690467289516, 57.195541926792686, 62.959044865199495, 59.52161816188267, 66.43090684073312, 65.3210780279977, 77.09716987609863, 69.08264514378139, 79.54026072365897, 1.7312747176204408, 12.434446692466736, 89.92767170497349, 50.86385004861014, 62.105986731392996, 56.57330642427717, 45.421586649758474, 57.72150318963187, 68.81170013972691, 1.135914412992341, 0.25224699452519417, 0.16320905940873282, 0.13874753271894796, 0.14410848862358502, 0.09344666890267815, 0.06559851965201752, 0.2438037661569459, 0.1634263941752059], [0.05127287103927561, 0.05656630592420697, 0.07521306231085743, 0.061335569114557335, 0.04654373301725302, 0.0321586006321013, 0.031986415585769076, 0.09528977357383285, 0.04989027112190213, 0.49647929625851767, 15.54781723022461, 57.62367255347115, 46.96592106137957, 29.79322590146746, 40.924837589263916, 45.06184714181082, 45.26826075145176, 70.1223805291312, 8.209025655473981, 0.14220312157911913, 56.00555869511196, 65.46281433105469, 63.21411323547363, 64.54424163273403, 61.328921045575825, 61.04135595049177, 59.53601482936314, 59.47639928545271, 56.419685227530344, 52.98842505046299, 47.661890847342356, 44.103753089904785, 45.34812682015555, 42.688863618033274, 44.09061404636928, 43.18922424316406, 41.65982845851353, 41.71114785330636, 41.59754828044346, 43.874031748090474, 42.96877874646868, 41.50312573569161, 44.34042263031006, 42.561298166002544, 42.47411911828177, 41.18800408499581, 40.98028073992048, 38.77852167401995, 41.03992755072457, 44.57746042524065, 45.5879682132176, 43.78973967688424, 42.417004925864084, 43.35670362200056, 41.46753011431013, 46.44601515361241, 52.637495858328684, 51.514413356781006, 54.88580438068935, 53.783441407339915, 52.200127601623535, 51.14336912972586, 53.17524821417672, 52.97547708238874, 52.854345662253245, 50.4420040675572, 52.54437610081264, 50.81771748406546, 52.007520062582834, 49.05927780696324, 55.14497218813215, 44.35052531106131, 40.101920740945, 34.384421825408936, 36.94966547829764, 38.70450251443045, 34.94941806793213, 36.81761148997715, 34.39794649396624, 37.62285906927926, 40.38251331874302, 42.19853271756853, 44.68152706963675, 44.54241023744856, 45.05635459082467, 47.293379238673616, 42.69958816255842, 40.22376782553536, 39.28668165206909, 38.876053537641255, 39.00343486240932, 46.939712456294465, 45.45867960793631, 46.724217551095144, 44.355882372174946, 42.57878678185599, 41.09676381519863, 43.761422293526785, 39.183316775730674, 36.132807459150044, 34.734913281032014, 36.50953183855329, 37.01622922079903, 38.03867401395525, 38.20224503108433, 36.66951411111014, 40.859844139644075, 48.34753908429827, 51.17811359677996, 52.03473615646362, 48.85719639914376, 47.13600254058838, 44.017494678497314, 45.64328282220023, 49.40552738734654, 51.53335762023926, 50.84490578515189, 51.46839543751308, 50.163398674556184, 51.05773605619158, 50.39952972957066, 51.89714445386614, 51.83090727669852, 53.46162864140102, 44.09329605102539, 45.47038732256208, 47.62163993290493, 41.100842407771516, 41.518307549612864, 37.36022411073957, 37.11845459256853, 39.2760717528207, 41.66370207922799, 41.264601026262554, 41.32021788188389, 42.1854944229126, 44.317146165030344, 43.56631340299334, 43.53483806337629, 43.54964814867292, 45.137002331869944, 46.15864808218819, 43.26652295248849, 46.190790448869976, 44.083214214869905, 46.571374552590505, 46.91816956656319, 51.95200742994036, 51.48899337223598, 53.402325766427175, 53.27551071984427, 57.913370745522634, 54.452521664755686, 59.81759752546038, 60.60578727722168, 68.27978774479458, 65.73767117091587, 66.98635973249162, 1.2409941915954863, 17.947846617017472, 72.11927195957729, 36.39291327340262, 41.85563564300537, 34.61790214266096, 30.009766510554723, 46.42993354797363, 31.950082233973912, 0.11357047728129796, 0.03844405710697174, 0.03482688531013472, 0.023168276263667003, 0.027726323377074938, 0.04151445520775659, 0.09940962107586009, 0.03754219585763557, 0.05196855942319546, 0.05589179461821914, 0.05237402480893901, 0.016793677250721624, 0.03569296062258737, 0.10634273583335535, 0.026607790629246404, 0.0352157639073474, 0.14573043159076146, 0.03494914714246988, 0.43872812230672154, 13.535361834934779, 67.71605260031563, 40.47435113361904, 32.94820485796247, 51.88212244851248, 48.5309020451137, 52.75491346631731, 76.7483355658395, 9.649968266487122, 0.015369396623490112, 64.71625818525041, 67.86584186553955, 68.70774119240897, 67.14603628431047, 66.08027294703892, 63.009231703622, 63.391361781529014, 61.292151178632466, 58.430876050676616, 54.22883135931832, 51.711547647203716, 47.64925554820469, 49.25418867383684, 46.803513867514475, 46.07104866845267, 44.904786586761475, 46.34120852606637, 44.89181429999215, 44.26991925920759, 45.026109082358225, 45.36071695600237, 44.73193277631487, 46.53852694375174, 44.901604311806814, 46.86012431553432, 44.15011147090367, 42.82098708833967, 41.824014391217915, 43.93365771429879, 47.17039612361363, 48.7143622807094, 49.04505137034825, 44.925968170166016, 44.400111130305696, 43.94340603692191, 48.719003677368164, 54.375000613076345, 51.69137007849557, 55.0076653616769, 52.35364804949079, 53.603173868996755, 53.566282408578054, 54.83678136553083, 56.034643854413716, 54.56625325339181, 53.96717957087925, 55.135123116629465, 54.59622083391462, 55.64224433898926, 52.82836982182094, 54.346050943647114, 48.91767004558018, 40.306506974356516, 42.08678831372942, 44.34497717448643, 37.913839203970774, 36.35484756742205, 37.21256446838379, 38.107544558388845, 37.88513272149222, 42.06081247329712, 43.34907449994768, 46.13678904942104, 48.81416620526995, 49.05788121904646, 48.371767452784944, 47.766096455710276, 41.96702568871634, 40.68613222667149, 40.415607588631765, 40.41326951980591, 47.32908603123256, 48.41063567570278, 47.83043677466256, 45.14470441000802, 45.67798907416207, 43.45064326695034, 44.67368255342756, 38.94599757875715, 38.29710878644671, 37.28839363370623, 38.05082988739014, 38.199701990400044, 39.14492450441633, 38.518509660448345, 38.68021508625576, 43.03588792255947, 48.701021739414756, 55.65068640027727, 53.74512556621006, 52.0277601650783, 49.57622725622994, 46.01448685782296, 45.004173619406565, 51.160461698259624, 53.15659577505929, 53.37590176718575, 55.18227011816842, 52.865827560424805, 55.33213233947754, 52.98739324297224, 54.03150251933506, 53.41496453966413, 55.48276581083025, 45.10189308438982, 48.763552052634104, 49.38174717766898, 43.36395754132952, 43.70967558452061, 41.37031091962542, 40.45876979827881, 43.34371396473476, 44.474397795540945, 44.342083249773296, 45.11618900299072, 45.89934131077358, 46.582856450762065, 47.59696340560913, 45.12055941990444, 45.92965282712664, 47.924504961286274, 49.101578439985005, 47.0851035118103, 48.90495831625802, 46.909501688820974, 49.734941482543945, 50.039925711495535, 55.57038606916155, 56.498474325452534, 57.91048376900809, 55.82345683234078, 60.996039799281526, 58.39874758039202, 64.14203126089913, 63.254822731018066, 73.27467400687081, 70.42432144709996, 72.216491154262, 1.6786400505474635, 22.00375505856105, 77.229234286717, 43.10590491976057, 49.00524166652134, 40.0974565233503, 30.82152455193656, 52.94479731151036, 41.45147977556501, 0.03576545530397977, 0.08451530244201422, 0.011662627670115657, 0.007185444119386375, 0.0662264223875744, 0.014401534272890006, 0.0474769697258515, 0.03316509198131306, 0.08434102072247437, 0.19073915215475218, 0.1985139013933284, 0.09863856102206878, 0.15184948753033364, 0.24234201173697198, 0.10930947413934128, 0.28039200284651344, 0.23908735066652298, 0.23507186185036386, 0.7270724741475922, 23.87621293749128, 73.51570701599121, 63.664182799203054, 42.40894501549857, 56.74610464913504, 60.75137288229806, 56.01872900554112, 81.15341704232353, 9.759327701159886, 0.23451467603445053, 64.56632995605469, 72.18507140023368, 70.95741503579276, 70.12666756766183, 67.75829069955009, 65.17462389809745, 65.58223302023751, 62.269130434308735, 60.58788176945278, 57.172425270080566, 54.160808495112825, 50.01158748354231, 53.08744035448347, 48.567119530269075, 48.43640654427664, 47.98386689594814, 46.83020189830235, 46.96555628095354, 47.429570879255024, 48.24295479910714, 48.34732369014195, 47.2368243762425, 51.304456165858674, 47.94871595927647, 48.98751333781651, 47.057345458439414, 45.2731488091605, 44.82508727482387, 44.9327391896929, 50.2593081338065, 50.5516014780317, 48.53714847564697, 48.29183190209525, 45.896044390542166, 44.55586889811924, 50.12356117793492, 56.497848987579346, 54.87295021329607, 58.131179400852744, 54.92368595940726, 55.64157383782523, 54.741059507642476, 57.235726833343506, 59.79107625143868, 57.10715389251709, 55.42573847089495, 57.82778978347778, 55.06021111352103, 58.05968591145107, 54.46059199741909, 58.433189800807405, 50.88480234146118, 45.81228385652815, 40.98220191683088, 41.76899855477469, 43.66214990615845, 37.90111010415213, 39.36670058114188, 39.81419236319405, 41.35896103722708, 45.204344272613525, 47.230101994105745, 51.17349304471697, 52.68222836085728, 54.13138287408011, 53.82136467524937, 50.33266026633126, 42.68079328536987, 42.833809988839285, 41.41624893460955, 41.09977238518851, 52.748913696834016, 52.238224574497764, 53.669226918901714, 49.87082045418875, 47.54024873461042, 46.48315327508109, 48.41652774810791, 41.87641423089163, 40.67143331255232, 38.20294679914202, 41.47116749627249, 40.84301560265677, 40.87298665727888, 41.71770347867693, 39.70000914164952, 44.49260902404785, 51.530679089682444, 55.055757318224224, 55.59685870579311, 54.45451579775129, 52.806076526641846, 49.26587206976754, 47.11502940314156, 52.572717802865164, 55.79049110412598, 54.818347794669016, 55.405592169080464, 54.57960074288504, 55.27986798967634, 54.23052324567522, 56.333075932094026, 55.57497188023159, 57.66678612572806, 47.017643451690674, 49.5915584564209, 52.21487862723214, 45.615601199013845, 46.41674586704799, 43.51817280905587, 42.70103686196463, 45.81405912126814, 45.9412111554827, 46.70718056815011, 45.848709787641255, 48.66053111212594, 49.14896515437535, 50.64768811634609, 47.92723560333252, 48.90055315835135, 50.39825126102993, 52.525400570460725, 48.105328355516704, 51.17883620943342, 48.78905194146292, 53.013629640851704, 52.73490265437535, 57.672487122671946, 58.89781584058489, 62.379759652274, 59.74676064082554, 64.06806073869977, 59.68219103131975, 67.00811454227993, 64.9418592453003, 74.4807631628854, 72.33672278267997, 76.25461741856166, 2.0565949124949316, 21.244018180029734, 84.90193544115338, 47.576455797467915, 57.84357261657715, 46.12752015250069, 40.666861397879465, 61.14233412061419, 51.1925311088562, 0.1764807022575821, 0.2960031394447599, 0.07875808208648648, 0.14557960682681628, 0.20285212860575744, 0.10769806203565427, 0.187503842903035, 0.11213970477027552, 0.15184221363493375], [0.03379544422828725, 0.028928438068500588, 0.04586365433143718, 0.03980349183880857, 0.04642788673351918, 0.04240166688604014, 0.06899475026875734, 0.05262392247095704, 0.06365195196121931, 0.5277946101767677, 5.409067077296121, 54.72434561593192, 37.37154967444283, 27.60862020083836, 30.32046910694667, 45.367821489061626, 33.45557968957083, 75.0010095323835, 8.743805050849915, 0.7228590430957931, 71.0985746383667, 61.25044114249093, 66.4190810067313, 60.71772970472063, 59.85264423915318, 55.30992242268154, 56.66847937447684, 51.85330826895577, 49.33401305334908, 45.63455588476998, 46.128267083849224, 44.527169363839285, 43.90634434563773, 40.820569447108674, 42.53687872205462, 42.260927540915354, 42.157072816576274, 40.883332524980815, 44.96838344846453, 43.0463901247297, 46.18014233452933, 45.7518310546875, 44.86189535685948, 43.17592886516026, 41.950145040239605, 41.38852562223162, 39.43590463910784, 40.609208720070974, 40.928627831595286, 41.90073987415859, 44.68514708110264, 46.3446444102696, 43.66511331285749, 43.23859119415283, 44.09175355093819, 47.070303848811555, 53.84788594927107, 53.542495250701904, 54.29522487095424, 51.6355482510158, 52.022715772901265, 53.78147159303938, 52.456853117261616, 52.367627825055806, 54.097649369921, 49.321169308253694, 51.42448282241821, 49.82685225350516, 49.530233655657085, 46.77490813391549, 52.81621742248535, 47.0994758605957, 40.124179295131135, 30.921606404440745, 35.5005213873727, 40.88646616254534, 34.94650329862322, 36.38082340785435, 35.699726240975515, 36.09859452928816, 39.10396139962332, 39.34868737629482, 40.13499069213867, 44.142433711460654, 46.33322157178606, 43.33761692047119, 40.48141050338745, 38.51484795979091, 40.607110364096506, 41.51007740838187, 37.351538862500874, 41.431493282318115, 46.857452733176096, 41.79622507095337, 38.013406889779226, 42.58866364615304, 39.42184148515974, 41.17045293535505, 38.54092454910278, 39.455109460013254, 35.43225186211722, 35.3011463029044, 37.112625053950715, 35.15908343451363, 38.953793457576204, 40.20392724445888, 44.24374539511544, 54.832786151341026, 54.272295815604075, 52.895308767046245, 50.76309422084263, 51.19643599646432, 47.76135778427124, 42.187016078404014, 50.41370752879551, 53.28206287111555, 50.71459926877703, 51.838011809757774, 51.68018000466483, 53.793002128601074, 52.582539081573486, 50.74906233378819, 52.034489495413645, 51.24514634268624, 43.65971108845302, 45.52185262952532, 46.28986481257847, 42.16444138118199, 40.03699677331107, 36.935564109257285, 37.68840490068708, 41.147499561309814, 44.69885240282331, 42.9398638180324, 43.23807355335781, 44.14142622266497, 43.099898202078684, 43.75361251831055, 43.959355626787456, 43.24294771466936, 44.60042422158377, 44.625739983149934, 44.179248741694856, 46.671060357775005, 44.604627881731304, 46.97377252578735, 47.321352686200825, 49.8098395892552, 48.5791711807251, 53.15584189551217, 55.935076168605256, 57.78509310313633, 57.22517251968384, 60.18709577832903, 64.49470097678048, 68.6482298714774, 70.17106655665806, 58.52558694566999, 1.597076558641025, 28.475925615855626, 59.68268435341971, 33.03658594403948, 35.76638378415789, 42.98449557168143, 46.18527705328805, 54.93096767153059, 28.06157500403268, 0.09059758178357567, 0.08361656923911401, 0.011748071344170188, 0.052606117712067704, 0.039655306576085944, 0.059362124651670456, 0.0577459628028529, 0.06947740579822234, 0.0669082822278142, 0.047633137953068526, 0.06736910928572927, 0.04661147456083979, 0.058988285783146105, 0.08593060435461146, 0.04844029267717685, 0.06438440337244954, 0.04009045786889536, 0.03964494873902627, 0.23689820670655795, 5.015536308288574, 65.10242516653878, 37.29026617322649, 31.386763981410436, 39.08358580725533, 47.604675906045095, 39.22198697498867, 81.91338321140834, 9.779060585158211, 1.2382073125668933, 77.67899812970842, 65.63403184073312, 70.21027524130685, 63.70904731750488, 65.25907925197056, 58.17673179081508, 60.67767333984375, 54.44333267211914, 53.35871539797102, 49.07033239092146, 48.800519943237305, 47.48990208762032, 48.88488149642944, 43.453401701790945, 46.87080022266933, 45.68665000370571, 47.62746599742344, 44.48535510471889, 48.04812036241804, 47.76131956917899, 50.68290506090437, 48.57742370877947, 46.94932181494576, 45.59591695240566, 44.97349732262747, 45.708394391196116, 43.310866355895996, 42.293743882860454, 42.27858986173357, 44.1506256375994, 45.21447822025844, 48.525826386043, 47.65682213647025, 44.47801433290754, 43.14520045689174, 50.95968655177525, 55.20756503513881, 55.651923179626465, 55.65634570802961, 53.785192353384836, 54.13881744657244, 54.47808756147112, 54.92037861687796, 52.82346091951643, 54.7477263041905, 51.86306701387678, 54.103107179914204, 52.93980850492205, 51.93392126900809, 51.84407411302839, 54.38308136803763, 48.83919709069388, 43.87848206928798, 38.835774830409456, 46.00987672805786, 40.32294293812343, 37.569416999816895, 36.1614340373448, 37.13264281409127, 39.91103288105556, 41.097232818603516, 40.74028648648943, 43.88847010476248, 46.18794863564627, 49.49447475160871, 44.564873763493125, 42.49283409118652, 39.159446239471436, 39.60672262736729, 40.940933091299875, 37.29397651127407, 42.96292488915579, 47.778502464294434, 45.33669703347342, 41.082662446158274, 45.79093204225813, 41.64407689230782, 43.790173939296174, 39.51368277413504, 40.65283645902361, 36.91685261045183, 37.333289418901714, 38.64222581045968, 36.79895557676043, 40.220762729644775, 39.69692414147513, 48.32321344103132, 55.516513211386545, 53.02451746804373, 54.278733321598594, 51.594633783612935, 53.3176828111921, 51.365100043160574, 42.64051457813808, 52.307143756321494, 55.09225967952183, 52.15805625915527, 53.60634224755423, 54.56327247619629, 55.751001017434255, 54.62649760927473, 53.20118236541748, 54.24351985113961, 52.19112968444824, 45.9153082711356, 47.65179511478969, 46.6012031691415, 44.617416041237966, 43.27960293633597, 39.33551706586565, 41.21603659221104, 43.37525531223842, 45.112753118787495, 44.74745505196707, 46.26687669754028, 47.62653146471296, 44.98512513296944, 46.90368604660034, 46.56283521652222, 46.03507089614868, 46.95711769376482, 47.21640362058367, 47.703340326036724, 49.424485547201975, 48.73079129627773, 50.168245043073384, 50.50547238758632, 52.145674569266184, 53.58981943130493, 58.6334924697876, 58.790799685886924, 62.004730633326936, 61.732965741838726, 62.522010122026714, 67.01716109684536, 71.27348164149693, 72.316864831107, 60.096150806971956, 1.839220085314342, 33.95261907577515, 65.52923910958427, 39.70256955283028, 42.389684609004426, 55.51397017070225, 45.771404130118235, 61.483428137642996, 34.55574008396694, 0.1114213058192815, 0.04743440861680678, 0.04205005682472672, 0.067557504533657, 0.05857603504721608, 0.04532543696197016, 0.07698120243315186, 0.0650004588865808, 0.07166946745876755, 0.12094255669840745, 0.11963121992136751, 0.11025951137500149, 0.10001974619392838, 0.13132032911692346, 0.12278338149189949, 0.14846593194774219, 0.12332824511187417, 0.2337593308516911, 0.5953039590801511, 10.103605730193001, 78.41427734919957, 48.62292398725237, 41.905982289995464, 41.15786279950823, 61.71401800428118, 41.45544719696045, 89.36095578329903, 10.00893565586635, 1.4080889225006104, 79.79949801308769, 66.5178496497018, 74.01877049037388, 66.57959134238106, 68.00796031951904, 60.91086878095354, 63.05533994947161, 56.26911776406424, 54.997500147138325, 51.9818742615836, 49.945280824388774, 50.76349721636091, 51.756756101335796, 46.426393440791536, 48.25124747412545, 47.35146617889404, 49.34352166312081, 46.69221762248448, 51.65450988497053, 48.90251949855259, 52.27917378289359, 51.9270008632115, 49.65981755937849, 48.89354937417166, 47.18135690689087, 48.773258686065674, 44.91266931806292, 45.46512058803013, 45.16905437197004, 46.968714237213135, 49.177244322640554, 50.296956947871614, 49.58703170503889, 45.65366343089512, 45.91264016287667, 50.10894216809954, 57.35569095611572, 57.01772362845284, 57.54659966060093, 56.90536083493914, 55.30317572184971, 57.31647879736764, 58.143331800188335, 54.62656014306204, 57.23907239096505, 53.43662902287075, 57.193269865853445, 55.21793522153582, 54.753045150211875, 52.61470576695034, 57.396337917872835, 50.99153014591762, 48.9752254486084, 36.961727551051546, 42.209743635995046, 44.551943165915354, 39.21869005475725, 39.66350678035191, 39.679195812770296, 40.97908564976284, 44.44621590205601, 44.92105579376221, 46.36283826828003, 52.60778536115374, 53.25487457002912, 48.409120968409944, 45.00056055613926, 41.405562605176655, 40.88405166353498, 42.24554075513567, 39.534926891326904, 46.75005790165493, 52.47966752733503, 50.49670723506382, 44.82410410472325, 51.18295301709856, 44.70287193570818, 46.94704280580793, 42.799044677189414, 44.06686857768467, 39.61987556729998, 40.06214230401175, 42.220735686165945, 40.545545850481304, 43.741578238351, 41.85535771506173, 50.642265047345845, 58.57755252293178, 57.72120789119175, 56.57215649741036, 54.75573410306658, 56.34918533052717, 52.682061604091096, 44.223821435655864, 52.413117681230815, 57.41185324532645, 53.62577288491385, 55.60481786727905, 56.36575678416661, 59.053552763802664, 55.886487415858674, 56.263812814440044, 56.11761924198696, 53.65365947995867, 46.019586835588726, 49.84690128053938, 50.182728563036235, 46.16906343187605, 44.77060644967215, 41.4399596623012, 43.87871135984148, 45.46863637651716, 47.777859755924766, 47.30460752759661, 48.99807807377407, 49.97913244792393, 46.4592410496303, 49.47807700293404, 49.395653997148784, 47.69361979620797, 49.01339190346854, 49.84052978243147, 50.18899236406599, 52.10841138022286, 48.55998373031616, 52.992062432425364, 52.934736319950645, 56.26152685710362, 54.72517939976284, 60.52145004272461, 61.23379325866699, 64.65544060298375, 61.51134599958147, 67.26613589695522, 68.84041704450334, 76.70964799608502, 74.31848798479352, 66.67658819471086, 2.348153267587934, 34.19280440466744, 74.44438239506313, 45.03007997785296, 48.28452239717756, 54.11499902180263, 63.929902757917134, 72.37830080304826, 42.746130670819966, 0.17342201567121915, 0.18337332883051463, 0.15649492825780595, 0.3195269171680723, 0.12849253442670616, 0.15433634551508085, 0.12031906444047179, 0.12462815535920006, 0.2144013645925692], [0.07525733672082424, 0.04672061352591429, 0.07169633066015584, 0.06523939820804767, 0.06136454255985362, 0.006147503096144646, 0.08773235910172973, 0.13518706948629447, 0.03593800336654697, 0.12563272645430906, 2.6545410326548984, 52.26404060636248, 39.901621546064106, 28.54298962865557, 26.113362652914866, 50.14360325677054, 38.143035956791465, 69.11854648590088, 11.97332341330392, 1.1272456667252948, 75.43535532270158, 57.97472333908081, 66.34251880645752, 56.692033767700195, 54.548504080091206, 48.86098664147513, 50.639263425554546, 46.94349922452654, 45.90996510641915, 45.42976120540074, 44.05872876303536, 42.53968232018607, 46.19938884462629, 42.60822629928589, 42.09339257649013, 39.54572091783796, 41.584079197474885, 45.648282051086426, 51.35652944019863, 51.07940053939819, 52.133959906441824, 48.63321079526629, 48.31991304670061, 44.27091632570539, 41.94143199920654, 40.95728915078299, 40.226748602730886, 38.31954104559762, 40.799373967306956, 39.65472425733294, 43.85675157819475, 45.55826119014195, 45.009659222194124, 42.19338410241263, 46.06976672581264, 48.994103704180034, 53.71875367845808, 52.9847320829119, 52.56034653527396, 52.69270624433245, 56.93755531311035, 52.546512671879356, 55.29746777670724, 51.97439105170113, 52.23894023895264, 49.446942125047954, 49.02392884663173, 48.95350537981306, 49.27274036407471, 48.28433132171631, 51.63353674752371, 48.45716776166643, 41.615516321999685, 33.900747299194336, 30.99859939302717, 40.9844913482666, 35.39101777757917, 36.41187490735735, 33.27474239894322, 36.845320905957905, 37.15349783216204, 36.316479614802766, 37.125892639160156, 41.710220268794465, 43.107145173209055, 41.489323139190674, 38.67760256358555, 37.48277643748692, 38.805306979588096, 43.18817853927612, 39.128009114946636, 40.01150035858154, 40.916551862444194, 43.110487256731304, 39.00488356181553, 37.65299688066755, 36.35656377247402, 37.15679822649275, 36.63867105756487, 37.42228889465332, 37.62033339909145, 34.87529468536377, 36.81471756526402, 36.513058049338206, 35.29970107759748, 38.75290366581508, 49.72142028808594, 55.410893644605366, 50.138051646096365, 52.63815941129412, 52.2598751613072, 50.11718967982701, 50.47687360218593, 47.63366379056658, 49.61969518661499, 50.657964502062114, 48.94939204624721, 51.17112718309675, 50.627864905766074, 52.4450272832598, 50.047266483306885, 49.29199034827096, 50.583705629621235, 51.30706868852888, 47.12766122817993, 43.62764515195574, 43.88326242991856, 42.98219919204712, 38.261718136923655, 37.265718187604634, 37.03236641202654, 43.126179763248985, 43.93753480911255, 41.24765089579991, 42.260465485709055, 44.238638469151084, 48.205170495169504, 47.72352484294346, 48.795041288648335, 45.99153348377773, 48.393824509211946, 46.81698989868164, 44.96053198405674, 45.66657318387713, 47.74976124082293, 47.11781563077654, 47.95634160723005, 48.84022542408535, 49.88084323065621, 52.688818727220806, 57.821668420519146, 60.96796907697405, 61.74199840000698, 62.91682761056082, 65.6715521131243, 67.78852231161935, 73.12192480904716, 43.03506108692714, 1.8290214325700487, 38.94467742102486, 54.49104247774397, 38.273491859436035, 31.348555837358745, 24.40888442311968, 33.57016243253435, 48.991904599326, 29.921729360307964, 0.03614143155781286, 0.020106376813990728, 0.046018859038927724, 0.01429190845893962, 0.04488037905788847, 0.03314689027943781, 0.043273482604750564, 0.0223666855267116, 0.09798815127994333, 0.0333093044215015, 0.06506802061838762, 0.05504022638446518, 0.029687413413609778, 0.07777352777442761, 0.04775742521243436, 0.11553031711706094, 0.06229389126279524, 0.043195471433656554, 0.06664889864623547, 2.843475363084248, 63.93758051736014, 43.99534034729004, 26.45578898702349, 36.13210916519165, 54.751655510493684, 41.216119970594136, 78.56304522923061, 14.044972249439784, 1.3900692037173679, 78.50439548492432, 62.803988865443635, 70.00392763955253, 60.698427609034944, 58.220397744859966, 53.11513934816633, 54.68795442581177, 50.639958245413645, 49.017095293317524, 49.54361241204398, 48.084612301417756, 46.984715938568115, 48.82680150440761, 45.421339988708496, 46.145067828042166, 44.78015327453613, 45.920672280447825, 49.138323988233296, 54.219385283333914, 56.65634434563773, 56.04498972211565, 53.74602535792759, 50.83763102122715, 46.692679677690776, 45.194679328373496, 44.46231140409197, 43.85246453966413, 42.687432289123535, 42.174978324345176, 41.231374740600586, 46.39893415996006, 47.30447203772408, 49.03058174678257, 45.73663534436907, 46.72393962315151, 49.94516965321132, 56.204971994672505, 54.80897467476981, 54.2326146534511, 53.420477935246055, 56.52789647238595, 55.94745091029576, 56.94147062301636, 52.767847537994385, 53.3444368498666, 52.86019951956612, 50.8118462562561, 51.75145809991019, 51.537686347961426, 51.275027070726665, 53.63219649451119, 52.18565797805786, 42.842995507376536, 40.671353408268516, 44.039190428597585, 41.41968134471348, 37.553106103624614, 38.65202277047293, 36.700416224343435, 38.49774496895926, 38.90744897297451, 39.76533610480172, 40.792186055864605, 45.8213130405971, 45.005601474217, 41.52490486417498, 40.20079360689436, 37.56421627317156, 40.49739136014666, 43.02785233088902, 39.277739320482524, 39.68240935461861, 43.241578919546946, 44.10584102358137, 42.56569984980992, 40.44047171728951, 39.15185880661011, 39.827272347041536, 39.619899885995046, 38.83284616470337, 38.25341156550816, 35.88941206250872, 38.606723989759175, 39.410244941711426, 36.885099342891145, 42.187599727085654, 51.29294300079346, 53.84652757644653, 53.84105239595686, 53.178367955344065, 53.80455003465925, 53.08554697036743, 52.47356006077358, 49.80975273677281, 51.57443189620972, 52.86809614726475, 50.50168909345354, 52.89608696528843, 52.20677007947649, 53.964316913059776, 52.89705971309117, 52.36654043197632, 53.708209787096294, 51.53247519901821, 48.288642678942, 47.839994021824424, 46.50502967834473, 44.30302742549351, 42.75172744478498, 40.568957805633545, 41.81838982445853, 44.21718938010079, 44.6831807409014, 44.41248934609549, 45.43658781051636, 47.608962944575715, 51.01553617204939, 52.06636783054897, 51.95685032435826, 50.67327833175659, 51.38642406463623, 49.66530316216605, 48.37451546532767, 48.88080985205514, 49.45616238457816, 49.22668422971453, 49.80169630050659, 51.02458272661482, 53.89037070955549, 57.03959308351789, 61.925152914864675, 63.68067782265799, 64.0356057030814, 66.46443189893449, 67.06241471426827, 69.17383330208915, 75.25330557141984, 43.86528744016375, 1.9594247894627708, 45.598133427756174, 59.52249363490513, 44.288818359375, 34.25725589479719, 25.03228896004813, 39.15665653773716, 62.12292643955776, 32.7013839994158, 0.014422197360545397, 0.022230074375069568, 0.003480394404115421, 0.043061786464282444, 0.0019596424244809896, 0.02460165774183614, 0.03779031236522964, 0.007845233759975858, 0.13439226070685045, 0.20696616784802505, 0.08509483920144183, 0.14200285875371524, 0.1717916452991111, 0.16452738509646483, 0.15767627129597322, 0.1992239747196436, 0.28850483894348145, 0.1389259195753506, 0.38546404615044594, 4.170285778386252, 77.00083310263497, 51.81906059810093, 39.70269809450422, 37.65243755068098, 65.69296646118164, 47.551636832101, 85.58158043452671, 14.372303622109548, 1.9164677688053675, 83.42058644975934, 64.49805695669991, 73.6711173738752, 62.782706533159526, 61.47088663918631, 53.74939523424421, 56.33203717640468, 52.303346565791536, 50.88765457698277, 52.19791112627302, 50.937233448028564, 49.43141984939575, 51.937478746686665, 47.707398074013845, 47.85842759268624, 45.37243856702532, 47.98862641198294, 52.02650601523263, 57.055424554007395, 58.55736105782645, 57.68195404325213, 56.81250163487026, 54.00913626807076, 48.99256815229143, 48.14138950620379, 45.305384976523264, 45.888856479099815, 43.626672404153005, 46.38109118597848, 44.029139859335764, 48.59214346749442, 49.029803548540386, 52.57447222300938, 46.18490879876273, 49.36123956952776, 51.831112248556956, 57.341405459812705, 59.23854855128697, 56.372906480516704, 55.277488231658936, 59.148618016924175, 57.56234427860805, 59.76815414428711, 54.01793616158621, 55.51512704576765, 53.98239265169416, 52.74030140468052, 53.74104002543858, 54.27462346213204, 53.57371350697109, 55.63215555463518, 53.46206637791225, 48.35697821208409, 41.14056873321533, 35.27836315972464, 45.72801957811628, 41.2182183265686, 42.17145906175886, 37.86679989950997, 42.73319659914289, 41.76503113337925, 43.224118096487864, 43.45660482134138, 50.17648213250296, 49.5631160054888, 47.6804529598781, 41.46089111055647, 37.38801690510341, 41.6768411227635, 44.93713739940098, 39.73618841171265, 42.5512684413365, 48.13136672973633, 49.689347403390066, 46.83107737132481, 45.30293921061924, 43.54877267565046, 42.44415501185826, 41.92855698721749, 41.405090127672466, 41.571329253060476, 38.451049600328716, 40.5467027255467, 41.66481726510184, 37.1697427204677, 43.67483384268624, 52.103304454258506, 57.119591167994905, 54.42351988383702, 56.21967438289097, 55.5898688180106, 55.78509930201939, 54.065427098955425, 50.332073143550325, 53.85832561765398, 55.578400816236226, 52.206738812582834, 53.71756553649902, 53.56413541521345, 57.42053154536656, 53.829608712877544, 53.676199436187744, 54.37257916586739, 55.66383239201137, 51.01033891950335, 48.982976164136616, 48.979543754032676, 47.642783301217214, 43.42891277585711, 42.722169807979036, 41.945969172886436, 48.92230796813965, 47.862231731414795, 47.293035302843364, 47.31755549567086, 49.57559149605887, 51.86793075289045, 54.939222131456646, 54.80573681422642, 52.13698237282889, 52.06233787536621, 54.0011180468968, 49.853456905909944, 51.072702475956504, 52.36429616383144, 52.901603834969656, 52.51789651598249, 53.90339510781424, 55.75057717732021, 60.10932459150042, 63.03457873208182, 67.06404754093715, 65.57165091378349, 70.24370997292655, 68.76714829036167, 74.46693624768938, 75.3151375906808, 54.29757336207798, 2.6895501826490675, 46.43675667898995, 68.18210996900285, 48.70466954367501, 46.03031138011387, 34.9780272756304, 50.45757845469883, 66.61828586033413, 43.573925154549734, 0.14111236296594143, 0.10676470997610263, 0.060105432623199055, 0.09346891128058944, 0.12536878990275518, 0.10237477160990238, 0.14868918353957788, 0.0724353367196662, 0.20409801389489854], [0.02735285091746066, 0.0892860618020807, 0.10969208646565676, 0.03288335406354495, 0.036385649881724796, 0.027456831320055892, 0.06414430375610079, 0.06951474558029856, 0.04452023981139064, 0.06954736954399518, 1.3278920544045312, 47.92108644757952, 46.01847512381417, 45.110015528542654, 21.344761848449707, 39.07014799118042, 37.850888524736675, 67.78531224387032, 19.01246871267046, 0.6863690582769257, 68.56405244554792, 60.69335542406355, 67.34449073246547, 59.06034810202462, 56.658658095768516, 50.754582677568706, 52.66934640066964, 45.51197576522827, 46.949300970349995, 43.65915870666504, 46.17295094898769, 43.28646428244454, 44.61473056248256, 43.415832792009624, 42.57650082451956, 41.82877043315342, 48.974287441798616, 53.00793906620571, 55.80324452263968, 54.68342072623116, 54.05788830348423, 51.622252873011995, 50.08474506650652, 44.42857095173427, 42.30250556128365, 41.87992307118007, 41.19315617425101, 38.91411229542324, 38.3598301751273, 39.72081899642944, 43.709550516945974, 45.20793996538435, 43.41922698702131, 42.993583815438406, 46.23838560921805, 48.18829332079206, 54.174426964351106, 50.92947578430176, 52.94949776785714, 53.417896679469514, 54.973018169403076, 51.387473242623464, 54.9703118460519, 51.301121030535015, 50.84833124705723, 50.627705097198486, 48.322702748434885, 48.365448066166465, 47.81631108692714, 46.04979065486363, 50.793829577309744, 51.68890694209507, 44.527864183698384, 33.17832919529506, 29.71957847050258, 40.42427199227469, 35.371416909354075, 38.62823561259678, 33.9005423273359, 35.71436262130737, 36.44950982502529, 38.57735742841448, 35.27813386917114, 39.64126212256295, 38.01779120309012, 43.86645473752703, 38.648791858128135, 39.5126440184457, 43.006719384874614, 44.875572885785786, 41.12480674471174, 41.19621685573033, 42.48142862319946, 38.35708563668387, 35.7329421043396, 34.30442374093192, 38.3570613179888, 35.85793672289167, 36.904008865356445, 36.94626086098807, 38.188459805079866, 38.474339962005615, 38.126676423209055, 35.24699204308646, 37.08245597566877, 46.310500962393625, 52.54124593734741, 51.76467704772949, 53.1426785332816, 51.70386641366141, 53.12739944458008, 47.22833367756435, 48.3583539554051, 50.13539743423462, 47.58212552751814, 48.542432580675396, 50.461987086704795, 50.3352449962071, 48.83017832892281, 51.58445119857788, 50.83693272726876, 48.058302947453086, 52.59168985911778, 49.24933188302176, 46.568414619990754, 43.80962542125157, 41.61814968926566, 40.78605079650879, 38.5818772315979, 37.840907437460764, 37.78929969242641, 40.58278472082955, 44.35864775521414, 41.67723369598389, 44.73923880713326, 48.89235775811331, 51.29419367653983, 51.3182691846575, 50.950268268585205, 52.0206868989127, 50.026366301945274, 51.20472519738333, 50.54872839791434, 49.61170475823538, 47.62764665058681, 44.25162465231759, 48.74201611110142, 49.28303064618792, 50.16404138292585, 56.76859596797398, 61.1550076348441, 66.5482063293457, 64.95535264696393, 61.882164410182405, 71.25823034558977, 64.69763006482805, 74.2377985545567, 29.070033073425293, 0.7095316925219127, 52.305045400347026, 49.700777190072195, 34.76939719063895, 27.693620988300868, 53.08082219532558, 32.84515959875924, 56.621780531747, 20.284379890986852, 0.14737256776009286, 0.17843757010996342, 0.038687898843948326, 0.02973426625664745, 0.028436544284756695, 0.09725612734577485, 0.0272595811901348, 0.034393572847225835, 0.05500436580872961, 0.05061351142025419, 0.057444069002355845, 0.07376428148044006, 0.017922177677974105, 0.04480254430589931, 0.03207885580403464, 0.06817950401455164, 0.03366031397932342, 0.02370903474677886, 0.0505821325683168, 1.2573196355785643, 53.89977857044765, 47.35827193941389, 45.1095222064427, 33.909870283944265, 41.299897875104634, 42.45603295734951, 72.34510231018066, 23.634226288114274, 0.6641462221741676, 73.88769272395542, 65.52777303968156, 69.89976719447544, 61.234043393816265, 61.51957961491176, 55.40606117248535, 57.13446726117815, 50.37508249282837, 49.45132643835885, 47.565331731523784, 50.2267210824149, 47.56401852199009, 46.61868483679635, 46.73569597516741, 45.49838508878435, 44.46257890973772, 52.48969030380249, 56.776009695870535, 59.85310282026018, 58.60783972058977, 57.90392814363752, 55.77391965048653, 51.537856578826904, 48.054985182625906, 46.007451806749614, 44.45664862224034, 44.20400864737374, 42.58215318407331, 40.1720871244158, 42.439590045383994, 43.969962051936555, 46.58753606251308, 46.43874386378697, 45.652878284454346, 46.98165873118809, 50.61791508538382, 55.728447164808, 53.95804268973214, 55.51395627430507, 55.569378580365864, 56.534320081983296, 53.63758829661778, 56.760421412331716, 51.34950133732387, 55.43159927640642, 52.53498561041695, 52.13473463058472, 50.036118098667686, 49.670417036329, 49.9465662411281, 53.153945037296836, 53.817980902535574, 47.971676281520296, 37.95979806355068, 44.210522583552766, 42.50541727883475, 35.832659176417756, 39.21069962637765, 36.263225146702354, 39.63237190246582, 37.193213735307964, 41.002897126334055, 38.1116509437561, 40.3149733543396, 42.31125681740897, 43.319826057979036, 37.90523386001587, 37.83128418241228, 40.56277390888759, 44.9576450075422, 39.73318678992135, 41.23240654809134, 43.49931192398071, 38.71433768953596, 38.83663640703474, 35.6748377936227, 40.590299197605674, 37.35162571498326, 38.47830390930176, 37.82603134427752, 37.65361874444144, 39.3411659513201, 39.796325070517405, 36.15506601333618, 38.65610831124442, 49.53649745668684, 53.34170968191964, 53.49583114896502, 54.78724070957729, 53.28556476320539, 52.42837939943586, 50.348682812282014, 49.41435854775565, 50.99130432946341, 48.99744578770229, 50.134004320417134, 53.61784846442086, 52.747385093144004, 49.769765853881836, 52.75372532435826, 54.25139563424246, 51.761362757001606, 55.21707364491054, 49.37215518951416, 47.850954805101665, 46.36967876979283, 44.33414145878383, 42.64094884055001, 41.3817754473005, 42.23865509033203, 41.53812728609358, 44.26467684337071, 45.72320100239345, 43.95377969741821, 48.40304476874215, 51.812018598829, 53.8055853162493, 54.27363681793213, 54.4612694467817, 55.757379463740754, 56.003873756953645, 54.02024296351841, 52.55591358457293, 53.322345052446636, 49.894843850817, 48.04595947265625, 50.13102354322161, 51.75585978371756, 53.23256390435355, 60.85807636805943, 65.58467183794293, 69.67501381465367, 67.87515245165143, 66.10668999808175, 72.81903198787144, 67.13316822052002, 79.06400339944022, 27.85969683102199, 0.9861030003854206, 58.51244790213448, 53.65615735735212, 41.553329944610596, 30.476369312831334, 61.74465261186872, 38.387678555079866, 61.945844650268555, 23.555089780262538, 0.2799959826682295, 0.22364508786371776, 0.11410409079066344, 0.030597956518509557, 0.027902659361383746, 0.08547381458005734, 0.025390768523461053, 0.028375837452975766, 0.03194421749295933, 0.18630959412881307, 0.1540156291531665, 0.1599259948624032, 0.1326048501900264, 0.08822932493473802, 0.11191961515162673, 0.12819609604775906, 0.19510948764426367, 0.08027620241045952, 0.12348614021071366, 2.180517337151936, 70.52791908809117, 56.45587144579206, 60.02944115230015, 31.021497181483678, 54.714295046670095, 49.14609554835728, 81.057434626988, 22.741648537772043, 1.187542894056865, 79.26045676640102, 65.92638424464634, 74.83125809260777, 65.17616639818463, 61.828579902648926, 54.464455195835654, 58.13412891115461, 51.423405851636616, 52.41668210710798, 49.51225519180298, 52.294400760105674, 49.41279867717198, 49.56901502609253, 49.360350200108115, 47.30632373264858, 46.600598675864084, 55.733286585126606, 59.81916087014334, 62.21670627593994, 59.170324189322336, 59.790138244628906, 58.54866886138916, 55.51679808752877, 50.14542021070208, 48.05889007023403, 45.8645065171378, 46.548626150403706, 44.9292060307094, 44.41378171103341, 45.013049943106516, 48.26001957484654, 51.40936701638358, 48.13346855981009, 47.47217723301479, 49.895691531045095, 52.64156750270298, 56.926778657095774, 56.75839253834316, 58.07970714569092, 56.28645351954869, 57.63666915893555, 54.84840570177351, 60.355214391435894, 53.096233299800325, 54.84048475537981, 54.34165620803833, 56.094832624707905, 54.019207681928364, 52.2771692276001, 51.53643914631435, 55.96252155303955, 55.473003591809956, 52.99130507877895, 37.427781445639475, 35.482355322156636, 46.11265100751604, 38.39953218187605, 43.52584709439959, 39.38662106650216, 42.44178915023804, 40.1265138898577, 42.43470893587385, 41.34214639663696, 44.584922790527344, 46.061647755759104, 48.65001848765782, 38.878780705588206, 40.30513817923409, 41.45519706181118, 48.06127677645002, 42.44692734309605, 42.277502468654085, 46.76330464226859, 43.49389232907976, 42.83233002253941, 39.6170129094805, 43.52186230250767, 41.89792932782854, 40.201947007860454, 41.00957781927926, 41.994710786002024, 42.848585333142964, 43.620471136910574, 39.23585557937622, 39.998663561684744, 49.92755249568394, 55.464717864990234, 55.54142597743443, 55.89350162233625, 56.2553915977478, 56.18588876724243, 52.547224862234934, 50.9214506149292, 54.039444310324534, 53.14328302655901, 53.21811165128435, 54.008351121629985, 54.091969217572895, 50.57631622041975, 54.34930270058768, 55.86089372634888, 51.88101421083723, 56.56349209376744, 52.51323080062866, 49.550108977726524, 48.50986637387957, 48.10756567546299, 45.23471484865461, 42.49016945702689, 45.163516657693044, 42.82518032618931, 46.04591703414917, 49.10417011805943, 46.26568855558123, 50.73135484967913, 53.581676142556326, 57.729931354522705, 56.19712053026472, 56.617601190294536, 57.24278620311192, 56.91301774978638, 57.22632244655064, 53.583656379154746, 55.079058102199006, 51.26923227310181, 50.85861805507115, 52.37176547731672, 55.81067909513201, 56.458581243242534, 63.6511618750436, 67.498108455113, 72.4509859085083, 69.04729965754917, 69.47305747440883, 75.38113852909633, 71.23602390289307, 79.22536836351667, 42.762646538870676, 2.5531286001205444, 61.508559771946494, 61.50127805982317, 50.929225649152485, 37.93929740360805, 64.91085638318742, 44.863934653145925, 71.75614520481655, 31.571693761008127, 0.3267769552767277, 0.33718391827174593, 0.2326057127543858, 0.08712171151169709, 0.19909502592469963, 0.1709729792284114, 0.1330949967460973, 0.172858614474535, 0.10818182357719966], [0.034052775241434574, 0.04851859222565379, 0.09495773924780743, 0.1710956855011838, 0.0738667266975556, 0.02738669285151575, 0.05134342171783958, 0.04895348906783121, 0.047089047863015106, 0.026899229901443635, 0.15260460201118672, 31.011213847569056, 53.42529303686959, 28.06389570236206, 19.16175423349653, 32.37972756794521, 43.24756826673235, 61.84768744877407, 43.48114933286394, 0.3387335565473352, 51.4633788381304, 68.01119818006242, 62.83123970031738, 61.88545090811593, 62.41508429391043, 60.112666675022666, 59.44695281982422, 54.10154383523123, 47.52805812018258, 48.06876346043178, 48.58944756644112, 45.62491873332432, 45.4645334652492, 41.59274360111782, 42.42140313557216, 45.1899927684239, 54.03972571236746, 53.08836099079677, 54.21817282267979, 54.64736304964338, 53.628239495413645, 51.81350203922817, 48.76513276781355, 43.52464158194405, 43.36479479925973, 42.19561447416033, 41.43147243772234, 38.76744277136666, 39.800542627062114, 39.58390474319458, 40.52865825380598, 40.75802523749215, 42.744501318250386, 42.84470476422991, 46.0791711126055, 47.28600025177002, 51.147617953164236, 55.73348808288574, 51.00515903745379, 52.992277826581685, 54.404884815216064, 52.6926645551409, 54.684813840048655, 52.022979804447715, 53.33099903379168, 51.381918157849995, 50.69184391839163, 46.57335131508963, 46.50601632254464, 46.335153170994346, 48.94574424198696, 51.52768094199044, 42.639725957598, 38.40742186137608, 26.072434289114817, 40.10166365759713, 35.58585221426827, 38.05579437528338, 34.039638314928325, 34.16682856423514, 35.171392168317524, 36.91916288648333, 34.8727377482823, 36.60098055430821, 35.24671758924212, 39.87114674704415, 37.547755990709575, 38.048241683415, 39.61008555548531, 39.030501570020405, 39.3048859323774, 38.61479432242257, 44.6197714805603, 41.259320395333425, 37.60314702987671, 36.96767520904541, 37.960777759552, 38.77103499003819, 36.44469472340175, 38.11320734024048, 38.0679155077253, 37.15395293916975, 36.540635449545725, 36.099251134055, 43.8394262450082, 50.951553685324534, 50.9046186038426, 52.366870471409385, 49.04695865086147, 50.661344800676616, 49.47395324707031, 50.12055260794503, 48.67221450805664, 50.321782861437114, 48.36668484551566, 51.092435359954834, 52.226711409432546, 49.83712863922119, 51.00383540562221, 50.380995409829275, 49.529420716421946, 49.62476389748709, 48.756666387830464, 48.26952123641968, 42.83012744358608, 41.87539631979806, 40.075052056993755, 38.37952484403338, 37.690576212746755, 38.04764413833618, 41.00752810069493, 41.184092249189106, 43.46197925295149, 42.13294172286987, 44.539113317217144, 48.04573713030134, 52.89816100256783, 51.83921732221331, 54.43005119051252, 52.051450048174175, 54.761671338762554, 52.07258994238717, 56.36981800624302, 53.081048011779785, 54.09842756816319, 49.301655292510986, 48.150331837790354, 48.23151806422642, 53.27739020756313, 58.32273428780692, 63.84097971235003, 61.22680337088448, 71.92605645315987, 62.535705021449495, 71.92850221906389, 61.24290234701974, 80.29352188110352, 12.012083070618765, 1.2240679455654961, 54.55976711000715, 52.919328689575195, 29.513321195329937, 63.49263872419085, 88.23021289280483, 23.215130056653702, 64.88425173078264, 12.812276703970772, 0.09044113874967609, 0.034015021552996974, 0.09558716190180608, 0.06764413309948784, 0.049745319078543355, 0.10713494582367794, 0.0311187423233475, 0.059893750053431304, 0.10262268116431576, 0.01715398104196148, 0.050971302935587506, 0.05335417542872684, 0.10178405259336744, 0.04861782457945602, 0.02011805779433676, 0.041640723789376874, 0.045396496541798115, 0.022050459370283142, 0.08603484090417624, 0.17802339233458042, 36.662232398986816, 58.93142427716936, 33.83364854540144, 28.984691824231827, 39.112907205309185, 50.16574716567993, 66.16923768179757, 51.026302405766074, 0.51191672789199, 51.82996579578945, 70.97061661311558, 66.96359048570905, 65.85380336216518, 64.08369418552944, 67.03087684086391, 63.59000383104597, 59.411009788513184, 51.486346108572825, 51.81257792881557, 50.914842878069194, 48.33538668496268, 47.53691012518746, 45.275705746241975, 45.15781218664986, 50.28994621549334, 58.62118026188442, 57.02002695628575, 58.47715105329241, 58.63575758252825, 55.51062808718, 54.233378955296104, 52.394534724099294, 45.966763155800955, 46.46728706359863, 43.66555104936872, 43.47205761500767, 41.46548734392439, 41.958799021584646, 40.290435791015625, 44.02207701546805, 41.72218854086739, 45.467875548771445, 44.58712189538138, 48.05955014910017, 49.38416167667934, 53.38748094013759, 54.233674253736226, 54.28890895843506, 52.91166482652937, 55.33955996377127, 53.75219535827637, 57.4413275037493, 54.06901584352766, 54.06009783063616, 54.80664355414254, 54.436749253954204, 47.063786438533235, 51.09321008409773, 49.61546720777239, 52.9421500478472, 52.926780632564, 45.42388997759138, 41.314534255436485, 43.73774978092739, 44.47570405687605, 34.52972602844238, 39.11422388894217, 36.4702536719186, 35.22218697411673, 36.15046977996826, 38.70289748055594, 37.236546175820486, 37.857253074645996, 37.54954515184675, 40.77997807094029, 36.85931805201939, 37.8090568951198, 41.15553167888096, 38.40889140537807, 39.93048088891165, 38.808805397578645, 47.12155376161848, 42.00791931152344, 38.159398964473176, 36.99936594281878, 38.167948722839355, 41.16461297443935, 37.607705048152376, 38.43873044422695, 38.039361885615754, 37.875106470925466, 38.178899083818706, 39.529302324567524, 45.66754593167986, 51.49872432436262, 52.199088845934185, 53.25989464351109, 51.38689654214041, 52.044265610831125, 50.96854897907802, 52.88898243222918, 50.80644750595093, 52.52448688234602, 52.10569116047451, 51.52407830102103, 55.418960503169465, 53.10243804114205, 54.592236042022705, 50.479687622615266, 53.174952915736604, 51.290386063711985, 53.24540070125035, 49.26917246409825, 45.373942852020264, 44.66480622972761, 44.02226114273071, 42.58158343178885, 40.0408912386213, 40.998960971832275, 42.42963327680315, 45.07559067862374, 45.76289258684431, 45.23152909960066, 48.77742065702166, 52.38647828783308, 55.32950244631086, 53.99600764683315, 55.6957802091326, 55.631693499428884, 58.72591045924595, 55.33529724393572, 58.939914975847515, 57.01116452898298, 56.12056875228882, 52.29443550109863, 49.19533395767212, 49.6292211668832, 55.619537625994, 60.44325501578194, 68.69827774592808, 67.11314351218087, 72.7983958380563, 66.20929404667446, 75.01498930794853, 61.99475996834891, 80.59595612117222, 11.328098927225385, 1.8948816699641091, 60.184517996651785, 54.72106606619698, 35.29191909517561, 68.09698063986642, 94.21554401942662, 26.509908505848475, 69.06159210205078, 18.44143795967102, 0.06848958094737359, 0.03384048877550023, 0.08612101485154458, 0.06552876625210047, 0.07554554446999516, 0.10749520042112895, 0.034620736193444045, 0.038122723278190405, 0.02763843782512205, 0.09942577020930392, 0.21042490511068276, 0.18838668481579848, 0.3046601877680847, 0.12285529263317585, 0.07302771136164665, 0.13144308967249735, 0.1709611862897873, 0.11956409923732281, 0.17292459521974834, 0.187742714371, 44.74250446047102, 67.94586426871163, 39.647122928074424, 26.88486977985927, 47.128356048039024, 57.65733310154506, 75.31747218540737, 52.75785255432129, 0.8983646226780755, 60.934485707964214, 72.86363247462681, 71.36415563310895, 66.83139405931745, 67.17011179242814, 68.28569371359688, 65.56774602617536, 61.166472162519185, 52.856395380837576, 54.63288995197841, 52.64552797589983, 51.411972590855186, 49.33259909493582, 47.371011461530415, 49.258743218013215, 51.17042541503906, 60.62130955287388, 58.03910187312535, 60.305041449410574, 60.230035645621165, 57.355211530412944, 57.96316501072475, 53.18098742621285, 49.35455887658255, 49.984135150909424, 46.10504273005894, 46.51151234763009, 44.47682966504778, 45.819999831063406, 43.597962447575156, 46.46507058824812, 43.5851742880685, 48.562919344220845, 46.32768038340977, 51.08255502155849, 50.081180640629356, 55.57070221219744, 59.09248352050781, 54.24236992427281, 54.36353261130196, 58.41128213065011, 55.988858699798584, 59.85348497118269, 56.179211548396516, 56.187598024095806, 57.613187721797395, 56.38892902646746, 49.69674028669085, 51.76002870287214, 51.16443954195295, 55.229757581438335, 55.63096741267613, 50.280409812927246, 42.14868981497628, 32.41636889321463, 42.9194986479623, 39.09987585885184, 43.499836512974326, 38.27384621756417, 36.25803484235491, 39.828318050929475, 41.88030522210257, 40.901950223105295, 41.3918433870588, 41.35649790082659, 43.0028110231672, 38.803625515529085, 38.834770815713064, 41.84048162187849, 40.906681946345735, 41.23255940846035, 40.84396750586373, 50.40882641928536, 44.345519133976524, 42.686247621263774, 40.444727488926475, 42.26623943873814, 44.38594027927944, 40.40870107923235, 41.68788875852312, 41.58367272785732, 41.129250117710654, 42.202343804495676, 41.864188875470845, 48.776948179517476, 53.347066743033274, 54.75536584854126, 56.42798137664795, 52.45672457558768, 55.29210376739502, 55.542409147535054, 55.733130250658306, 52.76274756022862, 55.437508719308035, 51.475208146231516, 55.13212844303676, 56.9370550428118, 55.903388908931184, 57.28411061423165, 54.40747996738979, 56.040970189230784, 52.64022650037493, 55.78017997741699, 52.569889886038645, 47.48678234645298, 46.45160845347813, 46.02453047888619, 44.008302211761475, 42.40803132738386, 44.14396578924996, 44.51542343412127, 48.23273399897984, 48.242583070482524, 48.02100849151611, 49.26256472723824, 54.14290993554251, 59.83849770682198, 57.057773045131135, 59.476635524204795, 58.534042903355186, 62.603672300066265, 57.295109612601145, 63.67050565992083, 57.926791191101074, 57.823923110961914, 54.332251821245464, 53.279658794403076, 53.75433540344238, 57.65569332667759, 62.80397496904646, 70.28236280168805, 70.04832662854875, 73.97234957558769, 66.57351166861397, 80.63232299259731, 64.73552553994315, 84.94352040972028, 23.5993880203792, 2.640395585979734, 63.76627268110003, 62.36796855926514, 42.89448165893555, 70.40710381099156, 94.55558885846818, 35.35999059677124, 82.56972394670758, 23.219889572688512, 0.2713100016117096, 0.12056508766753332, 0.17667754526649201, 0.22800483820693834, 0.18772275187075138, 0.29691796749830246, 0.1553517731704882, 0.1600126437842846, 0.15400037568594727], [0.0641740168045674, 0.06565975743745055, 0.0837645237999303, 0.1344011766569955, 0.11261216870376042, 0.0809261439634221, 0.041841383557766676, 0.02537458885594138, 0.055790855748845, 0.16308168481503213, 0.05890855113310473, 20.89338254928589, 54.06720583779471, 36.04759822572981, 29.767868450709752, 24.79144355228969, 43.78076260430472, 48.718284538814, 65.37453746795654, 1.4588675520249774, 23.416342939649308, 72.60978698730469, 59.81986263820103, 68.4187239238194, 59.455464363098145, 63.38278770446777, 59.308391843523296, 59.77074582236153, 50.02228076117379, 48.34981461933681, 46.0362104007176, 43.10515104021345, 43.741244724818635, 43.041012219020296, 45.68280764988491, 51.25296654020037, 52.55860948562622, 55.36289896283831, 52.4480219568525, 55.359087875911165, 51.540205069950645, 50.56596687861851, 46.603822640010286, 42.62554815837315, 41.38916833060128, 43.45109837395804, 41.20811217171805, 39.489708014896934, 38.72696604047503, 38.533406598227366, 39.9093132019043, 40.24539409364973, 42.224380016326904, 42.90461213248116, 45.394103050231934, 46.82287154878889, 47.7181921005249, 52.67941434042794, 48.98776347296578, 51.30916357040405, 52.97931943620954, 53.2242990221296, 52.041736466544016, 54.24027851649693, 52.28930425643921, 51.54595123018537, 50.95879718235561, 49.25896903446743, 44.533033643450054, 44.84822130203247, 44.45945569447109, 52.53329719815935, 42.35956416811262, 37.38043989453997, 24.969819443566458, 37.526327746255056, 37.858753885541645, 35.39886924198696, 35.85473707744053, 32.68758487701416, 34.64503138405936, 39.298208713531494, 37.81148181642805, 37.623216901506694, 36.46896825517927, 41.000281129564556, 37.15978247778756, 39.19389888218471, 39.9491993359157, 38.673610823495046, 42.04384497233799, 39.48351716995239, 37.77096339634487, 41.660808154514854, 36.66099909373692, 36.024630955287385, 34.31909486225673, 38.181720052446636, 39.327064582279746, 38.49493442262922, 35.53308064596993, 36.33291210447039, 36.80287088666643, 41.1869410106114, 46.41576269694737, 51.923585823604036, 51.96615048817226, 49.14040844781058, 48.661448274339946, 48.831039905548096, 51.89872169494629, 50.49791969571795, 49.436335699898855, 51.60183211735317, 49.28271450315203, 47.84594515391758, 49.80613619940621, 49.87688970565796, 50.92624487195696, 50.1075108391898, 50.03440884181431, 47.11743695395333, 46.29969303948538, 47.4185961995806, 46.19517476218087, 41.513155460357666, 39.53383602414812, 40.34722341809954, 35.669987951006206, 37.5574244090489, 41.9288592338562, 42.26057318278721, 44.342406341007774, 43.79867506027222, 45.215166091918945, 48.58117921011788, 50.096265179770334, 50.76123210362026, 50.98627035958426, 51.0707882472447, 52.23917300360543, 55.975500788007466, 54.86375774656023, 54.54372371946062, 54.13164690562657, 54.172651699611116, 51.27455806732178, 47.472934586661204, 52.262254919324604, 60.833000319344656, 62.4008126940046, 60.911667823791504, 63.55913298470633, 70.17850807734898, 72.8697816303798, 62.819809913635254, 66.2769695009504, 3.590887874364853, 2.4475995770522525, 66.03519998277936, 41.808502537863596, 42.05148104258946, 33.8639600617545, 40.00782128742763, 44.46065425872803, 59.27193464551653, 17.19878738267081, 0.28478467570883886, 0.10546492186508008, 0.017642551700451543, 0.05309394707104989, 0.08303544470774275, 0.05128670636830585, 0.04224697447248867, 0.03793485728757722, 0.06208771161202874, 0.04716928802164538, 0.06470959806548697, 0.08867526493434395, 0.03822820833218949, 0.02467728216600205, 0.08709689748606511, 0.016706853606072918, 0.017803734301456382, 0.0460164129201855, 0.1075214325849499, 0.0915354053889002, 23.635086127689906, 62.06569412776402, 31.063585894448416, 29.13271972111293, 33.8033960887364, 49.155291489192415, 52.9541461127145, 72.52280943734306, 2.0656175826277052, 22.679623706000193, 78.20986829485211, 61.81003516060965, 72.27566201346261, 64.39741230010986, 68.61544132232666, 63.29898548126221, 64.14417130606515, 55.377326897212434, 51.30699920654297, 47.477617672511506, 48.052549839019775, 46.09713568006243, 45.68067455291748, 50.45228392737252, 57.066871711185996, 57.496607371738975, 59.29705933162144, 53.47895744868687, 58.835400172642295, 55.19272368294852, 52.94773292541504, 47.252923352377756, 46.062721252441406, 45.534237793513704, 45.34950951167515, 43.544471740722656, 41.76241513660976, 40.1038384437561, 40.62442874908447, 42.79840891701834, 41.21873944146292, 43.29592425482613, 44.484816619328086, 48.36828293119158, 48.167379243033274, 48.958535875592915, 54.83845240729195, 51.51324953351702, 53.3027719770159, 52.653855391911094, 54.682472297123496, 53.0478321484157, 54.64835664204189, 55.01358870097569, 51.93757254736764, 53.093791007995605, 52.08651065826416, 47.805284295763286, 46.74964795793806, 49.06956461497715, 52.89393302372524, 48.28849329267229, 39.153887680598665, 42.79417398997715, 47.38162136077881, 36.986279010772705, 38.46823596954346, 35.68151501246861, 35.974861008780344, 36.49028532845633, 40.04090166091919, 39.419083050319124, 36.46621676853725, 38.48006180354527, 40.871798515319824, 35.92069632666451, 39.05488974707467, 40.56771060398647, 38.8091528075082, 43.100488798958914, 39.740954875946045, 38.48453991753714, 42.61136341094971, 39.4679080418178, 37.89413411276681, 36.340746198381694, 39.725981507982524, 40.47332280022757, 38.32735429491316, 37.50718545913696, 37.12267909731184, 40.130311080387656, 41.53163072041103, 49.07810395104544, 53.167097977229524, 53.553480352674214, 52.447966371263774, 48.462993826184956, 50.90132515771048, 51.470525060381206, 52.08000714438302, 51.77119793210711, 53.716683115277974, 51.6458489554269, 51.3275728225708, 51.45051424843924, 52.0226845060076, 52.655342306409565, 52.906894888196675, 52.35541984013149, 49.169156619480674, 50.53348405020577, 50.015513215746196, 47.152573994227815, 43.70436021259853, 42.55230719702584, 42.86234276635306, 39.6775803565979, 41.254147461482454, 42.73614263534546, 45.621851103646414, 46.43796566554478, 46.572805881500244, 48.86397784096854, 51.254943302699495, 54.693836075919016, 52.55331495829991, 54.44618490764073, 54.46724142347063, 58.65069620949881, 58.32301916394915, 58.9001156943185, 56.42437873567854, 56.798535755702424, 56.15795006070818, 52.65797219957624, 49.08288778577532, 54.83321346555437, 63.9157075881958, 66.7090015411377, 64.19644260406494, 64.45729187556675, 70.105482510158, 77.81625284467424, 63.81921795436314, 67.12494155338833, 3.3213815816811154, 3.038612046412059, 71.4747223172869, 45.008332116263254, 44.948073863983154, 41.54500947679792, 54.80407966886248, 45.92901359285627, 66.0706010546003, 23.38257990564619, 0.261998709823404, 0.09216205283467259, 0.024854624078476002, 0.03503765185762729, 0.014501589350402355, 0.014325794497770923, 0.05817934311926365, 0.036498100097690306, 0.015089124341362288, 0.1220482023698943, 0.15547343449933188, 0.26431327419621603, 0.3514564409852028, 0.12233911747378962, 0.17508282512426376, 0.10182802166257586, 0.12726110193346227, 0.15059157860066208, 0.2785460076161793, 0.25390351563692093, 32.8454201562064, 70.30272797175816, 46.23295906611851, 40.63203355244228, 38.021946225847515, 58.15827737535749, 57.492973463875906, 77.1628998347691, 1.9149637009416307, 29.79836756842477, 82.19905839647565, 65.20398698534284, 74.58201926095145, 65.69465487343925, 70.4665595463344, 63.81001853942871, 65.89652783530099, 55.80052777699062, 53.64207683290754, 50.180310589926584, 49.07520655223301, 49.56587791442871, 48.62222221919468, 51.803746768406455, 58.32470757620675, 58.31935051509312, 59.24688638959612, 54.83055925369263, 61.18564919063023, 58.451567786080496, 55.78379304068429, 51.78373943056379, 48.33851337432861, 45.78517893382481, 49.74158048629761, 46.675854614802766, 43.076111044202534, 42.237637179238455, 43.94488947732108, 45.83654349190848, 43.52991873877389, 46.48324360166277, 46.913694926670615, 50.13363606589181, 49.594428062438965, 52.12227998461042, 57.6826662336077, 51.63863672528948, 57.03718900680542, 54.52723217010498, 57.771221024649485, 54.55083867481777, 56.55175311224801, 55.08804212297712, 56.16283117021833, 54.74859135491507, 53.740060329437256, 48.72983244487217, 48.5902361869812, 52.57554571969168, 55.26992859159197, 51.53381272724697, 42.89602415902274, 32.24596779687064, 42.87363706316267, 40.149706976754324, 41.10286085946219, 39.54979951041085, 35.770187922886436, 38.898280824933735, 43.28030470439366, 42.049994128090994, 42.28386354446411, 40.988139152526855, 43.171217986515586, 36.90878227778843, 39.792962142399375, 41.03553976331438, 40.22427156993321, 43.4079396384103, 39.99832309995379, 39.357428210122244, 47.33917134148734, 43.24001210076468, 40.362141200474326, 40.07833160672869, 44.16900709697178, 45.12401614870344, 41.22594472340175, 39.289530413491384, 39.56942817143032, 42.05975982121059, 43.464223521096365, 49.72614506312779, 55.9469575881958, 55.69833019801548, 56.6057128225054, 49.660182339804514, 52.64830378123692, 53.52334254128592, 52.626896381378174, 53.73695795876639, 55.90738064902169, 53.300374848502024, 52.41648408344814, 54.90658644267491, 52.20682566506522, 55.25041804994856, 56.13844994136265, 53.175915241241455, 50.49070051738194, 52.85741329193115, 51.54947396687099, 49.99654810769217, 45.302022048405235, 42.786009856632774, 46.227744443076, 41.15224865504673, 43.61380434036255, 45.25643491744995, 47.43000514166695, 50.42898314339774, 48.19395957674299, 50.15109688895089, 54.35368353979928, 55.72916977746146, 55.757455893925254, 57.05629655293056, 56.75066614151001, 60.78903906685965, 61.65234579358782, 60.897938183375764, 60.39737606048584, 59.78667804173061, 59.7640060697283, 56.7752662386213, 51.321375029427664, 59.00168446132115, 66.67562934330532, 70.0798089163644, 66.14601680210659, 70.27403885977608, 72.09960855756486, 79.3349414552961, 65.12409659794399, 79.10870116097587, 11.12320784160069, 2.4688267580100467, 77.76211248125348, 50.27732828685215, 56.85699095044817, 45.959929602486746, 54.16853141784668, 55.109998430524556, 76.78211770738874, 27.859960862568446, 0.3993302078119346, 0.3074392500732626, 0.11113370196627718, 0.13056140126926558, 0.17753507782305988, 0.12134838849306107, 0.13262857177427836, 0.1673106543187584, 0.09306729997375182], [0.08700593986681529, 0.023632911599374244, 0.10123952824090209, 0.30933181994727676, 0.069943457575781, 0.02400129843902375, 0.04406583848010216, 0.0708158907613584, 0.015139622613787651, 0.0912213861676199, 0.09441483659403664, 15.759476729801722, 53.53781563895089, 49.75047070639474, 52.23673071180071, 34.056800365448, 41.810079778943745, 43.435273851667134, 73.95932865142822, 6.868596119540078, 4.8231189761843, 66.30811132703508, 57.642311096191406, 66.71293422154018, 59.90626348767962, 64.85406875610352, 58.86354037693569, 59.06329413822719, 50.348589011601035, 49.54338659558977, 45.76268066678728, 44.7100806917463, 42.60942138944353, 48.83582721437727, 51.22369030543736, 53.08428239822388, 53.42875323976789, 50.59366239820208, 54.02996696744646, 55.32883194514683, 51.0388126373291, 46.262558392116, 43.53422314780099, 44.033590180533274, 42.14395809173584, 43.586848803928916, 42.304284300122944, 40.27034854888916, 38.776332991463796, 38.05899402073452, 39.53298486982073, 37.775146211896626, 40.02603946413313, 42.76567595345633, 45.97523300988333, 49.01355518613543, 44.237596239362446, 51.44503211975098, 52.342339856284006, 50.19764287131173, 52.463155133383616, 52.39193957192557, 52.64075803756714, 55.32859223229544, 50.88502468381609, 53.45944690704346, 51.852738516671316, 52.42848014831543, 44.650805609566824, 42.256230558667866, 43.45208501815796, 56.20337043489729, 47.18831205368042, 40.375450474875315, 25.086448431015015, 37.99164860589163, 42.14640038354056, 38.16371726989746, 36.098823819841655, 31.366172994886124, 34.362541948046, 34.92410578046526, 34.28409331185477, 36.73337500435965, 37.14542055130005, 37.97090128489903, 34.30738714763096, 39.80755683353969, 38.10363967078072, 36.96459715706961, 37.03598294939314, 38.95655536651611, 38.53884008952549, 44.36853156770979, 44.23814514705113, 40.1325866154262, 37.84053223473685, 34.35781717300415, 38.856167793273926, 41.01883281980242, 39.36895179748535, 36.46636962890625, 38.20484365735735, 46.09299455370222, 50.77102558953421, 51.24229758126395, 51.79340784890311, 49.58698306764875, 50.44306019374302, 51.04807806015015, 51.86606863566807, 48.382735184260774, 49.61575903211321, 50.81402104241507, 51.274231501988, 50.57387045451573, 52.00581080572945, 48.38437148502895, 48.92614337376186, 49.76478052139282, 49.358217103140696, 43.87629338673183, 44.808856282915386, 45.600645201546804, 43.86977597645351, 38.81183133806501, 39.871820722307476, 40.18413182667324, 37.60267455237252, 39.79603672027588, 43.81186274119786, 40.55864667892456, 43.335191999162944, 46.272907733917236, 46.8393109866551, 47.91168553488595, 50.04116249084473, 54.73266608374459, 50.49244104112898, 50.62187555858067, 50.11951037815639, 50.23469066619873, 55.263758591243196, 52.321158272879465, 54.85485015596662, 54.68190254483904, 55.05491311209542, 49.80951649802071, 50.37540210996355, 59.68288585117885, 64.09910529000419, 61.1001307623727, 63.82606887817383, 59.9872864314488, 70.14462171282086, 64.75667585645402, 40.10603754861014, 0.4716705360582897, 8.167339938027517, 62.181798526218955, 39.32995503289359, 41.09484611238752, 33.150717054094585, 50.41439887455532, 33.538033962249756, 63.34673350197928, 15.477009875433785, 0.26290783818278995, 0.08847806908722435, 0.02449214049348874, 0.033324493427893946, 0.03611848011080708, 0.12747458262102945, 0.044534299056977034, 0.05241248417379601, 0.11385468845920903, 0.030011641194245646, 0.06219390234244721, 0.11959371050553662, 0.18505572926785263, 0.013986662695450442, 0.01803778817078897, 0.018807638735909547, 0.05486108635419181, 0.06724868967596974, 0.10332313964941672, 0.12196464756769793, 19.71009738104684, 65.04340716770717, 40.697482109069824, 48.39492579868862, 40.446426323481965, 50.42921938214983, 47.47795466014317, 81.72611536298479, 9.204665166991097, 4.7220265950475415, 70.34329850333077, 59.67857101985386, 69.59269850594657, 63.96855558667864, 66.05301516396659, 61.824737548828125, 62.44269643511091, 55.043736934661865, 55.55708026885986, 48.780436175210134, 48.615013463156565, 45.020818029131206, 50.81465680258614, 56.49712984902518, 56.98708207266671, 55.98817777633667, 54.66724531991141, 58.92114094325474, 59.23884037562779, 52.92305639811924, 50.82561411176409, 45.57387031827654, 47.250880581992014, 44.39602211543492, 46.18028129850115, 43.70026772362845, 41.53053290503365, 42.010556152888704, 40.380397592272075, 41.2227520261492, 40.9079395702907, 42.800778252737864, 45.024257387433735, 47.98283856255667, 50.92021036148071, 45.72212403161185, 51.84678391047886, 53.104373114449636, 51.98016153063093, 54.31753206253052, 53.7002888407026, 55.43852315630232, 55.972026688711985, 51.59261185782296, 54.706645080021445, 53.40088748931885, 53.07810892377581, 48.68307106835501, 41.6710775920323, 50.079568658556255, 54.92644092014858, 49.62616743360247, 40.606912340436665, 39.30826275689261, 55.20604337964739, 40.789375509534565, 39.330872195107595, 35.628785133361816, 34.09741953441075, 36.64504255567278, 38.068123953683035, 35.94728708267212, 39.26167161124093, 40.30078860691616, 38.13052919932774, 34.0842353275844, 40.92065824781145, 37.15505770274571, 36.298421246664866, 36.0891102382115, 39.655099460056846, 37.74476868765694, 43.35212128502982, 42.7145927974156, 42.07515008108956, 40.64279978615897, 35.68716042382376, 39.19668858391898, 43.3389961378915, 41.02532243728638, 36.73539693014962, 39.7619697025844, 47.17960943494524, 51.326822417122976, 53.348817689078196, 50.9789400100708, 50.943674428122385, 51.47835220609392, 52.9833528654916, 51.60153334481375, 51.38631636755807, 52.793403012411936, 53.62182283401489, 50.88915886197771, 52.21008437020438, 54.082929611206055, 51.37451485225132, 51.341201714106965, 51.2176627431597, 51.14093031202044, 45.84789684840611, 46.66872576304844, 49.56433194024222, 44.71114376613072, 40.86241149902344, 41.5192038672311, 40.55564158303397, 40.08627339771816, 42.371685300554546, 45.20266628265381, 43.47420808247158, 46.8586790902274, 48.0695937701634, 51.488798822675435, 51.466005257197786, 55.45569215502058, 57.39163051332746, 55.30367251804897, 54.06849125453404, 56.338974952697754, 53.88406869343349, 56.86274405888149, 56.0477168900626, 58.06574126652309, 58.40354183741978, 58.08838544573103, 51.255485262189595, 51.945837429591585, 63.30158410753523, 68.29330893925258, 64.55974306379045, 67.23226342882428, 62.90007550375802, 72.8065321786063, 66.48319203513009, 44.62867559705462, 0.5065947334681238, 10.937107290540423, 69.39441776275635, 42.61987842832293, 50.20219046728951, 42.63218021392822, 57.87113612038748, 38.93187189102173, 70.95059885297502, 18.73407350267683, 0.2640658803284168, 0.05895351764879056, 0.01835215005225369, 0.04257567719157253, 0.0560275626901005, 0.06658660913152353, 0.032098784377532344, 0.007128620204249663, 0.038956859947315285, 0.17115463662360395, 0.122988760471344, 0.17858535503702505, 0.37258686284933773, 0.1811062347676073, 0.08618343328791005, 0.19611597220812524, 0.11357739833848816, 0.23312840184995107, 0.19196044733481749, 0.3798862440245492, 26.177932262420654, 75.20040893554688, 62.4427033833095, 71.91031183515275, 46.64294794627598, 58.431348528180806, 52.41680370058332, 89.91881969996861, 8.898282613073077, 8.121859635625567, 74.33788735525948, 63.94895471845354, 74.40294333866665, 63.986884934561594, 68.15023163386753, 64.1840956551688, 65.02298641204834, 54.94513504845755, 58.965255056108745, 51.77502291543143, 50.910607951028005, 47.152351651872905, 53.01011732646397, 57.90387255804879, 59.32162816183907, 58.174907888684956, 56.69812733786446, 60.271162033081055, 62.494140897478374, 55.285634994506836, 53.470362527029856, 47.568729400634766, 50.55497482844761, 46.867159366607666, 49.13620826176235, 47.2789443561009, 44.78020191192627, 44.69827222824097, 43.59780958720616, 44.04350525992257, 42.738171509334016, 46.1534925188337, 48.85696016039167, 52.36085333142962, 54.515614782060894, 47.71085827691214, 55.87529386792864, 53.901477405003135, 52.79475096293858, 55.22248976571219, 55.943462644304546, 58.123317514147075, 59.44248512813023, 54.467574937003, 61.15672383989607, 53.372295652117046, 54.28812033789498, 50.32787643160139, 42.93237018585205, 50.10684381212507, 60.62501294272286, 51.302305698394775, 46.36629499707903, 33.55497019631522, 44.36496366773333, 43.70820951461792, 41.23224326542446, 38.49796036311558, 34.1608635357448, 38.55937549046108, 41.276607513427734, 38.75976153782436, 40.512962273189, 42.26053844179426, 38.97650711877005, 34.180846554892405, 40.88495145525251, 39.78523227146694, 37.03427716663906, 36.543129852839876, 41.41824654170445, 40.026216643197195, 48.655608313424246, 47.821320738111226, 44.60886280877249, 42.92394549506051, 40.9426805632455, 42.74089520318167, 46.635551588875906, 44.81982054029192, 40.856825147356304, 40.74696717943464, 49.056265762874055, 52.49156979152134, 55.36133214405605, 55.31363276072911, 54.466088022504536, 53.98561314174107, 54.42128603799002, 55.267788546425955, 53.22220761435372, 54.88593292236328, 54.94514199665615, 52.61347940989903, 53.52567366191319, 57.478712286267964, 54.29367889676775, 53.18550722939627, 53.467777797154014, 52.53515236718314, 46.61059365953718, 48.6019161088126, 50.85356671469552, 47.54410151072911, 43.519558974674766, 44.61383424486433, 45.70784548350743, 42.58739559991019, 44.83999810900007, 48.938340936388286, 45.90017509460449, 51.130296094076975, 51.073939255305696, 52.7201064654759, 52.605509826115195, 58.204694816044395, 59.341541699000764, 57.98281799043928, 55.78773961748396, 58.44196537562779, 57.030376298086985, 61.66790975843157, 60.82985973358154, 60.723830223083496, 60.69429343087332, 61.87496607644217, 53.907334736415315, 55.74141250337873, 65.53938347952706, 72.38195555550712, 65.51248005458287, 67.77848216465541, 65.14145319802421, 80.38888590676444, 65.01913711002895, 61.79410294124058, 2.377439707517624, 9.488140378679548, 78.46936961582729, 47.985207898276194, 56.993321555001394, 46.73847525460379, 64.31804997580392, 44.11677401406424, 80.24424525669643, 25.84163076536996, 0.4554501292960984, 0.22606599224465235, 0.11853311955928802, 0.12119897508195468, 0.13023831003478595, 0.19714638191674436, 0.14549667627683707, 0.2351041872586523, 0.1499905322811433], [0.011170060440365757, 0.08834210424018757, 0.0389179934614471, 0.14345150387712888, 0.08071397284844092, 0.14679323456117085, 0.05573737022600003, 0.09004064702561923, 0.045785168185830116, 0.14391609680439743, 0.12414573053164141, 11.720196196011134, 55.32133483886719, 42.0913393838065, 38.192336899893625, 31.63751057216099, 29.008958407810756, 32.96814966201782, 63.41273444039481, 23.140237161091395, 0.10885247401893139, 49.47728838239397, 57.3946008682251, 62.145202364240376, 62.57592119489397, 64.3571891784668, 61.79422800881522, 57.00087077277047, 51.08409752164568, 48.27338096073696, 44.69092798233032, 45.62779181344168, 44.19775526864188, 52.23523684910366, 52.184792927333284, 53.80361897604806, 52.82696281160627, 49.18003402437483, 54.95648145675659, 51.06872115816389, 51.11807073865618, 48.771594592503135, 44.68621710368565, 42.86628239495413, 42.68674094336373, 42.36773872375488, 40.96566867828369, 39.11395985739571, 37.565077849796836, 37.59257187162127, 38.897207328251426, 38.772327354976106, 40.65237440381731, 39.912450313568115, 42.4855489049639, 45.20518153054373, 44.38932057789394, 49.39121062414986, 50.19921316419329, 52.85665593828474, 49.65731273378645, 52.0357540675572, 49.91916254588536, 50.66961315699986, 51.358832768031526, 50.36478526251656, 52.61292355401175, 52.50140496662685, 41.17911039079939, 39.3018148286002, 44.01916919435774, 51.38669504438128, 49.52132606506348, 44.63367830004011, 21.847205196108135, 37.111468178885325, 47.545685700007844, 39.599301951272146, 38.49139778954642, 30.17462294442313, 33.334142548697336, 35.57540559768677, 40.38259322302682, 40.947978564671104, 43.654944624219624, 38.35149233681815, 39.17614623478481, 34.54594659805298, 35.48132698876517, 37.331430775778635, 37.70649800981794, 38.090445041656494, 39.99090242385864, 32.41696991239275, 34.029441833496094, 36.58365174702236, 39.24269608088902, 38.54076474053519, 41.67244986125401, 39.81270892279488, 36.76468358721052, 43.0548426083156, 48.59983859743391, 52.44857781273978, 52.35156011581421, 51.49321092878069, 48.4715644291469, 47.48613963808332, 49.39561230795724, 52.20248304094587, 49.243943555014475, 48.36638607297625, 48.39410591125488, 49.792993681771414, 50.140497412000386, 49.80225215639387, 50.741419315338135, 49.891550404684885, 50.87978574207851, 48.94795376913888, 45.45052242279053, 44.40869562966483, 42.207110268729075, 41.58943278448922, 40.416688033512656, 40.068235874176025, 39.11848313467843, 38.44426121030535, 38.950562545231406, 40.99292298725673, 41.292206219264436, 40.69703047616141, 39.7533643586295, 48.00181061880929, 47.705529008592876, 49.492213112967356, 51.28457736968994, 53.344923223767964, 51.31454495021275, 49.17184904643467, 51.310914516448975, 51.79860857554844, 52.16227728979928, 54.683757713862825, 54.08561161586216, 56.85857513972691, 58.131033488682334, 52.14844342640468, 49.22296346936907, 57.853532859257285, 63.60326794215611, 64.61985887799943, 63.799575396946494, 65.66210256304059, 59.122249603271484, 60.35248374938965, 32.36141906465803, 0.4400397576391697, 21.264558792114258, 60.05742849622454, 38.29308925356184, 35.70710870197841, 32.500306606292725, 35.91045468194144, 32.836839130946565, 62.169819831848145, 10.614849839891706, 0.4110427807484354, 0.1904267817735672, 0.02725744210848851, 0.052369512551065, 0.03581576528293746, 0.08838544227182865, 0.05251685643036451, 0.04359721505482282, 0.05828618524330003, 0.020479718655613915, 0.07174781789737088, 0.043759809008666446, 0.023780360651601638, 0.07066739337252718, 0.05911465614501919, 0.030623153916427066, 0.14430431382996695, 0.06985834892839193, 0.18791255168616772, 0.05937953586024897, 13.750531911849976, 64.92489869253976, 45.23956816537039, 43.029915945870535, 37.41322496959141, 36.88026687077114, 38.41719797679356, 69.47349521092006, 28.11824972288949, 0.1190283822693995, 50.910229274204795, 60.115661348615376, 66.08050918579102, 66.87203407287598, 67.6612104688372, 63.59652818952288, 59.72948047092983, 53.91966431481497, 51.267540386744905, 49.10269362585885, 48.58895771844046, 48.72024393081665, 56.480124132973806, 54.70092323848179, 58.64237226758684, 53.814729145595, 53.196058068956646, 57.403369494846885, 55.54865905216762, 54.08908918925694, 51.24119629178728, 47.56044019971575, 46.89416354043143, 44.39538982936314, 44.86356292452131, 43.415996074676514, 41.031707831791465, 41.25292805262974, 40.68616349356515, 38.521400111062185, 42.13878863198416, 40.78029768807547, 41.9904967035566, 44.6770315851484, 45.00835296085903, 43.95021874564034, 49.60520819255284, 51.59848655973162, 53.99889809744698, 53.442507198878694, 51.529855728149414, 52.09009592873709, 51.60727603094918, 52.22765289034162, 55.459128039223806, 55.2588392666408, 52.91460738863264, 42.587274006434846, 37.10899462018694, 46.07716655731201, 53.28814254488264, 53.4036910874503, 46.64411524363926, 29.940809113638743, 56.22908571788243, 48.437000615256174, 41.19477163042341, 38.519187109810964, 35.19399118423462, 37.35993923459734, 38.74990899222237, 41.264541966574534, 41.203547205243794, 41.850372382572715, 39.488912446158274, 39.305876050676616, 36.51183516638619, 34.75111648014614, 36.02342196873256, 36.56958859307425, 39.444923400878906, 40.821514402117046, 35.303362778254915, 36.65236248288836, 37.34122426169259, 40.82629476274763, 41.44071701594761, 42.44721916743687, 41.66421972002302, 35.774426324026926, 42.80012164797102, 53.38940906524658, 53.048273359026226, 52.65567234584263, 52.25724874223982, 50.09325660978045, 50.471506118774414, 50.52197783333914, 53.01289660590035, 50.479496547154014, 47.895906175885884, 49.14226361683437, 51.152419158390586, 52.50296483721052, 52.58857011795044, 54.206010001046316, 51.89716877256121, 51.96142223903111, 50.10925136293684, 46.95111445018223, 46.6593839100429, 43.1964955329895, 44.945655890873496, 41.81491572516305, 41.842475754874094, 42.10982159205845, 40.80062116895403, 42.59666797092983, 42.44036476952689, 43.304734570639475, 41.37626205171858, 45.636428424290244, 49.618882247379844, 50.4970372744969, 53.13489655085972, 55.91834838049752, 55.18042884554182, 54.04576369694301, 54.52216693333217, 55.120448521205354, 56.74855388913836, 56.873305320739746, 57.57304103033883, 57.28924880708967, 59.21502889905657, 59.99878570011684, 54.36547463280814, 50.82832390921456, 59.781974111284526, 65.4029208592006, 67.66367013113839, 67.75394112723214, 66.34063584463937, 61.3984933580671, 64.85282502855573, 39.66760969161987, 0.32202398031949997, 25.358918564660208, 63.67400755201067, 40.79709843226841, 46.393309593200684, 37.30953005381993, 43.12057604108538, 31.365724836077007, 67.28545883723667, 13.18679416179657, 0.39956123541508404, 0.1553017379982131, 0.0368585107581956, 0.0193771416587489, 0.0751520823687315, 0.04068548558279872, 0.026914747997320125, 0.02485037305658417, 0.06395385933241673, 0.10194992047867604, 0.15241789631545544, 0.15849994495511055, 0.19332803466490336, 0.15930681808718614, 0.2289235746221883, 0.0974905544093677, 0.3150502959532397, 0.1694081010563033, 0.20084599911102227, 0.15602790617517062, 18.781119755336217, 79.14836147853306, 52.942052773066926, 53.555669035230366, 46.05218430927822, 44.26443713051932, 44.196904114314485, 76.47872461591447, 28.44575653757368, 0.3136994684381144, 58.82907036372593, 59.462857246398926, 69.5921357018607, 67.22799723488944, 71.80273287636894, 66.33624458312988, 62.82743903568813, 56.09212282725743, 54.89567082268851, 52.16042212077549, 52.200811999184744, 50.388096468789236, 58.722165380205425, 56.097584111349924, 58.96568584442139, 55.71237250736782, 53.88374212809971, 59.191905294145855, 59.14394187927246, 57.256349086761475, 56.857988016945974, 50.95683779035296, 49.52394206183297, 45.968246596200125, 47.41356222970145, 46.24740784508841, 42.5309727532523, 43.22537224633353, 43.73303542818342, 42.137503215244834, 45.01517609187535, 43.10353558404105, 45.539855412074495, 45.79438877105713, 47.34056792940412, 45.535620485033306, 54.49161570412772, 53.16484676088606, 57.37428433554513, 53.413019044058665, 55.84478085381644, 53.18585811342512, 54.9142746244158, 54.328829833439414, 56.59552328927176, 57.95041854040963, 55.7470440183367, 43.90189402444022, 38.91840975625174, 46.02372101375035, 57.07758583341326, 53.05219561713082, 54.25511986868722, 29.79562302998134, 43.548275879451204, 52.13985892704555, 42.62394659859793, 40.83744314738682, 34.70380967003958, 37.87242099217006, 40.50575351715088, 43.73316049575806, 45.40010976791382, 44.63404655456543, 39.23892320905413, 38.85124846867153, 36.660481452941895, 35.12650680541992, 35.58873224258423, 37.20330599376133, 38.841923986162456, 40.58034242902483, 35.893216201237266, 38.32776076453072, 42.79105077471052, 43.56808519363403, 41.71131113597325, 45.49363946914673, 43.76851293018886, 36.785583768572124, 41.43094784872872, 50.824564933776855, 56.152620792388916, 56.12887879780361, 55.51222964695522, 51.91294118336269, 53.021210125514436, 51.381883416857036, 55.582111154283794, 52.229445525578086, 50.92348643711635, 51.271546023232595, 55.19499921798706, 55.10417236600603, 54.07756560189383, 56.521882806505474, 53.9328658921378, 52.259715352739605, 51.74218225479126, 49.00797230856759, 48.51026242119925, 45.067311900002615, 47.34025526046753, 45.22824607576643, 43.9892954145159, 45.75441231046404, 43.9245069367545, 47.22739914485386, 44.25288922446114, 45.77922780173165, 42.00194386073521, 49.52356685910906, 52.982407910483225, 51.472668579646516, 53.78444194793701, 58.969389234270366, 59.67250524248396, 58.19105550221035, 55.43837724413191, 57.30035202843802, 58.171183654240195, 59.17479188101632, 60.82021563393729, 59.524161202566965, 61.78573036193848, 65.07352066040039, 57.43658535821097, 53.626533712659565, 62.379551206316265, 68.07813712528774, 68.88059847695487, 72.70491477421352, 66.03985527583531, 68.34251608167375, 67.59899629865373, 50.024851594652446, 0.41926724942667143, 23.886847155434744, 70.14829730987549, 47.95106097630092, 50.10307788848877, 45.754613808223176, 49.05636303765433, 38.431841305324006, 80.69892147609166, 15.630966322762625, 0.461057108427797, 0.3481763212808541, 0.15012087885822567, 0.09335420493568693, 0.11701339110732079, 0.15900493785738945, 0.10897152298795325, 0.0727668282176767, 0.09989910945296288], [0.08712604735046625, 0.14330879439200672, 0.07356087703789983, 0.09371144005230495, 0.19030898809432983, 0.053584490570106676, 0.10314849830631699, 0.07404861479465451, 0.0608418873910393, 0.044956659964684925, 0.15363886579871178, 4.580010626997266, 48.632126876286094, 41.56699357713972, 32.264627184186665, 32.18705402101789, 29.222219467163086, 29.940381799425396, 59.804826736450195, 37.13532829284668, 0.05206418875604868, 31.377331801823207, 69.06091812678746, 59.20815018245152, 64.6930512019566, 61.34244224003383, 59.18715967450823, 54.41193723678589, 50.68163006646292, 45.254954951150076, 44.17601088115147, 42.80325181143624, 53.013747760227744, 55.76408794948033, 57.10758468082973, 50.51805904933384, 52.68071712766375, 52.12441655567714, 51.822885581425254, 52.52325357709612, 50.580283641815186, 46.3959881237575, 44.993049553462434, 45.70207847867693, 43.840409415108816, 42.502936771937776, 40.805081912449424, 40.501522064208984, 39.83998755046299, 40.25198793411255, 39.76152154377529, 38.56587553024292, 37.48136247907366, 39.06357846941267, 40.08948346546718, 44.41876009532383, 44.19494819641113, 49.40557949883597, 50.06683955873762, 51.36663906914847, 51.12107236044747, 50.837683132716585, 49.79458481924874, 55.48519420623779, 53.73463378633772, 54.03978477205549, 51.27178226198469, 51.67246750422886, 45.74051243918282, 44.03708165032523, 49.70241001674107, 47.76789256504604, 51.81573935917446, 51.149493966783794, 23.620746782847814, 27.520654269627162, 54.59920161111014, 41.93564762387957, 43.343922410692485, 35.000918115888325, 35.12421389988491, 34.75631373269217, 42.806857926504954, 39.950849533081055, 33.40255798612322, 33.71203422546387, 38.369335310799734, 36.124188218797954, 37.83655439104353, 33.50582558768136, 35.64288650240217, 36.267206464494976, 42.62263338906424, 48.97111211504255, 41.95002692086356, 31.645323821476527, 31.34159026827131, 35.58243717466082, 38.37074926921299, 43.34632996150425, 52.38839251654488, 51.93703406197684, 46.31166478565761, 50.64195932660784, 51.5524651663644, 49.75824226651873, 49.17233542033604, 49.05467462539673, 49.509396008082796, 49.381712436676025, 50.362224851335796, 47.384935651506694, 49.10685212271554, 47.833084038325715, 51.12362582342965, 48.793710708618164, 49.923876898629324, 50.793572493961875, 51.25062152317592, 48.941658701215474, 46.56843546458653, 41.17960023880005, 39.17026458467756, 36.808943612234934, 36.94879347937447, 38.67958974838257, 40.6722914150783, 40.195877756391255, 40.0005395753043, 40.3052840914045, 40.537743023463655, 39.415893827165874, 42.87374823434012, 48.91948699951172, 50.699820450374055, 51.6653664452689, 53.858645234789165, 52.850701332092285, 53.37735046659197, 53.081923484802246, 51.64628669193813, 50.9053863797869, 51.29971054622105, 53.09042807987758, 54.45916414260864, 54.60002844674246, 53.85709926060268, 55.2320887020656, 50.35342843191964, 52.699272292000906, 62.33201857975551, 64.22408253805978, 64.86390740530831, 64.85332529885429, 61.360347747802734, 58.798074449811665, 26.910032681056432, 0.42656825908592766, 36.36997726985386, 55.48455497196743, 42.0835747718811, 35.578257833208355, 27.512431076594762, 44.05359057017735, 52.41975321088518, 53.86981793812343, 10.908233182770864, 0.41537248556103024, 0.20548291743866035, 0.0695030747779778, 0.07794350758194923, 0.08491395533617054, 0.03490127988957933, 0.028800812416843007, 0.07489514829857008, 0.014763383427634835, 0.04074151221928852, 0.022707973374053836, 0.24095497759325163, 0.09890960862061807, 0.03694598410012467, 0.028942521062812636, 0.021485100600070188, 0.08695810993335076, 0.09553234305764947, 0.04770816017740539, 0.14198501328272478, 5.844811626843043, 58.43558692932129, 46.63636800221035, 36.260081086839946, 45.59340517861502, 36.142257009233745, 35.86355781555176, 61.80344132014683, 44.348343576703755, 0.0060941804217041606, 32.72033521107265, 75.54473386492047, 63.32505512237549, 67.81134019579206, 64.97311919076103, 60.64664268493652, 57.655154841286794, 54.18036420004708, 47.98492997033255, 49.04483250209263, 46.423666272844585, 57.85482175009591, 60.1841219493321, 60.66222749437605, 55.65345178331648, 55.08056933539254, 55.4135548046657, 54.89738007954189, 56.04260301589966, 52.5879100390843, 48.40866238730294, 48.87331969397408, 48.98291710444859, 45.555950914110454, 42.271457535879954, 43.70858819144112, 44.0915207862854, 42.578244822365896, 42.627406801496235, 41.89574064527239, 42.02487639018467, 38.82954229627337, 40.82826457704817, 41.62138407570975, 47.18521315710885, 44.17021260942732, 50.57238006591797, 52.2484974861145, 53.18810238157, 52.66998910903931, 54.24355806623186, 52.59675162179129, 56.22348894391741, 52.100278513772146, 55.41959278924124, 53.789666993277415, 52.50592129571097, 46.068053994859966, 46.763193471091135, 49.00307730266026, 53.935666016169954, 49.322413035801475, 56.48824657712664, 23.759674276624406, 47.093319756644114, 62.930800437927246, 39.7741116796221, 46.48619311196463, 32.94759341648647, 38.77301870073591, 38.764267444610596, 44.31370333262852, 40.22670691353934, 31.48721408843994, 34.53252615247454, 37.52927378245762, 36.29427317210606, 38.3567590713501, 35.043312549591064, 34.46077905382429, 36.46647037778582, 41.056387833186555, 51.689782415117534, 46.32432092939104, 36.712044034685405, 35.10355690547398, 37.26017352512905, 42.090377058301655, 44.570432322365896, 49.70523793356759, 54.821081910814556, 50.23642771584647, 51.14100326810564, 52.15243864059448, 50.6579019682748, 51.95962960379464, 49.97768027441842, 53.09472901480538, 50.04038429260254, 52.09878117697579, 48.72438505717686, 50.308140073503765, 53.83413199016026, 54.626646995544434, 52.16122811181204, 51.933903898511616, 50.59417656489781, 53.04309000287737, 51.50216368266514, 48.06821455274309, 43.770100593566895, 41.172617299216135, 41.291553088596885, 41.41743360246931, 40.66962330681937, 44.44228669575283, 41.73573752811977, 44.56668029512678, 42.69266428266253, 42.78520386559622, 41.35420846939087, 45.191403252737864, 51.69417715072632, 53.90099450520107, 56.50121886389596, 57.274219853537424, 58.26258373260498, 57.10339144298008, 56.97206354141235, 54.804062298366, 55.76315689086914, 55.86499663761684, 55.934492519923616, 57.819823673793245, 56.418243476322715, 55.62689576830183, 58.22253084182739, 50.38423327037266, 54.39763784408569, 63.86235237121582, 67.46383993966239, 68.6402394430978, 67.47618688855852, 61.49142551422119, 68.06687409537179, 29.78374855858939, 0.4239238995526518, 40.898229462759836, 59.834196771894185, 46.23954595838274, 40.67843362263271, 29.646153381892614, 49.451736382075715, 51.75814921515328, 63.6784405027117, 13.599702153887067, 0.294972227620227, 0.2701053576810019, 0.012002840039453335, 0.07308162096887827, 0.07009204317416463, 0.07509064780814306, 0.0021998531509390368, 0.2077224494091102, 0.037210653469498665, 0.2371469847857952, 0.1823660164539303, 0.4260872048991067, 0.22975600138306618, 0.17431431636214256, 0.10254427644291095, 0.17431875398116453, 0.20733268532369817, 0.1900442780128547, 0.1900938924934183, 0.3277923965028354, 7.695974145616804, 70.26923765454973, 53.31869724818638, 41.69362102236067, 49.51503447123936, 42.5820107460022, 42.826100962502615, 69.56557968684605, 47.289693219321116, 0.19002848171762057, 37.41978406906128, 73.53619725363595, 68.64649977002824, 72.67375905173165, 67.87826524462018, 62.73497935703823, 61.4076371874128, 56.40324231556484, 52.015527861458914, 53.2618088722229, 47.859118938446045, 58.92408003125872, 62.83962617601667, 63.550843783787315, 58.48417568206787, 55.766502448490684, 55.89414780480521, 57.195552349090576, 57.44554158619472, 55.443974018096924, 50.33303199495588, 51.984160218920024, 51.53325687135969, 47.89596176147461, 45.49181209291731, 47.79452848434448, 45.474677835192, 43.70277949741909, 45.961576325552805, 45.68078919819423, 43.94653272628784, 41.00858770098005, 43.920695849827354, 43.890512875148225, 47.70075907026018, 46.803433963230674, 52.65247617449079, 54.537842069353374, 54.93027979987008, 54.33356155667986, 56.038284710475374, 53.236746719905305, 59.75891304016113, 55.13794755935669, 57.24017020634243, 56.223492418016704, 54.24718155179705, 48.39559629985264, 47.754260199410574, 50.97781440189907, 57.5440114566258, 53.856140409197124, 59.57376439230782, 26.89167901447841, 40.28243841443743, 55.23638268879482, 45.204333850315635, 47.08181701387678, 36.85589953831264, 39.723084109170095, 40.70042814527239, 45.84827552522932, 43.45339127949306, 35.616931506565635, 36.705467564719065, 38.945837770189556, 34.696910108838765, 40.48274803161621, 35.43389163698469, 35.62040213176182, 38.357082162584575, 42.06987292425973, 49.58121953691755, 43.86895956311907, 35.582631724221365, 37.73248427254813, 40.170614106314524, 44.72369916098458, 46.82111712864467, 46.772917475019185, 51.798063141959055, 51.66516147341047, 55.26742376599993, 56.27589920588902, 51.31316920689174, 52.90801354816982, 53.466058118002756, 55.69419601985386, 54.283305236271445, 54.1073351587568, 50.36961426053728, 53.06606422151838, 56.82794748033796, 56.75360175541469, 53.5570239339556, 55.40764536176409, 53.429750306265696, 55.268021311078755, 52.40968874522618, 50.12004886354719, 46.62966299057007, 43.61128909247262, 42.74616541181292, 45.22333369936262, 42.78702081952776, 46.92827224731445, 44.45924377441406, 49.6292906488691, 46.89353820255825, 46.221859318869456, 44.128123896462576, 49.62447207314627, 56.590055056980674, 53.4213673046657, 57.109165396009175, 61.67656026567732, 63.967971937997, 59.31225504193987, 59.76968969617571, 55.88847460065569, 59.18643011365618, 58.53260462624686, 61.94751916612898, 60.9868403843471, 59.79241030556815, 58.63447911398751, 63.04313196454729, 54.586608001164024, 59.95190620422363, 67.61180182865688, 71.36598995753697, 71.59349482400077, 69.04891163962228, 62.65436635698591, 69.67192881447929, 36.51160587583269, 0.46945965183632715, 42.620809486934114, 67.56060055324009, 49.964232036045615, 45.79865149089268, 36.83691358566284, 58.55328941345215, 66.28501551491874, 72.75899955204555, 17.350280693599156, 0.5135833727461951, 0.7065663316420147, 0.17707919728543076, 0.14050708258790628, 0.15823937393724918, 0.24424864085657255, 0.09494586488498108, 0.401999401726893, 0.16242906983409608], [0.029930237348058393, 0.13864542676934175, 0.17150256223976612, 0.14622469006904534, 0.06536948015647275, 0.218840625669275, 0.055890054175896306, 0.05668793671897479, 0.12227490091962473, 0.1620965198214565, 0.1648811732551881, 3.612179760422025, 47.27296890531267, 39.000641686575754, 29.32874229976109, 18.925133330481394, 24.523206608636038, 30.481545720781597, 51.3640022277832, 56.481975827898296, 1.2509079681975501, 19.908437183925084, 78.01900822775704, 54.85258504322597, 62.07721424102783, 53.909874303000315, 57.60459280014038, 48.565861906324116, 49.25826031821114, 44.31146253858294, 44.64592102595738, 47.630179268973215, 56.72614247458321, 53.726751055036274, 56.376165185655864, 54.92394304275513, 54.29011794498989, 50.280861445835654, 51.120433126177105, 48.60948964527675, 47.03480550221035, 45.686681270599365, 49.73621995108468, 51.13943297522408, 49.75727299281529, 42.15124675205776, 41.96891212463379, 40.19793094907488, 42.100896630968364, 41.089471680777415, 38.962016650608604, 40.59985991886684, 38.14946304048811, 36.802030154636924, 40.57543700081961, 42.51653439658028, 44.178529603140696, 47.79618910380772, 51.75288595472063, 51.24955497469221, 51.8231635093689, 52.477774143218994, 49.54212202344622, 46.468593324933735, 42.86540692193167, 50.400547640664236, 54.064416136060444, 50.765498297555105, 54.40311649867466, 48.98269476209368, 48.750208037240164, 46.999421800885884, 51.563144547598704, 52.64675433295113, 37.09237800325666, 15.662992307118007, 55.64430100577218, 52.38582168306623, 35.08189937046596, 38.13890872682844, 33.0748461995806, 44.53211995533535, 39.79284749712263, 21.13571834564209, 22.849095480782644, 33.4293189729963, 34.24075044904436, 39.22002410888672, 34.23908288138253, 40.75782373973301, 39.80836977277483, 40.74111679622105, 33.68758698872158, 46.37240941183907, 49.61113500595093, 57.34406661987305, 52.39156436920166, 50.41277299608503, 48.59497138432094, 50.58461236953735, 43.23778520311628, 39.98308570044381, 49.197449684143066, 53.20572648729597, 50.50337750571114, 48.750920227595735, 46.934782709394185, 47.37743854522705, 50.377788816179546, 48.83321469170706, 47.92058270318167, 45.080416202545166, 47.8800608089992, 50.991773332868306, 49.115433147975374, 51.588706970214844, 49.59179122107369, 49.23302098682949, 48.73338644845145, 49.07670388902937, 42.956195558820454, 39.611520358494346, 34.69381121226719, 37.532640184674946, 37.954322883060996, 39.07188156672886, 36.985688413892476, 39.059937613351, 40.96330976486206, 39.02527652468, 40.664346149989534, 40.451529775347026, 44.5672778402056, 52.232662541525706, 51.878919328962056, 58.62908731188093, 55.05290160860334, 56.02779293060303, 54.22129603794643, 56.66371291024344, 52.9280868938991, 54.44846739087786, 51.58720963341849, 51.907344409397666, 49.833359241485596, 54.39651918411255, 49.29422419411795, 54.80547973087856, 47.16695329121181, 50.19415487561907, 57.20455026626587, 65.16937105996269, 60.56220122746059, 67.26078578404018, 59.49806376865932, 68.071168082101, 16.870196649006434, 0.9920091863189424, 49.378728185381206, 49.52251420702253, 40.90980168751308, 42.89133759907314, 39.501561641693115, 35.15877423967634, 43.18008041381836, 51.918854100363596, 10.296741332326617, 0.4451272503605911, 0.018145717647192732, 0.06106255376445396, 0.06835826406521456, 0.03495434472071273, 0.020590596366673708, 0.08799857553094625, 0.014883758932618158, 0.08780378169779267, 0.07510474776583058, 0.09533389192074537, 0.029161867685616016, 0.06703826239598648, 0.07945613177227122, 0.15862955871437276, 0.018893985709707652, 0.061085447535983155, 0.058149535075894425, 0.10121194579239402, 0.11631117521652154, 4.997035426752908, 58.217757429395405, 44.927604470934185, 30.18703590120588, 22.757448741367885, 28.44805291720799, 39.11344569069998, 52.88319458280291, 64.19327422550747, 1.871076490197863, 20.328636441911968, 84.17294434138707, 59.57684939248221, 66.37618282863072, 57.46898480824062, 63.21065303257534, 51.58243274688721, 52.52945831843785, 46.90188993726458, 48.83731065477644, 51.98411505562918, 57.99112803595406, 56.91004044669015, 59.910585267203196, 56.86816017968314, 56.98214537756783, 53.11297151020595, 54.054400307791575, 51.3935147012983, 51.57058259419033, 47.915388924734934, 53.59878955568586, 52.888944217136924, 51.352471692221506, 44.91971479143415, 42.54166603088379, 42.70338535308838, 45.759449754442485, 44.5732741355896, 41.344119685036794, 41.47068807056972, 40.38591793605259, 38.17680072784424, 41.82468489238194, 45.27445159639631, 45.21836921146938, 48.89556782586234, 53.080189909253804, 54.67515584400722, 54.118396690913606, 53.54325607844761, 52.54752710887364, 47.85627712522234, 47.89206382206508, 49.70891005652291, 55.32375628607613, 53.23493671417236, 54.2323888369969, 53.835896832602366, 51.820641313280376, 50.07034145082746, 55.490419251578196, 52.95923566818237, 40.88812678200858, 23.437960522515432, 74.86345604487828, 47.036879539489746, 33.87685591833932, 39.722424030303955, 34.99698543548584, 47.64393670218331, 40.456452574048726, 23.118089778082712, 28.183484622410365, 32.11681120736258, 34.3761430467878, 38.67972523825509, 34.79637704576765, 40.36941943849836, 39.06588179724557, 38.564162799290244, 32.41910300936018, 44.26770625795637, 48.42271859305245, 56.065031800951274, 52.55503463745117, 52.492052691323416, 51.500562122889924, 54.53304433822632, 51.27439825875418, 45.66323457445417, 49.51896367754255, 53.60347958973476, 52.87747968946184, 49.56179584775652, 49.97183683940342, 49.020260197775706, 50.4843533379691, 51.06171389988491, 47.984669412885395, 46.283145904541016, 48.810879707336426, 53.61895670209612, 53.63960674830845, 53.47874205453055, 51.25765310014997, 52.48301655905587, 49.52819088527134, 52.420851026262554, 46.2465740612575, 42.32013314110892, 38.00826174872262, 39.843590191432405, 42.11085687364851, 42.07566772188459, 39.15901892525809, 42.71403694152832, 44.55480234963553, 42.057393959590364, 41.728775433131624, 42.52286420549665, 45.536881583077566, 57.956633704049246, 55.47940288271223, 59.292327608381, 59.216210092817036, 60.6408965247018, 58.83665084838867, 60.18607439313616, 57.96290792737688, 58.241106850760325, 56.444271428244456, 56.08902045658657, 52.4470214162554, 57.6928835596357, 51.978751046316965, 57.75445849554879, 48.98984793254307, 53.212386335645405, 58.7301002229963, 67.6640522820609, 60.93786253247942, 73.84821305956159, 59.573125158037456, 75.6845177241734, 18.4513669354575, 1.1488429478236606, 59.52011735098702, 55.19821275983538, 46.10741206577846, 47.44861936569214, 32.54571655818394, 33.329108578818186, 46.58326292037964, 58.193720136369976, 15.214790071759905, 0.43982235501919476, 0.15784507723791258, 0.02336691739037633, 0.04456736746111086, 0.050664835809064765, 0.032187587648097954, 0.040527359782052894, 0.022990115020158033, 0.050434747976916175, 0.1919499978955303, 0.2901237149323736, 0.259043174130576, 0.3104788698256016, 0.15714340417512826, 0.2318439350596496, 0.18880749866366386, 0.2177036723920277, 0.20415229669639043, 0.2157462617116315, 0.4756576621106693, 6.7958736675126215, 70.82469054630825, 52.75197785241263, 38.55821514129639, 27.37606225694929, 36.280119691576274, 43.96480648858206, 61.15190873827253, 68.46409566061837, 1.8585656072412218, 25.16461740221296, 87.77925395965576, 62.093466077532085, 70.98233127593994, 59.70530768803188, 65.69254956926618, 53.523432867867605, 57.097905840192524, 49.048949309757774, 51.763752937316895, 54.292591503688264, 62.37404128483364, 59.88131250653948, 63.31615447998047, 59.38931056431362, 58.4258177621024, 54.27925443649292, 56.71652269363403, 53.40910720825195, 55.90152679170881, 50.06025614057268, 56.2868287222726, 54.77518905912127, 54.94458614076887, 46.95699610028948, 46.09567655835833, 45.20403160367693, 49.50315999984741, 47.53684411730085, 44.93903078351702, 45.424682072230745, 43.460648672921316, 39.94810152053833, 43.541400636945454, 47.66689355032784, 49.79975427900042, 51.232632637023926, 56.032875537872314, 57.276498862675254, 55.852118151528494, 56.39544643674578, 53.65582384381975, 49.61877107620239, 48.5548038482666, 51.26997225625174, 57.64038297108242, 56.272449425288606, 55.2566818509783, 57.43878793716431, 50.82442249570574, 50.36249930518014, 59.64066859654018, 54.6110691343035, 44.63786458969116, 27.01985764503479, 60.44711821419852, 48.90024396351406, 40.45269707271031, 40.979040486471995, 35.71924720491682, 46.64364276613508, 45.654591015407014, 27.1708767414093, 27.16925607408796, 32.33865329197475, 34.159776142665315, 39.29348741258894, 35.91805253710066, 37.97861378533499, 39.405631337847026, 38.29682738440377, 33.246108872549875, 45.358361516680034, 47.133640153067454, 52.53316865648542, 50.45167943409511, 53.070504120418, 53.259394373212544, 56.6762752532959, 55.49731533867972, 51.46724203654698, 53.40609169006348, 55.977300371442524, 56.938090324401855, 52.29746838978359, 53.30113220214844, 51.065580572400776, 53.90313802446638, 52.674283095768516, 50.77108464922224, 47.59871435165405, 50.025424821036204, 56.02824108941214, 55.52643176487514, 56.053918157305034, 53.874070235661094, 53.660770961216514, 53.29170002256121, 57.9290771484375, 49.15542697906494, 44.79056862422398, 38.99666036878313, 41.01962144034249, 44.98906128747122, 45.759602614811485, 40.681292806352886, 43.346538407461985, 47.55126510347639, 42.26613868985857, 45.143561431339805, 43.46647473743984, 47.70601885659354, 62.523038455418174, 56.54605906350272, 61.10131890433175, 60.95457989828927, 63.72919709341866, 62.00655800955636, 65.20385496956962, 59.74231379372733, 59.84592533111572, 59.320995875767295, 57.51999848229544, 54.444381850106375, 60.11546679905483, 55.486396244594026, 62.43731158120291, 52.323875018528526, 55.796612467084614, 63.52295371464321, 71.0620618547712, 65.85569327218192, 73.99491732461112, 64.53070654187883, 78.85237516675676, 22.374972990580968, 1.2192740142345428, 60.0984992980957, 60.51352909633091, 49.20866755076817, 54.11598914010184, 50.772366591862266, 48.68649653026036, 55.682818344661165, 70.85855606624058, 18.236698865890503, 0.5328542015382222, 0.27717102425439016, 0.2224107240991933, 0.25819671526551247, 0.08570537822587149, 0.19866828168077127, 0.2531629353761673, 0.11032851838639804, 0.30717817693948746], [0.08784872785742794, 0.1394641064107418, 0.04071624357519405, 0.2330145165324211, 0.08806720256273236, 0.13969069639486925, 0.12822485236184938, 0.16075762095195906, 0.011690876779279538, 0.2115325049630233, 0.21796926456902707, 3.271658752645765, 42.60581180027553, 48.247033391680034, 26.87967426436288, 60.87805243900844, 43.13407291684832, 23.86756590434483, 47.01645530973162, 62.94042369297573, 9.338596037455968, 6.726791203022003, 80.53975909096854, 51.66315344401768, 66.94118254525321, 57.471708502088276, 56.45496817997524, 47.25062697274344, 48.07034764971052, 39.737397398267476, 49.24587862832205, 50.62096187046596, 53.3950822693961, 51.566900048937114, 55.59881462369646, 51.11032002312796, 52.79697438648769, 50.208593232291086, 49.52212510790144, 45.919709954942974, 50.55642352785383, 53.150790555136545, 52.74991423743111, 49.966695172446116, 53.95002099445888, 46.403061389923096, 41.04983568191528, 39.081178256443565, 42.709082875932964, 39.228733675820486, 40.30807726723807, 38.8959253856114, 38.651056970868794, 36.2648058618818, 39.65505082266671, 39.3775953565325, 39.134019306727815, 46.93712077822004, 52.922226088387625, 51.9748079436166, 50.82297379629952, 47.87368583679199, 42.63083226340157, 45.01656920569283, 49.84872170857021, 51.95624930518014, 54.992122241428916, 51.572826862335205, 52.046176365443635, 52.332518577575684, 52.17262315750122, 50.318364347730366, 49.45660359518868, 48.03679827281407, 48.74000113351004, 22.973998035703385, 20.970088924680436, 63.46734728131975, 49.35435043062483, 44.29449503762381, 37.688602924346924, 32.66315501076834, 19.298065730503627, 33.89810003553118, 45.543586594717844, 41.59486280168806, 35.96911137444632, 39.825667313167024, 42.18099546432495, 41.09935201917376, 39.27158669063023, 42.71925503867013, 41.70452274594988, 36.79289327348982, 41.21309403010777, 39.980855328696116, 42.48553153446743, 44.27464403424944, 37.044289520808626, 39.51294279098511, 43.55505384717669, 48.07407188415527, 51.4349433353969, 49.911401408059255, 49.14568907873971, 48.74023389816284, 49.690400055476594, 52.14872482844761, 48.891235624040874, 50.66679218837193, 47.707543986184255, 48.93766348702567, 47.163225582667756, 48.01672840118408, 49.34234046936035, 46.0528895514352, 46.253490992954795, 50.76212494713919, 47.58520705359322, 48.39289345060076, 44.183699062892366, 37.642605849674766, 36.891283239637104, 35.65703650883266, 37.23885645185198, 39.39438567842756, 37.32013300486973, 42.05378784452166, 40.64356408800398, 41.45500946044922, 38.246807302747456, 40.80860117503575, 43.351933683667866, 55.46584347316197, 53.93079532895769, 52.85120507649013, 56.08261769158499, 58.120315892355784, 53.49569913319179, 58.91467217036656, 56.700472354888916, 58.0022486277989, 53.36805377687727, 55.7556528363909, 51.1602463041033, 56.01629366193499, 49.334325722285676, 53.686045033591135, 47.803526401519775, 51.341201714106965, 49.49194213322231, 65.42948382241386, 55.305305344717844, 70.8890517098563, 56.13462495803833, 71.27315507616315, 6.239940915788923, 3.258645210947309, 57.45403923307146, 44.75586584636143, 37.043261187417166, 34.49648584638323, 48.406963552747456, 46.886291231427876, 47.70219734736851, 44.37924221583775, 17.025556632450648, 0.2696642284946782, 0.3003348798624107, 0.17046106526894228, 0.029646830234144415, 0.04298165487125516, 0.07130136221115078, 0.09054312256297894, 0.1342969536781311, 0.1733715326658317, 0.030787328856864145, 0.27717343983905657, 0.02434932583543871, 0.16466748900711536, 0.11736791208386421, 0.048588349018245935, 0.06729322871459381, 0.11407998922680106, 0.07167204589183841, 0.21755936156426156, 0.3611277905958039, 5.471698573657444, 54.52818059921265, 56.18954004560198, 28.265886783599854, 54.95008911405291, 46.31070940835135, 32.215336663382395, 51.315545490809846, 71.39389392307827, 11.320561868803841, 4.969599596091679, 83.13692624228341, 54.28563288279942, 72.61977849687848, 58.315049580165315, 58.81404141017369, 48.86260904584612, 50.70168604169573, 42.950810704912456, 53.00934260232108, 52.89930745533535, 59.51038292476109, 53.51685292380196, 59.36433179037911, 53.42461906160627, 56.47157437460763, 54.4075459752764, 54.59940310886928, 49.495419706617085, 54.94705275126866, 55.09440319878714, 56.45941850117275, 52.32123817716326, 57.28296416146414, 47.56789214270455, 42.298694474356516, 41.98131118501936, 45.34149129050118, 41.05485575539725, 41.98545578547886, 40.19536358969552, 41.50512681688581, 38.31764071328299, 41.35343027114868, 42.24115991592407, 41.598993505750386, 49.010105405535015, 54.17693873814174, 52.880696705409456, 52.762275082724436, 49.687672887529644, 45.39124386651175, 45.74239887510027, 53.71114540100098, 55.74845797674996, 55.901314871651785, 53.962798731667654, 54.44855771745954, 51.91294813156128, 54.44849518367222, 51.788818563733784, 52.46885960442679, 50.47314936774117, 51.50802796227591, 26.037297248840332, 33.951733180454795, 75.4643223626273, 44.083815234048025, 40.843182359422954, 37.242334025246755, 32.64169897351946, 27.94110539981297, 47.99191985811506, 50.216385637010845, 37.9253488949367, 36.22478076389858, 41.3235947063991, 39.9693352154323, 40.230194909232004, 38.50518996374947, 41.417034081050325, 39.888996669224326, 38.94879422869001, 39.19009126935686, 36.957131317683626, 38.210214614868164, 42.06149339675903, 37.00435822350638, 39.44886997767857, 42.750459398542134, 50.74566119057791, 52.451937266758506, 51.23010001863752, 50.04008204596383, 50.629101685115266, 49.83569731031145, 54.16707229614258, 51.87330865859985, 50.88610165459769, 49.60304035459246, 51.207153592790874, 50.90537943158831, 49.342420373644146, 50.32423904963902, 48.482337611062185, 48.030930519104004, 51.30131558009556, 51.875212465013774, 49.7226014818464, 46.09854963847569, 41.81382833208357, 41.105695724487305, 41.53300993783133, 40.13700219563076, 42.755628858293804, 41.72634356362479, 44.30591440200806, 42.81740181786673, 44.526346002306255, 40.880744321005686, 42.637540749141145, 45.6826617377145, 56.23837545939854, 60.04428250449044, 54.32334075655256, 55.71525600978306, 62.94331414358956, 57.817826066698345, 62.89189747401646, 59.00020449502127, 61.213344710213796, 55.84318624223982, 60.041482380458284, 56.33307245799473, 57.623401573726106, 53.57106624330793, 56.91924333572388, 49.70475155966622, 53.59195600237165, 49.68192672729492, 67.7987848009382, 59.48947579520089, 75.62354728153774, 59.39659922463553, 78.63749517713273, 5.951478200299399, 5.369613468647003, 66.5066283089774, 46.16230283464704, 45.40152025222778, 42.18330226625715, 49.35409334727696, 45.96953201293945, 55.17764261790684, 55.56308003834316, 22.267472199031285, 0.4960089900663921, 0.3731751798519066, 0.18237949215940066, 0.03410153476787465, 0.06788845320365258, 0.08335679889257465, 0.18211647841547215, 0.10054361594042607, 0.12946746711220058, 0.15805543666439398, 0.38513202539512087, 0.2210220614714282, 0.23515895860535757, 0.3583815151027271, 0.2448904535600117, 0.2860821975128991, 0.32402858989579336, 0.17598667448120459, 0.5635830440691539, 0.5313292890787125, 6.6928318824086865, 66.87696034567696, 63.89658614567348, 40.38824210848127, 74.50982747759137, 54.680162021092, 36.81541238512312, 57.56267431804112, 77.48215566362653, 11.206209284918648, 8.639721035957336, 89.51415661403111, 54.73400708607265, 75.09481021336147, 63.524913106645855, 63.704093251909526, 50.54447957447597, 52.53443670272827, 45.5869676726205, 55.9952267238072, 54.38313347952706, 62.67056955610003, 56.69466018676758, 61.88864707946777, 54.94545119149344, 56.900118419102256, 54.46947874341692, 57.15813977377755, 51.784211908067974, 56.07114274161202, 59.4513510295323, 58.67535536629813, 55.0938994543893, 60.57374218532017, 50.13057191031319, 46.32152080535889, 44.04758037839617, 48.32110466275896, 42.98489161900112, 45.94802386420113, 44.088178702763145, 42.6348865372794, 41.235977922167095, 44.3373897416251, 44.04101780482701, 45.53979982648577, 53.51731497900826, 59.497764996119905, 56.715845244271414, 57.33683007104056, 53.67811713899885, 46.3300392968314, 47.60019779205322, 56.488732951028005, 57.96311984743391, 58.64146205357143, 56.899878706250874, 57.7246298789978, 51.784771238054546, 58.081753390175955, 52.403786250523154, 56.434648173195974, 52.22599227087838, 55.67579024178641, 27.687065362930298, 37.80968223299299, 61.837918281555176, 39.017619609832764, 43.48233052662441, 39.85903951099941, 38.339451108660015, 33.29275212969099, 40.7694411277771, 45.306302138737266, 39.49310220990862, 36.49560070037842, 40.09014007023403, 38.84480054037911, 40.565320423671174, 38.77438054765974, 44.013190269470215, 42.50951324190412, 39.42062555040632, 42.011018208095, 40.245956897735596, 40.186233656747, 43.4078562600272, 37.31493922642299, 41.26187038421631, 45.492743151528494, 52.73339489528111, 56.15198155811855, 51.387782437460764, 52.38846199853079, 54.53440618515015, 52.65652002607073, 57.9801915713719, 53.657498359680176, 54.77950389044625, 52.08235910960606, 53.37989003317696, 53.22789124080113, 50.425363131931846, 53.43980087552752, 51.4327129636492, 51.40646614347185, 54.644931180136545, 52.70869057519095, 52.20320217950003, 48.81644868850708, 43.049468176705496, 41.422231333596365, 41.390314783368794, 40.942708356039866, 45.184423787253245, 43.745403221675325, 46.177456855773926, 44.03025851930891, 48.059383392333984, 41.91836050578526, 44.14284365517752, 47.55138322285244, 58.88066073826381, 61.69650159563337, 57.47363315309797, 57.702423436301096, 62.663468497140066, 61.25591632298061, 68.20550455365861, 62.99443204062325, 64.20572539738247, 58.039932182856965, 62.77372251238142, 58.72590351104736, 63.07213374546596, 56.200598103659495, 61.08965982709612, 52.10831410544259, 54.63698591504778, 52.94967494692121, 71.3916357585362, 61.54013238634382, 80.20608575003487, 60.93040016719273, 83.70353099278041, 9.063416974885122, 4.542814748627799, 73.0578624180385, 53.573932375226704, 45.625068119594026, 41.61267450877598, 65.32111276899064, 59.51177256447928, 66.33625153132847, 67.24843883514404, 26.43905598776681, 0.7108631410769054, 0.4296334460377693, 0.386828037244933, 0.18673286427344593, 0.17230915038713387, 0.21328062830226763, 0.5632969737052917, 0.2788398132792541, 0.2878405531602246], [0.0874690603730934, 0.08139254857919045, 0.0308723459020257, 0.0730063985767109, 0.07615571708551475, 0.06083260503198419, 0.23098452974643024, 0.1194345804729632, 0.043323789191033156, 0.26479193993977135, 0.2732750933085169, 4.568950397627694, 50.642463071005686, 44.06132738930838, 38.99841478892735, 88.81249277932304, 56.46699898583548, 23.86529905455453, 43.18246364593506, 64.41815267290387, 27.209604263305664, 0.9767658157008035, 64.03389644622803, 64.32880578722272, 66.64040197644914, 53.663883754185264, 52.51121234893799, 50.18456983566284, 46.615047454833984, 44.57406275612967, 47.119646481105256, 51.06664364678519, 58.83567115238735, 55.41988808768136, 54.7446482522147, 53.97391932351248, 54.186826024736675, 52.16089459827968, 49.723595074244905, 49.364220346723286, 51.382362842559814, 53.66667693001883, 53.65573351723807, 54.80765799113682, 56.526746545519146, 49.10536173411778, 40.06524120058332, 40.61403424399239, 40.814788545881, 41.58433975492205, 40.18396506990705, 37.58915683201381, 38.88170937129429, 39.585975306374685, 38.99785893304007, 39.79520641054426, 41.40209197998047, 40.78795460292271, 51.19667223521641, 50.24584599903652, 48.724468435559956, 48.60257618767874, 52.91342272077288, 53.966932909829275, 54.00907026018415, 54.12331601551601, 51.397916385105674, 53.51412228175572, 50.4240916115897, 50.076799801417756, 52.74567583629063, 51.598260743277415, 50.45096376964024, 48.0848832811628, 47.131468841007774, 47.84991257531302, 25.342334951673234, 24.9355457169669, 54.213573115212576, 54.81000995635986, 44.790103094918386, 33.95161853517805, 51.41038840157645, 63.19142736707415, 46.44569206237793, 38.72267552784511, 41.5643185206822, 39.34302806854248, 33.4011891910008, 43.44641528810774, 43.052785941532676, 39.78582286834717, 41.58674383163452, 40.26881299700056, 43.93167052950178, 41.657372270311626, 39.148992674691335, 34.25838497706822, 26.61081198283604, 39.724953174591064, 51.12272950581142, 50.91459274291992, 51.13830736705235, 48.01249694824219, 45.80726030894688, 50.455789293561665, 48.80296918324062, 50.345288617270334, 49.78447866439819, 50.03439147131783, 50.40347630637032, 51.43491554260254, 50.16324234008789, 47.39865834372384, 49.76532595498221, 46.660238538469585, 43.08919102805001, 42.04829181943621, 51.21318115506853, 42.877774715423584, 43.91879899161202, 41.05759334564209, 39.66361795152937, 38.545864718300955, 36.862590653555735, 43.493173190525596, 42.24829224177769, 40.28985909053257, 41.636937618255615, 41.86604404449463, 40.05379056930542, 39.32082857404436, 42.094869068690706, 53.67048454284668, 57.12000111171177, 51.78608444758824, 44.9813939503261, 55.242629119328086, 59.46793637956892, 60.09682478223528, 55.34121363503592, 55.995205879211426, 56.22607714789254, 58.248086316244944, 53.32118470328194, 53.00938081741333, 50.348599433898926, 54.60016393661499, 50.93164709636143, 55.70518112182617, 51.69527496610369, 60.2044871194022, 59.38729558672224, 69.54363032749721, 59.663806097848074, 58.06572389602661, 0.44871463786278454, 12.562544550214495, 52.30807828903198, 44.99962602342878, 26.28744455746242, 25.376652104513987, 45.825846740177695, 26.98814606666565, 37.84129653658186, 49.47008657455444, 19.43646342413766, 0.14486349453883512, 0.1098822323339326, 0.10172371047415904, 0.04494238358789256, 0.11207658744284085, 0.1053759523534349, 0.10529030087803092, 0.08421085734984704, 0.10015098165188517, 0.0695366147639496, 0.05805331202489989, 0.03284161737454789, 0.014495192461514046, 0.03718388865568808, 0.09814421433423247, 0.08222578958209072, 0.10029293117778641, 0.1166226499314819, 0.4678694914494242, 0.37269765404718264, 9.269959994724818, 64.76099068777901, 52.83628729411534, 39.79566151755196, 89.00607654026577, 62.18500859396798, 32.384455817086355, 47.63029391424996, 69.91745730808803, 35.51876040867397, 0.3321164830454758, 63.786387716020855, 67.5564524786813, 69.82451125553676, 56.71038048607962, 56.93346629823957, 52.355937480926514, 49.93997934886387, 46.190644536699565, 49.8284329686846, 55.73802873066494, 63.44967106410435, 56.44134971073696, 56.04148088182722, 58.63226958683559, 57.38963985443115, 52.94393573488508, 54.45982074737549, 52.42547157832554, 56.189088412693565, 55.84559031895229, 57.25658185141427, 57.07360798971993, 57.613326685769216, 51.30134684698922, 42.976414816720144, 42.192136900765554, 44.19375658035278, 43.894132886614116, 42.98921339852469, 41.155903407505576, 44.31672927311489, 41.199892452784944, 40.798394271305625, 42.27928468159267, 43.055460997990195, 42.54701961789812, 52.31578731536865, 51.494030816214426, 51.22934266499111, 48.512899262564524, 53.030583245413645, 54.423106466020855, 54.66643238067627, 53.227488245282856, 52.81328528267996, 53.552271366119385, 50.79535123280117, 52.240559169224326, 52.27165930611746, 53.518374579293386, 50.20611619949341, 52.12294006347656, 51.309198311397004, 49.22621522630964, 28.36193868092128, 35.354901041303364, 67.01119259425572, 51.52726752417428, 41.36297014781407, 38.91186802727835, 63.67455645969936, 68.55614539555141, 42.2040947505406, 35.544781412397114, 39.483246190207346, 40.18662275586809, 35.87342078345162, 41.784482615334646, 40.9210855620248, 40.76635612760271, 40.678180013384136, 38.739733355385916, 46.298355511256624, 41.79645783560616, 37.424137115478516, 32.383479595184326, 26.192144802638463, 39.651267528533936, 50.89435611452375, 51.575185775756836, 51.80987160546439, 50.71626683643886, 47.49539811270577, 52.50180448804583, 50.30244949885777, 51.66904551642281, 51.58000782557896, 51.80853407723563, 54.744599614824565, 52.44770928791591, 52.689583029065815, 49.70881972994123, 50.69006865365164, 49.009591238839285, 46.54950162342617, 46.452643735068186, 53.15771096093314, 45.59615319115775, 47.5096731867109, 43.40614005497524, 42.01943942478725, 42.69128506524222, 41.752263818468364, 46.290552684238975, 45.46052435466221, 45.374602930886404, 43.879083088466096, 46.556710379464285, 44.17098385947091, 42.47024202346802, 45.77029241834368, 56.51545224870954, 56.88611432484218, 56.0226616859436, 48.4885527747018, 53.380605697631836, 59.46695668356759, 64.04991204398019, 60.256105286734446, 60.38805157797677, 57.02604409626552, 62.85732323782784, 57.986219133649556, 58.78609575544085, 53.25364473887852, 55.688383851732524, 51.383606570107595, 57.90135383605957, 53.310512270246235, 65.29858670915876, 64.17146383013043, 74.21555737086705, 64.87915870121547, 62.23399339403425, 0.6666558789355415, 16.114470618111746, 61.85421180725098, 47.51049654824393, 35.3401118006025, 32.611099106924875, 49.91484771456037, 29.279212066105433, 46.36007635934012, 56.277559825352256, 28.87832358905247, 0.11008415757013218, 0.05046580113204462, 0.04704274124066744, 0.06438157388142177, 0.041224778430270295, 0.1686936036816665, 0.14100758358836174, 0.024450622632035186, 0.06254199759236403, 0.2318927895809923, 0.11230534873902798, 0.1190465127250978, 0.3445977275925023, 0.25460911063211306, 0.331699726837022, 0.417618816452367, 0.3237489791853087, 0.2207117538366999, 0.7559534758329391, 0.39053430408239365, 10.838708639144897, 76.84075355529785, 56.74655628204346, 50.95453098842076, 99.45784868512834, 67.54296602521623, 37.94377899169922, 56.22368001937866, 76.22150230407715, 33.88209138597761, 1.4648765495845248, 72.34838880811418, 66.38398565564836, 75.0951645714896, 60.50032751900809, 62.66826275416783, 54.706877844674246, 51.24665757587978, 48.276618821280344, 53.79753582818167, 59.21596690586635, 67.52222565242222, 60.11473723820278, 58.544798714774, 61.01561982291085, 60.66164384569441, 56.99687555858067, 56.82746458053589, 54.26092856270926, 56.93570361818586, 57.45226396833147, 57.016809940338135, 58.60682528359549, 61.24629306793213, 55.07554578781128, 46.27115331377302, 45.25446857724871, 45.5732866695949, 47.28032009942191, 46.86347334725516, 44.12174545015608, 46.403592927115305, 46.3249705859593, 45.29701239722115, 47.81339284351894, 45.063483442579, 45.91397769110543, 55.23830386570522, 53.994948046548025, 53.75993912560599, 53.282059397016255, 56.456937994275776, 59.89657769884382, 57.78661128452846, 57.6224079813276, 55.17697211674282, 56.80948611668178, 55.394145011901855, 56.77721520832607, 55.08414070946829, 53.72869655064174, 51.00332818712507, 54.65663889476231, 53.299971852983745, 52.90358059746878, 28.89866270337786, 42.84753268105643, 62.52938216073172, 49.28429521833147, 45.1091365814209, 43.020046029772075, 50.3396258354187, 56.83476366315569, 44.711946283067974, 37.48918267658779, 39.08697305406843, 41.822760241372244, 35.82015241895403, 39.53704956599644, 40.248479093824116, 39.29184416362217, 41.923338890075684, 41.73237460000174, 47.02481746673584, 40.73805264064244, 39.82149144581386, 35.0062369619097, 26.4005959715162, 40.67378875187465, 55.0067412512643, 56.682823930467876, 53.91070808683123, 54.13628830228533, 50.15557152884347, 54.13827201298305, 53.75434235164097, 54.22354030609131, 56.03391081946236, 54.701558998652864, 54.839185442243306, 56.95758349554879, 56.18320328848702, 53.23313365663801, 54.9425607408796, 51.802874769483296, 49.19215863091605, 47.93876266479492, 58.08737448283604, 48.55931322915213, 49.27414737428938, 45.11553239822388, 44.925537381853374, 44.28347519465855, 43.12537029811314, 49.65142413548061, 50.26952198573521, 47.00053698675973, 45.154306820460725, 45.62468944277082, 46.35856165204729, 44.52438661030361, 46.90005908693586, 58.70113318307059, 61.73887171064104, 57.10200875146048, 49.26978390557425, 57.102689674922395, 62.31064592088972, 66.24247864314488, 61.954418727329795, 61.706819670540945, 60.56860746656145, 63.953081948416575, 60.1805088860648, 60.252916063581196, 56.90761205128261, 58.18146351405552, 53.12383154460362, 61.68311936514718, 54.31010791233608, 68.40666879926408, 64.73521981920514, 79.92625399998256, 67.11192062922886, 72.48973601205009, 2.161855778523854, 15.428223099027361, 71.29606328691754, 53.68827887943813, 37.30337394986834, 33.74070944104876, 61.005343437194824, 37.32606676646641, 49.8700179372515, 67.46308953421456, 32.378872939518516, 0.41061918490699356, 0.14132574865860598, 0.22197517247072288, 0.2597608199076993, 0.1761632835758584, 0.19792369806340762, 0.35039396371160236, 0.18743612510817392, 0.18125549890100956], [0.2632910747613226, 0.06924886841859136, 0.082326660597963, 0.362678623093026, 0.07808526711804525, 0.22576370489384445, 0.2136428574366229, 0.11310342805726187, 0.041405591049364636, 0.22829191280262812, 0.17549374593155725, 11.332466738564626, 61.38240133013044, 33.6452967779977, 38.24165868759155, 75.704500743321, 54.71382256916591, 24.47011021205357, 34.06915773664202, 48.767137323107036, 46.33314166750227, 0.7237392930047852, 37.678621837071006, 76.52149077824184, 56.439536230904714, 64.12462602342877, 54.454234395708355, 53.27004943575178, 46.54689604895455, 47.87960917609078, 52.521936893463135, 56.68745143072945, 54.301321915217805, 55.632002694266184, 54.211589404514854, 54.25287560054234, 53.17085000446865, 51.998480456215994, 52.19149446487427, 53.81245361055647, 54.92586074556623, 54.15947791508266, 54.62211677006313, 49.94418995720999, 51.14401183809553, 47.92814581734793, 40.68103224890572, 39.939110551561626, 43.03756243841988, 42.78006567273821, 42.7982942717416, 42.435980456215994, 44.45966414042881, 40.09825209208897, 38.59458548682076, 37.163701261792866, 38.5955547605242, 37.46585757391793, 42.99726636069161, 49.07425812312535, 48.275170121874126, 47.76618678229195, 50.2432473727635, 47.8090363230024, 49.70368848528181, 49.02499886921474, 50.160192080906455, 49.7843952860151, 50.25547620228359, 49.49522863115583, 51.83533327920096, 50.6872615814209, 49.2552170072283, 50.83371918542044, 53.86357498168945, 49.394469329289024, 44.22066347939627, 37.760155473436626, 24.24941110610962, 35.06010634558541, 56.384655884334016, 72.00124291011265, 63.66844204493931, 38.787915638514924, 36.22658382143293, 44.004873275756836, 41.13603155953543, 42.489690031324116, 52.262098584856304, 34.50657115663801, 39.84955174582345, 39.8044753074646, 45.761388301849365, 44.9129889351981, 42.638586453029085, 43.9950658934457, 40.04272903714861, 40.31700222832816, 40.83013711656843, 45.737403120313374, 49.317896706717356, 49.927194663456504, 51.93512330736433, 48.48426226207188, 49.03220762525286, 50.05370398930141, 52.71375233786446, 49.88038117544991, 52.328641482761924, 50.00618873323713, 50.19884838376726, 49.900159222739084, 51.203818457467214, 48.74316256386893, 48.160622119903564, 46.44008486611502, 47.219356604984824, 44.88118008204869, 48.08963932309832, 46.00734410967146, 37.75983238220215, 41.281846455165315, 38.03065579278128, 39.924147605895996, 41.789388043539866, 41.57803079060146, 41.05644689287458, 41.581376348223, 41.80359710965838, 43.07315458570208, 40.69691930498396, 41.82405955450875, 40.149689606257844, 51.38213355200631, 53.345482553754536, 55.74894782475063, 54.81259816033499, 48.48000996453421, 48.735964230128694, 56.747171197618755, 56.63317557743618, 59.75571686880929, 57.35819925580706, 59.31625025612967, 57.01781048093523, 54.848093032836914, 53.805738176618306, 55.73699344907488, 51.97257062367031, 50.92447655541556, 50.09979139055525, 61.64370223454067, 62.88812460218157, 63.53510611397879, 63.74091175624302, 39.89301272800991, 0.27988481149077415, 22.494690452303203, 58.85858631134033, 42.371171133858816, 21.18914999280657, 34.95975003923689, 37.61042874200003, 46.053261280059814, 51.11741760798863, 43.38927330289568, 37.88996866771153, 0.1962724830955267, 0.15422419724719866, 0.026435503802661384, 0.024297675749819194, 0.04701844629432474, 0.013217337146800543, 0.2626741778637682, 0.16484538731830461, 0.08360331066484962, 0.20202765427529812, 0.02813005680218339, 0.011012833698519638, 0.2564735348735537, 0.03737388185358473, 0.0707282308222992, 0.0998383534273931, 0.07361949567816087, 0.0342974040790328, 0.4352638210569109, 0.31606120456542286, 17.676670585359844, 70.83800329480852, 41.764416217803955, 46.64675555910383, 77.55209623064313, 59.98502826690674, 33.23454359599522, 38.95240729195731, 51.26829079219273, 56.60943358285086, 1.3026658594608307, 31.82194355555943, 79.42201628003801, 57.82794611794608, 67.9927646092006, 56.283604758126394, 55.32114723750523, 49.54619019372122, 50.0244277545384, 55.310037067958284, 59.92334910801479, 58.490352630615234, 57.063946519579204, 56.51924596514021, 54.80069242204939, 57.13431440080915, 55.85133300508772, 54.04134464263916, 56.40124470846993, 58.93780967167446, 57.787580558231895, 54.968738079071045, 55.05274180003575, 52.182708467756, 50.06226069586617, 42.87002747399466, 42.39141123635428, 43.63930770329067, 45.37477316175188, 45.974267210279194, 45.32024022511074, 44.31843158176967, 44.76162590299334, 41.29684066772461, 39.75290577752249, 39.35968637466431, 40.71649585451399, 45.44232702255249, 52.618499483381, 52.57515662057059, 52.2647180557251, 51.13515288489205, 51.449051652635845, 51.2686208316258, 52.08260924475533, 51.60990245001656, 52.063456535339355, 49.18298353467669, 49.93982648849487, 52.5485589163644, 52.69725384031023, 51.34706251961844, 54.31357158933367, 55.45837415967669, 49.48074858529227, 44.71614646911621, 37.42325816835676, 28.030120509011404, 44.601970195770264, 59.61854553222656, 69.25514807019914, 56.14060735702515, 34.86492797306606, 36.56973450524466, 40.50672626495361, 39.54804509026663, 41.13737256186349, 52.400093282972065, 36.62121023450579, 41.447630473545615, 39.76456832885742, 46.33999606541225, 43.959550176348, 42.197445324489046, 42.152341093335835, 38.69143990107945, 41.44232899802071, 40.47742223739624, 48.331579072134836, 51.26815530232021, 49.245426995413645, 51.21353203909737, 49.515500000544954, 51.539784703935894, 50.261156354631694, 53.14854976109096, 51.525242124285015, 52.74397005353655, 50.935312271118164, 49.41497346333095, 52.42132002966744, 52.64003542491368, 51.19019998822893, 52.806823457990376, 49.08410024642944, 46.08273206438337, 48.960394518715994, 48.865871225084575, 50.93110861097063, 39.90344544819423, 42.4227545601981, 40.57607970918928, 44.19518443516323, 45.02836724690029, 43.475278105054585, 44.77329887662615, 44.116794858660015, 44.17549671445574, 44.54254920142037, 44.05694307599749, 45.345896448407856, 42.88756125313895, 52.48965208871024, 56.10185030528477, 57.682502950940815, 58.79149450574602, 52.23739079066685, 50.23495469774519, 56.440376962934224, 56.93491847174508, 61.30998025621687, 59.51049409593855, 59.994783537728445, 60.37343256814139, 58.340493883405415, 58.96166283743722, 58.46494306836809, 53.81398221424648, 53.47225591114589, 55.047930172511506, 64.3115325655256, 65.0525232042585, 65.64228630065918, 69.88528020041329, 38.32881341661726, 0.0897936127813799, 29.946927002498082, 64.2451286315918, 44.802304131644114, 29.478368282318115, 45.513118743896484, 47.68105745315552, 44.64141164507185, 59.31087929861886, 51.38992943082537, 48.23213297980172, 0.8332743325403759, 0.10481540100382906, 0.05100971819566829, 0.06379912620676415, 0.04939178876312716, 0.014955527581540602, 0.20378875120409898, 0.10931344356920038, 0.17566133051046304, 0.30926621918167385, 0.061100164960537634, 0.23942718814526284, 0.3981760468866144, 0.12082358236823763, 0.22049222061676638, 0.20892798900604248, 0.22987811054502214, 0.1179563512227365, 0.6109400114842823, 0.41975245624780655, 22.265589237213135, 83.38655417306083, 46.78543812888009, 54.14302110671997, 78.43813051496232, 68.69872937883649, 38.09867170878819, 50.74584879193987, 59.227751050676616, 61.08799920763288, 1.7291407521281923, 40.84656613213675, 78.32361030578613, 61.61234501429966, 68.15423379625592, 57.357580866132466, 59.110757282802034, 55.16184936250959, 54.54557541438511, 55.6569675718035, 60.81804779597691, 62.53783117021833, 60.12492329733712, 58.5447917665754, 54.31087221418108, 56.38156393596104, 61.31870024544852, 56.51758534567696, 59.15724073137556, 60.52379853384835, 62.824096952165874, 56.892246110098704, 57.07515396390642, 55.560238225119456, 51.942286900111604, 44.13112551825387, 46.140874590192524, 44.352227619716096, 46.64298268726894, 46.288204193115234, 47.95833921432495, 46.10893024717058, 46.65971394947597, 42.45930903298514, 42.175082547324045, 43.58568845476423, 44.7890921320234, 48.867792401994976, 56.5296265738351, 55.38018260683332, 53.87700237546648, 56.61907768249512, 56.6363821710859, 55.85444927215576, 55.78719070979527, 55.222656522478374, 56.66508517946516, 53.722644669669016, 53.74381930487496, 55.93090377535139, 58.13057490757534, 50.64213650567191, 55.482262066432405, 58.73555455889021, 53.14059754780361, 46.6502366065979, 39.49644429343087, 39.681134360177175, 51.26803023474557, 58.722825459071565, 62.04163251604353, 49.69304037094116, 36.792667457035606, 38.34382847377232, 42.122241497039795, 40.550409589494976, 37.90429237910679, 56.01791954040527, 41.57736028943743, 43.00149086543492, 44.31997060775757, 49.25681856700352, 45.06669698442732, 43.93872989927019, 43.38175187792097, 40.32645525251116, 42.041291509355815, 40.6052690914699, 48.29657404763358, 53.07638577052525, 51.860979080200195, 55.34485796519688, 50.94925730569022, 53.98473766871861, 53.25185905184065, 55.87281336103167, 53.494226115090505, 55.60806615012032, 55.40301786150251, 51.64111723218645, 55.22720064435686, 54.91548013687134, 54.51171336855207, 57.65310512270246, 56.185951301029746, 48.824605873652864, 51.342032023838584, 52.35594095502581, 52.37886306217739, 42.15844855989729, 45.072783606392996, 44.590394496917725, 47.495523180280415, 48.09252282551357, 48.63302666800362, 47.976956912449424, 48.75585692269461, 47.46953344345093, 44.93960748400007, 42.681720869881765, 47.8225679397583, 44.658455576215474, 56.77134050641741, 61.66278198787144, 59.537341935294016, 58.62151377541678, 52.60437726974487, 50.472520555768696, 56.74042102268764, 60.91000025612967, 64.79760769435337, 61.20422172546387, 62.492966651916504, 62.82807132175991, 61.0655426297869, 59.6855400630406, 63.0916998726981, 53.729915959494456, 54.65823003223964, 57.24782017299107, 66.62004375457764, 68.57193170275006, 69.46499756404332, 70.71807043892997, 48.09343998772757, 0.32984862902334755, 31.527207919529506, 70.0333115713937, 56.5106406211853, 31.4532756124224, 49.21352434158325, 55.14574343817574, 59.458862032209126, 68.50781372615269, 58.09513562066214, 55.48519420623779, 0.7858985289931297, 0.26796539393918856, 0.10249622937824045, 0.16603361070156097, 0.12064424556280885, 0.07135877305907862, 0.49724300099270685, 0.18021138278501375, 0.23819966401372636], [0.06217494407402618, 0.05652956325294716, 0.04700964908780796, 0.06386316634182419, 0.04662222255553518, 0.12246432075543062, 0.06414532834397894, 0.3689097730176789, 0.08999407238193921, 0.11423496662506036, 0.1372263522020408, 17.88404130935669, 55.48788663319179, 33.43890053885323, 24.34746755872454, 32.61989900044033, 42.91471481323242, 25.752657345363072, 28.445784330368042, 41.66941697256905, 59.68883350917271, 7.834746173449925, 9.945096475737435, 85.05874238695417, 58.95850140707833, 67.82160963330949, 53.95445741925921, 52.08586794989449, 45.473020689828054, 52.87863309042794, 54.03019625799996, 56.918888977595735, 54.87207474027361, 53.769944531576975, 52.69763946533203, 50.874591963631765, 51.117091042654856, 53.97998857498169, 53.92802994591849, 52.46428768975394, 54.20492260796683, 50.891861711229595, 52.15229272842407, 53.19112137385777, 49.625417028154644, 43.53906604221889, 39.16385834557669, 40.67437587465559, 42.88039418629238, 46.156494140625, 45.719970090048655, 43.866270610264365, 40.228787899017334, 41.95632198878697, 37.153049673352925, 38.11661890574864, 38.79699345997402, 37.893533093588694, 43.874931539808, 50.23090042386736, 48.06683186122349, 47.48373556137085, 50.355116844177246, 50.47050210407802, 48.580095291137695, 49.45118400028774, 46.21100275857108, 49.191255365099224, 50.65078353881836, 50.56173195157732, 50.234979016440256, 49.9534831728254, 50.31950037819998, 53.15561955315726, 47.55841479982649, 41.07940026691982, 35.393404483795166, 42.77872119631086, 42.85648890904018, 33.46377508980887, 39.156093733651296, 36.71662637165615, 36.21106849397932, 38.29607697895595, 43.1260929107666, 35.819794586726594, 47.12453801291329, 31.823625019618444, 41.58516659055437, 50.449674878801616, 45.940394742148264, 53.29589326041085, 40.831238406045095, 43.43790374483381, 44.525137015751426, 43.60744326455252, 43.51838820321219, 39.914670263017925, 46.32846205575125, 49.265715735299246, 51.807776723589214, 52.15605865206037, 51.47677843911307, 47.217317308698384, 51.26010581425258, 51.36570453643799, 51.281554903302876, 51.38299512863159, 52.397122928074424, 51.97366843904768, 49.84047072274344, 50.278565066201345, 49.11916780471802, 47.99146127700806, 47.24255664008004, 47.65540470395769, 47.2221463067191, 44.153394494737896, 48.560087953295024, 47.51538808005196, 41.3659405027117, 37.97883265359061, 42.07815170288086, 43.705485820770264, 42.96176106589181, 43.42305197034563, 43.45050777707781, 43.842097827366416, 43.3996365410941, 43.32648243222918, 43.07308857781546, 39.758610248565674, 40.227895055498394, 43.22369425637381, 53.297442708696636, 53.9565384047372, 55.35601677213396, 54.105226380484446, 54.90920243944441, 48.32164314814976, 47.485868658338276, 52.96592330932617, 57.578940050942556, 59.51038987295968, 58.90439578465053, 56.21303537913731, 58.221752643585205, 51.675146034785676, 52.83329956872122, 46.97337647846767, 56.66256645747593, 58.10563434873308, 65.78349454062325, 60.58691596984863, 71.55199323381696, 19.122887747628347, 0.07267107335584504, 37.67966059276036, 54.669548647744314, 30.308306285313197, 18.58973162514823, 29.104466608592443, 32.9926872253418, 26.543852193014963, 32.355231693812776, 50.312298570360454, 45.919195788247244, 2.139830857515335, 0.1892891228199005, 0.06853293254971504, 0.07463462477816002, 0.03399054679487433, 0.07310569539133992, 0.13162408210337162, 0.1884159025337015, 0.05878361926547118, 0.08339234055685145, 0.011368269849169468, 0.08809788591627564, 0.12246269227138587, 0.09587439256055014, 0.05745122754680259, 0.08628266224903719, 0.22541997262409755, 0.02661082028810467, 0.13030446719910416, 0.053523313852825334, 23.206418752670288, 63.04807908194405, 36.96032401493618, 34.38385902132307, 39.32657126017979, 47.646847997392925, 30.131901945386613, 34.35088981900896, 43.92444092886788, 65.6458020891462, 12.026127117020742, 7.2601518630981445, 85.17518724714006, 62.39114080156599, 70.12102563040597, 56.527628966740195, 55.18031072616577, 47.14514984403338, 55.819208008902415, 55.56759289332798, 58.42551898956299, 57.17654207774571, 57.035976546151296, 55.114129134586875, 51.89444507871355, 51.86382784162249, 55.53357451302664, 55.54597357341221, 53.847420419965474, 55.227596691676546, 52.01370743342808, 53.18663283756801, 55.40003361020769, 51.278733934674946, 45.078196253095356, 41.756328514644075, 44.05701603208269, 45.2297295161656, 49.93787751879011, 46.297928197043284, 44.53797728674752, 42.2442900793893, 43.93767377308437, 39.74051366533552, 40.19663858413696, 40.243973187037874, 41.414435454777305, 45.58538695744106, 55.623685700552805, 51.94087641579764, 51.73889923095703, 51.87441689627511, 54.50118337358747, 52.342697688511436, 52.10279723576137, 48.79611478533064, 52.65499489648001, 54.22865765435355, 52.902736391339985, 51.474040848868235, 51.844668184007915, 51.801182883126394, 53.90025452205113, 46.71221106392996, 42.84274189812796, 35.88815443856375, 44.89413499832153, 44.80640009471348, 34.65049614225115, 40.181557519095286, 34.469606740134104, 34.6031928062439, 38.596190520695274, 41.78017473220825, 35.21470376423427, 45.804668630872456, 31.50262519291469, 42.34388903209141, 50.72863810403006, 44.62282868794033, 51.5174879346575, 40.55183744430542, 43.5857058252607, 45.37215716498238, 47.03476728711809, 43.89916685649327, 38.87513290132795, 47.13863590785435, 48.590455055236816, 53.81059149333409, 55.27233266830444, 51.82889577320644, 50.0367225919451, 54.128231866019114, 54.72170182636806, 53.78194407054356, 51.638466494424, 53.9040412902832, 53.765845094408306, 50.69439738137381, 53.523801122392925, 53.972633906773154, 52.63076652799334, 50.67238548823765, 51.40676491601126, 48.66299077442714, 46.40962743759155, 51.31031002317156, 50.371820313589915, 45.153115204402376, 40.3690824508667, 46.56474249703543, 45.20811019624983, 47.446052006312776, 45.33312913349697, 45.826454707554404, 46.34682614462716, 46.928901059286936, 47.57226603371756, 48.08357701982771, 43.648684297289165, 45.14687919616699, 44.776321343013215, 55.63868686131069, 57.83892774581909, 56.17742238725935, 56.952959469386506, 58.67245101928711, 48.561554023197715, 50.553769315992085, 54.64816904067993, 61.05803162711007, 61.33411134992327, 62.07985455649239, 58.80348709651402, 61.948742049080984, 56.07441881724766, 56.20529856000628, 50.25309297016689, 60.87755216870989, 58.555464199611116, 68.76931612832206, 60.748371260506765, 75.72559547424316, 16.575450590678624, 0.1660011631569692, 46.03371947152274, 57.993608542851035, 35.212921551295686, 26.353752953665598, 27.773438419614518, 40.747724533081055, 26.323326792035783, 39.420712402888704, 57.76878915514265, 54.19607755116054, 3.6352230267865315, 0.3307952396571636, 0.08402601084006683, 0.10824021830090455, 0.03938314618010606, 0.06841394464884486, 0.07026884225862366, 0.044463320901351314, 0.06437189797205584, 0.1258137324558837, 0.10640910334352936, 0.14987623984260218, 0.15996567559029373, 0.19406968701098645, 0.2842479273676872, 0.14158368696059498, 0.4589193974222456, 0.25191527232527733, 0.2642294886921133, 0.20852160081267357, 31.192242213657924, 74.47095925467355, 44.511244092668804, 37.40229197910854, 43.51716879435948, 55.93844951902117, 33.346076079777305, 45.4654541015625, 49.801817893981934, 73.72179753439767, 10.024222561291285, 12.616036994116646, 88.88332271575928, 64.34115968431745, 73.33492183685303, 58.96914604731968, 57.18642936434065, 50.867053168160574, 59.69988809313093, 59.48120743887765, 61.1503176007952, 61.15568855830601, 59.38375200544085, 56.80781160082136, 57.06811891283308, 53.066811152866904, 59.77294840131487, 58.45976666041783, 54.83656597137451, 59.222887311662944, 53.91025645392281, 56.03151021684919, 60.684357506888254, 51.584951468876426, 48.415492466517854, 44.70423378263201, 44.04679523195539, 48.432539871760774, 52.91787999016898, 47.62193523134504, 46.501409666878835, 43.655503954206196, 45.27951683316912, 39.833918298993794, 40.05220985412598, 41.8114138330732, 43.8381929397583, 48.362189361027305, 57.58914000647408, 55.334546838487896, 54.455700465611045, 56.09089299610683, 59.20261246817452, 54.74621507099697, 55.249403612954275, 51.43827152252197, 55.022308690207346, 57.99185759680611, 57.3944410596575, 55.1297938483102, 56.1138984816415, 55.460927622658865, 57.628890650612966, 51.77253198623657, 44.36527286257063, 39.62531253269741, 46.64052997316633, 43.88035808290754, 35.176082202366416, 41.337980951581685, 36.70956352778843, 36.18921988351004, 37.98203229904175, 42.72522006716047, 35.33185386657715, 47.622247900281636, 35.61563219342913, 37.1390768459865, 50.840128898620605, 46.08813081468855, 51.081974846976145, 41.58482265472412, 43.854531628744944, 46.22575725827898, 47.970286641802105, 45.423070090157644, 40.03797994341169, 48.209964752197266, 51.546802384512766, 56.370085511888774, 59.525404930114746, 53.995239870888845, 51.24160623550415, 55.57294648034232, 60.73087569645473, 54.300363063812256, 54.386996677943635, 56.28803423472813, 55.54440328053066, 54.342184271131245, 57.93595586504255, 57.065791266305105, 55.05682386670794, 53.79352671759469, 57.24063573564802, 52.051870414188926, 46.84713813236782, 53.58626542772566, 53.96696070262364, 47.98856735229492, 41.372864382607595, 48.395676204136436, 46.4025159563337, 48.74998222078596, 49.2905763898577, 50.36823156901768, 49.85504109518868, 48.853343623025076, 51.140131269182476, 51.27315105710711, 45.90802308491298, 47.63814885275704, 47.8214110646929, 59.97510623931885, 61.60888481140137, 59.58238015856062, 58.408648763384136, 60.199269022260395, 49.1720609664917, 48.505773884909495, 56.81948457445417, 61.19307681492397, 63.3361097063337, 63.44821194240025, 61.625741141183035, 63.382933616638184, 58.90551444462368, 62.111559186662944, 52.96562801088606, 62.224126952035085, 62.24795232500349, 70.98174067905971, 67.02951499394008, 74.98721040998186, 24.749650137765066, 0.1453332986150469, 48.55414029530117, 65.41127954210553, 43.60396916525704, 27.283927406583512, 33.9342862537929, 45.650734765189036, 32.002895491463796, 44.34064844676426, 63.69698524475098, 66.46256283351353, 4.846099274499076, 0.3781270741352013, 0.1664827601718051, 0.20063829954181397, 0.0874192084052733, 0.23058435693383217, 0.22355989100677626, 0.24383500590920448, 0.21720459631511144], [0.062209569716027806, 0.09841912279703788, 0.02936381327786616, 0.05355081148445606, 0.024042989326907054, 0.2716415066804205, 0.06219941204679864, 0.24367769435048103, 0.06500067601778678, 0.11831452271768025, 0.3962927593716553, 25.07638396535601, 47.15151786804199, 43.0672173500061, 27.155385732650757, 21.77862126486642, 39.93706430707659, 25.95793318748474, 26.38367884499686, 44.2928135735648, 62.47074631282261, 21.855650731495448, 1.3692507722548075, 61.393303053719656, 68.40938554491315, 61.8499664579119, 61.36285604749407, 52.524511201041086, 51.00584690911429, 53.53148930413382, 57.347974981580464, 55.18571989876883, 52.64686550412859, 56.810465812683105, 55.09247159957886, 53.78625890186855, 52.27250351224627, 52.07135316303798, 54.7929173878261, 52.14259304319109, 51.41115270342146, 50.836116313934326, 52.56441470554897, 51.868094035557334, 48.774578843797954, 41.66351447786604, 42.479021072387695, 41.881208487919395, 46.80777311325073, 46.85145991189139, 45.443042687007356, 44.57864161900112, 45.36049113954817, 42.75120980398995, 42.68463216509138, 39.74100003923689, 41.44433355331421, 37.89734418051583, 40.862821442740305, 47.08425235748291, 47.19917556217739, 48.67366668156215, 47.987455640520366, 45.48135157993862, 45.41626780373709, 48.20057773590088, 46.977750369480674, 48.452109473092214, 50.274569852011545, 48.36148411887032, 48.50060789925711, 49.21518496104649, 47.33856337411063, 52.54405648367745, 45.09815495354788, 42.21180725097656, 45.01825066975185, 36.42273146765572, 33.03819792611258, 33.48628725324358, 34.78010783876692, 33.84277153015137, 42.43400021961757, 44.44629233224051, 40.41865784781319, 40.751514775412424, 37.522777216775076, 43.30958441325596, 36.057235377175466, 38.46567555836269, 45.725799628666465, 38.07450934818813, 43.43604857581002, 36.24218600136893, 43.34520435333252, 44.167165824345176, 44.95337881360735, 38.33347218377249, 43.42043249947684, 52.98551375525338, 50.57328680583409, 49.12089443206787, 51.40046984808785, 52.606093474796836, 52.7850512777056, 51.4231070790972, 51.81272036688668, 50.87039177758353, 50.91417932510376, 51.39624534334455, 50.593189920697895, 51.10880184173584, 49.848398617335725, 48.31257574898856, 47.982241017477854, 46.563366753714426, 46.96326684951782, 45.543482371738975, 47.167606421879356, 42.38256965364729, 39.78514541898455, 38.099484648023335, 45.34366260256086, 44.18695429393223, 44.99406746455601, 43.78671373639788, 43.721108845302034, 44.1966609273638, 47.864580222538535, 48.09223100117275, 48.21424136843, 40.66824756349836, 41.88644048145839, 40.58442449569702, 43.15868691035679, 53.57492944172451, 54.6263655935015, 52.85998412540981, 56.33795009340559, 55.01607615607125, 56.432171140398296, 50.760123865945, 55.4034104347229, 59.62554236820766, 60.743799345833914, 56.65065029689244, 60.17092037200928, 54.23302459716797, 52.818527698516846, 48.68763950892857, 58.08497040612357, 57.53190769468035, 68.28387328556606, 56.8594262940543, 69.06719929831368, 3.2900979689189365, 3.410059920379094, 57.62926932743618, 56.03081539699009, 20.291625125067576, 22.28323766163417, 33.84803131648472, 27.401789699281963, 45.52520860944475, 46.249954359872, 46.42203344617571, 48.04651532854353, 6.459131394113813, 0.1714542234050376, 0.11686331273189612, 0.0625754968662347, 0.02947455019290958, 0.17784390625144753, 0.15158639236220292, 0.09186064079403877, 0.036332632548042705, 0.04193885172052043, 0.09949304017105273, 0.08846247635249581, 0.03663580538704991, 0.09043941527072873, 0.13007453882268497, 0.04714785310040627, 0.37044231221079826, 0.08327549682664019, 0.09478794943009104, 0.09642911529434578, 32.00264188221523, 58.731719153267996, 45.118370737348286, 33.46688093457903, 30.78605052403041, 44.88348340988159, 28.071894815989904, 32.65360818590437, 48.68287304469517, 67.7907109941755, 25.9235326562609, 1.0568240455218723, 57.75233929497855, 72.180666242327, 64.75184685843331, 63.504436765398296, 54.31157398223877, 52.995442731039866, 54.15164729527065, 60.03586823599679, 55.527977739061626, 54.18174341746739, 58.87130846296038, 58.891645840236116, 55.78704827172415, 54.60211290631975, 55.3319308417184, 56.267286913735525, 55.50142867224557, 52.725529534476145, 52.57682071413313, 54.97500535420009, 52.50580317633492, 51.672057560511995, 44.620921407427105, 44.65983826773507, 42.34793288367135, 49.4904899597168, 47.2509639603751, 48.4819415637425, 46.574574198041645, 45.682564462934224, 44.57157530103411, 43.37955972126552, 39.68874263763428, 41.546048232487266, 40.91062157494681, 44.55309656688145, 49.31510700498308, 50.92747817720686, 51.87160982404436, 53.23224776131766, 47.07622023991176, 47.49788556780134, 50.24619688306536, 50.32442665100098, 53.51430640901838, 52.915625299726216, 51.40331860951015, 50.43371139253889, 49.50748177937099, 49.78026110785348, 53.522248200007844, 47.112493310655864, 42.66639314379011, 45.02952759606497, 37.661136695316856, 34.4482410294669, 33.769579206194194, 35.08798599243164, 35.17719391414097, 43.51877382823399, 43.803955691201345, 40.46474872316633, 38.96588332312447, 37.92417117527553, 42.662950311388286, 33.43422787530081, 37.54355580466134, 45.68993302753994, 38.87540735517229, 42.565296854291645, 35.16288409914289, 44.262641021183555, 43.770409788404194, 46.46447651726859, 38.27166100910732, 43.50644077573504, 53.920901094164165, 52.88939585004534, 49.654318060193745, 51.744099957602366, 53.90418372835432, 51.93381009783064, 51.58613613673619, 52.55840451376778, 52.91839068276541, 53.14319269997733, 52.659184660230366, 53.06146798815046, 52.03246756962368, 52.737602029527935, 52.610571588788716, 51.765528202056885, 48.38479879924229, 50.57253987448556, 48.93227515901838, 49.5336799621582, 45.12069838387625, 42.62982824870518, 43.03892081124442, 49.49391194752285, 48.5012332371303, 47.447809900556294, 47.342530795506065, 49.082359722682405, 49.747847761426655, 50.686271463121685, 49.95190245764596, 51.303281920296804, 46.10923944200788, 45.91686119352068, 42.93257168361119, 47.64206068856375, 53.65670279094151, 59.01474012647356, 56.68929270335606, 61.36894266945975, 57.139393533979145, 56.512374196733745, 50.28878239222935, 56.32230275017874, 61.02631310054234, 65.55810192653111, 59.60897091456822, 63.1804770060948, 55.746925898960654, 56.69965941565377, 51.30588749476841, 59.93648815155029, 59.66033894675118, 72.35376671382359, 59.79709339141846, 68.85719694410051, 2.5421261276517595, 5.375757847513471, 66.51371547154018, 56.1379531451634, 25.60462076323373, 24.92784537587847, 31.608665125710623, 36.58993639264788, 42.9280240876334, 47.930782658713206, 58.343321800231934, 56.63937684467861, 12.737769433430262, 0.5606448788728032, 0.1727206954466445, 0.11905907919364316, 0.04580980579235724, 0.03243839454704097, 0.17244043334254197, 0.09604687616229057, 0.09063158995871033, 0.10101178474724293, 0.10420291458389588, 0.1444197462073394, 0.1804814940052373, 0.19535518517451628, 0.359130292066506, 0.1244717530374016, 0.46922194744859425, 0.13375582200075897, 0.18376056876565727, 0.5561917349696159, 39.49269574029105, 66.70458943503243, 54.789061137608115, 38.33689764567784, 33.68228203909737, 54.77153778076172, 36.344004903520855, 42.31311546053205, 53.92597327913557, 78.36310386657715, 26.858431884220668, 2.089179575443268, 66.47402736118862, 72.94515568869454, 68.84858117784772, 65.07953780038017, 55.40363277707781, 54.65223721095494, 57.879268986838206, 62.756115777151926, 58.753661564418245, 58.966206959315706, 63.36537551879883, 62.90275750841413, 58.31748144967215, 57.94985921042306, 58.89317444392613, 58.924573353358674, 58.09095975330898, 55.45335061209542, 55.85728413718087, 57.3145089830671, 54.27676003319876, 53.09667798451015, 48.81744922910418, 47.87826469966343, 45.132989747183665, 51.333252974918906, 47.155867440359934, 48.20763363157, 47.201426778520855, 46.55457728249686, 46.405719075884136, 44.900697571890696, 41.629812240600586, 45.39478744779314, 43.331863812037874, 47.03226246152605, 53.840440954480854, 54.6272862298148, 56.01410150527954, 56.51827669143677, 51.001556396484375, 52.15512064525059, 54.44550051007952, 52.81954560961042, 55.43794298171997, 55.78860814230782, 52.50757496697562, 55.83746787479946, 52.99242026465279, 50.7273804800851, 58.9277069909232, 49.614810603005544, 46.03992073876517, 45.84278992244175, 38.224896158490864, 34.57100180217198, 35.022791045052664, 36.19113411222185, 33.948801040649414, 41.887513978140696, 44.88049915858677, 41.5776104245867, 39.27620029449463, 37.46894257409232, 44.97279902866909, 37.50070973805019, 40.162887709481375, 44.68249634334019, 39.97075612204415, 47.839997495923726, 35.73795175552368, 45.74547692707607, 45.319809436798096, 47.39299556187221, 37.84132432937622, 45.25719574519566, 54.71780388695853, 54.907656465257915, 49.127790519169395, 54.56422437940325, 55.40246895381382, 53.62933036259243, 54.40083401543753, 54.774560247148784, 56.30532830102103, 56.08203404290335, 54.646918364933555, 55.6393712588719, 55.38773529870169, 56.97281394686018, 55.73265777315412, 53.96009240831648, 53.09975603648594, 54.70048550197056, 51.63987350463867, 53.23695169176374, 48.835111549922395, 43.85408694403512, 43.20869656971523, 51.33332940510341, 50.62841728755406, 48.53945180347988, 50.57551370348249, 52.83546045848301, 50.78472048895699, 53.22164828436715, 52.07528584344046, 53.40964221954346, 48.135462692805696, 49.25107588086809, 47.996794019426616, 51.71204791750227, 57.55898482458932, 61.095829827444895, 58.40003299713135, 60.81223215375628, 59.17837715148926, 55.910559449877056, 48.94679341997419, 59.804354258946006, 63.611327852521626, 67.87324169703892, 62.147411891392295, 66.73949718475342, 57.46370070321219, 58.88492693219866, 52.51316131864275, 63.27955136980329, 59.1845679964338, 74.76288087027413, 58.99383299691336, 78.02853420802525, 4.840996691158839, 3.733146812234606, 70.62377643585205, 65.33493968418666, 32.06121172223772, 28.123426130839757, 43.7810057912554, 41.34443235397339, 58.70432240622384, 57.183434690747944, 59.25783675057547, 66.33610561915806, 13.595192773001534, 1.0535814080919539, 0.35543295474989073, 0.2496823492859091, 0.1591158104794366, 0.1553577035665512, 0.28326774282114847, 0.13842820056847163, 0.10700223794473068], [0.10681479264582906, 0.1601437231791871, 0.10539776725428444, 0.11576414028448717, 0.14958149780120167, 0.18843654356896877, 0.15540551314396517, 0.30293274617620874, 0.07564371491649322, 0.18276076098637922, 0.37670554327113287, 33.198840277535574, 51.52936935424805, 50.090612820216585, 28.764722279139928, 27.681181975773402, 37.27558462960379, 32.027283668518066, 19.983562844140188, 43.876150948660715, 58.66993577139718, 39.22623927252633, 0.15545503262962612, 27.520695958818706, 79.88840716225761, 58.17967782701765, 68.32271371568952, 49.985309396471294, 53.19934456689017, 52.800844533102854, 59.63620090484619, 54.68660300118582, 56.327854360852925, 52.91555234364101, 54.44454860687256, 50.62019756862095, 52.21597991670881, 54.16158669335501, 55.66929367610386, 51.36274460383824, 51.93648515428816, 52.475390911102295, 56.240994930267334, 50.143523352486746, 45.82877540588379, 38.94471911021641, 43.24550812585013, 45.45585516520909, 47.01280403137207, 48.482535634722026, 49.47186878749302, 47.916229656764436, 44.84818308694022, 46.325988497052876, 46.53577545710972, 42.792888573237825, 45.0411901473999, 41.207879407065256, 42.48969350542341, 46.02645165579659, 47.53792803628104, 48.500114577157156, 49.02497802461897, 45.0201301574707, 45.80195535932268, 46.86158691133772, 45.28262962613787, 46.92413112095424, 49.33659430912563, 49.30928788866316, 46.73605033329555, 47.60714251654488, 48.02421855926514, 50.10873719624111, 44.90415777478899, 40.39449896131243, 38.370665890829905, 36.590214320591514, 34.362632274627686, 32.557135922568186, 34.49760798045567, 40.8778851372855, 42.523465224674766, 40.55157341275896, 35.362113271440776, 31.80424996784755, 36.464941774095806, 32.79812724249703, 36.90443270547049, 41.67202949523926, 42.962712969098774, 46.19387544904436, 42.57084151676723, 35.6145031111581, 40.44800703866141, 36.5454227583749, 40.96982022694179, 40.469209466661724, 37.84575033187866, 46.371297700064524, 51.848955222538535, 56.0809258052281, 52.087472983769004, 50.15515463692801, 51.73273270470755, 51.25096198490688, 53.044868741716655, 52.23556341443743, 51.608130659375874, 50.9757890020098, 50.37478024618966, 49.12579986027309, 49.62708806991577, 49.26558371952602, 46.91689804622105, 45.17182322910854, 47.27570996965681, 45.47133922576904, 43.5751063483102, 41.410662582942415, 42.99978508268084, 43.23489475250244, 44.30543497630528, 43.66508552006313, 47.18005064555577, 44.12410088947841, 45.98029824665615, 46.97193125316075, 49.29235512869698, 49.433316707611084, 49.152685914720806, 45.175453662872314, 43.63487127849034, 38.78985071182251, 42.09876700810024, 43.36552783421108, 51.614106110164094, 53.15067938395909, 55.97913122177124, 54.058541434151785, 55.06632205418178, 54.55040788650513, 52.71162966319493, 55.422733375004356, 60.21162986755371, 57.108272552490234, 59.91788782392229, 54.75700214930943, 53.176926204136436, 50.39098344530378, 57.59206172398159, 62.173071588788716, 63.12377970559256, 65.13302503313336, 48.32544033867972, 0.11249324187104191, 20.27042964526585, 65.41580976758684, 39.808192593710764, 13.130730884415762, 30.576176711491176, 22.72284323828561, 25.187945978982107, 30.05231727872576, 29.26733759471348, 34.311583859579905, 52.2348963873727, 17.755105325153895, 0.16679614835551806, 0.04107724456116557, 0.03139570335458432, 0.07047525261129652, 0.03949622404096382, 0.0609438508482916, 0.06506418011018208, 0.02538352007312434, 0.03722097398713231, 0.09172112720885447, 0.013525956077501178, 0.1020438229399068, 0.17257900376405033, 0.1527514098478215, 0.10634588423584189, 0.3048175536096096, 0.02105118254465716, 0.17141314489500864, 0.2744127522621836, 42.74690539496285, 59.05374036516462, 57.96971368789673, 31.21237461907523, 30.778852190290177, 47.2475072315761, 41.52673918860299, 24.807565110070364, 51.68452262878418, 62.475964409964426, 47.9921213558742, 0.40135541771139416, 24.57155564853123, 82.94983209882463, 59.124479975019185, 72.52108628409249, 53.89383091245379, 56.604437828063965, 55.265766620635986, 61.52413068498884, 55.62289360591343, 60.91153580801827, 55.42589133126395, 58.641663551330566, 54.25020054408482, 55.472631863185335, 57.10113327843802, 58.17978204999651, 53.119732107434956, 54.401101521083284, 55.51909099306379, 56.74807446343558, 50.47455985205514, 46.19210018430437, 41.682743617466514, 45.92600849696568, 46.96377059391567, 48.90794604165213, 49.310701847076416, 52.79720715114048, 50.70080362047468, 45.94953857149397, 45.76905216489519, 49.364665031433105, 44.87197024481637, 46.613709926605225, 44.216438974652974, 45.394686698913574, 46.27228239604405, 48.73177446637835, 51.58857148034232, 53.73321982792446, 50.20540400913784, 48.81793212890625, 49.05027641568865, 48.52455833980015, 49.53185258592878, 51.343835081372944, 52.65691954748971, 48.77700029100691, 48.01612738200596, 46.973164558410645, 49.13865055356707, 47.2091566494533, 40.26519645963396, 38.035307611737935, 40.16161618913923, 36.14809002195086, 33.270135743277415, 35.27048737662179, 40.474903515407014, 42.26747274398804, 41.13930416107178, 35.33056150163923, 30.569297994886124, 35.21712173734392, 33.35328483581543, 36.981588976723806, 40.5982792036874, 41.46609878540039, 44.61830193655831, 41.85606990541731, 36.102092947278706, 41.77772549220494, 36.88783345903669, 41.31762967790876, 41.00520740236555, 39.29364027295794, 46.603892121996196, 50.30897038323538, 57.09465408325195, 52.738845757075715, 51.82889229910714, 51.55213165283203, 50.98398787634713, 55.470755849565776, 54.41149950027466, 54.036442688533235, 54.67860562460763, 52.118173599243164, 52.74368865149361, 54.07791996002197, 51.00731645311628, 50.51398045676095, 50.72442749568394, 50.06844111851284, 49.59422309058053, 48.51256922313145, 45.99521255493164, 47.530868666512625, 48.35767650604248, 49.161569186619346, 48.18607684544155, 50.65210369655064, 48.52525315965925, 48.516831942967, 50.051501410348074, 53.751215662275044, 51.64934042521885, 53.244216033390586, 50.09982960564749, 45.37646157400948, 42.79273223876953, 45.430376120976035, 44.50237124306815, 53.590705326625276, 57.61672782897949, 58.24624851771763, 55.58000585011074, 56.611889771052766, 56.44360440117972, 53.23622213091169, 57.78800787244524, 62.6660601752145, 59.5985347202846, 61.86259133475167, 56.856316975184846, 54.35167898450579, 51.08822475160871, 60.329172543116975, 62.32286780221121, 63.6506199155535, 66.45434311458042, 46.37892682211739, 0.23349904481853756, 27.632179805210658, 68.93511404309953, 42.63844401495797, 15.965492555073329, 28.60425536973136, 18.989362478256226, 28.225656713758195, 33.84535278592791, 28.261627537863596, 48.13241590772356, 63.61589976719448, 27.29758930206299, 0.17949293633656843, 0.14400453705872807, 0.048950001397835355, 0.050968978953148635, 0.013893934947970723, 0.07094721442886762, 0.01793837091619415, 0.09636267314531974, 0.15065328457525798, 0.17493276031953947, 0.13827117399445601, 0.1617899848414319, 0.26065195351839066, 0.23249022609421185, 0.2573738694190979, 0.3519815185240337, 0.21400556154549122, 0.29807579251272337, 0.24043445980974607, 50.83904150554112, 67.11672183445522, 66.84427601950509, 39.01831790379116, 39.10277325766427, 51.91628674098423, 44.59877402441842, 32.44203553880964, 56.366236209869385, 68.61387102944511, 50.20606061390468, 0.4815656393766403, 33.880086830684114, 82.81295258658272, 61.06900978088379, 74.68743732997349, 55.069966384342735, 57.155454295022146, 58.15372283118111, 64.7035916192191, 58.39047227587019, 62.87516621180943, 57.72811092649187, 62.12743582044329, 56.75469609669277, 57.095060552869526, 59.179009437561035, 61.74722344534737, 55.25747741971697, 57.517712524959016, 56.94434370313372, 60.6917017527989, 52.00791263580322, 50.41573987688337, 44.11617646898542, 48.587185927799766, 48.55007907322475, 49.336434500558035, 48.96007490158081, 51.73226022720337, 50.84684780665806, 47.717104707445415, 48.63036550794329, 51.30711385181972, 45.392150606427876, 48.6906168120248, 47.36682864597866, 48.58865894590105, 52.16619259970528, 54.432677609579905, 57.54051651273455, 57.91391270501273, 52.699734347207205, 52.27702678952898, 55.40214933667864, 54.25110033580235, 52.31022180829729, 55.531708921704976, 57.306306634630474, 52.99517869949341, 51.28769711085728, 50.90161003385271, 52.703489848545615, 49.56814302716936, 43.76020288467407, 39.024814469473704, 39.94805983134678, 37.05193253925869, 33.081704071589876, 35.897461550576345, 41.414438928876606, 43.83974238804409, 41.35734558105469, 35.199320452553884, 30.783844470977783, 37.59781081335885, 32.7554930959429, 37.854421683720176, 42.480785914829795, 44.55135951723371, 47.23135266985212, 42.262230328151155, 36.55729375566755, 42.593131337847026, 37.53684384482247, 42.73539917809622, 41.37023448944092, 40.137985365731375, 45.97348206383841, 53.33863510404314, 57.47647844042097, 55.92922231129238, 53.25398867470877, 56.07610028130667, 52.99913222449166, 56.74194267817906, 58.10006536756243, 56.22846038000924, 56.698721408843994, 53.066373416355674, 54.02965777260916, 57.68593536104475, 55.325739996773855, 53.64198303222656, 53.921641077314106, 56.34939725058419, 53.07627807344709, 52.46482270104544, 46.24820341382708, 49.90343529837472, 48.897301401410786, 50.381304604666575, 46.11473546709333, 50.26486669267927, 50.69210794993809, 50.784192425864084, 52.13744442803519, 54.643010003226145, 53.06019994190761, 55.355547768729075, 51.81629521506173, 49.465017863682334, 46.84654058728899, 49.42693478720528, 47.22409527642386, 58.68255370003836, 61.01655088152204, 60.745703152247835, 59.676695006234304, 59.89832169669015, 56.67915528161185, 53.023662839617046, 61.424618584769114, 66.5990185056414, 61.835507256644114, 62.9276042665754, 58.34416948046003, 56.66134704862322, 53.257723331451416, 63.56847831181118, 64.80982262747628, 65.92354937962124, 67.10618836539132, 57.99617937632969, 0.28614904678293634, 23.344957147325786, 76.74347877502441, 51.462600639888215, 23.79042179243905, 38.27427353177752, 33.03661026273455, 36.06094571522304, 43.757486139025005, 40.40054389408657, 46.641106673649375, 70.96235520499093, 32.59790447780064, 0.3647346927651337, 0.25409915085349766, 0.12879171408712864, 0.19483006692358426, 0.0969625184578555, 0.17777776265782969, 0.11505769033517156, 0.2171264426516635], [0.08945106794791562, 0.13144422961132868, 0.06509397458285093, 0.05589886834578855, 0.009506580952022756, 0.15871003296758446, 0.2869432855929647, 0.12351496437830584, 0.014451023224475128, 0.10156572716576712, 0.2977586181036064, 38.06644943782261, 52.41315589632307, 48.25832421439034, 28.680822781154088, 32.59346457890102, 27.96182492801121, 15.969133411134992, 18.12211091177804, 43.12044749941145, 54.02003799165998, 58.839798382350374, 14.657151971544538, 4.232588538101741, 76.71813869476318, 58.17580073220389, 67.24503421783447, 55.46146610804966, 55.08164978027344, 50.54087693350655, 59.945263726370676, 54.3056297983442, 56.74085875919887, 50.915624550410676, 57.40828881944929, 51.567681721278596, 55.88535138538906, 54.31444011415754, 54.14931270054409, 52.009774753025596, 54.304306166512625, 50.64996017728533, 53.65310362407139, 45.72919382367815, 43.69141224452427, 40.73735087258475, 44.397366591862266, 47.17732695170811, 52.322811944144114, 51.72552742276873, 52.65218087605068, 49.00534241540091, 45.341296740940635, 43.87751974378313, 49.29277549471174, 45.98228543145316, 43.710776873997276, 47.05187027794974, 47.070922238486155, 47.31236171722412, 46.742439201899934, 44.185637610299246, 45.52799483707973, 43.822924273354666, 46.15707084110805, 44.56337642669678, 47.68645620346069, 46.83094188145229, 47.18637350627354, 46.836201667785645, 45.983803612845286, 46.725787843976704, 47.88665117536272, 46.852870396205354, 44.97376135417393, 44.08628879274641, 43.1229419027056, 33.950138568878174, 30.334268229348318, 33.99162973676409, 39.65361254555838, 40.37605496815273, 43.28044366836548, 36.5953038760594, 33.672165461948936, 35.37872641427176, 34.360495703560964, 35.80411945070539, 32.997908796582905, 34.49943535668509, 41.17414590290615, 41.12705448695591, 40.34509726933071, 34.94039583206177, 39.69943938936506, 36.636583123888286, 39.92080552237374, 40.40262140546526, 37.69959497451782, 44.868006297520225, 44.68339613505772, 47.15794495173863, 48.467510155269075, 50.862432616097585, 51.0196772984096, 54.05516113553728, 50.85130855015346, 47.43088756288801, 52.0908637046814, 49.66154071262905, 48.07827207020351, 46.874805859157014, 46.89602565765381, 45.47204794202532, 48.138533796582905, 46.112619740622385, 45.136026109967915, 42.291951247623985, 45.534599099840435, 45.07091801507132, 45.77774436133248, 44.72771174567086, 41.625841345105854, 44.736859049115864, 45.71864645821707, 42.85549184254238, 43.939528942108154, 48.43680259159633, 51.8213152885437, 49.61906290054321, 51.26653984614781, 48.59845590591431, 43.58345808301653, 41.17499705723354, 40.824727943965364, 40.89996303830828, 45.51625238146101, 51.61410958426339, 52.001346588134766, 55.56734275817871, 57.300226960863384, 59.074675287519185, 55.20212459564209, 54.6571113722665, 57.85851124354771, 57.833226748875205, 58.73407459259033, 58.66549587249756, 54.65405069078718, 52.167009013039724, 56.8662667955671, 64.99967520577567, 59.47210529872349, 71.43119880131313, 18.704024280820573, 0.07510084618947335, 44.08632353373936, 55.540727683476035, 31.826373032161168, 10.669948186193194, 32.484707900456016, 37.09009552001953, 27.63346869604928, 38.80488313947405, 32.893383571079795, 37.07372209003994, 50.256386416299, 39.26138326099941, 0.3574801763253552, 0.05364963332457202, 0.03484161291271448, 0.011487839593818145, 0.03831500992445009, 0.11695936614913599, 0.04301654174923897, 0.07156932926071541, 0.015094586548262408, 0.06418065287704978, 0.004896801056539906, 0.0741427411724414, 0.03267039924061724, 0.15114284759121283, 0.15167762818081038, 0.16695871177528585, 0.030693300866654942, 0.2331556518163, 0.26195582641022547, 50.01892825535366, 63.17021451677595, 55.214641775403706, 28.665198019572667, 37.00873211451939, 39.96215772628784, 28.127443926674978, 24.574010099683488, 50.12665660040719, 58.79125826699393, 62.08165413992745, 20.860496725354874, 2.872363801513399, 71.89041219438825, 62.28372165134975, 70.10300895145961, 56.11821331296648, 56.7245443889073, 55.07377399717058, 61.74693856920515, 56.81533997399466, 58.54281847817557, 54.88738162176949, 57.992194584437776, 54.144893646240234, 57.49999114445278, 56.75041600636074, 55.79535831723894, 53.47788047790527, 56.08242661612374, 52.63613748550415, 56.49839442116873, 46.530154364449636, 45.43215485981533, 42.95547294616699, 45.69061047690255, 48.25241824558803, 54.89424296787807, 53.248478753226145, 55.69077403204781, 50.624488081250874, 46.76307882581438, 43.66066299165998, 50.90850959505354, 48.03897305897304, 47.186661856515066, 48.93924420220511, 52.33446059908186, 52.51557234355381, 49.71765783854893, 48.606119768960134, 48.73213577270508, 48.83161660603115, 47.29810748781477, 48.75053807667324, 49.668096337999614, 48.13631732123238, 48.74191883632115, 47.538331031799316, 49.993841784340994, 49.59831557955061, 48.512256554194856, 48.49179410934448, 48.32297025408064, 43.479787485940115, 46.465119225638254, 34.640483788081575, 30.56838083267212, 34.82849856785366, 39.333272797720774, 39.75250973020281, 42.15383843013218, 35.65403488704136, 31.642798151288712, 33.742432594299316, 33.31138025011335, 35.86409282684326, 32.146459170750205, 34.842481817517964, 40.30641317367554, 40.53527293886457, 39.41666855130877, 35.2266720363072, 39.8120106288365, 38.6658844266619, 39.467081206185476, 38.589419501168386, 37.52100542613438, 45.67938218797956, 46.819539887564524, 47.85390778950283, 47.778099468776155, 51.10370881216866, 50.4941086087908, 54.885335377284456, 53.55098247528076, 50.29583133969988, 52.91351304735456, 51.07651356288365, 50.70404495511736, 50.9248309135437, 51.693197454724995, 47.795094762529644, 50.933880942208425, 51.34574236188616, 48.8467150415693, 47.2383599281311, 47.973083291734966, 48.050180503300254, 48.056843825748985, 46.958090441567556, 45.35031202861241, 49.641404833112446, 49.89819288253784, 46.21873957770211, 48.277956349509104, 51.69856146403721, 53.24659579140799, 56.27164690835135, 54.8421106338501, 52.61786024911063, 46.9115583556039, 44.866533279418945, 43.97908156258719, 43.42871822629656, 46.69814443588257, 54.83833776201521, 53.96877418245588, 57.99945892606463, 56.869626249585835, 61.89639432089669, 55.72243697302682, 56.25367191859654, 59.987821442740305, 60.727394648960654, 60.708016123090474, 59.467804363795686, 55.8968437058585, 53.84157351085118, 59.447744914463584, 68.92395523616246, 61.14286913190569, 72.95551545279366, 15.336697953087942, 0.0673982116526791, 52.39393023082188, 56.63057695116316, 34.4345635005406, 13.413988096373421, 28.339570692607335, 31.82963173730033, 38.775603430611746, 45.22750956671578, 36.271913869040354, 47.11919484819685, 56.27479791641235, 56.29560429709298, 2.55399951338768, 0.13812086491712502, 0.017878113613863076, 0.05255479671593223, 0.034037844078349214, 0.0910348908177444, 0.037405216600745916, 0.03434562077745795, 0.11381867860576936, 0.19160250654178007, 0.07378999795764685, 0.24557780953390257, 0.14050210214086942, 0.29069208300539423, 0.27246896656496183, 0.24344036994235857, 0.1255040762147733, 0.24871801531740598, 0.3458498146917139, 58.907869883946006, 69.8349335534232, 63.48120893750872, 40.656400884900776, 46.859825542994905, 40.30910907472883, 22.29290607997349, 31.578398772648402, 59.863684926714214, 62.60222012656075, 71.5007016318185, 17.717176846095494, 4.7784329397337775, 83.33410222189767, 60.21303340366909, 71.59383528573173, 57.51473522186279, 59.87401689801897, 55.401381560734336, 65.10720552716936, 59.95850699288504, 63.52928352355957, 57.38258048466274, 62.17906093597412, 55.382208006722585, 60.44985580444336, 59.66671739305769, 58.03354331425258, 55.0955878666469, 56.69077614375523, 55.655491079602925, 61.26518521990095, 50.03676080703735, 47.188186986105784, 43.68128524507795, 46.426125935145784, 48.05324813297817, 55.590094634464805, 54.5104592187064, 57.462050506046836, 51.987325123378206, 47.793142318725586, 45.02183246612549, 53.16676098959786, 51.07955687386649, 49.76261963163103, 52.643995898110525, 53.86220966066633, 56.67207506724766, 53.00558015278408, 50.976053033556255, 53.44193049839565, 51.834808690207346, 53.03618001937866, 50.3849002974374, 53.11926310403006, 51.144324507032124, 52.41022375651768, 51.323132923671174, 53.918371949877056, 51.25600290298462, 51.56278671537127, 52.34454243523734, 48.84087855475289, 45.103918484279085, 44.94621522086007, 35.20600461959839, 31.88853509085519, 35.776361397334504, 41.21067605699812, 40.04521301814488, 44.120793546949116, 35.61001804896763, 33.20648329598563, 35.67434447152274, 34.24001393999372, 36.78066444396973, 33.700489793504985, 35.345013754708425, 42.65263571058001, 41.25327546255929, 38.78238487243652, 36.40065704073225, 41.69956520625523, 38.6066267149789, 42.51478345053536, 40.96540812083653, 38.109319823128835, 46.27103866849627, 48.71604374476841, 50.981455257960725, 49.74272346496582, 52.93491349901472, 54.755636828286306, 56.712621280125205, 56.013000215802876, 51.62191588538033, 56.19094705581665, 53.86928640093122, 54.47367198126656, 51.71813106536865, 54.44893986838204, 51.819929122924805, 55.74944462094988, 55.6151567867824, 53.456573826926096, 50.33875036239624, 53.12191036769322, 51.15512548174177, 51.15438897269112, 50.529346397944856, 46.26691491263253, 51.84732239586966, 51.45188651766096, 49.42019850867135, 49.4018691607884, 54.254775932856965, 55.69754157747541, 57.802348954336985, 56.68839985983712, 52.965530736105784, 52.09836775915963, 46.62614025388445, 46.68748242514474, 46.71269743783133, 49.84504958561489, 57.339261940547395, 58.129115785871235, 60.03319317953927, 58.895898137773784, 65.22727734701974, 56.799859387534006, 58.96263558523995, 62.39919376373291, 61.19645363943917, 63.53460584368025, 61.72031307220459, 59.74669115883963, 55.47621018545968, 61.149636677333284, 69.11151490892682, 64.03157574789864, 74.72587476457868, 24.107933623450144, 0.11847247209932123, 53.635621956416536, 62.77574443817139, 43.38882861818586, 18.426883220672607, 42.20892027446202, 46.48227432795933, 38.74140092304775, 51.50401537758963, 46.442214488983154, 48.058448859623496, 60.9789194379534, 65.45493507385254, 2.566510396344321, 0.2692343087068626, 0.14184963197580405, 0.09194623798664127, 0.18145562601940973, 0.1530295413519655, 0.10839650527174984, 0.20649065050695622], [0.07338601177824394, 0.1468883380293846, 0.1181915043187993, 0.2345595679112843, 0.1054829912526267, 0.02493918820151261, 0.043147675426942964, 0.031140112783759832, 0.04084778098123414, 0.27834453699844225, 0.14023151594613278, 45.124978474208284, 52.989866801670615, 45.91612468447004, 28.720137425831386, 37.43633467810494, 28.643495321273804, 16.118081944329397, 18.321366139820643, 33.42988177708217, 67.10246413094657, 45.80154194150652, 61.40100860595703, 0.9069844058581761, 28.736007111413137, 75.87040288107735, 60.660990715026855, 62.93979140690395, 54.27507162094116, 53.98387609209333, 54.73056077957153, 54.4061632837568, 54.877873011997764, 52.3820036479405, 53.211476121629985, 53.40772104263306, 55.21444722584316, 53.14930016653878, 51.00148344039917, 54.598315715789795, 51.14265693937029, 54.61901787349156, 51.572354384831016, 44.01782471793038, 42.30571215493338, 39.86312852587019, 45.143408570970806, 49.94890430995396, 53.293687207358225, 48.06120034626552, 53.31135647637503, 50.7661132131304, 44.706009047372, 44.21556350163051, 46.21253831045968, 47.068615436553955, 44.126418113708496, 43.27246366228376, 48.47808183942522, 48.35006128038679, 47.93142189298357, 46.20055266789028, 44.89489582606724, 46.82565777642386, 45.588829789842876, 45.34533364432198, 45.72378465107509, 45.45474692753383, 47.48568800517491, 45.94724219185965, 47.49660015106201, 47.03054625647408, 45.8103974206107, 46.1883863721575, 45.43534755706787, 45.1630893434797, 31.600483621869767, 29.01336703981672, 36.67412076677595, 39.36835772650582, 38.17028331756592, 36.59721115657261, 42.339966773986816, 36.45731612614223, 35.23395027433123, 34.38673904963902, 33.497859477996826, 33.5291611126491, 31.947049345288956, 37.27276366097586, 41.33098758969988, 42.17627763748169, 39.91800192424229, 36.690400396074565, 38.58205441066197, 41.596922942570274, 36.40976960318429, 39.309152126312256, 34.81165266036987, 37.865125383649556, 42.11314977918352, 47.7850615637643, 46.78580290930611, 49.02781983784267, 49.40411690303257, 49.96287018912179, 48.95872695105416, 47.92409154347011, 47.22315379551479, 48.97781017848423, 48.490362780434744, 47.47826732907976, 48.37691954204014, 44.63479001181466, 45.65746062142508, 43.74658441543579, 42.64268936429705, 44.155030795506065, 43.708042757851736, 43.966696398598806, 44.94103533881051, 42.53703505652291, 44.107036113739014, 47.10632331030709, 43.040421622140066, 42.621910776410786, 45.345927715301514, 47.84365572248186, 52.900804792131694, 51.78775896344866, 52.323670046670095, 54.01254783357893, 46.678255217415945, 43.211854525974815, 40.88745628084455, 41.36315080097744, 41.70442547116961, 45.9360625403268, 50.48417615890503, 54.57513999938965, 55.53488424846104, 57.005088329315186, 59.11889362335205, 51.833023003169465, 58.11050156184605, 63.12623241969517, 58.2101526260376, 58.2545759337289, 55.19467960085188, 55.41894313267299, 56.77451235907418, 62.219548089163645, 60.41371822357178, 63.126920291355674, 2.5624852180480957, 1.4901227205991745, 55.07256848471505, 53.50387021473476, 29.498723030090332, 9.257745061601911, 72.87466621398926, 105.91582407270158, 35.65186357498169, 30.17134686878749, 36.845678738185335, 59.211318561008994, 42.99574817929949, 53.15850305557251, 13.874072619846888, 0.17711178053702625, 0.0747472412352051, 0.15175088282142365, 0.2034541248743023, 0.0631057448419077, 0.10976682031261069, 0.04349517695871847, 0.07837861816265754, 0.1189726609736681, 0.13191568931298597, 0.19205032608338765, 0.04595017093898995, 0.05897997372916766, 0.007519950857385993, 0.0950824607695852, 0.03989436464118106, 0.13860841946942465, 0.4467236804110663, 55.31326450620379, 59.59631129673549, 49.686550753457205, 26.775326217923844, 41.932670320783345, 36.466209820338655, 21.712573426110403, 23.180088554109844, 39.42031288146973, 72.74572849273682, 49.60981484821865, 66.75852830069405, 2.1543779969215393, 24.76360559463501, 80.26826517922538, 60.19646889822823, 64.56926209586007, 55.513605390276226, 57.980445180620464, 55.78912925720215, 56.35227033070156, 54.18953234808785, 55.25025476728167, 53.38205092293875, 55.40273298536028, 55.09150579997471, 55.89378649847848, 51.10717248916626, 54.80437496730259, 54.76011841637747, 56.95948035376412, 53.029693875994, 47.06342165810721, 42.087820121220176, 41.8898138318743, 47.12646613802229, 51.793519020080566, 54.24934591565813, 53.53856257029942, 55.43208565030779, 50.618554319654194, 46.31326287133353, 45.73120880126953, 46.16262592588152, 51.33230801991054, 45.15482446125576, 45.80566569737026, 52.40865346363613, 48.99239444732666, 51.205173356192454, 49.719009263174875, 49.42395053591047, 50.533761978149414, 48.98189224515642, 48.89388983590262, 47.10329042162214, 48.469879490988596, 50.631140981401714, 50.13108260290963, 51.123066493443076, 49.58894593375069, 48.01314313071114, 47.92097875050136, 48.686305454799104, 47.979173387799946, 35.5298045703343, 31.661926542009624, 37.724003996167866, 38.76952723094395, 36.157907826559885, 36.963099820273264, 38.14589861461094, 36.580132484436035, 35.09240157263619, 32.71884829657418, 31.160200595855713, 32.64537457057408, 31.749362673078263, 37.1243188721793, 40.17677021026611, 40.41761909212385, 39.190042631966726, 35.515359265463694, 39.360679967062815, 39.59556382043021, 39.11992835998535, 40.147445338112966, 37.25003262928554, 36.47956773212978, 40.73910876682827, 49.777398450034006, 48.01688820975167, 49.49535369873047, 50.53972700663975, 51.71249260221209, 49.71298170089722, 50.199491092136924, 48.66114602770124, 50.97706052235195, 50.89665249415806, 50.43588270459856, 49.94513143811907, 47.46081345421927, 46.99837957109724, 47.900193214416504, 47.90716225760323, 48.690457003457205, 46.601661750248496, 48.19135400227138, 48.4998505456107, 44.58752836499895, 51.20279359817505, 50.59890481403896, 47.45529311043875, 44.83786848613194, 49.35689694540841, 52.53926222664969, 56.90235226494925, 54.12151295798165, 56.431556224823, 55.51207678658621, 49.15517684391567, 45.338948249816895, 42.88013015474592, 43.924684115818565, 43.1322455406189, 45.29961797169277, 51.47260257175991, 56.77537393569946, 56.95154551097325, 59.193079539707725, 60.87197276524135, 52.89697633470808, 56.51293352672032, 66.4604297365461, 61.56079632895333, 63.40172849382673, 57.948136057172505, 58.03594739096505, 60.80984892163958, 63.57616301945278, 63.94819736480713, 61.581647872924805, 1.3888783476182391, 2.701476331268038, 62.58988012586321, 56.18633345195225, 33.57594680786133, 10.401287402425494, 60.52678625924246, 100.00169808523995, 42.44837604250227, 34.087900502341135, 38.40742186137608, 61.982545035226, 52.736462524959016, 62.05608476911272, 27.29668951034546, 0.16435016532029423, 0.1597661998655115, 0.031386943467493565, 0.2276391756853887, 0.057938191773636, 0.04339492680238826, 0.035240465974701304, 0.1464693019432681, 0.22104666515120439, 0.20968200426016534, 0.3434797190129757, 0.14136913418769836, 0.2119458820670843, 0.1270470241350787, 0.1526228953152895, 0.1471723863588912, 0.27310535098825184, 0.6308806357639176, 66.52504103524345, 66.56671633039201, 61.77663516998291, 39.810551507132395, 51.48183672768729, 39.337851660592214, 21.686239753450664, 29.42389440536499, 47.62973458426339, 76.4480344227382, 54.88852112633841, 69.91438620431083, 1.7537499687501361, 35.096539224897114, 78.82086508614677, 62.800952502659385, 64.69865839821952, 56.094283717019216, 59.01307255881173, 58.491888182503835, 58.73211520058768, 57.13082987921578, 57.50568866729736, 57.909434591020855, 56.88550983156477, 57.759419509342735, 56.3515442439488, 53.22546284539359, 55.44694437299456, 55.81856877463204, 57.803214005061555, 55.95321444102696, 49.68652990886143, 44.83944920131138, 43.57217768260411, 50.415990012032644, 54.661238602229524, 56.71075916290283, 55.07554578781128, 57.73709842136928, 53.4328214100429, 47.608455726078574, 45.339076791490825, 48.43429429190499, 50.7496668270656, 46.88498844419207, 47.21586513519287, 53.79595511300223, 51.66650594983782, 54.75363227299282, 54.320068155016216, 52.308321475982666, 54.816930362156455, 52.284020151410786, 53.752442019326345, 50.638843059539795, 50.22296210697719, 55.866723264966694, 55.32532657895769, 58.44131919315883, 54.563480922154014, 50.28573213304792, 50.268990448543, 50.69522074290684, 47.67202132088797, 37.15500559125628, 35.67187786102295, 38.77188267026629, 39.99824319566999, 37.89428697313581, 37.447194712502615, 39.62186622619629, 38.52443299974714, 37.208471979413716, 33.52735110691616, 34.230745043073384, 35.557670320783345, 32.24809047154018, 39.21486507143293, 40.84388065338135, 43.23111145836966, 40.327077116285054, 38.43146957669939, 40.99556677682059, 42.36181191035679, 39.91892603465489, 41.74266835621425, 36.87603194372994, 36.64669622693743, 41.487395014081685, 49.826609066554475, 50.209739685058594, 50.221058300563264, 52.51298761367798, 54.328291348048616, 53.47790132250105, 52.97460855756487, 50.376750060490195, 53.832860469818115, 52.57497249330793, 51.91734286717006, 55.47254153660366, 51.29521853583199, 51.15305839266096, 50.06906645638602, 51.04086235591343, 51.81681285585676, 49.5483615057809, 50.89366824286324, 50.86684819630214, 48.438765457698274, 53.526083605630056, 53.763065814971924, 49.9252804347447, 47.589619159698486, 53.3277542250497, 56.37049198150635, 59.48067242758614, 58.050104345594136, 59.12302780151367, 60.20881584712437, 52.69470385142735, 49.25834717069353, 44.31774023600987, 48.90347140175955, 48.42895112718855, 49.91573360988072, 53.836341517312185, 59.144692284720286, 60.49508162907192, 63.8404655456543, 62.14380577632359, 52.794660636356895, 59.93785694667271, 70.92237527029855, 61.68490505218506, 66.61067758287702, 59.44047015053885, 61.988360677446636, 62.520175797598704, 67.32407692500523, 63.84850461142403, 70.92088835580009, 3.95355452810015, 2.0612951517105103, 66.62872900281633, 63.22879477909633, 44.53682041168213, 15.782911266599383, 86.82972008841378, 114.19467217581612, 46.996309007917134, 39.05216257912772, 50.39704922267369, 69.39136750357491, 57.490812574114116, 75.28031321934291, 27.76894293512617, 0.4105885151241507, 0.3111386229949338, 0.2286112585238048, 0.424560256834541, 0.19277922197112016, 0.3269031085073948, 0.12596488291663782], [0.24666666824902805, 0.05124696457226362, 0.014145260926203003, 0.08968700135924987, 0.03459613251366785, 0.038839639630168676, 0.09244050325027534, 0.08415024381663118, 0.12100473764751639, 0.09209907121424164, 3.539957795824323, 62.10688304901123, 53.66399839946202, 49.58090339388166, 33.75173970631191, 40.54679305212838, 29.22892447880336, 28.289196252822876, 14.88847313608442, 23.142342465264456, 63.00957216535296, 48.872183663504465, 64.53800909859794, 19.947929007666453, 3.6943267924445014, 69.26647363390241, 62.53485039302281, 64.4302008492606, 58.28247989927019, 58.01587404523577, 54.668624537331716, 54.665681975228445, 52.933923380715505, 54.37382289341518, 54.78532648086548, 55.40972982134138, 52.71325554166521, 48.53730133601597, 53.39954648699079, 54.61527974264962, 51.306610107421875, 51.99337700435093, 44.286438601357595, 42.461879866463796, 41.69596951348441, 43.18413468769619, 49.22817114421299, 52.52673462459019, 56.58912399836949, 46.43957417351859, 51.21992438180106, 50.74669994626726, 47.828136920928955, 43.43585055215018, 45.3168043409075, 47.27551542009626, 48.852304867335725, 46.965010847364155, 47.02055127280099, 48.013059752328054, 46.98873199735369, 45.35596438816616, 46.87891571862357, 48.17906958716256, 45.90129722867693, 45.27963147844587, 45.75677817208426, 44.93118626730782, 47.013606548309326, 45.37267133167812, 46.6513865334647, 44.42279005050659, 46.667211055755615, 47.73636163984026, 48.032535552978516, 43.82208701542446, 46.27988372530256, 47.22539458956037, 33.36535038266863, 37.27663033349173, 39.513634136744905, 38.49776233945574, 42.41295412608555, 37.904851709093364, 35.84806680679321, 33.99435690471104, 35.95563186917986, 34.7998685155596, 35.95782402583531, 39.50063753128052, 43.038646357400076, 41.09534638268607, 41.30039814540318, 36.24794953210013, 36.28670310974121, 42.59185634340559, 35.936211654118125, 37.12728575297764, 35.80544308253697, 34.528510093688965, 31.475982325417654, 31.074154104505265, 42.737056323460166, 42.50789083753313, 49.90099300657, 50.486736570085796, 48.931024483272004, 47.862196990421836, 48.52526010785784, 49.83961609431675, 47.00346565246582, 44.89238057817732, 44.633956227983745, 46.277003696986604, 44.992003849574495, 45.55653803689139, 47.80577414376395, 45.35769101551601, 45.31905208315168, 47.36351088115147, 45.0817745753697, 44.69507258278983, 44.99608244214739, 45.865687710898264, 44.35932520457676, 42.552842208317344, 44.55761637006487, 51.082985809871126, 53.403892585209434, 48.87038060597011, 51.98650871004377, 53.80962221963065, 46.96900258745466, 45.23228645324707, 40.27568823950631, 40.94736017499651, 41.32360512869698, 42.93380846296038, 44.288446630750386, 53.42469549179077, 55.33269166946411, 56.26262814658028, 59.30734266553606, 58.844405038016184, 53.06931250435965, 60.11423001970564, 57.14209290913173, 60.111902373177664, 54.880603654044016, 55.791835580553325, 58.07530198778425, 61.9134521484375, 68.50569452558244, 39.2990459714617, 0.32489877034510883, 11.317130327224731, 57.52087048121861, 50.69802434103829, 21.756572893687657, 10.161113364355904, 35.21810838154384, 39.705581596919465, 30.329668521881104, 33.58848483221871, 31.671247550419398, 59.30068629128592, 61.20156751360212, 49.29466193062918, 37.674275738852366, 0.6099373538579259, 0.10063468212527887, 0.01940077164077333, 0.2617015657680375, 0.04667394049465656, 0.07726095563599042, 0.1438148593796151, 0.2214356828480959, 0.007771946040780416, 0.04451250111950295, 0.07113886664488486, 0.04956446235467281, 0.04190320149064064, 0.07561113166489772, 0.027538732193144302, 0.13781199577663625, 0.011076063832401164, 4.848394351346152, 75.15915748051235, 57.80411727087838, 59.62900257110596, 36.19339575086321, 42.54103374481201, 40.03428002766201, 27.173400674547466, 21.491139548165457, 23.901801415852137, 69.4127471106393, 50.96207325799124, 69.61908081599644, 26.485621077673777, 1.6786542726414544, 61.35475444793701, 66.10832282475063, 63.393293380737305, 60.72624124799456, 58.946216991969514, 58.39761502402169, 56.22675459725516, 55.40916701725551, 55.10297727584839, 56.15823841094971, 55.29954181398664, 55.76059995378767, 50.315977641514365, 56.17685610907418, 56.14462341581072, 52.77336093357631, 50.905042443956646, 45.436626025608604, 42.974392890930176, 44.71723733629499, 44.83871269226074, 49.57115854535784, 54.875955309186665, 56.53484467097691, 47.82987397057669, 53.34493712016514, 53.33183281762259, 48.832815170288086, 44.22663198198591, 46.84251410620553, 49.85946362359183, 51.36971712112427, 47.44039617265974, 47.37121990748814, 51.588811193193706, 50.75037554332188, 51.05530766078404, 50.023270879473, 48.182095527648926, 49.313891070229666, 49.03488962990897, 49.77149942943028, 48.96822166442871, 49.23000546864101, 49.3161735534668, 51.9203861781529, 48.84701381410871, 50.28627756663731, 50.12323113850185, 51.156938961574006, 47.89787251608712, 46.89448663166591, 40.95407560893467, 30.256948675428117, 39.33601038796561, 39.34875338418143, 37.9394884790693, 41.83812618255615, 36.035907881600515, 32.29998656681606, 32.364879267556326, 33.79115683691842, 32.94117328098842, 34.14757163184029, 39.02509239741734, 41.72086838313511, 43.36176538467407, 39.80966213771275, 36.57966695513044, 36.74959904806954, 44.453570570264546, 37.051741463797434, 39.32735988071987, 33.94540337153843, 34.98943621771676, 35.68432208469936, 30.83228383745466, 41.99604136603219, 44.79707561220442, 51.73405981063843, 51.26013708114624, 51.33698763166155, 50.72715466363089, 50.26748963764736, 50.68986020769392, 50.27897500991821, 48.84916428157261, 46.59853853498186, 47.90230199268886, 50.080246107918875, 50.145211764744346, 51.12162821633475, 49.17261682237898, 48.16277953556606, 50.04112080165318, 48.40164123262678, 48.49415302276611, 51.749370166233604, 51.13361733300345, 49.047931398664204, 46.804302488054546, 49.266691957201274, 54.52558544703892, 57.72174637658255, 52.18172877175467, 55.68662248338972, 57.767138957977295, 51.49680314745222, 49.13204281670706, 42.924442291259766, 41.67767490659441, 43.73082937513079, 43.36334957395281, 45.69022485188076, 53.41924115589687, 58.4677084514073, 56.20484345299857, 61.329546383449006, 61.70011465890067, 54.4804082598005, 60.26101071493966, 59.38890062059675, 60.438599722726, 57.503725801195415, 57.04063878740583, 61.69707134791783, 64.99314389910016, 70.47590487343925, 32.94832297733852, 0.2487111214016165, 18.277609859194072, 64.33386407579694, 55.09968730381557, 26.808326687131608, 9.28430541924068, 31.74807378223964, 41.93951429639544, 42.43130431856428, 43.72269998277937, 30.72688661302839, 51.44966656821114, 70.74193055289132, 59.32533155168806, 53.46619013377598, 0.9385373698813575, 0.11438112306807723, 0.036477750832481046, 0.21626352252704756, 0.01898855822426932, 0.12539998894291265, 0.11334296448954514, 0.28987955089126316, 0.13738953987402575, 0.09565485934061663, 0.11028142805610384, 0.11730472690292768, 0.21241324341722898, 0.17116704024374485, 0.06772783039403812, 0.29639503413013046, 0.18405311235359736, 4.814878412655421, 83.83048152923584, 69.2421201978411, 66.14932414463588, 47.20252806799752, 52.72201027188982, 45.01169504438128, 34.00011696134295, 25.14267325401306, 36.55357299532209, 74.31941209520612, 55.629310267312185, 77.30903434753418, 23.816368103027344, 4.624284982681274, 77.48360783713204, 61.00661495753697, 70.94813919067383, 60.60478673662458, 65.03218582698277, 57.710062980651855, 58.69734641483852, 56.285088198525564, 58.09750843048096, 56.93499142783028, 59.592357771737234, 57.07158953802926, 52.11003031049456, 56.096899713788716, 59.43518951960972, 54.073890004839214, 55.26175056185041, 47.91300221851894, 45.62795509610857, 45.095299243927, 45.6274721963065, 51.85443040302822, 58.492332867213655, 58.95290810721261, 50.11759614944458, 54.00947672980172, 54.1884970664978, 48.937191009521484, 46.44177327837263, 49.66406985691616, 52.79113095147269, 53.20186676297869, 50.1247284752982, 52.8154114314488, 54.42841141564505, 52.950619901929585, 52.01865107672555, 55.491569178445, 54.45612777982439, 53.92213092531477, 53.013664381844656, 52.51130962371826, 53.69874286651611, 52.51500259126936, 54.37793275288173, 57.850590297154014, 52.630662305014475, 53.39726747785296, 52.896826948438374, 55.190660067967, 52.60288340704781, 47.16100215911865, 37.85120466777256, 29.909448419298442, 41.826901367732454, 41.13093505586897, 39.98489570617676, 44.29458883830479, 37.38765907287598, 34.989127022879465, 32.65537650244576, 36.218103545052664, 33.829236439296174, 36.744585922786165, 39.30765131541661, 43.92374610900879, 43.58574751445225, 40.79790789740426, 36.72662135532924, 38.78148855481829, 44.809102943965364, 39.24122306278774, 40.32020534787859, 35.117693015507285, 35.90084532329014, 37.63366004398891, 32.88597331728254, 44.06406150545393, 43.700444902692524, 53.48076050622122, 56.36471455437796, 56.27273430143084, 51.84351478304182, 52.78368248258318, 53.11819308144705, 53.09690727506365, 51.19502551215035, 49.66660247530256, 52.801257950919016, 52.53916495186942, 53.9340957232884, 55.7354405266898, 51.76824842180525, 51.84178120749337, 53.539399828229634, 52.10324192047119, 51.461058139801025, 53.115656988961355, 55.30493014199393, 51.40343672888619, 49.806087562016074, 52.070429052625386, 56.69461154937744, 60.39570154462542, 56.69789457321167, 58.33792304992676, 60.769062995910645, 54.288217612675254, 51.79394980839321, 47.22315032141549, 46.291292667388916, 43.74900238854544, 45.92166239874703, 49.06547212600708, 56.43365110669817, 61.049804959978374, 59.79747554234096, 64.50125312805176, 58.2229824747358, 53.439620222364155, 63.74476105826241, 59.94046252114432, 64.1644253049578, 60.275733947753906, 62.273646763392854, 63.631915364946636, 70.05150195530483, 71.52141421181815, 47.05107470921108, 0.3000897658722741, 15.530182702200753, 71.33457715170724, 59.091566358293804, 32.96917452130999, 17.086391585213796, 42.98504447937012, 47.58717686789376, 43.746612208230154, 44.89266892841884, 41.47898769378662, 63.90289510999407, 73.05962031228202, 66.81869275229317, 63.663515772138325, 1.1693831256457736, 0.13389827364257403, 0.0998821257214461, 0.21936255480561936, 0.17800779959985188, 0.1554729730955192, 0.1707424401704754], [0.14804277036871227, 0.16966841423085757, 0.09844178586666073, 0.19226056337356567, 0.1756687265421663, 0.17849566627826008, 0.0888667135898556, 0.06169294672352927, 0.14073445967265538, 0.08215899459485497, 4.5086999620710095, 68.34630284990583, 54.62015042986189, 42.16874579020909, 21.09294523511614, 40.03418622698103, 28.54522521155221, 39.10220003128052, 9.751826252256121, 13.204357470784869, 58.73021139417376, 56.905777726854595, 52.29317092895508, 63.16687938145229, 0.9595049704824175, 12.301305311066763, 80.91602488926479, 55.65211425508772, 64.67543057032994, 59.80315222058977, 63.57357134137835, 53.12832702909197, 57.403404235839844, 55.44065972736904, 58.089153221675325, 52.118687765938894, 52.64477409635271, 55.45604998724801, 57.76577363695417, 52.70876005717686, 48.84867443357195, 46.537116459437776, 46.011592933109824, 41.40530899592808, 39.127418518066406, 42.90980243682861, 49.26347841535296, 53.27926274708339, 53.88109139033726, 49.02751759120396, 53.03736816133772, 51.70751074382237, 47.438283920288086, 40.33942059108189, 43.41245596749442, 44.807595184871126, 47.43514680862427, 46.39632511138916, 46.11210904802595, 47.25568873541695, 45.59609413146973, 44.710619177137104, 42.82929713385445, 45.42435203279768, 48.198121547698975, 46.396835803985596, 44.98801210948399, 45.33161790030343, 45.87617949077061, 49.25029420852661, 50.55119153431484, 50.400040422167095, 47.729726110185894, 46.13259581157139, 42.28511422021048, 49.06848069599697, 80.65778814043317, 116.10940115792411, 107.49054295676095, 63.60685321262905, 40.31039101736886, 37.880439213344026, 36.0255446434021, 36.43787159238543, 34.601226466042654, 32.872083868299214, 35.92019605636597, 39.21123811176845, 43.453408649989534, 45.44015918459211, 43.79762240818569, 43.86445713043213, 43.170721190316335, 40.88488892146519, 39.91720635550362, 44.982599462781636, 42.078054428100586, 37.58915683201381, 39.546005793980186, 34.47157655443464, 51.22923844201224, 60.99334389822823, 67.77010958535331, 59.87967273167202, 48.25349521636963, 49.152651173727854, 52.54851027897426, 55.53815337589809, 53.816619055611746, 49.846196038382395, 45.505840505872456, 45.216340337480815, 47.04188224247524, 44.86093997955322, 45.82995659964425, 46.63647222518921, 46.32796178545271, 47.22250761304583, 48.135403633117676, 45.486871923719136, 50.27165160860334, 42.44971009663173, 41.29465198516846, 43.64686386925833, 45.10254621505737, 39.93538979121617, 44.61308036531721, 50.26557540893555, 52.776088101523264, 47.75357927594866, 48.96872888292585, 56.7638920375279, 53.72239800861904, 49.52089180265154, 43.445675304957796, 41.72175080435616, 46.20353691918509, 42.73095233099801, 41.30366032464163, 45.49810021264212, 56.055745533534456, 56.223537581307546, 59.970985957554404, 59.208789416721885, 61.12310150691441, 61.55592564174107, 57.964943749564036, 56.656830719539094, 56.742859840393066, 55.73539188929966, 63.63622324807303, 60.18859658922468, 71.37359823499406, 8.084360207830157, 0.2151880038103887, 28.513699497495377, 52.09158979143415, 55.50880765914917, 19.573414155415126, 10.301702346120562, 16.77307994025094, 9.082904066358294, 12.124630859919957, 45.50633730207171, 53.04854781287057, 33.69204078401838, 38.67800555910383, 51.2770003591265, 43.38768563951765, 0.5620553089039666, 0.4978424459695816, 0.13108461962214538, 0.27319282772285597, 0.10759421225105013, 0.28169120741742, 0.018495073275906698, 0.11890419679028646, 0.22684619895049504, 0.10058629579309906, 0.09779997316322156, 0.0812663614217724, 0.07325161434710026, 0.09108628306005682, 0.06849781157714979, 0.12066286456372056, 0.043442451395094395, 4.529686561652592, 78.46856362479073, 60.79460457393101, 49.750880650111604, 26.2512982913426, 43.53640488215855, 39.013659136635916, 35.99750518798828, 17.47804764338902, 18.870186976024083, 58.2837792124067, 61.78609166826521, 51.80898571014404, 69.80855124337333, 2.670194238424301, 6.024568906852177, 76.79374899183, 62.291149275643484, 67.10173457009452, 60.56144387381417, 62.42501326969692, 55.13679763248989, 59.42556626456124, 55.480059487479075, 59.85838345118931, 57.780104296548025, 56.860475472041536, 57.619079794202534, 60.08807005201067, 53.88132415499006, 55.312003408159526, 51.22371809823172, 46.712770393916536, 42.41835635049002, 40.225074086870464, 43.32078490938459, 49.050950390951975, 53.42942721503121, 57.72004059382847, 52.232144900730674, 54.231315340314595, 52.34014075142996, 49.3572165625436, 44.962335041591096, 46.755713735307964, 47.49063859667097, 49.9593300819397, 49.423387731824604, 51.75572081974575, 51.41631868907383, 52.444252559116904, 49.01374626159668, 47.483516693115234, 51.20132752827236, 50.32412093026297, 47.52178389685494, 48.72303363255092, 48.379622391292024, 47.88268722806658, 49.84600148882185, 54.732026849474224, 54.10739769254412, 51.04071296964373, 47.29755163192749, 48.8069817679269, 60.02529307774135, 82.9909862790789, 102.16756275721959, 79.38507270812988, 49.735010964529856, 38.33156837735857, 37.36544220788138, 33.467853682381765, 34.40300130844116, 33.47439193725586, 33.74147374289376, 35.19574907847813, 36.89241232190813, 40.88063314982823, 44.632344245910645, 42.18421248027256, 44.3232501574925, 42.54607118879046, 40.36812359946114, 36.656684262411936, 43.222902161734446, 41.76242903300694, 37.97251674107143, 44.59126649584089, 34.673703125544954, 37.04004764556885, 46.38183464322771, 63.850985118321006, 63.34723377227783, 50.233631065913606, 50.36248540878296, 51.27093458175659, 53.973835945129395, 54.57270812988281, 52.95597348894392, 51.27175446919033, 48.14054877417428, 49.090086119515554, 47.99129452024187, 47.734530789511545, 47.54112420763288, 47.838805879865376, 49.028267996651785, 52.9689735685076, 51.952448640550884, 53.67847844532558, 45.69119412558419, 47.42838273729597, 45.047940322331016, 48.32918889181954, 44.25582831246512, 47.63997622898647, 50.5436110496521, 53.373452527182444, 50.47868013381958, 51.778399739946636, 58.43662221091134, 54.80583756310599, 50.960728781563894, 46.349285806928364, 41.638428006853374, 46.69683470044817, 44.45986911228725, 45.680910791669575, 48.46241365160261, 59.814248493739534, 56.8156213760376, 65.62533269609723, 61.65683432987758, 63.778181893484934, 62.75240543910435, 59.107276235307964, 59.04518713269915, 62.52314962659563, 62.16306618281773, 65.39635481153215, 60.70477131434849, 70.01589243752616, 5.682437871183668, 0.21236205473542213, 38.95926863806588, 60.745112555367605, 60.031219891139436, 22.319661855697632, 9.873243417058672, 22.056387662887573, 17.38297196796962, 22.914500611168997, 55.76757941927229, 45.474549293518066, 34.78187962940761, 52.46415914808001, 56.24340942927769, 59.955484526497976, 4.147900853838239, 0.429814017776932, 0.08331397654754774, 0.2793701562498297, 0.2287254152553422, 0.06849783193320036, 0.053518526788268767, 0.13482743235571043, 0.15258567088416644, 0.14573714908744606, 0.2617940365203789, 0.31084449163505007, 0.1730676439723798, 0.16491660635386193, 0.22889418048518045, 0.16648699423032148, 0.1142390106937715, 5.667150097233908, 90.62552792685372, 67.93742915562221, 61.73458467211042, 33.30215651648385, 56.810618673052105, 37.85128457205636, 51.6064908845084, 17.634531497955322, 24.20942943436759, 64.96240506853376, 65.48340879167829, 57.2763911655971, 71.86097962515694, 1.6191305752311433, 14.111291936465673, 82.35590703146798, 61.237441062927246, 70.01098006112235, 61.761571475437705, 64.5793856212071, 56.43657977240426, 61.11336708068848, 56.9572708266122, 64.03095735822404, 59.99119131905692, 58.42953504834856, 58.883071763174875, 65.23343345097133, 59.37206513541085, 59.01833929334368, 53.596889223371235, 49.64681053161621, 45.99636248179844, 42.50197444643293, 44.91615036555699, 49.61039154870169, 54.711105823516846, 59.638938495091026, 53.19590520858765, 58.855723653520855, 55.47658886228289, 51.836083684648784, 46.738110474177766, 47.750452586582725, 50.29163810185024, 52.767986501966206, 52.326782839638845, 52.491674014500205, 55.92391388756888, 55.74975381578718, 52.39832149233137, 52.797346115112305, 54.42157786233084, 54.1423783983503, 52.369229384831016, 54.11826467514038, 51.90497159957886, 55.146156855991904, 55.865934644426616, 58.188019139426096, 56.11136238915579, 52.8877387046814, 52.90404265267508, 54.887951374053955, 63.69531767708914, 85.4316383089338, 97.33723763057164, 69.88892800467355, 45.3580036844526, 41.53204413822719, 37.02761731828962, 33.17179788861956, 37.66777917316982, 35.24893406459263, 35.21700014386858, 38.76376370021275, 37.729180404118125, 42.78800398962838, 48.308080264500205, 43.39366456440517, 44.07385499136788, 44.35267925262451, 40.77445772715977, 38.1181058202471, 44.98959629876273, 43.747574533735005, 41.43182679585048, 48.499916553497314, 36.663010597229004, 35.3592506136213, 39.69655588694981, 58.87390014103481, 63.96917397635323, 55.21904693331037, 54.463555404118125, 53.39593342372349, 56.41431427001953, 57.132712841033936, 55.26950127737862, 52.89133439745222, 52.963918754032676, 53.257077148982454, 52.13034336907523, 51.56113304410662, 50.95015014920916, 50.759185859135215, 53.48611061913626, 55.39004904883248, 50.172205516270225, 55.119788442339214, 46.673401900700156, 49.677521569388254, 47.60701050077166, 49.80894327163696, 45.43492719105312, 50.47659567424229, 52.64315169198172, 56.26502874919346, 53.928592750004356, 55.622501032693044, 60.65514728001186, 57.53722306660244, 55.98121568134853, 50.18023068564278, 47.70808594567435, 49.12326724188668, 46.44139460154942, 45.69594669342041, 51.675024441310335, 63.07642773219517, 59.64057132175991, 65.19346741267613, 63.18613978794643, 65.20518207550049, 62.89353724888393, 63.99895395551409, 64.07939325060163, 66.78682831355503, 65.22522068023682, 70.4256763458252, 62.31384209224156, 76.28270898546491, 12.777890069144112, 0.32866664816226276, 40.882234709603445, 67.40398815699986, 66.47078950064522, 30.701723711831228, 18.46841434070042, 24.468253305980138, 13.175291419029236, 17.045501436505997, 63.858308519635884, 71.36541325705392, 43.98964629854475, 55.241566044943674, 63.67177718026297, 71.90910979679653, 5.136467099189758, 0.6555154738681657, 0.2659261519355433, 0.5682115757039615, 0.3086727995957647, 0.393357552587986, 0.11675356647797994], [0.16452471166849136, 0.1853964895542179, 0.27660746020930155, 0.06919848719345671, 0.08968215661921672, 0.11600998709244387, 0.13913531548210553, 0.0385701390914619, 0.17335223512990133, 0.34147890923278673, 2.4161309685025896, 59.465094566345215, 49.36795500346592, 43.67815160751343, 25.27633922440665, 39.09233706338065, 38.89805153438023, 29.945478303091868, 23.00986463682992, 3.1213841991765157, 25.23560541016715, 60.3602796282087, 51.38832092285156, 47.38898645128523, 38.422311850956504, 0.28195648746831076, 27.18782687187195, 70.80185181753976, 67.10046304975236, 60.302366392953054, 62.15019811902727, 54.03302764892578, 56.31528506960188, 55.56946195874895, 53.17237860815865, 50.15081896100725, 56.01163836887905, 55.960655961717876, 54.71098075594221, 50.902454239981516, 48.607811655317036, 45.000980922154014, 46.092595032283235, 38.676216397966655, 43.25534677505493, 46.84616191046578, 51.1511024747576, 53.71346957342965, 55.88347537176949, 49.33149085726057, 49.54474496841431, 52.716250215257915, 44.72621093477522, 40.48698990685599, 43.38717842102051, 45.909926891326904, 44.67875821249825, 49.09615189688546, 52.20088842936924, 48.00822033200945, 50.19460998262678, 46.61499534334455, 46.35615757533482, 45.14953340802874, 47.6109744480678, 43.190513134002686, 44.64797074454171, 44.77717249734061, 49.79775667190552, 51.02956805910383, 51.77488742555891, 49.238155705588206, 49.05201346533639, 47.05570568357195, 53.624595165252686, 69.72957106998989, 76.9562326158796, 65.90970856802804, 63.46898705618722, 71.59188979012626, 44.95214898245675, 31.360930579049246, 34.163712297167095, 36.79191705158779, 36.33071994781494, 36.348945072719026, 37.26545068195888, 45.223663738795686, 53.6763071332659, 48.874952520642964, 47.87835850034441, 42.23341614859444, 45.74701942716326, 45.86253670283726, 47.68039737428938, 45.301893506731304, 42.38428585869925, 37.6342784336635, 38.2044997215271, 71.51749542781285, 112.90384973798479, 88.23065062931606, 66.27434308188302, 64.44689042227608, 56.746903691973, 52.66790464946202, 54.40504462378365, 54.429804529462544, 52.599534375326975, 48.159197739192415, 46.34213611057827, 45.42443541118077, 45.34556640897478, 45.086964879717144, 45.309870038713726, 46.08812734058925, 43.641044752938406, 42.02492502757481, 46.34492233821324, 48.34837634222848, 50.73420361110142, 44.07384456907, 42.963518960135325, 42.99229839869908, 42.706244536808555, 42.260507174900596, 46.899642195020405, 53.48802832194737, 54.19277368273054, 48.84563112258911, 50.78975098473685, 52.47250740868704, 53.66806656973702, 52.87763254983084, 45.854362147195, 43.02449287687029, 41.63447448185512, 39.68970843723842, 43.302486828395296, 44.61011348451887, 57.94302913120815, 58.78963238852364, 60.80488095964704, 52.47295904159546, 47.45799943378994, 54.03345496313912, 58.53297288077218, 64.53331211635044, 56.157310826437815, 58.17035681860787, 59.77672822134835, 64.57911464146206, 43.26829126902989, 0.3019406736961433, 3.8936332634517123, 46.45081983293806, 55.969667775290354, 49.98748765672956, 15.342317308698382, 5.1136305417333325, 23.495328324181692, 15.955056360789708, 21.57759598323277, 58.566087995256694, 70.88512597765241, 28.799741200038365, 49.612865107400076, 45.28524214880807, 45.730826650347026, 5.066221245697566, 0.23127350424017223, 0.1874909507376807, 0.08251768856176309, 0.24518607769693646, 0.1752822194248438, 0.14786994749946253, 0.0494409655886037, 0.04616984325860228, 0.31138531118631363, 0.07013198174536228, 0.10091216902115516, 0.153674203902483, 0.22948116755911283, 0.05569570478317993, 0.17407871543296746, 0.29542597755789757, 2.432667681149074, 67.77841963086809, 56.81573602131435, 52.59170375551496, 32.113865171160015, 49.20058332170759, 40.94302797317505, 26.926942859377178, 27.408902917589458, 7.527190242494855, 23.209359577723912, 60.20723860604422, 55.18824904305594, 51.41463375091553, 44.11414064679827, 0.1277684425669057, 18.092322247368948, 74.62699495043073, 71.79748698643276, 64.15992982046944, 62.30296121324812, 55.53669078009469, 55.31280245099749, 55.77046986988613, 54.89802278791155, 53.18736239842006, 60.905511719839915, 59.155607904706685, 57.82417672021048, 56.2284916469029, 53.832697187151226, 49.00397709437779, 47.94292116165161, 41.04331827163696, 46.13923828942435, 47.67228882653372, 49.13160508019583, 54.872001784188406, 56.19826698303223, 53.0353045463562, 51.35475417545864, 54.53733832495553, 49.368959018162315, 46.459220205034526, 48.48676013946533, 51.48832981927054, 49.7384364264352, 55.8232101712908, 57.94199732371739, 53.902113165174214, 55.45977769579206, 52.3515670640128, 52.55680990219116, 51.26041153499058, 51.13563231059483, 47.55243240083967, 51.1854578426906, 52.20490448815482, 53.098043305533274, 51.046215942927766, 52.67678792136056, 51.20089326586042, 51.74909223828997, 50.13275017057146, 60.98787566593715, 70.52006762368339, 71.14734404427665, 64.82628290993827, 63.130533354622976, 66.02500697544643, 41.6057436806815, 33.3684527533395, 35.905399867466514, 36.36121906552996, 33.804542541503906, 37.769226346697124, 36.34754501070295, 44.07613400050572, 52.64147022792271, 50.058387075151714, 47.125469071524485, 41.54186889103481, 43.82760041100638, 42.968354906354634, 42.09304516656058, 44.05013384137835, 41.93786757332938, 39.86602245058332, 33.62901714869908, 52.175072397504536, 95.90289320264543, 85.14142595018659, 63.80523817879813, 59.03404222215925, 58.92905494144985, 53.49434770856585, 56.43269920349121, 52.84174510410854, 52.32393407821655, 49.89402396338326, 51.593202454703196, 51.37666531971523, 48.793231282915386, 47.1482070514134, 46.62261404309954, 47.54075595310756, 47.27186066763741, 48.232351848057334, 52.58096531459263, 52.34125593730381, 54.6989985874721, 49.850938183920725, 44.44244997841971, 43.951893261500764, 42.90271527426583, 41.83276217324393, 47.49756595066616, 53.76365293775286, 56.3098064150129, 51.98784276417324, 49.9773120198931, 53.86798708779471, 56.35147476196289, 52.07898923328945, 48.63748393739973, 44.953674112047466, 44.90369571958269, 45.59833492551531, 44.99817384992327, 48.44529676437378, 61.75727054050991, 61.49451051439558, 64.21693284170968, 56.17452151434762, 50.62145866666521, 57.336166518075125, 63.244692257472444, 71.21989018576485, 64.05230222429547, 63.56762368338448, 64.89563288007463, 66.99063982282365, 39.14016151428223, 0.4792413040995598, 7.034706703254154, 52.34859323501587, 62.159307207380024, 56.93066964830671, 17.245420217514038, 10.84850299358368, 31.202230249132427, 18.98682985986982, 31.275165489741735, 79.08842631748745, 86.33004038674491, 32.1506141935076, 59.8171945299421, 52.149360588618684, 64.6480199268886, 12.483586958476476, 0.3851933106780052, 0.21418637755726064, 0.6351368416632924, 0.16675957531801291, 0.22493727638253144, 0.04890091617458633, 0.23952166736125946, 0.2115997749247721, 0.32383170617478235, 0.1255265221531902, 0.3410194596009595, 0.09518978465348482, 0.20785188674926758, 0.12118635433060782, 0.11356522542025362, 0.32715785769479616, 2.7467397195952277, 79.97052792140416, 66.08523396083287, 62.00313254765102, 39.71183497565133, 56.663733754839214, 51.006906509399414, 33.77798652648926, 35.47356585093907, 6.501097210815974, 32.811370509011404, 63.96460206168038, 61.80043969835554, 58.38666466304234, 42.03288418906075, 0.5924092744077954, 37.52505275181362, 74.54268550872803, 74.21710681915283, 66.44685990469796, 65.08822999681745, 56.75703763961792, 57.5390157018389, 57.920325892312185, 58.263101373400005, 56.20904016494751, 62.675884928022114, 63.75548907688686, 61.44196128845215, 56.57460226331438, 54.324157169886995, 51.655704975128174, 53.44436584200178, 42.77407285145351, 45.36198500224522, 49.693950584956575, 51.94260999134609, 58.14811910901751, 59.786011014665874, 53.358069215502056, 54.228793144226074, 56.36124045508248, 50.12766408920288, 49.335294995989116, 51.131890705653596, 58.29804733821324, 54.770703996930806, 60.11500126974923, 63.246415410723, 56.69759580067226, 59.118956157139365, 56.77163927895682, 54.35225568498884, 51.09355401992798, 54.99287264687674, 52.97509840556553, 54.64300305502755, 56.37304197038923, 58.55235835484096, 55.1396290234157, 56.850647245134624, 54.90878207342965, 56.03178814479283, 54.75926726205008, 53.33246857779366, 65.12831415448869, 73.8659587587629, 72.64007418496269, 70.96021515982491, 64.99319948468889, 36.28814138684954, 31.553201130458287, 35.51087767737252, 37.2484449659075, 35.062948158809114, 38.84068373271397, 36.740444796425955, 46.64607463564192, 56.57779148646763, 54.286522252219065, 51.67087984085083, 43.109948771340505, 43.218698501586914, 44.14064107622419, 44.33521148136684, 46.671508516584126, 45.07406554903303, 42.415650027138845, 35.9732038634164, 44.81167377744402, 82.36793436322893, 80.41961778913225, 63.14398506709507, 60.120830808367046, 58.82262243543352, 55.606176240103586, 59.140995843069895, 53.693865231105256, 54.5499701499939, 52.28030981336321, 54.829537868499756, 52.62262323924473, 52.65440429959978, 51.92535066604614, 51.50030156544277, 52.194131306239534, 51.06755038670131, 51.859933376312256, 55.24027715410505, 55.29704393659319, 57.49783372879028, 49.55146040235247, 44.44634096963065, 44.14206198283604, 45.05330433164324, 43.52117095674787, 52.13594709123884, 57.69876520974295, 59.7790002822876, 52.94356748035976, 52.894777229854036, 58.7144250869751, 58.93095874786377, 55.05418355124337, 54.821158340999055, 47.006675720214844, 48.26668984549386, 46.603197302137104, 49.3396133014134, 49.98021984100342, 66.25165721348354, 63.716655594961985, 68.12480817522321, 56.38561473573957, 53.85788093294416, 60.63599804469517, 68.88344029017857, 75.32999978746686, 70.26406124659947, 67.275363104684, 70.64365523202079, 66.0752980368478, 53.75186879294259, 1.3080495191471917, 5.359039613178798, 60.9784608568464, 69.23715223584855, 60.75959260123116, 29.81270170211792, 14.429006133760724, 31.96149812425886, 20.97746443748474, 31.672894273485454, 80.86223888397217, 92.88415105002267, 41.64740507943289, 62.23655033111572, 60.078759465898784, 75.12636893136161, 15.451975515910558, 0.9706190483910697, 0.3008238321968487, 1.0100565893309457, 0.2924599381429808, 0.4626926492367472, 0.09669454462294068], [0.062365510634013584, 0.09608748648315668, 0.04809632292017341, 0.04834767943248153, 0.09523144670362983, 0.10172447721873011, 0.13222474844327994, 0.06093701121530362, 0.42556866843785557, 0.19010774817849907, 1.6187309452465601, 46.24554920196533, 50.601944650922505, 36.63984530312674, 28.198385034288677, 38.74110909870693, 47.50371858051845, 25.26747853415353, 29.450009209769114, 26.51229521206447, 4.32304105588368, 23.287839480808803, 57.21804019383022, 43.173243386404856, 63.523731912885395, 9.314415437834603, 0.6437317090375083, 30.90836661202567, 59.14856243133545, 61.57720797402518, 52.803203446524485, 56.451073714665, 52.009493350982666, 50.610150473458425, 44.63169806344168, 55.70725168500628, 54.03941304343087, 53.54256820678711, 52.33076763153076, 51.906093733651296, 46.124032156808035, 44.93562616620745, 43.0191080229623, 45.09225593294416, 46.081404958452495, 46.73167644228254, 49.37365600040981, 51.91038772038051, 51.68890346799578, 52.71706315449306, 49.45388684953962, 52.525563853127615, 50.09224564688546, 45.28359195164272, 43.434777055467876, 46.86941753114973, 48.63587542942592, 50.1605464390346, 50.27385418755667, 51.907490321568076, 48.85487570081438, 46.91541460582188, 49.310632365090505, 48.537089415958945, 43.460485390254426, 45.933731419699534, 45.182151726314, 44.535409927368164, 46.60463557924543, 47.42405053547451, 45.854223183223176, 45.94819062096732, 45.76830870764596, 47.56345224380493, 49.70337234224592, 49.63953576769148, 31.032958235059464, 22.9854017666408, 24.670070682253154, 27.992120810917445, 42.36455644880022, 37.454233237675254, 36.85340860911778, 37.146737234933035, 37.59864807128906, 36.76568760190691, 39.381225790296284, 47.625256470271516, 41.8603777885437, 38.25311974116734, 48.45253331320626, 40.32440900802612, 44.38253218787057, 45.23865100315639, 45.46020821162632, 41.5239633832659, 36.20274107796805, 36.44813755580357, 62.74008628300258, 70.97534833635602, 45.216142313820974, 41.75534881864275, 46.82265615463257, 51.39913579395839, 53.83908258165632, 49.110916818891255, 47.82435015269688, 50.0726934160505, 50.69697168895176, 46.6032772064209, 47.57309981754848, 43.65544836861746, 45.348175457545686, 43.09353365216936, 44.69905737468174, 42.39840112413679, 44.39999648502895, 47.40764236450195, 45.27600104468209, 47.4840794972011, 49.85077142715454, 48.23607955660139, 44.146018981933594, 42.47029760905674, 45.13670355933053, 38.59006915773664, 47.45493875231062, 48.73591559273856, 58.04448325293404, 49.28057445798601, 43.94962467466082, 46.277726309640066, 59.401963233947754, 60.90502534593855, 47.419537680489675, 45.56576871871948, 40.30343934467861, 42.996095589229036, 41.95448071616036, 45.983424936022075, 57.80993291309902, 56.44382674353463, 57.63185405731201, 58.5258857182094, 56.24828706468855, 50.20641149793352, 50.54858248574393, 51.40743889127459, 65.86325291224888, 54.269165652138845, 60.47666195460728, 50.340324129377095, 5.934523292950221, 0.33300175411360605, 25.89198783465794, 55.12211956296648, 50.25235646111624, 43.06519195011684, 2.711930981704167, 10.443713103021894, 26.14683907372611, 25.84319063595363, 30.62643998009818, 43.5375964982169, 62.85498169490269, 35.11568151201521, 46.66731875283377, 52.024251324789866, 53.471474238804404, 14.531822102410452, 0.9981457484619958, 0.22512984462082386, 0.0853279974045498, 0.0804554306502853, 0.09085708071610757, 0.10825412826878683, 0.105262650576021, 0.08097014017403126, 0.026725952413731387, 0.02620976877265743, 0.1496168223342725, 0.121618513283985, 0.20229266291218145, 0.1903134664254529, 0.5266712818826947, 0.07126347281570945, 1.8434960501534599, 57.589966842106406, 61.9196013041905, 45.50812646320888, 33.07835851396833, 50.20631422315325, 40.62148271288191, 17.02765498842512, 31.83033003125872, 27.30680956159319, 4.746439090796879, 21.085001707077026, 62.68406295776367, 47.40411615371704, 62.39578914642334, 13.298914636884417, 0.6390510659132684, 24.622171538216726, 61.77619743347168, 66.44774232591901, 56.17849588394165, 55.72581032344273, 51.16561031341553, 49.42901577268328, 46.25524888719831, 57.28594146456037, 57.14609159742083, 57.60198722566877, 57.31229598181588, 56.104101521628245, 48.759178161621094, 48.2283045223781, 46.974759169987266, 48.019302708762034, 46.15431240626744, 48.71463673455374, 50.77561487470354, 52.14754710878645, 52.072409289223806, 52.89026437486921, 50.558622632707866, 55.219776494162424, 53.66502325875418, 51.669184480394634, 49.26110560553414, 52.18398346219744, 55.67662402561733, 56.22418028967721, 56.58754675728934, 59.28747081756592, 53.61277280535017, 52.795855726514546, 55.05956493105207, 53.87247909818377, 50.45409740720476, 51.48292064666748, 51.40749447686331, 49.658226421901155, 52.04872635432652, 49.78814383915493, 49.22107008525303, 49.634654658181326, 46.83775806427002, 47.66619178227016, 49.87868234089443, 48.06887115750994, 35.62116643360683, 28.125908374786377, 27.55812243052891, 29.899335316249303, 45.93248769215175, 39.26856075014387, 35.954304763248985, 35.75090667179653, 36.691310610089985, 37.192762102399556, 39.50468485695975, 46.4908310345241, 44.172755650111604, 44.06271702902657, 51.403089318956646, 38.46050957271031, 42.76627002443586, 43.49446555546352, 42.970397676740376, 38.063510349818635, 37.39906106676374, 34.34095042092459, 52.49334505626133, 72.30745697021484, 57.045433044433594, 47.069942542484824, 49.67644459860665, 52.740422998155864, 51.58525024141584, 48.79801859174456, 48.7978309903826, 48.7382675579616, 53.05010073525565, 50.89465488706316, 48.14464126314436, 47.728895800454275, 48.11520174571446, 47.94496740613665, 49.52833679744175, 47.123905726841514, 50.770702498299734, 49.34050267083304, 49.998274735042024, 51.24130398886544, 53.12095499038696, 48.82167720794678, 44.546513148716514, 44.61180884497506, 44.4679776600429, 39.35455165590559, 48.68045507158552, 52.48668868201119, 57.25730446406773, 50.693827629089355, 50.03966515404837, 51.130056381225586, 57.80156033379691, 59.023293358939036, 54.19725179672241, 47.86557034083775, 43.97658021109444, 43.93272318158831, 44.648953914642334, 47.25262805393764, 57.150503703526084, 56.77983815329415, 63.126913343157085, 58.437435150146484, 58.35475853511265, 49.81735406603132, 51.117407185690745, 58.544228962489534, 71.35792309897286, 55.82427671977452, 66.6335232598441, 47.85981028420584, 3.9621733341898238, 0.15484752665672982, 34.00955261502947, 56.62307289668492, 57.96711506162371, 42.09983703068325, 5.8978810991559705, 20.250366721834453, 25.988374982561382, 26.577484948294504, 34.9386761529105, 51.89497314180647, 70.6342612675258, 43.066310610089985, 46.335556166512625, 58.9463837487357, 67.28718199048723, 21.89046468053545, 1.0075081203665053, 0.2668004578777722, 0.1987966333648988, 0.049282626049327, 0.28339386891041485, 0.16958856422986301, 0.10351837453033243, 0.26104751229286194, 0.15098279475101403, 0.0965840316244534, 0.1710055217679058, 0.22826764839036123, 0.1684612732912813, 0.21577248030475207, 0.6350573716419083, 0.14069049060344696, 2.4632925178323473, 70.60041659218925, 72.26357909611293, 53.61534363882882, 39.90398045948574, 53.98651640755789, 63.35466834477016, 34.36478969029018, 36.951385157448904, 34.042511395045686, 9.1470194373812, 32.82475968769619, 66.23940753936768, 49.57107169287545, 69.08611924307687, 10.420451402664185, 0.5710794446723801, 43.26779099873134, 62.3375562940325, 66.82417488098145, 59.010626792907715, 60.268563406808035, 56.70052099227905, 55.71072231020246, 49.1479229245867, 60.33746869223458, 59.469388553074424, 62.09801714760916, 60.721926416669575, 58.6956649507795, 51.435064928872244, 52.00203793389456, 49.64590726579939, 49.40614577702114, 49.11181313650948, 51.007104533059255, 51.586855275290354, 55.03032691138131, 56.53348977225167, 56.56257840565273, 52.607747146061485, 57.32374313899449, 55.425717626299175, 50.686247144426616, 50.644769872937886, 55.643158027103965, 55.36678647994995, 60.008047648838584, 59.66077668326241, 61.550221170697895, 58.851943833487375, 56.790597438812256, 57.20881993430001, 58.12186534064156, 51.34680543627058, 57.55520153045654, 54.986865929194856, 53.00226933615548, 54.342646326337544, 55.006699562072754, 53.669449261256624, 54.039256708962576, 50.7615065574646, 49.6110828944615, 46.62788772583008, 48.607870715005056, 44.753444399152485, 38.91128090449742, 38.35173552376883, 38.34267159870693, 47.305031367710654, 36.13309580939156, 36.99463769367763, 36.621422154562815, 38.24239519664219, 36.27331740515572, 42.113632678985596, 49.41259370531355, 51.66432768957955, 51.0275148664202, 54.0285564831325, 39.70256607873099, 45.137217726026265, 45.69445283072335, 46.89700535365513, 41.791083403996055, 39.475561482565745, 34.58533246176583, 48.62016207831246, 69.52337632860456, 61.25489493778774, 50.10211556298392, 54.54150724411011, 56.1857602255685, 52.20657900401524, 50.288143157958984, 50.82074342455183, 51.66607516152518, 57.00216661180769, 52.47590855189732, 51.37506723403931, 49.80032055718558, 50.83697094236101, 51.91649171284267, 53.024802344185964, 53.3032340322222, 54.81638145446777, 54.311285631997244, 53.17669691358294, 54.46509790420532, 57.13740634918213, 50.164816107068745, 45.62073591777256, 45.10729530879429, 48.84251832962036, 41.23779487609863, 51.832533155168804, 53.83000823429653, 61.33033847808838, 52.105044978005544, 51.61868149893624, 53.16813325881958, 60.96426568712507, 60.573068210056846, 57.07919086728777, 49.964617661067415, 46.5825229372297, 49.10901648657662, 48.253029687064036, 49.98437486376081, 62.172633852277485, 62.53193909781319, 63.99642481122698, 59.898731640407014, 56.652887616838726, 50.56698131561279, 55.88398953846523, 61.720479828970774, 70.50697026933942, 62.88497012002127, 67.60513850620815, 57.19995403289795, 10.616490483283997, 0.5853834514107022, 30.975058896201, 63.67588356563023, 60.3766565322876, 53.89936167853219, 14.38709807395935, 19.757152318954468, 36.474290575299946, 34.39365250723702, 47.16937473842076, 55.381916182381765, 67.93983323233468, 49.73972531727382, 61.19261128561837, 70.73115389687675, 78.3547590800694, 28.47765919140407, 1.2319340663296836, 0.4302814469805786, 0.22229814156889915, 0.11780335514673165, 0.24927677533456258, 0.22684744745492935], [0.025185917104993547, 0.0802142114511558, 0.06297726423612662, 0.05049223346369607, 0.04530169841434274, 0.12168089779359953, 0.1288145671465567, 0.06278017695461001, 0.14317949275885308, 0.027110749622806907, 0.44740254112652367, 49.6475053514753, 45.57288367407662, 44.63473790032523, 24.658243111201696, 30.238598482949392, 38.88144186564854, 47.03947121756417, 34.79061004093715, 20.166732992444718, 11.245974693979536, 8.125695041247777, 49.5606598172869, 39.98596920285906, 52.474362577710835, 45.85485894339425, 0.17744038147585733, 0.8341424231018338, 26.831912347248622, 43.141983440944124, 47.19243928364345, 34.92333105632237, 37.715179783957346, 37.52766180038452, 50.90860686983381, 51.79595783778599, 54.32870129176548, 54.75970499856131, 52.77292319706508, 50.17134393964495, 48.7245900290353, 45.61780725206648, 44.576449462345664, 44.09869827542986, 54.67872026988438, 60.23167542048863, 57.67826802389962, 51.76181786400931, 55.18483052934919, 50.769358021872385, 50.847407136644634, 50.40517861502511, 50.78516864776611, 46.71647725786482, 45.013366086142405, 48.93554776055472, 51.04828650610787, 50.76314285823277, 52.832017626081196, 49.132994719914024, 48.889769554138184, 49.42720576695034, 48.975419998168945, 44.476471832820344, 46.81969622203282, 44.92710420063564, 43.60389273507254, 43.791563579014365, 42.308640820639475, 43.654565947396414, 44.42781707218715, 42.22447381700788, 42.54288196563721, 40.86042084012713, 34.89538540158953, 37.11436210359846, 33.80519567217146, 15.678966215678624, 17.04099726676941, 25.98854521342686, 32.34093924931118, 39.55218621662685, 36.06734153202602, 37.90870795931135, 35.84539175033569, 36.370109285627095, 35.4594783782959, 42.04120813097273, 41.3579535484314, 38.861681188855854, 36.643357617514475, 37.025268827165874, 40.257970333099365, 36.51043857846941, 38.45432915006365, 36.353926931108745, 39.27401508603777, 45.30249800000872, 42.25643900462559, 25.57034182548523, 21.99042841366359, 19.285631929125103, 25.01864617211478, 33.60255146026611, 40.30818149021694, 44.178168296813965, 45.904851232256206, 47.11880922317505, 47.95466014317104, 46.844407490321565, 46.70577703203474, 45.412884031023296, 42.996019159044536, 45.73851483208792, 48.01595715114048, 43.171468121664866, 43.279300689697266, 43.736870833805625, 50.970581327165874, 48.310852595738, 49.17437471662249, 45.28011785234724, 43.813818659101216, 42.71754578181675, 41.961130142211914, 41.36668048586164, 48.54317603792463, 50.85003702981131, 54.15992954799107, 47.377056394304546, 46.71906893593924, 48.375251974378315, 72.7174562726702, 81.6088228225708, 48.7247428894043, 48.962239265441895, 42.339407444000244, 40.7222489629473, 44.41123172215053, 45.77240119661604, 49.564481326511924, 58.03659009933472, 56.6359201158796, 56.64596373694283, 59.046660150800435, 57.48545898709978, 55.37899446487427, 50.18341990879604, 56.08441380092076, 57.22103834152222, 50.271516118730815, 13.92777350970677, 0.17157798819243908, 0.26290873384901453, 37.30763666970389, 50.58077696391514, 57.52978154591152, 18.481914690562657, 2.0200534675802504, 19.210541009902954, 29.528395312173025, 25.88434134210859, 34.94378307887486, 39.13817432948521, 23.892033985682897, 20.60712718963623, 44.779691219329834, 46.368452412741526, 53.696634088243755, 12.819140655653817, 0.7924044313175338, 0.3358221527721201, 0.29045749987874714, 0.11738433263131551, 0.1613638512790203, 0.0725917254707643, 0.07368776308638708, 0.061383086921913285, 0.09356341085263661, 0.03638322411903313, 0.056274976913950274, 0.1767179181001016, 0.18470836005040578, 0.029489457607269287, 0.0908501868003181, 0.039916617197117636, 1.0831893107720783, 59.96940871647426, 52.62081323351179, 54.108106408800396, 33.33499717712402, 38.34652437482561, 35.88602828979492, 13.385602099554879, 26.487036773136683, 19.053030558994838, 11.009204404694692, 11.843065534319196, 50.16811302730015, 47.037873131888254, 55.790345191955566, 53.95005920955113, 0.2729473608945097, 0.7271630178604807, 22.595691204071045, 37.90446260997227, 48.37482466016497, 40.76271874564034, 42.71560723440987, 40.989851883479524, 54.18981722423008, 54.99422754560198, 57.74901458195278, 55.038008144923616, 54.125959805079866, 52.11418880735125, 50.049264090401785, 45.996425015585764, 46.239549432482036, 46.15477098737444, 60.05545520782471, 62.73181792667934, 58.10175377982003, 54.774991035461426, 57.673890658787315, 52.78480461665562, 52.49984162194388, 54.61497054781233, 54.651549339294434, 51.27375555038452, 48.786199705941335, 54.167642048427034, 54.33167512076241, 53.898743288857595, 56.66056885038103, 54.22807053157261, 55.17524896349226, 53.29588631221226, 53.65169661385672, 49.89158167157854, 52.72116953986031, 49.69497544424874, 47.291826316288535, 45.71445322036743, 46.78993361336844, 46.2571804864066, 47.04593651635306, 44.106789452689036, 42.8702324458531, 40.51982709339687, 34.78543710708618, 37.73063952582223, 34.30707795279366, 18.284994057246617, 19.760605573654175, 26.396147387368337, 32.56656115395682, 41.8510011945452, 36.92057337079729, 38.9269734110151, 34.482339314052034, 36.36472790581839, 34.652198450905935, 41.48234714780535, 41.18087523324149, 37.81619616917202, 35.97621938160488, 35.141806738717214, 37.953826086861746, 37.017851625170024, 38.914897441864014, 37.84995746612549, 37.81685624803816, 42.59157494136265, 46.31569821493966, 32.028259890420095, 31.8057473046439, 27.538222789764404, 30.012670857565745, 37.22920887810843, 38.84882354736328, 41.506189891270225, 45.26553010940552, 50.21198395320347, 50.81921829496111, 47.05127968106951, 49.52681514195034, 48.483289514269146, 50.882662296295166, 50.919105597904746, 51.325794083731516, 48.63822392054966, 47.60915054593767, 48.01172569819859, 51.220035552978516, 49.17629589353289, 49.791784695216585, 49.03797115598406, 49.23818349838257, 44.4107210295541, 43.154118469783235, 42.165167467934744, 51.325748920440674, 52.37010833195278, 55.29092604773385, 50.592436041150776, 52.73548630305699, 50.53309842518398, 65.20599501473563, 73.05675070626395, 53.315570558820454, 51.23006527764456, 45.169947215488975, 41.34244169507708, 45.91255331039429, 45.23236983163016, 52.06885181154524, 58.165850911821636, 57.77617161614554, 56.21725640978132, 60.276470456804546, 56.916874000004356, 54.911540508270264, 52.21333612714495, 61.363974707467214, 60.46471105303083, 47.07539340427944, 9.964078085763113, 0.0748440817530666, 1.2120750291006905, 47.37408256530762, 56.00494725363595, 64.40119906834194, 17.946693216051372, 7.560080409049988, 16.148730448314122, 20.974699054445537, 27.888262612479075, 37.106486320495605, 47.65771845408848, 29.341144834245952, 30.57674993787493, 48.59306410380772, 51.96928412573678, 61.51233959197998, 15.591882705688477, 0.886397219129971, 0.22382171052907193, 0.3629019153969628, 0.21650381891855172, 0.1828230233596904, 0.15597427476729664, 0.11680064323757376, 0.2555104765508856, 0.1546305175870657, 0.18190310629350798, 0.11792615641440664, 0.23374855571559497, 0.3475037845117705, 0.1617189422249794, 0.21766408665903977, 0.26551862380334307, 1.4125036341803414, 74.32097543988908, 61.233591760907856, 62.62325232369559, 37.73666361400059, 41.99943903514317, 56.985115732465474, 58.09166499546596, 41.119981220790315, 25.81757262774876, 18.45531872340611, 17.090607404708862, 58.13506691796439, 48.99594497680664, 63.062892641339985, 55.70552505765642, 0.2767181157001427, 1.7337906169039863, 34.622571332114084, 46.626692635672434, 53.72115775517055, 47.435108593532014, 49.810892241341726, 45.122647353581016, 53.64265700748989, 59.50342082977295, 62.74485969543457, 57.76915740966797, 55.530909878867014, 53.61795963559832, 51.33368028913225, 50.477193219321116, 49.30976384026663, 47.01061882291521, 59.3453562600272, 63.03402982439314, 62.00127043042864, 54.25815623147147, 61.554813929966514, 54.3479825428554, 52.89000729152134, 55.28553771972656, 54.38734061377389, 50.74870102746146, 50.26213952473232, 56.0109817641122, 58.627461433410645, 57.63156918116978, 58.885350772312705, 57.15432173865182, 56.670671531132285, 56.29902628489903, 57.47870533806937, 54.686203479766846, 55.619603633880615, 53.04741873059954, 51.06059523991176, 50.76742989676339, 49.582327774592805, 50.17556497028896, 50.99582065854754, 45.18110602242606, 44.44072682516915, 44.98521198545183, 37.03188351222447, 40.63653251102993, 40.313107763017925, 25.19096323422023, 31.465636457715714, 33.15861368179321, 37.69543647766113, 41.759990215301514, 38.332704407828196, 41.241758823394775, 38.32028797694615, 38.210833004542756, 34.55401693071638, 43.34308515276228, 45.64957789012364, 42.80450596128191, 37.033241885049, 36.32493209838867, 40.87747866766793, 39.7147775377546, 43.86640957423619, 42.013404914310996, 40.8267741884504, 44.85747282845633, 52.244161810193745, 39.10101883752005, 40.581923144204275, 33.502935137067524, 37.018838269369944, 39.215483461107524, 43.74435404368809, 44.69403730119978, 49.268484592437744, 54.00197614942278, 54.55906881604876, 50.751761708940776, 50.788694858551025, 50.79353427886963, 54.06504494803292, 52.505747590746196, 55.33120128086635, 49.765638623918804, 50.41651112692696, 52.65269504274641, 55.089775698525564, 53.39579793385097, 54.80241904939924, 50.81521960667202, 51.54175451823643, 47.547308104378835, 45.421124594552175, 46.51915536608015, 53.42664793559483, 55.766728264944895, 57.69695520401001, 51.4705354826791, 54.8431841305324, 50.874598911830354, 67.9512699672154, 80.23251669747489, 52.902965681893484, 52.84503160204206, 47.90116943631853, 43.09256090436663, 50.18960380554199, 48.644341809409006, 56.63411705834525, 63.7906608581543, 60.40484537397112, 58.858614104134695, 62.25656809125628, 56.9714104107448, 55.728037221091135, 52.47889280319214, 64.74687889644078, 61.567911284310476, 56.26217998777117, 16.867436477116176, 0.21009939829153673, 0.8015111312270164, 47.83200706754412, 61.45709446498326, 67.3686079297747, 27.246377604348318, 9.907218371118818, 26.902485200337, 39.14807898657662, 35.334629671914236, 48.767179012298584, 52.19874838420323, 34.99604395457676, 31.12196465900966, 62.13548183441162, 66.0446217400687, 77.46247836521694, 25.76630708149501, 1.0887074832405363, 0.3867123605949538, 0.4413996503821441, 0.33452221538339344, 0.3790623668049063, 0.26223190873861313], [0.05921604963285582, 0.08638036450637238, 0.08444795784141336, 0.10180987085082702, 0.06634627881326846, 0.021940216089465787, 0.06589087325015239, 0.07661925828350441, 0.07175956333854369, 0.08908374980092049, 0.7040275250162397, 48.880260944366455, 50.87026671000889, 38.40611212594168, 26.443577527999878, 34.83242777415684, 43.69405255998884, 111.19148009163993, 129.83991704668318, 15.837899310248238, 5.396139519555228, 24.454436813082012, 42.822550433022634, 51.299852984292166, 43.58121728897095, 62.345449447631836, 13.642153910228185, 0.2188821520124163, 1.3093411241258894, 7.740947229521615, 15.31527839388166, 11.520360793386187, 9.56890276500157, 24.695627893720353, 50.25491687229702, 48.12051364353725, 53.76788786479405, 52.329329354422434, 53.90804692677089, 52.15383870261056, 45.937205518995015, 43.41776786531721, 43.527215889522004, 53.20052228655134, 48.22525078909737, 35.26716961179461, 39.349059104919434, 48.489129475184846, 49.66996540342058, 47.27429253714425, 49.2764368057251, 53.13133559908186, 52.312789167676655, 49.96644156319754, 49.66705410821097, 47.77789797101702, 48.70315483638218, 47.679966585976736, 48.29971463339669, 50.516825744083945, 46.32326480320522, 48.25077499662127, 47.325406960078645, 44.58725391115461, 41.33921773093087, 31.194760935647146, 34.72493914195469, 40.720730781555176, 40.98023557662964, 41.35520206178938, 41.932524408612935, 42.09207936695644, 41.87119265965053, 40.553814206804546, 33.58273867198399, 36.207549231392996, 41.527044909340994, 38.73732927867344, 26.66838128226144, 26.677891629082815, 27.573616913386754, 35.56297527040754, 37.78748621259417, 38.43704898016793, 37.439315455300466, 37.64347784859793, 36.69734512056623, 39.20861864089966, 38.7450452532087, 38.380681719098774, 38.85986076082502, 38.870255265917095, 39.63821881158011, 37.54228775841849, 36.72705561774117, 33.772240366254536, 37.38019323348999, 34.50453880855015, 24.352376461029053, 19.38262357030596, 11.605539628437587, 18.61610698699951, 34.127321107046946, 33.32279961449759, 36.18277890341622, 41.22651447568621, 45.44218805858067, 46.01397269112723, 44.90310512270246, 46.44003970282418, 46.55607461929321, 45.65241275514875, 42.90848922729492, 43.86306054251534, 45.22885751724243, 45.97740779604231, 47.25264889853341, 44.68429940087454, 46.06785944529942, 52.939419405800955, 50.34767879758562, 46.719836711883545, 46.88936928340367, 43.737162658146445, 44.36295563834054, 43.162866251809255, 48.37749971662249, 52.40331029891968, 53.22105073928833, 52.83724267142159, 44.68056474413191, 54.99739245006016, 72.17846366337368, 60.72638021196638, 53.197687421526226, 53.374550342559814, 44.008875438145225, 42.040864195142476, 40.14141430173601, 44.793969767434255, 43.041099071502686, 57.226926939828054, 54.10173143659319, 56.98935760770525, 55.868171964372905, 58.73982770102364, 51.58264119284493, 54.18400853020804, 41.14006846291678, 49.90053789956229, 16.803752762930735, 0.5529738504971776, 0.14281343668699265, 7.833817720413208, 52.34247187205723, 49.020902906145366, 52.74682228905814, 13.996774332863943, 8.960688727242605, 12.632584997585841, 22.999225207737513, 23.81537103652954, 30.02842242377145, 41.81598227364676, 61.374126025608604, 15.944118159157888, 37.6016913822719, 45.68374218259539, 47.46083082471575, 7.9066183396748135, 0.28759866899677683, 0.133572074717709, 0.0620369232658829, 0.10101823761527028, 0.0254608781542629, 0.10016316814082009, 0.06273993304265396, 0.044183720368891954, 0.04339619566287313, 0.06816936670137302, 0.0611272927905832, 0.08188538891928536, 0.0937959108767765, 0.05802719521203211, 0.08938223057027374, 0.0986390495672822, 0.9754203621830259, 58.84518323625837, 59.11999838692801, 44.0383358001709, 26.71851600919451, 37.63355234691075, 49.98769957678658, 116.36256572178432, 135.148382459368, 19.831126315253123, 5.700821936130524, 26.750585419791086, 44.641168458121165, 54.19962808064052, 48.41734068734305, 62.45305619921003, 18.97874563080924, 0.2875787472086293, 0.5174599247319358, 5.641578555107117, 13.448241846902029, 12.797193901879446, 16.32098150253296, 32.777122838156565, 53.006254128047395, 50.27841567993164, 56.50056573322841, 55.23242221559797, 56.01742969240461, 52.20027003969465, 46.751708098820274, 45.53643342426845, 45.79626478467669, 57.33102485111782, 43.572149889809744, 34.654804025377544, 42.735308851514546, 48.72536127907889, 48.861969811575754, 46.24862725394112, 51.65401308877127, 56.556338923318044, 56.69147791181292, 53.097195625305176, 52.88705430712019, 52.12716804231916, 50.59215463910784, 51.1595584324428, 53.48297698157174, 54.876844678606304, 51.80995498384748, 52.51475245612008, 52.11050626209804, 52.08407531465803, 42.856190136500764, 36.01707478931972, 37.14988476889474, 43.42980214527675, 42.84739719118391, 43.60384062358311, 46.42905112675258, 42.704941749572754, 43.155455998011995, 42.71100057874407, 33.74827602931431, 35.47601509094238, 42.096831934792654, 36.962853159223286, 24.226393461227417, 26.836136851991924, 28.349100146974834, 36.35154717309134, 38.25805991036551, 37.48329060418265, 36.12778738566807, 36.93172870363508, 36.72340781348092, 38.35576547895159, 35.75070169993809, 38.26662703922817, 35.276438508714946, 36.7284209387643, 37.822341850825715, 34.71895326886858, 36.10148845400129, 33.22242593765259, 38.32559987476894, 34.67160824366978, 25.934159926005773, 24.93891211918422, 15.103684902191162, 21.45373044695173, 34.61248254776001, 33.65937382834298, 35.83725888388497, 40.020807470594136, 45.951286043439595, 46.099650927952354, 47.18721423830305, 48.58665091650826, 50.061201095581055, 49.050700255802695, 46.79733691896711, 46.920608384268625, 49.295221260615754, 47.287316935403005, 50.63272517068045, 51.55855873652867, 48.442910058157786, 50.87752757753645, 52.13538081305367, 49.2441520009722, 48.23387697764805, 44.58233111245291, 46.20329025813511, 45.944313526153564, 49.86737067358834, 54.23234019960676, 54.3675799369812, 56.091931751796174, 45.539563587733674, 57.078020095825195, 65.3734882899693, 55.85263579232352, 56.95049633298601, 54.91533075060163, 46.546027524130686, 42.9281074660165, 41.18121916907174, 45.66185188293457, 46.13152926308768, 56.23307398387364, 55.96380696977888, 56.35507045473371, 56.455468450273784, 60.33464077540806, 53.89553322110857, 53.97479132243565, 48.194133281707764, 49.14757898875645, 12.443138020379202, 0.07656103997890439, 0.2087336837181023, 13.142529794148036, 63.780822208949495, 53.82072196687971, 58.406126567295615, 19.402064629963466, 14.166099326951162, 9.414178541728429, 20.387051684515818, 23.984797648021154, 25.68067400796073, 38.35416391917637, 68.87831251961845, 15.505327258791242, 38.12900754383632, 52.37309258324759, 56.976041385105674, 11.338568125452314, 0.6405715814658574, 0.05578849105430501, 0.07619794910507542, 0.09485789281981331, 0.03396555295746241, 0.04645445477217436, 0.14062171429395676, 0.2100071039583002, 0.1362079389925514, 0.22614817640611104, 0.1334291481013809, 0.14075193873473577, 0.14537645344223293, 0.2695208676159382, 0.18654022818165167, 0.15777155118329184, 1.6635573570217406, 72.96436745779855, 70.1716502053397, 52.565575054713655, 37.572092056274414, 48.67692886080061, 57.88566132954189, 113.18327849251884, 132.07736206054688, 21.025516441890172, 11.466335943767003, 32.64673294339861, 50.536179951259065, 61.19607843671526, 52.55596569606236, 72.95530005863735, 16.811682394572667, 0.5926807969808578, 2.3600129740578786, 10.407255036490303, 20.903429644448416, 23.74106352669852, 25.461932556969778, 41.131206035614014, 59.11226504189627, 56.49213409423828, 60.962716238839285, 56.41581508091518, 56.91206584657942, 56.420560700552805, 52.38419927869524, 49.86501523426601, 48.10924366542271, 56.201223441532676, 53.43617044176374, 40.90382276262556, 44.83086470195225, 52.441587924957275, 49.52349042892456, 48.219431672777446, 52.2179844720023, 59.498675210135325, 57.22265379769461, 55.037289006369456, 56.32016270501273, 54.52694034576416, 55.47088786533901, 52.65218087605068, 57.34778390611921, 58.42913205283028, 54.311740739004954, 57.100049359457834, 54.7800076348441, 53.487541948046, 47.55979401724679, 42.2574325970241, 44.028976576668875, 48.51905884061541, 47.605464526585166, 45.84465898786272, 48.33018248421805, 47.1935579436166, 46.096513816288535, 44.451357569013325, 35.452495438711985, 38.96474034445626, 43.09974534170968, 40.583132130759104, 27.618040221078054, 32.991829122815815, 32.791477816445486, 40.27809231621878, 40.27733843667166, 42.15533229282924, 39.87825128010341, 40.30332122530256, 39.16364989961897, 39.230731282915386, 40.28347717012678, 40.225442341395784, 39.38020093100411, 40.75069836207798, 39.53999212809971, 40.697325774601524, 41.32174301147461, 37.27762392589024, 38.64404623849051, 39.60485356194632, 34.493386949811665, 34.04656914302281, 23.795966454914637, 28.4045432976314, 37.03227955954415, 35.68354388645717, 38.72104617527553, 43.655271189553396, 49.792298861912315, 49.048282282693044, 50.07106406348092, 50.920641149793354, 51.73388263157436, 51.23723929268973, 49.95355265481131, 50.378695556095664, 55.31294141496931, 49.97180209841047, 53.82636737823486, 56.19645002910069, 52.813698700496126, 55.18669959477016, 57.32484442847115, 50.78911175046648, 52.274466378348215, 46.66372306006295, 50.3443922996521, 47.36985111236572, 53.904110772269114, 58.25010824203491, 57.41217633656093, 58.44165965488979, 50.3380103792463, 51.428901876722065, 72.49398136138916, 74.76018496922084, 54.50161068780081, 58.108938217163086, 48.16816438947405, 46.34010376249041, 42.17844547544207, 49.714659690856934, 46.59178141185215, 60.72742938995361, 58.14961991991316, 59.63580485752651, 56.87225614275251, 63.19947338104248, 56.69892985480172, 54.998657022203716, 48.70175130026681, 60.89374147142683, 21.770524876458303, 0.8818312755652836, 0.316411057221038, 10.969108956200735, 66.82799639020647, 57.00112090791975, 64.42885289873395, 21.966804538454326, 18.937391689845494, 18.8314368724823, 32.31371968133109, 31.21186740057809, 42.69565200805664, 56.90534693854195, 82.51709829057965, 23.83749236379351, 51.92342601503645, 63.840187617710654, 72.6784838267735, 19.67042316709246, 0.7668145416038377, 0.3941466345318726, 0.19608387750174316, 0.22410772661013262, 0.13273236049073084, 0.10059281651462827], [0.08105431922844478, 0.06027812657079526, 0.026979020530624048, 0.015215185969801885, 0.005800034642951297, 0.0314646900099303, 0.06507023942789861, 0.02180317576442446, 0.1171082638736282, 0.10816400524760995, 0.08420174462454659, 47.84138018744332, 54.90149341310774, 41.007038252694265, 37.17347042901175, 32.40085356576102, 30.857568332127162, 21.722019502094813, 50.687299796513145, 15.577550309044973, 1.6385322255747659, 29.453716073717388, 60.35262966156006, 46.76553153991699, 44.351376465388704, 55.72725207465035, 41.863209179469514, 1.0833753922155924, 0.029676831659993956, 0.231405465730599, 1.882892553295408, 3.9439625399453297, 10.516419921602521, 8.464471834046499, 42.78516912460327, 49.5072455406189, 54.84712723323277, 51.255707604544504, 51.984014306749614, 44.96069526672363, 46.634915828704834, 45.34688309260777, 49.09242071424212, 48.29364538192749, 30.15616158076695, 33.88533966881888, 40.82499197551182, 40.068552017211914, 39.81153815133231, 40.4586238861084, 42.686532497406006, 50.525392872946604, 47.37056677682059, 51.44823176520211, 52.052964755467, 47.58298363004412, 47.883694716862266, 48.109368732997346, 48.301743507385254, 46.85172741753714, 50.219071115766255, 47.683242661612375, 44.49078164781843, 33.382769516536165, 27.84217173712594, 28.82224120412554, 19.928767613002233, 33.66819109235491, 37.68505934306553, 37.18184648241316, 39.89351994650704, 41.86042295183454, 44.70813519614083, 42.72654022489275, 44.33720908846174, 43.27832794189453, 40.31576197487967, 39.56717348098755, 43.90518399647304, 37.23748070853097, 33.18540940965925, 38.34018414361136, 40.197705132620676, 39.59666510990688, 40.2373446055821, 42.01591321400234, 39.97007172448294, 39.374152524130686, 43.59940767288208, 42.06453670774187, 39.692890712193076, 40.69767318453108, 38.233306952885215, 37.42649255480085, 33.02591698510306, 36.21142980030605, 36.89160980497088, 29.865316935947963, 25.48258260318211, 20.936082703726633, 25.89539245196751, 35.33616174970354, 33.949745995657786, 32.94515807288033, 38.10339648383004, 41.92212642942156, 42.24181652069092, 44.709854875292095, 45.37612458637783, 44.58708020618984, 42.27684933798653, 43.141608238220215, 41.24339859826224, 41.8598393031529, 43.23421730313982, 46.66713809967041, 45.53974771499634, 44.97045053754534, 43.558482783181326, 46.235887731824604, 51.93412276676723, 46.239650181361604, 43.362762451171875, 46.61282403128487, 43.96132891518729, 43.74151917866298, 48.04560164042881, 56.190641335078645, 52.26249115807669, 51.28865596226284, 41.63207735334124, 68.67860044751848, 51.98781149727957, 30.580415112631663, 61.912847655160085, 49.89193255560738, 47.956550053187776, 37.034360545022146, 42.69922685623169, 42.617123467581614, 45.5363952091762, 47.11459166663033, 53.06853430611746, 49.11382116590227, 55.342530318668906, 53.47179733003889, 58.48477322714669, 46.624170439583914, 43.66015229906355, 18.295209646224976, 1.1141070574522018, 0.30626386457255905, 0.546766069318567, 21.87577792576381, 52.30985007967268, 49.091312476566856, 51.473783765520366, 28.598561320986065, 15.413986240114484, 8.773375715528216, 15.77145368712289, 20.706387417657034, 39.579965114593506, 43.701507977076936, 51.382894379752024, 27.650519575391495, 38.82381003243582, 48.34617376327515, 48.68886586597988, 6.053771751267569, 0.19007653556764126, 0.21167391166090965, 0.06953364956591811, 0.012760380282998085, 0.044720014091581106, 0.23108772135206632, 0.089222652704588, 0.03220500564202666, 0.028189842522676502, 0.04739689241562571, 0.08746195611144815, 0.03045831061899662, 0.14051879410232815, 0.05793471767434052, 0.028392610838636756, 0.14760891507778848, 0.38084058995757786, 53.48389414378575, 63.70758124760219, 45.05442993981497, 33.635249682835166, 39.299521923065186, 37.53625324794224, 38.1862850189209, 65.89144175393241, 19.91583354132516, 2.6726306676864624, 32.46915783200945, 65.11824621473039, 45.99738386699131, 50.41953706741333, 61.80604689461844, 45.5054930959429, 1.8205943533352442, 0.2574862076767853, 0.30859069685850826, 1.4055751945291246, 3.2536752947739194, 10.05763384274074, 18.542035715920584, 49.93663031714303, 52.89082717895508, 57.00625215257917, 52.20642614364624, 54.31308174133301, 47.47775316238403, 47.977860178266255, 47.23708840778896, 54.525811263493125, 49.96457249777657, 40.78808661869594, 45.76856926509312, 45.92855848584856, 41.90573215484619, 40.11971160343715, 41.93052680151803, 42.62236588341849, 53.20718560900007, 50.88128307887486, 56.54929344994681, 54.334593364170615, 52.48186315808977, 54.90764256886074, 50.72460120064871, 49.46441337040493, 51.718742506844656, 52.408854961395264, 51.452362469264436, 46.94548640932356, 35.55577346256801, 31.170612471444265, 32.693410941532676, 26.59874643598284, 37.49201059341431, 42.649255411965505, 40.871242659432546, 40.33963598523821, 42.22022499356951, 48.16285596575056, 42.23717859813145, 40.724562713078086, 41.7684565952846, 39.71465247017996, 39.566645417894634, 40.213929176330566, 35.36090081078665, 33.0089807510376, 38.502886635916575, 39.744203158787315, 40.06471313749041, 41.117271423339844, 41.21884019034249, 37.69132661819458, 38.344578879220144, 40.68234198434012, 38.14326524734497, 37.313483578818186, 38.02621936798096, 37.1668244770595, 36.75206913266863, 33.88820232663836, 34.88231931413923, 36.04941170556204, 29.751178877694265, 26.741785526275635, 19.1369891166687, 25.483633518218994, 35.18763010842459, 33.49155746187483, 31.59594644818987, 35.7983454976763, 40.020539964948384, 44.176632744925364, 47.21496186937605, 48.981628213609966, 47.47961180550711, 44.353342805589946, 45.68041399547032, 44.14645324434553, 45.96328558240618, 47.49961566925049, 48.57024621963501, 50.608469009399414, 44.927090304238455, 46.41171884536743, 48.66054500852312, 50.3518442426409, 48.5335944720677, 46.087700026375906, 46.49676827022007, 46.05409506389073, 46.10900667735508, 49.38710076468331, 58.810268538338796, 53.78147159303938, 52.54193728310721, 47.92865650994437, 67.78833471025739, 53.538103989192415, 32.401906217847554, 62.02734007154192, 50.894804273332866, 50.39326592854091, 40.20284332547869, 43.05386291231428, 44.24005937576294, 49.1423157283238, 47.63244438171387, 54.12171792984009, 51.6778940473284, 58.5916017804827, 55.80743776048933, 61.41824013846261, 49.47468280792236, 49.94027117320469, 18.2494957106454, 0.9678146903003965, 0.03367406788415142, 0.9179954550095967, 29.29157985959734, 56.156119210379465, 54.533145087105886, 58.38232898712158, 38.05243839536394, 20.936348472322734, 10.145335742405482, 15.728616305759974, 18.647948844092234, 33.17924983160836, 45.47277055467878, 51.456041540418354, 28.257048674992152, 46.79030186789376, 56.79741709572928, 59.54264341081892, 7.829141582761492, 0.6437682956457138, 0.10749902735863413, 0.08479355608246156, 0.027555855024339895, 0.044295366520860364, 0.11551289233778204, 0.17461991496384144, 0.16598832527441637, 0.08529068476387433, 0.17683169485202857, 0.2615360032234873, 0.13368042318948678, 0.20143468252250127, 0.15551376662084035, 0.1744935717433691, 0.2053412664681673, 0.6045616737433842, 65.55644825526646, 73.19124003819057, 51.728911195482524, 51.798792702811106, 46.60022694723946, 41.42046996525356, 28.219278267451696, 55.93869618007115, 20.964556421552384, 6.053189405373164, 39.78547893251692, 67.73259626116071, 54.2706629889352, 54.38229969569615, 67.24352645874023, 49.41681126185826, 1.5774295500346591, 0.2754306362143585, 0.42024314563189236, 4.075149306229182, 6.231404185295105, 12.216528603008815, 29.918554033551896, 55.77204711096627, 57.59989581789289, 61.11185237339565, 54.03803382601057, 55.2960399218968, 49.22301210675921, 49.503166948046, 52.44764675412859, 57.57817922319685, 54.66509485244751, 37.98616647720337, 35.459679876055034, 43.813096046447754, 40.26035703931536, 39.74369594029018, 41.37605707986014, 44.061278751918245, 55.98741694859096, 53.81758485521589, 58.6239595413208, 58.89001996176583, 54.55347899028233, 58.965838704790386, 52.588719504220144, 51.89488976342337, 55.93928330285208, 56.020476477486746, 53.73127085821969, 51.91601923533848, 42.327814374651226, 39.171306814466206, 38.68138585771833, 34.676138469151084, 44.32642548424857, 45.00403812953404, 44.801234109061106, 44.65276847566877, 44.69984252112252, 49.91433007376534, 44.45800004686628, 45.371695109776084, 43.43698310852051, 43.05120175225394, 41.60000794274466, 44.63285493850708, 40.523012842450825, 36.071861335209434, 41.08356918607439, 43.82601274762835, 43.52310255595616, 45.890881878989084, 45.176634856632774, 43.570256505693706, 42.89876522336687, 44.686581884111675, 41.62786674499512, 41.1769460269383, 41.35534797395979, 40.718285015651155, 42.39192887714931, 38.09010805402483, 38.81436048235212, 39.73657056263515, 34.312382902417866, 34.486483914511545, 26.13369655609131, 29.73369721003941, 38.51734583718436, 37.200151511601035, 34.009642941611155, 38.60083539145333, 42.54282638004848, 46.792535713740754, 53.67874247687203, 50.07570546013968, 49.23820781707764, 44.4801995413644, 48.647975717272075, 49.65325151171003, 49.74022558757237, 52.12516001292637, 52.161641529628206, 56.06633111408779, 50.32541329520089, 49.185957363673616, 53.58994797297886, 54.165251868111746, 50.44257034574236, 47.52417407717024, 52.089036328451975, 49.180707999638145, 50.87864623750959, 51.95723247528076, 61.544516699654714, 57.236352171216694, 54.68883337293352, 48.29149144036429, 68.54129014696393, 59.21441050938198, 40.974847248622346, 63.24544961111886, 53.032632963997976, 51.81621183667864, 41.59878853389195, 45.12168502807617, 48.80631126676287, 50.55487755366734, 51.32835796901158, 57.615365982055664, 54.7069125856672, 59.06642777579171, 57.19079283305577, 60.564209256853374, 50.90124872752598, 51.09408903121948, 30.578990731920513, 1.7383702397346497, 0.35213570882167133, 0.9607470695461545, 28.461313554218837, 64.4009141921997, 58.389833041599815, 63.29720674242292, 40.37771558761597, 23.345384461539133, 15.79215931892395, 22.17068726675851, 26.091517516544886, 54.81644051415579, 61.653818811689106, 66.81855378832135, 40.17104489462716, 55.82356800351824, 63.967951093401226, 73.07851246425084, 17.755136592047556, 0.8686382206422942, 0.3923679499753884, 0.19402255596859114, 0.08654708056045429, 0.1584461506988321, 0.20897300301917962], [0.04765933279746345, 0.15578347072005272, 0.05515774864969509, 0.054481367979730876, 0.046425803631011925, 0.11843671330383845, 0.061876103681113036, 0.057015872693487575, 0.07265517528035811, 0.21876365265675954, 0.07781687937676907, 47.95245409011841, 52.08214371544974, 47.55638245173863, 34.09333746773856, 18.381292615618023, 36.65007305145264, 19.52773322377886, 39.14645658220564, 7.56595858505794, 5.279927858284541, 23.182548216411046, 63.99565356118338, 46.877157824380056, 46.024773665836875, 47.36202049255371, 51.460026332310264, 2.1099531693117957, 0.12325906168137278, 0.12224052633558001, 0.09818958797092948, 0.86939416293587, 3.1909100455897192, 3.9184209619249617, 33.9031583241054, 50.371966225760325, 54.26638289860317, 55.54581723894392, 54.914927755083355, 51.87152297156197, 45.75466939381191, 43.27290834699358, 51.52373089109148, 57.442793573652, 64.94654927934918, 104.98362595694405, 65.2440641948155, 41.43036767414638, 43.41314731325422, 39.59681797027588, 42.835387229919434, 42.95319741112845, 49.01602527073452, 46.80977419444493, 52.43065840857369, 51.744252817971365, 52.851444789341514, 45.666896275111604, 48.44914954049246, 48.012483051845, 48.66719443457467, 34.22132328578404, 30.206935541970388, 24.296307972499303, 36.60810245786394, 30.865527493613108, 41.56343262536185, 42.01607649666922, 39.01347500937325, 39.023459570748464, 38.15256193705967, 43.647503103528706, 44.945537771497456, 47.208100523267476, 54.509972844805034, 47.59949254989624, 47.93684843608311, 42.22847597939627, 44.285434586661204, 43.00678539276123, 42.5471898487636, 40.42313248770577, 41.7520102092198, 40.66587822777884, 41.0927859715053, 43.27642413548061, 42.04403257369995, 41.52072204862322, 38.82540116991316, 37.88577890396118, 41.16755553654262, 39.54690905979702, 37.30838360105242, 40.21488455363682, 36.416439873831614, 36.35985721860613, 36.80425705228533, 31.81990773337228, 34.32675872530256, 38.30432449068342, 43.73246914999825, 41.79587418692452, 40.992408820560996, 36.870959758758545, 38.31414576939174, 39.64332921164376, 45.44271959577288, 46.33197784423828, 45.0836957522801, 44.92352935246059, 41.65105635779244, 41.86133663994925, 40.04001576559884, 38.29732418060303, 39.119150161743164, 40.859260490962434, 46.526544775281636, 34.77541085651943, 29.00491976737976, 40.34668493270874, 52.02807630811419, 51.51432997839791, 50.215134961264475, 50.15363992963518, 47.475936208452495, 47.18481363568987, 47.23985379082816, 50.71217087336949, 55.511847496032715, 45.41401311329433, 48.25608689444405, 45.525879110608784, 34.962664808545796, 45.49778754370553, 56.16924435751778, 52.68558086667742, 50.63590397153582, 41.13648319244385, 40.76058564867292, 39.26460027694702, 44.96271371841431, 46.27899088178362, 47.99547038759504, 51.16783373696463, 55.30977998461042, 51.38668462208339, 56.38196693147932, 50.72966991152082, 34.352915218898225, 1.8768217819077628, 0.05524148665634649, 0.05372619582340121, 1.3182119109800883, 31.174916880471365, 52.29172222954886, 47.35424893242972, 55.605985164642334, 48.22640419006348, 27.40202420098441, 8.740032179015023, 11.820009674344744, 23.922100578035625, 58.759011677333284, 49.88365030288696, 54.245232582092285, 19.33934497833252, 40.03838293892996, 53.497064454214915, 42.634976863861084, 2.9105239595685686, 0.162573407803263, 0.07055189314165286, 0.09879117711846318, 0.10044807820980038, 0.08294990858329193, 0.11975525612277643, 0.045886524354240725, 0.2108488945024354, 0.13152431031422956, 0.06804165284016303, 0.02433553970019732, 0.2673757741493838, 0.25945474633148735, 0.22120177825646742, 0.06736575732273714, 0.21888489329389163, 0.21298296856028692, 52.19064678464617, 60.6705653326852, 52.19083091190883, 38.2636844771249, 30.182165213993617, 38.856237275259836, 26.12239531108311, 43.77031946182251, 8.022894706044879, 6.536687621048518, 24.464143446513585, 68.0587933404105, 48.153093746730256, 51.460988657815115, 50.77754994801113, 60.056302888052805, 2.877101387296404, 0.21210555492767266, 0.037437426658081155, 0.2048464244497674, 0.4072777256369591, 2.687443792819977, 10.211334943771362, 47.12502786091396, 50.7496668270656, 57.65282719475882, 56.815687383924214, 58.05342558452061, 52.671865122658865, 47.710879121507915, 44.994988100869314, 53.19930635179792, 61.96604306357247, 74.62214510781425, 91.67203085763114, 55.73749371937343, 43.27420766013009, 44.95796462467739, 40.890259878976, 45.69864954267229, 45.514209611075266, 54.407869066510884, 48.84621129717146, 55.276310511997764, 54.683295658656526, 55.70825917380196, 50.271835735866, 52.97480658122471, 51.35308313369751, 49.19506992612566, 35.247940472194124, 33.89089822769165, 30.917291573115758, 38.7011639050075, 29.15261936187744, 54.85643434524536, 49.713735580444336, 40.13899285452706, 44.765113898685996, 37.51396690096174, 47.2876296043396, 45.12753888538906, 46.75780861718314, 47.90594284875052, 43.10049227305821, 45.29033170427595, 41.68384838104248, 43.397156034197124, 40.663293497903005, 40.7566043308803, 38.79191780090332, 42.08936956950596, 39.928698675973074, 40.70796694074358, 40.020790100097656, 39.96516629627773, 37.803682463509695, 39.44065373284476, 38.99454116821289, 38.7068510055542, 38.688483442579, 37.55455480303083, 38.22780397960118, 34.71477392741612, 34.1549471446446, 35.41969299316406, 31.73055042539324, 29.972013473510742, 33.627780369349885, 38.40969392231533, 37.87689215796334, 38.68697220938546, 35.276619161878315, 35.48644781112671, 38.850525856018066, 45.71553366524832, 49.59621374947684, 47.01625381197248, 46.70170191356114, 45.115462916237966, 43.705228737422395, 42.25017172949654, 40.66627080099923, 39.84862068721226, 43.11292607443673, 47.93061242784773, 37.495376995631624, 27.24909782409668, 42.211828095572336, 54.43675620215279, 51.23559256962368, 49.853647981371196, 49.846272468566895, 51.58045251028878, 49.02375166756766, 49.336597783224924, 54.25211477279663, 60.528537205287385, 47.82922778810774, 52.74290697915213, 43.34837620598929, 45.559921809605186, 50.24193068913051, 53.55966772351946, 56.68283782686506, 49.740256854466026, 42.63543544496809, 42.4965374810355, 41.88111816133772, 46.87204395021711, 47.65004069464547, 49.187972341264995, 53.90824147633144, 58.08392122813633, 54.98791510718209, 59.696024894714355, 53.96756867000035, 38.899805954524446, 1.7864681673901421, 0.08046104892023972, 0.07665884401649237, 2.701049668448312, 36.680624280657085, 58.87254524230957, 52.49868822097778, 60.677152224949424, 54.7753141266959, 31.948529311588832, 10.826694335256304, 15.97609898022243, 23.73257109097072, 58.90661226000105, 55.09377786091396, 56.50037465776716, 19.234383753367833, 40.37855631964547, 58.19587755203247, 54.08960335595267, 4.072127274104527, 0.150723363671984, 0.17112391255795956, 0.14220074670655386, 0.06766092005584921, 0.04377888941339084, 0.14861571176775865, 0.19028774994824613, 0.28176261644278255, 0.18517428290631088, 0.2583427902843271, 0.1280836220830679, 0.3740797484559672, 0.2847948265927178, 0.3959216278578554, 0.12123733945190907, 0.31702865979501177, 0.31525464355945587, 63.61128616333008, 72.4068717956543, 64.13987731933594, 47.21602841785976, 29.117075851985387, 52.345091342926025, 24.208055428096227, 43.54179668426514, 9.743972182273865, 12.842524818011693, 29.744532925742014, 73.15528311048234, 55.90692901611328, 59.65439823695591, 55.62696177618844, 63.50383227212088, 2.5074196585587094, 0.39609006739088465, 0.11839587906641619, 0.436407315411738, 0.5921411716512271, 4.609470120498112, 19.932300771985734, 54.631072998046875, 58.516721044267925, 60.442330905369346, 60.25978783198765, 60.19727488926479, 53.45507649012974, 49.24720573425293, 44.8398244040353, 57.52462945665632, 54.431409563337056, 59.04627105167934, 84.51892989022392, 52.58566229684012, 45.97070973260062, 43.431174414498464, 42.99480322429112, 47.3057678767613, 47.83192021506173, 56.92061907904488, 53.20788737705776, 57.95892660958426, 59.43060370853969, 58.395092827933176, 53.24502549852644, 56.64195115225655, 53.79903663907732, 55.49342434746878, 44.41600513458252, 41.52221243722098, 40.18236003603254, 44.40974480765206, 32.04291711534773, 54.1403842653547, 55.31127732140677, 43.1543755531311, 47.14545556477138, 42.15876122883388, 51.66066598892212, 49.60405479158674, 50.23013264792306, 53.36634452002389, 48.866239479609895, 51.73448712485177, 44.81460591724941, 48.24412557056972, 43.82863916669573, 44.03226654870169, 43.288809299468994, 47.63744708469936, 43.23265743255615, 43.745771476200645, 43.99958917072841, 43.218688079289024, 42.2744139943804, 41.92556578772408, 42.82602105821882, 43.68896995271955, 42.78005525044033, 39.01785584858486, 41.30629021780831, 38.21383115223476, 38.01367786952427, 37.89676053183419, 36.77236482075283, 36.62309667042324, 42.07713379178728, 44.22044808523995, 43.1008084160941, 43.73970569883074, 39.18220158985683, 38.47200884137835, 41.75184692655291, 50.85543925421578, 51.96978439603533, 49.901100703648154, 48.79461744853428, 47.120476790836875, 46.235509055001394, 44.988293511526926, 43.22822100775582, 44.85233116149902, 46.50502620424543, 53.613095896584646, 43.5900171824864, 32.62903240748814, 47.884750843048096, 57.430787086486816, 54.205888407570974, 53.94889191218785, 53.833082812173025, 54.123996938977925, 51.65815421513149, 52.86469152995518, 57.55566011156355, 61.367455754961284, 50.21153579439436, 52.64506939479283, 50.001088755471365, 46.35858597074236, 44.4327780859811, 59.23959078107561, 55.10686479296003, 53.13503898893084, 43.29171017238072, 44.66764456885201, 43.16018077305385, 50.341078008924214, 48.09176894596645, 54.243217604500906, 53.41564198902675, 58.60146822248186, 55.07034853526524, 63.71306337629046, 51.96515342167446, 45.96913249152047, 4.533292676721301, 0.1580689259405647, 0.3529255778661796, 2.211965535368238, 42.59362118584769, 62.67085443224226, 55.02354546955654, 66.23785809108189, 60.02588367462158, 37.6742444719587, 17.20854786464146, 18.255907160895212, 32.741627965654644, 70.30877985273088, 63.11810302734375, 71.4834839957101, 27.739142111369542, 54.657441411699565, 69.53290925707135, 71.11499323163713, 9.186502575874329, 0.6630456926567214, 0.37813955917954445, 0.20675989320235594, 0.3104285496686186, 0.18408243863710336, 0.43894012378794806], [0.1506889212344374, 0.017762160460863794, 0.056297219291861565, 0.08020972633468253, 0.05786389897444418, 0.2013217607246978, 0.05390383629128337, 0.14251907462520258, 0.13408237376383372, 0.06653328306440796, 0.08534429581569773, 24.800630807876587, 61.272369657244, 40.19828183310372, 40.6693696975708, 21.473055124282837, 41.42564637320382, 25.882606029510498, 40.56041499546596, 24.441177913120814, 3.7508460453578403, 18.404150451932633, 58.80794089181082, 54.233733313424246, 58.447211265563965, 41.33037962232317, 52.5664644241333, 5.795012150491987, 0.09178967281643834, 0.10789682529866695, 0.05219220456534198, 0.29782229182975634, 3.011100002697536, 7.433492047446115, 30.242882047380718, 49.44547258104597, 53.547237396240234, 57.09436573301043, 54.70262554713658, 49.583057335444856, 44.060740266527446, 44.3996456010001, 47.08886596134731, 61.57813903263637, 59.86428247179304, 51.46114846638271, 69.23502608707973, 47.56149632590157, 44.880304609026226, 43.55994190488543, 39.22431809561593, 40.107225690569194, 42.60088552747454, 45.67450107846941, 47.47463689531599, 47.81295510700771, 46.01864535467965, 46.93566165651594, 41.91895457676479, 38.02475329807827, 32.6359806060791, 31.075654915400914, 31.152439458029612, 45.0036802973066, 43.8584816796439, 43.03736441476004, 65.74391760144914, 53.066435950142996, 42.159542901175364, 37.62046194076538, 44.00779499326433, 40.158086504255024, 47.247218881334575, 53.6892203603472, 51.77018002101353, 48.67218671526228, 49.285987104688374, 49.71966239384243, 46.51893302372524, 42.79055050441197, 43.39309481212071, 43.93554762431553, 44.446820395333425, 41.86466482707432, 44.54554387501308, 44.68165561131069, 42.129839352199006, 40.56775229317801, 40.65881538391113, 40.429378918239046, 38.55300746645246, 39.113285882132395, 39.67184809276036, 39.155579566955566, 37.09048114504133, 38.98978860037667, 38.51361118044172, 38.012309074401855, 42.142099448612754, 43.40558072498867, 41.87926646641323, 39.64725146974836, 38.480120863233296, 38.748283113752095, 43.68480798176357, 39.41807556152344, 43.11699424471174, 38.96573393685477, 43.67659173692976, 41.559948103768484, 41.18989746911185, 37.505299023219514, 42.60566936220442, 39.45658942631313, 38.718850544520784, 33.63535737991333, 39.60560744149344, 35.17525536673409, 12.24464362008231, 21.01714559963771, 49.04088939939226, 55.02238859449114, 45.24006496156965, 51.620693002428325, 49.41922576086861, 47.382826873234336, 51.62907600402832, 55.33403614589146, 52.78146253313337, 45.23260259628296, 47.2971590587071, 37.974611622946604, 31.736838545118058, 49.66048111234392, 54.78532995496477, 55.778571469443186, 47.00867680140904, 41.65098340170724, 41.86644009181431, 41.23648166656494, 45.01134763445173, 47.797943523951936, 48.549936635153635, 52.183028084891184, 53.035658904484336, 54.42404794692993, 55.030986990247456, 55.15946613039289, 16.373831238065446, 0.2836065760680607, 0.0490037956541138, 0.07923895985420261, 2.0688408953802924, 36.19460473741804, 51.78231504985264, 52.87411676134382, 50.46351569039481, 55.455824170793804, 31.106859275272914, 4.661119554724012, 14.602172613143921, 19.624113423483713, 24.250197989600046, 30.28792027064732, 43.915922437395366, 26.721316133226665, 48.42725229263306, 43.56973191670009, 45.95086220332554, 2.665416483368192, 0.2321490586868354, 0.01780252481278564, 0.049665190878191164, 0.0862389849498868, 0.05234375196908202, 0.10072250491274254, 0.08418241994721548, 0.06701882236770221, 0.1024055363876479, 0.09027982383434262, 0.08927544272903885, 0.1198520694992372, 0.11506721696683339, 0.1717499289661646, 0.14272197016647883, 0.05105603838871632, 0.10988513646381241, 28.412563255855016, 69.94519451686314, 44.11925452096121, 41.211145060403005, 31.837142739977153, 45.44831984383719, 26.946707010269165, 47.157830306461875, 21.613170760018484, 6.065581951822553, 15.822295393262591, 68.02785996028355, 53.97954041617257, 62.57141876220703, 45.73845229830061, 59.904443059648784, 9.017973150525775, 0.09501141136778252, 0.1256168894469738, 0.07095371479434626, 0.09599280370665447, 3.7772661362375533, 13.27059030532837, 39.07219423566546, 53.72566713605608, 55.14669534138271, 57.921534878867014, 58.59043448311942, 54.88663469042097, 48.319805349622456, 48.438150542122976, 50.13460186549595, 59.93503597804478, 58.336832182747976, 52.70990303584507, 68.81976005009243, 45.67826352800642, 40.866531780787874, 44.04597534452166, 39.99579048156738, 40.431772572653635, 44.64001505715506, 48.4239102091108, 50.95340538024902, 49.11886903217861, 52.391842297145296, 52.051741872514995, 44.63052034378052, 40.531097071511404, 36.170202663966585, 35.34755332129342, 41.262725012642996, 45.62339012963431, 41.739958558763774, 39.901343618120464, 57.642780099596294, 56.49808175223214, 44.417759554726736, 44.0707699911935, 43.93082979747227, 42.61999307359968, 46.67331504821777, 50.50810922895159, 50.741179602486746, 51.333649022238596, 52.211550440107075, 47.732533182416645, 45.678260053907124, 42.28814363479614, 42.28916849408831, 44.54085036686489, 41.76498597008841, 41.15612574986049, 42.30366243634905, 40.515960420881, 39.8777961730957, 40.61453798839024, 41.22272770745413, 41.37438603809902, 41.35791880743844, 39.088598932538716, 39.12816892351423, 40.20714773450579, 35.38636595862252, 33.67970425742013, 37.668710231781006, 35.24366733006069, 38.76922845840454, 39.09356689453125, 40.70030655179705, 38.17404924120222, 40.6373176574707, 40.00709867477417, 42.33699989318848, 39.641988209315706, 42.45547015326363, 43.16702822276524, 46.169317041124614, 46.16759041377476, 41.80655356815883, 40.10446378162929, 45.814896379198345, 41.02076094491141, 40.99033825738089, 34.85558264596121, 38.2198691368103, 37.211789744240896, 14.301312140056066, 20.930239268711635, 50.36858245304653, 54.94482932771955, 47.61600146974836, 50.61434718540737, 51.281329086848665, 51.4015086037772, 53.34070219312395, 55.07055698122297, 55.8859315599714, 47.064825194222585, 47.267535414014546, 38.4653559412275, 41.39594629832676, 56.9232941355024, 53.56141519546509, 55.80088560921805, 50.49635982513428, 44.36525896617344, 44.77713428224836, 45.63220044544765, 46.693680218287874, 51.16303253173828, 49.63501596450806, 56.754571029118125, 55.09320116043091, 55.812072208949495, 58.563267026628765, 62.86831528799874, 17.71752773012434, 0.213151109537908, 0.10324902326932975, 0.22961074060627393, 4.145792944090707, 44.833345208849224, 56.15953424998692, 59.87926278795515, 54.25986548832485, 65.03809874398368, 30.12451253618513, 8.77883265699659, 20.41031425339835, 23.135826792035783, 27.49281804902213, 30.49041509628296, 52.71903644289289, 23.45564021383013, 50.16475704738072, 49.88407414300101, 57.48572996684483, 2.805487607206617, 0.278845377266407, 0.06839001950408731, 0.06473849687193121, 0.053103422812585316, 0.13364850490220956, 0.118066436744162, 0.32058999155248913, 0.1875469298767192, 0.13660144859126636, 0.20369649758296354, 0.27048520158444134, 0.32234690870557514, 0.1791203934699297, 0.47685231800590244, 0.2637802985097681, 0.5706574501735824, 0.1693906355649233, 37.98404380253383, 82.16633932931083, 53.8013573374067, 55.46526329857962, 29.258871214730398, 58.82051018306187, 29.791325569152832, 45.76730816704886, 30.710738999503, 10.519619567053658, 25.75431796482631, 70.70378494262695, 62.341607093811035, 68.08393887111119, 50.35302196230207, 63.37324087960379, 8.833252685410635, 0.137356875198228, 0.3110438995063305, 0.17625394942505018, 0.22599912940391473, 6.676993463720594, 20.64072867802211, 45.78804159164429, 58.6341039112636, 58.11950990131923, 63.01658289773123, 59.75150626046317, 54.68929195404053, 50.12022256851196, 51.1916834286281, 49.46795000348772, 63.58527905600411, 61.77623912266323, 67.83126068115234, 63.48710100991385, 41.03649861471993, 45.25922809328352, 43.3101715360369, 41.71769305637905, 40.935555185590474, 45.65926020486014, 50.91698292323521, 54.86946221760341, 54.60763325010027, 57.62665333066668, 55.498135226113455, 50.2154997416905, 48.34532955714634, 45.35756594794137, 42.09655400684902, 45.50148745945522, 48.00209896905081, 45.15253850391933, 44.13810150963919, 57.5865135874067, 57.849707875932964, 50.35953937258039, 46.80929476874215, 49.98628909247262, 47.191487380436485, 51.716630254473, 53.98637049538748, 53.49708182471139, 56.72744178771973, 57.725866658346995, 54.124406882694785, 49.98967286518642, 47.90961497170584, 43.48271267754691, 50.368339266095845, 47.367794445582796, 45.205535888671875, 47.372467109135215, 44.08873803274972, 45.13089486530849, 45.171722480228965, 44.994578157152446, 46.10856546674456, 43.82524497168404, 41.55836044039045, 42.444540636880056, 42.85026332310268, 39.01850550515311, 38.319443770817344, 43.04477119445801, 38.42610556738717, 43.62100962230137, 40.16189064298357, 44.35163007463728, 44.16848598207746, 45.96549163545881, 48.02007743290493, 48.00861637932913, 41.65315471376692, 44.98551423209054, 46.42250592367989, 47.808046204703196, 46.387288979121614, 44.80439901351929, 41.83127178464617, 48.700080258505686, 46.15546233313424, 43.82916375568935, 35.7158008984157, 39.15356111526489, 40.975243295942036, 24.093326772962296, 27.85379433631897, 57.03436803817749, 57.99856260844639, 50.43302352087838, 54.97964675085885, 54.28600461142403, 52.81470618929182, 56.262544768197195, 55.18915925707136, 62.47613116673061, 51.96232203074864, 47.04085738318307, 43.83707775388445, 39.85516241618565, 49.629936831338064, 57.90374749047415, 59.34703772408621, 52.69977951049805, 47.0080167225429, 46.54857751301357, 46.819293226514546, 49.67476313454764, 52.87488106318882, 52.05238110678536, 56.66112470626831, 58.735380853925435, 58.601169449942454, 61.37202072143555, 58.444251332964214, 24.883257048470632, 0.4835371364440237, 0.15045478594090256, 0.35710633067148073, 4.267617447035653, 49.94343260356358, 62.772659437997, 62.637037549700054, 63.29949964795794, 66.57460948399135, 42.04416111537388, 12.210171869822911, 21.369334152766637, 25.61777196611677, 33.28343806947981, 42.489224502018516, 59.58617387499128, 37.54486901419503, 64.08259637015206, 57.33078513826643, 73.8375197819301, 6.244845041206904, 0.4367662061538015, 0.1252226470304387, 0.22902573485459599, 0.13628659477191313, 0.15740306595606463, 0.17012368408696993], [0.03604287434635418, 0.043439343704708984, 0.02132035738655499, 0.16574368625879288, 0.018710798218048046, 0.0929139917716384, 0.029654741952461854, 0.15562580632311956, 0.1468814712549959, 0.09900657806013312, 0.23475658733929905, 15.024086339133126, 63.62332739148821, 45.245039871760774, 33.69919742856707, 20.25639602116176, 42.14992312022618, 31.41070399965559, 18.069850036076136, 27.265257596969604, 10.772500991821289, 3.6290059089660645, 51.24536173684256, 54.66897194726126, 56.95217432294573, 54.339259079524446, 46.73344128472464, 17.747398035866873, 0.27727942700896946, 0.12804554269782134, 0.2912772244640759, 0.3029311719749655, 1.4032977053097315, 12.960638982909066, 36.594213008880615, 47.70067221777779, 51.018621172223774, 56.73067617416382, 54.131560053144185, 55.10543346405029, 48.8309600012643, 42.49075657980782, 46.131279127938406, 49.410790647779194, 53.901057038988384, 42.80719838823591, 31.522952147892543, 75.13181631905692, 48.33667210170201, 40.020866530282156, 41.33103275299072, 41.96679292406355, 42.79987498692104, 42.092579637254985, 43.13115119934082, 45.213845934186665, 40.56992360523769, 35.652648721422466, 31.501430102757045, 30.22371891566685, 39.42000021253313, 50.67742640631539, 60.6216847555978, 60.63745716639927, 54.62489604949951, 46.51456955501011, 46.90073306219918, 48.462476185389924, 41.76803970336914, 42.6880715233939, 44.40944256101336, 43.451042788369314, 54.25174651827131, 54.221059799194336, 39.224898270198274, 36.60486459732056, 35.043757234300884, 47.95604630878994, 50.011980056762695, 49.08349575315203, 45.04565436499459, 45.76140914644514, 48.49283633913313, 45.82775402069092, 47.28735167639596, 48.38480922154018, 45.69786092213222, 40.0963065964835, 40.302209513528005, 34.34606082098824, 35.65557738712856, 34.94950839451381, 41.79106950759888, 37.57407576697213, 39.7070963042123, 41.88719436100551, 43.28658240182059, 40.7458450453622, 42.88135303769793, 42.07085609436035, 35.94565773010254, 27.195997953414917, 28.4412419455392, 23.659658432006836, 33.50485283987862, 43.249020440237864, 44.68823208127703, 36.19642516544887, 41.028605461120605, 39.6768091065543, 39.91688673836844, 37.52227347237723, 40.043906756809776, 41.32919495446341, 42.42422757829939, 40.77285964148385, 34.17509692055838, 53.41476651600429, 26.078760623931885, 15.588877609797887, 32.962594577244346, 50.35108688899449, 54.76601396288191, 49.442186083112446, 50.884607791900635, 50.807534899030415, 49.77829476765224, 46.07791348866054, 41.36515883037022, 51.284021513802664, 39.40731627600533, 47.355600357055664, 31.90131630216326, 40.034533636910574, 58.06781530380249, 49.48214864730835, 50.67001267841884, 44.030015332358225, 44.61287886755807, 41.636201109204976, 45.517096587589805, 48.40283284868513, 47.267010825020925, 53.071768692561555, 52.56876080376761, 51.083833490099224, 54.9689222063337, 55.845423562186106, 4.527539134025574, 0.07137733099183866, 0.22089114492493017, 0.20868587414068834, 8.125356316566467, 47.24176107134138, 47.31563431876046, 52.17931774684361, 49.00110054016113, 56.73705462047032, 9.62326807635171, 8.181271944727216, 25.888333082199097, 17.560991764068604, 48.33861064910889, 48.06814854485648, 35.196885108947754, 36.66621719087873, 62.11406053815569, 43.74133505140032, 46.332742146083284, 0.9082516378590039, 0.03495011744754655, 0.06421098339238338, 0.0228207967842796, 0.04653823349092688, 0.06724377708243472, 0.001730482276928212, 0.048947422964764495, 0.108440501482359, 0.044639475377542634, 0.06874083567942892, 0.13451973029545375, 0.09738960196929318, 0.11254514979996852, 0.14795723424426147, 0.18368803337216377, 0.24120522130812916, 0.260252377816609, 17.303307397024973, 71.9116597856794, 49.69087948117937, 30.941658905574254, 19.491753714425222, 50.76416424342564, 17.89868811198643, 10.304884621075221, 28.7262761592865, 14.21596394266401, 4.427051680428641, 51.87508739743914, 61.56863389696394, 59.05795097351074, 57.25942366463797, 47.51825073787144, 21.224443367549352, 0.378252521689449, 0.08964780239122254, 0.1962843710290534, 0.10722580166267497, 1.544919905917985, 22.639916488102504, 45.29885366984776, 51.50532511302403, 54.53258923121861, 60.60412665775844, 57.863583428519114, 58.54006699153355, 52.50152308600289, 45.06999390465872, 48.49243334361485, 49.179954120091026, 60.3074038369315, 48.634041104997905, 36.184008734566824, 69.66835744040353, 44.93315955570766, 40.61422879355294, 41.60622658048357, 42.557876178196494, 43.90504503250122, 43.49466357912336, 44.796054227011545, 47.5445670400347, 43.07178579057966, 37.80403682163784, 35.91899749210903, 38.45271021979195, 47.65167004721505, 55.1353246143886, 58.14967550550188, 56.51896456309727, 54.523681640625, 47.519671644483296, 48.86859144483294, 50.885396412440706, 44.979778494153706, 44.40751096180507, 44.6458272252764, 43.490814277103965, 49.786667346954346, 56.529591832842144, 48.39550597327096, 47.44425242287772, 46.103065967559814, 52.85644054412842, 51.25430754252842, 49.96571200234549, 44.12152658190046, 43.87990297589983, 47.38012054988316, 44.722316469464985, 46.16949422018868, 49.00020769664219, 43.570419788360596, 42.14116839000157, 39.86733218601772, 39.310649463108604, 41.226504053388325, 39.00003719329834, 39.882051944732666, 38.34675713947841, 38.33019263403756, 37.94646447045462, 41.504431997026714, 41.7095810345241, 40.49463292530605, 38.81084816796439, 41.880378178187776, 36.56505141939436, 37.06960875647408, 32.38133955001831, 39.8517404283796, 42.79505293709891, 42.725907938820974, 37.52310725620815, 41.138376576559885, 43.88156706946236, 42.656620502471924, 41.942446436200825, 43.97736883163452, 43.56923859460013, 44.311278411320274, 46.08087689535958, 35.5920604297093, 48.978154114314485, 36.132345403943745, 19.55639280591692, 37.85570362636021, 51.7684360231672, 53.64134727205549, 50.64862959725516, 51.04591369628906, 51.02297074454171, 51.66909762791225, 46.80439281463623, 46.06648370197841, 49.997374943324495, 40.522943360464915, 45.65553249631609, 39.86408737727574, 46.4636983190264, 57.633452142987935, 50.70698056902204, 52.39736611502511, 46.18556192943028, 45.959252153124126, 44.36763872419085, 47.291166237422395, 50.06678049904959, 50.040123735155376, 54.271823338099885, 56.53639759336199, 55.194248812539236, 57.14555311203003, 60.69835812704903, 4.858451000281742, 0.25579907106501715, 0.25109994464686936, 0.24572380312851497, 12.145910586629595, 53.62277126312256, 53.49020658220564, 57.70514365604946, 59.56700379507882, 61.775224685668945, 9.41116910321372, 15.687055655888148, 28.320183481488908, 21.487637656075613, 46.75500849315098, 51.67996113640921, 47.00870112010411, 35.935937200273784, 59.076509611947195, 51.78312104088919, 53.41742767606463, 1.1370956067528044, 0.0497183880236532, 0.12457223050296307, 0.08592098951339722, 0.13339682269309247, 0.040893822974924526, 0.03817097729604159, 0.2050797047891787, 0.21204155550471374, 0.13829789470349038, 0.2897818961313793, 0.11717713517802102, 0.21715191485626356, 0.20383951919419424, 0.2970734605831759, 0.35313223249145914, 0.31693032650010927, 0.44730703053729876, 21.516952105930873, 84.76052570343018, 58.838436535426546, 47.78417566844395, 28.540648085730417, 59.13242871420724, 42.61994443620954, 24.68966633932931, 33.76900250571114, 17.996697664260864, 9.015497854777745, 63.195999281747, 63.97216864994594, 68.93593393053327, 63.93127850123814, 59.1460610798427, 24.610505512782506, 0.3903621733188629, 0.30023502664906637, 0.3582457809575966, 0.42590755596756935, 3.3630021597657884, 31.251843861171178, 53.18946770259312, 53.091921942574636, 58.414325441632954, 64.12472329820905, 59.60342625209263, 58.0640424319676, 54.97618307386126, 45.67047459738595, 50.689669132232666, 51.435863971710205, 58.953095708574565, 51.655103955950054, 49.43020738874163, 60.11983721596854, 42.73713622774397, 43.134326526096885, 39.36949028287615, 41.95948689324515, 44.600882802690776, 43.42428527559553, 42.84221036093575, 49.422786712646484, 45.91320644106184, 44.26811620167324, 46.78505597795759, 44.74861192703247, 47.75661563873291, 51.74214056559971, 54.39266640799386, 55.63226672581264, 56.786960056849885, 51.68006535938808, 53.89739881243025, 54.71792548043387, 50.53891059330532, 50.30152191434588, 50.02303811482021, 46.531724657331196, 57.522326128823416, 63.1634122303554, 55.53604807172503, 55.69422728674752, 53.75874056134905, 60.441858427865164, 57.34582451411656, 54.06825154168265, 49.06218215397426, 48.18313775743757, 51.833571910858154, 49.09353937421526, 49.41810015269688, 55.11067587988717, 50.53946992329189, 45.16872085843767, 45.450630119868684, 43.62124238695417, 47.95843301500593, 42.77302714756557, 45.0328106198992, 42.63926042829241, 43.14525951657976, 40.30734075818743, 46.168879304613384, 45.18533052716936, 42.48918628692627, 42.92025600160871, 45.68316548211234, 42.56753070013863, 46.762908594948904, 39.2716839654105, 46.233778953552246, 49.808335304260254, 45.13754429136004, 41.36671870095389, 43.826266356876914, 47.36244085856846, 45.52443388530186, 44.553339753832134, 48.437445299965994, 47.51037495476859, 47.613652978624614, 45.91547850200108, 37.57443012510027, 49.18199341637747, 42.42458888462612, 30.230378764016287, 38.80218376432146, 60.991690226963584, 55.19397783279419, 52.800330366407124, 54.98598003387451, 55.06691265106201, 54.73572676522391, 52.658437728881836, 48.47274562290737, 51.44715132032122, 41.28888498033796, 47.124492849622456, 36.797281060900005, 44.046684060777935, 62.2628492627825, 54.014284883226665, 56.37075253895351, 49.13188648223877, 49.431138447352815, 47.30255780901228, 50.12830332347325, 52.831166471753804, 51.653485025678364, 56.763044357299805, 60.565369606018066, 58.42667933872768, 58.8481570652553, 60.69780921936035, 8.20606745992388, 0.20284584537148476, 0.4775305816105434, 0.3752146932695593, 12.137699552944728, 61.371437072753906, 56.15806818008423, 63.17630113874163, 59.277743339538574, 67.39128684997559, 17.71197090830122, 17.740918840680802, 34.426732880728586, 25.29372361728123, 65.59970773969377, 64.98093591417584, 48.35891328539167, 47.60977588381086, 77.69714682442802, 55.92770760399954, 71.87926728384835, 2.907395098890577, 0.25669077464512413, 0.23320882182036126, 0.19316594621964864, 0.2185514069029263, 0.15018696816904203, 0.15658176716949257], [0.06929135828145913, 0.27118048284734997, 0.10450132071439709, 0.059125940182379315, 0.03749787734289255, 0.07261318753340415, 0.05122936337387987, 0.0674526844439762, 0.1976904177239963, 0.10985304854278054, 0.047613714888159714, 9.920234084129333, 69.51610851287842, 38.65570184162685, 45.606717927115305, 37.10981103352138, 35.7025784764971, 43.343495096479145, 107.90104252951485, 23.451295852661133, 9.071866852896553, 14.467044915471758, 35.385473115103586, 57.703073092869346, 52.114814145224436, 52.250071253095356, 59.218892097473145, 38.42818307876587, 2.0672208794525693, 0.10141445456870965, 0.3529974211539541, 0.24406673918877328, 1.0935069514172417, 19.126189879008702, 38.54837996619088, 45.972165380205425, 45.57101460865566, 54.5729478427342, 54.573197977883474, 55.60252148764474, 48.3624255997794, 45.35644728796822, 41.07353251320975, 53.03810814448765, 53.78024871008736, 61.99100794110979, 36.40004212515694, 42.87243502480643, 87.61262920924595, 44.53400986535208, 43.277455942971365, 41.980974197387695, 43.22204405920846, 40.92324645178658, 36.854339667728965, 30.848427976880753, 28.613357509885514, 29.778304644993373, 43.139370918273926, 52.51537779399327, 58.96886811937605, 65.56320885249546, 58.77931431361607, 52.74159376961844, 44.50165210451399, 43.24258640834263, 42.87937280109951, 43.90028551646641, 46.71888133457729, 48.007476874760215, 47.951696736471995, 54.502017157418386, 53.01187522070748, 40.74403851372855, 26.154049566813878, 25.21561370577131, 26.032989365713938, 36.298264912196565, 47.33023248400007, 51.79530470711844, 42.89992904663086, 49.28986419950213, 50.56941318511963, 48.95632982254028, 48.6858503477914, 46.95910835266113, 48.90100131716047, 35.21833767209734, 31.591072286878312, 22.543095077787125, 25.659277030399867, 21.31480121612549, 30.53963613510132, 41.163723605019705, 45.11194365365164, 45.31445237568447, 45.939477579934255, 45.67464351654053, 43.380779130118235, 40.72883585521153, 30.750277723584855, 17.126944746289933, 14.290068217686244, 10.667749949863978, 19.325559752328054, 36.04967226300921, 47.48696299961635, 44.99241031919207, 38.70582267216274, 39.56657246180943, 41.3625602040972, 39.894819259643555, 40.56792252404349, 43.19279214314052, 39.01254047666277, 48.94530650547573, 41.5419522694179, 51.70696531023298, 68.30501665387834, 33.318060943058555, 35.73537049974714, 37.019491400037495, 40.490967750549316, 45.40320519038609, 43.15178387505667, 40.584306376320974, 39.15799406596592, 44.248466696058, 43.073512417929514, 46.285080977848594, 46.13636173520769, 47.79738766806466, 36.54312290464129, 34.09274687085833, 58.78952121734619, 53.49257244382586, 54.35311378751482, 45.61112308502197, 44.45774296351841, 44.65515170778547, 42.037775720868794, 42.67680154527937, 46.78498649597168, 51.73733588627407, 53.074461119515554, 55.625690255846294, 51.28395550591605, 45.59592737470354, 0.9890552248273576, 0.44679354237658636, 0.0670208376167076, 0.34424803778529167, 10.425556591578893, 42.63819735390799, 46.98743963241577, 51.0206743649074, 40.86103922980172, 35.04307631083897, 1.8684730870383126, 27.278869118009293, 17.842339958463395, 26.771615879876272, 31.854961395263672, 33.1165006501334, 32.85837854657854, 25.930194241659983, 48.825199944632395, 46.392771107809885, 39.27448756354195, 0.022251823118754795, 0.11017078613596303, 0.32598149510366575, 0.001074638105429975, 0.214884630803551, 0.06475147046148777, 0.06386666079717022, 0.03111807057367904, 0.3172929084726742, 0.026932625698723962, 0.057350641515638144, 0.03727688866534403, 0.0772124200261065, 0.13595130347779819, 0.1905688670064722, 0.3413342998496124, 0.1418412317122732, 0.06282929610460997, 9.742136120796204, 77.53915868486676, 45.26627704075405, 43.716446604047505, 34.01768895557949, 43.96004349844796, 37.344250202178955, 102.2409565789359, 27.444505487169536, 10.509626320430211, 19.22807652609689, 41.03508465630667, 58.072543552943635, 58.74658135005406, 55.76363631657192, 60.69421700068882, 41.53583090645926, 3.1473921750273024, 0.18035721353122167, 0.8232941680720874, 0.2920110465160438, 1.2606046135936464, 28.98301730837141, 44.81721149172102, 46.55391372953142, 50.39526353563581, 57.37091098512922, 58.174178327832905, 58.29656042371477, 50.515634128025596, 47.4767039843968, 41.75257996150425, 51.89566796166556, 52.67782667704991, 62.324215752737864, 42.1819612639291, 47.60695491518293, 78.28647218431745, 44.322788102286204, 46.506898743765696, 42.063157490321565, 44.76461015428816, 41.21934740883963, 38.27788312094552, 34.82429838180542, 33.699006353105815, 38.24662664958409, 53.05616651262556, 54.34823962620327, 60.03499971117292, 66.09953335353306, 56.81350564956665, 53.962861265454976, 47.88131148474557, 48.39413022994995, 48.490567752293174, 49.37002904074532, 49.40136194229126, 49.8065322467259, 49.5976277078901, 51.83597946166992, 58.430007525852744, 53.4503447668893, 38.852033615112305, 36.27643714632307, 40.02208941323416, 46.15335355486189, 51.12590135846819, 52.58232021331787, 47.05284997395107, 47.24909489495413, 46.197408608027864, 46.402852943965364, 49.07736396789551, 46.62161350250244, 49.78760187966483, 41.76751511437552, 39.97331305912563, 34.99351481028965, 35.46970960072109, 33.8142283303397, 39.76383876800537, 40.68475995744978, 43.69544219970703, 42.063091482434956, 41.08559806006295, 42.725650855473106, 43.92215844563076, 44.812226159232004, 41.47068459647042, 32.752286502293174, 27.484306505748204, 20.72550538608006, 31.00870554787772, 42.7896020753043, 49.17026138305664, 42.40153128760201, 42.26727819442749, 43.69544914790562, 45.132739612034385, 42.93653563090733, 43.66577686582293, 45.34074783325195, 42.83400106430054, 51.05805567332676, 44.174926962171284, 50.25518437794277, 68.19381768362862, 43.369877406529014, 38.203912598746165, 41.4888402393886, 41.21171828678676, 47.07064431054251, 43.796239716666086, 42.0149369921003, 42.59788390568325, 45.84197003500802, 44.392419474465505, 43.17142295837402, 45.54625817707607, 44.97549145562308, 40.02448654174805, 39.058436802455354, 58.83042526245117, 55.57591683523995, 56.82350410733904, 48.53950391496931, 46.84511273247855, 47.67132650102888, 45.34251962389265, 46.69316257749285, 48.692284379686626, 56.4189487184797, 56.68365771429879, 59.94204671042306, 55.868300506046836, 49.06997108459473, 2.0900352895259857, 0.5522928727524621, 0.028621590962367396, 0.43803476808326586, 13.392199414116995, 50.958088466099326, 51.581119537353516, 60.608510971069336, 46.150452681950156, 34.55939483642578, 4.092907164778028, 29.6260279246739, 21.532919066292898, 31.200642585754395, 32.618523257119314, 36.89438213620867, 41.59940692356655, 26.107696396963938, 52.7255608013698, 55.034999574933735, 44.380697863442556, 0.16871402758572782, 0.051069816042269976, 0.24698213274989808, 0.13246752827295236, 0.37527315584676607, 0.13940575239913805, 0.08589079470506736, 0.16409567397619995, 0.4565157549721854, 0.18640920306955064, 0.12981805258563586, 0.16086241390023912, 0.17731087628219808, 0.22422413607793196, 0.2266639308737857, 0.517608388194016, 0.23696220612951688, 0.24616457947662898, 14.623606068747383, 97.15146364484514, 51.41153138024466, 59.23041221073696, 51.122798987797324, 52.08210897445679, 53.39155953271048, 117.08035632542202, 28.216274908610753, 16.720429965427943, 21.302353518349783, 48.04854072843279, 66.9999851499285, 64.4507188796997, 62.62527424948556, 69.9123295375279, 47.180946963174, 3.019396586077554, 0.23423433250614575, 0.8969191802399499, 0.7762608347194535, 1.6817870416811533, 39.834623541150776, 50.13354573931013, 48.88240793773106, 52.35019132069179, 59.34024238586426, 61.10363960266113, 59.7251934323992, 53.5069899559021, 49.878859519958496, 46.17497634887695, 56.76393025262015, 57.940743173871724, 64.69866534641811, 41.76687240600586, 53.47674444743565, 65.50265530177525, 40.089431353977744, 46.16721868515015, 43.76454898289272, 46.57802745274135, 44.641005175454275, 41.640634059906006, 37.50971112932478, 40.72452449798584, 44.274004799979075, 53.1654304095677, 49.90285512379238, 52.635171685900005, 60.11008194514683, 57.312764985220774, 56.40163728169033, 51.6228677885873, 53.14749363490513, 52.2441930770874, 53.743402412959504, 53.371267318725586, 55.121108600071494, 52.852313314165386, 55.72046715872628, 60.88846778869629, 61.62311472211565, 46.84511620657784, 43.36050776072911, 48.84249748502459, 53.10052033833095, 56.099032810756135, 59.12916306086949, 48.0197126524789, 50.442316736493794, 51.2787686756679, 50.924525192805696, 55.04150308881487, 53.90783500671387, 59.224388122558594, 49.123110907418386, 46.26516396658761, 39.49357121331351, 41.47837625231062, 34.92299754279, 44.9993064062936, 51.03091253553118, 51.78631026404244, 50.8764888218471, 47.48235981804984, 49.17812326976231, 46.625330788748606, 45.72230468477522, 45.75577415738787, 38.679544585091726, 35.84916809626988, 26.1138333933694, 39.30126244681222, 53.99520860399519, 52.65682922090803, 48.590187549591064, 47.443710463387625, 46.64977107729231, 48.88664286477225, 44.88949012756348, 46.94060182571411, 52.140109062194824, 47.19356141771589, 54.74877200807844, 46.379923888615195, 49.816680090767996, 64.19674137660435, 52.850270543779644, 42.48174129213606, 42.594322953905376, 47.13100331170218, 50.28121927806309, 49.31154605320522, 47.335749353681294, 47.32824877330235, 45.62111112049648, 42.55065699986049, 46.057402406420024, 45.311148507254465, 50.82109430858067, 35.57970653261457, 39.02255630493164, 65.12696620396206, 58.27441998890468, 59.15086923326765, 51.66363981791905, 47.86618525641305, 48.93377249581473, 46.12294823782784, 48.48252868652344, 52.78169182368687, 58.57143810817173, 60.663957595825195, 60.8291996547154, 56.76539979662214, 50.0007517678397, 5.672444190297808, 0.67307134611266, 0.1663980790014778, 0.45155216274516924, 16.863357884543284, 58.20686265400478, 54.357800347464426, 63.09701524462019, 48.66220562798636, 44.44604914528983, 7.178112311022622, 35.7847443989345, 24.70679886000497, 39.50771427154541, 43.70076104572841, 43.562933104378835, 43.22067526408604, 34.870170388902935, 64.10637310573033, 57.937321186065674, 64.17467389787946, 0.34500300298844067, 0.15450699707227095, 0.3686991828892912, 0.18126438770975384, 0.3182952404022217, 0.25351086099232945, 0.269211401364633], [0.07678680893565927, 0.03845741067613874, 0.039887728568698676, 0.03117904712312988, 0.024564879447487847, 0.10239672900310584, 0.04733032473762121, 0.07135945837944746, 0.0896431544263448, 0.03888896234067423, 0.03896191503320422, 3.0391498804092407, 58.59448528289795, 46.16550595419747, 29.79869065965925, 22.69262031146458, 41.53812728609358, 20.92405710901533, 16.82137165750776, 36.55475418908255, 8.531320452690125, 21.311935084206716, 61.409124101911274, 55.27752297265189, 60.703951426914756, 56.87577540533883, 52.85832003184727, 47.02563040597098, 5.039991361754281, 0.09178178145417146, 0.5963818526693753, 0.20699514129332133, 0.13576984964311123, 24.199193000793457, 45.242802551814485, 41.08857536315918, 51.163696084703716, 51.50371660505022, 54.809009415762766, 53.4660998071943, 49.21825953892299, 40.82314722878592, 42.404091698782786, 41.97564492906843, 53.5793137550354, 55.47408751079014, 61.30968148367745, 34.03363854544503, 39.29782656260899, 62.03829738071987, 46.46105800356184, 47.69220583779471, 45.41709811346871, 40.08553341456822, 37.1838093485151, 41.47874798093523, 52.060496602739605, 62.60896682739258, 61.3937338420323, 54.00504377910069, 53.20002549035208, 50.366178376334055, 48.526278018951416, 48.3593544960022, 45.88869319643293, 44.2687589100429, 42.42024973460606, 46.666516235896516, 47.45423003605434, 51.523998396737234, 48.9510874067034, 59.502336910792756, 44.637451171875, 27.500838007245743, 21.51584039415632, 20.176298924854823, 22.282367399760656, 33.640377453395296, 46.41510609218052, 49.955213274274556, 45.36471217019217, 49.35366255896432, 51.252963066101074, 49.2509160723005, 44.22238663264683, 38.39937237330845, 30.93395335333688, 25.435079506465367, 19.970071179526194, 12.338199377059937, 13.962322558675494, 11.145821622439794, 13.678106495312282, 34.96481875010899, 46.293304170881, 47.970286641802105, 48.980478286743164, 47.60025685174124, 47.49156618118286, 38.49580989565168, 24.059697491782053, 10.481731040137154, 9.165952410016741, 8.763179234095983, 10.134247285979134, 24.435259784970963, 44.82650818143572, 51.25714588165283, 41.714757442474365, 41.275982175554546, 42.50667142868042, 40.60798583711897, 45.38768638883318, 42.15694774900164, 45.02865212304251, 42.13593292236328, 47.0259222303118, 42.12129654203142, 81.8654545375279, 77.88626984187535, 40.76538685389927, 41.44139099121094, 33.71209328515189, 38.6329152243478, 38.36629547391619, 44.69284915924072, 42.12316908155169, 47.15101064954485, 44.294790336063926, 50.36034536361694, 39.13523524148123, 62.569202286856516, 44.211585657937185, 32.61105741773333, 62.01426356179373, 51.81261961800711, 57.02491501399449, 46.33462858200073, 47.50488935198103, 44.01687976292202, 41.3743200302124, 42.51861538205828, 47.408955574035645, 50.234308515276226, 54.14556067330496, 51.350324698856895, 49.1818197114127, 36.485213143484934, 0.45086065413696425, 0.16449343120413168, 0.1410765770290579, 0.05385402164288929, 15.655366659164429, 51.284417561122346, 48.50012499945504, 50.2009710584368, 37.03419031415667, 38.62296887806484, 3.463621412004743, 22.403257369995117, 17.409736428941997, 28.231745072773524, 39.002177238464355, 41.16047184807913, 24.58948721204485, 44.354902676173616, 51.52190351486206, 55.60521738869803, 28.126561505453928, 0.3444452743445124, 0.07474019125636135, 0.17596193509442465, 0.24725816079548427, 0.18031386871423039, 0.11760564361299787, 0.10711483404572521, 0.04964963546288865, 0.07344797559614692, 0.13638420881969587, 0.04672102064692548, 0.03349522640928626, 0.11668899708560534, 0.03055234539455601, 0.08521356247365475, 0.07725788187235594, 0.05123836753357734, 0.1443174909800291, 3.4468703908579688, 63.675821031842915, 53.91561351503645, 27.30304363795689, 25.78112585203988, 50.15284783499581, 22.886600119727, 25.316522393907817, 35.909481934138704, 15.56558724812099, 18.36629319190979, 68.18728637695312, 61.125380516052246, 64.10522665296281, 58.12602036339896, 56.8660375050136, 49.86395910808018, 5.575895931039538, 0.15312480766858372, 0.8622941353491375, 0.236991464559521, 0.11799388777996812, 27.7992388180324, 50.11511564254761, 45.11902734211513, 54.713478633335654, 55.60459552492414, 59.4034640448434, 56.80046040671212, 52.372376918792725, 43.16500282287598, 46.615947246551514, 43.933209555489675, 56.19494921820504, 60.014995847429546, 63.40396581377302, 38.53707872118269, 44.91796037128994, 57.33862618037632, 47.34769330705915, 48.99862003326416, 44.43397317613874, 43.36337389264788, 41.4096029826573, 48.32066345214844, 55.08825751713344, 57.182131903512136, 58.44131919315883, 54.129861218588694, 54.40565953935896, 53.430545875004356, 53.71835763113839, 56.58334657124111, 54.96365894590105, 49.58793149675642, 44.97836453574044, 49.99044758932931, 52.47244487489973, 53.594658851623535, 49.704695974077495, 57.670496463775635, 51.87503181185041, 41.99700716563633, 30.436625616891043, 27.44103138787406, 32.44704518999372, 45.006469999040874, 49.15410334723336, 54.3274575642177, 45.69445630482265, 49.48319782529558, 48.503526142665315, 52.64015007019043, 50.406213896615164, 47.82245676858084, 46.22931473595755, 41.776301111493794, 38.367956093379426, 29.765151705060685, 30.946623393467494, 25.8507468019213, 29.197077410561697, 43.52712556294033, 48.547904287065776, 47.35852207456316, 45.851297991616384, 47.46576751981463, 46.091035161699565, 42.785763195582796, 36.170494488307405, 25.107767241341726, 20.30539992877415, 12.807675259453909, 21.092853171484812, 35.92852347237723, 48.07771621431623, 46.896588461739675, 44.29298727852957, 47.55273812157767, 48.79250519616263, 44.55669225965227, 46.25812891551426, 45.8382944379534, 45.56420537403652, 46.432935169764924, 49.909789425986155, 43.39240346636091, 67.23771776471818, 73.13052667890275, 41.97568661825997, 42.123047488076345, 37.949896880558555, 40.805203505924766, 41.92597573144095, 44.10075494221279, 44.17761244092669, 45.031657218933105, 40.82423462186541, 47.92685692650931, 35.330123765128, 55.31309427533831, 48.518259797777446, 37.18682139260428, 63.487260818481445, 53.266314779009136, 58.89013808114188, 48.51715850830078, 49.36172941752842, 44.944943700517925, 43.80372987474714, 46.9708924974714, 50.17755215508597, 53.51337187630789, 58.581978525434224, 55.137336117880686, 53.00498260770525, 39.21845381600516, 1.175659628851073, 0.37849413443888935, 0.36441358285290854, 0.08249045895146472, 20.87989956992013, 61.54108428955078, 57.479587759290425, 56.36664962768555, 37.650478158678325, 44.79089171545846, 4.9166052511760165, 31.272552967071533, 22.614161252975464, 32.028954710279194, 35.4898350579398, 47.62049000603812, 28.870814323425293, 42.46681308746338, 51.067644187382285, 62.00179154532296, 29.92814949580601, 0.30770037748983925, 0.037577920726367404, 0.05768656384732042, 0.09859569796494075, 0.2175382184130805, 0.08511381104056324, 0.07866542134433985, 0.22100022621452808, 0.2993563509413174, 0.2137357217392751, 0.13862576282450131, 0.09607548319867679, 0.1711069763238941, 0.13306964667780058, 0.14918440553758824, 0.16031821524458273, 0.131762543959277, 0.23617363987224443, 5.358762553759983, 81.4297399520874, 57.737338134220664, 44.558213915143696, 32.32475342069353, 58.788854190281455, 28.64887843813215, 20.477192401885986, 43.323685782296316, 15.706142357417516, 28.941477503095353, 73.24443544660295, 64.79948370797294, 71.21320601872036, 65.74261828831264, 63.563656261989046, 55.2049594606672, 7.447962539536612, 0.199416651523539, 0.9973993599414825, 0.5555175425750869, 0.3707166574895382, 34.05715124947684, 51.537102699279785, 46.37353502001081, 56.27500636237008, 55.665173394339426, 62.16544246673584, 59.933959007263184, 52.92261866160801, 44.88994870867048, 47.90743671144758, 47.57628556660244, 55.50252996172224, 62.30845723833357, 64.410370690482, 43.67484426498413, 58.60007163456508, 57.66050148010254, 48.00456557955061, 47.67992489678519, 46.94747012002127, 44.28261014393398, 45.02983331680298, 50.7496668270656, 53.97255400248936, 51.38228988647461, 54.19879082271031, 55.18964910507202, 55.413558278764995, 54.58008016858782, 57.10132782799857, 59.12505667550223, 56.01878111703055, 53.72964150565011, 49.249189444950645, 53.83601147787911, 53.596458435058594, 54.216487884521484, 56.21861130850655, 60.516593251909526, 59.78364862714495, 50.10286944253104, 40.92554630552019, 37.67933750152588, 44.60555894034249, 54.362549441201345, 56.3898218699864, 58.100138323647634, 50.890454701014924, 53.196005957467214, 55.36803020749773, 57.809509072984966, 57.42528063910348, 55.68858882359096, 54.53616060529436, 49.17327690124512, 47.76687117985317, 35.9664432661874, 36.356963293892996, 30.93506853921073, 34.250286851610454, 53.575235162462505, 58.40442425864083, 56.934300082070486, 53.14817803246634, 53.90852982657296, 52.34661299841744, 45.909395354134695, 45.49978167670113, 35.87177406038557, 29.99080487659999, 21.761209079197474, 26.94243734223502, 45.42365721293858, 53.630066871643066, 50.52341958454677, 45.90690442493984, 49.170949254717144, 49.93621342522757, 46.83249132973807, 49.34292759214129, 51.66418525150844, 49.63952881949288, 49.340224742889404, 52.14440999712263, 46.12490068163191, 61.20005975450788, 73.8115543637957, 47.55255399431501, 41.15575054713658, 41.24453462873186, 42.91899142946516, 44.42425612040928, 44.03190524237496, 42.09328140531267, 45.90675156457083, 41.92577770778111, 49.75133228302002, 43.799745082855225, 48.60094336100987, 43.475062710898264, 37.74121815817696, 65.77066816602434, 58.274517263684956, 60.100215503147666, 50.01075369971139, 50.75666018894741, 46.922769274030415, 47.08301557813372, 48.50709056854248, 51.54209497996739, 54.821519647325786, 59.40561103820801, 58.41801493508475, 54.58809144156319, 44.531904561179026, 2.3160621438707625, 0.8618974366358348, 0.6167684644460678, 0.24017316954476492, 22.651120458330425, 68.40800285339355, 56.91062756947109, 61.53542150769915, 42.93197413853237, 50.83685629708426, 8.94141789845058, 31.60543073926653, 25.35125991276332, 40.53385898045131, 52.02036728177752, 55.036163398197715, 33.01329558236258, 55.37868179593767, 60.64185537610735, 68.082702091762, 46.22103248323713, 0.2918623387813568, 0.14012520307941095, 0.28109776069011005, 0.2707516487155642, 0.2829260868685586, 0.15667891981346266, 0.20484202754284653], [0.05448952057797994, 0.14672263977783068, 0.059450530979250155, 0.06366065756550857, 0.1636668262737138, 0.07012683844992093, 0.02154582609156413, 0.061575960500964096, 0.04264050781992929, 0.0067719045910052955, 0.07013563226376261, 0.5095410953674997, 50.77242912564959, 47.953249658857075, 38.43145915440151, 28.301793336868286, 32.848852566310335, 36.67446122850691, 30.385980197361537, 37.84538555145264, 26.95638758795602, 1.7230080983468463, 32.86495501654488, 60.034165927342, 56.104077202933176, 55.60220881870815, 54.42447873524257, 42.17183426448277, 5.287136614322662, 0.12495838478207588, 0.08061475745801415, 0.10057215512331043, 0.060142433137765954, 19.446097101484025, 50.573345865522114, 52.359050273895264, 56.26323611395699, 54.20910194941929, 54.360388551439556, 52.72918776103428, 45.37546798161098, 42.723945072719026, 43.14564514160156, 42.29646062850952, 48.29470498221261, 53.315765108381, 53.4736316544669, 51.909901346479145, 24.41046166419983, 35.46948725836617, 46.141611099243164, 47.480848584856304, 52.29396302359444, 52.625180176326204, 59.43859413691929, 58.76495933532715, 52.778968129839214, 46.534691538129536, 47.91672992706299, 50.06025961467198, 52.789421694619314, 49.59704058510916, 51.48521702630179, 46.883536270686555, 47.24222660064697, 44.91203703199114, 45.968983105250764, 47.21989161627633, 48.11979450498308, 50.885507583618164, 52.23915215900966, 52.276387555258616, 35.836491107940674, 23.182423148836406, 15.598235096250262, 17.60923136983599, 22.532775265829905, 32.56598792757307, 44.232996531895225, 48.19305631092617, 47.528794629233225, 45.384319986615864, 44.74337298529488, 41.567966324942454, 31.563168321337017, 26.294990301132202, 18.212541716439382, 15.657119342258998, 11.432995012828282, 10.748545340129308, 7.916554263659886, 4.528961777687073, 5.665870760168348, 17.55383859361921, 38.72432919910976, 42.338379110608784, 44.490760803222656, 45.432787145887104, 43.655563013894216, 42.00271511077881, 23.6385498046875, 12.919375368527003, 6.542238797460284, 8.137037975447518, 7.709801929337638, 14.712310246058873, 35.19771194458008, 47.930410930088584, 48.384503500802175, 40.58739832469395, 41.88765641621181, 44.626375743321006, 44.28569861820766, 41.97325127465384, 41.77655472074236, 44.839973790305, 43.896380628858296, 41.9691344669887, 51.90702131816319, 76.11135946001325, 49.75239883150373, 39.557574544634136, 42.74705130713326, 42.31728090558733, 41.34636742728097, 39.84940930775234, 44.3494552884783, 41.39375066757202, 43.50193139484951, 39.194440841674805, 66.07609707968575, 85.50038378579276, 37.70151962552752, 41.27841404506138, 58.90794631413051, 54.61555767059326, 53.52034091949463, 45.68956824711391, 42.84123066493443, 44.4680540902274, 47.08297388894217, 41.93883684703282, 46.915574414389475, 47.87403672082083, 53.7548565183367, 47.50553553444998, 54.48416028703962, 25.807529006685527, 0.4161529093980789, 0.11931447977466242, 0.02594566428368645, 0.3316560834646225, 30.717836584363663, 52.71230016435896, 46.98749869210379, 46.892892020089285, 64.87708118983677, 25.112300940922328, 1.5461209671837943, 34.47976153237479, 16.60328507423401, 31.180513654436382, 44.876764501844136, 39.64797755650112, 32.4380646433149, 57.9892589705331, 40.03158760070801, 51.5858929497855, 12.92220936502729, 0.5318051863993917, 0.195418777476464, 0.06911052191363913, 0.163980295881629, 0.19040960126689502, 0.17439901110317024, 0.04509652638807893, 0.047287889157554934, 0.07558076722281319, 0.07277689089200326, 0.2793567483978612, 0.09717694230909858, 0.05927116024707045, 0.06580430575247322, 0.06348797718861274, 0.008249477782685841, 0.15879593550094537, 0.028221312976841415, 0.45174071405615124, 55.68919679096767, 54.38187238148281, 38.24117578778948, 30.291015693119594, 48.307044982910156, 29.531931945255824, 36.2175372668675, 36.20786884852818, 34.62775468826294, 2.3359070675713673, 29.432468482426234, 68.07007026672363, 59.87559413909912, 62.870232990809846, 57.135405267987935, 46.75088473728725, 5.4382738300732205, 0.13209305836686067, 0.29586767671363695, 0.13305469176598958, 0.05808963400444814, 24.65049934387207, 56.37478596823556, 55.95053243637085, 61.74739715031215, 60.07239491598946, 58.26657894679478, 55.95442342758179, 48.33535541806902, 47.99468524115426, 47.69680207116263, 46.334225586482454, 49.78236641202654, 54.829374585832866, 57.293386459350586, 56.9165370123727, 33.96360765184675, 40.6016595023019, 47.796974250248496, 50.93725429262434, 53.15435150691441, 55.17814636230469, 57.479559966496055, 55.43907553809029, 45.33142335074288, 44.70124953133719, 51.09320313589913, 54.521385260990684, 56.91513695035662, 54.64199904033116, 54.04203946249825, 52.70429583958217, 50.51311193193708, 48.05216073989868, 47.35866798673357, 50.0501777785165, 52.81142316545759, 51.91057184764317, 51.2268065725054, 57.43646029063633, 46.064100469861714, 35.24216651916504, 30.365747043064662, 27.310655389513286, 31.92664248602731, 42.60598203114101, 49.54163564954485, 49.37923887797764, 44.93255506243025, 47.64916869572231, 49.68820789882115, 49.471399784088135, 44.7294487953186, 42.17653819492885, 34.54922614778791, 35.55588810784476, 28.879805292401993, 24.981511524745397, 23.107160261699132, 24.666183165141515, 19.48898138318743, 35.043072836739675, 48.90506253923689, 48.444400446755544, 49.92511715207781, 46.30686705453055, 45.60047149658203, 43.40723787035261, 35.85646023069109, 22.234607219696045, 16.927494968686783, 11.123769777161733, 13.563748700278145, 25.652401787894114, 42.33251483099801, 50.84140041896275, 44.881332942417686, 48.68983513968331, 47.41839122772217, 49.13284880774361, 46.4216582434518, 44.13277571541922, 43.51663030896868, 47.738251549857004, 47.16888836451939, 44.34018291745867, 45.62905291148594, 62.77821799686977, 52.538299901144846, 42.53132711138044, 40.419509002140586, 42.92471327100481, 41.4899936403547, 38.66574198859078, 39.567451408931184, 41.247675214494976, 43.79620844977242, 39.713829108646934, 53.727848870413645, 81.8265654700143, 44.46080017089844, 42.32830074855259, 59.86629050118582, 56.945455414908274, 56.86123282568795, 48.72848449434553, 44.335162843976704, 48.445960317339214, 50.58787454877581, 44.92239332199097, 51.05976840427944, 52.09298637935093, 57.96464497702462, 51.79552704947335, 61.007031849452424, 30.095521177564347, 0.8806551301053592, 0.09705158974975348, 0.02910239069855639, 1.4026425118957246, 36.110024315970286, 61.59851809910366, 53.561370032174246, 49.94382517678397, 69.15781770433698, 24.49098607472011, 3.5273183711937497, 39.63381365367344, 20.508629526410783, 34.11257355553763, 31.526137896946498, 45.07544824055263, 35.74399668829781, 49.896438462393625, 44.021343980516704, 61.014605385916575, 11.27778788975307, 0.4322309052305562, 0.057314258467938216, 0.10175431240350008, 0.030780390836298466, 0.1881409872855459, 0.0887194172080074, 0.12774154543876648, 0.14027400580900057, 0.20076453419668333, 0.1649068897323949, 0.21677581646612712, 0.23594915334667477, 0.15506674775055476, 0.21562872587570123, 0.4007862353963511, 0.11446588566260678, 0.2647586374410561, 0.08353684137442283, 1.0399212496621268, 72.54132638658795, 59.88143062591553, 50.0621634210859, 39.546245506831575, 48.94201305934361, 51.30376829419817, 35.71829530170986, 44.89743539265224, 38.54614612034389, 5.870205555643354, 41.54877887453352, 69.94281823294503, 64.30732890537807, 66.36394705091203, 62.461032731192454, 49.17549337659563, 6.344761873994555, 0.32767330003636225, 0.4424316207213061, 0.5979604508195604, 0.1350690722465515, 32.53478009360177, 56.547747475760325, 59.81648581368582, 65.11963585444859, 61.2194174357823, 58.502511978149414, 57.4136597769601, 49.656503268650596, 48.79043810708182, 48.98033932277134, 46.01655742100307, 53.09339148657662, 56.370009081704275, 58.513642992292134, 57.51055588041033, 37.61830105100359, 48.97287000928606, 47.870326382773264, 51.55488313947405, 51.67463534218924, 52.907391684395925, 53.6572516986302, 54.32277447836739, 46.06223835263933, 46.69643170492989, 51.694173676627024, 56.664102009364534, 60.446069036211284, 56.38108103615897, 58.48482881273542, 56.966772488185335, 54.726694107055664, 52.92374079568045, 52.81730828966413, 53.61958203996931, 56.27450261797224, 54.619830812726704, 55.2678337097168, 56.94344391141619, 54.52006162915911, 46.00089965547834, 39.580065863473074, 40.32878289903913, 46.70431791033064, 50.4601388658796, 56.3763701575143, 54.21454586301531, 50.720574719565256, 53.49299280984061, 52.897598198481965, 54.19998243876866, 54.22388424192156, 51.33146381378174, 44.14164856501988, 44.66075890404837, 35.70653894969395, 34.41893005371094, 28.86201442990984, 31.45675665991647, 23.030228069850377, 39.52592202595302, 58.858169419424875, 53.321900367736816, 55.6398298399789, 50.5425306047712, 49.20806653159005, 51.35311440059117, 45.05071265356881, 35.47718586240496, 29.885216576712473, 21.143359627042496, 23.59376345361982, 35.8113386290414, 51.49230071476528, 53.32246317182268, 48.31882217952183, 49.124378953661235, 51.9453684261867, 50.602226052965435, 49.17572266714913, 48.1443008014134, 46.913205078669954, 51.54310941696167, 48.52401638031006, 47.921812534332275, 49.15710844312395, 59.20644787379673, 55.368735449654714, 42.47465760367257, 42.16385773250035, 43.780828612191335, 42.31058979034424, 41.317355224064414, 41.6878262247358, 44.21897506713867, 45.891833782196045, 44.10578196389334, 43.01674216134207, 72.69092805044991, 55.734262807028635, 43.89494929994856, 63.257789611816406, 60.275157247270855, 59.97880268096924, 49.86698504856655, 46.48836442402431, 48.41549594061715, 50.439718110220774, 46.903626986912315, 53.315330845969065, 52.12409346444266, 59.92364093235561, 53.18120282036917, 60.80830642155239, 33.4847343308585, 1.1228611362831933, 0.530443828020777, 0.3382995384080069, 1.114674529858998, 38.95220232009888, 63.829487391880576, 57.05181149074009, 54.39940268652779, 72.86619635990688, 33.22174154009138, 4.96318336895534, 44.360561983925955, 21.714586666652135, 42.736542156764436, 57.38051339558193, 55.202333041599815, 40.46597508021763, 67.1391019821167, 51.570579120091026, 70.904344694955, 21.658745731626237, 0.6207605302333832, 0.16646232269704342, 0.2994436105447156, 0.2258829099259206, 0.4808608314820698, 0.24830454321844236, 0.2800369661833559], [0.18210685678890773, 0.2800283895007202, 0.030190428386309316, 0.04733427041875465, 0.17468035886330263, 0.032508035988679955, 0.07079880524958883, 0.06319288909435272, 0.12336020411125251, 0.03894702118954488, 0.3884175733796188, 0.05987838123525892, 35.27833536693028, 55.69965730394636, 44.9465000970023, 29.274907657078334, 26.555985484804424, 38.97000013078962, 28.67814425059727, 28.46934219769069, 58.361116136823384, 9.278363840920584, 9.016126666750226, 50.68494783129011, 50.82885544640677, 61.94567094530378, 51.05208369663784, 45.861126218523296, 6.244848949568612, 0.13009040297142097, 0.19473002372043474, 0.18860819935798645, 0.16793846205941268, 18.251008680888585, 61.83010850633894, 53.892455169132774, 57.555896350315635, 52.647494316101074, 52.325007574898855, 43.86689942223685, 43.46582508087158, 46.67391606739589, 50.39024346215384, 47.4212121963501, 44.24363422393799, 47.638419832502095, 54.00335884094238, 56.342344829014365, 56.20846346446446, 50.98122596740723, 47.798989227839876, 42.67952871322632, 44.35176903860909, 45.213501998356406, 39.82992308480399, 39.42305394581386, 41.21452535901751, 44.550435406821116, 48.884117194584434, 52.97072451455252, 52.775462763650076, 49.962859766823904, 47.5029091153826, 47.74563748495919, 47.98828247615269, 46.6473913192749, 46.13951621736799, 48.37521723338536, 50.30208819253104, 51.72964423043387, 53.658894947596956, 45.60488012858799, 33.59862225396292, 21.48907767023359, 20.318818637302943, 18.820924248014176, 24.72661338533674, 32.606193678719656, 43.530630929129465, 44.603043692452566, 45.30721582685198, 41.911308084215435, 40.121872493198936, 29.7333984375, 20.570091554096766, 17.68789366313389, 11.63739972455161, 10.942020535469055, 9.702388082231794, 9.392144066946846, 4.312847180025918, 7.863324982779367, 9.153674943106514, 2.652411626917975, 28.626307215009415, 33.28148215157645, 41.27539505277361, 41.175799574170796, 41.84317404883248, 40.100340025765554, 27.931860821587698, 20.710438217435563, 10.65134004184178, 7.93982812336513, 9.440434915678841, 12.7365882396698, 25.48475738934108, 40.5338694027492, 48.87212460381644, 44.42396429606846, 45.384542328970774, 42.2446722303118, 43.3390656198774, 42.93231807436262, 44.326227460588726, 48.28735031400408, 46.52042688642229, 43.161622524261475, 41.3942995752607, 53.49104036603655, 51.52281372887747, 38.58976691109793, 41.23832293919155, 40.3152825491769, 42.228378704616, 40.8011040687561, 38.80656112943377, 42.034242561885286, 42.31731217248099, 65.97299970899309, 88.54061671665737, 34.04958118711199, 36.8251051221575, 48.76526825768607, 56.734504631587434, 51.10023123877389, 52.01204333986555, 46.202161175864084, 48.09307173320225, 46.42039714540754, 49.869826861790244, 44.99987268447876, 48.536832332611084, 48.49191917691912, 54.560437611171174, 49.51330784388951, 57.63317421504429, 19.236277137483867, 0.321369112602302, 0.20105790559734615, 0.18171421571501664, 6.432925394603184, 48.658891337258474, 50.42367124557495, 50.62581171308245, 51.90719502312796, 58.76103360312325, 11.413335953439985, 8.803170459611074, 38.57509231567383, 11.616545575005667, 29.296971661703928, 35.14264052254813, 44.69366209847586, 23.96902871131897, 42.34258277075631, 41.67933900015694, 53.58565746034895, 3.450638702937535, 0.14939815763916287, 0.10990602177168642, 0.09224828106484242, 0.26045436412096024, 0.10957442170807294, 0.044290728734007904, 0.050220208774719916, 0.11391325960201876, 0.15786151135606424, 0.14972609361367567, 0.013628330048439758, 0.17125294277710573, 0.0416756004893354, 0.08122729816074882, 0.27723222811307224, 0.06558523393635239, 0.06860002609235899, 0.12305128068796226, 0.038829644809343984, 38.64559916087559, 63.272853306361604, 48.59518330437796, 25.304726089750016, 33.06114435195923, 40.74878065926688, 28.30137470790318, 30.979901790618896, 55.49462638582502, 16.228898763656616, 10.472813027245657, 51.72166075025286, 57.32574074608939, 66.7859250477382, 53.6056752204895, 48.63443715231759, 7.233466003622327, 0.060916010556476455, 0.39705863541790415, 0.31581782762493404, 0.226894809199231, 20.91516167776925, 65.46878283364433, 57.006123610905235, 60.56152030399868, 57.37420095716204, 56.82446295874459, 49.008760929107666, 46.610072544642854, 50.66261632101876, 56.87102631160191, 51.83537149429321, 48.461465222494944, 51.4297182900565, 57.93452453613281, 57.80593769890921, 61.1071970803397, 57.23827682222639, 47.897740500313894, 44.227378913334434, 46.48896891730172, 43.95522492272513, 40.84372431891305, 40.639985765729634, 43.78083208629063, 51.23691272735596, 50.95239094325474, 56.09354373386928, 55.85408101763044, 54.09268488202776, 49.55964885439192, 51.330817631312776, 51.0267470904759, 47.25385093688965, 47.252089568546836, 49.367211546216694, 50.84507254191807, 53.176627431597026, 58.539643151419504, 52.43307638168335, 43.75347008023943, 33.36902945382254, 26.82657265663147, 29.352164677211217, 34.82187693459647, 41.33702557427542, 48.47594179425921, 49.85231045314244, 47.6619290624346, 49.3655161857605, 48.60531725202288, 42.724632944379536, 40.14844587871006, 34.29013477052961, 29.455425330570765, 24.828962087631226, 20.476733820778982, 18.224023614610942, 15.360731772014073, 21.090238911764963, 14.660711186272756, 23.491360902786255, 46.589314801352366, 45.14198419025966, 48.857519490378245, 46.91597740990775, 47.291760308401926, 43.35257639203753, 36.79640906197684, 27.373269081115723, 20.493802070617676, 11.813258630888802, 13.169691170964922, 18.855257034301758, 35.65180104119437, 46.12923983165196, 48.218007292066304, 46.310122285570415, 47.46758099964687, 44.90930986404419, 47.18523400170462, 42.71829618726458, 47.36889573505947, 50.97741488048008, 48.538822991507395, 45.69132614135742, 44.20152466637747, 47.00618587221418, 47.99746799468994, 41.61576298304966, 41.892905780247276, 40.772050176348, 40.66649661745344, 39.54970570972988, 39.40086834771292, 41.655673435756135, 44.06903294154576, 54.94881064551217, 77.1503791809082, 39.49274090358189, 40.00291933332171, 51.361354964120046, 56.953953061785015, 53.870127132960725, 53.485412325177876, 47.62666000638689, 50.29775946480887, 51.58644880567278, 53.27523626599993, 49.33957856042044, 51.46604694638933, 52.56124980109078, 58.03462028503418, 52.938589096069336, 60.881422315325054, 21.81828679357256, 0.7028238581759589, 0.3056878697659288, 0.2591042694236551, 9.980308209146772, 55.108591420309885, 56.037471771240234, 58.04808241980416, 58.87435177394322, 60.826045172555105, 15.442961965288434, 10.71470500741686, 42.824085984911235, 15.928842544555664, 34.25402498245239, 30.34897756576538, 52.98703193664551, 25.31352424621582, 39.5999550819397, 46.984715938568115, 58.025191579546245, 3.3584061435290744, 0.20398600133402006, 0.05503940874976771, 0.11858806732509818, 0.1292285956442356, 0.0422121215212558, 0.04582782428977745, 0.03730731078290513, 0.2550326521907534, 0.3059845252760819, 0.2945658937096596, 0.14662194518106325, 0.4303135009748595, 0.1142012570053339, 0.17558932437428407, 0.2943541636424405, 0.33842683157750536, 0.1520880197307893, 0.5029692394392831, 0.20189664273389749, 52.986754008701865, 73.08771187918526, 59.55733190264021, 40.96169430868966, 38.28954914637974, 57.03485093797956, 31.7044495173863, 36.866655349731445, 63.771775654384065, 15.751699958528791, 13.892820596694946, 60.824280330113, 59.39887823377337, 71.71461582183838, 57.19990192140852, 54.71912751879011, 7.138514527252742, 0.16025022603571415, 0.6856684301580701, 0.7661558198077338, 0.3306923737483365, 25.870048897606985, 64.68563747406006, 58.47865186418806, 62.409949575151714, 57.99797895976475, 57.06024660382952, 49.73645618983677, 45.50075442450387, 51.07322359085083, 53.564833709171836, 52.458027362823486, 47.53635079520089, 53.21329654966082, 58.29280144827706, 61.71937506539481, 60.67460223606655, 51.87228379930769, 48.0045690536499, 45.49565444673811, 45.70295395169939, 45.23932497841971, 41.255307810647146, 42.5345059122358, 45.60913242612566, 53.30644757407052, 53.566859109061106, 62.01017107282366, 57.74363667624337, 58.352257183619905, 56.61424173627581, 59.274046897888184, 55.89302914483206, 52.8683636529105, 53.86200468880789, 54.95831230708531, 55.125235830034526, 54.78902292251587, 59.378457478114534, 54.75784635543823, 53.215909072331016, 44.62750135149275, 42.905088084084646, 44.816120624542236, 48.94210686002459, 49.85111536298479, 55.97079685756138, 55.85757596152169, 54.19035570962088, 55.053228173937114, 53.52384281158447, 48.98195130484444, 45.93479796818325, 44.2002739906311, 38.98360122953142, 37.15179899760655, 29.49176788330078, 29.85221610750471, 23.38600536755153, 31.603575570242747, 20.828698294503347, 27.03336841719491, 59.90955693381173, 55.83499779020037, 58.33715179988316, 52.15515538624355, 52.86155441829136, 48.26368127550398, 45.71121188572475, 44.67426272800991, 38.76275621141706, 27.43813920021057, 24.318877458572388, 28.024393456322805, 42.82109131131853, 49.59319128308977, 53.66021163122994, 49.671181338174, 53.113315446036204, 49.910157680511475, 51.04879719870431, 47.16477155685425, 51.275079182216096, 53.907491070883616, 53.28376170567104, 48.86025013242449, 49.290732724326, 47.72950724193028, 47.51376567568098, 41.660304410117014, 43.02218607493809, 41.49487822396414, 40.74566439219883, 42.4883177621024, 40.94676610401699, 42.86244351523263, 42.38522733960833, 45.50854682922363, 81.74411119733537, 62.91367312840053, 42.107799666268484, 53.11158881868635, 58.65945093972342, 56.605612073625835, 56.75258037022182, 49.65459598813738, 51.32729489462716, 51.72899109976632, 53.55796194076538, 49.044363498687744, 53.142848764147075, 54.47794164930071, 58.017131669180735, 54.07483843394688, 63.63413878849575, 25.6838093825749, 0.7667986367430005, 0.4800394241298948, 1.1297663428953715, 9.129504765783038, 58.881209645952495, 59.776304381234304, 59.38388402121407, 61.54094532557896, 69.64766570499965, 18.521475996289933, 13.990324667521886, 48.73289312635149, 16.190402269363403, 42.982056753976, 48.169359479631694, 61.24636254991804, 33.536755493709016, 55.63676915849958, 50.51043687547956, 72.59221499306815, 7.882910217557635, 0.356815401996885, 0.1938122236835105, 0.23143692261406354, 0.28488518031580107, 0.1788437683135271, 0.1215582729450294, 0.16484625584312848], [0.14618912126336778, 0.24828041451317923, 0.2473557341311659, 0.17734578012355737, 0.0685880770906806, 0.1242108970348324, 0.029269015150410787, 0.05979608850819724, 0.09671703127345868, 0.08570674208125897, 0.1971264872699976, 0.06858625183148043, 17.41216308729989, 61.14262594495501, 39.20168433870588, 39.030876772744314, 38.43124376024519, 34.050084931509836, 32.93789373125349, 27.774901015417917, 86.32938725607735, 69.26730741773332, 8.756951911108834, 54.3479790687561, 45.35142026628767, 57.77515370505196, 54.37771388462612, 51.93743705749512, 10.196136627878461, 0.12155745870300702, 0.1867828315922192, 0.12670360399144037, 0.08653198994163956, 16.759042842047556, 62.84362833840506, 53.49007109233311, 57.79936817714146, 53.24549102783203, 50.426127433776855, 41.36078493935721, 47.43393087387085, 56.72183459145682, 57.6469281741551, 56.00402661732265, 48.14448145457676, 44.85832398278372, 49.384060927799766, 52.54026276724679, 50.84196669714791, 55.74852051053728, 58.495230266026084, 49.71504878997803, 44.56917469842093, 42.43861034938267, 41.617145674569265, 43.22946126120431, 50.26466519492013, 47.92209741047451, 48.16985974993025, 46.554118701389854, 51.29462446485247, 51.10608509608677, 49.257638454437256, 48.89358064106533, 48.79580559049334, 45.38801295416695, 46.96557365145002, 47.925901549203054, 50.095313276563374, 54.64197472163609, 51.76311370304653, 41.04396792820522, 28.444874116352626, 22.65599635669163, 22.544564621789114, 24.06990439551217, 29.625829901014054, 36.32273299353463, 39.7810320854187, 38.91425820759365, 39.41083206449236, 39.17078569957188, 33.057110922677175, 23.020208767482213, 15.893795830862862, 14.217723573957171, 10.893846069063459, 9.787616423198156, 8.42003549848284, 9.071675777435303, 3.3883385487965176, 6.319779625960758, 12.417167391095843, 6.09068318775722, 22.45895412990025, 23.433070727757045, 31.605861527579172, 37.31231280735561, 36.61084699630737, 36.544040066855295, 33.15836007254464, 28.332704135349818, 16.731508868081228, 10.153621469225202, 12.270811404500689, 13.02924462727138, 19.58585316794259, 31.777054718562535, 44.79978540965489, 48.197496209825786, 44.76762567247663, 45.674358640398296, 46.39703730174473, 40.6562237058367, 41.54689243861607, 44.14442089625767, 48.51380252838135, 43.926640033721924, 46.65287692206246, 40.52748053414481, 36.94873441968645, 37.15247644696917, 38.20722688947405, 40.47671004704067, 40.300305707114084, 39.520537172045024, 37.896927288600374, 42.00724881035941, 60.474883215767996, 46.980692931583945, 19.753626108169556, 28.610399314335414, 52.39656012398856, 53.78686686924526, 56.11894982201712, 48.00585099628994, 50.933068002973286, 43.222617285592214, 51.724325384412495, 48.775607177189414, 53.414245401109966, 50.28866079875401, 53.18121324266706, 45.758789675576345, 59.59562342507498, 50.073488984789165, 59.96576091221401, 8.119058643068586, 0.5284094171864646, 0.2640143930912018, 0.4423060646014554, 21.425180298941477, 45.498593534742085, 35.593814849853516, 53.50953299658639, 51.81099721363613, 56.81317213603428, 12.770671759332929, 10.658084137099129, 28.179673535483225, 16.155331236975535, 34.99873638153076, 25.965862819126674, 42.323534284319194, 25.198931080954416, 44.75823170798165, 43.00830357415335, 45.98500912530081, 0.6180645748972893, 0.3866744983409132, 0.0741399320374642, 0.027634234300681522, 0.02409832555401538, 0.08946877771190234, 0.10073566849210433, 0.04266235664752977, 0.07972249069384166, 0.07816961580621344, 0.028559281091604913, 0.06462341733276844, 0.12307779783649103, 0.12152164562472276, 0.05924612230488232, 0.04776164570025035, 0.11009969602205924, 0.0029351626788931234, 0.09491218919200556, 0.07749104007546391, 21.957089219774517, 70.30454839978898, 42.78411647251674, 31.42777224949428, 45.099332673209055, 36.69748061043875, 25.711558750697545, 37.42572130475725, 81.72558729989188, 71.38723060062954, 11.32303716455187, 55.0590056010655, 49.92194182532174, 64.1399051121303, 55.71201467514038, 57.65312944139753, 11.038600495883397, 0.024577652869213904, 0.3215720217142786, 0.15390690070177826, 0.164665765528168, 20.628313984189713, 66.65567411695207, 56.55248267310006, 61.43506172725132, 59.04236616407122, 53.953085150037495, 44.32275683539254, 52.26881749289376, 59.05722836085728, 60.286580085754395, 59.34041609082903, 52.269182273319785, 47.07945810045515, 52.15328632082258, 58.153330257960725, 54.92237969807216, 59.27250439780099, 61.36501693725586, 51.6451541355678, 45.68310989652361, 43.8000681740897, 44.44139385223389, 45.07525021689278, 50.76752717154366, 50.97985022408621, 51.56042085375105, 49.312518801007954, 54.77928154809134, 50.52273171288626, 51.61747946058001, 50.93547207968575, 50.52261706760952, 45.37559304918562, 48.76854085922241, 49.6616518838065, 52.42436334065029, 55.34304101126534, 57.19735540662493, 49.10842588969639, 40.370166369846885, 31.347114086151123, 32.27099173409598, 31.965559346335276, 41.53607061931065, 43.83756760188511, 49.583845955984934, 47.665535177503315, 47.63444546290806, 48.249906471797395, 47.538209438323975, 39.12139095578875, 33.19733599254063, 27.278707572392054, 22.88079489980425, 22.14571370397295, 14.987318209239415, 14.732824802398682, 11.302863938467842, 16.63256652014596, 13.130624055862427, 15.776920182364327, 39.43400778089251, 40.95069531032017, 44.13943556376866, 45.397278376988, 43.883095673152376, 44.995724609919954, 40.251004764011924, 34.190167563302175, 27.414506639753068, 15.496226855686732, 16.599300282342092, 15.626295396259852, 26.853846073150635, 41.461120401109966, 48.573543139866416, 47.256710120609824, 46.58611863000052, 46.93511274882725, 49.54896599905831, 41.76171684265137, 43.43533985955374, 45.44743047441755, 49.59902776990618, 45.474702153887065, 48.15615790230887, 42.02839912687029, 35.09303385870797, 38.85997540610177, 38.4484474999564, 40.74122101919991, 40.05332503999983, 37.69179562159947, 37.55708394731794, 41.756012371608186, 53.712712219783235, 44.08049052102225, 25.84604808262416, 33.114899090358186, 53.893778800964355, 54.928421156747, 56.38723366601126, 52.3498022215707, 54.15323148454939, 45.49475465502058, 54.1941112109593, 53.40168653215681, 56.94977024623326, 53.63887371335711, 56.88854619434902, 49.81501947130476, 63.15084293910435, 52.82612555367606, 64.53421538216728, 8.245959673609052, 0.8262579547507423, 0.6661893182567188, 0.44056725076266695, 26.361804178782872, 54.475999627794536, 41.90229279654366, 55.21326950618199, 57.103283745901926, 63.92805453709194, 15.246202877589635, 13.25770400251661, 34.43240261077881, 19.763694047927856, 34.14351388386318, 26.201297317232402, 50.46873031343733, 27.011182819093975, 42.87601682118007, 46.69100863592965, 49.57021011625017, 0.20738942442195757, 0.19155906672988618, 0.13983256449656828, 0.04176505176084382, 0.08802001723753554, 0.04430862509512475, 0.08728273465697255, 0.027973696888823594, 0.30463244925652233, 0.2236445178943021, 0.37713559876595226, 0.17513885854610375, 0.3258967867919377, 0.12165989034942218, 0.22986535408667155, 0.3091601777289595, 0.3909050284751824, 0.2771685543869223, 0.3202155487877982, 0.1673908300165619, 31.947650364467076, 84.07043061937604, 48.87562302180699, 50.1846011025565, 51.175570556095664, 51.6609856060573, 38.09896353312901, 37.17404018129621, 86.17122541155133, 73.97650459834507, 15.269335167748586, 62.438332966395784, 53.31648424693516, 67.67915071759904, 60.33744089944022, 61.93586703709194, 12.22648537158966, 0.1766696742602757, 0.6633314916065761, 0.4338427244552544, 0.2874097648475851, 23.951962198529923, 66.41774000440324, 56.48770809173584, 64.41449792044503, 61.83550030844552, 55.68018497739519, 45.682178837912424, 51.97621842793056, 61.68472439902169, 60.99141924721854, 61.668034826006206, 50.76798575265067, 48.80268778119768, 52.1667936188834, 59.12214538029262, 55.75456196921212, 62.32392392839704, 59.308864321027485, 51.85427754265921, 46.7209449495588, 45.81367002214704, 44.318087645939414, 46.84347990580967, 52.884049211229595, 53.87447323117937, 54.07229886736189, 52.75559091567993, 58.86003153664725, 58.40126282828194, 56.57654428482056, 58.81585489000593, 56.41877153941563, 50.081500257764546, 52.175669942583355, 54.75319801058088, 56.60666472571236, 56.95625638961792, 58.93305015563965, 51.732367924281526, 47.46767827442714, 44.281241348811555, 47.75517736162458, 48.49948576518467, 52.60278613226754, 55.96883051736014, 52.68093947001866, 49.78386722292219, 50.58251748766218, 56.71105098724365, 56.61946678161621, 48.166514192308696, 44.61863892418997, 39.166724477495464, 33.67170340674264, 32.75800486973354, 27.24640887124198, 30.067509514944895, 24.7546580518995, 24.061111450195312, 18.492413418633596, 20.765928268432617, 53.11478846413748, 50.55624982288906, 50.114650113242014, 50.97949586595808, 47.107907499585835, 48.04211711883545, 46.406841209956575, 48.05766371318272, 39.858501025608604, 36.55844368253435, 29.268272127423966, 27.08262767110552, 34.24273763384138, 46.34812198366438, 50.93572916303362, 52.72344160079956, 54.53519827978951, 53.651793888636995, 56.492231369018555, 46.96714047023228, 48.37099967684065, 49.06429788044521, 53.962423528943745, 50.09459066390991, 51.70322717939104, 46.67530918121338, 39.0122833933149, 38.60626540865217, 39.49930347715105, 41.355320181165425, 41.24624041148594, 40.41483633858817, 39.13245248794556, 42.42340769086565, 53.24275343758719, 54.42685849325997, 45.491183280944824, 34.81283385413033, 54.14765555518014, 59.293265615190776, 61.31294713701521, 52.21827629634312, 55.74264233452933, 46.652692794799805, 56.23896953037807, 54.054535797664094, 57.3980575970241, 56.68328251157488, 60.44015611921038, 48.724544865744456, 62.56212207249233, 54.85934911455427, 67.29271970476422, 12.024489079202924, 1.1574764102697372, 0.9923056789806911, 0.7309667766094208, 25.927771057401383, 54.5751747403826, 44.745287214006694, 63.8506863457816, 64.08948203495571, 67.11260155269078, 20.949551786695206, 16.069760697228567, 37.68567773274013, 23.1617157799857, 46.437885761260986, 38.32451595578875, 58.15353522981916, 34.062817505427766, 54.68963936397007, 52.10735872813633, 67.57482351575578, 1.9821304168019975, 0.6204563836966241, 0.1998685829873596, 0.22520746902695724, 0.2868452508534704, 0.1974168052630765, 0.17841089011303016, 0.15189155670148985], [0.07317501452884503, 0.18361590509968145, 0.0901006498773183, 0.20590195352477686, 0.06718808292810406, 0.0685501741245389, 0.03933621869821634, 0.09007212426513433, 0.11162477132997342, 0.026880052805479084, 0.08738671336323023, 0.16443936553384575, 10.786107301712036, 62.186113357543945, 44.61420249938965, 46.058079855782644, 27.469011783599854, 48.075760296412874, 35.252050331660676, 22.3272544997079, 37.273882320949006, 41.85303006853376, 12.267587440354482, 33.659620489392964, 54.45812886101859, 46.60952711105347, 57.415657384055, 52.729823521205354, 16.528741325650895, 0.05875538542334523, 0.4651405321700232, 0.24730823667986052, 0.042599917855113745, 12.032128623553685, 68.59308896745954, 56.21230929238455, 58.161845275333945, 51.74876914705549, 46.27105951309204, 44.027416706085205, 57.72170121329171, 55.182113783700125, 57.94376911435808, 54.82819339207241, 51.59178849628994, 43.52766057423183, 48.953046798706055, 49.915431363242014, 56.79443979263306, 49.3635185786656, 46.894813196999685, 48.52474594116211, 46.196845803942, 46.68021808351789, 42.78586394446236, 44.48953097207205, 47.649231229509624, 48.77452325820923, 50.798272950308665, 50.10347393580845, 53.586751801627024, 48.660597120012554, 46.94674750736782, 47.41296468462263, 50.23705652781895, 47.52753005708967, 40.69202082497733, 48.41825784955706, 53.2837894984654, 56.664102009364534, 49.317594460078645, 39.31842449733189, 29.979020731789724, 26.12078332901001, 25.761467661176408, 29.26507248197283, 34.75629983629499, 38.997132846287315, 38.39625610624041, 39.05884327207293, 38.92538922173636, 33.45981809071132, 27.37478378840855, 17.497844798224314, 14.599103246416364, 11.98718159539359, 10.789247887475149, 9.887968386922564, 7.144705372197287, 8.623532601765223, 3.857124822480338, 6.788675333772387, 12.99149853842599, 8.113874418394905, 17.49106683049883, 19.976175171988352, 26.16777225903102, 32.595225947243826, 36.36309507914952, 38.775954314640586, 33.42068583624703, 34.51160512651716, 27.34252851349967, 20.734777757099696, 16.053152765546525, 16.03612446784973, 17.262799399239675, 27.16909452847072, 40.32667064666748, 47.16481672014509, 46.69354820251465, 45.44310869489397, 46.08192607334682, 42.680084569113596, 42.53990118844168, 45.692462171827046, 46.39259740284511, 45.702234813145225, 47.62947055271694, 44.538884026663645, 42.596716608319966, 38.446161542619976, 36.09007256371634, 37.57144239970616, 41.41592584337507, 42.07030718667166, 42.14887394223894, 40.25576080594744, 33.77579436983381, 19.310980694634573, 37.0142628805978, 55.023507254464285, 52.35275173187256, 52.47395610809326, 52.89656291689192, 49.746301787240164, 47.60180630002703, 46.01650530951363, 54.46675157546997, 53.689595563071116, 52.82397508621216, 53.765330927712576, 54.49994659423828, 51.53330203465053, 55.16719947542463, 50.43641424179077, 48.184840066092356, 1.7034235149621964, 0.6496837639382907, 0.38212283115301815, 0.7346217461994716, 40.920609610421316, 65.42380714416504, 43.70554140635899, 56.69911050796509, 50.45347554343087, 51.364731788635254, 6.194176171507154, 16.897080966404506, 18.423909391675675, 21.138971839632305, 35.20624085835048, 34.38317114966256, 31.738999434879847, 23.940025193350657, 48.21857704435076, 45.27923195702689, 31.777874605996267, 0.09053423375423465, 0.1822902648044484, 0.0630284325618829, 0.08853755625230925, 0.1143813809113843, 0.07231678308120795, 0.10666073126984493, 0.03309583391195961, 0.10626837518066168, 0.02527951931447855, 0.07729674157287393, 0.23564584819333895, 0.04910036136529275, 0.08640676630394799, 0.03905439257089581, 0.10785917339048215, 0.05988544478480305, 0.09578690225524561, 0.15034612534301622, 0.053854120030466995, 10.78600742135729, 70.4294353212629, 49.52838543483189, 39.704973629542756, 36.0675117628915, 52.25761004856655, 21.6419814654759, 35.14493342808315, 50.132638999394004, 43.2645149230957, 10.343203936304365, 38.13588278634207, 55.41683782849993, 51.533458369118826, 61.10980265481131, 58.11298206874302, 18.23378583363124, 0.03184138211820807, 0.9336804705006736, 0.8339405996458871, 0.1196040649499212, 15.527130705969673, 70.46695559365409, 58.890179770333425, 63.411164147513254, 53.45314141682216, 49.640675272260395, 47.32657078334263, 62.32686301640102, 58.37226104736328, 62.51039968218122, 58.039289474487305, 54.968084948403494, 47.052589416503906, 51.88241079875401, 52.970196451459614, 59.39077663421631, 52.070866789136616, 52.93130043574742, 52.04294545309884, 45.632495743887766, 47.81571701594761, 44.76244926452637, 45.12591995511736, 50.8952385357448, 51.01969119480678, 54.661318506513325, 51.74186263765608, 55.20396934236799, 51.224878447396414, 50.37104558944702, 49.54959481103079, 51.43787547520229, 48.0795053754534, 43.049252782549175, 47.70103005000523, 54.32779107775007, 57.90259061540876, 53.12266077314104, 49.23848227092198, 38.35788467952183, 35.834177357809885, 35.63760239737374, 38.76986421857561, 46.24018171855381, 47.07087707519531, 48.65036242348807, 46.46053688866751, 47.549632276807515, 46.64552225385393, 41.085827350616455, 33.41289690562657, 27.414676870618546, 22.422340597425187, 19.278645515441895, 18.247074263436453, 14.603176627840314, 14.805277143205915, 9.438647491591317, 12.359795246805463, 11.532659104892186, 14.43487388747079, 31.554962498801096, 38.65191854749407, 41.97598539079939, 47.3039231300354, 45.71183374949864, 45.88419076374599, 41.40665694645473, 40.31016520091465, 33.658043248312815, 24.245945692062378, 20.148811851228984, 16.903824193137034, 23.079179865973337, 35.813440459115164, 46.8335405077253, 48.73268468039376, 47.8246419770377, 46.10277761731829, 47.94556147711617, 46.0316732270377, 43.094461236681255, 47.82267216273716, 47.854804107121055, 46.931645597730366, 48.89187485831124, 47.30186646325247, 44.64201961244856, 39.16324690410069, 36.40762955801827, 38.881959506443565, 41.02731309618269, 40.632832595280235, 42.765234742845806, 40.62515483583723, 32.920818533216206, 23.11276398386274, 39.15583665030343, 54.55130073002407, 53.759362425122944, 55.013998644692556, 55.4956442969186, 51.32902152197701, 49.79358427865164, 47.161630971091135, 58.28606864384243, 55.60746513094221, 57.61878102166312, 56.454662459237234, 57.795463289533345, 54.56091703687395, 59.05853462219238, 54.31473193849836, 52.405624049050466, 1.31145370219435, 0.9645134274448667, 0.9516632769789014, 0.9070137728537832, 43.728373186928884, 67.33869593484062, 49.35707065037319, 61.50089590890067, 53.72473955154419, 56.63405452455793, 7.177184292248317, 22.663727964673722, 23.652739763259888, 23.370915617261613, 29.391460214342388, 33.67975984300886, 42.47534894943237, 24.560146706444876, 49.88118369238717, 52.55027164731707, 33.634176186152864, 0.24129353942615644, 0.01862912465419088, 0.2155071866831609, 0.056169132236391306, 0.15455224178731441, 0.020785617509058545, 0.04985048522108367, 0.04423983860760927, 0.297665930220059, 0.22564649475472315, 0.21681173811001436, 0.28668346096362385, 0.18963228512023175, 0.14765282986419542, 0.1542884816548654, 0.36030776745506693, 0.4514958443386214, 0.15822724173111574, 0.19258316606283188, 0.35134841821023394, 17.49518190111433, 87.90691321236747, 57.305108070373535, 59.69473252977644, 37.18550818307059, 68.37592996869768, 42.90468508856637, 28.489380802427018, 48.49388551712036, 48.275614806583945, 16.25090718269348, 45.22799594061715, 60.35816042763846, 56.62650530678885, 60.560283524649485, 63.41203267233712, 18.722999811172485, 0.14490289028201783, 1.3521371419940675, 1.4566914630787713, 0.25980687886476517, 18.06628908429827, 72.67993600027901, 61.388508796691895, 65.6228938783918, 55.95621953691755, 51.142816747937886, 46.886357239314485, 63.18410396575928, 61.7766421181815, 61.08808258601597, 59.064788000924246, 53.59754582813808, 48.79170615332467, 51.931551933288574, 55.63947548185076, 59.71923882620675, 55.26190342221941, 58.0329145022801, 55.35259478432791, 47.88776636123657, 49.382869311741416, 44.97152403422764, 47.33957086290632, 53.878006390162874, 52.230192456926616, 56.244271005902974, 55.80127818243844, 62.68462576184954, 56.79406458990914, 55.537785121372764, 56.063173157828196, 57.09471661703927, 53.53718335287911, 50.150210993630544, 53.606304032461985, 57.654460021427695, 60.689818790980745, 55.544021129608154, 52.028538363320486, 47.44816425868443, 47.5145195552281, 47.12880768094744, 48.69363580431257, 53.54239102772304, 52.29186119352068, 52.01555912835257, 51.34772259848458, 53.85279137747628, 53.78646387372698, 53.418105125427246, 43.27244976588658, 38.147948333195274, 34.445065702710835, 32.79211705071585, 33.86089938027518, 31.554215567452566, 31.98478501183646, 23.09960583278111, 25.046110664095195, 16.449950490679058, 21.54265522956848, 50.77634790965489, 49.358574935368125, 48.78283677782331, 53.80905941554478, 49.89305816377912, 50.29904835564749, 43.2310836655753, 49.47454731804984, 44.42352308545794, 42.83178458895002, 37.08488437107631, 29.13999969618661, 31.202132974352153, 41.099237373897004, 49.15377330780029, 52.5887577193124, 52.78510338919503, 50.610647269657676, 52.72745418548584, 50.438655035836355, 46.847683565957205, 52.25012683868408, 52.33288335800171, 51.86027731214251, 54.04036494663784, 52.17575332096645, 50.62333468028477, 39.53798757280622, 36.10605342047555, 39.03997891289847, 41.10456664221627, 40.24869796207973, 43.38815811702183, 41.62471921103341, 39.88865968159267, 26.96468026297433, 36.785354478018625, 55.21890449523926, 54.993563992636545, 57.298118182591026, 57.4635443687439, 53.31649119513375, 52.16484464917864, 48.55093717575073, 60.78247996738979, 56.6725857598441, 58.365764481680735, 59.376657894679475, 59.609200205121724, 53.630810328892295, 60.327630043029785, 54.71417345319475, 56.525627885546, 3.897381816591535, 3.036984213760921, 2.3930718515600478, 0.9376410522631237, 47.120674814496724, 70.95102964128766, 52.78830303464617, 67.43149607522147, 58.95055266789028, 63.22511918204171, 11.783917256764003, 24.372395958219254, 24.956624814442225, 29.034114360809326, 47.367158685411724, 50.97304098946707, 46.33135250636509, 33.188602106911794, 61.40321813310896, 57.967035157339915, 51.87538269587925, 0.2769847528210708, 0.3566993453672954, 0.3678764727498804, 0.15560532813625677, 0.3963127354426043, 0.19707243517041206, 0.15124525209622725, 0.10536916700324842], [0.06258037553301879, 0.16197719265307697, 0.1658416260033846, 0.1488549496446337, 0.17880194341497763, 0.13720603686358246, 0.059265745537621636, 0.09283290683690991, 0.061190600107823095, 0.04768105948876057, 0.02566993479350848, 0.08502466510981321, 1.9005959119115556, 50.633885519845144, 48.78192656380789, 25.75488076891218, 21.427872725895472, 37.45828403745379, 48.21888971328735, 15.19810049874442, 31.659654481070383, 19.431795971734182, 3.115043316568647, 33.67524698802403, 57.05094991411482, 50.67256266730172, 50.360011850084575, 60.96384184701102, 32.530149119240896, 0.8600280998008591, 0.16169322574777262, 0.17172882652708463, 0.14882714327956947, 8.933534298624311, 61.154979842049734, 58.42909731183733, 56.4895841053554, 53.05926888329642, 47.37856067929949, 45.75676774978638, 57.08858830588204, 57.342409474509104, 58.3511107308524, 57.42021887642996, 54.2881828716823, 46.24444096429007, 47.86523335320609, 53.24696752003261, 57.022153105054585, 55.623609270368306, 56.341900144304546, 53.45468044281006, 49.914719172886436, 47.33358498982021, 47.68339204788208, 47.887502329690115, 48.98012392861502, 50.855640751974924, 52.448345048086985, 53.23935924257551, 52.189469064985005, 48.609010219573975, 47.36466080801827, 48.00301265716553, 49.690796102796284, 47.3334356035505, 43.661871978214805, 48.89241681780134, 51.70024292809622, 51.94527115140642, 50.72585882459368, 39.293244225638254, 32.14534745897566, 29.69793483189174, 30.830202851976665, 34.44397830963135, 38.407995087759836, 40.01631546020508, 39.305841309683665, 40.22348294939314, 36.18823323931013, 31.508479050227574, 24.031717096056255, 16.402207681110927, 12.501816426004682, 12.12298239980425, 12.04931846686772, 9.66441009725843, 7.26473810843059, 6.992386094161442, 6.071248642035893, 5.554431642804827, 10.111762046813965, 7.671654582023621, 15.740020036697388, 18.38385476384844, 21.81247115135193, 31.280887331281388, 34.38615192685808, 38.460120473589214, 34.722069535936626, 36.480224336896626, 36.15846368244716, 30.85508782523019, 24.555258648736135, 18.894599471773418, 18.157334804534912, 25.126084429877146, 36.470086915152415, 46.02277258464268, 47.562194619859966, 47.62482568195888, 44.978010177612305, 42.657204151153564, 42.75940520422799, 44.53847755704607, 45.821729932512554, 44.15842151641846, 40.71888256072998, 46.7879707472665, 48.49538632801601, 38.455114296504426, 39.34272582190377, 37.875106470925466, 38.85399995531355, 37.717347621917725, 38.47326993942261, 37.86114753995623, 40.71828154155186, 50.799509729657856, 45.56204795837402, 39.700634479522705, 58.35511289324079, 48.3806403023856, 52.8262471471514, 44.17893954685756, 47.55865798677717, 46.48210409709385, 52.880060945238384, 53.371145725250244, 54.24079615729195, 53.92214829581124, 55.29687717982701, 52.61388240541731, 53.31777661187308, 54.95134673799787, 30.125589506966726, 0.7927917933889798, 0.4777130261063576, 1.0323092809745242, 6.414668568543025, 36.72092035838536, 37.73654549462454, 53.239894253867014, 55.761221817561555, 53.23708370753697, 47.37060499191284, 3.959752755505698, 19.68620947429112, 19.74349216052464, 25.65068905694144, 37.6840865952628, 39.20584283556257, 28.83200863429478, 22.190463576998027, 38.74133144106184, 49.22709764753069, 18.37511566707066, 0.24387851357460022, 0.09088965718235288, 0.05859086103737354, 0.047741306613066366, 0.09065077214368752, 0.01867649148750518, 0.06267592004899468, 0.03783596080860921, 0.038485875220171044, 0.09806139913520642, 0.04160059183569891, 0.09975651531879391, 0.102402774750122, 0.06699779456747429, 0.1569798636649336, 0.14355533330568246, 0.07726446366203682, 0.13380469009280205, 0.12951831652649812, 0.029681866389832327, 1.779835786138262, 57.10771322250366, 58.16450643539429, 25.084885086332047, 25.138995919908794, 49.906718322208945, 28.486123834337505, 24.41053114618574, 46.531568322862896, 25.085864782333374, 4.09540764774595, 39.34600189753941, 62.21933964320591, 53.376728602818076, 54.10389232635498, 64.7964334487915, 34.772464820316856, 0.9061840059501785, 0.7020297007901328, 2.6127254707472662, 0.30803543808204786, 11.443815095084053, 64.77217728751046, 59.53413186754499, 61.9688640322004, 57.07869059698922, 50.302567618233816, 49.860929693494526, 56.70100736618042, 61.315267835344585, 61.35066890716553, 60.01704556601388, 57.23125566755022, 50.08652033124651, 50.44746535164969, 57.15695858001709, 58.383857590811594, 57.274699279240195, 58.202631201062886, 53.20321123940604, 50.868950026375906, 46.33531297956194, 46.965285301208496, 49.08796344484602, 50.697392054966514, 53.32624299185616, 54.97750323159354, 53.061933517456055, 53.60612685339791, 52.85684353964669, 49.70873287745884, 50.12081663949149, 50.431599140167236, 46.73464332308088, 43.85438224247524, 47.391984598977224, 53.237271308898926, 52.014516898563926, 53.55730881009783, 46.33157137462071, 41.12687035969326, 38.9498017174857, 40.346455642155235, 42.56593261446272, 47.16132525035313, 47.48918294906616, 49.45600257601057, 47.44648626872471, 46.02376965114048, 44.39691148485456, 37.52636596134731, 29.528985909053258, 23.432179621287755, 21.533558300563268, 18.955191237585886, 18.181733403887065, 15.60662157194955, 12.528291668210711, 10.387273754392352, 9.545880777495247, 7.870793427739825, 15.99452907698495, 28.16595605441502, 32.370503834315706, 35.988632338387625, 41.65664618355887, 43.98113822937012, 44.69908169337681, 40.34020226342337, 42.88722079140799, 40.94836071559361, 35.181543486458914, 25.371539967400686, 22.69819971493312, 23.38736026627677, 31.826042992728098, 43.34395367758614, 47.49637433460781, 46.89146416527884, 48.22504234313965, 46.674558775765554, 43.79954705919538, 42.510746547154014, 45.946088790893555, 47.62026766368321, 46.62517098018101, 44.37919357844761, 48.901442527770996, 50.54360062735421, 40.741610118321006, 40.96743352072579, 40.11694622039795, 39.32701941898891, 38.066202776772634, 38.232219559805735, 40.20144326346261, 43.081846782139365, 49.24364478247506, 47.72746794564383, 41.56868198939732, 57.20069054194859, 52.67356743131365, 54.809693813323975, 46.77003049850464, 49.7082256589617, 48.33845778873989, 54.34720434461321, 56.14106593813215, 57.641161169324604, 56.190658705575125, 57.83451563971383, 56.775495529174805, 56.310796533312114, 60.478656087602886, 29.917233875819615, 1.7063895272357124, 2.3188666105270386, 1.2787342007671083, 10.406010440417699, 42.258971623011995, 44.39321504320417, 56.91164895466396, 61.69306223733084, 56.962402071271626, 52.92599548612322, 3.8130011558532715, 26.66392227581569, 23.71130265508379, 29.055287258965627, 27.482887336186, 39.555531774248394, 35.98798615591866, 19.64386194092887, 42.15420321055821, 55.83760683877127, 24.19649883678981, 0.4415046333202294, 0.10681765606360775, 0.11496652237006597, 0.15861710081143038, 0.022823410840438943, 0.057565316424838135, 0.08445133694580623, 0.08840764393763882, 0.1341697419328349, 0.3332588646028723, 0.22482244111597538, 0.24697382748126984, 0.2419968545436859, 0.23096278948443277, 0.2610079401305744, 0.478398292192391, 0.3347858398088387, 0.18711762077042035, 0.16771607899240085, 0.14925348040248665, 3.721024811267853, 74.7512217930385, 62.311688150678364, 36.13792133331299, 29.822849546160015, 54.323121888296946, 64.10089792524064, 19.72596706662859, 41.35178354808262, 27.465582847595215, 6.3153692569051465, 42.42947694233486, 63.02413558959961, 55.90944078990391, 57.666852133614675, 68.8766519001552, 36.183143683842246, 1.2287403919867106, 1.3318251690694263, 1.6490146688052585, 0.5403088043842996, 13.523181642804827, 66.58119637625558, 62.88951424189976, 64.13995374952043, 58.57602391924177, 50.151583262852256, 49.90070465632847, 60.77633081163679, 62.84455244881766, 62.2722293308803, 61.16389438084194, 59.032159260341096, 50.53556503568377, 50.35135439464024, 58.93919931139265, 63.33267729622977, 64.49309594290597, 61.77200766972133, 54.87694542748587, 50.72090128489903, 48.96157223837716, 49.63241733823504, 52.71398857661656, 53.31588670185634, 55.34462520054409, 58.129087993076865, 60.39628519330706, 59.4992310660226, 59.13124752044678, 55.751671518598286, 56.817077023642405, 58.09767171314785, 54.054692132132395, 49.831719466618125, 52.66219323022025, 57.74033628191267, 53.75005531311035, 57.55683088302612, 50.21779612132481, 46.364808082580566, 46.77929244722639, 49.938388211386545, 49.592291491372244, 52.46760892868042, 52.433364731924875, 52.086507184164866, 53.59949132374355, 52.46612548828125, 54.0077223096575, 48.21866389683315, 41.598013809749055, 38.59450210843767, 35.41539553233555, 34.632260595049175, 35.63421515056065, 34.49786853790283, 33.59957068307059, 27.593391486576625, 22.103555509022303, 12.87369009426662, 23.023264237812587, 45.642963205065044, 45.57832063947405, 46.82354204995291, 48.45612553187779, 48.570826394217356, 50.22309064865112, 42.95625114440918, 44.83657612119402, 45.521400996616904, 43.62359782627651, 41.83481536592756, 35.60342073440552, 32.667650495256694, 39.33888694218227, 45.61264474051339, 48.822017669677734, 51.314121110098704, 52.66571249280657, 51.30086047308785, 47.66612230028425, 47.50602190835135, 48.679173128945486, 51.74240459714617, 50.746085030691965, 48.15519905090332, 49.824621881757466, 52.48380865369524, 42.667442321777344, 39.05069998332432, 40.14456530979702, 39.63878856386457, 40.45195708956037, 40.54218987056187, 42.61055394581386, 41.316156659807476, 44.78602450234549, 47.96461343765259, 44.28071675981794, 58.53438336508614, 53.04377440043858, 58.08097519193377, 47.834807191576274, 50.69593988146101, 48.919115270887104, 55.28250135694231, 57.71388101577759, 57.337048939296174, 59.9300263268607, 62.3281067439488, 57.587257044655935, 57.717636517116, 61.77315412248884, 36.754362038203645, 1.7973874786070414, 4.947819599083491, 2.2556961945125034, 10.268663661820547, 43.61594091142927, 46.90000350134713, 59.379478863307405, 68.79350975581578, 59.9992025920323, 59.236505780901226, 7.367603148732867, 26.69811609813145, 26.788633755275182, 35.87131200517927, 49.16801364081246, 58.09238413402012, 41.46455628531319, 31.70089203970773, 51.76262385504586, 64.24404471261161, 34.94693408693586, 0.5976609183209283, 0.14510958561939852, 0.21934066526591778, 0.24494278218064988, 0.16479730632688316, 0.12892663399023668, 0.1927098756922143, 0.16375522581594332], [0.13463452484990868, 0.05075185113985624, 0.1429872095052685, 0.2271205306585346, 0.004661990620661527, 0.010078908276877232, 0.07391925209334918, 0.1160887378667082, 0.04619087105883019, 0.032752749643155506, 0.059205274496759684, 0.08584108522960118, 0.09619993330644709, 38.65833173479353, 56.94011919839041, 40.42806223460606, 20.82223473276411, 32.90203060422625, 47.28894976207188, 24.553582395826066, 17.266160590308054, 26.055994851248606, 2.2377038342612128, 25.372745479856217, 66.50497463771275, 61.7926299231393, 55.42452948434012, 54.552231788635254, 45.27058492388044, 3.366831485714231, 0.5467567869595119, 0.9077728635498455, 0.16244063207081386, 3.434484575475965, 52.838705267224995, 60.482970918927876, 57.27568939753941, 54.58773708343506, 48.47160611833845, 52.05821759360177, 56.40375995635986, 58.38210664476667, 56.243062019348145, 56.04029968806675, 55.17026710510254, 49.63022518157959, 49.09985181263515, 54.21258299691336, 56.93015548161098, 55.73414816175188, 56.36940458842686, 53.26775653021676, 49.85027463095528, 49.30039072036743, 44.865272181374685, 44.46310349873134, 53.78804111480713, 52.18345192500523, 51.955283505576, 51.3925905908857, 53.822997501918245, 50.13509866169521, 46.42733839579991, 47.84272118977138, 48.973422391074045, 47.8758328301566, 41.99509641102382, 41.79868820735386, 50.639801910945344, 53.454256602696006, 46.59004783630371, 41.75296211242676, 37.24623891285488, 36.7340316091265, 36.906058583940776, 36.08671658379691, 38.73204517364502, 42.0403083392552, 40.774023464747835, 37.040895325796946, 34.53633376530239, 29.47432095663888, 20.393153939928325, 17.520176308495657, 12.298567720821925, 11.274452754429408, 11.495366386004857, 11.041689838681902, 11.116496750286647, 8.320609382220677, 6.990839685712542, 2.1602472705500464, 5.571444741317204, 10.478815402303423, 13.375453386987958, 20.915097406932286, 19.940631662096294, 28.082921607153757, 33.49661227634975, 38.00787959780012, 36.42706714357649, 41.09210852214268, 41.99147987365723, 36.57260411126273, 30.789597579411097, 24.97644976207188, 22.86869808605739, 25.53312032563346, 36.16588088444301, 44.12747771399361, 47.25268016542707, 44.86855173110962, 42.70894391196114, 39.11185802732195, 41.77584253038679, 44.40754917689732, 47.6819155556815, 47.004351547786165, 45.002526896340505, 43.083580357687815, 47.09150627681187, 40.12376240321568, 39.6971047946385, 41.608040060315815, 38.45960978099278, 39.81589814594814, 38.44309043884277, 41.859721183776855, 42.45725931440081, 42.011525426592144, 43.74173109872, 41.678227288382395, 51.86952189036778, 54.14102349962507, 50.6433732850211, 48.05999135971069, 43.51759263447353, 49.524772371564595, 52.64305789130074, 53.34410333633423, 51.62477854319981, 53.50940792901175, 51.0075353213719, 58.25076137270246, 50.18590041569301, 53.797487190791536, 6.937611707619258, 0.7156764513679913, 0.5115043414490563, 0.32037812577826635, 16.133246387754166, 56.58753980909075, 53.270876271384104, 55.9344299861363, 48.624650614602224, 59.68790939876011, 21.197637217385427, 5.25427120072501, 38.767328126089915, 11.00002670288086, 28.396344423294067, 33.20018822806222, 46.27638183321272, 24.474928787776403, 42.30629580361502, 44.578096185411724, 47.53936283929007, 12.329928415162222, 0.28774325123855043, 0.027142915575365936, 0.10793473505015884, 0.04394098464399576, 0.036904315264629464, 0.05230212045301284, 0.08810080361685582, 0.13567830169839518, 0.06755120772868395, 0.029914905849312032, 0.008658904964769525, 0.13530275970697403, 0.09975739062896796, 0.09120943038059132, 0.08701541221567563, 0.18031169740217073, 0.10214913157480103, 0.07064859795251063, 0.05745850822755268, 0.09145005246890442, 0.013461906612584633, 42.97509813308716, 64.98415987832206, 40.605849266052246, 17.462688650403702, 46.97057635443551, 42.47534547533308, 22.473755529948644, 27.124686854226248, 28.4576918057033, 3.4398648696286336, 28.3072772026062, 71.36329405648368, 64.15414197104317, 61.63208484649658, 59.155357769557405, 50.540126528058735, 4.1916462779045105, 1.0589820040123803, 4.768810987472534, 0.1104009316435882, 3.827868563788278, 57.05651889528547, 63.12801810673305, 63.40796102796282, 60.4778778893607, 52.59837402616228, 53.37242071969168, 59.592795508248464, 58.42433779580252, 58.33227416447231, 58.05680240903582, 56.643941811152864, 53.413362979888916, 51.83919300351824, 56.286529949733186, 58.611598696027485, 58.58028316497803, 56.49883215767996, 55.647111552102224, 51.097382477351594, 48.98345211574009, 46.72252566473824, 45.471742221287315, 56.17260728563581, 54.16531440189907, 53.99328047888619, 53.57291446413313, 53.87428910391671, 50.76436921528408, 48.043604033333914, 49.62770993368966, 51.21844094140189, 50.2397906439645, 42.18486213684082, 44.043178694588796, 52.34475088119507, 53.08360842296055, 50.69036742619106, 45.91486011232649, 43.81339481898716, 42.92688805716378, 43.50652068001883, 44.063415322984966, 48.574109418051584, 49.01364203861782, 49.587035179138184, 48.16480146135603, 45.07021624701363, 40.524854115077424, 31.207719326019287, 26.60030630656651, 21.709660393851145, 20.27594304084778, 20.388272830418178, 19.449623312268937, 18.824210745947703, 13.958556635039193, 12.326167702674866, 5.091363302298954, 7.157508730888367, 21.949399300983973, 26.400979859488352, 31.486272607530864, 33.27750430788313, 39.57886382511684, 44.62080676215035, 44.31202186856951, 40.3095120702471, 43.590065819876536, 44.630259786333355, 39.23643922805786, 33.609482288360596, 27.64941828591483, 27.573653391429357, 32.57076481410435, 39.89190101623535, 44.72789587293352, 45.513625962393625, 46.879634857177734, 44.88456038066319, 40.85041890825544, 43.834430490221294, 45.28919219970703, 48.609249932425364, 48.27454825810024, 48.32743794577462, 45.16275930404663, 47.33879961286272, 41.27474887030465, 41.067348616463796, 43.17318780081612, 39.79274327414376, 41.051138469151084, 41.26675149372646, 43.374553544180735, 44.47074999128069, 43.29394749232701, 46.97128507069179, 49.071339879717144, 52.35112237930298, 57.36726665496826, 52.46734837123326, 50.77548285893032, 45.04887138094221, 51.722831521715435, 55.29341002873012, 55.82641329084124, 53.461236068180625, 56.38250541687012, 53.773418630872456, 59.92479433332171, 52.09775284358433, 54.35503149032593, 5.78371090548379, 2.4519960497106825, 5.4247739144733975, 1.0020088383129664, 21.24146819114685, 58.29993724822998, 57.06272711072649, 59.99017688206264, 54.946354457310264, 65.64139693123954, 21.497340815407888, 7.836550099509103, 49.04201848166329, 14.932283265250069, 31.247400488172257, 22.60078249658857, 49.130312715257915, 31.605090277535574, 39.43564755575997, 50.357583454677034, 56.58192219052996, 14.905869688306536, 0.24993376008101872, 0.10637360917670385, 0.05831387625741107, 0.020438277129349963, 0.051979938455458195, 0.02783733849147601, 0.13352172741932528, 0.05894340069166251, 0.23801420682242938, 0.25560940695660456, 0.15740320166306837, 0.4039584680327347, 0.2163190809743745, 0.18690085597336292, 0.180192071678383, 0.4833069773656981, 0.2656169570982456, 0.2981428860553673, 0.10773114061781339, 0.14245042045201572, 0.28159227701170103, 58.53445979527065, 72.25510924203056, 50.72393764768328, 28.18181358064924, 46.20350565229143, 67.3269465310233, 28.403744254793438, 23.963134901864187, 34.11861154011318, 6.085835950715201, 33.800047057015554, 75.58497783115932, 68.23917552403041, 61.13155746459961, 63.27003928593227, 52.11228500093733, 5.7204727445329935, 1.6437241584062576, 3.7936816896711076, 0.3346208743751049, 5.48736936705453, 60.750678062438965, 62.9492062159947, 66.08526870182583, 60.51957402910505, 54.600612095424104, 54.32679748535156, 61.61802864074707, 61.21638107299805, 59.124959400721956, 56.93827792576381, 60.17337308611189, 54.18130568095616, 51.252056326184956, 57.88399723597935, 60.95035539354597, 59.71607739584786, 60.460382325308665, 58.54657745361328, 53.56777974537441, 48.84291090284075, 48.960662024361746, 48.319951261792866, 60.33295931134905, 59.00928579057966, 59.578044482639854, 58.55976513453892, 60.90404564993722, 57.78088249479021, 55.03695896693638, 56.00932114464896, 58.090431690216064, 56.46364300591605, 47.013092381613596, 47.99601582118443, 55.5954030581883, 56.75481421606881, 52.74761438369751, 48.84029838017055, 48.49589007241385, 48.29019560132708, 50.31634242194039, 47.36944464274815, 51.46074199676514, 53.2334497996739, 53.218542439596995, 52.42065647670201, 52.408761160714285, 50.863460949489046, 42.81080797740391, 40.408051422664094, 35.466582911355154, 36.07460934775216, 38.135962690625874, 37.76472391401018, 40.022846766880576, 35.49230514253889, 31.109117439814977, 15.434082167489187, 8.453490206173488, 33.847742966243196, 45.94819062096732, 44.298392977033345, 43.606383664267405, 45.15974725995745, 48.590771198272705, 48.06333344323294, 41.69722366333008, 48.81949894768851, 47.635512011391775, 42.01221329825265, 42.68540688923427, 38.815135206495015, 36.89478513172695, 40.37312282834734, 44.35428081239973, 46.267571517399375, 51.24034513745989, 52.8274005481175, 51.033559799194336, 44.33161578859602, 47.758307525089805, 47.739109652382986, 52.040850571223665, 50.79334667750767, 48.98538024084908, 47.005612645830425, 49.669718742370605, 43.915672302246094, 42.098506450653076, 42.121359075818745, 39.85892139162336, 40.263834612710134, 41.27883093697684, 45.99099152428763, 46.1178308895656, 46.95901802607945, 46.492901597704204, 45.59924166543143, 56.03521013259888, 58.53771850040981, 55.041645526885986, 52.98135873249599, 47.00511237553188, 52.420527935028076, 57.143534660339355, 58.42606094905308, 54.49704919542585, 57.939971923828125, 54.53772742407662, 61.84492901393345, 51.63453728812081, 60.399995531354634, 11.042711223874774, 2.276740985257285, 5.759480365685054, 1.992895130600248, 23.28666697229658, 64.3078430720738, 60.48666736057827, 64.93005425589425, 59.927323477608816, 67.84640080588204, 29.97777353014265, 7.743381704602923, 49.28955500466483, 17.595923832484655, 37.42542600631714, 46.05171183177403, 66.31374631609235, 36.59058952331543, 57.86061307362148, 56.72948455810547, 67.97430324554443, 26.554924147469656, 0.5108275977628571, 0.17915555515459605, 0.250955660960504, 0.2585655669016497, 0.11234842214201178, 0.1350410080381802, 0.22168645582028798, 0.2565480108772005], [0.11836552140968186, 0.35514064186385697, 0.13448184090001242, 0.1049626295321754, 0.01657610330065446, 0.03582517656364611, 0.04519547036449824, 0.06684496812522411, 0.03378077430118408, 0.11071777357054607, 0.05370771252949323, 0.14849106488483294, 0.05155717381941421, 23.844134841646465, 58.462705748421804, 40.11006055559431, 37.538546153477256, 26.1466931615557, 33.083590507507324, 44.666345255715505, 21.029324054718018, 26.44589822632926, 6.171548060008457, 12.462776235171727, 60.36199583326067, 54.950773511614116, 53.46546057292393, 32.72178391047886, 58.286450794764924, 9.662604434149605, 0.8656697113599096, 2.946946850844792, 0.8552777575595039, 0.6625182266746248, 35.07350942066738, 60.516266686575754, 53.08715895244053, 56.451765060424805, 52.64125483376639, 51.82687732151577, 55.377698625837056, 58.25771304539272, 55.85104465484619, 56.47762278148106, 53.457258224487305, 48.431428159986226, 49.821491718292236, 53.97855029787336, 54.74233797618321, 59.028643471854075, 54.825910908835276, 51.886506761823384, 50.249229771750315, 50.02910041809082, 49.96938412530081, 50.18531676701137, 51.686808586120605, 52.68832540512085, 50.96342120851789, 51.84130525588989, 48.754627091544016, 49.64286742891584, 49.491431440625874, 48.60062026977539, 47.962775639125276, 49.090294565473286, 44.129864420209614, 39.17761925288609, 43.40752969469343, 44.48369448525565, 43.51519203186035, 42.89334215436663, 39.630145004817415, 40.53070797239031, 37.68543801988874, 38.500579833984375, 38.467273644038606, 41.85291542325701, 38.647454329899375, 35.21986280168806, 32.28331436429705, 28.663328954151698, 22.65031794139317, 16.96427525792803, 12.226579172270638, 13.60228340966361, 15.597906793866839, 17.486244780676707, 15.444499254226685, 16.25568754332406, 4.184328087738582, 2.087835750409535, 9.16498053073883, 13.664796352386475, 17.598159415381296, 19.80437227657863, 19.298684120178223, 27.65650371142796, 32.81864874703543, 37.47609574454171, 41.931624616895405, 44.56112173625401, 44.13658332824707, 39.97626951762608, 38.204854079655235, 34.43234007699149, 29.409251076834543, 33.51012999670846, 38.09388787405831, 42.41731759480068, 40.427544593811035, 39.92289693014962, 39.40128523962838, 37.98534311567034, 41.79601662499564, 41.33170672825405, 44.25815943309239, 46.0770206451416, 46.397436823163716, 47.05302715301514, 47.39846726826259, 44.084485735212056, 37.77897466932024, 40.77776159558977, 40.3949089050293, 40.88875559398106, 42.63079752240862, 43.08849273409162, 42.16134943280901, 45.88074445724487, 50.167018686022075, 54.50114515849522, 51.52081612178257, 52.327967507498606, 49.044141156332834, 46.10874959400722, 43.10669354030064, 51.88366494859968, 52.785693986075266, 53.49058525902884, 52.739078521728516, 51.795009408678325, 52.49129186357771, 49.39935391289847, 51.51615388052804, 25.691507986613683, 0.13196358031460217, 0.6910192487495286, 0.6232872317944254, 0.9283387171370643, 25.39692521095276, 55.23736238479614, 45.12436008453369, 54.74874768938337, 51.70899418422154, 52.28814043317522, 12.909689579691205, 13.504762836865016, 23.941039630344935, 12.770262684140887, 34.25415699822562, 33.02545492989676, 44.593795640128, 17.981826782226562, 33.481048311506, 44.351018633161274, 46.38932132720947, 3.1594946341855183, 0.28601882234215736, 0.03793799551203847, 0.054454114620706866, 0.025179250498435328, 0.009838527916664523, 0.041656530262636285, 0.03782705842916455, 0.03147594351321459, 0.011917154637298413, 0.09625089128634759, 0.04473077565697687, 0.1228292640298605, 0.04833491618878075, 0.02374250687924879, 0.06785523212913956, 0.20285683763878687, 0.020992911653593183, 0.04471850435116461, 0.15634658693202905, 0.16067694313824177, 0.16499706703637326, 27.834669419697352, 67.99626650129045, 42.30628538131714, 29.242886883871897, 32.78533213479178, 33.47318295070103, 31.207514354160853, 30.26504680088588, 33.230322565351216, 8.830462983676366, 12.061824355806623, 66.57260145459855, 58.72636904035296, 58.510196685791016, 36.51379803248814, 64.81171948569161, 11.62454034600939, 0.39534129042710575, 3.8296425257410323, 2.2805972354752675, 0.2694689461163112, 40.06600897652762, 63.671436718532014, 57.584984983716694, 59.434036118643625, 57.33744151251656, 53.13466031210763, 56.708059787750244, 60.85059315817696, 58.301973070417134, 58.62029784066336, 55.300083773476736, 49.680102825164795, 52.77788073675973, 55.854383264269146, 54.261439255305696, 60.611783572605674, 55.217580863407676, 54.05049542018345, 51.55971908569336, 50.79330151421683, 51.753942080906455, 52.997867652348106, 52.934180464063374, 54.03784622464861, 52.92541183744158, 50.86386741910662, 50.2362505367824, 50.55786875316075, 52.96265765598842, 50.36500065667288, 50.863822255815776, 49.63031203406197, 42.23149149758475, 39.85167442049299, 42.79095002583095, 46.58814402988979, 45.61650446483067, 46.54256384713309, 44.609217166900635, 45.18740803854806, 45.66765015465872, 45.10130248750959, 48.044764382498606, 49.90536689758301, 48.287492752075195, 46.51233918326241, 45.58271884918213, 40.04584183011736, 32.187286785670686, 26.28074128287179, 21.326364755630493, 19.327328068869456, 21.08595708438328, 22.805172443389893, 23.736416918890818, 19.5391560622624, 13.604428665978567, 4.229244717529841, 13.158003432410103, 29.595494065965923, 23.50182662691389, 32.83841289792742, 31.637041568756104, 39.770443030766074, 44.031213896615164, 46.17406613486153, 43.84699283327375, 46.96993712016514, 45.790192059108186, 42.77468776702881, 38.88384941646031, 35.16007702691214, 33.612904276166645, 38.19302477155413, 42.76876442773001, 44.402720178876606, 43.08098520551409, 43.1194052696228, 40.753797258649556, 38.81092807224819, 41.76002843039376, 44.31153202056885, 44.14328139168875, 48.78597041538784, 48.17501531328474, 50.50225189753941, 49.74248027801514, 46.95693356650216, 40.59099401746477, 41.937770298549104, 42.67901802062988, 41.88786138807024, 44.428143637520925, 43.813936778477256, 43.8186685017177, 47.86780071258545, 49.36315032414028, 57.758015973227366, 55.157923630305696, 53.67965963908604, 52.62623977661133, 49.58347075326102, 46.96830429349627, 54.018888064793174, 54.904776436941965, 57.24575308391026, 53.29792560849871, 54.363869598933626, 53.35248286383492, 51.58059842245919, 51.84163529532296, 22.767869302204677, 0.2052525005170277, 2.0889685239110674, 1.542810041989599, 1.8296372166701724, 31.074143682207378, 58.3703224999564, 49.22546829496111, 59.0098694392613, 55.66402346747262, 56.280262674604145, 12.745798076902117, 18.357052087783813, 32.17218140193394, 15.967637811388288, 33.46075957162039, 21.372063057763235, 50.748311928340364, 19.209189585277013, 31.461283411298478, 49.99338320323399, 56.24729694638933, 4.092201054096222, 0.30558994359203745, 0.03251030908099242, 0.33146951347589493, 0.045239429255681377, 0.12961769476532936, 0.04879952607942479, 0.04397609543853572, 0.040955423776592524, 0.21377746521362237, 0.42960988730192184, 0.20509847306779452, 0.32947586902550285, 0.15395183329071316, 0.17129731896732533, 0.19805762730538845, 0.45499819783227785, 0.2131218375372035, 0.42563991461481365, 0.20529613031872682, 0.21654734015464783, 0.2838306283312184, 39.09525530678885, 78.43872111184257, 46.84887170791626, 47.60241774150303, 38.06642164502825, 48.730502946036204, 53.978157724652974, 26.21824744769505, 33.77708673477173, 10.399828280721392, 17.23900703021458, 69.83164010729108, 60.843255860464915, 60.54872867039272, 38.67081069946289, 64.92922742026192, 12.837225079536438, 1.7752681055239268, 6.256037720612117, 2.0211000399930135, 1.900613933801651, 45.36650480542864, 63.015651839120046, 62.35334954942976, 61.047637122017996, 59.5821647644043, 53.9768306187221, 60.30345031193325, 61.88030924115862, 59.11881719316755, 59.4521153313773, 58.45366614205496, 51.410735811506, 53.5582537651062, 57.214159624917166, 57.96346378326416, 62.33858462742397, 59.13627801622663, 54.45225763320923, 51.49556636810303, 53.1798757144383, 53.03232029506138, 54.872627122061594, 56.472578389304026, 59.39850303104946, 59.16276454925537, 58.96652657645089, 57.10482277188982, 57.93477814538138, 58.61334964207241, 57.4191905430385, 57.30459042957851, 57.59462213516235, 48.77999496459961, 44.91071687425886, 48.25622238431658, 47.34808240618025, 47.59805079868862, 47.92238923481533, 45.1225083896092, 49.17576783043997, 47.865705830710276, 46.101273332323345, 49.64006730488369, 53.33531386511666, 50.736770970480784, 50.542475019182476, 50.3839761870248, 47.183625493730815, 44.072163105010986, 37.945481300354004, 34.354252747126985, 33.46929195949009, 38.91111414773123, 38.211003235408235, 41.379218510219026, 41.57815933227539, 24.585672651018413, 7.489259157861982, 13.554427691868373, 47.48428794315883, 42.26623943873814, 46.52865355355399, 38.08556045804705, 46.75133637019566, 49.863389355795725, 49.24191468102591, 48.075513635362896, 51.73296199526106, 49.43513018744332, 45.16320398875645, 42.682770047869, 42.250731059483115, 39.044443130493164, 44.78346756526402, 45.10589524677822, 45.35226099831717, 46.66435882023403, 46.17823505401611, 44.171202727726524, 43.329251289367676, 46.05091278893607, 45.84960263116019, 49.737769399370464, 53.387387139456614, 51.151769501822336, 53.934245109558105, 52.45419890539986, 46.896671840122764, 41.26248182569231, 43.755686555589946, 44.218488693237305, 42.38443871906826, 45.46857731682913, 45.02499042238508, 43.740841729300364, 48.0935720035008, 53.540240560259136, 53.06732184546334, 54.56480802808489, 56.101641859327046, 53.25564929417202, 51.12715898241316, 46.84657185418265, 55.219356128147666, 57.20366784504482, 58.79531601497105, 55.435639653887065, 58.17749261856079, 58.7368608202253, 52.087010928562705, 53.68433230263846, 33.380980355399, 1.197022082550185, 2.111677408218384, 4.079200974532536, 2.9872926516192297, 30.311290536608013, 63.75994982038225, 55.04919474465506, 64.73530319758824, 60.533595493861604, 61.4989504132952, 18.87408491543361, 17.570550748280116, 33.89679724829537, 16.987322432654246, 43.96111004693167, 46.21448380606515, 62.42251886640276, 25.079331738608225, 44.322301728384836, 55.74525833129883, 67.54072870526994, 8.509527427809578, 0.6421594076922962, 0.12495492425348077, 0.4139954665941851, 0.2520787721233708, 0.1615140653614487, 0.13284699219678128, 0.27514486440590447, 0.20679152650492533], [0.22013053431042603, 0.21394002863339015, 0.11347428815705435, 0.1592867470213345, 0.07970039759363447, 0.08002331919435944, 0.03844852186739445, 0.035782221904290576, 0.06946646102837153, 0.26435051219803946, 0.05524141541016953, 0.11088176191385303, 0.10401848198047706, 10.792987755366735, 66.71430996486119, 49.40913002831595, 40.67560917990548, 41.885248865400044, 43.105276107788086, 38.92815807887486, 20.010137966700963, 27.74194049835205, 16.198715788977488, 5.722277104854584, 52.51603787285941, 60.23002174922398, 66.28425121307373, 45.90341642924717, 53.023972034454346, 31.448696749550955, 0.2348838805087975, 3.5305056401661465, 0.10766040334211928, 0.2824253280247961, 17.106643847056798, 63.22796099526541, 57.86150591714041, 57.14429548808506, 52.283141204289024, 55.93514565059117, 57.36994865962437, 59.52500193459647, 54.61221211297171, 55.062566552843364, 53.117953368595664, 53.05624641690935, 54.131747654506135, 58.79469067709786, 57.638930797576904, 57.076765945979524, 60.18593542916434, 52.460949080330984, 46.722039290836875, 49.31214707238333, 52.64736924852644, 57.30734886441912, 52.33377272742135, 51.283184255872456, 49.19179732458932, 46.58191844395229, 44.102696963718955, 48.704666069575715, 51.2457959992545, 49.603457246507915, 50.6373005594526, 46.3978328704834, 41.07189621244158, 38.328938484191895, 43.56936713627407, 42.51225083214896, 42.3108503477914, 44.0284936768668, 45.99461153575352, 43.51134967803955, 41.08782148361206, 39.15023292813982, 39.6107942717416, 42.00222178867885, 42.16829068320138, 32.81103352137974, 29.831701551164898, 28.11558508872986, 20.796281473977224, 15.751463719776698, 13.6291138785226, 15.942033699580602, 19.208295004708425, 20.63429638317653, 21.663262060710363, 21.929063660757883, 9.832515682492938, 3.2944125831127167, 10.428012779780797, 15.08642383984157, 19.620743547167095, 20.647735936301096, 20.769749777657644, 27.564353227615356, 33.3510023525783, 36.062203339168, 40.471262659345356, 45.895144598824636, 47.12134878976004, 41.42406913212368, 38.91200351715088, 39.11710044315883, 39.18054791859218, 39.838924476078574, 40.71989699772426, 40.715026310511995, 39.23265593392508, 36.70693710872105, 37.381457805633545, 36.7434846333095, 40.84594079426357, 41.13804653712681, 42.618770190647666, 44.75945111683437, 43.4434484073094, 47.015625, 46.71350690296718, 48.51427500588553, 48.34976250784737, 37.754280771527974, 42.1113224029541, 45.036277770996094, 42.42858757291521, 45.11419834409441, 46.90342548915318, 46.642256600516184, 47.43331595829555, 51.18221998214722, 53.748137610299246, 51.188025202069966, 51.328090463365825, 44.96601063864571, 44.76927934374128, 52.98098005567278, 52.96164321899414, 54.548441546303884, 48.61758777073452, 47.25570610591343, 45.7688958304269, 50.369503089359824, 29.828574861798966, 4.565439820289612, 0.21342920032995089, 4.4685771550451, 1.0059687686817986, 6.729314701897757, 49.610634735652376, 50.05753592082432, 53.119277000427246, 54.57301732472011, 44.26702880859375, 50.71496057510376, 7.410083566393171, 15.884652001517159, 17.226154599870952, 17.275952339172363, 33.403763498578755, 37.79159607206072, 31.818181106022426, 22.497419357299805, 43.76623739515032, 48.23516239438738, 47.73390545163836, 0.9170268326997757, 0.08403422111379248, 0.05578207550570369, 0.04143036775557058, 0.04769362595730594, 0.016524855247033492, 0.02549213486989694, 0.05558953440881201, 0.15179626324347087, 0.12567033086504253, 0.05117174218009625, 0.056970132647880485, 0.1741631251892873, 0.043032833375036716, 0.13308613507875375, 0.15260563338441507, 0.05387826230643051, 0.054649838046836, 0.08910726103931665, 0.076608727420015, 0.21078576360430035, 0.1535004446549075, 12.12595362322671, 75.2281391961234, 55.84782416479928, 38.96575478145054, 49.33936664036342, 50.72323587962559, 25.6096008845738, 27.442608628954204, 36.54850428444998, 23.24106420789446, 6.844068544251578, 57.00625910077776, 65.90906238555908, 68.56394822256905, 47.55964115687779, 57.2560190473284, 35.73538787024361, 0.5293269593800817, 1.8740001618862152, 2.013468095234462, 0.8404669665864536, 18.849842650549753, 65.29707200186593, 62.13323756626674, 61.25005899156843, 57.18544619424002, 58.48926871163504, 59.32731178828648, 60.86282893589565, 57.27230215072632, 57.89720923560006, 54.80752944946289, 54.145862919943674, 55.73220614024571, 58.9935759135655, 59.36455413273403, 58.11825227737427, 59.22865431649344, 53.29765462875366, 49.224526814052034, 52.31979642595564, 52.450478145054404, 58.927609716142925, 55.51786116191319, 53.10374777657645, 50.21646554129464, 46.81036131722586, 45.46341480527605, 47.95956209727696, 52.52183961868286, 49.704466683524, 50.64738239560808, 48.68280356270926, 41.66222906112671, 39.61315318516323, 42.037004470825195, 42.406610420772004, 45.057886668613975, 47.07014056614467, 49.05411182131086, 47.754552023751394, 45.03141055788313, 46.41852113178798, 45.70592778069632, 51.24275268827166, 51.582877431597026, 44.181882108960835, 42.197445324489046, 38.8783221244812, 30.48335920061384, 26.470397574560984, 22.14665171078273, 22.75769713946751, 25.926694086619786, 28.36697265080043, 29.85657262802124, 26.638224363327026, 13.145438483783177, 7.2207030313355585, 26.556383269173757, 28.981851748057775, 25.583974191120692, 31.997715609414236, 29.9404547555106, 38.89742619650704, 44.51965141296387, 44.338129724775044, 44.42619814191546, 48.259501934051514, 48.086773191179546, 42.85541193825858, 41.52307401384626, 41.37746409007481, 42.29944487980434, 45.05197375161307, 46.71681424549648, 43.869254861559185, 41.96814782278878, 39.956036363329204, 37.596584456307546, 38.222641468048096, 41.215029103415354, 42.478204659053254, 44.55394772120884, 46.091698714665, 45.93755292892456, 48.49038709912981, 48.92905119487217, 50.58433791569301, 49.679262093135286, 41.322535106113975, 45.25587558746338, 48.06140879222325, 43.574484484536306, 46.32844468525478, 48.97082723890032, 48.490578174591064, 48.168838364737375, 55.16180419921875, 54.70374420710972, 52.87479421070644, 52.88083566938128, 46.38916499274117, 48.08783973966326, 56.010561398097444, 56.84547083718436, 55.682689802987234, 52.1132230077471, 48.596242904663086, 51.98221124921526, 49.34198611123221, 30.18839774812971, 4.232837804726191, 0.17229511828294822, 0.8704249390533992, 0.6917094002876962, 10.918494803564888, 53.11996487208775, 55.484353474208284, 58.81816169193813, 57.69168846947806, 51.370693343026296, 50.23901244572231, 6.977660255772727, 23.188521930149623, 15.61659744807652, 21.997041361672537, 27.254373243876866, 28.969042743955338, 42.447438035692485, 20.941676003592356, 41.265924658094136, 57.04646485192435, 49.927642822265625, 0.8500308905329023, 0.14365545793303422, 0.0719721212184855, 0.02803099068946072, 0.01659242546052805, 0.11003321316093206, 0.11552676159356322, 0.062383451099906645, 0.07237280293234757, 0.2980501167476177, 0.3740586595875876, 0.18205843652997697, 0.2587871492973396, 0.20540082827210426, 0.223626903125218, 0.20206610006945475, 0.2401791135115283, 0.1993100672428097, 0.47734493442944115, 0.12800578054572853, 0.6953119326915059, 0.35600414552858894, 19.6162463256291, 90.4800465447562, 58.86991882324219, 53.78052316393171, 55.72776624134609, 62.078270367213655, 49.96309947967529, 24.449706826891216, 35.46140997750418, 23.827733618872507, 8.6541211775371, 60.6744841166905, 66.35066209520612, 69.99209485735211, 49.791433811187744, 61.17806870596749, 35.74348599570138, 0.7573807878153664, 9.953893763678414, 1.2869745471647807, 0.7835984038455146, 26.45611728940691, 65.95701885223389, 65.67059326171875, 64.24598326001848, 58.61920697348458, 59.659400939941406, 62.13474532536098, 61.74964141845703, 57.61665487289429, 57.330163274492534, 56.61890745162964, 55.93875176565987, 59.02988025120327, 61.92425659724644, 62.27953883579799, 59.43926116398403, 62.67824036734444, 57.24647569656372, 52.415261200496126, 54.694642066955566, 53.09085886819022, 59.95932688031878, 59.52604416438511, 57.544490882328574, 54.63071516581944, 53.23927933829171, 50.58209712164742, 56.29053211212158, 60.89216423034668, 56.14757292611258, 57.46464565822056, 56.45318596703665, 46.89530651909964, 43.289229665483745, 45.95272779464722, 44.65145526613508, 45.990998472486226, 46.15089389256069, 50.93510035106114, 50.66440200805664, 46.98920794895717, 47.44074705668858, 46.4705353464399, 54.991462162562776, 55.1516181400844, 49.312758513859336, 47.384414536612375, 49.712335518428254, 43.11744935171944, 37.413304873875205, 33.793050221034456, 39.18119062696184, 41.97127798625401, 42.72131865365164, 45.26247637612479, 43.61958524159023, 25.087883234024048, 8.345199925558907, 30.043267250061035, 48.215221064431326, 41.63401590074812, 43.19196878160749, 38.64281988143921, 43.57297672544207, 52.453007289341514, 47.26361663000924, 48.78377825873238, 52.97157914297921, 50.31124939237322, 44.32611281531197, 41.77140610558646, 41.745353834969656, 43.38043172018868, 46.49614988054548, 45.784953117370605, 45.94402865001133, 45.15518924168178, 42.7633969443185, 42.477176325661794, 41.29153571810041, 45.312083039964946, 46.14969880240304, 49.137361662728445, 51.13564968109131, 48.319951261792866, 53.34134490149361, 51.91979210717337, 52.09110689163208, 50.926119804382324, 40.36968347004482, 44.474338735852925, 48.927988120487754, 44.04111507960728, 45.89902516773769, 48.30282047816685, 50.287698473249165, 48.995149408067974, 54.92359215872628, 57.588226318359375, 53.711485862731934, 54.30637672969273, 47.72961841310774, 48.72692462376186, 58.158614362989155, 58.95440196990967, 57.82733120237078, 52.63325745718819, 49.077593258449006, 50.18138061250959, 51.302218845912385, 37.61100196838379, 8.058413028717041, 0.3164406956306526, 12.012271540505544, 5.263565284865243, 9.49679262297494, 56.3571514402117, 60.048507009233745, 60.60514804295131, 62.697896821158274, 54.257169587271555, 60.260913440159385, 10.97140794140952, 22.635294198989868, 23.983154399054392, 23.002621139798844, 44.99241379329136, 53.272102628435405, 46.893044880458284, 28.875565154211863, 60.089925221034456, 60.32706029074532, 70.76314340318952, 3.279035351106099, 0.39205169837389675, 0.16670880732791765, 0.149654426745006, 0.1120782702096871, 0.14269400095301016, 0.3548484375434262, 0.10709103782262121, 0.3167163979794298], [0.14037346547203405, 0.18440438993275166, 0.12292189763060637, 0.06592308330748763, 0.07042901044977562, 0.14106350844459875, 0.14201257537518228, 0.10816575586795807, 0.06834520905145577, 0.09621490178895847, 0.03371922778231757, 0.11637419754905359, 0.020852907826857905, 2.006720091615404, 55.7027006149292, 52.33111504146031, 36.18301166806902, 21.17141819000244, 45.31265279224941, 40.568513120923726, 29.3948335647583, 20.255576133728027, 26.018354722431727, 4.502743184566498, 32.43371507099697, 63.215426445007324, 73.50835582188198, 74.97398798806327, 52.46139029094151, 56.063326018197195, 11.981264335768563, 1.8096066457884652, 4.286056663308825, 0.3284777711544718, 2.8522487665925707, 39.13194874354771, 55.07274913787842, 48.96743304388863, 56.90729243414742, 54.114033222198486, 54.958371366773335, 58.30771228245327, 56.025802271706716, 56.989600794655935, 54.85611820220947, 52.659980228969026, 57.59957620075771, 55.85549150194441, 57.080309527260916, 53.281767572675435, 54.59169755663191, 56.03343139375959, 56.43292849404471, 53.643845149448936, 54.623270171029226, 53.97928333282471, 53.41948781694685, 50.438422271183555, 48.77328995295933, 44.747003419058665, 43.853298323495046, 49.42022977556501, 48.02642113821847, 49.63752773829869, 47.04888950075422, 44.86142635345459, 38.9073760168893, 38.33248553957258, 42.18098851612636, 39.28042132513863, 43.57668706348964, 45.30680588313511, 46.98814834867205, 45.23847729819161, 40.402659620557515, 40.07338448933193, 42.055629117148264, 41.907966000693186, 37.436466693878174, 33.809962136404856, 29.270957606179373, 26.195577212742396, 21.16043656212943, 16.42573949268886, 16.746914761407034, 21.891691037586757, 21.510540655681066, 26.471748999186925, 26.420783962522233, 24.26616668701172, 12.869756545339312, 1.2201785828386034, 8.33035944189344, 23.818065200533184, 23.834728717803955, 22.62533048221043, 21.07321756226676, 25.208243404115947, 32.39409644263131, 35.20428841454642, 42.55768162863595, 46.30423716136387, 47.1323686327253, 41.9798902784075, 39.35473230906895, 38.26080444880894, 43.0617630141122, 44.24636139188494, 43.44454969678606, 41.275193555014475, 38.81105661392212, 38.19547748565674, 37.6239082472665, 37.01224790300642, 36.063030174800325, 40.356464522225515, 40.73242459978376, 45.17407444545201, 42.77975647790091, 46.07007244655064, 47.10398524148123, 46.488923754010884, 50.103074414389475, 45.12781681333269, 44.15547548021589, 46.22530909946987, 44.49968229021345, 49.227264404296875, 50.46558625357491, 51.98828397478376, 50.728787490299766, 52.658375195094514, 51.15499694006783, 50.330290930611746, 51.05444955825806, 45.771035875592915, 46.927716391427175, 49.41253464562552, 51.56069878169468, 53.966102600097656, 49.43547412327358, 44.04190370014736, 48.29265873772757, 29.73684126990182, 13.0007518018995, 0.08622299187949725, 0.08769530430436134, 1.9322697094508579, 12.617126124245779, 32.697534697396414, 49.298935072762625, 48.51029021399361, 53.55718721662249, 43.61893211092268, 60.53130953652518, 21.157426255089895, 5.283209579331534, 47.68146392277309, 20.282830442701066, 22.679743562425884, 34.180176053728374, 39.042410782405305, 22.42394389425005, 33.417378493717735, 36.417152064187185, 54.30581045150757, 22.615669012069702, 0.48638828630958286, 0.12726141405957087, 0.03989337398005383, 0.06819536816328764, 0.032697075844875405, 0.1049601189526064, 0.03192740000252213, 0.055703647035573206, 0.12070977847490992, 0.06828741822391748, 0.08330452455473797, 0.07308048103004694, 0.028380777187911526, 0.08316329427595649, 0.24664006967629704, 0.11448036559990474, 0.05270051211118698, 0.06670393462159804, 0.041781723366252015, 0.016363616666889617, 0.00996235801306154, 0.01748040727605777, 2.3465621301106045, 61.34964057377407, 58.60656820024763, 38.25681618281773, 28.311223779405864, 59.22627108437674, 26.71024591582162, 32.42452955245972, 26.13298957688468, 40.68283530644008, 6.976413922650473, 32.24032585961478, 72.4917301450457, 72.31006949288505, 73.547849382673, 57.73566361836025, 61.66898672921317, 16.163689919880458, 0.736589823450361, 2.2035126175199236, 0.06047012483967202, 1.8159232097012656, 42.455765451703755, 58.71193068368094, 55.50481939315796, 59.7071350642613, 58.38159942626953, 56.69184616633824, 61.59598200661795, 57.1946108681815, 57.854582037244526, 56.975381306239534, 54.43241010393415, 58.53370244162423, 59.2210043498448, 58.2980751310076, 55.422674315316335, 56.49000794546944, 56.4032701083592, 58.00003562654768, 55.5397549356733, 56.31800181525094, 53.69966697692871, 53.31988539014544, 50.970008100782124, 49.08367988041469, 44.98816496985299, 45.835803508758545, 48.385865347726, 50.72238819939749, 51.20101138523647, 49.416550704411094, 45.423952511378694, 38.19444220406668, 38.40783180509295, 39.70538704735892, 40.828149931771414, 45.30239725112915, 46.993488039289204, 49.55144303185599, 50.38652965000698, 45.38795736857823, 45.77448565619332, 49.06288044793265, 50.15358781814575, 47.35651057107108, 45.85924325670515, 42.09016861234392, 37.50429153442383, 31.68522732598441, 25.193237032209122, 23.717762742723735, 27.426683357783727, 29.476075376783097, 33.7696521622794, 31.183525698525564, 29.86429555075509, 19.214011635099137, 20.5005852494921, 36.30823905127389, 29.189288479941233, 32.541954108646934, 32.78308091844831, 32.28101103646414, 36.33537176677159, 44.68357331412179, 44.254727022988455, 45.931563581739155, 47.45587675912039, 47.86057806015015, 43.73444938659668, 41.74680600847517, 43.59046534129551, 48.62171500069754, 49.27250065122332, 48.33595643724714, 45.04999698911394, 40.91855641773769, 39.49558271680559, 38.87891272136143, 38.26986837387085, 37.14980139051165, 41.277045249938965, 43.25445393153599, 45.97407266071865, 45.69728422164917, 49.18689884458269, 50.23910277230399, 49.08817536490304, 50.92141587393624, 48.087151868002756, 45.50027847290039, 48.58648763384138, 46.665651185171946, 51.742203099387034, 52.75949580328805, 52.88907275881086, 52.8167176927839, 54.82125908987862, 52.18894100189209, 52.96042381014143, 53.13448313304356, 48.99325949805123, 50.022193908691406, 53.54747363499233, 54.77133975710188, 59.58258165631975, 49.58169548852103, 45.4307930128915, 48.49721023014614, 31.859484672546387, 15.509942599705287, 0.14309973775276116, 0.3398607117789132, 3.6885758553232466, 18.00976722581046, 39.49720859527588, 54.57961116518293, 53.791338035038535, 55.76443188531058, 47.66269336427961, 61.0985882622855, 17.467328310012817, 13.785693270819527, 50.80452632904053, 19.55197548866272, 24.93790810448783, 21.35929226875305, 36.2270632471357, 36.800696100507466, 27.381735461098806, 37.3362250328064, 59.40007332393101, 24.306596517562866, 0.7258296151246343, 0.10955688836319105, 0.14368448566113198, 0.03905571232150708, 0.02614735033629196, 0.050017289484718015, 0.07187634600060326, 0.05174617974885872, 0.06632257079971687, 0.2641533027802195, 0.19420077997658933, 0.1437231350157942, 0.1335125807672739, 0.13409351530883992, 0.5184332696454865, 0.21447380499116012, 0.12337319127150945, 0.16221062227019242, 0.183738217822143, 0.10487841655101095, 0.2416474904332842, 0.10022576978164059, 5.7849303143365045, 79.40131064823696, 63.58517483302525, 48.93829229899815, 28.658060482570104, 62.493369647434776, 55.19155291148594, 35.57282086781093, 25.390501601355417, 34.14499385016305, 8.457499316760472, 40.428736209869385, 65.55006286076137, 74.8901093346732, 75.00545637948173, 59.639341490609304, 62.00628008161272, 12.33929979801178, 6.98354755129133, 14.385222928864614, 0.3457443160670144, 4.464534171989985, 53.29510811397007, 58.12151098251343, 59.705877440316335, 61.09897041320801, 62.186551094055176, 58.889526639665874, 63.80282020568848, 57.80933536802019, 61.32912949153355, 58.34773390633719, 57.118392603737966, 61.03812503814697, 61.52568013327462, 59.70747552599226, 57.850816113608225, 60.58227457318987, 60.87915025438581, 60.59964506966727, 57.78815031051636, 61.54434994288853, 59.07306330544608, 58.53152070726667, 55.978749070848735, 53.5659384727478, 50.918299606868196, 51.12206595284598, 55.80084392002651, 55.30843203408377, 56.68273360388619, 54.77125290461949, 51.91568572180611, 44.76516948427473, 43.55702713557652, 46.68036052158901, 44.380121162959504, 46.36031607219151, 45.80485275813511, 50.09190171105521, 51.78476776395525, 45.53897646495274, 46.72097969055176, 52.13976860046387, 53.64866025107247, 48.79333550589425, 49.91388886315482, 50.30072634560721, 49.580330167497905, 43.40485463823591, 34.598172732761924, 37.68383298601423, 44.992511068071636, 42.085916314806255, 49.262026241847444, 45.61733477456229, 42.403198855263845, 25.99573312486921, 19.579941987991333, 47.4877689906529, 46.916012150900706, 48.13027238845825, 42.341988699776785, 39.05282613209316, 41.72641999380929, 48.11145666667393, 47.59139442443848, 50.31089503424508, 51.9375273840768, 50.605571610586985, 45.634861605507986, 41.75027663367135, 42.89804955891201, 46.317164284842356, 47.96177509852818, 48.388439655303955, 46.13136945452009, 42.685254028865266, 41.68838208062308, 42.91243232999529, 43.39878191266741, 41.09234823499407, 46.29801852362496, 46.853825773511616, 49.459747655051096, 48.70529835564749, 52.71851532799857, 53.630622727530344, 53.15228789193289, 55.578991413116455, 48.779758725847515, 46.735709871564595, 47.81608527047293, 47.77755403518677, 51.91515071051461, 53.206066949026926, 55.04907315117972, 54.752291270664756, 55.86961024148123, 54.53859594890049, 54.91346515927996, 53.83147430419922, 50.26701716014317, 50.429229804447715, 56.21628713607788, 54.86783286503383, 60.08176803588867, 50.28424521854946, 48.011055197034565, 50.9413606779916, 35.9343113218035, 22.139957121440343, 0.12519826048186847, 0.6330439139689717, 4.120329099042075, 14.855602945600237, 38.25644792829241, 58.371448108128135, 55.54620286396572, 63.16626793997628, 49.971426895686555, 69.8995726449149, 26.949710369110107, 8.888499549457006, 56.72241129193987, 27.539112159184047, 29.125271252223424, 44.628262179238455, 55.35528721128191, 31.230974946703228, 42.92824990408761, 49.186652183532715, 66.47367300306047, 42.65159000669207, 0.8699635352407182, 0.1598875762096473, 0.24054440962416784, 0.19480074064007827, 0.15745061769017152, 0.17434650606342725, 0.15991819170968874, 0.2558547652193478, 0.19052860273846559], [0.05014867422037891, 0.14481525069900922, 0.05872303965900626, 0.042455681666199646, 0.038507897074201276, 0.10364177290882383, 0.03540039328592164, 0.0351424210571817, 0.08319929734404598, 0.12655660616500036, 0.09507104102522135, 0.03075583465397358, 0.07627811123217855, 0.1762697050081832, 39.75761318206787, 62.465382303510395, 41.15337426321847, 30.55104160308838, 29.88219063622611, 39.898668561662944, 35.20016118458339, 24.847880295344762, 20.249154261180333, 1.1955494987113136, 9.928108998707362, 41.33059849057879, 57.74237905229841, 59.42018835885184, 56.08382320404053, 46.0811687197004, 44.57342004776001, 5.7507043566022595, 1.4285054441009248, 0.6188814767769405, 0.10711452870496682, 6.968793485845838, 35.035457611083984, 44.56516906193325, 48.09921046665737, 57.68069641930716, 61.27551719120571, 52.320032664707725, 55.86746324811663, 54.59857974733625, 54.48642887387957, 57.27320889064244, 57.12428815024239, 58.7274112701416, 58.84175082615444, 55.01604836327689, 56.0636317389352, 53.777729988098145, 51.81853600910732, 51.22644526617867, 54.08722012383597, 53.75622878755842, 52.29198973519461, 48.92670965194702, 47.227531160627095, 43.886482919965474, 45.3336363519941, 46.70489113671439, 49.0375577381679, 50.10788951601301, 47.8841359274728, 41.36275127955845, 37.42750004359654, 39.321679728371755, 39.6734288079398, 42.18912833077567, 44.70856251035418, 49.7196033341544, 48.98209374291556, 46.55576542445591, 41.32733283724104, 42.59033121381487, 44.84782178061349, 42.63655063084194, 36.248932702200754, 32.96584980828421, 28.912663323538645, 26.558462517602102, 20.60971713066101, 19.009121417999268, 19.998598745891027, 23.708410467420304, 24.793498482022965, 28.003333466393606, 28.87243672779628, 27.48586811338152, 14.090105141912188, 9.177524634769984, 25.866343770708355, 27.81659541811262, 26.292266607284546, 24.091671364648, 21.644896234784806, 24.133938993726456, 32.248083523341585, 35.468563147953574, 41.04749066489083, 45.03241457257952, 44.72869838987078, 44.346995626177105, 39.35598298481533, 42.24443599155971, 42.85707255772182, 43.91399778638567, 43.808096817561555, 43.544489111219136, 39.910494395664756, 38.34904657091413, 38.141715799059185, 36.65421417781285, 35.6998165675572, 38.63265119280134, 40.44506447655814, 41.93512303488595, 42.36936460222517, 46.156264850071494, 45.81358664376395, 45.377493381500244, 48.32608304704939, 49.26715401240757, 42.284860610961914, 43.189457007816856, 46.40578160967146, 48.02106755120413, 50.76464366912842, 49.830597332545686, 48.176999023982454, 52.633636134011404, 51.58727216720581, 51.62303454535348, 50.51958417892456, 50.02033526556832, 47.280413900102886, 51.40494796207973, 51.15053967067173, 53.022856848580496, 43.28996270043509, 44.338088035583496, 28.040118966783794, 30.665850162506104, 3.336430077041898, 0.49154949507543017, 6.437015277998788, 23.949045692171367, 48.282594272068565, 53.0529008592878, 48.56569514955793, 45.39788634436471, 47.369211878095356, 46.76218945639474, 22.956498997552053, 1.2479477099009921, 31.690094539097377, 40.12184122630528, 11.591462578092303, 27.30777015004839, 37.57315513065883, 34.235487188611714, 16.56387836592538, 18.441271202904836, 38.20271750858852, 52.85595417022705, 8.388044255120413, 0.1643909995577165, 0.06155474949628115, 0.0166741312547986, 0.013374879407430334, 0.018272959926564778, 0.06337887554296426, 0.019532487162255814, 0.03947251263473715, 0.08094251022807189, 0.06791663276297705, 0.1661151841815029, 0.06225288060626813, 0.03962536282571299, 0.026701450514207994, 0.1506948516305004, 0.011671876102419836, 0.013389536612001913, 0.07280538257743631, 0.15194607020488807, 0.02422215140956853, 0.059187035475458415, 0.044185867932225974, 0.33924354346735136, 46.090736389160156, 72.42084462302071, 41.43324422836304, 27.166084221431188, 44.956950187683105, 31.265035016196116, 27.783426455089025, 35.28734023230416, 30.029777322496685, 6.742703012057713, 7.99699182169778, 41.608047008514404, 64.39803763798305, 64.80205454145158, 60.10994298117501, 50.75852925436837, 50.33310842514038, 11.031654034342084, 1.0596002851213728, 0.9121261813810894, 0.15345619060099125, 6.897488466330937, 40.153396470206125, 51.48570687430245, 55.190826824733186, 61.34737546103341, 62.83542946406773, 54.21062707901001, 59.13190759931292, 56.07491213934762, 59.06706006186349, 58.18672677448818, 58.305495807102744, 61.07659026554653, 58.55772236415318, 54.15329054423741, 57.273618834359304, 55.683395045144216, 53.525336674281526, 53.589631829942974, 54.19091851370675, 54.48282970700945, 53.41983870097569, 50.59669181278774, 48.251108510153635, 44.60851887294224, 46.10143314089094, 48.24173191615513, 49.47670125961304, 48.81055314200265, 48.50619772502354, 43.11397525242397, 37.33389391217913, 40.270994731358115, 40.00266572407314, 41.233389718191965, 46.09891094480242, 48.670804023742676, 49.71831791741507, 49.31948437009539, 45.82045841217041, 46.45963709694998, 50.184382234300884, 51.993345737457275, 47.51861899239676, 46.18824045998709, 41.73166935784476, 38.691061224256245, 31.11842107772827, 26.49703870500837, 27.636788197926112, 31.601616178240093, 32.26612104688372, 36.81361627578735, 34.77939564841134, 33.749804633004324, 22.96843252863203, 24.36981643949236, 33.93272985730852, 34.51233121326992, 37.12548964364188, 33.8568103654044, 33.59246962411063, 36.4921543938773, 44.23083564213344, 45.774405751909526, 48.25452702386038, 46.95658268247332, 44.79415042059762, 43.33957978657314, 40.765157563345774, 45.78128446851458, 48.74653591428484, 48.61080632890974, 47.36234705788748, 44.257436820438926, 42.89326919828142, 40.9781163760594, 39.393590109688894, 36.68134341921125, 36.590078830718994, 41.25698927470616, 39.26012216295515, 42.023712566920686, 45.305006299700054, 47.85923705782209, 48.10653734207153, 47.21784537179129, 50.67415033067976, 48.37226077488491, 41.9928035054888, 43.73611000605992, 47.19212661470686, 50.42498445510864, 52.47412633895874, 52.199252128601074, 49.51084818158831, 55.54947199140276, 54.137174197605674, 54.62609461375645, 52.46417999267578, 52.4307348387582, 50.27346508843558, 56.51672724315098, 56.21981682096209, 55.33802093778338, 45.11294419424874, 49.976565088544575, 31.83637843813215, 37.14950956617083, 1.3119508240904127, 0.2431361691227981, 9.276778783117022, 31.468488693237305, 50.24873644965035, 57.44558674948556, 54.71919352667672, 50.68309266226632, 51.01825291769845, 50.2374004636492, 15.98581256185259, 5.665246290819986, 40.98463378633772, 39.382889883858816, 13.392140354428973, 24.616555656705582, 22.94461931501116, 41.684195790972026, 19.39516680581229, 14.382500972066607, 45.17670781271798, 57.33678838184902, 10.963148270334516, 0.4452640973031521, 0.040912978018500974, 0.1505529292459999, 0.022018931240641644, 0.06476894952356815, 0.08805411362222262, 0.08346198539116553, 0.07923684961029462, 0.04015979736245104, 0.18982627828206333, 0.25961374065705706, 0.19580586813390255, 0.12768161722591945, 0.1413323168775865, 0.23624922867332185, 0.16651831540678227, 0.12632500859243528, 0.1666403567152364, 0.21928598891411508, 0.08073151976402317, 0.21194566493587835, 0.09579446792070355, 0.6111408578498023, 60.54553944723946, 78.49730137416294, 52.16714102881295, 39.78042411804199, 45.91555840628487, 62.31576674325125, 42.061305795397075, 31.63592290878296, 27.65747124808175, 4.127285114356449, 12.923523443085806, 50.39248078210013, 61.6805693762643, 67.26017434256417, 60.54125240870884, 57.00406347002302, 56.34346348898751, 7.772645780018397, 5.536039326872144, 2.4573129415512085, 0.12684840336441994, 13.49721622467041, 46.93790939876011, 52.340800830296104, 58.67036655970982, 62.73465279170445, 62.27842017582485, 55.20277425221035, 59.632379395621165, 56.9801790373666, 58.162324701036724, 61.96476459503174, 61.121906416756765, 61.41603755950928, 61.50644057137625, 56.7474491255624, 60.84086568014962, 58.26371281487601, 56.50025653839111, 58.68772315979004, 57.04159416471209, 59.95758983067104, 55.857419627053396, 55.65196486881801, 53.18921409334455, 50.977321079799104, 50.987844126565115, 54.248626777103965, 54.00935861042568, 58.24588373729161, 56.51046691622053, 48.76183237348284, 44.04692724772862, 45.19093424933297, 45.122383322034565, 46.742456572396414, 47.89636823109218, 51.98438950947353, 51.62342711857387, 51.108892168317524, 45.582645893096924, 50.166143212999614, 51.37471635001046, 54.777975286756245, 52.90468883514404, 53.157519885471885, 50.155304023197715, 49.73131104878017, 42.52342700958252, 37.42800031389509, 42.164903436388286, 44.51638575962612, 43.67895065035139, 48.21623550142561, 46.03281273160662, 41.92457914352417, 30.225660937173025, 34.273208958762034, 51.74127551487514, 48.326691014426096, 47.13344212940761, 44.04941817692348, 39.88004738943917, 42.353241307394846, 50.32100813729422, 49.860867159707205, 53.555547441755024, 53.30135107040405, 48.818963936397004, 48.19793394633702, 40.601336411067415, 46.27341842651367, 47.99645355769566, 47.67249379839216, 48.03529051371983, 46.62678991045271, 44.895156383514404, 47.72415018081665, 44.73051186970302, 41.846832275390625, 39.17341211863926, 45.71031904220581, 42.70269053322928, 46.787220341818674, 50.507042680467876, 52.620132310049875, 50.76161772864205, 51.08023084912981, 53.44262531825474, 50.12333883558001, 43.48940379279, 44.712248529706685, 47.995696204049246, 50.36844348907471, 54.516934939793174, 55.51345252990723, 49.736963408333914, 58.51874297005789, 57.22521768297468, 56.43626362936837, 53.94392742429461, 52.917407512664795, 52.37352337156023, 58.06952803475516, 56.903265953063965, 57.56370265143258, 45.31795079367501, 52.54842342649187, 34.98218924658639, 43.942051138196675, 5.471791505813599, 1.2773191566978181, 7.083172994000571, 28.36408567428589, 56.19616515295846, 59.863671030317036, 56.65974201474871, 52.72182614462716, 55.80575629643032, 54.6531891141619, 29.03077575138637, 3.8358381475721086, 37.44248383385794, 49.03193317140852, 14.77067858832223, 35.95871686935425, 52.135478087833945, 51.205447810036794, 22.07464231763567, 26.707701138087682, 52.266962323869976, 73.55961963108608, 19.70488796915327, 0.5807172475116593, 0.19754242923642906, 0.16621198398726328, 0.10935401996331555, 0.11268680755581174, 0.18521532070423874, 0.12249820679426193, 0.1738866221691881, 0.18590514654559748], [0.026902900775894523, 0.02293268551251718, 0.051993668611560545, 0.04098328442445823, 0.022563023027032614, 0.06551847287586757, 0.08035508889172759, 0.024217968241178563, 0.02590411588815706, 0.05732205483530249, 0.12117499565439564, 0.05920895215656076, 0.1268973257392645, 0.03977378557569214, 18.73386331966945, 67.07895837511334, 39.03736291612898, 35.970230034419465, 25.127197878701345, 43.05530118942261, 46.36085108348301, 19.83864947727748, 33.44975362505232, 20.4019364629473, 0.9729259588888713, 12.12776449748448, 51.352256298065186, 59.29171616690499, 59.04342923845564, 48.028522968292236, 65.79546628679547, 62.587879044669016, 28.65639638900757, 4.731573419911521, 0.19075086366917404, 0.11153088243944304, 9.112161193575178, 27.88172435760498, 39.02744436264038, 40.42456381661551, 44.16404608317784, 53.658551011766704, 55.66474608012608, 61.61421407972063, 60.00898565564837, 56.383884634290425, 56.209481375558035, 58.367821148463655, 53.81971100398472, 58.5421028137207, 53.97400270189558, 54.43704802649361, 53.948693888528005, 50.17587416512625, 51.837685244424, 52.29467521395002, 52.06134080886841, 47.491190978458945, 44.25771822248186, 42.82439865384783, 45.82566956111363, 47.23231846945626, 50.25966944013323, 48.31794670649937, 45.62189279283796, 39.22836194719587, 38.716571535382954, 37.81729051045009, 40.26630122320992, 42.539560726710725, 46.32245533806937, 49.33660820552281, 49.62505224772862, 45.926786695207866, 40.88434001377651, 42.24091672897339, 43.386462756565635, 41.225586891174316, 35.29401050295149, 29.54533154623849, 26.004751886640275, 25.276490347726003, 20.032839468547277, 20.347167287554058, 25.045989070619854, 28.611637830734253, 29.09141615458897, 30.86823729106358, 30.887098176138743, 31.699033396584646, 22.853045531681605, 23.663012674876622, 29.159994874681743, 32.12912341526577, 30.09698029926845, 26.73760792187282, 21.66074160167149, 25.190259729112896, 32.38564395904541, 34.003657068525044, 37.78889322280884, 44.32571676799229, 47.257397992270334, 43.78672415869576, 37.61246109008789, 42.15795176369803, 45.09328079223633, 42.79706791469029, 43.55215297426496, 42.98959902354649, 40.64802483149937, 41.30005073547363, 38.137421812329976, 38.128663608006065, 35.74852343967983, 36.348173822675435, 40.76376792362758, 39.472584179469514, 40.5462441444397, 42.67821897779192, 45.137044021061485, 44.14361490522112, 47.110401902879985, 50.0301912852696, 46.96178688321795, 47.40158700942993, 48.33339255196707, 49.36649588176182, 50.922329562050955, 50.236556257520405, 49.401358468191965, 49.192141260419575, 49.79037421090262, 50.98763568060738, 50.407468046460835, 48.627961431230815, 51.7828118460519, 47.99418149675642, 49.943342276981895, 49.69910614831107, 56.95209094456264, 29.103985445840017, 28.214636870792933, 10.152072020939418, 0.3653259410389832, 7.417836018971034, 41.12780489240374, 47.83545337404524, 46.6678398677281, 48.76375355039324, 46.68533543178013, 50.272263050079346, 48.743975503104075, 29.919922828674316, 1.3146323944841112, 13.416010890688215, 62.272972788129536, 27.846005405698502, 13.875829645565577, 29.64781747545515, 39.47892093658447, 27.732991218566895, 31.370140416281565, 41.612771783556255, 39.15890427998134, 42.68457310540335, 2.6089782203946794, 0.08212873871837344, 0.05412733894107597, 0.048578523831175904, 0.0713986437767744, 0.019858390924387744, 0.060386719315179756, 0.059592541573303084, 0.01057502594111221, 0.07486162188329867, 0.07271363107221467, 0.033637969821159325, 0.016021115938201547, 0.07947268124137606, 0.10917636592473302, 0.13189099063830717, 0.10810751720730748, 0.06384931065674339, 0.06881001232458012, 0.03391868993639946, 0.04590769125414746, 0.0712149507765259, 0.03278701566159725, 0.05911177237118993, 21.677676098687307, 75.30858543940953, 45.78173262732369, 28.619214841297694, 31.84158263887678, 48.10061052867344, 23.92109830038888, 26.39962669781276, 28.729560920170375, 28.667753219604492, 5.6402314731052945, 8.838224121502467, 53.593627044132774, 65.15385573250907, 63.985245159694124, 54.9601640020098, 70.15664209638322, 62.93685231889997, 38.24598741531372, 7.701550943510873, 0.1703569372849805, 0.5698328944189208, 8.401061705180577, 30.326507091522217, 46.840617247990195, 46.27597188949585, 46.53170728683472, 55.75941181182861, 58.29989555903843, 63.48980385916573, 61.99091066632952, 60.06320244925362, 59.9491616657802, 58.56244019099644, 56.09468323843819, 58.68833460126604, 55.049722807747976, 56.38043137959072, 55.58394547871181, 53.960783754076274, 54.35519477299282, 55.44601331438337, 52.59320109231131, 47.781427655901226, 46.57769741330828, 41.5753870010376, 46.56963055474417, 47.47891698564802, 50.726456369672505, 49.23990317753383, 46.600897448403494, 41.221459661211284, 39.487189292907715, 39.14367035457066, 40.46734734943935, 45.155574866703574, 48.09200171061924, 50.44517592021397, 51.81905712400164, 51.29499271937779, 44.60284219469343, 46.856869084494456, 51.63456508091518, 50.59413487570626, 47.259979248046875, 44.1957437651498, 38.236221722194124, 36.73773152487618, 29.23233257021223, 26.48932794162205, 30.810018335069927, 35.85234342302595, 35.97506945473807, 38.32248360770089, 37.58928189958845, 36.96643148149763, 26.21173003741673, 23.757945912224905, 36.826557295663015, 41.26434394291469, 39.91583408628191, 35.86583335059029, 32.46786199297224, 36.462353570120676, 45.43281146458217, 45.947516645704, 45.70839091709682, 47.246273926326204, 47.63333722523281, 45.107778208596365, 40.57578093664986, 46.27349485669817, 50.474240234919954, 48.365458488464355, 48.78405966077532, 46.215119566236226, 43.16300174168178, 43.89863531930106, 39.96338060923985, 38.78076594216483, 36.534461975097656, 38.23514822551182, 41.390950543539866, 40.12094143458775, 41.27685417447771, 43.638918604169575, 46.0156124659947, 46.81513820375715, 48.74991621289934, 51.40991939817156, 48.02699089050293, 50.44691644396101, 50.56632818494524, 49.78559037617275, 52.7212563923427, 49.729709489004954, 51.83921037401472, 50.43771008082798, 52.12380164010184, 54.08205761228289, 53.891496317727224, 51.70519699369158, 55.44888986860003, 51.859700611659456, 55.04746464320591, 54.9915212222508, 56.89558819362095, 32.35401923315865, 31.431180340903147, 7.21664137499673, 0.20858270967645304, 10.872149450438362, 48.315584318978445, 50.71122939246041, 51.22028568812779, 52.215014117104666, 51.63505492891584, 55.968698501586914, 52.939787660326274, 29.428737299782888, 3.1723401163305556, 19.820334025791713, 57.22788231713431, 29.548027447291783, 17.857747588838848, 25.33778735569545, 28.241750478744507, 39.868718351636616, 24.272057022367203, 33.266189166477744, 47.35185180391584, 49.60697998319353, 3.2115351217133656, 0.18977010915321962, 0.08032961668712751, 0.060385464025395255, 0.05463771601872785, 0.01282314901306693, 0.05040237846385155, 0.03613478869998029, 0.05477777582460216, 0.044248635814126046, 0.26220284029841423, 0.061823578285319467, 0.10862874066723244, 0.09585073882980005, 0.20816846404756817, 0.16081707419029304, 0.22429159602948598, 0.15931808176849568, 0.1806432567536831, 0.07580277031021458, 0.17015432672841208, 0.16670500753181322, 0.26869650185108185, 0.2007546140147107, 32.59632723672049, 87.81877531324113, 49.96666043145316, 49.362340859004426, 38.2389349937439, 67.61544963291713, 60.37800448281424, 22.916668449129375, 42.00213493619646, 27.26859794344221, 3.6986846157482693, 16.2119642666408, 58.99055344717843, 68.37816034044538, 67.28834233965192, 58.66942160470145, 71.08070387159074, 69.4629270008632, 36.03142629350935, 5.892220054353986, 0.3487783446907997, 0.5340181876506124, 15.126412459782191, 39.09418528420584, 50.88442366463797, 51.27233116967337, 50.61090782710484, 56.35408728463309, 58.808079855782644, 66.08899293627057, 64.33409336635044, 59.24033423832485, 59.303965841020855, 62.770623615809846, 57.29065234320504, 62.035823822021484, 58.1271459715707, 59.709580830165315, 60.12799440111433, 56.885548046657014, 59.21243722098214, 60.066454206194194, 58.12372398376465, 52.453156675611226, 50.679420539310996, 47.84172759737287, 52.08703177315848, 54.09600612095424, 58.55863952636719, 55.146236760275706, 53.50219917297363, 45.7909494127546, 45.92811032703945, 43.74755368913923, 46.22206776482718, 47.83460916791643, 51.30442837306431, 52.90574843542916, 54.52089541299002, 51.109851019723074, 45.31357690266201, 47.16029691696167, 52.245412485940115, 56.00062200001308, 52.15988710948399, 52.187367234911235, 46.907340799059185, 45.79214450291225, 37.93614639554705, 38.90198768888201, 42.65095772062029, 48.9310314314706, 47.039106437138145, 48.68158415385655, 44.19015393938337, 43.86290420804705, 34.06652436937605, 33.39593982696533, 44.928403513772146, 51.05220876421247, 48.54761593682425, 44.00669370378767, 37.571619578770225, 41.55206537246704, 50.74235732214791, 51.55878455298287, 50.918900626046316, 51.33791521617344, 52.444853578295024, 48.733685220990864, 41.85448571613857, 46.776666028159006, 48.79559367043631, 46.08614362989153, 47.54554326193673, 47.936174460819785, 44.89863395690918, 47.457353251320974, 42.92884397506714, 42.27613714763096, 40.01631893430437, 42.04696471350533, 45.31383746010916, 44.14947918483189, 45.7210123198373, 48.19029092788696, 50.65601205825806, 49.36761801583426, 52.46096992492676, 54.097722326006206, 49.64115122386387, 52.24624974387032, 53.03417893818447, 52.38967793328421, 55.85145459856306, 53.05747972215925, 53.552511078970774, 52.973222391945974, 54.384578704833984, 56.235644817352295, 56.74733795438494, 53.41089289528983, 58.310359546116416, 53.099123750414165, 56.62235723223005, 55.59705325535366, 58.56619916643415, 35.59215423039028, 42.690861225128174, 14.141063230378286, 0.6014783563358443, 8.030588967459542, 48.76425382069179, 55.04033579145159, 54.69624015263149, 55.7470509665353, 54.301690169743125, 56.99910593032837, 56.68258421761649, 36.43499156406948, 4.589501432010105, 18.16442891529628, 69.53587613786969, 36.12603643962315, 18.494798387799943, 38.74644878932408, 56.40221398217337, 40.771820885794504, 39.33567687443325, 55.157572746276855, 51.34336607796805, 65.1485264641898, 6.408945424216134, 0.2576957664319447, 0.1810383948364428, 0.256838749561991, 0.2249423111123698, 0.08711394907108375, 0.22657219293926442, 0.16653521092874662, 0.1421586096818958, 0.15268310851284436], [0.023533302658636655, 0.07305972464382648, 0.02002992288076452, 0.020320162842316285, 0.014689107591818486, 0.03156415306563888, 0.09404509607702494, 0.06712508773697273, 0.06493561129484858, 0.004081341911972101, 0.13437423881675514, 0.06106572930834123, 0.04176036986921515, 0.015860676333042126, 2.035831958055496, 54.60647290093558, 44.48616804395403, 45.60534913199288, 32.99698468617031, 29.320091792515345, 51.096708502088276, 37.38567883627755, 43.44147859300886, 50.53312969207764, 14.053658366203308, 0.8614035717078617, 18.035340070724487, 51.189730984824045, 55.50095272064209, 56.044444288526265, 44.15351956231253, 59.21870449611119, 52.9508352960859, 53.45819623129708, 6.571631848812103, 0.32129091822675293, 0.32215360764946255, 5.71801438501903, 16.047830445425852, 26.712854964392527, 57.907707963671, 49.73564672470093, 46.81723655973162, 53.01609625135149, 56.87656055177961, 59.062404768807546, 55.65625885554722, 56.97260897500174, 56.481409549713135, 56.63857432774135, 53.51241649900164, 52.999670709882466, 44.507009165627615, 45.65232937676566, 47.779662813459126, 49.92102466310774, 50.65865584782192, 47.86135278429304, 43.91416801725115, 40.96630791255406, 44.95617546354021, 47.528801577431814, 46.200660364968435, 45.12780291693551, 41.94666051864624, 36.615693364824565, 37.305722440992085, 40.73152133396694, 45.97636904035296, 47.42046526500157, 49.425006662096294, 50.041992800576345, 50.16543449674334, 46.152724742889404, 42.56006833485195, 45.1172833442688, 45.665867941720144, 38.12442173276629, 34.39340237208775, 29.18134321485247, 26.157719952719553, 24.449098859514507, 21.947670936584473, 23.702700785228185, 26.51374912261963, 31.75838143484933, 32.42234434400286, 33.103125367845806, 34.53640324728829, 31.980814116341726, 27.379338332584926, 26.592946427209036, 29.603432382856095, 34.71691744668143, 31.931725093296595, 29.859918185642787, 24.83346799441746, 24.291819436209543, 33.03506776264736, 34.06525979723249, 39.17568417957851, 42.877243178231375, 45.39811563491821, 45.04104423522949, 37.13277135576521, 40.98514100483486, 44.92903927394322, 44.69721957615444, 42.97625848225185, 42.70784609658377, 43.283886500767295, 42.15729863303048, 40.10787187303816, 41.01344796589443, 36.94555561883109, 39.12400000435965, 38.772560119628906, 39.27020399911063, 39.29584632601057, 40.074409348624094, 42.29896545410156, 45.78062786374773, 45.909628118787495, 50.118784291403635, 48.699486187526155, 50.12942198344639, 47.44905710220337, 49.696559633527485, 49.37259987422398, 49.06580563953945, 45.597449030194966, 40.2358090536935, 52.02961880820138, 50.56198903492519, 51.01277078901018, 49.35599020549229, 44.794636794498985, 49.70927831104824, 47.84336042404175, 51.25965418134417, 29.21940197263445, 30.61221006938389, 8.675428697041102, 0.599343305187566, 2.035559892654419, 33.070753710610525, 48.069399220602854, 45.56309366226196, 52.242959771837505, 47.4776211466108, 52.31904949460711, 47.92553676877703, 47.60156658717564, 18.83800639425005, 4.499167033604213, 37.01451996394566, 65.87851810455322, 16.72113173348563, 13.102708799498421, 27.436555010931833, 34.16304179600307, 26.44018680708749, 25.343585627419607, 26.21658856528146, 49.519714082990376, 24.871964488710674, 0.5614228599837848, 0.1376458089798689, 0.0311082487792841, 0.03541402505444629, 0.0298517172757004, 0.06812067502843482, 0.04254618127431188, 0.004890354973862746, 0.04809108462982944, 0.041458737304700274, 0.04165465411330972, 0.20679136365652084, 0.03321314922400883, 0.04765142107914601, 0.013849160966596432, 0.13894362933933735, 0.10873783552753073, 0.08419422645653997, 0.11730703392199107, 0.030780010856688023, 0.05171043113140123, 0.02015057997778058, 0.02508463727177254, 0.007511944144165942, 2.75519328883716, 62.65861170632498, 55.29951054709298, 42.64666025979178, 30.972613130296978, 43.285533223833355, 33.04350982393537, 33.41422748565674, 43.35141256877354, 46.45858791896275, 23.64378179822649, 1.2602282166481018, 20.074330636433192, 59.07712800162179, 59.4877804347447, 62.90189593178885, 51.18277931213379, 65.37578119550432, 59.40479115077427, 63.13162422180176, 10.881301965032305, 0.17296395025082997, 0.7064172710691179, 5.729313458715167, 20.058332409177506, 34.94557571411133, 64.03582109723772, 52.06097602844238, 49.34311866760254, 55.834438460213796, 59.717515672956196, 61.73244462694441, 58.2067688533238, 57.84617124285017, 60.14345414297921, 57.492664269038606, 56.87054341179984, 53.02286032267979, 48.53854158946446, 47.5559412411281, 52.32199553080967, 53.74479900087629, 53.46258749280657, 49.96538543701172, 45.81983307429722, 42.517479351588655, 47.0691157068525, 46.79986258915493, 49.772364480154856, 46.11810881750924, 43.69754750388009, 38.57545709609985, 38.400362491607666, 42.743427821568076, 47.72263894762312, 48.61355781555176, 50.95691769463675, 51.99754939760481, 51.26749174935477, 47.9658328465053, 44.358272552490234, 47.017174448285786, 52.21286712374006, 49.20275115966797, 45.33837154933384, 42.69971670423235, 39.54269845145089, 34.69329009737287, 32.74673836571829, 29.375201429639542, 34.46174485342843, 39.52096448625837, 38.951198305402485, 39.18535607201712, 40.58970512662615, 38.62277085440499, 31.28100197655814, 34.67730924061367, 38.92706721169608, 44.02192415509905, 42.541996070316856, 40.94311482565743, 33.7774932043893, 36.12147842134748, 43.931135518210276, 44.43540450504848, 46.255662305014475, 45.37877185004098, 47.7122757094247, 45.91271659306118, 39.65519673483712, 44.984604018075125, 49.153860160282676, 47.697621958596365, 45.98518977846418, 45.54021324430193, 47.3892365864345, 46.34082637514387, 43.34604161126273, 42.93577132906233, 39.29334150041853, 40.01083680561611, 38.84637083326067, 38.88641677583967, 40.20992701394217, 41.88534961427961, 42.636495045253206, 47.02037409373692, 47.77284663064139, 50.55193151746477, 50.011309555598665, 50.60666247776577, 49.47804226194109, 50.73842811584473, 49.97654076984951, 48.96403884887695, 48.54282167979649, 41.690584659576416, 54.946656703948975, 52.114588328770225, 53.34713969911848, 53.083361761910574, 48.85384389332363, 53.81990902764456, 53.213928835732595, 52.198859555380686, 32.76932348523821, 39.349969318934846, 8.98308537687574, 1.0269793612616402, 3.9887614846229553, 37.91001769474575, 53.99971103668213, 50.84987027304513, 57.71923460279192, 52.97522347314017, 57.84794650759016, 49.240907192230225, 50.31675583975655, 18.452364001955303, 9.514005916459219, 43.36392627443586, 63.31146444593157, 20.756153890064784, 18.573502370289393, 23.11039812224252, 29.88276038851057, 37.990005356924875, 19.92473418372018, 25.474760668618337, 57.912272930145264, 27.4681293623788, 0.5646814022745404, 0.05301060940005949, 0.11027378096644368, 0.04678844667172857, 0.0564847595856658, 0.09853527442153011, 0.0386196857185236, 0.02453223512774067, 0.11115644646010228, 0.040612498963517804, 0.24007103645375796, 0.3767855832619326, 0.1236356757581234, 0.08414864247398716, 0.099474930071405, 0.26014725917151993, 0.3637897920395647, 0.21623194350727967, 0.19622566417923995, 0.1721189705921071, 0.2703849955328873, 0.11116445317332234, 0.1424934531428984, 0.15384058068905557, 6.173052779265812, 82.51285294124058, 57.9733441216605, 60.77658094678606, 43.580727440970286, 49.402480602264404, 71.48395647321428, 42.881874152592246, 52.61214188167027, 59.23796490260533, 20.537283897399902, 2.6412899494171143, 24.377497673034668, 59.16664859226772, 63.74267659868513, 63.855376379830496, 53.92065790721348, 68.177079473223, 61.99073001316616, 66.75266402108329, 8.685516612870352, 0.29575653267758234, 0.357643540416445, 9.759767174720764, 29.34378514971052, 42.7417949948992, 67.41545963287354, 52.918470587049214, 50.26442895616804, 57.72052001953125, 61.66656180790493, 63.154775619506836, 58.021178994859966, 58.09518078395298, 61.651081221444265, 60.687366076878135, 60.53581196921212, 56.115281173161094, 50.56791932242257, 51.710519313812256, 54.86374385016305, 55.409587383270264, 56.649774823869976, 53.42570298058646, 49.261188983917236, 45.79655660901751, 52.790991987500874, 51.93365028926304, 54.28195033754621, 51.56092459814889, 48.65452092034476, 42.74130514689854, 44.98268978936331, 48.21779537200928, 54.03527886526925, 54.03970834187099, 53.94813803264073, 54.515013762882774, 51.925635542188374, 49.70788172313145, 46.75747857775007, 50.136655058179585, 55.531569957733154, 55.187293665749685, 53.7162766456604, 48.92369065965925, 50.41205733163016, 43.30177116394043, 42.52387864249093, 39.88966369628906, 44.85858106613159, 48.923308508736746, 46.97490855625698, 47.189128467014854, 48.45248120171683, 44.619868755340576, 40.09205429894583, 38.08835015978132, 43.58080734525408, 51.63236250196184, 48.35368129185268, 47.514498710632324, 39.86637333461216, 41.62705380575997, 49.287675516945974, 48.947901657649446, 51.851477418627056, 51.64616162436349, 50.78140619822911, 49.769029344831196, 40.5847475869315, 44.80955457687378, 48.68410982404436, 48.3621198790414, 47.87664229529244, 47.342680181775776, 49.43949365615845, 51.751808983939036, 47.52888148171561, 48.44288573946272, 42.55141435350691, 45.16557332447597, 44.658431257520405, 44.80048022951399, 44.433726515088765, 45.67331641060965, 47.818798542022705, 51.67650440761021, 51.76133496420724, 55.17747238704136, 53.98067992074149, 54.64801965441023, 51.28839193071638, 53.82653066090175, 54.57810688018799, 52.60122626168387, 50.56692573002407, 46.744961397988455, 57.5150339944022, 54.67282819747925, 58.08798592431204, 57.15191418784005, 52.00767639705113, 57.83151749202183, 53.65992675508772, 54.04220969336373, 34.362906728472026, 42.1145463671003, 14.135539412498474, 0.8514343180826732, 2.7503167390823364, 37.57113320486886, 55.885219369615825, 53.44782951899937, 57.284517083849224, 55.279777663094656, 58.73370633806501, 54.0793582371303, 53.96723515646798, 23.759351185389928, 8.671457801546369, 40.11520569665091, 74.72577054159981, 20.567395653043473, 16.762272017342703, 35.663925647735596, 49.52136428015572, 38.48105539594378, 35.3316593170166, 38.62046752657209, 66.7252116884504, 46.184196608407156, 1.0681871729237693, 0.20869681212518895, 0.21061447422419274, 0.16663739830255508, 0.14850318352026598, 0.1621730314301593, 0.08625426555850677, 0.06872805207967758, 0.13755004054733685, 0.14163839045379842], [0.02908317119415317, 0.01554484203058694, 0.12086198745029313, 0.08958488183894328, 0.009694181465809899, 0.030248507591230527, 0.07976419345608779, 0.007637888725314821, 0.0117719116720504, 0.050297436237867386, 0.08402503374963999, 0.06654853653162718, 0.06900340159024511, 0.0578794034996203, 0.2457074640052659, 25.629667282104492, 56.605500902448384, 41.58432585852486, 39.03558765138899, 33.65680994306292, 40.16773407799857, 27.161307334899902, 16.233882359095983, 28.67133675302778, 55.45765849522182, 5.549757242202759, 9.249410697392054, 52.92050640923636, 59.61352893284389, 57.559325286320274, 52.34499059404646, 45.78086410249983, 49.856201444353374, 47.88187081473214, 38.310383319854736, 0.8070582364286695, 0.6786145972354072, 0.27735623717308044, 2.148528482232775, 14.262443048613411, 23.154434067862375, 45.22687380654471, 47.49456432887486, 53.850293500082834, 52.66136986868722, 55.528217451913015, 52.5887507711138, 56.31682756968907, 58.400005204336985, 55.014161927359446, 52.50905840737479, 49.04751450674874, 47.77354839869908, 43.559879371098106, 42.23809923444475, 45.548054286411826, 45.47088411876133, 45.20102303368704, 41.61080196925572, 40.893810408455984, 42.82562153679984, 43.9520982333592, 46.07235492978777, 44.117805821555, 35.440780775887625, 37.329353264399934, 42.319007532937185, 45.310425894601, 45.40777015686035, 48.3990113394601, 47.333314010075156, 51.049259253910606, 49.89267948695591, 46.460866928100586, 41.13326965059553, 44.62618466785976, 41.11934893471854, 36.72126429421561, 30.527365616389684, 28.98595987047468, 25.844847781317576, 25.01661729812622, 24.033309970583232, 24.07055057798113, 30.51539387021746, 33.551232065473286, 35.60912520544869, 35.33609921591622, 40.35749980381557, 34.056470326014924, 30.921290261404856, 32.018845081329346, 31.599333695002965, 36.354521002088276, 32.89312996183123, 33.47373880658831, 26.009269952774048, 26.60699568475996, 32.29929869515555, 34.40133721487862, 38.80460868562971, 42.511142594473704, 45.316880771092, 44.21857901981899, 37.983272552490234, 38.48320238930838, 44.723952770233154, 47.22466502870832, 44.08969688415527, 39.32789141791207, 38.30686753136771, 42.08965791974749, 40.37687485558646, 38.10640157972063, 40.03649302891323, 35.953259059361045, 39.959124837602886, 39.23257255554199, 39.99958072389875, 40.02787378856114, 42.858326707567485, 42.859990801130024, 48.006809847695486, 43.960057394845144, 45.30828237533569, 44.56996331896101, 45.43099798474993, 43.774971280779155, 45.67610958644322, 44.42259897504534, 48.29726539339338, 44.326151030404226, 42.16196434838431, 46.31088311331612, 43.37750652858189, 40.875178813934326, 46.95918825694493, 40.14785180773054, 44.35592753546578, 28.73198757852827, 42.59349264417376, 29.25870098386492, 2.4247525972979407, 5.321849380220685, 15.642163344791957, 49.108411993299214, 44.76066357748849, 42.21941900253296, 41.91343770708357, 52.33926180430821, 44.72119780949184, 55.27525438581194, 38.3574469430106, 5.779436460563114, 7.366309915270124, 58.29649094172886, 38.89504643848964, 10.502088393483843, 20.62953165599278, 32.251950195857454, 32.31111063276018, 25.474512270518712, 16.276500872203282, 30.62108986718314, 44.415539605276926, 7.606710638318743, 0.10243842498000179, 0.10624727274158172, 0.07142874359020165, 0.09731921753180878, 0.048157421605927606, 0.048827223878886016, 0.04697404296270438, 0.04979320329480937, 0.028695171299789633, 0.011940023811933185, 0.0471093326673976, 0.06441595525081668, 0.1474275698087045, 0.01817487768961915, 0.041892175296587605, 0.020147594423698525, 0.05967515999717372, 0.004439817899505475, 0.06313156988471746, 0.11752211595220224, 0.0651564405166677, 0.07167562177138669, 0.08863422035106591, 0.1006786511944873, 0.4588756454842431, 29.266482966286794, 68.30204977308, 45.91991492680141, 37.820344243730815, 50.61175898143223, 43.09661170414516, 26.650321177073888, 30.287392207554408, 29.44328682763236, 57.110304900578086, 10.944486277444021, 9.163797599928719, 58.2495002746582, 70.63553973606655, 60.70890549251011, 58.50125435420445, 54.295784200940815, 59.360572814941406, 53.680854729243684, 48.3302971294948, 2.156303950718471, 0.5618312294994081, 0.7692936371479715, 3.3173659571579526, 22.00816195351737, 31.689274651663645, 52.05600111825125, 52.66560826982771, 58.32644462585449, 54.722664151872905, 57.659295967647004, 56.61323424748012, 56.883036272866384, 59.83245277404785, 56.8502060345241, 55.8245199067252, 53.363137926374165, 50.06194107873099, 46.599775314331055, 46.42724459511893, 50.326681341443745, 49.25411571775164, 46.346961634499685, 44.9520378112793, 43.36410345349993, 45.391170910426546, 46.52396699360439, 47.54384790148054, 47.17625345502581, 37.66914449419294, 40.907644271850586, 45.801545415605815, 46.43241058077131, 48.72848449434553, 51.8957895551409, 50.366452830178396, 52.435063566480366, 51.964806011744905, 48.116195338112966, 45.08055864061628, 49.73571968078613, 52.4029872076852, 48.129570620400564, 43.443392821720664, 43.237444741385325, 38.0160367829459, 36.58126156670706, 29.729149614061626, 30.809128965650284, 38.39428629193987, 39.91895382744925, 42.638072286333355, 43.48213250296456, 45.899532386234824, 40.032879965645925, 34.14776965550014, 37.90534850529262, 40.79658426557268, 45.5404703276498, 43.18690354483468, 44.20656558445522, 35.2564172744751, 35.69077696119036, 43.633360045296804, 44.531595366341726, 45.69634621483939, 45.977817739759175, 47.72293424606323, 46.8424585206168, 40.4121994972229, 42.08896309988839, 47.30443034853254, 50.9871632031032, 48.210572719573975, 44.205443450382774, 44.737268992832725, 45.26928908484322, 44.527812072208945, 41.066848346165244, 41.49112619672503, 36.76115737642561, 41.25697190420968, 41.079299518040244, 41.775373526981895, 41.25078453336443, 43.663021905081614, 43.544711453574045, 49.98083128247942, 44.80674055644444, 47.261803150177, 47.11497034345354, 47.04123953410557, 47.086632115500315, 49.220899854387554, 46.267495087214876, 50.37360947472708, 44.31169877733503, 45.42630100250244, 49.136590412684846, 48.696752071380615, 47.04793759754726, 52.515704359327046, 44.7943970816476, 48.6797776222229, 33.08175270898001, 52.32815163476126, 25.689552068710327, 5.176694129194532, 11.84245148726872, 20.693279641015188, 56.54404408591134, 50.53664895466396, 45.94306285040719, 47.41722393035889, 56.23343529020037, 49.42680277143206, 62.593972614833284, 39.63031870978219, 5.574679562023707, 15.922207014901296, 55.71505798612322, 43.52993263517107, 15.297325985772268, 24.191185201917374, 19.828904628753662, 35.11203718185425, 31.49994318825858, 13.428095545087542, 34.876448086329866, 52.16475779669625, 8.233131561960493, 0.3007578785930361, 0.05091827542388013, 0.07117360763783966, 0.028202904321785485, 0.07810561638325453, 0.017623662981869917, 0.02618863749583917, 0.025157723974968706, 0.012826280452177992, 0.03170395163553102, 0.14175682195595332, 0.1236290939684425, 0.2616107506411416, 0.1669899650982448, 0.08113241182374102, 0.18233732799334185, 0.21355175732501916, 0.11444455252162047, 0.1097665149718523, 0.16010571164744242, 0.2590751738420555, 0.14073915513498442, 0.1261747402272054, 0.23901561594435147, 0.47960418462753296, 45.7813400541033, 76.6849957874843, 56.31149135317121, 53.38658114842006, 50.31635284423828, 55.327935627528596, 33.97105959483555, 22.11997410229274, 34.53919642312186, 61.52848025730678, 9.256529995373317, 15.323452949523926, 62.63042286464146, 70.7522416796003, 64.84481375558036, 63.66694818224226, 56.34984540939331, 61.06989220210484, 56.02175842012678, 47.66140794754028, 1.1998372972011566, 0.7323513137442725, 0.6051714324525425, 8.21564815725599, 29.147675718579972, 37.11885758808681, 55.337298325129915, 53.32142441613333, 58.42080116271973, 57.02666596003941, 59.268404960632324, 55.18859297888619, 56.98515394755772, 61.358256340026855, 61.031260217939106, 59.04828602927071, 53.76373631613595, 52.1717963218689, 48.74816179275513, 47.52015107018607, 53.80306659426008, 52.72746808188302, 49.99780225753784, 49.17592763900757, 48.02934285572597, 50.481195381709504, 51.23683629717146, 53.61026797975813, 52.44705615724836, 41.40857812336513, 46.12765564237322, 49.58235904148647, 52.1989985193525, 51.33350658416748, 55.26122597285679, 52.60144860403878, 55.81542818886893, 54.0559914452689, 49.810624735695974, 45.71860476902553, 52.86303785869053, 56.145081996917725, 52.17759459359305, 50.11536577769688, 52.06101424353463, 47.692219734191895, 43.601794379098074, 41.24107442583357, 39.8698022706168, 47.40156963893345, 49.312338147844585, 51.010825293404714, 49.190004689352854, 53.87002290998186, 45.98423787525722, 39.2460173198155, 40.758185046059744, 42.40184048243931, 51.32407440458025, 47.29461254392351, 50.80506134033203, 39.31113931110927, 41.76697315488543, 48.72809886932373, 48.61291858128139, 48.89973674501692, 50.64799036298479, 54.081275939941406, 48.61253295625959, 42.56592219216483, 44.33434990474156, 46.41849333899361, 51.567216191973, 49.54242079598563, 43.31617477961949, 45.454396043504985, 47.51983840124947, 47.20934772491455, 45.286312171391074, 46.38386351721627, 42.1978691646031, 45.29421922138759, 45.27162715366909, 45.72660214560372, 45.88414907455444, 48.581123624529155, 47.73958560398647, 54.81058318274361, 50.29441390718733, 52.152414321899414, 51.408561025347026, 50.88905463899885, 50.282612391880576, 52.79456683567592, 50.19374145780291, 54.94562142235892, 53.20136301858084, 51.706736019679475, 52.998930726732524, 53.546063150678364, 51.845929282052175, 57.935580662318635, 46.86002704075405, 51.77579416547503, 37.6393540927342, 56.20951959065029, 34.714763505118235, 4.075732520648411, 12.77105130468096, 19.04275417327881, 57.571453366960796, 52.09707539422171, 49.05330583027431, 48.84418242318289, 59.46512235913958, 51.25773647853306, 62.876576696123394, 44.812347752707346, 9.43344589642116, 10.73088823046003, 63.361428941999165, 48.443861961364746, 13.084371634892054, 26.254946095602854, 42.84670237132481, 45.484665870666504, 34.337823731558665, 25.422807250704082, 40.33769048963274, 65.12287371499198, 18.551608596529277, 0.4183422704892499, 0.27947885755981716, 0.20221779335822376, 0.20528346885527882, 0.16126037468867643, 0.10718215150492531, 0.12355288091514792, 0.12290709199649946, 0.11574088010404791, 0.13713256509176322], [0.03210321860387921, 0.05734412757945912, 0.009557955382790948, 0.013396810507401824, 0.05369429449949946, 0.023164379776322415, 0.06368490840707507, 0.041788047312625816, 0.026363567216321826, 0.014696624063487564, 0.007436824380420148, 0.06194280367344618, 0.046253150395516834, 0.04449692874082497, 0.039490381854453256, 4.323150490011487, 53.40123837334769, 34.96663570404053, 33.315583910260884, 29.362562656402588, 40.64081954956055, 32.3187050138201, 10.592357652527944, 15.766671589442662, 52.08967208862305, 17.008217402866908, 1.287580560360636, 11.567082217761449, 45.198691913059776, 62.11108670915876, 56.0573262487139, 47.89372444152832, 52.5171217918396, 52.93076195035662, 49.0394024848938, 12.241919926234655, 1.390656652195113, 0.9038321492927415, 0.199237124728305, 17.08775516918727, 14.137750676700048, 11.80518742970058, 31.05116251536778, 37.95752600261143, 45.135133266448975, 43.13574743270874, 52.08351598467146, 46.25772244589669, 50.095219475882395, 55.032324518476216, 53.387112685612266, 49.968932492392405, 46.32799652644566, 42.34587621688843, 41.266463143484934, 43.439262117658345, 42.3146892275129, 43.14144842965262, 40.083806787218364, 38.80915975570679, 40.781742913382395, 40.40669999803816, 40.20922524588448, 38.253279549734934, 36.95281301225935, 42.72012703759329, 45.84296015330723, 46.707298687526155, 49.6355961390904, 48.861070019858225, 48.80875355856759, 51.427425384521484, 52.61653314317976, 43.0566908291408, 40.161397320883616, 42.61625494275774, 40.732563563755576, 36.81598908560616, 30.309310300009592, 30.58461877277919, 27.622228247778757, 25.526083537510463, 26.063846315656388, 27.83842318398612, 31.719447204044886, 34.786065919058665, 36.295760086604524, 37.439690658024375, 41.205794947487966, 38.183940001896445, 33.49738005229405, 32.59356532778059, 33.60710947854178, 36.93579339981079, 35.99096345901489, 37.36843340737479, 29.285819802965435, 27.420737436839513, 34.78047956739153, 36.63356065750122, 38.16060100282942, 39.76569741112845, 47.81341716221401, 44.37354816709246, 39.99216004780361, 37.25449684688023, 42.89996031352452, 48.40628957748413, 46.25959151131766, 44.12208938598633, 39.409067222050254, 38.139127595084055, 38.931472369602744, 39.480956758771626, 40.293968949999126, 37.91628496987479, 39.32132537024361, 41.59850713184902, 39.268546853746685, 39.711216585976736, 42.86692162922451, 42.43169341768537, 44.607209137507844, 46.079115527016775, 48.033032349177766, 44.698425088609966, 41.6203487941197, 42.06772593089512, 38.81003870282854, 37.47000217437744, 34.772798333849224, 41.12002638408116, 29.71824094227382, 26.353108508246287, 29.255508286612375, 36.44398600714547, 32.2973393031529, 30.166802746909006, 24.759367193494523, 16.621202741350444, 14.669365167617798, 1.5028869956731796, 1.8323893547058105, 11.104567561830793, 35.56538282121931, 47.968563488551546, 43.33433737073626, 45.126805850437705, 52.655616760253906, 51.88232742037092, 55.339598178863525, 49.23068986620222, 13.609927296638489, 2.500773706606456, 26.86892887524196, 49.51152910505022, 17.204031535557338, 11.711774979318891, 27.157669952937535, 39.897966793605256, 32.76413665499006, 19.683345079421997, 28.45925341333662, 41.93254177910941, 37.48913403919765, 0.2621922551521233, 0.0468997365928122, 0.055711355193385055, 0.04951211677065917, 0.007644865761644074, 0.07771391168768917, 0.023233714180865457, 0.02095389080100826, 0.01597970494601343, 0.038495510417435846, 0.05319120828062296, 0.0542502691304045, 0.05671442333342774, 0.045766779886824746, 0.045069530872362, 0.06953105077679668, 0.040051621917103014, 0.05380345382062452, 0.081645302873637, 0.041737252181129794, 0.017490419060257927, 0.026161501184105873, 0.06558705241020236, 0.08332258037158422, 0.04386869691578405, 0.05539744793038283, 5.174015598637717, 63.39313357216971, 45.111113343920024, 35.599071162087576, 38.31151587622506, 47.26560728890555, 22.971668652125768, 20.549630846296036, 23.432176147188457, 55.10216433661324, 30.593832084110804, 4.557478487491608, 9.129234654562813, 49.235289573669434, 66.87067917415074, 66.03160081590924, 55.62606545857021, 58.04350355693272, 60.894596099853516, 56.62319796425955, 17.680120365960256, 0.2861729583569935, 3.6686232345444814, 3.4073086508682797, 28.17873900277274, 22.736213309424265, 18.70341805049351, 38.22669226782662, 43.62641532080514, 48.79505171094622, 49.85796628679548, 57.20398746218, 54.33275556564331, 55.118520396096365, 58.669692584446494, 57.15840033122471, 54.41934401648385, 48.337512833731516, 46.95852470397949, 45.19816037586757, 47.48757791519165, 46.78539991378784, 46.55258662360055, 43.70054565157209, 42.35741370064871, 44.16988951819283, 44.24834510258266, 43.350311279296875, 42.27419512612479, 39.55777256829398, 46.149021353040425, 51.847798347473145, 48.89355284827096, 52.4245092528207, 50.84784834725516, 52.85525587626866, 53.53920875276838, 54.01446206229073, 48.003714425223215, 42.52638346808297, 49.22889723096575, 50.777282442365376, 46.44483743395124, 42.74020038332258, 41.623656136649, 41.508204868861604, 35.573303767613, 32.552821091243196, 35.386268683842246, 39.6705070904323, 43.040386881147114, 45.44621801376343, 45.50900193623134, 47.767656326293945, 42.44684049061367, 40.89169120788574, 45.11463608060564, 44.00545345033918, 46.25423445020403, 45.21326923370361, 46.191123962402344, 37.33213949203491, 35.67104755129133, 44.4693603515625, 45.306260449545725, 44.610985483442036, 44.60575348990304, 48.7532548223223, 46.26107495171683, 41.29887301581246, 39.45577301297869, 48.455573150089805, 49.08618123190743, 49.52828121185303, 47.68357964924404, 43.01120444706508, 42.13132626669747, 43.77049316678728, 42.29725272314889, 43.345860958099365, 41.54094478062221, 41.24384675707136, 42.0416910307748, 39.02580458777291, 41.459251335689, 43.52193178449358, 44.20231328691755, 45.99188436780657, 46.994036946977886, 48.88356133869716, 47.61499745505196, 42.938394274030415, 45.80899388449532, 40.82315417698452, 41.257906436920166, 37.25697387967791, 45.740283148629324, 35.50261626924787, 29.48571252822876, 35.11388192858015, 38.90741423198155, 34.68359736033848, 33.71359757014683, 27.053169046129497, 18.546991518565587, 13.090200304985046, 4.20723933832986, 3.7585646254675726, 12.37259817123413, 42.75060878481184, 53.38942296164376, 48.42861066545759, 50.70559787750244, 62.16137777056013, 58.59466593606131, 66.81366225651333, 53.03456456320626, 11.572816218648638, 8.677273443767003, 34.75140135628836, 46.25883068357195, 22.68774093900408, 16.47794999395098, 25.985821519579204, 25.251009566443308, 44.93375015258789, 21.686370032174246, 22.32499807221549, 48.83048057556152, 43.54950223650251, 0.7641344911285809, 0.13648908319217817, 0.07053969308201756, 0.11662072289202895, 0.0501793032911207, 0.08460306416132621, 0.017269918927922845, 0.08110145027084009, 0.024604907924575464, 0.011386095812278134, 0.22824932794485772, 0.11774441759501185, 0.1650475093296596, 0.16418492847255298, 0.1104073573702148, 0.12075893155166081, 0.10565240109073264, 0.1586161915745054, 0.15169647788362844, 0.12871167409632886, 0.09901563650263207, 0.14676056988537312, 0.1822636662317174, 0.12397929946226732, 0.12203406170010567, 0.09355529557381358, 11.305457353591919, 88.136613709586, 46.28271859032767, 49.29734740938459, 40.013345105307444, 58.26611341748919, 43.169904776981895, 12.71605544430869, 22.73091357094901, 58.29396874564034, 22.039197819573538, 2.3403543489319936, 15.815350668770925, 54.77722488130842, 70.58998734610421, 64.95205225263322, 55.85076672690255, 63.46310888017927, 62.656770433698384, 60.768111092703684, 15.222068309783936, 1.520152509212494, 4.564702876976558, 4.625360216413226, 41.86051327841622, 29.17379399708339, 29.11242229597909, 45.789368697575156, 45.941364015851704, 51.98317704881941, 53.19288274220058, 59.991455350603374, 55.942201546260286, 54.56050361905779, 60.77241897583008, 58.96841648646763, 56.914765221732004, 50.69899014064244, 48.27832112993513, 46.58666058949062, 49.39088405881609, 48.885534627096995, 49.53382934842791, 45.76574829646519, 46.06025116784232, 45.08157655170986, 46.3090626852853, 47.25309010914394, 45.38441726139614, 44.32176671709333, 52.90776341302054, 55.71619054249355, 53.30898019245693, 57.506744793483186, 53.47659158706665, 55.500289167676655, 54.68642929622105, 54.26223829814366, 48.599140303475515, 45.519396441323416, 50.48908506120954, 55.09240211759295, 53.759629930768696, 50.678030899592805, 50.950122356414795, 48.62800312042236, 43.583590098789756, 41.116816316332134, 44.181211607796804, 45.47312838690621, 48.441819190979004, 49.45734010423933, 49.93517814363752, 52.498517990112305, 48.877130780901226, 40.76346220288958, 45.17817735671997, 43.510786873953684, 50.7879444531032, 50.2570013318743, 52.11620378494263, 42.103342396872385, 40.14424221856253, 49.76708732332502, 49.61157969066075, 47.20687764031546, 46.83986684254238, 53.642559732709614, 49.81948716299874, 44.6642746925354, 41.8598393031529, 48.859284332820344, 51.03778430393764, 49.88239615304129, 47.10633373260498, 42.974160126277376, 44.6714243888855, 46.681229046412874, 46.37526512145996, 47.745804241725374, 45.03287662778582, 44.548865113939556, 46.489830493927, 42.22656175068447, 45.8858757019043, 47.100952352796284, 47.33560691561018, 52.024636949811665, 50.529527051108225, 53.3854763848441, 50.71632242202759, 47.07997921534947, 47.853640283857075, 44.89879376547677, 46.70897320338658, 45.02841935838972, 48.800589425223215, 42.96765661239624, 33.431323528289795, 39.84508058003017, 42.80917515073504, 42.22973360334124, 41.918572425842285, 35.661240168980186, 27.34278907094683, 25.112655299050466, 2.648806597505297, 5.551471275942666, 13.744927321161542, 41.330699239458355, 56.4764415877206, 50.80751058033535, 52.97912836074829, 61.19674546377999, 59.14872918810163, 64.00929287501744, 57.10692112786429, 20.42948259626116, 4.493363550731114, 32.86099106924874, 57.034534794943674, 24.207916464124406, 15.454634938921247, 34.43126310620989, 55.68702547890799, 47.93823112760271, 25.55248669215611, 41.95700986044747, 56.03916365759713, 61.6653528213501, 3.929961051259722, 0.3599040391189711, 0.21388362880264009, 0.14290279974894865, 0.09268526440220219, 0.19882574251719884, 0.11391381600073405, 0.13317811728588172, 0.21055203543177672, 0.09353388779397522, 0.19937033472316606], [0.028047709792320217, 0.029033590640340532, 0.019114865821653178, 0.007499280984380415, 0.022004792267190557, 0.03409163833462766, 0.04214694484003952, 0.014931926437254463, 0.04151084200878229, 0.04728731579546418, 0.008530121562736375, 0.08416241673486573, 0.013963894452899694, 0.015712016095806445, 0.07988791074603796, 0.29240766380514416, 22.64511374064854, 52.41957255772182, 30.297150952475413, 21.5477899483272, 29.981869493212017, 51.45217834200178, 23.603998150144303, 11.653825266020638, 34.85821253912789, 65.49310847691127, 5.7347308823040555, 0.643182747066021, 8.425997921398707, 45.39287321908133, 44.12811347416469, 36.02219213758196, 54.499717303684776, 50.54170376913888, 51.61673600333077, 28.90421257700239, 0.24227934224264963, 2.199819867100034, 14.318383863994054, 1.467781547989164, 16.669127941131592, 5.384367534092494, 22.46939900943211, 40.400856563023154, 44.48458385467529, 41.86381367274693, 44.89078944069998, 50.47516434533255, 52.345897333962576, 56.37437949861799, 52.30628565379551, 49.518522466932026, 48.85754033497402, 43.145176138196675, 41.41464390073504, 41.28733900615147, 39.687488487788606, 40.32233149664742, 39.53230742045811, 37.74022109167916, 38.11784873689924, 40.998658725193565, 40.10096536363874, 37.96410247257778, 39.910400594983784, 45.56531013761248, 44.60095575877598, 47.577105454036165, 46.08661610739571, 48.84007256371634, 48.9011298588344, 52.52308682032994, 49.98374605178833, 39.519818033490864, 39.47448798588344, 43.095722334725515, 38.693100520542686, 36.07628386361258, 31.608411516462052, 32.47832250595093, 28.38117824281965, 27.622952597481863, 27.222399371010916, 28.435134478977748, 33.89510188783918, 35.93393611907959, 36.82178040913173, 39.60484313964844, 42.31414726802281, 41.43086794444493, 37.70928771155221, 33.024113927568706, 37.92943096160889, 39.70469570159912, 39.46077224186489, 36.53615386145455, 31.13191795349121, 29.74422025680542, 34.45304223469326, 38.72339119229998, 41.11659049987793, 42.25764104298183, 44.47182348796299, 46.56974867412022, 40.78836802073887, 36.57549108777727, 39.267949308667866, 46.67291900089809, 47.69611419950213, 47.22550228663853, 44.56299080167498, 42.568433965955464, 40.090650762830464, 37.91654552732195, 40.71327883856637, 38.5504401070731, 39.66087688718523, 39.56992149353027, 41.29430110113961, 41.93851375579834, 41.94489915030343, 44.92279631750924, 46.73116227558681, 46.00821958269392, 46.40464905330113, 48.03177472523281, 46.751246043613975, 42.06730209078108, 35.73554767881121, 31.07451888493129, 23.80113765171596, 18.772719383239746, 19.288173232759746, 16.46539807319641, 20.145690373012, 13.992436051368713, 14.9791054385049, 8.838894622666494, 5.03047102689743, 2.6268016525677274, 3.0425453782081604, 1.9591781284127916, 3.130726703575679, 24.229367290224346, 44.95097821099417, 50.63619579587664, 47.40834065846035, 42.06191028867449, 43.472662108285085, 46.89597007206508, 32.50715058190482, 12.905287895883832, 1.1809223464557101, 5.507936903408595, 57.667658124651226, 49.489545004708425, 15.23294745172773, 16.458062512534006, 33.494454860687256, 33.9097695350647, 26.76639951978411, 23.962044034685405, 27.430713312966482, 47.54766246250698, 22.894128492900304, 0.3569404695715223, 0.1210596039891243, 0.06453274469822645, 0.09802849018680197, 0.08838081466300146, 0.05291283589654735, 0.0045670084405823475, 0.03950219175645283, 0.019669819257355163, 0.054434169083833694, 0.09094790262835366, 0.023750410115878497, 0.03363541513681412, 0.07069007679820061, 0.05584583404873099, 0.04866584450272577, 0.040041844227484295, 0.05973863694816828, 0.03380653488316706, 0.07662436086684465, 0.030727156371410404, 0.037306533860308785, 0.060369918788118024, 0.029558332304337194, 0.024399456002616456, 0.1569904623819249, 0.24213861407978193, 29.196361746106827, 65.92583533695766, 35.65989569255284, 24.087471178599767, 38.60249253681728, 36.32211460386004, 24.376794167927333, 21.45674249104091, 37.47683572769165, 66.30076708112443, 15.091978924615042, 4.073721017156329, 7.272842313562121, 50.63862419128418, 49.33367953981672, 45.16976656232561, 60.678500175476074, 58.910357339041575, 58.45268644605364, 35.31471960885184, 1.5801730028220584, 3.861005391393389, 18.063372577939713, 4.651858040264674, 24.94789092881339, 11.928643022264753, 29.636491911751882, 47.511712482997346, 50.68415921075003, 47.7857529095241, 51.730978284563335, 55.86380502155849, 57.42381804330008, 60.259954588753835, 58.5267333984375, 53.38639007295881, 52.59222487040928, 48.08208315713065, 46.18809454781668, 45.41545833860125, 44.451791831425254, 44.23358365467617, 43.31732818058559, 41.82521642957415, 42.59106772286551, 43.86664233888899, 44.20226812362671, 40.781801973070415, 44.34726313182286, 49.18524169921875, 48.859294755118235, 50.9178375516619, 48.37638800484793, 49.73864139829363, 51.769585950034006, 54.346617221832275, 50.92378520965576, 44.742605209350586, 44.216550145830425, 50.52187361036028, 50.71924066543579, 46.48040178843907, 43.16987351008824, 43.636927945273264, 39.98859909602574, 36.59468896048409, 35.960384437016074, 38.06904111589704, 39.488492080143516, 44.15212992259434, 43.45161601475307, 47.45225327355521, 47.04311554772513, 48.76322201320103, 46.54029178619385, 42.035364695957725, 48.70880719593593, 46.20692069189889, 48.404243332999094, 45.27028267724173, 39.21062319619315, 36.61761801583426, 45.509054047720774, 46.15343345914568, 47.659306117466514, 45.605672223227366, 46.9031788281032, 47.92956324986049, 42.243237427302766, 39.7844888142177, 42.12247426169259, 49.50633880070278, 50.4539167540414, 49.18334484100342, 47.237682478768484, 44.442891189030235, 44.19472237995693, 42.796081270490376, 42.26014239447457, 41.64038045065743, 39.91033111299787, 41.33603893007551, 41.169042451041086, 42.67181968688965, 42.64582300186157, 44.35110548564366, 46.078180994306294, 48.389846665518625, 48.060832091740195, 49.52421998977661, 47.76977552686419, 43.189189502171104, 39.29979290281023, 32.844068731580464, 26.189987386975968, 20.71792663846697, 22.1699663911547, 18.340947900499614, 20.880679505211965, 16.736002615519933, 16.70187827519008, 10.604840091296605, 5.372675018651145, 4.808315404823848, 2.3495392160756245, 3.424259215593338, 5.084007331303187, 28.596794741494314, 51.245684828077046, 53.936329569135395, 55.77851240975516, 49.25227444512503, 48.47046661376953, 51.201692308698384, 38.41998420442854, 12.905784692083087, 4.257168224879673, 14.001799617494855, 53.19182314191546, 50.863572120666504, 19.884884527751378, 23.745805672236852, 26.074301617486135, 27.875156572886876, 39.362437861306326, 17.66657485280718, 24.288486037935527, 57.54371615818569, 23.953277145113262, 0.4868071866886956, 0.08711602538824081, 0.04980621420379196, 0.1016246782881873, 0.1751663934971605, 0.029194895377648727, 0.04610404232516885, 0.07761451309280736, 0.03461573539035661, 0.13869912603071757, 0.07320219664169209, 0.10803017100053174, 0.1690499567027603, 0.1291695088148117, 0.08792989421635866, 0.1841516356383051, 0.13767851436776773, 0.0923683817631432, 0.11299366823264531, 0.16593568452766963, 0.15941481372075422, 0.12749355446015084, 0.1532306591314929, 0.12875957866864546, 0.07553612640393631, 0.25993609907371656, 0.574954802436488, 46.57104103905814, 76.2626564843314, 43.20101533617292, 34.47771528788975, 43.41176462173462, 76.19792706625802, 27.33115083830697, 16.82459041050502, 39.49055569512503, 74.72574969700405, 9.949026550565447, 2.2831821824823106, 11.142150368009295, 55.17592988695417, 52.796960490090505, 47.40310171672276, 64.4392751966204, 60.47196497235979, 60.799454416547505, 37.24103471211025, 1.5825118316071374, 4.221156145845141, 19.638685532978602, 9.097601243427821, 36.50256974356515, 16.93241081918989, 39.43318441935948, 51.98545953205654, 56.25295972824097, 51.167545386723106, 55.250657762799946, 57.67616966792515, 59.509194782802034, 63.714640617370605, 58.767821993146626, 54.0828149659293, 53.48345988137381, 48.170749119349885, 47.78718076433454, 47.648341860089985, 45.53922660010201, 46.95390067781721, 45.73961264746529, 44.90660701479231, 45.45581695011684, 48.04229777199881, 47.61572354180472, 46.00835854666573, 48.51552220753261, 54.106108801705496, 52.07038388933454, 53.889766216278076, 48.268506799425396, 52.64475672585623, 51.39503288269043, 57.026499203273225, 50.64641659600394, 44.43867015838623, 45.06098556518555, 52.3867701121739, 54.812480040958945, 51.76411771774292, 51.16103492464338, 52.51944943836757, 48.50401251656668, 43.20883900778634, 42.96828195026943, 42.8554744720459, 43.69919075284685, 46.77835096631731, 47.48436784744263, 50.501581396375386, 51.63276549748012, 51.747289180755615, 48.45800849369594, 43.67020286832537, 47.9858158656529, 51.92907837459019, 51.329650333949495, 49.00352198737008, 42.7935972894941, 42.4074581010001, 48.6629456111363, 50.89741332190377, 51.633290086473735, 48.770257064274375, 52.271951130458284, 53.39236552374703, 46.71319770812988, 41.865311009543284, 42.432412556239534, 50.27651187351772, 51.15295416968209, 49.31498193740845, 49.07071801594326, 49.26323870250157, 47.914780957358225, 46.867774282182964, 49.30290944235665, 45.84688935961042, 42.98304687227522, 45.361974579947336, 44.913009779793875, 47.957227502550396, 46.25755916322981, 50.13230201176235, 52.596859318869456, 52.70493854795183, 51.286165033067974, 54.33870322363717, 52.87530837740217, 48.222422872270855, 40.18396854400635, 35.13949646268572, 29.96980742045811, 22.202774047851562, 24.10849642753601, 22.155191046851023, 24.34060968671526, 23.097243445260183, 22.124243770326885, 16.89233708381653, 7.463556034224374, 7.584907191140311, 2.4245204840387617, 5.5619061674390515, 6.260040317262922, 29.504524775913783, 54.54749311719622, 56.741709913526265, 57.44858489717756, 49.740413188934326, 52.19104978016445, 53.43833827972412, 41.173732485089985, 18.730628933225358, 2.933005073240825, 9.088284577642169, 64.63773659297398, 58.4487190246582, 20.499556916100637, 21.690483365740093, 44.104774475097656, 47.552779810769216, 39.24028505597796, 29.271992887769425, 37.827848298209055, 62.741184098379954, 41.31700781413487, 0.6906564225043569, 0.18225977144071034, 0.27963242360523766, 0.1529948003590107, 0.27511861867138315, 0.11333154474518128, 0.1024696918736611, 0.115549058254276, 0.09415291529148817, 0.1631304579121726, 0.17579466264162744], [0.06942432400371347, 0.10052114964595862, 0.022007811748023545, 0.08297926200819866, 0.037946833430656364, 0.026474139586623226, 0.04861174151301384, 0.09234316740185022, 0.02031960983627609, 0.06016318273863622, 0.047732210851141384, 0.06387436895498208, 0.17044786097747938, 0.032339643953101974, 0.08957158933792796, 0.10943300143948623, 6.70408535855157, 51.19397980826241, 38.494639124189106, 33.68340417316982, 31.679415157863072, 49.02769824436733, 40.22536938531058, 17.147351605551584, 23.524663618632726, 74.30930246625627, 59.13911288125174, 4.818131472383227, 5.19379060609, 38.161292348589214, 62.595577648707796, 49.70856612069266, 55.5210851260594, 54.34850365774972, 47.71346732548305, 50.232627051217214, 5.578184493950435, 1.2929682369743074, 14.960208075387136, 10.45017579623631, 3.41427943110466, 3.807627158505576, 3.0844538722719466, 17.48915433883667, 38.895018645695274, 45.3889023235866, 38.31331198556082, 41.956551279340474, 54.51632349831717, 52.5537874358041, 54.17123079299927, 50.707908153533936, 45.14444385256086, 43.21361936841692, 42.33580132893154, 43.16093117850167, 41.34212555204119, 40.75525638035366, 37.99656793049404, 38.931097166878835, 35.98237895965576, 39.407729693821494, 39.97826712472098, 39.495422908238, 43.97525657926287, 45.38038035801479, 46.56603486197335, 47.6332677432469, 47.61394132886614, 51.729074478149414, 53.70535407747541, 53.74286045346941, 47.226329122270855, 41.47184494563511, 40.37706593104771, 45.48417949676514, 39.62303352355957, 35.136071000780376, 33.689883368355886, 34.476777281079976, 31.700582844870432, 30.86895295551845, 30.113402366638184, 30.153326715741837, 32.22485569545201, 34.05877365384783, 37.35824734824044, 40.84928635188511, 41.99808413641793, 41.58271735055106, 37.54505314145769, 37.877969128744944, 42.00608498709542, 39.09450142724173, 37.92988954271589, 35.60029404503958, 30.92735603877476, 31.45560325895037, 36.93434817450387, 41.046997342790874, 40.80423075812203, 40.87801020486014, 45.904945032937185, 47.01376288277762, 40.25318997246878, 36.315930707114084, 37.62481498718262, 42.308237825121196, 48.82713154384068, 48.6464957509722, 46.35980885369437, 44.617568901606965, 43.46736758095877, 40.08272634233747, 42.0385365486145, 41.63851833343506, 41.429460934230256, 40.22605030877249, 40.32329729625157, 41.007708753858296, 40.61370767865862, 42.51827144622803, 46.136278356824604, 46.63451630728585, 46.86916044780186, 47.9708320753915, 45.751810210091726, 44.53281824929373, 35.37631886345999, 27.03147850717817, 20.010813679013932, 15.57291064943586, 15.362333331789289, 10.692695719855172, 8.401829481124878, 7.0397432787077765, 2.593237293618066, 0.6770604263458933, 5.920632975442069, 0.33154002683503286, 0.5909135660954884, 1.1372116633823939, 6.948286311967032, 31.937651906694683, 49.407806396484375, 50.30929000037057, 43.554991313389365, 46.2170581136431, 40.08773946762085, 35.740175179072786, 36.57936470849173, 4.119981254850115, 1.7049560270139148, 36.86609254564558, 68.80822604043144, 31.419934681483678, 10.586514217512947, 19.27393463679722, 33.648044790540425, 31.357102121625626, 24.564046382904053, 28.94528685297285, 36.29238326208932, 52.89876549584525, 12.234245640890938, 0.16337228779281887, 0.13348168028252466, 0.0039461459299283365, 0.06280977465212345, 0.10485852868961436, 0.04668085815917168, 0.03654972304190908, 0.024839798088318536, 0.10788518842309713, 0.06457014554845435, 0.028925235383212566, 0.0644902480500085, 0.07273155796740736, 0.053968093557549376, 0.1382619459182024, 0.05364236621452229, 0.07139350048133306, 0.02557722825024809, 0.05922337781105723, 0.097716920476939, 0.015808457974344492, 0.0344930460809597, 0.05174886674753257, 0.0715049295020955, 0.07333224466336624, 0.05848481958465917, 0.14402800079967293, 7.8647858415331156, 63.934224537440706, 47.71770225252424, 30.405570643288748, 36.348986761910574, 44.88182626451765, 27.86771157809666, 26.895502260753087, 29.03819990158081, 74.70969935825893, 48.25790384837559, 9.975695473807198, 6.953493118286133, 43.1058006967817, 61.64305605207171, 50.39462430136544, 61.47154671805245, 62.45087446485247, 54.63569007601057, 56.82769734518868, 8.777109503746033, 2.8211421157632555, 17.90462187358311, 16.815097434180124, 5.110255454267774, 4.486361503601074, 4.939969437462943, 20.053400925227574, 42.53121246610369, 51.61991827828543, 46.974484716142925, 48.490275927952354, 57.57285690307617, 56.052358286721365, 58.54550743103027, 55.140695571899414, 50.305190563201904, 46.72999150412423, 49.606233051845, 48.00894294466291, 46.955210413251606, 45.367717266082764, 43.507861682346885, 43.545979499816895, 41.373910086495535, 41.67032371248518, 43.726452010018484, 43.5369051524571, 48.44523423058646, 48.83198138645717, 51.56249141693115, 50.27776949746268, 48.22127294540405, 52.88901717322213, 52.524372237069265, 53.467093399592805, 48.503706795828684, 42.007721287863596, 43.72212675639561, 51.40190117699759, 50.531524658203125, 45.8598963873727, 45.22896868841988, 42.058345862797324, 41.0434433392116, 38.96342713492257, 36.60581997462681, 38.61206020627703, 39.997225284576416, 43.432411193847656, 45.35612072263445, 49.212301458631245, 50.251220430646626, 52.08573940822056, 45.392911434173584, 46.300287110464915, 52.423338481358115, 48.11626134599958, 47.24657269886562, 43.958702496119905, 38.136966705322266, 39.391147817884175, 45.34845685958862, 47.39503485815865, 45.513917786734446, 43.7478038242885, 48.047533239637104, 48.920428480420796, 42.839427607400076, 38.84702743802752, 39.94399166107178, 45.76639100483486, 50.59394032614571, 51.3433313369751, 48.847048555101665, 47.50082812990461, 46.05743019921439, 44.70144060679844, 45.20891618728638, 43.605636732918875, 42.42648574284145, 40.9687363079616, 42.149228300367085, 42.006012031010215, 40.97722700663975, 43.50554098401751, 46.24796370097569, 47.5548677444458, 46.30516127177647, 49.53020933696202, 47.01125110898699, 45.514807156154085, 36.21457038606916, 28.295930794307164, 22.417638404028757, 18.145425592150005, 16.2029698235648, 12.523457459041051, 9.960582273347036, 9.278817210878644, 3.8316249336515154, 2.133800038269588, 6.795327799660819, 0.6876450840915952, 1.043900938970702, 1.6162703058549335, 7.870232360703604, 38.82876409803118, 54.505849088941304, 56.616656235286165, 47.68410076413836, 50.904177393232075, 42.86919369016375, 42.807253973824636, 34.68707145963396, 5.584613748959132, 6.721881432192666, 35.297230992998394, 61.37862845829555, 38.63646227972848, 16.224340745380946, 25.375630719321116, 20.742252281733922, 36.57810361044747, 30.648458821432932, 17.80288634981428, 39.23998975753784, 60.856110027858186, 12.890295420374189, 0.39594600083572523, 0.2249541583337954, 0.06469287896262747, 0.04863783457715597, 0.15728487872651645, 0.0136919791776953, 0.03187136997335723, 0.06452376767992973, 0.10025561175176076, 0.021337975548314195, 0.05186244672430413, 0.1724626621497529, 0.17400403586881502, 0.11546422780624457, 0.18112508447042533, 0.13547033071517944, 0.11892002022692136, 0.2757937067321369, 0.12178231163748673, 0.18275685262467178, 0.1694952520940985, 0.17260375672153064, 0.1458709697638239, 0.25484325949634823, 0.33833319374493187, 0.17404489724763803, 0.2237766965159348, 16.297765833990915, 78.94937896728516, 50.9188346181597, 51.26759944643293, 45.35192401068551, 71.51425061907086, 47.83889620644705, 21.188317946025304, 29.73020921434675, 82.1645119530814, 66.0284810747419, 8.87169533116477, 7.048092842102051, 46.08131810597011, 70.454115322658, 59.25432096208845, 64.56415516989571, 65.21375615256173, 58.59861251286098, 59.71472249712263, 8.50207461629595, 4.1476012127740045, 23.397323983056204, 20.52907807486398, 7.849846346037729, 5.506330132484436, 5.421203408922468, 20.639186177934917, 45.93696233204433, 55.890791824885774, 51.6019606590271, 49.22179964610508, 57.62466614586966, 57.3785331589835, 61.42010225568499, 55.809567383357454, 52.69391175678798, 49.44021279471261, 51.61316810335432, 49.452490261622835, 48.35575532913208, 49.05926043646676, 45.50456551143101, 46.432577337537495, 41.79444980621338, 44.9493453843253, 47.391067436763215, 48.35267380305699, 50.942420278276714, 53.05676058360508, 55.99374328340803, 54.312828132084434, 50.678725719451904, 53.64760412488665, 56.58491686412266, 54.05450453077044, 47.24452298028128, 43.705923557281494, 44.8193028994969, 55.00452825001308, 54.80807140895298, 52.01406873975481, 52.42522144317627, 49.50456701006208, 48.89726666041783, 44.14391367776053, 42.62231377192906, 42.50422913687569, 43.278915064675466, 44.78046246937343, 45.823480878557476, 51.01968077250889, 50.774374621255056, 50.6851840700422, 47.55189391544887, 46.61796917234148, 53.362648078373496, 49.52033247266497, 48.46112476076399, 46.8459187235151, 40.55127116612026, 42.7712345123291, 50.481917994362966, 51.66524485179356, 48.516578333718435, 46.21338251658848, 51.43865714754377, 52.47695425578526, 47.202319622039795, 39.64656012398856, 41.033347606658936, 46.31759854725429, 51.884269441877095, 51.38210923331124, 49.319036211286274, 47.809519222804475, 47.535117489951, 45.359476702553884, 49.542240142822266, 48.082569531032014, 47.29667615890503, 44.19177981785366, 44.90875053405762, 47.083269187382285, 45.28707299913679, 49.04179613930838, 51.65858847754342, 51.44738755907331, 50.52584450585501, 52.934753690447124, 50.91567318780081, 49.90623542240688, 38.99352673121861, 33.14839635576521, 24.20991928236825, 20.345548357282365, 18.557386023657664, 14.527609757014684, 15.28141634804862, 13.063437581062317, 5.030512716088976, 2.404512494802475, 9.119286571230207, 1.804377800651959, 1.940947792359761, 2.610049980027335, 10.707703828811646, 37.9832968711853, 57.86611257280622, 60.227874755859375, 52.1432010105678, 50.814927782331196, 45.416674273354666, 44.27785062789917, 44.608709948403494, 7.542594398771014, 4.04402528490339, 46.34267112186977, 76.88502747671944, 40.01801429476057, 11.937341298375811, 25.417728117534093, 44.9342017854963, 47.24576670782906, 32.80810832977295, 40.396475723811555, 50.086155550820486, 71.02759878976005, 22.704366241182598, 0.5685916095972061, 0.3327878527343273, 0.19981096179357596, 0.14868063399834291, 0.44119950969304356, 0.1311456063496215, 0.2350392107452665, 0.1444123773170369, 0.23483575880527496, 0.15492715952651842, 0.19596189047609056], [0.06945968246353523, 0.024771123559081128, 0.018858047102444937, 0.0359053047639983, 0.024026375396975448, 0.016794330340677073, 0.08970311656594276, 0.041870750553373776, 0.05555412166618875, 0.03423892114577549, 0.031265906390867064, 0.018202205687495213, 0.08404379524290562, 0.0712375934900982, 0.0649427291271942, 0.030412431473710706, 0.2688487379678658, 28.761880465916224, 51.56597593852452, 38.635465213230674, 40.44557169505528, 41.739385332380024, 47.27592536381313, 22.808662176132202, 15.58459404536656, 32.913630621773855, 77.3513627733503, 25.318966422762188, 2.3171829751559665, 27.19288863454546, 56.87385422842843, 55.46534667696272, 53.193761689322336, 56.34649985177176, 45.60022136143276, 58.71316051483154, 17.874829735074723, 1.7531108430453708, 2.1539422145911624, 4.653036194188254, 7.318733862468174, 3.2040775333132063, 17.300575017929077, 16.013016496385845, 28.980269295828684, 41.57848937170846, 46.245173999241416, 38.48592955725533, 51.17870419366019, 48.922012669699534, 51.221442563193186, 51.61248370579311, 47.00927087238857, 41.365078926086426, 43.8946088382176, 41.46189512525286, 40.958734376089915, 40.05441243307931, 40.66313716343471, 38.8341315814427, 38.59160123552595, 38.42383698054722, 39.77762051991054, 44.28765801021031, 47.01396438053676, 47.79491410936628, 45.94778415134975, 47.48250573022025, 47.84085212435041, 51.13122020448957, 52.37456560134888, 49.94286285127912, 40.6778221811567, 41.2631071635655, 38.78206525530134, 43.706045150756836, 40.85531391416277, 37.22558886664254, 35.569777556828086, 36.72690275737217, 33.069037505558555, 32.72645657403128, 31.37511532647269, 32.03893232345581, 30.997383458273752, 35.759605816432405, 36.60138007572719, 41.04894978659493, 42.889437266758506, 43.37887532370431, 40.870596476963584, 38.59128161839077, 42.41816874912807, 41.35806124550955, 38.77786159515381, 34.57856491633824, 32.632742745535715, 33.81962360654558, 37.540654931749614, 43.60287829807827, 41.98839487348284, 42.49485601697649, 44.078482491629465, 46.00189324787685, 38.96006768090384, 35.16547230311802, 36.929699829646516, 40.890287671770366, 43.39526265008109, 47.317854268210276, 49.70314999989101, 49.25161436625889, 46.929199831826345, 45.20280177252633, 44.911303997039795, 45.14428751809256, 43.16657658985683, 43.22522633416312, 44.932357038770405, 44.05275331224714, 42.1896390233721, 43.24979863848005, 42.85607896532331, 45.41894980839321, 45.797411237444194, 47.70941999980381, 46.35419123513358, 43.476959569113596, 35.069903305598665, 30.642855099269322, 26.044547694069998, 17.53040405682155, 12.652037348066058, 7.134582281112671, 8.525561264583043, 2.7988119082791463, 0.4017069531338555, 6.96000748872757, 1.9218237442629678, 0.09675327861415488, 0.8630474720682416, 0.11810256194855485, 10.683223588126046, 41.28106130872454, 49.57805463245937, 45.78553329195295, 41.23771497181484, 49.91908958980015, 49.75507388796125, 50.67390366962978, 24.64177588054112, 1.3393809007746833, 13.652209690638951, 61.047338349478586, 52.05672025680542, 16.613309587751115, 12.35744501863207, 31.539551394326345, 38.510216985430034, 32.16450016839163, 25.385889734540665, 25.11069243294852, 33.995562417166575, 47.82697309766497, 3.1959661628518785, 0.12768738477357797, 0.11208387490894113, 0.04132923211104103, 0.12430551195783274, 0.034764806141278574, 0.04974044719710946, 0.059195361100137234, 0.08682643342763186, 0.0138771658031536, 0.030805252359381745, 0.02239263609849981, 0.019930364830153327, 0.09512812617634024, 0.055255752855113575, 0.08591438736766577, 0.02081681146020336, 0.024018797857154692, 0.06095031050166913, 0.04019421944394708, 0.04351084433229906, 0.04004692306209888, 0.02998178226075002, 0.006409005827403494, 0.04469502364684429, 0.0432140734711928, 0.04630408801936677, 0.028169318534699932, 0.7513548540217536, 33.53010606765747, 63.39236232212612, 37.80127838679722, 41.47405794688633, 53.3446626663208, 29.100367171423777, 27.235996995653423, 24.211515630994523, 39.396470138004844, 72.08311353410993, 28.224595376423427, 4.125367411545344, 28.191045999526978, 62.44930417197091, 60.71509633745466, 57.48657764707293, 61.81432219914028, 51.30070413861956, 64.8927354812622, 21.34209200314113, 3.1846167147159576, 1.863841244152614, 8.398540377616882, 9.851822120802742, 4.028597244194575, 21.516465732029506, 18.71921477999006, 35.003085953848704, 45.052786690848215, 53.632842676980154, 43.68527003696987, 54.5924722807748, 54.663993562970845, 55.42044741766793, 56.800321442740305, 52.58711099624634, 46.912374768938335, 49.45818778446743, 46.623638902391704, 46.735230445861816, 45.4952722958156, 43.966411522456575, 42.08169181006295, 41.88183035169329, 41.038715090070454, 43.55830907821655, 49.09154871531895, 50.48106336593628, 49.687520027160645, 49.399565832955496, 50.41474281038557, 49.201375416346956, 50.94896895544869, 53.163773264203755, 50.91741371154785, 42.715044430324006, 43.021220275333945, 43.555602754865376, 49.28095660890852, 50.039720739637104, 46.36108384813581, 47.18174253191267, 45.21148007256644, 41.62748806817191, 40.60201733452933, 37.285037653786794, 38.39174672535488, 40.29187059402466, 44.228254386356895, 43.77935559409005, 47.87094129834856, 50.808118547712056, 52.690250056130544, 47.04952873502459, 47.944929191044395, 52.757616315569194, 50.848807198660715, 47.94605132511684, 43.33646351950509, 40.47309698377337, 41.36423819405692, 45.33641563143049, 48.376731940678184, 46.555365903036936, 44.829092911311555, 47.8938182422093, 49.090600286211284, 42.21916886738369, 38.292227676936555, 39.80892562866211, 42.25026205607823, 45.80249384471348, 50.08292463847569, 50.62343890326363, 50.46212952477591, 47.94273008619036, 47.300744329180034, 46.27274445125035, 46.7970346723284, 46.10955211094448, 45.21490553447178, 47.52272885186331, 45.40155846732003, 41.61461305618286, 44.54140969685146, 43.5790251323155, 44.70180538722447, 46.84510925837925, 48.50242485318865, 47.77640758241926, 45.320184639522004, 37.15789604187012, 31.290521008627756, 27.185916117259435, 19.317260129111155, 14.234674572944641, 9.776292596544538, 12.140727230480739, 3.2974129021167755, 1.6943455849375044, 9.12872222491673, 2.111021889107568, 0.07412686345300504, 1.641069512282099, 1.127064362168312, 15.162831442696707, 48.204020568302695, 52.426520756312776, 52.22817400523594, 46.86637074606759, 54.586003507886616, 54.7477263041905, 58.62606484549386, 25.88902963910784, 3.5864822821957723, 19.784844364438737, 52.66997521264212, 53.705843925476074, 26.7890819140843, 19.456870283399308, 31.464740140097483, 25.83866388457162, 41.95943130765642, 23.63423149926322, 21.535745246069773, 41.25022520337786, 52.50863109316145, 3.8771803634507314, 0.12248709239065647, 0.01641385879234544, 0.05073696408154709, 0.027411001368558834, 0.06468911987862416, 0.041654474301529784, 0.04950013384222984, 0.06565943852599178, 0.06879621092230082, 0.03613882937601634, 0.10628079915685312, 0.1017415966572506, 0.17921453341841698, 0.109567656713937, 0.11076297078813825, 0.12990532575973443, 0.10353375691920519, 0.18719437665172986, 0.1103390356791871, 0.13909027432756765, 0.14164263808301517, 0.0937245222074645, 0.05380562852535929, 0.21423958827342304, 0.1628114107464041, 0.14339266132031167, 0.22417758857565268, 1.1143545870270049, 56.687857900347026, 68.87110028948102, 52.958301135471885, 54.10081774847848, 61.62483092716762, 62.63232667105538, 25.10678928239005, 22.332903385162354, 39.68094675881522, 83.80168124607631, 30.583979538508824, 5.131662419864109, 34.086774894169395, 68.18771021706718, 66.39581843784877, 61.99678189413888, 64.86519282204765, 56.50020442690168, 69.35222830091203, 23.626517261777604, 4.398833308901105, 3.237082128013883, 15.001492534364973, 11.881108658654348, 5.534029994692121, 25.24800968170166, 21.58888680594308, 35.667646408081055, 45.25569840839931, 56.01627629143851, 48.40225267410278, 56.985511779785156, 57.353582177843364, 57.873943192618235, 58.652210916791645, 54.4143065725054, 47.730525153023855, 52.87647567476545, 47.94283430916922, 50.06234407424927, 47.76755210331508, 47.94169133050101, 44.82589326586042, 45.238140310559956, 44.10132122039795, 46.82392072677612, 50.18747418267386, 54.188542229788645, 52.2933029447283, 51.69752965654646, 52.58993196487427, 50.841525486537385, 51.85860627038138, 52.404171875544954, 50.689377307891846, 41.11823027474539, 45.02715826034546, 43.009439604622976, 50.524044922419954, 53.18014669418335, 52.069174902779714, 51.9262296131679, 50.15698548725673, 45.88568115234375, 45.01717022487095, 40.717635359082905, 41.77945211955479, 41.46858624049595, 46.61137880597796, 44.631392342703684, 49.09963641847883, 51.556140763419016, 51.84411927631923, 48.58419820240566, 47.018800326756065, 51.087967668260845, 53.97417293276106, 48.36711910792759, 43.06443807056972, 42.75711577279227, 44.87612526757376, 49.16130862917219, 53.186264583042686, 49.79082931791033, 48.495455810001914, 50.54726232801165, 52.53416224888393, 44.70230565752302, 40.97555249077933, 41.00159086499895, 43.841618401663645, 46.03781196049282, 50.767582757132395, 50.43310342516218, 52.27350752694266, 49.75212090356009, 47.500393867492676, 50.78812163216727, 51.04590327399117, 48.457271984645296, 49.417676312582834, 51.04236664090838, 49.87611845561436, 46.61775377818516, 50.89205626079014, 48.58051218305315, 50.98250443594796, 50.477988788059776, 53.28135068075997, 51.70694446563721, 48.76255151203701, 39.76894221987043, 34.768480028424946, 30.222301483154297, 21.98597809246608, 15.502037286758423, 17.483686106545584, 17.46559647151402, 5.808382221630641, 2.2273542753287723, 13.327237231390816, 3.9809695141656056, 0.22184371309620993, 2.10266928587641, 1.1442673419203078, 15.475321463176183, 49.28318350655692, 57.518904141017366, 54.76357167107718, 49.99205609730312, 58.10451916285923, 57.47873313086373, 59.074793406895225, 31.056929520198278, 4.232199004718235, 18.863853693008423, 68.52149472917829, 60.16156809670584, 21.694191966738018, 17.021947043282644, 44.14269079480852, 52.211831842150005, 49.84238147735596, 32.97410774230957, 38.91194098336356, 46.56792477199009, 69.74516977582658, 9.313264642442975, 0.5206150040030479, 0.15850797880973133, 0.13440929193581852, 0.1729755396289485, 0.18706616067460605, 0.20340209480907234, 0.11542126296886376, 0.1599428089601653, 0.17684859037399292, 0.14428492129913398, 0.10669748072645494], [0.027339580468833447, 0.051400187957499704, 0.027149120778111473, 0.021843777603602836, 0.04998213119272675, 0.08194056738700185, 0.07525372691452503, 0.08100808385227408, 0.12588815417672905, 0.07019666648869004, 0.1097103390576584, 0.003845187128588025, 0.04714066741455879, 0.038108769205531905, 0.053769879907901795, 0.043038756985749514, 0.2997094877064228, 7.31580172266279, 58.00958592551095, 35.69277804238455, 36.03534855161394, 38.38495486123221, 48.22442742756435, 37.09023100989205, 15.714832816805158, 25.36244477544512, 59.40934222085135, 47.74039159502302, 6.368941170828683, 9.560557109969002, 44.56571102142334, 54.57930197034563, 54.465330668858115, 60.06510625566755, 56.782534054347444, 50.97611209324428, 22.66930910519191, 4.118586838245392, 0.4091805549604552, 0.6344711716685976, 1.7135285841567176, 3.0568106813090186, 19.393665994916642, 25.97407385281154, 24.173630578177317, 36.21841621398926, 48.031969274793354, 42.276536669049946, 52.52677631378174, 51.82609217507498, 54.1987178666251, 49.80052205494472, 48.55417503629412, 42.55444376809256, 43.0051977293832, 40.13120739800589, 41.66622427531651, 39.86714111055647, 40.38623060498919, 38.79199423108782, 41.68762820107596, 39.940243107931956, 43.09501361846924, 48.91357755661011, 49.644576685769216, 50.33852802004133, 49.39538996560233, 49.34959438868931, 48.92283603123256, 49.12122447150094, 46.44096728733608, 45.12100757871355, 41.94792856488909, 41.86769771575928, 37.79452821186611, 44.86092608315604, 42.36010960170201, 39.13624620437622, 40.6779020854405, 37.97703307015555, 35.85387897491455, 33.60488952909197, 31.206030913761683, 30.943937914712087, 32.049834047045024, 36.20692041942051, 39.98039327348982, 42.546766008649556, 43.821826457977295, 46.169671399252756, 38.43739291599819, 46.85866519383022, 44.38606882095337, 42.24102790015084, 41.869538988385884, 36.11754921504429, 31.811840874808176, 35.31246839250837, 39.41452850614275, 44.43479306357247, 43.763395581926616, 43.146367754255024, 45.65253782272339, 47.688481603349956, 38.332350049700054, 36.22563191822597, 37.14462498256138, 39.62173073632376, 40.29869372504098, 43.867173876081196, 47.922118255070274, 48.74868985584804, 51.426796572549, 49.11307076045445, 47.61857577732631, 47.96948759896414, 45.32868228639875, 45.36291258675711, 45.895005634852815, 43.41165345055716, 45.39383554458618, 42.737904003688264, 42.270015784672324, 45.002464362553184, 47.41823836735317, 46.79799699783325, 48.33747461863926, 45.33196531023298, 41.00108364650181, 36.77213205610003, 25.322907788412913, 25.994383437292917, 21.26617251123701, 10.322601658957344, 4.579169460705348, 2.086029653038297, 8.193316646984645, 4.419861163411822, 0.21024423837661743, 0.46326261865241186, 0.29978051675217493, 2.1550387271812985, 17.064841747283936, 43.82817363739014, 48.68047939028059, 48.99885279791695, 48.09307173320225, 49.92423473085676, 48.00402362006051, 50.651061466761995, 15.488939932414464, 3.2676604986190796, 25.334471327917917, 49.318727016448975, 34.04663167681013, 7.025375706808908, 22.48533296585083, 29.83908748626709, 35.88699408939907, 24.75465284075056, 24.855603218078613, 29.317934376852854, 44.89629241398403, 28.07266432898385, 0.3219224714807102, 0.08505591164742198, 0.08406845999083348, 0.039343865787876506, 0.01861979140500937, 0.04184720538822668, 0.1538293712905475, 0.07811042041118656, 0.16317469839538845, 0.05704374012670346, 0.11395627872220107, 0.07416393860642399, 0.01163092312136931, 0.09036604527916227, 0.0630558385912861, 0.029664512856730392, 0.05815434588917664, 0.042653623901839764, 0.015109736538891281, 0.009730585717729159, 0.04655936646408268, 0.023796134894447665, 0.044901528994419744, 0.018478172664929713, 0.04323471789913518, 0.07672809530049562, 0.03527684562972613, 0.04035469297585743, 0.1494910219418151, 12.78365707397461, 71.13306549617222, 44.63305296216692, 37.46155316489083, 49.52440411703927, 38.28706863948277, 28.180924211229595, 22.83363573891776, 26.169365133558, 63.0372815813337, 51.88614892959595, 10.030519366264343, 10.340017318725586, 48.11128643580845, 57.90547064372471, 59.61423764910017, 64.46914550236293, 62.74247646331787, 58.75364766802107, 27.906614542007446, 4.147356288773673, 0.3761186919042042, 1.1629622301885059, 1.7818567348378045, 4.511138779776437, 24.99181396620614, 32.67684643609183, 32.17857721873692, 40.60373701368059, 53.17836100714547, 49.08247784205845, 56.84594331468855, 56.242787565503804, 60.10202203478132, 53.4287497656686, 52.96480812345232, 46.89308656964983, 48.41688558033535, 45.87003033501761, 46.722237314496724, 46.67627150671822, 45.157641955784385, 42.816078186035156, 44.50882959365845, 42.260600975581575, 46.99740334919521, 53.10430015836443, 52.64707047598702, 52.22410583496094, 52.95114796502249, 50.537878785814556, 50.34642464773995, 48.75491544178554, 47.65609604971749, 45.25633069447109, 41.08942651748657, 42.84629242760794, 42.8670015335083, 49.88511984688895, 50.903593744550435, 48.34300538471767, 48.604764870234895, 46.19905533109392, 44.612055506025044, 41.86663464137486, 38.190037046160015, 38.984407220567974, 41.11643416540963, 44.04388393674578, 46.52145869391305, 49.654661996024, 51.298814228602815, 53.15327106203352, 45.35979284558977, 51.610496520996094, 52.48216193062918, 49.556525639125276, 48.44239936556135, 41.88122238431658, 37.61141538619995, 40.83727291652134, 45.774815695626394, 49.90286554609026, 48.125196729387554, 45.53832680838448, 48.3052419253758, 50.868005071367534, 40.73368222372872, 38.60132871355329, 40.09177984510149, 41.518290179116384, 41.17319747379848, 46.11711869921003, 49.64299597058977, 50.17744098390852, 50.95590673174177, 49.67229652404785, 50.00311762945992, 48.630052839006694, 47.86066491263253, 47.145518098558696, 47.688582352229524, 46.46351766586304, 47.157924107142854, 43.22338506153652, 44.892557757241384, 44.84040805271694, 49.065399169921875, 48.03217077255249, 50.761923449380056, 46.09478024074009, 43.37631491252354, 38.136699199676514, 26.819869382040842, 26.993477072034562, 22.540996721812657, 10.173425572259085, 6.345170080661774, 2.972904452255794, 7.806878685951233, 4.456382632255554, 0.3310244216450623, 0.31529682129621506, 1.0324333714587348, 2.7829133442470004, 22.66084793635777, 49.50946201596941, 55.20564385822841, 55.207599776131765, 52.23133543559483, 54.10830443246024, 53.608430181230815, 56.69302041190011, 19.567820855549403, 6.245351825441633, 26.77416065761021, 47.92991413388933, 40.72789784840175, 12.026594383375985, 29.63328184400286, 21.92283981187003, 33.072897229875835, 35.535022667476106, 22.88559784208025, 32.82075752530779, 54.424874782562256, 33.45436028071812, 0.7174783146807125, 0.13355983394597257, 0.04657887773854392, 0.03904436043064509, 0.03598160602684532, 0.008872318647003599, 0.03014499707413571, 0.10885259615523474, 0.0628072912139552, 0.10828259959816933, 0.0919302517016019, 0.01588930542181645, 0.15658294782042503, 0.17049085295626096, 0.14555959004376615, 0.12737820350698062, 0.17389914792563232, 0.1526950914412737, 0.13431614264845848, 0.19742671187434876, 0.2163829854024308, 0.11489663326314517, 0.17217129921274527, 0.10569309962115117, 0.12221406346985272, 0.30295291223696297, 0.15418732565428528, 0.21600197441875935, 0.36870463831084116, 20.79229841913496, 85.80666732788086, 49.209480490003315, 50.62755571092878, 54.04588876451765, 68.39707333700997, 41.55594246728079, 20.422642094748362, 28.49875044822693, 64.82281575884137, 52.23683146068028, 9.229577933038984, 13.259877051625933, 53.45289475577218, 62.621140071323936, 63.44450855255127, 69.14538737705776, 68.34464223044259, 62.89091777801514, 28.358278717313492, 6.732099626745496, 0.7647476696542331, 1.7961797948394502, 3.979606798716954, 6.046429676668985, 27.995911053248815, 38.55910798481533, 40.21300506591797, 41.439716475350515, 58.301945277622764, 51.091080461229595, 59.47558634621756, 56.95433521270752, 63.11426762172154, 54.45590196337019, 56.53681101117815, 48.535710198538645, 51.05752066203526, 46.424413204193115, 49.09201424462454, 48.04036617279053, 47.779951163700645, 45.80468600136893, 50.09964895248413, 44.171762057713096, 49.22917863300869, 55.9526481628418, 56.11792148862566, 53.0745028087071, 52.90982007980347, 53.27366597311837, 51.864897864205496, 50.58944136755807, 47.95445169721331, 45.87766987936837, 42.08401598249163, 45.23452377319336, 42.99163831983294, 50.29448686327253, 53.69632141930716, 52.860348905835835, 53.99215487071446, 51.04118544714791, 48.66357789720808, 45.667146410260884, 39.718744959150044, 39.67656591960362, 42.0781968661717, 44.963245255606516, 47.42890385219029, 46.83594111033848, 50.18216575895037, 50.79280819211687, 46.19682843344552, 51.596992697034565, 50.47393104008266, 50.57011495317732, 50.83053691046578, 44.00455018452236, 38.70376253128052, 45.242733069828574, 49.97954933983939, 54.88547434125628, 50.16493770054409, 51.54635769980294, 53.118453638894216, 55.279597009931294, 44.102835927690776, 40.92603267942156, 41.135621615818565, 42.29822199685233, 41.474050998687744, 45.552101612091064, 50.42852108819144, 50.3930401120867, 52.26389816829136, 50.802250794001985, 49.652549743652344, 49.69315849031721, 49.20553043910435, 49.956557750701904, 50.649723938533235, 49.114800861903596, 51.460026332310264, 48.84222303118025, 47.34943730490548, 49.57481677191598, 52.620868819100515, 51.61345992769514, 54.75337518964495, 48.75957768304007, 45.889012813568115, 40.559449195861816, 29.255299840654644, 30.7081264768328, 26.796283721923828, 15.412848472595215, 7.976879392351423, 3.7212045959063937, 11.50172051361629, 8.11192979131426, 0.7784869181258338, 0.894770504108497, 1.8679576175553458, 3.541230184691293, 22.798762730189733, 51.903460366385325, 57.50024822780064, 59.34334823063442, 56.88404723576137, 57.78184829439436, 56.41552325657436, 61.022526332310264, 21.160177741731914, 5.318908989429474, 31.253612177712576, 54.665768827710835, 43.6926212310791, 9.815841742924281, 30.62622458594186, 40.31937503814697, 51.83248451777867, 37.52526119777134, 34.79623113359724, 43.25417252949306, 58.21224055971418, 50.56699521200997, 1.4941476817641939, 0.2880441408072199, 0.09926421780671392, 0.14401174310062612, 0.14561655984393188, 0.11972462705203465, 0.21164212908063615, 0.1381204713668142, 0.19592800443725927, 0.16479552856513432, 0.17400206811726093, 0.14324704770530972], [0.02563193004711398, 0.04859995535973992, 0.04133511840232781, 0.04683468883324947, 0.05988775858921664, 0.03330637654289603, 0.010467256768606603, 0.06377360650471278, 0.032829413922237496, 0.06037346752626555, 0.028665641455778053, 0.06288789438882045, 0.051171545404940844, 0.032398856311504326, 0.11902018556637423, 0.09671447998178856, 0.15958828798362187, 3.549412774188178, 62.3749931880406, 39.23208270754133, 46.08056075232369, 45.609469413757324, 37.10445397240775, 45.886035510471885, 23.4388325214386, 18.852599348340714, 34.4847468648638, 47.161578859601704, 12.725242699895587, 12.902587652206421, 45.33197225843157, 53.56896788733346, 54.051065172467915, 58.329300335475374, 53.1888701575143, 54.905436515808105, 31.26095642362322, 4.889757411820548, 0.11646193212696485, 0.7195521891117096, 0.5676620709044593, 0.6145098656415939, 4.619123773915427, 12.120476705687386, 23.77240685054234, 37.821330887930735, 42.70918015071324, 50.24513380868094, 53.22088050842285, 56.4089537348066, 56.611236640385215, 54.19019937515259, 49.834860052381245, 43.10256978443691, 41.833470889500205, 41.056749139513286, 38.48655489512852, 40.6543859073094, 40.70543084825788, 41.811038630349294, 42.01760162625994, 41.14030817576817, 47.33252191543579, 50.91470043999808, 52.900575501578196, 52.72185393742153, 50.76723534720284, 49.18983098438808, 49.30011279242379, 45.246141161237446, 44.510792459760395, 42.75108821051461, 41.09491906847273, 39.174169472285676, 37.65254872185843, 43.53551551273891, 46.44696010862078, 42.288324287959504, 40.59730645588466, 38.336998394557405, 34.65985883985247, 36.6573999268668, 33.54955060141427, 32.02455302647182, 35.6899744442531, 37.14608063016619, 40.93173367636544, 44.75288159506661, 46.84491123471941, 47.44724709647042, 41.473460401807515, 51.72664608274187, 47.2927052634103, 44.25558165141514, 44.643954685756135, 39.67658676419939, 33.55084991455078, 35.769673756190706, 40.183631556374685, 42.34657451084682, 45.39519739151001, 43.71682528087071, 45.09540694100516, 47.81648131779262, 38.63442645754133, 35.530673095158164, 37.44754212243216, 39.10338817323957, 40.685982840401785, 42.83649894169399, 46.7710588318961, 50.592495100838796, 49.92783737182617, 50.798488344464985, 51.71785313742501, 46.92682007380894, 48.76235696247646, 46.72665984289986, 49.858688899448936, 47.94422047478812, 47.32270758492606, 44.6817980493818, 44.235091413770405, 43.69779763902937, 46.11416571480887, 46.22009795052664, 48.212768350328716, 41.65203257969448, 44.595171383449006, 38.478119782039094, 37.80201836994716, 34.7428411756243, 34.18522392000471, 19.788212503705704, 8.823788370404925, 4.193691219602313, 2.175348094531468, 0.6435460075736046, 0.19404424194778713, 0.46227022047553745, 0.1333531250378915, 5.041600738252912, 28.19271877833775, 50.04203796386719, 46.07413714272635, 51.85179703576224, 48.80847910472325, 50.879855224064414, 46.86867754799979, 36.23942061832973, 6.187631402696882, 10.551346778869629, 52.27809681211199, 62.12754004342215, 25.987221581595286, 15.22199535369873, 24.11613597188677, 35.274816104343955, 28.87649621282305, 29.345449243273052, 32.145705291203086, 23.664886951446533, 49.93017891475132, 12.84006689276014, 0.1937016360461712, 0.012080864781247718, 0.042848353274166584, 0.08892167492636613, 0.05921175450618778, 0.026709324913099408, 0.12077122660619871, 0.07266920738454376, 0.02996299701875874, 0.21626760730785982, 0.04374580404588154, 0.05634304415434599, 0.016505269333720207, 0.016275497020355294, 0.02137094217219523, 0.08042734608586345, 0.015372853759410126, 0.024727395369804332, 0.03630582023678081, 0.03780632918434484, 0.015890056899349605, 0.039058117728148184, 0.0046329187877875355, 0.07799702363887004, 0.04008870046319706, 0.012604764213652482, 0.02688012914066868, 0.08902473761034863, 0.02446101269950824, 6.124629480498178, 72.99726022992814, 46.856146471840994, 47.981838021959575, 52.05758878162929, 41.667923109872, 28.549201318195887, 28.41487353188651, 24.567240817206248, 37.35909850256783, 41.06105702263968, 13.943743075643267, 13.991532785551888, 48.858085768563406, 57.406148774283274, 61.50284835270473, 61.54662200382778, 58.07454463413784, 59.76019845690046, 34.297357422964915, 7.024361269814627, 0.8688414011682782, 1.2290974642549242, 0.8674238600901195, 0.6574919106704848, 5.2767824956348965, 16.386159079415457, 26.84667205810547, 42.45391375677926, 49.707947731018066, 55.805547850472585, 59.74311978476388, 57.83909797668457, 59.384530203683035, 57.77063042776925, 55.05540990829468, 45.55793809890747, 48.17200674329485, 45.89663846152169, 44.16019330705915, 44.03951351983206, 42.83583191462925, 42.69465494155884, 44.466174602508545, 43.61693102972848, 50.155244963509695, 53.19826412200928, 53.891857624053955, 54.13116747992379, 51.61476271493094, 51.071597712380544, 47.59670632226126, 45.773554597582134, 43.740087849753245, 41.73299298967634, 41.51401356288365, 41.8010436466762, 40.68692084721157, 47.485635893685476, 52.69338369369507, 48.89824983051845, 48.755954197474885, 46.2800087928772, 44.873418944222585, 43.49628945759365, 40.88166495731899, 38.64099250520979, 41.43404674530029, 43.683157784598215, 46.11511761801583, 50.307334082467214, 52.32851294108799, 53.537753105163574, 47.98968948636736, 56.05903203146798, 51.295496463775635, 50.68793903078352, 49.37538957595825, 42.779151984623496, 39.89337056023734, 40.104321343558176, 44.665633065359934, 47.92868777683803, 48.400599002838135, 45.982928139822825, 48.98863547188895, 50.357319423130576, 42.03246034894671, 38.25286265781948, 39.52204145703997, 40.84275851930891, 43.09963417053223, 43.94213451657976, 48.82838569368635, 50.530725615365164, 49.63212203979492, 52.1827049936567, 51.02606616701399, 49.49244935171944, 51.049808161599294, 48.335136549813406, 49.313752106257844, 49.526676177978516, 49.05014787401472, 48.420304094042095, 45.63575792312622, 43.77538122449602, 48.74653244018555, 47.56522750854492, 50.70654283251081, 45.59897068568638, 45.763163566589355, 38.6035486630031, 39.931297302246094, 36.23054429462978, 35.194922242845806, 21.611124515533447, 9.842210156576973, 4.159648954868317, 2.5585577487945557, 0.5925714171358517, 0.1843966274921383, 0.3677339261131627, 1.1150792624269212, 7.457572766712733, 32.699379444122314, 53.595096588134766, 51.624114990234375, 55.443289620535715, 53.56857531411307, 55.611008712223594, 54.90094797951834, 38.93103115899222, 8.045465060642787, 14.819315978458949, 49.428755215236116, 59.689208711896626, 31.604197434016637, 20.066341945103236, 27.483069726399012, 23.38182255199977, 36.01592138835362, 36.92079223905291, 30.081735951559885, 30.310376848493302, 57.98248447690691, 17.225195748465403, 0.3511060726429735, 0.06467182402099882, 0.03422853277463998, 0.09368991692151342, 0.0937660892627069, 0.023941645032859275, 0.05841944952096258, 0.02595711456212614, 0.07012850086071662, 0.07877230418047734, 0.059660211870712895, 0.06131212572966303, 0.07314773742109537, 0.1326856365693467, 0.047022819452519925, 0.1666063621108021, 0.10501786228269339, 0.1190936980502946, 0.13349814154207706, 0.1222599595785141, 0.14249870500394277, 0.203164702547448, 0.0824242000068937, 0.2095606414867299, 0.12119748230491366, 0.13381266966462135, 0.18176912276872567, 0.3026499056390354, 0.25250671058893204, 11.58778611251286, 91.31638036455426, 50.40898622785296, 58.99017129625593, 57.504111426217214, 56.508472783224924, 55.51811824526106, 27.652048179081508, 24.66339520045689, 38.26601559775216, 50.63878399985177, 15.916811738695417, 16.85103699139186, 55.1368636403765, 61.42071369716099, 64.25362627846854, 67.32627255575997, 61.403336252485005, 65.62199756077358, 38.09952286311558, 8.356652293886457, 1.4927190669945307, 2.2259246834686826, 1.3913818704230445, 0.8422301805445126, 5.645666701453073, 16.60572910308838, 30.697238649640763, 45.01623569216047, 51.175598348890034, 56.44958332606724, 60.50369044712612, 60.472291537693565, 62.09455694471087, 59.989690508161274, 55.63299628666469, 48.00644506726946, 51.558419772556846, 48.081763539995464, 46.72768817629133, 46.424857888902935, 44.91430909293038, 45.641841070992605, 46.7252493585859, 45.6928825378418, 51.73740536825997, 55.43464953558785, 57.84446198599679, 54.18235485894339, 54.21855844770159, 53.519145829336985, 49.364543437957764, 45.51930264064244, 45.43958248410906, 43.73380667822701, 41.21630757195609, 41.29612847736904, 41.00545753751482, 47.99982690811157, 55.94167348316738, 52.64817871366228, 49.732721533094136, 47.67496735709054, 45.66581930433001, 46.33561175210135, 41.192742756434846, 39.89115408488682, 42.69677414212908, 45.018056120191304, 46.80125917707171, 49.0366336277553, 52.30942971365792, 52.18190247671944, 48.59329686846052, 52.49449150902884, 52.225749083927695, 50.281969683510916, 51.86010708127703, 45.628437995910645, 41.18656233378819, 41.047125884464805, 48.84491545813424, 52.12226261411394, 53.31944070543562, 51.2628573008946, 52.4945262500218, 55.08698599679129, 45.97828326906477, 40.3035192489624, 41.93057196480887, 42.56700611114502, 43.89362219401768, 45.272523471287315, 49.368754046303884, 50.913779803684776, 50.87277848379952, 52.14659867967878, 51.13065045220511, 48.88693816321236, 52.01865455082485, 50.78608928407942, 52.172164576394216, 52.8156407220023, 52.56094060625349, 51.796030793871196, 49.34306655611311, 47.89191443579537, 52.931067671094624, 52.10746989931379, 55.358122076307026, 47.2909369468689, 48.5156820161002, 43.42586599077497, 42.13875041689192, 38.40190151759556, 38.6177716255188, 23.66246724128723, 10.860382676124573, 6.49922901391983, 4.09617064680372, 1.7877013640744346, 0.8396280801721981, 0.9109951449292046, 1.7897377290896006, 7.649553230830601, 31.99684361049107, 58.133093629564556, 55.670950821467805, 61.6069393157959, 56.268631390162874, 59.8753023147583, 55.243890217372346, 44.358411516462056, 8.894511478287832, 13.934655700411115, 60.01923424857003, 68.62307739257812, 33.306262901851106, 20.603972707475933, 31.59337908881051, 49.31392928532192, 45.521977697099956, 39.43983384541103, 46.08537932804653, 34.38202469689505, 68.04329885755266, 26.057045766285487, 0.5590516243662152, 0.08365530001797847, 0.15890720167330333, 0.16485549749008246, 0.18858909181186131, 0.18073298622454914, 0.1869314443320036, 0.12162973625319344, 0.17205357338700975, 0.2451324462890625, 0.13330029430133955, 0.1770396251231432], [0.03846878292305129, 0.052745451485472064, 0.033639035121138604, 0.0313576070059623, 0.054697874933481216, 0.05640025144176824, 0.03754792608586805, 0.058089444014642916, 0.05877126992813178, 0.10429112413632018, 0.01570595508175237, 0.03183134997795735, 0.038571706507354975, 0.02037081548145839, 0.056816580173160346, 0.025196882230894904, 0.25461361610463684, 0.6204952501824924, 51.50683287211827, 52.97064808436802, 45.263247626168386, 51.712826115744456, 35.13024146216256, 47.33825070517403, 27.086536032812937, 16.223503487450735, 35.33493539265224, 84.48379284994942, 51.41582884107317, 10.67870031084333, 26.233910424368723, 49.56767054966518, 53.205139364515034, 59.79477964128767, 56.88125058582851, 53.88045563016619, 35.14477014541626, 5.306722283363342, 0.0972947563443865, 0.49495530660663334, 0.3403635876519339, 1.2023696984563554, 6.348872601985931, 20.582699060440063, 29.890879358564103, 41.52187544958932, 49.123065744127544, 57.48538603101458, 55.341759068625315, 57.10600049155099, 58.75664928981236, 55.076202392578125, 52.21609803608486, 44.5613579750061, 43.52133076531546, 40.44344207218715, 42.07823508126395, 41.84393835067749, 41.363081318991526, 40.36450358799526, 43.49485812868391, 46.80154057911464, 51.15063694545201, 51.81710468019758, 54.485723631722585, 49.896007674080984, 50.590212617601665, 53.590868609292166, 49.04237283979143, 44.33504819869995, 40.47344439370291, 42.19554499217442, 40.85128395898001, 39.60035807745797, 39.73182841709682, 42.70309352874756, 48.84662471498762, 41.04913738795689, 41.197071484157014, 38.85391310283116, 37.2276177406311, 36.40031657900129, 34.28722347532, 34.38416126796177, 36.13226202556065, 36.44393042155674, 42.02027668271746, 45.950737135750906, 49.442040170942036, 45.244390215192524, 47.108932358878, 51.79952573776245, 44.3742846761431, 48.80517871039254, 44.250137737819124, 42.564497811453684, 35.8350111416408, 37.46970340183803, 40.851106779915945, 44.39274256569998, 44.78985643386841, 42.00878436224801, 45.788270882197786, 47.42625658852713, 38.59070839200701, 38.007490498679026, 37.75493042809622, 39.39116518838065, 41.821655477796284, 42.38982704707554, 46.518526554107666, 47.46167503084455, 50.35959843226841, 49.99917105266026, 52.285725934164866, 48.6264363016401, 47.193109784807476, 44.84609167916434, 47.27047797611782, 48.672579288482666, 47.64308902195522, 45.705778394426616, 43.28830208097185, 44.63457809175764, 45.671742643628804, 47.64912700653076, 47.333359173366, 46.84795454570225, 46.856354917798726, 39.18803112847464, 40.245425360543386, 34.90115588051932, 32.525153364454, 19.738586732319423, 12.258676375661578, 5.511158696242741, 3.9101526056017195, 1.329769479376929, 0.4726987066013472, 0.39329610445669716, 1.3678880568061556, 8.324102589062282, 30.435691084180558, 49.94635779517037, 47.99378892353603, 48.67512232916695, 49.13138273784092, 45.163137980869834, 53.13577549798148, 23.379512275968278, 4.972639432975224, 37.37545803615025, 56.162636620657786, 34.294793537684846, 10.646630900246755, 16.422836882727488, 30.611327648162842, 34.52090181623186, 21.994197811399186, 21.178640842437744, 18.651226656777517, 33.152089323316304, 54.657278129032676, 4.785408931119101, 0.06043989610459123, 0.041794293227472475, 0.039825432268636565, 0.07646413160754101, 0.060585021174379756, 0.10765257304800407, 0.06766227034053632, 0.09951336908021144, 0.14567772299051285, 0.08018782322428056, 0.12507543207279273, 0.043514990181263, 0.04008371662348509, 0.1008195218497089, 0.04684306874072977, 0.114718300689544, 0.030386141634413173, 0.06049168189721448, 0.036751159732895236, 0.07177409755864314, 0.11046912441296236, 0.07966357349817242, 0.028234323885824, 0.039379407452153306, 0.01828120243070381, 0.03149342257529497, 0.025921869756919996, 0.04194499585511429, 0.1425919085741043, 0.4759678883211953, 58.47667162758963, 60.53588145119803, 50.33287566048758, 52.72985826219831, 44.557817867824006, 33.66576269694737, 27.002928359167917, 21.96210755620684, 31.41747154508318, 68.61875561305455, 48.906056131635395, 14.455893056733267, 25.6126355103084, 50.92957305908203, 58.495445660182405, 66.02122020721436, 61.909158161708284, 59.77788162231445, 40.23326601300921, 8.214684963226318, 0.6218955836125782, 0.7310669826609748, 0.12258900835045747, 2.5664604561669484, 7.289467181478228, 24.273946932383947, 33.07702098573957, 46.446921893528526, 54.005307810647146, 61.795735767909456, 60.10435662950788, 59.89618859972273, 61.06887776511056, 56.57256644112723, 54.70825358799526, 48.410006863730295, 47.10504831586565, 45.10893508366176, 44.21345124925886, 44.63771867752075, 44.39150578635079, 42.5291280065264, 44.436151436397004, 48.9578514780317, 52.43528243473598, 53.10879564285278, 55.07285336085728, 52.06604126521519, 51.89546993800572, 54.27632924488613, 50.460590498788015, 43.90169947487967, 41.40775128773281, 41.39831215994698, 41.46312495640346, 40.04198905399868, 42.19416577475411, 47.682582582746235, 52.30701868874686, 50.62530102048601, 49.35760218756539, 47.313195501055034, 44.470402581351145, 43.086401326315745, 39.66762358801705, 40.983706201825825, 42.116307735443115, 42.81294107437134, 46.718224729810444, 51.98565755571638, 53.152194091251914, 50.7703446660723, 51.50056907108852, 55.37336294991629, 50.439033712659565, 53.011312416621614, 48.3840240750994, 45.594746180943076, 40.33486952100481, 41.57454626900809, 44.90440443583897, 48.0624440738133, 49.939895970480784, 45.97580623626709, 48.403677054813926, 49.4636629649571, 41.35414593560355, 39.75165857587542, 41.07086787905012, 41.20384250368391, 42.4996919631958, 43.00769213267735, 48.63584763663155, 49.08100482395717, 51.311581543513704, 50.92124911717006, 54.189476762499126, 48.16379049846104, 48.03575256892613, 45.60560621534075, 49.61715909412929, 50.55574260439192, 48.28745106288365, 49.21267318725586, 46.29696239743914, 46.332665715898784, 48.1310019493103, 49.50405979156494, 49.17372506005423, 45.772029467991416, 48.11965901511056, 40.559900828770225, 42.83204167229788, 36.41447005953108, 34.716451917375835, 21.285950558526174, 11.583138636180333, 5.356337632451739, 4.727622066225324, 1.2017459890672137, 0.49170669806855066, 0.46448457879679544, 1.1733616207327162, 9.645074997629438, 34.084923199244905, 53.2558125768389, 52.00028698784964, 53.294260433741975, 54.46079002107893, 50.08431427819388, 59.812483651297434, 25.817445823124476, 7.03460465158735, 38.91154841014317, 45.035805293491904, 35.360139983040945, 16.00104127611433, 22.036918810435704, 25.580920457839966, 25.308855056762695, 32.945734773363384, 20.040720462799072, 22.63744466645377, 40.988524777548655, 64.34744780404228, 5.640921081815447, 0.1606548364673342, 0.09380967835230486, 0.08591613798801388, 0.019003336716975485, 0.11268377450427838, 0.04628097711663161, 0.022672217971246158, 0.06688196863979101, 0.06394400021859578, 0.06854838279208966, 0.024045666147555624, 0.038211194066596885, 0.06999302455889327, 0.12722743302583694, 0.12297008718763079, 0.23747279016034945, 0.12355058746678488, 0.1617118583193847, 0.0874349707737565, 0.15812626214964048, 0.1878674698195287, 0.18290594033896923, 0.09341721369751863, 0.21913250429289682, 0.09228443341063601, 0.12127531027155262, 0.10301901346870831, 0.09390370973518916, 0.28456170910171097, 1.5166574567556381, 73.67325047084263, 65.5977691922869, 59.9532333101545, 64.93743324279785, 51.45273767198835, 61.25942516326904, 31.5412015914917, 19.657888616834367, 40.723183495657786, 89.84338310786656, 56.4199457849775, 16.231987237930298, 31.890327726091655, 58.70959608895438, 62.1613221849714, 70.25156838553292, 65.77168260301862, 62.92736107962472, 44.65775728225708, 8.712889041219439, 0.8294692167213985, 1.3787085733243396, 0.9115495894636426, 4.1683003306388855, 9.658106344086782, 26.738443442753383, 34.361308642796104, 48.61839723587036, 57.53522545950753, 65.00170407976422, 59.17405537196568, 61.90325219290597, 62.32284000941685, 60.177854674203054, 57.51845250810896, 51.01699876785278, 49.60703904288155, 46.742602484566824, 47.446274348667686, 47.53570808683123, 46.538325445992605, 45.77861636025565, 47.03375979832241, 49.86138480050223, 55.31197214126587, 56.21526575088501, 56.197561740875244, 53.10825020926339, 52.80322429112026, 55.900800704956055, 52.204140186309814, 45.625960963112966, 42.99359423773629, 43.14376565388271, 42.88433381489345, 38.76551464625767, 43.067846161978586, 49.389883518218994, 54.56203917094639, 52.429192338671, 51.74689660753523, 49.67240422112601, 46.67338800430298, 45.75800800323486, 42.37078550883702, 42.563521589551655, 43.68910891669137, 44.60101134436471, 47.52474382945469, 50.893782888139995, 51.48092303957258, 50.91895621163504, 50.67607845578875, 52.736695289611816, 50.97744614737374, 53.704471656254356, 49.79427562441145, 48.92048406600952, 43.68254634312221, 44.11325822557722, 49.92094823292324, 51.84636007036482, 54.2758081299918, 49.50874982561384, 53.77367224012102, 53.00851229258946, 44.99418558393206, 43.39331020627703, 43.18929372514997, 43.07265778950283, 44.336225918361116, 44.95317384174892, 49.83202518735613, 49.58593388966152, 52.83144439969744, 52.15069464274815, 54.623579365866526, 48.17087071282523, 49.854513032095774, 46.711825438908164, 48.926678385053364, 53.408200468335835, 51.65366915294102, 52.66316597802298, 49.409574713025776, 49.725901876177105, 51.621009145464214, 53.75860159737723, 53.953401293073384, 50.48330068588257, 51.64778750283377, 44.96316187722342, 51.07933105741228, 43.40734904153006, 39.81576613017491, 26.121497256415232, 12.64733168057033, 6.585704122270856, 5.686630240508488, 1.7339903776134764, 0.9876246558768409, 1.2303430374179567, 3.041178971529007, 12.228670580046517, 36.08924225398472, 59.35905115944998, 56.24425710950579, 58.098776476723806, 58.71799646105085, 53.31649466923305, 62.77870437077114, 28.21155708176749, 8.363623942647662, 46.726055349622456, 64.04465225764683, 43.839474882398335, 15.858366966247559, 22.90998601913452, 40.26245192119053, 49.43159008026123, 34.552759306771414, 30.16945001057216, 33.66145133972168, 45.06128086362566, 78.48612867082868, 12.386688249451772, 0.3853681284402098, 0.14121776659573826, 0.14521600705172333, 0.16672627281929764, 0.28709712305239266, 0.21460724568792752, 0.18310488680643694, 0.18972658791712352, 0.23532514540212496, 0.1902870035597256, 0.1978741650070463, 0.13406406688903058], [0.0562893211442445, 0.07177885408912386, 0.10827765986323357, 0.023153021100110242, 0.04844703392258712, 0.08350842432784182, 0.04081314176853214, 0.04873679890962584, 0.1090864125373108, 0.029770455921867063, 0.05292993497901729, 0.03500268016276615, 0.010747300893334406, 0.01994549955374428, 0.03790086268314293, 0.05926299747079611, 0.12035784950213772, 0.061116110533475876, 27.510938950947352, 64.79677391052246, 36.60774115153721, 42.0807329586574, 34.2706937108721, 38.70495414733887, 42.636595794132774, 22.391655615397863, 37.35931389672415, 70.4852363041469, 70.69056946890694, 28.2450977734157, 13.380725332668849, 33.718506472451345, 54.26136629922049, 57.29926463535854, 53.98281649180821, 55.39062227521624, 44.76432875224522, 11.35976881640298, 2.066722563334874, 0.5727587374193328, 0.7735827927078519, 1.7673108982188361, 9.52878907748631, 22.543928861618042, 33.22228002548218, 43.24038035529, 49.63358810969761, 54.85612167630877, 59.25428622109549, 60.49453966958182, 56.676452432359966, 55.290523052215576, 53.08008221217564, 44.13582944869995, 41.94520834514073, 43.61440883363996, 46.15994739532471, 46.68879216057913, 45.39596169335501, 48.79619121551514, 50.1548558643886, 51.94699083055769, 51.247456618717735, 52.92717667988369, 50.95520843778338, 51.76106398446219, 51.150748116629465, 51.918062005724224, 49.66296509334019, 45.56584514890398, 43.621860776628765, 43.95263671875, 39.350337573460166, 41.36865030016218, 38.76323216302054, 40.306882177080425, 44.63904578345162, 43.812369959695, 42.667581285749165, 40.74925313677107, 37.806128229413716, 34.99946246828352, 34.727857385362896, 35.69050945554461, 36.73356260572161, 39.56415448869978, 42.81614071982247, 47.08789668764387, 50.32704612186977, 46.061665126255576, 51.96464620317732, 50.15258032935006, 47.42262615476336, 49.238687242780415, 47.00122833251953, 47.03432607650757, 37.151093755449565, 35.36174154281616, 38.81103229522705, 44.24829299109322, 46.082749434879844, 45.619829177856445, 47.443178926195415, 47.40018694741385, 38.343679087502615, 36.820324761526926, 40.32100786481585, 41.39365339279175, 43.6354375566755, 44.93861041750227, 45.169947215488975, 47.08666338239397, 49.25083269391741, 49.15394006456648, 49.64521939413888, 51.552235875810894, 45.95399931498936, 40.698941230773926, 34.86429916109358, 40.40344476699829, 46.759941714150564, 47.12181084496634, 45.78996276855469, 44.124153000967844, 45.69200011662075, 48.17937878199986, 45.763222626277376, 43.084831033434185, 36.192224979400635, 39.324962752205984, 35.46844155447823, 34.5450815473284, 33.54127529689244, 21.67901710101536, 15.316668033599854, 9.943980421338763, 7.70050002847399, 3.546955934592656, 0.7546608937638146, 0.29089998613510815, 1.4230697814907347, 8.384058594703674, 34.07129430770874, 50.63518483298165, 49.349031584603445, 48.94840540204729, 51.86985192980085, 45.54395832334246, 50.4104140826634, 21.61279903139387, 17.421515362603323, 44.97915315628052, 47.54234709058489, 25.70758090700422, 7.97854174886431, 22.98521763937814, 33.49913099833897, 29.45886468887329, 21.018867015838623, 35.39671182632446, 19.877371788024902, 47.45247561591012, 30.07959590639387, 0.16843653390450136, 0.24470871474061692, 0.07181616672979933, 0.050395074034375806, 0.0570143527750458, 0.0455132758111826, 0.048867186198809316, 0.015267596014642289, 0.01203182535911245, 0.03831838224349277, 0.08579844608902931, 0.019539898460997, 0.02964005506198321, 0.02873075706884265, 0.05165225014622722, 0.068660171436412, 0.032366340913410695, 0.013242920461509908, 0.04731175662683589, 0.0660935788016234, 0.02418480144946703, 0.09107506687619857, 0.006944975549621242, 0.04494853111516152, 0.031974140887281725, 0.03740333705874426, 0.07188471912273339, 0.04783862889079111, 0.07533198914357594, 0.10570128953882627, 0.05400363522182618, 28.511427436556133, 71.97389480045864, 43.70382867540632, 43.17342056546892, 38.29695592607771, 36.33133486339024, 26.871070657457622, 29.425051280430385, 36.1568968636649, 68.6256412778582, 67.21130071367536, 38.29908554894583, 17.568768535341533, 31.2671959059579, 59.71299239567348, 61.291678701128276, 57.230640751974924, 58.740703174046104, 49.9915315083095, 14.15731940950666, 2.316143785204206, 0.8179404182093484, 0.6254285254648754, 1.781986687864576, 10.381988780839102, 26.00560130391802, 36.72585357938494, 49.471750668116975, 52.53785869053432, 61.20576422555106, 61.500791685921804, 62.071092878069194, 59.93696757725307, 57.98093850272042, 56.96406616483416, 48.0303955078125, 44.967188358306885, 46.98332977294922, 47.76514802660261, 50.04818364552089, 47.70685958862305, 48.91006524222237, 51.98876340048653, 52.40374108723232, 53.35851042611258, 52.120060035160606, 53.25234195164272, 51.84161097662789, 50.54112706865583, 51.798420974186485, 48.579237188611714, 45.05029576165335, 42.72845097950527, 43.74224179131644, 41.290010588509695, 41.940712860652376, 41.53986780984061, 43.7437287058149, 51.413466453552246, 48.87941673823765, 49.7039212499346, 46.52800737108503, 45.52122034345354, 41.28772463117327, 41.24453810283116, 41.75310802459717, 41.32813882827759, 43.086377007620676, 48.3780277797154, 50.401061807359966, 53.233265672411235, 49.84953464780535, 52.949296270098, 55.90639053072248, 50.21095561981201, 54.44609110695975, 50.59557662691389, 48.846405846732004, 40.661834376198904, 40.35969543457031, 43.095951625279014, 47.930584635053364, 51.01285416739327, 46.64271170752389, 49.726648807525635, 50.39623975753784, 40.89377219336373, 38.42525093896048, 41.367924213409424, 43.31803342274257, 43.18935973303658, 46.11142117636544, 46.16523150035313, 48.96387556621006, 50.116425377982004, 50.71699987139021, 50.43307910646711, 50.15433127539498, 46.756280013493125, 42.89511047090803, 37.26139988218035, 43.34002794538225, 48.52584375653948, 48.92903382437569, 47.52637665612357, 45.63422931943621, 48.21582555770874, 50.820465496608186, 47.42322369984218, 46.114523547036306, 38.58334330150059, 42.80992208208357, 40.200275966099326, 39.26116786684309, 36.49139356613159, 23.759476252964564, 15.361515181405203, 8.41075096811567, 6.545299044677189, 4.252858604703631, 0.836726284452847, 0.3843971719699246, 1.3513768570763725, 10.688043900898524, 37.98208441053118, 54.42744561604091, 53.2721825327192, 54.065857887268066, 56.316921370370046, 50.45545925412859, 54.20098645346505, 25.42826679774693, 18.753127200262888, 46.62362848009382, 53.13623407908848, 32.19648620060512, 13.123424853597369, 27.187983206340245, 20.24194724219186, 30.51080458504813, 27.885771683284215, 32.8757004056658, 25.878478799547466, 52.545098713466096, 36.768161160605295, 0.22168832857693943, 0.04774965937914593, 0.05034137138032487, 0.07007822141583477, 0.06942648853042296, 0.057750929679189406, 0.023256986235667552, 0.06568249514592545, 0.0785020843946508, 0.01667089803543474, 0.01989203269061233, 0.05116521806589194, 0.07020354004842894, 0.06876160563634974, 0.19163147998707636, 0.21104128632162297, 0.13243274656789644, 0.1730771434626409, 0.17060526753110544, 0.1132941371096032, 0.142770186864904, 0.2761359597955431, 0.12238871838365283, 0.13033098434763296, 0.15625279982175144, 0.08367685029017073, 0.17646205611526966, 0.13746298450444425, 0.12278382932501179, 0.31304196800504414, 0.10631719577525343, 41.2103772844587, 83.91171291896275, 50.96395969390869, 57.534124170030864, 47.95856155667986, 54.82801621300833, 48.807482038225444, 27.271021127700806, 44.52342775889805, 77.98187010628837, 76.49316992078508, 34.384644167763845, 17.140010833740234, 39.18856266566685, 64.23918097359794, 65.39750126429966, 62.582834652491975, 63.86737591879708, 55.15381377083914, 14.725126198359899, 3.1682387249810353, 1.3486367698226656, 1.1931326112576892, 2.2792223606790816, 10.957601870809283, 27.84284918648856, 39.513634136744905, 50.648087637765066, 56.79301193782261, 63.306135177612305, 61.67113372257778, 61.84657573699951, 59.12167985098702, 60.34780066353934, 58.34693486349923, 49.82532712391445, 45.45135620662144, 48.4255256652832, 52.17602777481079, 52.55976983479091, 49.52877105985369, 51.219295569828574, 54.85784830365862, 55.44029842104231, 54.75601897920881, 52.1657965523856, 54.69576072692871, 52.21731744493757, 52.830464703696116, 53.66208069665091, 51.57051311220442, 45.79455900192261, 44.16396965299334, 44.47161504200527, 39.604207379477366, 43.075784478868755, 43.82142693655831, 44.66408709117344, 51.600379943847656, 50.567412103925435, 48.764503955841064, 47.56498432159424, 46.481496129717144, 41.764047963278635, 40.98538071768624, 43.35545294625418, 41.13925552368164, 45.267774377550396, 46.29341186795916, 49.7552684375218, 51.57011359078543, 50.89515863146101, 51.95168086460659, 52.190643310546875, 51.5649093900408, 54.13263354982649, 54.004449708121165, 50.95665366309029, 42.63432720729283, 42.90657499858311, 47.290078844342915, 52.527398177555625, 55.16378443581717, 52.01383597510201, 55.75551387241909, 53.767867020198274, 44.70188876560756, 41.5748485156468, 46.05115597588675, 46.315319538116455, 45.55589880262102, 49.75548035757882, 47.8332507950919, 48.33831535066877, 52.36799260548183, 50.681452887398855, 50.22192335128784, 52.00623117174421, 47.53294965199062, 44.0493243762425, 39.52717617579869, 42.87142406191145, 52.13948025022234, 52.54711021695818, 51.38460711070469, 49.38072231837681, 53.59075743811471, 53.33448355538504, 51.75991753169468, 47.49859775815691, 43.2203243800572, 45.085533550807405, 43.44765554155622, 41.87110928126744, 39.88032879148211, 24.68221092224121, 17.78854353087289, 10.987780502864293, 9.321597269603185, 4.951776598181043, 1.2216258708919798, 0.7145968750119209, 2.5348504952022006, 11.795239346367971, 42.01452704838344, 59.52757971627371, 60.361836024693076, 56.89665126800537, 60.91293934413365, 54.56231015069144, 58.21870585850307, 27.892065014157975, 22.347359112330846, 54.743407998766216, 63.879472732543945, 32.414854185921804, 11.8348388671875, 29.713887895856583, 45.84586450031826, 42.56752027784075, 31.00045803615025, 47.668276241847444, 31.977923665727886, 59.612792423793245, 52.81054769243513, 1.2405537409441811, 0.3850228898227215, 0.17758675505008015, 0.3142248716737543, 0.18354053342980997, 0.21020272560417652, 0.10648526889937264, 0.16329790678407463, 0.16853148809501103, 0.07157196876193796, 0.23672667305384362, 0.11089381948113441, 0.1688712848616498], [0.04241369391924568, 0.053196042842630825, 0.09367268891738993, 0.11524998715945653, 0.03364870763782944, 0.0361702285840043, 0.058449189710829935, 0.039446626523775716, 0.04818866814353636, 0.05198544476713453, 0.014337989468393582, 0.057736714370548725, 0.06510073279163667, 0.05698536575904914, 0.06589381130678312, 0.09700627718120813, 0.04594684611739857, 0.009512985474430025, 4.792410978249141, 58.1632661819458, 48.220956802368164, 34.39922843660627, 52.896722725459504, 39.82925605773926, 42.390257835388184, 23.69944555418832, 19.786131518227712, 58.49454934256417, 64.97715609414237, 41.73870440891811, 6.158978334494999, 18.1670275415693, 44.7458222252982, 61.09562138148716, 53.455260617392405, 54.00372362136841, 44.68716205869402, 19.71941317830767, 4.2143299749919345, 0.5602538798536573, 0.1575264779052564, 2.8688443217958723, 14.299121720450264, 29.947562762669154, 40.516356468200684, 46.63612481525966, 52.109144415174214, 52.40166704995291, 58.21317856652396, 62.78957830156599, 58.45577144622803, 55.74665491921561, 52.501648153577534, 48.17109652927944, 50.20583479745047, 50.912880011967246, 51.90656968525478, 53.69527571541922, 49.07678379331316, 53.570176873888286, 51.31782449994768, 56.686621120997835, 50.27823155266898, 55.977359431130544, 44.87182085854666, 47.13447393689837, 52.41970804759434, 53.97139712742397, 50.30703183582851, 45.53049966267177, 44.17053917476109, 42.39256811141968, 42.9018224307469, 40.80647502626692, 38.03818416595459, 39.27762120110648, 43.94378818784441, 46.11317907060896, 41.56557614462716, 41.82403523581368, 37.963755062648225, 37.08533600398472, 35.54573678970337, 38.19410521643502, 40.55535670689174, 42.108022008623394, 46.506005900246755, 48.94533429827009, 49.70797552381243, 49.29186528069632, 55.37044470650809, 50.823432377406526, 49.32550498417446, 50.31602280480521, 46.43133708408901, 46.77507141658238, 38.661399364471436, 36.276159218379426, 39.171682017190115, 44.46832854407174, 45.74609184265137, 45.36071000780378, 44.71701151984078, 45.1670880317688, 37.61891596657889, 37.82247734069824, 38.79272379193987, 44.709323338099885, 45.9992390360151, 44.02714920043945, 44.15588889803205, 45.85073518753052, 48.067085470472065, 47.992729323250906, 48.87697444643293, 47.93288101468767, 47.74360513687134, 42.527693203517366, 38.28048522131783, 33.30670411246163, 37.3483670098441, 44.59905195236206, 44.32232257298061, 45.454465525490896, 48.719576903751914, 45.53458520344326, 45.66980062212263, 40.41833128247942, 33.58287763595581, 37.798881258283345, 38.93160785947527, 37.67334468024117, 33.341000420706614, 25.216723680496216, 19.57191160746983, 13.768690160342626, 11.79039558342525, 5.727083086967468, 1.910686433315277, 0.6219897642731667, 1.896003586905343, 11.213464941297259, 37.40734331948416, 47.49342482430594, 51.346322536468506, 47.760100160326274, 50.22994157246181, 46.39036703109741, 43.8513354573931, 27.536576066698345, 18.297594615391322, 34.29758671351841, 34.363361835479736, 14.260876229831151, 10.84587483746665, 28.831044571740286, 36.061831610543386, 23.649628707340785, 27.535943780626567, 29.567972251347133, 29.974191733769008, 55.5462132862636, 13.819682989801679, 0.1774725847478424, 0.024705320929310153, 0.010368075304930764, 0.02540073959556009, 0.026460502729085938, 0.04231137762378369, 0.05532622889482549, 0.009311442762347204, 0.03427401836961508, 0.06356838358832256, 0.018823645376999463, 0.00865887273435614, 0.07028707449457475, 0.03558613546192646, 0.011502918338270059, 0.019049758690276315, 0.07860203938824789, 0.023211132535444837, 0.02243202505633235, 0.016283770058570162, 0.018122793341587697, 0.03277874771239502, 0.027920793209757124, 0.048019597572939735, 0.05155015776732138, 0.0397741587699524, 0.025389755809945718, 0.03530286405501621, 0.12539656912641867, 0.02622978894838265, 0.15255221910774708, 5.0597290226391385, 69.53916263580322, 54.87805713926043, 37.22037076950073, 51.549022333962576, 38.1512313570295, 26.905408654894146, 28.03404971531459, 26.26274197442191, 64.9911914552961, 65.03973157065255, 52.47712101255144, 10.18256071635655, 19.547118697847637, 46.03704418454851, 64.08450712476457, 56.36313383919852, 57.851031507764546, 50.3871237209865, 23.11051971571786, 4.8536662970270426, 0.6619186731321471, 0.33689746792827335, 3.726689330169133, 15.5709582056318, 31.270419870104107, 43.829063006809776, 52.535742964063374, 53.96007503782, 56.16210855756487, 59.39010960715157, 63.11810997554234, 59.689069747924805, 58.04896136692592, 54.12138441630772, 50.65815210342407, 52.20894486563546, 53.02465990611485, 52.434007440294536, 55.62962988444737, 52.429445947919575, 53.92068222590855, 51.70293535505022, 55.37768472943987, 53.619724478040425, 56.431156703404014, 48.38550056729998, 48.97021927152361, 51.52277898788452, 52.73350259235927, 51.41669389179775, 45.92411163875035, 42.79508072989327, 42.89055592673165, 41.86881290163313, 41.21144730704171, 39.79480341502598, 43.26978165762765, 49.545582226344514, 50.79204389027187, 48.16851527350289, 46.95186138153076, 44.300588607788086, 42.14515665599278, 38.99789367403303, 42.44844899858747, 42.908826214926584, 45.830255372183665, 50.25112315586635, 52.02098914555141, 52.4639368057251, 51.21561649867466, 53.256573404584614, 53.127156257629395, 50.54650844846453, 52.922517912728445, 48.96496295928955, 50.885497161320274, 41.74183457238333, 40.08286183220999, 43.31426749910627, 48.42569589614868, 48.86686481748308, 48.710283688136506, 49.33173057011196, 48.588311535971506, 39.49876151766096, 38.595940385546, 41.618570055280415, 48.17476517813546, 46.02755989347185, 46.774512086595806, 45.58847543171474, 46.087192807878765, 47.04358802522932, 47.39391967228481, 49.0478514943804, 48.77288000924246, 46.74729251861572, 42.27121434892927, 37.89984900610787, 36.81721544265747, 41.393632548195974, 47.13472407204764, 47.437092304229736, 47.11185755048479, 51.91024875640869, 48.602760314941406, 46.7718300819397, 41.87568467003958, 36.64293377740042, 39.43615130015782, 41.036383969443186, 39.991746629987446, 35.767898491450715, 25.256274563925608, 21.275514364242554, 14.16009521484375, 11.723454901150294, 5.49896547624043, 2.0842129162379672, 0.27408078578966005, 2.4411598997456685, 12.307461415018354, 40.65512241636004, 50.41615676879883, 54.43315356118338, 51.439508301871165, 55.578254904065815, 50.781336716243196, 46.35492427008492, 28.681606190545217, 21.688494443893433, 36.30536944525582, 45.78016580854143, 20.46959454672677, 16.21682800565447, 25.813457557133265, 21.520704133169993, 31.300088678087505, 27.28639922823225, 31.1294652393886, 33.662785393851145, 63.65804753984724, 17.24754810333252, 0.09566199074366263, 0.08176760881074838, 0.029577232897281647, 0.04193611043904509, 0.07401279493102006, 0.08703707105347089, 0.06213290882962091, 0.044573901753340445, 0.04040290967428258, 0.06936765275895596, 0.01900070739377822, 0.025143430634800876, 0.04801776892106448, 0.17700576622571262, 0.10437415646655218, 0.13819375314882823, 0.18971294936324867, 0.10058843996375799, 0.18380436141576084, 0.14855400579316275, 0.171090162226132, 0.14425697922706604, 0.13647901373250143, 0.19501867251736776, 0.092778440830963, 0.19962099912975514, 0.1332020288599389, 0.1529171352407762, 0.29076243351612774, 0.13854344295603888, 0.26308651002390043, 9.602162054606847, 85.57063702174595, 61.52935573032924, 49.30609171731131, 66.1020416532244, 57.13459580285208, 55.96529041017805, 27.056424277169363, 26.126612867627824, 68.64951528821672, 69.04385335104806, 48.86794178826468, 11.370265807424273, 22.844546147755214, 53.42973640986851, 69.5845969063895, 60.46361323765346, 63.634222166878835, 55.20891298566546, 27.48613735607692, 5.435115439551217, 1.674287655523845, 0.6238794028759003, 4.670052332537515, 17.430714777537755, 34.33091722215925, 46.245208740234375, 55.22716242926461, 57.85607589994158, 57.98341900961739, 61.46117305755615, 65.24509947640556, 61.79825101579939, 59.63192081451416, 55.70891577856881, 52.794664110456196, 53.81494106565203, 54.690163952963694, 54.591489110674175, 58.294538497924805, 53.21015248979841, 55.656759125845774, 55.6655729157584, 58.06727681841169, 56.03674568448748, 59.1666624886649, 50.51512343542916, 50.008710929325645, 54.558356625693186, 54.81095838546753, 53.32413421358381, 47.01338768005371, 46.032218660627095, 42.037973744528635, 43.96970844268799, 41.87933942249843, 40.92318044389997, 44.44920710154942, 48.16273784637451, 53.05979347229004, 50.19777488708496, 49.76868540900094, 45.372459411621094, 43.44372980935233, 41.07639864512852, 42.91581610270909, 44.598704542432515, 47.433163097926546, 49.27146189553397, 51.78787708282471, 51.07535668781826, 52.27549818583897, 51.81676769256592, 51.74805348260062, 50.45387506484985, 54.349653584616526, 49.58882086617606, 53.53239951814924, 44.6905632019043, 42.131930759974885, 46.33114753450666, 53.621815885816304, 52.706637382507324, 56.21900735582624, 52.83835090909685, 52.28403752190726, 43.549255575452534, 41.14662756238665, 43.765427930014475, 50.66767808369228, 49.27815301077706, 46.95547791889736, 47.020731925964355, 49.85696922029768, 47.891139711652485, 47.81001949310303, 49.196282386779785, 48.48625292096819, 50.47947917665754, 45.135887145996094, 41.29227570125035, 38.40470858982631, 43.74388156618391, 48.969364643096924, 50.00154733657837, 51.29175138473511, 54.22357504708426, 51.40278359821865, 47.98792116982596, 45.22072465079171, 40.50787966591971, 44.11909123829433, 43.04477119445801, 42.22898319789341, 36.25302866527012, 28.959040812083654, 22.64688379423959, 16.171862738473074, 13.60797485283443, 6.792449508394514, 2.9235299016748155, 1.4034735815865653, 3.6008092505591254, 14.20816285269601, 43.585073539188926, 55.85250725064959, 60.58624199458531, 56.70905685424805, 59.516803060259136, 53.46679810115269, 52.812250001089915, 34.11066974912371, 23.63637501852853, 43.56277676991054, 47.80408573150635, 18.19934187616621, 14.74549136843, 38.197874614170615, 52.077252183641704, 34.258711542402, 36.690879821777344, 41.44004651478359, 40.384684630802695, 74.97479397909981, 30.666274002620153, 0.23723215450133595, 0.17590732659612382, 0.20115044420318945, 0.15319604027484143, 0.20842553382473333, 0.14689623617700168, 0.10217190999537706, 0.0839432974212936, 0.12546610539512976, 0.20215559883841447, 0.0719956595982824, 0.048573007341474295, 0.14283121430448123], [0.08620982830013547, 0.04586602920400245, 0.07733714833323445, 0.01851467615259545, 0.04460330606837358, 0.044193355566156764, 0.055025400394307714, 0.0650792368022459, 0.04827070641996605, 0.038184683703418286, 0.02273547779103475, 0.02839614770242146, 0.06113466168088572, 0.08797306939959526, 0.03248197006593857, 0.05678089601652963, 0.09893525724432298, 0.0724673228604453, 0.5125763724957193, 27.36143456186567, 63.18782820020403, 29.1520357131958, 47.38925395693098, 85.09925733293805, 39.004345076424734, 39.81579392296927, 13.666636756488256, 32.61259991782052, 55.54051923751831, 52.16421583720616, 30.42191628047398, 17.349057810647146, 48.71328183582851, 62.26164027622768, 52.57188401903425, 58.02640404020037, 50.15904910223824, 35.07644156047276, 6.343356166567121, 1.192599662712642, 0.8767904660531453, 4.303438884871347, 15.464511803218297, 30.338576112474712, 46.01183959415981, 51.69839470727103, 51.37163134983608, 55.10260207312447, 59.71625110081264, 60.53253241947719, 57.50106464113508, 55.27032811301095, 55.022454602377756, 53.846572739737375, 54.12268372944423, 55.838603905269075, 59.37286417824881, 58.68134471348354, 58.18580266407558, 54.86913912636893, 54.5831686428615, 50.69905267442976, 53.29969392504011, 48.903989042554585, 48.409850529261995, 54.51541675840105, 53.11284644263131, 51.8605135508946, 51.11109822137015, 41.95933403287615, 43.68728848866054, 45.362367153167725, 39.53203991481236, 40.0233713558742, 39.07966007505144, 38.12713153021676, 41.95603016444615, 43.218528270721436, 41.90336629322597, 41.87894684927804, 38.29812669754028, 36.0572874886649, 38.24737010683332, 38.268954685756135, 39.83072907584054, 42.38235425949097, 47.922121729169575, 51.867024012974326, 51.65693480627877, 55.97858926228115, 55.249264648982454, 51.58796003886631, 54.343323775700156, 51.087429182870046, 50.43141153880528, 46.67900562286377, 42.22150346211025, 36.798121792929514, 37.81267690658569, 42.25208943230765, 47.28108787536621, 46.22405842372349, 46.305682386670796, 45.29562970570156, 36.04842158726284, 36.9337923186166, 39.45114203861782, 45.42932346888951, 48.65258584703718, 46.75192696707589, 46.71776614870344, 46.47781705856323, 46.63866090774536, 49.47424854551043, 47.91404792240688, 47.82173415592739, 46.65759474890572, 42.64469044549124, 41.980699743543354, 35.59687205723354, 30.99554565974644, 32.993458475385395, 38.15497643607003, 40.644394397735596, 44.899888106754844, 40.9253830228533, 41.40781382152012, 37.54122468403408, 36.099348408835276, 38.71575859614781, 40.03018059049334, 41.055804184504915, 36.926604407174246, 27.10724687576294, 21.82570399556841, 18.74902081489563, 16.281677280153545, 8.754351547786168, 3.950755706855229, 1.0005063989332743, 2.0000057433332716, 14.385197741644722, 34.80758101599557, 48.84218481608799, 47.154915537152974, 49.232374804360525, 49.30056095123291, 42.13198634556362, 47.369090284620015, 16.312044382095337, 32.040940352848594, 41.16976853779384, 29.271739278520855, 9.36600146974836, 14.41575505052294, 31.49636834008353, 28.084712505340576, 25.374091693333217, 37.07737684249878, 27.565562214170182, 42.456408160073416, 33.54401636123657, 0.7181689547640937, 0.13476234727672168, 0.04988263760294233, 0.04207972576841712, 0.05682515685579606, 0.06069786833333118, 0.04310492772076811, 0.04386805909286652, 0.07667641807347536, 0.054190181461828094, 0.06852280880723681, 0.055411527532019784, 0.026275517119626914, 0.06461703231824295, 0.048790725480232916, 0.04957085754722357, 0.0569168608635664, 0.021858552703633904, 0.05658510473689862, 0.04546752219487514, 0.0662291297422988, 0.01544604733187173, 0.05729485236640487, 0.019666910038462708, 0.0930234326847962, 0.008428098733669944, 0.055915319427315674, 0.05011240313095706, 0.012297308970508831, 0.05025056982412934, 0.017694054204704504, 0.009775833825447729, 0.4276463969477585, 34.51612145560128, 74.18126801082066, 37.01755632672991, 43.22546257291521, 91.68673324584961, 29.813222817012242, 30.430327074868337, 23.575213500431605, 36.214004107883994, 54.64925643375942, 44.05681800842285, 27.13695910998753, 21.875098739351543, 53.90120642525809, 65.12229701450893, 57.73692124230521, 61.03406034197126, 54.63200058255877, 38.305589062826975, 8.475900752203804, 1.3661647949899947, 1.1425769754818507, 4.934221540178571, 15.060435840061732, 32.407419613429475, 48.33109964643206, 55.629303319113596, 56.374546255384175, 59.11908122471401, 62.38136468614851, 61.92994717189244, 58.970306396484375, 57.15166057859148, 56.253581592014854, 56.21618638719831, 55.42828845977783, 56.82388973236084, 59.01184967585972, 58.42594977787563, 56.48546382359096, 53.4870034626552, 56.10843372344971, 54.43034301485334, 55.20800971984863, 50.80510997772217, 49.062199524470735, 54.026600565229145, 54.07822568075997, 52.746624265398296, 49.910442556653706, 44.76192120143345, 43.970837524959016, 44.80596930640084, 39.95117957251412, 40.454951763153076, 40.63198144095284, 40.99084200177874, 47.07547330856323, 47.296130725315635, 49.55075863429478, 45.371312958853586, 42.59550067356655, 40.33676290512085, 41.40491642270769, 41.728177888052805, 41.92400939123971, 44.42864738191877, 50.42368514197213, 52.99776342936924, 54.170952865055625, 56.679426261356895, 54.430509771619526, 53.416329860687256, 55.131134850638254, 52.020992619650706, 51.81047262464251, 49.44614308220999, 43.00755664280483, 39.02525915418352, 41.93518556867327, 46.79696519034249, 51.11296728679112, 49.62539618355887, 50.15379973820278, 48.57484245300293, 39.37161643164498, 42.36535201753889, 42.11444909232003, 48.21354307447161, 49.11337300709316, 48.634489263807026, 46.789801597595215, 48.039313520704, 47.58641604014805, 48.68491928918021, 48.54643474306379, 47.59641449792044, 45.86652149472918, 42.088282176426475, 42.502721377781455, 37.63567502158028, 33.84896237509591, 37.347036429813926, 41.010682582855225, 43.80550513948713, 46.52087851933071, 44.47597851072039, 41.95743022646223, 39.132337842668804, 39.01309980664934, 40.749645709991455, 42.902208055768696, 42.53426619938442, 39.90398393358503, 28.84801033564976, 24.16341151509966, 20.342157636369976, 16.869449717657908, 7.914334314210074, 4.195997587272099, 0.6483085634452956, 2.2273922732898166, 16.357013123376028, 36.487613746098106, 51.61992175238473, 50.98487377166748, 52.22578035082136, 53.242621421813965, 45.50106361934117, 49.25636345999581, 18.64447127069746, 36.193288053785054, 42.19925880432129, 32.96621111461094, 13.327160801206317, 20.134371757507324, 18.967294999531337, 26.15589083944048, 30.258206299373082, 31.81521769932338, 32.14827959878104, 47.83335501807076, 41.652133328574045, 2.1207712973867143, 0.19869154186121055, 0.051259646391762156, 0.0653867692287479, 0.06256409069257123, 0.06632595668945994, 0.013076040710854744, 0.029638738704047034, 0.050422663268234046, 0.06438879349402019, 0.007516774465329945, 0.05670251165117536, 0.024494055658578873, 0.04207285560135331, 0.20749455663774694, 0.11322468905044453, 0.13598841934331826, 0.06935573768402849, 0.1586977650544473, 0.12247429522020475, 0.2124048431536981, 0.11315829439886979, 0.12421472397233758, 0.17342767465327466, 0.18373635863619192, 0.05661873293242284, 0.20408179690795286, 0.1650590987077781, 0.1254788211413792, 0.1387348576847996, 0.2305289070521082, 0.14785120636224747, 1.3649631908961704, 53.36400645119803, 84.67418738773891, 46.558923380715505, 57.042004108428955, 95.70435537610734, 54.48512956074306, 45.22587326594761, 17.875521080834524, 39.614299637930735, 64.69388498578752, 56.282857826777864, 34.578005586351665, 25.59654000827244, 56.74950579234532, 71.49096025739397, 61.67589323861258, 68.61566366468156, 61.46567549024309, 43.48900427137102, 10.016696793692452, 2.254167590822492, 1.4628145630870546, 6.599854562963758, 17.94819576399667, 33.66864619936262, 51.53208262579781, 58.1820193699428, 59.60386398860386, 60.87091663905552, 63.37760434831892, 62.37418024880545, 60.91398157392229, 58.114948408944265, 58.470758710588726, 57.38871921811785, 57.65912921088082, 59.22559710911342, 64.81888307843889, 62.852473395211355, 60.98645823342459, 56.91336515971592, 58.4715508052281, 56.83676127025059, 56.967905044555664, 51.14788893290928, 49.100616114480154, 55.35086815697806, 55.554988861083984, 54.95673854010445, 51.250131675175254, 45.04876715796334, 44.42868559701102, 46.601095472063335, 42.39937039784023, 43.95303971426827, 41.81649991444179, 41.78077227728707, 48.43557276044573, 47.73698697771345, 51.91550159454346, 48.18676471710205, 44.266226291656494, 40.97709151676723, 43.79328325816563, 41.79035036904471, 43.95697586877005, 44.89943299974714, 54.67812967300415, 53.956899711063926, 54.777735573904856, 56.790184020996094, 54.99162891932896, 54.04271691186087, 57.84855100086757, 55.726911612919395, 55.11105803080967, 50.87589822496687, 46.68407433373587, 41.93190254483904, 44.30925301143101, 51.39248636790684, 57.25733225686209, 54.80383995601109, 54.32627289635794, 51.48939636775425, 40.57067748478481, 45.31675917761666, 44.60412413733346, 49.69399227414812, 51.902379921504426, 50.5296173776899, 49.340044089726035, 50.873108523232595, 49.70855222429548, 51.76741811207363, 48.399862493787495, 48.05240045275007, 49.375101225716726, 43.79598610741751, 46.26396540233067, 42.94418559755598, 36.9792092187064, 39.8967091696603, 43.95203569957188, 48.541463306971956, 50.67417464937483, 47.46595859527588, 45.58320869718279, 44.28106764384678, 42.102741377694265, 43.407078061785015, 45.94685656683785, 48.6326618875776, 43.90302658081055, 30.603722844805034, 26.774490697043284, 22.199645621435984, 18.371575559888566, 9.972526226724897, 4.739258127553122, 2.196043521165848, 3.217617618186133, 18.692547593797954, 40.87751340866089, 58.38917991093227, 54.69679600851876, 58.09303726468767, 56.17050545556204, 49.73365606580462, 55.355933393750874, 22.488853965486797, 39.93735613141741, 51.07669421604702, 37.55639260155814, 11.948532240731375, 18.212640728269303, 42.63914230891636, 40.90968704223633, 34.145327363695415, 46.764881883348735, 38.084768363407676, 54.438979625701904, 59.144622802734375, 4.812367073127201, 0.29982193452971323, 0.12033209231282983, 0.1463740220559495, 0.12440265103110246, 0.14588863881570951, 0.1470576325165374, 0.15927765465208463, 0.13142776835177625, 0.14100040468786443, 0.13952949004513876, 0.1569978312722274, 0.1333075546260391, 0.09597133485866444], [0.029757221096328328, 0.0493499977913286, 0.04448387711974127, 0.04405602686373251, 0.009570647380314767, 0.02444038523494133, 0.02800609015061387, 0.05584216656695519, 0.019620820547321012, 0.04940094220052872, 0.0381780001334846, 0.042334061049457104, 0.045134351322693486, 0.05339856858232191, 0.11016820770289217, 0.03525565837376884, 0.03286936945681061, 0.1143807838005679, 0.15329824121935026, 7.958589128085545, 65.59767886570522, 44.61436925615583, 31.575643811907085, 34.985705035073416, 38.8152984891619, 48.84493282863072, 16.782058749880107, 26.229043211255753, 68.40295846121651, 72.94728183746338, 56.93166324070522, 17.264442648206437, 44.580104214804514, 66.83140100751604, 59.28328105381557, 57.177330698285786, 51.068981715611045, 43.58090809413365, 17.56163968358721, 3.844687981264932, 1.4938667139836719, 6.758904039859772, 19.945167098726543, 36.33634451457432, 48.97277620860508, 54.290434088025776, 55.296755586351665, 54.843548910958425, 58.443514823913574, 58.396711758204866, 56.76705346788679, 56.63159138815743, 55.94231619153704, 56.052007402692524, 57.2919898714338, 62.20015566689627, 60.26725714547293, 60.245071547372, 55.55649662017822, 51.459505217415945, 50.19975164958409, 51.18675020762852, 45.68000405175345, 46.61292478016445, 53.44247593198504, 53.208825383867534, 52.992951801845, 54.961536271231516, 47.7942088672093, 45.59817859104702, 45.241107191358296, 43.863460063934326, 41.50258725030081, 41.48025574002947, 39.90231984002249, 38.139356885637554, 39.383782727377756, 44.265618324279785, 41.28690126964024, 39.51373141152518, 39.46979795183454, 39.541076047079905, 39.72017976215908, 41.45919227600098, 41.478612491062705, 42.93379456656319, 46.17275639942714, 52.21094594682966, 53.28957734789167, 53.37644720077515, 50.151600633348735, 52.85318878718785, 53.8148889541626, 51.569908618927, 49.31142793382917, 47.45407370158604, 42.70443800517491, 38.089312485286165, 40.12049674987793, 42.32321466718401, 45.56177003043038, 43.329268659864155, 45.909919943128315, 43.462517738342285, 35.947540691920686, 38.179197856358115, 43.0026581627982, 49.045436995370046, 50.770910944257466, 47.786478996276855, 48.88855014528547, 46.69701187951224, 47.102849211011616, 45.48819555555071, 46.487878050122944, 47.72295161655971, 44.66199220929827, 37.48744215284075, 39.02956703730992, 35.42347976139614, 30.439835684640066, 23.59733830179487, 22.369447435651505, 22.88252673830305, 21.09751714978899, 20.73563412257603, 23.535947493144445, 22.909188713346207, 29.029365267072404, 33.58601474761963, 36.06678220203945, 33.03958409173148, 29.59677948270525, 31.421056815556117, 23.042818205697195, 21.3059526852199, 19.102807453700475, 11.093103034155709, 5.16232351745878, 1.119602756840842, 2.2138081107820784, 16.37100853238787, 37.61405222756522, 47.313685349055696, 46.0962358883449, 49.336726324898855, 45.12459979738508, 51.310150214603965, 28.50271439552307, 28.6062581879752, 50.59951278141567, 50.72695663997105, 27.987809453691753, 9.77322062424251, 25.398443392344884, 35.06463657106672, 26.643730810710363, 36.87190471376692, 33.033031940460205, 31.46720675059727, 51.23883737836565, 23.253338200705393, 0.45538243864263805, 0.07439559046179056, 0.06947290032569851, 0.018649555343602384, 0.03656183149931686, 0.05281377996184996, 0.06732376957578318, 0.055885599593498876, 0.017388762640101568, 0.02736089495010674, 0.031655812968633006, 0.06901999177145106, 0.01492443201797349, 0.002747404617756339, 0.061224425078502724, 0.018751768162474036, 0.017604182241484523, 0.0290040370476033, 0.0212140971062971, 0.05542287942288177, 0.030873268709651062, 0.01169246539939195, 0.010781125015845256, 0.05512044957971998, 0.04159830856536116, 0.025745742422129427, 0.037611460712339194, 0.009289532866595047, 0.05637584453714745, 0.021250556489186626, 0.06629127676465682, 0.07063639110752515, 0.2526164704135486, 12.940417987959725, 78.45149884905133, 48.56981543132237, 35.67723839623587, 42.620066029684885, 41.22977318082537, 29.1664844921657, 24.14328953198024, 32.89614200592041, 69.8915822165353, 68.84576715741838, 56.54951926640102, 19.757063729422434, 46.30569975716727, 66.8222849709647, 59.86080142429897, 60.673226492745535, 55.44246973310198, 47.09845100130354, 18.150383131844656, 4.1456166335514615, 1.815438789980752, 6.944882128919874, 21.65356237547738, 38.69011974334717, 51.737384523664204, 57.144281591687886, 57.67125381742205, 57.46929747717721, 63.363492556980674, 58.93410628182547, 60.00754043034145, 61.76711613791329, 56.65872410365513, 56.51356928689139, 57.24814673832485, 62.95449379512242, 59.964204515729634, 59.25671114240374, 56.70091356549944, 55.164229120527, 53.94790874208723, 53.439335346221924, 49.80254398073469, 48.03427955082485, 55.31716244561331, 53.7403347832816, 53.277942589351106, 55.08976527622768, 49.32983718599592, 44.35620198931013, 45.08706215449742, 43.64614473070417, 41.71351718902588, 42.26185165132795, 41.602912289755686, 39.30583436148507, 43.36640330723354, 47.009687764304026, 45.92627600261143, 44.69323131016323, 44.28142547607422, 42.55090018681118, 42.75041423525129, 44.562368937901084, 44.5582069669451, 46.33287068775722, 50.46618379865374, 54.64359712600708, 53.36806419917515, 52.09929186957223, 51.5550776890346, 53.9041177204677, 53.53582150595528, 52.36334078652518, 51.635819230760845, 48.893156800951274, 46.954557282584055, 41.06585475376674, 42.46308537891933, 45.71612426212856, 51.63398838043213, 48.69646372113909, 50.69227818080357, 47.66860975537981, 39.65485627310616, 39.535586970193044, 45.75254324504307, 50.983487606048584, 51.448408944266184, 48.99690382821219, 48.617542607443674, 48.28790269579206, 47.362986292157856, 45.2675381387983, 46.97363356181553, 47.25445195606777, 45.06475843702044, 40.15088469641549, 39.529132093702046, 36.730317796979634, 33.21161454064505, 25.477102211543492, 27.438319853373937, 27.547665391649517, 26.86182086808341, 28.350840670721873, 26.520740747451782, 26.781136648995535, 31.117750576564244, 35.538336958204, 39.00061389378139, 35.19129875728062, 30.258525916508265, 31.920409951891216, 26.494526931217738, 23.887944970812114, 20.131861720766338, 10.100793446813311, 5.579281006540571, 1.0621982600007738, 2.493862203189305, 18.43170527049473, 39.998142446790425, 52.084353242601665, 48.860107694353374, 52.61843694959368, 47.48051854542324, 54.34722866330828, 31.22802891050066, 33.069346700395855, 50.342252254486084, 55.39355788912092, 31.291796003069194, 15.325014557157244, 20.217322826385498, 21.86624152319772, 30.952192374638148, 35.27645935331072, 34.091082777295796, 36.185992445264546, 56.505582332611084, 29.839372362409318, 0.36233949129070553, 0.008236123365350068, 0.0763624259935958, 0.0235220101395888, 0.027239486375557523, 0.02080946631862649, 0.034080802130379846, 0.04847903024139149, 0.014732488031898226, 0.03056712049458708, 0.08077844724591289, 0.07609802803822927, 0.01797232311218977, 0.10113974966640983, 0.17297832162252494, 0.12648236086325987, 0.14313936419785023, 0.20937153377703258, 0.18884966282972268, 0.17296369240752288, 0.08813553103911025, 0.13684941242848123, 0.12493185406284672, 0.10071606561541557, 0.13365572451480798, 0.15174305252730846, 0.17894032384668077, 0.14600557754082338, 0.21792088502219745, 0.17205653179969105, 0.24443420661347254, 0.2179200029266732, 0.4079069175890514, 23.532480342047556, 93.96340778895787, 56.94172075816563, 50.033262389046804, 47.3445075580052, 54.405975682394846, 60.383813176836284, 18.281995909554617, 33.92198099408831, 77.11231000082833, 78.19290774209159, 64.70616940089634, 23.19027635029384, 51.24590022223336, 75.50540011269706, 68.09439590999058, 67.88822201320103, 61.469260760716026, 53.39252185821533, 21.261131593159266, 5.544160033975329, 2.5133349640028815, 8.652229530470711, 22.880607298442296, 39.99012075151716, 52.95987490245274, 60.17460986546108, 61.83349922725132, 59.018325396946494, 65.23940195356096, 59.397780418395996, 59.64203044346401, 62.67813614436558, 58.95544419969831, 59.65403693062918, 60.85034997122628, 64.41110025133405, 60.31472029004778, 61.57847254616873, 58.34168202536446, 58.60847200666155, 58.34839398520333, 56.36358199800764, 48.09935985292707, 49.30029691968645, 56.30517544065203, 55.19606229237148, 55.08104528699602, 58.024010385785786, 48.72295372826712, 48.07173034123012, 47.65876068387713, 47.18461561203003, 42.16726234980992, 43.80598109109061, 42.89647231783186, 42.43247161592756, 45.75050742285592, 51.41236516407558, 48.491443225315635, 45.15290675844465, 46.79731954847063, 46.738589899880544, 46.450250080653596, 47.7012871333531, 45.89344923836844, 47.18515757152012, 49.45104503631592, 53.52854674203055, 54.87982545580183, 51.1865348134722, 51.749450070517405, 56.104153633117676, 56.03484187807356, 56.30410541806902, 53.01498106547764, 51.51626852580479, 49.61795118876866, 43.48362289156233, 48.06849248068673, 50.68336364201137, 55.83846494129726, 53.40245083400181, 55.086843558720176, 51.897474493299214, 43.8233585357666, 42.7301915032523, 48.89967768532889, 53.04051569529942, 54.126286370413645, 50.69238587788173, 50.44499526705061, 50.241656235286165, 48.75224385942732, 46.97256701333182, 48.32795558656965, 49.15434306008475, 46.05300767081124, 41.9698223386492, 43.54547922951834, 41.01150941848755, 35.66406461170742, 27.67850865636553, 27.965137481689453, 29.8057222366333, 27.259664297103882, 31.781466824667795, 27.6791444165366, 28.66165270124163, 33.78304481506348, 39.73969725200108, 43.410319396427695, 39.20098604474749, 33.6130119732448, 36.891231128147666, 29.05254098347255, 26.640355723244802, 22.986383199691772, 12.783865519932338, 7.12649153811591, 1.9798401168414523, 3.538262869630541, 21.71542739868164, 45.26933772223336, 56.92555577414376, 53.022728306906565, 58.462115151541575, 51.6763584954398, 59.13220637185233, 35.21406800406319, 37.20268760408674, 59.33230059487479, 60.732369559151785, 34.6400842666626, 13.607213156563894, 32.08403308050973, 49.274095262799946, 36.164869921548025, 46.7778229032244, 45.373182024274556, 42.806361130305696, 66.29381193433488, 41.270604269845144, 0.40416770109108513, 0.1564727265919958, 0.12147481313773564, 0.1356650295534304, 0.1153351433042969, 0.12548780494502612, 0.23304005659052304, 0.14401605858334474, 0.12907615596694605, 0.12046680865543229, 0.12862910995525972, 0.2519368768802711, 0.12904087214597634, 0.15729908724980696], [0.0705769242984908, 0.04339589710746493, 0.04194793391174503, 0.054455234203487635, 0.0010356126939378946, 0.031265472128455124, 0.03863520720707519, 0.06510285660624504, 0.01636775573050337, 0.02948383255196469, 0.07267241685518197, 0.005030288826674223, 0.02420537463123245, 0.05666303787646549, 0.03566582600719162, 0.16023516255830014, 0.018339137446933558, 0.07140941212752036, 0.08839756090726171, 2.81453720160893, 56.29015343529837, 52.53685467583792, 68.3945094517299, 36.62798472813198, 34.92187193461827, 46.39712068012783, 29.354266507284983, 12.908951333590917, 50.56582791464669, 53.61931800842285, 62.19594505855015, 33.305380480630056, 32.36543164934431, 63.50693811689104, 57.77287122181484, 58.61795629773821, 56.58243983132498, 53.80185760770525, 30.245758601597377, 7.195709492479052, 2.8564509068216597, 9.178235956600734, 21.6558153288705, 36.20979697363717, 51.67979090554373, 59.90738214765276, 57.66136653082711, 54.81140654427664, 56.66143390110561, 56.44534839902605, 55.47141940253121, 60.590577670506065, 61.766483851841514, 61.86561380113874, 60.869916098458425, 59.34726006644112, 57.270711013248985, 54.96465253829956, 47.69392204284668, 40.445113113948274, 36.246042251586914, 32.46393278666905, 36.865255287715364, 48.24894067219326, 54.47722945894514, 53.426283155168804, 53.92215176991054, 53.459922858646934, 47.653004101344514, 47.49011748177664, 46.360236167907715, 48.31387506212507, 44.02224377223423, 40.5042005947658, 39.879547119140625, 38.91089527947562, 36.945305483681814, 40.717472076416016, 39.12549039295742, 39.22588491439819, 38.11954409735543, 39.01742158617292, 40.13004010064261, 41.14610644749233, 41.17518465859549, 42.37358215876988, 48.151582513536724, 51.97445011138916, 53.78382008416312, 52.105833598545615, 48.775301456451416, 53.38053968974522, 54.48920120511736, 52.461293016161235, 50.35955326897757, 48.283435004098074, 43.60597024645124, 37.37692410605294, 39.95651578903198, 42.279791900089805, 44.324844769069124, 42.37931442260742, 45.74740852628435, 38.37242725917271, 34.75187383379255, 36.83189698628017, 41.5793787411281, 48.99599361419678, 50.51935141427176, 47.37968628747122, 47.61817625590733, 48.4339017186846, 47.62731661115374, 45.12912654876709, 43.32384211676461, 43.79471458707537, 45.316078254154746, 38.444233417510986, 32.79328087397984, 34.90162835802351, 30.093502725873673, 26.164030654089792, 17.233007260731288, 11.449656793049403, 8.80904950414385, 7.125455388001033, 6.259040645190647, 9.572304776736669, 18.701279742377146, 30.10911532810756, 31.59694004058838, 27.254051889692033, 24.35492992401123, 25.09113151686532, 29.679133006504603, 24.311114583696636, 19.146376132965088, 13.591055120740618, 7.5483318737574985, 1.0228220586265837, 2.3622127303055356, 16.444475310189382, 41.02764660971505, 49.37930835996355, 50.005042280469624, 47.75732782908848, 50.9615729876927, 47.43433039528983, 39.75580317633492, 53.31784609385899, 47.65205567223685, 40.47744655609131, 12.030147518430438, 13.963705250195094, 35.13054370880127, 24.320418221609934, 24.78606912067958, 31.502399376460485, 31.637701647622244, 35.48320647648403, 48.920570918491904, 8.371001192501613, 0.1792006098798343, 0.08481076373053448, 0.05582099288169827, 0.04229886543803981, 0.038607567083090544, 0.07367831787892751, 0.0768080335110426, 0.04266692318820527, 0.009748977409409625, 0.027401934444372143, 0.10270373895764351, 0.03643036873212882, 0.0119962692759665, 0.041726385442806144, 0.02315903970572565, 0.05842976325324603, 0.0816069927864841, 0.03511058758678181, 0.007974726231103497, 0.020392358968300477, 0.03202427105445947, 0.11903288774192333, 0.026917558828634874, 0.02265237082195069, 0.06866673287004232, 0.021384109144232104, 0.06702317856252193, 0.06525354566318647, 0.03252784921122449, 0.11720434443226882, 0.07972426845559052, 0.040133473596402576, 0.05300010567797082, 3.7194106578826904, 73.16988127572196, 57.454358850206646, 72.4325453894479, 36.83335958208357, 38.50015599387032, 29.870243208748953, 28.817127329962595, 23.2353093624115, 56.76522261755807, 56.28714139120919, 59.49945340837751, 37.154936109270366, 34.91360010419573, 68.19213621956962, 61.42481313432966, 63.126628467014854, 59.97029113769531, 57.68502514702933, 32.15321976797921, 7.884664637701852, 2.948771187237331, 10.077052320752825, 21.276785884584697, 37.170319420950754, 52.30251278196062, 62.11244855608259, 59.0608275277274, 58.74451773507254, 59.07451547895159, 59.37030724116734, 55.21653168542044, 61.47026130131313, 62.49884482792446, 62.506876945495605, 60.61350672585623, 60.057692527770996, 57.999861921582905, 56.49929768698556, 51.78793614251273, 47.63059268678938, 42.53516251700265, 37.16077607018607, 41.750113351004465, 49.88180555616106, 55.99282612119402, 53.030513763427734, 52.97440011160714, 54.63126754760742, 47.26385286876133, 47.280379159109934, 45.5949581010001, 47.388176986149375, 46.54979692186628, 43.55956322806222, 44.22496094022478, 41.27210508074079, 41.33345420019967, 46.436847005571636, 43.997317109789165, 44.02063179016113, 42.42701728003365, 42.24626684188843, 43.35138477597918, 44.17462818963187, 43.75644390923636, 47.088991028921946, 49.79586328778948, 53.181487696511404, 54.93623440606253, 52.555045059749055, 48.991293157849995, 53.818703515189036, 55.06427580969674, 54.62065070016043, 51.254561151777, 51.04301282337734, 44.71959624971662, 39.767253807612825, 41.91088424410139, 46.519923142024446, 48.62777035576956, 47.093809604644775, 49.39321517944336, 45.087961946214946, 40.174352237156455, 40.76798548017229, 44.136955056871685, 51.90318243844168, 52.45437608446394, 49.6510454586574, 48.72496175765991, 50.01101425715855, 47.360926151275635, 44.734319482530864, 44.50007138933454, 44.920340129307334, 45.336571965898784, 39.83038861410958, 34.964961188180105, 36.043992110661094, 31.769950185503276, 27.685913699013845, 18.00959699494498, 15.378123113087245, 11.617707661220006, 8.792815906660897, 8.757237655775887, 11.219195468085152, 19.49531987735203, 31.845987796783447, 33.05469989776611, 28.99708914756775, 26.320943559919083, 27.44443600518363, 32.272033963884624, 25.15879307474409, 20.54855040141514, 16.35921049118042, 7.604180625506809, 1.161571504814284, 2.709487169981003, 18.483050721032278, 46.54057318823678, 53.84213284083775, 52.74004432133266, 51.83868925912039, 52.88751288822719, 49.27049957002912, 45.10062156404768, 53.62709304264614, 51.42478854315621, 43.084806714739116, 16.908901589257376, 15.955153635569982, 19.681340524128505, 23.9760776587895, 27.909635271344865, 30.62697846548898, 34.2066764831543, 39.95474399839129, 58.04102652413504, 10.722763180732727, 0.19991160210754189, 0.019752873639975275, 0.03881184683580484, 0.012274061512601162, 0.05252884275146893, 0.04377418038036142, 0.025438269367441535, 0.035053332801908255, 0.03185458301699587, 0.015360801281141383, 0.03269114205613732, 0.008217403432354331, 0.008902752638927527, 0.040662544313818216, 0.2301183119416237, 0.14705723896622658, 0.22095922912870133, 0.3196498948548521, 0.1761888779167618, 0.19113377455089772, 0.15783645984317574, 0.20971371898693697, 0.12189562698560101, 0.12738903292587825, 0.19417372000004562, 0.18586524868650095, 0.11794145059372697, 0.36946701311639374, 0.1714133077434131, 0.13964029481368406, 0.11596422669078622, 0.21496148167976312, 0.22922150577817643, 7.413628884724208, 89.85846069880894, 66.22821399143764, 79.44288172040666, 49.633848667144775, 46.76215818950108, 59.780403818402974, 35.3584064074925, 17.036463567188807, 62.16443497794015, 61.09703881399972, 67.61647101811, 40.07365894317627, 40.30249438967024, 70.85417870112828, 65.40647833687919, 66.80631106240409, 67.55080359322685, 65.53684043884277, 37.90354892185756, 10.195685863494873, 3.877337566443852, 11.044268488883972, 24.054052080426896, 40.566633633204866, 56.905426842825754, 64.56897027151925, 63.6612992967878, 62.891112327575684, 64.21163136618478, 61.30554730551583, 55.78861856460571, 63.56565039498465, 64.18070493425641, 64.20296001434326, 61.31558050428118, 62.684896741594585, 60.78720474243164, 60.22602653503418, 54.40584714072091, 51.720097405569895, 40.88015372412545, 37.01299830845424, 42.58864974975586, 53.33188840321132, 58.847045353480745, 55.96281337738037, 55.37463794435774, 58.20184258052281, 49.83434588568551, 49.04171623502459, 48.63818917955671, 50.82536050251552, 50.66875158037458, 45.3130418913705, 46.14386578968593, 42.512712887355256, 42.63388252258301, 47.82599687576294, 45.635889938899446, 44.70277118682861, 45.74831526620047, 43.91345582689558, 47.74499477658953, 47.01661164419991, 44.19092171532767, 47.369757311684744, 52.216289111546104, 54.2671993119376, 55.56362199783325, 51.51005336216518, 49.7923127583095, 55.49440056937081, 56.89003658294678, 56.285748277391704, 54.82248544692993, 53.68680238723755, 46.93146841866629, 45.02180119923183, 46.28029714311872, 51.30202429635184, 51.96827663694109, 52.88952439171927, 52.29423747743879, 46.783499581473215, 41.41460568564278, 44.79172897338867, 46.77953563417707, 53.70123379571097, 54.13955742972237, 49.78123038155692, 49.14676257542202, 51.299491677965435, 51.651365825108115, 47.94140992845808, 43.84611736025129, 46.81152514048985, 46.97076742989676, 42.3827120917184, 37.06807320458548, 39.94747618266514, 37.81032146726336, 30.97800145830427, 21.795764207839966, 18.542694057737076, 15.054694890975952, 13.743096470832825, 10.647383911269051, 13.385375414575849, 23.11360124179295, 34.510580267224995, 36.38348456791469, 31.655561992100306, 27.886522088732036, 30.472731930868967, 37.47165584564209, 28.69500058037894, 23.19201339994158, 17.886704206466675, 9.024735484804426, 1.6559492966958453, 4.5695019108908514, 21.061676604407175, 52.94470003673008, 58.0048576763698, 59.41461590358189, 52.921788351876394, 55.69002015250069, 53.9918977873666, 48.63067470278059, 60.93169253213065, 57.953076226370676, 47.93930115018572, 16.92118600436619, 17.76783095087324, 45.685927391052246, 36.95003373282296, 34.202625683375764, 41.6246532031468, 45.922968660082134, 44.3812016078404, 71.63056346348354, 17.19332262447902, 0.2647417554897921, 0.17527539336255618, 0.1462360080331564, 0.18712231623274939, 0.12745368374245508, 0.20492042547890119, 0.1572140125291688, 0.10031499713659286, 0.14946237419332775, 0.0878980437825833, 0.2761439393673624, 0.10941437565322433, 0.16626900807023048, 0.1775547010557992], [0.041462438713226996, 0.053489566913672855, 0.03299080686909812, 0.04230167457301702, 0.07580025973064558, 0.03811949684417673, 0.06602776090481452, 0.014833116471501333, 0.02703342037940664, 0.024154777971229384, 0.01565162817548428, 0.01620103628374636, 0.055179668723472526, 0.05760606923805816, 0.03234252772693123, 0.01660153309681586, 0.09335428635988917, 0.008510382130875118, 0.19607737713626452, 0.10050593689084053, 42.24161849703108, 64.69485078539167, 34.89916869572231, 39.36047846930367, 40.24442829404558, 39.95287145887102, 47.857319355010986, 12.75000260557447, 28.54847870554243, 77.87578501020158, 64.07010350908551, 50.44248696735927, 29.094765186309814, 51.02825484957014, 53.183863980429514, 48.80076660428728, 53.727386815207346, 54.70056888035366, 42.212675775800435, 10.655738251549856, 2.3958867405142104, 9.395615560667855, 21.614820957183838, 42.42110783713204, 52.04567609514509, 56.680868012564524, 55.675349031175884, 54.79742329461234, 52.615904331207275, 56.807130677359446, 57.9192384992327, 57.94820553915841, 54.90865700585501, 55.51775346483503, 51.23746163504464, 52.93055697849819, 52.1041590826852, 46.524081638881135, 35.570326464516775, 25.64883736201695, 19.469847781317576, 22.480432748794556, 37.90051255907331, 52.93739400591169, 53.640680244990754, 53.91724634170532, 53.081655979156494, 52.06338357925415, 49.67559344427926, 49.16470282418387, 50.803623063223704, 52.74920899527413, 53.57756975718907, 48.432129928043906, 41.68406030109951, 38.553608485630576, 37.14039352961949, 39.30281884329659, 40.34353045054844, 38.50027411324637, 39.73588269097464, 38.63880729675293, 40.51837144579206, 39.57513264247349, 41.910734857831685, 44.48213808877127, 49.53242581231253, 52.36398696899414, 53.081117493765696, 53.31649466923305, 50.017604623522075, 51.82247216360909, 52.94735772269112, 53.647927216121126, 51.00480120522635, 49.11033664430891, 43.76760619027274, 38.754046644483296, 39.02225753239223, 42.17574610028948, 42.88224935531616, 42.60486684526716, 45.54445511954171, 37.51027740750994, 36.38283838544573, 35.689213616507395, 43.066626753125874, 48.59497485842024, 50.449997970036094, 47.012223856789724, 46.31272438594273, 45.492135184151785, 43.69970839364188, 40.42117656980242, 39.60485356194632, 39.88380289077759, 44.33206047330584, 43.02889803477696, 34.329822880881174, 32.05363818577358, 32.36817618778774, 22.758977345057897, 19.42153521946498, 11.328618305070059, 7.2924540383475165, 1.6603151538542338, 1.326023748942784, 2.5229725497109547, 6.117742947169712, 16.568446806498937, 19.23396338735308, 15.885946103504725, 21.12176809992109, 25.25833817890712, 27.586097615105764, 28.249282326017106, 21.922143254961284, 17.812004123415264, 9.615587711334229, 3.1926596888474057, 5.609147838183811, 25.40182195390974, 47.00327110290527, 48.6185188293457, 50.479260308401926, 47.49161829267229, 48.48844507762364, 53.97379425593785, 54.10271808079311, 47.466528347560335, 45.27879422051566, 33.24317325864519, 7.967836311885288, 22.53550069672721, 22.771668229784282, 20.14073978151594, 28.19110679626465, 35.596420424325125, 38.21356364658901, 41.85598305293492, 30.305454049791607, 0.8500381101455007, 0.04558032864172544, 0.02083263489683824, 0.04314780095592141, 0.03194910633776869, 0.032061858501817496, 0.062030158271746974, 0.05250518223536866, 0.017661170701363256, 0.03370873084557908, 0.01227251106008355, 0.01905442531486707, 0.023395488803674067, 0.016242408260170902, 0.023207880656367967, 0.010370386564838035, 0.035783623079104085, 0.07384175660886935, 0.04512554733082652, 0.054381772609693665, 0.011562797357328236, 0.07476305788648979, 0.008607442324448909, 0.035011765746665854, 0.08359064241605145, 0.04163699863212449, 0.06215983309916087, 0.0918015336085643, 0.07444813621363469, 0.0887796643323132, 0.04365997275869761, 0.10965242609381676, 0.06776666295315538, 0.07774840162268706, 0.27197806004967007, 50.19686119897025, 70.61393778664726, 43.85260350363595, 34.637287616729736, 39.002528122493196, 39.01311717714582, 29.304552146366664, 21.697205747876847, 36.70022862298148, 73.69881289345878, 65.30782781328473, 48.15095370156424, 32.439655780792236, 56.01171132496425, 56.97197321483067, 53.17986876623971, 58.352146012442454, 58.474052156720845, 45.740165029253276, 13.183723058019366, 2.1035019840512956, 9.612741555486407, 21.306204557418823, 39.80688633237566, 54.82052605492728, 59.99830627441406, 57.813615458352224, 57.55341584341866, 57.878984110695974, 59.75564043862479, 59.11669799259731, 59.16372340066092, 56.58488212312971, 58.2917731148856, 54.05732549939837, 55.05482973371233, 54.95645713806152, 51.44641828536987, 41.325741699763704, 31.571235179901123, 24.227717093058995, 26.813070569719585, 40.37571798052107, 53.768065043858115, 54.36348049981253, 54.43607875279018, 53.70830358777727, 52.681880950927734, 49.34281642096383, 48.314754009246826, 50.50833504540579, 51.70340435845511, 53.237347739083425, 47.53448172977993, 42.83142328262329, 41.42291920525687, 39.76595796857561, 44.776741709027974, 43.985303674425396, 43.56985003607613, 44.021354402814595, 42.99673482349941, 44.152022225516184, 44.60079247610909, 46.164269174848286, 48.37431396756853, 51.46693631580898, 53.846638747623985, 54.892922810145784, 54.419677530016216, 51.79868153163365, 53.7933669090271, 54.654860155923025, 56.08788095201765, 54.30557073865618, 50.372626304626465, 45.98895917619978, 41.06827967507498, 41.06018154961722, 45.30224091666085, 47.12839078903198, 47.363368443080354, 48.1289279120309, 40.72410760607038, 39.66999987193516, 40.39645835331508, 45.605224064418245, 54.55522993632725, 53.58479240962437, 49.05276039668492, 48.42736346381051, 49.28938477379935, 47.33936589104788, 43.01383434023176, 38.95283113207136, 40.459916251046316, 44.33712223597935, 44.15415184838431, 34.913294383457725, 33.89223575592041, 34.55546563012259, 23.66265310559954, 20.921455008643015, 14.300130077770778, 9.709548200879778, 3.844820431300572, 2.9758952174867903, 3.889247647353581, 7.484031506947108, 19.734242371150426, 20.873243195669993, 15.10404794556754, 20.858429636274064, 27.38778039387294, 27.8431236403329, 28.968733549118042, 24.67613819667271, 18.592363255364553, 10.211374027388436, 4.047907590866089, 6.03169949565615, 26.278226034981863, 50.22498403276716, 52.265051569257466, 53.251129490988596, 53.410343987601145, 50.87447731835501, 58.09796701158796, 56.6800411769322, 52.05990947995867, 50.20040825435093, 35.40915257590157, 12.171659742082868, 19.767524242401123, 14.731289250510079, 21.8853542804718, 28.822621617998394, 34.78979362760271, 42.17463786261422, 48.59658336639404, 36.80731078556606, 1.1808217061417443, 0.08613186462649278, 0.04701698405135955, 0.018329008615442684, 0.006348871509544551, 0.01495287281328014, 0.08496770209499768, 0.033272161414580684, 0.03522634566096323, 0.03768335149756499, 0.023253651236050894, 0.023803875282672898, 0.014129489227863294, 0.01916056515515915, 0.053334202750452926, 0.12838164823395865, 0.26850306508796556, 0.2354020912732397, 0.22182163356670312, 0.24624974919216974, 0.1433410926588944, 0.1925541926175356, 0.06728137470781803, 0.16851626176919254, 0.09982960711100272, 0.10222845231848103, 0.2627518022699015, 0.17131254529314383, 0.1727649766419615, 0.15896908406700405, 0.16187097478125775, 0.17684044795376913, 0.07601085664438349, 0.19751106734786714, 0.7680592462420464, 66.87718963623047, 82.65601362500871, 53.948343004499165, 54.45256682804653, 54.43108647210257, 55.6464375768389, 58.754933084760395, 15.193245444978986, 36.94571195329939, 85.18333748408726, 72.74663175855363, 57.05723455974034, 37.03494419370379, 60.64317553383963, 61.74206788199288, 56.170137201036724, 64.2910075868879, 63.750611441476, 52.25758572987148, 15.480110509055, 3.252613523176738, 10.056920783860342, 24.474110637392315, 45.11508076531546, 58.209061758858816, 61.36931092398507, 62.30153683253697, 60.80979333605085, 61.74761949266706, 61.478196144104004, 60.29892703465053, 58.71236147199358, 57.0132976259504, 58.08418525968279, 56.15984691892351, 57.40873350415911, 55.57824795586722, 53.25807768957955, 42.581906523023335, 33.74173777444022, 25.669760125023977, 31.46106801714216, 43.93168789999825, 56.59972347532, 57.435647351401194, 57.550177982875276, 54.33129644393921, 54.76877587182181, 52.0202248437064, 52.02937562125069, 52.77095685686384, 55.850902216775076, 57.06839336667742, 50.409257207598, 45.567742007119314, 42.837009634290425, 41.20497506005423, 46.81287656511579, 47.26490552084786, 45.12044824872698, 46.779441833496094, 44.987091473170686, 48.0230165209089, 43.80210052217756, 48.09348515101841, 48.42315285546439, 52.94504049846104, 52.557153838021414, 54.70877470288958, 53.65271799904959, 51.26937818527222, 54.22828939982823, 55.57675061907087, 56.67317983082363, 53.695921897888184, 52.61245455060686, 48.27297101702009, 44.455054010663716, 43.590819699423655, 48.89333745411464, 49.952037947518484, 51.055391039167134, 52.02511984961373, 44.15571519306728, 42.65536635262625, 42.797870431627544, 48.68589203698294, 56.823226179395405, 53.73432459150042, 51.92528118406023, 48.81454140799386, 49.513425963265554, 49.14619977133614, 45.85376460211617, 41.09967858450753, 44.14002963474819, 46.29121623720442, 46.13409662246704, 38.495229721069336, 38.76327732631138, 38.92668158667428, 28.716176952634537, 24.99261474609375, 17.770269768578665, 12.101000905036926, 7.648814116205488, 6.11026451417378, 7.011194433484759, 8.855589406830923, 24.229238748550415, 23.815021889550344, 16.462351288114274, 25.151464462280273, 29.360672746385845, 30.988055501665386, 32.11632135936192, 28.732015371322632, 19.89804094178336, 12.4896787915911, 4.397715083190373, 7.991223948342459, 29.53128228868757, 55.28471435819353, 56.77521760123116, 58.25313070842198, 55.40490777151925, 54.39484119415283, 63.380070958818706, 62.09298665182931, 56.59631190981184, 54.57762050628662, 41.62085601261684, 10.668828657695226, 32.074138845716206, 31.55366665976388, 27.55288348879133, 37.36064795085362, 48.94197831835066, 50.32075800214495, 57.87732001713344, 50.71669067655291, 2.2505779777254378, 0.09803526875163827, 0.07164779505027191, 0.1455776933580637, 0.07921764706926686, 0.1104458642325231, 0.1150704196521214, 0.2126600266035114, 0.06989048434687511, 0.11632741934486798, 0.13501112535595894, 0.11731676411415849, 0.08487455959298781, 0.1061988864094019, 0.22447478691382067], [0.01783454148764057, 0.1084386422964079, 0.03035799939451473, 0.054941798094660044, 0.045014002959110906, 0.026637881960985915, 0.08557894679584674, 0.08873359858989716, 0.07905217951961926, 0.022898222718920027, 0.04379734217322298, 0.0651480131117361, 0.039014477748423815, 0.03086862413744841, 0.01639755698852241, 0.016550403786823153, 0.044987319569502554, 0.021448904149500386, 0.039820903047387085, 0.08549141577844109, 8.619958622114998, 62.16288552965437, 44.303287982940674, 39.85655900410244, 40.72218990325928, 32.154856068747385, 49.08462136132376, 25.634808949061803, 12.640287944248744, 52.06392206464495, 63.76709256853376, 67.01974582672119, 49.37316962650844, 47.927437101091655, 65.27153042384556, 49.10238790512085, 54.89202996662685, 55.7487359046936, 46.08026545388358, 18.192463159561157, 3.860998008932386, 7.609036547797067, 21.717765467507498, 38.95114271981375, 51.42919717516218, 54.45838247026716, 58.62379278455462, 57.446948596409385, 54.86798919950213, 47.22762843540737, 41.56224448340279, 39.034941468920024, 41.84373337881905, 39.41725219999041, 38.54434306280953, 41.720837116241455, 40.517308371407644, 35.78787456239973, 32.036722796303884, 18.650453669684275, 12.303031938416616, 27.515811375209264, 50.29556383405413, 54.32967751366751, 55.04768351146153, 53.05945995875767, 52.90721797943115, 51.64666189466204, 49.42448207310268, 53.29919365474156, 56.239966596875874, 56.593435355595176, 54.040653296879356, 52.087990624564036, 43.34543364388602, 39.88099234444754, 37.09637669154576, 37.53421742575509, 40.290279456547324, 39.99689871924264, 40.07223456246512, 39.70904527391706, 39.44004576546805, 40.16954755783081, 41.47195611681257, 43.88871676581246, 49.433000564575195, 52.44267531803676, 53.31297888074602, 55.003218514578684, 48.825457027980256, 52.0432824407305, 54.203668458121165, 51.5844338280814, 51.77148975644793, 47.014360427856445, 42.82018109730312, 37.89474555424282, 39.09120798110962, 43.08672441755022, 43.45542362758091, 41.30178083692278, 44.12367704936436, 35.82680531910488, 34.89897067206246, 36.14495638438633, 43.37933043071202, 50.570663860866, 47.55480521065848, 43.615920066833496, 38.45725434167044, 41.43044410433088, 38.5874879019601, 38.67880112784249, 35.97730677468436, 36.567320006234304, 39.13726758956909, 43.9371908732823, 39.77628299168178, 31.275297505514963, 29.913158757346018, 27.141480650220597, 15.287165982382637, 16.09548466546195, 10.59317580291203, 4.933502835886819, 1.6851454100438525, 5.597457494054522, 2.4114446256841933, 13.321360792432513, 5.856371692248753, 4.8857826079641065, 8.56756225654057, 26.63123447554452, 30.890964848654612, 31.016612597874232, 24.781868934631348, 19.17849244390215, 10.734333668436323, 2.633996946471078, 6.39979464667184, 25.22227876526969, 47.49258756637573, 51.104716300964355, 51.63840396063668, 47.51748296192714, 53.17172547749111, 51.08192620958601, 50.244400773729595, 43.074516432625906, 47.8493914604187, 14.857619660241262, 9.140808616365705, 16.70162466594151, 19.587948049817765, 24.63331992285592, 34.79973649978638, 38.371899196079795, 43.11035524095808, 35.013744490487234, 8.614076972007751, 0.15468792164964335, 0.1552654363747154, 0.01655252251241888, 0.13738275452383927, 0.08294612914323807, 0.07246805567826543, 0.042099396498607736, 0.05011545314586588, 0.03545087968398418, 0.05080100760928222, 0.05610342290518539, 0.04921591927164367, 0.02295677180934165, 0.01967345450871757, 0.083036727138928, 0.06392702327242919, 0.06481898469584328, 0.06854828779718705, 0.01453784347644874, 0.05183885745438082, 0.04996359022334218, 0.10976749884762935, 0.0071096763546977726, 0.05412403108286006, 0.009705589335810925, 0.042671903635242155, 0.06418691575527191, 0.10012215748429298, 0.06027326826006174, 0.059675322845578194, 0.0904329013345497, 0.049272970496011634, 0.086706875557346, 0.05213997772495661, 0.14566952628748758, 11.178879414285932, 72.13999148777553, 52.3490309715271, 41.47081313814436, 34.85027074813843, 40.35820157187325, 32.27592495509556, 28.8891784123012, 23.045493262154714, 55.26417548315865, 66.94922161102295, 68.49894087655204, 50.061416489737375, 49.79039852959769, 65.55077852521623, 51.996225765773225, 60.794771330697195, 59.65390491485596, 50.21728890282767, 21.09521382195609, 5.235566650118146, 8.398500425474984, 23.117433173315867, 39.27411583491734, 54.623516832079204, 57.01248468671526, 61.419087818690706, 60.44906370980399, 57.33348103931972, 49.051756381988525, 44.623127460479736, 42.078301089150564, 44.57036631447928, 43.0878951890128, 42.39381531306675, 44.65316104888916, 43.7818534714835, 38.422527245112825, 34.4055096081325, 22.84647079876491, 15.738069329942975, 30.224177496773855, 49.96992608479091, 54.60552794592721, 54.4009347643171, 55.0352531841823, 54.24873447418213, 52.67832694734846, 50.52859251839774, 50.02010250091553, 56.11494418552944, 57.62792485100882, 55.37063578196934, 54.37451771327427, 47.29899685723441, 43.09666381563459, 41.955324922289165, 41.231392111097065, 45.29552895682198, 44.0904403414045, 44.468849658966064, 46.31210252216884, 46.73567165647234, 45.9442093031747, 45.92694302967617, 46.90476301738194, 50.66466951370239, 54.351289885384695, 54.268377031598774, 54.53324931008475, 50.263223443712505, 52.221910204206196, 54.6524977684021, 55.26056589399065, 53.935547896793906, 48.344919613429475, 44.51745925630842, 40.19942133767264, 40.19384888240269, 44.24780314309256, 46.71349648066929, 44.8467378616333, 47.47881276266915, 40.187480858394075, 37.575486251286094, 41.20319284711565, 46.51820693697248, 53.52584389277867, 53.44878142220633, 50.202280793871196, 42.13126025881086, 44.3930343900408, 41.87486825670515, 41.85689326695034, 38.00316524505615, 37.189562456948416, 40.62649236406599, 45.250588008335654, 41.08253043038504, 34.13878910882132, 32.31291716439383, 28.705648694719585, 18.606888464518956, 18.502568210874283, 14.738157544817243, 10.418776886803762, 4.9848904098783215, 4.516683007989611, 5.205924766404288, 16.004555327551707, 8.206472192491804, 5.551561602524348, 10.01866226536887, 27.603610549654277, 32.64561080932617, 33.16255678449358, 27.086565562656947, 21.70759677886963, 11.423975382532392, 3.7354279926845004, 7.357616850308009, 27.084283079419816, 51.10935422352382, 55.2603748185294, 55.910806110927034, 49.693589278629844, 55.544424125126426, 56.04690742492676, 55.28063576562064, 48.967700549534385, 50.480507510049, 20.993485246385845, 10.97810079370226, 14.875335829598562, 17.912138087408884, 25.33350726536342, 33.40621273858206, 37.94697516305106, 48.65413876942226, 45.77398885999407, 11.030590091432844, 0.19873959571123123, 0.14183387639267103, 0.054683632483439784, 0.11069025897553988, 0.09321579057723284, 0.08816926780023746, 0.06415240546422345, 0.09612446664167301, 0.0321891720273665, 0.06728200574538537, 0.037346268871000836, 0.06167898925819567, 0.07039329915174417, 0.06223536083208663, 0.07851280524794545, 0.1285320251647915, 0.16501268691250257, 0.24007033077733858, 0.08930899628571101, 0.15813596520040715, 0.12917341717651912, 0.20858163759112358, 0.2045702606971775, 0.16967308255178587, 0.05771382059901953, 0.1371220342282738, 0.20283931786460535, 0.11334932914802007, 0.12787835166922637, 0.19825680447476252, 0.11007781326770782, 0.14487759449652263, 0.15357948041387967, 0.18556373486561434, 0.2693459412881306, 21.225132976259502, 89.72880731310163, 59.39812782832554, 58.23788636071341, 53.196443693978445, 48.11439228057861, 67.00459875379289, 30.693066256386892, 16.531341688973562, 61.708250999450684, 72.4779588154384, 77.22393975939069, 57.780250208718435, 55.9931492124285, 73.2108131136213, 57.73798084259033, 65.92304216112409, 66.76216915675572, 54.33550010408674, 23.316212449754985, 6.878796509334019, 8.957308428628103, 24.699564048222133, 43.299151693071636, 57.480581351688926, 60.53180285862514, 66.1904296875, 63.901741709027974, 61.39927155630929, 53.044799259730745, 46.80370841707502, 42.11899321419852, 45.9907865524292, 44.163643087659565, 41.94156401497977, 47.105520793369834, 46.71349648066929, 40.25458656038557, 36.703605447496685, 27.705622264317103, 22.29953466142927, 35.20073788506644, 54.21041515895298, 56.69003963470459, 56.827360357557026, 56.5315512248448, 56.65463508878435, 54.301398345402305, 51.78261729649135, 51.89403166089739, 57.64381538118635, 58.82565879821777, 57.373228209359304, 55.77636194229126, 47.77279451915196, 45.16213744027274, 43.74908229282924, 43.25148357663836, 46.20482233592442, 46.336594922201975, 45.761617592402864, 48.20428112574986, 46.733694893973215, 46.77965027945382, 46.62354162761143, 45.80664886747088, 50.30269963400704, 53.84084742409842, 53.51161745616368, 54.802561487470356, 47.761670453207834, 53.44177763802664, 54.97861841746739, 55.23300586427961, 53.2060877936227, 48.29680333818708, 44.614174706595286, 43.878002643585205, 43.582655566079275, 48.19534574236189, 50.39757381166731, 48.497060843876426, 49.87759147371565, 42.30629927771432, 40.43527793884277, 45.26366451808384, 49.35138007572719, 57.35560062953404, 55.75366217749459, 51.147659642355784, 43.07537106105259, 47.03426354272025, 45.80830601283482, 45.31301062447684, 39.748493671417236, 39.47288990020752, 41.67617756979806, 45.054329190935405, 43.533667291913716, 34.86253431865147, 37.125010217939106, 32.547863551548545, 23.36419149807521, 22.205892051969254, 18.76066425868443, 14.959799868719918, 7.811002441814967, 8.048738530703954, 8.7860700743539, 19.116425922938756, 11.826485395431519, 5.587118574551173, 12.646721107619149, 28.416407346725464, 35.56863457815987, 35.631706850869314, 31.161819526127406, 22.552287544522965, 12.608743991170611, 4.580616423061915, 9.727518848010472, 29.23080744062151, 56.9146158354623, 57.484989983694895, 60.01347419193813, 53.698134899139404, 61.169404302324565, 59.61661393301827, 59.9838262285505, 52.3354993547712, 56.52958141054426, 20.22097931589399, 14.067567791257586, 25.955447469438823, 26.532564844403947, 34.9527462550572, 45.68708079201834, 54.36576645714896, 54.08444084439959, 61.61802864074707, 16.893068381718226, 0.3237677067518234, 0.15749142478619302, 0.19389523565769196, 0.1527765563556126, 0.2765785003347056, 0.19453528417008265, 0.17848658747971058, 0.1037859208881855, 0.10807177876787526, 0.30468724774462835, 0.15619683425341332, 0.18103359080851078, 0.1884327166314636, 0.12577273537005695, 0.2390546995614256], [0.04087086474256856, 0.0164738718220698, 0.09645579529127904, 0.046578813277717145, 0.055699362086930444, 0.03741664991581014, 0.04953813858862434, 0.06733827665448189, 0.11559530720114708, 0.01886718866548368, 0.12337450762944561, 0.05439262577731695, 0.023649096355906556, 0.04910481255501509, 0.03366441233083606, 0.02232397174728768, 0.04456040229914444, 0.04076962053243603, 0.04058846864583237, 0.010832495205769581, 0.574383584516389, 32.72434779575893, 60.2271590914045, 33.652133805411204, 37.992972237723215, 28.939172438212804, 38.30621787479946, 39.883722986493794, 13.07881133896964, 29.277558394840785, 59.584033829825266, 56.05095475060599, 74.76581995827812, 62.58595439365932, 65.86243302481515, 62.305789130074636, 55.8099946975708, 55.907738481249126, 51.3355632509504, 24.194768735340663, 4.8755331465176175, 7.054875152451651, 21.752322333199636, 41.30198928288051, 51.10319117137364, 55.4496819632394, 55.781288215092246, 61.22125176021031, 53.311255727495464, 37.0806668145316, 29.513130119868688, 23.11050581932068, 21.129758528300695, 28.017137799944194, 31.737731388637, 34.615195819309776, 37.866212776729036, 37.047968591962544, 35.754676069532124, 30.164693968636648, 23.646543707166398, 39.54879549571446, 51.489962645939414, 48.44949000222342, 52.489891801561626, 52.66521222250802, 54.76883840560913, 52.341530391148154, 50.98591947555542, 53.12427275521414, 55.765706879752024, 54.804513931274414, 54.95989997046334, 53.432262080056326, 46.16113901138306, 41.07962955747332, 38.86288322721209, 37.83311850684029, 40.67303139822823, 39.5231670652117, 38.884026595524375, 40.94119017464774, 39.69424908501761, 41.332339014325825, 41.8664505141122, 45.92336470740182, 49.54079144341605, 52.955945696149556, 51.6984155518668, 53.81199502944946, 51.57014833177839, 52.542593887874055, 55.04288230623518, 52.65530756541661, 50.88143593924386, 45.557802609034944, 44.16582134791783, 38.67191546303885, 38.78396558761597, 41.745475428445, 41.134141649518696, 41.32768719536917, 41.96552835191999, 35.2516508102417, 36.64056444168091, 38.212563105991904, 49.370967047555105, 49.54036065510341, 44.73577165603638, 36.382303374154226, 28.25588137762887, 32.744844981602256, 38.98919800349644, 37.547036852155415, 34.90941034044538, 35.17793389729091, 35.16445786612374, 40.24098546164376, 39.19741119657244, 31.025217941829137, 24.53697793824332, 29.04396343231201, 15.70111880983625, 12.492723839623586, 11.477405292647225, 11.35298650605338, 5.83274998835155, 4.879594802856445, 3.5654550790786743, 7.7159736667360574, 1.0451819045203072, 2.9865272641181946, 9.546185629708425, 22.53337628500802, 30.51670707975115, 34.44950907570975, 29.45352152415684, 23.966702801840647, 13.488877517836434, 5.133571437426975, 9.130502700805664, 32.52336767741612, 46.33078275408064, 51.23482826777867, 53.41020849772862, 51.92174455097744, 54.66161380495344, 55.213019371032715, 50.36474357332502, 49.492237431662424, 37.42802810668945, 7.606465714318412, 14.313590475491115, 18.800032751900808, 22.587808472769602, 31.341937678200857, 49.30700887952532, 32.77038655962263, 43.104390212467735, 22.37121227809361, 1.7253901362419128, 0.03034745156764984, 0.0951873826395188, 0.06932020959045206, 0.055904585003320656, 0.058831707042242797, 0.08558901625552348, 0.05459075461008719, 0.055263773139033995, 0.018272674941856946, 0.06129691975989512, 0.029365231416055133, 0.018243345265675868, 0.0569656068193061, 0.035868290678731034, 0.018659215985930393, 0.04779056825542024, 0.0034526645862830003, 0.13561044819653034, 0.01956927733096693, 0.10212307583008494, 0.017095854339588965, 0.044078954562012634, 0.05414274168599929, 0.06567371490278415, 0.015000463563150592, 0.1416355948895216, 0.0689571729994246, 0.01326470058743975, 0.04159218478681786, 0.013054733014931636, 0.029367501115692512, 0.10092743605907474, 0.04303224304957049, 0.08090544864535332, 0.02561514139441507, 0.7360878161021641, 43.735380445207866, 68.61728954315186, 40.301024845668245, 38.37926776068551, 35.985126972198486, 35.101340430123464, 26.610386405672344, 22.046102591923304, 40.022846766880576, 63.26831613268171, 61.26178060259138, 77.58434976850236, 65.20234026227678, 68.13915620531354, 62.464805603027344, 62.52747140611921, 58.52637904030936, 57.369590827396934, 24.810092517307826, 5.631798531327929, 7.226339323180063, 23.48874143191746, 43.058737073625835, 52.89640310832432, 58.90331881386893, 59.37539332253592, 62.20203168051583, 56.55977133342198, 39.09987933295113, 32.74216992514474, 27.38310078212193, 25.011501686913626, 30.519931043897355, 33.127391951424734, 37.05670942578997, 38.10179144995553, 39.080889906202046, 35.02186346054077, 31.695218835558208, 27.83175638743809, 39.07368809836251, 52.268060139247346, 49.96519783564976, 53.84464808872768, 53.559532233646934, 53.827611105782644, 53.71835763113839, 53.826454230717246, 54.29631226403372, 57.49555819375174, 55.69624573843819, 56.94267266137259, 54.99397741045271, 49.745488848005024, 42.81388602937971, 41.179579394204275, 43.176432609558105, 45.96902826854161, 45.001418658665244, 44.92518997192383, 46.47235924857003, 44.878821168627056, 45.308542932782856, 46.58445453643799, 47.91574328286307, 51.99794544492449, 55.21491622924805, 52.80992235456194, 52.95377785818917, 53.29487187521798, 52.21179710115705, 56.201129640851704, 53.83366993495396, 53.11326680864607, 47.818583147866384, 46.4105897630964, 39.53006315231323, 40.523586068834575, 43.60598414284842, 44.82986068725586, 46.672314507620676, 45.39323105130877, 37.37233829498291, 38.19487646647862, 40.81904779161726, 52.980014256068635, 54.5446652003697, 49.90574210030692, 41.45429032189505, 32.11458083561489, 37.153160844530376, 40.68674366814749, 41.957100187029155, 36.61748252596174, 36.11029182161604, 36.10581718172346, 42.95418405532837, 39.99345588684082, 36.04677486419678, 26.356653826577322, 29.78984907695225, 18.70078468322754, 15.778129168919154, 14.937873091016497, 15.88480486188616, 10.09579769202641, 9.105294636317662, 3.1077594331332614, 9.764483264514379, 2.632438595805849, 3.4979218457426344, 10.748756391661507, 23.009287936346873, 31.31062909534999, 34.65048571995327, 31.71726199558803, 23.91359772000994, 14.571192332676478, 6.197574274880545, 11.654729400362287, 35.03953620365688, 49.71993337358747, 54.50658907209124, 56.53829097747803, 55.702790941510884, 59.55577550615583, 59.006714957101, 56.74374573571341, 53.28234427315848, 41.69953046526228, 12.78444048336574, 18.841338055474417, 17.809268270220073, 21.97327331134251, 28.607262202671595, 48.245758397238596, 38.68382120132446, 51.39265659877232, 33.19241666793823, 3.133948496409825, 0.17904826519744738, 0.056286311841436794, 0.05214577241401587, 0.03828323073685169, 0.02487960604152509, 0.04314495450151818, 0.018155084823125174, 0.06747676565178803, 0.023794133216142654, 0.00786776451527008, 0.040269122924655676, 0.04938550552885447, 0.017908924192722355, 0.07696731282132012, 0.014879733523620027, 0.1953365933150053, 0.24015992454120091, 0.23362888927970613, 0.2556521546627794, 0.22265685589185782, 0.1562745536544493, 0.12579633481800556, 0.07864643593451806, 0.18273037618824414, 0.10141085833311081, 0.20216705250952924, 0.15205029318375246, 0.08370309602469206, 0.07934326425726924, 0.09777197002300195, 0.1595539269702775, 0.202852440731866, 0.12145084728087698, 0.252066042806421, 0.1310612644468035, 0.9723352534430367, 62.918905121939524, 80.81429631369454, 50.92119353158133, 55.252808230263845, 41.349497590746196, 54.283013411930625, 48.46152775628226, 16.140595844813756, 37.725716727120535, 68.6413094656808, 66.22542081560407, 83.60132993970598, 72.72480051858085, 74.28818689073834, 67.40427303314209, 65.5565733228411, 63.175613267081125, 60.44076756068638, 28.323683636529104, 8.418309739657811, 9.124306644712176, 24.703533206667217, 44.58021886008126, 55.68077904837472, 62.810436793736045, 62.31362669808524, 66.825133732387, 61.20853655678885, 43.69115516117641, 35.746557099478586, 30.388877596173966, 27.53731952394758, 35.1820124898638, 36.48652982711792, 41.55369472503662, 42.87334523882185, 41.72540555681501, 39.97432402202061, 36.14662742614746, 32.97793272563389, 44.608616147722515, 56.74978024618966, 53.06635257175991, 57.34947231837681, 55.52336066109793, 55.37013898577009, 55.64415509360177, 54.68467835017613, 55.42934111186436, 57.806774956839426, 56.89609541211809, 57.68348264694214, 55.678736277988975, 51.003776345934185, 45.48819555555071, 43.770340306418284, 43.63818209511893, 48.70273099626814, 46.48574495315552, 46.05669716426304, 48.63549675260271, 46.5157333782741, 46.69576815196446, 47.99367080415998, 47.977679525102886, 51.72011130196707, 55.233599935259136, 51.91892358234951, 52.5161247253418, 48.71168375015259, 53.86462415967669, 57.41095345360892, 54.85907118661063, 52.514603069850374, 48.412904262542725, 47.501001834869385, 41.285035678318565, 42.13043689727783, 46.744645254952566, 48.16446099962507, 48.57130581992013, 47.78235871451241, 40.565337794167654, 42.76852124077933, 42.97212082999093, 57.02455023356846, 58.44488361903599, 52.33631924220494, 42.637043952941895, 32.6522776058742, 38.982239382607595, 40.071425097329275, 44.80203662599836, 40.679173605782644, 40.56323248999459, 40.08145134789603, 46.4069766998291, 40.81230803898403, 37.680629866463796, 30.06467812401908, 33.42245067868914, 22.17127960068839, 22.600680010659353, 20.152398858751567, 21.48991666521345, 14.242533854075841, 10.600707650184631, 5.984549454280308, 13.869526760918752, 5.497746501650129, 4.18979458298002, 13.128238218171255, 25.588549579892838, 34.034680775233674, 37.90306602205549, 37.25655351366316, 26.82192083767482, 16.963801043374197, 8.31046153817858, 13.754457644053868, 38.95415823800223, 53.637484073638916, 57.7604478427342, 61.415530341012136, 59.1994024004255, 60.23763697487967, 63.22715500422886, 58.26604740960257, 58.41713946206229, 43.984667914254324, 13.469552840505328, 22.78836648804801, 24.65737979752677, 32.18988193784441, 41.97158718109131, 61.83990546635219, 49.543278898511616, 58.61554527282715, 48.12341104234968, 4.343024943556104, 0.3599047176539898, 0.16926691148962292, 0.21857644484511443, 0.16592371516994067, 0.17079725222928183, 0.11244115073766027, 0.0989565835999591, 0.12381236627697945, 0.10888857886727367, 0.11344060567872864, 0.17145876958966255, 0.14688255691102572, 0.13043304958513804, 0.10504648967513017, 0.14137449461434567], [0.09542239324322768, 0.03501281747594476, 0.06286078691482544, 0.02771318015376372, 0.07108241253133331, 0.06951330708605902, 0.09297908363597733, 0.07530085117157016, 0.04454013106546231, 0.09452752768993378, 0.1442895217665604, 0.025268912115799527, 0.0563450967227774, 0.1263997560100896, 0.03951665133770023, 0.010349156900442072, 0.048517954402736256, 0.06461059980626617, 0.03446213202551007, 0.07085527971919094, 0.04985401360318065, 9.226949776921954, 54.15565640585763, 39.0112898009164, 35.979884556361604, 33.90613910130092, 30.331655706678117, 48.460332666124614, 24.106071506227764, 9.213275722094945, 46.615398338862825, 57.33237974984305, 57.33258472170149, 67.74257387433732, 62.19991247994559, 62.246284757341655, 57.426180430821006, 55.99537263597761, 52.721464838300435, 32.831284046173096, 8.615232110023499, 4.879420229366847, 23.259666272572108, 37.171778542654856, 51.815030642918174, 59.00043378557478, 57.01788343702044, 59.11928967067173, 49.93629332951137, 30.231914315904888, 18.093750102179392, 13.738698261124746, 16.179966075079783, 22.404197113854543, 29.309124061039515, 35.352080072675435, 38.21798617499215, 37.02090883255005, 38.07588161740984, 31.66392067500523, 35.551667077200754, 46.35003621237618, 46.15963472638811, 45.712723118918284, 49.2099529675075, 52.55822038650513, 54.895281723567415, 53.671742166791645, 55.85285466057913, 53.2941701071603, 51.02589593614851, 55.40340001242501, 57.9838741166251, 54.271017347063335, 46.98266969408308, 41.73828404290335, 39.405638286045615, 38.34735468455723, 38.224885736192974, 41.185419355119976, 38.33199221747262, 40.92032820837838, 38.67548336301531, 41.372881753104075, 42.37808806555611, 43.88795593806675, 49.331751414707725, 54.316972732543945, 54.03590420314244, 52.765679700034006, 53.655997548784526, 50.05840444564819, 55.003579820905415, 50.53127799715315, 50.145135334559846, 46.78612947463989, 44.05087382452828, 39.8369094984872, 39.85711485998971, 43.18417290278843, 42.25672040666853, 42.15837907791138, 38.38836990083967, 35.67968416213989, 38.02421133858817, 42.80056285858154, 47.000099250248496, 44.86026947838919, 38.682334286826, 27.85899680001395, 14.802146979740687, 25.12120679446629, 31.13754252025059, 34.580597264426096, 33.14882714407784, 29.029434749058314, 30.186709335872106, 29.327957153320312, 31.7030668258667, 27.950030360903057, 16.826226711273193, 19.69281373705183, 22.26958966255188, 11.10146519115993, 8.504267641476222, 9.432411483355931, 5.031130237238748, 4.13291836636407, 3.1397639214992523, 5.21435466834477, 1.0641466868775231, 3.361955153090613, 12.63292806489127, 25.4704840523856, 30.746942588261195, 35.480218751089915, 34.87047610964094, 28.18414991242545, 11.048856037003652, 6.717246115207672, 15.505989074707031, 36.761918204171316, 42.537424155644004, 47.880213669368196, 47.51392895834786, 48.93344245638166, 50.551160267421174, 52.4371132850647, 44.651295457567485, 53.99877650397164, 23.99664432661874, 9.27439033985138, 13.707807438714163, 24.865949085780553, 25.483473709651403, 50.187984875270296, 35.82300118037632, 33.873492990221294, 42.25195394243513, 15.253944907869611, 0.2549205039228712, 0.06853234222424881, 0.07501706068537065, 0.06143942568451166, 0.020177466927894523, 0.08767033421567508, 0.06281851418316364, 0.029992055280932357, 0.07108214111732584, 0.05653655555631433, 0.04852099084694471, 0.07205172694687333, 0.03197382536849805, 0.13961531115429743, 0.07904466135161263, 0.11172442098281213, 0.1242517177015543, 0.03990096678691251, 0.04138949619872229, 0.053596239403954575, 0.14066443485873087, 0.04763074950980289, 0.05292701388576201, 0.06030947488865682, 0.08272430247494153, 0.09634036291390657, 0.04274657641404441, 0.03783687683088439, 0.05575015043307628, 0.044812145576413186, 0.01185246480495802, 0.05113762204668351, 0.03559275117835828, 0.04925532519285168, 0.09703157975205354, 0.013511082589892405, 0.03527172947568553, 12.803702626909528, 68.0160688672747, 47.703917026519775, 41.03084625516619, 31.369702679770334, 33.50409548623221, 33.611393042973106, 26.183226789746964, 20.794014624186925, 52.75683464322771, 59.9277195249285, 63.68327644893101, 70.771238054548, 68.45082460130963, 64.3359763281686, 61.25521455492292, 59.96139744349888, 57.03531299318586, 35.98000267573765, 10.031583309173584, 4.971991947719029, 22.79070803097316, 42.438724994659424, 53.9086583682469, 60.773864201136995, 60.61463928222656, 61.37639113834926, 52.5927494594029, 33.03867040361677, 22.554656880242483, 15.600423778806414, 20.200761795043945, 27.53906873294285, 31.538707188197545, 37.926015922001426, 40.58562305995396, 40.3071323122297, 37.318086760384695, 32.65061003821236, 34.37202623912266, 46.41922984804426, 48.526465620313374, 46.86208023343767, 50.178424154009136, 52.655752250126426, 54.96382222856794, 56.23366110665457, 57.5473952293396, 56.86178173337664, 54.77167327063424, 56.6830393246242, 57.855763231004985, 58.32172679901123, 51.31328385216849, 45.16858884266445, 42.25523349217006, 42.15450893129621, 43.04518461227417, 45.836720670972554, 44.872665064675466, 45.08666263307844, 43.54652145930699, 44.648707253592356, 45.95247418539864, 48.75636066709246, 53.361585003989084, 55.55043084280831, 55.8543415750776, 54.32721437726702, 56.408554213387625, 50.98241410936628, 57.68905510221209, 51.80948250634329, 51.513134888240266, 49.15626423699515, 46.169299670628135, 41.7825927053179, 41.60849516732352, 43.50613505499703, 44.71619858060564, 44.22642353602818, 42.13242060797555, 38.269847529275076, 41.26271459034511, 45.78591544287545, 51.74521861757551, 50.174015522003174, 48.36345740727016, 35.99305139269148, 18.574947595596313, 27.523287636893137, 34.21056400026594, 39.15199082238333, 35.11612272262573, 31.293873514447892, 31.720899377550396, 33.46055112566267, 37.02818359647478, 31.02564525604248, 22.15168046951294, 21.753114427839005, 22.291014432907104, 11.157041226114545, 7.829476833343506, 8.919605766023908, 7.155128538608551, 7.581915123122079, 6.5197292396000455, 5.096716020788465, 1.541292946253504, 3.3750462106295993, 12.169522302491323, 26.12116895403181, 31.991083553859166, 36.50642251968384, 36.26830775397164, 29.676166125706263, 12.076995747429983, 8.589402181761605, 19.515532187053136, 40.70176567350115, 47.36624499729702, 53.394477776118684, 53.047766140529085, 53.16538177217756, 55.65268400737217, 58.09901966367449, 50.900977747780935, 58.839242526463096, 28.541278634752544, 15.720368794032506, 21.43078923225403, 19.632798671722412, 21.560350554330007, 45.200279576437815, 40.93580879483904, 37.699931962149485, 53.100099972316194, 22.08858735220773, 0.2454801004912172, 0.047217396154467545, 0.02948670954044376, 0.02552413797405149, 0.0717314923448222, 0.10200814556862627, 0.04151829910863723, 0.09967680781015328, 0.0396170745204602, 0.06304971142006771, 0.016080409720806137, 0.10917200294456311, 0.04086638641144548, 0.03515070936243449, 0.012655052988390838, 0.056600487125771384, 0.25639512336679865, 0.11786670317607266, 0.23080344232065336, 0.09357692727020808, 0.24545909304703983, 0.17243216878601483, 0.23153631442359515, 0.19133121467062406, 0.10994691707726036, 0.1346502397209406, 0.16304760878639563, 0.0773832547877516, 0.07642496656626463, 0.23584965297154017, 0.21055522454636438, 0.06736545198197876, 0.12552768923342228, 0.2272260021418333, 0.16711966028170927, 0.28470577565687044, 0.15431570447981358, 19.61917325428554, 89.35774571555001, 56.53413942881993, 55.438467570713584, 47.67513063975743, 44.54040568215506, 63.64782673971993, 27.578656094414846, 13.99899775641305, 53.98170130593436, 62.65939685276577, 68.04207597460065, 78.32213728768485, 73.68390205928257, 69.28157206944057, 66.70946707044328, 64.69689355577741, 60.643057414463584, 39.78476674216134, 11.914420059749059, 5.830947799342019, 26.33961684363229, 44.08846705300467, 58.31256907326834, 64.24209226880754, 65.41995784214565, 64.53051894051688, 57.410960401807515, 38.808273860386436, 29.805076054164342, 18.85546200616019, 25.486124447413854, 31.97786808013916, 37.908120836530415, 41.985653809138704, 47.5141339302063, 44.420802865709575, 40.85409450531006, 36.06514242717198, 40.611928939819336, 51.308760574885774, 51.4028183392116, 49.403870241982595, 52.06238303865705, 53.695675236838206, 58.37385218484061, 58.12156309400286, 56.819168431418284, 55.760339396340505, 55.25117540359497, 56.949203968048096, 57.27994169507708, 58.87100274222237, 50.960259778159006, 47.11411224092756, 42.56984792436872, 44.15860216958182, 43.15727642604283, 46.32821886880057, 45.310314723423545, 47.6546299798148, 44.406267234257285, 46.048362800053184, 46.27982119151524, 47.38868073054722, 51.641923223223, 56.04931844983782, 54.433337688446045, 52.73035158429827, 51.577106952667236, 50.465461186000276, 57.38632556370327, 49.24325220925467, 50.677131107875276, 48.27505200249808, 47.56941727229527, 44.347134590148926, 43.40081426075527, 45.421062060764854, 48.19913598469326, 45.65089804785592, 43.756596769605366, 40.52742494855608, 45.01833404813494, 50.007085050855366, 53.771615573338096, 55.313802991594585, 53.12408167975289, 37.13143730163574, 21.45026503290449, 28.274212462561472, 34.595209326062886, 44.72897284371512, 40.014418601989746, 35.45695965630667, 36.1503620828901, 38.51140512738909, 39.14077295575823, 35.94915614809309, 23.624526602881296, 26.26537881578718, 29.216692175183976, 17.174562488283428, 12.736243435314723, 15.655377081462316, 12.892616987228394, 12.316224830491201, 9.12479475566319, 8.325810977390834, 3.745677019868578, 4.202786411557879, 15.293579169682094, 27.964911665235245, 35.22276714869908, 40.41600363595145, 38.39076702935355, 33.07932778767177, 13.729947004999433, 11.026648725782122, 22.5976471219744, 45.225105490003315, 50.51846899305071, 57.50631053107125, 53.70708417892456, 54.09093393598284, 59.205016544886995, 60.22606822422573, 54.21712017059326, 60.37902586800711, 30.213181972503662, 14.036375590733119, 19.18239038331168, 30.45998546055385, 39.39879083633423, 61.31699793679373, 56.37976087842669, 46.411222049168174, 66.03191348484584, 33.45938382829939, 0.5689177949513707, 0.17891597801021167, 0.14210225056324685, 0.10411935299634933, 0.11954634876123496, 0.1604090846542801, 0.12876478981758865, 0.198787798838956, 0.13354819028505258, 0.11842296618436064, 0.12003052420914173, 0.1316898050052779, 0.09483006609869854, 0.19930562962378773, 0.21040882383074078, 0.17737666703760624], [0.1269287961934294, 0.10952573003513472, 0.0683266171919448, 0.11275509532008852, 0.03761088056489825, 0.043938389247549434, 0.08703140528606516, 0.1160838252731732, 0.0327602813818625, 0.09406692454857485, 0.08079095943165676, 0.06517999925251518, 0.030138517064707618, 0.09468297327735595, 0.09367414776768003, 0.08165083971938916, 0.0897509397140571, 0.06628643202462367, 0.018233116350269744, 0.011278949195652135, 0.03583933758948531, 0.34020774172885077, 27.80570411682129, 46.03458104814802, 39.93433019093105, 46.33867938177926, 41.18270608357021, 31.778826509203228, 39.137330123356406, 12.23983633518219, 34.66156809670584, 61.9415089743478, 51.730241775512695, 70.4225218636649, 63.787631443568635, 68.92573397500175, 64.54713208334786, 63.025393213544575, 53.17970895767212, 36.821172441755024, 12.418917468615941, 4.912275220666613, 19.788584232330322, 38.826530252184185, 50.4009610584804, 58.39607947213309, 59.432431084769114, 57.63374049322945, 46.2581011227199, 23.98743622643607, 11.494186060769216, 10.39844732625144, 14.819126640047346, 21.84837770462036, 23.2333482333592, 24.45494055747986, 29.890434673854283, 34.86510515213013, 34.40946660723005, 34.76742737633841, 42.0014922278268, 44.03389590127127, 43.76332957404, 42.677895886557444, 45.15391424724034, 51.472255161830354, 58.246884277888704, 59.25664166041783, 57.607187952314106, 53.321462631225586, 47.53454426356724, 55.28359917231968, 56.46328864778791, 55.06328221729824, 45.82020132882254, 41.9772047996521, 40.57228946685791, 39.79078388214111, 42.23484052930559, 40.89272996357509, 40.08375120162964, 39.00703055518014, 40.52698373794556, 39.88706159591675, 43.42349665505545, 43.50952925000872, 50.64369290215628, 53.46468932288033, 53.88607324872698, 52.84787341526577, 55.039595808301655, 50.277098996298655, 53.77284887858799, 53.268440927777974, 49.005662032536094, 45.421722139631, 42.62614917755127, 41.71094288144793, 40.39163282939366, 41.7563111441476, 41.70332418169294, 40.57894584110805, 36.70846223831177, 35.923468657902305, 37.577487332480295, 46.71017871584211, 47.223518575940815, 48.47915881020682, 36.499714033944265, 19.450418881007604, 7.211822365011487, 12.170442070279803, 22.967788083212717, 25.12592462130955, 23.91834681374686, 16.916489022118704, 14.93789393561227, 14.62782883644104, 21.14345690182277, 20.544935601098196, 19.43225281579154, 11.40148319516863, 18.88034176826477, 12.519547360283987, 6.810060586248126, 7.46320949281965, 4.004067063331604, 3.7560554572514127, 3.5053486015115465, 1.151010894349643, 0.4605336593730109, 4.788131756441934, 13.115037509373256, 22.40459837232317, 25.304345675877162, 31.618986674717494, 30.490540163857595, 27.087560892105103, 13.835758515766688, 8.48851694379534, 20.716910464423044, 39.836551666259766, 45.50052513395037, 41.54239000592913, 35.415791579655235, 55.361370359148296, 57.407263960157124, 50.28404024669102, 45.07730688367571, 50.05123390470232, 13.797937733786446, 10.541806902204241, 22.92927942957197, 32.20928478240967, 34.97407375063215, 49.77158628191267, 51.818000997815815, 45.37627049854824, 33.55350412641253, 6.314060824257987, 0.1258783425603594, 0.060582490238760195, 0.011732818725119745, 0.056467161779957156, 0.03443888541577118, 0.029892191889562776, 0.04208976808669312, 0.07644266275955097, 0.02178542359199907, 0.025854715146124363, 0.02571151202677616, 0.092323293111154, 0.010156948285709535, 0.08997586728738886, 0.0485781777783164, 0.11692904920450278, 0.002204075123050383, 0.05400265473872423, 0.04933510394766927, 0.11195016279816628, 0.16556177102029324, 0.08060516297285046, 0.08683918310063225, 0.07855207885482482, 0.073797244711646, 0.04235910916967051, 0.04975235887936183, 0.057602954762322564, 0.03637106137882386, 0.0596927883369582, 0.08298992179334164, 0.061688373397503576, 0.04592314488919718, 0.01724835847770529, 0.051614337002060244, 0.08615840891642229, 0.05565676705113479, 0.4844977248992239, 37.79787376948765, 56.81405108315604, 45.92564371653965, 41.753969601222444, 41.57152380262102, 28.918442487716675, 31.69248471941267, 18.523612567356654, 40.92821788787842, 64.07857336316789, 56.68459572110857, 76.4065328325544, 67.30376734052385, 73.71830259050641, 66.31419794900077, 66.38829353877476, 57.79047795704433, 42.11115217208862, 13.738039919308253, 5.779148978846414, 22.2071270942688, 41.88647869655064, 53.39132329395839, 63.69026633671352, 59.83030578068325, 59.474293981279644, 48.61059788295201, 27.937336002077373, 15.348480360848562, 13.963432533400399, 18.994398185185023, 25.787585939679825, 27.768790074757167, 29.100921290261404, 32.646135398319785, 36.56979009083339, 35.47882216317313, 35.58343424115862, 44.90462677819388, 47.05903387069702, 42.6531776700701, 44.28121703011649, 46.85618468693325, 52.704236779894146, 58.17096478598458, 59.66909367697579, 61.301711899893625, 56.560205595833914, 50.88590363093785, 55.444265842437744, 57.673216683524, 55.53994948523385, 49.31874786104475, 44.60340152468, 42.96510314941406, 43.67339903967721, 45.477238246372764, 45.53225408281599, 45.67357349395752, 44.716611998421804, 45.43629251207624, 43.783854552677695, 46.496983664376394, 47.56983069011143, 52.773173332214355, 54.37771041052682, 55.07649074281965, 52.83334125791277, 56.247873646872385, 52.592186655317036, 53.06324325289045, 54.296572821480886, 50.2598466191973, 48.04918691090175, 44.45508180345808, 42.83878142493111, 41.653554235185894, 43.18790408543178, 46.1261305127825, 44.49575308391026, 39.3625351360866, 37.48952661241804, 40.32463829857962, 50.01190710067749, 51.20619821548462, 52.07590423311506, 42.001433168138774, 23.997179337910243, 12.296220098223005, 16.38532703263419, 26.687507935932704, 29.98793179648263, 29.04702237674168, 19.83082754271371, 18.152481487819127, 15.515737397330147, 25.725852932248795, 25.107374668121338, 23.247717108045304, 16.27404989515032, 20.48487537247794, 13.39296111038753, 6.517965699945178, 6.159220218658447, 4.1046865327017645, 5.312928761754717, 6.043675150190081, 2.990885304553168, 1.5152428469487598, 6.124919133526938, 13.076626999037606, 22.675430468150548, 25.498829228537424, 30.493350710187638, 33.32808371952602, 28.52903938293457, 14.325792380741664, 12.220249363354274, 24.905458280018397, 43.8435708454677, 51.257079873766216, 46.17238814490182, 40.85615117209298, 57.81940678187779, 61.19315324510847, 54.87341921670096, 49.42817851475307, 52.90789195469448, 19.283571788242885, 19.63800982066563, 23.79513440813337, 24.36447501182556, 34.142968450273784, 56.243346895490376, 59.17673737662179, 49.33848074504307, 46.50147220066616, 11.198067733219691, 0.343574659632785, 0.07508871398333992, 0.1516078340687922, 0.11955025712294237, 0.05684414565829294, 0.04017615005640047, 0.06375805448208537, 0.14414373173245362, 0.0652957030438951, 0.12606207627270902, 0.0861155865713954, 0.11831722328705446, 0.06574071345052548, 0.031607698050460646, 0.10063347433294569, 0.0709532398198332, 0.17825216720146791, 0.15285149376307214, 0.15119183781955922, 0.1472720495824303, 0.33657896359051975, 0.11859900530959878, 0.23009635454842023, 0.18422229827514716, 0.12445675741348948, 0.12004002369940281, 0.14006838255694934, 0.17804980091750622, 0.09828522069645779, 0.2802613712847233, 0.12651730541672024, 0.1816511798117842, 0.24910684302449226, 0.2311325589460986, 0.16529680309551104, 0.2822133536849703, 0.17012312768825463, 1.1394072941371371, 58.23283849443708, 72.73286737714494, 56.99011843545096, 61.51882226126534, 53.7720741544451, 47.28869267872402, 44.54980312074934, 16.414231538772583, 41.81727116448538, 72.1135744367327, 60.640993799482075, 80.88662011282784, 74.58723735809326, 77.5076902934483, 70.55176530565534, 70.33621828896659, 60.207405362810405, 44.85231726510184, 15.518065043858119, 7.0595482502664835, 23.915487630026682, 45.08645418712071, 56.538812092372346, 67.76761518205915, 63.93681621551514, 62.057724543980186, 53.29111289978027, 32.21685137067522, 25.23646351269313, 21.616688285555156, 21.700834444590978, 31.973244053976877, 33.50116334642683, 34.27219452176775, 37.29094014848982, 41.329514571598594, 39.827956744602744, 39.97130502973284, 48.94126612799508, 51.10437931333269, 48.22605678013393, 46.367952142442974, 50.90775571550642, 55.04250015531267, 59.194872174944194, 64.21526527404785, 61.66174670628139, 58.529609952654155, 55.09721721921648, 57.86415318080357, 59.19199562072754, 57.585679803575786, 49.691900866372244, 45.59413126536778, 44.7327561378479, 43.05843482698713, 48.72562183652605, 48.0489159311567, 47.93426023210798, 45.3400217464992, 45.99586568559919, 44.21530989238194, 48.17531755992344, 46.12029750006539, 50.85832623073033, 54.458222661699565, 55.02688407897949, 53.431747913360596, 53.497217314583914, 50.78830575942993, 53.401227951049805, 54.27670097351074, 51.112407956804546, 46.67151199068342, 44.858584540230886, 45.25835262026106, 43.10867725099836, 45.079172474997385, 48.218003817967, 45.4868163381304, 42.20829493658883, 39.9768705368042, 44.48253413609096, 54.348760741097585, 53.67163099561419, 56.835666928972515, 46.14131580080305, 26.793893541608536, 17.687513249261038, 20.186014243534633, 25.54837509563991, 32.167967319488525, 32.14403772354126, 22.320301089967998, 22.394052743911743, 21.51445596558707, 31.511814185551234, 28.62984037399292, 26.53887380872454, 19.309231485639298, 27.14433809689113, 17.438708680016653, 11.596667647361755, 12.011510712759835, 9.645204407828194, 10.281775781086512, 8.576775567872183, 7.520295023918152, 2.50635940687997, 6.500293391091483, 14.907222849982125, 23.517692838396343, 26.750427348273142, 33.175695828029085, 36.69526066098894, 30.862473760332378, 16.071445635386876, 16.61088640349252, 27.75487630707877, 48.209183079855784, 52.83491849899292, 48.83798810413906, 41.91018942424229, 62.16363593510219, 64.75345884050641, 57.39864819390433, 52.89913722446987, 56.75240666525704, 20.166005168642315, 16.333755765642437, 30.08314643587385, 44.69541651862008, 50.937379360198975, 60.275442123413086, 68.77664647783551, 55.12380797522408, 61.42346518380301, 16.17709994316101, 0.4406418896147183, 0.14731840709490435, 0.3144254737666675, 0.2242795316768544, 0.1471035557665995, 0.08156877769423382, 0.1889802808208125, 0.18302610889077187, 0.14288989401289395, 0.21655127565775598, 0.2012078889778682, 0.35091933980584145, 0.21908495255878993, 0.1785928596343313, 0.17269016137080534, 0.19535962279353822], [0.13080183336777346, 0.06124119846416371, 0.01163228867309434, 0.06970821627016578, 0.04948437147374664, 0.0707065991259047, 0.1173095309308597, 0.1734545582107135, 0.17592507707221167, 0.1406004082943712, 0.10216505000633852, 0.04198178602382541, 0.02725308930634388, 0.10654463392815419, 0.11894228974623339, 0.015522465642009462, 0.01670713859078075, 0.12021561499152865, 0.006845945484071437, 0.05983986758760043, 0.03155412431806326, 0.09539197451834168, 6.77537648166929, 45.98834426062447, 47.375882148742676, 44.629394735608784, 36.540319306509836, 45.21736519677298, 38.334924357278005, 25.99115947314671, 17.55471232959202, 66.50849042619977, 49.161902700151714, 59.868041447230745, 68.20550455365861, 61.05182688576834, 61.68754536764962, 63.125447273254395, 56.26065485818045, 31.10147442136492, 17.178908586502075, 8.912832140922546, 18.586269685200282, 32.50465617861067, 49.11567980902535, 58.483154296875, 54.613004207611084, 52.91004242215838, 44.2020457812718, 18.309119939804077, 11.574495077133179, 7.928589412144252, 11.807555028370448, 14.652616534914289, 16.486977440970286, 20.657598904200963, 24.454382964542933, 28.801347970962524, 28.061948469706945, 34.54822908129011, 48.374056884220664, 40.86483989443098, 40.38877364567348, 38.29303019387381, 43.64093358176095, 50.951741286686485, 53.87717260633196, 50.386963912418906, 49.027455057416645, 43.742616994040354, 55.36056784221104, 57.55251257760184, 55.59730339050293, 51.20819929667881, 44.598739283425466, 42.09802007675171, 42.802261693137034, 38.746865681239534, 38.613515853881836, 40.278001989637104, 40.62414387294224, 39.17160211290632, 40.22989613669259, 40.20099857875279, 41.50995234080723, 45.67717613492693, 51.089795044490266, 53.35231263296944, 54.217182704380576, 53.1800320489066, 55.088934966496055, 55.55041347231184, 50.47071402413504, 50.507282393319265, 46.364971365247456, 44.76947389330183, 40.43604918888637, 39.77174929210118, 39.45211131232125, 40.16515629632132, 41.886270250592915, 40.15958384105137, 35.90770666939871, 36.64366333825247, 40.307104519435335, 46.176720346723286, 47.25824914659773, 49.40977968488421, 39.81189250946045, 33.354069982256206, 28.33465310505458, 14.355016504015241, 13.844674791608538, 15.580914974212646, 13.742782064846583, 7.980527196611677, 6.386131014142718, 7.471804414476667, 11.033709832600184, 19.359725781849452, 20.863017184393748, 13.50979767526899, 12.769950883729116, 12.461152093751089, 5.2001746978078565, 4.707634704453604, 3.290447984422956, 1.8528958771909987, 1.0084784797259738, 1.4142775961330958, 0.9647214391401836, 4.497774788311549, 12.7440618957792, 20.984502962657384, 23.100715807506017, 26.2994510446276, 25.00411401476179, 26.256073440824235, 13.557940006256104, 4.798709520271846, 23.97676031930106, 41.68711403438023, 45.568693910326274, 29.548677103860037, 45.1686235836574, 56.28317049571446, 52.80502387455532, 42.92634262357439, 58.88492693219866, 38.17689105442592, 9.222677503313337, 18.40461424418858, 37.387384619031636, 33.56144939150129, 35.237188134874614, 40.71098940713065, 41.02022245952061, 49.9192841393607, 30.45302336556571, 1.363750295979636, 0.14792701229453087, 0.060238160858196874, 0.057750834684286795, 0.027421932567709258, 0.0758882589372141, 0.09180236820663724, 0.11144170936729227, 0.10713106460337128, 0.10752333926835231, 0.05120808451569506, 0.023475723873291696, 0.06900487401123558, 0.049840470044208426, 0.026810160305883204, 0.12449942369546209, 0.15202069548623903, 0.08221227316451923, 0.10892743856779166, 0.012364248994604816, 0.1136431483817952, 0.10048450875495162, 0.12904735894075461, 0.06777300047022955, 0.17248141685766832, 0.033231676622693024, 0.1317399623138564, 0.04202231492048927, 0.07035825960338116, 0.08572755275028092, 0.13816267624497414, 0.03919263729559524, 0.04187494729246412, 0.020519928640819023, 0.09709542989730835, 0.032245663460344076, 0.05326199983911855, 0.052503489290497134, 0.1703332835542304, 8.761188575199672, 60.373119899204795, 55.04174974986485, 43.391069412231445, 41.23725291660854, 37.38744020462036, 27.71227863856724, 28.976816041128977, 25.25773021153041, 72.78921031951904, 50.28688553401402, 68.69456045968192, 71.48375497545514, 68.87722165243966, 66.35017572130475, 68.19786153520856, 59.45299080439976, 36.044971806662424, 19.16400718688965, 9.179910472461156, 18.735918249402726, 36.29793834686279, 50.511142117636545, 61.03684656960623, 57.00475481578282, 52.4594725881304, 44.65306030000959, 23.46178068433489, 15.70898243359157, 14.505790676389422, 16.58527534348624, 19.792702777045115, 20.36063289642334, 22.943175826753887, 24.65003728866577, 29.23323236192976, 29.797915935516357, 35.6490078653608, 48.34737580163138, 43.05913659504482, 41.70838941846575, 38.72141442980085, 45.443935530526296, 52.67574916567121, 56.846641608646934, 55.951925550188335, 51.801672731127056, 48.235322202954976, 56.023168904440745, 59.13775103432791, 58.49817630222866, 54.81786142076765, 48.362929344177246, 45.397723061697825, 45.200946603502544, 43.1838949748448, 43.034706728799, 44.81251103537423, 44.87278665815081, 45.00656379972185, 43.3199337550572, 44.52957691465105, 43.866440841129844, 48.43560402733939, 54.2880300113133, 54.32933357783726, 55.47039106913975, 52.77164820262364, 55.39056668962751, 57.01063299179077, 50.977546896253315, 52.42286252975464, 46.87913806097848, 46.01538664954049, 41.22506925037929, 41.05567216873169, 39.880575452532085, 44.21393067496163, 45.57331446238926, 44.56433875220162, 39.39545570101057, 41.00324106216431, 43.37022829055786, 51.0318957056318, 50.010041509355815, 53.30303600856236, 45.008085455213276, 35.94104412623814, 29.360950674329484, 15.836994307381765, 16.32705249105181, 19.67742347717285, 18.893166405814036, 8.914068051746913, 7.683669754437037, 7.057146344866071, 11.688887613160269, 20.289884601320537, 23.816213505608694, 18.42644374711173, 14.282438227108546, 14.841197592871529, 5.674006232193538, 3.672773914677756, 2.165401096854891, 2.39821286712374, 3.4485171139240265, 3.443016529083252, 1.1907006331852503, 6.089801635060992, 15.552451678684779, 22.051475286483765, 22.4178729057312, 27.61337971687317, 26.53422372681754, 29.99834714617048, 13.875396251678467, 6.272385963371821, 25.55389196532113, 44.301043714795796, 47.89430461611067, 33.15474353517805, 45.682307379586355, 60.18875639779227, 57.900697231292725, 47.02936506271362, 61.70267159598214, 44.21899243763515, 18.869530371257238, 23.341309343065532, 28.334128516060964, 27.378923177719116, 37.48027161189488, 48.58491734095982, 42.90968779155186, 59.757474763052805, 42.058432715279714, 2.737574828522546, 0.21645930702132837, 0.06348270497151784, 0.05806102018271174, 0.052224485868854184, 0.08897062444261142, 0.06578771557126727, 0.13740898668766022, 0.13285926010991844, 0.10515910613217525, 0.11629057489335537, 0.059629772789776325, 0.025608990474471023, 0.059360346889921596, 0.06567891248102699, 0.17398382909595966, 0.18480913607137545, 0.26346819954259054, 0.21437830797263555, 0.12537735301469052, 0.2263826916792563, 0.2015380369765418, 0.16396677946405752, 0.15479530660169466, 0.24643363218222344, 0.1677139483924423, 0.2261549210441964, 0.21107133185224874, 0.211264185075249, 0.20795942097902298, 0.20315996637301786, 0.15804193381752285, 0.16560639148311956, 0.08581329243523733, 0.18962034290390356, 0.18413639574178628, 0.19016422943345138, 0.11898066768688814, 0.24107993660228594, 14.053966692515782, 82.08043180193219, 64.7955857685634, 59.91685949053083, 46.26065111160278, 60.24297319139753, 47.61844376155308, 30.78650563103812, 23.982400519507273, 76.67253766741071, 56.85471888950893, 72.00055503845215, 78.60690920693534, 73.25217573983329, 69.31946059635708, 70.54240608215332, 63.404750960213796, 38.49028607777187, 20.06242663519723, 10.129428710256304, 20.858697141919816, 39.53280769075666, 53.81551776613508, 62.65531826019287, 60.026898111615864, 57.225797857557026, 47.47792339324951, 31.42162309374128, 21.62002863202776, 21.1135744367327, 23.907622269221715, 25.13233607155936, 24.010391337530955, 27.401179994855607, 30.242458207266672, 33.107978684561594, 33.130720138549805, 41.55671719142369, 52.82792166301182, 47.40539114815848, 44.760920660836355, 41.269978931971956, 46.25679833548409, 54.24138675417219, 57.953614711761475, 57.2910727092198, 49.5996218408857, 48.744771071842735, 59.190397535051616, 62.991965430123464, 59.30113097599575, 56.383266244615825, 49.4163179397583, 45.614944594247, 47.30306502750942, 43.12615197045462, 42.695509569985525, 46.639397416796, 47.67340053830828, 43.80409118107387, 44.08536468233381, 44.843652861458914, 44.23187787192208, 49.205176080976216, 53.195481368473594, 54.22955049787249, 53.96821485246931, 51.66691936765398, 53.602204595293315, 54.335211753845215, 53.68879304613386, 49.850104400089805, 46.7593789100647, 44.6246143749782, 43.40767560686384, 41.85316555840628, 42.33980696541922, 44.76481165204729, 46.7111827305385, 46.59433140073504, 40.946067810058594, 42.570414202553884, 46.59242412022182, 52.01571198872158, 54.07715565817696, 53.42563349860055, 50.10680559703282, 42.35447808674404, 35.481410367148264, 19.349423340388707, 16.901569502694265, 22.01787553514753, 22.09377591950553, 10.337441274097987, 10.280617168971471, 11.174049547740392, 19.043940578188213, 25.94694808551243, 28.39728590420314, 22.65664427621024, 19.97137222971235, 21.257614067622594, 9.987382343837194, 8.14079521383558, 6.016010028975351, 6.8704261013439725, 6.691976385457175, 6.155882477760315, 3.4329546689987183, 7.097711665289743, 17.13465029852731, 24.003212111336843, 25.90111950465611, 31.242046901157924, 27.676813295909337, 33.98415000098092, 16.313689368111746, 8.66817912033626, 28.667687211717876, 47.721023491450715, 51.11446462358747, 36.22356135504586, 50.20800610951015, 63.942833355494905, 61.20324897766113, 49.786076750074116, 66.41004834856305, 45.37892818450928, 15.954510927200317, 26.207906791142054, 46.69691113063267, 49.547725745609824, 45.79060895102364, 54.87119231905256, 53.42910412379673, 68.46039227076939, 55.50053582872663, 5.1722867999758035, 0.40965479665568894, 0.14856609728719505, 0.20530244069440023, 0.13410467042454652, 0.17687920587403433, 0.1631164936614888, 0.26789395777242525, 0.25593105969684465, 0.2155789349760328, 0.3097794902111803, 0.31584716747914043, 0.21452787066144602, 0.17135229387453624, 0.13210908536400112, 0.28234059257166727, 0.3249347869838987], [0.058860605848687034, 0.13449218177369662, 0.07499117457440921, 0.06680578951324735, 0.0699408994987607, 0.06290732763175454, 0.07125788168715579, 0.04326210357248783, 0.13053626833217485, 0.022454959539962665, 0.06046869991613286, 0.1202717162668705, 0.11847241781651974, 0.07198162749409676, 0.11813906713255815, 0.07004618777760438, 0.051634184151355705, 0.03278182486870459, 0.06268088692533118, 0.06262496885444437, 0.054978876640754085, 0.025199623512370244, 0.020922345707991293, 38.936155455453054, 56.479599543980186, 37.557163851601736, 38.49718911307198, 43.90134859085083, 39.83297334398542, 29.647598607199534, 12.623027750423976, 47.72605398723057, 69.0725633076259, 49.05636651175362, 73.44275093078613, 63.97073037283761, 69.30424404144287, 65.13110038212368, 58.57541247776577, 38.988593510219026, 28.194968257631572, 8.699995790209089, 11.959712760789053, 30.19177804674421, 43.1317834854126, 55.59767859322684, 49.59699889591762, 51.77584975106375, 36.46495567049299, 12.903598615101405, 5.175482971327646, 10.223747900554113, 10.613223961421422, 10.110987322671072, 9.563259959220886, 12.440923282078334, 15.214904717036656, 20.0081490448543, 22.224845000675746, 38.60821785245623, 39.273726735796245, 36.40820278440203, 34.178591864449636, 35.66102130072457, 38.823400088718955, 46.804979937417166, 42.05313471385411, 41.583915914808, 32.311301708221436, 44.289318629673545, 63.91599941253662, 54.63369594301496, 56.48438337871006, 49.39394474029541, 44.54450511932373, 43.580150740487234, 41.424159458705354, 39.782904624938965, 40.03597886221749, 42.519393580300466, 40.59941870825631, 39.29177815573556, 40.41190767288208, 40.41926234109061, 43.04221078327724, 50.112979071480886, 53.28032234736851, 54.98405885696411, 51.5925805909293, 53.741877283368794, 53.378118242536274, 54.58045537131173, 50.91961629050118, 47.681835651397705, 46.571725436619346, 44.02811847414289, 39.48384026118687, 42.41991622107369, 41.42457635062081, 40.177954878125874, 40.58269786834717, 39.43367426736014, 36.46337495531355, 38.32991818019322, 43.020431654793875, 46.892436913081575, 48.86862965992519, 47.62517656598772, 46.332683086395264, 51.71920803615025, 45.70415251595633, 23.461005960191997, 12.392172983714513, 8.192274417196002, 6.749115330832345, 4.475169692720685, 2.498479498284204, 2.7950915821960995, 4.617118350097111, 13.195188454219274, 22.475958108901978, 21.610989025660924, 10.364405495779854, 10.33399670464652, 4.1509667464665005, 1.2551862129143305, 1.2428045230252402, 1.494420398558889, 0.09193715240274157, 3.142783348049436, 0.4839325323700905, 2.1709025502204895, 15.628720317568098, 16.855169432503835, 20.98008390835353, 19.689888545445033, 23.140393495559692, 27.380528211593628, 9.720357860837664, 2.4944977462291718, 20.257724864142283, 49.059402874537874, 42.139219420296804, 38.97746597017561, 59.13150460379464, 54.06003877094814, 49.72180938720703, 41.741733823503765, 66.83296435219901, 17.25567054748535, 12.871284280504499, 31.088939871106827, 35.472725118909565, 24.37810911451067, 41.2728659084865, 27.173701184136526, 30.58150597981044, 23.562168257577078, 10.8151307957513, 0.03680049262142607, 0.05933965835720301, 0.06335722349051919, 0.03169892708371792, 0.07105921341904572, 0.027213941228442957, 0.0390622262576861, 0.07643523958644696, 0.14915156444268568, 0.14812282393021242, 0.05799261706748179, 0.1256484141839402, 0.0903516671221171, 0.033525953867605755, 0.06517921215189354, 0.049327032773622444, 0.07167577104909079, 0.06007889511861971, 0.1299741563520261, 0.11661935225129128, 0.07728503005845205, 0.10763616607125316, 0.11494885331818036, 0.13601115026644298, 0.03451534613434758, 0.18620030927870954, 0.0754440084898046, 0.1166392197566373, 0.0780313778668642, 0.05599986489063927, 0.03236945538914629, 0.11922215830002512, 0.06634426356426307, 0.04100016976839729, 0.056937847951693196, 0.10057328149144139, 0.07324106991291046, 0.16335559583136014, 0.031691788895321746, 0.32349176013043945, 46.11450617653983, 66.79244245801652, 42.02837480817522, 29.688645090375626, 33.386459009987966, 26.900694302150182, 27.85914271218436, 21.124974693570817, 55.36840541022164, 67.72304943629673, 52.8543004989624, 78.85317420959473, 70.100250516619, 71.04298904963902, 69.25926835196358, 61.487499782017295, 41.67151185444423, 29.648283004760742, 9.676810894693647, 12.870423572404043, 32.10476303100586, 43.1672887802124, 55.69583232062203, 53.79660129547119, 52.98213693073818, 36.99364062717983, 18.938928978783743, 9.65545039517539, 13.905237027576991, 14.796044724328176, 15.549771411078316, 13.642708029065814, 15.460910899298531, 16.23560724939619, 20.827756813594274, 25.640134743281774, 42.43399327141898, 42.8160434450422, 37.861171858651296, 33.91318110057286, 37.21297788619995, 41.13196686335972, 52.23472268240792, 46.82346561976841, 46.6324075290135, 37.5139217376709, 46.269871371132986, 62.69310256413051, 56.86609309060233, 57.562483242579866, 50.89847987038748, 47.10073001044137, 46.208240849631174, 43.947161538260325, 44.10202298845564, 46.114325523376465, 46.48228127615792, 45.15174988337925, 43.883411816188264, 44.05096762520926, 43.15136350904192, 45.86990874154227, 51.38447856903076, 54.59434134619576, 54.42856775011335, 54.11132689884731, 53.40771409443447, 54.54195192881993, 57.23836367470877, 51.550599575042725, 50.208238874162944, 49.21005024228777, 45.27090106691633, 42.482672350747244, 42.7153570992606, 44.57982628686087, 44.156507287706646, 44.26685857772827, 42.32311739240374, 38.43041345051357, 40.04482739312308, 46.03733948298863, 49.649565492357524, 52.61866624014718, 50.76191650118147, 49.32041890280587, 49.04240410668509, 43.781353201184956, 25.483713422502788, 13.991230538913182, 10.314014554023743, 8.221574102129255, 7.088840118476322, 4.676320910453796, 5.24969972031457, 7.27937969991139, 12.969711593219213, 22.42237707546779, 22.896600314549037, 13.15866698537554, 11.144887958254133, 5.39042158637728, 2.8694700939314703, 0.747872069478035, 1.078515235866819, 0.8164593119706426, 4.593233917440687, 2.9858947609152113, 4.33532851082938, 16.57845742361886, 20.675452300480433, 21.19557360240391, 19.95744456563677, 23.900621959141322, 29.798280715942383, 10.319979582514081, 2.858860411814281, 22.36602544784546, 51.861048562186106, 43.805901186806814, 44.003250871385845, 58.262038299015586, 57.15563494818551, 53.53488349914551, 46.05705847058977, 68.70389883858817, 26.282355001994542, 21.392553295407975, 29.347759519304546, 29.36920860835484, 22.545189959662302, 48.62222221919468, 31.270263535635813, 38.05512040002005, 38.23056936264038, 17.62727063042777, 0.10843845230660268, 0.08418459804462534, 0.06604364540960107, 0.09453483551208462, 0.03904372600040265, 0.034055842219718864, 0.08848882386726992, 0.1393423229455948, 0.11186260463935987, 0.17176105694047042, 0.11460419824080807, 0.08043541386723518, 0.061995064440582476, 0.03153737807380302, 0.10583574803812162, 0.0837719469730343, 0.18070820612566812, 0.24306305018918856, 0.24162474593945912, 0.14642610640398093, 0.16089688347918646, 0.18132105895451137, 0.28882974865181105, 0.1831363844020026, 0.1361584873603923, 0.2140250490712268, 0.11761024408042431, 0.17128636741212436, 0.21643388909952982, 0.253657370273556, 0.1283037117017167, 0.26184910642249243, 0.18107522571725504, 0.14756977717791284, 0.17616374497967108, 0.24746223698769296, 0.13684846247945512, 0.24082182188119206, 0.15604781439261778, 0.7793850270765168, 68.15836797441754, 76.63525363377163, 54.5907039642334, 48.641190801348, 57.863951683044434, 57.8881869997297, 33.11668130329677, 17.759639024734497, 57.954927921295166, 75.88863495418003, 60.665430613926475, 83.57360662732805, 74.38309233529228, 77.36154883248466, 72.41272217886788, 65.4276772907802, 44.319703102111816, 31.793264865875244, 12.353063310895648, 13.82168059689658, 35.253276688711985, 45.67978865759713, 60.555155754089355, 58.46590886797224, 57.53638233457293, 42.53916467939104, 26.870379311697825, 18.873607226780482, 19.299597808292933, 19.046817132404872, 21.61897771699088, 16.13579637663705, 18.92023311342512, 20.263978242874146, 25.653343268803187, 29.889267376491002, 45.32919992719378, 47.49063164847237, 42.65676988874163, 36.31400605610439, 40.53705167770386, 43.96772125789097, 54.08271769114903, 48.49882221221924, 46.753031730651855, 35.42218392235892, 49.293275765010286, 64.92582975115094, 62.168395451136995, 58.68707697732108, 52.92988995143345, 48.11589309147426, 47.197028568812776, 45.54342678615025, 45.304450443812776, 45.93272393090384, 49.16818734577724, 45.925893851688926, 45.068246432713096, 45.99851989746094, 44.52905927385603, 47.92733287811279, 51.53393084662301, 54.265253816332134, 54.42114012581961, 53.314351149967735, 51.82639789581299, 55.69781950541905, 55.437508719308035, 51.93220158985683, 49.72199351446969, 48.96274300983974, 46.16113206318447, 41.73391710008894, 45.576243128095356, 47.54267365591866, 45.278894969395225, 44.74678455080305, 44.41807222366333, 41.482027530670166, 40.7941107068743, 47.01083074297224, 50.63798495701381, 54.147037165505544, 52.33127137592861, 53.20156799043928, 54.95506749834333, 51.779452392033164, 32.16969394683838, 17.053198303495133, 12.890586376190186, 10.924581425530569, 9.153062633105687, 6.578577876091003, 8.429921048028127, 10.764067615781512, 20.55102048601423, 30.516210283551896, 31.572537967136928, 18.52051714488438, 18.321303606033325, 10.303496718406677, 7.15382661989757, 5.547517316681998, 4.022679116044726, 4.2114490781511575, 7.502242735454014, 5.175618461200169, 6.638745367527008, 18.947303295135498, 24.281426668167114, 23.888690165110997, 21.15325038773673, 27.33930628640311, 33.233442306518555, 10.78773057460785, 3.6565055762018477, 24.770086526870728, 55.25728981835501, 47.74602310998099, 43.16316155024937, 63.64793791089739, 61.2606897354126, 57.482252393450054, 49.348937783922466, 73.69136442456926, 24.612397159848893, 18.801691634314402, 40.69664832523891, 48.154518127441406, 35.567710467747276, 51.46414313997541, 41.293630599975586, 47.56286859512329, 57.44254691260201, 25.354718378611974, 0.26059978774615694, 0.1455081570893526, 0.2685509968016829, 0.12460789430354323, 0.1048677974779691, 0.0893103601410985, 0.14526321951832089, 0.2967446967959404, 0.19436934164592198, 0.31302899441548754, 0.2678230915750776, 0.1570898677621569, 0.3428291124956948, 0.1011619988296713, 0.2569779578064169, 0.13959047677261488, 0.20960252066808088], [0.22546391455190523, 0.04224828065239957, 0.060587959231010506, 0.20215420105627604, 0.12073472142219543, 0.11271390824445657, 0.14687562228313514, 0.11843237067971911, 0.15623978552009377, 0.12059856658535344, 0.14494122751057148, 0.043797145398067575, 0.1776778008788824, 0.11703561991453171, 0.14088130822139128, 0.08740048762410879, 0.05739050544798374, 0.028102411589186107, 0.0637018582118409, 0.014688179695180483, 0.0538030636629888, 0.035922322422266006, 0.11880009594772543, 11.506647654942103, 70.10794217245919, 39.1301144191197, 95.95606081826347, 115.32176031385148, 42.31365047182356, 44.148249353681294, 13.185892633029393, 23.938871792384557, 68.76700932638985, 81.312301499503, 65.24057619912284, 54.280070849827354, 70.0919474193028, 65.75813361576625, 61.943391936165945, 52.74971621377127, 34.75930493218558, 9.267597607203893, 10.330371482031685, 23.642036063330515, 43.24620989390782, 49.85639599391392, 49.97629063470023, 45.01409217289516, 33.759872572762625, 11.621655975069318, 7.831074919019427, 9.88323666368212, 8.120522107396807, 6.872792397226606, 6.042861342430115, 7.678449920245579, 11.130044869014196, 12.464592320578438, 20.834625107901438, 37.30147361755371, 33.50228548049927, 29.636457170758927, 28.524800981794083, 28.632023845400127, 37.067725794655935, 35.99367673056466, 28.061345713479177, 15.951398134231567, 16.780504090445383, 48.378079891204834, 58.6043586730957, 54.82998602730887, 54.91386120659964, 47.39847421646118, 45.857131004333496, 41.43077066966465, 41.552155699048726, 40.748846667153494, 38.338784081595286, 42.66976996830532, 40.58924307141985, 38.57681546892439, 40.31150272914341, 43.29754318509783, 49.26546907424927, 52.25952775137765, 51.92591347013201, 54.17399617603847, 49.50274658203125, 51.13052885872977, 55.54716518947056, 51.78599064690726, 52.010393142700195, 46.17717892783028, 45.7986341203962, 43.32202516283308, 41.4401090485709, 40.69289282390049, 41.68986552102225, 41.11839703151158, 40.958261898585725, 38.738333293369834, 34.86822141919817, 38.08725929260254, 42.41655676705496, 44.49965797151838, 47.611193316323416, 47.95518473216465, 48.500208377838135, 51.81112922940935, 46.04943629673549, 29.946249553135463, 13.224363940102712, 7.0210673894201, 2.1856653009142195, 4.192227321011679, 0.3467394826667649, 2.001491137913295, 2.896233034985406, 9.90169368471418, 18.16086448941912, 25.513416971479142, 15.109578711645943, 7.92603508063725, 3.754911175795964, 0.9767262978213174, 1.842585836138044, 2.1868875324726105, 1.5520123881953103, 3.3856545899595534, 1.5297679475375583, 1.2288593798875809, 8.022957239832197, 17.744434629167827, 18.69829375403268, 16.953191144125803, 17.773745604923793, 24.56272622517177, 6.226887856210981, 1.9069011850016457, 16.01657918521336, 45.35109370095389, 37.986958571842735, 37.24901124409267, 60.95518439156668, 44.928917680467876, 43.6679481778826, 57.07539367675781, 50.24126713616507, 10.582011784826006, 25.85350349971226, 33.62203768321446, 32.25282914297921, 30.172604492732457, 37.196319580078125, 23.01959558895656, 34.432826450892854, 12.133006913321358, 5.649186398301806, 0.09961987872208868, 0.044661286885717084, 0.1194526973579611, 0.012788276553952267, 0.05907796097121068, 0.08558314692761217, 0.06349151235605989, 0.09037821819739682, 0.12025929907602922, 0.1269067166639226, 0.08744981711996452, 0.09465106177542891, 0.10507937826748405, 0.05630160941343222, 0.011933773656242659, 0.106406470627657, 0.1543973186718566, 0.46210460364818573, 0.08099970394479376, 0.1945328414440155, 0.1779864121760641, 0.12010426739496843, 0.16628605286989892, 0.09904466423072986, 0.11543677427939006, 0.23862222848193987, 0.06272885256579944, 0.17655801453760692, 0.021608850120433738, 0.19138009633336747, 0.14075530426842825, 0.15011428349784442, 0.031729892029293945, 0.06480025712932859, 0.03238048158319933, 0.0721613307084356, 0.11691878975502082, 0.145276722365192, 0.06431044305541686, 0.30055483377405573, 13.460927520479474, 82.77923992701939, 46.901236806597026, 85.81245517730713, 117.10238211495536, 39.57920776094709, 28.17249952043806, 18.56524269921439, 35.01821913037981, 76.25818879263741, 79.81244945526123, 75.76124668121338, 61.97381114959717, 74.13884231022426, 67.56409549713135, 66.01541846139091, 52.886845861162456, 37.39745255878994, 10.364709479468209, 10.928025994982038, 24.37413821901594, 42.345890113285606, 50.03625011444092, 51.447113105228965, 44.100341524396626, 36.16506099700928, 13.487883056913104, 10.502545237541199, 12.238194823265076, 12.535763587270464, 11.106233392442975, 9.333546434129987, 10.317092605999537, 12.648055161748614, 14.197953343391418, 25.158473457608903, 41.53832878385271, 34.72131218229021, 29.809307507106237, 31.03732865197318, 29.86102294921875, 39.316447734832764, 41.370943205697195, 33.70905692236764, 22.74739990915571, 19.61008848462786, 52.57169989177159, 62.041979925973074, 57.461400849478586, 57.62845638820103, 51.12952136993408, 46.69623020717076, 46.234557151794434, 44.95045709609985, 46.53988879067557, 43.78162070683071, 47.39402042116438, 44.95928130831037, 42.4747131892613, 43.01436587742397, 45.81757838385445, 47.65963268280029, 53.2895565032959, 55.74969128199986, 55.3406925201416, 51.52637815475464, 50.47692918777466, 55.524368149893625, 53.080849988119944, 54.54853187288557, 48.29181105749947, 47.283234868730815, 44.284802300589426, 42.99160705293928, 42.46206051962716, 44.154964787619456, 44.169952051980154, 45.36277709688459, 40.95453419004168, 37.71464129856655, 40.730496474674766, 43.93596451623099, 46.879488945007324, 50.398282527923584, 49.434911319187705, 51.78765821456909, 54.311098030635286, 50.342724731990266, 34.15631593976702, 16.539434603282384, 6.766784599849156, 3.9276260222707475, 7.08931085893086, 2.7183074738298143, 4.373592240469796, 4.957820228167942, 10.058865410940987, 15.690093755722046, 27.12155669076102, 15.773348808288574, 8.322895339557103, 3.245314223425729, 2.3655057421752383, 1.8276296215397971, 1.6182420743363244, 1.5370088389941623, 2.805381430046899, 2.0035189262458255, 1.926224125283105, 9.427645019122533, 21.149084942681448, 21.56380902017866, 16.979121821267263, 18.01685438837324, 27.658410991941178, 5.747406567846026, 1.3557586733783995, 17.088500363486155, 50.828792912619456, 40.09844316755022, 41.2653340612139, 62.60563169206892, 49.156972953251426, 49.213423592703684, 57.81515448434012, 56.983597551073345, 17.911552701677593, 29.01677165712629, 27.568747963224137, 24.281049728393555, 28.678463867732457, 44.70312554495675, 24.46188701902117, 44.39989921024868, 20.676855836595806, 7.540092178753444, 0.13272269815206528, 0.08166867161967925, 0.07621433572577578, 0.026426192605867982, 0.11452630242066723, 0.07168073114007711, 0.17249160845364842, 0.14915567636489868, 0.09781839538897787, 0.06998856658382074, 0.13162991750453198, 0.06549874786287546, 0.10470731716070857, 0.023936203182009713, 0.07009570047791515, 0.15908846551818506, 0.13299074662583216, 0.410910357854196, 0.14448190001504763, 0.2642545944878033, 0.27245672579322544, 0.17301086416201933, 0.3052653324391161, 0.14743009395897388, 0.27453236441527096, 0.22854763908045633, 0.1379193671579872, 0.18969575528587612, 0.09650030040315219, 0.312575135912214, 0.2077090958399432, 0.23853553884795733, 0.27343110208000454, 0.2369076790554183, 0.22804967580097063, 0.17055542234863552, 0.1909314761204379, 0.28382544432367596, 0.12132101639040879, 0.3975588785750525, 21.556240694863455, 100.70251423971993, 56.12563746316092, 114.44753796713692, 125.40324211120605, 61.610066005161826, 50.1288800239563, 16.276980297906057, 30.775770664215088, 80.22641617911202, 83.95506272997174, 74.66979585375104, 65.67786107744489, 79.50057261330741, 71.26077338627407, 71.89947959354946, 57.08959232057844, 40.86397136960711, 11.017124482563563, 12.992722289902822, 26.17362264224461, 45.94369861057827, 53.71707221439907, 57.3510981968471, 48.1917222567967, 40.09370797021048, 18.135840552193777, 15.235791002001081, 16.7443300315312, 18.988318511417933, 16.049339941569738, 12.714483414377485, 12.960050123078481, 16.440024988991873, 17.06696789605277, 29.006123542785645, 49.26633759907314, 41.15822410583496, 33.78842272077288, 33.075700828007285, 30.9517685345241, 41.109381743839805, 44.421556745256694, 33.915050165993826, 20.677948440824235, 20.770732947758265, 54.33398887089321, 63.5050482068743, 59.47334902627127, 57.569042342049734, 51.56604889460972, 47.53058726446969, 46.280484744480674, 47.14940561567034, 46.47100782394409, 41.21315656389509, 48.22666127341134, 45.83570623397827, 42.78943879263741, 43.330536706107004, 47.39956160954067, 51.249978814806255, 55.07565001079014, 52.96181344985962, 53.113437039511545, 50.64012152808053, 50.606797967638286, 55.13597774505615, 52.972315652029856, 52.79980230331421, 48.764615127018516, 48.75022540773664, 44.72209760120937, 46.1867743900844, 44.54735040664673, 45.18773112978254, 45.63509784426008, 47.05825219835554, 42.394906180245535, 38.167740276881624, 42.09115873064314, 45.0832336970738, 48.138822146824424, 50.44549553734915, 53.98065907614571, 56.18594782693045, 58.98860100337437, 57.4035918372018, 42.21258544921875, 21.967891931533813, 8.305867910385132, 5.221219922815051, 9.816931741578237, 4.029620800699506, 6.155340952532632, 7.471382311412266, 15.151886292866298, 24.4824241570064, 33.4095687185015, 23.316436529159546, 16.418872935431345, 9.772423318454198, 7.660910929952349, 7.9885245731898715, 6.263880934034075, 6.107579903943198, 8.288050992148262, 5.656091170651572, 4.326664975711277, 13.421222039631434, 26.737036432538712, 22.652242592402867, 19.665033102035522, 19.822661672319683, 31.013888904026576, 5.8978307247161865, 1.8027590875114714, 18.22029764311654, 50.595778124673025, 42.20757927213396, 42.78418595450265, 66.86377961294991, 52.484034470149446, 51.25142056601388, 63.177600451878135, 60.08480439867292, 13.221799186297826, 33.586747782570974, 42.78695133754185, 42.19060482297625, 37.9426394871303, 50.798384121486116, 37.27926370075771, 59.399072783333914, 36.92163297108242, 8.890532766069684, 0.2811142083789621, 0.17868340334721974, 0.20260081280555042, 0.1245160885155201, 0.21876769672547067, 0.15185800993016788, 0.28342654715691296, 0.2864832117089203, 0.21827919222414494, 0.3182231257004397, 0.2125485704413482, 0.14295761180775507, 0.190873882068055, 0.21043824510914938, 0.119414997952325, 0.20032834474529537, 0.3402923686163766], [0.07000594386564833, 0.15640800792191709, 0.18618972413241863, 0.193282830661961, 0.07628640971545662, 0.0397251108661294, 0.1557761561125517, 0.16713572799095086, 0.1914471084518092, 0.2837046379489558, 0.09936031193605491, 0.16905862838029861, 0.1436120452625411, 0.1765313752527748, 0.19401174012039388, 0.12110455014875957, 0.05767333919980696, 0.018741160963795016, 0.1399119802351509, 0.05396383235763226, 0.04946876856099282, 0.11892434928034033, 0.10572027494864804, 1.4527548743145806, 51.47481557301113, 45.09438555581229, 36.161680698394775, 40.33123213904244, 36.53160626547677, 46.949155058179585, 24.67771543775286, 12.40459896836962, 49.52068683079311, 67.96984945024762, 45.094451563698904, 66.03833362034389, 68.56470557621547, 68.99889155796596, 73.92087037222726, 58.349061012268066, 35.52394029072353, 10.29640087059566, 6.6887246285166055, 16.999690226146154, 36.09069790158953, 36.42888409750802, 38.91860430581229, 36.60271760395595, 26.39905868257795, 9.976200086729866, 6.351137280464172, 6.360885168824877, 5.851815845285143, 4.050062835216522, 6.687547777380262, 7.433530262538365, 7.184647960322244, 9.297433171953474, 23.63660430908203, 33.75424453190395, 22.746350731168473, 20.966555765696935, 22.294181074414933, 23.06173815046038, 24.29948503630502, 18.15957386153085, 11.945224029677254, 6.410975166729518, 21.77610080582755, 49.62939487184797, 55.72719996316092, 56.131800515311106, 53.32158769880022, 51.54779250281197, 45.50005613054548, 44.549389702933176, 41.85133123397827, 43.48495694569179, 40.667153222220286, 42.74562692642212, 41.63460649762835, 41.95963280541556, 41.33171367645264, 50.59024041039603, 53.492211137499126, 55.58229528154646, 53.445081506456646, 52.731001240866526, 41.906763962336946, 48.43427692140852, 55.95893628256661, 50.334303515298025, 49.22160162244524, 44.7541948046003, 43.62613044466291, 41.5587808064052, 42.57687950134277, 42.90038067953927, 42.77524014881679, 42.3269111088344, 40.111307757241384, 37.43079348972866, 36.01668569019863, 39.33967556272234, 40.541807719639365, 44.03005007335118, 45.63417025974819, 43.70760154724121, 50.366393770490376, 50.90525436401367, 50.26408502033779, 37.52920430047171, 13.934731262070791, 6.454149969986506, 3.5632064683096747, 3.9783643739564076, 1.8143649676016398, 0.4018268638423511, 0.1560023661170687, 5.452706107071467, 9.452963386263166, 20.024326188223704, 16.387779746736797, 11.256118195397512, 5.130346170493534, 3.8652516092572893, 2.7883370646408627, 4.671521008014679, 4.70410111120769, 5.47906105858939, 5.75992157629558, 9.11023827961513, 2.0674123891762326, 12.157167536871773, 14.886161123003278, 13.435275639806475, 13.205355405807495, 20.000728368759155, 5.262973819460187, 0.12556876774345124, 10.043639302253723, 44.13783400399344, 35.372462613242014, 48.699246474674766, 62.71061202457973, 47.303488867623464, 44.93792601994106, 65.77381569998605, 24.02167694909232, 12.817661557878766, 40.34724078859602, 31.84564733505249, 31.548215797969274, 29.85808038711548, 37.57230050223214, 25.88143699509757, 20.479768446513585, 3.633117505482265, 0.23762318066188268, 0.08535990890647684, 0.03755535604432225, 0.1606949378869363, 0.0099936045506703, 0.09025796143604176, 0.042459162550845315, 0.05562042810821107, 0.022730256464066248, 0.08120261984212057, 0.1162860965622323, 0.10003343224525452, 0.05450285039842129, 0.10651878852929388, 0.055215715896338224, 0.1243056340941361, 0.038675946449594836, 0.08104963055146591, 0.15213283018342086, 0.20847342482634953, 0.2536096285496439, 0.12567533845348017, 0.17631406762770244, 0.12793011032044888, 0.16016516488577637, 0.16491233158324445, 0.11718883312174252, 0.24168803968599864, 0.06363274263484137, 0.17798285665256636, 0.04779473785310984, 0.1316594337778432, 0.1912239654255765, 0.07623195728021008, 0.03192855690472892, 0.18546301312744617, 0.06259661966136523, 0.09074668306857347, 0.03847634180315903, 0.13938019877033575, 0.014175494750296431, 2.7051525797162737, 68.87057917458671, 53.086071559361045, 45.08920567376273, 52.908736160823274, 40.3537859916687, 33.256166390010286, 21.62865308352879, 22.668607337134226, 57.260643073490684, 73.19179589407784, 50.08459915433611, 68.6144129889352, 75.53693798610142, 70.81792994907924, 74.79223006112235, 61.67631013052804, 38.99587174824306, 10.772549629211426, 7.110831167016711, 18.125089951923915, 37.14526769093105, 40.251254899161204, 41.08376373563494, 38.610931124006, 28.03849482536316, 13.613916431154523, 9.56756784234728, 7.917191760880606, 7.585831301552909, 5.643811098166874, 8.35958617074149, 9.91141334601811, 9.765138132231575, 12.47511623586927, 29.486546312059673, 35.653041294642854, 23.02494396482195, 20.668055943080358, 22.247826167515345, 26.290131773267472, 28.416904142924718, 22.2491671698434, 14.900140898568289, 9.00871901852744, 24.0176556791578, 53.297675473349436, 59.032784598214285, 58.29932580675398, 54.712099415915354, 52.41730049678257, 47.40244858605521, 46.56774064472744, 45.53891045706612, 46.99149738039289, 44.929004532950266, 47.29788861955915, 45.64344263076782, 43.8494108063834, 45.91218852996826, 52.708009651729036, 53.23028836931501, 56.113505908421104, 54.79155206680298, 53.43940830230713, 43.5772568157741, 48.665683201381135, 56.89574452808925, 52.010924679892405, 50.80695819854736, 48.56604255948748, 44.21314900262015, 43.07881389345442, 43.61820602416992, 42.955361774989534, 43.97403022221157, 45.12277936935425, 43.96607453482491, 40.03652776990618, 38.45018802370344, 41.3625602040972, 42.35392917905535, 45.37232739584786, 48.59109776360648, 48.538221972329275, 52.801539352961946, 51.977333613804404, 51.63732698985508, 40.793224811553955, 18.114936896732875, 7.393572040966578, 5.186988319669451, 6.05986054454531, 3.2847923679011206, 2.756559044122696, 4.116366454533168, 5.478258975914546, 8.570638571466718, 16.990770476205007, 15.681502308164324, 9.859516382217407, 4.00795544896807, 3.2284350948674336, 4.211059544767652, 5.56878879240581, 4.653126520769937, 4.671362067971911, 3.284938062940325, 6.091841799872262, 2.5024666786193848, 13.191743884767805, 18.95142183985029, 13.405016234942845, 15.142846686499459, 21.53520849772862, 6.689971395901271, 0.15319648810795375, 11.028132166181292, 49.341006415230886, 36.9659103666033, 50.49079431806292, 63.698270661490305, 54.62171030044556, 49.45735052653721, 68.31778744288853, 33.63388088771275, 18.63222680773054, 33.72412756511143, 28.668441091264995, 23.942267724445887, 33.06348589488438, 44.87805339268276, 33.41550942829677, 39.184501443590435, 11.596354978425161, 0.6408194367374692, 0.23936804703303746, 0.08974871411919594, 0.08484859205782413, 0.03102068044245243, 0.09561851700501782, 0.09788782987743616, 0.07432159621800695, 0.053568324473287375, 0.1086619006735938, 0.20699953820024217, 0.1262539659759828, 0.08528644392000777, 0.1434073176767145, 0.11678453481623105, 0.18879905768803187, 0.2341304895068918, 0.19940888908292564, 0.22301624874983514, 0.2730099761060306, 0.3772070077913148, 0.25594826734491755, 0.18819589433925493, 0.4243256465664932, 0.24541140560592922, 0.24822599600468362, 0.29919594526290894, 0.31016720512083595, 0.15003774474774087, 0.36350057327321594, 0.36647912487387657, 0.28669947439006394, 0.22194138142679418, 0.15288793109357357, 0.20934018545917102, 0.276479217090777, 0.24027340273771966, 0.3016411140561104, 0.15698892889278276, 0.2859730619404997, 0.18219450994261674, 4.942658390317645, 90.33573940822056, 63.84166758401053, 55.945192745753694, 55.08492933000837, 49.44361046382359, 62.17319665636335, 31.380323001316615, 17.263207605906896, 60.31182289123535, 75.81962544577462, 53.78125272478376, 75.70790536063058, 80.25047084263393, 76.0290024621146, 80.29236848013741, 64.96899890899658, 42.838253361838206, 12.580826997756958, 8.253107632909503, 21.46161665235247, 39.73331185749599, 43.1747441973005, 43.858509472438264, 42.468421595437185, 31.344630105154856, 17.79546741076878, 14.309398974691119, 13.305126326424734, 13.723052654947553, 12.36841448715755, 14.107203790119716, 14.04516679900033, 13.556876063346863, 15.991906132016863, 37.47129453931536, 44.20675318581717, 30.163130623953684, 24.536772966384888, 25.591156891414098, 28.818023647580826, 35.359907218388145, 22.48944977351597, 15.946313789912633, 10.871102009500776, 29.269296986716135, 56.563832555498394, 61.82446656908308, 60.8748562676566, 57.52703700746809, 54.89875929696219, 50.13393831253052, 47.45812450136457, 45.18575436728341, 48.76943022864205, 45.48076793125698, 48.32372065952846, 46.65339456285749, 45.024048941476, 45.29080070768084, 54.17456940242222, 55.21973480497088, 57.066030979156494, 53.524127687726704, 50.9174519266401, 43.00546523502895, 48.334636279514854, 58.335039547511506, 52.31741319383894, 48.748870509011404, 48.41235188075474, 44.1472418648856, 43.077552795410156, 46.4543217250279, 44.82519844600132, 45.657662119184224, 46.61674281529018, 44.48274258204869, 41.52229928970337, 39.24956784929548, 41.77051673616682, 43.40013681139265, 47.90823228018624, 49.73920767647879, 50.41462469100952, 56.48244135720389, 55.284474645342144, 54.23807941164289, 45.84709085736956, 24.6692681653159, 9.325423989977155, 6.5637617111206055, 9.078633529799324, 7.374843171664646, 5.703716729368482, 8.325389742851257, 10.38765937941415, 14.925824914659772, 25.554463454655238, 24.898159197398595, 19.261021409715923, 12.293154205594744, 9.015431846891131, 8.872038398470197, 10.97023890699659, 10.269406250544957, 9.857098409107753, 10.655429925237383, 13.341982177325658, 9.313485247748238, 18.40317596708025, 19.56476538521903, 14.981504304068428, 16.367185286113195, 24.965742588043213, 8.488133924348013, 0.5374037516968591, 12.764387113707405, 51.16654484612601, 38.05506134033203, 53.060380595070974, 68.15203121730259, 56.759483405521934, 50.37748656954084, 74.73003673553467, 30.446266242436, 17.988575220108032, 52.789456435612266, 43.717902251652305, 43.21747561863491, 40.289664540972026, 55.06288269587925, 44.12799188068935, 55.39595849173409, 19.486457450049265, 0.8299609646201134, 0.38330139219760895, 0.2855130966220583, 0.28017248319728033, 0.15088660562677042, 0.26633213300790104, 0.2468926746930395, 0.2098135586295809, 0.23266990216714994, 0.18801217419760569, 0.3401131810886519, 0.25319743209651535, 0.21391100090529236, 0.260900405900819, 0.27693041573677746, 0.25428667079125133, 0.3086169697344303, 0.19693531681384358], [0.11109856063766138, 0.13875707292131015, 0.12327887490391731, 0.14458378883344786, 0.13543814101389476, 0.09871689788997173, 0.1280690471508673, 0.21733768417366914, 0.08763335405715875, 0.25102682571325985, 0.03665856345157538, 0.2879701262073857, 0.09372251374380929, 0.13831981138459273, 0.0431128156903599, 0.16064326065991605, 0.09792768023908138, 0.1858467518218926, 0.024241538851388862, 0.01866152130865625, 0.06984692239867789, 0.04004557956276195, 0.010743970982730389, 0.12758096334125313, 18.290868759155273, 59.01741518293108, 32.25187723977225, 45.4986560685294, 49.511539527348106, 32.514164788382395, 38.43427664893014, 13.448220133781433, 32.175367150987896, 74.61239678519112, 61.90571185520717, 70.61410454341343, 58.459877831595286, 68.43038300105503, 65.39914798736572, 57.11786106654576, 38.1758314541408, 7.174670781408038, 3.655632708753858, 15.762290750231061, 27.894872086388723, 28.01857434000288, 25.835426024028234, 28.975376026971, 19.523166520254954, 7.390329837799072, 4.153072919164385, 7.227807998657227, 5.8122645275933404, 4.662781476974487, 4.079963539327894, 4.342073040349143, 5.185550042561122, 11.381167531013489, 27.22182788167681, 17.193034274237498, 12.109640989984785, 12.041640707424708, 13.924830947603498, 12.669717907905579, 10.046598366328649, 5.856394708156586, 3.260094561747142, 13.014234781265259, 32.63907602855137, 43.4683472769601, 56.28809329441616, 57.264485427311485, 54.95143011638096, 52.27465745380947, 47.85870552062988, 41.837108271462576, 45.07982560566494, 41.22294657570975, 40.195207255227224, 40.80299745287214, 40.196982519967214, 40.40524435043335, 45.94958026068551, 52.038939816611155, 52.5611629486084, 53.45230763299124, 52.57949924468994, 51.08290243148804, 42.56512662342617, 50.112044538770405, 54.397005558013916, 50.79567779813494, 47.72742278235299, 42.47437967572893, 41.376362800598145, 41.45767062050955, 42.810700280325754, 39.26658051354544, 42.28393997464861, 41.73289571489607, 40.74085276467459, 35.77364117758614, 36.70154183251517, 37.72005047116961, 38.95962299619402, 40.923600809914724, 44.31108386175973, 46.7237867627825, 51.894472871507915, 52.84828335898263, 51.796148913247244, 41.363550322396414, 18.39398350034441, 9.210717047963824, 2.842486764703478, 3.512203867946352, 2.3986616773264746, 2.5861946429525102, 2.0998335523264746, 4.164011555058615, 5.851881853171757, 13.36375435761043, 13.403703893933978, 8.315507667405264, 7.487784402711051, 4.157646570886884, 4.561016857624054, 3.887931832245418, 5.11740471635546, 3.780959103788648, 3.1342909123216356, 5.993447056838444, 7.368013092449733, 5.937329496656146, 10.19453159400395, 10.28237245764051, 7.167660049029759, 7.0420578973633905, 2.7176560802119116, 0.4433753543666431, 3.5841120779514313, 36.959472860608784, 33.94025823048183, 62.58456475394112, 49.46110602787563, 41.07527303695679, 59.94345024653843, 59.53345789228167, 11.044567261423383, 34.05132865905762, 48.88959584917341, 31.821929659162247, 36.82993759427752, 38.36223772593907, 31.68213537761143, 23.646738256726945, 21.947544131960186, 1.464489404644285, 0.39077217131853104, 0.07410962866353137, 0.016295846285564557, 0.1142815819808415, 0.16279048472642899, 0.06872007929320846, 0.14074091932603291, 0.10923941539866583, 0.09020783126886402, 0.14416650336767944, 0.04692469311079808, 0.04187521531379648, 0.06729215662926435, 0.11998399027756282, 0.08972331655344792, 0.20931461825966835, 0.1692300806088107, 0.10712172117616449, 0.15460391901433468, 0.15900542640260287, 0.18686094454356603, 0.09980719509933676, 0.2096664115254368, 0.16147633881441184, 0.1379900976483311, 0.24516724156481878, 0.17157699753131184, 0.17105407773384027, 0.11112439246582133, 0.2188056404037135, 0.1340144116963659, 0.1028687111767275, 0.11704530939459801, 0.11029443557241134, 0.05842590917434011, 0.2956156145249094, 0.06421744304576091, 0.0453692906802254, 0.030290865139769654, 0.22164605584527763, 0.0402323632900204, 0.09093452191778592, 27.87169984408787, 74.26730755397251, 37.516096523829866, 45.06935814448765, 41.15570885794503, 34.03599745886666, 29.088638612202235, 22.727790355682373, 45.31861434664045, 73.98261206490653, 64.19437898908342, 74.20837293352399, 68.42334447588239, 69.85825170789445, 72.78049727848598, 61.350828715733115, 42.16951356615339, 7.8112247841698785, 3.68923202582768, 16.707742554800852, 30.6879106930324, 30.2458176612854, 30.07707371030535, 31.157921586717876, 21.961206027439662, 10.066607441220965, 4.981453222887857, 7.969364047050476, 5.833346664905548, 6.42413375207356, 6.647737205028534, 8.256089278629847, 9.422104699271065, 14.973274162837438, 30.907584939684185, 19.173319510051183, 11.445148280688695, 10.581782494272504, 14.39054959160941, 15.583392007010323, 11.72191674368722, 8.247946858406067, 6.292885320527213, 13.390457153320312, 32.48135886873518, 47.02497032710484, 58.89787837437221, 60.73699705941336, 58.09323181424822, 53.78265973499843, 48.46437999180385, 45.45828356061663, 47.424793992723735, 44.430252415793284, 43.93685041155134, 42.9044314793178, 44.30716160365513, 42.389708927699495, 48.08176701409476, 54.514381476810996, 54.54703801018851, 54.57946177891323, 55.35178531919207, 52.65140267780849, 43.695077419281006, 50.40036351340157, 56.618372440338135, 50.839236055101665, 48.44244105475289, 43.74251971926008, 43.74032061440604, 41.76784862790789, 44.92169502803257, 41.889237131391255, 45.58088452475411, 44.2377039364406, 43.90401322501046, 38.80620329720633, 39.42584017344883, 38.89805848257882, 41.89092901774815, 43.60946866444179, 46.04102897644043, 49.81671135766165, 53.52962023871285, 57.790272985185894, 55.932821478162495, 45.165496894291465, 21.08132437297276, 10.62535377911159, 5.122590243816376, 5.771474259240287, 3.5459636449813843, 2.886105384145464, 3.664404809474945, 3.7099450400897434, 5.414448022842407, 13.113436818122864, 11.338462165423802, 7.236023374966212, 5.762317402022226, 3.8985617075647627, 5.529692147459302, 5.012988924980164, 5.797900864056178, 5.0911600674901685, 4.259126314095088, 5.792874710900443, 6.530470286096845, 5.523131310939789, 7.958201766014099, 11.363916022436959, 7.527786919048854, 7.492504835128784, 3.125202451433454, 0.7256764833416257, 3.5279317668506076, 41.26747063228062, 37.934402397700715, 60.20155497959682, 53.530926500047954, 46.72042383466448, 61.81856060028076, 63.23085839407784, 18.372497933251516, 26.85119012423924, 42.16523347582136, 25.00465076310294, 30.621176719665527, 47.06756278446743, 38.251469544001985, 37.87790659495762, 38.46487998962402, 1.5459810261215483, 0.5764306432434491, 0.07718929555267096, 0.05423288167055164, 0.12313973451299326, 0.10622611601970025, 0.06631935454372849, 0.29797279089689255, 0.1467046993119376, 0.18271600481654915, 0.11565208701150757, 0.1752019351614373, 0.1587728788810117, 0.07001297348844153, 0.09564790435667549, 0.12574152275919914, 0.1289835495076009, 0.14176549363349164, 0.19677157274314336, 0.2350583454327924, 0.224083435056465, 0.2573858116354261, 0.14719842853290693, 0.3242544877742018, 0.16747222707739898, 0.25304894149303436, 0.2486673423222133, 0.22538562518145355, 0.41418743772166117, 0.2744367724018437, 0.46731309273413246, 0.2405452781489917, 0.14425697922706604, 0.16493356972932816, 0.2294041674051966, 0.21426845315311635, 0.404906869999, 0.15974196259464535, 0.18793296201952867, 0.2390246811722006, 0.3317032280777182, 0.13564000518194266, 0.3691225073167256, 42.80849422727312, 90.63079466138566, 47.50048419407436, 63.60597079140799, 62.330045291355674, 45.84754943847656, 47.91668128967285, 18.778776475361415, 41.428602831704275, 81.80895873478481, 70.46398176465715, 82.9641523361206, 71.22540705544608, 77.68646049499512, 76.35697828020368, 66.1114147731236, 45.10532202039446, 9.47307755265917, 5.799271830490657, 19.554263183048793, 33.61244569505964, 34.529024260384695, 32.296911988939556, 34.76053128923689, 25.167664187295095, 15.52259179524013, 9.371076260294233, 12.849271518843514, 12.55062404700688, 12.65964823109763, 11.871105858257838, 13.49552868093763, 11.859140191759382, 19.637500865118845, 37.44603088923863, 26.466914790017263, 16.45034827504839, 13.931926795414515, 16.350919553211757, 20.133081129619054, 14.330151506832667, 9.439687115805489, 8.375397665160042, 18.314075742449077, 35.61953360693795, 48.10454320907593, 60.06819125584194, 61.55309077671596, 57.64303718294416, 54.84324319022042, 50.927294049944194, 44.030845642089844, 47.41505609239851, 44.957113470349995, 43.26869426454817, 44.271242891039165, 44.69137961523873, 43.668469292776926, 49.01605306352888, 53.12761831283569, 53.46945578711373, 55.74741922106062, 52.35214376449585, 50.714863300323486, 39.719002042497905, 48.98991394042969, 56.104313441685264, 50.95593105043684, 49.065982818603516, 43.296417576926096, 44.32653318132673, 42.33273369925362, 45.896582875932964, 44.774650301252095, 47.37477043696812, 45.94733599254063, 45.79388850075858, 41.908813680921284, 40.398584502083914, 41.29018429347447, 44.594879559108186, 45.38260725566319, 48.93892111097063, 51.54828929901123, 56.37095403671265, 59.30032498495919, 58.79250199454171, 49.60678195953369, 25.711949586868286, 13.517850637435913, 6.7276784011295865, 7.064839737755912, 7.908394472939627, 9.545364873749868, 10.397443311555044, 11.181988733155386, 13.085207155772618, 19.337906701224192, 20.021786621638707, 17.958110843385967, 17.592309032167705, 11.104265315192086, 9.850141525268555, 6.656966584069388, 8.417228426252093, 9.053195306232997, 8.936912860189166, 11.19690043585641, 12.511919106755938, 13.353569167000906, 14.976197617394583, 12.875632115772792, 8.525599479675293, 9.578545127596174, 5.045189048562731, 0.8680267791662897, 5.354623598711831, 44.54272985458374, 38.63763305119106, 67.51497868129185, 58.40145737784249, 48.722630637032644, 67.99141665867397, 67.07119723728725, 15.636787176132202, 43.03859077181135, 64.31322792598179, 41.04273462295532, 48.859652587345664, 52.13515499659947, 51.802940777369905, 49.54053783416748, 58.956868580409456, 4.058809748717716, 0.6438891291618347, 0.265865083783865, 0.19094602391123772, 0.23834761178919248, 0.32911467126437594, 0.18477412366441318, 0.26589884768639294, 0.40717738387840136, 0.29940072713153704, 0.2136022946132081, 0.19190402036266668, 0.31248730633940014, 0.17687358760407992, 0.2501167745462486, 0.298789774200746, 0.26921308413147926, 0.28844173518674715, 0.2898029035755566], [0.22708110777395113, 0.10136437868433339, 0.15131406911781856, 0.1570702309587172, 0.09131534291165215, 0.11130602950496332, 0.10862308168517691, 0.1417161641376359, 0.17767165335161345, 0.19263799169233867, 0.009730180293055517, 0.20707569697073527, 0.22263833188584872, 0.1902186886540481, 0.12115069053002767, 0.25356131685631617, 0.14765711820551328, 0.04783824212583048, 0.03206759551540017, 0.05514381493308714, 0.05825239419937134, 0.028030156091387783, 0.038221596008432765, 0.15785946218030794, 5.096008607319423, 57.4848301751273, 46.32871913909912, 49.0277955191476, 77.88990374973842, 35.92148494720459, 34.87715332848685, 24.28307339123317, 9.898821473121643, 55.27118968963623, 65.35479763575962, 70.01931095123291, 70.15336949484688, 70.42065974644252, 70.73262691497803, 64.22491632189069, 35.224719592503135, 3.122911717210497, 1.9565113229410989, 12.560495700154986, 22.392246212278092, 19.923707587378367, 19.962337834494456, 21.96697129522051, 16.545375313077653, 12.60542709486825, 7.485164931842259, 4.4233070356505255, 2.619841077498027, 1.4208702423742838, 2.1297121090548377, 4.122427020754133, 5.524414990629468, 20.312231745038712, 22.953823941094534, 8.518193568502154, 4.094219505786896, 2.8990659458296637, 3.9585928406034196, 5.411288329533168, 2.332676806620189, 1.9721910187176295, 5.327307190213885, 21.980513334274292, 31.195792743137904, 39.59977790287563, 54.11098643711635, 58.86732019696917, 55.756712436676025, 53.85745014463152, 50.686598028455464, 46.5962803704398, 43.36628866195679, 42.92203821454729, 43.11284964425223, 41.021497453962056, 40.07091440473284, 42.58550916399275, 49.710268429347444, 53.35717984608242, 53.27891533715384, 53.96212475640433, 50.96790279660906, 47.7975127356393, 44.645688261304585, 48.70262329918997, 52.68222141265869, 51.13262374060494, 46.47136913027082, 41.53548002243042, 42.1113988331386, 38.84603384562901, 43.183610098702566, 41.796127796173096, 42.871396269117085, 40.739251204899375, 38.271869455065044, 34.88269451686314, 36.96098061970302, 40.247231892177034, 42.90262494768415, 44.02171570914132, 44.553291116442, 45.833753790174214, 48.899375438690186, 52.57418039866856, 52.163090229034424, 41.024464334760395, 15.294433798108782, 10.806745188576834, 4.271227470466068, 1.6515685660498483, 0.775326030594962, 2.9296282487256184, 3.7923246196338107, 0.7510032100336892, 6.286584607192448, 5.895034943308149, 13.53073867729732, 6.531055671828134, 9.24447226524353, 8.800980908530098, 7.288057565689087, 10.316977960722786, 5.018214404582977, 5.592466516154153, 4.794388609273093, 5.041180372238159, 3.441439939396722, 4.207152485847473, 6.681320888655526, 6.099663734436035, 5.416472554206848, 0.9645689044679914, 0.8359508003507341, 0.8259180358478001, 2.72330670271601, 34.257988929748535, 38.096507344927105, 66.93790994371686, 44.305723326546804, 44.47544697352818, 69.77630465371269, 37.315258843558176, 17.836076157433645, 64.24818583897182, 36.66002287183489, 35.17966399874006, 35.87211104801723, 49.17199148450579, 36.81785467692784, 27.808832543236868, 17.363602127347672, 2.1503895137991225, 0.35093519038387705, 0.17743128910660744, 0.034849266787724834, 0.08740037227315561, 0.10725280735641718, 0.09001391953123467, 0.17678833646433695, 0.07573805842548609, 0.1275869073080165, 0.0798707709514669, 0.18027810991874763, 0.06918292160012893, 0.09765741295580353, 0.06976446003786155, 0.07963455255542483, 0.10229553907577481, 0.1426346834216799, 0.20389771035739354, 0.21723361047250883, 0.2609215761934008, 0.2335907013288566, 0.19628471029656275, 0.2210106078003134, 0.08154281694442034, 0.04402149621663349, 0.12328914792409965, 0.17090256086417607, 0.1068858081208808, 0.16942127820636543, 0.16474792254822596, 0.19721385543899878, 0.15365976467728615, 0.1366358231753111, 0.1691104006022215, 0.12109146799360003, 0.1263903650854315, 0.06286285644663231, 0.2038667013070413, 0.07842969827886138, 0.12513180476214203, 0.026749914877914956, 0.20188015433294432, 7.969291959490095, 72.40634373256138, 51.67921073096139, 53.24847180502755, 73.57938030787876, 28.881936652319773, 33.26196118763515, 23.13980984687805, 26.429931265967234, 67.66900634765625, 71.39185115269252, 76.84606197902134, 73.13697460719517, 73.48145934513637, 74.259094783238, 69.67458302634103, 39.15126126153128, 4.003601099763598, 2.5765868042196547, 11.847456795828682, 24.417889288493566, 21.178481033870153, 22.06754125867571, 24.360858474458965, 18.124103307724, 11.193714686802455, 6.045089977128165, 5.639569657189505, 2.423458061047963, 3.806717813014984, 3.636957036597388, 5.540817081928253, 10.324377792222158, 21.88766281945365, 29.1211005960192, 7.904197760990687, 3.222145672355379, 2.3490812863622392, 4.756939555917468, 4.935114817959922, 2.6286800546305518, 3.7844427568571906, 7.094063426767077, 23.868408373423986, 33.41319220406668, 44.79308039801461, 57.54935809544155, 62.624433517456055, 58.78572055271694, 56.31094939368111, 52.39478485924857, 47.42690971919468, 47.36339623587472, 47.69871282577515, 45.60877111979893, 44.353693689618794, 41.5047481400626, 45.682814598083496, 52.980768135615754, 55.72464650017874, 54.58777182442801, 56.13987084797451, 53.07100439071655, 48.35210405077253, 46.77285146713257, 51.29696600777762, 52.66699096134731, 53.40726593562535, 48.32933827808925, 44.206919942583355, 43.55032212393624, 43.374619552067344, 44.80603184018816, 44.74954298564366, 45.39308513913836, 44.76910216467721, 43.22914859226772, 39.06574630737305, 39.60316514968872, 41.30579342160906, 42.18496635981968, 46.61991466794695, 48.86266810553414, 52.09941346304757, 52.284610748291016, 56.10951764242989, 54.75972931725638, 46.24399627958025, 17.28684537751334, 13.134418640817914, 6.491199936185565, 4.091141019548688, 3.192369384425027, 3.189289595399584, 3.0074155032634735, 2.007150662796838, 5.211177170276642, 5.588445246219635, 13.588790876524788, 7.3753668921334405, 10.203513877732412, 7.751855901309422, 8.491800836154393, 8.963038955415998, 6.77024827684675, 7.486933248383658, 6.175365660871778, 6.72191139629909, 4.2192666700908115, 2.3476914295128415, 2.821805017335074, 4.323389334338052, 5.543641090393066, 1.3039317343916212, 1.3793436821017946, 1.2285127299172538, 3.094477083001818, 35.48867123467581, 39.2802927834647, 66.307875088283, 48.86140700748989, 47.050400733947754, 67.16848591395787, 44.26744570050921, 16.890110186168126, 48.68850108555385, 36.527805600847515, 23.916429110935756, 37.484753199986045, 53.36092145102364, 46.70523854664394, 42.29111051559448, 28.068787234170095, 2.6305855980941226, 0.35638662214790073, 0.08969754579343966, 0.16807917665157998, 0.07256422444645848, 0.07206565048545599, 0.0906916470932109, 0.3736749344638416, 0.22122471274009772, 0.17267417508576596, 0.09688086355371134, 0.21801157801279, 0.08959167397447995, 0.1816610592816557, 0.13757241863225186, 0.19178210119051592, 0.13113840030772345, 0.11676127463579178, 0.2880998078201498, 0.3619095172200884, 0.309744586369821, 0.30048855447343414, 0.30276794359087944, 0.3017562750194754, 0.2312241340322154, 0.2871590597288949, 0.2250944793756519, 0.3198498184127467, 0.40745949159775463, 0.2573862187564373, 0.29380327463150024, 0.262120493288551, 0.3695579910916941, 0.25738100760749405, 0.29398153935159954, 0.45042829162308146, 0.31437197806579725, 0.1275561832423721, 0.3476172627082893, 0.2409802462373461, 0.31022726904068676, 0.15138771730874265, 0.5196483901568821, 13.427910549300057, 92.80778339930943, 67.07309409550258, 67.62817178453717, 93.78455420902797, 46.393816811697825, 44.709257330213276, 32.50459711892264, 16.531140191214426, 69.50850718361991, 74.96370465414864, 83.56451143537248, 78.68542385101318, 78.92499773842948, 78.78699956621442, 76.40330192020961, 41.74137599127633, 4.924011596611567, 2.7387942373752594, 14.516969459397451, 26.97550208227975, 25.206155470439366, 25.150370121002197, 29.489784172603063, 22.454755680901663, 18.11583321435111, 14.247859648295812, 11.732859287943159, 7.659428358078003, 10.574895092419215, 11.459204486438207, 12.410359025001526, 13.347241963659014, 29.775844982692174, 35.08058616093227, 17.031109980174474, 7.625092966215951, 6.7430291431290765, 8.537853496415273, 8.429131558963231, 4.203624103750501, 5.047861933708191, 9.592554433005196, 26.690907342093332, 36.98960024969918, 43.8395026751927, 56.234512260981965, 64.44278403690883, 60.51553017752511, 57.71217523302351, 53.66067716053554, 50.39823389053345, 45.85002647127424, 46.84216322217669, 46.14094407217843, 46.16221250806536, 42.14440972464425, 46.06151226588658, 51.74858849389212, 54.11335577283587, 54.497153418404714, 56.64901052202497, 51.471303258623394, 48.873983246939524, 44.92085082190377, 49.97114896774292, 54.04576369694301, 51.54973105021885, 49.16605077471052, 45.46770879200527, 45.41456202098301, 42.90846143450056, 45.96303544725691, 47.079075949532644, 47.67022868565151, 46.78264147894723, 45.27537570680891, 41.62340252740042, 41.30020359584263, 45.62467207227434, 46.18099001475743, 47.19207797731672, 51.01546669006348, 53.307663508823936, 55.1453925541469, 57.91481944492885, 58.22822489057268, 48.339020592825754, 19.392693247113908, 14.925852707454137, 9.834343927247183, 6.074202060699463, 6.6394423586981635, 9.238337005887713, 12.546792984008789, 10.766003557613917, 14.84015188898359, 11.904402494430542, 21.03175245012556, 15.269943135125295, 18.542179891041346, 17.964055027280533, 15.442687511444092, 16.10474487713405, 9.325474364416939, 10.259055171694074, 8.160720041819982, 8.812706862177167, 4.912815008844648, 9.58592324597495, 10.600499204226903, 7.847913009779794, 6.831976073128836, 1.7757204983915602, 1.7775738218000956, 1.3614070160048348, 4.468690931797028, 42.681053842817036, 40.92890228543963, 74.31627150944301, 50.79772751671927, 52.41144316537039, 74.50314331054688, 46.46040834699358, 24.502322060721262, 73.2581511906215, 44.56308460235596, 45.66432196753365, 49.04490198407854, 60.81872871943882, 54.26863064084734, 54.728247029440745, 40.248930726732524, 3.9848861268588474, 0.5110053196549416, 0.254195149987936, 0.2377719698207719, 0.19613092711993627, 0.27034979313611984, 0.2074032529656376, 0.5213725747806686, 0.27215051651000977, 0.3062827278460775, 0.2049826064280101, 0.40584248836551395, 0.1989607167031084, 0.2705770752259663, 0.2973947062024048, 0.3120267710515431, 0.35477740849767414, 0.2529812236981732, 0.4006403503673417], [0.2197666224092245, 0.1425826804978507, 0.15848060670707906, 0.10618330724537373, 0.23837898724845477, 0.09129436260887555, 0.21561254960085663, 0.10077341539519173, 0.15982851652162416, 0.09380195662379265, 0.22748632888708795, 0.1670835893601179, 0.13087271313582147, 0.06366495269217662, 0.13580336927303246, 0.09769716832254614, 0.08244496996381454, 0.05851337912359408, 0.0584441889077425, 0.06988122912922076, 0.08807396755686828, 0.0866693729268653, 0.0243175025430641, 0.12336358321564538, 0.5468565587486539, 35.37620421818325, 58.592345237731934, 27.363911594663346, 54.09884098597935, 72.03361456734794, 30.31128706250872, 47.549323081970215, 20.164499146597727, 17.708173717771256, 63.18144975389753, 71.43300533294678, 71.93655518123082, 70.73742812020438, 72.81391116550991, 64.61131954193115, 42.67349420275007, 4.8222061565944125, 0.09448242546724421, 6.944821766444615, 12.565316881452288, 11.390139392444066, 13.557971273149763, 13.27901325907026, 10.983898196901594, 5.235974856785365, 2.2835567338126044, 3.264390502657209, 1.487968344773565, 0.996120131441525, 4.105175946440015, 3.3608781823090146, 8.078346541949681, 22.659414870398386, 18.15938799721854, 3.8605876309531073, 1.1434262841939926, 1.8984148289476122, 0.5472917439682143, 1.2978428325482776, 0.37641342037490433, 1.7329603071723665, 9.168840255056109, 22.045678751809255, 28.862648453031266, 27.40192518915449, 32.56601572036743, 51.30557829993111, 54.13208811623709, 52.396052905491416, 53.49657460621425, 46.30853462219238, 45.12111527579171, 44.75979505266462, 41.61948026929583, 40.74841935294015, 38.99568067278181, 45.88979796000889, 49.835749421800884, 50.88153668812343, 51.2930645942688, 52.84186322348458, 51.355820723942344, 48.27874149594988, 46.926695006234304, 47.034760338919504, 52.5711544581822, 51.34457506452288, 47.02399410520281, 40.39785146713257, 40.8215526172093, 40.838964802878245, 42.956101758139475, 43.06500087465559, 42.99622065680367, 41.80226305552891, 36.45942143031529, 36.967223576136995, 38.09096963065011, 40.501650605882915, 45.783778871808735, 46.70575271333967, 46.75011696134295, 48.688091141836985, 47.72578648158482, 43.91560629435948, 52.82649728230068, 31.622697012765066, 17.898377180099487, 7.063510026250567, 5.375764795712062, 1.32723197553839, 4.132808932236262, 3.407159047467368, 5.7257234113557, 1.722757746066366, 3.4295724162033627, 6.326657908303397, 7.640240039144244, 9.158629008701869, 3.1448784470558167, 8.66621104308537, 7.686092938695635, 10.850623062678746, 8.645841530391149, 7.4339627879006525, 5.686892535005297, 6.053291022777557, 7.732743144035339, 2.7648699581623077, 2.1994837479931966, 1.2217950161014284, 3.1633363366127014, 0.14268211301948341, 1.412706760423524, 0.4183262027800083, 1.0955207347869873, 30.326079777308873, 45.40561274119786, 61.509692328316824, 56.322622367313926, 43.69319445746285, 68.46708338601249, 19.675821917397634, 40.96482447215489, 52.55581283569336, 27.14548454965864, 36.558436734335764, 49.65179933820452, 71.42227731432233, 37.01837968826294, 35.00468751362392, 17.193626608167374, 0.45852275299174444, 0.13820034850920948, 0.055014214744525294, 0.09215897907103811, 0.09534843971154519, 0.1032045181574566, 0.053732312816594324, 0.13060961796769074, 0.042187921569815705, 0.16100521838026388, 0.11107171100697347, 0.12031506108386175, 0.09340430117611374, 0.06394809857010841, 0.06017597990908793, 0.14412793543721947, 0.06303318230701344, 0.18972860995147908, 0.10434158000030688, 0.27711717571531025, 0.1845896164221423, 0.2631780579686165, 0.15455944782921247, 0.2998200889144625, 0.1338497041059392, 0.14158845027642591, 0.16956637613475323, 0.27286466104643686, 0.18418022910399096, 0.16674491896161012, 0.18445328516619547, 0.08720652160367795, 0.1707232240587473, 0.20460812295121805, 0.10129917146904127, 0.12515051875795635, 0.07159645030541079, 0.06776930923972811, 0.06381765021277325, 0.01395897677035204, 0.04199318880481379, 0.02326235005498997, 0.1544694605150393, 0.8258512137191636, 45.42450836726597, 75.89263016836983, 30.40778364453997, 67.2087368283953, 53.32940789631435, 28.440621818814957, 43.500170026506694, 22.900998524257115, 34.74647855758667, 69.1488892691476, 78.95327690669468, 76.69125611441476, 79.08299282618931, 79.07318196977887, 69.21104785374233, 47.4917642048427, 5.800098666122981, 0.24326397797891072, 9.27578432219369, 12.954462034361702, 13.251910073416573, 16.012488433292933, 13.480333839144025, 13.502207636833191, 7.854022213390895, 3.5272988293852126, 3.257103796516146, 2.528008908033371, 2.171779760292598, 3.9071514180728366, 6.117967026574271, 11.648833853857857, 25.47228537287031, 20.715932505471365, 5.496322555201394, 1.2489746319396156, 1.2099177220038004, 0.7377275366868291, 2.4643662316458563, 2.113940132515771, 5.481346581663404, 12.71178925037384, 22.627361093248638, 32.86523641858782, 32.531434535980225, 41.43163224628994, 56.62360095977783, 56.98445217950003, 56.142928055354524, 53.25504132679531, 49.621849128178184, 46.15045963014875, 45.00772762298584, 44.18745803833008, 43.1734379359654, 41.93350063051496, 44.92637116568429, 53.221130643572124, 52.378887380872456, 53.5922269821167, 53.45882504326956, 54.20219544001988, 50.05499982833862, 48.39746536527361, 50.3522298676627, 54.75501149041312, 53.12994595936367, 48.43792125156948, 41.4839973449707, 43.59543330328805, 41.43276827675955, 43.052230085645405, 44.38578741891043, 46.60516364233834, 44.12491730281285, 40.70901264463152, 37.664961678641184, 40.98414741243635, 43.34854643685477, 46.121124335697715, 48.64835091999599, 49.158654417310444, 49.006245681217735, 52.16153383255005, 50.62622513089861, 57.054163455963135, 35.97651815414429, 20.012079988207134, 9.279736110142299, 7.296125292778015, 3.1630086856228963, 5.232052598680768, 3.5758617435182845, 3.577072684253965, 1.9559778315680367, 3.1047938551221574, 5.909636582647051, 7.4875863790512085, 9.083162018230983, 7.176582404545375, 11.79565623828343, 9.139051590647016, 13.258948598589216, 9.977151121412005, 9.200887952532087, 8.69250476360321, 9.149143849100385, 9.362902573176793, 3.3599775220666612, 0.8934393269675118, 0.7141231490033013, 3.502500057220459, 0.2874693402222225, 2.9914561424936568, 0.914279580116272, 0.5335086349930082, 33.92463173185076, 46.84156220299857, 65.8183536529541, 57.061709199632915, 45.05637543542044, 70.75074781690324, 28.1587108203343, 33.078368936266216, 56.43212250300816, 23.875408683504375, 27.026300362178258, 51.56181744166783, 73.40084634508405, 48.28149993079049, 49.13664947237287, 22.68996957370213, 0.5534429624676704, 0.13534759730100632, 0.027474520727992058, 0.12429807521402836, 0.056040831442390165, 0.07240938954055309, 0.0939174432839666, 0.18322390184870788, 0.10371008102915116, 0.18668880020933493, 0.13327556848526, 0.17361158478472913, 0.1473446935415268, 0.19128576639507497, 0.0373334343811231, 0.19447684873427662, 0.12256778377507414, 0.2701443870152746, 0.1055129553590502, 0.34038910056863514, 0.27546619144933565, 0.3023169349346842, 0.32527687719890047, 0.31242645531892776, 0.39992474019527435, 0.32129781214254244, 0.20309132577053138, 0.31270090916327065, 0.24284339483295167, 0.2738142300929342, 0.18765169568359852, 0.32326751787747654, 0.24880114942789078, 0.4878787291901452, 0.2780092592750277, 0.2718966358474323, 0.22009291632899217, 0.12916105426847935, 0.21365109485174927, 0.12628531429384435, 0.16407731281859533, 0.14463625316108975, 0.4229071283979075, 1.1871005977903093, 62.8426764351981, 84.48321614946637, 43.9638545853751, 68.20269053322929, 86.52963433946881, 39.381559303828645, 64.20373821258545, 26.257079192570277, 24.53053174700056, 73.20353834969657, 80.95342009408134, 84.89553615025112, 79.76272119794572, 84.1388773236956, 71.5020843233381, 53.15858990805489, 6.0877527850014825, 1.2012142347437995, 11.734725747789655, 16.780993938446045, 17.20601177215576, 19.668343918664114, 17.645334209714616, 18.76997831889561, 13.496977380343846, 7.995850580079215, 8.804083279200963, 7.627158318247114, 8.31253296988351, 11.933025598526001, 12.847755943025861, 18.982407331466675, 32.277377128601074, 27.544861793518066, 10.246307832854134, 5.51986392055239, 2.9633020418030873, 3.6731599739619663, 4.499891383307321, 2.7884588752474104, 5.6979705691337585, 13.749902231352669, 27.10221290588379, 34.71137973240444, 33.38739354269845, 35.70098039082119, 55.071015562329976, 55.48533664430891, 55.36455610820225, 54.43966054916382, 49.81762851987566, 47.52519198826381, 45.32408605303083, 43.83240161623274, 44.28657061713082, 41.42257179532732, 45.61594860894339, 52.98361689703805, 51.298994881766184, 53.69937515258789, 53.88760532651629, 53.75628784724644, 50.82786880220686, 46.73200648171561, 47.1908655166626, 55.10685437066214, 53.768673011234824, 49.978632177625386, 43.440127168382915, 46.223203795296804, 43.34057685307094, 45.31399032047817, 46.24434716360909, 48.18600041525704, 46.25592286246163, 43.734925338200156, 41.58449956348964, 43.159246240343364, 46.73935420172555, 49.871841839381624, 52.345734051295686, 51.27805301121303, 53.15342392240252, 56.63693107877459, 56.01821831294468, 58.63919694083077, 36.32178109032767, 23.18954678944179, 11.868554132325308, 10.367877858025686, 5.9074135933603555, 9.223244650023323, 9.426548072269984, 12.255722522735596, 11.711273840495519, 11.930935059274946, 14.803107568195887, 13.938782930374146, 17.61819975716727, 12.217992067337036, 20.26022447858538, 13.607965299061366, 17.411753143583024, 11.842061519622803, 12.334482959338597, 10.290219579424177, 11.58054608958108, 12.081981948443822, 4.571989365986415, 7.00380676133292, 3.1782119955335344, 4.835743418761662, 0.40417758056095665, 3.5728019305637906, 0.6075648697359222, 2.5212978167193274, 36.73181165967669, 49.716709409441265, 68.84689971378872, 60.67590849740164, 52.743768555777415, 76.1735041482108, 28.370323419570923, 49.61854525974819, 55.569944858551025, 34.84246792112078, 50.6538268498012, 60.00002942766462, 74.8719675881522, 55.15875046593802, 60.22309439522879, 32.53356763294765, 0.43027154036930626, 0.23605362059814589, 0.129336238439594, 0.16952869029981749, 0.3483547759907586, 0.21283876629812376, 0.26259997327412876, 0.32752168817179544, 0.1606190912425518, 0.27793548894780024, 0.30746096319385935, 0.2166359025452818, 0.15938784873911313, 0.37424813370619503, 0.28806441543357714, 0.38336664012500216, 0.2411251270345279, 0.4019429476133415, 0.18643873291356222], [0.2411704531737736, 0.33554474051509586, 0.3469501813607556, 0.196791426677789, 0.22317936856831821, 0.17634996213018894, 0.13615474184708937, 0.07887292413839272, 0.11615424363740853, 0.1760162314666169, 0.15671237158988202, 0.17178735695779324, 0.16896557408784116, 0.14532006718218327, 0.12923637165554933, 0.11249379148440701, 0.07573851982929877, 0.1236087650592838, 0.17196924505489214, 0.029958912237946476, 0.09945306767310415, 0.10670697343136583, 0.20291709154844284, 0.07824778304036174, 0.16347352521760122, 12.607528924942017, 57.02537359510149, 53.175255162375315, 40.63596623284476, 67.19323539733887, 55.15217399597168, 26.07711911201477, 53.99699429103306, 8.598454816000801, 42.906595843178884, 77.92889009203229, 66.92376341138566, 69.70837211608887, 68.91597175598145, 60.68059158325195, 51.710759026663645, 5.160863961492266, 0.33957499425326076, 2.8635717247213637, 1.5166678790535246, 7.3752374819346835, 8.058161156518118, 7.302619252886091, 3.6452177933284213, 1.5988184937408991, 2.0642468333244324, 0.8268602224332946, 1.531205790383475, 4.688474612576621, 2.600037842988968, 3.9513992837497165, 11.550080844334193, 22.228610924312047, 12.777870961597987, 1.534566004361425, 2.6306064426898956, 4.107718118599482, 1.3842206661190306, 1.0685214464153563, 2.236515692302159, 0.3588549154145377, 5.725800275802612, 17.28217445101057, 22.596297434398107, 23.519568852015905, 11.841034923280988, 28.19726984841483, 55.669425691877095, 46.860298020499094, 56.726437773023335, 53.76879807880947, 48.29051521846226, 45.39619793210711, 43.506395612444194, 42.63372271401541, 40.611783027648926, 47.29415396281651, 50.99799197060721, 50.58565807342529, 51.02218907220023, 52.38963624409267, 51.599348136356895, 52.018317563193186, 43.21351861953735, 33.10961498532976, 54.198471205575125, 49.99633271353585, 48.73927852085659, 37.34616443089077, 39.47941425868443, 42.40321969985962, 41.623277459825786, 41.94297102519444, 41.26282576152256, 35.71191685540335, 35.88895695550101, 37.14704990386963, 41.83615289415632, 45.28181668690273, 48.154987130846294, 49.520766735076904, 54.69443709509713, 52.39787680762154, 52.59685237067086, 47.02295534951346, 44.775755064828054, 24.86418945448739, 13.239971331187657, 6.9823785168784, 3.199849771601813, 2.029478047575269, 3.5390812371458327, 3.502064274890082, 4.662989922932216, 1.9207793431622642, 1.481655580656869, 4.614341676235199, 5.421589033944266, 4.57989467893328, 5.308277377060481, 8.254075169563293, 12.18361324923379, 10.54615386894771, 12.080608810697283, 10.129292351858956, 7.569711480821882, 8.7511180298669, 6.6898945314543585, 7.194428418363843, 1.9782459395272392, 0.8665914876120431, 0.9776616990566254, 0.6667257409010614, 0.43711044053946224, 1.4595420701163155, 0.1993599667080811, 16.168758630752563, 52.67463745389666, 55.454299041203086, 75.87623936789376, 54.06222745350429, 61.154285022190635, 19.235966205596924, 32.21477385929653, 26.026273931775773, 33.13169288635254, 41.29799059459141, 59.02503735678536, 51.07672895703997, 33.94258935110909, 47.906238147190635, 6.219927932534899, 0.16529472677835397, 0.17630602020238126, 0.04077355942821928, 0.09567868270512138, 0.02064784606253462, 0.022862847295722792, 0.04565640938069139, 0.06642891080783946, 0.06714311641241823, 0.06001900761787381, 0.05539202982825892, 0.14865943656436034, 0.17603312698858126, 0.17566650094730513, 0.04452950520707028, 0.1306858988744872, 0.0640450951510242, 0.2293082225535597, 0.14895142375358514, 0.1799069648342473, 0.28678328703556744, 0.29427409651024, 0.23521112437759126, 0.27340871042438913, 0.17518520248787744, 0.10241004186017172, 0.13597826845943928, 0.10166748706251383, 0.1615430252360446, 0.16257503628730774, 0.15538373216986656, 0.1582843472382852, 0.051985648327640126, 0.1794634336339576, 0.11073706432112626, 0.1496147188757147, 0.10502118031893458, 0.1627362154956375, 0.027458015363663435, 0.14849436256502355, 0.06935558840632439, 0.29306451284459656, 0.10993479165647711, 0.2470514518874032, 19.3566894190652, 73.15950066702706, 57.488085406167166, 49.643958296094624, 73.57025732312883, 31.95904541015625, 31.458695207323345, 47.74971260343279, 19.611498968941824, 57.85104887826102, 81.20873165130615, 75.27035645076207, 74.8300838470459, 79.26786354609898, 67.88929898398263, 60.39620181492397, 4.922558554581233, 0.5796575929437364, 4.917795130184718, 2.4782066089766364, 9.072859576770238, 8.5261892080307, 6.329551833016532, 4.676964487348284, 3.1253403297492435, 3.0310278705188205, 3.663581882204328, 1.4833835107939584, 3.763566025665828, 6.34621969291142, 6.379729551928384, 15.182963848114014, 25.728967462267192, 16.51664798600333, 4.747583372252328, 2.03036915404456, 4.2655447125434875, 3.8458800315856934, 2.810149197067533, 4.771963732583182, 4.767308005264827, 8.151268754686628, 21.536870854241506, 29.26433597292219, 29.494529792240687, 17.512635775974818, 36.0592086655753, 60.19636467524937, 52.440834045410156, 57.67873355320522, 54.314012799944194, 50.77314479010445, 47.06838962009975, 44.936994961329866, 42.92456041063581, 41.976402282714844, 48.958601883479524, 53.09228672300066, 52.1408177784511, 52.21609803608486, 54.174246311187744, 53.10290357044765, 53.708956718444824, 44.244943959372385, 39.0053699357169, 56.38757412774222, 54.230585779462544, 52.19504499435425, 40.16254724775042, 43.766977378300254, 43.88605560575213, 46.430920192173545, 43.09494761058262, 45.0004563331604, 39.72626291002546, 38.45801516941616, 39.927705083574565, 44.36797571182251, 46.74992935998099, 49.911932945251465, 50.69623517990112, 57.46381534848894, 57.78314413343157, 55.91881043570382, 46.697790077754426, 47.26112222671509, 26.30642703601292, 16.23360095705305, 8.092107449259077, 5.4443782567977905, 3.1512314890112196, 4.510239856583731, 4.7884544134140015, 5.119046228272574, 2.9884590804576874, 0.1371214371174574, 4.938930681773594, 4.602998307773045, 5.526479474135807, 8.728657977921621, 13.044820751462664, 10.272996732166835, 11.864482487951006, 13.998391526085989, 11.562194160052709, 9.839332733835493, 10.396791049412318, 9.868483901023865, 7.793810861451285, 2.2453533666474477, 1.255424297281674, 1.4985433944634028, 0.9173173542533601, 2.5675276560442786, 2.925608281578336, 0.25759368762373924, 15.888388395309448, 54.60411051341465, 59.038899012974326, 73.57821995871407, 54.46422243118286, 67.63564109802246, 23.178266389029368, 35.406001567840576, 30.312096527644567, 26.269149950572423, 42.16584144319807, 62.79613740103585, 58.377340180533274, 43.78273589270455, 60.51627363477434, 9.113222530909947, 0.15730636114520685, 0.09546635552708592, 0.07072038017213345, 0.10161122972411768, 0.07349298960928406, 0.10830604298306362, 0.04195423410939319, 0.13327474067253725, 0.06840651469039065, 0.09321710014981882, 0.06368401274085045, 0.1333587025957448, 0.24220752609627588, 0.17742124678833143, 0.06545340815292937, 0.21953098076794827, 0.1463062364075865, 0.20418129728308745, 0.22804158766354832, 0.35062393280012266, 0.3989547336740153, 0.48658717849424904, 0.26161313908440725, 0.3702187756342547, 0.4447830431163311, 0.239716786891222, 0.24547931339059556, 0.12700277008116245, 0.3137799155499254, 0.2516109900815146, 0.2540766234908785, 0.24250768284712518, 0.2212839624179261, 0.19189063965209893, 0.18351138356540883, 0.17284070115004266, 0.21455573130931171, 0.32028424367308617, 0.16934909565108164, 0.24781814217567444, 0.2414265051484108, 0.3140450327524117, 0.22560989457581723, 0.40437318863613264, 27.589754104614258, 85.66497966221401, 72.30874238695417, 59.57263878413609, 83.67503643035889, 69.3374216897147, 34.7167889050075, 67.31708008902413, 12.531076158796038, 53.979967730385916, 86.75632626669747, 79.87710244315011, 81.20749487195695, 83.78214291163853, 67.43588733673096, 66.06855133601597, 6.59365416424615, 0.998037617121424, 6.608151580606188, 3.367492433105196, 10.811396139008657, 13.291110072817121, 12.58192047051021, 10.152383821351187, 5.429341052259717, 9.435161232948303, 7.097133227757045, 6.740052708557673, 10.481022323880877, 12.072528055735997, 13.19971694265093, 22.8022837298257, 32.789580958230154, 21.841702222824097, 8.172789062772479, 5.4743258612496515, 4.927022772175925, 4.95221563747951, 3.231465377977916, 4.4710811121123175, 5.372998109885624, 9.996184842927114, 22.958659887313843, 29.4520172391619, 32.36307621002197, 17.881953375680105, 34.8343037877764, 62.332859311785015, 53.91723591940743, 60.92003345489502, 56.90857785088675, 51.93054791859218, 48.64480039051601, 45.10981750488281, 44.38165324074881, 40.66722617830549, 49.685126372746055, 52.4202812739781, 52.22061089106968, 53.42728022166661, 56.11851208550589, 54.13341869626726, 55.010163239070344, 44.10669217790876, 38.48007222584316, 56.719979422433035, 56.441235065460205, 52.59788417816162, 41.08138745171683, 44.94259173529488, 46.0854036467416, 47.07692200796944, 45.23090723582676, 47.55641024453299, 42.577668121882844, 42.45784991128104, 41.78846740722656, 47.77708155768258, 51.117226532527376, 53.386271953582764, 56.487916537693565, 63.4428687776838, 64.813887323652, 60.957880292619976, 52.66951315743582, 47.41677924564907, 28.017469576426915, 18.281195129667008, 11.146498203277588, 9.455613255500793, 6.940707998616355, 6.184988047395434, 11.307514888899666, 10.787181666919164, 11.87065075125013, 8.636695095470973, 10.69706700529371, 9.966007947921753, 12.78891338620867, 16.043546880994523, 18.817615168435232, 19.25095694405692, 13.966749429702759, 17.930561235972814, 14.685597896575928, 11.58991573538099, 11.044994575636727, 9.565298386982509, 10.981916223253522, 4.0733184559004645, 1.2025854183094842, 2.472019238131387, 1.3644345849752426, 3.9927037187985013, 3.268498407942908, 1.064881676009723, 20.29962944984436, 60.42239652361189, 61.258494104657856, 73.70118917737688, 61.821117537362234, 69.25252859933036, 26.561950513294764, 34.25845445905413, 29.54551567350115, 48.30317483629499, 58.90561866760254, 69.621109689985, 63.92648424421038, 52.596591813223704, 69.24703257424491, 11.660763042313711, 0.24617695595536912, 0.36061006837657517, 0.2175100999219077, 0.18695275033158915, 0.19440136849880219, 0.19802614328052315, 0.19595754785197123, 0.32151013932057787, 0.1939500748578991, 0.24486594487513813, 0.1898124904504844, 0.2272301140640463, 0.2896102810544627, 0.2881922242896897, 0.18464837755475724, 0.4040855440710272, 0.2542955188878945, 0.37208539832915577, 0.38714914715715815], [0.17827554951821054, 0.269685615918466, 0.1989893644515957, 0.21331522001751832, 0.2361441371696336, 0.08905801296766315, 0.07227392002407994, 0.2727587553007262, 0.11247581709176302, 0.19859892183116504, 0.12767618894577026, 0.24190682651741163, 0.12625088542699814, 0.16770301040794167, 0.03050182167706745, 0.17955070680805615, 0.07008039951324463, 0.09194945424262967, 0.01570176682434976, 0.12097188298191343, 0.018523320688733032, 0.18313842000705854, 0.26314347982406616, 0.07336633426270314, 0.09516146260180644, 1.0766297770398003, 68.80834415980748, 58.52057729448591, 65.72457381657192, 49.013808795383994, 76.6876083101545, 43.158871037619456, 46.72996023723057, 32.1735953603472, 17.903452839170182, 75.08203247615269, 67.69936997549874, 70.70008850097656, 56.74070937292916, 61.990459033421104, 32.585474150521414, 1.1262339438710893, 0.12790762366993086, 0.6180913906012262, 1.0738223791122437, 1.5757018370287759, 1.8510928196566445, 3.931664662701743, 2.8256436799253737, 5.31842782667705, 4.0129720483507425, 3.2192456679684773, 4.423317023686, 5.644247531890869, 5.583170260701861, 4.095613488129207, 12.814743314470563, 21.899056128093175, 9.133660657065255, 2.135355349097933, 5.123176498072488, 5.4103633505957465, 3.1226487713200703, 4.327343727861132, 4.631001719406672, 2.3486656972340176, 4.001271281923566, 12.280150651931763, 17.489857843944005, 17.585454634257726, 8.4378776039396, 10.8755601474217, 39.63980647495815, 54.52858706883022, 57.67814643042428, 56.47565296718052, 51.68603386197771, 43.990518297467915, 44.62779317583357, 41.16612073353359, 41.910950251988, 44.662940638405935, 47.515801497868125, 48.65750517163958, 48.7255071912493, 50.526653970990864, 52.328908988407676, 53.3785525049482, 44.319359166281565, 26.02793628828866, 54.75268036978585, 50.29679366520473, 49.69013949802944, 40.93409258978707, 39.21031747545515, 40.05499955586025, 41.302993297576904, 42.35326215199062, 39.80812658582415, 36.141082763671875, 34.43358727863857, 38.37240294047764, 40.67539725984846, 46.17399665287563, 47.10407209396362, 46.0566520009722, 40.26380681991577, 34.018519265311106, 36.42469433375767, 43.862018312726704, 37.54402480806623, 15.956762143543788, 11.529871140207563, 7.142013813768115, 2.734201043844223, 3.4235617901597704, 3.7776035581316267, 4.913736513682774, 3.153738920177732, 1.7384499268872398, 2.166055313178471, 3.023682104689734, 6.57009846823556, 3.9278613924980164, 5.933257418019431, 9.200229610715594, 16.937392677579606, 18.77041779245649, 10.788388047899518, 12.034908771514893, 12.398862361907959, 11.528269580432347, 11.630868417876107, 6.8165454268455505, 4.080862462520599, 1.2294512795550483, 1.6126898122685296, 1.1696066622223174, 2.232843352215631, 2.341949177639825, 0.633603786783559, 8.618159907204763, 53.688393524714876, 49.21101951599121, 82.4434334891183, 61.27530179704939, 51.13723734446934, 17.011892999921525, 17.320457288197108, 32.5214603969029, 35.06084285463606, 45.907620089394705, 41.461617197309224, 28.72998649733407, 52.80123015812465, 24.316504648753575, 0.041957966051995754, 0.12837731918053968, 0.07065530866384506, 0.10722778298492942, 0.047848314978182316, 0.01563366735354066, 0.08103758655488491, 0.10236197443945066, 0.2285808872963701, 0.06016920134425163, 0.09040102375937359, 0.0866044574816312, 0.23844149389437266, 0.1711398581308978, 0.14814514773232595, 0.06355298762874943, 0.122379992423313, 0.12371993623673916, 0.33170751641903606, 0.07872473209031991, 0.37487686425447464, 0.4143320199634348, 0.27176160737872124, 0.21969567478767463, 0.25014524587563103, 0.12524828208344324, 0.022813750198110938, 0.04870535220418658, 0.13627994512873037, 0.27397013029881884, 0.18616586684116296, 0.3338865909193243, 0.21705994621983596, 0.13875977349068436, 0.12067897298506328, 0.16628614786480153, 0.07711526059678622, 0.056458049054656706, 0.07154701902930226, 0.06753458362072706, 0.0664999330682414, 0.14955732838383742, 0.09672123819057431, 0.09774621283369404, 0.11058189014771155, 3.0436581756387437, 79.83897767748151, 67.72992120470319, 65.93422876085553, 63.820190702165874, 63.199056489127024, 30.89978211266654, 46.29524619238717, 27.863936969212123, 30.64506115232195, 81.76058537619454, 77.04847690037319, 75.11951800755092, 70.41707447596959, 69.85589626857212, 40.57889372961861, 1.129454868180411, 1.0268310606479645, 2.839883578675134, 2.4668647604329244, 2.839206563574927, 1.6322335749864578, 2.4402134248188565, 3.8584584423473904, 6.2036009686333795, 5.517691739967891, 4.430143628801618, 5.903424458844321, 6.198809317180088, 6.752795704773494, 7.313332506588527, 16.27759347643171, 24.813412019184657, 12.479577847889491, 4.3737824474062235, 5.142672274793897, 7.6540956156594415, 4.8911683303969244, 5.439705158982958, 6.393090069293976, 4.007636700357709, 4.688330437455859, 14.20094975403377, 20.24174574443272, 22.40419363975525, 13.446098327636719, 16.401432956968033, 43.55219118935721, 53.80263928004673, 58.69080121176583, 56.36936984743391, 53.78403547831944, 44.44581985473633, 45.48330749784197, 42.40336561203003, 41.98730053220476, 47.55795621871948, 48.95842817851475, 53.01973363331386, 49.711960315704346, 53.13780089787075, 55.45738056727818, 55.8201390675136, 44.741660254342214, 27.404101712363108, 56.67822422300066, 52.65803125926426, 53.05554812295096, 40.44716283253261, 42.45700570515224, 41.19068956375122, 44.47010728291103, 44.16287183761597, 43.55651296888079, 37.40921238490513, 37.980819838387625, 39.614581039973665, 46.299908433641704, 47.367735385894775, 50.34469107219151, 51.56482253755842, 53.87107556206839, 49.683274677821565, 53.12236200060163, 50.77175515038626, 38.27606616701399, 19.646365029471262, 14.699874707630702, 8.011327692440577, 3.331996474947248, 2.8543345289570943, 3.892239281109401, 7.030664588723864, 4.7260105184146335, 4.924283010619027, 1.9923225556101118, 2.142663551228387, 5.368320669446673, 5.433284589222499, 9.315922328404017, 11.62316199711391, 14.221737895693098, 15.255838291985647, 12.803741710526602, 14.366554856300354, 14.110318320138113, 14.252262200628008, 13.220695291246686, 10.373623149735586, 5.540973850658961, 2.303311765193939, 2.924354131732668, 2.1853587116513933, 4.1724453653608045, 3.9961604475975037, 0.7717261580484254, 7.893811072622027, 55.99961798531668, 53.46952526909964, 81.68274470738002, 62.8526679447719, 61.42654323577881, 22.154169661658152, 20.99683427810669, 31.25667633329119, 34.38764926365444, 48.62949003492083, 50.151763916015625, 36.46549415588379, 62.77299295152937, 29.830912930624827, 0.09500531812331506, 0.06198892369866371, 0.04168150374399764, 0.09391578087317091, 0.12970855060432637, 0.029492863853062903, 0.03867534933877843, 0.13624447131795542, 0.13882141161177838, 0.1094922579026648, 0.053390867209860256, 0.10865164800946202, 0.10382921820772545, 0.18764052699719155, 0.25781714277608053, 0.23102944876466477, 0.23012390307017735, 0.15799089441342012, 0.3243483970207827, 0.08896724533821855, 0.44942329983626095, 0.5341956924114908, 0.36537105004702297, 0.3029395043849945, 0.35487131774425507, 0.18819491724882806, 0.20413721964827605, 0.40368374277438435, 0.3055039053516728, 0.4848787901656968, 0.24316208916051046, 0.3768619863050324, 0.20783066217388424, 0.2860292446400438, 0.2668729525591646, 0.33479343940104755, 0.1874886437186173, 0.19339170839105332, 0.20492877145963057, 0.32117765716144014, 0.12714493673826965, 0.2586516594248158, 0.3186669147440365, 0.1900498012879065, 0.18758049021874154, 5.18738089288984, 98.54917022160122, 74.73514366149902, 80.4337226322719, 63.06217002868652, 98.70224598475865, 58.606700216020855, 57.137100628444124, 41.18666655676705, 22.49831393786839, 89.29589285169328, 80.20702375684465, 83.28407519204276, 70.42188262939453, 74.5667610168457, 42.035760743277415, 1.69048672914505, 1.1845290043524332, 5.769794966493334, 3.855287023953029, 4.614725564207349, 6.583570156778608, 8.315128990582057, 7.916602032525199, 10.621830173901149, 7.042754020009722, 9.607202972684588, 12.087529216493879, 12.675244331359863, 11.7998286315373, 15.645500217165266, 23.898191826684133, 32.386891160692485, 18.64670511654445, 10.233362470354352, 8.771350315638951, 9.912181990487234, 6.056586640221732, 7.6023628030504495, 7.183141069752829, 7.098413867609842, 9.538370643343244, 17.542412281036377, 22.960039104734147, 24.518400192260742, 17.43273844037737, 17.658327341079712, 43.03490127835955, 58.8553067616054, 62.052638462611604, 56.945514474596294, 54.69489567620413, 43.955297878810335, 47.48406907490322, 42.183006967817036, 43.762384619031636, 48.60451473508562, 49.811267444065635, 52.561058725629536, 50.26474509920393, 54.93386159624372, 56.71105098724365, 56.76991612570626, 46.244788374219624, 29.195590496063232, 55.51630129132952, 54.04028851645333, 53.569721766880576, 44.913301604134695, 44.28065422603062, 43.828660011291504, 46.55386509214129, 47.36304187774658, 46.00531870978219, 41.929547105516704, 40.219904627118794, 45.26891735621861, 49.49898760659354, 52.661196163722444, 56.14871937888009, 60.2124080657959, 62.14807891845703, 59.88956696646554, 60.37255709511893, 55.49282332829067, 39.43695729119437, 22.742668185915264, 18.961378608431133, 12.055741207940237, 7.0658676368849616, 8.186877403940473, 7.6993900537490845, 10.660627177783422, 10.47578946181706, 8.527298314230782, 8.280375838279724, 8.587472319602966, 11.511038047926766, 11.518164294106619, 18.517829929079326, 19.925105912344797, 26.304818528039114, 24.689777510506765, 13.933837550027029, 16.444089685167583, 17.619427851268224, 16.729076998574392, 14.062521662030901, 10.69875715460096, 7.928803069250924, 1.5211719402245112, 2.7399615347385406, 3.305669967617307, 8.225742152759008, 6.247272568089621, 0.7623870191829545, 11.243360434259687, 63.267058508736746, 56.38736915588379, 85.21210997445243, 69.08991295950753, 61.449194363185335, 22.981069564819336, 17.71086961882455, 46.001528467450825, 49.36406053815569, 58.97768538338797, 55.690461363111226, 44.35572256360735, 70.84770992824009, 43.21359157562256, 0.19524645672312804, 0.1876059624233416, 0.16352373680898122, 0.20830813369580678, 0.23995763968144143, 0.18517270870506763, 0.17938708487365926, 0.32018800026604105, 0.3103133887052536, 0.1488681539360966, 0.27350565950785366, 0.1959549422774996, 0.31455678386347635, 0.3483962480510984, 0.3934368597609656, 0.3583643345960549, 0.36972102948597496, 0.3410364229764257, 0.4484746535973889, 0.18192405945488385], [0.12315306094075952, 0.1566190187420164, 0.17133130000105926, 0.16477541678718158, 0.21490770099418505, 0.15979263558983803, 0.1891122015991381, 0.12331289664975234, 0.16135340183973312, 0.10432205176247017, 0.19871025585702487, 0.1393655559846333, 0.12928138566868647, 0.1188100025589977, 0.2054141139877694, 0.07560517412743398, 0.1153496503829956, 0.08640959579497576, 0.02383576812488692, 0.06535202823579311, 0.07189668169511215, 0.22972188464232854, 0.08706115226128272, 0.24296295270323753, 0.012586717726662755, 0.08301571969475065, 39.76618725912911, 71.30902167728969, 40.8656667300633, 55.24292441776821, 56.1937506539481, 65.60593332563127, 33.70528057643345, 56.34032637732369, 20.056272268295288, 55.14702885491507, 81.98548466818673, 60.145364897591726, 65.03286675044468, 70.71573584420341, 25.36199140548706, 0.19397826120257378, 1.4086942843028476, 0.6966728025249073, 0.5949859161462102, 0.9246509607349123, 0.8525061862809318, 2.49934389761516, 6.063779762813023, 6.297345195497785, 6.674004435539246, 5.841956785746983, 4.932930478027888, 5.997996824128287, 10.22418303149087, 8.92905444758279, 16.502359015601023, 19.400878225054058, 7.82790914603642, 2.4504737428256442, 5.060277061803, 5.864316957337516, 7.366642560277667, 6.826634645462036, 7.334160600389753, 4.07465945822852, 1.4139849032674516, 6.63286371741976, 10.98667573928833, 15.93064386504037, 9.465370263372149, 4.735070535114833, 17.740133694240026, 57.44201190131051, 62.245075770786826, 61.47275570460728, 55.73387023380825, 47.596365860530305, 42.82801171711513, 43.020198890141074, 40.36687987191336, 45.03037180219378, 48.63172388076782, 49.7114565713065, 50.218768869127544, 54.12156159537179, 53.686722482953755, 53.81786625725882, 44.90241725104195, 37.771078041621614, 57.64717483520508, 50.25111968176705, 52.019217354910715, 40.8190130506243, 42.21758815220424, 41.62943008967808, 42.9460894039699, 43.06579991749355, 38.886625221797395, 36.04259899684361, 37.04095091138567, 40.79785926001412, 41.07284811564854, 44.53556278773716, 47.24441180910383, 36.14231606892177, 17.8824588571276, 7.560017006737845, 6.713795466082437, 15.905699832098824, 20.0904643535614, 13.26216561453683, 9.254356946263995, 7.3181041819708685, 1.48871625321252, 5.542882433959416, 4.232456088066101, 7.856479270117624, 4.467423319816589, 3.7507327028683255, 2.2562318571976254, 3.5405777054173604, 4.956783643790653, 5.784895573343549, 4.687939601285117, 12.819817236491613, 17.24779302733285, 24.610583680016653, 14.753387996128627, 12.810209614889962, 17.41548432622637, 16.365514244352067, 15.345426627567836, 9.3488507100514, 4.567647176129477, 3.0712700997080122, 1.699303450328963, 1.2437327589307512, 1.8987778723239899, 1.5905490517616272, 0.6797469907573291, 0.514943211206368, 44.829541070120676, 51.96827663694109, 56.245410510471885, 50.738591398511616, 42.51539141791207, 8.239992908069066, 25.679687363760813, 30.534810611179896, 41.18992178780692, 39.923699447086875, 25.591504301343644, 45.781718730926514, 46.89454221725464, 2.368681068931307, 0.014728854476873363, 0.13520110159048013, 0.05056849401444197, 0.021439954272604415, 0.04097295033612421, 0.09252057716782604, 0.1063643064615982, 0.09892201224075896, 0.0560056731503989, 0.06525722332298756, 0.06936528467174087, 0.02360182791016996, 0.1614795143582991, 0.07908580092979328, 0.2699515473629747, 0.05583846176575337, 0.06622355218444552, 0.08674336038529873, 0.04918777024639504, 0.09024006846760001, 0.2033420851720231, 0.27567431171025547, 0.3379385849194867, 0.17054445722273417, 0.23763789130108698, 0.20421531902892248, 0.22059245380972112, 0.13767518954617636, 0.21762987492339952, 0.11727833189070225, 0.20038625092378684, 0.19368237922234194, 0.12939471458750113, 0.1868204360029527, 0.08120244342301573, 0.12216169413711343, 0.09802116200860057, 0.12691874030445302, 0.12844828037278994, 0.15430024745208876, 0.11901985986956529, 0.17034525291195937, 0.13810050886656555, 0.24633095626320156, 0.09807992992656571, 0.12218207732907363, 51.3749178477696, 79.30178465162004, 48.53490768160139, 58.022440092904226, 67.39574064527238, 43.3941023009164, 35.28691291809082, 39.08086558750698, 28.428368670599802, 74.10611629486084, 81.49167619432721, 74.10581752232143, 68.15296922411237, 75.94874382019043, 24.953673567090714, 0.030165251344442368, 4.675122780459268, 3.208166765315192, 1.5406940983874458, 1.3494172479425157, 1.0762570713247572, 2.4924725634711127, 8.056810600417, 8.262477278709412, 9.005620990480695, 6.540345847606659, 5.617517811911447, 6.247009405067988, 9.923085451126099, 10.293132611683436, 19.566868952342443, 22.971791982650757, 9.589127234050206, 5.349368589265006, 7.0665550742830545, 5.617334987436022, 6.869290939399174, 7.157862654754093, 7.626990692956107, 6.552860856056213, 2.40829861164093, 5.8945655056408475, 12.569536175046649, 16.62276087488447, 13.094116483415876, 7.613037841660636, 23.716633660452707, 58.492847033909385, 63.95016370500837, 63.47301006317139, 58.8885816846575, 48.829539094652446, 44.74476262501308, 45.81184959411621, 42.41997528076172, 47.50726563589913, 49.86318785803658, 51.826884269714355, 52.104812213352744, 55.453896045684814, 54.43456751959664, 53.11089399882725, 44.73928049632481, 38.024742875780376, 58.33528273446219, 54.018519810267854, 53.800547872270855, 44.73097045081002, 42.62467963354928, 42.20241328648159, 44.638121673039024, 46.06553527287075, 41.87789419719151, 37.862439904894146, 38.41282408578055, 41.68475859505789, 43.56629603249686, 49.24492672511509, 50.41527434757778, 48.92874894823347, 36.22296380996704, 28.02301597595215, 21.559541089194163, 26.50007333074297, 22.734276499067033, 14.927257980619158, 12.597055384090968, 7.860902667045593, 1.9974247046879359, 4.572648576327732, 4.436333605221339, 9.441634348460607, 7.625562838145664, 5.907860449382237, 5.141270041465759, 2.8516086637973785, 3.6859377111707414, 7.109478439603533, 8.509585618972778, 13.441059146608625, 16.435833488191875, 18.194045611790248, 11.710194264139448, 13.237319724900381, 20.496551820210048, 19.20203467777797, 15.86991834640503, 10.53918743133545, 6.608843794890812, 4.61824916941779, 3.1511761205536977, 2.4697966831071034, 4.3208063415118625, 5.61072073663984, 1.455665952392987, 0.4258913796927248, 42.48027522223336, 54.65150417600359, 59.745537757873535, 55.713734354291645, 59.43732261657715, 12.11146228654044, 21.251709835869924, 35.6184218951634, 39.912690026419504, 50.43115792955671, 33.74945722307478, 52.556549344744, 56.237402711595806, 3.234617905957358, 0.06141719687730074, 0.18238095779504093, 0.02643251315956669, 0.024398887729538337, 0.035353794893515963, 0.05534226606999125, 0.05390921028863106, 0.13066220443163598, 0.0375607537903956, 0.07532069153551545, 0.04147093736433557, 0.09403670938419444, 0.1805598105170897, 0.19337949476071767, 0.23011196085384913, 0.14917843442942413, 0.21625076606869698, 0.021616968791931868, 0.23426087679607527, 0.10254463606647082, 0.39557394651429995, 0.4154576009937695, 0.4424494797629969, 0.3132210469671658, 0.3667393023414271, 0.3020561332149165, 0.3005114889570645, 0.22508184505360468, 0.260043307606663, 0.17814402229019574, 0.30866785986082895, 0.27474689004676683, 0.21671390693102563, 0.19977346594844544, 0.2578284064573901, 0.17757269580449375, 0.3157161830791405, 0.19481174647808075, 0.29774502026183264, 0.27319581327693804, 0.2860253362783364, 0.30790646214570316, 0.20313643477857113, 0.24891394908939088, 0.25737571503434864, 0.299380642494985, 60.877573013305664, 92.66527584620884, 60.12045560564314, 67.62197399139404, 73.4717457635062, 82.27084718431745, 44.52506405966622, 65.03028202056885, 27.179560252598353, 69.75874655587333, 94.83854034968785, 76.08943789345878, 76.94724859510148, 80.46810231889997, 31.27199363708496, 0.3485515240047659, 4.640151628426143, 4.714187289987292, 4.654372419629778, 3.294605395623616, 3.125469739948, 6.053037413528987, 10.803330148969378, 10.066206182752337, 12.784453511238098, 11.558804307665143, 10.53944104058402, 13.332255567823138, 15.527544123785836, 19.833462647029332, 28.22756052017212, 31.137681484222412, 17.089664186750138, 12.985308562006269, 9.470179285321917, 8.605191094534737, 10.96383614199502, 9.224314672606331, 9.634006517274038, 9.873087951115199, 6.914634449141366, 11.496153269495283, 16.702444553375244, 22.800873245511735, 15.384543248585292, 9.264371037483215, 24.993012530463083, 60.72249616895403, 67.4482273374285, 65.48942593165806, 59.98373590196882, 50.6145521572658, 45.01062849589756, 46.026851177215576, 44.15818527766636, 48.658370222364155, 51.72153915677752, 52.56604058401925, 52.71540600912911, 57.35259900774275, 55.96707609721592, 53.14594071252005, 47.94704144341605, 41.123146125248496, 59.29207052503313, 53.60312523160662, 55.58214242117745, 44.568535464150564, 45.62230273655483, 45.21785504477364, 46.19739818572998, 48.23543684823172, 43.97489179883684, 41.558971881866455, 41.49220664160592, 45.03564201082502, 46.2771635055542, 54.47847318649292, 56.048988410404746, 60.18122455051967, 45.25801910672869, 37.83211101804461, 26.837005376815796, 27.020653213773453, 24.055191584995814, 18.608066184180124, 17.32447508403233, 13.064801165035792, 6.615462388311114, 9.724832500730242, 8.651486941746303, 11.067648308617727, 10.963185616901942, 8.262155055999756, 7.483898622649057, 7.132227276052747, 8.423865692956106, 13.633552040372576, 16.051261118480138, 24.065520082201274, 28.13365387916565, 33.64235074179513, 20.678924662726267, 16.103907619203838, 24.720815113612584, 21.381870440074376, 19.280726500919886, 12.75617173739842, 7.036225753171103, 5.40444826228278, 3.1678381179060255, 1.8452604583331516, 8.004472426005773, 8.265964405877249, 1.0481571448700768, 0.8082100631935256, 56.741261754717144, 57.09541491099766, 65.84729290008545, 57.39973211288452, 58.1394408089774, 9.809820260320391, 32.92818014962332, 46.22744219643729, 54.85851533072335, 57.11068705150059, 44.5823450088501, 60.41444083622524, 68.99866226741246, 6.984939796583993, 0.28487103964601246, 0.44021107416067806, 0.13657308582748684, 0.14223151148429938, 0.14274767307298525, 0.19938846517886433, 0.14152734141264642, 0.2595795424921172, 0.1089113505024995, 0.3294814330126558, 0.19473376923373767, 0.27108556936894146, 0.25616333580442835, 0.2856910899281502, 0.5266480488436562, 0.16999697445758752, 0.38227639719843864, 0.2684264991964613, 0.30752528831362724, 0.16745529084333352], [0.08193599406097617, 0.19869273608284338, 0.1077334408515266, 0.19857169900621685, 0.21665883702891214, 0.2556021602026054, 0.14713043932403835, 0.11553886665829591, 0.15698377202664102, 0.22287161222526006, 0.12410735259098665, 0.07087072996156556, 0.1557196205747979, 0.17685973191899912, 0.0721005339707647, 0.10004338635397808, 0.05435674823820591, 0.0586456527401294, 0.0510877802568887, 0.10119385604879685, 0.14921994720186504, 0.048369599506258965, 0.11648638652903692, 0.01707307591901294, 0.02239781162435455, 0.08351965408240046, 2.6894770094326566, 73.77539593832833, 54.807188987731934, 40.131450584956575, 58.749298095703125, 58.1109254019601, 32.48291179112026, 34.693693092891145, 30.50494725363595, 32.50730691637312, 85.00777040209088, 63.45128999437605, 70.75610487801688, 70.19899831499372, 24.62529649053301, 0.4432128316589764, 2.769963639123099, 0.29066833427974154, 1.4933212803942817, 1.1286304209913527, 1.1488358910594667, 4.215299682957785, 7.561024495533534, 8.611143095152718, 6.988904178142548, 9.71583024093083, 9.618166361536298, 7.769637210028512, 12.664828113147191, 12.119754093033926, 16.556572335106985, 13.791718227522713, 8.868548665727888, 1.2852186071021217, 6.525767224175589, 8.095818655831472, 8.069126282419477, 10.0576651096344, 10.478193538529531, 7.878923688616071, 4.2760933807918, 1.935281753540039, 4.622251331806183, 8.168911967958723, 4.2595032538686475, 3.11912516610963, 2.9759987890720367, 28.664167949131556, 59.36286572047642, 60.528314862932476, 58.55898693629673, 56.40837008612496, 44.13799033846174, 40.31392765045166, 39.65422051293509, 43.36769567217146, 46.89313868113926, 50.46308490208217, 51.00080599103655, 55.222614833286826, 51.88143457685198, 56.00312335150582, 40.70149121965681, 37.84345047814505, 57.10767500741141, 50.79141160420009, 50.563604491097585, 42.50607735770089, 40.536047663007466, 41.094418798174175, 41.7417824608939, 41.54973077774048, 37.843624183109824, 37.84075805119106, 39.245642117091585, 41.35435438156128, 42.39171348299299, 44.572325706481934, 44.22454752240862, 29.53766073499407, 11.633657251085554, 0.9745952636003494, 4.045820959976741, 9.316315770149231, 10.583843503679548, 10.489437460899353, 10.225392886570521, 6.6380696552140375, 1.3057668187788554, 5.120556592941284, 5.0187112007822305, 10.368166208267212, 8.646038685526166, 5.879891778741564, 1.7589822879859378, 3.3313552864960263, 4.595998866217477, 6.018306842872074, 8.629201463290624, 10.20138338633946, 14.881422451564244, 19.831181900841848, 25.107781137738908, 15.557721887316022, 14.668105806623187, 17.87543943950108, 17.87528657913208, 12.486790078026907, 7.0716732910701205, 5.101750424930027, 3.261564322880336, 1.22086906007358, 3.2710140900952474, 2.0715194259371077, 1.7370550760201044, 0.008209005713329783, 22.47753187588283, 57.64179345539638, 46.31961005074637, 60.561450822012766, 19.95100358554295, 18.107321671077184, 40.488768645695274, 26.596893004008702, 51.455107007707866, 24.91381696292332, 36.77705485480172, 54.389564037323, 13.784229806491307, 0.24356649603162492, 0.19357795268297195, 0.044423867482692, 0.05842866402651582, 0.06525158469698258, 0.11015018581279687, 0.0802135057747364, 0.01908085764651852, 0.06374531159443514, 0.10021593780922038, 0.12519193653549465, 0.03876151989347168, 0.15739423143012182, 0.074101683018463, 0.1846006629722459, 0.028285203834197352, 0.18637767833258423, 0.06092921484793935, 0.09089775210512535, 0.1351863638098751, 0.1259558584008898, 0.1413942128419876, 0.10642090985285384, 0.14641083936606133, 0.19583401376647608, 0.24203056416341237, 0.18087003672761576, 0.09208951065582888, 0.25385775523526327, 0.09676111569362027, 0.2684494065386908, 0.2015450123165335, 0.22237344538526876, 0.02850987356422203, 0.14462668581732682, 0.07887389444346939, 0.050718803091772964, 0.0903435382725937, 0.162323584780097, 0.11501397910927023, 0.0616841461243374, 0.13969892023929528, 0.1536238837455, 0.053952202267412624, 0.09249836193131548, 0.1238916598792587, 0.30284239245312555, 5.26699378660747, 87.13089670453752, 60.64797673906599, 44.578756264277864, 67.64925261906215, 51.249627930777415, 29.336611134665354, 39.36872598103115, 23.870791605540685, 53.55301134926932, 89.19883346557617, 71.79127529689244, 73.94026974269322, 79.89115170070103, 22.68109498705183, 0.19821217044123582, 5.693593638283866, 2.0391251870564053, 3.123695343732834, 1.208103482212339, 2.6421089683260237, 5.061519486563546, 8.424304297992162, 10.893601145063128, 11.184464028903417, 10.427416971751622, 9.847206779888698, 8.431005835533142, 13.326123782566615, 14.529212185314723, 17.728592736380442, 16.69243914740426, 8.876685874802725, 4.37893670797348, 6.75904734645571, 5.661224152360644, 8.454769543239049, 9.057464105742318, 10.43782103061676, 8.248388937541417, 4.703855752944946, 2.860992423125676, 3.091918626001903, 8.633070741380964, 4.944338985851832, 4.5025955353464395, 7.8819730792726785, 39.43992417199271, 61.59773990086147, 61.12713146209717, 60.61839825766427, 57.1401960509164, 45.56450762067522, 42.433322770254954, 42.909461975097656, 44.811625140053884, 47.92144080570766, 51.93766287394932, 55.13078396660941, 57.180578981127056, 54.32985816683088, 55.400662422180176, 42.7835328238351, 39.03280142375401, 59.453233991350444, 53.3920111656189, 53.83161326817104, 45.89023222242083, 42.378897530691965, 45.16981519971575, 44.78211614063808, 44.92692354747227, 41.57595675332205, 40.91941104616438, 42.68906511579241, 44.48474713734218, 44.456433228084016, 47.388031073978965, 51.13885280064174, 42.45955569403512, 26.334284101213726, 12.879660333905901, 3.3245323726109097, 11.358191575322833, 12.843566179275513, 13.012885093688965, 12.713552355766296, 6.21557445185525, 1.0192802143948418, 3.9677110484668185, 4.932706832885742, 10.242400339671544, 8.94534536770412, 6.293878478663308, 5.928527866091047, 3.1542502641677856, 2.8051682072026387, 6.035445008959089, 11.487315160887581, 12.144738946642194, 15.906207050595965, 18.209724221910747, 17.920415128980363, 13.678717068263463, 15.862732172012329, 20.502271924700054, 18.00455433981759, 12.678155626569476, 7.924741847174508, 6.534925818443298, 4.532152737889971, 3.353479436465672, 5.9610810450145175, 6.256869333130973, 3.939167848655156, 0.2654984848839896, 23.820380687713623, 59.74453026907784, 54.42655624662127, 61.14595413208008, 33.09976938792637, 14.28825386932918, 38.03933409282139, 30.62847580228533, 51.04362079075405, 33.19967058726719, 38.28877789633614, 70.52686296190534, 14.404585821287972, 0.20048869614090237, 0.23544576178703988, 0.13468214443751744, 0.04646670572193606, 0.042042280813413005, 0.1064384567684361, 0.10409635744456734, 0.03564000774973205, 0.17000755960387842, 0.1743595339357853, 0.11764726495104176, 0.059416801003473144, 0.17107651010155678, 0.1808016946805375, 0.18082057152475628, 0.14368150010704994, 0.21711287195129053, 0.10921667769019093, 0.19527325885636465, 0.03052677140970315, 0.06585291600120918, 0.29831382259726524, 0.2634816888187613, 0.3104169874319008, 0.2793962391359465, 0.40537136793136597, 0.3717684681926455, 0.21709271946123668, 0.36580270688448635, 0.3427003536905561, 0.46029557500566753, 0.274740674665996, 0.25794682438884464, 0.2758396571235997, 0.297445324914796, 0.15145432230617317, 0.20575851122183458, 0.21166557925088064, 0.21820192065622124, 0.22799053468874522, 0.22775342741182872, 0.2947704313056809, 0.21414666968796933, 0.1968674768826791, 0.17762768428240502, 0.24158777935164316, 0.4419042361634118, 7.733815772192819, 104.70575359889439, 70.07090132577079, 58.20017153876168, 71.26410852159772, 77.56713213239397, 42.110398292541504, 45.00112336022513, 36.959514549800325, 43.4612774848938, 99.59069129398891, 75.65833691188267, 84.96139117649624, 82.13439846038818, 30.69615125656128, 0.8127781237874712, 7.864216957773481, 3.532152146100998, 4.826153167656489, 2.7444376945495605, 3.7281671251569475, 7.246087406362806, 11.906080484390259, 14.203541432108198, 13.59946244103568, 13.600970200129918, 16.09771156311035, 12.951264125960213, 20.598316873822892, 24.397645711898804, 26.89086433819362, 23.248003721237183, 17.78004935809544, 10.240906476974487, 12.381085395812988, 13.938360827309744, 11.753874983106341, 12.393232583999634, 16.126732451575144, 13.342036025864736, 10.141599348613195, 8.14595251423972, 8.81306643145425, 13.167572838919503, 6.896568264280047, 6.400711374623435, 9.609772069113594, 37.444380692073274, 64.50486619131905, 63.335977690560476, 60.714200019836426, 58.6932122366769, 47.916170597076416, 42.7677013533456, 41.90374149594988, 45.87962927137102, 48.80831582205636, 53.36532660893032, 56.27802882875715, 58.79607336861746, 54.63915375300816, 54.49771622249058, 42.69597509929112, 40.33332354681832, 61.58146027156285, 55.20743301936558, 54.88870872770037, 46.949144635881694, 44.04566267558506, 45.10054165976388, 46.487124170575825, 44.77024514334542, 44.82826607567923, 42.15440123421805, 45.42263582774571, 47.69036109106881, 49.718022618974956, 52.75979804992676, 55.50114379610334, 52.83724961962019, 40.778175013405935, 25.509864704949514, 8.443317174911499, 16.814788239342825, 14.899736166000366, 15.535053389413015, 17.95358235495431, 13.588797824723379, 7.351157631192889, 9.229771614074707, 9.114002466201782, 13.17366988318307, 13.4226907151086, 10.032655068806239, 8.716608933040074, 6.793037065437861, 5.415951439312526, 13.560113055365425, 19.968530416488647, 21.97017788887024, 25.6603296824864, 30.60970871789115, 35.412018707820344, 21.26368158204215, 19.213266440800258, 24.264916011265345, 23.117789268493652, 15.903118576322283, 8.687980617795672, 6.337639536176409, 4.895517034190042, 5.798580050468445, 8.79698656286512, 6.906257961477552, 3.648615462439401, 0.26239690131374765, 27.605029719216482, 70.26986299242292, 54.35873140607561, 70.56944152287075, 27.35308630125863, 22.02921325819833, 57.38271597453526, 38.4341585295541, 68.08816337585449, 42.36413260868618, 50.11101620537894, 82.19827325003487, 27.839823246002197, 0.7053397574595043, 0.6763757573706763, 0.18539178052118846, 0.19891560769506864, 0.1321251123611416, 0.24012602493166924, 0.16451257946235792, 0.17828092351555824, 0.18576516477125032, 0.22867672358240398, 0.22705742690180028, 0.25241144427231377, 0.2668550935174738, 0.25703321769833565, 0.3402149884828499, 0.3276183929826532, 0.4357765492584024, 0.3324520321828978, 0.5295820885470935, 0.3345396401626723, 0.3095852934888431], [0.1874741366399186, 0.14932210743427277, 0.08677124138921499, 0.06373531677361045, 0.21386952884495258, 0.09909539150872401, 0.16021165810525417, 0.08270381750272852, 0.025851403895233358, 0.044304964398699145, 0.15011265501379967, 0.15446190163493156, 0.13439817753221306, 0.08557224965521268, 0.12645019830337592, 0.0921071729223643, 0.0730338588889156, 0.1698147878050804, 0.020553477108478546, 0.06350110684122358, 0.12645156894411358, 0.039360476325133016, 0.07578288923416819, 0.08466607292315789, 0.04524944103988154, 0.16148526833525725, 0.13087341881224088, 23.77603554725647, 81.45098059517997, 38.10308381489345, 50.28093787602016, 62.88980606624058, 44.27557161876133, 23.911912781851633, 35.89003392628261, 28.988984073911393, 54.94420051574707, 73.29609530312675, 54.47301190240042, 67.66200951167515, 12.38406183038439, 0.70051559060812, 6.253391325473785, 1.1461248993873596, 1.0150234656674522, 0.6386093124747276, 3.018017585788454, 5.074163905211857, 10.11489394732884, 12.220843434333801, 11.948718105043683, 10.613435012953621, 10.209616133144923, 8.866988795144216, 15.00635974747794, 11.352806721414838, 16.771938698632376, 14.590687240873065, 8.881977796554565, 3.7121102724756514, 6.593857833317347, 5.891086195196424, 12.039541482925415, 13.471906542778015, 14.79170036315918, 10.899741615567889, 5.788382266248975, 3.803250227655683, 0.8365009022610528, 1.6847283009971892, 1.1310040993349892, 1.4753066641943795, 1.1701529643365314, 5.5921065126146585, 37.04766634532383, 63.76124218532017, 56.36532252175467, 59.79309817722866, 51.36651747567313, 46.119529724121094, 41.13712590081351, 47.136214460645405, 47.43758910042899, 54.682326384953086, 52.91397162846157, 56.38503456115723, 52.201909814562114, 55.48815761293684, 39.19623695101057, 37.6866192136492, 59.357466970171245, 49.815856729234966, 50.73650346483503, 41.61059352329799, 42.903750555855886, 41.61682953153338, 43.27636507579258, 39.27100999014718, 40.651321751730784, 39.52597761154175, 40.484182834625244, 41.1067726952689, 43.563978808266775, 47.030643531254356, 45.9443621635437, 35.1988445009504, 21.650741406849452, 3.3078100127833228, 5.6552647692816596, 10.592234322002955, 15.173014027731758, 10.391533868653433, 8.121394106319972, 4.278212581362043, 5.218914857932499, 8.97992047241756, 7.337018915585109, 11.663495421409607, 11.041992085320608, 6.759585397584098, 1.6028063254696983, 3.3817390629223416, 3.2109875168119157, 3.953393416745322, 7.702633125441415, 12.17810593332563, 11.276519843510219, 14.135101675987244, 15.582617282867432, 20.193344593048096, 17.662338188716344, 18.192077534539358, 18.06405176435198, 12.555021388190132, 11.923883506229945, 6.256905376911163, 2.198334038257599, 1.6223371688808714, 1.4215869924851825, 4.842688577515738, 2.490788928100041, 0.06369697954505682, 11.606768591063362, 62.15987695966448, 48.3405179296221, 59.77076666695731, 17.032004560743058, 34.15966149738857, 21.907289743423462, 50.40423366001674, 41.477636269160676, 33.80211762019566, 49.291611671447754, 14.04558369091579, 0.2471636544380869, 0.09643320007515804, 0.05372446895177875, 0.02561433902675552, 0.01716015740696873, 0.024472641093390327, 0.03661862827305283, 0.05975391077143805, 0.05399434268474579, 0.049127329739608934, 0.08923930395394564, 0.15279866302652018, 0.07802039238491229, 0.06619088750864778, 0.06744598730334214, 0.03924326618601169, 0.053274132045251985, 0.03812901669048837, 0.029891503176518848, 0.015178577309208257, 0.21440094390085765, 0.1184116889323507, 0.11258749717048236, 0.155812552730952, 0.0593848420040948, 0.12305737393242971, 0.3009175514536244, 0.13761214007224354, 0.16020470990666322, 0.1900689766875335, 0.11714409052261285, 0.19424563114132198, 0.10915860866329499, 0.21890784134822233, 0.07302657142281532, 0.17155756428837776, 0.11578244715929031, 0.08307641465216875, 0.11572812364569732, 0.149151903710195, 0.0953219768458179, 0.18168533726462296, 0.19122488823320183, 0.09348758456430264, 0.28195640604410854, 0.05776255298405886, 0.17913547051804407, 0.1360999976417848, 0.12420048830764634, 35.73062835420881, 89.00729247501918, 43.97417613438198, 52.56056540352957, 65.83634948730469, 36.30397285733904, 29.188103812081472, 23.366397551127843, 37.92099584851946, 71.62371948787144, 79.26195757729667, 62.37596593584333, 70.98828588213239, 11.624251995767866, 0.46338052089725223, 7.945005399840219, 3.470584809780121, 3.5929821048464095, 1.5303307516234261, 3.229268010173525, 7.030298071248191, 13.903592910085406, 13.560885173933846, 13.270600727626256, 15.141326768057686, 11.894648092133657, 10.817832776478358, 16.865570885794504, 14.605273246765137, 20.111847434725078, 17.234454223087855, 12.465530327388219, 6.354430726596287, 6.309875837394169, 5.469376572540828, 10.84397884777614, 11.37542918750218, 14.936596359525408, 11.451962726456777, 5.862812238080161, 3.9009002106530324, 1.0006840122597558, 2.379055597952434, 2.4574119533811296, 1.341372862458229, 1.2015628388949802, 10.85987285205296, 47.76422391619001, 63.936308997017996, 59.43168067932129, 61.298022406441824, 52.03228344236101, 48.14137213570731, 42.993462221963064, 49.842336314065115, 51.63357496261597, 56.8943201473781, 54.62088693891253, 57.21876628058297, 51.63171631949288, 54.65662152426583, 39.61743327549526, 38.558163029806956, 62.16998658861433, 54.15651798248291, 53.59853594643729, 46.481944288526265, 44.70742647988455, 43.66222286224365, 46.23715925216675, 44.111899852752686, 43.09700427736555, 39.25377150944301, 41.51029280253819, 40.815031732831685, 46.68166330882481, 48.95307459150042, 51.44169698442732, 41.07710041318621, 32.136693477630615, 8.676394496645246, 3.1767372403826033, 11.706785304205757, 17.217931406838552, 11.609025018555776, 11.708095908164978, 5.701655719961439, 2.1570669497762407, 6.025910343442645, 6.886413906301771, 12.392583795956202, 11.488862872123718, 7.587634359087263, 5.835752912930079, 3.07586698446955, 2.0780379218714575, 5.140565233571189, 9.681188259805952, 13.904250383377075, 13.610233885901314, 14.349715897015162, 14.695393119539533, 16.233555793762207, 17.32823232242039, 18.042119775499614, 17.88727743285043, 15.452965634209768, 10.65995146547045, 7.311932444572449, 2.821557487760271, 4.0627328753471375, 6.813059168202536, 8.114493676594325, 4.435377359390259, 0.08316841721534729, 10.986409102167402, 69.58134514944894, 53.400345529828755, 67.45318835122245, 22.938918318067277, 25.34940300668989, 31.04124743597848, 44.12465327126639, 52.413437298366, 33.193920952933176, 59.579135349818635, 20.350568430764334, 0.6265717755470956, 0.04306114864136491, 0.05237058802906956, 0.03016642521002463, 0.01637897191436163, 0.041423697756337266, 0.14865936871085847, 0.0666549511786018, 0.20036376427326882, 0.02834970367673252, 0.0746308181967054, 0.019617802762825574, 0.1885642981422799, 0.16557596597288335, 0.08886027429252863, 0.036724764720669816, 0.23166393328990253, 0.07765694188752345, 0.11741790654403822, 0.11221899837255478, 0.11848195801888194, 0.06556409757052149, 0.30834243446588516, 0.30868938299162046, 0.4139377639761993, 0.2968592063656875, 0.5513763619320733, 0.41634602046438624, 0.2377593219280243, 0.401274780609778, 0.16794139333069324, 0.31475358616028515, 0.2274800863649164, 0.3317851136837687, 0.18092138825782708, 0.2445921152830124, 0.2091067558420556, 0.28112520064626423, 0.26559801240052494, 0.3390869104436466, 0.23087116011551448, 0.2880542374082974, 0.25011210622532026, 0.09582344815135002, 0.2507372812501022, 0.2670080353106771, 0.3134707749954292, 0.2862772356186594, 0.26642927208117073, 50.95200879233224, 99.75642667497907, 56.64892714364188, 66.58567796434674, 76.76614379882812, 62.76226493290493, 35.04057148524693, 42.152271611349924, 40.12503392355782, 67.98310661315918, 85.41502516610282, 67.40730244772774, 80.35627801077706, 15.836533989225115, 0.9234884402581623, 16.01664171900068, 6.285174122878483, 2.9775927492550442, 2.8932162140096938, 3.745270550251007, 7.96185564994812, 16.748535428728374, 16.580866711480276, 14.816632236753192, 18.284327030181885, 12.830649478094918, 17.179935182843888, 26.121822084699357, 24.45170964513506, 27.610077585492814, 24.890884433473857, 20.10409324509757, 13.281459024974279, 15.609114238194056, 13.316020233290535, 17.761824233191355, 17.796238660812378, 19.879091467176163, 16.229504993983678, 10.708496791975838, 9.743276493889944, 8.291203737258911, 4.857265029634748, 2.6069213364805495, 1.698343187570572, 1.3906796681029456, 11.339923024177551, 49.98742512294224, 67.62030642373222, 61.289260728018625, 62.13090297154018, 55.78718376159668, 49.0623836517334, 43.50718770708357, 49.98184224537441, 51.39303527559553, 56.92085879189627, 54.96867554528372, 56.009300300053184, 52.50898197719029, 53.54954072407314, 42.09353848866054, 41.58217191696167, 61.46880217960903, 55.66917208262852, 55.20247547967093, 45.78655120304653, 45.93751471383231, 44.64950977052961, 48.38692494801113, 43.471571241106304, 45.95588575090681, 40.60103416442871, 44.81297656467983, 43.9747702053615, 51.52294921875, 53.45578868048531, 58.7984288079398, 52.169496468135286, 46.99114302226475, 20.806702034814016, 8.199802790369306, 18.17017160143171, 18.595936366489955, 15.405691828046526, 16.75369794028146, 12.73481558050428, 12.340212617601667, 13.4662116255079, 10.464270217078072, 15.63608193397522, 18.548005955559866, 15.672393219811575, 10.397606594221932, 6.26959365606308, 6.102283205304827, 10.07300933769771, 20.830581256321498, 23.857965230941772, 23.79238986968994, 26.19462878363473, 27.346435138157435, 31.086077213287354, 25.8757255758558, 21.86474766050066, 23.67929925237383, 18.5404497895922, 13.180841292653765, 9.692036134856087, 5.7118904164859226, 6.28375061069216, 9.085514851978846, 13.186494520732335, 6.404692258153643, 0.14551465745483125, 13.498472111565725, 73.31291689191545, 54.330014501299175, 74.51924923488072, 21.985092197145732, 45.960384709494456, 37.07103313718523, 65.01044491359166, 64.8164164679391, 50.35773631504604, 75.54726995740617, 45.2125118800572, 1.2705225156886237, 0.37366092950105667, 0.17073991602020605, 0.19865031407347747, 0.10190356975155217, 0.18043276162019797, 0.2896377481520176, 0.15909058254744324, 0.3376449692462172, 0.12935417890548706, 0.18860521380390438, 0.27759641142828123, 0.3793925419449806, 0.3829399501638753, 0.3203550013048308, 0.18100895998733385, 0.4145645403436252, 0.29584422654339243, 0.27827953334365574, 0.24991638958454132, 0.39655565097928047, 0.24633578743253434], [0.12999250393893036, 0.016825403851856078, 0.12797406581895693, 0.06543687903987509, 0.10477956078414406, 0.07040385715663433, 0.2179234634552683, 0.01954044807436211, 0.0718786394489663, 0.13201480970851012, 0.18510226319943154, 0.10018920352948563, 0.1165094974317721, 0.04232846652822835, 0.11853656651718275, 0.11389502058071749, 0.07484445494732686, 0.2089962496289185, 0.05518715635740331, 0.12042560800909996, 0.04621986486017704, 0.20130781004471437, 0.07260741320039545, 0.023996094075430716, 0.15823527558573655, 0.12036262638866901, 0.3776764454586165, 2.643864474126271, 51.34118086951119, 59.53821046011788, 40.11769315174648, 66.27181393759591, 51.50732272011893, 38.76008115495954, 25.613545724323817, 25.061094454356603, 38.22793599537441, 65.29689134870256, 66.28564780099052, 75.08497851235526, 2.1871055322034016, 0.6040159144571849, 4.474744549819401, 1.260259483541761, 1.286332164491926, 0.7790158497435706, 4.946074732712336, 8.910276072365896, 11.95418460028512, 15.373485190527779, 19.389314685549053, 11.556179625647408, 15.746323789869036, 10.277621626853943, 15.177361863000051, 13.802511385508947, 12.63382351398468, 13.092382039342608, 6.705629161425999, 3.8847243700708662, 4.867069372109004, 7.313332506588527, 13.94368314743042, 13.789162158966064, 15.785124267850604, 12.25890132359096, 10.615868619510106, 4.957316483770098, 2.799315218414579, 0.8588857725262642, 0.08509420816387449, 0.3831997205104147, 0.1171088202723435, 3.4370866758482794, 18.45005546297346, 49.47251149586269, 61.626185825892854, 58.648556164332796, 56.69957603727068, 49.71778290612357, 42.07204076222011, 43.47865840366909, 46.71946498325893, 52.58481809071132, 55.0065084866115, 59.12476485116141, 52.68939195360456, 53.75541237422398, 36.27672202246529, 29.824534484318324, 59.63795185089111, 49.07337917600359, 51.838383538382395, 41.92466252190726, 43.328657218388145, 41.03821134567261, 42.71286269596645, 39.90047856739589, 41.2227589743478, 40.85808277130127, 43.28313956941877, 48.2232323374067, 52.28752204350063, 53.019288948604036, 49.360315459115164, 44.08517708097185, 22.187475851603917, 5.447128874914987, 6.9453233395303995, 15.189258916037423, 21.46566571508135, 12.088977915900093, 8.59728925568717, 2.33005234173366, 3.7183063285691396, 6.115602033478873, 9.931567464556013, 11.705115130969457, 10.62300181388855, 10.724588819912501, 3.119768960135324, 2.941593263830457, 3.422075092792511, 2.7369366799082075, 7.208857221262796, 8.948189786502294, 9.680971128599984, 14.098720039640154, 8.326834099633352, 11.621295537267413, 13.303250312805176, 20.72328543663025, 16.387402806963237, 13.467936515808105, 13.93870563166482, 11.506951638630458, 4.755530374390738, 1.7074849541698183, 4.236489951610565, 5.814709424972534, 4.6444742764745435, 0.6938319663916315, 6.335602845464434, 42.79328809465681, 65.38536970955985, 36.3117652620588, 22.16341597693307, 30.07136923926217, 34.13045474461147, 61.09796987261091, 23.15944024494716, 35.222037587847026, 14.702063390186854, 0.6405117075358118, 0.07639170477965049, 0.2241891643830708, 0.018572383859593953, 0.19074896377112183, 0.02802980155684054, 0.0671197883784771, 0.042858850210905075, 0.08322799258998462, 0.06798891709851367, 0.09550058083342654, 0.045150564916964085, 0.05424362966524703, 0.017844120705766336, 0.025420249173683778, 0.122309804760984, 0.08773919873471771, 0.03602267096617392, 0.014712803731007236, 0.046307969239673445, 0.020953364936368804, 0.10031368077865668, 0.05863466725817748, 0.08044370556516306, 0.11987630677010332, 0.17439464133765015, 0.06172418647578784, 0.1381021509213107, 0.1246341128966638, 0.13437499877597603, 0.07230883743613958, 0.20393450052610465, 0.20121619424649648, 0.07472341108535017, 0.052171091948236735, 0.1855955310165882, 0.10243858104305607, 0.12343257665634155, 0.06884815956332854, 0.10829494215015854, 0.15900925334010804, 0.1755687240511179, 0.05843597184866667, 0.13876369542309216, 0.21470206417143345, 0.1480142990393298, 0.08715462724545173, 0.03485788757513676, 0.0683205443035279, 0.25174848841769354, 2.700293400457927, 68.85632841927665, 63.83771405901228, 47.932839325496126, 74.96495532989502, 44.62570176805769, 37.70520911897932, 22.57611118044172, 31.926051889147075, 51.58721310751778, 70.4851598739624, 72.47189998626709, 77.94811575753349, 2.9205558555466786, 0.7626835661275047, 7.951119814600263, 4.493170303957803, 3.1933343155043463, 2.0605108737945557, 6.751491180488041, 11.588997704642159, 15.01511447770255, 17.437716824667795, 21.668738978249685, 13.817429167883736, 17.117766175951274, 13.11357317652021, 18.74048147882734, 17.095372131892614, 20.564972468784877, 14.515014410018921, 11.314542123249598, 6.7922593014580865, 3.743894806929997, 7.074629749570574, 12.244324002947126, 14.090370910508291, 14.263174346515111, 11.142976335116796, 8.912462149347578, 5.735908601965223, 3.636471314089639, 1.3603190800973346, 0.12462800608149596, 0.6421259152037757, 0.6880055218935013, 4.546290584972926, 24.05076037134443, 55.945237909044536, 60.44927910396031, 58.822580746241975, 56.941126687186106, 54.03790875843593, 42.84750141416277, 45.670627457754954, 49.42576054164341, 55.116675649370464, 55.72504254749843, 61.160941396440776, 52.970008850097656, 54.993261745997835, 36.49356140409197, 33.3775166784014, 62.50910036904471, 51.44821092060634, 54.89604949951172, 46.494961738586426, 46.5622307232448, 45.57740347726004, 45.94158288410732, 42.41541378838675, 43.75171218599592, 43.20760570253645, 44.42437423978533, 48.85061992917742, 53.12970972061157, 55.7867043358939, 53.058984007154194, 48.87463985170637, 35.9472245488848, 8.47478209223066, 4.825727590492793, 15.030866043908254, 21.589334964752197, 13.846278956958226, 11.728107588631765, 4.064455594335284, 3.5594005925314764, 5.57414151089532, 8.390247702598572, 10.54685824257987, 8.486790316445486, 9.059647577149526, 5.90276003735406, 4.268323123455048, 2.4724871558802466, 4.000553446156638, 11.092321361814227, 11.562992334365845, 11.014565808432442, 14.037159868649074, 10.680441703115191, 12.89329617364066, 14.021218964031764, 20.11319191115243, 17.38415663582938, 14.27335866859981, 13.767052122524806, 8.683175069945198, 3.643972328730992, 3.044250726699829, 4.669102166380201, 7.166200927325657, 5.245515601975577, 0.48939625918865204, 4.435365634305136, 50.695901666368755, 67.15374878474644, 55.60617276600429, 25.848584175109863, 30.8208783694676, 33.81944990158081, 63.43327331542969, 32.42278902871268, 38.090504101344514, 33.719750199999126, 2.6077620685100555, 0.20279068047446863, 0.14084605154182228, 0.03429297663803611, 0.10580230983240263, 0.020672001909198504, 0.07301840864654098, 0.05403221511681165, 0.11768207379749843, 0.14872476591595582, 0.12057743700487272, 0.1275503614119121, 0.16218333159174236, 0.12377017496951989, 0.1611626385045903, 0.08323164310838495, 0.19841636876974786, 0.13604670550142015, 0.06493406423500606, 0.1752494733248438, 0.0670485489868692, 0.03926112522770252, 0.12324882937329155, 0.23753830950175012, 0.207597748243383, 0.2949266843497753, 0.21991759645087378, 0.25028540406908306, 0.21961171286446707, 0.4319436949278627, 0.23542741420013563, 0.3968281777841704, 0.3407758655292647, 0.4076661190816334, 0.20964921744806425, 0.3440202128674303, 0.21485107046152863, 0.34531306635056225, 0.22615094482898712, 0.27505939613495556, 0.3138585170464856, 0.23222581456814492, 0.23956631496548653, 0.35940887140376226, 0.32521494052239824, 0.28906273043581415, 0.29043749666639734, 0.2759448843342917, 0.3282251389963286, 0.6413480969411987, 7.716350606509617, 93.0100246156965, 75.12282535008022, 62.444148608616416, 78.53436306544712, 70.88880157470703, 55.534793921879356, 34.58686801365444, 37.26541246686663, 50.44628068378994, 79.07967158726284, 79.2258061000279, 92.19329166412354, 3.793571387018476, 2.00713872058051, 13.30555190358843, 9.865284255572728, 3.5378920095307484, 2.656701053891863, 6.014733297484262, 12.813578622681753, 15.661241361073085, 21.80793571472168, 27.299143961497716, 15.833214487348284, 21.459719794137136, 21.28413881574358, 28.840834583554948, 25.11696318217686, 26.225362403052195, 21.51373335293361, 18.17862582206726, 15.814351865223475, 13.561513117381505, 17.793620926993235, 20.281129871095928, 20.750273977007183, 24.015493052346365, 19.30962405885969, 14.750874485288348, 11.224413565226964, 6.262025330747877, 2.756992655141013, 0.30416795132415636, 0.866181055349963, 0.8988004050084523, 6.836713007518223, 24.58534608568464, 56.31633077348982, 63.02212061200823, 60.35778522491455, 57.53252608435494, 55.40865979875837, 43.06137044089181, 47.42727797372, 48.63655982698713, 55.98709733145577, 55.86598675591605, 59.51089014325823, 53.660635471343994, 53.803507804870605, 38.010985442570274, 34.086177349090576, 62.96696581159319, 53.990275382995605, 56.62491416931152, 48.32227543422154, 49.152230807713096, 45.8820298739842, 47.75862366812569, 44.22399166652134, 46.488374846322195, 45.12308856419155, 46.918781008039204, 53.18597623280117, 57.850076130458284, 60.58963966369629, 58.34444740840367, 55.94840976170131, 45.329130445207866, 23.03458285331726, 12.373588289533343, 19.80049170766558, 23.138310773032053, 16.728581939424785, 16.701847008296422, 10.724653959274292, 9.972339493887764, 9.648641160556249, 14.742811100823538, 15.078059945787702, 16.32902925355094, 18.744897059031896, 13.320344618388585, 8.706448929650442, 8.639712350709097, 8.527491995266505, 21.202619075775146, 18.9371554510934, 22.073957920074463, 25.14282785143171, 23.892110415867396, 22.23303345271519, 24.036283799580165, 28.98245276723589, 24.222398247037614, 18.912386860166276, 21.46402246611459, 16.26802580697196, 7.920392274856567, 4.262727218014853, 9.634292261941091, 14.799471923283168, 11.477885586874825, 0.970176209296499, 7.986826607159205, 58.998286792210166, 79.88266100202287, 47.44003486633301, 30.917892592293875, 45.5729774747576, 49.8252854347229, 82.91359724317277, 42.935333592551096, 56.18459987640381, 63.14684077671596, 6.542720828737531, 0.6262618207505771, 0.44347477331757545, 0.2896012429680143, 0.458843075803348, 0.19083479845098086, 0.27582926196711405, 0.20906997924404486, 0.2972768853817667, 0.1864078731409141, 0.2736243488533156, 0.2618189794676644, 0.33210451368774685, 0.24147563108376094, 0.2662359167422567, 0.291353383234569, 0.3651449350374085, 0.2738298092569624, 0.20049884702478135, 0.2625440891299929, 0.3715834995465619, 0.350678269884416, 0.23426787927746773], [0.08072831029338495, 0.1983282949243273, 0.09539044102919952, 0.08466489905757563, 0.023853874831859554, 0.10111214686185122, 0.023339930356347134, 0.035321089505617104, 0.09527948019759995, 0.07765418024999754, 0.09704014964933906, 0.08261830173432827, 0.050154831925673146, 0.03334730238254581, 0.08839393074491195, 0.01850129204935261, 0.06227008146899087, 0.01342993404250592, 0.09687360322901181, 0.028203991674152867, 0.1323388373213155, 0.08423426002264023, 0.05954083041953189, 0.03470410439851029, 0.03713527501427701, 0.022759511501395276, 0.15045498950140818, 0.2200938391366175, 13.019881061145238, 77.77348668234688, 42.72029032026018, 52.47272627694266, 68.83091190883091, 43.21290717806135, 34.11486298697335, 22.245998791285924, 31.79149307523455, 66.93910503387451, 85.49637467520577, 53.609896251133506, 0.3227783484118325, 0.20157729701272079, 2.3738602995872498, 4.009975203445979, 3.441490965230124, 1.3301937537533897, 7.982686349323817, 12.999475938933235, 16.74494842120579, 18.405241319111415, 19.387086050851003, 18.64089294842311, 16.56256515639169, 13.278730119977679, 16.904727458953857, 15.884172575814382, 16.281465360096522, 8.767686009407043, 5.9534705962453565, 4.526732274464198, 6.882015696593693, 4.883254332201822, 13.760018808501107, 14.513781104769025, 21.782159634998866, 15.042363575526647, 11.97346237727574, 7.2303840432848245, 5.92465945652553, 3.1059800429003577, 0.06584815268537828, 0.3018134619508471, 0.31004998141101425, 4.132022048745837, 17.99211880138942, 34.27301788330078, 56.39640528815133, 64.34525912148612, 60.44442926134382, 56.11177233287266, 48.99223811285836, 46.68850728443691, 49.48698459352766, 53.32911259787423, 55.64554820741926, 60.41199507032122, 48.69326407568795, 54.817163126809255, 37.02730812345232, 18.02596173967634, 60.6420499256679, 50.10157707759312, 54.51059470857893, 49.564175605773926, 46.820999009268625, 40.7174060685294, 40.194008690970286, 39.87765373502459, 41.60295050484793, 46.3782320022583, 53.4707099369594, 55.946453843797954, 54.283485889434814, 56.82210404532296, 54.034747328077046, 45.04451833452497, 21.556233746664866, 12.325335655893598, 13.184853008815221, 20.505735601697648, 22.869794164385112, 14.045694862093244, 11.527488776615687, 4.723566055297852, 4.82652576480593, 6.59326810496194, 8.943158422197614, 12.697288359914507, 10.335070201328822, 9.374229873929705, 7.729549578257969, 2.3851626302514757, 2.4217898419925143, 1.9704509292330061, 7.278641019548688, 5.29881306205477, 7.355883274759565, 10.608760612351553, 8.923561028071813, 9.65488498551505, 12.013930422919136, 16.498344693865093, 18.09712518964495, 16.38104694230216, 13.537900532994952, 7.516032304082598, 2.5064977194581712, 2.376163193157741, 4.137291823114667, 5.094694529260908, 3.16755411028862, 0.3896157033741474, 2.1384451261588504, 47.625676836286274, 69.56530175890241, 24.39768045289176, 21.349486623491558, 29.518956184387207, 53.72689001900809, 29.501057624816895, 20.803726468767437, 21.303322792053223, 1.9094364089625222, 0.11226859249706779, 0.011585708940401673, 0.061867011311863146, 0.04304997656228287, 0.06260166117655379, 0.05047203008351581, 0.07519499292331082, 0.05399557761847973, 0.12708042162869657, 0.010085880224193846, 0.060578371531197, 0.10686006450227328, 0.16800664125808648, 0.0446882382966578, 0.09048231225460768, 0.09021595333303724, 0.05668966019792216, 0.12457981652447156, 0.03628645145467349, 0.034706662475530586, 0.09712083424840655, 0.07726715066071067, 0.13516087803457463, 0.08987508448106901, 0.18517832697502204, 0.09913740639707871, 0.13082452357879706, 0.043676366164748154, 0.12671188211866788, 0.07107863987662963, 0.11428236908146314, 0.09315747049238, 0.1889341947223459, 0.06867013233048574, 0.11328464440469231, 0.12257574977619307, 0.011062041058072021, 0.0959817503712007, 0.06847638344126088, 0.038522658603531976, 0.06747232124741588, 0.1591947783849069, 0.12167498096823692, 0.07294117100536823, 0.12395749134676796, 0.1493777065937008, 0.05662982358730265, 0.09816853302930083, 0.058943875666175566, 0.08816430092390094, 0.30336681859833853, 22.113837105887278, 91.72911725725446, 47.48743895121983, 65.93843242100307, 65.98933492388043, 44.4413069997515, 28.82785882268633, 19.056291001183645, 45.007130077907014, 68.7241597856794, 88.98833778926304, 59.059229442051475, 0.5155169261353356, 0.5855607390403748, 6.164978538240705, 4.503527462482452, 3.0242149446691786, 4.0519948686872205, 8.334816711289541, 15.770906516483851, 17.21002609389169, 21.335164649145945, 21.279224702290126, 19.965862308229717, 18.216349329267228, 16.132539408547537, 19.881573711122783, 20.812243223190308, 22.731208869389125, 12.700134515762329, 11.536386813436236, 6.226646840572357, 5.221790977886744, 5.821746213095529, 12.677686623164586, 12.496123245784215, 17.73705390521458, 13.036116395677839, 12.581967370850698, 8.434985416276113, 5.263018114226205, 2.492584820304598, 0.2578848334295409, 1.2927288498197282, 1.0980586728879382, 5.0738911884171625, 20.314123392105103, 39.1703097479684, 59.488787923540386, 64.54154573168073, 62.791169439043315, 57.70904854365757, 49.42396790640694, 50.23970379148211, 51.48283379418509, 56.15256173270089, 54.99115644182478, 60.4862574168614, 49.97017969403948, 54.098337241581504, 38.43843167168753, 20.83262402670724, 65.2906379699707, 54.079653535570415, 59.41201032911028, 53.01353236607143, 50.32370751244681, 43.951955795288086, 46.31570168903896, 42.60574926648821, 43.52456515175955, 47.02659967967442, 53.416868346078054, 58.11609138761248, 55.420812198093955, 57.81423037392752, 58.07319668361119, 52.842717851911274, 31.15062597819737, 12.44404215472085, 16.82103293282645, 22.35710222380502, 24.74651997429984, 16.420477969305857, 13.540533900260925, 6.280841052532196, 3.48767694405147, 5.94595307963235, 6.6189247625214715, 12.426094089235578, 9.264982478959219, 9.071033937590462, 8.918507082121712, 3.9563246880258833, 3.0568458565643857, 1.566817045211792, 10.936473267418997, 8.9768146276474, 9.291535019874573, 11.618715150015694, 10.850783739771162, 12.190618770463125, 11.98698878288269, 18.236526897975377, 19.467071975980485, 14.150813290051051, 11.1706041097641, 7.0063194036483765, 2.4034257531166077, 3.1131562292575836, 6.840370365551539, 4.166641882487705, 4.624944193022592, 0.6256619415112904, 1.598526235137667, 58.078056948525564, 77.89834581102643, 38.33537599018642, 17.41852763720921, 29.801327501024517, 49.66595976693289, 44.60635450908116, 24.721268483570643, 41.57070391518729, 10.260812197412763, 0.6157182550856045, 0.11813922998096262, 0.03650368104821869, 0.08541365566530398, 0.05873916843639953, 0.051863688443388255, 0.02562670363113284, 0.07552917820534535, 0.0997445188196642, 0.049981710501015186, 0.04512792559606688, 0.024013971776834557, 0.23947009869984218, 0.056898503098636866, 0.17741230369678565, 0.1150902057332652, 0.26483482335294994, 0.14429594070783683, 0.09222547550286565, 0.08878875670156308, 0.07909239629017455, 0.10952752815293414, 0.22964637726545334, 0.26651892012783457, 0.3564809113740921, 0.181702585624797, 0.31865252980164116, 0.27337969626699177, 0.2575621221746717, 0.1678094725523676, 0.22251909971237183, 0.12302369145410401, 0.35910214643393246, 0.2879610066967351, 0.39389704221061295, 0.2783485810671534, 0.18137030702616486, 0.2919981543506895, 0.24128284571426256, 0.3411830136818545, 0.29321639612317085, 0.2445015987115247, 0.22339649977428572, 0.18912911069180283, 0.2809022068977356, 0.2213086610926049, 0.13742102389889105, 0.18640439904161862, 0.21198210226637976, 0.3277681592319693, 0.22545806558004447, 38.39394930430821, 101.770494052342, 59.945277622767854, 73.50084481920514, 85.10664326804024, 62.84102971213204, 46.58400637762887, 31.765802110944474, 44.72962597438267, 79.83057730538505, 100.74536378043038, 68.11411489759172, 1.123410478234291, 2.091041909796851, 10.112000022615705, 9.960471102169581, 8.627798795700073, 3.746255023138864, 8.630235876355853, 16.31930524962289, 20.065080847058976, 24.812112706048147, 29.073107651301793, 23.605142865862163, 26.40060986791338, 25.727746316364833, 29.191911424909318, 27.29969460623605, 28.454697132110596, 17.950222900935582, 17.734359741210938, 15.692133052008492, 16.401719570159912, 16.011388880865915, 22.508887359074183, 21.362802846091135, 29.761479582105363, 19.865066528320312, 18.467613560812815, 15.022901671273367, 10.856514266559056, 5.455427195344653, 0.40670420069779667, 1.1940879885639464, 1.2615174331835337, 10.005547540528433, 26.42789544378008, 40.35918821607317, 60.76743711744036, 68.97875567844936, 65.63285759517125, 60.507887159075054, 51.94058806555611, 51.05644369125366, 52.32241242272513, 54.99216740471976, 57.04045813424246, 59.17474324362618, 49.79651294435774, 55.43230104446411, 39.83457490376064, 23.677054984228953, 63.34760202680315, 54.736977440970286, 59.24332891191755, 54.487078530447825, 51.204916272844585, 44.80421141215733, 46.61729172297886, 43.54655967439924, 46.18814665930611, 49.62748759133475, 56.98844739368984, 58.81402056557791, 57.67984526497977, 61.25317178453718, 61.71219062805176, 59.03649493626186, 42.830311570848735, 22.773149933133805, 21.65287971496582, 23.590800046920776, 26.148501430238994, 20.133815901620046, 19.006785086223058, 13.10408193724496, 8.055738840784345, 10.34873296533312, 14.024525438036237, 17.806091206414358, 17.77660652569362, 18.52258423396519, 18.87928911617824, 9.969621011189052, 8.783346380506243, 7.939497215407235, 18.67526568685259, 17.171805790492467, 20.326501607894897, 22.691359213420323, 23.04143030302865, 22.518168415342057, 21.4029860155923, 25.793523175375803, 25.381694759641373, 21.390326397759573, 16.047335386276245, 11.431123341832842, 5.017788827419281, 5.59595798594611, 12.395943249974932, 11.860646213803973, 8.227157848221914, 0.95767813708101, 2.525582032544272, 66.8231326511928, 83.59093543461391, 32.27133914402553, 30.792613097599574, 47.428205558231895, 72.34706170218331, 57.240715639931814, 38.02895695822579, 67.0536391394479, 28.959205831800187, 1.2393408460276467, 0.3569936395755836, 0.2744469775685242, 0.30929984737719807, 0.20487725708101476, 0.1478596744792802, 0.17482374688344343, 0.26747470455510275, 0.32392518115895136, 0.1403909038220133, 0.21611021432493413, 0.11698382055120808, 0.31664116201656206, 0.1366134179489953, 0.42460438875215395, 0.19310936996979372, 0.42078952917030876, 0.29896654614380425, 0.18979506567120552, 0.20802032628229686, 0.3806389022086348, 0.22719255036541394, 0.47006729351622717], [0.05402785213664174, 0.07182970350342137, 0.0976041072447385, 0.1164986001593726, 0.05417986433686955, 0.06248745694756508, 0.049084809342665334, 0.11948127725294658, 0.01877953381543713, 0.20484694013638155, 0.10685494156288249, 0.09147067314812116, 0.046017756419522424, 0.0839129261938589, 0.08084649073758296, 0.017592368946809853, 0.04139180661046079, 0.1336842229855912, 0.04801113624125719, 0.0415727345805083, 0.21733696492654936, 0.14530288667551108, 0.04945252103997128, 0.247114609926939, 0.09351042405303035, 0.10710582988602774, 0.2086838385356324, 0.3406240908162934, 3.115477578980582, 74.88135460444859, 62.32521629333496, 36.94836963926043, 65.84249864305768, 60.079961504255024, 34.785225187029155, 32.58649206161499, 21.677646568843297, 60.15047877175467, 88.83217702593122, 29.252763748168945, 0.06319664817835603, 0.628833957016468, 4.338834745543344, 1.4729641441787993, 2.056406659739358, 3.0158052359308516, 10.131349887166705, 19.07311953817095, 22.943914072854177, 25.910699333463395, 26.223053864070348, 20.812637533460343, 20.282052244458878, 19.210799830300466, 13.216252786772591, 20.16305044719151, 21.449228014264786, 8.694247892924718, 3.6093075488294875, 7.855316315378461, 5.901822899069105, 6.822714558669499, 11.37706548827035, 18.80430589403425, 21.554501908166067, 18.19332994733538, 13.807828494480678, 10.92952767440251, 9.44281119959695, 3.1225543192454746, 0.4237179234623909, 0.032531119750014374, 1.0972809089081628, 3.9932274392672946, 22.698666981288365, 27.950810296194895, 39.89937032972063, 59.99187919071743, 60.40375450679234, 57.431874479566304, 51.2334942136492, 45.608785016196116, 49.17898137228829, 55.80317504065377, 57.391818114689414, 54.448661940438406, 51.42302022661482, 53.835441725594656, 40.62194129398891, 13.453274079731532, 51.95344918114798, 53.18415927886963, 52.34733213697161, 53.136803831372944, 51.59575591768537, 41.96256494522095, 40.85604347501482, 39.70549821853638, 42.46935265404837, 52.80152545656477, 56.66695771898542, 54.110583441598074, 57.903827394757954, 57.6540778705052, 53.092880793980186, 42.93754659380232, 28.363936288016184, 23.189649275371007, 27.05362936428615, 27.3381633077349, 21.996751274381364, 16.584519726889475, 11.471233555248805, 5.6450261643954684, 5.4845375418663025, 7.647775360516139, 8.264878749847412, 12.294435279709951, 11.065776637622289, 7.642299311501639, 6.032924549920218, 1.0648862357650484, 3.2839136379105702, 2.8785494353090013, 1.788051271012851, 4.139109645571027, 5.402692973613739, 4.672521982874189, 6.12506547995976, 11.509830798421588, 11.974517634936742, 16.376294374465942, 19.93884423800877, 15.936964988708496, 11.932223950113569, 7.779371636254447, 1.9170138537883759, 2.657410638672965, 3.221179221357618, 4.629067948886326, 1.8692977513585771, 0.4139695736978735, 0.3911377117037773, 55.101104736328125, 60.4239181791033, 20.87738605907985, 39.35519436427525, 45.898632594517295, 52.273194858006065, 17.656025750296457, 25.548757246562413, 11.904261793409075, 1.852211696760995, 0.04279114937941943, 0.07971947799835886, 0.03807510029790657, 0.11983661247151238, 0.045729233151567836, 0.07628800427275044, 0.09122699086687394, 0.03784588438325694, 0.025761111240301813, 0.03424073961962547, 0.06680061907640525, 0.02362082519435457, 0.07803905888327531, 0.07852083231721606, 0.042007651778736284, 0.12274459643023354, 0.10721870418637991, 0.10046873281576804, 0.061357601146612845, 0.023947176789598804, 0.10824992135167122, 0.05376941171873893, 0.07650772748248917, 0.10266759339720011, 0.06462465905185256, 0.03622162761166692, 0.11672563797661237, 0.10298378393054008, 0.09044996649026871, 0.0893391707379903, 0.10968199664992945, 0.05714541181389775, 0.045429924569491825, 0.07510873076639005, 0.09340867094163384, 0.016112728343744363, 0.13693368647779736, 0.017712065916774527, 0.05585073985691581, 0.10365191700735263, 0.1466493308544159, 0.0021371387036716832, 0.2198388185352087, 0.1414861814784152, 0.217906350802098, 0.08324336140815701, 0.1888512098895652, 0.08867509530058929, 0.13833819968359812, 0.11297226045280695, 0.3447455939437662, 4.122440917151315, 89.49185984475272, 66.3351537159511, 42.43992703301566, 77.83927917480469, 55.2544584274292, 39.42616673878261, 24.249906165259226, 30.50105278832572, 68.93189007895333, 94.248304775783, 32.430393832070486, 0.11766821811241762, 2.2617615376199995, 4.0486436656543185, 3.903088024684361, 2.548080082450594, 4.916658665452685, 10.028560842786517, 19.744386741093226, 21.978581735066005, 26.637265511921473, 24.30823802947998, 22.650646243776592, 20.808515514646256, 24.57506275177002, 17.257746321814402, 21.919469935553415, 25.32865742274693, 13.100508826119558, 6.834821794714246, 7.92931376184736, 5.4541283164705545, 6.4710128137043545, 10.150906460625784, 14.456638251032148, 16.780663899012975, 16.664173875536235, 12.16204343523298, 8.799752814429146, 8.005302735737391, 1.323096277458327, 0.2364493693624224, 0.11494183726608753, 1.4594979924815041, 7.907292314938136, 30.914241313934326, 29.263887814113072, 45.19689927782331, 61.63439164842878, 62.90826048169817, 58.66769845145089, 53.94244050979614, 47.726349285670686, 51.07128504344395, 57.59602567127773, 57.504403250558035, 55.51442527770996, 54.443634918757844, 55.94645731789725, 44.28346129826137, 15.7727530002594, 56.9488912991115, 57.351793016706196, 57.215128898620605, 58.104487895965576, 55.30131360462734, 46.55260746819632, 43.24213130133492, 43.4845608983721, 45.29001556124006, 56.62808949606759, 60.510075841631206, 58.23924820763724, 60.95125865936279, 60.45944431849888, 59.37121745518276, 50.93861613954817, 31.895153250013077, 27.6185439654759, 30.667007037571498, 31.445556163787842, 24.29209041595459, 20.491604702813284, 13.130588446344648, 5.480828940868378, 2.450560595308031, 5.960586420127323, 5.98639463526862, 8.856255565370832, 9.072478294372559, 5.5561487163816174, 6.7716522472245355, 1.8523146169526237, 3.417554421084268, 3.503106938941138, 5.999382555484772, 7.051549570901053, 6.61947193316051, 6.859110959938594, 9.458302208355494, 13.760825668062482, 13.005970767566136, 17.982693570000784, 17.467277935573033, 13.879929951259069, 9.411806600434439, 4.549172350338527, 1.8323437571525574, 3.894275971821376, 5.246612548828125, 5.092997866017478, 3.089308274643762, 0.2418741211295128, 0.48995928040572573, 55.69436625071934, 79.10644994463239, 19.472253595079692, 28.611358165740967, 47.77844687870571, 57.02227469852993, 27.813930783952983, 32.45101261138916, 15.337293761117117, 2.148449880736215, 0.08278454281389713, 0.03459698407511626, 0.03255982517397829, 0.021728923677333763, 0.024706679695684994, 0.016095391774017895, 0.07300668356141873, 0.02296377089805901, 0.0782663274024214, 0.16463695493127617, 0.06245973879205329, 0.06311811453529767, 0.06186802911439112, 0.16225985677114554, 0.12448714221162455, 0.20909949551735604, 0.13472808125827992, 0.14159800404948847, 0.07283486492399659, 0.13436676136084966, 0.0968774708786181, 0.10777295873101268, 0.14388355426490307, 0.278619750802006, 0.19827927755458014, 0.2395821926849229, 0.37177555209824015, 0.1313193520264966, 0.22152276603238924, 0.18382839512612137, 0.3984103857406548, 0.09181593890701022, 0.34829294787985937, 0.28977500221558977, 0.302116441407374, 0.17628961322563036, 0.2511576201234545, 0.15619363156812532, 0.2269257775374821, 0.22499273983495577, 0.29699925599353655, 0.213562885299325, 0.3763993339879172, 0.28296389483979767, 0.36614680556314333, 0.27839871123433113, 0.4607305973768234, 0.2084466362638133, 0.33058019833905355, 0.3399139903485775, 0.5345406596149717, 7.861259630748203, 109.91922324044364, 79.11210577828544, 53.82200043542044, 85.2379503250122, 82.35091822487968, 48.904746396201, 45.0920718056815, 29.718025548117502, 77.72649601527623, 100.48345838274274, 37.80682304927281, 0.22360061667859554, 2.144681351525443, 13.5901084286826, 8.274264029094152, 7.254852124622889, 5.240409978798457, 12.991414291518074, 23.115927151271276, 29.760086468287877, 35.342338698250906, 33.93928895677839, 29.51254994528634, 29.55010495867048, 32.37551001140049, 27.802855355398997, 30.006017957414898, 35.90899556023734, 17.91920440537589, 16.210025719233922, 18.967812640326365, 13.987847634724208, 18.57228990963527, 18.569434200014385, 26.831057718821935, 32.99430962971279, 26.48751446178981, 19.961476257869176, 16.015547377722605, 13.79529481274741, 6.1248474802289685, 1.4011274789060866, 0.21563504982207501, 2.117413363286427, 15.095552035740443, 38.83556638445173, 31.57477876118251, 46.11547892434256, 64.358884538923, 66.24889877864292, 60.01625347137451, 55.69806964056832, 47.12443726403372, 52.23592472076416, 58.984223638262065, 56.80688401630947, 55.75231770106724, 55.539056641714915, 54.84962511062622, 44.80513899666922, 19.47904372215271, 57.5128870010376, 59.46883269718715, 60.23847770690918, 59.30272906167166, 56.698172501155305, 47.68391663687569, 45.81702600206648, 44.82877329417637, 48.162852491651265, 56.40364531108311, 62.25392082759312, 58.42613043103899, 60.943011147635325, 60.73637866973877, 62.70674187796456, 54.841989040374756, 45.65997239521572, 33.18038238797869, 36.36294916697911, 31.932617936815532, 25.176735060555593, 21.988564559391566, 16.557986293520244, 13.511250717299324, 12.283077580588204, 12.55000044618334, 13.478744438716344, 16.974956376211985, 15.979032857077462, 16.917100463594707, 18.87330150604248, 10.091923202787127, 8.812558344432286, 10.20886138507298, 13.570144517081124, 16.939583097185405, 16.715008633477346, 16.92520206315177, 18.47411707469395, 22.980023860931396, 20.813144751957484, 24.724893706185476, 25.55735390526908, 22.257286139896937, 16.425114154815674, 12.489656209945679, 3.623247806515012, 8.061836753572736, 8.810943756784711, 11.200054049491882, 5.184910374028342, 0.7892426209790366, 0.635968237050942, 62.00488349369594, 73.20286437443325, 27.559852531978063, 56.43311956950596, 65.46985980442592, 73.36828013828823, 39.33097641808646, 53.241523606436594, 43.10005106244768, 3.7868980765342712, 0.18172967274274143, 0.2770178924713816, 0.1468591203114816, 0.38263143386159626, 0.093840029223689, 0.2676442026027611, 0.3097973492528711, 0.24303889434252465, 0.19846903665789536, 0.2575571010155337, 0.2134446030748742, 0.19344201497733593, 0.1647671250892537, 0.29700617705072674, 0.26086998039058273, 0.32499626225658823, 0.31289532301681383, 0.2840366858456816, 0.2504418742443834, 0.30550566954272135, 0.22404587135783263, 0.19260319641658238, 0.2990039198526314], [0.09458561707288027, 0.10394680832645722, 0.10950177096362625, 0.013099949740405594, 0.08116346837154456, 0.036307153558092456, 0.11425639476094927, 0.06313435866364411, 0.024669117693390166, 0.12714328111282416, 0.059960931805627685, 0.013043702580034733, 0.036244280503264496, 0.09500964717673403, 0.07299261074513197, 0.04727035241999796, 0.10685439873486757, 0.029700824658253362, 0.051466562253023894, 0.16273027152887412, 0.1402086221746036, 0.18078687547573022, 0.24368179270199367, 0.09683483852339642, 0.12699211708136968, 0.04770845194746341, 0.16898219819579804, 0.03632893792486616, 0.06805438215711287, 39.764794145311626, 67.72720445905412, 54.20766714641026, 39.57847472599575, 64.30564744131905, 45.395468371255056, 27.463729415621074, 23.882221392222814, 33.76124136788504, 89.61627428872245, 13.256486330713544, 0.1305568279432399, 0.612765867795263, 4.089336659227099, 2.4021963562284196, 2.5154072642326355, 5.194478477750506, 13.51660430431366, 22.88101203101022, 29.656457560403005, 29.377807004111155, 28.528354985373362, 22.494019951139176, 22.33237358501979, 16.459516423089163, 15.800406830651418, 17.875871964863368, 22.770228215626307, 9.633640868323189, 3.0515693511281694, 9.533313223293849, 7.024754277297428, 5.600433494363513, 9.640173043523516, 21.626589468547277, 20.497706958225795, 17.809084142957413, 11.295754194259644, 12.624813437461853, 7.3378170898982455, 2.1003025557313646, 0.3082429612321513, 0.09875980844455105, 0.09059562760272197, 3.5261122073446, 8.989471639905657, 13.939297097069876, 29.721305097852433, 46.50785412107195, 61.12130887167794, 61.4552948815482, 54.4865574155535, 51.815256459372385, 52.04786477770124, 56.467165742601665, 58.16946744918823, 56.14745480673653, 57.698647090366904, 51.172391755240305, 44.213437352861675, 13.668213129043579, 48.974329130990164, 49.682701451437815, 50.070393562316895, 53.84211894444057, 51.58920724051339, 44.56530107770647, 38.89177731105259, 41.38350902284895, 48.06668594905308, 54.61610657828194, 55.565338202885215, 59.011648178100586, 56.15822451455252, 61.62001582554409, 53.14764649527413, 45.78681870869228, 37.95246771403721, 29.849277019500732, 36.30682509286063, 33.22658096040998, 24.013363429478236, 19.85240864753723, 12.565610442842756, 8.033151984214783, 5.036438226699829, 5.687388462679727, 5.635882769312177, 11.799647978373937, 11.986388632229396, 7.516525626182556, 6.980350077152252, 0.4109398334154061, 2.008714658873422, 2.0670560768672397, 2.5413774592535834, 4.421131815229144, 4.865247641290937, 5.0770269972937445, 8.261988299233572, 10.994283148220607, 14.220875450542994, 19.258655548095703, 21.52733792577471, 15.491323164531163, 9.51662538732801, 5.359139059271131, 0.7103053310087749, 2.890569167477744, 3.55088318671499, 2.127502364771707, 1.9184912145137787, 0.23661601756300243, 0.17347928402679308, 58.30588490622384, 24.958221163068497, 32.1310967036656, 40.686503955296104, 45.95078577314104, 34.04019069671631, 17.86124948092869, 6.215121950422015, 10.077070559774127, 0.45095893314906527, 0.037951549249035973, 0.07770462254328386, 0.03464580127703292, 0.0956704385046448, 0.015430919393630964, 0.057118779314415793, 0.05509422420124922, 0.05241492011451295, 0.08298649519149746, 0.040299467010689635, 0.06031985647444214, 0.027275718449215804, 0.013487780001014471, 0.057048815568642955, 0.04413872331913028, 0.07975492466773305, 0.0950827661103436, 0.040280583381120644, 0.07095739245414734, 0.005742960518026459, 0.16847378547702516, 0.12133101799658366, 0.0748743579855987, 0.03956873229305659, 0.0540542301854917, 0.11978684871324471, 0.03808345306398613, 0.07959590320076261, 0.09398007206618786, 0.0556632368825376, 0.023367109076519097, 0.04392412304878235, 0.04160146375319787, 0.04353510535189083, 0.024244419232543026, 0.10324278074715819, 0.10532814956137113, 0.04319254694772618, 0.06746791755514485, 0.07437558046409062, 0.044483042521668334, 0.07508456134902579, 0.11951554327138833, 0.1668118360851492, 0.0975700244307518, 0.05765626047338758, 0.0844979862283383, 0.04391105446432318, 0.037889140990695784, 0.13815886287816934, 0.04765352114502873, 0.02487421508080193, 48.691787583487375, 83.75844260624477, 56.0345014163426, 50.200814723968506, 64.78599725450788, 48.79421097891671, 26.85810705593654, 24.869103567940847, 49.874287605285645, 88.49033955165318, 16.680352755955287, 0.3037600432123457, 2.2186008478913988, 6.2175542541912625, 3.810738214424678, 3.855040797165462, 5.200410068035126, 11.670020648411342, 20.439698185239518, 29.90535593032837, 26.262399775641306, 27.974847589220317, 23.193126848765782, 25.557039499282837, 22.66942548751831, 20.13949431691851, 19.519197361809866, 25.44783639907837, 15.675655399050031, 4.217856185776847, 9.196882316044398, 6.291289406163352, 5.205847901957376, 8.633135880742755, 15.410545144762311, 15.756980589457921, 16.952894108636038, 11.278513107981, 10.055200236184255, 7.079450496605464, 0.8819528147578239, 0.30962714552879333, 0.3023963506732668, 1.0879549064806529, 8.22994407585689, 13.213549937520709, 18.73120215960911, 33.638174874441965, 52.22314350945609, 64.9555333001273, 62.42584705352783, 56.37756872177124, 51.843914304460796, 53.78584895815168, 56.75326476778303, 59.29980387006487, 58.57045841217041, 58.07901579993111, 54.50563022068569, 47.4664762360709, 16.29182165009635, 52.11266367776053, 55.65793684550694, 54.75694308962141, 57.33701072420393, 58.533021518162315, 49.44368689400809, 42.799937520708355, 46.687242712293354, 52.86009529658726, 57.68307965142386, 58.81989874158587, 61.85790130070278, 58.74993732997349, 63.83052962166922, 58.106742586408345, 51.008904116494314, 42.47021770477295, 39.954219409397666, 39.739540917532786, 36.99333838054112, 29.102173703057424, 22.565461329051427, 13.608863353729248, 7.401592867715018, 3.3393613483224596, 4.3883580310004096, 3.409704042332513, 7.262510342257364, 11.832155994006566, 4.125428642545428, 6.279133532728467, 1.0945458156721932, 2.3776670438902716, 5.397466625486102, 4.710484768663134, 6.607716883931841, 5.51460109438215, 5.778555342129298, 8.793964965002877, 11.315415859222412, 14.990639448165894, 18.578399113246373, 16.707572323935374, 12.504620024136134, 6.451279495443616, 4.868772549288614, 1.5952509194612503, 2.550626162971769, 4.769861902509417, 3.674005917140416, 2.645390037979398, 0.1237173985157694, 0.23630459713084356, 65.9327210017613, 31.47119849068778, 20.125809839793614, 40.889009203229634, 47.67995616367885, 49.054730210985454, 25.85501299585615, 25.219450848443167, 5.414074557168143, 1.0786908950124467, 0.05873896487589393, 0.036759312331144295, 0.06417659523763827, 0.08870022145232984, 0.031354187189468315, 0.09930260931806904, 0.06081303608204637, 0.021867514454892704, 0.020782078948936293, 0.08731278697294848, 0.09087445799793516, 0.05868968966283968, 0.008259159629233181, 0.0754836213641933, 0.1380242415304695, 0.1731877446706806, 0.08517665695399046, 0.03855183221665876, 0.033035759814083576, 0.10457853121416909, 0.09879855957946607, 0.06008897814899683, 0.09061106427439622, 0.22455484047532082, 0.3100179002753326, 0.308644029710974, 0.1668035986700228, 0.23743604070373944, 0.24361809183444294, 0.2623716869524547, 0.13100903082106793, 0.1705292308969157, 0.2974064312875271, 0.27247499195592745, 0.10508824672017779, 0.2050829210451671, 0.21739415185792105, 0.13329401106706687, 0.18201357179454394, 0.24607672276241438, 0.182566672829645, 0.19371598027646542, 0.2877942499305521, 0.318251189908811, 0.1480339222720691, 0.3241409281534808, 0.3309942404074328, 0.2982091110731874, 0.23532756098679133, 0.19683270874832356, 0.16287042972232613, 0.17162472568452358, 63.03956753867013, 96.25264467511857, 76.61754267556327, 63.7612977709089, 85.67857728685651, 62.30196067265102, 38.52593381064278, 32.49292414528983, 46.133971554892405, 105.43596063341413, 18.312512397766113, 0.3307562374642917, 3.2988218665122986, 14.137627346175057, 4.8279953088079175, 7.601421322141375, 11.958495957510811, 19.01050410951887, 29.546901839120046, 40.479148864746094, 38.275284494672505, 38.578983306884766, 30.272394520895823, 34.07290628978184, 30.335539749690465, 32.19905008588518, 32.86117172241211, 36.050579002925325, 22.66023302078247, 17.639231954302105, 22.766052348273142, 15.620679514748709, 14.965090921946935, 19.40395975112915, 28.069893734795706, 29.00072305543082, 25.726874317441666, 19.31348204612732, 15.41940062386649, 11.388906955718994, 3.297517776489258, 1.5689447138990675, 0.8774977166737828, 1.9283665588923862, 11.76857476575034, 11.408757090568542, 20.960913828441075, 38.12147569656372, 55.893657956804546, 69.03261116572789, 67.90791320800781, 60.042538506644114, 53.068134784698486, 55.43814447947911, 57.09591170719692, 59.75238173348563, 59.41758278438023, 59.16436958312988, 52.97286803381783, 49.14378179822649, 18.836483001708984, 54.07680477414812, 54.268220697130474, 57.33099705832345, 60.01824760437012, 61.30488722664969, 51.0763954435076, 45.03348459516253, 48.926216329847065, 54.87828990391323, 59.69307885851179, 60.215354101998464, 61.027167728969026, 60.032540048871724, 67.02829905918666, 62.86608491625105, 55.348151411329, 48.523936476026265, 44.18443209784371, 44.854613644736155, 38.89299324580601, 30.713045801435197, 25.68576008932931, 18.284064735685075, 14.98837433542524, 9.931543145860944, 11.476310082844325, 10.893509081431798, 18.267196246555873, 19.36140203475952, 19.30387442452567, 18.19672761644636, 10.528235333306448, 7.588680062975202, 10.361422981534686, 13.685730406216212, 15.674097265516009, 17.41416243144444, 17.84502022606986, 18.331180470330374, 20.02228168078831, 22.13323473930359, 25.22648068836757, 26.43746485028948, 19.915308952331543, 12.867744173322405, 7.686381288937159, 3.11351232443537, 5.6268674816404065, 15.206580775124685, 8.258027826036725, 5.799680471420288, 0.5758310354181698, 0.34144986793398857, 72.69083077566964, 32.91721589224679, 45.544882433755056, 59.11019447871617, 65.03247765132359, 61.6939377103533, 42.4596460206168, 55.186932359422954, 14.678568056651525, 1.914134259734835, 0.39027754643133705, 0.19357488570468767, 0.16710173338651657, 0.27680825229202, 0.16196868382394314, 0.3500868044793606, 0.15921077824064664, 0.12527222079890116, 0.19975258064057144, 0.1563379288251911, 0.22255966253578663, 0.17156634453151906, 0.11772598858390536, 0.31479302261556896, 0.2328627146780491, 0.3086924771113055, 0.17411524775837148, 0.17436363228729793, 0.14291308633983135, 0.3004264278071267, 0.2566883862018585, 0.3271864918725831, 0.21376206246869905], [0.042502748247768195, 0.09033716004341841, 0.11584256536194257, 0.023306973910491382, 0.02473784820176661, 0.08116625036512103, 0.13295620919338294, 0.07422607884343181, 0.06006501907748835, 0.03242134974737253, 0.02017043900143887, 0.03129234890054379, 0.05393964936956763, 0.007120975659095815, 0.05815490907324212, 0.079508155052151, 0.05731324066541024, 0.10198512287544352, 0.06333078776619264, 0.18328997758882387, 0.0773030315924968, 0.054566262888589075, 0.13282833248376846, 0.09334676140653235, 0.06683290377259254, 0.06339997798204422, 0.07315330819359847, 0.06155250354536942, 0.19878884378288472, 2.3568367787769864, 45.49720389502389, 56.49245023727417, 37.30636862346104, 49.12762376240322, 79.97867121015275, 29.47095455442156, 35.66043765204293, 24.04392855507987, 84.47947107042584, 7.313302108219691, 0.35119591067944256, 2.937059998512268, 1.9760320697511946, 3.1299055133547102, 1.3222072337354933, 3.4382376883711134, 13.66030694757189, 21.03292669568743, 28.673052958079747, 33.74264104025704, 29.891838209969656, 24.645152705056326, 23.587763684136526, 20.946449416024343, 17.313133886882238, 20.098654542650493, 20.466778789247783, 9.962062239646912, 3.405248292854854, 8.197748729160853, 9.190100874219622, 7.5468527759824475, 11.00309954370771, 17.46061635017395, 16.50166072164263, 14.175425546509878, 11.002046023096357, 9.821510604449681, 5.311367588383811, 2.3286705187388828, 0.3641511797904968, 0.18057164416781493, 0.9716629066637584, 4.510729704584394, 3.8638815113476346, 6.726354335035596, 14.914289167949132, 31.372513226100377, 45.1224284853254, 52.87998104095459, 53.26256275177002, 51.08756814684187, 52.801403863089426, 57.33565929957798, 59.671053068978445, 56.7246173449925, 55.81564358302525, 51.04578515461513, 44.51793868201119, 13.43589837210519, 47.242032051086426, 50.30247381755284, 48.99301978519985, 51.37112760543823, 50.599106311798096, 43.90201561791556, 38.842111587524414, 47.542864731379915, 51.049193246024, 53.75900111879621, 56.93165281840733, 55.801629066467285, 57.02751016616821, 59.67860576084682, 53.867768219539094, 44.35027517591204, 34.14500079836164, 41.647742067064556, 45.095466000693186, 36.95736755643572, 26.02223355429513, 23.217125926698955, 14.05928988116128, 11.284672686031886, 6.438945140157427, 5.324482313224247, 6.4054040142468045, 11.607525944709778, 11.494068809917994, 7.594865696770804, 6.633512505463191, 1.6880835209574019, 3.4935737933431352, 3.545234735522951, 5.2833424636295865, 4.72941426719938, 3.7436377235821316, 8.651770080838885, 9.942452686173574, 13.108899644442968, 18.05144773210798, 22.210126979010447, 18.724512781415665, 13.509212289537702, 7.821874635560172, 3.3256896819387163, 1.284427923815591, 2.1375522826399123, 3.113708176783153, 2.7283280789852142, 2.004666247538158, 0.03201336360403469, 0.6079223762665475, 34.866310664585654, 36.33721651349749, 37.978933402470176, 43.053532872881206, 47.853202547345845, 16.191116196768625, 9.920847262654986, 12.847351210457937, 1.2348919361829758, 0.0876694181933999, 0.09954658336937428, 0.09266299488289015, 0.03010859027771013, 0.05639890115708113, 0.016129723949623958, 0.10570515718843256, 0.038313632498362234, 0.058173331298998425, 0.018339354578139525, 0.035790578063045225, 0.06055444638643946, 0.04481393690886242, 0.032641734528754435, 0.07124811756823744, 0.08423729307417359, 0.10180553501205784, 0.012282193754799664, 0.06971179214971406, 0.005794496100861579, 0.10271566081792116, 0.07027534262410232, 0.1083086689135858, 0.051549849033887894, 0.02520854115885283, 0.042590825485863855, 0.046571746335497925, 0.059867558601711474, 0.026274461997672915, 0.06312023156455585, 0.0827783342184765, 0.010644064334753369, 0.03224516812978046, 0.07273210079542228, 0.014375850026096617, 0.05339465682793941, 0.049356708502663035, 0.05461673910862633, 0.04621628898062876, 0.0695535781394158, 0.01727543372128691, 0.06236091695193734, 0.11826080988560404, 0.09228315097945076, 0.1404720294688429, 0.04166476767776268, 0.09207003670079367, 0.006479491196971918, 0.06557797361165285, 0.0490359276799219, 0.12013951050383703, 0.11242566656853471, 0.20918925212962286, 4.694730596882956, 70.32692159925188, 75.03847421918596, 44.817353929792134, 62.61651257106236, 75.09129442487443, 31.858140196119034, 32.08308465140206, 38.695150239127024, 94.48999091557094, 6.311442221914019, 0.21003292900110992, 3.707730301788875, 5.264408622469221, 3.994632278169904, 3.5239647797175815, 2.5745987508978163, 10.296225428581238, 17.007644176483154, 30.15124920436314, 35.20319059916905, 28.868382453918457, 24.956426790782384, 25.19355664934431, 23.25712149483817, 20.272757291793823, 20.628915003367833, 23.043639830180577, 12.88030217375074, 2.5345061251095364, 4.215742630617959, 8.644424966403417, 7.163828551769257, 9.54937311581203, 8.968713896615164, 10.99849375656673, 12.06071959223066, 9.798242824418203, 7.481531023979187, 5.064900653702872, 2.6956509181431363, 0.2716215577508722, 0.7262322306632996, 0.5916753166488239, 6.0931993041719705, 7.016548889023917, 14.091233355658394, 26.085575069699967, 41.451962675367085, 53.93381779534476, 60.571303367614746, 57.2438770702907, 55.64171974999564, 54.45894180025373, 60.040155274527415, 63.05038588387625, 60.040308134896414, 58.59087916782924, 54.30293389729091, 48.360198702131, 16.49766203335353, 52.00995193208967, 53.88607324872698, 54.88534232548305, 57.53900180544172, 56.49144622257778, 48.88671234675816, 43.41589185169765, 49.71355492728097, 55.120511054992676, 59.911029951913015, 59.374816622052876, 59.81883430480957, 61.23171574728829, 62.55616051810128, 56.76999602999006, 53.28014516830444, 47.30414547239031, 49.11577360970633, 51.40624727521624, 41.40301261629377, 30.675595011029923, 25.522305454526627, 15.805077757154192, 9.45163801738194, 4.283787642206464, 1.946805558034352, 2.7597812712192535, 1.4701223309550966, 8.68301352432796, 4.5915107641901285, 6.962384641170502, 3.6496377161570956, 3.5931340966905867, 8.789106437138148, 8.502434185573033, 4.445745808737619, 4.684641378266471, 8.998482584953308, 10.000149658748082, 13.80909480367388, 19.954305716923304, 18.926370109830582, 13.196917687143598, 8.656948225838796, 5.536478800433023, 3.4850140469414845, 4.369018588747297, 4.1243369068418225, 6.361815358911242, 3.9645396300724576, 1.2333318484680993, 0.13794574859951222, 0.834372202200549, 40.932442392621724, 29.790592534201487, 41.13195644106184, 45.35820518221174, 58.71382754189627, 29.88553966794695, 20.352390595844813, 5.246546106679099, 5.047561424119132, 0.18995598703622818, 0.1239403108400958, 0.03855732495763472, 0.0924104984317507, 0.08839162372584854, 0.014836334423827273, 0.031842532235064676, 0.04870118260649698, 0.034218565095216036, 0.06488941663077899, 0.025965180647160326, 0.09469844387578112, 0.08348680620214768, 0.007315602403001061, 0.05626955541915127, 0.03217901435813733, 0.14216274874550955, 0.009137339158249753, 0.016075098487947668, 0.09496733373297112, 0.0672288289559739, 0.0712475815255727, 0.015307112197790827, 0.027725604129955173, 0.12195300390677792, 0.18290853234274046, 0.2566403459225382, 0.1634016005056245, 0.15837920643389225, 0.145070596997227, 0.16046887716012342, 0.1918187149401222, 0.232192050665617, 0.28271348827651566, 0.09468334647161619, 0.27088032609650065, 0.26873344129749704, 0.2703106552362442, 0.1241697371006012, 0.23511569521256856, 0.1310184895992279, 0.31984021035688265, 0.21375590137072972, 0.26329916289874483, 0.17349660024046898, 0.2861130301441465, 0.22667729801365308, 0.15213768849415438, 0.08654157085610287, 0.21172588744333812, 0.2849796866731984, 0.20190046967140265, 0.5013632284743446, 6.859218222754342, 93.11551911490304, 90.51569080352783, 63.31356280190604, 73.46885531289237, 102.0425785609654, 43.621346609933035, 47.35027803693499, 34.45115579877581, 101.91517639160156, 9.271734390939985, 0.28347162902355194, 5.6824652297156195, 10.522867849894933, 13.949625594275338, 5.704969576426914, 8.171144945280892, 19.457625899996074, 25.915045431682042, 39.62582669939314, 47.22568988800049, 38.59518303189959, 34.51158080782209, 35.930861541203086, 33.51767226627895, 32.12589945111956, 33.98971203395298, 36.45187221254621, 25.018726076398575, 18.23520152909415, 18.550606318882533, 17.750283275331768, 19.050291231700353, 18.415625401905604, 27.07299051965986, 26.707272086824688, 22.12659399850028, 18.394598415919713, 14.196674006325857, 8.430516856057302, 4.814443715981074, 1.69132214146001, 1.0563691556453705, 3.2285278098923818, 12.802455425262451, 12.274109193256923, 14.895047869001116, 28.26010240827288, 47.230324336460654, 59.349928174700054, 65.98711150033134, 62.34022440229143, 56.281659262520925, 54.81933791296822, 58.86034420558384, 61.17221137455532, 57.874672753470286, 56.85263442993164, 52.69613170623779, 48.82310506275722, 18.548197031021118, 54.0414662361145, 55.30498225348336, 57.47404657091413, 58.8782844543457, 58.8037302834647, 51.98236410958426, 47.163541725703645, 51.7491443497794, 59.835815702165874, 61.30151735033308, 61.94364207131522, 58.60495621817452, 63.20607416970389, 61.89895125797817, 61.500784737723215, 55.59778281620571, 55.96315731321062, 54.93346207482474, 54.96997833251953, 42.49063498633248, 31.04178592136928, 26.87174984386989, 19.013151373182023, 15.6618059022086, 13.453384382384163, 11.612679771014623, 15.106705631528582, 16.628932612282888, 16.70376992225647, 17.750132152012416, 17.97492027282715, 14.423648204122271, 9.781141570636205, 14.453786884035383, 16.78431691442217, 14.367913229124886, 14.25720236982618, 21.28006022317069, 21.314139400209697, 22.84834681238447, 26.181581803730555, 28.12655803135463, 23.577410868235997, 16.360688720430645, 12.544284684317452, 6.098237182412829, 4.622145806040082, 7.674975820950099, 9.878014223916189, 7.3898530176707675, 7.642033542905535, 0.18353273027709552, 0.9608124260391507, 44.631135259355815, 49.42712238856724, 53.714334624154226, 57.668137550354004, 74.4085852759225, 42.89378336497715, 44.27177095413208, 31.590853418622697, 6.431978702545166, 0.18338231263416155, 0.20799162425100803, 0.24972829967737198, 0.19175924813108786, 0.2255485685808318, 0.12263714362468038, 0.15978468315941946, 0.17337915939944132, 0.1688845298652138, 0.18415197490581445, 0.22383933886885643, 0.2176148792994874, 0.2486679937158312, 0.1564632813845362, 0.19670305427696022, 0.11999673316521303, 0.26544669909136637, 0.14131438998239382, 0.19037024623581342, 0.17525140036429676, 0.2729108285691057, 0.1327646994697196, 0.23684780512537273, 0.20546779967844486], [0.07141365297138691, 0.09749537879335028, 0.1823912308152233, 0.05773807144058602, 0.054462307931057045, 0.04193902474695018, 0.041701900506658215, 0.04904630248035703, 0.023268623111237372, 0.057173950996782096, 0.06441565669540848, 0.07008873870862381, 0.12934003823569842, 0.18044523309384072, 0.011231846142826336, 0.0617450446422611, 0.0727836965982403, 0.11285321148378508, 0.055429922616375346, 0.13715126551687717, 0.06723099348268338, 0.06852711750460522, 0.02233177998901478, 0.05548510786944202, 0.10383487718978099, 0.1160094714058297, 0.12374011586819376, 0.087980227944042, 0.14481940333332333, 0.31000978499650955, 2.1365945168903897, 24.554450920649938, 45.72496237073626, 30.428398949759348, 68.66488470349992, 56.484341689518516, 31.808325086321148, 25.85223545346941, 52.58124671663557, 6.5757239035197665, 0.851052004311766, 3.2674251283918108, 3.3208037955420355, 3.9583687611988614, 1.1579754863466536, 2.429087838956288, 11.486449241638184, 21.599090235573904, 28.074856485639298, 26.334775686264038, 32.423959800175254, 28.02611139842442, 27.273432152611868, 22.59419560432434, 19.443059001650127, 16.904659714017594, 16.543792860848562, 14.592462505613055, 5.690346658229828, 10.12007122380393, 11.912882770810809, 9.655615414891924, 14.209040062768118, 19.091732025146484, 14.361029301370893, 13.821439146995544, 11.754964113235474, 8.81439961705889, 4.341256627014705, 1.0548092850617, 0.21070501793708118, 1.1936469950846262, 2.6815901526382993, 6.127106947558267, 9.730991210256304, 8.409781694412231, 7.861337797982352, 17.17500022479466, 30.000779015677317, 39.845914363861084, 51.96354143960135, 51.02338763645717, 54.97040564673287, 57.20689180919102, 58.12901503699166, 61.330317633492605, 55.07240867614746, 50.95927660805838, 44.57008491243635, 21.576133387429373, 46.85549681527274, 48.1805808203561, 48.08155161993844, 46.52457843508039, 44.118458952222554, 38.68397406169346, 41.18218844277518, 49.40391540527344, 52.46981498173305, 52.60241787774222, 53.04032809393746, 55.77009119306292, 54.45193106787545, 53.5870748928615, 48.89258704866682, 35.1796327318464, 37.124940735953196, 49.523646763392854, 52.81363616670881, 42.561430181775776, 27.109041248049053, 22.230308021817887, 14.944006613322667, 9.44292150224958, 6.252481111458369, 5.889182823044913, 8.999107054301671, 11.880399073873248, 13.748754041535513, 8.98898092338017, 9.47572307927268, 6.965551282678332, 2.0680383784430365, 7.332208156585693, 8.08358027253832, 6.5398933461734226, 7.04540171793529, 7.743586676461356, 9.876002720424108, 16.03811686379569, 17.771867854254587, 20.185684204101562, 17.80622148513794, 12.151438747133527, 5.5900446346827914, 3.8825582691601346, 2.0047567912510464, 1.4993562251329422, 0.8284779584833554, 1.2362475948674339, 0.9554924943617412, 0.28724678073610577, 0.406700428043093, 18.321272339139664, 40.18433679853167, 24.73186101232256, 48.507462297167095, 28.073491164616176, 9.478845426014491, 6.299663288252694, 5.965752840042114, 2.373291850090027, 0.158717401857887, 0.07312229235789605, 0.20524857858461992, 0.0922112398381744, 0.07558952032455377, 0.060373006122452874, 0.059405958013875146, 0.09019760574613299, 0.1155740147722619, 0.09482258185744286, 0.029390262572893074, 0.04349841017808233, 0.0942239375518901, 0.08618656133434602, 0.08796262674565826, 0.056652103284639974, 0.07351882143744401, 0.11683657845216137, 0.06231861707887479, 0.0714828906846898, 0.06693045675222363, 0.021924438453944664, 0.09142368459807974, 0.13728671467729978, 0.015081258424158608, 0.057517405067171366, 0.06558750024331467, 0.01767743518576026, 0.043968190505568466, 0.08532294910401106, 0.04285433456035597, 0.015657957210870724, 0.0344113131452884, 0.039340384903230836, 0.06493796581136328, 0.06795950260545526, 0.06883861257561616, 0.04314858466386795, 0.024875928381724016, 0.08558220376393624, 0.01956523156591824, 0.10029369792235748, 0.10972583679748432, 0.07697373176259653, 0.020424234847139035, 0.10140983374523264, 0.05885551683604717, 0.08994206945811, 0.05670724782560553, 0.044003677887043784, 0.06690291501581669, 0.049804619646498134, 0.07459326128342322, 0.6421581591878618, 14.723597594669886, 61.28951781136649, 54.41394526617867, 42.28239400046212, 79.5704367501395, 50.00739771979195, 30.588600090571813, 31.28029326030186, 75.04212897164481, 5.09710077728544, 0.4486251798059259, 2.8998582576002394, 4.6999465227127075, 5.812111232961927, 4.645199494702475, 2.6522416131837026, 4.4944769995553155, 16.993079015186854, 23.671939373016357, 25.48807689121791, 31.21564027241298, 27.36077274594988, 26.738738741193497, 22.69839426449367, 19.949398551668438, 20.32589885166713, 24.23277885573251, 12.92632964679173, 4.157100703035082, 0.851038107914584, 10.259067331041608, 7.943666134561811, 11.116439427648272, 7.743634445326669, 6.026964732578822, 9.230936305863516, 8.134894456182208, 4.728899666241237, 2.622522213629314, 1.0247324875422885, 0.6238111151116235, 1.1357606840985162, 2.4144466817379, 9.739266514778137, 13.91722788129534, 16.412438903536113, 20.484053747994558, 30.35503986903599, 46.35957261494228, 52.47393526349749, 59.2254581451416, 56.79939733232771, 59.04764679500035, 60.438488551548545, 61.166069167000906, 63.732441902160645, 58.661556243896484, 57.2699328150068, 48.829469612666536, 26.89854904583522, 51.634353160858154, 54.46933283124651, 53.713330609457834, 51.614029679979595, 52.10241855893816, 43.933202607291086, 46.61520726340157, 53.547372886112754, 56.985365867614746, 56.99267884663173, 55.36554275240217, 58.07845646994454, 58.03620100021362, 57.45589440209525, 53.253880977630615, 47.35036488941738, 45.476769242967876, 57.40579441615513, 57.555604525974815, 48.339149134499685, 33.46725961140224, 24.541654075895035, 16.123703036989482, 8.586105261530195, 4.302928192274911, 2.2874826831477026, 5.641250686986106, 9.70425193650382, 5.108541854790278, 1.5780848520142692, 4.008525635514941, 6.762966564723423, 3.5189388436930518, 7.894183669771467, 5.3933849930763245, 4.457204691001347, 5.25511714390346, 9.627887759889875, 11.856507693018232, 17.232651165553502, 16.59719671521868, 15.755431141172137, 13.691478303500585, 6.332978163446699, 3.5548538650785173, 1.7706014130796706, 3.8685824019568305, 2.5833044094698767, 1.4829480541603905, 0.432758235505649, 1.2554606667586734, 0.2522682191005775, 0.4976137525268963, 14.86090442112514, 48.79760864802769, 34.5945040839059, 53.413293497903005, 43.53605399812971, 17.53559262411935, 12.32370022365025, 7.100771912506648, 4.081228111471448, 0.13525043108633586, 0.03342481483040111, 0.08118334266224078, 0.09843561798334122, 0.1069139266120536, 0.05499692567225013, 0.07795323777411665, 0.045113079249858856, 0.03622082694034491, 0.02749282251378255, 0.043952886148222854, 0.04123765702492424, 0.03909820896972503, 0.04174220209409084, 0.06876350553440196, 0.05457725176321609, 0.08586760237812996, 0.006391725236816066, 0.07402158195951156, 0.04674630964707051, 0.04331466289503234, 0.03790583973750472, 0.03800273793084281, 0.027993264142423868, 0.24676416016050748, 0.17326900602451392, 0.2723583382155214, 0.15618814900517464, 0.1406411746782916, 0.24388323617833002, 0.20812283935291426, 0.12617061473429203, 0.15320617758802005, 0.1977117915770837, 0.18929814733564854, 0.1913084430353982, 0.2568270516182695, 0.2811339401773044, 0.24647475140435354, 0.14918325202805655, 0.08972685172089509, 0.26120398246816223, 0.31832626302327427, 0.34368162389312473, 0.103820906153747, 0.15036208448665483, 0.1447220742702484, 0.1651122687118394, 0.14338975719043187, 0.24691989751798765, 0.1672027672507933, 0.32249233233077185, 0.24838602170348167, 0.7856708669236728, 27.188759667532786, 83.57170282091413, 72.79950060163225, 55.5198518208095, 95.79978193555559, 74.74387754712785, 44.55238437652588, 35.02228382655552, 71.74225575583321, 7.7674389736992975, 1.1956812973533357, 8.121348943029131, 11.477808288165502, 13.78937668459756, 6.848653486796787, 5.344168731144496, 17.20332281930106, 27.47645330429077, 38.518457548958914, 36.33863047191075, 43.49385758808681, 38.52088941846575, 38.30614839281355, 36.37485490526472, 32.596031938280376, 31.74719136101859, 34.791339601789204, 30.993075575147355, 21.534136738095963, 23.044541358947754, 21.84464304787772, 16.76097617830549, 21.088837112699235, 28.345520087650844, 23.956690447671072, 19.934847286769322, 18.36646863392421, 13.415351680346898, 7.490882430757795, 1.239545926451683, 0.5724669130785125, 2.2646406974111284, 3.8165360518864224, 12.371438690594264, 25.00297451019287, 26.454100574765885, 26.186792952673777, 36.64976385661534, 56.21185071127755, 60.87381403786795, 65.82993630000523, 60.01819201878139, 60.81993075779506, 59.57438278198242, 59.642231941223145, 63.58809307643345, 59.83976922716413, 56.17592852456229, 50.428819860730854, 31.860655444008962, 51.80904129573277, 56.40862716947283, 55.57631288255964, 55.071373394557405, 53.364673478262766, 45.85026271002633, 49.47379691260201, 55.32696287972586, 58.40277058737618, 59.1276205607823, 56.06527498790196, 59.47332123347691, 58.70540632520403, 56.38281461170742, 57.9346079145159, 55.00843661172049, 55.47512626647949, 61.392948695591514, 57.468654768807546, 48.2433716910226, 33.64839220046997, 25.227465595517838, 19.05844841684614, 15.184921503067017, 11.18789209638323, 12.12370674950736, 17.140132427215576, 21.89571578162057, 24.612616028104508, 16.063976321901592, 21.5410658291408, 17.394990614482335, 9.372491955757141, 18.990284851619176, 18.81462049484253, 16.830008268356323, 15.484465292521886, 17.527680362973893, 19.951456955501012, 25.443822077342443, 25.440737077168055, 25.717301436832972, 21.972788674490793, 17.81606708254133, 6.19911938054221, 5.457048296928406, 6.760666276727404, 7.383965287889753, 2.7198575735092163, 3.9436846120016913, 2.7734557603086745, 0.35037960591060774, 0.511707250561033, 30.708282811301096, 55.12566314424787, 40.28555120740618, 68.44704478127616, 57.050279412950786, 32.02574464253017, 38.918114457811626, 8.123277068138123, 4.675286063126155, 0.41718596539327074, 0.2738654730575425, 0.36589297918336733, 0.1502199721123491, 0.23186901371393884, 0.18712159698562963, 0.29036728186266764, 0.09763774222561292, 0.20187465819929326, 0.19661996087857656, 0.08332207147032022, 0.20142084040812083, 0.19728540017136506, 0.1527504056159939, 0.22534998852227414, 0.13468426146677562, 0.32783226722053116, 0.1978648147944893, 0.14507609313087805, 0.18041389834667954, 0.22800296545028687, 0.16891376115381718, 0.2044680326112679, 0.14805055995072636], [0.07986897961901766, 0.14175108154969557, 0.09879071571465049, 0.016354992486802594, 0.03465157561004162, 0.027361383495320166, 0.028063785983249545, 0.06794390987072672, 0.10942800742174898, 0.023968737239816358, 0.06543298424886805, 0.06840291845479182, 0.0604137046528714, 0.013190846291503735, 0.03401575097814202, 0.07715776403035436, 0.014005545476850654, 0.03147509195176618, 0.06092750493969236, 0.06244796620947974, 0.14421580572213444, 0.04064007801935077, 0.05549458021830235, 0.007306912913918495, 0.06048640289476939, 0.08026819569723946, 0.04508375635902796, 0.1522478690104825, 0.04246711837393897, 0.12140671536326408, 2.5420588169779097, 3.325878368956702, 43.0235652923584, 34.10780709130423, 42.32185629435948, 71.62692260742188, 53.76017189025879, 41.39958715438843, 35.82322004863194, 1.8604470491409302, 0.1226208180721317, 3.001445697886603, 2.61529369865145, 4.583443471363612, 2.269285351037979, 1.0645115758691515, 6.656398134572165, 16.7101275239672, 27.354852880750382, 28.468930516924175, 32.607454776763916, 29.60322741099766, 27.151534693581716, 23.633604424340383, 20.85883263179234, 18.951378413609095, 7.887330140386309, 15.614981991904122, 4.617587787764413, 6.576950694833483, 14.3445759671075, 11.690284201077052, 14.58781589780535, 16.25646574156625, 11.415707894733973, 12.824538537434169, 12.780567731176104, 6.846222920077188, 2.6252752201897755, 0.9212743533509118, 0.5288582273891994, 1.9169901864869254, 4.066679017884391, 8.481497526168823, 15.35104945727757, 11.74004806791033, 15.713391065597534, 19.015131609780447, 26.024714061192103, 37.09694296973092, 47.71408918925694, 51.60224553516933, 49.42703206198556, 56.58095986502511, 58.42829826899937, 61.40515668051583, 63.3609356198992, 51.61722237723214, 46.77939319610596, 30.640600408826554, 45.12234858104161, 47.42213978086199, 45.28280333110264, 43.09049034118652, 36.7079758644104, 40.32366555077689, 46.91789163861956, 51.050169467926025, 51.11566318784441, 53.92991290773664, 49.21206521987915, 56.41415793555123, 56.49848822184971, 56.65330103465489, 47.967809609004426, 36.85267557416643, 36.49632331303188, 50.63420166288103, 53.31902033942086, 42.819361209869385, 28.264380761555262, 17.41318620954241, 15.483058282307216, 12.457655412810189, 10.741500735282898, 7.063540858881814, 5.571510749203818, 4.294913010937827, 4.722167296069009, 8.739186235836574, 8.470655730792455, 7.800494159970965, 5.682695823056357, 4.671434155532292, 10.208934341158185, 9.489067094666616, 8.84913887296404, 10.815809982163564, 13.245908566883632, 18.054621321814402, 20.747968912124634, 20.194244384765625, 11.391278897012983, 7.946158800806318, 3.9924066833087375, 1.4207577684095927, 5.0775129369327, 2.366149753332138, 4.861349701881409, 1.9103961288928986, 0.400272828659841, 0.08475703054240771, 0.07920075833265271, 8.031631197248187, 22.272775411605835, 37.76826402119228, 45.33927828924996, 9.602132524762835, 4.881268450192042, 6.751994490623474, 3.541803628206253, 0.09842788268412862, 0.048959880867706876, 0.06589836427675826, 0.015373598451593092, 0.019469325730044926, 0.03669192023309214, 0.04251568791057382, 0.1126304009397115, 0.07560771863375391, 0.07668818387069873, 0.0669783138270889, 0.040872910525649786, 0.04039773584476539, 0.054549184162169695, 0.08131168077566794, 0.05147053846823318, 0.10282123408147267, 0.03859968589884894, 0.029409363333668028, 0.08754380100539752, 0.11160311249217816, 0.008526987579118992, 0.05428442997591836, 0.06690011945153986, 0.05077107064425945, 0.015923983650282025, 0.11626685330910341, 0.07629757840186357, 0.07515871844121388, 0.04641968324514372, 0.018500555838857378, 0.009070890223873513, 0.014094838140798467, 0.06801085413566657, 0.02588799050343888, 0.029414431990257332, 0.06953122041055135, 0.04315995351810541, 0.0664287411740848, 0.03136249924344676, 0.08769250195473433, 0.04482822685635515, 0.03225800601233329, 0.05455603736585804, 0.08604085950979165, 0.04768910691408174, 0.08890906774571963, 0.03967377969196864, 0.035055429475115876, 0.042631619011185, 0.1079211507790855, 0.0026774482934602667, 0.09949167631566525, 0.057640796660312583, 0.09203277834291969, 5.557189209120614, 26.639132840292795, 67.03300298963273, 41.78957564490182, 58.558507510593955, 70.63597747257778, 46.672036579677034, 35.022627762385774, 43.02468742643084, 2.8049636696066176, 0.4201193265616894, 1.4114004990884235, 0.13106629917664187, 2.7765533540930067, 4.759587253843035, 4.202799873692649, 3.463998568909509, 7.9609106949397495, 21.9928046975817, 24.2740581035614, 27.527230739593506, 27.62542963027954, 25.75475570133754, 23.726981265204294, 24.315174068723405, 20.84259295463562, 16.042869431631907, 18.583599839891704, 8.87029961177281, 4.7551933867590765, 8.711244923727852, 10.004314235278539, 9.370776619229998, 6.207228362560272, 2.7604613261563435, 6.785747102328709, 3.616656788757869, 2.0852727336542944, 0.316436054451125, 0.24368751953755105, 0.8275886976293155, 2.087408001933779, 4.506238562720163, 8.73569129194532, 18.691018990107946, 16.251678432737076, 21.32631959233965, 29.050456523895264, 38.202196393694194, 48.769812379564556, 55.510680198669434, 55.98393937519619, 53.71499122892107, 61.617055892944336, 62.53733089991978, 64.09914697919572, 66.54473223005022, 58.70562866755894, 51.761515617370605, 38.097084045410156, 51.686499391283306, 56.064166750226704, 52.91687250137329, 51.39729104723249, 43.52635778699602, 48.45294673102242, 55.30443334579468, 58.36103970663888, 59.755320821489605, 58.61972114018032, 54.751047543116975, 58.457584926060264, 59.98019926888602, 62.13309165409633, 53.566859109061106, 44.40691689082554, 45.42501905986241, 58.868244307381765, 60.70247840881348, 48.698002747126985, 34.76683330535889, 21.10094608579363, 16.198502131870814, 11.366340943745204, 6.390147507190704, 1.48697410098144, 3.1874137989112308, 4.440063919339861, 3.962388728346143, 2.4377657047339847, 3.4658376702240536, 7.699554204940796, 9.2633262021201, 9.978939414024353, 2.000241764954158, 4.3047890067100525, 7.184794306755066, 10.599960718836103, 12.790630459785461, 15.886673927307129, 17.07661199569702, 14.157633815492902, 5.527714516435351, 4.574019977024623, 1.3958102613687515, 2.870649116379874, 3.957908008779798, 3.5431220488888875, 5.206652590206691, 1.5657941401004791, 0.44450313385043827, 0.09763934356825692, 0.18130345775612763, 10.715200935091291, 39.23979868207659, 35.05874449866158, 59.73630360194615, 24.8045426436833, 16.451760496412003, 8.702048982892718, 2.999281551156725, 0.13842878410858767, 0.008162048545532992, 0.04913190985098481, 0.0676227185342993, 0.07104609733713524, 0.03327407149065818, 0.033024791295507124, 0.11515196599066257, 0.03127274263117995, 0.07517344943646874, 0.10235634938414608, 0.05611524298521025, 0.046849141629146676, 0.05819640148963247, 0.02708356242094721, 0.17113445699214935, 0.04189506585576704, 0.056130886610065184, 0.059273596187787395, 0.04196445963212422, 0.11739088727959565, 0.01183765662634479, 0.08924648963979312, 0.03691444918513298, 0.0371163031751556, 0.23963853823287146, 0.292722938316209, 0.16530537977814674, 0.07960878179541656, 0.1496626098773309, 0.1002468993621213, 0.10680000736777272, 0.1345965676009655, 0.15934716377939495, 0.12831880232053144, 0.13407895394733974, 0.16334134659596852, 0.11213532143405505, 0.16026842434491428, 0.13775598949619702, 0.1718747794095959, 0.19634755620998995, 0.20646227417247637, 0.1920346383537565, 0.1677793184561389, 0.24045628149594578, 0.1849315437887396, 0.15337402001023293, 0.14005639962852, 0.11403877500976835, 0.17465143970080785, 0.31168546793716295, 0.20528317029987062, 0.2873516008257866, 0.2730911560356617, 6.673283559935434, 48.188981192452566, 88.00056103297642, 61.35420554024832, 71.7354326248169, 92.89480263846261, 73.98607226780483, 58.343759536743164, 49.9211288860866, 2.774939634970256, 0.5528536683746746, 4.694992022854941, 10.206591061183385, 10.81416152204786, 7.9562223979405, 4.476972750255039, 11.209530523845128, 21.44944861957005, 36.16918822697231, 37.39167513166155, 40.424747943878174, 40.14136566434588, 36.260484082358225, 32.85943119866507, 33.468736103602815, 33.037499632154194, 23.312960692814418, 35.79107420785086, 18.283102410180227, 20.465416942323955, 23.84126697267805, 17.618667023522512, 22.396627051489695, 25.194611038480485, 19.224362713950022, 18.350856031690324, 18.50333251271929, 10.53966772556305, 7.306866339274815, 0.7439631649426052, 0.6399454293506486, 3.4405744544097354, 4.931964678423745, 10.593885387693133, 25.395688431603567, 25.08078738621303, 27.88913287435259, 36.535670961652485, 49.421602044786724, 60.58248996734619, 62.926596777779714, 59.451656750270296, 55.42159039633614, 62.60135160173689, 63.64872305733817, 63.03922012874058, 63.93673978533064, 60.24693366459438, 54.07808671678816, 40.73121213912964, 52.45646401814052, 58.38224560873849, 56.17199584415981, 52.773242814200266, 47.12865482057844, 50.193130016326904, 56.14658975601196, 59.87491321563721, 60.31745788029262, 60.53754901885986, 53.9268661226545, 59.365478243146626, 59.1212351662772, 62.11565167563302, 57.06137221200125, 54.02960218702044, 50.47491768428257, 60.665430613926475, 58.31420884813581, 51.31204012462071, 36.61861855643136, 21.66081976890564, 17.122539588383265, 14.979730776378087, 15.203969989504133, 10.08050991807665, 13.651827539716448, 15.857937914984566, 17.492050000599452, 14.29738553932735, 13.01687683377947, 13.856308681624276, 15.82726856640407, 19.037761892591202, 20.483732393809728, 20.731079578399658, 16.182983330317906, 18.530235937663488, 19.86705197606768, 23.546934332166398, 26.577882732663834, 24.379896538598196, 13.328670297350202, 9.57036622932979, 6.045063052858625, 4.532833227089473, 9.199679834502083, 10.254078524453298, 14.328088760375977, 3.2414471166474477, 0.9524036943912506, 0.33952649257012774, 0.24375664868525096, 11.175205554280963, 41.26445858819144, 49.598423276628765, 79.03953184400285, 36.43337958199637, 37.095501218523296, 28.830797910690308, 5.876323878765106, 0.20563843766493456, 0.17337804660201073, 0.13730335235595703, 0.16181068015950067, 0.1799543130078486, 0.12050306956682887, 0.07311191755746092, 0.18502820788749627, 0.07637263116027627, 0.2753956780901977, 0.10299265916858401, 0.253802549626146, 0.0803424749257309, 0.14222294837236404, 0.18579350039362907, 0.24099039712122508, 0.1863550559750625, 0.10606786129730088, 0.2178164313414267, 0.15507033041545323, 0.20943003706634045, 0.1157407851091453, 0.18813774388815674, 0.12319713857557092, 0.12628873411033834], [0.05425649129652551, 0.05277986678161791, 0.014070426147165043, 0.09688732320708887, 0.13100001987602028, 0.04725315494995032, 0.04837970967803683, 0.0439869011087077, 0.007876199553720653, 0.11833247675427369, 0.03207977521898491, 0.06403700701360192, 0.0504091841700886, 0.044609864109328816, 0.045350926129945686, 0.13682836427220277, 0.04795920456360493, 0.046656522500727854, 0.1674608684011868, 0.03740247192659548, 0.06624918723745005, 0.02945227388824735, 0.058900904043444564, 0.0902510607349021, 0.045852343152676306, 0.047547364341361184, 0.06837351753243379, 0.07061903418174811, 0.0017590374689981608, 0.180648712175233, 0.20286373155457632, 0.6085757783481053, 32.08024978637695, 39.038182803562705, 48.28177785873413, 62.651100703648154, 70.15225083487374, 53.310348987579346, 38.65017802374703, 0.963636543069567, 0.07564377598464489, 0.5388723186084202, 1.3277669868298938, 1.1152796745300293, 5.307223856449127, 2.581692861659186, 2.383285096713475, 12.272458127566747, 20.880717720304215, 24.403855664389475, 32.1981919833592, 33.3753662109375, 24.997436795915874, 27.764824390411377, 19.19980083193098, 24.02893955366952, 10.599112170083181, 19.297091245651245, 5.651861020496913, 1.3000411774430956, 16.788207905633108, 12.23925702912467, 13.155686208180018, 11.870960814612252, 6.809108683041163, 9.237449373517718, 8.739190578460693, 6.5305341226713995, 1.499249939407621, 0.8068604841828346, 2.2892425315720693, 1.6241575969117028, 3.3491557027612413, 7.701879245894296, 11.92700411592211, 17.528898034776958, 19.19017583983285, 23.106736421585083, 30.507719584873744, 43.86452661241804, 52.62047277178083, 52.465819767543245, 48.57306718826294, 53.119669573647634, 61.127993038722444, 58.631901332310264, 64.12006105695451, 56.46403905323574, 43.92863416671753, 34.483645575387136, 41.66745063236782, 41.43516193117414, 38.37041922977993, 34.42566980634417, 33.97936269215175, 43.61498553412301, 48.40722411019461, 52.33733715329851, 53.293437072208945, 52.27389662606375, 54.4286059652056, 57.01657370158604, 61.82919829232352, 58.367084639413015, 46.2820793560573, 32.595809595925466, 40.13078008379255, 51.201796531677246, 52.2149897984096, 38.34887981414795, 30.05392231260027, 19.782278742109025, 14.538077218191964, 11.261483073234558, 7.106725650174277, 5.520850999014718, 4.740683376789093, 5.558829418250492, 4.576100528240204, 0.8124042781335967, 0.9219513684511185, 1.1085306938205446, 3.863966626780374, 7.0300770316805155, 6.95716176714216, 7.401985440935407, 10.94290816783905, 14.129459738731384, 18.075422491346085, 18.86356360571725, 16.6623569216047, 13.051363348960876, 10.694469247545515, 3.495040080377034, 0.3799825688557965, 2.135008373430797, 3.635554369006838, 1.8312088123389652, 0.9480171012026923, 0.16576284808771952, 0.6925143056682178, 0.09240659007004329, 0.6248938941529819, 21.859863076891216, 26.991350923265728, 49.820744786943706, 26.145803792136057, 7.754467555454799, 7.886114205632891, 1.2286400773695536, 1.3638943625347955, 0.13824310978608473, 0.16703322849103383, 0.1005619296005794, 0.11525097782058374, 0.05177736182564071, 0.05261277753327574, 0.13175750922943863, 0.10336866256381784, 0.13735732303134032, 0.04224835868392672, 0.03069474614624466, 0.010382958122396042, 0.05907139953758035, 0.05870065478874104, 0.07036587276629039, 0.06519184647394077, 0.013208550966477819, 0.06160561926662922, 0.00661789792190705, 0.031056937961173908, 0.10085183368729693, 0.04160385558913861, 0.036106232553720474, 0.048707686364650726, 0.07561808664883886, 0.026523625145533254, 0.08777526287095887, 0.009097301351305629, 0.05350291369748967, 0.07653619202652148, 0.08375350439122745, 0.02236581700188773, 0.042582201305776834, 0.03247171061645661, 0.04590116374726806, 0.07816262011017118, 0.09478547956262316, 0.06375365757516452, 0.009605554614349135, 0.08465205438967262, 0.11319916934839316, 0.06428478764636175, 0.03847561237801399, 0.07505457010120153, 0.1287014146468469, 0.12075616312878472, 0.0440244512366397, 0.08280268684029579, 0.1022685333820326, 0.046469864302447865, 0.07967900338449649, 0.10017777021442141, 0.09155568001525742, 0.06201286919947181, 0.2603931331208774, 0.31735956775290625, 11.400828327451434, 65.68335015433175, 60.025362559727256, 62.864375659397666, 78.69884777069092, 66.69429220472063, 56.53670678819929, 37.53911590576172, 1.1450519455330712, 0.03909614622326834, 0.34306309851152555, 1.4960490997348512, 3.326405346393585, 5.839549669197627, 2.7054411470890045, 3.8418965424810136, 8.425103340830121, 9.380671722548348, 19.458023684365408, 25.557517187935964, 27.481763465063914, 25.851778609412058, 23.497940846851893, 24.313322373798915, 28.690022196088517, 21.19887920788356, 32.282942635672434, 8.99808132648468, 7.458938956260681, 8.513279455048696, 9.135543618883405, 6.595194927283695, 5.112223097256251, 2.658846527338028, 2.169146393026624, 2.0356235120977675, 2.074518007891519, 0.6293365614754813, 0.5744793936610222, 2.479700037411281, 2.1163396494729176, 3.9605917504855563, 12.071615236146108, 20.757751975740703, 21.590913942881993, 25.48614181791033, 33.594679151262554, 40.7016510282244, 50.26974432809012, 59.41332353864397, 59.21487603868757, 55.93126508167812, 56.94278730664934, 65.81209332602364, 63.106221607753206, 68.57084083557129, 64.30472333090646, 54.048386641911094, 41.370283126831055, 52.19677856990269, 51.451709338596885, 49.29254273005894, 42.84470476422991, 41.942814690726145, 50.798338958195274, 55.57754966190883, 57.18273639678955, 59.624646050589426, 56.76190832683018, 57.66224200384957, 58.84350872039795, 65.51370988573346, 62.443161964416504, 52.87208093915667, 41.90368243626186, 48.8263498714992, 58.2212940624782, 58.283167770930696, 44.620174476078574, 35.924069677080425, 23.2130959715162, 16.974322353090557, 10.864588941846575, 6.3620151196207315, 3.4583694423948015, 4.429416673524039, 2.789875873497554, 3.021539671080453, 3.396884398800986, 3.9319608296666826, 5.641424826213291, 3.6349750629493167, 2.8845348741327013, 1.923732544694628, 2.3819115247045244, 6.605271552290235, 11.780272058078221, 15.851116521017891, 14.23758499962943, 12.20553047316415, 6.461736100060599, 3.4181157052516937, 3.4430384593350545, 2.0118307088102614, 2.9613317932401384, 4.8959812607084, 2.2125648174967085, 2.1605807840824127, 0.5014212567891393, 0.510858918939318, 0.09138695549752031, 0.8626462678824152, 41.20916829790388, 31.68249668393816, 54.88649572644915, 45.42738492148263, 20.584606340953282, 10.51961348737989, 5.541582686560495, 1.2566021255084445, 0.06634902688009398, 0.07669585810175963, 0.04160453412415726, 0.07357879036239215, 0.041911924058305364, 0.06080597931785243, 0.09569164272397757, 0.010224476090765424, 0.0624943237219538, 0.1442140686724867, 0.13633477075823716, 0.012991860808272446, 0.10020155286682503, 0.021555120324982063, 0.09013763003583465, 0.023956499860755036, 0.031169310145612274, 0.07832223868795804, 0.022052854598898972, 0.06528916196631533, 0.026043200299942067, 0.02229481509753636, 0.07496982107737235, 0.057695744426122735, 0.028457056398370435, 0.09591503680816718, 0.16274742489414556, 0.07980963494628668, 0.1770237066916057, 0.15642821469477244, 0.17885363421269826, 0.1264103547270809, 0.23623497943793023, 0.14889198408595153, 0.1963303621326174, 0.16299040828432354, 0.1945435894387109, 0.0836522194689938, 0.2439649317945753, 0.1416130539562021, 0.3102529448057924, 0.0984373821743897, 0.1886874386774642, 0.31398241754089085, 0.15743723697960377, 0.24023901458297456, 0.12747292699558394, 0.19187537261417933, 0.27827738917299677, 0.0712864955088922, 0.18563005487833703, 0.1813073389764343, 0.13567770458757877, 0.14813454901533468, 0.34578700949038776, 0.5100560763052532, 22.409017426627024, 94.61890084402901, 82.28762013571603, 84.32480416979108, 93.62724699292863, 89.32688181740897, 67.91517407553536, 56.20066063744681, 2.1279444439070563, 0.31165311538747376, 1.5169476526124137, 3.338450700044632, 4.45916234595435, 12.379689676421028, 6.824073365756443, 4.58150405543191, 15.848726340702601, 24.010681424822124, 31.251704897199357, 40.72016102927071, 40.85838154384068, 32.54264892850603, 37.367307799203054, 29.03451909337725, 36.56568023136684, 22.004078149795532, 38.43002782549177, 19.131665059498378, 11.242789813450404, 27.807076386043004, 16.485137905393326, 21.905517952782766, 24.247981514249528, 16.80614468029567, 13.820025188582283, 15.17305224282401, 9.153042657034737, 2.404553315469197, 0.873228808598859, 2.085863981928144, 1.6684120850903648, 3.613165101834706, 13.215701273509435, 20.303932121821813, 26.00970595223563, 29.772944109780447, 42.3219118799482, 51.271493911743164, 60.707022530691965, 66.48189272199357, 63.431015150887625, 57.99947282246181, 57.69269595827375, 66.21365056719098, 61.73364666530064, 67.95766925811768, 62.38993181501116, 58.453548022678916, 46.50047166006905, 57.71330084119524, 56.578625270298545, 53.80244473048619, 46.15051521573748, 46.11921010698591, 54.479668276650564, 60.00018923623221, 59.37492084503174, 61.465738024030415, 58.0231522832598, 57.91160937717983, 59.68948663984026, 63.96109322139195, 63.85891996111189, 59.71279089791434, 53.40434421811785, 55.875905309404644, 59.1165520804269, 56.540104457310264, 46.23168407167707, 37.97737005778721, 22.45337472643171, 17.232725858688354, 13.840360828808375, 12.40442613192967, 10.525032213756017, 12.999574950763158, 5.202184464250292, 4.378350453717368, 5.409866120134081, 8.302059429032461, 7.197008805615561, 9.874679957117353, 11.392985548291888, 16.317540407180786, 11.954695292881556, 15.025119883673531, 20.757001570292882, 23.638740880148752, 22.586734976087296, 20.7960296017783, 14.572503805160522, 13.79565351349967, 5.51280107668468, 1.9388867829527174, 6.450860432216099, 10.494590418679373, 4.9764774441719055, 1.925375142267772, 1.714507520198822, 1.613963286791529, 0.2068969572761229, 0.6240528907094682, 45.02063042776925, 43.46548114504133, 71.49038355691093, 63.16044534955706, 34.04105574744088, 38.51719297681536, 10.330747553280421, 1.9245997667312622, 0.18013284914195538, 0.24494994751044682, 0.24468179047107697, 0.2561247950153691, 0.21604534637715134, 0.16793711856007576, 0.17087611156914914, 0.12091185977416379, 0.14337214242134774, 0.16045475006103516, 0.1720960768205779, 0.09456414822489023, 0.16276385901229723, 0.056820169623408995, 0.271744752568858, 0.21146048525614397, 0.07876275040741477, 0.11197119738374438, 0.10724830188389335, 0.08332112152129412, 0.1546144905899252, 0.2141499537974596, 0.20213798406933034, 0.15551869278507574, 0.10449170587318284], [0.13059498875268868, 0.11702724679240159, 0.0818539931039725, 0.2346337182181222, 0.19223738461732864, 0.10090389767927782, 0.11134592736405985, 0.03917609461184059, 0.048887236908610375, 0.008086353723358895, 0.08603088504501752, 0.08709089245115008, 0.10471183620393276, 0.014827890055520194, 0.08381248265504837, 0.11404036278171198, 0.03668155221800719, 0.00828622978380216, 0.0890664200165442, 0.025365345512649844, 0.039507124706038406, 0.02221973180504782, 0.06916829917047705, 0.015332048359726156, 0.057133523880371025, 0.04744707686560495, 0.1600430557238204, 0.019491898893777813, 0.21676506847143173, 0.07727296570582048, 0.21392306525792393, 0.4919204094580242, 4.974168470927647, 22.21415867124285, 34.19849497931344, 42.99543898446219, 64.0482931137085, 43.39281688417707, 25.3895514351981, 0.9412338137626648, 0.1210451919053282, 0.848069001521383, 0.16710765021187918, 0.9666328451463154, 3.472033074923924, 2.6416983732155392, 2.196216357605798, 3.4211247095039914, 14.112751058169774, 21.577870437077113, 24.23863445009504, 33.01270498548235, 24.69464819771903, 30.086676120758057, 26.087520565305436, 24.591736691338674, 17.36591935157776, 10.757055146353585, 15.496478727885656, 1.8290440142154694, 11.677866901670184, 16.729724918092998, 8.707790800503322, 2.719506038086755, 2.0391920634678433, 6.115014042173113, 3.948015511035919, 2.426635341984885, 2.8195794224739075, 1.0548798527036394, 0.5007898392421859, 1.2230959577219827, 3.2689908615180423, 6.637876408440726, 13.408265386308942, 14.848701647349767, 20.95333855492728, 30.331905841827393, 37.88275991167341, 46.52138921192714, 52.01931810379028, 54.626483712877544, 56.45048311778477, 53.689077922276084, 56.54313039779663, 59.436315127781455, 56.26741892950875, 54.73323236192976, 42.87320627485003, 27.16781779697963, 33.90456533432007, 39.49849053791591, 34.69728183746338, 35.299051421029226, 38.35092258453369, 42.945519651685444, 46.920323508126394, 51.810041836329866, 52.379193101610454, 53.69971561431885, 58.78647790636335, 65.45965984889439, 66.06973252977643, 63.55554076603481, 51.84000941685268, 41.87026160103934, 40.784786224365234, 47.95638329642159, 44.19291932242257, 31.872526441301616, 23.22388652392796, 17.659744773592266, 9.434200644493103, 7.581320183617728, 4.4486835939543585, 3.651980996131897, 2.8398114911147525, 1.1036842167377472, 1.5809200427361896, 0.7184962800570897, 2.7189217380114963, 2.3943548798561096, 1.3367126839501517, 4.316237032413483, 3.585774217333112, 9.972554888044085, 11.816532969474792, 13.328913484300886, 15.906973089490618, 15.47929583277021, 12.268811191831317, 11.712610500199453, 2.4454339104039327, 1.60993506865842, 2.245960465499333, 2.740374735423497, 4.0949573176247736, 2.010036336524146, 4.508744691099439, 1.761165325130735, 0.1724917713020529, 0.13872982295496122, 18.834501028060913, 23.757987601416453, 33.66616569246565, 37.870225361415315, 7.2981550352913995, 6.125696897506714, 13.60811642238072, 2.313453746693475, 0.23801040702632495, 0.0827307892697198, 0.0901137591738786, 0.05835349591714995, 0.06180796519454036, 0.05374472322208541, 0.10317863883184535, 0.08157374457057033, 0.029690884120230163, 0.18518735149077006, 0.11293622345796653, 0.2896658123603889, 0.1480087214814765, 0.03131814340927771, 0.0224777345678636, 0.03512531179668648, 0.11368143132754735, 0.059956819883414676, 0.03254454117268324, 0.1040791090843933, 0.02218401711434126, 0.06509271250771624, 0.06339554036302225, 0.013120615372567304, 0.12143847080213682, 0.04670523792239172, 0.07856156477438551, 0.11751538488481726, 0.04510535073599645, 0.07166370669645922, 0.10965125901358468, 0.08432668327753033, 0.1511164525789874, 0.051765904761850834, 0.01726932860245662, 0.07443003289933715, 0.054700263376746855, 0.031734943722507784, 0.006071574179389114, 0.04526636031057153, 0.04216320253908634, 0.015616452920117548, 0.0036519004913446096, 0.04659317447138684, 0.03447137027978897, 0.07272517973823206, 0.025527057370969226, 0.09578437131962605, 0.08243724823530231, 0.035805475299379656, 0.0471315241551825, 0.023967649887448976, 0.17206771405679838, 0.044495218832577975, 0.2161689754575491, 0.15949344235871518, 0.07645229795681578, 3.296633618218558, 30.358948230743408, 56.27593394688198, 57.39924921308245, 62.52521324157715, 72.47141361236572, 47.10631288800921, 37.24917105266026, 0.449750190866845, 0.031092859605061154, 0.49228969535657335, 0.08305619430861302, 3.2492974953992024, 3.989710347993033, 4.146563325609479, 2.5347599514893124, 4.6253775869097025, 4.998453293527875, 10.909945913723536, 19.564060143062047, 24.97446952547346, 24.04939157622201, 27.163732256208146, 24.237008571624756, 23.761220250810894, 18.457212107522146, 31.54797955921718, 22.59666395187378, 6.488668620586395, 16.627951179231914, 9.617613111223493, 6.809068296636854, 4.726320581776755, 0.5027764812111855, 3.2383154332637787, 3.376571774482727, 3.268984781844275, 1.4361891746520996, 0.8289923423102924, 0.5834037576402936, 2.4457051072801863, 4.018599654947009, 7.369937743459429, 16.14204454421997, 21.079936470304215, 29.22869518824986, 34.749817167009624, 43.003290448869976, 53.652318477630615, 56.72939770562308, 60.2601352419172, 60.183600834437776, 58.11862053189959, 61.83529881068638, 64.10910374777657, 63.23725768498012, 60.52349281311035, 57.297854151044575, 38.86797973087856, 45.754599911826, 52.51224763052804, 47.10452720097133, 45.384688241141184, 47.478833607264924, 55.94892740249634, 57.587694781167166, 60.74709974016462, 59.02860178266253, 58.290765626089915, 62.1967510495867, 67.23046384538922, 68.0105311529977, 64.2750962121146, 57.198560919080464, 47.65238223757063, 50.006789752415244, 56.99934564317976, 46.876949378422324, 37.40950768334525, 29.012748650142125, 21.757564749036515, 10.896844216755458, 6.626642908368792, 3.0770855247974396, 0.712818787566253, 1.6046746309314455, 2.595639850412096, 2.907174493585314, 3.805210053920746, 2.684075653553009, 3.2833108816828047, 1.4544601142406464, 5.532863565853663, 2.6865900329181125, 4.667514937264579, 8.49676445552281, 9.31400375706809, 9.725047894886561, 6.845956717218671, 6.634692396436419, 7.4974198171070645, 2.6158658393791745, 4.057872176170349, 3.2340874544211795, 3.96489702803748, 1.8517088208879744, 2.086645002876009, 1.417309616293226, 0.9865092528717858, 0.05186603617455278, 0.3852812759578228, 35.971883705684114, 35.66702454430716, 35.2500353540693, 57.25504629952567, 22.478648798806326, 18.05224503789629, 6.994976469448634, 6.251611718109675, 0.2710837780364922, 0.30702501801507814, 0.09904607558356864, 0.120388532855681, 0.1228399577417544, 0.12563250932310308, 0.059624120593070984, 0.050921165983059576, 0.05061452243743198, 0.13083034540925706, 0.06262824617858444, 0.15331098410700048, 0.06074468046426773, 0.03947759486202683, 0.04202501888253859, 0.0392839748944555, 0.022967674170753787, 0.06742861002151455, 0.12800546841961996, 0.07581271763358798, 0.04912464613361018, 0.05497995890410883, 0.022545650834217668, 0.06430576116378818, 0.08673479727336339, 0.07625300543648855, 0.14456302566187723, 0.1817272435873747, 0.09259056126964943, 0.21772940243993485, 0.2746596575847694, 0.20412987789937428, 0.21013029877628597, 0.1846305863665683, 0.1282002893941743, 0.2838525314416204, 0.19789100624620914, 0.13516216725111008, 0.18463448115757533, 0.24482835403510503, 0.21350501983293466, 0.2643647614334311, 0.12537082550781115, 0.12963917718401977, 0.23160232231020927, 0.13192889360444887, 0.11828134235526834, 0.16774555455361093, 0.162660151720047, 0.15896662777023657, 0.22731619301651204, 0.08027017701949392, 0.3378904360745634, 0.1269240871604, 0.25086490011640955, 0.2322073041328362, 0.2838807042155947, 4.757293479783194, 54.0657501901899, 80.864365032741, 80.75324944087437, 75.82553141457694, 94.48568303244454, 59.97643334524972, 35.79292590277535, 1.6582756404365813, 0.18298543750175408, 1.2630613446235657, 0.9296112145696367, 4.466923918042864, 9.131277424948555, 8.667540754590716, 5.307019753115518, 5.35151297705514, 20.92542937823704, 27.680332558495657, 23.602361849376134, 39.89167519978115, 30.33010278429304, 35.071612562452046, 33.95941093989781, 30.402728830065044, 22.62067345210484, 26.095441511699132, 30.268541744777135, 9.012259994234357, 24.586942434310913, 23.78245047160557, 19.187658854893275, 13.702994074140276, 8.31066998413631, 9.457375492368426, 9.656872170312063, 7.2349594320569715, 4.579525990145547, 1.5863396376371384, 0.5750731389437402, 2.702523555074419, 3.306661388703755, 8.634735703468323, 18.945904970169067, 24.32253394808088, 35.84820924486433, 41.04645538330078, 46.57310465403965, 57.39765807560512, 64.61860820225307, 64.075106212071, 63.971765654427664, 59.319224085126606, 62.32236058371407, 65.84565312521798, 66.36295345851353, 64.36605507986886, 61.18851184844971, 46.921403953007285, 53.111995288303916, 57.653584548405235, 53.681619031088694, 52.42033338546753, 55.05830035890852, 62.36671093532017, 63.47295447758266, 63.35438346862793, 61.36215427943638, 60.12561116899763, 61.731506620134624, 67.61336517333984, 67.07804121289934, 64.75505692618233, 60.37717069898333, 55.691274302346365, 51.99603469031197, 58.09998893737793, 48.46547433308193, 43.06212084633963, 31.907239641462052, 21.035853624343872, 10.798353501728602, 11.165008204323904, 7.7847451993397305, 8.103304471288409, 3.940889264856066, 4.2559075610978265, 4.930495134421757, 6.15170921598162, 3.6999778492110114, 2.2518275678157806, 0.9245292586939675, 8.117320724896022, 7.075210358415331, 13.552253774234227, 18.369001252310618, 18.210068157741002, 18.241548708506993, 17.804097073418752, 14.092213920184545, 18.25839809009007, 3.8203545212745667, 3.6127922875540595, 3.968863146645682, 8.461465001106262, 10.865256837436132, 5.183058679103851, 9.774979387010847, 5.1146480185644965, 0.5238496075783456, 0.27505508065223694, 40.645165647779194, 42.69787195750645, 53.93703828539167, 78.46134444645473, 35.37690598624093, 32.00333322797503, 28.28325728007725, 9.800377658435277, 0.20920929605407373, 0.45274041326982634, 0.16068648334060395, 0.21204128409070627, 0.14958206777061733, 0.18238817740763935, 0.2181363741734198, 0.13947467798633234, 0.15175639252577508, 0.20397043574069226, 0.21415124301399502, 0.2910844662359783, 0.20076910752270902, 0.194455176325781, 0.1071166932316763, 0.09141427331737109, 0.16767206921109132, 0.21076197416654655, 0.1924444870757205, 0.14200952196759836, 0.15868810271578176, 0.1538287198969296, 0.15157081319817475, 0.1223635718758617, 0.26451542334897177, 0.09054737697754588], [0.1371487413666078, 0.15831262857786246, 0.21540611210678304, 0.11078099946358375, 0.058896636058177264, 0.11723665626985685, 0.04699563055432268, 0.08408815786242485, 0.006987080343865922, 0.0904435950464436, 0.02731257477509124, 0.05110763079885926, 0.09572815469333104, 0.07411205103354794, 0.06927088009459631, 0.09197559819689818, 0.05501242001940097, 0.06672184794609036, 0.006710890298044043, 0.01400260317937604, 0.041864748911133835, 0.015423016157001257, 0.15607780564044202, 0.06530100918774094, 0.10317507652299744, 0.21058691213173525, 0.033784468924360614, 0.06909055262804031, 0.05001454820324268, 0.14456149217273506, 0.2186605967581272, 0.4928203097411564, 2.2942391548837935, 14.326863271849495, 32.769465923309326, 26.663451535361155, 45.69284779684884, 55.887081486838206, 24.43393267904009, 5.599703064986637, 0.598244024174554, 0.33435999123113497, 1.0323993904250008, 3.490369588136673, 1.8643447714192527, 2.6573413738182614, 1.1488996190684182, 3.887872338294983, 4.300605322633471, 13.760067445891243, 18.376298597880773, 21.606147868292673, 24.194412640162877, 25.75185309137617, 32.015072209494456, 21.890376091003418, 24.461400645119802, 8.005207198006765, 12.434300780296326, 10.636243343353271, 7.789010524749756, 10.429421527045113, 4.2113014289311, 6.186940491199493, 7.014726289681025, 3.6831145712307523, 2.748383185693196, 1.0302968003920145, 0.1522891510810171, 0.2240388145936387, 1.317318307501929, 1.2637557302202498, 2.5235177661691393, 5.827508441039494, 10.23616519996098, 18.728077207292827, 24.022380454199656, 32.28761529922485, 41.09752116884504, 53.86119869777134, 56.10994495664324, 61.21617957523891, 61.822583607264924, 57.204699652535574, 53.43580566133772, 53.92022017070225, 53.23377636500767, 43.77721207482474, 42.02864578792027, 25.18477586337498, 24.306141410555156, 34.892870153699604, 30.30054862158639, 34.447174480983186, 37.270932810647146, 44.11539132254464, 51.27109439032418, 56.16457864216396, 55.24234424318586, 51.44941643306187, 57.76801095690046, 59.27201107570103, 60.506226539611816, 60.29691900525774, 55.12295682089669, 42.96457856042044, 43.33923932484218, 42.97630017144339, 35.594860553741455, 22.56948607308524, 13.466082215309143, 12.970805065972463, 8.100795303072248, 4.0264550277165005, 1.6444557820047652, 0.2671658896974155, 0.13223624282649585, 0.6646788450224059, 1.1535544778619493, 0.7071607283183506, 1.1299943306616373, 1.43246548303536, 1.1174364387989044, 1.9791298806667328, 0.381988236946719, 4.287259570189884, 6.217379680701664, 12.862374084336416, 15.618202481951032, 11.142079148973737, 8.671784366880145, 2.978720094476427, 0.6863831175225121, 3.5420337872845784, 5.3159807579857965, 2.9112915183816637, 1.1584211481469018, 0.5343456215092114, 3.7361744897706166, 0.10918240488639899, 0.26729882827826906, 14.39761243547712, 24.64044530051095, 30.628712041037424, 50.01868159430367, 20.02619525364467, 7.68509760924748, 10.38069120475224, 10.417295183454241, 1.800443274634225, 0.2392347827553749, 0.06971323742930378, 0.17789365643901484, 0.1580488005919116, 0.21711702458560467, 0.07378517357366425, 0.15239174557583673, 0.04461057996377349, 0.20567357220820018, 0.19303163699805737, 0.03709991655445524, 0.12339118602020399, 0.06669132065560136, 0.15671186947396823, 0.06333154094006334, 0.07163115058626447, 0.04683051584288478, 0.0373109918353813, 0.03266162917550121, 0.054765314528984685, 0.10604821092316083, 0.08846705646387168, 0.05373580727194037, 0.10660671988236052, 0.07213600778153964, 0.09676042358790125, 0.1821331160941294, 0.07078511919826269, 0.09785995565887008, 0.14039198947804316, 0.09918630841587271, 0.12591136007436685, 0.06339579820632935, 0.11723475637180464, 0.021757479823593582, 0.0305029005477471, 0.025561216520145535, 0.04930698884917157, 0.026651361059131365, 0.08756674227437802, 0.040940258518925736, 0.07722020960812058, 0.09307198186538049, 0.036336408595421484, 0.06209424590425832, 0.03048802027478814, 0.11268137249031238, 0.03147349739447236, 0.10341839239533458, 0.03664762885974986, 0.014286902566839541, 0.2889874944729464, 0.056433129856096845, 0.2221202025456088, 0.16268238052725792, 0.10471127301986728, 0.25328946858644485, 0.49769723947559086, 6.226798832416534, 35.973658970424104, 56.900041988917756, 48.0508371080671, 69.09545067378453, 61.203429630824495, 39.584696837833945, 10.160110218184334, 0.7940968062196458, 0.44831647351384163, 0.9837663429124015, 2.3110852794987813, 2.370517347540174, 1.3278937914541789, 2.3443365352494374, 3.757630092757089, 3.1077589988708496, 6.864627829619816, 8.539172785622732, 14.143327474594116, 14.559034722191946, 20.066022327968053, 23.479507275990077, 20.485035181045532, 18.25758515085493, 16.16954377719334, 29.13610349382673, 18.339824029377528, 18.170098645346506, 6.5926709941455295, 6.387446394988468, 5.348603853157588, 5.668681740760803, 4.2974478006362915, 2.6818148834364752, 2.353266490357263, 0.49215181704078403, 0.41614153715116636, 1.7358990694795335, 1.4959063359669276, 2.72372077192579, 6.249716596943991, 14.517452359199524, 19.22643154008048, 30.098859786987305, 37.577674933842246, 48.17285442352295, 60.30144228254046, 64.8872880935669, 69.55795056479317, 68.70935317448208, 62.941201891217915, 58.53036730630057, 59.298650469098774, 61.556856700352256, 53.39317846298218, 55.16129698072161, 36.60315186636788, 34.05665445327759, 51.4528523172651, 42.21722684587751, 47.01584734235491, 46.83562496730259, 54.471959250313894, 57.859939098358154, 62.32679353441511, 59.076801436288015, 57.70066901615688, 61.14431435721261, 64.18308816637311, 65.58924375261579, 61.48563071659633, 58.42339284079415, 47.18030425480434, 48.26321227209908, 47.53653839656285, 43.21857343401228, 29.451728888920375, 17.280294963291713, 12.777497495923724, 8.337236421448843, 3.8950915166309903, 1.7411215092454637, 0.6413905460919652, 0.11616366170346737, 1.9482397096497672, 2.252947530576161, 2.36083351288523, 4.915823144572122, 4.9202947446278165, 2.5868612357548306, 7.475515621049063, 1.8301379212311335, 5.345860183238983, 6.052991815975734, 6.7816467966352185, 6.838183420045035, 4.716445020266941, 3.972164409501212, 2.578755510704858, 1.8060831491436278, 5.2008530156953, 5.292269596031733, 2.892799973487854, 5.062600799969264, 0.4589217315827097, 1.2487926759890147, 0.17886012100747653, 0.42923832152570995, 29.387204442705425, 42.85275425229754, 32.09283644812447, 65.11535576411656, 39.78338405064174, 22.454646246773855, 17.192542689187185, 11.536451084273201, 2.421752061162676, 0.4397908438529287, 0.07975998653897218, 0.3056736205305372, 0.12212962657213211, 0.07853272025074277, 0.06177849641868046, 0.1940463182649442, 0.03303006011992693, 0.1841917099165065, 0.11839121074548789, 0.14099664560386113, 0.08848849817046098, 0.11915575686310019, 0.04093509486743382, 0.016952205083466003, 0.08254079946449824, 0.04352980599339519, 0.07831731252372265, 0.02194660110399127, 0.04509896911414606, 0.06072646179901702, 0.11763978749513626, 0.1318999065884522, 0.13945681894464151, 0.08589703722723893, 0.12892050003366812, 0.15452123273696217, 0.2733731009066105, 0.2199327549231904, 0.19675916912300245, 0.1510987835271018, 0.2022612060287169, 0.22206530906260014, 0.19406533081616673, 0.30079177820256775, 0.1096889516338706, 0.09938019301210131, 0.16544745144035133, 0.2668070260967527, 0.2025469642664705, 0.17670936855886663, 0.1740631769810404, 0.2588449604809284, 0.1622639008398567, 0.1315202119627169, 0.1303068692130702, 0.239781953394413, 0.14702405860381468, 0.2894316092133522, 0.11759170650371484, 0.18308348581194878, 0.36395823157259394, 0.12450607333864484, 0.2543754503130913, 0.3492959854858262, 0.19492314835744246, 0.3736983303512846, 0.6908671483397484, 10.248043145452227, 70.25345829554966, 85.40852165222168, 70.63035637991769, 84.89406313214982, 85.80591692243303, 49.47904975073678, 10.690602575029645, 1.0193684782300676, 0.5953334346413612, 1.5637616834470203, 6.61004843882152, 6.717909233910697, 7.02156548840659, 6.274298455033984, 6.835375913551875, 5.270318499633244, 20.102179016385758, 26.580019303730555, 26.869785240718297, 28.92697661263602, 30.138697283608572, 38.58134569440569, 30.01481785093035, 29.936577660696848, 13.75108516216278, 29.461703027997697, 20.756414447511943, 19.779365709849767, 21.712325028010778, 11.45041675227029, 4.7017956120627264, 6.55870863369533, 7.587926183428083, 5.412931144237518, 3.207159710781915, 0.4202519937285355, 0.7466348558664322, 2.209447681903839, 2.5009107163974216, 3.2180948725768497, 6.887367980820792, 13.926006061690194, 19.269546849387034, 32.58089181355068, 40.67234352656773, 49.66363212040493, 65.33351530347551, 69.13460377284459, 71.31558772495815, 71.46671104431152, 64.02657999311174, 58.03547143936157, 62.39424664633614, 63.28034346444266, 59.809002603803364, 63.64028794424874, 45.7218530518668, 47.52274969645909, 62.98695577893938, 51.39083617074149, 54.785444600241526, 53.167681625911165, 60.931810651506694, 62.90156241825649, 68.93436363765171, 61.40278039659773, 61.69908632550921, 64.36477661132812, 65.31806250980922, 65.44880676269531, 62.344573974609375, 56.556853090013774, 47.91630261284964, 48.641552107674734, 48.784038816179546, 45.66631610052926, 38.27302285603115, 28.0195175579616, 20.49657266480582, 11.680810332298279, 6.343374839850834, 5.560832670756748, 1.0524214931896754, 0.28707606132541386, 1.8740264347621371, 2.7720728516578674, 2.9455741473606656, 7.360496878623962, 7.021858615534646, 2.597704116787229, 7.231144002505711, 2.4263317925589423, 7.909772821835109, 10.327104091644287, 15.038851261138916, 18.669276339667185, 13.570743799209595, 13.152988570077078, 6.493392527103424, 1.224195727280208, 7.351190635136195, 11.046947019440786, 8.539346490587507, 5.844044719423566, 5.297140283243997, 7.1503268991197855, 0.37159126198717524, 0.35083324728267534, 30.81897108895438, 44.90186486925398, 50.35211869648525, 87.17112677437919, 50.00078303473336, 34.87362016950335, 42.325507572719026, 20.269274507250103, 2.285055156264986, 0.5840291497962815, 0.3477127461561135, 0.47171010822057724, 0.2571532369724342, 0.1942396464624575, 0.12388807721436024, 0.20915014137114796, 0.10500320592629057, 0.27904304808803965, 0.17496376936989172, 0.13333238900772162, 0.15785271754222258, 0.15666411417935575, 0.2797856368124485, 0.1783570008618491, 0.1266138202377728, 0.14531850655164036, 0.2911187729665211, 0.11171366620276656, 0.2022727546947343, 0.10116520151495934, 0.290362857814346, 0.20847118566078798, 0.2389569633773395, 0.14715721431587422, 0.10546680140708174], [0.03972394039322223, 0.1229409644646304, 0.04541747345189963, 0.08604942940707717, 0.06286466134978191, 0.05625085838671241, 0.024911734674658095, 0.05815513977514846, 0.02095401124097407, 0.007502358988858759, 0.03620692375781281, 0.05831127068293946, 0.05840304932956185, 0.07035152175064598, 0.13804026852760995, 0.1011460939688342, 0.12790140828916005, 0.01729789492674172, 0.07358049348528896, 0.10168343942080225, 0.02726009178773633, 0.011122666465650712, 0.07143084704875946, 0.0579524002969265, 0.03593981844772186, 0.10098450085414307, 0.09202529410166399, 0.17934486642479897, 0.08563051545726401, 0.24576038973672049, 0.24242188887936728, 0.13108680450490542, 1.2215338072606494, 16.573755230222428, 31.972184453691753, 28.710832050868444, 31.367656435285294, 49.50955581665039, 40.896110262189595, 26.871576138905116, 8.401898963110787, 0.9937789142131805, 1.2364663545574461, 1.5931144569601332, 1.2851676898343223, 0.7906350834029061, 2.505083109651293, 0.9302781330687659, 0.4977591761520931, 1.6674846091440745, 9.622509854180471, 15.952567168644496, 17.498246056692942, 16.06879837172372, 20.83702744756426, 22.947443757738384, 24.58662976537432, 15.400357348578316, 9.547283445085798, 10.916601419448853, 12.877718312399727, 3.078064786536353, 2.9361632466316223, 1.840856603213719, 3.8331587484904697, 0.3540159564997469, 0.45280335417815615, 0.42637360095977783, 0.7733365116374833, 0.4465159944125584, 0.3171584771147796, 0.6336411876337869, 2.0059058495930264, 7.345893502235413, 10.897121276174273, 17.48803220476423, 24.26794021470206, 28.95204050200326, 35.180344922201975, 43.771712575639995, 54.816732338496614, 63.884121077401296, 67.01101888929094, 67.92948041643415, 60.802574157714844, 53.28172588348389, 47.330295017787385, 38.340781688690186, 29.386221272604807, 18.215176820755005, 4.523816636630467, 31.545763083866664, 33.79950162342617, 40.172670773097444, 48.40654666083199, 49.662027086530415, 54.92062527792794, 52.99681152616228, 52.41715805871146, 55.797546999795095, 53.364447661808555, 58.26092658724104, 45.34094933101109, 33.449621609279085, 28.044631821768625, 27.56623271533421, 31.771131379263743, 34.75563975742885, 24.566042252949305, 14.405430027416774, 10.075140697615486, 6.496599555015564, 5.5659613098417005, 0.45097934348242624, 0.04505896268944655, 0.3377845303288528, 0.3347417621740273, 0.23081158474087715, 0.4267952154789652, 1.129703591976847, 1.1797476666314262, 1.2006388370479857, 1.0360744446516037, 2.079190671443939, 0.06053910470966782, 0.7826242446899414, 4.202047296932765, 6.493947080203465, 6.562575740473611, 2.488586349146707, 1.270412755864007, 0.9168821147509983, 2.393361504588808, 6.596713977200644, 2.867021288190569, 2.2957929457936967, 2.146134827818189, 1.3053717485495975, 0.17985203063913754, 0.34780996665358543, 15.623127017702375, 23.799374546323502, 23.242921113967896, 51.608860220227925, 27.64532232284546, 5.856141533170428, 10.926766633987427, 14.926960945129395, 0.1039963753095695, 0.15120534066643032, 0.18829342696283544, 0.24528397672942706, 0.2828129343688488, 0.09536490097109761, 0.0818277337987508, 0.13812364691070148, 0.13929911383560725, 0.1400283897029502, 0.20894937642983027, 0.10213309779231038, 0.11723979110164301, 0.11839203855821065, 0.11735829045729977, 0.10015340402190175, 0.10360269607709986, 0.10802746364580733, 0.030429625551083257, 0.04769717130277838, 0.07364967013044016, 0.06333343405276537, 0.11526815832725593, 0.10243188390242201, 0.09900205901690892, 0.11301142549408333, 0.07091480759637696, 0.14967314074082033, 0.047676031544272385, 0.16182735855025904, 0.15160027518868446, 0.08065551027123417, 0.057694156654179096, 0.03778440571789231, 0.039639103159840615, 0.029964628895478587, 0.026865347255287424, 0.04534686849053417, 0.10771719672318016, 0.12586621035422596, 0.08709259557404689, 0.13064754807523318, 0.06447375286370516, 0.08078384159931115, 0.05643733338053737, 0.05382795911282301, 0.018667519558221102, 0.06197061003851039, 0.01603823198404695, 0.010537434252910316, 0.08023829265896763, 0.03085119596549443, 0.06189821713737079, 0.28346761209624155, 0.13556588201650552, 0.13685627920286997, 0.06358168287468807, 0.20003759248980454, 0.08885343465954065, 0.12648137020213263, 1.055370134966714, 47.65319517680577, 61.07955714634487, 52.38641575404576, 55.32251255852835, 73.76111739022392, 48.18635824748448, 51.7932584626334, 9.94264463015965, 1.0504568900380815, 1.2059165367058344, 1.1970124202115195, 1.1727222778967448, 0.21112657817346708, 0.20878952715013707, 0.1903376765549183, 2.0387230600629533, 2.4396510549954007, 7.082074310098376, 6.925990411213466, 9.47149075780596, 9.598991070474897, 13.743810398238045, 17.523919650486537, 19.710199866976055, 12.10162103176117, 15.495896816253662, 12.292463728359767, 12.73283360685621, 13.770498429025922, 3.3917192816734314, 2.628505046878542, 4.340520986488887, 1.1170380030359541, 1.413034628544535, 0.5844418619360242, 1.786855312330382, 0.662670761346817, 0.468361890741757, 1.6115218635116304, 3.0546951719692776, 8.43503144809178, 13.476557493209839, 19.649370125361852, 28.8345308303833, 33.9507291657584, 40.95034442629133, 51.78430918284825, 62.637023653302876, 69.90695858001709, 72.42673669542584, 71.03372710091728, 68.58939947400773, 59.01198863983154, 56.84882681710379, 51.02598973682949, 42.9716031891959, 30.755329063960485, 7.706253136907305, 46.715292590005056, 46.031172956739155, 53.08689144679478, 59.2169257572719, 58.59850828988211, 59.88377216884068, 60.50637245178223, 60.0175666809082, 60.393443380083355, 57.58030537196568, 61.16945988791329, 49.02473831176758, 33.89857946123396, 28.966025488717214, 30.62905250276838, 33.822034631456646, 34.72156926563808, 29.85505792072841, 20.8260840347835, 9.235501272337777, 6.035742912973676, 2.4672447400433675, 0.32884352867092403, 0.022211621615237424, 0.18146699826632226, 0.5315131449273655, 0.4751142369849341, 0.7690226574029241, 1.8991222424166543, 3.1583709801946367, 3.5533741159098486, 2.5711424563612257, 5.760507830551692, 0.775426345212119, 2.1073219733578816, 4.351397088595799, 3.7565366200038364, 2.448077917098999, 2.5615359204156056, 1.7551598016704832, 1.6063203769070762, 4.110733202525547, 9.240531768117632, 4.5503027353967935, 0.9962841740676335, 2.0537921828883032, 0.7085297405719757, 0.16770539885120733, 0.5177512605275426, 25.048771824155533, 43.68853221620832, 23.87250781059265, 61.415169034685405, 46.6046598979405, 26.17984127998352, 22.630661487579346, 34.34131172725132, 5.934795141220093, 0.3661363289824554, 0.5014582776597568, 0.23969496520502226, 0.26930601628763334, 0.17064231554312365, 0.15041050474558557, 0.1768980555768524, 0.14276976617319243, 0.07318209164908954, 0.11258139035531453, 0.13444457575678825, 0.10065969292606626, 0.09161314514598676, 0.07759773292179618, 0.023380206498716558, 0.1127349767567856, 0.11942828366799013, 0.029274321294256618, 0.05581350524776748, 0.08032267527388674, 0.006841923891832786, 0.15230558519916876, 0.11942114547959395, 0.04513890089999352, 0.12834381312131882, 0.10339586503271546, 0.11718945737395968, 0.08533761224576406, 0.21857397497764655, 0.24918446743062564, 0.14765806815453938, 0.16537188978067466, 0.14245861715504102, 0.15166493957596167, 0.19550926690655096, 0.09897852742246219, 0.18710756488144398, 0.18136747074978693, 0.2187855150550604, 0.19689022137650422, 0.1872342745108264, 0.1965754082692521, 0.1449551239077534, 0.13222583409930977, 0.0960170952603221, 0.13748441264033318, 0.16935216262936592, 0.14561512134969234, 0.15404199702399118, 0.17013353641544068, 0.2189343042139496, 0.10952013212123088, 0.34503367277128355, 0.18495983869901725, 0.21826917704726967, 0.13316375948488712, 0.2374486071722848, 0.261314583676202, 0.29164113636527744, 2.578475194317954, 67.4207819529942, 79.91533837999616, 78.29864542824882, 75.60418265206474, 88.27997589111328, 67.99401528494698, 55.84417288643973, 14.44501999446324, 1.7989445264850343, 2.425407247883933, 3.3833367143358504, 2.8509179694311957, 2.65847110748291, 5.656464636325836, 4.332072845527104, 3.6392243206501007, 3.276175298861095, 10.851836391857692, 22.533588205065044, 28.889428547450475, 21.085931028638566, 26.088891097477504, 27.967529399054392, 33.368612561907085, 20.81202609198434, 17.792151382991246, 19.35914387021746, 17.170862572533743, 16.445527962275914, 3.1919846279280524, 0.6650943255850247, 1.7121056147984095, 0.3802926593593189, 0.9375875294208527, 0.48199843615293503, 2.852856082575662, 2.4280881668840135, 4.060698355947222, 4.803713526044573, 4.882150871413095, 11.323355913162231, 15.468748467309133, 20.467134884425572, 27.15555248941694, 34.01522581917899, 39.8428293636867, 52.42563138689314, 63.6846660886492, 74.21503625597272, 74.1817752293178, 71.54776872907365, 68.69122532435826, 62.27739184243338, 63.41415882110596, 57.93099137714931, 56.8696470941816, 37.85508176258632, 14.077610543795995, 64.1701089314052, 56.7913304737636, 63.28665937696184, 64.15319701603481, 65.87806647164481, 65.69223690032959, 66.56856455121721, 64.97425869532994, 66.22895744868687, 61.15108190264021, 65.94142014639718, 52.28065374919346, 34.76908104760306, 28.431575264249528, 32.25432995387486, 35.62151384353638, 38.081374168395996, 35.09735911233084, 26.360504865646362, 18.715502704892838, 14.785242012568883, 11.398300920213972, 3.163117902619498, 0.14662399435681955, 0.5193657396095139, 0.5869054325989315, 0.45144842831151827, 1.7434034496545792, 2.283011951616832, 4.062624744006565, 2.5955710198198045, 1.8471054221902574, 5.14822301694325, 0.46233546840293066, 1.7153362014463969, 8.417825971330915, 10.18798291683197, 10.47636616230011, 4.256700089999607, 2.3610641062259674, 2.3930277739252364, 5.864163662706103, 11.372298155512128, 9.23618653842381, 4.694069215229579, 5.8274063893726895, 3.400090775319508, 1.070934099810464, 0.372264314442873, 30.584108080182755, 45.47033521107265, 40.813840116773335, 83.9334190913609, 61.44547012874058, 34.664948395320344, 44.39513969421387, 51.79113578796387, 6.824454648154123, 0.25215949064918924, 0.4644625942621912, 0.3479937682194369, 0.3745098039507866, 0.22671003054295266, 0.18878198574696267, 0.2635748381061213, 0.21536181734076568, 0.15655987762979098, 0.19752799001123222, 0.18402485815542086, 0.16567075731498854, 0.2046185859612056, 0.13391492489193166, 0.18615467101335526, 0.2335085714501994, 0.17525055898087366, 0.2362943376813616, 0.1772916465997696, 0.09834637027233839, 0.096104198800666, 0.20327111040907248, 0.2926635800727776, 0.2325699675296034, 0.15580765370811733, 0.11192828682916504, 0.15223494970372745], [0.1705083455890417, 0.08298875471310956, 0.04212406124653561, 0.017830828204751015, 0.11482624204031058, 0.12075290616069521, 0.04665617644786835, 0.062025578160371096, 0.06777667813003063, 0.03206758533737489, 0.020618971004816036, 0.06398693112922565, 0.11860067450574466, 0.04753585299476981, 0.13450975583067962, 0.07230944811765637, 0.017873379135770456, 0.02323385328054428, 0.09382314048707485, 0.02005014492065779, 0.09977727849036455, 0.02153577020258776, 0.15441375279000827, 0.0644870385793703, 0.16213248217744486, 0.1409950985440186, 0.180807462228196, 0.11024543177336454, 0.27871170586773325, 0.11593946016260556, 0.23000445376549447, 0.12030558873500143, 0.0489213129372469, 3.4599916296345845, 22.28624623162406, 27.78630300930568, 24.952475002833776, 29.592464651380265, 59.30407006399972, 30.82858739580427, 33.583926813943044, 12.228393520627703, 0.8251392947775977, 0.7991801734481538, 0.6774246639439038, 0.2862465929772173, 0.14012480952910014, 1.3927423059940338, 0.5541246458888054, 0.862574506018843, 0.760259350495679, 3.2103873661586215, 6.872527497155326, 8.39591656412397, 10.425693818501063, 8.214408772332327, 11.466132708958217, 16.333604642323085, 10.659545864377703, 14.018747142383031, 4.805715910026005, 1.5093626081943512, 0.742477281817368, 0.44824264890381266, 0.6285584717988968, 1.0963605982916695, 0.5392928474715778, 0.5081536269613675, 0.6934896047626222, 0.9387244284152985, 0.6544833406805992, 0.4404789055032389, 0.8845066034368106, 1.4914587289094925, 3.9985514964376176, 7.513931342533656, 12.016228539603096, 21.747752155576432, 28.617215497153147, 39.139946120125906, 54.09151063646589, 63.16098730904715, 69.3933755329677, 65.7730097089495, 61.63597583770752, 57.39724465778896, 44.91585506711687, 36.503632817949565, 21.244393382753643, 18.06076352936881, 0.57620726951531, 12.910221116883413, 38.67491708483015, 42.78981399536133, 51.74109833581107, 52.41987133026123, 62.44540623256138, 57.5068108013698, 53.75286933353969, 57.210317271096365, 50.17215340478079, 38.364405563899446, 16.88674204690116, 4.531346746853419, 1.7308390438556671, 2.196404827492578, 5.772784863199506, 12.75903786931719, 12.331601193972997, 11.465467418943133, 7.363515870911734, 1.6896367690392902, 0.0983214137543525, 0.0679040120116302, 0.7136478487934385, 0.9604185500315258, 0.1727450412831136, 0.32933565654924934, 0.20362991972693376, 0.811967518712793, 0.43989267838852747, 0.47009025514125824, 1.0380821483475822, 0.7226940233792577, 0.27842460413064274, 0.4542468695768288, 0.48898338420050486, 1.602640654359545, 1.1300126782485416, 0.4735312419278281, 0.3691975532897881, 2.540176723684583, 3.872468182018825, 5.4651607530457635, 3.0188635289669037, 1.5870316347905566, 4.810850628784724, 0.3146039827593735, 0.34928613315735546, 22.768039533070155, 31.642235347202845, 22.316583803721837, 53.390861238752095, 37.1672101020813, 10.043987580708094, 10.71595047201429, 28.07506319454738, 4.680829422814505, 0.382352420261928, 0.13548514991998672, 0.15874594104077133, 0.19356048719159194, 0.17638224682637624, 0.3507256859115192, 0.36304267070123125, 0.23523834720253944, 0.21199720645589487, 0.30424202020679203, 0.1252213985260044, 0.10834735898034913, 0.10211580872003521, 0.005584940738377294, 0.032554298506251404, 0.1217670581702675, 0.052432741836777756, 0.02677829290873238, 0.06024688681853669, 0.19659819347517832, 0.06642462925187179, 0.06918478078608002, 0.061289394806538305, 0.0454112139663526, 0.1298266699803727, 0.2468188772244113, 0.2379949635693005, 0.16280063561030797, 0.19890696315893105, 0.0906426432941641, 0.15167713963559695, 0.0911520602447646, 0.13876953082425253, 0.19641318411699363, 0.06625190816287484, 0.06185125572873013, 0.03775583939360721, 0.08492977198745523, 0.08197975956967898, 0.18255893753043242, 0.16087545534329756, 0.036045449386749945, 0.16182687000504561, 0.05385317008144089, 0.03773653846500175, 0.011939656554854341, 0.007119641489615398, 0.026790660905784795, 0.05758848161037479, 0.030683207658252547, 0.11233447824737855, 0.1141561751386949, 0.198025627593909, 0.1528973491596324, 0.31713616688336643, 0.14956631218748434, 0.38550033420324326, 0.07819724575217281, 0.4117523112467357, 0.12321528260196958, 0.13819470309785434, 12.765989542007446, 52.36165584836687, 51.22815799713135, 50.04025575092861, 54.57553604670933, 71.02424280984062, 39.95165205001831, 64.36929294041225, 9.934658544404165, 1.3185738687004362, 0.7769038687859262, 0.8641577182071549, 0.5582473703793117, 0.30583891166107996, 0.8746035748294422, 0.7877503867660249, 0.7883374009813581, 1.263707309961319, 2.5737369571413313, 2.7524808858122145, 3.235979970012392, 4.497283637523651, 4.496552773884364, 9.754417061805725, 12.143587282725743, 7.793863841465541, 13.759952800614492, 3.9201871071543013, 5.104225720678057, 1.8286345047610146, 1.114973085267203, 1.0254729049546378, 2.996544612305505, 1.9088043400219508, 1.195472742830004, 1.650536215731076, 0.6104714423418045, 1.3115372977086475, 0.3954661137291363, 0.46874507303748814, 1.6184644166912352, 4.325498981135232, 9.168762956346784, 16.120244571140834, 25.620942081723893, 34.179106031145366, 44.43334436416626, 62.02221924918038, 71.35579000200543, 75.36535917009626, 72.45482131413051, 69.73950004577637, 68.70317622593471, 54.15062591007778, 50.557198251996724, 32.91039623532976, 30.672447477068218, 1.5253511731113707, 22.89839816093445, 54.84352806636265, 51.61546100888933, 61.85815143585205, 59.056811468941824, 65.8312634059361, 63.44689178466797, 56.706885542188374, 59.05208669389997, 53.06794023513794, 40.089202063424246, 17.389564071382793, 4.405778901917594, 1.9898509510925837, 1.9606607002871377, 5.339641979762486, 12.438733730997358, 15.30494121142796, 9.395084023475647, 0.759010520364557, 1.5148311661822456, 0.20615784265100956, 0.06993441270398242, 0.4378825862492834, 0.2600376350539071, 0.6423236674496106, 0.14738719697509492, 0.9358311550957816, 1.1910833269357681, 0.4907876359564917, 0.6906024111168725, 2.5494484433106015, 2.761251900877271, 0.9700448449168886, 0.6841311955026218, 0.48616176417895723, 0.653940349817276, 1.0452192510877336, 1.729477739759854, 3.173763628516878, 4.7493564656802585, 7.635206069265093, 2.284166221107755, 2.3510213536875586, 0.9216990619897842, 1.3841030895709991, 0.25047086126038004, 0.45226758292743136, 29.999420642852783, 53.06884697505406, 22.94027669089181, 58.05971370424543, 55.10136876787458, 29.635154383523123, 20.890994106020244, 40.00599043709891, 16.549676248005458, 0.6682152609739984, 0.5647273255246026, 0.19099419989756175, 0.38120303622313906, 0.3337464870086738, 0.6157959880573409, 0.2796510968889509, 0.22367620547967298, 0.1455733235925436, 0.3182615850652967, 0.1680749018809625, 0.2342206532401698, 0.08225006077970777, 0.1176712443786008, 0.02989310791183795, 0.1514520017164094, 0.09858985577843019, 0.1367881814283984, 0.07166193572006055, 0.11312714964151382, 0.05185790393235428, 0.09682244168860571, 0.2128656498555626, 0.11262329667806625, 0.08240212047738688, 0.16188800601022585, 0.20980019148971352, 0.27667838068945066, 0.2557518450277192, 0.14384007374090807, 0.1746639654572521, 0.15399668445544584, 0.29571896897894995, 0.22570832286562237, 0.13127915561199188, 0.2403888622564929, 0.19272244216075965, 0.1532242809023176, 0.15685098272349152, 0.22706776777548449, 0.29607340853129116, 0.08537776794816766, 0.1381774004548788, 0.14544616613004888, 0.18314323760569096, 0.09931763886873211, 0.17449971927063807, 0.1511635293385812, 0.24053672860775674, 0.15573389695159026, 0.19120997403349194, 0.19929524803800241, 0.2224786997373615, 0.14550492726266384, 0.41668013110756874, 0.15374968413795742, 0.3678381490920271, 0.19654847042901175, 0.5590261657323156, 0.1643878782966307, 0.18427246915442602, 15.876651150839669, 74.71618202754429, 78.22551563807896, 78.43503856658936, 71.39430386679513, 94.3255478995187, 55.840309688023154, 66.68926865713937, 18.852222408567155, 1.6233137164797102, 1.821864353758948, 2.884176390511649, 1.2174307874270847, 1.4782817959785461, 3.7326682550566535, 3.635399554456983, 2.2751672182764326, 1.8954981054578508, 5.406355977058411, 9.7172554901668, 14.167879802840096, 17.38541947092329, 15.878311770302908, 17.09970259666443, 19.82661693436759, 13.29259785584041, 19.611695255552018, 9.128132496561323, 3.700002602168492, 0.6027090017284665, 0.28140654840639656, 0.31801573825734003, 1.5643255731889179, 1.3200947642326355, 0.8164190341319356, 2.380091096673693, 2.6659495404788425, 2.6494575568607877, 1.2061354049614497, 1.659747681447438, 2.309299809592111, 4.608003616333008, 10.692627106394086, 15.859944207327706, 25.64661567551749, 33.26452507291521, 43.38662951333182, 60.862078530447825, 72.04538481576103, 74.73329544067383, 73.41040706634521, 71.2432222366333, 70.2628870010376, 63.18033109392439, 61.34293556213379, 48.99655294418335, 44.67536401748657, 2.4354686737060547, 32.949424266815186, 74.29016017913818, 58.671693665640696, 71.57829911368233, 64.63114275251115, 72.74839660099575, 70.92369542803083, 63.42191995893206, 63.623924936567036, 56.27901199885777, 43.03781604766846, 18.881736619131907, 5.2152370895658215, 1.8428153438227517, 3.1098712512425015, 10.03842728478568, 16.898534876959665, 20.713349512645177, 20.737055029187882, 10.201982668467931, 6.794632111276899, 0.5480771075401987, 0.1980819460004568, 0.9111490909542356, 1.8911376765796115, 1.6537185992513384, 0.40327860308544977, 0.850015745631286, 1.2432963252067566, 0.21870751066931657, 0.9684372054679053, 2.8437330978257314, 2.4922434900488173, 0.7077525737030166, 0.9238607117107936, 0.465930455497333, 1.8281924256256648, 1.767812362739018, 1.7082973505769457, 2.6554290992873053, 5.637260683945247, 11.307866641453334, 11.99874860899789, 6.0069895301546365, 3.60655215382576, 10.601901003292628, 0.6552411285894257, 0.4557955307619912, 40.82498155321394, 56.21795122964041, 38.23145873206002, 83.73702825818742, 74.3311962400164, 38.235690185001914, 40.22524779183524, 63.44215311322893, 25.825330291475566, 0.5665769577026367, 0.838887879891055, 0.2869177726762635, 0.3139630928635597, 0.31988678500056267, 0.5231190153530666, 0.831065836761679, 0.44756015124065535, 0.23214067199400493, 0.352725980005094, 0.13954622271869863, 0.27007634352360455, 0.16609395960611956, 0.1896808139447655, 0.12003027993653502, 0.32278062828949516, 0.1269259870584522, 0.18495161485459122, 0.1114311038649508, 0.2821633049419948, 0.152424138837627, 0.1460963383849178, 0.3095516652933189, 0.13577559004936898, 0.20954348812145845, 0.28180121151464327, 0.22379123073603424, 0.40015747770667076], [0.07801763074738638, 0.05004619507651244, 0.06566372008195945, 0.08351949801934616, 0.19885801364268574, 0.08151727688631841, 0.029827615711838007, 0.13794317016644136, 0.23425466141530446, 0.08849045235131468, 0.05313518503680825, 0.0379011273118002, 0.02057850656897894, 0.12747408050511563, 0.11808000744453498, 0.06488150491246156, 0.0560575335818742, 0.0412687542848289, 0.08945783294205155, 0.07534553948789835, 0.06919767295143434, 0.11953319875257355, 0.10265547476176705, 0.08306882184531007, 0.24476397463253566, 0.09044086733566863, 0.08728979820651667, 0.1867704415427787, 0.1516631075314113, 0.17486707812973432, 0.2013326987091984, 0.1988141667097807, 0.12755915522575378, 0.731155409344605, 9.01987087726593, 5.556549974850245, 25.566478627068655, 24.54036865915571, 33.65627840587071, 59.326200076511924, 26.771694047110422, 39.05612652642386, 18.831315279006958, 0.3580059323992048, 0.6369785485523087, 0.670783380312579, 0.14604969588773592, 0.22741363064518996, 0.4239075875708035, 0.709332094660827, 1.572280609181949, 0.2722149230539799, 0.8754838790212358, 1.3926084446055549, 4.360653826168605, 6.793858255658831, 6.511806990419116, 6.783392097268786, 5.540242552757263, 7.208052098751068, 5.283474913665226, 0.51603521832398, 1.5263867803982325, 1.491921978337424, 1.8918939445699965, 0.03458555415272713, 0.7056380414537021, 0.21852908310081276, 0.37904046369450434, 0.07809514658791677, 0.10852286884827272, 0.40943932107516695, 1.0283993993486678, 0.7802742336477552, 0.23910260413374218, 0.4711085462144443, 2.7418792375496457, 7.294067757470267, 8.4403190272195, 10.285350629261561, 12.845206822667803, 28.18939232826233, 54.98848485946655, 74.43666989462716, 65.06791346413749, 62.029883112226216, 41.458761487688335, 33.96901682444981, 18.340089797973633, 19.75517381940569, 1.7986102529934473, 8.306786809648786, 59.06140422821045, 55.02585227148873, 62.119903973170686, 71.54433631896973, 69.86087117876325, 65.2741915839059, 51.45227909088135, 39.6166342326573, 26.014397723334177, 10.218091198376246, 2.9144794387476782, 1.0382673612662723, 0.14380557702056, 0.4172921154115881, 0.22721377494079725, 1.7599845656326838, 0.6165827629821641, 2.504048045192446, 0.8020517879298755, 0.27821254836661474, 0.3195142149925232, 0.17972084267863206, 0.20176029790725025, 0.5719855331948825, 0.11029587406665087, 0.5260653772524425, 0.25091611593961716, 0.11393597695444312, 0.448070409574679, 0.5188233458570072, 1.1629062103373664, 0.511877318578107, 0.43591915017792154, 0.37074491168771473, 0.1760063927088465, 0.5545584197555269, 1.5735036006995609, 4.865713604858943, 4.204944261482783, 2.6523790572370802, 4.798142373561859, 5.482858683381762, 2.541541610445295, 0.41391797789505547, 0.6130113346236092, 0.13597824131803854, 27.96752766200474, 30.47771031515939, 15.573992831366402, 50.4034172466823, 43.72377347946167, 11.82359755039215, 11.02346384525299, 30.272391046796525, 23.267646278653825, 1.1209476675306047, 0.19573732252631867, 0.13864994581256593, 0.13300996273756027, 0.21582092770508357, 0.1440177820622921, 0.1822038194430726, 0.18395965094012873, 0.3583919645420143, 0.04392870994550841, 0.3267593676490443, 0.22167593852749892, 0.13361275967742714, 0.14785237344247953, 0.11103597935289145, 0.11595094097512108, 0.06555049294339758, 0.10140105350209133, 0.02723218533875687, 0.1314471201705081, 0.033421846239694526, 0.09152552591902868, 0.010351197594510657, 0.07439618078725678, 0.11910937220922538, 0.08543732975210462, 0.18337406164833478, 0.24814373041902268, 0.14768938933100018, 0.24929767421313695, 0.12636006171149866, 0.1923469951642411, 0.04861232505312987, 0.17748420126736164, 0.03019260648371918, 0.11640087754598685, 0.10645639044897896, 0.14930374627666815, 0.09396150734807764, 0.11741076835564204, 0.08695198276213237, 0.04222960736868637, 0.17242631981415407, 0.03982295900849359, 0.08574411579008613, 0.04309310085539307, 0.09545619107250657, 0.06523506915462868, 0.10699149673538548, 0.0532700065523386, 0.247966252799545, 0.2712963766285351, 0.27919371000358034, 0.1593679676630667, 0.22032760802124227, 0.15917934849858284, 0.236415225480284, 0.3330901807972363, 0.35033281413572176, 0.236812738435609, 0.3637402318418026, 0.5479801041739327, 1.3137372710875102, 17.08330658503941, 44.11390788214547, 47.56427213123867, 48.500955309186665, 63.6590758732387, 64.20298085893903, 34.85387338910784, 71.73088155473981, 17.88542573792594, 0.4478648134640285, 0.42145300071154324, 0.5694064487304006, 0.18480389778103146, 0.1618938006992851, 0.33690352046063965, 1.8949014289038522, 0.5178592290197099, 0.7611660904117993, 1.2103468818323952, 1.6682539050068175, 1.6112501238073622, 2.7355466059276035, 2.1370743768555776, 2.2242010959557126, 3.3938426077365875, 5.204588106700352, 2.008790437664304, 1.446179272873061, 1.546016309942518, 1.2110273710318973, 2.548543006181717, 0.140878933348826, 1.214696888412748, 1.4252740974937166, 1.6255487565483366, 0.12984550611249038, 0.12818724795111588, 0.93224165056433, 1.6587081657988685, 1.5839595539229256, 0.77496537566185, 1.4430357558386666, 3.9914856127330234, 9.718955193247114, 11.068021774291992, 14.227435418537684, 17.296888998576573, 34.06320660454886, 60.9671630859375, 80.16111006055559, 71.10971260070801, 71.83075496128627, 54.44476400102888, 49.79672139031546, 31.128815582820348, 31.383369786398752, 1.6679193058184214, 10.222731726510183, 71.62446294512067, 60.9649327141898, 70.560791015625, 71.55595370701381, 72.72226442609514, 64.37533787318638, 52.86774526323591, 42.95192241668701, 30.31090838568551, 14.667405775615148, 4.539635513510023, 1.4006938678877694, 0.2989070793347699, 0.13721097659851822, 0.15477668760078295, 2.2116945556231906, 2.697214262826102, 1.8678119225161416, 1.0422969907522202, 0.5183136303509984, 0.1803248609815325, 0.14346706947045668, 0.0763932993369443, 0.5283634939364025, 0.8588704104934419, 0.5250604397484234, 1.0079421656472343, 0.3161276195730482, 0.27128090603010996, 1.348747506737709, 1.7528685246195113, 0.7796320138233048, 0.63887100986072, 0.7031663826533726, 0.4807199133293969, 1.2213724787746156, 2.734285507883344, 1.8223435623305184, 6.423702095236097, 4.721081205776759, 2.8220152003424506, 1.811919744525637, 1.1849693464381355, 0.5120661141616958, 0.21031188831797668, 0.24271238329155104, 33.05160447529384, 57.52558830806187, 23.369732686451503, 50.38761009488787, 60.83402170453753, 31.37333311353411, 25.79835912159511, 36.25976841790335, 33.3364701952253, 2.230276427098683, 0.36011845618486404, 0.23403090770755494, 0.33765696574534687, 0.41735893754022463, 0.40763802773186136, 0.33741478302649086, 0.35260460366095814, 0.35909337976149147, 0.1514704307275159, 0.2770880529923098, 0.17077164431767805, 0.216118723154068, 0.2157700104372842, 0.21702014335564204, 0.09582097149853196, 0.10896416088300091, 0.04506660299375653, 0.017406491063801304, 0.09955122454890183, 0.05476929074419396, 0.020830519563917602, 0.11243750700461012, 0.11923342198133469, 0.17654292391879217, 0.1383487984005894, 0.26865549119455473, 0.20647025374429567, 0.14816971070000104, 0.18431813456118107, 0.17478432399885996, 0.4051420773778643, 0.16284581247184957, 0.3008296675980091, 0.1813468568559204, 0.15416178559618338, 0.21187141963413783, 0.3403743899294308, 0.22329291461833886, 0.17706283102078096, 0.21744326422257082, 0.19960870407521725, 0.19547352168176854, 0.15995293270264352, 0.22428386073027337, 0.23372686973639897, 0.19594432998980793, 0.1548490465751716, 0.2077403763043029, 0.12089687772095203, 0.2796715072223118, 0.2641149248395647, 0.24961129309875624, 0.28140261290328844, 0.3722976712243897, 0.2147121743432113, 0.33256396331957405, 0.30204546664442333, 0.5159579738974571, 0.3400653036577361, 0.4015319453818457, 0.4101364208119256, 1.3510570228099823, 34.940058844430105, 72.68116583142961, 74.62859303610665, 74.20793519701276, 76.29737663269043, 93.52788775307792, 47.32707452774048, 70.96589878627232, 29.010870899472916, 0.2818861912403788, 2.0667436250618527, 0.9973083819661821, 0.536191996719156, 0.27635645653520313, 2.6332719453743527, 5.9096908654485425, 2.6277346653597693, 0.8875277127538408, 2.8188908994197845, 4.647217512130737, 6.423257844788687, 11.346037438937596, 10.576544421059744, 10.15039142540523, 7.532300642558506, 11.192851373127528, 8.675325342587062, 1.2384423570973533, 2.5484780839511325, 2.204005071095058, 2.157385481255395, 0.12301181709127766, 0.9281212602342878, 1.3122655557734626, 1.8771118691989352, 0.17585711500474385, 0.19414664645280155, 1.021356857248715, 2.115988765444074, 2.1650699717657904, 1.6043012738227844, 2.4545410445758273, 4.881572868142809, 9.250642265592303, 9.962189044271197, 14.014263817242213, 16.027072702135357, 31.873398440224783, 59.91738060542515, 83.09793989998954, 75.51114627293178, 79.78596987043107, 63.59069865090506, 66.48044749668666, 44.93698106493269, 42.889155864715576, 3.103559681347438, 11.159638115337916, 78.18518829345703, 66.37838540758405, 80.18803433009556, 78.49540451594761, 78.36760629926408, 70.65612030029297, 57.82595893314907, 45.088698455265586, 31.204825401306152, 13.46631932258606, 4.456836002213614, 1.4634877783911568, 0.6245342705930982, 0.5764530620404652, 0.3320127214704241, 2.647584365946906, 8.611690265791756, 6.575825086661747, 1.0742769432919366, 0.497575863131455, 0.31762487494519775, 0.4388737359217235, 0.4472044089010784, 0.9685075559786388, 1.2552520036697388, 0.6146352589130402, 1.1454990186861582, 0.2647599130868912, 0.32510330794113024, 3.8094454152243475, 3.488953241280147, 1.0338133488382613, 0.6807322236044067, 1.1344149048839296, 0.680412660752024, 1.0768354002918517, 6.8206609317234586, 10.79165370123727, 13.322585412434169, 8.265427657536097, 10.280439121382576, 9.935079778943743, 9.567648615155901, 0.821269365293639, 1.4145543298551013, 0.17427188078207628, 49.20667341777256, 52.20133311407906, 29.042714493615286, 79.95055879865373, 79.24715096609933, 39.88439001355852, 36.84215252740042, 61.526645932878765, 43.95327247892107, 2.336906739643642, 0.5713257257427488, 0.32649264910391396, 0.5108798721006939, 0.43759621733001297, 0.5349828473159245, 0.48571501672267914, 0.4206370216395174, 0.6822728237935475, 0.23333122953772545, 0.3539342066007001, 0.24760171664612635, 0.27160410583019257, 0.2394619019968169, 0.29070095824343817, 0.19423657948417322, 0.1958355065435171, 0.22419999380196842, 0.0875402454818998, 0.1625414759452854, 0.12452448877905097, 0.2283864463014262, 0.19374096393585205, 0.1381238369005067, 0.29391241020389963, 0.15741650094943388, 0.38938093025769505, 0.2900310270488262, 0.16405257343181542], [0.16605165973305702, 0.08626354791756187, 0.10505576524883509, 0.1462876716894763, 0.15436111204326153, 0.02141163730993867, 0.1667844368410962, 0.010667967427122806, 0.10592811022486005, 0.08683617719049964, 0.045682326025728665, 0.04013987557430353, 0.03675118348162089, 0.08403538819402456, 0.06058424085910831, 0.09002422647816793, 0.032527699933520386, 0.07700329553335905, 0.17319811268576554, 0.06319765241018363, 0.1160033510199615, 0.14151803191219056, 0.09242323453405074, 0.057681094855070114, 0.09687103836664132, 0.1290630330996854, 0.22230849601328373, 0.16734910011291504, 0.2666210260774408, 0.2623569763132504, 0.04769052844494581, 0.09106980822980404, 0.03699379367753863, 0.10501090729875223, 3.546087844031198, 12.819422057696752, 16.365748746054514, 24.054302215576172, 25.91164255142212, 48.60569245474679, 59.53491701398577, 29.228215762547084, 39.84998948233468, 30.056388923100062, 0.8591052921754974, 0.4990370475820133, 0.01892306941694447, 0.5017314829996654, 0.1376138228390898, 0.3334712189223085, 0.28912634987916264, 2.211158675806863, 0.43197458184191156, 0.38233770962272373, 0.842481401349817, 1.1227260806730814, 2.1447569131851196, 4.210978771959033, 4.640883794852665, 4.909497244017465, 1.1044841281005313, 1.1133525265114648, 1.9487640815121787, 2.6725965780871253, 1.256011528628213, 0.551138060433524, 0.8212285446269172, 0.43510998359748293, 0.4244275082434927, 0.322160610130855, 0.08895194437354803, 0.15900678347264016, 0.2898891589471272, 0.4329764795090471, 0.642748050391674, 0.6145136111548969, 1.0587489136627741, 1.9882044451577323, 2.261122737612043, 1.62977434694767, 2.064454410757337, 4.440991069589343, 9.933772649083819, 22.75385478564671, 39.01277324131557, 60.3765801021031, 50.67186089924404, 37.02099568503243, 27.16279772349766, 15.929539101464407, 0.4526482682142939, 3.930242019040244, 34.375142506190706, 62.79013415745327, 74.21532113211495, 70.97217995779855, 57.183330467769075, 42.11342075892857, 28.300563505717687, 13.247212222644261, 3.726279386452266, 0.3993191884032318, 0.3456343933939934, 0.6902639578495706, 0.7982886869992528, 0.6134428828954697, 0.32291467966777937, 0.42133680837494986, 0.4311820257987295, 1.2838948667049408, 0.20176736824214458, 0.32041807792016436, 0.16035861521959305, 0.0747716413544757, 0.056995123092617304, 0.22452415712177753, 0.18063719065061637, 0.4418383368424007, 0.10875853084559951, 0.26673952543309754, 0.2567564568349293, 0.08144440901066576, 0.12989191790776594, 0.738199417080198, 0.34530568388955935, 0.13888926511364325, 0.4832182249852589, 0.6048486669148717, 0.8893518862979752, 1.5599011991705214, 3.80519528899874, 4.485329696110316, 5.068942333970751, 0.11440571317715303, 0.9418850988149643, 1.1911347870315825, 0.6290260638509477, 35.89897278376988, 28.491036210741314, 12.748053635869708, 43.75844151633126, 47.6928277015686, 22.514491081237793, 13.037073510033743, 24.570570741380962, 32.03549643925258, 8.940593668392726, 0.37488096260598724, 0.08022892887571029, 0.2805522456765175, 0.17068871376769884, 0.06891796724604708, 0.08653175245438303, 0.16517416467624052, 0.10173931677958795, 0.13468546925910882, 0.0799787123022335, 0.10778492808874164, 0.0451673756220511, 0.08087412068354231, 0.19738112789179596, 0.07832362289939608, 0.11429893890661852, 0.047177145457161326, 0.0468902472805764, 0.054666686071349044, 0.08853295578488282, 0.11394539502050195, 0.027636371685990264, 0.08459513887230839, 0.034274140505918434, 0.17178422212600708, 0.05540182448125311, 0.09822325009320464, 0.18589908044253076, 0.1032351947256497, 0.25813152162092073, 0.20466756261885166, 0.12182481507105486, 0.17456762705530438, 0.22252370017979825, 0.1003176909206169, 0.16597472743264266, 0.10891777622912611, 0.10870954740260329, 0.2103988222245659, 0.09764043600963694, 0.14699591297124112, 0.08839958972696747, 0.11042119948459522, 0.1203523397977863, 0.08710753012980733, 0.04252566237534795, 0.08340317676109926, 0.18290311763329165, 0.1760827007570437, 0.19863546772726945, 0.19805867224931717, 0.20682484257434094, 0.1505550734166588, 0.10747527184763125, 0.2261897706027542, 0.3096378392406872, 0.2517156201813902, 0.26515577041677063, 0.3815065042248794, 0.1901018720652376, 0.22520185075700283, 0.1847150232642889, 0.25748512202075546, 9.18684651170458, 31.657733304159983, 41.38405098233904, 47.73358236040388, 48.703429290226524, 73.62576648167202, 58.940429142543245, 36.267609460013254, 67.8642576762608, 33.46041216169085, 1.161852581160409, 0.667169774217265, 0.643412634730339, 0.2218476485993181, 0.09482337574341468, 0.23473870115620749, 0.5504990975771631, 2.1322132434163774, 0.552457295358181, 0.6488211559397834, 1.157117275255067, 1.2792025527783801, 1.5792528007711684, 1.0857086841549193, 2.192374438047409, 0.3173911603433745, 1.6693506347281593, 0.24507981911301613, 0.894069496010031, 0.6753308677247593, 0.7524921872786113, 0.7672617233225277, 0.5826823934912682, 0.20135314975466045, 0.9209202123539788, 0.8086042648979596, 0.06115511951169797, 0.06270254576312644, 0.5208270326256752, 0.5490716770291328, 0.9315813545669828, 1.0333366372755595, 1.2364889362028666, 2.05848981652941, 2.3109167856829504, 2.1348036187035695, 2.2710786376680647, 5.934589735099247, 13.244033421788897, 27.08212913785662, 42.2303763117109, 63.5809850692749, 60.09771415165493, 46.20885576520647, 39.763609477451865, 20.209815297807964, 0.33337345559682163, 4.947510404246194, 39.924453326633994, 65.08638872419084, 75.03248487200055, 69.80812045506069, 60.34752968379429, 44.67567321232387, 32.58243778773716, 17.02083706855774, 7.030679353645869, 2.727040490933827, 0.9753534857715879, 1.3666891668524062, 1.498669873390879, 1.1025460149560655, 0.047455100542200465, 0.8957042768597603, 0.9445916392973491, 0.12679969812078135, 0.23677913738148554, 0.047550875760082684, 0.19384110213390418, 0.11735944396683148, 0.20064631982573441, 0.43865106787000385, 0.6538637025015694, 0.7414205585207257, 0.22026677057147026, 0.5819637434823173, 0.23589679758463586, 0.22291921824216843, 0.37507863342761993, 1.135754930121558, 0.40453801836286274, 0.2309020741709641, 0.8763399730835641, 3.5988064323152815, 3.1242175442831854, 1.9574132859706879, 1.7443238688366753, 2.5280464717320035, 1.8774173728057315, 0.7666039786168507, 0.1893606675522668, 0.6496154761740139, 0.5629654143537793, 41.36651720319475, 55.56945153645107, 17.507973534720286, 37.08384908948626, 63.27510452270508, 41.57073518208095, 26.523956026349747, 29.352456501552037, 47.60189315250942, 13.609245504651751, 0.7931433288114411, 0.2563231172306197, 0.6324434919016702, 0.21477967500686646, 0.0597915898210236, 0.07402454715754304, 0.377564975725753, 0.11752564433429923, 0.1994111282484872, 0.16077746131590434, 0.13026587212724344, 0.07111397119505064, 0.13654234819114208, 0.1673017790807145, 0.09376026743224689, 0.11103000824472734, 0.10143734155488865, 0.07033413089811802, 0.04264660106439676, 0.10005077560033117, 0.03730382989825947, 0.0784810498090727, 0.09219958939190422, 0.17899067114506448, 0.07692376444382326, 0.1530157806617873, 0.1399216561445168, 0.17480856126972608, 0.17024012069616998, 0.2952771069748061, 0.24563296086021832, 0.21347481145390443, 0.26177992299199104, 0.42772917822003365, 0.23637763464025088, 0.30158767263804165, 0.19274391100874969, 0.19416352840406553, 0.2685575378792626, 0.1814324879752738, 0.18955377861857414, 0.19677387976220675, 0.20458403495805605, 0.20320575391607626, 0.19394901634327003, 0.1746133603155613, 0.10610006456928593, 0.4482191987335682, 0.2420576512813568, 0.2601510046848229, 0.22990500767316135, 0.33958959632686203, 0.26674595794507433, 0.30486803661499706, 0.38172781520656174, 0.45124611631035805, 0.29123662092855995, 0.38164413826806204, 0.4607486735497202, 0.3771712897079331, 0.3931436240673065, 0.1850066033325025, 0.2799479423889092, 9.710359403065272, 62.85680907113211, 69.62104020799909, 71.34282466343471, 67.72620391845703, 91.52071993691581, 90.16813496180943, 46.749470778873985, 69.60248156956264, 52.0001653943743, 1.112148533974375, 1.1899008303880692, 0.8890645674296788, 0.8142933196255139, 0.24422027809279306, 0.7756687179207802, 1.8197727288518633, 6.238347172737122, 1.9083481473582131, 2.2364516385963986, 2.783476799726486, 3.2828375356537953, 3.7895887664386203, 7.23039186000824, 7.868653382573809, 8.056006346430097, 4.639868923595973, 1.3298003120081765, 2.9880769295351843, 4.592162157808032, 2.0311651570456366, 1.077654636331967, 0.7579680191619056, 0.35942420629518373, 1.32465332533632, 1.3780593510184969, 0.14864849857985973, 0.2864451866064753, 0.787179385977132, 0.9163687080144882, 1.3818606670413698, 1.7240710641656602, 2.5061335904257636, 3.234413802623749, 3.9943530474390303, 2.582108233656202, 2.4704839033739905, 7.203239602702005, 13.507074849946157, 27.861446040017263, 47.042604855128694, 70.02538367680141, 68.97430883135114, 60.13272612435477, 52.059106963021414, 27.697465079171316, 0.9746887385845184, 6.387640510286603, 46.15484046936035, 76.20158181871686, 82.28953783852714, 76.91284806387765, 65.6485674721854, 45.72560507910592, 31.73448657989502, 16.60565267290388, 6.659711556775229, 2.953992758478437, 1.7210618427821567, 1.8639139831066132, 2.871212137596948, 1.4241253648485457, 0.5032150319644383, 1.60868558713368, 2.606845340558461, 1.887955401624952, 0.5836161662425313, 0.8537159327949796, 0.5056197600705283, 0.12665987919483865, 0.24641555600932666, 0.2699542615030493, 0.391673917216914, 0.8117719377790178, 0.5856949261256627, 0.7750933745077678, 0.37129170234714237, 0.393992118537426, 1.1048219842570168, 1.862572763647352, 0.3651857285627297, 0.34323655920369284, 1.4321609565189906, 7.213433044297354, 8.225658774375916, 7.083787041051047, 9.017961859703064, 8.4670843567167, 10.315267835344587, 1.8527523534638541, 1.8767514313970293, 2.3031612932682037, 0.7326386868953705, 61.94674791608538, 44.06474242891584, 24.22123268672398, 66.05341121128627, 82.06786251068115, 48.119572162628174, 42.571494647434776, 54.7611015864781, 62.71992261069161, 12.835657392229352, 1.0432976399149214, 0.2664421099637236, 0.8502481845872742, 0.2517702558210918, 0.25155358601893696, 0.18955033166067942, 0.4711846507021359, 0.3213660999068192, 0.24394324581537927, 0.26234956671084675, 0.26206352348838535, 0.201043927775962, 0.21005264722875186, 0.2837705101285662, 0.24227771375860485, 0.2557717668158667, 0.18366727020059312, 0.09800164734146424, 0.16782528241830214, 0.25137000158429146, 0.26456229654806, 0.1818248304937567, 0.22192449947553022, 0.22680053354374, 0.2023790811321565, 0.19020168456648076, 0.27096747713429586, 0.27710010377424105, 0.2125454627509628], [0.10505280005080359, 0.12404580946479525, 0.13085741895650113, 0.09258860708879572, 0.06566901265510491, 0.12728281505405903, 0.04600970220885106, 0.033027671676661284, 0.04329219999323998, 0.10604287763791424, 0.041026608885398934, 0.03580839978531003, 0.029942355983491455, 0.16608819205846104, 0.033225546058799536, 0.050555191335401366, 0.0334114680465843, 0.029943862331232855, 0.08726579842290708, 0.0871750715055636, 0.04138044114889843, 0.08882574364542961, 0.12693126606089727, 0.09989591355302505, 0.08431869013501064, 0.07820563244500331, 0.21059563809207507, 0.06369422469288111, 0.18185076410216944, 0.2163318238620247, 0.30659452825784683, 0.09740808526320116, 0.16549435178084032, 0.06756947389138596, 0.19449264502951077, 5.235070722443717, 20.594556161335536, 20.351859058652604, 23.49930443082537, 23.184377329690115, 58.01173986707415, 61.57647146497454, 31.09008632387434, 43.22269024167742, 37.74359444209507, 3.686956925051553, 0.2245675969336714, 0.28845804716859547, 0.0777182068143572, 0.12153419852256775, 0.3848316515130656, 1.1781284106629235, 0.9596783497503826, 0.7761689882193292, 1.387851317014013, 0.5877844882862908, 0.7268423693520683, 0.5058173494679588, 1.3903042482478278, 0.3051891193858215, 0.3225077215049948, 0.3172620487000261, 0.5029137624161584, 0.41060108159269604, 0.5011716644678796, 0.43713633343577385, 0.18950111073042664, 0.125444392274533, 0.19887911608176573, 0.06339638853179556, 0.19750445841678552, 0.014963211990626795, 0.05568605940788984, 0.12465746807200567, 0.1314473237310137, 0.16458565768386635, 0.6055509235177721, 0.30666973707931383, 2.1469010838440488, 3.335584568125861, 2.880189427307674, 2.906586068017142, 2.9557866965021407, 5.369524879114969, 8.678084645952497, 28.59015052659171, 37.34479910986764, 24.28683931486947, 17.64074318749564, 1.6134672505514962, 0.7101998052426747, 0.6937197095581463, 8.21835013798305, 31.760997431618826, 47.89927952630179, 42.99187455858503, 36.225847312382285, 24.717353173664637, 11.52043982914516, 4.789071934563773, 2.1681432468550543, 0.6087297243731362, 0.3625811854643481, 0.1083055544378502, 0.1108495993539691, 0.0949918424178447, 0.18475436472467013, 0.1134492162881153, 0.18551467678376607, 0.25608009312834057, 0.29476722862039295, 0.26650065396513256, 0.15053163681711468, 0.23250835654991014, 0.17257859664303915, 0.1669671256095171, 0.3659895211458206, 0.05287785063098584, 0.2999293330524649, 0.09101320483854838, 0.12928967736661434, 0.2919948973826, 0.4396094578717436, 0.16135661809572152, 0.3436174616217613, 0.15719863692564623, 0.5839323635612215, 1.5373265019484927, 0.8271099776029587, 0.635506941803864, 1.6320106898035323, 1.7492186576128006, 0.3166249586003167, 0.486059766794954, 1.1375359488385064, 3.282318592071533, 40.20788771765572, 19.716409819466726, 15.114836760929652, 53.28411953789847, 55.66560765675136, 19.973543541772024, 8.38715488570077, 23.76885805811201, 31.80700840268816, 11.169597489493233, 0.180777552404574, 0.062167548042322905, 0.07896614127925464, 0.1380184061293091, 0.07713809330016375, 0.05862018732087953, 0.07197164624397244, 0.04158119930486594, 0.04363594583368727, 0.06390353239008359, 0.05573459162509867, 0.12040599834706102, 0.046249187751007934, 0.05410559867907848, 0.12715253633047852, 0.07560094006891761, 0.03844159063217895, 0.07034000701137952, 0.047149135531591516, 0.017832985946110318, 0.03158481106428163, 0.07634052966854402, 0.08040351593600852, 0.09284717642835208, 0.04566949832120112, 0.04218256453584347, 0.09637103948209967, 0.0699591181640114, 0.02666784097839679, 0.03917312941380909, 0.21173803322017193, 0.1239694742751973, 0.1378792385969843, 0.20000382858727658, 0.10690748052937643, 0.17111110181680747, 0.09896233079156705, 0.17389874080462114, 0.11862416538809027, 0.11104456960622754, 0.11565797669546944, 0.09047116392425128, 0.07916495882506881, 0.21387813266898903, 0.13792027639491217, 0.036375247939888916, 0.02849765993388636, 0.0663488640316895, 0.026252738699050884, 0.1493603360972234, 0.10031863408429281, 0.13608349567013128, 0.22844119050673076, 0.25843748663152966, 0.12007841521075793, 0.16848859111113207, 0.24021312168666295, 0.14055918050663813, 0.16923094913363457, 0.19674942536013468, 0.264437093266419, 0.055288787332496474, 0.490962806556906, 0.1729184476924794, 0.47100215192352024, 17.977013417652675, 43.29696648461478, 40.7578306879316, 46.16846588679722, 51.138390745435444, 74.47649696895054, 56.21790606634957, 41.2445068359375, 67.76847675868443, 41.35313149860927, 3.6090396089213233, 0.22718972765973636, 0.16547329005386147, 0.3108764642051288, 0.0967536653791155, 0.827795243688992, 0.8630132739033017, 1.3202341624668665, 1.102335614817483, 1.9703799273286546, 1.2080996824162347, 2.3498749009200504, 2.9736767879554202, 3.7958803602627347, 2.1742472393172125, 1.1495133404220854, 1.7299074424164635, 0.6565232883606638, 0.8606827503868512, 0.16711287493152277, 0.8851378581353596, 0.44361479580402374, 0.23258182832172938, 1.1357459191765105, 0.8267058964286531, 0.34013671268309864, 0.3533944184226649, 0.05603906385866659, 0.15882906158055576, 0.28648410737514496, 0.47872968869549887, 1.3075317697865623, 1.1920205737863268, 3.142229446343013, 4.749526262283325, 3.8604152287755693, 4.019156813621521, 4.908283046313694, 6.312284256730761, 9.450532385281154, 31.192923137119838, 37.34492070334298, 25.49766366822379, 18.111686876841954, 1.6456407755613327, 0.9498306896005357, 1.3646827659436633, 10.67583417892456, 37.819176946367534, 53.742436613355366, 49.688847133091514, 42.65758630207607, 29.30024078914097, 14.866925035204206, 7.010982947690146, 3.5133535776819502, 0.8513029537030629, 0.4278581812977791, 0.4155448063143662, 0.23848120176366397, 0.27293528297117775, 0.2211590984037944, 0.07635671272873878, 0.24586067721247673, 0.14895740843244962, 0.35125410184264183, 0.4024326599070004, 0.15869704580732755, 0.1032590859436563, 0.295306175415005, 0.20251018766845974, 0.49998900507177624, 0.5330085275428635, 0.37716732706342426, 0.019556347846186588, 0.544725090265274, 0.24647610847439083, 0.38700345211795395, 0.3455241450241634, 0.7704701625875064, 0.18064890216503823, 1.192532243473189, 4.969946571758815, 2.7445037024361745, 1.8967277194772447, 4.694679353918348, 1.0164095227207457, 0.8824124815208572, 0.4646330422588757, 1.3664875605276652, 2.712794078247888, 51.84401157924107, 48.76229442868914, 16.295723063605173, 36.92244243621826, 65.49319880349296, 38.238889830453054, 23.2072160584586, 35.18283237729754, 42.19884191240583, 21.6422107560294, 0.7889869489840099, 0.3041982411273888, 0.11671084591320582, 0.3418792448937893, 0.2158202627407653, 0.19310848787426949, 0.20854183472692966, 0.0922114501840302, 0.058482675414000235, 0.10474532190710306, 0.28437177357929094, 0.17869469416993006, 0.0776813623628446, 0.11835569622261183, 0.10688718554696866, 0.03914185234212449, 0.03998831120718803, 0.10820380132645369, 0.07154841681144067, 0.10921653519783701, 0.043537334339427095, 0.07888029302869524, 0.11342848704329558, 0.23258009127208165, 0.09546865576079913, 0.02491336824771549, 0.13600485346146993, 0.1464313989771264, 0.10734476242214441, 0.07695213399295296, 0.3767894373408386, 0.18070124435637677, 0.35518499091267586, 0.31114752537437845, 0.27178915590047836, 0.2827567516693047, 0.19518730204020227, 0.2290701653276171, 0.2857603547828538, 0.21621884778141975, 0.2713038133723395, 0.20932911176766666, 0.1504545688096966, 0.31305524015000885, 0.26881763392261093, 0.17900949370648178, 0.2080215069332293, 0.29294796766979353, 0.17197527044585773, 0.26337171186293873, 0.14481687918305397, 0.3148753967668329, 0.3602727550481047, 0.4341436411653246, 0.2753258432660784, 0.23634286650589534, 0.3272206357547215, 0.17619341053068638, 0.20130873285233974, 0.3816145269998482, 0.41304546328527586, 0.2749132125505379, 0.6782539965850967, 0.38545867215309826, 0.31923118446554455, 20.687370198113577, 70.73357186998639, 70.43697411673409, 64.49349893842424, 64.68489401681083, 92.26690087999616, 94.23020471845354, 50.11704724175589, 68.61789403642926, 66.03362274169922, 6.3593074934823175, 0.7968417246426854, 0.21217077571366513, 1.317779928445816, 0.2047475211854492, 0.9867738272462572, 3.050863240446363, 4.239203657422747, 3.0173905108656203, 3.5116495319775174, 1.8053187387330192, 2.3182994638170515, 2.6113032613481795, 2.413690413747515, 3.1853801480361392, 2.8385421420846666, 1.3861240382705415, 1.2188415974378586, 0.8382945688707488, 0.8733841116939272, 0.8349899404815265, 0.6016625921641077, 0.39589155518582886, 1.5129753457648414, 0.9093505931752068, 0.7085381001234055, 0.4355089621884482, 0.3461512199469975, 0.3404982361410345, 0.31658712348767687, 0.849445287670408, 1.536751538515091, 1.7430623365300042, 4.48457625082561, 7.093271766390119, 5.758397315229688, 6.097823330334254, 6.6158163121768405, 7.940605453082493, 12.52461780820574, 37.26497820445469, 44.19458341598511, 34.14493131637573, 23.53190537861415, 3.1937622811113084, 2.5589255690574646, 2.5462527062211717, 11.454729846545629, 40.76048837389265, 55.6824813570295, 50.45857204709734, 42.22982045582363, 28.26981598990304, 16.48276162147522, 8.262908935546875, 4.244079555783953, 1.5380834213324954, 1.144232383796147, 0.3548595926591328, 0.3776545694896153, 0.4833460609827723, 0.4637311877948897, 0.15759848404143537, 0.35900462738105227, 0.24153501646859304, 0.546565114387444, 0.5374368642057691, 0.42201108219368116, 0.2529781838612897, 0.5185371126447404, 0.2688518592289516, 0.5466330764549119, 0.4491502573447568, 0.5631803199648857, 0.18506372241037233, 0.8634647439633096, 0.4631573643003191, 2.1466822155884335, 0.4050950141889708, 0.8566197369779859, 0.5971094050577709, 0.9031883552670479, 10.381568414824349, 6.572651496955326, 3.6486015660422186, 9.068391016551427, 6.137828017984118, 2.913554025547845, 1.6990722055946077, 2.7280052048819403, 6.597445709364755, 65.09329523359025, 34.350118568965364, 27.55514165333339, 72.04771246228898, 84.99210916246686, 40.353504589625764, 30.862522397722515, 57.431978702545166, 60.88971151624407, 20.707799639020646, 0.42701196670532227, 0.5901762970856258, 0.4201440523777689, 0.6665841170719692, 0.42474655540926115, 0.4345999423946653, 0.36507868287818773, 0.24414667061397008, 0.21205182852489607, 0.30583348338093075, 0.3293409219809941, 0.33116493267672403, 0.1374839919486216, 0.34192329538719995, 0.2704927740352494, 0.196961711826069, 0.17495650904519217, 0.2123757340013981, 0.19781710021197796, 0.1880957425705024, 0.1688111259468964, 0.18193353180374416, 0.29165959251778467, 0.26883028181535856, 0.17444994194167002, 0.1249630938151053, 0.2637433319219521, 0.15551078106675828, 0.3207186146506241, 0.16135555958109243], [0.0707399355513709, 0.16208535113504954, 0.13419416919350624, 0.05622977291100791, 0.0802336921915412, 0.033880943033312044, 0.026437507177303945, 0.057139603554138114, 0.046375222238046784, 0.008161742356605828, 0.040453277328716855, 0.09439405306641545, 0.052032548668129106, 0.021151252889207432, 0.03184811318559306, 0.03651053425190704, 0.008096987215269889, 0.0641681474766561, 0.10566800739616156, 0.04966539104602166, 0.02933747594111732, 0.01118695002514869, 0.03936762808422957, 0.08372231213642017, 0.07993329116808516, 0.2090945422117199, 0.018358758983335326, 0.11824140378407069, 0.13459834536271437, 0.045648490877023766, 0.13445661296801908, 0.30517185745494707, 0.07572534267923661, 0.04716459595199142, 0.04005583222689373, 0.8042470387050084, 7.891653656959534, 24.438565390450613, 28.765026262828282, 23.132413489477976, 23.671949795314244, 64.8943544115339, 58.22830826895577, 31.83729907444545, 33.99883154460362, 38.95755590711321, 4.543448771749224, 0.7040339846696172, 0.3364476534937109, 0.08448389984135117, 0.6450918189116887, 0.12470451769019876, 0.3283563676689352, 1.5543217957019806, 2.433747257505144, 2.2743935797895705, 5.653600241456713, 4.459780735628946, 2.8725824526378085, 0.7440573998859951, 0.5678324646183422, 0.4216868510203702, 0.7029907777905464, 0.1275436439152275, 0.06700947894049541, 0.31560227062020985, 0.16340622811445168, 0.06111363388065781, 0.13483514051352227, 0.06493035943380424, 0.07109181702669178, 0.03769184675599847, 0.06772388810557978, 0.014576280788917626, 0.04218596738896199, 0.09551188522683722, 0.07276740497244255, 0.06854598077812366, 0.33393245988658493, 0.3301465058965342, 0.273937099214111, 1.0110334626265933, 0.8630875870585442, 1.4003466750894273, 1.2312672563961573, 4.332813262939453, 7.618782264845712, 2.4691811161381856, 0.9337794823305947, 0.931947437780244, 0.1987411563417741, 0.9852976607424873, 1.652257849063192, 11.769659553255353, 25.736725125994, 25.392269917896815, 18.521628856658936, 8.749640669141497, 2.2474087306431363, 0.30416681138532503, 0.21545727364718914, 0.5119711735418865, 0.33860965605293003, 0.13701056449541024, 0.13429236678140505, 0.10606948299599545, 0.06666225900075265, 0.08060603828302451, 0.0416951796172985, 0.07720405368932656, 0.029903920367360115, 0.01632300464968596, 0.15337564849427768, 0.09636225923895836, 0.0750883679304804, 0.07068076051239457, 0.13939782711012022, 0.16374291719070502, 0.12969837257904665, 0.19880947124745163, 0.12794954356338295, 0.06574690847524575, 0.0618094036887799, 0.21977594548038074, 0.07592115431491818, 0.5656920937555177, 1.3943740470068795, 0.16223274251180037, 0.9930312229054314, 1.0972426938159126, 0.7557590348379952, 0.16930971347859927, 0.5455880239605904, 0.748235167137214, 12.16776614529746, 39.28881474903652, 16.350983824048722, 18.503473213740758, 66.44498389107841, 57.0146073613848, 42.70246819087437, 17.10204413958958, 21.33456710406712, 31.4873982157026, 19.71038399423872, 0.30029992173824993, 0.10085684127573456, 0.04545894890491452, 0.04915674083999225, 0.08122410226081099, 0.06270019124661173, 0.12517738874469483, 0.048665087936179977, 0.03200993360951543, 0.08373323655022041, 0.06515382137149572, 0.023402964563242028, 0.09395054222217628, 0.08314405780817781, 0.0244628159063203, 0.06615858245640993, 0.13822997334812367, 0.06719836273363658, 0.0453915839482631, 0.029388450884393284, 0.08967763079064232, 0.03330385917797685, 0.02784588633637343, 0.04193932669503348, 0.06157011831445353, 0.03881349567590015, 0.028564627947551862, 0.08431290223130158, 0.04484166184972439, 0.055734276106315, 0.0587855666609747, 0.0658098358128752, 0.20142018901450293, 0.09631159302911588, 0.07886520919523068, 0.18107567355036736, 0.18391189564551624, 0.040339256304183176, 0.05996380200875657, 0.1553931502359254, 0.06116381833063705, 0.06328222501490798, 0.09741001908800431, 0.06992680632642337, 0.037577975009168894, 0.09392118201191936, 0.12024783183421407, 0.057062813746077676, 0.08950754920286791, 0.04798436464209642, 0.04591288883239031, 0.06442761926778726, 0.20249534132225172, 0.011716289612065469, 0.2327403069606849, 0.1693213571395193, 0.1673138705747468, 0.049535529621477635, 0.18260878271290235, 0.11425578407943249, 0.08208755842809166, 0.27022562122770716, 0.28307596168347765, 0.12476945349148341, 0.22929041779467038, 0.09425553014235837, 1.7487256612096513, 17.29520753451756, 48.79262678963797, 43.3366094316755, 44.549559933798655, 50.87410906382969, 77.46029663085938, 53.14410638809204, 42.486076968056814, 64.1475133895874, 52.811701093401226, 4.539262047835758, 0.6672904991677829, 0.10405227302440576, 0.22998838605625288, 0.4003926579441343, 0.4751150512269565, 0.6913972198963165, 1.8488292268344333, 1.2116617198501314, 2.9162149684769765, 2.777954067502703, 1.9320402017661502, 3.55446064046451, 3.952486676829202, 3.5267981248242513, 2.7763147268976485, 0.852934966129916, 0.35408486851624077, 0.05869431048631668, 0.6195472010544368, 1.2636221945285797, 0.29550056212714737, 0.1546907986381224, 0.5798162615724972, 0.12146449940545218, 0.04227239578696234, 0.030864060989448, 0.05558176857552358, 0.07407828034566981, 0.08992933335580997, 0.21153273566492967, 0.2215765467179673, 0.514268367418221, 0.8740702463047845, 0.9632059718881334, 1.384938936148371, 1.4411457372563226, 2.4563623411314826, 1.4796217126505715, 5.849815198353358, 9.555595227650233, 3.3826872748988013, 1.0874766749995095, 1.0657341331243515, 0.8493416618023599, 0.6842823188219751, 1.1336432205779212, 16.65225945200239, 30.815451826368058, 28.059665986469813, 24.215700183595928, 12.213588646480016, 3.2510475729193007, 0.4837735380445208, 0.540646986237594, 1.0407297377075468, 0.619819157889911, 0.2837945574096271, 0.3123210652598313, 0.3433153506900583, 0.2973978546048914, 0.17619372265679495, 0.12792529272181646, 0.09558128578854458, 0.05412254848384431, 0.05286201362365058, 0.24465212492006166, 0.12382486489202295, 0.035193830262869596, 0.2778521105647087, 0.1072195591405034, 0.01855460793844291, 0.1750011702201196, 0.08046111677374158, 0.21617787783699377, 0.17957361415028572, 0.4352470205298492, 0.4416901176529271, 0.24649236617343767, 1.0854205510446002, 3.030055556978498, 0.5971113592386246, 1.533939038004194, 1.1823652918849672, 0.7145991006067821, 0.2815720023853438, 0.7293021945016724, 1.321053072810173, 7.010375414575849, 59.300192969185964, 38.251136030469624, 12.899385401180812, 48.58709560121809, 72.4852683203561, 54.61297641481672, 28.641143356050762, 27.918627977371216, 45.544076442718506, 30.859308855874197, 0.890646368265152, 0.3920643462666443, 0.20002140264425958, 0.4425258013818945, 0.04795959811391575, 0.22401920493159974, 0.1680992070053305, 0.05750502858843122, 0.02087187796964177, 0.20649250969290733, 0.17617024534514972, 0.06627767213753291, 0.2021993100643158, 0.18966963168765816, 0.04604512173682451, 0.19635607860982418, 0.08484150136687926, 0.07890626056385891, 0.11864735771502767, 0.06168734880962542, 0.1035337026364037, 0.03541854749034558, 0.14831655924873693, 0.03838088210406048, 0.04196529083752206, 0.04392205351697547, 0.10596686814512525, 0.04030656448698469, 0.1083508398649948, 0.13652180215077742, 0.022569419915920923, 0.2488792895206383, 0.23832209887249128, 0.22688578468348297, 0.16418343569551194, 0.24649866297841072, 0.2862526997923851, 0.2602429326091494, 0.27264975543533054, 0.1954038632767541, 0.19970690166311605, 0.3354900505925928, 0.29769274592399597, 0.13404922054282256, 0.1083614317966359, 0.2140070271811315, 0.16823377407022885, 0.1784921378961631, 0.2791268064507416, 0.22956991993955203, 0.16959518673164503, 0.17133048575903687, 0.39341940784028595, 0.11421714829547064, 0.47736382484436035, 0.2405746994274003, 0.3284870263721262, 0.1555460106049265, 0.24283541526113236, 0.2505011782050133, 0.26875387877225876, 0.4764723383954593, 0.4452881174428122, 0.34131975205881254, 0.35989977791905403, 0.3070722169109753, 0.9081762933305332, 22.53995622907366, 76.81322479248047, 76.4717903137207, 62.427667481558665, 58.90137331826346, 100.49765355246407, 93.56091948917934, 51.82033906664167, 58.76867662157331, 73.70487867082868, 10.287314363888331, 1.3628642920936858, 0.48606351230825695, 0.556898931307452, 1.5762368483202798, 0.935327193566731, 0.8955075017043522, 4.84714845248631, 3.8811282430376326, 7.19965216091701, 9.144791671207972, 9.124086039406912, 7.683209436280387, 3.9430088996887207, 3.7403442774500166, 2.754033156803676, 1.6061175763607025, 0.47765706053801943, 0.3799409068056515, 0.6284299844077655, 0.8190567440220288, 0.23813647883278982, 0.35019740568740026, 0.3335146994463035, 0.2131155271615301, 0.15019756688603333, 0.17870713850217207, 0.12316883009459291, 0.32125544441597803, 0.25614851659962107, 0.2682092865662915, 0.25348993497235434, 0.9755525950874601, 1.9702759214809962, 2.6762013903685977, 2.1422184322561537, 2.37868104662214, 3.3664350041321347, 2.4805131937776292, 8.271068726267133, 12.964854802404131, 4.424582030091967, 2.0991797702653066, 1.9456237128802707, 3.293482393026352, 2.013822019100189, 3.2773818969726562, 19.22918128967285, 30.363954407828196, 30.22226674216134, 24.665213891438075, 14.474607161113195, 5.405583424227578, 1.7164199032953806, 1.0568801739386149, 1.1755520403385162, 0.5256625988653728, 0.28658743468778475, 0.2435066763843809, 0.4657774322799274, 0.32373489279832157, 0.228781842227493, 0.28187074778335436, 0.26934596842953135, 0.06801924761384726, 0.0786592195342694, 0.4044901137905461, 0.24380159484488623, 0.2124796448541539, 0.4415138071136815, 0.18714070453175477, 0.2141318233417613, 0.37052007232393536, 0.40462525082486017, 0.3265363739005157, 0.20436283254197665, 0.3263471983373165, 0.4013172297605446, 0.6849884295037815, 1.5372758018118995, 3.7192161083221436, 6.004253676959446, 5.973533085414341, 3.8412564396858215, 2.9687266307217732, 1.1071822004658836, 2.2169135212898254, 1.2014301717281342, 19.529075963156565, 63.06469917297363, 25.323090178625925, 30.267704486846924, 82.06122003282819, 86.99952711377824, 64.89446558271135, 37.720304080418174, 48.14092745099749, 68.7531407220023, 34.84619562966483, 0.8263403560434068, 0.45630530055080143, 0.4051730457161154, 0.5251750850251743, 0.26827545730131014, 0.41011514195374077, 0.36347316045846256, 0.322002294340304, 0.15775899828544684, 0.3001422573413168, 0.29903874226978844, 0.18961104697414807, 0.2699021228722164, 0.42585248606545584, 0.18086452702326433, 0.2413671197635787, 0.3074622388396944, 0.2746726854571274, 0.43392716135297504, 0.1665411006127085, 0.18982346914708614, 0.09658107999712229, 0.2025355105953557, 0.1249587240495852, 0.26645437787686077, 0.1713477476899113, 0.26301113835402895, 0.1227726877800056, 0.2527306542864868, 0.4612865075469017, 0.16866262177271502], [0.04510850253115807, 0.0974729803523847, 0.0733363294441785, 0.04054386853905661, 0.0450407643802464, 0.06764690830771412, 0.030200484275285686, 0.046860215320651016, 0.0215052513937865, 0.05131978155778987, 0.031657926605216095, 0.0943058163725904, 0.045966516847589185, 0.04434023464896849, 0.025951837256018604, 0.09640654721962554, 0.028526406069951396, 0.013658786940920566, 0.05022175922723753, 0.053052759995417934, 0.06161203820790563, 0.1539821909474475, 0.05436847671600325, 0.09831549692898989, 0.0174402057725404, 0.09296408801206521, 0.04974622153011816, 0.06396313490612165, 0.10975204860525471, 0.06778307671525649, 0.15459550518010343, 0.06465048409466233, 0.23230398180229322, 0.047303210478276014, 0.09029111465705292, 0.09279372822493315, 1.6835236570664813, 19.517368248530797, 31.774987629481725, 29.045719589505875, 32.0330228805542, 33.55381332124983, 60.83390358516148, 74.11991541726249, 28.55429608481271, 25.873969418661936, 43.78140878677368, 9.130933489118304, 0.9677415170839855, 0.051422715320118835, 0.6353524529508182, 1.4054010553019387, 0.7394794598221779, 0.9913329311779567, 0.8969977274537086, 0.6242808784757341, 2.2179266554968695, 2.84725844008582, 5.229818318571363, 4.045006717954363, 2.164130662168775, 2.9378332027367184, 0.37097783918891636, 0.5246960393020085, 0.022753277460911443, 0.25516263235892567, 0.10494266703192677, 0.4384697904544217, 0.12726704590022564, 0.062318610293524604, 0.04861327160948089, 0.08105737942137889, 0.05541840109175869, 0.03334112771387611, 0.04374575994110533, 0.07028595491179399, 0.08191103075764009, 0.09404627672795739, 0.15083667902009829, 0.06872516152049814, 0.0785542433815343, 0.16587557989571775, 0.052119889695729525, 0.1601557603904179, 0.7353283997092928, 0.7376109915120261, 1.082797171814101, 0.12840379561696733, 0.40847007451312883, 2.0858342349529266, 1.4030007783855711, 0.2667445737336363, 1.5207619965076447, 3.6142570546695163, 9.051334926060267, 4.452634513378143, 2.8256723412445615, 0.3569948880800179, 0.7168236098119191, 0.22956365027597972, 0.268106149243457, 0.10168227234057017, 0.12437487180743899, 0.02126331634021231, 0.024693215864577463, 0.016221483936533332, 0.06655527438436236, 0.04150579370824354, 0.03554295688601477, 0.15874243980007513, 0.17439479061535426, 0.06009200441518, 0.0487301390884178, 0.14089667025421346, 0.14901581672685488, 0.06289286126515695, 0.06703719031065702, 0.11257902226809945, 0.11198320066822426, 0.14566983841359615, 0.16954828639115604, 0.049903187035982094, 0.29129204366888317, 0.27501862975103514, 0.0762518790683576, 0.6638782279832023, 0.9502892707075391, 0.5882594085165432, 1.511494836636952, 0.021138387865253856, 0.842911918248449, 1.0579100272485187, 0.3798722390617643, 26.43955625806536, 29.63650233404977, 12.655712945120674, 31.36118071419852, 68.21272373199463, 58.00622647149222, 30.42939601625715, 17.301129136766704, 24.93614673614502, 36.501266956329346, 19.03737279347011, 0.8895246684551239, 0.0326177584938705, 0.029561629984527826, 0.07109438188906227, 0.05559098647375192, 0.048012096368308575, 0.025160249821575623, 0.07400389933692557, 0.1621789482555219, 0.02998180261680058, 0.10928537936082908, 0.11515364875750882, 0.04600191262683698, 0.019847089923652153, 0.08264243043959141, 0.03808264899998903, 0.07597377470561437, 0.061373472080699036, 0.07518658587442976, 0.026542215308706676, 0.03024809029219406, 0.046927546350551505, 0.046179620948221, 0.044695725930588584, 0.008890128494905574, 0.03582179067390306, 0.04225295915135315, 0.02787691743911377, 0.03064841577517135, 0.028225056793806807, 0.09613124520650931, 0.03533924710271614, 0.054792286295975955, 0.07764547464570828, 0.1804206429847649, 0.01260762254241854, 0.0528859523391085, 0.09820190338151795, 0.034651419546987326, 0.06907075976154634, 0.0862983228372676, 0.052574671006628444, 0.06964905480188982, 0.021283560432493687, 0.05608944847647633, 0.06412392734949078, 0.07742348512900726, 0.0631468165665865, 0.12261946100209441, 0.06305677496961185, 0.06409867227609668, 0.08729268198034593, 0.019217870830159103, 0.16575427140508378, 0.0758804761405502, 0.04785471695608326, 0.1718555497271674, 0.110081239869552, 0.046921269901629, 0.04073667426460555, 0.28284086287021637, 0.03610367447670017, 0.17898218945733138, 0.13336759140448912, 0.33490363348807606, 0.05080354533025196, 0.24553780310920306, 0.09956632195306675, 4.387280625956399, 36.79337617329189, 55.39076471328735, 45.83930887494768, 54.211196831294465, 58.628267424447195, 77.90712833404541, 62.13643373761858, 36.94768871579851, 50.27320453098842, 54.84729051589966, 12.103929570743016, 0.4989185482263565, 0.5292497692363602, 0.5850041774766785, 0.9671541771718434, 0.37777548442993847, 0.884056164750031, 1.0827424547501971, 1.478282121675355, 4.119629502296448, 3.008520701101848, 4.397046753338405, 2.90356490441731, 4.1122909017971585, 3.57893545286996, 1.476044693163463, 0.5142837294510433, 0.04361084343067237, 0.46674301475286484, 0.4792412498167583, 1.5451842631612505, 3.022161317723138, 2.249667980841228, 0.0819621787273458, 0.0992038824728557, 0.05598849603640182, 0.026562040405614034, 0.05808460605995996, 0.04798170478482332, 0.018893358064815402, 0.1236593702009746, 0.021299897859405195, 0.08004722398306642, 0.06409895726080451, 0.15078843518027238, 0.03452369211507695, 0.35705932176538874, 0.5453239924141339, 0.7249743353043283, 0.590756254536765, 0.9239533181701387, 0.9983619025775364, 3.6719375252723694, 1.697354263492993, 1.2195369601249695, 2.6701827304703847, 4.850015018667493, 12.390027727399554, 5.643277823925018, 3.4248708742005483, 0.2558606820447104, 0.6511165584836687, 0.24776641066585267, 0.45995001069137026, 0.09264901027615581, 0.07773626941655364, 0.10230727094624724, 0.05880985821464232, 0.0614682702081544, 0.1486829003053052, 0.09847557012523923, 0.0645898977028472, 0.1519331916102341, 0.1623523546648877, 0.2702334650925228, 0.15395973143833025, 0.09609149662511689, 0.06359963012593133, 0.11493677539484841, 0.06559476056801421, 0.16592072961585863, 0.1778632037873779, 0.10147775510059935, 0.1331359531198229, 0.12544470440064157, 0.22248217383665697, 0.15551216527819633, 0.10647076860602413, 0.6032352192061288, 1.6204902508429118, 0.4778703919478825, 0.557550270642553, 0.15451803005167417, 0.36687859201005524, 0.7571543742503438, 0.9062904002411025, 23.28675729887826, 61.13178675515311, 27.67708080155509, 17.19246452195304, 51.756790842328755, 72.71316228594098, 47.11035673958914, 36.969975062779014, 34.61018616812569, 46.02689634050642, 39.19572278431484, 4.157041643347059, 0.4612289677773203, 0.05695635838700192, 0.2278773279062339, 0.05615073036668556, 0.19704491379005568, 0.05424392143530505, 0.1711335884673255, 0.1360785695058959, 0.020433988788032105, 0.05630813352763653, 0.06005290722740548, 0.02944269297378404, 0.09184692760131188, 0.13533546509487288, 0.06878043498311724, 0.03797632934791701, 0.07938770151564054, 0.1191707117749112, 0.03165655257180333, 0.024821382647912418, 0.0703900218276041, 0.06380847641932112, 0.05742205732635089, 0.10335248628897326, 0.08715039318693535, 0.016218684979581406, 0.047599950805306435, 0.07503795956394502, 0.04387159765298877, 0.024859170263100947, 0.07752812201423304, 0.13751405104994774, 0.26035103680832045, 0.26021030864545275, 0.05863412443016257, 0.1818906891026667, 0.22056805369045052, 0.14434662727372988, 0.11176672764122486, 0.19705536322934286, 0.16622319338577135, 0.21433040340031895, 0.17197456476943834, 0.16883856590305055, 0.10852094180881977, 0.12195155184183802, 0.2231448039944683, 0.1997758001089096, 0.14962298343224184, 0.09680214670619794, 0.1576742764030184, 0.14696486320878777, 0.2762009363089289, 0.20847148421619618, 0.2017900584531682, 0.23765485467655317, 0.18257634873901094, 0.07190672401338816, 0.138542682996818, 0.5273302750928062, 0.22899476651634487, 0.3328257149883679, 0.32916528997676714, 0.39648717322519844, 0.17969532976193087, 0.31911542639136314, 0.23317785348211015, 2.9053753444126675, 49.36768054962158, 87.32541847229004, 73.48960958208356, 76.21511690957206, 68.6220976965768, 89.25385625021798, 112.86061109815324, 49.83825077329363, 44.265548842293875, 83.94855921609062, 25.240142583847046, 0.9206024408340454, 1.2154874631336756, 1.4388699850865772, 3.642989592892783, 1.0624223394053323, 2.9263552129268646, 2.203341300998415, 2.7298486488206044, 7.074542897088187, 6.375819018908909, 10.579940353121076, 8.0702805519104, 11.590085966246468, 9.765647956303187, 1.6096790709665842, 2.758229000227792, 0.08469512779265642, 0.5611529116119657, 0.40580147770898684, 1.3651153998715537, 2.521566625152315, 1.7346856317349841, 0.42002525446670397, 0.21106519789568015, 0.1260898962084736, 0.2096739975469453, 0.19419033053730214, 0.15952614774661406, 0.1833560668996402, 0.32645275124481743, 0.1896162445523909, 0.20898649229535035, 0.22290484687047346, 0.5184039569326809, 0.12248584388622216, 0.6798427999019623, 1.1702290688242232, 2.089726746082306, 1.3821374007633753, 1.4079737343958445, 1.3007764922721046, 4.724548356873648, 3.5399376026221683, 4.134564220905304, 8.009982347488403, 6.58353237594877, 13.80653612954276, 8.190727574484688, 5.006570092269352, 1.1982500680855341, 1.8012588194438388, 0.4172746906323092, 0.6818764507770538, 0.21114260517060757, 0.14235237214182103, 0.18093299120664597, 0.1357958103929247, 0.20369298277156694, 0.32988896114485605, 0.11649751450334277, 0.10620970225759915, 0.37013767712882584, 0.22680947663528578, 0.3541523148970944, 0.24202966849718774, 0.3053170368075371, 0.20551707489149912, 0.1068802373483777, 0.2018806564488581, 0.3116064593195915, 0.31040235821689877, 0.6514773762651852, 0.4633946887084416, 0.13649770058691502, 0.35418955289891785, 0.5107544788292476, 1.7398611711604255, 2.304356166294643, 4.421831846237183, 3.3830147087574005, 2.868237005812781, 1.9559791343552726, 5.765268649373736, 2.2712623306683133, 0.7897184640169144, 41.39832953044346, 49.24551037379673, 21.2187944820949, 49.00154175077166, 85.59808935437883, 86.4432682309832, 47.64253316606794, 37.98988028935024, 55.715652057102744, 69.78356552124023, 48.886146068573, 2.452166280576161, 0.3809990685965334, 0.1405086296477488, 0.32967432694775717, 0.15475107968917914, 0.3755187855235168, 0.13277411753577845, 0.3011157922446728, 0.3165268695780209, 0.06441638272787843, 0.21930597855576447, 0.23727452222790035, 0.07959867162363869, 0.15450945336903843, 0.3699389749339649, 0.09221684453742844, 0.14442678940083298, 0.23770240641066007, 0.21147776075771876, 0.1964948254504374, 0.1430379639246634, 0.18034683194543633, 0.1309305786022118, 0.18603063481194632, 0.22032059196914944, 0.2091318480670452, 0.1261084202144827, 0.20922328744615826, 0.11492214617984635, 0.11750393121370248, 0.16317454911768436, 0.13815545663237572], [0.05457872757688165, 0.17492312512227468, 0.031173873293612684, 0.062394769064017704, 0.11283850762993097, 0.04992027933310185, 0.0979826415755919, 0.07331405313951628, 0.07992569836122648, 0.0149047731621457, 0.07575327118060418, 0.06620023772120476, 0.07427962882710354, 0.045469961528267176, 0.0865533570093768, 0.07960092435990061, 0.028884058485605886, 0.11224320171666996, 0.03090650335486446, 0.044879493569689136, 0.05719959283513682, 0.06726394992853914, 0.05762839982552188, 0.05073701497167349, 0.12065198086202145, 0.04522865751226034, 0.05449721855776651, 0.08772458309041602, 0.04207712019394551, 0.04358847213110753, 0.1022817851709468, 0.05752555427274533, 0.11275161443544285, 0.14745589186038288, 0.05343081935175827, 0.02713121423896934, 0.2991265175598008, 4.100663959980011, 23.687706572668894, 24.547650371279033, 33.830865791865754, 35.583284854888916, 39.35747684751238, 78.02720710209438, 80.80373505183628, 39.19583395549229, 21.750501905168804, 42.87187916891915, 25.340358189174108, 1.020942679473332, 1.2093417814799716, 0.16948282133255685, 0.2043442271117653, 0.11288346736026661, 0.38620253652334213, 0.37930088543466156, 1.7988823183945246, 0.8871931678482464, 2.3608706423214505, 2.846882803099496, 4.986685216426849, 3.770909837314061, 0.6743495975221906, 0.5586816327912467, 0.020011624487649118, 0.7302337416580745, 0.3430391326546669, 0.08188804877655846, 1.7499384475605828, 2.91245208467756, 0.08330281464649097, 0.168647775426507, 0.21550870660160268, 0.054370956761496406, 0.06768893676676921, 0.025457768767539943, 0.052938067221215794, 0.04510324388476355, 0.06286008802375623, 0.05506115918979049, 0.01569546153768897, 0.08303612324276141, 0.08455847083990063, 0.06916358335209744, 0.09193981226001467, 0.1702938335282462, 0.13007468810038908, 0.07425844496382134, 0.05236283237380641, 0.0727932368006025, 0.11487055037702833, 0.2291219239788396, 1.5142956120627267, 1.039579593709537, 1.53455927329404, 0.2726881062345845, 0.39788367971777916, 0.17703562176653317, 0.08230684737541846, 0.05333495931699872, 0.03890754062948482, 0.0767463343217969, 0.051934707311115096, 0.18619612950299466, 0.1724921241402626, 0.19514680707028934, 0.09209922049194574, 0.06745316620383944, 0.11570897538747106, 0.032935445196926594, 0.06346607407821075, 0.11876326506691319, 0.22051697357424668, 0.0798512902110815, 0.05551978100889495, 0.15496460108884744, 0.07701580093375274, 0.06493392174265214, 0.14967208222619124, 0.08277621718921832, 0.1593450874622379, 0.13809106365910598, 0.15918868514043943, 0.5071641600557736, 0.5457098888499397, 0.4470700318259852, 1.3590298635619027, 0.6510754664029393, 1.139322070138795, 0.6498537776725632, 0.1226078173411744, 8.680555599076406, 35.66122627258301, 20.645939826965332, 16.71480713571821, 51.44771065030779, 73.19649287632534, 60.48124776567732, 27.865621907370432, 21.67864884649004, 26.956807953970774, 35.89038828441075, 24.223899057933263, 1.5371305410351073, 0.18364240867750986, 0.0906610723052706, 0.06541740508483988, 0.0920556653290987, 0.08929598198405334, 0.013203870771186692, 0.10935117011623723, 0.0439569777143853, 0.02762780518137983, 0.11083860708666698, 0.06326973318521466, 0.02961173640297992, 0.00819731455495847, 0.0843348256977541, 0.07282058176185403, 0.13887539585786207, 0.15807166722204002, 0.049017403673912795, 0.036993440839328935, 0.03188320701675756, 0.011051143785672528, 0.04837748408317566, 0.06490656321070024, 0.05518836075706141, 0.038365231693855355, 0.04308935873476522, 0.013294306766640927, 0.0935438826147999, 0.038380922816161595, 0.08144591535840716, 0.09200102290404694, 0.05598159194258707, 0.08401391256068434, 0.09019865747541189, 0.01650271804205009, 0.07723587019635098, 0.14195640624633857, 0.019687384832650423, 0.04099373725642051, 0.04302217019721866, 0.11591435436691556, 0.01920503464394382, 0.06680436458970819, 0.058882644666092734, 0.03277514808412109, 0.1473177828426872, 0.10521606914699078, 0.014303752287690128, 0.10951133830738918, 0.09492686590445892, 0.0036402814273190287, 0.09557626462940659, 0.04855840187519789, 0.044307434266167026, 0.041699505278042386, 0.08391401863523892, 0.05329969245940447, 0.01834312384016812, 0.09976656442242009, 0.019276525093508617, 0.07710116742444889, 0.18092541875583784, 0.08808012865483761, 0.06173356382974556, 0.1352626040045704, 0.10629915352910757, 0.039752924016543796, 0.02297395740502647, 0.46497936653239386, 12.78104715687888, 47.01312712260655, 52.37595871516636, 54.642099789210725, 56.92049748556954, 63.008557728358674, 91.8624392918178, 61.331887926374165, 37.41885995864868, 50.187317848205566, 61.63125801086426, 18.572373288018362, 1.9882474371365138, 0.5256984255143574, 0.287109798086541, 0.3120896305356707, 0.09579115666981254, 0.7531915668930326, 0.6047602402312415, 0.9599632258926118, 1.4455087717090334, 2.0921740319047655, 2.3512033096381595, 1.6225119595016753, 2.5213764182158878, 1.0969293734857013, 0.0962340704032353, 0.021334034956193397, 2.0221351044518605, 1.065255033118384, 0.03182628132136805, 1.1595299286501748, 1.585025668144226, 0.057933706657162735, 0.12915486602910928, 0.1570550182035991, 0.032601853633033376, 0.08257055322506598, 0.03736224497801491, 0.04108468130496996, 0.07433845781322036, 0.01452343987434038, 0.009126175560855439, 0.04648046301943915, 0.12086928848709379, 0.0881213496572205, 0.18780836941940443, 0.09416910513703312, 0.29047500608222826, 0.033991863152810504, 0.142711642863495, 0.08582889874066625, 0.11822552606463432, 0.14882183713572367, 0.87218348469053, 3.2400993832520077, 1.7424543691532952, 1.3648869778428758, 0.5799557683723313, 0.423877406333174, 0.24126037263444491, 0.47032616819654194, 0.132667017568435, 0.056569135415234735, 0.12369025711502347, 0.07705851471317665, 0.17431637910859926, 0.18857324123382568, 0.14447469397314958, 0.039217994149242125, 0.03586229582184127, 0.06540669780224562, 0.09136850613036326, 0.13326932596308844, 0.03684416652790137, 0.11081843424056258, 0.052567899227142334, 0.0658719896205834, 0.07599533176315681, 0.04637979895674756, 0.11242754611053637, 0.042818141502461264, 0.061194019924317083, 0.12112662967826639, 0.20567871550364153, 0.21263774351349898, 0.24945436151964323, 0.09716586183224406, 1.0591751422200884, 1.7598958675350462, 0.13608531414398126, 0.23600425039018902, 0.5210914984345436, 0.4852403679064342, 3.7170113580567494, 45.93966170719692, 53.50420372826712, 22.654405219214304, 25.85386654308864, 62.06677804674421, 72.31273760114397, 47.42147970199585, 34.7964882169451, 35.32814700262887, 47.85411623546055, 45.28840357916695, 7.283371874264308, 0.5288025875176702, 0.09929832097675119, 0.156087264418602, 0.11038128126944814, 0.05820789587284837, 0.05020224116742611, 0.09691336538110461, 0.03601584490388632, 0.10987072438001633, 0.13027913070150784, 0.047337557920919995, 0.04808557153280292, 0.1422747748770884, 0.03156455000862479, 0.06064615039420979, 0.11111220597688641, 0.02022395675469722, 0.01298400676543159, 0.1004999250705753, 0.10416789539158344, 0.09440904190497738, 0.05185604813907828, 0.015045421597148691, 0.021066975447216203, 0.04608307559309261, 0.07793047970959119, 0.0563056874088943, 0.078061498036342, 0.010691669503492969, 0.03945201409182378, 0.012151108422715749, 0.02365391225820141, 0.2149583739893777, 0.2597829944321087, 0.12450487911701202, 0.3203962290925639, 0.21594934724271297, 0.14954040572047234, 0.27050422770636423, 0.18774434285504477, 0.15898535533675126, 0.10000416702990021, 0.3671307899057865, 0.2980038406593459, 0.1653426992041724, 0.2782950582248824, 0.19751272297331265, 0.16284483538142272, 0.14283995383552142, 0.20237001590430737, 0.13318115712276526, 0.2838888737772192, 0.26792318906102863, 0.1830887376729931, 0.1146385728248528, 0.18256238448832715, 0.24206413807613508, 0.11370376870036125, 0.16297062220317976, 0.2847880412425314, 0.16391926844205174, 0.16008908753948553, 0.21180695880736622, 0.1854763531259128, 0.2739259712398052, 0.20628216383712633, 0.1925201030181987, 0.09355904108711652, 0.4987641136561121, 9.41150348527091, 57.10957186562674, 86.22091892787388, 77.62738691057477, 78.06184387207031, 73.18397222246442, 105.14936828613281, 106.21260247911725, 63.29075186593192, 37.891115120479036, 73.97077928270612, 55.95538922718593, 2.9086653164454868, 1.6708155104092188, 0.5526018504585538, 0.27157357175435337, 0.15642240643501282, 1.8156504929065704, 1.0417448260954447, 2.7800682740552083, 3.067062531198774, 6.684724637440272, 7.983970897538321, 10.00885488305773, 6.7418740051133295, 2.228605602468763, 0.6745898532015937, 0.0974211742037109, 4.776582547596522, 0.7051383682659694, 0.12599570197718485, 1.6642977744340897, 7.791886210441589, 0.11958843150309154, 0.36254430030073437, 0.2492684700659343, 0.17317551746964455, 0.14361481368541718, 0.20729299102510723, 0.15167950093746185, 0.3025252180440085, 0.12209959461220674, 0.17645423939185484, 0.13377294822462968, 0.2314979364829404, 0.12659075004713877, 0.24370442863021577, 0.16597042552062444, 0.4651769559298243, 0.42362743403230396, 0.30674779574785915, 0.14371443619685514, 0.26188710438353674, 0.7881366088986397, 2.130606255361012, 4.409764128071921, 2.1621834295136586, 3.1283043878419057, 1.692123029913221, 0.734706210238593, 0.7877742169158799, 0.7810358213526862, 0.3288564479776791, 0.21236852795950004, 0.26288080534764696, 0.11715268077594893, 0.36676283393587383, 0.32485594121473177, 0.25425342257533756, 0.15393372997641563, 0.1262757062379803, 0.14618475149784768, 0.1717636218028409, 0.237104915614639, 0.16204484259443624, 0.22404038879488195, 0.2414249580885683, 0.2541214610849108, 0.225749170673745, 0.09762400189148528, 0.20356140126075062, 0.24164485771741184, 0.18782708341521875, 0.4857298359274864, 0.24688545508044107, 0.5047619289585522, 1.3219509103468485, 1.5623320915869303, 3.579418352672032, 6.354154969964709, 1.2148153334856033, 2.440635093620845, 1.688275464943477, 0.6923034712672234, 15.077868870326451, 57.405214241572786, 41.6085889680045, 27.44337640489851, 71.15825271606445, 89.19875008719308, 83.98696885790143, 45.48173720496041, 44.48423991884504, 56.72510371889387, 65.692994253976, 55.00107846941267, 5.087348546300616, 0.54938776578222, 0.12468117608555726, 0.19578950186925276, 0.20476590948445456, 0.40127163220729145, 0.22823999130300113, 0.15956048161855765, 0.17727465608290263, 0.1507115707333599, 0.21194012809012616, 0.1449563724121877, 0.22502342318849905, 0.23102168632405146, 0.16643568341221127, 0.21263269521296024, 0.15865526162087917, 0.3160008692315647, 0.1806015404207366, 0.15031247000609124, 0.26715734015618053, 0.15284592977591924, 0.1028752318982567, 0.11338267235883645, 0.09138763403253895, 0.09773262177727052, 0.18824192615492003, 0.09792600425758533, 0.20062151258545263, 0.07220601902476378, 0.19906137058777468, 0.13769569487443992, 0.1649995640452419], [0.023373831662216356, 0.042429507177855284, 0.031765359054718695, 0.09024535425539527, 0.0240323990916035, 0.02145603215987129, 0.021830899008948888, 0.056613881407039504, 0.04280250466295651, 0.06013433142964329, 0.02627183267447565, 0.0872230100046311, 0.030605634142245566, 0.01378482990964715, 0.0499396820419601, 0.06294502703739063, 0.06486999695854527, 0.10597637442073651, 0.10343600037906851, 0.03852575272321701, 0.005013398393722517, 0.01111391675658524, 0.0034087807580363005, 0.06395584065467119, 0.12888368272355624, 0.09558471917573895, 0.088510075584054, 0.12173847827528204, 0.024265463996146406, 0.013492053923463183, 0.11334966841552939, 0.10252837836742401, 0.09795153074498687, 0.054611555101083856, 0.048276585925902636, 0.035749065290604315, 0.021403354093698517, 0.27096487155982424, 3.7658971462930952, 29.935486793518066, 29.75731761114938, 21.351390429905482, 37.18377113342285, 68.5025747844151, 65.95760944911412, 95.44282518114362, 45.287934575762065, 16.429726021630422, 24.92062098639352, 42.38358061654227, 11.939274634633746, 0.13134091586938926, 1.3510043684925352, 0.7782728267567498, 0.6416173396365983, 0.5341901555657387, 1.2868843291487013, 0.765386089682579, 0.7074024496333939, 0.7580956923110145, 1.9984968985830034, 2.193174349410193, 2.9007128860269273, 0.6755929993731635, 1.3768219202756882, 1.3153861654656274, 2.9632707749094283, 3.515498833996909, 2.9966874846390317, 0.6775120592543057, 0.08160678922597851, 0.06747894374919788, 0.08470094283776623, 0.07307739369571209, 0.03712706134787627, 0.08859025806720768, 0.10240295116922685, 0.15815504560513155, 0.15409732476941176, 0.09419236531747238, 0.061926505262298245, 0.06254161082740341, 0.02344122206393097, 0.10839386577052729, 0.026348427403718233, 0.05893550254404545, 0.0145001355891249, 0.0841107734345964, 0.13542138119893415, 0.05060299412746515, 0.1477567000048501, 0.18803193313734873, 0.06358881427773408, 0.03473218896293214, 0.2852533534169197, 0.6096506321004459, 0.42586165985890795, 0.12100008289728846, 0.12610557036740438, 0.06087961393807616, 0.10402806968029056, 0.06494828632899693, 0.02324230782687664, 0.0330303247485842, 0.09856503496744803, 0.030133261810988188, 0.05953838090811457, 0.09282622326697622, 0.052466936609042544, 0.057287279915596755, 0.26944717871291296, 0.17774531511323793, 0.1228388992271253, 0.11996329495949404, 0.159252670992698, 0.04842979234776326, 0.12095284328929015, 0.14874353419457162, 0.07724454187388931, 0.053590214012988975, 0.13289881870150566, 0.030518422036298683, 0.39936272321002825, 0.644809331212725, 0.3667117809610707, 0.3645311322595392, 0.18856793508997985, 0.5132410111171859, 0.389606665287699, 3.4845956351075853, 21.576056957244873, 29.72695050920759, 18.314876522336686, 29.639024530138286, 66.9200461251395, 74.5682270867484, 63.162654876708984, 26.86271718570164, 27.303331988198416, 46.45533963612148, 52.03232513155256, 36.57789169039045, 2.8946607879229953, 0.7831410712429455, 0.12100688181817532, 0.12369229272007942, 0.08097917826047965, 0.14879221229680947, 0.12266824766993523, 0.1408849044569901, 0.026513635413721204, 0.055953059545052905, 0.08356734830886126, 0.03740234300494194, 0.0018822345134269977, 0.0217441669665277, 0.012266225281304546, 0.05643613915890455, 0.07640375556158167, 0.11249351328504936, 0.08385498608861651, 0.05619309809324997, 0.04696241965783494, 0.032497165857681205, 0.08712204399385623, 0.032071137468197515, 0.013692904529826981, 0.06433494495494024, 0.03601276435490165, 0.06502020425562348, 0.08214563424033777, 0.06411568993436438, 0.08360966175262417, 0.0491001374487366, 0.025277780568493263, 0.13071869925728866, 0.008731686327207302, 0.03780820194099631, 0.05605265830776521, 0.052551119056131156, 0.08222306865666594, 0.029153837223670313, 0.051390237241451225, 0.04116643459669181, 0.07606771787894623, 0.07877961878797837, 0.03997624685455646, 0.06243416480720043, 0.03891563894493239, 0.031667052901216915, 0.04718785273975559, 0.03187100695712226, 0.06704722584358283, 0.08864458836615086, 0.0729711554678423, 0.02432463564244764, 0.03900395367028458, 0.03140098914237959, 0.0928551017173699, 0.09958561948899712, 0.08283382481230156, 0.01084849760601563, 0.0460513506882957, 0.13069182927055017, 0.10941111868513481, 0.013005223707295954, 0.06351015171302216, 0.0897732838722212, 0.1732432216938053, 0.1346172493483339, 0.06390490981617145, 0.0220454110697444, 0.06194252547408853, 0.3966800943017006, 12.662329367228917, 52.78659725189209, 58.07539578846523, 52.063380105154856, 60.46985966818673, 84.96404538835797, 87.50292410169328, 75.27444199153355, 38.00001771109444, 40.055656160627095, 61.518328939165386, 34.76858425140381, 6.006111451557704, 0.20348483536924633, 1.154370891196387, 0.7233929144484657, 0.24975807379399026, 0.2864293631698404, 0.6337711949433599, 1.347759342619351, 2.1617719658783505, 1.172407871910504, 0.14569566345640592, 1.6056977531739642, 0.6181882854018892, 0.28191387546913965, 0.7784281298518181, 1.3269068215574538, 0.9669946943010602, 1.959396345274789, 2.2225915023258755, 0.9224457762071064, 0.07614099966096026, 0.05489496900034802, 0.13120630809238978, 0.01109187030566058, 0.09599190804042987, 0.110066576727799, 0.035917046812496016, 0.10081895188029323, 0.06859695911407471, 0.05718146916478872, 0.0714291710672634, 0.12030869642538683, 0.011564754930857037, 0.09202340098896197, 0.08816309313156775, 0.07823949134243385, 0.05284295018230166, 0.0798606268529381, 0.11068004023815904, 0.08466141138757978, 0.13751766085624695, 0.298023165336677, 0.16006609877305372, 0.14110392199030944, 0.14438182967049734, 0.37340827020151274, 0.2539841527385371, 0.07794192659535579, 0.11296004682247128, 0.05753354062991483, 0.04004607828600066, 0.1595102021736758, 0.12493211190615382, 0.0707082004685487, 0.10475307077701602, 0.06582653455968414, 0.07356397115758487, 0.035173718484916856, 0.09921562112867832, 0.07769806110965354, 0.14692548103630543, 0.1437686782862459, 0.0805416317390544, 0.07678287343255111, 0.050074194824056964, 0.15803497204823153, 0.04362543532624841, 0.1019593317593847, 0.06457788084766694, 0.09922450993742261, 0.30128374323248863, 0.04092978872358799, 0.25808239568557056, 0.4374024548700878, 0.1766998419272048, 0.5443962450538362, 0.40608635385121616, 0.3561498134263924, 0.3769815441753183, 1.891675510576793, 20.961205652781896, 54.29321684156145, 42.095084462847026, 23.009814262390137, 43.903290612357004, 74.55608163561139, 76.1970932824271, 46.37541798182896, 35.83681072507586, 49.579954964774, 58.54921776907784, 50.76708943503243, 9.752103311674935, 0.8987399339675903, 0.039894914254546165, 0.10715211275964975, 0.0460761511432273, 0.06786099967679807, 0.12552208453416824, 0.12747477261083467, 0.026540423976257443, 0.05873604717531374, 0.11058235833687441, 0.03341886068561247, 0.06501112545707396, 0.1015840679673212, 0.05791653972119093, 0.10072737679417644, 0.02869703048574073, 0.05284938608695354, 0.0642185490578413, 0.017470839932294827, 0.03687615945403065, 0.0562985051157219, 0.05586727575532027, 0.0356949555155422, 0.057986232052956305, 0.11047108537916626, 0.041709571345044036, 0.010892092632795019, 0.05334955121257475, 0.14256807842424937, 0.09743599340851818, 0.06759688670613936, 0.05593942777652826, 0.01089337167130517, 0.10444425591932875, 0.13615308622164385, 0.10786840825208596, 0.15606134438088962, 0.20267843721168383, 0.09588837716728449, 0.13010191092533724, 0.1750693901308945, 0.13293655881924288, 0.15428745028163704, 0.15721634668963297, 0.19381102946187767, 0.13015330316764967, 0.13903418662292616, 0.1372732932546309, 0.22070834759090627, 0.19479775508599623, 0.15269753416734083, 0.29812052154115265, 0.20266103957380566, 0.07415608117090804, 0.15192784475428717, 0.19626714981028012, 0.20818313397467136, 0.27994482112782343, 0.13985843025147915, 0.14604771456548146, 0.1734172116432871, 0.20793913278196538, 0.12662203051149845, 0.21109312639704772, 0.25114117243460243, 0.32646925321647097, 0.2039869919951473, 0.23937743795769556, 0.2331101628286498, 0.09271165941442762, 0.22771893069148064, 9.831276297569275, 76.47191538129533, 88.76105526515416, 69.32560280391148, 74.73514366149902, 103.87176132202148, 97.52265725816999, 120.37549781799316, 75.78441197531563, 33.71340996878487, 49.19680002757481, 77.28743934631348, 24.653632981436594, 0.29853231087327003, 3.1986783487456183, 1.32977023933615, 0.9060828228081975, 1.3716638599123274, 2.2285797638552527, 2.698411524295807, 4.932891828673227, 3.9931683795792714, 4.72591324363436, 5.536497039454324, 6.97667361157281, 1.3653697690793445, 4.098525651863643, 2.8361330713544572, 4.266644699232919, 11.77235632283347, 11.415112955229622, 2.468025109597615, 0.1158516848725932, 0.17783898008721216, 0.5298665847097124, 0.1293309594371489, 0.264423956828458, 0.2735883593559265, 0.10853542853146791, 0.20077297517231532, 0.2816000665937151, 0.18260612285562924, 0.15656986566526548, 0.20065970053630217, 0.12303716715957437, 0.18446426386279718, 0.1627311943364995, 0.13556153939238616, 0.08838362379797868, 0.08545473417533295, 0.16708433574863843, 0.12668738700449467, 0.24057011253067426, 0.2709039662565504, 0.2702840023807117, 0.28336675465106964, 0.3742877330098833, 0.8627359430704797, 0.5728493896978242, 0.20597682307873452, 0.21615682968071528, 0.15739889975105012, 0.3101766231868948, 0.11468801088631153, 0.253662282867091, 0.1398421318403312, 0.1846908809883254, 0.18338846016143048, 0.3015365110976355, 0.19233634216444834, 0.10989350280059235, 0.2626942896417209, 0.43104588453258785, 0.3831179163285664, 0.2972392131175314, 0.1596010715833732, 0.323555162442582, 0.3173839950135776, 0.20481259269373758, 0.2904577984341553, 0.10056625865399837, 0.1880623043647834, 0.5577105677553585, 0.09576706867665052, 0.8416804586138044, 1.3659787135464805, 0.340324802590268, 1.4087841766221183, 1.0195587937320982, 0.8471060789057187, 0.4923116256083761, 5.679566962378366, 32.588871819632395, 47.19518034798758, 33.73812818527222, 41.03278827667236, 87.80564321790422, 95.83875438145229, 86.41126482827323, 44.56224387032645, 50.273016929626465, 71.23857389177594, 77.54590538569859, 64.19750567844936, 6.509175360202789, 0.9049637285726411, 0.20163087413779326, 0.23387090915015765, 0.12981639696019037, 0.1395100975143058, 0.24413643830588885, 0.27795006388000076, 0.1336986893521888, 0.22721682834838117, 0.13211102597415447, 0.09447589117501463, 0.12750707087772234, 0.1415900516190699, 0.12247548944183759, 0.18393951202077524, 0.15246381956551755, 0.2547999418207577, 0.1411496281091656, 0.19588604383170605, 0.11463452875614166, 0.13060565532318183, 0.18860754796436854, 0.21073688194155693, 0.11668803356587887, 0.2616418818277972, 0.1477602690990482, 0.16699480983827794, 0.20906379100467476, 0.28678722253867556, 0.20887275625552448, 0.12277807534805366, 0.12535359071833746, 0.1772250144609383], [0.1378374679812363, 0.0226326865210597, 0.09348902305854218, 0.03867073869332671, 0.057461860190544806, 0.10149754118174314, 0.033831318374723196, 0.01258689584210515, 0.02629046524608774, 0.03576024076236146, 0.02432122261130384, 0.024299385658066188, 0.03059111688552158, 0.10225220782948391, 0.029309058894536326, 0.23338985496333667, 0.06344910391739436, 0.03911178306277309, 0.0550534713880292, 0.06430838030896016, 0.037912146720503054, 0.11878827586770058, 0.10496281273663044, 0.0389021293127111, 0.026813127200252244, 0.015408827989761318, 0.04134496733812349, 0.04231109603175095, 0.09611717239022255, 0.12275723075228077, 0.02297385223209858, 0.029711355521742786, 0.07641821514282908, 0.05300836684182286, 0.07534935285470315, 0.0385083890120898, 0.15442473148661, 0.06539193288023983, 0.08059806549655539, 3.625876396894455, 37.58934095927647, 28.858258928571427, 30.853156226021902, 33.00604861123221, 36.3395163672311, 65.40885462079729, 95.83564853668213, 85.15198721204484, 32.87690591812134, 18.222621815545217, 40.37282405580793, 40.86680623463222, 13.29220267704555, 0.13610580590154442, 0.3949613650994641, 0.35014339429991587, 0.6296476562108312, 0.6422990773405347, 0.2564321442374161, 0.6493860770549092, 1.0597752928733826, 0.32369352930358475, 0.1618587611509221, 0.3511378009404455, 0.1968204951179879, 0.29168013855814934, 0.21554739666836603, 0.10204123772148575, 0.17446222342550755, 0.02557146070258958, 0.06740787399134465, 0.04431827386308994, 0.0375697375940425, 0.04816612721021686, 0.12096086357321058, 0.04913339923535075, 0.04709566697212202, 0.06661244774503366, 0.07287183829716273, 0.015876721989895617, 0.10911380499601364, 0.11270704825541802, 0.001571123768891474, 0.040245170638497384, 0.13115829495447023, 0.01617477528218712, 0.06623925348477704, 0.011450618555370187, 0.04572620349270957, 0.0492574218660593, 0.3195966434265886, 0.08025657239237002, 0.03272736564810787, 0.03247762065646904, 0.07414643240294286, 0.13315185798066004, 0.11331321751432759, 0.06166565604507923, 0.01710528088733554, 0.04062243610886591, 0.10811597175363984, 0.039784180732177835, 0.10854752681085042, 0.08257039716201169, 0.14889864729983465, 0.14488967241985456, 0.05957584282649415, 0.14788074977695942, 0.0440383578118469, 0.024673609595213617, 0.1126103230885097, 0.12219640798866749, 0.11164860147982836, 0.0445224179088005, 0.05436869723988431, 0.040279409515538385, 0.12464940707598414, 0.040635284169444015, 0.03637254058516451, 0.12123309182269232, 0.1582942809909582, 0.07820567994245461, 0.4094366069350924, 0.9436062978846687, 0.13190530772720063, 0.2522705261196409, 0.2713142899530274, 3.2705600687435696, 17.550315856933594, 37.35141726902553, 33.67362805775234, 29.406127861567906, 54.67325551169259, 82.10515349251884, 70.9626887185233, 44.21895769664219, 24.371397154671804, 26.972370181764873, 48.06169366836548, 63.19455405644008, 45.51411581039429, 1.1643675033535277, 0.34941489196249415, 0.058780335155980926, 0.15319639311305114, 0.04239854562495436, 0.13851115825985158, 0.011513295683211513, 0.07379112432577781, 0.016136534744873643, 0.03701049581702266, 0.03957576870119997, 0.037019537296146154, 0.09323358176542179, 0.15117285240973743, 0.06226390001497098, 0.02535106404684484, 0.022053014054628353, 0.09464849012770823, 0.06622337576534067, 0.05677953216114214, 0.05763682044510331, 0.04414297094834702, 0.07258345412888698, 0.04120833074141826, 0.042485072410532405, 0.10088866456810917, 0.039040777765746625, 0.11239516641944647, 0.05781144143215247, 0.01382026300832097, 0.022716159899053828, 0.04204591776111296, 0.06808179497186627, 0.04066770117995994, 0.058555712923407555, 0.05905308587742703, 0.04854620860091277, 0.18384292934622082, 0.03877327211999467, 0.03551967634952494, 0.06840814317443542, 0.02041034184263221, 0.04655023677540677, 0.060191545502415726, 0.021393827462036694, 0.02511774129899485, 0.08177519483225686, 0.03167005881134953, 0.05392099304922989, 0.03924392097230468, 0.04829686733761004, 0.02759472999189581, 0.11002647530819688, 0.05576883050213967, 0.02373082420256521, 0.07557911838271789, 0.02406994752319796, 0.11840881194387164, 0.040505398996174335, 0.035417645038770776, 0.05241371910752995, 0.04700111311727336, 0.08086024464241096, 0.01381392718758434, 0.03973566208566938, 0.0725894659491522, 0.05806831443416221, 0.05761655938944646, 0.10536601860076189, 0.11945644287126404, 0.11782508183802877, 0.11702781676181725, 0.06860420586807386, 0.4083832491721426, 18.246971777507238, 42.7959040914263, 41.822520528520855, 53.43693821770804, 63.664683069501606, 61.179437501089915, 91.09111281803676, 81.57638168334961, 42.23865509033203, 34.15498883383614, 54.00113889149257, 58.65636593954903, 18.686683314187185, 3.921579352446965, 0.4672770489539419, 0.3227832338639668, 0.19856698997318745, 0.4596705628292901, 0.4099179596773216, 0.43438780520643505, 0.7915874208722795, 1.1348016155617577, 0.45145388373306816, 0.4239383930606501, 0.27943700551986694, 0.8222373362098421, 0.38351534785968916, 0.08859432249196939, 0.45657144912651604, 0.04915142451812114, 0.012302615962523435, 0.020664858631789684, 0.08406998669462544, 0.0549663678476853, 0.04187837389430829, 0.13536465567137512, 0.05533101935205715, 0.0062817694852128625, 0.006841353074248348, 0.09702423800315176, 0.10427721416843788, 0.08648386145276682, 0.06057185080966779, 0.038807239583028216, 0.07862455996551684, 0.13608276285231113, 0.025434584922290275, 0.025497035589069128, 0.06304699049464293, 0.04339539499155112, 0.08987866714596748, 0.1853798518755606, 0.22144982351788453, 0.044388305462364636, 0.08558312657156161, 0.05112908946882401, 0.13704811462334224, 0.05862106941640377, 0.05916514593575682, 0.021693259876753603, 0.12308873582099165, 0.016689635779974715, 0.07116949571562664, 0.1676625290087291, 0.07144516413765294, 0.0781276687713606, 0.1949731699590172, 0.059466401913336346, 0.06496826239994594, 0.06320928928575345, 0.06979968279067959, 0.11819351278245449, 0.1546106229403189, 0.1226911007293633, 0.09061808032648903, 0.02385052795788007, 0.08046296238899231, 0.22463022571589264, 0.0511419443147523, 0.057100621717316766, 0.0590141922501581, 0.09622763110590832, 0.017723304153020893, 0.5236947387456894, 0.8770885329161371, 0.11945625288145882, 0.1948470710111516, 0.5379304577197347, 2.363724614892687, 18.246080671037944, 43.75471380778721, 55.51038490022932, 31.41251400538853, 29.57094955444336, 57.437783922467915, 79.51577527182442, 64.19205829075405, 50.76695047106062, 35.36013650894165, 54.99489457266671, 69.8712100982666, 66.24499389103481, 10.054418563842773, 0.6352571323513985, 0.15938308542328222, 0.14124650933912822, 0.08387196303478309, 0.08781978833888258, 0.030333813013775007, 0.07454876295690026, 0.09827464233551707, 0.04979699969823871, 0.07731223931269986, 0.08727584752653327, 0.10671764678720917, 0.13391626839126858, 0.024608217479128922, 0.026374299943979298, 0.03725006278338177, 0.05850672948041132, 0.07354679743626288, 0.03897776900391493, 0.0824281151539513, 0.09516581879662615, 0.04906011406066162, 0.014679840499801295, 0.017576418284858977, 0.010042538799877678, 0.036500851557190926, 0.03787932258897594, 0.022446238668635488, 0.030255778093955348, 0.12267126036541802, 0.07135557715914079, 0.029911238367536237, 0.03968418841915471, 0.024448900849425366, 0.18867842773241655, 0.13989026711455413, 0.2415414218391691, 0.22298601322940417, 0.07273913041821548, 0.21339448647839682, 0.12133636485253062, 0.14383201274488652, 0.1689251876835312, 0.09151936482105937, 0.15924751412655624, 0.22977760593805993, 0.0972612706412162, 0.14991581200488976, 0.1537292602338961, 0.2130676225892135, 0.16088532124246868, 0.16322576494089194, 0.13408614641853742, 0.12213371135294437, 0.1621247333075319, 0.2740705263401781, 0.15423444312598023, 0.12259841284581594, 0.10365789490086691, 0.12332766157175813, 0.07518161221274308, 0.14412775901811464, 0.23868815494435175, 0.2102816527975457, 0.19407435533191475, 0.09493802780551569, 0.11433917603322438, 0.21050609861101421, 0.15901647295270646, 0.2543499102549893, 0.40729124205453054, 0.18512123503855296, 0.1945944388530084, 12.231851986476354, 60.53338704790388, 71.52151148659843, 79.21600219181606, 69.57938575744629, 62.10007381439209, 90.29852485656738, 121.03602136884416, 110.80333287375313, 56.99158797945295, 39.80271046502249, 70.74650246756417, 63.519014086042134, 20.954260928290232, 0.48232809560639517, 1.1734342511211122, 1.251976905124528, 1.1026850874934877, 0.7774083731429917, 0.5790868635688509, 1.239118177975927, 2.459733520235334, 2.201563213552747, 0.9141501699175153, 1.4064774832555225, 1.6972297387463706, 0.6606475327696119, 0.5837185436061451, 1.0132755594594138, 0.9510698573929923, 0.2676713168621063, 0.1532371323555708, 0.23014037790043013, 0.10665683647883789, 0.1880624129303864, 0.24704681070787565, 0.2127366332071168, 0.15585525972502573, 0.13337140477129392, 0.14377402514219284, 0.22809877459492, 0.1422445529273578, 0.16472990065813065, 0.11142348391669137, 0.1138798078255994, 0.24256315987024987, 0.23328408492462976, 0.16319263886128152, 0.16827800098274434, 0.14918983381773743, 0.3240572783563818, 0.9420381763151714, 0.2860446609556675, 0.18252940768642084, 0.3678144003663744, 0.16670788452029228, 0.21326887607574463, 0.22519653104245663, 0.11085831852895872, 0.18911582497613771, 0.20661037122564657, 0.14907871692308358, 0.18142756181103842, 0.2384669796696731, 0.19069035191621098, 0.2214122733899525, 0.29004030940788134, 0.14844246820679732, 0.1805649809539318, 0.15757453175527708, 0.1590038522013596, 0.14046513555305346, 0.1592436736183507, 0.18817814386316709, 0.17675674387386867, 0.1912924431796585, 0.2435269510107381, 0.2698051195059504, 0.12352625520101615, 0.0971067478614194, 0.36984273152691977, 0.2371173735175814, 0.17003718444279262, 0.8508531121270997, 3.481097434248243, 0.3509141829396997, 0.34215071318405016, 1.1476438407387053, 6.1385562760489325, 32.1302490234375, 55.54054703031267, 55.24736431666783, 44.152168137686594, 70.21532658168248, 99.57815674373082, 92.66482421330043, 63.05149064745222, 45.59705993107387, 49.47290406908308, 70.69842788151333, 84.26548045022147, 73.14037922450474, 5.122818665845053, 0.5973173624702862, 0.19231669179030828, 0.3104851666305746, 0.22154958173632622, 0.1941936146467924, 0.09284610434302262, 0.26170197288904873, 0.22552228213420936, 0.20559606993837015, 0.23380430415272713, 0.1623210877712284, 0.23659704572388104, 0.4212590754032135, 0.1451984058533396, 0.15828155167400837, 0.1773802497025047, 0.19307834734874113, 0.231089892664126, 0.1364861519208976, 0.20982270528163227, 0.15618472918868065, 0.14684769378176757, 0.15728044110749448, 0.12594658961253508, 0.14061817234115942, 0.11100058018096856, 0.12946665287017822, 0.11992563626595906, 0.10140687533255134, 0.17812319126512322, 0.2443064520401614, 0.13030743918248586, 0.24772862983601435, 0.18919543070452555], [0.03511253158961024, 0.05148039758205414, 0.05285868201670902, 0.09881118033081293, 0.061991868540644646, 0.06184657383710146, 0.05691084225795098, 0.06524211913347244, 0.04713544948026538, 0.06863404105284385, 0.09181168449244329, 0.04392996523529291, 0.014244940264948776, 0.009831639089887696, 0.012945334510212498, 0.07413704147828476, 0.05145514929401023, 0.017115955939516425, 0.10049985043172326, 0.023154515573488813, 0.05783470839794193, 0.050876525164182694, 0.05448736962197082, 0.012814606257182146, 0.07441975309380464, 0.02712478511966765, 0.020335434969248514, 0.018335274886339903, 0.06152614924524512, 0.09909912345132657, 0.04692027584782668, 0.03622763943193214, 0.028514891330684935, 0.03292842575215867, 0.03573384914281113, 0.1637985570622342, 0.028719164298049042, 0.1713342855551413, 0.05803001791770969, 0.3725833616086415, 13.271671618734088, 43.84499175207955, 34.361294746398926, 44.28650113514492, 32.75121300561087, 32.875290461948936, 54.96103947503226, 92.145891053336, 103.19924518040249, 72.00708634512765, 38.743617398398264, 36.96734169551304, 40.716732093266074, 39.53456211090088, 14.607863187789917, 1.0078543360744203, 0.1937403261129345, 0.5121760911175183, 0.381485822477511, 0.38131741008588244, 0.3017886004277638, 0.15806953662208148, 0.3068196933184351, 0.053076691925525665, 0.3094777049762862, 0.015578090246500713, 0.10451339185237885, 0.08400220104626246, 0.375176586742912, 0.023466829975534762, 0.04280028585344553, 0.09421051612922124, 0.029230952728539705, 0.05471142188512853, 0.03452350212527173, 0.07002005060868603, 0.08666218045566763, 0.07496773118951491, 0.07049191064600434, 0.06664769763925246, 0.04688027281580227, 0.04080935554312808, 0.057516054782484255, 0.02610105898098222, 0.020000325183251073, 0.04721611033060721, 0.01457530539482832, 0.018356781053755964, 0.0810298105435712, 0.048003587539174726, 0.05424140067771077, 0.1884135819439377, 0.054028642629938464, 0.04950386578483241, 0.01392499149577426, 0.08338113794369356, 0.09744326730391809, 0.05063811849270548, 0.035141016489693096, 0.026082592650449703, 0.04256912932864257, 0.031123217261795486, 0.10674225725233555, 0.07034724698002849, 0.006498575842540179, 0.11191514360585383, 0.031525208548243554, 0.10883262686963592, 0.05783504766545125, 0.29835936586771694, 0.03159408663798656, 0.1649607518421752, 0.08693949093243905, 0.08286635378109557, 0.09181964370821204, 0.009169128523873431, 0.04041167973939862, 0.04181153140962124, 0.12401889876595565, 0.05274323267596109, 0.08297213060515267, 0.17843759725136416, 0.5933013579675129, 0.13069205997245653, 0.24937166167157038, 2.693447470664978, 21.680120127541677, 49.352804456438335, 53.404038497379844, 38.65185601370675, 51.348104749407085, 71.70449229649135, 81.1220737184797, 58.56488595690046, 35.013925143650596, 23.14378595352173, 29.175204481397355, 51.47080646242414, 61.3191032409668, 42.7466378893171, 1.1096287263291222, 0.3575579635798931, 0.018822374820177044, 0.11840159233127322, 0.04179820837453008, 0.09719011945916073, 0.05537827931610601, 0.06653949844517879, 0.007204935037797051, 0.08064402267336845, 0.034947182783590894, 0.02975376396040831, 0.03762151999399066, 0.055362740864178965, 0.08387020562908479, 0.026495767890342643, 0.14436801469751767, 0.04415819727416549, 0.03010462424052613, 0.018789325075756227, 0.016225578895370876, 0.04500637961817639, 0.03997384823326554, 0.038688926824501584, 0.03868766814204199, 0.018183674896135926, 0.06290331748979432, 0.0994634831856404, 0.06524458900094032, 0.03638999929119434, 0.027668384968170097, 0.0343829978789602, 0.0056790124092783245, 0.02871328479211245, 0.02376889340978648, 0.021832515618630817, 0.021390958955245357, 0.05062416102737188, 0.07059837957578045, 0.06616232118436269, 0.019343508374212042, 0.0652443515136838, 0.059334996821624894, 0.015151434212124773, 0.0740421890680279, 0.015970829707969512, 0.008986516938810902, 0.05585322329508407, 0.07264532973723752, 0.03266922537503498, 0.018907615781894753, 0.1004162888441767, 0.008465481772353607, 0.03853504865297249, 0.09585210268518754, 0.11391579732298851, 0.02274307399056852, 0.03547452662938407, 0.037020361716193814, 0.052011015359312296, 0.018592996057122946, 0.05829097570053168, 0.021508058832426156, 0.09696148708462715, 0.11056888263140406, 0.06042118889412709, 0.03356958706197994, 0.051836194204432626, 0.027230690865378295, 0.02725530811585486, 0.09753710191164698, 0.08351588821304695, 0.0028183463021248046, 0.10338462849280664, 0.0481457745523325, 0.28341930040291374, 27.14787299292428, 36.989176409585134, 61.201407705034526, 63.411789485386436, 54.31091390337263, 59.5867714200701, 87.98212051391602, 108.35760865892682, 72.32425076620919, 40.208335876464844, 49.273362227848594, 65.96559987749372, 53.13725199018206, 22.267433983939036, 4.737130241734641, 0.3842024052781718, 0.26556405850819176, 0.42355930911643164, 0.6240907801049096, 0.5168456605502537, 0.4501150798584734, 0.368964571505785, 0.34122141876391, 0.06261130994451897, 0.9759237808840615, 0.032859442489487786, 0.2393032605094569, 0.10425327545297997, 0.44646605423518587, 0.10012118039386612, 0.07959057670086622, 0.11325283468301807, 0.032096032918031724, 0.02494763596249478, 0.07105079958481447, 0.11717195117047854, 0.05014024681544729, 0.08431343827396631, 0.0664109228444951, 0.05650445067190698, 0.10198489217353718, 0.046861769165843725, 0.04512032261118293, 0.014791870024055243, 0.04796528084469693, 0.03788662701845169, 0.030228904714541774, 0.06329787881778819, 0.07328321372291871, 0.1004958131483623, 0.06679132314664976, 0.026343826936291795, 0.11540204685713563, 0.04301492344321949, 0.02874670603445598, 0.06880883845899786, 0.028662221639284065, 0.00565156397143645, 0.021995616777400886, 0.06908919555800301, 0.11344623751938343, 0.01023269654251635, 0.06089360533016069, 0.028075794356742075, 0.031654798558780124, 0.13418913446366787, 0.0639740593199219, 0.10471535101532936, 0.016016244056767652, 0.5474733742220061, 0.17068304121494293, 0.1882522805993046, 0.015511549709896957, 0.09876232580947024, 0.03712075775755303, 0.021999347023665905, 0.0517897179483303, 0.046168051926153045, 0.04708035922210131, 0.08728494668113333, 0.05384721254397716, 0.12506567473922456, 0.48738155301128117, 0.19032950699329376, 0.6238550298980304, 3.073642692395619, 23.295124667031423, 45.840305941445486, 54.45640570776803, 50.854806968144004, 42.54502548490252, 54.35248497554234, 75.29188891819545, 79.27493681226457, 60.20492485591343, 41.14176034927368, 35.55401904242379, 52.786472184317454, 66.06925310407365, 65.59756074632917, 8.83016768523625, 0.20076880896730082, 0.15438654353576048, 0.08712907361664943, 0.12616328655609063, 0.02862024067768029, 0.0893709058208125, 0.061230077275208065, 0.057858104285384925, 0.04097438883036375, 0.05850895507527249, 0.0009503585856042004, 0.04515923659450241, 0.06771912478974887, 0.08125948107668332, 0.06906360121709959, 0.1108788170718721, 0.012157368756431555, 0.0697685991014753, 0.07083454368902103, 0.03389569438461747, 0.036259727352964025, 0.0933642608246633, 0.0186577316905771, 0.04022697911464742, 0.055640187047954114, 0.008033227824073817, 0.06226758446012225, 0.15650426489966257, 0.05617202279557075, 0.04276745154389313, 0.03702671280396836, 0.04066861041688493, 0.01913933888343828, 0.0397122085227498, 0.0762567984472428, 0.15006977160062107, 0.11049296134816748, 0.13225191698542663, 0.2024204989096948, 0.22121430401291164, 0.18534574870552334, 0.14558282308280468, 0.19557253351168974, 0.18767686933279037, 0.16616038818444523, 0.12203611087586198, 0.17426215058990888, 0.15107215781297, 0.0946183360314795, 0.1215880877737488, 0.2843136909816946, 0.15687763557902404, 0.142142243417246, 0.2839037744062287, 0.13029450630503042, 0.14240076525935105, 0.12156269699335098, 0.15642529699419225, 0.1635865962931088, 0.1718780499483858, 0.1757322917027133, 0.09354494791477919, 0.20779806535158837, 0.16448299533554486, 0.1693014217806714, 0.16562541760504246, 0.20390878404889787, 0.09298436263842241, 0.07277819367923907, 0.25285064641918453, 0.2438853532075882, 0.17488693206437997, 0.3500244878232479, 0.0669814758002758, 0.2755188729081835, 20.452774694987706, 54.81481116158621, 90.13863985879081, 92.89105755942208, 68.21077823638916, 56.94505589348929, 81.5755478995187, 123.58884511675153, 127.46132632664272, 96.4585267475673, 56.250993388039724, 56.35683182307652, 59.37544195992606, 54.695840631212505, 23.85593809400286, 1.8876292705535889, 0.7951589577964374, 1.735809502857072, 2.493939284767423, 2.196241110563278, 1.5100599250623157, 0.7428544387221336, 0.6186837245311055, 0.16438415992472852, 1.131659944142614, 0.11658583262137004, 0.6262806568826947, 0.14171300216444901, 1.0164021402597427, 0.12316151548709188, 0.1925833967647382, 0.2106209203068699, 0.048200559469738176, 0.18142403342894145, 0.1220082366572959, 0.1667279148740428, 0.1824495576854263, 0.17367509566247463, 0.21184659882315568, 0.23636780945318087, 0.3083256882216249, 0.18151319293039186, 0.26588427275419235, 0.10608157449002777, 0.10832461448652403, 0.11355875219617571, 0.12205152719148568, 0.1357137890798705, 0.24071282201579638, 0.18156507371791772, 0.2586011492780277, 0.3527148520307881, 0.20341531267123564, 0.0956155653776867, 0.13797630981675216, 0.2405000062925475, 0.15689330973795482, 0.1660936881921121, 0.09055240492203406, 0.15415134972759656, 0.21399245224893093, 0.09726939270538942, 0.24813330812113626, 0.11645807804805891, 0.12660882622003555, 0.16551001236907073, 0.1226203702390194, 0.20914361386426858, 0.3370313293167523, 0.6866733133792877, 0.12940939808530466, 0.30671948726688114, 0.22083291304962976, 0.2845137231051922, 0.19768832783613885, 0.06433922651090793, 0.2834081995700087, 0.12369516970855848, 0.2415572724172047, 0.13989817883287156, 0.1457126268318721, 0.48960437944957186, 1.5464127915246146, 0.15713110912059033, 1.8551675038678306, 3.608663320541382, 34.38038839612688, 62.05712699890137, 65.91678183419364, 56.47061204910278, 64.20181356157575, 86.82446725027901, 95.53567395891461, 80.34368787493024, 52.38566187449864, 44.96158811024257, 51.26782178878784, 67.7408368246896, 81.61722319466728, 68.68746634892055, 3.823637979371207, 0.4497684027467455, 0.14163216150232724, 0.2982752003840038, 0.15320144141358988, 0.2027137888861554, 0.2163552197494677, 0.188808231481484, 0.1442483211202281, 0.17604838045580046, 0.12824030938957418, 0.08485884472195591, 0.1581300212336438, 0.15806693104760988, 0.2038678683872734, 0.09554129971989564, 0.1922874197896038, 0.08854168853057282, 0.223181797723685, 0.12036709114909172, 0.06407963936882359, 0.15857842431536742, 0.1314311203147684, 0.18216989269214018, 0.08558620712054626, 0.17746828283582414, 0.10557493953300373, 0.1538387622152056, 0.2379496374300548, 0.23522398940154485, 0.15262628799038275, 0.058042842229562144, 0.1526276043483189, 0.14455189768757137, 0.10870330488043171, 0.24314224879656518], [0.04074494560648288, 0.03742789324106915, 0.048799258058092425, 0.07896225327359778, 0.043433884890483956, 0.048735533441816054, 0.14772512098508223, 0.03683746260191713, 0.06430980523249932, 0.04503438275839601, 0.028337708873940364, 0.051379312827650986, 0.03334737702139786, 0.02793687448969909, 0.056518096011132, 0.05959291476756334, 0.05429722375369497, 0.044028108540390215, 0.028518555419785634, 0.07846154192728655, 0.043039717112800906, 0.01116314362401941, 0.09227217906819922, 0.025538183648937514, 0.04529661957972816, 0.026660087019471184, 0.019227478886023164, 0.011076673665749175, 0.0358620820833104, 0.03164712093504412, 0.07619089234088149, 0.10503190795757941, 0.06310511380434036, 0.1291487863553422, 0.029150773638061116, 0.021607511710109453, 0.14835420437157154, 0.08726401387580804, 0.07879851598824773, 0.05843721356775079, 0.026353616500273347, 10.506389328411647, 28.209455251693726, 67.21210670471191, 67.00639833722795, 51.392086846487864, 30.42715174811227, 52.42209127971104, 85.45207296098981, 103.88595649174282, 103.8629093170166, 76.85048798152378, 43.877120222364155, 40.102751050676616, 44.35463864462716, 46.63668761934553, 20.843692507062638, 3.6903406977653503, 0.08576828520745039, 0.21168012704168046, 1.2264242534126555, 0.5684112278478486, 0.10178227483161859, 0.10698322539350816, 0.3027986133737223, 0.44871431216597557, 0.017072704421090226, 0.034194789228162596, 0.2700181523604052, 0.010005937772803009, 0.04849301824080093, 0.0545511383430234, 0.0459577739238739, 0.10071037270660911, 0.018885860252859335, 0.10194307406033788, 0.06004043575376272, 0.04048698016309312, 0.009929107252641447, 0.02820213757721441, 0.08020281884819269, 0.08141474345965044, 0.027014350152707527, 0.07606699184647628, 0.07737613017005579, 0.057970951444336345, 0.05141703937468784, 0.06274057765092168, 0.04645660912085857, 0.041678640326218944, 0.06095968107027667, 0.47042528859206606, 0.07769002046968256, 0.04705854432125177, 0.11088596204561846, 0.04770281332145844, 0.05177121769104685, 0.04993852174707821, 0.14044726294066223, 0.00964652031793126, 0.03753392790843334, 0.04868339481098311, 0.0380735294893384, 0.023989191677953516, 0.07259514528725829, 0.0902578935825399, 0.08916427155158349, 0.09959649640534605, 0.143706171640328, 0.6112103941185134, 0.3652004934847355, 0.03396455890366009, 0.10622422290699822, 0.11956561915576458, 0.02316353839289929, 0.08171680689390216, 0.009270561027473636, 0.07778766165886607, 0.07164113862173897, 0.03795802925846406, 0.02596683118359319, 0.352124635130167, 0.6935837311404092, 0.1852856305028711, 7.391306059701102, 24.744656120027813, 32.66067450387137, 48.356943471091135, 53.33096776689802, 63.41286645616804, 75.82815088544572, 64.85456902640206, 44.15868207386562, 19.86635368210929, 27.90145203045436, 45.7462933404105, 61.867545400347026, 71.30952194758824, 21.931165490831646, 0.19407565811915056, 0.10204409435391426, 0.02970759304506438, 0.04566630581393838, 0.07361354492604733, 0.05289298874725189, 0.05086810454460127, 0.040870189600225, 0.015511186693661978, 0.0560548194417996, 0.021549703919195702, 0.03551308438181877, 0.016680177001814758, 0.04405986397926297, 0.018356061806636195, 0.018297633156180382, 0.08090567256190948, 0.02235632768965193, 0.01785961674925472, 0.01891288290997701, 0.028210950050769106, 0.041098859294184616, 0.08771614890013422, 0.016119946260005236, 0.04565144589702998, 0.02154412805767996, 0.07352376117237977, 0.010932598628902009, 0.13361905648240022, 0.05635460299838867, 0.06996194765503917, 0.0719106188043952, 0.02960066610415067, 0.0780154187232256, 0.05555698508396745, 0.07829462909804923, 0.016373480869723216, 0.01816067934435393, 0.005724353815561959, 0.005044008804751294, 0.0319466907531023, 0.04451372926788671, 0.030330569616385868, 0.15818593251918042, 0.040646242509995184, 0.021010768998946463, 0.005181830293232841, 0.049199298556361876, 0.04958482179790735, 0.055008732181574614, 0.013658581684077424, 0.04416545420618994, 0.042420977992670875, 0.024483115977740715, 0.043087791318872144, 0.06639417660023485, 0.04853622395811336, 0.08256374073347875, 0.03161041897588542, 0.06446335092186928, 0.01569404679217509, 0.03659826543714319, 0.01190476628419544, 0.012723145673849752, 0.023498773707875183, 0.06772951316088438, 0.0409648757694023, 0.0577322563954762, 0.04195573706445949, 0.05583992740139365, 0.02120200221958969, 0.094300998773958, 0.10671977060181753, 0.09105176598365818, 0.0824973935793553, 0.052441623860171864, 0.06529361315603767, 0.30405990140778677, 25.510778393064225, 51.374104908534456, 79.71717575618199, 67.39951351710728, 62.24203940800258, 55.44879954201834, 78.80672550201416, 104.55337265559605, 98.94127791268485, 70.47955962589809, 53.098463671548025, 53.34806728363037, 64.23629052298409, 53.69177034923008, 30.32491942814418, 6.773645945957728, 0.15575328948242323, 0.027083911866481816, 0.43538663589528626, 0.3419850149324962, 0.19497365850423062, 0.10482931097171136, 0.08000634224819285, 1.2065017053059168, 0.10933120083063841, 0.07803648723555462, 0.16021673354719365, 0.14951445854135922, 0.07026561921728508, 0.06148742525173085, 0.15440995299390384, 0.022995276975312402, 0.0556238309613296, 0.04560366685369185, 0.0030728501567084876, 0.07084191257932357, 0.06934306264988013, 0.08072233918522086, 0.02683581062592566, 0.0926503741315433, 0.024445423357454792, 0.010445508024921375, 0.043424958762313635, 0.09767563162105423, 0.07346174985702549, 0.06631419089223657, 0.029869074201477424, 0.06295727459447724, 0.0922370513102838, 0.08962214019681726, 0.2750798064683165, 0.0944305243236678, 0.029223295460854257, 0.07093772172395672, 0.07154798254902874, 0.11406396222966057, 0.06993456876703671, 0.04284298945484417, 0.03165283080722604, 0.05852944004748549, 0.010171702181521271, 0.03176394770187991, 0.09423114359378815, 0.11870294330375535, 0.08656817621418408, 0.05267402210405894, 0.0854675652725356, 0.12412206323019095, 0.24830204620957375, 0.3763628016625132, 0.1791693972689765, 0.0937980618327856, 0.033669776150158474, 0.05921817344746419, 0.07312629571450607, 0.056701120654387135, 0.07322860522461788, 0.08275347948074341, 0.10234174731054477, 0.1740985150848116, 0.2993719301053456, 0.5467221002493585, 0.8696812646729606, 11.253692405564443, 34.38148273740496, 46.051083019801546, 66.51466042654855, 65.82475294385637, 56.3773637499128, 74.02296720232282, 81.16802910396031, 71.62418501717704, 41.24941921234131, 36.362330777304514, 43.39765977859497, 56.98460503986904, 80.49523503439767, 48.966811180114746, 3.733000031539372, 0.17126489856413432, 0.01822869060561061, 0.023753763775208166, 0.0314810562745801, 0.09065805282443762, 0.03329796949401498, 0.041030893834041696, 0.03900591802916356, 0.03228044516539999, 0.026265176245942712, 0.04791271134412714, 0.022301539379571165, 0.030562730373016427, 0.030381232433553253, 0.06767972226121596, 0.021056889024163996, 0.010525159554422965, 0.014917544887534209, 0.01570812809014959, 0.029138322520468916, 0.04798753000795841, 0.03480165059279118, 0.0031399704166688025, 0.06046392981495176, 0.06035156441586358, 0.058544340676495006, 0.028039236586274843, 0.03939058631658554, 0.07533073385379144, 0.03447558737492987, 0.05465815010081444, 0.09543047459529978, 0.06553688831627369, 0.04199497674458793, 0.02193790058871465, 0.02354498703165778, 0.07266208955219813, 0.1106348294498665, 0.08157407026737928, 0.11926034625087466, 0.1408993165407862, 0.13131262095911161, 0.2759837508201599, 0.14758663198777608, 0.12930985699806893, 0.14152939058840275, 0.09770900197327137, 0.12322372357760157, 0.1249774516160999, 0.10444050362067563, 0.09839789143630437, 0.21622362466795103, 0.1355142726429871, 0.13983236093606266, 0.14363742247223854, 0.1687510891684464, 0.11148955965680735, 0.09878648844148431, 0.19876715780368873, 0.11322142529700484, 0.1809652080493314, 0.09472067268299204, 0.20165737771562167, 0.14448388133730206, 0.20333790539630822, 0.15189581790140697, 0.18375744750457151, 0.1549803838133812, 0.15606161579489708, 0.18576141925794737, 0.23290475670780453, 0.18388398071484907, 0.3247630904827799, 0.27105880794780596, 0.12358576272215162, 0.12340540811419487, 0.08847429643252067, 17.001456805637904, 64.53450025830949, 101.489196232387, 100.4032483782087, 87.39636652810233, 57.25536591666085, 75.44922392708915, 111.45415673937116, 123.52226747785295, 124.01470020839146, 95.44636181422642, 59.04612513950893, 59.94679233006069, 62.13281372615269, 67.84501116616386, 29.41929817199707, 6.235038961683001, 0.11198542626308543, 1.5316906443664005, 3.37958316717829, 1.3518623624529158, 0.20638596612427915, 0.3325257753687245, 1.6040580868721008, 1.1127011328935623, 0.16225252859294415, 0.2155719596360411, 0.40833149052092005, 0.11559940555265971, 0.18360263295471668, 0.2287166214415005, 0.10292792014245476, 0.1851844202194895, 0.15790682392460959, 0.21560402720102242, 0.19029914933655942, 0.14137997717729636, 0.13174190292400972, 0.11715980539364473, 0.13017749972641468, 0.16961650630193098, 0.08236005130623068, 0.16588878418718064, 0.22821613401174545, 0.22735704082463468, 0.2048290946653911, 0.35821399837732315, 0.19286108043576988, 0.22066264147205011, 0.14975681767932006, 0.9488585931914193, 0.22789323276707105, 0.16183723802013056, 0.21248641663364, 0.07563500931220395, 0.26657792553305626, 0.13638933854443686, 0.16693060685481342, 0.14638652067099298, 0.22881251201033592, 0.124289620667696, 0.16304669954947063, 0.18464079153324875, 0.34343148874385016, 0.15842458685593946, 0.16083296548042977, 0.16095613315701485, 0.22696205201957906, 0.6598762284432138, 1.7855550221034457, 0.3461942933499813, 0.19823769692863735, 0.15663041813032968, 0.08652113338134118, 0.23357096953051432, 0.2093829603067466, 0.1761926505714655, 0.1324561967381409, 0.14761608040758542, 0.45035017867173466, 0.6407338327595166, 0.7362174977149282, 1.5510299780539103, 12.987194997923714, 42.37686518260411, 45.501362391880576, 70.1275360924857, 74.56217520577567, 78.06182302747453, 90.42541980743408, 83.07871423448834, 64.896119253976, 35.6797536441258, 46.69807842799595, 62.65825734819685, 76.29500729697091, 97.17824895041329, 40.42386899675642, 1.1613836863211222, 0.26843708434275215, 0.12157892755099706, 0.19627533294260502, 0.09525511400508029, 0.15035206930977957, 0.22939398937991687, 0.19725720025599003, 0.1708451160894973, 0.1667946284370763, 0.11638447056923594, 0.16270690278283187, 0.13468645992023603, 0.09829118501927171, 0.09545360585408551, 0.18642342516354152, 0.2074815830481904, 0.14783319804285253, 0.09024214478475706, 0.1137249797050442, 0.1457515476005418, 0.2099968037967171, 0.22335700903620037, 0.1555190049111843, 0.1461405652974333, 0.17443030513823032, 0.15508808089154108, 0.10998789380703654, 0.1619112797613655, 0.1072848749213985, 0.14059573997344288, 0.215269482295428, 0.13499109500220843, 0.21898584573396615, 0.1706961640822036, 0.1644019511129175, 0.0632030399782317], [0.0632371770750199, 0.04295737688828792, 0.03827219097209828, 0.06792535872331687, 0.043096547813287804, 0.06898424654666867, 0.019943214587068984, 0.010244729512903308, 0.04495773544268949, 0.07989914728594677, 0.02368543529883027, 0.08599838321762425, 0.015073748737839716, 0.06105810257473162, 0.0884240712704403, 0.016269113702167357, 0.05426452515114631, 0.02533010918913143, 0.05385675274633935, 0.025939652463421226, 0.050573369288550954, 0.046415795239486864, 0.07169225266469376, 0.014410251751542091, 0.055614429858646224, 0.03256175560610635, 0.04996916438852038, 0.04993176353829248, 0.06890745673860822, 0.033548521942326, 0.06699064959372793, 0.047007800079882145, 0.03312870893361313, 0.04717092329104032, 0.09584436738597495, 0.02752899351928915, 0.05743678832160575, 0.13230827610407556, 0.14731718573187078, 0.0247540940264506, 0.07474279683083296, 0.09561829987381186, 3.135250849383218, 51.598337173461914, 80.84008802686418, 75.95993041992188, 60.391463143484934, 43.768874236515586, 53.310939584459575, 71.5351369040353, 96.32953344072614, 105.04472146715436, 103.41502148764474, 74.68096160888672, 54.68092284883772, 58.02620949063982, 60.29563358851841, 38.95899418422154, 19.382726056235178, 4.644108193261283, 0.6946157014795712, 0.21805511281958648, 0.06395089413438525, 0.05247241238664303, 0.25687731749245096, 0.1218291169830731, 0.05292951089463063, 0.16089172661304474, 0.047396692247795205, 0.0489244240203074, 0.01775331236422062, 0.07193644384720496, 0.04604337790182658, 0.027729196972878914, 0.12036304708038058, 0.061552591754921844, 0.03321796003729105, 0.020181176818108985, 0.06385692381965262, 0.07658255632434573, 0.014006548012340707, 0.035529572782771926, 0.020210710054795657, 0.0686848701110908, 0.04316854716411658, 0.030749164654740264, 0.09529434011450835, 0.06002650542982987, 0.02381214323187513, 0.07938403742653982, 0.010473070965547646, 0.16982469441635267, 0.02784923490669046, 0.0056317825552209145, 0.06590255083782331, 0.04567505552300385, 0.02499024965800345, 0.03618593666968601, 0.04925006654645715, 0.05279837382425155, 0.031209822078900676, 0.07060768229088613, 0.021586606046184897, 0.12885366433433124, 0.01721256914814668, 0.1950834183288472, 0.05201777356809803, 0.06929610124123947, 0.11980245501867362, 0.0507951959568475, 0.36479662944163593, 0.2901449666491577, 0.12796626266624245, 0.07438630131738526, 0.03363195460821901, 0.13418027279632433, 0.07432258687913418, 0.08309721853584051, 0.2726341491299016, 0.310130129967417, 0.5628078313810485, 1.1703867060797555, 1.213883406349591, 12.758958833558218, 27.566698244639806, 46.26711641039167, 57.70944111687796, 65.38939271654401, 71.92429855891636, 65.52346515655518, 44.38666984013149, 20.178850650787354, 25.278465373175486, 34.350900241306846, 57.97400420052664, 70.3277553830828, 61.2276371547154, 7.168785222939082, 0.3847876281610557, 0.060314584257347245, 0.05668249147545014, 0.14420284570327827, 0.20313876893903526, 0.10175332174237285, 0.08888575328247887, 0.03725628155682768, 0.02470806390712304, 0.06885774726314203, 0.09004163090139627, 0.005718439110621277, 0.04821548045479825, 0.047221141667770486, 0.023230267222970724, 0.057882579043507576, 0.0563690931137119, 0.057450128320072374, 0.04540803163711514, 0.032250355529998026, 0.029114336307559694, 0.014882820857954877, 0.012154143170586653, 0.01237765430206699, 0.02110149252361485, 0.06449922506830522, 0.0681917244302375, 0.00437714416433924, 0.03117671635534082, 0.044299034002636156, 0.03872848541608878, 0.0340153099303799, 0.03409184189513326, 0.0383882001042366, 0.03653114814577358, 0.013947048972892975, 0.0096455466201795, 0.051397904687161954, 0.06703570431896619, 0.06289851346186229, 0.04391487461647817, 0.06456757390073367, 0.04667210845010621, 0.021521217322775295, 0.036558862908610275, 0.034053172184420485, 0.02842359783660088, 0.002649292058777064, 0.013683828275783785, 0.03255497704127005, 0.019049380407003418, 0.0795916894982968, 0.09923335803406579, 0.01614528275760157, 0.0493760026459183, 0.0574297858402133, 0.02562486649756985, 0.04446999768593481, 0.0348239811802549, 0.04842015375782337, 0.020823705375992825, 0.03171490997608219, 0.09256131641034569, 0.05063431191125086, 0.06328696118933813, 0.043596394027450254, 0.022512343246489763, 0.03195420892110892, 0.03425628824957779, 0.038893623876252344, 0.06290654731648308, 0.029437739668147903, 0.008155049456815635, 0.052466824650764465, 0.06641111283430032, 0.047311291830348115, 0.09200490412435361, 0.08785790165088006, 0.03951557246702058, 0.3942969436092036, 11.985892704554967, 75.01769910539899, 91.54119627816337, 80.04938302721295, 63.25038283211844, 65.65913568224225, 81.50499589102608, 97.10549436296735, 112.77168805258614, 95.6720323562622, 68.64169161660331, 55.498625074114116, 58.13369812284197, 74.4784494127546, 66.31212738582066, 37.644912651606965, 14.127174649919782, 2.6633179102625166, 0.10261539369821548, 0.2681069906268801, 0.08060407731682062, 0.08276162868631737, 0.0923245551862887, 0.09971668531319924, 0.06916555788900171, 0.21328582588051045, 0.02704801397132022, 0.02667617508476334, 0.05533891071432403, 0.03904784131529076, 0.05788033309259585, 0.08940954839012452, 0.06794134500835623, 0.04866664517404778, 0.03161855461075902, 0.06805686559528112, 0.013348959369717963, 0.10049189800130469, 0.0646849876003606, 0.011605431408887463, 0.0077258319527442965, 0.010648030371937369, 0.053717127202876976, 0.04108385009957211, 0.10226055381021329, 0.12098056823015213, 0.0326616834583027, 0.1875334677419492, 0.21800259420914309, 0.3769240044057369, 0.17784491048327514, 0.06774096004664898, 0.0427771579873349, 0.017458658532372544, 0.03184811318559306, 0.024301290645131042, 0.028841341313506876, 0.0372963320863034, 0.04794568136068327, 0.03990509227982589, 0.024288658019421355, 0.11791802756488323, 0.08208976366690227, 0.08105853971626077, 0.04880773974582553, 0.09363810398748942, 0.036972134839743376, 0.014983162616512604, 0.2620497356568064, 0.18957151552396162, 0.46521012272153583, 0.4059600649135453, 0.16594447834151133, 0.10824615548231772, 0.034365417036627016, 0.07005545656595911, 0.27545194221394403, 0.14792410816465104, 0.1338665589158024, 0.17013151438108512, 2.3616321214607785, 18.187974623271398, 40.28283446175711, 54.887065478733604, 54.678365911756245, 67.12158557346889, 72.13630894252232, 77.64154733930314, 68.84522519792829, 46.270840644836426, 40.797744614737375, 34.333759035382954, 52.20171179090227, 72.15545122964042, 79.90586103711809, 27.767231941223145, 0.9651939166443688, 0.11626758612692356, 0.038450594791876416, 0.05150307422237737, 0.13982012016432627, 0.04792635668335216, 0.10137404780834913, 0.0226723723379629, 0.05642816297976034, 0.014384893201557654, 0.0608945484938366, 0.07577768487057515, 0.01178773510868528, 0.07115796062030963, 0.020251077799392597, 0.02586346315885229, 0.04549696722200938, 0.05369197390973568, 0.016198262771857635, 0.047885128895619085, 0.04297513754240104, 0.01949773938395083, 0.01310443485687886, 0.060637383721768856, 0.013649776844041688, 0.059728587844542096, 0.07978310422705752, 0.04620304397706475, 0.017592102621815035, 0.049655016245586533, 0.019861664855852723, 0.016598313448152373, 0.046218772418797016, 0.028076785017869303, 0.03514320815780333, 0.03456427190186722, 0.04054329517696585, 0.01305495184247515, 0.15606595841901644, 0.14839661281023706, 0.13619712314435414, 0.15802186275167124, 0.1377740113862923, 0.15327579528093338, 0.07242492120712996, 0.08774586194860083, 0.1537549767111029, 0.1121868086712701, 0.08650598847972495, 0.13738632361803735, 0.08350761008581944, 0.19592117837497167, 0.17730350739189557, 0.1001061304871525, 0.12321915025157587, 0.14445315727165767, 0.1627119510833706, 0.09489155494208847, 0.13032852805086545, 0.18875837272831372, 0.1479046613510166, 0.08324389066547155, 0.17416562219815596, 0.08482778138880219, 0.13502476390983376, 0.14902124500700406, 0.1565126380217927, 0.13963908702135086, 0.15504872586045945, 0.18324129948658602, 0.1493689263505595, 0.18415428192487784, 0.16392500884830952, 0.08174400936279978, 0.13680701756051608, 0.2037592213600874, 0.16599497491759913, 0.2422679971371378, 0.16964732536247798, 0.1515309696218797, 5.996434347970145, 82.62892954690116, 112.56060177939278, 105.28990255083356, 92.60839789254325, 72.30627577645438, 76.1302238191877, 91.28443949563163, 120.04764011928013, 121.44432531084333, 119.31618935721261, 91.39164325169155, 74.09355395180839, 78.07302352360317, 80.03068542480469, 59.60144601549421, 31.209327833993093, 6.953699392931802, 0.7923193158847945, 0.6476502216288021, 0.17627103493681975, 0.25363085312502726, 0.2828275364424501, 0.20718905303095067, 0.1317069312291486, 0.26607035419770647, 0.43281544957842144, 0.16641521879604884, 0.18815762496420316, 0.17632227790142807, 0.14381072031600134, 0.16011986588793142, 0.1833088272916419, 0.15043889465076582, 0.11764330230653286, 0.14763830921479634, 0.25122490365590366, 0.1954986953309604, 0.09772620962134429, 0.18289467665765965, 0.1452377744551216, 0.11001601229820933, 0.12159659660288266, 0.10432087111153773, 0.1671774714652981, 0.1327625417283603, 0.09611981867679528, 0.2859149250601019, 0.15944119516227925, 1.3929098227194376, 0.1333661936223507, 0.13190840184688568, 0.13649261157427514, 0.09885232669434377, 0.06538287443774086, 0.11835720257035323, 0.09042854513972998, 0.12499987041311604, 0.16898426094225474, 0.10582741562809263, 0.14331677396382603, 0.20326022670737334, 0.205456888835345, 0.3258076272904873, 0.12405112917934145, 0.2544417567551136, 0.13094661917005265, 0.1570388147873538, 0.7229113174336297, 1.5409690950598036, 0.3178994373551437, 0.17349657309906824, 0.10957575842205967, 0.17885267069297178, 0.1071332630568317, 0.23539622873067856, 0.2823121212422848, 0.39350536465644836, 0.9088533627135413, 1.524666884115764, 3.0428413280418942, 23.725490876606532, 48.43285948889596, 64.13217871529716, 79.36004529680524, 83.0737532206944, 84.57878167288644, 84.05713176727295, 60.57392978668213, 36.38189690453665, 45.05144568852016, 50.81180804116385, 70.93220002310616, 91.87912191663469, 90.56698935372489, 17.655541113444738, 0.4685828217438289, 0.20026045053132943, 0.2417991565806525, 0.21173721897814954, 0.21939865286861146, 0.15689124699149812, 0.22153868446392672, 0.1035350529210908, 0.16923785662012442, 0.15848908839481218, 0.1885837178145136, 0.1152067237666675, 0.1191738737480981, 0.25683820673397606, 0.12372707442513534, 0.15100412789200032, 0.18301754577883653, 0.10007366258651018, 0.08567338529974222, 0.09938167221844196, 0.14231335637824877, 0.08330183077071394, 0.07299722478325878, 0.10818976922226803, 0.07759987709245511, 0.14466722149934086, 0.15515672149402754, 0.05959784771714892, 0.09944961392985922, 0.15379567524152143, 0.09577229339629412, 0.12166712353272097, 0.16149004522178853, 0.1069054924217718, 0.15551631791251047, 0.12888877173619612, 0.08624835551849433, 0.13671183266810008], [0.02064505558727043, 0.13173620322985308, 0.019971823319792747, 0.18279160718832696, 0.05636740695419056, 0.03451246236051832, 0.011906179333371776, 0.05212500924244523, 0.045608002692461014, 0.12454846820661, 0.03289482130536011, 0.010341523381482278, 0.020920406794175506, 0.025680028001910875, 0.05156971314655883, 0.03232689767277666, 0.07805500445621354, 0.10604881481932742, 0.04103542644796627, 0.010063892296914543, 0.02286211447790265, 0.013757087157240935, 0.04792175282325063, 0.014541058036099588, 0.0014509550050466455, 0.017921916441991925, 0.09004229586571455, 0.028930738302213804, 0.04485376352178199, 0.03702973907015153, 0.043165520897933414, 0.062166068835982254, 0.031576746675584993, 0.061499408180160184, 0.016138555082891668, 0.06381806411913463, 0.11836378436003413, 0.10541000124067068, 0.15215212771935122, 0.051173513156494925, 0.060388232448271344, 0.09653491925980363, 0.03235967091417738, 2.618900682244982, 38.26847873415266, 84.69369098118374, 86.61001110076904, 73.1387186050415, 49.492143630981445, 32.49810750143868, 43.17662715911865, 74.35519531794957, 94.6268287386213, 98.06938321249825, 91.04229477473667, 75.31539467402867, 65.020630972726, 52.93617459705898, 52.982303687504356, 34.82771689551217, 16.281319447926112, 3.9844770516668047, 2.143164038658142, 0.36239800815071377, 0.25130779349378174, 0.2580971877489771, 0.028593102669609443, 0.030365310609340668, 0.02204866294882127, 0.1685990294707673, 0.00745783606544137, 0.018830110119389634, 0.027823861089668105, 0.054640050179192, 0.06185268743761948, 0.03532608013067927, 0.093096924812666, 0.05267731639157448, 0.07302355872733252, 0.08825675132019178, 0.15481881105474063, 0.13633458076843194, 0.007492025748693517, 0.020937426148780754, 0.10267418875758137, 0.03299673726516111, 0.013449056007500206, 0.05292651176984821, 0.0774122214476977, 0.04300490487366915, 0.33284471396889004, 0.9958777044500623, 0.1115499764148678, 0.07218545262834855, 0.11216219142079353, 0.13412121310830116, 0.060029477413211546, 0.05197133802409683, 0.0960186423201646, 0.03248078262965594, 0.03259400637554271, 0.017535366916230748, 0.017094446379425268, 0.021863841884104267, 0.0903743641184909, 0.013012568848872823, 0.08834862496171679, 0.03156164587874498, 0.19060999979930265, 0.16096818393894605, 0.11763088511569159, 0.14446725722934517, 0.9879841165883201, 0.9057520234159061, 0.2032536177762917, 0.13623035778956755, 0.16748753482741968, 0.08887760407690491, 0.20289780758321285, 0.27018995742712704, 0.8823558102760996, 2.7231755554676056, 6.112006340708051, 11.984290276254926, 34.97066913332258, 60.45435128893171, 59.006708008902415, 57.857614925929475, 60.06450176239014, 31.501645496913365, 9.641333392688207, 32.06579405920846, 57.37402377809797, 60.571449279785156, 75.86474009922573, 36.1157009942191, 1.4243147032601493, 0.3786342383495399, 0.035627770370670726, 0.018644311964245777, 0.037236990806247504, 0.04182430822402239, 0.039797198426510604, 0.04302267570580755, 0.04262262163683772, 0.07071521652064153, 0.04315682886434453, 0.03708217625639268, 0.16105795412191323, 0.02839360149976398, 0.04822335485368967, 0.023457581543230584, 0.02138576307334006, 0.05627208635477083, 0.0054463461440588746, 0.021549602138942907, 0.022593847176592265, 0.02589277926433299, 0.01434232191448765, 0.017168208224964992, 0.017673399598736848, 0.018043041728170853, 0.04909542841570718, 0.03082213770332081, 0.020226143333794813, 0.0534231247646468, 0.042123769476477585, 0.044067829980381897, 0.02228923753968307, 0.047884921942438395, 0.03911285514810255, 0.026280159995492016, 0.067947485750275, 0.009363172575831413, 0.021242788959560648, 0.014326839441699641, 0.026453452750242183, 0.07849019646112408, 0.06276931360896144, 0.09428541282457964, 0.03562118858098984, 0.03389711252280644, 0.044973334962768216, 0.04028190313173192, 0.0595253123236554, 0.042070345021784306, 0.021203747750925164, 0.030596182149435793, 0.026643876817875674, 0.047724957311792035, 0.03739669420091169, 0.10798234106706721, 0.06927334996206419, 0.06586936369006123, 0.05947057490370103, 0.025369209769581045, 0.030748214705714157, 0.01697790459729731, 0.043217344009982686, 0.021790231012606194, 0.021812361432239413, 0.07092808652669191, 0.09223804875676121, 0.032984757729406865, 0.023407732968085578, 0.03867384299103703, 0.05943617317825556, 0.057138965731220584, 0.00438471746331613, 0.026634116091632416, 0.06767309975943395, 0.0610778954412256, 0.038393760698714426, 0.10954671033791133, 0.142117938292878, 0.07207222548978669, 0.1405976534421955, 0.04935872035899332, 0.29599507844873835, 13.9326685156141, 69.33678245544434, 98.15377603258405, 86.68227931431362, 70.12024743216378, 64.11650357927594, 65.30794593266079, 79.88635049547467, 101.10383524213518, 108.1933810370309, 88.62933826446533, 75.44711167471749, 73.79373918260846, 74.6723666872297, 66.2693612234933, 61.58871419089181, 35.650599002838135, 14.403687766620092, 4.231036049979074, 2.244169133050101, 0.4469650760293007, 0.3423256395118577, 0.059177759901753495, 0.028408334191356386, 0.21014248526522092, 0.09212114395839827, 0.12021902123732225, 0.1544107265238251, 0.20869495293923787, 0.10441191694033997, 0.07891412478472505, 0.05742553821099656, 0.04588469909504056, 0.014987890309255038, 0.06498885593776192, 0.08546080027839967, 0.10946452617645264, 0.10566095741731779, 0.12063717522791453, 0.07797056077314274, 0.057722532988658974, 0.07009139856589691, 0.029603152934994017, 0.043666456160800796, 0.047328879458031485, 0.05392227887309023, 0.023887966127533997, 0.20671017015618937, 0.7842919209173748, 0.14546511082776956, 0.12139310395078999, 0.11454995615141732, 0.09673180298081466, 0.06920489256403276, 0.06964125843452555, 0.05452577131135123, 0.06142295763960906, 0.0556703173954572, 0.0708157414836543, 0.03247506257944873, 0.03768491552078298, 0.02457764438752617, 0.049154603454683504, 0.0858746591423239, 0.05073061299377254, 0.0665030882560781, 0.08609749682779823, 0.09121333195694856, 0.49544868298939293, 0.4798638735498701, 1.4283073118754794, 0.5945144700152534, 0.4842328248279435, 0.7124985733202526, 0.2937456805791174, 0.6724956770028386, 0.868532586310591, 1.4950002474444253, 7.393524272101266, 23.459553786686488, 40.2032185282026, 57.48720645904541, 75.5283430644444, 75.6361860547747, 74.93490437098912, 80.72651277269635, 56.652005195617676, 30.170982088361466, 32.35535676138741, 47.754364422389436, 58.653544970921104, 82.06927299499512, 63.246568271092, 11.62881522519248, 0.30861208428229603, 0.3810005070907729, 0.03824835064421807, 0.01743002944359822, 0.036508318835071156, 0.03307086043059826, 0.1312275869505746, 0.09242319382194962, 0.05897117991532598, 0.038067646590726714, 0.08539280428418092, 0.05588747235015035, 0.09129120742103883, 0.05989372969738074, 0.024324052102331604, 0.04347554694062897, 0.009338874236813613, 0.0448504454855408, 0.02578869368880987, 0.002983043290441856, 0.019908568589016795, 0.03161255296851907, 0.057841011988265176, 0.022372621011787226, 0.017210869417924966, 0.062351627807532034, 0.040660356038383076, 0.06008933777255671, 0.019807812924097692, 0.026602077364389385, 0.05748051990355764, 0.036573176604828665, 0.034446196630597115, 0.07580709936363356, 0.021167081414854953, 0.05994358845055103, 0.019664426600294452, 0.08587120539907898, 0.06505364246134247, 0.1677088322384017, 0.20805392733642034, 0.11939508973487786, 0.35794942400285173, 0.18694103881716728, 0.12250230514577456, 0.15596020195100987, 0.16003138492149965, 0.2100891659834555, 0.20675058370190008, 0.13401758724025317, 0.21899835791971, 0.10165160255772726, 0.11002311655985457, 0.1899458904351507, 0.25878332235983437, 0.20181451285524027, 0.13076205764498028, 0.1316853402448552, 0.08490090710776192, 0.16486555337905884, 0.1484134676201003, 0.13084726807262215, 0.10668934509158134, 0.12907831370830536, 0.13587590466652597, 0.214875280590994, 0.09917706676891871, 0.12751855169023785, 0.12485655024647713, 0.16874941997230053, 0.15692186249153955, 0.15715736842581204, 0.17502578747059616, 0.14109757090253489, 0.19784069965992654, 0.15014613393161977, 0.18335400415318354, 0.2509938217699528, 0.18487179199499743, 0.18092521519533225, 0.13003427455467836, 0.09708237488354955, 4.804588564804622, 62.76577377319336, 119.26513399396623, 112.08018943241665, 97.28167288643974, 74.0999949319022, 58.268958704812185, 62.52865259987967, 96.75770923069545, 118.41857937404087, 115.82877036503383, 106.78564126150948, 96.24278518131801, 78.81879452296666, 69.30072130475725, 73.18318707602364, 51.859665870666504, 27.186128037316458, 7.923597131456647, 2.8759288787841797, 0.6105935243623597, 0.254542342786278, 0.35570816855345455, 0.09867915098688432, 0.22207151087267057, 0.15707568638026714, 0.5237567297049931, 0.37640970200300217, 0.33554924598761965, 0.1632191560098103, 0.13210618123412132, 0.22302846238017082, 0.11616189751241889, 0.18637632126254694, 0.22819390520453453, 0.15466566570103168, 0.22688944877258369, 0.2880039986755167, 0.21062849275767803, 0.12821732062314237, 0.08906224702617951, 0.3050310750092779, 0.13164633805198328, 0.1521249727479049, 0.16196520972464765, 0.2130997037248952, 0.25788602765117374, 0.30816818667309626, 1.8569864119802202, 0.2047043392168624, 0.23810187354683876, 0.14744632451661996, 0.20891942589410714, 0.15453668976468699, 0.15816913199211868, 0.14220576786569186, 0.24933371799332754, 0.21050607146961348, 0.1176210870700223, 0.09290510974824429, 0.1129227341817958, 0.1801143115652459, 0.08003002312034369, 0.15922783661101544, 0.12107682520789759, 0.2540295331605843, 0.09979929695171968, 0.14293907423104557, 1.1082384352173125, 2.9681438505649567, 2.0546053392546515, 0.25866376448954853, 0.4351268655487469, 0.41443488587226185, 0.36689997943384306, 0.8980231838566917, 0.5784294988427843, 2.0735022681100026, 11.524635672569275, 26.928530522755214, 50.49479995455061, 75.2635611125401, 89.46788855961391, 71.873548916408, 79.68670095716203, 86.90280818939209, 47.04579060418265, 23.43818633896964, 49.78064325877598, 71.95267500196184, 78.2016555241176, 101.34035887037004, 56.60638679776873, 4.923097039972033, 0.5148452850324767, 0.28872357149209293, 0.17268186967287744, 0.10516467690467834, 0.10772897609110389, 0.15565625897475652, 0.26971696423632757, 0.14779874203460558, 0.2084009437156575, 0.13988131045230798, 0.1391026508063078, 0.2367790016744818, 0.20598128783915723, 0.15192796689059052, 0.13863362026001724, 0.1198959978563445, 0.08681626218770232, 0.16012256645730563, 0.10714215186557599, 0.09395162787820611, 0.2271813138255051, 0.13049300493938581, 0.11323044981275286, 0.0959740693547896, 0.09108586236834526, 0.1246938511197056, 0.08143566947962556, 0.14932737286601747, 0.157384012692741, 0.10015185696205922, 0.16673399454780988, 0.07900029194674321, 0.08221519765044961, 0.31924388664109365, 0.12155918218195438, 0.16860182503504412, 0.09480273470814739, 0.21975904995841639, 0.11841576014246259], [0.034860174238149605, 0.014604928537404962, 0.010335442859546413, 0.05869509080158813, 0.025155835951279317, 0.014200429215894213, 0.016260384349152446, 0.0717446491388338, 0.025291130744985173, 0.023506941573162164, 0.051856506150215864, 0.02311509777791798, 0.03662238396438105, 0.02409484806204481, 0.07051965594291687, 0.054725742366697104, 0.01941278001426586, 0.008234494033136537, 0.04738237176622663, 0.02608564605803362, 0.07348709313997201, 0.04633981628077371, 0.01667276400673602, 0.011271916180183845, 0.08059144978012357, 0.03518659029422062, 0.035846984679145474, 0.050335430806236606, 0.004731992534029165, 0.07951868591564042, 0.05337156967392989, 0.04503347012879593, 0.06863631414515631, 0.027932601415419152, 0.025561050279065967, 0.05141786040206041, 0.05163896782323718, 0.02119785128161311, 0.04797415608274085, 0.1547593849578074, 0.006897100239127342, 0.18065697673176015, 0.10349039853151355, 0.010568541690840252, 0.10726730086441551, 11.586929747036525, 77.44649056025914, 105.92076424189976, 80.95649814605713, 60.646816389901296, 34.0422751562936, 26.165448086602346, 41.84643622807094, 70.84552124568394, 84.72502735682896, 85.35996764046806, 91.9865619114467, 90.24213327680314, 77.95926761627197, 62.80733789716448, 42.528061458042686, 29.478361334119523, 5.070900857448578, 3.0305810144969394, 1.330011363540377, 0.07116348389536142, 0.21482102493090288, 0.25603634119033813, 0.0645788104406425, 0.15613416475909098, 0.1852423128272806, 0.10851640919489519, 0.13111535725849016, 0.026119318358334045, 0.051051071512379816, 0.11243316438049078, 0.04586125571014626, 0.03625760693103075, 0.014863206106903297, 0.06130158808082342, 0.05662659376061388, 0.0252285630309156, 0.06288628626082625, 0.016320719683010663, 0.07004029130829231, 0.025848335220611522, 0.0721209171627249, 0.06877259790365185, 0.02335638483054936, 0.031927427143922875, 0.2873027463044439, 0.6248627358249256, 0.2753958137972014, 0.07757274247705936, 0.021069660749552504, 0.07169339260352509, 0.04448277450033596, 0.00826535465395344, 0.042463912295975854, 0.056423922135893784, 0.026596272497304847, 0.06951131219310419, 0.05363374203443527, 0.06833944150379725, 0.07205486856400967, 0.09530011444751706, 0.08753344656101295, 0.04332699866167136, 0.08422095395092453, 0.09385345064635787, 0.04754507089299815, 0.11149748494582516, 0.1325822142618043, 0.4668331784861428, 3.7949506044387817, 1.1665573801313127, 1.0830696714775903, 0.20408079267612525, 0.44692061841487885, 2.6019155936581746, 6.110613226890564, 4.67824512720108, 7.968254940850394, 18.0081604548863, 29.582014560699463, 25.804298094340734, 42.67443568365914, 41.44606712886265, 19.16732668876648, 17.076363597597393, 45.141640254429404, 59.40219252450125, 60.28514180864607, 47.304656164986746, 12.048447336469378, 0.1463464056806905, 0.2536554975169045, 0.12236040990267481, 0.042921940396939, 0.18601063159959658, 0.03915258676611951, 0.09695937684071915, 0.04507247571434293, 0.011569899074467165, 0.0668036046304873, 0.029733458799975257, 0.07016542673643146, 0.03812331699633172, 0.08549370244145393, 0.028020731239978756, 0.02571583429484495, 0.04831586631813219, 0.02365281472780875, 0.01658795730743025, 0.047848800130720646, 0.0792115063273481, 0.0037689884941625807, 0.06651234347373247, 0.013063471697803055, 0.01977905321733228, 0.07973258050956897, 0.022306021103369336, 0.04165810446387955, 0.01380157785024494, 0.012832288879768124, 0.042853421930755885, 0.0162520977402372, 0.03374394342037184, 0.007755488173903099, 0.02146591671875545, 0.06948170771024056, 0.022515549324452877, 0.06785816340042011, 0.005338202929124236, 0.03618298504235489, 0.019290733616799116, 0.024160530251849974, 0.037996593796248944, 0.07426983078143426, 0.038901783259851594, 0.046687338168599775, 0.020383042682494436, 0.09542907681316137, 0.023206389575664486, 0.042558310087770224, 0.023525226395577192, 0.05244453477540186, 0.055281998589634895, 0.025080281076952815, 0.032424844202718565, 0.08759031458092587, 0.06563991707350526, 0.029821932981056825, 0.007158265399214412, 0.027121694392657707, 0.014029808192779976, 0.011869451929149883, 0.042502432728984525, 0.018025123314665895, 0.02839495348078864, 0.040514264056192975, 0.1101304879412055, 0.06492254271038941, 0.07204292634768145, 0.025226468054045523, 0.048291551015738926, 0.0559975409082004, 0.03714482539466449, 0.05927580821194819, 0.061957616092903275, 0.05653855723461934, 0.024710966340665306, 0.07027425696807248, 0.016347918759233186, 0.03998513566330075, 0.09286949344511543, 0.020672524381162863, 0.036684069582926374, 0.019695496718798364, 0.01780787336507014, 2.180692562035152, 43.50914709908621, 103.67758696419853, 100.393798828125, 73.47321878160749, 53.884277139391216, 51.721966470990864, 61.018822942461284, 81.86385645185197, 96.59238379342216, 96.05116081237793, 90.66984353746686, 86.21280343191964, 76.4480483191354, 77.88955633980888, 71.56037276131767, 50.4685948235648, 33.169254847935264, 7.283218579632895, 2.637284747191838, 1.9596873010907854, 0.25344053762299673, 0.33718492250357357, 0.4698499994618552, 0.28460261119263514, 0.7994808458856174, 0.46003165202481405, 0.12970659642347268, 0.08234687415616852, 0.044712193975491185, 0.02509908328231956, 0.0482375464136047, 0.013879121680344855, 0.05552665117595877, 0.05064613538395081, 0.030060946941375732, 0.07071647181042603, 0.04421936720609665, 0.028034096683508584, 0.05277689140556114, 0.04652816403125014, 0.025491575078506554, 0.11490333718912941, 0.06895475062940802, 0.05664552149495908, 0.037508574447461536, 0.1429425347596407, 2.1578646898269653, 0.24304125564438955, 0.03959739700491939, 0.020090780686587095, 0.03564853693491646, 0.08247829960393054, 0.0810831773227879, 0.016428756028679863, 0.06432719608502728, 0.029262094093220573, 0.11435845999845437, 0.01466252258978784, 0.04512985263551984, 0.07315477382923875, 0.09865808925990548, 0.06260014125811202, 0.017692900695172802, 0.03114513394289783, 0.049106641206890345, 0.014205505506002476, 0.03657408244907856, 0.49936963830675396, 3.0636996030807495, 0.32021161328469006, 0.949281673346247, 1.8379676725183214, 0.8682056409972054, 0.22259388784212725, 3.715710307870592, 14.00324831690107, 16.682428530284337, 26.108888013022288, 41.04214055197579, 49.12693241664341, 44.10104676655361, 51.413549831935335, 63.03453704289028, 49.8684789112636, 33.56449965068272, 32.5210747718811, 56.10965313230242, 77.95627989087785, 77.41659940992082, 35.72069590432303, 1.2075848643268858, 0.3019227875130517, 0.08462513690548283, 0.03487778561455863, 0.0936304365417787, 0.10594636960221188, 0.038650596381298134, 0.04004078910553029, 0.04601604990395052, 0.025494893114747744, 0.03162713468606983, 0.05782971438020468, 0.026066580920347145, 0.055964374116488864, 0.022883001482114196, 0.01904490546855543, 0.010352705638589603, 0.0526908633432218, 0.03906138487426298, 0.020668531202578118, 0.025644113143373812, 0.04282991069235972, 0.0598488242498466, 0.03233635984361172, 0.01215068857917296, 0.06577031793338911, 0.06668395855064903, 0.018381187958376746, 0.03371372825599142, 0.02785549608857504, 0.00526951186059575, 0.08253893349319696, 0.01857448901448931, 0.025230895495042205, 0.020457844382950237, 0.05462585522660187, 0.014414241537451744, 0.027315514528059533, 0.03485586893345628, 0.05685347890747445, 0.02089802870926048, 0.10738364926406316, 0.13042912765273026, 0.10534551327249833, 0.15282941423356533, 0.07462238400642361, 0.1805431049849306, 0.11387944141668932, 0.10841076807784182, 0.10945293001298394, 0.18769491836428642, 0.10755795133965355, 0.21220957434603147, 0.15048276872507163, 0.11549782886036805, 0.1702865053500448, 0.1222959083638021, 0.1270625897284065, 0.08121644838580064, 0.09238031719412122, 0.112586974698518, 0.1658924754176821, 0.10991584017340626, 0.253216593925442, 0.09840874121125255, 0.09768191485532693, 0.21981876104005746, 0.1033364050090313, 0.09932911968124764, 0.09779897571674415, 0.17998076230287552, 0.19243071281484195, 0.08359578571149281, 0.16228075564971992, 0.15636610159916536, 0.19969865067728929, 0.25802005188805716, 0.1604313270321914, 0.1154874065624816, 0.13152083621493407, 0.2570218454514231, 0.05268709408119321, 0.2841080677296434, 0.146479887089559, 0.09179845305957965, 0.3934840043740613, 24.747751542500087, 114.364319392613, 134.49412618364607, 101.29771082741874, 83.52342673710415, 55.996824809483115, 48.23313699449812, 59.68941715785435, 89.04742527008057, 102.22817189352853, 100.57224941253662, 110.01758193969727, 106.62397057669503, 99.1536773954119, 85.97206224714006, 61.930572509765625, 50.33415412902832, 19.973555701119558, 8.290078997612, 3.0425822905131747, 0.4004912626530443, 0.781707896717957, 0.5029123510633196, 0.2814320884644985, 0.6183311034526143, 0.5061869610633168, 0.16677086614072323, 0.24317183292337827, 0.11733129833425794, 0.13574819080531597, 0.257306558745248, 0.11694278275328022, 0.15473722400409834, 0.17016944448862756, 0.1828498797757285, 0.18097967441592896, 0.1052817241953952, 0.09802903980016708, 0.17277246766856738, 0.14706629062337534, 0.09294413908251695, 0.23297991124647005, 0.2363271787762642, 0.1421673899250371, 0.09203199802764825, 0.4644279075520379, 3.2157313993998935, 0.31641564411776407, 0.23511379531451634, 0.10367375904960291, 0.15514195657202176, 0.236425376364163, 0.1944285234702485, 0.10550479936812605, 0.18652126991323062, 0.1530346575060061, 0.3964480624667236, 0.1720135805330106, 0.13611894233950547, 0.24157914838620595, 0.17971724644303322, 0.174267904566867, 0.1632472202181816, 0.15466818985130104, 0.15315513818391732, 0.20954257888453348, 0.2810932552175862, 1.1596470709357942, 4.887020255838122, 8.081751159259252, 3.4258722833224704, 2.317572508539472, 2.074823077235903, 0.8384009088788713, 4.239387350422995, 17.55301523208618, 29.10858515330723, 48.22737693786621, 50.9508102280753, 50.06835079193115, 40.693434783390586, 64.59456048692975, 60.60513414655413, 35.90675129209246, 35.36282893589565, 61.37407738821847, 75.96438421521867, 91.26458154405866, 81.61698000771659, 21.709213972091675, 0.27856997347303797, 0.3184193308864321, 0.344403015183551, 0.1929206693811076, 0.2544141268091542, 0.14965411461889744, 0.18452877897237027, 0.1665993867708104, 0.18233914646719182, 0.16961327647524221, 0.17846810418580258, 0.14749527403286525, 0.09226182462381464, 0.14421898126602173, 0.1345448632325445, 0.09866363967635802, 0.11747607056583677, 0.12738144690436976, 0.1399823443165847, 0.17582050125513757, 0.1961764839610883, 0.09705258719623089, 0.19026956520974636, 0.08172538357653789, 0.10533272288739681, 0.18112671295447008, 0.24428533603038105, 0.10245836033884968, 0.18649220147303172, 0.09106005768158607, 0.14737693752561296, 0.18449198880365916, 0.10146052031112568, 0.14313555083104543, 0.1260240783116647, 0.15273393078574113, 0.22447429836860724, 0.09931144384401185, 0.09524803688483578, 0.1589625837015254, 0.0887794064890061], [0.05005304828020079, 0.021499616160456623, 0.08718889326389347, 0.028125739623127238, 0.023500088369473815, 0.025059987790882587, 0.038601877566959174, 0.045201397367886136, 0.03073406725057534, 0.030007312140826668, 0.04822887134339128, 0.02736709506383964, 0.07601672597229481, 0.025927398120984435, 0.07031166460365057, 0.08048451944653477, 0.08960508182644844, 0.020166478053267513, 0.0278413333663983, 0.029220204733844315, 0.07341272570192814, 0.04736458397071276, 0.07129273124571357, 0.013960660385367061, 0.024093248415738344, 0.025523629072787504, 0.03558256297505327, 0.04025352679725204, 0.024754379011158432, 0.010127077477851083, 0.061661415201212676, 0.02026799537374505, 0.04915684601292014, 0.11443373667342321, 0.06932909839919635, 0.04902927125138896, 0.08696958396051611, 0.07192628617797579, 0.0382664607438658, 0.03872563556901046, 0.06100039995674576, 0.026273313577153852, 0.02276416794796075, 0.06435520601059709, 0.056088311930320094, 0.13151372516793863, 1.8651331748281206, 31.09550244467599, 92.12393474578857, 91.78831590924943, 71.83668177468437, 64.8270263671875, 50.02054023742676, 33.148344244275776, 28.006456681660243, 47.37258175441197, 50.932998520987375, 77.45191015516008, 83.46409606933594, 86.48213645390102, 86.63990225110734, 58.68232440948486, 20.409397091184342, 6.295599026339395, 0.3894959012312548, 0.5560838750430516, 1.102677053638867, 0.6596271246671677, 0.46242601211581913, 1.096023176397596, 1.2665087367807115, 0.15249539858528546, 0.15521751823169844, 0.013845028688332863, 0.06035558134317398, 0.024738241752077426, 0.02967452464093055, 0.13607633034033434, 0.046593632482524426, 0.23373047954269818, 0.08974865305104426, 0.0655999377902065, 0.0848448465445212, 0.019986157372061695, 0.16464253248912947, 0.1506729078079973, 0.028932475351861546, 0.05585056683048606, 0.09797216499490397, 0.06792291599724974, 0.14511664238359245, 1.1240099774939674, 0.2663910841303212, 0.18559022487274238, 0.062303512889359675, 0.2449264159160001, 0.042830249959869046, 0.03261170256882906, 0.024299899648342813, 0.1080398808366486, 0.039695899933576584, 0.06710093189030886, 0.12644966904606136, 0.05478432708020721, 0.10445823374071292, 0.04822727000074727, 0.006473958592063614, 0.021355712453701665, 0.1433923899063042, 0.2282644457050732, 0.17216824580516132, 0.13432154378720693, 0.17113295064440795, 1.205973099384989, 0.20510168932378292, 0.9420943047319139, 1.1510894958462035, 1.233594468661717, 7.659891281809125, 9.811564258166722, 11.543572987828936, 23.71594057764326, 26.51671426636832, 18.344154494149343, 30.126944405691965, 52.4388816016061, 24.655208485467092, 8.338551368032183, 31.78566701071603, 64.0040191922869, 68.68879345485142, 62.43969481331961, 15.674501998083931, 0.19506009029490606, 0.2643815076776913, 0.055313557253352234, 0.06334026690040316, 0.03825609951413103, 0.11510841761316572, 0.03653797760073628, 0.03322632298139589, 0.05421084963849612, 0.034790583686637025, 0.019267297017255, 0.058918579880680354, 0.08948404474982194, 0.030087935671742474, 0.047824793561760864, 0.043679385645581145, 0.018877013852553706, 0.050447507827941857, 0.09955946196402822, 0.06883705194507327, 0.04398573402847562, 0.08162991369941405, 0.06907392173473324, 0.0999683268102152, 0.03368620687563505, 0.03336596209555864, 0.10718604629593236, 0.062415030119674544, 0.009211088281257876, 0.044903422107121775, 0.009066535725391336, 0.05617187351786664, 0.032329750912530084, 0.028961628608937775, 0.04630530938240034, 0.048635001693453105, 0.014885884443564075, 0.03857312464554395, 0.05528857698664069, 0.042119131689625125, 0.016515203086393218, 0.02271237367364977, 0.015278966565217291, 0.05385993507557681, 0.019762064396802868, 0.06103219610771962, 0.01290470383329583, 0.032582715552832396, 0.06666871865413018, 0.0610867299671684, 0.026215207230831896, 0.027603537376437868, 0.030890964902937412, 0.10311440870698009, 0.054323774828974686, 0.01651346094773284, 0.0368672468965607, 0.013211142122080284, 0.05839304093803678, 0.060336005607885976, 0.017454360013029406, 0.08381832484155893, 0.08088451584002801, 0.015411630339388336, 0.03818640039701547, 0.03341038917590465, 0.03086510593337672, 0.020090616141845073, 0.03575194227908339, 0.011493066009799284, 0.051816377589212995, 0.06416937562503985, 0.01596056856215, 0.059243889924670966, 0.02311850232737405, 0.020997885315279876, 0.06325829987015043, 0.021878423601655022, 0.02142889584813799, 0.016313601850665042, 0.013461814162188342, 0.01432017792415406, 0.06802762073597737, 0.08187319564500026, 0.0492370420667742, 0.06950179234679256, 0.0564008214111839, 0.05586682452953287, 1.184083993945803, 16.698739426476614, 74.72791753496442, 101.27364921569824, 83.31024905613491, 58.62627329145159, 46.815002713884624, 56.84245531899588, 66.10856601170131, 71.88102517809186, 76.24459116799491, 77.08920724051339, 87.32509190695626, 88.92128767286027, 80.07482038225446, 85.42501667567662, 81.64877496446881, 39.82881484712873, 15.005697931562151, 5.089449942111969, 1.0124047547578812, 0.7625380882195064, 1.4280203729867935, 0.9091348190392766, 0.6290357261896133, 2.548675021954945, 0.5348613081233842, 0.4970080107450485, 0.09907156135886908, 0.06687470152974129, 0.03218564364526953, 0.13437756363834652, 0.08047653308936528, 0.13869216426142625, 0.05071604145424707, 0.17097576122198785, 0.07812837444778, 0.042756109831056426, 0.011918962933123112, 0.13070207514933177, 0.06007552958492722, 0.1296021563134023, 0.10101311467587948, 0.04527912355427231, 0.120100467598864, 0.07198573941630976, 1.7138419044869286, 0.159394539094397, 0.1985884995332786, 0.08862424588629178, 0.11029883926468236, 0.08977898356637784, 0.10235353346381869, 0.09977573821587221, 0.05083680372419102, 0.04713889643816011, 0.03442691605804222, 0.03502220840060285, 0.04619379893743566, 0.028752025749002184, 0.015639015905825154, 0.029118923204285756, 0.08459928472127233, 0.09323355462402105, 0.08110582003636019, 0.07689373248389789, 0.3618912510573864, 0.34184371680021286, 1.2223564088344574, 0.1712306732577937, 1.1525174592222487, 0.6290661788412503, 3.341503781931741, 16.466916254588536, 26.076893295560563, 30.798491273607524, 50.71536704472133, 44.3176394871303, 34.861210686819895, 45.11188111986433, 54.76652118137905, 54.0675219808306, 34.83181980678013, 27.121886730194092, 44.75162744522095, 71.2908799307687, 83.61358656202043, 46.849528312683105, 5.134489033903394, 0.573017992079258, 0.1376961019954511, 0.08033867512962647, 0.04003643969606076, 0.029240401328674386, 0.04798646131530404, 0.07643489353358746, 0.03476172559229391, 0.039138323960027525, 0.03751359221392444, 0.006156570868500109, 0.011404167744331062, 0.017451021620737653, 0.07939456829002925, 0.020032168831676245, 0.030634495629263774, 0.0167759674867349, 0.07566945853510074, 0.06283756744648729, 0.031005389655807188, 0.006937141014662172, 0.02570284713458802, 0.04977123572358063, 0.03345952868195517, 0.01384135102853179, 0.06285274627485446, 0.06933588374938283, 0.01530283403449825, 0.03556235959487302, 0.054851312057248185, 0.05103716493717261, 0.04061042943171092, 0.040145405634705505, 0.027343617752194405, 0.017793917596074085, 0.0524929652123579, 0.12183580733835697, 0.038497339069311104, 0.07290938163974456, 0.05274837597140244, 0.04014182636248214, 0.0194176535920373, 0.20783386485917227, 0.0738096551171371, 0.16414773118283066, 0.17349168764693396, 0.1284654608794621, 0.26711068408829824, 0.2105100748262235, 0.15394044747310026, 0.1870730681610959, 0.10313886989440237, 0.19366122250046047, 0.12597058261079447, 0.1666334763701473, 0.2716037258505821, 0.19494221519146646, 0.14299003221094608, 0.14926223350422724, 0.10312512277492455, 0.16766457818448544, 0.18506533732371672, 0.15018710387604578, 0.14644195698201656, 0.113363917650921, 0.1364449377038649, 0.11231012562555925, 0.1269820069095918, 0.1025744169684393, 0.23449456425649778, 0.1520736212176936, 0.06629219957228218, 0.14319307702992642, 0.09034627276871886, 0.06759397579090935, 0.1879524631159646, 0.1342434851186616, 0.11406723276845046, 0.12201344780623913, 0.3936673988189016, 0.08469595560537917, 0.14912421948143414, 0.13045603835156985, 0.19858754958425248, 0.15142264829150268, 0.13107298953192575, 0.15804179811051913, 0.233417702040502, 4.595628006117685, 56.01511941637312, 125.99322754996163, 114.89538410731724, 90.93405573708671, 84.78484439849854, 71.38661221095494, 50.2518561908177, 47.60479055132185, 66.57888957432338, 63.138780866350444, 91.76427514212472, 97.86379991258893, 100.13066359928676, 111.04862512860979, 112.89658887045724, 57.29011385781424, 29.059188672474452, 15.324750525610787, 4.457174292632511, 3.0980284810066223, 3.7077598316328864, 2.994848817586899, 3.424057500702994, 2.953826435974666, 0.16764779122812407, 0.6526733349476541, 0.1577961277216673, 0.13216506450303964, 0.17948611027428082, 0.2647886558302811, 0.2400500290095806, 0.5059875260506357, 0.38733807844775064, 0.42251862638763016, 0.3027079610952309, 0.17303740845194884, 0.09558538414005723, 0.18634732067584991, 0.1786679598901953, 0.161067697884781, 0.09696601291320153, 0.1000126555029835, 0.26620717399886673, 0.27042961599571363, 4.818545758724213, 1.005190136177199, 0.4448682671146733, 0.2866923362016678, 0.36383186121072086, 0.19596564956009388, 0.39909147205097334, 0.19189967773854733, 0.138426612796528, 0.1827965062111616, 0.15088087879121304, 0.20943777236555303, 0.08899323322943278, 0.17094297440988676, 0.07526437312896762, 0.0942699218701039, 0.27999584696122576, 0.1871504211532218, 0.29895034272755894, 0.23908911485757145, 0.4566318658845765, 0.23888213453548296, 1.439392511333738, 0.3135659598878452, 2.802573706422533, 2.3007320293358395, 4.745344749518803, 21.018490076065063, 44.06925180980137, 57.518852029527935, 71.558413369315, 52.61589738300869, 41.17166887010847, 59.84853090558733, 82.56336634499687, 43.36437095914568, 28.56676115308489, 49.038026741572786, 77.51558344704765, 92.73503576006208, 101.77512850080217, 37.69763905661446, 1.2609575603689467, 0.3708668037184647, 0.17061840396906647, 0.1502722735915865, 0.1628943955791848, 0.3425786245082106, 0.07880816475621291, 0.15337792837194034, 0.2231939435005188, 0.08428466160382543, 0.17408828277673039, 0.17052130560789788, 0.13720497834895337, 0.11296042680208172, 0.14565879186349256, 0.13707284043942178, 0.1045303348717945, 0.1637150701135397, 0.19913106970489025, 0.18323504339371408, 0.06321652246905224, 0.15933352522552013, 0.11726047284901142, 0.25433194264769554, 0.15603764993803843, 0.13917114213109016, 0.18575067126325198, 0.28670148285371916, 0.07923370799315826, 0.13558693017278398, 0.1271943205169269, 0.13299903832376003, 0.14152712428144046, 0.19660192541778088, 0.2956354548888547, 0.09127096672143255, 0.1535615806600877, 0.15996787404375418, 0.0782967529126576, 0.15392344338553293, 0.18850652767079218, 0.14751064963638783, 0.13959435799292155], [0.07462705232735191, 0.026290285434307795, 0.02011693312254335, 0.043682266026735306, 0.03512800558071051, 0.016702390541987758, 0.09334544504859618, 0.03448805206322244, 0.02062905064251806, 0.01441507613552468, 0.04507312710796084, 0.009114258789590426, 0.049593619004424126, 0.010314762808515556, 0.10573395421462399, 0.04393727645011885, 0.0694187328751598, 0.0398353049531579, 0.04370764662910785, 0.0181360960206283, 0.10645019542425871, 0.05136563016899994, 0.0521876787367676, 0.013672125243049647, 0.051726298672812324, 0.021361993991636803, 0.05702427974236863, 0.04844387534207531, 0.04547965440100857, 0.05918100329914263, 0.0172092697716185, 0.06636421249381133, 0.06910895449774605, 0.059087026199059825, 0.015418386851836528, 0.014245364349335432, 0.026816255246688212, 0.025012456412826265, 0.01702767514091517, 0.033534221816807985, 0.09892663984958615, 0.05631846422329545, 0.06263347089822803, 0.037003540833081515, 0.20101324442241872, 0.17749249296528952, 0.1155750190040895, 0.07557935586997441, 6.632865020206996, 55.79313489368984, 111.30039310455322, 96.76018278939384, 83.628066607884, 78.81547328404018, 43.40337119783674, 20.3330329145704, 33.16220590046474, 56.561303411211284, 63.775548526218955, 67.81491156986782, 59.65136882237026, 68.94046415601457, 59.867006165640696, 29.900516510009766, 18.44810996736799, 13.853271450315203, 5.3585132871355325, 1.5492525420018604, 0.11866703523056847, 0.3802306684000151, 1.7492789115224565, 4.894979417324066, 3.0326296474252428, 0.9876764416694641, 0.41677300898092134, 0.15638309211603232, 0.22455211276454584, 0.2020700355725629, 0.11444563817765031, 0.2085053295429264, 0.1658910640648433, 0.1711571336324726, 0.061974097708506246, 0.0712304145896009, 0.09096420103950159, 0.1429783749793257, 0.059682040342262814, 0.000576459603118045, 0.10153589876634733, 0.03198657164882336, 0.28883571975997513, 0.44576222343104227, 0.0698825658432075, 0.04781229494671736, 0.04346193213547979, 0.09469332093639032, 0.03000031305210931, 0.021082632642771517, 0.07833938526787929, 0.03666026657447219, 0.042465537387345514, 0.09314074460417032, 0.058981419008757384, 0.06355724882866655, 0.06270927683051143, 0.12896505264299257, 0.027209423881556307, 0.01779111015743443, 0.2373748639864581, 0.15727440214582852, 0.0887833759188652, 0.2514503944133009, 0.08501216649476971, 1.1771997404950005, 0.29537294326084, 2.271810804094587, 9.987926908901759, 15.948669229234968, 18.108893701008387, 35.70692457471575, 30.773133822849818, 26.540551798684255, 39.00310482297625, 49.100359031132285, 36.53858225686209, 14.857769046510969, 20.17186771120344, 46.22611509050642, 64.68492875780377, 71.9915988104684, 46.45295292990548, 2.739316003663199, 0.08195533909435783, 0.01755475266171353, 0.07766958299492087, 0.0692915211298636, 0.033441035210021904, 0.04542376686419759, 0.03597094624170235, 0.062172562416110716, 0.11200333958757774, 0.0466030844753342, 0.07044169905462436, 0.031205018050968647, 0.0683327918606145, 0.07610992954245635, 0.12479257796491895, 0.05083863916141646, 0.05957223302019494, 0.03891213431156107, 0.01657726359553635, 0.0385327857386853, 0.05731315245585782, 0.041161678066211085, 0.0212712551999305, 0.050764678844383786, 0.05344605924827712, 0.05862658590610538, 0.02654920082672366, 0.05985273261155401, 0.042834378845457516, 0.05963168625852891, 0.06321708565311772, 0.05728362939719643, 0.03069182505298938, 0.07616555584328515, 0.01146362691984645, 0.02867673889600805, 0.04123139414670212, 0.06044833708022322, 0.08935181863073792, 0.06307653390935489, 0.08060723250465733, 0.10137731156178884, 0.05471192400104233, 0.013260088245650488, 0.014298276510089636, 0.03592380841395684, 0.038277792278677225, 0.059173491916486194, 0.04872845292889646, 0.020006538867684345, 0.009525730058417788, 0.044791979515658956, 0.05785050469317606, 0.07125615820820842, 0.04094801078151379, 0.042744903825223446, 0.03187528172773974, 0.02172671165317297, 0.039802759020988426, 0.01750840193458966, 0.010611280067158597, 0.037661041266151836, 0.03952401004997747, 0.004800072921040867, 0.032426771242171526, 0.04294128882299576, 0.00703910192740815, 0.015392130939289927, 0.029232489610356942, 0.029738150869629214, 0.037814067876232524, 0.027641136698158722, 0.05643958950947438, 0.07691151010138647, 0.054636267346463034, 0.04371261689811945, 0.04807037913373538, 0.01916106048572276, 0.018100091256201267, 0.032509901959981234, 0.018166696253631796, 0.11648410665137426, 0.07495329196431808, 0.014625162451661058, 0.009839319258130022, 0.034974890761077404, 0.06909612340054341, 0.03941674723422953, 0.19001432747713157, 0.08201823929058653, 0.2363871612719127, 2.25458231142589, 33.531096185956685, 89.66323716299874, 102.20506913321358, 89.68238639831543, 66.38698032924107, 53.90298516409737, 46.591235978262766, 51.734535762241904, 51.323528970990864, 78.26566927773612, 80.16989953177315, 84.47009100232805, 83.49258368355888, 83.70870740073067, 76.71023164476667, 57.10303361075265, 38.57241031101772, 26.064711366380962, 11.993094512394496, 3.1996476224490573, 0.19532340259424277, 0.293896668191467, 1.9137482004506248, 9.373842511858259, 7.104456629071917, 1.5352496419634138, 0.2614938797695296, 0.16837284660765103, 0.11848015311573233, 0.05659871275669762, 0.027513458460037197, 0.1116485743384276, 0.422773646989039, 0.19720732793211937, 0.020474544826096723, 0.04286174077008452, 0.1871680359223059, 0.18882942891546659, 0.010548573253410203, 0.05392381236223238, 0.10362482310405799, 0.10611307887094361, 0.3349770781184946, 0.8342583711658205, 0.06746959353664092, 0.11082355039460318, 0.030030538394515003, 0.07178382096546036, 0.13143114745616913, 0.03747021686285734, 0.03572331488664661, 0.04798533833984818, 0.022235497566206113, 0.056281205865421464, 0.03799158620781132, 0.14435369760862418, 0.18099190161696502, 0.20847235274102005, 0.05520068973835025, 0.03311502288228699, 0.2602725981601647, 0.1901345367410353, 0.0593942329287529, 0.5839381175381797, 0.16660446221274988, 2.0072012543678284, 0.22493121027946472, 4.344312965869904, 17.27809064728873, 30.2777897971017, 42.872483662196565, 60.44838973454067, 57.326348713466096, 48.76511539731707, 56.31259264264788, 70.04305294581822, 64.59103080204555, 55.223754337855745, 30.80203832898821, 36.5115259715489, 67.0404861995152, 86.55526624407086, 73.48770577566964, 18.41445463044303, 0.9209969682352883, 0.3836523847920554, 0.09028933689530406, 0.008729415779401149, 0.019335815483438115, 0.09571104204016072, 0.025145008228719234, 0.01637994052310075, 0.11395851788776261, 0.007046435618706579, 0.06718684799437012, 0.028584139222013097, 0.09052086661436728, 0.08027111339781966, 0.04805483389645815, 0.059883653452353816, 0.04535282263532281, 0.08082492689469031, 0.025443880852045755, 0.010366276338962572, 0.06422650827361004, 0.09339292892920119, 0.048495613637247255, 0.02750668328787599, 0.055819914011018615, 0.0614838358014822, 0.03564674560246723, 0.03074510022997856, 0.049402652108775716, 0.07006184158048459, 0.056366477361215014, 0.04309934677023973, 0.012789910975178438, 0.07210539906684842, 0.027669938813362802, 0.12134898560387747, 0.046833348726587634, 0.03395905259198376, 0.06457560097000428, 0.04429120370852096, 0.03316995368472167, 0.08850425375359398, 0.03620127495378256, 0.08343459971781288, 0.17460654782397406, 0.2125388402491808, 0.09796360866831881, 0.1400828082114458, 0.1032421700656414, 0.07898651768586465, 0.13585354015231133, 0.12910111248493195, 0.15234743723911898, 0.14429504504161222, 0.22088571664478096, 0.07670549329902444, 0.10680207689957959, 0.14003020817680017, 0.13111291453242302, 0.07919973374477454, 0.16060098792825425, 0.18787474371492863, 0.14290932725582803, 0.07416462392679282, 0.2830953949264118, 0.13107332879943506, 0.0980985624981778, 0.17150841121162685, 0.10916299199951546, 0.1605108649070774, 0.13087773429495947, 0.12908908884440148, 0.22338633531970636, 0.14822079081620487, 0.116465867630073, 0.18328672062073434, 0.1648374077464853, 0.07948476595005818, 0.0886671564408711, 0.11655854194292001, 0.09659255402428762, 0.2039045635610819, 0.18594547866710595, 0.1965074326310839, 0.1962196659296751, 0.276686468826873, 0.19382833210485323, 0.15883102933210985, 0.4648250405277525, 0.36250209542257444, 0.20804794265755586, 0.41181723347731997, 15.485410247530256, 86.80632550375802, 139.71541949680872, 119.33158656529018, 100.33895669664655, 95.1193378993443, 63.26175703321184, 41.731290681021555, 44.8873222896031, 75.99160030909947, 79.6420796258109, 91.57272720336914, 81.75281729016984, 87.93505341666085, 107.31530938829694, 93.4281255177089, 54.51091085161482, 35.90547629765102, 11.894260730062213, 2.3164067310946326, 0.12307317022766386, 1.150024141584124, 7.84871552671705, 17.805960927690776, 6.419118021215711, 1.9711579084396362, 0.49688994565180367, 0.41245155515415327, 0.386622603982687, 0.3834185887660299, 0.2471459853862013, 0.31544001932655064, 1.2435511286769594, 0.5249817839690617, 0.1394316860075508, 0.31924187817743843, 0.3450768547398703, 0.3098371928291661, 0.09174488950520754, 0.10984012245067529, 0.22048486529716424, 0.297817949205637, 0.7656087577342987, 3.718836997236524, 0.40026894743953434, 0.23765515323196137, 0.14718415215611458, 0.14202131490622247, 0.1643023421721799, 0.13334838886346134, 0.15954074982021535, 0.1608612196786063, 0.21783177980354854, 0.17466465756297112, 0.19143222139350005, 0.40848953489746365, 0.3965441701667649, 0.3369553062532629, 0.19701546537024633, 0.12195778079330921, 0.2645996973982879, 0.2006760532302516, 0.14859892481139728, 0.556615737932069, 0.17337503390652792, 6.673897172723498, 0.606316148170403, 3.9075921944209506, 19.23036595753261, 39.666393756866455, 67.24074717930385, 85.33289745875767, 63.15205192565918, 48.57304981776646, 77.57221126556396, 91.08638109479631, 56.23472418103899, 38.12718711580549, 39.32169015066964, 64.08333982740129, 89.57261180877686, 103.40884453909737, 72.20941093989781, 7.599791969571795, 0.35323555980409893, 0.1909341766898121, 0.30843107828072136, 0.14610273018479347, 0.10887442462678466, 0.24170836859515735, 0.13356408157518931, 0.2012567299285105, 0.2440381592937878, 0.06949635728129319, 0.18995962398392813, 0.1182138416916132, 0.18935996187584742, 0.2419133133121899, 0.20014003770692007, 0.16150348021515779, 0.17282670975795814, 0.13503160354282173, 0.09888573097331183, 0.10445275796311242, 0.09496131512735571, 0.1902515161782503, 0.08402440271207265, 0.11119492618100983, 0.16406032230172837, 0.22683429744626793, 0.08572838734835386, 0.2596963047981262, 0.1040422578475305, 0.17492494359612465, 0.12123575167996542, 0.1904232126793691, 0.06368902032928807, 0.3358151231493269, 0.18838924967816897, 0.25798571801611353, 0.10360480632100787, 0.08254706912807055, 0.13444331368165358, 0.13109538118754113, 0.32631248448576244, 0.23071002161928586, 0.14766303503087588, 0.1558140590786934], [0.029720376644815718, 0.072749009888087, 0.028987613107476915, 0.03251918771171144, 0.0774791928540383, 0.11205225517707211, 0.005708375588125948, 0.04849517598216023, 0.025285812726776515, 0.04586327435182674, 0.019850759101765494, 0.039148725901863406, 0.0361375944422824, 0.024013856425881386, 0.023569624638184905, 0.10572573715554816, 0.05784000097108739, 0.07509182167372533, 0.014910628919356635, 0.03219858670075025, 0.010818532651423343, 0.06701034067996911, 0.041535978338548114, 0.05128630263996976, 0.05213694467342325, 0.012222762568853796, 0.009094728007247406, 0.033007977197745016, 0.045246089076889415, 0.019014106764058982, 0.046381230665636916, 0.06078708890293326, 0.049064249731600285, 0.044483225726123364, 0.025910339750615612, 0.01942517176004393, 0.038027765695005655, 0.06376121645527226, 0.023656707822478244, 0.05437665645565305, 0.04221390267567975, 0.10142011355076518, 0.046125358502779684, 0.011848158652095922, 0.026037130804200257, 0.030022178843085254, 0.09613210016063281, 0.218240190031273, 0.04605704020442707, 0.5066034187163625, 12.851785898208618, 74.54296343667167, 115.24251610892159, 95.33744185311454, 82.54493277413505, 66.93759032658168, 42.02449423926217, 23.625697374343872, 33.39146171297346, 49.201521328517366, 76.31227357046944, 61.56782095772879, 44.74725702830723, 62.33504104614258, 65.03989832741874, 44.13582250050136, 17.408110550471715, 12.27992570400238, 6.663066668169839, 2.085857685123171, 0.2375992690878255, 1.0996983391898019, 4.329842039516993, 1.8059085756540298, 0.4105104021728039, 0.7379862485187394, 0.4713479333690235, 0.5577336379459926, 0.6518211492470333, 0.5539983298097337, 0.1462465931794473, 0.21344317815133504, 0.1294124922049897, 0.03323825501969882, 0.06142010779253074, 0.1071102200075984, 0.017645449044981172, 0.0459758467040956, 0.11595821487052099, 0.23224223511559622, 0.015011696710384317, 1.1573480857270104, 0.3697485237249306, 0.2089078907987901, 0.15704004972108773, 0.057032293240938864, 0.05499953803207193, 0.047369903685258966, 0.1124001672225339, 0.10148861844624792, 0.045130904364798746, 0.07048494209136281, 0.13063350240034716, 0.06456667144915887, 0.13665094093552657, 0.24627691773431643, 0.08828544656613044, 0.13653313368558884, 0.2873181626200676, 0.46961690911224907, 0.2348792664706707, 1.0703788953168052, 2.6168935213770186, 1.0617337077856064, 8.546191334724426, 26.165962253298076, 32.84508316857474, 45.01753500529698, 45.50424589429583, 34.237853050231934, 40.12150771277291, 52.8994151524135, 33.89103371756417, 13.912037576947894, 14.07716064793723, 35.27136632374355, 53.24767623628889, 65.66173430851528, 65.81127343858991, 17.168694734573364, 0.2940195644540446, 0.15455338172614574, 0.09054589098585503, 0.07158232320632253, 0.026901543705857227, 0.037765464412846735, 0.10181090222405535, 0.019870653748512268, 0.054647999216935465, 0.042348113509693315, 0.021068259574738995, 0.025083934988028238, 0.08065772229539496, 0.04739347259913172, 0.028293239385155693, 0.03333971636103732, 0.0393627426320953, 0.10120100102254323, 0.06435057161641972, 0.10076812282204628, 0.044838879856147935, 0.07781886748437371, 0.07888998250876154, 0.04150867748207279, 0.03415779210627079, 0.04977035362805639, 0.04258459314171757, 0.0337574666232935, 0.04886550682463816, 0.07624524299587522, 0.008604246424511075, 0.09162501272346292, 0.06053225150597947, 0.043824612495622466, 0.031451916588204246, 0.011576456267253628, 0.01925523266462343, 0.029854234640619585, 0.07051347448889698, 0.03018660144880414, 0.059218315939818106, 0.05065570951306394, 0.06433189833270651, 0.05447326966428331, 0.036675262198384316, 0.05035186492438827, 0.04642917595005461, 0.06547042581119708, 0.03361626348591276, 0.029959163295903375, 0.06537030118384532, 0.013784692506305873, 0.052933076596153636, 0.02388590168473976, 0.022829298828063265, 0.012876971258914896, 0.08297648001462221, 0.058272254919367175, 0.03568489962656583, 0.05148419398548348, 0.020803103356489112, 0.10265050110008035, 0.03253595431202224, 0.08726315892168454, 0.05906954713697944, 0.05406092054077557, 0.08433221333793231, 0.05637604809765305, 0.07403322562043156, 0.06856014858931303, 0.011811237865393715, 0.05956392775156668, 0.03697873359279973, 0.039470551668533256, 0.013011690994192446, 0.04218963487073779, 0.0669846445588129, 0.017052962444722652, 0.0867178203271968, 0.09858677522944552, 0.012647780789328473, 0.06599451268890075, 0.02618951110967568, 0.05027093944538917, 0.043979545789105554, 0.03525396542889731, 0.10221094611499991, 0.03895172682989921, 0.04078735065247331, 0.046069599887622256, 0.03761302134288209, 0.11994432312037263, 0.08498588004814726, 0.20001087178077015, 1.0293484798499515, 7.819835339273725, 52.91145290647234, 97.19893373761857, 113.94738578796387, 93.15003776550293, 60.74330602373396, 44.38371685573033, 48.652950627463206, 58.175154549734934, 59.309010233197895, 67.85350881304059, 76.87712042672294, 70.98934200831822, 67.32252747671944, 78.74845790863037, 79.62151295798165, 71.40499019622803, 43.10565825871059, 29.90132944924491, 12.53065492425646, 4.099359001432147, 0.9800629530634198, 0.6138693285839898, 3.64751113312585, 1.1557189502886362, 1.2669013100011008, 0.05181189586541482, 0.6360442872558321, 0.3328113571873733, 0.743001925093787, 0.6053755357861519, 0.060888027772307396, 0.13312725430088385, 0.07747208859239306, 0.013327139379855777, 0.13796590108956608, 0.19056540647787706, 0.07435160782188177, 0.1124988194288952, 0.10828242317906447, 0.07225885654666594, 0.03947679079802973, 2.2904777910028185, 0.7885412329009601, 0.06898721853005034, 0.2983723665986742, 0.1868748137993472, 0.15752940917653696, 0.24555900054318563, 0.020415902437110032, 0.09664214814880065, 0.03560656275866287, 0.08769985048898629, 0.044829753560147116, 0.058357824970568926, 0.06371150697980608, 0.15528858798955167, 0.21074811848146574, 0.15248079651168414, 0.4172282788370337, 0.8214148432016373, 0.20953664848847048, 0.8223916622144836, 2.1941546968051364, 3.1498970006193434, 16.74317489351545, 44.57691151755196, 58.362436294555664, 67.69534696851457, 72.73211697169712, 55.306093965257915, 53.27322823660714, 59.022417885916575, 63.1001558303833, 48.62997988292149, 33.45590278080532, 29.296672889164515, 47.77290916442871, 75.38086754935128, 81.61238030024937, 41.96230091367449, 2.850210555962154, 0.4001234152487346, 0.22594101966491767, 0.030454911158553193, 0.029605612624436617, 0.07224743680230208, 0.1461485041571515, 0.012282248885769929, 0.04718414454587868, 0.07603784876742534, 0.04968297188835485, 0.03903121042198368, 0.06640929436045033, 0.05809451945658241, 0.012920789354081665, 0.09540226789457457, 0.01817887256454144, 0.09740638892565455, 0.058063795390938006, 0.0494507059587964, 0.018837465438991785, 0.15366627861346516, 0.03701591731182166, 0.025866462283634713, 0.04968873943601336, 0.03920692724308797, 0.07963638459997517, 0.014294206996315291, 0.007558549321921808, 0.03424295503646135, 0.037656851312411685, 0.027644337687109197, 0.04170387504356248, 0.054336873947509697, 0.01657793704154236, 0.06642740446009807, 0.030116746268634285, 0.05557689669408968, 0.05614145818565573, 0.0404051590178694, 0.04518564857010331, 0.062461387632148604, 0.02507109201646277, 0.11808983263160501, 0.047150652057358196, 0.03219685982912779, 0.20259834293808254, 0.13372625144464628, 0.11550683980541569, 0.11902143407080855, 0.2710744956774371, 0.17843800437237534, 0.15704150178602763, 0.07974155752786569, 0.16267608372228487, 0.10667890243764434, 0.20034587809017726, 0.13454478180834226, 0.09970293819372143, 0.154572529984372, 0.06931188396577324, 0.21141066721507482, 0.15581021857048782, 0.24246469086834363, 0.15476999724549906, 0.15463792718946934, 0.13332553580403328, 0.11433910817972251, 0.18519944298480237, 0.19183476907866343, 0.12376515381038189, 0.12446181928472859, 0.12991072689848288, 0.16916954171444687, 0.1140511514885085, 0.1149233268307788, 0.16079774951296194, 0.16781627147325448, 0.11884273508829729, 0.2341605078961168, 0.05581491660060627, 0.19561845676175185, 0.07558105899287121, 0.17891915355409893, 0.11096526921859809, 0.14620064278798445, 0.2231773736753634, 0.25858755143625395, 0.17265068420342036, 0.17008590325713158, 0.09996027938489403, 0.25347375869750977, 0.17643686889537744, 0.30066160804459025, 0.3423906974494457, 1.632600526724543, 28.352075713021414, 103.70645672934396, 151.88171522957938, 121.36561611720494, 97.91595309121269, 82.99455070495605, 65.19273090362549, 45.11730071476528, 47.86742550986153, 64.00907748086112, 98.78893171037946, 94.16910920824323, 69.48777375902448, 78.36094297681535, 103.60047585623605, 101.85177407945905, 57.855214323316304, 35.46213606425694, 12.893066883087158, 2.2454816911901747, 0.7494379111698696, 1.4344952255487442, 9.995602062770299, 5.025790546621595, 3.355583437851497, 1.07097470334598, 1.2118433501039232, 1.3041354034628188, 1.6661470809153147, 2.4496034809521268, 1.5251272022724152, 0.32305415932621273, 0.3116615020803043, 0.1802230400166341, 0.2833825780877045, 0.1681342465536935, 0.14419426902064256, 0.18963094162089483, 0.16824019301150525, 0.4720916620322636, 0.10502567900610821, 1.7818503294672285, 0.9039536884852818, 0.23693647608160973, 0.31457133165427614, 0.3770542288465159, 0.14833850307124002, 0.39902570843696594, 0.1821425070187875, 0.26019760646990364, 0.07168429344892502, 0.13307694771460124, 0.23455709804381641, 0.1833162640354463, 0.17646558449736663, 0.3153496113206659, 0.39324543146150454, 0.19775339934442723, 0.33578038215637207, 0.6069518540586744, 0.2340291706579072, 1.4634845214230674, 6.801602891513279, 1.8670873556818282, 17.491949251719884, 59.060869216918945, 79.72920308794293, 92.71090466635567, 79.22645228249687, 62.56208038330078, 78.25164086478097, 89.63381154196603, 57.23368058885847, 31.264451367514475, 34.62712240219116, 52.7237160546439, 75.34431307656425, 97.96329116821289, 94.11785234723772, 25.13862419128418, 0.43005278067929403, 0.3316470996609756, 0.2960885805743081, 0.20632932202092238, 0.1399693571563278, 0.2378052994608879, 0.2348911001213959, 0.06739549072725431, 0.16694140913231031, 0.19239625680659497, 0.2181454258305686, 0.18547115554766996, 0.11455610367868628, 0.27772375888058115, 0.11862079985439777, 0.19788052966552122, 0.1127288970830185, 0.17190772907010146, 0.12611270855580056, 0.11008223731602941, 0.11972795187362603, 0.24899795172469957, 0.15963479477380002, 0.1785356184201581, 0.15175259272967065, 0.13709865191153117, 0.2249843938542264, 0.11588816291519574, 0.09046363897089447, 0.1491505466401577, 0.19870997087231704, 0.1769982073456049, 0.1189176860664572, 0.19023243577352592, 0.07402287796139717, 0.11154397137995277, 0.1720834153571299, 0.09152647586805479, 0.21207460016012192, 0.21639460192195006, 0.15522901261491434, 0.1547606877450432, 0.1733974391328437, 0.2184722897197519, 0.09815256710031203, 0.12258439431233065], [0.0369806063494512, 0.026544303500226567, 0.09557266839380775, 0.022401163587346673, 0.010692001985652106, 0.019153459197176353, 0.043288508762738535, 0.08449428142713648, 0.02499655494466424, 0.06202217869992767, 0.05621011575151767, 0.04340628547860043, 0.1542249164943184, 0.056984721150781424, 0.07853162102401257, 0.05620410732392754, 0.006256041981812034, 0.041007209569215775, 0.030209250947726623, 0.01533195675749864, 0.03375142426895244, 0.027631170715072324, 0.030050141271203756, 0.0497490645918463, 0.1045260193890759, 0.043373196718416045, 0.040508069031472714, 0.007140127309997166, 0.03251966268622449, 0.03616646610732589, 0.05935631639191082, 0.0205112535706056, 0.006857305008452386, 0.052182861138135195, 0.03503523288028581, 0.17628799831228598, 0.009278613541807448, 0.010085378108280045, 0.023440507905823842, 0.04704749777114817, 0.0637735997193626, 0.0704280130032982, 0.0034193586948926425, 0.002453368464817426, 0.052335456878479035, 0.08036628471953527, 0.032683769773159704, 0.08063178190163203, 0.12469112340893064, 0.04367791322459068, 0.5709507944328445, 1.0398688124758857, 13.284583108765737, 59.362671170915874, 104.84550271715436, 96.05140399932861, 71.7453477042062, 55.230796337127686, 37.32465975625174, 23.840261220932007, 29.553165640149796, 67.78078201838902, 74.30013084411621, 64.27568680899483, 59.8139705657959, 59.626487323216026, 40.17612402779715, 37.45888158253261, 37.738261699676514, 24.98290637561253, 15.653707776750837, 5.1204389078276495, 1.0614368894270487, 1.1042687339442117, 0.4448381130184446, 0.29631607979536057, 0.34831550238387926, 0.07214342416929347, 0.05542315422956433, 0.74897037340062, 0.2869385629892349, 0.4877137637564114, 0.22976332956126758, 0.04423787424873028, 0.29076351917215754, 0.8087338379451207, 0.3370912032467978, 0.32608096833739963, 0.2181956781340497, 0.8859309298651559, 0.2271865385451487, 3.0141869570527757, 0.10526428584541593, 0.3700812230152743, 0.29387848345296724, 0.1011739003338984, 0.25696758979133194, 0.01513573291179325, 0.10243773287428276, 0.2032255128558193, 0.0961542407582913, 0.14009793954236166, 0.1945455436195646, 0.22697501203843526, 0.38620587491563385, 0.3914254919758865, 0.15324393127645763, 0.17635522756193364, 0.7548684711967195, 2.7878765293530057, 2.238083813871656, 0.5365351183073861, 6.507100020136152, 15.568050384521484, 39.86432709012713, 58.897287777491975, 61.3944217136928, 44.72833708354405, 39.05507387433733, 51.005398750305176, 53.842824186597554, 20.5590751852308, 7.02089672429221, 22.505010264260427, 49.57920108522688, 56.70866428102766, 84.14112159184047, 32.25879417146955, 1.1535730425800597, 0.24825514586908476, 0.07393755896815232, 0.05828006485743182, 0.03259699871497495, 0.003744955631970827, 0.1369298052574907, 0.0625206780220781, 0.03978292204971824, 0.03044604609853455, 0.08461771373237882, 0.07724386333887066, 0.08745288409824882, 0.06283963697829417, 0.034127492125013044, 0.038649188421134434, 0.10783019315983568, 0.0293255371174642, 0.03131169732660055, 0.06798337346741132, 0.11180932606969561, 0.05415370002655046, 0.029254423254834752, 0.08539831398853234, 0.10585744080266782, 0.01941651026053088, 0.041841885673680475, 0.04024974735719817, 0.045521988200822046, 0.06451761336731059, 0.029120680609984056, 0.0063245193118096465, 0.01536438733871494, 0.048988708427974155, 0.0337085679971746, 0.10225625189819507, 0.02375022691142346, 0.02719580059471939, 0.08488810315196003, 0.050329632724502256, 0.0370517948509327, 0.042412859321172745, 0.0457476248432483, 0.059265107714704106, 0.03382103517651558, 0.0091688180941024, 0.017030083940231373, 0.02678434204842363, 0.052024558918284516, 0.044632645922579935, 0.06044833708022322, 0.026899340163384165, 0.011972233021099652, 0.04038548828767879, 0.06399829659078803, 0.0455448548309505, 0.03477929286392672, 0.04321471129411033, 0.08385667564081294, 0.033028984641922374, 0.031558436408106766, 0.059405130201152394, 0.055640268472156355, 0.05422625916876963, 0.012663816268156682, 0.024699439727036015, 0.016917840677446554, 0.08980266443852868, 0.0470809699036181, 0.01716977055184543, 0.03528689134067722, 0.05750401757125344, 0.10827975653644119, 0.040259728607322486, 0.05236150244516986, 0.08119510167411395, 0.03215928255979504, 0.054548417417598624, 0.018387757873694812, 0.018853774028165, 0.055782180678631575, 0.01777901696706457, 0.0007840594064743657, 0.07916900289377996, 0.0807542439017977, 0.024059269078341976, 0.04227058070578745, 0.07699528203478881, 0.10015053381877285, 0.0655635886692575, 0.05489313017044749, 0.036603853173021755, 0.10292718732463461, 0.05797980632632971, 0.06569956030164446, 0.17681151522057398, 0.11091273025210414, 0.09069761141602482, 3.3430015529905046, 10.133305805070059, 50.94659267153059, 94.69437217712402, 111.12500667572021, 91.83188806261334, 62.15434619358608, 40.4962796483721, 47.13966771534511, 51.92712940488543, 70.23332241603306, 83.7013909476144, 72.13550295148576, 62.23776626586914, 70.74643298557827, 77.65495041438511, 66.71487276894706, 65.03683417184013, 63.35064533778599, 45.33714519228254, 25.981289557048253, 10.88209753377097, 1.6098296514579227, 2.066860224519457, 1.0775974222591944, 1.0763232963425773, 0.9082722110407693, 1.3380978724786212, 0.8768645077943802, 1.7395527362823486, 1.19549879857472, 0.4557155179125922, 0.5380110133971486, 0.0739896772429347, 1.4233642114060265, 2.453329235315323, 1.2389535925218036, 0.8837987557053566, 1.2314588746854236, 1.8851125027452196, 2.1619261290345873, 2.3455014441694533, 0.044699413768414936, 0.33160123069371494, 0.6038631083709853, 0.5042769664100238, 0.6991870190416063, 0.4006776969347681, 0.2744596797440733, 0.03522655261414392, 0.209265994440232, 0.05095486542476075, 0.13379985892346927, 0.4420397531773363, 0.845948009618691, 0.6898936948605946, 0.16477057204714843, 0.32071372919848984, 0.6400355930839265, 2.1307543388434818, 3.03810960480145, 4.036338405949729, 16.60857786451067, 39.07879849842617, 74.47497531345913, 81.03549916403634, 75.08570112500871, 63.383586747305735, 54.07562010628836, 63.59090709686279, 72.8988389968872, 60.83002649034773, 36.33559758322579, 25.04829066140311, 40.11007792609078, 65.88017872401646, 90.28332219805036, 59.146964345659526, 9.06156267438616, 2.2440444997378757, 0.19317697919905186, 0.08026352737631116, 0.0412995801307261, 0.04782749752381018, 0.09728366908218179, 0.13273147839520658, 0.010102554374108357, 0.05263670946338347, 0.08264038804918528, 0.044513196617897065, 0.020676098564373593, 0.046786058228462934, 0.050754069949367216, 0.04059965768828988, 0.04820267649899636, 0.04478531290910073, 0.051808767818978856, 0.005081492351434592, 0.01734719388852162, 0.06752134540251323, 0.051338434485452514, 0.028816255873867443, 0.10142453759908676, 0.03878384369558521, 0.03201860867972885, 0.012067920877598226, 0.03915256980274405, 0.07628573118043797, 0.05216816406963127, 0.048996213025280407, 0.02467442722991109, 0.018913502073181526, 0.049123730111335, 0.03326835822580116, 0.03724946227989026, 0.06348812646631684, 0.034510250336357524, 0.03619098157754966, 0.025637298955449035, 0.028480747448546544, 0.07290421120290246, 0.06495138723403215, 0.01685961219482124, 0.010057412287486451, 0.006023330763647599, 0.052434794405209165, 0.1006887342248644, 0.09367957604782921, 0.23518411868384906, 0.11925418515290533, 0.07960751293493168, 0.15137397018926485, 0.13869706328426087, 0.13082866264241083, 0.11155783385038376, 0.11722357411469732, 0.222784176202757, 0.194466127880982, 0.25667717680335045, 0.1891133686793702, 0.2465052040559905, 0.13006001817328589, 0.12519800263856137, 0.12433938442596368, 0.10264005844614335, 0.12901537279997552, 0.12486463838389941, 0.09875574401978936, 0.12874520729695046, 0.09641682023980788, 0.19468403261687073, 0.11062089912593365, 0.16458305210939475, 0.2243359043662037, 0.1636222465229886, 0.11378774419426918, 0.22230563259550504, 0.12900573760271072, 0.19877824506589345, 0.08079675412071602, 0.13456962976072515, 0.27760534094912664, 0.12683529406785965, 0.18759644936238015, 0.14251615692462238, 0.1909538542053529, 0.1625415573694876, 0.17824342767042772, 0.11119746390197958, 0.12007922945278031, 0.2570520538304533, 0.2965029754808971, 0.11921698786318302, 0.26524601557425087, 0.25824934244155884, 0.16227546307657445, 1.4198105335235596, 1.9128831497260501, 25.132178000041417, 92.4642436163766, 143.58834539140975, 126.82337052481515, 93.12030642373222, 70.6281190599714, 58.73200402941023, 48.24762051446097, 52.725949900490896, 85.58432497297014, 101.77769933428083, 94.78668594360352, 85.14717905861991, 84.40123435429165, 73.53694765908378, 81.29401384081159, 73.16589995792934, 51.66803802762713, 26.86669502939497, 10.48326051235199, 1.0697178393602371, 2.859024780137198, 1.6616708125386919, 0.9940002794776643, 1.0306316167116165, 1.7405482828617096, 2.6104953161307742, 4.730654954910278, 2.1323261516434804, 0.8263012181435312, 0.3068816028535366, 0.10823943120028291, 2.853389139686312, 1.7715152097599847, 0.41943682889853207, 0.7269562003867966, 0.6464986662779535, 1.2118479098592485, 1.467735299042293, 5.091019366468702, 0.10755256377160549, 0.7606979555317334, 0.7742176843541009, 0.4804126183901514, 0.6521919550640243, 0.4340736706342016, 0.3632994826350893, 0.29082116750734194, 0.23593370988965034, 0.3064992347998278, 0.5201560971992356, 0.34147804070796284, 0.553098483809403, 0.5220914419208253, 0.25685508868524004, 0.2559154805328165, 1.0449673788888114, 3.6651487009865895, 2.5792258168969835, 1.5569474548101425, 15.043834856578282, 49.26561151232038, 96.63209969656808, 102.60229069846017, 86.29431969778878, 70.10942213875907, 69.17154734475272, 86.44968141828264, 81.06544589996338, 49.95706149509975, 36.28843668528965, 46.867346967969624, 72.6874817439488, 88.08752468654087, 121.6772289276123, 46.23221213476998, 1.7630523038761956, 0.7450069689324924, 0.2020928750612906, 0.29910390877297943, 0.18777170138699667, 0.15481452271342278, 0.37422794050404, 0.21912813452737673, 0.10812679438718728, 0.19892043886440142, 0.16939541245145456, 0.11753261967429093, 0.2624474657433373, 0.15027485202465737, 0.15595500437276705, 0.17034556503806794, 0.162411346499409, 0.16307595797947474, 0.18105681027684892, 0.19384693753506455, 0.18580346128770284, 0.247490328337465, 0.17832540827138083, 0.20677397958934307, 0.290456658495324, 0.15673857661230223, 0.10152631106653384, 0.07749482630086796, 0.11797935355986867, 0.14040515305740492, 0.11161580788237707, 0.17220806224005564, 0.14078965171107224, 0.1750372275710106, 0.15849085258586065, 0.1816412867712123, 0.17525403308016912, 0.16306530497968197, 0.14356336716030324, 0.1727340625865119, 0.11591776061270918, 0.17493920640221663, 0.1490512905376298, 0.17084716526525362, 0.15637249339904102, 0.155894275488598, 0.1483303335096155, 0.18190183064767293], [0.01856865530966648, 0.017476644799379364, 0.05475738923996687, 0.04693786347551005, 0.037915054243057966, 0.006541471978250358, 0.01762299971388919, 0.0399382692495627, 0.046993618697992394, 0.031759391339229684, 0.04313935998028942, 0.04478598805144429, 0.03440333357346909, 0.031375533901154995, 0.0413309555899884, 0.018185260971742015, 0.010994083231448062, 0.04900195003886308, 0.0206766990678651, 0.039380231872200966, 0.06500339015786137, 0.029102699431989874, 0.059487463640315194, 0.010439639545178838, 0.07999008454914604, 0.04387813873056855, 0.0734828319400549, 0.04353790430884276, 0.04638551900695477, 0.03281465917825699, 0.042171809755797894, 0.06536096454198871, 0.051377915045512576, 0.04568314366042614, 0.03615755694253104, 0.023540305140029107, 0.017563180066645145, 0.04610447658758078, 0.035759077074804475, 0.04758950136601925, 0.03951156911041055, 0.0447493878725384, 0.05763927674187081, 0.026024496482153023, 0.04327686849449362, 0.04912123988781657, 0.03185862030035683, 0.005394970016953136, 0.15741553742970738, 0.028123632771894336, 0.0842636948717492, 0.052057481437389336, 0.29654613030808313, 0.6648163433585847, 9.130606923784528, 49.33935969216483, 96.1265835080828, 88.91272054399762, 69.02462073734829, 51.94818244661604, 34.26633719035557, 23.734487056732178, 24.61839345523289, 42.805409227098735, 61.91177763257708, 66.87188121250698, 53.11894696099417, 65.95663670131138, 74.72521468571254, 64.82629680633545, 42.26748316628592, 25.258327756609233, 17.586958919252666, 6.799793754305158, 0.968319411788668, 0.20743485912680626, 0.23015823694212095, 0.7108117895466941, 0.37722321120756014, 0.6897134216768401, 0.5321578617606844, 0.5047748482653073, 0.7160208757434572, 0.0457027431444398, 0.26472462926592144, 1.2339051834174564, 1.6711587948458535, 3.226625523396901, 5.001021521432059, 5.722504658358438, 2.7765624736036574, 1.6765943488904407, 0.27834787539073397, 0.18246478401124477, 0.16052577910678728, 0.5225071938974517, 0.6590124262230737, 0.1830125381903989, 0.6830191037484578, 0.46468634796994074, 0.2771511296076434, 0.6624027671558517, 1.3466597901923316, 2.0929268257958547, 1.1549560597964694, 2.9247328085558753, 1.895316583769662, 1.0945853335516793, 0.845059508723872, 3.0791031079632893, 10.364082404545375, 11.901664035660879, 23.177137306758336, 45.75041709627424, 65.66819613320487, 66.37826034000942, 54.58535385131836, 52.84173468181065, 43.27579184940883, 25.0508736542293, 30.300927298409597, 31.211440086364746, 39.00156232288906, 51.44566787992205, 73.81211021968296, 52.071224621364046, 5.9182540859494885, 0.233875251774277, 0.06870904631380524, 0.09986167467598404, 0.1819905558867114, 0.059797581285238266, 0.13095542655459472, 0.07627359897430454, 0.012594895769975014, 0.07739217073789664, 0.006621698566180254, 0.042364184611610005, 0.12496773499463286, 0.0449226382188499, 0.08841590170881578, 0.06197846068867615, 0.03587806158299957, 0.027349527792206833, 0.010975640649641199, 0.024823292723989913, 0.018229135046047822, 0.04060524542416845, 0.07067635003477335, 0.010532101815832513, 0.014033528261019714, 0.0006042423784882495, 0.06705487971859318, 0.06765714740114552, 0.029061739665589163, 0.028732446621039083, 0.010571729957259126, 0.03609245829284191, 0.075299426248031, 0.014027740357310643, 0.022520388975473385, 0.016090513107233813, 0.06255465227046184, 0.04396229064358132, 0.05424425731013928, 0.028202807630545328, 0.08831350398915154, 0.06038090427006994, 0.10475191726748433, 0.03806967201775738, 0.03160000346334917, 0.043403876679284234, 0.034413026446210485, 0.02023450967057475, 0.05059407139196992, 0.015171686786093881, 0.0362083826081029, 0.0485442374566836, 0.07330135096396719, 0.04200316666226302, 0.045381606090813875, 0.05623710448188441, 0.034328487768237076, 0.020235807368797914, 0.13613723564360822, 0.05948882071035249, 0.05588163694898997, 0.04592696164867707, 0.0593390612463866, 0.02327877908412899, 0.055757156307143826, 0.048566082891608985, 0.04466355997802956, 0.020949465056349124, 0.05199579242616892, 0.10234592030090944, 0.041302212846598456, 0.057936210451381545, 0.027610485575028827, 0.028753650840371847, 0.07171394542923995, 0.04967297028217997, 0.05094590197716441, 0.02972257849095123, 0.01790713455661067, 0.015548819942133767, 0.04456010035106114, 0.0342888172183718, 0.03569765608491642, 0.053356272101934464, 0.057006278208323886, 0.02972539101860353, 0.032925793036286316, 0.045855688330318244, 0.026365875931722776, 0.10862863210162946, 0.010047498890863997, 0.017851811900202717, 0.04079653123127563, 0.015813462170107023, 0.09417748504451343, 0.054360198588775735, 0.07694552506187133, 0.04459012891831143, 0.13416852056980133, 0.03710959246382117, 0.26444765127130915, 0.13623440185827868, 2.8437834722655158, 7.361110057149615, 37.36370515823364, 82.86395236424038, 101.60138879503522, 88.9238029207502, 58.094583238874165, 44.34366396495274, 39.073034967694966, 60.810036523001536, 70.6692384992327, 80.95322554452079, 75.67112159729004, 67.41149915967668, 62.26442650386265, 73.76791272844586, 83.47679737636021, 82.1011860711234, 64.33285658700126, 48.793231282915386, 39.105232919965474, 19.67243640763419, 5.6039497171129495, 1.6677659026214053, 1.5649206212588718, 2.0237147339752743, 0.27104849421552246, 1.2596490191561835, 0.6453364714980125, 0.4924629660589354, 0.5752513493810381, 0.36420565258179394, 0.24613483250141144, 0.5047856505428041, 1.1537466389792306, 3.6760360939162116, 4.681814764227186, 4.416823063577924, 2.421915126698358, 1.4837717413902283, 0.19388374127447605, 0.23017661167042597, 0.4380168819001743, 0.6892295447843415, 0.5459610553724425, 1.5078984924725123, 1.3449088441474097, 0.7417282877223832, 0.7519983766334397, 0.683174298277923, 1.381646684237889, 1.8680512011051178, 1.8385528411184038, 2.1391864120960236, 3.1148552809442793, 2.291215819971902, 2.4123852380684445, 8.895730018615723, 25.511886630739482, 39.75786679131644, 56.9922445842198, 75.35108062199184, 85.9294628415789, 76.5926125390189, 70.18851348331997, 63.21692030770438, 59.557053974696565, 59.99023246765137, 59.93621022360665, 37.44122273581368, 37.53270966666085, 58.763430731637136, 87.64491748809814, 76.66820893968854, 23.81374863215855, 2.1181422727448598, 0.2076795388545309, 0.21635223419538566, 0.07218416341181312, 0.05392178354252662, 0.029726938078446046, 0.043796225983117304, 0.05538995011842676, 0.07314060601804938, 0.04728713598368423, 0.008742074698342808, 0.08510421655539956, 0.07903026283851691, 0.0703710907005838, 0.05413605472339051, 0.08469140942075423, 0.11010200304112264, 0.030997399905962602, 0.020416070374527147, 0.0508233110553452, 0.022107751474582722, 0.04940732382237911, 0.020059825919036354, 0.04462866631469556, 0.04592195406023945, 0.025684401160106063, 0.04232174903154373, 0.013773696846328676, 0.06753468540097986, 0.06811113482607262, 0.01257190021819302, 0.05432090123317071, 0.04215959951813732, 0.03738726595682757, 0.01621160955567445, 0.026417836447113326, 0.07025286954428468, 0.017943258064665964, 0.010616042534820735, 0.03456761368683406, 0.04205812799877354, 0.002027401355527607, 0.020176001292254244, 0.03445425423394356, 0.005467050791984158, 0.02751236771499472, 0.09010012062000376, 0.06509138257907969, 0.03956875943445733, 0.10717734747699328, 0.09753326140344143, 0.1433423954461302, 0.14079734629818372, 0.11766033353550093, 0.11220195357288633, 0.08364841967288937, 0.0943553697850023, 0.17437834292650223, 0.176577556346144, 0.15063835680484772, 0.18056331175778592, 0.08902240344988448, 0.15804629001234258, 0.1390052946018321, 0.07630250456609897, 0.23801768092172487, 0.18815582006105355, 0.17922017882977212, 0.16493518464267254, 0.12205363065004349, 0.17745950259268284, 0.1391493340155908, 0.17681140665497097, 0.2202019840478897, 0.11677475034126214, 0.21121455702398503, 0.14187572843262128, 0.11649383684354168, 0.08592397506747927, 0.14545280220253126, 0.12048621475696564, 0.09763848861413342, 0.21762627868780068, 0.30663507751056124, 0.2817858766232218, 0.16452677441494806, 0.12842628226748534, 0.08894767638828073, 0.22037536331585475, 0.12169197148510388, 0.13964737871927874, 0.14617401707385266, 0.09255048020609788, 0.1958573960832187, 0.2432461189372199, 0.10147901717573404, 0.2451062005545412, 0.3283838890492916, 0.18134817321385654, 0.2886474941458021, 0.15586017231856072, 0.8734350289617265, 1.126797399350575, 14.736128670828682, 72.03518486022949, 136.0485632760184, 132.17644337245395, 95.66752992357526, 73.55180290767125, 58.9658317565918, 52.018150806427, 53.39939362662179, 71.20752934047154, 85.51862975529262, 91.1155218396868, 81.19879572732108, 87.33806419372559, 107.21938950674874, 108.1482663835798, 86.32514885493687, 64.47582966940743, 46.427473885672434, 18.09322551318577, 3.270995851073946, 1.7860086091927119, 3.686214770589556, 4.806351670197078, 4.987516828945704, 4.6960985234805515, 2.9304509588650296, 1.6354028220687593, 1.3848221195595605, 0.46364813510860714, 0.3501524052449635, 2.8818105288914273, 2.851646661758423, 5.8071984222957065, 7.870254942349025, 12.979371326310293, 13.346713032041277, 4.823168482099261, 0.34591166994401384, 0.4912995227745601, 0.8617034299033028, 1.2627579037632262, 2.3252211724008833, 2.1119004019669125, 2.520728064434869, 1.0463170664651054, 0.9186529283012662, 1.3881827677999223, 2.939812570810318, 4.898442225796836, 7.383359926087516, 5.7182788508278986, 4.224902527672904, 1.118880795581, 0.6775263899138996, 4.608042699950082, 24.1312152998788, 49.6886282648359, 76.5419671194894, 99.86064270564488, 107.3213334764753, 93.85512706211635, 86.5380277633667, 80.13964012690953, 67.51902253287179, 55.781830174582346, 69.63989067077637, 60.682050704956055, 65.32719939095634, 82.12515040806362, 115.2766387122018, 76.62636688777378, 8.14234379359654, 0.3864626054252897, 0.22243530063756875, 0.19928559927003725, 0.4464456710432257, 0.13061226425426348, 0.2966193306658949, 0.14539420391832078, 0.125948733783194, 0.18287262426955359, 0.13615816166358335, 0.0982229651084968, 0.2890436771724905, 0.16534257706786903, 0.16355425731412002, 0.14782449922391347, 0.1598206048033067, 0.1667885080512081, 0.1162437152649675, 0.07583817626748766, 0.15333343004541738, 0.14835625354732784, 0.2088063276771988, 0.21948979369231633, 0.14083527640572616, 0.12305337057581969, 0.1972870286554098, 0.1708537470549345, 0.10933420674077102, 0.14546507011566842, 0.11714821601552622, 0.11090967005917005, 0.20540294530136244, 0.17702758791191237, 0.2649251770760332, 0.06736882430102144, 0.17040702674005712, 0.22072851365166052, 0.18130049934344633, 0.16130910707371576, 0.13164686730929784, 0.18886574410966464, 0.2059179398098162, 0.08313858203057732, 0.12349483902965273, 0.10381873484168734, 0.12979233610842908, 0.15780899274562085, 0.13734463442649159, 0.09753175505570003], [0.05898105259984732, 0.07015861424484424, 0.07497408227728945, 0.03355079164196338, 0.016560943132000308, 0.012563497410155833, 0.07124914894146578, 0.09923576683338199, 0.0280461881775409, 0.05871641715722425, 0.034837148152291775, 0.01999627093651465, 0.009063013280475778, 0.014767678554302879, 0.054384127126208374, 0.002380431887494134, 0.03440291966710772, 0.0400860711399998, 0.10033512927059617, 0.06349079989429031, 0.03519997779013855, 0.07601974545312778, 0.04201282900092857, 0.05352076595383031, 0.028106308076530695, 0.05976006508405719, 0.0399998700512307, 0.03328583389520645, 0.01412073867062905, 0.019876562092187147, 0.05198946508712002, 0.029104314345334257, 0.06509772009615387, 0.1243018207273313, 0.10381496218698365, 0.0550100960369621, 0.07616202746118818, 0.05262339660631759, 0.05752372222819498, 0.03429769924176591, 0.06383044059787478, 0.09766560287347861, 0.0038759667492870775, 0.04378486052155495, 0.13992157472031458, 0.03901867448751416, 0.044935672876558135, 0.0697602666914463, 0.04091906787029334, 0.09032433573156595, 0.005560654273722321, 0.07204172534069844, 0.02101809548081032, 0.13193095635090554, 0.30102348434073584, 0.025947146882702197, 3.0270016065665653, 40.0040727342878, 85.94192096165249, 93.8817525591169, 62.80663612910679, 51.296611649649485, 38.8749418258667, 34.15195941925049, 17.204521383558, 27.868362971714564, 53.800916126796174, 60.41166155678885, 63.60661697387695, 85.78469017573765, 80.45357363564628, 64.12073503221784, 38.153284549713135, 18.656932864870342, 13.358257464000157, 18.336591379983084, 13.778897064072744, 6.013920792511531, 4.122819593974522, 2.866153849022729, 0.27867802338940756, 0.08757620783788816, 0.14873003134770052, 0.023932371155491898, 0.06632480317992823, 0.11126334286694016, 0.21697641855904035, 0.39750413436974796, 0.3575627676078251, 1.0615198335477283, 0.8942046059029443, 0.6958082403455461, 0.25358786114624565, 0.31215238145419527, 0.32352967666728155, 0.2774367385676929, 0.27501539992434637, 0.42881548564348904, 0.8458178394607135, 1.1531777552195956, 1.3609270474740436, 1.50856790798051, 0.5868874649916376, 0.18853973517460482, 0.8468139288680894, 3.0944599296365465, 7.366997786930629, 11.874009336744036, 18.238246577126638, 22.006602082933696, 33.498842648097444, 46.71545239857265, 59.25974750518799, 67.30310726165771, 66.18493366241455, 60.474160603114534, 45.88753284726824, 30.42859697341919, 29.611877918243408, 31.535695144108363, 45.47304500852312, 49.408699240003315, 63.84052807944161, 62.08922072819301, 13.876203979764666, 0.30994613841176033, 0.27052233102066175, 0.17881288139947824, 0.11477060216878142, 0.07263285826359477, 0.07917749815221344, 0.09627191908657551, 0.024997572747192214, 0.03444723818185074, 0.07254871992128235, 0.004695858423864203, 0.0721920072766287, 0.07127325729067836, 0.02555524541198143, 0.02039176016114652, 0.04670766707775848, 0.021985240280628204, 0.027887875779664943, 0.07213827408850193, 0.014279250388166733, 0.029674989437418323, 0.046708437215004645, 0.09549567502524171, 0.06966986547091178, 0.07347515770899397, 0.05362191177638514, 0.021613338629582098, 0.1037184948633824, 0.06604477177773203, 0.015899785395179476, 0.018669371958822012, 0.05917674209922552, 0.024481446781594838, 0.03205032001382538, 0.007196326124747949, 0.03683780526210155, 0.05921592749655247, 0.10919296967663936, 0.02818322510990713, 0.05544476217723318, 0.05280438903719187, 0.030651584533708434, 0.042279381304979324, 0.036922985155667574, 0.05395579511033637, 0.07422301186514751, 0.0707429414615035, 0.03612839011475444, 0.020618592721543143, 0.01772935498904969, 0.0693443382957152, 0.12612695779119218, 0.08356774864452225, 0.07540143720273461, 0.08722085226327181, 0.05865593933101211, 0.03655988410381334, 0.12650230979280813, 0.05740278693182128, 0.015572577149474194, 0.01916233104254518, 0.03949013079649635, 0.06083417244787727, 0.006048907293006778, 0.033153485639819076, 0.031070844536381106, 0.014917975757271051, 0.061929796157138686, 0.07106405137372868, 0.05625339950035725, 0.09473330700503928, 0.1115897453523108, 0.10201748899583306, 0.10141737226928983, 0.05724428115146501, 0.007592600753663906, 0.03363957455647843, 0.08452335665268557, 0.026209726364218762, 0.03340114752895065, 0.038434506726584265, 0.03578034575496401, 0.0625618447416595, 0.023522670014894435, 0.047222206967749765, 0.07587817590683699, 0.05308369779959321, 0.008471500377969017, 0.031749345628278594, 0.07122518308460712, 0.05366445931472948, 0.04714762579117503, 0.037868561023580175, 0.05035779192777617, 0.024215949599498084, 0.0715853019750544, 0.013204126918156232, 0.0368603224466954, 0.1828844172081777, 0.05849522152649505, 0.11607239874345915, 0.30963751354387825, 0.066727547640247, 0.07674018679452793, 0.06941202894917556, 2.1592130746160234, 2.6597109266689847, 23.30564250264849, 69.47785867963518, 96.85055106026786, 90.4267052241734, 63.30568354470389, 41.215817723955425, 39.33489867619106, 50.4572206224714, 58.468236514500205, 65.28469726017543, 75.92394569941929, 75.61659213474819, 79.54680592673165, 94.82829175676618, 97.94141129084996, 90.58692373548234, 69.28556033543178, 48.77080944606236, 35.07765749522618, 36.15265498842512, 29.908326285226003, 14.707337072917394, 11.288436004093715, 8.07409771851131, 3.4951447376183102, 1.109643816947937, 1.1570387823241097, 0.42869261652231216, 0.4477386330919606, 0.4959274030157498, 1.3982398509979248, 1.5159384267670768, 3.357474650655474, 4.255156721387591, 1.987985142639705, 2.745268438543592, 1.8584342428616114, 1.9444340510027749, 1.480492951614516, 1.1983571137700761, 0.9915761181286403, 1.1747232505253382, 1.6166709129299437, 2.6475289974893843, 2.3035903445311954, 1.8075190378086907, 1.7149730495044162, 0.5529536572950227, 3.0836515724658966, 8.244180934769766, 18.273864780153545, 26.8966452394213, 42.42525938579014, 55.7546557698931, 68.8215457371303, 88.33477633340019, 85.94708347320557, 81.0152312687465, 76.61545821598598, 75.79832226889474, 69.52350834437779, 64.00649969918388, 55.739456585475374, 42.41425691332136, 51.48327153069632, 64.09147616795131, 78.58405658176967, 80.81912531171525, 38.07144519260952, 1.8370971935135978, 0.6813461620892797, 0.14940665289759636, 0.07990170536296708, 0.1550090994153704, 0.1654277874955109, 0.07871351590646164, 0.03417969860934785, 0.026638499427852885, 0.05423672557143228, 0.024551607302523086, 0.03532953726659928, 0.039239829406142235, 0.0684408824890852, 0.09464317719851222, 0.04797620525849717, 0.0032303095088406864, 0.13173773671899522, 0.02765289062101926, 0.037174643616058996, 0.062300316989421844, 0.12855630314775876, 0.03125045954116753, 0.008752194199977177, 0.09319324285856315, 0.031425053386815956, 0.1074370906821319, 0.012120609969965048, 0.013447756612939494, 0.0011434061452746391, 0.08757514253790889, 0.05272243218496442, 0.058832582352416854, 0.05968497839889356, 0.03813588346487709, 0.06981467841459171, 0.04842664394527674, 0.04110662512747305, 0.07404240619923387, 0.05789990882788386, 0.05173647669809205, 0.041139975123639615, 0.024068788924653615, 0.05712386154170547, 0.027763902342745235, 0.04602717448558126, 0.06889181650642838, 0.04886128972949726, 0.020658928235726695, 0.03855674820286887, 0.08029946937624897, 0.24997029240642274, 0.2889220836971487, 0.1606175306120089, 0.15223342978528567, 0.19167163568947995, 0.16478687045829638, 0.24784620638404573, 0.15795645197587355, 0.12072959169745445, 0.15942959221346037, 0.13241046347788402, 0.10902423158820186, 0.1076288175370012, 0.08228741413248436, 0.10992831164704901, 0.12179930215435368, 0.15113128535449505, 0.13621343512620243, 0.15006633821342671, 0.1504699715546199, 0.25372839931930813, 0.2417013661137649, 0.1484023667871952, 0.14178732889039175, 0.12542941022132123, 0.18610382159905775, 0.15263179769473417, 0.2517514739717756, 0.1395951858056443, 0.10957619946982179, 0.16753077107880796, 0.17337975651025772, 0.12758401674883707, 0.14829878163124832, 0.25079503815088955, 0.2262321383293186, 0.18660801383001463, 0.1844250988215208, 0.169717187327998, 0.1486272332923753, 0.2637761187340532, 0.11059736753148691, 0.15988214792949812, 0.13194384851625987, 0.24808005669287272, 0.09513941021370036, 0.16113385504909924, 0.36758947957839283, 0.1647570420588766, 0.238110395946673, 0.807472034224442, 0.15497046363140854, 0.09514537453651428, 0.20210050179490022, 0.7290266007184982, 0.426243675074407, 6.134558456284659, 54.26002182279314, 121.87914357866559, 137.99000113351005, 97.35515703473772, 76.5302038192749, 66.94936752319336, 63.987364360264365, 52.32726573944092, 57.590241295950754, 78.68092836652482, 87.6105169568743, 83.46446432386125, 108.92909104483468, 113.93840871538434, 110.35147067478725, 94.50487395695278, 71.82809380122593, 46.77276808874947, 38.18348142078945, 25.21333817073277, 10.532033392361232, 9.348649212292262, 6.409166463783809, 2.5960775869233266, 0.40022158569523264, 0.41486466995307375, 0.18341477374945367, 0.22607059271207877, 0.2337561281664031, 0.29894325882196426, 0.4023787299437182, 0.7506384296076638, 1.1635554326432092, 0.35606890491076876, 0.673501863011292, 0.5085258984139988, 0.6317612113697189, 0.6853746516363961, 0.6679357045463153, 0.6082213116543633, 0.6744262448378971, 1.5557168637003218, 2.8576957200254713, 3.1663010460989813, 2.419170153992517, 1.6110463461705615, 0.2044836524873972, 1.2387129025799888, 3.578409343957901, 14.55848147187914, 25.92262417929513, 46.07565532411848, 64.20224434988839, 81.26246901920864, 106.83161054338727, 108.34206553867885, 97.90557248251778, 88.53377274104527, 83.89902550833565, 72.4793484551566, 61.964952196393696, 62.213614327566965, 59.75360461643764, 69.15573324475969, 87.24149812970842, 109.4996701649257, 90.23795740944999, 20.30908247402736, 0.2125493304005691, 0.2990552713828427, 0.2313707247376442, 0.16978167529617036, 0.26051516085863113, 0.17725119234195777, 0.30595097850475994, 0.09331877862236329, 0.08804407808929682, 0.19355606314327034, 0.14077845588326454, 0.21515394135245255, 0.23858575043933733, 0.19964771983878954, 0.22583002490656717, 0.30887622439435547, 0.0724358456209302, 0.12651001795061997, 0.13977540470659733, 0.10545861827475683, 0.15069251747003623, 0.21383100162659371, 0.29143499742661205, 0.1469538573707853, 0.24415199032851628, 0.2318186935569559, 0.1517518191997494, 0.37331740079181536, 0.3315597043505737, 0.08847423536436898, 0.1562920869993312, 0.15572823796953472, 0.16029426295842442, 0.14655189322573797, 0.1639596548463617, 0.12264700952385153, 0.174196224127497, 0.26914685911365915, 0.2864844330719539, 0.1781797810856785, 0.2774522363075188, 0.1629036779382399, 0.23616970436913626, 0.18198560258107527, 0.1867878527513572, 0.11367157899907657, 0.12960895523428917, 0.0807752784873758, 0.0804687435073512, 0.16110980776803835, 0.14478052327675478], [0.1449207357530083, 0.10625632439873048, 0.16822449171117373, 0.16484415238457067, 0.13634420239499637, 0.06279099280280726, 0.06997502981019871, 0.05025986236120973, 0.12644205588315213, 0.03447280198867832, 0.04180812177115253, 0.0660417794382998, 0.08163951496992793, 0.08923673230622496, 0.15650403419775621, 0.1845972974385534, 0.04927249212882348, 0.03698946462411966, 0.04924376295613391, 0.11000993940979242, 0.05808588170579501, 0.16918824213956082, 0.15151429123112134, 0.1688919530383178, 0.11769827721374375, 0.0504401592936899, 0.08141851611435413, 0.08439023486737694, 0.13913631971393312, 0.08390104504568235, 0.1884902021182435, 0.04975019435265234, 0.1179804934987, 0.03373855245964868, 0.14241714509470121, 0.1561103481799364, 0.23940770061952726, 0.19005095479743822, 0.18375226349702903, 0.23275024071335793, 0.1570262483188084, 0.1424423458852938, 0.06407313221799475, 0.032766371233654876, 0.02212780388072133, 0.06030553938554866, 0.08649904706648417, 0.16048527056617395, 0.30413777008652687, 0.14381921557443483, 0.05347117522199239, 0.026765236198636036, 0.04675773956945964, 0.16192338482609817, 0.05361334187909961, 0.052132215284343274, 0.156641600387437, 0.4189295561185905, 1.3705613762140274, 23.857193980898174, 60.297676358904155, 78.269747870309, 49.33467313221523, 41.235060759953086, 40.296300070626394, 41.8013528415135, 42.4465069770813, 51.18878255571638, 57.444728646959575, 61.719187464032856, 63.93391186850411, 61.794895035879954, 52.840633392333984, 43.269069467272075, 44.42988068716866, 35.13507740838187, 33.088099888392854, 39.97661345345633, 51.177029677799766, 54.96087966646467, 56.61631229945591, 49.187235832214355, 45.74218348094395, 39.68837438310896, 38.02851227351597, 37.80324820109776, 33.204311983925955, 30.855296271187918, 31.607525621141704, 27.276008197239467, 24.91899684497288, 21.499970708574565, 16.61860237802778, 12.613996829305377, 10.811559421675545, 10.13032763344901, 7.464151842253549, 10.266699058668953, 11.512916667120797, 14.752604586737496, 20.406866209847585, 25.128116777965, 29.569021429334367, 33.42276334762573, 35.93451976776123, 33.71642896107265, 42.56252104895455, 43.88655240195138, 47.262928758348735, 59.21104758126395, 63.6617648260934, 55.94346611840384, 54.16431038720267, 65.16151959555489, 57.90931647164481, 46.360389028276714, 44.74508919034685, 45.25651829583304, 47.234920569828574, 56.392920766557964, 61.04055690765381, 40.56069639750889, 13.554949675287519, 0.5047278936420168, 0.7165048612015588, 0.1452088010098253, 0.10320532561412879, 0.11952445922153336, 0.04946424612509353, 0.0960237652595554, 0.09726155562592403, 0.030594509560614824, 0.016253904339724352, 0.09763062439326729, 0.11265684344938823, 0.13469194248318672, 0.010405479547833758, 0.12595627909260138, 0.099598532010402, 0.12558222987822124, 0.11504547670483589, 0.26577245018311907, 0.12131011911800929, 0.08061505601342235, 0.09006658741938216, 0.09918709551649434, 0.13118839476789745, 0.03676271518426282, 0.13385106117597648, 0.2477705090173653, 0.3093395009636879, 0.2196637157882963, 0.23023162728973798, 0.1170170959085226, 0.16007477045059204, 0.062035586551896164, 0.06776475626975298, 0.07682510545211178, 0.030412200771804367, 0.038988252369953055, 0.17401379320238317, 0.06973019401941981, 0.09222553657101733, 0.024163849984428713, 0.11814060062170029, 0.09405517232205186, 0.12793084313826902, 0.1210556820567165, 0.06758588086813688, 0.06982294297111885, 0.027571669979287044, 0.039575687276997736, 0.03414556829790984, 0.1336758498634611, 0.12536068819463253, 0.04062792206449168, 0.11572695656546525, 0.13494380111140863, 0.19298104542706693, 0.10802279532487903, 0.16303904567446026, 0.18038337784154074, 0.15805752655225142, 0.12669637080814156, 0.05725777721298592, 0.0411830078145223, 0.055440209207258055, 0.13720131425985269, 0.02052793196136398, 0.0548717868514359, 0.10031294117548636, 0.0817487658932805, 0.12271874424602304, 0.07722894235381059, 0.06137259677052498, 0.0967721011755722, 0.19506827342723096, 0.2207255552389792, 0.2330683379301003, 0.15544683592660086, 0.0912827393040061, 0.1143678780645132, 0.028627870803964988, 0.12261251280350344, 0.1934922401394163, 0.132771335542202, 0.028162134545189992, 0.10795923016433205, 0.24959639246974671, 0.30029221358043806, 0.12908184209040233, 0.20040751621127129, 0.24762307692851337, 0.08019097162676708, 0.20698724314570427, 0.2566453670816762, 0.21704439419720853, 0.17122000668730053, 0.09428564352648598, 0.15542238152452878, 0.017744964687153697, 0.07150523484285388, 0.14405557646283082, 0.10820025937365634, 0.25017271297318594, 0.15170652020190442, 0.08178318118942635, 0.0635172084772161, 0.1749704461544752, 0.16759557117308888, 0.0054952973566417184, 0.021521894161456397, 0.6052650702851159, 4.4377475636346, 13.818500927516393, 59.23403222220284, 92.16584627968925, 97.81297383989606, 66.98585251399449, 53.89037070955549, 39.19686576298305, 44.700002329690115, 67.52940314156669, 77.08410031454903, 75.10380813053676, 88.9647000176566, 83.02915273393903, 79.1387938090733, 76.37088857378278, 77.38629831586564, 73.00069264003209, 64.25545365469796, 60.62981414794922, 66.52335957118443, 73.76328522818429, 77.59349359784807, 77.22659397125244, 68.41192858559745, 65.50409357888358, 66.94192600250244, 62.27804497310093, 68.21362004961286, 67.64772401537213, 64.52530084337506, 62.17744895390102, 58.33624158586775, 50.81712341308594, 40.149561064583914, 30.452203478131974, 32.83907992499215, 35.10762160164969, 33.878210817064556, 32.06870535441807, 31.165033067975724, 28.889194045748027, 34.31294570650373, 40.40252413068499, 43.944014004298616, 48.079140595027376, 53.45351661954607, 56.531881264277864, 59.230981963021414, 67.52668639591762, 72.38747242518834, 74.35179764883858, 90.64036927904401, 90.73577499389648, 76.91491167885917, 77.74351910182408, 85.9988545009068, 80.79639080592564, 71.73500878470284, 56.337672165461946, 42.81043972287859, 47.1917062486921, 60.673289026532856, 82.99885163988385, 80.39405536651611, 45.563309056418284, 8.202258110046387, 1.6560707816055842, 0.12442042864859104, 0.11858756520918437, 0.07740133774599858, 0.011806882518742765, 0.21831860153802804, 0.052538959708596976, 0.0645746917330793, 0.14914391056767531, 0.06325134488620929, 0.04202884921271886, 0.04270152847415634, 0.04607611043112619, 0.19180399073021753, 0.1144716532102653, 0.21525344172758715, 0.04480545861380441, 0.24754414973514421, 0.1045789315498301, 0.08013037844960179, 0.07952107435890607, 0.11731360214097158, 0.1059478691646031, 0.05461530400706189, 0.114927845874003, 0.146662725135684, 0.24263101337211473, 0.13898278080991336, 0.14615195111504622, 0.1667917107364961, 0.18112064685140336, 0.14036464451679162, 0.08298887684941292, 0.05929489540202277, 0.1750061913792576, 0.04794247867539525, 0.12516528367996216, 0.09505194704979658, 0.03885723404320223, 0.1311063870255436, 0.19752712148640836, 0.11824152592037405, 0.21979574513222488, 0.1263785314347063, 0.06632113230547734, 0.051107702045036216, 0.06261751175458942, 0.06272662018558808, 0.029279257636517286, 0.04631326859816909, 0.039493187596755366, 0.053878893343997855, 0.31942084857395714, 0.25674114908490864, 0.3834426631884915, 0.4120058390711035, 0.35709989815950394, 0.4019118164266859, 0.3121589225317751, 0.26592729187437464, 0.2635302719260965, 0.1348810094807829, 0.1991582111056362, 0.28199215126889093, 0.12451911478170327, 0.1487540379166603, 0.21159811929932662, 0.34292674011417795, 0.21866686642169952, 0.2850070723465511, 0.18896844717008726, 0.2542959531503064, 0.2644297922296183, 0.35708901445780483, 0.3488019034266472, 0.2942730379956109, 0.19579822782959255, 0.16191821438925608, 0.22903710710150854, 0.25944255984255243, 0.3405686409345695, 0.28834997011082514, 0.2730341319526945, 0.19656000552432878, 0.44126117495553835, 0.3563437930175236, 0.38431840762495995, 0.3663055013333048, 0.5864547767809459, 0.29297391484890667, 0.3248020383928503, 0.4375305894230093, 0.31854423561266487, 0.307742175246988, 0.2954258147094931, 0.18470055689769133, 0.09207524784973689, 0.32919595975961, 0.3206374618623938, 0.24848891475370952, 0.4360405536634581, 0.4798423232776778, 0.303821219929627, 0.16302954618419918, 0.6235862757478441, 0.37168096431664055, 0.12229152502758162, 0.19354116251426084, 0.36867646553686684, 0.6720024634684835, 2.3830471209117343, 36.163473333631245, 105.43616907937187, 142.33436230250766, 98.08109787532261, 77.96079621996198, 66.18258517129081, 73.32272774832589, 83.19319970267159, 86.2571051461356, 92.15682056971959, 94.53401470184326, 91.80524172101701, 84.70690645490373, 88.05044215066093, 90.69676780700684, 96.06220149993896, 95.74596813746861, 83.78243473597935, 82.37387507302421, 85.2757624217442, 80.46230057307652, 76.77936622074672, 70.21110207693917, 64.57343101501465, 69.3459540775844, 69.34884452819824, 77.81703799111503, 79.20662907191685, 73.44117368970598, 71.07796628134591, 64.14463683537075, 52.95239864076887, 41.9904967035566, 28.779450723103114, 32.17043045588902, 34.468328271593364, 34.839532307216096, 29.97835717882429, 28.28718474933079, 23.630837304251536, 28.425142969403947, 35.03963695253645, 36.28610903876168, 44.56350496837071, 53.82127087456839, 58.43451690673828, 73.7860336303711, 85.23397595541817, 95.3051883152553, 101.4551500592913, 121.25552885872978, 106.33437660762242, 82.04965823037284, 76.55975450788225, 95.59963907514299, 96.20018577575684, 81.14119516100202, 74.1811637878418, 66.25358186449323, 72.07681846618652, 91.55442564828056, 115.60519817897251, 88.98371028900146, 29.600635732923234, 1.6402739435434341, 0.5341209449938366, 0.14185165401015962, 0.2590991939817156, 0.270036445664508, 0.1046969559309738, 0.44807323228035656, 0.19204943041716302, 0.22712104634514876, 0.26180291175842285, 0.2358361365539687, 0.2839860128504889, 0.2054348907300404, 0.24963477041040147, 0.40030974096485544, 0.22600583332989896, 0.3321237569408757, 0.21145034794296536, 0.443362652191094, 0.24041364235537394, 0.1806195487401315, 0.35206033715179985, 0.3475198250796114, 0.2790149024554661, 0.27470308382596287, 0.4856276756950787, 0.5050826317497662, 0.5699628474456924, 0.4621789710862296, 0.42387127237660543, 0.3553418953503881, 0.3478502987750939, 0.22975632707987512, 0.25532195238130434, 0.2238126860133239, 0.18045132633830818, 0.16880096149231705, 0.2802246761109148, 0.3181990241365773, 0.19939035150621617, 0.38199187389441897, 0.46571880685431616, 0.27341894273247036, 0.5844457702977317, 0.3013133273593017, 0.2803213537803718, 0.15362110175192356, 0.13586792509470666, 0.14304682559200696, 0.12944493974958146, 0.30384806277496473, 0.2486167507512229, 0.1569188090839556], [0.05082875969154494, 0.04730437755850809, 0.11926128262920038, 0.16958386876753398, 0.12366099868501935, 0.03989946043917111, 0.11161526505436216, 0.0613963319254773, 0.0386507151249264, 0.026582900268424834, 0.09363658406904765, 0.07353966603321688, 0.1106135438063315, 0.021695266644071256, 0.030058738309890032, 0.02128666133752891, 0.01320023467165551, 0.009848191103498851, 0.05686936341226101, 0.14859477217708314, 0.08270957147968666, 0.03564603653337274, 0.009045018531781222, 0.02811056249109762, 0.049196082300373485, 0.052382075626935275, 0.09992543661168643, 0.08440078608691692, 0.11411725437002522, 0.09550559520721436, 0.0432145789797817, 0.06469405961355992, 0.10228179874164717, 0.07050078588404826, 0.05797606759837695, 0.12289562475468431, 0.09146101759480578, 0.14800357818603516, 0.17328952492347785, 0.21626976504921913, 0.05991639955235379, 0.02980544458010367, 0.06974865017192704, 0.039214442018419504, 0.025621487393176982, 0.033274163092885695, 0.14558671787381172, 0.11250130286706345, 0.1474119227911745, 0.058388467612011094, 0.019938268066783036, 0.06394343024918012, 0.023775010402979593, 0.0062903800945995104, 0.041092569274561744, 0.15315483962850912, 0.05487358836191041, 0.10320661483066422, 0.01781342038884759, 0.456374782536711, 0.48227956678186146, 11.655907120023455, 55.000064032418386, 75.63568578447614, 73.28043406350272, 60.45276015145438, 52.352310521262034, 56.455041136060444, 61.35205159868513, 56.70212255205427, 67.9874700818743, 68.69215638296944, 65.88402802603585, 44.518834999629426, 48.23682648794991, 57.048090730394634, 51.42545209612165, 67.05070005144391, 71.46543257577079, 78.80443259647915, 91.8603687286377, 100.26684134347099, 92.09174374171666, 81.43839740753174, 79.97776099613735, 66.05197988237653, 54.86890288761684, 68.89206995282854, 83.14696638924735, 79.29172366006034, 71.40333652496338, 56.873465129307334, 44.038297585078645, 45.79091119766235, 43.96854114532471, 22.0225099836077, 33.02275555474417, 49.470190797533306, 61.11012922014509, 65.22501918247768, 71.05925478254045, 78.3920431137085, 78.76007529667446, 79.83735874720982, 75.84188747406006, 60.17414433615548, 78.62782328469413, 62.8395219530378, 68.6627585547311, 65.27132892608643, 65.16698782784599, 58.4863087790353, 38.13263102940151, 49.70593275342669, 51.833863735198975, 49.21883623940604, 65.43043572562081, 75.7782211303711, 71.88295677730015, 44.99992479596819, 10.945438180650983, 0.3120329592909132, 0.3043833454804761, 0.05544204803715859, 0.21568961760827474, 0.1579063625207969, 0.0419917299545237, 0.055896629180227, 0.10819654778710433, 0.0237661215942353, 0.013879210738066052, 0.031951216581676684, 0.011948303635498243, 0.05889401691300528, 0.08412259351462126, 0.0658100868708321, 0.12576797205422605, 0.06049580739012786, 0.033039834416870556, 0.020283566056085483, 0.025333108313913857, 0.0761162331327796, 0.07043870671519212, 0.0895450586186988, 0.12692131873752388, 0.14023961765425547, 0.04549734380894473, 0.15118506604007312, 0.09472674557140895, 0.1199885228914874, 0.1145152287291629, 0.25529690086841583, 0.20912514414106095, 0.16159964219800063, 0.13685691702578748, 0.2014227674475738, 0.030762463941105773, 0.07793104967900685, 0.10591895678745848, 0.0882938943271126, 0.17281058776591504, 0.07525587108518396, 0.1368820228214775, 0.05750227373625551, 0.08217114715703897, 0.08776625871126141, 0.015783460744257485, 0.10609734364386116, 0.061786849184760025, 0.08417089163724865, 0.0511795996156122, 0.04975551745987364, 0.04729897981243474, 0.03382260937775884, 0.04511393420398235, 0.05913746849234615, 0.03931813234729426, 0.12239019758999348, 0.11921666216637407, 0.08186554855534009, 0.09081095390553985, 0.1884205708546298, 0.06549694295972586, 0.08784218677984816, 0.06817632168531418, 0.00942909055655556, 0.1353413683495351, 0.047934458391474824, 0.12039975582488946, 0.04076615661116583, 0.0805896788037249, 0.04960932030475565, 0.04468082530157907, 0.034129629510321786, 0.037101087027362416, 0.047050415471728356, 0.06903329784316675, 0.07726906412946326, 0.07594868926597492, 0.018538840480947068, 0.08377671028886523, 0.05843651467668159, 0.06168578817908253, 0.06416613901300089, 0.1334496805710452, 0.04355401951553566, 0.04212982540151902, 0.1494022695613759, 0.1559113474296672, 0.13798283732363156, 0.2985350792961461, 0.21530585177242756, 0.15802488901785441, 0.13566454100821698, 0.11134629377296992, 0.11216363670038325, 0.03301416543711509, 0.08528656605631113, 0.03262894753632801, 0.09773429775876658, 0.10490369876580578, 0.06926883091884, 0.15202240539448603, 0.10621399059891701, 0.04968729754909873, 0.15438129167471612, 0.11198000476828643, 0.03798579151875206, 0.10887064518673079, 0.06182706595531531, 0.14236930837588652, 0.03900771275428789, 0.05847029893526009, 0.1718073058873415, 0.5236222169228962, 3.049836426973343, 9.170357567923409, 51.98591463906424, 85.0069227218628, 88.6827699116298, 78.15613092694963, 67.66200256347656, 59.41264956338065, 64.47532939910889, 75.78330026354108, 68.1104462487357, 83.60669394901821, 87.46680041721889, 93.9030487877982, 71.89254529135567, 78.50784179142543, 95.86433070046562, 88.06282384055001, 88.38615131378174, 94.52582972390312, 100.04444340297154, 113.55370085580009, 118.98694201878139, 119.83067567007882, 114.60562338147844, 107.05814266204834, 95.1773762021746, 74.94188731057304, 85.9616607938494, 97.13733100891113, 100.9771626336234, 105.52426528930664, 89.6674199785505, 69.13207462855748, 78.95621599469865, 82.0134094783238, 63.66775417327881, 70.21678570338658, 94.0043535232544, 95.57608468191964, 103.08922740391323, 99.81011540549142, 110.01453168051583, 102.1265127999442, 108.87879998343331, 97.59890678950718, 79.49585478646415, 96.92725917271206, 91.34648690904889, 92.00842789241246, 84.90245655604771, 82.22910935538155, 65.75191497802734, 47.600218636649, 71.11488206045968, 65.03794588361467, 57.795515401022776, 65.67400482722691, 79.86241395132882, 87.90942846025739, 75.17957128797258, 38.73332364218575, 5.244140727179391, 1.6322298837559563, 0.058785838074982166, 0.17442034424415656, 0.03548278100788593, 0.06396254458065544, 0.11139795064393963, 0.13214789756706782, 0.07360746525228024, 0.06415051913687161, 0.0940241836277502, 0.07961465112332787, 0.049453308140592914, 0.13623195913221153, 0.139909618933286, 0.10025971688862358, 0.05761934816837311, 0.05409188887902668, 0.11578810614134584, 0.06197236744420869, 0.09638571619455304, 0.019800791782992225, 0.04179312275456531, 0.11281125087823186, 0.115452163453613, 0.019513825752905438, 0.13068570888468198, 0.1703599499804633, 0.2414065290774618, 0.21845596416720323, 0.2741069500999791, 0.1618649765316929, 0.11278050645653691, 0.11264274349170071, 0.1950742716767958, 0.09190755470522813, 0.08903650340757199, 0.11181674924279962, 0.18845077923366002, 0.08379676099866629, 0.07540713011154107, 0.08010565941887242, 0.054421371913381984, 0.14096288170133317, 0.07798954618296453, 0.024924621750999774, 0.05092869772176657, 0.09040731377899647, 0.05392595314021621, 0.042762128436671834, 0.05350325296499899, 0.04684394405090383, 0.05091530004782336, 0.05753567801522357, 0.04485537504245128, 0.1379795532141413, 0.17640949679272516, 0.2369500467819827, 0.20799800248018332, 0.2391209245792457, 0.1890759678291423, 0.1619725650442498, 0.18017637037805148, 0.16234327586633818, 0.19338828857455934, 0.23576049347008976, 0.1527306331055505, 0.20223874651959964, 0.12237900176218577, 0.31515394896268845, 0.14334489245499882, 0.1173789586339678, 0.11208713187703065, 0.10763818132025854, 0.21683564968407154, 0.14854377348508152, 0.18325846642255783, 0.153322573485119, 0.07476154475339822, 0.13406441972724029, 0.1835306268185377, 0.27196256230984417, 0.15019610125039304, 0.1839026404278619, 0.19666720048657485, 0.1827244593628815, 0.29674586387617247, 0.2530137390962669, 0.2847012701843466, 0.2692526291523661, 0.19672362745872565, 0.26337380175079617, 0.1781094577163458, 0.27668386325240135, 0.32026372477412224, 0.22632836816566332, 0.23498986767871038, 0.2428384550980159, 0.20987800588565214, 0.12517367037279264, 0.18244094029068947, 0.2357215727014201, 0.3366108275949955, 0.202865102195314, 0.1575686420713152, 0.3094243178410189, 0.17939647579831736, 0.21567501553467341, 0.26446293187992914, 0.3712167649396828, 0.31553365715912407, 0.14891330365623745, 0.16163750445204123, 0.18922699615359306, 0.5329424653734479, 1.5966462045907974, 33.669017927987234, 106.0410167149135, 137.4907452719552, 126.168336050851, 101.30937685285295, 79.1155173437936, 83.62648241860526, 89.97634383610317, 85.91647665841239, 103.31314005170549, 105.14623464856828, 101.38998290470668, 72.73703629629952, 74.23913260868618, 90.40529782431466, 83.95896066938127, 100.21486186981201, 103.28679248264858, 115.07152094159807, 123.39084924970354, 130.82985469273157, 123.11524200439453, 119.39541271754673, 117.88683373587472, 95.774566922869, 82.02021176474435, 104.5991404397147, 114.26796177455357, 121.46241841997418, 122.75900786263603, 98.73139367784772, 74.02579511914934, 99.87632478986467, 105.7218998500279, 75.3129836491176, 89.91318471091134, 111.3676586151123, 108.06224073682512, 115.56913008008684, 112.80061340332031, 126.01173755100795, 118.68330574035645, 115.89379160744804, 105.27358818054199, 87.38756316048759, 105.06770610809326, 86.26153809683663, 92.50550201960972, 83.81656428745815, 94.47895022800991, 81.71417835780552, 61.966286250523154, 81.2797074999128, 77.01422228131975, 70.64519078390938, 93.70565046582902, 116.06255640302385, 119.40120751517159, 80.68676212855748, 25.342133453914098, 1.1660242144550597, 0.6077297266040529, 0.12873348221182823, 0.19818262702652387, 0.32656891644001007, 0.11756856845957891, 0.16462331637740135, 0.2651622843529497, 0.21299759777528898, 0.12004113649683339, 0.229217705982072, 0.08335894306323358, 0.2010568877948182, 0.16743508407047816, 0.18984606436320714, 0.18917934942458356, 0.12151483313313552, 0.17604884185961314, 0.2127048641975437, 0.14878518267401628, 0.13964967216764176, 0.08884169600371804, 0.20488770652030194, 0.1872043918286051, 0.2401436125593526, 0.15443780007106916, 0.337170021874564, 0.1692898188318525, 0.31545847547905786, 0.26855886780789917, 0.29999121544616564, 0.21555320492812566, 0.29383389013154165, 0.32642851397395134, 0.32061813718506266, 0.18281793434705051, 0.2784227042325905, 0.23877802012222155, 0.24186953423278673, 0.3101895696350506, 0.3316250608435699, 0.35462405958345955, 0.39820145123771256, 0.29687440555010525, 0.1966640249426876, 0.19861049763858318, 0.22161512821912766, 0.16669876500964165, 0.22158037365547248, 0.15895233782274382, 0.15802448189684323, 0.19987346843949386, 0.0811126935960991, 0.14177096262574196, 0.08816039934754372], [0.008010799697201167, 0.013562099941607033, 0.021950495894998312, 0.07284648822886602, 0.024792556783982685, 0.008432817944724644, 0.024017496766256433, 0.03641096941594567, 0.03967617152790938, 0.037655517991100035, 0.017999284701155763, 0.00967538180494947, 0.028106498066335917, 0.0441216954828373, 0.04869090958631464, 0.02098928318758096, 0.052788911653416495, 0.002479433115305645, 0.026503313199750016, 0.04939717293850013, 0.06404441661600556, 0.04787090001627803, 0.05174874461122921, 0.04002548474818468, 0.02091359599892582, 0.02340436234538044, 0.04919238767719694, 0.03351466983024563, 0.035586644363190444, 0.045597397190119536, 0.05451347625681332, 0.02227755995201213, 0.07767235141779695, 0.020081374494891082, 0.018128470983356237, 0.03464634749772293, 0.03561965848452278, 0.0516332342023296, 0.03984976792708039, 0.09611118092600789, 0.03746633564255067, 0.034523498732596636, 0.02236705193562167, 0.06323523646486656, 0.042067759803363254, 0.10407315833227974, 0.06002296347703252, 0.019907781488395164, 0.02794786506066365, 0.021133809450215528, 0.041401981243065426, 0.06442286952265672, 0.18613131583801337, 0.02840694997991834, 0.08374436452452626, 0.08277849028153078, 0.042579002013163905, 0.2617517773594175, 0.09921635394649846, 0.1591325702943972, 0.05547693830781749, 0.16090692579746246, 0.23026441410183907, 8.284886956214905, 36.74015644618443, 67.64158875601632, 85.46681703839982, 84.7170021874564, 74.26014396122524, 66.73924010140556, 65.85083648136684, 59.91440677642822, 71.53629725319999, 70.72331632886613, 76.04467064993722, 67.82124137878418, 64.32166998726981, 68.43645572662354, 58.627162660871235, 66.03219836098808, 58.97476019178118, 57.13913297653198, 49.52632876804897, 45.85921893801008, 66.02799470084054, 58.58680057525635, 69.71086651938302, 71.40464973449707, 71.9774592263358, 71.83754335130963, 61.388877051217214, 45.13331978661673, 48.540143149239675, 58.05554131099156, 68.38822133200509, 133.14600890023368, 52.14767565046038, 38.43964065824236, 59.17682770320347, 43.63065024784633, 58.417479923793245, 65.49137837546212, 71.99686554500035, 52.4847605569022, 41.66994156156267, 71.8658572605678, 70.37927627563477, 67.38606875283378, 66.43672248295375, 68.1387323651995, 61.119745526994976, 56.035689558301655, 62.03089754922049, 78.24225384848458, 85.55731732504708, 89.52867834908622, 72.06581946781704, 33.75813552311489, 7.643786226000104, 0.06843835155346564, 0.224465083863054, 0.10368578947548356, 0.10271143354475498, 0.11186875216662884, 0.11540108333740916, 0.10171140863427094, 0.04561325116083026, 0.05855031178465911, 0.037351113611033986, 0.06764182608042445, 0.058192730615181584, 0.02274130640684494, 0.04892711441165634, 0.047816077779446325, 0.13293357326516084, 0.024719978982050504, 0.07390620386494057, 0.04115382741604533, 0.031082949601113796, 0.0481262463144958, 0.02498459067594792, 0.052788107589419396, 0.08188816412751164, 0.05770506749727896, 0.07591850124299526, 0.0489170483446547, 0.022182171499090533, 0.08806900746588196, 0.10296105300741536, 0.04203566170430609, 0.02922940906137228, 0.015115010452323725, 0.07748715206980705, 0.03378206351771951, 0.015225004371521729, 0.06289501900651626, 0.05010035913437605, 0.041878814942070415, 0.052752023097127676, 0.023563806200399995, 0.03111423345814858, 0.19920754060149193, 0.05501420795917511, 0.055954162164458206, 0.07094433744038854, 0.015480058899681483, 0.034108279405960014, 0.03634409300450768, 0.02756674720772675, 0.014478108646082026, 0.023953745008579323, 0.02555751341528126, 0.06919448383684669, 0.06729195985410895, 0.02676783498775746, 0.023088541613625627, 0.02860957071451204, 0.0663275783881545, 0.027876157479892884, 0.05197381467691489, 0.009835742530412972, 0.019993315916508436, 0.05096549806850297, 0.10222035061035838, 0.05086309356348855, 0.06020751143140452, 0.03167955151626042, 0.013866522133217325, 0.029406835790723562, 0.041934600698628595, 0.024869136246187345, 0.03230441780760884, 0.06738412526569196, 0.0483084838571293, 0.032635380048304796, 0.015813601269785846, 0.024688752800492302, 0.05131669422345502, 0.01720982786667134, 0.018693298799917102, 0.024399367793064033, 0.08115408423223666, 0.03374435393405812, 0.1629116575100592, 0.05056161366935287, 0.10381812416017056, 0.05474534863606095, 0.06679031891482216, 0.056850388180464506, 0.029123859546546425, 0.048749585902052264, 0.04237369427989636, 0.03175152711836355, 0.060940912791660855, 0.08047256365950618, 0.03667983213173492, 0.08850661505545888, 0.050972256277288706, 0.03545440806608115, 0.02454347166764949, 0.04870561004749366, 0.018042945036930696, 0.04247588165370481, 0.0810204671163644, 0.02661609759421221, 0.041175174127732, 0.060192515807492394, 0.07853745642517294, 0.02701763595853533, 0.04806694574654102, 0.048377158386366706, 0.04887246859392949, 0.07285832187959126, 0.13591804169118404, 0.04970579441370709, 0.32395791368825094, 0.13766985626092978, 1.3578826508351733, 6.203006029129028, 33.83625759397234, 71.75934832436698, 95.97744042532784, 96.7124000276838, 96.54549040113176, 85.07898248944963, 75.44584015437535, 78.44974790300641, 75.83179868970598, 79.69883251190186, 73.11064093453544, 79.64016887119838, 73.42008590698242, 70.5896051951817, 82.90723964146206, 74.6847344807216, 86.19989367893764, 73.16751194000244, 74.71159621647426, 64.12796810695103, 57.10946069444929, 79.79068074907575, 52.47161109106881, 58.545285088675364, 64.69733824048723, 71.46910122462681, 72.46810626983643, 61.718311991010395, 48.01449802943638, 47.59893669400896, 67.03639371054513, 79.30915669032505, 151.50142642429896, 65.49813897269112, 46.2199833052499, 62.11695793696812, 46.164567947387695, 52.9041051864624, 71.94052955082485, 71.30266407557896, 55.46894236973354, 47.251961026872905, 70.89206027984619, 68.36014366149902, 65.53939042772565, 68.46927206856864, 68.64634690965924, 67.59854466574532, 68.18119975498745, 66.75579071044922, 80.11029093606132, 87.85416943686349, 97.65880720955985, 95.62955801827567, 67.44918618883405, 26.126190764563425, 1.3972200942890984, 1.323638019817216, 0.14166363195649215, 0.20361903602523462, 0.06902615965477057, 0.11069779749959707, 0.12173451563077313, 0.051394115069082806, 0.004319868175246353, 0.06985887818570648, 0.13876516105873243, 0.05009643720196826, 0.04628441728917616, 0.011474760831333697, 0.02106075837010784, 0.1616867118115936, 0.04149077433560576, 0.07146026154181787, 0.04424041196970003, 0.02701846037858299, 0.04375346809891718, 0.05059787118807435, 0.05542143414329205, 0.020821634147848402, 0.05162706971168518, 0.05703128222376108, 0.03505865930180464, 0.035145077521779707, 0.13440317154995032, 0.09534590877592564, 0.0647274028243763, 0.056710209630961926, 0.06181245031101363, 0.305962187903268, 0.11934316823525087, 0.13955466369433062, 0.11001644656062126, 0.02324535444911037, 0.04351595030831439, 0.009124107725386108, 0.08084481475608689, 0.08621379772999457, 0.06377300939389638, 0.05492346407845616, 0.13337559811770916, 0.06966006742524249, 0.06545346243573086, 0.036927870607801845, 0.03277758402483804, 0.06213970775050776, 0.01804198999889195, 0.05042646984968867, 0.026398152146222334, 0.04689906145046864, 0.01662626739458314, 0.03506039635145238, 0.05882369354367256, 0.08664227902357068, 0.06886803385402475, 0.15470955334603786, 0.12447039596736431, 0.11726814029472214, 0.12209583552820341, 0.08281664430562939, 0.15362072177231312, 0.2250440235116652, 0.1637311378227813, 0.08058241169367518, 0.06551766541919538, 0.17870850914290973, 0.15047375778002398, 0.08307004999369383, 0.16907012276351452, 0.23008096537419728, 0.11554384710533278, 0.1157459012631859, 0.14403845023896011, 0.18067248804228647, 0.12266462429293565, 0.08777573784547192, 0.12005249517304556, 0.14514763786324433, 0.16710872229720863, 0.16626476044101374, 0.16169302218726703, 0.12036531338734285, 0.17172894866338798, 0.1283307716782604, 0.12185879610478878, 0.16699535266629287, 0.10146405547857285, 0.10668375396302768, 0.09802592532443148, 0.08247764821031264, 0.20299857003348215, 0.08249742072075605, 0.1579703755144562, 0.18317130181406224, 0.1704802406685693, 0.17805023517991814, 0.16922092038605893, 0.12220514751970768, 0.17066643067768641, 0.1670056799692767, 0.16646335407027177, 0.16233562199132784, 0.13377547237489903, 0.0794410818655576, 0.19581642613879272, 0.366568175809724, 0.1301714200526476, 0.26080125836389406, 0.18154021219483443, 0.15023104580385344, 0.2743925319186279, 0.10933656804263592, 0.3394837991467544, 0.11548778654209205, 0.2548841344458716, 0.963876255920955, 17.463456426348003, 62.370358739580425, 119.04479272024972, 141.48191561017717, 135.6001682281494, 113.3303301674979, 96.77323150634766, 90.40552016666958, 84.70136874062675, 97.87318692888532, 98.6050615310669, 106.74437591007778, 98.18401459285191, 91.62090601239885, 94.00414507729667, 83.34024442945207, 89.25896317618233, 82.86300046103341, 81.53263582502092, 76.69254153115409, 71.01641913822719, 100.16229179927281, 80.51617690495083, 83.41051851000104, 86.73536355154855, 93.92719377790178, 95.44485405513218, 89.21161815098354, 69.80614021846226, 72.30774184635708, 82.58865778786796, 102.47545133318219, 170.81486157008578, 81.25054591042655, 71.90665013449532, 91.65024130684989, 70.23888792310441, 79.55132920401437, 92.84678363800049, 95.43255574362618, 74.8047993523734, 64.27247674124581, 87.57376098632812, 91.51313250405448, 83.4093929018293, 87.78181089673723, 86.45899895259312, 80.45189911978585, 78.81549412863595, 88.00222165243966, 108.96147659846714, 120.16805240086147, 129.2682887486049, 107.16920266832624, 54.993272168295725, 12.792725341660635, 0.22718223663313047, 0.5752328389457294, 0.17539182997175626, 0.18506757648927824, 0.2086093489612852, 0.3129221930035523, 0.1882438396236726, 0.09619700882051672, 0.2153767179697752, 0.15527171960898808, 0.23107795044779778, 0.13420455077929155, 0.08763390367052384, 0.17222229790474686, 0.17363477711166653, 0.25600238729800495, 0.09557473114026444, 0.1636092865041324, 0.13789708406797477, 0.13438326333250317, 0.14709534549287387, 0.13922497709946974, 0.1279661948127406, 0.2194591917629753, 0.14491042202072485, 0.15255307406187057, 0.11847973242402077, 0.13881596976092883, 0.19834284271512712, 0.24627830194575445, 0.18864399886557034, 0.06578843481838703, 0.1409312348280634, 0.3329455985554627, 0.19488216484231607, 0.20156574834670338, 0.176179242719497, 0.09839123500777142, 0.13132243257548126, 0.15526501568300383, 0.25411654849137577, 0.20974605796592577, 0.3229230935020106, 0.08077869830386979, 0.18317130181406224, 0.16327908422265733, 0.086336178305958, 0.1472246471260275, 0.07928235216864518, 0.07802808018667357, 0.1644547139959676, 0.0839310973616583, 0.06373310474944965, 0.17840622179210186, 0.1540510215397392, 0.14718324291918958, 0.11105389267738376], [0.036429177903171094, 0.14456227927335671, 0.01826532301492989, 0.05426369055307337, 0.0698292465614421, 0.050862835720181465, 0.04958241299859115, 0.010417861115586544, 0.00914533484527575, 0.02486291408006634, 0.023777359830481664, 0.053372061611818414, 0.03969854622014931, 0.05277420440688729, 0.03235335036047867, 0.03442036480243717, 0.015391579629587275, 0.023904155973078947, 0.03407814905845693, 0.028441173589921424, 0.039243011735379696, 0.0525255959614047, 0.009460852780778493, 0.0427778093809528, 0.031862884892949035, 0.011452196997457316, 0.014704958169854112, 0.02869062850783978, 0.05343383204724107, 0.04688175880749311, 0.06302852755678551, 0.0086248543811962, 0.03012046803321157, 0.04056289466097951, 0.01720011294154184, 0.03513846180534788, 0.007102150977256575, 0.037744660529174974, 0.018316783110744188, 0.01860569483999695, 0.041009530158979554, 0.10534431226551533, 0.03204399606745158, 0.05987884942442179, 0.047551106461989026, 0.03088704975587981, 0.08482514867292983, 0.03072612839085715, 0.02932384077991758, 0.028249797876924276, 0.04451410585482206, 0.03686614088448031, 0.011660782054864934, 0.061383290482418876, 0.04076260108766811, 0.07720174667026315, 0.0346975226088294, 0.055238487531564066, 0.030359146118696247, 0.18693327637655394, 0.08712688194853918, 0.09827895781823567, 0.10321881489029952, 0.06852546866450991, 0.12118141459567205, 2.1979614411081587, 13.341693827084132, 39.72714533124651, 64.3434247970581, 94.27456201825822, 112.58374622889927, 103.7686847959246, 88.08024297441754, 77.98048046657017, 64.27611759730748, 63.95687566484724, 70.52479934692383, 72.596175466265, 73.8485882622855, 62.22587094988142, 79.66052709306989, 72.54645415714809, 92.1259844643729, 65.0903422491891, 63.28656210218157, 74.22009454454694, 79.96032101767403, 87.76403740474156, 77.06726482936314, 71.18838705335344, 66.03593649183, 69.15692833491734, 69.12173570905412, 62.59899616241455, 74.23039872305733, 64.55057838984898, 64.19120366232735, 64.54148319789341, 70.92259761265346, 65.17739622933524, 69.1500357219151, 72.51058755602155, 80.76676368713379, 65.1810301371983, 72.17591367449079, 67.6144768851144, 76.06883648463658, 67.37978758130754, 72.05504976000104, 80.70303480965751, 87.18586390359062, 106.07534081595284, 82.20392213548932, 55.856537205832346, 32.70473650523594, 12.96114272730691, 1.2909780123404093, 0.2542396890265601, 0.289950824209622, 0.12315094391150133, 0.16372702590056828, 0.0431533310163234, 0.04355281172320247, 0.03972880209663084, 0.05946144860770021, 0.07891027070581913, 0.018731681829584495, 0.046343473584524224, 0.09963804988988809, 0.05759093112179211, 0.04102882090955973, 0.028039226408249567, 0.018873967230319977, 0.026420828786545565, 0.09777623122291905, 0.04313330744792308, 0.012532423898976828, 0.06448901990162474, 0.052901809702494314, 0.02923968547422971, 0.04825230115758521, 0.0545067078700023, 0.015272746095433831, 0.04057053157261439, 0.10281247419438191, 0.07198832463473082, 0.0034513465320092757, 0.03143509231241686, 0.03255586592214448, 0.0337814155167767, 0.009238764876499772, 0.034947223495692015, 0.043661926939551315, 0.059551856613584926, 0.02834631609065192, 0.04433771389137421, 0.03042588003778032, 0.003945380033526037, 0.0065029986186086065, 0.06231530582798379, 0.04534110433555075, 0.019965455268642733, 0.04829007859474846, 0.019659788813441992, 0.03087613212742976, 0.055627169353621345, 0.06452821208430187, 0.0347288471779653, 0.07033593580126762, 0.017394277433465635, 0.05661726051143237, 0.027807951139818345, 0.04435762550149645, 0.027258755073749592, 0.0319950872633074, 0.03809442836791277, 0.03055161257673587, 0.05092632963455149, 0.040567471379680295, 0.01941165025345981, 0.046125792765191624, 0.05483474223209279, 0.10436304206294672, 0.015586348017677665, 0.024840156015540873, 0.05825708966170039, 0.05733456023569618, 0.0904944444607411, 0.024634325810308968, 0.019081246107816696, 0.020013096908639585, 0.0328606401037957, 0.0161917047309024, 0.06267809814640454, 0.04348253245864596, 0.035332376935652325, 0.03725814752812896, 0.05041070408853037, 0.024178029669980918, 0.012386861174101276, 0.027710628862093602, 0.06514918019196816, 0.040458366341356716, 0.032803039266062636, 0.08226207084953785, 0.007107099193880069, 0.07981488680733101, 0.03133623993822506, 0.05750293870057378, 0.0309214446959751, 0.03481980479721512, 0.06024242205811398, 0.02928289458421724, 0.04002988165510552, 0.021041944290378263, 0.08029574421899659, 0.05014532565006188, 0.030056658600057875, 0.06136382331273385, 0.01644361424925072, 0.05874142117266144, 0.04919768364301749, 0.04989603866956063, 0.00973022694233805, 0.07339646800288133, 0.012703542797161, 0.04929163360169955, 0.05011811639581408, 0.032470787808831246, 0.0276142395700195, 0.03417257399165204, 0.06140092560755355, 0.060781823471188545, 0.10168420616537333, 0.013577354256995022, 0.015167834403525506, 0.06815725485129015, 0.15165229168321404, 0.07431793212890625, 1.0604213667767388, 1.623862732733999, 14.78099318913051, 43.30790294919695, 75.61740507398332, 93.30364853995187, 109.56153692517961, 114.91888986315045, 101.41592747824532, 92.5912914276123, 89.87631062098912, 73.87692301613944, 76.98590837206159, 75.84295054844448, 82.9808349609375, 76.24024854387555, 66.47517381395612, 77.07970210484096, 71.99923488071987, 82.64259665352958, 66.91856615883964, 69.37937491280692, 81.99986049107143, 94.8601770401001, 102.06160967690604, 87.71464266095842, 77.82115827287946, 72.56784071241105, 69.80240208762032, 69.97356401171002, 60.90365655081612, 69.82800619942802, 56.47947447640555, 58.24754088265555, 69.24341256277901, 74.04344354357038, 73.85465403965541, 75.02372319357735, 73.18653610774449, 84.01021753038678, 72.54990046364921, 74.43127809252057, 77.7059988294329, 84.7288349696568, 77.5486638205392, 79.61338356563023, 90.17370741707938, 96.67502566746303, 109.30271652766636, 103.6577012198312, 88.27470915658134, 66.7217514855521, 34.79714829581124, 8.9041633946555, 1.2841298026697976, 0.38310624552624567, 0.180604756676725, 0.18358482819582733, 0.05588987775679145, 0.08604919191982065, 0.04897463900436248, 0.046935807514403544, 0.040807075665465424, 0.02374147211334535, 0.019540621100791862, 0.03694065081487809, 0.08819717594555446, 0.023293708550876806, 0.019950195016073327, 0.007114166560183678, 0.05068398067461593, 0.024053557509822503, 0.008978465272645866, 0.011929680393742663, 0.049218192363956144, 0.006445140785737229, 0.002823508469321366, 0.023805580101907253, 0.04999374771224601, 0.02323623324212219, 0.07105779528085675, 0.04553404916077852, 0.044309452907847505, 0.04870206470202122, 0.013458951592578419, 0.038627600829516134, 0.024858434052605714, 0.06755292442228113, 0.06691230594047479, 0.07403684221208096, 0.13093832747212478, 0.051454070423330577, 0.05395951348223856, 0.01357956967383091, 0.024732011104268686, 0.04508081151704703, 0.05517751098211322, 0.031596576861504994, 0.022173107967578938, 0.030971252559018985, 0.04543150216341019, 0.07088609877973795, 0.04562175998996411, 0.04743961637307491, 0.032991831456976276, 0.06793179802064385, 0.05373000579753092, 0.03721972887537309, 0.036509418061801364, 0.10424051899462938, 0.011046446627005935, 0.016667574910180907, 0.02686049064089145, 0.09845226923269884, 0.16800134868494102, 0.13106137301240647, 0.11608550804001944, 0.12087644024619035, 0.1048974155315331, 0.17301391756960324, 0.17351443214075907, 0.07882392033934593, 0.15745616810662405, 0.10084362341357128, 0.17533922993711062, 0.04415959166362882, 0.10808944781976086, 0.14115806908479758, 0.08690616807767323, 0.15954533671694143, 0.15432894948337758, 0.13233809093279497, 0.09798918265317168, 0.1698855725782258, 0.15632775079991135, 0.059424828072743754, 0.1080696549532669, 0.10739359658743654, 0.09052812693906681, 0.18402654092226708, 0.13931839780083724, 0.17229019211871283, 0.1177732553333044, 0.1939810567668506, 0.13356205954083375, 0.17344759644142219, 0.10966120633695807, 0.14363690678562435, 0.11929706856608391, 0.11007798968681268, 0.08745699602046184, 0.06124978193214961, 0.13201650604605675, 0.17109827750495502, 0.1389529388397932, 0.14965852509651864, 0.09008958297116415, 0.12627884106976645, 0.15673375901366982, 0.19278927786009653, 0.11473592902932848, 0.17703649029135704, 0.20946537517011166, 0.19237655214965343, 0.16008131152817182, 0.12311830637710434, 0.11683351147387709, 0.21246382141751902, 0.16622076423040458, 0.11564068762319428, 0.1730911891375269, 0.1322598151330437, 0.39246690752250807, 0.13236802789781774, 0.19718626620514051, 0.12099455962223665, 0.5376086692724908, 0.2614352543439184, 4.264913729258946, 23.338665553501674, 62.50261075156075, 99.24450424739292, 132.31733894348145, 149.12179347446985, 138.72814995901925, 120.00192097255162, 105.74348095485142, 84.43926879337856, 85.80703558240617, 91.06814902169364, 94.63518047332764, 92.68914985656738, 81.63077218191964, 95.64725508008684, 86.47819682529995, 102.46858651297433, 80.12053258078438, 80.5275650024414, 90.44627829960415, 115.32965346745083, 122.11752237592424, 97.70290047781808, 88.16010556902204, 79.83205727168492, 80.84264496394566, 85.02853856767926, 77.81415448869977, 86.20014381408691, 72.12544890812465, 72.72885826655796, 73.24917411804199, 82.23005431038993, 78.7778626850673, 82.88047518048967, 83.19210188729423, 93.62314755575997, 79.77362986973354, 86.21476282392229, 89.44573075430733, 100.18538761138916, 91.26857675824846, 99.69471972329276, 118.16602625165666, 129.0947505405971, 137.6470102582659, 123.74706949506486, 85.28032738821847, 51.672880922045024, 18.498739753450664, 2.6498171261378696, 0.3971551502389567, 0.4074362042759146, 0.1594798309462411, 0.2273632562054055, 0.2822375095316342, 0.28928108300481525, 0.16316355685038225, 0.1281505934894085, 0.12878548513565743, 0.07607595529407263, 0.10602396686694451, 0.12433352188340255, 0.19451699086597987, 0.08681866420166832, 0.15052258515996592, 0.14449001529387065, 0.10601077614618198, 0.1991044847028596, 0.18873625248670578, 0.08702574630400964, 0.15776228239493711, 0.113034991015281, 0.09854691808245011, 0.14033872447907925, 0.12016323208808899, 0.08222053093569619, 0.09766104990350348, 0.1779396746839796, 0.26691618881055285, 0.1178025273340089, 0.17019236540155752, 0.13003869860299996, 0.1497063889567341, 0.19469817328665937, 0.11443172820976802, 0.1513285083430154, 0.2453908867069653, 0.10709029143410069, 0.11555779778531619, 0.12066993489861488, 0.13591316980975016, 0.14225029333361558, 0.11123655430440392, 0.12860796680407865, 0.08243684111429112, 0.13242893320109161, 0.09707285503723792, 0.10194892981754881, 0.1392743337367262, 0.17175893991121224, 0.0748711417296103, 0.20190447302801268, 0.10980454007429735, 0.09998792290155377, 0.10883214510977268, 0.16923020274511405, 0.09778951693858419, 0.1152072258825813, 0.13745956468795026], [0.03593339950644544, 0.02079411276749202, 0.07155160592602831, 0.031196675462914363, 0.022604383129094328, 0.046711229386606386, 0.03461265144869685, 0.06692034658044577, 0.018630412174388766, 0.034282489879322905, 0.049933741467871835, 0.03632012036229883, 0.01136457861866802, 0.0503920647315681, 0.0052217145816289955, 0.03218468012554305, 0.09609118449900832, 0.04422318057290145, 0.012647744318071221, 0.02172139533130186, 0.04533001368067094, 0.022484555541138564, 0.012501972943677433, 0.07268598077020474, 0.0398427858017385, 0.005567533770642642, 0.06856828422418662, 0.02132060844451189, 0.06936393438705377, 0.02829838776960969, 0.030468152769442116, 0.014277386113202997, 0.022024271311238408, 0.029999532736837864, 0.0496711959131062, 0.011646630358882248, 0.042171348351985216, 0.06363457467939172, 0.10653421841561794, 0.04734382079914212, 0.06085672016654696, 0.054454396212739606, 0.030414585822394917, 0.017312663241422603, 0.006069122123465474, 0.048662655388138125, 0.008295952342450619, 0.039459993663643084, 0.04566140679110374, 0.03136260102369955, 0.02615108567156962, 0.07710270091359105, 0.04621834494173527, 0.03960976330563426, 0.02321661000938288, 0.03808799585593598, 0.06987286957779101, 0.12259994633495808, 0.024642956775746176, 0.008550338513617004, 0.06643072928168944, 0.05333133933267423, 0.040277652109840086, 0.04386253242513963, 0.04451042140967079, 0.10282402286039931, 0.3410475238093308, 0.0992868673056364, 0.7213786425335067, 6.4179889389446805, 21.548988512584142, 39.54520327704293, 69.84644671848842, 96.12378338405064, 117.35959053039551, 106.90564359937395, 110.69263417380196, 104.99176924569267, 104.63808509281704, 101.76543576376778, 100.04621519361223, 92.83429077693394, 99.25760854993547, 106.91125774383545, 98.69311605181012, 119.90310369219098, 71.83613981519426, 60.062827246529714, 97.32912213461739, 98.15130942208427, 111.25468785422188, 99.44829491206578, 99.28199672698975, 93.00315284729004, 95.67406817844936, 92.82842649732316, 102.40869304112026, 101.39345005580357, 111.8171306337629, 90.40885530199323, 83.01984909602574, 112.49527481624058, 107.7598898751395, 107.94853346688407, 98.42375523703438, 101.69236155918666, 98.79692213875907, 92.53042520795549, 83.58666924067906, 68.47410801478794, 33.78931556429182, 14.901811940329415, 1.4362697303295135, 0.2111542895436287, 0.09448466463280575, 0.4591192124145371, 0.0665854691926922, 0.15616188969995293, 0.022950907570442984, 0.06302632910332509, 0.028546935146940604, 0.05987770948559046, 0.08253530333084719, 0.13357349964124815, 0.0032940472717330393, 0.05867270593132291, 0.03970066664208259, 0.023964952710749846, 0.013625988254456647, 0.032951706288648505, 0.04413390572049788, 0.025462491371269737, 0.033358033413865736, 0.0523425034646477, 0.042255625793976445, 0.08885562632765089, 0.08433983328619174, 0.046916937455534935, 0.035795609400208504, 0.03467872040346265, 0.012340415452074791, 0.022771966011662568, 0.029459737773452486, 0.03776573582685419, 0.06092906557023525, 0.048441792239568064, 0.057525635696947575, 0.035143934190273285, 0.04202090356765049, 0.035337035078555346, 0.0318992475845984, 0.09677688484745366, 0.058222776145807335, 0.02861872415191361, 0.03657465920384441, 0.06744697117911917, 0.04163463733025959, 0.07260419015905686, 0.07438984327018261, 0.07197346471782241, 0.08804726720388446, 0.10966107741530452, 0.021753177911575352, 0.05676189364333238, 0.024203464555154954, 0.06493115331977606, 0.033368225009845834, 0.08538866522056715, 0.03998180405635919, 0.06512389119182314, 0.03437662982781019, 0.043501636612096, 0.0489785439733948, 0.060938707552850246, 0.013141830618094121, 0.06291821811880384, 0.04499509897349136, 0.01081952076804425, 0.04593870708984988, 0.004709502914920449, 0.06290003338030406, 0.039275652662451775, 0.047292862819241624, 0.008656374029149967, 0.055429077840277126, 0.01434079690703324, 0.07218839747032949, 0.03404240044099944, 0.0255019939837179, 0.056799460734639845, 0.01010504544579557, 0.043005271282579215, 0.05899699817278555, 0.04174007488680737, 0.008262480209980692, 0.020907384010830095, 0.02282750071026385, 0.012786907609552145, 0.0585273773010288, 0.028349506901577115, 0.10920650645026139, 0.041019708184259276, 0.03326560676630054, 0.01581027984086956, 0.026949236235980476, 0.010225180070847273, 0.02181468711101583, 0.035438781404601674, 0.060843291958527904, 0.045902778660612445, 0.07795920888228075, 0.04428674912612353, 0.0516039655943002, 0.0282632905457701, 0.03514761524274945, 0.06540275551378727, 0.035114434880337546, 0.04913304300446596, 0.05972264387777873, 0.029738826011972766, 0.014280069719201751, 0.10379181057214737, 0.018380909759019102, 0.04058318625071219, 0.10104553507907049, 0.019276104401797056, 0.03868049602689488, 0.04997335434226053, 0.15663074382713862, 0.057572237482028346, 0.05528924195095897, 0.08542563859373331, 0.033031115241880925, 0.077791006836508, 0.059029201444770606, 0.03754059112231646, 0.06166680955461093, 0.015572510992309876, 0.11214689045612301, 0.1148884908429214, 0.249990241335971, 0.24677135263170513, 1.0623164879424232, 0.8666243287069457, 7.6053149189267835, 25.957007340022496, 51.9706529208592, 76.5755477632795, 105.51594134739467, 116.69746889386857, 126.11159706115723, 128.15482602800643, 125.41253880092076, 110.83390494755336, 109.30097947801862, 109.86639608655656, 109.74207196916852, 104.38610172271729, 112.38939816611153, 121.01627458844865, 112.26796449933732, 134.60810443333216, 89.11153629847935, 78.93007687159947, 116.37683037349156, 119.06459508623395, 131.03538240705217, 120.07512719290597, 116.74089513506208, 112.44296182904924, 112.81440557752336, 115.472320829119, 123.85389110020229, 118.78397124154228, 129.1367037636893, 119.31436892918178, 114.15135710580009, 127.80123220171247, 123.78560420445034, 120.65293938773019, 114.0319106238229, 120.10421235220772, 118.48490687779018, 118.74171229771206, 103.27865614209855, 95.03625134059361, 60.10789326259068, 37.3167005947658, 10.14941086087908, 1.3787316977977753, 0.876856093960149, 0.2826222117458071, 0.06153910247875111, 0.14899759127625398, 0.007649730857727783, 0.06628926830100161, 0.02114461172771241, 0.05229433087099876, 0.0721558074333838, 0.012344436620229056, 0.014904603528391038, 0.02942536658208285, 0.04417351180953639, 0.04940817538382752, 0.030948219687810967, 0.019530002027750015, 0.09418984116720301, 0.024545507272705436, 0.048184579970049005, 0.006439374086247491, 0.003993720564592097, 0.0566976703038173, 0.019977902993559837, 0.02301451513942863, 0.028900299221277237, 0.04992217244580388, 0.034512065417532406, 0.030342555937490294, 0.013339675314325308, 0.024079272290691733, 0.048959877475031784, 0.013333331860069717, 0.05264368819605027, 0.06773135199078492, 0.038391066914690394, 0.025943316552521925, 0.07393894317959036, 0.02717531392616885, 0.009845151266615306, 0.056636676790991, 0.02133151759127421, 0.013942522296149815, 0.025174000333728533, 0.060232997206704955, 0.03847195168158837, 0.07640584544943911, 0.007676040204907102, 0.12552017106541566, 0.02527172633978937, 0.013034790022564786, 0.027924905131970133, 0.09307084192654916, 0.09649532674146549, 0.05569091093327318, 0.025280465870829563, 0.016689532303384373, 0.02133876604161092, 0.06190240369843585, 0.021615971345454454, 0.10826651831822735, 0.023078009053798657, 0.04497970640659332, 0.10576615070125886, 0.09711812010833196, 0.11181898840836116, 0.10636639634945563, 0.19872507506183215, 0.0732261896399515, 0.15419421957007476, 0.09835758645619665, 0.12244874159140245, 0.12097280578953878, 0.21881827472576074, 0.15922717164669717, 0.132274525772248, 0.3218182756432465, 0.07245895652366535, 0.14399501042706625, 0.1673553426350866, 0.17196824082306453, 0.0811094773401107, 0.1413747388869524, 0.10940685069986752, 0.09431177391005413, 0.1358104803200279, 0.18569169299943106, 0.20769191533327103, 0.092088350360947, 0.1159610782882997, 0.15445332495229586, 0.12608635425567627, 0.11014551070651837, 0.15120292508176394, 0.10544807384056704, 0.19778408269797051, 0.14266973654074327, 0.1831782635833536, 0.09701011768941369, 0.10773411938654524, 0.1865523061049836, 0.24536477667944773, 0.17972145336014883, 0.14222297551376478, 0.10582478969757046, 0.1998470462858677, 0.17563546475555214, 0.11983898734407765, 0.23207387700676918, 0.0893818980881146, 0.17327782697975636, 0.22765923318053993, 0.14340340931500706, 0.12543205650789396, 0.18022654125733034, 0.3638782730059964, 0.21005492710641452, 0.16360655879335745, 0.139511305306639, 0.15925754287413188, 0.22378513749156678, 0.11687674772526536, 0.13104876583176, 0.19576841300087316, 0.21840203420392104, 0.297021104821137, 0.18714255014700548, 0.26609792986086434, 0.30904110840388704, 0.592338923897062, 0.22550974280706473, 1.9264162864003862, 11.547721930912562, 31.5684072630746, 58.850074768066406, 102.2856057030814, 132.13793645586287, 152.9183725629534, 157.121032169887, 157.22959082467216, 143.46507045200892, 138.87614658900668, 137.71857670375277, 137.6371577126639, 135.2607765197754, 144.3276059286935, 153.28957312447685, 143.46054022652763, 160.6323321206229, 102.47873088291713, 88.04965005602155, 132.36714363098145, 145.43933159964425, 163.4377645765032, 148.8331653050014, 140.79665647234236, 136.17432567051478, 136.8839451926095, 136.02503667558943, 153.5429183415004, 146.3882609776088, 163.71826335362024, 147.81436484200614, 143.1135193961007, 156.17183876037598, 156.42094557625907, 152.8206947871617, 146.60981123788017, 141.81509562901087, 137.57178906032016, 130.47880390712191, 113.69570813860211, 90.33272389003209, 45.652312006269185, 22.24143729891096, 3.427263442959104, 0.2933162493365151, 0.33082552946039606, 0.6660220186625208, 0.1551285215786525, 0.19570832193962165, 0.11881841639322893, 0.17689406579094274, 0.16230804632816995, 0.13341204901891096, 0.15700066754860537, 0.203502979395645, 0.18057692317026003, 0.17342055003557885, 0.10905460281563656, 0.19974560530057975, 0.12741715141705104, 0.14634498075715133, 0.21993940456637315, 0.14223453775048256, 0.17896438469844206, 0.12627837966595376, 0.17426561111850397, 0.1435272012438093, 0.14145329967141151, 0.19883262286228792, 0.08274532348981925, 0.20908980603728974, 0.114319186391575, 0.08420929671930415, 0.08829296473413706, 0.1167047798101391, 0.1565680064793144, 0.07284530079258339, 0.18327526694961957, 0.16241127864590713, 0.09426226120974336, 0.15100613635565552, 0.11504934435444218, 0.151944903124656, 0.1773995743798358, 0.217491372355393, 0.08240721627537693, 0.18266210199466773, 0.14178122207522392, 0.1514516081660986, 0.14807417296937533, 0.20754144340753555, 0.12527391713644775, 0.22355180286935397, 0.07499700997556959, 0.08007557317614555, 0.10341159347444773, 0.27797563107950346, 0.18835726353738988, 0.23650074803403445, 0.10123324500662939, 0.17544229940644332, 0.10680022449897868, 0.1735672221652099, 0.1896310094743967, 0.26214730899248806, 0.09157907590270042, 0.152475042534726], [0.03318495948665908, 0.05325697867998055, 0.022660055231036882, 0.04756323527544737, 0.03373366700751441, 0.09611416648008994, 0.03394604507567627, 0.051378301810473204, 0.0024410625961276567, 0.053218665200152566, 0.029450452021722282, 0.06237344949373177, 0.0501306082255074, 0.02389678538643888, 0.0017686231544108263, 0.023072324626679932, 0.03495208519910063, 0.038640791550278664, 0.09409040864557028, 0.019215860670166354, 0.05526876376409616, 0.013866833411157131, 0.03452807545129742, 0.023557239677757025, 0.05504225520417094, 0.050210539650704177, 0.027901051233389547, 0.016386344197339246, 0.019187635309728127, 0.063641862145492, 0.07833581617368118, 0.08250572598938431, 0.033438042870589664, 0.10055435036442109, 0.055570918800575395, 0.008012544380367866, 0.03472987515851855, 0.03749408093946321, 0.027485319612813846, 0.012703799792299313, 0.0030550994685784516, 0.031353705429605076, 0.0496908768213221, 0.036839813725756745, 0.0817628251388669, 0.05504221109939473, 0.011438576255126722, 0.044527079444378614, 0.02400508975344045, 0.04359307599120906, 0.055537768972239325, 0.024476900596969893, 0.034651134562279494, 0.02858412904398782, 0.023474103870934675, 0.048872499128005335, 0.03293978103569575, 0.047498726951224465, 0.05970675937299218, 0.06710078939795494, 0.045492441393435, 0.07196994990642581, 0.03825373142691595, 0.08500529972038098, 0.11215398793241807, 0.08620973330523286, 0.02918788611090609, 0.05547862107466374, 0.0077140042392004815, 0.11786620106015887, 0.4329100102186203, 0.3052061099026884, 0.09261801479650394, 1.0138404262917382, 9.056869166237966, 7.296202591487339, 15.653040749686104, 29.3198972429548, 27.29060983657837, 45.497467926570344, 35.664405073438374, 42.02929197038923, 32.35110446384975, 22.29959372111729, 23.405272722244263, 7.068514466285706, 0.07200984776552234, 0.5366214822445596, 3.254685172012874, 8.713789701461792, 29.277405534471782, 27.383422136306763, 32.114747592381065, 55.000216892787385, 48.985442774636404, 39.186551162174766, 38.34059408732823, 24.85184597969055, 16.097153970173427, 3.536365794284003, 0.9905240088701248, 10.678737657410757, 11.886219058718, 15.134458473750524, 14.467729313032967, 7.184313144002642, 3.1772709488868713, 1.2524479712758745, 0.3448558694549969, 0.18099049026412622, 0.6439700648188591, 0.6959943217890603, 0.10970838487680469, 0.1829179096966982, 0.12804593624813215, 0.1834178814398391, 0.020905904804489443, 0.10867012451801981, 0.06667320377060346, 0.0639611060864159, 0.04103688869093146, 0.05138140610818352, 0.004648208302179617, 0.04036550543137959, 0.06602347256349665, 0.044535367749631405, 0.03842725657991, 0.034761121696127315, 0.02913723686443908, 0.05696817168167659, 0.08372191858610936, 0.03824130066537431, 0.03723441915852683, 0.02868997711422188, 0.027840378328359554, 0.03454060799309185, 0.028304136657555188, 0.02897682100800531, 0.06691738816776446, 0.029886003650192703, 0.03647256003958838, 0.06694732513278723, 0.012091259937733412, 0.0890800789264696, 0.06281441583165101, 0.04879209612097059, 0.04711773971627865, 0.031110535442296947, 0.03039898630231619, 0.04491491649033768, 0.05372559531990971, 0.03403107908421329, 0.031158786067473035, 0.05257849455145853, 0.029043347973908697, 0.05695406493863889, 0.0514334768855146, 0.05180642348048942, 0.08191230640347515, 0.04596210976264306, 0.058459198102355, 0.03660786331498197, 0.06976078916341066, 0.04630674448396478, 0.01943673569309924, 0.08712219327156033, 0.026011738327464888, 0.017302792253238813, 0.04553493804165295, 0.020720245749024407, 0.009242327185347676, 0.04142503107764891, 0.025314161919855645, 0.03531199035101703, 0.04192875172676785, 0.012678143535075443, 0.030140094658625976, 0.028698363807052374, 0.04367846283795578, 0.005745835810167981, 0.01327361399307847, 0.02998368555147733, 0.03347976938156145, 0.06401620991528034, 0.01323527337184974, 0.015689977278400744, 0.008690967440738209, 0.08121939322778157, 0.023780121468007565, 0.0029749763572388993, 0.03102905356458255, 0.03219145529770425, 0.027245560960311974, 0.016603192114936452, 0.03434862329491547, 0.0365412311761507, 0.012795792177452572, 0.05943120630191905, 0.03313553838857582, 0.09142736904323101, 0.04032461351848074, 0.06912270161722388, 0.07707406673580408, 0.02649332007526287, 0.010910841403529048, 0.01544665970972606, 0.04795256849112255, 0.01899254970651652, 0.03006742355812873, 0.15459018546555722, 0.044674117982919724, 0.04105681047907897, 0.03201801835426262, 0.08253578509071044, 0.017265109810978174, 0.011160452384501696, 0.021858737604426484, 0.009966885537973471, 0.0018531014003591345, 0.03229325929922717, 0.06584850552358798, 0.008812588057480752, 0.01575569509129439, 0.01983455229284508, 0.025259702699258924, 0.03353287831747106, 0.030816590679543357, 0.028056941261248927, 0.054207002344940386, 0.0631076515253101, 0.09707438852638006, 0.019092518270813992, 0.026878475211560726, 0.05115244464416589, 0.07655206296060767, 0.05052498974172132, 0.07050599703299147, 0.11456313330147948, 0.05910023727587291, 0.027470637811347842, 0.0402530959275152, 0.09004154947719403, 0.05855213025850909, 0.14082675400589192, 0.05144667439162731, 0.1471687222697905, 0.8578269322003637, 1.0717745061431612, 0.9901477204901832, 8.445815920829773, 26.321822507040842, 27.312114511217388, 41.13134847368513, 56.66559934616089, 54.99581520898001, 73.03573935372489, 58.895050457545686, 66.94330869402204, 58.168928963797434, 42.426687240600586, 33.73943444660732, 13.474289774894714, 0.22530980567846978, 0.4098092312259333, 4.98407964195524, 13.273071680750165, 37.99767616816929, 38.7621864591326, 51.08758551733834, 74.33248165675572, 72.0905133656093, 66.31459399632045, 58.87138489314488, 42.488710335322786, 32.28451292855399, 11.709752185004097, 4.796093957764762, 23.18960758617946, 25.446742057800293, 31.4517365864345, 31.365790843963623, 17.47136173929487, 9.374465244156973, 5.254711977073124, 2.277020650250571, 0.8741207293101719, 0.738940703017371, 0.08751352477286543, 0.1023451942684395, 0.09756199736148119, 0.12680195085704327, 0.07511550933122635, 0.10693313593843154, 0.08944178558886051, 0.07930817721145493, 0.05365342294265117, 0.12480438447424344, 0.0398257647507957, 0.1197895628533193, 0.023911548612107123, 0.02536503508287881, 0.04967634938657284, 0.009132102564243334, 0.055322873539158275, 0.030983978483293737, 0.049018418083765676, 0.06174347722636802, 0.06719725672155619, 0.04412662164707269, 0.020388353915352906, 0.045025242891694815, 0.03581903242905225, 0.07615853979119233, 0.07201516069471836, 0.03348329097830823, 0.049403462958123, 0.04630325002861874, 0.07268798244850976, 0.028231194143050482, 0.06829459712441478, 0.045063498696046214, 0.051122290547937155, 0.033006552274205854, 0.05321153040443148, 0.047150648664683104, 0.027260027326909558, 0.04119762345882399, 0.05257389408403209, 0.029487679845520427, 0.05513051225404654, 0.07408246012138468, 0.04998994113079139, 0.07332733885518142, 0.007844355905295482, 0.044381801704210896, 0.0672093957130398, 0.052709791077567, 0.030222607909568718, 0.04578651847051723, 0.026750708763886775, 0.06728039083204099, 0.06482040961938244, 0.03801754695762481, 0.08216247547950063, 0.036353134483631165, 0.02243685452932758, 0.03121286191578422, 0.026785736437886953, 0.021780667061518346, 0.08936927055141755, 0.06776888854801655, 0.04001228724207197, 0.1333955063351563, 0.1388101615011692, 0.19781997720045702, 0.13077676828418458, 0.12151422245161873, 0.15810684247740678, 0.07564774541450398, 0.17565986487482274, 0.10522446941052165, 0.12329844385385513, 0.12455836124718189, 0.18648369264389786, 0.0794630189027105, 0.0490781461287822, 0.1707304979541472, 0.09412317510162081, 0.22264985341046536, 0.10203650154705558, 0.25790632941893166, 0.15950288756617478, 0.10541075441454138, 0.12965350784361362, 0.10065318577523742, 0.15542182512581348, 0.15660107827612332, 0.149651332625321, 0.11592407098838262, 0.12569949430014404, 0.07593436539173126, 0.1601028618003641, 0.10808489484978573, 0.21629986486264638, 0.1423748859337398, 0.22563343974096434, 0.3220181449183396, 0.14212343442652906, 0.08613057540995733, 0.13912125623651914, 0.07044460996985435, 0.21474007570317813, 0.0835670226120523, 0.09048870405448334, 0.09605117128895861, 0.09136551379093102, 0.2141999482576336, 0.10954485793731042, 0.1301640375916447, 0.1292563205850976, 0.12594755313226155, 0.1332630291581154, 0.25690494743841036, 0.09262146175439868, 0.15813361746924265, 0.11463899351656437, 0.22586286600146974, 0.1709282501999821, 0.09494566132447549, 0.12623671761580876, 0.17333722593528883, 0.14225008977311, 0.2496971142079149, 0.22145795236740792, 0.18803240811186178, 0.3459245078265667, 0.17113057577184268, 0.21047370534922394, 0.19064373656042985, 0.15326151890414103, 0.13400544146341936, 0.35096075758337975, 0.5487080365419388, 0.4604609747018133, 0.21654202044010162, 2.5055145493575504, 11.801212191581726, 15.827258144106183, 28.373135702950613, 44.76592683792114, 46.804396288735525, 61.5219281060355, 49.898665360042024, 60.89546462467739, 54.940069811684744, 39.051089082445415, 28.73958890778678, 10.050848058291844, 0.20360009132751397, 0.6014988209520067, 3.499792213950838, 11.762331809316363, 36.68467855453491, 41.745909690856934, 58.2496566091265, 80.28121662139893, 77.41457748413086, 72.32675211770194, 58.82643004826137, 38.12790625435965, 28.40103793144226, 9.890835387366158, 3.1010672322341373, 16.009318317685807, 17.387288536344254, 21.329500130244664, 20.282406602587017, 10.057544384683881, 4.136974811553955, 1.7520710016999925, 0.4991697147488594, 0.21000471551503452, 0.7102039850183895, 0.9007138194782394, 0.20381784678569861, 0.22336669851626667, 0.18761166211749825, 0.2664187955004828, 0.26824486894266947, 0.21282134151884488, 0.2915517868740218, 0.1788268999329635, 0.24991049990057945, 0.2149035483598709, 0.20420124621263572, 0.1292684120791299, 0.12499631488961832, 0.17390134637909277, 0.09582879500729696, 0.11659867050392286, 0.20038075479013578, 0.17844985159380095, 0.1771480143070221, 0.1502689623406955, 0.23094256914087705, 0.09088922970529113, 0.25492381517376217, 0.10566036030650139, 0.14314110124749796, 0.09472492031220879, 0.1586800552904606, 0.1365722580147641, 0.22727326889123234, 0.12774493811385973, 0.10523780262363808, 0.201232587652547, 0.1205640970064061, 0.2389226295053959, 0.1891412293272359, 0.17835531809500285, 0.12472855140055929, 0.07117620642696108, 0.17586388678422996, 0.23891527418579372, 0.13173713960817882, 0.18662520790738718, 0.2005627785942384, 0.2519853242806026, 0.17446744814515114, 0.30992564665419714, 0.1165752610457795, 0.1871331049395459, 0.1640333437493869, 0.13528742481555256, 0.19158494605549745, 0.105558539341603, 0.14663957352084772, 0.2523705693227904, 0.15720550370003494, 0.21775933940495762, 0.15870539178805693, 0.1254189879234348, 0.1410766313118594, 0.11744525150528975, 0.10411718168428966, 0.1826989057340792, 0.08975190323378358, 0.13688926957547665], [0.044506930346999846, 0.041173783130943775, 0.020011288612814884, 0.021443138298179423, 0.05647162314770477, 0.013863512830409621, 0.02209135128318199, 0.05001935901652489, 0.056850931008479426, 0.05263241772939052, 0.01612085210425513, 0.030033734294452837, 0.02551251127650695, 0.036502856628171036, 0.051706434560141394, 0.04297968711970108, 0.032614589735333405, 0.035220988626990996, 0.03621760389900633, 0.013236590577954692, 0.02741844150503831, 0.016690156555601528, 0.010272899742371269, 0.03594435445432152, 0.007073383212887815, 0.017334624027301158, 0.009733202318394822, 0.022734878983880793, 0.03963654847549541, 0.042983778685863526, 0.039685365677412064, 0.07483430406344788, 0.01853200084795909, 0.028554259932466915, 0.03725255300690021, 0.013614432803089065, 0.057306855650884767, 0.0020076638320460916, 0.02075907152279147, 0.033179622808737416, 0.019430033463452543, 0.031092126787241017, 0.019938088255003095, 0.01837986142241529, 0.0502496877286051, 0.050372807907738855, 0.04632940755358764, 0.0143288937064686, 0.03851853311061859, 0.02413058650147702, 0.05465625359543732, 0.004615833276017968, 0.04870479580547128, 0.011717038545092302, 0.0155584924588246, 0.018872284463473728, 0.07554091007581779, 0.059926272236875126, 0.02977037789033992, 0.06302955214466367, 0.0339951811890517, 0.034871458275509734, 0.04099662781559995, 0.03192268079146743, 0.11040984759373323, 0.054065707605332136, 0.03870622607480202, 0.05629137032000082, 0.0798133872449398, 0.0693937356450728, 0.06621322488146168, 0.05731463844754866, 0.09017989598214626, 0.020843971520662308, 0.11971163989177772, 0.2590464310986655, 0.36398363592369215, 0.5737070579613958, 0.43625100808484213, 0.8263558809246335, 0.6546346811311585, 0.6829654180577823, 0.6301380470395088, 0.7468072580439704, 0.7828648260661534, 0.2855231932231358, 0.11236695971872125, 0.24358913195984705, 0.15675358580691473, 0.5835110747388431, 0.6758457943797112, 0.47596028872898644, 0.3397031830889838, 0.2816415386540549, 0.34031467884778976, 0.5140781604817936, 0.676794983446598, 0.8023728164178985, 0.40399204194545746, 0.12371601430433136, 0.05992531550249883, 0.4479530230164528, 0.46730663308075493, 0.5095173737832478, 0.6951487043074199, 0.4298032154994351, 0.20492605731955596, 0.056246614150170765, 0.052785186496164115, 0.14329905062913895, 0.18216860347560473, 0.2763357747878347, 0.11708819280777659, 0.11794434115290642, 0.06806124893150159, 0.0995649445269789, 0.016397629931036915, 0.030929593901549066, 0.07390519284776279, 0.04568217335534947, 0.03140556925375547, 0.07398478500545025, 0.024659221260143176, 0.07146992388048343, 0.045326095140938244, 0.03593698895669409, 0.052699697869164605, 0.06034139317593404, 0.05593361273141844, 0.006559367915282824, 0.045170286537281105, 0.03769201299707804, 0.04414494548525129, 0.06588953653616564, 0.04449577183861818, 0.049913405773362944, 0.022082467563450336, 0.011528145422094634, 0.007570257443668587, 0.02675310568884015, 0.049996003841183016, 0.03418506242867027, 0.011325271933206489, 0.05289012532947319, 0.02044914895668626, 0.09298667644283601, 0.03853920467996171, 0.04922040778079203, 0.04916858806141785, 0.005475439181152199, 0.011292688681610992, 0.004097478322884334, 0.0559750474723322, 0.09496075194329023, 0.03687948427562203, 0.04684715691421713, 0.04507042993126171, 0.054538466701550145, 0.019939116235556345, 0.03530894712145839, 0.041334124348525486, 0.009026017006752747, 0.15011357782142504, 0.03204020644937243, 0.05860855723065989, 0.036335268656590154, 0.02152928849682212, 0.03686765741024699, 0.025568997620471885, 0.04051816223987511, 0.051446623501500914, 0.03229779530582683, 0.05317424829783184, 0.040645703074655364, 0.029462384060025215, 0.01989185287883239, 0.019277380047632114, 0.03522305476612278, 0.0179375431034714, 0.05307980300858617, 0.043037301528134515, 0.006719758326653391, 0.02891820915309446, 0.03329996099429471, 0.18042465991207532, 0.0457392890405442, 0.03135818376072815, 0.06306329569114105, 0.026377338084525297, 0.03876143168391926, 0.03390632702835968, 0.012966813536227813, 0.035167319899691005, 0.01753507853884782, 0.021251384301909378, 0.04277925126786743, 0.011521338867688817, 0.0343779767198222, 0.01211288315244019, 0.08653195601488863, 0.03349477179082377, 0.059555839614144394, 0.040949530699955564, 0.059999771150095124, 0.024217247297721248, 0.029205616230943372, 0.011408742766694298, 0.03453175989644868, 0.0265643168906016, 0.07239214796572924, 0.009296169787246202, 0.007434208627923259, 0.015351037162223032, 0.029766764691365615, 0.05152042097012911, 0.06898626179567405, 0.0047403796509440455, 0.016258135005565624, 0.02291135406786842, 0.026404247087027346, 0.032305917370000055, 0.0015473501282810631, 0.07490554345505578, 0.04373740378235068, 0.025415884497176324, 0.027243752664487277, 0.01813000956151102, 0.06788567799542632, 0.08735337693776403, 0.03282491862773895, 0.014740579561995608, 0.02843584369734994, 0.03335262209709201, 0.01991671779459076, 0.028872598029140915, 0.06274588379476752, 0.0257909141946584, 0.026821997349283526, 0.05810217333159276, 0.05496092938951083, 0.06880157813429832, 0.024654914259112308, 0.05828714876302651, 0.05791942349502018, 0.04282052316037672, 0.09256120105939251, 0.11850289760955743, 0.10189274033265454, 0.07957996441317455, 0.11560889147222042, 0.08607897282178913, 0.25132421404123306, 0.1537717500967639, 0.5297662700925554, 0.2714353948831558, 0.4499864567603384, 0.2751430187906538, 0.22722507933420794, 0.3130622154900006, 0.24453430409942353, 0.42711450691734043, 0.43928234970995356, 0.0499478176768337, 0.13831093614654882, 0.039831773178385835, 0.4392675305051463, 0.46182445010968615, 0.2646965921989509, 0.3663759061268398, 0.04647896345704794, 0.24863851815462112, 0.317923864615815, 0.15015070725764545, 0.5171663090586662, 0.39089194632002283, 0.12681630865803786, 0.12585490596081528, 0.44090649113059044, 0.3267947057528155, 0.3032460393650191, 0.46144501332725796, 0.3227552782211985, 0.26648222495402607, 0.046359541293765814, 0.11527273165328161, 0.1404467743954488, 0.10350067155169589, 0.07175602817109653, 0.04216938738578132, 0.04200944650386061, 0.03472452490989651, 0.06432943525058882, 0.03322392436010497, 0.06165459592427526, 0.05536973995289632, 0.06481158866414002, 0.03174451445894582, 0.04510363743507436, 0.016839780312563692, 0.039400730415114334, 0.0629033717725958, 0.023801617457398346, 0.09263065590390138, 0.03048128920740315, 0.017366946042914475, 0.06328088151557104, 0.05251753157270806, 0.024958548501932194, 0.025162412651947567, 0.07656452764890023, 0.04157070576080254, 0.05856616236269474, 0.04608253615775278, 0.045001351673688204, 0.04020432961572494, 0.053899059404752085, 0.0067698859493248165, 0.027828663421262587, 0.04361492821148463, 0.06522187164851598, 0.03058593287797911, 0.0341011072908129, 0.06398206603314195, 0.05424608596201454, 0.019871783509318317, 0.01633691292123071, 0.05310767722715225, 0.017014589593080536, 0.029518000182828734, 0.11405510056231703, 0.006961087787723435, 0.01125233874855829, 0.040126901984746964, 0.07445890456438065, 0.052560547300215275, 0.048438196003969224, 0.03396694056157555, 0.03806372805099402, 0.01140037049273295, 0.05729526627276625, 0.06080153491348028, 0.04369550085227404, 0.01707083505711385, 0.033779678467128954, 0.04967251566371747, 0.03521656457866941, 0.007610091690107116, 0.032315460965037346, 0.012926954692894859, 0.025685880366446714, 0.026930586700992923, 0.02364539834005492, 0.17805414354162558, 0.20623533135013922, 0.10583775650177683, 0.09432150410222155, 0.10363316908478737, 0.07492156366684607, 0.062393201648124626, 0.1347331702709198, 0.29724578133651186, 0.20460992785436766, 0.07396491750010423, 0.13066831124680384, 0.10160780990762369, 0.10491514565157038, 0.17977224849164486, 0.08568563285682883, 0.11529949307441711, 0.09709920933736221, 0.15473259639527115, 0.08076892061425106, 0.0905876276748521, 0.12866238531257423, 0.08235231600701809, 0.154928163758346, 0.13938911472048077, 0.1219294723123312, 0.13614848575421742, 0.1477513260075024, 0.12303851065891129, 0.09624354275209562, 0.1224651892802545, 0.12897546137017862, 0.11015176679939032, 0.11636743934026786, 0.08120060459311519, 0.07497140884931598, 0.200752551268254, 0.20256778172084264, 0.10858542299164192, 0.18153870584709303, 0.14694177944745335, 0.12313186350677695, 0.13441565659429344, 0.17747388753507817, 0.11290600150823593, 0.2244272351797138, 0.1886415968516043, 0.10943846364638635, 0.16633189469575882, 0.1099846436242972, 0.15642202645540237, 0.11113689786621503, 0.14576982733394417, 0.08147570983107601, 0.16430076797093662, 0.08427303829895598, 0.16477544392858232, 0.1271658627582448, 0.08296668196895293, 0.10640208050608635, 0.09090228471904993, 0.0977261078410915, 0.12043195909687451, 0.15252084364848478, 0.14035082954381192, 0.15241050028375216, 0.21173024363815784, 0.19126564104642185, 0.17682001047900744, 0.3326451432492052, 0.24098610877990723, 0.2500858062079975, 0.13894455214696272, 0.14613192076129572, 0.2640326049711023, 0.38655928309474674, 0.5238790288567543, 1.1333619271005904, 0.797144948371819, 1.0994960814714432, 1.0436643745218004, 0.7221534209592002, 0.6203083002141544, 0.7279396419014249, 0.8958240247198513, 0.42743081280163353, 0.1809135036809104, 0.3765866096530642, 0.18104874928082737, 0.6670764620815004, 0.6515361645392009, 0.4911879716174943, 0.5777416271822793, 0.26226434271250454, 0.37279840292675154, 0.5347906861986432, 0.7525783340845789, 1.0909787842205592, 0.6933476009539196, 0.36922624175037655, 0.15743604275797093, 0.4855964088014194, 0.4767601458089692, 0.5169644856027195, 0.803687817284039, 0.6510590729968888, 0.20736773844276155, 0.09659303578415088, 0.167161458038858, 0.2234190949904067, 0.2201938551983663, 0.3829506438757692, 0.1334995800363166, 0.1863512968910592, 0.18566710289035523, 0.2740974234683173, 0.10912129602261952, 0.11740668357482978, 0.1393203248402902, 0.15637644247284957, 0.12216017421867166, 0.15088136733642646, 0.08459642130349364, 0.11861283385327884, 0.16549288614520005, 0.07384643171514783, 0.2347670096371855, 0.08200753879334245, 0.1391729741756405, 0.15741260615842684, 0.12667366702641758, 0.08381462004035711, 0.1026560515165329, 0.12020101291792733, 0.10770313069224358, 0.25103624377931866, 0.12092613615095615, 0.09390939585864544, 0.13387984463146754, 0.10594153843287911, 0.1364431328007153, 0.11909421373690877, 0.13138720552836144, 0.09362298622727394, 0.11905204957084996, 0.16818957429911408, 0.13365215542060987, 0.1468170647110258, 0.0909135958978108, 0.07125015317329339, 0.08789587247052363, 0.11840992474130221, 0.13370524400046893, 0.23836609508310044, 0.11621616674321038, 0.10539383175117628, 0.15954300255647727, 0.14694176587675298, 0.10346370496387992, 0.1620667049927371, 0.13667580245860986, 0.16478526911565236, 0.20264863595366478, 0.12647140930805886, 0.13842803772006715, 0.11141405227993216, 0.08279430693281548, 0.09848530031740665, 0.12790252108659061, 0.1567433534988335, 0.19275179558566638, 0.10054486444486038, 0.12336746443595205, 0.16666037349828652, 0.06226668879389763, 0.10075625524457012], [0.07611174123095614, 0.03758956099461232, 0.034910314583352635, 0.0399152770904558, 0.021119902875008326, 0.021347571729815433, 0.023932130275560275, 0.03826643020978995, 0.0090951699031783, 0.03180663433990308, 0.010391275265387126, 0.02753488829226366, 0.00947782803060753, 0.011183521726966968, 0.0055073850339145535, 0.03331999134804521, 0.010838274627790918, 0.04724456469661423, 0.03261928180498736, 0.017182681376912763, 0.05794175408248391, 0.024667757230677774, 0.014553554954805543, 0.03973914975566523, 0.047251597712082524, 0.005193334006305251, 0.05044443067163229, 0.009242288169584103, 0.03668778795482857, 0.0568947168732328, 0.06518620784793581, 0.020760533765756657, 0.022568800752716403, 0.0231721439132733, 0.07741446061325924, 0.04090420456070985, 0.04398135408493025, 0.040602151304483414, 0.027321823207395415, 0.11724098532327584, 0.03824276630101459, 0.06890830490738153, 0.04703772347420454, 0.036400370698954375, 0.05837132781744003, 0.009599418961443007, 0.011063175907890712, 0.039125696423330476, 0.03767700040979045, 0.029366822580673864, 0.04303305050624268, 0.02796745945566467, 0.05899083028946604, 0.027835944102012684, 0.03996848441394312, 0.0399151787028781, 0.044052559549787214, 0.05992353095539978, 0.02434163973001497, 0.047049482486077716, 0.030681762378662825, 0.023870811065925018, 0.057393918479127545, 0.0187672743839877, 0.046029393295092244, 0.03125945691551481, 0.06304300070873328, 0.009961349540390074, 0.0465102608847831, 0.08221337917659964, 0.012341354374906846, 0.10696459960724626, 0.1499319068555321, 0.05070910004100629, 0.12209688047213213, 0.07608979740845305, 0.2162681094237736, 0.21586792304047517, 0.2590187197285039, 0.37055910165820805, 0.25389922729560305, 0.21264018623956613, 0.4278108738362789, 0.20549176553530352, 0.20074645802378654, 0.12416464808796134, 0.06616217869200877, 0.20245682767459325, 0.10323529650590249, 0.12494097357349736, 0.21675034426152706, 0.23518669711691992, 0.20161511855466024, 0.14233295246958733, 0.24810578674077988, 0.3088199874120099, 0.3938621383692537, 0.11130769191575901, 0.06809088734111615, 0.01831935645480241, 0.029898827962045158, 0.12831884303263255, 0.042238767591438124, 0.1577524029250656, 0.21994817123881408, 0.1042420660544719, 0.10560032352805138, 0.060265736521354744, 0.1429852010416133, 0.20456523953803948, 0.1501469753150429, 0.059477319541786394, 0.028859556586082493, 0.04775788661624704, 0.045877652508871894, 0.02741624983692808, 0.04511995959494795, 0.05695996140795095, 0.05691885236384613, 0.031640169343778064, 0.05644101443301354, 0.07551055920443364, 0.03744155215099454, 0.04754267227170723, 0.02048783902344959, 0.00677011877165309, 0.02977041181709085, 0.027879051431747418, 0.021095156702878218, 0.07482055694397007, 0.03428489189328892, 0.04485918840925608, 0.05044986912980676, 0.04040356106790049, 0.026733122832540954, 0.042563022513474734, 0.04625503672286868, 0.016848976158403924, 0.028150070192558423, 0.017302902515179346, 0.031638995478195805, 0.017712700347016965, 0.07896903183843408, 0.042195721329855065, 0.0428286146904741, 0.060546962145183764, 0.025626771484634707, 0.03368212209482278, 0.055845711912427626, 0.05601980024948716, 0.04479638999328017, 0.05186008881511433, 0.00795271625143609, 0.0204399921266096, 0.009404268049235855, 0.04191006826502936, 0.07471157064927475, 0.02649140660651028, 0.011171122347669942, 0.031211755903703824, 0.052922538947314024, 0.07347924248980624, 0.09055382306022303, 0.014827718725427985, 0.04673944965803197, 0.03344131340937955, 0.036426005751958916, 0.025647816248238087, 0.024051029966878038, 0.014236195644895946, 0.055740990210324526, 0.029143452245209898, 0.07203646669430391, 0.044306009342627864, 0.006521344085090927, 0.02410661555560572, 0.05469780707997935, 0.025556633016094565, 0.02548592457813876, 0.03747805054964764, 0.06830717037831034, 0.03883906966075301, 0.10585766471922398, 0.02763057190791837, 0.024763490040121332, 0.028620895463973284, 0.07305860506104571, 0.06101434385137899, 0.011443482063311552, 0.008188963485216456, 0.05275790938841445, 0.07377720078719513, 0.03264313909624304, 0.05353134431477104, 0.041504049873245616, 0.03366711290021028, 0.02622649126819202, 0.01852286607027054, 0.03242353802280767, 0.03607936595965709, 0.026994676029841815, 0.007778263201804033, 0.04321139325786914, 0.014813243877142668, 0.08848847781441041, 0.013880397326179912, 0.02084214286878705, 0.05211081089718001, 0.03906300657295755, 0.00502864210700084, 0.014092627812975218, 0.029388715513050556, 0.08760406848575387, 0.03415975307247468, 0.01742266903498343, 0.04700634801494224, 0.0440363493481917, 0.016799290431663394, 0.03355563638199653, 0.02731085808149406, 0.046658659886036596, 0.0609423445005502, 0.017742879888308898, 0.045625929587653706, 0.02396870161672788, 0.04326237498649529, 0.03945134234215532, 0.005530017569461572, 0.02457292008745883, 0.04152169856908066, 0.026245127232479196, 0.017381056178627268, 0.022709549271634648, 0.06377669383904763, 0.011666856639619385, 0.0013958889196926194, 0.03142569799508367, 0.09297216936413731, 0.03495167129273925, 0.0110166928664382, 0.04540417077285903, 0.029444297709103142, 0.03871265858677881, 0.06300564735595669, 0.15743235152746948, 0.09746205593858447, 0.05007721430488995, 0.11506393285734312, 0.08182955905795097, 0.057334668801299164, 0.060714906347649436, 0.07664982628609453, 0.06986648456326552, 0.021680547523179224, 0.07649830941643034, 0.13712510120655808, 0.06489268038421869, 0.07154648977198771, 0.10731932414429528, 0.1946912793708699, 0.23965791719300406, 0.13181620250855172, 0.15117807712938103, 0.18016414317701543, 0.048952868208289146, 0.028818410222551653, 0.09925436547824315, 0.10853160159396273, 0.09515522007963487, 0.13593560217746667, 0.05050091192658458, 0.19557809749884264, 0.2523222847708634, 0.19365014880895615, 0.08879413069891078, 0.07839657219925097, 0.07616843283176422, 0.035492083722991605, 0.09510076764438834, 0.10184345154889993, 0.22511145632181848, 0.1110052824286478, 0.07002748735249043, 0.03084931642349277, 0.10095448246491806, 0.04093353423689093, 0.06266112798558814, 0.05891233735850879, 0.10925863151039396, 0.028787920251488686, 0.01251562252374632, 0.03166433197579213, 0.05219688984964575, 0.020484914537519217, 0.025925812045378343, 0.009749376896901854, 0.023161623227809156, 0.0373105406095939, 0.016750322255705084, 0.059422439629478116, 0.0780777218086379, 0.025921920647046397, 0.02241635089740157, 0.029343185813299248, 0.022967548641775335, 0.023585936620033214, 0.038459368249667544, 0.05419314665985959, 0.059262692130037715, 0.013894818739832511, 0.010380854663838233, 0.04295002156868577, 0.0499046933837235, 0.012715095704022263, 0.042846670507320335, 0.043036368542483876, 0.01346722971980593, 0.03812464353229318, 0.11001188001994576, 0.028921235419277633, 0.011854594556747802, 0.07115212521914925, 0.029777723031916788, 0.0028830145061614788, 0.046722621989569495, 0.03030794725886413, 0.028034819323303442, 0.04166140553674527, 0.029446597942816358, 0.0335073077252933, 0.02313909586519003, 0.03934611173878823, 0.014082703390158713, 0.03396600079057472, 0.04823526653594204, 0.021208392323127816, 0.013955516241756933, 0.040474437443273406, 0.1016481691705329, 0.012802139024383255, 0.0215310306354825, 0.08167532804821219, 0.030094989043261324, 0.03477700620091387, 0.030561441156480993, 0.029196401725390127, 0.04220819280349782, 0.056004390719213655, 0.01279132063167968, 0.06837193654584033, 0.016492132895759175, 0.06409299972334079, 0.19971489480563573, 0.19004676145102295, 0.10898070356675557, 0.1420980572168316, 0.11570689907031399, 0.19258878433278628, 0.15845471381076745, 0.08822805607425314, 0.10136995624218668, 0.1728466179754053, 0.12116856314241886, 0.11148122724677835, 0.057731455724154196, 0.08485349108065877, 0.1177956469889198, 0.16103781520255975, 0.11778890235083443, 0.1665982739733798, 0.15104730986058712, 0.08093475457280874, 0.20247229827301844, 0.07540278070207153, 0.12567577271589211, 0.21034121460148267, 0.16744419001042843, 0.08760052653295652, 0.15333108231425285, 0.07906131260097027, 0.2318425237068108, 0.1463453471660614, 0.08324927144816943, 0.10104847992105143, 0.08298971823283605, 0.0919122840943081, 0.12202186164047037, 0.13372598003063882, 0.1716834461050374, 0.19221660787505762, 0.19490518075014862, 0.1579414563519614, 0.12104753963649273, 0.18082628478961332, 0.19847190007567406, 0.13511625757174833, 0.19767034665814467, 0.16952410340309143, 0.08501441244568143, 0.15012279232697828, 0.11683465141270842, 0.11277361254074744, 0.1170414010328906, 0.12221034509795052, 0.1630414884005274, 0.141663808375597, 0.10898335663867847, 0.1415263914636203, 0.10436412093362638, 0.15349083659904345, 0.1231533730668681, 0.1719799523374864, 0.0733909108010786, 0.2021204371537481, 0.14352592559797422, 0.14959824404546193, 0.11671400788639273, 0.16479517572692462, 0.18423767387866974, 0.09148331425551857, 0.26464830764702385, 0.3504144554691655, 0.2993396861212594, 0.3243428873164313, 0.2631195139672075, 0.07392926727022443, 0.23852158816797392, 0.1680236996284553, 0.216228862958295, 0.2984895088842937, 0.34158144944480484, 0.5121861334357942, 0.30750927488718716, 0.26451593903558596, 0.4648826888629368, 0.3818474273596491, 0.23679781066519873, 0.19588555528649262, 0.3461797184177807, 0.3199861768100943, 0.14422120686088288, 0.1407166684844664, 0.2790268175303936, 0.2971969539565699, 0.3067679889500141, 0.26880623453429764, 0.4548326352877276, 0.42070283953632626, 0.522220634988376, 0.2875818684697151, 0.18390912722264016, 0.14712163193949632, 0.10840521087603909, 0.202885078266263, 0.2530638149806431, 0.2496376202574798, 0.505321313227926, 0.2020904187645231, 0.13679100413407597, 0.12853853910097054, 0.14118886100394384, 0.2669554352760315, 0.36233618003981455, 0.20901465149862425, 0.17280817218124866, 0.1989049275538751, 0.15909362238432678, 0.18168638220855168, 0.14472777396440506, 0.08411597101283924, 0.08915205792124782, 0.10203105291085583, 0.13199298802231038, 0.18657811757709297, 0.11224530517522778, 0.08493513919945274, 0.18198504618235997, 0.11873938063425676, 0.1567590819405658, 0.15162372535892896, 0.14655350813908236, 0.19164578350526945, 0.11434402077325753, 0.21187110750802926, 0.15093077825648443, 0.1177965969379459, 0.10084050215248551, 0.15619239663439138, 0.1331601496785879, 0.08468601506735597, 0.12229746899434499, 0.11169515576745782, 0.12182900841747012, 0.089408802001604, 0.15451040331806454, 0.1769565317247595, 0.09421719969915492, 0.1237523430692298, 0.1628426776400634, 0.08645625186285802, 0.22619275615683623, 0.13293089983718737, 0.12254830982003893, 0.14322300042424882, 0.09039727824607066, 0.14328466568674358, 0.07970919140747615, 0.14997348748147488, 0.15101912351591246, 0.122501083782741, 0.14832935641918862, 0.11258411806608949, 0.10369044422571148, 0.1679472287318536, 0.30341640593750135, 0.11218106147966214, 0.17068709885435446, 0.12710738661033766, 0.08821748449866261, 0.08978421507137162, 0.13665548712015152, 0.1199054837759052, 0.09647949651948043, 0.10566410581980433, 0.10987424597676311, 0.3061344272324017, 0.09835552370973996, 0.10003225837967225], [0.0805680878194315, 0.0381258411466011, 0.027642380113580396, 0.028435753791459968, 0.025877753106345023, 0.019531313296673552, 0.045968684766973765, 0.05968829643513475, 0.05026200992454376, 0.02805661895711507, 0.04498887002202017, 0.009592684501382922, 0.03736775468236633, 0.00976539880502969, 0.10806414524891547, 0.03696164468835507, 0.022391689542148794, 0.041431032719888856, 0.02281591642115797, 0.005200478980051619, 0.035743158643266985, 0.046019866663430414, 0.029869617029492344, 0.05805236886122397, 0.04414655700592058, 0.008349013780908925, 0.020967578548671942, 0.016473636031150818, 0.047022727850292406, 0.0769942845883114, 0.08949192254138844, 0.009407896515248078, 0.006894981513531613, 0.017590465656082546, 0.015940519548686485, 0.06884081781442676, 0.017811564595571587, 0.027748068728085076, 0.025651020629863654, 0.0327653059336756, 0.02650524702455316, 0.034374526369252374, 0.0230011276435107, 0.04175239708274603, 0.01449197281285056, 0.06515558556254421, 0.04039662304733481, 0.032711928976433616, 0.06059514491685799, 0.017160656130207435, 0.01463828531892172, 0.04183336666652134, 0.06131464309458222, 0.015267121040129235, 0.044689178067658625, 0.059755654606435976, 0.015575398158814226, 0.03900522592344454, 0.025380310602486134, 0.024350213019975593, 0.05305358441546559, 0.0631116684526205, 0.01852563110047153, 0.06083932252866881, 0.09439294705433504, 0.0031309401757815586, 0.05526557464950851, 0.058676003611513546, 0.020103547322962965, 0.045420930587819645, 0.027413600157680254, 0.05346914300961154, 0.05650266273213284, 0.054938412204916985, 0.03711802665410297, 0.07146398669907025, 0.02537878559503172, 0.23098439403942653, 0.22460560846541608, 0.2613387123814651, 0.214264911200319, 0.13332758497978958, 0.18666613713971206, 0.1286198275962046, 0.15131337701209954, 0.08950174094310828, 0.03305103363735335, 0.05816173513552972, 0.055227837924446375, 0.09885086105870348, 0.1580194743084056, 0.17262608052364417, 0.10616894944437913, 0.14708908940000193, 0.06826883314975671, 0.22439389196889742, 0.12561456885721, 0.15119459267173493, 0.08866376376577786, 0.01878148629995329, 0.01523755387669163, 0.05379432413194861, 0.13609180093875953, 0.04741219338029623, 0.10148462187498808, 0.04506476755653109, 0.06099069690597909, 0.03361816338396498, 0.053792777072106085, 0.07327881003064768, 0.10347724852285214, 0.0667196698486805, 0.03919741078945143, 0.05351302047659244, 0.07198643152202878, 0.031752996146678925, 0.12990107813051768, 0.02994399464556149, 0.04180857638961502, 0.02556333694207881, 0.03381134569644928, 0.05996482659663473, 0.07325226574071816, 0.03254394066919174, 0.08899134690208094, 0.02945969706135137, 0.014053445808323366, 0.041073244597230635, 0.00787367285894496, 0.06688276252576283, 0.011126823340808707, 0.08825177087315492, 0.012074805463531187, 0.042340703907289674, 0.011135662107595375, 0.046340409998915026, 0.029960740889821733, 0.0012588382045838184, 0.0044810282997787, 0.018555293258811747, 0.059771966588284285, 0.014478977170905896, 0.03018248952659113, 0.01798859777461205, 0.06116969444389854, 0.06480981768774134, 0.01933591896002846, 0.051557278992342095, 0.03392552278403725, 0.03469161596149206, 0.05931480361946991, 0.03609888401946851, 0.028988912502037625, 0.024256683753005097, 0.02102419890330306, 0.024806302207122956, 0.009083335404284298, 0.040753722456949096, 0.03807314611705286, 0.014814293910084026, 0.024248831406501786, 0.055992065130599906, 0.021303482220641205, 0.013332537974097898, 0.016395445048276867, 0.04076514220131295, 0.039421232350702794, 0.02124511803101216, 0.026918507081323435, 0.049788796209863255, 0.0572763147896954, 0.030872976939593042, 0.01736797402346773, 0.039977675170770714, 0.021832960059068034, 0.021469168597832322, 0.027757758208151375, 0.02047651936300099, 0.03610791192789163, 0.01814894238486886, 0.022396790429151485, 0.04883248591795564, 0.0851123793316739, 0.017159159960491315, 0.09468358395887272, 0.07909656249518905, 0.02954086342028209, 0.03028141993231007, 0.03693914446713669, 0.04100042421902929, 0.023209263171468462, 0.05560418397986463, 0.036376353951969316, 0.03466702245974115, 0.04715038403602583, 0.027470198459923267, 0.024524070655128787, 0.06180766663913216, 0.010713178215415349, 0.014353200527174132, 0.03385148782815252, 0.04754165107650416, 0.04411863868257829, 0.06438113283365965, 0.026037894156096236, 0.044251719755785804, 0.06614493033183472, 0.076232099772564, 0.01099995001485305, 0.054371370667857785, 0.02946588530072144, 0.04957814162064876, 0.024309962322669368, 0.004619572428055108, 0.031693393630640845, 0.04453827187951122, 0.04489388869010976, 0.05234515992924571, 0.01389076788577118, 0.004789610335137695, 0.023925182076969316, 0.06342224071600608, 0.04955419611984065, 0.038952296799314876, 0.06389097949223858, 0.05634480834539447, 0.01944834373093077, 0.04363331651049001, 0.06985370774886437, 0.021107538270631006, 0.03186618935848985, 0.04253315679462893, 0.03151349703382168, 0.018351610616913865, 0.06798284421009676, 0.03319187715117421, 0.05574148554088814, 0.0538250515902681, 0.052617530671081374, 0.01247013608060245, 0.07873051999402897, 0.031233109400740693, 0.0012031600594387523, 0.01677621345567916, 0.03796415303700736, 0.043778044637292624, 0.03953444591856428, 0.03599182476422616, 0.022637539742780582, 0.008506755361200442, 0.03442769298063857, 0.07656025966363293, 0.07826451571392161, 0.02659505113427128, 0.10736614306058202, 0.12459101235227925, 0.18721333492015088, 0.21802749644432748, 0.15956174369369233, 0.10835163375096661, 0.17008221202663013, 0.03813630754926375, 0.017737505890961205, 0.042896301951259375, 0.04993266938254237, 0.12357778315033231, 0.16423017318759645, 0.12834086827933788, 0.09717712551355362, 0.05044281575828791, 0.18802372286362307, 0.20115881732531957, 0.1382182211216007, 0.16024540843708174, 0.07154049830777304, 0.034637780993112495, 0.02612956932612828, 0.0618316935641425, 0.12943641734974726, 0.07953768489616257, 0.20029753925544874, 0.09057047430958066, 0.015977114638579742, 0.029845043883791993, 0.05763070684458528, 0.148008884329881, 0.05420599811311279, 0.0624703239383442, 0.06217258955751147, 0.005767941632906773, 0.039128814291741164, 0.023818521461050426, 0.07600466161966324, 0.029883978223162036, 0.007906386728531547, 0.01399407144968531, 0.02632696534107838, 0.04545779200270772, 0.05562691829566445, 0.03356412485507982, 0.023954947711899877, 0.09083074677203383, 0.024019111679600816, 0.014234334762607301, 0.04937719686755112, 0.059787552537662644, 0.06942105346492358, 0.008309899629758937, 0.033437910556261025, 0.017905400899638022, 0.06364376882889441, 0.05365756539894002, 0.025967709886442338, 0.05469501151570252, 0.08030058217367955, 0.013107059939232255, 0.007742003138576235, 0.04414156298818333, 0.039928511915994544, 0.037691046084676466, 0.05499700031110218, 0.0654184025313173, 0.005279262832898114, 0.026717630181727663, 0.07469249024455037, 0.024348038315240825, 0.03462552325800061, 0.02721905059713338, 0.04787429269137127, 0.06423699842499835, 0.059382494272930283, 0.02171309175901115, 0.023767273407429457, 0.06777185374604804, 0.025957801578832523, 0.018672352423891425, 0.04125718526276095, 0.0738813423418573, 0.007036926798588995, 0.02049222235967006, 0.06029028591832944, 0.06605927207108055, 0.01301737966215504, 0.05990930886140891, 0.07886727872703757, 0.04808920508782778, 0.03094300514619265, 0.04433046035202486, 0.012086745135353079, 0.01970528289010482, 0.023108363317857896, 0.02442732682850744, 0.2767086976340839, 0.10469969721244914, 0.11870215620313372, 0.09416290332696267, 0.10838962492666074, 0.09955442723418985, 0.18557882548442908, 0.16229925251432828, 0.1628564383302416, 0.15551382090364183, 0.21986734414739267, 0.09203224230025496, 0.13419340923428535, 0.14645269140601158, 0.2372201308608055, 0.2478474277470793, 0.10239568405917712, 0.1612062683062894, 0.13633452648563044, 0.08778350028608527, 0.09003867248871497, 0.13462645028318676, 0.13478691024439676, 0.0950113231582301, 0.1385527660271951, 0.10961377673915454, 0.07545117381960154, 0.13183069601655006, 0.14765557114567074, 0.10118460761649267, 0.1536853997302907, 0.13322264275380544, 0.09787767899355718, 0.12238371079521519, 0.10107879686568465, 0.09750520398042031, 0.07436727519546237, 0.11572435099099364, 0.091105974146298, 0.14127622917294502, 0.14574459940195084, 0.13277088770908968, 0.10825769057763474, 0.13156481885484286, 0.10902511368372611, 0.13733035804969923, 0.12400709225663117, 0.13163303876561777, 0.21518942873392785, 0.09175713027694396, 0.15759355787719997, 0.16774794299687656, 0.1548852396330663, 0.1337557677179575, 0.21804067359438964, 0.15606350212224893, 0.1627999163631882, 0.16023050780807221, 0.1126366231058325, 0.08645103392856461, 0.14562479725905828, 0.11841198748775891, 0.1240940261632204, 0.18996444158256054, 0.3156031391450337, 0.11454968473740987, 0.1007106848327177, 0.17533708576645168, 0.18626723997294903, 0.11162584341530289, 0.17459996603429317, 0.15266134110944612, 0.07058909043137516, 0.11122897506824561, 0.08968692672039781, 0.21150195731648377, 0.21810166032186576, 0.4317512352551733, 0.407257858131613, 0.45900673844984596, 0.4574102269751685, 0.4381977250533444, 0.33037764206528664, 0.21049304359725543, 0.2578141843633992, 0.2219606111092227, 0.1122594051329153, 0.1196606411997761, 0.20628763282937662, 0.25279590221388, 0.461618609726429, 0.30964894007359234, 0.5170562235372407, 0.303603817309652, 0.483525139944894, 0.30726014396974016, 0.24514626126204217, 0.3462451291935784, 0.24579339368002756, 0.11260507801281554, 0.09723966608622245, 0.16339670148278984, 0.33110362025243895, 0.1617038380354643, 0.3543082965271813, 0.23637559903519495, 0.18634582789880888, 0.12078858353197575, 0.13502456034932817, 0.2596677249031407, 0.176498235602464, 0.17565677075513772, 0.14050051436892577, 0.14639179967343807, 0.16071993511702332, 0.08509191471551146, 0.1826533760343279, 0.0973901447973081, 0.1598225182720593, 0.07892220613679715, 0.11460187765104429, 0.19455117546021938, 0.16982937630798134, 0.15906173123845033, 0.11934274754353932, 0.14411360477762564, 0.06892028783581086, 0.1119158628529736, 0.16492008045315742, 0.14975319430232048, 0.1471570786088705, 0.15573893168142863, 0.08544098027050495, 0.08389114521976028, 0.12366003516529288, 0.14666083880833217, 0.09033127714480672, 0.14464553552014486, 0.13267686989690575, 0.09155278267072779, 0.18075931338327272, 0.10338784474879503, 0.08432580118200608, 0.10012175036328179, 0.178568106676851, 0.15563333806182655, 0.06979379989206791, 0.147359146337424, 0.1475613633436816, 0.0962227727951748, 0.18749815677957876, 0.147754949384502, 0.1567480353904622, 0.14399757528943674, 0.15165177599659987, 0.08095627770360027, 0.06645097676664591, 0.1589516457170248, 0.06689790064202887, 0.10451387361224208, 0.08571996672877244, 0.1503539013543299, 0.14764008697654518, 0.19229956556643757, 0.10219400309558425, 0.1544428076595068, 0.1606484039553574, 0.15276538766920567, 0.21710054975535187, 0.09525482223502227, 0.10938977875879832, 0.12109453497188431, 0.10464330416704927, 0.18759514657514437, 0.10071961435356311, 0.07484533025750092], [0.04812185280025005, 0.07381495447563273, 0.003305712772998959, 0.06928626926881926, 0.02568460302427411, 0.04725042723917535, 0.01650485542735883, 0.017896739400124977, 0.059310318502996645, 0.024905724550730417, 0.020411748106458356, 0.02049098742593612, 0.030073255566614013, 0.011939247737505605, 0.018854835935469185, 0.04244239595053451, 0.04839953647128173, 0.039700578432530165, 0.05169556103646755, 0.032447425848139186, 0.04060124885290861, 0.0349124892880874, 0.05227569829938667, 0.05462690356320568, 0.01438662176951766, 0.04541016562974878, 0.05059481438781534, 0.016317138714449744, 0.02746956572601838, 0.044937559203909974, 0.015798008535057306, 0.003550470744292917, 0.029358554631471634, 0.11936410782592637, 0.035830279146986346, 0.014864337564046894, 0.03278306319511362, 0.011784774999666427, 0.02839587289573891, 0.05230948595064027, 0.006420848383900842, 0.028500452105488096, 0.011159070717569972, 0.020393661755536283, 0.023659011448866556, 0.020632509474775622, 0.03350844766412463, 0.02220960975890713, 0.04385851210515414, 0.03049794045676078, 0.023462982681979026, 0.06226616632193327, 0.053485058048473935, 0.004979984360813562, 0.01790679189642625, 0.038144297299108336, 0.0195738608350179, 0.03184470354712435, 0.04590638168156147, 0.05461433709466031, 0.04208263668364712, 0.04493190361452954, 0.06839914580008813, 0.01740172944430794, 0.03416555454688413, 0.022649512493184636, 0.05649962628792439, 0.06199230958840676, 0.02242659847252071, 0.009825197248054402, 0.03572554387418287, 0.05089286428743175, 0.05008509888180664, 0.04373576512028064, 0.04952388256788254, 0.007187509410349386, 0.12421272907938276, 0.11108958361936466, 0.0986224797421268, 0.05861382944775479, 0.07694093816514526, 0.21247448798801216, 0.16877652066094534, 0.16223097832075187, 0.17206631627465996, 0.050602498796901534, 0.02863046620041132, 0.06769007670560054, 0.02096051160645272, 0.1254990550556353, 0.032750296739063094, 0.1577694612954344, 0.07126360852271318, 0.13519160210021905, 0.019821992609649897, 0.12203972068216119, 0.062314423732459545, 0.037937031992311986, 0.03552849391209228, 0.039513034746050835, 0.04627747248326029, 0.04444484778546861, 0.04237739568842309, 0.07837318309715816, 0.06656332859503371, 0.027465326578489373, 0.011578997380898466, 0.026665333791502883, 0.008818283510793532, 0.05826159513422421, 0.05648260523698159, 0.07987936799015317, 0.027950423137683953, 0.02925863695730056, 0.08459853154740163, 0.0487889782525599, 0.018996145942115357, 0.00912965220465724, 0.019552076468244195, 0.039565658529422114, 0.01159773936628231, 0.03004011252362813, 0.03872788491259728, 0.0418453869143767, 0.02868746992732797, 0.014733972327251519, 0.03308378652270351, 0.02969709610832589, 0.06545006976063762, 0.042422867712697813, 0.04424029661874686, 0.005690287540866328, 0.016445945017039776, 0.03549601583342467, 0.04213519261351653, 0.03342986652361495, 0.07562430202960968, 0.020264053085286702, 0.02725652269353824, 0.0410367156645017, 0.04730073043278285, 0.057382899070424695, 0.025194290227123668, 0.07997907871114356, 0.08345585143459694, 0.03598696645349264, 0.04175431394417371, 0.020771938243082592, 0.0493969897340451, 0.09684236347675323, 0.035634202882647514, 0.04150327295064926, 0.005247523933316448, 0.03844883738617812, 0.007833195700576263, 0.004488027388496059, 0.03720078757032752, 0.009821201524963337, 0.06435723483030285, 0.0053398195388061655, 0.05299579019525221, 0.025090150368799056, 0.014417934464290738, 0.06245321128517389, 0.009051545190491846, 0.03806573651464922, 0.027737502241507173, 0.01591199224016496, 0.023112253019852296, 0.06928586214780807, 0.06963620334863663, 0.0460235884280077, 0.01747912654121007, 0.10864324096058096, 0.040861192225877724, 0.07974510626601321, 0.03077804989048413, 0.013885080914146133, 0.020309767685830593, 0.0731037479958364, 0.032504575460084846, 0.06375448538788728, 0.023946272641686455, 0.08289840099002634, 0.009327123706628169, 0.03617460174219949, 0.058798743811036856, 0.009646178505915617, 0.025979358636374985, 0.040376049865569384, 0.10583378707191773, 0.022979255067184567, 0.03809005181704249, 0.037622144246207814, 0.04068616072514227, 0.03976575850642153, 0.02484499227388629, 0.022291246003338268, 0.04335291191403355, 0.014392411369564278, 0.00041811280139622146, 0.05295420617663434, 0.038836959416845014, 0.011290514825044997, 0.05681121296116284, 0.012776113813742995, 0.03290697047486901, 0.016166524296360354, 0.04649130261636206, 0.04914098186418414, 0.05931008101574012, 0.013313242982673858, 0.013075775234028697, 0.0663452542253903, 0.019363353827169964, 0.03923300334385463, 0.0317793640175036, 0.049723246334386725, 0.015163600345009139, 0.05627825763076544, 0.02027341177953141, 0.019536731398797462, 0.015877252943547707, 0.04572716361976095, 0.03395614506942885, 0.034154280687549284, 0.050938210782728026, 0.05817967560142279, 0.058897389232047966, 0.003309057102472122, 0.03431790940729635, 0.07258822423006807, 0.02988842941288437, 0.033933834838015695, 0.0437999952451459, 0.029276618135294745, 0.04347660206258297, 0.05149338813498616, 0.03202479013374873, 0.025146529843498553, 0.03948700275006039, 0.020619218670097843, 0.017140298383310437, 0.011483593660938953, 0.03863674408889242, 0.06210259867033788, 0.04118595944185342, 0.02329348463432065, 0.06458330234246594, 0.015419552235731056, 0.04620698965819819, 0.017596297664567828, 0.05104870342516473, 0.02769237118107932, 0.03620420622506312, 0.05282928787970117, 0.07549453899264336, 0.02701044688001275, 0.024519561789929867, 0.036339275405875275, 0.09042186156979629, 0.07697014231234789, 0.04452460279156055, 0.10686288042260067, 0.06958403079105274, 0.046788826651339016, 0.049306547801409445, 0.08419692702591419, 0.05384988597195063, 0.1738537810742855, 0.061594009532460144, 0.08782558302794184, 0.12482528335281781, 0.09960941571210112, 0.11519480869174004, 0.04546684705253158, 0.05921370868704148, 0.068867206041302, 0.05568911281547376, 0.09096311538347177, 0.06465424317866564, 0.0177409477598433, 0.05665119404771498, 0.04281264536881021, 0.047448416972266774, 0.06300366603370224, 0.07936152363462107, 0.08959814719855785, 0.059202675707638264, 0.020441859794248427, 0.02829200105874666, 0.00817427150572517, 0.035519598317997794, 0.021134703420102596, 0.05021694162860513, 0.07969282514282636, 0.09181301442107984, 0.03277215913736394, 0.07936943535293851, 0.07227898868066923, 0.017639503381880264, 0.05562199552410415, 0.08154832664877176, 0.01618428834314857, 0.044101444605205736, 0.05778955189245088, 0.04083867843395897, 0.019653715925025086, 0.04209780194131391, 0.031230290087738206, 0.02945552746366177, 0.064668919891119, 0.06005526174392019, 0.08213029256356613, 0.02114788057016475, 0.0408596485587103, 0.02346915056529854, 0.02167029825172254, 0.013278731843456626, 0.07022254581430129, 0.11052249797752925, 0.025843349684562002, 0.016619714442640543, 0.06308578912700925, 0.035440352213169844, 0.06417721270450524, 0.027143202256411314, 0.029016464416469847, 0.04533066168161375, 0.07022331255887236, 0.02342445376728262, 0.06155705651534455, 0.03183312773970621, 0.01300903283325689, 0.04727252373205764, 0.05639583757147193, 0.08034238671617848, 0.032098764021481783, 0.0634736397436687, 0.07135298515536956, 0.03539462234558804, 0.03784262741516743, 0.04502839468685644, 0.012271295634231396, 0.05970371275075844, 0.030573173026953424, 0.018923564747508084, 0.043565904056387286, 0.011109675064549913, 0.01095936683538769, 0.03609572204628161, 0.1082959124552352, 0.24031186210257666, 0.11915967879550797, 0.0913308881489294, 0.09066839369812182, 0.16263204679957458, 0.16195412246244295, 0.09112960073564734, 0.113605191132852, 0.09394739381968975, 0.10565905751926558, 0.1456016999270235, 0.08271269274077245, 0.13468419361327374, 0.19825759157538414, 0.14910220780542918, 0.10492627362587623, 0.09061986487358809, 0.152768128950681, 0.1381488341305937, 0.08239668541188751, 0.1254706380090543, 0.13305174692400865, 0.11169051458793026, 0.17787096622799123, 0.11067415733954736, 0.14774352285478795, 0.15082223979490145, 0.09019751075123038, 0.12866284671638692, 0.08719289662050349, 0.22200033254921436, 0.1327195768909795, 0.10601947496512107, 0.2243104593030044, 0.0928194039900388, 0.058546525559255054, 0.09946754082505192, 0.16408103119049752, 0.13973296912653105, 0.14594338302101406, 0.15309440929974827, 0.103022786123412, 0.06703381120626416, 0.1159917480711426, 0.12069295080644743, 0.1631936159517084, 0.09006141698254005, 0.1207833316709314, 0.15780456869729928, 0.090083028322884, 0.14236704206892423, 0.17802032535629614, 0.13047245889902115, 0.09610808002097265, 0.12790528950946672, 0.15027190718267644, 0.11741729586252145, 0.15453351422079972, 0.09521488366382462, 0.12309580615588597, 0.09136324748396873, 0.2028623337724379, 0.19653978518077306, 0.15703341364860535, 0.07400060844208513, 0.12470609189144202, 0.12001430722219603, 0.09223461536956684, 0.10862728181694235, 0.15761053482336657, 0.11857381808970656, 0.15694068505295686, 0.201162399990218, 0.13703113767717565, 0.15236999174313887, 0.11068732770425932, 0.26229083271963255, 0.3347531072795391, 0.22037716821900435, 0.26588476129940575, 0.21654013411274978, 0.2652929701975414, 0.1678389616842781, 0.2670919836631843, 0.2533569692501, 0.2388422909591879, 0.08552627890769925, 0.14557989181152411, 0.1029139898185219, 0.1874826726104532, 0.14798390067049436, 0.24046328397733824, 0.25796644762158394, 0.241109520729099, 0.18593374001128332, 0.36679192951747347, 0.2773704592670713, 0.2670968962567193, 0.18680491112172604, 0.1538440412176507, 0.20008818406079495, 0.1716025783015149, 0.12536946843777383, 0.1814959445702178, 0.17064375403736318, 0.0826091007994754, 0.10394110184695039, 0.10681895206549338, 0.10263893886336259, 0.18557320721447468, 0.21194244867988996, 0.2519209991608347, 0.1610579134098121, 0.09824127876865012, 0.1534681056759187, 0.1665938092129571, 0.08527814543672971, 0.14066136788044656, 0.11877185532024928, 0.19726360562656606, 0.17133486909525736, 0.11385953319924218, 0.13529130603585923, 0.1309379203511136, 0.13702737859317235, 0.12587159792227404, 0.12159431672522, 0.0655519450083375, 0.23208524925368174, 0.19668556164417947, 0.18225483170577458, 0.09419749504221336, 0.09047400698597942, 0.10749931912869215, 0.13266982670341218, 0.11434824126107351, 0.16511882336011954, 0.22639434891087667, 0.14538106748035975, 0.10266380038644586, 0.1551455935197217, 0.10900515796882765, 0.0989954365151269, 0.21648144083363668, 0.24010553317410605, 0.21590708808175155, 0.13219280301460198, 0.11218387739998953, 0.12929936684668064, 0.23763599140303476, 0.1007734357512423, 0.1094803563984377, 0.09349306034190313, 0.13080715308231966, 0.07486413246286766, 0.12082101750586714, 0.22483556398323604, 0.08930719816791159, 0.18815957914505685, 0.11544748156198434, 0.1640669990863119, 0.1774059526090111, 0.08414370952440159, 0.1669541791613613, 0.16936460696160793, 0.1360554721738611, 0.24078309110232762, 0.0871377724355885, 0.1006262886470982, 0.14506344523813042, 0.13646590443594114, 0.11194535877023425, 0.14444147289863654, 0.12479820980557374, 0.10322755442133971, 0.21288658944623812], [0.0497855595978243, 0.04715790220403245, 0.0025331839029344595, 0.042158887056367736, 0.03780001202332122, 0.0231931784988514, 0.01726592405300055, 0.018342306205470647, 0.047573925594666173, 0.04531585944018193, 0.015927795320749283, 0.027364221468035663, 0.06153792182781866, 0.04923759846548949, 0.04961950172271047, 0.012237738684884139, 0.09349167613046509, 0.08219785429537296, 0.06139606051146984, 0.05100814738710012, 0.02726518249671374, 0.014580655643450362, 0.117338395810553, 0.008780755435249634, 0.0585838042731796, 0.0354951981987272, 0.03240866453519889, 0.02379081517990146, 0.01581589302181133, 0.026631471501397233, 0.04995417215728334, 0.040624037451509915, 0.030413642658718994, 0.03260547361735787, 0.011702180324521447, 0.008071028161793947, 0.011684566403606107, 0.06405999578003373, 0.019850906683132052, 0.013669514579565396, 0.016510702702882032, 0.020333513018808196, 0.03544910192223532, 0.04697862985943045, 0.026384817236768346, 0.025379455648362637, 0.03270050244671958, 0.04496574215590954, 0.026883489585348537, 0.059554848953017166, 0.042156152560242584, 0.030285107770136425, 0.09495105567787375, 0.038734948462141414, 0.009167075955442019, 0.03668788634240627, 0.0760629613484655, 0.009726160821238799, 0.05357133377609508, 0.05906603232558284, 0.03856083976903132, 0.039012923903231106, 0.030120766588619778, 0.029640044883957932, 0.05690010444128087, 0.047172541597059796, 0.02033326535352639, 0.05271272913419774, 0.04979457732822214, 0.015775223329131092, 0.15608919145805494, 0.0029683481303176707, 0.09689516028655426, 0.01478317120511617, 0.134060443512031, 0.02156776312871703, 0.049916788270430903, 0.08572541536497218, 0.16015415904777391, 0.10091894758599144, 0.10468879315469946, 0.06384751253894397, 0.08087849044906241, 0.04180114303848573, 0.0838911384344101, 0.03881225734949112, 0.04206767498648592, 0.05766903728778873, 0.0596897756414754, 0.06595290492155723, 0.11203558357166392, 0.07388232621763434, 0.09419879104409899, 0.01281623134855181, 0.019387808229242052, 0.10008696187287569, 0.07208479195833206, 0.044638952905578275, 0.07456649307693754, 0.025007362311173762, 0.02002461504058114, 0.013771052256093493, 0.08141002085592065, 0.09291302146656172, 0.0306818743369409, 0.08516054853264775, 0.043154036692742787, 0.028905808925628662, 0.07399530908358948, 0.05732494539448193, 0.03782113142577665, 0.056751871681106944, 0.040381668135523796, 0.033429717245910845, 0.007654566267904426, 0.04088571108877659, 0.033455552466745885, 0.05929285301161664, 0.045440068668020625, 0.02942670668874468, 0.0026838231299604687, 0.05280064352388893, 0.024580231302284768, 0.03215063802365746, 0.038828956096300056, 0.06297172739037446, 0.040666785157684765, 0.02850057084911636, 0.06374429379190717, 0.034755232012165446, 0.027016669046133757, 0.028391771151551178, 0.028348794439807534, 0.014304488498185362, 0.05087513756006956, 0.0311405300827963, 0.009544169247549559, 0.07621637811618191, 0.054557452111371925, 0.012797007603304726, 0.027238867212353007, 0.03540898353925773, 0.02281903089689357, 0.025618944583194594, 0.027473523281514645, 0.006877211529561984, 0.0865363868485604, 0.03474990211959396, 0.04444358231765883, 0.036041557988418, 0.035926563266132555, 0.03781127231195569, 0.035000447782554796, 0.020462629751169255, 0.04188627543460045, 0.02497033804788121, 0.0189045030024967, 0.02455622303698744, 0.01831647946632334, 0.03987103999991502, 0.02957934992653983, 0.013676575584603208, 0.06067728836621557, 0.08005734094019447, 0.016610274324193597, 0.015215021425059863, 0.012995540164411068, 0.019834635413384864, 0.013887257315218449, 0.056628476695290635, 0.047075724827923944, 0.026088721518005644, 0.014425815648532339, 0.048299710399338176, 0.014552281005308032, 0.045390379548604996, 0.06304839506213154, 0.03141261923259922, 0.014861750649288297, 0.03514474843229566, 0.056956080187644274, 0.03359764787767615, 0.07293845007994346, 0.02651463625287371, 0.06746760542903628, 0.03275795400674854, 0.0429061305310045, 0.048639083081590276, 0.05853248666971922, 0.04979045183530875, 0.05368020132716213, 0.021211644202204685, 0.05448448245546647, 0.038549521804920266, 0.04031565685623458, 0.010049062065913208, 0.022457962057420185, 0.017272463434242775, 0.011434976626852793, 0.027281170478090644, 0.06094552004443748, 0.05686338891142181, 0.01771003540073122, 0.03222138208470174, 0.02584412321448326, 0.03216324181162885, 0.02262996559563492, 0.027552245218040686, 0.03423789995057242, 0.06240052982632603, 0.013899166452964502, 0.02741191060548382, 0.05430166476539203, 0.015229774472702826, 0.021327414150748934, 0.029055412326540266, 0.024713331035205295, 0.05889203559075083, 0.010458731824266059, 0.03547845873981714, 0.05584528443536588, 0.016686293995007873, 0.02804894811872925, 0.04573761645172324, 0.015259195751111423, 0.06821282686931746, 0.02674968078333352, 0.030796570503818135, 0.018447655552466, 0.07546722795814276, 0.034771934151649475, 0.0020993767455885454, 0.027883687522262335, 0.04424101586586662, 0.05635020948414292, 0.01619351133038955, 0.0018716218016509498, 0.03884750045835972, 0.01864555198699236, 0.018895463219710758, 0.03824873062382851, 0.044821102238659344, 0.04331725150612848, 0.03161537567419665, 0.013843881115982575, 0.09909787494689226, 0.07749167111303125, 0.0788612872628229, 0.06363621673413686, 0.02007915059636746, 0.04357939333255802, 0.026708642985405665, 0.07351253820317132, 0.012102986719193203, 0.0835418218214597, 0.0760011671643172, 0.08276435639709234, 0.07700599610273327, 0.06341709063521453, 0.05514886662630098, 0.03999960881524852, 0.027100715786218643, 0.02716655234274055, 0.10106781816908292, 0.014387508954054542, 0.04168767501999225, 0.06651119674955096, 0.04325748274901083, 0.06665694607155663, 0.08788091077336244, 0.04414065035858324, 0.1077471472589033, 0.0756754499993154, 0.03438600039641772, 0.01584226937432374, 0.04449530025678022, 0.023747322781543647, 0.04256381979212165, 0.05953574140689202, 0.07004865764507226, 0.05177957045712641, 0.04311605230239885, 0.05844990895794971, 0.012146299305771078, 0.03952089557424188, 0.05508598339344774, 0.02132927333670003, 0.03731649814705763, 0.016745480908347026, 0.04010490048676729, 0.037742380651512315, 0.04659150527524097, 0.08040893064545733, 0.011686853914787727, 0.09365712332406215, 0.03809758016307439, 0.020939743345869438, 0.037496520272855244, 0.02552430421513106, 0.0018911926599685103, 0.02939058487702693, 0.02294725365936756, 0.02028686203993857, 0.06318969997976508, 0.03632085318011897, 0.03422992377142821, 0.08733870701066085, 0.04448749710406576, 0.02147262743008988, 0.010313515152250017, 0.039918109974158664, 0.02973847317376307, 0.019409158333603824, 0.042076441658926864, 0.02042758172111852, 0.04944705204772098, 0.1476211151374238, 0.006166168322254504, 0.026192050526982973, 0.024969747722414986, 0.019072250429806963, 0.01101760719237583, 0.033759532762425284, 0.021634658199868033, 0.013718600650983197, 0.05556321742811373, 0.02894568642867463, 0.030224541734371866, 0.014896176123459424, 0.03453233325853944, 0.0529055314670716, 0.02233933547644743, 0.04155748450596418, 0.02654839337005147, 0.030269735559288944, 0.020947617744760852, 0.023437630917344774, 0.03927468235737511, 0.1199690353657518, 0.07101019604929856, 0.07348636032215186, 0.027238972385280898, 0.016652552144868032, 0.024642468230532746, 0.018404273416048715, 0.005542841457229639, 0.05340043116094811, 0.07345462523932968, 0.028554561880550215, 0.06572289512093578, 0.009792680153623223, 0.020677557414663688, 0.1697936582245997, 0.2158053892531565, 0.1283236877726657, 0.17793845332094602, 0.19879368852291787, 0.06713056351457324, 0.2656826935708523, 0.1577583604625293, 0.12260351542915617, 0.09594176430255175, 0.09121544898620673, 0.15392102780086653, 0.1402758378535509, 0.15095779752092703, 0.11419496020036084, 0.23362253819193157, 0.25453200191259384, 0.15984201936849526, 0.15879615263215133, 0.14791540934571198, 0.10854935207005058, 0.08325305088822331, 0.19481707976332732, 0.19396289916975157, 0.14386659088943685, 0.10270080090101276, 0.11342086709503617, 0.15538631060293742, 0.13122610774423393, 0.210580099640148, 0.09123323338904551, 0.15930711664259434, 0.13748733034091337, 0.1278528251818248, 0.07038145193031856, 0.10197069722094707, 0.11437132502240793, 0.1399481190102441, 0.10593398633812155, 0.14076358239565576, 0.12211282604507037, 0.19160166515835694, 0.10651567405355827, 0.15680826215871743, 0.11113634825284992, 0.10095433997256414, 0.07317912645105805, 0.10507124941796064, 0.12332698303673949, 0.14705343917012215, 0.09879745356738567, 0.06735929088400942, 0.15402462652751378, 0.11538460850715637, 0.08787658850529365, 0.06960139450217996, 0.14075067665960106, 0.11261509997504097, 0.09493800744946514, 0.14160962056900772, 0.14694464286523207, 0.15157633647322655, 0.08102342552904572, 0.12824887250150951, 0.13183502506996903, 0.12001212233943598, 0.14884133823215961, 0.14923798266266072, 0.15834386833012104, 0.18569466498281273, 0.19657220558396407, 0.18918647404227937, 0.14213484738554272, 0.1657160156007324, 0.22621417072202477, 0.09924707122679267, 0.1580256896891764, 0.18211940968675272, 0.2815870115799563, 0.18831883131393365, 0.29776344927293913, 0.13700133641915663, 0.11122134154928581, 0.15984106941946916, 0.16670941800943442, 0.27183258214167183, 0.12552173169595854, 0.16299126323844704, 0.1132341410432543, 0.21990485356322356, 0.19739681562142714, 0.14050820895603724, 0.2656747954232352, 0.15357304790190288, 0.09824860016150133, 0.1965110424373831, 0.21588443858282907, 0.18642068388206617, 0.1493430198835475, 0.12420324315982205, 0.10950128920376301, 0.22262290199952467, 0.15640184682394775, 0.13640464629445756, 0.14206240698695183, 0.15259666315146855, 0.1755242935780968, 0.07982163823076657, 0.25885041590247837, 0.23872267880610057, 0.09244877459215266, 0.10163147720907416, 0.12218939193657466, 0.08959436097315379, 0.23100149312189647, 0.15407634446663515, 0.12443610280752182, 0.11466690844723157, 0.2218358013778925, 0.1570159617279257, 0.06594415181981665, 0.13363540917634964, 0.0881969520289983, 0.05781752110591956, 0.156788598213877, 0.12395749134676796, 0.07821176640157189, 0.160047371206539, 0.15941340236791543, 0.10313984019947903, 0.19694260427994387, 0.11364021032516446, 0.06212947544242654, 0.09100091656936066, 0.14157846224095139, 0.14196123741567135, 0.07329407706856728, 0.13949962093361787, 0.10839320080620901, 0.12829969477440628, 0.2191233847822462, 0.1603465372962611, 0.11785234537507806, 0.09136725084057876, 0.07030426178659711, 0.0974816113178219, 0.15282011830380984, 0.08430121785828046, 0.10488540546170302, 0.10982667388660566, 0.15018148560609135, 0.15538055662597927, 0.12631903748427117, 0.14163822760539396, 0.19577795320323535, 0.11547551862895489, 0.06940953194030694, 0.08773050670112882, 0.12418630692575659, 0.11471116250114781, 0.12652820268911974, 0.14769355553601468, 0.1785470720912729, 0.13205134203391417, 0.22674474439450673, 0.09202161644186292, 0.12047879158386163, 0.09394372973058905, 0.14438678297613347, 0.182094968855381, 0.12408388885004179, 0.10825027418988091, 0.12924653611012868, 0.15570959182722227, 0.10375462685312543, 0.12956612610391208], [0.032006561290472746, 0.03015936505315559, 0.07521976623684168, 0.003866093640681356, 0.014164069068751164, 0.05615600597645555, 0.04839615397421377, 0.034031001052686145, 0.0893139767327479, 0.03990854263039572, 0.03696982103532978, 0.03832918791366475, 0.0704077315915908, 0.021857728283586245, 0.016519508391086544, 0.03502658834414823, 0.03268725744315556, 0.06488241414938654, 0.04427627593811069, 0.061372684980077405, 0.054207395895251205, 0.04293355013110808, 0.03896324156916567, 0.05891291411327464, 0.0495108988003007, 0.05298102866592152, 0.02113729712021138, 0.031760517707360644, 0.018414965431605066, 0.05672039104891675, 0.06242102158388921, 0.10051416752061673, 0.03215378303346889, 0.097565410392625, 0.06304697013859238, 0.028495040788714374, 0.04193803069314786, 0.05586469053689923, 0.028797609731554985, 0.030757690447249582, 0.010274951462633908, 0.03668176595653806, 0.07429500443062612, 0.011711712045195912, 0.02340349042788148, 0.07039825924273048, 0.045072814981852255, 0.013927752285131385, 0.04319380223751068, 0.05452941165172628, 0.05534623549985034, 0.00045629295969514975, 0.06023611846779074, 0.008709320116655102, 0.019262823775144558, 0.026512604040492858, 0.03444294984053288, 0.10554114848907505, 0.01574224991989987, 0.02953080753130572, 0.01882760293249573, 0.08012305027140038, 0.048889876409832916, 0.08002732933631965, 0.022152667100142156, 0.026999654780541147, 0.07065273701612439, 0.04779416109834399, 0.0036402237518424435, 0.010334745664814753, 0.055663369196866236, 0.01902514822514994, 0.0135935559769028, 0.04198061555091824, 0.04646978287824562, 0.034121487090098004, 0.05253345339692064, 0.03947426325508526, 0.07678373517202479, 0.06310258965407099, 0.1771935982895749, 0.07503848203590938, 0.10354623517819814, 0.054737796541303396, 0.0840724226353424, 0.025082735677382777, 0.06873777548649482, 0.07569181626396519, 0.04127095952363951, 0.04072337158556495, 0.01683188895029681, 0.02773962775245309, 0.028289841621049812, 0.07086355106106826, 0.023891745567587868, 0.039120790615145645, 0.03435724747500249, 0.0651752155806337, 0.026103466083960872, 0.041380916123411486, 0.0313660411962441, 0.04111019761434623, 0.0408294266089797, 0.010860274429433048, 0.043312654431377134, 0.02909936782504831, 0.05884178328726973, 0.057061551670942984, 0.06144638745380299, 0.034576380359275, 0.11086513780589614, 0.10957866933728967, 0.09791695938578673, 0.04122988779896072, 0.025764578554247106, 0.05511791864410043, 0.01042509260254779, 0.026470460230484605, 0.10972840165985481, 0.006518207556967224, 0.07031659755323615, 0.01813022669271699, 0.026282772355313812, 0.03677875575210367, 0.034963613509067466, 0.04848890292591282, 0.0179326457769743, 0.03408817441335746, 0.029532514046877623, 0.03068003211436527, 0.03102262444528086, 0.021317683958581517, 0.05705739225127867, 0.03584128498498883, 0.01293367812676089, 0.01634375085788114, 0.08325408904680184, 0.024204041309920803, 0.034776873886585236, 0.03511561892394509, 0.046361078175583055, 0.011014305271341332, 0.016312002204358578, 0.04172737949660846, 0.020017176600439206, 0.017670836432703903, 0.042500766925513744, 0.036887087260505984, 0.06681357230991125, 0.025982556232650365, 0.04124131093599966, 0.05895870165633304, 0.04761902442468064, 0.025337512006184885, 0.03917063919029065, 0.07921797276607581, 0.005049048623602305, 0.08908241987228394, 0.04106711403333715, 0.019917525251262953, 0.02677734804871891, 0.017311623386506523, 0.05388289670060788, 0.024239744126264538, 0.08700359213565077, 0.022385438538289497, 0.02378915616178087, 0.05199145319472466, 0.03499807969533971, 0.06171942315995693, 0.007482112352071064, 0.05255788405026708, 0.0723539125174284, 0.041046082840434144, 0.034654598483549695, 0.056980575301817486, 0.003825309869301106, 0.04136362365846123, 0.021613135069076504, 0.018840847936059748, 0.05479173668261085, 0.04611366395173328, 0.059230305653597624, 0.050498296174087694, 0.05089449277147651, 0.0415130913523691, 0.020147346758416722, 0.017676632818100706, 0.03163484623655677, 0.030810246377118995, 0.03352840677169817, 0.05266944199268307, 0.08170627603041274, 0.0580962293648294, 0.028713345860264132, 0.058760243734078746, 0.04636312735133937, 0.06975808180868626, 0.036165797750332525, 0.04266090797526496, 0.04061760493953313, 0.054880679052855284, 0.035863819132958136, 0.027381444383146505, 0.036818450050694604, 0.003482783695549837, 0.0751891303807497, 0.06053081979709012, 0.010078536778954523, 0.026924030356375233, 0.023278029302933385, 0.015641774150675962, 0.04042724194005132, 0.03411743284336158, 0.06160223337688616, 0.024398891122213433, 0.05822619596230132, 0.017674034028979282, 0.054047936773193736, 0.0575749719781535, 0.01224960880686662, 0.037763238817985566, 0.05474674981087446, 0.07316344550677709, 0.017394944094121456, 0.05239795334637165, 0.05239462852478027, 0.05365824393395867, 0.045392248912581375, 0.030020631783242737, 0.029422537091055086, 0.02322563622146845, 0.018612303771078587, 0.05045439835105624, 0.04797818997342672, 0.007795017079583236, 0.05668172812355416, 0.034914993082306216, 0.03743004419707826, 0.06918729815099921, 0.01618198641309781, 0.008960379769892564, 0.0854595857007163, 0.024003866694069335, 0.011508730838873556, 0.07313285036278622, 0.014864128914528658, 0.04701908411724227, 0.040348528485213, 0.04356759021590863, 0.026571673906541297, 0.04492026334628463, 0.00929360746938203, 0.06237784640065261, 0.04239387730402606, 0.0417993008159101, 0.0865709310663598, 0.08997658653450863, 0.06183784787676164, 0.04492372048220464, 0.06637484513755355, 0.05236206902191043, 0.018713819395218576, 0.04500290212620582, 0.028817104042640755, 0.058410072167004855, 0.04005386786801474, 0.05873557220080069, 0.019355872978589365, 0.026360352656670978, 0.03225060319527984, 0.06212797588003533, 0.08864660361515624, 0.012092270954911197, 0.0242567058053932, 0.08192384828414236, 0.013678156571196658, 0.055208160408905575, 0.0612446182806577, 0.047107266528265815, 0.03356397218470063, 0.0300546874558287, 0.040104964947594066, 0.020301861056525792, 0.09072792836065803, 0.06510195415467024, 0.03236145885395152, 0.06020410518561091, 0.03984356950968504, 0.05554709882874574, 0.06365715632481234, 0.019065168220549822, 0.08328345604240894, 0.007130927223313067, 0.11583189879144941, 0.03003643486382706, 0.006178039716490145, 0.03953035095972674, 0.026776445597144108, 0.039995595280613215, 0.037332229981465, 0.03697449953428336, 0.06389963759907655, 0.029570155777037144, 0.022630871439884816, 0.05680833936535886, 0.06930113597107784, 0.023050409641915133, 0.05781690363905259, 0.05534602854666965, 0.019948926155588458, 0.05298888270876237, 0.02288574954893972, 0.020839805315647806, 0.07143028386469398, 0.056190719828009605, 0.02364816845926855, 0.023670809476503303, 0.023807181444551264, 0.006328784328486238, 0.029351670893707445, 0.004180910988777343, 0.033627103082835674, 0.04559210800964918, 0.03770151588001421, 0.013734346904259707, 0.013776045425661972, 0.06407964615417377, 0.018591437122917602, 0.006219598714129201, 0.0592940743746502, 0.04750175661008273, 0.019879121865545, 0.056677212473005056, 0.016324063164315054, 0.04655702551826835, 0.01673947417709444, 0.024754216162753955, 0.009959704092969852, 0.05605719770703997, 0.008117981936915644, 0.01883884286507964, 0.025073963915929198, 0.037186351737805774, 0.01592842805465417, 0.02382038064700152, 0.051870982694838724, 0.013464176312222012, 0.0487603135406971, 0.020451986929401755, 0.04680560003700001, 0.058414170518517494, 0.08414563656385456, 0.18335857747920922, 0.1180554987596614, 0.20316035992332868, 0.13831833217825207, 0.10362912501607623, 0.13003503451389925, 0.20002660022250243, 0.14789088709013803, 0.11250422056764364, 0.11043253101940666, 0.054617526209247966, 0.22996466447200092, 0.1272877547889948, 0.09630211389490537, 0.12381954517747674, 0.2548328371984618, 0.14313111321202346, 0.08185416273772717, 0.191485160695655, 0.14429663281355584, 0.19629681536129542, 0.09389112291059323, 0.13370452475334915, 0.1826095969549247, 0.17212490098817007, 0.18398455317531312, 0.09532578342727252, 0.11776828845696789, 0.16431839631072112, 0.19755034095474652, 0.19137590298695223, 0.14264510571956635, 0.2070969758289201, 0.13453117039586815, 0.11422290227242879, 0.10780972854367324, 0.2489342237157481, 0.16040018227483543, 0.09715985679732901, 0.10881038449172463, 0.07828310757343258, 0.09065449051558971, 0.12024161645344325, 0.130395716588412, 0.1183270484741245, 0.23273525866014616, 0.12864133715629578, 0.1439660234110696, 0.20470011872904642, 0.15922645239957742, 0.14329493870692595, 0.16559063589998654, 0.08663497120141983, 0.12682488534067357, 0.07846635952591896, 0.054777192284486124, 0.21217381555054868, 0.12228742667606898, 0.14698828623763152, 0.1574603207409382, 0.1636831382555621, 0.12193321782563414, 0.20857386157980987, 0.12353274199579443, 0.08735643713069813, 0.12959566951862403, 0.180628043998565, 0.12954007035919599, 0.13606521593672888, 0.22192433662712574, 0.13515690181936535, 0.14441088453999587, 0.12916056572326592, 0.12828399347407476, 0.09684291987546853, 0.252536946109363, 0.17718859070113727, 0.2603152644421373, 0.20672038889357022, 0.3623106399817126, 0.14950896240770817, 0.18939516427261488, 0.17674811290843145, 0.15912651776203088, 0.14989557809063367, 0.16210794635117054, 0.2001976589007037, 0.18114074505865574, 0.19855639125619615, 0.20243938932461397, 0.15203539255474294, 0.12270308365779263, 0.10944438725709915, 0.2197537166731698, 0.16867121202605112, 0.18871158095342772, 0.17879481879728182, 0.09361801935093743, 0.12728839261191233, 0.1648355485605342, 0.13759044052234717, 0.13899598510137626, 0.14286158553191594, 0.16355549224785396, 0.12927124835550785, 0.14334338610725744, 0.18288968263992242, 0.17513067541377886, 0.1448252930172852, 0.19148183587406362, 0.16924110001751355, 0.1920161550598485, 0.09358314943632909, 0.14229590445756912, 0.14767656501914772, 0.1002605582720467, 0.12197534127959184, 0.17679354761328014, 0.06931901536881924, 0.14123881475201674, 0.118085720709392, 0.16867931373417377, 0.13529387089822972, 0.09396211802959442, 0.16749474086931773, 0.15679485430674894, 0.1161864876214947, 0.1428950780204364, 0.18298029420631273, 0.1737089952720063, 0.06664916327489273, 0.11382397796426501, 0.09488499350845814, 0.16581900364586286, 0.12438091076910496, 0.12965156723346027, 0.11437743183757577, 0.17216080906135695, 0.101398712556277, 0.17072363117975847, 0.10045823587902955, 0.08004046577428069, 0.10246175301394292, 0.1524135944034372, 0.07721328176558018, 0.15746576259178774, 0.12959545238741807, 0.14504918243203843, 0.09827238959925515, 0.13281382540506975, 0.15619748564703123, 0.11327834081436906, 0.09825061541050673, 0.14264160447887012, 0.15261509216257504, 0.14907419787985937, 0.14882911103112356, 0.13148080264883383, 0.11666323989629745, 0.11387849146766321, 0.08737523933606488, 0.12057491285460335, 0.08024583118302481, 0.12529155904693262, 0.06755745025085551, 0.07981935835310391, 0.1709965243935585, 0.08562102275235312, 0.13784683176449367, 0.07759897464088031, 0.10895374537046466, 0.15846661531499454, 0.0793300328244056, 0.15202107546584948, 0.10655483909483467], [0.027085547135876756, 0.025229860729138767, 0.042135932216686864, 0.013539676055578249, 0.023914064280688763, 0.031029168915535723, 0.08714719050164733, 0.032856256767575226, 0.059177047439983914, 0.04397526423313788, 0.04474785099072116, 0.01939592690074018, 0.07154047795172248, 0.01629520846264703, 0.012161659642255731, 0.051237152955893955, 0.01719367703688996, 0.05385384522378445, 0.015182745210560305, 0.0366848600762231, 0.04080223431810737, 0.040097348392009735, 0.03059711852776153, 0.01884836101505373, 0.07918739119278533, 0.026998847323868955, 0.07212325810853924, 0.019154220852734785, 0.030247079275016273, 0.03963228049022811, 0.023166020134729997, 0.027381878645558442, 0.019901756097429564, 0.03886951891971486, 0.024656115266095315, 0.0067821691294999, 0.0582729945225375, 0.04141618298100574, 0.030444431185190166, 0.06731425651482173, 0.01708754907096071, 0.00886596501472273, 0.04619624844885298, 0.03168896958231926, 0.016841471561097672, 0.027148445635767918, 0.022424359306959168, 0.03730287655655827, 0.02030513498799077, 0.10528439083801848, 0.05030409266640033, 0.03692247964707868, 0.01711682616067784, 0.06428845173546247, 0.05976594798266888, 0.045439094970268865, 0.06179987705711808, 0.04556224229080336, 0.024321841774508357, 0.04968768431405936, 0.01402305592117565, 0.005544224820498909, 0.029219390491821935, 0.07882451745016233, 0.05912792828998395, 0.0398756167186158, 0.07907593503062214, 0.04789173782670072, 0.043066203727253845, 0.022692027801115598, 0.07631004987550633, 0.06876917130180768, 0.03962414146267942, 0.05723958568913596, 0.04188727966642805, 0.06396099073546273, 0.028187891734497886, 0.07025269312517983, 0.06210738234221935, 0.09136628732085228, 0.09647089948079415, 0.12319101818970271, 0.03188102213399751, 0.02887443346636636, 0.03898813362632479, 0.03444722800382546, 0.04123788772683058, 0.05165731880281653, 0.13458681026739733, 0.029136805994702236, 0.06474458333104849, 0.02271296569545354, 0.03667668033657329, 0.08745030566517796, 0.09429513623139688, 0.08201823250523635, 0.07340387081993477, 0.025655456552548066, 0.009633002204022236, 0.0526976419080581, 0.02528300868081195, 0.04882227396592498, 0.035397088820380826, 0.037011961452662945, 0.06646867974528245, 0.034584499030773125, 0.0649455925449729, 0.02287133746514363, 0.047317524174494405, 0.07137377546834094, 0.017827233665489724, 0.06966090880866561, 0.04332804699827518, 0.039763712723340304, 0.05356737452426127, 0.021381291527567164, 0.010329608306554812, 0.04530657368845173, 0.03459072798224432, 0.026012306600543003, 0.035628554078617265, 0.0470262969444905, 0.052159027595605166, 0.050722039703811915, 0.005439778773247131, 0.03512860947687711, 0.019340244620772343, 0.026715540293870226, 0.03842207596504262, 0.0431412293442658, 0.04225832636335066, 0.04783120911036219, 0.016457059420645237, 0.03753441306097167, 0.04616303415969014, 0.0651224526975836, 0.04287777115990009, 0.023703480937651226, 0.030642142718923942, 0.05704680710498776, 0.013598650926724076, 0.02258715173229575, 0.01970605133101344, 0.02426576255155461, 0.08682511028434549, 0.03313400150675859, 0.003201491490472108, 0.04333489680928843, 0.0043451088297713015, 0.05894308178020375, 0.0527904180011579, 0.038143042009323835, 0.019893963122740388, 0.04120353349883642, 0.02601457799651793, 0.056413991775895865, 0.07819594296493701, 0.027953334052913954, 0.005075184520267482, 0.07150073615568024, 0.0300599596729236, 0.019687216895233308, 0.034652651088046174, 0.026986772793212106, 0.036869394459894726, 0.039031804140125, 0.04638297110795975, 0.08642510032015187, 0.05624648862119232, 0.02153499497632895, 0.035864850506186485, 0.06538085918873549, 0.03079880288402949, 0.010951209148125989, 0.06332225858100823, 0.019310056597792676, 0.047901790323002, 0.054985108984900374, 0.04025087033265403, 0.02484679887337344, 0.03407962487212249, 0.03774407698905893, 0.04709633532911539, 0.05276503061343517, 0.05944599836532559, 0.06986892050398247, 0.06142806700829949, 0.005650197571542646, 0.09462334361991712, 0.014418233019698943, 0.005988740744734449, 0.04724825931979077, 0.0038372567505575716, 0.02288484200835228, 0.04816767427005938, 0.012787903359692012, 0.043564720012779744, 0.015317770286596246, 0.016556939775390283, 0.02921091898211411, 0.1096327757196767, 0.024723624411438192, 0.03950339276343584, 0.025201798217105012, 0.04198328558621662, 0.05745031152452741, 0.0242751314238246, 0.017935381969437003, 0.02552652302464204, 0.018791823780962398, 0.021341907658747265, 0.0386795291144933, 0.01726359498154904, 0.0727796321734786, 0.05610474944114685, 0.02872729654024754, 0.00856254281409617, 0.035455096779125075, 0.07167028170078993, 0.02038032514974475, 0.055510973624352894, 0.022905421975467886, 0.01700442683483873, 0.0602601861049022, 0.06413240903722388, 0.021189936170620576, 0.0023728812770319302, 0.03135115074525986, 0.0334396815326597, 0.02313847839832306, 0.06287355015852622, 0.006830762414860406, 0.027792168415284584, 0.03092017922816532, 0.03153802946742092, 0.03306346439889499, 0.04164355667307973, 0.025508017678345953, 0.007902335874470217, 0.010325599012763371, 0.03164820319839886, 0.017973741250378743, 0.04890572698786855, 0.05080909574670451, 0.041496640270841975, 0.06821111017572028, 0.05916718832616295, 0.047348577329622846, 0.031980726069637706, 0.09954342818153755, 0.008901630511640437, 0.06111444133733, 0.016471971924017583, 0.07771004403808288, 0.048428584555430074, 0.037428429283733876, 0.057434209888534885, 0.14905105983572348, 0.13443871321422712, 0.027386908286384175, 0.0786150401192052, 0.03503673583535211, 0.03572705700727446, 0.021389466178204333, 0.035495561214962175, 0.0499780362338892, 0.07959752489945718, 0.020535256746890287, 0.04581939349217074, 0.049972875975072384, 0.06731097919068166, 0.09361669620765106, 0.07598898067538228, 0.06725662853568792, 0.029902437768344368, 0.055314792187086174, 0.034751859693122764, 0.060051271958010535, 0.029735474048980644, 0.02897816790001733, 0.0852771479902523, 0.07815859639751059, 0.027128271093325954, 0.00786057798125382, 0.07223978292729173, 0.02510678635111877, 0.09495742033634867, 0.021610773767211607, 0.034850260841527154, 0.030967422228838717, 0.08690887543239764, 0.028964247754109756, 0.07108435314148664, 0.02248221798799932, 0.018519570086417452, 0.04110157343425921, 0.02238461920725448, 0.031082165893167257, 0.035914315709045956, 0.04542087630501815, 0.01995569114972438, 0.01778140541033021, 0.02452214531201337, 0.02747009159065783, 0.050428709015250206, 0.03137404112411397, 0.09583192305373293, 0.026298678912488476, 0.027712713660938398, 0.02370896519693945, 0.13581407655562672, 0.08037976721035582, 0.038054666215819974, 0.029259617440402508, 0.05654597362237317, 0.05123066616111568, 0.0537784633758877, 0.034634042265159745, 0.026802492860172476, 0.039003156391637664, 0.0581493450860892, 0.011200789595022798, 0.032335627025791576, 0.04783404877941523, 0.0351783121669931, 0.08298716015581574, 0.038514312622802596, 0.04859944645847593, 0.03292874127094235, 0.04901302033769233, 0.04154972545802593, 0.05467171062316213, 0.06641996771629367, 0.052796806408358474, 0.09221662740622248, 0.027320557739585638, 0.011354415860426213, 0.0349907074123621, 0.013651407872592764, 0.020432774210348725, 0.021347665028380494, 0.0481776046300573, 0.019664767564141324, 0.03371084448216217, 0.01430838498552995, 0.03824208776599594, 0.027910722053742835, 0.05291093260582004, 0.032080345188400576, 0.028479302168956826, 0.0567404451513929, 0.0234225063717791, 0.10017428254442555, 0.11613624888871397, 0.2542848251760006, 0.09168840146490506, 0.12162590931568827, 0.12826514377125672, 0.27499306255153244, 0.11470600563500609, 0.15168102085590363, 0.12712401071829454, 0.16755612114710466, 0.1382446297045265, 0.20730162199054444, 0.18612671537058695, 0.06477298680692911, 0.1719645360218627, 0.10902027572904315, 0.09412452538630792, 0.09234038540827376, 0.11986596589641911, 0.11345205934984343, 0.13307082732873304, 0.13412216305732727, 0.05533701081627181, 0.3330858110317162, 0.076412026903459, 0.13192210825426237, 0.10613745863416366, 0.12994683853217534, 0.21732491414461816, 0.07640251384249755, 0.12278423644602299, 0.07611987008047955, 0.13125601756785596, 0.09635439501809222, 0.0958291749869074, 0.11809446024043219, 0.18871250376105309, 0.09249161729323012, 0.08300818117069346, 0.07947568036615849, 0.09880492423794099, 0.10720708766686064, 0.07680613361299038, 0.10551986963089023, 0.13084794660764082, 0.09589582069643907, 0.1260769904724189, 0.16047083134097712, 0.2033147673521723, 0.16444825434259006, 0.15279372329158442, 0.13846178805189474, 0.0808795014662402, 0.12569323820727213, 0.0601506909089429, 0.15186436101794243, 0.09609512000211648, 0.11522858616496835, 0.19821191259792872, 0.10838167928159237, 0.1233074955110039, 0.16738266045493738, 0.11770502185182911, 0.18401337734290532, 0.141434178554586, 0.09624060469546489, 0.1786237329776798, 0.15870657243898936, 0.1671357008495501, 0.19191392697393894, 0.2548369626913752, 0.1005419942417315, 0.19853405388338224, 0.14496321204517568, 0.15065856357770308, 0.12873869336077146, 0.19374974417899335, 0.30090927332639694, 0.21279257163405418, 0.14956851064094476, 0.3960423528083733, 0.14690076879092626, 0.201957534466471, 0.25543187505432535, 0.1733153499662876, 0.13434914659176553, 0.13476591637091978, 0.25211139608706745, 0.09431216067501477, 0.16879953656877789, 0.07761575481189148, 0.1636369028793914, 0.21704146292592796, 0.17478424257465772, 0.1722192580678633, 0.30034158378839493, 0.17610340964581284, 0.15948342718183994, 0.13140843010374478, 0.11679273151925632, 0.10221745326582875, 0.08094038641346352, 0.16388292610645294, 0.25781551429203575, 0.32974568169031826, 0.18052023835480213, 0.12438004224428109, 0.10248132874923092, 0.15632006978350027, 0.1469405445137194, 0.1832912668053593, 0.08219267707318068, 0.1325593204902751, 0.28749458172491615, 0.13838841127497808, 0.12242685205170087, 0.16232661104628018, 0.2211609711604459, 0.11787966319492885, 0.10193168824272496, 0.1213548481464386, 0.16549238402928623, 0.21671886023666176, 0.14479067416063376, 0.13904876155512674, 0.07113404226090227, 0.1139015480875969, 0.06916732886540038, 0.11244242638349533, 0.19535795359739236, 0.22847487298505648, 0.12545481457241944, 0.11006996940289225, 0.26535943948796814, 0.22474408389202186, 0.14343980593340738, 0.07091422405626092, 0.11867565262530531, 0.23570697062781878, 0.10023325402289629, 0.1755561711532729, 0.05815716180950403, 0.10868524906358548, 0.22596261064921105, 0.179388021251985, 0.20432127905743463, 0.12995629731033528, 0.10314634735030787, 0.1322919369808265, 0.1084339264780283, 0.14604897664061614, 0.1545195635408163, 0.07004854907946927, 0.13712694682180882, 0.14721000434032508, 0.21944433184606688, 0.09706409515014716, 0.2956107019313744, 0.11966996427093234, 0.11582298284130436, 0.142582327659641, 0.12827640745256627, 0.13463702185877732, 0.11690903242145266, 0.12864395630146774, 0.15738155639597348, 0.19823334073381765, 0.18982626471136296, 0.20488710940948554, 0.17093814324055398, 0.11213477860604014, 0.11408537679484912, 0.11587499933583395, 0.15452347190252372, 0.08711584896913596], [0.055703311160738976, 0.03071803686075977, 0.03560289188421198, 0.0348061085678637, 0.027759335802069733, 0.02225295966491103, 0.021279982856607864, 0.07666357340557234, 0.0319743003430111, 0.050692665922854624, 0.024245264008641243, 0.05061218488429274, 0.02882406920460718, 0.024383145717105696, 0.027042836749127934, 0.04294869503272431, 0.01813966341848884, 0.037666574719228914, 0.029478950492505516, 0.041742700817329545, 0.02894906892574259, 0.032116144695984464, 0.022706451759274517, 0.024082132315795337, 0.04201757874605911, 0.09902875936989274, 0.03273938250328813, 0.05566577799618244, 0.02078145300038159, 0.020928287978417108, 0.024340096062847545, 0.02714427264540323, 0.025491709089172736, 0.0035192102118993974, 0.027134240505152514, 0.021169812518305013, 0.016117023470412408, 0.01963273053323584, 0.04442004054518683, 0.03425885311194828, 0.04814169655687042, 0.04669779100056205, 0.054365531874022315, 0.038217497656920126, 0.043340345445488176, 0.022924990925405706, 0.0277334971885596, 0.0427734938982342, 0.028962595521339347, 0.008629807686832334, 0.04113002780026623, 0.038933246928666315, 0.046189700585923026, 0.05729956139943429, 0.08681831136345863, 0.05306008817361934, 0.069151960047228, 0.0522271864382284, 0.054680585861206055, 0.052821016537823846, 0.021544674278369973, 0.051507443987897465, 0.026857454196683, 0.0370401477973376, 0.007221677889382201, 0.012085203164523202, 0.060499973595142365, 0.014660636262435998, 0.02108571319175618, 0.010466216065521752, 0.01233239601632314, 0.03722044133714267, 0.04680033799793039, 0.036573532835713456, 0.07984852178820542, 0.029226589748369794, 0.09103991876223258, 0.06057478886629854, 0.07146157789975405, 0.02729676490915673, 0.025042071073715175, 0.024813252102051462, 0.038267485331743956, 0.12153362855315208, 0.050128989919487915, 0.01607650305543627, 0.06192617956548929, 0.012186155604597713, 0.09696651502911534, 0.02646878594532609, 0.058361679049474854, 0.044619366992264986, 0.02330404772822346, 0.015451563821573342, 0.03260887986315148, 0.014892291510477662, 0.004820633804359074, 0.12842480306114468, 0.031101002025284936, 0.041164354886859655, 0.024387196571167027, 0.014539317593776753, 0.017477017993639623, 0.03704295014696462, 0.040172102595014234, 0.05859018250235489, 0.08083797512309891, 0.012606664959873472, 0.02224855257996491, 0.03528571408241987, 0.033953491997505934, 0.03629915363022259, 0.0210815622537796, 0.0736519160813519, 0.060778749707554064, 0.1126505330737148, 0.03233765584549733, 0.029527594667992423, 0.029718259615557532, 0.00830557312084628, 0.010505000279018921, 0.025850350469616905, 0.014270531213177102, 0.021676474616729786, 0.04490568162873387, 0.005888747159458164, 0.016632937393816452, 0.03609288237722857, 0.039743421133607626, 0.0388148256045367, 0.03344840070764933, 0.018783723769177283, 0.07945514789649419, 0.016480211035481522, 0.05259491509890982, 0.017415744585118124, 0.04494634283972638, 0.038514370298279185, 0.014814550057053566, 0.026441211978505765, 0.06157052543546472, 0.07526283963982548, 0.04889591537149889, 0.03903175664267369, 0.026989849949521676, 0.1248653983431203, 0.04195615775617106, 0.02942379916618977, 0.039211188443005085, 0.03175819372492177, 0.006894041318446398, 0.06002535870564835, 0.022567589567708116, 0.02680771079446588, 0.057945241752479754, 0.009167999611236155, 0.04105806916153856, 0.012572940921277871, 0.059349198559565206, 0.07382247264363936, 0.018827574094757438, 0.014444446523806878, 0.009592938952014914, 0.022785689382414733, 0.02967507764697075, 0.04596274080021041, 0.04151631439370768, 0.025640332006982396, 0.07018651560481105, 0.019708806183189154, 0.0454957051468747, 0.03348574388240065, 0.05783322240625109, 0.02039632330914693, 0.03385940972449524, 0.0043472440946581105, 0.08181130646594933, 0.03021143243781158, 0.03814991556906274, 0.05851368446435247, 0.0027631674103239284, 0.04474025818386248, 0.01713933825625905, 0.055526579929781814, 0.08087968467069523, 0.019525479591850723, 0.03380335594660469, 0.04167425020464829, 0.06113721975790603, 0.052107224839606454, 0.054368222265371254, 0.02434824526842151, 0.06098933305059161, 0.036377996006714444, 0.057151369351361475, 0.0203008025418967, 0.007675594068132341, 0.014380408085084386, 0.0332934402727655, 0.009625977670241679, 0.028783648873546293, 0.047437848789351325, 0.033406484206872325, 0.022380142572468946, 0.02458786651758211, 0.05249569631580796, 0.032744498657328744, 0.03285823808982968, 0.01350662122214479, 0.027549790617610728, 0.03499666155715074, 0.01634310624961342, 0.021751222034384097, 0.03857965554509844, 0.02102272478597505, 0.011567910966862525, 0.025275602471083403, 0.02875562198460102, 0.016677832663325325, 0.03891496719526393, 0.01745788500245128, 0.024997722024896314, 0.02650073985569179, 0.011767780241955603, 0.013978728924744895, 0.03110370598733425, 0.0715706931161029, 0.03869526094890066, 0.028311573401359574, 0.01439965981990099, 0.027316788477557044, 0.05212325183674693, 0.057994035205670764, 0.022371559104483043, 0.030894031881221702, 0.008013400182660137, 0.0224939006646829, 0.02454629776600216, 0.023471479636750052, 0.015352864117760743, 0.028208938194438815, 0.07116473918514592, 0.0510092601845307, 0.026179557000952106, 0.009221595396021647, 0.013758506143598683, 0.055325638569359264, 0.036947049400103946, 0.008796147153978901, 0.06166531677756991, 0.041283821154917986, 0.01655987274300839, 0.06473971823496477, 0.04055554951940264, 0.06258364607180868, 0.044161362640027485, 0.048455447756818364, 0.02518541498907975, 0.0022121626243460923, 0.03843226756102272, 0.042925970894949775, 0.01607349544896611, 0.07008715093668018, 0.06825367467744009, 0.03835809689813426, 0.022539659370003, 0.06315221770533494, 0.020969570048951676, 0.06287895129727465, 0.0771054829071675, 0.025990001458142484, 0.030519792677036355, 0.024623777983444076, 0.15288475554968628, 0.05130699795803853, 0.015573381213471293, 0.0256105578903641, 0.019189669218446528, 0.0384767591021955, 0.02508945995941758, 0.04445751942694187, 0.04223194831450071, 0.023607553049389805, 0.01810673072135874, 0.018972643185406923, 0.03286521003714629, 0.012419418132464801, 0.020182776464415447, 0.04720672958397439, 0.042839447502046824, 0.0014214895158407412, 0.03092345655230539, 0.018404809458713447, 0.018391891848295927, 0.009671861904540231, 0.01626699836924672, 0.07962506663586412, 0.033484715901847394, 0.02367697057447263, 0.015503989133451666, 0.0184583492643599, 0.06745377010000603, 0.05193003220483661, 0.051585960667580366, 0.052547264977225235, 0.03395324433222413, 0.013882838355909501, 0.017407753138935993, 0.06768148645226445, 0.011040981875599494, 0.08473141584545374, 0.043074773624539375, 0.02873286392007555, 0.033176905275987725, 0.01764343209963824, 0.06329257267394237, 0.056990746541747024, 0.051435210542487245, 0.02791737678593823, 0.05387730896472931, 0.033267937534089596, 0.09639759055737938, 0.010897738044150174, 0.03176157282931464, 0.01693452415721757, 0.03146307509658592, 0.05403604544699192, 0.042428893103663406, 0.010380774935973542, 0.0386755630773093, 0.04436807154810854, 0.02100741533961679, 0.09725275502673217, 0.045195857129458866, 0.042992928730590005, 0.018417594754802327, 0.04172859746696694, 0.033685904927551746, 0.02799669752961823, 0.1555101703852415, 0.04341937102643507, 0.07172788932387318, 0.028115615880649005, 0.023647171012791138, 0.023668741641033973, 0.04264953572835241, 0.027140650964741195, 0.009686983057430812, 0.06829068876270737, 0.038393499462732246, 0.02632210194133222, 0.022577645456684486, 0.18068911215024336, 0.13313614310962812, 0.07512957536216293, 0.13223894339587006, 0.10604557820728847, 0.1011127100459167, 0.1358766374843461, 0.18230584396847657, 0.14041956514120102, 0.11023201035069567, 0.09231770198260035, 0.1036969581618905, 0.21420068107545376, 0.17129928671887942, 0.14723264026854718, 0.1285856972847666, 0.10813457718385117, 0.19346167892217636, 0.08570671493985824, 0.12956011428364686, 0.12403351441025734, 0.13233123772910663, 0.11605447184826646, 0.09230930171906948, 0.11527913702385766, 0.1684089989534446, 0.1810193280024188, 0.11598916963807174, 0.1277968596134867, 0.11715669770325933, 0.08339677139052323, 0.07254422123410872, 0.1196994941149439, 0.10607603764427559, 0.09337521916521446, 0.07733849183257137, 0.06368377525359392, 0.11417361348867416, 0.2844907614801611, 0.12185198361320154, 0.14886090718209743, 0.11695400572248868, 0.14193210112197058, 0.08611169856573854, 0.1549560244062117, 0.08935005443968944, 0.13852740238819802, 0.13503161711352213, 0.09908755442925862, 0.0953201719426683, 0.22323613480797835, 0.08012777287513018, 0.1391073734100376, 0.07899852097034454, 0.2380420538995947, 0.12997138792915003, 0.1852775016533477, 0.12207294175667421, 0.14363098996026175, 0.1844522673636675, 0.14547999788607868, 0.18646488365318092, 0.12151381533060755, 0.24091231131127902, 0.10013743809291295, 0.09051768428512982, 0.17670062902782643, 0.03630310270403113, 0.07826391181775502, 0.17167826209749493, 0.09535815633301224, 0.15171008929610252, 0.1525962288890566, 0.14473933620112284, 0.15718297633741582, 0.1678459777363709, 0.13945681894464151, 0.18641073655869278, 0.1501640472561121, 0.35732585032071384, 0.16136724395411356, 0.16614995231585844, 0.19762545478131088, 0.20296171201126917, 0.12895773803549154, 0.12247581513864653, 0.17280241820429051, 0.15807249503476278, 0.15688385095979485, 0.1370077282190323, 0.179256086902959, 0.1544682662934065, 0.16281290352344513, 0.1411809492856264, 0.1237710706357445, 0.16760984754988126, 0.18229968287050724, 0.2963419184088707, 0.1060609741668616, 0.07908698836607592, 0.10736110154539347, 0.09316835419407912, 0.1235822071986539, 0.06941721974206821, 0.15097214175122126, 0.19098064276788915, 0.2061131950467825, 0.13632763256984098, 0.15359896793961525, 0.10453818552196026, 0.15793556666799954, 0.11805116970624242, 0.0923187740679298, 0.20835940380181583, 0.07814102912587778, 0.20507692279560225, 0.17746305811618054, 0.10767700709402561, 0.12751000214900288, 0.10899747016706637, 0.12634494395128318, 0.1356840149632522, 0.1221970593822854, 0.10272383037954569, 0.09860746376216412, 0.13971209738935741, 0.09031434091074125, 0.14592762743788107, 0.09076984146875994, 0.18327362489487442, 0.19288971461355686, 0.10824210462825638, 0.14392385924501078, 0.11656008900276252, 0.12514180636831693, 0.11440992009426866, 0.0664020883185523, 0.12123583310416766, 0.13930925114878587, 0.2091594644423042, 0.21200220047363214, 0.21705978337143148, 0.150326759953584, 0.20468016979949816, 0.08181003082011427, 0.23136326085243905, 0.1878319281552519, 0.1377298523272787, 0.1257622316479683, 0.05635410427514996, 0.18110615334340505, 0.1613037602177688, 0.09251972899905272, 0.2019937682364668, 0.14852774648794106, 0.08543602696486882, 0.14815814846328326, 0.1293750913547618, 0.2293700778058597, 0.11290434588279043, 0.11213142664304801, 0.049370360627238236, 0.13202710476304802, 0.236311708177839, 0.11721597452248846, 0.15640675941748278, 0.1086679667766605, 0.15319765518818582, 0.14318758089627537, 0.1654331072100571, 0.10903377179056406, 0.11002093167709452, 0.10938621644995042, 0.11073895743382828, 0.09968052618205547, 0.06272664732698884], [0.01445887896365353, 0.019982844424833144, 0.010961370210030248, 0.02589891491723912, 0.03286327621234315, 0.005779001753710742, 0.052542220069361587, 0.015456201608425804, 0.04191377306623118, 0.04838399801935468, 0.08718652517667838, 0.05120713117399386, 0.030186730370457684, 0.06377376935311727, 0.023424170478912335, 0.015769462566822767, 0.04824293737432786, 0.02195987494529358, 0.01360670174472034, 0.0168160061418478, 0.01782955595159105, 0.03718193447483437, 0.04909356922975608, 0.03957596547635538, 0.0504631005626704, 0.05750697598393474, 0.005304983975033143, 0.03366693987378052, 0.034872954445225854, 0.04621815834460514, 0.0735479441604444, 0.0811149056202599, 0.007413757582461196, 0.06261551007628441, 0.04283258751300829, 0.036704571518514834, 0.048137045199317594, 0.05801152105310133, 0.022782429021650126, 0.037620722715343745, 0.04057133563661149, 0.04411670146510005, 0.01926094084046781, 0.0595886196408953, 0.019257680479703203, 0.030769171259765114, 0.009963263009142662, 0.0703152676245996, 0.014554895061467375, 0.023271250738097087, 0.024383922639702047, 0.056241118016519716, 0.01584678502487285, 0.05328783505995359, 0.06137583338256393, 0.03647210881380098, 0.046737695645008764, 0.008308416182574416, 0.018272415402212312, 0.027849489357322454, 0.032768423802086284, 0.04952391649463347, 0.03402432766077774, 0.048426399672670026, 0.01866167058636035, 0.03970576922542282, 0.04883084386321051, 0.005135748435610107, 0.019348227585266744, 0.01977119578181633, 0.030673392649207796, 0.03338782449385949, 0.043400283836360486, 0.025501651323533485, 0.03594614578677075, 0.08092208632401057, 0.04854949610307813, 0.04419134031715138, 0.05841212134276118, 0.029277649508523088, 0.05244801226737244, 0.04207978005121861, 0.05495503292019878, 0.0510983721885298, 0.07591996009328536, 0.046487278903701475, 0.049421454314142466, 0.1553696593535798, 0.040127936750650406, 0.027170146882001842, 0.06930052528956107, 0.04343515375096883, 0.014019703110014754, 0.13778629287012986, 0.050687305496207306, 0.024064444604196718, 0.06760401810918536, 0.03377680826400008, 0.01390816382731178, 0.003519049483916855, 0.05808062305940049, 0.0335628797433206, 0.027992259910596267, 0.03609121657375779, 0.04901789900447641, 0.05032230793897595, 0.06356912997684308, 0.021828049161870564, 0.0442559911337282, 0.015252488432452083, 0.017966014432853887, 0.024866281310096383, 0.05037581381787147, 0.008178860946957554, 0.04877367728788938, 0.021038644913850085, 0.0393944743222424, 0.05726429793451514, 0.02572590884353433, 0.03582405698086534, 0.009287033313220101, 0.03330003563314676, 0.008252550698151546, 0.037539461361510415, 0.03763048004891191, 0.0340011014070894, 0.028100513387471437, 0.02035988088963287, 0.048679958031113656, 0.05398270580917597, 0.020271435546289598, 0.017418124546696032, 0.05456954699807933, 0.0219996744168124, 0.057998418541891236, 0.007791156215327126, 0.05272238129483802, 0.04006049715514694, 0.03766815909849746, 0.05557073559612036, 0.04245032123955233, 0.051794060572449646, 0.009931273475688483, 0.02840193560613053, 0.039320927911571095, 0.02015088701487652, 0.05406526655757001, 0.06298873147794179, 0.058517396050904474, 0.02803865134982126, 0.015721546120143363, 0.042747634928673506, 0.03051623036818845, 0.03432383641068425, 0.05607032396697572, 0.0213280825077423, 0.019184839745451297, 0.005420570719122354, 0.053809485996940305, 0.01438974981595363, 0.0589553564786911, 0.02040098145204995, 0.15720797356750282, 0.013988552415477378, 0.04691149899736047, 0.00904918897763959, 0.019314555284966315, 0.0358914015814662, 0.020928593319175497, 0.06149288745863097, 0.01645819766313902, 0.03531897926170911, 0.10903839939939124, 0.056910642090120485, 0.03058770385437778, 0.014157772263778108, 0.07388404291123152, 0.015688294511554495, 0.03581449642245259, 0.027456127339974046, 0.07940355209367615, 0.03437738300168088, 0.010696486253956599, 0.022708835113527517, 0.02866572966533048, 0.03092623854588185, 0.038931045082530806, 0.03440165759197303, 0.07081780423011098, 0.025305044105542556, 0.05690655391663313, 0.034343381611896415, 0.012270375371112354, 0.06273533257522754, 0.07014868049217121, 0.03599990611629827, 0.03919064240264041, 0.02320560926039304, 0.03530355616073523, 0.01765416482729571, 0.011327703633079571, 0.03040629412446703, 0.00876173100966428, 0.05411558671455298, 0.02899293282202312, 0.07577095380319016, 0.0570865963984813, 0.124391428061894, 0.015055804879271557, 0.005465032150303679, 0.03324673670743193, 0.022999029273965528, 0.01217201493480908, 0.012206222429605467, 0.015218025638854929, 0.02096037589944899, 0.031116737252367393, 0.06294879969209433, 0.041558261428560526, 0.04004089767113328, 0.046900323525603325, 0.011563555620211576, 0.018485115774508034, 0.049217347587857924, 0.036886564788541625, 0.027551106975546906, 0.06803515247468438, 0.03538928906034146, 0.059399518716548166, 0.022754963620432785, 0.06719336871589933, 0.00548258500306734, 0.02852918467085276, 0.037727005047989745, 0.03703907910468323, 0.018280447560495565, 0.0548403605020472, 0.01939507364295423, 0.05015402786167605, 0.05131214464615498, 0.025609036275584782, 0.024887236167809794, 0.06930710029389177, 0.03105599819017308, 0.032464986334421804, 0.02002391106049929, 0.04040517598124487, 0.023432202637195587, 0.08655684467937265, 0.016535789838859012, 0.01632637357605355, 0.06324729403214795, 0.06042116175272635, 0.039719940429287295, 0.07373279067022459, 0.07789752326373543, 0.04802716323839767, 0.09422625135630369, 0.011873410332814922, 0.0449524564402444, 0.03621747837002788, 0.07506516203284264, 0.033760472533426115, 0.018519271531009247, 0.010747776716016233, 0.00717162320922528, 0.0478102695196867, 0.026424950886783854, 0.017367122462019324, 0.1340378075838089, 0.03562000793005739, 0.07522338282849107, 0.04632579774728843, 0.05564482483480658, 0.055783809162676334, 0.03097085900870817, 0.08440550190529653, 0.012868486178506697, 0.06958375259169511, 0.005638640847921903, 0.08263278845697641, 0.013186046504415572, 0.018698895017483404, 0.00877477414906025, 0.08786311958517347, 0.03531328296022756, 0.05253645930705326, 0.01600395578757993, 0.03425646127600755, 0.030218261892774274, 0.04537968244403601, 0.04489528986492327, 0.08023893048188516, 0.0834593391045928, 0.021557227176214968, 0.013375086360611022, 0.03129605030907052, 0.04303064849227667, 0.02785681244651122, 0.04053676767008645, 0.021648697089403868, 0.07053104854587998, 0.019671293374683176, 0.024859813175031116, 0.11835585907101631, 0.02427738924909915, 0.03657677962577768, 0.026326332607173493, 0.03578766036246504, 0.0294083726725408, 0.034228926324950795, 0.0077918118497888956, 0.041031490944858105, 0.08740155292408806, 0.007600794912182859, 0.018394141191882745, 0.050301609228232076, 0.02999903740627425, 0.028699727662439858, 0.047959041715200455, 0.021059087477624416, 0.041907751067940674, 0.03139266351770077, 0.030157566935356175, 0.01749080921789365, 0.018543249262230735, 0.024199386559692875, 0.05319856360022511, 0.05200050485187343, 0.08482826314866543, 0.07496292716158287, 0.03533485358847039, 0.03708356725318091, 0.04915854574314185, 0.046595617197453976, 0.030200976213174205, 0.04413127978997571, 0.03182294632175139, 0.06889116511281047, 0.019684236430163895, 0.03546008401151214, 0.06829150979007993, 0.044020519126206636, 0.025514882756397128, 0.029835988833968128, 0.08629311847367457, 0.016812202953068272, 0.012662645795249512, 0.08495915255376271, 0.04199954328526344, 0.04600225867969649, 0.011624222588060158, 0.09441472802843366, 0.06502108635114771, 0.09724226487534386, 0.1474589045558657, 0.1445116334195648, 0.061095455927508216, 0.1410615678344454, 0.07184839714318514, 0.10936863560761724, 0.10236734165144817, 0.12932278987552437, 0.15814566825117382, 0.13009087794593402, 0.09682719821908645, 0.07975809342627015, 0.1036392826853054, 0.11853507374014173, 0.1881366039493254, 0.16248082848531858, 0.0864284997805953, 0.10437494356717382, 0.068797418714634, 0.13867309742740222, 0.06760771612503699, 0.10294374357908964, 0.17551815962152822, 0.08786573873034545, 0.10163950427834477, 0.15746421553194523, 0.16116999382419245, 0.18194665467100485, 0.3654816783964634, 0.12381788955203124, 0.15630978319261754, 0.12094023610864367, 0.10892898562763419, 0.17667105847171374, 0.10883008236331598, 0.13833220143403324, 0.1111109506871019, 0.0808989822066256, 0.14289761574140616, 0.09370265980916363, 0.1303816573428256, 0.13942302790071281, 0.14454718865454197, 0.11493798318718161, 0.1916150458689247, 0.08274977467954159, 0.06927630837474551, 0.11541458618428026, 0.15011603411819252, 0.1471179271382945, 0.09375948711697545, 0.09285656056766, 0.08005529854978834, 0.11852501785116536, 0.14465598495943205, 0.14031222090125084, 0.1405482425221375, 0.07603544675345932, 0.18845005998654024, 0.12714490959686892, 0.14036533662251063, 0.12284903654030391, 0.1665833190615688, 0.16288607673985617, 0.1298328446490424, 0.12899098625140532, 0.13670578013573373, 0.20355317741632462, 0.1348062620631286, 0.13736161137265818, 0.14638562500476837, 0.10654604528099298, 0.19042393192648888, 0.11593836093587534, 0.18063952481108053, 0.2433439094041075, 0.13640722472752842, 0.12006284961743013, 0.2370107892368521, 0.14772421174815722, 0.11866706237196922, 0.16933230869472027, 0.16996908666832106, 0.18053117633930274, 0.2389365259025778, 0.20004219295723097, 0.06453427140201841, 0.1421743245529277, 0.18696454327021325, 0.11324149636285645, 0.18901267408260278, 0.10627151001244783, 0.17852753028273582, 0.10552311981362955, 0.20093528074877604, 0.11939804814755917, 0.15731218297566685, 0.1377248718802418, 0.07896801403590611, 0.2689404216195856, 0.10657748859375715, 0.1724940783211163, 0.14876507089606353, 0.1698520936604057, 0.12053794626678739, 0.17130132232393536, 0.15511952420430525, 0.1457128303923777, 0.09483347912984234, 0.1759785727730819, 0.12738025268273695, 0.11599731205829553, 0.08514142063047205, 0.1688566149345466, 0.17536970973014832, 0.08753759919532708, 0.12315664360565798, 0.10752346819000584, 0.10737998517496244, 0.10020572585718972, 0.10734770726412535, 0.10789613319294793, 0.11808886911187853, 0.14359156707567827, 0.13192057476512023, 0.22628051787614822, 0.09105982019432954, 0.08484810351261071, 0.17892884303416523, 0.12530707035745892, 0.12697480086769375, 0.30560777549232754, 0.0726843997836113, 0.12872326347444737, 0.14762642128126963, 0.12350110869322505, 0.1363568367170436, 0.08513589735542025, 0.20338779129087925, 0.10798586944916419, 0.1173140499740839, 0.11955074566815581, 0.11038262476878506, 0.21226445425833973, 0.1239552114691053, 0.13183438724705152, 0.08613712327288729, 0.050637484062463045, 0.17223742923566274, 0.07376208981232983, 0.14216869271227292, 0.1430466491729021, 0.11776946910790034, 0.12214798772973673, 0.1651299784758261, 0.11834416112729482, 0.11472744734159537, 0.18588769462491783, 0.12127407533781868, 0.1720460687897035, 0.1560906163815941, 0.0971076503129942, 0.18502039116408142, 0.10678007879427501, 0.13061451699052537, 0.08624829445034266, 0.18870624766818114, 0.1296038662216493, 0.08402922031070505, 0.1995663499193532, 0.17832877380507334, 0.2188751766724246, 0.099893620104662], [0.0318905657290348, 0.024961847878460373, 0.030335818084755113, 0.03242087477285947, 0.051522147841751575, 0.08911781904420682, 0.06296334748289414, 0.03955051362780588, 0.028433110897562335, 0.033729134393589835, 0.07573914408151593, 0.04113650780969432, 0.019506628192695122, 0.050671923107334545, 0.015598454778747899, 0.017320059273125868, 0.022812993631565144, 0.01587424533707755, 0.03781946222963078, 0.09603970404714346, 0.046248136021729024, 0.03740320474441562, 0.020148983724149208, 0.022284379228949547, 0.010433811777537423, 0.015095638277541314, 0.06337219875838075, 0.03326737435002412, 0.009772256249561906, 0.035354656632989645, 0.02403897070325911, 0.008139295570020164, 0.016850423134331192, 0.026810394400464635, 0.06196305115840264, 0.03426840349233576, 0.02415344973893038, 0.03694755830136793, 0.010794400553485113, 0.054840964398213794, 0.030436529644898007, 0.06092559825628996, 0.011020793762457157, 0.01491760425934834, 0.01604321752009647, 0.029410859503384148, 0.013208271070782627, 0.029497186121131693, 0.01720885925793222, 0.02570719993673265, 0.03780792034896357, 0.019452864470492517, 0.03156184943925057, 0.06629599258303642, 0.0538384560495615, 0.03130446753597685, 0.035096921891506226, 0.0019500500597392342, 0.022484730263905864, 0.034356772500489435, 0.032652119507214854, 0.012018911141370024, 0.021266342606395483, 0.043538555702460666, 0.013747592755992497, 0.014540957952184337, 0.03229592254917536, 0.018344913476279805, 0.07530930571790252, 0.013168450395044471, 0.050472410063126256, 0.05747279817504542, 0.04624183921675597, 0.0685125222163541, 0.029077658097126653, 0.01320604293141514, 0.07022925652563572, 0.07899871774549995, 0.09351026798997607, 0.05022652593574353, 0.045613614177065234, 0.0190587272268853, 0.013863913166070623, 0.04559720041496413, 0.014419995514409882, 0.03749333794361778, 0.029940452692764144, 0.04136733863768833, 0.03508756828627416, 0.026588564339493, 0.045212260713534694, 0.04238655591117484, 0.04704731456669314, 0.09765062082026686, 0.05753909783171756, 0.03648458368011883, 0.04021695715242198, 0.062038992797689776, 0.027692735893651843, 0.038777414576283524, 0.024544918643576757, 0.023156539304181933, 0.013210000486911407, 0.05006475979462266, 0.042712181473949125, 0.06052121174122606, 0.055032738750534396, 0.042388913820364645, 0.03182532458699175, 0.06891912754092898, 0.03316247283614107, 0.050484213179775646, 0.02306933737626033, 0.06355402578732797, 0.04500052386096545, 0.024572024421234216, 0.04228446692494409, 0.060724745105419836, 0.03441084834880062, 0.05070807206045304, 0.029109196404793432, 0.03568612438227449, 0.0758662201198084, 0.07416140088545424, 0.004391384918043124, 0.04779764537566474, 0.017845873022451997, 0.061672115698456764, 0.11713111693305628, 0.03360224495242749, 0.008243460025239204, 0.03258025925606489, 0.0471571286741112, 0.014032646165495473, 0.02735701033712498, 0.03946128627285361, 0.07523858879825898, 0.03645339821066175, 0.037941686742539914, 0.0369298485373812, 0.03371632704511285, 0.0775762912152069, 0.018812644628009627, 0.04310614908380168, 0.010112734943894404, 0.03149160410144499, 0.033213909183229716, 0.05994938313961029, 0.02053760108537972, 0.05916168540716171, 0.034711154377354045, 0.03163722110912204, 0.025673973773206984, 0.033423657928194316, 0.01020716072525829, 0.04742053257567542, 0.03459905021424804, 0.023704705693359886, 0.05380941814343844, 0.03748135840786355, 0.028621071883078133, 0.01177214237395674, 0.04033182295305388, 0.04779630187632782, 0.012319218866260988, 0.026649620616808534, 0.034479495736637285, 0.062361473350652626, 0.03782049360285912, 0.008938506345397659, 0.05756931299609797, 0.032800172455608845, 0.051740184891968966, 0.016133622133306096, 0.005887172534130514, 0.028958554845303297, 0.020695916875930767, 0.006162666657473892, 0.007929909841290541, 0.06470404764903442, 0.0333324492509876, 0.07795395702123642, 0.014872608905924218, 0.022252281129892384, 0.021978388773277402, 0.026542822597548366, 0.05981702809887273, 0.041456711877669604, 0.03912607301026583, 0.04064322642183729, 0.03291699582976954, 0.040464764926582575, 0.019562680274248123, 0.0235762030351907, 0.03633207275665232, 0.037730781095368524, 0.03918318869546056, 0.025705184687727263, 0.014662529375138027, 0.0936236579769424, 0.008207166035260473, 0.03148226745958839, 0.0216155218160046, 0.01034526210943503, 0.032595020785395584, 0.056202275279377184, 0.03122751827218703, 0.005036497846179242, 0.03329538766826902, 0.03168066092101591, 0.11646379131291594, 0.04453653482986348, 0.05015469961134451, 0.030361853473420655, 0.008400451824335116, 0.05058932503951447, 0.07157327154917376, 0.039427708967455795, 0.024463608095954572, 0.02608696071963225, 0.042448855603912046, 0.0718400850892067, 0.05259739853707807, 0.012649603504022318, 0.013763302538011755, 0.037943729132946045, 0.03239313286862203, 0.05430085391604474, 0.056831636865224154, 0.03382660934169378, 0.04840606737083622, 0.038761065275009186, 0.032431093510240316, 0.06620097053902489, 0.06373628707868711, 0.07790867159409182, 0.030944745588515486, 0.04113362403586507, 0.021909865218081644, 0.016627081636605517, 0.0190092280972749, 0.023928696888365915, 0.04981980526021548, 0.025580941533137645, 0.02038334123790264, 0.036386474301772456, 0.034676094472940476, 0.01980350592306682, 0.053027433675846884, 0.04351903424997415, 0.02499884839302727, 0.03631115012935229, 0.03302032992775951, 0.02929733720208917, 0.06182646205914872, 0.05329115648886987, 0.008481902319804897, 0.045984457313482247, 0.03142050041684082, 0.04352913763640182, 0.030805062369576523, 0.0677168991948877, 0.0704850981544171, 0.0853756373482091, 0.06675515044480562, 0.03288711654022336, 0.03203958898250546, 0.027859502837860158, 0.07596172392368317, 0.05580098627667342, 0.032383572310209274, 0.02424554051166134, 0.062324133568576405, 0.042446646972426345, 0.027396060027448193, 0.049849314748176506, 0.038036128639110496, 0.03725989814847708, 0.00892172787072403, 0.0030299695000784205, 0.020452278699459772, 0.02226529034253742, 0.020956001044916253, 0.028597808309963772, 0.034305325975375514, 0.06877748335578612, 0.06897467920290572, 0.03287873663274305, 0.010168335799660002, 0.08867596382541315, 0.006789054987686021, 0.027307093908478106, 0.02675877315258341, 0.07751109757061515, 0.06861140512462173, 0.03282513575894492, 0.023575298887278353, 0.013552367204933293, 0.04696943910260286, 0.05915346834808588, 0.019977075180837085, 0.03031447476574353, 0.05931328370102814, 0.04175054468214512, 0.04606047019894634, 0.011169264858056391, 0.06702866791082279, 0.012769682149934982, 0.013642741284067077, 0.01957505675298827, 0.032825203612446785, 0.02218315876754267, 0.06933671834745578, 0.027319711267149875, 0.045992820257587094, 0.030647489574870894, 0.015428256143682768, 0.08351773382829768, 0.0532532874494791, 0.08046940847166947, 0.052334408541875224, 0.04670485455010619, 0.05625717554773603, 0.03135349847642439, 0.03696965140157512, 0.08098984483097281, 0.009841608465649188, 0.021136983297765255, 0.012115133344195783, 0.014857866036306535, 0.026430786287944232, 0.011832154555512326, 0.024137436312490275, 0.01346616102715156, 0.01354608905967325, 0.04746088505323444, 0.039385955315083265, 0.006700849252021206, 0.019080006085070114, 0.06604023916380745, 0.05141753131257636, 0.015051055134141018, 0.10411199767674718, 0.028911936096847057, 0.0286440810055605, 0.030798904664282287, 0.007763789201687489, 0.06981578442667212, 0.02383569348603487, 0.03211398356195007, 0.00597590795119426, 0.05635962076485157, 0.16879262908228806, 0.11068933616791453, 0.1279238677982773, 0.1108757500935878, 0.07784566961761032, 0.16112868461225713, 0.19144390576652118, 0.12956799886056355, 0.13384343444236688, 0.14759541223091738, 0.10798384741480861, 0.12359017319977283, 0.1408683889146362, 0.12897158014987195, 0.08954925875046424, 0.1522275943841253, 0.08956498719219651, 0.07580856499927384, 0.11470919474959373, 0.21822390519082546, 0.13948781442429337, 0.12800611981323787, 0.07459165315542902, 0.1654478178492614, 0.17513212747871876, 0.1646067194108452, 0.15059627406299114, 0.07879217168582336, 0.08647740858473948, 0.21960104629397392, 0.16003570040421827, 0.05471200203256948, 0.107447282278112, 0.08263268667672362, 0.13595776313117572, 0.09683099801519088, 0.1488063529665981, 0.19787778838404588, 0.10101989324071578, 0.12258163946015493, 0.20476772795830453, 0.21663914594267095, 0.17775569669902325, 0.16372838297060557, 0.1653069675500904, 0.14201294178409235, 0.12655617190258844, 0.11434399363185678, 0.12428075900035244, 0.14768409675785474, 0.12830308744949953, 0.19453338427203043, 0.17840593680739403, 0.15358535652714117, 0.12159939216715948, 0.08522374049893447, 0.1621196171534913, 0.11125804350844451, 0.1583145149052143, 0.12792403064668179, 0.12183326961738722, 0.08041402644344739, 0.10621538838105542, 0.1939584615507296, 0.07508677337318659, 0.11701710947922297, 0.1210931371897459, 0.07682139386555978, 0.12967344320246152, 0.1489093681531293, 0.1274356482816594, 0.18657828042549746, 0.13915900992495672, 0.07683695945888758, 0.1135415377627526, 0.10281489656439849, 0.3488427512347698, 0.340463359441076, 0.3092233086270945, 0.14924672219370091, 0.22610698933047907, 0.17111918995422976, 0.0710202112261738, 0.1347753887197801, 0.14934231420712812, 0.14583998785487243, 0.20716538572950022, 0.1351295704288142, 0.1607842602367912, 0.09171696100383997, 0.1138404935066189, 0.14968265380178178, 0.14825881591864995, 0.15659198590687343, 0.10849029238202743, 0.15208810115499155, 0.25813795413289753, 0.18677196146122046, 0.14721412983323845, 0.1547193649624075, 0.0842516915872693, 0.197722390294075, 0.10095425176301173, 0.14419345477862017, 0.1483902617224625, 0.10662447035844837, 0.1396577331636633, 0.11137171848011868, 0.1714258606412581, 0.114420193114451, 0.1398653241672686, 0.2830922193825245, 0.12184215842613152, 0.1299035344272852, 0.13788056852562086, 0.07930713226752621, 0.20429043285548687, 0.23559883928724698, 0.14178340695798397, 0.14917352183588914, 0.07091326732188463, 0.10062667541205883, 0.21928018065435545, 0.13411167290593895, 0.08671133353241853, 0.10458451589303357, 0.1162559153246028, 0.1039797579869628, 0.15334368949489935, 0.16715061504926, 0.15239687530057772, 0.06650200938539845, 0.09005313206996236, 0.10691160602228982, 0.09925354445087058, 0.12560847561274255, 0.09569938480854034, 0.10521395211773259, 0.09973833058029413, 0.08709143527916499, 0.08802638868136065, 0.12115249543317727, 0.11731733408357416, 0.21735310048929282, 0.20683557699833596, 0.126036386936903, 0.15858041920832225, 0.13401183326329502, 0.06772479734250478, 0.20778965151735715, 0.09605189732142858, 0.10623573764626469, 0.15679509857935564, 0.09312724175729922, 0.07252930024904863, 0.13818114596818173, 0.07351817682917629, 0.19248712621629238, 0.11640440592808382, 0.17746616580656596, 0.11961804277130536, 0.0676727197798235, 0.11637609744710581, 0.08842812212450163, 0.15695686132780143, 0.10963299963623285, 0.1454163920134306, 0.1760511217372758, 0.08522891093577657, 0.0635531572625041, 0.09536585092012372, 0.1958104550306286, 0.10067245616976704, 0.051834436798734326, 0.08946567680686712, 0.18435136920639447], [0.023203722933041196, 0.005442794437320637, 0.058459632364766936, 0.021228232687073093, 0.05141151949231114, 0.012143926129543355, 0.018799316503905823, 0.023213363219318644, 0.03941819929916944, 0.06328139720218522, 0.03200368769466877, 0.059102720714041164, 0.07408201907362257, 0.029518057858305316, 0.02258176077157259, 0.02757478615136019, 0.031358153226652315, 0.017721263458952308, 0.05022639701408999, 0.028576305535222803, 0.02291834637123559, 0.0417829854413867, 0.022267059622598544, 0.03817237168550491, 0.02553840078014348, 0.00994227676918464, 0.02379599240209375, 0.03216212562152317, 0.03880663229418652, 0.03226413318355169, 0.030747732945850918, 0.07397493946232966, 0.0347200635421489, 0.040853545136217556, 0.029261015222540925, 0.012378934188745916, 0.020218026358634233, 0.02568248599501593, 0.01158259276832853, 0.0069400086732847345, 0.017459599999710917, 0.026450197478490214, 0.06122644032750811, 0.048950096392737966, 0.03977673381034817, 0.019628353982365558, 0.06355550499366862, 0.03368761144312365, 0.02616360124998859, 0.03406898544303008, 0.03375255742243358, 0.008742118803119021, 0.020637206633442214, 0.03391758731699415, 0.04789843836000987, 0.027349069781069244, 0.07228177745959588, 0.03665430225165827, 0.009634869871661067, 0.04104209644719958, 0.04402768784867866, 0.02344021274309073, 0.010780652585838522, 0.046425467756177695, 0.006984901822371674, 0.12048255066786494, 0.08912543899246625, 0.05007940258032509, 0.0614800699321287, 0.015846645925194025, 0.08461451783244099, 0.08421889120446784, 0.021342650654592683, 0.024468977004289627, 0.04232569471267717, 0.06498951411673001, 0.021936728419469934, 0.008598450039114271, 0.08507877827755042, 0.05243691482714244, 0.04818185904462423, 0.024702082620933652, 0.033728255690740686, 0.058838662026183944, 0.03872906556352973, 0.03223085443356207, 0.01708908086376531, 0.08223773179841892, 0.024165461505098, 0.04637255898809858, 0.0038579321366601755, 0.03772384986015303, 0.036531324564878426, 0.022559559105762413, 0.04357345615114484, 0.023306956947115914, 0.03846489831006952, 0.04606687896219747, 0.0418250037224165, 0.023762910427259545, 0.0872724616367902, 0.028676246958119527, 0.050682192734841786, 0.07529730243342263, 0.00988193804265133, 0.05206895207187959, 0.05325356225616165, 0.0620707618072629, 0.003626799360582871, 0.052784368861466646, 0.016001854025359665, 0.051631001822118244, 0.059196670672723224, 0.020075131972719516, 0.03692952962592244, 0.042980691351528676, 0.02603774318205459, 0.023675186027373587, 0.03330024937167764, 0.030678257745291506, 0.016915033238806894, 0.06468201561697892, 0.018362499407625625, 0.01875854842364788, 0.06643011181482247, 0.03729426594717162, 0.014826994389295578, 0.03762980490656836, 0.01945937840667154, 0.051058403083256314, 0.041302809957414865, 0.029705099428870847, 0.10061917081475258, 0.027924304628478627, 0.036313345190137625, 0.012270931769827647, 0.006697700001365904, 0.01821583236700722, 0.055497433458055766, 0.03510533572573747, 0.037792758483971865, 0.05728569892900331, 0.05948918033391237, 0.015834607017625655, 0.02654764019618077, 0.03939371097034641, 0.04256636090576649, 0.026447145767243843, 0.037437521652983766, 0.01035538500374449, 0.011814190340893609, 0.03200132978547897, 0.04963029042950698, 0.046759999091071744, 0.058783293568662236, 0.03846242504992655, 0.05622674325214965, 0.042675944311278205, 0.008989992734443928, 0.03891333871121917, 0.021337317369346107, 0.031110348845166818, 0.0196187934239528, 0.03891725046560168, 0.01149355455501271, 0.07399743289819785, 0.020892656408250332, 0.0724601371745978, 0.0482078774699143, 0.04343204606058342, 0.01604402667310621, 0.08999878820031881, 0.03544696453692658, 0.005138881146974329, 0.04840480190302644, 0.04053536310259785, 0.031884343562913794, 0.006130147442620779, 0.05806648238961186, 0.06487185614449636, 0.06591508337961775, 0.006392281211446971, 0.00819119586542781, 0.017708220319556336, 0.061105036841971536, 0.05894703763936247, 0.016199158438082253, 0.03285147988104394, 0.09087225275912456, 0.030038901338619844, 0.00976753534216966, 0.02688905187616391, 0.05519144130604608, 0.023631805587293844, 0.04656798725149461, 0.007733032905629703, 0.01750934849094067, 0.02010951334211443, 0.01735353988728353, 0.019339844285111343, 0.03023922862485051, 0.004961769936406719, 0.03078840094219361, 0.016117917440299476, 0.016675052366086414, 0.026313540525734425, 0.013151523490835513, 0.04211298416235617, 0.039498293572770696, 0.05423222688425865, 0.011652495445949691, 0.053100318514875004, 0.0377167354204825, 0.020052855668057288, 0.03388706002650516, 0.03010030197245734, 0.009189694072119892, 0.011313206732406147, 0.033638739958405495, 0.02945143250482423, 0.05071887094527483, 0.005268426628650299, 0.08762789863560881, 0.012494907697795756, 0.03385289918099131, 0.053064081352204084, 0.03765502605321152, 0.02747632223846657, 0.04610400500574282, 0.04229639557057193, 0.05317276569881609, 0.019606416945212653, 0.05813354879085507, 0.05700768277581249, 0.011591741116717458, 0.015278615423345139, 0.06620544208479778, 0.017160620507118956, 0.023062853974157145, 0.0305074195909713, 0.010593033412338367, 0.009390061222282904, 0.03494349155308945, 0.020713222911581397, 0.05582474857302649, 0.0086856002287407, 0.026818350223558288, 0.07078545846577201, 0.044589843933603594, 0.0320302794820496, 0.017306693829596043, 0.03937384346500039, 0.029094685933419635, 0.05373681150376797, 0.06789244298956224, 0.019048564468643496, 0.013788284501060843, 0.038614321899201186, 0.06933683369840894, 0.03562224031026874, 0.04918846913746425, 0.04360118109200682, 0.03472704906016588, 0.04205220099538565, 0.04773377826703446, 0.019811619505552307, 0.02717690509078758, 0.010475696896069815, 0.037755734220679314, 0.034823380676763396, 0.04881278465368918, 0.04476653105978455, 0.06315819559884922, 0.11523698642849922, 0.04541519696691206, 0.005738265055697411, 0.049899336349751265, 0.014754360608224357, 0.09969238697418145, 0.050016878971031735, 0.046050943567284515, 0.040150494647345374, 0.06593271850475244, 0.010229006160183676, 0.04144069166587932, 0.011730948512974595, 0.009902013349346817, 0.05474506704402821, 0.022717623838356564, 0.031073877587914467, 0.02504226954520813, 0.07665085087397269, 0.03072095795401505, 0.015710384219086597, 0.011175634605543954, 0.011203599578168775, 0.01741849265194365, 0.013798867951014211, 0.011885890288145413, 0.011119736890707697, 0.024332776366333877, 0.00872676185930946, 0.03565954616559403, 0.014231807219662836, 0.06817261009876217, 0.04471603109102164, 0.01898236319954906, 0.05036711499893239, 0.026036971348470876, 0.021833792960803424, 0.05355116092999067, 0.008308723219670355, 0.014633235322045428, 0.027242904495713965, 0.043980159863297424, 0.01924344651134951, 0.07562478378947292, 0.02428762664619301, 0.03341944422572851, 0.016792832474623407, 0.03762057004496455, 0.03361126607550042, 0.04262349016166159, 0.0019021155894733965, 0.020305950926350694, 0.005418166160650019, 0.053278488240071704, 0.0579634943444814, 0.024888581363484263, 0.09126464277505875, 0.04487246394689594, 0.01402224337549082, 0.030416126096887246, 0.03115173608862928, 0.014462782236348306, 0.05143281192119632, 0.007546892090301428, 0.018625903309189847, 0.018442949912111675, 0.10604114058826651, 0.016934968597654785, 0.013213548376890165, 0.08745652104594878, 0.12809500790068082, 0.03636984680114048, 0.056310986767389944, 0.029633581837905303, 0.05049068979652865, 0.0046325239652235594, 0.010771294739762587, 0.033667906786182096, 0.049785091408661435, 0.20461395835237844, 0.07728749314056975, 0.15540863440505095, 0.12013488289500986, 0.21422391411449226, 0.08161143719085626, 0.09992981316255671, 0.050222488652382574, 0.1588224255080734, 0.12987509023930344, 0.0811046597414783, 0.21814880493496144, 0.22169978224805423, 0.12644571997225285, 0.07849540761006729, 0.08755551930516958, 0.12900086572127684, 0.08952268731913396, 0.1630615187542779, 0.11971230485609599, 0.0719530408137611, 0.15456125273236207, 0.14097209620688642, 0.15366067391421112, 0.1291987265327147, 0.08038973488977977, 0.10201056115329266, 0.11668869853019714, 0.08279857491808278, 0.14290434680879116, 0.193594400371824, 0.21894341015389987, 0.12637532874941826, 0.2006035449781588, 0.19898905232548714, 0.20022805726953916, 0.0965021528037531, 0.09590654833508389, 0.09718876917447362, 0.09605275227555207, 0.12383847630449704, 0.06824431089418274, 0.12954716783549103, 0.10144783849162714, 0.054902215754347186, 0.06264812725463084, 0.1509956597749676, 0.13876860801662716, 0.07102520524391107, 0.11125585862568446, 0.1045760138492499, 0.19387865226183618, 0.10826140894953694, 0.08947746296014104, 0.10872958454170398, 0.11626397632062435, 0.13852920729134763, 0.16660780060504163, 0.07779545802623034, 0.10343365943325417, 0.14348925756556646, 0.07894804475030728, 0.09715936825211559, 0.15294405951031617, 0.0852396385744214, 0.13769934539284023, 0.15156005163277897, 0.07262377946504525, 0.15944065233426435, 0.1491975419755493, 0.18033331552786486, 0.16712925476687296, 0.13030230945774487, 0.14840084686875343, 0.13015031761356763, 0.12258210086396762, 0.09246311882244689, 0.20736739917525224, 0.12598494041178906, 0.17006693141801016, 0.16853512504271098, 0.11808033314134393, 0.1525308723960604, 0.1897533629089594, 0.14820990711450577, 0.14518934062549047, 0.2487398370036057, 0.16243467453335012, 0.09795182930039507, 0.13095174889479363, 0.12964255628841265, 0.15332811033087118, 0.10383053456566163, 0.17133028219853128, 0.15346005825059755, 0.1356404394443546, 0.19600911651338848, 0.1574632791536195, 0.09845953634274857, 0.08373760631574051, 0.16927550174295902, 0.0843250412227852, 0.22487863738621983, 0.1829824112355709, 0.1554686033299991, 0.12337397837213107, 0.1572656219026872, 0.10570266017956392, 0.13104282186499663, 0.09226780251732894, 0.13613110168703965, 0.15018443044807228, 0.11457377273057189, 0.15357402499232972, 0.10746031693582024, 0.16312607457595213, 0.0867618504645569, 0.13440694420465402, 0.14533673200224126, 0.1231708385582481, 0.08399807555334908, 0.15426317229866982, 0.16642060636409692, 0.13965284771152905, 0.2588620052805969, 0.09874607489577361, 0.23071173152753285, 0.1740287481141942, 0.2665951060397284, 0.2641221173107624, 0.14502060253705296, 0.14742733910679817, 0.18310655600258283, 0.0882877196584429, 0.07986044364848308, 0.1176911254546472, 0.057362149469554424, 0.22036504958357128, 0.11268358451447316, 0.10356719512492418, 0.15630109794437885, 0.1389887790594782, 0.14194683890257562, 0.08119244860219103, 0.16453662674341882, 0.08822879567742348, 0.11534807618175234, 0.0933857975261552, 0.09827213854129825, 0.0744771028735808, 0.10254538245499134, 0.26914843331490246, 0.15523940777140005, 0.17685618996620178, 0.16365523689559527, 0.07240281453622238, 0.11954474741859095, 0.2110423312655517, 0.08860350985612188, 0.2138628520603691, 0.11136007481919867, 0.15792807564139366, 0.09244777036032506, 0.156782667817814, 0.09692755354834454, 0.11458762841565268, 0.20172323632453168, 0.23309803062251636, 0.1960292961448431, 0.11303640915346996, 0.15926303900778294, 0.20688724065465586, 0.10986037672098194, 0.05750359009419169, 0.11026766058057547, 0.12417445970433098], [0.03651101940444537, 0.011669360433838196, 0.01841861934268049, 0.022442011395469308, 0.08123556271727596, 0.09410975367895194, 0.006721728198629404, 0.02712641190737486, 0.07308921377573695, 0.024507943574073057, 0.023788847428347384, 0.01706452977045306, 0.015378575505954879, 0.017184718678306257, 0.048998584505170584, 0.01545984873415104, 0.034547420484679084, 0.01599278031582279, 0.024397242282118117, 0.08033516031822988, 0.032508762021149905, 0.0685349545840706, 0.011641649911845369, 0.05878186185977288, 0.009943225870041974, 0.04739922996876495, 0.027478352754509876, 0.03995078143530658, 0.022761594603902528, 0.007743208386403109, 0.07187224764909063, 0.057661729465637884, 0.03425791334094746, 0.049849107794995816, 0.07543405438108103, 0.03406938238601599, 0.029594257340899537, 0.03813139156305364, 0.036983561369457414, 0.0455983199977449, 0.019470636998968463, 0.008453642184446965, 0.02638535327943308, 0.029000722404037203, 0.022785333151529943, 0.02803840707721455, 0.008533247064666023, 0.03034268825181893, 0.02980867101411734, 0.034868296302322827, 0.006926895559964967, 0.03319659296955381, 0.027298848011663983, 0.06002894137054682, 0.03285816345097763, 0.014979116851463914, 0.031196268341903175, 0.06837791443935462, 0.034139787179550955, 0.018648937876735414, 0.014841021404468586, 0.032878628067140064, 0.00502816416389708, 0.04891988801370774, 0.03114317636936903, 0.03812153923458286, 0.06040408302630697, 0.021151344491434947, 0.04851100620414529, 0.03203036429892693, 0.041762436008346934, 0.017750418412366083, 0.018965998631236807, 0.02459219896367618, 0.013884304839718555, 0.03545199248141476, 0.013461236559253718, 0.018722998277683343, 0.0437899529268699, 0.07515999408704893, 0.01954937250619488, 0.08507303108594247, 0.022204603866807053, 0.04798864619806409, 0.08400335455579416, 0.021816337647448693, 0.030884793626942804, 0.049389800655522516, 0.02766803721897304, 0.047298253779964786, 0.03047813062689134, 0.029702100304088423, 0.018629048319001282, 0.06381405397717442, 0.019029674053724323, 0.010731247602961957, 0.02030433262033122, 0.07015321310609579, 0.051889784900205474, 0.0272537814120629, 0.012480843363196721, 0.03221343643963337, 0.053580819695655785, 0.05936445202678442, 0.053535527483161004, 0.02161876860606883, 0.04413614488605942, 0.02753349899181298, 0.03378870637555208, 0.06417133659124374, 0.010488650977744587, 0.04865060799888202, 0.03938436075778944, 0.028389806792672192, 0.009016062898029174, 0.024454709109184996, 0.007582109754106828, 0.06167005973735026, 0.10804779934031622, 0.05037158993738038, 0.014113843058502036, 0.014513100696993726, 0.045742641003536325, 0.07624617937420096, 0.03782844942595277, 0.043679707949715, 0.10088350091661726, 0.021532599747713124, 0.041121233986424546, 0.021312165772542357, 0.032632292713969946, 0.03573733002745679, 0.040208187087305954, 0.061111638987702985, 0.09270785961832319, 0.007304895120406789, 0.017416077067277262, 0.025139637624046633, 0.039374593246195994, 0.06682290216641766, 0.033640795919511995, 0.014633016494501914, 0.025724896130019, 0.01663353280829532, 0.06961837144834654, 0.022916633070313504, 0.0558130438439548, 0.0344593568172838, 0.012976910985474075, 0.022619965685797588, 0.06616187335125037, 0.0318048667561795, 0.0474680334196559, 0.03464536701462098, 0.09471171602074589, 0.03466809454507061, 0.014987790225339788, 0.08703774958848953, 0.05927441721515996, 0.0673602136916348, 0.050618122065705914, 0.0380216181677367, 0.04578566351639373, 0.060295985612486086, 0.048090931959450245, 0.006729383345892919, 0.04049493259351168, 0.057850172211016924, 0.011307272095499294, 0.03080695548227855, 0.06099031014101846, 0.009584572615234979, 0.04999295382627419, 0.027886539065678204, 0.022466482760916864, 0.015225475953359689, 0.08497712016105652, 0.0212543104841773, 0.012087008067672806, 0.06540711849395718, 0.034444025318537436, 0.033835359050759246, 0.034669638212238035, 0.03624915238469839, 0.0033663299109321088, 0.03405855975246855, 0.014394460545320596, 0.046126539153712134, 0.042906924416976314, 0.061077515461615155, 0.023616367219282047, 0.014919556743864502, 0.049879417954278846, 0.03744175231882504, 0.02230565469445927, 0.05296647408977151, 0.03371889190748334, 0.027008645369538238, 0.027715156387005533, 0.05494330444240144, 0.049790763961417336, 0.0414946657339377, 0.03302321370158877, 0.04020762051056538, 0.1005077553646905, 0.044776206969150474, 0.06789192730294806, 0.017842800955155065, 0.020312875376216004, 0.01014797211558159, 0.03524955834395119, 0.04382813069969416, 0.01505011027412755, 0.018038363229217272, 0.02447683104713048, 0.01751986239105463, 0.05554483930713364, 0.008315814758784004, 0.016715065576136112, 0.00616324765308361, 0.02181830539900277, 0.0282977295906416, 0.01617789823961045, 0.0741958636790514, 0.03930175929729428, 0.02128523980666484, 0.04223867259653551, 0.04897024888279183, 0.007997069541098816, 0.004275625571608543, 0.01801034651829728, 0.02448947385086545, 0.028859268208699565, 0.03300752257928252, 0.07968517126781599, 0.045678044469760995, 0.03208470816857048, 0.08118284733167716, 0.03332497858043228, 0.05955946299114397, 0.03114721704540508, 0.048713165534926314, 0.0685999243121062, 0.05410977166944316, 0.0439381042628416, 0.03302218572103551, 0.029040050293718065, 0.03522718704438635, 0.016304182088268653, 0.06816962454468012, 0.023177704507751123, 0.058756525362176557, 0.04025295343516128, 0.032773122657090425, 0.03346831231777157, 0.03354125822495137, 0.026776418455743363, 0.051228474493005445, 0.02533004472830466, 0.02966211423543947, 0.02255682460963726, 0.04438627664265888, 0.04006690252572298, 0.14004774152168206, 0.018592410820669363, 0.021318245446309447, 0.05263336089306644, 0.033297063649765084, 0.022179855998339396, 0.024395532373871123, 0.05551917032737817, 0.057174792380205224, 0.08377419292394604, 0.08514783278639827, 0.05593157712636249, 0.016705123341775367, 0.031747835887862105, 0.021423983254602978, 0.06402287312916347, 0.033528366059597046, 0.04794943705201149, 0.020130376597600322, 0.025988958210551312, 0.049755120516887734, 0.0414940652304462, 0.06400611331420285, 0.007396451546810567, 0.02482560313572841, 0.025446245546585748, 0.06342218643320457, 0.034280986924256594, 0.0019072169005604728, 0.07095895308469023, 0.0372045127275799, 0.03070954160232629, 0.031178209132381847, 0.03324544070554631, 0.01897104693177555, 0.011119965896276491, 0.07076720587377038, 0.05395984935707279, 0.0395727424350168, 0.05507328800324883, 0.022411516335393702, 0.05056710641032883, 0.0224420147881444, 0.045703713449516466, 0.07284270200346198, 0.06200010595577104, 0.026339850721082518, 0.08312342355826072, 0.008588948004346873, 0.04636138351634145, 0.026556827560333267, 0.05227981361427477, 0.05694200737135751, 0.019912743275719028, 0.024755753044571196, 0.03896296676248312, 0.014087118108623793, 0.01379643879564745, 0.01546141445370657, 0.01979920910006123, 0.048534602259418795, 0.031891410505133014, 0.04425090890643852, 0.011652280011081269, 0.07777124789676496, 0.041057085285761526, 0.030202156864106655, 0.06785205658525229, 0.05379271261127932, 0.041114553809165955, 0.026550870022869537, 0.039019973882074864, 0.04144817590713501, 0.04615163477137685, 0.018244729477113912, 0.07070406819028513, 0.08573460951447487, 0.06235416552850178, 0.042023383613143644, 0.040681434728737385, 0.05282398512853043, 0.032074540321316035, 0.04498514825744288, 0.07527991158089467, 0.02479268570563623, 0.011180419125594199, 0.03013594202431185, 0.03837224096059799, 0.02138882496261171, 0.1504229355071272, 0.08421251297529254, 0.18020401389471122, 0.14968327805399895, 0.09934153008673872, 0.161436902359128, 0.10996060312858649, 0.10521853222910847, 0.07790466145213161, 0.1657723475779806, 0.06199463696352073, 0.15756899490952492, 0.1083546532317996, 0.14904830498354776, 0.10014525481632777, 0.0904425840292658, 0.08737404511443206, 0.10488417731331927, 0.09746789812509503, 0.1365785412490368, 0.12860523909330368, 0.12285584903189115, 0.08970336762389966, 0.22155849768647126, 0.17585455014237336, 0.130310682579875, 0.11266320132251297, 0.09452769732368843, 0.24484382463353022, 0.11497471907309123, 0.15777828225067683, 0.13073274493217468, 0.11478255795581, 0.20004386215337686, 0.179219446011952, 0.17265248910656997, 0.2584345010774476, 0.07968137147171156, 0.12540203811866896, 0.14364276932818548, 0.12701275811663695, 0.14453268157584326, 0.1017150930794222, 0.12513546885124274, 0.10859268331634146, 0.1524954800094877, 0.14041455755276339, 0.2114798506455762, 0.06690258253365755, 0.10266860441437789, 0.09323196685207741, 0.10558291910482304, 0.11623049740280424, 0.09508311894855329, 0.1216841276202883, 0.08832908315317971, 0.11891491764358111, 0.2450035246355193, 0.21331079596919672, 0.1187006091432912, 0.12447524070739746, 0.1563641745597124, 0.1853577723460538, 0.11142832187137433, 0.22810116303818567, 0.10408383168812309, 0.16915975723947796, 0.18164431303739548, 0.13522323540278844, 0.14205259537058218, 0.08397987045879875, 0.16302938333579473, 0.10935627269957747, 0.19208202723945889, 0.09459026503775801, 0.1385452342884881, 0.1313993920172964, 0.15846531252775872, 0.1072865848296455, 0.14223794399627618, 0.10913903971335717, 0.152387389381017, 0.166516157665423, 0.1360846898917641, 0.10067907867154904, 0.10469794659210102, 0.07542473809527499, 0.2127644938549825, 0.08511828937168632, 0.09089951629617385, 0.11455592725958143, 0.10161189468843596, 0.14850449987820216, 0.13251927335347446, 0.09176678583025932, 0.1445496856634106, 0.18749735610825674, 0.16503406076559, 0.19144642991679056, 0.09144903466637645, 0.10068274954599993, 0.1823150041912283, 0.16067600675991603, 0.12989069654473237, 0.12761544649090084, 0.11948078870773315, 0.08964925445616245, 0.16607128296579632, 0.14398376031645707, 0.14067567139863968, 0.0916210093668529, 0.1941420595560755, 0.09248927634741579, 0.13586930930614471, 0.13123610935040883, 0.1599325630813837, 0.12445918656885624, 0.10701391553240162, 0.24481331769909176, 0.11278896778821945, 0.09290219204766409, 0.10842846427112818, 0.1497845561908824, 0.14813657104969025, 0.10498045464711529, 0.17460354869919165, 0.14556151708321913, 0.13718813710979053, 0.2558310164936951, 0.1390359372432743, 0.07888196222484112, 0.172597948461771, 0.10366704833826848, 0.18168403447738715, 0.253158049924033, 0.10676342075956718, 0.14671369668628487, 0.09791136825723307, 0.14312846692545073, 0.2344486681478364, 0.10148308160049574, 0.15625659961785587, 0.12378356925078801, 0.06095157257680382, 0.1508350098239524, 0.11901873350143433, 0.16171166832957948, 0.13568424566515855, 0.13382206058927945, 0.13550876293863567, 0.15118323399552278, 0.28139387337224825, 0.14886572478072985, 0.0800216771396143, 0.21619797604424612, 0.1706914957612753, 0.08852540369012526, 0.17920564460967267, 0.12482824176549911, 0.18424880185297557, 0.15302247101707117, 0.0921628942180957, 0.11843432486057281, 0.14200451437916073, 0.1781333014369011, 0.13708616686718805, 0.21518761026007788, 0.15791903755494527, 0.11793144898755209, 0.09132588734584195, 0.1151411094303642, 0.09994033724069595, 0.11417909605162484, 0.22129438471581253, 0.09378132915922574, 0.07001053754772459], [0.04916101561060973, 0.026179713064006398, 0.03452265734917351, 0.04323778487741947, 0.009213856704133962, 0.0518087949603796, 0.055580177410904846, 0.06226214260927268, 0.008147153005536114, 0.047722090501338243, 0.0442518249287137, 0.05296916787379554, 0.06404347345232964, 0.08197762218437024, 0.01296845474280417, 0.01728522328526846, 0.03992415572117482, 0.010546772591104465, 0.07476459137563195, 0.049931308919829984, 0.016354605721841966, 0.09620975170816694, 0.03447522435869489, 0.030320707109889815, 0.07136086973228625, 0.02898739936894604, 0.03120080434850284, 0.03876406100711652, 0.02463972525271986, 0.040933652980519195, 0.02880198967510036, 0.02997583829398666, 0.026135496329516172, 0.014987859775179198, 0.04881630964311106, 0.030155979163412536, 0.006592461764479854, 0.047884979617914984, 0.0855865938855069, 0.04776902137590306, 0.01257005799561739, 0.018237676105595062, 0.04904769008447017, 0.0368775402727936, 0.02681303390168718, 0.0460426688327321, 0.0789702260600669, 0.04741816448846033, 0.03486964997968503, 0.10536669713578053, 0.02424252781617854, 0.05961107915001256, 0.011591814907400735, 0.014816105598583817, 0.031431224662810564, 0.0670051227456757, 0.03876681246661714, 0.08997320743011576, 0.051716663475547514, 0.03405257846627917, 0.0898758919377412, 0.028723445854016712, 0.11596827075949737, 0.031833514504666836, 0.034555227030068636, 0.003742577790814851, 0.011917925622713352, 0.027448154553504925, 0.07038558420858212, 0.020152183016762137, 0.024876701911645274, 0.08544925161238227, 0.04369506658986211, 0.028644810430705547, 0.04165442680407848, 0.039598679436104636, 0.04007073285590325, 0.041354924839522154, 0.04108051170728036, 0.010781539770375406, 0.0203468886403633, 0.05590278349284615, 0.05778508713202817, 0.0424848213525755, 0.07227850013545581, 0.016828950893666064, 0.031034363101103475, 0.061031171519841464, 0.013845365411335868, 0.04223474727145263, 0.04493042440818889, 0.024407398255009736, 0.03438385961843388, 0.057083536205547195, 0.04555518552660942, 0.012212460710933166, 0.08549523593059608, 0.055662548169493675, 0.03984995452421052, 0.025078208152470843, 0.07648902705737523, 0.07603426610252687, 0.014187375898472965, 0.009321675070428422, 0.022290891468791024, 0.05142339046246239, 0.042666275187262466, 0.019430262469021336, 0.006944841114870671, 0.04276486632547208, 0.014963824368481125, 0.06613783964088985, 0.021194380574992726, 0.051398858028863154, 0.017938749199467044, 0.04990269509809358, 0.11820185876318387, 0.053301968944392035, 0.016587407694065144, 0.05284690943413547, 0.021654250898531506, 0.026281325379386544, 0.026086485745119195, 0.004248601218153323, 0.030979235523513386, 0.059752981178462505, 0.06828416804117815, 0.09326764422335795, 0.013599263304578406, 0.013838300165454192, 0.07128588482737541, 0.09385259569223438, 0.058563624641724994, 0.08584246265568904, 0.02660096117428371, 0.05103809453014817, 0.044690243367637904, 0.02899559267929622, 0.06956520822963544, 0.0012986723450012505, 0.02099880133755505, 0.03875108741755996, 0.04709524628041046, 0.06171548765684877, 0.07172791646527392, 0.02474726117881281, 0.02125719765068165, 0.04549494179497872, 0.018666233734360764, 0.022254165760906677, 0.025541796847911816, 0.06504866879965578, 0.03926939317690475, 0.03751325294641512, 0.017299648939764926, 0.02506937362652804, 0.015470103094620364, 0.029735338341976916, 0.05166607190455709, 0.009474294559497918, 0.0437652542521911, 0.014839184270905597, 0.02636414227475013, 0.03950781002640724, 0.014066004643349775, 0.01662208083351808, 0.01770398286836488, 0.06375611387193203, 0.008416797732934356, 0.013419774676939207, 0.039813856461218426, 0.030287882978362695, 0.0265051537259881, 0.07679841866982834, 0.020212291041389108, 0.031361206634236236, 0.032167462299444845, 0.053817231474178176, 0.06160797378314393, 0.05305075831711292, 0.027240485518372486, 0.0788280051201582, 0.024166850805548683, 0.07457734963723592, 0.021194411109068563, 0.031503902548657994, 0.029879225085356405, 0.057301217024879794, 0.052066047941999774, 0.03553676864664469, 0.059686681521790366, 0.024115251610055566, 0.0615691819361278, 0.07351482486618416, 0.02867186362189906, 0.02330331491040332, 0.0366976097492235, 0.026501197866829376, 0.04436142869027598, 0.03004146959366543, 0.02484940953685769, 0.017437973392329047, 0.03333351794364197, 0.0320925316773355, 0.031016361567058733, 0.04055699479899236, 0.03172678094623344, 0.025497266290975467, 0.06175737362354994, 0.015181415281923754, 0.02590480799387608, 0.025599524910960878, 0.05016794800758362, 0.022078213148883412, 0.0372529601279114, 0.007399790787271091, 0.036938272549637725, 0.04460074459867818, 0.07315663980054003, 0.020952118128272038, 0.03898905643395015, 0.05289056637723531, 0.04634290700778365, 0.02904187555291823, 0.02564357370803399, 0.08300292930964913, 0.04903810577733176, 0.027501444997532026, 0.02432037953154317, 0.021556112682446837, 0.011745323277344661, 0.033972521512103934, 0.030315855584506477, 0.06449210723595959, 0.053075324677463086, 0.04850456351414323, 0.026604167252246822, 0.011320612093965923, 0.051319221766399484, 0.007256578338066382, 0.04727850841092212, 0.03432980751884835, 0.05795423912682703, 0.050618366338312626, 0.08032718074641057, 0.050527066058878384, 0.004692925456246095, 0.05544659761445863, 0.05528136755206755, 0.05777718219906092, 0.007534782784724874, 0.05297455544184361, 0.03879671211221388, 0.03412243703912411, 0.03639551917357104, 0.018329395380403315, 0.0265439845887678, 0.06532762811652251, 0.020843633949490528, 0.06903394245143447, 0.0398048319454704, 0.013260352026138986, 0.05789146785225187, 0.0434394861970629, 0.05769573764077254, 0.01914723194204271, 0.03273284821105855, 0.02494362073152193, 0.004479120344123138, 0.04119207304237144, 0.031024453097156117, 0.004911828062696648, 0.05829195279095854, 0.09488358894096953, 0.03633177759391921, 0.0309288237643029, 0.03892662442688431, 0.03375900011243565, 0.03363526246643492, 0.006931364561231541, 0.03633515330563698, 0.043769257608801126, 0.025613875926605294, 0.016901783146230236, 0.04607572027349046, 0.019583036324807575, 0.023253720785890306, 0.07156455915953432, 0.012103194520542664, 0.02838050407756652, 0.007961247132958045, 0.07455073749380452, 0.07642215743128743, 0.010579649309095527, 0.05128468094127519, 0.008246897653277432, 0.040149113828582425, 0.07372905872762203, 0.024276025393711667, 0.016054521913507154, 0.06482135278305837, 0.04915774167914476, 0.007923490900014128, 0.014925648291994418, 0.041249178549540896, 0.06390361381428582, 0.03695597552827426, 0.028634455986320972, 0.06537635371621166, 0.0180033576076052, 0.04289887699165514, 0.029890213959983418, 0.03367434947618416, 0.03347048702250634, 0.057594011670776775, 0.0016697322945609422, 0.007758340565487742, 0.01773716662345188, 0.03827778210065194, 0.02449529568132545, 0.012463459296018949, 0.03088667316894446, 0.05062162330640214, 0.006971549525457833, 0.02860137401148677, 0.034715079702436924, 0.09647025487252645, 0.10569104366004467, 0.02202608130340065, 0.05577168034921799, 0.02139056201225945, 0.04413287095459444, 0.03319854036505733, 0.023405098555875675, 0.021285735137228454, 0.021659480707187737, 0.03186342093561377, 0.00735727378300258, 0.02299131263446595, 0.02964916778728366, 0.04644018178805709, 0.05002429875146065, 0.023534496880269477, 0.022653052749644433, 0.030387576735977615, 0.00850874007612999, 0.058983685315719674, 0.048151206225156784, 0.06028411124965974, 0.040054583722459416, 0.024012767377176454, 0.025384300388395786, 0.14875392935105733, 0.12009782131229128, 0.09580133469509226, 0.16331857496074267, 0.10614442718880517, 0.10068511763321501, 0.17563184137855256, 0.23199285992554255, 0.12295932562223502, 0.22865810458149227, 0.0963615399918386, 0.16916168427893094, 0.1293558073895318, 0.15534524566360883, 0.09099278093448707, 0.06397629170013325, 0.14367124065756798, 0.12709141389599868, 0.14735850851450646, 0.1036525819716709, 0.06656034304095165, 0.15075357205101422, 0.12862088611083372, 0.18930339919669287, 0.17986337574464933, 0.17635990945356234, 0.08005774806120566, 0.21697565859981946, 0.07045471335628203, 0.14051329796867712, 0.13588870183697768, 0.12090709645833288, 0.19533145001956395, 0.11130407532410962, 0.0961894838671599, 0.07268676787082638, 0.07436431678278105, 0.07337436133197375, 0.2527079369340624, 0.09000560747725622, 0.07225507710661207, 0.08291765781385557, 0.15617522969841957, 0.11056133732199669, 0.14188457652926445, 0.16930591368249484, 0.16977958540831292, 0.14619536378553935, 0.20811899884470872, 0.1587754301726818, 0.13300639364336217, 0.09369990495698792, 0.08802283315786294, 0.06486446689814329, 0.08858444302209786, 0.12797938553350313, 0.08785745381776776, 0.13253463538629667, 0.11276366521737405, 0.12388178040938717, 0.11797478023384299, 0.06488186453602143, 0.15197359158524446, 0.13019082615418093, 0.15258793719112873, 0.11474898404308728, 0.18134205282798835, 0.12412218536649432, 0.22035929560661316, 0.1734570280781814, 0.04924188680680735, 0.13724278632019246, 0.17800098710826465, 0.19868918055934565, 0.06783364793019635, 0.18710168876818248, 0.10198585569326367, 0.19854083923356874, 0.18324504499988897, 0.1415830219962767, 0.11237889514969927, 0.23507115617394447, 0.14344364644161292, 0.1497841083577701, 0.1268171907535621, 0.12626015421535286, 0.13556516276938574, 0.12204694029475961, 0.08935725369623729, 0.07596889603883028, 0.08326212968677282, 0.1079578527382442, 0.12942690428878578, 0.20614632112639292, 0.1569888067564794, 0.18218369409441948, 0.24613190123013087, 0.20215777015047415, 0.12486435339919158, 0.12328160261469227, 0.23327279410191945, 0.16162090748548508, 0.08295756924365248, 0.11035102539296661, 0.12491195941609995, 0.20254446725760186, 0.12727859456624302, 0.07951510325074196, 0.11373024513678891, 0.06372254674455949, 0.10944816669715302, 0.18651848791965417, 0.11125266951109682, 0.17350343987345695, 0.06828484657619681, 0.2803388871252537, 0.2454852302159582, 0.12599836183445795, 0.1578761405710663, 0.0926020760089159, 0.16429357549973897, 0.14486156749938214, 0.0960007222103221, 0.11255693595324244, 0.09721874685159751, 0.12821540715438978, 0.1321327390947512, 0.12731005144970758, 0.09759460096912724, 0.25923205113836695, 0.12475063093006611, 0.1966450395328658, 0.18639758655003139, 0.15364797173866204, 0.1381901569132294, 0.10948845810656037, 0.13269981795123645, 0.11129581076758248, 0.1288121651325907, 0.08541356067040137, 0.15674921604139463, 0.13540981896221638, 0.1630847653640168, 0.17426091565617494, 0.1805375681391784, 0.10790375992655754, 0.09146239502089364, 0.18777045288256236, 0.09499051927455834, 0.122816656849214, 0.16285535267421178, 0.25505954931889263, 0.1194507431771074, 0.1548592924539532, 0.1126868346972125, 0.1283753921410867, 0.11471148819795676, 0.14870310707816056, 0.05404655595443078, 0.09350080921181611, 0.11355316785297223, 0.0566254300730569, 0.09234074503183365, 0.10559248644858599, 0.16112109859074863, 0.18801400624215603, 0.09037064574658871, 0.1272216383367777, 0.10065437321152006, 0.10470882350844996, 0.12880666899893964, 0.16566127139542783, 0.18278848592724117, 0.18145519175699779, 0.09504985716193914, 0.09504476814929928], [0.04235929576680064, 0.03639884399516242, 0.035014554525592496, 0.035139313366796286, 0.008650147622185094, 0.05733529305351632, 0.015817886218428612, 0.028727028518915176, 0.043062291972871335, 0.011815511787842427, 0.06308680692953722, 0.08265771783356156, 0.03487883395116244, 0.017819038658801998, 0.04254051211423107, 0.03531197678031666, 0.016259843217475072, 0.06412573225264039, 0.04939948674291372, 0.008686668921395071, 0.01317372261213937, 0.009589713366170014, 0.040673838529203615, 0.02297143664743219, 0.02698418078944087, 0.046576814992087226, 0.03144899210227387, 0.017927468554782014, 0.05601328292063304, 0.04341485198321087, 0.03694101383111306, 0.024608059719737087, 0.04503464738705328, 0.05365271048088159, 0.024787408399528692, 0.003201981307938695, 0.04202904598787427, 0.04745095469323652, 0.05423544314024704, 0.031459828306521685, 0.10547452992094414, 0.031789341874952824, 0.02239364541934005, 0.014861177287197538, 0.019052410065861683, 0.10515503492206335, 0.02785106864757836, 0.05432133210290756, 0.03670698031783104, 0.031532170317534886, 0.052519689314067364, 0.05004214082977601, 0.023845617060682604, 0.08750810327806643, 0.08884077998144285, 0.01771047305581825, 0.10572549288294145, 0.03369367076084018, 0.0318852901192648, 0.00672166925089966, 0.04721584230927484, 0.011100483459553548, 0.09779022940035377, 0.03910205965595586, 0.02690029520142291, 0.021568779234907458, 0.022136119327374866, 0.02077156674515988, 0.05796117375471762, 0.034029019730431695, 0.006601762359163591, 0.028001532091626098, 0.08906475760574852, 0.027411905516471182, 0.04492683495794024, 0.031931148908500157, 0.011356323391997387, 0.04886126258809652, 0.005967460614296475, 0.044888680933841636, 0.05620399197297437, 0.03300514431404216, 0.047277263299162896, 0.027258023952267, 0.03648475670654859, 0.04165379237383604, 0.04233231721445918, 0.03269199361758573, 0.028460672990019833, 0.044258664561701674, 0.052441888488829136, 0.019816316664218903, 0.0936499647796154, 0.07035428338817187, 0.006571880949195474, 0.041384298620479446, 0.0227502121789647, 0.04287823595638786, 0.02676007424348167, 0.031199294608086348, 0.02468048145861498, 0.06526895519345999, 0.027258040915642465, 0.06692810223570891, 0.11620890641851084, 0.028241440021832074, 0.035791986023208926, 0.012507955078035593, 0.02476938650943339, 0.08723610573049102, 0.05484209076634475, 0.0890681774222425, 0.04771115590951272, 0.03566997524883066, 0.015394322607400162, 0.13172694801219872, 0.04400735215416976, 0.02185068678643022, 0.046065121556499174, 0.01650173925528569, 0.06991116609424353, 0.021667599378685867, 0.05907088385096618, 0.04834402212873101, 0.013129407490071441, 0.05744183662214449, 0.03546946815082005, 0.028369416815361807, 0.027490525672744428, 0.03925942210480571, 0.01999627941820238, 0.05222824834553259, 0.020818098980401243, 0.030461604906512157, 0.011010379098089678, 0.033788719946252446, 0.0507767194482897, 0.02926498804507511, 0.015710562334528992, 0.019636523543990085, 0.03570744055988533, 0.0544473699826215, 0.02603855912041451, 0.03756747467975531, 0.04131948834817324, 0.008450304640323987, 0.020856130868196487, 0.03736835179318275, 0.06327503932906048, 0.027198319655976126, 0.034302896820008755, 0.002760931213353095, 0.024553018655361872, 0.04864357498341373, 0.03284997014062745, 0.024114849578057016, 0.07136541591691119, 0.10688364359417132, 0.0494132033283157, 0.06141153110989502, 0.026669588206069808, 0.05535916159195559, 0.05266619859529393, 0.028637743488486325, 0.03556759788521698, 0.02142293831067426, 0.05244634307122656, 0.009016211327564503, 0.005806359013409487, 0.025072287934433137, 0.029800521808543375, 0.030162927362003496, 0.04600503049524767, 0.013731625978834927, 0.040330652480146716, 0.059282722483788214, 0.017153567135600106, 0.045630787898387225, 0.016198664803856185, 0.049082868732512, 0.011415179519514953, 0.03408239668767367, 0.01444992739042001, 0.027068736430789744, 0.04557935155129858, 0.00916372738512499, 0.02312052096905453, 0.03735910675355366, 0.032788121673677645, 0.010609058713141297, 0.04597926652058959, 0.05818701735032456, 0.03382026164659432, 0.04115371885044234, 0.009541349086378301, 0.027266731252893806, 0.04906074509822896, 0.08039396216294595, 0.021761388185300996, 0.023491633823141456, 0.03698401598791991, 0.026259064341762235, 0.05331417918205261, 0.025991501020533696, 0.03494837361254862, 0.01321027529359396, 0.01641571119294635, 0.03600248454936913, 0.007797294412739575, 0.019169121481744305, 0.029736250971576998, 0.025964885484427214, 0.008923247789165803, 0.10061478069318192, 0.01874064527718084, 0.060688938812485764, 0.051009307681982, 0.052216550401811085, 0.028492380931441273, 0.023898844740220478, 0.015312857693061233, 0.05337485039074506, 0.06150583390678678, 0.020486595608027916, 0.023825142266494886, 0.03338514088786074, 0.033121340043310604, 0.02186293264717928, 0.026536437583022883, 0.029988727066665888, 0.027036799483799508, 0.01233852403571031, 0.047045211108135324, 0.028412517359746352, 0.06025506995086159, 0.022927372583321164, 0.07665771086301122, 0.032387124441031895, 0.0320178826472589, 0.05701795579599483, 0.026609045919030905, 0.04028365375208003, 0.0674022760774408, 0.08724739655320134, 0.004561431306813444, 0.04579602474612849, 0.020033373231334344, 0.09794827377689735, 0.026959629696128622, 0.013446439406834543, 0.015368916559964418, 0.035035297341112576, 0.01957887181613062, 0.12149222434631415, 0.03191696074126022, 0.007477826555259526, 0.0483242971157389, 0.03107375545161111, 0.050038218897368224, 0.013474509552387255, 0.030654838109122853, 0.02128328392947359, 0.10766956356487103, 0.029002866574696133, 0.03934681062985744, 0.07389451270656926, 0.13475778752139636, 0.04593749590484159, 0.11584970355033875, 0.010795267381971436, 0.043964377138763666, 0.028009004458518963, 0.05502516969240137, 0.03923519840463996, 0.035116507804819515, 0.028632586622344594, 0.014327458604904158, 0.020479348854028752, 0.0100972109108365, 0.054654374053435664, 0.0463044272868761, 0.023847148853487203, 0.04107882554775902, 0.03412340395152569, 0.06536166343305792, 0.08485283290169068, 0.02914511804868068, 0.03458587645686098, 0.04929313316409077, 0.07130407635122538, 0.03740673651918769, 0.0872073019189494, 0.03639581772897925, 0.06151992029377392, 0.026410888248522366, 0.015596478545506085, 0.050472912179040055, 0.0666603251759495, 0.02747286170987146, 0.06963450022573982, 0.014441522037876504, 0.05658534561683025, 0.06018242599176509, 0.018156163693804826, 0.0721647912370307, 0.05549314172406282, 0.019368678630728806, 0.05212283793038555, 0.0163649041870875, 0.04196544350790126, 0.04685111616605094, 0.03001342574134469, 0.06206903154296534, 0.0738650778574603, 0.04570783215707966, 0.006769926661425936, 0.10867878941020795, 0.054437653361154456, 0.021595752698236277, 0.011244734915505563, 0.05850472780210631, 0.03577035432681441, 0.016395716462284327, 0.00874941305456949, 0.01249850562973214, 0.026838507802624787, 0.07786211730646235, 0.022243731588657414, 0.005244351782104266, 0.03578187245875597, 0.0708479651116899, 0.023723377280735543, 0.002318043985204505, 0.0682480021246842, 0.06426796676324946, 0.041560938249209096, 0.07752289050923926, 0.011876528201225613, 0.013476720728379275, 0.027558367300246443, 0.05460921076259442, 0.04145848285406828, 0.04887313355824777, 0.03268684692946928, 0.010739535060045975, 0.035482635122856925, 0.036332130432128906, 0.03162182514954891, 0.007023998161977423, 0.0332200431397983, 0.03340150036716035, 0.07047988022012369, 0.1377714058118207, 0.14454584515520505, 0.09181751989360366, 0.14759514081690991, 0.14695524158222334, 0.16824366711080074, 0.06079651375434228, 0.14997645946485655, 0.07929027745766298, 0.0807450565376452, 0.13867164536246232, 0.13535647253905023, 0.10897005735231297, 0.05618378520011902, 0.1155163257249764, 0.0819107254168817, 0.12021249373044286, 0.2263291281248842, 0.061707026325166225, 0.12015697599521705, 0.2087744636727231, 0.11437463627329894, 0.10976049636623689, 0.12096148782542773, 0.1073103810527495, 0.09691470209509134, 0.18848389174257005, 0.07200418199811663, 0.15764767783028738, 0.12646273763052054, 0.1092665364433612, 0.11459537728556565, 0.12376864148037774, 0.0979994624587042, 0.08508525150162832, 0.09170319352831159, 0.14333050751260348, 0.1562160775065422, 0.13608449990195887, 0.13256727292069367, 0.15133439802697726, 0.0843992865245257, 0.10000413988849946, 0.1755382985408817, 0.15611284518880503, 0.17755010058837278, 0.08080561578805957, 0.13499661827726023, 0.08422676899603435, 0.1126096649095416, 0.12240910157561302, 0.14422378529395374, 0.2008206761841263, 0.1290916401360716, 0.184556639620236, 0.06486925735537495, 0.189842712400215, 0.13703687808343343, 0.09740191737988166, 0.08171044223542724, 0.17479385063052177, 0.18057719458426746, 0.14645906963518687, 0.10881038449172463, 0.060741633842034, 0.08523653088403599, 0.16991314824138368, 0.1367368841809886, 0.14818423134940012, 0.1707144302449056, 0.1748144645243883, 0.18404207937419415, 0.19077765223171028, 0.12333900667726994, 0.07295134903064796, 0.13289154480610574, 0.10329953341611794, 0.1924334540963173, 0.13143916774008954, 0.18135820196143218, 0.2129918166569301, 0.16642078278320177, 0.15747869546924317, 0.1060810045206121, 0.0803227974101901, 0.13682098181119987, 0.1782670406890767, 0.10696616702313934, 0.1042500524116414, 0.14668622958872998, 0.26109528115817476, 0.1318715438246727, 0.21323496289551258, 0.10790963603981904, 0.1111663259299738, 0.26078570634126663, 0.20157082378864288, 0.1343387242938791, 0.09064111659037215, 0.13916442463440554, 0.12451773057026522, 0.14200793419565472, 0.1527835045542036, 0.2624402461307389, 0.14351135066577367, 0.1477530901985509, 0.1308344573314701, 0.10495863974626575, 0.14023691708488123, 0.1892084585768836, 0.14255598693021707, 0.1751828547567129, 0.13214803327407154, 0.26264120106186184, 0.19062370620667934, 0.24610847820128712, 0.09807330063943352, 0.13776266628078052, 0.1289087613778455, 0.11503580079546996, 0.12874982133507729, 0.1704143684889589, 0.1022042693304164, 0.12575126652206692, 0.10399874339678458, 0.13315100302653654, 0.08955208145614181, 0.1286812350153923, 0.22921406903437205, 0.24614938029221126, 0.11873526871204376, 0.16944618044154985, 0.07667098300797598, 0.1943832923259054, 0.10482610828642334, 0.0930126371926495, 0.10638673204396452, 0.12440156537507262, 0.1390093115291425, 0.12234257800238472, 0.18936100681977613, 0.10913863259234599, 0.07705891504883766, 0.1068093982924308, 0.15324729681015015, 0.15545721751238617, 0.09637917511697326, 0.11316475405224732, 0.12111794443002769, 0.08034611187343087, 0.229500057974032, 0.13620187288948468, 0.09435665900153772, 0.15376495117587702, 0.13337795941957406, 0.1336187036441905, 0.15898444609982626, 0.16991379963500158, 0.21393966222448008, 0.17084879374929837, 0.09943096100219659, 0.13477872711207184, 0.10031034238636494, 0.11536619306675025, 0.11162173149308988, 0.14715695647256716, 0.15332346915134362, 0.09593951835164002, 0.13553878132786068, 0.09912083657192332, 0.10543987713754177, 0.0815152752080134, 0.08144459221512079, 0.07246497512928077, 0.10349441545882396, 0.18851435796490737], [0.04910240714837398, 0.025158575536417108, 0.05202181085145899, 0.05046975699120334, 0.05707301891275814, 0.04465755833578961, 0.0221013613710446, 0.02209238096007279, 0.10618608245359999, 0.02660322578490845, 0.040350852467651875, 0.06490146062736, 0.03185211654220309, 0.027224263442414146, 0.01695193536579609, 0.013665451002972466, 0.009895577444694936, 0.077379739976355, 0.02556204772554338, 0.06929030655218021, 0.02710219838523439, 0.03691555180453828, 0.013657597808300384, 0.035746371506580284, 0.0288602045870253, 0.06266107370278665, 0.025569501432723234, 0.007340416428633034, 0.07451301773211785, 0.00925496914091387, 0.03166111911247883, 0.0698472752368876, 0.0032343605749442107, 0.03484507683398468, 0.038935170575444183, 0.013893738172815313, 0.040002821678561826, 0.030848631103123938, 0.02873701655438968, 0.024577261015240635, 0.04755489947274327, 0.03924942389130592, 0.008359170601969319, 0.03029587951355747, 0.013637723517604172, 0.040950636712035964, 0.022208273044920394, 0.03397450961970857, 0.04822450836322137, 0.02692587936430105, 0.02119012107141316, 0.04131954941632492, 0.08834091680390493, 0.014800492507804717, 0.047450384723820856, 0.02650248199435217, 0.012029599764251282, 0.027265944152272174, 0.002612262070345293, 0.01767755053671343, 0.02865011657455138, 0.051059414100434096, 0.01819678588903376, 0.048275296709367206, 0.053752424594547064, 0.03146160946094564, 0.05265419531081404, 0.03301151575786727, 0.03505197573187096, 0.04939861821808985, 0.010201058150934321, 0.10797133522906474, 0.02716061007231474, 0.08995931781828403, 0.09791797040296452, 0.08561635443142482, 0.015084674847977502, 0.017336266082046286, 0.08166584891400167, 0.06742718509797539, 0.03537462931126356, 0.011080053618310817, 0.054413439839013984, 0.03636367213247078, 0.02583108516409993, 0.02524560104523386, 0.04288400011137128, 0.024691823171451688, 0.039652650111487935, 0.014001078171921628, 0.04606146425274866, 0.01878547269318785, 0.0486139196104237, 0.07231371610292367, 0.01668686735709863, 0.03408281398671014, 0.0625454784770097, 0.03698518306815198, 0.034492516823645146, 0.03223964146205357, 0.022011547083301202, 0.07852843190942492, 0.010198899561406245, 0.03293216108743634, 0.02949636848643422, 0.008799275200414871, 0.09119379014841147, 0.02694019136418189, 0.04937160913167255, 0.02950831748811262, 0.050996554616306505, 0.008419590752704867, 0.05021490941622427, 0.0163178901919829, 0.05396922331835542, 0.016017682551007186, 0.052188004433576546, 0.021626698984099284, 0.005112443302225853, 0.07257743552327156, 0.024641640417809998, 0.05562420754826494, 0.030774304377181188, 0.032997928094118834, 0.03761205103780542, 0.01143882137590221, 0.039255378036094565, 0.03519525857908385, 0.056700967984007936, 0.009933613573334046, 0.04818204224907926, 0.04308055813557335, 0.00903038083509143, 0.027836987349603857, 0.015757074213719795, 0.02866269661379712, 0.033679126362715445, 0.07545110596609966, 0.009908534070876027, 0.04522858287340828, 0.010809031464824719, 0.047385920504374165, 0.022944149361657243, 0.031033860985189676, 0.014318808979753937, 0.04070113938567894, 0.027120439102873206, 0.018613002662147795, 0.02859045977571181, 0.07066794977124248, 0.0486030257306993, 0.01853906609384077, 0.10887740339551653, 0.02852031621815903, 0.00848267160888229, 0.07187913477952991, 0.04322015314495989, 0.02274642256088555, 0.05389277956315449, 0.06492385906832558, 0.019043528042467575, 0.02330409861834986, 0.020371248047532778, 0.05338960513472557, 0.06883214613688843, 0.02454119178998683, 0.024387417095048085, 0.006694847185696874, 0.019444715264918547, 0.027208404382690787, 0.014447320119610854, 0.08781721669116191, 0.029903279151767492, 0.08991211213703666, 0.03759955242276192, 0.05066765172939215, 0.1518801980252777, 0.009051790311267334, 0.04876149758430464, 0.06732590017574173, 0.02518188321430768, 0.027507044607773423, 0.04366560459935239, 0.06488060924623694, 0.04885584109329751, 0.04578217923907297, 0.04788866067039115, 0.02528006044615592, 0.047241192377571545, 0.03337179749671902, 0.03598208100135837, 0.018879027405221547, 0.013992358148763222, 0.07354848698845931, 0.03477481792547873, 0.04342172893562487, 0.003925350952028696, 0.023886966984719038, 0.02679776177475495, 0.02510293566488794, 0.07884173188358545, 0.056199605244078805, 0.03604856386248555, 0.035065325908362865, 0.052223400212824345, 0.020843460923060775, 0.014461275888606906, 0.0009465727842845288, 0.03456425493849175, 0.02841397112102381, 0.02170979916783316, 0.020198058769372956, 0.03476771366383348, 0.044185440455164225, 0.03471083885857037, 0.04346061238486852, 0.02825298359883683, 0.03533528445820723, 0.011245468581494476, 0.03139575085203562, 0.05978309456259012, 0.011329345687824701, 0.02937083950798426, 0.0480820160093052, 0.053250111905591826, 0.014118395180308392, 0.026324198614539843, 0.010147413172359978, 0.019645327535857047, 0.04904238394062434, 0.16255681083670684, 0.04086657300857561, 0.030717799373503243, 0.037346604745835066, 0.03943190570654614, 0.008506751120356577, 0.05480889004788228, 0.03926380204835108, 0.06884706033659832, 0.09674177744558879, 0.05423905294654625, 0.056878934148699045, 0.03243801456743053, 0.03076180236946259, 0.04390105964349849, 0.001850804135236623, 0.06841666557426963, 0.04112550536436694, 0.009130684426054358, 0.12066074753446238, 0.04869445493178708, 0.013682591645712299, 0.030321904724197726, 0.04202810960954853, 0.018897895767752613, 0.03414637575458203, 0.02021387542065765, 0.02323549024627677, 0.05611743126064539, 0.035667596983590295, 0.04336636047810316, 0.035916463272379975, 0.009764315693506172, 0.023009689059108496, 0.04198671897341098, 0.026478051341005733, 0.006945548487627613, 0.006908172234294138, 0.031249387455838065, 0.08597823751292058, 0.08114963304251432, 0.03568431608644979, 0.025799601139234643, 0.03737216855266264, 0.016556281596422195, 0.02836924378893205, 0.19415653949337347, 0.048795604147017, 0.0769303258774536, 0.01263534917961806, 0.04324668047151395, 0.026047402128045048, 0.05145570908540061, 0.03814392410484808, 0.028765850900007144, 0.012341496019091989, 0.030017245893499682, 0.07717768581850187, 0.022331997120220746, 0.03396093213398542, 0.061655131966939995, 0.03653814384181585, 0.03264876415154763, 0.0363333382244621, 0.016584905596183877, 0.0561815833539835, 0.011546336097775825, 0.044488898278879266, 0.032460016065410206, 0.018159235761101757, 0.006228508727092828, 0.05350024366219129, 0.05655653841261353, 0.011466798222889858, 0.021180769162518636, 0.03336365507649524, 0.07305021836821522, 0.016977885937584297, 0.07686277093099696, 0.023405514158574597, 0.04437025643086859, 0.032709082522030385, 0.03254396781059248, 0.02938947207959635, 0.03488891698153956, 0.0545711178066475, 0.014940116354929549, 0.04424184707126447, 0.02249486927342202, 0.008647223136254718, 0.05150822091049381, 0.02620648975217981, 0.06985297493104424, 0.017789505422115326, 0.04703867342323065, 0.059825265513999124, 0.026268161800024763, 0.02674001844466797, 0.04454354748928121, 0.009878760802426508, 0.030151629753943, 0.031050678475626876, 0.01280716696887144, 0.04142969261322703, 0.04030840331688523, 0.0996363806937422, 0.060043903067708015, 0.04760976581435118, 0.014449108059384992, 0.023342756454699805, 0.032817230825977664, 0.03354676792930279, 0.06956109630742244, 0.030421228680227484, 0.06179093396557229, 0.03970080913443651, 0.03305081989882248, 0.007931877592844623, 0.03634008964789765, 0.06228538243366139, 0.019329601799004843, 0.0365561385905104, 0.18266696030540125, 0.10705447157046624, 0.16071395043815884, 0.1616426206060818, 0.11945808492600918, 0.1638980167252677, 0.07887417264282703, 0.11126651162547724, 0.23902720532247, 0.09285292361996003, 0.129496481269598, 0.15253756275134428, 0.24994369383369172, 0.09298260523272411, 0.10163470025041274, 0.10045602385486875, 0.09642513229378633, 0.1577815120773656, 0.10095811262726784, 0.12931238114833832, 0.10840170963534287, 0.09766779454158885, 0.087955522484013, 0.09510197543672153, 0.17386345698365144, 0.1328563152679375, 0.09179499253098454, 0.15471659653953143, 0.16148692396070274, 0.07761942568634238, 0.07483471796980926, 0.33654655675802914, 0.13434485825044767, 0.19479867789362157, 0.10972431009369236, 0.1159619332424232, 0.1724800733583314, 0.09848926296191556, 0.18325292957680567, 0.11136622913181782, 0.16451156165982994, 0.24636531727654593, 0.17136990864362034, 0.2070478091814688, 0.13836266765637056, 0.12881836694266113, 0.1023018155246973, 0.10686841048300266, 0.16302615350910596, 0.1521888364638601, 0.15231489469962461, 0.1852161485169615, 0.11997371725738049, 0.10739679248737437, 0.2400250317794936, 0.09010037167796067, 0.13816813166652406, 0.1624325710747923, 0.13838305084833077, 0.1240497992507049, 0.17361113695161684, 0.11252498373921428, 0.18261544592678547, 0.20333171715693815, 0.12701501085289887, 0.08022567869297095, 0.1332141610660723, 0.08564819807985, 0.21663211631987775, 0.13880070272300923, 0.14406551021550382, 0.23330995067954063, 0.15732504799962044, 0.2566718299474035, 0.16733719860868795, 0.1669780093112162, 0.13285674953034946, 0.0874196155262845, 0.20035435977791036, 0.18590195743100985, 0.12127087265253067, 0.12685408948787621, 0.07946409777339015, 0.15756887277322157, 0.13754024250166758, 0.09499362017959356, 0.08289291164172546, 0.12150165598307337, 0.10299323592334986, 0.15190220970128263, 0.15795561059245042, 0.12204573250242642, 0.13668892532587051, 0.1061889390860285, 0.15878098058913434, 0.2015004325658083, 0.16757947632244655, 0.10146109706589154, 0.1618883724191359, 0.12112903169223241, 0.23249581722276552, 0.16251508093305997, 0.19693564251065254, 0.12431368151945726, 0.06797150588993515, 0.13817479488040718, 0.1391291543841362, 0.12187261107776846, 0.15757142406489166, 0.17961782749210084, 0.10159262429390635, 0.13016137773437159, 0.18196163672421659, 0.11030035918312413, 0.15039047439183506, 0.1369247298155512, 0.11170727440289088, 0.20779532407011303, 0.1091023241834981, 0.10756813615028347, 0.1413016878068447, 0.1887313806052719, 0.11501217420612063, 0.16760763552572044, 0.11231847839163882, 0.11237403005361557, 0.2186255164976631, 0.22631012914436205, 0.1749143177377326, 0.15936416786696228, 0.14545091587517942, 0.10145642874496323, 0.21370479411312512, 0.09061980380543641, 0.15649110132030078, 0.10149252680795533, 0.15542265293853624, 0.10055994827832494, 0.1065492954637323, 0.16771055571734905, 0.10525889827736787, 0.19955879103924545, 0.09250446874648333, 0.11658880460475173, 0.09734092386705534, 0.12310210296085902, 0.14634811558893748, 0.07750589999237231, 0.16576344519853592, 0.16075862518378667, 0.2022491009639842, 0.15353426284023694, 0.2199827086712633, 0.10104893453951393, 0.10362173576972314, 0.15400000927703722, 0.12384801650685923, 0.13907373164381298, 0.3033055875982557, 0.22191685917122023, 0.1395181313689266, 0.19755283796361514, 0.11313753122729914, 0.130613811314106, 0.10198330440159355, 0.10275485978594848, 0.15837999353451387, 0.09041676577180624, 0.234638549387455, 0.13739365179623875, 0.03802758588322571, 0.23029502960188047, 0.13744500332645007, 0.23367722811443464, 0.11738590683255877, 0.10882546153983899], [0.02217123012191483, 0.03209531706358705, 0.04158520605415106, 0.043595162486391406, 0.027686966649655784, 0.0439016567543149, 0.03581820800900459, 0.02721846366434225, 0.023713019443675876, 0.03871320480746882, 0.05449771049565502, 0.04603509638192398, 0.010218443066280867, 0.058719925183270655, 0.02566404341320906, 0.008632409020460077, 0.047109380164848905, 0.029715654041085924, 0.02020836910898132, 0.030588341677295308, 0.0149260588056807, 0.005103546011793826, 0.04988202013607536, 0.03494062474263566, 0.06788024971527712, 0.038129573089203665, 0.023264478958610977, 0.006696549460424909, 0.01773797068744898, 0.043238446449062655, 0.0392391440857734, 0.05767040114317622, 0.040838206852121015, 0.032816223201474974, 0.012691520852968097, 0.019074107919420515, 0.0035980137846698718, 0.026302348090601817, 0.10143447135175977, 0.013657653787439423, 0.04733738489449024, 0.03145270708150097, 0.03209121531939932, 0.02779985112803323, 0.017980438391012803, 0.09829317312687635, 0.007104867237753102, 0.05234876634286983, 0.02337724469336016, 0.07638085500470229, 0.08376533804195267, 0.06316957463111196, 0.04028590309566685, 0.06841396500489541, 0.005873090387987239, 0.04768516801829849, 0.0365345001087657, 0.053604446285005124, 0.008571000753103622, 0.031410067940929105, 0.039856353109436374, 0.06207652935492141, 0.05839086962597711, 0.012126965298583465, 0.04112995655408927, 0.06443324432309185, 0.0061771788251852346, 0.020577544745590006, 0.07191899192652532, 0.03060514898970723, 0.10108199276562248, 0.04134698597980397, 0.062114493389214785, 0.05231676323871527, 0.059682827442884445, 0.021961274423769543, 0.04533987957984209, 0.11343736906668969, 0.037592139427683184, 0.08629879102643047, 0.026252889673092535, 0.026284679038716213, 0.04695528146943875, 0.0200911810222481, 0.03654235754428165, 0.02028679588277425, 0.03777766107980694, 0.03063616482540965, 0.027562072101448263, 0.04400958114170602, 0.049849426706454585, 0.023520775205854858, 0.03925615156601582, 0.03522378079859274, 0.030098296901477233, 0.06755280907132796, 0.018962254814271415, 0.028131820993231874, 0.06030127140028136, 0.09595895159457411, 0.030791298286723237, 0.025839792464726737, 0.051833181508949826, 0.0337275466216462, 0.0670373531590615, 0.02626686749447669, 0.025423009114872133, 0.1138800520982061, 0.0542382217411484, 0.03430675768426486, 0.03964721843866365, 0.022783133001731973, 0.0144889906514436, 0.05920237036687987, 0.023917205897825103, 0.04805551582415189, 0.03961249440908432, 0.09554131329059601, 0.01809913112914988, 0.06002705504319497, 0.043891003754522116, 0.02278709564624088, 0.0274114950027849, 0.024993269138836434, 0.03142990491219929, 0.031497802518840344, 0.030486581780548607, 0.06721177058560507, 0.058387999422848225, 0.044299183280340264, 0.027524528758866445, 0.027491674093263488, 0.026779578732592717, 0.10157189504908663, 0.027378165362668887, 0.06201723896499191, 0.0156940654518881, 0.01631163070643587, 0.05217987219137805, 0.0427920687943697, 0.02466416947676667, 0.06988002133688756, 0.05422714804964406, 0.01503456334051277, 0.026448557120082632, 0.034093148075044155, 0.02662841130846313, 0.018997765944472382, 0.009110476805030234, 0.01907937165482768, 0.04478130955249071, 0.08441336612616267, 0.022045923363683478, 0.033669012798262496, 0.023155328119173646, 0.034790247811802795, 0.011769658935788487, 0.039167019205966165, 0.04954273227070059, 0.04834453781534519, 0.024669387411060076, 0.014973415460969721, 0.047240055831415315, 0.07692909772906985, 0.049633316695690155, 0.015091785894972938, 0.05006799640666161, 0.023872420890256763, 0.04126858804374933, 0.00968952671558197, 0.036626977646457295, 0.05849697893219335, 0.01837635170003133, 0.12482716968016964, 0.08491268647568566, 0.011217773326539567, 0.038785014168492386, 0.024000323044934442, 0.018204047910070846, 0.013226467683645231, 0.05217635737998145, 0.05884348641016653, 0.08957969104605061, 0.02333180489949882, 0.03307761185403381, 0.006615440776970769, 0.04245581058785319, 0.013090675863038217, 0.030174136760511568, 0.03303266230172344, 0.036102415794240575, 0.02836279770625489, 0.012147997339655246, 0.020591687111716186, 0.09600420988031796, 0.007594761887698301, 0.012129041615740528, 0.016555251919531395, 0.016785487333046537, 0.041962061010833294, 0.06942901268069233, 0.035008155940366645, 0.04815177958724754, 0.0203121476474085, 0.07316387976918902, 0.06019911116787365, 0.026692914543673396, 0.01751755876466632, 0.04501062724739313, 0.027091011039114425, 0.05406441499612161, 0.03131103914763246, 0.017580525118059347, 0.05712017709655421, 0.044787877771471224, 0.019891137024387717, 0.016521223388346176, 0.06242173404565879, 0.019579492675672685, 0.05859150564564126, 0.046677760646811554, 0.03554106377331274, 0.0007352580547116563, 0.02027605128075395, 0.032242647372186184, 0.035501471254974604, 0.03822794370353222, 0.06738113292625972, 0.06390798357980591, 0.12125732909355845, 0.0359758927619883, 0.01925426914489695, 0.02524558238552085, 0.089915253754173, 0.03191372412922127, 0.03344719630799123, 0.06546066847762891, 0.018922100808205347, 0.05812024950448956, 0.025621451770088503, 0.02927943066294704, 0.019135069201833436, 0.02431797412490206, 0.026804638727168952, 0.05095849219443543, 0.022313870057197552, 0.04830949826698218, 0.06683582147317273, 0.06285072424049888, 0.07631842299763646, 0.09701043660087244, 0.02975898528737681, 0.017664615962920443, 0.05487754761374422, 0.0611136881634593, 0.02223091575849269, 0.07320067672325031, 0.027874932724184225, 0.09852820408663579, 0.04368984526289361, 0.002583256606677813, 0.029425298728580986, 0.020178384646507244, 0.0667986852516021, 0.0470301103112953, 0.0341390102569546, 0.04709021833592227, 0.04575410485267639, 0.00782223990453141, 0.028989814953612428, 0.006999972085135856, 0.0861859235114285, 0.03101953032559582, 0.012430751363613775, 0.03487781954130956, 0.07398287153669766, 0.03208473530997123, 0.05299820238724351, 0.011128403479233384, 0.024982344725036194, 0.019570727699569294, 0.03361280634999275, 0.06317180022597313, 0.07583808127258505, 0.008568762435710855, 0.0027018823394817965, 0.04785471356340817, 0.0711850273822035, 0.05624191529516663, 0.04863707122525998, 0.03428253737677421, 0.05645668180659413, 0.030046860554388592, 0.01727747611169304, 0.021369693667760918, 0.046082088324640474, 0.028847214034093276, 0.029052616762263433, 0.01875570536191974, 0.12838904426566192, 0.045860085237239084, 0.006240371215556349, 0.02269120338106794, 0.0038112811577905503, 0.005628942886167871, 0.06269454583525658, 0.03619332930871418, 0.0427532124865268, 0.05635097622871399, 0.04011636772858245, 0.004411000517263476, 0.021103772401277508, 0.045638784433582, 0.017695051651181917, 0.039405184997511764, 0.032253123952874115, 0.027345454885757396, 0.06217416375875473, 0.04189385127808366, 0.026422089165342704, 0.04829629058284419, 0.023986750648223927, 0.017388207937723825, 0.053962719560201676, 0.039501095922397714, 0.039468119120491404, 0.028355886827089956, 0.06486655000065054, 0.01672309773441936, 0.016973051375576427, 0.011322096389319216, 0.01605244050733745, 0.03620750390525375, 0.023252265328275304, 0.019564315543643067, 0.017678610747680068, 0.05476703800793205, 0.022044038732669184, 0.04002696395452533, 0.05640749480309231, 0.04763797930042658, 0.018423155349280153, 0.005516616926927651, 0.024879943612696867, 0.05769627368343728, 0.0041595820886349034, 0.03750018096928086, 0.03384456677096231, 0.03693085276920881, 0.071114493667015, 0.01907034544274211, 0.02193592265913529, 0.12907645452235425, 0.12414912320673466, 0.09062538814863988, 0.07397461376552071, 0.1933266640241657, 0.15037488165710652, 0.14027973264455795, 0.18138291420681135, 0.07089388157640185, 0.1004437491563814, 0.18898903392255306, 0.11517237632402352, 0.12987002836806433, 0.16138722002506256, 0.20014135406485625, 0.10360851790755987, 0.1313160000635045, 0.07621961472822086, 0.18996387161314487, 0.12014245534581797, 0.09441401556666408, 0.07865309914840118, 0.09639631491154432, 0.09388617639030729, 0.1425644957593509, 0.12568588288766996, 0.10281182280076401, 0.08673439693770238, 0.20377128571271896, 0.16360776658569062, 0.09722125064581633, 0.09791683724948338, 0.13942893115537508, 0.11121111602655478, 0.1639569949890886, 0.1978657240314143, 0.09836238369877849, 0.13468355579035624, 0.18879847414791584, 0.08294477885855095, 0.09801173715719155, 0.17308806787644113, 0.1473352619047676, 0.11303350502359015, 0.13087774786565984, 0.21044298128357955, 0.09197247015046221, 0.13095778785645962, 0.0806759273899453, 0.09615371150097676, 0.16781832064901078, 0.10403113665857486, 0.16992095139409813, 0.22906291857361794, 0.14132023895425455, 0.16154668932514532, 0.0995669054931828, 0.20251655232693466, 0.09800303155290228, 0.13705743769449846, 0.08267810102552176, 0.09388572855719499, 0.1625312300665038, 0.20520804290260586, 0.14384917968085834, 0.1636051745819194, 0.10198389472705977, 0.09065974237663404, 0.18225097762686865, 0.13528580990220818, 0.14143747623477662, 0.15182537239577087, 0.20789452588983945, 0.19099339922623976, 0.17901270996247018, 0.14018787257373333, 0.13935157816324914, 0.24979392758437566, 0.13413836647357258, 0.1949139338518892, 0.1258165551615613, 0.12707211636006832, 0.17260619944759778, 0.09675825227584157, 0.08750451382781778, 0.11532413746629443, 0.09548867254384927, 0.14470243746680872, 0.2276111521891185, 0.07738142952855144, 0.2388530932366848, 0.15979306985224995, 0.11690710538199969, 0.09494287254554884, 0.10538755530225379, 0.17013296644602502, 0.1343644272003855, 0.11716573578970772, 0.1708665985081877, 0.1666883019996541, 0.14369040248649462, 0.1227806673518249, 0.21490824382219995, 0.09666835995657103, 0.12398996603276048, 0.12678926225219453, 0.2100119079862322, 0.2000852663602148, 0.10268875011908156, 0.08506092602120978, 0.14418733439275197, 0.12562534399330616, 0.09098948325429644, 0.1986421173704522, 0.14607694585408482, 0.11291028984955379, 0.15920860692858696, 0.16563645058444568, 0.1107295665091702, 0.17395174796027796, 0.09884241329772131, 0.0673621678724885, 0.16924439769770416, 0.19843460779104913, 0.10364758795393364, 0.17342939813222202, 0.08146538252809218, 0.10570996121636458, 0.20172791821616037, 0.0995281000754663, 0.1926163871373449, 0.08741768170148134, 0.16269177145191602, 0.16801086174590246, 0.09053799962358815, 0.11235577746161393, 0.17423135867076261, 0.07295764583562102, 0.12299277739865438, 0.13905222208372184, 0.14572074211069516, 0.261624918452331, 0.16601324108030113, 0.10660823980080229, 0.11475266170288835, 0.12847924871104105, 0.08801509785865035, 0.12072661971407277, 0.17301003634929657, 0.10922250630600111, 0.21279846131801605, 0.14981319036866936, 0.08659242027040039, 0.1261380993361984, 0.10296426247805357, 0.07529620320669242, 0.11207352046455656, 0.12062763502555233, 0.14719726145267487, 0.0832375870751483, 0.12515117015157426, 0.12835431684340748, 0.1608271300792694, 0.21415508352220058, 0.1548274013080767, 0.09492466066564832, 0.1317846913422857, 0.052808721483285935, 0.1078969067228692, 0.18685394206217357, 0.11955350052033152, 0.14888285100460052, 0.07416305651089974, 0.22642149031162262, 0.20464894361793995, 0.09562923107296228], [0.036795797159097025, 0.03593224599691374, 0.05536304620493736, 0.0700295026014958, 0.05931032528834684, 0.03809517475643328, 0.026994058562974845, 0.027630568515243273, 0.022351240373349616, 0.019052564432578425, 0.05520598231149571, 0.029998155310750008, 0.011874091412339891, 0.03651560969384653, 0.008994705160148442, 0.022156151377462914, 0.01288401784508356, 0.06116508040577173, 0.039663577917963266, 0.027667999899547015, 0.02694659503842039, 0.06691476223724228, 0.041647498961538076, 0.05164943761857493, 0.02820547596950616, 0.04570402218294995, 0.01594717428088188, 0.06897285394370556, 0.060249329544603825, 0.0041785407811403275, 0.022718047922743217, 0.00407382077537477, 0.06495915645999567, 0.04407530404361231, 0.06504970017288413, 0.04011121425511582, 0.020448127761483192, 0.015991175580503683, 0.029605921357870102, 0.03613688198051282, 0.02580416089455996, 0.03010544866057379, 0.01160033476272864, 0.02512794137666268, 0.011165149543168289, 0.027279462266181196, 0.012483395503035613, 0.05203286757958787, 0.022010386788419316, 0.02736865060536989, 0.021037104639357755, 0.01858658729387181, 0.007760212473970438, 0.010223463377250093, 0.02144730619953147, 0.032863795291632414, 0.030327475496700833, 0.03725664457306266, 0.04809990558507187, 0.049358632149440904, 0.03091643371486238, 0.0361593855944063, 0.04861484920339925, 0.046527444784130366, 0.03060445688398821, 0.042405263121638975, 0.034315039204167466, 0.09017454234084912, 0.04279722905318652, 0.02376854226791433, 0.05640527938625642, 0.04817492441673364, 0.011274966195092669, 0.07308846738721643, 0.03749116663155811, 0.048493686597794294, 0.027989350691703812, 0.0677458183573825, 0.04385664952652795, 0.043071275776518245, 0.02691119077748486, 0.02558428840711713, 0.05010465765371919, 0.03895998799375125, 0.0335654378203409, 0.016721681292567934, 0.05900925251522234, 0.025442386378667185, 0.02989625631432448, 0.13469363882073335, 0.01790540768498821, 0.03689160630373018, 0.04946701115529452, 0.036004689788179736, 0.03609447693452239, 0.03379961721865194, 0.056251329968550375, 0.03896883609039443, 0.0022720526695983218, 0.031633787721927674, 0.0502648970910481, 0.024684907203274112, 0.03557406093126961, 0.014378867810592055, 0.12401018637631621, 0.03615441871806979, 0.057772147469222546, 0.04670425404661468, 0.01182159485428461, 0.012869100252698575, 0.02722518625003951, 0.02529894407572491, 0.045694281812757254, 0.06001596778099026, 0.06116118561476469, 0.034737159231943746, 0.1101044321964894, 0.043833365597363026, 0.015261287335306406, 0.013026220125279256, 0.022179263976535628, 0.02417703900885369, 0.03223047445395163, 0.03622581756540707, 0.04428228436570082, 0.050994122068264654, 0.05428682181185909, 0.06386086610811097, 0.029444575908460786, 0.013354698927806956, 0.014044957335240074, 0.005417463876905718, 0.02441107082579817, 0.08110539255929844, 0.06757887160139424, 0.045741331430950334, 0.03265455884060689, 0.017381095194390843, 0.049114888800042014, 0.04320094042590686, 0.032993497260447056, 0.02134592119338257, 0.04885426689205425, 0.060942297003098896, 0.051505028403231075, 0.038343827306692085, 0.08331225985395056, 0.01904720570226865, 0.0014477468066615984, 0.041216866711952856, 0.011545415834656783, 0.025636023309613978, 0.048510989240769825, 0.02588773944548198, 0.08302564666207347, 0.03477835648560098, 0.019107037223875523, 0.020235169545880387, 0.037110661156475544, 0.018475818148415004, 0.05294903234711715, 0.017304042454010675, 0.07281576416322164, 0.028090243759964193, 0.08515918467726026, 0.02594133183759238, 0.0680690792256168, 0.02147227798455528, 0.05117109078647835, 0.02562006755865046, 0.030358779709786177, 0.004379599612937974, 0.036264500846820216, 0.06973980207528387, 0.017693238266344582, 0.030704771501145194, 0.021352092469377176, 0.04995758518842714, 0.03802891581186226, 0.08734055262591157, 0.04622491994606597, 0.05154353865821447, 0.0483029130846262, 0.02952839873198952, 0.07190527194844824, 0.02009836840443313, 0.027313667216471264, 0.05700353014149836, 0.027421221802277223, 0.03234562523929136, 0.03352662222459912, 0.031772117263504436, 0.021338009475065128, 0.025511084656630243, 0.06387813482433558, 0.03720262300755296, 0.014805829185726387, 0.031543488281645944, 0.04258432172771011, 0.05637091158756188, 0.05163194498579417, 0.06356999171631676, 0.020597239224506275, 0.030136776622384787, 0.04184969900442021, 0.04068056620391352, 0.05612001308639135, 0.04126635566353798, 0.01575038385843592, 0.036071196398032565, 0.04366180819592305, 0.017498110254694308, 0.021522072276898792, 0.045438606425055435, 0.044696960864322524, 0.0005661482563092639, 0.013539011939428747, 0.013711298766013767, 0.06738148576446942, 0.05317724063726408, 0.009109444583633115, 0.0493860924616456, 0.01948070476230766, 0.03401617506252868, 0.03605045697518757, 0.04101115185767412, 0.010981712689889329, 0.04876710567623377, 0.03081945070464696, 0.029632190841117075, 0.023054711553933363, 0.019545548961364796, 0.030365727908377136, 0.01607552935768451, 0.1985326832426446, 0.013584198130826865, 0.039987534284591675, 0.08428976418716566, 0.01821738960487502, 0.030430307478777, 0.021447399498096535, 0.03543077129870653, 0.023041296916614686, 0.050110381096601486, 0.025499797226595025, 0.08923435064830951, 0.059946316161326, 0.025755815274481262, 0.06844510976225138, 0.021936709759756923, 0.028004164807498455, 0.013689667069619256, 0.031123061198741198, 0.062316160782107284, 0.05558432665254388, 0.02001188911630639, 0.0061730605417064256, 0.04376531532034278, 0.027048427877681594, 0.09237106197646686, 0.005636591672165585, 0.015495385309415204, 0.057613092075501166, 0.03616618451529315, 0.04641880114961948, 0.0572317825364215, 0.0379996777379087, 0.05375040934554168, 0.07542786614171096, 0.02579408634587058, 0.04316385170178754, 0.01969802426174283, 0.040013464500329325, 0.020935763737985065, 0.02746072780740048, 0.04005128264959369, 0.039287791653935394, 0.010194732508222972, 0.019356885692104697, 0.08833547495305538, 0.035064447205513716, 0.01152643805835396, 0.07564127219042607, 0.04552558443642088, 0.05186869263915079, 0.03080845165199467, 0.02964034683204123, 0.013191835256293416, 0.00660315844496446, 0.029031792522541115, 0.08980796379702431, 0.030394053352730613, 0.029399694209652286, 0.017517041381714598, 0.01495423327599253, 0.022079124082145945, 0.08659836423716374, 0.06395533853875739, 0.024794393917545676, 0.049841609983039756, 0.024669750427295054, 0.026388442310105478, 0.020940011367201805, 0.05884092154779604, 0.03688199485519102, 0.03944762057757803, 0.05419779462473733, 0.039234852351780446, 0.018298187858558128, 0.026902592042461038, 0.12317648396960326, 0.028723584953695536, 0.0211603045463562, 0.021971681454618062, 0.051284127935234985, 0.048305735790303776, 0.025548661925962994, 0.03063791205308267, 0.05783470839794193, 0.019657653124470795, 0.013447357125447264, 0.03572105197235942, 0.07088127439575535, 0.052933483717164824, 0.022984771556886177, 0.0162135179354144, 0.04562909156084061, 0.10659468945647989, 0.0326811133085617, 0.030204080510884523, 0.025091251291866814, 0.014586318018180984, 0.047249219446842156, 0.045991415690098486, 0.04454086049060736, 0.059164345264434814, 0.022522528057119677, 0.012248652072490325, 0.025884533367518867, 0.02509183992099549, 0.028501035645604134, 0.06644718375589166, 0.03351217960672719, 0.026915109317217554, 0.03524806895958526, 0.019114385758127485, 0.06011622811534575, 0.018569174388955747, 0.022585852337735038, 0.05622630559706262, 0.024432098626026084, 0.029626694707466022, 0.1397627703845501, 0.13999443581061705, 0.19661761314741202, 0.14055178447493485, 0.16962459443935327, 0.173308523904, 0.10055471677333117, 0.14851785344736917, 0.11662274492638451, 0.09827213854129825, 0.12098766570644719, 0.10101379999624831, 0.08252838227365698, 0.10768890181290251, 0.11794869734772614, 0.11765897646546364, 0.14648346975445747, 0.19233242023204053, 0.10238232370465994, 0.12072598189115524, 0.09840579636927162, 0.12332239614001342, 0.13331717625260353, 0.11623492145112582, 0.09380901338798658, 0.16204227773206575, 0.06567129931811776, 0.2410005751465048, 0.07554227393120527, 0.09948716405779123, 0.09573153379772391, 0.25510112994483536, 0.12669069825538568, 0.20626183492796762, 0.1402511391788721, 0.09097430442592927, 0.07448531993265663, 0.1275815333106688, 0.12788487917610578, 0.10210124057318483, 0.13205139631671564, 0.16441472114196845, 0.1461748584572758, 0.10469296614506415, 0.15872261300683022, 0.15882626601627894, 0.08150802845401423, 0.15234443811433657, 0.1335698626935482, 0.12201073366616454, 0.0936244111508131, 0.11737000197172165, 0.11275412501501185, 0.10498453942792756, 0.15137109320078576, 0.1306964840207781, 0.10757243127695151, 0.09224539729101316, 0.24256158566900662, 0.187139985284635, 0.18328986902322086, 0.14028441453618662, 0.10979650621967656, 0.17307957261800766, 0.13204647015248025, 0.061056243388780525, 0.10333251021802425, 0.17944499105215073, 0.10649938242776052, 0.2159700289900814, 0.15663405507802963, 0.08888300521565334, 0.24556692583220346, 0.10303711678300585, 0.18463351763784885, 0.11968766046421868, 0.11707060518009321, 0.22979551926255226, 0.1623221327151571, 0.1246186965810401, 0.11925251595675945, 0.13879389023142202, 0.11768535790698868, 0.1505037625985486, 0.1943204735538789, 0.08688327430614404, 0.1991627708609615, 0.1462963976498161, 0.10184419793742043, 0.3018737701433045, 0.1414261039878641, 0.1278002658592803, 0.1495690941810608, 0.10007520286100251, 0.1621194543050868, 0.17759202048182487, 0.13082440144249372, 0.14356699053730282, 0.1760024164936372, 0.22936828647341045, 0.10099166618394, 0.0709647342030491, 0.07969535607844591, 0.1409464475831815, 0.39728616178035736, 0.10626781878194638, 0.2549005278519222, 0.11940671982509748, 0.11072625525827919, 0.11388370261660644, 0.10939984821847507, 0.15391635947993823, 0.1745687805648361, 0.11477438839418547, 0.1738651804625988, 0.10442792358142988, 0.13866992188351496, 0.15970416819410665, 0.14451791665383748, 0.14656490752739565, 0.12716918757983617, 0.12259085396570818, 0.09201506179358278, 0.10295504797250032, 0.17066005244851112, 0.13468515713300022, 0.18405292236379214, 0.12132032428468977, 0.065075565927795, 0.08431065628038985, 0.09581499360501766, 0.10939197721225874, 0.0777315196714231, 0.16287625155278615, 0.23344324209860393, 0.11446782627276011, 0.102051252898361, 0.08374496842069284, 0.2025714593806437, 0.10272294149867126, 0.09280048643371888, 0.09569083526730537, 0.14221017834331307, 0.15098081342875957, 0.1274808794260025, 0.1584597078285047, 0.223275272707854, 0.11645900085568428, 0.09382260444441012, 0.07934210396238736, 0.11675440786140305, 0.13770504508699688, 0.11605436328266348, 0.1132268603625042, 0.13694409520498343, 0.09631733343537364, 0.08650554743196283, 0.17495158288095677, 0.1482087264635733, 0.1302207631192037, 0.12077001881386552, 0.07891283556818962, 0.07624567725828715, 0.13142033160797187, 0.1802341951323407, 0.09376617068690912, 0.14294005132147244, 0.08530821132340602, 0.16335822854723248, 0.12515847118837492, 0.09694520224417959, 0.11620984279683658, 0.13713165585483822, 0.1832231961722885, 0.1057506665321333, 0.16438810899853706], [0.058310660001422675, 0.03351248834016068, 0.008881260890380611, 0.02696825048354055, 0.018834898880283748, 0.025980004940980246, 0.02385276203442897, 0.033697653761399646, 0.04621489459116544, 0.03131877105416996, 0.02570578519121877, 0.03322632637407098, 0.0570367444306612, 0.08532898806567703, 0.005250797864781427, 0.07661029483590807, 0.049652417456465106, 0.011142126001816775, 0.0429474431356149, 0.06834817424948726, 0.018304118254621114, 0.039462483887161524, 0.028389060404151678, 0.011423237971030176, 0.02716711552680603, 0.065379495333348, 0.08872628398239613, 0.04305023440558996, 0.0196584283507296, 0.034957737395805974, 0.054219816478767564, 0.04526166824091758, 0.08131482239280428, 0.025846735574305058, 0.009067745214062077, 0.05106461846402713, 0.03172039593170796, 0.06109946606946843, 0.05085406904774053, 0.011046316009014845, 0.00799181598371693, 0.010682063992135227, 0.03359855372192604, 0.035993164870887995, 0.027941502098526274, 0.038229772355407476, 0.014086427699242319, 0.016206708836502264, 0.0353571909612843, 0.035605259971427064, 0.03079390725386994, 0.043961551040410995, 0.03652656124904752, 0.02506786897512419, 0.010364954892013754, 0.03460656498957958, 0.04348177249942507, 0.025800393328868916, 0.022104262108249322, 0.02957989275455475, 0.017119901620649865, 0.01746793071340237, 0.06047932577452489, 0.02754988900518843, 0.08118801776851926, 0.00831593943959368, 0.06127047725021839, 0.005868005616191242, 0.040321163167910914, 0.012828014109150639, 0.06591433020574705, 0.032697452431810756, 0.0546037044509181, 0.038381597958505154, 0.01841388486458787, 0.02262823193866227, 0.031145758195114986, 0.11582207360437938, 0.020912244017901163, 0.014446273479344589, 0.05183798892955695, 0.08967239250029836, 0.04322992404922843, 0.006183630845043808, 0.03573298740333744, 0.02236367792024144, 0.019335483001278977, 0.0536658570968679, 0.010818333331761616, 0.023420547101912752, 0.03705763364476817, 0.0021436755404075874, 0.04419505868905357, 0.05946349099810634, 0.026628121234742657, 0.04633551097608038, 0.027616320976189206, 0.07267084943928889, 0.037189944580729516, 0.023430908331647515, 0.05183170908795936, 0.028703161049634218, 0.04223232150876096, 0.03610081445159657, 0.01631825660089297, 0.016232016496360302, 0.0250699469886188, 0.04780572333506175, 0.041837787322167835, 0.05267521971836686, 0.03238469189299004, 0.10978536467467036, 0.041110272253198285, 0.028111870367346064, 0.03302260980542217, 0.040686150547116995, 0.03287725403372731, 0.031935284579438825, 0.036998977685081105, 0.035803884134760926, 0.059470045646386485, 0.0881322401442698, 0.056767657798315795, 0.04087027780977743, 0.029767697677016258, 0.1267535305981125, 0.056031596580786366, 0.002191845589550212, 0.04184939366366182, 0.04138287030426519, 0.04284819721111229, 0.04600512549015028, 0.01613573237721409, 0.04299597196014864, 0.01645293732040695, 0.032236157184732814, 0.03552423271217516, 0.02005184125820441, 0.030330148924674307, 0.017300071327814033, 0.05769691829170499, 0.05502833505826337, 0.07053663967443363, 0.035275149292179515, 0.007751038680518312, 0.012758199641081904, 0.0244941913655826, 0.09847425376730305, 0.05712677924228566, 0.04575039326612439, 0.08395091736955301, 0.06111476703413895, 0.023467581453067914, 0.03224438102915883, 0.005771404281923813, 0.030005239216344695, 0.016997161421126554, 0.0322732119821012, 0.04190602419631822, 0.024672322075015733, 0.006775025003922305, 0.01429721460278545, 0.006903943688874798, 0.053425306254731755, 0.01720376345994217, 0.02169539386938725, 0.026952718816963688, 0.006430152795344059, 0.02608065543297146, 0.0019741439900826663, 0.03824851688529764, 0.01655245805159211, 0.05943788308650255, 0.06396483802901846, 0.022859507207093493, 0.03516411721440298, 0.07818280652697597, 0.0903949440856065, 0.014859311315896255, 0.022680392621883323, 0.04717779006542904, 0.04202863208151289, 0.05468445011813726, 0.03450150401996715, 0.04506351565942168, 0.03326627512329391, 0.044887578314436336, 0.10428008437156677, 0.08073361643723079, 0.06722262036055326, 0.04454102333901184, 0.045512559956737926, 0.038058761174657514, 0.027834931388497353, 0.015209243699376072, 0.02002692375598209, 0.028450372828436748, 0.034833707979747226, 0.048208335481051884, 0.015010427849899446, 0.0682391675987414, 0.04146650992333889, 0.079731053805777, 0.02025924057566694, 0.019403448461421897, 0.11020697919385773, 0.02698485253910933, 0.05601261456363967, 0.03850225505552121, 0.02587906607160611, 0.028756147849240472, 0.036735030955501964, 0.0062241826422645575, 0.04043596450771604, 0.05731595480548484, 0.028048035489129167, 0.026365908162136163, 0.006318054569419473, 0.04509826683040176, 0.005397154899713184, 0.029461763200483153, 0.02148141785125647, 0.028457622975111008, 0.025674709983702217, 0.014343760408727186, 0.05476880898433072, 0.04113003119294133, 0.025426004846979464, 0.034985462336667945, 0.046518861316144466, 0.02375895287176328, 0.043916146869638135, 0.010832778494139867, 0.0180681458275233, 0.04867072995486004, 0.04240410961210728, 0.033357025789363046, 0.0428291168063879, 0.03839298716879316, 0.03484484613207834, 0.041575431757207425, 0.024677485726507645, 0.022226077803809727, 0.017922087772084132, 0.024682040392820324, 0.013339571837734963, 0.008565155173917966, 0.03182569778125201, 0.041986328815775256, 0.027966428082436323, 0.022715303248592784, 0.050828223648880205, 0.05282332694956234, 0.08161115899149861, 0.05384384361760957, 0.05670287127473524, 0.02960702058460031, 0.12518116139939853, 0.015272338974422641, 0.05694118634398494, 0.01529296304631446, 0.0330469420711909, 0.022470723604783416, 0.04344618673037205, 0.04418238365490522, 0.05177857640332409, 0.039815895458949466, 0.013337996788322926, 0.024113977660558054, 0.049558654094913175, 0.02238210693134793, 0.03234174741165979, 0.01734621510175722, 0.03690471899296556, 0.041592456200825315, 0.02386004780419171, 0.013699689031844693, 0.014711748609053237, 0.012569678016006947, 0.022596245797883188, 0.049234280429248295, 0.058329034729727676, 0.04778688720294407, 0.01599054115026125, 0.03276571644736188, 0.025348288838618567, 0.03080759330519608, 0.04245764263240354, 0.04189440428412386, 0.06954749168029853, 0.08752139577908175, 0.06491222897810595, 0.014897053129971027, 0.003764399901098971, 0.044576286803931, 0.03170809409181986, 0.02567299159376749, 0.04189616847517235, 0.014902372844517231, 0.010573087875465197, 0.03153098288125225, 0.03014468155535204, 0.04281707959515708, 0.05027839654524412, 0.05749738828412124, 0.022902008944324086, 0.026331988196553927, 0.01587989244477025, 0.0275550255152796, 0.0162151481157967, 0.03953488018097622, 0.0375820869313819, 0.05403095304167696, 0.013233079159233187, 0.020021419140643308, 0.01719113761958267, 0.024980879089395915, 0.03868424493287291, 0.045593655069491694, 0.03671309391834906, 0.03467336676216551, 0.044397716743073294, 0.0306288095058075, 0.03627582220360637, 0.04625984075080071, 0.06527423419590507, 0.01767383555748633, 0.033929736486503055, 0.026737787760794163, 0.013938086373465402, 0.01997176225164107, 0.02243861193502588, 0.03848045372537204, 0.005597123834637127, 0.02373955525191767, 0.08065348145152841, 0.05156875980485763, 0.023292875649141412, 0.006332545532911483, 0.06098750779139144, 0.01568723769326295, 0.05540953942441514, 0.07412288723779575, 0.05184813642076083, 0.014798714746055859, 0.018596300522663763, 0.03541907674766012, 0.026112354892705168, 0.04141224408522248, 0.042576230197612724, 0.07574776826160294, 0.017372208081984093, 0.18069065921008587, 0.22389545371489866, 0.10368474453155484, 0.11239511213664498, 0.16085098737052508, 0.1990269688623292, 0.13026243874004909, 0.12438981314854962, 0.14061091201645987, 0.16399191240114824, 0.21213150210678577, 0.21173339204064437, 0.15573553900633538, 0.23835681272404535, 0.10387434078646557, 0.11020552712891783, 0.17724797608596937, 0.07608892888362918, 0.11656691506505013, 0.18773633614182472, 0.10815050240073885, 0.10523704266441719, 0.09389345707105738, 0.09490748015897614, 0.3186357835573809, 0.13773614913225174, 0.16619259145643028, 0.08961959569049732, 0.10832004116049834, 0.14694715344480105, 0.11792498933417456, 0.15810644892709597, 0.20185936401997293, 0.06904247163661889, 0.06668176009718861, 0.16667811040367397, 0.10042298598481075, 0.11623363223459039, 0.22808563815695898, 0.07119221985340118, 0.13356087888990129, 0.15828015389186995, 0.1416803239179509, 0.13029287782098564, 0.13347121727253708, 0.09895612219614641, 0.06631295595850263, 0.05865315733743565, 0.1179075509841953, 0.12672957831195422, 0.143515801855496, 0.09954569448849984, 0.1262306243713413, 0.1254239547997713, 0.09109313626374517, 0.12188510969281197, 0.1913295861865793, 0.08580886160156556, 0.10559140757790633, 0.13145446191940988, 0.12634581247610704, 0.1167287320962974, 0.12487058235066277, 0.08008986990898848, 0.15098830445536546, 0.09977578571332352, 0.12265764895294394, 0.10785935659493719, 0.12519385000424726, 0.12774858863226005, 0.12807579178895268, 0.1247508344905717, 0.211568005915199, 0.09801454629216876, 0.13464392934526714, 0.1964979331408228, 0.09310191883040325, 0.20150934851595334, 0.1610620796148266, 0.16109489356832846, 0.13588343640523298, 0.24752821773290634, 0.1145374168242727, 0.14234869448201998, 0.09346112169857536, 0.06842317272509847, 0.137905389336603, 0.189444398773568, 0.10574351477303676, 0.11352376014526401, 0.19032734925193445, 0.15646526270679065, 0.09320848275508199, 0.1677011919340917, 0.09580378420650959, 0.1914926381515605, 0.12647090719214507, 0.1754705264632191, 0.10924376480813537, 0.09997165841715676, 0.20575575636965887, 0.08599426451006106, 0.11388911732605525, 0.11031234211155347, 0.09946774438555751, 0.12408463523856231, 0.1490576687668051, 0.0876577745324799, 0.12576004676520824, 0.17260330888841832, 0.07584754005074501, 0.21907788222389563, 0.12703817603843554, 0.23911169650299208, 0.1696845633643014, 0.10997960210910865, 0.08731662069580384, 0.15358645575387136, 0.15644323746008532, 0.10526611788996629, 0.19821696089846746, 0.13456717346395763, 0.1876482487257038, 0.13460328509765013, 0.08394888854984726, 0.15077077969908714, 0.1813158206641674, 0.0907805555367044, 0.09533655856336866, 0.12270628634308066, 0.0717485642858914, 0.14203704334795475, 0.09353862396840538, 0.12237327492662839, 0.15031678548880986, 0.11897667790097849, 0.1009610438985484, 0.19040938413568906, 0.0944065720375095, 0.05757444950618914, 0.10378305068505661, 0.1542629280260631, 0.11884968328688826, 0.1461664717644453, 0.1758484026151044, 0.15958575026265212, 0.15648133041603224, 0.20889465936592647, 0.15854878590575286, 0.16470284068158694, 0.1203705652483872, 0.1707458599869694, 0.15243921588574136, 0.1480647549033165, 0.12564853632024356, 0.10235989812229361, 0.13429467380046844, 0.2056273775441306, 0.14905951438205584, 0.12501653523317405, 0.05905231234750577, 0.12606016280395643, 0.051636073871382644, 0.19606586918234825, 0.06792972170348678, 0.06554207232381616, 0.09375174503241267, 0.15326135605573654, 0.1275127570011786, 0.13793399637298925, 0.09980139362492732, 0.14148903132549354, 0.14452129575823033, 0.1980194936373404, 0.15234967640468053, 0.0969262168343578], [0.04769408396844353, 0.03762063789846642, 0.04014729196205735, 0.05721929749207837, 0.02623644537691559, 0.002500929104696427, 0.030689663918954984, 0.03540556372276374, 0.029490227744515454, 0.04184627918792622, 0.011838872900365718, 0.038215624900268655, 0.01347417537389057, 0.08297237487775938, 0.001778660701737473, 0.05682249360584787, 0.01613542534011815, 0.018271606249202575, 0.020922992012596557, 0.021559317064072405, 0.07864144191678081, 0.009881869340980691, 0.03947694346840892, 0.011940872828875269, 0.021366820071956942, 0.04715373260634286, 0.06076253950595856, 0.02845109546823161, 0.00933527121586459, 0.021887599091444696, 0.16676748703633035, 0.047391603235155344, 0.028121804120019078, 0.05603304525305118, 0.038739942479878664, 0.029773353266396692, 0.017655431991443038, 0.05600139159443123, 0.047209596394428184, 0.026212123289172138, 0.03404972183385065, 0.029310449891324555, 0.04117381366501961, 0.011643239380126553, 0.07265071730528559, 0.04637670822973762, 0.023778107915339724, 0.00929490092676133, 0.019230077675144588, 0.0353178800349789, 0.10219533980957099, 0.024255118033449565, 0.011828147806227207, 0.06834085964198623, 0.053392397306327305, 0.017121328240526573, 0.023499034943857362, 0.08524305160556521, 0.019876336479293447, 0.031442729224051745, 0.1091554941875594, 0.019267100242099593, 0.03336123609915376, 0.019882137953702892, 0.03940040132563029, 0.02728019847667643, 0.05402214226445981, 0.06396188640168735, 0.04741255300385611, 0.014670167983110462, 0.014451708544843962, 0.07709563057869673, 0.047291498963854144, 0.017540718861190335, 0.021301127704126493, 0.07107054495385715, 0.0689728268023048, 0.023656059821535434, 0.06541215322379555, 0.04006838851741382, 0.05506636694605861, 0.03778472462935107, 0.03158850229478308, 0.027915144405726875, 0.04426428283165608, 0.05509199521371296, 0.09109772994582142, 0.08255021753055708, 0.024466032162308693, 0.024549888912588358, 0.07204653615398066, 0.06619702146521636, 0.060353640733020644, 0.025944264805210487, 0.0360776560514101, 0.023738171040479625, 0.01644065583656941, 0.031044880393892527, 0.0469811132975987, 0.0980123139119574, 0.031146877777895758, 0.020264869023646628, 0.009240619821607001, 0.032516266618456156, 0.008518740834136094, 0.030232399169887816, 0.03628477547317743, 0.04767218764339175, 0.0750647277704307, 0.03498096025681921, 0.034971844138843675, 0.04123640512781484, 0.049744460731744766, 0.030727295471089225, 0.04530915551419769, 0.023301345462511693, 0.04560515623805778, 0.024380514697570885, 0.01234546460078231, 0.03398551885038614, 0.0051472920126148635, 0.03868289804086089, 0.02782239206135273, 0.03156114037015608, 0.024190416326746345, 0.013430088409222662, 0.006314172925028417, 0.040728732012212276, 0.008310460269318094, 0.03995125301714454, 0.04242838420239942, 0.007470551811690841, 0.05726690350898674, 0.018505310673000555, 0.03493378171697259, 0.028191747509741356, 0.0025538050062355717, 0.08014170998441321, 0.012296871315421802, 0.01669113364602838, 0.01279741557248469, 0.09643549352352108, 0.030925668576466184, 0.10390887821891479, 0.10008708400917904, 0.07884327215807778, 0.03241084263260875, 0.05026431694360716, 0.02890675887465477, 0.06541338815752949, 0.034847231182668886, 0.04345126895766173, 0.10652561459158148, 0.057544023995952945, 0.03154725075832435, 0.059143765297319205, 0.041407100789781125, 0.024821754145835127, 0.015056227267320667, 0.01034194661770016, 0.020765230924423252, 0.06498916127852031, 0.025850628668974553, 0.06783562246710062, 0.04188003969777908, 0.022061514402074472, 0.02232284877183182, 0.0367374736815691, 0.06870291914258685, 0.006955148061803941, 0.0557992899391268, 0.023711321409791708, 0.05159885283293469, 0.02203649003058672, 0.05217495959784303, 0.03158456679167492, 0.013669321197085083, 0.04633023875898548, 0.03216204758999603, 0.06465418211051396, 0.02400182600000075, 0.045488760340958834, 0.034309180054281435, 0.07257979682513646, 0.026548810669087937, 0.05595200103042381, 0.024694891846073524, 0.0224600875683661, 0.051650407923651595, 0.0677217710763216, 0.024403167589168464, 0.031365915667265654, 0.07478872686624527, 0.02933219015332205, 0.07936790864914656, 0.0248849478084594, 0.017013858471597944, 0.032693815484110794, 0.05623707394780857, 0.044564816169440746, 0.02026899451656001, 0.046386764118713994, 0.034213343768247535, 0.04806858440861106, 0.04214977093839219, 0.011383895662480166, 0.07797447592020035, 0.01795390767178365, 0.04595580956499491, 0.04719123523682356, 0.01290028402581811, 0.13989372764314922, 0.029980635536568503, 0.023186545819044113, 0.06231945167694773, 0.035641741406704695, 0.012901865860580333, 0.0192456839805735, 0.01436638446258647, 0.01662144809961319, 0.06573245567934853, 0.04114403954840132, 0.03166323953441211, 0.029986874666064978, 0.01188592760757144, 0.05897077957966498, 0.06774065470589058, 0.04634806387392538, 0.02199710955444191, 0.029494041111320257, 0.1377210042306355, 0.01836131706035563, 0.11350782814302615, 0.08093943646443741, 0.019663305321176137, 0.04345298565125891, 0.027616069918232303, 0.06142447755805083, 0.024745066118027483, 0.032108830088483434, 0.02587977853337569, 0.0674884771662099, 0.0129105680721945, 0.04196871065401605, 0.042214693168976476, 0.04915644567725914, 0.03442504669406584, 0.05306550966841834, 0.014281364024749823, 0.009421141518812095, 0.024175283299492936, 0.06982229157750096, 0.062248537982148786, 0.020908834379432455, 0.04855942307040095, 0.027048911333882382, 0.05244118620508483, 0.00916919722554407, 0.020877898271594728, 0.07492446779672589, 0.051342200354806015, 0.05710236555231469, 0.04287314015839781, 0.06521865539252758, 0.02441488758527807, 0.04138516035995313, 0.050790717625724416, 0.01861123677476176, 0.07309534094695534, 0.01622080709785223, 0.027538155438378453, 0.0437336786250983, 0.041116083905633004, 0.009253266018017061, 0.0453375148853021, 0.06933771579393319, 0.034147122143102546, 0.02243821499203997, 0.040000708041978736, 0.05583687060113464, 0.03000811281214867, 0.007085418727781091, 0.022342963942459652, 0.04527100149009909, 0.021975079218723943, 0.044834462593176534, 0.057746539557618756, 0.10654122768236057, 0.02314179643456425, 0.041963597892650535, 0.0261635215221239, 0.015731121945594038, 0.020871116314083338, 0.011574935500643082, 0.06726603303104639, 0.05365710738780243, 0.014352661091834307, 0.03205983986013702, 0.02692328905686736, 0.020810160120683055, 0.024874615416462933, 0.04377732878284795, 0.04352429968171886, 0.03133149019309452, 0.03912925533950329, 0.045381660373615365, 0.01630444671692593, 0.038678284002734084, 0.04738369830218809, 0.04111213143914938, 0.01836261645491634, 0.011580318827847285, 0.03125276995290603, 0.05451059587565916, 0.0517650192736515, 0.04015045054256916, 0.013837298478132911, 0.06530535859721047, 0.043776321158345254, 0.03780400859458106, 0.03147229638748935, 0.034498050276722224, 0.048799817849482806, 0.062706786606993, 0.011907959639626955, 0.048154554795473814, 0.03334616583638957, 0.032453821040689945, 0.016855546073721986, 0.08043177691953522, 0.027136939378189187, 0.01566908348883901, 0.09276719750570399, 0.03029350803366729, 0.02492206197764192, 0.0578210698440671, 0.013552583487970489, 0.05635539349168539, 0.04185577189283712, 0.010265169532171317, 0.02011977957694658, 0.03400643129966088, 0.023128232519541467, 0.006497831998525986, 0.03963171730616263, 0.06164185982197523, 0.02589745776328657, 0.01597402730424489, 0.035311311815998385, 0.03825136333970087, 0.04753480805084109, 0.04272311606577464, 0.14081639956150735, 0.16866993638021605, 0.11456584744155407, 0.10706245114228555, 0.07543649710714817, 0.09686408338270017, 0.11442046452845846, 0.14369315733867033, 0.08727723852332149, 0.11290380305477551, 0.1047969109245709, 0.14429657853075437, 0.11275985185056925, 0.18882375636271068, 0.05619061465508171, 0.11708908847400121, 0.12172051066798822, 0.12094079250735895, 0.11167591929967914, 0.10903115264539208, 0.22766483787979397, 0.08129358424672059, 0.18417596790407384, 0.12579945607909135, 0.12290836764233452, 0.17731897799032076, 0.1340221469955785, 0.07068602594413928, 0.144232891233904, 0.2086743933281728, 0.31322373396583963, 0.13062728701957635, 0.16847069135734014, 0.10881771266992603, 0.10500898025929928, 0.26863383235675947, 0.10302119835146836, 0.10890436159180743, 0.1556923027549471, 0.13321520601000103, 0.10958945804408618, 0.15597131635461534, 0.087011605634221, 0.11351516310657774, 0.2136295581502574, 0.13111409518335546, 0.08925181613968951, 0.11689918009298188, 0.16092365847102233, 0.11883566475340299, 0.18670066100146088, 0.12044531266604151, 0.15546105802059174, 0.20327512733638287, 0.2060119711927005, 0.08123491132365805, 0.1648275689887149, 0.15602188078420504, 0.15330767285610947, 0.14561798476747104, 0.1508863749248641, 0.15954532314624104, 0.09191227052360773, 0.1221438350954226, 0.12309474764125687, 0.09262091892638377, 0.15119605830737523, 0.09375585016927548, 0.17194374570889132, 0.0857751044843878, 0.1230891158006021, 0.14912843996925013, 0.15569669966186794, 0.09749730583280325, 0.09608452807047538, 0.22008007844643934, 0.26772280409932137, 0.157444850142513, 0.1510935995195593, 0.1170066057571343, 0.1321473547390529, 0.18094709116433347, 0.22730870198990616, 0.14366818724998406, 0.13945832529238292, 0.16957449141357625, 0.13008730885173592, 0.1660192257591656, 0.08261619827577046, 0.14148650717522415, 0.1501842811703682, 0.13693071449441568, 0.15520009345241956, 0.1393623532993453, 0.1432422843894788, 0.11054695237960134, 0.16272146414433206, 0.1175368537328073, 0.1411351074597665, 0.1494849965508495, 0.17074808558183058, 0.12246441575033323, 0.10448462875293833, 0.14166376766349587, 0.09712232024009738, 0.12553413531609944, 0.10281313237335, 0.11498455783086163, 0.13112921294357094, 0.19571028969117574, 0.08111331784831625, 0.2352933899632522, 0.12096041574009828, 0.10216817126742431, 0.12020602050636496, 0.09169973299971648, 0.19697799666651658, 0.0729863682229604, 0.21631002931722573, 0.16708562496517385, 0.14394868005599293, 0.07729051262140274, 0.12866884496595177, 0.11235284619033337, 0.15760683002216475, 0.15510994328984193, 0.07261799834668636, 0.07735544163733721, 0.137938135436603, 0.1963231832321201, 0.08291057390826088, 0.08735193165817431, 0.13851578586867877, 0.10538069531321526, 0.1577233751969678, 0.07224384735205344, 0.08252638059535197, 0.167672530614904, 0.14938867171960218, 0.11892780980893544, 0.11001603943961007, 0.09733312749969107, 0.12205145933798381, 0.12443283226873193, 0.18177579955330916, 0.1384267620742321, 0.13358986590589794, 0.1772985676569598, 0.11163098671074424, 0.11665808303015572, 0.09057279489934444, 0.13298807319785866, 0.1742042986942189, 0.14145027340522834, 0.08088058712227003, 0.08989508769341878, 0.21345118486455508, 0.12858812644013337, 0.0774295444467238, 0.18374904724104063, 0.18384297005832195, 0.17968303470739297, 0.12889764697424003, 0.12395641926143851, 0.1267666398946728, 0.14600222557783127, 0.09110112940626484, 0.1278709556375231, 0.11753058406923499, 0.13672662473150662, 0.15177418371396406, 0.10121173544653825, 0.08531465062073298, 0.12889010166483267, 0.1303641511393445, 0.14603698014148644], [0.0051585883484221995, 0.029624292693500007, 0.02371153175564749, 0.04197149264759251, 0.04709253214033587, 0.02980966167524457, 0.057990554321025095, 0.04594615061900445, 0.05180529371968337, 0.0095716600938301, 0.07314042959894453, 0.030205210271690573, 0.06308925644095455, 0.048142283489661555, 0.05259155635056751, 0.019602439033665826, 0.01279363189158695, 0.016027182041268264, 0.044021503001983674, 0.03019882525716509, 0.020097523628334914, 0.01901137057159628, 0.03699116435434137, 0.03891941159963608, 0.03346935726170029, 0.06211302775357451, 0.016072906819837432, 0.02934601191165192, 0.026755819828914743, 0.01764482818543911, 0.06554547856960978, 0.030285745593053953, 0.013907524308056703, 0.009120243468454905, 0.02227035051743899, 0.0337862365080842, 0.050346239869083674, 0.03708935854956508, 0.06845953541674785, 0.06631532404571772, 0.023171719828886644, 0.08713100744145257, 0.016958510370126793, 0.021396480533959608, 0.05536560428195766, 0.021409698396122882, 0.06734175753912755, 0.027727605808260183, 0.052311545304421864, 0.027922576060518622, 0.02176761713677219, 0.05489537272868412, 0.023297700033124005, 0.04620127978601626, 0.011772193264083138, 0.024928311285163676, 0.025532370300165246, 0.03778396127745509, 0.04661994267787252, 0.037259016052952836, 0.08135218253093106, 0.07005267457238265, 0.03289464149358017, 0.048800306394696236, 0.01259732831801687, 0.017469421794105853, 0.03412041839744363, 0.06548369795616184, 0.0518072377225118, 0.049094030633568764, 0.027761870130364383, 0.007848907178933067, 0.020048467242824178, 0.01998122951148876, 0.022799344899665033, 0.03284349013119936, 0.032788287914757214, 0.010700543893368115, 0.026118607592902014, 0.025490676019606844, 0.04222319860543523, 0.03366310954360025, 0.03683389690039413, 0.09407214926821844, 0.08503693980830056, 0.03281662692981107, 0.027511989431721822, 0.05730230946625982, 0.012402771123951035, 0.042505855938153606, 0.073904690731849, 0.07173568569123745, 0.022718329514775957, 0.028045701328665018, 0.03714283050170966, 0.0038139121773253593, 0.032723101055515666, 0.007049351622949221, 0.03341529837676457, 0.012046119547449052, 0.06702171971223184, 0.06277306590761457, 0.03150100181145327, 0.013834324798413684, 0.04837807101596679, 0.06660385070634739, 0.05081687854336841, 0.028788717530135597, 0.0320995613001287, 0.030806385512862886, 0.012712313710445804, 0.06601403414138726, 0.08641327345477683, 0.031675792432257106, 0.01290253336940493, 0.042994682743613205, 0.025514803028532436, 0.05668018784906183, 0.057427309187395234, 0.07456865760364703, 0.06046921560274703, 0.037976824678480625, 0.0304257884355528, 0.0287469469143876, 0.03749199444428086, 0.009155624828833555, 0.07469855634761707, 0.016885477949732115, 0.02678883564658463, 0.024546179022373896, 0.048829320552093644, 0.05131154074998839, 0.03687744867056608, 0.04019772746999349, 0.02509265416301787, 0.026371901322688376, 0.0338516981740083, 0.01705454512765365, 0.07751317388777222, 0.040383276263517995, 0.016144816264776245, 0.026848565387938703, 0.028141354410243884, 0.052248444940362654, 0.0251864175245698, 0.06925854432795729, 0.024861847083749514, 0.012592059493597065, 0.019814752641000917, 0.09770356690777199, 0.03655296643929822, 0.02940432521115456, 0.05101239162364176, 0.05356186481990984, 0.029769695962646177, 0.020448621395709257, 0.07616506729807172, 0.08210581780544349, 0.05236896972305008, 0.014282227460561054, 0.03648810188419052, 0.012076039549096354, 0.01978129068655627, 0.01565581643288689, 0.05166745272332004, 0.0031640319045566556, 0.05410710163414478, 0.010434355453721114, 0.05491986105750714, 0.03281873378104397, 0.021439204491408806, 0.016794569524271146, 0.06627820139484746, 0.05094057208459292, 0.03524245408230594, 0.014053228677117398, 0.026986231661534736, 0.011578297641660486, 0.01089327413189624, 0.0657878987757223, 0.02058308498401727, 0.05411612614989281, 0.04608211885871632, 0.03845378729913916, 0.05291841006172555, 0.04324758631576385, 0.023311428492888808, 0.017257598428321735, 0.0780851992645434, 0.011504364466028554, 0.034006360053483925, 0.03807237597980669, 0.058083757891186645, 0.06220843656254666, 0.015788164688274264, 0.02136792608403734, 0.04650590468996337, 0.031177601843540157, 0.05099832220003009, 0.03447733799527798, 0.025175498199782202, 0.015049755739580308, 0.017649559270856634, 0.05730749347380229, 0.026339365568544184, 0.056027905350284915, 0.03698940694864307, 0.0430560358799994, 0.01910062676428684, 0.0442530259356967, 0.030087223209972893, 0.03951650884534631, 0.07970026188663074, 0.05894568735467536, 0.09070845440562282, 0.05381329936374511, 0.025237587546663623, 0.06748956960758992, 0.05244573238970978, 0.01612067568515028, 0.026494746695139577, 0.051837517347718985, 0.050919293226408105, 0.03764438323144402, 0.051326817965933254, 0.023301579557093124, 0.08094744317765747, 0.010705478539291238, 0.05400406948423811, 0.07837043503033263, 0.014198753234398152, 0.04880096457366433, 0.09311904505427394, 0.051550676846610646, 0.023558308370411396, 0.029323857743293047, 0.021637377428955266, 0.05555555676775319, 0.0517824372675802, 0.019710075043674027, 0.008019950590096414, 0.04964827839285135, 0.03670323819720319, 0.05157126359907644, 0.05732799880206585, 0.04007685663444655, 0.06716502630817038, 0.022389742146645273, 0.04207753749298198, 0.03252724531505789, 0.026056682790762613, 0.056979265729231496, 0.025606435790125812, 0.026248538567285453, 0.027099731910441602, 0.07068098442895071, 0.0725973437407187, 0.01692828842039619, 0.027527863758483102, 0.022253110638952682, 0.03814955594550286, 0.01651661952824465, 0.048676070025456805, 0.03419778496026993, 0.006922428255035941, 0.02396861171083791, 0.05928314996084996, 0.040748185611196926, 0.042134079816085954, 0.01620968251622149, 0.10169523235942636, 0.04527971727241363, 0.06468753210668053, 0.0382392480969429, 0.062007651265178404, 0.04442601165335093, 0.07284818456641265, 0.06719433902097599, 0.010241096806047218, 0.012140253558754921, 0.01606221141160599, 0.042018671187439134, 0.023507387709936926, 0.03302757328908358, 0.019062160614079664, 0.015291468572935887, 0.03446068335324526, 0.022873863311750547, 0.10955889682684626, 0.03458413262186306, 0.023398408200591803, 0.011298146647667246, 0.06542692493115153, 0.02720141377566116, 0.030438025814614127, 0.04519216250628233, 0.012920175279889787, 0.052942613405840735, 0.015542477336046951, 0.007050594190202121, 0.06653916596301965, 0.014367997679593307, 0.09946045013410704, 0.022599967562460473, 0.11142351105809212, 0.016008359479850957, 0.013193207593368632, 0.03951501267563019, 0.04465112243113773, 0.07676862419715949, 0.05187429394572973, 0.028196046029084494, 0.059984633033829074, 0.03242809099278279, 0.07844873118613448, 0.0071415997309876335, 0.02296568775948669, 0.05331960067685161, 0.059408943567957194, 0.016855220376913036, 0.07399929208414895, 0.03993944990049515, 0.04482734136815582, 0.011305126228502818, 0.02513501510423209, 0.06652430604611125, 0.04275398262377296, 0.03861412512404578, 0.036708822540406666, 0.031248966764126505, 0.03977334452793002, 0.032850536717368026, 0.01614209364301392, 0.040826888888009956, 0.01396803097200713, 0.020280039370326058, 0.056851582402097325, 0.05928571482322045, 0.04149743415681379, 0.030383037336702858, 0.05864697588341577, 0.03222272219136357, 0.02313906533111419, 0.041722924914211035, 0.09373915820781674, 0.06069472671619483, 0.03204113943502307, 0.04718703171238303, 0.05803343094885349, 0.00982405137204166, 0.05577491017590676, 0.0443106607001807, 0.11311391142329999, 0.11653368041983672, 0.10978622641414404, 0.18694410579545157, 0.13110931829682418, 0.12953255219118937, 0.1217273095888751, 0.16246994478361948, 0.15477880463004112, 0.09826220478862524, 0.14626127667725086, 0.12987001479736396, 0.192371843116624, 0.11006963692073311, 0.17883825860917568, 0.12008005726550307, 0.13386829596545013, 0.15796474367380142, 0.1201885278735842, 0.08218374755233526, 0.14015979479466165, 0.09204839143369879, 0.23335527681878634, 0.09841942135244608, 0.1345241814851761, 0.10670002523277487, 0.09332348765539271, 0.11503200099936553, 0.08725912842367377, 0.11032755486667156, 0.1479617804288864, 0.22873830742069653, 0.10920743604323693, 0.18452558985778264, 0.1290798879095486, 0.1094041501304933, 0.13502844156963484, 0.11711739695497922, 0.14884395737733158, 0.11710567186985697, 0.16583743265696935, 0.19029015196221216, 0.10349206094230924, 0.08142005638884646, 0.2169377420629774, 0.11575990622597081, 0.11572053762418882, 0.13230400133345807, 0.16583565489522048, 0.08735784169818674, 0.1328805796802044, 0.14607693228338445, 0.10185810790530272, 0.22237392035978182, 0.09368438686111144, 0.09146060368844441, 0.10368846968880721, 0.14021432186876023, 0.058390353939362934, 0.14928480157894747, 0.20162476732262544, 0.1787898519209453, 0.172804290960942, 0.08643771428614855, 0.05996818534497704, 0.15757715090044908, 0.0914075422499861, 0.15453379920550755, 0.18620001072330133, 0.11766546326024191, 0.10267224136207785, 0.09400020420019116, 0.12347678999815669, 0.08305065746286086, 0.2008032106927463, 0.13670656723635538, 0.09474019413547856, 0.10583875394825425, 0.07316018175333738, 0.125716484817011, 0.1308297754398414, 0.16142401019377367, 0.16792265219347818, 0.133987853835736, 0.1475309514041458, 0.13329919507460936, 0.08746949463550534, 0.12938976128186497, 0.09951346407511405, 0.22802087877477917, 0.12191838505012648, 0.16073931407715591, 0.11672144463019711, 0.09279880366687264, 0.22074886970221996, 0.2336695742394243, 0.08607580406325203, 0.09706074997250523, 0.18489782059831278, 0.069964342883655, 0.0779854953289032, 0.1747899151274136, 0.09811731042074305, 0.137894654912608, 0.16639900180910314, 0.18414277397096157, 0.08547866610544068, 0.10941035194056374, 0.09100479778966733, 0.11081854280616556, 0.21749677349414143, 0.18207907756524427, 0.1939894977424826, 0.1862910022693021, 0.08945637409176145, 0.1083663986729724, 0.13324242883494922, 0.11623615638485976, 0.17357883868472918, 0.21144603246024676, 0.13827230036258698, 0.11673443179045405, 0.16876396776310035, 0.15723181728805813, 0.1398375178022044, 0.07193122591291155, 0.13542368821799755, 0.1099614512973598, 0.19454863773924963, 0.08262453068579946, 0.0979268184996077, 0.08844127213316304, 0.13618020048098906, 0.13386609751198972, 0.11440141126513481, 0.09377495771540062, 0.21609646720545633, 0.13967618931617054, 0.1546987917806421, 0.1248975337616035, 0.07338383368083409, 0.115126548068864, 0.14328816692743981, 0.19176616918827805, 0.1315405408718756, 0.11253384540655784, 0.12019019706973008, 0.07471057320279734, 0.08266022841313056, 0.19220541204724992, 0.08869370073080063, 0.12367969911013331, 0.13093797463391507, 0.11293464247137308, 0.0974922643176147, 0.12377136919115271, 0.138645508193544, 0.18656308124107973, 0.15004750208130904, 0.06085729692131281, 0.15594831401748316, 0.15052870554583414, 0.11037784788225379, 0.160586752263563, 0.1978004082505192, 0.1012734074943832, 0.12065613349633557, 0.10690005735627242, 0.2446676226598876, 0.17903839929827622, 0.08985885392342295, 0.16163688019982406, 0.18218959734908172, 0.07171391828783921, 0.11178992675351244, 0.18847114885491983], [0.10203994171960012, 0.018143758377326385, 0.04412994646866407, 0.04616269489218082, 0.05701437313109636, 0.030521553475409746, 0.05328381473996809, 0.052258236200681756, 0.060895674861967564, 0.0159462107611554, 0.01135776103806815, 0.03424528241157532, 0.015308048576116562, 0.018666286320824708, 0.0020753305247386117, 0.01628334427784596, 0.0402833687673722, 0.045613766847444434, 0.08855676557868719, 0.01178163253436131, 0.0332848059146532, 0.06870076818657772, 0.021845194045454264, 0.038821135980210135, 0.018319008705605353, 0.04336035205051303, 0.026275138836354017, 0.011501195707491465, 0.026581259910017252, 0.06911096974675145, 0.021166499571076462, 0.02851160043584449, 0.09447302775723593, 0.10859392503542559, 0.017099930638713495, 0.04244775637718184, 0.07726051458822829, 0.021865265111305883, 0.037345498733754666, 0.022106441901996732, 0.0338426091974335, 0.016554018682135, 0.022310865843402486, 0.040800921352846284, 0.005490627339375871, 0.004563924074838204, 0.04254011856392026, 0.027597759650754075, 0.055230996504958184, 0.04359179695269891, 0.05770337115973234, 0.011935933093939508, 0.052315633477909226, 0.01524787100165018, 0.017848690639116933, 0.03600111390863146, 0.024790929996275475, 0.05115911125072411, 0.0432779846845993, 0.03464404047865953, 0.08031618847910847, 0.015480616994734322, 0.02706742176919111, 0.03037133939298136, 0.049850529325859885, 0.053505264821329286, 0.02719594817608595, 0.02598488360776433, 0.011228835991849857, 0.03744278708472848, 0.04384592188788312, 0.052136954851448536, 0.009983736106992831, 0.01689584935749216, 0.015958288684487343, 0.0353280207408326, 0.038284957608474154, 0.025331386531304036, 0.03982304043269583, 0.031003683140235286, 0.06593421128179346, 0.07504568129245724, 0.04839731087642057, 0.013032983423077633, 0.04891838166596634, 0.04190390716706004, 0.04312252213380166, 0.010166988907647985, 0.06450268559690032, 0.04219032697645681, 0.03692393171201859, 0.07151638317321028, 0.01680220982858113, 0.04505725617387465, 0.015330435142719319, 0.03414805173607809, 0.039164288102516105, 0.03215130977332592, 0.04760392362784062, 0.04566346614488533, 0.032778455942337, 0.029372736013361385, 0.02656053745054773, 0.04622697590717247, 0.006581743455691529, 0.00736721941003842, 0.042469937686941454, 0.010275717359036207, 0.014288749878427811, 0.021525178270946656, 0.04456763548244323, 0.03590619025219764, 0.03566189728943365, 0.06121763972831624, 0.028311262971588542, 0.046532197921936, 0.033215222148490806, 0.058558216717626364, 0.02856364407177482, 0.011507607863417693, 0.019592364484976445, 0.037969791663012335, 0.04320601586784635, 0.02387869225016662, 0.08455330718840871, 0.014976616449920195, 0.050380512672875605, 0.046338106372526715, 0.03737895729552422, 0.045060136555028815, 0.050168687610753944, 0.028137042320200374, 0.05922689262245383, 0.035943085593836646, 0.022238198135580336, 0.051264952535607984, 0.06307314123426165, 0.03437680624691503, 0.024640067912904278, 0.025777360457660894, 0.026003606085266386, 0.030802677318985974, 0.024367035599425435, 0.038965687687907896, 0.022983180392267447, 0.030869665688702037, 0.041110265467848094, 0.029618213019732918, 0.03050815240879144, 0.039925777419869385, 0.029703677898006778, 0.0240961576346308, 0.015023381083405443, 0.030637667780475955, 0.012212660030594893, 0.0032827123442465173, 0.050289785755532126, 0.06571158394217491, 0.027161485382488797, 0.026589276801262583, 0.04802744483043041, 0.0024457126814273317, 0.008740130695514381, 0.010031932449367429, 0.07262808816241366, 0.03566396342856543, 0.03453626197629741, 0.026283170994637266, 0.10292698376412902, 0.06415181513875723, 0.012243641939546381, 0.0337279978474336, 0.034137558192014694, 0.015044877072796226, 0.03004306075828416, 0.02848627750894853, 0.07500891826514687, 0.027860564745164344, 0.028016178270003626, 0.028194485398541604, 0.018573462730273604, 0.006551152552544538, 0.05889811526451792, 0.051311856268772056, 0.04676561396835106, 0.016290226319272603, 0.04381279920094779, 0.05136065311463816, 0.016629166435450315, 0.05432929810402649, 0.03636766191838043, 0.009671109578838306, 0.0242677523554968, 0.02019580772944859, 0.07244897527354104, 0.0808634337569986, 0.07462453496243272, 0.05003355736179011, 0.04687650016109858, 0.023152710670339208, 0.0326285980907934, 0.030813255679926703, 0.02243276296316513, 0.02896493307447859, 0.05400060895564301, 0.0645807171240449, 0.021991655829229524, 0.01757159050820129, 0.046321546725396595, 0.03930995939299464, 0.01737909351608583, 0.022171789913305213, 0.0262423147048269, 0.027783276213865195, 0.05374987330287695, 0.04121925854789359, 0.03561848461894052, 0.034272963247661076, 0.013819212127210838, 0.004497283030234809, 0.058276522904634476, 0.026537604663254957, 0.016917340257870297, 0.06293709496302263, 0.017090414185076952, 0.011650835579660321, 0.027525327733850906, 0.031337671647114415, 0.02154811953992716, 0.010478635800869336, 0.011596686788834631, 0.021641090711844817, 0.03883754634963615, 0.06849144691867487, 0.03354698166783367, 0.00661444163415581, 0.03811863849737814, 0.052617547634456835, 0.023910116903217773, 0.019418455959696854, 0.009805140601071929, 0.04575558066634195, 0.09053815568664245, 0.02493154620086508, 0.02744483821360128, 0.00959322478489152, 0.05044933308714202, 0.023272794405264512, 0.05334776666547571, 0.019528239533039074, 0.026296049589291215, 0.026013994456401894, 0.04785180264817817, 0.019103035563603044, 0.043799187788473706, 0.04139289226649063, 0.0996712709644011, 0.0416807709261775, 0.051063682085701396, 0.03816320467740297, 0.040599477876509936, 0.018574005558288524, 0.038696519631360254, 0.06326789435531412, 0.0748107996104019, 0.03184395715860384, 0.020393967096294676, 0.024974823164354478, 0.015519603920568312, 0.06348100863397121, 0.012854491393747074, 0.004936698491552046, 0.011443308188713022, 0.04091193646724735, 0.052999691771609445, 0.03222960253645267, 0.035469393511968, 0.00484856909107683, 0.007887039150643562, 0.040367055883897204, 0.031012877289737974, 0.034050851594656706, 0.0378598147071898, 0.048556824281279526, 0.013228331110440195, 0.017419354391417334, 0.01789291076628225, 0.027153169935835258, 0.03048056996028338, 0.020975841408861533, 0.009745825614248003, 0.02278983692771622, 0.04655759209500892, 0.018360601205910956, 0.03379162068345717, 0.0269124257112188, 0.01789159101567098, 0.04406063411650913, 0.04167004668020776, 0.03474125758345638, 0.02593327932325857, 0.024883030947031717, 0.01782952032850257, 0.0442337487558169, 0.016394883560548936, 0.02486905991099775, 0.053099361780498705, 0.04914186395970838, 0.00445721680963678, 0.00905463082848915, 0.031723642721772194, 0.006350572087935039, 0.063628508576325, 0.017701619870162437, 0.02295428667483585, 0.01280893964160766, 0.04178495319294078, 0.03764681238681078, 0.022019910027406046, 0.06390787501420293, 0.01051519441950534, 0.03469230806721108, 0.06186642098639693, 0.037535793879734616, 0.060271476927612505, 0.027470349433964918, 0.023782289387392144, 0.05692294732268367, 0.031922395806759596, 0.027053917225982462, 0.06863343715667725, 0.029109936007963758, 0.043623311511640034, 0.08865031520170824, 0.019747443663488542, 0.02765064636644508, 0.06821351897503648, 0.03036261343264154, 0.04136419702055199, 0.00586226096908961, 0.022742595623380372, 0.02191044875819768, 0.0817501229633178, 0.02959397914154189, 0.008427650900557637, 0.045559982769191265, 0.009548284562437661, 0.041606260995779715, 0.013180312883507992, 0.009038967695752425, 0.025808927603065968, 0.03993114802454199, 0.19974982578839573, 0.08705965948424169, 0.13799111545085907, 0.2083039539200919, 0.10844109180782523, 0.14337199314364366, 0.10469797373350177, 0.14674508571624756, 0.12486029575978007, 0.05518065259924956, 0.132494113274983, 0.15430050529539585, 0.10423671241317477, 0.1725886661027159, 0.24161188091550553, 0.055976200981863906, 0.17770890492413724, 0.07704141563070671, 0.23137050760643824, 0.3285782214786325, 0.13603530611310685, 0.1689529669071947, 0.15519427162195953, 0.08736510880823646, 0.094046772058521, 0.09237718914768525, 0.07976823752479893, 0.08083235006779432, 0.150693236717156, 0.15062132557587965, 0.14384208220456327, 0.0931375962016838, 0.21547767040984972, 0.1626239993742534, 0.11241341222609792, 0.13628963460879667, 0.21666083192186697, 0.12859616029475415, 0.10619909675525767, 0.17929587619645254, 0.15426720279668057, 0.09012813733092376, 0.08306709836636271, 0.09199630708566733, 0.1041260976344347, 0.08882782674793686, 0.10238908869879586, 0.14181042622242654, 0.12632306798228196, 0.14510324810232433, 0.1834364054458482, 0.10350645945540496, 0.10334449993180377, 0.06784064362623862, 0.06261800708515303, 0.13571837597659656, 0.13423478629972252, 0.20949042668300016, 0.12421760096081666, 0.0735763069242239, 0.1279805526137352, 0.0931965269680534, 0.10433507284947804, 0.19292189074414118, 0.11249373041625534, 0.17481099042509282, 0.18100250033395632, 0.13876288118106977, 0.11697700805962086, 0.07754924480936357, 0.1892510298639536, 0.05402545351535082, 0.1363179838018758, 0.06244103158158915, 0.11555265448987484, 0.09020515784089055, 0.19909175538590976, 0.081734957705651, 0.12283986274685178, 0.12302507566554205, 0.11394726777715342, 0.2060006396578891, 0.16542936169675418, 0.09717865900269576, 0.11442689704043524, 0.1049204110833151, 0.11966221540101937, 0.17492444148021086, 0.11484165835593428, 0.15307770376758917, 0.15084019383149488, 0.2056203479213374, 0.10210536606609821, 0.08429834086980138, 0.07933398189821414, 0.1942316804613386, 0.11300442301269088, 0.1585138277815921, 0.1472081315836736, 0.12919845511870726, 0.10477518423327378, 0.08332621731928416, 0.08259878028184175, 0.13429461951766694, 0.07418306650859968, 0.08831646240183286, 0.11332833527454308, 0.19367074913212232, 0.12648512928613595, 0.09940342605113983, 0.11915940738150052, 0.12140788244349615, 0.09457746108195611, 0.11309932292039905, 0.10228065201746565, 0.15251042135059834, 0.11187139845320157, 0.13585462580834115, 0.11491897063595907, 0.17567260776247295, 0.09348075171666485, 0.2785900038267885, 0.07856737981949534, 0.1967467383614608, 0.2577277661434242, 0.12812278712434427, 0.15833827720156737, 0.11588133685290813, 0.10720591380127839, 0.14175414852797985, 0.10471929330378771, 0.16202441869037493, 0.11773228538887841, 0.11120607451136623, 0.07118531915226153, 0.08409159124961921, 0.17794153386993067, 0.09196736756712198, 0.14201474668724196, 0.08037722948938608, 0.10933059014912162, 0.18117654456623963, 0.13437596229570253, 0.12301432767084666, 0.11592354173106806, 0.17753099304224762, 0.12919713876077107, 0.09508147689380816, 0.09600623191467353, 0.16729485802352428, 0.11676264527652945, 0.16415581932025297, 0.08772601479930536, 0.09379543590226344, 0.20777703076601028, 0.1464911372001682, 0.1856539121695927, 0.20728471289787972, 0.12245187642318861, 0.12098715001983301, 0.15559774211474828, 0.1361600887030363, 0.1041875389803733, 0.06190406610923154, 0.15224233216473035, 0.09161848521658353, 0.20052160508930683, 0.13361145689019135, 0.1670445328844445, 0.13731875510088035, 0.13967107316212996, 0.11750099994242191, 0.16283205178167137, 0.08796463520931345, 0.082982512190938, 0.1222231558391026]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.07203759984778506, 0.029340658270354782, 0.039327197575143406, 0.013877473688418311, 0.0594735536724329, 0.02295184225243117, 0.05989565673683371, 0.013391512845243727, 0.03819168957748583, 0.04930700920522213, 0.013387103215791285, 0.0144842968854521, 0.03130749040948493, 0.003028355222860617, 0.07584328563617808, 0.00920525542460382, 0.031270042061805725, 0.020118843198620846, 0.04983263975009322, 0.08243445945637566, 0.045716866850852966, 0.02650669908949307, 0.022704487400395528, 0.03174684861940997, 0.06776177750102111, 0.03095789559717689, 0.008170995029753872, 0.035453956840293746, 0.03953713970258832, 0.007455660512537828, 0.023425546208662645, 0.023927919965769564, 0.008861317898013761, 0.05610625918156334, 0.018575074250942895, 0.02250922198540398, 0.015493185159617236, 0.044625049723046165, 0.031799859167741876, 0.056775403275553665, 0.018555188085883856, 0.014401049120351672, 0.02939919548641358, 0.021111056474702697, 0.02204567739473922, 0.041204049185450585, 0.010480461908238274, 0.0012725550020279894, 0.03842410139207329, 0.095866128004023, 0.08168565535119601, 0.022273398836010268, 0.02379366841965488, 0.06072303519717284, 0.05311286462736981, 0.05907300766557455, 0.06450559651213032, 0.012666543978931648, 0.11742215417325497, 0.015319727860125048, 0.012473281090413886, 0.058758282767874856, 0.003905112372844347, 0.007124070626949626, 0.04906091812465872, 0.07887756531792027, 0.04333961262766804, 0.057302377319761684, 0.07389455341867038, 0.018166575813665986, 0.009553929125624043, 0.06158529035747051, 0.04984739449407373, 0.025877495263037936, 0.012510154379664786, 0.01903871722918536, 0.055199756752699614, 0.009438088779071612, 0.01427825294168932, 0.014900360988186938, 0.024951681727543473, 0.05701842398515769, 0.05142975851361241, 0.005184547401898141, 0.028626316958772283, 0.02253215477269675, 0.03268270447318043, 0.027986824845096896, 0.03179994398461921, 0.0275282165966928, 0.0319983510167471, 0.016933740449271033, 0.021875911325748478, 0.05991015703018222, 0.051199100712048154, 0.07631109481943504, 0.09120647196791001, 0.011586971015536358, 0.047409262109015665, 0.019451880594715476, 0.02440193944078471, 0.048053137558911524, 0.06961906355406557, 0.07850677985697985, 0.05870540453387158, 0.02641993820933359, 0.07251628594739096, 0.055923519523016045, 0.02642450644634664, 0.026728715747594833, 0.02698212313199682, 0.06230983005038329, 0.010392264230176806, 0.03876539093575307, 0.03139119788206049, 0.021529240999370813, 0.06682123975562197, 0.01943556352385453, 0.03522174519353679, 0.04099025637177484, 0.09750167559832335, 0.011873111777406718, 0.018171390019623295, 0.02640371274070016, 0.009911258388975901, 0.008372439354258989, 0.029747039678373506, 0.021716209627421837, 0.0199285955500922, 0.017692987208387682, 0.03626531848151769, 0.05650252702512911, 0.042203616084797044, 0.030993155669420958, 0.03344929976654904, 0.0432549891328173, 0.0231697096688939, 0.03526593478662627, 0.06856917310506105, 0.025735737423279455, 0.09664108963417155, 0.020716255963114754, 0.05168021935969591, 0.06397108055119004, 0.022060971574059556, 0.020046591093497615, 0.06353998011244194, 0.047586461529135704, 0.029323080820696693, 0.047046520680721314, 0.021212673879095485, 0.01591371402277478, 0.011055331194906362, 0.032634385994502475, 0.01987918632637177, 0.03218322466792805, 0.011812095364023532, 0.0355638761206397, 0.05396882976804461, 0.01805063962404217, 0.0525349326032613, 0.04875998105853796, 0.006481560304694409, 0.021934256855664507, 0.0380192059757454, 0.005950266536923924, 0.01956629177688488, 0.04881172613906009, 0.01669074348839266, 0.011807123398674386, 0.011301954077290637, 0.032435785579894266, 0.028000437953908528, 0.06915744939552886, 0.011732068943924137, 0.017580117997048155, 0.06117630337498017, 0.047298325026141744, 0.04355281850855265, 0.026510400498019795, 0.03647040569090417, 0.02086640558471637, 0.03262353961222938, 0.05457923987082072, 0.0479885919152626, 0.05730646210057395, 0.041308475724820576, 0.030337527993002107, 0.030120525708688155, 0.03626301824780447, 0.06547096185386181, 0.015051955889378275, 0.0586231118068099, 0.01721345802902111, 0.021066656535757438, 0.01060643871980054, 0.036404489406517575, 0.03193979344463774, 0.04389851174450346, 0.018278690154797265, 0.04348018812015653, 0.03439262968354991, 0.03397581579961947, 0.020466634804116826, 0.04224778532183596, 0.012139066122472286, 0.043561636071119986, 0.021748541821060435, 0.02399442996829748, 0.08548917661287955, 0.008122488257608243, 0.05913660675287247, 0.00653497754995312, 0.017273959603958895, 0.05454213757600103, 0.010440436823825752, 0.05851210347775902, 0.032013122724103074, 0.0351539154403976, 0.03595848155340978, 0.074285430301513, 0.08840122499636241, 0.024864493370322243, 0.018024507544136474, 0.052793359450463734, 0.05039679412064808, 0.07726085385573761, 0.0323863712671612, 0.013086630097989525, 0.052376786446464915, 0.02802528760262898, 0.07151493110827037, 0.0754881404074175, 0.014688747968258602, 0.05835670538778816, 0.031700969474124055, 0.04926175091947828, 0.02001170251917626, 0.009491471673495002, 0.03634109727240034, 0.04370028452415552, 0.034512343616890054, 0.04204138514718839, 0.027738218095951846, 0.05411120677100761, 0.03943046381963151, 0.045584488061389754, 0.017811976805595413, 0.03333303279110363, 0.0323757793355201, 0.028206096829048226, 0.042100295557507446, 0.04949907532760075, 0.03420940487246428, 0.07189862230526549, 0.013350376659738166, 0.04631480208731123, 0.031776490421699624, 0.07966106291860342, 0.045377840221460373, 0.05526067901934896, 0.07174764147826604, 0.029564381444028447, 0.036291587964764664, 0.025257027574947903, 0.023045698912548165, 0.03374665077509625, 0.01786098738999239, 0.01481665181927383, 0.01871776846902711, 0.018758933492270962, 0.05679524363949895, 0.008457141728805644, 0.048717430127518516, 0.020322994029681598, 0.008800639903971126, 0.026581597481189028, 0.010824375686102679, 0.03681541699916124, 0.04308513146159904, 0.05378964563299503, 0.039337613087679656, 0.02239655124555741, 0.06234858797064849, 0.02034765199225928, 0.02523574871676309, 0.028427794575691223, 0.03623840778267809, 0.07185090772275414, 0.04038936272263527, 0.026613110343792608, 0.009455928312880653, 0.04236021518175091, 0.021621438641367213, 0.025523137134898986, 0.09959335478820971, 0.05349826912528702, 0.010962326944406544, 0.014925158050443445, 0.07522024121135473, 0.007196757842653564, 0.007847413553723266, 0.0606361555733851, 0.024122228646384816, 0.04447266093588301, 0.024439587956294417, 0.07711531487958771, 0.006798844551667571, 0.012256812304258347, 0.04593983685065593, 0.009031164543037968, 0.028364870630736862, 0.04779525353972401, 0.03615363501012325, 0.020286317515586103, 0.0021381136736766037, 0.025168687404532517, 0.04956846231860774, 0.09414319188467093, 0.005753959570678749, 0.019511170984644974, 0.018066636087106805, 0.0572846471997244, 0.03095627050580723, 0.013642003377234297, 0.06085752762321915, 0.020117084096585, 0.019048698479309678, 0.022039624862372875, 0.009032756555825472, 0.04669515149933951, 0.042782783042639494, 0.026646897995046208, 0.012490149470977485, 0.016603622984673296, 0.03285423812589475, 0.031191942681159292, 0.017915534820141535, 0.016850552055984735, 0.006601742003113031, 0.027538504883913056, 0.022884195703747015, 0.058799775184265206, 0.056923191595290384, 0.02350565405296428, 0.014492468143414174, 0.041604676616511176, 0.05017487924279911, 0.0069739897070186475, 0.06312062511486666, 0.026640146571610655, 0.04441737729523863, 0.18705997243523598, 0.16847111204905169, 0.15065339314086096, 0.058594945818185806, 0.1461359919714076, 0.18334375827440194, 0.14106650756938116, 0.15856631925063475, 0.12232550606131554, 0.10996964121503489, 0.1900758570326226, 0.08985438237765006, 0.15772713428097113, 0.10205465235880443, 0.15557335556617805, 0.13410046350743088, 0.11880225368908473, 0.09374943801334926, 0.0711453670103635, 0.13008231483399868, 0.11672835211668696, 0.11049693077802658, 0.08268662342535597, 0.1200977670294898, 0.13563649037054606, 0.08082034678331443, 0.06631542582597051, 0.09545940054314477, 0.1721080190369061, 0.14170974519635948, 0.1273249385080167, 0.09661225868122918, 0.09115062175052506, 0.1994417980313301, 0.12826603943748133, 0.15098599743630203, 0.05039724534643548, 0.11114757122205836, 0.09550926608166524, 0.19719268514641694, 0.14807159453630447, 0.08422512694128922, 0.13591866594340118, 0.1053696284070611, 0.09856012237391301, 0.22423187137714454, 0.060722424515656064, 0.1468875373580626, 0.15651879911976202, 0.1551818544311183, 0.13762499152549676, 0.15313147088246687, 0.09780162878866706, 0.15937788784503937, 0.2404098425592695, 0.19254596877310956, 0.13107193101729664, 0.12762417245124066, 0.1638061295130423, 0.18990519190473215, 0.08849778731486627, 0.10625999527318136, 0.08714348570044551, 0.12063773162662983, 0.13840769524020807, 0.24218022184712545, 0.1732282532112939, 0.12950952271265642, 0.1352469027042389, 0.17512349651328155, 0.18910670546548708, 0.1665602760123355, 0.1530781923128026, 0.11275092911507402, 0.09476893009351832, 0.12975888433200972, 0.11774747100259576, 0.1278184913098812, 0.17701374579753193, 0.06945818290114403, 0.07548725831189326, 0.1781283345605646, 0.10282719840428658, 0.09517540649643966, 0.14449324512055942, 0.1250178244497095, 0.16603358356016024, 0.17263377511075564, 0.12045943976512977, 0.1705110054463148, 0.11988457132663045, 0.08980269157992941, 0.08135581269328084, 0.10160547574715954, 0.2026846254510539, 0.19466869772544929, 0.1336457093379327, 0.13405319675803185, 0.13770382372396334, 0.19022381837878907, 0.09852013630526406, 0.07289633341133595, 0.10417520321373429, 0.13885888031550817, 0.14846906677952834, 0.11901652147727353, 0.10693221991615635, 0.13031251462442534, 0.11631687491067819, 0.10951513810349361, 0.13370190560817719, 0.21348156966269016, 0.207493321704013, 0.11018135092620339, 0.11158307535307747, 0.06636700127273798, 0.2315213866531849, 0.12292470676558358, 0.1072031453784023, 0.20044592129332678, 0.14621912608189241, 0.09388474468141794, 0.09266564795481307, 0.10667655470647983, 0.09520131974880185, 0.09694683751357452, 0.19627939058201654, 0.20128654475722993, 0.08206566210303988, 0.12058006972074509, 0.10251298919320107, 0.13930409428264412, 0.05712188021945102, 0.11177814738558871, 0.09941103242869888, 0.11087923776358366, 0.10222339044724192, 0.16657191967325552, 0.2374062394457204, 0.07431990666581051, 0.2473715575678008, 0.2009549718350172, 0.15408076851495675, 0.199692964553833, 0.14202497899532318, 0.11478315506662641, 0.14734778766121182, 0.1322922355362347, 0.11009338564638581, 0.16023179702460766, 0.06625903956592083, 0.059409662815076966, 0.08287638252867119, 0.16774844511279038, 0.08527285964893443, 0.0862292954698205, 0.04367129072280867, 0.17330975883773395, 0.09096099835421358, 0.14674052596092224, 0.12557723586048397, 0.12277287776981081, 0.07128608160253082, 0.08296056158308472, 0.11613137700728007, 0.08927862505827631, 0.09154783615044185, 0.10796440738652434, 0.10004105897886412, 0.07730698745165553, 0.1400381198951176, 0.11817234248987266, 0.12607823897685322, 0.2050088250211307, 0.12038286030292511, 0.09965627534048897], [0.026663165872118304, 0.05024242401123047, 0.022641885759575025, 0.018031579575368335, 0.02083224304286497, 0.06269833884601082, 0.036726013225104125, 0.008433364165414656, 0.02781887385728104, 0.03926544749577131, 0.037293736689857075, 0.01717520222466971, 0.0141154172597453, 0.05480313267824905, 0.026948905450158885, 0.032560137300086875, 0.0947202927033816, 0.005631926319827991, 0.05319378332101873, 0.05667542792590601, 0.04485296285045998, 0.015514251975608724, 0.06635742035827466, 0.026568447472527623, 0.06921002228877374, 0.036420971022120545, 0.03590211225673556, 0.044599194146160565, 0.00868121943702655, 0.027719538026888455, 0.006531189204127128, 0.014334403410820025, 0.02522139939745622, 0.013913822809367307, 0.014636390509882143, 0.03727948066911527, 0.048501208158476014, 0.020328888802656105, 0.03439224970393947, 0.03361145945798073, 0.044743321769471676, 0.02754204174769776, 0.06268156546034984, 0.020156651169859936, 0.05311441168721233, 0.10207739685262952, 0.029627200216054916, 0.11080892796495131, 0.016340875565739613, 0.024446078143747788, 0.024654257776481763, 0.013197528165099877, 0.030446378580693687, 0.023208133410662413, 0.02566606205488954, 0.024119183720488633, 0.02166282249215458, 0.0233873904882265, 0.03435880471287029, 0.05252050016341465, 0.004898671268685055, 0.026762959713648473, 0.06298848041998488, 0.05327778256365231, 0.0771111554599234, 0.008301022695377469, 0.030685816625399247, 0.03425823564508131, 0.040451122980032644, 0.014822756938104118, 0.018958098787282194, 0.017797452763521245, 0.049450899341276715, 0.025329154151092683, 0.04468112724966236, 0.09755164291709661, 0.02951290099216359, 0.03430562453078372, 0.024947071082091758, 0.025828242102371793, 0.028837897748287235, 0.0529343963467649, 0.03463462241260069, 0.061478753574192524, 0.0544990777437176, 0.04105277319571801, 0.01996107193242226, 0.036128831162516556, 0.014582253593419279, 0.06648572454495089, 0.05027759587392211, 0.034574714555804215, 0.03924832805725081, 0.029734680163008825, 0.053863103834113905, 0.030342467727937868, 0.03111436916515231, 0.011657617537171712, 0.045133801709328375, 0.03996132926217147, 0.05407460659210171, 0.014158100505093378, 0.04359864676371217, 0.02377338700794748, 0.036359906263117275, 0.041426164231130054, 0.02402686224585133, 0.01560796275069671, 0.04264406334342701, 0.055998982795115025, 0.05830614774354866, 0.014748343698946493, 0.03233383908601744, 0.03596918883600405, 0.010653038808543767, 0.029304000415972302, 0.03052969928830862, 0.009021445377064603, 0.05795738074396338, 0.037756802913333685, 0.04689373495057225, 0.06034528796694108, 0.024479767407423685, 0.049070780631154776, 0.018805967843426124, 0.03192484192550182, 0.013180345962090152, 0.02862646962915148, 0.05206710984930396, 0.0030572228591024342, 0.03845876435350094, 0.026529407960229685, 0.024666885313178812, 0.004481736944788801, 0.04286815292601075, 0.025545600036691343, 0.015055508020200899, 0.0288547830922263, 0.021239920452769314, 0.0230805722198316, 0.05151806306093931, 0.04134051954107625, 0.08400486768888575, 0.02289047384900706, 0.013433233419034098, 0.048153900009180815, 0.023043402071510042, 0.0424320109720741, 0.04175542674160429, 0.01522048023928489, 0.02913027848782284, 0.04492640748087849, 0.01912994117343, 0.02463660908064672, 0.02361220440694264, 0.01982002655443336, 0.0380759857861059, 0.049935726182801385, 0.04278202986876879, 0.022645230937216963, 0.02061173951785479, 0.0468194591147559, 0.05518081205497895, 0.06852805388293096, 0.055234853976539204, 0.05107725617874946, 0.04657079638647182, 0.034899237499173195, 0.034033698229385276, 0.02344058593735099, 0.025860560725310018, 0.036514296728585444, 0.04778310437021511, 0.03654505472098078, 0.02879060385748744, 0.0471159585618547, 0.0021825469032462153, 0.03715801611542702, 0.05944220535457134, 0.05587846140510269, 0.039229817621942074, 0.004318075146459575, 0.06688143259712628, 0.05394116250265922, 0.018381610346425856, 0.02602606898705874, 0.03894994567547526, 0.030918289508138384, 0.020758850998910408, 0.09353551627801997, 0.04881305606769664, 0.05451293003612331, 0.02966232118862016, 0.01038927019440702, 0.04330528214839952, 0.024766462023503015, 0.06313891841896943, 0.026526435976848006, 0.02012155733869544, 0.04072868790743606, 0.04437344554545624, 0.019810296362265944, 0.01906682045332023, 0.010231309786571987, 0.02418535784818232, 0.02430802001617849, 0.025824988526957374, 0.03306222946516105, 0.04237155689458762, 0.04680111492052674, 0.06473986751266889, 0.06707890664360353, 0.028477856889367104, 0.08735797061984028, 0.04282248751925571, 0.0310557369541909, 0.06511074796851192, 0.022565679491630623, 0.03478535557431834, 0.014347633147346122, 0.029089013380663734, 0.03497843949922493, 0.02434251843286412, 0.08137488631265503, 0.019511818985587785, 0.04890958445944956, 0.020552218426018953, 0.029525620131088153, 0.028679843193718364, 0.05581638562892165, 0.009302817734091409, 0.06468042105968509, 0.0359678080172411, 0.028910864011517594, 0.0663801987788507, 0.04447631145428334, 0.04841863723205669, 0.023094677266531756, 0.015455407722453986, 0.034450922627002, 0.007748584928257125, 0.024927659891545773, 0.03823808780206101, 0.03369132302967565, 0.015280213373314058, 0.04887942357787064, 0.010266248402850968, 0.011156153016989785, 0.05076642267938171, 0.08197721506335906, 0.04993024022717561, 0.060784252626555305, 0.03849913379443543, 0.06570484608943973, 0.02790688833088747, 0.02334496678252305, 0.033127575780131986, 0.059431606637580056, 0.022599112608336976, 0.07828996756247111, 0.03205393999814987, 0.02309405810332724, 0.027523862098210623, 0.01704915755960558, 0.03500385402834841, 0.059166699780949523, 0.05237901882667627, 0.012118470040149987, 0.07996271244649376, 0.05149675706135375, 0.0292311562890453, 0.008902093611790665, 0.017294744827917645, 0.05766865730817829, 0.0067418026571561184, 0.029122726393065283, 0.04142374186111348, 0.021393520424940755, 0.06294508132019214, 0.03095095757661121, 0.048596372694841454, 0.052066801115870476, 0.011012804012612572, 0.008793879998847842, 0.020416960951739123, 0.03729754666398678, 0.04812556777947715, 0.03268707423870053, 0.05750481824257544, 0.012456203212163277, 0.013402109865897467, 0.04030738212168217, 0.01762271472918136, 0.09048155908073698, 0.009870111177276288, 0.085290745832026, 0.04044378123113087, 0.04904949498761978, 0.031162982806563377, 0.03185713770134108, 0.014954263810068369, 0.03674536843651107, 0.015004051317061697, 0.0173325697625322, 0.02545388076188309, 0.027573558002976433, 0.029274565566863333, 0.0589804079915796, 0.0024836675979063977, 0.03229320501642568, 0.037971101235598326, 0.017813988661925708, 0.04372654043670211, 0.010850001409250711, 0.04281788365915418, 0.06863920470433575, 0.009985822602175176, 0.017285321672846164, 0.08451393858662673, 0.018827967645068253, 0.024257182476243803, 0.0757580887792366, 0.02065021075707461, 0.08075300896806376, 0.04693630963031735, 0.037391405020441325, 0.034701573462890725, 0.014949139174340027, 0.02199026313610375, 0.012087035209073551, 0.050433214487774033, 0.04856079710381372, 0.08044970381472792, 0.10415309654282671, 0.02950973901897669, 0.002458615448891318, 0.06375124877584831, 0.0204783463185387, 0.08349266874470881, 0.02600995378036584, 0.0034117733095107333, 0.02657099876419774, 0.0357824118940958, 0.06339753525597708, 0.0170103419638638, 0.043224265067172904, 0.04160985383870346, 0.03539619993950639, 0.0017125411749085678, 0.02053993524584387, 0.03946381042312298, 0.07596428878605366, 0.1623643918761185, 0.11699973898274557, 0.19179645899151052, 0.1394133519913469, 0.09813795824136053, 0.10669781999396426, 0.13371956108936242, 0.09277802013925143, 0.16442424777363027, 0.11041454984141247, 0.12839283049106598, 0.12985560271356786, 0.07069179349179779, 0.18059920626027243, 0.11179503612220287, 0.2546556852757931, 0.1039091224915215, 0.10382902821792023, 0.14847689707364353, 0.16600873560777732, 0.08968715063695397, 0.09270372055470943, 0.23050268845898764, 0.1112568425014615, 0.19155230852110045, 0.09600860000188861, 0.1506513711065054, 0.18104214034974575, 0.10593052580952644, 0.1187012605369091, 0.07539689780345984, 0.12347859490130629, 0.11529937093811375, 0.13211234233209065, 0.09390368937913861, 0.11808673851191998, 0.09803608299366065, 0.14870179072022438, 0.09983551036566496, 0.12164721531527382, 0.1662583007876362, 0.11622676546020166, 0.15437922892825945, 0.11230971850454807, 0.11439032400293009, 0.1322851109185389, 0.14130495834563458, 0.22170559050781385, 0.0972253829240799, 0.14421173451202257, 0.1680186241865158, 0.06506392226687499, 0.1083468704351357, 0.14031683493937763, 0.1356147772499493, 0.1768817843071052, 0.16020785830914974, 0.10277011325316769, 0.1591443225209202, 0.1426703200808593, 0.12012307638568537, 0.13815032690763474, 0.15876582211681775, 0.14090029363121304, 0.144650380260178, 0.1376451982983521, 0.09840852408004658, 0.1531198000801461, 0.09565607391830001, 0.1576256254421813, 0.1238702724554709, 0.13537323235401086, 0.10367091598787478, 0.10833272976534707, 0.1337153406015464, 0.13623692600854806, 0.11109515439186778, 0.13866202373589787, 0.07738090705658708, 0.0963887492460864, 0.12127723731100559, 0.10611319422189679, 0.16984142708991254, 0.16873184591531754, 0.13136186903076513, 0.2024746595748833, 0.11406841341938291, 0.09134158186082329, 0.12446264709745135, 0.13858864695898124, 0.0952177606523037, 0.09425875318369695, 0.2174242516713483, 0.13590467455131666, 0.10111819260886737, 0.1419978104531765, 0.07957547251135111, 0.11757341319961206, 0.11720382874565465, 0.10593271747763668, 0.16204283413078102, 0.05516643389793379, 0.10021930334291287, 0.14919819336916718, 0.19297748990356922, 0.09755267429032496, 0.09718800921525274, 0.15728141819792135, 0.08964381939066307, 0.10924653323101145, 0.14364523919565336, 0.10279311559029988, 0.16864122077822685, 0.1280743668654135, 0.09276183029370648, 0.09800736739167146, 0.11315962432750634, 0.18118019508463995, 0.11336961734507765, 0.09406251407095365, 0.13192278678928102, 0.1417328832404954, 0.19497129720236572, 0.16529973436679157, 0.0910723391654236, 0.10651309562048741, 0.11710924096405506, 0.1513969860970974, 0.08620129232960087, 0.08425831408905131, 0.12479317507573537, 0.13216634014887468, 0.07145004280443702, 0.07583601174077817, 0.2764260470867157, 0.1144942891384874, 0.051520502394331355, 0.11543078960052558, 0.10800134004758936, 0.1339444683066436, 0.10419205123824732, 0.12947262397834233, 0.21983913066131727, 0.10553607304713555, 0.0649603438962783, 0.16562667968017714, 0.21907671514366353, 0.10384835289525134, 0.11364536719130618, 0.07734853415084736, 0.1144722503210817, 0.1620014842067446, 0.11283936936940465, 0.09005297600690808, 0.07795034042958703, 0.1439157711075885, 0.1536319718829223, 0.15846202841826848, 0.07354025635868311, 0.051787475390093665, 0.13607603178492614, 0.11838624386915139, 0.18359302489885262, 0.15886038275701658, 0.15058311048362935, 0.1440322348581893, 0.18684071062930993, 0.12751754745841026, 0.12025026098958083, 0.11797092615493707, 0.0817340077566249, 0.12457756378820964, 0.09637169766106776, 0.08550322907311575, 0.1331029220351151, 0.19237404157008442], [0.008558537761148597, 0.06983502767980099, 0.01808060033779059, 0.022869702195748687, 0.01380483481833445, 0.027687182084524205, 0.04513792720224176, 0.01641930403587009, 0.012525189867509263, 0.04113314566867692, 0.04145111735644085, 0.03780304168217948, 0.03260928359148758, 0.023632718216893927, 0.03590218350291252, 0.025679992378822396, 0.0080618518238355, 0.07899440226278134, 0.035284726813967736, 0.042215286887117794, 0.0637149675084012, 0.030178713479212353, 0.02224488679452666, 0.012117772845418325, 0.008482482467245842, 0.01369486125518701, 0.032804962912840505, 0.014981356017025453, 0.056848987005651, 0.02158772902164076, 0.035435507473136695, 0.023700907593593, 0.031863112202180285, 0.031411323230713606, 0.04101705171966127, 0.0314866813298847, 0.0444361693225801, 0.0570373958242791, 0.05494991337348308, 0.01251589139324746, 0.05862456387174981, 0.024899207221876298, 0.05025384036291923, 0.021630933042615652, 0.01895005814731121, 0.0032161092551957282, 0.061638148235423226, 0.04416034144482442, 0.03400448390415736, 0.09046370003904615, 0.04289909412286111, 0.04812346771359444, 0.08766347422663655, 0.013122834182078285, 0.0685819499194622, 0.019982325345543877, 0.11640760861337185, 0.08352819683828525, 0.022500095689403157, 0.04765172302722931, 0.07713658016707216, 0.04592099393318806, 0.057689752961908064, 0.009768160442555589, 0.042691116354295185, 0.011640827188135257, 0.025938955268689563, 0.049748067145368884, 0.04513597980673824, 0.03955014382622071, 0.01765129971317947, 0.01236738043371588, 0.028831902891397476, 0.0452110529212015, 0.0062481607975704324, 0.02296192358647074, 0.021301867307296822, 0.03213338627080832, 0.028092050359451344, 0.025850984899859344, 0.04722045974007674, 0.04774025488378746, 0.07130352673786026, 0.032409349855567725, 0.01751295829723988, 0.021059201132240038, 0.05101595053981457, 0.027908659307286143, 0.05540276764492903, 0.025397966083671366, 0.06227226635175092, 0.07160391419061593, 0.060394631033497195, 0.04695007371317063, 0.02604261167081339, 0.03350461733394435, 0.04593363843326058, 0.021020908008462617, 0.01918300430822585, 0.04179106340078371, 0.030973342446876422, 0.020971213800034354, 0.006346970339239175, 0.022279787243210843, 0.05081804562360048, 0.032448922017855306, 0.04258978393461023, 0.02580207779205271, 0.010619651492951172, 0.038751616674874506, 0.05763160929616008, 0.04661199703280415, 0.042433534283190966, 0.031370780763349364, 0.06248786406857627, 0.042223354668489525, 0.041182627834911854, 0.035403107425996234, 0.03664247538628323, 0.018429886416665146, 0.14426912500389985, 0.014735951953168427, 0.016127896994086247, 0.010642094886861742, 0.03035517668883715, 0.05436901615134307, 0.05875330910618816, 0.01000761375429907, 0.01581523653918079, 0.0486360093179558, 0.01720771423008825, 0.053844186277793984, 0.01746813766658306, 0.023397392094401375, 0.045911046609814675, 0.035119350866547654, 0.04164535818355424, 0.06021718055542026, 0.04856938057179962, 0.01776545644471688, 0.047652330316070995, 0.00989154864302171, 0.026578427026314393, 0.027533120708540082, 0.06129454488732985, 0.024470956630206535, 0.01931319821492902, 0.023609354559864317, 0.02115690678225032, 0.04466920538938471, 0.017631756208304847, 0.02726007652069841, 0.05709862682436194, 0.018540845551927174, 0.033764849084296396, 0.046110301810715876, 0.030473309635583843, 0.046748796477913857, 0.06540970371237823, 0.02551237048049058, 0.040550969408026764, 0.011428589915989764, 0.02365403269816722, 0.039299991713570695, 0.028916285506316593, 0.033184874669781754, 0.02581493942333119, 0.004841910966206342, 0.00772729843655335, 0.0431361606876765, 0.02412717686300831, 0.026869840853448426, 0.045378793563161574, 0.005465756062351699, 0.029703762714884112, 0.061636797950736115, 0.026483969862705896, 0.02216700284874865, 0.05060750299266406, 0.036840054605688365, 0.016805951949208975, 0.03441886184737086, 0.030050779094121287, 0.016525901887299757, 0.02439137125786926, 0.022200860049841658, 0.032510071593735895, 0.06113385422421353, 0.03341303885515247, 0.015391443922583545, 0.025893902239788855, 0.017577061196789145, 0.019075361512867466, 0.023916430671566298, 0.024142513450767313, 0.040542436830167256, 0.026729418031339134, 0.023965936586526886, 0.03546361578628421, 0.033675889750676494, 0.025690112728625536, 0.026302112299682837, 0.05385441180052502, 0.02731668669730425, 0.013351788012576955, 0.010898676118813455, 0.025440564512142112, 0.0939695140612977, 0.040511292072811296, 0.03735625012112515, 0.017019948323390315, 0.05669085102687989, 0.048779013965811045, 0.027256894191460948, 0.026456248314519013, 0.015314976418656963, 0.07933955945606742, 0.04154681793547102, 0.03183025075122714, 0.010120162357842284, 0.03117452807990568, 0.03652916003816894, 0.035081040779394765, 0.03703235821532352, 0.009428887844218739, 0.053773907013237476, 0.02923876266660435, 0.020116926337193166, 0.021064122207462788, 0.06056685679193054, 0.048635714155222685, 0.03508988209068775, 0.056837200852377076, 0.046804076725883145, 0.022358142770826817, 0.0473806313239038, 0.00907409460549908, 0.03095067259190338, 0.027441664366051555, 0.05669895612767764, 0.0410799383451896, 0.09004014490970544, 0.024911551470203058, 0.024882715428248048, 0.07022788588489805, 0.054728911125234196, 0.015127514156379869, 0.03212038214717593, 0.007696196935804827, 0.057122470544917245, 0.0452067374384829, 0.045106823156986914, 0.05104185361415148, 0.03315640673307436, 0.04677656891622713, 0.03512073847066079, 0.016108345007523894, 0.043158769474497864, 0.05078885504709823, 0.044292635417410305, 0.023429836246318052, 0.00611265905068389, 0.004274284616777939, 0.021407998665901165, 0.0286296723144395, 0.0032200583290042622, 0.031183664553931782, 0.011541461671835609, 0.049159957095980644, 0.13543390695537838, 0.032980140298604965, 0.029845830984413624, 0.047267370258591006, 0.04336082363235099, 0.03090541430615953, 0.0798615293045129, 0.031279639939644506, 0.030132800407175506, 0.018661081957231675, 0.01382034273618566, 0.1267767772078514, 0.007678985046888036, 0.027023423862244402, 0.014612278767994471, 0.009446537388222558, 0.03893888894734638, 0.02572105053280081, 0.03440074835504804, 0.027472349415932382, 0.015847173486171023, 0.01796366839802691, 0.020158254208841493, 0.021131115666191493, 0.04852172366476484, 0.046492313633539846, 0.038378887211105654, 0.029891289437987974, 0.030967649538069963, 0.03569213280986462, 0.008881457665536021, 0.051544821089399714, 0.016581624879368713, 0.0308712907800717, 0.04387438643191542, 0.01982210117525288, 0.05241808548037495, 0.0029811230363390806, 0.0737610991512026, 0.05449789370011006, 0.024355469970032573, 0.04414625166516219, 0.06069064193538257, 0.04889734708038824, 0.03634944325312972, 0.03323490644938179, 0.008270668431318231, 0.01925583995346512, 0.018063536878409128, 0.02301029465161264, 0.0213682958856225, 0.04961445002949663, 0.038971149894808016, 0.06017654987850359, 0.07412676167275224, 0.041150824898587804, 0.013208634087017604, 0.0396642632383321, 0.04797087197325059, 0.12636291155857698, 0.041091992519795895, 0.0038509288070989506, 0.07181580032088927, 0.08252738482717957, 0.04755422772307481, 0.019250968072031225, 0.044720271934888194, 0.047183299769780467, 0.0430852535979024, 0.03690303283344422, 0.03153395147195884, 0.04248963895120791, 0.029161993214594464, 0.039983978761093955, 0.027133071728582894, 0.018123149572472488, 0.09850864870739834, 0.016416679801685468, 0.03122550980853183, 0.032042421866208315, 0.04401281436106988, 0.02543764341888683, 0.02420391408460481, 0.08410263101437263, 0.12655496411025524, 0.10905203116791588, 0.1033858023583889, 0.07461325771042279, 0.08617679721542768, 0.15393769262092455, 0.11488672665187291, 0.10673399269580841, 0.06493172328919172, 0.09738193452358246, 0.14712586599801267, 0.1602332355188472, 0.11402685993484088, 0.12702855441187108, 0.134642612987331, 0.079064359223204, 0.175613154524139, 0.15877233605299676, 0.13301296186234268, 0.14011810560311588, 0.14838526770472527, 0.10013648814388684, 0.1299504754798753, 0.10207183286547661, 0.11365421528794936, 0.17536337221307413, 0.08925622661731072, 0.07909847596394164, 0.08767768953527723, 0.0807183493993112, 0.19532357901334763, 0.08310344070196152, 0.13282367773354053, 0.09315101083900247, 0.13618158469242708, 0.07529888342001609, 0.12171675158398491, 0.08238318256501641, 0.09523437118956021, 0.18128558514373644, 0.1217305665569646, 0.14407678746751376, 0.08018333132245711, 0.14419992800269807, 0.11526880972087383, 0.22735927999019623, 0.1389166507869959, 0.11526563417698656, 0.19133909924754075, 0.1810102899159704, 0.15170510884906563, 0.15725750662386417, 0.10211255853729588, 0.16555236652493477, 0.08780901998813663, 0.1987472360155412, 0.19286869359867914, 0.11255260011447327, 0.18504537482346806, 0.10721575934439898, 0.08822771002139364, 0.10657119857413427, 0.14113130766366208, 0.11019131182027714, 0.0977539142061557, 0.10160985908338002, 0.16530965454876423, 0.17958038592977182, 0.17640029585787229, 0.09750352799892426, 0.1041486928505557, 0.15034896161939415, 0.10748449313853468, 0.15882797592452594, 0.1262120867946318, 0.12242423290652887, 0.09678045394165175, 0.13805864325591496, 0.0908872348123363, 0.18150073502744946, 0.11963476187416486, 0.13771701444472584, 0.09412236085959844, 0.08438368700444698, 0.07969474539692913, 0.16225183648722513, 0.09621640135134969, 0.21102535431938513, 0.10509417711624078, 0.07954878572906766, 0.11555220665676252, 0.15113641507923603, 0.18942629545927048, 0.14353321306407452, 0.09851079966340746, 0.24237751268914767, 0.06989487446844578, 0.08342987711408309, 0.1818221299243825, 0.1738417302923543, 0.12979776438857826, 0.08446511799203497, 0.08750898537359067, 0.18526463662939413, 0.08874073677829333, 0.11599226375775677, 0.11848056023674351, 0.11881064038191523, 0.1415828184357711, 0.14002771116793156, 0.0953811654554946, 0.12364366890064307, 0.14194284911666596, 0.24375464022159576, 0.12204338477126189, 0.09951752849987575, 0.11036494214619909, 0.1938336111072983, 0.20188772678375244, 0.3303251234548432, 0.1271130863044943, 0.0918350193117346, 0.09017698506691627, 0.16193367141698087, 0.08856793426509414, 0.09857566082584006, 0.16780639200338296, 0.09096679982862302, 0.13426536108766282, 0.08621645758726768, 0.16203520739717142, 0.15760099462100438, 0.09492596345288412, 0.1413221659937075, 0.13551178920481885, 0.13883840212864534, 0.32314179890922134, 0.18896585516631603, 0.11390205020351069, 0.14299155212938786, 0.0896321621590427, 0.09421818357493196, 0.12804086080619267, 0.2078679815999099, 0.10380340673561607, 0.18822885757046087, 0.15754386197243417, 0.10335995695952858, 0.11320930666157178, 0.08512820955365896, 0.06676931147064481, 0.24453069429312432, 0.1854320312184947, 0.133370753377676, 0.15908465215138026, 0.2633662564413888, 0.10942329838871956, 0.13533200456627778, 0.11017616013331072, 0.14536932882453713, 0.09875187637018305, 0.1917964182794094, 0.09962962927030665, 0.10669186924185071, 0.10589745401271752, 0.08704382247690644, 0.07593389720256839, 0.10820119575198207, 0.1669308239860194, 0.06640716376049177, 0.11350291554949113, 0.09882110729813576, 0.10925517776714903, 0.13409306747572763, 0.12520683716450418], [0.06473306859178202, 0.06652678269892931, 0.028957425084497248, 0.05948584194162062, 0.05536446434312633, 0.0298042741071965, 0.07876211936984744, 0.028338993001463156, 0.03924570891207882, 0.05196574689554317, 0.07320689210402113, 0.07977483967053038, 0.028497018718293736, 0.0915703024449093, 0.04045840705345784, 0.008577418846211262, 0.010334283412833298, 0.029051866981067827, 0.10665711467819554, 0.015473631476717336, 0.03757955938843744, 0.04220246596794043, 0.042026511659579616, 0.013478875925232257, 0.02101987154622163, 0.014472902586151446, 0.10786278319678136, 0.05026165369365897, 0.08853275222437722, 0.03621445210384471, 0.022066893488434807, 0.04527995815234525, 0.07253578025847673, 0.004951426942300583, 0.04477456830708044, 0.08435951758708272, 0.008781152378235544, 0.008316544183929051, 0.05731162575206586, 0.018840566344027008, 0.012716797978750296, 0.01205565466079861, 0.04740630030365927, 0.03983466713024037, 0.022381022971655642, 0.014755658306447523, 0.018285134541136876, 0.05232910918337958, 0.028369006301675524, 0.03871365264058113, 0.013836234026322407, 0.03177661255800298, 0.02667452794100557, 0.11013709008693695, 0.06496481544205121, 0.024143410813329474, 0.04111557500436902, 0.02178778828653906, 0.02098691340402833, 0.0683029227490936, 0.024463184011567916, 0.02684135764970311, 0.04614331932472331, 0.02258904484499778, 0.04251781511785729, 0.039976389346910376, 0.0209297468287072, 0.08185584550457341, 0.07394079558019127, 0.010323467564636042, 0.05988465089883123, 0.09406008491558687, 0.05845928631190743, 0.0418691831374807, 0.03779414269540991, 0.0711258930553283, 0.014242811361327767, 0.006270125824292856, 0.08378998243382998, 0.04075599554926157, 0.02162721467071346, 0.00832327694765159, 0.04588174407503434, 0.03740768986088889, 0.039561882482043335, 0.04973333615011402, 0.02176769686463688, 0.029302338005176613, 0.06943929248622485, 0.05272868488516126, 0.021012675682348863, 0.051687934302857945, 0.056582845215286524, 0.028443144734150598, 0.01001503353472799, 0.0341573849852596, 0.01411147921213082, 0.03790222993120551, 0.02342100511305034, 0.020395166406940137, 0.05239132405923946, 0.04318734597680824, 0.015711218817159534, 0.0578489304919328, 0.07071547436394862, 0.039472119084426334, 0.03094363957643509, 0.030727787408977747, 0.025994644334007586, 0.06723192307565894, 0.04386336702321257, 0.06986296296651874, 0.015957494798515524, 0.06781835375087601, 0.025101385212370327, 0.005353075992648623, 0.1389691015439374, 0.03586949168571404, 0.05109712029142039, 0.017229571539376463, 0.05243676554943834, 0.00928383571694472, 0.014111495327337511, 0.0682510623176183, 0.01645729351522667, 0.03748396737501025, 0.07635272294282913, 0.043257492927036116, 0.013209725680228854, 0.027698104801986898, 0.038359857696507654, 0.018447774296094264, 0.020510668334152018, 0.04532324190118483, 0.011529426156942333, 0.029232333547302654, 0.035898017297898016, 0.058635203300842216, 0.03782576921262911, 0.004038539074826986, 0.03989520602460418, 0.024330140257786428, 0.026570108186985766, 0.015499115555680223, 0.02531603637284466, 0.034433962644210885, 0.04958829928987792, 0.03907192591577768, 0.09019877961171524, 0.025654698289664726, 0.019226213418213383, 0.05287849523925355, 0.011160532112366386, 0.02184279203148825, 0.008592099799508495, 0.032314392272382975, 0.06376532159213509, 0.01848323453616883, 0.032079778611660004, 0.042281759570219686, 0.018516095987121974, 0.02641713585970657, 0.042740785117660246, 0.021681164990046194, 0.03497831057757139, 0.03297940408810973, 0.01811274084528642, 0.02840536051163716, 0.08614079414733819, 0.0031603109881481422, 0.024577754649466703, 0.03244806027838162, 0.019272760920492665, 0.021005004843963043, 0.05695373924182994, 0.004973070088973535, 0.029501918902886764, 0.016636004372100745, 0.014614188844071967, 0.024000311170571616, 0.03835781191342643, 0.0730478638517005, 0.0074913539990250555, 0.05347037794334548, 0.017549546601782953, 0.00431666845854904, 0.07078142118241106, 0.05282397834318025, 0.014706155784162027, 0.05997159837612084, 0.05157062577615891, 0.03495002584531903, 0.03482307194332991, 0.010569733367966754, 0.06782095932534762, 0.027041886800101826, 0.049784548580646515, 0.02072072750888765, 0.04292845772579312, 0.08514799563480274, 0.0348016913048923, 0.019933501358277032, 0.053771511784621646, 0.022093973821029067, 0.04403603382940803, 0.09407594906432287, 0.023526298480906656, 0.038674728479236364, 0.038359803413706164, 0.03802294470369816, 0.039964297852878056, 0.025288364018446634, 0.04570471768134406, 0.06908173167279788, 0.02981670486873814, 0.00703008207658838, 0.024588205785091435, 0.009711656287046415, 0.052234022678541284, 0.016017658802281533, 0.09458883332886867, 0.03847907290660909, 0.027002321423164437, 0.049702347455812354, 0.030340008038495268, 0.03800008825159498, 0.03211699625743287, 0.032594688303236447, 0.017516239014055048, 0.04962019382842949, 0.039602957599397214, 0.03435454690562827, 0.0673142700855221, 0.03273051744326949, 0.005413866369053721, 0.024077036517805288, 0.0658778114510434, 0.018139936528833847, 0.05010633024254015, 0.05109182093292475, 0.024959260963701775, 0.07769586265619312, 0.01858493166842631, 0.031472255675388236, 0.02671659711216177, 0.03052358908046569, 0.01796289486810565, 0.04997160711458751, 0.03711750418213861, 0.043613547392721684, 0.03964868068162884, 0.04054650464760406, 0.005336769947981728, 0.023685833938153725, 0.037531953371529064, 0.03794620917843921, 0.053482011426240206, 0.02819430728309921, 0.04841609951108694, 0.03557746039171304, 0.048109208300177536, 0.060338916523115974, 0.021255513187497854, 0.017399676875876527, 0.09478682984731027, 0.011730141056302403, 0.05838420641209398, 0.04661390032353146, 0.032358839708779535, 0.06534237268247775, 0.03446274609970195, 0.06348723080009222, 0.038446740712970495, 0.016642927125628506, 0.016455748151721697, 0.00785872049164027, 0.04443904631105917, 0.03515679582155176, 0.026641778448330503, 0.03606729142900024, 0.03990496675084744, 0.017985267864008034, 0.019717489735090306, 0.05475870899057814, 0.01936067870285894, 0.040179118647107055, 0.04567642277106643, 0.06881143724811928, 0.033282176591455936, 0.010599322583792465, 0.030375648090349774, 0.03453175311109849, 0.12745700856404646, 0.026689637219533324, 0.020127650583162904, 0.01992817146570555, 0.024836393538862467, 0.030349351465702057, 0.06971580229167428, 0.07598340990287916, 0.009242956526577473, 0.009468566027602978, 0.001991121784418023, 0.04304643121681043, 0.03997100856421249, 0.03709772488634501, 0.022863985538216572, 0.025662111284743463, 0.049917836607034714, 0.08331825810351542, 0.021841969307778136, 0.04340946102248771, 0.02608247221048389, 0.04005024449101516, 0.03418512010414686, 0.03327176107891968, 0.015821228003395454, 0.04923130166051643, 0.02232823464354234, 0.02516119977060173, 0.04066568932362965, 0.05579659615510276, 0.07163300298686538, 0.03415553258465869, 0.0431683911010623, 0.017624780868313143, 0.019987804515819465, 0.01257795699140323, 0.04421852582267352, 0.04553914835144367, 0.02304857929370233, 0.02832703891077212, 0.07987875730863639, 0.0283534797241113, 0.039491762673216205, 0.036399637881134234, 0.022422252455726266, 0.03805498173460364, 0.03828178206458688, 0.035479490113045485, 0.03364979668653437, 0.03174539655447006, 0.014828940088461553, 0.024545934749767184, 0.012857569398225417, 0.03325665010405438, 0.01508241702270295, 0.016842090724302188, 0.04328093970460551, 0.053957576264760325, 0.062007169505315166, 0.03977924778259226, 0.12024962316666331, 0.1248440109193325, 0.14161765442362853, 0.2482564757977213, 0.19210174546710082, 0.14574932200568064, 0.23514888914568083, 0.12632589068795952, 0.08522167775247778, 0.05475125867607338, 0.1998523117176124, 0.2118235014911209, 0.11489956453442574, 0.15175335268889154, 0.11946728586086205, 0.1106837789661118, 0.1156946447278772, 0.08625456411391497, 0.16383901132004602, 0.15122427179345063, 0.17776617327971117, 0.10810997350407497, 0.18321755076093332, 0.1583147727485214, 0.12021565570362977, 0.16146548225411347, 0.23646104016474315, 0.08005115948617458, 0.14367874525487423, 0.18600683180349215, 0.0684669857312526, 0.17341692665857927, 0.1302343202488763, 0.12504058251423494, 0.12950488153312886, 0.17157559974917344, 0.08141050940113408, 0.16249996317284449, 0.1951142373893942, 0.1042377437864031, 0.09610025651220765, 0.08425239047833852, 0.13303240867597715, 0.08786992529141051, 0.12184437045029231, 0.08340194861271552, 0.1774121815604823, 0.10771921875753573, 0.10816228176866259, 0.13313298113644123, 0.08445527923426457, 0.09264235384762287, 0.11679507925042085, 0.18371702038816043, 0.1412098277360201, 0.1163526608475617, 0.16109664418867656, 0.050047874450683594, 0.10514252952166966, 0.13351040945521422, 0.14105632954410144, 0.12120521760412625, 0.12698624096810818, 0.13662559086722986, 0.12496963489268507, 0.23663227526204927, 0.09613150983516659, 0.18933885943676743, 0.1493340903627021, 0.10742515525115387, 0.13695769304675715, 0.18572807604713099, 0.15410857488002094, 0.10178776417991944, 0.175260832001056, 0.20003432195101464, 0.07751240035785095, 0.0685027784534863, 0.15266965994877474, 0.1707544366696051, 0.15221415939075605, 0.12630735311125005, 0.14365996340555803, 0.10266221261450223, 0.13911396877041884, 0.17351022522364343, 0.09817611905080931, 0.11665967080209937, 0.16822598448821477, 0.07963877304324082, 0.144647286140493, 0.18211984394916467, 0.10737771208264998, 0.11406944479261126, 0.11945032248539583, 0.15944114087947778, 0.09004293368863207, 0.10759966767260007, 0.11539254736687456, 0.08752971461841039, 0.1190411387277501, 0.208927826157638, 0.08764416312000581, 0.11852071593914713, 0.1847179409648691, 0.09989806450903416, 0.06597051290529114, 0.13410148130995886, 0.14913424822900975, 0.1426001459892307, 0.10790409919406686, 0.10507278969245297, 0.16232331336608954, 0.1923945333276476, 0.1348242839532239, 0.11824012813823563, 0.25078600006444113, 0.12879631455455506, 0.17990023376686232, 0.10864917814199414, 0.15757955291441508, 0.13095301096992834, 0.15406586788594723, 0.16260889518473828, 0.1797931066581181, 0.16343163246554987, 0.14369036177439348, 0.12627698188381536, 0.10007115200694118, 0.0953299632029874, 0.10790350208325045, 0.11030169589711086, 0.08736362960189581, 0.12685807927378587, 0.08012299598859889, 0.09755668443228517, 0.12452893996877329, 0.18099804914423398, 0.1865910640252488, 0.11723725338067327, 0.11401280068925448, 0.08792288494961602, 0.10140857845544815, 0.1128734318273408, 0.10067472926207952, 0.12137707695364952, 0.24839926670704568, 0.12839699669608048, 0.1650817889188017, 0.13330066071024962, 0.04838508028270943, 0.14128707216254302, 0.14017735528094427, 0.07782767486891576, 0.14092473446258477, 0.11266201388623033, 0.20497203485241958, 0.09291950826134, 0.12516379090292112, 0.16035465257508413, 0.10730258468538523, 0.11869200531925474, 0.12609038475368703, 0.08816453162580729, 0.1404158603399992, 0.1586952001920768, 0.09654490050992795, 0.2078305400375809, 0.1707458599869694, 0.06762102898210287, 0.07903448332633291, 0.1092842665633985, 0.13316027181489126, 0.14885507178093704, 0.17004605968083653, 0.09907839420650687], [0.05091155792719551, 0.03357035380655101, 0.056518380995839834, 0.04863187703969223, 0.02267182611727289, 0.02373288355634681, 0.04352181624355061, 0.05837466620973178, 0.0383130455655711, 0.05651122584406819, 0.05669404014146753, 0.02137349346386535, 0.038876677464161596, 0.00868674780109099, 0.03142210175948484, 0.054659198437418254, 0.029656638457838978, 0.022697545987154757, 0.09457917777555329, 0.03865225200674363, 0.026605230855888555, 0.025176780630967448, 0.03421221740011658, 0.03986343701503106, 0.031148916775626794, 0.04684000176244548, 0.012273759564517863, 0.05522592784836888, 0.019214861527351395, 0.06380793359130621, 0.01260070996691606, 0.01819580540593181, 0.04627023251461131, 0.040945791972002814, 0.01938763350647475, 0.044093420928610225, 0.03527588210999966, 0.023532074510252902, 0.041529131920209954, 0.021258018678054214, 0.043465050003890476, 0.03523130575194955, 0.03011019162035414, 0.034512048454156945, 0.03099239571020007, 0.021752930246293545, 0.03827185509726405, 0.059352489454405646, 0.021838420569630604, 0.029141993394919803, 0.02221450030005404, 0.026606991654261947, 0.03285826862390552, 0.04013513939987336, 0.016687347420624325, 0.029691311597291912, 0.02525328884699515, 0.031400605770094056, 0.033399128887270174, 0.044101220688649585, 0.03692060010507703, 0.023054448621613637, 0.049008579325995276, 0.07843964560223476, 0.038961589336395264, 0.023565327815179313, 0.02381633488195283, 0.026284577258463417, 0.0404368398178901, 0.05913117847272328, 0.0296378023257213, 0.03498501789623073, 0.02358461856575949, 0.014323489175045064, 0.04011705983430147, 0.0707432942997132, 0.047105716075748205, 0.016690198964040195, 0.00877911422867328, 0.028225886302867105, 0.03778584421213184, 0.050941084378532, 0.010582298988343349, 0.008966209233871527, 0.04795968632346817, 0.04223529688481774, 0.03038154116698674, 0.04858020659802215, 0.07347132398613862, 0.028927474548774104, 0.04644956932004009, 0.08805085665413312, 0.05685122956388763, 0.0805032334423491, 0.05919757990964821, 0.10701351519674063, 0.026250681041606834, 0.01989213955987777, 0.03829041303002408, 0.022708926715755036, 0.09038458964122192, 0.04880697639392955, 0.05295243859291077, 0.05088703906429665, 0.011859822669066489, 0.038812338773693354, 0.010006095532194843, 0.02278014744764992, 0.03213312842750123, 0.052490807470998595, 0.030368272414697067, 0.07692989161504166, 0.07301239004092556, 0.008155216546063977, 0.041573525073805025, 0.02224356195490275, 0.006872452454574938, 0.011607517055901033, 0.030276853391634564, 0.05559387364025627, 0.05082984534757478, 0.05304955391745482, 0.03959892710138645, 0.031549025127398114, 0.08442416161830936, 0.017981503690992082, 0.043447224888950586, 0.04337429594514625, 0.03905478272853153, 0.02287384295569999, 0.03387012039976461, 0.023602145125291178, 0.0326702194288373, 0.0234025014630918, 0.03789180763331907, 0.057341067386525016, 0.013610174147678273, 0.054959273764065335, 0.04592643578403762, 0.014616292302629777, 0.06323929410427809, 0.059152240199702125, 0.020928405025707822, 0.0725522618740797, 0.061961314108754904, 0.0185889265433486, 0.026179599409390773, 0.04071136151573487, 0.015446271248427885, 0.02363168854000313, 0.04025949451274105, 0.04697064689493605, 0.03889646015263029, 0.041564693940537314, 0.0197643069550395, 0.05900913716426917, 0.034850898664444685, 0.08182164055428334, 0.023658980914790715, 0.03828195848369172, 0.014059394864099366, 0.023906844668090343, 0.046694445822920115, 0.0399920363644404, 0.022011482622474432, 0.014002916153653391, 0.043723107049507756, 0.010446361282707324, 0.11830685527196952, 0.036554428682263405, 0.0027295648719051053, 0.04355684561388833, 0.106672049233956, 0.06577729327338082, 0.021788113983348012, 0.0497485624759325, 0.02604652172885835, 0.01369026248409812, 0.04928895678105099, 0.06578325759619474, 0.05455095853124346, 0.039389507445905886, 0.0014176912040316633, 0.014015711627767553, 0.05068426565932376, 0.04094971051173551, 0.033167080088917694, 0.06250751444271632, 0.10990733134427241, 0.04316960567874568, 0.01678281560141061, 0.07313659587608916, 0.04029966039316995, 0.03656943787687591, 0.025484837225771377, 0.02522109914571047, 0.03426817279042942, 0.02887487451412848, 0.032138689021979056, 0.07552220965070383, 0.02276494656689465, 0.02640190444487546, 0.047563225097422085, 0.05312672031245061, 0.03781577778447952, 0.034411662590823004, 0.09220093289124114, 0.0018439072508564486, 0.035703328637672324, 0.04606934882966535, 0.05455847669925008, 0.056337113758283, 0.05279078780274306, 0.040477579060409746, 0.03962377844644444, 0.01844154704096062, 0.01857818363766585, 0.013166817670155848, 0.016049315853576576, 0.055998511213277063, 0.012285537236104054, 0.010541410468119596, 0.023043259579156126, 0.030592395924031734, 0.05954904069325753, 0.022450106318241785, 0.08504272771200963, 0.06276708801410028, 0.015450301746438657, 0.060090633774442334, 0.04426007591454046, 0.043562514773969135, 0.03695212484204343, 0.01810709882660636, 0.027470122124733667, 0.02678082214801439, 0.03694999763475997, 0.09672669361212424, 0.03864726138168147, 0.03418607683852315, 0.07310750029448952, 0.07967739525650229, 0.07054563026343073, 0.029756057408771346, 0.06609807070344687, 0.01909914586160864, 0.04511224465178592, 0.020590229957763637, 0.02780513182681586, 0.040796056256762574, 0.07104656552629811, 0.032116823231003115, 0.02543448653471257, 0.053043972966926436, 0.014869233194206442, 0.056995333438473086, 0.05413734733260103, 0.037981072307697365, 0.04716634996501463, 0.02956242047782455, 0.13051804288157395, 0.05204026361129113, 0.03788783820345998, 0.014937258026163493, 0.05477989963921053, 0.009615704650059342, 0.016622771242899553, 0.00962608793218221, 0.06174220158053296, 0.056524776188390594, 0.06167067720421723, 0.0807001239487103, 0.013239453147564615, 0.05706946338926043, 0.02438701336671199, 0.04934162127652338, 0.06162496430001088, 0.026006737524377446, 0.027963359407814484, 0.01663571429838027, 0.02142041246406734, 0.05025783014882888, 0.07277301645704679, 0.030382837168872356, 0.026039344524698596, 0.0583895668387413, 0.03591082125369992, 0.09761799007122006, 0.033631893540067334, 0.08171401132962533, 0.02576441570584263, 0.037310387939214706, 0.022904514434880445, 0.11345583200454712, 0.009482804236800542, 0.014941753320662039, 0.048259988959346495, 0.035026825831404755, 0.0128594862596531, 0.04662397317588329, 0.030917390449238673, 0.05438140620078359, 0.0075363408707614455, 0.027149069887985076, 0.047296214782233746, 0.03139353543519974, 0.027813796719004, 0.02179681958763727, 0.017768825371084467, 0.09403529124600546, 0.0463971524898495, 0.025714490795508027, 0.0012473102126802716, 0.025625799483220493, 0.025745124955262457, 0.011178576903018569, 0.031210853452129022, 0.043462206942162344, 0.052661492954939604, 0.05742443219891616, 0.015179204954100507, 0.06507423599915844, 0.0032673649423356566, 0.03152666400585856, 0.06091407673167331, 0.04745677652369652, 0.023894212042380656, 0.007950206520035863, 0.015017903609467404, 0.0044321742025204, 0.04395929491147399, 0.0438374944829515, 0.05169495374762586, 0.15795904397964478, 0.05879192453409944, 0.017388828797265887, 0.01777473371475935, 0.01421214412299118, 0.05388103412198169, 0.017972404536392008, 0.018959613616711328, 0.060278601545308313, 0.0432680916440274, 0.0431294805104179, 0.05726246588996478, 0.06282336570854698, 0.02790383153062846, 0.029388746047126393, 0.06783717631229333, 0.06384361774793693, 0.04452546453103423, 0.028470009631876434, 0.18103245086967945, 0.11372064386627503, 0.1998197284660169, 0.1300831019346203, 0.10932944342494011, 0.12239493376442365, 0.1677781513759068, 0.0778806209564209, 0.13398185558617115, 0.19698046653398446, 0.14360196223216398, 0.1732896063476801, 0.19878496256257805, 0.1087395047236766, 0.08115935644933156, 0.17499727542911256, 0.08898678036140543, 0.1885114266936268, 0.19695557786950044, 0.09159768811826195, 0.10473313541816813, 0.1254091084535633, 0.10626330652407237, 0.19130353044186318, 0.12345741103802409, 0.11188726260193757, 0.10594934158559356, 0.0852439065596887, 0.14713058860174247, 0.17121874461216585, 0.09360404152955328, 0.06726539520812885, 0.07836979042206492, 0.14508488694471972, 0.1754399516752788, 0.16473831449236187, 0.20581906368689878, 0.11643145233392715, 0.12397739956421511, 0.05283406137355736, 0.17676810255008085, 0.12415767274796963, 0.1503795771194356, 0.23506192809769086, 0.0882890292310289, 0.0660570871883205, 0.10452838747629098, 0.1337570705051933, 0.10312622878700495, 0.10381442614431892, 0.25063672236033846, 0.16738508961030416, 0.07759117827351604, 0.20117880696696894, 0.14275671115943364, 0.15560668520629406, 0.11047576727079493, 0.12224728454436574, 0.11391197038548333, 0.08900736032852105, 0.13168159473155225, 0.26212149752037867, 0.13093104000602449, 0.14758451495851788, 0.08554351369717292, 0.14028741366096906, 0.10265987845403807, 0.10547476062285048, 0.1636242549866438, 0.17406274271862848, 0.10299149887370211, 0.14221563376486301, 0.0863738777115941, 0.09755694906094245, 0.17557749072355883, 0.12389969373387949, 0.06664418961320605, 0.09726706533027546, 0.14309582939105375, 0.14778806189341204, 0.12665959421013082, 0.17274315495576176, 0.1231645688946758, 0.1856054783399616, 0.2718879777405943, 0.11083184209253107, 0.08233934241746153, 0.08528650498815946, 0.15069144538470677, 0.07695651054382324, 0.1932733990252018, 0.14570692713771546, 0.2448635564318725, 0.20184510121388094, 0.142808537664158, 0.15500439038234098, 0.16495562211743423, 0.17785770765372685, 0.12547233434660093, 0.10447093591626201, 0.27000224749956814, 0.10799821878650359, 0.20512360600488527, 0.11971492400126797, 0.15133978559502534, 0.15263056276100023, 0.13157216060374463, 0.103380530141294, 0.11207002600921051, 0.2336184126990182, 0.1862535471362727, 0.27060877638203756, 0.16585390748722212, 0.09459964917706591, 0.18732742379818643, 0.16011970303952694, 0.11715364429567542, 0.23323259768741472, 0.09421972384942429, 0.09226101716714245, 0.11875600474221365, 0.13288636079856328, 0.1481777038425207, 0.1234075522848538, 0.19547523159001554, 0.18002889757709845, 0.11471159676355974, 0.10501613201839582, 0.11030091558183942, 0.11035483197442122, 0.12116270059985773, 0.23323243483901024, 0.18400197795459203, 0.10605026688426733, 0.10391100881887333, 0.11578598911208765, 0.06003466820610421, 0.1323010836328779, 0.2057790301207985, 0.1668790110519954, 0.228940483714853, 0.19194014556705952, 0.10227358846792153, 0.13688791250543936, 0.13083015541945184, 0.14672474323638848, 0.09598547552845307, 0.14071102307311126, 0.29197763545172556, 0.12096296703176838, 0.09527576182569776, 0.10048900744212524, 0.09886813656027828, 0.14279755896755628, 0.10246125089802913, 0.20811355699385914, 0.1208707405520337, 0.24531787633895874, 0.13056848517486028, 0.17211997482393468, 0.11153097743434565, 0.0746968396540199, 0.14499203621276788, 0.04950156555111919, 0.09406184232128517, 0.1356917909745659, 0.0946402662832822, 0.08539272964532886, 0.2948169788079602, 0.19964234584144183, 0.046521609382969994, 0.11716992913612298, 0.1725128601704325, 0.14534893206187657, 0.11624565587512084, 0.1364338504416602], [0.025277079981086508, 0.025876440141083937, 0.021533091685601642, 0.015387829027271696, 0.02315837813408247, 0.02646912182016032, 0.06556557677686214, 0.08664635701903275, 0.058498804191393514, 0.09332446474581957, 0.032407409245414395, 0.017471167325441326, 0.07345287461898156, 0.03081569162064365, 0.036903005692043474, 0.05406806890719703, 0.020899797989321605, 0.049769576705460034, 0.04588070930913091, 0.010851985276011484, 0.08777900838426181, 0.05073179364470499, 0.044266148802957365, 0.061506797426513264, 0.01181056272305016, 0.038076382729091814, 0.028163182881793807, 0.014493239976997887, 0.020428624968709688, 0.01404138230386057, 0.04809576312878302, 0.020360837624009167, 0.021664917469024658, 0.04851506384355681, 0.04650628127689872, 0.05285700264253786, 0.03508125451792564, 0.04551997295181666, 0.018770624650642276, 0.06946702421243701, 0.042478487228176424, 0.05001883654456053, 0.0845989997365645, 0.027182606481281773, 0.01209059582158391, 0.022464777941682508, 0.054920492095074484, 0.03941936977207661, 0.073613605994199, 0.09677019449216978, 0.07216464874467679, 0.04065575557095664, 0.046543868724256754, 0.03788033360615373, 0.06924755884600536, 0.028652606798069816, 0.029793529505176202, 0.0294710760936141, 0.025302950825010027, 0.030798253270664384, 0.060551026569945474, 0.049264027404465845, 0.07669838903737919, 0.03146085628707494, 0.010236864443868399, 0.026542060941989933, 0.028818688421909298, 0.019795741786115935, 0.01975595249262239, 0.06634790729731321, 0.07289401960692235, 0.036352313456258604, 0.06847673627947058, 0.029021058098546097, 0.0626698335898774, 0.055493633661951335, 0.06596494213278804, 0.01501494858946119, 0.016066786433969225, 0.02790079339008246, 0.051995429409933944, 0.04182411144886698, 0.1145074934299503, 0.022317408617319803, 0.019253599091566036, 0.05271885630541614, 0.024604607672829713, 0.07279064479683127, 0.019259269947984388, 0.03439967626971858, 0.018200363464919583, 0.018222371748249446, 0.06540068598198039, 0.03005335752719215, 0.01513470323490245, 0.009662856048505222, 0.0395244952025158, 0.008795243854235326, 0.01559827327063041, 0.02527701891293483, 0.02324226711477552, 0.05611530066068683, 0.03685093491471239, 0.011552882264368236, 0.03720668064696448, 0.054395577404648066, 0.015074021848184722, 0.03408545348793268, 0.015533390055809702, 0.00693845991710467, 0.0673951989571963, 0.01693527224207563, 0.031878131574818065, 0.04551549462069358, 0.052871621679514647, 0.056262200099549124, 0.010100119281560183, 0.03494003102449434, 0.049831727120493136, 0.043185334120477946, 0.046413104848137925, 0.024810660098280226, 0.027095930417999625, 0.023047447836558734, 0.03496554733387061, 0.016997063033548847, 0.04542843857780099, 0.08091099906180586, 0.010882647425335432, 0.030703611206263304, 0.029232472646981478, 0.06666589594845261, 0.03393066268680351, 0.019767960866114924, 0.05695321676986558, 0.03261336497962475, 0.015833685906337838, 0.0388212004410369, 0.11058819373803479, 0.013293327131707753, 0.012822354278926338, 0.053750517911144664, 0.04855655286727207, 0.03357667096757463, 0.05378332507929631, 0.00969015436047422, 0.02303178046297814, 0.040452195065362115, 0.025709384819492698, 0.029707355557807853, 0.040719992481172085, 0.040905924646982124, 0.05161798752046057, 0.019802523743627325, 0.04837582167237997, 0.03695295944011637, 0.07419898494013719, 0.051353572601718564, 0.0202564484040652, 0.023275218471618633, 0.020364421985245178, 0.03521818967003908, 0.06578750522541148, 0.0457312585785985, 0.031735184602439404, 0.036953895818442106, 0.030970736872404814, 0.023234438516997864, 0.030808763778103248, 0.016768892062827945, 0.08845013380050659, 0.04013154316427452, 0.03169830283150077, 0.021349374936627488, 0.028645926620811224, 0.022139111666807106, 0.03870556789583393, 0.05368795358975019, 0.010475925053469837, 0.057646489569119046, 0.018650654570332596, 0.03459898575342127, 0.051539555657655, 0.01682116979333971, 0.018606702464499643, 0.028607433329203298, 0.0408169279939362, 0.0388061946390995, 0.04347084808562483, 0.047987272164651325, 0.02094041170286281, 0.027923670198236192, 0.016017170257068107, 0.03611492119463427, 0.047428681781249385, 0.03906194805832846, 0.03903145130191531, 0.07372032598193203, 0.016001136474577442, 0.040800378524831364, 0.04690789597641144, 0.029420464166573117, 0.021565160946920514, 0.005709614338619369, 0.03052905128736581, 0.02983018396688359, 0.034965313239289184, 0.01637329257625554, 0.030759553025875772, 0.00819717884795474, 0.033276744918631654, 0.028838433790951967, 0.00612430864878531, 0.00913370305871857, 0.008932847363342131, 0.04984262778556772, 0.04357098628367696, 0.04628938416551266, 0.026402772969699333, 0.02296615594864956, 0.0581571753802044, 0.004349746192539377, 0.051976254010306935, 0.006969288307508188, 0.028228425720174397, 0.06753313155578715, 0.04193039038883788, 0.01755989765349243, 0.04338936281523534, 0.019950122073558823, 0.0706419822360788, 0.011375158675946295, 0.004242990581717874, 0.032967302416052134, 0.043023381382226944, 0.032389577345124314, 0.125778448634914, 0.04875417279877833, 0.012805027887225151, 0.046236261658902676, 0.03686869896150061, 0.0604552242106625, 0.02288957479010735, 0.021520769489662986, 0.01730560478089111, 0.0619542369885104, 0.06797732093504497, 0.02817612763361207, 0.047768227489931245, 0.02039848274684378, 0.09180988637464386, 0.04141294976164188, 0.05689469312450715, 0.03504780613418136, 0.011099536903202534, 0.034815316288066764, 0.11341391211109501, 0.02490843360179237, 0.02705826154643936, 0.009301269826080118, 0.036669328409646235, 0.07411708576338631, 0.046249058829354386, 0.03157653293705412, 0.047687763414744816, 0.05608375896034496, 0.14616512826510838, 0.032727172265627553, 0.04711537162906357, 0.021707783918827772, 0.04225658931370292, 0.01772438980905073, 0.03252936573699117, 0.04572637651913932, 0.08202718238213233, 0.089508207381836, 0.02757507622508066, 0.04761208301143987, 0.057876445086938996, 0.028886660667402402, 0.06706409422414643, 0.04661777136581285, 0.006887480732984841, 0.10770830791443586, 0.036558937547462325, 0.02599336699183498, 0.04805053198443992, 0.03991561975064022, 0.0055805213549839595, 0.019959901459515095, 0.025073453318327665, 0.06998374219983816, 0.041117227237139425, 0.07972907248352255, 0.05873338731804064, 0.012329189938360026, 0.057172587141394615, 0.03046018337564809, 0.045209251410726986, 0.03369187942839094, 0.049925514230770726, 0.0375683839166803, 0.042716035552855046, 0.015058917658669608, 0.027991257375106215, 0.023606687917241027, 0.058659610205463, 0.025127030443400145, 0.002206030364115057, 0.03142192873305508, 0.057136706209608486, 0.02631623430975846, 0.026391107256391218, 0.025133339122736027, 0.021274349319615533, 0.062047338778419156, 0.022934892447665334, 0.04323865340224334, 0.02747754699417523, 0.07620240708014794, 0.03926557981009994, 0.04289941642699497, 0.0434128808389817, 0.04607630720628159, 0.024706610145845583, 0.04369113787210413, 0.015276715525292923, 0.023659211616697054, 0.02564285446091422, 0.024896905291825533, 0.05604022754622357, 0.05562145608876433, 0.04206627720434751, 0.05226829208965812, 0.07014835479536227, 0.04728300031274557, 0.03318506126691188, 0.0629386216668146, 0.08813099842518568, 0.033219466385032446, 0.0475406773787524, 0.02940002329913633, 0.024786007224715183, 0.09101361195955958, 0.02122778824663588, 0.015679665242454836, 0.06965040508657694, 0.04583168854670865, 0.020486432759623443, 0.014905504283628293, 0.044615024368145635, 0.03348890585558755, 0.11480271044586386, 0.09980023333004542, 0.059368407885943136, 0.16137005308909075, 0.10601395847541945, 0.16037671853389057, 0.1803710963577032, 0.15753277471022947, 0.17039764938609941, 0.1339359459068094, 0.1891730119075094, 0.10696717804031712, 0.12451454145567757, 0.08239912135260445, 0.16600539721548557, 0.10490694216319493, 0.06974193946059261, 0.10199571480708462, 0.12396920286118984, 0.14224529931587832, 0.1462918378944908, 0.12668879835733346, 0.06361712275871209, 0.22444320789405278, 0.11234707185732466, 0.12333121709525585, 0.09353236787553344, 0.09356571787170001, 0.05392383271828294, 0.08450002183339425, 0.19025052551712307, 0.11530230220939432, 0.11932555346616677, 0.11839513267789568, 0.08981054901544537, 0.11054619242038045, 0.11808322370052338, 0.14418981783092022, 0.06247708893248013, 0.12297980380909783, 0.13862988831741468, 0.1751068995467254, 0.2891159275812762, 0.06330944105450596, 0.14898297563195229, 0.06635991736714329, 0.10753448081335851, 0.11135286877730063, 0.1745336867336716, 0.2434555691267763, 0.19773513318172523, 0.19003386928566865, 0.1661364494689873, 0.10197530447372369, 0.17334591118352755, 0.08928998373448849, 0.11527699285319873, 0.12985993176698685, 0.12406729188348566, 0.14730244795126574, 0.1904679959905999, 0.10969031548925809, 0.24838200477617128, 0.06588937368776117, 0.13588316499122552, 0.1189353551183428, 0.12756770476698875, 0.11090804157512528, 0.09132980927824974, 0.1390272927071367, 0.17385999645505631, 0.16109745843069895, 0.23713797384074756, 0.09637291223875113, 0.21209818603737013, 0.17681976620640072, 0.1441183273813554, 0.16697240461196217, 0.15135509334504604, 0.12024289209927831, 0.20704307300703867, 0.13560959324240685, 0.19196204867746147, 0.09005645689155374, 0.13071462804717676, 0.14878316063966068, 0.08754295962197439, 0.09818928941552128, 0.121512485401971, 0.11814890589032855, 0.22714343800076417, 0.12899378181568213, 0.13425054188285554, 0.08280530598546777, 0.05568175749587161, 0.0973461689427495, 0.202147904251303, 0.10646082128265075, 0.19809198831873281, 0.11141917521932296, 0.05878800938704184, 0.1429243635918413, 0.1598714677883046, 0.07355653441378049, 0.11621240765920707, 0.16870813790176595, 0.08423533889331988, 0.1994936109653541, 0.07495750566678387, 0.09904338179954461, 0.0779527153021523, 0.14231678976544312, 0.13385233682181152, 0.11786728671618871, 0.155966865164893, 0.15051212214997836, 0.13016124202736787, 0.13096735520022257, 0.16159371180193766, 0.18629909040672438, 0.13015687226184777, 0.12637207178132875, 0.12783050137971128, 0.21784608332174166, 0.1326455215790442, 0.13704996023859295, 0.07909570754106555, 0.11132779690836157, 0.10082197136112622, 0.11604339815676212, 0.16867526966546262, 0.12132484332791396, 0.12143410103661673, 0.05167080807898726, 0.13336882633822306, 0.10837485321930476, 0.15935260563024453, 0.0816831583423274, 0.2119134616638933, 0.15416956160749706, 0.08767718741936342, 0.12696858548692294, 0.09923997375049762, 0.152268007929836, 0.11035086254456214, 0.15197052460696014, 0.20423425015594276, 0.07984558373157467, 0.13083387379135403, 0.11101036465593747, 0.15792722068727016, 0.10676992791039602, 0.11858068486409527, 0.1629773804119655, 0.17218630840735777, 0.1438602398016623, 0.13865625618823937, 0.10541131759860686, 0.1081488196338926, 0.08890090496944529, 0.10549025836267642, 0.17231850059969084, 0.2389248279588563, 0.16104427485593728, 0.1114439485328538, 0.1213995771748679, 0.10613767576536962, 0.17766258812376431, 0.10309715356145586, 0.11842787877789565, 0.21181396128875868, 0.17672493415219442, 0.21524752490222454, 0.09883197064378432, 0.1573547814041376, 0.0801219374739698], [0.0330049712876124, 0.008680047267781836, 0.03715899659852896, 0.029765024249042784, 0.0290972134763641, 0.029056742255176817, 0.04615352788407888, 0.03490201610007456, 0.03682351531460881, 0.012806693690695932, 0.025430757984785095, 0.04189935080440981, 0.011829858562642974, 0.06509372352489404, 0.018029440493722047, 0.021111394045874476, 0.009511267932664071, 0.03275973516117249, 0.041027599546526156, 0.05671268967645509, 0.009732122599546398, 0.00920318758913449, 0.0431180879074548, 0.052849226631224155, 0.06007114624870675, 0.04081883128466351, 0.02815717615054122, 0.033595225507659573, 0.07647501530924014, 0.016356247776587094, 0.058947655106229443, 0.010960077600819724, 0.02126483286597899, 0.0645707765860217, 0.04323545750230551, 0.03008988985259618, 0.017271479558465735, 0.021412549939538752, 0.04927119951961296, 0.027151760279334018, 0.05429025859172855, 0.03709129237436822, 0.018215881560796073, 0.03812133567407727, 0.08775082203958716, 0.017410026231248463, 0.04875196755996772, 0.07693859721933093, 0.07442817371338606, 0.06992583602134671, 0.027882929259378995, 0.0741093165374228, 0.032045655085572174, 0.057128903056894026, 0.017186506618080393, 0.006804366978550596, 0.059423389578504224, 0.02194596837008638, 0.08061424855675016, 0.024748423170032244, 0.038232483102806976, 0.02765898556182427, 0.0121816560692553, 0.007951482165870922, 0.03740086719127638, 0.02328289270267955, 0.014495122911674636, 0.03928640404982226, 0.08459677414170333, 0.03171711860756789, 0.018472518771886826, 0.011109951567570013, 0.01197569354969476, 0.03967712486961058, 0.07115806240056242, 0.019862085547564284, 0.047984395176172256, 0.05663665982761553, 0.06165059256766524, 0.05225178333265441, 0.06854670002524342, 0.036701579179082594, 0.00951252576695489, 0.011340532185775893, 0.06818063716803278, 0.07454680877604655, 0.035354751627892256, 0.04164344132212656, 0.030748116318136454, 0.035846007588718615, 0.029209772257932594, 0.038893081048237424, 0.07807678543031216, 0.034019513454820426, 0.04965474143890398, 0.02599193697928318, 0.035024016696427546, 0.030033483236495937, 0.06561431594725166, 0.009019866086808699, 0.023548503539391925, 0.049397335786904605, 0.0396495017090014, 0.06248289040688958, 0.043520164010780196, 0.0220166445776288, 0.020102955301159194, 0.034548526496759484, 0.080486310778984, 0.024317799402134757, 0.018723176393125738, 0.030816784062023674, 0.03006552705275161, 0.002518223690068615, 0.06323712279221841, 0.03515434291745935, 0.010978036726425802, 0.036350854605968506, 0.03032854079668011, 0.01805980154313147, 0.01912708454100149, 0.01110263356739389, 0.022325059099655067, 0.04999508103355765, 0.02768801837893469, 0.02371527048360024, 0.013939702134978558, 0.05067036247679165, 0.059945162651794295, 0.00967577365892274, 0.06924918054469995, 0.04063993552699685, 0.0327158509088414, 0.02100659261590668, 0.016033802846712724, 0.025498597915949564, 0.06255290165011372, 0.04745366204796093, 0.00937506729470832, 0.04594579778079476, 0.02457536450986351, 0.01997010492985802, 0.030897706148347685, 0.022311836148479154, 0.031251199144337855, 0.015619550432477678, 0.06537254713475704, 0.040188509571765146, 0.04712465059544359, 0.06131189502775669, 0.02349557271892471, 0.03766428805621607, 0.04267858720517584, 0.03705812558265669, 0.02141923690214753, 0.017451255715319088, 0.023790674383885095, 0.07069482654333115, 0.04985486516462905, 0.020304018797885095, 0.014296218852645584, 0.0511385821737349, 0.02365059931097286, 0.024503207399642894, 0.052341536552246125, 0.016188965145764605, 0.01574907767852502, 0.04059099279610174, 0.06837380251714162, 0.0278073709923774, 0.03207640289994223, 0.06459048802831344, 0.07195686775126628, 0.05190109268629125, 0.021645955807928528, 0.017459410009905696, 0.07246441194521529, 0.004269272363412061, 0.05658053480354803, 0.04458060907199979, 0.021259733675313846, 0.024450027217556323, 0.01904532785660454, 0.009382724562393767, 0.03147956010486398, 0.04615245240607432, 0.022882299198369895, 0.0300755218735763, 0.03775941527315548, 0.03295148915744253, 0.02969385271093675, 0.026190888535763537, 0.02948968152382544, 0.02460919287321823, 0.04414531867951155, 0.026855187889720713, 0.046804877397205145, 0.09806725489241735, 0.06328660156577826, 0.05896543272371803, 0.029675701899187903, 0.08978455433888094, 0.013222957961261272, 0.08009071807776179, 0.017962787998840213, 0.006968737845974309, 0.03747148572334221, 0.04998732877096959, 0.015391640697738953, 0.02173228751468871, 0.043415683188608716, 0.015579676322106804, 0.019111770005630593, 0.0231146618191685, 0.03599326665114079, 0.048983731373612366, 0.0689801142684051, 0.09107448333608252, 0.051670234716896496, 0.02186148227857692, 0.05186293187684246, 0.0379724175935345, 0.05835496833814042, 0.027929802458467226, 0.019129583246207664, 0.006252135316442166, 0.04192658380738326, 0.05355528981557914, 0.05022772355005145, 0.025030374826331223, 0.024970768917618052, 0.05246818172080176, 0.03943891836596387, 0.0798509848703231, 0.0030371261361454216, 0.002379436561438654, 0.033456149577562294, 0.11642265852008547, 0.03867931876863752, 0.02822770138404199, 0.01941581136946167, 0.03583771249811564, 0.026842024310358932, 0.08136529182749135, 0.033614003964300664, 0.02800592899854694, 0.02508429461158812, 0.03122053275417004, 0.011474276526964136, 0.019441629626921246, 0.04119728758398976, 0.008503652759827673, 0.05082456634512969, 0.04402829853019544, 0.025473134193037237, 0.01213361494176622, 0.06508587287472826, 0.026184975103076016, 0.006918958820668715, 0.029347423264490705, 0.048171056767127345, 0.0893269774637052, 0.03239705819370491, 0.02577266499533185, 0.03228523222995656, 0.07327546485300575, 0.02037353640688317, 0.02589161557677601, 0.061694134159811904, 0.06051509814070804, 0.016342658416501114, 0.00021469017623790672, 0.03723010028313313, 0.025938463330801045, 0.009529858095837491, 0.05002962525135704, 0.046136886812746525, 0.07988506768430982, 0.05695200897753239, 0.04863453350429024, 0.030109268812728778, 0.031829154917172024, 0.02373539243957826, 0.022767177250768458, 0.045093527263296504, 0.08166852912732533, 0.05001210547717554, 0.04397642792069486, 0.04456991536010589, 0.00831671042500862, 0.046981160795050006, 0.01032137343593474, 0.0225801238058401, 0.05050015875271388, 0.03058582091970103, 0.024486859794706106, 0.023483201329197203, 0.04743195232003927, 0.0526310708373785, 0.05123158896874104, 0.04059490115780916, 0.019260438724554012, 0.02145816445616739, 0.052770282474479506, 0.03976263724533575, 0.046177649803991826, 0.012617273854890039, 0.05196184871186103, 0.0557950219538595, 0.02148420493384557, 0.025710713051791702, 0.04411811621061393, 0.036263316803212674, 0.08162741669054542, 0.05732173592384372, 0.02911418702985559, 0.02825533811535154, 0.08585492055863142, 0.08426271099597216, 0.009499369821112071, 0.04606149817949959, 0.010979518477272774, 0.09897066998694624, 0.042993098364344666, 0.01933620564107384, 0.06526833094124283, 0.013900322507002523, 0.007989600566881043, 0.033624426262187104, 0.0383692757625665, 0.04456420548792396, 0.015553203278354235, 0.01905534303347979, 0.04231748104627643, 0.023044430052063296, 0.09372282586991787, 0.009743185264856687, 0.012511945712114019, 0.012723967549391091, 0.03702361529160823, 0.007765483842896563, 0.032125277777335474, 0.017247137114671723, 0.07712665998509952, 0.03155316758368697, 0.04760583031124302, 0.01718917495704123, 0.020875609912244335, 0.040549340923982005, 0.012438919228900756, 0.040522362371640544, 0.029558440869940177, 0.2875867539218494, 0.09173595998436213, 0.16444737224706582, 0.13124241972608225, 0.1564740700913327, 0.12871160624282701, 0.10573115186499697, 0.1072666019733463, 0.15076252871326037, 0.10207974458379404, 0.0975081284663507, 0.1357873829879931, 0.07852026913315058, 0.11793875002435275, 0.07108960500253098, 0.12174687853881291, 0.11074348326240267, 0.22027266025543213, 0.1626689862459898, 0.11290165209876639, 0.13633968335177216, 0.14556822100920336, 0.16161151656082698, 0.1202283443084785, 0.14414979783552034, 0.17682682297059468, 0.11865870282053947, 0.1861752306244203, 0.2527003644832543, 0.14756780942635878, 0.08235784606742007, 0.14099436572619847, 0.07520028549645628, 0.1313306021371058, 0.11251314330313887, 0.08793698490730353, 0.09893718428377594, 0.1013735049803342, 0.2422705212874072, 0.0948086040360587, 0.21184589314673627, 0.11820857625986848, 0.10051858478358813, 0.13707655881132397, 0.19834623539022037, 0.07722324265965394, 0.13689567494605268, 0.15879152502332414, 0.11527247380997453, 0.16399899630674294, 0.1445176995226315, 0.1769635613475527, 0.13390452973544598, 0.13927350592400345, 0.08386690794889416, 0.1700265043015991, 0.12407581428331987, 0.2136725636997393, 0.14550143959266798, 0.12164399905928544, 0.14554961557899201, 0.16375560579555376, 0.12469599529036454, 0.05149780200528247, 0.11343379318714142, 0.0794062933751515, 0.15242898357766016, 0.1746964944260461, 0.19623344019055367, 0.08004174142011575, 0.08851646059857947, 0.1115004772852574, 0.12455958261021546, 0.10719291985567127, 0.16280793664710863, 0.18062960462910788, 0.13465707935392857, 0.1203014903834888, 0.21690316391842707, 0.11785283392029149, 0.09340915948684726, 0.0847545335335391, 0.10607885356460299, 0.07172885962894984, 0.16038722225597926, 0.20148488054318087, 0.13688781751053675, 0.16462502628564835, 0.1367695624274867, 0.1631654974605356, 0.1015911450875657, 0.12454122145261083, 0.16784885472484998, 0.1574500205793551, 0.13825339637696743, 0.08594716060906649, 0.14495937153697014, 0.07886782834040267, 0.10596494789102248, 0.12745846062898636, 0.10764263929533106, 0.17763430678418704, 0.10570935732019798, 0.25020297563501764, 0.10666880583656685, 0.08214140696717159, 0.08174238766410521, 0.12429959513247013, 0.15220111794769764, 0.12625233749193804, 0.15191484402332986, 0.10561426063733441, 0.1436604926628726, 0.05627495316522462, 0.12683137213545187, 0.09616865284208741, 0.10345480936978545, 0.1436367439372199, 0.08233701504234757, 0.1487959170980113, 0.11626240211938109, 0.18473703494029386, 0.13106832121099743, 0.15727794409862586, 0.2073620387486049, 0.0763164891728333, 0.09000169911554881, 0.13796615893287317, 0.1046921858297927, 0.09871379019958632, 0.13187884486147336, 0.13962749764323235, 0.24972919534359658, 0.07775037615959134, 0.21050521651548998, 0.12461238620536667, 0.15326275383787497, 0.14245073257812432, 0.14870024366038187, 0.14851144807679312, 0.14902828820049763, 0.16847857593425683, 0.1132808310378875, 0.0988682247698307, 0.1429232915065118, 0.05465443172891225, 0.16724402217992715, 0.10418760683387518, 0.13769839544381413, 0.1831013448536396, 0.14209674085889543, 0.1141994521021843, 0.07738820809338774, 0.1030488418681281, 0.09000743952180658, 0.09516915040356771, 0.12642840375857695, 0.14318915509751864, 0.161053543644292, 0.13957020214625768, 0.09923394835953202, 0.08701634859400136, 0.09631220371063266, 0.1337235373045717, 0.1576287874153682, 0.11748577361660344, 0.11995656389210906, 0.1532180519508464, 0.10137047871415104, 0.09751293927963291, 0.08420489302703313, 0.124187704707895, 0.13921091785388334, 0.12375321159405367, 0.0711559589420046, 0.14263530767389707], [0.026264977774449756, 0.012752700114755757, 0.009237892110832036, 0.026691923882546167, 0.0437288067436644, 0.018694737294156636, 0.03091012333918895, 0.018808537794809257, 0.044261392272476635, 0.05447726962821824, 0.037862016553325314, 0.03779938437842897, 0.006122767526124204, 0.0219507537383054, 0.047057445094521554, 0.03340903549854245, 0.07281729086701359, 0.038560666742601564, 0.05243113710145865, 0.05667410138994455, 0.09794975298323802, 0.026825305207499435, 0.031081117556563446, 0.09353653408054795, 0.037884876398103576, 0.07033541332930326, 0.022551654172795157, 0.015463867357798984, 0.04136684669979981, 0.004268700697658849, 0.01417008088901639, 0.0394980391221387, 0.06235376519284078, 0.08800629047410828, 0.041791429809693775, 0.03623420425823756, 0.05922638372118984, 0.014939490406374847, 0.03289115382358432, 0.03308377295200314, 0.003970293718988874, 0.049714337169591866, 0.031580027392400165, 0.03872219200379082, 0.05061704319502626, 0.02037927511680339, 0.03215203919847097, 0.0321753163422857, 0.06039072945713997, 0.02972982863762549, 0.005279243325016328, 0.027158418404204503, 0.051393416178013594, 0.018599888276574866, 0.008283518188233887, 0.02757963089139334, 0.03840596754369991, 0.06263610361410038, 0.022711598447390964, 0.03250571200624108, 0.015098204836249352, 0.049499611370265484, 0.0698711189574429, 0.04231583220618112, 0.028971552183585506, 0.044251309242099524, 0.04327207803726196, 0.030217820845012153, 0.03443772512088929, 0.03132555979703154, 0.03886087438357728, 0.042474877421877215, 0.05350210963349257, 0.025613838607179265, 0.02885937677430255, 0.04859803510563714, 0.040321424403893094, 0.04790116946345993, 0.021144474324371134, 0.008703276065976491, 0.019032308465934226, 0.015813016033332263, 0.08771792666188308, 0.06026632684682097, 0.029627743044069836, 0.0225290419932987, 0.021550501197842614, 0.015969467548919574, 0.021759327135181854, 0.0526142533469413, 0.022488755672903996, 0.045455685151474814, 0.013792796758934855, 0.019645714300817678, 0.04695153934881091, 0.03472618053534201, 0.05526034653718982, 0.039070117619952986, 0.08920965875898089, 0.039953074883669615, 0.016889308279912387, 0.03118790200512324, 0.02618727194411414, 0.015338189101644924, 0.03596651880070567, 0.03765560280797737, 0.03640627056094153, 0.04687298534970198, 0.058979512325354984, 0.020340490055137446, 0.028516821762812988, 0.04848059765728457, 0.034407282647277625, 0.045555680857173035, 0.02394051187937813, 0.029240401328674386, 0.020770654115559797, 0.0655725249754531, 0.045723577562187395, 0.01272028819325247, 0.04518409811758569, 0.016909986634605696, 0.04819640005007386, 0.015179956431633659, 0.02636171311938337, 0.04079118437532868, 0.048016737547836134, 0.05557864052908761, 0.024270198474239026, 0.06702684943697282, 0.04531581872808082, 0.06296805651592356, 0.03169330542108842, 0.04287253626223121, 0.025051955632599335, 0.041226294956036975, 0.030623852807496275, 0.018564295722171664, 0.007230777043982276, 0.01584155691255416, 0.11503099676753793, 0.0179059640837035, 0.015427399493221725, 0.010021101334132254, 0.051574191477681906, 0.05426644201257399, 0.024576579087546895, 0.030481411343706504, 0.03048850203465138, 0.050850544058318646, 0.04606728608320866, 0.04309245963980045, 0.041368322513465366, 0.03025276879114764, 0.017563882350389446, 0.009946106251196137, 0.03224503242277673, 0.04636988556012511, 0.036188172442572455, 0.020789934688114693, 0.0311512746848166, 0.03267556967745934, 0.010502849323009806, 0.011264374263451567, 0.03454385478315609, 0.03213367804086634, 0.0854637451203806, 0.06622931294675384, 0.01629804982803762, 0.04651439655572176, 0.030319210940173695, 0.10226242656686477, 0.025206736255703226, 0.044778195076755116, 0.045998357103339264, 0.0262934474074947, 0.0029258256129521343, 0.02151294767723552, 0.029150481868003095, 0.05186648400766509, 0.05308353155851364, 0.07103726959654263, 0.018269012549093792, 0.017436733369582465, 0.014370443798335535, 0.05866851258490767, 0.03255724674090743, 0.02490928177056568, 0.03358379897794553, 0.004038969944563827, 0.11329999965216432, 0.017063813916008388, 0.042466606079999886, 0.04036857240966388, 0.03476305891360555, 0.0326773983293346, 0.010081938783904272, 0.009466622872943324, 0.0491972799146814, 0.06204311829060316, 0.07776739381785903, 0.07992059577788625, 0.04748981439375451, 0.0528624580640878, 0.062435610086790154, 0.03724177787080407, 0.03940911032259464, 0.017667632051078335, 0.02139526595627623, 0.02037143294832536, 0.035058683050530295, 0.04106777221230524, 0.01717385702899524, 0.028390281767185246, 0.049050967408610244, 0.07168434773172651, 0.009308220569177397, 0.020711582553173815, 0.016789490689656565, 0.053338918568832536, 0.02956474106758833, 0.018648909038997123, 0.01925145661724465, 0.025466833995389085, 0.018746606207319667, 0.010532992393044489, 0.03274634087990437, 0.03811922203749418, 0.06090265020195927, 0.020779626044843878, 0.024838793856490935, 0.01199474511668086, 0.10986516039286341, 0.020483942536105002, 0.07129714172333479, 0.03950277529656887, 0.030126730911433697, 0.05262145599616425, 0.041911483010543246, 0.027714211526992064, 0.03849033998059375, 0.08491603843867779, 0.05100292606013162, 0.036409259507698674, 0.06202418716358287, 0.061191183647939136, 0.07508813044322388, 0.08242576742278677, 0.06380824571741478, 0.024822707487536327, 0.04172360005655459, 0.01964303239115647, 0.0423168432233589, 0.10324780190629618, 0.0243851253430226, 0.006617443727528942, 0.04066780974556293, 0.010421531141868659, 0.1231906246393919, 0.04783140927819269, 0.03516887374488371, 0.03465609804594091, 0.014098211308009923, 0.04239844045202647, 0.021697806061378548, 0.041924124117940664, 0.03550089789288385, 0.045519803318062, 0.006025869332786117, 0.023318614178736295, 0.004867404375025737, 0.013799999408157808, 0.05936810254518475, 0.03337855909817985, 0.01966882689989039, 0.02029232763951378, 0.04956580924668482, 0.029243624370012964, 0.061517477567706785, 0.015472437255084515, 0.05712047565196242, 0.0038296766662304954, 0.025710957324398414, 0.061914508763168535, 0.004261209246968585, 0.008825274965991932, 0.04627080587670207, 0.03752233174496463, 0.031247982888349464, 0.040581927568252595, 0.03198009163939527, 0.057328154865120134, 0.04536170805139201, 0.0633461701550654, 0.100863043085805, 0.046328247258705754, 0.0373694781613137, 0.03996744964803968, 0.024927988981029818, 0.044764929717140536, 0.06201409056250538, 0.04423115335937057, 0.031392592271523814, 0.025645405752584338, 0.013750566435711724, 0.04415336610483272, 0.051021684160722156, 0.04408282899696912, 0.01617314849447991, 0.06693040246942214, 0.0325906951246517, 0.07998015758182321, 0.028148694462808113, 0.024091485921027403, 0.05708015031580414, 0.04285238037950226, 0.04804267454892397, 0.008719992624329669, 0.012909222876520028, 0.0542785368992814, 0.045100448320486715, 0.033395973699433465, 0.017160747732434953, 0.01370496888245855, 0.030902706951435124, 0.014936038359467472, 0.03031801332586578, 0.040241377627743144, 0.019625745015218854, 0.053373639205736775, 0.05100869360779013, 0.11114974253411804, 0.07288186025938817, 0.01725298099751983, 0.053246949932404926, 0.0022378797376794474, 0.03359041469437735, 0.02689571169737194, 0.023132805845567157, 0.04465854899691684, 0.011824274219439497, 0.03179622561271701, 0.01643888316383319, 0.03465322105746184, 0.022153338849810616, 0.05387613170647195, 0.01732467331125268, 0.04585324899692621, 0.07365501698638711, 0.052470654980944734, 0.04312347208282777, 0.0420545826533011, 0.09339997212269477, 0.08257869564528976, 0.0643410449847579, 0.12137350785945143, 0.14554805494844913, 0.16913649705903872, 0.05076749476471117, 0.12806828719164642, 0.21903920572783264, 0.17411923754428113, 0.15441531342055115, 0.12163303393338408, 0.11396146272974354, 0.15227818595511572, 0.27955431065389086, 0.06875971930899791, 0.16203694444681915, 0.12720650700586184, 0.09075002146086522, 0.12755177276475088, 0.17675525109682763, 0.08432885458959, 0.17653802489595755, 0.15012566931545734, 0.10968464972185236, 0.23771988547274045, 0.11492407321929932, 0.11504876081432615, 0.18059748278132506, 0.09502940611647707, 0.20221881116075174, 0.11683683629546847, 0.16086561658552714, 0.15554005306746277, 0.14032105542719364, 0.17884294050080435, 0.17648710762815817, 0.08080381767026015, 0.1286022535392216, 0.14120566153100558, 0.08231910171785525, 0.11971443545605455, 0.09514565952122211, 0.19661092279212816, 0.11799489201179572, 0.12633312387125833, 0.15489822679332324, 0.08816635688500744, 0.22835640077080044, 0.11322231417787926, 0.07814215549400874, 0.09377748186567, 0.1630737323846136, 0.13514033199420997, 0.13674026328538144, 0.1407837348857096, 0.3076915293931961, 0.09828920369701726, 0.19270853219287737, 0.1409233638218471, 0.13090008523847374, 0.1473346512232508, 0.13914756982454232, 0.20302056813878672, 0.17462549252169474, 0.08865509887358972, 0.11184296105057001, 0.0869302289294345, 0.12021864125771181, 0.17535427984382423, 0.11492962363575186, 0.17980917436735971, 0.19436075139258588, 0.13464040096317018, 0.1173445704792227, 0.09924938503120627, 0.13864778807120665, 0.1069759243567075, 0.1723546122333833, 0.07197474714900766, 0.11184719510908638, 0.07502668909728527, 0.20217368858201162, 0.14487513819975512, 0.09688148102057831, 0.07374435969229255, 0.1164526090558086, 0.09080484709037201, 0.09340605179646186, 0.08976157235779933, 0.12997042440942355, 0.15961309522390366, 0.10192742025745766, 0.11744153313338757, 0.07123386833284583, 0.10397894374494042, 0.1540438019271408, 0.09645811588104282, 0.11195580142417125, 0.11482974328100681, 0.13151592362139905, 0.07831056788563728, 0.14237878072474683, 0.14330029913357326, 0.12925553348447594, 0.09719832973288638, 0.15692157750683172, 0.1711876541376114, 0.13127447372036322, 0.12661875997270855, 0.1715490554592439, 0.12223995636616435, 0.08989945745893888, 0.14486994062151226, 0.1116971235190119, 0.1999290675989219, 0.10297167208045721, 0.2607405701918261, 0.17469107971659728, 0.1562053837946483, 0.13286147213407926, 0.1501174047589302, 0.07121974801910774, 0.10734300501644611, 0.17343536924038613, 0.1221251618117094, 0.17014313090060437, 0.19808012752660684, 0.1336470799786704, 0.13142350715185913, 0.1280937458255461, 0.11750189560864653, 0.16261154147131102, 0.12688006380839006, 0.06444601435214281, 0.16092930388237747, 0.07672627004129545, 0.08520800527185202, 0.21437995002738067, 0.1616205817886761, 0.32398863775389536, 0.12123628093727998, 0.12079618312418461, 0.17390921738530907, 0.14172673571322644, 0.09467643898512636, 0.13160759370241845, 0.08744882645883731, 0.09602388061050858, 0.09495984270636525, 0.18769563761140617, 0.12417929087366376, 0.15017731940107687, 0.11738331482878753, 0.11754363908299378, 0.1528059776340212, 0.10731672535517386, 0.17961108285401547, 0.09020526640649353, 0.18533083450581345, 0.07622991488980395, 0.08775534786816154, 0.09923299162515573, 0.11938679803694997, 0.0791221364800419, 0.1303625362260001, 0.21455324787114347, 0.17804019286164216, 0.11186392778264624, 0.24598547337310656, 0.14057527535728045, 0.20897615142166615, 0.20677475311926433, 0.1105791013687849, 0.10349236628306763, 0.12399842057909284], [0.02067319443449378, 0.04086552806464689, 0.04018991753192885, 0.03293571661093405, 0.02629128796979785, 0.026990825343610983, 0.08772790112665721, 0.05183647579646536, 0.054544434417039156, 0.021421303041279316, 0.05883453653327056, 0.04865108297339507, 0.027081379234524708, 0.014594446867704391, 0.04440562506871564, 0.03205584328887718, 0.03658865738127913, 0.02438386496422546, 0.030191995802202394, 0.042037066271794696, 0.03620887454599142, 0.04057561719257917, 0.061002455917852264, 0.02364144756990884, 0.004737194777200264, 0.02992335021761911, 0.020405753249568597, 0.02724647698258715, 0.023296853560688238, 0.024096210221094743, 0.01645792116011892, 0.04894754510106785, 0.04466095440355795, 0.022196800714092593, 0.05888420529663563, 0.07111835453127112, 0.02868423331528902, 0.015966962058363215, 0.048956267668732574, 0.01820810215680727, 0.08616075664758682, 0.01319564862309822, 0.036561332776078155, 0.04227016679942608, 0.008430923983853842, 0.02825270200680409, 0.04573687345587781, 0.038848107747201405, 0.024312184524855444, 0.05326563000146832, 0.06891966358359371, 0.04909111632566367, 0.016952849691733718, 0.0023594630349959645, 0.01931494883527713, 0.010509747479643141, 0.07187797448464803, 0.04873914324811526, 0.03790217904107911, 0.08257939453635897, 0.03928576961957982, 0.015712365541341047, 0.05616595329982894, 0.03530393274767058, 0.022185004382793392, 0.1264929731509515, 0.027194328173728924, 0.008211265234941882, 0.055289031605103185, 0.06938038886125598, 0.010881392983719707, 0.06316228037966148, 0.05280852470813053, 0.036558018132512055, 0.031686601495104175, 0.009648803588269013, 0.02600689189109419, 0.029135666055870906, 0.03918791129919035, 0.018726411308827143, 0.045471342347030125, 0.06662675126322679, 0.0385004026549203, 0.04235067158671362, 0.055120741349778006, 0.06963901926896401, 0.011194034778912152, 0.06954511002238307, 0.08720836721892868, 0.017743846800710474, 0.04780201853385993, 0.012837923264929225, 0.05134914855339697, 0.03757028042205742, 0.02732483420654067, 0.029398520344070027, 0.04447958538574832, 0.037531732847648006, 0.022861671733802984, 0.06333094382924692, 0.01534208219631442, 0.033326376362570694, 0.03570810552420361, 0.028867692220956087, 0.025130881129630973, 0.014280995919502206, 0.023768382812184945, 0.062412539896156104, 0.018474425455289226, 0.013559691990459604, 0.010536137402855923, 0.021039053731198822, 0.02994758409581014, 0.024002102503020848, 0.04294883752507823, 0.061100918134408336, 0.055203237637345276, 0.01679476460308901, 0.03359052325998034, 0.05065277824178338, 0.04579031826662166, 0.04227273166179657, 0.03544801287353039, 0.026466322863208394, 0.04120694313730512, 0.036163911422980685, 0.04245750014004963, 0.059403461005006514, 0.05919833308351891, 0.04537816591826933, 0.012238883712728108, 0.06300143365349088, 0.023958984995260835, 0.06969754291432244, 0.05484450974368623, 0.025797282245808413, 0.058002530464104245, 0.012965047648841781, 0.026368467935494015, 0.03457913860412581, 0.02782638354359993, 0.02497611746990255, 0.07130088045128755, 0.04565681650170258, 0.03482050708095942, 0.018597750891266123, 0.02606628236493894, 0.06836741750261613, 0.04314704778205071, 0.011545866212275411, 0.01719384836698217, 0.02361668273806572, 0.04072633678359645, 0.02237067531262125, 0.026764008050252284, 0.02718887953752918, 0.01431112626700529, 0.005288864951580763, 0.0436843762706433, 0.021432480209374, 0.020383568547133888, 0.09243569243699312, 0.0028863726183772087, 0.07124534236001116, 0.02735756673584027, 0.08579159967069115, 0.02800503502865987, 0.022271015481757264, 0.051114830055407116, 0.06589706827487264, 0.016470219607331922, 0.003881755501164922, 0.022680831973307898, 0.04117147611188037, 0.03508542411561523, 0.022158409202737466, 0.009174868930131197, 0.04736600210890174, 0.05207170353138021, 0.04128226391705019, 0.013264488545246422, 0.03431259987077542, 0.01822610029817692, 0.057878182136586735, 0.045805595482566526, 0.016123450893376554, 0.05035132888172354, 0.040057783015072346, 0.023783266477819, 0.05203021450766495, 0.021122751025749103, 0.0606396703847817, 0.013922731125993388, 0.035328298940190246, 0.0525859889707395, 0.05229629522987774, 0.051089161075651646, 0.017250193914930736, 0.0196172616311482, 0.07440774302397456, 0.015867220803296993, 0.011892997942465757, 0.04739883641845413, 0.01566694610353027, 0.05491273983248642, 0.04805377198915396, 0.046569988929799626, 0.01147477440203407, 0.0750557914642351, 0.04203878975074206, 0.08810366703463451, 0.041528195541884215, 0.029111801979265044, 0.018219286110252142, 0.041986976816718063, 0.032860690993922095, 0.0309864076386605, 0.021926628425717354, 0.030366762674280574, 0.040203756253634176, 0.06615500657686166, 0.007192246432948325, 0.03845275592591081, 0.043911543009536605, 0.03617777728608676, 0.018841877612950544, 0.04340261460414954, 0.026290120889565775, 0.03858660713636449, 0.04364291438832879, 0.042926313555134196, 0.04882624339578407, 0.02774790079066796, 0.0180378220975399, 0.022598199978736893, 0.026646553638524244, 0.04778676845931581, 0.012948800975989019, 0.04181136177586658, 0.008871987013013234, 0.0555055012394275, 0.060914307433579645, 0.009061779194910611, 0.04864856221580079, 0.06576993116842848, 0.02516008018782096, 0.04714499646797776, 0.04662997142544814, 0.0097719831392169, 0.006748612180152642, 0.020428497743393694, 0.033257983425366025, 0.04095284195084657, 0.031030224037489722, 0.03922715097931879, 0.0032967037363310476, 0.06659431728933539, 0.05232683609106711, 0.03538821018966181, 0.04356275565390076, 0.032660879394305606, 0.016712468483352234, 0.06616881476449114, 0.0462453879549035, 0.06277246879679815, 0.0648657154025776, 0.0579443664423057, 0.03252240736037493, 0.04832602398736136, 0.032641049208385606, 0.02967837532716138, 0.048845428973436356, 0.048407387121447494, 0.01888186198526195, 0.04419359644608838, 0.06500740708517176, 0.06224523351660796, 0.02340368550669934, 0.027715510921552777, 0.008666234839308475, 0.057630638991083415, 0.027277660755706683, 0.023623649596369693, 0.005207652367451894, 0.05091194129948105, 0.03009397124073335, 0.04206120176240802, 0.017238034567396556, 0.025777116185054183, 0.08875776122191123, 0.07181932870298624, 0.02706032938190869, 0.02461438366611089, 0.044126903239105425, 0.04017818905413151, 0.02406343867603157, 0.05811373556831053, 0.03561645579923477, 0.0322284320635455, 0.04266320142362799, 0.03922099666669965, 0.03731545659580401, 0.04068128205835819, 0.006906541205743062, 0.03872605286804693, 0.027858980365895798, 0.01234801928512752, 0.09007310135556118, 0.03763972508854099, 0.03451515953721745, 0.06358231391225543, 0.030959900668156997, 0.04055262842614736, 0.023554050563169376, 0.08288624164249216, 0.05822308827191591, 0.02079483710362443, 0.029847435719732727, 0.06741569071475949, 0.067463120312563, 0.02629192409637783, 0.028351218506161655, 0.05475360301456281, 0.007282565381111843, 0.11119354196957179, 0.04084408296538251, 0.012677596466216658, 0.04408548206889203, 0.07404111698269844, 0.02976084447332791, 0.018686007941141725, 0.035071425938180516, 0.05146530017788921, 0.0874288978853396, 0.03857336552547557, 0.03754506266808935, 0.025242014987660304, 0.03959090342479093, 0.021372214425355196, 0.03079657389649323, 0.045420682922537835, 0.007515304588845798, 0.03702534555590578, 0.03965516408373203, 0.04943805128069861, 0.010888744910646762, 0.04101243768153446, 0.008279279888873654, 0.05132259747811726, 0.014176921370173139, 0.05098842237410801, 0.026405035883986523, 0.14278440895889485, 0.08469258328633648, 0.07802005990275315, 0.10757625142910651, 0.09640719861324344, 0.14296004096312181, 0.15358583150165422, 0.09170320031366178, 0.19301231232072624, 0.07531732600182295, 0.14544885312872274, 0.143312987738422, 0.15796292519995145, 0.11743690552456038, 0.13811699726751872, 0.15060012814189705, 0.14112619150962147, 0.17753902689686843, 0.1117068672818797, 0.10637069826147386, 0.13587770956967557, 0.20616109961909906, 0.145171603720103, 0.12458251709384577, 0.07077900559774467, 0.08166508895478078, 0.07992136252245732, 0.09680088463106326, 0.13321006271455968, 0.11860353792352335, 0.11219702062330075, 0.1213566530495882, 0.15743522851594857, 0.11736910630549703, 0.17102564711655888, 0.11756485008767673, 0.10672962293028831, 0.1435137798211404, 0.1297056736158473, 0.11756444296666554, 0.16881488503089973, 0.1438231917896441, 0.08441655524075031, 0.14402984641492367, 0.11080416464912039, 0.07157530036887952, 0.14485050737857819, 0.1217448700751577, 0.10903758515736886, 0.18134108930826187, 0.12468201746898037, 0.12545667375837052, 0.1658892591616937, 0.1433878844337804, 0.2098273600318602, 0.0758775652253202, 0.18272915482521057, 0.19252653553017549, 0.10619585335786853, 0.18443016069275991, 0.16390807261424406, 0.14462555944919586, 0.10271136569125311, 0.1019159530156425, 0.13004928374929087, 0.21002579081271375, 0.10439734200813941, 0.20895285052912577, 0.16916821178581032, 0.25713586647595676, 0.12763197560395512, 0.2025648368788617, 0.09635598279003586, 0.14010669264410222, 0.07075617289436714, 0.08175532732691083, 0.1797487847507, 0.119333166629076, 0.072068961736347, 0.09473109498087849, 0.09873364413423197, 0.22716975158878736, 0.15919245779514313, 0.11161129562450306, 0.11598584481648036, 0.15904498499419006, 0.1437907578157527, 0.1978506605540003, 0.1496948538614171, 0.11518005734043461, 0.1439855380782059, 0.12274634705058166, 0.10719075532896177, 0.19960193229573114, 0.13561502152255603, 0.08546157380832092, 0.14613251787211212, 0.13745898114783422, 0.08197670616209507, 0.17842591287834303, 0.1637073348143271, 0.07654480263590813, 0.060814033528523784, 0.08011772377150399, 0.11179489362984896, 0.13374541327357292, 0.07335460239223071, 0.13813508701111588, 0.08165345207921096, 0.15026718457894667, 0.10342686051236731, 0.08540294159735952, 0.1367119683751038, 0.14229454738753183, 0.17223456581788404, 0.16545035557023116, 0.1380486280790397, 0.1302801077919347, 0.12094056180545262, 0.1395414729735681, 0.19607208456311906, 0.1648224392639739, 0.10137178828673703, 0.1367839609405824, 0.11895415053835937, 0.07122008050126688, 0.11423314815121037, 0.13307191298476287, 0.1073056041662182, 0.14318816443639143, 0.11150602770170995, 0.17306461770619663, 0.13128166619156087, 0.10219548908727509, 0.1533254233321973, 0.11564452813139983, 0.18837208274219716, 0.10853210370987654, 0.1694967177297388, 0.12188854308000632, 0.13408051457788261, 0.08121114902730499, 0.11135740817657538, 0.16225548700562545, 0.11736184598079749, 0.10283875385565416, 0.08973782363214663, 0.1639320927539042, 0.15233735420874187, 0.10952691747141735, 0.18103478503014359, 0.10618823340960912, 0.12403896983180727, 0.0992217075877956, 0.1158216664833682, 0.20738054918391363, 0.10611704830080271, 0.23076188883611135, 0.1475068498402834, 0.1067757158141051, 0.09505047462880611, 0.15891907603612968, 0.0992530762617077, 0.18463468471808092, 0.12366717335368906, 0.12883858728621686, 0.21144265335585388, 0.06025631166994572, 0.1781184822320938, 0.14190219129834855, 0.20394287364823477, 0.060417022689112594, 0.10584382939019374, 0.11307961147810731, 0.15552660450339317, 0.13150212221911975], [0.07422828408224241, 0.053361886979213784, 0.011439661062987787, 0.03551069933122822, 0.05006886153881039, 0.025650974828749895, 0.03640276253489511, 0.020620283970077122, 0.01815490670768278, 0.030336659468178238, 0.055758778005838394, 0.023882675250726085, 0.02869919840512531, 0.047348295737590106, 0.06274279646043267, 0.022532378689252903, 0.04278007568791509, 0.05292438456256475, 0.007638962506981832, 0.056185630815369744, 0.013045552436129322, 0.013104812291982983, 0.019785801248092736, 0.020301140113068477, 0.021935362867744904, 0.01944680176010089, 0.06583576942128794, 0.04655557006065335, 0.04359535926154681, 0.023887409728818705, 0.02245493239856192, 0.035200788639485836, 0.0594067315437964, 0.03982317274702447, 0.07787091790565423, 0.0809130889496633, 0.06960121808307511, 0.03571194942508425, 0.014017956730510508, 0.030586401067141975, 0.046394173721117635, 0.019847797296409096, 0.024425783161340014, 0.016487196553498507, 0.041300882917961905, 0.04075023139427815, 0.05625901437763657, 0.025812958101076738, 0.023710403691178987, 0.04207293363288045, 0.00458068007303934, 0.04896068832437907, 0.015105733182281256, 0.00853950230936919, 0.09958057797380857, 0.043893711109246523, 0.023852268400202905, 0.014667565801313944, 0.017470806005543897, 0.007243780319445899, 0.1024711982214025, 0.022657856777576462, 0.009601697990936893, 0.04307742669646229, 0.0811971847766212, 0.0371694697865418, 0.04748068131240351, 0.031356595988784514, 0.04564894210281117, 0.025286448853356496, 0.03430204186588526, 0.032043595731790574, 0.0383742935290294, 0.03068383869581989, 0.06726772258324282, 0.0247971674294344, 0.011591203377715178, 0.011533483796353852, 0.040623104465859275, 0.06402907493923392, 0.03153060290164181, 0.025785842145394002, 0.025992325440581356, 0.0242539950579937, 0.019825258059427142, 0.024385635940624133, 0.022318380618734018, 0.036618991289287806, 0.01052476091509951, 0.024489741872197816, 0.08767741133591958, 0.1007427116855979, 0.01544780982658267, 0.038918322550931146, 0.037396517781806846, 0.02351413234802229, 0.06613644864410162, 0.03924720168911985, 0.015110377754483904, 0.04158479554046478, 0.007327899153876517, 0.06279430405369826, 0.0031457301187661608, 0.03825943451374769, 0.0094885862033282, 0.03088511593107666, 0.02567570234116699, 0.008311588333786597, 0.018144762609153986, 0.03700194627578769, 0.051666492596268654, 0.05605962346973164, 0.04387100732752255, 0.033608019285436184, 0.045006016601941416, 0.007885201168911797, 0.020088943553024104, 0.022801648526053344, 0.025675890634634664, 0.011777476507372089, 0.06139084936252662, 0.02043904217758349, 0.031740616275263686, 0.016162919579073787, 0.04340016509273222, 0.03393313255427139, 0.024807688114898543, 0.010600063883300339, 0.04326627656285252, 0.038385960938675065, 0.02971076519627656, 0.061014018154570034, 0.04844840795599988, 0.06019926044557776, 0.031155939613069807, 0.05189817837838616, 0.11369584341134344, 0.08107512311211654, 0.12069289652364594, 0.030770029606563703, 0.01773971112977181, 0.03853615466505289, 0.025698116049170494, 0.056828088127076626, 0.06741016743970768, 0.013551299360447695, 0.02632893478897001, 0.02443885344213673, 0.05755703151226044, 0.019585355218233805, 0.035445369979632754, 0.012841404997743666, 0.09638663900217839, 0.01945320882701448, 0.0536638520258878, 0.0377309405510979, 0.02245497819967568, 0.08257834959243025, 0.024462291738018394, 0.07953651103058032, 0.10043196300310747, 0.051987348057861836, 0.021415694949350188, 0.055954718563173494, 0.00467811176453584, 0.04158889049930232, 0.06121943106076547, 0.017994278809055686, 0.02858374567170228, 0.0635857405140996, 0.016777721499758105, 0.02586360225853111, 0.05221266578882933, 0.019973351719922254, 0.055596112805817804, 0.09118758155299084, 0.010161675978451967, 0.006017935137996184, 0.06244266006563391, 0.009568128319058036, 0.009194645681418478, 0.034781867904322486, 0.019937109468238692, 0.06440435908734798, 0.0640279214297022, 0.030494551174342632, 0.04082992533221841, 0.03449944805886064, 0.013073251083759325, 0.04346530445452247, 0.020477991783991456, 0.03047442582568952, 0.01093926523546023, 0.035380525780575614, 0.0237641385756433, 0.017470651638827155, 0.030707536531346183, 0.030889516230672598, 0.03576083108782768, 0.015421443652095539, 0.05274557362177542, 0.0267489632325513, 0.03944161893533809, 0.008465047509941672, 0.01571117471238332, 0.03926581051200628, 0.022882468832124556, 0.00997118151281029, 0.07780743416930948, 0.018529569996254783, 0.01597701964367713, 0.048209801116692166, 0.04286389511876872, 0.04064322981451239, 0.04368744324892759, 0.026746461134670035, 0.039466826511280875, 0.02537062281875738, 0.04427139048597642, 0.033666838093527725, 0.01655374387545245, 0.040880781531866105, 0.010143464098551443, 0.023409266457227722, 0.01452818961947092, 0.04687673764835511, 0.01141114138798522, 0.025026176390903335, 0.012532003207265266, 0.05769377667456865, 0.07014939973929099, 0.033027033853743754, 0.027116042195952365, 0.015474352420174649, 0.014139065901482744, 0.06347368724112, 0.03961350203358701, 0.008399310189166238, 0.025945221539586782, 0.08580486503030572, 0.08231324596064431, 0.035467317194810936, 0.04980563744902611, 0.04227957468745964, 0.010327468376739748, 0.04496400171358671, 0.03557282599753567, 0.021857448387891054, 0.02834647215370621, 0.0479414473021669, 0.007467325377677168, 0.02701345957549555, 0.04194691610921707, 0.010441070405899413, 0.012196090205439498, 0.03461201362577932, 0.023419376629005586, 0.014712267688342502, 0.04389556011717234, 0.034183613756405454, 0.029204747706119503, 0.03085982014558145, 0.04285279428586364, 0.06755508216364042, 0.09684251953980752, 0.015658774845568196, 0.031797107708241255, 0.018551669881812165, 0.05933334119617939, 0.02578338415228895, 0.01471820826243077, 0.020462801081261466, 0.043587267731449435, 0.07275183937911477, 0.027383228930245553, 0.0530877690097051, 0.0026131986607132213, 0.016512209050623432, 0.09227931047124521, 0.09722638037055731, 0.049427103118172715, 0.00624279528191047, 0.043866461142897606, 0.018714106076263955, 0.030338240454771688, 0.03661235521680542, 0.03945570532232523, 0.06949662190995046, 0.03672016425324338, 0.04030424050454583, 0.03379566814484341, 0.017941085056268742, 0.03705772524699569, 0.03296813362144998, 0.042972369119524956, 0.03563217745561685, 0.054840214617018185, 0.030864105094224215, 0.024500060693493912, 0.0033440317659239683, 0.016230815489377295, 0.011571422385584031, 0.04877077655068465, 0.03858063602820039, 0.05693932037268366, 0.05706171451934746, 0.07250040822795459, 0.04323860590479203, 0.023406459018588066, 0.0357724679633975, 0.00856649103973593, 0.04460420512727328, 0.049056521217737875, 0.08413654419460467, 0.07597766271127121, 0.04020162226100053, 0.03684536414220929, 0.03530862481732454, 0.007149166244614337, 0.05076938109206302, 0.03411566186696291, 0.029291847853788307, 0.05962619012487786, 0.04899210788841758, 0.011842287627847066, 0.015438062671039785, 0.06692620912300688, 0.026105433835514953, 0.05919265374541283, 0.02975934830361179, 0.04230703499966434, 0.013734020359281982, 0.03691695297935179, 0.027507168440414325, 0.03476357460021973, 0.02592070946203811, 0.03140407647671444, 0.0209097673650831, 0.035383782748665125, 0.05192577439759459, 0.026375541663063422, 0.025080411694943905, 0.04448637752128499, 0.01147426974161395, 0.029918023717722723, 0.07345766507621322, 0.01380214951599815, 0.0037610046814994086, 0.042664497425513606, 0.03566486248746514, 0.007782872150918203, 0.03368933152939592, 0.14309060467141016, 0.13607220484742097, 0.20375597796269826, 0.09823651545281921, 0.13579445332288742, 0.16235346746231827, 0.13455084791140898, 0.15311912154512747, 0.14295177640659468, 0.1004414896347693, 0.16316175194723265, 0.1578779454742159, 0.13262773039085524, 0.1785874856369836, 0.08884194027632475, 0.11060766769307, 0.09916545024939946, 0.2224791068583727, 0.10364365923617568, 0.09510350892586367, 0.12432991207710334, 0.19229455797799996, 0.12828750828547136, 0.11190043296664953, 0.1248701209468501, 0.08771078168813672, 0.11188180039503745, 0.16127112268337182, 0.10242249976311411, 0.06886732139225517, 0.10745236450540167, 0.12649808930499212, 0.17421292965965612, 0.07606473911021437, 0.12035542034677096, 0.12798921072057315, 0.15404164418578148, 0.16021722209240707, 0.07238979344921452, 0.13466837017663888, 0.20088923536241055, 0.10576918375279222, 0.10991484951227903, 0.07158257426427943, 0.10744377425206558, 0.21706931000309332, 0.08495888792510543, 0.08574189698057515, 0.10344372889293091, 0.21265056782535144, 0.10315839813223907, 0.13462132055844578, 0.10234068879591567, 0.09964209395859923, 0.2145891695150307, 0.16295285815639154, 0.1236653413091387, 0.15173121887658322, 0.10631288707788501, 0.13341939076781273, 0.2178653265748705, 0.0773644322263343, 0.0729154341721109, 0.12514234919633183, 0.17264837718435697, 0.15082408541015216, 0.16536510443048819, 0.1790244486182928, 0.15189634715872152, 0.1948884887886899, 0.09398459789476224, 0.13442484395844595, 0.0874754386022687, 0.0859313914552331, 0.1712783064161028, 0.08916465831654412, 0.13278301991522312, 0.07134518200265509, 0.1657382036958422, 0.15680030972829886, 0.09858210690851722, 0.176315397556339, 0.10345617322517292, 0.11926164903811046, 0.10903761229876961, 0.11500392322029386, 0.13185622250395163, 0.09408477680491549, 0.1255949456244707, 0.07544365565159492, 0.17457465667809757, 0.19953349525375025, 0.1378216038325003, 0.10517330108476536, 0.09085527581295796, 0.09804424576993499, 0.15725363897425787, 0.19584146408098085, 0.09569004138133355, 0.12443838268518448, 0.10212481966508286, 0.12460336168961865, 0.1851997279695102, 0.19887562841176987, 0.20912635193339416, 0.0738621126594288, 0.08308845864874975, 0.06742996030620166, 0.10921948682516813, 0.09780933016112872, 0.20581102983227798, 0.2733843374465193, 0.12932675252003328, 0.11885493514793259, 0.11456734021859509, 0.14208127026047024, 0.1127443133986422, 0.1443222000130585, 0.1005114194537912, 0.10548407690865652, 0.14120368020875113, 0.1279566546103784, 0.06617368664592505, 0.08863847476563283, 0.20259823437247956, 0.0864655477926135, 0.1292737317936761, 0.13653451789702686, 0.17814182383673532, 0.15653242410293647, 0.1029598248590316, 0.14861180340605123, 0.16251715725021704, 0.24244615329163416, 0.1429553862128939, 0.17376702358680113, 0.11970344318875245, 0.14567485957273416, 0.29534268059900826, 0.1394230414714132, 0.08118955804301159, 0.10171450275395598, 0.2259869971977813, 0.14557672983833722, 0.14324925972947053, 0.08850378556443111, 0.2277545402092593, 0.1452287227979728, 0.1420839572591441, 0.09852785803377628, 0.16493039418544087, 0.07603915155466114, 0.21411344861345633, 0.1519737137215478, 0.11063639686575957, 0.1382648093359811, 0.13887102609234198, 0.16579836261059555, 0.14311123213597707, 0.22483755887619086, 0.17322496910180363, 0.11062759626656771, 0.08028814462678772, 0.12183010764420033, 0.07681052373456103, 0.09051276490624462, 0.23442714501704487, 0.12965510918625764, 0.10760141150759799, 0.19341350293585233, 0.06093762868217059, 0.09533208701759577, 0.13207173879657472, 0.14142721678529466, 0.13403201289474964, 0.14468194570924553], [0.04097823612391949, 0.02655871049501002, 0.032289415398346524, 0.019988611972491657, 0.05235891044139862, 0.05095110973343253, 0.03240238808627639, 0.021835974450888376, 0.05563439914424505, 0.042894022073596716, 0.022838386108300517, 0.038021384073155265, 0.04993053538990872, 0.0423011317450021, 0.009117923726859902, 0.04118738775806768, 0.09615808805184704, 0.01404682669921645, 0.017606781030605947, 0.028770885629845516, 0.02591146611874657, 0.05503695245300021, 0.04460368604798402, 0.07934363066617932, 0.02162033602196191, 0.10082466514515025, 0.01764918607659638, 0.05686227611399122, 0.032016735923077376, 0.013121715447466289, 0.04864434851333499, 0.03160437662154436, 0.040327955303447585, 0.06230609132243054, 0.023820378950663974, 0.03561469839353647, 0.03361280634999275, 0.027213539196444408, 0.028786763349281888, 0.06404749037964003, 0.06231578080249684, 0.07078729051032237, 0.00896079367625394, 0.05853559436010463, 0.033652398868330886, 0.044028994028589556, 0.06500426546803542, 0.017746781464666128, 0.10254412037985665, 0.03097723045253328, 0.010677148005925119, 0.04327496859644141, 0.01873111186016883, 0.08950014638581447, 0.057170850091746876, 0.03986027504184416, 0.023244314594194293, 0.03964250601295914, 0.05908060725778341, 0.055957025582236905, 0.042127983178943396, 0.044414252641477754, 0.0027484152108497384, 0.049779215295399935, 0.012818305121202554, 0.022780310296054398, 0.054139128487024984, 0.029912639542349746, 0.031325491943529675, 0.015512623491563966, 0.08358051867357322, 0.045669291368020434, 0.03298897821722286, 0.04782172319080148, 0.051979918099407635, 0.03224724444693752, 0.02216462797618338, 0.01603532785416714, 0.030536382858242308, 0.044447405862488916, 0.02649153383182628, 0.06655310307230268, 0.029345540329813957, 0.02970643953553268, 0.06491237825581006, 0.005133999935683927, 0.13539755104907922, 0.05277180239292128, 0.023052684430565153, 0.09822014240281922, 0.09146372494953019, 0.027575374780488864, 0.03316107505400266, 0.02786590651209865, 0.034726757290107865, 0.010708503957305635, 0.023337787882025753, 0.029123337074582065, 0.03361545602924057, 0.051496278694165606, 0.04393692700458424, 0.047843487201524634, 0.02797138986976019, 0.05217237098674689, 0.012385791633278131, 0.022246645896562507, 0.010746697845336581, 0.05689395691401192, 0.04080547432282141, 0.03868406172841787, 0.018685972318053246, 0.01852767518721521, 0.03805885956223522, 0.031149188189634254, 0.04668811169852104, 0.027581854789916958, 0.03256712621077895, 0.019475420670849935, 0.014451230177655816, 0.012780408092242266, 0.02962192121360983, 0.024641511496156454, 0.042551914895219464, 0.021886571110891442, 0.017146054056606123, 0.038145525447492085, 0.014369979001847761, 0.021104686727215136, 0.06165361204849822, 0.027991679763155322, 0.0485015677820359, 0.029307427017816474, 0.060996885145349164, 0.09297672233411244, 0.023104115688641156, 0.015680657599919608, 0.010382910624944737, 0.0558779050063874, 0.02561657310330442, 0.02497648896782526, 0.023931789311713407, 0.07285845758659498, 0.03703307746244328, 0.02576882279078875, 0.02747998123855463, 0.043178938927927187, 0.07607231156102248, 0.028830230302576507, 0.06429067733032362, 0.05571596583883677, 0.03170307293268187, 0.07598789501935244, 0.06552890874445438, 0.023637301720944897, 0.024525054530905824, 0.026345932091187154, 0.05683890736794897, 0.08134365334574666, 0.05675294376643641, 0.030574316358459846, 0.03727451379277876, 0.019853169597419243, 0.058338893843548636, 0.03567678774041789, 0.03655770600640348, 0.035442862792738845, 0.009951303829438984, 0.03370663756504655, 0.0227037986873516, 0.009641674729729337, 0.014694418824676956, 0.03917586051725915, 0.024215593368613293, 0.07394014418657337, 0.011964566423557699, 0.015407637160803591, 0.08206260869545595, 0.08022760573242392, 0.022086011212585226, 0.05782721737133605, 0.018905697224129523, 0.04464597235034619, 0.03852629215855684, 0.03274385065638593, 0.0301824555998402, 0.02375518360973469, 0.020835028429116522, 0.030500579957983324, 0.03620117317352976, 0.019486134738794396, 0.0497955985234252, 0.03164936010060566, 0.03894748937870775, 0.010993686288462153, 0.014593210237632905, 0.08577764899070774, 0.0746413151334439, 0.0834525605397565, 0.03813429908560855, 0.017619147331320813, 0.0042553038718844095, 0.022563469163807373, 0.08251785141016756, 0.04935676957081471, 0.021310499969071577, 0.01768307381176523, 0.0806297870086772, 0.011064112286216446, 0.048222632213894806, 0.06451729445585183, 0.028254383077312793, 0.05899100670857089, 0.08895407497350659, 0.09888918471655675, 0.030724303131656985, 0.02167253741728408, 0.017769069643691182, 0.021126420203862444, 0.018355768340240632, 0.048071006778627634, 0.0717607100627252, 0.0513010913107012, 0.049932526890188456, 0.06050088283206735, 0.09963801596313715, 0.0027969667238981594, 0.013808525200667126, 0.052130610549024174, 0.020777904262234057, 0.05034691161875214, 0.08302559237927198, 0.03218844938757164, 0.0020266346109565347, 0.0007332793829846196, 0.047680788074753115, 0.04387907510889428, 0.04541010456159711, 0.05673304572701454, 0.025329769921622107, 0.0483319306346987, 0.016595640020178895, 0.010333541265156652, 0.043955566361546516, 0.024875894454973083, 0.05049690178462437, 0.02729848329909146, 0.02217382042934852, 0.04839193009372268, 0.09250980881708008, 0.035400081159813065, 0.020275713709582175, 0.028287987524111356, 0.017979680128129463, 0.0200278737050082, 0.013254114592980062, 0.04435740837029048, 0.04067872737401298, 0.01419053617532232, 0.02175303372288389, 0.014307852335540312, 0.011046203202567995, 0.04592807444610766, 0.05925589320915086, 0.045375265181064606, 0.0476320455116885, 0.06802627045129027, 0.06537059295390334, 0.017120639527482644, 0.02416153618001512, 0.023733531557289616, 0.07612387343708958, 0.03742422236661826, 0.05065842365313854, 0.01847234065644443, 0.05821601115167141, 0.02524481903362487, 0.057486294236566336, 0.025259446552289382, 0.0690542102924415, 0.02316945182558681, 0.0456776916315513, 0.018038141008998667, 0.04063905343147261, 0.02183464791492692, 0.058116945038948736, 0.020185958793652908, 0.0545619847252965, 0.04654703748279384, 0.035145057165729146, 0.007382734113239816, 0.038494574039110115, 0.014053056498856416, 0.015777801762201955, 0.03268421082092183, 0.055411402003041337, 0.036585244350135326, 0.024742796418390105, 0.02291018868397389, 0.051684192182230096, 0.05684874612571938, 0.04197890224999615, 0.019528707722201943, 0.09011482447385788, 0.039208908565342426, 0.041375708367143355, 0.017966270579823425, 0.09085688394095216, 0.015421106080923761, 0.03392217421372022, 0.014804494168077196, 0.04339344081069742, 0.017234097367950847, 0.0689761923359973, 0.027817197875784974, 0.04509643478585141, 0.022492280662325875, 0.0716324398027999, 0.04942838215668287, 0.029309340486569063, 0.004363645558312003, 0.017348776571452618, 0.00189082497880528, 0.043428253049829176, 0.015407895004110677, 0.05029132263734937, 0.029726571669535976, 0.05064096494710871, 0.05283928609320095, 0.0325574638721134, 0.0345136769382017, 0.006734855730818319, 0.02869846558730517, 0.014262271745662605, 0.05980496374624116, 0.035689055653555055, 0.05183775144230042, 0.10247177497616836, 0.03519830520131758, 0.021329459933830158, 0.08387329974876982, 0.05111812095024756, 0.023490113904699683, 0.030861268817846264, 0.07791534837867532, 0.0738198874252183, 0.08412479196808167, 0.036194720305502415, 0.05657838384753891, 0.020308480165632706, 0.03449916985950299, 0.015175335608156664, 0.057564753240772655, 0.13855454378894397, 0.1313718163541385, 0.08029877727052995, 0.06608994185392346, 0.2093850773360048, 0.10213043793503727, 0.09978018940559455, 0.07722985159073557, 0.18770087590175016, 0.1610972277287926, 0.10921304074249097, 0.09229119161942176, 0.15639884769916534, 0.07616428698280028, 0.07071309270603315, 0.12754573380308493, 0.16872455844921724, 0.07602123144481863, 0.12034518803868975, 0.21139628227267945, 0.11168207361229829, 0.21623235062829085, 0.11378648890448467, 0.13564281431691988, 0.10501607095024415, 0.15455779220376695, 0.2539249302021095, 0.14093715165342602, 0.10163888002612761, 0.053628473210015466, 0.11294652361954961, 0.11431218391018254, 0.0972848158063633, 0.18506982922554016, 0.13702633364924363, 0.11918352251606328, 0.1663377843797207, 0.16893677706164972, 0.12652183803064482, 0.11894019985837595, 0.08146949445030519, 0.11825695580669812, 0.08857412250446421, 0.1102427379893405, 0.22974642046860286, 0.19949061184057168, 0.13016352190503053, 0.2347776490662779, 0.18389379233121872, 0.16177323859717163, 0.052707629943532605, 0.08669652789831161, 0.12406307139566966, 0.14963316145752156, 0.12688284580196652, 0.0721736325483237, 0.09049286347414766, 0.12130059248634747, 0.21038375874715193, 0.12130102674875941, 0.14257596300116607, 0.1565574077623231, 0.10958147847226687, 0.15045714724276746, 0.13256573943155153, 0.16833026174988064, 0.15543608793190547, 0.09797472985727446, 0.10473323041307074, 0.08501173223235778, 0.11316343090896096, 0.11241240120892014, 0.18449319659599236, 0.10941023658961058, 0.11303470603057317, 0.19747859266187462, 0.07663905793534857, 0.13501443660684995, 0.11488554600094046, 0.21060042854930672, 0.11865042469331197, 0.07762023992836475, 0.1559562257358006, 0.08611690971468176, 0.11418738774955273, 0.09898878687194415, 0.19803508637206896, 0.15078744451914514, 0.13248297172997678, 0.1268008652010134, 0.3105579598673752, 0.15612644303057874, 0.08849405537226371, 0.12802389743072645, 0.1581340381609542, 0.1667477280965873, 0.16381748818925448, 0.10778823933963265, 0.12567524345857756, 0.13004583679139614, 0.13883243102048123, 0.10800172002719981, 0.15687646849879197, 0.07274495903402567, 0.15769113121288164, 0.0961917501741222, 0.2747062050870487, 0.1276494139539344, 0.13702672719955444, 0.1123138168560607, 0.12242837197014264, 0.12695905885526113, 0.09626840427517891, 0.1237487332629306, 0.11681619526020118, 0.11275068484246731, 0.05274334463423916, 0.2121072512652193, 0.12379350300346102, 0.16287595299737795, 0.1642011861715998, 0.11197777917342526, 0.11610111434544836, 0.13660731113382749, 0.11896789765783719, 0.12120709036077772, 0.14099059307149478, 0.15145776926406793, 0.17115258744784764, 0.09999374473201376, 0.1532859733062131, 0.1056199399754405, 0.15856143379850046, 0.2167977060058287, 0.13460768200457096, 0.10831793091659035, 0.16960171423852444, 0.13552412497145788, 0.1446293049624988, 0.12123970075377397, 0.14050900962735924, 0.1524090346481119, 0.0986591817012855, 0.07550082222691604, 0.06742105114140681, 0.11704145531569209, 0.10951534166399922, 0.08677063070769821, 0.11209951514112097, 0.13368775136768818, 0.14894303706075462, 0.12769723710204872, 0.06630757517580475, 0.12927241543573992, 0.11595167379294123, 0.12078436304415975, 0.17261947159256252, 0.08702356142124959, 0.21129637477653368, 0.09593428006129605, 0.18486617372504302, 0.09203072916716337, 0.1679046167326825, 0.2786123411996024, 0.11405576552663531, 0.06391970866492816, 0.10980006852852446, 0.21168053416269167, 0.15266740721251282, 0.14806493132242135, 0.08282680197485856, 0.1470065659710339, 0.13739791299615586, 0.24887139137302125, 0.06598325579294137, 0.085697391868702], [0.053974302152970006, 0.018606242757024508, 0.03305630924712334, 0.03952103806659579, 0.044123646271015914, 0.035745774395763874, 0.00596636435615697, 0.03741713846102357, 0.05070265056565404, 0.08233360879655395, 0.028874687916998352, 0.042822144859071286, 0.04761568603238889, 0.014651381044781633, 0.008982785844377108, 0.057575603015720844, 0.06677275842853955, 0.008735402154603174, 0.007389031766381646, 0.025731243825118457, 0.030041686724871397, 0.03857237486434834, 0.023761268372514417, 0.03353578244735088, 0.03947837517729827, 0.02168188593350351, 0.03524492055709873, 0.02393313281105033, 0.026656146427350383, 0.07293083691703421, 0.0283137939072081, 0.006217449454457632, 0.08108853774943522, 0.013486854648882789, 0.07219802588224411, 0.015633713154654418, 0.06153709401509591, 0.009910079434380999, 0.07777265246425356, 0.008813093566069645, 0.045194116687136035, 0.06348666083067656, 0.03128636422167931, 0.030311227975679294, 0.03383851423859596, 0.03213762372199978, 0.027036745200998018, 0.008897130976298025, 0.03449961429994021, 0.02571092000497239, 0.05590861210865634, 0.005233583431358316, 0.03947321152580636, 0.019175818622378365, 0.02208870499660926, 0.05777366738766432, 0.025990055740943978, 0.047549813852778504, 0.0691441772505641, 0.0601456222523536, 0.04634526152429836, 0.08020022005907126, 0.021593126767714108, 0.05406747518905571, 0.09408844767936639, 0.03610051928886345, 0.05378111984048571, 0.0318484456677522, 0.05124808754771948, 0.02523469359480909, 0.03822693607902952, 0.05830050233219351, 0.03895260553274836, 0.05584307580388018, 0.04684776420305882, 0.024568122844876986, 0.032178159404013834, 0.015082165964746048, 0.021063516614958644, 0.026567422884649465, 0.05442306146557842, 0.06815028629664864, 0.04186215012201241, 0.038936391938477755, 0.019108265372259275, 0.0537418156995305, 0.05081242056829589, 0.06375373899936676, 0.06898104386138064, 0.04536872410348483, 0.022303283214569092, 0.0812850414908358, 0.03263846059728946, 0.026867014755095755, 0.016267721009041582, 0.0890057250591261, 0.05346168590975659, 0.0464906308666936, 0.06030588543840817, 0.042589068080165556, 0.09877294488251209, 0.022068757763398544, 0.015620525826566985, 0.027524484654090235, 0.02557088394782373, 0.053829390821712356, 0.026106933397906165, 0.02126642403059772, 0.03050898700686438, 0.032043619480516226, 0.03195736750162073, 0.06413080090922968, 0.027239197998174598, 0.02705871107588921, 0.029844294102596383, 0.07372667706970658, 0.028920197260699103, 0.027100905776023865, 0.026534172972398143, 0.03320810431614518, 0.03795594276328172, 0.0705644188980971, 0.04148617386817932, 0.024481663912800804, 0.040505470242351294, 0.0718977130683405, 0.014641523627298219, 0.0574399774361934, 0.04741344188473054, 0.02810530554104064, 0.0738029715472034, 0.014977795404515095, 0.04817721447242158, 0.023544206716386334, 0.017621752905792425, 0.030186034872063568, 0.029975444743675844, 0.0644980783441237, 0.0918779977198158, 0.01971195967468832, 0.07164108433893748, 0.023054480852027024, 0.05905893484928778, 0.01699440656895084, 0.045971436226474385, 0.043025905532496314, 0.04050900201712336, 0.050829536614141295, 0.056208806178931675, 0.04784667292343719, 0.046383171275790246, 0.010106522107629903, 0.04385081412536757, 0.07444905223590986, 0.017658444686925838, 0.03462531291214483, 0.028929913882166147, 0.005616545627292777, 0.051940525748900006, 0.01978618122770318, 0.009208843178514923, 0.03446371640477862, 0.048798118119261095, 0.01515168187740658, 0.06256865044789654, 0.02539962510179196, 0.032944405251847844, 0.009384553214269025, 0.03144557907113007, 0.024291909898498228, 0.05645918220813785, 0.0332443414788161, 0.051850185596517155, 0.07668857063565936, 0.02374634738745434, 0.04470507953582065, 0.08056652718888861, 0.022238915686362555, 0.030067990134869303, 0.02055757206731609, 0.01737806892820767, 0.025723667981635247, 0.013406815506251795, 0.055913487382765324, 0.02329653125655438, 0.07424789374428135, 0.026745222808261002, 0.058975230769387314, 0.03174699450443898, 0.0446484252544386, 0.01653148283782814, 0.03284874877759388, 0.03949815108041678, 0.018953588225745728, 0.028131953307560513, 0.030677704739251306, 0.04470070977030056, 0.0335801993496716, 0.011229870757753295, 0.027522250577541332, 0.012580069779817547, 0.035512453344251425, 0.06473152831728969, 0.015936735019619976, 0.011545677918807735, 0.014711078555722321, 0.03716786844389779, 0.034190351609140635, 0.05560749523075564, 0.047226393528814824, 0.06538374974791493, 0.009795732713038368, 0.043420287048710246, 0.018208875686728528, 0.07033700788659708, 0.006036742008291185, 0.038112938803221495, 0.025853765197098255, 0.042482059715049605, 0.009889258587333773, 0.03166122089273163, 0.0684495202398726, 0.004665607212310923, 0.04917360582788076, 0.04010807603065457, 0.04614666789504034, 0.02103831752070359, 0.01670381037651428, 0.08377709705382586, 0.03952944511547685, 0.015914764055716138, 0.09069079892443759, 0.04588590349469866, 0.013005962462297507, 0.03144443573962365, 0.037523953443659205, 0.09151110704988241, 0.0614258007013372, 0.046394302642771175, 0.046374584415129254, 0.08308874363345758, 0.026096400838079195, 0.04357474197500518, 0.03256288875958749, 0.02045085547225816, 0.03790146318663444, 0.039768564248723645, 0.04721497378445097, 0.03783520084938832, 0.03225451494966235, 0.0135390356881544, 0.03330564711775098, 0.01004233439120331, 0.008627842479784573, 0.06891005552772965, 0.013994965419572378, 0.030303445179015398, 0.047015582876546044, 0.024896438799000213, 0.020364717147978287, 0.033295078934835534, 0.03163355023467115, 0.02649720129556954, 0.04824666253158024, 0.030647364045892442, 0.03410112764686346, 0.050930987777454514, 0.041577677708119154, 0.011222760558926632, 0.00959470059855708, 0.02918769951377596, 0.02542692595826728, 0.05092891485297254, 0.02971382878188576, 0.044824342243373394, 0.018380214260624986, 0.06252597738057375, 0.01864232724931623, 0.038602030237338374, 0.015326375806970256, 0.07644303595381123, 0.04043336911126971, 0.09313185579542603, 0.0409888721603368, 0.027180304551231008, 0.03449619109077113, 0.04510523199236818, 0.05913558216499431, 0.026872836585555757, 0.01351073568886412, 0.020904522289388945, 0.08709343017211982, 0.023719580877306204, 0.058937965626163144, 0.06181215854095561, 0.03683424634592874, 0.05052012464563761, 0.08476029429584742, 0.03249642625451088, 0.046904099572982104, 0.0395609936011689, 0.030665942334703038, 0.061914603758071146, 0.020838787513119832, 0.016940642846748233, 0.028081940187673484, 0.030007396957703998, 0.024024784232356718, 0.026218135109437362, 0.01422235946769693, 0.045432153557028086, 0.02511139360389539, 0.032650477452469726, 0.0356676444810416, 0.07125710137188435, 0.04856747728107231, 0.04257968733353274, 0.032471296710095236, 0.061012226822120805, 0.02240693792035537, 0.018715442790250694, 0.038002693826066594, 0.05792680595602308, 0.03915923980197736, 0.055110559931823185, 0.04249742853322199, 0.0153874252989356, 0.04251224095267909, 0.0049265709323143315, 0.025405908336064646, 0.0233211977008198, 0.04652835062838026, 0.04275599787277835, 0.020118612496714507, 0.07214949705771037, 0.07188899389335088, 0.03310789826459118, 0.019316271978563497, 0.056196348275989294, 0.033900457700448375, 0.04944172215514949, 0.015184093798909868, 0.008200223773850926, 0.035349309777042696, 0.03882810453485165, 0.045242828716124804, 0.04451657572228994, 0.03918384687442865, 0.019986133623336042, 0.12366036086210183, 0.0627109460266573, 0.030389340927026103, 0.09005832286285502, 0.11526479279356343, 0.13899954062487396, 0.2424846397978919, 0.10842361274574484, 0.1007314615749887, 0.06806284348879542, 0.150901180558971, 0.1188356511827026, 0.18540551406996592, 0.15650340994553907, 0.16981541205729755, 0.18628440690892084, 0.09147397082831178, 0.06815405216600214, 0.1629548801907471, 0.10410547016986779, 0.08027388182069574, 0.19338211390588964, 0.1035741093967642, 0.09449028968811035, 0.09818736237606832, 0.07016451071415629, 0.09168252535164356, 0.1232902742922306, 0.1687638863388981, 0.217029602133802, 0.11228296386876277, 0.13694229030183383, 0.15919195567922934, 0.11199725312846047, 0.11088277293103081, 0.16191370891673224, 0.06298468740923063, 0.19445049443415233, 0.07317837327718735, 0.11354212130286864, 0.1595694382808038, 0.11728005536964961, 0.1184027051287038, 0.1591863374092749, 0.13647704598094734, 0.08617029684994902, 0.09876064982797418, 0.1233996677079371, 0.15423050762287208, 0.0907138351883207, 0.09361863003245421, 0.11585657032472746, 0.11216620834810392, 0.18099066668323108, 0.06797200800584895, 0.12744278647005558, 0.1380065589078835, 0.07583343330770731, 0.2216342900480543, 0.10389763489365578, 0.18185615167021751, 0.16413422833595956, 0.23433141729661397, 0.21998349577188492, 0.20098443382552691, 0.14716936009270803, 0.09790210625422852, 0.11520839296281338, 0.11874005916927542, 0.14420786686241627, 0.08854253669934613, 0.18200541580361979, 0.1752880955381053, 0.12775150633284024, 0.1688596683421305, 0.24930714656199726, 0.10468766000121832, 0.1362466426300151, 0.07447971523340259, 0.08204126198376928, 0.06147019724760737, 0.13637755917651312, 0.07191414718649217, 0.083724415594978, 0.1168920419045857, 0.12916646897792816, 0.10467716306447983, 0.11418919265270233, 0.10684413928538561, 0.1489940086113555, 0.13790353015065193, 0.16117204299994878, 0.13735564026449407, 0.14409284160605498, 0.16067626460322312, 0.1505882673497711, 0.07910287965621267, 0.09507154314113514, 0.19698461916829857, 0.1040886425014053, 0.15615328587591648, 0.18697489771459783, 0.09549754778189318, 0.22698027747017996, 0.09881384018808603, 0.12620774417051248, 0.13241186126002244, 0.12536954986197607, 0.09296031535736152, 0.20448528097144195, 0.13837311709565775, 0.106867840513587, 0.19808905704745225, 0.12424512234117303, 0.13975184597074986, 0.11038485714899642, 0.10887461461658988, 0.14403049780854157, 0.2956675631659371, 0.10939148188169513, 0.16430649480649404, 0.1772283257118293, 0.15177494367318495, 0.16779937595129013, 0.2465348153242043, 0.10869436857423612, 0.11585754741515432, 0.10148187380816255, 0.15002150061939443, 0.13628297139491352, 0.11436010205319949, 0.13307850834514412, 0.12829269229301385, 0.1374069375119039, 0.10315236595592328, 0.15115241493497575, 0.07943277659692935, 0.14809409475752286, 0.08352461417338677, 0.09304839598813228, 0.1513262420360531, 0.20526999314980848, 0.18721778610987322, 0.1787748427263328, 0.09940058298941169, 0.1643385759421757, 0.0806407860613295, 0.140326198722635, 0.19395512315843785, 0.1807638867092984, 0.22118207359952585, 0.1424440557935408, 0.14963309360401972, 0.11468258260616235, 0.12986134311982564, 0.12716237508824893, 0.09479310629623276, 0.13634074186640127, 0.16906126109617098, 0.17551316560379096, 0.1257739295916898, 0.1123105056051697, 0.10032163999442544, 0.0935497587280614, 0.10592272265681199, 0.12700887689633028, 0.1828023823244231, 0.1933889128267765, 0.11166221289230244, 0.10275770284767662, 0.09633120269115482, 0.17251861414739064, 0.09380562071289335, 0.14744822441467217, 0.16717000758009298, 0.06869491242936679, 0.3289145034338747, 0.1437844338693789, 0.16695569907980307], [0.05047382141596504, 0.021007690146299343, 0.012979656507793282, 0.015316246975479382, 0.07296258557055678, 0.05139745006869946, 0.04574736360726612, 0.01419622908412878, 0.03518391347357205, 0.016048440543402518, 0.006703022260418428, 0.04769272350573114, 0.016222428796546798, 0.034903746364372115, 0.03500118060037494, 0.00884017813950777, 0.044853583710002046, 0.04885899967380932, 0.04056163937119501, 0.07684415871543543, 0.020108909445947835, 0.07472588095281806, 0.01990457032141941, 0.008441949329738106, 0.02758505068985479, 0.01187340694013983, 0.018537105127636875, 0.0407383570314518, 0.039983758237212896, 0.014671408005857041, 0.029972567755196775, 0.034790980629622936, 0.022204909207565442, 0.03020958003721067, 0.017040847201964686, 0.020985118678904006, 0.05193404573947191, 0.010555187273504478, 0.02891576981970242, 0.02699836217133062, 0.0503540565924985, 0.0037688472740618245, 0.026603532822004387, 0.007478279477384473, 0.0711711784824729, 0.03672434063628316, 0.011255390459804662, 0.04455462457346065, 0.04528567480987736, 0.022134548518806696, 0.02307740006861942, 0.07305788581392594, 0.0454303418685283, 0.013260319795725601, 0.11442528212709085, 0.04625522331999881, 0.0115802484298391, 0.04739271942526102, 0.03735176839732698, 0.061737614683806896, 0.004843070412919457, 0.023316269840246866, 0.04418608167075685, 0.010161532637929278, 0.05445748693974955, 0.04738349813435759, 0.027086505566590598, 0.02827126842125186, 0.03606727446562477, 0.03640426548996142, 0.06267213382359062, 0.04180667309888771, 0.01566738206227975, 0.04070170256974442, 0.04412785318813153, 0.014053170153472041, 0.03482955873810819, 0.03346031238990171, 0.0065780551937807885, 0.05500591626124723, 0.10617405881306954, 0.014597322159845914, 0.03458031586238316, 0.04521052027121186, 0.02470287650690547, 0.03614060374509011, 0.0367010736704937, 0.04869203934712069, 0.022987512838361517, 0.028962195185678344, 0.04577089520171285, 0.06446210241743497, 0.030783471385283128, 0.05618065715368305, 0.08069361001253128, 0.021900119758876305, 0.03470170238454427, 0.019774206780961583, 0.03530225676617452, 0.022062583094728843, 0.039749090293688435, 0.037221710197627544, 0.04063707210921815, 0.03976801124268344, 0.05068892040955169, 0.029593076689967086, 0.054770274619971, 0.012892498684647893, 0.05361371846603496, 0.024335268286189864, 0.02860473275982908, 0.014282363167564784, 0.0520923920640988, 0.07429241921220507, 0.03961859104622688, 0.0340127484606845, 0.02323455217161349, 0.02626627547267292, 0.045376720638679605, 0.04214011538507683, 0.042470589080559354, 0.04057491830150996, 0.025620786805770228, 0.04859515133180788, 0.03773292187335236, 0.014496100002101489, 0.045670485589653254, 0.02939515481037753, 0.05577846909207957, 0.051897683047822545, 0.05046048481017351, 0.013849676653210605, 0.019799802818202546, 0.07185236657304422, 0.051773891119020324, 0.022017204369019185, 0.04829174100554415, 0.09768279695085116, 0.06626284614737545, 0.03509421114410673, 0.03312708044956837, 0.02336711755820683, 0.05177017613979323, 0.060431054793298244, 0.030746457300015857, 0.049830661820513864, 0.03285247054217117, 0.009362038574181497, 0.04636626557580062, 0.03718755953013897, 0.009779866867964821, 0.05709750045623098, 0.03520910069346428, 0.04411945292460067, 0.05656515920002546, 0.021152681205421686, 0.00836332662895854, 0.03545758021729333, 0.018059311301580498, 0.07098154151546103, 0.03630034445918032, 0.01848053396679461, 0.036108366546354125, 0.08407892300082104, 0.03140134198058929, 0.07024588741894279, 0.011578372280512537, 0.006255287111603788, 0.03130929531263454, 0.01579757427264537, 0.0334114171564579, 0.07431327059332814, 0.05637760872819594, 0.021364762414512888, 0.11185987014323473, 0.0470024023338088, 0.05233542973707829, 0.01702550722153059, 0.02960950741544366, 0.032166637879397185, 0.04008135532162019, 0.07763853323246751, 0.027589166004742895, 0.07696142992270844, 0.013554089835711887, 0.06051404641142913, 0.04506609748516764, 0.015552053161497627, 0.047729876690677235, 0.07015949634036847, 0.030018911696970463, 0.012525052464167987, 0.03359635866114071, 0.02874286552625043, 0.09139728958585433, 0.053361910727939436, 0.03426419996789523, 0.04358051630801388, 0.003689149095277701, 0.02230520686134696, 0.030838229161288058, 0.028952526061662605, 0.07789062934794597, 0.02646409217933459, 0.041634572869432826, 0.03913176931174738, 0.03151560388505459, 0.046853928693703244, 0.03546336133565221, 0.055591325741261244, 0.07137938016759497, 0.014250205696693488, 0.04224582435563207, 0.025237623169752102, 0.03312655797760401, 0.008137449106600667, 0.049805820653481145, 0.028284935812864984, 0.0631615204204406, 0.030411047262272665, 0.03245049621909857, 0.050120949279516935, 0.014098121402119952, 0.05169082486203738, 0.03600752606455769, 0.020655815456328646, 0.03671683603897691, 0.053907120400773625, 0.02402867902336376, 0.031781284271606376, 0.0303150922326105, 0.025700353518394486, 0.03856032068974205, 0.04731772094964981, 0.01498185474026416, 0.03095666744879314, 0.03837001197306173, 0.007774326850527099, 0.05977162732077496, 0.01586510886305145, 0.0660910682220544, 0.030255272585366453, 0.03803705823208604, 0.011954052523443741, 0.061112962130989344, 0.040489836795521636, 0.0202661633291947, 0.0556194103056831, 0.04705253250098654, 0.046966551936098506, 0.03894084991355028, 0.041184415774686, 0.03136557300708123, 0.025867790515933718, 0.015097785840875335, 0.023304632964677045, 0.03159700094589165, 0.01603994528496904, 0.10002541196133409, 0.024691724783873985, 0.053193477980260334, 0.0468494842893311, 0.01857928964974625, 0.021612844995356033, 0.0067606587212399715, 0.0023117895886701134, 0.019610844386209334, 0.06925864610821009, 0.020748547444652234, 0.006392624719800162, 0.10785998084715434, 0.009438570538934852, 0.04074018907600215, 0.011229249898211231, 0.02189525805546769, 0.03298662370070815, 0.03195834459204759, 0.07567827949034316, 0.04483277643365519, 0.025177879857697656, 0.0058051189906629065, 0.004257929802406579, 0.06118952123714345, 0.06152367937777724, 0.0269885590366487, 0.017712223676166365, 0.01070608922080802, 0.04418840904587081, 0.015111410824049796, 0.06561969672994954, 0.04432267416268587, 0.022599957384435192, 0.030183174846959964, 0.027160467579960823, 0.052523919979908636, 0.01580486004240811, 0.026104030964363898, 0.02005434505242322, 0.038287427475942035, 0.011669829471169837, 0.028161946251722317, 0.04399155925161072, 0.03768379593800221, 0.05563558318785258, 0.046849192519273074, 0.018409923916416507, 0.06949104435209717, 0.04040505723761661, 0.02980190941265651, 0.09564250321792704, 0.017398704874462316, 0.037570494160588296, 0.012341117735819092, 0.027053432073444128, 0.0013657871978856356, 0.02729855284893087, 0.06318195110985211, 0.0281457139977387, 0.04640115584645953, 0.029798011228974377, 0.03844472546396511, 0.025938008712338548, 0.023932737564401965, 0.02207687304222158, 0.005403977993410081, 0.04657525096886924, 0.03931046150890844, 0.025355399885614003, 0.010899803335113185, 0.06337541501436915, 0.018894857627206614, 0.040652980362730365, 0.016715130036962882, 0.07080834545195103, 0.01904898855303015, 0.07857288273849658, 0.02223149760227118, 0.01270797023815768, 0.04823551420122385, 0.03312012207295213, 0.017902854696980545, 0.042885472532361746, 0.02001031152238803, 0.023942516950358237, 0.032449352887592146, 0.047625840308942964, 0.060608050652912686, 0.046423951230411015, 0.01992352180449026, 0.07792862730899028, 0.028811170253902674, 0.04104721260124019, 0.16860054938920907, 0.09414268976875714, 0.08110826954777751, 0.0711749918492777, 0.14815417224807398, 0.14411163702607155, 0.15077369739966734, 0.1665971747466496, 0.1946932335517236, 0.10106442549398967, 0.08115309357110943, 0.1047129218599626, 0.1400661976741893, 0.11420602032116481, 0.13345495957349027, 0.13866310939192772, 0.15866220981947013, 0.09147979944412198, 0.16385526901909284, 0.16080832108855247, 0.0718830567119377, 0.20139147341251373, 0.10938334624682154, 0.1226561561759029, 0.15721861299659523, 0.08755857949810368, 0.1079827481880784, 0.12476797428514276, 0.07738457793103797, 0.1967868669224637, 0.09553906055433409, 0.13924835941621236, 0.11730284057557583, 0.18019486724265985, 0.1859612071088382, 0.1824223077190774, 0.14797776671392576, 0.11515045964292117, 0.20554838249725954, 0.07299743512911455, 0.19125500161732945, 0.17306946244622978, 0.19455114831881865, 0.17656146149550164, 0.1411942621426923, 0.16263166681996413, 0.09762139631701366, 0.11430801770516805, 0.10285668075084686, 0.1209447415811675, 0.08996226944561515, 0.18714022955724172, 0.14677617619080202, 0.07401412485965661, 0.14621593696730478, 0.14458937996200152, 0.07721307141972439, 0.13504001737705298, 0.10763801847185407, 0.16314191158328736, 0.07860915043524333, 0.11084426606872252, 0.18987760267087392, 0.09473367341394935, 0.18163950900946343, 0.07847637470279421, 0.1382120328822306, 0.09688682109117508, 0.14957035625619547, 0.17211818349148544, 0.15538324362465314, 0.13061865605413914, 0.18349713433001721, 0.08391341473907232, 0.12207135398473058, 0.08752877145473446, 0.12156129921121256, 0.11615173305783953, 0.091097132835005, 0.10647361166775227, 0.21256930647151812, 0.10416338991905962, 0.2083300639476095, 0.17244571234498704, 0.14523443606282982, 0.10109771442200456, 0.12713203100221498, 0.10211665688880853, 0.11532484314271382, 0.2168409286865166, 0.09987607318907976, 0.10210567819220678, 0.09225705452263355, 0.14181297751409666, 0.17649211521659577, 0.11070987542292901, 0.11531834277723517, 0.07431751143719469, 0.10502840671688318, 0.07526541807289634, 0.15348409196095808, 0.15875719115138054, 0.137517443725041, 0.12971021980047226, 0.10593805754823343, 0.1327131443790027, 0.1519004726516349, 0.18641788831778935, 0.13567049854568072, 0.1124462601063507, 0.13216769721891197, 0.16976748034358025, 0.20925967049385819, 0.2883010341652802, 0.17147105107350008, 0.18125187552400998, 0.09601912408002786, 0.08762002762939249, 0.14729583902018412, 0.14581649697252683, 0.10722336572195802, 0.11382498898144279, 0.13512256794742175, 0.11402569285460881, 0.15954984218946525, 0.11587333013968808, 0.12437906515385423, 0.13503893172102316, 0.22051100246608257, 0.14919701271823474, 0.22609002595501287, 0.20373676185097012, 0.0981275291581239, 0.19891780614852905, 0.12030706794134208, 0.13294700825853006, 0.1337745495672737, 0.17731038773698465, 0.07664643361100129, 0.09780862448470933, 0.10397635174116918, 0.132672839398895, 0.19319314190319606, 0.20431144029966422, 0.18689597052122864, 0.12945823903594697, 0.13155056961945125, 0.20862905361822673, 0.12269313633441925, 0.17523629617478165, 0.10733012642179217, 0.12436715007892676, 0.06759158734764371, 0.18362483462052687, 0.14571080835802214, 0.09875629363315445, 0.06566009670495987, 0.11498263079140868, 0.13307067805102893, 0.17385269541825565, 0.13034311655376637, 0.07805286028555461, 0.14665387703904084, 0.16768243722617626, 0.11732743068465165, 0.1604505024318184, 0.110984186774918, 0.09119516757449933, 0.21030214455510887, 0.16544055752456188, 0.13726738999996865, 0.1085629431264741, 0.1737164320158107, 0.15787806761051926, 0.23082895523735456, 0.11637995152601174], [0.02956124661224229, 0.03926864678838423, 0.047177817206829786, 0.08986947978181498, 0.055223573331854174, 0.006435445368489516, 0.025833180140970007, 0.029814584446804862, 0.08369520466242518, 0.06390822106706244, 0.039423614008618255, 0.06349678457315479, 0.018007386409278427, 0.09220908209681511, 0.02774203655176929, 0.005528870845280055, 0.02680173290095159, 0.03898879519796797, 0.04011965862342289, 0.033002796582877636, 0.0333328461939735, 0.025512630020135214, 0.03619130388168352, 0.0331541268554117, 0.019837773637846112, 0.046217422134109905, 0.033482883857297044, 0.007411351327651313, 0.050531527426626, 0.04128224016832454, 0.04467128509921687, 0.022899232039760267, 0.040114033568118296, 0.019342653420088545, 0.06219582259654999, 0.031774095193083794, 0.03253436314740351, 0.019812625433717455, 0.04393228243238159, 0.07219095554734979, 0.02703227874423776, 0.10066728573292494, 0.025618283011551415, 0.08165671583265066, 0.005386473910350884, 0.04118576266669801, 0.05012847762554884, 0.024607959635821835, 0.05016300148729767, 0.020591083215549588, 0.03445025427000863, 0.019679469721657888, 0.026065602133582746, 0.0355740134338183, 0.03317124968660729, 0.036515630049897094, 0.027242042756240283, 0.05519672370116625, 0.017586072141836797, 0.020633517099278312, 0.023127055261284113, 0.040971450773733, 0.03871780188222017, 0.049857002549937794, 0.018106929192851697, 0.02682019753514656, 0.08682949362056595, 0.044357907093529186, 0.04663277716775026, 0.011116119450889528, 0.02440655347891152, 0.05120193020307592, 0.05574485785993082, 0.025215769253138984, 0.08174339189593281, 0.03455302179125803, 0.006953434336797467, 0.03706562339461275, 0.09963852486440114, 0.01891780228886221, 0.06483654518212591, 0.048477208374866416, 0.018141302080558877, 0.06469511134283883, 0.022824739072737948, 0.017196079050855975, 0.05766514928213187, 0.06482905415552002, 0.023525601286174994, 0.044478292776537795, 0.028400101865242635, 0.028715985361486673, 0.06887391675263643, 0.038710436384592734, 0.03148162963667086, 0.052636075033141036, 0.08363438756870371, 0.056980473521564684, 0.031489687240017314, 0.05201040128512042, 0.011594465434817331, 0.03110893749232803, 0.05276524095929094, 0.04615293416593756, 0.05688619786607368, 0.01532002302285816, 0.08769793023488351, 0.056611954367586544, 0.02941719362778323, 0.022483620859150375, 0.06756878857101713, 0.02031444788112172, 0.01850367709994316, 0.045362318732908795, 0.023166108344282423, 0.07668960879423789, 0.040809755878789086, 0.006814024652287896, 0.006405524094589055, 0.09512506598340613, 0.020520196662151387, 0.016148799265335714, 0.015410481918869274, 0.06147489270993641, 0.051738837999956946, 0.04594715824350715, 0.05950406739222152, 0.021913720993325114, 0.01969586482404598, 0.04653400961043579, 0.08300125332815306, 0.0491627390895571, 0.0301831578835845, 0.01847355014511517, 0.02702267747372389, 0.01513317653111049, 0.02402770871828709, 0.047645989406321726, 0.020148900603609424, 0.028862969617226293, 0.01755611821343856, 0.07919381691941194, 0.05671523079009993, 0.038133182895502875, 0.03563433519697615, 0.019431655162147114, 0.01884440515589501, 0.016827729530632496, 0.013873808751148837, 0.03991338737042887, 0.04349815572745033, 0.016831303713843226, 0.009408439343262995, 0.08571770720716033, 0.10388002012457166, 0.014006402127311697, 0.018427967858899916, 0.048425666854849884, 0.023129206217293228, 0.08826631187860455, 0.016202225416366543, 0.038850021215953996, 0.002815296711300367, 0.01451815408654511, 0.0367205544108791, 0.07525783883673803, 0.07288267450141055, 0.004967249530766691, 0.029374961608222554, 0.01441474026069045, 0.04817066660949162, 0.015944421125043715, 0.16642037566219056, 0.05791337096265384, 0.09944021621985094, 0.08331864486847605, 0.026510834760431732, 0.01896679590988372, 0.029253934709621326, 0.12861629921410764, 0.04829725410257067, 0.01902488529283021, 0.006705132504326424, 0.02804012885982437, 0.0941900040156075, 0.0357850174685674, 0.015037872895066227, 0.04868471116891929, 0.05482107653681721, 0.05274755494402988, 0.03715383633971214, 0.01657472417822906, 0.008317065807724637, 0.04998979524576238, 0.0187860748930169, 0.015119894208120448, 0.04781135856839163, 0.04639527294784784, 0.022075911218832647, 0.05253430495836905, 0.04194164728479726, 0.002899453925367977, 0.045336222276091576, 0.013137837439509375, 0.041758894055549584, 0.03277675621211529, 0.02145647829664605, 0.0231260578148067, 0.04548691472570811, 0.04008472764066287, 0.033101771093372784, 0.07852550742349454, 0.028337427281907628, 0.021987004471676688, 0.08595162536948919, 0.023484032534595047, 0.031806763261556625, 0.05419644773272531, 0.02891626175759094, 0.07392301796270268, 0.02483029690171991, 0.009058528164002513, 0.02090241713449359, 0.036296826255108626, 0.0584902750062091, 0.06448918953537941, 0.050557620490768125, 0.02623442673523511, 0.010441570825475668, 0.025439819819959145, 0.027472359593957663, 0.029003707958119254, 0.002646515790339825, 0.009971853262478752, 0.05640320646177445, 0.014612185469429408, 0.022091263073629568, 0.03323232801631093, 0.02735099851685975, 0.019182646381003515, 0.051479698690984926, 0.007515342756440597, 0.06529433240315743, 0.05247241238664303, 0.05837667467338698, 0.11502073731805597, 0.027340233558788896, 0.042106375231274536, 0.03337502732340779, 0.029137294539915662, 0.02758961553419275, 0.027140350712995445, 0.024042095357019986, 0.02746186265721917, 0.04290155041962862, 0.054979494107621055, 0.04862193310899394, 0.031199443885790448, 0.015457833485145654, 0.006377921714114824, 0.019891438972471014, 0.02762744216514485, 0.05235743123505797, 0.03837949449994734, 0.054807024076581, 0.02783276346911277, 0.012331468967853912, 0.02509546499433262, 0.002598360160066347, 0.020006890009556497, 0.04762758414394089, 0.055378431986485205, 0.020741497465808476, 0.010109672206453979, 0.006840279292581337, 0.042907490993716886, 0.028859580334808146, 0.04794124374166131, 0.034399693233094046, 0.06513171470058815, 0.023923224503440515, 0.060341461029435904, 0.0569492405546563, 0.0258265321941248, 0.13635330833494663, 0.09440088591405324, 0.06058320948587997, 0.01397170523913311, 0.044405295979231596, 0.038455571846238205, 0.015084076040823544, 0.021788665293050662, 0.0382961296875562, 0.014014776945779366, 0.0207239386758634, 0.07620259028460298, 0.032676550160561285, 0.014235583267041614, 0.03849926610876407, 0.052286313979753425, 0.040917615805353434, 0.025843191925170164, 0.039963327547801394, 0.013778579753956624, 0.023794430075213313, 0.0707813940410103, 0.028002115631742135, 0.021672177793724195, 0.009149109196316983, 0.04873261574123587, 0.036434382266764126, 0.02077407223571624, 0.0518000588220145, 0.02775844861753285, 0.017902237230113575, 0.004844776504406971, 0.023597561621240208, 0.0752278883010149, 0.012255601967418832, 0.04869915717946632, 0.036734159038003, 0.05266642590452518, 0.030377486920250312, 0.0697444025427103, 0.035570654685475996, 0.018522229943690554, 0.0735770126006433, 0.05306527218116181, 0.012921189689742667, 0.017493984761780927, 0.04458312304424388, 0.03704143022852285, 0.031247107578175407, 0.019205825137240545, 0.025769825326278806, 0.03416553758350866, 0.02075851851675127, 0.017343731663588966, 0.009394752443768084, 0.04587893494005714, 0.03862448974645563, 0.040685475404773436, 0.06240977147328002, 0.01743049593642354, 0.010997406356701893, 0.019561816838436892, 0.02798724892948355, 0.04751076416245528, 0.12441790449832167, 0.04548326420730778, 0.04921034849914057, 0.055751317513308356, 0.11584830576820032, 0.14937728590198926, 0.1767254498388086, 0.2216783134000642, 0.11977411939629487, 0.12073861621320248, 0.14822140149772167, 0.1364239574010883, 0.12999054975807667, 0.1693343442997762, 0.09355490880885295, 0.1637392531016043, 0.11935770245535032, 0.2032391649803945, 0.12488708432231631, 0.16771005360143526, 0.11862362256007535, 0.09199308404432875, 0.09865363128483295, 0.08521145901509694, 0.11432620244366781, 0.1183525478201253, 0.1597119170640196, 0.13061404201601232, 0.07809904816427402, 0.10040518122592143, 0.09854212083986827, 0.0752361189307911, 0.10593659869794335, 0.15263586890484604, 0.09481055143156222, 0.07755305817616837, 0.17133243993989059, 0.11486281507781573, 0.15711855622274534, 0.15406414440699986, 0.06850546545216016, 0.10874746393944536, 0.2015854258622442, 0.18097985083503382, 0.19249787421098777, 0.16089015241180146, 0.10788740044725792, 0.1614000986197165, 0.1108296164976699, 0.07641527708619833, 0.06900218701256172, 0.0721732322126627, 0.09641787875443697, 0.1526350410921233, 0.11479350951101099, 0.13181895736072743, 0.13497903064957686, 0.15890603459307126, 0.09964647050946951, 0.07043640648147889, 0.04993407055735588, 0.1233951486647129, 0.11036303546279669, 0.23890297913125583, 0.18461161452744687, 0.17653300373681954, 0.15256228856742382, 0.1075680207993303, 0.15234739652701787, 0.24840607919863292, 0.10542749387345143, 0.1530761838491474, 0.11421117718730654, 0.21206949757678167, 0.09882344824395009, 0.10688615417374031, 0.08122638213847365, 0.10734525096735784, 0.14489047309117659, 0.1112938972988299, 0.08518931841743843, 0.11156007980129548, 0.12579946964979172, 0.10003652636493955, 0.18935532069631986, 0.13502551029835427, 0.08265162458909409, 0.21413334326020309, 0.09047539798276764, 0.05736743525734969, 0.12010311388543674, 0.16897442218448433, 0.09695907149996076, 0.11717879080346652, 0.15659619282398904, 0.12695436339293206, 0.1928336676210165, 0.12884078573967728, 0.14902072932038987, 0.10711630646671567, 0.1112624132739646, 0.13362616752939566, 0.10034722076462847, 0.11472322685377938, 0.10021005491060869, 0.1549044150326933, 0.11119450548929827, 0.11237538033830267, 0.14734116515942983, 0.1457452100834676, 0.18231025444609777, 0.11654640973678657, 0.126242620870471, 0.17934080878538744, 0.2283387588603156, 0.09372342976608447, 0.1411455568990537, 0.1374845076352358, 0.06469446673457112, 0.20644906988101347, 0.08033242582210473, 0.111325265972742, 0.0900106964898961, 0.2031681359346424, 0.15708008328718798, 0.06777124984988145, 0.11443166035626616, 0.16192309984139033, 0.09353339246341161, 0.2255381734243461, 0.09872418535607201, 0.11342658035989318, 0.17498142485107693, 0.131703307852149, 0.12727788888982364, 0.09990507377577679, 0.0794818957469293, 0.16738582242812428, 0.11052525282970496, 0.17828286412571157, 0.11473043289567743, 0.13776324982089655, 0.12302864475974015, 0.12066925636359624, 0.11297112051397562, 0.15081895568541118, 0.09856084840638296, 0.14651093685201236, 0.09567073706005301, 0.08408860569553715, 0.13403090009731905, 0.1280539429613522, 0.1427257563918829, 0.12044751111950193, 0.10650863764541489, 0.12111155263015203, 0.09171622818601982, 0.1322614164756877, 0.2935838092650686, 0.07954226500753846, 0.13735691591032914, 0.1478794469897236, 0.09727987607142755, 0.26861315060939106, 0.0897560626534479, 0.1736219935119152, 0.07769926890198674, 0.1175263092986175, 0.21523917892149516, 0.09360188378819398, 0.14984181097575597, 0.09598063757377011, 0.1125863708023514, 0.10164670353489262, 0.12016015153910432, 0.18412773763494833, 0.3596533068588802, 0.11254755859928471, 0.20794929723654473, 0.19904245303145476], [0.07276825992656605, 0.04062558451135244, 0.008116980249594365, 0.03640046230118189, 0.02085629541293851, 0.03465709549241832, 0.0424511388742498, 0.01366345356551132, 0.027988605999520848, 0.03480546395959599, 0.09083595792097704, 0.04457915022170969, 0.04044883970969489, 0.04923871804827026, 0.07667664199003152, 0.05920177325606346, 0.07977707205074173, 0.04993333773953574, 0.024943552878020064, 0.018582429570545043, 0.009167556867136486, 0.012821456916364176, 0.03354753467387386, 0.07675383213375296, 0.017553957079404166, 0.049554708413779736, 0.08046289453549044, 0.023414825355368, 0.012429728472073163, 0.046231919034783325, 0.0478849185497633, 0.06042893776404006, 0.031170887739530632, 0.0476779348349997, 0.02835878586795713, 0.026060906671253697, 0.059996738098561764, 0.02272600374583687, 0.013201076903247407, 0.055416616544659646, 0.02468035084062389, 0.05718580500355788, 0.04764929387186255, 0.01743004471063614, 0.04044972859056933, 0.0767319765208023, 0.04353560068245445, 0.02918121950434787, 0.014552932398925935, 0.036928152199834585, 0.033945922939372916, 0.02275623078458011, 0.06912658283753054, 0.08200462787811245, 0.049984682484396865, 0.03205690858885646, 0.029418828897178173, 0.07542339459593807, 0.009955133311450481, 0.04355040970923645, 0.08159448060074023, 0.020800183959571377, 0.03176595277286001, 0.04469713728342738, 0.01168754686867552, 0.06601139464016471, 0.04517674619065864, 0.07327176683715411, 0.035180340986698866, 0.04251369641029409, 0.012061250878364911, 0.025460213189944625, 0.04791348148137331, 0.02486438480471926, 0.0924225967111332, 0.026962164024423276, 0.02912511144365583, 0.06988164982093231, 0.06551747542939015, 0.02111203865414219, 0.01750560806665037, 0.011769472338658358, 0.04825377697125077, 0.07079427942101445, 0.03431248112714716, 0.021411944347034608, 0.034351927760456286, 0.0343433883972466, 0.01485728079985295, 0.030286196818841354, 0.04838973503293736, 0.013514728019280093, 0.048787770460226705, 0.05097168291519795, 0.018242749851197004, 0.04720736401421683, 0.025134865826527988, 0.04559705113726003, 0.045248219676847966, 0.023612357077321837, 0.03908697582249131, 0.048004350891070705, 0.03376857424154878, 0.015873337796490108, 0.06503236360315766, 0.029225378563361507, 0.03171112375067813, 0.045016262480723004, 0.05499675264582038, 0.06159276102802583, 0.015850990245650922, 0.024667726696601937, 0.02217697392084769, 0.0457684083708695, 0.020094454953713075, 0.02647069262872849, 0.03274408814364246, 0.04768733933035817, 0.016300105789144124, 0.048733986381973536, 0.042399556642132144, 0.049234056512692144, 0.016379083872639706, 0.01608837572192507, 0.05608290061354637, 0.029051361472478936, 0.01592465370361294, 0.022299753136134574, 0.06704823686076061, 0.0375963972349252, 0.015240583535549896, 0.0872852180951408, 0.03791218064725399, 0.06774794895734106, 0.016482446808367968, 0.04591575903551919, 0.03187022664185081, 0.03632963342326028, 0.03595706341522081, 0.010337270663252898, 0.008423370192758739, 0.009673282587235528, 0.0312982182284551, 0.0057571906696206755, 0.015714078842263137, 0.03614403373960938, 0.040898253808596303, 0.026519146814410175, 0.05963266334895577, 0.017418043122493794, 0.033752855977841785, 0.0357935059416507, 0.028420094899567108, 0.01657260036362069, 0.017469440453818867, 0.06672466386641775, 0.08025069627910852, 0.01853279473393091, 0.05785165141735758, 0.055383358150720596, 0.02114423005176442, 0.03688193039436426, 0.01847528719476291, 0.023428228118323853, 0.0020234683969257666, 0.07818693880523954, 0.06715782705162253, 0.08837611241532223, 0.05150683330638068, 0.0340757538298411, 0.03100031760654279, 0.03911251927326832, 0.012839586523893689, 0.013253366508122002, 0.02183024591899344, 0.03599194690052952, 0.09976471202181918, 0.07502890112144606, 0.028796985479337827, 0.018674345620508705, 0.03330601013398596, 0.02091231187140303, 0.04876400477119854, 0.022693406923541, 0.06602852764938559, 0.027035286350707923, 0.0448771051264235, 0.041173823843044896, 0.014155103924817272, 0.03611196617462805, 0.033044943785560985, 0.09050675308597939, 0.041765150148421526, 0.005198262290962572, 0.027911521028727293, 0.04270972856985671, 0.030000855880124227, 0.03098893178892987, 0.012054350177225257, 0.08690435638917343, 0.013738765015399881, 0.0524451183155179, 0.020954464163099016, 0.04061329284948962, 0.029722415642546754, 0.01775632336336587, 0.046953456210238595, 0.018403277665908848, 0.025619451788121035, 0.03586845013446041, 0.01206540860169168, 0.021383671489145075, 0.05777106859854289, 0.02596208992015038, 0.02862137383116143, 0.03456047549843788, 0.020372581368844424, 0.01138626374969525, 0.03556128750954356, 0.033837934091155014, 0.02750826597080699, 0.048369524867406914, 0.13782887772790023, 0.02229430110725973, 0.015314835622640592, 0.0552332967386714, 0.025027818445648466, 0.0664627764906202, 0.04368862389986004, 0.045474636634545665, 0.05490129294672182, 0.06851273256220988, 0.024139575394136564, 0.05945400507854564, 0.026537516453702534, 0.014671399524169309, 0.0176694573102785, 0.0356466098954635, 0.035678653711719174, 0.0499428949052734, 0.04804127337411046, 0.04360220228720989, 0.04840634557019387, 0.007788558274374476, 0.04303423794252532, 0.04949778950374041, 0.04764894103365285, 0.035482825112662146, 0.04560943100867527, 0.019539209747953073, 0.06599538121372461, 0.03845301037654281, 0.05035484030044504, 0.023585071487884437, 0.02531808045958834, 0.04948175911392484, 0.04745390971324273, 0.018120691579367434, 0.06536074741078274, 0.02607316949537822, 0.01641386218502053, 0.011179644747504165, 0.03845580594081964, 0.013389223637724561, 0.05518258303137762, 0.020110446327765073, 0.06848445122263261, 0.023437150853819082, 0.031065233051776886, 0.028222296852618456, 0.020261942841378704, 0.009069630693245147, 0.018061541985454302, 0.03946741344407201, 0.06587479197021041, 0.03705155736367617, 0.03854100958311132, 0.03129064238497189, 0.016911123180761933, 0.07679646448897463, 0.016369531795914685, 0.03447277484727757, 0.030309110946421112, 0.0369480264905308, 0.03904895411272134, 0.032690809573978186, 0.028822189662605524, 0.055173229426145554, 0.022691870041723763, 0.03674359406743731, 0.012266957250955914, 0.03257865112807069, 0.05258180919502463, 0.0787560125546796, 0.02366028370202652, 0.004836165895020323, 0.012567560986748763, 0.009623117645138075, 0.02906035545415112, 0.045412737277469466, 0.0766215245904667, 0.025908075139990876, 0.00852488327239241, 0.08986246372972216, 0.059216877445578575, 0.04186748340725899, 0.05951873053397451, 0.011608321119898131, 0.0384120981075934, 0.01476752758026123, 0.06724986354155199, 0.06786715398941721, 0.022646074016977633, 0.018650965000103627, 0.08375023385243756, 0.023014479516340152, 0.04208297595115645, 0.015998593664595058, 0.047280421879674704, 0.01255215993816299, 0.024636101875720278, 0.04038846366373556, 0.04440516366490296, 0.03021761049915637, 0.07388341187366418, 0.040842529120189805, 0.0048320467633727405, 0.036224966003958664, 0.02258008479007653, 0.06973818716193948, 0.013099808944389224, 0.018160058484811867, 0.04889411725369947, 0.018092596836920296, 0.013720958560173, 0.035316662064620426, 0.038143415203584094, 0.018806620933381573, 0.05724255767251764, 0.04859078495896288, 0.00471070095331275, 0.008151791640557349, 0.020205922990239093, 0.04919314085106764, 0.0028381983283907175, 0.05062363177005734, 0.02090041375985103, 0.051151569333991835, 0.04691693406285984, 0.014479474197807056, 0.06145288781928165, 0.04881620786285826, 0.14787651571844304, 0.1285815853625536, 0.0779269513274942, 0.0918809018496956, 0.1455810453210558, 0.14597426993506296, 0.10094815851854426, 0.09582063901637282, 0.23345968978745596, 0.11846841445990972, 0.15745352182005132, 0.18989832513034344, 0.102274952323309, 0.09558361994900874, 0.1116207204759121, 0.1681672233555998, 0.16109755342560156, 0.11113673501781055, 0.162870497575828, 0.14166417478450707, 0.11835032222526413, 0.09304820599832705, 0.15204447135329247, 0.18784771087978566, 0.11391610944909708, 0.19723985690091336, 0.14493982972843306, 0.10368147399276495, 0.08901488528187786, 0.1187787763774395, 0.12188262625464372, 0.19010154636842863, 0.09950971177646092, 0.13133043928870133, 0.06517989747226238, 0.10368961641298872, 0.17884437899504388, 0.17160998790391854, 0.14115245081484318, 0.22108558591987404, 0.10234047845005989, 0.10388669012380497, 0.10291356912681035, 0.22024226188659668, 0.16642801596650056, 0.1225693579763174, 0.20920698903501034, 0.10889532350535903, 0.17744126357138157, 0.14978941450161593, 0.1565562949648925, 0.1558015468929495, 0.18843870131032808, 0.13448326582355158, 0.13549958914518356, 0.1081622207005109, 0.12531564704009465, 0.13027324101754598, 0.13520118301468237, 0.09969742848937001, 0.21236501314810344, 0.10848234673695904, 0.12891043057399137, 0.08819929976016283, 0.1343768715326275, 0.22744181698986463, 0.10705036643360342, 0.07578503340482712, 0.14074610333357537, 0.17284261461879524, 0.0865039053772177, 0.0997818721724408, 0.15346431945051464, 0.0856707322278193, 0.1549816730299166, 0.1436431628784963, 0.20713038689323834, 0.07531284767069987, 0.16158755070396832, 0.16816274502447673, 0.0853203231734889, 0.09318559576890298, 0.10160399654081889, 0.15014021710625716, 0.08044819746698652, 0.0733009370576058, 0.11244925244578294, 0.18132784430469784, 0.1230282104973282, 0.09952663443982601, 0.19623973699552671, 0.13884526890303406, 0.17284226178058557, 0.1332249226314681, 0.06107565627566405, 0.13859882498426096, 0.06948095453636986, 0.11860706630562033, 0.12613014690577984, 0.13597832274224075, 0.11415720651192324, 0.10766815899738244, 0.11958491669169494, 0.09863704788897719, 0.12298386144850935, 0.1397834928440196, 0.10169285748686109, 0.17440006961779936, 0.17741995757179602, 0.1458782029471227, 0.08440895564854145, 0.15229257089751108, 0.11063552155558552, 0.10621312885944333, 0.11657332043562617, 0.12074555084109306, 0.14893017203680106, 0.17761207797697612, 0.07469662930816412, 0.14435221840228352, 0.143039768827813, 0.13494017773440906, 0.11708640147532735, 0.13557908630796842, 0.2317875080874988, 0.12732155940362386, 0.07494364319635288, 0.17302486912480422, 0.14189406244882516, 0.18443465259458336, 0.15186483599245548, 0.14948597364127636, 0.13918917759188584, 0.15099527979535715, 0.10263347665646247, 0.17757710628211498, 0.16534709611109324, 0.1809564278061901, 0.1737074346414634, 0.08123970178088971, 0.17887280961232527, 0.10060901314552341, 0.1408113105488675, 0.055522817453103404, 0.11389005370438099, 0.08992174054895129, 0.11067129392176867, 0.12213266640901566, 0.13330219419939177, 0.13798609429172107, 0.07739401635314737, 0.09506441852343933, 0.15882883087864944, 0.20737455093434878, 0.11200462201876299, 0.10892195600484099, 0.15963944952402795, 0.1024691965430975, 0.12263669579156808, 0.13426960871687957, 0.07959358939634902, 0.09321076941809484, 0.20654270771358693, 0.13729812763631344, 0.10355212486216, 0.13548409140535764, 0.1618764302028077, 0.22323712546910557, 0.12387116812169552, 0.14489170802491053, 0.1266518317695175, 0.19335414469242096, 0.13403415706540855, 0.1474543855126415, 0.23592556746942656, 0.1379317979195288], [0.07139421294310264, 0.040318713656493595, 0.04298657085746527, 0.038024189815457375, 0.12274081020482949, 0.03654495294072798, 0.017129586011703526, 0.005010567206357206, 0.02939311581264649, 0.04294676799327135, 0.052233615557530096, 0.02510811627975532, 0.02595701956722353, 0.08213459447558437, 0.01437881013511547, 0.06452650896140508, 0.057946931304676194, 0.02476279454172722, 0.03653419137533222, 0.0072127755099375334, 0.03003374786515321, 0.04369515819208963, 0.028138865883062993, 0.01869953962575112, 0.03037996357306838, 0.03650626626663974, 0.035841953341982195, 0.0040775255765765905, 0.03252244467980095, 0.11787021798746926, 0.09272119961678982, 0.03301714759852205, 0.1008584765451295, 0.06915440277329513, 0.021692158953685845, 0.035681795328855515, 0.014518026861229112, 0.01406395377125591, 0.042240728557642014, 0.02414042017023478, 0.010359842978817011, 0.09718575647899083, 0.01158993027638644, 0.014637672941067388, 0.02017698177535619, 0.016737986489066055, 0.03689473095749106, 0.0469225251914135, 0.03877578269956367, 0.03402910115463393, 0.033229121938347816, 0.035577745376420875, 0.020130466503490294, 0.03052827436476946, 0.01932590378315321, 0.02868669979008181, 0.01845903119205364, 0.04625349644837635, 0.021396612848288248, 0.027629187696480324, 0.03070605393233044, 0.0572044715019209, 0.010209852812944778, 0.02657436769056533, 0.010559962463698216, 0.03740350329982383, 0.030932596419006586, 0.056024872298751555, 0.015714631848303334, 0.030246750185532228, 0.019367638775812726, 0.01287349546328187, 0.04291989800653287, 0.03284420598564403, 0.03681595304182597, 0.01180198519224567, 0.03774305579385587, 0.05042348429560661, 0.02642697631381452, 0.012665370961518159, 0.02296668181328901, 0.023396218228819113, 0.047058215231767724, 0.026309484582660452, 0.022514224484828965, 0.030859145003237894, 0.014496524086488145, 0.07832842014197793, 0.011443624555665468, 0.032190413746450625, 0.028970222254948955, 0.09719381068966218, 0.06821081840566226, 0.06312618231666939, 0.035120063328317234, 0.024054361573819603, 0.02936862748382347, 0.0033769710363620625, 0.014205353683792055, 0.05848638700055225, 0.06705055745052439, 0.016562391804265122, 0.050650484793420346, 0.03423893471647586, 0.010230125742964447, 0.017205471671851616, 0.057755570858716965, 0.052154617117983956, 0.025269020681402514, 0.04231736569532326, 0.05076793920514839, 0.06399045272597245, 0.04524717812559434, 0.048148865279342444, 0.048494324420711825, 0.027535624502758895, 0.05403180799580046, 0.025463247937815528, 0.027735509044889892, 0.008674059196242263, 0.03222834385399308, 0.03835153207182884, 0.0016892889460515498, 0.021677358408591578, 0.042915066837200096, 0.023071318698514785, 0.08035005416188921, 0.010929092299193144, 0.069689631196005, 0.06220908795616456, 0.03201749588229826, 0.015555618863020624, 0.006313773861620575, 0.053873953609062095, 0.029106750286051204, 0.008219948786843036, 0.038260859437286854, 0.04262791760265827, 0.025376773738701428, 0.12311008253267833, 0.0261752924083599, 0.021915983907612305, 0.016679737650390183, 0.05522786845852222, 0.0172606789773064, 0.03968032416222351, 0.0246938757398831, 0.013547569114182676, 0.06087984463998249, 0.023860941774078777, 0.0436297067041908, 0.0071327482416693655, 0.028533120173960924, 0.09035605045833758, 0.010321715247950383, 0.04258687301938023, 0.026002026795010482, 0.007847766391932964, 0.02381426535014595, 0.05045694285737617, 0.018138564191758633, 0.029767297341355255, 0.041085950165454826, 0.09221533818968705, 0.034751374540584426, 0.04307176432173167, 0.07745000227753605, 0.054261101941977224, 0.037577157374471426, 0.027703080160011138, 0.04038348660937377, 0.059021676491413794, 0.0953208233362862, 0.04277637427938836, 0.030332693430994238, 0.02373342977703682, 0.059703780604260306, 0.04081514683951225, 0.011113846358577055, 0.048271462986511846, 0.038988601815487654, 0.05469102512246796, 0.03750415039913995, 0.07207456643560103, 0.017780847315277373, 0.06745134772998945, 0.03671381316546883, 0.03496190020814538, 0.048952583223581314, 0.0753825128610645, 0.024173773559076444, 0.03579837782308459, 0.029435761738568544, 0.025992171073864614, 0.03990800319505589, 0.04193985255967293, 0.02799187314563564, 0.060767302821789465, 0.020342775021812746, 0.0010987811235411624, 0.027947882024039115, 0.0209041931999049, 0.0690143531454461, 0.0335229174233973, 0.012141194177924522, 0.02142003926980708, 0.09031425948653903, 0.048346631095877717, 0.03434485064021178, 0.0960626249600734, 0.034109493983643394, 0.04668622537116919, 0.037545052490064075, 0.018545269600248764, 0.037429097640727244, 0.04486551235562988, 0.016294407791325023, 0.02235317419815276, 0.03318937674963048, 0.048506181820162704, 0.013105308470715369, 0.04168727468433125, 0.05677889094554952, 0.04930616442912391, 0.011273223208263516, 0.015396178400676166, 0.0597568488280688, 0.028672969633979455, 0.012400979791501803, 0.03682079778185912, 0.059128443976598125, 0.02549304410682193, 0.05918970890343189, 0.028720850457570384, 0.05506393779069185, 0.0390409406141511, 0.013466985447199216, 0.051446884737483094, 0.03637294092082551, 0.06779288833162614, 0.08521551665450845, 0.030435080972633193, 0.04993941741330283, 0.07582854785557304, 0.042658563636775525, 0.05693661980330944, 0.012932644209026225, 0.06713808846793004, 0.06249692251107522, 0.04020941184301462, 0.046462047579033036, 0.05247812904417515, 0.01109911875599729, 0.05479751101561955, 0.03182074786829097, 0.020265435600387197, 0.022544275104467357, 0.01782174770986395, 0.025509771691369157, 0.03967546924416508, 0.010745211853645742, 0.01817651465535164, 0.09606883355549403, 0.03780083305069378, 0.04680200719407626, 0.044138543507350345, 0.061848921568265984, 0.07402844873390027, 0.002032798677516569, 0.09173815843782254, 0.05150679937962975, 0.035218837670981884, 0.009214737103320658, 0.0365031755396298, 0.029409760276653936, 0.021184139785223773, 0.07848901581019163, 0.03459929109417966, 0.015686131681182554, 0.027976105688139796, 0.035429895988532474, 0.03201412017058049, 0.04322654155216046, 0.08336361138416187, 0.004675504069642297, 0.08143281284719706, 0.04154348972120455, 0.03244802974430578, 0.11218616406300239, 0.0180085534895105, 0.04729927158249276, 0.06713049566107136, 0.02290575615396457, 0.05044162153665509, 0.12172724173537322, 0.04152424646807568, 0.016270570856119906, 0.03987392716641937, 0.03255838667973876, 0.05679850060758846, 0.01673197975781347, 0.03458412583651287, 0.06146442969994886, 0.023251296719536185, 0.03821507867957864, 0.012814388277807405, 0.06347587212388005, 0.08002282386379582, 0.014665304583364298, 0.040020124321537356, 0.006499720870384148, 0.023425020344023193, 0.05365587245406849, 0.04626932667036142, 0.022391996579244733, 0.05929450185171195, 0.0729438987161432, 0.023369736703378812, 0.035446150294904194, 0.0737540763137596, 0.038322819862514734, 0.021942702920309136, 0.02739173945571695, 0.036003675378326855, 0.04299101186916232, 0.023511026353974427, 0.043925500474870205, 0.05030874741662826, 0.033438287143196375, 0.056164022867700884, 0.03256622375920415, 0.06699771314327206, 0.01760409233559455, 0.05448230775073171, 0.016620208076866608, 0.07171851875526564, 0.0028835170461596654, 0.04671548040849822, 0.05339391722476908, 0.06572259656552758, 0.04372721218637057, 0.03894481255805918, 0.008792131074837275, 0.030377883863236223, 0.0019718178872218622, 0.027173444562192475, 0.036808909848332405, 0.03030735014804772, 0.04251596950260656, 0.044136338268539736, 0.04937177198007703, 0.03348316205665469, 0.1077664787215846, 0.13813903608492442, 0.09591449398015227, 0.1679193680839879, 0.1957742212606328, 0.1612318219350917, 0.16196781529911927, 0.1443103663623333, 0.08077724623892989, 0.1486751242939915, 0.19633418907012257, 0.12360715014593941, 0.14580553184662545, 0.21492606215178967, 0.16601885935025557, 0.21297872093107018, 0.15951013432017394, 0.082532385630267, 0.11971333622932434, 0.17603917952094758, 0.05644385749474168, 0.15443777292966843, 0.09985726419836283, 0.11096032269831214, 0.08803164732775517, 0.07903444261423179, 0.1800770599927221, 0.09136241967124598, 0.13353555596300534, 0.32142787373491694, 0.12566939448671682, 0.09538898896425962, 0.2185604449893747, 0.14122239420456545, 0.13073126572583402, 0.23200778769595282, 0.2125764853720154, 0.10571853111365012, 0.2550148202904633, 0.09121158133660044, 0.13240408524870872, 0.10799805593809911, 0.14857673671628746, 0.1720233785786799, 0.11712490155228547, 0.11523325448589665, 0.1354965628790004, 0.09437970883612122, 0.0532666410186461, 0.14082572263266357, 0.09377054723777942, 0.13093428340341362, 0.08159532876951353, 0.18337089967514786, 0.15436470827886037, 0.10380948640938316, 0.17087186393993242, 0.14837382760431084, 0.1605413854122162, 0.07838382931160075, 0.11500503601772444, 0.10300178546458483, 0.0940700118829097, 0.13390976802578994, 0.1523170524409839, 0.09663975292018481, 0.1187335452330964, 0.1552189024431365, 0.1890609043517283, 0.1361171645777566, 0.10777096383805786, 0.1989243065140077, 0.11992251500487328, 0.20011509475963457, 0.16330805766795362, 0.11996546627155372, 0.18208002751427038, 0.24869651932801518, 0.07886191830039024, 0.09666513012988226, 0.14430591517261096, 0.0408712481148541, 0.16139293328991958, 0.0909056638234428, 0.1205810196697712, 0.13049922032015665, 0.14109387967203343, 0.31305947420852526, 0.1031329802104405, 0.11760761136455194, 0.1838090568780899, 0.26289573311805725, 0.18264441937208176, 0.18489875697663852, 0.2547489159873554, 0.11664126893239361, 0.10399362724274397, 0.10610506537237338, 0.2198238093405962, 0.08790544659963676, 0.21100468614271709, 0.11640714720955916, 0.12183804650391851, 0.09593226481229067, 0.12637592586023466, 0.10499683448246547, 0.12177285285932676, 0.1805665958672762, 0.13304444588720798, 0.27858943385737284, 0.1401455727006708, 0.11944596629057612, 0.24350046100361006, 0.07888916826673917, 0.09036937010075365, 0.17706995563847677, 0.11711308147226061, 0.09597491073821272, 0.19745382613369397, 0.11739812046289444, 0.1450875060898917, 0.08566151093691587, 0.11448895585324083, 0.16872577981225081, 0.0770946874150208, 0.15011897896017345, 0.10803228124443974, 0.1377675381622144, 0.1366195519055639, 0.17731022488858017, 0.08866843887205635, 0.1791336927562952, 0.10924558328198535, 0.14281372167170048, 0.08404267566012484, 0.08559666334518365, 0.11924244649708271, 0.1371416031782116, 0.0901978500187397, 0.1270463184586593, 0.13975480438343116, 0.0955179784713047, 0.12884928099811077, 0.13894098305276462, 0.1370323183281081, 0.13549572149557726, 0.11895995879811899, 0.13806671782263688, 0.1120948875322938, 0.11901679289128099, 0.10768833184348685, 0.24782199625458035, 0.15205369942954608, 0.18565750840519155, 0.16193364427558013, 0.1543658482176917, 0.0804078924868788, 0.14285242530916417, 0.13552428781986237, 0.11464723093169076, 0.09141350657280002, 0.1700302633856024, 0.16193027874188765, 0.2165794348610299, 0.18304282799363136, 0.16285928817731993, 0.15645185485482216, 0.1189817940550191, 0.07727774259235178, 0.1847954432346991, 0.11539725639990397, 0.10668483283370733, 0.19962595243539127, 0.10458057360457522, 0.12196364333587033, 0.09686349305723395], [0.02903560588934592, 0.023998854016619067, 0.03651697015655892, 0.046535655057856014, 0.0422688979389412, 0.04083664622157812, 0.014517424661400062, 0.036153468769043684, 0.08123903681657144, 0.0485607055015862, 0.07467226990099464, 0.05456757924652525, 0.036429897150290866, 0.014501473999449184, 0.0194735055057598, 0.04642192580338035, 0.03111453540623188, 0.027251676257167543, 0.059111908078193665, 0.09740895378802504, 0.037491492328367064, 0.012089268437453678, 0.05855417264891522, 0.009215268905141523, 0.006475472149239587, 0.016396264379311885, 0.048896722828171084, 0.060972057549016814, 0.04768341739795037, 0.02433768895986889, 0.014414585893973708, 0.03764606599829026, 0.007905475795269012, 0.028415307835010544, 0.09507517330348492, 0.07952785292374236, 0.04284532700798341, 0.006195113777981273, 0.028871132393500636, 0.02526649653113314, 0.04208858065041048, 0.057135566270777156, 0.013178574137522705, 0.021323322584586482, 0.0387946459730821, 0.03260092743273292, 0.027378321425723176, 0.020878637874765054, 0.04841644556394645, 0.04804655237655554, 0.0210997843117054, 0.041225511248090436, 0.031129822800202028, 0.01668955265943493, 0.01608357678300568, 0.10469547672463314, 0.01957818479942424, 0.03602593811228871, 0.031523457927895446, 0.05468033141057406, 0.05302061779158456, 0.015014612714626958, 0.05465279645951731, 0.047413679371987066, 0.020316342690161297, 0.013843767461366951, 0.05642515028427754, 0.0433265813626349, 0.0672975034852113, 0.013905721101244646, 0.029036348885191337, 0.032351179048419, 0.051748323919517655, 0.07030502853116818, 0.024921473348513246, 0.04121012207386749, 0.08283609790461403, 0.005129625505235578, 0.034222361498645375, 0.005420792939340962, 0.03262435046157666, 0.04060062120801636, 0.036543802823871374, 0.0545520407945982, 0.04850382051829781, 0.0619917396189911, 0.003658123081550002, 0.03840922111911433, 0.027923634575147713, 0.012687755831783372, 0.07460683198379618, 0.02300801986296262, 0.050881129024284225, 0.0017043906970814402, 0.020480717798428874, 0.0432399290480784, 0.04008976915585143, 0.05095648712345532, 0.04383038004328098, 0.024647726876927272, 0.03807722071983984, 0.022148244748158113, 0.006232154156480516, 0.037132720329931805, 0.034157910849899054, 0.03010697875704084, 0.0806441040975707, 0.0319983001266207, 0.04532075507034149, 0.0211626404031579, 0.031431373940514665, 0.06988101199801479, 0.0015218652011494019, 0.046724155478711636, 0.03685035137459636, 0.02105924523701625, 0.006004157908526915, 0.04502523610634463, 0.03464836274672832, 0.010251041584914284, 0.06120727849858148, 0.005488018796313554, 0.0259854756295681, 0.02729265807595636, 0.01999538714465286, 0.018527612422725985, 0.01658772660552391, 0.034484140308839936, 0.005644026719632426, 0.07298977446875402, 0.023633172835356424, 0.06759403685906104, 0.06453511278544154, 0.06213961275560515, 0.02875414617093546, 0.1154600480305297, 0.03783108214182513, 0.004234121704939753, 0.025992316958893622, 0.006843219893718404, 0.013526862769919847, 0.05942277889698744, 0.04444852883794478, 0.029549789548452412, 0.011975718146589185, 0.04499200824648142, 0.01310449677319931, 0.020409027181033577, 0.03902764811313578, 0.027848449502406374, 0.053846415265330246, 0.06345162806766373, 0.04942402596186314, 0.08637167925813369, 0.023374735810128704, 0.04004207153671554, 0.07649068268282072, 0.016152522726250545, 0.009944443840400448, 0.036825557705014944, 0.025336953911132047, 0.014809459348076155, 0.05667725997045636, 0.048567168547638824, 0.025003223247560005, 0.035677937857274494, 0.059050249601049085, 0.020105450613690273, 0.018168423125254254, 0.02154480659269861, 0.04578835730041776, 0.02748387094054903, 0.017588879580476453, 0.015028855164668389, 0.020648899488151073, 0.025266910437494516, 0.021465402728478824, 0.07326999586075544, 0.018967055449528352, 0.08118522898959261, 0.06008260670517172, 0.029636682742940526, 0.026061430839555602, 0.0413103722301977, 0.03714391276506441, 0.05832137406936713, 0.06342439845736537, 0.023818053271887556, 0.001062824810755306, 0.012058391701430082, 0.05559857928061059, 0.06095683800854853, 0.09398550034633704, 0.01643682211371405, 0.06261333876422473, 0.035002934613398144, 0.030298753109361445, 0.018344911779942255, 0.03412574829001512, 0.026592674565368464, 0.053042527687336714, 0.030104230690215315, 0.03489725956959384, 0.02469229814596474, 0.06184470786580017, 0.06002294312098196, 0.052738136877971034, 0.02060509835635977, 0.06397709237145525, 0.0199817621614784, 0.0231696587787675, 0.026101157368559922, 0.01764744733061109, 0.03884176005210195, 0.018277207555781518, 0.008376245087544833, 0.026567322800734212, 0.02820104852850948, 0.029568751209548542, 0.029094139712729623, 0.029381651963506426, 0.00886771987591471, 0.04489323390381677, 0.07948404670293842, 0.029648014277751957, 0.03942919495914664, 0.03760982883561935, 0.06348453701606818, 0.06909775188458817, 0.03730687991316829, 0.018456072779372334, 0.11208657547831535, 0.012833779960471605, 0.03301595337688923, 0.034703571748520644, 0.07980037294328213, 0.03697701011385236, 0.038151119968720844, 0.026947370264679193, 0.07921338586934976, 0.025185973084132587, 0.09243620133825711, 0.037220047786831856, 0.0352383591234684, 0.06015024986118078, 0.01088920037727803, 0.04854407460827913, 0.038797750270792415, 0.04685955374900784, 0.08913504026298012, 0.07681908684649638, 0.038933419955096076, 0.07769808825105429, 0.04549853124522737, 0.035528917996478934, 0.025044831014903526, 0.052917677243905406, 0.05707327675606523, 0.023084270235683237, 0.039355329637016566, 0.031274659492607625, 0.02839406968892685, 0.06039099408579724, 0.028201097722298334, 0.027497148174526434, 0.02397863706573844, 0.01407857789724533, 0.05944441059338195, 0.02321036409453622, 0.05029465763696602, 0.018420470046943853, 0.02313515018405659, 0.03833095210471323, 0.03285726099940283, 0.0274328060913831, 0.06301543861627579, 0.0123968771991453, 0.027891246402370076, 0.03105597783412252, 0.05950908176600933, 0.07855194314782109, 0.02946566477684038, 0.052714340654867034, 0.04082104670149939, 0.04380132178110736, 0.015404386978064264, 0.021291059940787296, 0.020746442289756875, 0.05119504985798683, 0.055818455160728524, 0.0297690818884543, 0.013446454673872461, 0.051465273036488464, 0.04381842764892748, 0.028081200584503155, 0.009311771851831248, 0.03158918082980173, 0.01844898208842746, 0.03658697122175779, 0.012784913564766092, 0.07466099264898471, 0.025459510906200324, 0.07374727739287273, 0.038256947682904344, 0.07641989112432514, 0.01279463866792087, 0.02741908441696848, 0.0024291943825249162, 0.037847295736095736, 0.06094932662589209, 0.03496238196800862, 0.00853473475269441, 0.055777017027139664, 0.07295315393379756, 0.03608425819714155, 0.006515020986885897, 0.08031783053385359, 0.08751034922897816, 0.057872774212488105, 0.03905953247366207, 0.04030921416623252, 0.007849006414679545, 0.008161587141720312, 0.08188721417848553, 0.02590179699473083, 0.05001967792798366, 0.05314923071169427, 0.007626234038200761, 0.04009234758892229, 0.09453141569559063, 0.029042167322976247, 0.01753183174878359, 0.033056746902210374, 0.006864221824798733, 0.037282676569053104, 0.051710193644144704, 0.043537110422870944, 0.032562702162457366, 0.023534739456538643, 0.05579113734087773, 0.036823634058237076, 0.022216700449852005, 0.06839103052126509, 0.09774665388145617, 0.04109155825738396, 0.014815995336643286, 0.055489029801849804, 0.06172004741217409, 0.02054290214021291, 0.034786522654550414, 0.025653049449569414, 0.014594407851940818, 0.2255184551967042, 0.18850070584033216, 0.14212279660361155, 0.18650604358741216, 0.1511799091739314, 0.12739551972065652, 0.09589687921106815, 0.1326390483549663, 0.12020732329360076, 0.17345705521958216, 0.14951926256929124, 0.12924074142106942, 0.1678037592875106, 0.14199312856154783, 0.13380664427365574, 0.16540907349969658, 0.1754421636994396, 0.1707447471895388, 0.10305929809276547, 0.17006315876330647, 0.10913523313190256, 0.07451202707099062, 0.1711063249302762, 0.09685619202043329, 0.09329831400620085, 0.08804565907589026, 0.13580492990357534, 0.14747262453394278, 0.19364216923713684, 0.18078854467187608, 0.13589262376938546, 0.14126390697700636, 0.13381405387605938, 0.10128859310810055, 0.10339313732194048, 0.11945614431585584, 0.15962395178420202, 0.1469400016857045, 0.12374584270375115, 0.07515049459678785, 0.13142050802707672, 0.11691580420093876, 0.16377403480666025, 0.0634281507560185, 0.18624301627278328, 0.10221960422183786, 0.12210389652422496, 0.13048917800188065, 0.09367218680147614, 0.17272213394088404, 0.12292843870818615, 0.22985620743462018, 0.12925779979143823, 0.07795332598366908, 0.16837474650570325, 0.27256263153893606, 0.0836318905598351, 0.1311297422008855, 0.1331927329301834, 0.15746033431163856, 0.12397110275924206, 0.07767336243497473, 0.10279046251837697, 0.17730071182761872, 0.14369855847741875, 0.17390201134341104, 0.06672461636896644, 0.09150929536138262, 0.18286305692579063, 0.07138056081852742, 0.14089771519814218, 0.14896305384380476, 0.11677564600748674, 0.1365616185856717, 0.1270402930676937, 0.12759817098932608, 0.2555714632783617, 0.11867301990943295, 0.17921435699931212, 0.07389747111925057, 0.10659565297620636, 0.16929581708141736, 0.12523593274610384, 0.09009602905384131, 0.11005544875349317, 0.12243563229484217, 0.12111691305679934, 0.0999834852825318, 0.07319284642913512, 0.11718572543135711, 0.21178968330579145, 0.09699886079345431, 0.14031203091144562, 0.06195938028395176, 0.14178703033498355, 0.20017196956489766, 0.09277151977377278, 0.17076244338282517, 0.05298034334555268, 0.1794088115649564, 0.17985398481999124, 0.08785956406167575, 0.15023215860128403, 0.07031184780810561, 0.14245745007480892, 0.13514072554452078, 0.1223703572260482, 0.11598574982157775, 0.15545200636344297, 0.06310739368200302, 0.0964181637391448, 0.1715790331363678, 0.20814704948237964, 0.09204269852489233, 0.09604588550116334, 0.07302566218589034, 0.1289001711245094, 0.091924287378788, 0.11339076049625874, 0.15103479767484324, 0.21840871098850453, 0.07439914598528828, 0.08235274348407984, 0.08933046513370105, 0.10384768793093306, 0.09450004023632833, 0.1670350469648838, 0.1655625852623156, 0.1135571508535317, 0.16803334839642048, 0.0678324740646141, 0.1153526630784784, 0.1974458737032754, 0.14448229356535844, 0.11181911054466452, 0.19810914168400423, 0.13056308403611183, 0.13539518974721432, 0.1794315967708826, 0.1095754395106009, 0.1510442564530032, 0.14846629835665226, 0.16032182505088194, 0.11442419647106103, 0.14915233797260694, 0.10211604620729174, 0.14402903217290128, 0.13319029020411627, 0.0936214527381318, 0.10574220520045076, 0.3769765230161803, 0.18353252671658993, 0.17083625442215375, 0.23738409206271172, 0.09172025189868041, 0.1071301553664463, 0.14867169090679713, 0.07895343910370554, 0.11637228408030101, 0.15423153899610043, 0.1276468083794628, 0.13947625218757562, 0.16986694000661373, 0.12980406119355134, 0.08016412199607917, 0.12422965174274785, 0.1658261146928583, 0.20472511595913342, 0.14957361322428497, 0.14223987103572913, 0.09863625400300537, 0.1541913425815957, 0.09452199762953178, 0.13856449111231736, 0.10652621170239789, 0.12055082486144134], [0.04489702352189592, 0.017718528962827156, 0.06187310455633061, 0.01350495541867401, 0.039319034798869064, 0.059705273381301334, 0.020644629806546227, 0.023736294891153063, 0.024598416040784547, 0.04680172560204353, 0.015608291840180755, 0.02066380181349814, 0.0834010054490396, 0.019771433269072856, 0.016728045951042856, 0.02580929740465113, 0.06344596230025802, 0.01563152318288173, 0.02774925616436771, 0.04300340870395303, 0.01869224537430065, 0.017541380432833518, 0.04141350955303226, 0.03338816715404391, 0.05266019356037889, 0.0268596882732319, 0.02158156962000898, 0.022374298689620833, 0.022627684021634713, 0.036223249310361486, 0.008030556940606661, 0.0383919693662652, 0.023929782544395754, 0.03534249050010528, 0.03951485321990081, 0.07746191056711332, 0.02104558632709086, 0.04431283879759056, 0.02480880600134177, 0.02100868589643921, 0.07647067268512078, 0.04761347740090319, 0.015151720893170153, 0.04510490968823433, 0.03598943632096052, 0.07408753556332418, 0.035751854069530964, 0.012838598407272781, 0.019069644855335355, 0.028505785390734673, 0.012187852790313107, 0.04902316104354603, 0.03689536878040858, 0.015174036213595952, 0.024343741492235234, 0.0985304093254464, 0.009148051529856665, 0.04554082772561482, 0.04532019867162619, 0.015128671058586665, 0.043351883933480294, 0.0971961109233754, 0.05405827425420284, 0.07163799021925245, 0.048952169317219935, 0.08630433465753283, 0.010702656681782432, 0.00888027107742216, 0.02639396728149482, 0.016101164410689046, 0.024804210622927973, 0.04910556233621069, 0.03133100504055619, 0.036867949180305004, 0.03557776912514653, 0.02088356064632535, 0.01561303310362356, 0.058494224080017636, 0.04290539092783417, 0.0391481762884983, 0.016366758284025958, 0.01656519415389214, 0.04066507185676268, 0.005791561860990311, 0.08528985016580139, 0.033098015402044566, 0.013131758613911058, 0.012574255582876503, 0.03300169735614743, 0.02596686002133148, 0.010809793120383151, 0.030270634618188654, 0.08713180811277457, 0.017862344460029687, 0.04041572380810976, 0.007532705619399036, 0.032267641209598096, 0.006437651455468897, 0.014540350663342645, 0.08488965021180254, 0.06010347844234534, 0.0736032108377133, 0.020955727934571247, 0.07604865104492221, 0.01794445567897388, 0.02554730315958815, 0.031241733580827713, 0.0402368280504431, 0.029580065780984502, 0.07917521827455078, 0.03741934709250927, 0.03259683247389538, 0.04725185216271451, 0.05888054799288511, 0.06135093114737954, 0.029944367839821746, 0.06161956994661263, 0.012697447008187217, 0.04119107220321894, 0.04042061943826931, 0.026778983318113854, 0.04525533750919359, 0.011403240695861834, 0.030647459040795053, 0.016996990091034343, 0.015581998608208128, 0.021320416758369123, 0.041332760493138006, 0.028170056441532712, 0.03694738866761327, 0.04746335152802723, 0.03500079383541431, 0.04447329197345035, 0.02586110185698739, 0.017928832410169498, 0.02668977971188724, 0.01914425317331084, 0.030523894421224083, 0.019677186451320137, 0.030720218350844722, 0.05549728078767657, 0.02646337802122746, 0.03037212649360299, 0.030494812410324812, 0.039132916035928896, 0.06324390135705471, 0.04399637345756803, 0.03267644838030849, 0.022010958454172527, 0.035511459290449104, 0.0413021890978728, 0.04398255169923816, 0.012857700016216507, 0.026266414572351744, 0.020243120279961398, 0.029246304583336626, 0.019363343649144684, 0.1509751273053033, 0.031409599751766236, 0.03457309964245983, 0.01047445772149201, 0.01941553995545421, 0.04600005344088588, 0.06866942665406636, 0.06335355261606829, 0.035786707020763836, 0.023191266726436358, 0.027399120220382298, 0.035755348524877, 0.019492280569725802, 0.062065034971705506, 0.0588076597611819, 0.04798657666625721, 0.016992978252736584, 0.02546429797075689, 0.06232508351760251, 0.08021469999636922, 0.014757073051961405, 0.014754713446434056, 0.05632219955857311, 0.05289209647370236, 0.037077385799161026, 0.030303055021379675, 0.039584630368543525, 0.025319641090131233, 0.01856457392152931, 0.008275745569595268, 0.05026712268590927, 0.04272543326286333, 0.040201903853033266, 0.020462982589378953, 0.024125704442017844, 0.06032160709479025, 0.01018784283327737, 0.009956650685385933, 0.053654946253768036, 0.026263573206961155, 0.05613266097913895, 0.015939153996961455, 0.07067037214125906, 0.04119800343843443, 0.00928244217565017, 0.01563607106384422, 0.029374523953135525, 0.059537430959088464, 0.03456216844330941, 0.025310669160847152, 0.02169123275338539, 0.009935291251167655, 0.05127913052482264, 0.023579895962029696, 0.0533757833763957, 0.004567974504815149, 0.03268311159419162, 0.04307932659451451, 0.009734020801261067, 0.017830412602052093, 0.037141103630087206, 0.045489286205598285, 0.017031493596732616, 0.05419600668496319, 0.02502495502786977, 0.039567219159965, 0.04996746465829866, 0.0984621826293213, 0.020520578338099376, 0.025488818529993296, 0.04592176067775913, 0.015376088675111532, 0.006374185954752777, 0.029957036088619913, 0.04963484339948211, 0.005315195502979415, 0.015266237248267447, 0.009886796353384852, 0.03071881378335612, 0.015550563777131694, 0.06291697639971972, 0.02355941607882934, 0.02681202966985958, 0.03963118465617299, 0.03010040714538523, 0.0804988161793777, 0.03145353150154863, 0.01517782243900001, 0.009555064823611506, 0.026611861839358295, 0.0641676928581936, 0.036969088217509646, 0.03449574325765882, 0.01124238463983472, 0.01441181916743517, 0.02616871570769165, 0.06020454623337303, 0.05823434516787529, 0.03477891966966646, 0.01422890308978302, 0.032931428269616196, 0.06905560807457992, 0.08135019442332642, 0.02175266731397382, 0.03886021959728428, 0.042845374505434713, 0.01767801194052611, 0.01663480166878019, 0.002682735989635278, 0.03181026789492794, 0.03213469245071922, 0.029941986181906292, 0.038079432744000635, 0.04948847321793437, 0.055910668069762845, 0.08505160973540374, 0.02382342387656016, 0.0877182659293924, 0.047063548517014296, 0.01685846207796463, 0.031146046572497914, 0.022360202124608413, 0.055687111137168746, 0.03983584438849773, 0.05104549056185143, 0.05796326364257506, 0.010763965713392411, 0.030358118138142993, 0.025053909813453044, 0.06118011674178498, 0.03127536177635193, 0.018123694096824954, 0.04357373774317758, 0.06847242079675198, 0.0334769297125084, 0.047926641668059995, 0.04453732193048511, 0.014967211954561728, 0.042372415241386206, 0.03991952132699745, 0.003970848845451006, 0.004875544674827584, 0.04417444479518703, 0.014491686131805182, 0.021221114854727472, 0.017530162552637712, 0.028247825036357557, 0.05978077397282634, 0.028737956325390508, 0.02112873231193849, 0.03555457340553403, 0.0534590701572597, 0.03183038645823087, 0.06918818024652344, 0.0018714498354321612, 0.03979591938800045, 0.048150704109242985, 0.06268857472709247, 0.02186206242601786, 0.03394742589443922, 0.05325254784630878, 0.04642310306163771, 0.02808319208478289, 0.018008716337914978, 0.03662886397380914, 0.05309102937046971, 0.002893125102023727, 0.00865497624701155, 0.05741776219968285, 0.04109303067837443, 0.02610259416646191, 0.046262076523687155, 0.03991985380915659, 0.03426681232771703, 0.026006447450656976, 0.022537116560020616, 0.01930475215028439, 0.02271941856348089, 0.04858218113492642, 0.06920155417174101, 0.013509520263011967, 0.021394310918237482, 0.013818257937340863, 0.03633148582386119, 0.010496605104500694, 0.021840130477877598, 0.02255334542132914, 0.010497614425340933, 0.016421114028032337, 0.061195370209004195, 0.03855192721156137, 0.04874787599380527, 0.018072072848943726, 0.03115248926249998, 0.026923792869118706, 0.1512554572629077, 0.07971681135573558, 0.12293269990810327, 0.1045840544892209, 0.13534709518509253, 0.17540512925812177, 0.13507006290767873, 0.11209027349416699, 0.1169989247407232, 0.1881047399448497, 0.06053620736513819, 0.10784028297556297, 0.16729385379169667, 0.12663949600287847, 0.09951774563108172, 0.10584661816912037, 0.09873268739985568, 0.052238399229411564, 0.13187678211501666, 0.12666328544063227, 0.09637680024440799, 0.14049053990415164, 0.15955254275883946, 0.07277144225580351, 0.17232401030404226, 0.17400600362036908, 0.11148485740912811, 0.15391846293849604, 0.10431886943323271, 0.10120706034025975, 0.14585378925715173, 0.08129945357463189, 0.09281510886337076, 0.11288886171366487, 0.04566606493400676, 0.14067986474505492, 0.12645245103963784, 0.11274480872920581, 0.10542621822761637, 0.11816410507474627, 0.2551660250340189, 0.14185504668525287, 0.10713599755295686, 0.08689254987984896, 0.12938863491373404, 0.07093486509152822, 0.13182140008679458, 0.17398783245256969, 0.16837614428784164, 0.09123307732599122, 0.09511152242443391, 0.2547498387949807, 0.1280382280903203, 0.10926862633121864, 0.11460851372352668, 0.1621924103902919, 0.052419347555509636, 0.08961696297462497, 0.0846618999327932, 0.0962663008166211, 0.10284798871725798, 0.14580128421740873, 0.10518189133810145, 0.12817099025206907, 0.190538332930633, 0.21005783123629435, 0.22338272551340715, 0.07315880432724953, 0.11356082851333277, 0.10233689578516142, 0.07937339121209723, 0.15583531079547747, 0.17136120982468128, 0.16078914568892547, 0.07487001536147934, 0.08008771216762917, 0.11934540740081243, 0.13181594466524466, 0.13086268438824586, 0.10247021434562546, 0.10255311096885375, 0.14744864510638372, 0.17954953972782406, 0.15492804162204266, 0.1363926769367286, 0.1241002551146916, 0.16365625469812325, 0.10891278221138886, 0.15230572090617248, 0.12409842307014124, 0.11947799314345632, 0.13532010306205067, 0.17792220919259957, 0.11620396668357508, 0.250467658575092, 0.12253824036036219, 0.1484836959945304, 0.09956538557474102, 0.12298561206885747, 0.2847111496542181, 0.11595578571515423, 0.14944610292358057, 0.09564146505934851, 0.15397550059216364, 0.10396194644272327, 0.11289800158036606, 0.15523654435362133, 0.12684942116694792, 0.12624549785895006, 0.17555036289351328, 0.10857570637017488, 0.17700602406901972, 0.09870716091245413, 0.17024117921079907, 0.16583085086728844, 0.1043327319036637, 0.11328969949058124, 0.08960871877414839, 0.1187528699104275, 0.0957930362118142, 0.10137638196881328, 0.20503243803977966, 0.08033703307488135, 0.14520326416407311, 0.09845154998557908, 0.1237039499516998, 0.09591076882289988, 0.21068566611834935, 0.12841659278741904, 0.2252086903899908, 0.1902958516563688, 0.1603077793759959, 0.20680577574031694, 0.08032432411398206, 0.1170648919152362, 0.12382154007043157, 0.16626448902700627, 0.12788259929844312, 0.1409942435898951, 0.12899155622082098, 0.12188794596918992, 0.08348736938621316, 0.13265750450747354, 0.1551587435283831, 0.1636017140533243, 0.12815437971481256, 0.09076893901718514, 0.10728079692593642, 0.08844373521528073, 0.09568572589861495, 0.12260674525584493, 0.10013249835797719, 0.14126177637704782, 0.15441200216966017, 0.09310391372335808, 0.07496068799602133, 0.08133422849433762, 0.2243158333003521, 0.0644820174202323, 0.15326085393982275, 0.1717502682336739, 0.06556644530168601, 0.19677743528570446, 0.154358764312097, 0.11822229623794556, 0.16981222294270992, 0.12898687432919229, 0.12324136548808642, 0.09501339269003697, 0.10591560482446637, 0.12709457586918557, 0.18455796954887255, 0.17739174408572062, 0.087733532967312, 0.0950722216761538, 0.21900138418589318], [0.06686599592545203, 0.009730361801173006, 0.03533091808536223, 0.037014712912163565, 0.035465631035289595, 0.01411056743069951, 0.04934923104675753, 0.026345017765249525, 0.08679514617792197, 0.04274159596700754, 0.055012162176093886, 0.03842317858444793, 0.03333120753190347, 0.09282310879124062, 0.013532495458743401, 0.04022203598703657, 0.035096043188657076, 0.023388888354280164, 0.025286799995228648, 0.014232501021719404, 0.07013256528547832, 0.03632154528583799, 0.037032599095255136, 0.07114791151668344, 0.0771968544327787, 0.005541243083176336, 0.059226566925644875, 0.031927576421626976, 0.07001237637762513, 0.01580171672893422, 0.06762616549219404, 0.06064856597887618, 0.03150397379483495, 0.04175606795719691, 0.037983012917850695, 0.04726251194785748, 0.033559629560581276, 0.06953784291233335, 0.02817211070630167, 0.058400104487580914, 0.050937423682106395, 0.05450839402952364, 0.057046271062323024, 0.03340744772659881, 0.026225658366456628, 0.12088546476193837, 0.015763082641309926, 0.01032837082831455, 0.042254404430942874, 0.04087911233572023, 0.07319790151502405, 0.008620957045682838, 0.018886538787877986, 0.04706598785040634, 0.07876688268567834, 0.04269466848511781, 0.03527981082775763, 0.08141590375453234, 0.04681478061580232, 0.019115685152688196, 0.094826225590493, 0.026929119369015098, 0.024403869872912765, 0.041455015540122986, 0.013871402496338954, 0.10288653629166739, 0.039123613320823224, 0.05076208684061255, 0.02027098262416465, 0.030227367832724537, 0.032375399355909655, 0.02067214440155242, 0.013673943716899624, 0.05630239312137876, 0.008558368975562709, 0.027561609001298035, 0.06929238965468747, 0.08283666108867951, 0.0028809663906161275, 0.025857851674248065, 0.06315224484673568, 0.017559980774032216, 0.025537684925698807, 0.021358655599345053, 0.03247812955773302, 0.10895117372274399, 0.008544045949487813, 0.028038447789315666, 0.03716484217771462, 0.07405018899589777, 0.04720040903027568, 0.03138014115393162, 0.04221431318936603, 0.051069344460432015, 0.04830680787563324, 0.005419927807192185, 0.02718612129267837, 0.006217578376111175, 0.049615562826927216, 0.04371175515864577, 0.040524530291025124, 0.016581338198323334, 0.09934779975031104, 0.06283036818993942, 0.022000325810430304, 0.03732609941757151, 0.03646102833694645, 0.020952893354530846, 0.0974559084113155, 0.047771928898457966, 0.016748627614496008, 0.017596204366002764, 0.027288081357255578, 0.06282644625753164, 0.03794429570968662, 0.06681657822004386, 0.06178882372166429, 0.0737919792799013, 0.037665960645037036, 0.004521274332156671, 0.017886101667370116, 0.05698907734560115, 0.02311046508007816, 0.030840393687997545, 0.005945531210662531, 0.06587041541934013, 0.042234689595976045, 0.1005492749224816, 0.009603419773546713, 0.02337648643047682, 0.070658253505826, 0.023427831175337945, 0.08949351031333208, 0.025650370932583298, 0.010258828622422047, 0.07541597142283406, 0.05726001637854746, 0.053568887657352855, 0.02169367208677743, 0.04345200516815696, 0.05463055068893092, 0.010183083758290325, 0.04235742301014917, 0.04359191230365208, 0.04781043576076627, 0.055183929923389635, 0.03557929243626339, 0.05772626493126154, 0.008902080889259065, 0.032908408969108544, 0.01801840921065637, 0.054664833670748134, 0.023371417773887515, 0.05747794147048678, 0.05181569905419435, 0.09663126444710152, 0.004746633199309664, 0.06405877441700016, 0.03157771698066166, 0.01152236430373575, 0.023196862944002663, 0.023893662429015552, 0.011963341667849039, 0.040124472829380205, 0.065754413072552, 0.026275868261499063, 0.015505407271640641, 0.04091004335454532, 0.06570520571299962, 0.010698058758862317, 0.04090290516614914, 0.028373839167345847, 0.024510986803631698, 0.041194380061434846, 0.030255832376756837, 0.023376177697043334, 0.03815690787242992, 0.00674135482404381, 0.05554677313193679, 0.03008022072858044, 0.0230115194073213, 0.01238618603175772, 0.061282249832791943, 0.0659747469638075, 0.020052116064886962, 0.028566609269806316, 0.13829982174294336, 0.006324794966660972, 0.005027156115310001, 0.043450084914054186, 0.0102112726474713, 0.11664859711059503, 0.035296886161501916, 0.011542771244421601, 0.036380204638200145, 0.009033374870861215, 0.03294851378138576, 0.025956144257049476, 0.05520973461014884, 0.03645001571359379, 0.018156107714665786, 0.05708338014249291, 0.02504758756341679, 0.05272864078038505, 0.02036726165429822, 0.028061312723106573, 0.03013575542718172, 0.08054758927651814, 0.030064044453735863, 0.059321806100862365, 0.0408746611459979, 0.018653996355299438, 0.058922101477427144, 0.008256247017665632, 0.0112079303279253, 0.0228947723683502, 0.06485258574996676, 0.04032879668687071, 0.011051960572201227, 0.04884260626775878, 0.045789395458996296, 0.025530736727107848, 0.08524147740432195, 0.028700552082487514, 0.060005586195204935, 0.04359874854396496, 0.06304833399397985, 0.013761390765596713, 0.03963983937033585, 0.03449401638603636, 0.005199071868056697, 0.021489689193133796, 0.01631172400500093, 0.011156225959504289, 0.04024626307987741, 0.02086205787158438, 0.090891407802701, 0.033117435074278286, 0.01300340608161475, 0.03836483475086944, 0.003255798464774021, 0.08885575524930443, 0.014626448275521398, 0.05571306510163205, 0.013813789784243065, 0.03829413479460137, 0.02551314570674939, 0.04120282782241702, 0.03512935247272253, 0.032221826525138955, 0.019674893002957106, 0.00894468355857368, 0.043018645207796774, 0.07090134546160698, 0.014365102031401225, 0.02097247587516904, 0.037740026134997606, 0.017703170322680047, 0.04424277666424002, 0.0632028364177261, 0.08813789912632533, 0.02329814277722367, 0.046969415353877206, 0.006999050549763654, 0.012700537735197161, 0.03270514701892223, 0.025340176952470626, 0.006285462836136243, 0.03788247438413756, 0.03319289834637727, 0.08638732627566371, 0.06271707998322588, 0.028017379276986634, 0.007269977708347142, 0.028794505433844667, 0.0300549385137856, 0.025909366052863852, 0.060483641257243495, 0.032369183975138834, 0.025033967669254968, 0.02960792642885021, 0.043375500344804356, 0.03365498408675194, 0.02147868844414396, 0.05666807599897895, 0.028383011264460425, 0.04816764712865863, 0.015046665012570364, 0.026095252417560135, 0.0609015781166298, 0.027276566617989113, 0.041179957799613476, 0.03681926429271698, 0.046192692925355265, 0.04497256821819714, 0.09832070807793311, 0.015554146442030157, 0.04015802977872746, 0.036898164344685416, 0.027314610380147184, 0.043825243533189805, 0.035221643413283994, 0.023997374810278416, 0.028000407419832687, 0.014394657320476003, 0.04500554162742836, 0.08671625291130372, 0.04898084081443293, 0.027155760243268948, 0.04502239304461649, 0.04444362302975995, 0.08418744110635348, 0.01982642344332167, 0.030969827635479823, 0.010805801638135952, 0.07453996235770838, 0.0217558140201228, 0.02017082746273705, 0.016735155301700746, 0.09030003739254815, 0.03114386847508805, 0.02569026709534228, 0.030648520948099237, 0.06713887556855168, 0.05335757828184536, 0.029866678972861598, 0.014846688868211848, 0.002924920616871012, 0.02223718711840255, 0.029389645106026104, 0.021788292098790407, 0.05039673983784659, 0.016185502920831953, 0.03179546565349613, 0.03692444061328258, 0.007230545493907162, 0.02732002000058336, 0.046966436585145335, 0.015574807833348001, 0.011232215944411499, 0.05107741902715393, 0.07915267734123127, 0.02959706647587674, 0.005659998161718249, 0.017740689916536212, 0.011327760460387384, 0.017372026573866606, 0.02309822430834174, 0.038218281364866664, 0.03652509900608233, 0.03810095587479217, 0.046704549209347794, 0.13677855980183395, 0.07437060680240393, 0.14038808111633572, 0.05317976139485836, 0.09357121400535107, 0.14591343248529093, 0.13923024253121444, 0.10397198197564908, 0.14559232257306576, 0.14249656083328383, 0.20159864372440747, 0.1371021938643285, 0.16870473165597233, 0.10560759742345129, 0.09538042585232429, 0.18559827229806355, 0.09912359820944922, 0.10732796189508267, 0.11101005931517907, 0.11528376463268485, 0.14470251889101096, 0.07880845652627093, 0.09849551226943731, 0.14932457730174065, 0.12732712339077676, 0.15174003983182566, 0.1322650941354888, 0.10853960830718279, 0.1475929016513484, 0.09109129064849444, 0.12579718977212906, 0.12682861728327616, 0.09067039537642683, 0.19187838530966214, 0.13594335104737962, 0.08745863128985677, 0.17219488508999348, 0.10648543174777712, 0.04568142018147877, 0.111631013852145, 0.18213285825082234, 0.21526640174644335, 0.1310959104448557, 0.09307607343154294, 0.1544295083731413, 0.22078274217035088, 0.1630754830049617, 0.1329904209290232, 0.28035017794796396, 0.21488008461892605, 0.17446849308907986, 0.061162318768245835, 0.19186743375446114, 0.18271908536553383, 0.15727502639804566, 0.17811194115451404, 0.12982376585049288, 0.18911902766142571, 0.1367192558412041, 0.10972169773387057, 0.28463903495243614, 0.16374123442385877, 0.17221338195460184, 0.1058211527498705, 0.12578931876591273, 0.17661574429699353, 0.10266652131187064, 0.18867171023573193, 0.12317995806889874, 0.14143374429217406, 0.08462306737367596, 0.1737969605518239, 0.1236194044883762, 0.1272523488317217, 0.16769783997109958, 0.06680066657385655, 0.1366858719182866, 0.276646190988166, 0.10029369792235748, 0.09015921423477785, 0.13780975661107472, 0.12814863930855477, 0.08470137031482798, 0.15262947710497038, 0.13917629899723188, 0.21306011799190724, 0.09920211828180722, 0.10969862754323653, 0.13571768387087754, 0.18022138439118862, 0.16825742780097894, 0.15025790221989155, 0.12867962010204792, 0.12468353738742215, 0.20214742927678994, 0.16147587741059916, 0.13362019642123155, 0.13207806274294853, 0.07004452536680869, 0.08835120339478765, 0.10488748177886009, 0.10524121565478188, 0.23388811679823057, 0.13589280018849031, 0.09681967326572963, 0.09962276928126812, 0.15498581209353038, 0.13370502686926297, 0.18680434115231037, 0.15289664348321302, 0.16490228926496847, 0.06715754885226488, 0.08720698300749063, 0.12480522585766655, 0.13391910466764653, 0.11944653625999178, 0.20447295877550328, 0.12337030071233, 0.14147155226341315, 0.11238859820046596, 0.0952966267775212, 0.1948709147317069, 0.09029940635498081, 0.16645082831382751, 0.20043211989104748, 0.17911222390830517, 0.0964882971186723, 0.13128771872392722, 0.10222553461790085, 0.18109661314104283, 0.1546249400292124, 0.16804602343056882, 0.1912582314440182, 0.13927293595458778, 0.11119267344474792, 0.2091011240014008, 0.11888196798307554, 0.13925548403390817, 0.06657639717949287, 0.11331901220338685, 0.12719109069023812, 0.156882073198046, 0.1527860015630722, 0.11688936847661223, 0.12297308631241322, 0.1263796170907361, 0.14573771905686173, 0.11547463653343064, 0.08345427723335368, 0.07860335574618407, 0.06646549063069479, 0.08153326317135777, 0.13681667989918164, 0.08615175927323954, 0.11450776484395776, 0.1728802461709295, 0.16580600291490555, 0.13719448819756508, 0.09694497832762343, 0.06911625553454671, 0.08343926125339099, 0.09262127176459346, 0.09856199513056449, 0.10793568499918495, 0.15955231205693313, 0.16734867942120346, 0.10280498316777603, 0.16586092353931495, 0.2034203338303736, 0.11902988861714091, 0.15220410350177968, 0.10410871356725693, 0.10248627526951687, 0.08439425858003752, 0.14710545566465172, 0.06872537186635391], [0.0217253155673721, 0.05033502707790051, 0.041262382841003795, 0.10159805257405553, 0.08585397060960531, 0.08351495862007141, 0.012275625535819148, 0.01325200604540961, 0.04725349761013474, 0.024567661441064308, 0.01717655929470701, 0.01780334414382066, 0.047463592407958846, 0.03334591477843268, 0.04345806448587349, 0.059082778569843085, 0.017366087696115886, 0.02564886288850435, 0.01446000363544694, 0.015157608880794473, 0.026580489772771086, 0.035741421593619246, 0.012441980270003634, 0.023371813020535877, 0.01000278682581016, 0.011444818777298289, 0.01879030216618308, 0.009803402703255415, 0.029036827252379487, 0.0210495065631611, 0.04752751040671553, 0.03837550810671278, 0.023376805341935585, 0.02437092360508229, 0.032350894063711166, 0.041567947515951734, 0.04072060655536396, 0.007152315495269639, 0.07280512473412923, 0.023770313244313, 0.05169653134154422, 0.032887164037674665, 0.020025020465254784, 0.022097631124779582, 0.024774097238800356, 0.03086685316104974, 0.038071069799895794, 0.0347640902868339, 0.0470385987843786, 0.05405561100425465, 0.02279272409422057, 0.023564893552767377, 0.03925640262397272, 0.015556239722562688, 0.01918240380473435, 0.010008518750380193, 0.016148521065978066, 0.06551047294799771, 0.024112104903906584, 0.016333494801074266, 0.03992695128545165, 0.08890674037060567, 0.022646177493567978, 0.06305855273136071, 0.05294986355251499, 0.03605604810374124, 0.039840227724718194, 0.03122681598844273, 0.049348454124161174, 0.015906645384218012, 0.06042189457054649, 0.10845122233565364, 0.03246006356286151, 0.014065622967401785, 0.03992397251671978, 0.04883307285074677, 0.04023367964795657, 0.06232109373169286, 0.0140774634034772, 0.04138165233390672, 0.07757380777703864, 0.08776579052209854, 0.08387359830417804, 0.04549773735925555, 0.022943455559600676, 0.002191989142115095, 0.036344920817230425, 0.027630307279261093, 0.04064238843108926, 0.03141847498981016, 0.07701379925544773, 0.08993923318173204, 0.029596944339573383, 0.03799797461501189, 0.04778273456862994, 0.031667951960116625, 0.05838310718536377, 0.024095969341163124, 0.0359680115777467, 0.044829692491995435, 0.04685547236087067, 0.028813704582197324, 0.054037680716386864, 0.010588746767358055, 0.0339934712808047, 0.018838067638820837, 0.04807174977447305, 0.06475451029837132, 0.005466698377858847, 0.015816008372764503, 0.04714474541002086, 0.006469664737648729, 0.07564860036862747, 0.0225038157576429, 0.05620193261919277, 0.019175367396590964, 0.014511704611192857, 0.07657134692583766, 0.07773249676184994, 0.014700106644470776, 0.10796877715204443, 0.0347853250402425, 0.035797723036791594, 0.037718713350061855, 0.032368722571326156, 0.02929303189739585, 0.025316887934293066, 0.05767983277993543, 0.024815230031630824, 0.026646674078490053, 0.03314553660207561, 0.05901573931000062, 0.08940890378185681, 0.03865798902032631, 0.01692252087273768, 0.01415691730965461, 0.015697827928566506, 0.005312039466973926, 0.0668059184349009, 0.02419523392537875, 0.026980387778686624, 0.013341730427263039, 0.08231090501482997, 0.035602213349193335, 0.09311717908297266, 0.03295382331790669, 0.04284050601667591, 0.0522437053732574, 0.03250041264774544, 0.030416604464075396, 0.02133932413666376, 0.034577995272619386, 0.02925670313249741, 0.04164991454620447, 0.021563792002520392, 0.025587969459593296, 0.06052267737686634, 0.014672990688788039, 0.009250685040439879, 0.03516304173639842, 0.03436741532225694, 0.035145901941827366, 0.05890256645424025, 0.022201078877385174, 0.027575941357229437, 0.047845376921551566, 0.02688041582171406, 0.05328614890043225, 0.004816529091580638, 0.04191167978569865, 0.0517371043429843, 0.04656599575121488, 0.10030030685343913, 0.004854542319662869, 0.049669869377144744, 0.018402555026113987, 0.04167794143514974, 0.010281374644754189, 0.016004106761621575, 0.08826971133904797, 0.03350805411381381, 0.03878915323210614, 0.03761360827567322, 0.01180815477190273, 0.04654835384073002, 0.03611875831016472, 0.027930011107985462, 0.025798888677465062, 0.017503414702202593, 0.029183336533606052, 0.05789374094456434, 0.017586267220654657, 0.03620752426130431, 0.05674193114308374, 0.012156412870224034, 0.015146813388647777, 0.013005478157927948, 0.04981962205576045, 0.01840622759690242, 0.05778615243200745, 0.039119464079184194, 0.10601539696965899, 0.05419693288526364, 0.04648315341078809, 0.05371903727895447, 0.05613144300878048, 0.04953094272475157, 0.01837624652710344, 0.015669393918610046, 0.033596535080245564, 0.013405641640669532, 0.05455006625769394, 0.016588311841977493, 0.043269872798451355, 0.06848814245313406, 0.10732320536460195, 0.011749971242222403, 0.04304899607918092, 0.03760021060173001, 0.039098846792642555, 0.025277619416426336, 0.031383574541125975, 0.028569065566573824, 0.03295114988993321, 0.0326114786522729, 0.06798395700752735, 0.037741447665861676, 0.04334437933617404, 0.041379552268024, 0.0327023989520967, 0.008911529489393746, 0.08916936734957354, 0.022859078033694198, 0.016366544545495083, 0.025244549315954958, 0.0076862131411741886, 0.06082693247922829, 0.051609346376998086, 0.01444274340091007, 0.03176153890256371, 0.06090509971337659, 0.04808210421885763, 0.04059195631582822, 0.010714979725889862, 0.024116425475637828, 0.011796260053025824, 0.033448726404458284, 0.025684470709945475, 0.02179897902533412, 0.008728766930289567, 0.043883505942566056, 0.031710282367255004, 0.07993270762796913, 0.02512948165115501, 0.0334506771926369, 0.009647337952628732, 0.07091163205248968, 0.04856086495731558, 0.04547745934022324, 0.053289639963103194, 0.07210608438721725, 0.008008032122493854, 0.04736030920009528, 0.050762901082634926, 0.01780908285374088, 0.03447383336190667, 0.06955815825079169, 0.0757181705640895, 0.06616017701370375, 0.06831512959407908, 0.1153121952499662, 0.06927705476326601, 0.0553491667711309, 0.0404824712978942, 0.012954375989335989, 0.049631745887121985, 0.03386765731764691, 0.060220634298665185, 0.014580273967502373, 0.0503158041808222, 0.040130722136901956, 0.07170932460576296, 0.08972583391836711, 0.05316111185987081, 0.009587759185316307, 0.0279830555830683, 0.03100745240226388, 0.028050753021878854, 0.018830547774476663, 0.07679396069475583, 0.030932179119970118, 0.08412162999489478, 0.01955694834967809, 0.09824146875845534, 0.02584669316586639, 0.03394887795937913, 0.05656224489212036, 0.005266661165348653, 0.035784165907119, 0.06031176155166967, 0.011042259217772101, 0.016914346222100512, 0.03194457372384412, 0.030869628369276012, 0.04616110033488699, 0.019137839321047068, 0.04195635453132646, 0.053455463743635585, 0.048496882497732124, 0.030602882682744945, 0.02428809822803097, 0.004275617938089583, 0.018146579386666417, 0.012111615988292863, 0.00639242200746334, 0.0381125859650118, 0.045304622900273116, 0.04543451825156808, 0.0356799463209297, 0.04113751882687211, 0.04007391518514071, 0.0781514649944646, 0.048126572011304755, 0.025039657185386335, 0.062187829454030306, 0.043165483578507385, 0.038915252179971764, 0.05515551287680864, 0.06075863792960133, 0.023886561560045396, 0.06360568265829768, 0.058249150801982195, 0.04787742752315743, 0.0799166059919766, 0.033711865677365234, 0.062198550307324955, 0.05555414880758949, 0.03288239732916866, 0.064292400809271, 0.021489930073065416, 0.05429753927247865, 0.034031411566372426, 0.06297758993293558, 0.07367336457329136, 0.045799851683633666, 0.04077687746446047, 0.02049253448577864, 0.024868623952248266, 0.14794162793883256, 0.036296188432191095, 0.04864197024809463, 0.0052652133412526125, 0.1212117722524064, 0.1684821043163538, 0.12733004109135695, 0.2108570369226592, 0.14733452908694744, 0.12600989692977496, 0.08456265740096569, 0.09962188040039369, 0.15202765725553036, 0.08037175371178559, 0.12540305592119694, 0.07063089497387409, 0.09112877292292458, 0.13096021701182636, 0.11298289988189936, 0.11578768544963428, 0.1525050202118499, 0.08125596626528672, 0.1600495289478983, 0.13693102662052425, 0.11045059362160307, 0.09973927374397006, 0.09264892206660338, 0.13508697200034345, 0.17995687787021908, 0.1433185517255749, 0.17724380988095487, 0.1391590777784586, 0.07230326666363648, 0.11699830048850604, 0.12194501076425825, 0.1493885495832988, 0.055196632098938735, 0.07570221820580107, 0.05413862297843609, 0.11372759206486599, 0.08293753888990198, 0.10249409877828189, 0.24150127970746585, 0.10990378260612488, 0.10139423422515392, 0.1361839867063931, 0.09482453603829656, 0.12019877375236579, 0.10846604154046093, 0.08086276200733014, 0.1296855482671942, 0.10632642385150705, 0.10912669037601777, 0.05721004227442401, 0.11703650201005594, 0.08566239981779031, 0.11841215033616338, 0.09953644605619566, 0.09303431638649531, 0.22018497996032238, 0.1025681948023183, 0.14156050820435795, 0.11261226369866303, 0.0625074737306152, 0.13807662443390914, 0.15518589849982942, 0.10381361190229654, 0.12258514070085116, 0.11881624508116927, 0.1470916678330728, 0.1138969747615712, 0.14237118113253797, 0.12691280990839005, 0.07644468479390655, 0.12811547251684324, 0.17436384941850389, 0.12322356072919709, 0.11765700871390955, 0.10084547581417219, 0.07813843033675637, 0.18015249951609544, 0.23615922778844833, 0.08643600437790155, 0.18714991903730802, 0.24687907685126576, 0.17291403721485818, 0.12559170222708158, 0.14299250207841396, 0.21164731308817863, 0.09613281262240239, 0.16881051526537963, 0.21707282481448992, 0.15103745753211634, 0.09633350971021823, 0.19897162754620823, 0.2499549575150013, 0.09293351322412491, 0.13430128273155006, 0.17174360501979077, 0.13913775820817265, 0.16038344960127557, 0.15147497691214085, 0.10758208683026688, 0.11584095044859818, 0.15499056183866092, 0.159901391182627, 0.1421946534620864, 0.09381111006119422, 0.20916946604847908, 0.13151648002011435, 0.19406192457037313, 0.16549105410064968, 0.06340103649667331, 0.08293190704924719, 0.10928792386714901, 0.1533982708517994, 0.1295202299952507, 0.1966808254697493, 0.12362116867942469, 0.11947929593069212, 0.21319155022501945, 0.18470183254352637, 0.11143434047698975, 0.07543887197971344, 0.20721513591706753, 0.08166681243372814, 0.09992300067096949, 0.21159910996045384, 0.10836367774754763, 0.16046473809650966, 0.16470548696815968, 0.13663464252437862, 0.17996161404464925, 0.20122245033936842, 0.09444976079144649, 0.18141218620751584, 0.1558866894670895, 0.16942068109554903, 0.123750239610672, 0.10602187019373689, 0.049328552692064216, 0.16055195698780672, 0.16961274721792766, 0.07436912759606328, 0.1227637989712613, 0.1711583821369069, 0.23328609338828496, 0.08687363910887923, 0.10479231724249465, 0.18056164256164006, 0.11800680708672319, 0.1430715921201876, 0.19042390478508814, 0.1370108766215188, 0.10213088576814958, 0.12969873898795672, 0.16275385740612233, 0.12244324545775141, 0.11779058511768069, 0.14162030071020126, 0.11597249124731336, 0.1611816103437117, 0.13838225017700875, 0.12085829621979169, 0.15200397638337954, 0.1135630269667932, 0.10021103878638574, 0.14895651276622499, 0.1284353882074356, 0.14354675662304672, 0.19123056078595774, 0.25557716297251837, 0.1324359763945852, 0.13509214243718556, 0.12421992155058043, 0.11778951303235122, 0.25465288971151623, 0.06259009215448584, 0.17412035034171172, 0.06813445607466356], [0.020895334925236445, 0.020655145402997732, 0.017327575744794946, 0.012909037127558674, 0.031253051544938765, 0.0748213440445917, 0.07904606591910124, 0.0077461752807721496, 0.031020066368260553, 0.032367409606065066, 0.019738064613193274, 0.04376895905339292, 0.02607052999415568, 0.04072149882891348, 0.05233220669573971, 0.03341135269563113, 0.05681602716712015, 0.017395787173882127, 0.05357403095279421, 0.015404441260865756, 0.06110672639416797, 0.057403791163648875, 0.01871424517594278, 0.03706521627360156, 0.02604710017996175, 0.05061216792091727, 0.03391707502305508, 0.06760711901422058, 0.0842532997152635, 0.02518722498124199, 0.03738584103328841, 0.034307253014828475, 0.03551916405558586, 0.03661531362948673, 0.036118225660175085, 0.010757693505313779, 0.05987518533532109, 0.041264530404337814, 0.08887904257114444, 0.012112412418771003, 0.002879602535228644, 0.03005924042580383, 0.04275293428716915, 0.07131966230060373, 0.02755590930714139, 0.10245922886367355, 0.032913314777293375, 0.015193818902064646, 0.031536570617130825, 0.06097205076366663, 0.039196671186281104, 0.035202915846769295, 0.021093697852588127, 0.046599321998655796, 0.036559517694903274, 0.061260563853595934, 0.0436212691212339, 0.05151299101167491, 0.034452666461999924, 0.11354000427361045, 0.035941250156611204, 0.05248722819877522, 0.014202558967683996, 0.016438089277861372, 0.047948473532285006, 0.018322969653776715, 0.021397120053214685, 0.011232717212156525, 0.026474377073879753, 0.006265826032696558, 0.025306611521435634, 0.014394253592139908, 0.03524626066376056, 0.031703476661017964, 0.046073168981820345, 0.03557457322520869, 0.0332910823635757, 0.04632539401895233, 0.06173388274120433, 0.035791127676410336, 0.027160978177562356, 0.038189640401729515, 0.0034635090601763553, 0.03234266682661005, 0.03595867832856519, 0.016139727252136384, 0.036139908246695995, 0.07205483463725873, 0.05972550729555743, 0.04545650617884738, 0.025002403916524987, 0.0688540017498391, 0.05560531374067068, 0.030056166662169353, 0.03184639309932079, 0.013456541945093443, 0.06315299802060638, 0.05508104365851198, 0.016740366450643966, 0.03331389471090265, 0.04641893007127302, 0.006315504125918129, 0.0387251639871725, 0.021310289623215795, 0.04974125126110656, 0.039028021307396035, 0.04385438661224075, 0.030319974292069674, 0.059716421711657725, 0.05870984215289354, 0.037391801963427236, 0.05569168446319444, 0.07122326283050434, 0.054389518086931536, 0.06565759969609124, 0.030151297271783863, 0.014240041242114134, 0.04094103883419718, 0.01560841397648411, 0.031645950462136946, 0.03889395635841148, 0.010176594419005727, 0.029346982216728584, 0.04381176782771945, 0.054468910076788495, 0.032490509429148266, 0.05779574691717114, 0.05355890301455345, 0.007013368910910296, 0.030740048536764722, 0.007976051918896181, 0.029995434385325228, 0.07660408624048744, 0.016046365922583, 0.01620353838162763, 0.006434665053218071, 0.038504188880324364, 0.06353074525083814, 0.027672216994687915, 0.048821703996509314, 0.031321183246161254, 0.06352424488535949, 0.04076827364042401, 0.04734009564188974, 0.05045097514188715, 0.008883848653307982, 0.06342591837580715, 0.009688997458267425, 0.004837207446273948, 0.025103268147047077, 0.03364338113793305, 0.05106905608304909, 0.018846104886116724, 0.02929143055475184, 0.0195672858306872, 0.007742210091756923, 0.025255740054750016, 0.08207264422838177, 0.04268346926463502, 0.03483273767467056, 0.009191383624316325, 0.02241560281254351, 0.03288496558421424, 0.03708834753238729, 0.017715509481994168, 0.062080899120441506, 0.033372252115181515, 0.022756127307989767, 0.029129376036248038, 0.023509630268173556, 0.0238714980826314, 0.0496646209087755, 0.04349824054432767, 0.10120645644409315, 0.010641355283691414, 0.0416952813975513, 0.07031598687171936, 0.038964730953531604, 0.03874661247911198, 0.029474913209144558, 0.014941454765253832, 0.0649126021723662, 0.02305684215389192, 0.025157710404268334, 0.014055266826679664, 0.02163856316890035, 0.04656233505478927, 0.03267837202708636, 0.04731620442388313, 0.05691009247675538, 0.06431245830442224, 0.04102869198790618, 0.048538045824638436, 0.04354504928258913, 0.01716946860376213, 0.032140653380858045, 0.0244667310533779, 0.004574759006832859, 0.02530173964000174, 0.07927912234195642, 0.040398885961622, 0.052685533450650315, 0.03842313447967172, 0.018382380483672023, 0.03760938439518213, 0.037937856412359645, 0.04632628629250186, 0.018400879044617926, 0.017247808864340186, 0.02474388716343258, 0.052227610522615056, 0.03441282967105508, 0.053411983219640594, 0.04627855474661503, 0.040023469499179294, 0.0228374649970127, 0.035967926760869365, 0.022081251289429407, 0.04407776712573, 0.0391601252901767, 0.020369860443419645, 0.04259722407108971, 0.03239121600719435, 0.019362320757604072, 0.03620167528944356, 0.06201288277017219, 0.09299371963632957, 0.007358434077884469, 0.008504892782574254, 0.04199440338249717, 0.01565368413659079, 0.08477286754974298, 0.0230320264319224, 0.07454387750476599, 0.014240958960726857, 0.09306654679988112, 0.03648082798879061, 0.06520580393927437, 0.05107065064034291, 0.04559439806533711, 0.05171651080516832, 0.03653644750426922, 0.04281379887834191, 0.028334060051877583, 0.0327012420498899, 0.041953698066728454, 0.061155262004051886, 0.059428051114082336, 0.038276214684758864, 0.009785333315708807, 0.03143119412873473, 0.03814877223755632, 0.05960371704506023, 0.06762444879859686, 0.024928723495187502, 0.04786078305914998, 0.061094092072120736, 0.04747400113514491, 0.021772848641765968, 0.033887229660259824, 0.026276017539203167, 0.04643739979448063, 0.02034686828431274, 0.014023770927451551, 0.013511550779055272, 0.04515187109687498, 0.07059422694146633, 0.020218759176454375, 0.020799116963254552, 0.03318064061126538, 0.040146304693605216, 0.03350247655596052, 0.07282366909618888, 0.039622265313352854, 0.015157313718061362, 0.030523718002119234, 0.023474605986848474, 0.024794049561023712, 0.021438692197469727, 0.01710740470194391, 0.039233861690653224, 0.015999038105032275, 0.05368297992806349, 0.06272459136588232, 0.02855166114334549, 0.055297635429139645, 0.04800853405946067, 0.026246116197268878, 0.016992845938407948, 0.0344769783717181, 0.018006665465821112, 0.02474660978519491, 0.01585609113265361, 0.039589739737233946, 0.029425787273794413, 0.058227709095392904, 0.02043905235560877, 0.024323582216831188, 0.011223544266873171, 0.12433179840445518, 0.041322056603218825, 0.05677434815359967, 0.026931205864197443, 0.0286596940963396, 0.027902851047526513, 0.0064017798535392755, 0.04475385941831129, 0.014985844526173813, 0.04927307227626443, 0.06224227510392666, 0.011156548263638147, 0.05977955939514296, 0.03892166433589799, 0.03067601179437978, 0.028942439638610398, 0.023235486853601675, 0.03186100535094738, 0.006066334192707602, 0.02485845610499382, 0.045973102029945166, 0.028630255854555538, 0.0553652819778238, 0.02295629513849105, 0.011257817070665104, 0.007200840078959507, 0.052320566427494795, 0.010909321485087276, 0.061596275839422426, 0.05689415708184242, 0.010365150819000388, 0.012904370502967919, 0.025750558324424282, 0.057332836756748815, 0.09195613781256334, 0.02518601549257125, 0.06284545202340398, 0.009791628424344319, 0.026096587435209324, 0.013975491464537169, 0.02105340813951833, 0.023441688556756293, 0.08428060396441392, 0.03885568019800952, 0.026113978287737285, 0.04576215906334775, 0.03848294734156557, 0.04932902766657727, 0.007112656819767186, 0.058531523149992735, 0.05128956978608455, 0.05199740055416312, 0.023202174176861132, 0.1275586395391396, 0.07979076488741807, 0.0697226147832615, 0.12246480930064406, 0.10702319110610656, 0.15137196172560963, 0.12751674678708824, 0.10240796554301466, 0.09502456816179411, 0.13174748048186302, 0.1320736658360277, 0.15965341377471173, 0.1212949063628912, 0.1138589768005269, 0.08153233357838222, 0.10385858520333256, 0.16723692470363208, 0.07273086586168834, 0.10616058989294938, 0.10949020194155829, 0.14907227084040642, 0.12307694288236753, 0.09261411322014672, 0.21161000723285334, 0.13513134819056305, 0.1733252022947584, 0.15341456926294736, 0.07390452788344451, 0.17185706964560918, 0.1926745240177427, 0.13102334790996142, 0.10266680629657847, 0.08479074694748436, 0.17233892450375216, 0.10651950099106346, 0.10214161340679441, 0.1394359336367675, 0.11338538649891104, 0.16940295776086195, 0.11398807487317494, 0.22414746162082466, 0.11056254511432988, 0.10355923590915543, 0.21044112209762844, 0.08139766473323107, 0.2405684840466295, 0.1551122231675046, 0.14921769446560315, 0.16901498500789913, 0.18754193585898193, 0.11923971878630774, 0.10129453028951373, 0.04782871210149356, 0.1530908809176513, 0.10482199636421033, 0.2474981179194791, 0.1150541076702731, 0.16001579218677112, 0.18108530874763215, 0.19621361339730875, 0.13668980742139475, 0.2095244484288352, 0.1859686981354441, 0.1330329922160932, 0.10783100740185805, 0.12197163647839002, 0.10368910751172475, 0.19742416058267864, 0.16157277221126215, 0.0863623833283782, 0.14193398744932242, 0.18410066408770426, 0.12585253108825, 0.1272078776465995, 0.10954723280987569, 0.11966571664171559, 0.12040656831647668, 0.2117650524846145, 0.12913343789322035, 0.10383839200117759, 0.112687581085733, 0.13439517840743065, 0.0764958124075617, 0.17135500801461084, 0.1051169555368168, 0.15244583838752337, 0.12258290153528963, 0.1617624634610755, 0.2184472382068634, 0.24784495787961142, 0.23247993950332912, 0.13067056398306573, 0.18477101597402776, 0.1373016560184104, 0.15062161056058748, 0.12142848276666232, 0.1337669635457652, 0.1595662220248154, 0.09040090162307024, 0.10839038488588162, 0.15343313398105757, 0.09539662248321942, 0.15347490459680557, 0.1570075207522937, 0.19455981999635696, 0.19081527021314415, 0.0935103969116296, 0.12503811264676706, 0.0861568550712296, 0.2196835968643427, 0.14522713502602919, 0.13457777218094893, 0.15653429685958795, 0.15042582606630667, 0.16436778008937836, 0.08003461680241994, 0.07461369875818491, 0.1621822595064129, 0.10638806197260108, 0.19401586561330728, 0.11974005693835871, 0.115385395607778, 0.11058255511202983, 0.19888453079121454, 0.10758140829524823, 0.19314526447228023, 0.06293392620448555, 0.09537473972886801, 0.12434387632778712, 0.11875046789646149, 0.1168620235153607, 0.09260616757507835, 0.22639470174908638, 0.11952394353491919, 0.08068615291267633, 0.09859788963305098, 0.0699208148622087, 0.21020564330475672, 0.118977424289499, 0.15513397700020246, 0.13301680237054825, 0.13009657764009067, 0.1015262296423316, 0.1409601675612586, 0.11268393056733267, 0.16701216676405498, 0.1261626487331731, 0.10845863193805728, 0.10534626644636903, 0.11990168397980076, 0.12168160347001893, 0.1459074749478272, 0.1647015650357519, 0.12783819596682275, 0.12300026842526027, 0.09746485828821148, 0.1538290320230382, 0.16401358480964387, 0.1534484281603779, 0.2733613486800875, 0.10341422619032008, 0.10886975630585637, 0.09214952029287815, 0.14532371770058358, 0.11189769847052437, 0.13265417968588217, 0.10470009754811015, 0.1609400518770729, 0.11617584819240229, 0.09566002977745873, 0.0840866786560842, 0.07823433447629213, 0.13487909601203033, 0.18516570622367517, 0.1090868671557733, 0.14622293944869721], [0.044084718716996055, 0.014324242348915764, 0.016972084463174855, 0.04152607511995094, 0.015429446972640497, 0.03251079762620585, 0.040895675375525437, 0.030053123432610716, 0.026590772970978702, 0.024016616367069737, 0.061477654347462315, 0.034205001180193255, 0.046146878240896125, 0.03119217338306563, 0.04256948895220246, 0.11566450420234885, 0.016344242795769657, 0.03092600784397551, 0.023655922418194156, 0.020305525145626495, 0.01366473684486534, 0.03221940415512238, 0.026131381014628068, 0.03259632357263139, 0.0559924213614847, 0.052661265645708354, 0.016356066268469607, 0.059997694832938056, 0.010987590499488371, 0.06525349816573517, 0.06224536922361169, 0.010260227252729237, 0.027040494106976048, 0.04489665711298585, 0.04484425046082054, 0.018521668455962623, 0.020834568721641387, 0.013671729996401285, 0.0475033274186509, 0.008735495453168238, 0.017119596279891472, 0.04690409618030701, 0.03003577668485897, 0.046577914218817434, 0.031280630600771735, 0.07678269022809607, 0.020172060700133443, 0.03806962791298117, 0.03469411297036069, 0.04823183993409787, 0.007174529883611415, 0.04905317943277104, 0.025154751991587024, 0.02365789525876088, 0.043222918175160885, 0.06902074494532176, 0.045739723302956135, 0.03996320201882294, 0.04060197488537856, 0.07424273687813963, 0.06876979555402483, 0.049410845419125896, 0.0744502464575427, 0.07263390999287367, 0.054135556000151804, 0.040240142694009204, 0.054546619299799204, 0.1288486567458936, 0.031573686482650895, 0.021694031710337316, 0.04690059833228588, 0.03130039293318987, 0.019691184628754854, 0.08025615848600864, 0.02401512528636626, 0.03947779502985733, 0.03667895342888577, 0.014946555652256523, 0.07661775193576302, 0.010646861595367747, 0.027286983826862912, 0.01408680428617767, 0.04498213556196008, 0.040580567105540206, 0.04481840845463531, 0.07447866350412369, 0.059621501447899, 0.04546987671138985, 0.02879726028602038, 0.12113619702202932, 0.0604855954380972, 0.05482001123683793, 0.07205039701823678, 0.04312051027747137, 0.04955754129748259, 0.046770811546593904, 0.010249409708194435, 0.014996592520869203, 0.03897606248834303, 0.05231386589418564, 0.01942350765291069, 0.03503360778891614, 0.02669841067732445, 0.023969729597281133, 0.035427745032523356, 0.01005003830817129, 0.054478036372789314, 0.041823158107165775, 0.06671857740730047, 0.03779282294479864, 0.017528118465894034, 0.0808843190648726, 0.05032372607716492, 0.04660608699279172, 0.0619102611339518, 0.027720847599474446, 0.017645355746416107, 0.031932723109743426, 0.013504124213276165, 0.015992183205006377, 0.039515450330717225, 0.054563026276550124, 0.04264204130907144, 0.03049041550340397, 0.029519920436931506, 0.025352773955091834, 0.01716506151881601, 0.041472487816853185, 0.04745701740362814, 0.028483756751354252, 0.044793923518487384, 0.011036905576474965, 0.049076612639640055, 0.06769135235143559, 0.034925313599939854, 0.09959030138062579, 0.060634798503347805, 0.07347960211336613, 0.05401621865374701, 0.03681372066161462, 0.023775200392784815, 0.04010364519698279, 0.03527000599673816, 0.04873975392963205, 0.09936974357281413, 0.0605841458642057, 0.05115661424185548, 0.021933932855193104, 0.024639228225818703, 0.028422888767506396, 0.019482317979314497, 0.03438351356557437, 0.011170839059299656, 0.044136524865669866, 0.04369656954492841, 0.05392888441149678, 0.015577684821827071, 0.017056255035900643, 0.04490906073312674, 0.03348650723429663, 0.022678389247240763, 0.07515046067003693, 0.03145706666899579, 0.033513529891414304, 0.04054742745522942, 0.03158902476674744, 0.0547991937824658, 0.010049693951649325, 0.10730194686246769, 0.03468390780368021, 0.04381988310654249, 0.04281594304900084, 0.03894648514688015, 0.025272075785323977, 0.01751820506927158, 0.039217773625361066, 0.010867263340125126, 0.0026375444971823265, 0.015636374708265066, 0.0460936743100839, 0.024255774516080107, 0.009562588928799545, 0.00373616478671985, 0.03515167288216097, 0.049385793906237395, 0.01866638131572732, 0.015304552424432976, 0.006996641750447452, 0.017565934918820858, 0.006709082002219344, 0.02276539270366941, 0.058984472416341305, 0.06340694653668574, 0.02197867545432278, 0.08492312912962266, 0.0035868747841699845, 0.037076761546943865, 0.0074196006171405315, 0.015615355389724885, 0.014087180873113019, 0.09146153328141995, 0.023903857417670742, 0.025381404740203704, 0.0011783204827224836, 0.03746926012848105, 0.02556563717579203, 0.03298619283097131, 0.05778340436518192, 0.01689267042092979, 0.037469585825289996, 0.07345883894179549, 0.03447151955749307, 0.01982934114390186, 0.04180505479286824, 0.05203154782897659, 0.02493056741410068, 0.05823204493416207, 0.03943180053361824, 0.00945117771958134, 0.023751850306455578, 0.04841033196342843, 0.007799988196763609, 0.01902608460347567, 0.03062107420659491, 0.028849473555705378, 0.0035433603334240615, 0.004769497709016183, 0.02382941364443728, 0.08428386771785361, 0.04842722748539277, 0.03963344078511, 0.029082516407860175, 0.063774305395782, 0.02245388406195811, 0.06612861834998641, 0.07977355045399495, 0.04744184536061116, 0.017286397150850723, 0.0192762587685138, 0.08935899074588503, 0.06505978320326124, 0.09756051815514054, 0.051205411087721586, 0.02385767632430153, 0.040378241533679624, 0.06922901448394571, 0.032653276409421644, 0.06352226356310503, 0.016333635597090636, 0.007797921209463051, 0.02849287286932979, 0.02774675067381135, 0.04698029566290123, 0.010941610422118433, 0.07836761911000524, 0.03410589435536947, 0.01540788312974785, 0.047416624213968, 0.0415608364689563, 0.07781703543982335, 0.05577852337488106, 0.04030265273260219, 0.01653365754256291, 0.014935368306136556, 0.023002902012584463, 0.08846200137798275, 0.11122597594346319, 0.07001910065965992, 0.038905786616461616, 0.053128043455736976, 0.017762185905926993, 0.019418807101569006, 0.04711343780426042, 0.033794480708560774, 0.029274518069412028, 0.029427565035543272, 0.020436499367601106, 0.09013218818498508, 0.027420005528256297, 0.019281719279076372, 0.03486893751791545, 0.008897021562526268, 0.016281764987590056, 0.04432521188365562, 0.05229097890800663, 0.02518977627291211, 0.026330975483038595, 0.01648324747968997, 0.06518442330083676, 0.06250179439250912, 0.011215998109297028, 0.05270129921180861, 0.011186827888845332, 0.08526530076882669, 0.07410904512341533, 0.01545969267109675, 0.016829743083300333, 0.04775820213503071, 0.026420737184318047, 0.021790473588875363, 0.025919125082769563, 0.035695712082087994, 0.02157213628691222, 0.041469980629959276, 0.04872671248657363, 0.009186219124655639, 0.03564104590831058, 0.04695103723289711, 0.01981201984121331, 0.1140991917678288, 0.08643814854856048, 0.030005866861236945, 0.020803032110312154, 0.07827286848000117, 0.006489978379769517, 0.035818713517593484, 0.05492683979017394, 0.03950991348496505, 0.015888053524707044, 0.03431894417319979, 0.05070461153185793, 0.03807431319728494, 0.02572051279379853, 0.03767279349267483, 0.0824327834748796, 0.026990470809063742, 0.01896684680001012, 0.030819097866437266, 0.029520941632134572, 0.02981688468051808, 0.049064100453896184, 0.009856823765273606, 0.017952028129781996, 0.017894732632807324, 0.019639785601092235, 0.04234959610870906, 0.06828291953674384, 0.028723374607839754, 0.06957546089376722, 0.057190866874797006, 0.052240706248474975, 0.055609795464468856, 0.05947347903358085, 0.028141469761197056, 0.023407739753435765, 0.027263190996434008, 0.04481747546898467, 0.028149591825370277, 0.08425900619477034, 0.014818597518439804, 0.09052534494549036, 0.018302796807672297, 0.12955096763159546, 0.10543905611016921, 0.11732665715473038, 0.15361499493675573, 0.08065450603940658, 0.14385002106428146, 0.10018311028501817, 0.10638552425163132, 0.1569354467626129, 0.1337648058044059, 0.14464320135968073, 0.08616461751184293, 0.07977084309927054, 0.12937776478273527, 0.11100570990570954, 0.17047053761780262, 0.19063897324459894, 0.10362029727548361, 0.1460642572492361, 0.09792130879525628, 0.12998926054154122, 0.09613251406699419, 0.11376237376992192, 0.11936105441834245, 0.15560683448399815, 0.17697272157030447, 0.11368833881403718, 0.0962922072836331, 0.13579087065798895, 0.1512903475335666, 0.12941323859351023, 0.13025886964585098, 0.11745168401726655, 0.12078114678817135, 0.18341804428824357, 0.1809495881732021, 0.07620436804635183, 0.10091146334473576, 0.09115741388606173, 0.08483493993324892, 0.0985611876738923, 0.15346194457794937, 0.14533386858446257, 0.09063380198287112, 0.12595990246960095, 0.11889870065663542, 0.10897632701588528, 0.12403531931340694, 0.12470943028373377, 0.11240009936903204, 0.07544951140880585, 0.163433274520295, 0.1674167364835739, 0.11512021055178982, 0.12490210708762918, 0.1768306770495006, 0.11845138323094163, 0.12916933239570685, 0.16662788524159364, 0.35025198704430033, 0.20189981827778475, 0.12476315668651036, 0.18612408265471458, 0.16559727197246893, 0.12506471121949808, 0.1773302009595292, 0.18868677371314593, 0.22665889614394732, 0.19504103703158243, 0.14086192926125868, 0.13342183349387987, 0.23796820214816503, 0.14161314895110472, 0.1667206274079425, 0.10798061080276966, 0.1206926658217396, 0.09170159218566758, 0.0779310700350574, 0.1800658098821129, 0.1185128992157323, 0.1301472099231822, 0.1131043644355876, 0.19059143508119242, 0.1792836489954165, 0.17877595552376338, 0.14040869501020226, 0.09949048887938261, 0.08828515479607241, 0.21880663106484072, 0.25377779666866573, 0.22670116887560912, 0.21344336814114026, 0.28829918855002945, 0.12443292726363454, 0.18260319158434868, 0.0870931858995131, 0.08830462196575743, 0.1092923954129219, 0.15050855305578026, 0.19061001337000302, 0.12235621655625956, 0.2019813239042248, 0.08260342146136931, 0.09186442701944283, 0.09668636827596597, 0.0999424203432032, 0.13005628623068333, 0.19787217011409147, 0.12238527142575809, 0.1682764674936022, 0.1020533088594675, 0.1426494890557868, 0.13264278029756887, 0.16758585455162184, 0.1623186043330601, 0.186531325802207, 0.18830281788749353, 0.11299195832439832, 0.16065600354756626, 0.10001907444425992, 0.12277147998767239, 0.1142396620873894, 0.08594810377274241, 0.06505057548305818, 0.1566834252859865, 0.128321842157415, 0.10197663440236024, 0.13517366163432598, 0.0938285823379244, 0.07155582641384431, 0.11311718196208988, 0.09554497737969671, 0.21553959351565155, 0.195167353110654, 0.12956140350018228, 0.17271594570151397, 0.09606269959892545, 0.21585051183189663, 0.2194126306899956, 0.14022068652723516, 0.15629583251263413, 0.1726476036544357, 0.09846541245601007, 0.08346770544137273, 0.15711714486990655, 0.15397391282022, 0.08510832169226237, 0.08692240542066948, 0.15337285293000086, 0.08525759261101484, 0.13043405381696566, 0.11176649693931852, 0.10073195012020213, 0.1412272932274001, 0.09359541734946625, 0.12781322587813648, 0.11336403978722435, 0.13816217412906034, 0.11710848100483418, 0.1697398368269205, 0.15424624963530473, 0.13332439586520195, 0.15033951641193458, 0.125646297154682, 0.17111205176583358, 0.09546156506985426, 0.10465344148022787, 0.1682082475828273, 0.1367136782833508, 0.12271654579256262, 0.20083835880671227, 0.09407318064144679, 0.28358738709773335, 0.08776302209922246, 0.3102629599826676, 0.16286139163587773], [0.03156329471884029, 0.022566968708166053, 0.02203030518389174, 0.01840461777257068, 0.07116944821817534, 0.038589066825807095, 0.0626628582498857, 0.027078188423599516, 0.0267171365475016, 0.019168017166001455, 0.029413027422768728, 0.018061436812526414, 0.045770535578152964, 0.013699468507963632, 0.020797787034618, 0.06087284215859004, 0.021058787225878665, 0.04267024800979665, 0.04361670597323349, 0.08768830860831908, 0.024290205079263875, 0.04658403799736074, 0.042056292561548095, 0.06275553934808288, 0.04284619553280728, 0.03106322119544659, 0.024209573066660335, 0.027847209479659796, 0.055994100735655854, 0.014277801715901919, 0.0305828251875937, 0.01376722616675709, 0.039729857218584845, 0.032533216423221996, 0.02216803591831454, 0.05099791847169399, 0.05394123035616108, 0.061145382534180365, 0.01066160446498543, 0.02639763815594571, 0.045746104924806526, 0.015496645688212343, 0.02362617035396397, 0.02303963280948145, 0.05026582329134856, 0.12654887086578778, 0.030846235874508108, 0.03024610218458942, 0.0162452462328864, 0.06264812046928064, 0.057466691359877586, 0.01978634068343256, 0.016766681735004698, 0.017751863691955805, 0.019112251765493835, 0.03679161399070706, 0.03320193982550076, 0.00450977443584374, 0.07992430057908807, 0.02205938210577837, 0.03838458011991211, 0.047040407080203295, 0.061673818821353574, 0.05231754694666181, 0.051646177257810316, 0.10771488291876656, 0.045055756611483436, 0.025625911441498568, 0.03049814740994147, 0.017439328766028796, 0.07018044950174433, 0.06790637331349508, 0.11977217878614153, 0.014752062070848686, 0.029883974830486944, 0.02794558348666344, 0.005005398465852652, 0.055174182767846754, 0.033770046662539244, 0.06691601752702679, 0.051641485188156366, 0.05979361864072936, 0.010349823561097895, 0.030112715770623515, 0.0710374867277486, 0.054544956889003515, 0.04222405355955873, 0.07210693255599056, 0.014840208858783756, 0.04376542049327067, 0.05600490640582783, 0.055810987882848294, 0.06998077700180666, 0.04888520808890462, 0.08789381650941712, 0.03441210363858512, 0.041256398162139316, 0.018966458338711942, 0.017352888493665626, 0.07548529056033917, 0.05944472950484071, 0.04142261888565762, 0.03643727282594357, 0.029451418934123855, 0.05987780448049307, 0.05046373499291284, 0.021569948011477078, 0.029699528656367744, 0.034871085081249475, 0.03718463843688369, 0.02645171570059444, 0.06740642192640475, 0.018099529768473337, 0.05196312435769609, 0.05150376632809639, 0.01347428818033742, 0.019490981175165092, 0.003837742327180292, 0.04891362174281052, 0.05035415498007621, 0.018381379644519517, 0.08385411077844244, 0.03640572773292661, 0.04438051588035055, 0.025824557657220533, 0.02027884514869324, 0.038632370930697234, 0.04705590142735413, 0.14289471161152634, 0.06580082486782755, 0.04730563624096768, 0.049189385159739425, 0.07874138333967753, 0.015446866662906749, 0.021010485710576177, 0.006553581283826913, 0.016039897787517736, 0.055109901752855094, 0.03217297539647136, 0.02977021164926035, 0.036169390593256266, 0.039400859336767874, 0.021821178994806747, 0.003618910118737923, 0.01496448424378676, 0.035061828060341735, 0.019176312256604433, 0.026985785524759973, 0.05692376835005624, 0.030101078895053694, 0.04547086397984198, 0.0157726584667606, 0.010491111515355962, 0.0689843754683222, 0.007684581264454339, 0.00665260710853285, 0.052904669727597914, 0.04071942590443151, 0.036276792508683035, 0.03279273571180446, 0.05292491381987929, 0.04829062481543847, 0.06249681394547224, 0.02038492731350873, 0.046962901417698176, 0.013414231045836849, 0.06057208151157413, 0.03654301572324974, 0.05042231721537454, 0.03200747731274792, 0.01904175028071872, 0.09335709549486637, 0.11306559294462204, 0.024404141286920224, 0.015916277188807726, 0.04860103762309466, 0.039087342231401374, 0.02466277508730335, 0.03268027871048876, 0.08078424872032233, 0.05195759090461901, 0.02124719604450677, 0.06232891724045787, 0.05047155850167785, 0.035495445864009004, 0.050839880880500586, 0.0440170246708606, 0.04063760815188289, 0.020301845789487873, 0.0680845362533416, 0.013555442664905317, 0.018876623694917986, 0.03733023848118527, 0.037826712376305034, 0.02493990575229483, 0.079548616095313, 0.04906869413597243, 0.10048399306833744, 0.029735022823193243, 0.031052968531314815, 0.03891006477975419, 0.018692213143887262, 0.04164681364116924, 0.012727114255540073, 0.016904042667842338, 0.012311062875336834, 0.0315860799247665, 0.057215538408075056, 0.05816894796277795, 0.09527990088931151, 0.0036971333320252597, 0.04219019805480327, 0.0247231697929757, 0.03806919365056923, 0.03621866241363542, 0.026104534776615243, 0.02401676564477384, 0.056322847559515915, 0.0820365325946893, 0.049478044134697745, 0.03199308219232729, 0.01432536362803408, 0.05462518008425832, 0.04489623302859919, 0.018005488207563758, 0.06346706473933798, 0.025479503940524798, 0.0449836317316762, 0.0022927787337851313, 0.023076132904472094, 0.01835490151175431, 0.014277742344087787, 0.015560416105602468, 0.04782742627763322, 0.03322865374918495, 0.04517175895827157, 0.04487484560481139, 0.03074240983862962, 0.046812544842915874, 0.05173701274075678, 0.027558647195941637, 0.012313649790095431, 0.016710385380844985, 0.028269039433715597, 0.11729084407644612, 0.023619800606476407, 0.03000802460259625, 0.05512035458481737, 0.07842173906309263, 0.038966586746807606, 0.0824575839298112, 0.04540254907416446, 0.04679534398019314, 0.043387062581522126, 0.037119512645793815, 0.07845527226371424, 0.03560564673638769, 0.009109732112847269, 0.027917870420164297, 0.07458562097911324, 0.09889561722853354, 0.03331440361216664, 0.013570155848615935, 0.013769165080572878, 0.008073395400840257, 0.026330919503899555, 0.019508394080081155, 0.019819614344409535, 0.024123616250497953, 0.029246348688112836, 0.1048686456467424, 0.036071325319686105, 0.03391306488109486, 0.03815429211993303, 0.022512492524193864, 0.023603246048358933, 0.0900513068107622, 0.11824613995850086, 0.013401812158658035, 0.012545754567586949, 0.04301247053912707, 0.025000973903973187, 0.03028645126947335, 0.04480073261739952, 0.02569514067311372, 0.061508086643048694, 0.03303299478388258, 0.07449355056243283, 0.015720373950898647, 0.04071176863674607, 0.013716196092510862, 0.026037590511675392, 0.08193437914763178, 0.024917892379952327, 0.08667967308844839, 0.06666592308985335, 0.026008359223072017, 0.06158824198480163, 0.030227479791002612, 0.025811785931832025, 0.018378904688038995, 0.015771677983658652, 0.05726804344781807, 0.03304517788014241, 0.028086974917511855, 0.045936210080981255, 0.02559834426002843, 0.03476204450375267, 0.03919696634901421, 0.011729275075984853, 0.030398932019514695, 0.02261133980937302, 0.03134246549702116, 0.07609415360327278, 0.02528342937252351, 0.042820855642535856, 0.03558033059484192, 0.069734312726983, 0.03801317379942962, 0.060594785293298106, 0.024253581151632325, 0.020939945210037485, 0.03212902329063841, 0.020144778503371135, 0.014827920589596033, 0.018899878786344613, 0.04702113329299858, 0.04150555622098701, 0.04694008567769613, 0.06193652043917349, 0.011850246843615813, 0.05738397115575416, 0.017972592829859683, 0.03277407260611653, 0.027698035252147486, 0.027322958057214106, 0.04090965998225978, 0.054961160091417174, 0.07956740472997938, 0.04282587340899876, 0.06656056695750781, 0.04732198554224201, 0.03735250460782221, 0.02529134787619114, 0.011208693679821278, 0.04066417619053807, 0.017571003575410162, 0.10130789064403091, 0.019437207274937203, 0.007830865780955978, 0.026767069939523935, 0.031545886902936866, 0.10222531748669487, 0.12240869445460183, 0.12050946136670453, 0.1373693873839719, 0.12314422641481672, 0.0765429570206574, 0.18895180949143, 0.11589101276227406, 0.13939876348844596, 0.13367039444191114, 0.13723351753183774, 0.06729220412671566, 0.17066489718854427, 0.16475651280156203, 0.11426122593028204, 0.13627386545496328, 0.07531210806752954, 0.12624568784875528, 0.12509749803159917, 0.17957313917577267, 0.14253313387078898, 0.10409375187009573, 0.1432525845510619, 0.10237955528178386, 0.1379352177360228, 0.17482886303748402, 0.14438875072768756, 0.13420852699450084, 0.07087999874992029, 0.1443274247327021, 0.10861107161534683, 0.09128632875425474, 0.15037845075130463, 0.1271632029009717, 0.07096085298274245, 0.10667968953826598, 0.11312787567398377, 0.13249427612338746, 0.08781273836003882, 0.15427892788180284, 0.09651277866214514, 0.15052234088735922, 0.13754154528890336, 0.13287764840892383, 0.1525135561823845, 0.1886622921696731, 0.10383864305913448, 0.13926925829478673, 0.07374794914254121, 0.10834492303963218, 0.12423833699098655, 0.15315832729850495, 0.22350251408559935, 0.06401735663946186, 0.0834005983280284, 0.08131895467106785, 0.14322678664965288, 0.10873668880334922, 0.17661368155053683, 0.12886222744626658, 0.10565452490534101, 0.12902051609541687, 0.15969749140952313, 0.1066589467227459, 0.10947175257440124, 0.3778558229761464, 0.1722894050180912, 0.08960329727934939, 0.18981060412313255, 0.07274679107857601, 0.11670665256679058, 0.1527470943651029, 0.15288457913058145, 0.135498259216547, 0.14800960357700074, 0.10527512883501393, 0.10392107827855007, 0.15781013268445218, 0.2250761589301484, 0.15131904956485542, 0.2140678782016039, 0.10512562042900495, 0.10839736022587333, 0.11452018203479902, 0.26803636870213915, 0.18042554200759955, 0.10546318481543235, 0.12810169825596468, 0.10330317036381789, 0.15963389910757542, 0.17150035021560533, 0.20415718214852469, 0.14986470474728517, 0.1133187815014805, 0.2600402406283787, 0.09868065733462572, 0.16342374788863318, 0.07978333492896386, 0.07353571017405816, 0.12880110501178674, 0.1475503710763795, 0.14358871722859995, 0.09383254498243332, 0.1784212581281151, 0.11206590730164732, 0.13872193837804453, 0.07936534378677607, 0.13280450233391353, 0.09275568955178772, 0.15485368775469915, 0.14486889567758354, 0.29303967846291407, 0.21933085364954813, 0.10165733617863484, 0.11445592476853303, 0.08367209375969001, 0.23220619133540563, 0.08929150365293026, 0.22670061247689383, 0.146332305723003, 0.12448472662695817, 0.10917696982089962, 0.08768586588225194, 0.15440183771508081, 0.19180310863469327, 0.11937542579003743, 0.12218990762318883, 0.17071890857602867, 0.16198423584657057, 0.16557884296136244, 0.10999586659350566, 0.09012589138001204, 0.14502252957650594, 0.04516754525580576, 0.09861276312065975, 0.10334796724574906, 0.12612446078232356, 0.15672667510807514, 0.07336144881056887, 0.09722627859030451, 0.11992015370300838, 0.16649756580591202, 0.17477808147668839, 0.15302555156605585, 0.084648247808218, 0.18976976988571032, 0.10616303261901651, 0.10718016339732067, 0.11541261843272618, 0.13552540061729296, 0.1472659699086632, 0.10877466640834298, 0.13812976729656967, 0.13473087682255677, 0.1393227811370577, 0.15122055342154844, 0.16279551945626736, 0.10575715332691159, 0.11714489119393484, 0.1240619450275387, 0.10500507189759187, 0.20737558230757713, 0.15449588266866549, 0.08822124358266592, 0.15470377222767898, 0.11750196346214839, 0.10036157178027288, 0.11450562067329884, 0.06640948435025555, 0.09219731629959174, 0.07517717459372111, 0.23335448971816472, 0.14458890498748847, 0.09206996206194162, 0.08548591964479003, 0.08237045324806656], [0.038935116292642694, 0.031214446295052767, 0.05310191307216883, 0.03510007707934294, 0.025617017543741634, 0.03805601989318218, 0.026342670034085, 0.03820153172793133, 0.026290030983675803, 0.08370887035770075, 0.013935033814050257, 0.03658153276358332, 0.009918338053726723, 0.08504104494516339, 0.014822589000687003, 0.018046473419027667, 0.04444872222042509, 0.0821011969819665, 0.01214613815370415, 0.039346423864896805, 0.022849727821137224, 0.03477948285373194, 0.01728900781433497, 0.04089782972420965, 0.03026301466992923, 0.03643724907721792, 0.030647689742701392, 0.05579635527517114, 0.03345699774633561, 0.02471843022587044, 0.05377911816218069, 0.02784539948749755, 0.031747533939778805, 0.01856947294436395, 0.0673152811026999, 0.040296545917434354, 0.023323547128321867, 0.030256456628973995, 0.004395431107176202, 0.0432973602520568, 0.08934852095054728, 0.018145449625860368, 0.04366310080513358, 0.031587094334619384, 0.07789762504398823, 0.06255849277866737, 0.02803390839004091, 0.059943907362009795, 0.04846753246550049, 0.02461222592475159, 0.025638459250330925, 0.029749428121639148, 0.05802577028849295, 0.028420206857845187, 0.039047329021351676, 0.06331507968051092, 0.05476236968700375, 0.05617478782577174, 0.014394938912508743, 0.07907949055411986, 0.054886629804968834, 0.01995004404203168, 0.026764618731769066, 0.041544361638703516, 0.017506162769028118, 0.0639949921252472, 0.0698153365935598, 0.1090799393132329, 0.05313819773229105, 0.07541558465787343, 0.02322866757666426, 0.05428316790078368, 0.028672196104058197, 0.024261582775839736, 0.03686957087899957, 0.005903583751725299, 0.030247527108128582, 0.076284313042249, 0.05931419972330332, 0.08347700137112822, 0.15861677511462144, 0.04998152729656015, 0.0358114260514932, 0.048622767707066875, 0.05696002247610262, 0.033273396348314624, 0.060794356012982984, 0.05191318757299866, 0.03281918161415628, 0.10511665019605841, 0.10621410594987017, 0.061191577198249955, 0.07359731436840125, 0.1010761573644621, 0.05728310692523207, 0.03000412302623902, 0.03595260204747319, 0.023900323946561133, 0.023427374860537902, 0.04307111632078886, 0.033558163924940994, 0.028713440855166743, 0.03349790322993483, 0.06154093452330146, 0.06679765387837376, 0.049618629805211506, 0.09150589590093919, 0.03492629069036671, 0.02373622534131365, 0.0609905883403761, 0.09177996976567165, 0.06339536394391741, 0.0079319513835279, 0.02036150767734008, 0.038829176620181115, 0.04697063332423568, 0.09817012758659464, 0.006056630293772156, 0.05294668122327753, 0.08812510195587363, 0.05645208473184279, 0.019648019623543535, 0.03128684258886746, 0.04510611408789243, 0.018589337057034885, 0.009120912673617048, 0.04368348738976887, 0.04500345852492111, 0.046138237097433636, 0.04723347064905933, 0.05120468844792672, 0.03861442707212908, 0.007459524769469031, 0.05465104923184429, 0.021440676912399273, 0.005438315258028784, 0.03219468851706811, 0.03920555320967521, 0.03498592374048062, 0.012498821996684586, 0.03546667258654322, 0.03966945403122476, 0.05910374530191932, 0.03574653774765985, 0.03458512667566538, 0.05927255802920886, 0.016638326658202068, 0.08453416571553264, 0.05416197476110288, 0.018240195166851794, 0.027000675975744213, 0.06790513837976114, 0.008456574303896298, 0.03169700682961515, 0.03188413321705801, 0.06176117341965437, 0.05247570328148348, 0.03200939078150051, 0.015092354168051055, 0.04399818853874292, 0.06498471687414817, 0.009590825315431824, 0.034271952230483294, 0.051888142845460346, 0.027778948856783763, 0.05175714487476008, 0.09816108950014625, 0.07226431875356606, 0.030145628111703054, 0.012969011141519462, 0.016973631523017372, 0.030241209947104965, 0.08148113811122519, 0.02724885694416506, 0.05621468907754336, 0.019401908186929565, 0.07230711395719222, 0.045333341894937415, 0.018181632505729795, 0.021399539030556167, 0.042028079075472694, 0.02293657012549894, 0.021150167233177593, 0.04361782555601426, 0.05015070643275976, 0.06634261472416775, 0.01552030281163752, 0.025114548791732107, 0.02883049493123378, 0.06663119566759892, 0.031583732193601985, 0.042852634830134254, 0.08033383038959332, 0.01130308214175914, 0.02953426805990083, 0.035754398575850894, 0.0390565028148038, 0.06435823227678027, 0.004273075552191585, 0.025637285384748663, 0.0159188488365284, 0.059114323662860055, 0.03567343917010086, 0.028525527367102246, 0.015852474541004215, 0.05004345718771219, 0.031988990626164844, 0.016317427091832672, 0.02917958762762802, 0.034670951177499125, 0.02962034022701638, 0.10895380643861634, 0.024666747909837534, 0.046201914216258695, 0.026063780267057673, 0.05562334580879126, 0.058119652393673144, 0.02314503474294075, 0.018340034809495722, 0.03792742732912302, 0.030112563100244318, 0.03855284323383655, 0.04557072397853647, 0.02485239509093974, 0.09145371655800513, 0.01379487562059824, 0.0501864313014916, 0.028258098056539893, 0.03100705545927797, 0.01971649398495044, 0.09415949708116905, 0.060477636222328456, 0.0594566852918693, 0.09564880680825029, 0.0403624859505466, 0.09610200713255576, 0.011290258678075458, 0.08581053079771143, 0.026752028514498045, 0.03170636382752231, 0.050172860601118634, 0.05620976630598307, 0.03483283606224826, 0.017004681285470724, 0.06952268444001675, 0.13129522332123347, 0.025260922365954945, 0.1242739057966641, 0.023375980921887925, 0.01935585092620126, 0.025332777528092265, 0.015681492197992544, 0.10918328019657306, 0.04217214902330722, 0.06511079546596323, 0.08959619301770415, 0.08380224356161696, 0.06258083015148129, 0.05533416096919349, 0.027836285065859556, 0.07598733183528696, 0.07855190922107015, 0.02836050765056695, 0.10953531094959804, 0.0357389347627759, 0.009153404322985028, 0.03317180947799768, 0.04887892485463193, 0.13470007133271011, 0.03998286596366337, 0.11328235095632927, 0.01756388574306454, 0.03312851555113282, 0.028091376913445334, 0.04425150601725493, 0.020877635339275002, 0.05039006983861327, 0.056880298004086526, 0.033854548021086624, 0.020833294772143875, 0.09305414996509041, 0.009639527166395314, 0.10774720154170479, 0.030754406337759325, 0.05737547589732068, 0.057449497282505035, 0.010950248172905828, 0.040447384252079895, 0.016722232602270584, 0.06981400666492325, 0.14279567264020443, 0.02729658000836415, 0.051343564210193496, 0.019561419895450984, 0.04783390289438622, 0.03444970126396843, 0.030806202308407853, 0.07793438128594841, 0.015707802393340638, 0.016000970233497874, 0.03343188177262034, 0.04749495768919587, 0.04918168717995286, 0.01423516936068024, 0.03766414217118706, 0.03106774023867079, 0.06749220232346229, 0.04207802264552031, 0.03983135587934937, 0.023238270543515682, 0.03201067660536085, 0.03280027423586164, 0.05945220696074622, 0.03544435217710478, 0.02566963623810027, 0.04936920033235635, 0.04799470890845571, 0.02338494436948427, 0.014872837911493011, 0.05241194813113127, 0.041134326319609366, 0.020438322930463722, 0.036799071090562005, 0.014956837154126592, 0.03437652465488229, 0.08487096335738897, 0.06102064744170223, 0.03284646211458104, 0.01791539232778762, 0.044491795623408895, 0.010962494881823659, 0.05258756656465786, 0.011958547817942287, 0.08936956232147557, 0.057245000398584774, 0.04444608950455274, 0.026042036612385085, 0.01934886710452182, 0.05216540243210537, 0.05743914283812046, 0.03339123073965311, 0.03827905435381191, 0.02302663547119924, 0.02041078289039433, 0.02507712928179119, 0.02331102137187762, 0.00803896229315017, 0.0301776854986591, 0.03355347864063723, 0.056346233268933635, 0.051745660669569454, 0.023617534299514124, 0.10681348307324307, 0.12117131799459457, 0.0984971271827817, 0.15054334833153657, 0.08051610525165286, 0.15235429044280732, 0.09443904672350202, 0.11600812790649277, 0.1440128016152552, 0.1551436936216695, 0.07454922436071293, 0.10865244868078403, 0.1271455745611872, 0.1330231941704239, 0.09087569971701928, 0.1125897838334952, 0.1818910962236779, 0.14170533471873828, 0.10583704404000725, 0.13764370552131108, 0.12904122498418602, 0.11564246538494315, 0.14084662151123795, 0.10155731333153588, 0.12811250053346157, 0.10125448993806328, 0.08660086124603238, 0.10404200000422341, 0.1284004436539752, 0.129204996196287, 0.11505523403840405, 0.09007654152810574, 0.059548918556954177, 0.12389407546392509, 0.15919665114155837, 0.1554312567625727, 0.08368376456201077, 0.09168694261461496, 0.06553511733987502, 0.17696012796035834, 0.15043924748897552, 0.14776267111301422, 0.10514212240065847, 0.12350152938493661, 0.1889130108590637, 0.16498051078191825, 0.14607542593564304, 0.1374000571668148, 0.1614080781915358, 0.11091523404632296, 0.15678591121520313, 0.08590210588382823, 0.1451539753803185, 0.07506896861429725, 0.20421849457280977, 0.14661582479519503, 0.24636013326900347, 0.19972678273916245, 0.09411167393305472, 0.19910198769399098, 0.09045309453670468, 0.1320390605500766, 0.10407414220805679, 0.15351461246609688, 0.11392763097371374, 0.15713698523385183, 0.11654883889215333, 0.20544616798205034, 0.12410144933632442, 0.17652411492807524, 0.07312656034316335, 0.16483204731983797, 0.16407389300210135, 0.12188771526728358, 0.1281765406685216, 0.10262373967894486, 0.1687033881566354, 0.14002506488135882, 0.15321294936750615, 0.18996901490858623, 0.3497393402670111, 0.18212829849549703, 0.14651665011686937, 0.2177906334400177, 0.2471693812736443, 0.16561990790069103, 0.2192109836531537, 0.2553017863205501, 0.15350135389183248, 0.21934460076902593, 0.3325080791754382, 0.1406091885375125, 0.28470129732574734, 0.20503060599522932, 0.21356550444449696, 0.25905609343733105, 0.10404400168252842, 0.14191268144973687, 0.1416473335453442, 0.1325731218925544, 0.15646515414118767, 0.13815658300050668, 0.13173909378903254, 0.13693665846117906, 0.24348952301910945, 0.17646468883114202, 0.24601098628980772, 0.1349375993013382, 0.11310434407953705, 0.1525665633380413, 0.17559750750660896, 0.11144695444298641, 0.1664698544357504, 0.15120447214160646, 0.274685550481081, 0.06614555458405189, 0.10600196197628975, 0.09763312140213591, 0.2103863778923239, 0.21804954883243355, 0.09657080697693995, 0.1827831119298935, 0.11312001145311765, 0.12220716955406324, 0.2534765542617866, 0.09676088499171392, 0.18462684085326536, 0.1399551486330373, 0.12870114323283943, 0.12324357751224722, 0.17505166679620743, 0.15135962595897062, 0.18943981187684195, 0.13454723810510977, 0.06247455799686057, 0.09486646271709885, 0.15610958822071552, 0.1690219874892916, 0.08048929633306605, 0.13399595554385865, 0.16868905749704155, 0.09313315179731164, 0.12298178513135229, 0.1022295719012618, 0.14480543908263954, 0.11170006836099283, 0.1420718114823103, 0.22024061983185156, 0.14390551165810653, 0.21637824922800064, 0.16995297824697836, 0.18535212693469866, 0.07855758855917624, 0.09600830144648041, 0.1000153696430581, 0.15698174999228545, 0.13910638274891035, 0.12283010541328362, 0.12492406448083264, 0.08380708830165011, 0.16681742721370288, 0.05075581717704024, 0.11329252219625882, 0.15255490610642092, 0.11191267373838595, 0.09847354130553347, 0.17602047909583363, 0.14677491411566734, 0.07888622342475823, 0.13375735548990114, 0.11169400225792613, 0.1131193804155503, 0.1353988131242139, 0.10223969564374004, 0.10049864942474024, 0.09532482669289623], [0.046547291933425834, 0.0815397228247353, 0.04941822788012879, 0.038476389300610335, 0.01835003980834569, 0.03206355823203921, 0.08073194045573473, 0.0449242938442954, 0.08174967513020549, 0.024149359869105474, 0.09918052729751382, 0.081508747701134, 0.032003473956137896, 0.00983800205202507, 0.049025770010692735, 0.028319037286564708, 0.06063515812690769, 0.05400062252634338, 0.040300620520221334, 0.05748522215123687, 0.044261843498264036, 0.039724880164223056, 0.011898155656776257, 0.02240865970296519, 0.021318983353142227, 0.04490666211183582, 0.05977161375007459, 0.06189882103353739, 0.04989672398992947, 0.06933922214167458, 0.03593428160196968, 0.06062704284808465, 0.021221036823200326, 0.0050401861080899835, 0.03851643304473587, 0.039096020694289885, 0.05085790277059589, 0.09239981150520699, 0.026829508731939962, 0.05136392704610314, 0.057198385042803626, 0.02319204025635762, 0.03538878694442766, 0.040843777624624114, 0.020872632839850018, 0.024853769124352505, 0.03639997375596847, 0.022796970027099763, 0.06688076763280801, 0.041024888799126656, 0.04158534176115479, 0.033078110577272515, 0.007686761906370521, 0.03685722493433526, 0.047123632792915614, 0.0333579519896635, 0.04274682407932622, 0.06334553911749806, 0.03287117775263531, 0.078773783386818, 0.06851640343666077, 0.05047915470121162, 0.03307546429069979, 0.046228984370827675, 0.042136288447571654, 0.024824722736541713, 0.035557911797825775, 0.08377094274120671, 0.02854471294475453, 0.05544531857594848, 0.025906758782054697, 0.09134620268430028, 0.011480920232965477, 0.03396306612661906, 0.04319834502946053, 0.03577645435663206, 0.07644585865948882, 0.06598881978009428, 0.10946677212736436, 0.07875373267701694, 0.14740216545760632, 0.05235157547784703, 0.0293130385024207, 0.022088598127343824, 0.04583682505679982, 0.05654346982815436, 0.07526555377990007, 0.06862017858241286, 0.031563189545912404, 0.07323124472584043, 0.0367747727515442, 0.10017549033675875, 0.11817899213305541, 0.0739469498928104, 0.11006019849862371, 0.02890537805589182, 0.06205604438270841, 0.04612641701740878, 0.08065916757498469, 0.02161392047336059, 0.05938955782247441, 0.04576146017227854, 0.07225765553968293, 0.017396906756662896, 0.05169987991186125, 0.04275580109762294, 0.03421374749658363, 0.03351662740377443, 0.0499455547625465, 0.04740865821284907, 0.01512374319801373, 0.04752734077296086, 0.06767197339130299, 0.07156415203852312, 0.0339617938734591, 0.012156903111775006, 0.032940775089498074, 0.05177745682054332, 0.012605824424619121, 0.020789963525852988, 0.028036128895889436, 0.008228769742085465, 0.06762448951069798, 0.05551164876669645, 0.09215593244880438, 0.021106620552018285, 0.04978053504601121, 0.018812335894576142, 0.02013058355078101, 0.028706496049250876, 0.036014755855181387, 0.028280067324106182, 0.060450623743236065, 0.0543724665019129, 0.028064517104732137, 0.035574766607689004, 0.10080674503530775, 0.013919965247623622, 0.024874155708987798, 0.01774257454755051, 0.03248890808650425, 0.048704599030315876, 0.03696620783635548, 0.05294766170637948, 0.021076371460886936, 0.05506197343181286, 0.022796361041920524, 0.019444264039131146, 0.05947271228900977, 0.04336064721324614, 0.037511882305677445, 0.049588418033506186, 0.06197539371039186, 0.04369678328345929, 0.047834248947245736, 0.059543605627758164, 0.05709194325442825, 0.03361208371019789, 0.008701393131299742, 0.05791249565247979, 0.05481189935068999, 0.023188954618360316, 0.02306900659043874, 0.01325132411771587, 0.031856879858033996, 0.014446868893823453, 0.06489115368042674, 0.04534466325172356, 0.01859267714566418, 0.04215644093762551, 0.029601697477379015, 0.02805224579891988, 0.11474146587508065, 0.06740437275064842, 0.09696238953620195, 0.029693289526871273, 0.036022945772856474, 0.014747909436534559, 0.025758541288918683, 0.021174128001023616, 0.004125149405029203, 0.03327050578913518, 0.016303277940356305, 0.014876400220340915, 0.057890395766922405, 0.01968368172778615, 0.01723392603785864, 0.03249876380765012, 0.017424083780497313, 0.006927633042713361, 0.030153509295944656, 0.0590066130139998, 0.05932226071932486, 0.06509844612862382, 0.014980652036943605, 0.0342928341456822, 0.03663075030116098, 0.024409230299560086, 0.03213644985641752, 0.03397221617134554, 0.016418367657544355, 0.02553385289918099, 0.0599284435489348, 0.04013097658753395, 0.03568994114175439, 0.024825674381905367, 0.05489059244947774, 0.040204115877194066, 0.010933513803008412, 0.0410627205190914, 0.033331994632525105, 0.0427471362054348, 0.04729585176599877, 0.04991149230461035, 0.027558352033208524, 0.060213353617915084, 0.026040769448237758, 0.008605834196454712, 0.034140625170298984, 0.05126009422487446, 0.03396880653287683, 0.021156431807737266, 0.04060831579512783, 0.006748052388762257, 0.016050264106265137, 0.02746394575972642, 0.06124963265444551, 0.01427370506072683, 0.03835400193929672, 0.06999683114034788, 0.006507779321899372, 0.02241395227611065, 0.018517254585666314, 0.029159550488527333, 0.05405939383698361, 0.13611236054982456, 0.07148500092859779, 0.061096745144043646, 0.0409795321258051, 0.06975612762783255, 0.06225383055529424, 0.03268076725570219, 0.011029410309025219, 0.08706431423446961, 0.014082247923527445, 0.06833810478981052, 0.045466161732162745, 0.021055386069097688, 0.04562707631183522, 0.045589597430080175, 0.026980587946517125, 0.05297323229855724, 0.03380514049370374, 0.05906895681151322, 0.12044002009289605, 0.06014626007527113, 0.11105372982897929, 0.1181713111166443, 0.04037208043571029, 0.05140568748382585, 0.01688256873083966, 0.023147988066609417, 0.12922936917415687, 0.09486068838409015, 0.07748839378889118, 0.12040603905916214, 0.06578954761581761, 0.08573655690997839, 0.14470143323498114, 0.03625678590365818, 0.21180558816662856, 0.11738062783011369, 0.0712810740140932, 0.0326426064462534, 0.05210648523643613, 0.03899630658062441, 0.100221345733319, 0.018398017323176776, 0.05156212033970015, 0.06870971127812352, 0.10616483752216611, 0.04775171873292752, 0.04498401849663683, 0.0627905178282942, 0.045887698219822984, 0.048243673584823094, 0.019530239515006542, 0.0440454383247665, 0.06272404853786741, 0.05245555418410471, 0.04067248485184141, 0.05056743549981287, 0.013086242484860122, 0.021874230255239775, 0.021545274781861475, 0.0160970948969147, 0.02387594587967864, 0.03226495760359934, 0.079341581490423, 0.019558890656168972, 0.013980753503606787, 0.022940217251224176, 0.08046559510486466, 0.028512424855892147, 0.04513596623603787, 0.014320367913959282, 0.008240538083815148, 0.016523781465366483, 0.04070564146552767, 0.04607407821874533, 0.05727350565471819, 0.09386678385947432, 0.09496718445526701, 0.07756753811346632, 0.018553988775238395, 0.03288718778640032, 0.039741287140973976, 0.054185679381979365, 0.06534929373966795, 0.07168833751763616, 0.017725505999156406, 0.07908558379858732, 0.04008788282849959, 0.05099235109186598, 0.015823321283927987, 0.011173862780976509, 0.028152465421174253, 0.013401093759707041, 0.005641085694410971, 0.022926115597199117, 0.01034739610206868, 0.02257326720947666, 0.025566934874015193, 0.01776422999267067, 0.030776119458356073, 0.035147527033197026, 0.031190086887883287, 0.00924114229357136, 0.016650772686781626, 0.050300781415509324, 0.011206822619507355, 0.06059608129518373, 0.0049646783071304, 0.031807326445622106, 0.02841803215311042, 0.03378144605085254, 0.04794003255665302, 0.041064267578933916, 0.11290650362414972, 0.10375441650726966, 0.02135675909396793, 0.03924389722357903, 0.11366188273366008, 0.14737714108611855, 0.16647260928792612, 0.13139755997274602, 0.15572293182568892, 0.12095577456057072, 0.1652962059846946, 0.11307902793799128, 0.2975360314760889, 0.09509795172406094, 0.13359427638351917, 0.11276688825871263, 0.10779226983764342, 0.16673141611473902, 0.1964591345084565, 0.12434868035571915, 0.16709274958286965, 0.16292129270732403, 0.0955931805074215, 0.14393683283456735, 0.18823311877037796, 0.11958980214382921, 0.11084102945668356, 0.12163399745311056, 0.12595828755625657, 0.09431954992136785, 0.21552112379244395, 0.1761163832353694, 0.1337373794189521, 0.301413180572646, 0.10121719765343837, 0.16100947958018097, 0.08527018622096096, 0.08014074646468673, 0.10342755261808634, 0.0721240316384605, 0.1278214497225625, 0.17876513967556612, 0.08095397746988706, 0.1366086953452655, 0.10849589029593126, 0.11138809831546885, 0.1721808122737067, 0.11003642263157026, 0.12647100218704768, 0.1178562944488866, 0.09506465601069586, 0.1172231805643865, 0.1251215860247612, 0.10210347295339618, 0.10552569146135024, 0.1445432531514338, 0.11694080143102578, 0.21040277129837445, 0.12597305247826235, 0.08717606895204101, 0.14016086687999113, 0.14472709542938642, 0.11148751048105103, 0.24810565103377613, 0.20440619092966827, 0.1318244534943785, 0.14666216873696872, 0.22865617754203932, 0.17310519410031183, 0.17464392153280123, 0.14091937403593743, 0.15755416213401727, 0.10181939069713865, 0.17583247061286653, 0.11830473824271134, 0.26080877653190065, 0.11151665356010199, 0.15447395241686276, 0.1561310842101063, 0.18064814220581735, 0.12531309574842453, 0.19816555508545466, 0.2690055881227766, 0.1757804812597377, 0.2604169632707323, 0.19312374134148869, 0.19899567482726915, 0.10872372878449303, 0.15809570093240055, 0.10948264984680073, 0.2660608547074454, 0.17763125337660313, 0.1597060409507581, 0.2283109932073525, 0.2161639000156096, 0.21512055742953504, 0.4750118596213204, 0.19442484581044742, 0.3283350073865482, 0.18444055584924562, 0.22112661014710153, 0.07235619918044124, 0.19111930818430015, 0.19117682081248077, 0.24181845411658287, 0.16873218518282684, 0.2466012846146311, 0.17548576635973795, 0.21568067451672895, 0.16516391879745893, 0.09895756747573614, 0.16965594275721482, 0.14635194252644265, 0.1198799301471029, 0.09412996723715748, 0.2186160305781024, 0.1940460739923375, 0.15178071122084344, 0.199882642232946, 0.13251149734216078, 0.1927695189203535, 0.11809945425816945, 0.14773616753518581, 0.07886531097548348, 0.08347187843173742, 0.0664707085649882, 0.13378375050212654, 0.13897786821637834, 0.3270929083228111, 0.09708691428282432, 0.10608718597463199, 0.13565145885305746, 0.11713217544768538, 0.09059140032955579, 0.10588213947734662, 0.09241758912269558, 0.11098057018326861, 0.1835400720259973, 0.14729635470679828, 0.29478668900472776, 0.19588647809411797, 0.1464653800108603, 0.08062558687691178, 0.08122593430536133, 0.1650869186435427, 0.14241033260311398, 0.1393647146012102, 0.18898809754422732, 0.11354343766080481, 0.13794173167220183, 0.16054924284773214, 0.11023129788892609, 0.18171887046524457, 0.07114499381610326, 0.1089729546968426, 0.0916449073702097, 0.11451725076351847, 0.10328597628644534, 0.13967895773904665, 0.1354076476501567, 0.1313506324908563, 0.09435079645897661, 0.13244751148990222, 0.16097967832216195, 0.14452116005122662, 0.10839028310562883, 0.07021454588643142, 0.13978558273187705, 0.09017095967595067, 0.1728197479886668, 0.13293311186134815, 0.10742829008294003, 0.10171558840998582, 0.20509161986410618, 0.11735564417072705, 0.1014713565153735, 0.21508675281490597, 0.2784782626799175, 0.28596375244004385, 0.11229897729520287], [0.038683427298175435, 0.032859903893300464, 0.012437051561261927, 0.07319174041705472, 0.05964774039707013, 0.03790557850152254, 0.009128182328173091, 0.04154766610424433, 0.012553471207086529, 0.049104045810444016, 0.06774046471608536, 0.032864673994481564, 0.035735073898519785, 0.0673549889719912, 0.026744457760027478, 0.03206852510837572, 0.012141426576168408, 0.04445904613073383, 0.03165451357407229, 0.049687233088271957, 0.01650646864436567, 0.052484968677163124, 0.0010189259275128798, 0.04781788268259593, 0.043677882690514834, 0.03550849069974252, 0.020222082301708202, 0.059599815468702994, 0.03108332279537405, 0.01807603210077754, 0.02696157030628196, 0.022555565927177668, 0.01033390173688531, 0.07446942185716969, 0.007309818740135857, 0.06068129850817578, 0.014628034351127488, 0.08977548232568161, 0.03922095934727362, 0.024922433475564634, 0.01122971045385514, 0.08011238370090723, 0.04065907360719783, 0.040697129243718724, 0.00922438332677952, 0.012100789113901556, 0.0023114038839204504, 0.034878508254353485, 0.0442872173152864, 0.03662123045484934, 0.010502357385121286, 0.028350687552509562, 0.011318277085332997, 0.05405340915811913, 0.05762567211474691, 0.019624705160302774, 0.0009214987949235365, 0.039696649714772186, 0.060278682969510555, 0.08820998668670654, 0.012278935090372605, 0.06413213762321643, 0.03720398007759026, 0.030940324932868992, 0.09070107872997012, 0.07312499292727027, 0.11089940382433788, 0.06435875474874463, 0.010524175678645926, 0.025199492894379154, 0.08774648620081799, 0.08561630014862333, 0.05504275732008474, 0.08247517155749456, 0.03179283972297396, 0.15171534115714685, 0.07981815056077071, 0.2290622400385993, 0.4316854444997651, 0.13279313008700097, 0.2761302872427872, 0.05334081507420965, 0.16092061863413878, 0.024047849333978126, 0.12825725919434003, 0.11466055735945702, 0.20755380631557532, 0.36547964279140743, 0.16526008078030177, 0.24344406117286, 0.3159174094242709, 0.2398669331201485, 0.22082356283707277, 0.5028880866510528, 0.563956292612212, 0.15705469250679016, 0.30789522560579435, 0.08844483444201094, 0.12214386223682336, 0.045815322282058854, 0.05449079961649009, 0.04141607780807784, 0.018188329646363854, 0.04412055893668106, 0.048313121643981764, 0.1256577508257968, 0.02162222234931375, 0.02165756723843515, 0.021063615002536347, 0.027169763509716307, 0.03285392939246126, 0.02157970704138279, 0.09290350840560027, 0.06049058945583446, 0.06598266546747514, 0.01224836115060108, 0.04199469515255519, 0.03536989313683339, 0.020943705990378345, 0.04192639381757804, 0.07575489966464893, 0.052966898174158165, 0.06393991543778352, 0.01882882259919175, 0.038927957748195956, 0.03336117842367717, 0.06560136271374566, 0.06848227312522275, 0.03640945967552917, 0.028952006982373338, 0.03666813079533832, 0.028010349654193436, 0.02280427615291306, 0.023847021628171206, 0.053646396712533066, 0.031995616520621946, 0.014550435390057308, 0.012079542486130126, 0.019294979549678307, 0.08093755013708558, 0.036111284246934314, 0.046106749679893255, 0.037944455165416, 0.010834702989086509, 0.04680516577458807, 0.06981759611517191, 0.01576964237860271, 0.027132442387353097, 0.027257567637466958, 0.05252995554889951, 0.0165911209769547, 0.010624327447398432, 0.014870681866471256, 0.026668275240808725, 0.028032836304711442, 0.024601389720503773, 0.003997521632949689, 0.04060295536848051, 0.02379188726523093, 0.06522307265549898, 0.05624896866668548, 0.03245109672259007, 0.022925533753420626, 0.06555425881275109, 0.03602947327973587, 0.0497624656584646, 0.04999086733109184, 0.01217686985286751, 0.03742241746346865, 0.04464856774679252, 0.04504732920655182, 0.05461882560380867, 0.041366768668272665, 0.024486479815095663, 0.0092334663661729, 0.027473772643133998, 0.06266549775110823, 0.08793425041117839, 0.06826510120715414, 0.030344394767390828, 0.023225693896945034, 0.0328249457691397, 0.02298802343596305, 0.043645408004522324, 0.04282033995592168, 0.020025948361892785, 0.058767890823738914, 0.02929743898234197, 0.012668481196409889, 0.05753934210432427, 0.049672057652579885, 0.039749086901013336, 0.03856155562347599, 0.006179565996197718, 0.007400774663048131, 0.04331536857145173, 0.02093748382425734, 0.06824186138276543, 0.05284245145906295, 0.006992596833567534, 0.03145070879587105, 0.019677905698439906, 0.018619389373010824, 0.03962454519101551, 0.03054193327469485, 0.00820739843350436, 0.023007388825395277, 0.026645814035353915, 0.05918806006333657, 0.09613636814590011, 0.025512278878263066, 0.046392955750759156, 0.022639244562014937, 0.06545450059430939, 0.008945893895413195, 0.05681281430380685, 0.07621313471879278, 0.10418582907212631, 0.031558212491550615, 0.057092784637851376, 0.04311138398147055, 0.006094600689331335, 0.04918937837438924, 0.057309447654656, 0.04363282457260149, 0.047189935842262845, 0.025227713165804744, 0.017755750001275113, 0.0646041062261377, 0.03658995677583984, 0.03568945259654096, 0.05968206748366356, 0.08327616179095847, 0.05002540137086596, 0.05652741908228823, 0.0509714081085154, 0.032034601750118394, 0.025708736818549887, 0.020209446283323423, 0.0480179589108697, 0.02198233445441084, 0.19698514842561313, 0.0279476377514324, 0.06299681961536407, 0.07302500400692225, 0.0762922383312668, 0.11132152724478926, 0.09474473353475332, 0.06460637253309999, 0.054274574254772494, 0.07547587249428034, 0.1363430760268654, 0.08233130856284074, 0.26828422397375107, 0.28705220403415815, 0.05841670823948724, 0.2506173976830074, 0.041127218665289025, 0.10805095452815294, 0.11484482032912117, 0.060589696280658245, 0.008010395120696297, 0.16588388516434602, 0.18272764847746917, 0.048983975646219084, 0.12494583188423089, 0.11506014663193907, 0.1433527906026159, 0.22011416804577622, 0.13811748581273214, 0.44191767115678104, 0.153852712895189, 0.2706909605434963, 0.10639113573623554, 0.08290180045046977, 0.15743274507778032, 0.04653559059702924, 0.012205464166722127, 0.04993523424491286, 0.07628847246191331, 0.08039034557129655, 0.10604449933660881, 0.018099219338702302, 0.01085442376123475, 0.020742503393973623, 0.03293008816295436, 0.023954369260796478, 0.05898665729910135, 0.042398362420499325, 0.042351892949747186, 0.07283430852528129, 0.017873345209019523, 0.02758158676858459, 0.05952069828552859, 0.09506748550172363, 0.03395980915852955, 0.022820357432855026, 0.05328457469918898, 0.06685920378991536, 0.037370190623083284, 0.05739004404417106, 0.025926137742187296, 0.03084527574745672, 0.03797759820840188, 0.05063959430637104, 0.02011210873856076, 0.04998510317610843, 0.02034861720832331, 0.09611912657107625, 0.000910943652602977, 0.05854571131723268, 0.03724913997575641, 0.05971360579133034, 0.0372246923590345, 0.046267016258622916, 0.08978274943573133, 0.02054131097559418, 0.048039292051856, 0.01852470320383353, 0.04524835877652679, 0.04857714979776314, 0.06593338346907071, 0.055985178000160625, 0.043896150442638567, 0.025088510010391474, 0.02318742621823081, 0.03918438630976847, 0.033621674802686484, 0.021816269793946828, 0.04098241589963436, 0.031275935138442686, 0.03700294032959001, 0.05426317825913429, 0.023297191131860018, 0.03197556920349598, 0.04827292522947703, 0.09294557079140629, 0.05149805984858956, 0.03909360171694841, 0.01487503806129098, 0.014388121331908872, 0.029091255938900367, 0.014442170038819313, 0.03894766919048769, 0.01426621912313359, 0.04500688512676528, 0.024914564165685858, 0.03686712815293244, 0.01924823527224362, 0.03678654872679284, 0.021696362478126372, 0.05757585407367774, 0.1140515993216208, 0.2111537331449134, 0.13708523048886231, 0.2373743482998439, 0.1294279628034149, 0.12794187611767224, 0.10899462710533823, 0.13526444961982115, 0.10396416525223426, 0.08672679056014333, 0.15726830890136106, 0.1282161535429103, 0.098781928686159, 0.11565005140645163, 0.11220727328743253, 0.1723092860941376, 0.1229248967553888, 0.18332960403391294, 0.11875767393835954, 0.13458459824323654, 0.08603872890983309, 0.1301612148859671, 0.13144680804439954, 0.12548172527125903, 0.19264373209859642, 0.105426204656916, 0.11187176486211163, 0.10587997495063714, 0.11565406833376203, 0.08010956099522965, 0.12543327787092753, 0.1102852685643094, 0.16262916981109551, 0.23790583120925085, 0.142851000385625, 0.10116685714040484, 0.10792085900902748, 0.34252537307994707, 0.2387815485043185, 0.1399566956928798, 0.17541496801589215, 0.15137341379054955, 0.08554034493863583, 0.08688693839524474, 0.1917727374072586, 0.10835883979286466, 0.09261722769588232, 0.176299424842, 0.11461814892079149, 0.06825419714940445, 0.1219753548502922, 0.13337470245148453, 0.16453474041606697, 0.10647769644856453, 0.10825039632618427, 0.17362066358327866, 0.11336677428334951, 0.15466266657624925, 0.23453337645956449, 0.21024552759315285, 0.08787283620664052, 0.13846904837659427, 0.11077064501919917, 0.18295307138136455, 0.26744615180151804, 0.3135565146803856, 0.2062501369842461, 0.08859293828053133, 0.16831635178199836, 0.2740474290081433, 0.24195201694965363, 0.1925298332103661, 0.14982418263597147, 0.13395274643387112, 0.17941969526665552, 0.28780198522976463, 0.21073054442448275, 0.4773769069995199, 0.4958017926130976, 0.17580067446189268, 0.22248024679720402, 0.20342011669916765, 0.27714315003582407, 0.14012476881699903, 0.18741632545632975, 0.23440841745053018, 0.2636509968766144, 0.38048153636710985, 0.21954364223139627, 0.2734133516039167, 0.3515725518975939, 0.3788342976144382, 0.5062162737761224, 0.5123445306505475, 0.8023170136979648, 0.3180446167077337, 0.5876950302294323, 0.2697638917182173, 0.24938718655279704, 0.2988065747278077, 0.12800466774829797, 0.12066775001585484, 0.1128049540732588, 0.20122768862971238, 0.20813664075519356, 0.26515932594026836, 0.13218314067593642, 0.06086326124412673, 0.11779979962323393, 0.14162982734186308, 0.08615272279296603, 0.1555717677942344, 0.363391817680427, 0.15829073903816088, 0.20355613582900592, 0.06865382034863744, 0.09582804183342628, 0.13261262620134012, 0.18489784773971352, 0.1139589792915753, 0.17210065014660358, 0.09138034656643867, 0.17198785048510346, 0.16622368193098477, 0.14907058807356016, 0.07986163108476571, 0.08999690187296697, 0.20724116452038288, 0.10324373748153448, 0.08680422497647149, 0.14374695159494877, 0.0856520589441061, 0.2150671160114663, 0.08100648929498025, 0.1420695044632469, 0.0939684012638671, 0.08479844831994601, 0.10872418340295553, 0.09454883368951933, 0.10985772364905902, 0.09927545434662274, 0.1610078103840351, 0.07578582050544874, 0.13481513730117253, 0.14073888372097695, 0.1052802721304553, 0.10503916149692875, 0.1458253857812711, 0.13420517503150872, 0.14405359514057636, 0.11276329880846397, 0.09333492097045694, 0.09673972826983247, 0.10739149991422892, 0.0823727399110794, 0.13547141637120927, 0.14205327390560082, 0.11749760726732866, 0.123886285881911, 0.14680790448827402, 0.1831902600824833, 0.08057018449263913, 0.1693082885550601, 0.09718384301023823, 0.2180203175438302, 0.1085956756557737, 0.10765233556074755, 0.12742386891373567, 0.06570844232503857, 0.11659788340330124, 0.16656826915485518, 0.2156885862350464, 0.14265128038823605, 0.1260539067110845, 0.12605230536844048, 0.14240769988724164], [0.02901630835341556, 0.07179481323276247, 0.03758205978998116, 0.061558243951627185, 0.09848470320659024, 0.01953156096195536, 0.031173727408583676, 0.058533151634037495, 0.0826111024777804, 0.03879528379599963, 0.020150384898962717, 0.036514242445783954, 0.07150028832256794, 0.04501228626551373, 0.018014180241152644, 0.0673574452687587, 0.06282097047993115, 0.05486954090052417, 0.023962442131180848, 0.004208769092136728, 0.026766488095745444, 0.009963683700854225, 0.03334068327343889, 0.011029037114764963, 0.03750544979370066, 0.06959372705646924, 0.0470799656717905, 0.04875006426924041, 0.04174966597929597, 0.04106915642374328, 0.023609961848706007, 0.009069807112349995, 0.033681993173169236, 0.02032166749372014, 0.03315604371683938, 0.020534851322216646, 0.021434849992926632, 0.015144574223086238, 0.018663707887753844, 0.04840790620073676, 0.054272369015961885, 0.05147178697266749, 0.06019089410879782, 0.05928059188382966, 0.02223075121375067, 0.011483133953463818, 0.011415352545944708, 0.017699121164956262, 0.012562751021635319, 0.004381443531851151, 0.040232488818998845, 0.03784285133172359, 0.06170420361948865, 0.01438071342584278, 0.030257640672581534, 0.06133250892162323, 0.07049291487783194, 0.029841990476208072, 0.0746388588366764, 0.05383420842034476, 0.0543542953341135, 0.017673637085993375, 0.08743708780301468, 0.03254226468769567, 0.04050237272999116, 0.04038657055103353, 0.04024289415350982, 0.06405260653368064, 0.13884358613618783, 0.3274845044527735, 0.19480975158512592, 0.32533200138381546, 0.09677938864167247, 0.41787448844739367, 0.9644738009997776, 4.8067134107862195, 3.85398553950446, 10.776795847075325, 22.109289509909495, 37.61648409707205, 37.94841691425869, 33.574185439518516, 48.33502190453665, 49.21705402646746, 54.727517468588694, 45.50586135046822, 33.185360772269114, 35.6925105367388, 42.095907824380056, 38.80034943989345, 41.677386556352886, 33.087210518973215, 27.672687802995952, 23.315415143966675, 22.270286219460623, 10.815672755241394, 8.608157975333077, 1.043333140867097, 0.07082651661975042, 0.28586693906358307, 0.3536910467914173, 0.21672119439712592, 0.07304742958928857, 0.04687284964269825, 0.11534133154366698, 0.07244356056409222, 0.056207255726414065, 0.022591492660077553, 0.026600962870621254, 0.06965419809733119, 0.016267816003944193, 0.024342516736526574, 0.07704083887594086, 0.008283580952723111, 0.07491262736065046, 0.03888978336804679, 0.05126743597377624, 0.02689490424069975, 0.02377170933011387, 0.036400954239070415, 0.018057343550026417, 0.006970837063688252, 0.05725458809839828, 0.05577951742868338, 0.040022465267351696, 0.03407558419608644, 0.013263228166449283, 0.07290537828313452, 0.020731029366808276, 0.04415738642481821, 0.005903895877833877, 0.07013428876442568, 0.07167321975742068, 0.02620160430004554, 0.0375237532758287, 0.006051163421943784, 0.04318146647087165, 0.03194450926301735, 0.09478182225887265, 0.028238337420459305, 0.02806307521781751, 0.01709425130060741, 0.021281046460249593, 0.02086092471810324, 0.030437808683408157, 0.03997572777526719, 0.060664640473467965, 0.07501463153000389, 0.011842897461195077, 0.04724217964602368, 0.053446276379483085, 0.04765304956319077, 0.056854686699807644, 0.05335727633376207, 0.030606899610055343, 0.02722471975721419, 0.04041673143261245, 0.050335227245731015, 0.03754029256690826, 0.02681059287195759, 0.03667534362258656, 0.021237577810617428, 0.0157198446935841, 0.03300474397838116, 0.030272487018789564, 0.021469071906592165, 0.07182278923158135, 0.0082022203631433, 0.00552125386561134, 0.03570831587005939, 0.06808666685330016, 0.049145348237029145, 0.010912314672688288, 0.013778009784540959, 0.01991361688955554, 0.03827858955732413, 0.023937729885801673, 0.06748999029930149, 0.030943863492991244, 0.025413066880511384, 0.02724520133675209, 0.06530491754944835, 0.04255875452820744, 0.04994100518524647, 0.011093916936910577, 0.02033763681538403, 0.013465420575812459, 0.039337148291191885, 0.020676671926464354, 0.02471788739785552, 0.02918588782527617, 0.004903466814929354, 0.0265388141519257, 0.026807743024879267, 0.07549811487219163, 0.00648516502198098, 0.011103492762361254, 0.02239393549306052, 0.02659858969439353, 0.021458844687523584, 0.007714166239436183, 0.03626889775374106, 0.029927085552896773, 0.05423508012401206, 0.035053017283124585, 0.004885877914992827, 0.019301230553537607, 0.052175841693367274, 0.010307012242265046, 0.04799278186900275, 0.02188531242843185, 0.11595554144254752, 0.143088962616665, 0.024244558332221847, 0.01055043752837394, 0.021146129949816635, 0.08621784179870572, 0.0456358701256769, 0.09045457374304533, 0.029775677248835564, 0.054270625180963955, 0.06984409290765013, 0.017795169493183494, 0.015277958940714598, 0.01149925509733813, 0.035194573258715015, 0.12738739087113313, 0.022881430673546026, 0.06551295638616596, 0.05491357782323446, 0.01383810254213001, 0.025877386697434952, 0.03386782355872648, 0.07690272307289497, 0.09289993931140218, 0.1710539555975369, 0.02470099357222872, 0.09695257113448211, 0.09431423699217183, 0.024943848040753176, 0.02491874054872564, 0.12143149546214513, 0.03142299742570945, 0.1297963530357395, 0.21261199989489146, 0.3379495771867888, 0.11945880417312894, 0.27788079902529716, 0.03796016325109771, 0.8050367449011121, 1.704108129654612, 6.710262741361346, 6.009505646569388, 15.608765091214861, 30.6106675692967, 46.72980390276228, 50.397459166390554, 47.86570930480957, 63.23436723436628, 67.19816861833844, 70.379561151777, 61.787522997174946, 46.635926791599815, 50.35250779560634, 57.92407444545201, 57.38137149810791, 57.94464111328125, 47.24116700036185, 40.37905311584473, 32.92870473861694, 30.37990747179304, 17.103124584470475, 14.780852488109044, 3.2566408727850233, 0.3188413796680314, 0.18751759002251284, 0.364968190235751, 0.23916342801281384, 0.03405767087159412, 0.07169721954103027, 0.06565327742802245, 0.1118673136723893, 0.08433308186275618, 0.04324516733842237, 0.046357407301132164, 0.10028093467865672, 0.04634075265909944, 0.08089133511696543, 0.14497201942971774, 0.0313657935309623, 0.06425751053861209, 0.048505343829414675, 0.044965195935219526, 0.031436177968446694, 0.037510182575455735, 0.04795626989964928, 0.02440315401846809, 0.05701801007879632, 0.05640301647196923, 0.04745665438739317, 0.08420560548880271, 0.078826797327825, 0.009717406023160687, 0.05529975924374802, 0.04090161594961371, 0.006887818728241005, 0.020088746777868698, 0.03622009751519986, 0.02121984090522996, 0.0643523425928184, 0.01607870320523424, 0.016044038547469035, 0.03207503565187965, 0.02305802110848682, 0.06740099364625556, 0.05672732228413224, 0.009981635192941343, 0.052850251219102314, 0.030899877460407357, 0.015350704680063894, 0.014999662891828587, 0.04083044101883258, 0.06501424671815974, 0.009923689998686314, 0.017079983405502777, 0.04839189616697175, 0.06565840715276343, 0.03142670561958637, 0.004411494151489543, 0.01181722932960838, 0.07509748744113104, 0.019582603758733188, 0.012906105008109339, 0.08313184417784214, 0.01599152502603829, 0.024269396106579473, 0.021554989706990973, 0.015871763595246842, 0.0013775089963538839, 0.022115038940683007, 0.02836476545780897, 0.025696655502542853, 0.02740189542860857, 0.02533730335666665, 0.018293098845918263, 0.05501860147342086, 0.008476843841240873, 0.06468059069343976, 0.050546736789069006, 0.024939115258998105, 0.048317270885620794, 0.04418657021597028, 0.222888494176524, 0.16177182724433287, 0.09620973135211638, 0.059195924284202714, 0.1725867119218622, 0.10137676194842372, 0.11363065655210189, 0.12441183839525495, 0.19378420018724032, 0.12137528562120029, 0.11241584816681487, 0.20242364731218132, 0.10311602362032447, 0.08749580143817834, 0.13803329318761826, 0.10226224336240973, 0.09620772967381136, 0.14565849330808434, 0.18437009677290916, 0.1520495739366327, 0.06613674041415964, 0.17070054741842405, 0.10782309568354062, 0.07239712841276612, 0.10911645128258637, 0.1544681577278035, 0.0897241782929216, 0.15028326585888863, 0.100711933337152, 0.12334447566952024, 0.10918614361435175, 0.11579875914113862, 0.1367408875375986, 0.09353139757045678, 0.07969750703445502, 0.32651827058621813, 0.27603417954274584, 0.08927133080682584, 0.08509574843836681, 0.16062207679663384, 0.22508316141154083, 0.1773995200970343, 0.2109309836689915, 0.19027704266565187, 0.13444320511605057, 0.15077992635113852, 0.1208653122718845, 0.10948490936841283, 0.10775801738990204, 0.18001634467925343, 0.19102678314915725, 0.17530594100909574, 0.13839962067348616, 0.13478297474128859, 0.08408213247145925, 0.12495986398841653, 0.21316173539630004, 0.15056217089295387, 0.10359039423721177, 0.31804448100072996, 0.11552540452352592, 0.18183063875351632, 0.20907926160309995, 0.1486067415348121, 0.11616491020790168, 0.184854530064123, 0.1289399332766022, 0.19703914624239716, 0.31619284035904066, 0.506149451647486, 0.3142976649105549, 0.5968059641974313, 0.12194792846483843, 0.8579489056553159, 2.4129189465727126, 8.628196580069405, 7.957995057106018, 18.767596823828562, 38.06409747259957, 57.21983977726528, 61.37070056370327, 58.569819177900044, 76.51851000104631, 78.22673157283238, 82.98933955601284, 73.38914557865688, 51.01848220825195, 60.15127086639404, 64.8563060760498, 63.719080516270225, 64.0768849509103, 52.73989840916225, 44.797579356602256, 40.277991567339214, 35.49222176415579, 18.9720493044172, 16.83804212297712, 3.982296185834067, 0.2966018516038145, 0.4030542251254831, 0.6041307768651417, 0.4374432483954089, 0.16809684570346559, 0.16097574281905377, 0.34397035411425997, 0.1968306460018669, 0.12010801290827137, 0.11804020458034106, 0.12238513571875435, 0.22317615231232985, 0.14812059833535127, 0.1959361739988838, 0.3084790099944387, 0.15968268577541622, 0.2202257734856435, 0.10760358960500785, 0.20109249731259687, 0.13155723283333437, 0.16645758652261325, 0.0803982030068125, 0.13582133688032627, 0.15314126892813615, 0.1513338280575616, 0.11251542996615171, 0.18081613390573434, 0.1389442671622549, 0.07998913460011993, 0.1379431973078421, 0.11484130551772458, 0.07239062804728746, 0.22843169101646968, 0.15300497838429042, 0.23371867303337368, 0.13469272958380835, 0.15612780010061605, 0.05504390743694135, 0.09948374424129725, 0.08930924734366791, 0.2205509003251791, 0.1370982855026211, 0.14944083749183587, 0.09575398652149097, 0.06700422707945108, 0.09037939884832927, 0.15873304887541703, 0.16895026633782045, 0.19465108295636518, 0.2596365665750844, 0.18021894166512148, 0.11509741177516324, 0.15220573198582443, 0.16200421191751957, 0.21467558773500578, 0.17250243787254604, 0.14666596853307315, 0.0835408175896321, 0.10161994211375713, 0.1634569689631462, 0.1554339709026473, 0.13424622640013695, 0.051288623229733536, 0.11075225672019379, 0.1505547205784491, 0.15883364847728185, 0.10228945261665753, 0.12369784313653197, 0.1946689962808575, 0.1783348127667393, 0.03277295980868595, 0.1943581322474139, 0.11739974894693919, 0.1441702895930835, 0.06658500778887953, 0.13085655043167727, 0.1388651228376797, 0.11434916406869888], [0.05480138884325113, 0.01814927825970309, 0.02933464984276465, 0.061889274045825005, 0.06252214365771838, 0.07256771211645432, 0.03600268132452454, 0.050969637132116725, 0.07233791266168867, 0.0791348454409412, 0.09975389617362193, 0.035174461480762274, 0.12594745813735894, 0.019865330641290972, 0.02781941498895841, 0.030215998978487084, 0.05814393037664039, 0.028169856273702214, 0.02005870294358049, 0.02296740106040878, 0.0597478107416204, 0.036205027252435684, 0.06740315138761487, 0.05329316495252507, 0.040453599632850716, 0.004624895959360791, 0.007637075331461216, 0.04649754174585853, 0.029154678607093434, 0.030848586998347725, 0.03381858227242317, 0.044188900983759334, 0.08587887963013989, 0.03341696418023535, 0.03572295865576182, 0.08326785652233021, 0.014032912490490292, 0.0446241811982223, 0.053438605541097264, 0.029265266244432757, 0.013182516425981053, 0.06622432571436677, 0.062144294647233825, 0.04545979028833764, 0.0614380007609725, 0.09574797470122576, 0.08492230131689991, 0.07917146597589765, 0.049196492814059765, 0.025871171316664134, 0.03960870139833007, 0.03378489640142236, 0.07045877099569355, 0.031548899598419666, 0.08122011926025152, 0.06307858987046139, 0.08062084391713142, 0.09109671892864363, 0.010290461924991437, 0.10507065230714423, 0.051616786513477564, 0.04699070778276239, 0.1107376478612423, 0.01259594749925392, 0.25126064888068605, 0.25541024335793083, 0.05819439981132746, 0.6182799147708076, 2.1901625224522183, 8.709511348179408, 19.31323364802769, 24.66338130405971, 36.864115783146445, 68.71765627179826, 72.44965185437883, 85.59414972577775, 92.96557004111153, 92.54687854221889, 110.34170150756836, 111.30830015454973, 104.6604027066912, 120.32145472935268, 113.72370937892369, 115.45809786660331, 115.47266129084996, 114.6592356818063, 124.74039786202567, 116.41701875414167, 125.39247240339006, 118.7143224988665, 121.89021900721959, 118.94682312011719, 118.74896621704102, 123.52895164489746, 117.79982839311872, 121.37641361781529, 111.76831259046281, 95.38941437857491, 56.75447028023856, 28.60723614692688, 12.716776319912501, 4.85533299616405, 0.8538366034626961, 0.12541103549301624, 0.5295529386826924, 0.5084202640822956, 0.07663696804749114, 0.027344174150909697, 0.10132730353091444, 0.11466456071606704, 0.031199169079107896, 0.050863829773983786, 0.0929308058694005, 0.05746866589678185, 0.09865407911794526, 0.053050371552152295, 0.019666779420471618, 0.027559235825070312, 0.023667618665578108, 0.026632397701697688, 0.02965271652543119, 0.04127698152193001, 0.01320419816433319, 0.02378038948933993, 0.023751064902171493, 0.01566736340256674, 0.03860627108120492, 0.03550568495744041, 0.04505148184086595, 0.06667988734053713, 0.0930207728275231, 0.04118349975241082, 0.04031149743657027, 0.038874601147004535, 0.031116699932941368, 0.036723343189805746, 0.018717178143560886, 0.07163634137915713, 0.05561566139970507, 0.0368005774383034, 0.024617859461743916, 0.04089262196794152, 0.030658291852367774, 0.06777397077530622, 0.01430360640266112, 0.017193459905683994, 0.012874414030063366, 0.034340402843164544, 0.04392586009843009, 0.08202986938080617, 0.07366801771734442, 0.02807287495982434, 0.049824001999305825, 0.012839529696585876, 0.043343846686184406, 0.02130945332880531, 0.04774082824587822, 0.04772449251530426, 0.026340929591762166, 0.054570008401892016, 0.07256349162863833, 0.027836140877168094, 0.02443683140778116, 0.059743142420692105, 0.0497690915529217, 0.04089299516220178, 0.04112981066906026, 0.03557560459843703, 0.07036529601152454, 0.02481163040335689, 0.0052502885394330534, 0.06583339454872267, 0.003147448508700888, 0.11137133850050823, 0.03670288875166859, 0.02110900729894638, 0.021064685391528264, 0.035190664897007604, 0.03575617294492466, 0.03800882438996008, 0.06144992262125015, 0.07825505693576165, 0.02442476705514959, 0.060454552460994036, 0.005470822174434683, 0.032616835686245134, 0.07304166882698025, 0.043272508906998804, 0.06384089003716197, 0.006332494218700698, 0.03772596688941121, 0.10202234730656658, 0.024637877941131592, 0.022906672176239744, 0.024661962541618516, 0.0051775627320499295, 0.0363081340411944, 0.030223741063049862, 0.05154468198972089, 0.017738840908610394, 0.054962361098400185, 0.013582131991695081, 0.08629022112914495, 0.021765298243345957, 0.027712861242304956, 0.01601262576878071, 0.053951978350856473, 0.04032271022775343, 0.045458290725946426, 0.1158114206045866, 0.041897094675472805, 0.17243292874523572, 0.04287599339815123, 0.018582587329936878, 0.019277300319767425, 0.022193747306508676, 0.012482296276305403, 0.008297826795439635, 0.05971501714416912, 0.041261558420956135, 0.08089352678507566, 0.030398592752005373, 0.06956699956208467, 0.044555326857204945, 0.052644675464502404, 0.0078018940319972375, 0.019150918083531514, 0.037256132279123576, 0.05601894190268857, 0.04445267468690872, 0.018141644740743295, 0.04798808301399861, 0.021996756716232215, 0.06926492255713258, 0.03168750394667898, 0.08153210966182606, 0.08920857988830123, 0.09949285018124751, 0.19345813696937902, 0.03742306885708656, 0.2655683197081089, 0.2901250177196094, 0.04371201300195285, 0.9204989778144019, 4.181227454117366, 13.286701440811157, 26.314129114151, 33.80240249633789, 49.04275499071394, 87.06865474155971, 93.2227645601545, 106.17161505562919, 114.1705549785069, 114.76247201647077, 133.74745886666435, 138.06744575500488, 123.79184368678501, 138.680540902274, 139.5794015611921, 136.08609744480677, 141.0590899331229, 141.65731593540735, 143.1457451411656, 140.93509238106864, 146.96483639308383, 140.60196794782365, 144.24885504586356, 143.1668815612793, 138.67731693812777, 151.68680436270577, 143.25505420139856, 143.05593272617884, 138.53949247087752, 120.08321489606584, 81.45320401872907, 42.70822824750628, 22.291137763432094, 9.307687844548907, 2.9380989713328223, 0.1172776533556836, 0.26055630722216194, 0.45458402005689486, 0.07252870992358242, 0.00508904062943267, 0.08702529847089734, 0.16184247631047452, 0.052881250091429265, 0.03424598130264452, 0.11591392010450363, 0.08429615598704134, 0.03744526034487145, 0.016442635462486317, 0.028843047829078775, 0.015958919722054685, 0.017631951287122707, 0.035896782364164076, 0.023914133830528175, 0.0994162435776421, 0.044859327508934906, 0.02213318127074412, 0.04636486440098711, 0.024952387403962866, 0.06195425055921078, 0.010618271522356995, 0.040885069873183966, 0.03777937438072903, 0.03866468955363546, 0.03777811909094453, 0.062249786486583095, 0.02869641301887376, 0.005701696259036128, 0.017620395835755125, 0.09351397957652807, 0.05669639126530715, 0.020618694501795938, 0.03644466885764684, 0.04759494321686881, 0.03736743237823248, 0.04392980917223862, 0.04509231268561312, 0.01808929576405457, 0.03304324405533927, 0.023350245784968138, 0.018972307310572693, 0.033030799723097255, 0.08131904288062028, 0.013366695426936661, 0.02657499024644494, 0.041686144923525195, 0.021340060347158993, 0.06834167388400861, 0.05820682378751891, 0.027949447743594646, 0.014288125626210655, 0.037111153094364066, 0.07320061565509864, 0.022872648734067167, 0.07796208587075983, 0.0745833750282015, 0.03463584716830935, 0.05218097820345845, 0.0839743675397975, 0.023492955270090272, 0.022407984560621635, 0.01525705836580268, 0.040785152199012895, 0.023823378075446402, 0.08135373637612377, 0.07850950078240462, 0.0271405746295516, 0.05124743954677667, 0.060693166085651944, 0.13688278278069838, 0.11684662077043738, 0.19185393090759004, 0.15935063787869044, 0.16816891969314643, 0.17667822380151066, 0.09459549654275179, 0.09028760663100652, 0.12105902044900826, 0.1168735178985766, 0.17927545229239122, 0.18990588401045116, 0.21000179781445436, 0.1267605602209057, 0.1095144459977746, 0.17965628685695784, 0.1038797962080155, 0.10863571600722415, 0.1103692033461162, 0.10220874766153948, 0.13191876986197063, 0.1612512416073254, 0.17636797044958386, 0.11380949124161686, 0.14588075423879282, 0.1469468820307936, 0.14618652925959655, 0.08658763659851891, 0.0938410877383181, 0.11896023021212646, 0.15004813990422658, 0.1408576409199408, 0.20394779981247016, 0.20462427208466188, 0.08928366657346487, 0.22720560537917273, 0.08307649607637099, 0.0893506719065564, 0.08788796075220619, 0.11077071965805121, 0.06983059006077902, 0.0783062931150198, 0.12271134821431977, 0.14572636038064957, 0.17582819584224904, 0.15473507983343943, 0.10617244389972516, 0.12348083406686783, 0.12510912812181882, 0.08391505679381744, 0.0831642442249826, 0.11755549987511975, 0.15485455627952302, 0.10327413585036993, 0.22929956444672175, 0.2092205597353833, 0.24778554535337857, 0.1865296566060611, 0.13808149631534303, 0.3141245570565973, 0.1154924820044211, 0.14449901266821794, 0.3299352915159294, 0.19959008507430553, 0.5197824143937656, 0.4876084551215172, 0.11846352900777544, 1.2734588895525252, 4.713000885077885, 15.634047848837715, 31.62387820652553, 40.95627818788801, 58.02793959208897, 99.95005907331193, 105.65677438463483, 121.28354399544853, 131.1575039454869, 128.90814971923828, 146.67252567836215, 146.09549168178012, 135.40268652779716, 153.22904041835238, 146.71450669424874, 146.05729048592704, 151.4619745526995, 144.94416127886092, 159.41088049752372, 150.8530205317906, 161.7381101335798, 154.22612081255232, 156.71916225978305, 155.22467422485352, 157.34909984043665, 163.8641755240304, 156.80973897661482, 160.93735803876604, 157.7581958770752, 132.36512865339006, 87.01750210353306, 45.532799516405376, 23.431087017059326, 10.46333828994206, 3.3831751687186102, 0.21953893319836684, 0.6072841190866062, 0.650870820241315, 0.32688033687216894, 0.18984553510589258, 0.27422957494854927, 0.25308604378785404, 0.1083647430475269, 0.22170462698808738, 0.3352546532239233, 0.17955882208687918, 0.16604600075100148, 0.12498807747449193, 0.15150775015354156, 0.0756607393601111, 0.06441381786550794, 0.09240498872739927, 0.1079234103006976, 0.22285098476069315, 0.18034597699131283, 0.05564040417916008, 0.16428075118788651, 0.13274606689810753, 0.1234200508998973, 0.10689960952316012, 0.08782052115670272, 0.12445170911295073, 0.15510534282241548, 0.0944573332422546, 0.10395362081804446, 0.1211646276393107, 0.08544970623084477, 0.10820362490734883, 0.19499007905168192, 0.16968191707772867, 0.12009661351995808, 0.16676523430006845, 0.12045121592070375, 0.06268480885773897, 0.07747923356613942, 0.10916976377900157, 0.09688375411289078, 0.09771493236933436, 0.11191986620958362, 0.10797482289906059, 0.14496321204517568, 0.1505652243005378, 0.13276171391563757, 0.08551375315125499, 0.08712066656776837, 0.10755884700587817, 0.13900443964770862, 0.17470401259405272, 0.1128472335902708, 0.1855195758066007, 0.2561446082379137, 0.18691885072205747, 0.12486208709222929, 0.18147914404315607, 0.07888394354709558, 0.1382119921701295, 0.11952193507126399, 0.1500021895127637, 0.13045769397701534, 0.09531916092549052, 0.11117652431130409, 0.11748467438987323, 0.10677129176578351, 0.18565695200647625, 0.13927060179412365, 0.20846251398324966, 0.22460729123226233, 0.11749076763434069], [0.007704115439472454, 0.08195655367204122, 0.059030456734555106, 0.005734736249516053, 0.12512151817125933, 0.026353229735312716, 0.02809343796356448, 0.03568494373134204, 0.04626876348629594, 0.09704182563083512, 0.06144185483987842, 0.03359484213537403, 0.07222546583839826, 0.0380723216970052, 0.009906930183725697, 0.037350285798311234, 0.00712784837066595, 0.03249747459111469, 0.029441349474447112, 0.01867988076992333, 0.016842282410444956, 0.08581878856888839, 0.03946667044822659, 0.017721606119136726, 0.12834670368049825, 0.07091853275362935, 0.053863419352897575, 0.047229165344366004, 0.033821347302624157, 0.04213770319308553, 0.03026899934879371, 0.04302005656063557, 0.028628233820199966, 0.033123100841684, 0.025350924947166016, 0.022569513214485984, 0.03147684935746448, 0.06081170615340982, 0.04279313748702407, 0.025923842597486715, 0.05076845149908747, 0.04112448077648878, 0.01939262413153691, 0.03425168438947626, 0.04579881352505513, 0.053068030426012616, 0.035693357565573285, 0.03561451518908143, 0.028356775707964386, 0.05788061807730368, 0.025673597186271633, 0.017213822741593634, 0.03487465078277247, 0.026942774886265397, 0.079110642096826, 0.01694139602061893, 0.03518931461232049, 0.030781917540090423, 0.026227956903832297, 0.17502262549740927, 0.042728985393685956, 0.21214598204408372, 0.2777389580649989, 0.5418372452259064, 4.618127141680036, 10.104768684932164, 39.99817718778338, 55.784487860543386, 77.28928756713867, 88.13724599565778, 103.2945397240775, 100.50397641318185, 97.46917002541679, 84.28485897609166, 90.6476857321603, 84.46755490984235, 72.9333506992885, 70.73514911106655, 71.37113857269287, 56.20018468584333, 71.26700592041016, 66.22835295540946, 50.296203068324495, 56.9465115410941, 64.42064707619804, 62.124524525233674, 62.36218070983887, 68.53060381753104, 78.05388123648507, 73.88335009983608, 81.4318105152675, 86.08781923566545, 78.46715314047677, 87.69019195011684, 83.49810750143868, 89.45061533791679, 93.11029406956264, 98.72726644788469, 109.30063206808907, 123.54073578970772, 108.2745429447719, 103.22040939331055, 86.67208630698067, 55.53126771109444, 31.799674579075404, 15.090193237577166, 3.497121282986232, 0.21304631658962794, 0.05001596634143165, 0.3705263691289084, 0.0428063248151115, 0.04405988433531352, 0.118742881874953, 0.11600849431540285, 0.05012004343526704, 0.014253961388021708, 0.11217783165297338, 0.045337959325739315, 0.024371846412707652, 0.05370052684364574, 0.05351021812696542, 0.01983071687365217, 0.016204177900882702, 0.013906958579484905, 0.009673897509596177, 0.016504282065268074, 0.023643610400280783, 0.023166948031367998, 0.026373249911037937, 0.04153389523604086, 0.021240113835249628, 0.045125608398978195, 0.06289279341165509, 0.027582399314269423, 0.07215027058763163, 0.030592738584216152, 0.040002801322511265, 0.055179366775389226, 0.02570771562334682, 0.045030257265482626, 0.032688862178474665, 0.010381377983971365, 0.03458735566320164, 0.034619223060352464, 0.05435783050156065, 0.0094124783229615, 0.03245642322248646, 0.028496893189315285, 0.02049907047434577, 0.02700369036756456, 0.03569285884233458, 0.014200314713109816, 0.030035593480403935, 0.06653842635984931, 0.06433023592191082, 0.05481632679168667, 0.01221946404049439, 0.026397178448470573, 0.05512997621138181, 0.09503024071455002, 0.06838165995265756, 0.05145586175577981, 0.021930713206529617, 0.03651172508086477, 0.034871828077094894, 0.05942412918167455, 0.034148329935435734, 0.04114071133413485, 0.04729780933952757, 0.07039722108415195, 0.02460922340729407, 0.07283178437501192, 0.03989977595795478, 0.10385793380971466, 0.04822334467566439, 0.060114165368889055, 0.01918684142375631, 0.018885939980724027, 0.031478759433541975, 0.08169631513633899, 0.018823156831786036, 0.03351557906717062, 0.04335739703050681, 0.010814608174509235, 0.04697834148204752, 0.0298778714079942, 0.04999111160369856, 0.04707692922758205, 0.07668582256883383, 0.04368363327479788, 0.04915869502084596, 0.04406060358243329, 0.05129032295995525, 0.012610544483842594, 0.017418323018188988, 0.04841372124584658, 0.019214350929749862, 0.10866672505757638, 0.02482048189267516, 0.03995858119534595, 0.022522081920344914, 0.044296245223709514, 0.043507773961339674, 0.013751552007826311, 0.024505029266167964, 0.009191895070086633, 0.0699992331543139, 0.026445664864565645, 0.010080917588701206, 0.04974593993808542, 0.0006417116123234987, 0.009306508116424084, 0.01472565857693553, 0.016805339571354643, 0.04508531020422067, 0.03590436838567257, 0.03339547158351966, 0.018750551888453107, 0.008348107088490255, 0.025332538344498192, 0.03656438957633717, 0.02978487139833825, 0.021807401341253092, 0.07157640638095991, 0.028775584484849657, 0.06493739584194762, 0.04486603822026934, 0.021797850960865617, 0.012366941930460078, 0.033453007960425954, 0.061801458043711524, 0.02714586041734687, 0.05304015620744654, 0.09734061852629695, 0.023805558049519147, 0.18074201074029717, 0.019874346675351262, 0.16204948377396378, 0.25441485962697435, 1.2740351557731628, 7.55795773438045, 16.324571984154836, 53.216398920331685, 72.02010032108852, 94.21817738669259, 108.8205462864467, 123.93372590201241, 124.07546915326799, 116.86018180847168, 106.54202352251325, 106.28299467904228, 112.64755848475865, 94.26747485569545, 93.97585201263428, 99.77486024584088, 89.63827228546143, 102.76716450282505, 98.64557647705078, 81.48737525939941, 95.57423646109444, 88.58874688829694, 90.97992079598563, 97.57613754272461, 88.38071087428501, 99.08155509403774, 94.53653689793178, 109.08115237099784, 111.07688345227922, 103.73005281175885, 110.61823981148856, 107.30379622323173, 104.46404661451066, 107.04050813402448, 112.49391991751534, 125.47737939017159, 141.3781234196254, 130.68491527012415, 129.85828808375766, 112.99703202928815, 78.25962434496198, 51.576950618198936, 26.79798776762826, 8.170723710741315, 0.7441015860864094, 0.07702598574438266, 0.3935171440243721, 0.09994067650820528, 0.027424580550619533, 0.16144215422017233, 0.04809330343934042, 0.03360277420974203, 0.03649328928440809, 0.08210964474294867, 0.0492555151826569, 0.04899211467376777, 0.004607645478764815, 0.078201764795397, 0.02742376291592206, 0.03354098341826882, 0.08278322645596095, 0.039791817643812726, 0.016812944252576147, 0.06047762265162809, 0.03820188456614103, 0.045250574193362675, 0.02072294631839863, 0.08596247514443738, 0.03019303735345602, 0.029549144940184693, 0.03153554602925267, 0.0669447738411171, 0.0462926309555769, 0.04073923573430095, 0.009767965363737727, 0.0071391782091398326, 0.07313475026083843, 0.01869217412812369, 0.04999091822121825, 0.04623374768665858, 0.021432680377204503, 0.03304492003683533, 0.04882087279111147, 0.036546591602798016, 0.03642220934852958, 0.05160218783255134, 0.045294909671481164, 0.02481615623193128, 0.06535852181592158, 0.01656276160585029, 0.03883231484464236, 0.04600776159869773, 0.013212366877788944, 0.04306118596079094, 0.06482144777796098, 0.06286781653761864, 0.06803148838558368, 0.04508878091084106, 0.009289724552737815, 0.04797231725284031, 0.00751361164397427, 0.02843472920358181, 0.05093914037570357, 0.039768398007644076, 0.01874250785580703, 0.080372350822602, 0.0671266076554145, 0.037131071489836485, 0.03250022605061531, 0.07224061074001448, 0.018031762779823372, 0.013833357037843337, 0.03787586545305593, 0.1251624066914831, 0.16285710329455988, 0.20554355132792676, 0.16890639226351464, 0.20589951079870972, 0.09987979156098195, 0.11870173551142216, 0.13384420797228813, 0.1106153012120298, 0.20335941495639936, 0.1881522238254547, 0.13665100878902844, 0.2576143150883061, 0.12130017179463591, 0.09315911254712514, 0.12716275506785937, 0.19354226174099104, 0.0694912343419024, 0.12045900550271783, 0.055124707386962006, 0.11041261601660933, 0.3805238498108727, 0.14029050778065408, 0.10457880941352674, 0.29442334707294193, 0.13182285215173448, 0.13155791136835301, 0.11965506364192281, 0.088172707972782, 0.15332321130803653, 0.17208671303732054, 0.20007100355412277, 0.1607957003372056, 0.11646784895232745, 0.13767590879329614, 0.090399110290621, 0.07189968081989459, 0.2127240803092718, 0.10729121243847267, 0.06868227810731956, 0.1964782149131809, 0.13253008920167172, 0.16991242899426393, 0.11238072719424963, 0.09043271813009467, 0.1156193409115076, 0.1638717031372445, 0.16056046581694058, 0.09324166990284409, 0.13292819926781313, 0.13186640052923135, 0.10019070987722703, 0.05787546121116195, 0.10889262293598481, 0.15563525153057917, 0.1327064268823181, 0.11921179028494017, 0.23225390591791698, 0.15910267404147557, 0.3569500504859856, 0.08152700707848583, 0.41309521347284317, 0.4241309884403433, 1.725154223186629, 9.195447513035365, 18.39146477835519, 61.43636104038784, 79.81203256334577, 108.60626384190151, 121.31154523577008, 134.32125500270297, 131.37621934073312, 125.85879380362374, 111.45216955457414, 117.14736475263322, 111.70186001913888, 102.05482823508126, 96.82133388519287, 98.46235942840576, 77.09070805140904, 96.13778400421143, 94.9336472920009, 75.04722894941057, 81.04478195735386, 87.5687096459525, 89.07078511374337, 92.24108832223075, 95.1370905467442, 103.98407895224435, 95.83503709520612, 106.78823988778251, 112.33073452540806, 104.20681735447475, 109.54213060651506, 107.17414283752441, 111.99537972041539, 117.14641979762486, 123.03336443219865, 140.74655996050154, 157.93291527884347, 146.52301434108188, 140.1149409157889, 125.14260128566197, 85.65220192500523, 54.738912514277864, 29.046112162726267, 8.330604365893773, 0.6474742367863655, 0.14832300533141407, 0.4586077598588807, 0.12767499472413743, 0.08327430939035756, 0.26761654551540104, 0.20533726311155728, 0.1416716386697122, 0.15597347409597465, 0.14596928948802607, 0.08773712241756064, 0.1583348980971745, 0.13725871832243033, 0.1674674501908677, 0.107094159083707, 0.11641638885651316, 0.2218658197671175, 0.1507205409663064, 0.16658288479915687, 0.13681977401886666, 0.1657444733594145, 0.08262611167239291, 0.12418357921498162, 0.172752369461315, 0.1811859490615981, 0.12379783205688, 0.11071413662284613, 0.14044692367315292, 0.11667070378150259, 0.1204936650714704, 0.16722006989376886, 0.09424804590110268, 0.10941103726093258, 0.10883649451924221, 0.1595209501683712, 0.11031532088028533, 0.12343668857855455, 0.11438473287437644, 0.12262255512177944, 0.17928472108074597, 0.16869019743587288, 0.07527938910893031, 0.10577798435198409, 0.16731582475560053, 0.202206339687109, 0.1568690181842872, 0.14334428177348205, 0.18849043282014982, 0.13118736339466913, 0.10045641740517956, 0.23518300588641847, 0.15351468031959875, 0.29752441495656967, 0.23889269254037312, 0.1440134530088731, 0.1551011223345995, 0.13845838180610112, 0.08816369702773434, 0.21461538810815128, 0.14272184803017549, 0.15508094270314488, 0.10861863049545459, 0.17738608510366508, 0.1230919249355793, 0.18714819555836065, 0.25685964844056536, 0.1594941480351346, 0.08409775234758854, 0.14993965572544507], [0.06335879090641226, 0.12609702082616941, 0.13431498913892678, 0.005319843891941543, 0.08147548591451985, 0.05730590570185866, 0.0638336907806141, 0.09400333903197731, 0.03641307626717857, 0.04118328940655504, 0.06495261538241591, 0.0274146569759718, 0.022056713766817535, 0.04902029084041715, 0.04139380828876581, 0.0338486345883991, 0.07359400311751024, 0.06194260689829077, 0.029039466753602028, 0.05086888146719762, 0.00995154895021447, 0.0035800241249879555, 0.07173964155039617, 0.04308023922411459, 0.07495474402925797, 0.02089755203840988, 0.09826902406556265, 0.04986735699432237, 0.003878038825600275, 0.0092840715078637, 0.027929001787145222, 0.031792093334453445, 0.009027811731877071, 0.013199389895557292, 0.03681597339787653, 0.017424680891313722, 0.06437095480837993, 0.05125720705837011, 0.034030865345682414, 0.022495018551126122, 0.055763677028673034, 0.013997958607173391, 0.06637671789420502, 0.019290725135111382, 0.021181449393874834, 0.03441930289513298, 0.056458870082029274, 0.02816079613486571, 0.02394894098064729, 0.013005172817169555, 0.016951456998607943, 0.01649082332317318, 0.10960855201951095, 0.03809538510228906, 0.05798957723059824, 0.01950011764919119, 0.031456835967089446, 0.05628851029489722, 0.06695098922188793, 0.396622147411108, 1.2756862214633395, 11.444010513169424, 27.129298721040996, 52.04662799835205, 76.77453027452741, 82.80084187643868, 90.44775826590401, 97.68453638894218, 74.05360875810895, 65.6320446559361, 59.86226054600307, 56.57337590626308, 49.50383744921003, 46.600932189396445, 50.713352067129954, 50.90198871067592, 69.00525610787528, 48.09025076457432, 61.11433982849121, 43.481819834027974, 43.405455657414024, 41.714747020176475, 65.6340457371303, 43.32314382280622, 58.74999291556222, 44.028736863817485, 40.637661593300955, 49.61140251159668, 58.03557913643973, 58.71090235028948, 47.070811067308696, 64.12164524623326, 62.085044860839844, 53.59810515812465, 54.84632819039481, 85.33025714329311, 68.0453416279384, 73.82159451075962, 63.150273186819895, 77.08633068629673, 93.21927656446184, 87.56085123334611, 96.1327326638358, 105.75437573024205, 103.2914616721017, 102.1832309450422, 92.26390620640346, 64.63635390145438, 41.28066178730556, 13.067709854670934, 1.1949065732104438, 0.08540726386542831, 0.4809170684644154, 0.17147387377917767, 0.06346587051770516, 0.05377241423619645, 0.012014277595361429, 0.026414966243984442, 0.027999353994216238, 0.06938127774213042, 0.06353715740676437, 0.03501833735832146, 0.014508739413161362, 0.0046764183955799255, 0.07798322223659072, 0.03029447833874396, 0.0780016105355961, 0.009971136559865304, 0.016856972693598697, 0.037662893666752746, 0.08385822270065546, 0.023265975128327097, 0.026301450728039657, 0.00688984797203115, 0.036021374964288304, 0.013844716562224286, 0.030209980372871672, 0.01841794928934957, 0.03502724652311631, 0.06313655033175435, 0.06918180201734815, 0.09951273804264409, 0.018463645230180452, 0.06443559205425636, 0.038720994389482906, 0.00457447995930644, 0.026307666108810475, 0.050249263644218445, 0.031206487079284022, 0.08140446365411792, 0.03420328109392098, 0.0668597330472299, 0.026074256847745607, 0.02880538913554379, 0.04237655430499997, 0.01910036213562957, 0.031918704576258145, 0.04905557805406196, 0.022913028353026936, 0.0764398875513247, 0.0241615209129772, 0.06006422519151654, 0.01912026696040162, 0.020163239744891013, 0.054422739161444564, 0.021185898887259618, 0.016256538751934255, 0.04271720263308712, 0.04758551497278469, 0.019853725996134535, 0.07339044261191573, 0.02175642639797713, 0.08713406763438668, 0.02481736402426447, 0.038673527472253354, 0.07716727709131581, 0.0348897481869374, 0.0753110224114997, 0.05608787427523306, 0.03972111090219446, 0.015060059293838484, 0.058968214717294486, 0.06891291894550834, 0.10203964994954211, 0.023671143654999987, 0.01202089840080589, 0.03455736780805247, 0.05731254855969122, 0.02735003160445818, 0.0051974573787967005, 0.038989823178521225, 0.026155877825138823, 0.07637438856597457, 0.08978812343307904, 0.06557259961430516, 0.05906337246830974, 0.08486744176064219, 0.03938410969983254, 0.01672744205487626, 0.04077489614220602, 0.023161821699302112, 0.02372099901549518, 0.047472650850457807, 0.06685296805309397, 0.07489434762724809, 0.025100162152999213, 0.07512516488454171, 0.03669034603184887, 0.040624227441315136, 0.043829195999673436, 0.07415522621678454, 0.048460051616919894, 0.02185532626962023, 0.021282641017543416, 0.056905030605516264, 0.03574355558625289, 0.05018203778724585, 0.09089459691728864, 0.04533646654869829, 0.04079648373382432, 0.10038507623331887, 0.007991970350433673, 0.08932148811540433, 0.052341159965310774, 0.08277783888791289, 0.027359858487865756, 0.07375670902963195, 0.04921121023861425, 0.056968931640897474, 0.03036301376830254, 0.06715313837464366, 0.044036756469202895, 0.10433819411056382, 0.04954113092805658, 0.024449036556429098, 0.42298271719898495, 2.7301209313528876, 17.38480802944728, 38.683393887111116, 70.24944223676408, 93.83513709477016, 95.90893118722099, 105.64535849434989, 112.33384731837681, 102.94799137115479, 90.28168937138149, 91.04210717337472, 86.9344641821725, 77.81370980398995, 82.7373492377145, 91.81304454803467, 81.24516105651855, 98.4788544518607, 76.59755270821708, 93.94792025429862, 69.12781538282121, 69.76647990090507, 69.5603129523141, 83.28975881849016, 63.16112627301897, 89.32069097246442, 80.54299695151192, 69.95031533922467, 88.43025847843715, 97.9769652230399, 92.3652456828526, 89.42810317448208, 106.2908114024571, 96.981872013637, 98.57806083134243, 86.56352070399693, 128.7882238115583, 111.12797355651855, 109.94464669908795, 100.77728380475725, 100.98689705984933, 118.21138409205845, 105.36022526877267, 107.86796910422188, 125.38449587140764, 122.55334118434361, 123.58901187351772, 120.16249384198869, 88.44647557394845, 59.7610113961356, 24.41954469680786, 3.185061399425779, 0.002672677980236975, 0.31363202205726076, 0.1541598585567304, 0.03046545559274299, 0.056323933215545754, 0.03402904008648225, 0.03620298486202955, 0.04587953205087355, 0.012553275280099894, 0.020850985876417587, 0.07498216362936155, 0.06308401815061059, 0.04182930224175964, 0.01664275409919875, 0.08397149055131845, 0.05035859599177327, 0.10757707245647907, 0.03045300786782588, 0.08505974537027733, 0.03521808449711118, 0.02556443616880902, 0.067631003446877, 0.03261048459847059, 0.008427955393147255, 0.008657965193768697, 0.02297248668037355, 0.05604184924491814, 0.03910587980811085, 0.07906817937535898, 0.027238448216978992, 0.06990011954413992, 0.05083693603851965, 0.03021504563678588, 0.055681384301611354, 0.026188408490270376, 0.007107166623297546, 0.04563444520213774, 0.007821777652549957, 0.0243070598891271, 0.007233448775618204, 0.007916184774200832, 0.0543378747866622, 0.03978009595136557, 0.04727960763765233, 0.05340956084962402, 0.011169841612822242, 0.020872670159276043, 0.050513919442892075, 0.023191690810823014, 0.056499097030609846, 0.016064360671277558, 0.01843296018029962, 0.045159789600542614, 0.09089004394731351, 0.008710748432869357, 0.06043934649122613, 0.04070915288424917, 0.020566968080986823, 0.0015471316188008391, 0.05584172212651797, 0.12149841258568422, 0.12805492005177907, 0.007197194649571819, 0.0477829584851861, 0.030472800734319856, 0.18009177063192638, 0.24921684712171555, 0.19568754519735063, 0.1767940361584936, 0.1590061727911234, 0.12953447923064232, 0.1555543565856559, 0.2609784374279635, 0.08611973242035934, 0.17353831657341548, 0.13774452225438186, 0.15811784831540926, 0.1548794720854078, 0.10501745516168219, 0.20111773881529058, 0.0873992730464254, 0.13413707725703716, 0.20121820271015167, 0.11811926748071398, 0.0912058816424438, 0.15648443810641766, 0.11377103187675987, 0.1442095631999629, 0.1638196459306138, 0.10231560335627624, 0.13205743527838162, 0.15133673218744143, 0.18273002335003444, 0.11217694955744914, 0.09421829892588512, 0.14619305676647595, 0.1327904159469264, 0.09101258058633123, 0.09829653187521867, 0.26604769112808363, 0.15333755553833076, 0.12498418268348489, 0.11318759354097502, 0.1821271992687668, 0.1773112155497074, 0.1743634965802942, 0.13325263400162968, 0.1679411626287869, 0.14493482213999542, 0.158617887912052, 0.0879765095721398, 0.19817820297820227, 0.10657811963132449, 0.16699837893247604, 0.11603406151490551, 0.1050264389653291, 0.10217077684189592, 0.19831472422395433, 0.14811487149979385, 0.15469970101756708, 0.09133254377437489, 0.17572999825435026, 0.1446890431855406, 0.14607971427696093, 0.5314744955727032, 2.945984091077532, 20.02156949043274, 44.14277417319161, 80.93210996900285, 105.88666943141392, 112.83707060132707, 118.89644868033272, 123.92740304129464, 99.13255487169538, 87.26634488786969, 82.04027121407645, 77.83871637071881, 71.99658066885812, 66.65637588500977, 73.07674067361015, 72.69778592245919, 99.15692220415387, 70.66015025547573, 84.24897153036935, 61.962763513837544, 60.30927290235247, 60.523881912231445, 90.5095624923706, 57.62370729446411, 80.52748162405831, 61.93850040435791, 58.69277450016567, 74.3910549708775, 85.2859832218715, 81.39575631277901, 66.18743501390729, 85.70723860604423, 85.4927407673427, 80.05506665366036, 76.9755277633667, 112.73557826450893, 97.42008100237165, 104.43687915802002, 88.49844115121024, 100.95961148398263, 116.85003743852887, 110.89330509730748, 117.03353936331612, 136.15980393545968, 138.69096320016044, 139.7271897452218, 130.03024210248674, 97.11939770834786, 66.89117635999406, 25.410163266318186, 2.7356345440660204, 0.1754338720015117, 0.5800580914531435, 0.3226236695689814, 0.09112206899694034, 0.19612043696854795, 0.12431621924042702, 0.08143668728215353, 0.19628177902528218, 0.1294887595410858, 0.17899671010673046, 0.1352463463055236, 0.18650623357721738, 0.11878060842198984, 0.10234167267169271, 0.12698070412235601, 0.24393537480916294, 0.24346865128193582, 0.1700699712548937, 0.18860389744596823, 0.13391803258231708, 0.08826485981366464, 0.16793847563011305, 0.12283519442592349, 0.11644792716417994, 0.14332118444144726, 0.08776160396103348, 0.09612059899206672, 0.1503870952874422, 0.1972237213381699, 0.12395344727805682, 0.20636208169162273, 0.1079950500279665, 0.15102129482797214, 0.28871637902089525, 0.12015077418514661, 0.24267758801579475, 0.15750815745975288, 0.14387742030833447, 0.1890307773969003, 0.11714046714561326, 0.17334295277084621, 0.12132769317499228, 0.09555600357374974, 0.10573352673756224, 0.09922802474881921, 0.1257714190121208, 0.15862604390297616, 0.1012969526595303, 0.0840057972818613, 0.16313258851213114, 0.09969945730907576, 0.12000632765037672, 0.09527979910905872, 0.11794940302414553, 0.09050135194723095, 0.1100733552926353, 0.09848916796701294, 0.1418850515037775, 0.1742382797279528, 0.21253156635378087, 0.23692431673407555, 0.14014051082943166, 0.09173623139836959, 0.13664990956229822, 0.12346730407859598], [0.08977126183786563, 0.13166617841592856, 0.020624475620154823, 0.03533210552164486, 0.05369279832978334, 0.012285560136660933, 0.029296427965164185, 0.02247535969529833, 0.04242769888203059, 0.06595684042466538, 0.11901578865945339, 0.02614671251337443, 0.06948961264320783, 0.031144991450543915, 0.02108895150013268, 0.01736354997514614, 0.09833537800503628, 0.010933980295833732, 0.02632212738639542, 0.03623500153688448, 0.058185639924236705, 0.07260624612016336, 0.015838864824867675, 0.06776753826332943, 0.11558820972485201, 0.06023564349327769, 0.08740804650421653, 0.02552651284661676, 0.08522971839244876, 0.07294638893966164, 0.028275979150618826, 0.03452513400199158, 0.002585007014983733, 0.012366962286510637, 0.009186929041918899, 0.03355057790343251, 0.04779294312798551, 0.029132378553705554, 0.02550040451543672, 0.014479650616911905, 0.0092203511324312, 0.03239355356033359, 0.012921420391649008, 0.030190899968147278, 0.06335629389754363, 0.016885352420753667, 0.06305384369833128, 0.05324413061940244, 0.019028174491333108, 0.05968678330204316, 0.046563230721013885, 0.07597994937428407, 0.028242071059399416, 0.024647696342851435, 0.03621100175327488, 0.023853678056704145, 0.05344154020505292, 0.014954202741916691, 4.164718100002833, 22.830988475254603, 57.78438091278076, 87.7321868624006, 82.23090199061802, 88.84963090079171, 73.5548323222569, 57.514961038317, 62.736778940473286, 55.41408634185791, 43.662636280059814, 45.01699651990618, 56.27350207737514, 35.09426368985857, 35.10210125786917, 33.91539062772478, 39.294348989214214, 52.7832030568804, 50.17673921585083, 36.46570955004011, 49.42479126793997, 56.33156817299979, 48.91629082815987, 43.68373448508126, 40.84630210059029, 67.91496562957764, 26.326001848493302, 42.0321615764073, 39.621862752096995, 30.69739498410906, 25.261537824358257, 35.92494167600359, 53.873934745788574, 34.78971719741821, 43.1525342805045, 38.81832095554897, 45.093218258449006, 44.491024834769114, 36.879613740103586, 54.42133467538016, 45.96144430977957, 69.57966368538993, 46.96451752526419, 80.39773791176933, 72.50518185751778, 65.92904540470668, 78.67514051709855, 76.40946497235979, 80.62987027849469, 93.8769860948835, 93.85709340231759, 94.05544362749372, 67.52396965026855, 48.739490440913606, 18.127026762281144, 1.8373351693153381, 0.1427583396434784, 0.27434028472219196, 0.034335015275116475, 0.03184320737740823, 0.05330786880637918, 0.06624680557953459, 0.06630673379238163, 0.014283345347004277, 0.010232752521655388, 0.008253208877119635, 0.0314962215322469, 0.07091566933585064, 0.05661937075534037, 0.08358392491936684, 0.05910468168024506, 0.13839909141617163, 0.03446296323090792, 0.032113288063555956, 0.02716502733528614, 0.007491849329588669, 0.039105920520211966, 0.07034828513860703, 0.03009963022278888, 0.037429721892944405, 0.025195272406563163, 0.06914404832891055, 0.024412412628797547, 0.022039621469697783, 0.04173763216074024, 0.041320485794650655, 0.011437072451891643, 0.014901141303458383, 0.00920513498463801, 0.015358299183260118, 0.0354861601122788, 0.13021046295762062, 0.040903329250535796, 0.07953308442873613, 0.03307461612192648, 0.0031765447264271124, 0.04668459010177425, 0.04299823487443583, 0.03413470495226128, 0.039854127514575205, 0.06604069378226995, 0.025951910198533108, 0.031100927386432886, 0.009341557842812367, 0.07990801573864051, 0.03051896147163851, 0.03630781512973564, 0.062490089663437436, 0.06002178282610007, 0.1497381715370076, 0.03481580483328019, 0.012074749484392149, 0.11473876530570642, 0.03754572763240763, 0.051843322214803526, 0.028180960499282395, 0.030382511472063403, 0.10043292652283396, 0.05843050964176655, 0.06429417857101985, 0.010012810484373143, 0.05342020367139152, 0.02578949266379433, 0.013163977152934032, 0.06290644553623029, 0.03957323098023023, 0.005500766772976411, 0.10019417040582214, 0.039254984485783746, 0.0377199448911207, 0.05131788844508784, 0.016715445555746555, 0.05357441771775484, 0.01978789283228772, 0.07842080947011709, 0.052094634622335434, 0.023198396433144808, 0.014677950779774358, 0.08288843331060239, 0.029715006040143113, 0.047902173695287535, 0.04504692208554063, 0.04349915995927794, 0.06069930682757071, 0.02654214745520481, 0.03708567749708891, 0.06028585508465767, 0.04272734673161592, 0.03928540660334485, 0.02268933062441647, 0.04558950582785266, 0.051317243836820126, 0.01020980192281838, 0.034105287066527774, 0.04849146778828331, 0.0625716360019786, 0.066632362747831, 0.05196533977453198, 0.03557279207078474, 0.006974460864772222, 0.021636072945381914, 0.03454693193946566, 0.06605183532727615, 0.030460973868944814, 0.024551050903807794, 0.08861532315079655, 0.02884759401370372, 0.0275477957246559, 0.09768990121249642, 0.05871827634317534, 0.16326091305485793, 0.03775675202320729, 0.06687630965773549, 0.0477601664939097, 0.11796555215758936, 0.03194713858621461, 7.365787931850978, 33.33899933951241, 76.85204437800816, 102.90087563650948, 95.81781251089913, 101.74825981685093, 86.19382790156773, 75.94651344844273, 86.5341020311628, 80.49134404318673, 61.620835712977815, 64.13208838871547, 66.36691393171037, 48.711621216365266, 49.05802713121687, 33.440199851989746, 37.11902781895229, 43.06989588056292, 49.279434953417095, 26.862463576453074, 36.838400500161306, 33.66830226353237, 23.05642625263759, 22.233948877879552, 29.267236845833914, 33.1932052884783, 19.2022830758776, 20.388981546674454, 17.897048337118967, 21.874497720173427, 20.259706837790354, 25.438914912087576, 34.188461780548096, 28.432984011513845, 39.33201517377581, 37.24948372159685, 43.50480794906616, 53.41823366710118, 50.55729900087629, 69.04964814867292, 63.70831775665283, 93.86055360521588, 80.10035501207624, 114.94320855821881, 110.07213224683488, 99.89709990365165, 102.82371589115688, 96.75285938807896, 92.1095380783081, 108.03481619698661, 106.76746477399553, 114.36527824401855, 91.79200540270124, 70.16192272731236, 30.10929250717163, 6.074304980891092, 0.1957455463707447, 0.12924661753433092, 0.06359107379934617, 0.058618029579520226, 0.06851651878761393, 0.08332222753337451, 0.005477170293618525, 0.05599825336996998, 0.03770189925229975, 0.02955901762470603, 0.029166712425649166, 0.04252602539158293, 0.09264204172151429, 0.03986270419721093, 0.012599597169485475, 0.07904775547129766, 0.010139194416946598, 0.07158376848591225, 0.1035404744158898, 0.033746735591973574, 0.034995212884885926, 0.01681304264015385, 0.0166510627605021, 0.06558000243135861, 0.022212595312989185, 0.06170310439275844, 0.02895506378263235, 0.004675932394872818, 0.003210137934989429, 0.059652218728193214, 0.03829664537417037, 0.04764875443652272, 0.05825563081141029, 0.04089700530416199, 0.022935862752742002, 0.027696666307747364, 0.038514930089669566, 0.05492583555834634, 0.02371061742970986, 0.013373920128547719, 0.03497662781072514, 0.02203808628421809, 0.04816376590835197, 0.026116327715239356, 0.05721717367747, 0.05696979338037116, 0.0550878086526479, 0.06962855625897646, 0.0675039409792849, 0.015040510699951222, 0.022860148422686116, 0.01413631868282599, 0.034523122145661285, 0.05222107283771038, 0.030353904435677186, 0.10906016680278949, 0.08789897337555885, 0.042372411848711114, 0.028618581659559692, 0.08563817611762456, 0.019596997182816267, 0.03394587204924651, 0.1996199677565268, 0.2146130268062864, 0.10451418573835067, 0.12173737904855184, 0.09714843705296516, 0.08791920050446476, 0.11812776273914746, 0.20305640835847172, 0.294354109359639, 0.2148648447224072, 0.1434711678219693, 0.18922922174845422, 0.14771445441458905, 0.2218679232256753, 0.1371157509940011, 0.06751768809876271, 0.19447819223361357, 0.13824019208550453, 0.1740739249757358, 0.1314158939889499, 0.1067215958610177, 0.1995682633881058, 0.17048423045447894, 0.10300576167979411, 0.28029684509549824, 0.10287597828677722, 0.15421186148055963, 0.11113663323755775, 0.24423498873199734, 0.2570630189563547, 0.1203406961368663, 0.0789584806188941, 0.08657168424023048, 0.14005566681069986, 0.14110542833805084, 0.08819888585380145, 0.16912238353065082, 0.18751547299325466, 0.16638959731374467, 0.11180693084107977, 0.09272730643195765, 0.10413419255720717, 0.12037797485079084, 0.12253472554896559, 0.11256763645048652, 0.11991187557578087, 0.09406672777341944, 0.16245045725788387, 0.0954959803660001, 0.15163144708744117, 0.15392309054732323, 0.14222528253282818, 0.2541719169488975, 0.07111334694283349, 0.14599366246589593, 0.16142190673521586, 0.181133077612945, 0.08692383034420864, 6.753359811646598, 37.66827596936907, 86.71540832519531, 117.66343525477818, 107.12047495160783, 112.14726734161377, 95.54854202270508, 79.37848581586564, 85.91421849387032, 78.22526550292969, 60.79258264814104, 64.74506541660854, 72.16489383152553, 50.53981038502285, 49.1040415763855, 44.734312534332275, 53.72955117906843, 74.41091292245048, 71.26632499694824, 55.22082567214966, 71.73659297398159, 83.04823248726981, 79.70981066567558, 71.30745138440813, 61.70091370173863, 105.83435644422258, 42.16162388665335, 65.95448275974819, 64.60310677119664, 48.872267041887554, 39.88646752493722, 53.3656462260655, 74.37450436183384, 49.409453119550435, 61.96782875061035, 53.102768080575125, 65.9706859588623, 59.22119195120675, 53.052216461726594, 71.83194310324532, 64.34252153124127, 92.3093821661813, 65.63393456595284, 106.24005481175014, 100.84666851588658, 86.26960495540074, 100.39170047215053, 96.2325713293893, 99.33974320547921, 116.81707518441337, 120.96382958548409, 127.2894834790911, 101.82956763676235, 74.3122832434518, 32.47179119927542, 5.754977064473288, 0.25926103815436363, 0.32615454867482185, 0.11383258178830147, 0.11951628965990883, 0.17297513250793728, 0.09401724221450941, 0.2722671159676143, 0.12639553552227362, 0.16969432069786958, 0.17333202835704598, 0.12460427092654364, 0.1610859776181834, 0.1708233758274998, 0.18585112158741268, 0.1296937313995191, 0.22503446973860264, 0.11097467371395656, 0.19447938645524637, 0.17295059668166296, 0.10998533573001623, 0.09242245421877929, 0.15428560466638633, 0.145503950172237, 0.12312876938709191, 0.08487035267587219, 0.19294211108769688, 0.14927011808114393, 0.10699552723339625, 0.07259831404579536, 0.09221127376492534, 0.14856756292283535, 0.1277654841542244, 0.12015321691121374, 0.11377865182501928, 0.11942818867308752, 0.2812060277376856, 0.1032860984227487, 0.22587919155401842, 0.09304004322205271, 0.09855181710528475, 0.11022413255912916, 0.13143772924585, 0.09923060318189007, 0.1744062714278698, 0.16458069080752985, 0.11465960741043091, 0.12468633295169898, 0.19395453961832182, 0.17369432534490312, 0.08299961127340794, 0.056858774873295, 0.16461950301059655, 0.14460365633879388, 0.17602000412132057, 0.12436887355787413, 0.21385071985423565, 0.1947198592658554, 0.21795942581125669, 0.21906013174780778, 0.2207251074058669, 0.1161584776959249, 0.16547726626907075], [0.059507276862859726, 0.03684012245919023, 0.053316425132964335, 0.005571914986441178, 0.045587276840316396, 0.07613851622279201, 0.05772572210324662, 0.04105647121156965, 0.08679755497723818, 0.06454910417752606, 0.045115884992160966, 0.04537558409252337, 0.045885906887373755, 0.03985870423327599, 0.0345067457029862, 0.0965717365699155, 0.05217407750231879, 0.023340376493121897, 0.027069830568507314, 0.019976890280044506, 0.053714698047510216, 0.06620554386505059, 0.092175094277731, 0.03642717622486608, 0.040402488982571025, 0.04197771481371351, 0.0850946017141853, 0.062382874345140796, 0.04724043920370085, 0.037030672055802176, 0.023118280107155442, 0.050665317568928, 0.017614356874089156, 0.03752029613990869, 0.019204805638375025, 0.039433581688042195, 0.027648841463295475, 0.03119645154635821, 0.05610339576378465, 0.02528996536109064, 0.033364411643041034, 0.016154590561719875, 0.02717058114441378, 0.04893293284944125, 0.05171974402453218, 0.023705779475026896, 0.0718925901289497, 0.03368139606235283, 0.13941578114671366, 0.09919446440679686, 0.04847516937713538, 0.03948413933228169, 0.10284378180014235, 0.020725923390792947, 0.11546680623931543, 0.02945290831848979, 4.7364897046770364, 33.392083576747346, 73.29062707083565, 79.15382276262555, 70.9550734928676, 63.26751708984375, 68.24191311427525, 59.05051640101841, 74.2304265158517, 41.787682260785786, 49.722771712711875, 51.97724328722273, 52.349242891584126, 53.022120339529856, 57.094414370400564, 56.01851708548409, 56.79146943773542, 79.81821646009172, 81.1156257901873, 68.07336371285575, 51.20680965696062, 59.023077964782715, 77.33180359431675, 88.5130810056414, 73.23192174094063, 65.16099848066057, 67.35951968601772, 64.27713898250035, 82.75252410343715, 102.45316846030099, 77.28249222891671, 89.75155571528843, 93.21478802817208, 92.56821646009172, 114.48434952327183, 97.94077205657959, 82.15913404737199, 103.40854576655796, 70.93383979797363, 79.89531367165702, 84.53105449676514, 59.84693281991141, 54.573027747017996, 39.45171526500157, 46.174503871372764, 45.61099454334804, 34.48199537822178, 42.615101541791645, 44.975644315992085, 56.593445777893066, 66.76505265917096, 60.53725719451904, 73.67402866908482, 71.23174381256104, 84.98613371167863, 86.14859512874058, 91.89358806610107, 81.99655314854213, 53.54840816770281, 13.949609092303685, 0.3681736168052469, 0.14364830617393765, 0.06917775116328682, 0.10418477734284741, 0.06237882349107947, 0.0444435449982328, 0.020086902858955518, 0.04133864339174969, 0.04434493011129754, 0.033908444057617865, 0.047241996441568644, 0.09619848124150719, 0.027679652042154754, 0.02648502668099744, 0.014664188393258622, 0.012857404853483396, 0.04123730757938964, 0.052129392578665695, 0.04665997624397278, 0.01856434321962297, 0.01911219409001725, 0.05779312777199915, 0.0660240018208112, 0.039703143294900656, 0.04726457130163908, 0.04692832327314785, 0.059073408001235554, 0.039823335595428944, 0.06479254218616656, 0.09194302173065287, 0.04902992264500686, 0.03151495249143668, 0.03553960492302265, 0.017481742293706963, 0.012913668977229722, 0.024608090253812925, 0.007759422828842486, 0.013101762277074158, 0.0573766701189535, 0.049275080739919624, 0.05054996322308268, 0.048808418280844174, 0.032103262708655426, 0.048155080660113266, 0.02748448501474091, 0.016264557339517132, 0.07878317431147609, 0.03248250610860331, 0.05468370372961674, 0.0849783279533897, 0.048791173313345225, 0.0381302584095725, 0.06413381360471249, 0.09195373579859734, 0.026178808916094046, 0.13562680089047977, 0.016904124092044573, 0.08872188707547528, 0.06345398258417845, 0.017936917154916694, 0.05242683179676533, 0.06741436078612294, 0.04294446436688304, 0.04443890381870525, 0.02658621491199093, 0.01536056718655995, 0.007746940329005676, 0.05530283979273268, 0.05020246169130717, 0.03171874709161265, 0.03655453046251621, 0.05357177143118211, 0.02240202871949545, 0.0754085211083293, 0.019336896050455313, 0.018965740787929723, 0.030627211555838585, 0.07017095001148325, 0.01950111679200615, 0.03167457785457373, 0.11187999549188785, 0.03321921193440046, 0.03860873416332262, 0.02407533678758357, 0.0291317543014884, 0.017457265839246765, 0.06262906042060681, 0.05968067648687533, 0.08859950649951186, 0.04998102178797126, 0.048755014182201455, 0.050595313111054044, 0.04754925745406321, 0.03682094705956323, 0.045477951278111765, 0.07028316613286734, 0.08077310038996593, 0.018624386783423166, 0.022567640457834517, 0.01760206521222634, 0.028237392560445836, 0.016715621974851404, 0.042630652098783424, 0.031810841257018704, 0.03750308170648558, 0.07843657862395048, 0.07362872375441448, 0.04252851900777646, 0.05212896510160395, 0.07009359023400716, 0.02919177750923804, 0.0377229575866035, 0.0549212859810463, 0.061241693794727325, 0.07867595899317946, 0.006802646892278322, 8.23610886505672, 46.96681390489851, 91.67018263680595, 93.09373651232038, 83.61609486171177, 78.04830183301652, 89.21709333147321, 84.09950883047921, 99.78703348977226, 59.51268972669329, 57.34396934509277, 49.78883171081543, 39.83650997706822, 36.720482621874126, 39.64203337260655, 29.247083595820836, 31.463062150137766, 42.71872697557722, 49.77187810625349, 50.45826285226004, 42.68255812781197, 46.425715991428916, 58.33370549338204, 60.54844379425049, 63.87639468056815, 55.24658611842564, 50.33016586303711, 59.28835323878697, 55.43617466517857, 67.41106837136405, 56.9636492729187, 58.36168588910784, 54.867138045174734, 65.54787417820522, 67.01491682870048, 53.92305156162807, 50.84694160733904, 49.64400345938546, 41.16162524904524, 43.16192477090018, 43.072473662240164, 37.37883486066546, 29.335787773132324, 29.978173051561626, 26.326684509004863, 40.609354632241384, 38.8946920803615, 48.387915066310335, 69.80395153590611, 94.00085163116455, 116.6438843863351, 88.91064303261894, 100.14995179857526, 86.66881370544434, 93.12640694209507, 97.52884810311454, 109.34287016732353, 108.44719873155866, 73.9741769518171, 24.342166083199636, 1.4015158180679594, 0.033444353246263096, 0.04748026401336704, 0.21784267707594804, 0.03910532680207065, 0.056568484021616836, 0.06417624918477875, 0.051656446885317564, 0.06952645030937024, 0.034861863790346045, 0.054672148278249164, 0.0342543781735003, 0.02691670896352402, 0.026964011336011545, 0.10262994827436549, 0.03531749666269336, 0.038466323233608685, 0.04043171348582421, 0.04252663268042462, 0.024372324779895798, 0.08238028522048678, 0.008172140905766614, 0.01955577278775828, 0.06936791738761322, 0.06689967840377774, 0.03735926281660795, 0.022589302688304867, 0.036587558154548915, 0.08226482570171356, 0.04093094223311969, 0.014410862433058875, 0.035643855043287785, 0.061516113712319305, 0.015082315242450153, 0.04882171417453459, 0.046493002346583774, 0.08668698091059923, 0.06704464062516179, 0.0715917751991323, 0.07629632311207907, 0.008431856969504483, 0.0055694981295216295, 0.04355663866070764, 0.01917296029361231, 0.027427376114896367, 0.0489985234370189, 0.025629687488877347, 0.015000220986881425, 0.05752820734466825, 0.011407860671170056, 0.033736415074339936, 0.008801438878955585, 0.04909345727147801, 0.013693689085942293, 0.06075510276215417, 0.07569402150277581, 0.06044127353067909, 0.09006720488624913, 0.06347719526716641, 0.07013196138931171, 0.12156952305563859, 0.09628045505711011, 0.1494622113449233, 0.1361677154366459, 0.11438467859157495, 0.19840927129345282, 0.13513944989868573, 0.10635942100946393, 0.20968997026128428, 0.16635410993226937, 0.1230222936719656, 0.12833877839148045, 0.13180573949856417, 0.11899456408407007, 0.08714050014636346, 0.21749803556927613, 0.13598015478679112, 0.12564985267817974, 0.09432548710278102, 0.09683011591966663, 0.21054337732493877, 0.11047033899064575, 0.2615317963063717, 0.13422122917004994, 0.10389924980700016, 0.1188058363539832, 0.13588358568293707, 0.16399006678589753, 0.14704110340348311, 0.085595584474504, 0.24432846371616634, 0.17220678659422056, 0.15965772925743035, 0.16945183942360537, 0.1185723931661674, 0.23478478725467408, 0.12667359917291574, 0.1633329734738384, 0.11973309516906738, 0.12860074719148024, 0.0963891495817474, 0.12120201491883822, 0.1064108878906284, 0.12719483620354108, 0.16214439725237234, 0.25908043927380014, 0.1705877206155232, 0.10465378074773721, 0.19513425417244434, 0.1615499598639352, 0.21349906229547091, 0.09265392286969082, 0.18457527219184808, 0.18874221002416952, 0.153756835897054, 0.0990460484421679, 9.246941481317792, 52.03688662392752, 104.63047681535993, 105.51787294660295, 91.1899231501988, 80.19201564788818, 90.23660945892334, 78.35851805550712, 100.02634334564209, 62.446163586207796, 71.89775644029889, 71.38238770621163, 71.30980682373047, 74.04249858856201, 80.24156325204032, 83.11067594800676, 83.61289174216134, 113.08678191048759, 121.39486803327287, 99.58563995361328, 77.31241812024797, 88.51867430550712, 112.17716544015067, 124.54495893205915, 108.31404345376151, 98.5789154597691, 97.60784217289516, 103.03050122942243, 120.8961958203997, 159.98278672354562, 116.13048894064767, 135.37372643607003, 130.90452003479004, 126.17554828098842, 162.04319163731165, 135.557131086077, 116.32373918805803, 147.9961714063372, 99.76641123635429, 106.39383234296525, 116.0662181036813, 86.30947371891567, 80.61966337476457, 54.73892988477434, 64.66801684243339, 60.16204057421003, 48.23676742826189, 59.385329246520996, 63.408565521240234, 77.95411900111607, 92.3472706930978, 82.64044966016496, 98.46966893332345, 89.43272372654506, 106.10176481519426, 109.31516769954136, 122.69669641767229, 117.07939747401646, 81.95326587132045, 27.236127274377004, 1.3275786255087172, 0.13752796101783002, 0.29242291727236336, 0.34047207183071543, 0.17633590288460255, 0.19062088350100176, 0.113120533925082, 0.19273936482412474, 0.32441266785774914, 0.16076968530459063, 0.12600351870059967, 0.16781712642737798, 0.1048072517982551, 0.12068932742944785, 0.16750737519136497, 0.16979576168315752, 0.1730829652931009, 0.10971027120415654, 0.1139121875166893, 0.16328662953206471, 0.1256215577679021, 0.1110100457444787, 0.11081007468913283, 0.1547965279647282, 0.10159061583025114, 0.15178345250231878, 0.16730301401444844, 0.09840960973607642, 0.2424770944884845, 0.17035437242261, 0.11269212048500776, 0.09295070051614727, 0.1415112465620041, 0.06271990947425365, 0.10891565241451774, 0.1223357655107975, 0.15228704762245926, 0.12833632209471293, 0.11374839594853775, 0.150395237707666, 0.14254774951509067, 0.11500966362655163, 0.15700072183140687, 0.10611104326588766, 0.14985600592834608, 0.15719419930662426, 0.15814360550471715, 0.10442121965544564, 0.1450081310634102, 0.10940743423998356, 0.0994558564520308, 0.13255889979856356, 0.182856556560312, 0.19808992557227612, 0.1467644511056798, 0.17594084622604506, 0.125711572223476, 0.1764386330864259, 0.19447547809353896, 0.1677792098905359], [0.07319031549351555, 0.08336639337773834, 0.03941890836826392, 0.03429353303675141, 0.08162424114665814, 0.018660683317908218, 0.04679079779556819, 0.06603001364107643, 0.04491732528965388, 0.03195604096565928, 0.021417462533073764, 0.030099039897322655, 0.05983260047755071, 0.03414267095338021, 0.03867578020851527, 0.04041759317208614, 0.03612085837604744, 0.04116527090913483, 0.057813490607908795, 0.02348624964776848, 0.026886456479717578, 0.04136432254953044, 0.02424446164098169, 0.02888859109953046, 0.036092705958123715, 0.0043660340015776455, 0.05869348945894411, 0.04870192899501749, 0.025541613643456782, 0.026160887109913995, 0.0261679387850953, 0.03122687027124422, 0.018983911955729127, 0.0030260231828184, 0.038250949433339496, 0.06894821633717843, 0.04452539328485727, 0.017924944404512644, 0.1024212987561311, 0.01548004023996847, 0.048386511991598775, 0.08792721400303499, 0.09051091929099389, 0.01944809267297387, 0.05337623120950801, 0.017715149858434285, 0.023530123722074286, 0.024130723904818296, 0.06108912519578423, 0.05670342088810035, 0.05732440256646701, 0.03787598419668419, 0.13721252365836076, 0.1934156199651105, 7.380853363445826, 33.12036384854998, 65.01282119750977, 79.27856377192906, 59.826831681387766, 66.96940612792969, 59.8743782043457, 53.88245671136038, 39.11954968316214, 44.88161781855992, 40.10577004296439, 46.719801970890586, 60.917198589869905, 48.37752056121826, 43.71338244846889, 64.74760845729283, 59.55185672215053, 75.21326310294015, 63.92029339926583, 43.09585782459804, 35.03186191831316, 30.79353720801217, 27.908570459910802, 21.474978038242885, 25.90633065359933, 27.607802050454275, 17.624216897147043, 19.418936593191965, 16.057478019169398, 13.036774737494332, 11.258560487202235, 10.27270403930119, 14.077388201441083, 17.281825304031372, 22.12730618885585, 26.71437314578465, 34.12439244134085, 46.02764674595424, 55.00901678630284, 53.952852385384695, 53.45542042595999, 69.68683964865548, 83.62723282405308, 91.85535907745361, 93.01264408656529, 79.79612813677106, 86.1371306010655, 72.12503201620919, 74.45656258719308, 62.11255972726004, 44.85629163469587, 38.753727027348106, 18.188688550676616, 43.29267249788557, 37.54293046678816, 48.25714996882847, 65.04189940861293, 71.72361373901367, 79.0218208857945, 78.2405515398298, 87.11940438406808, 90.03715447017125, 62.89708777836391, 33.22769962038313, 13.269531573568072, 1.207536118371146, 0.05136116880125233, 0.33605888006942614, 0.019844068746481622, 0.07766553892620973, 0.08504599825079952, 0.026229463251573697, 0.04719797648223383, 0.043278890528849194, 0.022876631734626632, 0.03031790815293789, 0.022229621452944617, 0.05269975893731628, 0.023385911281885843, 0.04974804000396814, 0.01765452784353069, 0.06450824279870306, 0.0828191955972995, 0.025623809679278305, 0.10360258751149688, 0.03667448866846306, 0.0461836378755314, 0.01276775002146938, 0.02671791347009795, 0.08559455988662583, 0.07643732268895422, 0.016037522914952466, 0.03362352041793721, 0.017944270778181295, 0.12687208423657076, 0.011416771532302456, 0.04315782291814685, 0.033485791379851956, 0.03429907666785376, 0.07979701419493981, 0.030479613225907087, 0.019022654608956406, 0.043442020525357554, 0.06406075573925461, 0.025811448360660245, 0.04212924864675317, 0.06467545418334858, 0.03901441668027213, 0.057148282017026625, 0.023283635698524967, 0.07525346907121794, 0.05237359054652708, 0.04554474287267242, 0.06619766607348408, 0.02852347819134593, 0.07137691030012709, 0.06966426077165774, 0.023999267922980443, 0.03707948586504374, 0.06043741945177317, 0.033030409565461535, 0.11554851542626109, 0.06985001651836292, 0.05790299616221871, 0.03547336633450218, 0.06576684383409363, 0.032774432229676416, 0.03205346841631191, 0.0492125401672508, 0.045388544111379554, 0.04445706480847938, 0.047071182035974095, 0.02581141613024686, 0.004632438300177455, 0.05678235825949481, 0.023242947346131717, 0.03963055022593055, 0.010652121938099819, 0.0053825345904832435, 0.03952314831050379, 0.026810090756043792, 0.0073403901354010615, 0.037614629470876286, 0.02816544070706836, 0.01816386167359139, 0.043084744696638415, 0.05500836916533964, 0.020957179999511157, 0.023409173158662658, 0.03804732446691819, 0.03605805656739643, 0.0030287307495850003, 0.03218713302963546, 0.04157831213836159, 0.035344909477446756, 0.07489455118775368, 0.04447712230363062, 0.02158815480236496, 0.0622514421120286, 0.0335537432692945, 0.018456761492416263, 0.023677730533693517, 0.06520432473293372, 0.08218760163124118, 0.025095788994804025, 0.06598789018711873, 0.02445250895938703, 0.07354611211589404, 0.028342769048841934, 0.024650622525119355, 0.02342288295871445, 0.0713455823383161, 0.11144393496215343, 0.044215560624642034, 0.08095217256673745, 0.4894519533429827, 12.119067089898245, 46.34826789583479, 82.85314096723283, 89.23978614807129, 70.60726056780133, 87.16460241590227, 88.41582706996373, 85.92425169263566, 59.7749981198992, 55.251488072531565, 43.486666202545166, 44.125389780317036, 53.65636232921055, 47.92533874511719, 42.20862150192261, 57.35360649653843, 56.98390327181135, 69.05155195508684, 58.40764127458845, 47.8821313721793, 39.46639333452497, 36.6095928464617, 33.568251677921836, 27.464815071650914, 31.493682861328125, 31.618472508021764, 19.813644647598267, 19.05137688773019, 18.840770040239605, 13.523706231798444, 13.547980632100787, 12.522912893976484, 15.001311881201607, 20.6918100970132, 27.346396923065186, 30.695307050432476, 37.48098380225045, 50.21599653788975, 53.9335537637983, 53.32650702340262, 50.4792811529977, 65.39434678213937, 78.03890786852155, 88.96123286655971, 81.79852254050118, 66.0211090360369, 66.52182401929582, 55.37472479684012, 42.69960553305489, 36.20374161856515, 26.152576548712595, 28.65792325564793, 22.26701361792428, 62.80161258152553, 68.72061620439801, 75.29178469521659, 99.57192420959473, 93.68818964276994, 96.01539148603166, 83.61290563855852, 98.58535643986293, 102.9017024721418, 84.41042682102749, 47.08867141178676, 23.77915528842381, 2.6532247832843234, 0.009067480585404804, 0.4871380403637886, 0.055989890425865135, 0.010747685113788714, 0.07745103365076439, 0.03848588200552123, 0.03325437701174191, 0.1509498315198081, 0.06801820945526872, 0.02769082921024944, 0.025849543012944714, 0.05321966603930507, 0.023267050606331656, 0.013434614237797047, 0.09515680106622831, 0.030430721385138373, 0.05616736125999263, 0.06766763755253383, 0.02246671515916075, 0.02987684342744095, 0.028726465334849696, 0.03571201388591102, 0.02616982171977205, 0.014038354341339852, 0.10729521579508271, 0.03517747078356998, 0.05916529521346092, 0.006277969689108431, 0.017747621151751707, 0.006300782884604165, 0.04635740051578198, 0.04269877701465573, 0.038356441272688765, 0.05935707635113171, 0.02124982197502894, 0.010306248890369065, 0.027123618039435575, 0.01828161803340273, 0.026876739858250533, 0.10200339582349573, 0.08903114298092467, 0.019635716087317893, 0.05851360982550042, 0.013969472010752984, 0.04797563189640641, 0.06628878654113837, 0.04093812113361699, 0.06856516974845103, 0.02034908709382372, 0.09090584024254765, 0.050040240931723795, 0.02087128085882536, 0.07525306195020676, 0.08370646155838456, 0.058602111147982736, 0.020196413321952735, 0.14328634845358984, 0.1529255219336067, 0.10837129769580704, 0.16047965229621955, 0.20121387365673268, 0.11533177777060441, 0.12414722330868244, 0.11214698545102562, 0.1144028769007751, 0.13736872241965362, 0.11648375381316457, 0.1938833612948656, 0.21268045050757273, 0.17179372161626816, 0.1923056859523058, 0.20729140325316361, 0.12816872394510678, 0.10264611776385989, 0.09474661986210517, 0.09841769787349872, 0.13220182753035, 0.08329443473901067, 0.1168344614229032, 0.17014665928270134, 0.09541774527834994, 0.09831720683723688, 0.14687791573149817, 0.08798525588853018, 0.15577129780181817, 0.10021790556077446, 0.11197061384362833, 0.1390619251344885, 0.19974555101777824, 0.14255008367555483, 0.0920428138758455, 0.13674436163689407, 0.09450751090688364, 0.13687582101140702, 0.14379174847687992, 0.17318197712302208, 0.14045851305127144, 0.22913212914552006, 0.1910122896411589, 0.1586007345467806, 0.1216996389308146, 0.15590248576232366, 0.1304194110312632, 0.18010998251182692, 0.10601929176066603, 0.16140687039920262, 0.23342296747224672, 0.159569736836212, 0.23084420870457376, 0.554721756705216, 12.234537465231758, 52.44781698499407, 94.42931924547467, 103.29624898093087, 79.17131832667759, 87.51757090432304, 81.7251078741891, 77.01313141414097, 55.47593920571463, 60.60787173679897, 56.290302821568076, 70.19641358511788, 79.56500325884137, 69.11423165457589, 69.46684578486851, 93.8536262512207, 87.02472128186906, 107.87493814740861, 94.10836110796247, 68.03380067007882, 51.79758719035557, 48.2389109475272, 44.13053492137364, 37.77087654386248, 43.059921741485596, 41.192621162959504, 26.47043057850429, 25.72407419340951, 26.683234793799265, 19.25883446420942, 19.598738602229528, 15.271153858729772, 20.588101284844534, 26.617442301341466, 34.566148485456196, 39.54516158785139, 48.41055924551827, 69.44197123391288, 77.70271927969796, 77.83361639295305, 77.35519123077393, 96.1909099306379, 113.69182409558977, 127.48928587777274, 129.7838589804513, 113.21454538617814, 127.04180799211774, 103.52950695582798, 108.23723806653703, 87.90739958626884, 63.652099881853374, 52.06749691282, 23.672531706946238, 56.07719462258475, 54.89457648141043, 67.66603251865932, 89.2469288962228, 96.28920609610421, 97.20113631657192, 94.90800843920026, 108.08929007393974, 119.02449008396694, 93.91021238054547, 52.502506256103516, 26.03935044152396, 2.8007202744483948, 0.09372569607304675, 0.5685213676520756, 0.12390174290963582, 0.10970375048262732, 0.3710252552160195, 0.07098076798553977, 0.08834569369043622, 0.21055761298963002, 0.15481183571474894, 0.1404217771653618, 0.27465222084096497, 0.18481607069926603, 0.14726208868835652, 0.12164698461336748, 0.11075328130807195, 0.12402963318995067, 0.1354401766189507, 0.12864656187593937, 0.1785801981708833, 0.09475951202745948, 0.1447082185851676, 0.14569308502333506, 0.11982671943094049, 0.15737781088267053, 0.17288008332252502, 0.13695005274244718, 0.1299393746469702, 0.05710645033312695, 0.1472691454525505, 0.10304752551019192, 0.13909087143838406, 0.145724229780691, 0.1558912085103137, 0.22986489268285887, 0.08731204058442797, 0.1595724102641855, 0.08687513867127043, 0.058517755674464364, 0.18453164239014896, 0.20932402275502682, 0.1693370041570493, 0.11895484264407839, 0.15675104808594498, 0.09387737579111542, 0.19437130939747604, 0.14040060687277997, 0.20244481760476316, 0.1924030285860811, 0.1471608919756753, 0.12940391552235397, 0.1546705647238663, 0.07574351384703602, 0.1142200795667512, 0.12045466287859849, 0.16437062993645668, 0.1461225976901395], [0.016758926079741547, 0.04651413531973958, 0.06361216266772576, 0.07495958198394094, 0.021392010684524263, 0.022029389161616564, 0.044799803024423976, 0.024253665968509655, 0.026454624919486896, 0.023309979820623994, 0.036466015569333515, 0.06277871810431991, 0.09950691621218409, 0.059472610508756976, 0.03702742526573794, 0.03555283635588629, 0.014693380666098424, 0.008878522153411592, 0.049234602733382156, 0.026585441382069672, 0.06464520509221724, 0.012979062789651965, 0.01910075738227793, 0.02073622864138867, 0.06385444716683455, 0.06814320239105395, 0.0592319273522922, 0.06370153930038214, 0.008980566186697354, 0.022300543629431298, 0.02002389748979892, 0.04955950565636158, 0.13428855341460022, 0.046165636341486654, 0.03135700310979571, 0.02450450849054115, 0.02839649884429361, 0.03595964863364186, 0.05141575015815241, 0.0409367606709046, 0.00850834313314408, 0.031555986896689446, 0.06297111670885767, 0.02335220335849694, 0.014872178036187376, 0.0718742696834462, 0.15267298477036612, 0.022033419659627334, 0.0691588878897684, 0.06910193166030304, 0.20790568100554602, 0.12265884317457676, 12.641562070165362, 44.87465224947248, 76.79968970162528, 83.37017726898193, 68.83059923989433, 68.94708578927177, 67.67751789093018, 40.886803150177, 28.03566517148699, 33.65986715044294, 35.17638097490583, 48.28752054486956, 33.843688692365376, 45.68977321897234, 75.38610649108887, 41.644552843911306, 39.30922508239746, 29.214010170527867, 17.870388099125453, 6.080293025289263, 2.9357059683118547, 0.6625482450638498, 0.5218612285596984, 0.23905252824936593, 0.420806709676981, 0.3045518121549061, 0.3408333238746439, 0.5551505365542003, 0.25575705617666245, 0.1892312302121094, 0.2156018151768616, 0.14301459517862114, 0.17859249322542123, 0.07712727745196649, 0.20649993286601134, 0.19169936063034193, 0.18766647417630467, 0.1280628317700965, 0.1880873151655708, 0.17347878191087926, 0.9847867510148457, 0.5607145237071174, 1.039239457675389, 1.4259417759520667, 4.12643699986594, 7.012363033635276, 18.718110016414098, 31.156653540475027, 30.692187309265137, 41.41284779139927, 57.880571774074006, 71.19666930607387, 92.9483871459961, 104.35705130440849, 106.69955308096749, 40.745779037475586, 32.27065474646432, 33.59320265906197, 25.820374488830566, 34.53790405818394, 46.87733847754342, 69.78872108459473, 72.47637462615967, 71.81553145817348, 76.95896325792584, 90.09823608398438, 82.40089661734444, 63.202273505074636, 30.053456783294678, 5.898038302149091, 0.15671937407127448, 0.06303911270307642, 0.018500426917203834, 0.02822700249297278, 0.024323203933558295, 0.10214710275509528, 0.013204717243622457, 0.11384323478809424, 0.053350117789315324, 0.0380379844323865, 0.06324536020734481, 0.03704539626570685, 0.0472120967959719, 0.03370426608515637, 0.03397365466558507, 0.025820131912561398, 0.006236797880514392, 0.03502984531223774, 0.01815435539798013, 0.07326999586075544, 0.011931078175881078, 0.09054860512592963, 0.021077884593978524, 0.04811452462204865, 0.04164266100685511, 0.02625554783402809, 0.039250044750847986, 0.012584481953776308, 0.038687970090125284, 0.05512729260538306, 0.02261904118183468, 0.042606821948928494, 0.04028527205809951, 0.06246530277920621, 0.047028827880110056, 0.016126809641718864, 0.017120057683704153, 0.02486209135635623, 0.02176262651171003, 0.04831494351050683, 0.01990423444658518, 0.04529129647250686, 0.058856962115636895, 0.011585902322881987, 0.0275011820652123, 0.037146504768835645, 0.028488180799675838, 0.02494953416420945, 0.0171268888350044, 0.03808779568810548, 0.025055331344317113, 0.007027102883772126, 0.026531857471647005, 0.02628224140166172, 0.03542381292209029, 0.08627340703138284, 0.019042946198689084, 0.03710836770811251, 0.08803364222071, 0.03512464343969311, 0.023774783093748347, 0.019219095585867763, 0.05086506810039282, 0.00788586019604866, 0.021884225076064467, 0.12768593270863804, 0.06788941672337906, 0.05401200155860611, 0.01676142817762281, 0.024723568432299153, 0.0449097867655967, 0.025894138030707836, 0.06215194173689399, 0.029557582523141588, 0.05447513563558459, 0.008105729290816401, 0.021192765661648343, 0.06656309789312737, 0.004411467434173184, 0.021232207205944827, 0.02912503680480378, 0.03815195117411869, 0.02155583957210183, 0.04881085761423622, 0.015746831727613295, 0.022341550893283317, 0.08486657323581831, 0.044814954711390395, 0.014652919622936418, 0.027035946226013557, 0.054710499077503166, 0.03216988466946142, 0.027197459612839987, 0.020942832376541834, 0.04245627877701606, 0.09539250377565622, 0.06103283393063715, 0.03157326239826424, 0.03987022575789264, 0.026633826017911946, 0.1016723250171968, 0.009658023182834898, 0.004101649192827088, 0.1450289213763816, 0.119173724470394, 0.8080236560532025, 20.976753984178814, 65.08276176452637, 97.17692879268101, 97.85931832449776, 84.19309411730084, 95.53029605320522, 91.62883390699113, 62.16065515790667, 41.11015994208199, 41.2000070980617, 25.09577465057373, 31.913086550576345, 26.63463040760585, 44.112636361803325, 82.5220593043736, 47.15892117364066, 47.871844564165386, 34.714530740465435, 22.062745264598302, 6.821103010858808, 3.6214406234877448, 0.43345367961696213, 0.3071921004780701, 0.23052423873117991, 0.30246466557894436, 0.42386619693466593, 0.31818580627441406, 0.41118996856468065, 0.35182143854243414, 0.3097362811011927, 0.2577336829687868, 0.10778011727545943, 0.28000132952417645, 0.2672710897667067, 0.1854085810482502, 0.27979329068745884, 0.290448434650898, 0.12758704301502022, 0.16865704421486172, 0.046492137214435, 0.7833096736243793, 0.30544546991586685, 0.6528656046305383, 0.8873576447367668, 2.8491898221629004, 6.809569435460227, 17.012492282049998, 31.61998721531459, 34.367089544023784, 46.2728590965271, 63.77229676927839, 70.18392072405133, 82.10299955095563, 69.96970081329346, 46.793300015585764, 19.919418811798096, 18.71038361958095, 29.681717736380442, 38.80442108426775, 57.155016558510916, 78.81953798021588, 109.45852988106864, 93.10178252628872, 87.27872657775879, 88.98586423056466, 106.63700539725167, 98.45914936065674, 79.97675350734166, 44.61218057359968, 12.697717411177498, 0.10002923889883927, 0.006543233624792525, 0.04293521932725396, 0.04453008874718632, 0.10520460190517561, 0.049706483126751015, 0.04747175518423319, 0.046116157567926815, 0.06696680587317262, 0.04174199514091015, 0.07377978600561619, 0.049255253946674724, 0.009058051493151911, 0.029634077168468918, 0.027510150601821284, 0.05927678530237504, 0.012357620555641395, 0.02916155895218253, 0.031123963650316, 0.06888239165501935, 0.016465821004073535, 0.05700609500386885, 0.04083425099296229, 0.035664601251482964, 0.04761058005637356, 0.027025520535452024, 0.012220794817299714, 0.028353111618863683, 0.05373979366517492, 0.03081609874165484, 0.019211166904174855, 0.051414186134934425, 0.04817432052056704, 0.02304700169978397, 0.042816869249301295, 0.04813623095729521, 0.027612807861130153, 0.04412624506013734, 0.08277344876634223, 0.04597683397254773, 0.03734692365729383, 0.01913717944574143, 0.004354082455392927, 0.004245577072392085, 0.06051600059228284, 0.08911889791488647, 0.017846726280237948, 0.03882736153900623, 0.045989305446190495, 0.03035193668412311, 0.015609767653846314, 0.05395539816735046, 0.034363045556736846, 0.03344034988965307, 0.14677807608885424, 0.20097243732639722, 0.1778603946524007, 0.14087692488517078, 0.09349145899925913, 0.10562501541738, 0.10316036588379315, 0.12203768507710525, 0.17611494474112988, 0.1284735490168844, 0.09341409922178302, 0.414190016154732, 0.21602561457880906, 0.16393829456397466, 0.10277672218424933, 0.1156263705343008, 0.12811117060482502, 0.10142170132270881, 0.17539522264684948, 0.08801909442991018, 0.17069155004407677, 0.052457691569413455, 0.11185448936053685, 0.11614585694457803, 0.15841601017330373, 0.15295655812535966, 0.1347871409463031, 0.11935300699302129, 0.1692232952586242, 0.09400350188038178, 0.20289252858076776, 0.13778724281915597, 0.19370866566896439, 0.1501893973244088, 0.09892119799873658, 0.09710359267358269, 0.12524772568472795, 0.07199125590601138, 0.14094116858073644, 0.09071856457740068, 0.14312326934720787, 0.1537448258272239, 0.11889481943632875, 0.1571773173553603, 0.11351888826383011, 0.07697308715432882, 0.23585613976631845, 0.09924121546958174, 0.14519532530435494, 0.15671387793762342, 0.21318357065320015, 0.8288520755512374, 22.470623629433767, 72.4250830241612, 106.46499579293388, 106.42375823429653, 87.96954427446637, 90.31374835968018, 94.11760221208844, 55.622535773685996, 36.17986413410732, 46.03214223044259, 52.44914756502424, 75.65727383749825, 52.98170266832624, 65.87890720367432, 100.89329092843192, 62.86033875601632, 62.318170819963726, 45.920370033809114, 29.642769609178814, 11.108041661126272, 4.6992968661444525, 1.0466058509690421, 1.2228028305939265, 0.6320529814277376, 0.6865683847240039, 0.6462051048874855, 0.7087541999561446, 0.895642557314464, 1.1916171440056391, 0.31037947801606997, 0.3889441436954907, 0.2656040106500898, 0.335336728819779, 0.20141978189349174, 0.46864524696554455, 0.2896537615784577, 0.3671935408243111, 0.3052282844270979, 0.6762309308562959, 0.5774773785046169, 1.8481865184647697, 0.8067698319043431, 1.8324119363512312, 2.5992309834275926, 6.085241879735674, 10.458796773638044, 25.653212990079606, 44.86992400033133, 45.728193283081055, 61.96154063088553, 88.17707306998116, 103.48462159293038, 134.44704518999373, 138.27131979806083, 145.84430040631975, 55.128011635371614, 46.519787652151926, 47.52016496658325, 33.024815695626394, 46.460634163447786, 64.79410580226353, 96.65986469813755, 95.24268926892961, 91.58986146109444, 96.19133377075195, 117.95716340201241, 109.99348558698381, 88.21792152949742, 47.47955969401768, 12.76367666040148, 0.26109590541039196, 0.144468451450978, 0.15437283712838376, 0.1403776995305504, 0.15786094138664858, 0.14265768575881208, 0.13086227726723465, 0.20719647620405468, 0.10425433396760907, 0.1520052384585142, 0.2232656375105892, 0.12189958963010993, 0.15105321311524936, 0.10458984917828015, 0.10410323100430624, 0.1753477794783456, 0.059513465102229796, 0.12352597021630832, 0.1799245796033314, 0.17813465850693838, 0.06320332496293954, 0.21398929027574404, 0.13606081902980804, 0.13186967106802122, 0.1611350221293313, 0.13104876583176, 0.12054726933794362, 0.13456626422703266, 0.14473635064704077, 0.15840105526149273, 0.12254630135638372, 0.15382645358996733, 0.1607962567359209, 0.1957922295800277, 0.11555498865033899, 0.1304256806948355, 0.11618587693997792, 0.10161234252154827, 0.17254123650491238, 0.19664680372391427, 0.12807024137250014, 0.12491554208099842, 0.14476571764264787, 0.09215270262211561, 0.19213979771094664, 0.14557755765105995, 0.20812396572104522, 0.14437238446303777, 0.07087535078504256, 0.08294029374207769, 0.09608207177370787, 0.07991552033594676, 0.13587013711886747, 0.08711424762649195], [0.05782291545931782, 0.02448495480764125, 0.03817464477781739, 0.0334535406104156, 0.03275498202336686, 0.04118537590173738, 0.0650035258648651, 0.05221759195306471, 0.013209507700854113, 0.04210556098925216, 0.0523739807041628, 0.06624461391142436, 0.028667171552245106, 0.010738730996048875, 0.09693986895893301, 0.025383862733308758, 0.05501386529899069, 0.058378845985446653, 0.03110975173435041, 0.020528831020263687, 0.012616256052362067, 0.058731487419988425, 0.05172651919669338, 0.00930728588718921, 0.057672077124672275, 0.013752274647621172, 0.02613170162242438, 0.044045227978910716, 0.03618949558585882, 0.06283696355032069, 0.013176777716060835, 0.02366152881378574, 0.03855993392478142, 0.08617641045046703, 0.018249058530532887, 0.03491322549858263, 0.07429799677005836, 0.02227206721103617, 0.027849789609068205, 0.04888524201565555, 0.03285447900582637, 0.0071091623644211465, 0.029615271570427076, 0.09088138584047556, 0.022154382097401788, 0.02993839673165764, 0.020699221341471587, 0.08060881349125079, 0.122776596141713, 0.09248127641954593, 9.554600766726903, 49.27532856804984, 77.50961494445801, 85.31912612915039, 67.11069774627686, 58.131943702697754, 51.80496270315987, 37.1000314440046, 36.99705566678728, 42.29782942363194, 49.64458015986851, 48.17339985711234, 53.96959406988961, 53.17440400804792, 45.444175243377686, 41.243235315595356, 17.331129721232823, 11.852407387324742, 2.259338136230196, 0.29515809193253517, 0.18660966945546015, 0.07666032322283302, 0.07122401600437504, 0.0475919339140611, 0.061144670072410784, 0.013708861128959273, 0.08633312489837408, 0.14632303693464824, 0.05807719645755632, 0.18888954711811884, 0.05596129696017929, 0.06453039696706192, 0.12715738107051167, 0.18392260292811052, 0.10483218796019043, 0.17598417747233594, 0.026643525676003525, 0.12389874378485338, 0.18420583701559476, 0.0363120016908007, 0.07957936730235815, 0.06563034294439213, 0.026620874480743493, 0.03992100731868829, 0.026920445995139222, 0.1783864764230592, 0.07627844371433769, 0.0846152710063117, 0.4219779154019696, 0.11187933731291975, 0.20791880387280667, 0.5668042397924832, 0.7691909883703504, 3.2165460756846835, 8.431248153959002, 25.3677236693246, 62.54076331002371, 94.4731137411935, 83.21139703478131, 50.624109404427664, 47.727183069501606, 34.5443902015686, 32.97113391331264, 19.27736704690116, 47.87772274017334, 60.40066255841936, 61.20626449584961, 57.30497258050101, 62.972850935799734, 74.92434310913086, 85.74456432887486, 72.398332459586, 21.821059124810354, 0.21361745308552468, 0.38382188283971375, 0.03503486307870064, 0.024728689675352404, 0.14240372367203236, 0.029173535095261674, 0.1195849302623953, 0.040950972586870193, 0.030973827599414756, 0.04216463424797569, 0.028937951129462038, 0.026378773186089735, 0.02433121743212853, 0.10063677879848651, 0.02968248724937439, 0.1027005294870053, 0.047480857731508355, 0.020020028143855076, 0.017529528122395277, 0.021111765543797185, 0.0705689922241228, 0.01194793128940676, 0.005161411478184164, 0.0404779556473451, 0.05545905551740101, 0.09749525665704693, 0.014641225071890014, 0.02785898375857089, 0.025778108542518954, 0.05355258924620492, 0.029936150780745914, 0.0419864577374288, 0.0303517399089677, 0.01001296569925866, 0.07180125253008944, 0.1067065866664052, 0.035208659645702155, 0.035606009752622673, 0.01485370152762958, 0.04821631844554629, 0.0445562530575054, 0.01272426949747439, 0.06193147213863475, 0.054622666112014225, 0.02901269176176616, 0.11248657187180859, 0.04996839425127421, 0.07294422441295215, 0.03138186802555408, 0.06558425006057535, 0.061669964742447646, 0.004989452044745641, 0.006357461762880641, 0.03643581736832857, 0.04776487213426402, 0.0514618430419692, 0.08465480245649815, 0.04420850725312318, 0.03806916650916849, 0.047420600429177284, 0.028049779324127094, 0.05852963003729071, 0.03027671089928065, 0.020117961103096604, 0.021584351613585438, 0.028086961346811483, 0.043167637927191596, 0.0441864073675658, 0.08380598228956972, 0.05747038259037903, 0.041954186611941884, 0.04473345587030053, 0.029675406736454794, 0.04039857044283833, 0.022663473351193324, 0.020819815673998425, 0.11249087378382683, 0.08345604142440216, 0.032224106402801614, 0.010141895834489592, 0.0331312330838825, 0.01903128557439361, 0.09050762161080327, 0.03940298315137625, 0.08457593633128063, 0.02562581983927105, 0.03877250198274851, 0.020021515831883465, 0.01993166931372668, 0.11308625433593988, 0.026639247512710944, 0.06733931481306042, 0.013397508550302258, 0.07375159966094152, 0.012507687056703227, 0.015424464829266071, 0.05085463901715619, 0.09061084035784006, 0.044655241138700924, 0.038718300605458875, 0.09156082331069879, 0.195695199072361, 0.03825999430513807, 15.50022554397583, 66.16769518171037, 93.9672292981829, 93.21227278028215, 77.4557386125837, 80.72103759220668, 79.71459797450474, 63.10828522273472, 51.686301367623464, 37.40547425406319, 26.78061900820051, 27.584122589656285, 47.040589877537315, 57.80822713034493, 56.881611892155235, 44.97188534055437, 22.255592516490392, 12.71992906502315, 2.878497975213187, 0.2077818483646427, 0.1758547808442797, 0.12093286721834115, 0.08259588972266231, 0.1089041241045509, 0.07339474452393395, 0.045179212665451426, 0.0616387114194887, 0.10088120068290404, 0.08070578971611601, 0.13324609292404993, 0.03368947741442493, 0.09247309328722102, 0.16682197339832783, 0.19971617045147078, 0.22590828713561806, 0.281660971896989, 0.1433826597141368, 0.2854301525013787, 0.25502554114375797, 0.19000591364290031, 0.17305471109492437, 0.15773993145142282, 0.12254875765315124, 0.03845451333160911, 0.10058618722749607, 0.08637958419110094, 0.057207511338804445, 0.06730819719710521, 0.53654944896698, 0.15576888221715177, 0.08082620932587556, 0.16778571025601455, 0.4855390318802425, 3.3193674726145606, 9.159339462007795, 26.91306209564209, 62.60008702959333, 70.37061882019043, 58.860045433044434, 36.10718250274658, 23.08667697225298, 21.786034992762975, 33.74726506641933, 33.60411480494908, 78.20833274296352, 90.32469872065953, 91.91133376530239, 74.12810039520264, 71.738267489842, 87.60115078517369, 95.35811969212124, 90.88457761492047, 35.32704223905291, 0.676885472876685, 0.3261126423520701, 0.047384383622556925, 0.04936976690909692, 0.12208672958825316, 0.03198952327615448, 0.0605917793831655, 0.021842457852991562, 0.0573032729859863, 0.05098191522327917, 0.019641466671600938, 0.026203017349221876, 0.010867660283111036, 0.07475826742925815, 0.04248401389590331, 0.07352232946349041, 0.04180377914703318, 0.025221375648730567, 0.0029749352210533936, 0.04433538990893534, 0.05755093148244279, 0.07757863216102123, 0.05249168278117265, 0.027138661160799007, 0.050144273920782974, 0.01821959314734808, 0.02753725807581629, 0.01802919282844024, 0.032670266926288605, 0.05274803331121802, 0.04032987895022545, 0.01574093695463879, 0.052500049117952585, 0.0011829857290389814, 0.11195960800562586, 0.14077880872147425, 0.05804002630923476, 0.013625117185126458, 0.03433737996965647, 0.04890397297484534, 0.09355551270501954, 0.03576367414955582, 0.029217829861279045, 0.008404524730784553, 0.03884658443608454, 0.04987862406830702, 0.05824815335550478, 0.018575525476730297, 0.06979316885450057, 0.04251001535781792, 0.04177698379914675, 0.019781448445948105, 0.032316641615969796, 0.13292335452777998, 0.17909360490739346, 0.16183303110301495, 0.16349696181714535, 0.13665039810751164, 0.09851392092449324, 0.14981129047061714, 0.12757624073752336, 0.107753321927573, 0.14024385171277182, 0.16513870443616593, 0.11760653927922249, 0.11196424239980322, 0.2274788785725832, 0.18191545563084738, 0.11772872986538069, 0.17925557121634483, 0.1525041652577264, 0.16759269418460981, 0.10809221624263696, 0.09183358081749507, 0.13921809675438063, 0.149855856650642, 0.14584408620638506, 0.11352422833442688, 0.09812865552625485, 0.1905185468494892, 0.12278745270201138, 0.1328583373022931, 0.19043995892362936, 0.1514502510960613, 0.20981689702187264, 0.14432046296341078, 0.18634483723768167, 0.10263843674744878, 0.10028035792389087, 0.2602229565382004, 0.1228840353765658, 0.17452189379504748, 0.08448389305600099, 0.14996305161288806, 0.12937271648219653, 0.16721166963023798, 0.13375185935625009, 0.17567156281854424, 0.10468660827193942, 0.27895953399794443, 0.19906287693551608, 0.2454009833080428, 0.17035043691950186, 17.066241809300013, 75.05390616825649, 105.9529413495745, 104.29004982539585, 82.98674092973981, 74.8087945665632, 71.81017439705985, 47.20330279214041, 49.29209804534912, 58.499218532017295, 69.94489574432373, 75.14505958557129, 81.85720702580043, 82.18808719090053, 70.4352718080793, 64.17001860482353, 29.94056245258876, 21.34068325587681, 4.957015539918627, 1.1483686247042246, 0.30551663466862267, 0.35302906802722384, 0.15377531919096196, 0.2760822469634669, 0.10929645305233342, 0.10112843170229878, 0.1469344784106527, 0.4049606371138777, 0.25016562906759127, 0.507759588105338, 0.1351993102580309, 0.3174444389130388, 0.30145372982536045, 0.36853277896131786, 0.3970768744392054, 0.6063223364097732, 0.22405727074614593, 0.5873964205384254, 0.5635806013430867, 0.38747397544128553, 0.275989721928324, 0.3739303893276623, 0.1963777510183198, 0.32807013445666855, 0.20515130380434649, 0.24680745069469723, 0.13126937113702297, 0.23974919372371264, 0.5599568443638938, 0.20579608849116734, 0.5683194356305259, 1.3714864637170519, 1.4631410198552268, 6.574412865298135, 13.99766457080841, 39.70349366324288, 87.70845876421247, 123.6492805480957, 113.61150291987828, 75.27976431165422, 72.02663162776402, 49.29490859167916, 45.44097907202584, 26.436806508472987, 64.41011360713414, 82.02742399488176, 82.43799999782017, 72.81498118809291, 78.98848342895508, 97.22393335614885, 109.34075096675328, 104.3608797618321, 39.25192676271711, 0.4731434998767716, 0.7636452945215362, 0.08565621836377041, 0.14915107589747223, 0.32149179173367365, 0.09552451276353427, 0.23706072941422462, 0.12898798712662288, 0.14371964734579834, 0.1955826436834676, 0.136101897539837, 0.16243071188884123, 0.14399837596075876, 0.25137222717915264, 0.13985085780067102, 0.18913934299988405, 0.21136907301843166, 0.13314839745206491, 0.08489457637603794, 0.09506522598011152, 0.1964806169271469, 0.18570500585649694, 0.13500429929367133, 0.07764927444181272, 0.15696315813277448, 0.11499740928411484, 0.07211151945271663, 0.1336420045367309, 0.08482975592570645, 0.13130317575165204, 0.08458256561841283, 0.08118334266224078, 0.19189769641629287, 0.07474124298564025, 0.18854419993502752, 0.1801429321723325, 0.1071966721543244, 0.15260510412710054, 0.11339983250945807, 0.09481379482895136, 0.15973692786480698, 0.13068279118410178, 0.09662988702101366, 0.10563515951590878, 0.07878659412797008, 0.12002885501299586, 0.1677385927843196, 0.14821806310542993, 0.13141320699027606, 0.14111597277224064, 0.08824383879878692, 0.08447205261992556, 0.11565476043948106], [0.040813009454203505, 0.049232543379600556, 0.05387553459565554, 0.07335135899484158, 0.08027344077293362, 0.0358934609352478, 0.048841388297400305, 0.03528037401182311, 0.09291989502630063, 0.039982893105064116, 0.02889167843386531, 0.031438878537820916, 0.03826485940122178, 0.03536899747060878, 0.03279026584433658, 0.015774514260036603, 0.04453706408717802, 0.03458005801907607, 0.04962437699681946, 0.011706575535104742, 0.04552413237148097, 0.05060775065794587, 0.02656472910062543, 0.00864792033098638, 0.04762622707390359, 0.01569379573421819, 0.034834525614444695, 0.051531742326915264, 0.010370556198592697, 0.03622892186311739, 0.0520562431109803, 0.04246113369507449, 0.025574083240436654, 0.025503030445958887, 0.024155520967074802, 0.06312638587717499, 0.034218504027064355, 0.061633635977549214, 0.0603658136512552, 0.0204272645059973, 0.045547151671988625, 0.05814200333718743, 0.05970152108264821, 0.05296388208600027, 0.057057941864643774, 0.11210870250527348, 0.05315285748136895, 0.033288347867450545, 1.7166623302868433, 26.217526572091238, 72.81650979178292, 80.94023936135429, 69.7432451248169, 61.169696126665386, 68.93593393053327, 43.54216841288975, 33.81683043071202, 54.389664786202566, 47.912689549582346, 39.79006126948765, 65.80711841583252, 62.13761493137905, 39.64471885136196, 17.781423364366802, 6.7994667547089715, 0.9785364121198654, 0.15261768416634627, 0.6019800922700337, 0.16379424157951558, 0.09197131664093051, 0.05152681616267987, 0.09917482760335718, 0.11210724365498338, 0.13825247356934206, 0.16481222052659306, 0.1598199669803892, 0.2288376178060259, 0.11079391198498861, 0.12622864304908685, 0.15579972841909953, 0.044788013478474956, 0.1345883844686406, 0.10403646994382143, 0.04067603698266404, 0.005002867106148707, 0.10381041600235871, 0.10301849778209414, 0.050128409772046974, 0.12449673669678823, 0.09540801508618252, 0.06342528055288962, 0.19869399815797806, 0.013224835806925381, 0.21914672638688767, 0.06845233616019998, 0.20983932938958916, 0.14633127434977464, 0.04288500773587397, 0.2881563976407051, 0.1819319033196994, 0.12617085900689873, 0.06068187526294163, 0.09154460632375308, 0.06790278386324644, 0.18430655875376292, 0.0024085800645739903, 0.24828307437045233, 7.344535997935703, 25.889364889689855, 48.50540910448347, 68.08342470441545, 66.61893899100167, 54.446431568690706, 56.450066225869314, 29.710580553327286, 32.8259721483503, 23.801617077418737, 52.769108636038645, 74.56250177110944, 66.72542708260673, 62.89051478249686, 71.32935210636684, 75.51018742152623, 53.55630479540144, 10.440223370279584, 0.3001341963452952, 0.08464254811406136, 0.11299427891416208, 0.09120679766471897, 0.1314664584185396, 0.10588018529649292, 0.026413867017254233, 0.020014080784416625, 0.01671664825906711, 0.025900266898263778, 0.04621478941823755, 0.06741130737853901, 0.021964969046946083, 0.012278802776043969, 0.07277986966073513, 0.031979898256914954, 0.06001532995807273, 0.048676982655056884, 0.05424434212701661, 0.08172589247780186, 0.0408397674826639, 0.014369470100583774, 0.03517205946679626, 0.08022174997521297, 0.01597815110082073, 0.045025039331189225, 0.048263340922338624, 0.05473114689812064, 0.05085870683459299, 0.02766968266639326, 0.03291652424793158, 0.040821477571236234, 0.02349079243971833, 0.05022158959348287, 0.03355282046166914, 0.001939041041103857, 0.016259710903146436, 0.018830130475440195, 0.047105977311730385, 0.04913252392517669, 0.06013751375888075, 0.0347579156181642, 0.01567811139726213, 0.06632949185690709, 0.0340936264422323, 0.048979500707771094, 0.03490444186276623, 0.013226037662077163, 0.032959713001868556, 0.09331617983324186, 0.057392161073429246, 0.07828348755304303, 0.024981842609122396, 0.03969095680596573, 0.07295109797269106, 0.07993065845221281, 0.0265690615467195, 0.04075852309220603, 0.05167104556624379, 0.07707122367407594, 0.03746546372505171, 0.01435675096165921, 0.029496867209672928, 0.03951809661728995, 0.018129118984299045, 0.04241919344557183, 0.026413958619481752, 0.04407587740570307, 0.08459249937108584, 0.026300541491114666, 0.019951611457924758, 0.022457780549302697, 0.03517067864803331, 0.07460922042706183, 0.018246359657496214, 0.013140136825053819, 0.0436349789212857, 0.010613323305733502, 0.02834843990526029, 0.018763315132153884, 0.049797888579113145, 0.02431764842809311, 0.018033698300964067, 0.012342694481568677, 0.03517969637843115, 0.058337434993258545, 0.04013496298076851, 0.01845776742058141, 0.057528010569512844, 0.0705335930521999, 0.041922831508730135, 0.09342965124441044, 0.08680545991020543, 0.040970541536808014, 0.09581637103110552, 0.023550432275182435, 0.0752325566219432, 0.024091665732807348, 0.07952260784804821, 4.611276652131762, 39.6826560156686, 89.12721838269914, 90.89090047563825, 81.87246526990617, 87.06386048453194, 101.81015436989921, 64.13742460523332, 44.55854395457676, 34.09459509168352, 32.83578647886004, 32.561482020786826, 57.12726197923933, 56.0224289212908, 42.70086315699986, 20.56230088642665, 7.1761859229632785, 1.0649658143520355, 0.06661365553736687, 0.5737302367176328, 0.0723188186862639, 0.03383708592238171, 0.27398258820176125, 0.10101264648671661, 0.16716464715344564, 0.016746495318199908, 0.15478115236120565, 0.2794303558766842, 0.19942326045462064, 0.1287381233913558, 0.1722185659621443, 0.185468319271292, 0.15832721708076342, 0.3582505578441279, 0.6115289255976677, 0.3027612939476967, 0.3593734790171896, 0.21631718107632228, 0.4480581688029425, 0.4775085970759392, 0.2581567902650152, 0.2094306070357561, 0.2814513317176274, 0.2967458910175732, 0.24253284292561667, 0.166885837114283, 0.11209858554814543, 0.10549501489315714, 0.3154317954821246, 0.1953598806368453, 0.23402482803378785, 0.24010784019316944, 0.11303020055804934, 0.06511125686977591, 0.08208918012678623, 0.11508112693471567, 0.19072248733469419, 0.32430461794137955, 0.28477428055235315, 8.558007614953176, 27.55596501486642, 48.308552742004395, 61.812870025634766, 53.43010466439383, 34.94578068596976, 35.91272326878139, 33.78568513052804, 45.19451257160732, 45.252964292253765, 88.82146985190255, 108.13114602225167, 89.98590455736432, 80.28143896375383, 79.8983152934483, 87.11893885476249, 70.80303301130022, 19.69282763344901, 0.11224301172686474, 0.23036348021456174, 0.011512796959972807, 0.04148418576057468, 0.15009660087525845, 0.04592773857127343, 0.049694055757884464, 0.05030406891767468, 0.020063866595072404, 0.030382240058055947, 0.03067331461768065, 0.024806673705045666, 0.03482099562617285, 0.014941113801406962, 0.059482171067169735, 0.016788474583466138, 0.07758739204811198, 0.0353690347900348, 0.030476841410355907, 0.016806096137900437, 0.04242539864831737, 0.03667920109416757, 0.03808386357767241, 0.04746267977835877, 0.0436629413494042, 0.011746424200412418, 0.04376855532505682, 0.03681402260969792, 0.02161330639916871, 0.07575974440468208, 0.02962194835501058, 0.004117556174086141, 0.030852743025336946, 0.037574124322938066, 0.034179949667304754, 0.007799150206015578, 0.03333996402631913, 0.02735836910349982, 0.04173730307125619, 0.024496895327631916, 0.050183581454413276, 0.06668625199901206, 0.03487809095531702, 0.014991727424785495, 0.06852588935622148, 0.03964792411508305, 0.03699858413477029, 0.04709041850375278, 0.05909845272877386, 0.0677056015868272, 0.015262227106307234, 0.1813030234937157, 0.1254679781517812, 0.16172960879547255, 0.17504607566765376, 0.18518524803221226, 0.08527358568140439, 0.10273248170103345, 0.1423934099397489, 0.1845956960959094, 0.12875550745853356, 0.14905808945851667, 0.12035950512758323, 0.11806281336716243, 0.1069766300331269, 0.12639063649943896, 0.11154589163405554, 0.15506415574678353, 0.15518175943621568, 0.13620593052889618, 0.1092142281787736, 0.09267923901123659, 0.15887947673244135, 0.1359411525939192, 0.06598939653486013, 0.10276803015066044, 0.11157258520168917, 0.11364678532949515, 0.15080013312399387, 0.10911117228014128, 0.09939569753727742, 0.10631391166576318, 0.14027696422168187, 0.15517148641603334, 0.1024292308304991, 0.08471764158457518, 0.13430470254804405, 0.1270353804741587, 0.16533121839165688, 0.17674785506512436, 0.11385274784905569, 0.22171461502356188, 0.24055412624563488, 0.099659478025777, 0.13949610612222127, 0.11326521794710841, 0.20322402007877827, 0.1637148122702326, 0.1784629337489605, 4.335084455353873, 43.32561043330601, 101.235093661717, 98.73408957890102, 84.00326238359723, 81.59150096348354, 90.95300347464425, 58.44327163696289, 41.40648324148995, 67.20279611860002, 67.20894527435303, 63.06634589603969, 93.32120663779122, 86.40746416364397, 57.537393297467915, 28.17432689666748, 11.654133592333112, 1.748533934354782, 0.4116088146609919, 0.9484502779585975, 0.5383781279836382, 0.18486757150718144, 0.6102697274514607, 0.23294470884970256, 0.3896849953702518, 0.4836168778794152, 0.5984216375010354, 0.7142857259937695, 0.49978235044649666, 0.3574150912463665, 0.4250402796481337, 0.6605325617960521, 0.5248995455248016, 0.29913243438516346, 0.42024653830698555, 0.3097645081579685, 0.32720147392579485, 0.2003178410232067, 0.32441114793930736, 0.38788584619760513, 0.2960236854851246, 0.3777369979236807, 0.5247617757746151, 0.49610154224293573, 0.49623437225818634, 0.5664263772112983, 0.360584664025477, 0.38666440173983574, 0.6598614635212081, 0.4609144532254764, 0.6773976853915623, 0.371729737413781, 0.21239079747881207, 0.24021507586751664, 0.38502791098185946, 0.2242209469633443, 0.343510768775429, 0.4514920174011162, 0.5630388047013963, 13.138137664113726, 40.30761521203177, 68.43412113189697, 99.28637409210205, 96.0424199785505, 79.52653108324323, 80.20270197732108, 42.12540292739868, 42.447017669677734, 34.85708345685686, 69.27421392713273, 96.38040815080915, 86.23446096692766, 80.00720051356724, 88.26571123940604, 99.58928080967495, 77.48991680145264, 20.825734887804302, 0.20007366341139587, 0.3165619634091854, 0.12471789840076651, 0.18350614527506487, 0.2458729451256139, 0.16237086510019644, 0.178957979327866, 0.21125241927802563, 0.10705928916909865, 0.11967076494225434, 0.14016411027738027, 0.14855657065553324, 0.12005702778697014, 0.07994244460548673, 0.12788903181041988, 0.09183743489640099, 0.16736173443496227, 0.1453507098236254, 0.23742846825293132, 0.21543727043483937, 0.10239565691777638, 0.11908413070653166, 0.1405058205127716, 0.20836442496095384, 0.10371149916734014, 0.1585392185619899, 0.10946529292102371, 0.15914466178842954, 0.12101412857217447, 0.11324216811252491, 0.1584750291492258, 0.17784425908965723, 0.15635251732809202, 0.12058880925178528, 0.21862270736268588, 0.10475538458142962, 0.09323660124625478, 0.11584834648030144, 0.13012700315032685, 0.07059373161090271, 0.13681541782404694, 0.08960410473602158, 0.0906205094818558, 0.11329317358987671, 0.11022937763482332, 0.09448618455124752, 0.07356633924479995, 0.09740955089884144, 0.17091580586774008, 0.2049672579658883, 0.15125479229858943], [0.018232429333563362, 0.017470592267013023, 0.046832565018641095, 0.010988939087837934, 0.034508883088294945, 0.05807581224611827, 0.017073664548141614, 0.04552420361765793, 0.07408543210476637, 0.02202263434550592, 0.04399893492726343, 0.09144984212304864, 0.02748995061431612, 0.019982247314016734, 0.01781177833410246, 0.026052340166643262, 0.04722333333588072, 0.03594629167179976, 0.07853480335325003, 0.048811773636511395, 0.032207719782101255, 0.009271147960264767, 0.041328061638133864, 0.040416704291211705, 0.012581261456944048, 0.00737825408577919, 0.01995578614462699, 0.04397105731602226, 0.03345697060493486, 0.06032404982085739, 0.029385014104523828, 0.019570334149258475, 0.03952244941943458, 0.04139617298330579, 0.047352227848023176, 0.03575650203440871, 0.052285825434539995, 0.08867931578840528, 0.048291493340262344, 0.09736716281622648, 0.07292583611394678, 0.03591048877154078, 0.04793363057875207, 0.04100313835910388, 0.1036326533981732, 0.09106619163815464, 0.7549846906747136, 24.036229951041086, 70.67376872471401, 79.24553203582764, 73.62819140298026, 67.53862340109688, 70.50481632777623, 47.578290121895925, 27.917175803865703, 34.11025980540684, 44.9415842464992, 65.3436666216169, 68.18765463147844, 44.28712994711739, 27.59177429335458, 10.517239809036255, 1.6758368866784232, 0.12233602335410458, 0.21311307086476258, 0.12474818820399897, 0.1087272639519402, 0.15566341073385306, 0.04867301322519779, 0.02793368707144899, 0.1460785743381296, 0.10595305317214557, 0.09605312546981232, 0.057300172080951076, 0.07567616924643517, 0.12864914030901023, 0.08263782997216497, 0.01563231197984091, 0.023720418868054236, 0.10857691416250807, 0.04575954670352595, 0.05898888289396252, 0.048889014670359235, 0.2633528214480196, 0.030127032859516994, 0.05665304984099098, 0.009424812393262982, 0.052408117800951004, 0.04396941865395222, 0.09663659094699792, 0.06484783600483622, 0.1273656234677349, 0.08427607813583952, 0.03340137144550681, 0.08911604128245797, 0.1045501616650394, 0.061801254483205934, 0.12219863358352866, 0.25741436438901083, 0.1955378060894353, 0.11216669010796718, 0.028732948736952882, 0.08461448390569005, 0.030197203558470522, 0.19488301979643957, 0.03617617255076766, 0.16426456134234155, 0.219434330239892, 0.09705128440899508, 1.2194557530539376, 13.142544559070043, 34.1176700592041, 57.443373748234336, 57.48447929109846, 60.82969992501395, 45.22120060239519, 46.27311965397426, 16.62742485318865, 20.051286935806274, 41.15180744443621, 45.864694118499756, 65.7358090536935, 61.98672090257917, 73.82787568228585, 65.49636023385185, 20.92417175429208, 2.5655055131231035, 0.3480533164526735, 0.05598135784800563, 0.07564491592347622, 0.0315261415338942, 0.029941904757704054, 0.10169989389500447, 0.024951259339494363, 0.01960602678757693, 0.01136753024599914, 0.046499292366206646, 0.0498593095690012, 0.0064909465644242504, 0.0241791679124747, 0.04325172198670251, 0.034071068545537334, 0.026879459087337767, 0.06338194252124854, 0.02444191533140838, 0.05728261838001864, 0.0009513813711237162, 0.05397960490414074, 0.049119475696768077, 0.015779618539714386, 0.009774240964491452, 0.012920549322318817, 0.04118926730006933, 0.09279420998479639, 0.01870386698283255, 0.03456542880407401, 0.008820698247291148, 0.02382497093640268, 0.04143111753676619, 0.058835859676556926, 0.06657767961067812, 0.058834679025624476, 0.012638217686409397, 0.03705595427059701, 0.049081911998135705, 0.04231911970834647, 0.022016308702794567, 0.03587808193905013, 0.030438358296773264, 0.04130728828853794, 0.02554015988217933, 0.011675492694069232, 0.012981993212763752, 0.02429075469262898, 0.07951260624187333, 0.019640533685950295, 0.021798252992864166, 0.03743893979117274, 0.037502698334200044, 0.06678726550723825, 0.03140185766720346, 0.042930540828300376, 0.005094423108468098, 0.015647519645946364, 0.04824078981099384, 0.10652862728706428, 0.07205024095518248, 0.06719302944839001, 0.020014457371351973, 0.10185132934046642, 0.050386164869580946, 0.01706803440382438, 0.06222586812717574, 0.023232648880886178, 0.0628922845103911, 0.0905437468151961, 0.0345898832061461, 0.03359449947518962, 0.028551030105778148, 0.033491945692471096, 0.053932955621608665, 0.042842388951352665, 0.05138579962242927, 0.09574148790644747, 0.04846268772546734, 0.008056959586351045, 0.011842970403709581, 0.01739034871570766, 0.014981325482949615, 0.04368032202390688, 0.04465216737506645, 0.03580386717138546, 0.016836218003715788, 0.12416092971605913, 0.049561812675424984, 0.04890447848343423, 0.054602018291396756, 0.0055003897619566745, 0.020385848424796547, 0.06503878254443407, 0.09592332850609507, 0.024256146014002816, 2.2896220769201006, 38.205583640507285, 92.00926167624337, 91.28872653416225, 81.92239502498082, 94.70079926082066, 101.80303246634347, 67.20869513920375, 43.29982566833496, 34.379995822906494, 25.345694405691965, 47.48340204783848, 66.23197991507394, 45.04243734904698, 31.082141058785574, 11.209183982440404, 1.945314952305385, 0.058701726874070506, 0.15852169878780842, 0.09146154006677014, 0.12102928704449109, 0.28458296081849505, 0.07855133925165449, 0.10314323965992246, 0.24331315819706234, 0.07161510323307343, 0.14932957131947788, 0.2713322304189205, 0.13875772431492805, 0.6083191835454532, 0.4367549153310912, 0.2809707117932183, 0.6259642967156002, 0.3596088763858591, 0.50824031659535, 0.5737113463027137, 1.2893588649375098, 1.5810738801956177, 0.7701839836580413, 1.3651767394372394, 0.6562775501183101, 1.2078150234052112, 0.9168230550629752, 0.6678951010107994, 0.6762990557721683, 0.8341380261949131, 0.5034837861146245, 0.4333120829292706, 0.4969361945986748, 0.6093760696905, 0.6010094614965575, 0.5736429499728339, 0.4113518941615309, 0.4046348045979227, 0.17266596481204033, 0.14865854089813574, 0.10754421779087611, 0.055124290087925534, 0.3122235733483519, 0.19265621714293957, 0.15452321405921662, 0.39539266909871784, 0.28757443172591074, 1.2766040350709642, 12.016300627163478, 33.92089360100882, 54.15178973334176, 45.46539504187447, 37.87886892046247, 34.52896172659737, 21.94816599573408, 20.29155043193272, 38.8516514641898, 71.18218231201172, 67.3416975566319, 81.1864904676165, 76.71602644239152, 81.90140451703752, 82.80939510890416, 40.04236078262329, 7.546692098890032, 0.06026583830160754, 0.22854856188808167, 0.06112562359443732, 0.007976174055199538, 0.08508955341364656, 0.10407930585954871, 0.05744546678449426, 0.04426451014088733, 0.03233849722892046, 0.0078419496504856, 0.04554328402238233, 0.0369381843400853, 0.04466543273468103, 0.05824296934796231, 0.02073773498913007, 0.07033274668667998, 0.03760963545313903, 0.025847502318876128, 0.015163281433550375, 0.03736211605636137, 0.043345749976911714, 0.057610527213130674, 0.040857154942516766, 0.01475029279078756, 0.02952624438330531, 0.022539598301851323, 0.07278956592615161, 0.06529399313564811, 0.05760600816990648, 0.044888565582888465, 0.02109823894820043, 0.08317250199615955, 0.02419741202278861, 0.048875284514256885, 0.04220860331718411, 0.05064733978360891, 0.007934358486506556, 0.01617661241575011, 0.06573417915829591, 0.016596298199146986, 0.03729359080482807, 0.017975853190624287, 0.01239344890096358, 0.04199768409931234, 0.03333849499800375, 0.013546100085867303, 0.012088749358164412, 0.10360703870121922, 0.048387278736169846, 0.08168866126132862, 0.09364149666258267, 0.13053766611431325, 0.1452050283551216, 0.102252465672791, 0.1304791085422039, 0.15744647862655775, 0.07604431520615305, 0.15281654920961174, 0.1646571752748319, 0.14122205493705614, 0.12360822223126888, 0.06821645024631705, 0.20731768969978603, 0.1236045445714678, 0.13421212323009968, 0.18334716452019556, 0.10718127619475126, 0.28258584226880756, 0.18171231581696443, 0.10933905826615435, 0.12116265988775662, 0.09869282346751009, 0.22665103870843137, 0.1762295357350792, 0.16490707972220012, 0.11806229768054825, 0.14550175171877655, 0.1700782086700201, 0.10477121480341468, 0.13347887114754745, 0.14583052907671246, 0.16404714515166624, 0.13362033212823526, 0.13518899652574742, 0.14977859865341867, 0.13003407099417277, 0.3173906717981611, 0.16209508132721695, 0.14007837059242384, 0.14980481724653924, 0.11635730202708926, 0.1315769917730774, 0.17959420090275152, 0.26146839399422916, 0.12159224040806293, 1.8794395157269068, 39.82742520741054, 102.12626266479492, 103.97852039337158, 88.45298603602818, 88.36259692055839, 89.6056157520839, 59.45431096213204, 34.832215854099815, 47.63561276027134, 62.69518007550921, 96.5553846359253, 94.65855421338762, 68.65533787863595, 41.98034885951451, 17.45644916806902, 4.053501324994223, 0.5116309289421354, 0.34567301560725483, 0.2147859310997384, 0.2831643612257072, 0.6576669184224946, 0.5583936082465308, 0.3828633028481688, 0.4740660903709275, 0.37331189108746393, 0.3948468012469155, 0.3175208419561386, 0.2508817549262728, 0.7082768912826265, 0.22156001760491303, 0.22710853415940488, 0.32606150795306477, 0.2534903149519648, 0.12082944491079875, 0.23580940227423394, 0.6395112755043166, 0.6826913441930498, 0.28738560900092125, 0.564040485237326, 0.4393426850438118, 0.7546554654836655, 0.381470976131303, 0.2692290432751179, 0.3973589007343565, 0.35291862966758863, 0.21501648372837476, 0.281453828726496, 0.2935664387685912, 0.43352736851998736, 0.48338237617697033, 0.2800837850996426, 0.6630833649209568, 0.4020442393209253, 0.34684905250157627, 0.21660053730010986, 0.4371503655399595, 0.20822911150753498, 0.32887645119002884, 0.25323689569319996, 0.22126435275588716, 0.6288267916866711, 0.3962557113596371, 3.0813686549663544, 20.188084806714738, 52.531111989702495, 83.85935824257987, 89.22895390646798, 82.05342415400914, 63.998752457754954, 65.83730139051164, 23.261983496802195, 26.76123353413173, 53.545951979500906, 63.73228209359305, 83.0287914276123, 80.24816404070172, 93.7586304800851, 93.10053879874093, 45.14408254623413, 6.1073844858578274, 0.3577664909618241, 0.2946846916207245, 0.29753388730543, 0.19226090264107498, 0.22280398942530155, 0.13229564178202832, 0.1731711205627237, 0.0868538191009845, 0.12999690084585122, 0.10638477786311082, 0.1206619960388967, 0.14827936195901462, 0.1368361267128161, 0.17444608786276408, 0.1406019010714122, 0.12093038378017289, 0.09845708683133125, 0.1273745394178799, 0.09398172090628318, 0.08294614271393844, 0.18696815307651246, 0.17528885549732617, 0.1028508385643363, 0.049063184431621006, 0.08720041478851012, 0.1307443343102932, 0.1909380443394184, 0.12756972680134432, 0.11751995821084295, 0.1504393560545785, 0.1489815642791135, 0.15616199826555593, 0.09164960283253874, 0.14703781929399284, 0.14773381980402128, 0.09857839532196522, 0.07365092542022467, 0.11877162461834294, 0.1436558650540454, 0.1409178405467953, 0.14512880173112663, 0.09498276361929518, 0.11148359533399343, 0.1283284103763955, 0.10104688536375761, 0.1387757190636226, 0.08856139997286455, 0.26143186166882515, 0.13237401257668222], [0.08270072338304349, 0.032952493389270136, 0.04443723462255938, 0.039284127564834695, 0.011717633959571165, 0.07176340384674923, 0.03702882304787636, 0.010517730444137539, 0.0464845545856016, 0.041929511685988734, 0.03554688560377274, 0.04023154565532293, 0.05531380831130913, 0.04938889820394771, 0.044078510121575425, 0.014088828865039562, 0.022467259683513215, 0.015157303540036082, 0.016523364166330014, 0.015303127500893814, 0.014432980978329266, 0.02831780065649322, 0.05590934492647648, 0.03892643782975418, 0.04266757118914809, 0.029475842802120105, 0.021478685051468865, 0.028681841479348283, 0.0035225515727818546, 0.023225302042971765, 0.019408730856542076, 0.04893457829686148, 0.044725489869181595, 0.08827738557010889, 0.03316685617236154, 0.08605058291660887, 0.03648256164576326, 0.012109554090004946, 0.0662532855889627, 0.038419762160629034, 0.05907868700368064, 0.11834868017051901, 0.0338001905807427, 0.10979771401200976, 0.03144259351704802, 13.545067599841527, 72.07534544808524, 82.76489884512765, 74.07910169873918, 65.13203144073486, 64.00327573503766, 43.49767214911324, 33.984806605747764, 38.76330164500645, 48.72416271482195, 57.016139439174104, 67.28726536887032, 42.31426191329956, 16.843149048941477, 4.3241801261901855, 0.2271750441619328, 0.24315818079880305, 0.21062330875013555, 0.028249735112435052, 0.05870980822614261, 0.05336193447666509, 0.02857521648651787, 0.1386438797094992, 0.07768899588180439, 0.09218387452087232, 0.09018257619546992, 0.25597554445266724, 0.4356355225401265, 0.09864715806075505, 0.09947509970515966, 0.12885004095733166, 0.16667498914258821, 0.12367059317018304, 0.012971412307316703, 0.1768846341541835, 0.3214751811964171, 1.2401662703071321, 1.4296971687248774, 1.2120693836893355, 0.6640772287334714, 0.42423024454287117, 0.9135874743972505, 0.6451733516795295, 0.6435957306197712, 0.15251310834927218, 0.2862781584262848, 0.30887861283762114, 0.9186935318367822, 0.10236632384892021, 0.10728971287608147, 0.2815717038299356, 0.11087907491517918, 0.07819818891584873, 0.05259083371077265, 0.20087115918951376, 0.10555403386907918, 0.08086103852838278, 0.07720321230590343, 0.10451924760958978, 0.05183220441852297, 0.07686659786850214, 0.0639625581513558, 0.13411499772753033, 0.03923011278467519, 0.041808345687708685, 0.1045800850593618, 0.9295952554259981, 12.399846400533404, 44.85478387560163, 65.26363727024624, 56.93382065636771, 74.4945900780814, 77.81470339638847, 47.472232818603516, 23.434978008270264, 31.947337695530482, 43.26908336366926, 53.93058688299996, 72.96643802097866, 70.53782027108329, 87.07264300755092, 67.155319077628, 26.537565810339792, 1.388619418655123, 0.528229686830725, 0.03744671240981136, 0.042596603211547644, 0.10810469450162989, 0.033148074323045354, 0.012466593279636331, 0.04586147623402732, 0.027047459268942475, 0.04370304276900632, 0.06190703809261322, 0.07338956051639148, 0.0690802660371576, 0.024483462030600225, 0.05594577547162771, 0.020175543281116655, 0.04531023438487734, 0.021179820909830074, 0.017326749628409743, 0.011091907625086606, 0.02445165909427617, 0.06929601303168706, 0.07359491235443524, 0.05235065606289676, 0.07532787722136293, 0.03808449800791485, 0.05071220433871661, 0.009300171447518681, 0.004339176313286381, 0.042208800092339516, 0.01784096721426717, 0.019537493054355894, 0.01598455647139677, 0.021628010253022825, 0.03551411236237202, 0.022459548133026277, 0.06944381831479923, 0.0632551039702126, 0.02377575509516256, 0.03026793404881443, 0.018039226665028503, 0.0865514435406242, 0.0247310000870909, 0.026637259405106306, 0.0410487121636314, 0.032854930231613774, 0.021026434676189507, 0.017548656024570976, 0.08072921953030995, 0.03809268453291484, 0.015821825114211867, 0.01949211602498378, 0.017267640746597732, 0.029930844636900083, 0.056539541110396385, 0.017847379370193397, 0.017427449314189807, 0.0389552959240973, 0.007277595112100244, 0.03646258218213916, 0.03901743955378022, 0.07910412816064698, 0.04154549139950957, 0.006912007653487048, 0.024494167616856948, 0.03273290588653513, 0.0396440327167511, 0.019671188201755285, 0.03340104574869786, 0.016347849209393774, 0.020171592510970573, 0.005636584886815399, 0.06047760908092771, 0.045387217575418096, 0.02827024892238634, 0.06134659530861037, 0.010342680283689072, 0.040237784784819396, 0.041266101212905984, 0.0780069302501423, 0.013210693440799202, 0.03392611650217857, 0.048508088503565104, 0.10257118035640035, 0.02563708182424307, 0.06805476213672332, 0.03216262095208679, 0.011694308470136352, 0.030118442606180906, 0.1483873983046838, 0.0760261168969529, 0.08367634138890676, 0.04150146126214947, 22.472497906003678, 93.00325012207031, 95.91319738115583, 80.62645871298653, 85.54501206534249, 96.81817245483398, 70.18106501443046, 44.731043406895225, 37.34618527548653, 18.244996752057755, 31.45500918797084, 57.56625958851406, 45.47783579145159, 18.52194673674447, 5.219642681734903, 0.08873112872242928, 0.31498303956219126, 0.31730821622269495, 0.02510183474182018, 0.08711480402520724, 0.11083316523581743, 0.19634830259851047, 0.3212655410170555, 0.2339060301227229, 0.3949932562453406, 0.35648172561611446, 1.3001132650034768, 1.088561462504523, 1.0570591986179352, 1.5712952677692686, 1.1547910400799342, 2.1826580337115695, 1.8301107798303877, 1.119889804295131, 2.1414289431912557, 3.4854294189385007, 5.0388001799583435, 7.36338038103921, 5.6895285078457425, 4.677804785115378, 4.812743578638349, 5.973916973386492, 2.457161818231855, 5.732052786009652, 4.043564532484327, 1.7130920418671198, 2.4802977996213094, 2.998161805527551, 1.6165370515414645, 1.5550451683146613, 1.6304704695940018, 1.1261806381600243, 0.8436488072787012, 0.3980560818953173, 0.9418845559869493, 1.447181224822998, 0.6653022287147385, 0.6997227902923311, 0.4342571465032441, 0.38245819030063494, 0.3927273835454668, 0.10406849001135145, 0.1806435960211924, 0.15351964719593525, 0.12494513977851186, 0.16843418617333683, 0.4277954032378537, 11.011390481676374, 37.27764824458531, 51.28610944747925, 40.1478031703404, 60.47166619982038, 46.78064387185233, 24.954519510269165, 21.296617780412944, 52.76127454212734, 77.88680485316685, 77.05546678815568, 90.53340176173619, 80.59315599714006, 98.85398074558803, 89.03876086643764, 45.72450726372855, 5.10916371856417, 0.3609022726970059, 0.05623861082962581, 0.055462580506822894, 0.10433729165898901, 0.011124583327078393, 0.06718712619372777, 0.0835661201604775, 0.02887426722528679, 0.044132348482630084, 0.023998423146882226, 0.07535878449146237, 0.061717801461262364, 0.013936242454552224, 0.007696414915179568, 0.054430077517671246, 0.05678292822891048, 0.05624395768557276, 0.007053549210208335, 0.01860061430904482, 0.023475615307688713, 0.03593913991270321, 0.027540633787534068, 0.03923399739765695, 0.009535975089030606, 0.036002440444592915, 0.051942242442497184, 0.030234913142131906, 0.015609245181881955, 0.03161868013973747, 0.01758027745277754, 0.025755587965250015, 0.057709939378712855, 0.01882045965508691, 0.04121828485014183, 0.017189478601462076, 0.027314771532214115, 0.02421829054531242, 0.025151430562670742, 0.07157759381724255, 0.010866705245072288, 0.04976416538868632, 0.0551994649826416, 0.07239652451659952, 0.030134374608418772, 0.04601031967571803, 0.03575687862134405, 0.035504280389951806, 0.2744553642613547, 0.0743635907503111, 0.13176270680768148, 0.10990241875073739, 0.08175317637090172, 0.18763747358960764, 0.0976633501372167, 0.0701829736520137, 0.10391028957175356, 0.12386297141867024, 0.15202581164027962, 0.14232733419963292, 0.15124884833182606, 0.15359606380973542, 0.13347165153494903, 0.06117590982466936, 0.09239264617541007, 0.15437264713857854, 0.15561330770807608, 0.10595688689500093, 0.17170716768928937, 0.12310652700918061, 0.09312357766819851, 0.1103356701454946, 0.10998417543513433, 0.14583747727530344, 0.1243151742964983, 0.15406312660447188, 0.1070012269275529, 0.12905491782086237, 0.12302115373313427, 0.13115454944116728, 0.062178866006433964, 0.149993504264525, 0.16378649270960263, 0.16540182674569742, 0.08495707623660564, 0.21153259995792592, 0.18639636518699781, 0.1354202955429043, 0.16693366026239737, 0.2981866922761713, 0.14317802712321281, 0.15917647151010378, 0.08882049856973545, 22.56346719605582, 103.90978881290981, 108.04138919285366, 89.94639015197754, 83.54309013911656, 84.45217159816197, 58.22182559967041, 43.61301919392177, 51.880684171404155, 68.67488316127232, 80.16764831542969, 96.78343146187919, 60.64776134490967, 27.820786918912614, 8.068315948758807, 0.7216494051473481, 0.5467649836625371, 0.5786578123058591, 0.1191875801554748, 0.21847109549811908, 0.27936524365629467, 0.22764590675277369, 0.23032347378986223, 0.236679202743939, 0.22047999341573032, 0.2741736908044134, 0.4869394195931298, 0.6914806525622095, 0.46825679923806873, 0.32808875345758026, 0.320890094020537, 0.5952232405543327, 0.44284834978835924, 0.35053944161960054, 1.0688422577721732, 2.270607680082321, 3.5366843257631575, 4.721014763627734, 3.196629498686109, 3.8781023025512695, 2.1809333605425696, 2.979150882789067, 2.080232249838965, 3.033230232340949, 2.004242407424109, 0.9961566094841275, 1.2582382091454096, 1.526155861360686, 0.3087022751569748, 0.42411815055779045, 0.4968869058149201, 0.34057197932686123, 0.21865632198750973, 0.20788769982755184, 0.3006620423070022, 0.2716698965856007, 0.2802442450608526, 0.41044178871171816, 0.36983431769268854, 0.2242068470056568, 0.34158215512122425, 0.20824500279767172, 0.5603993577616555, 0.3122304401227406, 0.25320619876895634, 0.3536752776375839, 1.5322313010692596, 19.406405517033168, 65.66438852037702, 94.25131334577287, 82.92800085885185, 101.42577307564872, 102.953355380467, 62.56824343545096, 31.74821969441005, 44.19824511664254, 56.425386224474224, 70.5445669719151, 91.3949783870152, 84.84543269021171, 110.52039527893066, 98.3048437663487, 45.680327142987935, 3.732678243092128, 0.5236972900373595, 0.2824939957686833, 0.173986570377435, 0.16992043570748397, 0.11368709709495306, 0.11570243430989129, 0.12390848754772119, 0.1120531711993473, 0.10785790452999727, 0.08910359695021595, 0.16417746458734783, 0.18042710263814243, 0.19899011084011622, 0.12945602701178618, 0.22142230213752814, 0.20983171622667993, 0.11033250817230769, 0.07143455184996128, 0.16053985192307405, 0.12905102302985533, 0.11221940549356596, 0.20260130135076387, 0.1025167889893055, 0.2020074882145439, 0.09603273549250194, 0.16124090073364122, 0.08883702089743954, 0.0657204727509192, 0.16412571950682572, 0.06931242679378816, 0.14867454075387546, 0.07650531189782278, 0.18706480360456876, 0.09817271959036589, 0.08132537361234426, 0.12162582789148603, 0.23721033281513623, 0.09267799050680228, 0.23714294071708406, 0.12793282446052345, 0.18082327209413052, 0.13070398861808435, 0.23092319018074445, 0.16479364223778248, 0.18511601031890937, 0.18367955168443068, 0.09262450159128223], [0.008991392212919891, 0.08645652327686548, 0.027315850402893763, 0.03263375834961023, 0.013108427187294831, 0.02060336130671203, 0.05184768858764853, 0.024038100482097695, 0.009147987917198666, 0.010782655960481082, 0.031416856683790684, 0.035259712620505264, 0.012738679036764162, 0.031222469971648285, 0.025024252744125466, 0.126304367557168, 0.046384016051888466, 0.043791642479066334, 0.015684026526287198, 0.04646715694772346, 0.02820619860930102, 0.03250023962131568, 0.08028952205287558, 0.07568720901118857, 0.07101858952747923, 0.10200922443930592, 0.04841488832607865, 0.03285262660522546, 0.031316192621099095, 0.048178876883217266, 0.013621459881375943, 0.04898600107324975, 0.026746115081810524, 0.10031217443091528, 0.06374254317155906, 0.020731872446568947, 0.058152133865015845, 0.03088927535074098, 0.05287012890247362, 0.09304728997605187, 0.09653228654393128, 0.06423725626830544, 0.21019907508577618, 5.393278164522989, 38.599536078316824, 90.35482610974992, 69.16989367348808, 71.66896615709577, 72.71354443686349, 49.91061626161848, 32.64110490253994, 41.94395766939436, 51.581786564418245, 44.6552072933742, 68.32599326542446, 59.84273610796247, 32.5322961126055, 6.454768793923514, 0.16784109228423663, 0.20953309296497277, 0.04807451480467405, 0.12355221595082964, 0.07738924625196628, 0.07417414377310447, 0.07797917816787958, 0.02179731661453843, 0.08494044534329857, 0.20453238487243652, 0.1567836177668401, 0.03503656280892236, 0.06851231187049832, 0.11020892658936125, 0.3316506551844733, 0.40708817009414944, 0.45352718819464954, 0.9560962276799339, 2.0643260862146104, 1.5317125746182032, 3.3107382442270006, 1.621331308569227, 10.08305035318647, 7.953651564461844, 5.441650654588427, 8.197677510125295, 4.953385540417262, 7.629670092037745, 1.7131957220179694, 3.270924197775977, 4.544285595417023, 3.6145703749997273, 4.720805449145181, 4.850657727037158, 1.5537763621125902, 2.1553731092384885, 1.2171803265810013, 1.565874261515481, 2.2038393999849046, 1.7023719485316957, 0.7914717985051019, 0.5845758861729077, 0.33657535378422054, 0.09850326792470046, 0.10818573193890707, 0.050160477337028296, 0.15247637246336254, 0.0850958095065185, 0.01557959829057966, 0.10827510178621326, 0.07920613911535059, 0.06780231318303517, 0.07030707092157432, 0.19632151403597423, 0.285126087388822, 0.5067131785409791, 16.85383016722543, 56.47842877251761, 48.27700097220284, 51.80293730327061, 70.46862316131592, 73.19185147966657, 38.64016566957746, 20.833897284099034, 33.910308020455496, 42.68871423176357, 50.98795182364327, 56.01371240615845, 65.33295249938965, 77.51596559797014, 59.93104771205357, 10.009881479399544, 0.1011710437014699, 0.04654584665383611, 0.018043855970193232, 0.04124504287860223, 0.05687069334089756, 0.023018097804327096, 0.03618738194927573, 0.013263257004187574, 0.03975959062310202, 0.03227500670722552, 0.11518847117466585, 0.037551956583878825, 0.09846963972917624, 0.017230655499068753, 0.05459590129820364, 0.010079933712924165, 0.021600571993206228, 0.03330547409132123, 0.03647021230842386, 0.02449343988804945, 0.017461226787418127, 0.02250138490593859, 0.02091133817365127, 0.015420432634917753, 0.07081851669188056, 0.04253679034965379, 0.02969280437433294, 0.016911849213231887, 0.056524141758148155, 0.02842089387455157, 0.035293259391827245, 0.07236843995217766, 0.02495011600798794, 0.027098788746765683, 0.022777394291811755, 0.02388805433708642, 0.02166769267725093, 0.03813461460439222, 0.02270787668281368, 0.1023127602945481, 0.008378298504145017, 0.016264933926452483, 0.06213919884924378, 0.027076093446729437, 0.04474787134677172, 0.020204611721315553, 0.023357231302985122, 0.030390714960438863, 0.045001429705215354, 0.02982079643490059, 0.059405428756560595, 0.027729103674313853, 0.018980157960738455, 0.023777471788759743, 0.00979720174135374, 0.02776728823248829, 0.0030588803929276764, 0.02078019771059709, 0.023828446732035706, 0.02427368444789733, 0.038607085323227305, 0.061022255569696426, 0.015719591939289655, 0.01561156746798328, 0.016196113512186066, 0.03685804256903274, 0.042575914678829055, 0.022296567414222018, 0.029524375019328933, 0.09303580237818615, 0.06358292459377221, 0.037561405184013505, 0.0382491377448397, 0.01195686505109604, 0.018299202268411006, 0.043382438365370035, 0.05497545003890991, 0.016863172807331597, 0.05150548302169357, 0.03554710273497871, 0.053600582028073926, 0.025275619434458867, 0.026619179839534417, 0.06569083434130464, 0.005842782773210534, 0.1036273268982768, 0.20163812089179242, 0.120547282908644, 0.32273459647383007, 11.760874424661909, 57.70621715273176, 107.26048115321568, 74.91858305249895, 95.38986601148332, 106.42065238952637, 68.24912534441266, 41.668819427490234, 30.913126128060476, 28.041036128997803, 28.90258843558175, 57.3703099659511, 61.64350768498012, 36.38749715260097, 7.509079762867518, 0.17577563651970454, 0.29144305842263357, 0.0344443476226713, 0.22232118461813244, 0.10657653185938086, 0.1058048882654735, 0.08324821971889053, 0.2921154594847134, 0.8981558510235378, 0.8755852792944226, 0.8472893376435552, 1.1971572467258997, 1.5947633513382502, 1.0346033807311739, 2.4048627274377004, 3.347327240875789, 3.013597445828574, 3.059896550008229, 5.300777230943952, 7.175245310579028, 5.017561273915427, 4.59016889333725, 6.598792791366577, 11.178906338555471, 7.735794271741595, 8.923023411205836, 8.5455208335604, 13.663294672966003, 8.909659419740949, 7.431133134024484, 10.143960867609296, 8.790732315608434, 7.669607469013759, 11.626577036721365, 8.52013645853315, 6.355514211314065, 7.654021791049412, 6.654035747051239, 4.8272514172962735, 8.373744862420217, 6.112411941800799, 4.3450294988495965, 2.491403409412929, 2.5767744055816104, 1.1062752434185572, 0.3176383642213685, 0.5506304619567735, 0.414437437163932, 0.12017773916678769, 0.37623987825853483, 0.23887184794460023, 0.15772318520716258, 0.042398491342152865, 0.1742422559431621, 0.49390911417348043, 0.5827715801341193, 14.070098672594343, 49.22720187050955, 46.016338552747456, 44.02366815294538, 59.637257031032014, 41.2167592048645, 21.84783227103097, 19.884335620062693, 58.75865037100655, 74.77948011670793, 74.39300046648297, 68.50078909737724, 73.17131955283028, 87.17625454493931, 80.57063688550676, 22.762812750680105, 0.09676353806363684, 0.06383059666092906, 0.11795232072472572, 0.0491352787773524, 0.04626666681308832, 0.030953851528465748, 0.03039747995457479, 0.07413102965801954, 0.05562464181067688, 0.022693739405700138, 0.04376614313306553, 0.024683200687702214, 0.051557129714637995, 0.0701780610584787, 0.029961097120706524, 0.030707662060324634, 0.02011520116190825, 0.027031388167025786, 0.06941690083060946, 0.014926248795485922, 0.020612801425158978, 0.034245784527489116, 0.011783326327401613, 0.045363533310592175, 0.010067673433305961, 0.060040571460766454, 0.035667729297918935, 0.024206736790282384, 0.033221820901547156, 0.015812993980944157, 0.03520131450412529, 0.010118900282707597, 0.07459438086620399, 0.05349168394293104, 0.04112999726619039, 0.02863316676978554, 0.022041836886533668, 0.017187958683020303, 0.033170618649039946, 0.03747492250321167, 0.08446121641567775, 0.03821848492537226, 0.044511948113462756, 0.020103457417072992, 0.013721676959123994, 0.054920956891562255, 0.14454615728131362, 0.1871213120009218, 0.1464513207652739, 0.15635852914835724, 0.1454338032220091, 0.1114678465362106, 0.11162823185856853, 0.129284534071173, 0.0761446976768119, 0.07443936275584356, 0.12989392637142114, 0.06055356429091521, 0.09477763569780759, 0.1421641329569476, 0.18102869178567613, 0.2520593660218375, 0.11823429273707525, 0.10111971252730914, 0.08756127328212772, 0.14896096395594732, 0.09827781109405415, 0.10975221823900938, 0.12176428974739142, 0.15249047242105007, 0.1410980187356472, 0.1605398112109729, 0.14172518865338393, 0.09437998703547887, 0.08504847490361758, 0.11117390516613211, 0.10758279929203646, 0.19774555547961167, 0.15940357718084538, 0.15611983409949712, 0.08681250988904919, 0.12619985959359578, 0.1544711161404848, 0.11664249029542718, 0.19102885946631432, 0.21452042034694127, 0.3046319064285074, 0.24693053694708006, 0.4841145968862942, 12.949356845446996, 62.81269495827811, 121.57336725507463, 84.01268414088658, 89.40493093218122, 93.63559872763497, 69.23877116612026, 40.092624051230295, 54.28819676807949, 71.86689254215786, 65.17233794076103, 99.97866480691093, 88.75680991581508, 48.69752679552351, 11.995945879391261, 0.38594170766217367, 0.3514187144381659, 0.06888409477791615, 0.38973536981003626, 0.46265959101063864, 0.21444036678544112, 0.19357046165636607, 0.14354819511728628, 0.5400846164141382, 0.7436231374740601, 0.2825974316469261, 0.39323718047567774, 0.5178379501615251, 0.2777760332184178, 0.9211515656539372, 1.8288970163890292, 1.7233954604182924, 2.4297038401876176, 3.441886361156191, 7.892996396337237, 10.820037092481341, 6.4773847460746765, 24.352272238050187, 17.062875407082693, 13.3697714975902, 20.989608151572092, 17.784755025591167, 25.119428055627004, 10.235770889690944, 14.042526483535767, 17.295680012021744, 12.095780202320643, 12.595642294202532, 11.681258491107396, 8.903347849845886, 6.288342067173549, 6.9540641733578274, 5.891466609069279, 4.872177600860596, 6.003174100603376, 3.109625675848552, 1.2502577688012804, 1.1093468900237764, 0.8378479299800736, 0.4754210433789662, 0.17094612281237329, 0.5306688302329609, 0.3540527873805591, 0.24561219768864767, 0.2241253006671156, 0.14679372310638428, 0.3995508945413998, 0.23444397268550737, 0.32827554057751385, 0.7461667752691677, 1.5723436857972826, 24.872403962271555, 81.00340543474469, 63.894960267203196, 75.21787670680455, 102.43337304251534, 110.47252219063895, 52.11600228718349, 28.22172055925642, 48.350193296160015, 57.39654288973127, 69.81593717847551, 70.3832436970302, 81.4718599319458, 100.11224392482212, 90.82705347878593, 19.803086859839304, 0.2060400896838733, 0.18108395167759486, 0.1596112088965518, 0.18842127653104918, 0.12984771813665116, 0.09913664643785783, 0.18883778846689633, 0.12476511086736407, 0.1242520162569625, 0.16847504755215986, 0.2117342741361686, 0.248078211077622, 0.20918021404317447, 0.11091025359928608, 0.1288585633571659, 0.08208609279245138, 0.17305538962994302, 0.12933644200009958, 0.22666524723172188, 0.09038940045450415, 0.1268940009176731, 0.12015532036977154, 0.08960779596652303, 0.12324402534535953, 0.13987974982176507, 0.16944377842758382, 0.18327651545405388, 0.08700580415981156, 0.14933993933456285, 0.10388297853725297, 0.15533276061926568, 0.21818012611142226, 0.22662209240453585, 0.14348790049552917, 0.12627476985965455, 0.06790664472750255, 0.06487059406936169, 0.12401393188961915, 0.10788373635815722, 0.1973036934754678, 0.10822619298206908, 0.09190062007733754, 0.08787986582943372, 0.10073149550173964, 0.1424938059811081, 0.06748325923191649], [0.027243688203660504, 0.049614348249243836, 0.08083613629319839, 0.022639292059466243, 0.010382181199799691, 0.039076919933514934, 0.03622406015970877, 0.0617453431976693, 0.001991611813926803, 0.018195072588111674, 0.06247586078409638, 0.03321646047489984, 0.035366157801555734, 0.025389073882251978, 0.04436004108616284, 0.05930974853358098, 0.013610576179676821, 0.02966256546122687, 0.027465750662876025, 0.01717139733955264, 0.04137566426236715, 0.015403394620599491, 0.049072687314557176, 0.1344801445624658, 0.0495482012629509, 0.06752216642988579, 0.024500832527077625, 0.030471189213650565, 0.05701047834008932, 0.023956910374441316, 0.027036697703546712, 0.03440063978944506, 0.024066383518012505, 0.06578752558146204, 0.03317749560145395, 0.036242875935775895, 0.152966831145542, 0.11394976478602205, 0.05572690721601248, 0.08446739108434745, 0.26840006347213474, 3.672024812017168, 40.40214197976248, 80.72888905661446, 77.67266832079206, 68.5361693246024, 68.78924356188092, 55.99565403802054, 39.88262169701712, 39.83315747124808, 47.58760070800781, 53.941422598702566, 51.807999065944124, 58.31840556008475, 27.302611112594604, 5.690319299697876, 0.15111703611910343, 0.3780898361333779, 0.058234297670423985, 0.1577037383935281, 0.14893534247364315, 0.059529051051608155, 0.029977453207331042, 0.01369011405456279, 0.11348962983382599, 0.09196854143270425, 0.11735111155680247, 0.35227790262017933, 0.5299127250909805, 1.9453672809260232, 2.3292713207857947, 6.593948594161442, 2.867916737283979, 5.151876900877271, 10.499322141919817, 7.3940436499459405, 11.927918672561646, 10.078109315463475, 3.8266087685312544, 4.840527253491538, 5.558039929185595, 8.628391998154775, 13.242724554879324, 9.785063828740801, 5.8124712365014215, 10.775496533938817, 13.3878333398274, 4.374622310910906, 13.23467767238617, 10.10356056690216, 3.4783524615424017, 9.502092361450195, 9.274019479751587, 11.937469840049744, 10.548480646950857, 10.70226946898869, 6.535257160663605, 6.280861462865557, 2.4337207674980164, 5.582664779254368, 12.261757901736669, 5.78598644052233, 1.441703113062041, 1.0245975404977798, 1.037635400891304, 1.2258947789669037, 0.38034346806151526, 2.0144480083669936, 0.046830678691289256, 0.05874153652361461, 0.06986351257988385, 0.09466199297457933, 0.18359919956752233, 0.05222679288791759, 0.4636412411928177, 1.0025581802640642, 27.341778108051844, 64.52945586613247, 64.98497281755719, 65.15641961778913, 67.17679595947266, 81.6626922062465, 33.49550403867449, 16.545828683035715, 28.881132398332866, 47.993319920131135, 58.60477556501116, 62.82887036459786, 71.28996971675328, 76.25905731746128, 28.569978169032506, 0.3826366721519402, 0.27272032307726995, 0.08650488246764455, 0.032128643311027966, 0.01986712367007775, 0.020673767796584537, 0.013085340881454093, 0.1019299647637776, 0.03376676255304899, 0.019440013017239313, 0.03482135185705764, 0.020399505638384392, 0.030141590828342096, 0.10633951957736697, 0.03090811487553375, 0.08859698913459267, 0.02416579907626978, 0.022233153227716684, 0.05182537157088518, 0.025290686304547956, 0.021103000567693795, 0.06096010854733842, 0.029888381915433065, 0.07822161873004266, 0.017504283227026463, 0.04647478028865797, 0.07614146106477294, 0.012207497227271753, 0.04902154952287674, 0.040244763517486196, 0.016598065782870566, 0.014435852877795696, 0.04798101607177939, 0.029521599811102663, 0.06575302886111395, 0.03570792231974857, 0.04779384218688522, 0.010899747355974146, 0.027397630836016366, 0.035625951896820746, 0.05334799736738205, 0.016816559147887995, 0.02004207544294851, 0.04710015548127038, 0.03462838328310421, 0.032143343772206984, 0.054401823319494724, 0.062200307713023255, 0.03709955693089536, 0.013632832976457263, 0.0724827798881701, 0.013506855316726225, 0.048005707961108, 0.027591810594978075, 0.00832079435765211, 0.042619239139769755, 0.06320924178830215, 0.03150958867211427, 0.06298126080738646, 0.060311870117272647, 0.03068745868014438, 0.014433286319087659, 0.019623926541368877, 0.04396935758580055, 0.06841961720160075, 0.010630974546074867, 0.006109791392061327, 0.06412829711501088, 0.06214348040521145, 0.02380187699704298, 0.01666689637516226, 0.03935810823791793, 0.04246476385742426, 0.031554205742265494, 0.020922963174858263, 0.014165058881709618, 0.04586451607091086, 0.020213056089622632, 0.04232359803946955, 0.055384627011205466, 0.06692179186003548, 0.03324789021696363, 0.2207737990788051, 0.07147052777665001, 0.08744198004049913, 0.09954888360308749, 9.033120223454066, 60.336315291268484, 102.3176577431815, 91.480135508946, 83.39596203395298, 87.95061043330601, 76.36020224434989, 58.170266492026194, 38.37816299710955, 29.0141886643001, 30.585692269461497, 43.13889496667044, 54.50534881864275, 29.588229724339076, 6.024008274078369, 0.11844704060682229, 0.5486548393964767, 0.09900035589401211, 0.14119746482798032, 0.17224976500230177, 0.18364494639847959, 0.619251794048718, 0.3391382076910564, 0.5442574439304215, 0.3651142381131649, 0.8735112962978226, 2.198051333427429, 2.6886540821620395, 3.2977409873689925, 2.5833610807146346, 5.983312240668705, 2.539625427552632, 1.6908442356756754, 1.4065339373690742, 3.6802393198013306, 7.307551605360849, 12.09491080897195, 10.804503526006426, 10.01654132774898, 11.70711534363883, 12.741591811180115, 15.603890929903303, 13.979640075138636, 15.715843779700142, 17.352900164467947, 11.476078186716352, 5.960722778524671, 4.3537203924996515, 4.620377055236271, 3.4209759746279036, 6.767481156757899, 9.885183027812413, 18.606412512915476, 8.275425246783666, 11.776749321392604, 10.612924320357186, 9.5449766431536, 5.2963911805834085, 6.955232773508344, 3.144075930118561, 1.96681832415717, 0.4534809392477785, 1.6002006424324853, 0.6616178921290806, 0.9934309614556176, 0.19130271619984082, 2.3712718784809113, 0.4475574642419815, 0.34756821819714134, 0.05326366564258933, 0.14247461701078074, 0.02218108075404806, 0.20123845019510814, 0.5214526961956705, 0.3429825971169131, 23.459532942090714, 53.85205486842564, 61.311897959027974, 64.78737994602749, 53.373633180345806, 42.98440177100045, 27.23066077913557, 24.948868887765066, 49.38775389535086, 83.38006455557687, 86.32709435054234, 79.74411392211914, 79.8331411906651, 90.82525389535087, 47.771995476314, 2.018064545733588, 0.3375562440071787, 0.03460527577304414, 0.0647644576217447, 0.0782610619706767, 0.05446810940546649, 0.03957161267421075, 0.06905783366944108, 0.07362762452768427, 0.019783606187307408, 0.018445640303460614, 0.016480088899178163, 0.04330507519521883, 0.03944510660533394, 0.008535566806261028, 0.028800317086279392, 0.029220917195613896, 0.012291236082091928, 0.015435967694169708, 0.034339564852416515, 0.024124172649213245, 0.056004451787365336, 0.048069880410496674, 0.028231623316449777, 0.05232656128438456, 0.04573104144739253, 0.019857415530298437, 0.028847298850970607, 0.014517819908048426, 0.0480361843614706, 0.015789124815325652, 0.021513325960508416, 0.08983886428177357, 0.018706526840105653, 0.03086097026243806, 0.03497456506426845, 0.049772161923881085, 0.06394295527466706, 0.04061166775811996, 0.03796456694336874, 0.07673687554363694, 0.05051339357825262, 0.06704753118434123, 0.03861229647217052, 0.011081885662861168, 0.14123546278902463, 0.17524785841149942, 0.19475911930203438, 0.05357643296676023, 0.10666145051696471, 0.14908449804144247, 0.10101143869438342, 0.23930125204580172, 0.12289170282227652, 0.10350455955735274, 0.1484608565058027, 0.11646646474088941, 0.15298748575150967, 0.1303305093731199, 0.2032721417823008, 0.11491272811378751, 0.07690169169966664, 0.08851525280624628, 0.09754729350762707, 0.17352009112281458, 0.07789497197206531, 0.11046417789267642, 0.18503107130527496, 0.22532910321440014, 0.24309247146759713, 0.1825049397136484, 0.088618105144373, 0.2276704968618495, 0.12428678439131804, 0.07633166800120048, 0.17816626466810703, 0.11200605372765235, 0.1380886480744396, 0.16758414464337484, 0.12243135752422468, 0.1533831666622843, 0.30404342657753397, 0.25524834490248133, 0.11460760448660169, 0.3525316747171538, 0.2707716247865132, 9.705936874662127, 69.91898591177804, 116.30079623631069, 98.35573932102749, 83.91447830200195, 91.7120246887207, 73.5961046218872, 47.601132324763704, 58.26976122174944, 65.55945682525635, 73.68273476191929, 73.75324508122036, 82.1051812853132, 41.33633075441633, 8.605971898351397, 0.7409874903304237, 1.0965201897280556, 0.14944249311728136, 0.5926484444311687, 0.2873662571821894, 0.22021978880677903, 0.3419048392346927, 0.20470689050853252, 0.3705020232924393, 0.32900046025003704, 0.6765906629817826, 1.1817229092121124, 1.8786094231264931, 5.830775397164481, 6.592398711613246, 16.340212379183086, 8.838645356042043, 11.301273669515338, 24.280111721583776, 17.309836966650828, 28.77451923915318, 26.310790504728043, 17.996567385537283, 21.724194288253784, 20.597017560686382, 21.86976773398263, 32.33619015557425, 27.857440403529576, 25.348744664873394, 37.34195729664394, 37.09643227713448, 17.976711171013967, 30.68171637398856, 23.347838912691387, 15.651284592492239, 27.92618588038853, 20.52795594079154, 29.114326102393015, 17.65436860493251, 24.02139207295009, 17.279249259403773, 16.482881477900914, 11.034415074757167, 20.905058997017996, 28.696287734167917, 13.172581621578761, 8.471382686070033, 5.319331092493875, 3.6247644679886952, 2.5044386642319814, 0.7186533202018056, 3.0658984908035825, 0.503964786018644, 0.2070000267454556, 0.1461495626717806, 0.17237114134643758, 0.20090248036597455, 0.3032039430524622, 0.5795526100056512, 2.0002465418406894, 40.24974366596767, 86.9262444632394, 77.93197509220668, 85.19612911769322, 99.7979838507516, 113.80587182726178, 45.56833955219814, 22.416154963629587, 38.08803054264614, 64.35709885188511, 78.42761094229562, 80.39896079472133, 88.54341684068952, 104.33694321768624, 47.61552551814488, 1.227963279400553, 0.4734776648027556, 0.18185383108045372, 0.13038665136056288, 0.20323551446199417, 0.2166662873434169, 0.1149580678237336, 0.1550441796758345, 0.113262402026781, 0.07793165357517344, 0.08945968534265246, 0.12467084878257342, 0.1192852756274598, 0.2755853421986103, 0.14298852586320468, 0.14858546267662728, 0.10815354902297258, 0.09892296218978507, 0.11989924125373363, 0.1410414967685938, 0.08589979207941464, 0.17679821593420847, 0.18421762995421886, 0.14060142609689916, 0.14149329252541065, 0.18768672166126116, 0.13158214863921913, 0.10424278530159167, 0.19887425777103218, 0.11545212274151188, 0.08447900081851653, 0.12259344596947942, 0.20364628599158355, 0.08783012921256678, 0.12640750488000257, 0.10409204874719892, 0.15115333774260112, 0.1689119426799672, 0.11326537401016269, 0.09379632478313786, 0.16899845589484486, 0.10444632545113564, 0.11101976236594574, 0.1748742570302316, 0.1217633940811668], [0.03088413205529962, 0.022219989648354904, 0.020761427735643725, 0.028158906414838772, 0.034487543161958456, 0.014092626964806445, 0.01705780379208071, 0.0165297966783068, 0.025114528435681547, 0.04948055132159165, 0.039416482605572255, 0.005725984420028648, 0.039052733552775214, 0.026997834610353624, 0.04238944307767919, 0.018401158940313116, 0.020490056136623025, 0.061238158627280166, 0.04835668359217899, 0.045335910149983, 0.04040608521816986, 0.042462528084537814, 0.030853004261319126, 0.020134273084944913, 0.05036858402724777, 0.03498636478824275, 0.0248879096138158, 0.06432150317622082, 0.029477535746991634, 0.06363470360104527, 0.003832392078558249, 0.023933154863438437, 0.008953180513344705, 0.025567413241203343, 0.03934570801045213, 0.05228612059727311, 0.12199625372886658, 0.010186529019847512, 0.11384661389248711, 4.704769441059657, 26.33575885636466, 68.96286514827183, 84.58907890319824, 71.28245871407645, 76.38819653647286, 62.64843954358782, 38.934602533067974, 44.30404186248779, 51.26274265561785, 43.218535218920024, 50.83023466382708, 52.679806913648335, 38.815930775233674, 8.737014923776899, 0.07285412853317601, 0.1995862852782011, 0.08940075457628284, 0.2143867625189679, 0.1509912900094475, 0.01793983655183443, 0.12026166037789413, 0.33982911918844494, 0.3850604806627546, 0.3712084325296538, 0.3283736838826111, 1.8359553005014146, 3.2665322848728726, 1.5641815066337585, 4.194859819752829, 6.171327020440783, 7.910470247268677, 4.961074156420572, 9.955348542758397, 8.094576665333339, 7.323321410587855, 3.8688012702124457, 8.50985746724265, 7.51756351334708, 3.515512296131679, 7.166270843573979, 2.7879017165728976, 9.173473834991455, 6.417671058859144, 4.454014165060861, 5.550322651863098, 9.606712256159101, 8.829666546412877, 5.885418636458261, 5.878037912505014, 9.522910901478358, 6.248987036091941, 11.034721664019994, 11.247025609016418, 7.723041721752711, 9.263145548956734, 8.087823016302925, 6.566766807011195, 14.868837526866368, 13.84592980997903, 18.982593195778982, 5.967976263591221, 10.31051526750837, 5.744161759104047, 1.4192311189004352, 1.6943031357867377, 2.5539697664124623, 0.7229784109762737, 1.6469289064407349, 0.855529955455235, 2.898396530321666, 1.4169002154043742, 0.19342198462358542, 0.23888047891003744, 0.03842486135129418, 0.2760254942945072, 0.14387280627020768, 0.45588287178959164, 4.224356225558689, 45.88276638303484, 77.61284433092389, 49.049852575574604, 40.2394186428615, 57.909656933375764, 59.871154240199495, 29.537313325064524, 13.95292946270534, 26.025480100086757, 45.8057872908456, 62.39216218675886, 62.765315192086355, 74.02620506286621, 54.60888392584664, 6.850243755749293, 0.3289132277880396, 0.010162612356777703, 0.05277614162436553, 0.11638225854507514, 0.04433927112924201, 0.05601476551964879, 0.060646265745162964, 0.0142244832823053, 0.022569849089320217, 0.0488697544538549, 0.03542875944237624, 0.05037570185959339, 0.019136478858334676, 0.021146930621138642, 0.027518048749438355, 0.05050262522750667, 0.05153175929029073, 0.022557528589719107, 0.09004018562180655, 0.06094995087810925, 0.024370367206366997, 0.03059809561818838, 0.05064318375661969, 0.039916104903178554, 0.034779096088771305, 0.020442112548542873, 0.03788461855479649, 0.02099346465963338, 0.04812561866960355, 0.014043217741086014, 0.0628581949110542, 0.023255208473918692, 0.026368713904438273, 0.02826250683782356, 0.018482952944136093, 0.05853477333273206, 0.01589933586572962, 0.021137230963047062, 0.07960973852979285, 0.0680233934628112, 0.07650394125708512, 0.057037443321730406, 0.009873557287002248, 0.027963717335036824, 0.008977411847029413, 0.050305646511593034, 0.08554865020726408, 0.026476850334022726, 0.017473270783999136, 0.013751523170088018, 0.03719865018501878, 0.06441150406109435, 0.03079795471525618, 0.04687363674331989, 0.061547957360744476, 0.035930963565728495, 0.04328297870233655, 0.011069932420338904, 0.04127683224422591, 0.08598332652556044, 0.06378957921905176, 0.01916201213108642, 0.047810035425105264, 0.00898333206506712, 0.06326772472155945, 0.07040112944585936, 0.03443174722737499, 0.05538844716336046, 0.03376619936898351, 0.11492366609828812, 0.06777018454990216, 0.04216075302766902, 0.008763705546568547, 0.02152185684203037, 0.04319859608741743, 0.03360101341136864, 0.058677706734410355, 0.07542190181889705, 0.11051812142665897, 0.183536095810788, 0.1808832817311798, 0.09264811460993119, 9.955633418900625, 43.08088098253523, 91.01036780221122, 93.58989347730363, 86.35924366542271, 99.75828879220145, 95.91489274161202, 71.94890907832554, 45.417435101100374, 29.81435537338257, 35.993374483925955, 44.046402658735005, 55.04079784665789, 42.79832901273455, 9.747450624193464, 0.08704010410500423, 0.3322540899472577, 0.02749029836351318, 0.06550588605127164, 0.10776736760245902, 0.17113746968763216, 0.2211003101297787, 0.1582960994648082, 0.7431352436542511, 1.0782263427972794, 0.9066573519791875, 1.6363574394157954, 1.4068200077329363, 1.2021475732326508, 1.9218910549368178, 1.1965652384928294, 1.1498305691140038, 2.1706602317946295, 0.7088099483932767, 3.3604046191487993, 4.251903661659785, 3.0662508947508673, 1.0048963576555252, 1.648338413664273, 4.109670996665955, 11.898302844592504, 8.372871994972229, 11.484779068401881, 9.968187945229666, 12.438235197748456, 9.845469730240957, 2.832463336842401, 3.25631474171366, 1.757878610066005, 0.9235180786677769, 1.1929428385836738, 0.8782936653920582, 4.730307110718318, 2.052772317613874, 7.253366947174072, 15.376599720546178, 6.123458709035601, 3.13919004372188, 1.1712369918823242, 0.7167690013136182, 0.7236601486802101, 0.8763401902147702, 0.1681683768651315, 4.062217840126582, 7.146892751966204, 7.618655460221427, 7.315336193357195, 2.7835076323577335, 0.8081433496304921, 0.9450948408671788, 5.049011426312583, 1.227396349821772, 0.21483230218291283, 0.3786107338964939, 0.02688830379130585, 0.1276166271418333, 0.058160669835550446, 0.7342082198177065, 3.403163181883948, 36.68791988917759, 70.62909875597272, 49.62335341317313, 41.38482223238264, 26.21638011932373, 32.279864583696636, 31.994682720729283, 14.746799366814749, 44.41814170564924, 74.55856909070695, 88.41411086491176, 77.95938573564801, 83.14419405800956, 76.58933298928397, 17.329604591642106, 0.035275169648230076, 0.08626801946333476, 0.011114372223216509, 0.1322112048843077, 0.02641601797326335, 0.03299707992534552, 0.016411582307357873, 0.010578109882771969, 0.04285062636647906, 0.033582465656633885, 0.016990572846095477, 0.13477597225989613, 0.05088178381057722, 0.04160045273602009, 0.0031968539156618393, 0.08793123771569558, 0.07416729056941611, 0.03872633106740458, 0.11696084535547666, 0.03550859247999532, 0.03528368187003902, 0.033085462504199574, 0.016800242077027048, 0.03763459536380001, 0.06036372376339776, 0.026232370774128606, 0.007393153866619936, 0.044075853656977415, 0.04356028578643288, 0.056127653390701325, 0.07779294066131115, 0.0344262239523232, 0.03009864634701184, 0.04744987242988177, 0.02441349658848984, 0.020634887740015984, 0.049246371923280616, 0.03007107407652906, 0.04975907637604645, 0.019214983663654754, 0.04811874510986464, 0.02813591425573187, 0.007305470178835094, 0.13671194123370306, 0.06354491306202752, 0.10183632014585392, 0.14202837167041643, 0.14727378663207802, 0.0966122993933303, 0.11165368370711803, 0.08807958582682268, 0.1977290263665574, 0.10379675030708313, 0.11112528813204595, 0.22455066069960594, 0.09267836370106254, 0.15434313086526735, 0.13759019624974045, 0.19013235185827526, 0.2049801501312426, 0.09189982619136572, 0.10820960280086313, 0.1339566819369793, 0.08755777204143149, 0.20847765888486589, 0.13433522305318288, 0.13281723165086337, 0.1186531659747873, 0.15471097826957703, 0.17376194814486162, 0.19852867988603456, 0.15059516126556055, 0.26204213606459753, 0.07049351198864834, 0.11972658123288836, 0.18081101775169373, 0.17194492635982378, 0.27598950479711803, 0.20555339008569717, 0.2783851133925574, 0.20821123889514379, 0.16902035900524684, 10.686865312712532, 47.4752379144941, 102.95396682194301, 106.46026406969342, 89.0311803817749, 96.12432534354073, 81.9359440122332, 48.74098777770996, 55.748926980154856, 69.33412824358258, 60.03973143441336, 70.4330553327288, 74.663069997515, 57.5372439111982, 15.896599428994314, 0.6740373628480094, 0.4768037891813687, 0.16823171132377215, 0.5323702703629221, 0.19508501967149122, 0.19114334189466067, 0.2295037220631327, 0.6710679307579994, 1.2941372713872363, 1.55405070739133, 1.7890471432890211, 7.8177847521645685, 9.53921137537275, 7.804769907678876, 16.33022608075823, 21.594733715057373, 23.609386478151592, 22.957784414291382, 24.144929306847708, 23.104724918092998, 21.759393862315587, 19.31885995183672, 27.068411656788417, 22.24913763999939, 14.567954472133092, 15.18109130859375, 15.183328628540039, 24.489070108958654, 22.53063348361424, 18.768540041787283, 20.463280371257238, 23.97753851754325, 24.625788075583323, 20.399905851909093, 24.359870093209402, 21.113763775144303, 20.286149944577897, 34.38809047426496, 26.93742421695164, 22.837573630469187, 31.708180700029644, 24.12586518696376, 17.692793880190166, 30.856487887246267, 27.9370094367436, 41.342559814453125, 22.91947031021118, 25.041790621621267, 16.027699777058192, 9.763337680271693, 6.354140639305115, 5.607323501791273, 1.9977532242025648, 3.9588811908449446, 4.740922221115657, 8.067987646375384, 2.197141770805631, 0.41552616017205374, 0.501854922090258, 0.17945472124431813, 0.3674134947359562, 0.2549933243010725, 0.6919858083128929, 6.6784816810062955, 66.54400266919816, 91.46793447222028, 63.02881172725132, 60.028287751334055, 83.85536997658866, 75.53620842524937, 38.409356934683665, 21.320844411849976, 35.18671989440918, 62.758207184927805, 80.71325560978481, 78.70990235464913, 94.95245606558663, 83.68984304155622, 13.855253423963275, 0.35137536962117466, 0.15937528227056774, 0.13715756232185022, 0.1681240956698145, 0.07585078344813415, 0.10640309152326413, 0.14343789246465477, 0.23708998784422874, 0.09632299241742917, 0.1400845588317939, 0.15113139392009803, 0.25749918126634186, 0.17265118631933415, 0.11562875897756644, 0.16592984912650927, 0.16038916286613258, 0.21149971815092222, 0.05346703276570354, 0.17103354526417597, 0.12774538594697202, 0.1065324813659702, 0.19253699854016304, 0.15671185590326786, 0.11336400586047343, 0.09716497295136962, 0.11305349466523953, 0.21573410236409732, 0.1674111182136195, 0.16920918173023633, 0.21260635448353632, 0.23178574389645032, 0.08467267506888934, 0.1106905507455979, 0.08016573012407337, 0.1372839326837233, 0.08792990100170885, 0.12414100792791162, 0.08986031277371304, 0.21099891859505857, 0.11052043523107256, 0.1926974177892719, 0.17301432469061442, 0.17664231572832378], [0.03339553604434643, 0.023980984796902964, 0.004961061715481004, 0.04443794029897877, 0.053764529659279754, 0.07274193955319268, 0.08260654950780527, 0.0897979825469, 0.06036242097616196, 0.03311336725684149, 0.05071324249729514, 0.08134055244071142, 0.016841519058548977, 0.06610370932945184, 0.040740253536828926, 0.012509033948715245, 0.08891258255711623, 0.053912636890475235, 0.03695770239989672, 0.0033152385564920095, 0.077199921411063, 0.020426945594538535, 0.07512574163930756, 0.013822363074203687, 0.013599668729252048, 0.04697573251490082, 0.04469251985262547, 0.07904847471841744, 0.05554469681477972, 0.09934492276183196, 0.03105195751413703, 0.050234481758837185, 0.07738766526537282, 0.026584104668082933, 0.030452003635998284, 0.10637139036719288, 0.0665570589314614, 2.0284349492618015, 34.22372388839722, 87.16482475825718, 92.55799565996442, 76.09829684666225, 77.02470711299351, 59.77724238804409, 43.35408067703247, 31.05613395145961, 30.909214292253765, 52.281581333705354, 66.41250801086426, 68.856661932809, 39.90447378158569, 11.778535008430481, 0.18827981555036136, 0.2573850245348045, 0.036286685549254925, 0.1454046940697091, 0.018373262669358934, 0.0960215125232935, 0.13234412989446095, 0.08544957052384104, 0.4973730083022799, 0.6820740944572857, 1.8711110140596117, 2.8906733904566084, 2.286200306245259, 1.4292034123625075, 2.9058565071650913, 7.5992604323795865, 7.013418725558689, 7.345487032617841, 8.746850967407227, 23.26469850540161, 24.13838062967573, 36.21196828569685, 40.63295766285488, 30.888473919459752, 6.130354796137128, 7.775289569582258, 6.966694695608957, 5.214230469294956, 7.822457415716989, 8.840549162455968, 8.282479405403137, 7.947666559900556, 12.616781319890704, 8.683075189590454, 4.079325607844761, 1.7079615571669169, 1.2799175658396311, 1.3968046137264796, 1.1222128910677773, 1.1202487221785953, 4.424839113439832, 14.718772070748464, 4.04025501864297, 5.924293373312269, 7.317163569586618, 7.182966062000819, 4.6243140782628736, 4.382156763757978, 6.75757953950337, 18.153132881437028, 44.19330147334507, 68.56080763680595, 90.64595563071114, 83.24911880493164, 61.398291860307964, 28.669526747294835, 5.77193066903523, 1.2040924174445016, 0.3180354157728808, 0.3522542896015303, 0.20419288666120597, 0.04888350496600781, 0.09591507073491812, 0.01651454151475004, 0.28492244545902523, 0.5050962567329407, 0.28731932970029966, 5.8651507411684305, 48.266887869153706, 63.20831148965018, 66.5930986404419, 57.186745507376536, 82.97551264081682, 111.38613387516567, 32.89430768149239, 21.95432036263602, 35.451303822653635, 55.674751486097065, 55.61190850394112, 67.78895309993199, 67.69335978371757, 21.07586830002921, 0.3776741384395531, 0.12137806761477675, 0.13116651879889624, 0.030659150199166367, 0.09403129467474562, 0.01547322774838124, 0.07785358812127795, 0.03208946130637612, 0.02796788523638887, 0.04796167443107281, 0.03716460469045809, 0.10011167411825486, 0.037614626078201194, 0.01929721362622721, 0.02621632850995021, 0.04956416719193969, 0.01303017937711307, 0.063554609327444, 0.009081161547718304, 0.05116145558921354, 0.036636185366660357, 0.028325975307130387, 0.011406787737671818, 0.05130131183458226, 0.026832445092233162, 0.04570710612460971, 0.04116933533389654, 0.03470255394599267, 0.0751469594293407, 0.0451529703236052, 0.02141559656177248, 0.03091138880699873, 0.03987510781735182, 0.017917056434920857, 0.021236766961270144, 0.04273798616070833, 0.034091336386544366, 0.03711484432486551, 0.05050322912367327, 0.06848583543407065, 0.028772395370262008, 0.027072780499500886, 0.06994296903056757, 0.034094142128846476, 0.04038739497108119, 0.055566498144928894, 0.043912574382764955, 0.02696485780844731, 0.025680413070533956, 0.00868689114161368, 0.047077224390315156, 0.03519279210429106, 0.04877031175419688, 0.039019566761063676, 0.02673637301528028, 0.0874747804233006, 0.042156678424882035, 0.02049028853486691, 0.01191884758216994, 0.049859557234283, 0.051173326559364796, 0.028369079244190028, 0.03788884582796267, 0.022941857609631758, 0.05086605536884495, 0.01835722379785563, 0.03072698673765574, 0.03797032092032688, 0.016946661452363645, 0.03368061235440629, 0.0401741280220449, 0.06998095342091151, 0.009461929955120598, 0.053467850400401015, 0.03817992717293756, 0.05878133938780852, 0.05981299760086196, 0.02217287048032241, 0.04051277806450214, 4.3375171933855325, 53.427707535879954, 107.2335707800729, 108.54552268981934, 88.9584049497332, 100.6435935156686, 85.12260328020368, 74.03690528869629, 39.40797288077218, 17.776811497552053, 40.58216980525425, 54.07293462753296, 69.71775913238525, 43.586685521262034, 12.90605046067919, 0.3666455288018499, 0.3526655632470335, 0.1500632440937417, 0.20355468376406602, 0.034386142888771634, 0.37386877834796906, 0.21027716089572224, 0.07770042919686862, 0.26108086907437866, 0.2047371260289635, 0.9289657920598984, 2.521469784634454, 3.7176275764192854, 5.243500190121787, 6.550388600145068, 7.836134944643293, 12.310390080724444, 12.5656156539917, 16.65694080080305, 30.827006680624827, 36.82269409724644, 49.95276403427124, 53.48688881737845, 39.80457258224487, 11.752970848764692, 1.814257053392274, 1.233600982597896, 5.05680730513164, 6.772576357637133, 7.862094283103943, 10.667565822601318, 8.871677092143468, 5.288748162133353, 0.9809030336993081, 1.7470564650637763, 0.8670968604939324, 1.026807501912117, 1.644042472754206, 0.5533630581838744, 1.8286805365766798, 1.922216317483357, 1.95365800176348, 2.1112375003950934, 0.8732906367097582, 4.131424069404602, 2.7805468312331607, 3.634586180959429, 6.006941327026912, 12.216707519122533, 31.384564876556396, 60.991280283246724, 85.7174733025687, 105.51254367828369, 98.76468249729702, 77.25637395041329, 43.7294362613133, 12.197742411068507, 2.954754671880177, 0.1563335454889706, 0.1797284965536424, 0.09434962937874453, 0.20155421325138637, 0.10666879226586648, 0.07123854343912431, 0.2468418659908431, 0.5046042374202183, 0.6404503136873245, 4.649963787623814, 41.972698892865864, 61.715866225106375, 66.7016156060355, 37.631808349064414, 42.85310166222708, 66.61791065761021, 26.62563075338091, 39.0708567074367, 60.30045563834054, 85.03140817369733, 71.60578618730817, 74.65456540243966, 84.13909271785191, 38.33874586650303, 1.1393091508320399, 0.2942928783595562, 0.06266097192253385, 0.03553143536139812, 0.13394133347485745, 0.06838819424488715, 0.06141708831169775, 0.06107750189091478, 0.011452060442284813, 0.0466149316967598, 0.047954180011791844, 0.06666115298867226, 0.0513306618668139, 0.03870253823697567, 0.0737899165334446, 0.02953212728191699, 0.05540474896718349, 0.025926288716228943, 0.028797250107995102, 0.07537656210895095, 0.07805271100785051, 0.022278467492599572, 0.05251939754400935, 0.017194699928430573, 0.036031437638614855, 0.020627294933157306, 0.02836726755569024, 0.0346358675243599, 0.07702255235718829, 0.03504400973075202, 0.02884778061083385, 0.0633256376854011, 0.02567211289091834, 0.032981911275003634, 0.046735151138688834, 0.05346398614346981, 0.01826470554806292, 0.019803112372756004, 0.06963135182325329, 0.023537940445489118, 0.02284027073931481, 0.016905408219567368, 0.165399628292237, 0.1425795049539634, 0.10937559737690858, 0.0798724265769124, 0.08986694884619542, 0.09208579906927687, 0.1396228564637048, 0.11424400471150875, 0.14524009504488536, 0.16061803272792272, 0.16400651447474957, 0.15183200846825326, 0.12356942359890256, 0.09673299041709729, 0.14936292810099466, 0.07425487586962325, 0.17559319202389034, 0.13665251513676985, 0.1318161075136491, 0.08042347843625716, 0.18579473532736301, 0.09854934723781687, 0.18184764284108365, 0.11218463735921042, 0.14795684069395065, 0.18147858764444078, 0.12344227970710822, 0.1544398899589266, 0.12826451951903955, 0.21768128073641232, 0.1060187014351998, 0.11577184844229903, 0.1588540588106428, 0.14535993789987905, 0.11599108310682432, 0.125157127689038, 0.15979171278221266, 6.098815185683114, 61.51898206983294, 121.36615807669503, 122.21453312465123, 93.66339847019741, 99.24725573403495, 77.60468714577812, 55.77787664958409, 39.87508290154593, 41.749804156167166, 75.30033097948346, 88.37877232687813, 94.84822613852364, 59.38029180254255, 19.16229793003627, 1.019579095499856, 0.5912749809878213, 0.30903804142560276, 0.28291015486632076, 0.4248443730175495, 0.22679011124585355, 0.19743340222963265, 0.2527969607285091, 1.775012759225709, 2.0398326005254472, 7.000584968498774, 13.537552254540579, 9.65061184338161, 8.483147723334175, 10.48997334071568, 18.186039549963816, 15.11807462147304, 14.054200325693403, 17.522422313690186, 31.88661391394479, 30.636612142835343, 43.695376191820415, 47.23650128500802, 39.3811354637146, 10.998967971120562, 17.361526353018625, 22.820220504488262, 12.931089162826538, 17.453980820519583, 27.768982887268066, 24.75826416696821, 26.515051909855433, 27.260935817446025, 23.115320920944214, 11.139999900545392, 7.391859310013907, 3.4484561000551497, 4.499100591455187, 5.063364667551858, 7.282785185745784, 17.070560114724294, 37.61862414223807, 18.90897355760847, 21.612637485776627, 25.508810315813335, 19.1749975000109, 13.210868801389422, 8.417581047330584, 10.005597914968218, 22.52011217389788, 49.68157236916678, 74.40708446502686, 100.7747894014631, 92.12230886731828, 66.34527029309953, 32.33286544254848, 7.31073214326586, 2.771227994135448, 0.4452653186661856, 0.352213306086404, 0.13754679714994772, 0.24205105592097553, 0.31518385878631044, 0.1178191921540669, 0.4024091011711529, 0.9252695675407137, 0.7047946495669228, 10.777532356125967, 64.7323363167899, 81.59475272042411, 87.49703202928815, 82.74628462110246, 101.88088008335659, 129.2900505065918, 41.92831032616751, 29.6341712134225, 44.64748784473964, 72.08217552730015, 70.83509199959892, 85.35030964442662, 96.11953803471157, 35.74690103530884, 0.6742593252233097, 0.40404032649738447, 0.21696370281279087, 0.12042305671742984, 0.19377057520406588, 0.16199963859149388, 0.23118157631584577, 0.12394078581460885, 0.0800691745909197, 0.1346701072262866, 0.226956773017134, 0.25516735496265547, 0.11633079844926085, 0.10722886185560908, 0.19223099281745298, 0.14845446470592702, 0.10555462419454541, 0.11880256581519331, 0.1603295196379934, 0.22294527398688452, 0.12603882966297014, 0.13517739357692854, 0.10688939757112946, 0.11580131043280874, 0.22698677783565863, 0.09886744445455925, 0.12477366040859904, 0.14622863914285386, 0.13391002586909703, 0.12872234066682203, 0.13953616682972225, 0.12188308765845639, 0.1144474023686988, 0.1378004199692181, 0.08978009636380843, 0.19039171508380345, 0.06182143411466053, 0.11022557783871889, 0.1258399374783039, 0.15841058189315455, 0.08481640235653945, 0.09227875407252993], [0.10422564550702061, 0.04261675230892641, 0.024164937336796095, 0.0663685958300318, 0.014860005117952824, 0.05394802927704794, 0.08322586199002606, 0.03339674383667963, 0.07782537463520255, 0.052301167111311636, 0.02044933894649148, 0.028101755106555562, 0.023994401130559187, 0.025119666642110263, 0.005297870807615774, 0.06526071777833359, 0.03509792612333383, 0.032136069876807075, 0.03454442135989666, 0.02795856725424528, 0.03790622989514044, 0.03720722686765449, 0.04931221017614007, 0.029949117584952285, 0.04351335491186806, 0.04062300607828157, 0.07714629678853921, 0.00562513291203816, 0.009363270963409116, 0.03518802200310996, 0.06107304391584226, 0.02965860960206815, 0.04308356743838106, 0.05027927864076836, 0.020348903889368688, 0.16107535175979137, 16.814711809158325, 67.59342384338379, 91.19457149505615, 84.71702998025077, 68.88068185533795, 70.85321984972272, 46.92725433622088, 32.63864524023873, 24.55136592047555, 48.41103172302246, 87.01413222721645, 79.10977118355888, 62.31790678841727, 14.21540721825191, 0.3711160160601139, 0.5323891607778413, 0.03915415757468768, 0.0416500977506595, 0.08821409860891954, 0.22322211627449307, 0.06993365274476153, 0.19740281387099198, 0.3953130362289292, 1.8437522649765015, 12.569674270493643, 24.95194693974086, 44.23198209490095, 53.76073816844395, 54.97335515703474, 61.96151283809117, 64.9626829964774, 63.19324084690639, 80.10434327806745, 74.00804941994804, 72.99088873182023, 97.1588773727417, 90.18209389277867, 96.49900000435966, 89.39527988433838, 82.21376078469413, 52.25056110109602, 9.626204558781215, 1.8718546884400504, 5.763069110257285, 4.562951496669224, 6.518851595265525, 4.7017348153250555, 9.624786257743835, 6.265050836971827, 0.8949696134243692, 1.489337682723999, 8.844397595950536, 17.756559235709055, 21.565012795584543, 12.109832065446035, 7.804095063890729, 1.1875841489859988, 4.258097546441214, 9.79101322378431, 3.1596166619232724, 4.255712143012455, 10.576567871229988, 25.5989944594247, 49.55884633745466, 79.97801807948521, 95.6509098325457, 109.88849830627441, 108.6093418938773, 100.828366960798, 105.58382524762834, 109.42763819013322, 111.62332453046525, 87.86145114898682, 45.25045599256243, 25.342063971928187, 20.84489801951817, 8.565163390977041, 1.1833513932568687, 0.1346958644155945, 0.12666192837059498, 0.1401737861867462, 0.20407182244317873, 0.19607654932354177, 0.5444406483854566, 0.23069373677883828, 7.734044194221497, 41.525245325905935, 79.50661059788295, 96.1520278113229, 47.73447520392281, 54.64466714859009, 42.19927270071847, 26.49892861502511, 26.422020741871425, 40.83892658778599, 57.292312962668284, 63.39810153416225, 71.18186269487653, 38.633293901171, 1.7405480657305037, 0.5217458776065281, 0.047176334607814036, 0.06700146544192519, 0.1018056096509099, 0.04182135998936636, 0.013364474921088134, 0.038407249974885156, 0.005712325934187642, 0.06715714851660387, 0.0141873207675027, 0.05988028113331113, 0.02537276529307876, 0.06264378463051148, 0.0369942618667015, 0.07567253908408539, 0.006143543420226446, 0.008985286245920827, 0.04309395920219166, 0.014196492864617279, 0.09271566955638783, 0.057920142742139955, 0.020262696015249406, 0.05191784571590168, 0.034863095331404886, 0.032695688240762265, 0.009443148105804409, 0.04073441813566855, 0.036420014287744246, 0.03586377502818193, 0.03686755902266928, 0.045361925182597976, 0.018000419550974454, 0.08951736760458776, 0.034697403865201135, 0.06907757225313357, 0.0602603353826063, 0.08507527703685419, 0.05876521739576544, 0.031087061523326805, 0.08525029157421418, 0.08668345252850226, 0.07290535114173378, 0.04551445985479014, 0.060272657578544955, 0.007688557479663619, 0.003311472899180704, 0.07194763288966247, 0.0791485043508666, 0.11725117691925593, 0.05881302018782922, 0.0267524780439479, 0.06962789808000837, 0.04830802584599171, 0.0254184306998338, 0.02402865357830056, 0.03613600327766367, 0.027546157062585865, 0.04255101244364466, 0.049140052271208594, 0.0384201828523406, 0.043195400187479596, 0.02680763615561383, 0.06843463318156344, 0.04179422537397061, 0.058769783936440945, 0.012059481598303785, 0.026841479786006466, 0.00598201815903719, 0.013863986108585127, 0.053661918201084645, 0.04568175266363791, 0.03438270950157728, 0.0103659353751157, 0.048917804911200485, 0.01817584460202072, 0.174463295510837, 28.110545907701763, 87.5863928113665, 104.7728523526873, 97.73211765289307, 90.72032220023019, 98.31034673963273, 83.0340929031372, 52.54510566166469, 16.30082998956953, 23.058976241520472, 52.718643869672505, 72.41336141313825, 65.86780398232597, 16.276784011295863, 0.42792486771941185, 0.8458686481629099, 0.10522684428308691, 0.15770132280886173, 0.1285921297967434, 0.45957931343998226, 0.18379433266818523, 0.33510380131857737, 0.13399948392595562, 3.2911269537040164, 20.392469542367117, 37.41773087637765, 60.95323889596121, 70.68364211491176, 73.13468170166016, 77.74317864009312, 81.78284740447998, 82.60182462419782, 96.19487040383476, 89.13108158111572, 90.12049811226981, 107.57219123840332, 100.92172990526471, 101.89128153664726, 96.05044514792306, 89.86278942653111, 63.00604942866734, 14.886272294180733, 1.4136683259691512, 0.382646524480411, 4.131550005504063, 8.711326565061297, 6.362871050834656, 3.1435615462916235, 0.5321561247110367, 0.6150985083409718, 3.4548516997269223, 14.778788873127528, 26.48530146053859, 32.50319010870797, 20.114796945026942, 13.03853350026267, 2.360757516963141, 1.2439908193690437, 0.225083785663758, 1.1139945834875107, 12.188720175198146, 20.1999123777662, 35.66767072677612, 65.22502613067627, 93.10912677219936, 100.48751613071987, 109.31076254163469, 110.65993595123291, 101.85449082510812, 106.29470934186662, 112.98588711874825, 114.66355051313127, 100.26841858455113, 63.64936923980713, 40.54387133462088, 31.931447165352957, 16.38112337248666, 4.1612726620265414, 0.18096503163022654, 0.09694903596703495, 0.20160476411027567, 0.12364508025348186, 0.1913209552211421, 0.47660310566425323, 0.26092798156397684, 7.02346408367157, 42.050664629255024, 76.12460967472622, 87.11514513833183, 50.68253680637905, 29.329444067818777, 25.11954617500305, 30.80636705671038, 46.777642250061035, 62.6621344430106, 75.95726925986153, 74.87294033595494, 81.15766933986119, 60.85622814723423, 8.223160028457642, 0.3373856603034905, 0.089258201154215, 0.07974275853484869, 0.10759466686951262, 0.03904596855863929, 0.02782078054068344, 0.04223681341058441, 0.009723175267156745, 0.051593740071569166, 0.023673927344913994, 0.04889038531109691, 0.07373185429189887, 0.026677696699542657, 0.04169432127049991, 0.016842580965853164, 0.04738177804808531, 0.03872446509610329, 0.06789616136146442, 0.013493148061180753, 0.06965324136295489, 0.03284766651423914, 0.05286944018942969, 0.039435244098837884, 0.049222124474389214, 0.0103920547324898, 0.0053670521176952335, 0.02175913205636399, 0.0263747511697667, 0.0757211832595723, 0.014192630304023623, 0.07103585824370384, 0.08911917611424412, 0.008495395836819495, 0.0724244462326169, 0.05542017546083246, 0.06365982296743564, 0.12613477451460703, 0.07933181058615446, 0.07907030318996736, 0.03766486820365701, 0.12035991224859442, 0.15097001115126268, 0.11903531689729009, 0.2313292526773044, 0.05155766575730272, 0.09143806954047509, 0.16184162135635102, 0.17126009453620228, 0.2566269380705697, 0.1848830013935055, 0.0933238947764039, 0.1445127869290965, 0.13718004897236824, 0.1436656495290143, 0.0999695753146495, 0.16101342865398952, 0.10832968314311334, 0.09658642006771904, 0.11500533457313265, 0.2245056466864688, 0.1293884992067303, 0.10820383525320462, 0.24797689222863742, 0.13212530235094683, 0.2305708405162607, 0.10194376616605691, 0.14405575288193567, 0.1931962224521807, 0.13980125689080783, 0.18144400949989045, 0.19883943535387516, 0.13835405026163372, 0.1050388900829213, 0.1105323638767004, 0.07281666661479644, 0.28660225389259203, 33.94385392325265, 102.73673139299665, 117.62230191911969, 101.57349872589111, 88.9293406350272, 89.80673830849784, 59.82099519457136, 45.01615926197597, 33.77969230924334, 71.84338678632463, 121.19395392281669, 101.97666100093296, 82.2037136895316, 21.06407199587141, 0.9858443971191133, 1.0095353658710207, 0.253839624779565, 0.3228028028139046, 0.44407891375677927, 0.4764863433582442, 0.22939379939011165, 0.6713643691369465, 1.1816907737936293, 2.407330423593521, 15.589772190366473, 29.30893645967756, 52.175645623888286, 61.88717406136649, 62.63752392360142, 68.68369347708565, 75.2434391294207, 77.14657851627895, 91.60444572993687, 86.78165245056152, 93.2787114552089, 113.42440182822091, 107.0722405569894, 111.41283580235073, 103.0089270727975, 93.10690334865025, 64.00229603903634, 12.357751607894897, 5.455301693507603, 20.76227699007307, 23.1203670501709, 27.886522088732036, 22.092695474624634, 26.98192048072815, 18.215529441833496, 3.315372041293553, 3.474009620291846, 14.25869710104806, 27.340517010007584, 34.57573699951172, 21.41595482826233, 11.40052434376308, 2.7781262525490353, 13.419642192976815, 24.988181795392716, 12.069834760257176, 18.80044616971697, 18.24245023727417, 30.629556247166224, 60.04497732434954, 90.99415070669991, 104.9103502546038, 114.85891301291329, 120.45652770996094, 111.09236403873989, 117.1379290989467, 122.84545734950474, 124.34687968662807, 99.22716849190849, 54.983315399714876, 30.06563002722604, 22.784296580723353, 10.362076112202235, 2.4352089847837175, 0.2024129671709878, 0.2627960427531174, 0.48745635471173693, 0.5103274903127125, 0.24533448687621526, 0.8586747752768653, 0.30257846947227207, 13.908434067453657, 58.04872512817383, 100.10328074863979, 118.81498800005231, 62.97970880780901, 73.48828942435128, 53.33989272798811, 33.04338475636074, 33.832745279584614, 54.30011640276228, 74.74203627450126, 76.19358444213867, 96.88037967681885, 65.14674077715192, 5.9827932970864435, 0.5889303982257843, 0.24924480276448385, 0.1284015971635069, 0.2101278424795185, 0.07650322200996534, 0.12547413924975054, 0.13703647096242222, 0.10822577907570771, 0.25901776977947777, 0.10839422539408718, 0.19400215920593056, 0.18131173588335514, 0.13419161790183612, 0.1697915411953415, 0.16409487330487796, 0.2199706036065306, 0.15804977768233844, 0.1876911592802831, 0.11348776386252471, 0.3653837793639728, 0.19466340515230382, 0.14187414066067763, 0.14779954270592757, 0.11358721674020801, 0.24469460121222905, 0.16537639525319847, 0.11553442903927394, 0.09963490827275173, 0.13607149917100156, 0.09428195229598454, 0.15666923033339636, 0.11622521840035915, 0.1599071723009859, 0.15865657797881536, 0.15581411336149487, 0.1571084460509675, 0.1867956966161728, 0.12743836242173398, 0.10811645351350307, 0.22275434780333722], [0.02804594729760928, 0.07151411686624799, 0.0737540695284094, 0.04278640302696398, 0.08865323968763862, 0.0616083876895053, 0.050867979015622816, 0.05805664363184145, 0.04949718900024891, 0.08365458755620889, 0.08016336882220847, 0.04204296274110675, 0.08602071380508797, 0.01480669092520007, 0.1002261226198503, 0.07919235128377165, 0.07283675125134842, 0.11438200516360146, 0.08648014308086463, 0.048840448526399474, 0.04706622873033796, 0.0171553788240999, 0.0727420277627451, 0.06682111761931862, 0.05918647229139294, 0.08331804775765964, 0.043730265593954494, 0.056536453776061535, 0.020300047671688453, 0.06568054096507174, 0.06623921955802611, 0.02240718897831227, 0.026315603272191117, 0.017831823954890882, 0.2752627395093441, 37.01730619158064, 90.27540819985526, 86.46061788286481, 72.04611437661308, 68.68341554914201, 56.88846281596592, 27.846601213727677, 19.445756639753068, 35.03599262237549, 72.04642009735107, 74.43532194410051, 72.69973836626325, 42.166901043483186, 2.634577121053423, 0.43374740385583466, 0.14997390817318643, 0.027604563660653572, 0.13600703834422997, 0.1610433520483119, 0.10573478881269693, 0.048528034040438275, 0.17548715057117598, 3.7566851377487183, 5.9187721610069275, 41.38687889916556, 78.09516743251255, 100.27742344992501, 105.20621149880546, 108.50014400482178, 113.6555267061506, 110.341979435512, 105.29270962306431, 101.80810465131486, 100.09063502720424, 99.13533415113176, 94.77410275595528, 90.10366957528251, 89.30661392211914, 80.5435458592006, 84.19686698913574, 84.47233527047294, 82.36710057939801, 47.36419527871268, 10.805962647710528, 1.6972302815743854, 3.2542155172143663, 1.2426913976669312, 6.168485641479492, 3.8082989624568393, 1.5374069490603037, 4.396891721657344, 29.254507746015275, 46.72552728652954, 50.55364424841744, 59.59904888698033, 55.61428478785923, 44.70196866989136, 39.56991801943098, 6.862478230680738, 2.9932811302798132, 13.747672728129796, 32.33911187308175, 57.47382770265852, 82.08831800733293, 100.27578367505754, 102.79153878348214, 88.29449067796979, 87.07180922372001, 97.37405613490513, 92.39110687800816, 88.01593044825962, 87.49036870683942, 93.14747388022286, 95.35877282278878, 98.63139520372663, 110.65576703207833, 111.56798212868827, 106.86406557900565, 75.02452918461391, 28.558527537754603, 1.3018795187984193, 0.2110368622733014, 0.04589081608823367, 0.041888558704938204, 0.3571231040571417, 0.20719252713024616, 0.4930073139922959, 0.37346369294183596, 15.546799319131033, 47.823102951049805, 57.46646956035069, 66.1954254422869, 78.38039793287004, 56.24075869151524, 27.529959644590104, 25.711734192711965, 39.55869320460728, 45.56620298113142, 54.21423666817801, 67.0477957044329, 60.560283524649485, 12.272414701325552, 0.20175299687044962, 0.3343358082430703, 0.1030523498941745, 0.1882064930562462, 0.053412827995738814, 0.03988255813185658, 0.12370513060263225, 0.023431123766515936, 0.05287267680146864, 0.0627474512106606, 0.08246537351182529, 0.05104894769777145, 0.08102963412446634, 0.0621579128450581, 0.03829329680385334, 0.023467863045100654, 0.15884244229112351, 0.133137011634452, 0.05788426859570401, 0.040684040303209, 0.023978418238194923, 0.037336833841566525, 0.052614199064139805, 0.03835046337917447, 0.05269250200529184, 0.02917271406788911, 0.07928942928888968, 0.053631760712180815, 0.07339380814560822, 0.13340866991451808, 0.061702127302331586, 0.006533980103475707, 0.043050285295716355, 0.030484498678041354, 0.07139052171260118, 0.02608313038945198, 0.17526757663914136, 0.17820376051323755, 0.15739349861230167, 0.09559986407735518, 0.0571419716413532, 0.028523973521909544, 0.058750737458467484, 0.06795324651258332, 0.0464901762482311, 0.03462034264313323, 0.06730472988315991, 0.031540350057184696, 0.08442684861698321, 0.023253200010263493, 0.03278454240145428, 0.04281591930027519, 0.0742456138666187, 0.06339007815612213, 0.09477720822074584, 0.06445637558187757, 0.12652694061398506, 0.029347026321504797, 0.04023489083296486, 0.04732458772403853, 0.010734686079168958, 0.08918567933142185, 0.0684032780783517, 0.011869868380017579, 0.03189361235126853, 0.0879180741363338, 0.06776603191558804, 0.09494821261614561, 0.05519389421013849, 0.09335887325661522, 0.024081891435863714, 0.046270436075116904, 0.04885226860642433, 1.5973525324038096, 58.58161721910749, 106.76844446999687, 100.22675023760114, 94.461656161717, 94.5701036453247, 87.5175917489188, 52.01116786684309, 20.775212798799785, 20.11838742664882, 43.01739876610892, 64.58406175885881, 80.28104291643415, 46.72026055199759, 2.874156219618661, 0.6689162690724645, 0.15326244171176637, 0.0500577607059053, 0.04407079517841339, 0.19651321374944278, 0.3646688205855233, 0.19937158322760037, 0.4768766909837723, 0.591958510024207, 10.212157436779567, 58.23458596638271, 93.46536786215646, 109.2509593963623, 110.71418053763253, 113.28916903904506, 115.79347351619175, 111.98993233272007, 105.90464442116874, 102.50543281010219, 103.90331309182304, 104.54056017739433, 100.87811606270927, 94.82679094587053, 92.89287798745292, 85.16703006199428, 89.75995608738491, 93.18615450177873, 90.72743715558732, 61.21716621943882, 18.342123883111135, 2.4952396835599626, 1.3498782174927848, 3.397270892347608, 3.0197659262589047, 1.1473320403269358, 0.9513326947178159, 7.71171007837568, 41.114777020045686, 58.605199405125205, 63.57323087964739, 75.69337667737688, 76.24964250837053, 59.80792563302176, 54.519439765385215, 12.722766535622732, 5.949269107409886, 23.207627739225114, 53.002189431871685, 74.70692007882255, 92.05690547398159, 102.34773649488176, 104.76774542672294, 92.40968636104039, 92.99929659707206, 100.70787130083356, 100.23118318830217, 93.99230534689767, 91.19670459202358, 98.26562813350132, 97.51078973497663, 101.85712419237409, 113.50846113477434, 117.53529657636369, 117.63765743800572, 91.51771831512451, 42.85387986046927, 3.9616487451962064, 0.14100121892988682, 0.1721087247133255, 0.32085736149123734, 0.26493025251797264, 0.0415285042753177, 0.756995922752789, 0.3968155841742243, 14.681152786527361, 52.27612699781145, 60.24386950901577, 60.49808325086321, 39.259215423039024, 20.846263340541295, 25.71382907458714, 38.76549727576119, 69.46476827348981, 73.03116049085344, 71.0606027330671, 75.67516544886998, 82.03678321838379, 29.594906943184988, 0.5610096592988286, 0.3650749373648848, 0.21171467804483005, 0.10174552537500858, 0.03988620525758181, 0.05279500150520887, 0.10418291137154613, 0.0355398763370301, 0.042765894306025336, 0.10648386433188405, 0.07014920296413557, 0.053535418917558024, 0.11525120852249009, 0.17754664005977766, 0.036481428492282114, 0.059063793160021305, 0.09276977593877486, 0.10763531111712966, 0.06835624881620918, 0.05994844676128455, 0.03602259971999696, 0.03682295891589352, 0.06438187922218017, 0.07563700420515877, 0.03425594898206847, 0.018562441625233208, 0.046587959929768524, 0.015818291643102254, 0.1170899977109262, 0.050204833171197345, 0.08179727436176368, 0.0484174260470484, 0.05227097908833197, 0.04673683390553508, 0.024718637179051126, 0.05026611166873148, 0.15960065089166164, 0.22239669199500764, 0.17498925514519215, 0.2675406853003161, 0.1210014671087265, 0.1487744211086205, 0.12694383252944264, 0.15866480182324136, 0.20813068321772984, 0.091801486111113, 0.11569453616227422, 0.19529350634132112, 0.20419735142162868, 0.13307516995285237, 0.13772671749549253, 0.24151151201554708, 0.22908039763569832, 0.15356512261288507, 0.1909531078168324, 0.14934228706572736, 0.21338719901229652, 0.15520409680902958, 0.1496062371879816, 0.10057539173534938, 0.09759277570992708, 0.1560809811843293, 0.159163199365139, 0.16700795984693936, 0.11105915810912848, 0.15913592225738935, 0.2808184485350336, 0.2122059373983315, 0.11672630294093064, 0.22592029720544815, 0.1724180688283273, 0.1543146866772856, 0.20705823147935526, 2.2957399657794406, 67.72296605791364, 123.19345092773438, 108.37805025918144, 92.09577369689941, 92.23837852478027, 74.39983749389648, 37.061493260519846, 26.96465768132891, 49.11864668982369, 109.77436024802071, 98.98069504329136, 91.1884570802961, 56.98321540015084, 4.685632799352918, 0.8450402383293424, 0.2729330030935151, 0.36297880698527607, 0.3268911120082651, 0.33365227920668467, 0.3067087935549872, 0.19551563156502588, 0.7072859587413924, 9.199787531580244, 7.892515233584812, 54.38555492673601, 96.9920928137643, 118.43019676208496, 119.2966788155692, 122.60411861964634, 125.81957817077637, 121.9533920288086, 117.6106984274728, 110.62294374193463, 112.10486943381173, 114.67233998434884, 107.26848547799247, 101.48768847329276, 101.5967126573835, 91.6590655190604, 98.13441835130963, 98.54312528882707, 95.5678163255964, 61.16655554090227, 18.261239903313772, 5.977305957249232, 12.515381046703883, 16.141565118517192, 17.85032864979335, 10.426281809806824, 3.5369379350117276, 7.596952761922564, 45.3354880469186, 71.53888893127441, 72.10447924477714, 84.68791702815464, 87.50161089215959, 78.36256885528564, 62.2657744543893, 10.043666226523262, 4.591682732105255, 18.69832328387669, 53.37889296667916, 78.07252325330461, 97.68175016130719, 107.80074528285435, 108.37993322099958, 94.40331908634731, 93.31266730172294, 104.2518903187343, 103.81743335723877, 96.32150827135358, 93.96679850987026, 101.37828908647809, 106.59249523707798, 111.53443622589111, 122.64482116699219, 124.3048847743443, 120.45807021004813, 84.56209209987095, 33.76158530371529, 2.7539224198886325, 0.2271333821117878, 0.27281309238501955, 0.38098927055086407, 0.5481167339852878, 0.32565194421580856, 0.9818512456757682, 0.9467815160751343, 24.58344054222107, 66.31488582066127, 73.63097763061523, 87.04943602425712, 109.97527435847691, 71.26911122458321, 36.5168274470738, 32.16201966149466, 53.28608240400042, 60.5493609564645, 68.82558958871024, 88.42163576398576, 92.90593365260533, 29.282804284776958, 0.3864935194807393, 0.4914698622056416, 0.3669957885784762, 0.24495059890406473, 0.14607431313821248, 0.12882823284183229, 0.2461648237492357, 0.13461951565529617, 0.0915694474907858, 0.2143560384533235, 0.1555341633835009, 0.15224982319133623, 0.2637163262282099, 0.2515694365969726, 0.15400009070123943, 0.1243461969175509, 0.22294310267482484, 0.28948686910527094, 0.0911077790494476, 0.09845372808298894, 0.13738195385251725, 0.11533392194126334, 0.18088839788522038, 0.1558569289211716, 0.18223330857498304, 0.08398276780332838, 0.14739073892789228, 0.16672054598374025, 0.19573037432772772, 0.1670579814485141, 0.16429075279406138, 0.15348433623356478, 0.1068766750395298, 0.13172176400465624, 0.1330654261899846, 0.14414541449929985, 0.2572979549212115, 0.38263398515326635, 0.18882260285317898], [0.16895447325493607, 0.036329056668494425, 0.04416125068174941, 0.030519260027046715, 0.18481471362922872, 0.19098014065197536, 0.1532756867153304, 0.11121237131633929, 0.049305150019271035, 0.05325352154406054, 0.07575025848512139, 0.06514999443399054, 0.160415666443961, 0.12248159625700542, 0.15421692335179873, 0.11857062897511891, 0.11040220050407307, 0.10820106004497834, 0.09983897089426007, 0.09648051432200841, 0.026299898579184498, 0.0560809769667685, 0.0927050911954471, 0.02627029239998332, 0.10023366792925767, 0.12354313715228013, 0.05094839220068284, 0.02848459474210228, 0.16540422875966343, 0.022054274433425496, 0.010553403574574207, 0.04103356726201517, 0.06994353221463305, 0.9522585421800613, 48.479061535426546, 98.3527307510376, 82.89576816558838, 65.54399708339146, 67.5626780646188, 55.79634843553816, 29.120558636529104, 36.09596463612148, 71.67019598824638, 70.58365753718785, 59.00828524998256, 72.12299619402204, 16.234785624912806, 0.5000771060585976, 0.4353386770401682, 0.05782922583499125, 0.11086870011474405, 0.2765121396098818, 0.13605001675231115, 0.20944432701383317, 0.22413740573184832, 0.9035530814102718, 1.595320618578366, 2.776170117514474, 45.78821529660906, 81.23883124760219, 86.95382186344692, 84.02916526794434, 90.7156182697841, 90.2291123526437, 91.05095223018101, 94.20667116982597, 90.69145938328334, 92.47341523851667, 94.04607050759452, 90.91264833722795, 89.83442687988281, 88.55329023088727, 77.1335506439209, 77.85489872523716, 80.44501345498222, 87.69654260362897, 89.17336136954171, 82.06010137285504, 56.611889771052766, 16.661417177745275, 2.283754106078829, 3.8586160796029225, 2.2374921313353946, 0.35710684635809486, 2.5482257774897983, 33.09167126246861, 56.44644621440342, 59.65777506147112, 71.88249819619315, 83.60688849857875, 86.46068736485073, 70.6039045878819, 67.53179332188198, 64.54700006757463, 55.03754608971732, 65.6912294115339, 77.92331763676235, 87.98394094194684, 88.58181258610317, 90.53766100747245, 91.00620583125523, 98.97685963766915, 102.65686879839215, 95.82001508985246, 96.88907187325614, 92.33689703260148, 82.91429206303188, 93.79407324109758, 98.03300244467599, 90.72885458809989, 90.83993543897355, 88.84717123849052, 91.7007199696132, 101.45690795353481, 103.37452738625663, 49.93559850965227, 1.5266619942017963, 0.41420174123985426, 0.23410082395587647, 0.2347092255949974, 0.042258156729596, 0.4129598050245217, 0.0735633536907179, 0.12385184344436441, 5.443934440612793, 39.21000828061785, 75.98745918273926, 80.7448421205793, 69.57856587001255, 69.27549934387207, 39.59067923682076, 14.100744571004595, 21.42121114049639, 40.72949593407767, 53.64820514406477, 67.92665249960763, 68.89168085370744, 32.920405115400044, 0.7705658631665366, 0.4312082715332508, 0.05356251621352775, 0.02772722582864974, 0.035361051825540404, 0.0661553390590208, 0.1612647037420954, 0.05999620205589703, 0.0710959696610059, 0.0711488886071103, 0.036925064865499735, 0.07977326546928712, 0.045837863215378354, 0.05543191411665507, 0.02638939056279404, 0.1353813340621335, 0.2358398549258709, 0.11561197202120509, 0.03469453705474734, 0.02037540916353464, 0.051087122077920606, 0.07056059874594212, 0.034360555333218405, 0.012603727751411498, 0.04697676049545407, 0.023680868758154765, 0.0562007146488343, 0.0278955771521266, 0.19389328147683824, 0.06367340045315878, 0.03581277633618031, 0.03289601891966803, 0.15425756759941578, 0.15629591393683637, 0.1957524267158338, 0.07698712604386465, 0.33600953700287, 0.2871220388582775, 0.16074823002730096, 0.08511678302394492, 0.13466410897672176, 0.09888028233711209, 0.185298834794334, 0.18616558185645513, 0.12503948328750475, 0.10214986439262118, 0.05582106073520013, 0.023815605456807783, 0.07498725264200143, 0.06809314686272826, 0.09076051161225353, 0.09239676488297326, 0.11009438309286322, 0.1015564515920622, 0.04683663962142808, 0.15684574443314755, 0.16264054205800804, 0.08198710810393095, 0.12137505491929394, 0.03681174612471035, 0.048754786872970204, 0.07603670204324381, 0.10115553917629377, 0.12583654480321066, 0.03780636989644595, 0.10030168427952699, 0.1368644351937941, 0.0506314824202231, 0.02639533283321985, 0.06253081533525671, 0.022266342071816325, 1.8128730590854372, 71.1810497556414, 110.50665174211774, 95.26712608337402, 87.95173604147774, 93.44876166752407, 79.851046698434, 47.33933809825352, 27.296560968671525, 25.257097925458634, 46.448276792253765, 65.3229193006243, 81.64258411952427, 16.75611243929182, 0.42555743189794676, 0.5261395275592804, 0.053665660321712494, 0.12307475799960749, 0.47833109008414404, 0.23016656935214996, 0.32197157027465956, 0.32912069665534155, 0.6194633341261319, 1.1576535893338067, 5.757254336561475, 57.428264890398296, 89.11020224434989, 93.90892696380615, 90.47111116136823, 100.9384194782802, 97.86368179321289, 96.09796387808663, 100.27162865230015, 95.41182231903076, 100.57627241952079, 101.7342939376831, 98.26717063358852, 95.61847564152309, 93.53637150355748, 82.19117219107491, 81.5661678314209, 88.40178476061139, 91.8505995614188, 92.94216850825718, 91.00687980651855, 68.74636622837612, 26.227318320955547, 3.422693048204694, 0.49180907543216434, 0.4478323252073356, 0.4932125029819352, 4.867435021059854, 44.0029798916408, 67.28894683292934, 73.7333801814488, 84.64196164267403, 94.21198654174805, 97.08446911403111, 89.1876607622419, 88.13181250435966, 82.55569553375244, 67.01308250427246, 76.89986188071114, 87.7199649810791, 96.3302560533796, 94.26618943895612, 94.86772278376988, 96.07513904571533, 99.56503159659249, 104.16441249847412, 100.52697495051792, 99.42836053030831, 95.74860845293317, 85.11702387673515, 95.27453981127057, 102.45373821258545, 97.06506279536656, 94.04167924608502, 93.26497486659459, 91.94176687513078, 102.58191858019147, 109.01680510384696, 66.77251502445766, 3.2210756497723714, 0.29447678849101067, 0.6245798138635499, 0.27681463052119526, 0.15801738442054816, 0.3604573979973793, 0.07757238285349947, 0.23968223588807241, 4.974382996559143, 41.459935733250205, 78.79773453303746, 84.17465359824044, 51.56990167072841, 22.119803871427262, 31.1771194594247, 25.703587429864065, 37.667386599949424, 67.91056047167096, 71.88750784737724, 76.08638068607875, 84.00103201184953, 53.67309359141758, 3.2159246461732045, 0.5973510178072112, 0.13312231456594809, 0.017974755660231625, 0.09226570584412132, 0.042260093947074244, 0.13432625282023633, 0.046988441475800106, 0.09458423964679241, 0.06472623574414424, 0.057245753572455475, 0.10900827244456325, 0.08137584983238152, 0.05901661462017468, 0.030620463525078127, 0.1744810188455241, 0.3052332784448351, 0.1103929520717689, 0.01492065257791962, 0.06343574356287718, 0.05907144024968147, 0.05639882991090417, 0.04898735135793686, 0.026096789299377372, 0.040183386632374356, 0.04189024147178445, 0.043303307611495256, 0.1650890221021005, 0.15094543461288723, 0.07340523467532226, 0.05478554165789059, 0.029527347002710615, 0.03590037859976292, 0.11642864319894995, 0.17918919692082064, 0.27359503614051, 0.41463022253343035, 0.23566050454974174, 0.22075127171618597, 0.2979868230010782, 0.26575092705232756, 0.1875465363264084, 0.2092242781072855, 0.27290732732840944, 0.28962982286299976, 0.1629944930651358, 0.15576581523886748, 0.18392159869628294, 0.22967487573623657, 0.10429526319993393, 0.18654534433569225, 0.2232380618474313, 0.33775608614087105, 0.2758381100637572, 0.1580864457147462, 0.17559188923665456, 0.26275695913604324, 0.15937281240309986, 0.15523144177028111, 0.20823870599269867, 0.1579401128526245, 0.2282946269427027, 0.2942603629614626, 0.21689090957599028, 0.09911323019436427, 0.16519735700317792, 0.2725238193358694, 0.08422008542610065, 0.15711128232734545, 0.2548186151044709, 0.1449704859405756, 2.2420625260898044, 84.5758912222726, 124.24472727094377, 104.32602064950126, 90.97234725952148, 87.79683290209088, 71.45692798069545, 39.756362506321494, 46.85469082423619, 98.67147936139787, 99.20200211661202, 76.22654669625419, 93.20489379337856, 23.78413540976388, 0.8189734742045403, 0.7380808634417397, 0.21796657757035323, 0.2336839320404189, 0.7244153852973665, 0.3348722037460123, 0.42521303466388155, 0.6094644420913288, 2.799642652273178, 3.7872506976127625, 4.0145180225372314, 56.52878584180559, 96.61608409881592, 103.34214183262416, 95.18115602220807, 106.22646413530622, 99.95768124716622, 100.25926085880825, 102.50237560272217, 98.3628681727818, 105.47257763998849, 105.73144667489188, 103.76341806139264, 102.95256328582764, 101.14838709150041, 88.62352262224469, 89.01763834272111, 93.81832245418003, 97.45736503601074, 99.1347713470459, 95.0361888068063, 68.1782398223877, 24.282380308423722, 4.899238228797913, 11.233588661466326, 8.475899015154157, 1.9485469503062112, 4.006376036575862, 49.92357117789132, 78.61356558118547, 79.2015151977539, 87.59946237291608, 97.032135282244, 96.53580461229596, 91.18495518820626, 100.90625626700265, 101.74366705758231, 68.985029901777, 85.7472254889352, 95.51487800053188, 105.39239542824882, 99.43942206246513, 100.65376567840576, 100.50080803462437, 102.82588372911725, 108.45006833757672, 107.18403012411935, 105.77286488669259, 102.10605035509381, 92.90566267286027, 103.80507251194545, 106.61551461900983, 95.95535905020577, 97.8313935143607, 95.3509908403669, 98.77616092136928, 114.44207668304443, 118.10233906337193, 59.98272841317313, 1.7665547387940543, 0.4874298647046089, 0.5412433370947838, 0.40429266010011944, 0.2566777196313654, 0.5984932907990047, 0.18459881735699518, 0.20178570225834846, 10.087980100086757, 58.82493618556431, 91.97476387023926, 99.84898362840924, 104.33369146074567, 88.83617224012102, 50.33852802004133, 18.941680465425762, 26.65878060885838, 55.583716188158306, 69.82390676225934, 82.94358566829136, 99.13632774353027, 57.107379708971294, 2.1879907761301314, 0.5202300846576691, 0.320393867790699, 0.17002334232841218, 0.19039502633469446, 0.12556118172194275, 0.2624500170350075, 0.1659178797687803, 0.21235666716737406, 0.18067559573267186, 0.17861901037395, 0.25321862953049795, 0.11162614197071109, 0.13918836334986345, 0.14252092024045332, 0.18331156857311726, 0.3675154649785587, 0.2946730208184038, 0.17381412748779568, 0.13645865768194199, 0.14333626148956163, 0.14133087838334696, 0.1584221984126738, 0.14521178656390735, 0.15446864627301693, 0.0957355982224856, 0.10691579258335487, 0.27741163277200287, 0.25503115941371235, 0.09251370360808713, 0.11079184245318174, 0.2527095382767064, 0.15843703118818148, 0.24427241672362598, 0.26931117315377506, 0.31084850856236046, 0.5330109702689307, 0.283975536269801], [0.2179901770183018, 0.2683212177029678, 0.10392665583640337, 0.0987550179873194, 0.1319042220711708, 0.1452369195009981, 0.031401033247155805, 0.10903354108865772, 0.041377414882715256, 0.016031699388154914, 0.011891808809845575, 0.053606393680508645, 0.09373028296977282, 0.08511607734752552, 0.04854134011215397, 0.06479573808610439, 0.06907990641359772, 0.10803865947361503, 0.05479273073641317, 0.16701163750674042, 0.042820540123752186, 0.005693969865595656, 0.07073447334447078, 0.06663691571780614, 0.21560925192066602, 0.0346791953779757, 0.07620541299028055, 0.06470661929675511, 0.06391628206308399, 0.027013547785047973, 0.0034871844192301588, 0.030842894089541266, 0.24861202814749309, 43.35641179765974, 88.43044607979911, 80.03361061641148, 72.12783214024135, 74.77103805541992, 61.619814327784944, 32.1057253565107, 38.112012250082834, 87.92329706464494, 71.66146210261753, 76.42248589651925, 78.70288467407227, 4.2393326333590915, 1.0772006149802889, 0.060086501496178765, 0.09581972299409763, 0.27623315315161434, 0.11761629661279065, 0.07436227439237492, 0.12067377540682044, 0.7090809281383241, 0.9679218445505414, 0.9002341223614556, 7.1775564551353455, 49.69315154211861, 85.74012442997524, 88.85422366006034, 92.30197538648332, 93.15616607666016, 93.17739282335553, 93.66710186004639, 94.9076818738665, 97.23055498940604, 91.92620291028703, 88.32912744794572, 86.56715461186, 85.88227067674909, 80.13145514896938, 71.31747068677629, 74.99457550048828, 83.02650547027588, 88.51466519492013, 89.46277468545097, 86.08790956224713, 89.75607899257115, 85.478976385934, 63.02947180611746, 22.039746727262223, 5.9747941834586005, 0.47531888314655846, 2.7549837572234015, 32.8358907018389, 51.05499151774815, 70.9689907346453, 88.69640922546387, 96.28405053274972, 98.07262802124023, 106.4293932233538, 103.95989922114781, 92.87169292994908, 74.77855600629533, 80.80135181971959, 82.49300193786621, 94.6378972189767, 97.52905654907227, 94.95276873452323, 87.63266781398228, 88.02569266727993, 88.09040818895612, 97.5344830921718, 95.7213020324707, 93.45354202815464, 95.62921060834611, 86.06200667790004, 77.72107642037528, 86.60792664119175, 94.39410577501569, 92.34961918422154, 88.54742595127651, 82.58343274252755, 85.43231228419712, 82.10546616145542, 95.9299008505685, 33.693534646715435, 0.14172702069793428, 0.0336990311874875, 0.2787162927644593, 0.019204016841415848, 0.09011219175798552, 0.0781882619485259, 0.14441863340990885, 0.12245825465236392, 0.36585194138543947, 8.886573161397662, 36.139092104775564, 44.837250096457346, 64.60212707519531, 64.93511254446847, 53.98922273090908, 33.84577662604195, 17.352453742708477, 42.791088989802766, 57.96322059631348, 54.765308720724924, 69.39295169285366, 38.400654315948486, 3.760433256626129, 0.09523589789335217, 0.1558202337473631, 0.039462449960410595, 0.16454871823745115, 0.03530604977692876, 0.1204555585448231, 0.033680418971925974, 0.10053770590041365, 0.031183386354574134, 0.06430397661668913, 0.01443244154298944, 0.040870026751820526, 0.07958554875637804, 0.026365823345258832, 0.12122614362410136, 0.19292274569826467, 0.1009035584117685, 0.04743960958772472, 0.024233778107113073, 0.014532966506002205, 0.04420426980193172, 0.08425904012152127, 0.04883224503802402, 0.04963181713329894, 0.03324153234383889, 0.09167179771299873, 0.10922485403716564, 0.036288181718971045, 0.024054992611386945, 0.041690073641283174, 0.013717284293047019, 0.1281659419515303, 0.2444655549313341, 0.25980101632220404, 0.15553106926381588, 0.3202623134212834, 0.17384555722985948, 0.3641770455454077, 0.08786098898521491, 0.18956668435462884, 0.10055732913315296, 0.10412870320890631, 0.0732057521651898, 0.06719383011971201, 0.062390955697212896, 0.05512916536203452, 0.02578741465029972, 0.04421364376321435, 0.08494382444769144, 0.07006591279059649, 0.041308211096163304, 0.14279359632304736, 0.062286495231091976, 0.16266524073268684, 0.026930400103862797, 0.17559682897159032, 0.1417101523173707, 0.05648393855829324, 0.00714299242411341, 0.11900528493736472, 0.25752781544412884, 0.045385158221636496, 0.08774638442056519, 0.012888285830350859, 0.02953574387356639, 0.02952430716582707, 0.0068918246293573505, 0.0544715190439352, 0.7641658123050417, 64.59276090349469, 102.45489161355155, 99.21007592337472, 97.54096576145717, 95.81317806243896, 93.7770779473441, 42.28680958066668, 23.907285281590053, 47.041809286390034, 64.66057532174247, 86.09512874058315, 81.67852715083531, 4.924430659839085, 0.8254191769020898, 0.002447707998466545, 0.02567591777603541, 0.4613179372889655, 0.20470621197351388, 0.11992494416024004, 0.03423887364832418, 1.203235183443342, 1.3164109161921909, 2.133772679737636, 13.279436230659485, 59.31444372449602, 93.34521961212158, 97.04683767046247, 98.06078829084123, 97.14384147099086, 96.04898602621896, 96.38939911978585, 101.00092547280448, 99.71139539991105, 94.28607518332345, 91.27583067757743, 90.32875646863664, 88.86864117213658, 82.37816211155483, 74.5978125163487, 81.14995683942522, 90.92031220027378, 96.92559855324882, 97.52215003967285, 90.26958560943604, 95.24082715170724, 93.17317526681083, 74.73290634155273, 33.410649163382395, 9.899966188839503, 1.7641285146985735, 6.517778532845633, 44.55764068875994, 61.184606960841585, 80.93864127567836, 96.63388538360596, 102.46231923784528, 101.68907506125313, 109.76987865992955, 107.02454117366246, 104.18327685764858, 88.94571059090751, 88.5657205581665, 88.45743288312639, 97.28459112984794, 101.04597759246826, 98.73520129067558, 91.38248552594865, 91.97377722603935, 94.82723563058036, 96.81786673409599, 95.02780927930559, 98.13716983795166, 99.5315968649728, 91.31538677215576, 82.87904385157994, 87.96886335100446, 96.23253658839634, 95.49363735743931, 92.1150757925851, 85.97511945452008, 92.80921472821916, 87.76803956712995, 99.32718086242676, 47.08451986312866, 1.2045790084770747, 0.1999337359198502, 0.2905010346855436, 0.021642614022961686, 0.21838798852903502, 0.12290136516094208, 0.32008171454072, 0.3102338101182665, 0.3640814263905798, 8.386685013771057, 38.563144888196675, 52.154686382838655, 54.33902631487165, 37.381773948669434, 25.09831769125802, 31.72137185505458, 29.385345799582346, 66.75154536111015, 84.03289645058769, 68.95744555337089, 79.58884252820695, 57.867321559361045, 11.425832288605825, 0.08608927298337221, 0.24906070264322416, 0.06866834778338671, 0.21545389454279626, 0.041126567271671126, 0.05137775558978319, 0.030209892163319246, 0.08062222134321928, 0.060692853959543366, 0.05263321840071252, 0.05611505638808012, 0.08243266133857624, 0.09057572617062501, 0.06617165782621928, 0.19213105817990644, 0.20815433694847993, 0.1407792294131858, 0.04639291503865804, 0.027022748719900846, 0.027266885619610548, 0.05227661092898675, 0.012338146600606186, 0.05240084729822619, 0.06007882047976766, 0.03426695821274604, 0.10051114125443356, 0.041536466883761544, 0.026091430569067597, 0.017364861244069676, 0.08916663963879858, 0.035363864353192706, 0.2317118921450206, 0.20481477757649763, 0.30544446568403927, 0.15039978389229092, 0.3109474118266787, 0.36058056567396435, 0.46430663977350506, 0.15568209758826665, 0.2561656971062933, 0.19351210764476232, 0.20156607404351234, 0.16029765563351767, 0.16181074801300252, 0.1450159206454243, 0.1745909143771444, 0.05335587515894856, 0.166049366284694, 0.15230477095714637, 0.15142651594110898, 0.117672452170934, 0.17249296552368573, 0.14365342232797826, 0.3035649779651846, 0.2796550595334598, 0.20904955533998354, 0.18743375023560865, 0.09222443055893693, 0.20169532139386448, 0.19910331762262753, 0.2528242649776595, 0.08306682016700506, 0.2210556896669524, 0.14664082202528203, 0.17076802094067844, 0.2598688155412674, 0.08994263942752566, 0.13846950978040695, 0.8937572613358498, 73.45913478306362, 117.63072313581193, 105.07384831564767, 98.90590463365827, 89.95993219103131, 76.52212306431362, 44.217939785548616, 55.34683820179531, 119.15911837986538, 100.8929226739066, 95.23465715135846, 100.55088370186942, 7.461269208363124, 1.2982122812952315, 0.16688263442899498, 0.2724771632679871, 0.4269302168062755, 0.2347767534000533, 0.47640128220830646, 0.21246144654495375, 1.6078595114605767, 6.289786423955645, 4.419949318681445, 10.671825068337576, 57.10494783946446, 100.50312873295375, 99.50179604121617, 105.22957829066685, 104.25244617462158, 102.42383316584996, 103.337813104902, 109.32729230608258, 109.33959756578717, 103.05413205283028, 96.0876874923706, 96.88355500357491, 96.41628170013428, 90.76970999581474, 81.81492028917584, 84.59821578434536, 96.04552582332066, 99.36233179909843, 101.68650422777448, 98.18757207053048, 102.63622570037842, 100.39291640690395, 75.31686074393136, 30.661781992231095, 8.997779948370797, 2.3614825180598666, 4.642039367130824, 49.22160162244524, 73.67860753195626, 87.20096928732735, 102.7577566419329, 107.18118136269706, 107.91157599857875, 114.0684095110212, 111.96480069841657, 104.79123033796037, 95.58153206961495, 102.19201346806118, 93.67723928179059, 102.24516718728202, 108.4510897227696, 104.8068846293858, 100.67250497000558, 99.1052553994315, 103.26299490247453, 103.5892058781215, 101.98638153076172, 103.60725034986223, 102.87555640084403, 91.97688307080949, 83.67713478633335, 94.03748253413609, 105.49279689788818, 103.39274556296212, 99.25564915793282, 91.64203548431396, 94.26439680371965, 89.01069014413017, 109.24940994807652, 43.008675302777974, 1.0814346734966551, 0.5559834518602916, 0.5838928456817354, 0.10569696727075747, 0.37830702162214686, 0.23509126795189722, 0.3246165540601526, 0.8331892713904381, 0.7972281096237046, 16.262342180524552, 53.48563814163208, 59.23131547655378, 96.85408769335065, 93.57042462485177, 67.3934963771275, 44.48351035799299, 20.995673928941997, 53.14504439490182, 73.95279039655412, 68.5866618837629, 92.27035413469586, 66.31621292659214, 9.050528066498892, 0.14301760787410395, 0.2776133476623467, 0.1261527014097997, 0.3192875028720924, 0.18831199168094567, 0.19752652437559196, 0.09865060501864978, 0.12359465153089591, 0.20065343087272985, 0.12553332107407705, 0.15820767278117792, 0.2240923645773104, 0.20626692394060747, 0.17009281074362143, 0.2778424210846424, 0.4656900369695255, 0.4834596206034933, 0.10466388413416487, 0.11914112764809813, 0.08751485470150198, 0.13608715975923197, 0.13868024918649877, 0.16148039645382337, 0.1674456149339676, 0.132768024291311, 0.16243324960981095, 0.15065324386315687, 0.0834273597491639, 0.13292507800672734, 0.1250458750873804, 0.08901847473212651, 0.19670320355466434, 0.3015141465834209, 0.2956269324890205, 0.1836679351649114, 0.35461369156837463], [0.08299458332891975, 0.14855081667857511, 0.11919565472219672, 0.09089720927711044, 0.21707545753036225, 0.030052285441862683, 0.05414217850193381, 0.15242157397525652, 0.2720819573317255, 0.07509693782776594, 0.039126459775226455, 0.050006310788116286, 0.03251290787011385, 0.018126815357910733, 0.0799732840220843, 0.14479823304074152, 0.03775568672322801, 0.031828313533748896, 0.022497590198846798, 0.04176153016409703, 0.054849120389137945, 0.10409540749554123, 0.12461516819894314, 0.02626694891867893, 0.10748705800090518, 0.07145623782915728, 0.008269034858260835, 0.01292919640296272, 0.12034429237246513, 0.10706138584230628, 0.14597209862300328, 0.08991857857576438, 15.50764969417027, 85.54409490312848, 78.86616734095982, 67.67299461364746, 61.32177134922573, 44.405846868242534, 34.95175961085728, 44.896261147090364, 78.6804141998291, 74.52052770342145, 81.96914945329938, 63.88663632529122, 1.543284039412226, 0.28478885548455374, 0.25092143565416336, 0.19747742558164255, 0.09933728245752198, 0.09213864337652922, 0.04901537824688213, 0.34117044721330914, 0.38094022603971617, 4.987016992909568, 26.603952373777116, 68.31286811828613, 100.68838855198452, 103.04984501429966, 101.38270119258335, 95.63515826633999, 87.46723815373012, 83.16280828203473, 79.55339976719448, 83.02063424246651, 83.04791287013462, 83.4756578717913, 81.38714054652623, 80.30087307521275, 80.69668415614537, 72.38479736873082, 71.22265556880406, 83.33526951926095, 84.79767077309745, 94.52858121054513, 94.50060081481934, 93.61776965005058, 81.01921258653913, 80.68140506744385, 85.49930681501115, 94.97166783469063, 73.2439351763044, 37.17002064841134, 20.634259905133927, 34.24320316314697, 52.026495592934744, 64.83707346235002, 88.7384249823434, 85.60029193333217, 96.13183634621757, 91.48138618469238, 97.2175132206508, 98.79870087759835, 114.67811393737793, 102.68326500483921, 76.71994522639683, 85.7783534186227, 93.66050801958356, 95.22184467315674, 88.43203026907784, 78.8078441619873, 84.72920322418213, 93.39569132668632, 90.19644887106759, 88.75991576058524, 100.41096087864467, 98.10643100738525, 95.45199680328369, 89.18337372371128, 83.81588336399624, 84.75129849570138, 78.78238596235002, 71.95474556514195, 79.50144113813127, 89.86113575526646, 94.01661014556885, 91.3409561429705, 78.86891187940324, 37.08596134185791, 3.006422345127378, 0.4330826295273644, 0.06471625449401991, 0.0897267431552921, 0.1152792184480599, 0.08853412286511489, 0.4147401994892529, 0.10403634102216788, 0.10204178733485085, 2.862453064748219, 26.275271313531057, 55.13337911878313, 71.15617520468575, 76.3740291595459, 64.7875189099993, 42.44050373349871, 18.28525808879307, 28.208239316940308, 53.566060066223145, 60.70987824031285, 62.23999663761684, 66.51620292663574, 22.81740300995963, 0.5438188388943672, 0.2820492024932589, 0.07846336718648672, 0.264211792498827, 0.04663659053455506, 0.1280337090470961, 0.03624500992840954, 0.1263301790292774, 0.011872380655924124, 0.016723096038081815, 0.07705751726669924, 0.01246098688404475, 0.07253265221204076, 0.0281262112049652, 0.16234309944723332, 0.05119464952232582, 0.02625770727172494, 0.051855311928583045, 0.034390597471169064, 0.0579812651766198, 0.08828287491840975, 0.009118950859244381, 0.12376638874411583, 0.014911285401987178, 0.1319485032664878, 0.01058447199674057, 0.10089169083429234, 0.09455088965062584, 0.01829103270678648, 0.15631400368043355, 0.2306317186781338, 0.14447781523423536, 0.10162843058684043, 0.2498216118131365, 0.08865117694118194, 0.14503627669598373, 0.128897864105446, 0.1549246489469494, 0.06491256824561528, 0.14233444524662836, 0.049244740046560764, 0.08999144645141703, 0.22474024338381632, 0.2800198128180844, 0.03264768188819289, 0.05141580104827881, 0.06998096699161188, 0.06111677549779415, 0.021184541817222322, 0.09644383271890027, 0.10919693232114826, 0.14613376637654646, 0.0826687440276146, 0.04055939681295838, 0.022976423879819255, 0.043792266731283495, 0.11619899980723858, 0.08405401398028646, 0.10543807223439217, 0.010176563036761113, 0.11028712775026049, 0.043619236908853054, 0.07367742221270289, 0.18257790936955384, 0.16949191370180675, 0.14603090046771935, 0.11109798388289553, 30.358864852360316, 100.64023753574916, 93.69565200805664, 92.4057536806379, 88.57583713531494, 71.39734022957938, 34.736914362226216, 26.86668460709708, 45.64471067701067, 76.76241261618478, 92.72861562456403, 69.99301201956612, 1.7164449819496699, 0.2867484374770096, 0.0792283204251102, 0.28699252009391785, 0.2632246326122965, 0.025620605297652737, 0.08134207914450339, 0.4080491656703608, 0.4680650181003979, 10.21163284778595, 39.24652106421334, 82.01154736110142, 107.89968068259103, 107.49494116646903, 103.69180992671421, 97.48897933959961, 91.42418166569301, 86.43720245361328, 84.19524805886405, 86.66534655434745, 87.512832232884, 87.86735016959054, 86.75303282056535, 86.38818986075265, 85.64264120374406, 76.90691430228097, 76.01657908303397, 90.92573874337333, 92.93509524209159, 100.581789289202, 98.83082239968437, 97.70474175044468, 86.46787875039237, 85.0640924998692, 89.80912848881313, 100.16208335331508, 80.30496556418282, 48.57727084841047, 33.52854272297451, 46.2258962222508, 64.9785179410662, 75.98142119816372, 96.59539931161063, 91.92593193054199, 99.81156757899693, 98.00702313014439, 100.23724201747349, 107.45273086002895, 117.6445917401995, 109.81544494628906, 82.97565160478864, 86.19467558179582, 94.28069032941545, 96.43289484296525, 90.33241816929409, 82.75751985822404, 87.805816922869, 94.55978557041713, 91.78048528943742, 90.2191972732544, 102.55662713732038, 99.88976955413818, 97.0657159260341, 91.20065116882324, 88.55243560246059, 88.78133705684117, 81.54630293164934, 74.30855900900704, 86.8891966683524, 92.81332806178501, 99.86914730072021, 95.08572251456124, 85.64824840000698, 55.076261452266145, 8.013299243790762, 0.2322393852685179, 0.025790004957733408, 0.1124343586021236, 0.16210592431681498, 0.09896585238831383, 0.4522173984774521, 0.10821132627981049, 0.0470881454114403, 2.340059050491878, 27.864042929240636, 63.515637261526926, 70.58057253701347, 52.02796513693673, 23.5082745552063, 21.148457867758616, 22.65024151120867, 49.67455816268921, 80.19460732596261, 74.14692306518555, 75.63761043548584, 85.57294382367814, 40.075746876852854, 2.2024093738624027, 0.24772008029477938, 0.02269565117811518, 0.2433886384325368, 0.06582311474319015, 0.13620515699897492, 0.04508555447682738, 0.07377721435789551, 0.013641885481774807, 0.045849893641258986, 0.08190824197871344, 0.023212299615676914, 0.1283289667751108, 0.06378883961588144, 0.2026848290115595, 0.09478549313332353, 0.10209210070648364, 0.02786140443224992, 0.02645486579941852, 0.02836978661694697, 0.04883093885811312, 0.050263926785971434, 0.055824558583221266, 0.09266951560441937, 0.12078791856765747, 0.05247362357165132, 0.015947427035176327, 0.020936276031924144, 0.06101946679076978, 0.1209964459495885, 0.2551461032458714, 0.1707847671849387, 0.12550968091402734, 0.15428339264222554, 0.10483850512121405, 0.18162490693586214, 0.18162496121866362, 0.1971599661878177, 0.1540232558867761, 0.2464220156627042, 0.13472426789147512, 0.10266812265451465, 0.2205529630716358, 0.32783880829811096, 0.15953051751213415, 0.12173314499003546, 0.13336231240204402, 0.2453270229910101, 0.16533727092402323, 0.16758007343326295, 0.1683282261448247, 0.21242833403604372, 0.1629238711403949, 0.06908269519252436, 0.08985060293759618, 0.1069668387728078, 0.163212777780635, 0.15347590882863316, 0.2742642345173018, 0.2425821317093713, 0.1701280674231904, 0.14295318775943347, 0.09615224586533648, 0.2936308453125613, 0.2928661092051438, 0.30098035665495054, 0.37979741021990776, 39.439760889325825, 120.43785095214844, 102.47239412580217, 92.1712589263916, 76.59878948756626, 57.895826544080464, 45.804675579071045, 59.45133713313511, 105.3718843460083, 102.20355442592076, 98.06098284040178, 86.49830491202218, 3.4441471312727248, 0.33322993186967714, 0.3940260724297592, 0.3206604506288256, 0.2718680830938475, 0.21517585803355488, 0.3232547342777252, 0.7702246414763587, 1.4313273898192813, 7.79486438206264, 31.540812492370605, 77.65017700195312, 109.00168582371303, 110.34377207074846, 108.62975570133754, 103.7972002029419, 96.17249720437187, 93.29984092712402, 90.19885989597866, 91.30809116363525, 92.27830287388393, 90.63825702667236, 90.20011751992362, 91.11619581495012, 89.33512238093785, 81.22191933223179, 81.93226841517857, 97.00281388419015, 97.58125836508614, 104.78988933563232, 103.64357553209577, 105.97828142983573, 92.18530818394252, 91.66329002380371, 97.4809958594186, 107.16663878304618, 84.50405379704067, 52.010400090898784, 30.2684132031032, 46.28693962097168, 79.38293266296387, 78.88856833321708, 102.16846602303642, 92.31090382167271, 106.09618541172573, 101.38780117034912, 104.59515912192208, 107.70456136975969, 120.62021337236676, 113.4906667981829, 90.73949922834123, 95.91831820351737, 103.35791424342564, 105.35705689021519, 96.40230887276786, 87.6341894694737, 94.66063867296491, 104.90500014168876, 103.30168942042759, 95.30532033102853, 105.73087692260742, 106.71768093109131, 105.6688642501831, 99.31583445412772, 93.14594527653286, 91.11102635519845, 86.50617722102574, 78.66990157536098, 89.25678144182477, 100.94905717032296, 106.07815483638218, 98.05723776136125, 86.63088348933628, 47.117926801954, 4.943171688488551, 0.7097864959921155, 0.23155276211244719, 0.2631309676383223, 0.15176274361354963, 0.21209130569228105, 0.8180271621261324, 0.1022130088614566, 0.2518046168344361, 6.102899857929774, 44.178553921835764, 68.81122071402413, 97.28612668173653, 116.98012161254883, 85.2575581414359, 54.56201137815203, 21.556871243885585, 36.42575740814209, 69.7137986591884, 77.57071045466832, 80.72991739000592, 98.02865982055664, 42.09032494681222, 1.8821844884327479, 0.4253480631325926, 0.21252867579460144, 0.40104901843837326, 0.07836806015776736, 0.29409971301044735, 0.15346095391682216, 0.24104462563991547, 0.063135010057262, 0.07834720199129411, 0.1460724946643625, 0.10805144307336637, 0.17996804655662604, 0.1830574707793338, 0.33438764831849505, 0.20845623074897698, 0.21307307801076344, 0.13150156582040445, 0.09513610574815955, 0.09769529556589467, 0.16700821769024643, 0.12147061979132039, 0.1756262638206993, 0.14330010914376803, 0.20961923977094038, 0.14011859414832933, 0.17173839387084755, 0.1920644667531763, 0.24430151230522565, 0.18606374732085637, 0.20891315623053483, 0.1842018879417862, 0.16597152474735463, 0.26786136095012936, 0.18459231699151651], [0.15106003917753696, 0.09495395302240338, 0.05876291037670203, 0.05059048533439636, 0.09214692150375672, 0.08458235527255706, 0.028192013834736178, 0.1262005924114159, 0.18999977968633175, 0.12141230649181775, 0.0338615912145802, 0.060269400610455444, 0.08781594104532685, 0.1426864827850035, 0.043943067746503015, 0.14127124872590813, 0.09426271582820586, 0.06141214857676199, 0.028082189549292837, 0.029205629801643745, 0.03139332848201905, 0.03715422310467277, 0.04272814401026283, 0.009881927016457277, 0.09914935539875712, 0.08210896620793001, 0.06331455042319638, 0.09289716410317592, 0.15745662951043674, 0.16157697912837776, 0.1670882033982447, 2.8006824936185564, 67.68776648385185, 80.85051727294922, 65.21582671574184, 75.05468436649868, 43.993596349443706, 28.626876967293875, 71.2881770815168, 74.88486344473702, 81.26466464996338, 94.77492264338902, 49.56855991908482, 0.6780563529048647, 0.10917944647371769, 0.0419762152513223, 0.23793617529528482, 0.027633791556581855, 0.09856641917888607, 0.1613835287945611, 0.4810960388609341, 5.699973387377603, 51.280814920152935, 94.28119059971401, 105.74930354527065, 95.04575647626604, 91.32485021863664, 91.59054933275495, 95.12089429582868, 93.91668810163225, 94.79605906350272, 85.6665291104998, 81.33436897822789, 77.90293162209647, 77.44489247458321, 76.74377059936523, 77.09920569828579, 73.15028735569545, 72.40362003871373, 69.77775682721818, 80.56505748203823, 87.90462725503104, 102.95215334211076, 94.5579581941877, 92.73221479143415, 82.55028288705009, 75.75886344909668, 72.50033896309989, 83.73000362941197, 86.2680138179234, 79.23763193402971, 58.749596868242534, 67.43579006195068, 56.41276134763445, 58.42584555489676, 83.23159544808524, 90.67135824475969, 95.28209250313895, 86.14222363063267, 91.79383972712925, 95.11742714473179, 104.37621443612235, 104.87198230198452, 95.68102332523891, 80.10655975341797, 73.38191250392369, 88.08471761431012, 98.5135884966169, 90.9976248059954, 81.53851400102887, 72.52806922367641, 69.43662112099784, 74.4109685080392, 84.650132724217, 90.05269759041923, 90.0281982421875, 83.59915515354702, 77.07117666516984, 80.18906266348702, 81.21953610011509, 76.86691352299282, 90.2567800794329, 93.60148307255336, 91.6387003489903, 88.80719130379813, 91.39481857844761, 92.16442189897809, 98.89441231318882, 83.1513784953526, 21.11465835571289, 0.18481624711837086, 0.08239568118005991, 0.08851712556289774, 0.05119907017797232, 0.13025642691978387, 0.1849462001451424, 0.04651864079226341, 0.12956916594079562, 0.5821099270667348, 18.24370959826878, 72.99118055616105, 76.83849539075578, 76.80657536642892, 67.7036361694336, 69.3444185256958, 28.909208331789287, 24.02175337927682, 44.05471617834908, 47.8036653654916, 60.484520367213655, 66.19145802089146, 51.86912931714739, 5.386007308959961, 0.42639257279889925, 0.06033648058239903, 0.18617696767406805, 0.04867494705000094, 0.17211346088775567, 0.04870342516473361, 0.058028172302458964, 0.10628386613513742, 0.04738015974206584, 0.030846795665898492, 0.040077480886663706, 0.03228271147236228, 0.02230150206014514, 0.05071469456223505, 0.011010355349364025, 0.0773104140534997, 0.013131951996391373, 0.12939152547291347, 0.06844649397368942, 0.09039693219321114, 0.0778311218268105, 0.036492230769779, 0.13187573717108794, 0.012686246939535652, 0.037882016372999976, 0.11602076222854, 0.03969534353486129, 0.05104874074459076, 0.14525228153382028, 0.21808884958071367, 0.1593087858387402, 0.045863084362021515, 0.1218861953488418, 0.11412983440927096, 0.11781073760773454, 0.011733719480356999, 0.10912851563521794, 0.10624166804232768, 0.13875885068305902, 0.021759089647925327, 0.08296911112431969, 0.12178023532032967, 0.13434375902371748, 0.026841766467051845, 0.1466806520308767, 0.05564032614763294, 0.08439050628138439, 0.029309957953436033, 0.12204832450619765, 0.07262358268988983, 0.014973288235653723, 0.0673445938155055, 0.07088972215673753, 0.009607506250696523, 0.046442834859980006, 0.019984133641368577, 0.09341624339244195, 0.06534860163394894, 0.04536258675424116, 0.07849175030631678, 0.11824419934834753, 0.16901657277984278, 0.3448421359062195, 0.28294448873826433, 9.093434929847717, 89.80595316205705, 92.4114442552839, 91.55697563716343, 96.08772223336356, 71.86449541364397, 21.241673163005284, 31.086872782026017, 50.70307220731463, 82.37163775307792, 102.9748808997018, 54.8922245161874, 0.6658950511898313, 0.09023785644343921, 0.05399607294904334, 0.22779025829264096, 0.06497762618320328, 0.04074134597820895, 0.18753520479159697, 0.33584253596408026, 12.012703197343008, 69.65107032230922, 105.604537827628, 112.4420724596296, 97.19864886147636, 92.80641460418701, 95.24268232073102, 97.47957842690604, 100.41774232046944, 99.90137999398368, 89.48587744576591, 84.35340295519147, 80.73618466513497, 81.38497965676444, 79.90428379603794, 79.46785354614258, 77.14782224382672, 75.99740205492292, 72.7405173437936, 87.32309082576207, 93.28251211983817, 106.80107321058, 100.11911569322858, 97.80046013423375, 87.54530116489956, 79.73558848244804, 74.62506335122245, 86.24276406424386, 88.38401821681431, 84.48340375082833, 64.67466626848493, 79.66919149671281, 67.9251377923148, 70.98463807787213, 91.34945378984723, 93.93260642460415, 100.16407748631069, 91.3016779763358, 96.88600076947893, 100.53463881356376, 107.67660876682827, 110.05804824829102, 99.71826716831752, 87.33869647979736, 79.24736636025565, 92.49524647848946, 102.39705480848039, 94.78619956970215, 86.23990835462297, 76.2728078024728, 71.89327485220772, 77.86809335436139, 88.71958146776471, 91.75365829467773, 91.79545865740094, 86.07329055241176, 81.46410574231828, 83.65413624899728, 82.16407421657017, 79.26441029139927, 92.98426069532121, 96.27471910204206, 96.66654886518205, 92.74168518611363, 93.09857940673828, 95.28814438411167, 100.44848809923444, 93.58980315072196, 35.234057971409385, 1.5727100947073527, 0.06738282926380634, 0.03682246358532991, 0.026148704013654163, 0.17205669464809553, 0.10142214915582112, 0.02730063934411321, 0.17236891575157642, 0.08659821495945964, 16.95459294319153, 76.86313370295933, 79.34279986790249, 67.39121736798967, 44.65468965257917, 35.81142895562308, 17.462799821581157, 34.145379475184846, 77.20659010750907, 70.12208870479039, 76.41862269810268, 78.10349137442452, 74.99725750514439, 12.805405804089137, 0.4836298514689718, 0.1742346699216536, 0.16155761373894556, 0.10971578090850796, 0.08022348702486072, 0.04738259907545788, 0.04747173822085772, 0.013591917314832764, 0.035718839948198626, 0.06432434623794896, 0.023582691526306526, 0.03937595710158348, 0.009896963352470525, 0.06539512878017766, 0.05702316015958786, 0.05272892576509288, 0.03707734169438481, 0.13898549494998796, 0.014783011749386787, 0.07166896534285375, 0.04559052023770554, 0.009706675840009536, 0.08079719516847815, 0.013943166056248759, 0.025995891142104353, 0.06581894853817565, 0.0983672487948622, 0.07849808103804078, 0.22028776444494724, 0.18383640183934144, 0.18525424147290842, 0.07115967052855662, 0.1844473411994321, 0.2206660612885441, 0.1985501894461257, 0.1261238365301064, 0.18925735381032738, 0.15548720876021044, 0.1896242784070117, 0.10910507903567382, 0.20734346045979432, 0.29366667196154594, 0.2675465207014765, 0.10643343560929809, 0.22292558290064335, 0.19129445164331368, 0.21094350942543574, 0.07982072899384157, 0.298220049057688, 0.16006286894636496, 0.1708711175514119, 0.16544207744300365, 0.2792328750448567, 0.10425214908484902, 0.11950281395443849, 0.143356251131211, 0.19978144552026475, 0.20823710465005466, 0.2574635446071625, 0.16874594587300504, 0.19728519661085947, 0.37135119629757746, 0.4755451338631766, 0.3387613764830998, 13.407825912748065, 108.43628311157227, 104.11317648206438, 90.36466475895473, 90.5357780456543, 54.65101432800293, 41.15084859303066, 96.26298359462193, 105.1355483191354, 109.90915530068534, 110.3941673551287, 71.24216611044747, 2.3602136032921925, 0.18855493435902254, 0.30743792014462606, 0.3131669812968799, 0.18194011359342507, 0.23681737961513655, 0.4478384048811027, 0.9114543774298259, 9.409036006246295, 63.24984087262835, 106.21133095877511, 121.0567547934396, 107.04282188415527, 98.23179040636334, 98.08572537558419, 104.97532285962785, 105.07855224609375, 104.06799234662736, 95.32277420588902, 88.8900624683925, 86.51398699624198, 87.91828046526227, 85.63722855704171, 85.05259323120117, 81.74242973327637, 83.17988695417131, 77.06294304983956, 91.50194590432304, 96.76153073992047, 110.94368648529053, 102.8778770991734, 102.16599941253662, 94.05870233263288, 84.97173704419816, 80.96169539860317, 93.10729244777134, 96.22852747780937, 89.0720705304827, 73.9706403187343, 91.8973331451416, 77.97797911507743, 83.5181530543736, 95.89942605154855, 100.93079035622733, 103.75393377031598, 97.14571053641183, 103.74241365705217, 107.81397465297154, 110.8802980695452, 113.20326151166643, 105.201479775565, 97.04192529405866, 86.97663279942104, 96.4749870300293, 105.9577078138079, 102.03289972032819, 88.56553990500313, 81.58541434151786, 76.63681697845459, 83.44762189047677, 95.35423564910889, 100.89800875527519, 98.44416904449463, 89.59552001953125, 83.47922229766846, 87.05611324310303, 88.34766524178642, 85.78557954515729, 98.69952923910958, 102.85062626429966, 98.62100764683315, 95.61982359204973, 98.2401282446725, 99.99039336613247, 105.77900709424699, 90.77804783412388, 26.020621572222026, 1.0223429586206163, 0.5641887858510017, 0.16906181749488625, 0.16562076285481453, 0.3337804951838085, 0.3972128799983433, 0.14868652368230478, 0.4154977431254727, 1.4065162411757877, 31.674061570848735, 88.9667636326381, 92.79156630379813, 110.62744617462158, 95.31151812417167, 93.27397973196847, 36.00884812218802, 28.633623668125697, 59.87855407169887, 64.03572382245744, 75.25204794747489, 91.51597431727818, 86.093092918396, 12.574293954031807, 0.7240672696913991, 0.21268449457628386, 0.2236411523606096, 0.13853467628359795, 0.1555760968476534, 0.2089161282139165, 0.16156343556940556, 0.16622711531817913, 0.09407508732484919, 0.08187338563480548, 0.2234490726675306, 0.21885157722447598, 0.18247336069388048, 0.1625078884618623, 0.11998185967760426, 0.18149014988115855, 0.08493251326893057, 0.24220046933208192, 0.09146695477621895, 0.17605946771800518, 0.16872937604784966, 0.13781164293842657, 0.2651080015514578, 0.09492804655539137, 0.08688493671693973, 0.14378485456109047, 0.16996523258941515, 0.11020535070981298, 0.1727676907820361, 0.1817680506833962, 0.29206283230866703, 0.12516141603035585, 0.19799906973327908], [0.1529712551938636, 0.05347373329901269, 0.1573840534048421, 0.2300356120935508, 0.21010486728378705, 0.09330405441245862, 0.11830722168087959, 0.040523546415248086, 0.02127910585009626, 0.04393445713711636, 0.08485290075519256, 0.05720756562160594, 0.12545515383992875, 0.06972990224936179, 0.09255564385758978, 0.042451997221048386, 0.1442609690129757, 0.07635543029755354, 0.06388567334839276, 0.025757625266643505, 0.03481332139511194, 0.03370089376611369, 0.03119670260431511, 0.017648706013070684, 0.0865218797698617, 0.03161748931077974, 0.0437504452254091, 0.05032185671318855, 0.13388574788612978, 0.281986695847341, 3.384025671652385, 52.479017870766775, 87.06839765821184, 79.28180858067104, 69.10942350115094, 37.42441156932286, 36.183108942849294, 84.32367856161935, 65.87983131408691, 83.36623069218227, 89.13081060137067, 42.95184598650251, 0.9410133170230048, 0.151472181347864, 0.08438057252871138, 0.044315159387354336, 0.18874675620879444, 0.14805053280932562, 0.02863078171919499, 0.2624002125646387, 28.1225836617606, 93.26728166852678, 101.48360988071987, 83.48874132973808, 76.57669421604702, 81.17085007258824, 91.71761104038784, 93.71330043247768, 96.68958909170968, 97.44255147661481, 86.98031534467424, 73.16483688354492, 69.30379935673305, 72.73245743342808, 72.95580727713448, 74.37950706481934, 74.63713932037354, 71.51504271371024, 69.5852222442627, 72.28362464904785, 81.48339394160679, 93.97330897194999, 93.90723160334996, 87.75377491542271, 90.71068504878453, 76.07381834302629, 67.64624404907227, 67.92742374965123, 81.84321335383824, 86.4906063079834, 85.90922968728202, 66.60252734592983, 71.04165499550956, 78.90882233210972, 79.47611495426723, 91.08251789637974, 88.26506505693708, 83.28351238795689, 80.73906816755022, 83.05004596710205, 86.67510877336774, 92.0683422088623, 96.69035339355469, 90.92042337145124, 81.02036598750523, 80.64059134892055, 86.27489253452846, 97.73798193250383, 88.72170761653355, 88.45878083365304, 77.11206681387765, 72.89451026916504, 71.1036468233381, 74.08474363599504, 75.65604400634766, 76.40768623352051, 75.4763149533953, 77.37463229043144, 79.8720372063773, 76.47308267865861, 74.62830815996442, 85.13022545405796, 84.331481388637, 90.90695776258195, 92.75972270965576, 87.91875989096505, 88.0333982195173, 86.78819070543561, 89.24027252197266, 94.2496040889195, 30.253307819366455, 0.17137680255940982, 0.30209668246763094, 0.11724847634988171, 0.054794043701674254, 0.0977243979328445, 0.03075642158676471, 0.1899242994508573, 0.04197584884241223, 0.2582505638045924, 7.0775063037872314, 70.48708452497209, 70.90310096740723, 65.12270695822579, 78.71072919028146, 93.33623559134347, 40.360407624925884, 12.369065012250628, 28.34087347984314, 38.91635308946882, 55.87222276415144, 66.05022198813302, 58.71457099914551, 6.425648893628802, 0.7986026587230819, 0.05481789420757975, 0.24302673499499047, 0.1273274083754846, 0.016596150617780428, 0.03870646356205855, 0.06348140896963221, 0.033553468462611945, 0.0653682995055403, 0.01950245350599289, 0.06354489949132715, 0.056100620555558374, 0.026109849402148808, 0.08247717323579959, 0.06237212635044541, 0.0936964037162917, 0.06377002383981432, 0.10215669724025897, 0.06853193510323763, 0.04086197593382426, 0.0844552181661129, 0.04958686079563839, 0.02211693374972258, 0.11761831864714622, 0.10396173609686749, 0.10980437722589288, 0.0912017629348806, 0.07997358257749251, 0.1290237730635064, 0.08859003415065152, 0.05518310550334198, 0.06659693643450737, 0.21816290489264897, 0.062346070605729303, 0.1416517983057669, 0.19256480490522726, 0.21794878638216428, 0.13330409409744398, 0.1391972793000085, 0.03437706069754703, 0.06399074449603047, 0.08777504573975291, 0.06340280747307198, 0.0981202484773738, 0.15794630109199456, 0.027389943034255078, 0.11084054091147014, 0.04172878067142197, 0.06957634298929147, 0.04120471075709377, 0.05624747249696936, 0.03299451506297503, 0.00849109307663249, 0.02193196171096393, 0.038559642154723406, 0.04473365264545594, 0.028141374766294445, 0.03009808316294636, 0.08699513080396823, 0.007655193064627903, 0.06389994293983493, 0.29786104975002153, 10.005644815308706, 78.4875738961356, 97.42968341282436, 99.57669067382812, 96.26690237862724, 64.5512593133109, 23.0635655266898, 50.99493823732649, 56.32559619631086, 86.33179828098842, 97.48035662514823, 51.38691391263689, 0.7369164430669376, 0.029563998071742908, 0.11890473961830139, 0.054383211103933196, 0.008322734967805445, 0.26104520527379854, 0.028379620285704732, 1.1208543011120387, 40.36103296279907, 102.94089726039341, 104.65066828046525, 87.75454616546631, 80.17407539912632, 86.6246509552002, 97.08025155748639, 100.3770397731236, 101.32856777736119, 96.65288870675224, 89.17627961294991, 77.08526066371373, 72.61705480303083, 76.85315608978271, 76.59213311331612, 80.2551817212786, 80.02833693368095, 76.93522126334054, 75.92187513623918, 75.42647552490234, 84.78482355390275, 98.7919819695609, 96.78970568520683, 90.79622432163784, 93.33322007315499, 79.86725684574672, 72.23456341879708, 70.42817074911935, 82.77483476911272, 89.75029114314488, 90.05813802991594, 73.4320923941476, 76.2785678591047, 89.95119830540249, 90.36240659441266, 98.60164996555874, 96.94070393698556, 88.41283934456962, 86.21426255362374, 87.39854826245988, 92.63731629507882, 99.05516583578927, 102.9286197934832, 98.51701395852226, 85.63992445809501, 84.95135102953229, 88.06535993303571, 98.97198895045689, 92.9555993761335, 90.80568081992013, 82.76975563594273, 76.31111322130475, 75.69432163238525, 76.87442452566964, 78.43246078491211, 76.7861407143729, 76.62854862213135, 76.97161592755998, 81.63157122475761, 79.54515920366559, 78.49272945949009, 86.44071129390171, 86.58088425227574, 92.85295363834926, 95.99832671029228, 89.8902348109654, 89.17706475939069, 91.57313019888741, 92.05345916748047, 100.26409680502755, 41.23807627814156, 1.4236428993088859, 0.10058786999434233, 0.16188022999891213, 0.3914466622684683, 0.11367313284426928, 0.06433333682694606, 0.14389366443668092, 0.05159640671419246, 0.5439564457961491, 5.321729958057404, 75.1007022857666, 77.18682943071637, 62.96348476409912, 77.91130420139858, 57.71657691683088, 22.107430866786412, 15.67109911782401, 50.5260842187064, 66.83753626687187, 70.9321791785104, 73.44375841958183, 75.39444432939801, 15.517854860850743, 0.892075200166021, 0.1071428032591939, 0.23041792586445808, 0.11068907153925725, 0.03943907782169325, 0.04740098737446325, 0.06877521026347365, 0.05417529779619404, 0.04666288037385259, 0.07471979449370078, 0.02702767658047378, 0.035773723253182, 0.052312037242310386, 0.07543841736125094, 0.016734676934512596, 0.11522847759936537, 0.06468793244234153, 0.029477915726602077, 0.055003103733594925, 0.029857155733874867, 0.0788574196132166, 0.03900051010506494, 0.061540025286376476, 0.08798201927649123, 0.07877356625561203, 0.13196860147374018, 0.07576828716056687, 0.04182782303541899, 0.08292991894164256, 0.08230885583907366, 0.08725896557526928, 0.11205993619348321, 0.2733227807496275, 0.10490954095231635, 0.251302745193243, 0.24024053450141633, 0.2542687846081597, 0.20095858164131641, 0.13229679529156002, 0.13201558323843138, 0.1337251929300172, 0.17293558748705046, 0.17796042428484984, 0.1509822519229991, 0.41644131392240524, 0.14674186946025916, 0.17126978401626858, 0.1222352609038353, 0.26930474064179827, 0.20466239218200954, 0.14216245019010135, 0.08388498412179095, 0.11788441294005939, 0.16532235672431334, 0.17145604187888758, 0.08378105969833476, 0.11273319220968656, 0.1365296324448926, 0.13832628460867064, 0.1742511447519064, 0.3004475166755063, 0.4434940979949066, 11.314624633107867, 94.11258561270577, 112.28176362173897, 102.65978009360177, 89.26863506862095, 48.533643109457834, 50.06565489087786, 113.62038271767753, 90.10538578033447, 109.8456209727696, 104.96499783652169, 69.81998103005546, 2.2065396436623166, 0.2602028176188469, 0.19773571672184126, 0.31999627341117176, 0.20395446302635328, 0.4179647336048739, 0.35269346460700035, 1.3124313354492188, 36.37658848081316, 103.29600579398019, 115.7798272541591, 96.77901935577393, 85.65747560773576, 90.594879422869, 101.57606955936977, 104.78477546146938, 107.3612369809832, 105.32413632529122, 96.04179464067731, 83.45375714983258, 76.80688108716691, 82.36156981331962, 79.61001368931362, 83.63769681113106, 82.37533419472831, 81.01275076184953, 79.4918943132673, 82.83704199109758, 92.59214605603898, 104.22793292999268, 101.657057762146, 94.6144539969308, 100.60614272526333, 86.15179824829102, 75.66712638310024, 74.74747671399797, 89.61021545955113, 97.36337675367082, 97.89721379961286, 83.5867178780692, 86.27390589032854, 99.5258229119437, 95.47313322339738, 96.3654556274414, 103.63012381962368, 95.42817837851388, 92.29690320151192, 91.47242995670864, 97.02497863769531, 103.66022341591972, 110.93029035840715, 103.90930243900844, 92.49158477783203, 89.50398445129395, 95.53495829445976, 107.79537432534354, 98.0035559790475, 97.13564954485211, 86.51132583618164, 82.682847567967, 80.13674272809709, 81.37789249420166, 85.7629006249564, 83.35424504961286, 82.60418701171875, 82.98713697705949, 87.39238521030971, 83.44063895089286, 81.91685731070382, 91.58361503056118, 93.40296609061105, 98.68144307817731, 102.04670579092843, 95.1566219329834, 95.49151815686906, 95.98268631526402, 100.52120099748883, 106.28082684108189, 35.24558155877249, 0.7812304251960346, 1.012325718998909, 0.29649179322378977, 0.6703944983226913, 0.2553691512772015, 0.2310660896556718, 0.5120123199054173, 0.24006020703486033, 0.6931127735546657, 13.523846064295087, 92.15768214634487, 81.03358840942383, 84.62359060559953, 107.21417835780552, 133.11796597072055, 54.09101731436593, 14.500305073601858, 36.522927965436665, 55.79948902130127, 73.03507232666016, 80.77917316981724, 90.86228779384068, 16.29975996698652, 1.0391295892851693, 0.1737835526998554, 0.36404804246766226, 0.20876633482319967, 0.1832202784717083, 0.08339139739317553, 0.09680045715400151, 0.14145091122814588, 0.12225622763591153, 0.16721742360719613, 0.14425928624612944, 0.11283345932939223, 0.13365989071982248, 0.1435064109308379, 0.19641166419855186, 0.1963287065071719, 0.0884150399693421, 0.08576375259352581, 0.17458229698240757, 0.16508845213268483, 0.19923177787235805, 0.13998921109097345, 0.1826565515782152, 0.15063716258321488, 0.12177203861730439, 0.18655267251389368, 0.14246842877141067, 0.11859828606247902, 0.1892276204058102, 0.23474393944655145, 0.19483020263058798, 0.21448543508137974], [0.21413003200931208, 0.255005239376, 0.15662299495722565, 0.07408947617347751, 0.08272912685892411, 0.12178722423102174, 0.09518648697329418, 0.05960192571261099, 0.13140838939164365, 0.14878151858491556, 0.24805837071367673, 0.10578852878617388, 0.04679498774930835, 0.03848149188395057, 0.015415023014481579, 0.05419267847069672, 0.17510578674929483, 0.127769799636943, 0.07146537769585848, 0.03564838765721236, 0.02438957822908248, 0.1226430061672415, 0.15273839554616384, 0.060465978990708075, 0.13082723771887167, 0.040031160693615675, 0.056911218844886334, 0.16391508866633686, 0.3185913259429591, 7.485342110906329, 65.34723104749406, 84.30427919115338, 61.57697868347168, 72.29709025791713, 54.38259499413626, 39.46863760266985, 109.20703983306885, 80.72269821166992, 90.86886773790631, 94.37699931008476, 38.23384543827602, 1.749309635588101, 0.14921769446560315, 0.13316057037029946, 0.05131431935088975, 0.15361758694052696, 0.10776054154017142, 0.17621250450611115, 0.12663452912654194, 46.70905658176967, 107.74397155216762, 88.09386839185441, 81.62906292506626, 80.76874392373222, 82.99821935381208, 78.73155294145856, 80.78571142469133, 81.00026484898159, 84.16106292179653, 78.31277111598423, 73.05667427607945, 67.68807220458984, 73.77616718837193, 80.07406302860805, 85.3506362097604, 85.70846148899624, 83.18987846374512, 76.92834949493408, 75.98851530892509, 75.24840709141323, 82.81671851021903, 90.96921362195695, 83.03022970472063, 87.23504325321743, 86.95131356375558, 68.27307578495571, 68.1648645401001, 62.24176148005894, 76.10987949371338, 87.19042887006486, 89.29674053192139, 70.87038884844098, 60.44746562412807, 75.97897543225969, 87.05252797263009, 109.03928252628872, 96.82127829960415, 91.07264450618199, 90.94795213426862, 92.74151842934745, 87.04370376041958, 90.30052593776158, 89.38179343087333, 84.05200399671281, 80.96196637834821, 81.83931541442871, 86.40657479422433, 99.0646779196603, 97.0432801927839, 86.43166473933628, 85.68249607086182, 80.78913688659668, 80.79579326084682, 82.00510638100761, 80.22707625797817, 79.27203941345215, 67.33789689200265, 67.21306555611747, 71.18632343837193, 75.30072702680314, 74.27659034729004, 79.99959918430874, 81.19268826075962, 77.14725249154228, 76.78268051147461, 80.18402521950858, 77.74055916922433, 80.22322000776018, 79.80224255153111, 81.29452800750732, 75.85652732849121, 22.984104190553936, 0.2662696806447846, 0.23271031571286066, 0.23118173916425022, 0.04841136672933187, 0.0495300233098013, 0.18689515627920628, 0.04822788746761424, 0.2811635514455182, 0.14472115146262304, 6.188247186797006, 75.29041590009416, 95.85476997920445, 79.11281449454171, 88.60226808275495, 102.50175026484898, 60.424571309770855, 17.45086281640189, 21.90502289363316, 39.900881562914165, 56.184217725481304, 64.88286903926304, 63.20789459773472, 16.399006298610143, 0.6106258226292474, 0.23648503316300257, 0.2047033892678363, 0.1444878304111106, 0.056623594635831456, 0.059042860354696, 0.06303675818656172, 0.044483300364975414, 0.04037937468716076, 0.060134894613708766, 0.07956410704978875, 0.09907237560089145, 0.04054929003385561, 0.14605156864438737, 0.059778480524463315, 0.07394036131777934, 0.04424103282924209, 0.06323134845920972, 0.15102224477699824, 0.03699599891634924, 0.09683052982602801, 0.07049900133694921, 0.194949584081769, 0.04565536443676267, 0.07915674176599298, 0.03297059331089258, 0.061176330516380925, 0.0594064329883882, 0.0749508220968502, 0.13621066670332635, 0.028177320158907344, 0.18698441077555927, 0.15453586195196423, 0.08009799875851188, 0.07931376155465841, 0.0953586788049766, 0.047004543111792634, 0.05367205212158816, 0.05707430812929358, 0.10243965312838554, 0.15654048509895802, 0.18961887726826326, 0.05287808472556727, 0.05417718073087079, 0.03818147762545517, 0.06329724778022085, 0.07748299943549292, 0.12948239488261087, 0.08715717853712183, 0.08967906928488187, 0.059981694977198324, 0.047689337615988085, 0.1593370943197182, 0.15281165018677711, 0.0520530336403421, 0.04352246085181832, 0.05450069604973708, 0.15559661574661732, 0.16067498895738805, 0.1449463436646121, 16.47961582456316, 91.75991167340959, 97.5272639138358, 86.59670530046735, 100.6289814540318, 82.5957727432251, 21.355609723499843, 56.87751940318516, 80.48689024788993, 92.9480675288609, 104.71252809252057, 41.537345613752095, 1.4562487325498035, 0.24690646252461843, 0.037688593180584054, 0.12935408391058445, 0.2344036405639989, 0.1921511563871588, 0.16677301031138214, 1.0892418431384223, 61.026472909109934, 113.08677496228898, 91.49590097154889, 86.79443713596889, 85.70561967577252, 85.43491091047014, 82.93291323525565, 83.49499470846993, 85.08981473105294, 86.00968674251011, 83.49533517020089, 75.88238157544816, 72.29460280282157, 79.3550842830113, 84.5276985168457, 90.44449956076485, 91.10013852800641, 87.56035791124616, 80.91366250174386, 79.98667553492955, 80.14908272879464, 88.80823353358677, 94.74809564862932, 86.89339338030133, 93.85933072226388, 90.59194728306362, 73.46031597682408, 70.90822873796735, 67.93441363743374, 78.19893877846854, 87.49985994611467, 92.40655967167446, 74.72549956185478, 64.6628473826817, 79.78888116564069, 90.69746262686593, 107.14312607901437, 101.39359596797398, 101.01131302969796, 95.29129191807338, 97.18926879337856, 95.23576191493443, 94.99462468283517, 95.63054466247559, 90.39349978310722, 85.3591616494315, 86.79028906141008, 88.30450998033795, 97.22606645311627, 100.05118315560478, 89.68756975446428, 88.2750357219151, 85.40201119014195, 85.34553623199463, 86.27090426853725, 86.1265971320016, 83.90571662357875, 71.87912831987653, 67.67742756434849, 74.26058864593506, 75.5681631905692, 76.38680689675468, 81.76073823656354, 83.33355331420898, 79.55736718858991, 76.94282954079765, 81.9329354422433, 80.67563806261334, 80.22571441105434, 84.48119422367641, 84.54909896850586, 83.68365914481026, 31.217790739876882, 1.3339759622301375, 0.24868623273713247, 0.2700179080877985, 0.23097815151725495, 0.03978218583922301, 0.34782199029411587, 0.13364062032529286, 0.12786536450896943, 0.10363673817898546, 4.036202047552381, 78.71933800833565, 93.50380529676164, 74.43190343039376, 97.68017292022705, 82.2693463734218, 19.373250450406754, 10.919043711253575, 34.4953567641122, 60.12821674346924, 83.86583396366665, 75.98818874359131, 78.3071847643171, 28.72174940790449, 0.7386197288121495, 0.30356174813849585, 0.1781065942985671, 0.15111486480704375, 0.014047568846893097, 0.07432245117213045, 0.04386896832979151, 0.00821962733087795, 0.012929427104869058, 0.034908088988491466, 0.08411698881536722, 0.1052760991400906, 0.051989743286477666, 0.10738575272262096, 0.0401603232270905, 0.049900099701647244, 0.04193803069314786, 0.05638283344783953, 0.09188760577567986, 0.08278313824640852, 0.08924241164433104, 0.07400050666183233, 0.07289287288274084, 0.09834852801369769, 0.05814990148480449, 0.02027175615408591, 0.05052283200036202, 0.08519858042044298, 0.051922561534281285, 0.055459008019949706, 0.07017687362219606, 0.2546134261148316, 0.27075401001742905, 0.19328823180070945, 0.210274677457554, 0.21783921654735292, 0.1954619458743504, 0.1998502625418561, 0.1278160892959152, 0.1937665447060551, 0.19985992488052162, 0.24565160700253078, 0.24143421330622264, 0.09623284225485154, 0.13002123311161995, 0.14512878816042626, 0.20041118030037197, 0.2503246505345617, 0.27995152505380766, 0.1284815285887037, 0.16749005897768907, 0.1324093235390527, 0.22228484228253365, 0.2422587147780827, 0.14104190388960497, 0.19293961407882826, 0.1454369787658964, 0.21892249770462513, 0.2244154286703893, 0.5427432251828057, 18.731445346559795, 112.9608736038208, 113.20376873016357, 85.82489245278495, 93.84599018096924, 67.58104215349469, 53.651588916778564, 149.62235559735979, 101.41680295126778, 107.87809262956891, 114.25589275360107, 60.28696918487549, 4.825709785733904, 0.46701475445713314, 0.28590159863233566, 0.14447193912097386, 0.3759385272860527, 0.3041885516473225, 0.6768432408571243, 1.4728214889764786, 56.83623668125698, 118.60839026314872, 101.62121895381382, 92.70278222220284, 88.67789922441754, 91.85501166752407, 87.84676265716553, 90.76183768681118, 89.13215855189732, 93.37782750810895, 90.60667746407645, 80.30657059805733, 76.06878089904785, 83.43818623679024, 88.9440916606358, 93.84329427991594, 94.70254325866699, 91.46478693825858, 86.0838657106672, 86.03771577562604, 84.88197326660156, 92.42575059618268, 100.13253961290631, 89.62931605747768, 98.03415584564209, 96.34266553606305, 79.49964155469621, 76.08242716108049, 70.89242158617292, 84.40903718130929, 96.03971018110002, 98.23460442679269, 81.50673988887242, 73.42931311471122, 92.61638137272426, 98.85310527256557, 109.60080814361572, 105.39880166734967, 105.55791541508266, 100.32779094151088, 103.80275876181466, 103.01178278241838, 103.71947765350342, 102.92643805912563, 97.69344397953579, 93.10488837105888, 91.42223617008754, 90.71226923806327, 103.28127561296735, 105.09296975816999, 94.3054120200021, 91.98447745186942, 88.64766761234829, 91.23336328778947, 90.51472500392369, 91.35697868892125, 88.95822429656982, 73.75984586988176, 72.5014784676688, 79.11796310969761, 82.28913484300885, 82.37504931858608, 87.39204474857875, 88.23032406398228, 85.31567982264927, 84.06391320909772, 88.11883326939174, 86.5090468270438, 87.87816851479667, 85.76276166098458, 89.73845836094448, 87.9667580468314, 28.236707823617117, 1.3977736702987125, 0.7445064815027373, 0.37723746044295176, 0.1935069372079202, 0.1791744184281145, 0.3701273633965424, 0.42693502083420753, 0.5101618192025593, 0.4346368004168783, 10.172517095293317, 97.73435497283936, 104.86702128819057, 83.91906411307198, 102.9119302204677, 140.85778672354562, 84.4287075315203, 25.96151324680873, 27.047605276107788, 54.47940424510411, 75.50776944841657, 82.12993771689278, 91.4619312286377, 30.327344349452428, 0.9112070649862289, 0.5064526210938181, 0.23292188293167523, 0.18931532784232072, 0.09899439157119819, 0.14013107919267245, 0.18607364036142826, 0.11864073521324567, 0.207316414053951, 0.09387320958610092, 0.11580036048378263, 0.22960780933499336, 0.179355492283191, 0.47303976544312065, 0.1313969221498285, 0.1833359415509871, 0.16020518488117627, 0.09465430517281805, 0.16901738702186517, 0.12927229329943657, 0.20028464709009441, 0.1773290881620986, 0.23118613607117108, 0.2209668830037117, 0.30807539022394587, 0.12984435260295868, 0.12005693279206753, 0.13730086891778878, 0.2793653793632984, 0.19684142113796302, 0.18448642481650623], [0.014568007750702756, 0.14862540124782495, 0.17920280833329472, 0.0945766129131828, 0.07943745170320783, 0.10381140666348593, 0.03121328939284597, 0.017693662350731235, 0.14708155766129494, 0.09209660813212395, 0.013089446018316915, 0.08558901625552348, 0.05354758505044239, 0.14121738661612782, 0.03610175422259739, 0.03689050029164978, 0.09008590531136308, 0.1974863822438887, 0.05030125978269747, 0.14839398009436472, 0.036890208521591764, 0.08776547161063977, 0.13911932919706615, 0.04548176125224147, 0.21277160490197794, 0.06570432361747537, 0.19417504992868218, 0.2707880181925637, 17.383967297417776, 75.69956752232143, 73.55319254738944, 71.67168985094342, 46.78145333698818, 26.474437952041626, 43.18516302108765, 99.27285289764404, 98.88404560089111, 96.43730000087193, 103.38144084385463, 34.576067038944785, 1.1673498004674911, 0.07575404471052544, 0.12377009354531765, 0.07915678926344429, 0.30028434257422176, 0.08491573988326959, 0.27699623363358633, 0.5142988743526595, 33.17889199938093, 110.60412802015031, 84.47664315359933, 88.70370483398438, 77.58321026393345, 70.07267311641148, 68.53860814230782, 75.19627475738525, 69.39507784162248, 73.01526301247733, 68.74581037248883, 73.3439336504255, 65.45045348576137, 73.80767032078334, 77.52393518175397, 87.16309465680803, 86.14409269605363, 84.7322256905692, 84.4265466417585, 85.27056516919816, 80.88874626159668, 85.3427986417498, 81.7817495891026, 92.48250348227364, 89.8800140108381, 86.26351138523647, 76.10650961739677, 69.982957976205, 72.14415345873151, 77.23379925319126, 69.3557927267892, 86.1302796772548, 88.27014419010708, 75.7194185256958, 57.30795335769653, 64.52349431174142, 72.88198961530412, 96.86118180411202, 112.82318115234375, 97.7066455568586, 93.63348647526333, 88.7924611227853, 92.02991172245571, 88.77281161717006, 85.35318619864327, 76.2501219340733, 75.0347569329398, 77.70034299577985, 90.58882059369768, 81.98071820395333, 86.62121159689767, 89.2702053615025, 86.98781939915249, 86.70871720995221, 85.3154991694859, 86.8350076675415, 87.83957127162388, 84.70646177019391, 81.83107485089982, 71.00095244816372, 70.02759320395333, 70.77620601654053, 71.00567027500698, 72.04275839669364, 69.62427112034389, 69.27511024475098, 70.97347927093506, 69.45679868970598, 68.57430798666817, 66.77245249067033, 73.51199667794364, 80.14223875318254, 76.588381086077, 54.72913987295968, 11.493632810456411, 0.16100934387317725, 0.3727376333304814, 0.19772943348756858, 0.025744512577408125, 0.02347812588725771, 0.10299907810986042, 0.10694999074829475, 0.1188734048711402, 0.15062980726361275, 3.821606934070587, 61.746702330453054, 88.16429533277238, 95.48604992457798, 100.89825194222587, 103.83333778381348, 92.31136240277971, 48.74609122957502, 24.188680376325333, 25.8694235597338, 53.121496949877056, 65.24926839556012, 72.78808471134731, 40.61339153562273, 4.813961250441415, 0.30411543271371294, 0.12272991293242999, 0.08505255289907966, 0.09875631398920502, 0.06858703893210207, 0.06243807316890784, 0.0752052455874426, 0.04201173995222364, 0.03625159850344062, 0.0446678076072463, 0.16652310586401395, 0.06487233111900942, 0.04180956365806716, 0.048328293686998744, 0.07063820279602494, 0.026292338002739207, 0.011249122492569898, 0.009312480072756963, 0.06832884278680597, 0.03669020693217005, 0.08640139909195048, 0.09648143712963377, 0.249639520155532, 0.026447530835866928, 0.02399901347234845, 0.03344918780827096, 0.025803334778174758, 0.14035209161894663, 0.0505519072259111, 0.11911930596189839, 0.09121071281177656, 0.11929550793554101, 0.1492737414581435, 0.03686400010649647, 0.07342083419540099, 0.046090912672558, 0.04855034427185144, 0.1568747314491442, 0.02647544746287167, 0.07954434811004571, 0.07803191390952893, 0.09615386756403105, 0.08307153598538466, 0.05081004908840571, 0.02008871115478022, 0.055182243763868294, 0.12756610342434474, 0.09330114349722862, 0.08575512162808861, 0.057965882787747045, 0.08029203263244458, 0.22382834660155432, 0.13547836456980022, 0.23977671510406903, 0.04193162192989673, 0.13441203321729386, 0.6035368144512177, 30.617633138384136, 98.30455194200788, 86.75512422834123, 98.34571307046073, 80.37274524143764, 47.098131384168354, 23.9597806589944, 60.29821831839425, 97.8522172655378, 99.81935650961739, 112.40023735591343, 38.29953718185425, 0.5845390281506947, 0.27162087921585354, 0.03412757354921528, 0.06074983054505927, 0.09705519955605268, 0.16832942036645754, 0.33800825689520153, 0.4935960652572768, 45.501994677952354, 114.54356207166398, 88.25833920070103, 94.77659715924943, 82.62979112352643, 74.13090746743339, 74.88550962720598, 79.04496533530099, 74.81920296805245, 76.6866841997419, 75.32212053026471, 76.60115882328579, 68.7741173335484, 79.08289555140904, 84.9209109715053, 93.30268968854631, 90.20306355612618, 89.61533628191266, 89.46125997815813, 92.53216920580182, 89.69638701847622, 88.9239557811192, 85.29308428083147, 95.3101006916591, 92.08331557682583, 89.8994620186942, 78.78032234736851, 74.28647068568638, 78.22696781158447, 82.27359867095947, 72.53857489994594, 86.4722352709089, 91.49352468763078, 83.33470671517509, 64.89153344290597, 67.74530451638358, 75.02813529968262, 95.20528711591447, 112.86623913901192, 100.98631341116769, 98.79005731855119, 96.21053164345878, 98.61323956080845, 94.73306669507707, 91.63154370444161, 82.46008832114083, 80.47526591164726, 83.80497469220842, 92.12142644609723, 84.58038670676095, 85.1039890561785, 93.25938851492745, 90.42124394008091, 91.0777027947562, 89.09306798662458, 90.80468722752163, 90.52070045471191, 89.09663936070034, 85.61265972682408, 74.61700344085693, 73.35860129765102, 72.75560188293457, 73.29225294930595, 73.34920038495744, 72.01429857526506, 72.77537645612443, 75.07862785884312, 72.03177329472133, 70.7427156993321, 70.48527799333844, 75.29958752223423, 84.06435789380754, 81.4867638179234, 61.474242619105745, 16.944373880113872, 0.730170339345932, 0.40062015716518673, 0.062024940337453566, 0.19775208298649105, 0.09202849678695202, 0.03561433876997658, 0.21456444369895117, 0.07497569719063384, 0.044170736601310115, 1.5916567466088702, 64.7973575592041, 89.45808465140206, 91.74075548989433, 105.33025768824986, 99.36612551552909, 46.74180344172886, 25.778878109795706, 43.071351528167725, 48.01313965661185, 70.77313491276333, 69.80609158107212, 88.75993660518101, 56.90829644884382, 10.817819748606, 0.33535013667174746, 0.1124264265277556, 0.0900151069675173, 0.06346799433231354, 0.15525687326278004, 0.06180497964045831, 0.12614719170544827, 0.052997897046485117, 0.02734452698911939, 0.0681684778204986, 0.08347130846232176, 0.09840288545404162, 0.03238638483786157, 0.08166424757135765, 0.029367073638630763, 0.0521169414610735, 0.04438397301627057, 0.027248005382716656, 0.05500062708077686, 0.04179881905604686, 0.09819220033075128, 0.09073029644787312, 0.19520089988197598, 0.08423123375645705, 0.060995799489319324, 0.01463872636668384, 0.0684540324977466, 0.052231145690062215, 0.05513175058045557, 0.10570166951843671, 0.14753306843340397, 0.23268572560378484, 0.25760717689991, 0.10049141624144145, 0.18506792932748795, 0.06033394964677947, 0.08894234988838434, 0.19869606090443476, 0.1242510120251349, 0.14192781278065272, 0.14551169904214994, 0.2416528101478304, 0.21434736677578517, 0.11206725080098424, 0.1037294464185834, 0.13036716383482727, 0.3273453504911491, 0.20890314105365956, 0.22506116330623627, 0.11152263145361628, 0.12157390639185905, 0.27422637226326124, 0.2716118411294052, 0.3393671725477491, 0.15675724989601544, 0.24077565435852322, 0.9989813779081617, 38.3173280443464, 120.49714687892369, 96.35630484989711, 98.33986963544572, 69.71976021357945, 34.94693061283657, 55.780576024736675, 139.2227783203125, 120.65888704572404, 111.18378843579973, 122.72565650939941, 52.484381880079, 3.008920873914446, 0.5419759377837181, 0.32384856098464554, 0.28696130748306004, 0.34657060887132374, 0.15005217040223734, 0.7218176275491714, 1.7377293769802367, 43.17818355560303, 123.50538335527692, 95.2478448322841, 99.7796128136771, 88.12668473379952, 80.45221873692104, 79.06511511121477, 84.57279927389962, 80.89429092407227, 83.81213828495571, 79.2239578792027, 81.68901893070766, 73.21205684116909, 82.62164783477783, 89.71520274026054, 94.28196184975761, 94.08572387695312, 94.25991521562848, 95.14328833988735, 97.06675815582275, 93.7563167299543, 92.53471919468471, 89.8266726902553, 100.92225796835763, 94.44448716299874, 95.83808040618896, 87.09531497955322, 77.60695920671735, 81.8503838947841, 85.13302557809013, 76.5348938533238, 94.29555252620152, 98.502443586077, 87.76171670641217, 70.41717869894845, 74.28334399632045, 83.7269047328404, 100.78381511143276, 117.53657504490444, 106.21755654471261, 105.63433170318604, 101.6923337663923, 105.59155164446149, 101.46045848301479, 98.50308282034737, 88.19913360050747, 87.09791360582624, 90.07127012525285, 96.16090066092355, 85.34591838291713, 89.45179653167725, 98.56966045924595, 95.19876970563615, 95.58668763296944, 94.66702406747001, 96.6211771283831, 96.62534604753766, 94.63618796212333, 91.66876520429338, 77.65983499799455, 76.93989045279366, 77.49015998840332, 77.24350588662284, 78.11399705069405, 76.45022310529436, 77.52364335741315, 79.14595045362199, 76.84476266588483, 76.92699459620884, 73.8662644795009, 82.9760684967041, 88.11030782972063, 83.63975347791398, 64.13190078735352, 14.915237597056798, 1.4631332031318118, 1.0765016696282794, 0.17072188055941037, 0.17695691170436995, 0.29639785683580805, 0.33607361785003115, 0.3642846883407661, 0.23587049756731304, 0.239162342356784, 7.069811173847743, 77.31582968575614, 99.25302273886544, 94.93747574942452, 106.25235312325614, 129.59289469037736, 115.65512793404716, 62.60164342607771, 29.822825227464946, 34.07496295656477, 68.96668665749687, 79.6120912006923, 101.11484118870327, 67.20480414799282, 12.48056709766388, 0.38483043015003204, 0.18884742366416113, 0.1822437715849706, 0.1647080382598298, 0.21483378138925346, 0.08681367018393107, 0.2100444912378277, 0.14833797381392547, 0.07431960811040231, 0.1844079861683505, 0.1723157593182155, 0.2424737832375935, 0.11002112845224993, 0.1484042802559478, 0.21885993677590573, 0.1031783606324877, 0.1371180580130645, 0.14527132122644357, 0.10978250125689165, 0.11109254203204598, 0.12811140130673135, 0.21223294309207372, 0.34085777827671593, 0.14086338132619858, 0.15630541342709744, 0.12941722837941988, 0.11196882929652929, 0.17785039304622582, 0.17283459433487483], [0.06000225458826337, 0.04257491383967655, 0.1009045083607946, 0.07525226127888475, 0.017718128627166152, 0.13235200090067728, 0.08785210017647062, 0.08019233548215457, 0.0932561226987413, 0.10895158762910537, 0.03173193441970008, 0.008106834454728025, 0.06355179340711661, 0.12771262627627167, 0.07409629545041493, 0.10748630482703447, 0.11142371461859771, 0.050870496380542, 0.06756866643471376, 0.059699363341288905, 0.027048996150759713, 0.05508693673514894, 0.25248787445681437, 0.09168964318398919, 0.20216429765735353, 0.7743532285094261, 11.372290338788714, 42.607819829668315, 81.43791103363037, 75.11297280447823, 81.33433423723493, 58.36588260105678, 37.4581971849714, 38.38383272715977, 97.57301085335868, 84.85587583269391, 99.66430745806012, 100.73780414036342, 42.776126044137136, 1.9439567966120583, 0.23898722603917122, 0.11133158313376562, 0.03937372811404722, 0.19977732002735138, 0.09801139110433203, 0.25288905150124, 0.9972283691167831, 9.183133568082537, 102.98427486419678, 83.63978127070835, 92.20420033591134, 77.25187846592495, 69.16477979932512, 68.7961014338902, 76.70489542824882, 69.10590076446533, 65.69252177647182, 67.52445602416992, 76.75210148947579, 70.53801482064384, 69.73355238778251, 76.23839337485177, 86.0231454031808, 87.56324836186, 88.88945797511509, 86.73304285321916, 90.51831027439663, 92.36919225965227, 89.35957309177944, 88.09812763759068, 88.03095245361328, 89.85732814243862, 88.6338893345424, 82.85530880519322, 64.94319329942975, 68.9087039402553, 81.08221190316337, 84.43875462668282, 78.58813517434257, 74.05460235050747, 87.74991171700614, 86.21502685546875, 67.3117230279105, 53.238598414829795, 68.94801684788295, 71.29780728476388, 82.86334787096295, 90.59038393838065, 83.04605075291225, 85.3520953314645, 89.58090795789445, 89.25050721849713, 76.04509449005127, 73.841904095241, 74.09458228519985, 79.83068152836391, 88.46770232064384, 84.94162355150495, 77.75068964276994, 84.47986711774553, 85.67196260179792, 82.46010221753801, 84.17350714547294, 85.80569458007812, 86.16224833897182, 89.53429249354771, 86.06716224125454, 78.55170576913017, 67.20861870901925, 68.75525992257255, 73.62080546787807, 71.29129682268415, 78.4956477028983, 79.33814457484654, 75.33815002441406, 77.34695066724504, 75.38370936257499, 77.57574789864677, 72.25313595363072, 71.8329575402396, 84.40613978249687, 73.35716302054269, 42.16425377982003, 5.938671801771436, 0.7716667183807918, 0.15216335068855966, 0.15797416173986026, 0.3127860517374107, 0.14031021243759564, 0.07602638152561017, 0.12295909492032868, 0.030497553691800152, 0.20951327974242823, 3.374139687844685, 57.146862847464426, 81.025313104902, 99.47642816816057, 70.6277299608503, 95.61156218392509, 128.4447465624128, 34.48489277703421, 27.902226754597255, 46.1904673576355, 63.48557240622384, 62.38531126294817, 73.64153889247349, 69.40917573656354, 24.57308077812195, 0.8087763956614903, 0.12137525847979955, 0.08159205144537346, 0.02627538819797337, 0.0193542733322829, 0.058284305701298375, 0.0394022537262312, 0.057451777160167694, 0.014702708826267293, 0.028590727797044174, 0.09428240691444703, 0.045370230451226234, 0.028734679001250436, 0.05646797941465463, 0.026257649596248354, 0.08022466767579317, 0.04138870909810066, 0.1493140600089516, 0.044661269922341616, 0.03073421652827944, 0.052563074843159745, 0.12555651340101445, 0.010296740918420255, 0.030096641276031733, 0.13404672353395394, 0.06215876101383141, 0.06161985493132046, 0.2102665893201317, 0.06680395068334681, 0.08107164222747087, 0.056430025558386526, 0.031229767615773847, 0.06372191570699215, 0.04116361189101424, 0.0633460208773613, 0.05857678143573659, 0.027651328294138824, 0.06998771841504745, 0.025632540728630762, 0.030379936431667635, 0.02746982526566301, 0.05085911734827927, 0.05665426102599927, 0.058379483808364184, 0.06688199578119175, 0.05456432567111083, 0.14062693901360035, 0.0656359340729458, 0.08268493387315955, 0.050037676069353304, 0.23888294877750532, 0.17799179974411214, 0.1551747705255236, 1.6841328186648232, 17.318739346095494, 62.61822182791573, 104.61478778294155, 97.60615376063755, 105.24098028455461, 82.03139836447579, 58.72814777919224, 26.601456233433314, 64.57695375170026, 89.3051825932094, 106.44488770621163, 107.29759843008858, 47.56101342609951, 1.7535017877817154, 0.3254481665790081, 0.16404116047280176, 0.13713384073759827, 0.34493058973125046, 0.3450989749814783, 0.7147616233144487, 1.5002890207937785, 14.034404907907758, 112.46240983690534, 88.85011032649449, 99.31235340663365, 78.45043577466691, 75.26563167572021, 73.08523832048688, 80.89350577763149, 72.68819046020508, 70.44707679748535, 70.94541549682617, 80.62281090872628, 74.51093918936593, 74.20594106401715, 81.27246052878243, 92.07730538504464, 89.19207286834717, 91.72257900238037, 90.02293845585415, 94.83288451603481, 95.8618085043771, 94.59668050493512, 91.5608457837786, 91.60030460357666, 91.38363197871617, 89.74167537689209, 86.00574016571045, 70.48223468235561, 73.44236877986363, 86.92404188428605, 89.13412489209855, 84.10002299717495, 75.98792471204484, 89.20168222699846, 90.13413047790527, 72.23267350878034, 57.09794405528477, 71.22626863207135, 76.21592984880719, 79.9904761995588, 96.3702985218593, 89.9766287122454, 89.7146121433803, 94.19977855682373, 90.10208538600376, 79.97951889038086, 80.25513308388847, 80.68572684696743, 86.32578114100865, 89.53576551164899, 87.68026297433036, 78.59274183000836, 82.75965990339006, 87.64047064099992, 86.95362731388637, 88.8185863494873, 91.66043431418282, 91.2195155279977, 92.52547809055874, 89.09329032897949, 82.93552575792584, 69.5994313103812, 70.81457396915981, 75.87576689038957, 75.18023831503731, 83.12739331381661, 82.59350763048444, 78.97665759495327, 82.14498751504081, 79.32674952915737, 78.8980804170881, 74.85130364554269, 75.32865183694022, 87.33998884473527, 80.60171617780412, 49.52360507420131, 8.605909364564077, 0.36590481283409254, 0.16129329720778124, 0.06776648653405053, 0.7794375728283609, 0.1013258718220251, 0.00851951860490122, 0.11498850690467016, 0.10883098481489079, 0.07885247987828084, 2.0894798679011206, 57.366387707846506, 85.6122567313058, 98.19308894021171, 80.32062680380685, 100.2386177607945, 92.83818176814488, 17.840488263538905, 33.409447125026155, 67.922671181815, 81.68968595777238, 71.2863358088902, 82.66706820896694, 85.83685030255998, 39.19357579095023, 0.6764661925179618, 0.0032011590083129704, 0.05657752550074032, 0.05197439821703093, 0.033475721920175214, 0.06942367939544575, 0.022830169049224684, 0.09671935186322246, 0.006400444411805698, 0.0651275756369744, 0.09305682339306388, 0.026255198388493488, 0.045767013981406174, 0.09427830177758421, 0.041500528276498826, 0.07946056939129319, 0.07010648918471166, 0.03678685746022633, 0.0176163924791451, 0.14702358362930162, 0.03693138202652335, 0.0967492006186928, 0.018055111169815063, 0.07854646737022059, 0.08740141043173415, 0.04371548031589814, 0.066117178249572, 0.05141082738659211, 0.14812286464231356, 0.1565354096570185, 0.13204451597162656, 0.13672695042831556, 0.15457098292452948, 0.17874745705298015, 0.0912898164242506, 0.11084305149103914, 0.1433749786977257, 0.18613869829901628, 0.06830820175153868, 0.10374009263302598, 0.13918529637157917, 0.2355415437902723, 0.10994517324226243, 0.14803726066436085, 0.15980166010558605, 0.08616549282201699, 0.32358138103570255, 0.12337720819881984, 0.12702763160424574, 0.1720708624592849, 0.4254447679434504, 0.39017082644360407, 0.22366353044552462, 3.644526881831033, 23.10194042750767, 77.76364803314209, 125.42022350856236, 99.63962745666504, 111.19867147718156, 75.73290497916085, 47.972961698259624, 55.453743185315815, 146.38784408569336, 106.64527375357491, 116.31194809504917, 119.49352128165108, 62.08047989436558, 4.135204323700496, 0.7245063089898655, 0.3658270255795547, 0.34758151748350685, 0.5905934604150909, 0.2189951009516205, 1.4115122130938937, 3.2857232093811035, 13.431783301489693, 121.80789675031389, 94.075211252485, 105.88364001682827, 85.3639975956508, 79.60612269810268, 76.07858480725969, 87.42495836530412, 80.5183447429112, 75.8475363595145, 74.73340661185128, 85.51564897809709, 81.34838349478585, 78.72020653315953, 87.4654872076852, 97.54069478171212, 96.25429834638322, 98.24948746817452, 98.40177113669259, 99.98753765651158, 101.4796633039202, 97.46840572357178, 96.0763966696603, 96.77285630362374, 95.76843861171177, 97.3032123020717, 94.00142138344901, 73.78767340523856, 78.79435076032365, 90.51598957606724, 93.33444990430559, 87.72325842721122, 81.5454969406128, 94.50182369777134, 93.58975451333183, 78.58528641292027, 69.03803076062883, 81.44396986280168, 86.01867771148682, 94.9889896937779, 103.35337012154716, 98.30715751647949, 97.30622087206159, 98.57184219360352, 98.44060461861747, 87.96366609845842, 88.31079115186418, 86.94825635637555, 88.23852293831962, 93.01411710466657, 89.51784610748291, 77.66206536974225, 87.75444194248745, 93.30298151288713, 92.87154701777867, 93.37839031219482, 93.93824836186, 96.24644688197544, 96.11089447566441, 93.91344329289028, 86.14412743704659, 74.78825569152832, 76.19320229121617, 81.35630444117955, 79.60203020913261, 88.40866347721645, 86.44665200369698, 80.65427930014474, 86.16859204428536, 83.1228700365339, 83.47095394134521, 78.54293714250836, 78.43722724914551, 95.42059094565255, 83.24674252101353, 53.22347913469587, 8.040765472820826, 1.2704258923019682, 1.660989454814366, 0.4307977578469685, 0.617943252835955, 0.29622018922652515, 0.22035785711237363, 0.28649094700813293, 0.15294264815747738, 0.3658786756651742, 6.223693856171199, 72.61981323787144, 94.77191407339913, 102.83957862854004, 78.07272475106376, 115.0348344530378, 148.17957605634416, 46.70314713886806, 34.49917132513863, 58.210124833243235, 80.30286026000977, 76.41075038909912, 94.99988446916852, 100.65323066711426, 45.996973923274446, 1.2016342750617435, 0.1447173516665186, 0.18074633979371615, 0.19661329766469343, 0.09014945011585951, 0.11048555174576384, 0.08116124277668339, 0.08154503575393132, 0.10227839249585356, 0.1981344646109002, 0.21016609828386987, 0.0955916673743299, 0.09412038632269416, 0.09548248430447918, 0.12340821724917207, 0.1365743071905204, 0.11023573550794806, 0.24558234214782715, 0.10984660246010337, 0.21596526567425045, 0.09030820016882249, 0.2012539886470352, 0.1207090320863894, 0.10355426903281893, 0.17668386921286583, 0.1237131915986538, 0.24049612507224083, 0.2062148124511753], [0.05696666533393519, 0.027470386753390943, 0.17415787332824298, 0.11743286145584923, 0.05433418694883585, 0.16975285112857819, 0.01141832537749516, 0.04639922880700656, 0.020220569168616618, 0.13607060350477695, 0.10657826890902859, 0.06898676391158785, 0.03671027460534658, 0.04872965393587947, 0.023523521576342837, 0.0801394572481513, 0.05468190561181732, 0.11071703396737576, 0.0946447921118566, 0.026079344164047922, 0.09091511581625257, 0.04151518124022654, 0.13759387390954153, 3.002682260104588, 32.07730375017439, 66.20822402409145, 90.34181908198765, 83.27003983088902, 70.12732069832938, 62.648300579616, 53.49723468508039, 36.690779072897776, 42.37653514317104, 101.33971963609967, 78.60212189810616, 107.25144154684884, 95.01152965000698, 46.02805321557181, 3.37435964175633, 0.0663329998829535, 0.04684870058138456, 0.08438875566103629, 0.08824269885995559, 0.14847060026867048, 0.09239677845367364, 0.6914903691836766, 0.4870692097714969, 58.21400540215628, 101.57841110229492, 88.48360674721854, 81.12802832467216, 72.32176331111363, 77.1703622000558, 66.99501718793596, 67.40132699693952, 65.14927686963762, 73.03060463496617, 68.45884977068219, 73.64108725956508, 68.51225362505231, 74.05893107822963, 74.1591796875, 82.61608232770647, 78.02980572836739, 79.2803703035627, 82.8333386012486, 87.64892659868512, 86.68901906694684, 88.58179174150739, 89.46325411115373, 87.55178383418492, 87.1666590826852, 83.72055407932827, 72.58339772905622, 64.58952304295131, 66.57325458526611, 76.60110323769706, 83.21530192238944, 84.57787145887102, 75.53632654462541, 81.48670128413609, 88.07790143149239, 76.56902340480259, 55.20468848092215, 53.51679733821324, 45.7071784564427, 28.936632871627808, 53.30698258536202, 75.98354039873395, 77.6126150403704, 74.46151665278843, 70.19405814579555, 70.03604916163853, 78.05749429975236, 79.0487173625401, 81.24290984017509, 84.8668748310634, 85.91118213108608, 78.55547169276646, 69.8604403904506, 72.99279253823417, 84.99378367832729, 82.06791809626988, 83.95051860809326, 79.9950203214373, 83.23223468235561, 86.7927348273141, 83.27561228615897, 69.92022269112724, 64.2793971470424, 68.77712590353829, 69.85279737200055, 75.71661840166364, 77.31095205034528, 82.07058620452881, 85.458541733878, 83.16125188555036, 79.43056256430489, 79.82640838623047, 78.52257197243827, 82.38280350821358, 85.23916625976562, 76.90600408826555, 38.72044863019671, 8.404479350362505, 0.5130902134946415, 1.0891013592481613, 0.11150338820048741, 0.08776135290307657, 0.09684714036328451, 0.03912043099158576, 0.06809093483856746, 0.0297528174040573, 0.2889959897313799, 2.995008409023285, 56.35797132764544, 78.29922907693046, 87.97223322732108, 81.28851086752755, 115.74154267992292, 111.8420329775129, 54.15571893964495, 21.169137443814957, 43.48040240151541, 60.67342104230608, 59.235401017325266, 64.31071962629045, 79.95001683916364, 34.03603914805821, 1.0368792414665222, 0.06492890736886434, 0.051327269191720655, 0.011678345933822649, 0.08931408529835087, 0.019876825024506876, 0.08981911212738071, 0.06568449682423047, 0.09727490919509105, 0.09180662940655436, 0.09484766729708229, 0.043592092115432024, 0.0501008849990155, 0.05688607572977032, 0.09015666294310774, 0.04825871331351144, 0.07163421756454877, 0.020378369272553494, 0.06665438799453632, 0.050291539768555334, 0.13349654019943305, 0.026716005090358, 0.08005861658602953, 0.05042940790631941, 0.018819267129791633, 0.12173640195812498, 0.046908503265253136, 0.05458474957517215, 0.03882650997755783, 0.07300624251365662, 0.07513021318508045, 0.025098369124212434, 0.11352506971785001, 0.025064194707998207, 0.054148207285574505, 0.022623507638594935, 0.0818232758236783, 0.08392943495086261, 0.021755535820765153, 0.05611648131161928, 0.02659848621780319, 0.0583409226632544, 0.06622778624296188, 0.010145755850576928, 0.06833798265350716, 0.03510722205308931, 0.04750159715435334, 0.07935271625007902, 0.018707810967628444, 0.14396203362515994, 8.060719830649239, 46.359565666743684, 82.0890336717878, 112.70376941135952, 100.97341060638428, 89.21197945731026, 100.97367463793073, 65.13465785980225, 51.70523868288313, 32.82103197915213, 66.87306240626744, 86.0140780040196, 112.71393462589809, 103.82367283957345, 51.159252711704795, 3.0048707255295346, 0.15188421495258808, 0.09307111334055662, 0.028812944622976438, 0.08135826899004833, 0.09380274372441427, 0.3848674510206495, 0.6232765380825315, 0.2237166054546833, 67.08043139321464, 106.19307109287807, 93.80861582074846, 85.01487840924943, 75.51238305228097, 80.97883660452706, 71.16148362840924, 73.30045182364327, 72.09244496481759, 78.32459694998605, 72.89967278071812, 78.00468104226249, 73.5586051940918, 78.66384274618966, 78.10986982073102, 84.6871040889195, 80.4932200568063, 80.82526751926967, 86.59119537898472, 91.51993479047502, 91.72442722320557, 93.73695904867989, 92.35596288953508, 91.25214426858085, 90.876024382455, 87.67198766980852, 75.17793846130371, 67.10196386064801, 69.64288534436906, 79.78493458884103, 89.47991589137486, 90.44345733097622, 78.35273020608085, 84.15838786533901, 91.41252258845738, 83.50813375200543, 63.738820348467144, 58.614579473223, 52.15955012185233, 36.07810081754412, 56.82725613457816, 82.58975560324532, 81.68247372763497, 76.46515478406633, 73.92893028259277, 74.79364054543632, 81.05344636099679, 82.84093298230852, 84.36162962232316, 86.75625678471157, 86.79789733886719, 82.70290701729911, 74.38578128814697, 74.87931183406285, 85.4466255732945, 84.56177943093437, 86.02853720528739, 79.43712166377476, 85.50895091465541, 89.68692357199532, 86.8285527910505, 74.45838301522392, 67.20488057817731, 71.2841054371425, 73.20998627798897, 77.77594634464809, 81.8194922038487, 86.56124169485909, 89.5895584651402, 84.90680612836564, 84.0309579031808, 85.25544588906425, 83.36173520769391, 84.14253207615444, 87.95855917249406, 81.90076528276715, 49.8520325251988, 16.811614649636404, 0.7144448288849422, 0.7484447530337742, 0.19870717530804022, 0.17889092649732316, 0.3492742452238287, 0.06138938372688634, 0.23746524485094206, 0.01570793131499418, 0.2369974356676851, 2.505242266825267, 56.79802853720528, 82.9248046875, 89.52924810137067, 82.27205617087228, 114.83196789877755, 69.25899737221854, 27.587919780186244, 38.44362892423357, 62.61885411398751, 78.99447277614048, 69.60368360791887, 71.513229233878, 89.72233159201485, 51.78483724594116, 1.1182105115481784, 0.04811653308570385, 0.07906003695513521, 0.012617213634907134, 0.03510399901175073, 0.056069832029087205, 0.05535880196839571, 0.03791877940031035, 0.06357360152261597, 0.10715657073472228, 0.13594344604228223, 0.027549364836886525, 0.13608120222176823, 0.042721932022167106, 0.08636630526078598, 0.08530136490506784, 0.03324727275009666, 0.04381991703329342, 0.08117162436246872, 0.021848091389983892, 0.08554227197808878, 0.061544815743608136, 0.04805379234520452, 0.08069050910749606, 0.04763980795230184, 0.13709615490266255, 0.06169538266424622, 0.07524945892925773, 0.07989855017513037, 0.19576440964426312, 0.1973791058574404, 0.12430324565087046, 0.2529658888067518, 0.1140670156372445, 0.10656416895134108, 0.17265713028609753, 0.1555625940007823, 0.1463823408952781, 0.10188117809593678, 0.14840315388781683, 0.09815089111881596, 0.11119366410587515, 0.10685949453285762, 0.11271643239472594, 0.1884239771004234, 0.10870851602937494, 0.19104502217045852, 0.19245469224240097, 0.11453901816691671, 0.23444725679499762, 11.898238573755537, 60.733168601989746, 105.4742591040475, 129.99787739345004, 116.3874819619315, 90.13146931784493, 84.2613115310669, 73.8289109638759, 49.35909605026245, 60.46352291107178, 146.81128120422363, 97.99412727355957, 125.44946152823312, 111.39735521589006, 70.29439013344901, 7.146657816001347, 0.2724822387099266, 0.31952783997569767, 0.17095045186579227, 0.4069303699902126, 0.25094765424728394, 0.22577502285795553, 2.4433783292770386, 1.3343877515622546, 71.5970106124878, 112.12088503156389, 100.18213585444859, 90.46047346932548, 80.37904030936105, 86.12671525137765, 76.49900640760148, 77.58326584952218, 74.3674658366612, 83.69870894295829, 79.79312651497978, 85.71414511544364, 78.76732226780483, 84.46223953792027, 82.49429430280412, 93.54652282169887, 86.4697686604091, 86.18052210126604, 89.6912453515189, 95.13865389142717, 96.1253467287336, 96.40298979622978, 98.639406476702, 95.73766504015241, 93.6312699999128, 93.53059755052838, 79.395432472229, 70.2656523840768, 75.28302301679338, 86.86262675694057, 93.14470849718366, 94.6305182320731, 83.71881008148193, 89.03887203761509, 97.52913992745536, 87.76282146998814, 67.18645395551408, 66.54253659929547, 60.98412363869803, 46.67271750313895, 66.55591188158307, 86.04575484139579, 87.05468191419328, 83.53157002585274, 83.89111845833915, 83.86413860321045, 89.02726854596818, 89.7060102735247, 90.32129410334996, 90.6515280859811, 91.80417864663261, 85.20368875776018, 74.40376322610038, 76.4202902657645, 89.3375403540475, 86.02288137163434, 89.52268205370221, 82.10359014783586, 91.13323279789516, 95.9960685457502, 92.18478012084961, 77.54892090388707, 70.57618127550397, 75.36967400142125, 77.29862594604492, 82.56703499385289, 87.3638836996896, 89.29874161311558, 92.91646017347063, 89.03062452588762, 87.7138922555106, 89.23520728519985, 86.11279800959996, 88.66666398729596, 93.40361227308, 86.48067038399833, 48.084508078438894, 15.94373253413609, 0.870620248573167, 2.866025958742414, 0.8044316545128822, 0.22513505576976708, 0.5142071907009397, 0.11737165759716715, 0.3062291235796043, 0.04725735508171575, 0.34995446300932337, 7.1090958544186185, 71.25260925292969, 89.4004215512957, 100.70666926247733, 84.75347328186035, 124.8561270577567, 137.7767331259591, 70.40572806767055, 27.670179503304617, 53.67319086619786, 79.65962382725307, 73.78381715502057, 77.82780075073242, 102.06198487962995, 65.0077907017299, 2.085231044462749, 0.20099499183041708, 0.17310161143541336, 0.14448021724820137, 0.1523419003933668, 0.2624182073133332, 0.21452614718249866, 0.1340587878865855, 0.17717580710138592, 0.16575532991971287, 0.22273579665592738, 0.11842804162630013, 0.17446307837963104, 0.15032415437911237, 0.22019741072186402, 0.1884806076330798, 0.1712093943996089, 0.07816110697707959, 0.20630402623542718, 0.1747167826231037, 0.13848898373544216, 0.1842666066118649, 0.15667855340455258, 0.13146432781858103, 0.11187281659139053, 0.2866735000695501, 0.12823040277830192], [0.19121272888566765, 0.10515121476990835, 0.21913969676409448, 0.03787838281797511, 0.10231860248105866, 0.13149353196578367, 0.05913238626505647, 0.09704740318868842, 0.030711455071078878, 0.02956676988729409, 0.04748299850949219, 0.022957538553912724, 0.03136094879092915, 0.10178297372268778, 0.044098021396036656, 0.02534945761518819, 0.06830111784594399, 0.05037583078124693, 0.0811643029696175, 0.03996349378888096, 0.1365123162312167, 1.1596456595829554, 37.31930269513811, 88.84229360307965, 111.4615009852818, 99.88664286477226, 90.78628839765275, 76.06233297075543, 75.79548045567104, 40.49218021120344, 69.40994003840855, 52.99784680775234, 91.77022974831718, 90.01223823002407, 106.04792322431291, 96.16268634796143, 47.897552898951936, 3.524144781487329, 0.22975290726338113, 0.09577842056751251, 0.041724736602710824, 0.09102151689252683, 0.1595286718968834, 0.0753456141267504, 0.3814082523541791, 1.0598864640508379, 4.0455330439976285, 99.16623973846436, 92.02180317470005, 88.14935670580182, 76.82988657270158, 72.50566128322056, 68.08124991825649, 72.33800819941929, 71.80176707676479, 70.8051313672747, 68.26110403878349, 69.1418924331665, 68.39493329184396, 73.9125394821167, 73.85006128038678, 75.9050327028547, 76.60724544525146, 72.43007183074951, 69.24759537833077, 74.74028532845634, 81.16361004965646, 82.40467643737793, 81.24685641697475, 84.21867738451276, 91.44424111502511, 85.27932684762138, 78.52490656716483, 65.02450806753976, 62.05228410448347, 62.38708305358887, 73.25596945626395, 86.15766252790178, 85.22346333095005, 75.58070468902588, 71.53208664485386, 80.94224739074707, 85.98624352046421, 73.70546231951032, 69.12764167785645, 67.3861243384225, 57.13928583690098, 43.98496668679373, 67.05830138070243, 71.86175782339913, 58.24776669910976, 59.608567919049946, 63.368536949157715, 76.92190156664167, 76.33654362814767, 79.83362756456647, 76.83022703443254, 79.69737339019775, 78.97407286507743, 84.54647254943848, 82.58628845214844, 84.65686552865165, 84.56441279820034, 87.4321983882359, 83.81857926504952, 81.80946595328194, 81.28497423444475, 79.8710297175816, 74.06416307176862, 65.45531027657645, 65.21994699750627, 68.13995524815151, 75.9254048211234, 82.71269008091518, 81.54782458714077, 87.66541467394147, 84.69362149919782, 86.93911947522844, 85.74319553375244, 84.97287654876709, 86.65252712794712, 82.86621052878243, 78.94671085902623, 83.95107446398053, 70.75213050842285, 33.12666933877127, 0.6810480409434864, 1.7622530439070292, 0.25231978776199476, 0.025617348329563226, 0.19322450379175798, 0.017801807262003422, 0.04818126193380781, 0.07345052688781704, 0.48532141212906155, 4.977036339896066, 56.78821073259626, 75.65644700186593, 90.07739148821149, 41.02200467245919, 41.36670480455671, 62.6681307383946, 43.053796904427664, 22.1339556149074, 33.8459746497018, 44.35262714113508, 66.00332164764404, 66.53920146397182, 73.46927915300641, 38.449607849121094, 0.6843446897608894, 0.0758741521941764, 0.05580490481640611, 0.10741687033857618, 0.11845316099269049, 0.05083266805325236, 0.08725741173007659, 0.05214053412367191, 0.09169069491326809, 0.027072398823552897, 0.06929065939038992, 0.097328649168568, 0.08597982528486423, 0.06796940921672753, 0.08179529303950922, 0.09192846036915268, 0.05199045914092234, 0.11486312720392432, 0.06266591165746961, 0.05573572477857981, 0.05711101008845227, 0.048551585990935564, 0.054510402493178844, 0.1193468730364527, 0.12118521439177649, 0.08197270959083523, 0.1621317493596247, 0.11209940657551799, 0.08316499061350312, 0.029426876322499344, 0.09223859158477613, 0.08674834083233561, 0.0689216720472489, 0.06077342999300786, 0.06062105816922017, 0.05219052858384592, 0.031153887044638395, 0.028288423482860838, 0.014048000564798713, 0.04522399597668222, 0.021379749556737285, 0.07413925350244556, 0.04438747764964189, 0.14087890620742524, 0.09984565446419374, 0.05809214458401714, 0.06372039578855038, 1.0331045240163803, 50.999388558524, 107.60053988865444, 126.98408235822404, 113.95798873901367, 106.42572457449776, 96.60516847882951, 112.11376312800816, 56.792122568402974, 59.50733961377825, 35.577865259987966, 55.47848572049822, 87.87133148738316, 113.85384913853237, 101.67210756029401, 53.416243008204866, 2.7842491354261125, 0.26705906114407946, 0.09523158919598375, 0.09384391722934586, 0.1961530337908438, 0.6546057483979634, 0.47911249101161957, 0.4770977848342487, 0.5042221950633186, 4.9409539103508, 108.44633715493339, 95.23190566471645, 95.02371679033551, 81.03111485072544, 78.95516681671143, 71.26951422010148, 77.59074905940464, 73.97574029650006, 76.00300230298723, 72.29124682290214, 73.80947685241699, 71.38855075836182, 77.42636857713971, 75.77687317984444, 80.66056741986955, 79.39617592947823, 74.26469503130231, 71.47474316188267, 76.95719146728516, 84.61996364593506, 84.23690250941685, 83.01156684330532, 87.14454991476876, 94.39992836543492, 88.48215457371303, 82.5064536503383, 69.04368659428188, 64.8382477079119, 65.32315553937639, 76.97253308977399, 88.67269502367292, 89.08941323416573, 77.66338552747453, 73.84373147147042, 83.84910270145961, 89.17639078412736, 79.44128363473075, 75.7096563066755, 77.86311844417027, 71.51428536006382, 52.82490961892264, 69.50047506604875, 75.9980273927961, 62.003848212105886, 62.888145446777344, 68.03744152614048, 81.28269522530692, 81.3958466393607, 81.78293078286308, 81.21624265398297, 83.80335576193673, 81.25384630475725, 85.33711501530239, 84.2521607535226, 87.27322360447475, 86.71386582510812, 90.31356075831822, 85.84561892918178, 83.04441792624337, 83.68704291752407, 84.36404759543282, 77.29766014644078, 68.28432491847447, 67.802168573652, 70.18416391100202, 78.94937201908657, 85.92816352844238, 83.75625392368862, 88.8830795288086, 87.72172287532261, 88.22190979548863, 88.31368160247803, 87.10403496878487, 89.57889298030308, 82.86397320883614, 81.00879028865269, 86.95976257324219, 77.895906993321, 44.84040110451834, 2.992682282413755, 0.9770604627473014, 0.04997790731223566, 0.08994528571409838, 0.19177572296134063, 0.023323845683730075, 0.1273992380925587, 0.060229970940521786, 0.4219401345721313, 3.9165449483054022, 60.060305050441194, 79.69137709481376, 94.5163801738194, 48.635472433907644, 44.16990341459002, 33.687593936920166, 29.238537311553955, 42.566787242889404, 50.85722146715437, 65.18883296421596, 79.55620683942522, 75.30342987605503, 83.27174908774239, 55.90031433105469, 0.5035775867956025, 0.07051258560802255, 0.04909505182877183, 0.007598400531735803, 0.03966238369633045, 0.020906172825821807, 0.06216920366776841, 0.01419850132827248, 0.07383016044540064, 0.08485065480428082, 0.10572581179440022, 0.028848360758274794, 0.046751357947609255, 0.025091420925621475, 0.07129643604691539, 0.012772462447173893, 0.0167891463331346, 0.106892037072352, 0.020883167096014534, 0.024770112541903342, 0.09685790192868028, 0.050496521805013926, 0.09085343019770724, 0.0691167644358107, 0.12400676655982222, 0.05238440300204924, 0.2624508855598313, 0.22265905434531824, 0.30622486237968716, 0.14276341508541787, 0.24560153111815453, 0.1664319514696087, 0.09478973397719008, 0.1609727708356721, 0.11101045286548988, 0.13089209209595407, 0.13759904434638365, 0.1297918339925153, 0.1411767287978104, 0.16676524787076882, 0.08282757550477982, 0.10325710462140185, 0.20375999489000865, 0.2840478409613882, 0.2770448438823223, 0.10355997551232576, 0.27005788737109726, 2.676062209265573, 64.11971364702497, 129.82492283412387, 144.524114881243, 121.33491897583008, 114.37718050820487, 98.7430110658918, 103.95147105625698, 51.17590406962803, 85.9478199822562, 71.94865199497768, 129.4562931060791, 111.82145241328648, 128.28115817478724, 112.9682456425258, 70.24169499533517, 7.219029383999961, 1.0261095336505344, 0.2286072958792959, 0.24624771358711378, 0.3369189367762634, 0.444289178188358, 0.17683720455638, 2.796242811850139, 4.455675218786512, 5.182569699628012, 113.29380348750523, 99.84879602704729, 100.02992166791643, 84.86925111498151, 84.05673571995327, 73.85240282331193, 82.80858216966901, 79.14788205283028, 83.3024045399257, 77.88296944754464, 78.06037780216762, 76.00183500562395, 83.81427138192313, 82.13772664751325, 86.78614098685128, 84.42574065072196, 80.53496483394078, 76.2053199495588, 83.07031386239188, 89.39352199009487, 89.80478586469377, 89.94547993796212, 93.03796332223075, 99.07230704171317, 93.87842437199184, 87.62621293749127, 75.09822177886963, 69.55722795213971, 68.88979094369071, 81.10584272657121, 94.11107090541294, 92.00799710409981, 82.6095301764352, 78.46684047154018, 87.69562544141496, 93.56012739453996, 85.51492636544364, 79.59532519749233, 80.15496090480259, 71.98749937329973, 59.55378137316023, 77.539137840271, 84.25496087755475, 74.08279119219098, 75.14330169132778, 76.55209759303501, 86.26831259046281, 87.07845170157296, 85.50862434932164, 84.52220943995884, 86.91459928240094, 82.00833034515381, 85.57688345227922, 85.8107042312622, 89.41777120317731, 90.8272271837507, 92.63708005632672, 87.90561389923096, 83.66292572021484, 86.87100628444126, 87.745089667184, 83.25953415461949, 73.02062007359096, 72.39898559025356, 74.34215354919434, 84.83545507703508, 91.39527021135602, 87.23700959341866, 93.57414191109794, 91.81098093305314, 91.53233732495988, 92.3043030330113, 91.30308151245117, 94.55408804757255, 88.99488994053432, 86.69575881958008, 88.6601118360247, 79.45310946873256, 40.85705096381051, 1.8025631265980857, 3.2911677743707384, 1.1112542791025979, 0.12849157090697969, 0.6200912232909883, 0.24412756306784494, 0.205246542979564, 0.19251634393419537, 0.7493256000535828, 9.547786320958819, 74.60080024174282, 84.3443216596331, 106.0243410382952, 56.273161615644185, 62.337695258004324, 88.12596906934465, 54.030071190425325, 29.072629962648662, 42.86641093662807, 60.661060197012766, 84.85200568607875, 82.26188400813511, 93.91456890106201, 69.24947834014893, 1.1603281029633112, 0.16762297041714191, 0.16741043967860086, 0.15137141889759473, 0.16067771666816302, 0.18756159980382237, 0.17614955002708094, 0.1054798767768911, 0.21260725014976092, 0.13266161642968655, 0.14046172930725984, 0.20333789182560785, 0.21372073968606337, 0.09329759475908109, 0.14776431316775934, 0.18142522765057428, 0.1575286763587168, 0.2605699322053364, 0.09692128388477222, 0.12197474416877542, 0.1540131050028971, 0.19620392391724245, 0.1672853992453643, 0.12680100090801716, 0.2828190140426159, 0.11743929396782603], [0.06510239520243236, 0.09237037665609803, 0.160459038402353, 0.017021775278928022, 0.015513978865263718, 0.017952028129781996, 0.05810119624116591, 0.08146437151091439, 0.11947617466960635, 0.07336944195308856, 0.05581806839576789, 0.012215504788660576, 0.07749060581305198, 0.017510953226259778, 0.02870000246912241, 0.06672332715243101, 0.06721905126635518, 0.1094875827963863, 0.059690026699432304, 0.07688843991075243, 1.9050080180168152, 77.03476810455322, 103.9354554585048, 93.82671587807792, 89.60711656297956, 65.92828805106026, 67.55501420157296, 59.263569014413015, 35.18128292901175, 76.88445772443498, 176.39191654750277, 112.37912178039551, 77.29578413282121, 98.28981481279645, 99.64200374058315, 53.895039899008616, 4.989531372274671, 0.2393908729510648, 0.3485956559223788, 0.1037387762750898, 0.1480581188308341, 0.02464776250001575, 0.37203556671738625, 0.5220401446734155, 10.342007109097072, 1.120906304035868, 12.676095485687256, 105.67249815804618, 92.0233804157802, 95.02994237627301, 83.19046906062535, 81.40681089673723, 77.86073521205357, 71.6615663255964, 67.789564541408, 69.67817524501255, 71.15599455152238, 72.49231379372733, 69.20281423841203, 65.74322278159005, 67.81351498195103, 69.57242366245815, 68.71339007786342, 63.46390792301723, 62.995738301958355, 65.54975714002336, 67.8992349079677, 68.20587975638253, 72.39952060154506, 83.07740797315324, 86.89337948390416, 84.91852079119, 74.24452441079276, 63.338138580322266, 62.02129513876778, 68.20056438446045, 79.8730307987758, 82.85987377166748, 84.87308652060372, 74.65900530133928, 66.26688071659633, 74.55268396650041, 80.05644934517997, 79.57646083831787, 83.7342003413609, 83.5756424495152, 85.11953912462506, 68.2636192866734, 58.93670490809849, 65.44971002851213, 46.69895737511771, 49.78523254394531, 73.39795589447021, 80.53998143332345, 74.00936262948173, 75.36025919233049, 77.85035460335868, 79.62730080740792, 75.3745516368321, 78.62217439923967, 88.8661606652396, 83.55680588313511, 81.23906748635429, 83.43035561697823, 86.56296484810966, 83.08336952754429, 79.79327937534877, 81.70031670161656, 77.99858747209821, 69.59633241380963, 62.76246643066406, 59.85289437430245, 62.337361744471956, 71.02952344076974, 77.92733369554792, 83.03849806104387, 83.9494138445173, 82.19067886897496, 84.45527744293213, 83.36627238137382, 85.272079876491, 81.65773814065116, 80.26238005501884, 78.94744041987828, 81.36947127750942, 87.17761639186314, 65.96370996747697, 4.5622254099164685, 1.3141036799975803, 0.24461798103792326, 0.07326629105955362, 0.15998007410338946, 0.17140098554747446, 0.006322581246162632, 0.03850389711026635, 0.11683532994772707, 10.50676018851144, 48.18418346132551, 64.30083233969552, 89.30528681618827, 53.10850034441267, 42.640729972294395, 72.84881196703229, 25.48344244275774, 21.111232893807546, 16.08085002217974, 39.26069886343819, 63.79525361742292, 65.52807181222099, 71.15250655582973, 19.132349457059586, 0.495688938668796, 0.013942219499897743, 0.018976200405242186, 0.09993176055806023, 0.050229653982179504, 0.05090972588264516, 0.033463450614362955, 0.09115573111921549, 0.12051702024681227, 0.18161691379334244, 0.08679947523134095, 0.04947669385001063, 0.030242580587842634, 0.0786853770592383, 0.06871350428887776, 0.07980106504900114, 0.0870189405977726, 0.0897962251412017, 0.08939009479113988, 0.11423058328883988, 0.07844373038304703, 0.0932511015396033, 0.07829872744956187, 0.06666224543005228, 0.07614515908062458, 0.03505457452099238, 0.02007121343298682, 0.034687446363802464, 0.05957438397620406, 0.005467382425974522, 0.11129448762429611, 0.051534734666347504, 0.03893120793093528, 0.016782008144738417, 0.15296480911118643, 0.029249076398887804, 0.054881768101560216, 0.04558131930285266, 0.030337955470063856, 0.02412774004707379, 0.0835039731381195, 0.08600849338940211, 0.027692946239507625, 0.06701846952949252, 0.11987394546823842, 2.897797465324402, 94.03115272521973, 123.46287427629743, 103.24215030670166, 105.8153600692749, 86.25569466182164, 103.89197363172258, 102.0402717590332, 61.024972098214285, 88.04697499956403, 181.04337419782365, 90.60437066214425, 70.61050537654332, 111.307938848223, 107.48706885746547, 61.6785682950701, 4.035392582416534, 0.42049846478870934, 0.1690675714718444, 0.2140058736715998, 0.08380844537168741, 0.5078857413360051, 0.5696465415613992, 0.8691384909408433, 10.578348347118922, 1.3896205020802361, 15.934192657470703, 107.95007596697126, 96.62489441462925, 100.63108675820487, 86.81259972708565, 86.97613947732108, 79.0621760232108, 75.86286408560616, 72.83087866646903, 74.63496453421456, 76.08367783682687, 77.62292616707938, 73.88685199192592, 72.07651969364711, 71.97012192862374, 72.63562733786446, 70.54150976453508, 68.11721379416329, 65.23150879996163, 69.19314234597343, 70.59939520699638, 72.22912992749895, 76.80838189806256, 87.28988538469586, 90.04282420022147, 90.12668200901577, 77.25392818450928, 66.38948862893241, 64.65963036673409, 71.89774254390171, 83.3707331248692, 86.65926688058036, 87.70989009312221, 80.47794096810478, 66.6890949521746, 76.17518561226981, 82.1243096760341, 83.47432381766183, 86.70556272779191, 83.49964305332729, 86.05674689156669, 75.27287864685059, 62.26456546783447, 70.18770054408482, 52.52542836325509, 57.47348724092756, 79.54858466557094, 84.47767148699079, 79.18110139029366, 76.31847136361259, 79.40146350860596, 82.11005197252545, 79.46357345581055, 78.76730837140764, 90.37104320526123, 84.87367711748395, 85.36294146946499, 84.20974894932338, 88.85793399810791, 84.91123907906669, 83.76655115400041, 85.7947998046875, 80.73826217651367, 73.5311528614589, 66.49706063951764, 63.01813234601702, 64.15114729745048, 73.63932241712297, 82.42663969312395, 85.28546905517578, 85.13570758274624, 87.34232343946184, 86.19978250776018, 85.44343635014125, 85.95586599622453, 84.44093636104039, 85.55195331573486, 81.10237557547433, 85.03691809517997, 91.60632869175502, 78.7226175580706, 10.723615203584943, 0.8745932610971587, 0.3405521661043167, 0.42241152642028673, 0.31989970430731773, 0.33464902000767843, 0.20160670472042902, 0.14449669207845414, 0.1564580159527915, 9.566760982785906, 51.795325551714214, 68.48233468191964, 97.93879876817975, 58.98238236563546, 43.02257864815848, 37.002350194113596, 18.477829149791173, 29.920412676674978, 33.0457957812718, 55.709926741463796, 76.8952065876552, 72.07624871390206, 82.47744492122105, 32.914384501320974, 0.5486077219247818, 0.05406530048432095, 0.03730377900813307, 0.09536165757370846, 0.07909059817237513, 0.041332706210336516, 0.03747463073315365, 0.05322632586051311, 0.08351755740919284, 0.011714809557556041, 0.021265518186347823, 0.12059646312679563, 0.05162066434110914, 0.05555328367544072, 0.04054745798930526, 0.03046482794785074, 0.06808540477816548, 0.0686913433351687, 0.0996067626401782, 0.05284934876752751, 0.04303351191005536, 0.09872662808213915, 0.10267971203263317, 0.06197449125881706, 0.09911846848470823, 0.12643288208970002, 0.1280637410070215, 0.2822631581553391, 0.2525596906031881, 0.07976784397448812, 0.1302800535091332, 0.11184786685875484, 0.10252369647579533, 0.22235322504171304, 0.29111253044434954, 0.12074640579521656, 0.15846992656588554, 0.09971171843686275, 0.1564632813845362, 0.13575750030577183, 0.13804809882172517, 0.12452546586947781, 0.1658300230545657, 0.12562528971050466, 0.29658165840165956, 5.007232342447553, 115.34651674543107, 139.7996872493199, 116.21709823608398, 111.3607451575143, 92.98737348828996, 88.90360450744629, 81.13954843793596, 44.587274755750386, 91.87678732190813, 171.13425636291504, 137.70041411263603, 105.2230886731829, 119.6138640812465, 113.88393483843122, 77.15793187277657, 9.841009855270386, 0.6968754945056779, 0.7535252975566047, 0.27782092509525164, 0.5841049828699657, 0.38508135239992825, 0.7525148774896349, 1.473265413727079, 19.916919197354996, 2.9991388959544043, 17.42709824017116, 110.64392730167934, 100.66691167013985, 104.85422270638603, 90.17477743966239, 90.04832022530692, 85.4809010369437, 79.87298910958427, 77.13389805385044, 78.02551174163818, 81.12310900006975, 82.18962274278913, 79.43990094321114, 74.84304918561662, 77.23493875776018, 76.88834176744733, 78.18968377794538, 71.05109064919608, 70.31920909881592, 75.06093774523053, 74.19919436318534, 76.90407248905727, 81.37129865373883, 92.93551213400704, 93.77405548095703, 94.87211404527936, 82.91224234444755, 70.25064427512032, 69.40092822483608, 75.85558932168144, 89.46106542859758, 90.71441623142788, 93.60397747584751, 84.52380752563477, 71.67743601117814, 80.99145453316825, 88.39559391566685, 87.29678494589669, 92.20173372541154, 91.77007688794816, 95.34157603127616, 79.60052245003837, 70.97592503683907, 76.0609711238316, 62.89613587515694, 66.80790914808, 84.55521338326591, 87.25856290544782, 82.88772909981864, 81.35662405831474, 83.68507657732282, 85.6058018548148, 80.66318689073834, 81.08271217346191, 92.9333859852382, 91.39609704698834, 87.04034083230155, 90.98808492933, 93.04963629586356, 87.43983445848737, 86.28260503496442, 90.2417094366891, 84.22168595450265, 77.07516493116105, 67.97508839198521, 67.4087963104248, 66.77402973175049, 80.31744452885219, 86.16338784354073, 90.92645440782819, 89.48451559884208, 91.0936975479126, 90.79619652884347, 91.08030142102922, 89.17749554770333, 89.75574547903878, 88.78998061588833, 86.18198122297014, 87.68393162318638, 96.30628476824079, 77.63606521061489, 8.011523979050772, 3.2322316340037753, 1.7931580884116036, 0.4938439748116902, 0.5033199063369206, 0.31159609130450655, 0.1863552052527666, 0.2614585959485599, 0.20839208204831394, 18.1253696169172, 69.58774444035122, 74.50883388519287, 106.50014672960553, 64.3722459248134, 67.69315133775983, 100.73319053649902, 31.71693890435355, 29.002586909702845, 24.804643392562866, 49.014618260519846, 83.77426365443638, 81.54512173788888, 93.72768320356096, 46.21804475784302, 0.6328736831034932, 0.23812467232346535, 0.19557072860854013, 0.1669011041522026, 0.16270295370902332, 0.1682734547981194, 0.16172181921345846, 0.14057006420833723, 0.2204865887761116, 0.27577468061021393, 0.11523693214569773, 0.2540500249181475, 0.09326777993036167, 0.10623258245842797, 0.22417963775140898, 0.16109987401536532, 0.12501376681029797, 0.16461361332663468, 0.11658347131950514, 0.18329341097601823, 0.13036215624638967, 0.17653962623860153, 0.12021964548953942, 0.15534292507384503, 0.2536816346858229], [0.05985112448355981, 0.06343581820172922, 0.07951184628265244, 0.032148531172424555, 0.06373048560427767, 0.0658737470262817, 0.06612268116857324, 0.11826159698622567, 0.049562487817768536, 0.10985913500189781, 0.05861219417835985, 0.034505313994096856, 0.060985641820090156, 0.07026249795619931, 0.03397421445697546, 0.0380543981944876, 0.058375724724360874, 0.0476977650209197, 0.13239449076354504, 0.592786431312561, 69.02912317003522, 100.748580796378, 86.480607850211, 90.50342723301479, 68.52408640725272, 72.66822828565324, 38.056127888815745, 27.911933388028825, 31.15001801082066, 50.75933871950422, 59.73614379337856, 51.210704122270855, 97.75369180951799, 100.92046533312116, 65.59731061117989, 5.159118226596287, 0.011120839510113001, 0.060994510272783894, 0.03588044663359012, 0.07594180892088584, 0.37633099194083897, 0.05544261122122407, 1.2147624620369502, 2.751796705382211, 0.5323085508176258, 0.6475399732589722, 40.793096269880024, 103.69484628949846, 96.90351022992814, 95.16821152823312, 90.51999173845563, 91.47466727665493, 78.50852271488735, 81.02907902853829, 75.896041733878, 77.02112184252057, 70.5394253049578, 74.51002202715192, 69.60189097268241, 71.10159015655518, 63.7244028363909, 65.93522235325405, 68.35144451686314, 69.58209555489677, 64.5261207308088, 66.10983753204346, 60.963299887520925, 65.98287309919084, 75.44873755318778, 83.91512448447091, 85.39919022151402, 84.12519632066999, 71.26729079655239, 64.37874943869454, 58.61890820094517, 71.22002914973667, 81.76542132241386, 82.51816831316266, 79.03673866816929, 78.15169102805001, 65.83598818097795, 63.092082023620605, 69.0310617174421, 72.31950514657157, 74.83206408364433, 76.61434650421143, 76.93442916870117, 76.07474245343889, 67.4170229775565, 70.47551577431815, 53.67808934620449, 64.9517604282924, 78.78761100769043, 73.32721628461564, 70.78050695146833, 73.33864607129777, 77.89900588989258, 81.8452422278268, 79.75885799952916, 82.25784710475376, 80.94670118604387, 73.46095521109444, 72.40559332711356, 73.63192953382219, 78.34087657928467, 82.89779703957694, 79.49039350237165, 79.0115306036813, 77.19731426239014, 77.38166386740548, 75.13746520451137, 69.70939350128174, 64.64968749455043, 63.272707394191194, 63.61498955317906, 69.9426097869873, 74.96972179412842, 78.35493278503418, 79.91617216382707, 82.55761323656354, 80.98167841775077, 80.58818803514752, 80.89357525961739, 81.53356688363212, 78.59918975830078, 78.90805108206612, 81.54069573538644, 79.46296201433454, 7.326917103358677, 1.8017632152353014, 0.12055630742439202, 0.09280813352337905, 0.07317157435630049, 0.10500188278300421, 0.058385773827987056, 0.05267303483560681, 0.19471620874745504, 4.397110155650547, 27.676903622491018, 62.20453303200858, 90.86326054164341, 62.49134077344622, 68.6036571775164, 85.1892226082938, 45.33315692629133, 40.383503437042236, 28.20814551625933, 57.002694674900596, 60.54740156446184, 68.56242656707764, 64.83869239262172, 18.012930393218994, 0.178642406261393, 0.0650693912591253, 0.042867284401186874, 0.041457841638475657, 0.02343637223488518, 0.07459581936044352, 0.09969646496964352, 0.07583827804774046, 0.021848065944920694, 0.08928440617663519, 0.04491648729890585, 0.10899822334093706, 0.07477632324610438, 0.07574590907565185, 0.05669422334592257, 0.06291002141577856, 0.020108042617461512, 0.06539223822099821, 0.08715392835438251, 0.09365181039486613, 0.15552555955946445, 0.06037774908223322, 0.11093259097209998, 0.15968504707728112, 0.05924888394240822, 0.09826600458472967, 0.06764255889824458, 0.09243500711662428, 0.06330298818647861, 0.08724348140614373, 0.0295246430406613, 0.04593442214120712, 0.005816966212088508, 0.034718689508736134, 0.050301945103066306, 0.08146124346447842, 0.03266214146944029, 0.12005324156156608, 0.042884967023772855, 0.03516657690384558, 0.04734659940004349, 0.03370342130905815, 0.08497896577630724, 1.2033042311668396, 89.35344478062221, 117.67509433201381, 96.02428518022809, 104.05580520629883, 94.80843380519322, 103.28679248264858, 59.29211221422468, 51.03729098183768, 33.16883795601981, 21.065058640071324, 67.95984404427665, 61.68355015345982, 106.42748941693986, 108.54957348959786, 72.15222031729562, 5.237681073801858, 0.2603794809963022, 0.04980506747961044, 0.2401572646839278, 0.06300646838332925, 0.7897051647305489, 0.09685827512294054, 2.5720442022596086, 1.00022933951446, 0.9821056148835591, 0.9281624065978187, 49.43360505785261, 101.75288731711251, 99.93570409502301, 100.11466189793178, 94.88458606175014, 94.58360399518693, 83.34574740273612, 85.5579218183245, 80.77107157026018, 79.26718957083565, 75.4326524734497, 79.61382825034005, 76.01329953329903, 76.05692727225167, 68.55646501268659, 69.58173424857003, 72.02852848597935, 72.47492940085274, 68.24854169573102, 69.7095811026437, 64.3351216997419, 70.69578061785016, 81.2123030253819, 89.6066232408796, 90.56848321642194, 85.66132490975517, 76.00735882350376, 66.50456469399589, 62.58296666826521, 75.03280448913574, 85.70566136496407, 85.46486459459577, 82.46621663229806, 81.07697990962437, 69.27911240713937, 65.55047975267682, 70.35359573364258, 72.14404228755406, 77.94197354997907, 81.84067726135254, 82.2718755177089, 80.99651976994106, 71.30368546077183, 76.86999157496861, 60.12102535792759, 70.65744740622384, 83.2452972957066, 77.28231157575334, 75.6688425881522, 77.17651830400739, 82.44245379311698, 85.25958006722587, 82.75344126565116, 84.32697895595005, 83.39962373461042, 76.81225899287632, 75.30149132864815, 77.87036541530064, 81.82191017695835, 85.14968735831124, 81.4957617350987, 82.04537814004081, 82.00666972569057, 80.04626328604562, 79.07027067456926, 73.93202917916435, 67.63293824877057, 64.9130311693464, 66.50083351135254, 71.47522953578404, 78.37010070255825, 80.70819732121059, 83.74350397927421, 82.36359868730817, 83.02282987322126, 81.35390036446708, 83.75935282026018, 84.67508370535714, 83.1566104888916, 79.80983693259103, 81.27599716186523, 89.2606863294329, 15.051556042262487, 0.5442131491644042, 0.17916578746267728, 0.4705457421285765, 0.26488226652145386, 0.07570558373949357, 0.05083301071343677, 0.061816969354237826, 0.06402795535645314, 3.386017850467137, 30.78491449356079, 64.80006735665458, 94.34991523197719, 71.92506980895996, 60.856519971575054, 36.21881226130894, 26.859319516590663, 44.91321127755301, 41.435353006635395, 74.00248391287667, 72.74096202850342, 74.29692077636719, 77.14450100490025, 29.491531644548687, 0.11371104259576116, 0.0775024937465787, 0.05133958460230913, 0.06757388436900717, 0.08076937523271356, 0.049250823113002946, 0.059834846428462436, 0.1027809019599642, 0.03264057084119745, 0.05600091661991818, 0.08248621810759817, 0.09409412701747247, 0.05200623508010592, 0.02757923225206988, 0.014225194047737335, 0.03544225889657225, 0.006418655867621834, 0.031230245982961993, 0.029170888808688948, 0.042609905890588246, 0.26905620683516773, 0.03603529850287097, 0.0786091640059437, 0.07109618000686169, 0.13686777358608587, 0.20844644627400807, 0.13865017651447228, 0.12667490196015152, 0.2163328823766538, 0.12695017004651682, 0.14194872522992746, 0.17953177568103584, 0.09613395256123372, 0.24653098838669912, 0.08308362747941699, 0.12634670814233168, 0.14091383719018527, 0.18922012937920435, 0.08367349832717862, 0.14080745646996157, 0.11350691212075097, 0.15379121048109873, 0.3406010477670601, 1.9065546435969216, 111.70196424211774, 130.66907337733676, 110.14294828687395, 113.93197468348912, 94.16650363377163, 93.82558332170758, 50.76157603945051, 33.93740252086094, 50.023444584437776, 67.22180638994489, 76.23393957955497, 73.13424396514893, 121.40235819135393, 113.10479858943394, 89.7114646094186, 11.444894671440125, 0.4669669855918203, 0.2870668875319617, 0.35350439537848743, 0.3728268471147333, 1.5821385830640793, 0.16113180587334291, 5.971667494092669, 7.324748396873474, 1.24788832451616, 0.9618630153792245, 50.45063373020717, 106.87519659314836, 103.73811272212437, 103.01216493334088, 99.57808031354631, 100.88294506072998, 86.77357864379883, 90.44415215083531, 86.39066341945103, 85.6067954472133, 80.85745852334159, 83.54880155835832, 78.55741024017334, 81.24467468261719, 72.55060917990548, 73.55777141026088, 75.02533517565045, 77.81079156058175, 72.50414657592773, 73.06620720454625, 68.30945655277797, 73.08882359095982, 81.64327893938336, 93.98516954694475, 92.960907799857, 92.08246094839913, 80.80625029972622, 72.19369411468506, 65.39144243512834, 78.60292788914272, 91.79782104492188, 87.231687273298, 88.15890353066581, 85.80838353293282, 73.62133353097099, 70.1827951158796, 75.37348161424909, 77.22518348693848, 82.07892404283795, 85.16438279833112, 83.09463950565883, 85.08889062064034, 76.04877703530448, 81.56077602931431, 67.74745150974819, 75.28942925589425, 87.11422797611782, 80.54643630981445, 79.11785193852016, 80.57555621010917, 84.56000069209507, 90.99575574057442, 85.78597559247697, 87.29586778368268, 87.95700972420829, 80.50353813171387, 80.50690800803048, 80.83650275639125, 86.64791352408272, 88.36795398167202, 84.9202995300293, 84.39637061527797, 86.45888778141567, 83.91960607256208, 84.67288112640381, 77.18983105250767, 70.89645848955426, 69.61812196459088, 71.4600477218628, 76.8541566303798, 83.6223065512521, 84.92370414733887, 86.58448341914585, 88.53151457650321, 89.81925201416016, 86.1963778904506, 87.99951185498918, 87.6762330191476, 86.26570006779262, 82.91332626342773, 86.97800159454346, 91.83253424508231, 11.641862205096654, 4.883096260683877, 1.1030385770968028, 0.6657245489103454, 0.8612797526376588, 0.31864883857113974, 0.22627488603549345, 0.1304914578795433, 0.27333266021949904, 10.402454699788775, 47.947889123644146, 75.72070394243512, 107.18041706085205, 79.84735720498222, 96.42023522513253, 118.24092783246721, 56.276257038116455, 48.97358219964163, 38.99292571204049, 70.10093144008091, 80.19978373391288, 85.64052895137242, 89.21754496438163, 41.74799762453352, 0.7185907321316856, 0.140753621501582, 0.19501445202955178, 0.22135161235928535, 0.18763777214501584, 0.08052555724446263, 0.12817835914237158, 0.0992093039676547, 0.15612066191221985, 0.12487849406898022, 0.16323902351515635, 0.14800964428910188, 0.15378950057285173, 0.19171517049627645, 0.08984039098556552, 0.23047310433217458, 0.1970264304961477, 0.21426607828055108, 0.12887098054800714, 0.09953105170279741, 0.3331564600978579, 0.14059118021811756, 0.15427018835076264, 0.26977577965174404], [0.05860297288745642, 0.09000415541231632, 0.03747402683698705, 0.07122002621846539, 0.11900577348257814, 0.050433143241597075, 0.11200849645371948, 0.11642567121556827, 0.17688262569052832, 0.07920022228998796, 0.12393850593694619, 0.019454250378268104, 0.09664444838251386, 0.05200887797400355, 0.09445765215371336, 0.052704145666211843, 0.06568815412798099, 0.009437143070889371, 0.17298722400196961, 47.76511328560965, 99.66677406855992, 82.40015316009521, 80.48969732012067, 45.54783541815621, 36.092900480542866, 28.165990795407975, 39.73417343412127, 49.56939370291573, 81.61998857770647, 127.47013664245605, 69.63164315904889, 86.03083011082241, 107.83163002559117, 62.97638756888253, 8.089304719652448, 0.06419800301747662, 0.027010092345465506, 0.04046360123902559, 0.03255909574883325, 0.09443334024399519, 0.17129893388066972, 0.804025293460914, 0.7012169786861965, 0.3353830591908523, 3.437824704817363, 54.229300362723215, 94.09309591565813, 88.99689102172852, 91.08857672555106, 98.53939410618374, 89.72508307865688, 90.38573169708252, 89.39666952405656, 85.63881274632045, 79.78655351911272, 79.16250801086426, 79.37588024139404, 78.90701580047607, 73.8219975062779, 70.6518749509539, 65.1352206638881, 65.59060559953961, 64.3378940309797, 67.43187822614397, 64.86925057002476, 63.17335510253906, 61.70989077431815, 71.76481655665806, 80.39563955579484, 84.41786139351981, 85.40114961351667, 83.6015453338623, 69.73203073229108, 62.043293135506765, 59.37606034960066, 69.41647134508405, 79.74457250322614, 82.26380865914481, 82.32026277269635, 78.03835896083287, 72.7846314566476, 71.08247566223145, 63.92464991978237, 68.79778289794922, 68.35645416804722, 73.07287052699498, 79.25497463771275, 77.27767712729317, 69.22889082772392, 72.16524124145508, 63.5743773324149, 70.44661821637834, 77.4588097163609, 71.66440813882011, 69.1826227733067, 72.64740453447614, 77.18171555655343, 78.7664954321725, 80.36995901380266, 77.06026104518345, 74.78199536459786, 71.89840262276786, 66.05789279937744, 66.49454539162772, 75.5194980076381, 79.69669246673584, 80.3221206665039, 78.33724961962018, 79.59429686410087, 78.31076308659145, 75.30163029261998, 74.5668374470302, 74.38247394561768, 67.72350801740373, 65.03393677302769, 60.51313304901123, 65.1921889441354, 64.76408958435059, 68.52978393009731, 71.67766530173165, 72.83706256321499, 74.50857680184501, 77.7514122554234, 76.33303478785923, 80.97114494868687, 80.7137975692749, 81.3995361328125, 77.3295454297747, 79.9165404183524, 7.845332622528076, 1.638517786349569, 0.3134437421602862, 0.3923904773380075, 0.10946021747908422, 0.02398618746415845, 0.06306187076760189, 0.036909685869302065, 0.12121242364602429, 0.366776811757258, 14.033644948686872, 51.255099637167795, 84.51667867388043, 85.67088563101632, 82.85234192439488, 71.9100478036063, 49.998274735042024, 26.20977064541408, 25.676494666508265, 53.376402037484304, 78.46317877088273, 64.86363642556327, 69.78887394496373, 9.781243188040596, 0.2213017400354147, 0.09464447998574801, 0.017062373725431304, 0.0920930661793266, 0.07752156736595289, 0.051375346790466986, 0.06012943919215884, 0.09923843347600528, 0.01741907958473478, 0.10421595602695431, 0.02112323448194989, 0.10749392477529389, 0.006066968198865652, 0.04792341523404632, 0.07102052335228239, 0.046070376810218604, 0.09087772853672504, 0.050001184456050396, 0.08622274082154036, 0.022019258633788143, 0.022416920866817236, 0.04717283336711781, 0.04826849439580526, 0.051044669534478865, 0.060952658232833655, 0.07455906311848334, 0.03727131450016584, 0.042863789945840836, 0.08215281992618527, 0.09161685673253876, 0.05268817634454795, 0.11921997341726508, 0.051602924043046575, 0.1484431738832167, 0.04132917443556445, 0.115218421710389, 0.08563953318766185, 0.09258283275578703, 0.012110035001699413, 0.06549445952155761, 0.05512322139527116, 0.14326682021575315, 60.624366760253906, 114.13076264517647, 93.27365316663469, 97.3813725880214, 66.90312031337193, 59.22024004799979, 54.231468200683594, 57.97567176818848, 27.890512091772898, 30.24094349997384, 90.61347975049699, 74.08373614719936, 93.97363553728376, 116.02330602918352, 69.2764790398734, 7.287445255688258, 0.25914671857442173, 0.06669237917023045, 0.08164646316851888, 0.06302554200270347, 0.6725921375410897, 0.8574183998363358, 1.1154426315001078, 0.5803624008383069, 0.28040190945778576, 5.044393045561654, 64.15661552974156, 102.85518428257534, 93.01749392918178, 94.08019311087472, 101.09139101845878, 95.12411825997489, 95.15248080662319, 94.60492106846401, 88.63893372671944, 84.78499031066895, 85.00237165178571, 82.75999341692243, 83.65968785967145, 78.36311081477574, 72.30399676731655, 69.5806781223842, 67.28516006469727, 67.3896609715053, 70.38420254843575, 68.11874239785331, 66.32775388445172, 65.06473813738141, 76.19507135663713, 86.87155519212995, 84.89058208465576, 88.4964678628104, 87.31281444004604, 75.0907107761928, 63.948579515729634, 62.33883476257324, 71.67697743007115, 83.40375096457345, 84.51483740125383, 86.11274242401123, 82.87509032658168, 78.85108280181885, 74.88581534794399, 69.6804473059518, 72.75625501360211, 71.8388009752546, 75.47423049381801, 80.6470809664045, 82.15724413735526, 73.57959570203508, 75.61648791176933, 66.55459867204938, 73.58797522953579, 81.59989438738141, 75.54487977709088, 71.3970136642456, 73.61319719042096, 80.87318924495152, 80.99058600834438, 83.39878300258091, 80.6888952255249, 78.72789818899972, 73.81571633475167, 66.99446133204869, 67.62393338339669, 77.10671670096261, 82.07273319789341, 83.59727913992745, 81.1717255456107, 82.28576496669224, 82.55398627689907, 80.11182648794991, 79.13102572304862, 77.64592470441545, 71.73999064309257, 69.34015233176095, 63.74908283778599, 67.42893913814, 67.55495166778564, 71.54574680328369, 73.467298916408, 73.86644513266427, 77.99908774239677, 81.19907365526471, 78.63470200129917, 83.43104348863874, 83.35860851832798, 85.50600487845284, 78.52866554260254, 87.60445812770298, 15.446953705378942, 0.8196504350219453, 0.30282238924077576, 0.7579314325537, 0.24833884994898522, 0.032478275442762036, 0.029161477527980293, 0.11532473457711083, 0.18893359761152947, 0.4655454275863511, 16.56075167655945, 55.58554009028843, 88.60380363464355, 91.90663678305489, 77.12500435965401, 44.86688068934849, 35.92534467152187, 38.245904036930625, 45.96493230547224, 62.570640563964844, 90.55505234854562, 71.44961847577775, 82.74629156930106, 16.840765816824778, 0.2574383573872702, 0.07032091982130494, 0.04366317205131054, 0.04484037263318896, 0.06296775117516518, 0.05255529883184603, 0.019728042650967836, 0.10363426831151758, 0.020880810883162276, 0.019290438454066004, 0.06111905537545681, 0.08319377406899418, 0.0899649021614875, 0.1251783658351217, 0.0435285948083869, 0.03928726578929594, 0.03138882300949522, 0.06379532641065971, 0.044014866929501295, 0.050399786460080316, 0.02648183756640979, 0.06304633231567484, 0.015224234234275562, 0.18843830776001724, 0.17066820843943528, 0.10652640169220311, 0.10500632040202618, 0.19613608398607799, 0.16985509278518812, 0.17049340424793108, 0.21884716674685478, 0.2646420108420508, 0.07184653795723404, 0.18280962907842227, 0.11069939884224109, 0.2226246797612735, 0.19184367145810807, 0.22166037293417112, 0.18464289499180658, 0.2072524553430932, 0.20000137229050907, 0.18086297996342182, 79.4527690070016, 130.36825806753976, 109.55977208273751, 108.04783017294747, 71.22330175127301, 52.26775441850935, 39.42556571960449, 53.59470748901367, 69.90108735220772, 99.87401103973389, 156.58199092320032, 95.95093304770333, 108.12330150604248, 122.13442039489746, 86.20608452388218, 13.507679343223572, 0.4661187625357083, 0.3505315434719835, 0.20455455939684594, 0.14632267052573816, 1.0188750475645065, 0.4644226964030947, 1.168533816933632, 4.651313040937696, 1.568032762834004, 5.028894220079694, 64.00968892233712, 105.83300849369594, 94.69757529667446, 97.62160655430385, 105.81618690490723, 97.51301315852574, 99.59037167685372, 99.7794669015067, 93.42585345676967, 89.39468928745815, 87.9907362801688, 87.26974255698067, 89.31837722233364, 83.8793134689331, 77.701003074646, 74.71689769199916, 73.38528932843889, 71.51982307434082, 75.01806041172573, 71.3969372340611, 67.75068242209298, 66.7179091317313, 80.53138651166643, 88.74225343976701, 87.84355953761509, 91.62221227373395, 92.31510053362165, 77.50084631783622, 68.4006655556815, 67.14457021440778, 76.1505125590733, 87.6855297088623, 87.24111597878593, 90.24712903159005, 86.20193644932338, 82.34119769505092, 79.09471443721226, 71.47613280160087, 75.7517762865339, 75.47718347821916, 79.21096474783761, 86.31932626451764, 84.72212995801652, 78.70182159968785, 82.60479845319475, 72.66635922023228, 77.27201434544155, 86.12472111838204, 77.51313768114362, 76.21350492749895, 77.87380477360317, 85.0240569795881, 85.23797116960797, 86.79887703486851, 84.66126373835972, 81.39590917314801, 78.77770287649972, 72.3505288532802, 71.5599558694022, 83.26113224029541, 87.90994957515171, 86.8703670501709, 84.63647951398576, 84.03275053841728, 86.65376390729631, 83.1040404183524, 81.0986304964338, 82.58910942077637, 75.91438497815813, 73.37031596047538, 67.3155653817313, 71.8132871900286, 71.4129945210048, 76.40844358716691, 79.5129473549979, 79.0722439629691, 81.85511561802456, 85.25315298352922, 82.1869476863316, 87.91432694026402, 89.35430635724748, 89.29514939444405, 82.19228390284947, 91.06340340205601, 11.975528597831726, 3.864185495035989, 1.1016984432935715, 1.1542225905827113, 0.5982702970504761, 0.21301006924893173, 0.2273387610912323, 0.26916539669036865, 0.5347457943218095, 1.937065269265856, 26.818696873528616, 65.46436377934047, 96.52778639112199, 100.14466421944755, 103.14240196772984, 98.91185229165214, 62.42541626521519, 33.3247902733939, 36.00303247996739, 67.07749230521065, 97.06768921443394, 79.08566788264683, 96.8153097970145, 31.914910452706472, 0.4460826005254473, 0.13629002815910748, 0.16184482404163905, 0.14281419664621353, 0.17061099436666283, 0.08009679775152888, 0.08968333048479897, 0.204389661816614, 0.07951871984239135, 0.1659296184246029, 0.13260700793138572, 0.13771358105753148, 0.11217326511229787, 0.14778199579034532, 0.27364953607320786, 0.16466457130653517, 0.15072744845279626, 0.2254150736012629, 0.10412364133766719, 0.11605451256036758, 0.06799790090216057, 0.19332647403436048, 0.11708606220781803], [0.06287507686231818, 0.05547974065744451, 0.03648430548076119, 0.1278138229889529, 0.07148994066353355, 0.09146639837750367, 0.10162505148244755, 0.14304833193974836, 0.024109641821788888, 0.07671411069376127, 0.06221831603241818, 0.11428175839994635, 0.038507876718150716, 0.07331771044326679, 0.06705610786697694, 0.19863155936556204, 0.26727801082389696, 0.5674025991133281, 13.884553108896528, 97.86955302102226, 86.36715766361782, 98.99194417681012, 57.79477194377354, 52.64018133708409, 37.161710602896555, 46.61751406533377, 41.13354410443987, 116.49241365705217, 162.9373414175851, 101.31922245025635, 102.60566752297538, 108.58311244419643, 66.34941141945976, 6.271442745413099, 0.27384039440325325, 0.08825452572533063, 0.12333161064556666, 0.12473434608961854, 0.23340122721024922, 0.20557990723422595, 0.19819895257907255, 0.12738209829798766, 1.2851771350417818, 1.905998136316027, 68.1981394631522, 102.51324953351701, 94.60917336600167, 97.53530297960553, 92.28520243508476, 89.98887838636125, 96.09925624302456, 92.89836706433977, 87.99002061571393, 88.70726925986153, 90.44350596836635, 85.12229061126709, 80.74675982339042, 77.13849776131767, 71.09847041538784, 69.63190719059536, 61.73099940163748, 60.70671680995396, 67.70881952558244, 65.14451735360282, 64.04338073730469, 60.822793415614534, 66.57488741193498, 75.74847589220319, 84.55817331586564, 77.35986042022705, 76.87069334302629, 82.1682778767177, 70.37530885423932, 61.85685212271554, 55.287323406764436, 61.17642198290144, 73.8202257156372, 79.04366602216447, 86.5133547101702, 80.52253450666154, 79.34837927137102, 75.07174219403947, 76.90833173479352, 74.25991467067173, 71.97861957550049, 69.27205998556954, 73.93730981009347, 78.22358403887067, 75.57477787562779, 71.3741888318743, 60.41106401171003, 73.68194266727993, 70.43932260785783, 70.96624619620187, 61.97549261365618, 63.55356747763497, 69.5319573538644, 72.82484068189348, 74.91305923461914, 76.2942429951259, 72.62265505109514, 68.38335064479283, 61.277844837733674, 59.058708327157156, 66.34928635188511, 76.25079590933663, 78.96760409218925, 79.90766756875175, 76.28502968379429, 78.96292100633893, 78.23028905051095, 82.57991000584194, 77.6526575088501, 77.24201897212437, 69.81965446472168, 65.27792971474784, 61.05107648032052, 61.70357486179897, 63.04702990395682, 67.30744293757847, 67.59270817892892, 72.49050031389508, 74.84858689989362, 77.3447550364903, 75.06425898415702, 77.49736527034214, 78.90142944880894, 79.4270328794207, 73.64347049168178, 77.46199199131557, 2.46713530591556, 0.6937286662203925, 0.4499182775616646, 0.37198445945978165, 0.03645182740209358, 0.09593483646001134, 0.05824005164738212, 0.06651642146919455, 0.11228305886366538, 0.16876605765095778, 8.96235021523067, 44.44451706750052, 80.20131233760289, 82.13812269483293, 66.97296360560826, 68.77997466496059, 34.88468517575945, 24.930100066321238, 34.85385601861136, 43.87092590332031, 75.76139954158238, 67.61592211042131, 65.56698172433036, 10.013683881078448, 0.1977146142827613, 0.12323812209069729, 0.10524730211389915, 0.13340197955923422, 0.07124072832188436, 0.03125064953097275, 0.05283174756914377, 0.11639327795377799, 0.08695390980158534, 0.041332214272447994, 0.17199299378054483, 0.07764725240745715, 0.04633728534515415, 0.06177353632769414, 0.057127668123160086, 0.1900249940476247, 0.06696539452033383, 0.09769280534237623, 0.16800787619182042, 0.1460848304310015, 0.042369680745261054, 0.1331878203366484, 0.046565605593579154, 0.02868370066529938, 0.06583173892327718, 0.10100460584674563, 0.06334823290152208, 0.0443886752639498, 0.06589529051312379, 0.14141535599316868, 0.051385148228811364, 0.09136713548962559, 0.058822485751339366, 0.029916741286537478, 0.016787226079031825, 0.01615726907870599, 0.08777869625815324, 0.12735313842339174, 0.2860072872468403, 0.7715592384338379, 17.94472861289978, 116.27866622379848, 96.28769833700997, 114.84721919468471, 69.21976784297398, 68.62491866520473, 58.518291337149485, 49.626052788325715, 17.977642229625157, 58.707122530256, 142.2032081059047, 111.63688741411481, 110.56000001089913, 113.15595817565918, 75.52632808685303, 6.843969966684069, 0.4738668182066509, 0.1377265817884888, 0.17826495080121926, 0.07911632822028228, 0.47608394495078493, 0.8409818932414055, 0.6997562827808517, 0.5645808705261776, 0.28163931305919376, 3.5282659317765916, 83.40566171918596, 106.75185217176164, 99.0203275680542, 98.60770879473004, 97.38962704794747, 91.54956190926688, 97.79384544917515, 96.40578992026192, 93.75612912859235, 92.41263239724296, 93.79533781324113, 87.84301062992641, 82.70046125139508, 80.41803359985352, 74.86668000902448, 73.50545147487095, 66.87391008649553, 63.11334351130894, 68.91583974020821, 65.43886389051164, 66.08797849927629, 63.34599004473005, 69.97452981131417, 78.82269941057477, 85.92227145603725, 79.1058315549578, 78.92726285117013, 85.90417834690639, 75.20302145821708, 65.67933409554618, 59.60239791870117, 63.65797110966274, 77.81750352042062, 82.3146208354405, 88.76646791185651, 83.27818311963762, 83.0140334538051, 79.8256093433925, 80.83043697902134, 77.55739770616803, 77.92258112771171, 71.90971429007394, 76.11997522626604, 81.37959480285645, 77.31719848087856, 72.92380387442452, 63.40821116311209, 77.61991064889091, 74.75581455230713, 72.65739604404995, 66.60593891143799, 66.42022051130022, 71.45244639260429, 74.13172040666852, 78.21487099783761, 79.08170740944999, 74.43097237178257, 70.94773619515556, 63.52227973937988, 62.43820095062256, 67.44931820460728, 78.05611855643136, 82.50386197226388, 81.92174189431327, 77.47184453691754, 80.02349403926304, 81.38053280966622, 86.15010983603341, 82.10334696088518, 81.78086716788155, 73.67370905194963, 68.76466083526611, 64.32179505484444, 64.81429726736886, 64.37069647652763, 70.65149974822998, 71.52012879507882, 74.91366372789655, 75.77175235748291, 80.96218872070312, 78.48218209402901, 79.00603457859584, 80.70905889783586, 85.54012748173305, 74.42521231515067, 84.86624949319022, 5.949749401637486, 1.0258229204586573, 0.7472521056021962, 1.6622963675430842, 0.5341872242944581, 0.06355348295931305, 0.1071636885670679, 0.00877712612106864, 0.08939042048794882, 0.13265457323619298, 9.860586404800415, 47.38933733531407, 82.7340418951852, 90.58300495147705, 72.81394590650285, 35.20912783486502, 17.492338350840978, 32.67267404283796, 55.872921058109824, 53.75012132099697, 83.33937590462821, 74.82517841884068, 80.14674118586949, 15.28065378325326, 0.12208411044308118, 0.20690967302237237, 0.04224021965637803, 0.11622895034296171, 0.019091704028791616, 0.028871821106544564, 0.03249319303514702, 0.08667697251907416, 0.10606535071773188, 0.04534207803330251, 0.11384915161345686, 0.10584850449647222, 0.014578679410208548, 0.07679204722600323, 0.05506088438310793, 0.17881753614970616, 0.03590576956048608, 0.13522301827158245, 0.05042886507830449, 0.12058705863143716, 0.06044165351028953, 0.13329582954091684, 0.0844150013955576, 0.10263680147805385, 0.1574689517063754, 0.15288240781852178, 0.15171766174691065, 0.1087554299405643, 0.15614686693464006, 0.2332544465150152, 0.11891871743968555, 0.19579543226531573, 0.12484432304544107, 0.17778856493532658, 0.08908450297479119, 0.19003671913274697, 0.2177283710667065, 0.3188931383192539, 0.5139767059258052, 1.2637771176440376, 26.990861075265066, 138.2783374786377, 110.88688496180943, 129.98738561357771, 77.96194962092808, 72.62970052446637, 52.478924070085796, 57.91460057667324, 55.68996804101126, 147.8536777496338, 185.59449986049106, 117.2327859061105, 121.27039800371442, 123.8935375213623, 92.12569958823067, 12.483778033937726, 0.8691562956997326, 0.23230813443660736, 0.38008538048182217, 0.26208746220384327, 0.8268761272941316, 0.8565183909876006, 0.6443838083318302, 3.845880900110517, 6.468768979821887, 2.686214395931789, 86.31462928227016, 112.61459623064313, 102.9190799168178, 104.0854879106794, 98.90587684086391, 95.30217974526542, 99.58026899610246, 98.81766945975167, 96.73005540030343, 96.63585172380719, 97.84353201729911, 94.16469710213798, 89.12411948612758, 85.59110641479492, 77.34028734479631, 77.9046825681414, 70.5094438280378, 67.77453558785575, 74.09775761195591, 69.78230094909668, 70.5953722000122, 67.72111783708844, 72.90118748801095, 82.26098769051688, 92.10510512760708, 83.50884246826172, 81.85022408621651, 92.28715487888881, 78.71450901031494, 71.58405917031425, 62.667755535670686, 69.00439453125, 83.24854210444859, 87.70899377550397, 94.64852796282086, 87.18078477042062, 87.26744270324707, 83.56878457750592, 82.59854507446289, 81.87498746599469, 77.95623125348772, 75.90404605865479, 79.53337505885533, 87.23436232975551, 79.94465282985142, 80.4698463167463, 70.41699109758649, 80.57213769640241, 79.26564707074846, 77.30264200483049, 71.29773085457938, 70.45544242858887, 76.06880869184221, 78.00136675153459, 83.09039415631975, 84.67116492135185, 78.71462018149239, 74.35890565599713, 68.13448701586042, 65.73192501068115, 71.65955829620361, 81.83820370265416, 86.2524220602853, 85.09112794058663, 80.9798093523298, 83.99124200003487, 83.34715093885148, 90.25602967398507, 86.95220988137382, 86.09594862801688, 77.19417367662702, 72.56644412449428, 68.02970123291016, 68.06280245099748, 68.22240952083042, 73.40717615400041, 75.70820413316999, 78.56977803366524, 81.740720476423, 84.6462903703962, 81.29065786089215, 84.99868910653251, 83.19390147072929, 90.61142308371407, 75.72829832349504, 92.29980060032436, 4.012996367045811, 2.993892571755818, 2.3561410903930664, 0.8656284021479743, 0.5279406851955822, 0.18547403253614902, 0.2198144591280392, 0.14151135512760707, 0.2939567592527185, 0.25424096467239515, 16.970641544887, 59.58511080060686, 92.69938455309186, 96.503495488848, 87.39494909558977, 93.35532924107143, 42.98031275612967, 31.362462656838552, 47.098926952907014, 59.207983425685335, 94.91422012874058, 82.51622976575578, 97.13789381299699, 24.76806112698146, 0.42121613770723343, 0.31556400124515804, 0.27102783960955484, 0.2367394837949957, 0.15736491871731623, 0.09355810470879078, 0.10327450904463019, 0.21776802465319633, 0.17044999157743795, 0.18537217085914953, 0.1685762306941407, 0.14446743364845002, 0.1867878527513572, 0.20562083646655083, 0.10444738396576472, 0.32896430790424347, 0.133921886661223, 0.20500111686331884, 0.21072854953152792, 0.24896304788334028, 0.14383251486080034, 0.28693413894091335], [0.08155975996383599, 0.07458722232175724, 0.07965555999960218, 0.06842573080211878, 0.12510679396135466, 0.07665645557322673, 0.10650113983345882, 0.06691308625574623, 0.08137557841837406, 0.13302419840225152, 0.028789888003042767, 0.11955967518900122, 0.06295572753463473, 0.028785063619060174, 0.015324014505105359, 0.005569682606229824, 0.06053342537156173, 0.1841440089046955, 35.5460181917463, 94.43999862670898, 88.1026439666748, 62.32563318525042, 45.65627942766462, 34.49213627406529, 31.187044961111887, 65.97196442740304, 122.35176004682268, 94.45044871738979, 68.01390102931431, 96.0896121433803, 101.15841334206718, 72.45707253047398, 8.827919942992073, 0.24101911272321427, 0.04055277431117637, 0.02717608236707747, 0.08759192270892006, 0.12808584767792905, 0.23569258568542345, 0.2995344528130123, 2.4237446742398396, 0.7408337071537971, 0.9501890646559852, 62.65740271977016, 99.91954258510044, 93.357510975429, 95.22053146362305, 92.24571582249233, 97.28172152382987, 90.60548932211739, 89.72489547729492, 92.1844049181257, 92.55361134665353, 91.49660273960659, 87.03158610207694, 84.70368943895612, 81.24550151824951, 68.71706567491803, 65.4345976965768, 64.31061540331159, 60.76238577706473, 59.53063692365374, 65.45371219090053, 63.44275065830776, 61.519968714032856, 60.38086714063372, 65.75095612662179, 80.46767153058732, 76.55328573499406, 82.74837602887834, 80.16004003797258, 75.26955740792411, 69.29194572993687, 61.227296692984446, 55.81567832401821, 56.975749560764854, 67.57438577924455, 72.39237090519497, 76.92482675824846, 81.05453722817558, 78.89368220738002, 78.16608769553048, 79.49703598022461, 79.42880467006138, 77.41888536725725, 68.2109797341483, 75.80565956660679, 79.0878496170044, 71.81646946498326, 62.72878851209368, 58.9437712260655, 67.50589738573346, 73.12126473018101, 68.28672899518693, 62.01581301007952, 61.17963899884905, 60.01275157928467, 59.742418016706196, 62.672070366995676, 62.36404282706124, 64.01084232330322, 62.139358929225374, 62.82437488010952, 61.78331238882882, 59.94359615870884, 66.36933190482003, 76.2581262588501, 79.03470979418073, 78.09672382899693, 75.89952972957066, 79.05870192391532, 78.78078787667411, 78.87756933484758, 78.7595819745745, 75.54261466435024, 68.79388495853969, 63.38236386435372, 62.12683827536446, 61.12069048200335, 65.07222829546247, 64.38102149963379, 70.36978503635952, 71.5125344140189, 71.61495086124965, 74.91981983184814, 77.14966351645333, 73.55400548662458, 78.79180771963937, 77.06254005432129, 75.82142502920968, 44.392794677189414, 0.3198941946029663, 3.3986331735338484, 2.6160419327872138, 0.08466313486652714, 0.12353329839450972, 0.016617193685046265, 0.0773662846269352, 0.024777893642229692, 0.012893442696492587, 0.09060824835406882, 3.6602276393345425, 38.690390723092214, 79.6149469103132, 89.600314276559, 85.77040467943463, 104.1777252469744, 38.621429852076936, 14.847763640539986, 30.865704672677175, 53.27879721777779, 67.99056897844586, 67.96220643179757, 49.31130634035383, 2.245743985686983, 0.1543899904936552, 0.0700778007241232, 0.05705458990165165, 0.04718725562893918, 0.05080084815355284, 0.23290896362492017, 0.09498796798288822, 0.21066604288561003, 0.08553098115537848, 0.09286008216440678, 0.07276767638645001, 0.04078561021015048, 0.023344174592888782, 0.07361089185412441, 0.010818206954614391, 0.029304631453539644, 0.0380178522983832, 0.05567202051835401, 0.11684898207230227, 0.11611155021403517, 0.04686952821378197, 0.03478148113936186, 0.0479216171162469, 0.019695566268637776, 0.03093666423644338, 0.1567056676638978, 0.0022663637895935346, 0.0719884806977851, 0.087125273820545, 0.1192182499383177, 0.05136648512312344, 0.03752568710063185, 0.029867435539407388, 0.07013777643442154, 0.01458381931297481, 0.052887594393853626, 0.012843673001043499, 0.0982306461249079, 0.05027005734986492, 49.273244108472554, 107.86081940787179, 99.94623756408691, 79.81732709067208, 71.24302073887416, 59.823864800589426, 31.408497946602957, 29.029596294675553, 72.42133794512067, 87.91739109584263, 79.46623461587089, 105.07953194209507, 105.83320999145508, 85.92658628736223, 11.139966896602086, 0.4164990708231926, 0.05860876079116549, 0.06523488595017365, 0.08133608089493853, 0.15124214440584183, 0.08096837598298277, 1.225164458155632, 1.539876056568963, 0.3557359613478184, 2.906018487044743, 75.03979437691825, 104.58151980808803, 96.84889738900321, 100.39876679011753, 96.10657269614083, 99.04905142102922, 93.49823978969029, 92.22480869293213, 94.58529935564313, 96.58718654087612, 93.3723314830235, 90.96523230416435, 89.46471323285783, 84.82766614641461, 73.12737914494106, 68.42004408155168, 68.35213238852364, 64.60001482282365, 62.39738723209926, 70.04824325016567, 66.39195523943219, 63.09338828495571, 63.28533921922956, 69.97253567831856, 83.77591732570103, 79.52197306496757, 85.53426320212228, 84.36017744881767, 80.16939231327602, 71.49262087685722, 63.72794641767229, 60.7050700868879, 60.65415368761335, 69.69732448032924, 74.17536899021694, 81.43759141649518, 82.2396011352539, 82.2044849395752, 80.31019755772182, 81.0871798651559, 83.81904479435512, 79.70919922419957, 71.26846504211426, 79.36967550005231, 81.58795738220215, 73.14754281725202, 67.48403140476772, 63.807815960475374, 69.06741469247001, 78.46494361332485, 72.67990820748466, 66.72180707114083, 64.03915623256138, 62.12343365805489, 60.980253492082866, 65.73846326555524, 64.35930143083844, 66.52454076494489, 64.14495645250592, 65.24681568145752, 62.815349170139854, 62.395483425685335, 67.83251830509731, 77.58075060163225, 80.34220790863037, 81.72698388780866, 80.30434717450822, 80.59277384621757, 80.99000930786133, 81.12154565538678, 81.07310281481061, 79.0946796962193, 73.200439453125, 66.96664769308907, 64.59738840375627, 65.90140547071184, 67.83866051265171, 66.39022513798305, 71.75262941632951, 75.11702360425676, 74.50337260110038, 78.10136522565568, 80.5516196659633, 78.63226318359375, 81.4007659639631, 82.03503922053746, 77.48375374930245, 53.99851247242519, 0.6673897824117115, 2.90028144632067, 4.289033966405051, 0.055894335731863976, 0.1596319042146206, 0.016047146237854446, 0.15073271388454096, 0.014536186154665691, 0.04450953592147146, 0.09243253046380621, 3.436141286577497, 42.32557010650635, 83.01447813851493, 94.52307823726109, 80.7006585257394, 54.189278738839285, 30.31177691050938, 24.99600546700614, 43.25277941567557, 70.36205863952637, 75.9996532712664, 75.36792305537632, 63.588961601257324, 3.3478459673268453, 0.1528537736407348, 0.11529690107064587, 0.06993032792317015, 0.05022773712075182, 0.026239324061732208, 0.01926097646355629, 0.08639151962207896, 0.11618309494640146, 0.11210458379771028, 0.07134104972439152, 0.10567645515714373, 0.06748612943504538, 0.07060743801827941, 0.0898963294125029, 0.02492492539542062, 0.010187607890527164, 0.01720302046409675, 0.07772124665124075, 0.047310151891516786, 0.042415308832590065, 0.07763947639614344, 0.13134603202342987, 0.15170151261346682, 0.24408934797559464, 0.18192993556814535, 0.2040354801075799, 0.08699846241090979, 0.13315054162272386, 0.20401466265320778, 0.19544366614094802, 0.1775002418352025, 0.11276107321360282, 0.16384977288544178, 0.10430096967944077, 0.2077162747404405, 0.13158411639077322, 0.20539750345051289, 0.2587648933487279, 0.2604368307760784, 68.44834409441266, 121.74373708452497, 113.58730234418596, 85.4376346043178, 68.15262876238141, 51.56118515559605, 42.10461739131382, 89.57912921905518, 163.58360726492745, 120.99700028555733, 88.5644976752145, 124.57332147870744, 113.65964003971645, 101.86155019487653, 19.63021046774728, 0.6127248842801366, 0.21883663588336535, 0.3870552107691765, 0.181364525907806, 0.5727425068616867, 0.6837767830916813, 1.5508834144898822, 8.920585462025233, 6.043782413005829, 2.0665117289338792, 78.13868400028774, 108.29708984919957, 99.84313324519566, 105.11029161725725, 102.74057374681745, 102.26483058929443, 97.44443443843296, 95.85383197239467, 98.73742471422467, 99.83885315486363, 99.01741627284459, 96.05708067757743, 95.262693132673, 88.50645242418561, 79.48193059648786, 71.72016048431396, 72.93638706207275, 67.43713801247733, 67.09160409654889, 74.81868185315813, 70.5843870980399, 67.50784982953752, 67.99530070168632, 73.78984819139752, 89.45178958347866, 84.62879480634416, 88.21838011060441, 88.88155092511857, 85.28105000087193, 76.47267273494175, 67.8429753439767, 62.808602469308035, 64.42478820255825, 73.99952398027692, 80.5590056010655, 85.67315769195557, 88.085433278765, 85.54480361938477, 86.99519143785749, 84.88602406638009, 86.14587838309151, 84.68536009107316, 75.02036721365792, 80.9772732598441, 84.7242352621896, 77.15670898982457, 74.50809737614223, 68.70184217180524, 73.23700087411063, 82.84209333147321, 74.60690076010567, 71.4195327758789, 65.8567841393607, 66.71380969456264, 65.43092904772077, 69.32478291647774, 67.93486527034214, 68.79032053266252, 66.75116321018764, 68.57273074558803, 66.02941908155168, 65.25980186462402, 73.54964201790946, 82.47884150913784, 85.9751055581229, 86.27708121708461, 84.16404369899205, 86.33658558981759, 86.12281036376953, 84.37748541150773, 86.29790496826172, 82.59559209006173, 76.94740840366909, 68.83740847451347, 67.50261783599854, 70.22242069244385, 71.94584492274693, 69.84905229296002, 76.17908355167934, 77.11296313149589, 78.58191653660366, 83.94871207645961, 84.9476545878819, 80.78516946520124, 86.40850639343262, 85.59379536764962, 80.6008962903704, 60.729256766183035, 0.4974324479699135, 8.354764989444188, 5.523377971989768, 0.10454676898994616, 0.5678661742380687, 0.12043304475290434, 0.36600005200931, 0.1848643281097923, 0.054138477093407085, 0.24071339198521205, 6.935275375843048, 55.02421249662127, 93.62283488682338, 102.4148838860648, 105.42382907867432, 141.51319640023368, 49.193701131003245, 18.752705097198486, 47.14663675853184, 71.46393871307373, 88.24734020233154, 82.87576430184501, 80.25493853432792, 6.7165456499372205, 0.3820960154490811, 0.18897819093295506, 0.16308213264814445, 0.19358734360763005, 0.14071940976594174, 0.25153181861553875, 0.1896450144371816, 0.2679859399795532, 0.12341193562107426, 0.18133893156690256, 0.13298766607684748, 0.1295692337942975, 0.19205903847302708, 0.2556177665080343, 0.1934373059443065, 0.10394438595644065, 0.10867706593126059, 0.16128451696463994, 0.11804496789617197, 0.2042835389396974, 0.22156623298568384], [0.07826375575470072, 0.07130951820207493, 0.13051709293254785, 0.13761024017419132, 0.07495877452726875, 0.1169389829571758, 0.05900067583258663, 0.05199525299082909, 0.04297323425167373, 0.09138548307652984, 0.0654303040355444, 0.06409915403595992, 0.11081708395587546, 0.022593414610517875, 0.007477821466246886, 0.15583863561706884, 0.04676848417147994, 1.8360745055334908, 68.33425467354911, 87.51188727787563, 73.14850861685616, 64.25554398127964, 30.472315038953507, 58.459335872105186, 100.87004225594657, 104.33094692230225, 54.52870866230556, 63.306142125810894, 105.11683682032994, 103.32840524400983, 75.5057475226266, 20.501901933125087, 0.11259629098432404, 0.01695142307185701, 0.0726405189239553, 0.06930827415947403, 0.12399643925683838, 0.186295765585133, 0.2709605832185064, 0.9788360531841005, 0.620788648724556, 2.065449740205492, 60.36255863734654, 105.24348163604736, 100.63712474278041, 92.71247495923723, 89.05411638532365, 89.44555010114397, 90.0229662486485, 92.44640064239502, 92.49133464268276, 86.5161131450108, 87.41880920955113, 88.17845576150077, 87.60119942256382, 81.63337080819267, 70.11527947017125, 60.767708097185405, 62.40713555472237, 59.65491935185024, 63.05187974657331, 63.56132166726248, 65.224928855896, 65.5591788973127, 63.90557711465018, 59.53986413138253, 66.80456706455776, 79.9761073248727, 77.39642878941127, 80.50916617257255, 79.46705450330461, 71.27951267787388, 65.46898433140346, 58.530228342328755, 58.252151012420654, 56.233834811619346, 59.276680265154155, 61.22958959851946, 68.82809094020298, 72.54662786211286, 80.91215474264962, 61.33490344456264, 69.85163007463727, 81.26337228502545, 68.62790639059884, 68.30131326402936, 75.75719588143485, 80.05653272356305, 70.56208338056291, 69.54174736567906, 64.315993309021, 63.06953511919294, 70.49533203669957, 67.62696974618095, 66.83577142442975, 61.67904772077288, 58.88671956743513, 57.21218286241804, 59.19411482129778, 58.077011244637625, 59.4862448828561, 57.769136565072195, 62.1164368220738, 60.42800371987479, 56.27065331595284, 57.49623564311436, 61.47308921813965, 65.46453748430524, 68.74767248971122, 69.38038934980119, 71.53802735464913, 74.33920751299176, 77.63303579602922, 75.42422430855888, 76.3256071635655, 74.86607551574707, 69.4484886441912, 65.20628683907645, 65.7150547845023, 59.29933834075928, 64.27998079572404, 64.42495495932442, 71.48935522351945, 72.49844905308315, 72.68239566258022, 71.12569345746721, 78.76441097259521, 72.30038370404924, 78.8573431287493, 75.4301928111485, 73.09884289332798, 12.511103561946324, 0.5312845057674817, 4.5492665852819165, 0.6741883776017598, 0.023913847149482796, 0.16568320164723055, 0.03421984413372619, 0.03951773699373007, 0.1555391845426389, 0.0521291415207088, 0.21379539210881504, 1.230901064617293, 31.959712437220983, 77.37631375449044, 85.17212309156145, 73.6207081930978, 83.42201777866909, 43.494990144457134, 16.801937546048844, 33.06599766867501, 55.139469214848106, 70.32831818716866, 62.37986387525286, 34.014916624341694, 1.7640609868935175, 0.03415720856615475, 0.08435847942850419, 0.046894973276981285, 0.04879874576415334, 0.10122907201626472, 0.09948815471891846, 0.07261212901877505, 0.12457076486732278, 0.08645218743809632, 0.03525923764599221, 0.0515015034138092, 0.04102531288351331, 0.039783732899065526, 0.04669446957164577, 0.058997825985508304, 0.12428953924349376, 0.1151738962424653, 0.07389101825122323, 0.03802461389984403, 0.05059549970818417, 0.08247613507722105, 0.061892212102455754, 0.14341326164347784, 0.1231847485261304, 0.10083807299711875, 0.06624581491840736, 0.07175199088773557, 0.03223366696121437, 0.07484804439757552, 0.010123201346557056, 0.10528481831508023, 0.052877009247562716, 0.015965844171919992, 0.018223430262878537, 0.08888329698571137, 0.055297353837106905, 0.22674783851419175, 2.4038869397980824, 84.28426143101284, 97.03749929155622, 86.19465473720005, 74.61159774235317, 46.528608390263145, 55.410160609654014, 45.88126904623849, 69.4501006262643, 60.85506779806954, 71.97045544215611, 108.69018418448312, 111.02078369685582, 85.90916715349469, 25.565050772258214, 0.31770600059202736, 0.0422079044261149, 0.09139266876237732, 0.07488317215549094, 0.10002585300909621, 0.2166862634143659, 0.7248506247997284, 1.0019273055451257, 0.6157001789127077, 4.585474516664233, 77.96241515023368, 107.78413908822196, 103.18986511230469, 99.06137752532959, 91.90807506016323, 93.49112483433315, 95.4399277823312, 95.69567707606724, 96.72945090702602, 90.190445627485, 91.02052606855119, 93.53401606423515, 89.735289982387, 85.18299007415771, 72.6624195916312, 64.00696522848946, 64.68715218135289, 64.65637166159493, 66.43966157095772, 67.32450076511928, 67.76022924695695, 69.31078924451555, 66.92936365944999, 62.87707001822335, 68.11757510049003, 82.75848565782819, 81.46587753295898, 82.65399169921875, 83.19590255192348, 73.71060398646763, 69.11617020198277, 61.58382960728237, 60.7385812486921, 59.16541181291853, 61.847479002816335, 64.34347343444824, 72.73176261356899, 75.74127755846295, 83.41242926461356, 67.65534618922642, 73.63213797977993, 83.22944845472063, 70.79355566842216, 72.96058763776506, 77.97781235831124, 82.45747579847063, 71.63814394814628, 71.78800964355469, 67.07339981624058, 65.04724257332938, 76.94239180428642, 73.51477595738002, 72.93267672402519, 64.87563596452985, 63.05056653703962, 59.3446683883667, 62.93806825365339, 60.29820442199707, 61.71098858969552, 61.460547719682964, 62.86944089617048, 62.211314473833355, 59.65363393511091, 59.601293155125205, 62.5782071522304, 68.02949973515102, 70.82796314784459, 72.54019383021763, 75.49927180153983, 77.74746567862374, 78.74631091526577, 78.41996097564697, 78.99115153721401, 78.08562755584717, 74.0935400554112, 68.52362087794712, 67.442918913705, 62.62022985730852, 67.40783051082066, 67.20690250396729, 74.00496441977364, 73.53591237749372, 77.29415130615234, 74.271087374006, 79.33393396650041, 76.60325717926025, 81.98901435307094, 79.5865843636649, 77.56743785313198, 17.764007704598562, 0.5446845952953611, 1.8189894280263355, 0.08848500371511493, 0.08770046117050306, 0.14489857479929924, 0.0937371701002121, 0.05662794404530099, 0.06784718470381838, 0.010515004429700119, 0.23464093783072063, 0.8512909572039331, 38.25911603655134, 81.0487424305507, 92.22927638462612, 77.75975009373256, 38.351012911115376, 31.91840192249843, 33.78345128468105, 40.719101428985596, 65.62138611929757, 77.58636474609375, 74.60266235896519, 42.797675882067, 2.2081073309694017, 0.07735607267490455, 0.04545286923114743, 0.09582395026726381, 0.07856336289218493, 0.09584974138332264, 0.04450674374986972, 0.14460875892213412, 0.07216671827648367, 0.049823686480522156, 0.028331188152411153, 0.053318806790879796, 0.1153752582945994, 0.03911024278828076, 0.08466677859957729, 0.0520254681552095, 0.05512433419270175, 0.06269820313900709, 0.12261408700474671, 0.049597171135246754, 0.04209844994225672, 0.162525815357055, 0.14477381935077055, 0.18245050763445242, 0.19798810460737773, 0.18186657396810396, 0.12413750668721539, 0.1857648797865425, 0.19110553392342158, 0.16887557320296764, 0.14513642846473626, 0.13167707568832807, 0.10598044563084841, 0.17994865402579308, 0.09901886632932083, 0.16489969726119721, 0.30198914823787554, 0.4662330821156502, 6.565094462462834, 108.23345824650356, 111.30044869014195, 100.48476464407784, 81.2031591960362, 41.559333188193186, 73.28326198032924, 127.45697675432477, 140.47163363865442, 78.51451901027134, 81.78389658246721, 126.29090227399553, 114.39351572309221, 99.60618577684674, 42.862040519714355, 0.5727955954415458, 0.11275422679526464, 0.21692121294992311, 0.1830087248235941, 0.28798448400838034, 1.7574502101966312, 2.351554627929415, 4.657208587442126, 3.8297328523227145, 3.1488608505044664, 78.71235506875175, 112.83326298849923, 108.17072296142578, 103.04127788543701, 96.1284178325108, 96.33245863233293, 98.76981026785714, 101.20019980839321, 101.49514389038086, 96.4182549885341, 96.50665691920689, 96.35656888144356, 95.53447886875698, 90.58875805991036, 78.06146172114781, 66.41852515084403, 69.59249005998883, 68.58557796478271, 69.25445325034005, 72.0339550290789, 72.89494800567627, 73.20437908172607, 71.45406532287598, 67.4323090144566, 71.67102977207729, 87.24506255558559, 85.52295848301479, 85.34538337162563, 87.69424274989537, 78.9597178867885, 72.01031030927385, 66.3340072631836, 64.44605663844517, 62.94881016867501, 66.08717250823975, 68.7585950578962, 76.00478104182652, 81.0100965499878, 86.65611934661865, 74.31333242143903, 78.35143089294434, 86.37222290039062, 75.41011251722063, 74.72629165649414, 81.13486535208565, 85.76537418365479, 75.019992010934, 73.72818292890275, 66.09694862365723, 69.0645728792463, 81.76623426164899, 76.60657841818673, 74.97985921587262, 68.76478590284074, 64.29859501974923, 62.317503792899, 64.91485159737724, 64.9298597063337, 65.0583666392735, 64.29138278961182, 68.18856484549386, 65.66588238307408, 62.05620983668736, 63.01400511605399, 66.97453389848981, 73.52477441515241, 77.35217571258545, 76.74144295283726, 80.67620781489781, 81.2947781426566, 85.13671507154191, 81.92962115151542, 82.46682807377407, 81.32489163534981, 77.31268215179443, 71.77267496926444, 70.84495149339948, 65.57966218675885, 71.3944011415754, 71.18963078090123, 80.87379373822893, 77.83820915222168, 80.67410251072475, 77.76538508278983, 86.84105260031563, 79.09095546177456, 86.96776689801897, 83.7448171888079, 83.82561779022217, 19.569981745311193, 1.2173940922532762, 10.717532924243383, 0.9163089969328472, 0.31655952068311827, 0.31237741080777987, 0.1764342226088047, 0.1258215763206993, 0.44191552698612213, 0.18326818304402487, 0.3663460505860192, 2.3096483051776886, 52.03831100463867, 90.69084099360875, 95.02778843470982, 90.15526689801897, 111.75871018001011, 58.746414593287874, 24.255433457238333, 43.13438211168562, 76.79051807948521, 88.99203423091343, 84.7535844530378, 59.98739760262625, 4.511249082429068, 0.1360272451170853, 0.20888184862477438, 0.17165882885456085, 0.19721591818545545, 0.21155345812439919, 0.11218175358538117, 0.1539525661085333, 0.24203878800783837, 0.19814724821065152, 0.21315275159265312, 0.1578554588236979, 0.1417565776833466, 0.10040591404374156, 0.15826073421963624, 0.10374178218522243, 0.11883675040943281, 0.14935042948595115, 0.16849904055041925, 0.13155408443084785, 0.11134235826986176], [0.10705149958708457, 0.0696494212107999, 0.13198586340461457, 0.055865168904087374, 0.11567259233977113, 0.0570035572828991, 0.16223456098565034, 0.09089772496372461, 0.08617725183389016, 0.18585338789437497, 0.07128170505166054, 0.08014459375824247, 0.04782491230538913, 0.0584527723757284, 0.08033748769334384, 0.08806971314230136, 0.626055328973702, 20.244412115642003, 90.26677853720528, 80.51580170222691, 59.295211110796245, 37.34587608064924, 39.551133564540315, 88.39380822862897, 114.83382306780133, 74.5619181224278, 107.37981646401542, 108.92905630384172, 103.48633084978376, 72.5497545514788, 18.261962515967234, 0.7072803676128387, 0.07748664995389325, 0.05518452364153095, 0.08558471434350524, 0.04990112428952541, 0.09917484117405755, 0.19259551540017128, 0.20753692436431134, 2.251257598400116, 3.444578788110188, 73.07949910845075, 102.17565046037946, 90.50462232317243, 90.10411425999233, 87.00703116825649, 80.04226112365723, 80.46558012281145, 82.37124865395683, 84.09279687064034, 81.68033368246896, 81.1156257901873, 78.70576817648751, 75.63879857744489, 70.04763875688825, 67.41459805624825, 61.23719787597656, 61.69922528948103, 62.49443967001778, 64.87589999607631, 64.71802997589111, 67.10354110172817, 64.71817588806152, 63.704461506434846, 61.767206464494976, 58.280596937452046, 59.4622597013201, 78.17528711046491, 76.64987959180559, 75.35382516043526, 77.18067332676479, 67.89364855630058, 61.29334626879011, 57.61803061621529, 57.965381486075266, 57.27759667805263, 56.604215485709055, 56.57037428447178, 63.999885014125276, 70.67533206939697, 78.80321666172573, 69.14469950539726, 65.22841685158866, 80.85263647351945, 63.184187344142366, 68.29200962611607, 73.81145014081682, 80.4206600189209, 79.97609342847551, 87.81918525695801, 72.2187145778111, 58.16923815863473, 69.24556650434221, 71.50815010070801, 72.26223114558628, 67.45720441000802, 59.40087236676897, 57.80444383621216, 57.46768549510411, 57.92386252539498, 56.18385294505528, 60.4870217187064, 54.500908919743125, 57.4141183580671, 55.974486351013184, 58.118200165884836, 54.8204357283456, 56.033090932028635, 55.92462607792446, 60.14682401929583, 58.87672110966274, 63.85113797869001, 67.5698902947562, 74.52695478711809, 73.81579276493618, 75.0217638015747, 67.94894926888603, 67.64144284384591, 62.98084136417934, 61.31611551557268, 60.53299100058419, 66.05575970241001, 62.561413356236045, 70.76135076795305, 68.72311060769218, 75.12001132965088, 71.04106439862932, 77.09696143014091, 75.08344296046666, 75.44750077383858, 73.73668752397809, 40.349116802215576, 0.6079450121947697, 0.980349240558488, 0.08981104434600898, 0.01898736909164914, 0.047228663228452206, 0.03547817036243422, 0.1442090068012476, 0.0371464267373085, 0.07701052871665784, 0.10089471710047551, 0.07801055362714188, 1.1363120887960707, 28.624089002609253, 72.34194782802037, 82.63122940063477, 91.06462628500802, 72.50437586648124, 22.409416948046, 30.279332297188894, 42.2912529536656, 61.30276107788086, 65.22056538718087, 76.39365782056535, 25.633763245173864, 0.8792092534048217, 0.06509397458285093, 0.009220782850336815, 0.05743504448660782, 0.08673551652048316, 0.14212924268628868, 0.12101001664996147, 0.1585597510316542, 0.13374754387353147, 0.07465706393122673, 0.08468333485403232, 0.10772928821721248, 0.08595233783125877, 0.06987491875354733, 0.03342630421476705, 0.13678634938384804, 0.11255621670612267, 0.04860985857833709, 0.07468947076371737, 0.10259340916361127, 0.032670714759400914, 0.0304122346985553, 0.11084011343440839, 0.07910658445741449, 0.061420087436480184, 0.049980227901999436, 0.08742970534201179, 0.0691476920619607, 0.05545082149494972, 0.09046160336583853, 0.054590194818696806, 0.04289767937734723, 0.04494013424430575, 0.11784214020839759, 0.15804882773331233, 0.18399849028459617, 0.5789387258035796, 26.515496594565256, 106.26472091674805, 89.48889296395438, 75.58748613085065, 45.83512953349522, 39.93447610310146, 91.02204077584403, 106.03829302106584, 79.1569494519915, 105.91951356615338, 113.03908252716064, 110.84822518484933, 80.45743683406285, 22.670712641307286, 1.289811366370746, 0.09972143505832978, 0.07395342990223851, 0.01747187809087336, 0.01571058777959219, 0.12169349140354566, 0.10548092850617, 0.4196484504001481, 1.1513540702206748, 6.47052036012922, 88.00246483939034, 104.95741735185895, 97.13338443211147, 92.53253746032715, 90.64723409925188, 84.01526887076241, 83.48380810873849, 85.79436901637486, 87.88528347015381, 84.64112091064453, 83.83569267817906, 80.84801592145647, 78.28683349064418, 72.79570688520158, 69.68096147264752, 65.37817137581962, 64.70953232901437, 66.84246948787144, 68.1356543132237, 70.03667449951172, 69.20524610791887, 69.99673625401088, 68.92006424495152, 65.2858715057373, 62.250641277858186, 62.80880396706717, 81.25537490844727, 81.3441242490496, 79.59804889133999, 78.7023149217878, 72.92509623936245, 64.19430950709751, 61.299189703805105, 61.48777770996094, 61.081738880702424, 61.22849178314209, 60.53105245317732, 69.04094900403703, 75.09638745444161, 80.0698802130563, 74.51473290579659, 72.13533619471959, 83.14628546578544, 67.64004625592912, 71.48868124825614, 78.12259197235107, 81.95348821367536, 79.04131058284214, 87.69445119585309, 72.34765924726213, 58.8909649167742, 74.85681356702531, 75.26751463753837, 73.41131033216203, 70.93666076660156, 63.121424266270225, 61.700997080121724, 62.020989418029785, 61.18769890921456, 58.997994967869346, 63.42477566855294, 57.76143101283482, 60.264755793980186, 58.92744295937674, 61.66440091814314, 57.8489852632795, 58.01148278372628, 59.50008569444929, 63.13156863621303, 61.85859612056187, 67.47458880288261, 70.63230882372174, 78.3893402644566, 77.63348742893764, 79.20983913966587, 71.60342379978725, 71.83290890284947, 66.90348856789726, 64.67350591932023, 61.500388690403526, 66.79966163635254, 65.75266538347516, 71.60548046657017, 72.60396439688546, 77.02943188803536, 73.77325589316231, 79.77460956573486, 79.37556757245744, 78.03441933223179, 77.46222128186906, 46.99181004932949, 0.6577461713126728, 0.7579843582851546, 0.5656514359372002, 0.030623944409723793, 0.1752605198749474, 0.009902097318055374, 0.22205348898257526, 0.04151460787813578, 0.057716548309794495, 0.1243863119078534, 0.046588248307151456, 0.7022046542593411, 33.61502347673689, 74.77962602887834, 88.10115010397774, 83.28886250087193, 44.94863319396973, 24.973201479230607, 41.50981337683541, 56.23658282416207, 67.5471418925694, 73.25444085257394, 88.00646005358014, 33.733333928244456, 0.590428712112563, 0.1526493988931179, 0.0566699080435293, 0.06396177105073418, 0.1008182122771229, 0.12216093417789255, 0.08313400870455162, 0.0696780893153378, 0.07166167787675347, 0.05313985675041165, 0.07704269806189196, 0.05046078336558171, 0.045732259417751005, 0.16273282282054424, 0.06933994138879435, 0.11038979688393218, 0.06436462407665593, 0.07930966320314578, 0.03882675425016454, 0.05559559711920364, 0.17733149017606462, 0.1899044183748109, 0.20397735679788248, 0.10726590986762728, 0.10114895738661289, 0.1480487957596779, 0.19359996435897692, 0.16825877130031586, 0.283855354147298, 0.20549595888171876, 0.12067457607814244, 0.14110227993556432, 0.09876824263483286, 0.2525875105389527, 0.2214923540928534, 0.2867673278919288, 0.8297421506472996, 42.34134251730782, 123.16146142142159, 99.89086736951555, 83.5010882786342, 55.95113345554897, 61.42844009399414, 99.86267852783203, 138.0004790169852, 95.85156685965401, 124.62847627912248, 127.17678369794572, 116.77167565482003, 94.79358550480434, 36.06703928538731, 4.2324365462575635, 0.26888676307031084, 0.2709603932287012, 0.20771000507686818, 0.2779611647129059, 0.32757588954908506, 0.2386612578162125, 1.0449157016617912, 5.829326263495854, 5.2084013649395535, 84.98320157187325, 106.8819363457816, 100.29583617619106, 98.89195959908622, 94.98210402897426, 89.90210233415876, 90.89667442866734, 91.0229162488665, 93.71467617579869, 89.68706948416573, 88.57983929770333, 87.67756012507847, 84.03389004298619, 78.7738674708775, 73.34864452907017, 68.95877960750035, 68.64162213461739, 71.15058885301862, 72.30926350184849, 73.56118992396763, 73.89407811846051, 74.18245615277971, 71.69231210436139, 69.55856200626918, 65.87698255266461, 66.53802721840995, 86.59060478210449, 85.16006796700614, 84.59770856584821, 85.8347588947841, 76.49773488725934, 68.3733104978289, 65.86180073874337, 65.24520369938442, 64.41109330313546, 63.36792550768171, 63.92988886151995, 73.0351209640503, 78.14272090366909, 82.89835289546421, 77.02861894880022, 75.13092000143868, 86.48806326729911, 71.41990103040422, 73.26819828578404, 81.2429723739624, 84.40794631413051, 79.44033867972237, 84.6846513748169, 70.28842163085938, 62.13058335440499, 78.28947380610875, 78.47600514548165, 79.72495773860386, 74.2982895714896, 65.94624914441789, 64.72332450321743, 63.6214930670602, 64.77738843645368, 63.427388191223145, 67.5453006199428, 59.544561113630024, 62.531411034720286, 60.924487250191824, 64.09921646118164, 61.4863463810512, 62.7195474079677, 63.02280848366873, 65.89886937822614, 66.12160778045654, 72.54104151044572, 74.42869336264474, 84.07488441467285, 81.43294307163784, 82.87677873883928, 73.1626968383789, 75.55289799826485, 70.90484496525356, 69.23221901484898, 65.97727979932512, 70.78450911385673, 69.18125397818429, 77.39480291094098, 76.27474634987968, 81.95319638933454, 78.6316031047276, 83.6710342679705, 82.05090195792062, 80.47543266841343, 82.20620809282575, 55.68159546170916, 0.9622999919312341, 4.631861993244716, 3.0235207762037004, 0.23376180071915897, 0.34920267335006167, 0.23798625117966107, 0.5074787831732205, 0.15866258979908057, 0.16877110595149653, 0.3607691169849464, 0.29339637075151714, 1.927613113607679, 45.40101650782994, 85.79142298017229, 95.77780478341239, 113.18062428065709, 96.49608176095145, 30.009419100625173, 42.43018218449184, 59.19997910090855, 79.03392464773995, 81.90806089128766, 97.9599838256836, 50.48274482999529, 1.1433251010520118, 0.14662957191467285, 0.1919265884373869, 0.19972425858889306, 0.2330435306898185, 0.30533044465950554, 0.11209688921059881, 0.1974932625889778, 0.22691786581916468, 0.14893036202660628, 0.13322208635509014, 0.1639066341200045, 0.13396078028849193, 0.34971059752362116, 0.06463636378092424, 0.16990238667598792, 0.14130978951496737, 0.17942008881696633, 0.15690006794674055, 0.16737871138112886], [0.20091235983584607, 0.0704195381009153, 0.10980933053152901, 0.09621622493224484, 0.15797079620616777, 0.10925612771617514, 0.1788284605635064, 0.10982779346938644, 0.017292023902492862, 0.11859797393637043, 0.055196652454989295, 0.04290129257632153, 0.03365867192457829, 0.009448516165970691, 0.08619611510740859, 0.027411386437181915, 0.5131489474858556, 60.56737068721226, 79.89372253417969, 80.66481971740723, 44.773423944200786, 82.32916341509137, 79.61484268733433, 31.055730955941335, 45.69168397358486, 83.70958287375313, 105.98595224108014, 93.49418204171317, 77.82629299163818, 11.708967907088143, 0.4073492975107261, 0.0028552823558649315, 0.05193276670096176, 0.14551426390452044, 0.02860064458634172, 0.05130069776039038, 0.09842179622501135, 0.2185451236686536, 0.16227181255817413, 2.0824554562568665, 71.12419959477016, 99.80448736463273, 90.67292853764125, 95.44939122881208, 88.13748918260846, 80.64333588736397, 68.07753263201032, 67.54471697126115, 66.26684597560337, 68.5084182194301, 66.71409457070487, 66.51589025769914, 60.91541985103062, 63.50500651768276, 62.91914830889021, 61.01045731135777, 62.18861470903669, 66.1085729598999, 66.51839855739048, 68.91268525804792, 69.46212100982666, 71.21843801225934, 68.02802671704973, 62.827063832964214, 58.792147636413574, 61.92300592150007, 57.94463069098336, 72.5881850378854, 75.1578929083688, 72.20966802324567, 72.54020772661481, 64.89437525612968, 60.39659786224365, 58.64841720036098, 57.54202427182879, 57.72949709211077, 62.539179120744976, 65.18441390991211, 68.94111728668213, 71.58168288639614, 78.75343976702008, 74.86085741860526, 71.13672024863106, 74.67957891736711, 64.89249229431152, 69.3780130658831, 71.95618384225028, 73.49499443599156, 85.04426234109062, 94.62516811915806, 71.00127206529889, 50.25148098809378, 63.61173779623849, 77.93512957436698, 72.05121435437883, 72.51406165531704, 67.93833936963762, 66.18959590366909, 61.391030992780415, 61.51706436702183, 61.50718402862549, 57.81811441693987, 58.324714524405344, 53.76339932850429, 57.48540687561035, 60.34512560708182, 61.683049883161274, 56.99141774858747, 52.811537810734336, 54.583463941301616, 54.48246145248413, 54.86799962180001, 58.62058271680559, 63.11020292554583, 70.26420715876988, 72.05841268811906, 71.41383525303432, 69.13654926845005, 66.0564684186663, 60.87018707820347, 58.08340358734131, 59.24532304491316, 62.68314579554966, 65.30919660840715, 63.97822747911726, 67.84785297938755, 73.57913712092808, 71.76585183824811, 71.5215323311942, 79.26370157514299, 73.7900218963623, 66.4209292275565, 2.6602732964924405, 0.45924693984644754, 0.23885618735636982, 0.13308513084692614, 0.07088820223829576, 0.1460163119648184, 0.16141647845506668, 0.07863150137875762, 0.2770448981651238, 0.12341554542737347, 0.23461024090647697, 0.22691687515803746, 3.494175898177283, 33.943871293749126, 57.1827711377825, 45.75910234451294, 66.79199082510812, 65.5341236931937, 16.587802750723704, 23.236480133874075, 47.96615941183907, 58.92829758780343, 61.38622978755406, 56.16964735303606, 6.7406498193740845, 0.06854496976094586, 0.15085516231400625, 0.019051052995824387, 0.1467712771679674, 0.06504681639905487, 0.09405168465205602, 0.060741484564329894, 0.1165186305131231, 0.03199578615437661, 0.0639722476314221, 0.02119932709527867, 0.07275529990770987, 0.14026627050978796, 0.15859457344881125, 0.2301629866872515, 0.07272382945354496, 0.05419823906517454, 0.08248490174966198, 0.16042454168200493, 0.08052553010306188, 0.09105469046958856, 0.07834070162581545, 0.05307651889909591, 0.09413733612746, 0.05717394421143191, 0.11773558306906905, 0.057904536436711035, 0.05803870316594839, 0.06333210412412882, 0.06966863053717784, 0.020833525474050214, 0.0544655920405473, 0.0867448328062892, 0.03564439447862761, 0.09611427504569292, 0.4993821233510971, 72.36149311065674, 90.84561211722237, 92.69841875348772, 55.65482752663748, 72.97868074689592, 70.1016401563372, 29.192352635519846, 52.39974587304251, 87.9094979422433, 116.68045970371791, 101.35388006482805, 87.64221463884626, 13.256861533437457, 0.5407319388219288, 0.4546498922365052, 0.022916029174146906, 0.07019649006958519, 0.08764192395444427, 0.1280743668654135, 0.025560975640213916, 0.28017457308513777, 0.5990143514105252, 3.1460620292595456, 83.02939592088971, 102.23548139844621, 94.50391510554722, 99.2273838860648, 92.25688852582658, 83.826826776777, 71.07532596588135, 70.83858694349016, 68.19550609588623, 70.29198605673653, 68.18128313337053, 67.9984690802438, 65.36613709586007, 67.1644629069737, 65.07219355446952, 65.68057782309396, 65.46462086268834, 69.055574962071, 70.00101634434291, 72.26095267704555, 72.47125380379813, 73.78741632189069, 70.48458317347935, 64.41228839329311, 62.10154683249337, 65.55487101418632, 61.77311243329729, 75.43440341949463, 78.57254341670445, 78.04076303754533, 74.72786889757428, 68.33110019138881, 62.911241258893696, 62.07693631308419, 61.301899501255576, 64.71361092158726, 69.37255872998918, 67.66551835196358, 72.19000462123326, 75.22565174102783, 80.99161434173584, 76.29074805123466, 76.49422604697091, 78.1612239565168, 67.5404577255249, 73.20994458879743, 75.94858401162284, 75.03150517599923, 84.50060749053955, 92.00006920950753, 72.63312598637172, 53.33302443368094, 64.99110807691301, 79.69481645311627, 75.70368085588727, 75.62809140341622, 72.4707396371024, 69.84849643707275, 66.94208581107003, 64.72591618129185, 65.96247318812779, 62.08982522147042, 61.62509495871407, 57.0437342098781, 61.418427739824565, 62.79363604954311, 65.83899675096784, 61.11028208051409, 55.86016763959612, 57.24137224469866, 56.80552216938564, 58.13844721657889, 60.89316477094378, 64.6331855228969, 69.99328994750977, 74.5593125479562, 73.20438602992466, 69.87933949061802, 68.16683088030133, 62.232874734061106, 59.8429445539202, 61.44419860839844, 64.0734177998134, 66.69101960318429, 66.23831667218889, 70.11584922245571, 75.5369518824986, 74.31755692618233, 73.85752364567348, 81.72467708587646, 77.72493961879185, 70.14977727617536, 4.018673479557037, 0.4166374648255961, 0.09585302549281291, 0.2216922640800476, 0.10884812460946185, 0.2006586148802723, 0.0749423336237669, 0.1206574769956725, 0.1076096896348255, 0.14590823490704807, 0.12547396283064569, 0.17875116185418197, 2.9744717053004672, 41.82328135626656, 64.2424396787371, 53.14668416976929, 56.39678743907383, 47.61176306860787, 25.905088663101196, 32.3993353843689, 61.268867765154155, 68.16489928109306, 70.20356328146798, 70.08422102246965, 9.293358053479876, 0.13600287213921547, 0.18162076787224837, 0.08319294625627142, 0.13912249117025308, 0.020895726779209714, 0.10130044032952615, 0.11047510909182684, 0.029996655748358796, 0.06225596794060298, 0.026470538262011747, 0.056987231730350425, 0.04090289159544876, 0.0683637194867645, 0.0834756035889898, 0.1662118211388588, 0.058051954954862595, 0.029598986729979515, 0.1560538669249841, 0.12842077256313392, 0.2507610028343541, 0.12784589055393422, 0.18964011541434697, 0.16417536112879003, 0.193920015756573, 0.13556082014526638, 0.17476193234324455, 0.1681923291512898, 0.1527290724750076, 0.13946398427443846, 0.17505940209542, 0.09277146549097129, 0.1417968962341547, 0.1421688012778759, 0.14217465024973663, 0.3303964781974043, 1.8110791210617339, 93.4649440220424, 105.01253046308244, 106.08927890232631, 62.35250881740025, 97.4654596873692, 94.67406954084123, 41.6872912134443, 64.67049040113176, 104.21049295152936, 123.37240873064313, 108.45830890110561, 102.5220251083374, 16.720897231783184, 0.6082229944212096, 1.1370353528431483, 0.09107036462851933, 0.3369186653622559, 0.21895185112953186, 0.36106541965688976, 0.3098247620676245, 0.37886423457946095, 1.090578394276755, 3.4255352956908087, 83.7669541495187, 108.03118228912354, 100.10599749428886, 106.5728874206543, 95.70703043256486, 87.24552113669259, 74.91030774797711, 74.5739871433803, 74.34011772700718, 75.74711404527936, 73.50505542755127, 75.21946089608329, 68.23370729173932, 70.9887444632394, 69.48256955827985, 69.61512729099819, 69.55110658918107, 71.53931277138847, 73.48638561793736, 75.58603395734514, 77.12074511391776, 78.9952231815883, 75.23960372379848, 68.45051888057164, 66.49164799281529, 69.58761937277657, 64.16674600328717, 80.71198408944267, 83.80286938803536, 80.94232382093156, 79.6602908543178, 71.67688710348946, 67.96683393205915, 65.9816780090332, 64.88503687722343, 66.85657433101109, 72.32014438084194, 71.3854866027832, 75.28234209333147, 79.69430923461914, 84.47736576625279, 78.60626997266496, 79.24347536904472, 82.09316784994942, 69.88412679944719, 76.3918651853289, 81.42114503043038, 79.1455683026995, 79.22987079620361, 84.45060130528041, 69.41465091705322, 56.94345433371407, 67.28976672036308, 85.96085480281285, 77.57838821411133, 77.97832652500698, 72.70877797263009, 73.27770342145647, 68.27829388209751, 67.39799880981445, 69.19795049939836, 65.02433436257499, 65.38650226593018, 60.43076910291399, 64.21195098331997, 67.1872946875436, 67.37066459655762, 62.18342440468924, 58.41877923692976, 61.01327133178711, 59.38136877332415, 61.37860066550118, 65.68466336386544, 69.60157135554722, 76.81886672973633, 79.58248492649624, 79.73532445090157, 74.27355398450578, 73.01948056902204, 65.3955557686942, 64.40126855032784, 64.82763086046491, 70.14369760240827, 69.93742643083844, 68.52385711669922, 72.85139669690813, 79.91768687111991, 78.29063415527344, 78.33152430398124, 86.71591554369245, 78.99252033233643, 77.88988985334123, 4.2562940546444485, 1.9009498357772827, 0.38419640702860697, 0.34341612671102795, 0.3993148457791124, 0.5403154811688832, 0.19259114563465118, 0.3566335546118872, 0.6079462064164025, 0.5141928057585443, 0.47173453548124855, 0.33935905726892607, 4.977931788989475, 53.22812400545393, 71.9130494253976, 58.89968490600586, 88.12785897936139, 88.91488143375942, 21.362226145608084, 36.27023935317993, 68.294524874006, 77.26393359048026, 77.3161701474871, 85.09560258047921, 16.779953445707047, 0.23263605684041977, 0.229551762342453, 0.1869008152612618, 0.337759831654174, 0.17524640634655952, 0.1891491681869541, 0.23164466289537294, 0.16268404972340378, 0.11334200096981865, 0.11000867054930755, 0.10496931988745928, 0.13710125748600277, 0.1852551099977323, 0.1966148040124348, 0.32218283893806593, 0.19710872322320938, 0.11733258755079337, 0.3250020705163479, 0.26120322250894135], [0.09976517342563186, 0.10212922335735389, 0.040508801849292855, 0.09154462667980365, 0.09916129761508533, 0.1714748101575034, 0.09408595745584794, 0.1487575527280569, 0.01394707611429372, 0.1565509752503463, 0.07436352968215942, 0.15629216842353344, 0.05340056686795183, 0.08223576404686485, 0.11280926277062722, 0.2622058801352978, 11.37309980392456, 80.42026397160122, 71.63198784419468, 59.06922789982387, 59.655892099652974, 102.61957086835588, 69.41902133396694, 79.2793002809797, 73.8025564466204, 104.87901387895856, 101.51666940961564, 80.88229833330426, 12.840085131781441, 0.2582061876143728, 0.10736506418990237, 0.15105919779411384, 0.058223746450884004, 0.09637611492403916, 0.04403582687622734, 0.07795264066330024, 0.0803188822631325, 0.3245360255241394, 0.6311792454549244, 34.24615267344883, 98.22371659960065, 87.75087056841168, 95.52482087271554, 77.44724791390556, 72.61747169494629, 65.85651315961564, 71.06151294708252, 63.80097198486328, 66.71943773542131, 61.016585622514995, 62.564922196524485, 61.42996174948556, 65.6002288545881, 62.01085894448416, 64.05326107570103, 60.657593045915874, 66.40593501499721, 68.68773732866559, 74.05640888214111, 72.79135036468506, 72.76509312220982, 68.67416054861886, 68.38412884303501, 57.88553973606655, 59.4387400490897, 58.66290419442313, 60.30991908482143, 66.27356488364083, 71.72593443734306, 70.75045599256242, 69.95050988878522, 64.27267129080636, 60.03614616394043, 59.69861657278878, 59.324254580906455, 61.313982418605256, 67.34628336770194, 68.78424780709403, 71.43123354230607, 76.26392105647496, 74.9727303641183, 77.9474070412772, 68.88674068450928, 66.16048295157296, 64.8296319416591, 69.02304349626813, 67.49182033538818, 66.2002683367048, 80.61329882485526, 80.97733579363141, 59.799080576215474, 45.99759578704834, 54.7674765586853, 70.29497378213065, 83.34305150168282, 75.54458100455147, 72.58055591583252, 69.54788957323346, 69.0635653904506, 67.32731478554862, 67.8479780469622, 65.19952624184745, 59.10245418548584, 52.68161691938128, 55.1988137790135, 64.83383560180664, 68.18716130937848, 66.40015411376953, 59.56398827689034, 52.778867380959646, 51.86946630477905, 52.24300146102905, 55.43934999193464, 54.979268074035645, 59.279355321611675, 59.66256931849888, 61.007316725594656, 59.94448552812849, 58.675987652369905, 57.32239171436855, 56.73179136003767, 54.883997849055696, 56.6702789579119, 59.08616065979004, 64.2874014718192, 68.55526297433036, 71.14785126277378, 73.48348821912492, 73.45568152836391, 77.80681719098772, 77.51226220812116, 80.1976089477539, 13.507931215422493, 0.4257475302687713, 0.10115446709096432, 0.07804117591253348, 0.05152778307508145, 0.1958131691707032, 0.12764644197055272, 0.04680271965584584, 0.1987436804920435, 0.10032765860004084, 0.022580091575426713, 0.12190815274204526, 0.012912251687209522, 11.044844320842198, 51.31314836229597, 37.81091206414359, 61.69974640437535, 72.26084150586809, 34.733231816973, 19.575736590794154, 26.75289395877293, 50.132315908159526, 62.63325078146798, 63.40245805467878, 47.00927087238857, 7.624189700399127, 0.16299240317727837, 0.0880451366039259, 0.1209824409868036, 0.105426604992577, 0.056671539920249155, 0.09890232793986797, 0.08074630504207951, 0.07161888267312731, 0.021637141638036286, 0.06597091324095215, 0.04199245259431856, 0.12805990049881594, 0.013244392034331602, 0.18830555916896888, 0.09400850268346922, 0.0827037292931761, 0.37954906640308245, 0.1676989256271294, 0.028317547902198772, 0.05530416972136923, 0.013063698158865529, 0.08999019116163254, 0.037374438252300024, 0.12789698424083845, 0.1834342341337885, 0.09392937192959444, 0.032823049263762574, 0.12065967544913292, 0.07680476297225271, 0.0678007389817919, 0.03859081744615521, 0.046573334107441564, 0.1937115155160427, 0.4105617808444159, 14.839241674968175, 96.23860236576625, 82.91091523851667, 75.34290259225028, 61.61736856188093, 106.33389718191964, 68.68415205819267, 45.11575126647949, 75.55252279554094, 115.41877106257847, 106.34047017778668, 91.9423713684082, 17.755683762686594, 0.4833794449056898, 0.4398633928171226, 0.20278530647712095, 0.045216898500387154, 0.15756752927388462, 0.09368520110313382, 0.18212491939110415, 0.09828033524432353, 0.2932743430137634, 0.6294455613408769, 44.9973782811846, 102.3420945576259, 93.28634752546037, 99.25331456320626, 81.63965892791748, 75.19090379987443, 68.13755117143903, 74.09310231889997, 67.42802892412458, 69.11236953735352, 64.90006583077567, 66.14890030452183, 65.06439072745187, 68.14218561989921, 67.29381057194301, 69.34588459559849, 65.33013153076172, 70.0053242274693, 72.46103995186942, 77.07371970585415, 75.34745366232735, 77.61985506330217, 71.81823430742536, 71.60072789873395, 60.24377223423549, 60.88296481541225, 61.327427182878765, 61.82387597220284, 68.95825849260602, 73.9936944416591, 74.44431291307721, 71.43328326089042, 65.44840376717704, 63.06706156049456, 62.1498715536935, 64.41027341570172, 65.53754915509904, 69.62761320386613, 71.91384152003697, 74.57259750366211, 78.79045282091413, 77.77070045471191, 79.67672334398542, 75.09464345659528, 71.8833806174142, 69.0973127910069, 73.17363330296108, 72.10726547241211, 71.43768147059849, 82.56801468985421, 80.67755576542446, 65.62834126608712, 51.84488705226353, 57.639205251421245, 70.1429055077689, 84.03476551600865, 79.60929107666016, 77.9253534589495, 74.90723664419991, 74.75951099395752, 69.9527541569301, 71.22495542253766, 68.46481132507324, 64.5829986844744, 56.712107113429475, 58.72778647286551, 68.40652983529228, 72.08455181121826, 71.63246032169887, 66.63440568106515, 58.362797600882395, 54.775470461164204, 56.44688047681536, 57.28258548464094, 56.42974621909005, 60.943532262529644, 60.947145325796946, 62.857378823416575, 61.693673678806846, 60.42690590449742, 57.78305728094918, 59.43973364148821, 58.106888498578755, 59.276388440813335, 61.851981435503276, 67.51315825326103, 71.42895453316825, 73.76110349382672, 75.83696814945766, 76.8334857395717, 80.16883645738874, 77.38052436283657, 83.10817459651402, 16.904206344059535, 0.6864559650421143, 0.045500512567481825, 0.20978048683277198, 0.027894386323168874, 0.011536811162451548, 0.02527162286319903, 0.041029041433440785, 0.18956904565649374, 0.02496517270005175, 0.2474876684801919, 0.17228147972907337, 0.17619943592165196, 11.550858174051557, 59.16075651986258, 43.0358601297651, 64.76340171269008, 46.77012082508632, 28.56096635546003, 32.386668818337576, 41.247254848480225, 60.50412123543875, 72.11164283752441, 73.35701710837228, 56.9045444216047, 9.181339195796422, 0.07052251257534538, 0.12312946149281093, 0.11005728079804353, 0.07991300975637776, 0.03377929509484342, 0.08463187475821801, 0.0812053204114948, 0.12603128435356276, 0.08639338559338025, 0.10228538819189582, 0.03656410798430443, 0.036445459350943565, 0.04043877025001815, 0.20193314791790076, 0.07110319605895452, 0.12618019564875535, 0.21012628184897558, 0.2002995612898043, 0.1938118708453008, 0.16623961393322262, 0.08612372220626899, 0.1776893495448998, 0.15805041550525598, 0.1865585214857544, 0.3837414085865021, 0.19250301750642912, 0.1114595141261816, 0.2635070931698595, 0.21711839522634233, 0.18760307186416217, 0.14922681397625379, 0.23389039667589323, 0.3262940011918545, 0.8355466106108257, 25.910878249577113, 113.27657890319824, 95.1448586327689, 82.00498131343296, 75.43730776650565, 115.73112733023507, 74.62726593017578, 108.88745743887765, 96.56941999707902, 125.1483404976981, 115.7058219909668, 103.12325273241315, 23.651615892137798, 0.7754391559532711, 1.0795000344514847, 0.4197334029844829, 0.28448487179619925, 0.35067495863352505, 0.5105097176773208, 0.41473441837089403, 0.39023374021053314, 0.6374131909438542, 2.8702906327588216, 46.98867988586426, 109.08375099727085, 97.63102831159318, 103.81682191576276, 84.44909354618618, 80.01046616690499, 70.75840473175049, 78.01087883540562, 70.19060489109584, 72.29523508889335, 68.7269321169172, 68.35017994471959, 68.90960720607212, 71.66374805995396, 70.15003435952323, 72.95666190556118, 67.89589977264404, 72.59304182870048, 76.61351272038051, 80.77769320351737, 79.06448282514299, 80.69532230922154, 75.88320841108049, 78.0574039731707, 63.03350176130022, 66.28639125823975, 64.70686422075543, 67.41854463304792, 74.3700019291469, 79.98504270826066, 78.5905600956508, 76.98729801177979, 71.90621934618268, 68.58870465414864, 68.01707635607038, 67.10914829799107, 67.28707081930978, 73.44890008653913, 75.38903168269566, 77.24647971561977, 81.77061857495988, 78.56477533067975, 82.4983937399728, 77.42042091914585, 74.88240378243583, 72.17587198529924, 75.43022755214146, 77.07378223964146, 72.62973526545933, 78.02647754124233, 76.14002077920097, 62.897879873003276, 56.985880034310476, 61.19439002445766, 74.45951557159424, 86.92573724474225, 83.6342921938215, 80.13230282919747, 77.60472883496965, 77.24805000850132, 74.27366515568325, 74.74182782854352, 72.15128925868443, 67.43490764072963, 58.85036659240723, 61.96655028206961, 73.65742247445243, 75.8804360798427, 73.98789269583565, 67.13560703822544, 60.24218109675816, 57.25902761731829, 60.070039476667134, 60.021409034729004, 61.930565561567036, 65.50549016680036, 67.56410244532994, 66.08335099901471, 67.21953432900565, 64.65806007385254, 62.86748150416783, 61.38217898777553, 60.26779910496303, 60.67195497240339, 66.68206337520054, 70.61504255022321, 75.46533679962158, 77.55017852783203, 81.40118980407715, 79.35828045436314, 86.7905808857509, 80.12916224343437, 89.70191083635602, 19.379505566188268, 0.8292016567928451, 0.11119677179626056, 0.5199953658240182, 0.34151115321687286, 0.5111477034432548, 0.41701999572770937, 0.33693606300013407, 0.4595523891704423, 0.1765337772667408, 0.24810700810381345, 0.1551023165562323, 0.4836031443306378, 15.035231249673025, 72.73181125095913, 52.599517004830496, 81.42537648337228, 91.0685589654105, 47.946850367954795, 31.213805947984966, 43.82385185786656, 68.61660167149135, 85.88393129621232, 81.73312609536308, 73.37879276275635, 16.837852784565516, 0.20297992389116967, 0.24055409910423414, 0.2012159906859909, 0.19932434361960205, 0.12532813208443777, 0.1747626108782632, 0.17950989971203463, 0.24283628378595623, 0.1487152257135936, 0.17420968626226696, 0.11120194223310266, 0.24616998061537743, 0.09716449797685657, 0.2838327725018774, 0.13768293841608933, 0.24239349897418702, 0.3864454249186175, 0.21881129938576901], [0.11200932426644222, 0.03327921139342444, 0.07505069566624505, 0.03493664513475128, 0.054880495848400254, 0.08400766325316258, 0.2275828029960394, 0.16003298626414367, 0.013856784307530947, 0.10174102668783494, 0.02838304010219872, 0.0579292554674404, 0.06937677226960659, 0.030943161209246943, 0.04723537054711154, 0.37480797937938143, 55.957275663103374, 88.65217004503522, 78.81288160596574, 52.40033994402204, 45.582534721919465, 59.70439747401646, 75.7733018057687, 65.51521069662911, 77.38458905901227, 97.78703621455601, 84.25441891806466, 23.594902958188737, 0.28264387058360235, 0.09999149199575186, 0.20525659886854036, 0.03808611970660942, 0.10697791924966232, 0.025463059644347856, 0.10605543732110943, 0.08269872170473848, 0.25315699140940395, 0.7438513966543334, 3.0924833842686246, 78.24263599940709, 91.41907473972866, 92.91238852909633, 80.13422053200858, 73.87050982883999, 71.17723519461495, 78.20971543448312, 74.00421401432583, 71.31459413255963, 62.85131999424526, 64.7922853742327, 65.66045583997453, 66.67895058223179, 66.9948365347726, 71.44570663997105, 73.62357779911586, 73.24081543513707, 73.31593935830253, 74.79966463361467, 75.32842254638672, 78.13082558768136, 72.52021081107003, 69.81327601841518, 61.6481351852417, 58.98130539485386, 60.152695247105186, 59.80848843710763, 59.72509615761893, 66.36630943843296, 69.6341861997332, 67.44352340698242, 66.29294340951103, 61.340385573250906, 59.65457889011928, 57.71969665799822, 57.86871814727783, 58.58104746682303, 66.71223940168107, 69.50642272404262, 72.15159497942243, 76.58433723449707, 71.95066002437046, 75.57404831477574, 68.63351358686174, 67.48831149509975, 68.8217750276838, 65.67003740583147, 68.34890147617885, 57.50448315484183, 63.55440126146589, 61.27648993900844, 51.81519392558506, 53.33057519367763, 56.35497317995344, 60.523444175720215, 69.44738388061523, 73.81161689758301, 72.18684319087437, 73.54552868434361, 68.53214631761823, 66.94655350276402, 63.762326104300364, 64.33835261208671, 63.17103440420968, 55.752421924046104, 54.421563965933665, 64.24356528690883, 69.54774366106305, 75.77225262778146, 70.33500930241176, 64.7944393157959, 55.78559957231794, 55.73053509848458, 54.29202175140381, 53.021689551217214, 54.12371901103428, 53.95977626528059, 54.86597074781145, 53.16520459311349, 55.208329336983816, 56.39270537240164, 56.127614225660054, 54.56602396283831, 57.278378350394114, 59.047757966177805, 59.095332281930105, 63.2403496333531, 71.63819258553642, 71.58196776253837, 72.95896870749337, 76.83082457951137, 75.23483725956508, 77.89300959450858, 49.17478118624006, 0.3926814060126032, 0.07776187054280724, 0.13059576228260994, 0.14319280561591896, 0.12027634387569767, 0.07200551871210337, 0.04093411099165678, 0.1310451424547604, 0.07088640412049634, 0.05893726673509393, 0.053767749307943244, 0.09673916508576699, 0.3030822410115174, 38.4579039982387, 45.015568665095735, 70.11418165479387, 88.97703307015556, 70.11049910954067, 19.65079276902335, 25.73329618998936, 29.24950156893049, 42.51427623203823, 64.31696605682373, 66.00915813446045, 50.60411248888288, 7.789719241006034, 0.15850903732436045, 0.10632810661835329, 0.09887127817741462, 0.09277508208262068, 0.03300344458382044, 0.0714943375704544, 0.05389233512271728, 0.11488998361996242, 0.06538324084665094, 0.06611630293939795, 0.11934771441987582, 0.031977598023201735, 0.09084323860172715, 0.06209875137678214, 0.09882462889488254, 0.47398385192666737, 0.2567472287586757, 0.1040133929678372, 0.08322868469570364, 0.10887056376252856, 0.042309908595468314, 0.1001753139176539, 0.004030343644054872, 0.13638517233942235, 0.12903481961361, 0.03969740967399307, 0.024026809659387385, 0.0723038094916514, 0.10124544506626469, 0.04536121611350349, 0.03219874954915472, 0.05851329091404166, 0.27699270525148934, 65.29464708055768, 98.7060466493879, 87.2466675894601, 64.09435967036656, 62.44727529798235, 69.55986826760429, 60.544462476457866, 66.31439944675991, 88.61185659681047, 106.97258949279785, 96.2018255506243, 31.01543835231236, 0.2769384224499975, 0.028640182821878364, 0.14081608743539878, 0.11258561762848071, 0.10306069587490388, 0.06454114496175732, 0.17728974670171738, 0.2309571440730776, 0.18251678693507398, 1.2682175593716758, 4.0457271592957635, 90.26510402134487, 95.42129271371024, 95.81408132825578, 81.14807387760708, 77.11537415640694, 74.60591411590576, 82.89652551923479, 77.81894874572754, 76.01871912819999, 66.46418176378522, 69.03564058031354, 69.17803696223667, 70.75427055358887, 72.00798961094448, 76.52599321092877, 76.34297766004289, 76.67783219473702, 76.87657151903424, 78.89933804103306, 78.56786033085415, 82.4555719920567, 76.60058212280273, 73.06211471557617, 61.70521463666643, 59.71015753064837, 62.056661469595774, 61.81861618586949, 61.63385663713728, 67.84410790034703, 71.95202187129429, 71.43640300205776, 68.9379141671317, 64.56029891967773, 62.42426981244768, 61.48435224805559, 61.337752205984934, 63.8770478112357, 70.34386825561523, 73.52321107046944, 74.51102951594761, 76.94384397779191, 76.29059519086564, 75.89205346788678, 72.88114193507603, 73.4190923145839, 71.21215684073312, 72.00809383392334, 71.88536780221122, 63.87380300249372, 68.75515569959367, 68.47744315011161, 58.345517430986675, 58.892187799726216, 60.36763777051653, 61.7593480518886, 71.13239846910749, 77.02410956791469, 74.67340196881975, 76.58332974570138, 73.39255714416504, 68.41884899139404, 67.62130001613072, 69.0130033493042, 67.00867734636579, 60.25470869881766, 57.90333407265799, 68.26374435424805, 72.77229145595005, 77.65501989637102, 73.55528395516532, 68.10385935647147, 60.71750736236572, 59.570818356105256, 56.210732051304404, 55.9425003187997, 56.535073961530415, 55.63159622464861, 58.350415910993306, 55.61868299756731, 57.432301793779644, 58.96468530382429, 59.717599051339285, 58.68563870021275, 59.19250283922468, 61.79388754708426, 62.628901209150044, 65.64037554604667, 72.57760987962995, 74.02726118905204, 75.50943701607841, 79.85360363551548, 76.73888601575578, 81.68778909955705, 58.141101428440635, 0.8000324134315763, 0.05025745356189353, 0.14531505959374563, 0.09721700301659958, 0.12706467961626394, 0.02988872118294239, 0.008464230723412973, 0.1667918057313987, 0.4530512908739703, 0.03324693687526243, 0.13646551088563033, 0.10573793721518346, 0.22323614837867872, 42.55325215203421, 51.25251490729195, 74.46206556047711, 71.02395793369838, 44.475127356392996, 29.80078206743513, 35.80063145501273, 40.62436274119786, 54.59435871669224, 73.34241894313267, 76.78779438563755, 62.966625349862234, 9.254774706704275, 0.12879269117755549, 0.10289866171245064, 0.057253237813711166, 0.08970989513077907, 0.02554808517119714, 0.15520276688039303, 0.05558526303086962, 0.1270193670477186, 0.05525962729007006, 0.08121963750038828, 0.08979188930243254, 0.04953988242362227, 0.07900633769375937, 0.046439445577561855, 0.07795417415244238, 0.23814315561737331, 0.2198739123663732, 0.2199891276125397, 0.19867734690862043, 0.22032802871295384, 0.12384739225464207, 0.16228926447885378, 0.15495394808905466, 0.30257374686854227, 0.3133118620940617, 0.13333803441907677, 0.16102197819522449, 0.12303903991622583, 0.15450011672718184, 0.2552356155855315, 0.11179201664136988, 0.22352601853864534, 1.0517451294830866, 86.21848011016846, 108.23616109575543, 102.82559885297502, 73.52268995557512, 67.8891669682094, 67.48831149509975, 88.92121819087437, 86.23129258837018, 97.06700829097203, 114.77331120627267, 104.82489436013358, 37.66361720221383, 0.5527526480810983, 0.21650559668030056, 0.550075963139534, 0.30081696542246, 0.2532324987862791, 0.17641497935567582, 0.46055271263633457, 0.6017274601118905, 0.3056826857583863, 1.7934577294758387, 4.429060578346252, 96.31121104104179, 100.64759567805699, 101.87614141191754, 89.08025550842285, 83.35673250470842, 78.90026215144566, 87.88899380820138, 79.93435559953961, 78.86501393999372, 68.11208602360317, 72.91543129512242, 72.75354521615165, 75.4660872050694, 73.41020556858608, 79.77510983603341, 79.5652881349836, 80.39379828316825, 81.4438031060355, 80.91244656699044, 80.59404536655971, 87.87418719700405, 80.10157094682965, 76.90193939208984, 67.51217855725969, 64.8396303994315, 66.54836613791329, 67.8983941759382, 64.77416447230748, 73.98589161464146, 77.24017075129917, 76.73538412366594, 73.1234256199428, 70.90863868168422, 65.84593800136021, 64.75953156607491, 64.26035213470459, 65.32997172219413, 75.41454546792167, 78.17735767364502, 78.26579434531075, 80.68092564174107, 78.0740727015904, 79.23017651694161, 75.78386306762695, 75.32508741106305, 74.93755858285087, 72.93444851466587, 76.89132254464286, 69.21194417136056, 68.67161055973598, 68.98446709769112, 57.737442357199534, 65.95945072174072, 61.36735848018101, 65.96851812090192, 75.5989020211356, 79.92371095929826, 76.40076582772392, 81.44777052743095, 75.90920857020787, 74.38948467799595, 72.29933452606201, 73.65786715916225, 69.53552872794015, 62.090422766549246, 60.4568178994315, 71.2293814250401, 73.6410803113665, 82.24678557259696, 76.77226516178676, 70.66999585287911, 61.19369520459856, 63.007307052612305, 60.48830018724714, 60.110464096069336, 58.500573430742534, 59.69304411751883, 61.4931069782802, 59.32035664149693, 60.12433270045689, 61.808152198791504, 63.37665939331055, 61.734244210379465, 61.54364817483084, 64.27499198913574, 66.88861247471401, 70.14700494493756, 76.97157423836845, 78.06090586526054, 78.5047220502581, 85.69585745675224, 80.20302159445626, 85.18716594151088, 60.42371668134417, 1.0395685200180327, 0.1626664213836193, 0.4410726236445563, 0.23488502044762882, 0.3410533863518919, 0.16238770633935928, 0.19854424547936234, 0.26588060866509167, 0.46283411021743504, 0.17271465648497852, 0.21965390417192662, 0.24040137444223675, 0.5202542947871345, 52.030768735068186, 60.81627600533621, 85.11070796421596, 110.80964878627232, 91.78317424229213, 30.47404514040266, 37.52304819652012, 49.51302991594587, 62.23044286455427, 83.90076950618199, 83.97989559173584, 78.04242365700858, 17.766340562275477, 0.3144666201301983, 0.22211685058261665, 0.2809232957661152, 0.2608671576849052, 0.13913344272545405, 0.309515540088926, 0.17528832624001162, 0.16213084012269974, 0.15426826131130966, 0.14966536472950662, 0.22912477382591792, 0.11809553232576166, 0.21941363492182323, 0.15291820732610567, 0.2612769385533673, 0.5154300736529487, 0.30378650607807295], [0.06334713367479188, 0.016639261340190257, 0.02960817070145692, 0.05844841618090868, 0.07319669372269086, 0.1875778439321688, 0.11495227313467435, 0.06365606388343231, 0.05402680380003793, 0.08575860251273427, 0.09201525856873818, 0.12286886333354882, 0.08626672346144915, 0.2874531368059771, 0.40065088123083115, 16.240081889288767, 83.06006526947021, 75.33234827859062, 58.77987016950335, 46.752823284694124, 32.890614713941304, 34.158508096422466, 75.8447709764753, 69.55992385319301, 98.30900573730469, 99.29136984688895, 44.16219091415405, 2.088104775973729, 0.06770017330667802, 0.07662101568920271, 0.4448853390557425, 0.025486197688483765, 0.03173198191715138, 0.04898932928751622, 0.0730984757787415, 0.07977014420820133, 0.29889863835913794, 0.6036511340311596, 11.653346708842687, 87.542966570173, 83.02759633745465, 85.60145228249687, 72.87011514391217, 80.82580947875977, 83.67737102508545, 86.65458379473004, 85.20270906175885, 82.41721098763603, 74.38399560110909, 70.28488499777657, 69.20958873203823, 79.07516915457589, 80.09497710636684, 80.946444102696, 79.35680743626186, 75.47562708173479, 80.37590667179653, 82.54498141152519, 81.07869611467633, 78.71689224243164, 71.02803652627128, 60.762656756809776, 58.34294659750802, 59.72505446842739, 60.57710511343819, 60.79286057608468, 61.22258581433977, 60.52675151824951, 64.40046950748989, 65.99489348275321, 66.39668001447404, 65.22582517351422, 59.54542963845389, 58.730843680245535, 55.87385211672102, 58.66003458840506, 61.07503386906215, 67.12512915475028, 72.2661360331944, 72.63150705610002, 74.54297038487026, 68.55347728729248, 65.6659379686628, 66.62931959969657, 69.1641127722604, 65.34949616023472, 66.6234553200858, 46.49546895708357, 35.41808795928955, 36.102905886513845, 33.84080171585083, 55.08196244921003, 62.57252352578299, 58.40380586896624, 60.6481990814209, 59.205822535923545, 66.08726283482143, 70.15664904458183, 68.08683626992362, 68.03636455535889, 61.3951860155378, 65.8912888935634, 58.20059885297503, 56.621415751320974, 51.9205390385219, 58.9866555077689, 68.6384607042585, 70.09230177743095, 68.62061773027692, 68.20837415967668, 65.58480385371617, 64.95185770307268, 64.38010433741978, 61.211232457842144, 58.55889660971505, 54.36237921033587, 55.50046634674072, 55.4795001574925, 55.49666220801217, 56.62557077407837, 56.52183416911534, 57.61580719266619, 53.98323685782296, 55.38370534351894, 58.540337971278596, 63.18959999084473, 67.79452555520194, 67.71725463867188, 72.62696293422154, 69.57174273899624, 77.90885843549455, 71.37261159079415, 75.9529057911464, 15.630083901541573, 0.179863945714065, 0.0369741297326982, 0.054939986406160254, 0.2810906767845154, 0.11111272166350059, 0.05543276567810348, 0.07610851818961756, 0.08414240673716579, 0.24138487023966654, 0.07957885161574398, 0.1770986576697656, 0.1723138051373618, 1.9765325571809496, 28.738320861543926, 53.899764674050466, 74.47670541490827, 73.42633233751569, 51.02750791822161, 14.997752666473389, 32.10083382470267, 41.71355887821743, 49.800087792532786, 65.22638102940151, 59.18079512459891, 51.245743887765066, 14.16865278993334, 0.3477161388312067, 0.0144936844174351, 0.041212880318718295, 0.03830438067338296, 0.08281133137643337, 0.0677427581644484, 0.07127686709697757, 0.03483642551249691, 0.047151215241423676, 0.07089589682540723, 0.03633988269471696, 0.08649864673082318, 0.051221851991223435, 0.06936368332909686, 0.30454035848379135, 0.3101069783525807, 0.09998105612716504, 0.021919373190030456, 0.0379646890796721, 0.09712466118591172, 0.0570868474564382, 0.04708213359117508, 0.14302489534020424, 0.04008294987891402, 0.062430799273507934, 0.1127529511494296, 0.09852439071983099, 0.09771720546164683, 0.2633204146155289, 0.2478815173464162, 0.6745840992246355, 19.322731835501536, 97.38219942365373, 82.96235970088414, 72.75875636509487, 50.59611511230469, 44.74258436475481, 44.02262592315674, 66.25603457859584, 72.12736661093575, 108.59822477613176, 106.46294607434953, 53.605987889426096, 2.0464310007435933, 0.07388385970677648, 0.1468686062310423, 0.460569757436003, 0.08127112473760333, 0.07335781864821911, 0.18187586989785942, 0.1404761549617563, 0.040908455582601685, 0.2872543531869139, 0.9550408614533288, 13.954303468976702, 94.13078989301408, 87.33383274078369, 91.96595355442592, 76.54523972102574, 84.52397428240094, 88.8370338167463, 93.99236788068498, 92.32670402526855, 88.65102359226772, 78.44946997506278, 73.52084868294853, 72.76464148930141, 83.48958206176758, 83.2529125213623, 84.83462129320417, 81.35160051073346, 81.72289139883858, 83.9974536895752, 85.46000780378068, 82.9862128666469, 81.3229808807373, 74.97767053331647, 62.5183345249721, 59.498056820460725, 63.30870601109096, 61.77509266989571, 63.31273596627371, 64.40197031838554, 62.75628253391811, 67.54072870526994, 69.04386029924665, 67.8252921785627, 68.89814267839704, 62.90752397264753, 62.53275898524693, 59.401928492954795, 62.59661293029785, 64.45907756260463, 70.51077093396867, 72.84179428645542, 75.7570777620588, 77.87654931204659, 71.2287769317627, 70.92337581089565, 71.1867264338902, 72.43060684204102, 69.95702729906354, 69.59434522901262, 53.273989064352854, 43.04860312598092, 45.89690944126674, 41.00938674381801, 59.75001239776611, 64.7836696079799, 59.88153484889439, 64.65841443198067, 62.237022808619905, 66.465578351702, 72.82208919525146, 72.83593000684465, 71.21203872135708, 64.80218655722481, 68.34173093523297, 61.77626691545759, 59.87560108729771, 55.55522509983608, 62.135467938014436, 70.8497735432216, 72.30697059631348, 72.33041381835938, 73.43997859954834, 69.00576332637242, 66.93791689191545, 68.35691274915422, 65.20361873081752, 63.34181417737688, 57.309693881443565, 57.2514853477478, 57.60466923032488, 58.17331327710833, 57.63386903490339, 58.862018721444265, 60.39060156685965, 56.01489012581961, 57.12921789714268, 63.11853381565639, 65.66991928645542, 71.4965466090611, 71.47891902923584, 74.97863633292062, 70.20691926138741, 82.09569699423653, 75.36207267216274, 85.35112953186035, 24.187028442110332, 0.31899890835796085, 0.03895377939833062, 0.10339543755565371, 0.23918144990290913, 0.22284380586019584, 0.042579039332589934, 0.1593087994094406, 0.21155116467603616, 0.15038790952946457, 0.028419379045122435, 0.11508738302758761, 0.2233279813081026, 1.0545304885932376, 34.83850744792393, 60.3891077041626, 84.69241946084159, 55.89126430238996, 29.811614309038433, 24.40075503076826, 42.84773070471627, 51.2210430417742, 60.083109038216726, 71.51072788238525, 70.32951327732631, 61.42440319061279, 17.17132462774004, 0.1876485879932131, 0.019875739368477037, 0.0818770836506571, 0.036366508408848724, 0.14038040009992464, 0.06461583809661013, 0.069318933944617, 0.020995340808959942, 0.036995405198207924, 0.06619078572839499, 0.029659773289625133, 0.018635765815685903, 0.0045532655619483975, 0.045689437072724104, 0.3828907699457237, 0.18402739587639058, 0.29804132293377605, 0.21114774846604892, 0.15584660161818775, 0.1866324275199856, 0.16218835275088037, 0.3172448139105524, 0.17262431633259567, 0.1915923556579011, 0.1665816634361233, 0.15474326296576432, 0.18976766642715248, 0.156985699066094, 0.38637086749076843, 0.42898131960204666, 0.894998166177954, 27.763210671288626, 112.91962214878627, 92.23045757838658, 81.72255093710763, 64.52126393999372, 52.04657588686262, 40.7322404725211, 97.03055109296525, 87.41138853345598, 120.18218503679547, 112.42976719992501, 67.54404994419643, 3.054583349398204, 0.12556682713329792, 0.4853516476494925, 0.7887303541813577, 0.2382770170058523, 0.19204515564654553, 0.4279181637934276, 0.2455734669097832, 0.31242325263363974, 0.5535567392195974, 1.2863304274422782, 18.840966326849802, 99.54609775543213, 91.91202858516148, 94.15826307024274, 79.78566414969308, 87.4572605405535, 92.21225329807827, 95.94308158329555, 94.65269688197544, 91.24766268048967, 81.3080700465611, 76.61118507385254, 76.12206663404191, 85.11111790793282, 86.00250230516706, 89.70951216561454, 85.77700546809605, 82.10181140899658, 86.37851102011544, 90.81647137233189, 87.53999968937465, 86.14208466666085, 77.98847784314836, 67.37317984444755, 64.88655158451625, 66.88697964804513, 67.19625786372593, 68.54327733176095, 67.22335583823067, 67.33000373840332, 72.20285878862653, 74.68924386160714, 75.03404821668352, 73.91824395315987, 68.37972368512834, 67.10229042598179, 63.15875693729946, 64.4456536429269, 68.15727710723877, 74.92564937046596, 78.87737478528703, 79.04417324066162, 81.00827612195695, 73.91065652029855, 72.57220418112618, 73.1813735961914, 76.01289653778076, 73.84976945604596, 77.51106016976493, 59.185380935668945, 47.11148582186018, 50.51508869443621, 43.272731167929514, 66.34604154314313, 69.70755222865513, 63.04344463348389, 64.65159824916294, 65.67871570587158, 69.38833808898926, 76.24769006456647, 76.1613586970738, 75.5046775000436, 66.67744282313755, 72.16315678187779, 66.19828810010637, 64.25892775399345, 57.24505826405117, 68.09179728371757, 75.29960836683, 77.89608764648438, 75.82297447749546, 74.67211655208042, 72.24925191061837, 70.19896357400077, 73.09436130523682, 67.87738977159772, 67.18778106144497, 60.80686814444405, 62.01336029597691, 61.794339179992676, 61.87537602015904, 62.39203017098563, 62.44651794433594, 62.29665919712612, 59.46182196480887, 60.43713365282331, 64.40119212014335, 69.7246378489903, 75.11571039472307, 75.40840326036725, 80.79160349709647, 75.22524179731096, 88.78873688834054, 78.22352845328194, 88.63310418810163, 23.998146874564036, 0.43706231883593966, 0.15416692889162473, 0.30792453831859995, 0.8369231138910566, 0.4363267868757248, 0.2075186310602086, 0.35286942230803625, 0.4256652375417096, 0.38181445055774277, 0.36263544112443924, 0.21857406997254916, 0.2777063069599015, 3.158050060272217, 47.98220975058419, 71.32271657671247, 89.54199109758649, 97.68137495858329, 67.46155398232597, 22.760028260094778, 46.908584526606965, 61.78458390917097, 69.38015311104911, 83.23725128173828, 78.72003282819475, 75.13145501273019, 25.756230456488474, 0.5407071315816471, 0.08070924345936094, 0.1467165465333632, 0.13143679286752427, 0.21429410177682126, 0.11130417710436241, 0.20588264241814613, 0.0839436977569546, 0.07429831568151712, 0.13322028145194054, 0.10879321755575282, 0.2555264356945242, 0.09826888157320873, 0.13767639733850956, 0.6334193338240895, 0.3260094778878348], [0.13566543667444161, 0.04539656100262489, 0.06713042102221932, 0.014039845422043331, 0.12082709717963423, 0.04892110937674131, 0.05552453753937568, 0.06523956105645214, 0.08830297991101231, 0.07975936907210521, 0.06167319456913641, 0.07141807023435831, 0.1203586637441601, 0.14181126760584967, 0.19547633081674576, 27.69516522543771, 78.1348624910627, 74.90567329951695, 58.814298493521555, 37.947273935590474, 29.20671456200736, 37.99370527267456, 57.379967961992534, 83.47851358141217, 94.67421545301164, 64.57101999010358, 9.736566271100726, 0.15698773467114993, 0.026716880400532057, 0.09012177945779902, 0.053297270089387894, 0.01777814674590315, 0.1420575486762183, 0.042318017088941166, 0.13638822574700626, 0.07318595251334564, 0.23847031806196484, 1.078829858984266, 20.108491454805645, 84.5310892377581, 84.57323006221226, 83.2557682309832, 82.79122556958879, 93.84348882947648, 85.48882893153599, 92.12666538783482, 92.38421426500592, 84.86333124978202, 78.30671923501151, 79.58868271963937, 78.33299037388393, 81.2117680140904, 80.37150151388985, 83.36616121019635, 82.00723252977643, 80.85258783612932, 83.18545940944126, 80.90781211853027, 80.07655048370361, 75.19141101837158, 59.98012978690011, 58.604824202401296, 58.71879550388881, 57.84309319087437, 56.25710432870047, 59.38689953940255, 60.95716462816511, 58.01258059910366, 55.31063461303711, 57.156413146427695, 58.424983978271484, 60.099075998578755, 57.58968891416277, 54.37881170000349, 56.80345508030483, 55.78709690911429, 60.54007816314697, 61.77031230926514, 68.24382386888776, 70.72315652029855, 69.79318182809013, 66.63514219011579, 71.3807270867484, 67.86097117832729, 68.26837185450962, 65.1819542476109, 69.38621194022042, 44.73003591809954, 21.632398162569316, 20.123127835137502, 23.55423515183585, 45.50120953151158, 57.924039704459055, 54.84558820724487, 61.23644747052874, 56.964253766196116, 60.142398016793386, 69.09509631565639, 71.54217542920793, 66.57471370697021, 63.815535409109934, 60.4761825289045, 58.6809903553554, 54.06677852358137, 56.32197618484497, 53.81493411745344, 67.07176004137311, 70.63601221357072, 71.4493544442313, 72.58154256003243, 67.82991967882428, 70.76836844852993, 70.40952178410122, 68.4931947163173, 67.56680529458183, 60.50426714760916, 56.4173332623073, 52.81477219717843, 52.50106797899519, 57.328679834093364, 55.331579957689556, 53.61162635258266, 56.56015001024519, 60.29835033416748, 59.686241831098286, 59.200875418526785, 62.07076631273542, 66.51197842189244, 69.84597424098423, 73.50966208321708, 70.29261139460972, 72.69357531411308, 67.4200940813337, 65.53711836678642, 7.702970113073077, 0.16143226117960044, 0.1266958551215274, 0.22136174967246397, 0.13133870384522847, 0.14119186012872628, 0.03871771367266774, 0.6603481088365827, 0.3488829747906753, 0.1919182695980583, 0.1375429973538433, 0.11215598961072308, 0.11535207953836236, 6.394840146814074, 35.67979185921805, 68.24519266401018, 82.39776992797852, 92.82910047258649, 40.51450824737549, 14.333096674510411, 36.169535636901855, 48.717777320316856, 55.272360461098806, 65.07249927520752, 58.67892674037388, 62.68472303662981, 17.17618315560477, 0.4976448565721512, 0.03898284105317933, 0.01519210051212992, 0.08872868599636213, 0.02693839494272002, 0.04038189883743014, 0.07779901354972805, 0.03823336859100631, 0.07718875951000623, 0.021626067946531942, 0.02863678675411003, 0.019591821656961526, 0.19133905853543962, 0.2808582921113287, 0.14816824506436074, 0.08246409786599022, 0.022545091042827283, 0.06483902862029416, 0.07842390358980213, 0.0907938073256186, 0.07995620529566493, 0.09028438358966794, 0.04901525950325387, 0.08557345744754587, 0.10558803525886365, 0.06653261810008969, 0.0767086756282619, 0.1662230576787676, 0.13285020845276968, 0.3058590777218342, 35.87952477591378, 87.47488812037876, 83.5384417942592, 69.02861595153809, 59.09567969185965, 34.542041710444856, 27.148022379193986, 60.21980789729527, 94.09533323560441, 103.78237274714878, 75.51246643066406, 13.21548066820417, 0.1509165968745947, 0.05542004653917892, 0.12979746583317006, 0.20871685604963983, 0.24492728444082396, 0.17154753554080213, 0.10935080370732717, 0.17520226085824625, 0.03999837388151458, 0.3283727067921843, 1.12872856429645, 26.2865378175463, 88.40290342058454, 89.81825147356305, 87.14468193054199, 87.9610674721854, 96.81089074271065, 90.38956015450614, 96.3770730154855, 93.7781479699271, 90.22007969447544, 81.46819823128837, 81.92784241267613, 83.75428758348737, 84.4023391178676, 83.79601846422467, 86.28515502384731, 85.6388474873134, 83.8797720500401, 85.81927136012486, 84.52678830283028, 83.79643535614014, 76.84774344308036, 61.59906005859375, 61.21015548706055, 61.22022342681885, 62.14042200360979, 59.75258323124477, 63.96028028215681, 63.96053041730608, 60.82954011644636, 57.615633487701416, 58.37319210597447, 61.813384192330496, 61.3789758682251, 60.2869552884783, 60.252520016261506, 60.551243918282644, 61.72195284707205, 63.91695826394217, 65.50710214887346, 71.68914372580392, 76.01111779894147, 71.54453086853027, 70.81176689692906, 73.66814354487828, 71.43430464608329, 73.1422552381243, 68.55879960741315, 73.27442387172154, 52.18878814152309, 29.88130474090576, 29.107313632965088, 31.3046293258667, 51.393587657383506, 63.22038745880127, 59.60188375200544, 59.919346945626394, 59.866575377328054, 65.22225379943848, 71.70627103533063, 72.1220234462193, 69.18775749206543, 67.4348590033395, 64.04771641322544, 62.375257219587056, 57.53815065111433, 58.10692323957171, 56.78176280430385, 67.96393653324672, 73.75233486720494, 75.10843563079834, 76.6066062109811, 70.63819394792829, 75.14958981105259, 73.28586060660226, 73.76878125326974, 72.11865356990269, 65.37826865059989, 59.30057512010847, 56.175695759909495, 55.18994092941284, 59.66458429609026, 57.460129329136436, 56.449166434151785, 58.716856956481934, 63.37064920152937, 63.79000077928816, 63.013421467372346, 65.13808332170758, 69.46021720341274, 71.47102587563651, 77.46554252079555, 74.46895817347935, 77.5604201725551, 73.3915079661778, 75.74434866224016, 10.963140453611102, 0.10070560260542802, 0.07960003547902618, 0.16789853705891541, 0.20240367124123232, 0.2863070640180792, 0.14982226916721889, 0.33610971591302324, 0.12432523018547467, 0.2781916766294411, 0.5709654507892472, 0.0962562584983451, 0.11271603205906493, 5.978864090783255, 43.39057261603219, 72.63955307006836, 87.8082696369716, 55.70786312648228, 24.02425994191851, 25.384203059332712, 48.16606255940029, 55.96127782549177, 64.74919959477016, 75.22973033360073, 69.0591949735369, 74.15478842599052, 20.692365952900477, 0.4147660923855645, 0.06710372745458569, 0.10145355854183435, 0.13867891925786222, 0.0486142690559583, 0.08871234687311308, 0.029130234383046627, 0.020020582846232822, 0.04492204450070858, 0.011766217066906393, 0.02876206806727818, 0.053867836615868976, 0.14334711804986, 0.14544102283460753, 0.060159287947629175, 0.2422310034079211, 0.10824874070073877, 0.14073618315160275, 0.21244195901921817, 0.19568793874766144, 0.2512140470956053, 0.19656704871782235, 0.17994675412774086, 0.2442170482661043, 0.1783522375460182, 0.1090752234948533, 0.1976005525461265, 0.1867265538977725, 0.31895515641995836, 0.3349300149296011, 50.79039021900722, 98.4708640234811, 94.453366960798, 78.08686433519635, 59.879908970424104, 47.361353465488975, 51.53499739510672, 76.37858717782157, 107.12036378043038, 108.39333629608154, 86.22507395063127, 16.869757175445557, 0.2701685700033392, 0.2947409286030701, 0.3360674838934626, 0.40422950206058367, 0.5187928932053703, 0.7624628522566387, 0.29448151109474047, 0.4642828639064516, 0.36145446449518204, 0.5027314807687486, 2.162073561123439, 29.833671365465435, 95.34862150464738, 93.52292673928397, 89.86985574449811, 91.68300206320626, 102.21606118338448, 92.59262548174176, 99.21714224134172, 97.5261869430542, 92.61131613595145, 85.65728800637382, 85.74502985818046, 87.38339424133301, 88.19268567221505, 88.71311269487653, 89.04975291660854, 87.82689080919538, 86.95872729165214, 90.17333916255406, 87.5190508706229, 87.71779714311872, 82.43380328587124, 66.33141558510917, 64.64414283207485, 65.6695579801287, 66.75683988843645, 64.13373511178153, 67.39395495823452, 66.11063657488141, 64.74312686920166, 63.49166597638811, 64.53456279209682, 67.38991110665458, 66.93110070909772, 65.86786651611328, 61.90617043631417, 65.60707977839878, 65.20985126495361, 68.3135907309396, 69.95235810961042, 77.87545149666923, 79.98743983677456, 75.1022378376552, 72.72876793997628, 74.06262057168144, 72.16403225490025, 76.40428856440953, 74.87101568494523, 80.40945257459367, 56.85649068014962, 30.950997284480504, 31.393413407461985, 33.774682658059255, 57.44441597802298, 67.81336906978062, 60.636533055986675, 61.77426583426339, 61.889341899326865, 69.44354847499302, 73.94159684862409, 78.22352150508335, 73.0936803817749, 71.20214448656354, 66.3372312273298, 64.31279018947056, 60.88206154959542, 62.62152222224644, 59.416832378932405, 74.3006728036063, 78.9631711414882, 77.4482901436942, 79.41832678658622, 74.15054307665143, 78.05846009935651, 76.29386084420341, 75.94233758108956, 74.77492904663086, 68.03300162724086, 63.976705823625835, 57.620681353977744, 58.02702590397426, 63.084612710135325, 62.09509890420096, 60.120254107883994, 62.121474266052246, 65.8475569316319, 66.44324684143066, 64.71010208129883, 69.25597490583147, 73.43737302507672, 78.27422251020158, 82.1021866117205, 78.61175904955182, 81.99975626809257, 76.80862508501325, 81.15626580374581, 9.768989171300616, 0.27118406551224844, 0.5044976802808898, 0.4418883313025747, 0.5304698837654931, 0.25892662895577295, 0.3876445862863745, 1.1662245179925645, 0.9071044251322746, 0.7539986978684152, 0.4952960940343993, 0.23287739817585262, 0.43558560950415476, 10.243563294410706, 55.38417434692383, 83.87412316458565, 100.07580062321254, 127.03180258614677, 57.39468772070748, 21.62173788888114, 50.418477467128206, 63.97156415666853, 74.9706598009382, 84.69867978777204, 77.55664035252163, 86.08283737727574, 27.541445016860962, 0.9070576333573886, 0.12231224748705115, 0.16364075695829733, 0.2081332616508007, 0.09473065393311636, 0.18706606567970344, 0.10525232327303716, 0.14767143529440674, 0.1736327822187117, 0.10216371329235178, 0.12036079434411866, 0.15712513801242622, 0.31206387334636276, 0.33410551345774103, 0.205928701375212], [0.14723113392080578, 0.10769511040832315, 0.03941568871960044, 0.08361488647226777, 0.051879518665373325, 0.12335409729608468, 0.05832744695778404, 0.057361552358738015, 0.0549471924480583, 0.05097766759406243, 0.022819706039237123, 0.018603774585894177, 0.030581681856087277, 0.010764423724529999, 0.5062778304730142, 59.91016837528774, 81.49471950531006, 64.56068107060024, 56.49218620572771, 25.46891028540475, 28.33586209160941, 57.002566133226665, 70.70747443607875, 100.22896671295166, 79.76488903590611, 45.74326392582485, 0.45558979894433704, 0.03129726827942899, 0.08480104032371726, 0.054598795250058174, 0.10774585804236786, 0.06568080559372902, 0.3326366479907717, 0.06911293071295534, 0.1440648181097848, 0.03390398268987026, 0.3236327868487154, 0.5208491257258824, 33.48007556370327, 83.21542698996407, 83.1790531703404, 88.68430546351841, 90.45865304129464, 88.84135559626988, 91.78024210248674, 84.50290039607457, 84.44563334328788, 86.27119609287807, 83.10991164616176, 79.68908418927873, 80.99742303575788, 83.19110134669712, 84.01391397203717, 82.83319268907819, 82.24135902949742, 79.96551132202148, 80.80961322784424, 80.73769242422921, 72.7595762525286, 59.97087478637695, 57.10751519884382, 56.207768644605366, 55.83383396693638, 57.42793485096523, 57.84948900767735, 54.18480409894671, 54.20391164507185, 54.88810770852225, 50.8863969530378, 52.3582547051566, 51.529779297964915, 53.89752735410418, 56.85302700315203, 59.37681770324707, 61.12423406328474, 62.38936901092529, 62.03411456516811, 63.45660536629813, 65.35507556370327, 70.37066050938198, 68.87799290248326, 68.30302946908134, 71.47103977203369, 66.42969785417829, 66.831894329616, 65.12220668792725, 64.96579578944615, 47.885563782283235, 30.761790888650076, 23.590822628566197, 30.17104114804949, 43.49382284709385, 51.8414546421596, 60.52258259909493, 51.40075472423008, 51.298755168914795, 55.51160430908203, 67.96609047480992, 66.52091380528041, 69.00964042118618, 63.0534222466605, 59.51069559369768, 57.36121129989624, 58.237702233450754, 53.595756667000906, 53.24486916405814, 55.809320722307476, 63.5186527797154, 70.46357182094029, 70.1025642667498, 65.88303443363735, 68.67694677625383, 69.14733982086182, 69.23768029894147, 68.90738378252301, 65.51650306156704, 58.71983078547886, 56.39954587391445, 52.016187940325054, 55.684826374053955, 51.09820236478533, 54.67091049466814, 64.37395518166679, 67.01556301116943, 66.35104424612862, 62.25688076019287, 56.988280636923655, 60.05144609723772, 63.71163899557931, 64.91205147334507, 68.54820360456193, 67.71166133880615, 67.84512233734131, 71.88194234030587, 53.8427095413208, 2.0638985548700606, 0.08111042050378663, 0.1227250410509961, 0.22521926196558134, 0.06977950994457517, 0.17480185734374182, 0.10618125806961741, 0.12394523700433117, 0.09724616645170109, 0.5103322129164423, 0.10590619354375772, 0.033911161590367556, 0.1693055879856859, 16.04631052698408, 48.209954329899375, 75.54854147774833, 85.96128559112549, 85.21651513235909, 28.64484327180045, 13.802405425480433, 21.945885249546595, 33.8844815662929, 53.12866054262434, 62.93097414289202, 56.01754433768136, 62.80965164729527, 18.969072001320974, 0.05288927376802478, 0.08657061215490103, 0.08354720260415759, 0.12618706242314406, 0.06456711249692099, 0.09215704524623496, 0.07397104467132262, 0.012330496966439699, 0.09795657904552561, 0.043132394818323, 0.06726982604180064, 0.07610116287001542, 0.14714395574160985, 0.18250268697738647, 0.09026958474091121, 0.0684759220374482, 0.03784320756260838, 0.030072807733501707, 0.09531579539179802, 0.11873577082795755, 0.10174675352339234, 0.05543569694938404, 0.04994375664474709, 0.028188460007576004, 0.03030643073309745, 0.025249857156138335, 0.02785405420166041, 0.07480773263211761, 0.3597540557384491, 67.71140425545829, 84.46302468436105, 77.14835030691964, 63.98114572252546, 38.68614884785244, 31.06261314664568, 55.79573351996285, 80.00824969155448, 108.04860837118966, 92.58863026755196, 55.88519852502005, 0.5364596652133125, 0.11446517998618738, 0.11705574526318482, 0.08706639055162668, 0.2593934067658016, 0.09523119564567294, 0.5890835300087929, 0.03221519384533167, 0.18721646975193704, 0.05943340475537947, 0.3975199849477836, 0.5496510916522571, 38.811438764844624, 88.28378350394112, 87.7454023361206, 92.36077799115861, 92.513429914202, 92.58802577427456, 94.01196180071149, 86.97698715754917, 86.11301340375627, 88.53373105185372, 89.2854288646153, 83.98036806924003, 83.95490986960274, 87.21763801574707, 86.98156602042062, 84.99044854300362, 83.60255977085659, 82.4249929700579, 84.27563871656145, 82.30455289568219, 75.2544172831944, 62.50807203565325, 59.657976559230256, 58.041783877781455, 58.85302775246756, 61.127214840480256, 59.838011332920615, 57.877879347120015, 57.2215907233102, 58.5983693259103, 52.90462630135672, 55.57678188596453, 55.30269282204764, 57.2946058682033, 61.60279818943569, 60.46956089564732, 63.60025242396763, 64.89038699013847, 64.9686028616769, 67.42370019640241, 68.4837451662336, 73.88409355708531, 72.12296840122768, 72.97813183920724, 72.79489394596645, 70.01102175031389, 68.91766711643764, 67.3347076688494, 66.11206790379116, 52.62037897109985, 35.99486487252371, 29.987407207489014, 35.66369635718209, 50.18430927821568, 56.34598568507603, 62.9579678944179, 55.471054622105186, 53.75902196339199, 59.79489081246512, 68.82001713344029, 71.74907888684953, 69.93060329982212, 65.81218365260533, 63.18322154453823, 60.99231556483677, 61.794790812901084, 56.91373688834054, 55.43078981127058, 58.9538391658238, 66.26271179744175, 71.65240165165493, 71.08649172101701, 66.57221930367606, 72.44194630214146, 72.67183440072196, 72.79891000475202, 72.20538098471505, 68.4459400177002, 63.5679224559239, 59.73248209272112, 55.264505522591726, 57.170194898332866, 53.43206058229719, 57.62703548158918, 68.75430107116699, 69.3188977922712, 71.17176001412528, 66.85941614423479, 60.596872738429475, 61.579264640808105, 65.83820465632847, 68.74065480913434, 71.07613195691789, 70.19737243652344, 74.11348138536725, 77.95142310006278, 64.870452608381, 3.5284535331385474, 0.13369474027838024, 0.13711657880672387, 0.4351220615208149, 0.09750909198607717, 0.39751390527401653, 0.3463475065571921, 0.06477557881070034, 0.11681923509708472, 0.706390346799578, 0.441902824810573, 0.07089372551334755, 0.11042466001319033, 17.479188885007584, 57.184970242636545, 83.0200297491891, 89.84974765777588, 60.10594081878662, 24.599900824683054, 24.986321415219987, 38.079150744846885, 48.91720451627459, 63.240259306771414, 70.48809201376778, 66.11521543775285, 77.18956702096122, 21.96251576287406, 0.036002630434398136, 0.032997012071843655, 0.06947523448616266, 0.06973949673452548, 0.05870459707719939, 0.02746580833835261, 0.02533541533297726, 0.05617411268342819, 0.09627363578017269, 0.021809369092807174, 0.017838015586936047, 0.0567342738753983, 0.06914581930530922, 0.09131449474287884, 0.18468066225094454, 0.14899347935404095, 0.09656656613307339, 0.18224831776959555, 0.14753177921686852, 0.23984559997916222, 0.17249968302037033, 0.18802514778716223, 0.14436034725180694, 0.18239926466984407, 0.15895909603152955, 0.10662120660500866, 0.12260799376027924, 0.20274855702051095, 1.567412636109761, 88.82261630467006, 97.90265423910958, 87.9305579321725, 72.8389733178275, 40.277685846601216, 40.919786248888286, 82.94735159192766, 93.79336452484131, 120.70828873770577, 99.92175211225236, 68.62714208875383, 1.062898725271225, 0.2339788233595235, 0.2715634751532759, 0.32629842524017605, 0.6275278042469705, 0.2435968401176589, 0.7511294175471578, 0.4183823583381516, 0.5640933024031776, 0.14812784508935042, 0.9645897490637643, 1.2712730297020503, 40.313965865543906, 96.25514602661133, 91.72276660374233, 96.55405752999442, 96.51696804591587, 96.15764195578438, 95.61935111454555, 88.27622386387416, 89.12142358507428, 92.60292271205357, 92.72846276419503, 88.96820190974644, 88.7564138684954, 88.59611197880336, 88.33321993691581, 89.2078035899571, 87.78995418548584, 84.13515308925084, 88.14787673950195, 86.93782016209194, 82.25501918792725, 66.66950798034668, 62.54086058480399, 61.90205710274832, 63.72519493103027, 63.81177643367222, 63.47849914005825, 59.57091563088553, 60.74725260053362, 62.256832122802734, 58.08261844090053, 60.076369285583496, 58.258487769535606, 61.52989074162075, 65.69389751979283, 66.15173516954694, 69.43393911634172, 69.53866236550468, 70.04469272068569, 71.78793321337018, 71.24709238324846, 76.93760449545724, 76.6007627759661, 75.26669475010463, 76.8844438280378, 74.3872265134539, 73.9092321395874, 71.72176551818848, 71.6925413949149, 54.43447719301496, 36.19252722603934, 29.864059312003, 37.0775158064706, 56.434193066188264, 63.901859828404014, 67.08678204672677, 56.94654975618635, 56.79015275410244, 65.7029093333653, 74.48680809565953, 73.97077928270612, 75.08984225136894, 70.69473838806152, 65.94174671173096, 64.48367418561662, 63.08042294638497, 61.01894801003592, 58.27033792223249, 62.30548340933663, 70.01395389011928, 75.72667939322335, 72.72964341299874, 69.703035899571, 74.52263300759452, 75.25393090929303, 75.8769758769444, 76.45585114615304, 71.45202950068882, 66.02339499337333, 63.87421294621059, 58.19595398221697, 63.05526351928711, 56.03217029571533, 60.76278182438442, 70.7318000793457, 74.02617727007184, 73.1789973122733, 69.43775367736816, 62.58105591365269, 66.87245791299003, 70.32114069802421, 72.66120365687779, 74.75115925925118, 75.2303626196725, 76.91616930280412, 83.24920218331474, 65.99565083639962, 3.1219747960567474, 0.47903459519147873, 0.5199071019887924, 0.5244714713522366, 0.21308455882327898, 0.2851790674030781, 0.8166299228157315, 0.22318356191473349, 0.6866331983889852, 1.5934044356857027, 0.3673830149429185, 0.16393818599837168, 0.3582044446042606, 25.500832046781266, 66.06561919621059, 88.27602236611503, 104.27639661516461, 115.66088799067906, 39.683114596775596, 24.807094369615825, 37.269654342106406, 54.40349864959717, 72.36229910169328, 81.54265512738908, 73.95641040802002, 88.76453631264823, 29.169062273842947, 0.21650957289550984, 0.19293852842279843, 0.10906619897910527, 0.15337231010198593, 0.13033078078712734, 0.11056086913283382, 0.11550393567553588, 0.12443071523947374, 0.2009463951523815, 0.14487451394753798, 0.12055181552256856, 0.19879879110625812, 0.23413176515272685, 0.22378205694258213], [0.04322399704584053, 0.08533996676227876, 0.05213961810139673, 0.1038754807252969, 0.04074556307334985, 0.025870935525745153, 0.0065593912399240905, 0.03324004974482315, 0.07661302254668304, 0.09398389900369303, 0.05336350867790835, 0.01882283792032727, 0.16357894241809845, 0.3742392041853496, 14.931039537702288, 78.19092750549316, 72.58177185058594, 68.45723778860909, 47.74895524978638, 41.774397305079866, 26.893667936325073, 33.983041763305664, 81.55282729012626, 89.3575998033796, 59.83200808933803, 11.840855138642446, 0.37835609327469555, 0.03511282675234335, 0.1612917637186391, 0.025276820441441875, 0.1977360559893506, 0.15894886372344835, 0.5858083228979791, 0.20101705778922352, 0.24411510516490253, 0.18054401422185556, 0.0873002272897533, 1.8756258232252938, 41.9928104536874, 80.92143753596714, 91.385758127485, 90.26194259098598, 95.23759623936245, 92.574921471732, 91.93702125549316, 90.20489093235561, 87.20173358917236, 80.24224417550224, 84.06424672263009, 81.61952999659947, 85.92168085915702, 83.32657037462506, 78.41811275482178, 80.46321078709194, 80.52206897735596, 78.75179999215263, 75.77877698625836, 69.24968678610665, 58.36083126068115, 53.59154953275408, 55.88868999481201, 55.83331285204206, 61.740476744515554, 65.95055702754429, 68.96435901096889, 67.97000925881522, 65.15648215157645, 57.77617161614554, 54.48341335569109, 53.61302988869803, 49.879894801548545, 53.6299591745649, 59.15225887298584, 59.53108160836356, 60.666917528424946, 59.163230078560964, 61.90932491847447, 63.713327407836914, 66.12331703730992, 72.77125617436, 66.81918607439313, 67.78008025033134, 67.26085526602608, 64.97173649924142, 61.39089897700718, 58.8620673588344, 53.86540583201817, 53.95912313461304, 45.229871954236714, 40.14929355893816, 42.89827537536621, 50.0042849268232, 43.75787871224539, 53.67089796066284, 56.55834347861153, 54.540048122406006, 52.8289361000061, 61.38363116128104, 67.42108767373222, 65.09054374694824, 60.93456908634731, 57.611780711582725, 59.02426610674177, 57.14208943503243, 54.24288061686924, 52.66314860752651, 53.16103914805821, 58.94411168779646, 65.43361105237688, 66.515383039202, 62.8294540132795, 66.47447899409703, 68.99239499228341, 69.94410364968437, 66.82376493726457, 61.95631558554513, 56.893121583121165, 54.724901471819194, 51.9053989137922, 50.26615905761719, 53.0147066116333, 63.30334894997733, 68.10904966081891, 73.85650226048061, 71.8319569996425, 64.11179964882987, 59.16826057434082, 53.78445931843349, 54.628637654440745, 54.923359394073486, 59.04584721156529, 59.06018829345703, 70.02745423998151, 64.11384241921562, 77.35100841522217, 33.24243674959455, 0.25063465961388176, 0.14070168643125466, 0.4473109117576054, 0.3864559286407062, 0.02492328842968813, 0.02877430205366441, 0.274159197296415, 0.16153049947960035, 0.24120340283427918, 0.3458785302937031, 0.3080902365701539, 0.18931209801563195, 2.6131071874073575, 30.47349623271397, 61.48342118944441, 78.03682340894426, 79.64002990722656, 83.98833070482526, 26.546707902635845, 15.222459145954677, 22.1519775050027, 32.14472906930106, 52.413812501089915, 59.0164771761213, 62.04090295519148, 62.72740582057408, 8.442098634583608, 0.11880032664963178, 0.03831278093691383, 0.11095270275005273, 0.032646867646170516, 0.08515152401689972, 0.048511511712734184, 0.0240068454628012, 0.08786755041884524, 0.07492009124585561, 0.07180298957973719, 0.07214125964258399, 0.03906036028638482, 0.052040816617331336, 0.08881138584443501, 0.14520961525184767, 0.028937384552721466, 0.08633814605751208, 0.05014164459758571, 0.029091564672333852, 0.040108835989875455, 0.06776481733790465, 0.07380516321531363, 0.0472059764101037, 0.06333998870104551, 0.0856390039303473, 0.2094937107924904, 0.6619269241179738, 15.569688422339302, 90.31805624280656, 80.33139651162284, 78.11130809783936, 52.70255878993443, 35.284095423562185, 33.50298030035836, 41.440015247889924, 90.73551791054862, 99.87959739140102, 71.95653125217983, 14.262835621833801, 0.37712322228721207, 0.08959162647702865, 0.4241639923836504, 0.026988184146050895, 0.2481223972780364, 0.15116818408880914, 1.1080544165202548, 0.028716613006378924, 0.19545478054455348, 0.20331073685416154, 0.17552141658961773, 2.6952468369688307, 46.533857754298616, 87.27439785003662, 94.27932153429303, 91.66779940468925, 98.35132026672363, 95.05907617296491, 94.31743240356445, 91.32523931775773, 90.06792804173061, 80.51330035073417, 85.40959167480469, 86.5314895084926, 90.2286468233381, 85.89984961918422, 82.95031152452741, 83.11066899980817, 83.97218309129987, 82.85489191327775, 77.59071431841168, 71.76059900011334, 61.78941985539028, 58.49017892565046, 57.7259396144322, 58.97303703853062, 65.2966342653547, 71.81203651428223, 75.71952274867466, 72.82164451054165, 68.38964571271623, 63.70624719347273, 58.10143763678414, 55.53485298156738, 54.01420497894287, 56.438876152038574, 61.460679735456196, 62.70720740727016, 63.48374502999442, 63.02264172690255, 65.69735077449253, 67.0404167175293, 71.31117561885289, 77.30218342372349, 72.15841116224016, 70.74967084612165, 69.51453821999687, 66.12943145206997, 64.94650064195905, 62.02310861860003, 57.67832013538906, 57.09295872279576, 47.74843760899135, 44.49482897349766, 47.774757385253906, 55.88470867701939, 51.2128198487418, 55.53012820652553, 59.2825653893607, 58.456556592668804, 58.55654811859131, 64.40274156842912, 68.56319086892265, 68.23282487051827, 64.63199043273926, 61.15005356924874, 62.53605243137905, 60.74806553976876, 58.64689554486956, 54.427765233176096, 57.253229345594136, 61.1220314843314, 67.06104591914585, 67.72347327641079, 65.71063573019845, 68.23421451023647, 72.45535632542202, 70.04404653821672, 69.67365891592843, 66.30996649605888, 59.98110948290144, 56.35157551084246, 55.69234432492937, 54.588299887520925, 57.09612710135323, 65.05765097481864, 72.53193242209298, 77.21032129015241, 74.54429054260254, 65.59693540845598, 62.642742020743235, 55.49744388035366, 57.59959704535348, 58.11245400565011, 61.63126495906285, 62.870851380484446, 74.5337223325457, 70.27566473824638, 82.41550173078264, 42.237397466387065, 0.5476332913552011, 0.034156645382089276, 0.3518109619617462, 0.8453862911888531, 0.5389457632388387, 0.3998940704124314, 0.3711446502379009, 0.32602888398936813, 0.44197510236075943, 0.758382034088884, 0.285834477948291, 0.37513405616794315, 1.4388751962355204, 35.88739013671875, 69.66705117906842, 88.79059900556291, 76.72513553074428, 56.266411440713064, 26.771612405776978, 25.916448967797415, 30.816014630453928, 42.250227315085276, 62.319226946149556, 66.94269030434745, 68.57821982247489, 74.72545787266323, 10.670488408633641, 0.12541529669293336, 0.06076063282255616, 0.09557556573833738, 0.024949758080765605, 0.10200585212026324, 0.07069466369492666, 0.0448297603454973, 0.061360579915344715, 0.09668908241604056, 0.06740811147860118, 0.07562681939452887, 0.0517169213188546, 0.03641164116561413, 0.17433315249426024, 0.19871854755495275, 0.09484721267861979, 0.18368508853018284, 0.08958865449364696, 0.16283015188361916, 0.12200179057461874, 0.12117206438311509, 0.1998876091092825, 0.2509192100593022, 0.23411957866379193, 0.20952926602746758, 0.4417508601077965, 1.090707153081894, 22.208283969334193, 102.710328238351, 89.96159975869315, 91.5324762889317, 66.43637507302421, 57.78140708378383, 37.72301735196795, 52.44042410169329, 102.15303407396588, 107.81411361694336, 83.36223547799247, 18.407454320362636, 0.7065996612821306, 0.25868718751839226, 0.680275053850242, 0.16596129243927343, 0.4627671795231955, 0.6466424614191055, 2.0420542870249068, 0.47350415480988367, 0.6779507185731615, 0.5107760833842414, 0.4927677639893123, 3.960308177130563, 50.523523807525635, 92.99632276807512, 96.98481110164097, 98.42563819885254, 101.56109619140625, 99.61981814248222, 97.68673896789551, 96.23229340144566, 91.88850198473249, 83.67927483149937, 86.78480693272182, 88.29633889879499, 93.52603258405412, 89.18115724836076, 84.6926418031965, 86.77599661690849, 89.20755345480782, 85.35157421657017, 83.02697099958147, 76.13743604932512, 66.28026989528111, 60.78486319950649, 62.0200583594186, 63.51871531350272, 68.80395984649658, 74.44814137050084, 77.96657017299107, 73.58242361886161, 72.44649042401994, 66.58093234470913, 61.95937279292515, 61.32166017804827, 58.01283768245152, 59.8790682383946, 66.34421416691372, 67.06194223676408, 66.33183942522321, 65.13010678972516, 70.06992162976945, 71.66427612304688, 74.11808109283447, 80.40204579489571, 75.98490919385637, 74.04215812683105, 74.08386816297258, 70.73393317631313, 69.64237117767334, 64.05293451036725, 63.06012725830078, 59.845230511256624, 49.36799669265747, 46.2420403616769, 50.71029485974993, 60.768076351710725, 56.074380602155415, 63.431897572108674, 65.36040483202252, 61.515514918736045, 59.17805058615548, 69.65694155011857, 74.80577210017613, 73.75640651157924, 66.40804031917027, 63.652016503470286, 65.62795216696603, 61.97058718545096, 60.80797985621861, 56.93895190102713, 61.78289549691336, 64.4618637902396, 70.72137083326066, 73.13530703953334, 65.90540763310024, 68.81557028634208, 75.85395649501255, 75.2325165612357, 72.24937697819301, 68.49086012159074, 64.46367727007184, 61.752260889325825, 58.650571141924175, 56.485321385519846, 60.62861210959298, 69.14747183663505, 76.30241407666887, 78.0875244140625, 79.27101802825928, 70.98540932791573, 65.77461474282401, 58.68278299059187, 61.633946963718955, 62.30946472712925, 64.61548846108573, 65.80607618604387, 79.79760810307094, 74.79463413783482, 87.71831825801304, 40.496540205819265, 0.7998214704649789, 0.13869109217609676, 0.568418990288462, 1.4396435150078364, 0.33547979114311083, 0.3820594016994749, 0.8309961919273648, 0.564975343644619, 3.0011564791202545, 0.9401480491672243, 0.4648522904941014, 0.4100193870919091, 4.593547454902104, 46.53898899895804, 80.14710944039481, 93.88364941733224, 93.06604099273682, 112.20993314470563, 37.37937682015555, 23.526553528649465, 33.70594412939889, 50.838867800576345, 69.75860064370292, 78.24829878125871, 76.91874708448137, 88.27969101497105, 12.776929480688912, 0.2612215429544449, 0.22875391372612544, 0.27508509904146194, 0.07413284813186952, 0.25628758913704325, 0.21327297442725726, 0.17014230308788164, 0.16382567132157938, 0.20282600500753947, 0.14481122020099843, 0.14985473028251103, 0.12815344333648682, 0.11580274892704827], [0.08583180287054606, 0.11555462224142891, 0.035216052284730334, 0.09029888388301645, 0.062029018332915645, 0.09429353488875286, 0.05379985758502569, 0.03796271115009274, 0.023081033623644283, 0.009646371040227157, 0.0049701269433301476, 0.02847401298848646, 0.0853349727445415, 0.09379644691944122, 41.61127444675991, 74.91240610395158, 63.04650184086391, 48.29752942493984, 31.81217438834054, 28.65152743884495, 28.962666034698486, 62.56970950535366, 99.9289573941912, 78.09678636278424, 29.41922869001116, 0.5419464079397065, 0.06738597766629287, 0.10264656559697219, 0.10500351805239916, 0.07343098507927996, 0.03289297229743429, 0.10963560521070446, 0.5335869107927594, 0.17565082678837435, 0.26858277938195635, 0.039606930421931405, 0.1815942507237196, 4.226476728916168, 48.79450280325753, 92.66025229862758, 93.05394417898995, 93.07271126338414, 95.23515742165702, 90.48622349330357, 88.97292668478829, 85.23298931121826, 86.81563608986991, 85.18993132455009, 82.35747732434953, 80.60417584010533, 83.44576672145298, 79.52439103807721, 78.07723413194928, 75.12684835706438, 72.69202586582729, 66.51951026916504, 63.785428864615305, 57.97578641346523, 55.014453751700266, 54.846824986594065, 56.2121981212071, 63.468431200299946, 73.32851559775216, 76.11898858206612, 75.95524038587297, 70.9846658706665, 71.0182465144566, 67.41798877716064, 59.03766223362514, 52.964519773210796, 51.39526217324393, 52.376535415649414, 52.46704959869385, 57.35385315758841, 60.10081304822649, 62.712988308497835, 62.28150517599923, 64.57168006896973, 68.0592588697161, 73.42511640276227, 64.75245135171073, 68.91125392913818, 63.08177784511021, 62.42998123168945, 59.38052109309605, 60.71620110103062, 51.962019784109934, 57.75938476834978, 58.79216153281075, 50.902676582336426, 48.32935217448643, 52.993528502328054, 49.60192516871861, 48.070632525852744, 56.28093317576817, 49.850757530757356, 55.87388685771397, 61.75938974108015, 61.532280921936035, 59.41782597133091, 63.18534074510847, 61.130292892456055, 65.30083097730363, 61.82313251495361, 59.00511687142508, 53.6783881187439, 52.556177616119385, 56.866513456617085, 64.3588706425258, 63.91540881565639, 68.29121058327812, 68.00035899026054, 65.60228552137102, 65.99408054351807, 62.88645703451974, 58.83116177150181, 52.54960114615304, 49.78565985815865, 50.27439962114607, 50.394124031066895, 53.99467706680298, 62.06727136884417, 68.6248561314174, 66.88714640481132, 65.20352840423584, 68.81236716679165, 59.198193413870676, 56.51524380275181, 52.178553444998606, 52.90617574964251, 53.09002161026001, 57.90818044117519, 57.84726211002895, 68.58534172603062, 65.0078045981271, 77.80389199938092, 16.065659523010254, 0.1780904315944229, 0.0680859951036317, 0.9045031390019825, 0.6957847901753017, 0.4012439479785306, 0.25771766954234665, 0.1766751025404249, 0.2186192875461919, 0.49769729375839233, 0.1731609289667436, 0.14829145345304692, 0.17196431889065675, 9.561448216438293, 42.68148463112967, 73.35399464198521, 79.65783814021519, 79.74307864052909, 57.954497132982524, 30.363030297415598, 17.264400959014893, 25.583647625786917, 33.7760306085859, 53.064049243927, 60.09565053667341, 58.84205654689244, 45.725945540836875, 0.49121343025139397, 0.08209095788853508, 0.007324795704334974, 0.09021959706608738, 0.08766210358589888, 0.028082991916952387, 0.05133674154058099, 0.06215310203177588, 0.046907356541071615, 0.08144125382282905, 0.07092886005661317, 0.0329107431295727, 0.15285145305097103, 0.10104255631033864, 0.12089366146496364, 0.10156612071607794, 0.04778958098696811, 0.03851698265810098, 0.07353201894355671, 0.05979057201849563, 0.030022284016013145, 0.04524957335421017, 0.03955556532101972, 0.05591784357758505, 0.00991711753886193, 0.03271348621430142, 0.08015565387904644, 48.98308386121477, 84.63177558353969, 71.45364148276192, 60.12499277932303, 44.56097929818289, 41.92965132849557, 26.227580615452357, 64.82987512860979, 109.55529049464634, 87.53159236907959, 36.395741190229145, 0.6277448811701366, 0.09996815039111034, 0.6495654274310384, 0.3086443011249815, 0.1463861542620829, 0.011271882253432912, 0.04333404524784003, 1.1527535894087382, 0.44725847457136425, 0.467229388654232, 0.08080316627664225, 0.32810102137071745, 6.15770377431597, 56.342876366206575, 96.69858006068638, 94.91196891239711, 96.31213515145438, 96.82198701586042, 91.86183479854039, 90.33892863137382, 88.96458884647915, 88.98284176417759, 89.59623568398612, 84.70076424734933, 82.20657634735107, 86.16847392490932, 84.20070934295654, 81.02481283460344, 78.2025726863316, 76.08287184579032, 69.58069896697998, 66.17624841417584, 60.65338938576834, 57.93815496989659, 55.79068217958723, 61.204854011535645, 70.54870809827531, 77.32095745631626, 79.07075010027204, 76.63581643785749, 74.55462946210588, 75.1069278717041, 72.1311811719622, 64.19180815560478, 57.880356379917686, 53.50086164474487, 55.74568564551217, 55.03258160182408, 61.581654821123394, 63.77579171316964, 66.19755159105573, 67.47310883658272, 69.08818980625698, 70.61691161564418, 77.59158979143415, 67.63885811397007, 72.44788701193673, 66.0173431124006, 66.66934122358049, 60.77523994445801, 60.0762859072004, 57.81713472093855, 60.77476051875523, 61.73099940163748, 54.60769925798689, 50.89972012383597, 56.58546577181135, 55.95538575308663, 52.95914881569998, 57.24489845548357, 57.42424535751343, 59.79587050846645, 65.13305977412632, 67.49566268920898, 61.83566011701311, 65.35465172358921, 64.65019471304757, 67.860568182809, 64.47068105425153, 62.00966385432652, 58.23923083714077, 57.174440247671946, 59.42785917009626, 67.67455101013184, 66.57863249097551, 71.52365847996303, 74.10018948146275, 68.93423162187848, 66.26938206808907, 65.00822843824113, 61.9787026814052, 55.4355389050075, 53.0107079233442, 52.90255226407732, 53.39411299569266, 56.31867231641497, 65.19337013789585, 72.22115339551652, 69.4839175088065, 69.64231559208461, 73.8456005368914, 62.28577831813267, 60.655578068324495, 54.46635205405099, 56.20387070519583, 55.93851205280849, 60.666125433785574, 60.88110269818987, 72.32120050702775, 71.22668552398682, 84.10817323412213, 21.925603457859584, 0.11740912630089692, 0.12358790689281055, 1.291408149259431, 0.6791475457804543, 1.0361538061073847, 0.5363059363194874, 0.14598421725843633, 0.48421729994671686, 1.322757009949003, 0.7255324710692678, 0.15920339577964374, 0.24234855281455175, 9.281584330967494, 49.40327617100307, 81.90758146558488, 89.74068178449357, 73.46664578574044, 39.738144329616, 28.062301090785436, 26.37883073943002, 37.21489906311035, 42.287535667419434, 64.52063165392194, 68.23217868804932, 68.32585430145264, 56.0650908606393, 0.4927148382578577, 0.06965835073164531, 0.03988067858985492, 0.06239822280726262, 0.05075411066146834, 0.013393556931987405, 0.08892486404095377, 0.09378102381846734, 0.01362763879088951, 0.02702819905243814, 0.03456153062039188, 0.03031265629189355, 0.037533039027558904, 0.26868043414184023, 0.19667929198060716, 0.17466495611837932, 0.18622504866548947, 0.10642215835728816, 0.14842277712055615, 0.12236848446939673, 0.137912337535194, 0.2510115179632391, 0.1226891465485096, 0.12788424135318824, 0.09589427363659654, 0.21130841198776448, 0.17578566526728018, 59.72291442326137, 95.31640270778111, 82.17025811331612, 66.95898383004325, 50.544437885284424, 39.29123272214617, 42.25729363305228, 89.34002086094448, 114.35673195975167, 99.15136364528111, 44.58701767240252, 1.4268728345632553, 0.26103885418602396, 0.7709172357405935, 0.28949251451662605, 0.3077923596969673, 0.26739523453371866, 0.3299080144081797, 2.212064330066953, 1.2145063557795115, 1.0882993851389204, 0.3629614364887987, 0.6074086438332285, 9.394360542297363, 58.576225417000906, 103.95723806108747, 99.07625361851284, 100.55392701285226, 100.8719391141619, 96.2668537412371, 94.60835347856793, 93.0051817212786, 95.01671300615583, 93.96310901641846, 84.82761750902448, 85.72310134342739, 90.06145926884243, 87.948164667402, 84.73431709834507, 84.63957146235875, 78.86083807264055, 72.77482754843575, 69.19242668151855, 63.604087829589844, 58.92726925441197, 60.907818521772114, 65.22401169368199, 71.514299256461, 82.01868316105434, 81.18851934160504, 81.11499350411552, 78.5795680454799, 79.68953582218715, 75.54214913504464, 66.03861849648612, 60.60534954071045, 56.707219055720735, 59.94905744280134, 58.77587495531355, 65.00496973310197, 68.23343631199428, 69.29149409702846, 71.48150375911167, 71.99672658102853, 74.54629857199532, 81.64877496446881, 72.48906203678676, 76.93150397709438, 71.92663315364292, 70.3478843144008, 65.62891101837158, 62.670319420950754, 59.76268591199602, 63.77588898794991, 63.256622314453125, 57.23122787475586, 53.65843984058925, 60.051327977861675, 59.79575933728899, 62.09279210226876, 64.49966893877301, 60.35761846814837, 64.29974842071533, 67.6711116518293, 71.65167903900146, 66.17985452924455, 71.08177389417375, 67.67526667458671, 70.56689153398786, 66.96283313206264, 65.76308768136161, 60.31436593191964, 59.71008110046387, 61.26136371067592, 71.95918546404157, 68.90749495370048, 73.0657764162336, 76.04396888187954, 73.75849791935512, 73.46288681030273, 69.4629339490618, 65.56846169063023, 59.76743153163365, 56.88104908806937, 56.04946436200823, 55.7760979107448, 59.55297538212368, 68.99532713208879, 74.41982051304409, 74.08852345602853, 71.41867119925362, 76.82519653865269, 65.93695245470319, 63.68745926448277, 55.980156081063406, 57.59334714072091, 60.95097378322056, 65.43227699824742, 63.863172258649556, 75.9885014125279, 75.7782211303711, 89.58859961373466, 19.920655591147288, 0.3020746165088245, 0.7062901950308255, 3.160392471722194, 1.9438356373991286, 1.913425977740969, 1.3085362187453677, 0.5454222985676357, 3.8419786180768694, 2.9727205421243394, 1.0238201022148132, 0.3116989843547344, 0.32022113991635187, 16.30099674633571, 60.78058310917446, 88.51251125335693, 94.71511949811662, 97.46405615125383, 79.67707075391496, 42.84558718545096, 28.817219393593923, 39.56062132971627, 50.06511640548706, 72.05522346496582, 76.75044087001255, 77.86487633841378, 63.946376936776296, 0.7602082703794751, 0.23593943672520773, 0.1647438377674137, 0.20022423033203396, 0.21865704123462948, 0.14920738073331968, 0.18482799934489386, 0.13387438920991762, 0.09044694022408553, 0.1979338896593877, 0.11072364289845739, 0.14562456655715192, 0.15891585978014128], [0.05154127574392727, 0.13715457676776818, 0.07407209889164992, 0.0798317144757935, 0.04411254543811083, 0.059408929997256825, 0.0693838968873024, 0.06673807171838624, 0.07856230437755585, 0.016689720596852045, 0.07213332756821599, 0.012910214385816028, 0.06428056715854577, 0.6262919477054051, 60.23671981266567, 70.76670782906669, 65.26816054752895, 51.17330544335501, 31.148232323782786, 29.09841125352042, 62.330323219299316, 74.76294340406145, 86.73259122031075, 58.40818323407854, 5.8314489381653924, 0.11631800127880913, 0.11250451912305184, 0.5123503389103072, 0.5887799805828503, 0.05932400455432279, 0.18823533079453877, 0.026161228073760867, 0.6239196807146072, 0.05147226194718054, 0.1698719747364521, 0.022582318866625428, 0.34452756707157406, 7.051919996738434, 73.45256178719657, 95.72838919503349, 92.60716806139264, 90.06861591339111, 90.38953930991036, 89.09714657919747, 84.58866895948137, 81.41566290174211, 77.8009112221854, 80.61287498474121, 83.27743966238839, 85.37735898154122, 81.78707190922329, 76.36660848345075, 69.4620167868478, 64.26914855412075, 60.83066572461809, 60.304777417864116, 57.410265581948416, 57.141964367457796, 54.75432014465332, 58.73105212620327, 69.4995231628418, 75.3556455884661, 74.86548491886684, 70.33962290627616, 72.52043315342495, 78.81676564897809, 74.91775621686662, 71.10012408665249, 66.52948093414307, 60.88855116707938, 53.91612420763288, 50.87218441282, 52.50026546205793, 54.525623662131174, 57.994379792894634, 59.93101991925921, 63.08863571711949, 65.98170580182756, 66.84884098597935, 70.45296886989048, 59.10307952335903, 59.05931976863316, 59.672623361860005, 58.18179702758789, 55.63985068457467, 60.63145392281668, 55.868189334869385, 64.14599173409599, 69.40824467795235, 64.01467078072685, 54.48201676777431, 53.06500809533255, 51.70423466818673, 50.403392927987234, 53.2279120853969, 57.47250754492623, 48.18168558393206, 54.48433746610369, 62.476923261369976, 61.07086494990757, 59.33480889456612, 61.7491272517613, 67.29499871390206, 63.459391593933105, 59.51342623574393, 59.02159105028425, 60.812489237104145, 59.675152506147114, 63.98601640973772, 65.88065120152065, 69.32587378365653, 64.55782536097935, 63.15614441462925, 57.79791252953665, 53.041620458875386, 54.02519008091518, 49.201837471553254, 51.23727403368269, 49.66925321306501, 52.530827113560264, 56.46517160960606, 63.25920009613037, 64.5297407422747, 64.38025719778878, 71.6849331174578, 67.01671641213554, 63.270317213875906, 55.07641083853585, 53.82283074515206, 55.243539333343506, 53.6653984614781, 54.40902246747698, 56.43481492996216, 61.64957346235003, 69.13477052961076, 70.29690538133893, 62.996766635349815, 3.6519992351531982, 1.2129240121160234, 0.5418795315282685, 2.0717343858310153, 0.5506729111075401, 0.4265715160540172, 0.07383615190961532, 0.09943658605750118, 0.7814561873674393, 0.7314281261393002, 0.17729448287614755, 0.13966142439416476, 0.6179628489272935, 23.612674713134766, 58.580658367701936, 78.63008144923619, 74.70539147513253, 88.3096308026995, 71.40363529750279, 38.411792278289795, 15.91351134436471, 34.75608444213867, 37.68579585211617, 45.231157370976035, 57.988602365766255, 67.65018367767334, 11.171375359807696, 0.2726040764578751, 0.1766958385705948, 0.07472140940704516, 0.140451402004276, 0.017941946795742427, 0.062273358793130944, 0.018704336868332963, 0.030765564846140996, 0.07314538968993084, 0.054078141759548864, 0.05345827627128788, 0.13691623455711774, 0.06721084099262953, 0.06982826268566505, 0.03600346163979598, 0.07878441603056022, 0.09269448569310562, 0.014137774988609766, 0.06763238765831504, 0.041727108082601, 0.03448176882894976, 0.021038585542035953, 0.06910094099917582, 0.06515038119895117, 0.05607459534491811, 0.49351160121815546, 71.63337053571428, 78.99701581682477, 75.49112851279122, 52.62692417417254, 39.633327279772075, 29.203525338854107, 32.17270251682827, 81.960373878479, 95.41519914354596, 70.31963988712856, 7.892390166010175, 0.15195623465946742, 0.13832631175007137, 1.048837199807167, 0.9102818146348, 0.13901521478380474, 0.1728228692497526, 0.0868865041328328, 0.913103923201561, 0.29894355737737244, 0.004955717828124762, 0.22124037332832813, 1.0264808280127389, 8.67088804926191, 79.38511439732143, 97.92973136901855, 94.28361552102226, 90.8043954031808, 92.21880544934953, 91.52213736942836, 87.55011626652309, 84.83026477268764, 82.73794678279332, 83.38634572710309, 86.63467025756836, 88.10297053200858, 86.51125635419572, 79.87139797210693, 73.11817278180803, 67.6417485645839, 63.408377919878276, 62.89222403935024, 60.66844613211495, 60.3947149004255, 58.55042675563267, 63.27150535583496, 73.01862594059536, 77.65914712633405, 76.60234001704625, 74.24908937726701, 77.6042285646711, 81.90275246756417, 78.26523848942348, 71.47650105612618, 73.18226991380963, 63.93242495400565, 58.023426737104145, 54.33093513761248, 55.58865983145577, 57.57840851375035, 61.16041333334786, 62.42365837097168, 67.49276529039655, 69.57936491285051, 71.87120737348283, 72.00686400277274, 62.60900156838553, 60.93977328709194, 65.04576955522809, 60.28794888087681, 58.22439643314907, 60.67233712332589, 59.67699377877371, 67.20271274021694, 71.94726235525948, 67.12155778067452, 56.89815902709961, 55.010833740234375, 52.813055992126465, 54.7172862461635, 58.41873754773821, 61.515292576381135, 54.44422204153878, 56.294350147247314, 66.69338199070522, 67.33477020263672, 66.0163356236049, 63.87601252964565, 70.89326926640102, 66.52148355756486, 64.18529769352504, 62.8542034966605, 65.90406663077218, 63.52485752105713, 65.70391682216099, 68.23801517486572, 72.69973836626325, 67.07988248552594, 67.03073787689209, 62.49818474905831, 55.66546174458095, 56.31404481615339, 52.9451516696385, 53.398132528577534, 52.562316349574495, 55.77757787704468, 59.7604763848441, 66.23256356375558, 67.3944343839373, 67.77616146632603, 74.62297194344657, 67.81887899126325, 67.14520944867814, 56.629708426339285, 57.73040730612618, 56.190033367701936, 57.60349498476301, 56.270743642534526, 59.887482506888254, 64.96638638632638, 73.2092706135341, 71.87038748604911, 73.8232273374285, 6.4858876041003635, 0.6154955870338849, 0.426403917904411, 1.2457932255097797, 1.4545936499323164, 0.552273765206337, 0.09067389661712305, 0.08248869476041623, 1.691441455057689, 1.3477569541760852, 0.3138304256967136, 0.14240844627576216, 0.2557393599833761, 26.529868943350657, 66.2316950389317, 86.8091812133789, 83.53625311170305, 76.80201734815324, 46.47841807774135, 30.964330877576554, 20.428848573139735, 41.66974353790283, 44.90346990312849, 57.48694242749895, 63.596201624189106, 79.86543641771588, 12.684534072875977, 0.2504742539354733, 0.254595757062946, 0.030616768901901584, 0.1821012520896537, 0.04420731303149036, 0.08435079841209309, 0.056089041355465136, 0.07662479512925659, 0.05656693356909922, 0.061755643359252384, 0.020077796919005256, 0.05159927691732134, 0.09164003548877579, 0.23199017292686872, 0.13841863322470868, 0.16150806711188384, 0.17963764071464539, 0.14577270432242326, 0.1881915788565363, 0.13974204792508058, 0.09587167842047555, 0.17204910862658704, 0.14981937860803946, 0.10184404187436615, 0.23322882503271103, 0.9885740620749337, 83.04230567387172, 90.80549321855817, 84.51141888754708, 67.74608966282436, 45.99846083777291, 41.050523553575786, 89.64164910997663, 94.67760617392403, 101.49444907052177, 80.9472153527396, 11.591062188148499, 0.25361095847828047, 0.338142281132085, 1.2703874600785119, 1.8671802878379822, 0.3187598469001906, 0.3299770892730781, 0.2920901636992182, 1.7855716326407023, 0.7216926685401371, 0.829151445201465, 0.6385841795376369, 1.4789453489439828, 10.309309755052839, 81.98279571533203, 101.59189755575997, 100.83893517085484, 96.5001881463187, 97.6878993170602, 96.28512750353131, 92.75242710113525, 87.78536837441581, 85.5134186063494, 87.60169274466378, 89.64401149749756, 91.69201387677873, 89.22287423270089, 83.312013898577, 77.61724948883057, 72.22890758514404, 67.48716504233224, 66.23676027570451, 64.53404862540108, 63.525489807128906, 62.52204486301967, 65.2953280040196, 75.0639671598162, 81.8218684877668, 79.40830748421806, 79.11209188188825, 82.10199206215995, 82.76960972377232, 78.99896826062883, 78.01107338496617, 75.61940615517753, 69.23184381212506, 60.642313957214355, 59.07338292258126, 59.1570531300136, 60.66680635724749, 64.9145736694336, 65.71515205928257, 70.71362359183175, 73.74173886435372, 74.25575269971574, 77.40512793404716, 65.21134512765067, 63.222527503967285, 68.7683572769165, 62.708548409598215, 60.70459066118513, 62.72336196899414, 59.023300307137625, 68.0624897820609, 72.12898554120744, 69.31458296094621, 57.042056219918386, 56.287593024117605, 56.12870856693813, 58.58190904344831, 64.54973070962089, 65.16470187050956, 57.281748226710725, 61.71603298187256, 69.48702335357666, 69.65828950064522, 68.33182975224086, 70.09845788138253, 71.25814696720668, 69.54143469674247, 66.9858455657959, 64.72431809561593, 68.69217027936662, 66.59190355028424, 70.05107116699219, 71.95140348161969, 76.68649659837995, 70.02480002811977, 69.86533887045724, 66.39183712005615, 57.36931984765189, 59.59377520424979, 56.252125944410054, 55.46508264541626, 55.794708660670686, 59.0037202835083, 62.98864419119698, 69.14358084542411, 70.89392934526715, 70.83801719120571, 77.85271004268101, 70.74576595851353, 70.30283219473702, 58.66057654789516, 60.22625582558768, 60.56542519160679, 60.21438830239432, 59.49030957903181, 62.99659987858364, 68.25964491707938, 78.75418322426933, 76.46605804988316, 76.28690569741386, 5.392457842826843, 1.7394696835960661, 2.9287152120045254, 5.231378623417445, 3.208909788302013, 0.8234342719827379, 0.5716962058629308, 1.185286466564451, 4.823013016155787, 2.4713858664035797, 0.6208971600447382, 0.11837420665792056, 1.0805437841585703, 38.352958406720845, 73.57294627598354, 91.08176054273332, 86.49871485573905, 111.49008587428501, 90.52609920501709, 52.7047301019941, 26.97398737498692, 49.84510864530291, 50.99579981395176, 61.84305994851248, 73.95299884251186, 90.91413525172642, 14.52472538607461, 0.5771899510707174, 0.37667183365140644, 0.18020091977502617, 0.22772465752703802, 0.15313384575503214, 0.21578269904213293, 0.1061915514458503, 0.22303201790366853, 0.11650172142045838, 0.16643055368747028, 0.1625847393380744, 0.16681145610553877], [0.02359832836581128, 0.0480178571306169, 0.02338427770882845, 0.07338770133044038, 0.1331885260130678, 0.14877668741558278, 0.03676746492939336, 0.09722713354442801, 0.030618410956646715, 0.05901423974760941, 0.10717674358082668, 0.040963226929306984, 0.34905681546245304, 3.4735840431281497, 70.65827424185616, 62.59907954079764, 56.17793655395508, 46.4739990234375, 29.039539166859218, 50.01548542295183, 63.670908655439106, 75.90966715131486, 89.99719538007463, 29.41118962424142, 0.329197669667857, 0.12714379679943832, 0.1020208273881248, 1.1860593450920922, 0.6552869975566864, 0.22607337470565522, 0.08460594793515545, 0.13953069783747196, 0.09335803187319211, 0.3573953051652227, 0.13535170922321932, 1.3570735113961356, 1.3307975956371851, 28.876628228596278, 103.92241368974958, 88.37262317112514, 92.15033095223563, 83.61410072871617, 85.59213474818638, 76.57103143419538, 76.93687493460519, 72.61027336120605, 78.66463484082902, 75.91537162235805, 80.5348675591605, 84.07211903163365, 81.3092234475272, 76.67368412017822, 70.08621515546525, 59.324178150721956, 58.90832151685442, 55.126965931483674, 58.929513522556846, 57.78212622233799, 60.66877269744873, 65.7583976473127, 73.02875641414097, 73.09825924464634, 69.69363498687744, 73.73857743399483, 79.69351713997978, 71.99449620928083, 80.70979540688651, 74.64681816101074, 67.06367233821324, 63.32672963823591, 59.08868980407715, 52.657124519348145, 51.503831250326975, 56.925347328186035, 59.459160804748535, 63.23938383374895, 63.94712039402553, 65.53741713932583, 69.68909086499895, 62.580923897879465, 57.01601089750017, 54.89618846348354, 59.34062453678676, 56.71355928693499, 56.973720686776296, 59.993609292166575, 66.28424426487514, 71.04214136941093, 68.82420689719063, 70.16001197269985, 65.44657639094761, 57.71592378616333, 51.88984189714704, 53.79923466273716, 57.39919362749372, 55.11328840255737, 59.77804837908064, 52.65227815083095, 54.81334509168352, 64.82036999293736, 64.58616011483329, 62.350292342049734, 64.62500054495675, 71.63175160544259, 66.90059811728341, 65.37306444985526, 60.961069515773225, 63.01743752615792, 65.5833169392177, 63.95841121673584, 68.15752724238804, 65.53885541643415, 60.01450947352818, 53.91595050266811, 50.50997134617397, 48.45860603877476, 50.512625558035715, 49.999098096575054, 53.47974606922695, 60.65116596221924, 63.02966635567801, 63.61350263868059, 64.92645508902413, 68.61794962201799, 66.8397388458252, 69.28567150660923, 63.49776649475098, 58.16456202098301, 53.07146644592285, 52.77519873210362, 53.403746673039024, 52.09523064749581, 56.27840403148106, 57.659066677093506, 67.09550203595842, 66.56937054225376, 75.96931048801967, 44.47330692836216, 0.19710300995835237, 0.12190199164407593, 0.4849783991064344, 0.7149617097207478, 0.153255004967962, 0.1536123893622841, 0.31792109619293896, 0.9544954278639385, 0.32574129370706423, 0.21171714791229793, 0.0740861649225865, 0.12251005401568753, 4.554611921310425, 36.06049408231463, 74.85712623596191, 75.32485812050956, 85.01723384857178, 91.10390445164272, 74.83871350969586, 43.249902861458914, 47.65566873550415, 52.356434277125764, 33.794568402426584, 53.11527483803885, 60.29966354370117, 30.167365550994873, 0.2791315833372729, 0.11134238541126251, 0.09438770876399108, 0.1437877994030714, 0.06460587041718618, 0.1546520000057561, 0.060721902043691704, 0.1654132939875126, 0.042064055002161434, 0.15986963574375423, 0.031125663380537714, 0.21826786068933351, 0.04129087452643684, 0.1070357168625508, 0.012541842813204442, 0.02013578961071159, 0.02027313527651131, 0.1625554809080703, 0.04896421670647604, 0.0582725941868765, 0.03279325818376882, 0.008541881422778326, 0.10189603801284518, 0.11945846490561962, 0.5474520953638213, 4.04318585566112, 82.58521842956543, 70.39035170418876, 65.62570789882115, 53.381411688668386, 34.03552845546177, 39.20853526251656, 59.43054812295096, 88.0870452608381, 98.87145546504429, 37.889193943568635, 0.3412530927785805, 0.08177596836217813, 0.3678421660193375, 1.9793127051421573, 0.6320794171520642, 0.697245431797845, 0.49325364934546606, 0.07592542908553566, 0.22685226505356176, 0.48661594837903976, 0.07804105377623013, 3.0880163439682553, 1.484521821141243, 32.492295333317344, 106.2021176474435, 88.38911124638149, 94.95072596413749, 84.5542962210519, 89.79054205758231, 79.68595055171421, 80.06188978467668, 75.20629405975342, 82.2008649281093, 80.8804292678833, 82.64074148450578, 85.19646957942417, 84.33436489105225, 80.01496165139335, 74.07008988516671, 61.70013550349644, 60.82413441794259, 58.646687098911826, 60.442108563014436, 61.62565081460135, 64.37345491136823, 70.62060110909599, 77.92914022718156, 76.7377187183925, 78.00948919568742, 81.30560343606132, 79.32461643218994, 74.33731760297502, 82.89785957336426, 78.87503324236188, 68.70289829799107, 68.14363084520612, 63.26185430799212, 57.117902755737305, 53.40101950509207, 58.39794853755406, 62.16681126185826, 67.00399426051548, 66.62572043282645, 71.23689242771694, 73.07545525687081, 65.03542368752616, 59.345856530325754, 60.69707271030971, 60.78694071088518, 57.33751794270107, 57.74581841060093, 59.252834047589985, 67.92394270215715, 72.61599867684501, 70.32396861485073, 72.82370812552315, 68.1693947655814, 59.0280111857823, 54.69901943206787, 57.869176728384836, 61.51022733960833, 59.02975518362862, 63.80974061148507, 58.47163418361119, 59.22506904602051, 68.0282073702131, 67.9193013054984, 66.95787906646729, 67.00689165932792, 75.96529442923409, 68.71946975163051, 69.11594785962785, 64.29384940011161, 67.19854382106236, 67.996461050851, 65.91400255475725, 69.92612865992955, 67.89269665309361, 62.63473769596645, 56.568533011845176, 53.708195890699116, 50.75049018859863, 52.104523863111226, 54.19911043984549, 57.502357006073, 65.63693618774414, 66.04501778738839, 67.4062602179391, 69.94115761348179, 71.35584558759416, 70.21455533163888, 72.00516169411796, 66.28514753069196, 60.830436434064595, 55.923559529440745, 55.07315560749599, 57.531365735190256, 54.061421462467735, 58.78230898720877, 61.0567809513637, 72.38116346086774, 71.36815084729875, 79.57642609732491, 52.457975251334055, 0.6183204640235219, 0.25440818284239086, 0.4218382186123303, 0.9650759058339256, 0.20846478029021195, 0.08442055859736033, 0.2927584121269839, 1.0276203325816562, 1.3740335213286536, 0.8546426487820489, 0.2429158352315426, 0.21295474150351115, 4.452510748590742, 42.16676555361067, 80.8915046964373, 83.69466509137834, 83.84701129368374, 72.35666411263603, 56.59746878487723, 36.337327684674946, 51.362563950674875, 56.881003924778526, 44.097808906010215, 59.90416513170515, 70.30486106872559, 36.98333992276873, 0.34552468785217827, 0.24590003224355833, 0.11561650463512965, 0.1185749444578375, 0.046202419724847586, 0.18320886551269464, 0.08358972639377628, 0.0950979720801115, 0.03971054271927901, 0.17935147535588059, 0.082417625002563, 0.07928087974765471, 0.09131582467151539, 0.24924255002822193, 0.12378210361514773, 0.13563328768525804, 0.1975613332220486, 0.22125486683632645, 0.1733536193413394, 0.13128850582454885, 0.18951913262052195, 0.24634070002606936, 0.318565378763846, 0.21275061102850096, 0.7516920587846211, 5.303880904402051, 94.10176726749965, 82.16567925044468, 75.64974199022565, 67.26306479317802, 43.590527875082834, 73.68929386138916, 95.83459935869489, 94.20752579825265, 111.07126930781773, 48.29503502164568, 1.1711337459938866, 0.2584469046975885, 0.2752333996551377, 3.0598872133663724, 1.3752343654632568, 0.9523811127458299, 0.21308204824370996, 0.3075916761798518, 0.23155042795198305, 1.0992145708629062, 0.65460781114442, 3.31619171159608, 3.9322361520358493, 33.75441823686872, 113.27462645939418, 93.93869999476841, 100.10807500566754, 88.72910049983433, 94.57857349940709, 84.84902490888322, 84.93739904676164, 77.067063331604, 86.15015847342355, 83.04766273498535, 84.7147718157087, 89.74737984793526, 86.99619197845459, 83.45306232997349, 77.14844063350132, 63.71798964909145, 64.67381164005825, 60.81240585872105, 65.9217289515904, 64.70222282409668, 67.15035806383405, 72.12477493286133, 80.85051727294922, 79.58200550079346, 81.11102608272007, 81.69465391976493, 83.91654886518205, 78.91993250165666, 81.44054440089634, 78.45381259918213, 73.96014853886196, 69.58916187286377, 66.99058423723493, 59.005575452532085, 58.45368003845215, 64.91282272338867, 66.88019820622036, 71.11959988730294, 69.85876587459019, 72.81479358673096, 78.87321281433105, 70.73596899850028, 60.49116284506661, 60.513007981436594, 68.58342402321952, 62.80528123038155, 60.86945056915283, 59.71167918613979, 69.90866088867188, 77.52385180337089, 75.4149067742484, 74.83032703399658, 69.85958576202393, 59.42622634342739, 54.92968225479126, 59.46689414978027, 65.19566999162946, 65.34433364868164, 67.04544721330915, 61.92199148450579, 64.17794649941581, 70.87141023363385, 71.35435172489711, 71.59268883296421, 70.94980675833565, 74.88299437931606, 72.32087394169399, 72.55685561043876, 67.01661218915666, 69.03881590706962, 71.54737962995256, 66.63127899169922, 73.5878849029541, 71.42571667262486, 66.05642672947475, 58.42563016074044, 57.37706708908081, 52.75076191765921, 55.383656706128804, 57.61071416309902, 60.29735674176897, 65.76214272635323, 69.42245374407086, 69.28433745247978, 72.53457273755754, 75.6027443749564, 74.55560220990861, 74.96616431644985, 70.63945852007184, 63.64872305733817, 59.78101525987898, 56.756235122680664, 60.569774763924734, 57.547888551439556, 63.00508362906319, 63.97259249005999, 76.61574309212821, 75.09460176740373, 86.91016633169991, 52.890514510018484, 0.44824245891400744, 2.4152832882744923, 1.5155076384544373, 1.9042452360902513, 1.0420061435018266, 0.6324612966605595, 1.2260403654405048, 3.847320480006082, 3.812296347958701, 1.557404624564307, 0.23890800029039383, 0.29116255204592434, 8.200047714369637, 54.218416009630474, 88.6216049194336, 90.10058457510812, 94.25252928052629, 111.76166316441127, 96.82457869393485, 57.92608594894409, 58.488851819719585, 66.62117631094796, 49.48422615868704, 67.2607649394444, 79.0678596496582, 40.9627365384783, 0.43524552775280817, 0.3886259107717446, 0.14406418028686727, 0.3432854137250355, 0.13730237526553019, 0.3955421639340264, 0.09480576097433056, 0.20325836752142223, 0.09504099549459559, 0.30422958944525036, 0.14897331329328672, 0.305382311876331], [0.13069321348198823, 0.03128922424678292, 0.03023468583290066, 0.0677263376169971, 0.10818438165421997, 0.07206227138106312, 0.03805582651070186, 0.015093275279338871, 0.057995928318372796, 0.008440973935648799, 0.11030199445251908, 0.09354806239051477, 0.2832013549549239, 6.476411998271942, 72.58169542040143, 61.114659445626394, 66.29729993002755, 44.07698515483311, 36.91315616880144, 38.54131712232317, 56.62369128635952, 84.72132396697998, 63.202905791146414, 9.144584962299891, 0.17059442454150744, 0.060033426487020085, 0.5714696294495037, 1.4887017054217202, 0.6271572155611855, 0.3710660215999399, 0.4442280557538782, 0.08341769741049834, 0.14886244067123958, 0.01930314571862774, 0.7832133216517312, 4.5362222109522135, 3.267670486654554, 79.14878531864711, 90.04074668884277, 86.75572872161865, 83.64629173278809, 81.54139750344413, 76.08053030286516, 70.99114159175328, 66.31472601209367, 62.66583783285958, 71.5529590334211, 78.86174828665597, 81.28174332209996, 81.38911383492606, 82.51934255872453, 79.22256823948452, 69.85620198931012, 61.1767554964338, 57.25065851211548, 57.23800931658064, 55.210823740277974, 60.793374742780415, 66.90833841051374, 72.5795762198312, 72.26339149475098, 75.43006774357387, 82.29900128500802, 77.9556337084089, 70.50469126020158, 69.6260290145874, 63.713070324489046, 75.93611894335065, 66.86657278878349, 68.36024788447789, 64.59551933833531, 62.55502796173096, 58.98878860473633, 62.71663611275809, 63.93673978533064, 65.13321958269391, 65.17268535069057, 72.22942175183977, 65.60400867462158, 58.675758361816406, 58.349033219473704, 56.35454586574009, 54.540207930973594, 59.85303333827427, 64.29364790235246, 62.49707998548235, 67.55132470812116, 64.17261028289795, 64.46050194331578, 64.82585212162563, 66.11899525778634, 63.034439768110005, 61.73423031398228, 58.816646984645296, 56.304348605019705, 57.91821016584124, 56.01980250222342, 56.339815684727256, 54.933948448726106, 57.89782762527466, 60.94919504438128, 61.60899598257882, 57.955765179225374, 65.93957887377057, 68.88115433284214, 65.18232945033482, 65.687150818961, 66.62963921683175, 63.413651602608816, 64.90315083095005, 65.34952395302909, 64.26156112125942, 58.22003296443394, 51.33740452357701, 50.15711055483137, 49.564345836639404, 48.14470379693167, 51.069763387952534, 63.41736194065639, 64.83054910387311, 64.65166078295026, 66.12202467237199, 66.76332950592041, 64.14478274754116, 65.7269639968872, 63.856738226754324, 62.02126734597342, 58.24704756055559, 57.00024196079799, 53.49821090698242, 50.42173269816807, 53.839169434138704, 54.23090192249843, 60.337336676461355, 64.52639171055385, 71.8013640812465, 66.97942543029785, 72.69058758871896, 19.090884344918386, 0.392906733921596, 0.30655596032738686, 0.9949591308832169, 0.04443980287760496, 0.12823156985853398, 0.2867566613214356, 1.043828200016703, 0.5151379236153194, 0.30062439718416756, 0.3206952730459826, 0.10267826675304345, 0.11577154988689081, 13.892718979290553, 48.66944912501744, 75.51140335627964, 78.30851187024797, 44.432910101754324, 60.375794955662315, 65.32120309557233, 56.19183642523629, 54.06247411455427, 32.96036073139736, 46.95277854374477, 61.15583447047642, 43.89779806137085, 0.13738503440150193, 0.08883914471204792, 0.0314617824873754, 0.014094041710320328, 0.07794343294309718, 0.0742746280240161, 0.08386523875274829, 0.08344085581068482, 0.09170657941805464, 0.1370004000408309, 0.07532505451568536, 0.15590739835585865, 0.07216889637389354, 0.02568866914537336, 0.08450754000140087, 0.03531365276181272, 0.08286964467593602, 0.06561731507203408, 0.05457652912342122, 0.04807346307539514, 0.10366630873509816, 0.03066715012703623, 0.11033271173281328, 0.17623470617192133, 0.556063844689301, 7.323005267551967, 81.96254171643938, 66.91222940172467, 71.7825483594622, 40.8463750566755, 32.84370742525373, 32.314345019204275, 61.34285218375069, 95.7963147844587, 74.6330815723964, 11.053606867790222, 0.27353005962712423, 0.15549695252307824, 1.3643695541790553, 2.863474884203502, 0.8287824849997247, 0.8663839644619397, 0.700962880892413, 0.3673090546258858, 0.27088846851672443, 0.1073202673079712, 1.8857387091432298, 5.246368059090205, 4.5151678664343695, 86.36860983712333, 91.67543547494071, 91.82320976257324, 86.1628806250436, 84.16607257298061, 78.84050069536481, 75.60392556871686, 67.04777485983712, 67.11990410940987, 71.94453866141183, 83.87280995505196, 82.85192503247941, 86.86824784960065, 85.56120136805943, 83.16351005009243, 74.28175980704171, 64.50431728363037, 59.45488766261509, 61.21348367418562, 58.85882255009243, 65.26838983808244, 68.80553708757672, 76.62677683149064, 75.72968101501465, 80.2162092753819, 87.09827491215297, 74.1796212877546, 74.33155059814453, 74.67540999821254, 66.67544174194336, 79.5048804964338, 73.01546451023647, 71.2972514288766, 67.68101978302002, 65.75158841269356, 62.672188486371724, 67.8394387108939, 67.7935458592006, 69.25698239462716, 69.93097850254604, 74.03124945504325, 65.75255421229771, 61.28803089686802, 60.43067182813372, 61.53854819706508, 59.72406782422747, 63.68902260916573, 65.7135261808123, 63.84400912693569, 69.95948001316616, 67.9999212537493, 66.96015112740653, 67.759888785226, 68.36006723131452, 65.37639958517892, 65.04717309134347, 60.516523769923616, 58.57273047310965, 61.536790302821565, 59.0288519178118, 59.110826764787944, 60.01183441707066, 62.21667848314558, 62.40805271693638, 64.84259033203125, 62.803558077131, 66.2703617640904, 72.46847452436174, 67.4645972933088, 67.44279384613037, 69.4289642061506, 64.14339310782296, 64.37496961866105, 68.17284802028111, 66.63303688594273, 60.606350081307546, 55.102581228528706, 54.587990692683626, 53.157613686152864, 50.666041782924104, 53.19989347457886, 67.04006930759975, 67.43918078286308, 67.243394442967, 70.34225627354213, 69.34425176892961, 67.35073716299874, 65.44713224683488, 63.47486523219517, 64.48404244014195, 61.648781367710654, 59.38373116084507, 56.844174998147146, 53.41370344161987, 57.9772698538644, 59.842624936785015, 63.74945109231131, 67.12269728524345, 75.7768245424543, 70.44056633540562, 78.60259437561035, 25.745200191225322, 0.23633331273283276, 0.27072369307279587, 0.9914176123482841, 0.43175728778753963, 0.3072980333651815, 0.44961888077003614, 1.2682527346270425, 1.3796820810862949, 1.3260863912957055, 0.8534968474081585, 0.3485526368021965, 0.06453031554285969, 15.132735320499965, 53.91714211872646, 83.79617827279228, 87.15045588357108, 56.15505961009434, 60.95906148638044, 53.84542628696987, 55.4401525088719, 58.680927821568076, 35.557646002088276, 53.91376529421125, 67.75306565420968, 52.39500720160348, 0.09363403956272773, 0.02916955209470221, 0.01340180282880153, 0.039237583455230506, 0.05408565314220531, 0.032074726918446164, 0.033696883624153476, 0.07882364892533847, 0.1208992525935173, 0.027576809882053306, 0.03578109892883471, 0.1060296462050506, 0.14396649838558265, 0.12164581753313541, 0.1753700761390584, 0.1425066167222602, 0.15848375510956558, 0.17044587965522492, 0.18840390603457177, 0.13498041486101492, 0.16955687664449215, 0.15682186000049114, 0.19046730388488087, 0.38002010541302816, 0.6916156538895198, 8.813140256064278, 96.52070617675781, 77.8707753590175, 85.37435735974992, 61.86343206678118, 56.45564562933785, 54.078170095171245, 76.42291668483189, 102.12096813746861, 85.1195182800293, 14.53861049243382, 0.42109077157718794, 0.13300766928919724, 1.672624756182943, 4.792048803397587, 1.7990893529994147, 0.8198513899530683, 0.7379627983484949, 1.1404559292963572, 0.3396966691528048, 0.33629796866859707, 2.0297974475792477, 9.26720677103315, 5.408214620181492, 88.77212374550956, 96.08724280766079, 96.91347394670758, 89.8757130759103, 88.68465287344796, 82.54940046582902, 79.4379415512085, 70.39657034192766, 69.68759005410331, 76.87486226218087, 88.25300298418317, 87.19583456856864, 88.00947557176862, 88.91490922655377, 87.29957117353166, 76.48787539345878, 68.9296041216169, 61.831630161830354, 65.5283566883632, 62.59413937159947, 67.48070321764264, 71.09848431178501, 80.13964707510812, 78.1988831928798, 84.14442198617118, 88.30867195129395, 76.72108473096574, 75.9609865461077, 79.00869573865617, 72.58607973371232, 77.50100612640381, 75.65127754211426, 76.1452249799456, 70.70060266767229, 71.73426532745361, 66.46683597564697, 71.54639298575265, 69.41856970105852, 73.72789110456193, 71.9906747000558, 77.43000248500279, 71.66271277836391, 63.772470474243164, 65.16987827845982, 65.8510171345302, 62.87786906106131, 65.19011838095528, 67.62459346226284, 65.52845396314348, 73.20707498277936, 71.14949798583984, 69.5736882346017, 70.51469666617257, 69.80946145738874, 66.64299365452358, 66.41036796569824, 64.71567453656877, 62.76071548461914, 64.5055957521711, 64.30952453613281, 61.81528799874442, 63.9944098336356, 66.3285390308925, 68.95764705113002, 68.43523979187012, 65.56275721958706, 69.36907768249512, 72.25171157291958, 70.54328850337437, 68.66288362230573, 72.54731573377336, 70.52156148638043, 69.41645050048828, 71.74898856026786, 70.69301523481096, 64.08581338609967, 57.4306446484157, 57.154346057346885, 56.4164890561785, 53.75169856207711, 56.78211368833269, 69.4119758605957, 71.55241012573242, 72.02498490469796, 72.8561840057373, 72.15135874067033, 69.1447342463902, 69.79564149039132, 71.36213370731899, 68.02926349639893, 63.32529830932617, 61.55262524741036, 59.187104088919504, 54.45091315678188, 59.69473252977644, 61.699489321027485, 68.07634449005127, 72.17737279619489, 80.38761438642229, 74.44292327335903, 84.1707626070295, 27.496271303721837, 0.6914402661578996, 1.0450004913977213, 3.0181298426219394, 0.9556303726775306, 0.7123879449708121, 0.6987972142440932, 3.676447340420314, 3.8144550664084296, 2.5199225076607297, 0.6352004068238395, 0.2571225129067898, 0.28804804916892734, 22.185811758041382, 64.71347195761544, 89.26580715179443, 96.3314858845302, 69.70813587733677, 84.64856937953404, 90.50442082541329, 70.02765573774064, 64.44201278686523, 46.1428895677839, 62.531779289245605, 78.12458610534668, 58.2118410382952, 0.23577479698828288, 0.190528290612357, 0.11452715737479073, 0.16832811757922173, 0.1991324403456279, 0.17377515243632452, 0.11393204145133495, 0.1793007209364857, 0.21866284949438913, 0.16416850792510168, 0.1419424962784563, 0.17581807209977082], [0.10026617654200111, 0.17007301109177725, 0.030592470562883785, 0.034034739780638895, 0.0669383548998407, 0.07926640659570694, 0.042568993621638844, 0.01943651008020554, 0.1441473008266517, 0.014069030061364174, 0.1409719062170812, 0.18115686705069883, 0.4543410502374172, 7.296277284622192, 69.90978649684361, 61.77452291761126, 54.432719298771445, 40.538191182272776, 42.21060173852103, 38.52336645126343, 65.07552868979317, 83.94627325875419, 37.93036549431937, 0.7755701403532709, 0.05408126641330974, 0.25856450838702066, 1.6214892715215683, 1.4736012071371078, 0.20521303692034312, 1.8383161681038993, 1.1719985795872552, 0.5831162759235927, 0.2848020190639155, 1.0121570080518723, 1.970926663705281, 0.7630234850304467, 32.69459908349173, 108.71345370156425, 80.9316166469029, 87.82369463784354, 75.94002383095878, 80.46990190233502, 70.87471062796456, 71.97279003688267, 64.71687657492501, 63.5204245703561, 63.76088087899344, 77.70173958369664, 77.88694381713867, 82.68270860399518, 79.44855145045689, 81.84451266697475, 74.74267550877163, 66.19122873033795, 55.89348772593907, 59.16803823198591, 55.51478658403669, 61.04514271872384, 63.367696217128206, 73.70206465039934, 69.9240164075579, 74.49599361419678, 71.59986632210868, 65.3825626373291, 66.33601529257638, 75.47805895124162, 71.95426613943917, 61.95389066423689, 66.5274520601545, 66.58150904519218, 65.00520597185407, 62.770665305001394, 65.55268927982875, 66.35938903263637, 67.36504350389752, 68.37056595938546, 68.34644181387765, 62.42895289829799, 59.04282474517822, 59.52261175428118, 57.84546947479248, 59.04288033076695, 59.98807157788958, 68.30209146227155, 61.282708576747346, 61.55584226335798, 67.80203655787876, 65.59989534105573, 64.74801840100969, 64.49853638240269, 64.52386256626674, 64.2953849520002, 65.51348059517997, 58.048832825251985, 59.553357533046174, 57.77864517484392, 60.0791346686227, 55.04680456433977, 55.5162387575422, 55.42255619594029, 57.902343954358784, 58.88000760759626, 63.53020763397217, 56.38990524836949, 59.22283867427281, 58.3259721483503, 55.398577962602886, 54.249596050807405, 56.70093788419451, 61.0074348449707, 63.1215215410505, 58.93320996420724, 56.98626913343157, 49.42665338516235, 47.65392473765782, 49.14229140962873, 49.89563594545637, 50.34321110589163, 60.381290980747764, 64.35894707271031, 63.46745845249721, 66.17355251312256, 64.95203835623605, 62.90312576293945, 60.73008360181536, 53.321796144757954, 61.540604863848, 63.5961251940046, 62.41946165902274, 55.3767397744315, 56.67920739310128, 53.83376373563494, 54.37799876076834, 54.778343541281565, 60.332389559064595, 66.39563083648682, 68.77818202972412, 68.66099371228898, 57.02308068956648, 8.347252249717712, 0.45552297681570053, 0.2651340572961739, 0.371065478771925, 0.14071334366287502, 0.1361386062843459, 0.25561657228640144, 1.1108737566641398, 0.3933894708752632, 0.6888978768672261, 0.28638710400887896, 0.24942016335470335, 2.630637275321143, 24.134970801217214, 66.78798866271973, 66.41045829227993, 65.85274028778076, 82.90393229893276, 80.58376203264508, 63.71771172114781, 33.04494115284511, 48.953321252550396, 54.35564988000052, 58.30913666316441, 44.42819227491106, 0.050931622207696946, 0.055219515692442656, 0.010105570462266249, 0.04544932727835008, 0.06942051742225885, 0.013329618577180164, 0.08267242168741566, 0.05572174695719566, 0.032030130204345496, 0.06416653256331172, 0.029229945104037012, 0.0751092532383544, 0.07102612126618624, 0.04566551192796656, 0.02661848094846521, 0.06290713085659913, 0.11797020690781729, 0.06341415936393396, 0.16509903727897576, 0.023374304940391864, 0.0997109856190426, 0.02418635190198464, 0.1694516630045005, 0.1341109536588192, 0.7200652158686093, 9.421848484448024, 81.16306809016636, 69.91626221793038, 66.09273106711251, 56.08034563064575, 56.26521635055542, 35.45028938565935, 75.00133609771729, 96.95118876865932, 47.76904944011143, 1.3700172454118729, 0.11492222760404859, 1.049565240740776, 1.6643903808934348, 1.9113391297204154, 0.22379280493727752, 1.6480180365698678, 1.0595156039510454, 1.4916734716721942, 3.495490627629416, 2.1174861022404263, 2.560364931821823, 0.17636088654398918, 39.22710084915161, 112.13765798296247, 86.6258043561663, 92.34000287737165, 79.07821941375732, 83.76631491524833, 74.80735628945487, 75.4666222163609, 64.5154413495745, 64.89386108943394, 67.23923942020961, 80.91339152199882, 81.79814038957868, 86.51219436100551, 83.35002749306815, 83.92337199619838, 77.82131808144706, 68.9677983692714, 57.58383853094918, 61.23464788709368, 58.071136542728965, 63.99521582467215, 67.7973187310355, 76.61395045689174, 71.2052503313337, 76.21464443206787, 71.48911203656877, 68.75743470873151, 68.922621182033, 76.09965174538749, 71.54009791782924, 69.25713525499616, 70.15008994511196, 69.93860067640031, 68.46524211338588, 67.60667405809674, 69.16601657867432, 70.52378490992955, 71.7215918132237, 72.72726712908063, 69.75328527178083, 65.20163154602051, 62.10083811623709, 63.37982777186802, 62.79863180433001, 63.46381064823696, 66.05110440935407, 72.97164222172329, 61.33952399662563, 63.88462134769985, 69.06850555964878, 68.37708336966378, 67.73577158791679, 69.45269230433873, 69.14178821018764, 66.82883712223598, 66.20906475612095, 61.57843085697719, 62.4677585874285, 60.88493115561349, 62.83572823660714, 57.65196214403425, 59.94568061828613, 58.943034717014854, 61.03412982395717, 62.735688073294504, 65.29434830801827, 62.63491140093122, 62.78592354910714, 61.01206929343087, 54.71177632468087, 55.21096270424979, 59.71190847669329, 65.31779153006417, 65.57192884172711, 61.02900205339704, 58.489984376089915, 52.264690262930735, 51.71181862694876, 51.26283645629883, 50.90394115447998, 53.17594998223441, 63.43504510607038, 66.98053714207241, 65.77287074497768, 69.80673081534249, 67.34296907697404, 64.7922923224313, 62.248070444379536, 58.34479481833321, 64.71320792606899, 66.782395362854, 64.83414132254464, 59.62258243560791, 58.02348232269287, 56.382699966430664, 57.55416277476719, 59.056700297764365, 65.46128572736467, 69.15248843601772, 71.52489525931222, 75.12311022622245, 65.7830707005092, 13.571567160742623, 0.21532519002045902, 0.5140360370278358, 0.6446845893348966, 0.26925455619181904, 0.45346242881246973, 0.658950001001358, 2.2350606960909705, 1.0108925444739205, 1.5335138951029097, 0.9755403271743229, 0.4948266020842961, 1.5466083181755883, 29.872056688581193, 70.11086041586739, 75.87748309544155, 77.28309672219413, 95.8579661505563, 77.93474742344448, 66.99970722198486, 37.50325972693307, 45.75299487795149, 60.68745640345982, 67.02376883370536, 52.77216236931937, 0.1968188937753439, 0.031230636140597717, 0.10735527971493346, 0.014621369440906813, 0.0684164280870131, 0.018366499371560555, 0.05082080386845129, 0.05434777121990919, 0.028827536518552473, 0.08607089146971703, 0.07301464956253767, 0.006233570174247558, 0.2004287950694561, 0.28782464829938753, 0.17190691482807907, 0.11585030066115515, 0.19361843408218452, 0.10203193500638008, 0.23467065766453743, 0.08929546629743916, 0.1515669726899692, 0.24939003639987536, 0.38940744740622385, 0.2260330290134464, 0.9422705067055566, 10.684832096099854, 94.19991752079555, 80.20942088535854, 76.83657768794468, 61.46326446533203, 62.690378870282856, 56.67830760138375, 91.34144251687187, 101.72458730425153, 60.1891941343035, 1.9445790946483612, 0.12716713840407984, 0.5901415018098695, 4.286541734422956, 5.43832984992436, 0.967557389821325, 5.375684022903442, 3.4600982410567145, 2.8409811769212996, 3.2041691626821245, 2.988086049045835, 6.416421251637595, 0.849976119186197, 40.496849400656565, 115.43591921670097, 90.725234576634, 96.93706308092389, 81.62795121329171, 88.35333497183663, 79.0776149204799, 78.65324674333844, 68.4035837990897, 68.28421374729702, 70.91943618229458, 84.48603016989571, 84.5546783719744, 88.10780647822789, 86.62390749795097, 85.07703699384416, 79.82443509783063, 72.00016593933105, 60.61716842651367, 64.80521597181047, 62.09424427577427, 67.6798872266497, 70.30413150787354, 81.29011590140206, 76.42534160614014, 82.23992770058769, 75.72245488848004, 74.25221606663295, 72.94729573386056, 79.24503871372768, 76.5243673324585, 68.74028655460903, 71.76717199598039, 73.25314848763603, 71.71557467324394, 70.26490892682756, 73.16947133200509, 74.74847030639648, 75.98206043243408, 76.44558865683419, 73.65277412959507, 68.86955778939384, 65.56484862736293, 68.52772726331438, 67.64673042297363, 66.79432541983468, 67.86381993974958, 76.10612746647426, 63.68369334084647, 64.77498435974121, 70.44986302512032, 71.54741437094552, 71.33941309792655, 72.74948746817452, 71.26413631439209, 70.74920531681606, 68.94597407749721, 63.41860566820417, 64.62445858546666, 65.24171570369175, 64.2100054877145, 63.32359600067139, 61.96754387446812, 64.25048569270542, 64.63139983585903, 67.86142975943429, 69.66224302564348, 67.86583491734096, 66.87426444462368, 62.12826265607561, 55.941471985408235, 57.356903416769846, 59.82704707554409, 66.19305610656738, 68.97298172542027, 65.34221444811139, 62.35446126120431, 55.55703510556902, 54.63868127550398, 55.01391526630947, 55.55384588241577, 55.80044787270682, 67.19909967694963, 70.09289932250977, 70.44478389195034, 70.97020666939872, 70.69432149614606, 68.22963564736503, 65.33901132856096, 58.82912594931466, 65.5129942212786, 70.00673471178327, 68.46429021017892, 60.69680173056466, 60.27524757385254, 58.69450460161482, 60.332174164908274, 61.34523541586739, 69.14899349212646, 73.46857738494873, 77.20068413870675, 78.93593420301164, 69.5855210168021, 13.08523234299251, 0.6608642297131675, 1.5318515385900224, 1.0481592076165336, 0.630941703915596, 0.4029279090464115, 0.6272213778325489, 4.461264610290527, 4.924987818513598, 1.5323594084807803, 0.702161933694567, 0.37475964054465294, 3.8001365661621094, 42.45179803030831, 77.11658314296177, 83.53717722211564, 80.52997602735246, 97.84549835750035, 99.20198127201625, 71.16410309927804, 41.698370116097585, 69.02710819244385, 67.95199257986886, 76.60871846335274, 60.72483076368059, 0.31794202221291407, 0.11217958227332149, 0.17275983334652015, 0.12248428325567927, 0.21199842781892844, 0.0637827328007136, 0.13365081192127296, 0.09737626197082655, 0.1529093999415636, 0.13994659909180232, 0.18216564506292343, 0.17264209395008429], [0.02536798331753484, 0.04973271529057196, 0.07082809760634388, 0.05642343698335545, 0.0765476253415857, 0.02778775624132582, 0.030873848857092004, 0.05290916162942137, 0.11221083559628044, 0.03171242993058903, 0.019812771318746463, 0.10311849348779235, 0.14967854187956878, 2.394278232540403, 54.02461338043213, 59.76492323194231, 52.57915530885969, 19.43725551877703, 23.41836312838963, 48.377899238041465, 79.6848110471453, 67.11615208217076, 12.931189911706106, 0.21385533389236244, 0.05910491916750159, 2.631793064730508, 1.688261242849486, 2.745472324745996, 0.648318768611976, 1.832639706986291, 0.7685930633119175, 6.041720100811549, 12.493066038404192, 0.5926409534045628, 0.6796774002058166, 16.6149354662214, 103.18681485312325, 87.10903767177037, 86.28166702815464, 80.6014243534633, 80.2229837690081, 73.52998556409563, 77.36202130998883, 76.12655517033168, 70.0157117843628, 61.72158459254673, 60.42896951947893, 71.36648327963692, 78.98801095145089, 80.27958379473004, 82.63892800467355, 80.53668103899274, 75.7058903830392, 71.08430303846086, 61.6067795072283, 56.03757946831839, 55.425634247916086, 56.34060083116804, 61.266491481236045, 66.38985688345772, 65.86009843008858, 63.94657148633684, 61.094877924237935, 61.96493135179792, 64.23599175044468, 69.47257804870605, 69.7812031337193, 67.35827595846993, 61.28200680868966, 64.21773188454765, 67.0122904096331, 66.67141873495919, 68.35298701695034, 71.37400817871094, 67.30341298239571, 66.19459860665458, 61.35480308532715, 59.51181425367083, 58.951157161167686, 58.52487128121512, 59.0201666695731, 62.6680543082101, 69.40808486938477, 65.61964212145124, 61.97882774897984, 64.42746325901577, 65.67488724844796, 65.37697628566197, 64.99335929325649, 62.8514381136213, 66.31104346684047, 64.17668887547084, 62.86047077178955, 62.97672803061349, 63.184409686497276, 60.778915541512625, 57.40966803686959, 58.81195000239781, 60.300719669886995, 55.99424007960728, 56.93594333103725, 53.729116916656494, 57.76505102430071, 63.37403992244175, 63.57480117252895, 61.995392254420686, 61.13192571912493, 50.20752668380737, 53.803945541381836, 71.1737402507237, 61.36070210593087, 58.3072953905378, 51.047063623155864, 49.3480657849993, 48.3095463344029, 49.209400585719514, 45.5101831299918, 47.95551129749843, 56.50878197806222, 64.81037153516496, 61.852203777858186, 63.487768036978586, 63.98998383113316, 63.37332425798689, 64.50524139404297, 66.99724755968366, 66.68598910740444, 67.00963619777134, 60.38207612718855, 60.48902974809919, 56.8594262940543, 55.26279279163906, 55.54108551570347, 61.18228626251221, 58.41932119641985, 64.65606594085693, 64.95388657706124, 69.95139925820487, 72.03754724775041, 47.90737765175955, 4.003613259111132, 0.16266610925751074, 0.10227806001369442, 0.15821618161031178, 0.06704675765441996, 0.28559229522943497, 1.5816111713647842, 0.535864128598145, 2.1186655589512418, 0.4948305104460035, 0.11981869914702006, 0.10611440201422997, 8.84007842200143, 50.64015279497419, 77.14678696223667, 108.94710772378104, 101.4960332598005, 102.33862740652901, 16.824977772576467, 21.77672961780003, 47.40279252188546, 49.27953917639596, 58.59334577832903, 41.73304510116577, 0.07971302513033152, 0.07892868614622525, 0.05307005246036819, 0.1406435224094561, 0.02814594130696995, 0.09455187352640287, 0.028091093625075052, 0.08760121185332537, 0.0757719376789672, 0.027809413382783532, 0.010884219082072377, 0.020595756625490527, 0.009397962762575065, 0.04509551876357623, 0.027366028067522814, 0.0958752678707242, 0.08406750325645719, 0.034820086389247856, 0.0324125762895814, 0.03762187283220036, 0.04572704487613269, 0.09128732620073216, 0.04476873629859515, 0.09527332588498082, 0.14070596120187215, 3.4834498337336948, 65.21865463256836, 69.04047652653286, 60.12012904030936, 28.79061300413949, 28.8705780846732, 41.12796817507063, 90.36980642591203, 77.59775284358433, 15.783922229494367, 0.21340744649725302, 0.32185160528336254, 4.680411662374224, 1.9376645513943263, 2.149816070284162, 0.27473402502281324, 0.5210250020027161, 1.1163324351821626, 6.427931811128344, 10.931306413241796, 0.46424790578229086, 0.195861263732825, 21.42983385494777, 106.50861658368791, 91.68949862888881, 91.61867564065116, 83.14768205370221, 83.42642293657575, 77.88116986410958, 79.35483414786202, 77.11093425750732, 73.74244063241142, 65.40688828059605, 63.632248878479004, 73.59837668282645, 84.03215299333844, 82.0273197719029, 83.56875678471157, 82.66458770206997, 80.09494931357247, 75.60484967912946, 64.29769175393241, 59.53971821921212, 59.08435412815639, 58.12785816192627, 65.17907074519566, 67.38217081342424, 68.5537691116333, 65.62233802250454, 63.254093170166016, 61.48501927512032, 66.77043751307896, 70.07523700169155, 72.34140586853027, 73.46274784633091, 62.89639295850481, 65.39935643332345, 70.64138317108154, 70.22224003928048, 71.9452543258667, 73.67167322976249, 68.95692443847656, 68.02702617645264, 65.00354535239083, 64.41709654671806, 64.27113573891776, 62.67773314884731, 63.54844665527344, 65.88832896096366, 71.13112694876534, 67.39656053270612, 62.89969335283552, 66.8470344543457, 67.99253531864711, 67.5044869014195, 66.03361579350063, 67.44893605368478, 68.59828622000558, 64.56217493329729, 65.49208014351981, 64.18367181505475, 65.62612479073661, 63.37397738865444, 58.62802423749651, 61.56461088997977, 64.11179270063127, 59.522847993033274, 58.605671882629395, 57.6978098324367, 60.448744092668804, 66.99562862941197, 67.94303635188511, 65.5199146270752, 64.10512937818254, 52.93560137067522, 57.923737457820344, 73.4084963117327, 62.388966015407014, 62.33850819723946, 54.284205027988975, 52.52844040734427, 51.21255929129464, 50.63551139831543, 48.93211882455008, 49.820845535823274, 58.55522101266043, 67.18873296465192, 65.87532888139997, 66.13262067522321, 67.24244948795864, 68.7131746837071, 67.12899235316685, 68.35418905530656, 68.96424783979143, 68.28656223842076, 63.59645175933838, 63.75311974116734, 60.530475752694265, 57.328679834093364, 57.506126403808594, 63.639718191964285, 60.63710280827114, 68.1277403150286, 70.18489347185407, 73.23764705657959, 75.65496008736747, 56.201824460710796, 6.142919310501643, 0.14052243105002812, 0.08016414235212974, 0.37791409556354794, 0.19800205528736115, 1.0475989005395343, 1.089504029069628, 1.0021116499389922, 1.584143681185586, 1.636433761034693, 0.710474313369819, 0.19281513004430703, 8.797889828681946, 55.991036960056846, 83.40505027770996, 109.82267802102226, 103.9081698826381, 106.90562970297677, 25.369620527539933, 23.77226962362017, 51.95677042007446, 56.64771120888846, 66.65678582872663, 48.6954597064427, 0.19306189965988907, 0.0021145256760064512, 0.05847880097904375, 0.049344542369778664, 0.10287921489881617, 0.08759456221014261, 0.007226470891120178, 0.06542801058718137, 0.08264369930007628, 0.045343014411628246, 0.06098733815763678, 0.04377409556348409, 0.12500608579388686, 0.1533122868942363, 0.13609963123287472, 0.14111268866275037, 0.11811394776616778, 0.12246908407126154, 0.11388082562812737, 0.10330670553126506, 0.12431805128497736, 0.18777508049138955, 0.12353880809886114, 0.13286759251994745, 0.26299314360533443, 5.029231641973768, 77.74457522800991, 77.24951607840401, 69.41299029758999, 33.84886857441494, 34.189858368464876, 69.53976712908063, 98.2136903490339, 88.21381514413017, 22.091748782566615, 0.5804378539323807, 0.15891413630119391, 7.606744510786874, 4.707996445042746, 6.933028502123697, 2.3258525899478366, 7.801178557532174, 4.337677436215537, 8.951329503740583, 17.442257472446986, 3.1155001606260027, 0.7534616238304547, 20.706515959330968, 111.4854792186192, 94.75087492806571, 95.65191037314278, 88.02141952514648, 87.97599220275879, 80.00881944383893, 83.46084431239537, 79.67294352395194, 79.3912843976702, 68.34103611537388, 65.7813892364502, 78.04239586421421, 89.21138191223145, 85.67426245553153, 86.22707503182548, 83.28467273712158, 81.94529628753662, 77.90489101409912, 67.88922950199672, 61.75859069824219, 62.46147741590227, 61.299988746643066, 69.79448114122663, 71.20279066903251, 74.12463324410575, 70.63869421822685, 66.33433382851737, 66.95680209568569, 71.37590503692627, 75.86061981746128, 78.84510735103062, 70.97837080274309, 70.01256425040108, 72.36808000292096, 75.38395949772426, 74.83958898271833, 75.75356197357178, 76.15047781808036, 71.98080130985805, 72.229400907244, 68.62026337214878, 67.26901939937046, 68.27967657361711, 68.30311979566301, 68.85911464691162, 70.8478558404105, 73.08029815128872, 70.19598279680524, 65.46762943267822, 68.92387185777936, 69.41685349600655, 70.99109295436314, 69.66908700125558, 68.12370341164726, 71.36230741228376, 69.46816594260079, 67.64871065957206, 66.64816311427525, 69.20473194122314, 66.03748594011579, 62.64789758409773, 63.09598691122872, 67.09232670920235, 62.70804813929966, 63.437678473336355, 60.97116524832589, 64.84943430764335, 68.33401843479702, 71.9726927621024, 68.49008887154716, 65.59651851654053, 53.54667806625366, 59.98249217442104, 71.89577620370048, 66.1046541758946, 66.17968777247837, 56.316045897347585, 55.38387210028512, 53.52777549198696, 53.332128116062705, 51.2142060143607, 53.482441970280235, 63.04897539956229, 72.14910057612828, 68.56503214154924, 70.43147114345005, 71.91448075430733, 71.58228043147496, 70.83078411647251, 69.74838679177421, 71.78211062295097, 71.31595597948346, 68.06169073922294, 66.56699425833565, 64.64727646963937, 59.065010343279155, 61.022588866097585, 67.13962309701103, 64.20010430472237, 73.83771433149064, 74.48197909763881, 79.18016338348389, 80.10005623953683, 59.88636384691511, 4.938560255936213, 0.6083886112485613, 0.805731781891414, 0.36381221083658083, 0.15599395228283747, 1.3612688119922365, 3.6568251933370317, 3.4974930116108487, 6.23436324937003, 2.7517259206090654, 0.39087628573179245, 0.3444907361907618, 15.132978507450648, 67.58312661307198, 88.00512599945068, 108.99215984344482, 98.43894399915422, 108.6499193736485, 23.96418755395072, 31.73164824077061, 63.88330118996756, 65.14738695962089, 77.16761766161237, 56.14368540900094, 0.31103879692299025, 0.14602448152644293, 0.09134440456650086, 0.17949395413909638, 0.15532601598118032, 0.13957777459706577, 0.14212914769138607, 0.14139983111194201, 0.10942757994468723, 0.12597105758530752, 0.1174412617193801, 0.12121699697204999], [0.03831709302695734, 0.003493479315823476, 0.06965970101633243, 0.04668030176045639, 0.03437390211703522, 0.032121420305754454, 0.09875251419310059, 0.024873689216162478, 0.03200711090383785, 0.04761008811848504, 0.06482087780854531, 0.06960848519312483, 0.07615584600716829, 1.0808552588735307, 49.32082884652274, 56.92028209141323, 46.95500544139317, 56.44959374836513, 57.357226508004324, 61.70529106685093, 78.94795458657401, 44.062574590955464, 2.9787774171148027, 0.06159929532025542, 0.354711509176663, 2.701043805905751, 1.5943204036780765, 0.7419364622661045, 0.23190646884696825, 1.0611165123326438, 0.6804919679250035, 4.700216199670519, 1.2679786064795084, 0.08049232259924922, 16.354148728506907, 98.28172710963658, 85.14974989209855, 83.14406204223633, 84.63564573015485, 82.74275493621826, 78.45455605643136, 82.13334928240094, 83.78778484889439, 78.24811117989677, 74.37902069091797, 62.51382514408657, 61.31407274518694, 67.15235219682965, 71.81241171700614, 76.88026796068463, 80.13171223231724, 77.5384360722133, 79.36319283076695, 72.59514713287354, 64.29742077418736, 54.838438510894775, 55.959978512355256, 54.824708870479036, 56.14326156888689, 57.17861611502511, 57.37740060261318, 56.3031986781529, 55.56806189673287, 54.026753425598145, 61.77466188158308, 64.94125475202287, 76.01080513000488, 62.63795471191406, 53.65124498094831, 54.57895108631679, 61.91791984013149, 69.31652845655168, 70.07297883714948, 71.06705066135952, 65.02802385602678, 63.06906264168875, 64.21173558916364, 65.98863315582275, 58.81110232216971, 61.708216258457725, 61.84651320321219, 65.95274571010044, 68.1196595600673, 63.782211848667686, 64.7657779966082, 64.57891314370292, 63.19314357212612, 62.03855446406773, 60.31494263240269, 62.81349400111607, 62.14168657575335, 61.802176748003276, 64.305070740836, 65.7652416229248, 61.59480776105608, 61.23549556732178, 59.51180730547224, 58.47810990469796, 56.48514073235648, 56.376946857997346, 53.2810241154262, 53.61707721437727, 57.153790201459614, 55.698031425476074, 56.46947601863316, 62.972183908735005, 62.2231194632394, 65.52425030299595, 55.456279277801514, 60.443685804094585, 67.61261476789201, 54.729497705187114, 55.17755576542446, 47.49375138963972, 50.43678944451468, 48.88318266187395, 52.17717770167759, 45.66454083578927, 49.20775038855416, 53.30411645344326, 58.867403575352256, 60.25108173915318, 60.38652992248535, 62.793698583330425, 64.41270528520856, 64.62251308986119, 62.603894642421174, 65.55555888584682, 63.811720848083496, 61.2872040612357, 59.893854004996165, 55.75830704825265, 57.68061304092407, 56.304869719914024, 54.52511644363403, 56.13236679349627, 61.52615261077881, 67.9631791796003, 67.28256838662284, 73.00977393559047, 35.645856857299805, 0.482907130249909, 0.300187203500952, 1.096778467297554, 0.6347931772470474, 1.2085263452359607, 1.1261279838425773, 0.36319384830338614, 0.9809163872684751, 2.0773183490548814, 0.40801496750542093, 0.0492614896834961, 0.9229449608496257, 24.506600414003643, 66.35811056409563, 80.73791476658413, 94.3308493750436, 50.92917701176235, 21.14190571648734, 43.160781792231965, 47.29003715515137, 56.271969999585835, 59.31181730542864, 51.43522473743984, 0.2691312256668295, 0.13348662001746042, 0.10433560210679259, 0.05697605625859328, 0.08181974065623113, 0.054902368424726386, 0.10457205799009119, 0.08907840294497353, 0.0954602894240192, 0.04644347607557263, 0.07045134103723935, 0.04608281435711043, 0.06342456809112004, 0.043082067875989845, 0.012668176703820271, 0.0478463166925524, 0.044857509035084925, 0.10337106457778386, 0.05223583097436598, 0.042474799390350065, 0.014759597202230777, 0.007496445556171238, 0.03453716442787221, 0.03697842485936625, 0.16152534261345863, 1.3841757199593951, 57.975602286202566, 67.81816332680839, 47.83006852013724, 49.19066824231829, 39.78659759249006, 51.09838996614729, 95.03170027051652, 53.60335104806082, 3.9664095640182495, 0.1342590507119894, 1.0646676932062422, 4.529594498021262, 2.281689839703696, 1.668718240090779, 0.3351034213389669, 0.776922270655632, 0.7476908192038536, 5.6078459194728305, 0.966355351465089, 0.1532675442951066, 21.88514757156372, 103.81000573294503, 87.80101571764264, 90.1374100276402, 89.36213697705949, 84.3664516721453, 84.076155935015, 86.14809485844204, 84.26270811898368, 81.6784507206508, 77.7939213344029, 65.16706425803048, 64.23538030896867, 69.09549236297607, 75.35913358415876, 80.65243107931954, 82.08647673470634, 81.12585353851318, 81.8682963507516, 77.01265893663678, 68.1631691796439, 58.767898423331125, 59.02500261579241, 58.389020102364675, 57.12652199608939, 59.255842617579866, 59.49170616694859, 56.58645241601126, 57.93789093835013, 57.11570712498256, 66.28418867928642, 69.25750350952148, 79.93887192862374, 68.47956929888043, 60.760815484183176, 60.27423313685826, 63.02779729025704, 71.20757797786167, 71.45362063816616, 72.6359886441912, 66.90444047110421, 66.5438984462193, 67.14401435852051, 68.03529453277588, 61.6045560836792, 65.70850263323102, 64.48248604365757, 69.65772669655937, 69.26766177586147, 64.6832195009504, 66.1531456538609, 65.64723341805595, 65.07787023271833, 65.33311925615583, 62.42186573573521, 65.45897197723389, 63.79906817844936, 65.81930555616105, 68.98685032980782, 67.94846984318325, 63.36847441537039, 62.91248498644148, 62.31313337598528, 62.24429062434605, 59.91055052621024, 59.96931838989258, 57.14221797670637, 56.350210189819336, 60.09604658399309, 59.02881717681885, 59.9141913822719, 65.0413088117327, 63.35345935821533, 69.1531902040754, 57.015472412109375, 63.72546591077532, 70.3233710697719, 57.744532993861604, 57.57722037179129, 51.403707708631245, 52.99156216212681, 52.31169830049787, 54.33269650595528, 50.28237962722778, 51.933688504355295, 56.07426595687866, 61.050826345171245, 63.35292434692383, 64.54317161015102, 65.24579429626465, 69.21211787632534, 66.13262067522321, 65.31511647360665, 66.78252737862724, 69.38412748064313, 63.93148694719587, 63.61114719935826, 59.80739756992885, 62.00163173675537, 60.089744567871094, 56.623243127550396, 59.545881271362305, 65.43691144670758, 71.86821964808873, 71.31567110334123, 76.83354827335903, 44.11471734728132, 1.3251641264983585, 0.3399735657232148, 0.45683672917740686, 0.9375343322753906, 2.7927849973951067, 1.786175474524498, 0.7491421241845403, 1.3090533167123795, 4.416755752904074, 1.562066865818841, 0.11212830538196222, 0.6056141629815102, 25.58582762309483, 72.44612911769322, 87.32869107382638, 95.19686589922223, 58.657199723379954, 25.120788165501185, 41.15346458980015, 51.265403815678184, 60.97503539494106, 66.60706451960972, 59.481318610055105, 0.35790073232991354, 0.08580354867236954, 0.07046270649880171, 0.1115348654400025, 0.11409574480993406, 0.06821057413305555, 0.09244747859026704, 0.1080895835267646, 0.04096127953380346, 0.056385578121989965, 0.06737660709768534, 0.07178352241005216, 0.16215747940753186, 0.06870355696550437, 0.09578079544007778, 0.10570394939609937, 0.22808216405766352, 0.14631933213344642, 0.2567676933748381, 0.13462403469852038, 0.13857443843569073, 0.21069237004433358, 0.14371677035731928, 0.0941793035183634, 0.2190354195024286, 2.477800573621477, 71.91286877223423, 74.21957342965263, 62.430856704711914, 73.22717612130302, 76.41505827222551, 90.47063868386405, 99.43185547419957, 68.23588902609688, 5.552664629050663, 0.1289233634514468, 0.6280509276049477, 9.896303619657244, 4.9784581150327405, 4.490138283797672, 2.046712185655321, 2.372187086514064, 0.6412009362663541, 8.677825825554983, 2.472998934132712, 0.5753258253846849, 23.533142157963344, 105.44242245810372, 89.27430479867118, 92.72706617627824, 93.2467497416905, 87.16875743865967, 86.56783553532192, 88.43216923304966, 86.51345198495048, 83.73380429404122, 82.91292326790946, 68.49846839904785, 69.43676703316825, 74.59328229086739, 78.53251484462193, 84.44675200326103, 86.74598039899553, 82.52456760406494, 84.71982315608433, 79.96774864196777, 71.16698660169328, 63.032424790518625, 62.032634598868235, 61.97718102591378, 63.126030921936035, 61.63867173876081, 63.436691829136436, 60.7581056867327, 60.497367586408345, 61.08628300258091, 69.92433602469308, 72.19413185119629, 81.61556952340263, 70.80603463309151, 62.80576760428292, 61.879155840192524, 66.17235742296491, 74.70838614872524, 75.43011638096401, 77.54803848266602, 69.60624054500035, 70.43997573852539, 71.43031638009208, 72.11177485329765, 65.73576736450195, 71.04019587380546, 69.27766023363385, 73.5420754296439, 72.31204278128487, 66.48161479404995, 68.80584975651333, 68.28223351069859, 66.69101960318429, 67.98503821236747, 63.190593583243235, 68.22102682931083, 65.15747574397496, 67.60107381003243, 71.54884569985526, 71.09988784790039, 66.38186645507812, 66.74839087894985, 62.5836614881243, 65.84808499472481, 64.61015919276646, 63.21287645612444, 61.09690679822649, 59.324178150721956, 64.47663566044399, 62.72425133841378, 63.612543787275044, 70.24810123443604, 68.43296078273228, 71.39446367536272, 61.865419251578196, 66.77663530622209, 71.75114250183105, 62.603519439697266, 60.40830557686942, 54.12364952904837, 58.3865395954677, 57.61759982790266, 56.274474825177876, 52.34781503677368, 55.89767401559012, 60.3484468460083, 64.51277324131557, 67.15365845816476, 66.66171904972622, 70.25938510894775, 72.48916625976562, 69.98561218806675, 69.18351214272636, 71.19919845036098, 72.1175696509225, 67.74633284977504, 67.38647869655064, 60.14479514530727, 64.06577478136334, 61.980592591421946, 62.33221312931606, 62.9893251146589, 69.62767573765346, 75.93611199515206, 77.06349890572685, 81.45578180040631, 46.289600781032014, 1.284268549510411, 1.482022532394954, 2.156130462884903, 1.611805871129036, 3.500307466302599, 4.593400239944458, 0.6437127100569862, 6.198833201612745, 7.237340927124023, 1.2875380026442664, 0.176308666488954, 1.6177624315023422, 36.91750226702009, 78.6830336706979, 88.17262622288295, 102.2492596762521, 63.38608809879848, 32.283449854169575, 56.33188084193638, 63.031403405325754, 72.51435347965786, 74.70069449288505, 69.40754985809326, 0.47248103256736484, 0.16039408903036798, 0.21149784539427074, 0.19420276129884378, 0.20694111633513654, 0.12795957231095859, 0.21201704681984015, 0.23468129709362984, 0.14611703370298657, 0.14768444959606442, 0.1868385121758495, 0.14738794336361544], [0.08872701680021626, 0.05164245888590813, 0.053980486999664984, 0.04906162380107811, 0.08958230340587241, 0.03146131769088762, 0.050038992427289486, 0.07436071376183204, 0.09571155094142471, 0.05161595870075481, 0.06737374367990664, 0.05022577276187284, 0.06810771500957863, 0.21841005448784145, 39.952718598502024, 62.16002982003348, 58.80632890973772, 55.741388184683665, 46.7084173474993, 64.94930076599121, 71.74793938228062, 24.19503971508571, 0.22757133575422422, 0.24811126930373056, 1.8459974016462053, 2.6081767891134535, 0.9582765506846564, 0.5183452229414667, 0.03448664749573384, 0.14469424076378345, 0.654421404004097, 2.4404542233262743, 0.3823445221143109, 10.95191216468811, 81.40758909497941, 73.9639561516898, 75.15045138767788, 82.51374231066022, 86.88090051923479, 82.83701419830322, 86.696286882673, 79.86503342219761, 84.11694880894252, 81.62522057124546, 82.02869551522392, 65.60374464307512, 58.083657196589876, 61.762710980006624, 72.72399452754429, 76.73687103816441, 77.26309285845075, 76.09926959446499, 76.48337296077183, 74.91871506827218, 67.64986406053815, 55.71495028904506, 52.74002000263759, 55.442483629499165, 52.56219823019845, 54.7993757384164, 53.71099601473127, 55.85611683981759, 55.81204441615513, 59.288179533822195, 64.27364403860909, 68.90320791516984, 67.28617450169155, 57.53378023420061, 67.11393560682023, 62.03371156964983, 68.27008805956159, 67.80089705330985, 65.41806098393032, 60.899730818612234, 62.5103371483939, 62.77994809831892, 64.80461842673165, 60.51859433310372, 61.728025572640554, 59.71999617985317, 63.29157175336565, 64.45201819283622, 62.79715183803013, 62.19792529514858, 64.61284814562116, 62.70476164136614, 62.936303411211284, 62.47831290108817, 63.79445457458496, 62.21199539729527, 65.98069136483329, 64.92174421037946, 55.161825043814524, 58.851652009146555, 64.97038854871477, 60.20468861716134, 58.87482425144741, 60.29142992837088, 56.244451659066335, 55.76188884462629, 52.97676944732666, 54.85593407494681, 58.18019546781267, 54.8767717225211, 56.02994687216622, 53.96147509983608, 59.44244343893868, 62.115477970668245, 64.45797279902867, 55.93884904044015, 64.5456382206508, 58.218987260546, 55.35551997593471, 50.97764764513288, 48.962538037981304, 49.84730775015694, 50.799732072012766, 51.28898252759661, 50.119982855660574, 48.24481691632952, 49.88359471729824, 54.584825788225444, 55.71804223741804, 56.607689585004536, 60.71854959215437, 63.990178380693706, 63.766974449157715, 64.50262192317417, 66.21999427250454, 64.31197030203683, 62.990464619227815, 63.67673124585833, 63.27053260803223, 57.46058791024344, 60.62256022862026, 60.613346917288645, 52.842193262917654, 64.2907018661499, 69.0358281816755, 68.6734379359654, 70.14261368342808, 11.974348272596087, 0.2414310106209346, 0.6132847570947239, 2.3248513979571204, 1.1711299461977822, 1.367598186646189, 0.2744228760046618, 0.6796975391251701, 1.7071077972650528, 1.7966926587479455, 0.18804954790643283, 0.09841948242059775, 6.973704125199999, 37.77103287833077, 76.77627427237374, 69.46098845345634, 36.52440445763724, 35.8260931287493, 31.29982464654105, 48.69692925044468, 49.55703633172171, 59.56047943660191, 44.4851153918675, 0.28220038009541376, 0.02078990076136376, 0.09589164770607438, 0.0770765637446727, 0.054261980644826374, 0.0031490038381889462, 0.04842142940365842, 0.036390498014433045, 0.03517679903390152, 0.04403977255736079, 0.028333978627675345, 0.0576229172625712, 0.05381430359557271, 0.04439666162111929, 0.031164234703672782, 0.04100214769797666, 0.08775443863123655, 0.05576691024803689, 0.05083803526524987, 0.02853476901405624, 0.043860924297145436, 0.12015397687043462, 0.08035785052925348, 0.027213617227971554, 0.15454549714922905, 0.4558931312390736, 48.55439043045044, 71.76018905639648, 60.214513369968955, 51.09255347933088, 33.324064186641145, 67.6527406147548, 83.44940757751465, 28.26329857962472, 0.24273814048085893, 0.6222901652966226, 3.624084847314017, 4.141777319567544, 2.287340896470206, 1.4768238684960773, 0.4355958146708352, 0.1566235242145402, 0.8258753695658275, 4.394287884235382, 0.2634649697159018, 15.801278829574585, 89.45575700487409, 77.18075670514787, 83.6604313169207, 85.71273463112968, 91.65942682538713, 85.61385481698173, 90.38644736153739, 84.25283472878593, 87.84826346806118, 83.06510966164726, 86.292311668396, 70.08522156306675, 59.46151624407087, 65.5842479978289, 74.49443026951381, 79.32107979910714, 78.20182922908238, 80.1473387309483, 78.55087198529924, 79.79092393602643, 68.65440682002476, 59.40351963043213, 56.15923547744751, 59.40203966413225, 54.18682255063738, 57.06600318636213, 54.65836899621146, 59.06378746032715, 58.8124155317034, 63.234978675842285, 65.53507559640067, 73.51975086757115, 70.76696491241455, 62.08847727094378, 70.56409140995571, 63.83751950945173, 70.75382586887905, 70.21734850747245, 68.3795360837664, 65.4210695539202, 66.79429067884172, 68.63004643576485, 67.89667797088623, 64.94128254481724, 62.863896233694895, 63.27494471413748, 66.7359744480678, 64.94900894165039, 63.63953753880092, 63.832641874040874, 65.5071507862636, 64.32852785927909, 65.60669067927769, 66.69310406276158, 66.3269270488194, 67.15082359313965, 65.49018328530448, 66.61035101754325, 56.482368401118684, 60.74936485290527, 67.78129618508476, 63.14128916604178, 61.40519836970738, 62.35455853598458, 58.85851682935442, 58.508265086582725, 56.28675924028669, 57.870357922145296, 60.38666888645717, 58.75030558449881, 58.935482025146484, 57.23790856770107, 61.288684027535574, 63.350304876055034, 66.66531821659633, 57.54491124834333, 67.08540630340576, 62.54911504473005, 58.6001341683524, 55.35906703131539, 52.4142815044948, 53.43563890457153, 53.97224828175136, 55.04469231196812, 53.38110249383109, 53.638821601867676, 53.687955788203645, 57.40869181496756, 57.77086666652134, 60.58000251225063, 64.18980707441057, 65.40096146719796, 67.46479879106793, 68.46712507520402, 68.79288441794259, 67.18530750274658, 65.21211637769426, 65.85981355394635, 66.57148279462541, 62.26220308031355, 64.17984335763114, 63.67537634713309, 57.3676175389971, 67.63985170636857, 73.6379953111921, 74.31165790557861, 74.67324216025216, 17.278550965445383, 0.19907264783978462, 1.1425678559712, 0.5108032790677888, 1.1079016647168567, 2.3306583549295152, 0.4620185654078211, 0.5782894492149353, 1.8436882112707411, 2.7207250126770566, 0.8855129522936684, 0.3732773943671158, 6.383612292153495, 44.79030806677682, 80.12413869585309, 76.08307334354946, 41.210099356515066, 26.468153306416102, 33.99811240604946, 52.84064381463187, 56.27236604690552, 65.09690829685756, 54.22611461366926, 0.46386705764702385, 0.03908068241019334, 0.06704344640352897, 0.0166287983302027, 0.055759174948824305, 0.0979807348921895, 0.07829802855849266, 0.03003122710755893, 0.0189532269058483, 0.04227927273937634, 0.02502262426008071, 0.1372627488204411, 0.18327061219939164, 0.13293270474033697, 0.1374162741537605, 0.12802597374788352, 0.18666916340589523, 0.11341496384037392, 0.09689997788518667, 0.11526723551963057, 0.19866220200700418, 0.18489349154489382, 0.1390523985028267, 0.10113456565886736, 0.16855257696339063, 0.6636520315493856, 61.63715703146798, 81.7751418522426, 74.9566730771746, 69.70577348981584, 69.11332838875907, 82.63686438969204, 89.82453959328788, 39.74817058018276, 0.25462943954127176, 0.4800567403435707, 4.299569172518594, 7.098726970808847, 3.760494487626212, 1.7823660160814012, 0.43840245263917105, 0.17194152011403016, 2.254131329911096, 5.077288857528141, 0.5050160267523357, 19.361905779157365, 93.38631820678711, 81.3787123816354, 88.4623383113316, 88.14903708866665, 95.27442169189453, 88.04389694758824, 94.63454123905727, 87.19671698978969, 92.12813145773751, 87.21783256530762, 90.81948689052037, 74.07497446877616, 62.463443756103516, 67.7832555770874, 79.1514812197004, 83.27903774806431, 84.03157629285539, 82.3307615007673, 81.50400229862758, 82.93025207519531, 73.47913864680699, 61.519246101379395, 59.27260167258126, 62.923192160470144, 57.177712849208284, 62.826619148254395, 58.25276940209525, 63.12059048243931, 62.759492601667134, 64.62187385559082, 68.84462765284947, 79.3676118850708, 75.28152220589774, 66.48173291342599, 71.42971883501325, 64.5683935710362, 72.48957620348249, 73.05308900560651, 71.32873371669224, 70.1673492704119, 70.91507271357945, 74.25344589778355, 70.48040730612618, 66.30424812861851, 66.63735866546631, 67.8924673625401, 68.57827540806362, 68.35590526035854, 66.010728427342, 65.68644210270473, 72.1889762878418, 68.08996295928955, 68.51375443594796, 69.2308154787336, 69.47157055991036, 68.34360694885254, 69.87596961430141, 70.88766901833671, 57.86014754431588, 64.29273074013847, 70.78772612980434, 63.59307493482317, 64.4838478905814, 68.61185605185372, 63.158736092703684, 63.19260161263602, 59.19715813228062, 63.05057348523821, 67.30139800480434, 62.775098255702424, 60.817297390529085, 60.772759437561035, 65.03181062425885, 67.55874538421631, 69.69479533604213, 62.78136553083147, 67.6399837221418, 64.7089764731271, 62.4084209714617, 56.38063982554844, 55.04081521715437, 55.7205296925136, 58.50600692204067, 58.255882195064, 55.898271560668945, 55.99910381862095, 57.031609603336875, 61.20124094826834, 62.64789063589913, 64.18105234418596, 67.71756035940987, 69.1515087400164, 68.57940796443394, 70.69651017870221, 73.38533796582902, 69.61446026393345, 68.42779132298061, 69.6491595676967, 69.47918578556606, 63.06700597490583, 66.43395015171596, 67.08503110068185, 60.13402543749128, 75.16543170383999, 77.15443692888532, 81.1256103515625, 79.39785739353725, 17.658016409192765, 0.4107130127293723, 2.8011549711227417, 5.8197833469935825, 3.085331082344055, 3.3354684029306685, 1.1756035004343306, 2.3795315495559146, 6.477584941046579, 4.61578733580453, 1.0875243352992194, 0.2545887274401528, 11.08436828000205, 55.25558750970023, 85.68798514774868, 79.82755483899797, 49.805865219661165, 46.5821407863072, 43.15539346422468, 63.86554854256766, 63.9821115221296, 74.46440710340227, 67.84578936440604, 1.2532283408301217, 0.12753482295998506, 0.12832907534071378, 0.13914033664124353, 0.1396502557077578, 0.12339498581630842, 0.16914208818759235, 0.1525188216141292, 0.12999054975807667, 0.16682216338813305, 0.09741335069494587, 0.2706142046621868], [0.018414168152958155, 0.0528251556014376, 0.0343555341740804, 0.08963098829346043, 0.08533242823822157, 0.09118697087147407, 0.06318161184234278, 0.05347673920914531, 0.056631316364343674, 0.07258603934730802, 0.04430385838661875, 0.07448311469384603, 0.04687910573557019, 0.04102487862110138, 35.94492816925049, 60.60201440538679, 56.8817960194179, 61.94351005554199, 52.79929161071777, 75.65998363494873, 58.76297909872872, 6.7004071559224805, 0.05785010435751506, 0.17221306982849324, 3.5274047894137244, 1.4520629857267653, 1.8139678346259254, 0.07107086386531591, 0.31759556223239216, 0.23360283353499003, 0.24582406346287045, 0.7344198141779218, 5.9602767910276135, 66.40557370867047, 60.51997702462332, 68.12527370452881, 79.56910964420864, 87.79945237295968, 86.39013535635812, 85.15514169420514, 83.97016116550991, 84.7455175944737, 83.11755466461182, 81.13385786328996, 81.30465153285435, 72.02661078316825, 58.315883363996235, 62.52512986319405, 65.28109114510673, 70.13551957266671, 75.84971809387207, 77.10154029301235, 76.03224727085659, 75.18772847311837, 67.87211608886719, 56.38494423457554, 54.08797400338309, 55.310554708753315, 53.696686199733186, 54.59039824349539, 52.868561676570344, 56.347816535404746, 61.74231801714216, 63.34085532597133, 63.70550373622349, 67.44879014151437, 60.45797824859619, 62.83643000466483, 67.91864817483085, 67.26775482722691, 66.13107122693742, 62.679289545331685, 61.277837889535085, 61.20694541931152, 62.708485875810894, 62.03678962162563, 63.13799571990967, 62.83759035382952, 59.24608039855957, 61.921241079057964, 62.420198168073384, 60.731966563633506, 64.50135735103062, 64.87752587454659, 62.532515798296245, 65.00368431636265, 65.5264459337507, 65.0443034853254, 64.46046025412423, 63.82098279680525, 61.353823389325825, 50.76879174368722, 54.99227162769863, 58.52856772286551, 59.26354816981724, 61.63758781978062, 62.54432078770229, 60.25302028656006, 55.16135604040963, 54.386954988752095, 53.93555137089321, 54.662791524614605, 59.47248050144741, 54.88732603618077, 56.79059396471296, 52.45882640566145, 56.02975927080427, 59.183803694588796, 63.30578776768276, 58.170044149671284, 61.52244227273123, 64.87004266466413, 55.9235178402492, 54.56635400227138, 48.305516379220144, 51.14751025608608, 51.85331869125366, 52.13384526116507, 51.85611534118652, 51.84097869055611, 50.36554609026228, 52.52048124585833, 51.44641481127058, 53.719170570373535, 53.14261599949428, 61.99084118434361, 61.263524600437705, 64.46433734893799, 63.266995974949424, 64.84069347381592, 61.85479545593262, 64.15145996638707, 60.71741008758545, 64.78685188293457, 65.38754449571881, 61.966098649161204, 64.9950407573155, 68.69222586495536, 64.8836750302996, 66.74411078861782, 64.7998936516898, 54.76208128247942, 1.6253204430852617, 0.2904900424182415, 0.7825181218130248, 3.6400218435696194, 0.9731897733041218, 1.0843302266938346, 0.30719438035573277, 2.01354843378067, 2.1660329486642564, 1.1935712162937437, 0.04561855730467609, 0.2526051795908383, 21.777215991701397, 42.00063065120152, 77.60629217965263, 43.35811063221523, 57.45904541015625, 34.78746598107474, 43.195786816733225, 50.13646745681763, 56.69951697758266, 33.85187019620623, 0.2950425509895597, 0.0981663413611906, 0.06070618038730962, 0.07037805925522532, 0.11430895408349377, 0.1214428541383573, 0.08015147410333157, 0.06260037196001836, 0.08285076104636703, 0.16629355746720517, 0.04528034830998097, 0.16045009531080723, 0.028304402982550006, 0.03555230370589665, 0.034918514679053, 0.03701734223536082, 0.10241173819771834, 0.04634372124980603, 0.07579873981220381, 0.06671034677752427, 0.10728370784116642, 0.006182620251950408, 0.056236928062779565, 0.1290177476725408, 0.08177958495382752, 0.016015786045630063, 45.34127589634487, 71.07001059395927, 62.84854071480887, 58.597431319100515, 47.77795008250645, 84.28193378448486, 70.77157156808036, 8.11289472239358, 0.09366785774805717, 0.4842722884246281, 2.9053138962813785, 3.037388946328844, 5.901287019252777, 1.728020897933415, 0.9382857148136411, 1.2747787215879984, 0.9948799865586417, 0.3700370639562607, 11.332614387784686, 73.63725185394287, 67.689955166408, 79.03078406197685, 82.89872809818813, 88.9208151953561, 89.55708258492606, 88.27284703935895, 85.34029729025704, 86.43759155273438, 85.14525440761021, 84.04292270115444, 84.50624247959682, 75.11710698263985, 63.15293434688023, 64.75655773707798, 67.45935835157121, 74.45348453521729, 77.97128105163574, 79.69230815342495, 76.48364394051688, 79.88352257864815, 70.25761331830705, 59.386767523629324, 55.93434313365391, 59.84601565769741, 56.90521492276873, 57.749483585357666, 56.26294081551688, 60.51632227216448, 63.97620555332729, 67.80125835963658, 68.28209454672677, 71.53440734318325, 64.44049113137382, 66.29333250863212, 70.71403353554862, 69.47655936649868, 68.81364563533238, 66.64390386853898, 64.48675918579102, 63.7802802494594, 67.97881262642997, 66.75253200531006, 65.80560370853969, 65.13403947012765, 62.522802216666086, 65.45465019771031, 64.3195229939052, 60.516558510916575, 65.09289918627057, 68.11411489759172, 65.01781000409807, 67.31175776890346, 67.44209207807268, 66.98475469861711, 65.09055069514683, 64.54755592346191, 60.87803854261126, 52.58742366518293, 57.93525409698486, 58.969278063092915, 59.578628131321494, 62.02481092725481, 65.84575039999825, 64.19974994659424, 59.479164668491904, 57.23818302154541, 57.678726605006624, 57.10478455679757, 62.8256950378418, 58.763430731637136, 59.54450552804129, 56.702410902295796, 57.972857747759136, 61.72365515572684, 63.461010524204795, 59.56267506735665, 63.403736523219514, 68.16854013715471, 58.3635619027274, 57.245374407087056, 51.75658934456961, 52.794372286115376, 53.837619985852925, 55.05415228434971, 54.941066878182546, 56.00387723105294, 54.37195382799421, 56.32865340369088, 53.979613372257774, 57.06384924479893, 57.16911792755127, 63.318954604012625, 64.1939343043736, 67.50228432246617, 67.47431087493896, 68.9592729296003, 65.26206697736467, 67.12886728559221, 63.913491112845286, 68.11149542672294, 68.74881894247872, 66.53893048422677, 69.2933770588466, 71.8971449988229, 67.71978378295898, 73.87209401811872, 71.36721284048897, 60.12396444593157, 4.38146585226059, 0.1895461111728634, 0.9800807578223092, 1.3804079507078444, 1.0477863933358873, 0.29913772695830887, 0.5181390568614006, 2.07263765164784, 2.5798459436212267, 3.3607919812202454, 0.3416327195508139, 0.08155240464423384, 25.166958945138113, 50.10081624984741, 83.5697990145002, 50.806426661355154, 50.46038205283028, 39.741767815181184, 49.606510979788645, 56.293971470424104, 63.10916069575718, 41.94089698791504, 0.45066404182996067, 0.05037598005895104, 0.11476460391921656, 0.07158857251384429, 0.04865265717463834, 0.0627112038699644, 0.039264127745160034, 0.07116167899221182, 0.07559042956147875, 0.11216423381119967, 0.02354422876877444, 0.09916659018823079, 0.120517956625138, 0.08966264195208039, 0.16053902411035129, 0.1334690595311778, 0.16861899197101593, 0.15114815373505863, 0.22341264890772955, 0.16489401113774094, 0.16773730356778416, 0.13021154861365045, 0.14101727306842804, 0.21476577860968454, 0.21741665207913943, 0.12993082510573523, 54.710581234523225, 77.32860742296491, 72.7020034790039, 75.40441499437604, 79.34381430489677, 92.93568583897182, 84.5972569329398, 12.432408264705114, 0.16534743537860258, 0.504703303532941, 7.7978712150028775, 7.682267955371311, 6.246473959514073, 5.361325570515223, 1.22086906007358, 1.1643219058002745, 2.3500540341649736, 1.7333058714866638, 12.416110396385193, 76.03233759743827, 70.23322514125279, 84.23284476143974, 86.63861683436802, 93.5783942086356, 93.13227122170585, 90.70177745819092, 88.59597301483154, 89.7205250603812, 88.73324162619454, 87.46669619424003, 88.4987746647426, 78.24497754233224, 66.66430377960205, 67.90644018990653, 71.00867189679826, 78.03391211373466, 82.81583608899797, 82.07984120505196, 78.70064040592739, 81.99861676352364, 74.95306001390729, 62.658271244594026, 58.736923354012625, 63.474594252450125, 59.50364317212786, 61.04575416019985, 59.499488149370464, 62.605610847473145, 67.0503317969186, 71.11149828774589, 71.85116182054792, 74.2069902420044, 66.60040814535958, 69.8785960333688, 73.43283585139683, 75.5091312953404, 73.61752591814313, 69.99079554421562, 67.27087456839425, 68.24757589612688, 70.4215977532523, 69.00265748160226, 68.36129706246513, 68.85586288997105, 65.69488416399274, 69.50509561811174, 68.37732655661446, 64.60095282963344, 67.48315593174526, 71.5785631452288, 68.38638005937848, 70.47871194566999, 71.80626950945172, 70.67713165283203, 67.53579548427037, 66.89078031267438, 64.73062705993652, 52.1309791292463, 57.66928400312151, 61.32783712659563, 61.83362429482596, 65.43732139042446, 68.52155031476701, 66.42403507232666, 62.336701665605815, 61.83644526345389, 61.55041572025844, 61.12417152949742, 65.50904069628034, 60.694786752973286, 61.57375471932547, 59.49712576184954, 62.889542034694124, 64.46989590781075, 67.0142081124442, 64.48459134783063, 64.08658463614327, 71.1405417578561, 63.23938383374895, 59.54116344451904, 56.244288376399446, 55.66209186826433, 58.58450766972133, 58.55771541595459, 60.28249454498291, 58.53156934465681, 58.790792737688335, 58.792800767081125, 57.39763028281075, 59.96334988730294, 59.76551382882254, 67.55315208435059, 67.54928193773542, 71.5962393624442, 69.51298182351249, 72.19705009460449, 68.1983757019043, 69.9858762196132, 65.35376235416958, 70.94805581229073, 70.48538916451591, 69.58850874219621, 70.54171126229423, 77.22264044625419, 73.53232015882219, 76.72618470873151, 76.1048698425293, 63.99013669150216, 3.41590878367424, 0.583174467086792, 3.769904519830431, 7.7267807211194715, 3.35208979674748, 3.2959770134517123, 1.6386667383568627, 8.60538911819458, 8.801746078899928, 3.041772391114916, 0.26570429812584606, 0.5409766999738557, 34.755469526563374, 56.439880166734966, 91.35472747257778, 59.042790004185264, 75.6406329018729, 44.676677227020264, 58.23194565091814, 64.1558859688895, 73.40799604143415, 51.98241622107369, 0.5588364473411015, 0.1816803432468857, 0.22186508694929735, 0.08389543356107813, 0.23834188495363506, 0.11582865539406027, 0.11323972538645778, 0.11700040394706385, 0.24510674338255609, 0.30162178937877926, 0.1284308284521103, 0.21116704600197927], [0.05356260781575527, 0.056390107343239446, 0.017152067573208894, 0.1628411848630224, 0.13994335569441319, 0.07739486452192068, 0.053365103235202174, 0.05671712729547705, 0.05250952146681292, 0.06053478244159903, 0.011228987814060279, 0.07815105787345342, 0.022390539425292184, 0.19973450446767466, 39.32963194165911, 58.340028354099815, 48.28464051655361, 29.96715668269566, 42.66189765930176, 76.17737429482597, 39.27129486628941, 1.2544796679701125, 0.13544462780867303, 1.026793931211744, 4.686632905687604, 2.8436994424888065, 2.694193967751094, 1.3599133704389845, 0.13412379154137202, 2.8432471581867764, 0.174212780381952, 13.948583364486694, 83.37276199885777, 76.96152019500732, 72.84255858830043, 76.64944185529436, 81.92466013772147, 79.18224784306118, 80.89731339045933, 82.85552419934953, 84.80252756391252, 84.94562571389335, 82.66995171138218, 80.53104604993547, 78.96809046609062, 69.0163801738194, 59.36108003343855, 58.56474699292864, 64.32665879385812, 70.57559762682233, 73.95782089233398, 77.84089810507638, 75.0967835017613, 76.9410091127668, 67.77346556527274, 56.2774521282741, 53.62288590839931, 54.65464128766741, 51.200844628470286, 51.4249518258231, 56.44651917048863, 60.256105286734446, 62.59409768240792, 62.782199314662385, 66.19276428222656, 64.30074896131242, 64.24667807987758, 65.68879754202706, 67.98995058877128, 68.68418679918561, 64.7407922744751, 63.65016828264509, 60.864461762564524, 64.57061699458531, 63.25551060267857, 64.46143995012555, 64.22032356262207, 60.63039779663086, 60.09660938807896, 61.42294406890869, 60.87664195469448, 63.236229351588655, 64.5058319909232, 61.16278266906738, 61.882414545331685, 65.38086032867432, 63.40065847124372, 63.11216926574707, 56.06824534279959, 55.004305907658164, 52.93157836369106, 64.26381233760289, 62.61125973292759, 63.0541934967041, 60.092232022966655, 58.324089186532156, 57.24479423250471, 61.549380438668386, 58.77659061976841, 54.72449152810233, 51.22826222011021, 51.832147530147004, 58.4716272354126, 60.57077530452183, 55.220794405256, 54.39710978099278, 54.546958105904714, 55.95922463280814, 61.48730523245675, 60.919713837759836, 59.79822594778878, 63.89062459128243, 55.60625614438738, 54.24282503128052, 48.36502422605242, 49.317535400390625, 49.676913602011545, 53.523158414023264, 53.119669573647634, 52.83073915754046, 52.937036173684255, 53.89377185276577, 51.34096894945417, 52.90437616620745, 53.2356002671378, 57.814112254551475, 60.99412209647042, 61.395137378147666, 65.47707203456334, 64.09442220415387, 63.55259472983224, 66.03011390141079, 66.47679274422782, 65.71554115840367, 66.23765659332275, 65.44337327139718, 66.32373782566616, 66.99584402356828, 67.35375268118722, 66.6786448614938, 56.29579189845494, 59.27381065913609, 50.015468052455354, 1.7729086492742812, 0.6037602424621582, 0.69855804422072, 1.2792256772518158, 0.2350151091814041, 0.12361884808966092, 1.8509818656103951, 0.6408251907144273, 1.7733357463564192, 0.5179552552955491, 0.27514608576893806, 11.262948274612427, 36.67994335719517, 60.373404775347026, 60.1094913482666, 19.374228409358434, 25.96039284978594, 53.27193587166922, 47.97277757099697, 55.5885625566755, 22.66372970172337, 0.09309292824140616, 0.04294560430571437, 0.07741633336991072, 0.1548663220767464, 0.12689738002206596, 0.01784961175040475, 0.06135387598936047, 0.04490031780941146, 0.037349502090364695, 0.11588695512286254, 0.059586088705275736, 0.12851066488240445, 0.05582648562267423, 0.053744760541511435, 0.02444291447422334, 0.13400791133088724, 0.0685366644923176, 0.07267749229712145, 0.07278098245816571, 0.08961546341223375, 0.02946600065167461, 0.09830210943307195, 0.06422327844692127, 0.08164904160158974, 0.012798585197223085, 0.28850063202636583, 51.42483718054635, 64.01729719979423, 58.8902006149292, 39.67800072261265, 38.328577177865164, 87.34126036507743, 45.88561167035784, 1.3637151207242693, 0.3495875655540398, 1.2144956077848161, 3.9346393602234975, 3.5242466160229275, 2.2375270894595554, 0.9848167151212692, 1.7725825182029178, 0.6823819322245461, 0.07879151350685529, 22.548259326389857, 89.97433580671037, 81.43403393881661, 81.34959248134068, 80.3550968170166, 82.31799071175712, 83.21038954598563, 84.4715918132237, 86.23699705941337, 87.54559993743896, 86.78239590781075, 85.02385548182896, 85.34878104073661, 81.81671292441231, 73.12919957297188, 61.56288078853062, 62.52030781337193, 67.8983872277396, 72.0037373134068, 76.0607557296753, 79.40670939854213, 76.15422984531948, 77.94583674839565, 71.08933353424072, 58.09836653300694, 55.00708518709455, 56.68361949920654, 55.27890566417149, 53.55652366365705, 57.47076007298061, 64.16249370574951, 65.64391912732805, 65.15825394221714, 69.70751748766217, 67.7685045514788, 67.88423374720982, 70.12460395268032, 70.76799324580601, 70.53205326625279, 68.52150862557548, 65.77412142072404, 64.86066259656633, 67.79153088160923, 67.52306638445172, 66.48429679870605, 68.3815232685634, 62.61874989100865, 62.9314535685948, 63.23525660378592, 62.995071274893625, 66.240081514631, 66.96363912309918, 63.30828217097691, 65.6853859765189, 67.34934057508195, 65.11694690159389, 64.63716684068952, 56.79196623393467, 55.39972441537039, 53.119815485818044, 66.81220313480922, 63.92838110242571, 65.45914568219865, 62.81379277365548, 59.72761140550886, 58.65473311288016, 61.71856907435826, 62.74591582162039, 58.44553674970354, 55.72433383124215, 55.139959062848774, 60.179098401750835, 62.91599382672991, 58.75801113673619, 58.72117178780692, 56.39786788395473, 55.834403719220845, 64.69374602181571, 63.476282664707725, 63.07928344181606, 66.84838240487235, 58.92705386025565, 57.510833808353965, 52.65174313953945, 53.030058656420024, 52.115703514644075, 54.51593439919608, 53.87063782555716, 54.435856410435264, 57.0472708429609, 56.8258387020656, 54.583481311798096, 56.45043795449393, 56.60622351510184, 59.75435502188546, 65.72640814099992, 64.8726760319301, 67.73285334450858, 67.50659220559257, 67.17058426993233, 68.74197496686662, 71.38569504874093, 68.6848121370588, 69.28683880397251, 67.86309037889752, 69.89086655208042, 70.18342740195138, 71.7259830747332, 70.20136765071324, 64.50487313951764, 66.64063821520124, 59.00271279471261, 3.1507663939680373, 0.7610031334417207, 0.48079373793942587, 0.2750315490577902, 0.5182556020362037, 0.11662858032754489, 1.9200886487960815, 0.41349533200263977, 5.252598856176649, 0.5496887639164925, 0.46685733433280674, 9.68068712098258, 40.96049574443272, 67.65463052477155, 64.8755942753383, 21.416258811950684, 28.743316616330826, 54.91038015910557, 55.00544541222708, 63.377111026218955, 29.016452039991105, 0.12496964846338544, 0.1265950926712581, 0.04236576220552836, 0.06192877835461071, 0.05675145438207047, 0.030296978740287677, 0.0671213965064713, 0.04814509940998895, 0.0724526597186923, 0.10526039105440889, 0.034557937777468135, 0.13530220330825873, 0.12944826457117284, 0.12545469243611607, 0.07754186913371086, 0.25556120382887976, 0.21842567436397076, 0.12704905974013464, 0.06891173150922571, 0.1331731639802456, 0.13346188063068049, 0.19981221029801027, 0.18037762386458261, 0.1407739504107407, 0.11923164421958582, 0.5713264314191682, 64.16498810904366, 73.65127331869942, 69.4193478993007, 41.59953546524048, 62.35818549564907, 95.19726889474052, 58.138478483472554, 2.1329810193606784, 0.39251280363116947, 2.227350801229477, 12.83453699520656, 7.687175989151001, 7.949708461761475, 7.6033468416758945, 2.8267660311290195, 8.458114232335772, 0.9893115482160023, 22.12891295978001, 92.22949177878243, 81.90869317735944, 80.66210297175816, 83.97779723576137, 88.1695898600987, 84.27301229749406, 87.02111516680036, 90.35137285505022, 89.26684243338448, 89.4254628590175, 89.06647028241838, 86.52275562286377, 84.00519398280552, 77.7175953728812, 64.31490939004081, 64.3071482522147, 71.62597070421491, 76.15592520577567, 79.93409851619175, 84.39477947780064, 79.40918295724052, 83.01997416360038, 73.81670297895158, 61.74588244301932, 58.90431240626744, 60.506386348179404, 57.50538642065865, 56.55722829273769, 61.646064622061594, 68.3037451335362, 67.08653885977608, 70.03511115482875, 72.69911997658866, 73.6141004562378, 70.98495769500732, 75.55602468763078, 75.48992647443498, 73.70906148638043, 71.6222951071603, 69.79671846117292, 69.92480155399868, 71.50157710484096, 71.4243061883109, 68.8039390019008, 72.32830851418632, 64.86954239436558, 66.56424971989223, 67.0283476965768, 64.10613686697823, 67.34888894217355, 70.38584927150181, 66.87313883645194, 67.20658983503068, 71.74569511413574, 67.727308682033, 66.76273890904018, 59.05671419416155, 58.52783121381487, 55.41077552522932, 67.21523339407784, 65.9989790235247, 68.34956850324357, 66.8081384386335, 61.69211728232247, 61.48702730451311, 66.97267178126744, 65.79789815630231, 61.441975184849326, 60.1811967577253, 60.43879427228655, 65.44686126708984, 66.31251648494175, 61.3127247946603, 62.568104471479145, 60.40342099325997, 59.71176951272147, 65.50885309491838, 65.91431522369385, 65.97762720925468, 68.04185363224575, 62.276092529296875, 60.087646211896626, 55.06532151358468, 55.273260252816335, 55.77640363148281, 59.00769465310233, 56.93818065098354, 59.189674922398154, 60.62512411390032, 60.02197183881487, 59.01269040788923, 60.55859511239188, 59.70322322845459, 64.41477584838867, 67.60390172685895, 67.72486986432756, 70.94273349217006, 69.78034155709403, 69.34143774850028, 71.81311348506382, 72.73386096954346, 71.04267638070243, 71.92829377310616, 72.11700684683663, 73.15375450679234, 73.49612699236188, 73.44737843104771, 72.89480904170445, 66.44585241590227, 70.21120629991803, 62.42113617488316, 2.50890896150044, 1.7671560836689812, 4.68951119695391, 3.258497778858457, 2.895183639866965, 0.5585701359169823, 5.2190329773085455, 8.430421318326678, 6.2562509434563776, 0.8650380766817501, 0.42619748041033745, 15.819677659443446, 54.62277684892927, 70.00175285339355, 75.51713562011719, 28.459885699408396, 35.781336307525635, 65.06411279950822, 61.93736784798758, 71.92257540566581, 36.6322717666626, 0.1698883952839034, 0.18913208267518453, 0.21801602920251234, 0.16897210159472056, 0.30806160239236696, 0.14938141139490263, 0.22151653708091804, 0.10860596224665642, 0.14379852025636605, 0.24902406175221714, 0.09876822227878229, 0.25456999987363815], [0.08567089507622377, 0.07498262503317424, 0.009901601139322987, 0.05477788778288024, 0.035576903992997747, 0.01887683234443622, 0.07589994331023522, 0.13792008640510695, 0.03266213129141501, 0.0847624656079071, 0.05406496460948672, 0.09628510980733804, 0.06844396982342005, 0.5320912567632539, 45.95851216997419, 59.01698439461844, 48.170683111463276, 33.08289221354893, 56.01934044701712, 72.08985328674316, 19.061170373644146, 0.17744310918663228, 0.04789961561826723, 1.314633154443332, 1.0779435294015067, 1.3505963789565223, 5.608604141644069, 1.3470331473009927, 0.43343761190772057, 0.031183912219213586, 31.747417177472794, 99.58768967219761, 88.88089779445103, 87.22900526864188, 86.7871206828526, 83.0482394354684, 77.0652915409633, 80.32985401153564, 82.92099707467216, 80.59180804661342, 83.84046609061105, 82.4595672062465, 83.64480481828961, 76.83596624646867, 75.3658663885934, 68.86668123517717, 61.904058183942524, 59.79052039555141, 65.06677395956856, 71.67007786887032, 73.25795664106096, 74.96016107286725, 74.41536671774728, 73.55935559953961, 64.37472643171037, 52.707109860011506, 53.001769065856934, 53.74441684995379, 54.24077878679548, 52.34993076324463, 53.944594451359336, 60.25531319209507, 59.59889602661133, 61.995642389569966, 62.60636820111956, 64.02974837166923, 64.3682507106236, 66.99680287497384, 67.19495160239083, 67.48617144993374, 66.00022969927106, 58.21075711931501, 60.686990874154226, 62.49624620165144, 64.3189810344151, 64.2308292388916, 61.26720714569092, 64.56026417868478, 55.40470279966082, 60.2163268498012, 64.34003407614571, 64.18047564370292, 61.00123010362898, 60.33666270119803, 65.61258969988141, 62.15408216203962, 62.88002300262451, 56.63894258226667, 49.09725318636213, 48.28849329267229, 49.53749452318464, 58.2887020111084, 62.32405594417027, 57.97716563088553, 59.13463824135916, 65.32642814091274, 60.253075872148784, 58.7051978792463, 57.13770859582083, 53.785369532448904, 49.43244470868792, 53.0302323613848, 55.95358616965157, 58.031048910958425, 57.01419741766793, 52.67095838274275, 52.83668334143502, 54.19123118264334, 57.74057946886335, 63.67181192125593, 57.67423459461757, 63.11922863551548, 57.279802731105256, 54.55750894546509, 50.817130361284526, 48.28544650759016, 47.551021916525706, 49.322954995291575, 50.93543039049421, 52.90869447163173, 52.05253049305507, 53.500382219042095, 51.42333984375, 49.45853519439697, 52.05736296517508, 56.996125153132844, 58.99916226523263, 63.59440204075405, 63.388422693525044, 63.219484192984446, 61.86589867728097, 58.09311716897147, 63.28988334110805, 63.43586499350411, 66.2626006262643, 66.88834149496896, 69.4812285559518, 64.90848704746791, 66.52629171098981, 63.73638847896031, 66.67088372366769, 51.406646796635215, 56.039573601314, 51.81773696626936, 3.0230107350008826, 1.000682275210108, 1.0094388510499681, 0.049166430320058546, 0.789329962006637, 0.5497546632375035, 1.2626546578747886, 4.020711038793836, 0.8124046038304056, 0.1167527793773583, 0.597619717674596, 21.550484112330846, 44.810364042009624, 56.6470685005188, 30.127427305494034, 45.114973068237305, 54.67015314102173, 48.50786529268537, 50.83126647131783, 13.50677694593157, 0.2710054208125387, 0.30626549305660383, 0.13578755940709794, 0.22410027629562787, 0.16497384756803513, 0.08282218793673174, 0.0170819053559431, 0.12371723566736494, 0.08192644707326378, 0.06394012578363929, 0.007746863145647305, 0.036285806846405776, 0.061477654347462315, 0.1263194853173835, 0.014555431104132106, 0.09178699260311467, 0.02700868438530181, 0.1209391640233142, 0.0625270562512534, 0.15139481478503772, 0.04880959553910153, 0.07075059533651386, 0.06864527080740247, 0.17023488240582602, 0.05513588964406933, 1.1952080598899295, 60.003823144095286, 66.45266859872001, 56.90980768203735, 28.30667618342808, 54.30075216293335, 84.09331103733608, 23.170411450522288, 0.01942689354265375, 0.2686437932508332, 2.437650842326028, 2.09632579769407, 3.61917399082865, 1.7663490069764, 2.3943546627249037, 0.9479064728532518, 0.30033729544707705, 43.982996872493196, 105.12394482748849, 90.61545998709542, 91.12920979091099, 89.69697066715786, 86.39392212459019, 83.80332102094377, 81.7511636189052, 83.89425209590367, 82.7040604182652, 85.58144841875348, 86.70945371900285, 83.86610494341168, 79.28176689147949, 79.20326614379883, 71.04411465781075, 65.54400403159005, 64.12336145128522, 68.73659706115723, 73.2554622377668, 75.60703836168561, 79.78689398084367, 78.09787722996303, 74.98389611925397, 67.03269032069615, 55.12828608921596, 55.08069787706648, 55.96592617034912, 57.177834442683626, 54.34819793701172, 55.860101631709504, 60.42541898999895, 62.25629016331264, 65.38872568947929, 66.33625847952706, 66.25328309195382, 69.24722712380546, 69.55018247876848, 71.4004738671439, 70.11180537087577, 69.44343035561698, 61.26330920628139, 64.84276403699602, 66.45785195486886, 68.86321408408028, 67.07658209119523, 65.54811041695731, 66.91821180071149, 58.13061312266758, 62.7509046282087, 67.09581470489502, 66.89228807176862, 62.9124641418457, 65.02218042101178, 67.84569208962577, 63.55103138514927, 65.14553179059709, 57.11603716441563, 48.93002046857561, 50.62119116101946, 50.96510962077549, 58.235763686043875, 63.836491176060264, 62.47795854296003, 61.20586150033133, 66.6287567956107, 62.20490823473249, 60.65770421709333, 57.25294099535261, 55.131246021815706, 54.077277251652305, 56.14459562301636, 60.650415556771414, 59.560236249651226, 61.55491120474679, 56.033535616738455, 55.799416065216064, 56.89629690987723, 60.019755363464355, 64.60468401227678, 61.68335560389927, 66.26260757446289, 59.86927127838135, 57.79196834564209, 52.33945982796805, 51.05920212609427, 49.9501028742109, 50.240103312901084, 52.44834852218628, 54.72155244009835, 54.83573566164289, 55.28256041663033, 54.476180280957905, 52.959055015019004, 53.56274924959455, 59.163292612348286, 63.83570602961949, 66.53916672297886, 66.40786661420549, 65.03933552333287, 62.62999207632882, 62.231721333095, 63.617525645664756, 66.9636321749006, 69.95540142059326, 69.59100314549038, 71.27141107831682, 70.2037022454398, 69.46307291303361, 66.84927177429199, 66.19547407967704, 57.70805842535836, 59.46201651436942, 60.52356229509626, 6.115107408591679, 0.8961077066404479, 0.5395280548504421, 0.46454168430396486, 0.5671341163771493, 2.066433995962143, 2.5375387966632843, 6.531368775027139, 1.3988710514136722, 0.0726280678063631, 0.6666513734630176, 21.863762753350393, 53.51529652731759, 61.47244998386928, 29.870350905827113, 42.453448227473665, 62.1128237588065, 51.62036296299526, 59.377060890197754, 18.583297593253, 0.2996405214071274, 0.30222734117082184, 0.19021600165537425, 0.12909393358443463, 0.07316286875201122, 0.10174156273049967, 0.0501375835654991, 0.09084279755396502, 0.07782384114606039, 0.09647758305072784, 0.05054690642282367, 0.02591598516197077, 0.2704790676278727, 0.2720410552408014, 0.1549757154924529, 0.2409502278481211, 0.0918772920433964, 0.2050362785479852, 0.11483867280185223, 0.17819622877453054, 0.08955724510763373, 0.18905306048691273, 0.17239725137395517, 0.22199084662965365, 0.17918854552720273, 1.4919800609350204, 70.947235924857, 75.30415943690709, 63.41547203063965, 47.98024688448225, 76.87534168788365, 90.95538670676095, 32.77282190322876, 0.2281961850821972, 0.24790890301976884, 5.249146470001765, 5.500946147101266, 5.3256261604172845, 14.861383846827916, 8.77166211605072, 4.0626073735100885, 0.3126957522971289, 42.19496829169137, 108.21075848170689, 91.95747675214494, 96.1633186340332, 93.16249588557652, 88.6110645021711, 87.62851279122489, 84.20756721496582, 87.56941836220878, 84.96396895817348, 88.216552734375, 89.7744917188372, 89.25513471875871, 82.85005596705845, 82.3698729106358, 75.75266565595354, 68.87837505340576, 66.70217841012138, 72.5039450781686, 78.81602913992745, 78.75633716583252, 83.06601292746407, 80.99872929709298, 78.07872799464634, 70.4196731022426, 58.09328392573765, 60.43622343880789, 58.31937830788748, 60.85074601854597, 57.37966571535383, 58.422975948878694, 66.77767058781215, 65.03295012882778, 70.5952957698277, 71.92513929094586, 71.19051320212228, 72.49075044904436, 72.68322944641113, 74.54680579049247, 74.04383264269147, 73.25973537990025, 64.97716999053955, 68.27303409576416, 70.43185329437256, 71.22091851915631, 70.54285771506173, 67.85562106541225, 72.06585420880998, 59.05148220062256, 63.16641385214669, 71.48692335401262, 70.7173547744751, 67.39439964294434, 67.6558256149292, 70.26638889312744, 66.38288089207241, 67.69029562813895, 58.46799332754952, 51.299484729766846, 52.25757878167288, 50.819993019104004, 63.690690176827566, 68.06116267613002, 63.87916701180594, 65.97160312107631, 70.72415706089565, 62.3548503603254, 62.363389696393696, 61.79385280609131, 57.63982711519514, 56.98136370522635, 61.44203077043806, 62.6233218056815, 62.554235867091585, 64.3888521194458, 58.422051838466096, 59.06540639059884, 59.87304415021624, 63.11405222756522, 67.58066000257219, 62.71088995252337, 67.94770554133824, 63.15253829956055, 59.88744081769671, 55.74169043132237, 55.154116017477854, 53.99322141919817, 53.275163309914724, 57.196452140808105, 58.432446343558176, 57.80446468080793, 58.75586414337158, 59.536535944257466, 55.762722628457205, 58.097470215388704, 62.877896853855674, 66.57076713017055, 71.0726717540196, 69.52473817552838, 67.79161425999233, 66.93970257895333, 62.98480183737618, 66.85688005174909, 68.55986268179757, 71.16745213099888, 72.65130247388566, 74.23825018746513, 73.20061315808977, 72.43682547977993, 67.90188217163086, 68.52971444811139, 60.29627282278878, 64.93725258963448, 62.92613819667271, 4.86806947844369, 2.4730616850512366, 2.825251106704984, 0.6623042438711438, 1.7832577739443098, 2.4903114565781186, 4.341011268751962, 17.75602422441755, 3.220491349697113, 0.08658826085073607, 1.6517358656440462, 35.14054216657366, 61.66985525403704, 69.27725723811558, 43.531864234379356, 60.12376989637102, 67.14889894212995, 58.728898184640066, 68.49730804988316, 24.995970726013184, 0.4162028767168522, 0.4600894089256014, 0.34531708327787264, 0.2608407219605786, 0.20918823432709488, 0.13886360291923794, 0.22107679210603237, 0.15932483997728142, 0.27845060559255735, 0.14820887574127742, 0.10746014051671539, 0.07319910930735724], [0.05870562845042773, 0.08824509408857141, 0.09083882133875575, 0.08767420186528138, 0.031675789039582014, 0.07751119935086795, 0.04184546833857894, 0.13569217095417635, 0.006309283232050282, 0.06294995998697621, 0.0457583660525935, 0.17040154417710646, 0.19516515465719358, 3.508264239345278, 57.743462971278596, 45.585202830178396, 43.39576292037964, 57.33124719347273, 64.96414906638009, 59.13525663103376, 5.451414176395961, 0.04772623295762709, 0.31264649065477507, 0.684600470321519, 1.6407122228826796, 1.2152886795146125, 2.0197028006826128, 0.530540831387043, 0.23578614209379467, 35.66805635179792, 107.70923750741142, 82.05278491973877, 90.65821920122418, 83.07530961717877, 88.58089542388916, 83.4818000793457, 87.32812826974052, 74.72679887499127, 83.42365060533795, 81.68461377280099, 84.00564561571393, 77.88549164363316, 77.78015000479562, 74.1710124697004, 71.33309023720878, 63.867021560668945, 58.96341378348214, 61.25445720127651, 66.6538953781128, 69.26322882516044, 74.99399185180664, 75.7873649597168, 74.6426283972604, 70.16276345934186, 59.49444375719343, 54.974741322653635, 55.12424571173531, 55.34719950812203, 56.39326122828892, 55.00003276552473, 50.60375813075474, 53.12695128577096, 57.53077513831002, 59.25418894631522, 59.12020683288574, 59.4684088570731, 65.26222678593227, 65.87838608877999, 66.89775630405971, 67.15030942644391, 63.105631010872976, 60.80636787414551, 63.229121344430105, 63.113142013549805, 65.45378167288644, 61.318533488682334, 64.30131871359688, 57.80819238935198, 56.75118030820574, 64.62387493678501, 62.87363065992083, 58.70200865609305, 60.53094823019845, 63.35732255663191, 64.8003591809954, 58.19758333478655, 57.732126985277446, 51.373677594321116, 49.01292984826224, 49.259368555886404, 54.378429549080984, 45.74186386380877, 53.85837772914341, 65.22255952017647, 57.37546900340489, 57.516270773751394, 57.97199617113386, 64.57003334590367, 57.711838245391846, 57.257617133004324, 51.34584658486502, 48.114823068891255, 57.97364984239851, 57.15729209354946, 57.537289074489046, 58.61290495736258, 56.010606561388286, 52.684823513031006, 57.47746161052159, 61.24910708836147, 56.85164431163243, 60.56172180175781, 58.89607184273856, 55.339890003204346, 51.285393783024375, 49.09206288201468, 46.9411472593035, 45.726529189518516, 45.470630509512766, 46.96771717071533, 47.0445225579398, 48.73149653843471, 48.01804855891636, 45.03460325513567, 49.031175817762104, 53.77082347869873, 60.23141833714077, 60.883180209568565, 67.67286259787423, 59.56607273646763, 54.599962438855854, 62.103791100638254, 64.35343020302909, 64.62840516226632, 66.91269493103027, 66.59372397831508, 65.98319966452462, 65.38182612827846, 62.23755087171282, 63.89573151724679, 54.58834505081177, 57.669252736227854, 56.41798986707415, 51.89267676217215, 59.50990349905831, 3.778725257941655, 0.7600776659590858, 0.2732631782335894, 0.2952478214034012, 0.7073546807680811, 0.3820466452411243, 4.988130007471357, 1.87443442429815, 0.17006417656583445, 0.016666302657020942, 11.816202061516897, 34.82256828035627, 51.834447383880615, 31.961275781903947, 28.25563645362854, 38.14085422243391, 50.14797019958496, 47.08535017286028, 16.968315635408672, 0.13519903884402343, 0.15305571923298494, 0.03676154810403075, 0.0762098098972014, 0.0639378119792257, 0.04900152934715152, 0.08091917540878057, 0.1688170563429594, 0.017173924882497107, 0.07728608178773097, 0.025499101728200912, 0.0323813501080232, 0.019513608621699468, 0.02076031154553805, 0.04214565562350409, 0.027277197655556456, 0.07202256351177182, 0.03611465995865209, 0.04675699996628931, 0.114688282300319, 0.06538645710263934, 0.03384541833241071, 0.02453560066143317, 0.12790313176810741, 0.2882193114076342, 5.504769393375941, 69.4946038382394, 52.2438109261649, 49.83184453419277, 44.3960394859314, 73.22611999511719, 68.21835177285331, 6.204119912215641, 0.3773808484630925, 1.0534276791981287, 1.9083976532731737, 2.9450782196862355, 3.3419356559004103, 4.087955704757145, 0.8224709151046616, 0.23704031908086368, 48.232483863830566, 110.43257699693952, 83.3952533176967, 95.02332074301583, 87.4878465107509, 91.32366902487618, 87.76649011884416, 90.08404091426304, 80.87283488682338, 84.5854241507394, 83.55555520738874, 84.63786220550537, 80.43037360055106, 81.14910915919712, 75.90362221854073, 75.71194226401192, 66.04030690874372, 62.029299463544575, 63.73567281450544, 70.74616200583321, 74.29741409846714, 78.2144888469151, 78.65832587650844, 78.27563299451555, 72.90091650826591, 62.21796389988491, 56.18790027073452, 55.566581930433, 58.652662549700054, 57.52771793093, 56.23670441763741, 54.181194509778706, 55.082497460501536, 59.91060611179897, 59.875073024204795, 61.892996651785715, 61.031051771981375, 65.65828105381557, 70.37982518332345, 69.89685589926583, 69.60993003845215, 67.64899553571428, 62.840835162571494, 66.90642070770264, 65.47399398258754, 67.37834930419922, 65.18467099325997, 66.61208806719098, 57.499136516026084, 59.12141581944057, 66.67490673065186, 66.1359349659511, 62.09367452348982, 64.16730185917446, 65.9444773537772, 66.13504559653146, 59.64483751569475, 58.34223788125174, 51.11252955027989, 51.49357918330601, 52.00804812567574, 54.41525847571236, 46.20276914324079, 52.66018520082746, 67.6760309764317, 61.19895499093192, 60.593468121119905, 59.66397285461426, 65.96268163408551, 60.76094055175781, 60.06635693141392, 54.757780347551616, 54.4506630216326, 59.98725169045584, 59.50119045802525, 58.976907185145784, 62.037873540605815, 59.654981885637554, 55.124728611537385, 61.47433294568743, 62.35558686937605, 62.197577885219026, 65.80942521776471, 61.687260491507395, 60.496012687683105, 54.31117098672049, 52.32741512571062, 49.282565116882324, 47.88516078676496, 48.26654393332345, 48.958501134599956, 49.267258235386436, 50.36465672084263, 50.54674121311733, 48.43188326699393, 52.547944000789094, 57.76497459411621, 63.2963799067906, 63.849880354745046, 68.51214940207345, 62.65101037706648, 59.471396582467214, 63.65189838409424, 66.65287399291992, 66.78391007014683, 69.16466862814767, 67.59214537484306, 67.5716551371983, 66.1773601259504, 64.42489242553711, 63.0043123790196, 59.00940390995571, 61.372354234967915, 62.379037039620535, 57.77199574879238, 68.51567213875907, 7.529668143817356, 0.5037734934261867, 0.47095655437026707, 0.45601629891565865, 0.8265115097165108, 1.6830092732395445, 3.810754716396332, 2.446886952434267, 0.4077652394771576, 0.01585765345953405, 11.530453051839556, 39.1781507900783, 60.08646501813616, 35.79277304240635, 22.937035356249126, 44.67147650037493, 54.90578045163836, 55.20129428591047, 20.974834544318064, 0.21733106167188712, 0.18728333259267466, 0.015045530162751675, 0.11551996267267636, 0.09097024678651776, 0.12076022076819624, 0.017740462607304965, 0.07077532115259341, 0.03372115142909544, 0.10740844293364457, 0.03444573861945953, 0.134788593011243, 0.15132340575967515, 0.16050625086895057, 0.17839072405227593, 0.09140330819146973, 0.2304562223809106, 0.28529007573212894, 0.1487186998128891, 0.18666195736399718, 0.19409959683460848, 0.1309879148112876, 0.1480243277869054, 0.385254867374897, 0.4266308200146471, 6.842494777270725, 82.32224995749337, 62.190039089747835, 59.05091939653669, 78.09254101344517, 80.34638377598354, 79.45404747554234, 9.707263980593, 0.5304613070828574, 1.242011885557856, 4.5978531667164395, 5.159033111163548, 7.124443556581225, 8.18654649598258, 2.398939822401319, 0.45266428164073397, 47.5523316519601, 114.49625178745815, 84.5609039579119, 100.64106437138149, 88.82784829820905, 94.29885986873082, 90.93650150299072, 93.56637382507324, 83.66280760083879, 87.98291955675397, 86.31802000318254, 90.39703641619, 83.7136892591204, 82.8588593346732, 80.21315901620048, 79.1112928390503, 70.94838237762451, 64.9267191205706, 69.90342889513288, 73.1796851839338, 77.39921501704625, 80.26085839952741, 81.30144841330392, 81.98887538909912, 76.04310730525425, 64.97531482151577, 60.69942814963204, 61.265087945120676, 60.431387492588584, 63.34431552886963, 60.82379395621163, 58.559132848467144, 60.05823448726109, 65.21574333735875, 65.17517280578613, 67.33006627219063, 64.56930378505162, 70.74613421303886, 73.89292471749442, 73.78313623155866, 71.98665169307164, 70.38948317936489, 67.17643465314592, 71.24645314897809, 69.57717623029436, 71.88936301640102, 68.40919794355119, 71.11388846806118, 62.60089302062988, 60.3291516985212, 70.62617356436593, 67.23442431858608, 66.79536764962333, 66.45394011906215, 67.98097351619175, 67.32981613704136, 61.25474902561733, 58.909586088997976, 52.17776829855782, 52.511372157505576, 52.080340657915386, 55.86994028091431, 46.6237222807748, 55.92514371871948, 70.01714311327252, 63.12077808380127, 62.7008706501552, 63.77041380746024, 70.79173524039132, 63.99389566693987, 63.78258010319301, 58.750111034938264, 58.662508147103445, 64.81460298810686, 62.58471066611153, 62.673876898629324, 65.94050298418317, 61.2675267628261, 57.67110790525164, 63.419585364205496, 66.46094390324184, 62.729462487357004, 66.57657582419259, 65.1077127456665, 62.86909348624093, 58.491888182503835, 55.129481179373606, 54.93753719329834, 50.86742837088448, 51.71500785010201, 53.227724484034944, 52.859911169324604, 55.256237166268484, 54.96434334346226, 50.93973479952131, 55.615358284541536, 59.65221650259835, 65.89854281289237, 66.38352707454136, 72.23138809204102, 67.19140802110944, 61.01172883169991, 64.98270075661796, 69.19195420401437, 68.75394671303886, 72.22136184147426, 70.72931957244873, 71.29884256635393, 67.51265103476388, 66.12160778045654, 67.00261851719448, 61.02470806666783, 64.03147152491978, 61.029182706560405, 59.20059749058315, 69.88579436710903, 5.768932955605643, 1.2107207817690713, 1.3921696224382945, 0.705277929348605, 0.8873064017721585, 0.9968476295471191, 9.47364730494363, 5.116500582013812, 0.491851198886122, 0.1301491233919348, 17.102987357548304, 49.27876097815377, 61.87716170719692, 45.795260769980295, 38.62418481281826, 47.1103949546814, 59.81169155665806, 62.778683526175364, 25.80040536608015, 0.325834470135825, 0.26247628991092953, 0.1371930089912244, 0.18159102089703083, 0.15153286951993192, 0.1544023398309946, 0.14358506671019963, 0.23034233706338064, 0.10216575568275792, 0.21412862065647328, 0.07807202211448125, 0.18747495088194097], [0.06274029266621385, 0.025186612603387663, 0.03760069575426834, 0.1318577424223934, 0.05200512906802552, 0.03339361579024366, 0.05959943548909255, 0.09810323760445629, 0.04244415335623281, 0.17722182534635067, 0.04897653211706451, 0.11736979841121606, 0.3007409695003714, 9.727481501443044, 57.709854534694124, 39.99326133728027, 27.030191353389196, 25.67386998449053, 73.50860595703125, 36.939826829092844, 0.8314939652170453, 0.05196988256648183, 0.4662802538701466, 1.707813907946859, 0.6088507207376617, 3.0812685574804033, 0.35473352085266796, 0.31834303640893524, 19.279338598251343, 100.34225014277867, 83.3735818862915, 90.94416536603654, 81.37300791059221, 84.99881417410714, 79.75065912519182, 81.26734665461949, 84.79598930903843, 84.53267342703683, 76.72754655565534, 81.50946358272007, 79.81570816040039, 75.43267331804547, 72.40144525255475, 68.70916557312012, 65.00036307743618, 58.76739815303257, 58.82765293121338, 60.50173800332205, 65.8606959751674, 70.99715873173305, 73.31546688079834, 73.057021686009, 73.09123461587089, 69.37392752511161, 54.854791096278596, 53.0758820261274, 52.85556507110596, 57.20937926428658, 55.4034868649074, 55.347692830221995, 52.826545919690815, 52.724980626787456, 53.44384125300816, 53.457258224487305, 55.0136581829616, 59.601175035749165, 61.31467029026577, 67.89535086495536, 65.15095138549805, 64.05778435298375, 62.647696086338584, 59.56191076551165, 60.07852322714669, 64.33557333265031, 62.837708473205566, 66.31179387228829, 56.58455555779593, 55.16008799416678, 66.47990553719657, 64.02209840502057, 61.160726002284456, 60.32945047106062, 65.1064759663173, 62.47846576145717, 58.14187615258353, 54.110138756888254, 56.716404574257986, 51.33303758076259, 52.93964869635445, 52.37602819715227, 52.73496866226196, 52.94953598294939, 53.07532269614083, 54.29714604786464, 61.24995476858956, 64.03982325962612, 58.69518552507673, 56.380334104810444, 57.17818880081177, 59.03220789773123, 52.79216970716204, 46.52015938077654, 54.00382784434727, 56.33859280177525, 55.66440561839512, 57.295366695949006, 58.118867192949565, 56.19125277655465, 52.63051986694336, 62.7525999886649, 60.686851910182405, 58.29109219142369, 56.832647936684744, 57.836356912340435, 53.23413419723511, 50.697669982910156, 49.414417607443674, 47.964370250701904, 44.16802740097046, 45.89105905805315, 43.67383677618844, 45.09697028568813, 46.59833356312343, 48.12983465194702, 47.986604486192974, 53.94330208642142, 58.18388843536377, 63.81808539799282, 60.55034760066441, 54.076523372105186, 64.27247674124581, 64.89799526759556, 65.74254880632672, 63.48232759748186, 63.87560258592878, 67.11299065181187, 65.8514826638358, 65.04432432992118, 61.54072993142264, 57.510774748665945, 61.57123947143555, 63.112266540527344, 66.41758019583565, 67.9473511832101, 57.562069824763704, 56.33320794786726, 2.1067372390202115, 0.729622408747673, 0.29350699910095757, 1.3644341507128306, 2.149357489177159, 2.9449505465371266, 1.292644060083798, 0.2030151127172368, 0.3356214149722031, 2.6010416405541554, 28.000366585595266, 43.56923164640154, 47.59863097327096, 36.922463280814036, 40.87145110539028, 41.18266439437866, 48.608332770211355, 15.89219948223659, 0.13822093526167528, 0.18827548649694237, 0.05049232167324849, 0.1233223554279123, 0.08998799270817212, 0.03331774200445839, 0.06507196969219617, 0.11339422102485384, 0.035300119380865774, 0.0679723812001092, 0.05418459711862462, 0.05842590917434011, 0.03217272094583937, 0.09029559977352619, 0.028953455654638152, 0.05036159511655569, 0.06198184657841921, 0.04300564447683947, 0.03428312770224043, 0.06889018123703343, 0.04181666113436222, 0.0940164483285376, 0.10599331744015217, 0.10874388805989708, 0.398322339036635, 15.145363671439034, 66.9727760042463, 50.112565653664724, 41.366954939705984, 27.677482060023717, 84.60332271030971, 43.80754096167428, 0.9497308092457908, 0.18381672432380064, 0.9356130467993873, 2.7540114436830794, 2.443262381213052, 2.7952998110226224, 0.5681944766214916, 0.1491833334522588, 28.206933055605205, 103.56635325295585, 86.56716850825718, 98.13173634665353, 84.22768224988664, 87.83742427825928, 82.08171027047294, 85.30254077911377, 87.18855285644531, 88.18925326211112, 80.16881561279297, 81.63481603349958, 83.36700889042446, 76.36740057809013, 73.1429500579834, 70.79035254887172, 65.53856359209333, 62.13590567452567, 61.87545245034354, 62.613705498831614, 69.71825245448521, 76.22328104291643, 74.13078239985875, 75.44247722625732, 75.08644458225795, 71.50574602399553, 57.387086391448975, 56.51247494561331, 55.78627354758126, 60.057984352111816, 58.14574629919869, 57.91890498570034, 57.33628116335188, 55.40612023217337, 56.004269804273335, 55.2051887512207, 59.617697851998464, 61.34960583278111, 64.7009026663644, 71.52896690368652, 70.0034065246582, 69.69933945792062, 66.55270181383405, 61.428238596235005, 64.47626740591866, 65.37099388667515, 64.67431885855538, 69.13690362657819, 57.853320939200266, 60.05296080453055, 69.28945827484131, 66.3986463546753, 63.7239442552839, 64.75110340118408, 68.27730028969901, 64.4497322354998, 57.69762570517403, 55.301650592258994, 58.332850864955354, 54.04076794215611, 55.41514594214303, 54.713548115321565, 55.51936197280884, 56.61291115624564, 56.433911664145334, 54.198488576071604, 61.00432205200195, 65.97215897696358, 63.29798494066511, 59.41223961966378, 59.8527067729405, 61.395033155168804, 56.846189975738525, 50.78126376015799, 56.6612845148359, 59.121735436575754, 58.41865416935512, 60.43590382167271, 61.97544397626604, 59.07648181915283, 54.96356514522007, 62.731810978480745, 64.48643956865583, 62.77968406677246, 58.186320304870605, 60.17438752310616, 57.232311793736045, 53.325895581926616, 51.64506033488682, 51.503376143319265, 46.06125865663801, 48.725726059504915, 46.77857330867222, 49.21899604797363, 48.73179183687483, 52.11570698874337, 51.59429679598127, 56.682994161333355, 61.360563141959055, 66.00847026279995, 61.243958473205566, 57.260052476610454, 64.93139525822231, 68.2301915032523, 67.32975360325405, 65.87288311549595, 66.24946853092739, 67.91197095598493, 65.46861607687813, 64.50947284698486, 62.37934970855713, 62.64017118726458, 65.28726114545549, 67.37281158992222, 66.33689771379743, 74.66295187813895, 60.88623046875, 66.66471372331891, 4.237839204924447, 0.6028486170939037, 0.14709135570696422, 1.465757342321532, 2.8752494752407074, 5.18443181685039, 2.3329147824219296, 1.418404066136905, 0.30438342690467834, 2.039612429482596, 30.20617471422468, 49.04674673080444, 49.34214244570051, 30.03555474962507, 48.30371332168579, 44.55669920785086, 56.73936489650181, 19.228681019374303, 0.06075066514313221, 0.28681303401078495, 0.021839026162134748, 0.07503399013408593, 0.047041133112673245, 0.043980125936546495, 0.07129393903804676, 0.03505078490291323, 0.04185113071330956, 0.06896883701639515, 0.06405826551573617, 0.03814343555963465, 0.1265234529439892, 0.1594689336738416, 0.1666072713477271, 0.2295328447861331, 0.16926419734954834, 0.11390256589012486, 0.15031758616013186, 0.22400308293955667, 0.17208739157233918, 0.2510523114885603, 0.23912610858678818, 0.3143647313117981, 0.6867442610008376, 18.593327317919048, 79.60597678593227, 56.23233052662441, 40.41760172162737, 40.41802903584072, 92.30469213213239, 56.56295360837664, 1.4658540742737907, 0.14675126038491726, 1.4260495815958296, 6.877170630863734, 4.480279224259513, 12.88054188660213, 4.792563838618142, 0.6750403461711747, 29.34367397853306, 105.4887947354998, 89.81046949114118, 102.46204130990165, 88.72423676082066, 90.10900579180036, 88.17967864445278, 88.22632884979248, 91.22458076477051, 91.03295639583042, 82.8135848726545, 82.66808959415981, 86.80481079646519, 81.86102853502545, 78.32585457393101, 74.63451984950474, 71.01101343972343, 63.48845590863909, 66.45921380179269, 64.9066527230399, 72.36048562186105, 79.12451526096889, 77.88718700408936, 78.73663902282715, 77.63525921957833, 76.30180263519287, 60.5196852002825, 59.03500802176339, 59.13413797106062, 63.15234375, 61.663740839277, 61.293881280081614, 59.76972443716866, 59.258406502859934, 59.54406779153006, 58.34733785901751, 62.725502014160156, 66.27149432046073, 67.00549507141113, 75.33932426997593, 73.4712941305978, 72.06310272216797, 70.58913271767753, 65.39213030678886, 67.04153537750244, 71.93847288404191, 67.95079748971122, 72.19501427241734, 59.97425161089216, 59.85229682922363, 74.11223765781948, 71.2234754562378, 68.40075588226318, 66.85904094151088, 70.18822860717773, 67.32382678985596, 58.71937220437186, 55.53174713679722, 60.04921572549002, 53.87797859736851, 56.851599148341585, 56.03756557192121, 58.719191551208496, 56.63255023956299, 57.24262292044503, 56.1849160194397, 64.62041473388672, 70.85157312665666, 64.73764474051339, 61.55475834437779, 62.236140387398855, 65.0255433491298, 58.132065296173096, 54.42388813836234, 60.696482113429475, 61.54435689108712, 61.65695244925362, 63.53435570853097, 64.90723637172154, 61.568140574863975, 57.54573113577706, 67.27142347608293, 67.19156088147844, 63.811067717415945, 62.14822483062744, 64.59509549822126, 60.612506185259136, 57.0502724647522, 55.02742256437029, 53.558128697531565, 49.54226098741804, 52.569219384874614, 49.433479990277974, 50.22506741115025, 52.004706042153494, 54.18619721276419, 55.392876965659006, 59.6848452431815, 64.67841134752545, 69.67119925362724, 66.50282764434814, 58.93519714900425, 68.3578577041626, 71.24639756338937, 71.02091462271554, 68.19731262751988, 68.01621477944511, 71.34125437055314, 69.74614252362932, 69.40349211011613, 68.34428092411586, 65.7443344933646, 67.0262701851981, 68.25550379071916, 70.76387991224016, 77.00347341809953, 65.90139852251325, 66.44372626713344, 4.021338547979083, 2.1918357355254035, 1.4950396567583084, 3.0219580829143524, 5.707694138799395, 8.264717204230172, 5.283027189118521, 1.5175185991185052, 0.32226450741291046, 3.454049834183284, 45.38509818485805, 55.330575942993164, 63.713549750191824, 49.46088368552071, 50.89448465619768, 51.046163831438335, 66.0809747150966, 24.94719089780535, 0.4010922275483608, 0.5596182282481874, 0.15229991264641285, 0.1565933022648096, 0.16251428026173795, 0.18486485736710684, 0.2119354054863964, 0.15419793794197695, 0.1087553756577628, 0.20573637740952627, 0.1283219235816172, 0.21772644402725355], [0.05533530769337501, 0.07216947991400957, 0.06950405186840466, 0.09066254472626106, 0.057807913050055504, 0.2106042012040104, 0.011847899960620063, 0.08611958314265523, 0.03636878489383629, 0.09092621664915766, 0.11727202151502882, 0.025761596392840147, 0.21100776669170174, 22.661018167223247, 54.30434785570417, 44.22834471293858, 26.240677969796316, 36.36845908846174, 83.4079407283238, 18.34338324410575, 0.05038311824734722, 0.20981358577098164, 0.6840352777923856, 0.7309336098177093, 1.8071061628205436, 2.9501556158065796, 2.4071454278060367, 3.727745456354959, 75.58419963291713, 89.3169389452253, 89.06131471906389, 82.08637251172746, 83.13218062264579, 78.72689764840263, 79.02522550310407, 79.71065834590367, 82.16296250479562, 85.11796883174351, 83.77783502851213, 76.01386233738491, 81.04521969386509, 70.2801741191319, 66.75072547367641, 63.58158956255232, 60.87545381273542, 55.02748857225691, 57.186307770865305, 60.151090213230674, 67.20458875383649, 72.66617856706891, 73.42643656049455, 70.82863017490932, 70.62561076028007, 61.18915108272007, 55.0583941595895, 52.16525111879621, 52.16124548230852, 55.60111100333077, 55.80432496752058, 54.7023024559021, 53.58325685773577, 48.86983864648001, 49.3514530318124, 50.579109396253315, 54.53987094334194, 55.82440873554775, 63.107027598789756, 64.81609685080392, 68.30817113603864, 63.10645089830671, 62.678233419145855, 60.97527163369315, 64.10767241886684, 63.160869189671104, 65.85160078321184, 57.745033264160156, 57.85916090011597, 65.0157116481236, 62.85873372214181, 58.1836383002145, 62.084280558994834, 64.21656458718437, 58.921453612191335, 54.901055676596506, 53.739004203251426, 53.15387208121163, 55.944018500191824, 55.78987618855068, 54.03451108932495, 55.027432986668174, 53.264230319431846, 60.39401313236782, 60.9991386958531, 59.083256312779014, 54.69289806910923, 50.790341581617085, 57.11866705758231, 57.62042774472918, 57.59815876824515, 58.58501488821847, 54.966806479862754, 51.605737004961284, 47.70378153664725, 54.16611344473702, 55.14471510478428, 60.831165994916645, 56.287148339407786, 56.60515349251883, 55.05855744225638, 59.21819032941546, 58.16471835545131, 54.19963502883911, 57.27535935810634, 57.29211146490914, 54.80995437077114, 52.9924167905535, 52.06678124836513, 51.38606970650809, 48.25654200145176, 44.22284173965454, 43.16461372375488, 48.14891440527779, 47.81056840079171, 46.592132295881, 48.80325753348214, 55.11181885855538, 60.53119836534773, 62.590415137154714, 57.81136424200875, 61.59879602704729, 62.65078803471157, 58.8193359375, 61.47575732639858, 59.34587042672293, 62.94792079925537, 63.08726692199707, 63.05060127803257, 60.83148561205183, 61.9292106628418, 64.76558344704765, 66.12897287096295, 68.85964271000454, 68.0400401524135, 67.8459700175694, 67.15145587921143, 59.663875579833984, 44.43053034373692, 0.3876727862017495, 0.8493843280843326, 2.5997907476765767, 4.2858260699680875, 1.9026469332831246, 0.9583739340305328, 1.3075975605419703, 0.4410690138382571, 0.12973292358219624, 28.94076704978943, 36.87849160603115, 59.47020149230957, 27.49160385131836, 27.26559979575021, 38.674243109566824, 41.81075375420706, 20.115389278956822, 0.23143084294029645, 0.14207882753440312, 0.029561528204275028, 0.15267162770032883, 0.03308851591178349, 0.13126239579703125, 0.03218639681914023, 0.07321068511477538, 0.020008282702682272, 0.08081670305026428, 0.058383249677717686, 0.04850104870274663, 0.0522955115219312, 0.05780992829906089, 0.06633453337209565, 0.038552493788301945, 0.027015792039622153, 0.07388744237167494, 0.006008753711025098, 0.08059243365590062, 0.027545122296682427, 0.07341564340250832, 0.03546358525220837, 0.08069107229156153, 0.13065406201141222, 33.56201914378575, 62.28826577322823, 57.36429282597133, 34.2001417023795, 38.13615376608712, 94.90130342755998, 20.844861541475566, 0.08641603509230272, 1.229894227215222, 1.422097685081618, 2.6371544684682573, 2.3037180176803043, 2.5322516517979756, 1.1063471138477325, 5.12332284450531, 85.1613325391497, 92.42791843414307, 93.03133474077497, 85.1155091694423, 88.13748918260846, 82.96932874407086, 84.16835853031704, 81.39937632424491, 84.45865426744733, 86.27691446031842, 88.38369859967912, 80.44315133775983, 84.20309952327183, 74.37556048801967, 69.61362648010254, 65.35015623910087, 63.867466245378765, 57.46321780341012, 58.660784993852886, 63.09857164110456, 69.5188877923148, 73.34553868430001, 76.87728023529053, 74.6914255959647, 75.84199169703892, 64.05260794503349, 56.194956166403635, 54.338248116629465, 54.680224554879324, 58.31876686641148, 59.09825052533831, 56.735963753291536, 58.52710165296282, 51.84786088126046, 53.103667872292654, 53.0180869102478, 57.030820982796804, 59.079038756234304, 65.50050830841064, 66.73588412148612, 70.32399640764508, 67.26067461286272, 65.36990301949638, 64.60390581403459, 65.57120622907365, 65.16510486602783, 69.48350756508964, 57.09258352007185, 60.84299182891846, 68.65692206791469, 66.55754470825195, 62.02841009412493, 67.27596064976284, 66.6599681036813, 60.008547919137136, 54.867266586848665, 54.54721866335188, 56.072612285614014, 56.214112349918906, 56.10521323340279, 57.30772406714303, 56.00024332318987, 55.66418675013951, 63.85880184173584, 65.43951007298061, 62.163774899074006, 55.97033132825579, 51.695716176714214, 57.241643224443706, 62.4256386075701, 60.22125312260219, 60.92586299351284, 55.938675335475374, 54.30634893689837, 52.54297603879656, 57.08546509061541, 58.84599617549351, 62.5592941556658, 59.46899250575474, 57.7725133895874, 58.11239147186279, 60.566140856061665, 63.47424684252058, 59.34179878234863, 60.8164427621024, 60.32472569601876, 58.356134278433665, 58.26009280341012, 55.68551424571446, 54.98662274224417, 51.49172748838152, 48.22536890847342, 47.068247182028635, 50.370302132197786, 49.38218491418021, 48.88046939032418, 51.38794224602835, 58.54082434517996, 65.03902285439628, 63.42000920431954, 61.01133973257882, 63.23294980185372, 63.77049718584333, 62.9664238521031, 61.615895543779644, 62.974018233163015, 65.96719101497105, 66.34912654331752, 68.64180973597935, 62.58771228790283, 66.1750602722168, 67.28228351048061, 69.67816829681396, 70.44816071646554, 72.41679382324219, 68.70460060664585, 73.49815586635044, 65.34787722996303, 57.43732534136091, 0.45761758727686747, 0.30503691041043823, 0.6319730228611401, 5.3810193708964755, 4.592906049319676, 2.963198470217841, 1.5583432827677046, 0.22882453565086636, 0.14364367856511048, 29.78252567563738, 41.66913209642683, 65.71979345594133, 24.708068643297466, 27.417543002537318, 43.92536503928048, 50.05721630368914, 25.442607879638672, 0.2596404477953911, 0.07278736068734101, 0.06990747486374208, 0.11993261160595076, 0.07138731902731316, 0.1782516786562545, 0.06652510671743325, 0.10777349477367741, 0.050682996798838885, 0.060269739877964766, 0.03331157412113888, 0.07842243795416184, 0.20510130934417248, 0.10810027723865849, 0.16332451892750605, 0.1684351089809622, 0.15043101007384913, 0.24298387872321264, 0.1522788102073329, 0.20258199024413312, 0.157579295071108, 0.19439184186714037, 0.33862705369080814, 0.14577995107642241, 0.21948904730379581, 38.58854750224522, 75.41039044516427, 61.18147332327706, 36.331056935446604, 50.15427916390555, 102.77572468348912, 29.849030358450754, 0.2562444885926587, 0.8541002550295421, 4.4341036677360535, 5.254256001540592, 5.774695617812021, 13.392132537705557, 5.542348725455148, 4.907041055815561, 89.56698376791817, 94.63931465148926, 98.21183518001011, 87.9926539829799, 93.06459576742989, 85.61157580784389, 87.46041502271379, 84.92222418103898, 89.35133947644914, 90.03676537105015, 91.1357341493879, 81.70971066611153, 87.28110980987549, 75.60109070369175, 73.91875811985561, 69.58839062282017, 68.84398147038051, 59.75357682364327, 61.3930390221732, 66.3673655646188, 75.36968789781842, 76.5305095400129, 80.56037439618791, 77.93988909040178, 78.71336255754743, 66.52013560703823, 59.10238470349993, 57.84684869221279, 58.52157783508301, 61.44371918269566, 62.253205163138254, 60.20959404536656, 62.58812917981829, 54.74244914736067, 55.559953348977224, 55.51769093104771, 60.07386793409075, 61.857192584446494, 69.30680097852434, 69.1362088067191, 72.8742423738752, 70.07416697910854, 71.25219236101422, 68.170166015625, 72.07442828587124, 69.04999555860246, 73.38797133309501, 60.97441700526646, 62.18608556474958, 70.3619544165475, 68.94668974195207, 64.86326122283936, 67.60145596095494, 70.4274342400687, 63.00698743547712, 56.02848080226353, 55.261146068573, 56.10723168509347, 58.51579693385533, 60.62718078068325, 60.04506070273263, 57.65761797768729, 57.90913929258074, 67.56101049695695, 67.31675352369035, 62.495197023664204, 58.66558619907924, 53.414426054273335, 61.72523239680699, 62.347679819379536, 62.05203396933419, 63.39659377506801, 59.51802594321114, 58.50654888153076, 55.54630013874599, 61.699058532714844, 62.45427908216204, 66.9749229976109, 61.80951404571533, 60.16043554033552, 58.86798027583531, 65.4841730935233, 63.947043963841026, 58.6812196459089, 63.50156021118164, 62.63302843911307, 59.65742070334298, 60.09002249581473, 60.733432633536204, 57.941299029758994, 53.92851284572056, 50.94516134262085, 49.73515340260097, 53.861990792410715, 54.271343912397114, 52.08689628328596, 53.403055327279226, 61.246709959847585, 68.56359386444092, 66.63177926199776, 63.326903343200684, 66.70813996451241, 69.67888396126884, 64.46956934247697, 67.47108691079276, 63.706476484026226, 68.56979860578264, 69.58127566746303, 71.77465520586286, 66.36537837982178, 70.62185873304094, 69.48605755397251, 72.60190078190395, 74.40630626678467, 74.58043507167271, 72.36363315582275, 76.64067322867257, 69.58126871926444, 56.5353171484811, 0.48166161136967794, 1.6484484991856982, 6.693088965756552, 12.802868843078613, 6.956714042595454, 6.057558953762054, 3.044727546828134, 0.9180472408022199, 0.2534651005906718, 39.66219357081822, 49.49099370411464, 76.49580328805106, 41.811236654009136, 32.797727721078054, 49.31726789474487, 57.90251071112496, 33.10249655587332, 0.46654195125613895, 0.2363515246127333, 0.14430602373821394, 0.21167697863919394, 0.19896679637687548, 0.24525401262300356, 0.0926563927371587, 0.12989218932177338, 0.13092848871435436, 0.1305763968931777, 0.07858868581908089, 0.16482131289584295], [0.04241642502269574, 0.09656655256237302, 0.02319883069555674, 0.04246530329276409, 0.05969724631203072, 0.05877110707972731, 0.08786364884248801, 0.05924534198961087, 0.055517697906387706, 0.0797493267538292, 0.08955404920769588, 0.027281954186037183, 0.1593205380652632, 39.584929602486746, 46.62174899237496, 34.21175561632429, 32.51593310492379, 51.2699305670602, 66.17164175851005, 6.497174518448966, 0.06980397113199745, 0.2315242907830647, 1.3232219964265823, 1.8838776775768824, 2.438135479177747, 2.2207532695361545, 0.6982864673648561, 32.986409527914866, 93.85004098074776, 82.51863384246826, 85.6184058870588, 79.61544023241315, 81.76948601858956, 72.96304035186768, 74.02025740487235, 74.34942136492047, 81.05531542641776, 81.74930150168282, 81.68751811981201, 81.51545292990548, 78.38533115386963, 72.82579953329903, 65.6859209878104, 60.42555100577218, 58.48604474748884, 57.863625117710654, 58.874699183872764, 60.39926597050258, 63.930020877293174, 72.34014129638672, 71.19701671600342, 71.35408769335065, 69.47009754180908, 56.85756417683193, 51.1607118334089, 52.78342192513602, 51.293359892708914, 56.35914209910801, 57.475933006831575, 56.95084374291556, 53.11502122879028, 51.631445339747835, 50.40009948185512, 52.79139845711844, 53.623271533421104, 56.904210908072336, 59.37305872780936, 62.96619456154959, 65.58902141026088, 64.7449403490339, 61.00327982221331, 61.59405040740967, 60.31952844347273, 64.3528048651559, 60.51938642774309, 57.12823820114136, 61.58849879673549, 62.58300140925816, 59.63497107369559, 63.097251483372276, 64.12040151868547, 56.18930728094918, 53.44660316194807, 55.03380101067679, 54.312522411346436, 56.598674297332764, 56.50701366152082, 56.33462190628052, 56.485696588243755, 55.07740790503365, 55.74816615240914, 55.94710002626692, 55.14651468821934, 63.19675663539341, 60.06738526480538, 56.59914330073765, 50.200324875967844, 55.528679507119314, 58.531472069876536, 57.05627918243408, 54.57462583269392, 51.88616977419172, 49.803944042750764, 52.382000173841206, 51.15206132616316, 53.115049021584646, 57.98306117738996, 57.427319935389924, 54.913076060158865, 62.09239605494908, 57.4503219468253, 49.46342325210571, 57.26997103009905, 56.60143273217337, 59.17333970751081, 57.72123915808541, 58.36334650857108, 54.789009026118684, 54.271180629730225, 49.26171357291085, 42.995136737823486, 43.66150719778878, 45.762176922389436, 46.18956061771938, 47.14349617276873, 54.77797876085554, 59.49023314884731, 60.90557425362723, 63.5750652040754, 59.84329891204834, 61.30007907322475, 57.62092454092843, 59.37959003448486, 58.2331337928772, 60.96591241019112, 61.486401966639924, 65.30313083103725, 59.5176021030971, 67.88868059430803, 63.57027094704764, 71.83743912833077, 64.13686874934605, 72.0886651447841, 63.99860654558454, 71.39335891178676, 63.279912676130024, 73.05150481632778, 23.15924916948591, 0.30157461762428284, 1.2803719128881181, 1.7906675934791565, 3.48734364765031, 1.1008150449820926, 2.429535997765405, 0.19781454892030784, 0.5397071338125637, 10.213670407022748, 46.94082069396973, 40.30639580317906, 49.89712980815342, 35.03971338272095, 44.57510846001761, 39.16436556407383, 23.525757959910802, 0.128933595759528, 0.20261314857218946, 0.1995821597852877, 0.14649157146258013, 0.12136091424950532, 0.1428573786148003, 0.03851106922541346, 0.12600948980876378, 0.069557696846979, 0.0609005263873509, 0.05387963294716818, 0.09406910264598471, 0.0614785635843873, 0.08186174875923566, 0.014855170555944954, 0.018160204369840876, 0.045466463680246046, 0.07985181268304586, 0.06163172250879662, 0.06262401890541826, 0.006780953703647745, 0.00603467078014676, 0.04884895396285823, 0.028427626638274108, 0.36691737707172123, 52.78068780899048, 53.50933149882725, 44.956932817186626, 29.687099116189138, 50.9139152935573, 80.20144435337612, 7.083516929830823, 0.04305629711598158, 0.7069368660449982, 1.2237551680632999, 2.039995014667511, 2.893181473016739, 3.8637338621275763, 0.5629093402198383, 39.063849449157715, 98.57050813947404, 85.8749611718314, 87.32369531903947, 83.75430842808315, 87.96413857596261, 76.8386482511248, 77.11318547385079, 78.72352082388741, 84.85360377175468, 83.359372820173, 86.09756755828857, 84.20346082959855, 82.41982351030622, 75.28642068590436, 69.18794509342739, 62.51012870243618, 59.007298605782644, 60.19761535099575, 60.252846581595286, 63.69717979431152, 68.26364707946777, 74.37663745880127, 75.62814698900495, 73.91319261278424, 71.44527585165841, 59.89608437674386, 53.37803486415318, 54.58517319815499, 53.988816261291504, 57.61723157337734, 59.7865321295602, 58.91883414132254, 55.39302635192871, 54.330486978803364, 54.440643719264436, 55.28968232018607, 57.20171192714146, 60.031879970005576, 62.92507512228829, 64.66501522064209, 68.53473104749406, 68.90725871494838, 63.22435488019671, 66.91842024666923, 63.806009428841726, 66.42875984736851, 62.05889878954206, 60.11375754220145, 65.3186114174979, 63.815639632088796, 62.405884878976, 65.76466492244175, 65.98627076830182, 57.886505535670686, 54.233816691807334, 57.18681846346174, 57.15247351782662, 58.14115353993007, 59.97143064226423, 58.5131288255964, 59.358307702200754, 57.634119170052664, 58.80714184897286, 58.39450223105294, 58.2694103377206, 65.46835204533168, 62.05755083901541, 58.85190214429583, 53.74214826311384, 57.05863809585571, 60.97925295148577, 58.80707236698696, 56.095697675432476, 54.0559150150844, 55.35579095567976, 55.527609484536306, 53.90760571616036, 53.505794865744456, 60.28229999542236, 60.77644198281424, 56.51323577335903, 65.57393687111991, 63.16728932516915, 52.54475825173514, 58.72291578565325, 58.73674270084926, 61.813974789210725, 60.15336227416992, 60.32990905216762, 59.30211762019566, 56.81925180980137, 53.13904809951782, 45.95682723181588, 45.778428758893696, 49.24861969266619, 48.743228571755544, 48.87326410838536, 58.94248580932617, 61.6223851612636, 62.01693861825125, 66.09600366864885, 62.456558091299875, 62.96693107060024, 59.59073884146554, 62.99687780652727, 59.21894073486328, 63.63124833788191, 62.82101195199149, 69.12029048374721, 63.422190938677105, 70.05711609976632, 66.1187242780413, 73.10837582179478, 69.74045194898332, 74.39037404741559, 67.6051732472011, 74.35283293042863, 68.21218177250454, 78.62026364462716, 32.71935551507132, 0.30276441520878244, 0.283298982573407, 2.369567398514066, 7.776640125683375, 4.254875319344657, 3.603857989822115, 0.2971805062677179, 0.5615969449281693, 8.717901297977992, 51.35398639951433, 46.46666519982474, 46.047011375427246, 27.012282371520996, 52.62529829570225, 44.73425694874355, 31.15055649621146, 0.11939625681510993, 0.24176324850746564, 0.08282972646078893, 0.16431845059352262, 0.07883562506841761, 0.06220503031675305, 0.04061389335298112, 0.07234375484819923, 0.03478702477046421, 0.1226553555045809, 0.009826680695238923, 0.06262568131621395, 0.10727958234825305, 0.19298127612897328, 0.12091096410793917, 0.09821506696087973, 0.12202909482376915, 0.1682165257100548, 0.2117266881146601, 0.17075511520462378, 0.1679105335580451, 0.12964437476226262, 0.2423647019479956, 0.1332930475473404, 0.6336789684636253, 59.78736591339111, 64.21059608459473, 45.42970561981201, 50.019233976091655, 66.01207637786865, 87.65909876142229, 11.097012264387947, 0.21369779163173266, 0.5373529972774642, 4.745225327355521, 5.500029853412083, 9.377930658204214, 9.02080454145159, 1.3802689867360252, 42.324958665030344, 102.86231313432965, 89.36219256264823, 91.62912573133195, 88.16335037776402, 89.8372825895037, 80.44031647273472, 80.26808452606201, 82.88424110412598, 86.77886622292655, 87.64396558489118, 88.52603244781494, 87.9520765032087, 83.97920772007534, 76.94795036315918, 71.79015663691929, 65.89192117963518, 63.24352496010916, 62.93082128252302, 63.810768944876536, 67.27162497384208, 70.12202617100307, 77.89266218457902, 77.40037536621094, 77.18690586090088, 75.8362455368042, 64.32113497597831, 55.48192507880074, 58.38595594678606, 55.307646887642996, 62.5642204284668, 63.79539258139474, 64.88878195626395, 60.93010139465332, 57.66212041037423, 56.92432941709246, 59.80763380868094, 61.18648297446114, 62.68001215798514, 64.79615552084786, 68.04397283281598, 72.66174561636788, 73.0733082635062, 69.29318945748466, 69.11123003278459, 66.35933344704765, 71.64046464647565, 66.68412004198346, 61.47494438716343, 67.90475177764893, 66.13927704947335, 66.99382209777832, 69.90091364724296, 70.66106046949113, 58.870620591299875, 55.51126037325178, 58.03754200254168, 58.41570118495396, 60.74746799468994, 60.85370595114571, 61.126408849443706, 62.215775217328755, 60.19003486633301, 60.569767815726145, 60.70257568359375, 59.249582290649414, 69.66867010934013, 66.62857614244733, 58.060495376586914, 52.5307228905814, 60.066898890904014, 63.76135335649763, 60.83338941846575, 57.76339735303606, 57.664924008505686, 58.769447871616904, 58.34896373748779, 59.813359124319895, 55.83696413040161, 62.517938477652415, 62.82612582615444, 58.975322995867046, 65.57381875174386, 63.17566885266985, 57.70616851534162, 60.246704374040874, 61.883741651262554, 64.13418674468994, 64.72854260035923, 63.58443137577602, 62.08554513113839, 58.538913590567454, 53.60103382383074, 48.25767803192139, 48.20207159859793, 52.38221556799752, 52.840233870915, 51.86370277404785, 60.84698009490967, 65.95826257978166, 65.5507298878261, 69.11306435721261, 66.06001199994768, 66.13303061894008, 66.50023596627372, 67.45001302446637, 62.95601545061384, 66.38800866263253, 67.02610342843192, 73.13210391998291, 67.24026080540249, 72.25991739545549, 70.45504638126918, 77.59871864318848, 70.00858293260846, 75.86615753173828, 72.60438823699951, 78.11816596984863, 72.06562491825649, 79.09477697099958, 32.3128650529044, 0.5817609429359436, 3.8345318862370084, 6.785957719598498, 11.208939058440071, 5.7210346800940375, 5.999895419393267, 0.8709477367145675, 0.6209233243550573, 13.43997609615326, 61.45660809108189, 52.36436217171805, 68.42238562447685, 44.758905683244976, 54.98532690320696, 54.93432365145002, 37.650780405317036, 0.17330289206334523, 0.28950643805520876, 0.255666295332568, 0.17478307549442562, 0.15612618518727167, 0.31782474422029083, 0.1287464422306844, 0.14737369412822382, 0.08024039611752544, 0.20576782072229044, 0.1499995296554906, 0.22951039884771618], [0.07226940098085574, 0.04593956882932356, 0.04194581009713667, 0.039808217835213454, 0.12942809851041862, 0.022639984165185263, 0.1387935916760138, 0.035806533814008744, 0.17612588272563048, 0.05638689787260123, 0.1368200590035745, 0.09277866474751915, 1.3719690378223146, 49.49808086667742, 45.434930665152415, 30.623698915754044, 31.503695215497697, 69.8612950188773, 44.8585775920323, 1.379635506442615, 0.026078401000372002, 2.1915304490498135, 0.9444941473858697, 0.6818982724632535, 3.2240557755742754, 2.104803902762277, 4.36679516519819, 68.30571842193604, 86.92345823560441, 83.04067284720284, 80.93074812207902, 79.88239697047642, 78.65069675445557, 74.64497688838414, 70.36847182682583, 71.2351484298706, 75.93676512581962, 80.72995907919747, 78.41534042358398, 80.90531771523612, 77.8846995489938, 74.78314876556396, 65.101945740836, 57.37927661623274, 52.0462771143232, 54.16305276325771, 55.93802220480782, 61.89060647147042, 68.9051742553711, 72.24203968048096, 71.08975737435478, 71.82999760763985, 65.2385264805385, 52.649450234004426, 50.37553065163748, 51.664143562316895, 51.376026085444856, 55.215548515319824, 56.748870032174246, 57.453063011169434, 53.89240653174264, 51.720892974308555, 50.942256995609824, 50.212605816977366, 53.294878823416575, 56.18101808003017, 60.15689195905413, 61.353906767708914, 64.976669720241, 64.88325119018555, 60.642612729753765, 63.467708587646484, 63.45927347455706, 61.515292576381135, 56.484616143362864, 63.63150542122977, 60.98352609361921, 58.366063254220144, 61.93604074205671, 60.98518671308245, 56.12574168613979, 57.839976923806326, 59.35279083251953, 62.907405853271484, 59.38125760214669, 56.75268111910139, 59.265472820826936, 55.50677531106131, 53.71923310416085, 55.604491301945274, 61.02877276284354, 58.99671649932861, 56.690779617854524, 59.619532176426475, 57.27077007293701, 59.51810932159424, 59.761907713753835, 52.16307980673653, 54.37664038794381, 57.545856203351704, 57.05645636149815, 49.72596093586513, 48.82184396471296, 55.156464508601594, 52.69034733091082, 48.066474028996055, 51.91194759096418, 58.687813486371724, 58.5339595249721, 59.02529444013323, 42.521637848445344, 52.11216688156128, 54.34310143334525, 57.20001309258597, 57.04129539217268, 57.60882772718157, 55.29262488228934, 58.51255212511335, 56.920698983328684, 55.10845940453665, 46.32468918391636, 43.936322348458425, 44.03639030456543, 45.78266021183559, 47.14094965798514, 56.8084716796875, 60.78466864994594, 59.97901807512556, 59.22597231183733, 61.64733614240374, 58.36812686920166, 55.7701050894601, 54.33050782339913, 58.39333493368966, 59.26345089503697, 64.11671202523368, 60.61715453011649, 62.58983843667166, 66.37575898851667, 66.48521396092006, 65.94322667803083, 70.47948319571358, 66.21711771828788, 66.77315425872803, 66.62656811305455, 68.58962876456124, 69.2748670578003, 65.98365824563163, 5.461207228047507, 1.3061403930187225, 3.2815948937620436, 2.784631069217409, 1.9514447833810533, 0.45383350604346817, 0.048530168033071926, 0.03308184251987508, 0.8999120082174028, 46.05789920261928, 38.42769323076521, 45.26639516013009, 28.87898540496826, 26.389279093061173, 52.201016971043174, 25.11538072994777, 0.14055334510547773, 0.08367698599717446, 0.07448272792888538, 0.04880570414076958, 0.023133029762123312, 0.13236473021762712, 0.04213446658104658, 0.038028142281941006, 0.03887530682342393, 0.01684426882171205, 0.13401593161480768, 0.012092209038590747, 0.026999152664627348, 0.050594363162027936, 0.016443660050364475, 0.046532048644231896, 0.13913513906300068, 0.07215174979397229, 0.04742095326738698, 0.0334286383752312, 0.13020047492214612, 0.04836441210604139, 0.09836228870387588, 0.2879921378833907, 2.8985752293041775, 61.518551281520296, 55.40420600346157, 39.21514299937657, 26.402482407433645, 77.63777446746826, 52.04318516595023, 1.0760266951152255, 0.1750860142388514, 2.1860596111842563, 1.5043110506875175, 2.1411099774496893, 3.6056404198919023, 1.6084394689117159, 6.438895634242466, 77.2935676574707, 90.39484078543526, 86.36953394753593, 83.21660123552594, 85.122207232884, 82.95199993678501, 79.77515847342355, 71.3297620500837, 74.73428903307233, 78.05880056108747, 82.37425027574811, 80.55225890023368, 85.38261181967599, 80.02073560442243, 77.12713745662144, 68.75876876286098, 60.55822685786656, 55.631693499428884, 58.50347082955496, 57.3510947227478, 64.69026497432164, 71.68066692352295, 75.60641302381242, 73.83086340767997, 74.32961899893624, 68.03405080522809, 54.882684639522004, 54.22103548049927, 55.13286147798811, 53.425237451280864, 57.403216634477886, 60.592947006225586, 60.01407173701695, 57.83971984045846, 56.308131899152485, 54.10362829480852, 53.42703356061663, 55.791543756212505, 59.58643095833914, 62.941903659275596, 65.69218131474086, 68.5212515422276, 69.78057779584611, 64.20659392220634, 66.0387018748692, 67.54641233171735, 63.96596390860421, 61.15584141867501, 66.82057571411133, 62.826216152736116, 59.75373663221087, 65.65445259639195, 61.977855001177105, 58.16406522478376, 58.91213607788086, 62.59348624093192, 65.39056696210588, 63.65448311397007, 59.774984223502024, 62.543493952069966, 58.9323970249721, 56.61588151114327, 58.432960510253906, 61.84679807935442, 62.20606858389718, 58.588829449244905, 59.54297692435128, 60.94935485294887, 62.063838958740234, 61.35034234183175, 53.829445430210654, 55.384952545166016, 60.01667731148856, 58.59862640925816, 53.20600094114031, 51.67383629935128, 56.37964275905064, 53.812279905591694, 48.870460510253906, 53.25100094931466, 59.22335284096854, 61.77353627341134, 60.75916181291853, 43.59440496989659, 55.35503707613264, 57.6810507774353, 60.118704659598215, 58.88835934230259, 59.61194474356515, 59.747705595833914, 60.328366552080425, 58.26268448148455, 55.12990154538836, 48.85617501395089, 46.45261594227382, 47.062028544289724, 47.030438559395925, 49.52872589656285, 59.97261183602469, 63.22419507162911, 62.624572481427876, 62.574517658778596, 65.05118915012905, 62.673724038260325, 58.858030455453054, 56.23928567341396, 62.08212661743164, 61.357783862522666, 67.25287873404366, 63.981249945504324, 64.85255404881069, 67.68245111192975, 68.8188567842756, 68.54951681409563, 73.16448252541679, 67.50884342193604, 68.12630203792027, 68.13737746647426, 71.81521184103829, 71.07207420894078, 73.73270620618547, 9.190187726702009, 0.5054827502795628, 0.9463459508759635, 3.589018374681473, 3.6869378175054277, 2.015045553445816, 1.3475805350712367, 0.0845687777868339, 0.526516033070428, 47.321189403533936, 48.47869675500052, 45.1493319102696, 28.553458826882498, 32.22749948501587, 58.58557769230434, 31.08887038912092, 0.05381575905318771, 0.11814416971589838, 0.03298968728631735, 0.029971885827503035, 0.029945202437894683, 0.0677821606929813, 0.02417334777835224, 0.04945495019533804, 0.07402158874486174, 0.03261140062074576, 0.07859297416039876, 0.028168409297774945, 0.1666753962635994, 0.08609177677759103, 0.09846257617963211, 0.15440634318760463, 0.2066684809646436, 0.12520922560776981, 0.17174076874341282, 0.1636098429028477, 0.24915757030248642, 0.15507594868540764, 0.23827346148235456, 0.4450340467904295, 3.5861264041491916, 74.49529184613908, 62.96571513584682, 41.80023070744106, 48.040928976876394, 84.68415805271694, 62.11757632664272, 2.5263865036623816, 0.23088855775339262, 5.378189717020307, 3.874365040234157, 5.573776296206883, 9.743780238287789, 4.567142128944397, 5.854298523494175, 81.57896641322544, 94.32627746037075, 91.14742101941789, 86.86674009050641, 91.09832504817417, 85.53613921574184, 84.86481121608189, 77.11504064287458, 80.37375273023332, 82.05835737500871, 87.36480781010219, 84.81420053754533, 88.47748538425991, 82.95783642360142, 80.20497403826032, 71.13112000056675, 62.830030713762554, 57.953083174569265, 62.11516530173165, 60.386300631931846, 67.76936612810407, 74.9767325265067, 78.59420789991105, 75.81603322710309, 77.75650528499058, 72.61609595162528, 58.04116548810686, 58.01942457471575, 57.45895160947527, 56.96169682911464, 60.67541517530169, 64.24724783216203, 63.82887595040457, 62.59072085789272, 57.12254067829677, 58.01325804846627, 57.52255194527762, 58.57027775900704, 64.51724093300956, 64.6820730481829, 67.5456827708653, 71.58158561161586, 73.29842294965471, 67.11822264535087, 69.50131579807827, 70.25238132476807, 67.42765372140067, 59.45253917149135, 69.45837593078613, 67.8317540032523, 63.52924183436802, 68.78975772857666, 65.70049136025565, 60.92996937888009, 61.764712061200825, 63.49318068368094, 66.85009166172573, 65.96602371760777, 62.436234610421316, 62.83586720057896, 62.615352221897666, 58.08286510195051, 60.91117450169155, 65.66342966897147, 62.428181648254395, 60.83119378771101, 63.14524269104004, 62.95755795070103, 65.94636031559536, 63.54190840039934, 54.9043630191258, 57.56045436859131, 62.871664319719585, 60.4465206691197, 57.2749285697937, 56.89331265858242, 59.13734803880964, 57.25337873186384, 52.98624331610543, 56.74894993645804, 62.69681985037667, 64.93737765720913, 61.065869195120676, 46.43385233197893, 58.198993819100515, 58.398719787597656, 63.50551373617989, 62.18741961887905, 64.01055744716099, 62.8960177557809, 64.86386571611676, 60.6677235194615, 59.31755651746477, 50.878521169934956, 48.71827411651611, 50.065908500126426, 52.15074675423758, 52.86094645091465, 64.13017068590436, 65.99124567849296, 65.06180599757603, 65.91817842211042, 67.78838334764752, 65.3077791758946, 63.03892830439976, 60.73853955950056, 65.29613399505615, 67.03912435259137, 70.9114943913051, 68.77072661263603, 69.07368196759904, 71.42408384595598, 71.58303778512138, 71.15971183776855, 76.94629669189453, 71.10605090005058, 73.46681254250663, 70.45535905020577, 74.87110601152692, 75.7606838771275, 72.8993045261928, 9.276268090520587, 2.5215129937444414, 9.834001728466578, 10.146859134946551, 7.270630180835724, 4.428012268883841, 1.6062450323786055, 0.159206571323531, 1.369354235274451, 59.80456270490374, 51.982221671513145, 58.648667335510254, 41.93303162711007, 36.90016998563494, 68.62497425079346, 36.74485342843192, 0.1889772274132286, 0.11125858633645944, 0.16713770931320532, 0.1672837571906192, 0.11011163823838745, 0.1813152642654521, 0.08189184857266289, 0.2674285370324339, 0.18056074689541543, 0.15421091153153352, 0.18510471949619905, 0.07611930011106388], [0.04732745114181723, 0.08230116803731237, 0.12553432530590466, 0.024908004428393075, 0.07023380949561085, 0.08266264399779694, 0.03961232816800475, 0.08842453267425299, 0.1326922726418291, 0.07168310601264238, 0.18311492912471294, 0.1192044485360384, 6.730753847530909, 63.09481961386544, 37.292378425598145, 36.94903319222586, 40.27019221442086, 65.47137451171875, 26.152845791407994, 0.17441079047109398, 0.17389772300209316, 1.590590740953173, 0.38801843194024904, 0.47786186954804827, 0.9128106875079018, 0.4494474014001233, 22.896447454180034, 88.5581122807094, 81.37618323734829, 80.98046943119594, 78.04773208073208, 80.98058755057198, 75.66643851143974, 73.90043572017125, 65.43443093981061, 67.82172775268555, 67.6865644454956, 73.29740851266044, 77.57043252672467, 79.41536685398647, 75.10009779248918, 74.25680882590157, 64.82853412628174, 58.52072320665632, 53.51333366121565, 54.952427182878765, 57.38354628426688, 62.58116013663155, 68.655608858381, 71.61615984780448, 67.99732957567487, 72.29469312940324, 60.20309053148542, 50.855776241847444, 51.27478040967669, 51.4081198147365, 50.9577236856733, 54.733350481305806, 54.153193269457134, 56.67391633987427, 55.643015589032856, 54.3009432383946, 54.285938603537424, 54.61671107155936, 54.7644818850926, 54.87636177880423, 57.79857955660139, 63.19350487845284, 64.43351513998849, 66.83103970118931, 60.83854498182024, 58.13776281901768, 60.073193958827424, 58.775075912475586, 62.11391462598528, 59.901545660836355, 56.024138178144185, 60.66698006221226, 60.50269685472761, 55.40409483228411, 60.51870550428118, 62.83829212188721, 65.25004659380231, 61.73158999851772, 63.199125971112935, 60.35604122706822, 59.04727159227644, 59.12214538029262, 58.955986159188406, 57.5749100957598, 58.224153246198384, 59.773268018450054, 58.775520597185405, 55.95108481815883, 59.83630207606724, 57.259760652269634, 58.997043064662385, 55.97542783192226, 58.33237143925258, 55.77766472952706, 58.33784661974226, 49.38146230152675, 48.710068293980186, 51.85059152330671, 50.152423994881765, 48.54137992858887, 49.58660439082554, 47.39265857424055, 51.89667545046125, 38.77290405545916, 47.24062851497105, 59.86619322640555, 57.52263184956142, 58.89034652709961, 59.34730175563267, 57.92026335852486, 56.560334137507844, 58.06579337801252, 58.15659243719918, 55.82382508686611, 48.627429894038606, 43.904371057237896, 43.29860625948225, 47.19584737505232, 47.02687413351876, 55.70175565992083, 57.904317242758616, 61.313878195626394, 59.549661091395784, 60.854129791259766, 57.349715505327495, 51.84160055433001, 51.3206593649728, 59.264590399605886, 56.67339522497994, 62.26061889103481, 60.44281727927071, 62.424777030944824, 63.98814255850655, 65.77844320024762, 64.26261724744523, 66.18374552045549, 63.881675311497276, 70.15682274954659, 63.37997368403843, 71.7709379196167, 65.10571166447231, 76.6773180280413, 36.025395257132395, 0.24579252515520367, 3.2843279242515564, 6.962334700993129, 5.4611082162175855, 1.6774000142301833, 0.5128450723631042, 0.39542705725346294, 0.3764129046882902, 25.21069438116891, 47.12169272559029, 42.35735464096069, 36.26078980309622, 23.852498735700333, 53.868438720703125, 26.011019161769322, 0.1027639317991478, 0.07499210416738476, 0.12527227508170263, 0.003697778364377362, 0.08127516880631447, 0.05297255037086351, 0.13875032828322478, 0.14942240848072938, 0.10325057032917227, 0.06387594994157553, 0.1929114820169551, 0.047809828471924574, 0.020336403577987636, 0.0726447394117713, 0.045851783361285925, 0.025658543886882917, 0.03415909828618169, 0.02552391236115779, 0.04757785091974905, 0.05376596476084419, 0.125830953674657, 0.043978236216519556, 0.23424926027655602, 0.24271479887621744, 10.735371555600848, 71.73159721919468, 43.10569647380284, 44.54040220805577, 36.49179308755057, 77.25401851109096, 28.84927143369402, 0.11789339674370629, 0.7689244598150253, 1.8365259213106973, 1.3182811758347919, 2.16326886841229, 2.707663267850876, 0.5353676038128989, 27.648235355104717, 94.77663884844098, 85.39307580675397, 85.84732123783657, 80.40677751813615, 85.07147148677281, 79.48721122741699, 75.37436403547014, 68.2676978792463, 72.00936535426548, 70.06153515407017, 76.83743231637138, 80.7994132723127, 82.6974526814052, 77.48089109148297, 77.22437749590192, 67.08557306017194, 61.91550186702183, 55.74387216567993, 58.3749361038208, 61.82057557787214, 66.27620519910539, 69.23071125575474, 72.41605731419155, 70.80530507223946, 74.88329315185547, 62.91252667563302, 54.169771671295166, 54.59003346306937, 53.76978472300938, 55.18688719613211, 57.158730370657786, 57.85739605767386, 59.32573454720633, 58.785261971609934, 56.99449927466256, 55.39965493338448, 57.648699964795796, 57.30312088557652, 59.13683387211391, 59.69158499581473, 65.46674701145717, 68.52597631726945, 68.17734350476945, 63.395815576825825, 61.593105452401296, 62.05954497201102, 61.77771214076451, 66.02645914895194, 64.6494790485927, 60.22241347176688, 62.87613895961216, 61.68047904968262, 55.29673474175589, 63.77930055345808, 67.47745146070207, 66.05199377877372, 63.88262721470424, 62.59175613948277, 64.69763006482805, 61.14364038194929, 63.22045694078718, 62.529875482831685, 60.38814190455845, 60.42562048775809, 61.71792984008789, 61.89345523289272, 58.20835304260254, 60.56846850258963, 59.715007373264854, 62.11472061702183, 59.34553691319057, 59.93416050502232, 56.80518170765468, 59.48323631286621, 51.64552933829171, 51.694799014500205, 53.640294619968955, 51.94510439464024, 53.731785024915425, 52.17334577015468, 49.83447095326015, 50.62396349225725, 41.038079329899375, 51.358832768031526, 60.88629995073591, 60.30456897190639, 61.42793982369559, 60.19632298605782, 59.69923496246338, 60.100257192339214, 60.632913044520784, 58.57268878391811, 59.03085994720459, 51.703949792044504, 45.75449568884713, 44.953246797834126, 48.29064376013619, 48.880320004054475, 58.875199454171316, 61.635294914245605, 62.28005300249372, 62.09736401694161, 63.228384835379465, 60.139104570661274, 55.14563921519688, 55.65342746462141, 62.03207179478237, 60.51375838688442, 64.49701472691127, 63.956382342747276, 65.42318180629185, 66.58125891004289, 67.49390479496547, 67.20580468858991, 69.023300579616, 69.44891248430524, 70.83921228136334, 66.92461109161377, 73.19107328142438, 68.82253238133022, 77.43892397199357, 45.98987633841378, 0.3223888693111283, 0.5287690950291497, 3.3039924119200026, 4.812341885907309, 3.1749391768659865, 1.3632647906030928, 0.308500560266631, 0.4099420883825847, 23.966195583343506, 55.07490655354091, 44.92775385720389, 33.19432742255074, 28.318149396351405, 60.22517190660749, 32.257637296404155, 0.1402741822281054, 0.0846010082002197, 0.07341047296566622, 0.01641203014047018, 0.13897933385201863, 0.03809144620650581, 0.10081397143325635, 0.0465062948475991, 0.03352144160973174, 0.000899329359526746, 0.1199851573577949, 0.027282346040010452, 0.1403320748358965, 0.15062185483319418, 0.13183748136673654, 0.08158442471176386, 0.26660463267139023, 0.16579695125775679, 0.17072684743574687, 0.15869572944939137, 0.31154197135141914, 0.167517091812832, 0.30744760962469236, 0.45595756492444445, 13.086492572511945, 83.9756988797869, 50.774381569453645, 46.50412293842861, 56.26203407560076, 87.70485264914376, 40.786012581416536, 0.2670517329658781, 0.8101576758282525, 5.699113547801971, 4.085466946874346, 5.574889745031085, 6.108043696199145, 1.705255233815738, 27.691692863191875, 103.84373228890556, 89.50972366333008, 89.87121064322335, 86.69379942757743, 90.56057616642543, 81.68924127306256, 80.96173708779472, 72.03182888031006, 76.08482428959438, 74.02339104243687, 79.59440108707973, 84.34072249276298, 87.64882932390485, 82.01012298039028, 79.35357652391706, 70.0043306350708, 63.602955273219514, 58.11623729978289, 59.867450850350515, 65.69673933301652, 67.74854237692696, 72.01884964534214, 75.97886426108224, 71.50547504425049, 78.5087033680507, 68.1661708014352, 56.75119073050362, 57.30515323366438, 56.176348890577046, 56.70234489440918, 61.557954515729634, 61.83024747031075, 62.843718664986746, 62.086135728018625, 61.19659955160958, 59.67158113207136, 61.48354625701904, 60.52478517804827, 61.7028591973441, 63.93621867043631, 69.1448106765747, 72.25698525565011, 72.4741928918021, 65.60256344931466, 65.34542451586042, 66.39312253679547, 65.10230009896415, 68.52880423409599, 67.40176473345075, 60.50412123543875, 65.40788882119315, 63.93236936841692, 57.361961705344065, 64.84824616568429, 70.0518285206386, 70.0209298815046, 66.36729608263288, 67.80828993661063, 68.25458662850517, 64.3779364994594, 65.1906464440482, 66.0337825502668, 62.67710781097412, 63.17827442714146, 65.02797521863664, 63.48739978245327, 62.81895528520857, 64.67664650508335, 62.13113226209368, 63.78851386478969, 61.33428505488804, 62.50605705806187, 58.546459334237234, 61.470761571611675, 53.21460975919451, 56.340493134089876, 57.02941049848284, 58.28159052985055, 56.32017312731062, 56.65179327556065, 52.063129970005576, 56.2372533253261, 43.20991597856794, 50.67637375422886, 62.93592126028878, 63.08499486105782, 65.31709671020508, 64.24509389059884, 63.59993280683245, 61.73507799421038, 64.31999547140938, 64.27932071685791, 60.62072590419224, 54.5862466948373, 48.82184049061367, 49.06171315056937, 52.695832933698384, 51.719624928065706, 63.841236795697895, 63.79494094848633, 65.52275644029889, 64.99478367396763, 65.5022314616612, 62.661279814583914, 57.97767979758126, 58.54019900730678, 66.61189351763043, 63.122445651463096, 67.74140657697404, 67.9907774244036, 69.67354079655239, 69.09249768938336, 71.62045383453369, 70.08524935586112, 70.73363440377372, 72.47112873622349, 74.79462718963623, 70.37875516074044, 78.48705278124127, 72.88810403006417, 80.7373172215053, 45.76891320092337, 0.3715106248855591, 6.895132592746189, 17.477420568466187, 13.114051733698163, 7.194664657115936, 2.2135221489838193, 0.47709393075534273, 0.4511474301772458, 32.33003405162266, 60.38328511374337, 58.19819825036185, 49.191693101610454, 32.26340430123465, 70.19028527396065, 38.29147727148873, 0.22816247546247073, 0.18377515726855823, 0.13752359125230992, 0.08144340477883816, 0.12019151342766625, 0.17797643771128996, 0.18644779814141138, 0.19275669460850103, 0.13422786524253233, 0.13577138313225337, 0.24784398078918457, 0.0765344685475741], [0.028111678681203296, 0.08076571114361286, 0.08723718460117068, 0.1159581605877195, 0.16115969366260938, 0.01833793643995055, 0.09570034832826682, 0.054341508341687064, 0.21478304054055894, 0.03539233568257519, 0.15236974747053214, 0.3194712772965431, 14.743997505732946, 64.5969020298549, 36.89856842585972, 31.637031146458217, 38.48110750743321, 60.13352516719273, 8.680364523615156, 0.08235037539686475, 0.4867756483810288, 1.0636166696037566, 1.0038034277302879, 1.3668651516948427, 4.327592125960758, 1.0895942470857074, 47.283981800079346, 84.3982674734933, 76.62622792380196, 80.62736197880336, 74.93018654414585, 76.90111950465611, 74.70869881766183, 71.34274128505162, 64.22504833766392, 66.37912191663469, 63.070521763392854, 66.0627634865897, 67.40801811218262, 73.25533022199357, 72.60527065822056, 70.40701348440987, 62.69768142700195, 60.04082924979073, 55.53411647251674, 56.91904878616333, 59.180843761989046, 65.46373844146729, 70.83111763000488, 72.77101298740932, 67.9912360055106, 68.54242965153286, 55.17586735316685, 53.000629561288015, 52.61776992252895, 51.43937281199864, 49.909181458609446, 49.556303296770366, 56.917106764657156, 55.624123437064036, 56.90551022120884, 55.03142472675869, 55.185897077832905, 52.13515152250017, 56.04492024012974, 57.19437115533011, 57.87392234802246, 60.36391353607178, 61.83923149108887, 60.972270011901855, 63.185688155038015, 58.830383573259624, 57.93243660245623, 60.98044804164341, 61.123038973127095, 58.87631116594587, 61.26277419498989, 60.80234486716134, 55.83160012108939, 60.64655235835484, 65.66358252934047, 62.35990864889962, 55.04683583123343, 49.879776682172505, 49.052802085876465, 53.16969312940325, 58.8200238091605, 58.80739198412214, 58.02427789143154, 57.93583427156721, 58.83142580304827, 56.28918416159493, 48.703578676496235, 46.003199509211946, 48.203360489436555, 52.47126715523856, 58.587432861328125, 58.58864879608154, 58.86093480246407, 59.027733257838655, 57.441994530814036, 53.79557296207973, 47.944286482674734, 48.430337292807444, 44.7292195047651, 56.93064532961164, 54.59572751181466, 52.87399516786848, 41.55439649309431, 50.507907731192454, 60.613353865487234, 56.51050860541207, 59.37061991010393, 58.492471831185476, 58.0522061756679, 57.91238062722342, 60.08756978171212, 60.28029196602957, 56.88547509057181, 56.942401681627544, 52.78468649727957, 43.34256056376866, 45.048565660204204, 44.63523122242519, 47.404230798993794, 55.90553937639509, 60.05248832702637, 59.332495144435335, 59.093650817871094, 60.442664418901714, 56.78468452181135, 52.645496709006174, 51.23719760349819, 54.740687779017854, 59.01572677067348, 62.31740651811872, 57.28445107596261, 63.19082287379673, 63.16867896488735, 65.36410127367292, 64.92821298326764, 66.17814527239118, 65.46869945526123, 65.19399547576904, 64.97297327859062, 63.557131903512136, 69.28499058314732, 69.39678015027727, 69.49055998665946, 7.888368027550833, 1.9568806631224496, 0.6222321912646294, 1.9136489714894975, 1.1274972132274081, 0.547764492886407, 0.22267020946102484, 0.21610363253525325, 5.331555145127433, 64.017012323652, 36.932479109082905, 46.79370648520333, 31.33167518888201, 45.99110964366368, 31.200917039598735, 0.07159731883023467, 0.12997810542583466, 0.04313963817964707, 0.01656408135646156, 0.08290423639118671, 0.12447543069720268, 0.15652128255793027, 0.03750038452978645, 0.027001183180670654, 0.020866850025153587, 0.027885709556617906, 0.0991324938035437, 0.07113286839532, 0.030143443228943006, 0.16291118253554615, 0.049094349545027526, 0.0990594020113349, 0.06991205497511796, 0.14793419119502815, 0.04708720903311457, 0.08197890461555549, 0.06490884987371308, 0.23165041687233107, 0.5386309772729874, 20.213819197246007, 71.70618765694755, 48.54657718113491, 36.2879433631897, 36.67127547945295, 70.78792067936489, 8.476726719311305, 0.06197398914290326, 1.1891514020306724, 2.1895172085080827, 2.819187717778342, 2.8256910145282745, 5.666098313672202, 1.671470160995211, 53.44435541970389, 89.62892695835659, 81.137526512146, 83.64062200273786, 79.4196469443185, 81.05606583186558, 76.78190926143101, 73.64308139256069, 68.84106322697231, 67.81658608572823, 65.62549250466483, 68.78481061117989, 69.64412212371826, 75.73288413456508, 74.60592106410435, 73.08052744184221, 64.77674225398472, 62.002687862941194, 58.90709168570382, 60.34746020180838, 61.25695855276925, 70.7553266797747, 71.05940764290946, 76.14991501399449, 72.27593994140625, 71.64847591945103, 59.35714735303606, 53.62033939361572, 55.39906433650425, 52.87623596191406, 52.36593246459961, 52.324767862047466, 58.808406421116416, 58.10304267065865, 59.09328951154436, 58.581346239362446, 56.83662230627877, 57.1397374698094, 60.15872628348214, 59.849149295261924, 61.73493208203997, 64.7490884235927, 66.37982368469238, 64.70246601104736, 65.362656048366, 61.124470302036826, 57.9343021937779, 65.48488875797817, 64.41741616385323, 63.18700136457171, 62.82926641191755, 62.87253284454346, 57.17626414980207, 65.10727500915527, 66.79636819022042, 61.24452127729143, 57.60709762573242, 53.70867879050118, 51.45678847176688, 55.437484400612966, 59.527607509068076, 59.469305174691335, 59.29261943272182, 59.45256001608712, 59.95449788229806, 55.77084159851074, 51.391374656132285, 50.083358900887625, 50.467021056583945, 53.36523280824934, 58.98870522635323, 59.8637752532959, 60.360300472804475, 61.47345747266497, 58.733296394348145, 57.13178178242275, 50.31279189246041, 52.053972244262695, 51.42763383047921, 59.4302840914045, 57.03210292543684, 56.84082249232701, 45.387099266052246, 53.84589181627546, 62.53443350110735, 57.934243134089876, 60.6652569089617, 60.08807700020926, 59.20246655600411, 59.54813248770577, 61.45136220114571, 61.83432606288365, 59.9740640095302, 60.337197712489534, 55.00826985495431, 46.775411878313335, 48.25922748020717, 45.9120843069894, 49.75173527853829, 58.206240790230886, 62.671792439052034, 60.52928761073521, 61.81037562234061, 62.37085900987898, 60.562958581107004, 54.22202559879848, 54.563946451459614, 57.586965220315115, 61.10008907318115, 64.60191862923759, 62.945711272103445, 66.24152673993791, 65.89256736210415, 67.12148135049003, 67.03817244938442, 68.28686101096017, 71.37366076878139, 66.67175919669015, 69.27184459141323, 64.85265827178955, 72.8155300957816, 69.68196201324463, 76.85152326311383, 10.65906035900116, 0.8026635551026889, 0.2865077203937939, 1.8822131497519357, 3.838806765420096, 3.2591456983770644, 0.855250399027552, 0.4558790719934872, 5.058109223842621, 65.12612547193254, 45.7521402495248, 41.905718258449006, 38.346107482910156, 52.50879784992763, 38.58654294695173, 0.21740977173405035, 0.01575216162018478, 0.04464472723858697, 0.021172747182260667, 0.0490400938849364, 0.06600923011345522, 0.05673350713082722, 0.063239036260971, 0.04794263134577444, 0.02019910540963922, 0.06853854403431926, 0.05279035693300622, 0.0894650796960507, 0.11215987761637994, 0.21133027438606533, 0.18165618740022182, 0.23632555029221944, 0.11323992894696337, 0.20773813713874134, 0.10634907335042953, 0.2414893103497369, 0.16221676979746136, 0.2364149269248758, 0.6231196065034185, 22.68263053894043, 85.34857954297746, 51.05049950735909, 44.09271240234375, 50.94396277836391, 79.37264238085065, 15.667449576514107, 0.24625954723783902, 1.951085431235177, 4.390180630343301, 4.674696334770747, 9.041648268699646, 8.633740374020167, 2.0885546718324934, 54.70854193823678, 94.30373055594308, 85.1772300175258, 91.23186247689384, 81.80930614471436, 85.53000395638603, 82.45340415409633, 78.34470503670829, 71.39681911468506, 72.01868983677456, 68.58782918112618, 72.28751564025879, 72.48121057237897, 80.26452010018485, 78.11615099225725, 75.54100268227714, 67.95917006901333, 64.67748028891427, 61.316761698041645, 62.661863463265554, 63.690988949366975, 73.9519705091204, 75.07864870343889, 80.79124913896833, 74.11387743268693, 74.31668145315987, 62.22943537575858, 58.05112573078701, 57.68696369443621, 57.13444641658238, 54.61974743434361, 55.22021770477295, 63.074252946036204, 60.72675541469029, 61.694667271205354, 61.17312853676932, 62.20809050968715, 59.94331823076521, 63.17948341369629, 63.981541769845144, 64.05741609845842, 68.9297569819859, 69.05918107713971, 67.57700525011334, 69.12584904261998, 65.25892639160156, 61.8576511655535, 67.81946958814348, 67.7529683794294, 64.78546224321637, 67.08378042493547, 67.2740707397461, 58.64623546600342, 67.46243640354702, 71.14825425829206, 66.89526884896415, 62.16252422332764, 55.433374541146414, 54.20056956154959, 59.8115873336792, 63.82789625440325, 63.19475555419922, 63.51973669869559, 63.149981362479075, 63.6852080481393, 61.52897357940674, 55.95629596710205, 50.99348953792027, 52.77114793232509, 57.26535047803606, 63.4893661226545, 63.93531540461949, 63.00363145555769, 64.15676839011056, 61.59558595929827, 60.04977852957589, 52.90823589052473, 57.896993841443745, 52.875148568834575, 59.54590906415667, 59.49243572780064, 57.7667498588562, 44.875055244990754, 52.19387074879238, 67.04566955566406, 60.206008774893625, 64.82544217790876, 63.94152709415981, 62.948747634887695, 61.68978268759591, 67.71950585501534, 66.39309474400112, 62.49986621311733, 61.925076484680176, 57.655832290649414, 48.068395205906455, 51.12804140363421, 48.73327875137329, 51.925909996032715, 62.46652180807931, 66.85574054718018, 65.03150490352085, 64.84456362043107, 67.03206498282296, 62.078673362731934, 57.54302828652518, 58.59846660069057, 62.1773864201137, 63.908808026994976, 69.16306359427315, 66.08318424224854, 69.14729118347168, 67.70106533595494, 70.0683513368879, 70.3052362714495, 72.54126385280064, 71.34015655517578, 69.76480538504464, 70.31371307373047, 69.43500219072614, 75.1990053994315, 75.13344914572579, 79.42282227107457, 10.455763016428266, 3.711517938545772, 5.567924175943647, 8.549409219196864, 6.087872641427176, 5.166046014853886, 0.9493468127080372, 0.3723576265786375, 7.63017383643559, 77.42825153895787, 49.84584862845284, 64.31727177756173, 41.79279613494873, 58.66103512900216, 46.70748628888811, 0.2688084601291588, 0.2434520950274808, 0.12623891606926918, 0.07457693573087454, 0.17531671614519187, 0.14094025934381144, 0.25091302181993214, 0.12365155347755977, 0.15832777347947868, 0.08766875322908163, 0.1622543606374945, 0.12459973831261907], [0.08823592708046947, 0.09055621828883886, 0.06699911092541047, 0.10270058376980679, 0.051588969970388074, 0.17357684379177435, 0.07457992807030678, 0.0193105705880693, 0.051117371169051955, 0.060851264744997025, 0.025025613206837858, 0.10796699260494538, 24.762492145810807, 62.428612436567036, 29.57569864818028, 33.90124062129429, 45.60167006083897, 43.71035303388323, 2.5077056203569685, 0.07576433130140815, 1.3130472281149455, 0.5968428222196442, 0.9548465290239879, 4.270408451557159, 4.297680131026676, 3.386716361556734, 64.91399696895054, 85.35397134508405, 80.05928421020508, 76.70285265786308, 75.08728531428746, 74.70611408778599, 72.01783520834786, 66.55429989950997, 61.903592654636924, 65.24691990443638, 63.23732021876744, 61.271459443228586, 62.544591767447336, 63.255892753601074, 61.852460861206055, 63.73582567487444, 59.536251068115234, 56.35319791521345, 55.412967681884766, 55.83018268857683, 62.427855082920615, 66.61617360796247, 67.91766847882951, 67.20706231253487, 70.49452604566301, 66.56263078962053, 56.558861119406565, 50.213366644723074, 53.61092458452497, 49.059319496154785, 52.20289298466274, 49.18799318586077, 53.71269137518746, 53.455938066755024, 56.502806527274, 56.18628828866141, 55.77416631153652, 54.062606130327495, 56.781213896615164, 57.23826987402779, 58.41225487845284, 60.766165597098215, 62.040180342538015, 61.391552107674734, 56.9726437159947, 56.373636041368755, 56.31350633076259, 57.145334243774414, 57.50328459058489, 58.570375033787315, 54.52330296380179, 56.971292291368755, 61.905781337193076, 64.32918098994664, 54.55563293184553, 50.331833430698936, 56.194876262119834, 59.55307960510254, 59.27146911621094, 47.46189389910017, 45.870481967926025, 51.38723005567278, 52.97277423313686, 53.59053856985909, 47.941541944231304, 49.379860741751536, 50.69815635681152, 57.23844010489327, 56.77055188587734, 51.92260612760271, 52.42940078462873, 56.98047433580671, 56.15113040379116, 57.84912075315203, 59.25616223471505, 56.757829734257285, 51.50753811427525, 44.73701190948486, 53.33621713093349, 60.91159834180559, 56.16202170508248, 58.93352958134243, 57.134470735277446, 54.56860869271414, 56.61575296946934, 56.77402598517281, 53.62752383095877, 55.73817811693464, 55.5319173676627, 56.632400853293284, 58.362505776541575, 57.710577147347585, 55.31878137588501, 57.92632566179548, 53.21713195528303, 44.948862484523225, 45.810317516326904, 45.032546588352744, 46.98032815115792, 52.406978947775706, 61.28092288970947, 57.2638635635376, 62.07126658303397, 58.97013963971819, 57.90535599844796, 50.776681423187256, 50.93827567781721, 50.042308943612234, 58.794204303196494, 57.644402503967285, 60.860501289367676, 62.81738499232701, 66.16739640917096, 65.82327992575509, 66.2876558303833, 64.44779368809291, 66.66551276615688, 63.68649346487862, 65.82209873199463, 60.57630607060024, 68.1122944695609, 65.2171607698713, 75.03901617867606, 36.204599721091135, 0.17807329179985182, 1.4777711033821106, 1.4884845742157526, 1.3866789170673914, 0.7916506603360176, 0.5133073989834104, 0.15214361889021738, 0.16607842115419252, 49.30887794494629, 43.78798178264073, 42.024254526410786, 32.46269253322056, 31.963631221226283, 39.56101042883736, 0.2369349833045687, 0.1360159678650754, 0.1505828933524234, 0.03414211794734001, 0.007591048604808748, 0.16778144905609743, 0.09084640057491404, 0.05389961241079228, 0.09252084179648332, 0.14479074201413564, 0.04071981606206723, 0.04384502282898341, 0.02609023974010987, 0.07158680832279579, 0.03046623251533934, 0.029024433810263872, 0.047045119505907805, 0.10377205163240433, 0.07863629183598927, 0.05158800984333668, 0.04826387696500335, 0.004338511348968106, 0.08071285326566015, 0.11458023238394942, 33.88858100346157, 68.30271680014474, 38.60858610698155, 28.29342770576477, 44.60162973403931, 53.003321988242014, 1.9170286187103815, 0.17425092762070044, 2.0070479597364153, 2.586923335279737, 2.8186086288520267, 5.325863267694201, 2.9252600031239644, 4.3123955471175055, 69.40684809003557, 89.66595390864781, 85.75627204350063, 79.57554367610386, 77.54734366280692, 76.06673812866211, 75.78207043239048, 68.83238492693219, 63.73374816349575, 67.57451779501778, 66.58908258165631, 63.91557557242257, 63.764896937779014, 64.50815963745117, 64.17972523825509, 66.15028994424003, 62.09752382550921, 58.64539473397391, 58.59294973100935, 57.821779591696604, 64.78510093688965, 68.70715059552873, 71.80950042179653, 70.4824639729091, 72.19080366407121, 69.26658480507987, 59.343223163059776, 52.72680105481829, 54.59186431339809, 51.41883741106306, 54.57382331575666, 52.35366194588797, 56.28074210030692, 55.520018577575684, 59.098229680742534, 58.375144549778526, 57.97109637941633, 57.70212466376168, 60.235267639160156, 61.48910481589181, 60.812169619968955, 63.21167441776821, 67.22146592821393, 63.692635672433035, 61.26417078290667, 60.77077920096261, 59.75463989802769, 59.854270117623464, 61.65168571472168, 60.132413455418174, 57.085319178445, 58.89013113294329, 65.82338414873395, 66.73739188058036, 55.934346607753206, 53.87330593381609, 59.26674434116909, 63.19467217581612, 63.32522882734026, 51.64959403446743, 47.990002155303955, 52.93512541907174, 55.43447583062308, 55.745306968688965, 50.84141778945923, 51.985351834978374, 56.63617719922747, 62.15708378383091, 60.1276330947876, 56.5845034463065, 55.45731108529227, 57.97163833890642, 57.44581951413836, 59.66191618783133, 60.23197419302804, 58.95597921098982, 56.29820639746529, 48.29243292127337, 56.21547072274344, 60.07097053527832, 57.70131172452654, 60.063994543892996, 57.863017150333945, 57.72425120217459, 57.745700291224885, 57.37835250582014, 56.79274443217686, 56.88303974696568, 57.71253653935024, 59.52136107853481, 60.51693371364048, 59.610951151166645, 58.992380823407856, 61.58503859383719, 55.521536758967805, 46.73427159445626, 46.99123682294573, 47.44831711905343, 49.85011829648699, 56.085483823503765, 62.85918535505022, 61.49779006413051, 62.16357340131487, 60.87313311440604, 59.95829159872872, 53.76091187340872, 53.05677448000227, 54.59719010761806, 61.53578976222447, 61.844227245875764, 61.983351026262554, 64.39320863996232, 66.75651332310268, 67.1799851826259, 67.74032960619245, 66.79003838130406, 67.84735270908901, 66.2492322921753, 68.49320166451591, 64.99413749149868, 69.60175200871059, 69.36328288487026, 75.0724995476859, 45.27611221585955, 0.44382739439606667, 0.5015846480216298, 0.5441483354994229, 3.068264786686216, 2.6113425620964597, 1.3173615166119166, 0.1067553326221449, 0.0695043300677623, 49.6649557522365, 54.25475508826119, 40.59070219312395, 32.64987700326102, 39.8274564743042, 46.7142607825143, 0.4068370849958488, 0.09087139780500106, 0.04261145295043077, 0.03537213569507003, 0.06019169478011983, 0.022125922642382126, 0.09171238089246408, 0.05536931247583457, 0.11733511170106274, 0.08876246346959046, 0.031184132743094648, 0.07690764923713037, 0.16243396885693073, 0.12560961555157388, 0.16381417693836348, 0.1758030764758587, 0.09037577547132969, 0.28409332994903835, 0.17216222041419574, 0.16535772196948528, 0.16272493824362755, 0.16138602580342973, 0.15690945887139865, 0.23910569825342723, 36.67475305284773, 82.90355709620884, 39.77520602090018, 50.783942290714805, 60.62929303305489, 65.01064641135079, 4.744010695389338, 0.23720330319234303, 5.323316318648202, 3.578548090798514, 3.919798876558031, 12.316566160746984, 8.81289620058877, 4.6484894667352945, 75.804415839059, 94.32345649174282, 91.22240597861153, 82.92982823508126, 83.17998422895158, 80.40533924102783, 80.75240870884487, 70.44852202279228, 68.60403932843889, 70.77041121891567, 70.79371547698975, 66.73887184688023, 68.28157343183244, 67.58090318952287, 66.92798791612897, 69.73802007947648, 65.00421932765416, 61.88679191044399, 60.83617564610073, 59.65972750527518, 67.7590480531965, 72.35965183803013, 75.57265172685895, 71.88575690133231, 76.6803891318185, 72.26690033503941, 62.16215596880232, 56.41376536233084, 58.39361980983189, 54.52585295268467, 58.29612963540213, 56.09109449386597, 59.51602486201695, 59.50617231641497, 61.400265148707796, 62.38235133034842, 61.98724201747349, 61.973352568490164, 62.79324695042202, 62.70790917532784, 64.896730695452, 65.96295261383057, 68.66737910679409, 69.32745102473667, 64.53563976287842, 64.53070654187883, 64.32354600088937, 63.61521884373256, 65.6360468183245, 65.10109806060791, 60.700762203761506, 61.39943136487688, 68.1321107319423, 69.91958345685686, 60.524173736572266, 56.90611818858555, 62.39158548627581, 65.13294860294887, 64.88011755262102, 53.991192545209614, 50.88223845618111, 57.38054118837629, 59.473265647888184, 58.87031487056187, 54.52980647768293, 54.70755181993757, 56.865363529750276, 61.66072532108852, 61.05233410426548, 56.11805350439889, 58.755822454180034, 60.48566681998116, 60.23347500392369, 63.453249386378694, 62.09259755270821, 61.049575669424875, 58.206282479422434, 50.25781079701015, 60.09521280016218, 64.22101838248116, 62.32119328635079, 63.699528285435264, 59.79668344770159, 57.08945335660662, 62.04279981340681, 61.471421650477815, 60.658621379307334, 60.31736755371094, 60.447681018284385, 61.34520067487444, 63.423288754054475, 63.07954747336251, 60.999840463910786, 63.73319925580706, 59.108005796160015, 49.49351242610386, 51.18674325942993, 49.79239266259329, 53.98215293884277, 57.73021623066494, 67.29631192343575, 63.91977228437151, 65.18235724312919, 63.44905962262835, 63.058216503688264, 57.31335210800171, 54.87090049471174, 57.41028642654419, 63.10104519980294, 65.7035972050258, 65.23131425040108, 67.81565502711705, 71.68097959245954, 70.66265855516706, 71.37541171482631, 69.31022644042969, 72.36315373011998, 67.97923646654401, 72.15847369602749, 67.86507756369454, 72.8296696799142, 71.77333504813058, 78.97195366450718, 44.174798420497346, 0.489189333149365, 3.7216735993112837, 6.077187180519104, 4.693893338952746, 4.2099469644682745, 2.0176539506231035, 0.1848306456314666, 0.6085315378648894, 60.67049585069929, 57.01041759763445, 58.030663285936626, 43.79149062292916, 43.24013369424002, 57.50375011989048, 0.6332557797431946, 0.2834547199308872, 0.20479083886103971, 0.12699979809778078, 0.22085348623139517, 0.14540221063154085, 0.15194832294115, 0.16017386370471545, 0.19582515209913254, 0.18435739459736006, 0.28546834045222824, 0.21055553667247295], [0.010130400603104914, 0.0051039586459020415, 0.022413575689175298, 0.08363074383565358, 0.030744587936039482, 0.1053955280887229, 0.08489425746457917, 0.06836057786962815, 0.04527155788881438, 0.015334891421454293, 0.05077130473884089, 0.14352475851774216, 37.43540709359305, 49.89679282052176, 30.349748815808976, 36.78124461855207, 41.041272027151926, 27.15832829475403, 0.22929237197552407, 0.045174663088151386, 0.8060708865523338, 1.8174656012228556, 6.035433718136378, 2.078291096857616, 0.2416117994913033, 7.697943091392517, 77.89562906537736, 80.18566499437604, 79.68044757843018, 74.33066817692348, 72.97503989083427, 71.38462502615792, 69.33098765781948, 64.285094669887, 59.392909731183735, 59.20020144326346, 62.11583232879639, 62.00573117392403, 57.35109124864851, 57.948563371385845, 60.086923599243164, 57.14915227890015, 55.68597977502005, 54.6551832471575, 55.82354021072388, 54.840384006500244, 59.918610436575754, 65.48736926487514, 68.83664417266846, 67.12070315224784, 67.07173224857875, 64.33908912113735, 55.561481952667236, 52.46776873724801, 50.35251126970564, 50.38260391780308, 52.14971842084612, 48.58869021279471, 50.97980853489467, 53.521067006247385, 55.13561296463013, 55.83452878679548, 56.32303925922939, 53.31875283377511, 57.53996760504586, 56.720055852617534, 58.206935610089985, 59.00465134211949, 61.20465251377651, 61.4924955368042, 57.90270178658621, 58.9041873386928, 55.871816294533865, 52.36548777988979, 51.539399078914094, 49.71056372778756, 52.76312623705183, 61.36197362627302, 61.232716287885395, 52.39177976335798, 50.765995093754356, 59.809440340314595, 64.65282113211495, 60.58927140917097, 62.44872052328927, 52.25091198512486, 54.584596497671946, 55.4939524105617, 56.673655782427105, 59.1643556867327, 56.14933429445539, 57.558453287397114, 61.98815223148891, 57.738891056605745, 60.24132646833147, 62.22105584825788, 55.05734845570156, 53.829473223005024, 56.450865268707275, 56.15281186785017, 58.26736409323556, 55.713039534432546, 53.68245281491961, 52.0592737197876, 53.07515246527535, 56.26181868144444, 54.51351295198713, 55.24116652352469, 53.542179107666016, 57.253149441310335, 57.666567257472444, 54.418030806950156, 52.667140347617014, 49.36410570144653, 51.45114653451102, 52.054416928972515, 54.247615814208984, 55.62981053761074, 56.247838905879426, 56.83193227222988, 54.2795010975429, 45.59777212142944, 44.44494438171387, 44.34226737703596, 45.483977999006, 53.68101453781128, 61.25790350777762, 58.816355160304475, 58.72718892778669, 59.809113774980815, 57.23286417552403, 51.36542313439505, 48.70307493209839, 50.14069543566023, 59.05708939688546, 57.00090898786272, 59.35351344517299, 62.34605394090925, 64.34395286015102, 62.29778480529785, 64.29459285736084, 64.870452608381, 64.55006422315324, 59.289569173540386, 64.06576783316476, 63.5898231778826, 66.6422015598842, 66.81633036477226, 72.47817420959473, 66.75213595799038, 15.140350546155657, 0.7371381883110318, 1.6510309491838728, 3.145602579627718, 3.04475143126079, 0.6845499873161316, 0.14902986240174088, 0.24552757080112184, 25.390463386263164, 62.860929352896555, 36.721038477761404, 36.99468285696847, 28.32540331568037, 41.44561549595424, 0.46038074472120827, 0.02064587831098054, 0.060336521294500144, 0.03357428252430899, 0.1318549739995173, 0.022958339225234728, 0.07790347401584898, 0.05637673681069698, 0.12615040796143667, 0.11462645418941975, 0.027536352231566395, 0.11796567429389272, 0.04104507860860654, 0.030311580813888992, 0.0689579261732953, 0.03587818032662783, 0.08122155096914087, 0.0588300514167973, 0.03743741648005588, 0.061982735459293635, 0.10574159451893397, 0.03114132396876812, 0.033130734360643795, 0.4746947394950049, 48.72322818211147, 55.92123188291277, 42.158712591443745, 32.36453880582537, 46.42636217389788, 33.25841065815517, 0.14191323784845217, 0.09113807563803025, 2.450089203459876, 4.507412374019623, 11.593360304832458, 1.4816711055380958, 0.48057606390544344, 9.715785946164813, 81.41992909567696, 84.2616936819894, 83.29209341321672, 79.31900923592704, 76.09135559626988, 73.10016305106026, 73.6455271584647, 65.66443715776715, 63.47131470271519, 63.57678835732596, 64.61848313467843, 62.77869742257254, 60.90962505340576, 60.896972383771626, 60.4032472882952, 59.46312822614397, 59.81873008183071, 56.93302508762905, 56.179475579942974, 57.58994252341134, 60.31467860085623, 66.8522594996861, 71.77079895564488, 70.90072468348912, 69.66486249651227, 65.65682888031006, 57.78513479232788, 52.65396308898926, 52.915562765938894, 51.36895629337856, 54.696167196546284, 50.255959102085654, 50.97738708768572, 56.46670716149466, 57.32640777315412, 58.24352829796927, 59.24809537615095, 57.60858106613159, 62.45161097390311, 59.754438400268555, 63.06909738268171, 64.39083235604423, 63.64945261819022, 64.78177969796317, 59.78748403276716, 62.55034487588065, 59.08536161695208, 58.41082354954311, 56.77724647521973, 52.5550103187561, 56.43368584769112, 63.53375816345215, 64.59330286298479, 54.50517858777727, 55.978696959359304, 62.80539240155901, 65.91569096701485, 61.55425112588065, 64.63244901384626, 56.79992886951992, 58.39417566571917, 59.799594742911204, 59.21664088112967, 61.45767116546631, 59.33100822993687, 62.16984067644392, 62.96100425720215, 57.773434025900706, 60.75711209433419, 63.75210530417306, 59.19912447248186, 56.94140114103045, 58.24453231266567, 59.30036667415074, 59.68790939876011, 56.5938835144043, 55.5153945514134, 55.030795914786204, 54.51660490036011, 57.41386127471924, 56.67236341748919, 58.498343058994834, 55.876395157405305, 61.36510031563895, 60.491732597351074, 56.62824930463518, 54.584888322012766, 50.42486980983189, 53.41145569937569, 53.18115765707833, 57.149124486105784, 57.52706480026245, 59.071534701756065, 58.492624691554475, 56.09562471934727, 47.88649484089443, 45.429820265088765, 45.919018609183176, 47.310881750924246, 55.02846826825823, 63.13470227377755, 61.78564698355538, 61.18303666796003, 61.76808193751744, 60.23398222242083, 53.42551537922451, 51.59636041096279, 53.61576053074428, 59.70304952348982, 60.52335384913853, 61.64348684038435, 63.12960229601179, 64.85852255140031, 65.35679871695382, 66.3443044934954, 66.59768445151192, 65.95317649841309, 62.9500538962228, 66.08701964787075, 65.93973868233817, 67.84492778778076, 69.90540218353271, 73.82103865487235, 71.8152048928397, 21.56392887660435, 0.7523025774530002, 0.5580573262912887, 1.436199922646795, 0.7778420927269118, 1.3101122656038828, 0.5012687221169472, 0.2746740425271647, 25.42442618097578, 68.44382081712995, 42.57005637032645, 29.359310899462017, 34.875489234924316, 50.90966647011893, 0.855406136385032, 0.02769229993490236, 0.08871160048459258, 0.10817903479827301, 0.0407455393246242, 0.04236105317249894, 0.035266935625778775, 0.02911164252353566, 0.07963968228016581, 0.07548480880047594, 0.03592706877472145, 0.07250399767820324, 0.13842222946030752, 0.16541756875813007, 0.1520277386797326, 0.14633288926311902, 0.1682531801717622, 0.1564652355653899, 0.17896065275583947, 0.17731280332165106, 0.1736858572278704, 0.12911665093685898, 0.12855509535542556, 0.4657123472009386, 54.975880827222554, 66.25488812582833, 43.74110576084682, 53.71543591363089, 58.653016907828196, 42.66798428126744, 0.5003419518470764, 0.2069095644567694, 3.5415682579789842, 5.701670050621033, 15.37734317779541, 6.112390662942614, 0.585435074354921, 10.718989440373011, 85.39813409532819, 87.06404113769531, 87.36452988215855, 83.36926010676792, 80.19773401532854, 78.4405415398734, 80.21785599844796, 69.82136372157505, 67.32605716160366, 65.20234721047538, 68.31931604657854, 68.90973227364677, 64.3420421055385, 62.06335258483887, 65.80936963217599, 62.686265536717, 63.299763679504395, 58.63214451926095, 61.699385098048616, 60.351691654750276, 66.37969166891915, 71.91471004486084, 76.81709493909563, 72.86219419751848, 72.58942876543317, 69.29389817374093, 61.06409045628139, 57.59775924682617, 57.26496137891497, 54.78860255650112, 57.13664204733712, 53.76235015051705, 55.035479000636506, 59.91797815050398, 62.06450598580496, 63.74483748844692, 63.01437337057931, 63.4239627293178, 64.27378300258091, 64.31189387185233, 66.30080182211739, 65.61839839390346, 65.94595037187848, 69.52168096814836, 63.05017048971993, 67.28710556030273, 63.07144587380545, 59.579239572797505, 58.45939145769392, 54.006054741995676, 58.09197071620396, 67.29089232853481, 67.11520017896379, 58.78255912235805, 58.20836346490042, 65.63695008414132, 70.88371549333844, 64.99675696236747, 67.77468844822475, 59.44249207632882, 59.775317737034385, 61.36496829986572, 62.29064900534493, 63.92505986349923, 59.606087412152974, 62.47422041211809, 65.94007219587053, 61.2255596433367, 64.4435761315482, 67.99193777356828, 59.15561485290527, 58.42715181623186, 61.47391605377197, 60.51739229474749, 64.4004625592913, 60.12081691196987, 58.47212750571114, 58.61833150046212, 57.986979961395264, 60.97826630728585, 58.01521744046892, 60.917671067374094, 58.41676425933838, 62.468495096479145, 61.5844966343471, 61.18099389757429, 57.539029598236084, 53.73907021113804, 56.044802120753694, 56.75307369232178, 58.20795004708426, 60.08898721422468, 61.183655057634624, 63.104970932006836, 59.89973218100411, 52.565481254032676, 47.97237457547869, 48.893775190625874, 51.1095244543893, 58.194800581250874, 67.31346007755825, 64.57994842529297, 64.70586368015834, 67.31601701463971, 64.14346258980888, 56.56044183458601, 53.89106900351388, 57.215788977486746, 63.759616306849885, 63.2862355368478, 66.43595123291016, 65.77928393227714, 69.32186467306954, 67.70622784750802, 70.82152216775077, 68.43544128962925, 69.36112199510846, 65.71998800550188, 69.54473509107316, 69.09698622567313, 73.08969906398228, 73.14374215262276, 80.29034655434745, 73.14930765969413, 21.613636289324077, 1.9412459135055542, 5.833723170416696, 8.41953957080841, 11.082847493035452, 2.559497058391571, 0.33660317371998516, 0.32086357687200817, 32.30873434884207, 76.33706474304199, 50.47087383270264, 49.012617179325645, 39.853237765175955, 61.797167096819194, 0.9135165810585022, 0.1794009269880397, 0.12427391936736447, 0.1640562375209161, 0.1588132381439209, 0.11847567478460924, 0.17150315935058252, 0.10550295375287533, 0.24141890555620193, 0.09803585229175431, 0.11979541182518005, 0.1322428924696786], [0.033115080557763577, 0.08243954846901552, 0.10404144360550813, 0.08748400849955422, 0.07256227705095496, 0.09378263194646154, 0.013843925220758786, 0.025833624581407224, 0.050565030093171766, 0.2216247362749917, 0.33595435853515354, 3.427025032894952, 56.88495397567749, 41.488405976976665, 27.76930250440325, 33.78214154924665, 42.97254467010498, 14.556497761181422, 0.08467630523123912, 0.24855177423783711, 1.2174479407923562, 2.387684826339994, 2.8122323538575853, 0.21740975816334995, 0.5042901571307863, 19.82606976372855, 83.51727758135114, 81.55457823617118, 81.72460760389055, 76.05846282414028, 69.58838367462158, 69.78621973310197, 66.84547110966274, 61.621002469744, 57.43340308325631, 59.62396512712751, 60.65618256160191, 59.33125836508614, 59.86695752825056, 59.841450691223145, 54.43609612328665, 55.591588497161865, 56.04688310623169, 53.61569799695696, 54.02736834117344, 53.25700766699654, 54.76960270745413, 60.003454889569966, 65.04698548998151, 65.90726280212402, 65.57262366158622, 58.17351477486746, 52.8845077923366, 51.50071150915963, 50.53757653917585, 48.35913562774658, 50.06926448004586, 46.544926234654014, 48.06979179382324, 50.71716315405709, 52.701509611947195, 53.8406320299421, 54.54639877591814, 56.19511944907052, 57.881033829280305, 55.61059876850673, 58.79494776044573, 61.101978983197895, 62.471024240766255, 63.36790466308594, 59.9812901360648, 57.091791425432476, 60.935507093157085, 58.86733409336635, 56.55024882725307, 57.13201802117484, 56.23618330274309, 56.383061272757395, 54.23905563354492, 53.5653270312718, 62.90691253117153, 61.73953178950718, 57.320077964237754, 60.01033360617501, 58.37980679103306, 55.28137922286987, 52.05944742475237, 56.22216183798653, 56.95566579273769, 57.9222366469247, 55.204271589006694, 58.43517003740583, 60.353817803519114, 51.281759875161306, 49.894739627838135, 56.542105538504465, 60.141307149614605, 57.95882586070469, 53.6346492086138, 56.358224936894004, 57.398655142102925, 54.45382445199149, 52.679626260484966, 49.68363945824759, 54.16373716081892, 52.52756493432181, 55.7650329044887, 57.96367570332119, 55.76342439651489, 54.23444202968052, 61.98783956255232, 55.02932289668492, 54.88365738732474, 48.43819917951311, 48.55872958047049, 50.2014331136431, 52.467817374638145, 56.02643803187779, 54.466539655412944, 54.283263547079905, 55.78577675138201, 45.913425309317454, 43.70477710451399, 44.00463356290545, 44.95259019306728, 51.664942605154856, 58.539017813546316, 62.01112297603062, 60.698490142822266, 56.918305328914094, 56.674788338797434, 50.70826251166207, 49.46476078033447, 48.74077238355364, 55.53633642196655, 57.874301024845664, 57.77761336735317, 60.80672918047224, 62.23865563528878, 62.36850357055664, 63.020939418247764, 60.75739002227783, 62.02968856266567, 61.782471656799316, 62.83128833770752, 63.12787219456264, 63.530040877205984, 66.25772993905204, 69.67488179888043, 72.4986297062465, 50.137012890407014, 0.8077661927257265, 0.24907180347612926, 2.027163863182068, 2.321989825793675, 0.19828252095196927, 0.3140908474368708, 0.08746769651770592, 5.746551505156925, 68.54609830038888, 34.98197732652937, 47.62636470794678, 36.256999560764854, 43.7184476852417, 1.2750566495316369, 0.2102644858615739, 0.04455116065219045, 0.05781819964093821, 0.027307826726298248, 0.10813590032713753, 0.03898930749190705, 0.11548135403011527, 0.06979339277105671, 0.09237674131457295, 0.03539281744243843, 0.04608161674280252, 0.032367877795227935, 0.06975416666162865, 0.040471350108938556, 0.11782414545970303, 0.02890522199283753, 0.09880979611937489, 0.06961579980062586, 0.02298256801441312, 0.07262452585356576, 0.15768389802958283, 0.2750376287315573, 4.512143662997654, 68.058258329119, 50.063087531498496, 37.411609513419016, 25.131295578820364, 50.37440504346575, 16.372186252049037, 0.1063432175932186, 0.5540817624756268, 3.577158668211528, 4.038195312023163, 6.462142135415759, 1.382433567728315, 0.27890611972127644, 22.106089864458355, 87.67558683667863, 84.60369791303361, 86.89094066619873, 79.64956283569336, 74.40816838400704, 71.77237619672502, 69.55799225398472, 63.86199106488909, 59.564481598990305, 61.313732283455984, 62.77378504616873, 64.09158733912876, 62.558773040771484, 61.589638301304404, 58.11583777836391, 57.88998310906546, 58.639071873256135, 55.63970824650356, 56.09140716280256, 54.79801389149257, 56.950815950121196, 60.57867540631975, 64.8459254673549, 69.05548463548932, 68.79608753749302, 61.386862073625835, 57.36408090591431, 53.328671387263704, 52.6175788470677, 52.06484964915684, 52.654765605926514, 49.856263978140696, 50.78459194728306, 53.345875126974924, 55.49217367172241, 56.374014718191965, 56.91108962467739, 57.59501123428345, 62.03842939649309, 59.84861428397042, 63.79299545288086, 63.74660233088902, 65.70097078595842, 65.42203535352434, 61.14855970655169, 59.90320628029959, 62.748472758701865, 61.190679686410085, 61.258028575352256, 59.56872000013079, 60.4217711857387, 60.44125393458775, 55.155780111040386, 56.43867118018014, 66.59969248090471, 61.18700408935547, 59.93576553889683, 62.730115618024556, 59.012023380824495, 58.65313502720424, 54.91662311553955, 58.71482808249337, 59.33419050489153, 60.14322485242571, 58.48371015276228, 59.04686164855957, 60.78170871734619, 55.693264961242676, 51.26115846633911, 58.51544257572719, 63.21147986820766, 58.85104056767055, 54.9656982421875, 57.668443271092, 60.69810799189976, 57.692428452628, 55.31526211329869, 52.32471227645874, 57.98840086800711, 55.43563270568848, 57.02788536889212, 57.245819091796875, 57.40979657854353, 56.22228690556118, 64.15818582262311, 56.824792998177664, 57.31833744049072, 51.75084318433489, 50.614798818315776, 52.37784515108381, 54.842440673283164, 58.38017504555838, 57.15733725684029, 57.806497028895784, 58.39664922441755, 48.380782740456716, 44.37212726048061, 46.87009845461164, 48.155202525002615, 53.89309440340315, 61.58747741154262, 63.415228843688965, 63.843300410679404, 60.16024099077497, 60.159761565072195, 54.53350986753191, 51.49303722381592, 51.51203012466431, 57.917734214237754, 59.60878331320626, 60.69753129141671, 63.13042218344552, 64.24813720158168, 63.80197947365897, 66.07620130266461, 63.33182961600167, 63.10957758767264, 63.03698975699288, 65.60762868608747, 66.50480093274797, 67.61610971178327, 67.60421439579555, 71.67330183301652, 74.08198520115444, 58.48872675214495, 1.603182505284037, 0.2904969091926302, 0.6602614192026002, 0.8061481852616582, 0.1477117131331137, 0.13081735824900015, 0.042910578328051736, 4.677596339157649, 73.76987212044853, 41.31247411455427, 41.6165828704834, 44.32607807431902, 54.93777690614973, 2.458645910024643, 0.21000673754939012, 0.07441012468189001, 0.06511941964605025, 0.03437585969056402, 0.11685308042381491, 0.002094753589647423, 0.10158283981893744, 0.024613085967887725, 0.03104735704671059, 0.04140218480357102, 0.08804360311478376, 0.11551821205232825, 0.15694565192929336, 0.1521387334380831, 0.21757981260972364, 0.14576410049838678, 0.23466091390166963, 0.08886268309184484, 0.18411997519433498, 0.1694287285208702, 0.25199699508292334, 0.4746081584266254, 5.276524109499795, 80.24320302690778, 54.97940008980887, 40.978825092315674, 45.60682562419346, 62.62252276284354, 24.036813599722727, 0.13620373207543576, 1.0567960355963026, 5.084803768566676, 6.984326618058341, 9.417779445648193, 3.3954847710473195, 1.4318702178342002, 26.28773464475359, 91.32002122061593, 89.26770401000977, 92.15502793448312, 83.99626554761613, 77.87693841116769, 75.3789290019444, 74.96791526249477, 68.7929538999285, 64.39833641052246, 66.23339734758649, 65.95810971941266, 65.94497762407575, 65.01810877663749, 66.93670790536063, 59.49122674124581, 60.355464526585166, 62.04232733590262, 58.94728006635393, 58.90345082964216, 57.506557192121235, 60.16258948189871, 66.30597823006767, 71.75668021610805, 72.53935309818813, 72.7119949885777, 62.865515163966585, 59.748143332345144, 56.89460154942104, 56.125512395586284, 55.06360183443342, 55.291120597294395, 53.53647116252354, 54.490774972098215, 56.77051019668579, 58.48241778782436, 60.25798824855259, 62.1469463620867, 60.4746469770159, 63.210215296064106, 63.12689249856131, 67.01918302263532, 67.42375578199113, 70.73394012451172, 71.54606642041887, 66.46628706795829, 64.80283968789237, 65.54686668940953, 65.8142055783953, 63.399074281964985, 61.78008147648403, 63.07591356549944, 62.813834462847026, 57.94478702545166, 60.200443267822266, 67.93699141911098, 65.22105176108224, 62.07512283325195, 64.84466784340995, 63.34918621608189, 59.74214703696114, 59.75863511221749, 62.50912121364048, 63.26064532143729, 65.62493664877755, 60.309988566807334, 63.765438897269114, 64.05131558009556, 56.936228207179475, 53.69413273675101, 62.59950338091169, 64.49470097678048, 61.73152051653181, 57.17138998849051, 60.988271713256836, 61.92049067361014, 59.46581717899868, 56.82690177645002, 55.82269600459507, 60.039495195661274, 57.832215785980225, 62.40537766047886, 61.36308533804757, 60.31064864567348, 58.90601471492222, 63.63131087166922, 61.54679570879255, 59.90267126900809, 53.65873861312866, 55.075927938733784, 55.51819467544556, 57.842130865369526, 61.64756543295724, 59.03186048780169, 61.521552903311594, 60.145990235464915, 48.395120348249165, 47.502836159297395, 48.54243605477469, 51.4585394178118, 57.9997854913984, 64.67595168522426, 68.47277396065849, 67.08303001948765, 62.462707247052876, 62.630666051592144, 57.30714041846139, 52.893981661115376, 55.944577830178396, 62.42204638889858, 62.73468753269741, 65.85489422934396, 66.44275351933071, 66.97578457423619, 67.46377740587506, 68.42170470101493, 66.1440782546997, 67.77121434892926, 67.49453708103725, 68.76063782828194, 68.65817969185966, 71.64769077301025, 71.96737739018032, 73.89665590013776, 78.00980881282261, 60.54753358023507, 1.2303949317761829, 1.1031620161873954, 8.79630650792803, 6.046212545463017, 4.905703093324389, 0.6905125730804035, 0.16929133875029428, 7.766293389456613, 81.78215953281948, 47.52529273714338, 65.85631166185651, 47.56872245243618, 64.51865141732353, 2.7347872981003354, 0.33857714065483635, 0.27335684320756365, 0.22048820368945599, 0.0870803887290614, 0.19627622860882962, 0.1680753497140748, 0.18276802131107875, 0.1609278789588383, 0.18958319989698275, 0.13412187807261944, 0.18209947432790483], [0.058902851438948085, 0.10955367889255285, 0.123270094660776, 0.06749370867120368, 0.059979381172784736, 0.06958657529737268, 0.1803187813077654, 0.051998445498091836, 0.034949988525893004, 0.11530289932021073, 0.07579802735043423, 7.670941523143223, 61.3845066343035, 34.81441109521048, 31.579256875174387, 50.037893363407676, 38.88598946162632, 6.265793859958649, 0.13021114149263927, 0.3071616749678339, 2.123347124883107, 5.178187991891589, 7.719260164669581, 4.480889797210693, 0.053433815083865605, 27.737349476133073, 87.13705280848912, 81.84352602277482, 80.78325176239014, 74.26735619136265, 71.27459335327148, 68.81341634477887, 66.55669007982526, 61.20731367383684, 57.79074198859078, 57.747072560446604, 57.96340472357613, 59.9042763028826, 62.482926504952566, 62.08927631378174, 60.04609598432268, 56.83441277912685, 55.108580998011995, 54.55438920429775, 55.812912940979004, 54.03295121874128, 51.619407585689, 55.25989191872733, 54.20576681409563, 58.800534112112864, 60.951140539986746, 54.8484126499721, 50.1095848764692, 49.716289043426514, 48.37171881539481, 50.48352997643607, 48.61193541118077, 47.34217643737793, 46.20248426709856, 47.26279674257551, 51.67826230185372, 54.60279730388096, 52.67784057344709, 55.49580063138689, 54.89762674059187, 55.93666730608259, 59.38447461809431, 58.459655489240376, 60.99025889805385, 61.85574041094099, 54.76556232997349, 56.850487436567036, 55.73972756522042, 56.19137784412929, 59.162583896092, 52.6435546875, 57.15890754972185, 57.690486431121826, 55.00504241670881, 62.92839636121477, 60.93252631596157, 56.326996258326936, 59.36306721823556, 59.47760132380894, 59.09114946637835, 58.2667179107666, 56.35032483509609, 59.55098819732666, 57.55634798322405, 57.76826804024832, 57.491198199135916, 54.29113238198416, 60.96823310852051, 61.811487334115164, 57.07654707772391, 52.70813124520438, 52.62623977661133, 58.232567514692036, 58.16624695914132, 52.538890498025076, 53.20809234891619, 56.94483355113438, 52.826862062726704, 52.10871015276228, 53.097880022866384, 55.06527635029384, 54.80243294579642, 52.97978843961443, 54.886030197143555, 51.48273304530552, 51.53960405077253, 61.32953248705183, 55.01033694403512, 52.11464738845825, 46.41275412695748, 48.67917660304478, 50.66372455869402, 54.55654661996024, 54.69009447097778, 54.71602514811924, 54.754212447575156, 52.47957720075335, 42.39641046524048, 42.13195855276925, 44.393843855176655, 51.45083039147513, 58.19158703940255, 61.40116146632603, 58.80322306496756, 58.88196005140032, 54.7148300579616, 51.844984327043804, 48.32800769805908, 50.67872224535261, 52.14494500841413, 60.82762936183384, 57.288289955684114, 57.838424001421245, 59.815408842904226, 59.58552074432373, 59.17478493281773, 60.692862101963584, 57.444634846278596, 58.75846971784319, 60.89692374638149, 61.89133603232247, 63.581665992736816, 63.43402372087751, 69.9132466997419, 70.03154672895158, 66.20746667044503, 18.38234874180385, 1.3373012180839265, 0.8549250279154096, 0.26100422175867216, 0.7278490981885365, 0.2669397475464003, 0.060230601978089125, 0.48331870245082037, 53.547529220581055, 46.34603752408709, 36.11141395568848, 26.28664551462446, 48.81529876164028, 4.492324360779353, 0.440573656133243, 0.22710389297987732, 0.1642770870987858, 0.06796104966529778, 0.1498056993420635, 0.025346602679097226, 0.03495831415057182, 0.08120295910962991, 0.046630748348044496, 0.13144896578575882, 0.08356441703758069, 0.024739732832780907, 0.13947611648057187, 0.10827497286455971, 0.0648303230160049, 0.10029870551079512, 0.10254093805061919, 0.04747625047873173, 0.09834453822778803, 0.04895289534968989, 0.23143570125102997, 0.3230117644582476, 13.353739397866384, 69.3819249016898, 46.044350215366904, 40.879354681287495, 45.407919543130056, 46.42877319880894, 6.569368038858686, 0.14603771295930656, 0.3679560784782682, 4.269577707563128, 6.554532766342163, 5.754868933132716, 3.317902705499104, 0.1173510979861021, 34.96390853609358, 91.37566239493233, 83.15260137830461, 84.54494394574846, 77.59420926230294, 76.87108939034599, 71.47117178780692, 69.65420395987374, 61.67992319379534, 61.73894814082554, 60.803234236580984, 61.171641622270855, 62.773409843444824, 64.21160357339042, 65.16038703918457, 62.282172203063965, 57.87109095709664, 58.60638059888567, 56.936075346810476, 56.270177364349365, 56.156084469386506, 54.56489488056728, 56.109177180698936, 56.137828077588765, 60.252082279750276, 62.66239152635847, 58.55738885062081, 52.842408657073975, 51.47748368127005, 49.673946721213206, 55.01591287340437, 52.098211424691335, 50.794903073992046, 50.212543283190044, 53.107572759900776, 54.056620257241384, 57.333217007773264, 54.96302318572998, 58.89006165095738, 60.34786319732666, 58.98061752319336, 62.28486115591866, 61.12194115774972, 64.92742783682687, 63.25567735944475, 57.196820395333425, 59.846835545131135, 59.25389017377581, 58.81734875270298, 61.7362174987793, 53.922752789088655, 61.149636677333284, 61.356324740818565, 58.5926787512643, 65.1383056640625, 64.0422134399414, 59.26229749407087, 60.31507464817592, 60.46332836151123, 62.6729736328125, 60.97636250087193, 59.71302713666643, 60.379123142787385, 60.03943266187395, 59.80368028368269, 60.58031518118722, 58.168928963797434, 62.008239473615376, 61.643646648951936, 59.60595539637974, 55.34019224984305, 52.922434534345356, 60.94442858014788, 60.283543722970144, 55.661192076546804, 54.028056212833945, 60.59451729910714, 55.104457242148264, 53.57878221784319, 54.408897399902344, 57.25313554491316, 57.241830825805664, 55.90234667914254, 56.72156708581107, 55.28094496045794, 53.80836806978498, 63.37404687064034, 57.29806954520089, 53.75002057211739, 48.2924086025783, 51.2019042287554, 53.37928901399885, 57.079347201756065, 56.295739786965505, 58.10731928689139, 57.91836302621024, 55.41057055337088, 44.9916911806379, 45.44284813744681, 45.38433040891375, 54.04162951878139, 57.70269441604614, 63.33200332096645, 61.96366677965437, 61.79648617335728, 56.175087792532786, 53.23912647792271, 50.78014162608555, 53.79056331089565, 54.52661030633109, 61.09776142665318, 60.090119770595, 59.658518518720356, 61.881497383117676, 61.28092288970947, 61.03162152426583, 61.54344667707171, 60.04452569144112, 59.76181738717215, 65.12759154183524, 64.6446361541748, 65.57399245670864, 66.03080177307129, 72.03799193246024, 72.05671732766288, 70.34321512494768, 26.046586990356445, 2.359276899269649, 1.4428713875157493, 0.12599817184465273, 0.7822216834340776, 0.07033807997192655, 0.008426033442706933, 0.23423414251634053, 55.60053082874843, 57.550872802734375, 34.836829457964214, 30.53583894457136, 59.73523357936314, 8.65864792891911, 0.45557573969875065, 0.22716162273926394, 0.0633341193731342, 0.07804937940090895, 0.09488081373274326, 0.011488805658050945, 0.09953463436769587, 0.07433109570826803, 0.016102017668474997, 0.07275320323450224, 0.09807091219616787, 0.2163781270916973, 0.3686295380549771, 0.21007202618888446, 0.18831588647195271, 0.23671673930117063, 0.16046211895133766, 0.35539292118379046, 0.13292893208563328, 0.1851461644151381, 0.29045654992972103, 0.44594952623759, 14.325644731521606, 84.49598693847656, 44.72476570946829, 44.66520575114659, 62.07964611053467, 60.88356930868966, 10.477989435195923, 0.280750785022974, 1.2069999128580093, 5.3709457857268195, 14.23006270612989, 19.65979242324829, 7.270475583417075, 0.2396420394735677, 41.08378110613142, 94.19324030194963, 90.55152266366142, 87.74738257271903, 82.05999020167759, 79.02640669686454, 78.01493658338273, 74.5627658026559, 67.94793483189174, 64.13233157566616, 63.262632506234304, 65.71852888379777, 65.6808557510376, 67.41131155831474, 66.94592816489083, 65.53514507838658, 61.492954117911204, 60.88199206760952, 59.50489384787423, 59.10319069453648, 60.157169886997764, 55.77970402581351, 60.693362372262136, 59.21228436061314, 65.06763553619385, 67.75301006862095, 61.1997401373727, 54.03772810527256, 56.53378159659249, 53.902679443359375, 58.47451768602644, 54.61380672454834, 53.37999773025513, 52.382351057870046, 54.96908548900059, 57.5955844606672, 61.175490924290244, 58.91011415209089, 60.96535655430385, 63.647659982953755, 64.20644106183732, 63.26280621119908, 64.80346502576555, 69.57327134268624, 69.79009682791573, 60.88598033360073, 62.878397124154226, 64.38594082423619, 62.144910539899556, 62.713092531476704, 58.55766677856445, 65.03864070347377, 64.52561351231166, 60.93628529139927, 67.38818100520542, 67.29929270063127, 61.41310541970389, 62.62569808959961, 67.25996589660645, 63.67777347564697, 63.33997985294887, 60.55120917728969, 64.01183591570172, 61.07399163927351, 62.567493030003135, 62.12077249799456, 59.75800282614571, 66.65085901532854, 64.64900657108852, 61.30191339765276, 56.025802271706716, 55.12382534572056, 64.19989585876465, 62.052047865731375, 58.043465341840474, 57.08151503971645, 64.109861101423, 59.53086621420724, 56.793418407440186, 56.54856736319405, 62.504361697605674, 61.219354901994976, 58.215586117335725, 60.01739992414202, 58.59464509146554, 55.16169997623989, 63.43563570295061, 60.56561279296875, 57.15528406415667, 51.815933908735005, 54.03944778442383, 55.264085156576975, 58.77799415588379, 60.839851243155344, 59.31559712546212, 61.772778919764924, 57.89709459032331, 48.36226579121181, 47.689457825251985, 48.899312904902864, 57.21360029493059, 62.196181297302246, 67.23953819274902, 64.67226219177246, 65.84537519727434, 59.51857485089983, 57.044369970049175, 55.358813422066824, 56.772959436689106, 56.91574839183262, 66.26945849827358, 65.187575340271, 63.241794858660015, 66.8194501059396, 65.13195501055036, 65.05904061453683, 64.55005032675606, 63.300430706569124, 64.90563828604562, 67.90257004329136, 67.9360603604998, 70.31124646323067, 69.28529630388532, 75.61227035522461, 76.21324784415108, 73.52711595807756, 25.06811213493347, 3.2924290895462036, 2.6967096499034335, 0.34637920771326336, 4.277564227581024, 0.4531260925744261, 0.1949204070759671, 1.0010149202176502, 64.11495413099016, 60.02877412523542, 52.06911931719099, 35.654062679835725, 68.35015910012382, 8.609183703150068, 0.6128210191215787, 0.4329477096242564, 0.20853175169655255, 0.15132818264620645, 0.2132099520947252, 0.0964645483930196, 0.12756835616060666, 0.14296906547886984, 0.17555262920047554, 0.1436270951692547, 0.10662920653287854], [0.006806622259318829, 0.0399797413099025, 0.05423427266733987, 0.11835585907101631, 0.06891447957605124, 0.14136841494057859, 0.0217857340217701, 0.1708595281732934, 0.03387027646281889, 0.14117818086275033, 0.15846645246659005, 22.379939215523855, 60.90610926491873, 20.460867609296525, 29.665111541748047, 46.298341614859446, 24.292401347841533, 1.1116086372307368, 0.044163832507495365, 0.29477260261774063, 2.565589325768607, 4.039640971592494, 2.033281969172614, 1.3759340707744872, 1.9015447752816337, 58.90803664071219, 86.94048132215227, 82.08473273686, 79.84853145054409, 79.1895365033831, 71.63052872249058, 70.94227491106305, 64.8852870123727, 61.52490888323103, 56.320152282714844, 57.575636182512554, 55.84668813432966, 60.85774980272566, 63.01431778499058, 64.76240812029157, 63.69027328491211, 59.96781063079834, 55.31643983295986, 52.240354197365896, 52.11210087367466, 54.32950380870274, 53.32687875202724, 51.749811376844136, 50.58970887320382, 52.95165865761893, 53.51821824482509, 51.51809590203421, 50.110835552215576, 48.85185323442732, 49.825118677956716, 51.84143032346453, 50.02821452277047, 48.32556193215506, 48.97965145111084, 48.12790305273873, 51.403613907950266, 51.71665457316807, 58.395759854997905, 55.501598903111045, 52.59770352499825, 57.83372354507446, 58.97215461730957, 63.787520272391184, 65.19468334742955, 58.24494573048183, 52.54584564481463, 55.73830665860857, 55.42956345421927, 58.716995920453755, 54.93094335283552, 51.12764188221523, 61.509143420628135, 57.61552579062325, 61.689171246119905, 59.6088319505964, 56.07980367115566, 58.16073703765869, 57.30809926986694, 57.884309904915945, 62.935789244515554, 50.88368715558733, 54.72132314954485, 49.620007855551584, 56.00947747911726, 51.044020312173025, 52.29769420623779, 48.57528018951416, 49.079702036721365, 56.9502739906311, 58.769802229745046, 61.04065418243408, 55.82906402860369, 56.12355300358364, 55.857214655194966, 60.640229497637065, 52.61864539555141, 55.12919977733067, 52.07584169932774, 52.58761126654488, 54.617857524326865, 55.79733855383736, 55.094354561397004, 52.72050251279558, 53.45102916445051, 57.5253346988133, 48.23305361611502, 48.67794329779488, 54.68656826019287, 50.83140890938895, 46.95480741773333, 43.948189871651785, 48.07854304994856, 51.04107775006975, 54.415251527513774, 53.95466933931623, 55.87656191417149, 53.13094997406006, 44.0650759424482, 42.42191730226789, 42.78506142752511, 46.97199726104736, 55.796046188899446, 58.432085037231445, 57.250877380371094, 57.731859479631694, 53.699465479169575, 49.78242547171456, 45.74809987204415, 47.154050486428396, 52.23157514844622, 55.22507102148873, 54.8607873916626, 57.37914112636021, 55.12642049789429, 58.33903476170131, 57.84381232942854, 57.62890107291085, 53.388613496507915, 60.13565131596157, 59.79271602630615, 62.29925782339913, 60.28666346413748, 62.92064911978585, 64.1921694619315, 74.08911405290876, 67.62749780927385, 46.78583765029907, 2.3467152076108113, 0.6576827147177288, 0.4966289539422308, 0.03913923319695251, 0.04161613368030105, 0.2719499415584973, 0.25735291625772205, 33.412028380802695, 60.92621735164097, 39.732130663735525, 27.036807775497437, 45.9071615082877, 19.691484894071305, 0.36380748823285103, 0.11820417935294764, 0.16619176364370755, 0.04449081514030695, 0.11782493256032467, 0.10136140670095171, 0.07634210386978728, 0.04752083022945693, 0.05527323191719396, 0.047996836115739176, 0.08643337844737939, 0.042486453229295354, 0.05986130929418972, 0.11066557387156145, 0.07921544183045626, 0.08367402079914298, 0.06220847048929759, 0.05953836055206401, 0.16605311179799692, 0.06220115588179656, 0.1514696164854935, 0.1350885054894856, 31.590314933231898, 68.42655454363141, 33.383947236197336, 29.368638856070383, 44.15021916798183, 32.332882813044954, 1.106170586177281, 0.059362776045288355, 0.11847742540495736, 3.89995482138225, 6.655017180102212, 1.2371972181967326, 2.6312122387545447, 5.645318857261112, 65.6149798801967, 89.01845128195626, 84.52266802106584, 84.67893995557512, 79.38162640162876, 75.95066152300153, 74.28833280290876, 68.52767862592424, 62.385151454380576, 58.88851220267159, 60.06515489305769, 61.64543233598982, 65.55932480948312, 66.58449677058628, 67.6128510066441, 67.69190066201347, 63.915360178266255, 58.12105587550572, 53.426651409694124, 53.984581334250315, 55.1568466595241, 55.53794840403965, 53.87639093399048, 54.31632655007498, 52.951929637363975, 56.01031821114676, 54.78905071531023, 52.886501925332205, 50.230757985796245, 53.52582304818289, 53.511676515851704, 53.03485638754708, 50.51975788388933, 51.61927556991577, 50.778178759983604, 55.380286829812185, 55.2784366607666, 61.79327610560826, 59.23695741380964, 56.269413062504356, 60.59476048605782, 63.12992886134556, 65.53703498840332, 69.11749730791364, 60.38209697178432, 55.25296803883144, 56.82590470995222, 60.462355613708496, 63.028179441179546, 56.22974579674857, 54.03715487888881, 63.65877710069929, 59.385850361415315, 62.89988790239607, 60.854574475969585, 57.51044470923287, 59.927031653267996, 61.66277503967285, 62.17038263593401, 63.4961336680821, 52.03904056549072, 56.42438915797642, 53.41215399333409, 56.97074685777937, 54.186381340026855, 53.64982407433646, 48.769013336726594, 50.72396544047764, 56.92525700160435, 59.45454025268555, 62.39439255850655, 58.88199479239327, 55.020446572984966, 56.654516969408306, 59.745023591177805, 54.04959215436663, 57.253528118133545, 54.321697507585796, 54.57590430123465, 57.5985027040754, 57.21045276096889, 55.98623922892979, 55.10428006308419, 54.9018234525408, 59.458132471357075, 52.779405866350444, 51.6562955720084, 57.157768045152935, 53.312593255724224, 47.42787899289812, 46.86640896115984, 50.67117302758353, 52.63821152278355, 56.49430888039725, 56.932465757642476, 56.974714279174805, 55.98686804090227, 47.5934510912214, 45.4355525289263, 44.964082513536724, 49.63354294640677, 56.89580358777727, 61.64382035391671, 60.28444698878697, 61.09342575073242, 55.80954653876168, 51.65795619147164, 48.01135049547468, 49.72043364388602, 54.033698150089805, 57.0741742679051, 58.64607565743582, 61.33783558436802, 58.79733794076102, 59.403755869184224, 60.14318316323416, 58.585383142743794, 55.72669621876308, 63.23538167136056, 61.72341891697475, 65.224928855896, 62.18778092520577, 66.03662436349052, 66.34277588980538, 76.87737056187221, 70.50741495404924, 53.30296305247715, 4.428555531161172, 0.3601163662970066, 0.31797570469123976, 0.3578338016356741, 0.018904194269063215, 0.25632876264197485, 0.240927591919899, 33.61394303185599, 70.47374398367745, 41.64007125582014, 27.096928800855363, 52.24062170301165, 28.39933388573783, 0.2354543927524771, 0.14180676213332585, 0.09366383403539658, 0.03933418309316039, 0.09652888029813766, 0.054661668304886134, 0.06224783230572939, 0.04422264113756163, 0.01422089637656297, 0.07089356945029326, 0.09956660693777458, 0.10515610700739281, 0.12165497775588717, 0.14039626424866064, 0.13959289235728128, 0.16557257329779013, 0.18796292612595217, 0.16469990941030638, 0.298635936741318, 0.09848862513899803, 0.275931177926915, 0.21560918406716414, 34.10019186564854, 78.52911717551095, 28.27944793019976, 39.69526699611119, 58.144224643707275, 43.15225635256086, 2.664396835224969, 0.11442833553467478, 1.4343978422028678, 5.907199936253684, 13.82644966670445, 9.25773116520473, 3.933114230632782, 6.689145428793771, 73.81197125571114, 93.4523538861956, 92.98568507603237, 89.65792873927525, 83.95176233564104, 78.68101869310651, 78.19578429630825, 71.86453710283551, 67.13751084463937, 63.77823747907366, 63.62377207619803, 64.34289673396519, 68.24627658299038, 68.70432267870221, 71.92739050728935, 70.68888105664934, 65.75613948277065, 60.63098839351109, 55.87876796722412, 56.602506228855674, 57.47567592348371, 59.613924980163574, 58.706594467163086, 57.251450606754844, 56.64417804990496, 60.53623580932617, 59.32935455867222, 54.835555008479524, 54.87405845097133, 56.213125705718994, 58.34890815189907, 55.23758820125035, 55.080527646201, 55.06829186848232, 55.338979789188926, 57.57602875573294, 57.64798082624163, 64.81245599474225, 60.532455989292686, 60.78082629612514, 63.632756096976145, 65.77297496795654, 68.965665272304, 70.72792993273053, 64.36312988826207, 57.224491596221924, 61.74830041612898, 61.67478152683803, 65.97389602661133, 59.26101902553013, 54.74012150083269, 67.18058967590332, 63.87496335165841, 68.47389262063163, 64.21037374223981, 61.197495869227815, 62.35137626102993, 64.09561729431152, 63.65003626687186, 68.59724399021694, 56.9281439781189, 60.1619085584368, 56.435068539210725, 60.88502148219517, 57.1311217035566, 56.88335241590227, 53.33314255305699, 53.88340514046805, 60.920853342328755, 64.56286975315639, 65.78061103820801, 58.0010917527335, 59.95722157614571, 60.069233485630576, 64.33157117026192, 57.11117689950125, 61.17305210658482, 57.62609052658081, 58.11634847096035, 59.4594943182809, 60.76080853598458, 59.42109857286726, 57.33714621407645, 58.055343287331716, 60.54202365875244, 54.97448076520647, 52.57651499339512, 58.53862176622663, 55.896485873631065, 49.91792924063546, 49.67282458714077, 52.905599049159456, 56.32845190593174, 58.462594577244346, 59.1253901890346, 60.44196959904262, 59.31764684404646, 47.949382986341206, 47.86243322917393, 47.625805377960205, 53.50152172361101, 61.18183462960379, 66.02338109697614, 61.858651706150596, 63.17721830095564, 58.30789988381522, 55.94511978966849, 50.24805900028774, 52.97764492034912, 58.960710934230256, 61.68170888083321, 61.720083781651084, 65.64119543348039, 59.96633761269705, 63.07375962393624, 63.59848758152553, 63.86076123373849, 58.16439526421683, 67.13792078835624, 65.7830707005092, 70.33587782723563, 65.95057787214006, 70.1021682194301, 70.39665372031075, 81.42052664075578, 73.15474115099225, 56.531634603227886, 6.344445730958666, 1.7314565650054385, 1.2123090965407235, 0.6571072627391134, 0.15482322153236183, 0.4607189808573042, 0.30593881915722576, 42.42415462221418, 74.9607377733503, 55.06162854603359, 38.88692399433681, 62.429793630327495, 32.78819826671055, 0.5950973587376731, 0.2918501522924219, 0.27900464300598415, 0.20751280922974857, 0.18218882381916046, 0.17904802092484065, 0.12316319825393812, 0.1885915073965277, 0.085419368930161, 0.21111887001565524, 0.15179630395557198], [0.026198729007904018, 0.09163620855127062, 0.07596936422799315, 0.03903360565059951, 0.04067704799984183, 0.08523698550249849, 0.05206465355253645, 0.048219639874462566, 0.05783316133809941, 0.03573908404048, 0.04252630019826548, 36.46850272587368, 56.185009820120676, 32.33455038070679, 53.89188194274902, 47.86272157941546, 7.571214897292001, 0.22291068227163383, 0.11585503683558532, 0.2834705433675221, 2.111215135880879, 4.760634694780622, 1.9608491701739175, 3.2459332644939423, 21.06400772503444, 79.40881470271519, 77.8794675554548, 84.05422742026192, 79.23214980534145, 75.199234689985, 72.68772493089948, 72.22589206695557, 67.04059737069267, 62.82197080339704, 56.86155939102173, 55.50852278300694, 58.91532530103411, 61.474319049290244, 61.9744781766619, 66.82395253862653, 68.31755815233502, 67.66464287894112, 60.65287521907261, 54.89415611539568, 52.13407107761928, 53.91325112751552, 53.38080024719238, 52.846619265420095, 50.72634172439575, 51.63825110026768, 49.27596780232021, 50.58164896283831, 48.7494089944022, 49.313168457576204, 50.82296684810093, 50.9173754964556, 49.82708501815796, 47.723424094063894, 48.48996325901577, 50.72708518164498, 53.15940284729004, 55.20215586253575, 53.39563812528338, 49.38046523502895, 55.03744534083775, 57.3810727255685, 60.85941737038748, 59.874558857509065, 63.146319661821636, 57.22557898930141, 52.28985316412789, 57.1042287009103, 56.926212378910606, 58.80348709651402, 51.43413039616176, 50.2132693699428, 56.37772158214024, 54.083513259887695, 59.99606895446777, 55.70333637510027, 54.79355314799717, 59.57977458408901, 63.47560174124581, 58.22153377532959, 46.89951017924717, 48.32441895348685, 56.1973637172154, 54.890171323503765, 55.75529500416347, 55.73899800436837, 57.30460432597569, 48.68348101207188, 45.7442193031311, 54.05102695737566, 51.52656923021589, 50.41460037231445, 58.9114898954119, 58.00511128561837, 55.28952945981707, 54.95187827519008, 57.86555324281965, 54.69225883483887, 53.45340197426932, 52.97645330429077, 60.58421312059675, 56.707066195351736, 54.7740078653608, 55.34692505427769, 53.48817770821707, 55.96010357992989, 57.39777272088187, 50.35448455810547, 52.11507817677089, 53.4953065599714, 47.002902848379954, 43.48480755942208, 43.82409157071795, 49.415713446480886, 50.589236395699636, 53.26244463239397, 52.94217436654227, 51.61492599759783, 48.586775984082905, 44.20961236953735, 43.46699585233416, 45.19487387793404, 53.74106087003435, 58.56422587803432, 58.31912817273821, 58.732455662318635, 52.064939975738525, 47.332309995378765, 45.690301282065256, 48.59878247124808, 51.182338101523264, 52.41171761921474, 51.98846115384783, 55.179935523441856, 54.68626601355416, 54.50889934812273, 54.10888460704258, 51.77577679497855, 50.24607181549072, 55.86560113089425, 57.12371839795794, 59.277444566999165, 60.189235823495046, 64.97564833504813, 64.51041085379464, 68.49913542611259, 71.4923290525164, 58.45096329280308, 10.07404635633741, 0.14907394003655228, 0.07513849809765816, 0.34482870091285023, 0.07924976891704968, 0.1803819393473012, 0.3619933570069926, 15.057804209845406, 72.34403228759766, 34.21572651181902, 35.6571615764073, 35.687490463256836, 28.279350655419485, 0.2290399026657854, 0.019009781103315096, 0.0679603372035282, 0.0754304581454822, 0.13768018356391362, 0.14194021640079363, 0.07707477241222348, 0.08931099796401602, 0.07178003474005631, 0.12752351856657437, 0.1626710489924465, 0.034706028045288155, 0.07338517039482083, 0.10488666075148753, 0.08308640947299344, 0.05509345745667815, 0.04738291459424155, 0.06862618361732789, 0.07413499908787863, 0.0651505169059549, 0.1652854172778981, 0.09905059462679283, 47.78849744796753, 64.98461151123047, 42.78750719342913, 33.93491506576538, 54.12572009222848, 12.173439349446978, 0.2291820150400911, 0.06702508524592433, 0.6650854774883815, 3.293611151831491, 3.5430625549384525, 1.6370177354131425, 2.4025309554168155, 28.108584778649465, 84.13098417009626, 82.58791433061872, 86.80919510977608, 80.86352430071149, 80.02050631386894, 75.87891442435128, 75.57447910308838, 67.76036821092877, 64.69296087537492, 59.82781137738909, 57.90385518755232, 60.448514802115305, 64.69626126970563, 65.23003578186035, 70.84015028817313, 71.41198703220913, 71.55840642111642, 64.30404240744454, 57.65311554500035, 54.29658324377877, 55.58651631219046, 55.97359003339495, 55.15263605117798, 53.17436926705496, 54.820790086473735, 51.86132301603045, 52.54152039119175, 51.90096943719046, 49.96185922622681, 52.06700011662075, 54.257676805768696, 53.20234966278076, 50.46028825214931, 51.50622143064226, 53.32505137579781, 56.70192800249372, 59.040476254054475, 58.44132614135742, 52.60008675711495, 57.81307349886213, 61.309882981436594, 62.22604465484619, 65.25747421809605, 65.51707976205009, 59.70663479396275, 55.026157992226736, 59.94934926714216, 59.071347100394114, 61.92739718300955, 54.11349126270839, 51.608696937561035, 59.72429016658238, 57.97867338997977, 64.19171782902309, 57.021242891039165, 56.46525846208845, 63.56732491084507, 62.82531288691929, 59.39351422446114, 49.38661091668265, 51.335747378213064, 60.19523906707764, 57.875374521527974, 57.29689877373831, 57.12737315041678, 60.488696234566824, 54.65586764471871, 48.45132780075073, 58.46268490382603, 55.37653827667236, 52.919620513916016, 58.13332292011806, 60.35814653124128, 57.03300271715437, 55.792811802455354, 61.29626451219831, 55.31288235528128, 54.65879283632551, 54.871769019535606, 63.31626565115792, 59.60284260341099, 57.43134641647339, 56.78099502835955, 57.354766845703125, 57.1100617136274, 58.508223397391184, 52.43819720404488, 55.901377405439106, 54.36502647399902, 49.9112937109811, 46.022869859422954, 46.91787426812308, 51.988079002925325, 53.57343905312674, 56.32187196186611, 56.2603109223502, 53.63873822348458, 50.39507246017456, 45.97268302100045, 46.606018270765034, 47.69171251569475, 55.36377443586077, 61.424146107264924, 60.052898270743235, 62.243679182870046, 55.27500425066267, 50.919011797223774, 47.11025251661028, 50.2686082976205, 51.53927401133946, 55.93362399509975, 54.11550276620047, 57.30356209618704, 57.12753643308367, 57.1105307170323, 55.002207551683696, 55.72938864571707, 53.50530849184309, 59.09875774383545, 59.35641779218401, 62.442501885550364, 62.46518080575125, 67.09138175419399, 65.18146787370954, 72.61576243809291, 71.52037893022809, 65.35095528193882, 16.512387003217423, 0.1186306793242693, 0.047566862045122046, 0.14881963868226322, 0.04975909673209701, 0.1279456623430763, 0.367356253521783, 14.438589436667305, 81.1051618031093, 39.06023638589041, 33.69955178669521, 44.80749791009085, 39.281178678785054, 0.16324916082833493, 0.05240765639713832, 0.06969146324055535, 0.07338331799421992, 0.0688715690214719, 0.08285638610167162, 0.04810487924675856, 0.08219500444829464, 0.01146534361344363, 0.09239276152636323, 0.16591249220073223, 0.12127013983471052, 0.2126577738672495, 0.13390769170863287, 0.19274012478334562, 0.17789111871804508, 0.18638761208525725, 0.18878123935844215, 0.12988381619964326, 0.21661561434822424, 0.1700594268207039, 0.2206622886338404, 55.83241653442383, 72.0462394441877, 43.644202709198, 71.64682919638497, 69.4385735648019, 17.484391348702566, 0.40634997827666147, 0.2609266516353403, 1.2480447675500597, 9.881963406290327, 12.000040105410985, 6.699075273105076, 4.496555379458836, 32.02693278448922, 88.34787368774414, 87.53826263972691, 92.54728153773716, 86.28202833448137, 84.54297065734863, 80.71861961909703, 80.25955908639091, 72.90257712772915, 70.83488355364118, 63.37357439313616, 60.87857355390276, 64.70856652941022, 69.40169947487968, 66.54562854766846, 73.61479527609688, 75.14146736689976, 75.29978901999337, 65.45198208945138, 60.72426795959473, 57.776022229875835, 58.78846509116036, 59.360280990600586, 59.819841793605256, 55.769615241459434, 56.834159169878276, 55.02463286263602, 57.36433104106358, 55.21363081250872, 54.250763348170686, 55.70170702253069, 57.262275900159565, 59.0044915335519, 54.58197702680315, 54.8208977835519, 57.38800702776228, 60.09042549133301, 63.81155409131731, 60.71561745234898, 57.800994055611746, 62.62130682809012, 64.40809862954276, 67.33089310782296, 69.68153817313058, 70.31044742039272, 58.588495935712544, 56.96497985294887, 62.327585629054475, 63.75773334503174, 67.02463041033063, 57.028524603162495, 55.40091603142874, 63.02046694074358, 60.80654157911028, 66.19939981188092, 60.17249066489083, 58.08320903778076, 66.77926867348808, 66.83796705518449, 63.29674121311733, 53.83119985035488, 56.117410796029226, 63.0701048714774, 59.04048320225307, 58.56656742095947, 59.8769907270159, 62.45919145856585, 54.34215995243618, 50.55618034090315, 58.01011746270316, 56.11744901112148, 56.678158215114046, 62.96605559757778, 62.80776868547712, 57.682562010628835, 59.361163411821636, 64.74211938040597, 60.204653876168386, 57.590084961482454, 57.09529331752232, 64.6829902103969, 57.615838459559846, 61.22867938450405, 58.197079590388704, 59.57480662209647, 60.01623957497733, 60.71417222704206, 55.25837026323591, 57.838740144457134, 59.177835191999165, 52.036358560834614, 48.82328224182129, 49.538182394845144, 53.410142489842, 56.3322490964617, 59.38579477582659, 60.29215948922293, 56.91925375802176, 53.370690618242534, 49.935445649283274, 48.74632746832711, 51.469736439841135, 58.20769643783569, 64.23494257245744, 62.21722044263567, 65.06449495043073, 57.77545942578997, 54.696802956717356, 50.77432598386492, 54.83947031838553, 55.11860377447945, 58.33334418705532, 57.84804030827114, 60.439391817365376, 60.27030045645577, 59.820390701293945, 60.70880126953125, 59.33323860168457, 55.34636919839041, 60.95109190259661, 62.117492948259624, 65.3728837966919, 65.1035577229091, 73.64462389264787, 69.23252473558698, 79.1948310307094, 75.10439872741699, 69.65594100952148, 17.80000111034938, 0.2795675556574549, 0.4772077617900712, 0.5479188188910484, 0.20252184490008013, 0.26479288988879746, 0.44817810665283886, 19.34420003209795, 86.89508179255894, 46.61109045573643, 51.25511700766427, 50.48174428939819, 48.422232219151084, 0.24794377971972736, 0.12451559997030667, 0.21253879953707966, 0.22003070823848248, 0.17173813602754048, 0.21305074063794954, 0.140479819050857, 0.20833230311317102, 0.20270179238702568, 0.20797759214682238, 0.21786451233284815], [0.05502082367560693, 0.06034321164978402, 0.024533734690131884, 0.05240623825894935, 0.061242854089609215, 0.11811576624001775, 0.02968075019972665, 0.030033859823431288, 0.031890331634453366, 0.06500588716672999, 1.257715031504631, 54.09912238802229, 41.382564067840576, 32.672753947121755, 48.90042461667742, 31.16230242592948, 3.0880932084151675, 0.15310734217720373, 0.10521857972655978, 0.02790309362379568, 4.250243042196546, 2.2966538710253577, 16.515329565320695, 3.412163270371301, 48.552851404462544, 85.90880584716797, 80.69569056374687, 83.39420413970947, 77.76268918173653, 77.95296560014997, 73.16071660178048, 72.04068783351353, 66.45271723611015, 63.78568594796317, 57.383449009486604, 57.68351738793509, 55.59275232042585, 60.76121847970145, 61.71298967088972, 66.15816920144218, 70.02555738176618, 69.60658795492989, 67.79653358459473, 61.21914645603725, 54.53257533482143, 51.32850388118199, 52.77899939673287, 51.4664568901062, 50.47880172729492, 50.4240186555045, 48.888758591243196, 50.17531483513968, 49.75005381447928, 50.14122002465384, 48.76877014977591, 49.59242698124477, 50.473034722464426, 50.64416537966047, 48.665537289210725, 49.64516380855015, 54.544199671064106, 54.639674867902485, 55.453277656010215, 56.48697853088379, 51.08147457667759, 59.907632282802034, 57.09773908342634, 62.002389090401785, 56.39924015317644, 52.96018757138933, 54.850674288613455, 57.13952554975237, 53.60164526530674, 60.542926924569265, 44.798222064971924, 50.95172739028931, 57.072145393916536, 58.7906676701137, 58.23826156343733, 55.630880560193745, 61.13706738608224, 59.828012875148225, 52.406384876796174, 49.76377650669643, 46.49891178948538, 58.890145029340474, 60.334515707833425, 56.686742714473176, 53.73529386520386, 55.146087374006, 53.1714996610369, 57.89422845840454, 49.48676225117275, 55.25066818509783, 59.992587906973704, 52.03096675872803, 50.744094371795654, 54.57839870452881, 59.03488295418875, 51.31510080610003, 55.84452377046858, 53.731055464063374, 53.93689932141985, 49.769317695072715, 51.39073889596121, 61.804962975638254, 55.62759058816092, 53.870366845812114, 54.810121127537315, 54.682559149605886, 55.606120654514854, 56.572323254176546, 55.632885115487234, 50.61199869428362, 49.773872239249094, 44.468616894313264, 43.44445937020438, 45.03159815924508, 46.81390142440796, 49.94185536248343, 52.17862292698452, 49.25173595973423, 47.39077908652169, 45.69337933404105, 43.42032480239868, 40.805144446236746, 48.4286801474435, 57.85244199207851, 57.30662625176566, 56.53673458099365, 51.509216104234966, 47.31543629510062, 44.90773262296404, 46.567566939762656, 49.37744624274117, 49.816096442086355, 51.45922381537301, 53.68748678479876, 51.77670785358974, 50.98706940242222, 48.773095403398784, 48.70262329918997, 52.3169025012425, 58.31281920841762, 57.89717449460711, 60.70319407326834, 59.81260871887207, 61.36361340114048, 61.851217133658274, 70.99548421587262, 69.88018717084611, 71.75696509225028, 29.985107353755406, 0.39176877641252106, 0.08851360396615096, 0.3546218339885984, 0.08082139172724315, 0.19450815634003707, 0.49472069633858545, 5.5641143918037415, 68.31281253269741, 43.84959840774536, 22.077046394348145, 26.484090736934117, 39.413521017347065, 0.15656807433281625, 0.09559574536979198, 0.04873046139255166, 0.03515282639169267, 0.10953255609742232, 0.030539680538432937, 0.12619604622679098, 0.03537860552647284, 0.14319105499557086, 0.052833382838538716, 0.042376459310097356, 0.08797632636768477, 0.03554729611745902, 0.09165932623935596, 0.07959277515432664, 0.0954619450494647, 0.025967796399657215, 0.056842808944306204, 0.034359072734202654, 0.06440798924969775, 0.09201527213943855, 2.150349561657224, 63.82305335998535, 50.79376704352242, 38.65722697121756, 40.18922138214111, 43.34577757971627, 3.0383888355323245, 0.22966051793524198, 0.024082834599539638, 0.043060707593602796, 2.4342814002718245, 3.518585571220943, 27.044832944869995, 7.072145334311894, 55.09688023158482, 86.76426110948834, 83.73083741324288, 85.21325642721993, 80.74835096086774, 81.27539266858781, 75.40916756221226, 76.19842733655656, 70.28704588753837, 64.80786323547363, 61.72486414228167, 60.2706617627825, 58.75102819715227, 63.98394584655762, 66.16492979867118, 68.34549685886928, 72.03792939867292, 71.36500331333706, 70.4886895588466, 62.80275208609444, 58.11824880327497, 52.73098039627075, 54.1336966242109, 54.930106094905305, 52.358511788504465, 53.688959802900044, 50.066610268184114, 51.64987891060965, 50.99205820901053, 53.129334517887656, 51.23229564939226, 54.874291215624126, 54.9666953086853, 53.629858425685335, 51.550908769880024, 52.8230961390904, 56.28004033224923, 58.528213364737375, 56.784309319087434, 61.776114055088584, 54.451938016074045, 61.40360723223005, 60.625325611659456, 64.2072401046753, 58.44873292105538, 56.56889084407261, 57.28873464039394, 59.40370723179409, 57.894023486546104, 61.49762330736433, 45.84453044618879, 54.10336773736136, 59.35003934587751, 63.55104528154646, 59.5212915965489, 57.151518140520366, 64.41449792044503, 61.52673625946045, 53.90782805851528, 53.62982715879168, 50.09546266283308, 60.334744998386924, 58.97557313101632, 56.87676204953875, 56.86732292175293, 57.521176201956614, 56.436124665396555, 58.95950889587402, 51.64912503106253, 55.92253119604928, 63.47667176382882, 55.70755740574428, 52.92743376323155, 54.62168598175049, 60.19668429238455, 54.000461442129954, 56.76300266810826, 55.91802181516375, 55.69655493327549, 51.20124414988926, 53.5159774507795, 62.631458146231516, 57.893940108163015, 56.83354772840227, 54.24280766078404, 57.15654168810163, 56.31372519901821, 57.00843736103603, 57.58221960067749, 52.873939582279746, 51.147677012852256, 47.178000926971436, 46.424857888902935, 47.04484564917428, 49.03360768726894, 52.31337629045759, 54.17596251623971, 52.57613284247262, 50.09380899156843, 49.074317182813374, 46.35907929284232, 44.535521098545615, 50.41066074371338, 58.86092785426548, 58.9639835357666, 57.50872850418091, 53.161372661590576, 48.18836975097656, 47.03682047980172, 49.675499643598286, 51.69336421149117, 52.22033643722534, 53.00431905473982, 55.60110405513218, 53.4005400793893, 54.25893790381295, 50.52600084032331, 50.962358134133474, 54.534274169376914, 60.20394515991211, 59.84753731318882, 63.97689342498779, 62.336847577776226, 63.74091175624302, 64.62377766200474, 72.30801282610211, 72.69480514526367, 73.46766022273472, 39.657576492854524, 0.7147107603294509, 0.04052360409072467, 0.5407164682235036, 0.0941738345261131, 0.19321770487087114, 0.4720651720251356, 5.887622518198831, 75.3660192489624, 50.91211918422154, 24.485995531082153, 39.45363644191197, 54.59425449371338, 0.6108875742980412, 0.04671016408662711, 0.025843599046181356, 0.05981311295181513, 0.05997089948505163, 0.053491534665226936, 0.1004065450813089, 0.10026769646044288, 0.014058656957266586, 0.057329898700118065, 0.08412701077759266, 0.21137057936617307, 0.1297457478940487, 0.15715641847678594, 0.121333759278059, 0.18833659536072186, 0.1300043918724571, 0.128898664776768, 0.19616954933319772, 0.11323538276233844, 0.18281542376748153, 2.3696344920567105, 76.76955536433628, 52.76311928885323, 44.606688022613525, 62.95078345707485, 50.94513007572719, 5.39133266891752, 0.36116768845490044, 0.2369791152221816, 0.2076973029013191, 6.89430445432663, 9.704724414008004, 23.30440398624965, 7.771554044314793, 63.14155319758824, 89.70252227783203, 90.51385647909981, 88.96348408290318, 86.63392680031913, 86.29639720916748, 80.80381843021938, 80.91603878566197, 75.04380348750523, 68.69547067369733, 63.691864422389436, 64.65759454454694, 62.55871050698416, 66.89451844351632, 71.22050162724086, 71.42009557996477, 77.4293076651437, 74.6249452318464, 74.32740947178432, 64.01381615230015, 61.07962662833077, 55.837790966033936, 57.157615184783936, 57.598599978855674, 56.33093588692801, 55.03887319564819, 52.94730561120169, 55.53254270553589, 54.82782861164638, 58.2825493812561, 53.91632917949131, 56.5820437840053, 57.56911877223423, 56.12541512080601, 55.69842747279576, 55.74822173799787, 61.828079632350374, 61.8472775050572, 61.64143017360142, 65.19041715349469, 58.56151608058384, 66.09173052651542, 65.94889640808105, 66.08683204650879, 65.13340718405587, 53.81872088568551, 58.988253593444824, 62.252913338797434, 59.79324408939907, 66.32333483014787, 50.141473633902415, 56.98705080577305, 61.79322052001953, 67.09489059448242, 62.02206638881138, 59.792083740234375, 66.02958583831787, 64.35206140790666, 57.64186641148159, 54.87885965619768, 51.94067144393921, 64.30700928824288, 64.31953689030239, 61.21836825779506, 58.450991085597444, 59.65465532030378, 59.655405725751606, 60.17908450535366, 54.760712487357004, 61.1920554297311, 64.94204684666225, 56.29096984863281, 55.61112683159964, 59.91240569523403, 62.043001311165945, 55.95827620370047, 60.191438402448384, 57.50473328999111, 58.74911049434117, 53.71549844741821, 57.56484910420009, 65.50919355664934, 58.95581940242222, 58.707407406398225, 58.89660685403006, 60.49192019871303, 59.778458322797505, 60.263282775878906, 60.668279375348774, 54.09701360974993, 54.22671563284737, 49.99770498275757, 49.1191782270159, 51.88319941929409, 51.74191127504621, 55.287820202963694, 58.19188928604126, 56.08964579445975, 52.15163959775652, 51.168730054582866, 50.04451847076416, 45.99202333177839, 54.16185767310006, 62.75009168897356, 62.04323060171944, 61.549894605364116, 56.6409957749503, 51.59352207183838, 49.63655151639666, 53.208679471697124, 55.8200626373291, 55.40147883551461, 56.55428225653512, 60.70468098776681, 56.76978063583374, 58.42047459738595, 54.62717505863735, 55.000164781297954, 58.50157397133963, 64.7005899974278, 65.27772821698869, 68.07284954616001, 65.47057546888078, 69.17880126408168, 67.43873609815324, 76.88403388432094, 74.27291475023542, 77.86543914249965, 43.26438638142177, 0.989033620272364, 0.5623582069362912, 1.7167501598596573, 0.13884483464062214, 0.4675741930093084, 0.7891273785914693, 8.17098253113883, 82.30856200626918, 57.226815768650596, 35.388651915958945, 41.09154224395752, 65.13276100158691, 0.7271369621157646, 0.17108507321349212, 0.15724962204694748, 0.13518698806209223, 0.1263751930424145, 0.107103692500719, 0.23139623765434536, 0.18432382068463735, 0.40117335319519043, 0.15852586499282292, 0.1328220356787954], [0.018159100054098026, 0.010933646117337048, 0.15461531840264797, 0.05284098243074758, 0.07945077813097409, 0.0325329110824636, 0.06963414738753013, 0.07923101420913424, 0.18510337599686214, 0.11160518202398505, 4.589332503931863, 61.89916665213448, 29.96711151940482, 34.34567172186715, 37.19537809916905, 30.64969907488142, 1.0370451297078813, 0.2589007360594613, 0.11690363128270422, 0.11578958534768649, 3.281719527074269, 2.1861110712800707, 28.00480648449489, 11.418302178382874, 79.8355244227818, 73.9269083568028, 84.02775478363037, 79.05746514456612, 82.64739785875592, 74.86309473855155, 74.45211574009487, 67.18156937190464, 68.13666180201939, 61.45876898084368, 61.32396003178188, 54.34645046506609, 56.090295451028005, 56.3376339503697, 62.02401188441685, 63.65227358681815, 69.15461458478654, 67.59916305541992, 71.6109903880528, 65.57265840257917, 61.09998485020229, 52.24301535742623, 51.330088070460725, 50.30992923464094, 50.06033951895577, 51.03000579561506, 49.11606543404715, 49.30074160439627, 48.21880980900356, 49.18792370387486, 50.61754335675921, 51.355316979544504, 52.40589850289481, 51.68180588313511, 50.50731018611363, 49.04268550872803, 52.36124243055071, 54.91392374038696, 53.863995347704204, 56.859575680324006, 55.35380377088274, 56.16567645754133, 60.68572630201067, 55.98965426853725, 59.86709649222237, 47.02019344057356, 52.82370410646711, 58.016308307647705, 57.46197754996163, 52.88186400277274, 41.39581080845424, 51.47466966084072, 60.20545291900635, 55.610557079315186, 54.238697801317485, 59.15951974051339, 58.602482659476145, 48.13300650460379, 56.36629179545811, 59.425065994262695, 46.984267779758994, 56.99169567653111, 51.667377948760986, 53.58208956037249, 54.27311222893851, 53.28653403690883, 52.947969164167134, 50.349499225616455, 54.170608929225374, 45.03890419006348, 55.79841899871826, 59.458500725882395, 57.418881348201204, 49.508822781699045, 55.76061037608555, 52.38779149736677, 54.48128373282296, 55.830971309116904, 49.851959569113596, 51.6587552343096, 47.486389773232595, 52.382754053388325, 58.365111351013184, 51.850216320582796, 51.87362827573504, 53.39367873328072, 53.99332216807774, 56.17217302322388, 51.73458787373134, 52.94607925415039, 49.09876789365496, 46.79254961013794, 45.80405024119786, 41.367958954402376, 45.251515592847554, 46.7952698298863, 48.189752442496165, 49.62109177453177, 46.71558441434588, 47.70553943089077, 43.2668251991272, 41.21524102347237, 44.188364778246196, 47.100163732256206, 52.464113984789165, 50.68193926130022, 47.13963992255074, 45.29687690734863, 45.251574652535574, 44.9527256829398, 46.365346567971365, 48.28809724535261, 49.11990431376866, 48.96509150096348, 48.96983017240252, 46.77569328035627, 48.47612592152187, 50.04419190543038, 51.990917342049734, 56.85730014528547, 59.493477957589285, 58.54443046024868, 60.922979491097585, 59.49167142595564, 63.38579627445766, 65.20065879821777, 71.71072483062744, 67.98464216504777, 55.26156990868704, 4.222239630562918, 0.12218937836587429, 0.10046738931643111, 0.049693814877952845, 0.23808626724140985, 0.20164608689291136, 2.238026274102075, 63.518249784197124, 51.71412542888096, 30.641298702784947, 18.38965129852295, 43.298738275255474, 1.4183015802076884, 0.19370952062308788, 0.028839855321816037, 0.06640421891851084, 0.04999496228992939, 0.04443390301561781, 0.06398385736559119, 0.07304540076958281, 0.09489230811595917, 0.031455190519669225, 0.1188466027379036, 0.07292173097708396, 0.02737466581831021, 0.11064012202301196, 0.029077603814325163, 0.10090756176837853, 0.11670826748013496, 0.0706232071721128, 0.09182695153036288, 0.2192310004362038, 0.27005940728953903, 7.560169867106846, 67.63321617671421, 36.87904746191842, 35.190788064684185, 35.98564461299351, 36.861604009355815, 0.24687381141952106, 0.1718657006110464, 0.15635073956634316, 0.27359044924378395, 2.4941166809626987, 3.8610883355140686, 25.585930109024048, 16.13129046985081, 85.57292992728097, 76.11513233184814, 87.99482876913888, 81.28774656568254, 85.11277852739606, 76.46454334259033, 77.01269367762974, 68.9412909916469, 71.26547036852155, 65.0436156136649, 63.600968088422505, 56.84155552727835, 58.86899471282959, 60.16764777047293, 63.87660312652588, 65.88568864549909, 71.50443976266044, 70.02291011810303, 75.54339981079102, 70.28357873644147, 64.98713370731899, 55.995282309395925, 54.18249382291521, 52.46504504340035, 52.27328865868704, 53.977987493787495, 51.57684292112078, 52.117840085710796, 50.71019063677107, 50.29785673958914, 54.8663945879255, 53.07431173324585, 53.95481177738735, 54.944329057421, 53.36077553885323, 53.430976663317, 54.14633887154715, 59.35674435751778, 57.99675260271345, 58.87057890210833, 60.422959327697754, 57.86325338908604, 62.577957017081125, 59.348427363804404, 61.379830496651785, 50.06175347736904, 54.800122669764924, 60.03944655827114, 60.07750184195382, 53.808309010096956, 46.14145476477486, 54.34509556634085, 61.64348684038435, 58.54101889474051, 56.15648399080549, 62.699877057756694, 58.68651417323521, 50.98869180679321, 61.08458764212472, 60.3789633342198, 49.01889487675258, 56.79644782202584, 54.278959138052805, 57.631520543779644, 57.20793056488037, 58.37899385179792, 54.69956833975655, 52.03540318352835, 56.51838091441563, 48.354799951825825, 53.84933117457798, 60.62718078068325, 58.18233551297869, 53.94825962611607, 57.63399757657732, 52.77019950321743, 54.735243865421836, 57.8584417615618, 51.43237597601754, 55.201818874904085, 49.92976549693516, 57.374110630580354, 58.58686310904366, 54.6053855078561, 54.7821546282087, 55.71133027757917, 57.487724099840435, 56.02975927080427, 54.31506197793143, 54.750404834747314, 50.85243763242449, 48.35774598802839, 45.75368969781058, 43.63947098595755, 48.006601401737754, 49.846984658922466, 48.82490464619228, 50.06707927158901, 49.46047721590315, 49.32417440414429, 47.2960855620248, 43.54470797947475, 46.53559480394636, 48.80823244367327, 55.171062673841206, 52.47719744273594, 48.9367914881025, 47.77712672097342, 46.668687547956196, 47.24391848700387, 49.044422558375764, 50.05387074606759, 51.42657423019409, 52.15626014981951, 51.143858977726524, 49.62643493924822, 50.7336824962071, 52.89283173424857, 53.78487273624965, 59.37529604775565, 64.13317230769566, 62.864195006234304, 63.3567111151559, 62.72132614680699, 64.88189629146031, 66.02006680624825, 75.08989088875907, 68.61896405901227, 65.12099075317383, 6.101481556892395, 0.05088835881490793, 0.08149441025618996, 0.0722338186044778, 0.14517464355698653, 0.2964665788624968, 2.2961355788367133, 67.36542565482003, 59.50045394897461, 32.39798048564366, 24.48615881374904, 56.87491035461426, 4.784265952450888, 0.265168445450919, 0.059266268009585996, 0.08295708069843905, 0.05938970031482833, 0.07773793182734932, 0.06175070362431662, 0.03972136874550155, 0.07406441108988863, 0.06224358467651265, 0.042553506059838195, 0.25841284223965233, 0.08765334369880812, 0.23192861622997693, 0.07818421109446458, 0.12964050711265632, 0.17219341945435318, 0.23884994483419827, 0.16956949739583901, 0.33369025002632824, 0.35410639164703234, 6.432439889226641, 83.97487204415458, 37.325417109898154, 50.4440016746521, 49.90469292231968, 48.37281663077218, 1.3605658497129167, 0.3389950639435223, 0.3566467453326498, 0.589402821447168, 7.468794107437134, 5.585466206073761, 34.153918811253135, 21.29988690784999, 88.98485674176897, 81.09135573250907, 92.78122738429478, 86.14282812391008, 89.93501595088414, 81.87560585566929, 82.91362503596714, 74.24534429822648, 76.59327956608364, 68.35581493377686, 69.4608633858817, 58.93561404091971, 60.60045106070382, 62.327981676374165, 67.66578238351005, 68.46661785670689, 75.03946781158447, 72.85906750815255, 78.00884301321847, 71.4617361341204, 67.54378591264997, 58.90235301426479, 56.2836012840271, 56.00989089693342, 55.441830498831614, 57.49043042319161, 53.560786383492605, 53.516102518354145, 53.456306321280344, 53.25771638325283, 57.38267775944301, 56.16779565811157, 58.21645811625889, 57.79731151035854, 55.5494441986084, 56.07676730837141, 57.20471007483346, 59.99377604893276, 59.97619710649763, 60.62185846056257, 62.927729334150044, 62.3228816986084, 67.11031559535435, 61.5810364314488, 62.192331995282856, 52.45475128718785, 58.13442768369402, 62.791565486363, 64.17682783944267, 59.070659228733604, 50.95392649514334, 55.65777703693935, 64.37262112753731, 61.49127265385219, 56.26988901410784, 64.48937865665981, 63.549002511160715, 54.35995428902762, 62.57041127341134, 62.508933612278526, 52.85001346043178, 59.10592828478132, 56.696800231933594, 59.05860410417829, 57.986278193337576, 57.088327748434885, 57.107536043439595, 53.2851687158857, 58.18471874509539, 50.46210173198155, 58.341487475803916, 62.36026300702776, 61.375904764447895, 55.96513407570975, 60.96320261274065, 53.79168544496809, 57.36599513462612, 61.54424571990967, 54.764193534851074, 56.37273277555193, 52.60548550742013, 58.63734177180699, 62.33328315189907, 58.65381595066616, 58.020536286490305, 57.653216293879915, 58.93464824131557, 59.12094334193638, 58.56779030391148, 57.99120446613857, 54.215126037597656, 52.88530683517456, 49.56677075794765, 46.83564928599766, 51.252448899405344, 53.221783774239675, 53.20834943226406, 53.66927555629185, 51.79476622172764, 52.42930350984846, 50.425905091421946, 47.209580489567344, 49.025096143995015, 53.13415309361049, 57.67152827126639, 56.123952525002615, 53.12967150551932, 51.03929901123047, 51.18579830442156, 50.42639493942261, 52.78370680127825, 54.44531985691616, 55.54932607923235, 54.91734225409371, 54.54357085909162, 51.98669631140572, 53.74541391645159, 55.98211547306606, 58.3633326121739, 61.14306368146624, 67.64800194331578, 65.85491507393974, 67.57986095973423, 65.62439468928746, 70.66262381417411, 70.7187305177961, 77.70423398699079, 71.7870785849435, 70.16662665775844, 6.118209345000131, 0.2577594130166939, 0.23874311628086226, 0.32234826577561243, 0.3890336560351508, 0.5178009292909077, 3.792691137109484, 74.14276804242814, 65.0318523134504, 45.909103529793875, 28.650486946105957, 68.1690126146589, 4.905698316437857, 0.46376484313181465, 0.2213534036917346, 0.1569524101380791, 0.20811959595552512, 0.26520467922091484, 0.10921446566603013, 0.12168378835277897, 0.1497919386518853, 0.1271716845887048, 0.20515515788325242], [0.12064971455505916, 0.05767046221132789, 0.11986021191946097, 0.035869634178067954, 0.09442481784416096, 0.029748973503176655, 0.08093997929245234, 0.029235872107424905, 0.19276295070137295, 0.10063831907297884, 14.08912718296051, 62.60044138772147, 26.183332749775477, 40.76930563790457, 43.23057644707816, 27.226901803697857, 0.14354218329702104, 0.035363972918795686, 0.08697679678776435, 0.12239150037722928, 1.0951393438237054, 0.41871486763869015, 0.6296216547489166, 30.655448709215435, 80.91456576756069, 75.54267719813755, 83.70113386426652, 79.25594738551548, 78.8947730745588, 73.27000481741769, 71.82325785500663, 67.19226264953613, 65.14929076603481, 60.18267672402518, 58.09390926361084, 55.19400215148926, 55.97205100740705, 57.580645833696636, 61.98901380811419, 63.48200103214809, 69.32631846836635, 68.76875332423619, 69.78213419233049, 68.25405161721366, 65.7577097756522, 57.32566779000418, 51.81148011343819, 50.82488455091204, 50.25702912466866, 50.77835593904768, 49.40633337838309, 47.909208502088276, 47.609821047101704, 48.033574308667866, 50.825593267168315, 51.033865519932334, 51.38122681209019, 50.01798677444458, 48.10552290507725, 51.12158652714321, 50.25095639910017, 55.31229870659964, 52.32622003555298, 55.5501320702689, 59.410384450639995, 57.97898605891636, 57.328620774405344, 59.695288385663716, 54.58004195349557, 55.762576716286794, 53.51270832334246, 56.77120501654488, 52.472389289310996, 49.18308775765555, 42.9829808643886, 46.208001136779785, 57.962866238185335, 54.33346428189959, 58.6292610168457, 57.35464525222778, 49.42450291769845, 56.286425726754324, 62.93220397404262, 46.44666828427996, 49.02071877888271, 52.55362067903791, 52.42959533418928, 55.48281792231968, 55.60961559840611, 56.14596789223807, 56.36740003313337, 53.83181129183088, 52.53935602733067, 49.22423846381051, 45.34906482696533, 55.98347037179129, 59.563279560634065, 58.277414662497385, 52.21608761378697, 55.19400909968785, 51.0075318472726, 55.51749290738787, 50.92079401016235, 52.83812856674194, 52.569733551570344, 51.99267871039254, 54.36605133329119, 52.88780123846871, 52.85340765544346, 55.68699073791504, 54.19005346298218, 55.62926162992205, 54.20669092450823, 51.68626315253121, 50.35490492412022, 46.15291581835066, 47.84880781173706, 43.96442781175886, 44.405478613717214, 43.742797647203716, 44.09657907485962, 46.010727882385254, 48.25811576843262, 46.80853394099644, 42.969675064086914, 42.32198483603341, 42.455900941576274, 42.04444251741682, 45.09157848358154, 44.694815499441965, 44.67529106140137, 43.061690058027, 46.28328834261213, 44.93554973602295, 46.508166790008545, 45.930531774248394, 47.77587604522705, 46.02971036093575, 47.201718602861675, 45.189756529671804, 49.48898914882115, 48.98807266780308, 54.09175034931728, 58.30188274383545, 58.224351269858225, 58.24572392872402, 60.78005504608154, 58.734032903398784, 63.34537165505545, 64.05064160483224, 73.20090498243059, 68.93910230909074, 68.16187681470598, 18.785601343427384, 0.26293791085481644, 0.1715388638632638, 0.06823791909430708, 0.24569967442325183, 0.39661088372979847, 0.47913751538310734, 55.948065825871055, 57.272948333195274, 42.99864905221121, 30.226307119641984, 45.729377950940815, 9.614319665091378, 0.6834055972950799, 0.05428240794156279, 0.11315794834601027, 0.05097116044323359, 0.013551936335196453, 0.07185869730476822, 0.07540775436375823, 0.03091118185381804, 0.048157340181725364, 0.06058136387062924, 0.07776538535420384, 0.06984516499297959, 0.08851058448531798, 0.015584911219775677, 0.12424996708120618, 0.04377978847229055, 0.08658311755529471, 0.0021453116579713033, 0.10758773902697222, 0.09932029872600522, 18.715561764580862, 70.81194060189384, 34.405936922345845, 31.657837527138845, 46.42577157701765, 31.248793601989746, 0.10525145474821329, 0.19990474890385354, 0.13633262658757822, 0.06028625542031867, 0.44381287374666756, 0.3081499747931957, 0.5678185139383588, 37.18558113915579, 86.49717930385044, 79.80627945491246, 85.80560425349644, 82.09061091286796, 81.28432805197579, 77.21569919586182, 75.2325860432216, 69.78778307778495, 69.50465093340192, 63.92321859087263, 59.46576854160854, 57.85776778629848, 58.5873772757394, 63.11478178841727, 63.67362540108817, 66.37678732190813, 70.40490818023682, 72.67559337615967, 71.49088382720947, 69.87432289123535, 68.32586819784981, 60.64848395756313, 53.290202685764854, 54.43472385406494, 51.81801489421299, 55.08785799571446, 52.26605558395386, 50.28994968959263, 48.10762473515102, 51.54924120221819, 53.35998691831316, 52.24772276197161, 53.37229912621634, 52.289669036865234, 52.45013420922415, 54.082964352199006, 53.020796707698274, 55.83030775615147, 53.78520972388131, 58.65460804530552, 60.593245778764995, 59.704272406441824, 59.96057060786656, 62.04407828194754, 58.556416102818076, 58.161091395786826, 57.28437464577811, 60.01830318995884, 56.44025536945888, 53.611859117235454, 44.79750987461635, 50.888252122061594, 60.289804049900596, 56.508747237069265, 61.34251172201974, 58.531367846897666, 51.83149439947945, 58.709116663251606, 63.63982936314174, 46.69124140058245, 51.344192913600374, 55.042097159794395, 54.427164213997976, 57.68976034436907, 57.75864825929914, 56.33458021708897, 57.765648569379536, 54.98402411597115, 54.94274486814226, 52.73195661817278, 47.563987255096436, 56.93295560564314, 58.72774478367397, 59.425434248788015, 54.36225414276123, 56.783694403512136, 53.384600911821636, 57.50443451745169, 54.17782810756138, 53.48017685753958, 53.99812684740339, 54.227299281529014, 56.82185738427298, 54.538116523197715, 53.62887525558472, 57.65371309007917, 57.47032928466797, 54.99110433033535, 57.949369362422395, 56.009154387882774, 54.269089221954346, 50.098151615687776, 49.35914816175188, 45.81338514600481, 45.51674917766026, 46.376185757773264, 46.162785734449116, 48.832367011478965, 51.05276114600045, 48.638206550053184, 45.58062049320766, 43.70397111347744, 45.42242738178798, 44.386065346854075, 48.58369445800781, 47.401486260550364, 46.38978338241577, 44.744317940303254, 48.847218785967144, 47.6645450592041, 49.930703503744944, 46.9681271144322, 50.60899707249233, 49.906513350350515, 49.82324266433716, 47.60417563574654, 52.40536001750401, 50.087739740099224, 57.03431592668806, 59.79284109388079, 62.34949329921177, 62.18265315464565, 63.913164547511506, 62.04942144666399, 65.1616655077253, 66.5812519618443, 74.05700642721993, 68.7664326259068, 74.07066658564976, 24.319770302091325, 0.3117927578943116, 0.18546769501907484, 0.051430874703718085, 0.17392524438244955, 0.5603169021861893, 0.5186119143451963, 60.203271184648784, 65.13934094565255, 46.98210341589791, 33.176529611860005, 59.734733309064595, 15.825059039252144, 0.6323626105274472, 0.09219729594354119, 0.1295869028461831, 0.1865983379206487, 0.053889108688703606, 0.02248409583366343, 0.07891396872167077, 0.06499491525547844, 0.08300508026565824, 0.026162966819746152, 0.1701152566820383, 0.1405603882989713, 0.3005968215210097, 0.07144830575478928, 0.14114991309387342, 0.06361665456954922, 0.1287480571440288, 0.13301897368260793, 0.18074844325227396, 0.3214346319437027, 19.454507895878383, 83.23780018942696, 34.798336437770296, 55.7695700781686, 62.97630419049944, 38.53092609133039, 0.5145650229283741, 0.5962767068828855, 0.39857111711587223, 0.22221796587109566, 4.814185764108386, 2.7985585161617825, 1.1361985291753496, 42.13638802937099, 89.93974072592599, 83.98163958958217, 92.24434702736991, 87.51291561126709, 84.39623859950474, 82.80810969216483, 78.5614262989589, 74.065108026777, 72.19722379956926, 67.38978603907994, 61.70957810538155, 62.18919835771833, 60.56778757912772, 64.58925901140485, 65.92363970620292, 68.94447326660156, 73.49544606889997, 73.98068741389683, 73.42329597473145, 72.25369875771659, 70.54805496760777, 62.17430141993931, 56.8130852835519, 57.03240517207554, 55.38669306891305, 57.714607102530344, 55.18677602495466, 52.10418340138027, 51.53923232214791, 54.475707803453716, 57.003809860774446, 56.66677359172276, 57.80059453419277, 56.112901415143696, 55.14209563391549, 56.83144242422921, 54.44513920375279, 60.507442474365234, 57.48724814823696, 63.264056886945454, 64.36351203918457, 65.04725646972656, 64.14995220729283, 65.70525782448905, 63.56874929155622, 59.02166053227016, 58.85303470066616, 63.2747015271868, 59.804208346775596, 57.02847943987165, 48.05073635918753, 51.97594397408621, 63.604928561619346, 58.008974484034944, 63.40008871895926, 63.55356052943638, 54.29534299033028, 61.14958803994315, 67.43808991568429, 50.25963122504098, 54.557470730372835, 58.57694108145577, 55.88674449920654, 61.17226696014404, 60.960256576538086, 58.9221762248448, 61.53863852364676, 58.14395713806152, 57.16693271909441, 54.10529933656965, 50.56576190676008, 60.48895331791469, 62.1818402154105, 63.14124052865164, 56.3977358681815, 58.51313577379499, 54.62983621869768, 60.28571850912911, 55.3474565914699, 56.47695575441633, 57.72342784064156, 58.47879082815987, 58.787714685712544, 57.790259088788716, 56.71273939950125, 58.69021756308419, 59.51107774462019, 58.117394174848286, 59.26270048958914, 57.037227221897666, 58.7680721282959, 51.57823950903756, 53.078397274017334, 49.41473027638027, 49.19766160420009, 50.03862987245832, 48.61300890786307, 53.0613602910723, 55.4074820790972, 52.673133168901714, 48.73482819965908, 46.82368448802403, 48.698002747126985, 46.01980570384434, 52.183354650224956, 49.008423941476, 50.17777797154018, 47.65185417447771, 51.07249402999878, 50.29795748846871, 53.83611570085798, 51.3832174709865, 53.1897143636431, 53.070799418858115, 54.34260811124529, 49.022754601069856, 57.78317540032523, 53.12859106063843, 60.53474194662911, 64.08299936567033, 68.45448630196708, 64.46361473628453, 68.78124618530273, 65.18058545248849, 71.22164113180978, 71.49796404157365, 76.88326958247593, 71.71530369349888, 79.3544728415353, 26.80258400099618, 0.6130692000899995, 0.4307377482099192, 0.20718530751764774, 0.461074098944664, 1.415139607020787, 1.1139209760086877, 69.6196505682809, 69.42547621045793, 61.320749964032856, 45.954398836408345, 65.72393458230155, 16.433323451450892, 1.1622316922460283, 0.37405998951622416, 0.17603069783321448, 0.23617697826453618, 0.28151375693934305, 0.23343257552811078, 0.10876904135303837, 0.11879864388278552, 0.17098686205489294, 0.21117600266422543], [0.08351252267935447, 0.086846341645079, 0.16483235944594654, 0.0093448046328766, 0.18347905815712043, 0.07188266316162688, 0.02318166375958494, 0.04202608418251787, 0.19048362943742955, 0.0838160856759974, 22.33219814300537, 54.752694266183035, 44.289252621786936, 37.70025505338396, 38.13244342803955, 24.26037015233721, 0.38007528388074463, 0.3833791251693453, 0.10079743553485189, 0.08375404721924237, 0.1887343390179532, 0.2156483626791409, 2.448884125266756, 47.911383288247244, 82.38331072671073, 76.21426922934396, 78.20590782165527, 78.11387893131801, 78.6988616670881, 72.9428905759539, 72.48043237413678, 67.62674045562744, 66.04977035522461, 61.05983815874372, 55.20652280535017, 55.94138165882656, 55.68568795067923, 58.238706248147146, 61.011527333940776, 65.46127877916608, 65.52393068586076, 68.86284582955497, 66.91442503247941, 67.8877008983067, 64.04051113128662, 63.84837259565081, 51.94646276746477, 50.849696568080354, 47.96676737921578, 49.18691274097988, 48.46029097693307, 46.41203498840332, 46.77685362952096, 47.81282309123448, 49.601768834250315, 51.25216749736241, 49.88024915967669, 49.32615116664341, 47.49508196966988, 50.918754713875906, 49.8365067754473, 52.26610769544329, 53.210003103528706, 55.20779779979161, 52.23113741193499, 57.15653821400234, 55.359310218266074, 59.19306564331055, 60.66346427372524, 58.3355050768171, 56.079824515751426, 57.02689177649361, 51.79992873328072, 52.88361842291695, 43.65601117270333, 56.87737001691546, 55.36085966655186, 59.09984861101423, 58.42639446258545, 51.269975730351035, 56.38144929068429, 61.39379637581961, 50.92078011376517, 49.716771943228586, 54.82477487836565, 54.391884735652376, 58.495876448495046, 54.71288456235613, 53.78328159877232, 53.18836293901716, 57.86339930125645, 57.087341104234966, 53.53772531236921, 49.792531626565115, 55.59844984327044, 47.12326649257115, 53.79635810852051, 55.28475604738508, 53.77727140699114, 51.474047797066824, 57.321641308920725, 54.08580616542271, 51.029769556862966, 50.53672538484846, 51.05353587014334, 50.77082756587437, 54.38358858653477, 52.03238419124058, 52.4676193509783, 54.37601157597133, 55.587617601667134, 53.39390107563564, 53.685735838753835, 53.53020388739449, 47.95409039088658, 47.102873529706685, 45.887512002672466, 45.96111079624721, 43.573094844818115, 43.687469141823904, 41.70470339911324, 44.83773994445801, 46.5075866154262, 45.68459333692278, 44.84083536693028, 42.01903642926897, 41.379468645368306, 44.18110738481794, 43.78221130371094, 43.88972078050886, 41.92653158732823, 43.97980417524065, 42.9584641456604, 43.776395661490305, 46.56914070674351, 48.645335401807515, 47.542798723493306, 47.32794305256435, 47.02259751728603, 46.70525244304112, 46.78729329790388, 49.40168155942644, 54.572520528520855, 58.84441893441336, 58.082330090659006, 57.64449283054897, 59.73009191240583, 59.21550832475935, 62.97327477591378, 63.067471504211426, 69.90150424412319, 68.90374987465995, 71.42079039982387, 39.57702950068882, 0.11296916633312191, 0.02359921046133552, 0.04624064838779824, 0.14804051763245038, 0.1167185405003173, 0.11720582363860947, 46.10535192489624, 65.77882535117013, 40.72326339994158, 34.03352737426758, 43.19555057798113, 19.006899731499807, 0.4151138551533222, 0.06813511425363165, 0.10945393424481153, 0.11477197280951909, 0.04170727111133082, 0.06989678115184818, 0.10171842468636376, 0.030914367575730597, 0.12598761383976254, 0.0451335370806711, 0.08247766178101301, 0.07951560536665575, 0.16955868154764175, 0.02686127943785063, 0.11744677142373153, 0.07590627404195921, 0.028849022329917977, 0.0638736497078623, 0.10557387423302446, 0.12351808563939162, 31.798514229910715, 58.62132617405483, 49.35602147238595, 31.352714334215435, 46.10360445295061, 26.25107421193804, 0.47290215854133877, 0.5275191249591964, 0.19806518618549618, 0.02385737098354314, 0.5556150344865662, 0.11618530697056226, 3.7195096697126115, 55.723388876233784, 85.7663608278547, 81.82611383710588, 82.40533651624406, 81.46460601261684, 81.65296472821916, 74.83357184273856, 75.38267408098493, 72.20738901410783, 68.90545218331474, 64.05697836194719, 57.52689456939697, 59.984312602451865, 58.481313024248394, 61.956642150878906, 62.00028378622872, 67.6311456135341, 67.2096609388079, 70.5654046194894, 69.89063726152692, 70.93923854827881, 66.84020437513078, 67.23393794468471, 54.34976822989327, 52.65821886062622, 50.98600285393851, 51.34888989584786, 51.57640518460955, 49.962474141802105, 48.781002453395296, 51.28285421643938, 51.59733315876552, 51.79432153701782, 51.790482657296316, 52.699734347207205, 49.37436819076538, 53.834204946245464, 52.15872328622, 54.14396953582764, 56.080606188092915, 57.11326483317784, 56.137880189078196, 61.74752221788679, 59.631899969918386, 59.780813762119834, 62.019898550851, 59.69135570526123, 59.753924233572825, 59.883640153067454, 56.47830717904227, 56.64521680559431, 45.11330202647618, 61.63718482426235, 57.2122870853969, 63.45643860953194, 59.50704084123884, 54.705641065325054, 60.2380816595895, 64.45461681910923, 51.866627965654644, 53.357940673828125, 58.988760811941965, 58.125391551426475, 60.247795241219656, 57.971923215048655, 55.08604451588222, 56.445615904671804, 60.92554337637765, 58.80993502480643, 56.004981994628906, 52.9364664213998, 58.76436873844692, 50.8691063608442, 54.93274988446917, 57.25401101793562, 56.42654309953962, 54.13473537990025, 60.07649435315813, 56.24450377055577, 52.87318222863333, 53.46142366954258, 51.826575074877056, 52.77824551718575, 55.62920604433332, 53.2886323928833, 55.63008499145508, 57.444051197596956, 58.04168660300118, 55.776365416390554, 56.121270520346506, 55.42796189444405, 51.107853412628174, 50.42868437085833, 48.2619754927499, 48.60128034864153, 46.69519492558071, 45.194043568202424, 45.347293036324636, 46.56453057697841, 48.531249455043245, 47.861484800066265, 48.775607177189414, 44.06434290749686, 44.16911826814924, 46.45216083526611, 46.19565418788365, 45.41645540509905, 46.60871417181832, 44.71875899178641, 47.39732428959438, 46.704488141196116, 48.89363622665405, 51.540062631879536, 50.90395852497646, 49.605239459446494, 49.27224356787545, 49.77006810052054, 51.06248862402779, 52.96483939034598, 56.49260309764317, 60.03520815713065, 61.018663133893696, 60.60764939444405, 62.880273137773784, 60.7478848866054, 65.57220676967076, 64.58531938280377, 70.6075245993478, 70.86694254193986, 74.4991203035627, 46.8981066431318, 0.47302141785621643, 0.013754204231580454, 0.19123818751956734, 0.2270901594310999, 0.32108323222824503, 0.09918761120310851, 49.699352809361045, 73.42562362125942, 46.57734305518014, 33.27138989312308, 51.75984804970877, 25.436005353927612, 0.3589844884616988, 0.07944325996296746, 0.1137194089325411, 0.05221718143937843, 0.0788348243970956, 0.034955101287258525, 0.032841905751930814, 0.10943686908909253, 0.06621672612215791, 0.04157116037926503, 0.20739359062697205, 0.175185623179589, 0.4315357596746513, 0.10854815106306757, 0.18151320650109223, 0.15493611618876457, 0.26322370980467114, 0.10077873510973794, 0.28475501015782356, 0.4785490355321339, 39.75871794564383, 67.90259783608573, 55.35363701411656, 52.02835076195853, 56.58760234287807, 31.07863916669573, 0.7052584418228695, 1.9575025268963404, 0.42093736838017193, 0.15559985914400645, 1.9422805437019892, 1.5111992125000273, 4.7128636581557135, 65.48604215894426, 89.23376205989292, 87.12856210981096, 85.7675906590053, 86.29318714141846, 86.88439546312604, 78.53861536298479, 80.31078815460205, 76.2517478125436, 73.24522059304374, 68.60752732413155, 61.869560377938406, 63.09068543570382, 62.29943152836391, 67.58994279588971, 66.53935432434082, 71.68591281345913, 70.13278893062046, 73.71878896440778, 73.13166618347168, 72.86589063916887, 67.86853081839425, 70.4933865410941, 56.51068925857544, 55.23166486195156, 53.152204513549805, 54.654457160404746, 54.06926250457764, 50.87286533628191, 52.41568851470947, 54.89345782143729, 55.92196144376482, 57.1392754146031, 55.69170161655971, 56.88167790004185, 52.759957858494346, 57.392026560647146, 57.48532697132656, 57.81097861698696, 59.15742138453892, 61.65230410439627, 57.8843411718096, 64.85896028791154, 62.99047156742641, 64.50048187800816, 63.17676666804722, 64.63261577061245, 61.69866248539516, 62.42875140053885, 56.65569816316877, 58.41724368504116, 50.10414096287319, 63.023315702165874, 60.75882135118757, 64.53423622676304, 64.4571042742048, 55.70234625680106, 61.75631863730294, 65.68471200125558, 56.81289768218994, 55.34619549342564, 61.86636420658657, 59.51415579659598, 62.50661986214774, 59.23951435089111, 59.30884347643171, 59.306710379464285, 62.88031482696533, 60.16352054050991, 58.65321840558733, 54.60219281060355, 59.141433579581125, 52.2127594266619, 59.76056671142578, 58.950566564287456, 57.1617875780378, 56.40909269877842, 62.76962307521275, 57.559516361781526, 57.19540991101946, 58.465485027858186, 56.75234760556902, 57.15220601218087, 57.96319627761841, 54.798055580684114, 58.66072246006557, 60.57016386304583, 60.560436385018484, 59.502705165318076, 59.09322002955845, 59.04686164855957, 53.163471017565044, 51.90005922317505, 50.45047739573887, 51.00402648108346, 49.93032482692173, 49.34049572263445, 48.10887541089739, 50.050618989127024, 52.36193377631051, 51.165652002607075, 50.92873232705252, 45.36938483374459, 47.01043469565255, 48.492645263671875, 49.16345909663609, 49.23258672441755, 48.59138263974871, 50.01342528206961, 49.11567980902535, 49.40191779817854, 53.67437205995832, 55.05432251521519, 54.817461899348665, 52.43275329044887, 53.08708599635533, 53.7919807434082, 53.19526250021798, 55.97521243776594, 60.90034226008824, 64.07631519862584, 67.31186199188232, 63.20263481140137, 69.24907534463065, 64.54703480856759, 69.92172350202287, 67.90172931126186, 73.97476060049874, 74.49297114780971, 78.49604375021798, 49.95273624147688, 0.5742684506944248, 0.255382450563567, 0.6141515991517476, 0.5507762112787792, 1.1987655375685011, 0.477396014545645, 58.05618749346052, 78.37046200888497, 57.605582918439595, 49.06733076913016, 63.50531223842076, 29.193936824798584, 0.590485437640122, 0.4033364142690386, 0.21603288847420896, 0.2054963388613292, 0.1235156429133245, 0.16151468961366586, 0.2071081173739263, 0.13230225071310997, 0.18634950555860996, 0.13509386591613293], [0.13536328503063746, 0.020958155393600464, 0.20701585018209048, 0.06242224294692278, 0.07671717767204557, 0.03670787259138056, 0.0858162237065179, 0.07960088364779949, 0.0871224579002176, 0.1762851213238069, 34.41892310551235, 39.660922050476074, 24.622112478528702, 36.14668301173619, 43.71425792149135, 19.438066720962524, 0.626496105321816, 0.3700122838573796, 0.14306655739034924, 0.02931084344163537, 0.09847844711371831, 0.11085559760353395, 3.9268569435392107, 49.51291527066912, 75.50446905408586, 77.80936023167202, 76.82514790126255, 76.4306639262608, 72.65913309369768, 75.94459574563163, 71.1875810623169, 67.17758110591343, 63.20412867409842, 61.33630003247942, 57.35796649115426, 56.5542197227478, 56.15980870383126, 58.226366247449604, 59.69542734963553, 63.31772477286202, 61.77976185934884, 65.01380089351109, 65.86535126822335, 67.33037199292863, 64.32585280282157, 64.17322867257255, 56.19533831732613, 49.84218692779541, 50.38227040427071, 48.38391637802124, 47.67350128718785, 47.31064203807286, 46.86870881489345, 48.55374424798148, 47.482008934020996, 47.82481915610177, 49.17866175515311, 48.948596477508545, 47.69231353487287, 50.77270357949393, 49.87786940165928, 51.77348041534424, 53.550572531563894, 53.19712809153965, 57.636787278311594, 56.3461663382394, 57.17848409925188, 58.24506384985787, 58.376047815595356, 55.62249061039516, 55.05634444100516, 58.0083943094526, 59.85829312460763, 49.23189190455845, 46.1634110723223, 57.85647889545986, 53.41056980405535, 57.89493022646223, 53.56852667672293, 54.59879514149257, 59.15163353511265, 58.051584311894004, 47.26030581338065, 53.6510990687779, 54.38042368207659, 55.523826190403526, 56.58741474151611, 57.55010502679007, 52.74283749716622, 54.215296268463135, 54.958208084106445, 55.07571601867676, 55.688828536442344, 52.50447607040405, 53.72260298047747, 54.403641087668284, 48.75842775617327, 54.519901820591514, 57.400652749197825, 52.70111009052822, 54.07296936852591, 52.95240906306675, 44.32142278126308, 47.61250305175781, 49.646779264722554, 50.64517634255545, 54.857594694410054, 54.45561361312866, 52.77430241448538, 55.777025495256694, 53.73007576806204, 55.93963418688093, 53.25467654636928, 49.66538306644985, 47.22964341299874, 47.61016845703125, 47.59870392935616, 48.40172461100987, 45.508487769535606, 42.215385573250906, 41.832862922123496, 42.83815608705793, 43.809288433619905, 45.21362706593105, 43.61717421667916, 42.34256887435913, 43.23291104180472, 43.918819836207796, 41.920938287462505, 43.693104130881174, 43.211118016924175, 42.17963709150042, 43.260255677359446, 44.42481197629656, 51.23271948950631, 49.29376908711025, 47.673390116010395, 47.87826122556414, 45.060040610177175, 47.594239711761475, 46.70274761744908, 50.9403531891959, 58.02814456394741, 56.97976909364973, 56.60056420734951, 58.94493852342878, 57.62197024481637, 60.322140966142925, 59.67457580566406, 63.45905113220215, 69.01234327043805, 75.26983533586774, 71.22535146985734, 60.07811328342983, 3.3239782537732805, 0.13491598117564405, 0.27704582097274916, 0.06969888641365937, 0.0804782769243632, 0.04497407117326345, 36.6095198903765, 69.51623358045305, 47.40739917755127, 31.459650584629603, 29.733916078295024, 24.759259496416362, 0.16092740398432526, 0.06020455301872321, 0.14782196150294372, 0.07445810389305864, 0.16611746405916555, 0.04361789340951613, 0.06689792099807944, 0.06750556267797947, 0.0914939401139106, 0.012994446874862271, 0.08042564974831683, 0.04078962035211069, 0.1149421493921961, 0.026308960414358547, 0.08759374796812024, 0.04016361751460603, 0.12739173349525246, 0.04134588336039867, 0.018251998283501183, 0.3287992610463074, 49.10919713973999, 49.193916525159565, 28.185956444059098, 33.7813390323094, 53.76768289293562, 22.473488024302892, 0.6545106992125511, 0.16084600692348822, 0.17964141336934908, 0.12348052194075924, 0.10949727906180279, 0.04609431552567652, 6.0855949350765774, 56.74645553316389, 79.61731624603271, 81.04023088727678, 79.27878611428397, 80.90432412283761, 74.40553501674107, 76.62025942121232, 73.53200054168701, 70.15833050864083, 64.04462446485246, 64.54845918927873, 59.77533163343157, 59.30208287920271, 57.509642192295615, 62.72436945778983, 62.39886025020054, 65.3898651940482, 64.77420616149902, 68.9469746180943, 66.02209568023682, 68.71383476257324, 66.50611414228166, 65.61853735787528, 58.684742382594514, 52.80967221941267, 52.06149019513811, 51.71197148731777, 49.72111804144723, 48.821229049137656, 49.32261800765991, 51.495451722826274, 50.63268348148891, 51.24592801502773, 52.025665283203125, 52.539043358394075, 50.812488964625764, 52.83141313280378, 50.60562024797712, 54.73869712012154, 57.1082239151001, 56.44617176055908, 60.14341245378767, 59.364137240818565, 60.97247150966099, 62.223175048828125, 60.13981328691755, 59.17031029292515, 60.28747640337263, 61.4013421194894, 60.13182980673653, 52.73469073431832, 50.62219864981515, 60.68888773236956, 58.322338240487234, 61.50992161887032, 56.53309372493199, 59.19253758021763, 59.947542735508506, 58.00925588607788, 49.26568446840559, 57.12730366843087, 57.086792196546284, 57.09794405528477, 57.15766034807478, 57.54851041521345, 53.64138201304844, 55.95528847830636, 54.812077045440674, 56.321604456220356, 56.70095872879028, 55.839257035936626, 55.15720101765224, 56.19449063709804, 51.768752166203086, 55.038154057094026, 57.009399686540874, 53.52960286821638, 55.33143751961844, 53.410333565303254, 46.157063892909456, 51.17471940176827, 52.05836697987148, 53.100676672799246, 55.70138045719692, 57.28156757354736, 54.149389130728586, 57.23390293121338, 55.64831011635916, 56.30046108790806, 57.4734594481332, 53.3273720741272, 49.688332966395784, 51.34091683796474, 51.756499017987935, 51.874389103480745, 47.854984760284424, 45.33689853123256, 44.68016869681222, 45.64348431995937, 48.064038685389924, 46.8485347202846, 45.082705633980886, 42.390164034707205, 45.25728259767805, 45.70780379431588, 44.83625997815813, 46.62508412769863, 45.2396411214556, 44.78020191192627, 45.070914540972026, 46.735991273607524, 53.3722574370248, 52.480845246996196, 50.026282923562185, 49.30733544485909, 48.86190727778843, 49.174868038722444, 49.24865790775844, 53.52944653374808, 60.353268895830425, 60.64625358581543, 60.86789417266846, 62.351966857910156, 62.64372866494315, 63.471842765808105, 63.505346979413716, 65.65657874516079, 69.46511568341936, 75.42372403826032, 73.51574870518276, 67.26457950047084, 4.768622083323343, 0.19050041639379092, 0.3746639671070235, 0.28159632108041216, 0.7986943966576031, 0.12702050698654993, 40.17102057593209, 74.0560336794172, 56.11462804249355, 31.52466835294451, 39.78606258119856, 34.154717854091096, 0.1694547435534852, 0.024161454755812883, 0.13544084158326897, 0.03349180320011718, 0.08867896295019559, 0.07780590068016734, 0.06775643064507417, 0.06844015645661525, 0.04760175231578095, 0.022970756416075995, 0.2529534309038094, 0.1262229840670313, 0.30697331364665714, 0.19507425810609544, 0.25157130935362404, 0.1838647374617202, 0.18518569586532457, 0.10548114563737597, 0.16667090436177595, 0.39164324743407114, 61.254380771092, 55.66816806793213, 34.84559113638741, 50.73804249082293, 62.62195301055908, 27.410485369818552, 0.9537654327494758, 1.3162415538515364, 0.41595819698912756, 0.29202374869159287, 0.3332028718931334, 0.24805850642068045, 8.528301460402352, 63.24709633418492, 85.83279255458287, 87.284090587071, 83.4374566759382, 84.17441041128976, 80.61920479365757, 83.00404889242989, 79.557756287711, 74.75847571236747, 68.13309042794364, 68.57195949554443, 63.04420893532889, 63.53821195874895, 62.065999848502024, 66.10321589878627, 64.43694755009243, 71.08153070722307, 66.7359744480678, 69.71586227416992, 69.07411275591168, 72.11183738708496, 68.56586592538017, 68.94097137451172, 61.807742255074636, 55.54542466572353, 56.70844193867275, 57.18634598595755, 52.97836405890328, 52.298389026096885, 52.88879483086722, 55.777171407427105, 54.44094596590315, 53.38687644686018, 56.76857164927891, 57.807407242911204, 53.93692364011492, 56.18415519169399, 53.93911927086966, 58.111165114811485, 57.80292912891933, 60.132733072553364, 62.79799951825823, 61.66920212336949, 63.77404771532331, 63.161369459969656, 64.57819053104946, 61.21923678261893, 61.67478847503662, 67.20545727866036, 64.12841279166085, 56.502101285117014, 53.725027901785715, 63.66805989401681, 59.09254605429513, 63.111057553972515, 59.94557639530727, 61.09185545785086, 63.07307175227574, 61.45224462236677, 51.24188763754708, 59.07143742697579, 59.33752564021519, 59.233392987932476, 63.00457641056606, 61.688504219055176, 55.79402773720877, 58.30204950060163, 58.03078835351126, 59.637771197727744, 58.670123372759136, 58.12044790812901, 57.448577948978965, 57.121804169246126, 54.270305156707764, 59.02558626447405, 59.33423914228167, 56.71856893811907, 58.518506731305806, 56.24298906326294, 49.987393856048584, 53.45988116945539, 54.805705547332764, 56.613543442317415, 58.49172142573765, 59.7324195589338, 56.69312463487898, 60.69609301430838, 58.03295966557094, 59.36010728563581, 59.13467993055071, 54.79202454430716, 51.09383889607021, 53.903784206935335, 53.882588727133616, 55.632808685302734, 49.85429763793945, 48.46471350533621, 47.643582344055176, 47.873790059770855, 50.63788768223354, 51.021271909986226, 48.76743262154715, 46.06253365107945, 48.20889472961426, 48.90876940318516, 47.50332948139736, 49.561910493033274, 48.39586727959769, 46.12015506199428, 48.08000564575195, 49.90277174540928, 57.41853741237095, 55.824248926980154, 53.32218871797834, 53.7979805128915, 51.66414703641619, 53.221766403743196, 52.576647009168354, 56.94394070761544, 65.06857354300362, 64.80501447405133, 64.45964731488908, 65.30918966020856, 65.22403948647636, 66.99470451899937, 67.56540870666504, 69.43541213444301, 74.73388603755406, 80.68109934670585, 79.5980280467442, 71.31650488717216, 5.228647981371198, 0.25278111015047344, 0.8720319271087646, 0.4553635482277189, 2.008587202855519, 0.13831620157829352, 50.00108528137207, 78.96459552219936, 65.97566086905343, 44.97807618549892, 47.379370144435335, 42.741961751665386, 0.3289612680673599, 0.13097713967519148, 0.3462853527494839, 0.1795698550662824, 0.2440008670091629, 0.1713178785783904, 0.15908495070678846, 0.23125561805708067, 0.16405758102025303, 0.08942503255925008], [0.07567743810692004, 0.05537223356908985, 0.09347383065947465, 0.03228366820673857, 0.07904023051794086, 0.056994471698999405, 0.03463062923401594, 0.10539765190333128, 0.14309611437576158, 1.604404628276825, 37.04974733080183, 29.681630883898052, 44.30136333193098, 42.83576938084194, 47.50607749394008, 19.06094455718994, 0.74155642837286, 0.22782646492123604, 0.23652403535587446, 0.08918231379772935, 0.23454331021223748, 0.03972997596221311, 10.175820963723318, 52.32599769319807, 79.17693247113908, 75.44961997440883, 78.76476533072335, 76.52542345864433, 79.11010469709123, 72.18224348340715, 70.76394939422607, 66.79536764962333, 64.0157755443028, 61.852238518851145, 57.3984432220459, 55.012084415980745, 53.419004917144775, 55.82994992392403, 56.13190821238926, 58.60511602674212, 57.100382872990195, 57.28227628980364, 59.64829077039446, 65.9022878919329, 65.75092138562883, 62.81737804412842, 56.34150757108416, 51.00615610395159, 47.504104205540244, 46.88759401866368, 46.80329499925886, 46.24873147691999, 46.84104108810425, 47.35351242337908, 49.42679582323347, 47.798714773995535, 46.888792582920615, 48.531791414533345, 48.7840006010873, 48.330599376133506, 49.253188133239746, 51.640846252441406, 52.91769586290632, 54.11347736631121, 56.49806090763637, 60.289359365190776, 56.98227391924177, 57.262182099478586, 60.34134578704834, 55.77148083278111, 58.52471147264753, 56.06860664912632, 55.06842735835484, 47.189798968178884, 46.85359648295811, 57.42324481691633, 55.14890834263393, 55.634736810411724, 52.137263774871826, 59.51510769980294, 54.261077948978965, 47.95918689455305, 51.82559190477644, 57.49399137496948, 52.5148914200919, 50.497745990753174, 52.1715600831168, 52.22444977079119, 49.069609778267996, 53.89269140788487, 52.56033958707537, 52.83280277252197, 53.522685936519075, 56.90780660084316, 50.175182819366455, 54.535743713378906, 57.42048290797642, 49.874357087271555, 53.698600428445, 52.28637906483242, 55.383545534951345, 48.8713116645813, 43.11591727393014, 46.36873728888375, 48.20955828257969, 49.42992946079799, 54.46183572496687, 53.52974183218819, 52.4451766695295, 54.399680614471436, 55.63764115742275, 54.383439200265066, 53.776913574763704, 51.570596490587505, 49.29077788761684, 50.31248964582171, 49.98239810126168, 48.879694666181294, 46.68606499263218, 43.8138290813991, 42.79226670946394, 41.634040219443186, 43.2768931388855, 43.60396916525704, 42.0407634462629, 41.10143647875105, 42.25588662283761, 42.980642795562744, 42.506546361105784, 43.71433087757656, 42.56294141496931, 44.35825170789446, 44.137246881212505, 49.18130554471697, 48.161744253976, 48.91773952756609, 49.29110097885132, 46.380549226488384, 46.088179452078684, 47.187554700034006, 46.680999755859375, 52.20245177405221, 55.43670967647007, 55.80875097002302, 54.404936926705496, 57.38333783830915, 59.2698849269322, 57.34029374803816, 59.286748204912456, 64.57486234392438, 67.12286404200962, 72.73798819950649, 70.60396712166923, 71.34067767007011, 13.555482949529376, 0.22380865551531315, 0.7230805712086814, 0.42881600133010317, 0.24883263345275605, 0.19545966599668774, 31.62463903427124, 72.30611596788678, 48.3319091115679, 38.57406398228237, 32.71493993486677, 30.532128606523784, 0.2189368690763201, 0.08791902408535991, 0.06562321154134614, 0.03988436642768128, 0.12101920401411397, 0.05709146149456501, 0.030958211115960563, 0.08228810623820339, 0.056450381608945985, 0.048201282109533033, 0.0476602115003126, 0.046789087887321196, 0.021481506060808897, 0.02272279597153621, 0.051007312789027176, 0.04115661958764706, 0.011271677844758545, 0.11670851175274168, 0.14277714863419533, 3.324088556425912, 50.470606327056885, 38.849959577832905, 48.334097794124055, 43.26710660117013, 60.56409808567592, 22.134669542312622, 0.7422656331743512, 0.27602449006267954, 0.30993150919675827, 0.09889866385076727, 0.30170058086514473, 0.08886813172804457, 11.920882752963475, 61.39721488952637, 83.30662209647042, 79.60027926308769, 80.54369871956962, 80.04634666442871, 81.54086249215263, 75.43828746250698, 71.58742209843227, 70.55252960750035, 67.05058193206787, 65.16369438171387, 59.60743536267962, 57.806910446711946, 55.87747212818691, 58.030010155269075, 57.6396290915353, 60.401461601257324, 58.65395491463797, 59.84410490308489, 63.66576698848179, 67.6108707700457, 66.59896986825126, 65.43131814684186, 59.22240093776158, 52.20483848026821, 49.99282734734671, 50.63734572274344, 49.28489971160889, 49.48631061826433, 48.91292790004185, 50.958988257816856, 50.99078321456909, 49.64049809319632, 50.1915979385376, 53.17208330971854, 51.33941602706909, 51.279640674591064, 52.02835076195853, 54.83947031838553, 55.888193198612754, 58.904652867998394, 59.66746085030692, 61.35125950404576, 59.94028186798096, 60.16610527038574, 62.56308787209647, 59.11417579650879, 61.39392144339425, 58.02375330243792, 56.72363070079258, 49.041764872414724, 52.08696229117257, 59.08026163918631, 56.51298563820975, 58.385386194501606, 55.44474874223982, 62.32874597821917, 55.529332637786865, 50.780763489859446, 55.475376401628765, 60.311412947518484, 54.82141195024763, 53.2250702721732, 53.579456193106516, 56.219952310834614, 51.05340038027082, 56.59905297415597, 54.17062629972185, 54.47662843976702, 54.49367584500994, 58.310547147478374, 51.07892458779471, 56.76456601279122, 61.055071694510325, 52.61629343032837, 53.84199735096523, 53.6947546005249, 57.41913148335048, 52.176760809762136, 46.588824953351704, 48.34242173603603, 52.99875702176775, 51.47178268432617, 55.15041957582746, 55.11373308726719, 54.57328830446516, 56.18461029870169, 56.419042519160676, 53.879757336207796, 54.26337432861328, 54.05202054977417, 50.83370181492397, 52.52001919065203, 51.90265784944807, 50.35427958624703, 48.27048356192452, 45.45840515409197, 45.11683865955898, 45.12017379488264, 46.31540291649954, 47.48635155814034, 45.25830398287092, 44.158306871141704, 44.36020762579781, 44.139237540108816, 45.16875907352993, 45.78447716576712, 45.691551957811626, 46.56988416399275, 46.277055808476035, 51.745743206569124, 51.22979429789952, 52.94352579116821, 51.52290405545916, 48.70951591219221, 49.21420873914446, 48.64199331828526, 49.59637703214373, 55.461358410971506, 58.9087245123727, 58.28986930847168, 59.48232609885079, 61.141243253435405, 61.575415338788716, 61.16693769182478, 61.61391530718122, 66.17114843641008, 69.48899664197648, 72.8887780053275, 71.41432857513428, 75.91389165605817, 18.57655610357012, 0.2822173706122807, 0.8602240607142448, 0.6801546003137315, 0.5649637271250997, 0.3130752705037594, 37.01729229518345, 75.36531748090471, 58.06601572036743, 39.47296633039202, 44.32129076548985, 40.45579596928188, 0.22142406632857664, 0.05408634864059942, 0.08600731952381985, 0.06134192020233188, 0.033993057374443324, 0.10843009954052311, 0.013727984790291105, 0.08082848920353822, 0.11307503136673144, 0.08474150566118104, 0.12592828273773193, 0.10691425909421273, 0.13351492849843843, 0.11293312255293131, 0.2215012021894966, 0.11779711262456008, 0.1602734455040523, 0.15460001065262727, 0.34501429381115095, 3.6731530257633755, 70.4551783970424, 43.786032812935964, 57.827001162937705, 56.18026420048305, 68.11030033656529, 24.53795416014535, 1.0975830469812666, 0.8419164259518895, 0.4093999931854861, 0.282136896359069, 0.5721276455691883, 0.22011954204312392, 15.114703008106776, 68.80443232400077, 90.95332309177944, 87.68074240003313, 85.80028193337577, 84.89473710741315, 86.1471985408238, 81.87698854718889, 76.60238865443638, 73.92107881818498, 72.06959233965192, 69.98960740225655, 62.032495634896414, 60.08134419577462, 58.59851523808071, 63.595909799848286, 62.081459590366904, 63.73201806204659, 62.52948638371059, 62.40693405696324, 66.72718497685024, 71.75585338047573, 71.8294209071568, 68.96957015991211, 62.51353331974575, 56.0069830758231, 52.428997789110454, 53.57753849029541, 52.394684110369, 52.50464282717024, 52.927166257585796, 54.19227688653128, 54.899909223829, 54.182532038007466, 52.77184622628348, 56.01511941637312, 54.870601722172324, 53.82210465839931, 53.7061322757176, 58.110866342272075, 57.86343404224941, 61.65292249407087, 63.465408733912874, 67.01642458779472, 61.92034476143973, 64.278486933027, 63.09412479400635, 63.582881927490234, 64.23037065778459, 60.33629444667271, 59.29157025473458, 55.362211091177805, 56.331370149339946, 61.567841802324565, 60.191292490277974, 61.593473706926616, 59.38813631875174, 64.72297014508928, 57.980823857443674, 53.238598414829795, 57.90845142092024, 62.85896301269531, 57.0726317678179, 55.05095611299787, 54.63273361751011, 56.71767609460013, 53.190304960523335, 57.88745396477835, 54.8816945212228, 57.46811975751604, 56.27547189167568, 61.01353536333357, 52.650238854544504, 59.43598856244768, 62.375840868268696, 53.00635487692696, 56.30807978766305, 54.40674693243844, 58.80622468675886, 53.95127861840384, 50.89546087809971, 53.04181500843593, 53.67476463317871, 55.25250250952584, 59.579211780003135, 57.99180548531668, 57.27913917813982, 59.019666399274556, 58.75433553968157, 57.42410291944231, 59.49433953421456, 56.83719553266253, 53.44426509312221, 54.775522572653635, 54.966962814331055, 54.36069427217756, 51.470688343048096, 47.34082848685128, 47.31274734224592, 47.91601078850882, 49.269325324467246, 50.887411390032085, 47.7783739226205, 47.08414118630545, 48.50749356406075, 46.16567618506295, 48.93311936514718, 48.76545238494873, 48.29435409818377, 49.72875411169869, 49.777165685381206, 56.61960921968733, 54.71050827843802, 55.728575706481934, 56.15273196356637, 52.204199245997835, 52.982473918369834, 52.47351142338344, 54.199930327279226, 57.98768867765154, 61.490793228149414, 62.73818942478725, 63.43626798902239, 65.13266372680664, 67.96054581233433, 65.34954479762486, 66.70364448002407, 70.64343983786446, 74.03232642582485, 76.54291207449776, 76.12914684840611, 79.0159774507795, 19.357050725391932, 0.3259409729923521, 1.5359353423118591, 1.3157325983047485, 1.9839143667902266, 0.41633863800338333, 44.084312030247276, 82.18977560315813, 67.1583971296038, 51.00624295643398, 52.066920212336946, 47.49228184563773, 0.2770128441708428, 0.20062977714197977, 0.16042648229215825, 0.25695689607943806, 0.2748506787632193, 0.20287595875561237, 0.10201953138623919, 0.166910142238651, 0.19245158455201558, 0.18583041269864353], [0.0706968010802354, 0.05367932262431298, 0.059620721132627556, 0.01730641902291349, 0.058062261901795864, 0.13136819297713892, 0.069199552493436, 0.10453282509531293, 0.3368156908878258, 3.7748915893690924, 35.35187857491629, 21.50739312171936, 28.00944788115365, 35.49797487258911, 55.55112566266741, 25.31829939569746, 0.7131806910037994, 0.06893664052976028, 0.35529002813356264, 0.14156075247696467, 0.020572545638840114, 0.17917025222309999, 12.683114034788948, 56.341094153267996, 71.31519167763847, 76.45166833060128, 75.23607403891427, 77.31972067696708, 83.89190360477993, 73.66516971588135, 76.50443989889962, 68.99423626491001, 65.30303355625698, 64.92680249895368, 61.38738318852016, 59.33361380440848, 54.02338007518223, 54.92086846487862, 54.86296565192086, 54.29212597438267, 52.447469575064524, 52.132142952510286, 52.75919355664934, 60.14644186837332, 60.29476506369454, 59.767035484313965, 54.48757185254778, 49.96660484586443, 46.17653621946062, 48.144533566066194, 46.452452659606934, 45.09501436778477, 44.99314335414341, 46.26859985079084, 47.6198924609593, 48.29049784796578, 47.87212596620832, 49.97601270675659, 49.526769978659495, 52.57725497654506, 53.21844169071743, 52.0483580998012, 52.105712005070274, 53.983629431043354, 56.08152682440621, 56.99604524884905, 57.818795340401785, 60.11089488438198, 55.43722036906651, 56.27590267998831, 55.82603461401803, 57.27970198222569, 53.951018060956685, 49.04518338612148, 49.68130486352103, 54.145168100084575, 52.910219601222444, 54.488457747868125, 56.095131397247314, 59.28420516422817, 50.749513966696604, 49.43315689904349, 56.32345962524414, 51.0268999508449, 51.77178852898734, 56.44378852844238, 54.29806668417794, 54.748483657836914, 55.003586769104004, 56.21316739491054, 57.61359766551426, 52.39509752818516, 52.340168544224326, 53.76457357406616, 55.64803566251482, 52.70460156032017, 55.492114612034385, 56.06213787623814, 50.51723221370152, 53.401297433035715, 53.19164596285139, 55.00747428621565, 48.279853207724436, 48.25185544150216, 51.669316496167866, 50.8113112449646, 50.02585908344814, 57.04868132727486, 55.304541042872835, 54.92548554284232, 54.271052088056294, 52.44019133704049, 54.002966267721995, 52.858101163591655, 50.125079359327046, 50.04389313289097, 51.03126689365932, 50.54557391575405, 49.31373820986067, 43.11085203715733, 40.83897522517613, 40.75051770891462, 41.24146352495466, 41.93418155397688, 41.05161789485386, 42.60986607415335, 43.3290046283177, 41.70986591066633, 43.23201125008719, 43.165395396096365, 41.977989946092876, 42.035649572099956, 44.94794879640852, 50.903128215244834, 50.1427138873509, 48.7431069782802, 46.2709379196167, 46.24186665671212, 44.966510908944265, 45.671186787741526, 48.310380118233816, 52.445659569331575, 54.58483968462263, 57.21834591456822, 55.98094470160348, 54.515917028699604, 56.42203024455479, 57.337048939296174, 59.847787448338096, 62.794504574366975, 64.6553989137922, 71.80820110866001, 70.28581605638776, 72.46230452401298, 39.389039039611816, 0.1297397089323827, 0.257615509309939, 0.6947497257164547, 0.10363277553447656, 0.21666991072041647, 27.214766774858745, 73.02992371150425, 51.59435238157, 37.026366642543245, 26.35515648978097, 35.77843543461391, 1.3692773708275385, 0.005247468378261796, 0.0472846932576171, 0.039014847550008974, 0.09265703734542642, 0.05730171914079359, 0.06807753377194915, 0.102607407341046, 0.01309340272564441, 0.032384586720062156, 0.04692700012986149, 0.06309268304279872, 0.09281135656471763, 0.05639475191544209, 0.04942497930356434, 0.0542210548051766, 0.11818722954818181, 0.11318373267671891, 0.3452024651425225, 11.323089276041303, 51.131425176348, 34.23762028557913, 35.30295630863735, 39.8149288722447, 64.96515655517578, 28.260559252330236, 0.8493440502456256, 0.41039795534951345, 0.417136052357299, 0.03649375068822077, 0.020961161303733076, 0.2155059924615281, 15.726903574807302, 60.38991369519915, 74.66476535797119, 81.98100308009556, 78.60459545680455, 80.85674980708531, 83.84461416516984, 76.39595767429897, 77.44681017739433, 72.97784001486642, 69.52401556287492, 67.6982513155256, 64.22807775224958, 61.589346476963584, 54.55632080350603, 57.50416701180594, 57.318066460745676, 56.09981448309762, 53.87453229086739, 53.26800319126674, 55.8814742905753, 63.11203030177525, 63.75784451620919, 61.75401183537075, 58.09696299689156, 52.89335284914289, 50.30759463991438, 50.337263447897776, 49.26170662471226, 48.93815333502633, 49.678018365587505, 49.58304343904768, 49.025884764535085, 50.242764472961426, 48.999901975904194, 51.12186445508684, 52.210039206913535, 54.57577575956072, 55.38313559123448, 55.87060035978045, 55.624189444950645, 57.38688836778913, 59.924509457179475, 60.1222482408796, 60.16160978589739, 62.521308353969026, 58.302077293395996, 59.2167728969029, 57.98682015282767, 61.38372148786272, 55.700237478528706, 51.242502553122385, 54.78780003956386, 55.6456732749939, 55.51252147129604, 57.205661978040425, 56.69705384118216, 60.79104709625244, 52.67811502729143, 54.90544693810599, 58.81122044154576, 53.61752189908709, 56.44786017281668, 58.68307481493269, 56.0943740436009, 57.36451516832624, 57.27165944235665, 55.14640351704189, 58.1487374986921, 54.32558502469744, 54.092337472098215, 54.823826449257986, 55.30596194948469, 53.48176104681832, 56.35017892292568, 57.406475339617046, 53.634447710854666, 55.605008942740305, 55.07270744868687, 58.741794041224885, 49.832320485796245, 50.63132510866438, 53.623195103236604, 52.56369209289551, 52.430773053850444, 57.48297848020281, 57.39788041796003, 56.33700166429792, 54.24119220461164, 55.761899266924175, 56.760661125183105, 53.80484185900007, 52.72372300284249, 51.5274064881461, 53.415582929338726, 52.80654900414603, 50.85783985682896, 44.91404506138393, 44.321322032383506, 43.60722092219761, 45.36993374143328, 43.84822266442435, 43.64483152117048, 44.01469802856445, 44.877577441079275, 45.25010858263288, 45.81104360307966, 44.92216055733817, 46.04558004651751, 45.12570456096104, 48.162268842969624, 51.79888302939278, 53.01148612158639, 50.29418461663382, 49.839643887111116, 49.49445390701294, 49.086973326546804, 46.72242144175938, 51.66659280232021, 55.28293909345354, 57.83704130990164, 60.46544061388288, 59.16977528163365, 56.42216920852661, 59.70792021070208, 61.23541913713728, 63.08646093096052, 65.1672727039882, 67.89068862370083, 72.1584528514317, 73.10240037100655, 74.73138468606132, 48.43279348100935, 0.031706116162240505, 0.1713528095611504, 1.168699488043785, 0.6921626073973519, 0.2705892345735005, 30.412928785596574, 77.44870703560966, 63.52383613586426, 36.772885935647146, 34.97160366603306, 52.00204488209316, 3.219876216990607, 0.4448974441204752, 0.06674111834061996, 0.08688049909791776, 0.07995198480784893, 0.24340687745383807, 0.01822435137416635, 0.06126773596874305, 0.1340186321841819, 0.0995500778247203, 0.08137751224317721, 0.25444229958312853, 0.23215728253126144, 0.21923937355833395, 0.1531899334596736, 0.20563868193754128, 0.1901124572115285, 0.19892550073564053, 0.4739774465560913, 14.211584840502058, 71.69125597817558, 34.75010551725115, 39.310034547533306, 48.807148524693076, 75.75862721034459, 33.811914580208914, 1.1424579875809806, 1.501795585666384, 0.44795484149030274, 0.5280082672834396, 0.1336799617856741, 0.45552813368184225, 19.688413790294103, 68.69519969395229, 84.63912677764893, 91.19981738499233, 84.31636210850307, 85.96093818119594, 89.89570304325649, 81.26058605739048, 85.56940024239677, 80.09345545087541, 72.70019694737026, 73.07259259905133, 66.6797913142613, 66.04948547908238, 58.43500328063965, 60.61897495814732, 61.707042012895855, 60.324301855904714, 57.91672325134277, 56.749641282217844, 58.29419803619385, 66.97288022722516, 64.7374085017613, 64.74177891867501, 61.29654938834054, 56.93177093778338, 52.21923862184797, 54.303055490766255, 52.714099747794016, 49.61150326047625, 50.483192988804404, 53.124411719185964, 52.69023963383266, 54.848291056496755, 51.759910583496094, 55.2749035017831, 56.20902974264962, 58.93671185629708, 59.03697436196463, 58.756843839372905, 57.98529502323696, 61.80467809949602, 62.06503404889788, 62.949706486293245, 63.3157445362636, 64.53290217263358, 61.25684043339321, 62.66847814832415, 61.239233698163716, 64.41335841587612, 57.08420051847185, 58.21010051454817, 60.19114657810756, 59.007520948137554, 58.16271032605852, 60.90799222673689, 60.54755442483084, 64.66965661730084, 56.90596185411726, 56.27484655380249, 62.11173289162772, 57.04783364704677, 56.295319420950754, 62.259250095912385, 59.7549386705671, 61.82500852857317, 60.20286124093192, 60.419624192374094, 61.99975572313581, 55.43003593172346, 53.597900186266216, 57.46560798372541, 59.61030496869768, 57.800181116376606, 59.12588351113455, 60.95261355808803, 54.53593478884016, 57.7811986378261, 60.06849697657994, 59.04726464407784, 51.999098845890586, 55.17342506136213, 55.67888566425869, 54.08145659310477, 56.82044342585972, 59.19672734396798, 57.68821784428188, 59.340429987226216, 57.82828310557774, 57.67430407660348, 58.254148619515554, 58.47423280988421, 55.430605684007915, 56.6478328023638, 55.23830386570522, 55.57169233049665, 54.23067610604422, 47.85284471511841, 45.32190431867327, 45.96239621298653, 47.917310101645334, 48.03632232121059, 46.64590787887573, 47.84301996231079, 47.98480142865862, 47.43993411745344, 47.297478675842285, 50.09984350204468, 47.98313733509609, 47.42291450500488, 51.10438278743199, 56.577965191432405, 55.96404320853097, 53.95777170998709, 52.812635626111714, 53.50590256282261, 51.433487687792095, 50.14573287963867, 55.621226038251606, 57.12186322893415, 63.19932052067348, 64.4759338923863, 64.25989355359758, 60.977328300476074, 66.62423351832798, 64.52669048309326, 69.85142162867955, 68.84041704450334, 73.3468518938337, 77.79881981440953, 76.9589215687343, 78.39309923989433, 49.858706269945415, 0.2978342611874853, 0.5774839467235974, 3.05063134431839, 1.1818360345704215, 0.24520608090928622, 37.31594671521868, 85.45952837807792, 69.86192730494908, 52.767736366816926, 39.72342804500035, 59.91490009852818, 1.8248334058693476, 0.5819570124149323, 0.13294452482036181, 0.2364897286253316, 0.22177462466061115, 0.28181757777929306, 0.2182115422827857, 0.19241556791322573, 0.1515535241258996, 0.1825919279030391], [0.03199414749230657, 0.049654327532542605, 0.0701164093666843, 0.019778924295678735, 0.17165397054382733, 0.09060666058212519, 0.05728808058691876, 0.1426300151007516, 0.5303579526288169, 13.675472259521484, 34.97928837367466, 16.245310408728464, 30.292196886880056, 36.212642260960166, 57.17311314174107, 30.994083063943044, 0.6098591866237777, 0.793805904686451, 0.5454912920083318, 0.05336015671491623, 0.13777459492640837, 0.35652683462415424, 18.126391002110072, 51.32598515919277, 65.90329538072858, 70.79133224487305, 75.44660445622036, 79.76704992566789, 74.6649112701416, 74.395904813494, 72.44612216949463, 72.12243338993618, 67.87800121307373, 67.39866583687919, 67.69262327466691, 66.36218915666852, 59.80027566637312, 56.920803206307546, 52.32014036178589, 54.068265438079834, 49.93529626301357, 51.18149389539446, 52.84509066173008, 58.26982028143746, 57.74603727885655, 58.139301845005576, 53.38768938609532, 51.4929712159293, 46.64529991149902, 47.59494842801775, 43.78816590990339, 46.93059294564383, 45.64516230991909, 46.781706946236746, 46.26464285169329, 48.8758418900626, 46.75511966432844, 48.126812185559956, 48.46859754834856, 50.25488560540335, 50.1614670753479, 55.411251476832796, 54.673366682870046, 56.05339356831142, 55.81262806483677, 57.687595980507986, 57.838288511548726, 54.31530169078282, 56.11816120147705, 54.75309378760201, 54.6040028163365, 55.31688799176897, 53.45741803305489, 46.56141430991036, 45.60527270180838, 47.80778564725603, 52.14073440006801, 54.845435346875874, 57.07247543334961, 53.867340905325754, 48.01097181865147, 55.35896280833653, 50.70703962871006, 56.848194531032014, 55.942861625126426, 53.78442110334124, 55.42918130329677, 49.947417395455496, 54.51646246228899, 51.29733426230294, 53.602479049137656, 55.52013669695173, 55.56911107472011, 55.24803829193115, 52.9231675692967, 51.38835913794381, 54.30307633536202, 54.12812416894095, 55.63009193965367, 53.03092023304531, 52.616734640938894, 57.41409056527274, 45.72536884035383, 46.21968105861119, 48.181588309151785, 52.429709979466026, 52.35447835922241, 48.39629111971174, 54.93450777871268, 50.80205971854073, 55.43627888815743, 52.88017559051514, 51.556526388440815, 50.657373905181885, 49.526255811963765, 51.753608567374094, 51.567254407065256, 51.16744463784354, 47.474435397556846, 44.17704268864223, 42.74704783303397, 41.0245338167463, 40.64848688670567, 40.803275380815776, 41.56618758610317, 41.97782318932669, 40.837971210479736, 44.49680226189749, 42.01359946387154, 42.3850953238351, 41.75785364423479, 45.10189308438982, 49.0149587222508, 48.29706736973354, 49.39146770749773, 47.66290181023734, 47.955247265951975, 44.56819500241961, 45.023861340114046, 43.792842047555105, 49.11723967960903, 53.34640319006783, 54.079559734889436, 54.701836926596506, 55.73850120816912, 55.84802566255842, 57.41890914099557, 57.791165828704834, 61.71174594334194, 60.391970361982075, 65.38990688323975, 65.44945294516427, 72.84267670767647, 67.14441735403878, 68.47113418579102, 4.107303397996085, 0.016640477614211183, 0.2860358128590243, 0.20380692237189837, 0.16465785380985054, 24.099345649991715, 71.92873845781598, 52.89799771990095, 42.34338181359427, 22.62045805794852, 37.64697626658848, 6.028869407517569, 0.3272699516798769, 0.0556529468989798, 0.12374103867581912, 0.05106903572699853, 0.059323000322495184, 0.09072624559381179, 0.10673657112887927, 0.012098326031783862, 0.023444528225809336, 0.045754539115088325, 0.07893670643014566, 0.0374838927361582, 0.04734166305778282, 0.13218588195741177, 0.10875751982842173, 0.10176740812936, 0.08203607119087662, 0.7031926555292947, 20.555767842701503, 49.36851780755179, 20.429050070898874, 25.314012357166835, 40.17087466376168, 67.2198817389352, 35.04236759458269, 0.47307477785008295, 1.814778059720993, 0.6333027886492866, 0.2362419819193227, 0.18300675707204, 0.5913891920021602, 20.10937213897705, 61.188741139003206, 74.07427270071847, 76.3187562397548, 77.3486738204956, 83.99102660587856, 76.7366417476109, 78.5721126283918, 74.67282526833671, 75.42769840785435, 71.65255451202393, 71.42984390258789, 68.26593998500279, 69.96593488965715, 62.38340745653425, 59.35251290457589, 54.87404455457415, 58.27381896972656, 53.38599749973842, 54.065058844430105, 53.35978889465332, 60.85423401423863, 59.88370268685477, 62.41516767229353, 56.6046393258231, 53.39364051818848, 49.11221265792847, 49.60278327124459, 44.8997734614781, 48.98231608527047, 48.4780227797372, 49.30598749433245, 49.783029964991975, 51.29351275307791, 48.215158530644004, 50.44040250778198, 51.31287043435233, 52.56731557846069, 51.639790126255576, 57.987699099949424, 59.07990033285958, 59.97726712908064, 56.42298214776175, 60.49522059304373, 61.19641889844622, 58.83892985752651, 60.33930996486119, 59.1507511138916, 57.95712007795061, 57.614473138536724, 55.357854570661274, 52.84681728907994, 50.43137679781233, 52.42724336896624, 57.5725998197283, 58.23409611838204, 57.47296265193394, 54.59740202767508, 50.96640198571341, 58.397844314575195, 53.698110580444336, 58.8101087297712, 56.09028502873012, 57.502690519605366, 56.50440113885062, 53.63426010949271, 54.577881063733784, 55.16859606334141, 54.1243964603969, 56.10279873439244, 55.9401205607823, 54.60614633560181, 56.879023688180105, 52.57680681773594, 55.386453356061665, 55.831846782139365, 56.06038345609392, 54.66941315787179, 55.028641973223, 57.15954678399222, 48.799929346357075, 48.97249480656215, 50.21416221346174, 54.15512834276472, 55.759585516793386, 50.96932370322091, 55.585672106061665, 53.43952989578247, 57.161996023995535, 54.26885298320225, 51.47809164864676, 52.47558546066284, 51.66855219432286, 55.78419951030186, 54.240935121263774, 52.92720447267805, 50.23157787322998, 46.32551254544939, 44.246340547289165, 44.44591018131801, 43.51981953212193, 42.96328966958182, 44.081053325108115, 42.780506883348735, 43.645863328661235, 46.21309764044625, 43.6371294430324, 42.26198019300188, 45.8658127784729, 47.55132416316441, 50.997088704790386, 51.71777670724051, 53.14082683835711, 49.78218575886318, 50.227652141026084, 45.951491015298025, 47.5605583190918, 45.68485736846924, 52.598221165793284, 55.84202241897583, 57.39725160598755, 57.45271560123989, 59.66382694244385, 58.441944531032014, 62.662224769592285, 60.370771408081055, 65.84962054661342, 63.239265714372905, 69.26668902805874, 66.54362746647426, 77.11237948281425, 68.25423227037702, 75.70529283796037, 5.477799092020307, 0.06370263852711235, 0.9217854802097593, 0.45148593772734913, 0.2882066363734858, 28.60586735180446, 77.66450418744768, 62.27787821633475, 47.21458319255284, 23.601785148893082, 46.328997067042756, 9.984419805662972, 0.8421199864574841, 0.16680804985974515, 0.09736714246017592, 0.04694054029615862, 0.10876668005117349, 0.0037559635903952377, 0.08972991869917937, 0.03358655043744615, 0.03429263737052679, 0.13603493970419678, 0.31209953714694294, 0.14030589695487702, 0.18104800289230688, 0.23912078887224197, 0.27780257750834736, 0.20820097944566182, 0.22346762381494045, 0.8249223807028362, 27.44913646153041, 68.05647959027971, 24.15885349682399, 41.82564026968819, 51.30503634044102, 75.59703295571464, 40.28884812763759, 0.8978188633918762, 3.895993913922991, 1.0396943475518907, 0.3828015833028725, 0.3767434326665742, 1.0117883192641395, 22.58036868912833, 72.69884204864502, 82.9239639554705, 85.96684414999825, 82.3545173917498, 87.88229574475969, 80.20000607626778, 86.3068264552525, 79.91325392041887, 80.81922953469413, 77.41412585122245, 75.25205489567348, 73.30963039398193, 72.36637769426618, 66.42502866472516, 64.23041234697614, 58.15534176145281, 61.124873297555105, 55.52871077401297, 55.98042011260986, 59.01708861759731, 64.36367184775216, 61.780428886413574, 65.96509960719517, 59.56036826542446, 58.18786975315639, 53.88020896911621, 51.741723673684255, 48.81937735421317, 53.27230412619454, 50.88374274117606, 52.93059171949114, 53.88063628332955, 54.81623901639666, 50.634385790143696, 54.027774810791016, 53.751017638615195, 54.77273634501866, 53.17306647981916, 62.43822874341692, 60.37248761313302, 63.42161423819405, 59.060876165117534, 63.948690686907085, 61.15436840057373, 61.66394928523472, 61.63710144587925, 62.55188042776925, 59.84213856288365, 61.894282068525044, 58.7061984198434, 57.5936632837568, 54.05118676594326, 53.30736821038382, 59.12604331970215, 61.397555351257324, 59.75247206006731, 57.93586206436157, 54.89407273701259, 61.367664200919016, 55.80178887503487, 59.41556780678885, 58.06627280371529, 57.808049951280864, 58.492735862731934, 54.503132343292236, 57.652024677821565, 58.8504638671875, 57.29794447762625, 59.096291133335654, 60.2086421421596, 57.17345012937273, 58.13953808375767, 56.51029321125576, 58.038629395621165, 57.52236434391567, 58.24629020690918, 55.87225750514439, 54.976669447762625, 60.05195331573486, 50.48470074789864, 52.24854612350464, 52.009003502982004, 55.65928827013288, 56.164127009255544, 54.827693121773855, 57.88574470792498, 57.07244416645595, 57.60639933177403, 60.363079752240864, 54.445736748831614, 54.3304557119097, 52.34277759279524, 57.46707057952881, 56.472877161843435, 57.922761235918315, 53.99646970203945, 50.13728734425136, 48.49440663201468, 47.38483490262713, 46.30145788192749, 47.499869278499055, 47.33899416242327, 47.13384165082659, 45.58709274019514, 49.72703095844814, 46.300339221954346, 47.33410610471453, 47.645812715802876, 51.28109632219587, 54.07451186861311, 53.687594481876914, 55.65269095557076, 52.76139613560268, 54.218356949942454, 49.887416226523264, 51.653888021196636, 48.901313986097065, 55.94906289236886, 59.04643086024693, 60.96297332218715, 60.91000720432827, 64.94321414402553, 61.652623721531455, 66.8895435333252, 64.3636371067592, 72.59200654711042, 67.05451461247036, 74.73150280543736, 69.184248651777, 81.50872012547084, 71.53808988843645, 78.79121712275914, 5.548888717378889, 0.1845782713166305, 3.1680179025445665, 0.9808850118092128, 0.32309723272919655, 34.68310751233782, 87.2045476096017, 66.79248414720807, 64.0572076525007, 29.92887905665806, 62.534607206072124, 11.011983684131078, 1.111361216221537, 0.28959630323307856, 0.3540658695357186, 0.15493736469319888, 0.37405803533537046, 0.2009386055703674, 0.18567779660224915, 0.13012359690453323, 0.11273880369429078], [0.03856747244883861, 0.13531877313341412, 0.08095253219029733, 0.1004084585500615, 0.09320629787232194, 0.14623992996556417, 0.10392552946827241, 0.08976200662021126, 0.6208466227565492, 16.30960382734026, 25.22117226464408, 27.757059778485978, 57.344261169433594, 40.33919824872698, 60.574603761945454, 39.78047970363072, 0.2996245894048895, 0.4347643921417849, 0.3905943137194429, 0.03927352884784341, 0.0778040075674653, 0.1845270147813218, 19.080086844308035, 43.643650327410015, 61.284355299813406, 63.86447851998465, 74.42838764190674, 69.2966079711914, 74.74779633113316, 77.2330766405378, 70.62021895817348, 73.50291538238525, 69.6405576978411, 69.47826167515346, 65.73654556274414, 68.74882589067731, 65.23567771911621, 64.76286670139858, 53.19429670061384, 53.80152409417288, 51.56894281932286, 52.61270121165684, 51.07023933955601, 54.09764589582171, 53.40193666730608, 55.44317150115967, 51.33112335205078, 46.53379174641201, 48.39719785962786, 44.995787143707275, 43.62247221810477, 44.15872376305716, 47.6580867086138, 46.19944790431431, 46.47115026201521, 46.88254267828805, 47.436063970838276, 47.299090657915386, 52.33832727159773, 51.963829789842876, 53.2605790410723, 55.068277972085134, 55.82074703489031, 55.059832436697825, 63.76878098079136, 58.74963160923549, 56.296347754342214, 56.14690242494856, 54.80957916804722, 56.28991024834769, 55.242611748831614, 55.84441259929112, 58.876054082598, 46.93489735467093, 47.41649089540754, 56.51030363355364, 54.03120027269636, 53.57349116461617, 55.368940421513145, 51.12594304765974, 53.9770564351763, 51.79322024754116, 54.451559339250835, 55.72626543045044, 57.88131523132324, 56.375789982931956, 50.98127113069807, 52.554378032684326, 51.12948662894112, 51.947921889168875, 52.70723492758614, 49.73149517604283, 52.462210178375244, 52.90159341267177, 53.78139863695417, 49.85146624701363, 52.480879987989155, 57.09026629584176, 51.19792638506208, 51.71252039500645, 52.11677353722708, 47.84959295817784, 42.26290430341448, 44.54387978145054, 50.88720294407436, 53.82957744598389, 53.19079828262329, 55.05201571328299, 48.78213153566633, 55.90663719177246, 59.81938321249825, 48.35230902263096, 49.50352130617414, 55.17545393535069, 53.31701578412737, 53.752355166843955, 50.82857404436384, 47.982432092939106, 44.77932643890381, 41.101297514779226, 40.78718682697841, 40.40386513301304, 40.639944076538086, 40.461417061941965, 40.675074168613975, 40.459565367017476, 40.962086881910054, 39.99714190619332, 41.479797158922466, 41.997497013636995, 44.46494129725865, 44.797989300319124, 48.26060322352818, 48.724200929914204, 49.847995621817454, 48.048346178872244, 46.53421211242676, 45.75174420220511, 44.142145361219136, 46.38021918705532, 51.922265665871755, 54.04260574068342, 55.91057334627424, 54.28229774747576, 56.88780621119908, 57.30049099240984, 58.280013288770405, 58.88724763052804, 62.119285583496094, 60.27319785526821, 65.80371379852295, 64.01369803292411, 75.99822889055524, 67.05660602024624, 81.5870749609811, 18.453067507062638, 0.20261333856199468, 0.1633543066148247, 0.11741326536451067, 0.20352991723588534, 22.195179666791642, 68.4077457700457, 55.726783071245464, 40.98997695105416, 32.980114459991455, 24.863769088472637, 8.523537601743426, 0.30270492125834736, 0.11452662811747619, 0.08555219216006142, 0.00906542207979198, 0.13061291564788136, 0.056888342036732605, 0.12357937092227594, 0.07246538903564215, 0.04550959136603134, 0.026605546374672225, 0.2956089377403259, 0.03901721902989915, 0.03158023434558085, 0.004803233197890222, 0.1025363172271422, 0.11284052287893635, 0.027795335477484123, 1.8478812319891793, 30.814694472721644, 37.97844702856881, 31.66893380028861, 51.61461680276053, 46.51344742093767, 67.6602863584246, 45.38679354531424, 0.27833346330693787, 1.0606876782008579, 0.47887733791555676, 0.3290185092815331, 0.11900319504950728, 0.4671272827046258, 21.52078751155308, 54.72552333559309, 72.3736663545881, 73.81906536647251, 78.4522978918893, 75.51147978646415, 77.49722630637032, 79.8624347959246, 73.74347591400146, 78.19602748325893, 73.35706574576241, 73.23462459019252, 70.47558525630406, 71.97205352783203, 68.74141911097935, 67.59463282993862, 57.036077295030864, 56.61648947851998, 54.699502331869944, 54.476555483681814, 52.67606183460781, 54.73032454081944, 58.087763581957134, 58.27920729773385, 54.446164063044954, 50.64924103873116, 49.095429284232004, 49.13504096439907, 46.53582756859915, 44.94968237195696, 47.996672425951274, 49.78271034785679, 50.521870136260986, 49.07993132727486, 50.31588384083339, 50.21853263037545, 52.45246532985142, 54.69098384039742, 54.40310607637678, 57.57957928521292, 57.875718457358225, 60.656995500837056, 64.9971113204956, 57.927527700151714, 58.01997348240444, 59.91515718187605, 58.477679116385325, 58.73434557233538, 58.0616591998509, 59.20772634233747, 61.48274026598249, 53.71359464100429, 52.38424791608538, 59.630656242370605, 57.478694915771484, 58.55137865883963, 57.71955074582781, 53.27326992579869, 57.11934798104422, 55.383837359292166, 57.39748437064034, 58.77582631792341, 59.91032818385533, 57.687929494040354, 52.056991236550466, 54.968599115099224, 52.34889548165457, 51.48598827634539, 52.848915645054404, 50.23890822274344, 53.8950503213065, 54.566517284938264, 54.80429853711809, 53.93301180430821, 53.40964221954346, 58.13466739654541, 51.49836301803589, 51.54273074013846, 53.416885716574534, 48.38388511112758, 43.05506842476981, 47.33442572184971, 52.42406456811087, 55.390361717769075, 55.100059032440186, 57.664930956704275, 50.97566046033587, 56.663289070129395, 58.78173228672573, 52.39419773646763, 50.505489758082796, 54.69856432506016, 55.629463127681184, 57.006363323756624, 54.59960113252912, 51.128725801195415, 47.78266096115112, 43.15793303080967, 43.38199853897095, 41.482729298727854, 42.87454380307879, 43.08605391638619, 43.268110615866526, 42.04627684184483, 43.28736754826137, 43.57212209701538, 42.15154205049787, 43.5780245917184, 47.14879070009504, 48.54508331843785, 51.91210045133318, 51.51106085096087, 52.58796909877232, 49.55369424819946, 49.11426585061209, 47.811534200395855, 49.41132913316999, 48.15531022208077, 54.75508097239903, 57.94671515056065, 60.493997710091726, 57.857795579092844, 60.877246447971885, 58.8953492300851, 63.91702774592808, 63.54470157623291, 67.99636377607072, 65.2247620991298, 70.18646376473563, 66.48536682128906, 78.31119387490409, 67.3998053414481, 84.36678518567766, 20.85388551439558, 0.16147276972021374, 0.11308732642126934, 0.16495125235191413, 0.24820029309817723, 25.479259627205984, 78.24966757638114, 63.52555928911482, 50.629598481314524, 30.246123382023402, 35.511850425175254, 13.84617647102901, 0.9295542176280702, 0.21568188230906213, 0.24188144930771419, 0.1206520487155233, 0.1970938497356006, 0.05256536150617259, 0.1391198041715792, 0.03435265379292624, 0.14273958493556294, 0.1760202483939273, 0.3647475035062858, 0.14559434460742132, 0.2227634537432875, 0.17242116294801235, 0.14716330756034168, 0.1284503431192466, 0.14208226092159748, 2.874449998140335, 44.64135258538382, 53.735120160239084, 40.09970079149519, 73.33822917938232, 56.20041397639683, 78.68037945883614, 53.21912261417934, 0.4122988576335566, 2.228799717766898, 1.308743036219052, 0.6703328873429979, 0.20164695541773522, 1.371872957263674, 24.894415855407715, 70.10886628287179, 83.90279838017055, 84.2328656060355, 83.31444576808384, 80.15436335972377, 81.92556340353829, 86.97383962358747, 77.59841987064907, 82.26792199271065, 77.38285200936454, 75.85687473842076, 73.14892550877163, 76.41746234893799, 72.70763846806118, 71.67421204703194, 59.796676499503, 57.160495213099885, 56.86078814097813, 57.639969553266255, 56.58008439200265, 57.4917436327253, 60.78567613874163, 62.0494909286499, 58.9578343800136, 53.450132846832275, 54.989617415836875, 53.39195558003017, 48.56458691188267, 47.72953156062535, 50.325274331229075, 51.94641760417393, 53.73842750276838, 52.30655663354056, 52.12831449508667, 52.65889630998884, 56.16074671064104, 55.90203053610665, 56.70710093634469, 60.453309059143066, 59.71303408486502, 64.3535691670009, 66.76692172459194, 55.7417425428118, 62.1304999760219, 60.5942393711635, 59.8955146244594, 63.89681543622698, 60.967850957598, 63.30743449074881, 65.38938576834542, 59.023043223789756, 53.176377296447754, 60.319167137145996, 60.2334680557251, 60.6940849849156, 61.87111677442278, 56.97766031537737, 59.4433536529541, 56.018701212746755, 60.36578260149275, 62.5625250680106, 60.95763710566929, 61.704255785260884, 55.56531735828945, 58.48964391435896, 57.18232645307268, 55.86431571415493, 56.48441464560372, 56.326652322496685, 55.61925274985177, 56.58283240454537, 57.40884467533657, 54.25489405223301, 57.702138560158865, 60.93676471710205, 54.61412981578282, 53.92807163511004, 56.082655906677246, 49.45849697930472, 46.728737354278564, 51.84008584703718, 56.360670702798025, 57.73967620304653, 58.73804896218436, 58.652141434805735, 53.36220686776297, 56.59035382952009, 59.94376291547503, 53.775930404663086, 52.05691828046526, 56.32440110615322, 59.492046628679546, 62.98030635288784, 56.30786091940743, 55.63641480037144, 50.8831000328064, 45.9245354788644, 45.71411623273577, 44.44366243907383, 44.822283676692415, 46.523636954171316, 45.95933553150722, 45.140115124838694, 45.54322876249041, 46.23795134680611, 46.55120393208095, 46.72585732596261, 51.00517988204956, 50.82171269825527, 55.044626304081504, 53.38525404248919, 54.856385707855225, 53.49587631225586, 52.37687587738037, 52.588643074035645, 52.04389040810721, 52.06855303900582, 58.63260310036795, 61.549713952200754, 65.30727195739746, 61.917836461748394, 64.25700310298375, 64.30086013248989, 69.87264142717633, 68.25223813738141, 73.68499292646135, 68.70878342219761, 75.75761972154889, 69.09725025721959, 84.07034029279436, 70.8018935067313, 88.61977059500558, 23.097441468920024, 0.23690667482359068, 0.9343580284288951, 0.5492689407297543, 0.3578036475394453, 31.30295828410557, 86.32383564540318, 69.03615474700928, 65.14141150883266, 40.19160114015852, 52.19468716212681, 18.995808669498988, 1.5106298944779804, 0.4635402208992413, 0.4708978203790528, 0.20571094591702732, 0.3673848334167685, 0.17706128396093845, 0.2831676724765982, 0.13972884363361768, 0.29904522906456676], [0.02925901354423591, 0.06960621888616256, 0.05273531756496855, 0.027166976427127208, 0.08538348799837486, 0.012997008344557668, 0.10633810822452817, 0.06326123114143099, 2.453791073390416, 21.259212153298513, 27.93045207432338, 34.489106859479634, 54.91368055343628, 40.790779045649934, 61.39609622955322, 44.65659345899309, 0.19612590596079826, 0.35977818444371223, 0.22048584238759109, 0.0450776122244341, 0.07881944879357304, 0.32513289206794327, 22.32996777125767, 41.234279087611604, 52.51532915660313, 63.14206736428397, 69.27866077423096, 71.80542877742222, 71.24026925223214, 72.32381997789655, 73.06021785736084, 73.13721084594727, 70.71332481929234, 68.2102918624878, 69.94443021501813, 73.22747489384243, 67.8108468736921, 69.1627995627267, 60.53193487439837, 52.468341963631765, 50.59474631718227, 52.8969589642116, 49.10248170580183, 51.46181549344744, 52.57721676145281, 53.03193814413888, 48.52074030467442, 47.356114523751394, 46.69674784796578, 45.47520589828491, 44.53698022024972, 45.62543984821865, 45.93358898162842, 48.30610350200108, 47.07838807787214, 47.68278060640608, 49.566944462912424, 50.82392222540719, 54.91423988342285, 57.01541335242135, 58.448378562927246, 56.93182304927281, 55.32672316687447, 55.967687538691926, 56.6866489137922, 76.8192002432687, 61.72555201394217, 52.774021012442454, 60.34562587738037, 52.72651270457676, 54.33597952978951, 55.595722675323486, 55.27316992623465, 47.88233286993844, 48.19384145736694, 55.925918442862375, 55.05051142828805, 56.413529123578755, 53.81201587404524, 53.103344781058176, 54.871932302202495, 54.07109682900565, 55.47050224031721, 54.67972775868007, 55.45723465510777, 54.45878199168614, 50.12590619495937, 51.36969975062779, 50.611067635672434, 50.647733279636924, 49.998035022190635, 50.39507246017456, 55.871944836207796, 54.25465781348092, 52.13407455171858, 52.86598736899239, 50.81637300763811, 52.353255476270405, 53.87485190800258, 51.72721930912563, 51.74955776759556, 50.783198833465576, 44.54080172947475, 44.10801928383963, 50.937198707035606, 51.5765198298863, 53.9500800541469, 53.53032200677054, 56.79070860998971, 56.49152265276228, 42.433159487588064, 53.557451248168945, 55.93047298703875, 51.80168662752424, 52.5224232673645, 53.602374826158794, 46.271302700042725, 47.53993953977312, 43.38481603349958, 42.88223545891898, 41.50501217160906, 42.220350061144146, 42.475529602595735, 40.817828382764546, 43.26796122959682, 41.98302044187273, 41.24348545074463, 41.51266213825771, 39.84038707188198, 43.417448248182026, 44.56714235033308, 47.42562777655465, 47.16902038029262, 48.291196141924175, 48.54000071116856, 47.25024829592024, 45.07661901201521, 43.382752418518066, 45.9188414301191, 46.78192581449236, 53.485092708042686, 55.29859338487898, 56.28753743852888, 54.296100343976704, 54.11869198935372, 55.44126074654715, 58.88359982626778, 58.19677039555141, 60.332132475716726, 58.72731399536133, 65.77694238935197, 61.8356670652117, 74.5575407573155, 68.32197025844029, 80.75073419298444, 40.754825592041016, 0.2258998868720872, 0.2247486707887479, 0.22673470207623073, 0.26019027829170227, 17.770539011274064, 68.54793957301548, 56.34319945744106, 42.88594232286726, 36.74351937430245, 23.862896714891704, 11.936839291027614, 0.1935339021895613, 0.13397393029715332, 0.06382057469870363, 0.09448507853916713, 0.013564074478511299, 0.04910109418311289, 0.1461331421243293, 0.09075452014803886, 0.11881691004548754, 0.06946941944105284, 0.12719122639724187, 0.025511551149455563, 0.013250195205078592, 0.1441517248749733, 0.008375767568525459, 0.12016889107014452, 0.09882623702287674, 4.828244575432368, 41.391746112278526, 40.32210915429251, 41.65119879586356, 55.13427891050066, 46.5789863041469, 67.52617917742047, 50.77205739702497, 0.1908298587160451, 0.7868097743817738, 0.6774145673428262, 0.2080085604850735, 0.07975636994732277, 0.5273382546646255, 23.22884406362261, 57.00289617265974, 69.26720319475446, 71.75498485565186, 73.91567311968122, 72.30769320896694, 73.68725109100342, 73.96888937268938, 75.74456405639648, 76.31936768123082, 74.53680038452148, 71.4874792098999, 71.70190061841691, 72.47480433327812, 69.47065339769635, 72.6872455051967, 63.738486834934776, 55.11709254128592, 54.187124797276084, 54.35494116374424, 50.38786717823574, 52.88164513451712, 55.930907249450684, 53.57928596224104, 51.59672171728951, 50.658266748700825, 48.60641854149954, 48.68693774087088, 47.17585393360683, 48.22545576095581, 47.362385272979736, 49.94680942807879, 50.02284009116036, 51.14616925375802, 50.59523616518293, 53.26905236925398, 57.47954607009888, 57.416258403233115, 62.91427762167794, 60.64256409236363, 58.51164885929653, 58.69084984915597, 61.54983901977539, 74.22941902705601, 60.982060023716514, 55.00355550221035, 62.702475684029714, 55.51592261450631, 58.303883825029644, 57.19205045700073, 57.436804226466585, 49.67989437920706, 52.79083565303257, 58.662105151585166, 57.62183128084455, 58.988434246608186, 56.65220321927752, 58.256222656794954, 54.525599343436106, 56.79412712369646, 57.145153590611045, 56.1496365410941, 57.37772021974836, 56.896078041621614, 54.104642731802805, 53.577851159232004, 52.262220178331646, 54.30291305269514, 52.32902710778372, 54.113147326878135, 57.01081711905343, 54.95064149584089, 54.3822580065046, 52.61521993364607, 54.3256892476763, 53.00874853134155, 55.59653908865792, 52.74662773949759, 53.313409669058665, 51.9791818346296, 45.3709968158177, 46.99644797188895, 52.29427569253104, 54.057005882263184, 56.76893295560564, 55.64327962057931, 59.33586502075195, 56.69887426921299, 42.38129465920584, 54.3876428604126, 56.58512878417969, 55.14659806660244, 54.05097484588623, 55.51209763118199, 49.7773254939488, 50.14068848746163, 44.79328189577375, 44.90331356866019, 44.44850185939244, 45.059741837637766, 43.17250687735421, 44.56943525586809, 43.60664422171456, 44.26964133126395, 43.37295893260411, 44.05684232711792, 43.395373821258545, 45.55616978236607, 45.85750273295811, 49.06663247517177, 49.76915788650513, 51.01822859900338, 51.67610836029053, 50.207707336970735, 47.85552324567522, 47.3176076071603, 49.09526252746582, 48.522505147116526, 56.27337006160191, 57.378613063267295, 58.41233130863735, 57.84224898474557, 59.904811314174104, 58.00641754695347, 64.45089953286308, 62.994925362723215, 66.12886864798409, 62.7713531766619, 70.16841929299491, 64.62193638937813, 77.74255330221993, 70.26606232779366, 82.87504863739014, 46.41426188605172, 0.24691121226974896, 0.26427747468863216, 0.23921442670481546, 0.3266816075359072, 22.23727880205427, 76.16382530757359, 63.423684801374165, 56.16184452601841, 33.81883846010481, 36.62034518378121, 15.873613051005773, 0.919810237629073, 0.042303774638899734, 0.12506719465766633, 0.028086365932332616, 0.14306173979171685, 0.043171006853559186, 0.1617568451911211, 0.07365991600922175, 0.08740160720688955, 0.1475017201155424, 0.22806623205542564, 0.08074272916253124, 0.15049997637314455, 0.21050763210015638, 0.20556584798863956, 0.20810883439012937, 0.16977132085178578, 7.941707611083984, 61.13678250994001, 54.37491028649466, 47.88599457059588, 67.79963942936489, 57.26806027548653, 78.48370374952043, 61.79128197261265, 0.4397221489676407, 1.5329110303095408, 1.2289885729551315, 0.8938076357756342, 0.26381558233073776, 1.4660106258732932, 28.07200425011771, 74.97837924957275, 84.0178883416312, 81.98939650399345, 81.05637850080217, 78.87164946964809, 77.65852178846086, 80.40032264164516, 79.98875304630825, 79.43585014343262, 77.19069957733154, 74.5971246446882, 74.84281294686454, 77.89687279292515, 74.7390832901001, 76.9009041104998, 66.80804811205182, 56.837014879499165, 58.20032092503139, 56.32463387080601, 52.52441045216152, 56.84396307809012, 60.69987283434187, 58.492325919015066, 53.97549309049334, 53.95926209858486, 52.0135372025626, 53.11049100330898, 51.92171675818307, 50.52014350891113, 51.58141483579363, 53.38620941979544, 51.93612037386213, 52.810096059526714, 54.09080539430891, 56.742078168051584, 61.494489669799805, 59.83382851736886, 64.68807629176548, 61.56886318751744, 61.566514696393696, 62.39753314426967, 69.30886459350586, 77.12526144300188, 57.7451548576355, 59.90980706896101, 66.21368530818394, 58.78153773716518, 60.77863066537039, 59.46801280975342, 62.70941693442208, 56.00055946622576, 56.12845843178885, 58.41101115090506, 60.08422769818987, 61.02868938446045, 61.97791058676583, 59.61687796456473, 57.05856166567121, 60.5531963620867, 59.92286273411342, 58.42249652317592, 58.423191343035015, 58.289667810712544, 56.57447372164045, 56.094367095402305, 53.680410044533865, 56.12192712511335, 54.842603955950054, 53.85383708136422, 60.90391363416399, 57.957404954092844, 54.74478721618652, 55.31124605451311, 55.69673211233956, 55.371615477970664, 58.45580618722098, 57.618822710854666, 54.179415770939414, 52.273076738630024, 48.25477021081107, 51.80331598009382, 56.14851093292236, 56.246629919324604, 59.44980158124651, 58.904937744140625, 57.62538528442383, 60.16341631753104, 49.111542156764436, 54.48530673980713, 57.94111837659563, 59.66093649183001, 58.076479707445415, 59.210060937064036, 50.903569425855366, 51.936165537152974, 47.47361898422241, 48.21887929098946, 47.031491211482454, 47.31502982548305, 46.999824796404155, 48.02725144795009, 46.73299312591553, 47.96376575742449, 46.683587959834504, 48.423878942217144, 45.718785422188894, 49.62148434775216, 49.564766202654155, 52.08242164339338, 52.83532496861049, 53.982781750815256, 54.29838282721383, 54.3389880997794, 50.48884882245745, 50.5391503061567, 53.26324020113264, 52.901072297777446, 62.1838412966047, 61.83321435110909, 63.93000003269741, 61.771750586373464, 63.3030640738351, 62.79854842594692, 69.45092051369804, 67.73912756783622, 71.96509143284389, 67.48853383745465, 75.70770386287144, 69.79479381016323, 82.8789118358067, 73.67091587611607, 86.30866077968052, 48.4617292540414, 0.4925523155501911, 0.4161667243710586, 0.5493930854967662, 0.2699946207659585, 26.608788319996425, 85.9668163572039, 70.64416245051792, 69.25502300262451, 47.20712430136544, 51.29881770270211, 20.361325979232788, 1.6099539590733392, 0.24524101189204625, 0.17463296997760022, 0.12656056880950928, 0.3008723610213825, 0.1470337209424802, 0.3252655863761902, 0.1384185246591057, 0.19908275801156247], [0.15509782465440886, 0.016007424797862768, 0.051223443155842166, 0.13744306271629675, 0.06390885210462979, 0.10817727060722453, 0.10669180138834886, 0.3529861846140453, 4.49966686964035, 22.918660845075333, 21.565372364861624, 19.226643460137502, 43.60458060673305, 45.473381996154785, 66.81660829271588, 49.91538619995117, 0.11068803338067872, 0.2248446156403848, 0.13649733417800494, 0.23765846448285238, 0.05638999877763646, 1.1217691834483827, 27.240461213248118, 39.9593437058585, 45.95153270448957, 65.7929996762957, 70.84295041220528, 68.28243500845772, 65.2680424281529, 67.026339667184, 65.4987712587629, 68.05263028826032, 67.96252604893276, 72.11927890777588, 71.66691643851144, 71.75353268214634, 68.29796423230852, 67.0221985408238, 66.4436776297433, 54.51654584067208, 50.146789005824495, 50.02512604849679, 48.68481159210205, 51.19246162687029, 47.20610291617257, 48.70338412693569, 46.8029580116272, 46.49975946971348, 43.91573831013271, 42.97209651129586, 43.93099308013916, 43.92593479156494, 46.37013387680054, 47.728079387119834, 48.87708214351109, 48.17952816826956, 52.48284632819039, 55.60527644838606, 58.96930585588728, 56.576860427856445, 58.16900191988264, 58.08432074955532, 57.581854820251465, 56.94895035879952, 51.14674595424107, 46.938159533909385, 74.21235425131661, 60.72466400691441, 55.70665066582816, 56.87799188068935, 51.752545492989675, 55.95101881027222, 54.14747837611607, 46.75996255874634, 45.30574975694929, 51.84573820659092, 52.734920024871826, 56.109521116529194, 53.7238050188337, 55.09968730381557, 52.41471924100603, 54.04460334777832, 54.99722569329398, 54.524560587746755, 55.77103962217058, 55.13871186120169, 54.13903978892735, 51.72223745073591, 51.252174445560996, 54.710831369672505, 56.61282777786255, 59.1543641771589, 54.605194432394846, 52.63009602682931, 50.9203006880624, 51.66927828107561, 50.53773634774344, 54.05493879318237, 53.284477370125906, 53.52417285101754, 51.53132874625069, 50.21800109318325, 43.96351064954485, 44.47345978873116, 52.05520207541329, 53.731236117226736, 51.64543901171003, 55.37733384541103, 58.4116017477853, 41.26109218597412, 48.76527867998396, 52.57452433449881, 49.791544982365195, 52.01019164494106, 51.552013533455984, 50.63004316602434, 48.706621987479075, 48.0848832811628, 44.7614244052342, 44.38574572971889, 42.774024214063374, 44.43262869971139, 40.45607737132481, 41.65391901561192, 42.3815586907523, 43.45165770394461, 41.49256794793265, 43.053574562072754, 40.249747140066965, 41.568824427468435, 43.23697921207973, 47.41193635123116, 47.89905718394688, 48.2351450238909, 48.065584659576416, 45.416073254176546, 45.281587396349224, 47.254583971840994, 43.3883387701852, 49.253212451934814, 52.778367110661094, 54.08253703798567, 55.96408142362322, 53.83697380338396, 56.250736304691856, 54.28423629488264, 54.42216498511178, 57.4483972958156, 56.13381896700178, 58.75496782575335, 62.3284888948713, 64.91959721701485, 69.38019480024064, 71.43119880131313, 76.42548057011196, 61.14525236402239, 1.2895073826823915, 0.2872451793934618, 0.4365203322044441, 0.6052156186529568, 15.820963076182775, 66.21053777422223, 55.424362727573936, 45.48551007679531, 25.344311714172363, 12.021982516561236, 13.677108560289655, 0.6428373456001282, 0.07876493529017482, 0.05888963357678481, 0.01145354304130056, 0.03571074841810124, 0.009961352084896393, 0.04790864013401525, 0.14299237994211061, 0.04197224582146321, 0.12421169770615441, 0.04843001287164433, 0.015046346101111599, 0.09622805858297007, 0.05704361799040011, 0.1177141685038805, 0.16525176194097313, 1.0725256715502058, 9.631635444504873, 44.27142701830183, 34.56962605885097, 26.98664525577, 43.017843450818745, 52.55737965447562, 75.63104438781738, 55.917545863560264, 0.04493223609668868, 0.38955748506954735, 0.7384930327534676, 0.3787281747375216, 0.060766108600156646, 1.5467763777290071, 30.23611797605242, 60.28571850912911, 62.18354947226388, 73.38238498142788, 76.40542806897844, 71.35906260354179, 70.06848335266113, 69.24176583971295, 70.88895443507603, 71.41582938602993, 69.54288687024797, 72.39059216635567, 74.17833587101528, 73.29321180071149, 72.18195165906633, 70.45189884730748, 70.317305292402, 58.74360057285854, 52.80293246677944, 53.343603066035676, 50.80407469613211, 52.26412745884487, 50.947885036468506, 51.04536131450108, 50.05136939457485, 49.71899536677769, 46.59292091642107, 45.71746873855591, 44.857948780059814, 46.34500919069563, 48.47941936765398, 50.15133312770298, 50.654698848724365, 50.28001376560756, 55.19044814790998, 58.28422737121582, 58.78740201677595, 58.756044796534944, 62.15365137372698, 60.5608880179269, 60.954989842006135, 60.75611850193569, 55.000234263283865, 51.68649244308472, 68.74020317622593, 61.580001149858745, 59.520617621285574, 59.118073735918315, 54.50990683691842, 57.66761990955898, 57.75730378287179, 51.12830890927996, 48.28403949737549, 53.81355490003313, 55.75563199179513, 57.916090965270996, 57.30063690458025, 57.78086512429373, 55.580919538225444, 56.95562410354614, 56.321979658944265, 57.54182972226824, 57.608532428741455, 57.83037451335362, 56.522535937173025, 56.73779112952096, 51.859408787318635, 56.68160104751587, 55.88236018589565, 59.399364607674734, 56.47897073200771, 54.21473693847656, 52.03179012026106, 53.56563622610909, 53.08251755578177, 53.76169701984951, 56.399910654340474, 55.72670316696167, 54.05451842716762, 51.9797237941197, 45.09281178883144, 47.85062823976789, 54.138153893607004, 56.413459641592844, 52.61341340201241, 57.442953382219585, 56.43835503714425, 45.20354870387486, 51.5718332699367, 53.81756401062012, 49.78072663715908, 52.43163810457502, 53.28765269688198, 54.475054672786165, 52.84733145577567, 49.15379415239607, 47.748361178806846, 46.13898120607649, 45.84328671864101, 45.67440727778843, 43.929290771484375, 42.64552422932216, 44.23728704452515, 44.510618754795615, 43.35402856554304, 44.62145641871861, 42.355297974177766, 45.08099637712751, 47.40942805153983, 49.08827611378261, 51.45414120810372, 51.31623683656965, 50.250053133283345, 47.53180667332241, 47.9108031136649, 49.18199689047677, 45.8127806527274, 52.356941495622905, 55.14505556651524, 56.93784366335188, 60.30604199000767, 57.40939705712454, 60.181405203683035, 57.87508269718715, 57.778919628688264, 60.15095819745745, 60.28712204524449, 60.96373067583357, 65.72405270167759, 68.6023439679827, 73.00717530931745, 71.48925100054059, 79.35997581481934, 65.49335166386196, 2.1910141110420227, 0.34588604846170967, 0.6293256506323814, 0.5911957280976432, 18.442348173686437, 74.94082423618862, 62.35835920061384, 58.29452460152762, 25.48641974585397, 16.758125679833547, 18.999477318355016, 1.695482375366347, 0.09457778677876506, 0.2141826863267592, 0.040341274945863655, 0.035595064982771873, 0.035183051734098365, 0.13886557067079203, 0.12137905827590398, 0.05992360559425183, 0.30587997660040855, 0.1889611461332866, 0.07726128811814956, 0.2524128827665533, 0.17966478211539133, 0.2359065684889044, 0.1944303690854992, 1.30315885586398, 18.71982795851571, 66.41340432848249, 46.78175210952759, 31.246382577078684, 58.01510279519217, 62.500366483415874, 83.49153450557164, 66.86821256365094, 0.2665800154209137, 0.8722516638892037, 1.5717086855854308, 1.4067528056246894, 0.22613839193114213, 2.16105478150504, 36.93374020712716, 79.0045268195016, 76.02836322784424, 81.51478590284074, 85.30076898847307, 79.2696144921439, 77.74652767181396, 74.08900982992989, 75.5011408669608, 74.76741804395402, 73.35860129765102, 75.51479407719204, 76.47656372615269, 79.08164487566266, 74.07226467132568, 73.57319641113281, 72.77557100568498, 62.34742273603167, 55.08399132319859, 57.01635135923113, 55.0956642968314, 56.145373821258545, 54.652699266161235, 54.98315906524658, 51.94371475492205, 53.0112498828343, 48.791859013693674, 48.183596338544575, 47.79693603515625, 50.250678471156526, 51.209359645843506, 52.28971767425537, 53.91415091923305, 54.96402372632708, 56.84435217721121, 59.95931298392159, 63.95741067613874, 61.88357489449637, 64.47958864484514, 63.59115028381348, 62.618062019348145, 63.13889898572649, 56.615791184561594, 65.81239209856305, 74.38777542114258, 57.64798082624163, 64.51802607945034, 61.86698259626116, 58.574099268232075, 61.78560529436384, 60.39118521554129, 54.68010296140398, 53.379747595105854, 54.45449842725481, 57.66031387874058, 58.34731701442173, 59.744405201503206, 59.54561723981585, 57.425707953316824, 60.86159215654646, 60.012793268476216, 59.33504513331822, 59.568838119506836, 60.94512340000698, 60.491329601832796, 57.308530058179585, 52.753475189208984, 58.79145976475307, 60.165688378470286, 61.96550110408238, 58.58288179125105, 54.965006896427695, 53.88471140180315, 54.92369638170515, 56.77418579374041, 56.13785239628383, 57.22570058277675, 56.49523646490914, 56.163004875183105, 53.374935967581614, 46.73935420172555, 51.323733942849294, 57.75979471206665, 58.20941959108625, 56.01086711883545, 59.148395674569265, 61.394150733947754, 49.47473839351109, 52.34764133180891, 56.54472500937325, 53.50087901524135, 55.097255434308735, 55.06675979069301, 56.59704841886248, 54.30042907169887, 54.04983534131731, 51.45857415880476, 48.859551838466096, 48.546591077532085, 49.689569745744976, 46.34217779976981, 45.46086829049246, 46.8331618309021, 49.552763189588276, 46.34143781661987, 48.27207122530256, 45.053884506225586, 47.95710243497576, 49.1546175139291, 54.7441896711077, 52.846052987234934, 54.851351737976074, 55.126118251255576, 50.25615017754691, 50.237431730542866, 52.77611589431763, 47.87624972207205, 56.00159822191511, 59.13080978393555, 61.46473748343331, 62.91374955858503, 61.140513692583355, 62.834679058619905, 61.937534604753765, 63.20581708635603, 64.65917873382568, 63.417577334812705, 68.31581415448869, 70.78615583692277, 74.00305366516113, 76.23380061558315, 76.86149392809186, 82.67713614872524, 70.31560298374721, 2.74566969701222, 0.35999471853886333, 0.8749648268733705, 0.5259456836751529, 21.408016511372157, 87.47048296247209, 68.13077667781285, 74.16758005959647, 36.77611684799194, 30.982576847076416, 27.66944820540292, 2.1712740617138997, 0.2080732248723507, 0.29794594805155483, 0.06998491606542043, 0.1341829869363989, 0.15437475059713635, 0.3724056939993586, 0.2710555781211172, 0.17033189934279236], [0.1620923943285431, 0.03066317391182695, 0.06170082451509578, 0.019635115583826388, 0.08747879056526081, 0.062211530682231696, 0.24629192692892893, 1.2726591953209467, 5.5934870328222, 25.427094289234706, 17.694378069468907, 19.63297585078648, 34.581795828683035, 43.194810594831196, 67.98480892181396, 50.14251586369106, 0.11684975560222353, 0.17322866033230508, 0.35920365527272224, 0.5149345259581293, 0.21179988847247191, 2.9538160136767795, 32.681199482509065, 37.83040523529053, 39.535329886845176, 64.02219567980084, 62.20011397770473, 67.04326547895158, 70.8515522820609, 69.53442396436418, 71.76203032902309, 68.90772424425397, 66.11337416512626, 66.64730848584855, 68.26764229365757, 66.78325693947929, 70.26935577392578, 66.93069076538086, 66.82112462180001, 58.84380749293736, 49.879748889378135, 49.27032239096505, 49.221177782331196, 49.01841197695051, 48.68327604021345, 47.50801951544625, 46.83174787248884, 47.06026370184762, 46.0553422655378, 45.03987693786621, 44.99348381587437, 44.48348603929792, 44.493811062404085, 47.321703570229666, 47.815505095890586, 56.00754587990897, 58.57229273659842, 58.85362529754639, 59.71072728293282, 59.97732271466936, 59.92105620247977, 58.91058662959507, 57.515801770346506, 57.81098556518555, 58.668441908700125, 48.71654054096767, 35.04498359135219, 58.71892751966204, 57.90766280038016, 55.42296961375645, 54.194955417088096, 55.79974610464913, 55.87073932375227, 49.44013636452811, 48.90508338383266, 51.44482019969395, 52.701929977961946, 56.175761767796104, 53.12237242289952, 54.18827819824219, 54.60105678013393, 52.380488940647666, 54.135683809007915, 53.05180999210903, 53.78797163282122, 59.5840060370309, 53.132558482033865, 52.982261998312815, 54.00909457887922, 53.95598602294922, 51.65516301563808, 53.55998386655535, 56.12256635938372, 52.696493012564524, 52.889083181108745, 53.34411375863211, 51.00402648108346, 49.01074463980538, 54.96644169943673, 52.107251031058176, 51.06933607373919, 48.14500951766968, 44.05445909500122, 46.56468691144671, 50.556631973811555, 53.708518981933594, 54.50578308105469, 55.72405242919922, 43.07366527829851, 48.6853153364999, 55.18214157649449, 53.91871588570731, 51.95346655164446, 52.058148111615864, 52.95212766102382, 51.33077941622053, 48.8299559865679, 47.12232501166207, 46.294276918683735, 44.00235455376761, 44.6933251108442, 43.96725572858538, 41.538863795144216, 42.00751979010445, 43.13457318714687, 40.27054309844971, 41.76687240600586, 39.83599233627319, 40.95856067112514, 42.346293108803884, 41.43383482524327, 46.52083683013916, 44.42594105856759, 46.0390556880406, 44.538067613329204, 44.7569636617388, 45.480628967285156, 46.48963941846575, 44.764822074345176, 49.8961501121521, 53.885041441236226, 55.798891476222444, 53.40806497846331, 52.999052320207866, 52.83950431006295, 51.659245082310264, 52.68712336676461, 50.04069348743984, 50.628809860774446, 54.062074593135286, 56.54418999808175, 62.39701202937535, 67.2318673815046, 73.01538113185337, 71.99676827022007, 77.97360174996513, 6.691057920455933, 0.5944584501641137, 0.3478720118956906, 0.5040443646056312, 20.9037492615836, 63.72816181182861, 55.63511896133423, 45.518170084272114, 34.62868922097342, 18.287099361419678, 12.664544974054609, 0.7912999391555786, 0.13794246449002198, 0.05078844453341194, 0.057474019538078985, 0.091601582909269, 0.11334341232265745, 0.18344118233237947, 0.2492886089852878, 0.17164949221270426, 0.09462446320269789, 0.028042181428255777, 0.0729275799489447, 0.014977393372516547, 0.04255176561751536, 0.07289865400109972, 0.07340440007724933, 2.497650057077408, 12.678423132215228, 46.724398204258506, 29.83597469329834, 29.291593755994523, 40.75020156587873, 50.6804975100926, 77.3081727709089, 60.07778671809605, 0.35233837366104126, 0.07240529797439064, 0.34387986468417303, 0.8563786670565605, 0.10381359154624598, 2.529779613018036, 37.6354318346296, 58.550885336739675, 57.751130308423726, 73.63117912837437, 68.88401004246303, 70.765700340271, 73.95473589215959, 74.53114455086845, 73.76992075783866, 72.63771179744175, 69.3531107221331, 69.52655165536063, 72.18700299944196, 68.88508701324463, 70.9526138305664, 69.73361492156982, 69.15054294041225, 62.977242197309224, 51.9055552482605, 51.48809358051845, 51.5367066519601, 51.70480442047119, 52.85257387161255, 49.11292484828404, 48.46912908554077, 47.583341462271555, 47.87767062868391, 46.07888971056257, 48.07187972749983, 45.71251467296055, 45.83215570449829, 48.55900750841413, 49.33810901641846, 57.934635707310264, 59.96443380628313, 59.398148672921316, 62.01556287493025, 61.962763513837544, 61.07754216875349, 59.761171204703196, 57.97825302396502, 59.66825294494629, 60.856506075177876, 53.83428485052926, 41.952948638371055, 54.15602118628365, 58.19081231525966, 58.192837715148926, 57.43184321267264, 58.85156168256487, 57.150093759809224, 51.9914801461356, 51.14019727706909, 55.63416010992867, 54.28170715059553, 58.9114898954119, 54.56288685117449, 57.80138315473284, 56.96682807377407, 55.52837378638131, 55.29929862703596, 55.08787189211164, 57.25114836011614, 62.138914244515554, 53.61130673544747, 55.12834167480469, 55.470342431749614, 55.74594272886004, 53.49002940314156, 57.16126298904419, 55.88679313659668, 53.728474208286826, 55.2081868989127, 54.7750118800572, 52.543323448726106, 51.01730448859078, 56.71707507542202, 53.94099875858852, 53.23713929312569, 50.99392032623291, 47.0828001839774, 52.336267130715505, 54.67238698686872, 54.64163078580584, 58.815180914742605, 56.95770856312343, 46.180423736572266, 53.25487457002912, 54.623586314065115, 55.38239213398525, 53.21373428617205, 53.99787671225411, 54.48119340624128, 54.41645703996931, 51.74623652866909, 50.711191177368164, 49.05357681001936, 48.80486604145595, 48.69857249941145, 46.666849749428884, 44.9117556299482, 42.09144013268607, 43.37630449022566, 42.35155289513724, 43.16636119570051, 41.92352301733834, 43.52994653156826, 45.11686992645264, 44.80819272994995, 46.931190490722656, 47.42995303017752, 48.59845243181501, 47.655679157802034, 48.452845982142854, 47.32825919560024, 49.562716484069824, 48.90136957168579, 53.315997873033794, 56.41700322287423, 59.00877162388393, 57.22339030674526, 55.696325642721995, 56.58924559184483, 56.24867616380964, 56.75655821391514, 55.232269355228965, 56.049332346235005, 57.47738170623779, 62.08358573913574, 66.0116525377546, 71.8510298047747, 77.18756593976701, 74.23183005196708, 78.87035710471017, 7.903621060507638, 0.5754150120275361, 0.9079424430217061, 0.7962377199104854, 27.461721386228287, 71.5176899773734, 63.41172695159912, 56.500506673540386, 39.768146651131765, 24.92102745601109, 13.102885110037667, 0.9137282839843205, 0.13989686247493538, 0.056030673773161004, 0.01812481876861836, 0.12534179777971335, 0.11958414316177368, 0.15507391308035168, 0.02671772687296782, 0.11330540079091277, 0.2242773196526936, 0.08889479815427746, 0.1580286616725581, 0.08542626284595047, 0.11243007026080575, 0.15896959975361824, 0.19660059548914433, 3.20582891362054, 24.65303717340742, 71.41006238119942, 39.67986283983503, 30.571378980364116, 52.13433163506644, 61.61074692862374, 87.47772993360246, 69.03624507359096, 0.8408553600311279, 0.5167136447770255, 1.3745809090988976, 1.8340703845024109, 0.1440757560942854, 3.900889354092734, 49.23073502949306, 74.59749289921352, 70.83458478110177, 81.2727176121303, 76.60374355316162, 76.96651594979423, 80.96972751617432, 78.52863080160958, 78.67097159794399, 76.65948895045689, 74.39255578177315, 73.56671374184745, 76.94379534040178, 73.36962808881486, 76.11645248958042, 71.94208594730922, 71.19320910317558, 66.08142634800502, 54.2006390435355, 54.40252242769514, 54.95568936211722, 55.33755193437849, 55.23163359505789, 52.78668410437447, 51.881062848227366, 51.259556906563894, 50.635789326259065, 49.69364486421858, 51.17217288698469, 47.93490988867623, 49.59215600149972, 51.47509350095476, 53.20056397574288, 59.70876094273159, 63.04261779785156, 63.13864190237862, 65.00214876447404, 64.46355220249721, 65.09513650621686, 63.81918321337019, 60.81841605050223, 61.35109274727957, 65.36476135253906, 54.37584829330444, 51.90053170067923, 63.01753480093819, 58.1833291053772, 61.568133626665386, 61.65444414956229, 61.925264086042134, 63.245129993983674, 56.3383252961295, 53.3121520451137, 55.20389986038208, 55.67383779798235, 62.6883430480957, 61.27917194366455, 59.91727638244629, 61.614276613507954, 60.44868155888149, 58.201866899217876, 56.61651379721505, 59.48059599740164, 65.73243222917829, 55.75933885574341, 57.87889378411429, 57.93035214287894, 59.13335977281843, 56.51417030606951, 60.56069346836635, 59.46244730268206, 55.627541950770784, 53.68295308521816, 56.70738581248692, 53.810230187007356, 53.308889865875244, 60.60544681549072, 56.70365810394287, 55.15420634405953, 50.942465441567556, 50.5635905947004, 55.03374889918736, 57.20434876850673, 59.2417516708374, 58.163766452244346, 57.9812650680542, 49.7196797643389, 53.27909599031721, 58.18064362662179, 56.88683346339634, 55.79560150418963, 55.858611243111746, 59.48204122270857, 56.982774189540315, 54.635651860918315, 52.3816944531032, 50.45505625861031, 49.73653609412057, 50.63956914629255, 48.700927938733784, 47.15632949556623, 46.46021727153233, 45.32447862625122, 45.700487341199604, 46.70976529802595, 44.059513909476145, 47.31115273066929, 49.26963104520525, 47.80720547267369, 51.35658849988665, 50.42997326169695, 52.07892322540283, 50.441545486450195, 51.50877489362444, 49.67154611860003, 53.1024033001491, 50.44237927028111, 56.03075286320278, 58.11283963067191, 62.426312582833425, 62.252725737435476, 59.65276541028704, 60.22972992488316, 58.97094563075474, 61.29155363355364, 58.198941707611084, 60.717312812805176, 61.70098318372454, 66.17187799726213, 71.31188433510917, 73.97950622013637, 79.99108069283622, 79.0003023147583, 85.19705322810582, 8.17773357459477, 0.4923984780907631, 1.1507807352713175, 0.6689163776380675, 29.781278473990305, 81.38495186397007, 68.18490314483643, 70.69192436763218, 52.67540522984096, 41.47941153390067, 23.819750138691493, 1.1554377653769083, 0.19972307793796062, 0.15344643326742308, 0.12470803250159536, 0.14872007045362676, 0.4281302738402571, 0.3338062252317156, 0.2602907828986645, 0.22613919260246412], [0.06166955762143646, 0.020834412658587098, 0.10837467001484972, 0.04838831689474838, 0.09576880572629826, 0.09385751507111958, 0.11397397491548743, 2.5705336204596927, 9.384933573859078, 23.163650853293284, 23.405654873166764, 20.801237276622228, 32.975424425942556, 48.41701412200928, 69.72513117109025, 54.88316059112549, 0.2508352074239935, 0.1168122733277934, 0.1769574409616845, 0.11083750785993678, 0.08366133219429425, 8.585903763771057, 47.162419591631206, 31.409185818263463, 44.14444521495274, 57.556111744471956, 64.07602337428501, 68.06619317190987, 70.978593145098, 68.73917484283447, 70.53105272565568, 70.19789355141776, 70.49495683397565, 65.41295405796596, 66.37184020451137, 65.68870026724679, 66.17656108311245, 65.17313003540039, 64.48226370130266, 57.494404792785645, 51.64007152829851, 51.357238156454905, 49.25117662974766, 47.626166684286936, 47.60773311342512, 48.87881571905953, 45.974548612322124, 44.86561959130423, 44.53083453859602, 43.93794475282942, 43.55763857705252, 44.74481126240322, 46.05203839710781, 47.48019892828805, 52.01544795717512, 59.226444789341514, 57.65538413184029, 59.97243813105992, 59.56099360329764, 60.046165466308594, 56.197106633867534, 53.51633875710623, 54.075151102883474, 57.760322775159565, 57.01903683798653, 61.90129974910191, 52.878330843789236, 36.79094082968575, 51.0161406653268, 57.375878947121755, 56.924454484667095, 54.217387676239014, 57.53161934443882, 50.2360976764134, 48.885020460401265, 51.58722005571638, 56.94709171567644, 53.5246661731175, 54.686186109270366, 53.73613459723336, 52.547346455710276, 51.76681709289551, 57.496273858206614, 51.422280243464876, 56.29103933061872, 53.581599712371826, 53.14386320114136, 57.158094610486714, 55.81865215301514, 53.076236384255544, 59.774136543273926, 52.314856256757466, 42.13251093455723, 43.41758721215384, 50.78044734682356, 52.69452667236328, 51.25151784079415, 51.344939844948904, 51.04475334712437, 52.14533063343593, 52.86146756580898, 47.92461960656302, 42.86032778876168, 48.768207345690044, 51.02646221433367, 55.3171763420105, 57.13824360711234, 45.12737560272217, 49.73263815471104, 52.77985749925886, 52.75239821842739, 52.03008781160627, 51.79371356964111, 53.479047775268555, 53.66595779146467, 51.06650815691267, 50.54547316687447, 49.17350271769932, 49.667790617261616, 47.419443879808696, 44.7890921320234, 45.59141799381801, 42.82019846779959, 41.49725450788225, 40.45637614386422, 41.27581194468907, 41.49201904024397, 39.623690128326416, 40.14093140193394, 42.31614140101841, 43.788106850215364, 44.45845167977469, 43.949638571058, 44.932777404785156, 43.06923927579607, 46.50613096782139, 47.300376074654714, 46.070121083940776, 47.161690030779155, 51.34150048664638, 55.10871301378523, 54.125393526894705, 53.827715328761506, 53.01499496187483, 51.650153364454, 50.69232334409441, 49.87138673237392, 50.16813039779663, 49.94409268242972, 54.82103674752371, 57.80461406707764, 64.8684515271868, 66.4295380456107, 73.10056604657854, 69.84498064858573, 79.37218379974365, 14.138529743467059, 0.6316966148359435, 0.7083455047437123, 0.37343237176537514, 35.68404415675572, 65.65227781023297, 55.91976581301008, 50.67760011128017, 27.50566700526646, 13.48820093699864, 10.102051939283099, 0.9114096484013966, 0.10422620869108609, 0.02631011392389025, 0.14688105056328432, 0.0682996589956539, 0.11356797348707914, 0.24872626630323275, 0.3336359943662371, 0.07849983844373908, 0.05918356816151312, 0.039992002437689474, 0.09652541298419237, 0.07439147853957755, 0.055560238659381866, 0.05155210855549999, 0.13445738649794034, 3.9929338778768266, 20.453796080180577, 42.28954717091152, 35.02579961504255, 29.62232106072562, 41.28338548115322, 56.00544057573591, 79.94562557765416, 66.28162479400635, 0.593293541244098, 0.03502421347158296, 0.3290037986423288, 0.6473737050380025, 0.24374134093523026, 8.781018733978271, 52.515308312007356, 51.77326502118792, 58.40839862823486, 69.49564606802804, 69.35673768179757, 73.05981486184257, 73.85094370160783, 71.66611739567348, 73.02394826071603, 71.00409998212541, 72.9079063960484, 69.70523153032575, 70.42051383427211, 69.27681255340576, 68.59356144496373, 67.90370259966168, 67.26731709071568, 60.56092970711844, 55.380133969443186, 53.676098687308176, 51.74767133167812, 51.80150597436087, 49.59852055140904, 51.27437046595982, 47.91063983099801, 46.766803060259136, 47.83085019247872, 46.359430176871165, 46.43221950531006, 47.0676565851484, 47.52694640840803, 49.966941833496094, 54.46014036451067, 60.99550478799002, 61.036144801548545, 62.43970176151821, 62.459455490112305, 61.032371929713655, 57.01969691685268, 57.18442133494786, 57.77200617109026, 60.78088188171387, 60.30779293605259, 62.322020121983115, 58.973384448460166, 45.71389389038086, 50.95073727199009, 60.00678307669503, 58.43884563446045, 56.528890064784456, 58.88386385781424, 54.26422895703997, 51.91652992793492, 55.60458857672555, 57.99845838546753, 54.175927775246755, 57.550855432237896, 57.823916162763325, 54.44019208635603, 54.55605329786028, 60.77352373940604, 52.82777575084141, 60.46981103079659, 53.51005063738142, 54.365137645176475, 61.99085508074079, 56.00134113856724, 55.24974407468523, 62.01019886561802, 52.78702804020473, 42.41375316892351, 43.48289680480957, 51.396787302834646, 56.57411936351231, 53.45596238545009, 54.109315395355225, 52.64443016052246, 56.25429030827114, 55.08835826601301, 48.68518679482596, 45.08648197991507, 52.96785838263375, 55.215624945504324, 58.80853843688965, 59.495485986982075, 47.673285893031526, 53.67317349570138, 54.62600776127407, 54.326832226344514, 53.23486723218645, 52.80072293962751, 54.05056490216936, 54.28056069782802, 53.46811131068638, 53.582336221422466, 51.37073155811855, 52.10447175162179, 48.37955290930611, 46.78159924915859, 48.69405617032732, 46.759333746773855, 42.5246707371303, 44.26075458526611, 42.65360498428345, 42.623401165008545, 42.85203511374337, 42.80803912026541, 44.443509578704834, 45.161963735307964, 46.61101055145264, 46.20401634488787, 46.42171382904053, 45.883294446127756, 47.43864870071411, 49.267866202763145, 48.77159111840384, 50.55176823479788, 53.824731077466694, 57.045123849596294, 56.71066883632115, 57.26248434611729, 56.22805043629238, 56.83984627042498, 53.30821589061192, 54.439410414014546, 55.478113991873606, 53.41436004638672, 57.67527682440621, 61.9338173185076, 68.5161793572562, 70.11136068616594, 76.46745463779995, 71.41015270778111, 83.08250795091901, 16.415140015738352, 0.8070452628391129, 0.9789054266044072, 0.36656852864793366, 38.337453501565115, 72.28524357931954, 66.69212436676025, 60.08606897081648, 36.039861406598774, 18.050737278802053, 9.860851304871694, 1.3349842109850474, 0.4207922433103834, 0.09769203859780516, 0.060171169095805714, 0.05769579192357404, 0.008664389224057751, 0.2164095432630607, 0.23252512993557112, 0.14263409988156386, 0.15699556496526512, 0.10070059501699039, 0.16507718845137528, 0.1408802361360618, 0.19545254137899193, 0.16609509954495089, 0.2675659539444106, 4.863021177904947, 36.129385471343994, 62.73277677808489, 46.96900258745466, 31.26196391241891, 49.7872440474374, 69.9671299798148, 87.18052768707275, 79.44503566196987, 1.1123443863221576, 0.258801208542926, 0.677256604390485, 1.514273681810924, 0.8595134988427162, 12.859014630317688, 70.02893420628139, 63.790778977530344, 71.38644545418876, 76.49083532605852, 77.06758444649833, 80.0759390422276, 79.17186723436627, 77.79943820408413, 78.48879677908761, 74.2951350893293, 77.21370506286621, 71.85805443355015, 74.40334633418492, 72.61579717908586, 73.08285508837018, 69.96362113952637, 69.15373911176408, 63.629865646362305, 58.689974376133506, 56.71563679831368, 55.12239749091012, 54.53485434395926, 53.08131899152483, 54.71061250141689, 51.11610439845494, 49.950022969927105, 51.194695472717285, 48.030023779187886, 48.36838020597185, 48.90840809685843, 49.48351049423218, 51.98544910975865, 55.97396176201956, 62.43027305603027, 62.168680327279226, 64.63998086111886, 64.59097521645683, 63.13124207087925, 60.1398480279105, 59.29749706813267, 58.84020137786865, 65.02199281964982, 64.615280015128, 68.22267355237688, 55.73502710887364, 49.77163144520351, 57.312285559517996, 60.372237477983745, 61.115097182137625, 59.46467072623116, 62.363104820251465, 56.84533534731184, 55.790890625544954, 56.51537234442574, 57.494189398629324, 58.250865595681326, 60.17431804112026, 60.184448514665874, 57.1996100970677, 55.974006925310405, 62.924074581691194, 57.18742643083845, 60.7499554497855, 56.1653151512146, 56.221564292907715, 62.979180744716096, 61.57479000091553, 57.982797145843506, 63.480416842869346, 53.046901089804514, 43.62720046724592, 46.199468748910085, 54.81846591404506, 57.56551613126482, 54.978823389325825, 55.4545978137425, 53.914178712027415, 56.91620697293963, 56.70998791285923, 52.98844242095947, 48.49924257823399, 56.833130836486816, 56.88791390827724, 60.48493031093052, 58.18131065368652, 53.10290357044765, 55.00138766424996, 58.52694879259382, 57.2336562701634, 57.679140022822786, 54.11921657834734, 58.6364871433803, 57.760096958705354, 56.79730939865112, 55.67336532047817, 53.74738025665283, 55.21098354884556, 51.568178517477854, 48.3760266985212, 49.69351979664394, 48.95798349380493, 45.241697788238525, 45.719754695892334, 46.241126673562185, 46.448971612112864, 46.08660568509783, 45.63575097492763, 47.514825275966096, 48.519889150347026, 49.74007272720337, 48.83412490572248, 51.152162075042725, 47.58701358522688, 51.73711354391915, 53.016106673649375, 51.30308389663696, 52.28108106340681, 57.11743722643171, 62.534739221845356, 61.21263599395752, 60.10550308227539, 59.482569285801475, 59.85510390145438, 57.39128310339791, 59.10581711360386, 59.93325029100691, 58.50839015415737, 62.636808259146555, 65.73592717306954, 72.61491475786481, 74.060946055821, 81.00451714651925, 76.56358991350446, 88.81352806091309, 16.792819772447857, 0.8333161302975246, 1.6173335973705565, 0.39335736259818077, 48.07193878718785, 81.57275472368512, 73.44045802525112, 75.16902392251151, 45.41585438592093, 30.60038423538208, 22.95915494646345, 1.2067179679870605, 0.5982691028288433, 0.12036595121026039, 0.22687325892703875, 0.0636998497481857, 0.5055588004844529, 0.5999749941485268, 0.5225107765623501, 0.3199629437710558], [0.04639895060764892, 0.020828799477645328, 0.045491528763834915, 0.1389840700264488, 0.21768232568034104, 0.033643041870423725, 0.17764339915343694, 2.9729852250644138, 14.378618666103907, 27.103029319218226, 19.56812310218811, 22.909451007843018, 35.870783942086355, 45.44159746170044, 65.32846396309989, 55.33938973290579, 1.2837506915841783, 0.21619558760098048, 0.10687831030892474, 0.07855036894657783, 0.4484523433659758, 6.17266845703125, 42.679782322474885, 24.46772176878793, 44.469596590314595, 56.49179710660662, 63.92435114724295, 68.79655306679862, 66.1707523890904, 68.54203360421317, 69.35085255759103, 68.37044089181083, 67.89305101122174, 67.10003226143974, 69.8733640398298, 67.78609044211251, 66.84092698778424, 65.36930547441754, 60.80927916935512, 57.80276237215315, 50.625568526131765, 49.36831978389195, 50.278016158512656, 48.330557686941965, 48.801926953451975, 47.85683298110962, 43.82941736493792, 42.181846618652344, 43.57784741265433, 43.75569697788784, 44.655839579445974, 43.1521486554827, 46.565155914851594, 54.854815414973665, 61.297654151916504, 59.0771974836077, 58.006292479378835, 54.75690140042986, 54.99933794566563, 54.48229469571795, 54.84923253740583, 57.32463598251343, 57.557605607169016, 56.151529925210134, 57.5255639893668, 54.39144352504185, 58.17574862071446, 58.70633738381522, 46.81892497198922, 50.85182966504778, 55.57210922241211, 55.396003655024934, 52.72796140398298, 52.04732281821114, 51.938600880759104, 48.991265365055625, 54.78957530430385, 53.407856532505576, 55.55478736332485, 54.42994696753365, 53.7576253754752, 55.071425506046836, 52.35232441765921, 56.80590084620884, 51.02129275458199, 43.1795141356332, 42.260944911411826, 55.11316333498274, 43.49952384403774, 47.997572217668804, 44.93722425188337, 52.33172648293631, 48.5421268599374, 40.35994904381888, 42.29975407464163, 53.7195040839059, 57.90598481042044, 53.198003564562114, 50.31582825524466, 52.317899567740305, 52.50891249520438, 45.04890612193516, 44.30545929500035, 45.66546147210257, 49.61904553004673, 56.90826170785086, 46.06583057131086, 50.91093104226248, 52.0780234336853, 51.84704794202532, 55.28057323183332, 49.86543212618147, 53.616156578063965, 52.43467794145857, 51.363668714250835, 52.646525042397634, 54.785948344639365, 51.14403963088989, 52.616797174726216, 47.87978982925415, 50.43337093080793, 45.398226806095664, 48.23175777707781, 43.067040170942036, 41.49128253119332, 40.38347911834717, 39.3915091242109, 40.502480915614534, 39.97890983309065, 41.51428801672799, 42.734568868364605, 44.34810038975307, 44.54882342474801, 43.36050081253052, 44.37025472096035, 45.0325813293457, 45.70926986421858, 46.0673383304051, 46.67677525111607, 54.83448845999581, 53.591389724186485, 56.331946849823, 53.809142793927876, 54.51526042393276, 52.36268418175833, 52.17237997055054, 48.40434408187866, 51.26641477857317, 50.52360718590872, 57.211852822984966, 58.54316588810512, 66.34658350263322, 66.22626849583217, 72.99418217795235, 70.35307461874825, 80.95953450884137, 21.85425935472761, 0.4409177819533007, 0.7338630354830197, 0.4537646754511765, 11.296704360416957, 65.93065738677979, 56.081933294023784, 49.79678045000349, 26.546565464564733, 9.190456969397408, 10.593977451324463, 0.3503213333232062, 0.42435311366404804, 0.14835976835872444, 0.13207779132894107, 0.02440511328833444, 0.11890726376857076, 0.2671406481947218, 0.3293172003967421, 0.19873856433800288, 0.06454461227570261, 0.03664938287277307, 0.03365946581055011, 0.04189322702586651, 0.05847219204796212, 0.1386104415037802, 0.22925779383097375, 4.293643227645329, 28.414892639432633, 46.79559986931937, 30.945487362997874, 22.78897098132542, 40.85251726422991, 54.78073024749756, 76.9208037512643, 65.09199592045375, 1.6108196611915315, 0.12449338473379612, 0.11515750283641474, 0.02955565887636372, 0.5322529109460967, 9.87344925744193, 60.18921497889927, 40.61954763957432, 56.2060489654541, 65.35823699406215, 73.05436747414726, 72.9471915108817, 73.09638323102678, 72.52564430236816, 72.91395827702114, 70.54471288408551, 71.03792381286621, 70.69143799373082, 71.79304013933454, 70.57627160208565, 70.20618275233677, 65.3804851259504, 62.87676429748535, 60.63009902409145, 53.91728803089687, 51.73281955718994, 51.24815838677542, 51.26602220535278, 49.50380270821707, 49.833487783159526, 46.618545872824534, 43.00998503821236, 45.40937171663557, 46.80293369293213, 47.62182406016758, 44.765138217381065, 48.359694957733154, 57.72379262106759, 63.15688787187849, 62.703788893563406, 60.97572326660156, 57.91279057094029, 57.44957848957607, 56.97162233080183, 58.22817972728184, 60.959527015686035, 61.04543454306466, 57.404168537684846, 59.6013765335083, 56.87397929600307, 57.785225118909565, 61.26594257354736, 52.675936767033164, 54.64925643375942, 58.33275359017508, 57.91986036300659, 54.12898227146694, 53.21831662314278, 52.755781991141184, 49.892081941877095, 56.602259567805696, 54.812216009412495, 58.10360894884382, 57.051488399505615, 55.61990588051932, 57.47063847950527, 54.61218432017735, 57.32913841520037, 49.78191130501883, 43.83759192058018, 40.544347286224365, 54.92322390420096, 45.36439602715628, 48.340417180742534, 46.20464515686035, 52.74244492394583, 49.34528303146362, 41.75306633540562, 41.00532899584089, 53.74252693993704, 58.41947405678885, 54.11479752404349, 52.502721650259836, 51.19701269694737, 52.017671380724224, 47.34910031727382, 48.27299533571516, 48.78057166508266, 52.86728320802961, 59.404561860220774, 47.707123620169504, 53.69750608716692, 52.518608706338064, 52.8940372467041, 55.34064735685076, 53.13653632572719, 54.23703718185425, 53.690193108149934, 53.700125558035715, 55.02076619012015, 54.357730865478516, 53.82285853794643, 54.01403822217669, 51.86499513898577, 52.35750777380807, 48.301847730364116, 51.06466688428606, 45.422152927943635, 43.87760312216622, 41.593452317374094, 42.26405423028128, 43.24624810900007, 41.77370595932007, 42.76975107192993, 44.78518724441528, 44.76707329068865, 45.58132226126534, 45.28671864100865, 47.622838497161865, 46.89981589998518, 47.16847147260393, 48.781249114445274, 49.57255513327462, 55.90023095267159, 57.32183585848127, 59.30503586360386, 57.85039574759347, 57.57050493785313, 55.38114840643746, 54.580761092049734, 53.04428161893572, 54.62005662918091, 57.401423999241416, 60.56466783796038, 65.6773191179548, 71.32678822108677, 70.88313879285539, 74.89993408748082, 73.57865074702671, 81.01461287907192, 22.896013191768102, 0.24583114736846515, 0.8767834092889513, 0.5210100742323058, 11.285774844033376, 75.32961068834577, 64.47796971457345, 62.200510025024414, 34.569438457489014, 16.241749456950597, 9.456629429544721, 1.529729841010911, 0.7697449986423764, 0.17373677449566977, 0.03486923607332366, 0.0828928437882236, 0.024387842875772288, 0.45004008816821234, 0.40356111792581423, 0.1096191710925528, 0.14158180063324316, 0.15411526523530483, 0.10406418809933321, 0.16703621404511587, 0.30325263472540037, 0.19491150469652244, 0.3157291023858956, 5.764764904975891, 43.662629331861226, 63.86993285587856, 36.48722117287772, 34.93349279676165, 52.535572733197895, 66.88691016605922, 84.38353729248047, 76.77335602896554, 2.5751619892460957, 0.20177671845470155, 0.37557046275053707, 0.17484080525381224, 0.7504569622022765, 12.514796529497419, 77.98734528677804, 49.567972796303884, 65.90021732875279, 71.59259850638253, 82.36589159284318, 80.7626017161778, 76.69432026999337, 77.75396919250488, 75.6926679611206, 74.94838387625558, 74.06316253117153, 74.23932715824672, 77.054306438991, 74.99621527535575, 74.55996567862374, 72.82004642486572, 64.94089344569615, 63.39546816689627, 56.35466398511614, 55.062927859170095, 53.90163026537214, 54.45647866385323, 51.76987082617623, 52.533512592315674, 48.143995080675396, 45.83467442648751, 48.05021177019392, 48.907091413225444, 49.61712087903704, 46.77130896704537, 50.46058702468872, 60.69514805930001, 65.29078388214111, 63.498579433986116, 63.89919172014509, 60.60143770490374, 57.547304902757915, 57.64829349517822, 59.73446927751814, 62.714558601379395, 62.275217056274414, 59.4613355909075, 60.753165517534526, 57.6702880178179, 63.841896874564036, 62.76200090135847, 54.72086804253714, 61.274725096566335, 60.30183138166155, 61.3998829977853, 58.47036961146763, 58.318711280822754, 55.31946924754551, 52.078780787331716, 58.060554436274934, 56.0600152015686, 60.52741159711565, 58.45264475686209, 58.14234863008772, 61.439814295087544, 56.93175704138619, 59.08799498421805, 54.86486945833479, 43.97085836955479, 43.4259215763637, 57.60213313783918, 50.09380899156843, 49.38079527446202, 50.957848753247944, 55.37076779774257, 49.97096831457955, 41.21457052230835, 42.88630015509469, 56.533486298152376, 61.748752049037385, 56.37583862032209, 54.00253547940935, 54.62620578493391, 54.84478916440691, 49.07461248125349, 49.93084594181606, 51.478567600250244, 53.657668590545654, 57.52956962585449, 51.358335971832275, 58.82936218806675, 55.26923724583217, 55.89988701684134, 58.06257288796561, 53.441829749516074, 57.12309306008475, 55.44579792022705, 55.33606154578072, 57.10052183696202, 57.95928791591099, 54.89147758483887, 57.26562145778111, 52.48756068093436, 54.06988089425223, 49.89156777518136, 54.33795976638794, 49.05601910182408, 47.64864410672869, 44.651903424944194, 44.109214373997276, 46.92971747262137, 43.845023018973215, 46.956367288317, 47.85703100476946, 49.329180581229075, 49.33490242276873, 50.67536973953247, 50.57395730699812, 51.01067590713501, 51.203415461948936, 52.09268413271223, 52.43340294701712, 60.197476387023926, 58.91579777853829, 63.109403882707866, 59.23827757154192, 60.652235984802246, 59.204641342163086, 60.206078256879536, 55.6675739969526, 59.021577153887065, 60.43474347250802, 65.67986215863908, 68.10340772356305, 75.75930118560791, 75.06136853354317, 81.84486702510289, 76.60297925131661, 82.13068812234062, 24.40225236756461, 0.4653800278902054, 1.1230751190866743, 0.5882613626973969, 16.289879628590175, 84.41353266579765, 70.95398262568882, 74.14107268197196, 47.40220887320382, 27.972469568252563, 27.594093254634313, 0.6802847161889076, 1.6023117005825043, 0.29160216131380623, 0.20112323494894163, 0.13440060668757983, 0.3309697317225592, 0.543312597487654, 0.6614595491971288, 0.3290048571569579], [0.005876005544061107, 0.14558384088533266, 0.09495905560574361, 0.1332019745771374, 0.12575153793607438, 0.13862190874559538, 0.1569470361407314, 3.314108120543616, 27.589486598968506, 29.396824223654612, 18.947442259107316, 37.413117272513254, 42.05662965774536, 44.30183233533587, 65.14424637385777, 60.350225584847585, 3.0276621196951186, 0.20133271227989877, 0.13283160302255834, 0.0035053912101180424, 0.1087062293663621, 0.14219035155006818, 16.727491072246007, 21.735974958964757, 48.40367010661534, 57.84045287540981, 62.5181052344186, 63.42012732369559, 69.1714778627668, 64.81274087088448, 65.92414692470005, 67.53532995496477, 67.80927658081055, 68.07398210253034, 67.76656600407192, 65.6973855154855, 67.50823198046002, 62.41150597163609, 61.34843158721924, 56.731040954589844, 51.850525515420095, 48.42764833995274, 49.94613197871617, 46.49133825302124, 47.47397681644985, 46.91496297291347, 43.4208528654916, 41.14870159966605, 45.040564809526714, 44.72799662181309, 43.39132996967861, 42.35829612186977, 47.39224168232509, 57.48291594641549, 59.55815873827253, 56.40352719170706, 52.04847969327654, 54.43639489582607, 56.214456285749165, 60.09517805916922, 59.61342470986502, 57.35133443559919, 57.629522936684744, 54.007673672267366, 53.25205707550049, 55.32014669690813, 56.60890899385725, 53.77005222865513, 55.54357991899763, 51.33949245725359, 49.16116271700178, 54.282207420894075, 54.56897347314017, 49.56722933905465, 48.268079485212056, 52.4067496572222, 49.13656261989048, 55.848928928375244, 58.049982752118794, 54.49732364927019, 54.76950543267386, 57.60135841369629, 57.09742988858904, 51.39017609187535, 40.6938099861145, 46.564704281943186, 41.61282042094639, 40.88145303726196, 40.15399054118565, 43.20680318559919, 34.90920189448765, 43.12451219558716, 42.40766307285854, 35.850863456726074, 36.69640711375645, 40.37584999629429, 52.38363994870867, 51.36554472787039, 51.95247990744454, 50.742458071027485, 47.86434398378645, 43.194661208561485, 45.430685315813335, 38.98417098181588, 56.55394179480416, 48.58553225653512, 49.042265142713276, 53.18883889062064, 49.98858199800764, 52.287132944379536, 51.94780376979283, 54.088477747780935, 53.999228136880056, 50.426658970969065, 52.39441660472325, 53.52153600965227, 52.48095294407436, 52.94502312796456, 52.03510441098894, 51.047518730163574, 52.126483644757954, 51.188622747148784, 48.4256020954677, 45.69570003237043, 40.207488196236746, 39.98489918027605, 39.42531211035592, 40.242371627262656, 40.288535458701, 40.45282908848354, 41.630350725991384, 41.83121967315674, 44.400771209171836, 42.213103090013774, 44.01292276382446, 44.70997299466814, 47.13586705071585, 46.437979561941965, 46.766879490443635, 55.415573256356375, 57.41545588629586, 56.34757334845406, 55.785936559949604, 52.72675936562674, 51.6657520702907, 51.97788252149309, 48.46956334795271, 52.116724899836946, 53.26239946910313, 61.45648997170584, 62.91534764426095, 69.85588237217495, 65.47870486123222, 70.52593885149274, 66.41027763911656, 77.29501983097622, 26.264810800552368, 0.17631781314100536, 0.43306439050606316, 0.40460163780621117, 10.197593144008092, 64.62684876578194, 58.36472225189209, 50.33834389277867, 35.04373638970511, 9.50517909867423, 9.213696088109698, 0.8573791533708572, 1.2542123794555664, 0.25723772815295626, 0.1720194566462721, 0.1550917314099414, 0.19207522831857204, 0.4490641105387892, 0.23597824892827443, 0.08903502420123134, 0.007376533151338143, 0.1376401228564126, 0.0823661716920989, 0.09820841053234679, 0.027082261330048953, 0.11191915374781404, 0.17775043126727852, 4.610503230776105, 42.61602217810494, 45.13837807519095, 24.11021958078657, 36.09805256979806, 47.88215569087437, 56.887298992701936, 74.59351852961949, 72.74682630811418, 3.806766016142709, 0.303864700453622, 0.36343242121594294, 0.05601201745282326, 0.4250081442296505, 1.0852032027074268, 36.802606855119976, 38.30095114026751, 58.39567647661482, 68.9580430984497, 70.5779252733503, 71.79800810132707, 72.82161671774728, 69.29079232897077, 69.86715235028947, 69.52495356968471, 70.74847575596401, 71.65609809330532, 70.42109748295375, 68.6468402317592, 68.31017916543144, 63.86620167323521, 63.33889593396868, 57.66747399738857, 55.22711031777518, 50.570945262908936, 51.74973842075893, 49.9166716166905, 50.32126522064209, 47.43968745640346, 46.376091957092285, 45.373696190970286, 46.635780879429404, 46.10693611417498, 47.268897260938374, 43.43825462886265, 51.35796076910836, 59.4169157573155, 61.13312080928257, 56.52294588088989, 54.82260704040527, 56.37326431274414, 58.29767908368792, 59.75682858058384, 61.32182693481445, 61.85077939714704, 59.20044463021414, 57.236977509089876, 55.0276449067252, 57.66613299506051, 59.78630978720528, 56.636746951511924, 58.027797154017854, 54.579861300332205, 52.481213501521516, 59.14379596710205, 58.72832843235561, 53.67118978500366, 48.82568631853376, 52.02977166857038, 53.48854596274239, 57.75032779148647, 58.0027037348066, 55.82903970990862, 57.2962942804609, 57.92306695665632, 54.83650343758719, 51.36086164202009, 42.09661654063633, 49.12622022628784, 44.16689484460013, 40.04761362075806, 39.932884965624126, 43.14832714625767, 39.64090429033552, 44.457419872283936, 42.942611830575125, 35.275410175323486, 37.91191455296108, 40.72196756090437, 53.88703210013253, 55.47417436327253, 54.8903728212629, 51.01272562571934, 47.66717495237078, 44.931207111903596, 45.28949097224644, 41.86199671881539, 59.302722113473074, 50.794027600969585, 50.48260586602347, 55.41384315490723, 52.54111739567348, 53.35066590990339, 53.5364225251334, 55.72713048117501, 54.719346387045725, 50.40696777616228, 52.9364629473005, 53.744965757642476, 55.270738056727815, 55.12088973181588, 54.243679659707205, 53.324127265385215, 53.52801520483834, 52.50348595210484, 52.0765643119812, 47.21692473547799, 43.48051357269287, 42.46892186573574, 41.59929575238909, 41.910331862313406, 40.75026062556675, 43.78598417554583, 44.9727851322719, 44.5842661857605, 46.44719287327358, 44.31748315266201, 48.158614090510774, 47.432659353528706, 49.474727971213206, 47.87972034726824, 50.74300003051758, 58.53102738516671, 60.67346967969622, 60.07138047899519, 58.14025722231184, 56.09095205579485, 55.73095893859863, 55.9172922543117, 52.47485589981079, 58.06044326509748, 58.364083017621724, 67.00023528507778, 68.88585131508964, 73.52366965157645, 70.21551418304443, 74.11933871677944, 70.88884326389858, 77.26010513305664, 29.33550637108939, 0.1566554560725178, 0.514515788427421, 0.5079581003103937, 12.017863971846444, 72.64004639216832, 65.85319192068917, 65.77632399967739, 42.320946080344065, 18.07452964782715, 5.0728068351745605, 1.6253622408424104, 1.1317253006356103, 0.16352708877197333, 0.09934030193835497, 0.0903305918244379, 0.17339514568448067, 0.4770929536649159, 0.6088204309344292, 0.09797177822994334, 0.29903971936021534, 0.32324737895812305, 0.17493482306599617, 0.19231358409992286, 0.18346875799553736, 0.26909466620002476, 0.2599696729864393, 6.18004092999867, 54.968651226588655, 62.73306165422712, 32.00379180908203, 52.298020771571565, 58.95212990897042, 66.11832128252301, 81.80144078390938, 82.67582293919155, 5.53971666097641, 0.34822449726717813, 0.6803849765232631, 0.10199861215161425, 0.6736780649849347, 0.8208322801760265, 44.06742443357195, 50.50006668908255, 71.95007637568882, 76.74502127511161, 79.20642062595913, 75.92484896523612, 81.30541583469936, 71.38966941833496, 73.04363945552281, 72.8360481262207, 74.02496133531842, 74.14628383091518, 75.12255437033517, 70.38096468789237, 71.66972351074219, 66.96043600354875, 67.11413710457938, 61.731798444475444, 58.828000341142925, 52.92410210200718, 54.10598373413086, 52.080219064440044, 52.66228008270264, 50.99181849615914, 50.14318983895438, 47.9028126852853, 49.68777363640921, 49.249783515930176, 49.76595476695469, 45.74223559243338, 52.57972158704485, 62.76795550755092, 62.72322995322091, 58.893077169145855, 58.54893984113421, 54.50223255157471, 59.08389554704939, 62.545877184186665, 64.1501328604562, 63.39092404501778, 62.32347924368722, 59.82604653494698, 59.45999458857945, 60.233294350760325, 60.81572709764753, 60.00264889853341, 60.185872895377024, 56.50885146004813, 55.57371078218733, 59.621109417506624, 56.6161698613848, 58.25663954871041, 53.056607723236084, 56.10545294625418, 57.1047602381025, 59.0722781590053, 64.150118964059, 58.69837474822998, 58.03270953042166, 60.43700858524868, 56.52292503629412, 53.69079760142735, 44.30996520178658, 48.941787242889404, 44.61998687471662, 39.84457336153303, 40.797226973942344, 44.565561635153635, 40.60694708142962, 46.86036055428641, 44.074202401297434, 37.59193958554949, 38.28264611107962, 43.55182293483189, 56.87683153152466, 53.99019200461251, 57.55839770180838, 52.760447706495015, 48.66587427684239, 46.23511300768171, 48.82131242752075, 44.551540170397075, 58.90404837472098, 53.48210845674787, 54.65856007167271, 57.51252222061157, 53.05834477288382, 54.13996737343924, 56.23011752537319, 58.72152614593506, 58.0728041103908, 52.74874346596854, 54.128867626190186, 57.88264581135341, 58.63450690678188, 56.87320804595947, 57.26897396360125, 56.43766369138445, 57.34456689017159, 54.24165425981794, 54.667710849217, 49.8835460799081, 45.073547908238, 45.73841060910906, 44.30986097880772, 46.4068238394601, 44.77822514942714, 45.82852527073452, 47.419374397822786, 47.606305258614675, 49.61366415023804, 46.17582402910505, 50.866994108472554, 50.75384269441877, 52.77134248188564, 51.282350472041536, 51.886506761823384, 60.4482855115618, 63.667226110185894, 61.59398092542376, 61.66499151502337, 58.47177314758301, 58.70470455714634, 59.81422070094517, 55.7662627356393, 60.16288825443813, 61.651442527770996, 70.07971164158413, 72.18810081481934, 78.76001971108573, 74.77148274012974, 79.44370855603898, 72.44217559269497, 79.19576903751918, 31.602366583687918, 0.19600431248545647, 0.6547290246401514, 0.566548187817846, 12.936555658067975, 83.26446042742047, 73.37274782998222, 77.70621422358921, 58.35711397443499, 34.01605265481131, 26.1457290990012, 1.5695382420505797, 2.4085376730987003, 0.30013786043439594, 0.3376783531691347, 0.24855888528483255, 0.6842214135187012, 0.5661916040948459, 0.8666592868311065, 0.2603812723287514], [0.10938054389719452, 0.11468218905585152, 0.08479544919516359, 0.1419789336089577, 0.10828886247639145, 0.09671154871050801, 0.08965925606233732, 1.4246205325637544, 32.566165106637136, 30.174529143742152, 27.32030122620719, 24.47363989693778, 41.678046635219026, 49.03142942701067, 63.56820733206612, 62.62573977879116, 7.476337245532444, 0.454267361334392, 0.07977713990424361, 0.015937929241252796, 0.05976200569421053, 0.31743673075522694, 10.594593235424586, 29.93611560549055, 52.980108056749614, 53.99324573789324, 62.53435012272426, 62.381489753723145, 66.26083578382219, 64.95774977547782, 67.35013266972133, 68.33467851366315, 69.21065180642265, 66.5449823651995, 65.45252404894147, 65.90606771196637, 66.24024132319859, 63.607013021196636, 60.171552658081055, 59.349782262529644, 52.017216273716514, 47.333056926727295, 51.04280437741961, 48.83823823928833, 49.415824617658345, 45.820256914411274, 42.025060517447336, 42.37599318368094, 42.209406648363384, 45.57858119692121, 45.151940958840505, 41.969120570591514, 48.74123443875994, 61.06606374468122, 59.68517875671387, 52.07531016213553, 58.085449831826345, 58.671554701668875, 57.15474557876587, 58.188085147312705, 53.38512897491455, 55.21929359436035, 51.922995226723806, 52.06335231236049, 49.299734115600586, 46.86336217607771, 48.86503049305507, 54.372728552137104, 54.68111045019967, 57.57476070949009, 52.091624532427105, 54.087654386247905, 52.09498746054513, 56.15679318564278, 52.904869488307405, 47.53228957312447, 51.206698485783164, 49.44658081872122, 57.01910979407174, 52.95645638874599, 56.72312348229544, 52.76127454212734, 42.47376128605434, 41.88790307726179, 49.5844087600708, 45.456539562770296, 41.564895221165244, 44.71628543308803, 39.21147435052054, 43.28853484562465, 39.33322763442993, 36.77005454472133, 39.10508005959647, 37.72376080921718, 35.894581522260395, 37.89689254760742, 39.18866341454642, 50.84180688858032, 54.032815728868755, 51.97744825908116, 47.14173827852522, 42.527793952396934, 41.29879658562796, 52.40433168411255, 51.94639675957816, 42.65735353742327, 55.84426668712071, 51.24106427601406, 52.870844159807476, 49.85588877541678, 53.966488225119456, 52.76340069089617, 50.975924491882324, 50.13783277784075, 51.39291020802089, 52.87258815765381, 51.37740877696446, 47.25285734449114, 49.09027719497681, 56.19704410008022, 53.227915559496196, 53.41267510822841, 51.214973790305, 44.61920172827584, 42.363976274217876, 42.37579863412039, 39.849232128688264, 39.97506053107125, 39.42359937940325, 41.76381172452654, 41.501954964229036, 41.2993072782244, 43.30159745897566, 44.96300206865583, 44.02897310256958, 46.526621205466135, 45.79307903562273, 45.62783350263323, 47.832493441445486, 55.48412070955549, 56.80710288456508, 56.62628991263253, 57.14952400752476, 53.49953801291329, 49.982856682368684, 50.011611802237375, 49.66575826917376, 54.105618953704834, 57.349458421979634, 64.23174640110561, 65.59984670366559, 66.26296888078961, 62.679352079119, 68.4926597050258, 70.63431685311454, 77.07902118137905, 54.272809982299805, 0.10701580185975347, 0.2436909664954458, 0.1792222551469292, 9.61696606022971, 64.44877338409424, 55.198028632572715, 52.15402977807181, 37.15877151489258, 11.294987286840167, 5.854116567543574, 2.6654955191271643, 1.2929539063147135, 0.06992795983595507, 0.14550081534045084, 0.04781724485967841, 0.26301857509783333, 0.054315262607165744, 0.2606871287737574, 0.06937658906515155, 0.060652033292821476, 0.023092675588226745, 0.11598796184573855, 0.05427091695102198, 0.10937625555587666, 0.043080571706273725, 0.15127738751471043, 2.7263491451740265, 47.04752765383039, 43.16326229912894, 35.25744908196585, 34.74247292109898, 46.318147454942974, 61.76360034942627, 70.38540458679199, 77.00860118865967, 8.726894004004341, 0.6057399905153683, 0.22538311460188457, 0.029721587829824005, 0.0578469695257289, 0.16099319473973342, 23.537823506764003, 43.46203483854021, 63.986850193568635, 64.59442847115653, 72.13742065429688, 69.77478994641984, 72.2718266078404, 67.41520254952567, 71.33412551879883, 71.37341758183071, 71.65282549176897, 69.26245757511684, 71.47921085357666, 68.95768179212297, 69.04903670719692, 67.0312728881836, 64.35691125052315, 61.46338258470808, 53.58109596797398, 49.36237212589809, 51.3746121270316, 50.568054812295095, 50.18888814108712, 48.228863852364675, 44.578954287937705, 43.66482148851667, 45.71733324868338, 47.60448135648455, 45.70990562438965, 44.33720908846174, 50.95825522286551, 62.33323451450893, 60.22544983455113, 59.027107919965474, 59.56596156529018, 60.669272967747276, 58.178079741341726, 59.6086026600429, 56.772476536887034, 58.76505661010742, 53.94993414197649, 55.13092640468052, 52.96291126523699, 49.807049887520925, 50.51046119417463, 58.600259235927034, 56.98365661076137, 57.64289474487305, 56.96033845629011, 57.251735482897075, 53.689473969595774, 61.577909742082866, 57.94945968900408, 49.73221778869629, 51.62318740572248, 52.575239998953684, 59.337609018598286, 54.263197149549214, 58.90876620156424, 51.61188268661499, 40.92034905297415, 45.16688305991036, 51.05424806049892, 45.82016658782959, 41.883421489170615, 45.80033642905099, 42.32628229686192, 45.34950256347656, 38.91179854529244, 38.87682131358555, 39.9412054334368, 41.512047222682405, 38.55842011315482, 36.93342753819057, 38.842969690050396, 51.48052699225289, 55.2291704586574, 52.96445376532418, 47.7692995752607, 43.98446989059448, 44.3254840033395, 55.2945043700082, 53.43554857798985, 46.041230474199565, 57.680130141122, 53.0910256249564, 53.75330012185233, 51.06313133239746, 54.288075174604145, 53.27222074781145, 53.506437574114116, 52.93353428159441, 53.29694243839809, 56.05987276349749, 51.147204535348074, 48.41604484830584, 53.936645712171284, 55.44589866910662, 55.10656254632132, 54.585829802921836, 54.03622382027762, 48.275649547576904, 43.47670248576573, 42.82589251654488, 43.19181592123849, 40.4218053817749, 41.79031562805176, 43.96681104387556, 43.21769448689052, 44.50362886701311, 46.019517353602815, 45.17428983960833, 45.85423013142177, 48.31880480902535, 49.45457124710083, 47.944057192121235, 50.95928355625698, 57.90244122913906, 60.859882899693076, 59.62195014953613, 59.707822935921804, 55.901981898716514, 54.744985239846365, 53.27548292704991, 53.95518350601196, 57.133595262254985, 64.62799521854946, 68.23754964556012, 71.04098796844482, 69.11750425611223, 69.09903594425747, 70.74500860486711, 76.49560873849052, 78.27258968353271, 61.74272796085903, 0.5605241539222854, 0.4731222210185868, 0.13295466213354043, 9.971871359007698, 72.778628213065, 62.69645159585135, 64.3916939326695, 43.239407607487266, 22.317806686673844, 12.740509629249573, 5.574824171406882, 1.1141771908317293, 0.09697952254542283, 0.10805879160761833, 0.03962886406640921, 0.2722014880606106, 0.29371837632996695, 0.31570961486016, 0.19409600059900964, 0.20432758943310805, 0.17131065896579198, 0.38130755775741165, 0.1992909868380853, 0.2017276468021529, 0.11621908444379057, 0.317088886563267, 4.6620310715266635, 59.998111724853516, 62.61007159096854, 40.98864984512329, 38.73835066386631, 57.584126881190706, 74.03814901624406, 76.97616699763707, 89.8462666102818, 10.907058068684169, 0.6957180223294667, 0.7316057937485831, 0.14063411791409763, 0.45893101394176483, 0.5142322150724274, 39.95297220775059, 56.4309378351484, 78.10808413369315, 70.6428006035941, 81.13015447344098, 74.76703589303153, 75.9655932017735, 70.57482637677873, 74.8911098752703, 75.74672494615827, 76.070663860866, 73.37672914777482, 72.67912306104387, 70.32697023664201, 70.24282755170549, 68.89023562840053, 67.6234678540911, 65.26351220267159, 55.962903703962056, 52.66948536464146, 55.3859600339617, 53.24687024525234, 55.21276923588344, 51.067369733537944, 47.188478810446604, 46.48312200818743, 47.61685957227434, 50.38581051145281, 49.47422422681536, 45.58208656311035, 53.65807853426252, 63.87162821633475, 63.25837326049805, 58.98532840183803, 59.22795254843575, 61.72006293705532, 63.69920172010149, 61.779768807547434, 58.13921499252319, 59.74980395180838, 56.969166142599924, 56.866812229156494, 56.256472042628694, 52.90847212927682, 55.425589084625244, 59.671567235674175, 62.047906739371165, 65.04973697662354, 58.90575763157436, 61.298057147434776, 57.70222193854195, 57.77852010726929, 53.80018309184483, 53.342102255140034, 55.83493178231375, 55.56817306791033, 63.401603426252095, 56.724593026297434, 61.64764881134033, 52.77557046072823, 44.23080437523978, 45.27369771684919, 52.10034799575806, 48.82741641998291, 42.19098349979946, 45.66530166353498, 40.632387910570415, 44.93610906600952, 38.27088975906372, 37.71541254861014, 40.47321162905012, 38.963253429957796, 38.98239919117519, 37.121775831495015, 39.438499791281565, 55.197736808231895, 57.712522642953054, 52.732071263449534, 48.89116961615426, 45.16007729939052, 46.823448249271934, 54.89156791142055, 55.12722996303013, 50.6585933140346, 61.240046637398855, 55.64182397297451, 55.99867997850691, 53.02928393227713, 56.72503423690796, 55.89831672395979, 56.36492647443499, 52.87646525246756, 55.69168424606323, 57.53272063391549, 52.952829429081504, 52.07913514545986, 57.46712269101824, 55.544920921325684, 58.49432700020926, 58.93129226139614, 56.36260577610561, 49.93391009739467, 47.63458442687988, 47.02796152659825, 46.72412722451346, 44.41972936902727, 46.49629579271589, 48.63053573880877, 47.01573269707816, 48.44673504148211, 48.34112589699881, 50.166351658957346, 49.30542469024658, 52.77553571973528, 52.65680490221296, 51.10630743844168, 53.83135271072388, 59.93403543744768, 64.79976163591657, 62.71742125919887, 63.97064699445452, 58.30696882520403, 57.93729339327131, 57.249824728284565, 57.40158380780901, 61.606473786490305, 69.29705265590123, 71.8511687687465, 75.3162979398455, 73.29235717228481, 73.92364270346505, 75.08753544943673, 77.70830563136509, 78.83377483912876, 60.21814032963344, 0.6382943636604718, 1.0443331386361803, 0.16735488123127393, 12.608206374304634, 80.52636296408517, 69.06350285666329, 77.80912399291992, 57.72957352229527, 38.790062631879536, 32.23307541438511, 6.630256840160914, 2.28833253468786, 0.23773258764828953, 0.3295594373983996, 0.10303092175828558, 0.41315967429961475, 0.3081533946096897, 0.44774018015180317, 0.2905948625079223], [0.08472041000745126, 0.13649707633469785, 0.1718966689492975, 0.12459444573947362, 0.10686159799141542, 0.057667795568704605, 0.03929706044229014, 2.2448122756821767, 36.71297856739589, 29.571578366415842, 12.800948534693037, 27.414263452802384, 47.890966006687705, 48.691916125161306, 68.20574079241071, 66.28650937761579, 11.257529548236302, 0.4594486547367913, 0.19435406103730202, 0.035944018579487286, 0.17529941350221634, 0.8227348380855152, 24.84622836112976, 36.7416398865836, 55.13727705819266, 56.02450295857021, 61.68226473672049, 62.96289416721889, 65.94293485369, 64.07229913984025, 66.85455935341972, 67.7512869153704, 67.2234948022025, 65.78879601614815, 66.21831280844552, 64.8699037006923, 65.97397940499442, 62.55642454964774, 62.527971676417756, 56.432417801448274, 51.62087712969099, 49.855867930821006, 50.12425947189331, 48.753081117357524, 48.57706935065133, 43.377579484667095, 39.93939542770386, 41.57627637045724, 43.71776328768049, 44.699634075164795, 42.937845366341726, 41.63508244923183, 48.90437466757638, 58.93440505436489, 57.77724858692714, 61.64497375488281, 58.75166048322405, 52.07419845036098, 56.140770639692036, 54.46059199741909, 50.920179094587056, 51.77445663724627, 48.6601037979126, 47.45529311043875, 47.34097439902169, 46.61989034925188, 48.20102589470999, 46.359722001211985, 48.62297262464251, 51.060810634068076, 54.31038236618042, 54.49033376148769, 51.34692702974592, 48.820433480399, 59.662117685590474, 49.11257743835449, 43.64808675221035, 55.51757628577096, 51.92621571677071, 58.76484816414969, 51.25365441186087, 42.52385432379586, 41.30844415937151, 44.294258798871724, 42.675408431461875, 40.60602297101702, 40.556312084198, 42.938554082598, 44.40844896861485, 44.3703658921378, 40.24951090131487, 42.64145605904715, 45.328407832554404, 44.80956152507237, 40.41282830919538, 37.42736107962472, 36.795540537152974, 39.65699979237148, 49.45520353317261, 55.3294677053179, 45.73994268689837, 39.25376456124442, 46.35618189402989, 56.5558351789202, 44.96395397186279, 51.89296511241368, 54.34436253138951, 49.05239561625889, 50.42159720829555, 50.075333731515066, 51.62199231556484, 52.23210668563843, 52.17096601213728, 52.179307324545725, 53.44448396137783, 53.90397875649588, 48.376228196280344, 49.82053286688668, 53.58464649745396, 52.558407987867085, 50.084053720746724, 53.90946435928345, 51.29215438025338, 50.096557004111155, 41.43332065854754, 39.05886064256941, 41.0874080657959, 38.16400214603969, 40.27340228216988, 37.15285859789167, 39.08619485582624, 41.41439723968506, 40.30202886036464, 43.855827467782156, 43.88005583626883, 41.76177937643868, 44.43349722453526, 45.5885066986084, 49.47971330370222, 54.1349264553615, 55.31828110558646, 55.455886704581125, 56.30708966936384, 52.55180719920567, 52.15709393365042, 50.91584341866629, 50.96224001475743, 52.33697237287249, 60.32951995304653, 62.8528277533395, 67.86281939915249, 63.58088779449463, 71.55912903376988, 66.83380508422852, 77.44539969308036, 68.27386093139648, 84.84017985207694, 14.829686164855957, 0.322866856519665, 0.1514703357326133, 8.311634046690804, 67.42941856384277, 55.32741451263428, 51.07242454801287, 35.468858446393696, 11.83793602670942, 5.081461685044425, 7.230023171220507, 0.8798836629305566, 0.14952560008636542, 0.11773255680288587, 0.03383128105529717, 0.019942556408100894, 0.14674554712006024, 0.02305605505327029, 0.10723635966756515, 0.008268252846651843, 0.13534280684377464, 0.06720038476799216, 0.131589856797031, 0.04396290132509811, 0.10220518535269157, 0.23837844442043984, 3.947822264262608, 52.085117544446675, 45.66814347675869, 18.537931067602976, 27.01932089669364, 56.71524769919259, 60.63445554460798, 74.4882880619594, 77.54575252532959, 15.563973528998238, 0.5586782672575542, 0.38362033079777447, 0.0555200592082526, 0.17797182367316314, 1.0282656465257918, 35.75883109228951, 52.03172063827515, 67.97236469813755, 63.77984251294817, 67.00580079214913, 66.97049004690987, 69.10927064078194, 65.84962749481201, 70.0408364704677, 71.13505962916783, 71.7415748323713, 67.86594608851841, 70.58676338195801, 68.9676594052996, 68.0143735068185, 65.45720018659318, 66.29889106750488, 59.44971125466483, 54.7554144859314, 51.061658314296174, 52.92411599840437, 49.883473123822895, 50.04489714758736, 46.80442060743059, 43.84225068773542, 44.114050320216585, 45.263195514678955, 46.20696585518973, 44.57653284072876, 42.459253447396414, 51.339530672345845, 60.34595244271414, 59.17436804090227, 62.453598158700125, 61.02536814553397, 55.9513384274074, 57.958572251456125, 56.803878920418875, 54.91561562674386, 55.19011810847691, 50.13353879111153, 48.690286772591726, 47.9421568598066, 50.136199951171875, 50.41833502905709, 48.907685484204976, 53.303032534463064, 53.819148199898855, 54.950422627585276, 58.2472699029105, 54.34308753694807, 52.43907962526594, 62.61419882093157, 54.75997597830636, 44.33282824925014, 56.605751037597656, 54.92086499077933, 60.77649062020438, 50.428107670375276, 43.94170025416783, 43.42064094543457, 43.068770272391184, 43.53812803540911, 44.55361073357718, 42.370896680014475, 44.333137444087434, 47.77123464856829, 45.40468168258667, 41.17722742898123, 43.06304495675223, 46.0950790132795, 42.364063126700266, 39.93494858060564, 38.29676137651716, 38.179517473493306, 40.39396742412022, 53.357923303331646, 56.88081284931728, 46.1889283316476, 40.17342812674386, 50.06369202477591, 56.52695151737758, 47.57185609000069, 53.51650203977312, 56.98877395902361, 50.24399083001273, 51.13068519319807, 52.61207587378365, 53.966634137289866, 51.58034481321062, 54.648763111659456, 54.2050198827471, 54.90222992215838, 53.87218032564436, 53.29287426812308, 52.30991956165859, 52.99789891924177, 53.27083110809326, 52.86765146255493, 55.64523206438337, 54.82252366202218, 52.80529138020107, 44.42689643587385, 40.56757164001465, 42.64442293984549, 39.079180649348665, 42.62170580455235, 39.545502049582346, 41.87398583548409, 43.279377119881765, 44.74695825576782, 46.799515179225374, 46.60671656472342, 45.253162315913606, 47.886164801461355, 48.39915377753121, 52.82749434879848, 58.47591427394322, 59.567448479788645, 57.23579978942871, 59.414775712149485, 54.4928594316755, 56.82412249701363, 54.260942459106445, 55.465506485530305, 56.42817940030779, 65.61817605154855, 67.82705007280622, 72.65523515428815, 68.5514553615025, 76.78632831573486, 70.11470971788678, 83.57493373325893, 69.20041710989815, 90.20580809456962, 19.70323256083897, 0.34180091481123653, 0.11714673680918557, 8.628875766481672, 79.13684136526925, 60.88836356571743, 66.70109449114118, 42.128380230494905, 25.82448434829712, 15.829394715172903, 5.705047743661063, 0.9399776011705399, 0.06875523419252463, 0.0336211150112961, 0.08066834136843681, 0.12392876217407839, 0.21541056329650538, 0.09160608159644262, 0.0919356799817511, 0.13465425664825098, 0.14824243608329976, 0.1740049043936389, 0.2583475128880569, 0.18962321989238262, 0.22260948057685578, 0.4172948838344642, 6.594474051679883, 62.970683097839355, 60.86342648097447, 24.502579144069127, 37.26634699957711, 67.99072878701347, 71.92504896436418, 81.14587129865373, 87.49270330156598, 20.162786415645055, 0.7302209309169224, 1.353190771171025, 0.21616896188684873, 0.6366020973239626, 1.9430498395647322, 56.42198160716465, 62.772708075387136, 79.52664920261928, 72.16947269439697, 74.9847229548863, 70.85686765398297, 75.61784281049455, 68.99250616346086, 72.66576167515346, 74.48020730699811, 76.4046151297433, 72.9663199016026, 75.45695727212089, 70.36538682665143, 70.4443531036377, 68.01957075936454, 69.56333541870117, 60.721308026994976, 57.27750982557024, 54.93705429349627, 56.484504972185405, 53.83534445081438, 53.4954594203404, 48.60348640169416, 46.395196029118125, 47.06602723257882, 48.35031836373465, 49.26979085377285, 46.70490850721087, 44.01032066345215, 52.42495393753052, 61.75798620496477, 59.991587366376606, 61.69680731637137, 63.915290696280344, 58.507966314043315, 60.121268544878276, 58.770351137433735, 57.98912000656128, 57.90521008627755, 52.770883900778635, 52.60453013011387, 52.53294284003121, 52.96387011664254, 53.87876374380929, 53.11883231571743, 54.76320341655186, 58.18029274259295, 60.72633157457624, 63.1475772857666, 59.756349154881065, 61.186906814575195, 59.2082405090332, 49.035521915980745, 46.12104095731463, 56.88526317051479, 57.8187849181039, 64.04855019705636, 55.412752287728445, 43.91093363080706, 43.31074128832136, 43.6552677154541, 47.82612541743687, 44.4177873475211, 43.30018697466169, 45.05148390361241, 47.25282260349819, 44.88449437277657, 40.661056177956716, 44.01302351270403, 47.376583916800364, 44.843020575387136, 39.243561131613596, 38.57674598693848, 37.95175552368164, 41.32531785964966, 56.2112010547093, 58.770934786115376, 49.995102882385254, 40.88748754773821, 50.15679441179548, 60.8640170778547, 51.100272927965435, 57.34491082600185, 60.01934541974749, 53.077573912484304, 53.62455695016043, 52.85959850038801, 57.51204626900809, 55.59782797949654, 55.30648306437901, 56.472877161843435, 57.07104410443987, 58.759435517447336, 55.93313067299979, 53.69879845210484, 55.44997031348092, 54.62295750209263, 56.68405376161848, 56.90763289587838, 56.370429447719026, 53.49883277075631, 48.009029797145296, 44.689625195094514, 46.19349677222115, 41.463805879865376, 47.37716061728341, 41.64573403767177, 45.72689396994454, 46.471893719264436, 46.68224695750645, 50.28248037610735, 49.859005042484824, 48.187119075230186, 48.794697352818076, 51.20777545656477, 55.02346903937203, 62.25838157108852, 62.64751543317522, 59.21191610608782, 62.29416479383196, 57.939207621983115, 59.05126680646624, 56.66194806780134, 57.85139281409127, 58.72766835348946, 68.6292473929269, 71.1761165346418, 75.31258065359933, 72.27077048165458, 79.73647785186768, 73.17552321297782, 86.75438771929059, 71.95841421399797, 90.51408576965332, 18.019110815865652, 0.8250564049397195, 0.3356781676411629, 9.966588991028921, 85.72072505950928, 68.56344795227051, 78.25205080849784, 53.97841133390154, 40.13855859211513, 36.52678768975394, 10.17154608454023, 2.17999752504485, 0.3344991723341601, 0.3277118136840207, 0.13854466431907245, 0.23096941198621476, 0.4026990798967225, 0.23867922542350634, 0.17666482952024254], [0.08671716214822871, 0.10438094181673867, 0.1281343222196613, 0.15837494523397513, 0.050830788511250696, 0.11606180002646786, 0.10649547406605311, 4.5031470486095975, 46.72545085634504, 26.550345284598215, 23.199017184121267, 39.22725370952061, 42.64179304667881, 51.58376680101667, 62.99648870740618, 64.33096667698452, 32.04736396244594, 0.28989035316876, 0.16825892057801994, 0.09823281743696757, 0.27707117104104584, 6.405804838453021, 43.33862440926688, 46.34780584062849, 60.760016441345215, 57.49100712367466, 60.23947129930769, 60.19904667990548, 61.77565547398159, 63.0199875150408, 65.60329301016671, 65.9442480632237, 66.4607354572841, 66.5366028376988, 68.95075443812779, 63.15972968510219, 64.73328821999687, 62.53205721718924, 63.53568976266043, 58.32561084202358, 48.56770665305001, 48.86089631489345, 49.12031773158482, 46.995075702667236, 47.25160666874477, 40.475428104400635, 41.7749079976763, 42.70431293760027, 45.994667121342246, 47.16763768877302, 45.6676675251552, 42.56482785088675, 52.16854109082903, 57.75510467801775, 58.05059766769409, 54.719190052577424, 56.05281686782837, 55.96937247685024, 52.946134839739116, 50.361067976270405, 47.41972875595093, 46.262975284031455, 45.945095198495046, 45.64068419592721, 43.71001257215227, 44.49663897923061, 47.012876987457275, 46.0521183013916, 47.90473733629499, 50.337579590933665, 50.36323928833008, 52.93737663541521, 56.07089608056204, 50.18154042107718, 41.5902214050293, 47.816550799778526, 50.30297408785139, 52.521989004952566, 56.10799946103777, 46.98331935065133, 38.55191659927368, 42.314772605895996, 46.028049741472515, 47.712689127240864, 43.31919724600655, 46.910470962524414, 48.96564735685076, 42.324204785483225, 44.220333439963206, 45.51414360318865, 41.149677821568076, 46.212649481637136, 46.692328793661936, 40.91310208184378, 44.54522773197719, 39.938030106680735, 36.925496169498985, 36.87904051371983, 44.34985133579799, 50.42450850350516, 43.559973171779085, 44.79295185634068, 54.35229390008109, 48.757892744881765, 43.76237072263445, 56.09284543991089, 49.590721198490684, 49.72576291220528, 47.9858957699367, 52.63684967585972, 53.35781560625349, 50.71751403808594, 52.77741868155343, 51.62699154445103, 51.78139441353934, 51.32883044651577, 55.33488730021885, 54.57578270775931, 52.95899942943028, 45.544906752450125, 49.502079554966514, 51.91729422977993, 52.059166022709434, 49.32512630735125, 44.071516922542024, 39.31596483503069, 39.69312695094517, 37.29308366775513, 39.1886807850429, 37.11537306649344, 38.45637886864798, 39.82555614198957, 42.08989763259888, 42.77031735011509, 43.80822535923549, 42.02896193095616, 47.2572729246957, 45.59752893447876, 49.5976277078901, 54.18853528159005, 55.66690696988787, 53.73179544721331, 54.378551142556326, 52.972913197108674, 51.14853858947754, 50.00215530395508, 50.128859179360525, 53.961068630218506, 61.612629890441895, 64.97669751303536, 68.18263108389718, 67.53855391911098, 68.68805694580078, 67.30095332009452, 72.71101529257638, 67.43363612038749, 79.68314347948346, 55.43814447947911, 0.8948095334427697, 0.23483326179640635, 8.111459050859724, 69.03209699903215, 54.390571526118684, 49.162708691188264, 37.35262972967965, 17.95066237449646, 7.7093885115214755, 11.018865874835424, 1.2804026369537627, 0.09098018053919077, 0.12964465974697045, 0.06602975579776935, 0.05536399954663856, 0.07182190035070692, 0.018959177657961845, 0.04840297664382628, 0.06614952401391097, 0.06625929740922791, 0.15474759201918328, 0.0713436213721122, 0.06640653950827462, 0.13900988149855817, 0.11947318911552429, 8.225097707339696, 62.18502943856375, 39.92874731336321, 27.407245772225515, 36.78288786751883, 53.541501658303396, 58.54937757764544, 74.13172735486711, 75.06744125911167, 34.217908246176584, 0.2593803788934435, 0.34735941940120285, 0.20953434146940708, 0.5861864568931716, 6.117378166743687, 55.62631559371948, 56.38511446544102, 70.51518998827252, 65.53611087799072, 68.84434277670724, 66.19947624206543, 67.5788882119315, 68.12585735321045, 70.06687137058803, 68.86275550297329, 71.39358125414167, 68.63418061392647, 69.99292864118303, 66.20935658046177, 68.0935343333653, 65.79851654597691, 65.32155745370048, 60.65339633396694, 51.489236559186665, 53.13192272186279, 51.52724320547921, 51.30240297317505, 49.81635005133492, 44.75296149935041, 44.67290782928467, 46.59780550003052, 49.415737765175955, 48.58711991991316, 45.26591573442732, 43.881250926426475, 52.04762159075056, 56.103208678109304, 59.5677125113351, 56.71868705749512, 58.28843103136335, 56.35029704230172, 54.2362311908177, 51.732590266636436, 48.281704902648926, 49.156629017421174, 48.93933800288609, 47.514901706150596, 46.107370376586914, 46.911339487348286, 49.17585120882307, 48.621426650456016, 48.813030174800325, 50.55236577987671, 51.933403628213064, 55.859743799482075, 59.23920863015311, 54.451361315590994, 42.55763646534511, 52.02087450027466, 54.30686657769339, 56.280613558632986, 57.58300822121756, 47.63572045734951, 41.40110533578055, 42.875012806483674, 46.605632645743235, 52.07963194165911, 47.33863285609654, 49.22305727005005, 51.78671325956072, 43.73083979742867, 44.655832631247385, 46.30512653078352, 43.35812452861241, 48.457727091653005, 46.89027949741909, 44.26072679247175, 45.85852411815098, 40.87418174743652, 37.785373960222515, 36.28092220851353, 45.97043180465698, 50.564743995666504, 44.46028600420271, 46.280752250126426, 54.68283707754952, 50.996675286974224, 46.179391929081504, 56.19657857077462, 52.571540083204, 51.497817584446494, 50.665100302015034, 54.744985239846365, 53.53641210283552, 53.04939896719796, 52.2406599181039, 52.54062754767281, 54.15645544869559, 56.60889509746006, 55.9960744040353, 53.58171435764858, 53.42075933728899, 48.55817025048392, 51.747820717947825, 53.825443267822266, 54.90191030502319, 52.796738147735596, 46.82622058050973, 41.520819323403494, 41.51683800561087, 41.098132610321045, 41.01612997055054, 40.94936473029, 41.681089946201865, 40.33611672265189, 45.69945553370884, 45.62899732589722, 46.243596758161274, 45.029888902391704, 49.996568952287944, 48.40929467337472, 52.15256370816912, 57.42815024512154, 59.27182347433907, 57.48476069314139, 58.67317363194057, 56.6062513078962, 54.77244452067784, 54.00261885779244, 54.26871749332973, 56.14826774597168, 64.30210386003766, 69.20786557878766, 73.04161752973283, 72.66577557155064, 73.1805398123605, 70.64981133597237, 76.47018527984619, 72.55555629730225, 81.76970836094448, 63.59098352704729, 1.1880425129617964, 0.24683527063046182, 9.54160589831216, 78.58557823726109, 61.48901448931013, 62.570168086460654, 46.36458226612636, 29.21991613933018, 23.356732606887817, 5.273148153509412, 1.9546622335910797, 0.13304873422852584, 0.1430395652673074, 0.06020886171609163, 0.12560086244983332, 0.03484722100464361, 0.14438860144998344, 0.06010076430227075, 0.19859025015362672, 0.2359422051480838, 0.1937358613525118, 0.29376701372010366, 0.16538942312555655, 0.24540402314492635, 0.28889491515500204, 12.302118250301906, 80.83234078543526, 52.93655327388218, 40.35260132380894, 51.34183400017874, 59.859286717006135, 68.71046488625663, 78.08226462772915, 82.96491663796562, 42.41619546072823, 0.3302806115576199, 0.6311910248228482, 0.19723575854940073, 0.9903345618929181, 12.002863679613386, 75.63570662907192, 62.476853779384065, 81.41345337459019, 71.1204058783395, 74.9927203314645, 69.77541528429303, 71.61148371015275, 70.22249712262834, 76.11998912266323, 70.30003901890346, 75.96295288630894, 70.03411061423165, 74.53288854871477, 67.74725696018764, 70.07875279017857, 68.59977313450405, 67.72540487561906, 64.08390263148716, 53.920095103127615, 55.12280396052769, 55.36530998774937, 53.66046871457781, 52.876169954027446, 47.38458129337856, 48.0632882799421, 48.192135674612864, 51.349768842969624, 51.7793481690543, 49.05083921977452, 47.08584002086094, 55.20547015326363, 60.83093670436314, 60.94655472891671, 58.374706813267295, 59.22370025089809, 58.186396735055105, 57.84563970565796, 56.12828125272478, 52.07442079271589, 52.00306626728603, 53.11158881868635, 51.28049530301775, 48.89957346235003, 50.767110279628206, 54.03411156790597, 48.726122106824604, 52.54503617967878, 54.69055305208479, 55.356405871255056, 59.5836238861084, 60.43732820238386, 55.668199334825786, 50.61571250643049, 45.31617900303432, 51.5552270753043, 59.40447848183768, 60.6980801991054, 53.59756319863455, 39.98016398293631, 43.16285930361067, 47.81784316471645, 53.3018548148019, 46.652008397238596, 50.81886741093227, 52.920742647988455, 43.57086099897112, 45.94904177529471, 48.60092599051339, 42.212470803942, 47.99445595060076, 49.97361557824271, 45.1329619543893, 46.47353349413191, 40.24563380650112, 38.29117155075073, 38.30589130946568, 46.84620359965733, 53.72789750780378, 46.36706624712263, 48.3090877532959, 56.96141195297241, 53.80647121156965, 49.05187797546387, 59.211777142116, 53.55385902949742, 54.445549147469656, 52.72907658985683, 57.771724769047324, 56.68391827174595, 56.45272043773106, 57.00459500721523, 56.13075481142317, 57.31771905081612, 59.297434534345356, 58.9861204964774, 54.63570397240775, 55.17158726283482, 54.59584910529, 52.976925781794954, 55.98140328271048, 57.37689685821533, 56.373642989567344, 50.66809497560774, 44.54834399904524, 44.22096572603498, 44.3936527797154, 44.80728599003383, 42.74216324942452, 44.38828182220459, 45.26040233884539, 48.63350261960711, 48.70315831048148, 51.17605345589774, 46.92255735397339, 51.52536024366106, 51.58218955993652, 55.50090408325195, 60.299316133771626, 61.364926610674175, 60.57252625056675, 60.463571548461914, 59.3703419821603, 58.901644298008506, 57.14097077505929, 56.398701667785645, 59.71255465916225, 67.8936207635062, 71.53334426879883, 74.53106117248535, 74.54736859457833, 74.6725959777832, 74.22760554722377, 78.2651481628418, 72.95946202959333, 84.3386241367885, 62.5660617010934, 1.461588857429368, 0.42400996493441717, 10.932464156832014, 87.67240456172398, 68.35323020390102, 73.75503076825822, 58.471752302987234, 39.096526827131, 43.32365451540266, 15.290511540004186, 2.7086607686110904, 0.18996403446154936, 0.33378035947680473, 0.14000626946134226, 0.14841931659196103, 0.21694749939654553, 0.18779507013303892, 0.12196638461734567], [0.05514960622947131, 0.0746830382517406, 0.1587776964796441, 0.06357626137988907, 0.11632683580475194, 0.1458259964627879, 0.2628626206091472, 12.476422497204371, 45.97405181612287, 25.45728247506278, 16.462099415915354, 25.779939447130474, 42.55754961286272, 52.089790207999094, 66.55949715205601, 64.0020111628941, 38.00636141640799, 0.31480181642941063, 0.2671294387962137, 0.3649007709962981, 0.2940634792404515, 19.300111974988663, 54.1934928212847, 53.55711773463658, 60.16812024797712, 57.863333293369834, 62.08227252960205, 62.27930954524449, 63.42030102866036, 60.81453895568848, 63.158194133213584, 63.55067702702114, 64.8198002406529, 67.43798569270542, 65.94927161080497, 64.00107315608433, 65.74377168927873, 61.711245673043386, 62.6843478339059, 53.94944429397583, 48.324175766536165, 47.07184634889875, 48.03376191002982, 46.63606228147234, 48.61222376142229, 40.618015561785015, 40.17330305916922, 41.60147748674665, 46.25499527794974, 46.550245080675396, 44.746763706207275, 42.502130780901226, 49.202198777879985, 52.52197510855538, 53.22265577316284, 54.16597100666591, 53.89210775920323, 49.338525908333914, 47.52073471886771, 47.74900736127581, 49.15513515472412, 44.43432058606829, 47.200037138802664, 44.65307419640677, 43.97529479435512, 44.62405851909092, 44.557790075029644, 44.42867864881243, 42.71598938533238, 43.06279829570225, 47.248462608882356, 49.972549029758994, 54.916678701128276, 51.1069084576198, 44.85733386448452, 36.20995330810547, 46.12324006216866, 52.95740481785366, 42.72475801195417, 36.18108006886074, 47.46640675408499, 45.88801574707031, 45.29870775767735, 48.43998834065029, 50.722520215170725, 46.982468196323936, 56.57551942552839, 46.59846210479736, 37.98348099844796, 36.98965583528791, 46.77272987365723, 55.844933714185444, 48.89110360826765, 48.2347628729684, 50.257591928754536, 45.30224091666085, 42.231831959315706, 35.11462538582938, 42.06260510853359, 41.22325577054705, 43.32943194253104, 46.65127188818795, 51.562157903398784, 46.8963383265904, 53.175908293042866, 53.79027843475342, 48.05494349343436, 45.49614429473877, 48.86417933872768, 48.57857363564627, 51.20150818143572, 49.19083847318377, 49.35403776168823, 51.60389573233468, 51.11089672361101, 53.78387219565255, 52.65233373641968, 49.79188544409615, 47.82603856495449, 48.84026363917759, 50.570618697575156, 52.71219941547939, 52.63431358337402, 52.498577049800325, 44.36005476542881, 38.681497028895784, 40.23568746021816, 35.93920285361153, 37.73879671096802, 39.74358824321202, 39.654157979147776, 39.641790185655864, 43.67253398895264, 42.55650043487549, 44.269999163491384, 44.25283363887242, 45.92908307484218, 45.90742553983416, 49.79230581011091, 55.894026211329866, 55.874672004154746, 54.0244778905596, 54.68870830535889, 53.01749978746687, 52.33332804271153, 51.00066702706473, 50.90554966245379, 49.819980485098704, 57.48612254006522, 65.60411289760044, 67.61720752716064, 68.6055679321289, 66.41931029728481, 66.79563168116978, 67.36732251303536, 71.09947790418352, 70.50880459376744, 77.14036682673863, 8.11610392161778, 1.3454068345682961, 10.816375391823904, 65.05932549067906, 57.885442461286274, 50.25877659661429, 39.80383259909493, 26.182558025632584, 12.371966753687177, 11.217435836791992, 0.944652218903814, 0.06042503618768283, 0.1222241600709302, 0.14225109400493757, 0.0590602308511734, 0.053586583850639205, 0.13383911895964826, 0.019628450673605715, 0.03743347079892244, 0.0823222433349916, 0.0889774640755994, 0.15631302659000668, 0.021316761150956154, 0.21570727308945997, 0.22614639864436217, 15.137567792619977, 60.58985505785261, 37.21016386577061, 24.16971700532096, 27.688428946903773, 49.24626077924456, 63.607784271240234, 75.72428226470947, 72.58798354012626, 45.8776455606733, 0.25861705413886477, 0.4056835483227457, 0.3133849267448698, 0.666909108204501, 22.454632350376674, 68.50544439043317, 61.838217054094585, 70.23676177433559, 64.81945977892194, 67.86625180925641, 65.57028906685966, 67.16713796343122, 65.92324365888322, 67.96115725381034, 66.79538154602051, 69.79376547677177, 68.7808084487915, 68.78077370779855, 65.79475062234062, 68.05724389212472, 65.4463609967913, 66.0535501752581, 56.58431931904384, 50.93685824530465, 48.74666445595877, 50.8495853969029, 47.183639390128, 48.82269859313965, 44.51037904194423, 42.1847996030535, 44.146526200430735, 48.288298743111746, 49.04375900541033, 47.477840014866416, 44.44344357081822, 51.02401644842965, 54.9885265486581, 57.434063162122456, 56.53745371954781, 54.859633990696494, 51.500374521527974, 49.169677734375, 50.58342770167759, 51.229544162750244, 49.45776047025408, 50.197983333042686, 48.41512073789324, 46.879669598170686, 46.11235223497663, 48.37648180552891, 46.571649006434846, 45.05690002441406, 45.23797007969448, 47.2942408152989, 52.554805346897666, 54.78165088381086, 52.478041648864746, 48.42298262459891, 43.955238819122314, 49.0408616065979, 53.50658696038382, 42.08755956377302, 40.3843754359654, 47.357830728803364, 48.266901765550884, 48.27973856244768, 49.1433162689209, 51.820495401109966, 49.74583625793457, 57.04775374276297, 49.0329441343035, 39.053343772888184, 39.84934677396502, 47.92893443788801, 56.12582506452288, 49.51745591844831, 49.36876794270107, 50.92202731541225, 47.45775972093855, 43.51012332098824, 36.274658407483784, 41.98781817299979, 43.34641333988735, 43.778831005096436, 47.62466934749058, 51.94714716502598, 47.56062085287911, 55.9165939603533, 54.26236336571829, 50.231136662619456, 46.96254423686436, 51.089426789964946, 50.39144550051008, 52.93727936063494, 51.809479032244, 50.91035434177944, 54.663316113608225, 52.61095721381051, 53.81415244511196, 54.00562742778233, 51.44741882596697, 51.66713128771101, 51.663921219961985, 50.736548628125874, 54.23345538548061, 54.103225299290244, 55.15367480686733, 45.65900312151228, 42.53201150894165, 43.32722936357771, 39.330434458596365, 40.04561601366316, 41.12632145200457, 42.211466789245605, 41.24138362067086, 47.02539416721889, 45.25234590257917, 47.159126145499094, 46.31840106419155, 48.856824670519146, 48.59780624934605, 51.83212668555123, 58.30617673056466, 59.74232074192592, 56.91576228822981, 57.9240848677499, 55.279836722782676, 56.0348835672651, 55.69034671783447, 53.941610200064524, 55.08318533216204, 62.07909720284598, 69.85978031158447, 72.34772872924805, 75.2325929914202, 70.11275032588414, 69.72893183571952, 71.13473306383405, 75.2593435559954, 74.40724427359444, 81.83698081970215, 9.883153285299029, 1.3110714427062442, 12.825704097747803, 74.25928933279855, 64.2223037992205, 62.1569378716605, 48.5814015524728, 31.995634623936244, 28.975711277553014, 2.0694310579981123, 2.019201010465622, 0.07853221813482897, 0.1492339385939496, 0.05234474602288433, 0.14247473914708408, 0.08084814636302845, 0.1661355130906616, 0.04222230972456081, 0.13117799961141177, 0.17249048208551748, 0.19086122060460703, 0.25746745296886986, 0.17042367798941477, 0.25223942207438604, 0.37080372710313114, 20.78761533328465, 77.94806712014335, 51.93784352711269, 31.23025233404977, 36.125056743621826, 61.21428966522217, 69.98883615221295, 81.10336221967424, 79.50759029388428, 52.04836157390049, 0.26805129647254944, 0.8547013827732631, 0.37481601323400227, 0.8092140778899193, 28.62025359698704, 79.49540315355573, 65.45204462323869, 76.95413425990513, 69.36613164629254, 75.17151137760708, 69.48117297036308, 71.48627022334507, 68.53379304068429, 72.19654287610734, 69.99055930546352, 72.80378764016288, 70.65952491760254, 72.14898245675224, 67.70306641714913, 71.13417720794678, 66.80304540906633, 68.45176955631801, 59.83569758278983, 54.21513645989554, 51.831549985068186, 53.947801045009065, 51.475593771253315, 54.54679829733712, 47.021975653512136, 45.82367890221732, 45.858843735286165, 50.93390873500279, 50.062212058476035, 49.743223735264365, 44.80199841090611, 52.5842205456325, 57.60486377988543, 57.58457851409912, 56.617104394095286, 58.543158939906526, 55.11829457964216, 52.00340672901699, 51.98739807946341, 54.89791509083339, 49.79004764556885, 53.03431790215628, 50.32587882450649, 49.45846918651036, 49.29770176751273, 50.13596371241978, 49.90477282660348, 47.516343457358225, 47.56591190610613, 51.67061580930437, 55.577497550419395, 60.147678647722515, 53.97787284851074, 52.21989522661482, 39.37061589104788, 46.76457616261074, 58.19884443283081, 46.926858288901194, 40.29586928231375, 48.29940891265869, 49.83211203983852, 51.12403924124581, 53.10618312018258, 54.236477851867676, 50.74216972078596, 60.83194419315883, 50.06986549922398, 38.46787813731602, 40.035898957933696, 49.307012353624614, 58.26193755013602, 51.97336619240897, 53.97887338910784, 52.86873885563442, 48.92966958454677, 43.28672136579241, 36.703768730163574, 42.537132331303184, 44.7059326171875, 44.45177446092878, 49.390818050929475, 54.85682691846575, 51.14297308240618, 60.29099219185965, 57.68548025403704, 51.57281296593802, 48.823191915239605, 53.135817187173025, 52.38166318620954, 56.10930224827358, 54.00693368911743, 54.52055147715977, 55.994028159550254, 54.68192686353411, 54.43983425412859, 57.08421441486904, 56.32806975500924, 57.017608983176096, 53.150960786002024, 53.64870194026402, 57.0227506501334, 56.40102931431362, 57.08871684755598, 48.40905843462263, 44.92579793930054, 45.213234492710654, 41.44154385157994, 44.038523401532856, 45.22825649806431, 46.280616760253906, 43.21249723434448, 50.43248503548758, 46.30473048346383, 50.77959271839687, 49.571592807769775, 50.66121278490339, 51.65503099986485, 55.840660572052, 60.8388854435512, 62.76068769182478, 60.64357158115932, 60.455699239458355, 58.80552986689976, 58.93751784733364, 58.86826515197754, 56.064628805433, 56.462878704071045, 64.39206913539341, 72.67482212611607, 75.85859094347272, 76.38899557931083, 72.82883589608329, 71.6305148260934, 73.24643652779716, 76.55569675990513, 76.15773868560791, 83.74572045462472, 9.920103805405752, 1.3933504905019487, 14.422208189964294, 83.59844643729073, 72.3654396874564, 69.62552874428886, 61.42276341574532, 47.448761803763254, 46.18889706475394, 19.80483259473528, 2.7319991162845065, 0.14431867163096154, 0.17427767547113554, 0.20609186190579618, 0.2547820827790669, 0.13622117042541504, 0.2567526027560234, 0.11937908987913813], [0.07839243313563721, 0.07444334575640303, 0.03740728613255279, 0.16983491315373353, 0.1974545589515141, 0.0390070036851934, 0.048208637429135184, 14.287729280335562, 33.08412551879883, 29.05904276030404, 15.610594204493932, 39.26205723626273, 46.77792017800467, 54.890609060014995, 64.13030964987618, 64.00888987949916, 19.373776776450022, 0.2788720301219395, 0.29452007902520044, 0.48401569362197605, 0.8528901285358838, 38.3582946232387, 59.17866897583008, 61.791740553719656, 63.67331968035017, 60.2894983291626, 62.58109065464565, 63.37763908931187, 64.13627120426723, 60.67466476985386, 65.27915954589844, 62.07978507450649, 65.46693461281913, 62.91948182242257, 66.12859766823905, 63.030673844473704, 65.96297345842633, 62.651455061776296, 60.79234640938895, 49.25391074589321, 47.69948754991804, 46.43838603155953, 46.79209450313023, 46.75037751879011, 47.42978627341134, 40.01604448046003, 38.2270188331604, 43.01593617030552, 44.750682490212576, 46.28474051611764, 43.18901579720633, 43.21899380002703, 47.827424730573384, 50.03767449515206, 51.23489080156599, 50.10460649217878, 47.15164640971592, 49.307234695979524, 45.57340131487165, 45.45257561547415, 49.453185081481934, 47.52667542866298, 48.06050552640642, 50.073582785470144, 48.34809841428484, 45.274906703404014, 45.474333899361746, 46.12403563090733, 44.72792019162859, 42.80753190176827, 45.04386520385742, 46.418204988752095, 55.30099398749215, 46.98302405221121, 45.31285081590925, 40.05168873923165, 37.99272905077253, 40.65948935917446, 37.07091154370989, 43.76723793574742, 43.280426297869, 46.26541757583618, 43.56068188803536, 44.76622213636126, 45.32222740990775, 47.20240300042288, 49.48549420492989, 55.30612523215157, 40.66741030556815, 43.572952406747, 54.18240697043282, 52.68437188012259, 49.240632738385884, 42.301762104034424, 45.518684250967844, 42.75813715798514, 43.62999711717878, 44.49604490825108, 32.9802360534668, 39.745089054107666, 33.49312775475638, 40.691847120012554, 48.295406750270296, 48.25226885931832, 53.149453026907786, 49.884932245527, 48.35799959727696, 47.43522323880877, 47.01929364885603, 48.129845074244905, 51.48400109154837, 51.661579677036826, 50.6398401260376, 50.08187198638916, 50.73530837467739, 50.87439046587263, 48.10802773066929, 48.434085845947266, 50.82327256883894, 50.59886312484741, 50.795587471553254, 53.27970743179321, 52.62948111125401, 51.31885978153774, 44.926301683698384, 40.39177526746477, 41.27952923093523, 37.77496208463396, 37.673546178000315, 37.75954055786133, 39.054149763924734, 38.88399532863072, 43.20449638366699, 43.227776323046, 44.769459996904644, 45.8121657371521, 45.49160017286028, 45.19613150187901, 48.44632509776524, 54.46621309007917, 54.9308043888637, 55.68557677950178, 51.242794377463206, 52.20100654874529, 48.42804438727242, 48.68182734080723, 47.746217659541536, 49.970474992479595, 53.31023781640189, 59.97007574353899, 62.63867037636893, 64.11084079742432, 62.862874848502024, 63.03291116441999, 61.89081491742815, 70.90271881648472, 68.68410342080253, 81.12647887638637, 19.473099538258143, 1.90502821121897, 14.273006047521319, 65.50890173230852, 54.43218776157924, 53.22633137021746, 36.7931364604405, 31.686769826071604, 13.666576828275408, 7.459942102432251, 0.5211850819843156, 0.032882801057504754, 0.12070976490420954, 0.026364786883017848, 0.024076368160811917, 0.08217314883534398, 0.11414943050060954, 0.07207079378089734, 0.1418579915272338, 0.027287750571433986, 0.02606391767039895, 0.22531975300184318, 0.0877505506255797, 0.03186897135206631, 0.09632691434983696, 18.76845145225525, 51.615419319697786, 43.86608648300171, 21.288573503494263, 36.44825567517962, 56.67092514038086, 63.84323787689209, 72.70695754459926, 75.21472222464425, 23.760429893221172, 0.28946472172226223, 0.3365972840360233, 0.2545569720012801, 1.4428921235459191, 41.89795364652361, 71.2947083881923, 66.93483883993966, 72.22496795654297, 66.83922467912946, 69.27698625837053, 66.29922458103725, 70.30383968353271, 64.76405484335763, 68.69201741899762, 65.74213191441127, 68.87039852142334, 67.29456097739083, 68.38489314488002, 66.65408992767334, 69.172256061009, 64.43302876608712, 64.36260182516915, 53.168341704777305, 52.01861980983189, 47.8219495500837, 49.79038463320051, 50.94997991834368, 50.227645192827495, 42.390080656324116, 40.70223467690604, 46.8278568812779, 48.47266224452427, 47.76950454711914, 46.20908852985927, 45.43955816541399, 47.25283997399466, 49.89158514567784, 54.2523683820452, 53.46120827538626, 48.56602866309029, 51.03376824515206, 47.14985030038016, 48.57538093839373, 50.865493297576904, 51.28358377729143, 50.53165667397635, 53.76611260005406, 52.02457094192505, 50.674164227076936, 47.260854721069336, 49.40761184692383, 46.71068940843855, 47.16607434409005, 47.49684681211199, 49.34649549211775, 57.70416743414742, 50.03116750717163, 46.322222573416575, 48.242781094142366, 41.72383526393345, 40.635535444532124, 41.53602545601981, 43.20363480704171, 43.53532443727766, 46.93816300800869, 46.403961181640625, 47.51593698774065, 47.01744542803083, 48.44777379717146, 50.99803713389805, 57.49240371159145, 42.61216592788696, 44.69521154676165, 53.936979225703645, 52.79782554081508, 49.65197999136788, 46.419834341321675, 47.36754083633423, 44.653077670506065, 45.470929282052175, 45.743732929229736, 32.90715837478638, 37.79697745186942, 34.14405584335327, 41.09284850529262, 50.31588384083339, 51.94295392717634, 55.27234309060233, 51.77482141767229, 50.87397704805647, 49.40912308011736, 49.50409453255789, 52.48157133374895, 52.364598410470144, 50.82156331198556, 51.529907839638845, 52.267810004098074, 51.17940248761858, 50.828501088278635, 51.5403162411281, 51.24850927080427, 52.187016350882395, 53.45667804990496, 51.11603144236973, 53.43116079057966, 53.1607403755188, 52.758602959769114, 47.25974300929478, 41.71720668247768, 43.81668826511928, 40.50140741893223, 40.41562148502895, 41.131028856549946, 41.540500095912385, 41.9402299608503, 45.88661221095494, 45.85655777794974, 46.75627653939383, 47.27551889419556, 48.36623321260725, 47.94687121255057, 52.81874309267317, 55.67391422816685, 57.18560600280762, 59.54367869240897, 54.57554646900722, 54.415741375514436, 50.564521653311594, 52.70593214035034, 52.03076178686959, 52.416470187050955, 56.708198751722065, 64.2502772467477, 69.34320259094238, 68.30711500985282, 67.4081084387643, 66.91850362505231, 65.04467868804932, 74.94147041865757, 73.20537962232316, 86.71762480054582, 21.388203723090037, 1.700787759252957, 15.87228420802525, 75.82528822762626, 61.598601477486746, 64.14610985347203, 49.37050151824951, 38.05402953284127, 34.24966498783657, 12.227723019463674, 0.5814059334141868, 0.07355725366090025, 0.10486673896334, 0.06348495770777975, 0.03251988321010556, 0.00549966881849936, 0.11051192640193871, 0.03372182657143899, 0.27794596552848816, 0.17004254486943993, 0.10179138077156884, 0.33262372868401663, 0.27289609078850063, 0.20963643384831293, 0.21464955913169043, 26.672753436224802, 71.94631740025112, 59.52191693442208, 28.208041293280466, 53.22888135910034, 65.33048588888985, 73.29922894069126, 76.83550766536167, 82.08230781555176, 28.320063625063213, 0.23072636074253491, 0.5753389075398445, 0.48388802047286716, 2.0618112725870947, 46.901413985661094, 76.80792331695557, 69.46065493992397, 80.23408004215786, 69.14617252349854, 71.92992659977504, 70.00413608551025, 74.44009535653251, 66.92780031476701, 72.8238331930978, 68.4814453125, 73.71435601370675, 68.81695992606026, 72.47222655160087, 67.8823299407959, 71.82637064797538, 66.10771138327462, 66.7537340436663, 54.219298430851524, 54.068230697086875, 49.699790545872276, 51.64324338095528, 52.26811919893537, 51.779282161167686, 45.291415623256135, 43.05900805337088, 47.26467623029436, 50.40553297315325, 50.25308949606759, 47.70132882254464, 46.03800303595406, 51.50851781027657, 52.75097383771624, 56.12971952983311, 56.39257335662842, 51.41262572152274, 54.17701516832624, 51.55612339292254, 51.2573230607169, 55.149853297642295, 52.88828761237008, 54.15563556126186, 55.46479082107544, 54.65729897362845, 52.53116062709263, 50.22048160008022, 50.85315677097866, 49.83249766486031, 50.194665568215505, 50.61491346359253, 51.84817702429635, 61.627915927342, 51.11445072719029, 48.82355669566563, 42.4491994040353, 39.73802968433925, 44.98091105052403, 40.20753683362688, 44.37683119092669, 45.720022201538086, 50.13685655593872, 48.32681608200073, 49.99254247120449, 48.91293484824044, 51.92813689368111, 54.94199793679373, 59.82922880990164, 41.31866148539952, 45.0050664629255, 56.25609336580549, 55.60892077854702, 53.45588942936489, 47.24860157285418, 50.42437996183123, 47.99867698124477, 47.15600987843105, 47.18393121446882, 34.49616275514875, 40.4694561277117, 37.17729193823678, 42.22172927856445, 53.33922222682408, 54.91934333528791, 57.200096470969065, 55.26507527487618, 53.98038462230137, 51.11831045150757, 50.24696813310896, 53.7339563369751, 55.22151354381016, 54.67997441973005, 55.24495676585606, 52.86814825875418, 53.514643396650044, 55.39542695454189, 54.713103430611746, 54.67188324247088, 54.34128795351301, 56.38893597466605, 53.97653184618269, 55.68840817042759, 57.883125237056184, 56.88443980898176, 48.85228749683925, 43.09333562850952, 46.85030998502459, 42.22830574853079, 43.20226601191929, 44.52416426794869, 45.547335147857666, 46.28163119724819, 48.34292548043387, 49.73514298030308, 50.57485015051705, 51.861142362867085, 50.7809510912214, 49.20600291660854, 54.84485517229353, 59.529108319963726, 59.37988880702427, 63.382343019757954, 55.09404189246041, 57.46299546105521, 52.83567932673863, 56.39826045717512, 54.331042834690635, 56.711148262023926, 58.05280719484602, 66.57161481039864, 70.88507039206368, 70.52576514652797, 69.39804472242082, 71.39575604030064, 66.1709052494594, 76.0491383416312, 74.79392542157854, 89.90395055498395, 22.173840011869157, 1.7413696902138847, 17.691798550742014, 83.93290492466518, 69.41718700953892, 74.74630941663469, 60.498180525643484, 48.75334167480469, 49.2620644569397, 28.014004162379674, 0.9784577020577022, 0.14379676963601792, 0.3698594234883785, 0.16378001948552473, 0.07972897070326976, 0.1676496368433748, 0.26818301369036945, 0.13170915682400974], [0.04656820099002548, 0.013493068333316063, 0.07242863957903214, 0.040990673670811315, 0.132005744480661, 0.15645353762166841, 0.30706255457230974, 7.906449845858982, 31.979994228907994, 26.22915611948286, 16.15374183654785, 48.128396374838694, 44.86345522744315, 51.70613847460066, 62.8053229195731, 62.65485967908587, 33.9609569140843, 0.31209576449223925, 0.2893640814082963, 0.5765125017080988, 0.9456118302685874, 53.246019090924946, 62.930001395089285, 66.850036076137, 62.40953268323626, 63.76710646493094, 62.59278447287423, 64.03108242579869, 62.97523416791643, 61.59976877485003, 62.68625858851841, 62.151066643851145, 61.25383186340332, 61.654562268938335, 62.14980901990618, 62.79930577959333, 62.106174332754954, 60.99978487832205, 54.642408984048025, 45.62349087851388, 47.455998352595735, 45.14384283338274, 47.197122369493755, 46.181604930332725, 46.7165641103472, 38.984709467206685, 39.98381526129586, 44.101137093135286, 47.19621562957764, 45.297401496342246, 47.13224009105137, 44.975119726998464, 45.62284469604492, 46.015984194619314, 48.8338817187718, 46.797802448272705, 46.993769441332134, 45.958001477377756, 45.25536142076765, 47.935882636478965, 51.860454491206575, 49.783637932368684, 48.59998450960432, 54.46832881655012, 50.62130233219692, 53.582277161734446, 48.68152509416853, 45.63306202207293, 42.906950201307026, 41.67173767089844, 44.90644373212542, 43.2789671761649, 49.56793458121163, 50.10218504496983, 50.66871336528233, 35.85707514626639, 37.55484315327236, 45.28220578602382, 41.30731160300118, 41.26905134746006, 48.880997453417095, 45.51307010650635, 44.91896786008562, 47.31811482565743, 46.391252926417756, 47.18537296567644, 49.920500074114116, 54.18091310773577, 49.15815762111119, 48.16592359542847, 52.80777883529663, 49.58931418827602, 45.84322765895298, 45.44392163412911, 47.377751214163645, 43.466915948050364, 39.87150457927159, 45.86937025615147, 34.681036949157715, 33.37924330575125, 33.52060093198504, 38.30859068461827, 49.40017032623291, 50.7256885937282, 52.571057183401926, 45.7320008959089, 46.14633240018572, 45.51069729668753, 48.028536864689414, 48.31726925713675, 46.57459504263741, 48.45976986203875, 47.48634808404105, 47.122543879917686, 47.97545610155378, 46.48024892807007, 47.82060159955706, 47.39537531988961, 45.567279951913015, 48.302542550223215, 49.561816692352295, 49.891265528542654, 49.98824153627668, 50.35850409099034, 43.70970337731497, 39.39634159633091, 41.30405289786202, 38.91738837105887, 40.11902720587594, 37.906043325151714, 37.697694642203196, 37.081292152404785, 39.28076178686959, 41.7682238306318, 43.106141158512656, 43.73210784367153, 45.95863028935024, 45.93033375058855, 47.846865790230886, 54.1197898047311, 53.965682234082905, 53.960106304713655, 52.449672154017854, 52.25878776822771, 48.412157331194194, 49.12954493931362, 49.96826546532767, 49.612128598349436, 50.205428327832905, 53.99073396410261, 55.77605969565255, 59.77712426866804, 56.64424753189087, 61.574178559439524, 64.57434817722866, 72.18298694065639, 71.69798878261021, 80.18060670580182, 25.89563911301749, 1.7420271635055542, 17.882415430886404, 67.1728354862758, 52.08936636788504, 48.301882471357075, 40.46409559249878, 31.665115765162877, 24.144248383385793, 6.658648482390812, 0.26727896077292307, 0.057850117928215435, 0.1691094913652965, 0.10254795410271202, 0.1064004995194929, 0.1199100571019309, 0.23142815594162258, 0.05421376055372613, 0.0614034633285233, 0.03565947152674198, 0.07976698902036462, 0.023898776886718612, 0.0942113371565938, 0.22543715313076973, 0.3100460187665054, 13.445498176983424, 48.24343422480992, 42.39849492481777, 15.548176799501691, 49.71263081686837, 58.9616003036499, 59.142760685511995, 74.71889877319336, 70.36229487827846, 39.52733251026699, 0.47220353888613836, 0.4398260462496962, 0.588334535913808, 0.8516677341290882, 58.259929520743235, 72.78286661420549, 72.70659623827252, 70.96992179325649, 68.67368112291608, 66.4296075275966, 66.75306701660156, 66.28526565006801, 65.38396617344448, 67.52727699279785, 66.85870742797852, 64.94707039424351, 65.40073217664445, 66.1483097076416, 65.30780696868896, 66.425626209804, 63.58018602643694, 57.107285908290315, 49.78523601804461, 50.16368702479771, 50.18579619271414, 50.15344190597534, 49.07620709283011, 49.099184785570415, 41.45605863843645, 43.0110307421003, 46.2942282812936, 48.92742531640189, 47.44372088568551, 48.47135945728847, 45.473844051361084, 46.786251068115234, 50.6771936416626, 50.27186005456107, 48.869574614933555, 49.131667613983154, 48.531284196036204, 46.377815110342844, 49.682621547154014, 53.012642996651785, 52.177771772657124, 52.984242234911235, 54.83559669767107, 54.30815894263131, 56.54474237986973, 51.80214173453194, 48.704777240753174, 45.73178897585188, 44.202094418661936, 45.82710436412266, 45.78684302738735, 50.700584752219065, 53.109584263392854, 52.89479807444981, 43.813603264944895, 39.87542336327689, 47.89553792136056, 41.840221064431326, 41.967640604291645, 50.175644874572754, 49.00985874448504, 48.81982203892299, 49.65040275028774, 48.82354974746704, 47.6268093926566, 52.68723106384277, 55.73318236214774, 50.61412831715175, 48.830803666796, 53.125585964747835, 51.1252794946943, 48.27441624232701, 47.262782846178325, 48.537030356270925, 46.652991567339214, 42.85665566580636, 48.62261479241507, 34.555007049015586, 33.25287641797747, 33.56231444222586, 39.59040130887713, 51.163188866206575, 51.23075314930507, 54.375817026410786, 48.481163365500315, 48.70829997743879, 47.728767258780344, 49.988269329071045, 50.38103015082223, 49.70728417805263, 48.616420473371235, 50.42538397652762, 49.88644347872053, 50.61275257383074, 49.730439049857004, 51.23607546942574, 49.33760527202061, 47.95501797539847, 50.03038583483015, 50.85610975537981, 51.289246559143066, 51.50774656023298, 53.71972642626081, 45.734700271061485, 41.07496384211949, 44.363890171051025, 41.0816445350647, 42.14443404333932, 40.61863047736031, 41.01752308436802, 40.71254580361502, 42.2525897026062, 45.06849309376308, 45.779026303972515, 46.13288763591221, 48.10229894093105, 50.03247724260603, 51.66461951392037, 57.442300251552034, 56.46395567485264, 54.9502523967198, 55.646357672555105, 55.624783515930176, 51.58833524159023, 52.74149649483817, 51.67072350638253, 52.829804624829976, 54.34743710926601, 56.624657085963655, 59.57263878413609, 63.79007026127407, 61.15081092289516, 64.9317079271589, 70.52442414419991, 75.98560401371547, 74.73349693843296, 85.73717839377267, 28.02353709084647, 1.7166130415030887, 20.152176516396658, 76.58159269605363, 59.376873288835796, 59.76655605861119, 53.70187997817993, 35.61100121906826, 41.35163068771362, 22.07065405164446, 0.02874592232650944, 0.07609576173126698, 0.10701688073043313, 0.08992615781192269, 0.05186831605221544, 0.10088580793568067, 0.21874085388013295, 0.043574714833604436, 0.2525620790464537, 0.0902937880850264, 0.17051255250615732, 0.17032377049326897, 0.22594921636794293, 0.36280257787023273, 0.3306636038635458, 19.26731300354004, 68.88254397256034, 57.19679607663836, 27.948277677808488, 59.05558163779122, 63.46153163909912, 68.08833708081926, 76.6887617111206, 76.12137181418282, 45.52253007888794, 0.5701074025460652, 0.9060826056769916, 1.2079023101500102, 1.781572727220399, 61.92380496433803, 75.56743362971714, 72.73311056409563, 74.96310710906982, 70.74772535051618, 70.73298127310616, 68.13637692587716, 70.04212188720703, 68.22897556849888, 71.45246028900146, 70.16063731057304, 68.24013437543596, 66.64197226933071, 68.13305568695068, 66.38962064470563, 67.53611510140556, 67.8939264842442, 57.81372315543038, 51.75016573497227, 53.06099898474557, 50.30877235957554, 52.883757386888774, 52.996085439409526, 52.61269426345825, 44.05472312654768, 46.03275714601789, 49.75313534055437, 52.937421798706055, 49.30811364310128, 52.03385373524257, 48.782419885907856, 50.63907235009329, 53.68402310780117, 53.08537673950195, 51.38722310747419, 53.7238050188337, 51.965337548937114, 48.31809956686837, 51.6290899004255, 54.25971262795584, 55.20772136960711, 53.6886818749564, 59.59643636431013, 56.630893094199045, 59.09572832924979, 54.30206537246704, 51.8126335144043, 47.545456409454346, 47.22649935313633, 50.66417966570173, 49.23018612180437, 55.793635163988384, 56.89122819900513, 52.33261237825666, 39.05961799621582, 41.87134552001953, 48.43179294041225, 41.6049724306379, 42.12197051729475, 55.12715353284563, 51.00900139127459, 50.29287140710013, 50.53921978814261, 50.579244886125835, 52.446475982666016, 54.999445642743794, 59.52675288064139, 50.1367175919669, 49.27463027409145, 57.474751813071116, 53.27688298906599, 52.766371045793804, 50.45685931614467, 52.509391920907156, 47.79777676718575, 45.40802724020821, 49.11420679092407, 35.16147708892822, 34.10450322287423, 34.25084270749773, 41.21704060690743, 53.59831707818167, 54.490774972098215, 57.87693091801235, 51.26460129874093, 50.857784271240234, 49.7488100869315, 55.27025168282645, 52.81908008030483, 51.100658552987234, 52.613896301814485, 53.52557986123221, 49.47456121444702, 53.20433684757778, 52.30736609867641, 52.744060380118235, 50.30643776484898, 51.023637771606445, 53.202043942042756, 54.59139878409249, 55.08178527014596, 53.740428583962576, 56.97135829925537, 47.52794694900513, 44.45660693304879, 47.74872248513358, 44.56948389325823, 45.53173991612026, 45.11745704923357, 43.676546573638916, 43.80178090504238, 44.75072070530483, 47.869958128247944, 48.00636516298567, 49.185769762311665, 50.66974169867379, 52.16384758268084, 52.9966447693961, 59.947320393153596, 59.48866285596575, 58.07104969024658, 58.141504423958914, 59.24766458783831, 54.11635739462716, 54.18373755046299, 55.88498660496303, 54.86206586020333, 56.38215453284127, 59.29712881360735, 61.551325934273855, 66.64193058013916, 62.33338042667934, 66.53318432399205, 70.28439167567662, 78.07651846749442, 76.90131405421666, 86.78614098685128, 29.475595951080322, 1.5903000022683824, 22.49278838293893, 86.04108565194267, 66.78534139905656, 68.52765083312988, 64.40657697405133, 46.11125789369856, 58.130529744284495, 32.887477602277485, 0.45202173611947466, 0.14244248159229755, 0.35185490388955387, 0.22179214443479264, 0.14682462359113352, 0.12659009865352086, 0.2727784056748663, 0.13338641396590642], [0.0875758957117796, 0.020106342887239795, 0.0318805234107588, 0.07168100255408458, 0.08420369202005011, 0.024717453135443584, 0.06424130712236677, 9.27145733152117, 22.709219557898386, 27.32580246244158, 25.949852432523453, 33.05651685169765, 40.41339111328125, 47.72620684759957, 59.37217630658831, 66.68410614558628, 39.50025538035801, 0.11097776783364159, 0.2542853408626148, 0.30945960166198866, 1.3640951003347124, 58.47318363189697, 65.6664799281529, 68.76391737801688, 65.08916105542863, 65.32717159816197, 62.43244784218924, 62.25990322657994, 60.88928072793143, 64.27012825012207, 60.85736765180315, 60.402156421116416, 60.54043252127511, 59.199596949986045, 59.9261839730399, 58.68146283285958, 59.780730383736746, 54.260282380240305, 48.39680528640747, 47.81056145259312, 48.89283718381609, 47.94036422457014, 45.9188483783177, 46.82832588468279, 46.19824586595808, 39.006634507860454, 39.59423671449934, 43.186010701315745, 44.748306206294465, 46.53386122839791, 46.38736540930611, 45.569586753845215, 46.149757862091064, 43.9741587638855, 46.09173692975725, 45.492871693202424, 45.30834143502371, 45.08591570172991, 49.077266693115234, 50.05491297585623, 52.124381814684185, 51.87620258331299, 54.88612747192383, 53.302622590746196, 53.994736126491, 50.79746001107352, 50.97667489733015, 47.46429797581264, 42.411258765629356, 41.15055329459054, 43.04891926901681, 43.76235335213797, 49.368670667920796, 49.51258870533535, 55.07968691417149, 32.56637355259487, 47.86340945107596, 48.78590440750122, 38.205531529017854, 46.9882629939488, 44.24836942127773, 47.521075180598665, 45.36394439424787, 45.75354378564017, 43.944476059504915, 43.6370530128479, 44.21119655881609, 47.93614666802542, 50.81578588485718, 48.03172608784267, 47.43016842433384, 44.86219760349819, 44.78407900674002, 43.695532526288716, 42.39935302734375, 46.592031547001426, 44.58525282996041, 48.72424956730434, 39.456978525434224, 34.2682340485709, 35.738410336630686, 38.360632692064556, 46.5375611441476, 52.43406997408186, 50.10127135685512, 47.04876095908028, 46.19109269550869, 44.50161041532244, 45.529627663748606, 44.14922904968262, 49.25709302084786, 46.97522817339216, 48.20693186351231, 47.80031633377075, 48.48001691273281, 46.56156717027937, 44.19153315680367, 44.829384735652376, 46.06056036267962, 44.93817962918963, 46.88381767272949, 47.64458635875157, 48.34631967544556, 46.94876248495919, 43.72410699299404, 40.71782990864345, 39.895024231501985, 40.314935139247346, 38.327653067452566, 36.87742158344814, 37.90050561087472, 37.06339011873518, 38.98924664088658, 42.199349130902974, 42.93519810267857, 43.20297472817557, 43.96975360597883, 45.14914778300694, 48.84427274976458, 50.73626722608294, 50.523214612688335, 52.02011019842965, 48.42433752332415, 49.55278403418404, 47.50731774738857, 47.25597708565848, 48.51612670081002, 50.38808257239205, 52.20742321014404, 54.20506157193865, 54.35894332613264, 54.72062138148716, 57.70076281683785, 67.5597459248134, 68.50745936802456, 76.10639149802071, 72.34860420227051, 81.2851687840053, 26.476412977491105, 1.3841135118688856, 23.32760923249381, 65.89785494123186, 53.28021812438965, 52.37583017349243, 41.2059200150626, 24.97288359914507, 29.45656830923898, 16.76588681765965, 0.1734771534268345, 0.07151739419038806, 0.09060156478413514, 0.12430772398199354, 0.08802677544632129, 0.06910253555646964, 0.07608998061290809, 0.04776787465172155, 0.058569738242243014, 0.005798123294620642, 0.062153013822223456, 0.04657659786088126, 0.10112953771437917, 0.03472802954326783, 0.07277992394353662, 13.45244550704956, 35.65847478594099, 43.2336232321603, 25.812526498522075, 40.424939019339426, 50.012278829302105, 54.79231636864798, 68.85729421888078, 75.67140647343227, 45.97053950173514, 0.06665955843137843, 0.3142608883125441, 0.24573113130671637, 1.7686292103358676, 65.43238122122628, 71.58090468815395, 73.78483854021344, 73.49461923326764, 71.61600698743547, 68.84951918465751, 67.3790510722569, 67.00921235765729, 69.11942890712193, 64.9695130756923, 64.77336542946952, 65.94226087842668, 63.17083290645054, 64.35161672319684, 62.69584015437535, 62.42037187303816, 57.68280867167881, 51.17736666543143, 50.34071670259748, 52.36130149023873, 49.941584382738384, 49.78820289884295, 49.3889559337071, 47.96011447906494, 41.124646936144146, 42.89589214324951, 46.45494358880179, 47.71543019158499, 49.52826036725725, 50.035920075007844, 46.632463114602224, 47.68087679999215, 45.64177506310599, 49.965135301862446, 49.330705710819785, 46.99640628269741, 47.411752223968506, 50.56082173756191, 53.35570682798113, 54.22403710229056, 54.40253632409232, 55.977154459272114, 54.484917640686035, 55.38499423435756, 54.46546963282994, 53.515636989048545, 48.84067358289446, 46.925993238176616, 41.309066023145405, 46.19310767310006, 44.86687026705061, 52.43936102730887, 49.77097136633736, 58.22301721572876, 37.263102190835134, 49.08263765062605, 47.389799390520366, 38.1642279624939, 49.272858483450754, 45.81103318078177, 48.79620163781302, 47.79109607424055, 49.53953381947109, 46.396919182368684, 45.40837812423706, 46.61350842884609, 49.44769947869437, 50.58195468357631, 49.44950601032802, 48.45369713647025, 47.31196914400373, 46.8331618309021, 45.198573793683735, 44.87836258752005, 48.73730870655605, 46.90831702096121, 49.864177976335796, 40.828855173928396, 34.93704332624163, 36.226722785404746, 38.94294037137713, 49.137792451041086, 54.74873726708548, 52.86925302233015, 48.8391831942967, 47.85464082445417, 47.16374669756208, 46.62099511282784, 46.299060753413606, 50.14754635947091, 49.413955552237375, 50.005889960697715, 49.38710771288191, 48.14351912907192, 48.87413610730852, 47.94444629124233, 47.79095711026873, 46.579889569963726, 44.614817414964946, 46.93389681407383, 48.271636962890625, 49.64448288508824, 48.01291036605835, 44.906690393175396, 42.93635497774397, 42.95045634678432, 41.25219849177769, 40.427270139966694, 40.446957860674175, 40.98650285175869, 40.78293105534145, 41.890154293605256, 44.40661464418684, 45.938800130571636, 46.69509070260184, 45.54451765332903, 48.76030376979283, 52.08152532577515, 54.07821178436279, 55.4329958643232, 55.30477728162493, 51.19940635136196, 52.35834155763899, 51.11224120003836, 50.41337054116385, 51.93289640971592, 52.336875098092214, 56.09296703338623, 57.91279057094029, 58.03434930528913, 58.55060740879604, 61.594613211495535, 72.87950910840715, 71.94888823372978, 79.6897303717477, 74.90547180175781, 86.33285440717424, 27.498546838760376, 1.5306667621646608, 26.60793195452009, 76.61385318211147, 59.70143754141671, 63.54961395263672, 51.111730507441926, 30.806644984654017, 44.513988631112234, 29.57620586667742, 0.1885646374097892, 0.06792998633214406, 0.0867362425529531, 0.009779454657940992, 0.040477524777608256, 0.02415004518947431, 0.042632222907351594, 0.09390537893133503, 0.1691451280244759, 0.1110120542081339, 0.22141356260648795, 0.12056275350706917, 0.24715380210961613, 0.17705065810254642, 0.22283033015472548, 18.900689567838395, 59.98261029379708, 59.43006174904959, 42.746728215898784, 41.32584939684187, 54.26313461576189, 65.15101391928536, 72.57291289738247, 82.6516362598964, 49.85413088117327, 0.17465795363698686, 0.8053079417773655, 0.5267747449023383, 3.1256890424660275, 69.10439995356968, 75.3584040233067, 74.1231324332101, 75.82483659471784, 74.29325907570976, 72.20669419424874, 68.39880343845913, 68.86314460209438, 71.11121341160366, 69.63795212336949, 68.3033699308123, 69.88697556086949, 66.3333819253104, 67.45390401567731, 64.27053124564034, 64.671998160226, 60.09719998495919, 53.97826542173113, 52.735965728759766, 55.4785030909947, 52.296641554151265, 52.160116400037495, 52.56353575842721, 49.766840662275044, 45.1076010295323, 45.22499431882586, 47.927840096609934, 49.668527126312256, 51.355066844395225, 52.0827134677342, 48.43233142580305, 50.01209122794015, 47.21078947612217, 51.649910177503315, 52.2073016166687, 49.63591228212629, 48.95442254202706, 51.838133403233115, 57.05772788184029, 56.25143807274954, 56.718120779309956, 57.99107592446463, 57.35223075321743, 58.17858001164028, 56.87506321498326, 56.46678706577846, 52.04459912436349, 46.04140765326363, 44.811010224478586, 49.692355973379954, 46.98385088784354, 54.206833362579346, 52.44877931049892, 53.584872313908164, 38.223009722573416, 48.26505354472569, 48.054675987788606, 39.33189010620117, 51.04644523348127, 48.50317873273577, 52.327307428632466, 49.383793422154014, 51.69656385694231, 50.67277806145804, 47.341724804469514, 47.5504070009504, 53.568846293858115, 53.09203658785139, 52.075779165540425, 51.60725171225411, 48.93397746767317, 49.192071778433665, 46.746316296713694, 48.49683155332293, 49.56987312861851, 49.67114659718105, 53.07667064666748, 42.06303589684622, 36.50369882583618, 37.15976858139038, 39.90305287497384, 49.81315735408238, 57.440365178244456, 56.9335218838283, 51.423273835863384, 51.16038179397583, 49.97319173812866, 49.000860827309744, 48.70662546157837, 53.782319273267476, 52.177591119493755, 52.98891142436436, 52.67281355176653, 52.0562720979963, 51.739656584603445, 50.37394298825945, 50.773037093026296, 50.349283831460134, 47.24223007474627, 51.33729682649885, 52.82880061013358, 52.971645150865825, 51.02235582896641, 47.95949956348964, 46.47712223870413, 46.246511527470176, 45.77568769454956, 45.65177699497768, 43.47806780678885, 44.77328150612967, 42.658079624176025, 45.28249066216605, 48.51078353609358, 48.37662424360003, 47.84612928118025, 48.08993462153843, 50.30501338413784, 54.55024807793753, 56.360448360443115, 57.618763651166645, 57.166078090667725, 53.68148006711687, 54.527082783835276, 53.210103852408274, 53.914623396737234, 54.84573411941528, 55.352796282087056, 56.97504084450858, 60.49479675292969, 60.9406487601144, 61.27884537833077, 62.122655459812705, 73.79423250470842, 73.22652993883405, 82.14804472242082, 79.09908485412598, 86.62937573024205, 29.879925523485454, 1.3820883291108268, 29.016703912190028, 82.49283518110002, 67.1590085710798, 69.71632780347551, 62.111475808279856, 35.99719599315098, 58.68692411695208, 40.82890381131853, 0.38615210780075615, 0.12246905692986079, 0.19176796052072728, 0.16803733818233013, 0.2550156888152872, 0.11315254720726184, 0.13457398595554487, 0.1841691147003855], [0.1306922771036625, 0.06554364652505942, 0.035208048964185376, 0.17337522389633314, 0.045902201905846596, 0.041810191302959404, 0.1551251153328589, 4.387968497616904, 19.63917711802891, 22.80086977141244, 26.194401230130875, 22.932458230427333, 38.306033747536794, 48.16565261568342, 57.54386554445539, 67.40881020682198, 44.20268154144287, 0.1087300255894661, 0.04078105724017535, 0.08227262206907783, 1.6877391508647372, 56.91381679262434, 63.85620321546282, 69.00397763933454, 64.52348041534424, 64.48680782318115, 62.75558771405901, 63.498760087149485, 62.934364863804404, 61.358110427856445, 61.958809988839285, 63.31308337620327, 59.09834085191999, 57.96978316988264, 56.802138396671836, 55.52491358348301, 52.34977790287563, 51.39336878912789, 47.34916285106114, 48.72314132962908, 48.43310614994594, 45.39475965499878, 45.66389812741961, 45.212491035461426, 44.57498686654227, 39.160106318337576, 38.040477071489605, 42.8056697845459, 44.699786935533794, 47.05383314405169, 46.5182694707598, 47.96785824639456, 46.84685673032488, 46.82148538316999, 48.89970547812325, 48.96763106754848, 47.06496068409511, 50.395899295806885, 52.63530370167324, 53.722276415143696, 51.46737057822091, 52.51305014746529, 52.46165084838867, 52.93565000806536, 50.84215777260916, 51.899517263684956, 52.539019039699006, 46.892634936741416, 43.18182788576399, 43.73367813655308, 42.736351081303184, 42.13865661621094, 45.1321907043457, 63.872038160051616, 44.56654133115496, 34.341895375932964, 53.06173896789551, 36.48983369554792, 44.49111863545009, 40.95541661126273, 49.54609291894095, 43.48582547051566, 45.38469171524048, 44.76774379185268, 43.80000911440168, 39.87344312667847, 46.37806871959141, 44.72389023644583, 48.6451130594526, 46.10485512869698, 46.33660881859915, 42.63158614294869, 41.3121406010219, 43.29383979524885, 45.82418959481375, 43.2039474759783, 43.81305088315691, 45.00058487483433, 43.79333189555577, 36.44970784868513, 36.69062968662807, 36.523390020642964, 42.874293667929514, 48.43149069377354, 49.15534707478115, 45.067801748003276, 43.27700778416225, 43.09050076348441, 44.61757237570626, 44.75628621237618, 44.786330223083496, 44.74835136958531, 44.482339586530415, 42.882971967969624, 47.30121333258492, 44.316451345171245, 44.73976339612688, 45.494587898254395, 44.87858492987496, 44.640987804957796, 42.857298374176025, 42.92119748251778, 45.79376343318394, 45.241927078792024, 42.39589629854475, 40.88544477735247, 40.925143310001914, 40.01451587677002, 39.40084750311715, 34.77283307484218, 36.41135726656233, 35.83576154708862, 36.4644901411874, 42.46989113943917, 44.176813398088726, 44.50412218911307, 42.453156403132844, 44.46160616193499, 45.929847376687185, 50.632607051304404, 48.15811382021223, 49.81647859300886, 45.96998017174857, 46.543779781886506, 47.156732491084504, 48.427929741995676, 47.62436362675258, 51.29842512948172, 50.58554342814854, 54.22860901696341, 51.63860545839582, 58.97100121634347, 64.78255789620536, 70.02348681858608, 69.93781552995954, 76.93553393227714, 69.02289758409772, 80.16844735826764, 19.078509603227886, 1.0966491656644004, 32.010990142822266, 65.2493656703404, 52.886262212480815, 51.93869468144008, 40.566890716552734, 29.593871661594935, 39.10460410799299, 18.232601165771484, 0.2548111512192658, 0.17423077513064655, 0.11672756501606532, 0.11191010209066526, 0.06130419365529503, 0.07584179285913706, 0.1242503063487155, 0.07949375653905527, 0.09712810135845627, 0.09807050507515669, 0.06857818405010871, 0.05007675629375236, 0.0406146058147507, 0.05894227432353156, 0.10015158554805176, 8.396287424223763, 32.34041813441685, 38.93500205448696, 28.815166200910294, 23.45101966176714, 45.447517326899934, 55.690065315791536, 64.86945901598249, 75.10202939169747, 50.47513655253819, 0.11833132324474198, 0.2288614208144801, 0.0546855832716184, 2.2598264643124173, 63.82276848384312, 70.30386747632707, 72.89783150809151, 70.69036797114781, 70.19157763889858, 68.02309349605015, 69.78098773956299, 67.83795874459403, 66.89267717088971, 65.80884156908307, 65.02507087162563, 61.870519229343955, 62.577887535095215, 60.48145621163504, 60.023827007838655, 56.082662854875835, 53.857067993709016, 51.57322985785348, 51.03834710802351, 50.15841334206717, 49.12056786673409, 47.49723938533238, 46.79370648520333, 47.02825335093907, 41.192638533455984, 41.88840682165963, 46.021824155535015, 46.52496406010219, 50.201422691345215, 48.739764894757954, 52.04843800408499, 48.919028418404714, 47.69253587722778, 48.51078701019287, 51.171189716884065, 49.95960453578404, 53.136921950748985, 55.277985027858186, 55.73494373049055, 55.376041480473106, 55.009127957480295, 58.987447602408274, 56.0039849281311, 53.96823222296578, 54.53365230560303, 55.43503168651036, 50.94614103862217, 45.375249113355366, 46.103614875248496, 43.866124698093955, 44.98100485120501, 47.92647477558681, 61.390377862112864, 48.07513495853969, 37.281094551086426, 50.36339214869908, 36.928567273276194, 46.10287836619786, 41.1313727923802, 51.55499431065151, 44.89674752099173, 47.94992841993059, 46.38674354553223, 45.80552325929914, 43.04872819355556, 47.496749537331716, 45.72709199360439, 49.74779912403652, 48.8419520514352, 46.63204274858747, 44.500269412994385, 44.18977526256016, 46.797003405434744, 45.802959374019075, 47.05084541865757, 46.395942960466655, 48.34869595936367, 42.93665375028338, 38.66024596350533, 36.71974958692278, 38.51341315678188, 44.457273960113525, 50.87714195251465, 51.11011157717024, 48.93633985519409, 45.586769648960654, 44.3569906098502, 45.640135288238525, 44.55339533942086, 46.98652941840035, 46.44288151604788, 44.970662457602366, 46.23954595838274, 49.9865392276219, 45.61216878890991, 46.82090173448835, 48.85128695624215, 47.57950258255005, 47.43080765860421, 45.577208927699495, 46.14914642061506, 47.76795162473406, 46.79095152446202, 43.44007158279419, 44.258861201150076, 42.64340155465262, 40.66180658340454, 41.60540669304984, 39.35736567633492, 38.75296967370169, 39.7097817829677, 41.44523681913103, 44.99118396214077, 46.731103215898784, 46.95887558800833, 45.10816730771746, 48.15256220953805, 47.316395146506174, 54.97565848486764, 51.80787399836949, 53.52838693346296, 50.558844975062776, 49.14424385343279, 51.14969546454293, 51.55299322945731, 51.001049177987234, 54.715983458927695, 52.89331463405064, 57.416404315403526, 54.33018125806536, 61.55240985325405, 69.02195262908936, 73.94353539603097, 73.48617022378104, 79.46213517870221, 72.52252456120083, 81.6623170035226, 18.476696593420847, 0.9343395722763879, 37.54775946480887, 74.33229405539376, 59.301693780081614, 62.78508281707764, 50.210083620888845, 32.39516993931362, 49.62770298549107, 24.95093945094517, 0.2734459212848118, 0.18195517707083905, 0.18786590918898582, 0.08168478682637215, 0.05881104565092495, 0.07461000074233327, 0.0642612221251641, 0.03170685576541083, 0.25742649659514427, 0.13147120816367014, 0.13306724466383457, 0.22357973137072154, 0.10445019988609211, 0.13230628121112073, 0.26541165954300333, 13.041852133614675, 56.71574796949114, 59.06825515202114, 45.53718382971627, 30.96934747695923, 54.70211138044085, 64.30800982883999, 69.81949465615409, 78.68227631705147, 56.932292052677695, 0.24069512582251004, 0.515247683439936, 0.21884663748954022, 3.282292102064405, 68.60957704271588, 70.33933108193534, 74.51020268031529, 73.86078929901123, 73.54026889801025, 70.7433340890067, 70.76795850481305, 71.56558391026088, 68.7184066772461, 70.0353057043893, 69.65782397133964, 64.58639635358537, 65.11926759992326, 62.06170586177281, 61.016154834202354, 56.90944290161133, 56.80982310431344, 53.24427509307861, 53.4489620753697, 52.99482781546456, 50.959589276994976, 48.188046659742085, 48.434384618486675, 49.9009895324707, 42.77454532895769, 43.74249887466431, 48.04792581285749, 50.67778423854283, 51.93281650543213, 51.148500374385286, 53.52940831865583, 51.70805965151106, 50.591473715645925, 54.90293863841465, 54.20152146475655, 51.86855261666434, 56.87467064176287, 55.82531547546387, 58.45264475686209, 56.96882220676967, 57.17096267427717, 60.78051362718855, 59.13337366921561, 57.36917740958077, 58.0529704775129, 57.25111361912319, 52.42099346433367, 48.449649810791016, 48.308038575308665, 47.36956623622349, 47.28306811196463, 50.70683118275234, 60.13627665383475, 52.15817437853132, 37.64635092871529, 52.22673920222691, 38.44762066432408, 45.08344909123012, 45.3373293195452, 55.64396054404122, 48.29401363645281, 48.789388929094585, 49.606931345803396, 47.72984075546265, 43.98152385439192, 50.392425196511404, 48.7780807358878, 53.39799009050642, 50.444237913404194, 47.99314274106707, 45.408166204180034, 47.429206098829, 47.51340784345354, 49.01555626732962, 48.65721334729876, 47.685959407261436, 49.62704290662493, 43.667051860264365, 38.30974408558437, 35.66906384059361, 37.933665888650076, 44.30527169363839, 50.59644167763846, 53.742374079568044, 50.69178485870361, 48.81580598013741, 46.49141468320574, 50.340021882738384, 48.24498019899641, 49.803784234183176, 49.327662399836946, 48.92135606493269, 49.754125458853586, 52.321054049900596, 47.413662978581016, 49.72088875089373, 49.603585788181846, 48.90315178462437, 50.760526861463276, 48.076851163591655, 47.798919745853965, 50.75593410219465, 50.75829996381487, 47.220405782972065, 45.377562863486155, 46.101558208465576, 44.57291630336216, 44.832976954323904, 40.67320857729231, 40.69440058299473, 42.843725068228586, 42.69197988510132, 47.76500906263079, 50.405546869550435, 48.99447890690395, 47.63742971420288, 49.67591653551374, 49.41903468540737, 57.71291174207415, 52.56636020115444, 56.11621570587158, 51.36809124265398, 52.29608569826399, 52.62631273269653, 54.363525663103374, 52.77003969464983, 58.34170286996024, 55.01741715839931, 59.57038756779262, 56.8060120173863, 63.62084688459124, 68.74587985447475, 75.40497779846191, 75.22706917354039, 83.33720111846924, 75.09967395237514, 83.4678064073835, 22.504873037338257, 1.0873748404639108, 39.171261651175364, 81.06161744253976, 69.17047037397111, 68.07192543574742, 64.00953606196812, 40.224090916769846, 63.920710291181294, 34.08774764197213, 0.6089939730507987, 0.2806812487542629, 0.35202404909900253, 0.23454773426055908, 0.1992325514022793, 0.14408232431326592, 0.16044360851602896, 0.20739554480782577], [0.09267220260309321, 0.019756693792130266, 0.14913933724164963, 0.08207891389195408, 0.09330796277416603, 0.034446495186005316, 0.23659848421812057, 2.697969228029251, 12.537962692124502, 24.882953064782278, 24.33490174157279, 40.19451590946743, 42.5049204826355, 47.71289757319859, 52.76311928885323, 66.81796319144112, 46.5967424256461, 0.0937317961028644, 0.08536132704466581, 0.12052559692944799, 2.1175258372511183, 50.92679377964565, 63.958612714494976, 68.63964189801897, 65.90219756535122, 65.57687595912388, 65.11135360172817, 64.62300641196114, 65.18373993464878, 62.01750142233712, 60.770230293273926, 60.96093055180141, 59.21275683811733, 56.53457716533116, 54.80839102608817, 52.775195258004324, 49.29166725703648, 49.30065475191389, 45.8547477722168, 48.02911009107317, 44.9528820174081, 45.11994450432913, 46.03303854806082, 45.68633386066982, 43.733150073460166, 37.98461702891758, 39.194218499319895, 42.338868958609446, 45.19043050493513, 46.53724152701241, 47.62041704995291, 48.347535610198975, 44.5678163255964, 44.02124670573643, 48.341549737112864, 51.667933804648264, 46.33837366104126, 51.97708347865513, 55.47723157065255, 52.44296019417899, 54.697417872292654, 58.40505654471261, 55.6570474760873, 51.15843629837036, 49.80554560252598, 50.83799580165318, 51.83412776674543, 48.635079860687256, 49.60697650909424, 44.215667724609375, 48.30312272480556, 48.76892301014492, 62.57221780504499, 54.46225609098162, 28.71734424999782, 45.57838317326137, 36.50396285738264, 38.090403352464946, 39.87434639249529, 40.79260294778006, 46.49751172746931, 46.54911947250366, 44.44770629065377, 44.15069511958531, 43.41840362548828, 41.379451274871826, 44.03234297888619, 41.975665773664204, 42.31659303392683, 43.68061474391392, 40.67703356061663, 41.744822297777446, 42.07659183229719, 43.30207688467843, 42.82614265169416, 45.33242736543928, 47.13474491664341, 46.96771022251674, 40.75751107079642, 38.04952710015433, 38.830389976501465, 41.52622502190726, 38.77466194970267, 50.53904608317784, 52.44101469857352, 45.893369334084646, 45.035214696611675, 42.1648930140904, 40.9783421925136, 38.937486035483225, 44.145668097904746, 42.41664361953735, 44.789244992392405, 47.99351446969168, 46.00615249361311, 46.88498497009277, 47.30985689163208, 47.85361596516201, 47.4267429624285, 46.71426773071289, 44.519693102155415, 42.319410528455464, 42.33725697653634, 44.085222244262695, 43.43904324940273, 41.37578957421439, 42.04151037761143, 38.26413263593401, 37.89276531764439, 38.10034622464861, 34.79223244530814, 35.822462694985525, 38.13487529754639, 43.328393186841694, 42.704865319388254, 42.62779937471662, 42.05609117235456, 43.40003606251308, 45.74534838540213, 47.21873474121094, 47.19463838849749, 47.769584451402935, 46.63775764192854, 46.728000845227925, 46.567052773066926, 49.07066590445382, 48.263858454568044, 49.83446747916085, 51.79415478025164, 53.86890772410801, 54.42329754148211, 65.11519595554897, 68.28510311671666, 70.41062654767717, 69.38209165845598, 74.84140941074916, 67.05145740509033, 76.56606347220284, 8.112738387925283, 0.3508700781634876, 40.875915322984966, 62.689545086451936, 54.7235153062003, 51.960143770490376, 39.87646211896624, 32.34673057283674, 39.22737182889666, 17.05609917640686, 0.5726551658340863, 0.10647302812763623, 0.15977446442203863, 0.025963889734287347, 0.18491382045405252, 0.10277427267283201, 0.04344659045870815, 0.07874713053128549, 0.04035131387146456, 0.08419758520488228, 0.1237554100475141, 0.039602716719465594, 0.12272369755165917, 0.11854664954755988, 0.22534160182944366, 4.192863081182752, 24.485286814825876, 41.195605414254324, 25.783849545887538, 25.327952180589946, 48.89095769609724, 54.93763099397932, 59.54907744271414, 74.06810964856828, 51.87197460447039, 0.14415348906602177, 0.19777047128549644, 0.10112968699208327, 2.7593272498675754, 61.79022584642683, 69.36994620731899, 74.76473603929792, 71.62410858699253, 72.10777963910783, 71.3512875693185, 67.60896001543317, 68.01073265075684, 66.91394560677665, 65.23889473506382, 63.85928126743862, 61.84590176173619, 60.282772472926546, 58.498627935137065, 55.69427939823696, 53.39814642497471, 51.938215255737305, 49.173780645642964, 48.84973750795637, 47.80950880050659, 46.64693968636649, 45.98880978993007, 48.54116106033325, 47.42506149836949, 42.11712414877755, 42.99006107875279, 45.04720033918108, 46.68750326974051, 48.57756962094988, 50.55752829142979, 48.40991653714861, 45.69127402986799, 45.88431235722133, 51.617357867104666, 51.89146082741873, 48.82403612136841, 53.98565135683332, 57.876437595912385, 55.593054567064556, 55.736475808279856, 61.936763354710166, 59.346516609191895, 54.88885811397007, 51.96455240249634, 53.72330822263445, 55.799690519060405, 51.67883900233677, 52.01159865515572, 47.76319905689785, 52.29180213383266, 51.72428716932024, 59.1579772404262, 54.928646973201204, 33.03579037530081, 45.28212935583932, 39.276968070438926, 37.887085165296284, 41.01229803902762, 43.514035156794954, 49.661109924316406, 47.916253975459504, 46.91950709479195, 45.962458746773855, 45.218817370278494, 43.96146787915911, 44.201681000845774, 41.84786408288138, 45.02000856399536, 45.410379205431255, 43.8554870060512, 43.760307107652935, 42.66842549187796, 45.31139169420515, 43.998672008514404, 48.655677795410156, 48.42609889166695, 49.231329100472585, 41.28683178765433, 38.38498265402657, 39.17193910053798, 41.40095942361014, 40.43449626650129, 52.06853566850935, 53.72443035670689, 46.425451959882466, 46.37822157996041, 43.58024106706892, 41.95899357114519, 41.53901318141392, 45.4624594279698, 45.55480098724365, 47.633007185799734, 48.81603527069092, 48.35702337537493, 49.103965146201, 50.618297236306326, 51.683685370853965, 50.26717002051217, 48.958431652614046, 48.5071496282305, 44.161614213671, 44.413823400224956, 46.84727014814104, 45.60022830963135, 44.712686266217915, 42.954951831272666, 41.44992337908064, 40.79296772820609, 41.200347559792654, 38.270010811941965, 39.84310381753104, 41.14355298451015, 45.70116826466152, 43.80746105739048, 45.468056201934814, 44.166693346840994, 47.408677646092, 49.74238995143345, 50.46780620302473, 51.643667221069336, 50.02323613848005, 49.39091532570975, 48.97739676066807, 50.60715927396502, 51.82126317705427, 51.5536150932312, 53.02017831802368, 54.77315671103341, 58.26580074855259, 58.310832023620605, 68.7718939099993, 71.824202810015, 75.7301743371146, 72.98904745919364, 78.24296256474086, 72.71586513519287, 79.0149074281965, 7.649870242391314, 0.2459092874612127, 43.89451503753662, 73.14438138689313, 60.66159520830427, 63.30154241834368, 45.12728180204119, 35.26815973009382, 51.279605933598106, 21.121149710246495, 0.3551880307495594, 0.04626960826239415, 0.1189577467739582, 0.049963841281299076, 0.0603296138080103, 0.13490965722927026, 0.02211060980334878, 0.06503743904509715, 0.21351351509136812, 0.15509767537670477, 0.28672002043042866, 0.20109270087310246, 0.2811564675399235, 0.18005597112434252, 0.25487544919763294, 5.889943216528211, 43.97089658464704, 62.897991044180735, 38.811987672533306, 51.402523040771484, 60.523888860430034, 63.90338148389544, 67.28607722691127, 78.5302288872855, 57.250286783490864, 0.31724456963794573, 0.46200152060815264, 0.17809955110507353, 4.288508943149021, 69.30663422175816, 71.98307337079729, 75.90547738756452, 70.7823760168893, 75.03609793526786, 73.86950928824288, 72.9889988218035, 73.40962886810303, 70.87893513270787, 67.5705851146153, 67.83481815883091, 64.41350432804653, 61.30360875810896, 61.854663440159385, 57.832490239824565, 54.81083679199219, 55.29198912211827, 51.21185752323696, 51.89615780966622, 49.054577350616455, 48.966818128313335, 49.44571576799665, 48.73352541242327, 47.869683674403596, 43.87261084147862, 44.66268008095877, 48.384444441114155, 49.26612220491682, 50.750097615378245, 52.97629696982247, 50.76852771214077, 47.42345299039568, 47.85112851006644, 53.8175813811166, 54.54511683327811, 50.904469217572895, 55.52803332465035, 61.36118847983224, 57.6290921483721, 57.86557061331612, 65.38762092590332, 62.40425900050572, 56.67525734220232, 52.46728583744594, 57.22956378119332, 57.201364517211914, 54.640248094286235, 52.67249393463135, 50.28836897441319, 53.45539263316563, 55.34010192326137, 59.53570910862514, 62.578554562159944, 39.40811879294259, 44.19715077536446, 41.068832056862966, 40.06472703388759, 42.6561723436628, 46.14932359967913, 53.602583272116526, 48.59368249348232, 51.12790938786098, 48.26113823481968, 48.76157529013497, 44.07006127493722, 47.99164193017142, 46.52016632897513, 48.98925733566284, 47.45759991237095, 45.976709502083914, 45.8627347264971, 45.93727500098092, 47.01891497203282, 47.080726146698, 50.11521986552647, 51.641839844839915, 51.7958015033177, 42.2411390713283, 36.80170011520386, 39.38702058792114, 41.70048931666783, 42.03389515195574, 54.476298400333945, 55.916562693459646, 49.695975984845845, 49.69799791063581, 47.21058103016445, 44.98595196860177, 44.55981200081961, 48.13012647628784, 48.44339295795986, 49.378214018685476, 52.920339652470176, 51.16791364124843, 49.836951460157124, 52.61036661693028, 52.429564067295615, 52.64667790276663, 50.90257235935756, 49.519668919699534, 46.653213909694124, 46.43953595842634, 49.17768553325108, 47.01381499426705, 47.10860231944493, 45.5801236970084, 43.79355771200997, 44.27061755316598, 42.828039509909495, 40.933161531175884, 41.52301842825753, 43.553587777274, 47.791735308510916, 47.62436362675258, 46.61506135123116, 45.77884565080915, 49.328544821058, 51.34180620738438, 52.41289186477661, 52.94581869670323, 51.95907374790737, 51.468294688633506, 51.91590459006173, 52.30161993844168, 52.981456007276265, 53.66315071923392, 55.20418473652431, 56.350852898189, 61.151464053562705, 59.090169770377024, 70.18219062260219, 72.30974987574986, 76.47566740853446, 74.59874357495988, 82.05449417659214, 73.16307204110282, 82.58911636897496, 10.65158236026764, 0.35958447626658846, 50.71706935337612, 77.41846152714321, 68.48569066183907, 67.67159802573067, 58.10779871259417, 39.72466482434954, 69.7783682686942, 25.54218077659607, 0.751913532614708, 0.15883691901607172, 0.3143125655395644, 0.1866768579930067, 0.29862301743456293, 0.225282596424222, 0.15025708797786916, 0.15070135199597903], [0.12453860230743885, 0.08474367018789053, 0.12953722051211766, 0.04951134663341301, 0.1777778576527323, 0.0776422041069184, 0.2311522364616394, 1.8262614778109958, 5.504096720899854, 19.178620985576085, 27.636591911315918, 45.383694648742676, 43.34338045120239, 50.06058618000576, 48.420456954411094, 65.82994324820382, 44.84845059258597, 0.29095948008554323, 0.11774646677076817, 0.11567739636770316, 1.1115326413086482, 51.1299660546439, 65.81792286464146, 67.51748003278459, 68.63719613211495, 64.98490333557129, 64.1968525477818, 66.66688850947789, 61.41689913613455, 62.22783729008266, 58.31551510947091, 58.91547816140311, 57.48939166750227, 52.570317200251985, 50.384775229862754, 51.56806039810181, 47.07790865216936, 45.30702475139073, 46.61536359786987, 44.94741725921631, 44.74633639199393, 44.46936729976109, 44.409873349326, 43.62086371013096, 45.922805377415244, 40.48463446753365, 39.082071099962505, 39.93199907030378, 42.65910448346819, 46.316278389522004, 48.26048163005284, 46.920959268297466, 44.47742026192801, 44.30917310714722, 48.28457798276629, 51.59510626111712, 49.74425206865583, 52.76385579790388, 50.19813619341169, 54.705832140786306, 54.24302305494036, 56.547525133405415, 54.30859667914254, 51.39683246612549, 50.1067465373448, 52.3368855203901, 49.37659856251308, 49.27064895629883, 46.05527973175049, 48.61865084511893, 48.4834805897304, 43.46532481057303, 55.04254879270281, 32.086426734924316, 38.10115916388375, 44.17856087003435, 38.185638836451936, 42.28617034639631, 42.175176348005024, 39.265142236437114, 46.93910796301705, 46.44905151639666, 44.28114407403128, 42.41587584359305, 42.79091875893729, 41.09254278455462, 39.61645357949393, 38.99630948475429, 39.792072772979736, 40.68474606105259, 40.431386947631836, 41.11860547746931, 41.09663527352469, 42.58037444523403, 45.112871238163535, 43.63983924048287, 46.56812974384853, 47.17537103380476, 41.03284733636038, 38.60550110680716, 38.1612992967878, 32.80472108295986, 33.3862748827253, 40.76655067716326, 55.97944736480713, 48.67306913648333, 42.867234298161094, 43.71360131672451, 44.171324321201865, 44.17672307150704, 43.64164924621582, 46.36915070669991, 47.290954317365376, 47.36415706362043, 48.83092178617205, 51.229158537728445, 51.86892434528896, 52.52689095905849, 49.577078410557334, 48.60890252249581, 47.15856334141323, 43.44654035568237, 43.477258341653005, 44.959093706948416, 46.94072341918945, 42.29829147883824, 41.15516689845494, 39.97564765385219, 38.72619826453072, 38.88565247399466, 35.95903301239014, 37.1655182157244, 39.682378087724956, 42.596046107155935, 43.22610528128487, 42.82004908152989, 43.277754715510774, 44.979312964848106, 45.265724658966064, 45.910580021994456, 47.08150087084089, 47.54288905007498, 46.64415693283081, 47.371508257729666, 46.00365809031895, 48.01724256787981, 47.691910539354595, 50.90443447657994, 52.236640385219026, 52.121105739048545, 58.300979478018625, 65.50687980651855, 68.80435589381626, 70.0087149483817, 70.73362050737653, 68.66924817221505, 72.89954771314348, 64.63083008357457, 2.5730058763708388, 0.0450198824650475, 42.52790859767369, 65.66558361053467, 53.242183685302734, 49.72758681433541, 37.973701408931184, 38.21073920386178, 43.3356922694615, 15.671149492263794, 0.7693342406834874, 0.09948001229869467, 0.2500298134982586, 0.029789702567671026, 0.2842659221163818, 0.019697218501408185, 0.10503965682749238, 0.0576579093134829, 0.03208489476570061, 0.033624782493071895, 0.1125173909323556, 0.04118679064725127, 0.25475966398205074, 0.029186372977814505, 0.15548415535262652, 2.7960515192576816, 12.679682493209839, 38.123879773276194, 29.981463023594447, 38.4518277985709, 51.25481823512486, 57.82481942858015, 55.78283418927874, 72.87798050471714, 51.204857213156565, 0.34432620501943995, 0.35643506954823223, 0.18833379979644502, 2.0618494876793454, 57.63642944608416, 70.23370456695557, 72.72243813105992, 72.99844142368862, 68.90661253247941, 68.90573011125836, 68.95454120635986, 66.82135391235352, 66.77819865090507, 62.702218600681846, 61.4642094203404, 60.05789402553013, 56.0686240196228, 54.99591595785958, 54.418954917362754, 50.351660115378245, 47.2218371118818, 49.09894159861973, 47.246482372283936, 46.67297806058611, 46.83155332292829, 46.99474218913487, 46.90944610323225, 46.77700648988996, 42.968629360198975, 42.07363537379673, 43.11574009486607, 44.29457841600691, 47.78102813448225, 50.81367710658482, 48.53754104886736, 45.37625660215105, 44.49227898461478, 51.13697331292288, 54.0298627444676, 50.48939078194754, 55.688821588243755, 51.53559146608625, 57.523833887917654, 55.846351146698, 59.21506364004952, 54.39201327732631, 53.62109327316284, 52.64489916392735, 55.45846101215908, 51.212635721479145, 52.25457715988159, 48.655333859579905, 53.5036061831883, 45.554331983838765, 46.56267193385533, 52.44945675986153, 34.84204755510603, 40.323929582323345, 43.708567346845356, 39.3171112877982, 43.22403819220406, 44.65324442727225, 41.496354716164724, 49.41035638536726, 49.93448332377842, 47.293921198163716, 44.71382924488613, 45.26724978855678, 43.88186584200178, 40.49298620223999, 41.67556612832205, 41.8696744782584, 41.22323840005057, 42.77883584158761, 41.65756334577288, 43.36736910683768, 44.38524545942034, 46.49566003254482, 47.44151483263288, 48.557423319135395, 46.72354704993111, 43.47864103317261, 38.84457472392491, 38.39410563877651, 30.76916640145438, 34.71306814466204, 41.563498633248464, 57.54475491387503, 49.27540847233364, 45.7538286617824, 44.60822704860142, 44.46479885918753, 45.57927254268101, 46.588508810315815, 48.0618326323373, 48.29814434051514, 51.17553234100342, 51.271101338522776, 53.75780602863857, 53.23185518809727, 55.2825083051409, 51.39029768535069, 49.062741483960835, 49.62340899876186, 46.53888477597918, 44.80916895185198, 48.30118070329939, 48.75516210283552, 46.90013204302107, 44.39252022334507, 42.62561069216047, 41.67535073416573, 41.692297390529085, 37.75181416102818, 40.49770055498396, 42.24017327172415, 44.91571610314505, 45.50235251017979, 45.50448213304792, 46.294183118002756, 48.23319605418614, 48.0001083101545, 48.33353846413748, 50.312798840659006, 49.93971879141671, 49.83939375196184, 50.44714573451451, 49.83443621226719, 51.80366339002337, 51.51455232075283, 53.5886903490339, 54.05708578654698, 54.00269181387765, 60.4932473046439, 69.83036163875035, 70.9131828035627, 72.11556162152971, 73.26786477225167, 74.13378402165004, 76.20485442025321, 66.76364912305559, 2.7783221048968176, 0.038458767746176035, 46.5518535886492, 73.99914182935441, 59.190946442740305, 57.87730612073626, 45.61770650318691, 39.91299227305821, 56.88829953329903, 13.565153104918343, 0.3113634895001139, 0.09107944342706885, 0.15932866691478662, 0.0482489932993693, 0.12479130231908389, 0.06154930764543159, 0.07329127471894026, 0.03598750588883247, 0.30659276406679836, 0.18280527288360254, 0.21403374789016588, 0.1436584299164159, 0.4702982125537736, 0.24280835528458866, 0.22699088975787163, 3.836503003324781, 28.842031410762242, 63.71751022338867, 48.17931972231184, 61.6342248916626, 58.80175699506487, 65.46669837406704, 62.265913418361116, 77.28914165496826, 54.95705468314034, 0.6921685242227146, 0.4192037114075252, 0.22570516089243547, 3.1666002529008046, 66.54858848026821, 71.66723605564663, 72.41632829393659, 74.5374813079834, 71.54551751273019, 70.32676873888288, 72.89798436846051, 67.99496023995536, 70.89934894016811, 65.17776448386056, 63.950559752328054, 63.81864125388009, 60.14706720624651, 57.86438594545637, 56.47585446493966, 51.826283250536235, 48.85129043034145, 50.910468987056184, 50.6039457321167, 49.4279214314052, 49.64201627458845, 50.37458569662911, 47.87241084235055, 49.850114822387695, 45.577201979500906, 43.830984183720176, 45.76819406236921, 46.12532104764666, 50.773731912885395, 52.92049598693848, 52.028486251831055, 47.226391656058176, 47.871271337781636, 53.46115616389683, 56.32359858921596, 53.03224733897618, 56.60511180332729, 53.12109048025948, 58.34931809561593, 59.2216922215053, 62.15976578848702, 60.23176574707031, 56.34855651855469, 56.27766057423183, 58.31308323996407, 52.776157583509175, 55.86609097889492, 53.47480590002877, 54.05417101723807, 52.297068868364605, 50.755197593144004, 60.20693288530622, 42.444412095206125, 39.49552018301827, 45.558754512241904, 41.99108035223824, 44.82040071487427, 45.86148057665144, 43.99580587659563, 50.706046036311555, 53.754755769457134, 47.982206276484895, 48.77542652402605, 48.08097839355469, 46.25777455738613, 43.4843350819179, 44.76539530072893, 45.24184022630964, 44.85301208496094, 44.4018030166626, 45.13506031036377, 44.464930874960764, 46.51552493231637, 49.36594697407314, 49.65005186625889, 50.18021331514631, 47.718348434993196, 44.214111328125, 40.50949512209211, 38.870126724243164, 34.98250191552298, 36.5954532623291, 43.41178894042969, 59.443527357918875, 51.780508518218994, 48.502859115600586, 47.94089923586164, 49.554100717817036, 49.1000394139971, 47.846983909606934, 50.77686555044991, 52.2270518711635, 52.589612347739084, 53.6155868257795, 55.51619706835066, 55.676669188908164, 56.74208511625017, 53.32965803146362, 52.85603060041155, 51.30829504558018, 48.28080858503069, 47.13453994478498, 49.55510473251343, 50.798762798309326, 47.690350668770925, 47.06274420874459, 46.6975052016122, 44.08453089850289, 45.95365537915911, 40.668410846165244, 45.261017254420686, 45.09467390605381, 47.79118640082223, 47.62942886352539, 49.90230621610369, 47.53295660018921, 50.71503700528826, 49.73007426943098, 52.0884804725647, 52.821699551173616, 52.53258153370449, 51.020980085645405, 53.63855062212263, 50.37394298825945, 54.99706588472639, 52.694693429129465, 55.69833019801548, 56.65381867544991, 57.14408356802804, 61.826676096235005, 70.20827416011265, 72.77862126486642, 75.31640911102295, 73.19895948682512, 77.34913934980119, 75.10833835601807, 72.72603729793003, 3.8782004458563666, 0.12706062197685242, 51.20199802943638, 80.72141279493059, 65.76545006888253, 66.4332275390625, 56.045319761548726, 47.690573011125835, 75.55337047576904, 20.97680609566825, 1.0673997466053282, 0.16466158575245313, 0.508944853075913, 0.1044351906914796, 0.2550893777183124, 0.11223041133156844, 0.23711965339524405, 0.10027111627693687], [0.1362419743090868, 0.15104504355362483, 0.10204365330615214, 0.09404040061469589, 0.12349106637494904, 0.09725679231009313, 0.15001413172909192, 0.4412424202476229, 1.261737387095179, 9.950859137943812, 18.068192890712194, 15.153776202883039, 41.07271262577602, 41.61423090526036, 48.971431732177734, 64.38489859444755, 51.39251068660191, 0.9065621399453708, 0.3914183537874903, 0.24261196010879107, 0.9355460618223462, 48.2426803452628, 62.47042669568743, 69.22381169455392, 68.78387260437012, 67.78407546452114, 64.69601808275495, 62.88023839678083, 61.16964748927525, 61.02180371965681, 59.83208451952253, 56.87947532108852, 55.098909105573384, 53.56313140051705, 50.79209252766201, 46.619317122868125, 44.41215235846383, 46.93156221934727, 46.065910475594656, 44.81006179537092, 44.642988886152, 43.99205732345581, 44.052916594914024, 44.977242401668, 45.188505853925435, 41.41099262237549, 37.76922287259783, 41.07712125778198, 43.229857308524, 45.42620372772217, 50.91785839625767, 47.4564882005964, 41.042418479919434, 44.291350977761404, 50.207655225481304, 50.79766150883266, 48.199201992579866, 52.94278580801827, 51.698985304151265, 56.37567186355591, 54.55189480100359, 54.688406058720176, 50.80015243802752, 51.3856007031032, 51.53137738364083, 51.00558287756783, 50.29691525868007, 49.59147160393851, 51.11401646477835, 44.916560309273855, 29.627896990094865, 44.61497722353254, 37.271832602364675, 37.219439710889546, 44.32590784345354, 38.759473187582834, 40.06506402151925, 42.46586118425642, 43.16908836364746, 40.27718905040196, 45.15425818307059, 46.99260561806815, 45.683200223105295, 45.245435919080464, 42.30011885506766, 38.80806194032942, 37.580329145704, 38.43308155877249, 37.69886541366577, 36.790774072919575, 37.56776680265154, 38.35631438664028, 40.66785846437727, 39.69675043651036, 41.90459612437657, 44.87679576873779, 48.514486925942556, 47.19683401925223, 41.32132611955915, 41.584242480141775, 40.86834526062012, 29.82645913532802, 32.95214796066284, 34.62641021183559, 40.12257773535592, 54.25059311730521, 46.01651920591082, 43.090705735342844, 42.47397320611136, 40.75593730381557, 42.827063288007466, 45.84922742843628, 48.3320689201355, 52.139525413513184, 50.80702420643398, 53.01357405526297, 50.360988071986604, 52.419635091509136, 49.689132009233745, 50.84337370736258, 49.54081923621041, 47.23964534487043, 44.21415649141584, 46.20061520167759, 46.88359185627529, 45.30583313533238, 44.088849203927175, 40.287392480032786, 38.47645221437727, 38.09799425942557, 36.043675967625205, 36.704574721200125, 40.186657496861045, 42.01333195822579, 42.14750862121582, 42.62513126645769, 44.17581285749163, 44.500422273363384, 43.97469030107771, 43.65349245071411, 44.836801937648225, 47.297016620635986, 46.265976905822754, 47.315477984292166, 46.90913690839495, 48.09288413184029, 47.22040925707136, 50.582503591264995, 51.177175589970176, 51.32161126817976, 58.86866119929722, 66.68837233952114, 66.08624839782715, 67.17194611685616, 67.50912829807827, 71.15241622924805, 72.91031047276088, 60.25254086085728, 1.4756017455032893, 0.037737926069114885, 39.15728187561035, 64.2812453678676, 45.78143732888358, 46.30195467812674, 38.19441441127232, 34.413489614214214, 41.80558429445539, 8.351676515170507, 0.5467080952865737, 0.1546067145786115, 0.12217618764511176, 0.09205028454640082, 0.16787826243255818, 0.04638299824936049, 0.11846215836703777, 0.0983920017523425, 0.08536222271089043, 0.10888320486992598, 0.06875945468034063, 0.09583306299256426, 0.13158425209777697, 0.05741430167108774, 0.26538796510015217, 0.20593626025531972, 4.397048056125641, 33.8132312638419, 20.256554092679703, 18.4271594115666, 56.954752104622976, 49.81217418398176, 57.13491889408657, 70.48341587611607, 57.501418999263215, 1.2996412217617035, 0.8792950745139803, 0.47518143909318106, 1.8142154727663313, 55.91153219767979, 67.11729158673967, 75.27725601196289, 71.35991028376988, 74.10934720720563, 67.92388711656842, 67.04075023106166, 63.85179805755615, 64.59136431557792, 63.51984786987305, 60.921589851379395, 57.61064120701381, 57.844065938677105, 53.85046720504761, 51.26548719406128, 48.67856516156878, 50.31783281053816, 49.016529015132356, 49.88341406413487, 47.16367026737758, 46.83055625643049, 47.02321243286133, 47.72314964021955, 48.31689058031355, 43.56136975969587, 40.72884627750942, 43.73528664452689, 45.403983388628276, 47.84852293559483, 50.341050216129844, 48.33505317143032, 42.19298805509295, 44.629300934927805, 53.16858489172799, 53.467864649636404, 51.338672569819856, 55.252429553440635, 54.250798089163645, 58.31616129193987, 57.73420797075544, 55.60371657780239, 53.73456083025251, 51.9124687058585, 53.51934732709612, 53.27838727406093, 55.30989462988717, 52.58115291595459, 55.524316038404194, 43.07842479433332, 37.40558542524065, 50.055986472538535, 36.71999972207205, 41.50668321337019, 41.98298570087978, 40.9412179674421, 41.84656129564558, 44.005616733006065, 46.44764103208269, 41.95794786725725, 47.073440960475374, 49.57588332039969, 48.31630693163191, 45.823050090244834, 44.42242179598127, 41.37060621806553, 39.74530792236328, 41.768831798008506, 38.31022351128714, 37.94634287697928, 40.06753063201904, 39.72631502151489, 41.21432386125837, 40.82171242577689, 44.242480822971885, 46.61863619940621, 50.09894371032715, 47.018449442727224, 41.997285093579976, 41.25767714636666, 42.060569286346436, 31.81642668587821, 32.316703932625906, 34.88575519834246, 42.097707407815115, 58.037211963108604, 49.030936104910715, 46.57971239089966, 44.26349217551095, 43.824390343257356, 44.961938994271414, 47.69719811848232, 50.091352803366526, 52.96547862461635, 51.22233540671212, 55.47756508418492, 51.31396130153111, 53.44298315048218, 51.17620631626674, 53.264153889247346, 51.52814299719674, 50.02344111033848, 45.060005869184224, 49.52889960152762, 48.6870767048427, 47.875190121786936, 46.413007736206055, 44.62764726366316, 40.529589312417166, 40.75214358738491, 39.0793890953064, 39.37732090268816, 43.424716063908164, 44.89055667604719, 44.45702035086495, 46.213497161865234, 46.40176207678658, 47.55987739562988, 45.8301476751055, 45.93516969680786, 47.22540501185826, 48.53001962389265, 50.35572133745466, 48.67855473927089, 50.715023108891074, 50.89172969545637, 50.21166433606829, 53.338808809007915, 53.52494062696184, 53.66203553336007, 61.43641662597656, 69.29903289249965, 69.60503155844552, 71.32705920083183, 71.92305483136857, 76.12410940442766, 75.00342055729458, 66.533066204616, 2.3089065849781036, 0.06443613488227129, 43.026504380362375, 74.28786032540458, 53.057646478925435, 56.067560945238384, 43.014369351523264, 37.28667742865426, 51.23823288508824, 11.629963415009634, 0.5278140434197017, 0.05243305057021124, 0.08108881594879286, 0.07715240360370704, 0.14341878491852963, 0.0721525911773954, 0.036160427145659924, 0.07218489622963326, 0.26342507185680525, 0.25105716979929377, 0.2286397841359888, 0.17618137331945555, 0.2661835609802178, 0.1442519309265273, 0.5157704268183027, 0.9796384615557534, 13.503481762749807, 60.1164881842477, 36.172957624707905, 24.42670828955514, 55.802511487688335, 58.54882866995675, 61.14111123766218, 74.16323048727853, 61.26603984832764, 1.5048777631350925, 1.1274941733905246, 0.7800169874514852, 3.1639008777482167, 62.14472988673619, 69.51448263440813, 78.73188645499093, 71.19609260559082, 75.38256985800606, 69.4870719909668, 69.36436680385044, 66.42103345053536, 66.36104270390102, 67.56133706229073, 63.457668440682546, 60.72401087624686, 60.316360064915244, 57.89232117789132, 52.70793669564383, 50.23665353230068, 51.28669309616089, 51.813078199114116, 51.79089607511248, 48.86258472715105, 47.84760924748012, 50.39594098499843, 48.870849609375, 50.72495208467756, 44.86738790784563, 43.32936246054513, 47.32363864353725, 49.040298802512034, 50.5008726801191, 53.140319619859966, 50.27001878193447, 41.733788558415, 46.89153364726475, 55.95603888375418, 58.03268868582589, 53.14910214287894, 57.96779251098633, 56.11263043539864, 62.259979656764436, 62.100136348179404, 62.7173934664045, 55.3409218106951, 56.44104746409825, 58.22976391656058, 56.13531630379813, 58.00225557599749, 54.91347905567714, 55.11873231615339, 48.70177909306118, 38.535564013889854, 48.105415207999094, 39.88948999132429, 40.58412572315761, 42.27133246830532, 44.92437355858939, 43.022147859845845, 45.79391976765224, 47.83541168485369, 43.41072934014456, 50.88812010628836, 50.368287154606406, 51.06808539799282, 49.163208961486816, 46.200497082301546, 42.641838209969656, 42.68014710290091, 44.27487679890224, 41.69128295353481, 41.79918500355312, 41.02268212182181, 42.199390820094514, 44.28232526779175, 44.428383350372314, 46.7008125441415, 48.32220247813633, 53.87985808508736, 50.91047593525478, 43.97139685494559, 44.314967904772075, 43.647510051727295, 31.455523354666575, 33.62903799329485, 36.20999499729702, 45.809125900268555, 55.890440940856934, 51.49541698183332, 46.77677719933646, 47.13697528839111, 45.60486970629011, 46.62247507912772, 50.85267039707729, 55.03121280670166, 55.25573689596993, 54.511226994650706, 59.798670632498606, 53.860420499529155, 55.18625838415963, 52.35447488512312, 55.722607203892295, 53.079238006046836, 50.823578289576936, 46.82968773160662, 50.962643010275706, 50.56906924928938, 49.760948589869905, 49.0828287260873, 46.638834612710134, 43.49176618031093, 44.23765182495117, 40.73903581074306, 41.74054568154471, 45.47566795349121, 48.57779891150338, 47.06454379217965, 47.977036816733225, 47.8850530896868, 51.315510749816895, 48.68318223953247, 47.84613275527954, 49.28493792670113, 51.775665623801096, 52.386825697762625, 54.419865131378174, 50.69696821485247, 53.75903933388846, 50.7540476662772, 56.98193345751081, 55.63354172025408, 56.04145656313215, 62.982078143528526, 71.47800186702183, 70.34018571036202, 74.18801471165249, 72.52641555241176, 77.79642268589565, 76.13242639814104, 71.60449382237026, 2.893379713807787, 0.12925679555961064, 47.22815302440098, 81.60385486057827, 55.438238280160085, 66.02277660369873, 50.74813822337559, 45.3524694442749, 70.47789900643485, 14.285649163382393, 0.9322758487292698, 0.1985725811017411, 0.14412879039134296, 0.26603870732443674, 0.3635105884500912, 0.1365438952509846, 0.16558627970516682, 0.21730313317051955], [0.20086974783667497, 0.025575718509831598, 0.2177438009530306, 0.015781026499878083, 0.18489408865571022, 0.0175734683538654, 0.15855715902788298, 0.3336352886898177, 0.29964288270899225, 8.78433563028063, 28.243996483939036, 26.143408400671824, 32.82062898363386, 48.74405540738787, 43.68906375340053, 58.075124808720176, 60.17542280469622, 2.036299224410738, 1.1162468854870116, 0.5817911784563745, 1.1403421525444304, 48.3362204687936, 59.94883510044643, 64.57407024928501, 66.40331554412842, 67.0287367956979, 66.01946926116943, 64.43340396881104, 60.441379002162385, 60.3516708101545, 56.432796478271484, 55.62151091439383, 52.061587469918386, 51.45093808855329, 47.28473915372576, 47.08124378749302, 44.964753014700754, 45.92560550144741, 46.211190359933035, 46.30858325958252, 42.73439516339983, 45.184931005750386, 44.785301889692036, 42.966023785727366, 43.45756367274693, 42.954524517059326, 40.2343429837908, 40.7285544531686, 41.36576679774693, 45.48578453063965, 46.77759708677019, 44.55393729891096, 40.70675795418875, 42.72036327634539, 50.720383644104004, 51.574508326394216, 52.33050012588501, 53.83664376395089, 53.701463086264475, 52.45959070750645, 51.59290368216378, 50.971158027648926, 48.34126486097063, 48.92580986022949, 50.36613668714251, 50.416403429848806, 51.665411608559744, 50.29355580466134, 42.350778170994346, 35.68045541218349, 49.93739114488874, 52.68536894662039, 37.38108260290963, 42.44015284946987, 39.654807635716026, 36.8855231830052, 39.44490950448172, 37.53558622087751, 39.248831340244834, 41.16513408933367, 43.239682061331614, 49.00887904848371, 45.00309664862496, 45.453214849744526, 41.126241547720774, 37.73155321393694, 37.25387845720564, 38.4831085886274, 35.75960234233311, 35.58248233795166, 37.631433146340505, 37.22097526277815, 38.27001428604126, 42.267702034541536, 42.25710950578962, 44.35242216927664, 45.98658289228167, 43.885471957070486, 37.33933435167585, 42.16792937687465, 39.00989668709891, 40.48270634242466, 37.68011917386736, 37.221951484680176, 34.06443296160017, 43.65264824458531, 51.93812492915562, 46.082235268184114, 47.119757652282715, 46.94762298039028, 44.80398212160383, 45.69658245359148, 46.88589171000889, 50.214183058057515, 50.080999987465994, 51.83165420804705, 51.67357226780483, 50.13230895996094, 49.15649700164795, 52.61232253483364, 51.24635532924107, 50.9729437146868, 46.66012389319283, 47.27205869129726, 47.49240691321236, 46.58489227294922, 42.06314359392439, 40.98773963110787, 39.53672647476196, 36.08284296308245, 34.415924957820344, 37.12404441833496, 40.74371542249407, 42.62144872120449, 42.446065766470774, 43.407463686806814, 43.382460594177246, 45.4076555115836, 43.83093902042934, 44.8872423853193, 43.5989282471793, 46.16089929853167, 46.465331145695274, 46.640172140938894, 48.63226236615862, 45.839576380593435, 47.25622027260916, 51.94311373574393, 49.34982367924282, 50.940457412174766, 58.25919648579189, 67.48912443433488, 65.6471083504813, 67.36004774911063, 69.56539208548409, 70.43340969085693, 67.68377126966203, 65.9537740434919, 3.574079530579703, 0.06298799187477146, 41.445744037628174, 66.1149514062064, 48.17471306664603, 44.06863342012678, 42.91606623785836, 36.41401147842407, 38.91563742501395, 7.9902147224971225, 0.3741816372743675, 0.12341811028974396, 0.07586266459631068, 0.03176076876531754, 0.32824052817055155, 0.04343615798279643, 0.2451515266937869, 0.13111324022923196, 0.12858305099819387, 0.03826996198456202, 0.15115096287003585, 0.05393113375508359, 0.07147519609757833, 0.057149964783872874, 0.21975520945021085, 0.49731785697596415, 1.795392694217818, 21.294682707105363, 38.94876296179635, 20.973133972712926, 44.91878373282296, 57.58717714037214, 50.8935535975865, 67.88651275634766, 66.58203016008649, 3.407818909202303, 0.6546813100576401, 1.109349387032645, 1.2932745005403246, 58.45408303397042, 62.64019898005894, 70.38707910265241, 70.34802327837262, 73.39611462184361, 69.8205577305385, 68.93013218470982, 64.5283511025565, 64.0939427784511, 59.22821657998221, 59.76672976357596, 54.5144579069955, 54.74013539722988, 49.73280838557652, 50.35977561133248, 47.268150329589844, 49.71361746106829, 48.150307519095286, 47.793972628457205, 45.72512912750244, 47.0628136907305, 46.29582984106881, 46.91555009569441, 44.89532661437988, 45.539042472839355, 43.73476552963257, 43.27837657928467, 43.639853136880056, 48.737364292144775, 48.90717131750924, 48.216343198503765, 41.57465744018555, 44.24149765287127, 51.27521467208862, 54.573851108551025, 53.45731381007603, 57.07826675687517, 55.976091384887695, 54.81068740572248, 51.933170863560264, 54.48026234763009, 52.08733401979719, 54.32890626362392, 50.74237469264439, 52.59111315863473, 51.31618125098092, 53.6839987891061, 39.6193197114127, 42.90184327534267, 55.68592071533203, 47.25206177575247, 40.78488349914551, 44.425819465092246, 40.95905746732439, 39.725168568747385, 41.045058795383994, 40.47219371795654, 42.672031606946675, 43.47891896111624, 44.67454760415213, 49.87729617527553, 47.19064664840698, 45.59127902984619, 43.66985198429653, 39.93501458849226, 38.73931993756975, 41.32292767933437, 36.02407509940011, 37.06926482064383, 39.7835681779044, 38.84486307416643, 39.69323812212263, 42.40747199739729, 43.823455810546875, 47.88053676060268, 46.76591716493879, 45.867598465510774, 37.49628026144845, 45.02645649228777, 40.606318269457134, 41.94624710083008, 37.55907808031355, 37.931890623910085, 35.17845501218523, 44.307561125074116, 52.88824592317854, 47.54493529456002, 45.95583711351667, 48.16841452462332, 46.961863313402446, 48.02528510774885, 48.9164263180324, 53.10984134674072, 53.78947591781616, 53.58463607515608, 51.410926886967246, 51.16168805531093, 51.651932103293284, 54.30733905519758, 53.73483180999756, 53.8425532068525, 48.81003550120762, 48.18297100067139, 49.60171324866158, 49.301884583064485, 46.051777839660645, 43.482129028865266, 42.86542081832886, 39.151976925986155, 36.67867183685303, 41.14144420623779, 43.777493476867676, 45.72933278764997, 45.199386732918875, 45.8360710144043, 44.89489582606724, 48.81341232572283, 47.270398071834016, 48.28324045453753, 48.951983724321636, 49.46876641682216, 48.72800159454346, 48.723051003047395, 50.897135393960134, 50.103168215070454, 49.513485022953574, 53.65369769505092, 51.08604301725115, 54.784489222935264, 60.30156735011509, 69.99595110757011, 67.6547486441476, 72.66872160775321, 71.26234367915562, 74.89150592258999, 70.92812837873186, 72.64862741742814, 4.6540380375725885, 0.06205912493169308, 45.108962876456125, 76.19266033172607, 54.984670298440115, 51.17694977351597, 48.228116921016145, 42.72829464503697, 51.908768790108816, 9.892532484872, 0.5007748571889741, 0.10253107215144805, 0.05780700381313052, 0.0818497319040554, 0.10213034294013466, 0.06597502516316515, 0.1173815777791398, 0.0363979992190642, 0.40104622287409647, 0.09179738097425018, 0.2320500197155135, 0.11473829033119337, 0.3277087467057364, 0.1462898158601352, 0.5432762822934559, 0.678428624357496, 4.957043332712991, 46.61325829369681, 55.65179116385323, 38.61716365814209, 43.027609143938335, 65.42544691903251, 55.457213810511995, 70.53554821014404, 71.28482110159737, 4.081335808549609, 2.025412048612322, 2.026808202266693, 2.617552080324718, 65.06125708988735, 64.68357385907854, 72.44789396013532, 70.35905701773507, 74.80987153734479, 71.55873993464878, 71.0814334324428, 64.58070577893938, 68.04429244995117, 62.18327154432024, 62.27190971374512, 56.40859937667847, 57.705199241638184, 53.03016287939889, 52.85882377624512, 49.070381028311594, 51.463809626443044, 51.60124152047293, 51.67311021259853, 47.21736594608852, 49.31829275403704, 50.82275145394461, 49.23954881940569, 48.4650365965707, 48.45147023882185, 47.27367762156895, 45.841514928000315, 44.90488733564104, 49.86147860118321, 51.23985528945923, 48.5500373840332, 42.63995177405221, 43.60452849524361, 54.54241745812552, 56.54866116387503, 56.347559452056885, 59.82694980076381, 59.40548597063337, 59.67895317077637, 56.119373662131174, 55.456793444497244, 54.79984821592058, 58.23379039764404, 55.71626697267805, 54.08551434108189, 52.0715720312936, 53.67288167136056, 47.36547027315412, 42.19496134349278, 49.54844488416399, 47.50858926773071, 44.974914755140034, 46.80292674473354, 42.14294712884085, 42.15323393685477, 41.3650997706822, 41.83280038833618, 44.271774428231375, 47.98701095581055, 47.083672182900564, 54.500137669699534, 50.910924094063894, 48.53878477641514, 44.91313484736851, 42.71937663214547, 41.839130197252544, 43.63663264683315, 38.55258362633841, 39.59986475535801, 41.86194460732596, 41.25497777121407, 44.158984320504324, 47.2442033631461, 45.98812886646816, 50.576868602207725, 50.88331890106201, 48.16071592058454, 41.47806705747332, 46.90901184082031, 43.58060932159424, 42.70176294871739, 38.71671049935477, 38.90625735691616, 36.94458981922695, 47.674692903246196, 55.59799473626273, 51.20946734292166, 49.76083394459316, 51.52798318862915, 48.24911437715803, 50.412484645843506, 49.15836606706892, 54.428303718566895, 53.81571231569563, 56.12582506452288, 53.74110950742449, 54.84132201331002, 52.30873836789812, 55.27823863710676, 55.14582681655884, 54.86476523535592, 51.34164639881679, 50.311468260628835, 52.77377782549177, 52.1148419380188, 49.563452993120464, 46.186708382197786, 45.303060804094585, 41.45971686499459, 39.8495135307312, 43.77056959697178, 46.57557126453945, 49.49393974031721, 47.121241092681885, 47.86293002537319, 47.70281573704311, 51.7167066846575, 50.3549222946167, 50.61003582818167, 51.19458777563912, 51.57227100644793, 51.32361582347325, 50.816407748631065, 54.487318243299214, 53.35462638310024, 51.359072480882915, 57.23932947431292, 53.21399484361921, 57.16303130558559, 59.90145533425467, 73.40439687456403, 70.43625150408063, 74.99199077061245, 74.59830583844865, 74.71459089006696, 72.28022003173828, 74.56685134342739, 5.375000493867057, 0.21745626495352813, 50.1746860231672, 82.31268923623222, 60.438634463718955, 62.26289790017264, 59.06939465659005, 51.78203364780971, 65.91389833177838, 16.737046582358225, 1.1120325859103883, 0.2439370575760092, 0.22286604823810713, 0.15491425379046372, 0.28834207196320805, 0.15267269978565828, 0.3679131950650896, 0.19757923297584057], [0.044219601300678084, 0.06813001167029142, 0.13557639930929455, 0.022831714412729655, 0.1413833155695881, 0.15403765439987183, 0.16835658890860422, 0.14168210167969975, 1.5908268711396625, 8.479532054492406, 31.665883541107178, 26.38553053992135, 35.03301184517996, 48.86704894474575, 52.69814668382917, 53.7814507484436, 67.28841182163784, 6.797580753053937, 0.9717003617967878, 0.4124393415238176, 0.6317207706826073, 45.73939377920968, 58.31286784580776, 63.06053025381905, 63.011448178972515, 70.2056963784354, 68.20740141187395, 66.1375538962228, 60.804332051958355, 57.88714476994106, 53.42416048049927, 51.505099296569824, 50.20935753413609, 49.75944083077567, 46.746229444231304, 49.190511907849995, 46.79517255510603, 47.83106211253575, 45.67987551007952, 47.194009576525005, 44.05789497920445, 45.13197183609009, 42.986336844308035, 43.6714848109654, 41.77418538502285, 42.62146609170096, 41.16624232700893, 39.65394605909075, 39.629356384277344, 45.50565637860979, 48.404219014304026, 45.502039841243196, 42.50495522362845, 44.608376434871126, 52.22047192709786, 52.97076620374407, 52.96427658626011, 53.96042592184884, 49.12962136949812, 51.80864177431379, 50.379272256578716, 50.682797363826204, 51.45145225524902, 52.981369154793875, 50.28713914326259, 47.38448749269758, 48.01864262989589, 54.44015734536307, 34.77972221374512, 66.7597233908517, 51.48813874380929, 40.30736855098179, 40.81698070253645, 38.53263187408447, 40.6865109034947, 34.99507815497262, 35.76038401467459, 39.458514077322825, 41.66681834629604, 41.18236562183925, 42.28808804920742, 43.006788866860525, 46.42859949384417, 42.59867252622332, 38.26226009641375, 37.07981218610491, 36.05596385683332, 38.03419589996338, 37.23079306738717, 36.469906261989046, 36.70094428743635, 35.369485310145784, 36.81682634353638, 38.93748256138393, 42.79612990788051, 45.27446549279349, 45.07638624736241, 41.57339981624058, 36.720291546412874, 42.769959517887656, 40.46322359357561, 36.19058173043387, 36.437364373888286, 37.60843113490513, 36.24303020749773, 30.866528034210205, 43.774394580296104, 51.72904668535505, 46.34488064902169, 45.10130248750959, 47.58560657501221, 50.64445720400129, 49.511136531829834, 50.469129834856304, 49.86062397275652, 50.60319185256958, 50.42840296881539, 50.74272557667324, 52.69586420059204, 51.79490171160017, 51.099459988730295, 52.336044788360596, 50.502540247780935, 45.38054016658238, 49.42732041222708, 47.066624777657644, 44.61684281485421, 40.742065225328716, 39.564272608075825, 37.73144204275948, 35.706577164786204, 37.63940273012434, 41.001479693821494, 42.832601002284456, 41.42853682381766, 42.34423296792166, 41.10757868630545, 44.44419050216675, 42.64474950517927, 43.720271587371826, 44.90066630499703, 44.489662987845286, 46.998615809849326, 46.305088315691265, 46.362893853868755, 47.866956506456646, 48.50885888508388, 50.16631344386509, 46.726079668317524, 48.9773759160723, 57.51577050345284, 65.69780240740094, 64.851852280753, 67.86158956800188, 65.63023812430245, 68.98962266104562, 70.08596502031598, 71.3452843257359, 6.463242556367602, 0.34618300252727097, 35.35098573139736, 65.67291396004813, 37.54233986990792, 48.998599188668386, 38.78267322267805, 26.950917618615286, 40.98970249720982, 5.97105952671596, 0.21143846000943864, 0.07577974761703185, 0.09531422797590494, 0.07036539100642715, 0.04445394354739359, 0.029643766648535217, 0.09089214062052113, 0.014841231750324368, 0.1564648420150791, 0.026747399209333316, 0.1231113038957119, 0.005515592339049492, 0.2273551273558821, 0.1558486372232437, 0.17717427361224378, 0.25612313938992365, 3.032133719750813, 15.213923283985682, 43.16230692182268, 21.626957723072596, 41.7446277482169, 56.84180566242763, 58.12249067851475, 61.536283084324424, 73.3164257322039, 7.399548360279628, 1.226988360285759, 1.2021280314241136, 0.6497161707707814, 52.28873103005545, 62.49932425362723, 68.9311466217041, 65.41937419346401, 73.93730286189488, 70.12012931278774, 70.0655859538487, 62.77548040662493, 62.53768525804792, 55.40736395972115, 56.27036496571132, 52.22700323377337, 53.57854945319039, 49.412110805511475, 51.44271142142159, 49.54940026147025, 50.65627956390381, 47.328676087515696, 49.66510166440691, 47.481185572487966, 48.97491972787039, 47.16975341524397, 45.95575026103428, 44.85182741710118, 46.890474046979634, 41.96948882511684, 42.28317567280361, 42.348704133714946, 48.345013414110454, 47.46468012673514, 47.97772468839373, 43.42097098486764, 46.04487133026123, 54.51756027766636, 55.64534323556082, 54.92979342596871, 54.252125195094514, 51.00997413907732, 53.689543451581685, 52.308189460209434, 54.71664701189314, 55.03312356131417, 54.93546315601894, 52.71532957894461, 48.68496445247105, 51.32078095844814, 50.120319843292236, 41.554837703704834, 70.85351167406354, 45.77594477789742, 41.72915063585554, 42.55269282204764, 40.65843323298863, 42.158486774989534, 38.3523782321385, 38.50873701913016, 41.90391172681536, 44.07127373559134, 44.93800939832415, 43.52833454949515, 47.2232997076852, 46.904974937438965, 43.415825843811035, 39.495909282139365, 38.44326761790684, 39.236817904881065, 38.442027364458355, 39.6161652292524, 38.24852350779942, 39.662534032549175, 38.03244495391846, 36.9447774205889, 41.885429518563406, 45.319663524627686, 46.81072609765189, 47.01106003352574, 43.40387841633388, 39.278486251831055, 44.89184904098511, 41.86608573368618, 37.99107537950788, 38.6330646106175, 37.31859050478254, 38.062037331717356, 32.68852635792324, 45.06470285143171, 53.69607823235648, 50.49610274178641, 48.746984073093955, 49.78384985242571, 51.29349538258144, 51.74193211964199, 51.57389341081892, 51.725662912641255, 54.28407996041434, 52.14710589817592, 51.505391120910645, 53.441239152635845, 52.88288538796561, 52.469679491860525, 54.865175179072786, 52.21018164498465, 46.86778817858015, 51.07113218307495, 50.124467917851035, 45.26121180398123, 44.46925960268293, 41.43615552357265, 41.556442737579346, 38.98135001318795, 41.26937443869454, 42.609226839882986, 45.07140786307198, 44.587212221963064, 44.34173583984375, 44.52640506199428, 47.14175564902169, 46.32900748934065, 45.966558183942524, 46.25905302592686, 48.69669648579189, 48.53265299115862, 50.16144623075213, 50.53785099302019, 50.7355237688337, 51.82532092503139, 51.32554047448294, 49.84205143792288, 52.33348785127912, 59.712464332580566, 68.77310289655412, 67.60905729021344, 72.3990342276437, 65.77264145442417, 74.0535809653146, 71.90166132790702, 78.70492049625942, 7.384042586599078, 0.16177930470023835, 38.05965757369995, 76.83643872397286, 40.50822360174996, 59.4584173474993, 44.5756573677063, 38.470052923474995, 54.03732163565499, 9.183378492082868, 0.5226051743541444, 0.04824634022744639, 0.1251975412347487, 0.053897020407021046, 0.1195566760642188, 0.0531636767222413, 0.040818335954099894, 0.033950404663171084, 0.17660532199910708, 0.21197345773024218, 0.2779123101915632, 0.10785820987075567, 0.2793800085783005, 0.15380404836365155, 0.2478881941309997, 0.17717700132301875, 3.6884942139898027, 38.466999190194265, 59.59457424708775, 38.42268705368042, 46.13304744447981, 63.6005095073155, 64.61771883283342, 64.82171099526542, 76.71713815416608, 8.523671354566302, 2.6473787426948547, 1.1401356607675552, 1.2692288479634692, 59.19927733285086, 64.94090734209333, 70.70383358001709, 65.10669136047363, 74.40802942003522, 72.29156644003731, 71.91361222948346, 66.09239755358014, 64.58199119567871, 58.10704830714634, 56.85361760003226, 53.847969327654155, 57.35227591650826, 53.121531690870015, 54.99474171229771, 50.97549370356968, 53.0333833694458, 51.53741536821638, 53.30184439250401, 48.5359012739999, 50.7442889213562, 49.45882701873779, 47.96632964270455, 47.60858774185181, 48.026111943381174, 44.18493236814226, 44.36067315510341, 44.47446032932827, 49.85051434380667, 50.34406920841762, 49.279136180877686, 44.74362312044416, 46.80593531472342, 58.27759878976004, 55.9808543750218, 57.68241262435913, 58.40215219770159, 54.12932620729719, 58.24105126517159, 55.07967301777431, 56.77275793892996, 58.0379832131522, 56.75087111336844, 55.68714707238333, 51.191805022103445, 53.876946789877756, 52.10010828290667, 41.494614192417686, 64.66728728158134, 42.41012620925903, 43.813002245766775, 44.50681461606707, 43.4138560295105, 44.34808301925659, 40.06621742248535, 40.40400062288557, 45.23850509098598, 45.82858433042254, 46.43277883529663, 46.217509746551514, 49.422908306121826, 49.864254406520296, 46.0785596711295, 41.04309940338135, 40.348550524030415, 41.84382370540074, 41.37997933796474, 43.832491942814414, 42.440406458718435, 41.21992410932268, 39.80527087620327, 40.73444652557373, 43.91391093390328, 47.75574711390904, 48.75269201823643, 49.64883245740618, 46.30163506099156, 39.72863571984427, 47.18360117503575, 44.400712149483816, 39.09158665793282, 40.806096349443706, 38.61094502040318, 38.50221960885184, 33.73063802719116, 48.845290660858154, 55.26500926698957, 51.49138355255127, 50.126132011413574, 52.0106953893389, 53.732761246817454, 53.201279640197754, 55.44555820737566, 52.755827154432026, 54.903883593423025, 56.7507495198931, 53.700948919568745, 56.67173113141741, 54.620421409606934, 55.54824563435146, 55.416361876896445, 53.54940870829991, 50.34849868501936, 54.04011481148856, 51.677616119384766, 50.59437458855765, 46.93729100908552, 42.71791751044137, 44.59561954225813, 41.992747919900076, 44.45863233293806, 45.30079916545323, 45.7105587550572, 46.22148411614554, 49.00194822038923, 46.17039748600551, 49.807821137564524, 47.87672219957624, 49.58150093896048, 49.13907091958182, 49.15020193372454, 51.99907105309622, 52.966843945639475, 52.019446645464214, 53.46066631589617, 54.635231494903564, 54.74517631530762, 52.66870716639927, 54.79459885188511, 60.92843382699149, 70.53736863817487, 70.05135604313442, 75.8918102809361, 67.43057891300747, 78.91970321110317, 73.65692220415387, 80.5677603312901, 8.714431541306631, 0.39834570778267725, 43.6455054964338, 82.67948463984898, 46.73386859893799, 70.69088213784354, 51.31869649887085, 40.04722799573626, 72.00455720084054, 12.670687181609017, 0.8441552115338189, 0.13661286155028002, 0.3061568188880171, 0.17605721498174326, 0.19614923399473938, 0.11453258565493993, 0.1013207488826343, 0.23649567259209497], [0.06272414353277002, 0.11042264476418495, 0.0907976817605751, 0.09711724479815789, 0.1292553570653711, 0.15438344941607543, 0.3032750535224165, 0.11164314605827842, 0.4277294496340411, 3.9495089394705634, 30.28671475819179, 21.274930715560913, 32.99595635277884, 45.84946019308907, 49.07772527422224, 52.65092672620501, 66.97554833548409, 6.496956952980586, 0.6507739797234535, 0.4932028406432697, 0.08106136920728854, 45.2246538570949, 57.04142393384661, 64.05434499468122, 62.29790987287249, 64.21577249254499, 64.58241503579276, 63.43127918243408, 59.87637233734131, 56.88253600256783, 51.95201437813895, 51.8273081098284, 49.00915697642735, 51.01707172393799, 49.47956739153181, 51.410763604300364, 51.41917092459542, 49.248317446027485, 46.938117844717844, 48.02707426888602, 45.95559740066528, 46.69775186266218, 46.087769508361816, 45.96717309951782, 43.21242775235857, 43.37275048664638, 40.60700266701834, 40.973551409585134, 40.606568404606406, 45.91668054035732, 44.274011748177664, 48.9403315952846, 45.692889486040386, 46.90906047821045, 49.97727033070156, 53.74346842084612, 53.08204507827759, 53.26945883887154, 49.020336627960205, 51.01528603690011, 50.76294830867222, 53.67113419941494, 49.87903322492327, 52.4026015826634, 52.89675051825387, 48.171221596854075, 44.78718485151018, 40.2884555544172, 58.742711203438894, 48.387779576437815, 48.83467728751046, 53.55547448566982, 35.4265786579677, 41.527541705540244, 35.53076689583914, 36.55638006755284, 38.47986377988543, 40.63141516276768, 41.53372212818691, 44.82282216208321, 41.475791522434776, 40.93124730246407, 42.302123410361155, 43.06786700657436, 36.41000584193638, 35.141806738717214, 36.364328384399414, 36.783940519605366, 37.17150061471121, 35.93106998716082, 34.99139560971941, 34.78713941574097, 33.596207754952566, 38.54499271937779, 40.33746119907924, 43.353990350450786, 42.56662743432181, 40.71746860231672, 39.223553793770925, 41.126901626586914, 39.22427988052368, 38.56684480394636, 37.24171563557216, 36.23922259466988, 38.73914623260498, 33.8602670942034, 31.263996260506765, 40.379720142909456, 47.51675687517439, 52.90299694878714, 47.42247329439436, 49.1978075163705, 48.05642345973423, 47.95741510391235, 50.31536620003836, 49.44369731630598, 50.75966528483799, 48.995562825884136, 50.47698129926409, 48.87583841596331, 50.05431890487671, 49.2054192679269, 50.62004470825195, 46.30421979086739, 48.62704426901681, 47.27384090423584, 43.04713705607823, 40.64298391342163, 39.78718818937029, 39.10583393914359, 37.60489102772304, 39.1644663129534, 41.229682854243684, 40.52553503853934, 43.06938518796648, 42.11579704284668, 43.63204683576311, 43.93007591792515, 42.50636918204171, 43.979849338531494, 42.938682624271934, 44.090409074510845, 44.821908473968506, 45.98319217136928, 45.96192373548235, 46.80228403636387, 48.550468172345845, 48.85020651136126, 48.21695811407906, 49.97621767861502, 55.67938246045794, 62.18350083487374, 67.55227661132812, 66.32243156433105, 66.43447821480888, 70.19526018415178, 71.12257371629987, 74.43592643737793, 9.215365392821175, 0.6978891172579357, 33.45754255567278, 67.67084762028286, 45.578754901885986, 48.93882731028965, 36.353318963732036, 22.56568714550563, 44.98712274006435, 6.4834370613098145, 0.0370538033145879, 0.12451835482248239, 0.01983276435307094, 0.06397057843527623, 0.15567497297057084, 0.01940583690468754, 0.05406389252415725, 0.05242777156776615, 0.09906099656862871, 0.053130116380218945, 0.20847476832568645, 0.10893220866897277, 0.20703981603894914, 0.1280842191938843, 0.3098369485565594, 0.1519519327474492, 0.9652647014175142, 15.69188117980957, 49.43378571101597, 19.85441493988037, 38.859707900456016, 58.53560624803816, 54.94900172097342, 59.36151082175118, 70.3840079988752, 8.77252195562635, 1.3302149240459715, 0.41375694796442986, 0.04556621850601264, 53.39084734235491, 60.591189111982075, 66.76405211857387, 65.44979340689522, 69.50007207053048, 66.88430459158761, 68.4018189566476, 62.10219996316092, 60.27433735983712, 55.56195790427071, 55.26442214420864, 52.870267459324424, 53.11269358226231, 50.93185206821987, 55.92499780654907, 54.45793431145804, 53.790542466299875, 50.253388268607004, 51.72212975365775, 48.14277219772339, 50.063893522535054, 48.12571437018258, 48.847930976322715, 46.53599779946463, 45.24776356560843, 43.21367842810494, 44.23405613218035, 43.64137479237148, 47.05143254143851, 45.97772741317749, 49.741090638296946, 46.40941899163382, 48.07164348874773, 52.09142650876726, 55.52587938308716, 56.246605600629536, 54.503740310668945, 51.88609334400722, 55.05157102857317, 53.833683831351145, 55.93032707486834, 52.25190905162266, 56.19181905473982, 55.211886814662385, 52.07600845609392, 46.885575566973, 44.527186734335764, 55.01630892072405, 44.594511304582866, 49.598930495125906, 50.27471229008266, 37.441945348467144, 40.09518098831177, 37.792999608176096, 39.18862519945417, 40.40883656910488, 42.29600204740252, 43.7249789919172, 46.561591488974436, 45.90555994851248, 43.322879791259766, 44.42350918906075, 45.45688002450125, 38.40032775061471, 37.06577682495117, 38.348858969552175, 37.58960846492222, 40.192448820386616, 37.76350450515747, 38.35600519180298, 37.624109745025635, 34.713321753910606, 38.81311675480434, 43.85685927527291, 44.33223417827061, 46.014125551496235, 40.978790351322715, 40.55326182501656, 44.1855924470084, 40.19039215360369, 40.67540768214634, 40.32486758913313, 37.97248894827706, 41.94772011893136, 35.58317715781075, 32.55907794407436, 39.004251275743755, 44.971336432865684, 53.95843873705183, 50.29004349027361, 51.387403760637554, 49.60165766307286, 49.23256935392107, 50.75079938343593, 51.788498946598594, 53.09545510155814, 52.25473696844918, 53.615975924900596, 51.92137629645211, 53.63975960867745, 51.183675629752024, 52.686536243983674, 48.93245928628104, 47.72024529320853, 50.206369808741975, 44.763467175619944, 43.43135854176113, 41.59348358426775, 41.11276551655361, 39.20466859000069, 43.148511273520334, 42.04663814817156, 46.33513580049787, 46.147510119846885, 45.953043937683105, 45.39579841068813, 46.74852234976632, 44.4396185874939, 45.68131726128714, 45.99474702562605, 47.57555947984968, 48.39070476804461, 50.08947678974697, 50.63649804251534, 49.42347458430699, 51.15668535232544, 51.70293535505022, 50.277536732809885, 53.27426699229649, 58.9220997946603, 66.20250565665108, 69.15796361650739, 70.22859764099121, 69.13458987644741, 74.74931103842599, 70.57652868543352, 78.45778002057756, 10.875409892627172, 0.6153264418244362, 39.47065258026123, 77.1273945399693, 48.45961005347115, 55.17355360303606, 49.49520778656006, 31.837326867239817, 53.54709843226841, 7.140493895326342, 0.4988969979541642, 0.045963802707514594, 0.10763164024267878, 0.04601975470515234, 0.14891145804098674, 0.012438849679061344, 0.03477209021470376, 0.025924365069451075, 0.16919346685920442, 0.14911155801798615, 0.2735809768949236, 0.2503670725439276, 0.30195896700024605, 0.27008763434631483, 0.31660153557147297, 0.27331930665033205, 0.9906174838542938, 33.13204377038138, 66.24356951032365, 32.13917398452759, 45.317467893872944, 60.7391996383667, 63.57594762529646, 63.980840001787456, 79.69451768057687, 9.159487979752676, 2.691949265343802, 2.350357800722122, 0.18107964976557664, 58.76666859218052, 62.626052447727744, 69.3740873336792, 66.3054918561663, 71.20232513972691, 67.29287256513322, 70.92235442570278, 64.40088639940534, 65.66904381343296, 57.860470635550364, 57.636752537318635, 55.675331660679404, 56.37300375529698, 54.45409543173653, 58.02955852236067, 56.76239122663225, 56.47916875566755, 52.504760946546284, 55.26801436288016, 49.477368286677766, 52.16411508832659, 51.842309270586284, 50.79425341742379, 47.671031202588765, 48.72626454489571, 45.136300563812256, 46.69913802828108, 46.51752948760986, 49.26043857846941, 47.56205218178885, 52.532029151916504, 49.65361281803676, 49.02490506853376, 52.29379626682827, 58.21571465900966, 57.169774532318115, 58.40566798618862, 56.47175850187029, 56.275840146201, 57.540658950805664, 58.645082065037315, 54.01699815477644, 57.51045165743147, 55.937997886112754, 52.938286849430625, 47.68220043182373, 49.05809661320278, 50.4249392918178, 51.12719372340611, 51.342445441654746, 52.304642404828755, 39.21269028527396, 41.00036450794765, 39.06646892002651, 40.303408077784944, 44.01891905920846, 46.66743687220982, 45.9618820462908, 49.83097948346819, 49.496277809143066, 45.16605969837734, 47.538758346012656, 47.365925380161826, 41.263899258204866, 37.32218967165266, 39.9940846988133, 41.204106535230366, 42.893998759133474, 39.34304196493966, 41.94610118865967, 40.61174828665597, 36.33580255508423, 43.59591620309012, 45.62079150336129, 46.01446601322719, 50.07945053918021, 45.43658433641706, 44.183424609048025, 46.98802328109741, 42.054934297289165, 41.4756247656686, 41.91101278577532, 39.5873441014971, 44.97428594316755, 35.62802430561611, 34.40398447854178, 42.67393888745989, 51.23171894890921, 58.08750649860927, 53.43933882032122, 53.62974378040859, 50.907185963221956, 50.57405458177839, 53.28584269114903, 52.797346115112305, 55.78720113209316, 52.677979537418906, 56.71449729374477, 52.947281292506624, 54.95307683944702, 53.0707368850708, 53.39235162734985, 49.41934388024466, 51.2379584312439, 52.44942896706717, 49.043241364615305, 45.22412231990269, 44.68227400098528, 44.72919518607003, 41.04645538330078, 44.78225857870919, 45.013425145830425, 47.42414433615548, 47.439826420375276, 48.213821002415244, 47.28159856796265, 47.9556884765625, 46.57000575746809, 48.91638115474156, 46.8585991859436, 50.137794562748496, 51.19777699879238, 52.39144972392491, 51.13563231059483, 52.669207436697825, 53.65711273465838, 54.923366342272075, 52.83073220934187, 55.91230692182268, 60.43092196328299, 67.29746532440186, 72.28983633858817, 72.45156260899135, 70.97438253675188, 77.4623532976423, 76.9705320085798, 83.46990476335797, 12.815469401223318, 0.6117475224392754, 42.02828448159354, 82.93254498073033, 58.99789769308907, 67.59035968780518, 52.70301737104143, 36.51510429382324, 70.76971639905656, 13.62645445551191, 0.8076134409223283, 0.30321327969431877, 0.32026630320719307, 0.14825991514538014, 0.33631289643900736, 0.09301883221736976, 0.1256820016673633, 0.10542318517608301], [0.0640574444883636, 0.03890864664156522, 0.07820027201835598, 0.059270658131156645, 0.2683225747730051, 0.030457733864230768, 0.021883702604100108, 0.09179357439279556, 0.36380306418452946, 8.308695827211652, 38.647711413247244, 37.210247244153706, 26.497226306370326, 39.72603709357125, 50.48897041593279, 49.36445311137608, 69.53412519182477, 12.776810492788043, 0.6314633616379329, 1.9622485807963779, 1.9367269788469588, 45.77978713171822, 59.010328020368306, 63.6287122453962, 63.08720438820975, 65.66587543487549, 68.62443923950195, 63.57640620640346, 58.39404364994594, 54.05125624792916, 50.646604197365896, 50.80648224694388, 49.898272786821636, 48.476386478969026, 51.25625303813389, 52.54169062205723, 49.622356346675325, 49.3479129246303, 47.18406670434134, 48.05072941098894, 47.92500523158482, 45.437185355595176, 42.395121574401855, 45.4849715914045, 41.66580390930176, 43.539788654872346, 42.876576151166645, 40.596827030181885, 40.00243295942034, 42.767465114593506, 44.23763792855399, 46.18595797674996, 45.126899651118684, 50.90613331113543, 49.85613543646676, 51.66614811761038, 51.75610991886684, 52.51901517595564, 51.678661823272705, 50.27517087118966, 51.96843644550869, 50.26724297659737, 49.7189154624939, 49.36599908556257, 53.71623495646885, 52.232290812901084, 44.927437714168, 46.15516356059483, 45.9668048449925, 39.606865065438406, 40.81222813470023, 43.243309020996094, 34.78149747848511, 40.42846870422363, 36.836562701633994, 38.72120598384312, 36.47333172389439, 40.00119270597185, 41.47146279471261, 43.23367534364973, 44.86555705751692, 39.17297438212803, 40.049781458718435, 40.74536214556013, 35.88270010266985, 32.84867886134556, 34.04157338823591, 34.41627584184919, 36.64436163221087, 37.3309200831822, 33.45608343396868, 33.79540566035679, 34.63259063448225, 35.13144697461809, 40.29048095430647, 41.80007784707205, 38.14316102436611, 39.46624394825527, 40.495880126953125, 38.932802949632915, 40.88798086983817, 37.970341954912456, 38.077667304447715, 36.903192452022004, 36.75416054044451, 37.117728505815776, 29.97583498273577, 26.665044409888132, 23.7970712184906, 33.40645939963204, 47.825263840811594, 50.02189861025129, 48.2664292880467, 48.46799305507115, 48.75805950164795, 49.57901348386492, 48.304745129176546, 50.38932629993984, 52.54288223811558, 52.33199398858206, 47.33853210721697, 48.672440324510845, 51.11754962376186, 50.71965408325195, 44.97199303763253, 44.88346603938511, 43.99570165361677, 39.96080977576119, 37.06255980900356, 36.4248263495309, 36.151289667402, 38.838613169533865, 40.19208056586129, 42.00700562340872, 41.61833381652832, 42.087806224823, 43.643024989536826, 44.90309122630528, 43.507014002118794, 43.36830363954817, 42.01042761121477, 44.35421480451311, 45.016840185437886, 45.679451669965474, 45.8900203023638, 47.04910142081124, 48.05466556549072, 48.3066280909947, 49.19453144073486, 48.18969338280814, 55.56463990892683, 63.626238686697825, 62.79913902282715, 65.8988346372332, 64.14792333330426, 68.10812555040631, 65.39674391065324, 74.12457071031842, 10.608685050691877, 0.6365141049027443, 41.47799410138811, 65.74023505619594, 48.25342920848301, 48.300096784319194, 30.44296932220459, 18.081872156688146, 44.15532609394619, 4.304351270198822, 0.20326234373663152, 0.06053836510649749, 0.1017471742151039, 0.05391107625993235, 0.08293355588934251, 0.09190936639372792, 0.04905815309445773, 0.027884394895019274, 0.12282109446823597, 0.07020151801407337, 0.10241625045559236, 0.08525404387286731, 0.32656126256499973, 0.040973201394081116, 0.0832193209124463, 0.1524363931800638, 0.40270667948893135, 17.61148953437805, 55.82848732812064, 35.04438952037266, 24.663098164967128, 49.48866605758667, 53.944243567330496, 59.777395248413086, 74.8031804221017, 16.605254888534546, 1.1235904800040382, 2.4327108902590613, 2.8150098962443213, 54.636937277657644, 64.72681249891008, 66.70051084245954, 64.35005337851388, 68.33916704995292, 72.05579321725028, 69.85400635855538, 61.66322667258126, 56.81571865081787, 54.396077973502024, 53.402832984924316, 50.96676329204014, 52.64849138259888, 54.95807259423392, 55.60274382999965, 53.60964611598423, 53.08981663840157, 50.12396764755249, 52.764658314841135, 50.42982040132795, 49.63740961892264, 46.31729282651629, 49.14386865070888, 44.92619398662022, 48.08399043764387, 44.78907128742763, 42.89563853400094, 42.816137245723176, 45.692521231515066, 47.106173924037385, 46.77189261572701, 45.716832978384836, 51.30338961737496, 50.61796719687325, 55.06800351824079, 55.93040697915213, 53.648820059640066, 53.76966312953404, 53.55806963784354, 53.790935039520264, 51.94587564468384, 49.51224129540579, 52.89985636302403, 53.30541229248047, 54.41017934254238, 48.17963933944702, 46.944103717803955, 44.83909831728254, 44.00847591672625, 42.682311466761995, 45.10276508331299, 38.796434129987446, 41.61943163190569, 40.358177253178184, 40.23821313040597, 37.793743065425325, 42.25505631310599, 43.79648985181536, 46.56574651173183, 47.010594504220144, 40.50529146194458, 41.628137724740164, 42.38434144428798, 38.65359653745379, 34.28678921290806, 36.27862582887922, 38.57277161734444, 37.989411285945344, 39.331250871930806, 35.8888110433306, 36.11033351080758, 36.58617394311087, 36.84073509488787, 41.23025608062744, 42.671173504420686, 39.135513169424875, 41.54760462897164, 43.29273503167288, 40.18916579655239, 42.04326827185494, 39.739085810525076, 40.075670446668354, 38.52787583214896, 37.727509362357004, 38.166225569588796, 32.597369466509136, 30.862102031707764, 26.773804562432424, 31.247143404824392, 49.17703587668282, 49.87008047103882, 49.59024177278791, 50.55422789709908, 49.2323122705732, 49.63092347553798, 51.89760650907244, 51.386656829289024, 55.75309937340872, 53.3267571585519, 51.585799149104524, 52.37696967806135, 53.14536401203701, 54.34228849411011, 47.613996914454866, 46.743332045418875, 45.733074392591206, 42.2132385798863, 40.617098399571006, 39.44465936933245, 39.55937760216849, 42.41194316319057, 43.17999356133597, 44.9956134387425, 43.992189339229036, 45.1777674130031, 47.271367345537456, 47.743792738233296, 46.878144468579976, 47.536930969783235, 44.500550815037315, 47.02048526491438, 47.0585857118879, 48.519176959991455, 49.55373246329171, 50.35188940593174, 51.11415890284947, 51.928602422986714, 52.21764053617205, 52.09173570360456, 58.643060139247346, 68.50266511099679, 65.9951366697039, 69.70936570848737, 66.49353790283203, 73.250702721732, 71.79608345031738, 79.87815162113735, 11.449821812765938, 0.4994489454797336, 47.88872173854283, 72.67419678824288, 54.28530284336635, 56.53403867994036, 37.071060929979595, 20.065956320081437, 58.32355417524065, 8.261558379445757, 0.4475298071546214, 0.018077675851860216, 0.12539580916719778, 0.07888143975287676, 0.0818550041211503, 0.07915664677109037, 0.014888644384752427, 0.035940245924783606, 0.30416724564773695, 0.15407221897372178, 0.18914345492209705, 0.11987459686185632, 0.43569585787398474, 0.13436415578637803, 0.19127780039395603, 0.31841620962534634, 0.5563620744006974, 30.134681224822998, 65.13605444771903, 49.56930685043335, 34.89981140409197, 54.22731665202549, 64.54201820918492, 61.03403949737549, 83.54286084856305, 16.942518711090088, 2.514422574213573, 6.34350859267371, 3.5872561378138403, 59.11753872462681, 65.7055913380214, 68.41276931762695, 66.9836985724313, 72.71158504486084, 72.69188690185547, 71.24641145978654, 64.83550316946847, 60.65069348471505, 55.602563176836284, 55.306333678109304, 55.4874141556876, 53.81821714128767, 57.310447760990684, 59.67458970206124, 56.48964316504342, 54.26054293768746, 51.5357860156468, 54.35204029083252, 54.20176117760794, 52.09317398071289, 48.29935680116926, 51.21648849759783, 45.55807706287929, 48.599081243787495, 48.767446517944336, 46.27184118543352, 44.95908675874983, 48.140024185180664, 47.8090363230024, 48.878579480307444, 48.30641617093767, 52.972416400909424, 54.1087942804609, 56.484803744724815, 58.17147200448172, 54.64566421508789, 57.0207530430385, 55.56700577054705, 57.662606784275596, 54.62517745154244, 53.961951051439556, 55.066151823316304, 57.295460496629985, 56.83949886049543, 48.54279388700213, 44.179481506347656, 48.29759195872715, 45.332465580531526, 46.31653547286987, 48.224121706826345, 39.80074759892055, 43.40052938461304, 43.327236311776296, 44.09239278520857, 41.08598715918404, 45.07104308264596, 47.49984148570469, 50.20605713980538, 49.51316540581839, 43.09827927180699, 45.335911887032644, 44.09048897879464, 40.971852575029644, 34.842388016836985, 36.550470624651226, 40.873486927577424, 41.789165701184956, 41.956672872815815, 39.39932237352644, 37.190747124808176, 38.970097405569895, 38.634301389966694, 43.090629305158345, 46.44131817136492, 42.820254053388325, 44.42543731416975, 47.92339324951172, 42.991204057421, 45.11602224622454, 42.869509833199636, 43.861094202314106, 40.0356696673802, 40.06821502958025, 38.44829116548811, 31.551446710314067, 31.001378672463552, 26.624058723449707, 37.488373211451936, 53.25786229542324, 51.38093498774937, 53.74244703565325, 52.329183442252024, 51.43421030044556, 52.497197832380024, 52.39681025913784, 53.36036906923567, 55.2949664252145, 54.57235377175467, 53.86452341079712, 55.19933489390782, 54.93791239602225, 55.30154636928013, 47.90955938611712, 49.80250576564244, 49.86280918121338, 44.74440131868635, 42.26652084078108, 41.97993196759905, 41.67498595373971, 43.84999792916434, 45.61306163242885, 47.73226220267159, 47.237863131931846, 47.59488589423043, 47.95759228297642, 51.345815317971365, 49.632535457611084, 49.76736525126866, 47.525747844151084, 48.94551495143345, 49.00533199310303, 51.51900611604963, 51.657619203839985, 53.042742592947825, 54.23455320085798, 55.25867598397391, 54.6910776410784, 54.86611318588257, 61.528431619916645, 69.29966517857143, 68.10061454772949, 72.30153710501534, 69.76190103803361, 74.07493277958461, 71.72885268075126, 83.25933265686035, 13.754870193345205, 0.5777876047151429, 52.03184570584978, 79.88750389644078, 63.46306719098772, 67.24783434186662, 43.06351048605782, 29.123353549412318, 73.04257638113839, 12.774031213351659, 0.6532352162258965, 0.1822008610303913, 0.3105948721723897, 0.11013456593666758, 0.13602412385599955, 0.14746323360928468, 0.12429572748286383, 0.08568886946886778], [0.11300796496548823, 0.07107291304107223, 0.08764604944735765, 0.06374297743397099, 0.1527374048850366, 0.09261399108384337, 0.11212122826171772, 0.034994307040636025, 0.6368583121470043, 7.979534472737994, 52.40574564252581, 40.63411453792027, 50.11102662767683, 43.13942650386265, 40.21363040379116, 46.84047828401838, 72.10009493146623, 20.171817336763652, 0.3614451549947262, 0.31321320310235023, 4.810836732387543, 54.79195853642055, 60.0365561076573, 64.17283957345145, 64.37788786206926, 68.6189432144165, 66.33593191419328, 62.71748379298619, 54.071659633091514, 50.725195271628245, 49.841127327510286, 51.159485476357595, 50.23376308168684, 50.03843879699707, 49.670677593776155, 50.92986488342285, 51.99552747181484, 49.7503456388201, 49.90735755647932, 47.738175119672505, 47.859469822474885, 46.42702920096261, 46.273574760981965, 43.96719666889736, 46.254922321864534, 43.6150689125061, 44.61509881700788, 41.50503649030413, 40.250928333827424, 42.23995787756783, 44.04475246156965, 44.85250834056309, 46.82584537778582, 48.00603512355259, 53.187963417598176, 53.591751030513215, 53.8170359475272, 51.60553898130144, 50.76967763900757, 50.65486560549055, 49.49090685163225, 49.269943714141846, 47.63862133026123, 51.416311740875244, 50.86322818483625, 49.58219575881958, 48.024534702301025, 47.93135241099766, 41.975631032671245, 40.84694480895996, 42.83523089545113, 42.716767583574565, 38.958323683057515, 38.26484830038888, 38.762415749686106, 37.299865109579905, 38.72008384977068, 39.913058280944824, 41.29925864083426, 44.38130235671997, 44.136055265154155, 42.47069713047573, 38.50372389384678, 42.46461050851004, 37.62087883268084, 37.15396336146763, 34.209341117313926, 34.610394614083425, 36.481124128614155, 38.98926748548235, 35.457150731767925, 35.586189201899934, 35.988135542188374, 37.2692756652832, 38.10105146680559, 39.54029437473842, 38.57674946103777, 42.00191606794085, 40.84429407119751, 37.258644921439036, 37.50242246900286, 37.616313866206575, 37.30884913035801, 37.97741869517735, 37.596737316676546, 35.40650531223842, 36.30069330760411, 35.997585092272075, 43.96551520483834, 34.33173710959298, 37.007168769836426, 48.05316475459507, 45.25274542399815, 46.77483170373099, 46.78236355100359, 50.98121207101004, 50.86616032464163, 51.87147086007254, 51.75136429922921, 53.566077436719624, 51.53510161808559, 48.60302087238857, 52.279052189418245, 50.564125605991904, 46.08944749832153, 44.49294253758022, 44.606180804116384, 38.465738092150005, 38.393063408987864, 37.62384223937988, 39.43724911553519, 39.75954130717686, 41.54898384639195, 41.69582707541329, 42.98271335874285, 42.47588743482317, 45.72628600256783, 44.06105293546404, 44.00794437953404, 43.98762437275478, 44.87006991250174, 46.164411612919395, 44.727638789585654, 45.200793743133545, 45.59728922162737, 46.80831159864153, 48.76813786370413, 49.845827783857075, 49.03919403893607, 49.57660593305315, 55.47904505048479, 64.45258794512067, 64.75341020311627, 67.30052253178188, 65.61930860791887, 71.08645003182548, 67.99580792018345, 70.8247322354998, 9.130164844649178, 0.3097396194934845, 48.17567539215088, 62.8246180670602, 48.226626532418386, 48.799165044512065, 33.367952483040945, 37.2917982510158, 48.26001957484654, 5.711578616074153, 0.2711953834763595, 0.08583123968648058, 0.15854809380003385, 0.25245096215179985, 0.10983231251261064, 0.0711360846513084, 0.14722805337182113, 0.06152971155409302, 0.09210994813059058, 0.14827885984310082, 0.06633736286312342, 0.059140623680182865, 0.15033909572022303, 0.07460943077291761, 0.06111334211059979, 0.06428557474698339, 0.5206742265394756, 8.823455725397382, 69.07031903948102, 40.00421517235892, 41.58131381443569, 49.917265687670024, 46.438914094652446, 54.13156352724348, 78.73097624097551, 23.302939653396606, 0.25014831285391537, 0.7537881891642297, 6.557471854346139, 61.669757979256765, 65.13533183506557, 66.32698958260673, 67.43351800101144, 70.56712082454136, 68.92345496586391, 66.35481711796352, 56.61533955165318, 54.87201568058559, 52.985718727111816, 53.80672829491751, 53.47015755517142, 54.00162179129464, 53.01609625135149, 53.72937747410366, 54.300317900521414, 51.14987959180559, 51.9974799156189, 51.820589201790945, 50.011987004961284, 50.454820019858225, 48.617448806762695, 47.89322417122977, 48.82016944885254, 46.37705428259713, 45.668098313467844, 44.13701064246041, 42.16554267065865, 44.5020238331386, 46.13667440414429, 47.033388069697786, 49.10396862030029, 50.306708744594026, 54.79290696552822, 54.69017784936087, 56.206069810049875, 53.46684673854283, 51.96743590491158, 53.38857180731637, 51.815548283713206, 49.04076433181763, 50.472527503967285, 52.4897597857884, 52.41264172962734, 52.933332783835276, 48.59977953774588, 47.30516685758318, 45.75138289587838, 43.09355797086443, 44.699540274483816, 44.25064843041556, 40.4043619292123, 40.82525948115757, 39.39931542532784, 40.249969482421875, 41.465348379952566, 41.75612701688494, 43.029770033700125, 47.027780873434885, 46.37114831379482, 46.557568481990266, 40.98726715360369, 43.18690007073538, 39.8857171194894, 38.02166829790388, 37.9097432409014, 36.29297385896955, 39.511869294302805, 40.80501937866211, 36.93541472298758, 35.8028062411717, 37.522276946476524, 38.12304251534598, 40.42469235828945, 41.77582515989031, 40.39583996364048, 44.74094458988735, 43.12858036586216, 41.01257944107056, 38.75259447097778, 38.49545553752354, 39.842912742069785, 39.780392851148335, 38.825210094451904, 36.75357689176287, 35.830557346343994, 37.70655359540667, 49.7434287071228, 40.037920883723665, 36.38033355985369, 46.51179027557373, 45.95068849836077, 49.509191036224365, 49.95549815041678, 54.693398339407786, 52.64262710298811, 53.44022124154227, 54.0632974760873, 56.976996762411936, 51.6855857031686, 53.952035972050254, 54.075658321380615, 53.84054865155901, 48.55538749694824, 46.87469468797956, 47.61368077141898, 43.28266709191458, 41.62628255571638, 41.19858619144985, 41.77885457447597, 42.055337292807444, 43.90655973979405, 44.302509784698486, 45.39920997619629, 45.99673768452236, 49.53305115018572, 46.2473418372018, 45.97169290270124, 47.91993999481201, 45.914634295872276, 48.041752338409424, 49.371929373059956, 48.368150915418354, 48.69491079875401, 49.78955432346889, 51.377596378326416, 51.62412888663155, 51.72674683162144, 52.35289069584438, 59.12339605603899, 66.92767524719238, 68.31347955976213, 71.08758953639439, 68.99767562321254, 74.6873539515904, 71.53633199419293, 74.40346445356096, 9.935598288263593, 0.31929491247449604, 54.32118681498936, 68.41203280857631, 54.65950502668108, 56.43484272275652, 39.89621237346104, 38.07527712413243, 58.163801193237305, 10.011388369968959, 0.4503454017852034, 0.07670146958636385, 0.14906506479850837, 0.10980067242469106, 0.24981284514069557, 0.031144621648958752, 0.11568944714963436, 0.0896096755085247, 0.13809193218392984, 0.1933482550084591, 0.15669124200940132, 0.11072837907288756, 0.3318859711289406, 0.28267931725297657, 0.16492056899837085, 0.32607152312994003, 0.6689359194466046, 16.707806825637817, 81.31931918007987, 51.66556794302804, 64.60225214276994, 56.1849125453404, 54.68809338978359, 57.31446034567696, 83.69424819946289, 24.595262902123586, 0.5865588369114059, 2.4341988904135565, 9.795417513166155, 65.78086117335728, 66.25602763039726, 66.85733168465751, 67.95833628518241, 72.22185516357422, 71.7863073348999, 67.1790749686105, 59.26552145821707, 55.23706361225673, 55.43041113444737, 56.016418729509624, 55.128244400024414, 55.901693548474995, 55.037528719220845, 55.3210951260158, 57.12505940028599, 53.58285733631679, 54.360913140433176, 52.93273523875645, 53.72692823410034, 52.54222910744803, 50.02935750143868, 47.498222555433, 52.24040630885533, 47.1230719430106, 49.2281676701137, 47.341776915958945, 44.522719042641775, 47.05613994598389, 47.65132958548409, 48.800648484911235, 51.80058533804757, 52.05993727275303, 55.7823999268668, 59.205051285879954, 58.99761976514544, 55.03097309385027, 55.15958424976894, 55.72834989002773, 54.325692721775596, 53.85820402417864, 52.328856876918245, 54.06477744238717, 53.855806895664756, 54.00885139192854, 47.637450558798655, 50.350388595036094, 47.17621176583426, 43.113023349217, 45.908064774104524, 49.64849894387381, 43.81402710505894, 45.1495612008231, 42.383038657052175, 42.58790976660592, 42.717385973249165, 43.96504620143345, 45.5819719178336, 50.53548165730068, 49.9266631262643, 49.008055686950684, 43.115420477730886, 46.988256045750205, 43.60470914840698, 41.984660216740195, 40.136536666325156, 40.190364360809326, 43.19699927738735, 42.67710379191807, 40.25457613808768, 39.79073177065168, 40.037528310503276, 41.44746371677944, 41.71825933456421, 42.25916617257254, 43.71700593403408, 47.9885812486921, 48.34985978262765, 44.30811698096139, 40.80173635482788, 40.07084839684622, 42.3405886377607, 42.69326530184065, 40.27105031694685, 38.64623144694737, 37.1449202810015, 37.87257385253906, 43.278109073638916, 34.09237166813442, 38.75824335643223, 48.36878320149013, 49.106577668871196, 51.54615272794451, 52.41612972532, 54.9895201410566, 54.36805588858468, 55.87881313051496, 54.98253720147269, 56.55261468887329, 56.478751863752095, 55.45494869777134, 55.840466022491455, 55.20104415076119, 50.596514633723665, 48.988169942583355, 50.098047392708914, 45.94053718021938, 44.9275141443525, 43.96780811037336, 43.69542482921055, 44.524435247693745, 45.3484707559858, 47.37927286965506, 48.500962257385254, 48.94314214161464, 52.74409164701189, 48.482344559260774, 48.2161625453404, 50.97975294930594, 50.554144518715994, 49.647404602595735, 52.07299293790545, 51.50867067064558, 51.5357095854623, 52.552602767944336, 54.875635692051475, 54.84577233450753, 54.96843235833304, 55.07288810185024, 62.07860388074602, 70.00052302224296, 69.91791588919503, 74.0350570678711, 71.09492683410645, 77.62489250728062, 72.38944571358817, 78.87550571986607, 12.240003091948372, 0.3945935448365552, 58.98835781642369, 74.70550959450858, 63.22618225642613, 63.44913605281285, 49.59359427860805, 57.96690661566598, 70.67113535744804, 14.614919083459036, 0.7798359000257084, 0.2353883305830615, 0.28478584278907093, 0.39690284377762247, 0.3124573693743774, 0.2259201614984444, 0.16670352832547256, 0.24251905509403773], [0.05438127727913005, 0.032349248616290946, 0.07498575307961021, 0.027752793028152416, 0.09070814906486444, 0.07576642797461577, 0.045745969217802794, 0.12715216992156847, 0.23602300509810448, 2.622212584529604, 51.610687596457346, 36.22575351170131, 29.95757164273943, 39.0610910143171, 46.063353538513184, 43.65583746773856, 74.58312402452741, 26.1593736239842, 0.02845789778179356, 0.41976795398763245, 2.817189242158617, 51.759521484375, 58.24703366415841, 69.73158604758126, 67.02513762882778, 68.51658235277448, 64.41372667040143, 58.89628723689488, 52.830780846732004, 53.45832824707031, 51.415113176618306, 50.08073943001883, 47.362864698682515, 50.66222374779837, 50.63365970339094, 52.59576497759138, 50.69527285439627, 51.19353859765189, 47.66498626981463, 47.17703512736729, 47.898820945194785, 47.53894247327532, 43.70921005521502, 44.12673078264509, 43.29297474452427, 43.01054089409964, 43.44858660016741, 42.738713468824116, 38.85559804098946, 40.88385016577584, 41.9472267968314, 43.00993640082223, 45.13746786117554, 49.20382465635027, 50.00881167820522, 46.492147718157085, 52.442109039851594, 51.359656129564556, 50.93040336881365, 51.0079904283796, 49.047528403145925, 46.97152130944388, 44.36457109451294, 48.65461819512503, 50.74842657361712, 53.102389403751914, 46.29628494807652, 39.309621129717144, 44.61770439147949, 48.01627676827567, 37.64867162704468, 37.41333614076887, 37.32966940743582, 34.96665307453701, 37.802362305777415, 37.5455117225647, 39.76866429192679, 39.724928855895996, 43.27202592577253, 46.537804331098286, 42.45461205073765, 45.510005950927734, 43.1034973689488, 39.40145894459316, 38.41268859590803, 35.02917296545846, 34.990739004952566, 33.681229387010845, 39.37205069405692, 41.734549386160715, 36.816551889692036, 34.6612936428615, 35.54528863089425, 34.45997306278774, 39.121790477207725, 40.89550576891218, 43.60052980695452, 44.05649839128767, 43.74776908329555, 40.74817269189017, 37.656686374119346, 38.43549953188215, 40.29884311131069, 39.00043324061802, 36.92832408632551, 36.26590715135847, 33.77406079428536, 35.74573373794556, 39.787552969796316, 54.82394804273333, 52.72151347569057, 42.287657260894775, 44.55963134765625, 44.63052034378052, 50.17768069675991, 49.492220061165945, 49.764568601335796, 45.734985147203716, 51.05132981709072, 50.123008796146934, 46.36434950147356, 52.17505155290876, 50.932206426348, 51.078354835510254, 47.89572899682181, 42.594288212912424, 42.81685985837664, 39.44767141342163, 35.275212151663645, 36.87476389748709, 38.27035822187151, 42.59064735685076, 40.51912532533918, 42.11283016204834, 40.87505374635969, 42.937286036355154, 43.730065073285786, 44.84588670730591, 44.05458068847656, 43.96088423047747, 43.77785478319441, 46.55879831314087, 44.40636450903756, 45.12569413866316, 45.57241467067173, 47.25526142120361, 45.77594130379813, 46.934921673366, 48.47972508839199, 50.046939917973106, 53.40955536706107, 67.01860632215227, 64.3819247654506, 68.84182058061872, 66.91824654170445, 68.82406793321881, 64.33703940255302, 64.82453196389335, 7.88970034463065, 0.22672429334904465, 50.87439046587263, 57.52378525052752, 54.005085468292236, 44.80616733006069, 29.766666412353516, 27.12655070849827, 48.614412443978445, 7.459342820303781, 0.5057313112275941, 0.07037273954067912, 0.13461309671401978, 0.08555489951478583, 0.0841506305815918, 0.12217804683106286, 0.09438389539718628, 0.02899179627586688, 0.06288110225328378, 0.03195409017748066, 0.09167918695935182, 0.05562244674989155, 0.07261354037161384, 0.06716191183243479, 0.02608883856529636, 0.01914465011629675, 0.09164312960846083, 3.398239948919841, 59.52679456983294, 38.29969351632254, 31.04291500364031, 48.92133174623762, 48.47274909700666, 48.97803599493844, 81.36678232465471, 31.35953746523176, 0.09414290011461292, 0.3194499984383583, 2.8357302929673875, 59.00027397700718, 62.23821095057896, 72.39891610826764, 70.9377794265747, 70.18342045375279, 66.76051548549107, 58.54742513384138, 55.807872022901265, 55.72623068945748, 54.024224281311035, 52.701002393450054, 53.073783670152935, 54.53077922548567, 55.05173431124006, 55.991971492767334, 53.5255103792463, 53.39517954417637, 50.637651443481445, 50.294643197740825, 50.43705000196184, 47.84187003544399, 46.710335050310405, 45.01458896909441, 45.985971450805664, 45.714901379176546, 45.96547079086304, 44.26497214181082, 42.347460406167166, 44.5142457144601, 44.8817081451416, 44.8602660042899, 48.054780210767476, 51.11036171231951, 51.52720151628767, 48.62624870027815, 54.06264781951904, 52.7583041872297, 52.20240313666207, 53.04326023374285, 53.80771146501814, 52.97778041022164, 46.47961664199829, 51.14243459701538, 52.830325739724294, 51.413629736219136, 46.93618624550955, 46.114891801561626, 46.59276110785348, 48.85457692827497, 40.26279238292149, 38.74271065848214, 38.92941917691912, 38.79312331335885, 40.76815571103777, 40.446384634290425, 40.88013287952968, 40.82879958833967, 46.975804873875205, 49.66181864057268, 45.286107199532644, 47.98457213810512, 45.57866110120501, 41.98403835296631, 40.16866513660976, 38.482194900512695, 36.67175490515572, 35.3252079146249, 41.05965001242501, 45.77051823479788, 38.04392685209002, 35.7251740183149, 36.534048557281494, 37.052391120365684, 40.457925592150005, 43.072894028254915, 45.91620806285313, 47.24247326169695, 46.757026944841655, 44.51445068631853, 39.146341936928884, 38.874174049922395, 40.364413261413574, 42.216052600315635, 38.8192137990679, 37.083512101854595, 37.40751355034964, 36.83112226213728, 39.38400854383196, 53.10134022576468, 52.98135873249599, 43.9175135748727, 45.10533939089094, 47.433420181274414, 51.47835915429251, 51.20109823771885, 50.40140921728951, 48.944875717163086, 53.900167669568745, 51.20051458903721, 50.25781774520874, 56.062818799700054, 53.775166102818076, 52.398033142089844, 49.04930019378662, 45.997779914310996, 45.69629757744925, 42.33712496076311, 38.997313499450684, 39.99252135413033, 41.98054688317435, 44.96473217010498, 44.03313159942627, 44.93453877312796, 43.375453335898264, 44.42445761816842, 46.75729097638811, 47.07091529028756, 46.50270898001534, 45.67471994672503, 46.57060330254691, 49.67867497035435, 46.93092993327549, 48.563047885894775, 48.99566010066441, 50.45417383738926, 48.89533158711025, 50.17679827553885, 51.25238983971732, 52.98228979110718, 57.06361648014614, 69.6462482724871, 67.44371100834438, 70.8349530356271, 69.27822998591832, 73.57177897862026, 66.49626854487828, 73.37643037523542, 10.726628116198949, 0.22094719191747053, 57.63325064522879, 62.59498010362898, 61.95846952710833, 53.325464793613975, 36.81813955307007, 31.78408976963588, 61.35220445905413, 11.369043792997088, 0.49874440899917055, 0.16650099919310637, 0.14537502851869377, 0.11561303053583417, 0.08138858593468155, 0.07594830928636448, 0.09498555239822183, 0.05720954015851021, 0.12113158298390252, 0.11986197611050946, 0.15926820944462503, 0.11198531091213226, 0.14762019232979842, 0.23162940942815372, 0.1716480537184647, 0.2472047193774155, 0.4454758002289704, 8.073060699871608, 76.39234461103166, 45.96748229435512, 42.94457817077637, 50.65668603352138, 60.58175345829555, 54.01862055914742, 86.50523921421596, 32.67211471285139, 0.4097718303757054, 1.0719834949289049, 3.5463757600103105, 63.61120973314558, 63.49951049259731, 72.23129081726074, 72.48491396222795, 74.10840920039585, 68.80445316859654, 62.70670713697161, 57.45550182887486, 59.164508547101704, 57.49172626222883, 56.139405318668906, 52.48191179547991, 55.147230352674214, 55.28121594020298, 59.2449825831822, 54.42185231617519, 56.88782358169556, 52.22727073941912, 51.78620604106358, 52.455974170139854, 51.396752561841694, 48.132068497794016, 47.916108063289094, 48.72359643663679, 48.691339424678254, 47.97912127631051, 46.3780061858041, 44.44700799669538, 46.6801347051348, 46.9117876461574, 46.46981273378645, 49.7566511290414, 53.026344844273154, 55.44205631528582, 49.938318729400635, 56.75424446378435, 55.08668375015259, 54.918676308223176, 55.461949007851736, 53.86081307274954, 55.66252613067627, 50.59125484739031, 52.52775600978306, 56.527740137917654, 53.875821181706016, 51.15775190080915, 46.27664239065987, 50.44134051459176, 50.04906954084124, 44.861551421029226, 44.97104460852486, 43.418184757232666, 41.26325307573591, 43.99477406910488, 43.274430002485005, 42.74999386923653, 43.86776099886213, 49.313651357378276, 52.21645934241158, 48.002814633505686, 50.46639224461147, 49.142256668635774, 46.3395722252982, 43.940790040152415, 39.97770084653582, 39.9757136617388, 37.64482579912458, 45.26812178747994, 46.84305953979492, 43.10829162597656, 38.42164134979248, 39.47787523269653, 38.744270529065815, 43.123977184295654, 46.297886507851736, 48.82197945458548, 49.74383865083967, 51.216286999838694, 47.565821579524446, 42.5991450037275, 40.43914461135864, 42.89056287493025, 44.91509076527187, 42.1802659034729, 40.81246089935303, 38.53293759482247, 37.17867462975638, 45.86943278993879, 55.460712228502544, 50.42534923553467, 44.9435019493103, 45.59755672727312, 49.54062121255057, 56.78608805792672, 52.88120739800589, 53.27056360244751, 50.14423554284232, 55.96589142935616, 55.844016551971436, 51.1052235194615, 58.04666151319231, 56.847089767456055, 55.58673518044608, 51.27706289291382, 47.95344420841762, 49.605197770254954, 43.96514000211443, 40.43016059058053, 42.97511550358364, 44.27983086449759, 47.07203047616141, 47.14604616165161, 46.38992234638759, 45.019212995256694, 45.81814118794033, 49.230061054229736, 49.88751350130354, 49.3272385597229, 48.22947529384068, 50.553606033325195, 52.021531105041504, 49.19668538229806, 50.876005922045024, 51.255936895098, 52.37202256066458, 51.14811822346279, 52.81560945510864, 54.35692834854126, 55.785908767155235, 58.22493144444057, 72.30553926740373, 69.11373138427734, 73.29098142896379, 72.51998152051652, 75.2245261328561, 71.83078275408063, 74.91087750026158, 12.455267838069371, 0.3541300860898835, 61.85665757315499, 69.04437446594238, 71.05594049181256, 60.618919372558594, 44.04165356499808, 44.521819250924246, 74.78590025220598, 15.739940132413592, 0.7682030413831983, 0.346119328801121, 0.2614956982433796, 0.2959149298923356, 0.18941978152309144, 0.2532072030007839, 0.18707586372537272, 0.15221824417156832], [0.03132062345477087, 0.015271641779690981, 0.02848656927900655, 0.011522540722840598, 0.05330018439729299, 0.18235604198915617, 0.031569533848336766, 0.1759685440255063, 0.043642269780061076, 0.8364187723823956, 43.678321838378906, 43.89851719992501, 27.145804166793823, 29.571408135550364, 52.6457051549639, 45.4952722958156, 72.17505209786552, 35.87467840739659, 0.11309654771217278, 0.4153212697378227, 6.647435826914651, 55.48104613167899, 59.1729645047869, 70.24594729287284, 66.50058337620327, 66.33590412139893, 58.5998979296003, 54.10077953338623, 51.805240631103516, 51.361372334616526, 48.889880725315635, 52.19904715674264, 49.695364543369834, 51.306231430598665, 51.80615084511893, 53.561668804713655, 49.946243149893625, 50.36413560594831, 46.693767070770264, 46.33424295697893, 46.273953437805176, 45.41015338897705, 43.84252166748047, 41.9862721988133, 41.18747254780361, 42.34625141961234, 44.009313174656455, 41.54146589551653, 38.724169390542166, 40.585702964237754, 41.840683119637625, 42.41288464409964, 44.29710408619472, 45.28166382653372, 47.14819662911551, 46.421967438289094, 52.68902717317854, 52.59533766337803, 47.832132135118755, 52.797620568956646, 52.61437920161656, 48.737065519605366, 46.046743869781494, 45.72897148132324, 47.27623803274972, 44.31334202630179, 34.20681544712612, 47.53267172404698, 53.660121304648264, 48.00781733649117, 38.09045546395438, 34.60004874638149, 38.28272254126412, 36.96857500076294, 37.04510940824236, 36.67448207310268, 36.230658939906526, 39.346460478646414, 46.32586342947823, 45.47450065612793, 44.39778348377773, 45.30832406452724, 41.46872867856707, 39.85777841295515, 40.25390216282436, 35.768482140132356, 35.98151043483189, 36.800709996904644, 43.66336931501116, 45.169589383261545, 40.18414919716971, 37.799068859645296, 34.21830776759556, 38.21309116908482, 42.18663740158081, 42.23140811920166, 45.1780001776559, 44.74043042319161, 44.86840581893921, 45.83796092442104, 41.1094651222229, 37.833094188145225, 37.43172802243914, 35.976156847817556, 37.14835616520473, 36.31551381519863, 37.19276557649885, 38.117192132132395, 33.44956602369036, 29.05349462372916, 50.98253222874233, 50.36710943494524, 40.231959751674104, 46.623124735695974, 45.87678050994873, 48.92066819327218, 46.93378564289638, 46.96072033473423, 47.44478743416922, 44.157243796757285, 49.10184594563076, 52.66441317967006, 48.53463322775704, 47.83057573863438, 49.89310680116926, 42.21293633324759, 41.046896593911306, 40.5417868750436, 37.27364955629621, 36.92022596086775, 40.40454953057425, 41.79674618584769, 42.64283527646746, 42.98292180470058, 43.03054475784302, 43.989469119480674, 42.09864888872419, 43.54864065987723, 45.075621945517405, 43.71194764545986, 45.15328196116856, 46.083875043051584, 44.44132784434727, 46.22256456102644, 47.48138359614781, 46.00860868181501, 46.68310506003243, 47.51877532686506, 47.683162757328574, 49.59171479088919, 51.32848303658621, 64.05032198769706, 64.85408960069928, 67.95475101470947, 66.00435692923409, 72.4858033316476, 61.942954199654714, 70.42980357578823, 11.849233797618322, 0.025076496547886303, 55.67678383418492, 58.332183837890625, 53.26304565157209, 46.982141630990164, 31.43302161352975, 27.871960401535034, 53.791501317705425, 6.919588948999133, 0.2445021958223411, 0.02650057361461222, 0.05782375005739076, 0.046921069733798504, 0.07856191761259522, 0.023881591291033795, 0.05844304896891117, 0.08581232891551085, 0.027589995513803194, 0.02344465036211269, 0.014559246167274458, 0.06044567043759993, 0.057604467895414145, 0.1004053440743259, 0.0104363452576633, 0.10316202829458884, 0.07943821166242872, 1.133690012352807, 53.23128890991211, 49.71082428523472, 27.587806871959142, 38.972831521715435, 58.919556753976, 53.2403632572719, 78.42521381378174, 39.41011987413679, 0.19478643712188515, 0.36951909746442524, 10.011788759912763, 63.358281408037456, 64.92136205945695, 70.50228718348912, 71.06630025591168, 69.55451120649064, 61.69884313855852, 55.9857702255249, 52.97363233566284, 54.41633197239467, 52.812798908778596, 53.63005992344448, 54.222310474940706, 54.41705111094883, 53.5572566986084, 55.7149954523359, 53.765442098890034, 52.5451786177499, 50.63495206832886, 48.568432739802766, 48.29352378845215, 48.008817877088276, 48.03767721993582, 45.46381780079433, 45.68776518957955, 45.29962491989136, 46.045236110687256, 44.80060877118792, 42.863815784454346, 42.70406975064959, 44.2368597303118, 45.14532279968262, 47.27469900676182, 47.76305314472744, 50.97631011690412, 46.92545822688511, 53.04269048145839, 55.88080031531197, 51.947279180799214, 55.82746941702706, 54.14984771183559, 50.7632713999067, 48.24161727087838, 49.23033550807408, 49.95601231711251, 47.036389691489084, 39.420330251966206, 49.55522632598877, 54.758773939950125, 49.27541889463152, 40.375158650534495, 37.13587720053536, 39.62948840005057, 39.766816071101594, 39.83735070909773, 39.7391483443124, 38.65648698806763, 40.883735520499094, 47.533502033778596, 49.01566049030849, 47.46689312798636, 48.36338792528425, 45.12039961133684, 42.58797230039324, 42.8557037625994, 37.827330657414024, 37.59103979383196, 38.0060452733721, 46.551196983882356, 47.0931008883885, 40.97648007529122, 39.00806583677019, 37.1091752733503, 39.34937872205462, 45.65582084655762, 44.0967493057251, 46.63397782189505, 47.82241160529, 47.71186229160854, 47.99257298878261, 41.5926775932312, 39.657288142613, 39.026419503348215, 39.063255378178184, 38.40248169217791, 39.227361406598774, 38.49424307686942, 38.97628477641514, 38.55819429670061, 34.24916819163731, 48.32941470827375, 50.829161167144775, 40.791439124516074, 48.01426179068429, 48.39632586070469, 50.394346373421804, 49.79416445323399, 48.79072298322405, 49.93314579554966, 48.683098861149375, 51.76355143955776, 52.76522806712559, 53.59993600845337, 50.53909124646868, 52.15518665313721, 44.78630243028913, 45.13767283303397, 43.68058000292097, 41.442999499184744, 40.31069326400757, 42.96199035644531, 43.75655508041382, 45.4225628716605, 45.25951296942574, 44.93048449925014, 46.698332037244526, 45.11100217274257, 47.769146714891704, 47.20752034868513, 48.012288502284456, 48.67581714902605, 49.682906423296245, 46.512026514325825, 50.30249466214861, 50.36433710370745, 48.37005819593157, 49.68471295492989, 51.24385050364903, 50.313705580575125, 51.98321526391165, 54.67184155327933, 67.81139578138078, 68.93540586744035, 72.71744237627301, 70.23879759652274, 76.96747480119977, 63.64624949863979, 76.929183278765, 15.907136372157506, 0.08951175611998353, 63.64816720145089, 63.146180697849815, 60.44465160369873, 57.40152127402169, 37.837846755981445, 30.80752045767648, 67.2385584967477, 10.028991631099156, 0.298672903329134, 0.06355607496308428, 0.05707580769168479, 0.07328678960246698, 0.08849096125257866, 0.03146937529423407, 0.030758542008697987, 0.022599696148453013, 0.11968915324125971, 0.08914201560297183, 0.10566730171974216, 0.08289453334042005, 0.12034590728580952, 0.26433816286070005, 0.10992941087377922, 0.19459967714335236, 0.21773645920412882, 2.055186382361821, 69.17488248007638, 57.834248134068076, 36.60855756487165, 40.43219641276768, 70.28050763266427, 57.12718207495553, 83.17546095166887, 42.23817566462925, 0.28351388818451334, 0.9128904832260949, 11.90021446772984, 66.74529198237828, 63.226522718157085, 73.60500526428223, 72.77388954162598, 69.56780311039516, 64.06954765319824, 58.313180514744346, 57.10169955662319, 56.537432874952046, 55.38988924026489, 55.64116389410836, 54.86948306219918, 56.365121023995535, 55.28632634026663, 59.323698725019185, 55.06302513395037, 53.39405393600464, 51.669462408338276, 49.84787055424282, 51.217495986393516, 48.7638577733721, 50.6613586970738, 48.2788005556379, 48.556513105119976, 46.60708829334804, 48.8577036176409, 45.86515269960676, 43.310960156576975, 46.00563832691738, 46.250121116638184, 47.25707490103585, 50.06637750353132, 49.04164675303868, 52.95147453035627, 49.425110885075156, 55.65925005504063, 57.81307002476284, 53.37564468383789, 58.12404012680054, 57.9950225012643, 51.93378925323486, 50.51703419004168, 50.50671264103481, 52.94910519463675, 51.268415859767366, 41.6820626940046, 53.13225276129586, 56.12320211955479, 51.36983871459961, 42.688571793692454, 42.95883240018572, 41.81990453175136, 41.36575290134975, 41.562984466552734, 41.01937477929251, 39.61888892310006, 43.46703059332711, 51.163584913526265, 50.648369039808, 51.46285424913679, 54.1154784475054, 48.35789884839739, 44.992698669433594, 45.33660323279244, 41.255144527980256, 39.39161334718977, 40.97100142070225, 48.35024888174874, 48.90386744907924, 42.953614303043906, 41.071489742824006, 39.15321717943464, 41.83434288842337, 48.11290536608015, 48.51235382897513, 51.31344018663679, 51.07603413718087, 51.18509306226458, 52.260333742414204, 45.22625889096941, 41.04022632326399, 41.60821376528059, 41.17280837467739, 42.06291430337088, 42.18670340946743, 41.95271587371826, 42.085780824933735, 39.551435811179026, 38.70102146693638, 51.41737828935896, 48.9635385785784, 41.59652689525059, 50.60500533240182, 51.21200690950666, 52.65104137148176, 50.98699992043631, 52.14580658503941, 53.4398147719247, 51.493575709206716, 54.587709290640696, 55.56186062949044, 54.43996974400112, 52.934805801936555, 54.221007687704905, 45.25052547454834, 45.9356004851205, 45.69294854572841, 44.019106660570415, 43.75163228171212, 44.66245426450457, 45.76032870156424, 47.99639449800764, 47.19826187406267, 47.186790398189, 49.84583125795637, 48.003019605364116, 49.712088857378276, 49.190133231026785, 51.36445733479091, 51.639147417885916, 52.53572906766619, 47.3295168195452, 52.12516696112496, 53.05120202473232, 49.93339940479824, 52.325539112091064, 53.612745012555806, 54.023272378104075, 54.678049768720356, 56.10671404429844, 71.17446286337716, 72.40467616489956, 73.46828556060791, 70.88060270036969, 80.13066305433, 65.77913107190813, 74.97742734636579, 18.757655688694545, 0.23879427782126836, 65.99830504826137, 70.68661594390869, 69.83688599722726, 64.30824606759208, 47.84157126290457, 44.95750951766968, 80.83643327440534, 13.765487909317017, 0.40878505046878544, 0.16335267813077994, 0.292325208229678, 0.24546460275139126, 0.139292409909623, 0.10297556008611407, 0.1653808464429208, 0.17792737962944166], [0.024981063990188495, 0.021310418544869338, 0.04252763691225222, 0.047474683062838655, 0.039449954738042185, 0.14075203372963838, 0.03716173448732921, 0.040054614256535254, 0.08059478138706513, 0.24816620349884033, 30.40346881321498, 51.72433580671038, 31.715323448181152, 29.210438796452113, 44.605204582214355, 35.50894955226353, 65.47772516523088, 44.17012923104422, 0.5261381162064416, 0.1403210282857929, 19.022611345563615, 67.74390098026821, 63.86069175175258, 70.48515292576381, 65.55952630724225, 64.86142689841134, 54.29465511866978, 51.456163133893696, 50.73344278335571, 50.49054070881435, 49.694568974631174, 52.61906228746687, 50.48782743726458, 51.25283452442714, 51.126443317958284, 51.13212694440569, 49.99426562445504, 49.88080154146467, 48.820242404937744, 45.261840615953716, 45.02026217324393, 43.941217354365754, 43.47156776700701, 44.363153662000386, 43.46302148274013, 44.058270181928364, 41.20491600036621, 44.11518635068621, 42.18709250858852, 37.341377122061594, 40.43360342298235, 41.83992229189192, 44.059847423008506, 45.27798475537981, 51.06626149586269, 48.44361530031477, 50.029343605041504, 50.833833830697195, 52.59927034378052, 51.46618938446045, 51.91339976446969, 50.033616747174946, 48.29161998203823, 46.03337206159319, 47.597779818943565, 44.82580988747733, 44.205881186894004, 51.118720395224436, 50.18178013392857, 48.523988587515696, 42.26450933728899, 39.84608459472656, 39.47788218089512, 36.60538918631417, 36.196821212768555, 35.456035545894075, 36.384533745901926, 41.03603308541434, 41.34559965133667, 45.496206828526084, 44.31054537636893, 45.71583243778774, 42.76888254710606, 43.62002992630005, 42.39515284129551, 39.5749763080052, 37.5326749256679, 38.35275343486241, 46.320061683654785, 46.14953899383545, 41.894295419965474, 39.54385880061558, 40.58938898359026, 41.98772437231881, 42.33668027605329, 42.0713563646589, 43.88028860092163, 45.32483993257795, 44.09955985205514, 45.05591338021414, 39.27940688814436, 37.583702496119905, 36.400337423597065, 36.95218072618757, 35.74785641261509, 34.33596856253487, 35.37180948257446, 36.45355020250593, 39.165157658713206, 39.119897093091694, 34.49290405000959, 49.630127906799316, 44.29602364131382, 41.10893358503069, 50.52756765910557, 47.555017130715505, 45.26212201799665, 43.58723790305001, 44.48953097207205, 48.56340571812221, 50.295758383614675, 50.844158853803364, 53.05291475568499, 49.033816133226665, 44.1532416343689, 41.6331022126334, 40.296188899448936, 38.29984637669155, 37.749368395124165, 39.01237024579729, 39.00884403501238, 42.20210409164429, 43.445008277893066, 43.09775120871407, 45.0431147984096, 45.97308949061802, 44.517368929726736, 43.26572043555123, 46.28264910834176, 44.38433524540493, 45.91060781478882, 45.61660173961094, 48.432060446058, 48.94200611114502, 49.04942178726196, 49.496611322675435, 49.41638742174421, 48.32387004579817, 48.20902327128819, 50.29721403121948, 49.77595322472708, 59.947834559849326, 64.94996779305595, 65.67068358830043, 67.2919692993164, 71.04768603188651, 64.90289374760219, 72.96914781842912, 14.545768874032156, 0.167040475245033, 60.6730180467878, 48.90365205492292, 51.56522900717599, 37.97095339638846, 29.35907813480922, 27.73915079661778, 55.64590951374599, 7.410785334450858, 0.3528337585074561, 0.164751817339233, 0.03733556158840656, 0.028123307075085383, 0.04144423022600157, 0.020683172291943004, 0.05152677884325385, 0.180754047951528, 0.017657847576109425, 0.04041052622986691, 0.02594310281399105, 0.0342687834719462, 0.01613029052636453, 0.04676329337858728, 0.026743923413700292, 0.08041227582309927, 0.02177641773596406, 0.10534577111580543, 36.99194179262434, 58.10596438816616, 31.78504514694214, 39.41950341633388, 50.85603679929461, 42.39794601712908, 72.48577553885323, 48.345235756465364, 0.6657357854502541, 0.21539079078606196, 26.50336503982544, 74.12952477591378, 68.89559963771275, 73.93498911176408, 68.81541742597307, 65.82772677285331, 58.37673568725586, 52.12399271556309, 52.74697514942714, 54.118730204445974, 53.90833527701241, 55.04757581438337, 54.062307357788086, 53.836890425000874, 54.87362766265869, 54.13857773372105, 52.16798176084246, 51.63356801441738, 51.9661157471793, 48.49455254418509, 48.61025742122105, 46.79892805644444, 45.43626124518258, 47.29118708201817, 45.50038269587925, 45.47857230050223, 44.329656396593364, 47.351844855717246, 43.451626437050955, 41.31718151909964, 42.605367115565706, 43.8643251146589, 45.89684343338013, 47.51210158211844, 53.30159773145403, 51.44743619646345, 51.72149746758597, 53.971991198403494, 53.7284950528826, 54.23675230571202, 52.12120648792812, 52.98910597392491, 49.39052275248936, 48.19240665435791, 50.04903827394758, 46.65865087509155, 46.595154762268066, 52.57518093926566, 50.61043534960066, 50.098940236227854, 44.59952442986624, 41.045197759355815, 40.30331080300467, 38.949593271527974, 38.34467962809971, 38.81789016723633, 39.79967410223824, 42.54193353652954, 43.386410645076204, 47.813285146440776, 47.271103313991, 48.65827989578247, 45.56677968161446, 46.49702187946865, 45.42864601952689, 41.3753205708095, 38.69219030652727, 40.86334950583321, 48.93620783942086, 48.32758385794503, 42.889472007751465, 40.62575238091605, 41.878397941589355, 45.15590490613665, 43.36107751301357, 44.90839965002877, 46.95662784576416, 49.676545347486226, 47.89825119291033, 46.36013541902815, 41.731898648398264, 39.17781727654593, 37.83507789884295, 38.10111747469221, 37.70508405140468, 37.5133033479963, 38.612220014844624, 37.81269080298287, 38.073824950626914, 43.57730892726353, 39.903549671173096, 48.499986035483225, 43.745274680001394, 42.33848680768694, 52.26656627655029, 48.906372274671284, 46.57624176570347, 47.371859141758506, 48.33853769302368, 51.68417869295393, 51.99175459997994, 53.18590327671596, 54.8198937688555, 52.26100771767752, 47.45529311043875, 43.33594935280936, 44.19202995300293, 42.069640159606934, 39.552172320229666, 41.45808751242501, 42.79280866895403, 44.88390724999564, 46.365645340510774, 45.40495613643101, 46.82285417829241, 47.40838234765189, 46.80483055114746, 46.04619148799351, 47.984283787863596, 47.88773162024361, 48.06804779597691, 49.21376058033535, 50.920391014644075, 52.81104448863438, 52.46829332624163, 52.371400696890696, 52.67510298320225, 52.274386474064414, 50.370225702013286, 53.3426650592259, 51.59992831093924, 62.88299683162144, 68.81384018489292, 69.33887386322021, 69.7540009362357, 74.96606009347099, 66.26702662876674, 76.31333664485386, 19.800126927239553, 0.11919637396931648, 68.1597159249442, 54.45646824155535, 60.75268609183175, 48.25418308803013, 32.92408766065325, 34.017873082842144, 69.13911315373012, 10.012753690992083, 0.43812178341405733, 0.13759858294257096, 0.023850178512345468, 0.027808483789807985, 0.060677776911429, 0.03925098791452391, 0.07055201527795621, 0.05848954897373915, 0.09341732904847179, 0.08601745683699846, 0.17962625489703246, 0.11563071315842015, 0.23767781630158424, 0.139628176178251, 0.1299178379454783, 0.0978024091039385, 0.22243003520582402, 0.26405209249683786, 53.62293107169015, 63.980582918439595, 43.41960218974522, 38.62678691319057, 59.90797969273159, 44.477288246154785, 78.22462626865932, 50.42492886951992, 0.6629450523427555, 0.46633535091366085, 29.202552591051372, 78.69902842385429, 69.01381628853935, 74.42223848615373, 71.64830916268485, 68.75262655530656, 58.68732016427176, 54.99535662787301, 55.07628229686192, 56.14422736849104, 56.45209162575858, 58.196051256997244, 56.159162521362305, 55.76586668831961, 56.58487170083182, 57.435998235430034, 55.50418710708618, 53.774728366306846, 54.102867467062815, 50.29282624380929, 49.51398181915283, 48.36004931586129, 48.576760155814036, 49.62743200574602, 48.41663891928536, 47.80831718444824, 45.098884514399934, 50.386053698403494, 46.75491469247, 43.12879923411778, 44.200600555964876, 47.52300330570766, 49.275200026375906, 49.60611840656826, 55.306257247924805, 53.32167455128261, 53.9085819380624, 56.34741701398577, 55.40949010848999, 58.06512287684849, 54.025113650730674, 55.05259936196463, 52.59732484817505, 49.090978963034495, 51.291553361075266, 48.392528670174734, 45.76771811076573, 54.24610458101545, 54.34170831952776, 53.492655822208945, 47.77681752613613, 45.32557644162859, 42.51140662602016, 41.969422817230225, 40.69099596568516, 39.394524642399375, 41.96602514811924, 46.52985906600952, 45.5385491507394, 51.24816186087472, 49.96625396183559, 53.00014318738665, 50.851840087345664, 50.92450434820992, 48.77243185043335, 44.28459732873099, 41.148597376687185, 43.57952192851475, 52.3798497063773, 50.443626471928184, 46.624444893428254, 45.20024830954415, 44.15386002404349, 48.662184783390586, 48.83400331224714, 47.57867922101702, 51.45194557734898, 52.762643337249756, 50.48538514545986, 49.9484908921378, 44.36976834705898, 42.38392802647182, 40.9862631389073, 39.23176656450544, 39.58069814954485, 38.5654273714338, 40.360390254429404, 39.71506936209542, 41.00120176587786, 43.34487778799874, 44.7239145551409, 51.37675217219761, 42.49880954197475, 43.326075962611604, 54.20477669579642, 52.16861057281494, 49.9396527835301, 49.99920926775251, 50.55277572359358, 52.78850105830601, 52.37449959346226, 54.17871400288173, 58.88844966888428, 52.839493887765066, 50.170388562338694, 45.58461570739746, 46.32326480320522, 44.37372882025582, 43.42027269090925, 45.16940525599888, 44.86178765978132, 47.02626964024135, 48.9135080746242, 47.675137587956016, 49.828144618443076, 52.527391229357036, 49.89654963357108, 48.730152062007356, 50.96098933901106, 49.95018972669329, 50.71791703360421, 51.91786745616368, 54.6498053414481, 56.16832719530378, 54.72536700112479, 54.913124697549, 55.79672711236136, 56.160715443747385, 53.423538616725374, 56.854215145111084, 53.38873856408255, 66.24404893602643, 70.92799636295864, 71.942718233381, 74.0158383505685, 77.92256028311593, 69.0427416392735, 77.31757368360246, 27.41471334866115, 0.24661982219134057, 73.35234791891915, 60.240173067365376, 67.65967491694859, 55.30927971431187, 42.98757014955793, 44.99389028549194, 81.54828316824776, 14.496608631951467, 0.7135183843118804, 0.33664328871028765, 0.18864798865148, 0.10614300905061619, 0.11907308415642806, 0.10863178728946618, 0.36038308484213694, 0.25613223175917355], [0.015042023833042808, 0.04172486552436437, 0.06983954672302518, 0.0296327811665833, 0.07580937245594603, 0.09609695883201701, 0.05430679788280811, 0.05096268214817558, 0.0388571492263249, 0.1326808732535158, 23.741539478302002, 56.00926555906023, 36.31692429951259, 24.535897493362427, 42.98016684395926, 42.146337849753245, 58.7039680480957, 51.85367999758039, 0.5362068159239632, 0.3010652278150831, 38.546069690159385, 63.353348187037874, 66.31936046055385, 68.45719609941754, 65.03752899169922, 59.95048877171108, 49.369844913482666, 49.831438064575195, 48.641750131334575, 52.23709201812744, 52.513609477451865, 53.69042934690203, 53.92657777241298, 53.8317174911499, 52.8691349029541, 53.637438910348074, 51.312432697841096, 49.365026337759836, 46.40915148598807, 45.323967933654785, 47.12807812009539, 46.76056357792446, 45.902940477643696, 45.896301473890034, 45.59276941844395, 43.97981807163784, 43.09229687282017, 42.47565467017037, 40.375929900578086, 39.24189703805106, 39.42838668823242, 41.79514810017177, 40.90467044285366, 45.742572580065044, 47.30477428436279, 47.99566493715559, 50.796831199101035, 53.61664295196533, 51.68398414339338, 53.69908332824707, 52.25516080856323, 52.97723150253296, 48.36528130940029, 46.39458458764212, 46.56098699569702, 48.38612937927246, 50.440353870391846, 48.24354887008667, 51.86600957598005, 50.907700129917686, 46.40646253313337, 41.30248955317906, 35.372316701071604, 36.39344481059483, 35.998863560812815, 38.12870529719761, 37.14125163214547, 39.12659515653338, 39.97460194996425, 41.22347116470337, 46.000166620527, 44.85019111633301, 41.42175538199288, 41.93992076601301, 43.73142344611031, 41.49558694022042, 39.84540714536394, 42.98939752578735, 44.760003498622346, 48.29980148587908, 42.9553860936846, 39.73029286520821, 40.55249057497297, 40.44173976353237, 42.080239636557444, 43.376978465488975, 43.954321656908306, 45.64627054759434, 43.8667048726763, 40.87909412384033, 40.09557703563145, 36.701976094927105, 35.4909085546221, 37.572564533778596, 35.50675392150879, 34.95053672790527, 36.00904614584786, 38.892739636557444, 38.32585000991821, 41.969902242933, 37.44863298961094, 40.01354660306658, 41.065218993595664, 41.222755500248496, 41.58834886550903, 45.734933035714285, 41.466189111982075, 45.2869861466544, 48.79409633363996, 49.90267447062901, 49.9072915485927, 49.86968789781843, 48.82176753452846, 48.062822750636506, 42.197393212999614, 39.693814822605674, 40.25990540640694, 39.5926525252206, 38.44075237001692, 40.21938698632376, 40.506854806627544, 39.659428187779014, 42.90333366394043, 43.99313082013811, 46.25614520481655, 45.88537195750645, 44.074178082602366, 44.57614721570696, 44.592770780835835, 45.63499014718192, 44.128363609313965, 47.75706032344273, 46.85873467581612, 48.652356556483674, 48.88532618113926, 52.58723953792027, 52.17776135035923, 50.73187943867275, 48.10440077100481, 49.77312183380127, 48.508494104657856, 53.76224940163748, 61.48043346405029, 65.14312771388462, 66.06148501804897, 71.16559001377651, 65.0831995010376, 72.5791106905256, 10.781964438302175, 0.41022235048668726, 59.951350348336355, 51.16122947420393, 49.16645377022879, 40.60491820744106, 31.06340524128505, 33.16047927311489, 62.4473169871739, 5.377458853381021, 0.3733763247728348, 0.08451906152601753, 0.1523879864918334, 0.09749772652451481, 0.04891389994216817, 0.07324695281152215, 0.0295616435552282, 0.05435003413419638, 0.03203425908993397, 0.0708063980564475, 0.044278006202408245, 0.05279735941439867, 0.06989190927041428, 0.05414060769336564, 0.019274107812504684, 0.019089449596192156, 0.012162434868514538, 0.14880666509270668, 29.60747276033674, 65.0676633289882, 34.061719690050396, 28.14380693435669, 51.31648697171892, 46.03492498397827, 66.40874208722795, 54.114210401262554, 0.6722019527639661, 0.1878412783678089, 45.63414246695382, 68.17578710828508, 71.05571814945766, 70.84788363320487, 68.4885950088501, 63.9461476462228, 51.94127593721662, 52.032780238560264, 52.95693928854806, 54.101741858891074, 54.291785512651714, 55.92039462498256, 55.98365797315325, 55.82176842008318, 55.26539141791207, 56.543887751443044, 53.90913084575108, 49.99732978003365, 49.84537615094866, 48.44065536771502, 50.95202963692801, 50.1271846635001, 50.25130728312901, 47.16369111197335, 49.275637762887136, 46.4371839932033, 44.50490386145455, 44.798343658447266, 42.862929889133994, 40.55019766943795, 41.27687154497419, 44.077992643628804, 43.2551383290972, 47.06538452420916, 49.16509887150356, 50.73082678658621, 53.16658728463309, 53.99562897000994, 52.24293892724173, 56.80398661749703, 54.74882064546858, 54.314579078129356, 50.471634660448345, 48.5910769190107, 46.874882289341514, 50.568947655814036, 51.62338195528303, 50.764007908957346, 54.317848205566406, 51.85544831412179, 49.870198590414866, 43.83087996074131, 37.871347495487754, 38.520295347486226, 38.91957010541643, 39.592972142355784, 38.726691586630686, 41.157841954912456, 43.12563780375889, 45.30273771286011, 51.39271913255964, 49.0500853402274, 46.0780211857387, 45.451283250536235, 47.276581968579976, 45.629330839429585, 42.54416390827724, 43.82390744345528, 47.85026693344116, 48.81544814790998, 45.00527490888323, 42.29243067332676, 43.252973965236116, 43.99062599454607, 44.43780858176095, 46.02582631792341, 48.27308218819754, 47.87124007088797, 46.19601896830967, 42.73713275364467, 42.74081529889788, 39.726728439331055, 37.228482791355674, 37.9434107371739, 36.87343679155622, 38.776409421648296, 36.76788670676095, 40.04778037752424, 40.620082650865825, 45.63864489964077, 42.06761128561837, 43.39347348894392, 44.22666672297886, 43.01955270767212, 45.70928028651646, 48.60000188010079, 44.60288388388497, 49.2104115486145, 50.5751176561628, 53.15562302725655, 50.805363586970735, 51.09280708857945, 49.90736103057861, 50.65192651748657, 45.595809255327495, 41.665630204336985, 41.73169715063912, 41.64702640260969, 39.42817824227469, 42.78742381504604, 41.77179173060826, 44.305372442517964, 45.16764388765608, 48.06493500300816, 47.598665714263916, 49.753753730228965, 48.93854938234602, 47.59025491986956, 46.45969615663801, 48.97101484026228, 47.90132924488613, 52.23474700110299, 49.085097312927246, 51.469486304691856, 52.9609067099435, 54.888962336948936, 56.646516118730815, 55.7744060243879, 51.581143856048584, 52.79423679624285, 51.707389150347026, 57.84963839394705, 63.303161348615376, 70.79437555585588, 66.36744894300188, 76.59106309073312, 66.6762546811785, 75.77362142290387, 12.400319746562413, 1.0964212864637375, 67.87190764290946, 57.26769202096121, 56.7346852847508, 52.916139466421946, 43.12146193640572, 41.96960694449288, 68.7128689629691, 6.508902209145682, 0.19559451804629394, 0.09889487762536321, 0.0881020724773407, 0.033824617841414044, 0.0352565811813942, 0.05902187326656921, 0.016515671275556087, 0.02199821387018476, 0.19434665143489838, 0.1612776501902512, 0.1414155595536743, 0.12923109265310423, 0.1420670888785805, 0.10487123086516346, 0.16133456570761545, 0.08009212264525038, 0.2392015888222626, 0.2698671376066548, 41.995652266911094, 72.72761453901018, 49.772242886679514, 32.235813004629954, 60.848196029663086, 55.35780593327114, 70.28611482892717, 59.71388176509312, 0.7870265256081308, 0.44595256607447353, 48.06095368521554, 69.0050129209246, 71.75588117327008, 71.400862966265, 70.7897619519915, 66.34143488747733, 53.751771518162315, 54.7461907523019, 54.00499514171055, 56.16001714978899, 57.20426886422293, 58.215217862810405, 59.230141230991904, 55.24639504296439, 58.10844489506313, 59.23834705352783, 56.54024689538138, 52.46007360730852, 51.60062313079834, 49.97161102294922, 52.30119957242693, 51.82066910607474, 52.34506355013166, 50.138711724962505, 51.806748390197754, 47.71005228587559, 47.285472188677105, 46.53952401024954, 44.0840653691973, 43.00273806708199, 45.792481490543906, 46.58586502075195, 44.588799885341096, 50.10055569240025, 53.21530110495431, 52.28325237546648, 54.799660614558626, 57.741850989205496, 55.00576155526297, 58.765001024518696, 58.11578219277518, 56.25798674992153, 52.98943253925869, 51.84887184415545, 49.71798092978341, 51.64729765483311, 55.76389339991978, 52.28620883396694, 55.41923495701381, 54.36821917125157, 51.648200920649934, 46.792469705854145, 39.80535772868565, 41.14142336164202, 40.99721002578735, 42.989974226270405, 41.55174922943115, 44.08541331972395, 46.667784282139365, 47.14830780029297, 52.923983982631135, 51.85864795957293, 50.19038895198277, 48.04650838034493, 49.343629360198975, 47.70356614249093, 45.84670870644705, 47.007394858769004, 49.716924803597585, 52.59342343466622, 45.209916727883474, 45.424237387520925, 46.261502265930176, 46.616308552878245, 49.366808550698416, 51.03357022149222, 52.24800763811384, 51.014778818402974, 49.8342034476144, 46.41534580503191, 46.35183579581124, 41.581136635371614, 39.07951763698033, 41.975349630628315, 37.17026383536202, 39.817058495112825, 39.43498747689383, 42.84962408883231, 41.75266681398664, 47.674255166734966, 46.70652396338326, 46.25857012612479, 46.57624871390206, 47.48324571337019, 48.60052299499512, 52.38526235307966, 46.57652316774641, 51.848347255161826, 54.120248385838096, 55.263612679072786, 53.17645372663225, 54.5187588419233, 53.164853709084646, 52.07734251022339, 48.72677871159145, 43.367066860198975, 44.593788691929404, 44.5214718409947, 43.28276784079415, 45.03429058619908, 44.69847025190081, 46.39251749856131, 47.42758369445801, 49.0469343321664, 50.15031521660941, 53.09561143602644, 49.689114638737266, 50.47599812916347, 49.74891778400966, 52.289085388183594, 49.50561966214861, 53.64317464828491, 52.06167779650007, 54.80014698845999, 55.65090874263218, 59.73562962668282, 59.06817177363804, 57.405394894736155, 52.84203345435006, 57.34633520671299, 54.93807567868914, 60.90080084119524, 67.1307988848005, 75.04984147208077, 70.66841166360038, 79.95300456455776, 70.00777694157192, 80.50295448303223, 22.303225891930715, 1.3793221861124039, 75.46867193494523, 64.084805897304, 66.18113994598389, 57.83624921526228, 46.397065094539094, 49.64108869007656, 85.95088413783482, 10.126782315117971, 0.47765521492276874, 0.19972222298383713, 0.32601878738829065, 0.16902227247399942, 0.11676595652742044, 0.11244498446051564, 0.06754003225692681, 0.10884635363306318], [0.1437070130237511, 0.04519717348739505, 0.013743519001374287, 0.03337338866133775, 0.015838223609275053, 0.08493999072483607, 0.19855678480650696, 0.020754725505997027, 0.13967252522706985, 0.18504062507833752, 19.597809280667985, 59.39307648794991, 47.96849748066494, 35.778147084372385, 34.34290286472866, 45.102521896362305, 52.75337791442871, 56.727389676230295, 0.5318272252167974, 0.6243744077427047, 48.132950919015066, 65.05740778786796, 68.35588441576276, 65.88344437735421, 63.581415857587544, 56.74391596657889, 49.667206968579976, 50.574210916246685, 52.71013232639858, 53.06567859649658, 56.11018466949463, 53.62700966426304, 54.5738719531468, 56.99420745032174, 54.838070256369456, 54.741743905203684, 50.10260541098458, 47.66513565608433, 46.22292586735317, 50.05346080235073, 52.71126140866961, 56.129441601889475, 54.75107186181204, 52.916035243443076, 48.623229707990376, 45.41375255584717, 43.136282444000244, 42.31748587744576, 40.27492046356201, 39.085055351257324, 39.6993316922869, 41.42298868724278, 39.43601928438459, 42.676266533987864, 44.44812665666853, 47.316739082336426, 47.48212705339704, 50.91338723046439, 51.342650413513184, 51.99851867130825, 51.721358503614155, 52.21062980379377, 51.25937972749983, 47.51137202126639, 44.945732321058, 44.85469354901995, 46.81634719031197, 50.36075183323452, 50.56604330880301, 51.62063046864101, 46.463472502572195, 40.00391639981951, 42.56173937661307, 37.32642807279314, 36.999518803187776, 38.03168065207345, 36.275360175541465, 38.414852959769114, 38.278463295527864, 43.507423945835654, 45.02197143009731, 45.06089176450457, 41.640126841408865, 39.9594270842416, 43.1214028767177, 44.10240861347744, 40.422930989946636, 43.10702010563442, 42.80047253199986, 43.527424335479736, 42.46337372916085, 40.28928933824812, 44.36023194449288, 41.81879281997681, 39.58614901133946, 41.138446058545796, 46.522306374141145, 42.79719645636422, 44.33829648154122, 41.668194089617046, 38.74772378376552, 39.441442353384836, 34.40656920841762, 35.6061235836574, 36.633348737444194, 34.302999360220774, 36.09941094262259, 38.83035176140921, 42.96341126305716, 48.96972942352295, 41.04478086744036, 40.26220178604126, 39.109950746808735, 40.91909837722778, 44.70456382206508, 43.357513087136404, 45.81816898073469, 49.628370012555806, 49.86706495285034, 49.74022558757237, 45.66648980549404, 48.37180914197649, 49.85993957519531, 46.115284374782014, 42.229302815028596, 38.27312707901001, 40.29418087005615, 37.037369115012034, 38.21912220546177, 38.9268205506461, 43.45210586275373, 41.6136611529759, 44.04925489425659, 45.5379307610648, 49.53235980442592, 52.20882327216012, 52.65887199129377, 51.035057135990684, 49.88060699190412, 47.20642948150635, 47.064602851867676, 45.56015804835728, 46.48047474452427, 49.3705084664481, 49.28759561266218, 49.90561008453369, 50.67018290928432, 52.39236341203962, 51.017787388392854, 49.14884008680071, 50.00537926810128, 50.030090536390034, 53.18649387359619, 61.8976936340332, 60.47397300175258, 69.30588381631034, 61.49353081839425, 67.48593521118164, 4.628136021750314, 1.6573533756392342, 64.07352897099086, 43.50456823621477, 42.45477185930525, 32.52536528451102, 27.264672211238317, 36.89958981105259, 57.1103709084647, 3.1771159172058105, 0.30643146272216526, 0.04721347422205976, 0.17683302478066512, 0.09049033932387829, 0.07182830572128296, 0.011021672465306307, 0.020310447917186787, 0.050613009304340394, 0.06703752279281616, 0.02141109787459884, 0.03738040936046413, 0.02294567267277411, 0.002647841054048123, 0.06291369907557964, 0.07633617347372429, 0.066891610622406, 0.31975265219807625, 0.28263287831630024, 22.14960469518389, 64.21557794298444, 46.97841044834682, 35.734199728284565, 41.287405014038086, 48.126888615744456, 58.87368474687849, 60.39773736681257, 0.4336232862302235, 0.8171173280903271, 55.19547864368984, 68.34306498936245, 69.73389979771206, 68.51021085466657, 65.44461005074638, 58.24536609649658, 52.84045968736921, 52.380224909101216, 53.28465454918997, 54.38823693139212, 57.984485558101106, 57.23886047090803, 58.26015533719744, 57.5798294203622, 58.30359200068882, 56.49540669577462, 53.49932261875698, 50.733967372349326, 50.88647338322231, 54.05041551589966, 56.023064681461875, 58.69679750714983, 56.87054688589913, 58.48706613268171, 50.498895917619976, 48.34606606619698, 45.64213636943272, 44.34360490526472, 42.97735629762922, 42.082820892333984, 41.56022950581142, 42.03154666083199, 40.97016416277204, 45.38422966003418, 46.46353851045881, 48.70335633414132, 49.15133101599557, 51.93581117902483, 54.73920086451939, 53.78345530373709, 54.868680545261924, 54.373600551060264, 52.749393122536794, 49.35538918631417, 46.560344287327354, 47.828967230660574, 50.226675919124055, 51.69738374437605, 53.86526686804635, 56.099401065281455, 47.603571142469136, 40.82322365897042, 41.57107216971261, 38.85843985421317, 39.388007232121055, 39.73223141261509, 39.7579779624939, 39.27542904445103, 40.903183528355186, 45.98388351712908, 47.90253128324236, 49.49234512874058, 47.41229765755789, 44.95114149366106, 45.785776478903635, 47.34985767092024, 42.810519627162385, 44.794595105307444, 43.44101653780256, 45.22393124444144, 45.59522908074515, 41.569578307015554, 46.690028939928325, 44.36706549780709, 44.363657406398225, 45.029211453029085, 50.414499623434885, 48.34273093087332, 47.82700089045933, 45.06167343684605, 40.05184507369995, 39.554350580487935, 36.37332282747541, 36.91048111234392, 37.947239194597515, 37.304794856480186, 37.366991656167166, 41.44116517475673, 44.31037514550345, 50.269535882132395, 45.73890045710972, 42.95904779434204, 42.9243415423802, 43.12570381164551, 47.979041372026714, 46.14479684829712, 47.79822840009417, 51.26383352279663, 52.62423522131783, 53.135285649980815, 48.89667953763689, 47.98730278015137, 53.1674280166626, 50.4469998223441, 43.40740810121809, 40.73421376092093, 41.27966819490705, 39.08442306518555, 40.341793400900706, 42.33354663848877, 45.04997961861746, 44.77634218760899, 46.454141071864534, 49.37864133289882, 53.19274377822876, 57.703323228018625, 53.88825498308454, 54.3209262575422, 54.52830219268799, 51.92893246241978, 49.30185679027012, 49.196907724652974, 49.193186964307515, 53.46277509416853, 53.31222152709961, 54.27285167149135, 53.31362853731428, 58.017930712018696, 53.786012240818565, 52.47379282542637, 53.16429090499878, 53.57926164354597, 54.82579278945923, 66.10439709254673, 63.8380823135376, 73.23584052494594, 64.63145542144775, 76.10265336717877, 6.433906827654157, 2.261782165084566, 70.43140166146415, 50.04328516551426, 50.53853191648211, 44.721336773463655, 32.35350854056222, 42.631238733019146, 68.34212698255266, 3.533171359981809, 0.2356313546853406, 0.09627702166991574, 0.0955343854480556, 0.06245812387870891, 0.013505016486825687, 0.018138767752264227, 0.06741137523204088, 0.0204634355115039, 0.22611047700047493, 0.1088267643270748, 0.08613497231687818, 0.10260326149208204, 0.11541117993848664, 0.2261762541851827, 0.21254994108208589, 0.1404579702232565, 0.39062074944376945, 0.432175482490233, 31.80870028904506, 75.33663531712124, 65.80800083705357, 48.7720879146031, 47.61510167803083, 59.19888128553118, 62.55250576564244, 66.49089758736747, 0.6234650622521127, 0.9216116666793823, 57.22086116245815, 71.10806587764195, 73.57701097215924, 69.99547168186733, 69.07767023359025, 61.974012647356304, 55.17342506136213, 55.16502121516636, 56.14674956457955, 58.4262763432094, 62.32164491925921, 58.375436374119346, 61.503967012677876, 61.0716917855399, 59.71004635947091, 60.04300403594971, 55.05332544871739, 52.08664962223598, 52.61191259111677, 54.1031037058149, 57.7849645614624, 61.36505167824881, 57.36582490376064, 58.19618674686977, 52.72111742837088, 50.61049093518938, 47.24593346459525, 45.606478214263916, 43.85371174131121, 44.51999882289341, 44.31823008401053, 45.06893083027431, 42.72608164378575, 46.67774452481951, 47.8035819871085, 51.7014171736581, 52.571380274636404, 56.42649793624878, 55.480830737522666, 55.92112071173531, 57.590279511043, 57.014735903058735, 53.39901842389788, 50.68616029194423, 47.57696301596505, 49.846411432538716, 53.539663859776084, 53.59697954995291, 55.20999343054635, 58.47153690883091, 52.13086100987026, 43.27306815556118, 45.4463917187282, 41.249304567064556, 42.241111278533936, 42.172355379377095, 40.92009196962629, 41.668517180851524, 42.76529380253383, 49.90370280402047, 50.760241985321045, 52.188711711338584, 50.636939253125874, 47.1316043308803, 49.66516767229353, 51.67501054491316, 45.419279847826274, 48.00085871560233, 45.88834578650338, 47.29828119277954, 48.728772844587056, 44.049848965236116, 51.40249177387783, 48.7619435446603, 48.59225116457258, 48.182710443224224, 54.408779280526296, 52.29186814171927, 51.0135281426566, 49.59022092819214, 42.53116730281285, 42.410049779074534, 37.67400128500802, 39.82119614737374, 40.749756881168906, 38.96216951097761, 40.30509649004255, 43.66379662922451, 47.68248183386666, 51.734073707035606, 45.691447734832764, 47.49264315196446, 44.360040869031636, 44.368931089128765, 50.63918352127075, 47.14639009748186, 49.0639956338065, 52.286987032209126, 54.99225773130144, 54.65843152999878, 50.18623045512608, 52.61780118942261, 55.768305506025044, 53.511634826660156, 45.92361831665039, 42.97258288519723, 44.24671575001308, 42.2337566103254, 44.04383877345494, 43.648399421146934, 49.23445231573922, 47.09353862489973, 49.32579333441598, 51.63051428113665, 53.799536909375874, 58.23527731214251, 57.39415618351528, 56.56178978511265, 56.332586084093364, 53.16001081466675, 50.80605493273054, 51.421630586896626, 51.49635846274239, 56.74404450825283, 54.82854080200195, 56.560747555324006, 55.65930216653006, 60.77120998927525, 56.09629174641201, 55.50537177494594, 55.71428673607962, 56.78238466807774, 57.47174324308123, 70.62925856454032, 67.15130301884243, 76.60612678527832, 68.65854794638497, 83.7257513318743, 14.15980339050293, 2.3401226699352264, 79.70741353716168, 53.61506571088518, 59.17955139705113, 43.982354164123535, 38.67430911745344, 49.457336630140034, 79.07908099038261, 5.165989560740335, 0.46543333360127037, 0.17729415717933858, 0.21770258673599788, 0.16387776924031122, 0.28142839723399704, 0.10544213665915386, 0.15581522615892546, 0.1395007608724492], [0.08030965418687888, 0.04765142107914601, 0.07179950869509152, 0.056880277648035965, 0.05517587571271828, 0.022062822278322916, 0.11617427399115902, 0.11167632642069034, 0.1937588094068425, 0.36361188015767504, 11.082058003970555, 51.27550997052874, 37.00447286878313, 39.657937799181255, 31.76950897489275, 48.56110239028931, 43.71737766265869, 62.397630419049946, 0.8483334130474499, 1.2274776654584068, 59.20752484457833, 64.73412895202637, 66.38777242388043, 64.3870108468192, 60.441413743155344, 54.48752668925694, 49.00238595690046, 52.66432980128697, 50.00081777572632, 54.74153893334525, 55.65314258847918, 56.23237221581595, 56.91594988959176, 56.66492884499686, 56.16995307377407, 52.0885569027492, 48.64694390978132, 48.53193037850516, 53.07889059611729, 57.53237669808524, 56.82449769973755, 56.546177182878765, 56.261137757982524, 53.07185207094465, 53.094989572252544, 48.06591469900948, 43.82144430705479, 42.08271666935512, 40.16078240530831, 39.64716114316668, 38.14681230272566, 39.70233678817749, 38.76107474735805, 41.81315435682024, 42.50820698056902, 47.050890581948416, 43.76703643798828, 45.907258783067974, 51.74769912447248, 48.82126031603132, 53.993985721043174, 50.26526968819754, 51.159415994371685, 47.9204089982169, 44.921757561819895, 49.8777825491769, 47.91676466805594, 48.6773943901062, 51.90608331135341, 51.028463295527864, 48.408162117004395, 41.15382589612688, 39.21446555001395, 36.60753617967878, 37.177420479910715, 37.594166483197895, 37.66698360443115, 39.66034534999302, 41.40171677725655, 41.7161922454834, 42.56579712459019, 46.569606236049104, 47.903656891414094, 40.9416800226484, 43.32499899183001, 44.16239936011178, 44.27135058811733, 41.84732559749058, 38.80810710362026, 41.487016337258474, 41.83740356990269, 41.73131152561733, 44.51180689675467, 41.25522790636335, 38.75786815370832, 42.5631741796221, 43.85361099243164, 43.17230190549578, 43.798862661634175, 41.539770535060335, 37.75414528165545, 37.730750696999685, 37.65962546212332, 37.22541168757847, 34.423105921064106, 34.86967706680298, 38.6913217817034, 41.166923250470845, 46.405580111912315, 45.74889196668352, 49.31766741616385, 39.76041330610003, 43.579765115465435, 46.18397079195295, 44.99041618619646, 48.73790972573416, 48.99998535428728, 51.327267101832796, 50.798460551670615, 49.94430807658604, 47.8393999508449, 46.85572957992554, 45.00627544948033, 45.68339477266584, 42.44284527642386, 38.82166303907122, 39.43624857493809, 38.17668955666678, 38.120603697640554, 40.94186067581177, 42.50163745880127, 41.66641535077776, 44.803308146340505, 51.63527032307216, 53.897499561309814, 55.315046719142366, 56.289743491581504, 56.764225551060264, 56.15148128782, 55.48331471851894, 52.478031226566856, 52.38846199853079, 48.09009095600673, 47.59084899084908, 49.53057411738804, 49.634345463344026, 51.02996758052281, 52.79803398677281, 50.15453624725342, 53.65331207002912, 49.65316118512835, 51.45359230041504, 49.64937441689627, 56.90803241729736, 60.0745974949428, 70.11391762324742, 60.91875498635428, 71.44952120099748, 3.803942007677896, 3.8174905606678555, 65.486862046378, 41.286057063511436, 43.56866536821638, 27.85637559209551, 47.05019923618862, 42.37804290226528, 53.28134373256138, 2.2800837201731543, 0.1974796647472041, 0.0186244970453637, 0.08417696452566556, 0.05093337622072015, 0.04410969219835741, 0.10155140329152346, 0.04919649620673486, 0.022573732005964433, 0.08250757838998522, 0.07682235059993607, 0.03706435114145279, 0.02841241218681846, 0.12606109918228217, 0.033293287602386305, 0.1323139350861311, 0.04345713150022285, 0.24663548277957098, 0.3201771437057427, 14.268038085528783, 61.612226894923616, 40.063476358141216, 47.66842562811715, 40.18662622996739, 52.933124337877544, 50.71363694327218, 68.66064630235944, 1.1476891125951494, 1.4166365095547266, 64.99955708639962, 67.86185359954834, 70.96369620731899, 68.75630215236119, 63.124022892543245, 56.7339175088065, 52.238502502441406, 54.624795300619944, 54.5505051612854, 57.23940937859671, 59.09000996180943, 57.87701777049473, 59.3975441796439, 60.72661645071847, 57.31743764877319, 55.37296690259661, 51.41580104827881, 51.80921152659825, 56.70738581248692, 60.2427647454398, 58.31844030107771, 57.060354300907676, 57.84720999853951, 56.08396564211164, 56.20055641446795, 51.467377526419504, 45.57929686137608, 45.096278939928325, 42.544841357639854, 42.33102791649954, 40.61048024041312, 42.35616997310093, 40.93225131716047, 43.858631065913606, 43.73913247244698, 49.87391240256173, 44.94643061501639, 47.92481763022286, 53.45097705296108, 51.07181658063616, 54.64587613514492, 53.28625610896519, 53.937733105250764, 49.94688933236258, 46.12757921218872, 50.27771391187395, 49.21015099116734, 52.98089320319039, 53.72462143216814, 53.64171552658081, 49.52051659992763, 43.15407330649239, 41.15971449443272, 38.63746282032558, 38.335181440625874, 39.09285817827497, 40.59322091511318, 41.520718574523926, 43.02426358631679, 44.66797113418579, 47.115734645298545, 49.640880244118826, 52.406009674072266, 43.56711939402989, 46.81954683576311, 46.82561261313302, 44.53383616038731, 43.37170130865914, 39.998031275612966, 41.349240507398335, 44.367996556418284, 43.779136725834434, 47.029795851026265, 44.90148271833147, 45.032487528664724, 45.8589722769601, 47.20504331588745, 46.93295185906546, 45.43435396466936, 44.251245975494385, 40.87299360547747, 38.421592712402344, 39.763557365962434, 38.26535551888602, 38.26582452229091, 36.08099126815796, 40.74740491594587, 42.98795577457973, 50.25317982264927, 49.26727213178362, 51.09340115955898, 43.90084137235369, 44.62042113712856, 45.97957215990339, 46.87814794267927, 49.98141840526036, 50.670064789908274, 52.148968015398296, 51.90793153217861, 51.46660280227661, 49.36379303250994, 49.65197999136788, 46.662621770586284, 45.847653661455425, 42.57473598207746, 40.07441629682268, 41.010467188698904, 40.981705120631624, 41.428036553519114, 43.90004232951573, 44.01646981920515, 43.64075640269688, 46.91495949881417, 54.77641889027187, 55.74697453635079, 58.296039308820454, 59.442499024527415, 59.1166215624128, 59.41843741280692, 60.733029638017925, 56.35977438517979, 56.068196705409456, 51.336570739746094, 50.909999983651296, 51.39014482498169, 53.41392925807408, 52.87435300009591, 54.67399549484253, 52.63052681514195, 58.6380991254534, 53.41798005785261, 55.316307817186626, 52.74515472139631, 60.31574862343924, 61.975318908691406, 74.60330159323556, 64.42158508300781, 80.16357667105538, 5.471757633345468, 5.647770268576486, 74.39304215567452, 47.3886981010437, 48.70970351355416, 28.18494895526341, 44.69449240820748, 47.90314619881766, 62.47000980377197, 2.8122855510030473, 0.23243947167481693, 0.11615406721830368, 0.022010771857042397, 0.054893011426819224, 0.005421033395188195, 0.069900085617389, 0.09932872613093682, 0.0716188894584775, 0.27608384830611093, 0.12952825027917111, 0.09884028269776277, 0.14237989352217742, 0.208397578181965, 0.1463302836886474, 0.24447329023054667, 0.16561091052634375, 0.3191591783293656, 0.5594918578863144, 19.24327223641532, 70.97846807752336, 48.739869117736816, 51.86616243634905, 43.089771202632356, 65.85864625658307, 53.77037531988961, 75.62308870043073, 1.1025541573762894, 2.186603741986411, 68.79678235735211, 69.845842225211, 71.84604099818638, 71.33720357077462, 65.88378483908517, 59.18481118338448, 52.87629502160208, 56.304411138807026, 54.569168022700715, 58.5979037966047, 60.76258727482387, 62.08120945521763, 62.076651436941965, 61.97351932525635, 59.38656602587019, 56.73033223833357, 54.291375568934846, 53.372396400996614, 56.99537822178432, 62.20786121913365, 60.631988934108186, 58.405028751918245, 60.35753508976528, 55.806079387664795, 58.08220502308437, 52.63839217594692, 47.99432740892683, 48.192795753479004, 43.356957231249126, 44.984604018075125, 42.50802632740566, 45.10535328728812, 42.3539639200483, 46.014997550419395, 46.7839720589774, 51.667437008449006, 46.454947062901084, 49.90273700441633, 56.22518083027431, 52.72354929787772, 59.68503284454346, 54.870163985661094, 55.05095611299787, 51.59361587251936, 46.7430089541844, 52.68310383387974, 50.73176826749529, 55.28747279303414, 56.28097139086042, 57.32915578569685, 50.541832310812815, 45.36718920298985, 44.45786108289446, 40.21465873718262, 41.680061612810405, 40.86338424682617, 42.07771744046892, 44.84552192687988, 45.803261620657786, 47.57684142248971, 50.0622433253697, 54.484264510018484, 57.11776031766619, 47.08490201405117, 50.96171889986311, 50.60884073802403, 48.46043341500418, 47.84928376334054, 41.829499994005474, 43.471529551914756, 44.22245264053345, 45.497992515563965, 51.361903871808735, 48.52099738802229, 49.09684671674456, 51.50704826627459, 52.48025812421526, 49.61977161679949, 50.31560243879046, 48.27218239648001, 42.89114304951259, 43.77682992390224, 42.30137995311192, 42.15043728692191, 39.39195033482143, 38.068422726222444, 41.896935735430034, 43.30723244803292, 50.64408547537667, 50.42811809267317, 53.81848464693342, 48.41016319819859, 47.75498628616333, 49.3942608833313, 50.28875807353428, 49.93727649961199, 52.10726145335606, 55.079544476100374, 55.16478845051357, 53.91581848689488, 51.806209904806956, 50.8110020501273, 49.20066670009068, 49.086125646318706, 46.409947054726736, 42.707727977207725, 43.636927945273264, 44.515506812504356, 43.62166275296892, 45.17557873044695, 46.09686470031738, 46.20675046103341, 49.17220687866211, 57.89604888643537, 58.33267021179199, 59.406389236450195, 60.82881055559431, 62.92324079786028, 61.312370436532156, 61.030259677342, 56.5586005619594, 57.96246671676636, 53.2422080039978, 53.1530521937779, 54.77646057946341, 55.26170539855957, 56.9066948890686, 59.929046630859375, 56.78751243863787, 63.500010762895855, 55.4440712928772, 59.433125904628206, 56.12308052607945, 64.3360458101545, 65.5347490310669, 79.04185949053083, 69.24560124533517, 88.15078108651298, 7.894729971885681, 4.743623767580305, 83.51147583552769, 51.98970488139561, 60.54012680053711, 37.24251467841012, 61.138679368155344, 55.35972711018154, 74.08121395111084, 4.319490960666111, 0.5226116882903236, 0.2341260654585702, 0.23794849749122346, 0.21017083445830004, 0.06544811557978392, 0.11659423288490091, 0.17856848665646144, 0.16332521103322506], [0.02968029897393925, 0.07151522287832839, 0.03603340878284403, 0.058451551012694836, 0.017321928637102246, 0.029023487253912857, 0.18044131116143294, 0.09133641820933137, 0.07916181720793247, 0.3180722195122923, 7.170023305075509, 56.89358711242676, 39.251363958631245, 30.40024832316807, 33.42666476113455, 40.104988370622905, 39.65391479219709, 70.06241062709263, 5.327483066490718, 0.11804913410118648, 59.665042877197266, 67.62260627746582, 66.6979261125837, 65.23399625505719, 59.037690026419504, 52.04371670314244, 52.27933011736189, 52.46836280822754, 55.0252616746085, 54.90486676352364, 57.81503636496407, 58.06024524143764, 56.44353491919381, 55.20022426332746, 52.85005514962332, 48.75465488433838, 50.81358330590384, 56.049304553440635, 57.44679921013968, 56.75088848386492, 55.7042361668178, 57.70397635868618, 56.499269894191194, 56.13676152910505, 54.057419300079346, 47.46010473796299, 43.78904485702515, 40.50894968850272, 40.17329611097063, 39.312424727848594, 40.115348134722026, 38.929391384124756, 37.76529366629464, 40.17690570013863, 42.2509742464338, 45.40584550585066, 46.184495380946565, 46.231788294655935, 48.607544149671284, 50.48863690240042, 51.13790437153408, 52.97053343909127, 53.1615845816476, 50.36782509940011, 43.33363560267857, 42.73844943727766, 44.99880266189575, 51.57877452032906, 52.351556641714915, 50.37944596154349, 45.54204756872994, 39.945568902151926, 40.88501398903983, 36.37583112716675, 36.64155803407942, 36.987547057015554, 37.62414796011788, 40.13350377764021, 40.65094307490757, 41.80432667051043, 39.969595772879465, 40.50987727301461, 45.14931106567383, 43.59772620882307, 43.96461541312081, 44.540374415261404, 42.416292735508506, 40.86327307564871, 40.40978847231184, 38.102364676339285, 40.897138595581055, 44.188482897622244, 43.54875530515398, 43.441926751817974, 39.87476328441075, 41.95064878463745, 41.25564479827881, 41.37355572836739, 39.670114517211914, 40.10920940126692, 37.94865662711007, 37.9842209815979, 34.86751965114048, 35.200133391789024, 34.98040008544922, 34.17410332815987, 39.73596606935774, 47.33902195521763, 46.88869878223964, 52.30646283285958, 50.47622047151838, 39.16066217422485, 37.99822160175869, 44.642686639513286, 49.332147462027415, 51.15134218760899, 49.447973932538716, 50.403771604810444, 47.494998591286794, 45.8532851764134, 47.08373819078718, 44.043203013283865, 42.84590680258614, 42.319796153477256, 36.86854178564889, 38.737082617623464, 37.97760282244001, 39.49125746318272, 39.23545605795724, 40.565765108381, 41.403794288635254, 40.952936104365754, 44.30490691321236, 53.586255005427766, 52.593437331063406, 55.57745933532715, 55.917625767844065, 56.810927867889404, 56.30841677529471, 57.42911951882498, 55.19113254547119, 57.36449779782976, 55.19594069889614, 54.45752436774117, 49.02594729832241, 50.52726541246687, 48.25317212513515, 50.118190220424104, 48.10106216158186, 51.819234303065706, 50.21813310895647, 52.78333159855434, 49.781862667628694, 55.38422645841326, 56.78121737071446, 70.85790293557304, 60.272774015154155, 74.95704133169991, 1.867355078458786, 12.468350427491323, 69.61584295545305, 40.19748626436506, 39.037661688668386, 49.0780622618539, 61.536428996494834, 43.52998127256121, 58.87838172912598, 0.9688548573425838, 0.04739162019853081, 0.03942504911018269, 0.014483285868274314, 0.08252995647490025, 0.10892769641109876, 0.08490759067769561, 0.03211183599861605, 0.06929038119103227, 0.013894264037454767, 0.12136710248887539, 0.048287456056901386, 0.052832894293325286, 0.10965967963316611, 0.021128874804292406, 0.11185391260577099, 0.019546653277107646, 0.053597562547240934, 0.3481856036399092, 8.241267033985682, 69.90701416560582, 38.43366173335484, 35.93335941859654, 44.897084508623394, 43.835090569087434, 46.38351263318743, 76.43337372371128, 6.538257913930075, 0.14403211272188596, 64.91210011073521, 70.59485803331647, 69.19442081451416, 66.06531347547258, 62.097169467381065, 53.58350351878575, 55.14501735142299, 55.705271448407856, 59.25257001604353, 57.06028481892177, 59.63720839364188, 59.6087555204119, 58.062492983681814, 57.889618328639436, 55.326615469796316, 51.7084869657244, 53.177304880959646, 58.946355955941335, 59.05919470105852, 59.0908020564488, 58.463296345302034, 60.573068210056846, 57.77605349676949, 58.51428917476109, 56.8188488142831, 47.808567319597515, 45.69353566850935, 43.3030982698713, 43.75415447780064, 40.93750415529524, 41.51429149082729, 41.52313654763358, 40.26197944368635, 41.703129632132395, 43.642090456826345, 46.99698298318045, 47.150044849940706, 46.36878940037319, 50.6147814478193, 52.67587423324585, 53.90164416176932, 53.71432072775704, 55.014835902622764, 52.89475985935756, 46.1932292665754, 44.558297293526785, 46.23163196018764, 54.17893981933594, 52.7405480657305, 52.83940356118338, 47.9757479258946, 42.132170472826274, 41.68359824589321, 40.101740087781636, 38.96756131308419, 38.78779057094029, 37.497093200683594, 42.4788612638201, 42.34431634630476, 43.8392664364406, 42.68048409053257, 45.099999700273784, 46.877876962934224, 46.66606460298811, 45.694998264312744, 47.23183209555489, 45.35675648280552, 44.231301171439036, 40.891788482666016, 39.07311487197876, 41.19852018356323, 46.527305603027344, 45.387213911329, 47.2443596976144, 43.926924909864155, 41.8351662499564, 45.089299474443706, 45.55504070009504, 44.26489223752703, 41.67693839754377, 39.949862888881135, 40.257685456957134, 36.01655714852469, 37.47709281103951, 36.98882205145699, 36.723783016204834, 42.56146839686802, 47.179845673697336, 49.21795381818499, 54.16486276899065, 51.436676910945344, 43.41572509493147, 40.868685722351074, 47.391977650778635, 51.15685558319092, 55.28430094037737, 52.196156706128804, 51.58080686841692, 51.65305423736572, 49.52183675765991, 48.67814132145473, 46.52406774248396, 46.24821731022426, 44.894617898123606, 40.654743739536826, 39.60800109590803, 40.93955039978027, 41.626845359802246, 42.68340580804007, 43.16816772733416, 45.1780766078404, 42.77064391544887, 48.26315321241106, 56.53910739081246, 54.85397815704346, 57.48794991629464, 56.09802532196045, 61.92916897365025, 58.86083057948521, 60.91220283508301, 57.98452377319336, 59.92848382677351, 58.5027551651001, 58.65660217830113, 52.75427770614624, 54.997496673039024, 50.498802116939, 55.383114746638704, 51.182751519339426, 56.03178467069353, 52.97410133906773, 58.08194446563721, 53.932417733328684, 59.64427471160889, 60.16714055197579, 75.37041745867047, 63.906688826424734, 82.0218584878104, 2.243790239095688, 14.777668476104736, 77.15181050981793, 45.70451034818377, 46.976353781563894, 47.96261583055769, 58.36264474051339, 44.55700145448957, 68.1328819819859, 0.99308756845338, 0.03751296456903219, 0.0513426583659436, 0.03514107416516968, 0.05094858219048806, 0.06385604172412838, 0.06253129030976977, 0.10321145278534719, 0.06968201124774558, 0.1522066140813487, 0.1632858831435442, 0.07027607544192246, 0.10599383312676634, 0.24661186976092203, 0.06096907878028495, 0.26587363332509995, 0.2103422595454114, 0.21391146230910504, 0.4438549429178238, 12.143313697406224, 80.5086589540754, 49.473022188459126, 39.02597829273769, 43.98735686710903, 55.9006860596793, 50.59713997159685, 83.68292958395821, 6.377907821110316, 0.5326699114271572, 69.08527851104736, 71.35890974317277, 71.38524341583252, 68.13971900939941, 65.21011529650006, 55.89220578329903, 55.548798016139436, 59.21441050938198, 61.86109052385603, 61.53100940159389, 60.647003991263254, 61.62173203059605, 60.227944237845286, 59.255036626543315, 57.87849078859602, 52.670902797154014, 55.49469239371163, 60.36400386265346, 62.136315618242534, 61.78671700613839, 59.074967111860005, 62.37217221941267, 59.553357533046174, 60.272106988089426, 58.30118792397635, 50.80028445380074, 47.255803380693706, 43.43519742148263, 44.42720215661185, 44.52453599657331, 44.29364735739571, 44.913027150290354, 42.07118960789272, 43.18157775061471, 45.582277638571604, 51.59526259558541, 49.43058953966413, 49.68856920514788, 55.130509512765066, 55.395329679761616, 56.144772802080425, 58.569923400878906, 58.286958013262065, 54.530939034053254, 46.620536531720845, 45.609254019601, 48.726611954825266, 55.78554398672921, 55.73053509848458, 53.697089195251465, 49.31288358143398, 44.4946413721357, 45.872694969177246, 41.120196614946636, 41.586017744881765, 40.191187722342356, 38.5078580720084, 45.10295615877424, 46.28043958118984, 47.02901070458548, 47.41519158227103, 49.86595671517508, 54.39238153185163, 51.39423383985247, 50.616237095424104, 49.715552534375874, 49.54340744018555, 47.172827993120464, 42.443665163857595, 37.29293428148542, 42.72632483073643, 48.899837493896484, 49.3266271182469, 50.94903148923601, 48.993134430476594, 50.103974206107004, 48.80565466199602, 49.76085131508963, 47.27315303257534, 45.95723022733416, 42.813024452754426, 43.870001792907715, 38.211757114955354, 38.38708448410034, 39.73634474618094, 37.34993382862636, 45.68191133226667, 51.253230571746826, 52.64846011570522, 54.85730981826782, 54.875507150377544, 45.32057721274239, 45.104116507938926, 47.77317667007446, 52.3104476247515, 55.879302978515625, 54.73525428771973, 54.727639062064036, 53.366816997528076, 52.05172102791922, 52.26915448052542, 49.33646924155099, 48.58274255480085, 47.24170548575265, 41.808929852076936, 42.57999576841082, 43.60745368685041, 45.441559246608186, 45.307493754795615, 45.346132687159944, 47.623008728027344, 44.180363927568706, 49.06872040884835, 59.08226272038051, 55.066349846976145, 60.73239735194615, 59.10000841958182, 63.50603485107422, 61.5522153036935, 63.687945638384136, 60.45588684082031, 62.16849272591727, 60.00978469848633, 61.078035490853445, 53.40550456728254, 58.65305859701974, 53.72952686037336, 57.32647378104073, 54.0343964440482, 59.22574302128383, 57.45383078711373, 60.87465476989746, 56.09358542306082, 62.844052178519114, 62.43749223436628, 80.04464435577393, 68.4902903693063, 88.47114862714494, 3.4443084597587585, 15.68554789679391, 83.17903232574463, 53.195835726601736, 54.79334470203945, 68.712785584586, 79.22698729378837, 56.96313510622297, 79.47218922206334, 2.1808230578899384, 0.16505722595112665, 0.1296738096113716, 0.16061554928975447, 0.14783931842872075, 0.20685691013932228, 0.10386996423559529, 0.21473509525614126, 0.1278497310621398], [0.13007939713341848, 0.021821643791294525, 0.03185672379497971, 0.03605906079922404, 0.032929178926029375, 0.021972555068454573, 0.11552300250955991, 0.04660768494276064, 0.18644986088786805, 0.2619901331407683, 5.008358819144113, 54.64016124180385, 44.119014808109824, 36.311000960213796, 19.237680673599243, 37.63976403645107, 34.196778774261475, 68.28958470480782, 17.173327445983887, 0.11764782134975706, 45.05192511422293, 71.49319757734025, 64.31663254329136, 61.48615877968924, 59.10223879132952, 57.4673068182809, 54.71977022715977, 53.84556525094168, 53.86341169902256, 56.0143585886274, 56.22466318947928, 54.70319529942104, 54.66205848966326, 52.423373222351074, 46.526159150259836, 48.61044502258301, 55.63158580235073, 55.490700653621126, 56.492078508649556, 57.722795554569785, 56.01186418533325, 55.1307179587228, 55.121257986341206, 55.93432576315743, 53.611560344696045, 45.10973412649972, 42.62127501623971, 42.90832247052874, 41.81769153050014, 40.09236696788243, 38.63308892931257, 38.429346902029856, 38.57329968043736, 38.34757702691214, 40.81211001532418, 42.52914537702288, 44.97944498062134, 43.67326354980469, 46.005950995853965, 50.1613906451634, 49.3884973526001, 50.5659773009164, 51.190870489392964, 51.698693479810444, 50.49390363693237, 48.60182578223092, 46.659717423575266, 50.19705922263009, 49.60725791113717, 48.75851113455636, 45.81404869897025, 40.48722614560808, 38.871498993464876, 37.564855507441926, 35.328463145664756, 35.884555271693635, 37.28232438223702, 38.24050876072475, 41.25639867782593, 39.39454896109444, 40.65814140864781, 40.7993357522147, 39.37582703999111, 45.07282529558454, 44.76108046940395, 43.75216381890433, 42.63989271436419, 44.39491040366036, 39.173227991376606, 36.577832630702424, 36.783766814640586, 41.33345420019967, 43.529043265751426, 43.48390081950596, 41.903609480176655, 38.05760438101632, 36.02058015550886, 42.21939468383789, 42.04298686981201, 39.982713971819194, 36.580868993486675, 37.08052437646048, 37.502599648066926, 35.01302187783377, 37.65965672901699, 35.908342429569785, 40.72576822553362, 46.46419858932495, 50.228399072374614, 50.14237689971924, 48.341594900403706, 41.12991714477539, 39.3934303011213, 50.04288911819458, 51.82136392593384, 49.31061846869332, 50.984199796404155, 49.29365791593279, 49.39905514035906, 46.38991887228829, 43.22059883390154, 40.46187216894967, 39.51384258270264, 41.065451758248464, 37.65337903159005, 38.781853335244314, 38.87341322217669, 38.70843172073364, 40.146945067814414, 41.14928524834769, 41.921591418130056, 41.21674183436802, 46.5563143321446, 54.35294703074864, 56.18125431878226, 54.83581209182739, 52.80862998962402, 54.848127773829866, 55.85116277422224, 60.64797673906599, 56.97842461722237, 58.192775181361604, 56.593084471566335, 56.529807226998464, 56.96719632829939, 55.46465880530221, 49.99325813565935, 50.26516546521868, 49.76566989081246, 50.41513538360596, 49.00970241001674, 54.246792452675955, 54.33280767713274, 58.514956201825825, 60.173644065856934, 69.64737388065883, 66.44033554622105, 69.05998706817627, 0.728216755603041, 18.095037255968364, 67.93848528180803, 34.760923862457275, 40.81694943564278, 81.39555481501988, 28.855578660964966, 44.3632926259722, 52.68629305703299, 0.7657394164374897, 0.0838340057858399, 0.08862582687288523, 0.02817347116901406, 0.023900697140821388, 0.05945695670587676, 0.06076731639248984, 0.03074548699493919, 0.016626813615273153, 0.1272020558161395, 0.02959714111472879, 0.07870338537863322, 0.051552118733525276, 0.05452408515182989, 0.06990481500646897, 0.03251105886218803, 0.04302443311150585, 0.13211431008364471, 0.22030954541904585, 5.275976938860757, 63.679705074855256, 46.98623759405953, 35.072880608694895, 30.86955397469657, 45.23901578358242, 40.76080799102783, 73.77803625379289, 20.9432567187718, 0.15681386685797147, 47.87462384360177, 74.2665571485247, 67.79007175990513, 65.87425191061837, 60.56860746656145, 60.813517570495605, 56.817222935812815, 58.01265008108956, 57.74716636112758, 58.593067850385395, 58.03916440691267, 58.24018274034773, 56.665526390075684, 54.568928309849326, 48.423281397138325, 51.85138014384678, 57.36339998245239, 57.42361307144165, 58.17434508459908, 59.04572214399065, 57.41391338620867, 57.33108391080584, 56.26221820286342, 55.53562075751168, 56.11446475982666, 46.443972383226665, 44.28091478347778, 45.41287013462612, 44.51430130004883, 41.374632699149, 41.665314061301096, 40.40283679962158, 40.31560564041138, 40.83577210562569, 41.347652844020296, 43.533083643232075, 46.92834867749895, 46.39882646288191, 49.379697459084646, 51.49034827096121, 52.44177205221993, 53.37991087777274, 51.19556747164045, 53.390131677900044, 51.59056561333792, 50.60115950448172, 49.623506273542134, 49.40441567557198, 52.70606763022286, 50.71102442060198, 47.53112227576119, 43.39107983452933, 39.403810909816194, 38.23831312997, 36.6404914855957, 38.384270463671, 39.22985233579363, 39.79242713110787, 43.77749695096697, 40.74013015202114, 43.55675268173218, 44.35280432019915, 42.95027221952166, 48.64778116771153, 47.92112466267177, 46.265066691807334, 43.65599380220686, 45.27880464281355, 39.02769797188895, 35.684770243508474, 37.20744364602225, 43.36069883619036, 45.838909353528706, 47.706515652792795, 46.65217515400478, 41.87684154510498, 39.593177114214214, 45.18423271179199, 45.15633569444929, 40.8099421773638, 37.89529793603079, 37.0822787966047, 39.5437684740339, 37.32907881055559, 40.53796189171927, 37.950935636247905, 43.87547697339739, 48.567550318581716, 51.90761191504342, 52.54304552078247, 49.66108213152204, 42.91307503836495, 42.2671149117606, 50.512608187539236, 53.670137132917134, 52.586680207933696, 53.85328122547695, 53.422357422964915, 49.71561506816319, 46.984253883361816, 44.183184896196636, 43.151085581098286, 42.03532648086548, 42.61779744284493, 40.11399671009609, 39.26557649884905, 41.076360430036274, 41.572176933288574, 41.65148367200579, 45.26259102140154, 43.671064444950645, 43.073418617248535, 48.20587921142578, 57.839761529650005, 57.0912320954459, 58.35538387298584, 54.370053495679585, 55.965509278433665, 58.791383334568565, 62.300119400024414, 59.862580163138254, 61.76496914454869, 61.87635571616036, 60.36002949305943, 60.819750104631694, 60.318076269967214, 54.90899746758597, 52.58631542750767, 52.738133566720144, 53.15023817334856, 53.45101179395403, 56.91655090876988, 58.43123040880476, 61.84255967821394, 66.4223049708775, 72.71411418914795, 69.35471575600761, 70.13494982038225, 0.7034650466271809, 22.04950373513358, 73.00579261779785, 42.41250249317714, 51.773476941244944, 95.51506560189384, 39.12960025242397, 46.73634563173567, 60.35126781463623, 0.7063027886407716, 0.13621876841144903, 0.05642663288329329, 0.03092150915680187, 0.05288215932835426, 0.034523312135466507, 0.008219218513529216, 0.08239536905395133, 0.031792079763753076, 0.34922883766038076, 0.07137815201921122, 0.13539666895355496, 0.10706069373658725, 0.08227482052253825, 0.20931279978581838, 0.2497974288250719, 0.16520693791764124, 0.26791187109691755, 0.42109687839235577, 8.151272228785924, 74.43165329524449, 58.36235291617257, 51.73220811571394, 27.48297939981733, 57.06624289921352, 46.11226190839495, 83.1878217969622, 20.78488121713911, 0.18949344328471593, 52.83221217564174, 76.1304600579398, 70.6722331728254, 66.70720890590123, 62.87313733782087, 62.23755087171282, 58.5500168119158, 60.03106703077044, 59.96621254512242, 63.013831411089214, 61.459700039454866, 61.239317076546804, 59.815742356436594, 56.749540533338276, 51.01379912240164, 54.959708895002095, 59.447995049612864, 58.28050313677107, 59.322781562805176, 61.185267039707725, 60.049167088099885, 59.73171779087612, 58.441416467939106, 59.18879944937569, 59.095116887773784, 48.70597233091082, 46.722296374184744, 47.90416758401053, 46.25636754717146, 43.721463203430176, 42.983755588531494, 42.39829690115792, 42.55007335117885, 43.21918140138899, 45.44402238300869, 45.6548307282584, 49.62838738305228, 46.63589899880545, 51.90437058040074, 52.72990689958845, 54.2495995249067, 56.05773619243077, 54.563345432281494, 55.11422988346645, 53.643056528908865, 50.62345627376011, 50.84765032359532, 50.779964447021484, 53.68594428471157, 54.24059118543352, 50.78826754433768, 45.559553555079866, 42.1628224509103, 41.28353834152222, 37.7307402747018, 40.43247781481062, 42.01434292112078, 45.134514876774375, 48.76943717684065, 44.30124173845564, 46.44811003548758, 49.91406604221889, 47.450134072984966, 52.56604058401925, 53.91456781114851, 49.19721344539097, 46.02441235951015, 47.29310131072998, 38.30244847706386, 36.27473136356899, 37.75006668908255, 45.0501081602914, 48.13714763096401, 51.07148306710379, 50.31828791754586, 47.53978320530483, 45.09576824733189, 49.78126164845058, 51.054671900612966, 45.51570347377232, 39.806830746786936, 39.86112397057669, 41.18781648363386, 40.71352549961635, 42.18321541377476, 39.07877765383039, 45.09463916506086, 50.65338911328997, 53.92105048043387, 55.47497688020979, 52.60839332853045, 45.85704067775181, 43.6971549306597, 52.21568809236799, 56.049162115369526, 55.52295766557966, 57.05283635003226, 56.11189045224871, 53.04766539164952, 51.0924631527492, 47.65704795292446, 45.39987005506243, 45.73287984303066, 45.81186349051339, 43.071136134011404, 43.20601109095982, 43.86594751902989, 43.55902821677071, 45.19392197472708, 46.895497594560894, 46.66189915793282, 45.268656798771445, 50.879462650844026, 62.08165413992745, 59.69615691048758, 59.53673049381801, 55.5980989592416, 59.50979927607945, 60.531504086085725, 66.87825965881348, 61.68714932032994, 61.156841959272114, 63.431313923427034, 62.723236901419504, 62.074504443577354, 62.23955890110561, 56.408477783203125, 56.58259963989258, 56.529720374516074, 57.800024781908306, 55.91611106055123, 61.363238198416575, 62.443155016217915, 65.78572491237095, 67.8141542162214, 76.8707628250122, 71.1260825565883, 78.026262147086, 1.5736476672547204, 22.540734427315847, 83.13434151240757, 48.00515270233154, 59.70926121303013, 99.62563378470284, 41.06674064908709, 58.308018003191265, 72.29101753234863, 1.3658874098743712, 0.21711167772965773, 0.17682030903441565, 0.17282182430582388, 0.1052189189940691, 0.09764268874589886, 0.08026003970631532, 0.158300604937332, 0.1860020684876612], [0.033603289896356206, 0.09038914261119706, 0.12135320609169346, 0.030963391730827943, 0.18196369947067328, 0.04733272335891213, 0.04756937601736613, 0.016515063986714398, 0.04979576137182968, 0.12020056508481503, 1.3482228091784885, 51.2997487613133, 48.12142733165196, 33.18625014168875, 16.32415509223938, 30.461680821010045, 40.16922099249703, 60.17449174608503, 38.61124031884329, 0.3553684667817184, 24.542684146336146, 78.64815371377128, 57.88369846343994, 65.51567622593471, 60.50486469268799, 59.84816265106201, 57.21983630316598, 58.161633355276926, 52.6937380518232, 54.15081351143973, 51.6922733443124, 52.38470649719238, 49.84878076825823, 48.43283864430019, 46.18373802730015, 54.662621293749126, 56.06867960521153, 55.70688343048096, 56.515521730695454, 56.820102964128765, 54.91385078430176, 55.79534789494106, 54.328541483197895, 50.98711803981236, 45.7423780305045, 41.172565187726704, 41.09599256515503, 41.560163497924805, 40.71610675539289, 39.701405729566304, 40.396201269967214, 38.83948516845703, 37.397226742335725, 39.754159927368164, 40.463310446058, 44.587702069963726, 42.27969809940883, 46.291737352098735, 44.85876519339425, 47.47614465441023, 51.02826527186802, 53.74595587594168, 50.94480698449271, 50.668855803353445, 50.52107456752232, 53.37519999912807, 52.19379779270717, 52.5345652444022, 50.199199267796104, 48.72144596917288, 45.557496888296946, 43.12216370446341, 38.091021742139546, 40.97485419682094, 36.467126982552664, 34.91679627554757, 37.62964398520333, 38.750409262520925, 39.82081399645124, 39.18517541885376, 40.28982434953962, 40.538267612457275, 38.14398785999843, 42.68031733376639, 42.86547987801688, 46.45875120162964, 41.64813811438424, 40.09082794189453, 40.75240761893136, 36.22928319658552, 40.64763225827898, 37.40696464266096, 44.097690786634175, 43.19869811194283, 38.858043806893484, 36.32678379331316, 36.596262727464946, 41.65340832301548, 42.848748615809846, 40.35794448852539, 36.46522317613874, 35.778609139578684, 37.55180679048811, 35.59004545211792, 35.25183841160366, 35.155519008636475, 41.60117176600865, 45.04361159460885, 51.33687646048409, 50.00266252245222, 48.835799421582905, 38.90580572400774, 40.61924191883632, 49.97626979010445, 47.87256370271955, 52.73684467588152, 48.6540275982448, 50.58731174468994, 45.412421975817, 44.73049797330584, 40.9661203111921, 38.10063457489014, 40.87403236116682, 38.809475898742676, 34.9196207182748, 37.42890010561262, 37.57083443232945, 38.478387287684846, 40.535429273332866, 41.1186888558524, 40.42874663216727, 41.326241970062256, 42.397195611681255, 51.50597824369158, 56.186705180576865, 55.67453956604004, 53.20353085654122, 52.201079504830496, 50.076000758579795, 52.42635399954659, 53.61660473687308, 59.228966985430034, 60.89524228232247, 56.54023994718279, 56.96315247671944, 58.885274342128206, 59.77462291717529, 50.35456098828997, 49.12976728166853, 48.52438463483538, 52.43103361129761, 52.955876214163645, 55.35273027420044, 58.699500356401714, 63.78130858285086, 66.06979506356376, 72.39121750422886, 52.24912282398769, 0.09570706582495145, 33.19363955089024, 59.84791251591274, 41.28544214793614, 28.581916911261423, 37.77859251839774, 39.788390227726524, 49.899763175419395, 46.19468144008091, 0.24788168019482068, 0.015706131500857215, 0.05771265351878745, 0.07034713841442551, 0.06150540642972503, 0.01593686224493597, 0.031051397722746645, 0.07978363348437206, 0.047057957388460636, 0.09610907068209988, 0.05219723590250526, 0.06561045508299555, 0.07217061306749072, 0.15571523723857744, 0.015273658725033914, 0.06403307829584394, 0.016834840577627932, 0.1751415455447776, 0.06136877661836999, 1.7670880130359103, 57.975036008017405, 54.733854225703645, 33.36426993778774, 22.59757242883955, 39.45027003969465, 47.90336854117257, 68.17678764888218, 45.58999013900757, 0.3658579939178058, 23.719635282244, 82.060441834586, 60.97294398716518, 68.92772115979875, 61.8153783253261, 63.65234306880406, 59.96530927930559, 62.12992327553885, 55.14456571851458, 57.06753526415144, 53.131505829947336, 54.34873642240252, 51.221209798540386, 50.7461336680821, 50.06496354511806, 58.53373718261719, 57.1583308492388, 59.479998452322825, 59.18482507978167, 58.839166096278596, 56.04196030752999, 57.00752019882202, 55.60698570523943, 52.9316964830671, 46.46120391573225, 44.7075445992606, 42.78395318984985, 44.25275373458862, 42.760645457676475, 42.05967991692679, 41.544669015066965, 41.68225376946585, 39.58986629758562, 41.15294347490583, 43.501198359898154, 45.960624422345845, 43.10900729043143, 47.37482949665615, 47.158010959625244, 50.14147015980312, 53.070069858006065, 53.80862862723214, 53.916829449789866, 53.293635095868794, 53.16141087668282, 55.860240595681326, 52.80698674065726, 54.68524462836129, 51.19419520241873, 50.55211564472744, 48.28030136653355, 44.081122807094026, 39.73594175066267, 41.49255405153547, 38.340840748378206, 38.76774154390608, 38.14394269670759, 40.315157481602256, 41.42462151391165, 40.819009576525005, 41.97058664049421, 46.45123325075422, 42.844228812626426, 46.80881881713867, 46.65302630833217, 47.53497157778059, 42.68230104446411, 39.14228071485247, 40.38639041355678, 35.31980916431972, 40.485204219818115, 37.72202375956944, 44.117781502859934, 47.04310859952654, 41.25178507396153, 40.243545872824534, 39.87759467533657, 41.99888317925589, 44.49369641712734, 42.13976832798549, 37.99346555982317, 38.28198603221348, 39.24289410454886, 36.488593442099436, 37.16411120550973, 37.53450230189732, 40.36389214651925, 45.823720591408865, 53.19276114872524, 51.503237179347444, 51.481020314352854, 42.43362849099295, 43.260029860905235, 50.984724385397776, 50.69314670562744, 53.80007886886597, 50.6352994782584, 52.46353381020682, 47.54055445534842, 46.27153199059622, 41.880103724343435, 41.49641030175345, 42.45761367252895, 40.382645334516255, 37.338024616241455, 39.02276822498867, 40.630699498312815, 40.822174480983186, 42.57678917476109, 43.66247647149222, 42.491024085453574, 44.349225997924805, 45.18119287490845, 53.22927393232073, 58.21187577928816, 57.21677214758736, 57.80975920813424, 55.78677729197911, 52.04925789151873, 53.02405193873814, 55.971922465733115, 59.29104913984026, 65.47967066083635, 62.13701738630022, 62.50478553771973, 62.162531171526226, 62.041757583618164, 54.698275974818635, 52.49578734806606, 53.33921527862549, 56.68917110988072, 57.73816844395229, 59.635784012930735, 62.18119403294155, 66.89358738490513, 70.4910866873605, 75.84381907326835, 52.29348012379238, 0.027132311769362007, 39.25294467381069, 65.76198291778564, 46.84472710745675, 36.580431256975444, 44.45804173605782, 47.06278937203543, 56.770454611097065, 50.72209984915597, 0.2998042111950261, 0.04376559012702533, 0.03058788027348263, 0.04186394823981183, 0.054486382353518686, 0.06808078395468847, 0.009505346018288816, 0.07235940865107945, 0.03550002597538488, 0.131473786596741, 0.14980375873191015, 0.22867732069322041, 0.1275389620235988, 0.25449584956680027, 0.12225093506276608, 0.17248024977743626, 0.1254584922322205, 0.18304198661020823, 0.2101754213550261, 2.706979521683284, 70.63537992749895, 61.279262270246235, 43.669077260153635, 23.32997509411403, 44.144657135009766, 51.67391620363508, 74.16866397857666, 46.07636056627546, 0.4624259035502161, 30.737743173326763, 82.50094372885567, 63.48485674176897, 70.2256168637957, 66.50275121416364, 66.42243698665074, 62.66986778804234, 63.00894682747977, 56.62880168642317, 59.173145157950266, 56.41458524976458, 56.707159996032715, 54.15609761646816, 52.370507853371755, 51.45998811721802, 59.851337977818076, 59.458646638052805, 61.98795073372977, 61.720959254673545, 59.92716366904122, 59.343660899571006, 60.80973080226353, 57.91098403930664, 55.11019992828369, 49.51260607583182, 46.43977219717843, 45.15408795220511, 46.449093205588206, 45.87980645043509, 45.411348479134695, 45.778272424425396, 44.90266043799264, 41.96524000167847, 44.20970964431763, 46.997476305280415, 48.36295018877302, 45.91282776423863, 49.827734674726216, 50.50843926838466, 52.756115504673545, 55.25165482929775, 57.23355899538313, 56.061029638562886, 57.30530956813267, 54.56983504976545, 58.26796858651297, 57.18157604762486, 54.77004391806466, 52.49130923407418, 52.72637721470424, 51.71514681407383, 46.31019524165562, 42.3439758845738, 44.58824402945382, 39.93069280896868, 41.407042571476524, 40.98320593152727, 42.09252405166626, 45.43386064256941, 43.207320826394216, 45.45581347601754, 49.521350383758545, 46.622825963156565, 50.327143396650044, 50.277158055986675, 53.246342182159424, 44.50127690179007, 39.42479794366019, 42.12973860331944, 35.71354968207223, 43.108593872615266, 39.21417372567313, 48.25002806527274, 51.61546795708792, 46.09252207619803, 47.004414081573486, 43.27498933247158, 48.95072610037667, 49.484809807368684, 45.64539507457188, 41.94800846917288, 40.334803513118196, 41.30002294267927, 38.878495829445974, 38.711659158979145, 38.81634766714913, 43.08360120228359, 50.08118411472866, 55.385397229875835, 54.17907183510916, 52.884931632450645, 44.48724848883492, 45.86948490142822, 55.77695948737008, 52.53754254749843, 58.70478098733084, 52.5613123348781, 56.59451232637678, 52.205932821546284, 49.3631329536438, 44.79986183983939, 43.983167103358674, 45.686379023960654, 42.819350787571494, 38.9933808190482, 41.41024569102696, 42.9095071383885, 44.074271883283345, 45.338819708142964, 47.04883738926479, 44.64212383542742, 45.51152065822056, 48.23939037322998, 55.67121485301426, 60.96236882890974, 59.76665333339146, 60.35654844556536, 58.748936789376394, 54.85839026314871, 57.13233763831002, 58.12017692838396, 62.40102808816092, 67.26374571663993, 63.9280823298863, 64.03136730194092, 65.24050671713692, 66.28858688899449, 56.376380579812185, 55.06540489196777, 56.42556687763759, 59.78098051888602, 62.13332789284842, 61.90072304861886, 66.07777854374477, 69.86598505292619, 73.86602824074882, 77.78767490386963, 61.10075610024588, 0.2825957488800798, 39.58011450086321, 75.11051314217704, 54.30966322762625, 40.60821860177176, 42.53169536590576, 51.75477933883667, 64.52835805075509, 63.116907937186106, 1.0926960749285561, 0.1935482057077544, 0.10730608592608146, 0.19790123855429037, 0.11827742042286055, 0.16117416002920695, 0.2376716009208134, 0.252264745001282, 0.11707918186272893], [0.13292317810867513, 0.03214991877653769, 0.07618389664483921, 0.018134918762370944, 0.0930348252877593, 0.04804869654721447, 0.057264698270176134, 0.04804909349020038, 0.018971828943384544, 0.0047496615859147695, 0.26020577603152817, 44.65191732134138, 45.94393832342965, 41.52307401384626, 38.15916619982038, 31.866686480385916, 39.56747225352696, 49.206298215048655, 58.29159246172224, 0.8521129073841232, 3.985067214284624, 74.34432138715471, 59.75708566393171, 66.35722119467599, 58.9143317086356, 61.86189651489258, 58.572751317705425, 58.62990025111607, 54.33458294187273, 54.33718851634434, 47.36615814481463, 49.01315566471645, 46.1548022542681, 49.57561581475394, 53.68088252203805, 55.0285655430385, 55.926766123090474, 56.48030826023647, 54.617419787815635, 54.37843997137887, 53.587575163160054, 50.06922973905291, 44.99062115805489, 40.939602511269705, 42.78087166377476, 43.91837167739868, 42.948458739689414, 42.63455302374703, 41.95523806980678, 40.119746344430105, 38.636205196380615, 39.42604167120797, 39.79446642739432, 37.95796026502337, 37.33332763399397, 42.50826951435634, 40.75757360458374, 42.65866674695696, 43.679204259599956, 45.98561361857823, 51.17084925515311, 52.57762323107038, 54.33842876979283, 51.53466388157436, 50.541693346840994, 51.31094230924334, 51.19513668332781, 50.18944747107369, 48.73514781679426, 51.00056627818516, 48.82597814287458, 43.77109071186611, 38.670265265873496, 42.11463321958269, 36.50119400024414, 34.80994687761579, 38.409801619393484, 35.46905994415283, 38.53816611426217, 37.79071365083967, 42.778724670410156, 39.173662253788535, 40.34316567012242, 39.71088654654366, 45.56407683236258, 42.381638595036094, 39.1248893737793, 41.10446241923741, 40.643869808741975, 37.39498247419085, 39.065899167742046, 38.305641174316406, 41.13247408185686, 45.619982038225444, 38.80591147286551, 39.295644828251426, 36.78011553628104, 40.54534435272217, 42.2179286139352, 38.05293519156319, 38.13976682935442, 37.46014615467617, 35.824297019413535, 35.39656244005476, 37.12793888364519, 39.974799973624094, 43.685325622558594, 44.99458163125174, 50.215940952301025, 49.25877101080758, 48.94578940527779, 41.39757217679705, 43.488354614802766, 49.690917696271626, 48.82737125669207, 48.221738474709646, 48.07586104529244, 48.50488798958914, 44.1151932988848, 40.64880302974156, 38.95865024839129, 40.13383729117257, 41.69437837600708, 38.1485458782741, 36.00475563321795, 36.468509674072266, 38.43817458833967, 39.068584646497456, 39.588358538491384, 39.78057697841099, 41.045652866363525, 41.93356663840157, 42.42689568655831, 51.07758705956595, 56.055488450186594, 54.571731907980784, 55.79365600858416, 54.96610123770577, 54.272139481135774, 50.30391556876046, 49.303524357931956, 49.74872670854841, 56.88122279303414, 57.23569556644985, 59.54139968327114, 57.63210071836199, 60.40020397731236, 56.49021291732788, 49.06500659670149, 47.57936709267752, 52.19260270254952, 54.10319750649588, 57.9280800819397, 57.5985027040754, 69.048814364842, 66.67949254172188, 80.26493004390171, 29.56957381112235, 0.10083693305828742, 47.23486498423985, 58.580588885716026, 45.28457164764404, 30.07908868789673, 22.9970452104296, 35.864360332489014, 52.496819155556814, 33.79011460712978, 0.03496111989287393, 0.00508147369172158, 0.03165037790313363, 0.04667359104912196, 0.04022506225321974, 0.05577751914305346, 0.0712492914338197, 0.06048805173486471, 0.028170992819858447, 0.09331354033201933, 0.03673035245654838, 0.01580624934285879, 0.042257437482476234, 0.036630064980792146, 0.034228159580379725, 0.03064497220995171, 0.06342482593442712, 0.04007940792611667, 0.04357227550021239, 0.556912610573428, 54.6415821484157, 52.2669484274728, 36.043488366263254, 36.90715639931815, 40.70122371401106, 45.951140131269185, 55.536801951272146, 66.68907410757882, 1.547211725796972, 2.811948997633798, 76.02020604269845, 64.06287738255092, 68.63274928501674, 63.85499422890799, 66.58542088099888, 61.722314153398784, 62.92039203643799, 58.11982257025582, 57.08012539999825, 50.23285634177071, 52.64360679898943, 49.03972905022757, 50.899407454899375, 55.17798655373709, 58.46651336124965, 58.950462341308594, 58.14270298821585, 56.85195350646973, 57.84070648465838, 54.93359409059797, 53.297758851732524, 47.67882708140782, 43.355782985687256, 45.12997422899519, 46.356206212724956, 44.53494439806257, 44.51090015683855, 44.038547720227925, 42.37874467032296, 40.187053544180735, 41.926736559186665, 40.75463104248047, 40.720240933554514, 39.396393707820344, 44.441032545907156, 42.66871036802019, 45.21022244862148, 46.079254490988596, 45.920012201581685, 52.635831764766145, 54.53706387111119, 54.80755724225725, 53.7465568951198, 54.84592866897583, 54.60294321605137, 52.528961522238596, 51.97840363638741, 52.07320138386318, 51.377638067517964, 51.50523131234305, 47.11605773653303, 39.14100224631173, 44.243321555001394, 40.43168919427054, 36.10462556566511, 40.06969846997942, 39.2362516266959, 39.29209777287075, 41.04523597444807, 43.353774956294465, 41.919618129730225, 43.48493957519531, 43.12907716206142, 48.6978394644601, 43.24315268652779, 39.91158178874424, 41.47346387590681, 39.031057425907676, 37.23842566353934, 37.94220175061907, 37.345149993896484, 41.67618799209595, 48.85266964776175, 41.268366949898855, 41.413031918661936, 40.540188789367676, 42.71934189115252, 43.09041043690273, 40.49294103894915, 40.33978189740862, 37.797602789742605, 37.05033097948347, 34.88970177514212, 38.66390419006348, 42.69532196862357, 45.304474762507844, 48.54100125176566, 50.834750992911204, 50.45685236794608, 51.120731898716514, 45.59039313452584, 44.992997441973, 51.887208529881065, 52.442324434007915, 51.27487768445696, 52.53412403379168, 51.223540919167654, 46.35834278379168, 41.67486088616507, 41.39738457543509, 41.375744410923545, 43.11260298320225, 42.2170809337071, 37.794719287327354, 39.50728348323277, 39.754719257354736, 41.35591425214495, 41.977284703935894, 42.539887292044504, 42.23447574887957, 43.61603123801095, 44.52270862034389, 52.617762974330354, 56.445977210998535, 58.47765827178955, 58.0246913092477, 59.081157956804546, 57.9531318119594, 54.66555690765381, 52.12346117837088, 51.761790071214946, 58.4285067149571, 61.08794362204415, 63.95407554081508, 62.39446204049246, 64.30479976109096, 61.13744258880615, 53.21427277156285, 50.49468878337315, 56.480276993342805, 58.73023918696812, 61.751420157296316, 61.84932027544294, 71.44412939889091, 68.89876801627022, 81.54169627598354, 27.688842364719935, 0.12433945227946554, 54.321037428719656, 64.34986577715192, 55.614500182015554, 35.8095703125, 29.421601499829972, 37.78997366768973, 56.67388159888131, 41.601675510406494, 0.09071089034633976, 0.058778896661741395, 0.07937278731593064, 0.05435470584779978, 0.047928717985217056, 0.048708151161138497, 0.024195405255470957, 0.02114258290800665, 0.03856026640694056, 0.20336629530148848, 0.1388028333229678, 0.2093117412711893, 0.17094723560980388, 0.1805104131677321, 0.13894196014319146, 0.1123536807884063, 0.15983744604246958, 0.19656409030514105, 0.1126334136351943, 0.9137590080499649, 66.55566869463239, 58.09912041255406, 51.88183757237026, 51.52987309864589, 47.762323583875386, 52.81323664528983, 59.88716288975307, 70.57264464242118, 1.2776092439889908, 6.377330252102443, 81.68204293932233, 64.82833957672119, 72.54031889779228, 64.63048267364502, 68.37193475450788, 62.523031507219585, 64.97557190486363, 57.89663600921631, 59.72817420959473, 51.4453204699925, 54.876948901585166, 51.20968621117728, 53.14276885986328, 56.216787406376426, 60.60641956329346, 61.667166301182334, 58.476845332554404, 57.66461828776768, 59.685956954956055, 57.414073194776265, 56.169108867645264, 50.92859336308071, 45.11890227454049, 48.958508082798545, 49.15741416386196, 46.94303022112165, 48.08035652978079, 46.45010764258248, 45.812523569379536, 44.20599930627005, 44.49941825866699, 44.59109279087612, 42.95355871745518, 41.135288102286204, 47.656992367335725, 45.34869309834072, 48.62890986033848, 48.23437029974801, 49.546346528189524, 56.116458892822266, 55.86727564675467, 57.26158455439976, 55.403139454977854, 57.139313629695344, 56.372604233878, 53.99283926827567, 55.52110249655587, 53.823949405125205, 55.257421834128245, 52.79978493281773, 47.93706383023943, 42.84355483736311, 47.49060385567801, 42.34579978670393, 38.436156136649, 43.38261692864554, 41.157591819763184, 42.332275118146626, 43.45900542395455, 47.6912122453962, 46.03633199419294, 48.82685708999634, 48.48660033089774, 51.02085154397147, 46.47536781855992, 41.06620563779558, 41.55656780515398, 39.40916449683053, 38.4270783151899, 37.938640798841206, 39.13149363654, 42.90090526853289, 53.26052345548357, 45.41725097383772, 48.494420528411865, 44.69773374285017, 47.70389270782471, 48.858978612082346, 44.49463789803641, 44.117670331682476, 40.973527090890066, 39.786403042929514, 37.7444212777274, 40.85008192062378, 44.45419590813773, 47.81131533214024, 49.593003681727815, 53.59853594643729, 52.74901097161429, 52.36307675497872, 45.97550398962838, 47.77833570752825, 54.6445768220084, 53.58402115958077, 53.64394242422921, 54.998003891536165, 53.87116241455078, 49.09013475690569, 45.20933307920183, 44.75079018729073, 46.85145991189139, 46.30432401384626, 44.572617530822754, 40.05276918411255, 40.68710150037493, 43.65883561543056, 44.902170589991975, 44.91078635624477, 43.9709278515407, 45.47347927093506, 47.04596083504813, 48.535032749176025, 56.15273196356637, 61.3564567565918, 62.03566401345389, 59.60184901101248, 62.03481633322579, 60.68288448878697, 56.42532021658761, 53.814406054360525, 54.522441387176514, 63.796962874276296, 63.66325174059187, 66.74151216234479, 65.30445098876953, 67.65740980420793, 63.90622329711914, 55.09402799606323, 53.085494858878, 58.79223796299526, 62.09052698952811, 65.3023248400007, 64.42007732391357, 77.015882900783, 72.55108860560826, 87.37529958997453, 37.924556800297324, 0.12533178260283812, 56.92634786878313, 71.78328486851284, 59.462266649518696, 44.54597118922642, 30.581606728690012, 47.46684449059622, 68.15654059818813, 52.77282592228481, 0.1755634450486728, 0.11647303295986992, 0.14853709670049803, 0.10985758794205529, 0.10738833794104201, 0.17424091244382517, 0.09904914934720312, 0.15692475305071898, 0.09050010344279663], [0.055797278082796505, 0.03751151928944247, 0.05774719773658684, 0.061205941784594736, 0.11854443752339908, 0.0759405197043504, 0.08824442912425313, 0.10039104734148298, 0.04320221946441701, 0.05495852059019463, 0.08719358872622252, 36.411586557115825, 53.363058022090364, 45.76566144398281, 36.51868609019688, 34.152282510484966, 39.64065762928554, 49.697244031088694, 63.54126221793038, 10.526149136679512, 0.32398928914751324, 47.0290767124721, 66.55773230961391, 63.34104987553188, 62.77972575596401, 62.9646520614624, 60.86272471291678, 62.1337308883667, 60.607274191720144, 57.12072719846453, 50.635653836386545, 47.25541775567191, 45.98975821903774, 52.2314361844744, 54.92735113416399, 56.88558626174927, 55.46134451457432, 54.06166464941842, 57.19751868929182, 53.890151841299875, 54.728358200618196, 50.28202179500035, 47.204324177333284, 46.559197834559846, 45.0985301562718, 41.95048202787127, 42.78544010434832, 41.39355959211077, 41.825813974652974, 43.302330493927, 40.400721073150635, 39.284232412065776, 39.08043827329363, 38.44613027572632, 39.093202114105225, 42.53797306333269, 40.36973558153425, 41.40678548812866, 43.01482793263027, 43.04403468540737, 49.065451281411306, 49.66352789742606, 50.798693316323416, 52.21266910008022, 52.77884653636387, 51.70602035522461, 52.77196087156023, 49.01973213468279, 44.91063002177647, 48.73621089117867, 49.04410294124058, 50.10088573183332, 42.12862341744559, 40.46902881349836, 42.46959236689976, 32.27638701030186, 33.60311426435198, 35.52951622009277, 34.57432304109846, 37.7440356527056, 39.271875040871755, 39.02150017874581, 39.61586645671299, 42.51989385059902, 44.41622747693743, 37.41551440102713, 37.839465686253135, 39.97637026650565, 37.99760321208409, 37.76138877868652, 41.951784815107075, 39.74017320360456, 40.982445103781565, 40.34401682444981, 39.662242208208355, 38.993283544267925, 37.62265409742083, 40.43766464505877, 41.836232798440115, 38.219382762908936, 35.712184361049104, 34.47487694876534, 36.71105391638619, 36.07078783852713, 39.44251585006714, 41.311567374638145, 46.2860016141619, 51.90010438646589, 50.94111749104091, 51.428464140210835, 49.42710501807076, 42.17392567225865, 49.798114504132954, 48.96239559991019, 50.840438093457905, 47.30870696476528, 49.985809666769846, 46.51017829350063, 41.91850641795567, 38.906708989824565, 38.042200224740164, 37.05099105834961, 38.94233240400042, 34.76925475256783, 36.2021678515843, 38.06673778806414, 38.65321438653128, 39.44695922306606, 41.94671957833426, 40.97069917406355, 40.61827959333147, 40.89749642780849, 43.19596746989659, 51.30791636875698, 53.6222814151219, 56.19434125082833, 54.979851722717285, 56.021324157714844, 54.745885031563894, 57.36008569172451, 55.70973219190325, 51.61650323867798, 50.744549478803364, 52.48611198152815, 58.101246561322895, 61.31524004255022, 61.21720790863037, 57.53900180544172, 54.190532888684956, 46.44807529449463, 53.861764975956504, 55.447267464229036, 61.17326055254255, 59.349594661167686, 70.16246468680245, 64.59029429299491, 77.3705050604684, 10.544564468520027, 0.26199659279414583, 57.147700105394634, 49.87288406917027, 33.439108984810964, 33.86638845716204, 37.172285761152, 33.716269152505056, 54.66338906969343, 32.85616207122803, 0.022551666047157984, 0.029598287838910307, 0.04594529905755605, 0.054298051566417725, 0.04911182521443282, 0.04762934833498938, 0.03804243222943374, 0.03168827408392515, 0.03889551359627928, 0.033036563878080676, 0.03022066390674029, 0.012092328630387783, 0.030588619876652956, 0.08461113872804812, 0.05958059257162469, 0.058660512657037804, 0.039428882833038054, 0.008154014690912195, 0.08285986020096711, 0.08562392688223294, 48.32752479825701, 58.138905797685894, 48.465787002018516, 41.64682143075125, 40.96764196668352, 47.734186853681294, 54.34109687805176, 69.7261734008789, 12.587017842701503, 0.4010683431157044, 47.446437631334575, 71.06359740665981, 65.73207092285156, 67.16686003548759, 65.78641278403146, 65.82425962175641, 65.2708078111921, 62.74200398581368, 61.23461314610073, 51.997497286115376, 50.06335851124355, 50.17070470537458, 54.50599152701241, 56.707125255039756, 57.39341620036534, 58.046123027801514, 55.59730339050293, 59.321252959115164, 56.799977506910054, 56.35816935130528, 54.21329518726894, 51.08552190235683, 50.21067074366978, 47.311319487435476, 43.53727340698242, 45.78102738516671, 43.48804889406477, 44.3547637122018, 44.98724780763899, 42.53474562508719, 41.19889538628714, 41.7203368459429, 40.617261682237896, 39.9898567199707, 43.62909385136196, 42.00913177217756, 43.34878962380545, 44.426205090114046, 45.59287364142281, 50.295150416237966, 51.708323683057515, 52.23507009233747, 54.82371180398123, 55.61063003540039, 54.34391784667969, 54.48330218451363, 49.843322958265034, 46.933907236371724, 50.41007014683315, 51.916682788303916, 52.046040875571116, 45.564834186008994, 41.27269915172032, 44.17013965334211, 36.97854913984026, 35.739754813058035, 37.16840866633824, 35.94863503319876, 39.921410015651155, 42.03258541652134, 40.77615656171526, 44.41227395193917, 44.86731147766113, 46.768157958984375, 39.99542917524065, 37.77905804770333, 39.56969220297677, 37.27332646506173, 37.39913749694824, 40.17305639811924, 39.6495235306876, 39.99400132043021, 43.30089569091797, 42.87506839207241, 40.30134793690273, 40.875442845480784, 41.16720117841448, 41.7788267816816, 40.97393356050764, 37.12788677215576, 36.712738854544504, 38.5364533833095, 37.77792549133301, 40.57956075668335, 42.607854570661274, 47.46489552089146, 51.53192629132952, 52.349242891584126, 50.148265498025076, 51.43243850980486, 47.60775048392159, 52.24459259850638, 51.82515416826521, 51.42292295183454, 48.27694886071341, 51.52989394324166, 46.869455746241975, 42.462797028677805, 40.07543420791626, 39.40346697398594, 38.500117778778076, 41.87427765982491, 38.18530879701887, 40.53073229108538, 40.16351652145386, 41.57230200086321, 42.95234625680106, 44.233229296548025, 43.47593123572213, 41.991434710366384, 43.94208587918963, 46.46290275028774, 54.70862184252058, 56.22439220973423, 56.68345969063895, 57.00021069390433, 58.1231438091823, 58.79349558694022, 58.17181594031197, 58.118002142224995, 56.68517589569092, 55.82638202394758, 53.24078362328665, 60.379595620291575, 62.51540238516671, 64.26717526572091, 62.442779813494, 59.706030300685335, 50.83873231070382, 57.518185002463206, 59.355382510593955, 62.68159634726388, 63.546841621398926, 71.98401137760708, 66.4803363255092, 80.82732418605259, 10.323506661823817, 0.5045263416000775, 66.67318357740129, 51.21596390860421, 47.52610567637852, 36.846800872257774, 37.29564755303519, 35.08177430289132, 58.471745354788645, 43.49182176589966, 0.050291319244674275, 0.015497995972899454, 0.04900364976908479, 0.07650342557047095, 0.042800536911402426, 0.06932057599936213, 0.019294781078185354, 0.06130732848708119, 0.03607742874217885, 0.15140884688922338, 0.1250216378165143, 0.13067398379955972, 0.1745457375156028, 0.15453169574694975, 0.10890576615929604, 0.2232267845954214, 0.2223204653710127, 0.12581958142774446, 0.09956222360155412, 0.22669830545783043, 57.35364123753139, 67.50219399588448, 61.35635948181152, 50.40195117677961, 49.06394004821777, 52.701252528599326, 62.96005235399519, 74.8075647354126, 12.243301749229431, 0.31187382925833973, 51.78436476843697, 69.61067349570138, 69.65936647142682, 68.50352668762207, 68.72866916656494, 68.47796426500592, 68.32397828783307, 63.70824827466692, 63.10554763248989, 55.616334506443565, 51.109611306871685, 51.60268327168056, 56.291622979300364, 58.74681064060756, 62.16961833408901, 58.97230747767857, 58.17500516346523, 60.704569816589355, 59.231746264866416, 60.09575475965227, 55.95089374269758, 52.67126062938145, 51.49060188020979, 50.48011146272932, 45.0221312386649, 48.18761239733015, 45.14267553601946, 46.38778230122158, 48.57783017839704, 44.108033180236816, 43.29347154072353, 43.781634603227886, 42.941496644701274, 43.523571559361045, 46.746667180742534, 44.646494252341135, 45.517704554966514, 46.44687673023769, 47.39246402468, 54.1210161617824, 54.08974926812308, 54.77214574813843, 56.402182715279714, 57.65887212753296, 57.34626225062779, 56.65866504396711, 51.12656143733433, 48.21627719061715, 53.937663623264854, 56.12766981124878, 54.34153808866228, 46.74778584071568, 45.14480863298689, 45.07328387669155, 38.13147415433611, 37.443560804639546, 39.0733893258231, 38.655309268406455, 41.9860394341605, 45.74542481558663, 45.7505247933524, 48.85023430415562, 48.632568086896626, 48.73538058144705, 39.75380209514073, 36.79765626362392, 41.03642913273403, 39.067031724112375, 37.935090269361226, 42.340421880994526, 41.29780299322945, 42.48972129821777, 44.82732459477016, 47.192724159785676, 47.77711629867554, 44.723046030317036, 46.70296648570469, 47.05957235608782, 43.55321257455008, 40.6523049218314, 37.741641998291016, 39.999907289232524, 39.97600548607962, 43.801982402801514, 43.63573285511562, 49.22051770346505, 54.037790639059885, 54.57210711070469, 54.12828050340925, 54.28952387401036, 52.09166622161865, 55.563083512442454, 55.66186605181013, 58.043722425188335, 50.409962449754985, 54.10496234893799, 48.301503794533865, 45.30114310128348, 42.25408703940255, 41.88288647787911, 41.70329638889858, 43.665738650730674, 39.3981203351702, 42.56290667397635, 43.123890331813264, 45.09119980675833, 45.128091267177034, 47.08659390040806, 45.26817042487008, 44.192703928266255, 45.48510013307844, 50.020185879298616, 57.73142521721976, 57.741628646850586, 59.61588437216622, 61.51288849966866, 59.62393733433315, 61.803170340401785, 62.67492607661656, 62.62938758305141, 58.508772305079866, 58.85640457698277, 56.642392362867085, 66.24917670658657, 66.8039903640747, 68.97787325722831, 65.12234565189907, 63.18435410090855, 53.32284532274519, 62.08224473680769, 62.533683095659526, 67.44669873373849, 66.58131449563163, 77.83028820582798, 68.84056295667375, 85.65942805153983, 14.738570962633405, 0.7604171505996159, 69.33539976392473, 61.03228160313198, 48.965035915374756, 47.72992760794503, 52.15659713745117, 44.9804698399135, 71.4937812260219, 49.08350270135062, 0.18567377967493875, 0.10751189238258771, 0.08829492570034095, 0.2015024817415646, 0.16485494109136717, 0.13075835284377846, 0.09201132306563002, 0.14577932682420525, 0.12854064255952835], [0.0698013791282262, 0.046981086156197956, 0.01453596054177199, 0.05071239432852183, 0.0641305430659226, 0.0435463656405253, 0.15640238965196268, 0.08157415847693171, 0.04575106501579285, 0.12431114379848753, 0.049390696321747134, 36.839849199567524, 51.33361080714634, 32.86459371021816, 32.76024913787842, 36.60594851630074, 32.11246510914394, 38.29671621322632, 61.478960445949006, 20.068586213248118, 0.40225282098565784, 22.601678814206803, 60.494775908333914, 59.36417893001011, 61.73546014513288, 60.2164032799857, 58.153055804116384, 63.07200172969273, 60.637227875845774, 59.9138092313494, 52.54389667510986, 48.59635407584054, 49.97473076411656, 54.30014419555664, 54.69859559195382, 56.01081848144531, 54.95959424972534, 51.32608938217163, 57.55975954873221, 55.85107592173985, 55.69929599761963, 54.682618209293906, 55.519153526851106, 54.87751170567104, 48.744833605630056, 41.59731898988996, 41.681409563337056, 41.34637784957886, 41.584989411490305, 41.41049930027553, 42.10692766734532, 39.89807449068342, 39.84526818139212, 38.291129861559185, 38.6500494820731, 40.86893238340105, 43.20545176097325, 40.1021465573992, 39.73135246549334, 44.824489729745046, 47.32648740495954, 48.243055547986714, 51.198416233062744, 52.65721137183053, 52.02492182595389, 48.40582404817854, 49.229922090257915, 47.24325145993914, 50.203986576625276, 49.33824450629098, 49.75944777897426, 50.303408350263325, 45.84279687064034, 33.93364701952253, 43.56195688247681, 36.601783071245464, 35.32375226702009, 35.46127448763166, 35.645822116306846, 37.53580508913313, 38.22424650192261, 39.90236847741263, 37.70228740147182, 42.25701917920794, 41.14442498343331, 39.47815663473946, 43.56334999629429, 43.02758135114397, 38.27031305858067, 38.49928052084786, 38.95059381212507, 39.43656471797398, 36.77465772628784, 42.75142519814627, 38.17277077266148, 33.557311739240376, 39.49210514341082, 38.26555354254586, 37.08784777777535, 39.14695337840489, 37.098023414611816, 38.8583391053336, 38.368821144104004, 43.10388994216919, 44.94251877920968, 48.12574563707624, 52.503593649183, 51.53018924168178, 51.058305808476035, 50.7087801524571, 43.512544768197195, 43.76913826806204, 51.69701548985073, 49.42830358232771, 49.71754666737148, 48.52455139160156, 48.62104797363281, 46.016147477286204, 43.00318622589111, 39.06174414498465, 38.48416471481323, 38.810236726488384, 38.882570947919575, 36.22100789206368, 40.06966372898647, 36.55305535452706, 40.41093145098005, 40.191024439675466, 42.219749041966026, 42.459152698516846, 42.26509993416922, 39.92946992601667, 43.995034626552034, 50.79848139626639, 51.74371780667986, 54.22080966404506, 55.42825371878487, 56.746135916028706, 55.571435247148784, 55.274983406066895, 55.69551617758614, 55.79024791717529, 54.7874630519322, 51.98322221211025, 54.65875462123326, 56.67029980250767, 62.832004002162385, 60.2772000176566, 56.47454820360456, 47.95244019372122, 53.61285965783255, 55.20314598083496, 61.19686358315604, 60.0860481262207, 72.11360222952706, 66.97396414620536, 69.65004893711635, 1.371685573032924, 3.915598690509796, 64.01843670436314, 53.99094935825893, 31.638657024928502, 30.525548662458146, 35.712924344199045, 33.475732939583914, 56.174837657383506, 32.34628241402762, 0.039835908849324496, 0.11317262505846364, 0.12440023544643607, 0.06191136036068201, 0.06517609089080777, 0.03130352437230093, 0.05798081734350749, 0.056112559379211495, 0.01591119835419314, 0.13399459847382136, 0.06953295746019908, 0.017626285519716994, 0.02016764004448695, 0.03189917294574635, 0.021529166360518763, 0.10798530626509871, 0.16589193258966717, 0.032230678014457226, 0.051302312673734765, 0.0679373416517462, 43.02899183545794, 58.991067613874165, 35.080134528023855, 32.049469266619, 42.27835014888218, 40.21915422167097, 42.52678646360125, 67.45894840785435, 23.192763805389404, 0.18459727029715264, 22.698123284748622, 61.957969256809776, 63.6430116380964, 64.6705459867205, 65.57095609392438, 60.689589500427246, 66.30351856776646, 62.97324003492083, 62.835881096976145, 55.10900483812605, 50.367213657924104, 53.4679445539202, 57.79230185917446, 57.941000257219585, 58.77459648677281, 56.77855273655483, 51.75909417016165, 59.450857707432334, 58.648007256644114, 59.956221035548616, 55.96011052812849, 56.552267278943745, 56.9313644681658, 49.803200585501536, 43.601464339665, 43.34103543417794, 43.69133928843907, 44.97484874725342, 43.68853916440691, 42.136141368321006, 42.481953212193076, 42.47497027260916, 40.90805074146816, 39.17618097577776, 40.9509037562779, 44.77538333620344, 40.847549302237375, 41.516164030347554, 46.82397631236485, 49.55167927060808, 51.66918795449393, 53.106978688921245, 53.698520524161204, 53.408464499882285, 50.091821806771414, 52.12752587454659, 49.118830817086355, 52.18757220676967, 51.167941434042795, 51.70446743283953, 52.500814369746614, 48.82438700539725, 38.17144019263131, 43.111303670065745, 42.91084814071655, 39.52723176138741, 37.84107766832624, 39.52935791015625, 39.11278908593314, 42.248528480529785, 40.389753341674805, 41.36676386424473, 43.958264759608674, 43.61705609730312, 40.73218488693237, 42.91114343915667, 42.82192162105015, 39.01341247558594, 37.6574194090707, 37.73652465002877, 39.30341291427612, 35.39750739506313, 42.135147775922505, 40.70891884395054, 36.50605773925781, 42.90316343307495, 39.2474034854344, 38.72090026310512, 41.54738228661673, 39.0037579536438, 40.713459491729736, 39.7751122202192, 43.972817761557444, 45.62217419488089, 49.532394545418875, 54.73918696812221, 54.126439230782644, 53.858384677342, 50.39045885631016, 46.200743743351524, 46.55827719824654, 52.99830191476004, 50.9674129486084, 53.59902926853725, 52.34106138774327, 51.718030316489084, 50.71040950502668, 45.07409681592669, 41.84881946018764, 41.44276673453194, 40.60248286383492, 40.971400942121235, 39.43073517935616, 42.89861931119646, 40.41382884979248, 43.32471758978707, 42.907933371407644, 45.427075726645334, 45.12416206087385, 43.94540016991751, 42.76425852094378, 47.592026710510254, 51.98640101296561, 54.80039364950997, 55.858267307281494, 58.47620609828404, 59.81410952976772, 59.403873988560264, 57.595473289489746, 57.78882775987898, 56.482309341430664, 58.817411286490305, 56.828472069331575, 56.033594676426475, 59.164043017796104, 65.47042260851178, 64.13886288234166, 63.200119563511436, 51.3705335344587, 56.40278026035854, 59.01562254769461, 64.69722706930978, 63.59892531803676, 75.10307162148612, 68.62850393567766, 68.25384317125592, 0.7163402214646339, 5.872372959341321, 70.34845406668526, 59.98292991093227, 41.48782927649361, 32.82897029604231, 36.70929602214268, 40.295400278908865, 63.363846915108816, 36.5516483443124, 0.075285272007542, 0.0912877061803426, 0.10558040173990385, 0.058270497513668876, 0.07685930361705166, 0.019626080890053084, 0.06310360745659896, 0.06586979116712298, 0.03256872755342296, 0.18037607680474008, 0.1039141843627606, 0.16465037635394505, 0.21178661632750714, 0.20851260343832628, 0.2304823324084282, 0.24599500000476837, 0.27040201319115503, 0.10420980171433517, 0.22051871062389442, 0.4631503075361252, 54.79384844643729, 66.84743744986397, 42.054927349090576, 41.79679829733712, 51.09277582168579, 43.368421758924214, 50.471273354121614, 72.72839273725236, 24.71420737675258, 0.3276016738797937, 31.754709311894008, 66.30206639426095, 66.37564781733921, 65.8866058077131, 65.39799458639962, 61.64791284288679, 69.77546392168317, 63.512010301862446, 64.34090954916817, 56.87629304613386, 53.51291329520089, 54.72053452900478, 59.18544346945626, 58.904131753104075, 60.52266597747803, 59.198047501700266, 54.04073667526245, 61.74087974003383, 61.10100623539516, 62.40725367409842, 58.46520709991455, 58.82398428235735, 59.40091405596052, 50.92633867263794, 44.9835478918893, 46.01045342854091, 45.83033527646746, 46.468565532139365, 46.5819080216544, 45.22765895298549, 44.46715777260916, 45.98791347231184, 44.49206011635916, 41.81294591086251, 44.05341339111328, 46.936915806361604, 44.10511493682861, 44.394896507263184, 49.705741677965435, 52.16090154647827, 52.66656017303467, 55.226877553122385, 57.88667924063546, 55.68009465081351, 54.47446060180664, 53.42802020481655, 51.196255343300955, 55.36086661475045, 52.62574298041207, 53.682237420763286, 54.316114630017964, 49.71757793426514, 40.86628859383719, 47.109158175332205, 39.879290035792756, 39.41252742494856, 40.650988238198416, 38.70204980032784, 41.78827633176531, 44.50040142876761, 45.21522862570626, 44.79415042059762, 46.22825166157314, 45.18929100036621, 40.93370696476528, 43.93705538340977, 42.97020312717983, 39.257870946611675, 39.29818092073713, 37.58769771030971, 39.61812114715576, 36.65114654813494, 46.8698969568525, 42.539373125348774, 38.63121638979231, 46.66909401757376, 42.51936231340681, 41.69848476137434, 44.61898980821882, 41.42298868724278, 42.984175954546245, 40.70402383804321, 44.91338150841849, 47.875026839120046, 50.40942396436419, 56.623166697365896, 56.07903936931065, 55.713133335113525, 53.0930996622358, 50.55324820109776, 47.72535221917288, 56.728949546813965, 55.06780549458095, 55.687928744724815, 55.03474596568516, 54.32870823996407, 52.46512842178345, 47.8458548273359, 43.09575012751988, 41.85986014774868, 43.11380502155849, 44.30399669919695, 41.87381213051932, 45.89902169363839, 43.10530390058245, 46.096823011125835, 45.30670166015625, 47.82611846923828, 48.542800835200715, 49.00636380059378, 46.38385656901768, 49.710997990199495, 55.016451358795166, 57.607570103236604, 59.35924570901053, 59.96116120474679, 62.50396565028599, 61.427613258361816, 58.87569277627127, 60.06193092891148, 60.5547319139753, 60.397285733904155, 58.10444620677403, 59.776193210056846, 61.31842926570347, 69.57439000265938, 66.57003062111991, 65.89809812818254, 53.943361146109446, 62.45318126678467, 63.06858321598598, 68.52284267970494, 65.29266684395927, 80.07719666617257, 69.95338644300188, 76.92684868403843, 2.5791912930352345, 5.276661770684378, 76.15147141047886, 68.033050264631, 44.46122053691319, 43.00132063456944, 48.655385971069336, 47.041097096034456, 73.4773668561663, 44.592308725629536, 0.18312155162649496, 0.21430148423782416, 0.2126009804861886, 0.17767974148903573, 0.17025667695062502, 0.1292499287852219, 0.18425716140440532, 0.18287722473698004, 0.1103963583175625], [0.024407108181289265, 0.0985220769154174, 0.10057051985391549, 0.14203864469059876, 0.08669129639331784, 0.045505733894450326, 0.07396043916898114, 0.19989971417401517, 0.02995368412562779, 0.3418702610901424, 0.08389514179102012, 27.417497839246476, 54.5362092426845, 42.543187686375205, 41.43723596845354, 26.036647592272075, 32.278099741254536, 30.55206993647984, 64.56719153267997, 34.20294877461025, 0.04609970648639968, 3.5230506573404585, 42.39810235159737, 57.58034011295864, 61.90095233917236, 59.9875157220023, 61.57995251246861, 58.79933902195522, 61.22822775159563, 57.29676675796509, 51.40010159356253, 49.159144265311106, 53.64773614065987, 56.81820958001273, 58.12750032969883, 55.965947014944895, 52.63482427597046, 47.398887634277344, 56.99264757973807, 56.8690356527056, 55.14465604509626, 54.19327047892979, 55.47516795567104, 55.53100367954799, 54.32961845397949, 42.820716108594624, 41.917464188167024, 41.99056271144322, 42.31254570824759, 44.87322439466204, 44.25432055337088, 40.34044892447335, 40.269535609654014, 38.26553269795009, 39.39755058288574, 37.84078584398542, 41.3669445174081, 42.91874129431588, 40.99899571282523, 44.422981125967844, 49.37380886077881, 50.32960305895124, 49.128221307482036, 50.579098973955425, 50.68768889563424, 49.55794307163784, 49.56656231198992, 52.34053332465035, 51.95843798773629, 50.465485504695344, 51.89815541676113, 49.61219808033535, 49.49308163779122, 37.840949126652305, 38.04288809640067, 40.11964559555054, 38.77327230998448, 40.394922801426475, 35.10572126933506, 39.26256445475987, 36.01378829138619, 39.00043671471732, 37.97170032773699, 41.3952306338719, 39.70205191203526, 38.71704053878784, 38.7674879346575, 43.93745837892805, 41.757683413369314, 40.90865870884487, 37.68130036762783, 42.4096120425633, 40.43564966746739, 38.53664445877075, 37.03857115336827, 37.32657745906285, 37.06623888015747, 38.35689803532192, 38.120235443115234, 36.643649441855295, 42.45151662826538, 37.8669319152832, 44.04953977039882, 49.821071352277485, 51.3620810508728, 51.845936230250764, 53.27312748772757, 50.26331377029419, 48.095965657915386, 46.852880818503245, 45.875971044812886, 49.81966086796352, 45.05463491167341, 48.62890638623919, 49.965750217437744, 50.838061809539795, 49.769241264888215, 48.06113086427961, 43.18199464253017, 42.14778307506016, 41.24301644733974, 41.936724594661165, 40.23303672245571, 37.82547548839024, 37.147630078451975, 38.771900040762766, 40.041652066367014, 42.19456877027239, 42.98585047040667, 42.82286657605852, 41.03471292768206, 39.767691544124055, 44.019099712371826, 51.27598244803292, 53.320594106401714, 54.1885769707816, 55.97113731929234, 55.374148096357075, 54.5098443031311, 56.6622815813337, 57.7392384665353, 57.58424500056675, 57.66682086672102, 54.92476987838745, 53.73218107223511, 56.243343421391074, 59.83532238006592, 61.38021959577288, 56.58522258486067, 50.56630039215088, 50.35236535753523, 56.1119703565325, 60.708120346069336, 64.02590601784843, 68.74336460658482, 71.76797798701695, 45.287052154541016, 0.36712177896073883, 15.537697178976876, 65.88109588623047, 47.554502964019775, 31.28143971306937, 40.4090450150626, 33.145839418683735, 28.91372118677412, 49.66147470474243, 38.23358488082886, 0.08665594471884625, 0.10081690270453691, 0.04292313461857183, 0.009436643499481891, 0.05508649229471173, 0.055655606756252904, 0.0015157138571209672, 0.008568826896537627, 0.0832724841311574, 0.04115577141887375, 0.0481886511801609, 0.07886157224753074, 0.11430163947599274, 0.03669853934219905, 0.04281870468652674, 0.014023320549832923, 0.12333063355513982, 0.04161147553739803, 0.0972095187753439, 0.1247767409575837, 34.64461101804461, 62.925234930855886, 48.00101505007063, 42.37320000784737, 34.25827380589077, 37.72073139463152, 36.798851353781565, 68.58529308864048, 42.38857289722988, 0.07412759627082519, 2.3452437094279697, 46.78646298817226, 62.150191170828684, 65.89933490753174, 63.90627193450928, 66.26795768737793, 61.88273416246687, 64.43418911525181, 60.95965208326067, 54.5433589390346, 51.03854513168335, 56.71674851008824, 58.40655735560826, 60.83700942993164, 59.18276841299874, 55.06631163188389, 46.80207559040615, 58.342918804713655, 58.638703618730815, 56.98977797372, 55.18237434114729, 56.34780611310686, 57.67341470718384, 56.134260177612305, 45.63923897062029, 43.07995687212263, 43.74882868358067, 43.79229661396572, 46.72795915603638, 46.81150776999337, 45.07545518875122, 41.512589182172505, 40.36004631859915, 40.818408557346885, 40.50268588747297, 43.11955118179321, 43.22058841160366, 42.416525500161306, 48.6644082069397, 51.37169735772269, 51.69469826562064, 52.20638792855399, 53.45293297086443, 52.01998513085501, 51.46079063415527, 52.49869864327567, 54.15501717158726, 53.03067009789603, 52.22658634185791, 53.63464226041521, 52.043133054460796, 49.8701707976205, 40.00308609008789, 40.51044702529907, 42.374207496643066, 45.41189043862479, 40.779203346797395, 36.47462408883231, 39.611391816820415, 39.422498089926584, 40.90380539212908, 41.413785798209055, 41.637837409973145, 40.53750678471157, 38.82442842211042, 38.70547178813389, 43.68918187277657, 40.86026797975813, 38.1386273247855, 36.91656078611101, 39.88899319512503, 39.29250424248831, 38.02384655816214, 39.34820795059204, 39.75468104226248, 40.01670455932617, 38.26910407202584, 39.4532264981951, 38.51740837097168, 44.60322434561593, 38.25742415019444, 43.6524224281311, 50.51675278799874, 51.86272655214582, 52.46818215506417, 53.55591917037964, 52.71823392595564, 50.6071696962629, 49.261574608939036, 47.25931569508144, 51.62008850915091, 46.437746797289165, 50.62352922984532, 52.91759163992745, 52.03842912401472, 50.87236854008266, 50.77653203691755, 46.645866189684185, 44.78852585383824, 45.74034915651594, 46.932038170950754, 42.58259092058454, 39.668922901153564, 39.859848976135254, 41.63109070914132, 44.5490631375994, 46.35641813278198, 46.23754487718855, 47.583185127803254, 44.83563116618565, 43.05610370635986, 45.529575552259175, 52.96685436793736, 55.12281090872628, 56.11469405038016, 57.32439626966204, 56.89930200576782, 57.78964417321341, 58.80509213038853, 60.1712121963501, 60.061833654131206, 58.83596992492676, 57.86711311340332, 57.38321624483381, 57.96255704334804, 63.25488526480538, 64.31606973920549, 60.94274016789028, 53.24598434993199, 53.31354863303048, 59.74609361376081, 65.7483297075544, 66.45035484858921, 68.79799134390694, 75.01926245008195, 46.13019173485892, 0.46704140731266564, 21.151148557662964, 71.30636051722935, 56.559135573250906, 34.42892503738403, 50.121699060712544, 33.33569547108242, 37.91768503189087, 60.63311454227993, 50.00135973521641, 0.7085053675941059, 0.11006399150937796, 0.12738374035273278, 0.09107791672327689, 0.045249790485416136, 0.025296028071482266, 0.024909208828051175, 0.0875169038772583, 0.08088919773165669, 0.06924682602818523, 0.17399988323450089, 0.1775149389037064, 0.24638898457799638, 0.12313731892832688, 0.1594465555889266, 0.15471100541097776, 0.2619897260197571, 0.23925747296639852, 0.42557645801986965, 0.19911755328731878, 42.211859362465994, 71.87871142796108, 55.41458313805716, 51.337807519095286, 40.00296449661255, 44.57483400617327, 43.303292819431846, 74.57669694083077, 42.67375128609793, 0.119703972446067, 5.2145101342882425, 50.67527593885149, 60.951654706682476, 69.02855341775077, 66.17740181514195, 68.92434433528355, 63.1390448978969, 67.18489061083112, 63.58662700653076, 57.26016712188721, 53.06862115859985, 60.30259568350655, 63.27725846426827, 63.71582875932966, 61.62392766135079, 55.82589912414551, 48.43257461275373, 60.64958872113909, 60.18800599234444, 59.27486678532192, 57.37439203262329, 59.89602184295654, 58.172677516937256, 58.44668320247105, 47.57936361857823, 47.215489932468955, 45.469025475638254, 44.50927427836827, 47.91863373347691, 50.07281848362514, 47.0052478654044, 45.53987973076956, 41.5553240776062, 42.9055883543832, 41.903633798871724, 44.818201610020225, 47.45868035725185, 46.67796686717442, 50.195144993918284, 54.698123114449636, 55.15337950842721, 54.219722270965576, 54.90747928619385, 55.21191460745675, 52.768782070704866, 53.931139264787944, 57.68959706170218, 55.685392652239116, 54.00302185331072, 57.35290820258004, 55.10018062591553, 52.966903005327495, 42.42573881149292, 45.861563955034526, 44.937029702322825, 42.055674280439106, 42.765123571668354, 39.250752517155235, 43.72867195946829, 41.34436287198748, 45.06349386487688, 43.37169088636126, 45.874220098767964, 42.21049404144287, 39.795338426317485, 40.90404857907976, 43.76545224870954, 41.44442040579659, 39.34381321498326, 37.62502690723964, 43.680687699999126, 42.5475754737854, 40.43398209980556, 40.878771032605854, 44.06864384242466, 43.83821031025478, 41.3124497958592, 42.520901339394705, 41.38073321751186, 46.8961889403207, 40.12280355181013, 47.92629759652274, 51.17366674968174, 54.71341609954834, 55.17983130046299, 57.780927658081055, 55.22328533445086, 52.94923721040998, 52.532793453761506, 49.34706177030291, 53.252835273742676, 47.95372213636126, 54.11020129067557, 54.97380331584385, 57.366610050201416, 55.73547874178205, 52.615390164511545, 48.31205463409424, 47.73997122900826, 47.5660856110709, 47.50478860310146, 45.86915486199515, 41.9073371887207, 40.7824307850429, 43.88955054964338, 46.67016404015677, 48.48074299948556, 49.38710423878261, 49.9836939402989, 46.1409649167742, 43.844481059483115, 49.39004332678658, 56.48518589564732, 57.53253998075213, 59.06719207763672, 61.06076226915632, 59.94060843331473, 60.06660706656319, 61.613581793648855, 63.371246746608186, 62.94755254473005, 62.27655111040388, 59.640474046979634, 61.47783483777727, 59.601730891636436, 64.30737059456962, 67.88464369092668, 62.53641373770577, 56.75668328148978, 57.2846143586295, 64.17378452845982, 69.68877819606236, 70.43775926317487, 74.53906549726213, 75.09781878335136, 54.66338906969343, 0.47561168457780567, 19.30556457383292, 81.76317705426897, 61.797014236450195, 45.56864527293614, 54.644621985299246, 46.27533612932478, 39.78342921393258, 64.1821849005563, 58.77631964002337, 0.7543230376073292, 0.23720083332487515, 0.19223766960203648, 0.13115623220801353, 0.2089803990508829, 0.19391382751720293, 0.11296474907015051, 0.2421740878905569, 0.23512565610664232], [0.02113323099911213, 0.041693571489304304, 0.022254476190677712, 0.10060397841568504, 0.08881919578249965, 0.07547857984900475, 0.06655663823974983, 0.1173871960490942, 0.029911455498742204, 0.20907950587570667, 0.1041143996907132, 30.957667555127824, 53.77787937436785, 36.832859311785015, 30.065147127423966, 37.51508903503418, 36.32989658628191, 26.66289394242423, 49.85895640509469, 50.908471379961284, 3.1323684326239993, 0.6176696675164359, 34.305632727486746, 58.041082109723774, 59.62676525115967, 59.314214433942524, 58.60440036228725, 58.23408917018345, 55.96006883893694, 52.34409775052752, 51.058799130576, 53.23588514328003, 55.54494176592146, 55.2914263180324, 56.88092054639544, 55.891743728092735, 47.90600190843855, 48.327948638371055, 52.293511390686035, 51.265904085976736, 54.83640616280692, 52.42661803109305, 56.599831172398154, 52.35519749777657, 54.05434124810355, 43.83267954417637, 42.172998087746755, 44.39056083134243, 46.65888711384365, 45.99464280264718, 46.56720563343593, 43.441662720271516, 40.02608115332467, 40.78948320661272, 40.305287565503804, 39.53619493756975, 40.04920128413609, 40.52628544398716, 45.717552116939, 46.07167053222656, 46.19708899089268, 50.91753530502319, 51.5112692969186, 50.63710948399135, 52.398873874119346, 51.323810373033794, 51.85342986243111, 51.18333516802107, 51.67521899087088, 49.29845217296055, 52.808407647269114, 51.35196099962507, 48.125412123543875, 42.36362191608974, 32.8580276625497, 39.67182724816458, 34.708544867379324, 43.39895214353289, 41.03784309114729, 38.3854203905378, 38.55358416693551, 37.18384061540876, 37.37770925249372, 40.621882234300884, 38.07317181995937, 41.52037811279297, 44.44514240537371, 45.103602341243196, 43.318512848445344, 37.18576526641846, 42.632499831063406, 47.78960568564278, 45.03685794557844, 43.081780774252756, 39.08832100459507, 38.23113911492484, 38.48737825666155, 38.53962871006557, 37.738244329180034, 41.35067878450666, 38.94329125540597, 38.72855370385306, 43.16508272715977, 46.303604875292095, 52.70094680786133, 50.88087313515799, 52.75529214314052, 51.05884429386684, 48.6735520362854, 50.15473427091326, 48.65446186065674, 50.402142252240864, 48.827572754451204, 49.208733558654785, 46.55834320613316, 49.29829583849226, 49.64212397166661, 48.375971112932476, 44.11812891278948, 42.673806871686665, 47.17539187840053, 46.36926882607596, 39.366964612688335, 40.774092946733745, 39.29390777860369, 39.84183577128819, 43.84757995605469, 43.89208664212908, 45.58108254841396, 43.7503399167742, 42.05325630732945, 39.04877533231463, 42.96325145448957, 50.86550719397408, 50.722881521497456, 53.482973507472444, 52.720561572483604, 56.322768279484336, 54.14722129276821, 56.332964760916575, 55.83160359518868, 57.987032072884695, 56.834878308432444, 58.27958597455706, 54.72872992924282, 58.82196235656738, 59.63053812299456, 60.48708425249372, 57.716663769313264, 53.687990529196604, 49.80680670057024, 56.784069606236045, 59.63116346086775, 66.76933969770158, 63.75849764687674, 79.08632796151298, 19.98630564553397, 0.5314750926835197, 33.76224190848214, 65.24130575997489, 45.79766137259347, 39.34792307444981, 46.79721532549177, 36.86326115471976, 40.31805835451399, 46.67084148951939, 48.17196158000401, 1.9870959903512682, 0.031371455905692916, 0.08744991211486713, 0.07260978128761053, 0.041654046824468036, 0.04197950614616275, 0.07830511924943753, 0.026076519762032797, 0.04429093568718859, 0.05890716692166669, 0.01566366708305265, 0.036657114779310565, 0.07904928896043982, 0.02430326009302267, 0.026416762665446316, 0.014796767350552338, 0.14469989974583897, 0.04217885973464165, 0.07792807769562517, 0.06917709976966892, 39.6094081061227, 62.54774624960763, 37.65501185825893, 28.47487643786839, 39.231801305498394, 41.55611269814627, 36.15302324295044, 54.66878087180001, 62.61218384334019, 4.1141022103173395, 0.42944226201091495, 35.95100089481899, 64.0714236668178, 64.39498737880162, 64.44632066999162, 62.86090850830078, 60.83477905818394, 59.262436458042686, 56.41186155591692, 53.211347579956055, 56.28491449356079, 59.31794561658587, 57.38934108189174, 59.53239481789725, 56.860114165714805, 49.55906173161098, 49.84902742930821, 54.06448909214565, 52.12140451158796, 55.38041884558541, 53.527362074170796, 57.08889055252075, 54.54277876445225, 54.71002537863595, 47.63898958478655, 43.68845578602382, 46.7961175101144, 47.91010134560721, 47.443634033203125, 49.182563168661936, 47.09531388963972, 43.69163111277989, 40.75421415056501, 40.637592111315044, 40.92635924475533, 41.82735300064087, 44.55335365022932, 46.623913356236045, 48.31997210638863, 48.39505781446184, 51.906263964516775, 52.725744928632466, 52.82406888689314, 53.727171421051025, 53.84721892220633, 53.39465842928205, 52.688374042510986, 53.741696630205425, 52.16632808957781, 54.41018629074097, 53.16148730686733, 51.184394768306184, 44.715191091809956, 35.89475522722517, 39.650940963200156, 39.4171028137207, 46.27399165289742, 40.08280277252197, 41.59268454142979, 41.21086713245937, 39.965753419058665, 38.588603087833945, 41.938604082380024, 38.0257225717817, 41.05592925207955, 46.19750935690743, 47.95166546957833, 43.19129133224487, 35.66247347423008, 44.07065534591675, 47.95918689455305, 44.9994592666626, 42.80814334324428, 40.24443176814488, 40.56063733782087, 38.94338853018624, 40.82399490901402, 39.77767263139997, 39.92053801672799, 39.85649994441441, 40.759199483054026, 44.978944710322786, 47.329103401729036, 51.50726366043091, 50.709700788770405, 53.64984491893223, 52.548298358917236, 48.81282867704119, 51.69991288866316, 50.84103216443743, 52.26162610735212, 52.16208274023873, 51.21302482060024, 48.83500732694353, 50.27186700275966, 52.02026653289795, 50.628914083753315, 47.780242988041465, 45.57852561133248, 51.195056779044016, 47.85435247421265, 40.84735475267683, 43.41896295547485, 42.97586938313076, 43.459404945373535, 46.724012579236714, 45.92743287767683, 49.02776425225394, 49.961334637233186, 45.15167345319475, 41.91968066351754, 44.38766690662929, 52.85158027921404, 53.38429519108364, 55.515766280038015, 56.976625033787315, 57.82484374727522, 56.20854336874825, 59.84293760572161, 58.98138877323696, 60.2185502733503, 60.110762868608745, 60.14839431217739, 55.65869419915335, 59.55985409872872, 62.532738140651155, 61.9498815536499, 60.14052200317383, 56.61650684901646, 53.08761753354754, 60.99016162327358, 62.68545954568045, 71.06791918618339, 65.1346995489938, 80.15045847211564, 18.669752291270665, 0.40155805540936335, 41.86371987206595, 68.7904178074428, 54.30365303584507, 41.643771171569824, 59.25375120980399, 34.386179719652446, 41.04806041717529, 53.90091460091727, 53.40879453931536, 3.3834216126373837, 0.17388226597436837, 0.046080263065440316, 0.046580743709845204, 0.03295184199565223, 0.023785593852932965, 0.07475403337074177, 0.035766147409698794, 0.06827043449240071, 0.12485151551663876, 0.07592815001096044, 0.12967402674257755, 0.1421869724456753, 0.15855360350438527, 0.12749898274030003, 0.1628006627517087, 0.2395087480545044, 0.2322627268731594, 0.33241718262434006, 0.24588960994567188, 46.59238243103027, 71.88355432237897, 48.38374267305647, 40.236899920872276, 51.330671719142366, 47.934083053043906, 41.61370284216744, 61.3002736227853, 67.11806283678327, 3.7937424864087785, 0.3752869708197457, 41.46586602074759, 63.320205279758994, 66.53897217341832, 66.96974658966064, 64.95105866023472, 63.98181969778878, 61.263482911246165, 58.63477093832833, 55.06424106870379, 60.497916494097026, 62.38000978742327, 58.74817943572998, 61.414661816188264, 58.662431716918945, 51.47756358555385, 50.30612162181309, 56.29751852580479, 53.355849266052246, 59.36675671168736, 54.91134248461042, 59.7197390965053, 55.82756321770804, 57.891504764556885, 49.0807512147086, 47.829627309526714, 49.51351628984724, 51.32960169655936, 48.390062059674946, 52.684837409428184, 47.98244251523699, 44.8753262247358, 45.5610647882734, 43.57756948471069, 43.49840170996529, 42.97854791368757, 45.9810278075082, 50.36164467675345, 52.312281949179514, 50.621632371629985, 54.28700862612043, 55.0111985206604, 54.30100577218192, 56.25284855706351, 54.80719941002982, 55.70347881317139, 55.86666767937796, 55.58477578844343, 53.4935417175293, 54.50339984893799, 55.74859694072178, 52.20897265842983, 46.01584523064749, 41.087807587214876, 44.846800395420615, 42.12309612546648, 43.98877429962158, 39.755935192108154, 44.00738852364676, 42.715395314352854, 42.29482780184065, 44.15021569388253, 45.645304747990195, 38.26131861550467, 44.02185467311314, 47.17319972174508, 49.58426979609898, 44.37909630366734, 36.96577140263149, 46.57851035254342, 51.145936489105225, 47.743559973580496, 45.60222591672625, 40.48546130316598, 43.58880819593157, 42.56466804231916, 42.70553234645298, 42.64337376185826, 43.0485405921936, 41.272963183266775, 41.75303159441267, 47.5690837587629, 49.83334534508841, 54.83105952399117, 52.1611864226205, 57.13506828035627, 54.860526834215435, 52.205238001687185, 53.438366072518484, 50.76952130453927, 54.70080859320504, 53.24138464246477, 53.84393242427281, 51.22570180892944, 52.83121510914394, 54.70882681437901, 52.669419356754844, 49.53559071677071, 47.62522520337786, 52.165869508470806, 50.447315965379985, 44.920625005449565, 47.69356768471854, 45.80151762281145, 46.27718782424927, 47.937539781842915, 47.05509771619524, 51.6427709034511, 51.217829499925884, 46.77372694015503, 44.21577194758824, 46.60932561329433, 56.12008932658604, 56.208821296691895, 58.54295744214739, 58.80707931518555, 63.183749607631135, 58.67289570399693, 62.93448298318045, 62.01257514953613, 63.60729789733887, 62.51802880423409, 63.60538714272635, 58.58536924634661, 62.03938824789864, 65.69869872501918, 66.57399804251534, 63.972780091421946, 60.88388892582485, 58.11794655663626, 65.30054610116142, 66.41969244820731, 73.46291460309709, 68.6056443623134, 81.88893944876534, 26.21858443532671, 0.5566040128469467, 41.42469446999686, 78.8749429157802, 58.257150241306846, 53.61931453432356, 63.534550258091514, 48.29508018493652, 50.0171286719186, 60.39397839137486, 69.4106695992606, 4.436078258923121, 0.2657766028174332, 0.21655135708195822, 0.2620109777365412, 0.19543902496142046, 0.1982512947704111, 0.17784917168319225, 0.09309779333748988, 0.12906061751501902], [0.06831755874944584, 0.04567480446504695, 0.04228051445846047, 0.016227648427177752, 0.019033629912883043, 0.13876601601285593, 0.10927700623869896, 0.049233951339764256, 0.07072190009057522, 0.12073605135083199, 0.04422493797859975, 39.95324666159493, 51.51842246736799, 46.30264254978725, 55.67740222385952, 96.67276055472237, 43.147243227277485, 24.318109682628087, 48.60041529791695, 50.14269651685442, 12.241813966206141, 0.8872076070734433, 21.53131229536874, 60.038439069475444, 63.46196937561035, 56.784003598349436, 58.510780334472656, 52.60614211218697, 55.44240719931466, 47.80549968991961, 54.841919558388845, 53.33773183822632, 56.831046376909526, 54.18374449866158, 58.08265665599278, 45.40938908713204, 48.78690147399902, 53.60571690968105, 54.336000374385286, 51.996277877262656, 55.07688331604004, 54.97796181270054, 57.92457818984985, 53.65013674327305, 53.88897064753941, 41.891224316188264, 42.25041491644723, 45.65662683759417, 50.2472425869533, 48.603211947849815, 51.005714893341064, 47.21620559692383, 43.7321321623666, 41.144386768341064, 40.40904154096331, 38.23825059618269, 40.92618553979056, 42.274365356990266, 46.700413022722515, 43.01633569172451, 50.842658042907715, 51.26355906895229, 49.74802494049072, 51.98941305705479, 53.648972920009065, 48.95647573471069, 51.64986848831177, 51.86522095543997, 52.94311237335205, 50.08021136692592, 51.337446212768555, 51.630024433135986, 52.47312232426235, 44.764599731990266, 39.315617425101145, 36.750804560525076, 39.0937614440918, 33.65421479088919, 40.76496648788452, 43.384781292506624, 38.8604166167123, 34.962817668914795, 37.399293831416536, 40.131700720105854, 43.529890945979524, 43.28909764971052, 46.40703228541783, 45.50245673315865, 46.85279744012015, 42.66919674192156, 47.976032802036826, 45.439947264535085, 46.3943691934858, 43.349863120487754, 41.28504262651716, 39.93328448704311, 38.661090169634136, 37.34980181285313, 37.437779903411865, 39.269644669124055, 41.23239265169416, 44.06563179833548, 47.30893972941807, 48.634565693991526, 47.58451918193272, 48.88236277444022, 50.63844353812081, 48.053029264722554, 48.30171571459089, 48.79219947542463, 49.81187193734305, 49.73838084084647, 50.5400778906686, 51.885520117623464, 51.89392743791853, 48.269920757838655, 50.39595488139561, 47.98876537595476, 46.34832348142351, 44.55788734980992, 45.141925130571636, 40.34698370524815, 40.985985210963655, 41.450666836329866, 40.219348771231516, 41.115926946912495, 44.11271626608712, 46.86749982833862, 46.875493730817524, 47.50563628332955, 47.05523668016706, 40.88817889349801, 40.85272571018764, 47.19669158118111, 50.03029898234776, 53.17685672215053, 54.35302346093314, 53.54593808310372, 53.01966067722866, 55.68042469024658, 56.66901785986764, 57.548489570617676, 58.945181710379465, 58.642149925231934, 55.088636193956646, 57.650405747549875, 58.18068184171404, 62.672521999904085, 57.17765031542097, 53.674253940582275, 48.79743494306292, 56.986779826028005, 59.06572600773403, 68.68677152906145, 61.641812324523926, 74.38646221160889, 5.016584183488574, 0.1865392103791237, 53.93584666933332, 55.08311237607683, 41.45108372824532, 25.472773483821324, 44.47139964784895, 41.076624461582725, 50.555363927568706, 46.83359956741333, 45.57784121377127, 2.9937143070357184, 0.09157211413340909, 0.12560190739376204, 0.008431205575886582, 0.026813156037990536, 0.026368669799662063, 0.00759218430279621, 0.009737340533839805, 0.15948287078312465, 0.10669401341250964, 0.0647523050595607, 0.08350166611905609, 0.010713137503314232, 0.08933722334248678, 0.10952685640326568, 0.03334037454000541, 0.03290932499138372, 0.08242959436029196, 0.1267337987997702, 0.08299643572952066, 47.56136431012835, 59.38073648725237, 46.50813552311489, 53.519034658159526, 94.68687507084438, 41.92156362533569, 33.97122287750244, 50.98182003838675, 60.79877349308559, 15.338502747671944, 0.6168456545897892, 23.747838020324707, 61.93190656389509, 69.06117521013532, 59.249728202819824, 64.80966976710728, 57.36081872667585, 58.032438550676616, 52.404988288879395, 56.85247114726475, 55.917976651872905, 59.498932293483186, 56.42059891564505, 58.82599231175014, 46.608804498400005, 48.638731139046804, 54.46524034227644, 54.47989756720406, 54.64269733428955, 58.19002022062029, 55.660695280347554, 59.11373111179897, 57.35648652485439, 52.731848921094624, 45.30260917118618, 44.30642856870379, 47.050546646118164, 50.92443486622402, 51.13413149969918, 52.85473476137434, 49.26992286954607, 46.1557993207659, 42.22028752735683, 41.6170414515904, 42.09967374801636, 42.34829766409737, 44.220778124673025, 46.763433183942524, 45.99412863595145, 52.313018458230154, 53.24629354476929, 51.903588908059255, 52.61222873415266, 54.736463274274556, 52.05443777356829, 54.33432585852486, 53.45632716587612, 53.684012685503276, 52.00445243290493, 52.32945442199707, 51.07830272402082, 55.037219524383545, 46.93782949447632, 41.86874341964722, 41.070228644779746, 39.11761460985456, 38.40624761581421, 43.45811258043562, 40.96461950029646, 40.491353375571116, 36.312939507620676, 40.592814445495605, 41.415442943573, 43.46003723144531, 44.28405884334019, 46.53611591884068, 47.27180855614798, 46.9585941859654, 41.72200788770403, 48.60180493763515, 46.91692583901541, 48.868230138506206, 43.237350940704346, 40.95488854816982, 40.68628508704049, 39.592193944113596, 38.415704114096506, 39.5112578528268, 40.049850940704346, 44.466594968523296, 46.37743990761893, 49.81836155482701, 49.75557763235909, 47.97134971618652, 51.544071742466514, 52.2935391834804, 50.62418583461216, 50.00729349681309, 51.68795156478882, 51.364141191755024, 51.18278973443167, 52.99504320962088, 52.552394321986604, 52.2677127293178, 51.51356567655291, 53.21012817110334, 50.11570276532854, 48.90453447614397, 46.82413264683315, 46.94917937687465, 44.15128224236624, 44.56704160145351, 43.62924671173096, 42.227937494005474, 44.81713158743722, 48.31430932453701, 48.91608933040074, 50.63414607729231, 51.1228198323931, 49.892047200884136, 44.410453523908345, 44.98525367464338, 49.13588169642857, 53.69922229221889, 56.721299580165315, 56.473999295915874, 55.84685141699654, 56.15105397360665, 56.7160120010376, 60.73454434531075, 61.0871376310076, 61.3496127809797, 60.58075986589704, 57.759343079158235, 60.36690820966448, 60.33702400752476, 64.43518270765031, 60.35877881731306, 58.39995656694685, 51.333312034606934, 58.59033720833914, 61.923026766095845, 69.92896352495465, 64.98784242357526, 74.34475217546735, 3.604726731777191, 0.6749600076249668, 59.9601537159511, 59.01244722093855, 47.32128667831421, 30.649518421718053, 61.09899125780378, 39.25341715131487, 46.640894753592356, 56.73311151776995, 57.059336389814106, 6.224713504314423, 0.1318250098930938, 0.11512597809944834, 0.029197643444474255, 0.02318678839531328, 0.043177649711391757, 0.05405941080035908, 0.02522789128124714, 0.08227552619895764, 0.22614475658961705, 0.16203091905585357, 0.1227511917906148, 0.08218921654458557, 0.1698597746768168, 0.2567258413348879, 0.19059640195752892, 0.1594332427318607, 0.198225822565811, 0.1282867890383516, 0.22892900290233748, 54.687103271484375, 67.66437884739467, 61.518808364868164, 70.26054545811245, 106.23882498059953, 52.83644362858364, 38.50080565043858, 60.40093353816441, 64.65496812547956, 17.187621627535137, 0.7131977358034679, 29.065443788255962, 62.58591270446777, 71.17157241276333, 61.66581835065569, 67.62770625523159, 59.00843811035156, 62.31193828582764, 55.57879686355591, 62.08935969216483, 56.81178944451468, 62.322020121983115, 58.58254132952009, 61.599004473005024, 45.91786520821707, 49.38855988638741, 54.25386224474226, 56.712614331926616, 54.77910089492798, 58.9861969266619, 58.25722667149135, 61.484345299857004, 58.89360523223877, 56.549745082855225, 46.27111162458147, 46.798417363848, 51.00095885140555, 53.03962285178048, 52.91466644832066, 56.23473807743618, 51.67402737481253, 47.51299442563738, 44.349003655569895, 43.40727261134556, 43.06019619532994, 46.15813738959176, 46.774459975106375, 47.52184295654297, 47.46925204140799, 54.31907108851841, 56.637142998831614, 53.734939507075715, 54.58420739855085, 57.49688182558332, 53.25199801581246, 58.141556535448345, 55.23148420878819, 57.2362687928336, 55.29521656036377, 55.87029811314174, 53.68896327699934, 57.13537400109427, 48.380900859832764, 46.641707692827495, 45.58530010495867, 45.02721037183489, 43.14403315952846, 43.928036621638704, 43.090003967285156, 42.05276993342808, 39.01142181668963, 42.224216733660015, 40.75656264168875, 44.525453158787315, 47.45396600450788, 48.035200187138145, 49.247956139700754, 49.709858485630576, 44.10413176672799, 51.56220654078892, 50.18379511151995, 51.55966002600533, 45.976768561771934, 41.63277217320034, 44.51333897454398, 41.44017505645752, 40.952088424137656, 41.892537525721956, 41.500283922467915, 45.06977503640311, 47.05255120141165, 52.35882098334176, 53.02244690486363, 52.444110121045796, 54.08977706091744, 54.18758685248238, 53.47635882241385, 53.09681000028338, 52.530761105673655, 54.10945783342634, 55.968597752707346, 54.10731431416103, 55.966836384364534, 55.79190158843994, 53.347494057246614, 56.24538966587612, 53.725816522325786, 51.67403779711042, 49.57049151829311, 50.714939730507986, 47.82947097505842, 46.288502965654644, 46.11389473506382, 44.736087799072266, 46.60633093970162, 51.19545977456229, 51.74258872440883, 52.74817718778338, 53.54228680474417, 52.2674035344805, 46.863171100616455, 48.19036388397217, 52.46920701435634, 55.67353902544294, 59.497257777622764, 60.06489086151123, 59.96169621603829, 58.710297857012065, 61.59472438267299, 61.99757398877825, 63.99199880872454, 64.46235016414097, 63.14791079929897, 58.37208734239851, 63.211945397513254, 61.74420097896031, 68.97371823447091, 63.642247336251394, 59.62359687260219, 54.187229020254954, 63.511572565351216, 63.92027950286865, 74.88944230760846, 67.83520030975342, 78.07754680088588, 7.196037360600062, 0.4370137628700052, 64.98739079066685, 65.79005364009312, 53.945289271218435, 35.656876700265066, 62.9295289175851, 52.43258305958339, 64.26154722486223, 59.03361143384661, 69.17966978890556, 7.487113033022199, 0.13546080408351763, 0.2890642232128552, 0.15373951968337807, 0.06510737564946924, 0.10965467204472848, 0.08854814818395035, 0.11371743439563683, 0.2996034733951092], [0.050492708438209126, 0.020737124307613288, 0.01859415295932974, 0.052108795648174625, 0.04684289910697511, 0.19885620873953613, 0.06152643422995295, 0.041312950663268566, 0.07974096041704927, 0.06917963749063866, 1.3685699573584964, 47.68673413140433, 55.19174746104649, 34.17791441508702, 44.03146055766514, 81.10994911193848, 44.78568751471383, 25.316011701311382, 45.328553744724815, 48.06755794797625, 21.112426246915543, 0.3050110175141266, 15.51974824496678, 63.61628886631557, 61.592751094273154, 59.78330816541399, 56.019145897456575, 53.60732889175415, 51.650097778865266, 53.776100635528564, 58.144377504076274, 55.55318232945034, 60.948472431727815, 62.22323063441685, 51.577784402029856, 49.76068803242275, 55.65174947466169, 55.69753810337612, 56.05265358516148, 55.730274541037424, 56.59585680280413, 53.481344154902864, 55.069382735661094, 50.747172423771445, 46.74315486635481, 42.105649198804585, 44.07326439448765, 49.09795148032052, 51.351825509752544, 51.976006507873535, 50.12070894241333, 48.68996715545654, 44.423238209315706, 43.27757058824812, 43.00578832626343, 39.146790095738, 40.88796697344099, 40.016131332942415, 43.19911847795759, 51.57998350688389, 52.66772052219936, 51.282600607190815, 50.64712183816092, 49.6505834034511, 51.63610063280378, 50.19238655907767, 51.83277286802019, 50.48801156452724, 50.49799265180315, 50.120274680001394, 51.01079055241176, 50.6014061655317, 51.19882617677961, 43.95349482127598, 40.026293073381694, 34.049344948359895, 39.2918997492109, 33.81135177612305, 35.93235540390015, 36.352332319532124, 40.039046491895405, 39.37726879119873, 45.068357603890554, 40.40380259922573, 40.54986415590559, 43.17770760399954, 46.18790694645473, 45.80598184040615, 45.20936434609549, 41.31182098388672, 45.65779413495745, 44.5548996244158, 44.52088819231306, 45.87363645008632, 41.39259726660592, 40.848817348480225, 38.336168084825786, 36.93744012287685, 37.83054767336164, 38.76267630713326, 44.34792668478829, 45.74897534506661, 48.29597997665405, 48.31797449929373, 47.76318516050066, 51.351519789014546, 51.74390888214111, 48.66746194022042, 49.59985113143921, 50.47775949750628, 52.10296746662685, 50.43886348179409, 52.1678740637643, 49.251711641039165, 51.46895476749965, 49.76973111288888, 48.36822387150356, 50.00453853607178, 49.320450169699534, 47.48300947461809, 38.630486828940256, 38.777934551239014, 40.508178438459126, 42.46198408944266, 41.973358971732004, 43.04678617204939, 45.82821954999651, 48.246870109013145, 48.48525932856968, 51.64611298697335, 48.748769760131836, 44.643989426749094, 38.69788435527256, 42.06845201764788, 49.229400975363596, 50.76032536370413, 54.506182602473665, 52.31998750141689, 55.10244573865618, 55.58928516932896, 56.35374682290213, 58.664154870169504, 54.847707407815115, 56.354882853371755, 55.57970012937273, 58.138374260493684, 59.26487527574812, 59.93907982962472, 57.378091948372976, 55.67983409336635, 49.442210401807515, 57.4065899848938, 61.607786996024, 65.32101549421037, 68.31244427817208, 58.114416871752056, 0.2878789853836809, 4.902029233319419, 67.78124754769462, 47.77154384340559, 29.863162994384766, 18.661551679883683, 45.24300752367292, 40.728224413735525, 38.19955955232893, 40.934627601078574, 53.18227284295218, 15.28318987573896, 0.207816535074796, 0.035888385493308306, 0.05773782038262912, 0.07947365833180291, 0.057691666430660656, 0.0587171906871455, 0.009756125775831086, 0.08761623461863824, 0.01935237173789314, 0.07071577970470701, 0.0448237892373332, 0.04490466721888099, 0.050479141130511246, 0.11089200779263463, 0.014921807783788868, 0.020141265388312082, 0.06900003605655261, 0.042861486319452524, 1.75481402022498, 60.85910470145089, 59.36060755593436, 42.978474957602366, 45.50611843381609, 88.26270961761475, 46.55358716419765, 31.858178411211284, 50.498784746442524, 50.95349918093, 29.306990964072092, 0.30633736348577906, 16.17390203475952, 63.351333209446494, 64.87503841945103, 63.57469000135149, 59.54721532549177, 57.5390956061227, 54.121467794690815, 56.21745790754046, 60.911772046770366, 58.06865603583199, 63.730684007917134, 62.361166272844585, 51.89176654815674, 50.60572794505528, 57.159088202885215, 57.42362696783883, 56.50557885851179, 55.95601803915841, 58.96494933537075, 56.26083551134382, 56.79273053577968, 52.70577580588204, 47.94069078990391, 45.078192778996055, 46.516991002219065, 50.91716705049787, 54.37736300059727, 52.41368743351528, 53.58181510652815, 49.8270537512643, 45.69144426073347, 45.49474423272269, 45.15097515923636, 42.784582001822336, 44.71344709396362, 44.21735266276768, 44.024029459272114, 52.42966134207589, 53.74975654057094, 51.51198148727417, 51.17043236323765, 50.55692032405308, 53.310484477451865, 50.375815527779714, 53.49597706113543, 50.2372476032802, 53.47812366485596, 50.712125710078645, 51.85982567923409, 53.061554840632844, 51.213278429848806, 45.30894245420183, 41.955915519169395, 37.42421701976231, 41.737592697143555, 34.75941610336304, 39.667724336896626, 39.64909969057356, 41.400066580091206, 41.9547621182033, 43.883637632642476, 40.400259017944336, 41.16219847542899, 43.28384133747646, 46.35169335774013, 45.480542114802766, 44.647727557591026, 42.50055701392037, 46.91034936904907, 47.76142726625715, 47.925755637032644, 46.905120849609375, 41.89947182791573, 41.885804721287315, 38.039146491459434, 38.20817184448242, 37.52303777422224, 39.25027309145246, 45.3307181085859, 46.64632824489048, 48.15687009266445, 48.49703652518136, 47.43728685379028, 51.89734942572457, 51.00187948771885, 51.55471985680716, 51.4035131590707, 50.788205010550364, 51.96826621464321, 52.74848985671997, 53.40304143088204, 52.10425288336617, 53.29733501161848, 51.32605116707938, 50.907220704214915, 53.26585272380284, 54.14994151251656, 49.36292798178536, 42.97450406210763, 40.72774498803275, 42.22656869888306, 45.72635201045445, 44.58357484000069, 45.758299827575684, 49.354881967817036, 51.84396641595023, 49.47927556719099, 52.34321880340576, 50.173664637974326, 47.830134528023855, 43.10948324203491, 43.8959915297372, 51.17301361901419, 54.65490184511457, 56.79709053039551, 54.77497713906424, 56.32805585861206, 56.76569162096296, 59.82063388824463, 60.32307897295271, 58.660423687526155, 57.16854122706822, 58.487496920994346, 59.41687406812395, 61.598969732012065, 64.44044944218227, 60.44257409232003, 59.05000223432268, 53.05544737407139, 60.476571628025596, 64.21218722207206, 66.96873215266636, 72.23648806980678, 56.88053492137364, 0.2728927523962089, 6.32707827431815, 74.45232418605259, 52.020092827933176, 36.37554277692522, 23.804566587720597, 53.986888136182515, 43.70071588243757, 36.780028683798655, 49.763686180114746, 60.00446932656424, 24.601398161479406, 0.2437130053128515, 0.13415355208728993, 0.09391968244952814, 0.04426783496247871, 0.0972093084294881, 0.09396274228181158, 0.03159054129251412, 0.030594930252326385, 0.1548278627118894, 0.19977949133941106, 0.13099783499326023, 0.17290858179330826, 0.12703212350606918, 0.1761212144047022, 0.11322442442178726, 0.10886668932757207, 0.19047225719051702, 0.14274360186287335, 1.9852527635438102, 68.60488700866699, 69.88839299338204, 49.30128008978707, 52.85436303274972, 88.6126764842442, 57.23385429382324, 40.284630571092876, 60.799350193568635, 59.49185902731759, 32.111346449170796, 0.4401644452341965, 21.940029655184063, 65.98435306549072, 66.56543091365269, 66.16693782806396, 62.08088288988386, 60.3522127696446, 56.39334808077131, 59.62738364083426, 63.448330061776296, 63.52462823050362, 62.624106952122276, 63.39997059958321, 53.68772649765015, 51.98221124921526, 58.02619906834194, 61.079452923366, 57.989186014447895, 57.1215192931039, 60.89922360011509, 57.591082027980256, 58.18058456693377, 55.07439933504377, 52.11633580071585, 46.686033725738525, 47.78745869227818, 52.482123715536936, 54.90207011359078, 53.80355991636004, 55.984477860586985, 53.08640854699271, 48.14129223142351, 48.0354642186846, 46.7394688470023, 45.2764561516898, 46.248776640210835, 45.95861986705235, 45.333177770887104, 55.20985099247524, 56.050120966775076, 52.53827905654907, 53.703992230551584, 52.26945672716413, 54.98973900931222, 53.0562881061009, 56.96314900262015, 54.29286943163191, 52.50183228084019, 52.54838521139962, 52.91764027731759, 54.27495697566441, 52.84360374723162, 46.30679757254464, 43.09767130443028, 41.446987765175955, 48.08359786442348, 42.2104697227478, 45.106843675885884, 43.85162728173392, 42.619378158024375, 42.4565749168396, 45.27226291384016, 40.60205207552229, 43.43359933580671, 44.54949392591204, 48.20126213346209, 49.475325516292024, 47.30050114222935, 45.05880035672869, 48.97456884384155, 50.492927415030344, 49.748900413513184, 49.895271165030344, 42.342659200940815, 43.55535956791469, 39.44558000564575, 38.28447348730904, 38.50099325180054, 40.61995758329119, 47.54348659515381, 47.75665037972586, 50.184392656598774, 51.27724354607718, 49.75684567860195, 53.004266943250386, 54.063276631491526, 53.671860286167686, 54.12356615066528, 52.96122980117798, 55.869165556771414, 55.060363973890034, 55.09513275963919, 53.67416361400059, 56.046844891139436, 55.26736470631191, 53.708432129451204, 57.30748782839094, 58.414735385349815, 52.93558052607945, 44.90473794937134, 44.31701067515782, 44.216980934143066, 47.36734628677368, 47.20666224615914, 48.83116149902344, 50.19882753917149, 53.36491666521345, 52.16866268430437, 56.376005377088276, 52.056939125061035, 51.19267702102661, 44.15494046892439, 48.26060669762747, 53.92576830727713, 56.6230902671814, 59.544158118111746, 58.69207273210798, 60.685128756931846, 62.12114075251988, 62.74726377214704, 64.8536101749965, 60.63432352883475, 60.146580832345144, 59.27929278782436, 62.12269714900425, 64.23623493739537, 68.79847076960972, 62.35975578853062, 62.4403965813773, 53.07526363645281, 65.13840988704136, 67.73686940329415, 71.91415418897355, 72.7020034790039, 65.7836126599993, 0.6877385047929627, 5.436722644737788, 80.26845278058732, 58.305190086364746, 43.45875528880528, 26.06076305253165, 63.13700212751116, 51.658887250082834, 51.09741027014596, 54.165234497615266, 71.75749315534318, 27.57425093650818, 0.3073176565979208, 0.2872121754501547, 0.205287295792784, 0.21328978852501937, 0.2051217332482338, 0.18051888128476484, 0.19663843060178415, 0.17894610496503965], [0.05250119923480919, 0.10387438149856669, 0.0969342506889786, 0.016741033111299788, 0.05069837918771165, 0.05043679036732231, 0.1206410564482212, 0.04484244555767093, 0.06869993358850479, 0.22251327788191183, 4.049427943570273, 56.56164039884295, 44.51597581590925, 22.473661729267665, 47.59288133893694, 77.35852636609758, 39.82643508911133, 20.87855683054243, 40.84223393031529, 47.876534598214285, 32.96819135120937, 0.5954989971859115, 5.5526012267385205, 63.55795179094587, 59.28910364423479, 62.96538162231445, 55.15540838241577, 55.17296648025513, 53.37686061859131, 57.75176954269409, 56.375522477286204, 60.93957873753139, 63.56042534964425, 52.57475709915161, 51.02347796303885, 55.43544510432652, 56.580817426954, 55.61084542955671, 53.216673374176025, 56.134413037981304, 53.17458813531058, 53.302004201071604, 49.42107398169381, 46.011304582868306, 42.889301776885986, 40.30753878184727, 44.475075244903564, 52.60185159955706, 53.286398547036306, 52.64817523956299, 52.48002883366176, 49.716188294546946, 47.99262510027204, 47.57109873635428, 43.31977047239031, 43.71812111990792, 42.426874841962544, 42.25496598652431, 43.64551591873169, 45.96041945048741, 49.72547803606306, 50.35598884310041, 48.49897159848894, 51.736029624938965, 51.18596853528704, 49.810694217681885, 51.42455230440412, 49.50263541085379, 50.81277731486729, 48.783000060490195, 50.237786088671, 49.19950287682669, 50.33658252443586, 44.89560801642281, 37.679601533072336, 38.50468274525234, 33.2609224319458, 34.627150194985525, 36.38875477654593, 36.18789625167847, 42.45185014179775, 42.213464396340505, 44.000732149396626, 41.99643741335188, 42.51411989756993, 42.43196439743042, 42.63094343457903, 40.70482982907976, 44.561924253191265, 39.90840993608747, 44.75982631955828, 44.167937074388774, 43.765778814043315, 46.258319990975515, 43.89712061200823, 45.51691246032715, 43.378395898001536, 39.844250270298545, 41.30473034722464, 41.29960605076381, 43.34824071611677, 46.02820955004011, 45.13920838492257, 46.66760015487671, 49.72170863832746, 51.41306345803397, 49.46628590992519, 51.49346453802926, 52.4771522794451, 51.6612948008946, 52.115936279296875, 50.37843499864851, 52.36745759419033, 50.49482774734497, 50.50426687513079, 47.29961177280971, 47.39222431182861, 46.6122681753976, 44.64632749557495, 39.61256953648159, 37.465854099818635, 39.42795589991978, 42.66882153919765, 43.32916096278599, 40.66122988292149, 44.83832359313965, 46.76671273367745, 49.93708889825003, 51.16374472209385, 49.92671523775373, 50.71551295689174, 48.59426266806466, 42.68420137677874, 39.38622849328177, 44.80828653063093, 50.004792145320344, 55.712309973580496, 55.010548864092144, 54.77630424499512, 54.14378540856497, 54.82960040228707, 55.64826495306832, 53.04507718767439, 54.26477786472866, 53.59210886274065, 54.831250599452424, 59.41938931601388, 58.84610734667097, 60.07946818215506, 56.30579383032662, 52.771457127162385, 56.54842839922224, 62.32436861310686, 62.155138288225444, 67.53089005606515, 25.549462488719396, 0.8783812778336662, 18.580344608851842, 60.67181600843157, 38.404246534620015, 19.301119463784353, 27.034798009055002, 46.11671222959246, 44.02631194250924, 35.79257501874651, 39.28835964202881, 56.19371938705444, 25.421052830559866, 0.41826206765004564, 0.06355157627591065, 0.04700045833098037, 0.06709992765848126, 0.017952553994421448, 0.008703586495747524, 0.07474635913968086, 0.04948613566479512, 0.03192415999780808, 0.08286163796271596, 0.08961245071675096, 0.041995210839169364, 0.09119269092168127, 0.08349331335297652, 0.052836239470967224, 0.005521665227466396, 0.13686185676072324, 0.23121783722724232, 7.004018681389945, 66.28229876926967, 53.80686378479004, 29.858135972704204, 55.401836667742046, 85.42437049320766, 45.888008798871724, 27.545554876327515, 46.93826723098755, 51.06237745285034, 44.93409061431885, 0.8045928744333131, 3.8001352633748735, 64.75279181344169, 61.36424568721226, 67.04646165030343, 57.577936036246165, 59.41354588099888, 56.90155669621059, 60.63786711011614, 58.73154544830322, 62.09301444462368, 63.44416809082031, 54.250617436000276, 53.224844455718994, 58.77077497754778, 56.45058386666434, 57.53353009905134, 53.85844373703003, 56.30223635264805, 54.3372927393232, 54.4948605128697, 51.82625198364258, 48.43654203414917, 45.17916052682059, 42.732793603624614, 46.66302476610456, 53.05793482916695, 53.22591100420271, 53.92374985558646, 51.977198123931885, 53.0249274117606, 47.59145695822579, 47.28904356275286, 45.05140747342791, 44.5942576953343, 42.22905962807791, 44.62126186915806, 45.11665105819702, 48.72196708406721, 49.616287095206125, 51.2980568749564, 50.182016372680664, 53.05916813441685, 53.506746768951416, 51.05186135428292, 51.03821161815098, 51.54604850496565, 51.12571723120553, 51.316316740853445, 51.094742161887034, 51.1028333391462, 49.48562969480242, 46.58717475618635, 38.75613457815987, 38.94966622761318, 37.12823070798601, 38.74880075454712, 37.27077647617885, 38.95478357587542, 41.6828339440482, 41.89485822405134, 44.624478885105674, 42.545960017613, 41.87145321709769, 42.20400789805821, 44.113477093832834, 42.387113775525776, 42.68880108424595, 40.339795793805806, 45.037000383649556, 46.42571251732962, 46.58616379329136, 44.992055961063926, 44.14035620008196, 44.6423670223781, 42.99418830871582, 39.236974239349365, 40.69948319026402, 40.37317146573748, 44.13310922895159, 46.12679753984724, 46.169216292245046, 46.0239885193961, 51.54718106133597, 51.45301559993199, 51.511436053684776, 52.35664619718279, 52.87955720084054, 52.48659140723092, 51.78033133915493, 53.217795508248464, 52.94041994639805, 52.4721565246582, 53.198594161442344, 50.7788006237575, 50.57787956510271, 51.13579906736101, 48.09169946398054, 43.27059459686279, 40.59130668640137, 41.29393284661429, 45.99465322494507, 44.84154755728585, 43.199834142412456, 45.60861131123134, 50.530187129974365, 53.15626573562622, 51.58403083256313, 52.76682267870222, 54.94330767222813, 53.07109471729824, 46.41792706080845, 42.03924873897007, 46.75354937144688, 54.120102473667686, 58.895522935049875, 58.20118250165667, 57.32002585274832, 57.05467414855957, 58.69388621194022, 57.531483854566304, 53.64921610695975, 55.62879957471575, 55.05010148457119, 54.68795095171247, 60.67998708997454, 62.09140246255057, 62.269936425345286, 59.48361151559012, 56.157053743089946, 60.626541546412874, 65.57341575622559, 65.04568617684501, 69.51390593392509, 23.401268822806223, 0.9941555282899311, 25.555962528501237, 65.72954872676304, 42.820688315800254, 22.415948254721506, 31.48299653189523, 42.0376159123012, 47.904473304748535, 37.40113162994385, 52.93752949578421, 64.80249227796281, 35.68051099777222, 0.3849098187472139, 0.0969217995713864, 0.05202386002721531, 0.004941506760327944, 0.0251439700701407, 0.05691365817827838, 0.044776173042399545, 0.008603555166960826, 0.12770913860627583, 0.1718029768339225, 0.2453354096838406, 0.10389789952231304, 0.124567643606237, 0.11680186460060732, 0.22103356942534447, 0.1721169485577515, 0.3020646556147507, 0.36866677605680054, 7.44908206803458, 79.72606250217983, 59.78638621738979, 34.97306278773716, 59.18361609322684, 86.71524851662772, 55.02027634211949, 34.21844325746809, 57.46263762882778, 55.91676419121878, 51.69253042766026, 0.8186766015631812, 6.746504545211792, 70.49792371477399, 63.108271326337544, 69.99222687312535, 61.82589094979422, 62.585655621119905, 59.8955146244594, 63.24766608646938, 62.63583551134382, 62.44767829350063, 65.1993316922869, 59.75196484157017, 53.52013942173549, 60.767673356192454, 60.78445325578962, 60.5073938369751, 55.478617736271445, 59.128621101379395, 57.86893354143415, 57.67550958905901, 52.48404141834804, 49.34631136485508, 45.48780993052891, 45.64734751837594, 47.117853845868794, 56.99605219704764, 56.09166424615042, 56.10210044043404, 54.257391929626465, 54.00817394256592, 52.401951926095144, 49.91248532703945, 46.40399592263358, 47.251815114702495, 44.95512628555298, 48.35510567256382, 48.49019602366856, 49.39288861410958, 52.13032947267805, 55.16098778588431, 53.73694058826992, 56.2524733543396, 54.68699904850551, 54.48916299002511, 54.5618064062936, 53.231452192579, 56.13629947389875, 55.907679421561106, 50.57422481264387, 54.432496956416536, 52.4120580809457, 47.85812882014683, 39.09777750287737, 42.17748314993722, 38.423110893794465, 39.88078389848982, 36.36225782121931, 38.44971554619925, 43.119895117623464, 42.85105194364275, 44.849364280700684, 44.53867905480521, 43.91421665464129, 44.890535831451416, 44.40980039324079, 42.86130748476301, 45.806297983442036, 40.1631760597229, 46.14022145952497, 47.77493109021868, 47.77502836499895, 47.99638754980904, 46.07775020599365, 46.471383026668, 43.91585990360805, 40.46921294076102, 41.78488908495222, 41.31022637231009, 43.8455684525626, 49.58053513935634, 46.665949957711355, 46.124966689518516, 52.8853519984654, 52.73203999655587, 54.94873421532767, 55.929990087236675, 53.985686097826274, 55.22230911254883, 55.105117321014404, 54.107797213963096, 54.650211811065674, 54.76865775244576, 56.46750620433262, 51.953084400721956, 54.156083720070974, 53.32332474844796, 50.271088804517476, 45.65630374635969, 42.98087208611624, 44.154287338256836, 49.06331818444388, 47.87987320763724, 47.49049268450056, 50.551691804613384, 51.73639440536499, 54.44756065096174, 55.10685437066214, 55.95814071382795, 55.58430331093924, 54.80058125087193, 48.79305757795061, 45.469067164829795, 49.837232862200054, 57.39003937585013, 62.94077110290527, 62.40709386553083, 60.97910703931536, 59.986619404384065, 59.81668036324637, 60.99949305398123, 57.47181967326573, 59.33343315124512, 56.518102986471995, 59.425871985299246, 62.938387870788574, 66.53786046164376, 65.86002894810268, 64.22388798849923, 58.372789110456196, 64.62182521820068, 67.97413648877824, 68.08150700160435, 71.31096717289516, 35.14467634473528, 1.1690251848527362, 22.94801698412214, 69.45294938768659, 52.535322598048616, 31.220431055341447, 34.47182321548462, 62.81320912497384, 57.38361576625279, 50.44367858341762, 54.15724059513637, 72.85213320595878, 46.94093533924648, 0.8661755727870124, 0.1970954510782446, 0.12080769107810088, 0.15815925252224716, 0.07182739648435797, 0.16053662209638528, 0.19262680943523133, 0.07984901033341885], [0.07329812113727842, 0.08685742212193352, 0.13914755625384195, 0.015306330186181834, 0.022470353803198253, 0.028630123540226902, 0.30191583931446075, 0.12616210590515817, 0.1747619594846453, 0.15782397479883262, 12.364231671605792, 64.38305037362235, 42.79875980104719, 25.952081067221506, 20.10733457974025, 32.659111159188406, 32.054190567561555, 17.394889865602764, 38.10249669211251, 52.95947190693447, 53.3555782863072, 6.677356941359384, 0.5200141476733344, 41.32173606327602, 64.35554245540074, 60.215638978140696, 57.02619695663452, 56.510084765298025, 55.47064815248762, 59.5283648627145, 58.53355652945382, 62.92314352308001, 46.30958727427891, 52.270245347704204, 53.99587563105992, 57.139529023851665, 55.304617473057334, 56.501680919102256, 54.35836315155029, 53.940984862191335, 53.24237823486328, 53.19070100784302, 46.668934209006174, 44.0846802847726, 39.95454250063215, 44.268901348114014, 46.984347684042795, 53.510022844587056, 53.426842485155376, 52.9640577180045, 51.94961724962507, 51.75524139404297, 47.2840964453561, 44.95037719181606, 45.05158117839268, 44.85893542425973, 43.173799242292134, 42.44536052431379, 40.64828538894653, 42.744543007441926, 45.8505927494594, 47.449439253125874, 48.639606612069265, 50.953947339739116, 49.950512817927766, 49.01568133490426, 50.57935605730329, 49.516469274248394, 49.33091763087681, 50.757942131587434, 51.60285350254604, 49.37085935047695, 51.08978809629168, 46.30424758366176, 41.162455558776855, 38.600505352020264, 33.19654737200056, 40.96936511993408, 37.28474930354527, 40.1481922694615, 38.45162630081177, 40.938393524714876, 44.998281547001426, 44.26396117891584, 44.83520385197231, 40.229156153542654, 41.82922206606184, 41.7104252406529, 42.861147676195415, 39.696347440992085, 39.36334807532174, 39.826320443834575, 44.989036968776155, 41.24113348552159, 43.45264087404524, 42.90526526314871, 46.80895778111049, 39.55109534944807, 38.60834639413016, 40.68920333044869, 41.59119415283203, 43.487117835453574, 40.57754577909197, 43.726049014500205, 46.23762478147234, 52.54026971544538, 48.408968108040945, 49.31833096912929, 55.38082184110369, 49.66820750917707, 51.843955993652344, 50.57378012793404, 51.3345696585519, 47.74181597573416, 52.265187059129985, 48.634916578020366, 47.10052851268223, 43.61933510644095, 40.16860607692173, 36.377293722970144, 37.40928881508963, 40.03545774732317, 41.80254445757185, 44.454949787684846, 41.01852362496512, 43.354521887642996, 47.19630248206002, 51.78191900253296, 52.21180404935564, 47.69871282577515, 54.39423322677612, 49.77926056725638, 44.53482975278582, 40.46880299704415, 39.908017362867085, 46.242002146584646, 53.05795914786202, 54.40360982077462, 56.276472432272776, 51.924933774130686, 54.512950147901265, 52.40587418419974, 51.2313437461853, 52.961723123277935, 54.02999823434012, 51.24508033479963, 55.213936533246724, 58.80198628561837, 59.22342232295445, 56.48966400963919, 54.55796752657209, 58.81930119650704, 63.376527377537315, 61.709849085126606, 59.67990507398333, 4.318834790161677, 0.038706531415560415, 41.77227463041033, 55.86437129974365, 40.832885129111155, 14.020145467349462, 35.227422441755024, 51.654916354588096, 41.46476820537022, 33.25899083273751, 36.73252385003226, 47.17021199635097, 33.70519024985177, 1.050334102341107, 0.07284583683524813, 0.10576274445546524, 0.04054684730778847, 0.04907742688166244, 0.0692813770313348, 0.0731450639931219, 0.021025065731789385, 0.07860948970275265, 0.051973258278199604, 0.09779047367296048, 0.0069468953796396294, 0.07545213055397783, 0.0069076506104985514, 0.2936423804078783, 0.13982463920755045, 0.24507604645831244, 0.24799724827919686, 16.69970175198146, 73.21988051278251, 51.74050426483154, 33.633724553244456, 27.468803337642125, 42.3883991922651, 38.95704868861607, 19.88319958959307, 44.07363264901297, 57.75801249912807, 62.98100117274693, 9.388124534061976, 0.5962907118456704, 39.73937068666731, 65.51516900743756, 64.56168855939592, 60.742444447108674, 60.12823758806501, 57.83209419250488, 63.48375197819301, 60.25830091748919, 65.29908003125871, 47.57745633806501, 54.08714369365147, 55.10139308656965, 58.54292964935303, 57.35331119809832, 60.34302030290876, 57.016063008989605, 56.25006232942854, 53.928234917776926, 54.317323616572786, 49.175976276397705, 44.78995370864868, 42.03481926236834, 46.084225927080425, 48.3307591847011, 56.04691784722464, 53.978862966809956, 55.111523560115266, 54.7118353843689, 52.32784243992397, 48.28950425556728, 46.44292320523943, 48.534980637686594, 46.72289391926357, 44.691007886614116, 44.683187689099995, 43.14940759113857, 44.57569210869925, 46.92706673485892, 49.23425776617867, 51.78995112010411, 52.550764969417024, 51.081245286124094, 50.7709561075483, 51.53944771630423, 50.91413763591221, 51.95878192356655, 52.56168406350272, 51.75579724993025, 49.8280473436628, 51.97739962169102, 46.07418925421578, 39.27586678096226, 40.79504523958479, 37.31584596633911, 42.32354818071638, 37.98457881382534, 39.67698628561837, 39.63737113135201, 40.66199765886579, 45.69308056150164, 43.938910552433555, 43.637563705444336, 40.86787625721523, 41.5655448777335, 41.870310238429475, 40.72936739240374, 39.392183099474224, 39.186492102486746, 40.544114521571565, 44.206638540540425, 43.01230573654175, 43.26433079583304, 43.789962019239155, 46.53166907174246, 39.862225260053364, 37.00032826832363, 39.86307988848005, 42.111437048230854, 44.86657496861049, 42.664802006312776, 41.33849859237671, 44.23251015799386, 52.961115155901226, 50.26705884933472, 52.09657859802246, 54.800647258758545, 51.86571775163923, 52.804763317108154, 51.03249325071062, 52.625670024326865, 49.791725635528564, 52.85773638316563, 51.57018654687064, 49.783280100141255, 46.70029490334647, 43.28927135467529, 39.405502796173096, 40.92296852384295, 44.400111130305696, 43.911513805389404, 46.76987416403634, 42.97975690024239, 46.10674156461443, 50.29430621010916, 53.581349577222554, 54.75205850601196, 50.70813396998814, 57.32031767708914, 52.77511535372053, 48.088204520089285, 43.20537533078875, 42.45993089675903, 48.90849494934082, 55.93645886012486, 57.417321477617534, 59.03116566794259, 54.502548694610596, 56.84494972229004, 56.23228188923427, 54.28906876700265, 54.76395034790039, 58.995875767299104, 55.00419473648071, 58.27711588995797, 61.12056541442871, 60.49519280024937, 58.46185111999512, 57.466149943215505, 60.719035966055735, 66.67285701206752, 64.23884746006557, 61.75145489828927, 3.0888499106679643, 0.13958734194082872, 49.94419343130929, 61.034755161830354, 43.80303852898734, 17.057646887642996, 35.63700485229492, 49.247372491019114, 50.33733640398298, 27.626155717032297, 50.726421628679546, 55.78265701021467, 48.16000025612967, 1.5109300783702304, 0.09618207426475626, 0.10130126135689871, 0.05541393293866089, 0.06497015551264797, 0.015605536988005042, 0.05391518139679517, 0.02378285935680781, 0.1733884960412979, 0.14259380847215652, 0.1585580411234072, 0.14526887850037642, 0.2903440488236291, 0.2358571711395468, 0.312721916607448, 0.3854807923947062, 0.21479404637856142, 0.30702374236924307, 19.343814407076152, 84.3794448035104, 59.34268120356968, 39.86913524355207, 27.76087086541312, 45.561429568699424, 48.76602561133248, 28.06375673839024, 49.860919271196636, 64.93700245448521, 69.00925827026367, 9.430974074772426, 0.6648791485599109, 49.4510624068124, 66.37415395464215, 67.80289813450405, 61.67538602011544, 64.06526756286621, 59.96410724094936, 64.91836738586426, 63.825603348868235, 66.60727991376604, 54.127029827662874, 55.031278814588276, 59.63809776306152, 61.883804185049875, 61.250559261866975, 62.96377658843994, 61.271250997270855, 58.90974589756557, 57.41179418563843, 57.45018993105207, 51.55319472721645, 46.91988229751587, 45.037462438855854, 48.1529096194676, 50.95776884896414, 55.957921845572336, 54.950061321258545, 57.98180702754429, 55.56595311846052, 54.662551811763215, 49.98221397399902, 49.33396094185965, 50.41904721941267, 47.968229975019185, 47.454108442579, 45.99453510556902, 45.30349506650652, 47.82088647569929, 50.4904260635376, 52.529850891658235, 55.18741178512573, 55.64736863545009, 53.51088094711304, 53.32804257529122, 55.32309620720999, 55.89197301864624, 52.54999371937343, 56.018572671072825, 54.57177012307303, 53.31461865561349, 54.02088219778878, 49.87138325827462, 40.71591567993164, 44.00132622037615, 41.81577035358974, 44.482099873679026, 39.71963432856968, 40.513149874550955, 39.28250578471592, 42.90321207046509, 45.708251953125, 45.65471955708095, 45.71089921678816, 43.34965467453003, 42.79787390572684, 44.428452832358225, 42.39396122523716, 41.47018085207258, 39.282568318503245, 41.35957942690168, 45.09393392290388, 43.76661259787423, 44.584297452654155, 43.485929693494526, 47.75995077405657, 39.460914679935996, 37.33501952035086, 39.86692224230085, 43.065862451280864, 44.93324293409075, 42.83463682447161, 43.608475072043284, 45.283081259046284, 54.099754674094065, 52.58678790501186, 53.51841974258423, 56.97328642436436, 52.015527861458914, 57.66772413253784, 55.29264920098441, 55.56984063557216, 51.667541231427876, 58.581936836242676, 54.27810103552682, 52.89465911047799, 50.14788334710257, 45.68501370293753, 41.317073822021484, 43.183610098702566, 46.350682394845144, 46.510223456791465, 49.31765004566738, 45.61479868207659, 48.57600280216762, 52.548458167484824, 55.97842597961426, 58.37772233145577, 54.89838409423828, 59.5423446382795, 56.21769414629255, 50.283213411058696, 46.30461931228638, 44.95779439381191, 52.719887597220286, 57.636623995644705, 60.344291823250906, 63.02050168173653, 58.024976185389924, 60.0732148034232, 60.30351284572056, 56.737464564187185, 55.92425087520054, 57.67919908251081, 54.85597923823765, 63.23158795492989, 64.25123609815324, 64.82685266222272, 62.707415853227886, 60.672934668404714, 64.37021705082485, 71.11208888462612, 67.06829289027623, 67.69461045946393, 7.66704705783299, 0.23787847267729895, 53.42845446722848, 67.68462589808873, 56.37141261781965, 22.63670120920454, 45.65167277199881, 65.92059639522007, 53.60851008551461, 42.59109551565987, 54.42788335255214, 62.686682428632466, 58.40661988939558, 3.085692822933197, 0.22589137804295334, 0.3267669943826539, 0.1977180883820568, 0.117558892550213, 0.1272949744015932, 0.2144839965871402, 0.1232321916946343], [0.05344123486429453, 0.1010538674890995, 0.13835415882723673, 0.0783000166660973, 0.11412036206041064, 0.07669984788766929, 0.335368348551648, 0.0869897228798696, 0.28951010214430944, 0.33579620559300694, 12.403621877942767, 58.98013114929199, 45.42013100215367, 38.494361196245464, 17.199315445763723, 38.5563599722726, 38.18000384739467, 20.587409939084733, 32.10952949523926, 61.98720727648054, 51.216398171016145, 33.45761203765869, 0.46860312351158684, 11.957897543907166, 65.99937507084438, 60.02611991337368, 61.039875984191895, 54.13090692247663, 55.843123708452495, 57.25209331512451, 54.70179871150425, 49.091632093702046, 48.71417120524815, 55.00630351475307, 52.48178325380598, 59.22847366333008, 53.30758013044085, 55.798662185668945, 50.58589778627668, 53.01695782797677, 49.05778741836548, 50.79345090048653, 46.00852877753121, 44.957697119031636, 40.39117077418736, 45.46482876368931, 48.39829567500523, 58.22217648369925, 50.44742018835885, 51.537464005606516, 55.58408791678292, 53.6976763180324, 49.838702406202046, 45.92089114870344, 46.68618311200823, 47.82750463485718, 45.6949531010219, 47.25416013172695, 45.556996617998394, 40.81179387228829, 42.49752412523542, 46.94861657278878, 49.813789640154155, 48.26267031260899, 48.843737738473074, 50.840111528124126, 49.684542724064414, 52.51769501822335, 48.9330290385655, 47.18744005475725, 49.08815452030727, 49.95268760408674, 49.09483173915318, 45.62230968475342, 42.44800083977835, 35.562242235456196, 32.32410029002598, 40.311787605285645, 38.571701594761436, 39.85307795660836, 41.566896302359446, 43.29646968841553, 40.92437553405762, 44.64735582896641, 41.69629955291748, 43.109785488673616, 39.471264021737234, 41.879058020455496, 43.571826798575266, 42.48707750865391, 42.49543271745954, 43.16762924194336, 41.221966879708425, 40.75390495572771, 43.91442510059902, 44.216164520808626, 43.189800943647114, 43.246765749795095, 37.92093331473214, 38.30216360092163, 39.267511572156636, 41.87398930958339, 41.51587220600673, 44.09278188432966, 44.04003463472639, 49.62559768131801, 46.386458669389995, 49.26863397870745, 52.64021955217634, 51.38194247654506, 50.471936907087056, 50.67655440739223, 49.626157011304585, 48.56370449066162, 49.09685713904244, 48.95558983939034, 47.15153176443917, 44.91341277531215, 39.00512327466692, 38.84500898633684, 43.44237143652779, 43.133968693869456, 44.54179532187325, 45.172743865421836, 40.81577519008091, 44.89190115247454, 46.85139390400478, 53.062138489314485, 49.2383120400565, 49.549563544137136, 51.03105844770159, 53.08520998273577, 47.27466426576887, 42.839872292109895, 40.35350111552647, 42.886598927634104, 50.44500568934849, 54.49691717965262, 53.82354293550764, 57.114327907562256, 52.72986173629761, 54.90265376227242, 54.958781310490195, 54.90265028817313, 55.51902845927647, 57.010045869009836, 60.349864278520855, 59.659032685416086, 57.227090222494944, 55.38255194255284, 56.24346154076712, 59.9523161479405, 57.57501779283796, 64.4391987664359, 38.0779104913984, 0.10696675734860556, 2.550359091588429, 51.16236203057425, 58.70716421944754, 38.215325014931814, 11.95699167251587, 36.295812198093955, 38.80686337607247, 41.28302070072719, 45.91059391839163, 36.33595541545323, 49.8571012360709, 45.56597369057791, 6.029364900929587, 0.09734745815928493, 0.11557056781436716, 0.04312892411170261, 0.06868092103728227, 0.02135521712313805, 0.04559284082746931, 0.08393615923289742, 0.0980884726824505, 0.060814542429787774, 0.09032807445951871, 0.012438780977390707, 0.07915459080998387, 0.05931677815637418, 0.30519017790045055, 0.022014700574800372, 0.2733985052577087, 0.2800318364586149, 16.189486844199045, 69.24312768663678, 51.17782177243914, 41.44418069294521, 17.167848791394913, 41.00436667033604, 55.521752153124126, 31.054341316223145, 35.82412331444876, 69.85800157274518, 55.86472913197109, 42.8289601462228, 0.26129330481801716, 10.411227669034686, 65.98739637647355, 65.36276721954346, 66.30367837633405, 58.09405517578125, 60.17956393105643, 59.675590242658345, 58.38324614933559, 53.46838576453072, 51.91745056424822, 56.88461698804583, 54.51109845297677, 60.700838633946006, 56.928751945495605, 57.47803136280605, 52.94904613494873, 56.01223938805716, 51.497320788247244, 52.8671372958592, 47.193332127162385, 46.031694071633474, 41.728761536734446, 46.165724822453086, 50.724232946123394, 57.45186792101179, 53.49849925722395, 52.34107181004116, 55.57499967302595, 55.452318804604666, 50.83808612823486, 47.32963841302054, 47.50785275868007, 50.67785372052874, 47.18854481833321, 48.71575886862618, 46.92256082807268, 43.25234167916434, 45.34013639177595, 49.35262032917568, 51.18453025817871, 49.19649430683681, 50.66486406326294, 52.195229121616904, 51.867048331669395, 54.6720187323434, 50.85901757649013, 48.231333936963765, 52.549583775656565, 49.30663020270211, 49.239844117845806, 45.280336720602854, 43.88848400115967, 39.04356418337141, 34.247973101479666, 42.23989881787981, 38.88067408970424, 41.14550542831421, 41.776565143040244, 44.457736015319824, 41.85729626246861, 43.05471059254238, 42.046770163944785, 42.95533398219517, 40.21497140611921, 40.995417390550884, 43.70940807887486, 41.54626015254429, 40.98017651694161, 43.706378664289204, 41.36029856545584, 41.56955051422119, 41.85282857077462, 44.466681821005686, 42.53134100777762, 43.56263085774013, 37.00048112869263, 38.49520192827497, 38.99502754211426, 42.77988849367414, 41.32366418838501, 42.73907477515084, 43.21537726266043, 47.930765288216726, 47.93414558683123, 51.16092722756522, 54.63016625813076, 52.427163464682444, 53.74387836456299, 51.36060455867222, 50.62542608806065, 50.39334583282471, 51.738763741084504, 52.434545925685335, 49.533860615321565, 46.606737409319194, 41.786726883479524, 41.90906729016985, 47.505434785570415, 45.27308974947248, 46.129854747227256, 48.08592203685215, 43.31126240321568, 46.74244615009853, 48.735950333731516, 54.15692445210048, 53.09522928510393, 52.369385719299316, 55.270206519535606, 56.39185421807425, 50.057271889277864, 48.01491839545113, 43.349727630615234, 45.39204290934971, 53.1374500138419, 56.007038661411826, 57.33286264964512, 58.67659214564732, 56.4857417515346, 58.5753846849714, 58.79578849247524, 57.2577908379691, 56.54887655803135, 58.09303379058838, 64.24334294455392, 63.10451929909842, 60.89310918535505, 59.10840879167829, 58.710006032671245, 64.70553711482457, 61.97753538404192, 65.42815671648297, 36.369671549115864, 0.09837421734950372, 3.2927613002913336, 58.1767943246024, 60.886251313345774, 44.24757385253906, 12.839260033198766, 25.503906624657766, 49.655294282095774, 55.74347959245954, 37.983237811497276, 39.29778139931815, 62.03437164851597, 57.00818722588675, 13.117091570581708, 0.16369180993310042, 0.10872054645525557, 0.07466410033937011, 0.015010989337627376, 0.053146638707923036, 0.0840565042038049, 0.10839735344052315, 0.21206701413861342, 0.2212129876549755, 0.3150570270206247, 0.15572434317852768, 0.1733128936695201, 0.20782744591789587, 0.4102255260305745, 0.1294265514505761, 0.380103239523513, 0.3704042328255517, 21.509915317807877, 81.25570842197963, 59.42050797598702, 52.41531331198556, 23.912215028490337, 54.43135050364903, 53.48830624989101, 34.83816351209368, 41.685342243739534, 74.29854665483747, 62.13633646283831, 45.50761924471174, 0.5951197232518877, 18.165551049368723, 70.06517601013184, 67.53602477482387, 68.08259786878313, 59.908723149980815, 62.63353565761021, 65.03233173915318, 58.73895917619978, 56.78789806365967, 52.776362555367605, 61.163873536246165, 57.49087858200073, 63.37567274911063, 59.52949047088623, 60.23674760546003, 55.15635681152344, 58.41812610626221, 54.20168127332415, 54.436818735940115, 50.07912744794573, 49.01834944316319, 43.93657595770699, 48.19558892931257, 53.93562780107771, 57.020138127463206, 53.039397035326274, 52.72836092540196, 57.988661425454275, 57.813796111515586, 53.18384313583374, 49.096106733594624, 50.97493437358311, 52.46853303909302, 50.659663336617605, 50.20005737032209, 50.184469086783274, 43.69242320741926, 47.58833026885986, 51.828590052468435, 57.34670346123831, 51.49429832186018, 53.01458849225725, 54.130924292973106, 54.00231313705444, 56.88568353652954, 54.17553520202637, 50.40152038846697, 56.04839086532593, 52.21287407193865, 52.31842415673392, 45.853201798030305, 44.830937658037456, 41.83722986493792, 35.233210291181294, 45.231751441955566, 40.9694241796221, 40.84497152056013, 42.50088357925415, 45.64743437085833, 43.080450194222585, 46.7788963999067, 43.67769650050572, 44.53670924050467, 41.63386651447841, 42.88336801528931, 45.28459249223982, 44.59769705363682, 43.940404415130615, 45.4808235168457, 43.441978863307405, 43.58987821851458, 44.0326486996242, 45.66787249701363, 42.68832860674177, 45.38315963745117, 38.59981748035976, 39.7479829788208, 41.3983781678336, 45.094135420663015, 41.8873541695731, 43.518391677311485, 43.51409074238369, 50.28768457685198, 50.8238388470241, 54.51172726494925, 56.68016971860613, 54.01054327828543, 56.08805118288313, 55.744389806474956, 53.852197306496755, 54.34761428833008, 52.19502762385777, 56.05081231253487, 52.581215449741904, 49.202601773398264, 43.57329286847796, 43.092550482068745, 50.760009220668245, 50.1271881375994, 50.26334851128714, 48.818724223545615, 46.62753684180123, 50.92627613885062, 50.76393495287214, 57.89908872331892, 55.7202204976763, 55.19859143665859, 56.27644463947841, 59.021320070539204, 53.04845748628889, 48.2200813293457, 45.50705991472517, 48.45405844279698, 56.235929693494526, 57.42467267172677, 59.49017756325858, 62.064943722316194, 59.08393723624093, 60.909687587193076, 60.40267058781215, 59.9038941519601, 59.764728682381765, 57.727683612278526, 66.1480804170881, 66.52739647456578, 65.54144014630998, 62.19370079040527, 62.944606508527485, 67.74415111541748, 65.26639570508684, 68.0120597566877, 46.680106912340435, 0.136035238259605, 2.6756880921976904, 63.880202293395996, 67.60657678331647, 53.22494173049927, 19.614596128463745, 43.31281532560076, 47.46366221564156, 55.528064591544016, 59.86575548989432, 51.73466082981655, 64.93431350163051, 67.64063685280937, 15.513757160731725, 0.3376116124647004, 0.31737981523786274, 0.19447258753435953, 0.23612663096615247, 0.12729334591754846, 0.17360033467411995, 0.1999593981142555], [0.06169269566557237, 0.018386853725782464, 0.07705616698201213, 0.09345738975597279, 0.08404988848737308, 0.04387226261730705, 0.1858841526721205, 0.02656368924570935, 0.29045166447758675, 0.14770708552428655, 18.31890995161874, 62.68418802533831, 40.751181261880056, 46.17205115727016, 27.903569493974956, 41.811768191201345, 20.32470028741019, 7.481466753142221, 26.204248564583914, 63.31293051583426, 46.73921871185303, 58.69223254067557, 11.25805674280439, 0.6211132055946759, 46.05933747972761, 64.65425940922329, 61.63157762799944, 56.94709518977574, 56.82954556601388, 56.951288427625386, 51.99241815294538, 46.39853116444179, 54.19587952750069, 54.148117610386436, 56.105661392211914, 53.772765500204905, 56.21157625743321, 53.37329271861485, 54.124208859034944, 53.785282679966514, 50.19729546138218, 46.148875440870015, 43.529421942574636, 41.13433967317854, 40.96327154976981, 48.73830229895455, 53.276681491306846, 54.19775206702096, 52.817791189466206, 49.52531433105469, 54.76169565745762, 53.569662707192556, 49.811753817967, 45.27487196241106, 46.976044586726594, 49.16222579138619, 46.61452633993966, 46.37228781836373, 48.827402523585725, 50.769580364227295, 47.88003649030413, 46.84675250734602, 45.44219500677926, 48.78648458208357, 49.48825263977051, 49.28363861356463, 51.5189505304609, 50.65287842069353, 48.11795670645577, 50.95762641089303, 49.96035146713257, 47.63407373428345, 47.89746952056885, 46.78862040383475, 36.47720534460885, 33.99359260286604, 35.34158134460449, 36.82523366383144, 37.612617424556184, 38.47636188779558, 41.67913055419922, 40.93119171687535, 37.72991691316877, 38.586998053959434, 41.377092361450195, 44.84729371752058, 45.38193328039986, 45.618731362479075, 43.21335186277117, 41.77047504697527, 46.75640508106777, 45.5532237461635, 47.54065520422799, 47.116516317640034, 41.61325815745762, 43.01105158669608, 41.45496082305908, 42.29751328059605, 37.07791532788958, 35.69302470343453, 38.855135985783164, 39.42462076459612, 39.32566104616438, 45.89754867553711, 43.77228232792446, 48.57501268386841, 48.09602471760341, 44.28645944595337, 52.81692961284092, 50.34013305391584, 51.36228254863194, 50.51703766414097, 51.025788239070344, 47.51771920067923, 48.38018519537789, 49.12384046827044, 43.695546422685894, 43.75780575616019, 43.86426258087158, 44.638406549181255, 45.311072077069966, 41.49469409670149, 45.074805532182964, 43.33451802389962, 42.74016216823033, 42.974743774959016, 49.42109830038888, 50.03675733293806, 49.77774585996355, 46.47693811144148, 51.99684068134853, 51.52732310976301, 51.25923381532942, 46.52732992172241, 42.11381333214896, 38.99065712520054, 45.7276999609811, 52.3733183997018, 56.12812491825649, 53.558514322553364, 57.25802707672119, 55.67876059668404, 55.90031780515398, 53.73046139308384, 54.190967151096885, 55.07607732500349, 60.65932314736502, 61.19444561004639, 55.89914008549282, 55.14506251471383, 55.90261765888759, 59.29471778869629, 61.16718782697405, 58.5194308417184, 17.430277041026525, 0.5642074048519135, 13.259015475000654, 61.367601667131694, 52.81814554759434, 29.84090096609933, 11.751784443855286, 43.88699361256191, 35.10954972675869, 35.22855152402605, 38.5976322719029, 30.651898179735454, 30.94366693496704, 58.61337743486677, 20.15419670513698, 0.22653085658592836, 0.046688257583550045, 0.021892080815242868, 0.056789347170186896, 0.005675071393073137, 0.03180665469595364, 0.0358166982685881, 0.03649697372955935, 0.06697903307420866, 0.06296390388160944, 0.08115400280803442, 0.025165389724341885, 0.07405956634985549, 0.07716255448758602, 0.030543819602046694, 0.21026532724499702, 0.09007154751036849, 23.264943429401942, 71.85854775565011, 49.45813914707729, 48.58655364172799, 25.94234142984663, 46.14472736631121, 34.86581039428711, 15.808095012392316, 29.56668336050851, 70.90111378261021, 52.81712416240147, 67.43353189740861, 15.6993522303445, 0.29033528215118815, 41.122760500226704, 68.6765159879412, 64.51083469390869, 60.97065108163016, 61.15528556278774, 62.00590487888881, 57.22939702442714, 51.050812176295686, 56.61522143227713, 58.677634375435964, 59.70619705745152, 56.434314659663606, 58.14769179480416, 56.746657030923025, 55.53062500272478, 56.13803652354649, 51.67116124289376, 49.83592660086495, 45.99919734682356, 43.20881468909127, 44.27365739004952, 50.06514419828142, 53.66031238010952, 55.70591763087681, 52.547961371285574, 50.53687824521746, 56.625608989170615, 55.84930065699986, 50.41054957253592, 46.92248787198748, 49.42675413404192, 50.159163747514995, 49.829364027295796, 49.73462533950806, 50.75650385447911, 50.550482818058555, 49.46163756506783, 49.212763513837544, 47.50586209978376, 49.854332378932405, 52.571585246494834, 51.46717950275966, 54.03569575718471, 52.19851909364973, 52.195309025900706, 52.78934179033552, 50.510850293295725, 49.80583395276751, 48.96848569597517, 46.98132174355643, 38.59283454077584, 35.93590940747942, 36.96927676882063, 37.163802010672434, 40.09191533497402, 39.266170569828574, 42.14723416737148, 40.55868836811611, 38.757173333849224, 38.741883822849815, 42.23900250026158, 44.79497030803135, 45.00878722327096, 46.80987841742379, 44.048605237688335, 42.169447558266775, 45.4419344493321, 47.19648313522339, 48.4272210257394, 48.2131643976484, 42.290193353380474, 43.88824428830828, 41.89627913066319, 39.95853771482195, 36.9933557510376, 37.10130296434675, 37.676290716443745, 40.8188601902553, 37.438801288604736, 42.90388951982771, 42.26403338568551, 47.434097630637034, 49.227108069828574, 48.16253982271467, 54.21128020967756, 52.04591580799648, 51.0315899848938, 50.32523611613682, 51.52261223111834, 50.54971851621355, 50.86716781343733, 50.78862885066441, 47.312149797167095, 47.09551886149815, 45.590493883405415, 50.10824040004185, 48.865228516714915, 42.379995346069336, 47.76422391619001, 47.004858766283306, 44.22935567583357, 46.15660183770316, 50.287232943943565, 53.6668575831822, 52.583240849631174, 48.97715704781668, 54.5524263381958, 54.83432865142822, 54.55685234069824, 49.64853368486677, 43.915852955409456, 43.59211206436157, 48.1972530228751, 55.0292603628976, 57.816582339150564, 58.17411231994629, 60.05776200975691, 57.937995161329, 58.29641451154436, 56.58515657697405, 58.57975510188511, 58.07307161603655, 60.73362718309675, 65.12627138410295, 60.21836962018694, 58.76154776981899, 59.66341005052839, 62.82466670445034, 63.26620388031006, 62.39904090336391, 16.198967661176408, 0.6221794283815792, 17.015141282762798, 69.84939275469098, 55.48061534336635, 38.53047445842198, 10.57774645941598, 40.19729518890381, 49.00069407054356, 44.54292093004499, 39.420344148363384, 32.84392976760864, 36.40487807137625, 68.2192689350673, 30.291067804609025, 0.35126088719282833, 0.05712027209145682, 0.010098997154273093, 0.11366319230624608, 0.03539198623704059, 0.06065001804381609, 0.030061703507921526, 0.13431948104075023, 0.11847776467246668, 0.20715592695134027, 0.13879611582628318, 0.13810523147029535, 0.10745832204286541, 0.32463631299989565, 0.07389633118041924, 0.28522010520100594, 0.18695896571235998, 26.536118847983225, 84.48188209533691, 56.55605752127511, 64.25889301300049, 36.089613982609336, 59.01992348262242, 29.358167920793804, 15.116660663059779, 39.26519782202584, 73.55772277287075, 57.13189990179879, 74.35589013780866, 15.266517673219953, 0.5281479912144798, 52.9037195614406, 68.53512709481376, 70.27754075186593, 63.519486563546316, 64.96073055267334, 63.211465971810476, 59.021396500723704, 51.164922441755024, 59.409981455121724, 60.89598573957171, 62.24483953203474, 57.76891074861799, 59.8630804334368, 58.06870814732143, 60.20815576825823, 59.87326649257115, 54.49741744995117, 52.694349493299214, 49.52227796827044, 45.2543956211635, 45.97297831944057, 52.035903453826904, 56.22561509268624, 56.56391245978219, 56.58731746673584, 51.26241956438337, 56.34389080320086, 56.13844299316406, 51.47273806163243, 48.8078989301409, 52.26946714946202, 53.126829692295615, 50.904260771615164, 50.00996855327061, 52.042851652417866, 54.12170055934361, 50.97346830368042, 51.91668973650251, 50.160424845559255, 51.9142404964992, 56.784378801073345, 51.821961471012656, 58.5815338407244, 56.22666079657418, 53.599939482552664, 54.94401638848441, 54.811976296561106, 51.080679007938926, 50.39548587799072, 48.46666247504098, 40.4775299344744, 40.206699575696675, 38.56524324417114, 41.86500876290457, 42.124391964503694, 39.529816491263254, 44.287560735430034, 41.67970725468227, 39.745895045144216, 39.923435415540425, 43.828187533787315, 46.339773723057334, 47.69591270174299, 50.97568130493164, 46.4142792565482, 42.87740993499756, 48.54003545216152, 48.56722027914864, 50.3618357522147, 51.49474300657, 42.33223690305437, 45.254833357674734, 43.255683762686594, 41.262877873011995, 37.134782859257285, 38.432629925864084, 39.734687600817, 43.45396450587681, 39.05477162769863, 43.19305270058768, 43.89485549926758, 51.054970673152376, 52.00817666734968, 50.39422825404576, 57.688151836395264, 52.65510606765747, 54.04764665876116, 54.91334356580462, 54.29722595214844, 52.530177456992014, 53.99814074380057, 55.69769443784441, 51.04576431001936, 51.186017172677175, 49.11052424567086, 51.33235318320138, 52.042274951934814, 45.53628403799874, 51.944586753845215, 48.360372407095774, 47.299417223249165, 49.855774130140034, 53.64484221594674, 55.24649231774466, 55.42369222640991, 51.59735747746059, 57.83110407420567, 58.05213321958269, 56.81780311039516, 51.98037345068795, 47.489356654030935, 45.78116634913853, 52.073823247637065, 59.70460591997419, 62.42723669324602, 60.291596685137065, 63.56155095781599, 60.94743020193917, 60.910681179591585, 57.249515533447266, 60.75059468405587, 60.060958181108745, 63.8954188483102, 67.90987954820905, 64.53199195861816, 63.367480822971885, 62.81928185054234, 68.42399760654995, 65.72924300602504, 64.64484460013253, 24.779244252613612, 0.6381924748420715, 16.4640223298754, 74.7904304776873, 64.2708717073713, 45.762503487723215, 20.361034154891968, 52.97548055648804, 43.32602037702288, 44.71026829310826, 53.37375129972185, 41.672679151807515, 46.74084806442261, 75.34468827928815, 41.53747762952532, 0.274782336716141, 0.1549215955393655, 0.1548705425645624, 0.14598876344306128, 0.19775449857115746, 0.2073415605617421, 0.07398813696844236], [0.029171787867588655, 0.0038419878359750976, 0.023107528719784956, 0.1454795907650675, 0.07078122440725565, 0.046133331289248805, 0.162541679505791, 0.014801842792491828, 0.14463885873556137, 0.17096008706305707, 15.7652975831713, 58.8117276600429, 40.036722319466726, 45.42092309679304, 26.26785237448556, 36.542323861803325, 30.677853175571986, 10.959460513932363, 19.143237284251622, 58.079523018428254, 53.639943735940115, 50.40820802961077, 47.39896059036255, 1.463085977094514, 7.611490998949323, 59.31586810520717, 58.501629556928364, 62.40225791931152, 53.66597168786185, 58.133427143096924, 48.5493460382734, 53.50219917297363, 54.270263467516216, 56.7040228843689, 53.77346379416329, 54.57270465578352, 52.932801246643066, 54.12948948996407, 50.870357036590576, 51.38894626072475, 49.280550139290945, 47.30025448117937, 40.939199515751426, 44.02884456089565, 43.99908195223127, 47.74156584058489, 52.6015111378261, 53.3428179195949, 51.599587849208284, 48.70580904824393, 53.25974178314209, 53.275660106113975, 51.15927355630057, 46.309444836207796, 45.47681788035801, 47.1556589944022, 49.214219161442344, 45.64364760262625, 47.00714472361973, 51.4887501852853, 48.122222900390625, 48.13411474227905, 49.53947475978306, 49.10815143585205, 50.06592239652361, 49.14548758098057, 50.37021180561611, 51.596982274736675, 50.52233566556658, 49.453056539808, 49.50871161052159, 49.158911500658306, 45.03149741036551, 41.83150107519967, 32.84343991960798, 42.93295383453369, 38.11194971629551, 34.19592414583479, 37.946964740753174, 37.39246027810233, 34.49803876876831, 33.541316986083984, 37.83797877175467, 37.407252992902485, 43.86489486694336, 46.893201214926584, 47.26984569004604, 50.61795677457537, 46.44073799678257, 44.11631195885794, 50.91682311466762, 47.659573623112266, 47.826309544699534, 47.438301290784565, 43.80652305058071, 43.84685386930193, 43.25027806418282, 38.39476571764265, 37.87459577832903, 36.897046770368306, 39.15549966267177, 40.49011312212263, 38.77603074482509, 40.381974833352224, 41.98454557146345, 44.54187175205776, 47.442098481314524, 45.05808469227382, 46.539569173540386, 51.28822864804949, 51.202995095934185, 51.01286458969116, 49.941893577575684, 51.05992473874773, 50.11637674059187, 47.41635193143572, 45.30949483598982, 44.977315357753206, 45.49684953689575, 46.56057357788086, 42.29541492462158, 40.26592254638672, 45.56161022186279, 44.03227349690029, 40.69588054929461, 42.13554382324219, 48.45377704075405, 50.99374662126814, 50.994806221553254, 46.63280010223389, 48.35941702978951, 54.08362443106515, 51.58962413242885, 50.17090967723301, 44.72994906561715, 40.55148308617728, 40.56832551956177, 44.77562652315412, 50.92362540108817, 53.18891184670584, 54.926788330078125, 54.247462953839985, 57.55607352937971, 56.09355068206787, 58.07752888543265, 56.441825662340435, 57.91411420277187, 57.075918265751426, 59.07402910505022, 54.02053131375994, 58.853965759277344, 58.19398069381714, 61.81624685014997, 46.26617840358189, 1.8228976811681474, 0.1492626541959388, 28.06123627935137, 61.79663208552769, 51.05950437273298, 29.86829423904419, 14.739270993641444, 26.989745889391216, 17.68755841255188, 39.79258346557617, 28.9864045551845, 26.335991621017456, 61.830664362226216, 50.19393253326416, 35.46284130641392, 1.0356147778885705, 0.014845133326681597, 0.08530812989920378, 0.055244974326342344, 0.09125614073127508, 0.029007606141801392, 0.03512467397376895, 0.08774502056517772, 0.007327129864799125, 0.013338834779070956, 0.11047438984470707, 0.015234422437580568, 0.018025043586801206, 0.18674112882997307, 0.09536708585385766, 0.08093116512256009, 0.13963488010423525, 19.669212443487986, 70.91724055153983, 44.772857666015625, 49.46789789199829, 29.377077443259104, 45.2138910974775, 33.2779073034014, 21.463489191872732, 27.067918334688457, 63.11899239676339, 64.10745007651192, 53.64851433890206, 58.47169671739851, 2.4763017169066837, 4.3150840657097955, 58.895050457545686, 62.6008026940482, 65.46412059238979, 59.41432407924107, 60.099374771118164, 52.484326294490266, 55.36624104636056, 55.3032625743321, 60.164521081107004, 55.907325063432964, 55.74353517804827, 53.85172135489327, 56.50877850396292, 52.96552031380789, 53.819502558027, 51.96608100618635, 48.82343857628958, 42.5450393812997, 46.69347524642944, 45.140014375959126, 49.03702620097569, 53.51168346405029, 55.013498374394004, 53.0790365082877, 51.191735540117534, 54.6069974899292, 55.12647955758231, 51.166961738041465, 47.17484297071184, 46.62242644173758, 49.3269293648856, 50.15184382029942, 46.02684422901699, 47.41885328292847, 52.315453801836284, 50.012150287628174, 49.55565711430141, 51.385552065713064, 52.114591802869526, 52.10091774804251, 51.74642760413033, 54.10555641991751, 52.44466945103237, 51.87491021837507, 51.68158006668091, 51.56655958720616, 48.11710555212838, 43.154788970947266, 40.944577421460835, 34.40655531202044, 42.4745638029916, 38.02510418210711, 34.86665807451521, 39.29022870744978, 38.50369610105242, 36.33252647944859, 34.909625734601704, 36.08354820523943, 38.691359996795654, 44.41160345077515, 46.944068976810996, 47.869933809552876, 48.34488139833723, 46.010495117732454, 43.97133084705898, 50.19882753917149, 48.517710890088765, 49.47653450284685, 48.051941871643066, 44.072899614061626, 43.553973402295796, 43.28056526184082, 39.42711169379098, 38.14263296127319, 37.55374533789498, 38.14121205466134, 39.3116569519043, 38.207237311771934, 40.54349960599627, 39.91613285882132, 45.40986851283482, 47.884160246167866, 48.2827228137425, 48.419515473502024, 51.5406289100647, 52.7343294279916, 51.15061262675694, 51.30525868279593, 52.81620005198887, 51.827106612069265, 50.92184666224888, 49.81634310313633, 47.15785462515694, 49.80636201586042, 48.998786790030344, 44.5565185546875, 44.286018235342844, 48.355835233415874, 47.09576552254813, 43.17830514907837, 44.10015392303467, 50.86662585394723, 52.67530795506069, 53.53426510947091, 49.867023263658794, 52.05645969935826, 57.26050410951887, 55.22716590336391, 51.40897444316319, 49.05717945098877, 44.34658915655953, 43.206223011016846, 46.237503187997, 52.08291843959263, 55.2428479875837, 56.421898228781565, 56.81452356066023, 60.31541510990688, 56.67221055712019, 60.365122522626606, 60.6700998033796, 60.14751189095633, 60.34787014552525, 60.62771579197475, 56.95766339983259, 59.90136500767299, 60.45563670567104, 65.47254180908203, 41.92143855776106, 0.8787513779742377, 0.10878195387444325, 34.79544946125576, 66.54384286063058, 55.94316039766584, 36.144873006003245, 16.854118517466954, 29.714655671800884, 17.755683762686594, 49.736133098602295, 35.18927335739136, 29.96931062425886, 78.77540302276611, 51.37298277446202, 55.54527875355312, 1.8927490072590964, 0.022589765788455094, 0.058550813900572915, 0.02748408298274236, 0.007449652084947697, 0.07056509064776556, 0.038730459952993054, 0.18841998731451376, 0.1269847617617675, 0.12816537198211464, 0.19451598663415226, 0.11471436518643584, 0.1150312681815454, 0.39503353408404757, 0.16092946673078196, 0.23444652397717747, 0.18748165480792522, 24.03655477932521, 82.18851797921317, 54.05305930546352, 62.30369772229876, 36.10880143301827, 53.277977330344065, 43.05802140917097, 16.424864019666398, 34.07133599690029, 66.86228575025285, 65.94796534946987, 61.39718014853341, 64.42446858542306, 1.801572791167668, 8.732165081160408, 70.00045354025704, 64.70177119118827, 70.85580457959855, 60.242007391793386, 64.33485766819545, 55.166379587990896, 58.60385145459856, 57.236994879586355, 63.392452648707796, 59.817277908325195, 59.9407890864781, 56.625754901341026, 58.25650405883789, 54.64844696862357, 55.408524308885845, 55.46212271281651, 52.99409825461251, 44.66040454592024, 48.89755848475865, 47.46920687811715, 52.060197830200195, 55.0631536756243, 58.32111535753523, 54.2362311908177, 50.356471742902485, 54.79910475867135, 55.634875774383545, 53.031681060791016, 50.134337833949495, 49.00365400314331, 50.257522446768625, 52.50429194314139, 49.781862667628694, 50.286979334695, 55.61608784539359, 51.3527044568743, 52.54954208646502, 53.952081135341096, 53.260422706604004, 55.289793491363525, 54.61433826174055, 55.213457107543945, 54.90220560346331, 52.85211181640625, 56.73347977229527, 53.9799017224993, 51.90790721348354, 46.88182701383318, 43.73808329445975, 36.20258126940046, 43.92900936944144, 37.98146602085659, 37.88970463616507, 41.12563705444336, 41.07763889857701, 38.77454730442592, 35.82412331444876, 39.51785169328962, 38.277205671582905, 47.68224906921387, 49.20244543892996, 49.391419070107595, 50.64420012065342, 49.321214471544536, 45.1779967035566, 52.720495564596995, 50.59091785975865, 51.24522277287075, 48.84472785677229, 46.26111664090838, 44.36558553150722, 46.2533346584865, 42.35892145974295, 40.801962171282085, 40.16033772059849, 40.986002581460134, 41.978820255824495, 40.376617772238596, 39.67125749588013, 40.43191501072475, 45.667351382119314, 50.52388163975307, 50.03178937094552, 53.554929052080425, 56.09728186471121, 54.8606310571943, 54.128961426871165, 54.7444953918457, 56.26094668252127, 55.688376903533936, 52.90588392530169, 53.62087440490723, 49.81694412231445, 51.23260831832886, 52.99646064213344, 48.44011688232422, 45.63789449419294, 52.176712172372, 49.73483725956508, 45.79957560130528, 46.68490464346749, 53.84912272862026, 55.24779857907976, 56.5667507989066, 52.8928873198373, 57.98330783843994, 59.93070030212402, 58.539858545575825, 56.01239224842617, 51.207136222294395, 47.23784228733608, 46.470580509730745, 51.60362475258963, 55.85416439601353, 58.602336747305735, 59.52986567361014, 60.92248616899763, 65.33141694750104, 60.133288928440635, 64.14663791656494, 64.22187995910645, 63.520368984767366, 65.0227849142892, 67.33678518022809, 62.22846957615444, 65.27141230446952, 65.98973097120012, 68.73325497763497, 54.440171241760254, 3.5991286550249373, 0.36544710025191307, 36.46032469613211, 72.78096975599016, 62.1841470173427, 41.30303498676845, 26.935925143105642, 34.44410685130528, 24.206577198846, 52.37665006092617, 45.81028972353254, 33.38518401554653, 72.71578870500836, 63.55397047315325, 61.92092146192278, 2.6134991092341284, 0.19058488043291227, 0.12918409731771263, 0.1702732060636793, 0.16468693582074984, 0.13801421278289386, 0.12133323002074446], [0.03369500408215182, 0.05474840882899506, 0.0510766319265323, 0.09087246989033052, 0.0694690869588937, 0.05187821248546243, 0.060740887453513484, 0.13893980240183218, 0.1531219171094043, 0.1824270167521068, 22.41860941478184, 63.41901561192104, 42.26143823351179, 39.8236870765686, 27.877824681145803, 39.0302722794669, 37.158226081303184, 18.495713812964304, 7.079190373420715, 47.93901974814278, 58.523710932050435, 50.70059517451695, 53.36055319649832, 24.290157079696655, 0.6493818429963929, 26.162238018853323, 57.12450701849801, 61.38768890925816, 55.92836420876639, 58.15023830958775, 52.36544261659895, 56.682275022779194, 53.637438910348074, 59.12766224997384, 53.6154339654105, 54.72809416907174, 50.02923938206264, 53.992134026118684, 51.79023947034563, 52.705650738307405, 46.388918331691194, 44.22360951559884, 40.138113907405305, 42.428125517708914, 42.868057659694124, 52.25881903512137, 53.31003631864275, 55.72967004776001, 50.21383564812796, 55.49727712358747, 54.338623319353374, 56.97887972423008, 50.91057668413435, 44.860231263296946, 44.03372914450509, 45.88130726133074, 49.409810951777864, 46.74958542415074, 44.815022809164866, 47.40992832183838, 50.24481766564505, 49.16088131495884, 48.49404532568795, 49.8862315586635, 51.50584970201765, 48.49055732999529, 47.67847619737898, 48.62368481499808, 44.737185614449636, 45.557083470480784, 45.93347086225237, 44.062616280147004, 44.843774454934255, 38.921963759831016, 30.000504561832972, 40.479353836604524, 39.56133352007185, 45.11693246023995, 37.33097914287022, 33.90086194447109, 36.57520273753575, 39.67256375721523, 37.201131207602366, 40.078234331948416, 45.49334069660732, 47.43910033362252, 50.35651690619332, 51.92410346439907, 49.45530080795288, 42.84106738226754, 54.112042563302175, 53.87775278091431, 52.62420048032488, 49.90408148084368, 48.41670492717198, 45.0564866065979, 39.80930430548531, 38.542460100991384, 37.86549711227417, 39.73455558504377, 40.319222177777974, 39.86055074419294, 37.68482657841274, 44.28729322978428, 46.77944530759539, 42.17758042471749, 45.33067294529506, 49.56437710353306, 47.56135041373116, 45.619922978537424, 47.80586099624634, 48.951125621795654, 48.58492428915841, 48.100200584956575, 48.39732640130179, 47.72754784992763, 46.9534455708095, 44.96367951801845, 48.925768171037944, 44.19550405229841, 41.63451617104666, 42.11503274100167, 45.3543940952846, 44.41389288221087, 40.72678961072649, 41.68064178739275, 47.35820593152727, 49.79337583269392, 50.55178213119507, 44.73156452178955, 47.516454628535676, 52.22814621244158, 50.9727908543178, 50.91298076084682, 47.84402397700718, 41.71804741450718, 39.26518045152937, 39.50794356209891, 44.55217940466744, 46.99594422749111, 51.15055704116821, 52.5367956161499, 55.22129814965384, 54.19091156550816, 56.11445781162807, 52.965513365609304, 58.34482261112758, 58.573995045253206, 57.97415706089565, 56.556005409785676, 55.76117665427071, 56.06997544424874, 59.813720430646626, 13.28533090863909, 0.059593179396220615, 0.0922054722905159, 31.741413933890207, 58.52116789136614, 51.08028643471854, 28.75456574984959, 10.932549272264753, 49.40859849112374, 81.98136438642229, 27.688427209854126, 38.63256434031895, 29.725269045148575, 53.3956207547869, 47.039860316685264, 62.64793232509068, 8.440580453191485, 0.9327791588647025, 0.18400641557361397, 0.0242517609814448, 0.016288964244137918, 0.031758980825543404, 0.05543111005265798, 0.06382557550179106, 0.040615494695625136, 0.07052067374544484, 0.026445415502946292, 0.11440370471349784, 0.06031824156109776, 0.0880632127768227, 0.04788002631227885, 0.3499527531010764, 0.26064978220633095, 27.80092028209141, 79.39507811410087, 44.99893467766898, 49.71897104808262, 32.89825425829206, 47.800865241459434, 34.27519614355904, 20.942841563905986, 21.832695620400564, 44.33782747813633, 71.43033722468785, 53.960022926330566, 64.45567294529506, 30.640180042811803, 0.29771508329680985, 21.388641459601267, 58.03227526800973, 65.23008441925049, 61.638887132917134, 59.79309122903006, 56.73590816770281, 56.90793514251709, 56.743919440678184, 60.58802768162319, 56.21206610543387, 57.373228209359304, 54.91198171888079, 55.97969055175781, 55.77916554042271, 53.58390998840332, 48.294180393218994, 43.98446989059448, 42.073618003300254, 43.882744789123535, 44.825698716299875, 53.95966509410313, 55.264581952776226, 57.994390215192524, 51.72289752960205, 54.43211133139474, 58.29857540130615, 57.83846569061279, 50.57563877105713, 44.98826224463326, 45.5468487739563, 46.33425685337612, 51.45841087613787, 49.10655682427542, 45.68156739643642, 48.05041674205235, 52.78538826533726, 50.777212960379465, 49.06584732873099, 50.947447299957275, 53.17629739216396, 50.34070975439889, 49.26352705274309, 50.346153667994905, 46.56995364597866, 48.02694572721209, 45.72938142504011, 44.80258900778634, 46.38987718309675, 41.48802382605416, 31.861298152378627, 42.67086083548409, 41.02160515104021, 46.557009152003694, 40.05358559744698, 36.623874868665425, 38.72817155293056, 40.28652742930821, 38.712746552058626, 40.194300515311106, 44.47424840927124, 48.969100611550466, 49.098139081682476, 51.42264154979161, 49.216723987034385, 43.438136509486604, 53.878840173993794, 54.1071822983878, 52.92958770479475, 50.50835589000157, 49.14882966450283, 44.42247043337141, 42.31964676720755, 40.512215341840474, 38.65980127879551, 40.01496403557913, 40.48826142719814, 39.18078415734427, 34.413044929504395, 42.877611432756694, 44.29521417617798, 40.08738163539341, 45.59317936216082, 50.4881192616054, 51.462319237845286, 48.16919272286551, 50.647444929395405, 49.6475122996739, 49.73394789014544, 50.472065448760986, 51.66070767811367, 48.645995480673655, 48.71368483134678, 48.815055574689595, 51.341295514787944, 46.852057456970215, 45.243556431361604, 45.160174574170796, 47.71967206682478, 47.07408019474575, 44.9892384665353, 43.98148216520037, 49.49458939688546, 51.831497873578755, 53.8378701210022, 49.19914851869856, 49.94858469281878, 54.925905908857075, 55.759060927799766, 54.32310104370117, 52.948525020054404, 44.25381680897304, 43.34499938147408, 42.82674714497158, 47.86658130373274, 48.132864066532676, 52.28221361977713, 55.408308914729524, 57.143965448652, 56.47555916649954, 58.31235367911202, 55.52751220975603, 58.980534144810264, 60.19994299752371, 60.06808703286307, 60.46544756208147, 59.49140739440918, 60.332229750497, 61.043273653302876, 10.970107759748187, 0.05527610890567303, 0.29970183383141247, 39.97897931507656, 60.437599182128906, 59.814317975725444, 32.38563353674752, 15.32657095364162, 50.920366695949006, 57.91460057667324, 35.89490461349487, 48.48399823052542, 25.905745267868042, 64.18239334651402, 52.04892437798636, 70.78733008248466, 13.541322520801, 0.9322052810873304, 0.281419114874942, 0.07683949717985732, 0.029548734426498413, 0.04002641434116023, 0.034720972779073885, 0.1499319611383336, 0.2533642702869007, 0.16172694893819944, 0.13960815939520085, 0.25279905061636654, 0.19529039865093573, 0.16045941838196345, 0.17871562018990517, 0.43460333506975857, 0.43149865737983156, 32.07809237071446, 85.54459517342704, 57.04515511648995, 58.221683161599294, 37.53229972294399, 52.79472664424351, 51.991799763270784, 26.52672140938895, 17.48346723828997, 60.128043038504465, 69.68185779026577, 63.586321285792756, 68.1097583770752, 32.628591196877615, 0.5416268450873238, 35.71659299305507, 58.902860232761924, 70.49470669882638, 60.859000478472026, 63.817883900233674, 58.02871779033116, 62.107452801295686, 59.54538100106375, 66.13772760118756, 59.97356373923165, 61.80934728894915, 54.98765802383423, 60.25224208831787, 56.75150687353951, 57.681908879961284, 50.36084910801479, 47.584744998386924, 43.54897764750889, 46.315972668784006, 45.15960134778704, 56.69001184191023, 56.36239038194929, 59.38151468549456, 51.74413469859532, 55.83440024512154, 59.02456487928118, 60.489425795418875, 53.336133752550396, 49.69727182388306, 46.30800308500017, 48.82442174639021, 53.540497643607004, 50.39600004468645, 48.23340450014387, 51.63721581867763, 53.6082113129752, 52.167335578373496, 51.68835456030709, 54.613132749285015, 56.20503452845982, 51.66363981791905, 51.065115043095176, 53.318408897944856, 48.133628368377686, 50.705542291913716, 48.60336480821882, 46.15067849840437, 45.59013605117798, 43.11562197549002, 36.12243379865374, 47.367040566035676, 47.14426047461373, 47.73529161725725, 42.67583227157593, 39.83269541604178, 40.57056283950806, 42.219801153455464, 39.92129189627511, 43.049631459372385, 47.99261467797415, 51.44397599356515, 52.96744149071829, 54.31453044073922, 51.199600900922505, 43.69049160821097, 58.96131542750767, 56.287593024117605, 56.6741178376334, 51.842663628714426, 50.62575265339443, 45.82682991027832, 43.667635508946006, 41.665473869868684, 39.835050855364116, 42.72441407612392, 41.66224990572248, 41.47472149985177, 35.48239353724888, 42.48182814461844, 45.346177850450786, 42.077394349234446, 45.79347160884312, 51.32740606580462, 50.49999025889805, 51.37646034785679, 54.31254325594221, 52.604036808013916, 51.93827778952462, 51.783732482365195, 53.61425624574934, 53.561026096343994, 52.155648708343506, 53.3588856288365, 54.445385864802766, 48.4962409564427, 49.581678118024556, 47.96061474936349, 50.497874532427105, 50.23270000730242, 46.54155288423811, 47.093507358006065, 51.564989294324604, 54.56549589974539, 57.392214162009104, 51.378409317561555, 52.65190642220633, 58.41792460850307, 59.61040224347796, 57.1963027545384, 56.36139331545149, 46.19460153579712, 46.57658570153372, 44.0411011832101, 50.48637873785836, 51.805223260607036, 55.519521781376426, 57.468036379132954, 60.93495123726981, 60.13191318511963, 60.815351894923616, 57.770380292619976, 63.36389555249895, 64.12090178898403, 64.88802460261753, 64.75033909933907, 64.1096943446568, 64.20257091522217, 68.50106007712228, 17.107159750802175, 0.10312387427049023, 0.32698692115289824, 42.381784507206504, 71.05443968091691, 63.82543659210205, 41.000597272600444, 21.1684148311615, 58.27374601364136, 93.62280014583042, 38.600797176361084, 49.8744022505624, 39.32799564089094, 61.12354619162423, 59.26140117645264, 82.05497360229492, 16.285669020244054, 1.404732074056353, 0.36562930047512054, 0.19669336479689392, 0.104742336353021, 0.12705864065459796, 0.13444874196180276], [0.029335399623960257, 0.1245600168726274, 0.06815829979521887, 0.20134048829121248, 0.13880078414721148, 0.07863691608820643, 0.012193327719744827, 0.1821839247963258, 0.39617491140961647, 0.5157258063554764, 28.764418295451573, 74.84857300349644, 38.73969514029366, 44.44551413399832, 22.249295711517334, 40.918962887355256, 23.904047421046666, 60.08715288979666, 5.116471486432212, 9.653243473597936, 42.22087117603847, 59.85658386775425, 41.95010335104806, 49.85795586449759, 4.089494296482631, 1.6570294158799308, 34.73095975603376, 50.66810539790562, 58.49296515328543, 56.56683417728969, 58.16086557933262, 51.20381498336792, 57.146817684173584, 57.61258322851998, 59.407709394182476, 57.293101583208355, 54.21241624014718, 54.47413403647286, 55.21993977682931, 51.973338399614605, 45.65435477665493, 39.47490835189819, 41.93188170024327, 46.65197713034493, 51.79067373275757, 48.15235376358032, 55.47643600191389, 58.88512148175921, 58.27707420076643, 55.5765734400068, 55.58624185834612, 53.18945728029524, 51.30480704988752, 42.58754498617989, 43.939091205596924, 46.813752038138254, 45.422309262411936, 46.940115451812744, 55.96495689664568, 50.68120622634888, 50.571219716753276, 53.6570918900626, 50.82288694381714, 50.540279388427734, 47.94885492324829, 48.320917061397004, 44.53813362121582, 40.90360736846924, 47.075431619371685, 52.222361837114605, 49.23997265951974, 47.077352796282085, 30.164332662309917, 21.940168619155884, 20.233989817755564, 30.74581003189087, 45.848306792122976, 33.81992237908499, 47.84741817201887, 36.082137720925466, 37.600211415972026, 38.28149618421282, 39.57310029438564, 39.55879395348685, 45.77999210357666, 48.9185767854963, 49.075157914842876, 55.648244108472554, 44.856465339660645, 40.18042843682425, 49.66293382644653, 52.40698937007359, 51.67609446389334, 49.86121456963675, 47.90215608051845, 42.39375972747803, 38.33188452039446, 38.07534313201904, 39.186551162174766, 39.575959478105815, 44.5572898047311, 54.35880088806152, 63.15999371664864, 61.50118773324149, 52.55323505401611, 35.85817296164376, 34.81715215955462, 38.96817970275879, 46.24168252944946, 44.12904800687517, 39.98919664110456, 44.46058130264282, 46.489507402692524, 46.68732261657715, 49.51134497778756, 45.611675466809956, 46.622224943978445, 45.254895891462056, 45.73895951679775, 46.22840452194214, 46.14472041811262, 41.94578504562378, 42.45914575031826, 43.078230244772776, 41.0614287512643, 41.57478945595877, 50.03110497338431, 51.5718297958374, 52.11530746732439, 45.43368346350533, 43.85561554772513, 49.58470058441162, 64.08063002995083, 68.48100062779018, 46.929575034550254, 48.21961580004011, 39.67147636413574, 40.38284683227539, 40.06308031082153, 41.65863684245518, 43.368981088910786, 49.84577219826834, 52.99538367135184, 55.5727345602853, 52.07723133904593, 55.024931635175435, 54.318327631269185, 57.88715519223894, 59.07505049024309, 58.39189665658133, 55.32256119591849, 57.42319965362549, 27.77328555924552, 0.8812095203569957, 0.16267411597073078, 2.5463482439517975, 50.4839677129473, 58.98099272591727, 44.991472312382285, 15.837465047836304, 11.39812113557543, 49.580948557172505, 79.58654267447335, 28.02568929536002, 34.90312222072056, 37.25239154270717, 32.78269876752581, 45.60204873766218, 54.65039941242763, 10.580989531108312, 0.41813892711486134, 0.02842535524229918, 0.03555448180330651, 0.0703028165070074, 0.06944221018680505, 0.16137031093239784, 0.123106432014278, 0.032324383700532575, 0.04885272661756192, 0.15064008028379508, 0.033837642321097, 0.03594333665179355, 0.11446649634412356, 0.05578398558178118, 0.5943879910877773, 0.314720690782581, 33.773136683872764, 82.88169111524309, 45.165267603737966, 53.665961265563965, 31.334054946899414, 46.83534703935896, 33.39760044642857, 40.15407739366804, 9.195074915885925, 12.81192147731781, 41.75428921835763, 66.63649014064244, 45.55810138157436, 61.2893510546003, 6.703090029103415, 0.7813906680260385, 29.418495655059814, 51.28970514025007, 61.61370686122349, 61.4247019631522, 60.528648376464844, 54.08236680712019, 57.80107395989554, 58.78982693808419, 61.4536828994751, 57.999431133270264, 58.92019598824637, 55.06349761145455, 56.56430503300258, 53.45199843815395, 47.914238997868125, 44.39965254919869, 44.836398942129954, 49.085816451481406, 51.64660978317261, 51.657153674534385, 57.75737673895699, 58.950239998953684, 57.67949438095093, 57.51106309890747, 57.37444414411272, 54.264183793749126, 53.525465215955464, 45.92613703863961, 44.737904753003804, 49.075105803353445, 46.074064186641145, 48.0767365183149, 54.62745993477957, 52.68303435189383, 52.315293993268696, 54.22145932061331, 52.58490146909441, 51.95596790313721, 49.24576398304531, 49.0622238431658, 47.69698967252459, 43.67090116228376, 47.47665534700666, 51.983663422720774, 51.20260599681309, 46.225409848349436, 31.60964482171195, 25.71726495879037, 32.973002978733604, 42.04083987644741, 56.176758834293906, 36.44247129985264, 46.559017181396484, 38.87145035607474, 39.99760743549892, 37.769942011152, 41.1976968220302, 39.51826163700649, 44.22943558011736, 48.05402980531965, 52.218366622924805, 54.85952281951904, 47.10473217282976, 39.52775982448033, 48.97553811754499, 52.731967040470664, 53.772900990077424, 50.06302152361189, 47.968177863529746, 43.71035303388323, 39.5942645072937, 41.738930225372314, 43.202311175210134, 39.44070584433419, 42.58204548699515, 45.112221581595286, 54.26915175574166, 64.02029187338692, 60.50666427612305, 44.07695041384016, 37.842356136866975, 39.726728439331055, 44.46836675916399, 45.90097066334316, 44.609825134277344, 46.191328934260774, 47.33577367237636, 47.88968753814697, 50.94614798682076, 48.090646811894004, 47.65081541878836, 47.78787905829293, 47.751147406441824, 48.03968524932861, 49.88045065743582, 46.14702722004482, 45.42198964527675, 46.562532969883506, 43.81863376072475, 43.84290034430367, 50.16275944028582, 53.40071031025478, 54.48843342917306, 49.23820434297834, 46.741403920309885, 52.60707664489746, 62.54963615962437, 63.36152621677944, 54.381663935525076, 51.793234143938335, 44.17877973828997, 41.419177600315635, 42.75007724761963, 44.05797140938895, 46.24439580099923, 53.83607748576573, 55.42209414073399, 57.560346671513145, 56.36901548930577, 57.31138924189976, 53.681302888052805, 59.390172140938894, 63.31477178846087, 62.992924281529014, 58.98166670118059, 61.985803740365164, 23.022790023258754, 0.8455895259976387, 0.398298726017986, 5.153012931346893, 57.56305994306292, 62.85503033229283, 51.98421927860805, 15.162999936512538, 21.158557074410574, 52.70312854221889, 63.426109722682405, 34.68082502910069, 44.163187980651855, 30.289535726819718, 34.69584356035505, 50.91257776532854, 62.15332480839321, 16.13654851913452, 0.6600774547883442, 0.022079892523054565, 0.06727740527795893, 0.024939049101833786, 0.06870770281446831, 0.09915186597832612, 0.18836351963026182, 0.16057379224470683, 0.25322077370115686, 0.4457657246717385, 0.2881308032998017, 0.21096603678805487, 0.18461358227900096, 0.364632532532726, 0.897766751902444, 0.5423493491751807, 43.829302719661165, 99.6933022907802, 55.08223690305437, 61.39855589185442, 33.56086574281965, 60.73639256613595, 31.259598050798687, 74.17245074680874, 11.822543161255972, 19.433623347963604, 51.189095224652974, 70.43561921800885, 50.9802497455052, 67.16972964150565, 5.57450498853411, 1.6967613867350986, 43.4122370992388, 56.22684839793614, 64.7762211390904, 62.01154681614467, 62.44248104095459, 55.468129430498394, 61.44071061270577, 62.18541158948626, 65.81815910339355, 63.68808460235596, 65.92168726239885, 61.44901371002197, 62.485233306884766, 58.57220241001674, 53.23044122968401, 47.003486497061594, 47.66963114057268, 50.739421708243235, 56.150904587336946, 53.31864513669695, 60.058755602155415, 62.459976605006624, 60.15585667746407, 59.924801281520296, 60.60908072335379, 57.90452568871634, 54.49503074373518, 44.769651072365896, 45.41091769082205, 51.45970671517508, 49.20262261799404, 51.521966048649375, 60.43340247017996, 53.90464925765991, 53.85909686769758, 58.05454771859305, 55.71614537920271, 54.867937088012695, 52.597828592572895, 52.60692378452846, 46.242551054273335, 43.98992075238909, 53.45069565091814, 54.83358172007969, 52.82182114464896, 47.95348937170846, 36.690185001918245, 31.97607544490269, 40.24204158782959, 49.869896343776155, 67.04660061427525, 41.36022908346993, 48.03449494498116, 43.810042313167024, 42.38103410175869, 39.761278356824604, 43.37021786825997, 41.51286016191755, 48.624205929892405, 53.09067126682827, 53.94058534077236, 57.11394228254046, 48.46496016638619, 41.769106251852854, 50.16119262150356, 58.10014874594552, 58.94773169926235, 52.373276710510254, 49.6081542287554, 46.723387241363525, 43.23073278154646, 45.13099561418806, 45.51969173976353, 41.17301682063511, 44.63732957839966, 47.17589214869908, 52.062984057835166, 66.63019507271903, 66.71042592184884, 46.477150031498496, 44.73155757359096, 46.03679404939924, 48.75214311054775, 46.40565306799752, 46.333044392721995, 45.51233359745571, 51.39683941432408, 50.66471120289394, 53.360032081604004, 49.401719774518696, 51.10359764099121, 50.05936677115304, 49.22530501229422, 49.58376257760184, 52.53335625784737, 49.62682751246861, 49.19201966694423, 50.045550278254915, 47.819260597229004, 46.651202406202046, 52.25976051603045, 55.996713638305664, 57.52920484542847, 53.46007571901594, 48.17131192343575, 56.64450808933803, 60.18613692692348, 62.399735723223, 54.97558900288173, 52.534672941480366, 46.81026404244559, 45.76775632585798, 47.963091782161165, 47.89019128254482, 50.79599046707153, 55.64216096060616, 59.13732719421387, 61.41408511570522, 54.96711220060076, 56.97086150305611, 54.74155282974243, 61.85814448765346, 66.55470984322685, 67.5613648550851, 66.08965996333531, 67.65214306967599, 35.881518908909385, 1.9703820986407143, 0.5568046420812607, 4.174347868987492, 63.54488917759487, 69.0150808606829, 52.12833186558315, 25.197421584810527, 20.388788734163555, 56.38713639123099, 85.00925731658936, 39.44201210566929, 47.882398877825054, 56.12346962520054, 45.2316437448774, 57.70206560407366, 74.707336970738, 23.007439715521677, 0.7864551991224289, 0.10474000897790704, 0.2309826569897788, 0.17052463042948926, 0.1400370206683874, 0.3519806499992098], [0.1643496360629797, 0.3890375643968582, 0.3614827186933586, 0.4789213612675667, 0.12993685049670084, 0.08118133419858557, 0.33374863117933273, 0.3504865973123482, 0.5607285286699022, 0.5188016870192119, 21.532747098377772, 72.89951297215053, 37.749872139522004, 44.28683117457798, 19.694762706756592, 44.07893759863717, 13.712731105940682, 43.96418809890747, 44.50098507744925, 3.2189106345176697, 15.993182863507952, 56.41884796960013, 49.337539264133994, 46.69007410321917, 29.054507323673793, 0.23100838703768595, 2.670917285340173, 25.79746801512582, 42.560631138937815, 56.15819672175816, 58.97870676858084, 52.2969959122794, 56.07083702087402, 58.26837158203125, 59.841707774571006, 58.241322244916645, 56.13044909068516, 50.96928201402937, 50.7690384047372, 50.36987829208374, 45.82979679107666, 40.06537321635655, 40.63859265191214, 45.69563749858311, 48.769398961748394, 57.46202966145107, 56.87612281526838, 58.45347854069301, 59.05016204289028, 56.23633616311209, 55.06329263959612, 50.48161227362496, 49.84963539668492, 43.510821614946636, 44.9404308455331, 45.413630962371826, 45.41999898638044, 46.85681002480643, 53.60732889175415, 53.79013252258301, 49.69558688572475, 51.792334352220806, 53.08464023045131, 50.07331875392369, 53.24421255929129, 44.464534827641074, 46.1146798815046, 51.75021437236241, 51.36508614676339, 47.953763825552805, 40.58617891584124, 28.310914584568568, 29.146758556365967, 34.57525757380894, 49.26880768367222, 54.022080762045725, 63.05032335008894, 46.103642668042866, 39.4044953073774, 48.33223220280239, 45.501053197043284, 40.961631774902344, 39.0662431035723, 36.85083082744053, 40.80471018382481, 46.25475903919765, 51.51792219706944, 53.597907134464805, 47.53778559820992, 38.186917304992676, 49.67327274594988, 55.20475448880877, 54.08979443141392, 52.695996216365266, 39.321071760995046, 39.23804773603167, 37.4599655015128, 39.73940890175955, 41.00694792611258, 38.16762563160488, 49.06857797077724, 50.92049176352364, 57.67646149226597, 81.28653063092912, 70.97839859553746, 53.521574224744526, 47.67390775680542, 37.4835581098284, 30.509960378919327, 29.841734749930247, 34.69518000738961, 35.72601475034441, 40.09676170349121, 43.38152606146676, 49.88916022436959, 52.00430652073452, 47.68501445225307, 46.42629269191197, 51.18081644603184, 50.15446329116821, 50.478162493024556, 43.52495772497994, 41.3401175226484, 43.324540410723, 42.27759626933506, 41.23501559666225, 47.99590465000698, 50.13343109403338, 52.86692190170288, 44.545401436941965, 48.19296598434448, 44.81537021909441, 67.79426847185407, 68.05190767560686, 46.06068543025425, 53.09444066456386, 40.19393573488508, 38.92689003263201, 36.68075629643032, 41.32673529216221, 45.08713163648333, 49.15708759852818, 50.415656498500276, 56.49324580601284, 54.4422105380467, 53.11734887531826, 49.58564553941999, 50.10943896429879, 52.497555664607454, 53.338937350681846, 48.46838215419224, 32.69653763089861, 3.132262472595487, 0.497629494539329, 0.3192744749997343, 27.18236037663051, 64.22417981284005, 55.97433696474348, 32.6580411366054, 5.692970037460327, 14.318723457200186, 20.093629258019583, 18.174884217126028, 25.295702116830007, 48.24668598175049, 38.3838848386492, 38.24510151999337, 38.26318768092564, 59.68975067138672, 16.92904962812151, 0.6902006098202297, 0.0025401649680653854, 0.0333773309497961, 0.1591453267527478, 0.11563403798001153, 0.17845009586640767, 0.06969995849898883, 0.07315686371709619, 0.1531335064875228, 0.3101413936487266, 0.039236311202070544, 0.04204381430255515, 0.35317145181553705, 0.1820152952734913, 0.5527214897530419, 0.16898727363773755, 24.64858511516026, 82.13159833635602, 45.37708691188267, 53.39034707205636, 21.38082126208714, 52.45992422103882, 12.886560763631548, 42.94590875080654, 35.05125434058053, 4.402429870196751, 15.75822605405535, 56.9093143599374, 58.87840952192034, 52.76813588823591, 39.00348697389875, 0.11237387399056128, 1.1224482612950462, 19.48268631526402, 39.888593673706055, 57.386999538966585, 59.96205752236502, 52.15510674885341, 59.15661539350237, 59.19250283922468, 60.431887762887136, 60.39502756936209, 58.907612800598145, 54.02626010349819, 54.72172267096383, 51.71374675205776, 46.82039104189192, 44.17671264920916, 44.99778822490147, 48.071296078818186, 50.258113043648855, 57.29565852028983, 58.009283678872244, 59.21165207454136, 57.88658891405378, 57.09158992767334, 56.702556814466206, 52.98019143513271, 51.08388907568795, 45.745205947331016, 47.12482636315482, 48.95045859473092, 49.77825655255999, 48.64008951187134, 53.688205923352925, 53.150651591164724, 53.09132787159511, 52.015906538282124, 51.12231956209455, 52.134706837790354, 53.20241567066738, 46.99376596723284, 50.72504588535854, 55.28531885147095, 50.94047130857195, 45.8577424458095, 36.39801672526768, 30.15137427193778, 39.79492848260062, 53.9502329145159, 58.67233289991106, 53.24742610113961, 67.14332648686, 52.895270551954, 37.056209155491416, 46.42845358167376, 43.27691398348127, 41.24944353103638, 37.225210189819336, 39.059854234967915, 39.94496440887451, 49.14975030081612, 50.1916708946228, 53.24296188354492, 47.605652127947124, 37.45322227478027, 50.50330802372524, 54.74497134344918, 56.47335311344692, 54.65165703637259, 41.87188400541033, 40.22222532544817, 36.852790219443186, 41.25756597518921, 42.119649818965364, 41.25378615515572, 47.035712242126465, 49.96019860676357, 51.738517080034526, 75.57497937338692, 68.46973064967564, 59.657462392534526, 57.14136682237898, 49.00685017449515, 39.753680501665386, 34.836086000714985, 35.641868591308594, 38.26598085675921, 41.652793407440186, 45.32569456100464, 51.0679429599217, 51.9346855708531, 50.07773086002895, 50.06129142216274, 51.584472043173655, 51.11042424610683, 52.57426725115095, 46.267227581569124, 42.22278193065098, 47.71782037190029, 43.88865075792585, 45.83720704487392, 49.616568497249055, 53.50711849757603, 56.00431496756417, 52.13502645492554, 48.683279514312744, 44.94618047986712, 62.589574405125205, 60.839920725141255, 52.64075803756714, 55.39320353099278, 45.81855460575649, 42.92407056263515, 41.00075013296944, 45.52268293925694, 47.930952889578684, 56.199635778154644, 58.28361940383911, 61.292158126831055, 56.91733258111136, 53.03256000791277, 48.526378767830984, 52.02642611094883, 54.22775091443743, 55.42751373563494, 52.50515699386597, 29.904219899858745, 2.104533140148435, 0.39990164286323954, 0.1329306284231799, 34.62243584224156, 63.079860142299104, 61.91301441192627, 29.05925989151001, 9.271523339407784, 17.264699731554302, 21.795164925711497, 27.97436121531895, 32.7206826210022, 49.44380153928484, 31.460140432630265, 44.98797389439174, 46.11986323765346, 67.92042691367013, 26.360308579036168, 0.690535263291427, 0.11926570667752198, 0.03593850548246077, 0.05294678978888052, 0.053634603773908954, 0.0855722360845123, 0.2858801026429449, 0.6077704387051719, 0.42701202098812374, 0.5436548505510602, 0.228242461170469, 0.25220307973878725, 0.8083092921546527, 0.49370848493916647, 1.4474336398499352, 0.5957270935177803, 31.57145404815674, 100.2274728502546, 55.14120626449585, 62.443127223423545, 31.273414543696813, 67.2818249293736, 22.121554817472184, 48.82154866627285, 58.92373956952776, 8.322184886251177, 22.930682965687343, 62.348124504089355, 58.458529881068635, 56.84806598935808, 40.30027444022042, 0.6951136919004577, 4.4384762559618265, 28.620482887540543, 50.23438147136143, 63.3879154750279, 62.90386922018868, 55.09130777631487, 61.524332182747976, 61.384951319013325, 64.2866302217756, 63.69956997462681, 67.63541875566754, 61.26831190926688, 62.72417490822928, 59.660477910723, 55.125774315425325, 48.16409274509975, 48.55944177082607, 54.35702562332153, 54.8277382850647, 60.581301825387136, 60.23946435110909, 63.48817103249686, 63.34624712807791, 61.052542550223215, 60.65961497170584, 55.20689453397478, 51.0498811176845, 44.33695895331246, 47.694450105939595, 49.544390610286165, 49.72342136928013, 51.89880507332938, 58.340500831604004, 55.665128231048584, 55.29682854243687, 54.438816343035015, 54.469645500183105, 54.81281702859061, 57.70119360515049, 50.126809460776194, 52.95478187288557, 58.30787903921944, 51.346176624298096, 49.36395631517683, 47.29964303970337, 43.73807634626116, 47.7769148009164, 54.523452350071494, 55.67230919429234, 57.76018728528704, 64.47837271009172, 51.458758286067415, 44.11576999936785, 51.64521319525582, 48.55681535175869, 43.555300508226665, 42.01626409803118, 40.36475024904524, 43.25067758560181, 50.37527356828962, 54.13993610654558, 56.66414022445679, 53.22293717520577, 39.05946513584682, 54.18727765764509, 60.221176692417686, 62.33312334333147, 57.48231145313808, 42.497604029519216, 42.79045670373099, 38.86131293433053, 45.23999547958374, 46.42822776521955, 42.33554424558367, 48.72739710126604, 50.552473476954866, 55.519469669886995, 73.61487865447998, 65.91423879350934, 55.54073463167463, 55.45569910321917, 51.83579880850655, 47.206175872257774, 42.57920714787075, 40.738292353493826, 41.08543130329677, 43.090087345668245, 46.98929132734026, 53.50671550205776, 55.81230844770159, 51.216186250959126, 52.57341957092285, 53.69662366594587, 55.63757862363543, 57.71394007546561, 48.23498174122402, 44.79787812914167, 51.50446701049805, 46.70185129983084, 46.92051110948835, 51.899371351514546, 55.73509659085955, 60.6860876083374, 54.723334653036936, 54.378610202244346, 48.94661276681082, 66.7232175554548, 72.10832159859794, 54.74072252001081, 61.94399642944336, 48.98907320840018, 49.58624308449881, 46.79490852355957, 51.183745111737935, 54.25681870324271, 58.400630542210166, 62.31466197967529, 65.16254792894635, 56.83402368000576, 54.26850209917341, 49.46345451899937, 52.85540526253836, 56.03251770564488, 59.67240101950509, 57.09499454498291, 41.31228303909302, 5.450169580323355, 0.738169941518988, 0.5735861701624734, 34.5460820879255, 72.82169314793178, 61.15291622706822, 37.65135710580008, 13.0657947574343, 21.441208056041173, 25.996382781437465, 23.66255235671997, 37.12671252659389, 65.2632064819336, 56.01377146584647, 56.634801455906455, 51.524505615234375, 80.14244719914028, 35.472183159419465, 1.1796320442642485, 0.1887810765100377, 0.16962471657565661, 0.17865172933254922, 0.16162291594914027, 0.27328611271721975], [0.20604629149394377, 0.233355846788202, 0.3209354744425842, 0.4002113805285522, 0.5795120064701352, 0.07656136567571334, 0.9618786488260541, 0.43136333035571234, 0.8014292727623666, 0.20373161855552877, 11.818182298115321, 62.42223399026053, 43.01490783691406, 54.804427078792024, 24.929999317441666, 41.649090017591206, 40.36822782244001, 19.004757949284144, 25.107588325228008, 12.814328159604754, 15.049026897975377, 44.084193910871235, 48.76965951919556, 45.65278448377337, 54.03740848813738, 5.684600932257516, 0.15175270129527363, 0.6322265778269086, 9.555967824799673, 25.731913498469762, 45.987232548849924, 55.26480776923043, 58.67531367710659, 63.7532239641462, 59.10069629124233, 59.76541655404227, 53.137849535260884, 50.70131778717041, 43.11070959908621, 41.17044946125576, 37.59816517148699, 43.81895685195923, 39.133341857365195, 51.37364632742745, 52.3683226449149, 51.59771530968802, 51.319644927978516, 52.578696727752686, 50.92743648801531, 54.95697477885655, 53.309404032570974, 52.79824243273054, 51.396658761160715, 51.25616271155221, 48.053602491106304, 47.411519459315706, 47.83082239968436, 45.50520474570138, 46.8782764843532, 48.13737692151751, 49.176577295575825, 49.98722015108381, 50.83394847597395, 51.70316464560372, 46.64655753544399, 47.166612829480854, 49.65983492987496, 39.30413205283028, 32.238967486790244, 32.54295812334333, 33.63865777424404, 47.939704145704, 57.40122250148228, 57.33694819041661, 55.6020107950483, 46.09558275767735, 34.58597864423479, 39.89891522271292, 42.15450198309762, 44.27824320111956, 41.58417994635445, 41.01871470042637, 36.614970752171104, 34.63309437888009, 35.79238741738455, 39.27259765352522, 49.3674373626709, 50.053773471287315, 43.19574512754168, 40.89019039699009, 44.020531041281565, 47.71106672286987, 51.26904467173985, 42.44379717963082, 36.08170345851353, 39.66219009671892, 38.02062259401594, 40.12722955431257, 41.766712597438264, 44.83001702172415, 44.38408511025565, 36.55828039986746, 34.47780908857073, 29.759902341025217, 40.00612940107073, 49.03954144886562, 58.361407961164204, 61.04988833836147, 54.13375915799822, 44.33033037185669, 31.12887464250837, 27.884864943368093, 30.55334493092128, 34.053204672677175, 35.154612268720356, 44.51850496019636, 52.43432010923113, 51.45123338699341, 50.08192409787859, 48.963653223855154, 53.006476470402305, 48.87932988575527, 43.25842482703072, 45.50509704862322, 45.04054396493094, 44.97074236188616, 45.10773999350411, 50.99107156481062, 50.354884079524446, 53.043402671813965, 46.42127956662859, 54.09267793382917, 42.193971225193565, 40.04003313609532, 50.884204796382356, 50.36047043119158, 42.74523435320173, 38.64264965057373, 39.166946819850374, 38.42228058406285, 44.33019488198416, 49.264308725084575, 54.498258181980674, 52.74432441166469, 55.66825492041451, 50.6262320790972, 49.26591028485979, 48.64393533979143, 51.51766511372158, 42.78641632625035, 32.88335732051304, 3.6141599970204488, 0.22222578259451048, 0.962234092610223, 3.3965808493750433, 52.914124488830566, 55.64354712622506, 52.751185757773264, 18.67222932406834, 7.533538290432521, 21.38088205882481, 22.493646485464915, 11.458270822252546, 27.72380222593035, 73.85469572884696, 48.97444725036621, 17.454116310392106, 35.43183497020176, 56.727997643607004, 20.924381937299454, 0.1281979823751109, 0.0312270806171, 0.3809030151792935, 0.14197740011981555, 0.10490559187850781, 0.33361783676913803, 0.2006238874580179, 0.18785856744008406, 0.3650041254503386, 0.13570939217294964, 0.552514238016946, 0.08997565694153309, 0.42843387754900114, 0.3148789794317314, 0.4295908340385982, 0.08255916740745306, 14.879344940185547, 73.86562524523053, 46.19176319667271, 62.57241930280413, 30.92183916909354, 50.51634284428188, 25.310798815318517, 15.983311210359846, 30.36038998195103, 12.145522356033325, 19.994565316608973, 46.29239048276629, 57.741027627672466, 53.44580064501081, 61.30730519975935, 7.225598905767713, 0.22492457420698234, 0.19122210623962538, 5.767227607113974, 21.035937002726964, 44.24090358189174, 53.37272991452898, 58.54713330950056, 63.35437652042934, 62.32445199148995, 61.39679799761091, 55.47506373269217, 53.53883702414376, 47.48050117492676, 46.68224695750645, 41.012388365609304, 45.52461106436593, 42.672827175685335, 53.19003050667899, 53.54167883736746, 52.972784655434744, 54.179315022059846, 53.39531850814819, 52.31970957347325, 55.190507207598, 56.86414412089756, 56.58387810843331, 52.30243982587542, 52.35466596058437, 48.05113240650722, 49.71074438095093, 49.38070494788033, 48.91184745516096, 50.2848288672311, 50.56172500337873, 50.856599603380474, 50.12841796875, 52.493543079921174, 53.13965606689453, 48.805793625967844, 50.55753871372768, 50.91431481497628, 38.10331310544695, 31.106091499328613, 31.356435094560894, 40.646416323525564, 65.68173817225865, 73.39159829275948, 68.13120746612549, 59.739826338631765, 45.53852483204433, 37.20043986184256, 41.51148789269583, 42.29645715441023, 38.77484955106463, 37.5664883341108, 38.89382355553763, 38.0450941494533, 39.35973153795515, 39.945054735456196, 40.87477581841605, 49.36627353940691, 50.03037541253226, 44.55579594203404, 42.88258981704712, 47.99056148529053, 51.84108638763428, 52.87416192463466, 45.57391200746809, 38.17271171297346, 37.93111937386649, 37.32018859045846, 39.46842915671212, 43.24518503461565, 44.40114641189575, 46.64315639223371, 36.9385518346514, 33.91939279011318, 29.77886744907924, 39.057735034397666, 52.6625406401498, 60.49679783412388, 64.84609917231968, 61.41603755950928, 53.21113913399832, 38.343157972608296, 32.04266003199986, 32.38072463444301, 38.08261789594378, 42.372817856924875, 48.33545964104788, 53.15685633250645, 52.866254874638145, 49.894850799015586, 50.658454350062776, 53.790104729788645, 49.56431456974575, 44.43280587877546, 46.212760652814595, 48.00712946483067, 46.64065851484026, 49.05542503084455, 54.18938643591744, 53.01691266468593, 55.08754185267857, 48.564694608960835, 54.181944915226524, 44.49270282472883, 40.70982905796596, 55.18094648633684, 54.461491789136616, 48.064347880227224, 41.697949750082834, 43.17155844824654, 42.43453523090908, 49.129121099199565, 52.0590374810355, 58.01983799253191, 55.70552505765642, 56.72578116825649, 51.474693979535786, 51.78939526421683, 50.15206616265433, 52.46410356249128, 45.535877568381174, 31.360079424721853, 1.167999022773334, 0.30187507293054033, 1.0334073134831019, 3.8325360161917548, 57.80347456250872, 57.7972663470677, 57.12745305470058, 19.762504168919154, 12.35299469743456, 15.316541228975568, 18.169468096324376, 14.996691329138619, 35.13918031964983, 83.25050149645124, 53.27165446962629, 23.880513872419083, 42.75224161148071, 62.25046757289341, 28.366295201437815, 0.843951053917408, 0.06436695823712008, 0.07507719924407345, 0.053220924721764665, 0.04989257474829044, 0.2513357491365501, 0.2493032110588891, 0.274855944194964, 0.3090772878910814, 0.25437121625457493, 0.617992595902511, 0.18619342893362045, 0.7545388117432594, 0.34098515287041664, 0.8176430027399744, 0.26932126975485254, 19.853650638035365, 90.54672145843506, 60.6069267817906, 69.9488423211234, 38.23513085501534, 57.984905924115864, 55.88564668382917, 25.967037064688547, 32.603105204445974, 20.85490689958845, 22.11335073198591, 52.68369443075997, 54.62887041909354, 55.24363660812378, 65.61387511662075, 6.839920035430363, 0.2751503198274544, 2.667082096849169, 11.066344652857099, 32.94634621483939, 51.56297084263393, 57.899470874241416, 62.495745931352886, 67.89922101157052, 69.12438992091587, 66.94851984296525, 61.74029609135219, 58.956972803388325, 52.65618303843907, 53.073054109300884, 47.01963063648769, 52.10582317624773, 45.996150561741416, 57.92075320652553, 59.19621317727225, 56.30609260286604, 56.54579850605556, 59.28064768654959, 55.433951241629465, 58.55804892948696, 59.121401923043386, 56.310053076062886, 53.392556599208284, 51.6130291393825, 49.967223235539024, 48.86536053248814, 51.613668373652864, 51.026656763894216, 51.54087209701538, 50.738657406398225, 52.14428492954799, 53.00036205564226, 54.65897348948887, 56.567469937460764, 55.98162909916469, 52.333446162087576, 52.591370241982595, 38.79840047018868, 41.00262614658901, 46.113734926496235, 49.67843525750296, 63.608291489737375, 58.3453437260219, 53.986561570848735, 50.97541727338518, 37.75189406531197, 31.410266263144358, 40.68741069521223, 43.804872853415354, 41.47545453480312, 41.46350710732596, 43.725149222782676, 40.62818772452218, 42.10095569065639, 43.26680782863072, 44.1962822505406, 53.602350507463726, 55.39842510223389, 47.00404930114746, 46.61169842311314, 48.20151226861136, 52.392658710479736, 55.892730372292654, 47.62735482624599, 39.2735321862357, 43.030867849077495, 42.72735663822719, 41.643444606236045, 45.5775146484375, 46.23409857068743, 46.165974957602366, 42.851465361458914, 42.42260864802769, 35.00071661812918, 38.29459006445748, 46.2004588672093, 51.50737483160836, 54.92187247957502, 54.83886235100882, 54.49587147576468, 42.25175591877529, 37.5028532573155, 35.59126833506993, 37.76218087332589, 43.00697994232178, 50.6339167867388, 59.1708869934082, 53.3213723046439, 55.94382047653198, 54.03974308286394, 58.35354260035923, 52.61177710124424, 49.96708427156721, 49.186798095703125, 50.302275793892996, 47.49455738067627, 52.08942542757307, 56.70251512527466, 56.31082432610648, 57.855481828962056, 53.11926310403006, 52.445006438664024, 54.68759659358433, 55.195131233760286, 57.63012742996216, 60.76637404305594, 53.36716440745762, 48.84449161802019, 48.456552846091135, 47.916931424822124, 52.341137817927766, 56.038194383893696, 59.991663796561106, 57.457332679203574, 57.9356883593968, 51.64424392155239, 52.76881333759853, 52.630436488560264, 55.55531195231846, 52.26868895121983, 37.92224999836513, 4.225223447595324, 0.2516515664756298, 1.0690263850348336, 3.7885395884513855, 61.68797615596226, 60.92255565098354, 58.81194305419922, 26.778414692197526, 16.280617679868424, 27.247334718704224, 27.731007507869176, 12.366535867963519, 37.91237660816738, 97.91162436349052, 71.48210825238908, 31.469523974827357, 54.971312386649, 74.06107807159424, 40.94905206135341, 1.5021142257111413, 0.16682277406964982, 0.28048718773892944, 0.2683630426015173, 0.13750390016606875, 0.40507055978689877], [0.08651358128658362, 0.2071183089699064, 0.624218181840011, 0.23745151130216463, 0.3422922284475395, 0.3185753939407212, 0.3635394669004849, 0.08863624238542148, 0.27402718152318684, 0.34172535315155983, 9.261106252670288, 63.621048382350374, 40.075944900512695, 42.254837444850374, 16.419810942241124, 39.964245659964426, 39.81021799360003, 81.34406171526227, 11.493314930370875, 2.93826008268765, 29.486330917903356, 51.28171818596976, 49.86547034127371, 34.75530971799578, 60.10931069510323, 20.597773177283152, 0.05495958249749882, 0.2056551431970937, 0.1685588601976633, 1.6021681768553597, 12.34213900566101, 47.65237528937203, 61.70478384835379, 62.95680059705462, 55.202214922223774, 56.94513579777309, 50.79250941957746, 49.6369058745248, 42.15747233799526, 43.20667116982596, 39.72267416545323, 42.459750243595664, 49.82836696079799, 51.091955934252056, 47.85956014905657, 54.283194065093994, 52.34037699018206, 49.184866496494834, 46.34813240596226, 53.63233198438372, 56.143067019326345, 56.2722236088344, 54.836465222494944, 53.07915115356445, 47.576455797467915, 48.416694504874094, 46.698648180280415, 51.72396060398647, 50.39472157614571, 51.06891918182373, 48.72835942677089, 49.385870933532715, 48.502796581813264, 50.32170990535191, 46.452376229422434, 42.34147800718035, 24.980128833225795, 23.470424243382045, 29.5916690826416, 39.25781536102295, 55.15716280255999, 59.22890445164272, 60.44607598440987, 57.41109241758074, 54.59463317053658, 51.35066863468715, 42.37108080727713, 38.08779082979475, 44.23073141915457, 41.001250403267996, 39.49471071788243, 37.77459035600935, 37.481084551130024, 36.76266166142055, 36.94222395760672, 39.82616410936628, 43.53210742133004, 36.53216906956264, 39.47835465839931, 33.55128765106201, 34.70684603282383, 39.41351406914847, 44.785444327763145, 42.36685282843453, 40.03102479662214, 37.6923063141959, 41.883619512830464, 40.69111408506121, 37.03836270741054, 38.58457660675049, 36.98576136997768, 31.941601957593644, 28.513275657381328, 27.90764808654785, 41.739684104919434, 42.79232924325125, 41.88588115147182, 45.19033670425415, 48.52428388595581, 55.01605878557478, 56.35245793206351, 45.95087262562343, 33.7947073663984, 27.69711766924177, 30.812342507498606, 26.885067803519114, 32.61123807089669, 50.44900090353829, 44.71419402531215, 46.01832226344517, 46.755321162087576, 49.053813048771445, 41.56265442711966, 46.36865043640137, 41.57428571156093, 42.25083180836269, 46.806762150355745, 53.83207879747663, 48.827781200408936, 52.33559315545218, 46.48515783037458, 63.69160039084298, 32.567381041390554, 25.326802253723145, 58.56972885131836, 47.06924077442714, 49.26749447413853, 36.9151155608041, 39.929859025137766, 37.373234612601145, 46.444170406886506, 53.38025828770229, 54.74217469351632, 54.97506788798741, 58.6863682610648, 58.00789751325335, 59.55216244288853, 50.461834226335796, 49.23580721446446, 27.69537714549473, 6.786702479634966, 0.23728977569511958, 0.64981909096241, 1.0560123005083628, 8.643797022955757, 55.60198300225394, 54.41580738340105, 50.94421638761248, 25.696187598364695, 12.140213932309832, 12.055734259741646, 19.490007979529246, 23.272919961384364, 25.52620165688651, 55.17386279787336, 34.279101031167166, 43.139610631125315, 50.34021643229893, 52.31327901567732, 22.45979486192976, 1.0322945160525185, 0.09924985322036914, 0.05885988660156727, 0.17577679002923624, 0.08933137437062603, 0.15540860726365022, 0.047020481899380684, 0.06406551905508552, 0.27485656844718115, 0.08620903441416365, 0.30912369968635695, 0.15804273448884487, 0.1216044540383986, 0.024302651107843434, 0.07875855706099953, 0.2449825443327427, 11.421804938997541, 71.13048771449498, 45.738250800541465, 44.795859677451, 22.01900635446821, 49.34915665217808, 52.756184986659456, 83.36475072588239, 17.52185950960432, 6.57273096697671, 34.585731983184814, 59.11250128064837, 48.35091938291277, 38.95160130092076, 66.02950940813336, 25.679209675107682, 0.028090876493869082, 0.16955144836434297, 0.2079941484012774, 0.33520745432802607, 11.704158016613551, 46.430628367832725, 61.22062642233712, 61.96446582249233, 56.83333580834525, 58.337603432791575, 51.94291571208409, 50.63761670248849, 45.81365612574986, 47.87610728400094, 42.22267770767212, 43.62822880063738, 52.05635895047869, 52.03967979976109, 50.76809344972883, 56.31215490613665, 54.562643664223806, 53.25093494142805, 46.259744371686665, 53.151433263506206, 56.67560822623116, 56.85933944157192, 55.261434418814524, 52.76204579217093, 47.08631249836513, 50.420270102364675, 51.85004608971732, 54.49223061970302, 51.3540107182094, 53.18712615966797, 52.791704177856445, 52.51463433674404, 51.640759399959016, 51.98940263475691, 47.22951487132481, 40.52696984154837, 24.640926463263376, 26.922685350690568, 37.491204602377756, 53.38419444220406, 66.21752766200474, 61.96893351418631, 58.06474767412458, 59.88768400464739, 53.329984596797395, 48.185764176504954, 39.68655742917742, 34.391828605106895, 41.929025990622385, 39.204515729631694, 37.39557307107108, 38.558437483651296, 37.739154543195454, 40.84187609808785, 43.27014643805367, 43.684547424316406, 45.04523399897984, 40.14648648670742, 39.76434598650251, 37.008506298065186, 38.008320808410645, 39.92372376578194, 46.33213765280587, 42.12184197562081, 38.10664824077061, 38.87256554194859, 41.03940296173096, 40.24699912752424, 36.223200048719136, 36.63134070805141, 33.758510725838796, 30.7734569140843, 26.566699607031687, 29.55241870880127, 43.09613575254168, 45.56012330736433, 40.75462409428188, 43.32844182423183, 46.89913845062256, 52.0360563141959, 56.50335890906197, 51.07112870897566, 39.758113452366416, 31.302385057721818, 31.523567063467844, 30.95055259977068, 38.1194155556815, 47.72577258518764, 44.48851653507778, 48.098237718854634, 50.4267076083592, 50.767325673784526, 40.03339760644095, 47.67469637734549, 42.240055152348106, 44.55825560433524, 48.473815645490376, 55.32382229396275, 51.97198697498867, 56.79595102582659, 50.93026787894112, 59.996465001787456, 36.339707442692344, 30.17592920575823, 62.462415422712056, 51.231173515319824, 51.7061801637922, 39.49034724916731, 42.518219334738596, 40.31164516721453, 48.28805903026036, 52.609557151794434, 57.557473591395784, 58.41089997972761, 62.06546483721052, 58.847663743155344, 61.03738852909633, 55.41290167399815, 51.14967114584786, 30.877141407557897, 4.867976112025125, 0.1464827505073377, 2.1681627886635915, 1.4217084773949213, 11.96999088355473, 60.69436986105782, 59.17817565373012, 56.6609787940979, 30.74030011040824, 17.198075192315237, 11.169396860258919, 18.696370840072632, 24.961797748293193, 28.149466242109025, 58.58100577763149, 39.92828525815691, 43.674614974430625, 50.923580237797324, 64.63135119846889, 31.252476147242955, 0.9058419157351766, 0.06988847588321992, 0.055936516861298254, 0.06229851208627224, 0.06779349222779274, 0.06613796856254339, 0.10049680380948953, 0.1704522714551006, 0.4847010682736124, 0.2271473870745727, 0.5728427129132407, 0.3438095955976418, 0.3577897511422634, 0.18207842617162637, 0.35530007045183865, 0.38267203739711214, 15.42782357760838, 87.45029149736676, 52.597852911267964, 55.07744264602661, 25.16390347480774, 57.699095249176025, 46.55542843682425, 85.26187297276088, 19.593643835612706, 10.312645758901324, 40.770080362047466, 61.62005056653704, 59.301283836364746, 43.27898454666138, 76.22189835139683, 27.37539001873561, 0.197249885648489, 0.36905280819961, 0.2947109102138451, 2.698378086090088, 18.74866645676749, 55.47830854143415, 68.94779450552804, 65.28881754193986, 59.7992890221732, 60.231286321367534, 56.24874564579555, 54.40747996738979, 50.11239889689854, 50.51706893103463, 45.392157554626465, 47.1991616657802, 55.526529039655415, 57.06565577643258, 52.42584678104946, 59.91574083055769, 57.871497426714214, 53.819808278764995, 48.03110422406878, 55.05674048832485, 60.02914932795933, 58.14323452540806, 58.27781765801566, 55.322474343436106, 50.300792353493826, 52.38234063557216, 54.19664035524641, 56.264174120766775, 52.367016383579795, 53.16924844469343, 52.18276405334473, 54.03433043616158, 52.81057895932879, 56.8318315233503, 47.99841294969831, 42.13307721274239, 33.032291957310264, 40.61617428915841, 46.84475142615182, 54.48346199308123, 56.97766031537737, 55.634351185389924, 54.40595831189837, 55.12758084705898, 53.34883505957467, 49.57074860164097, 42.46203620093209, 37.7483365876334, 44.26190798623221, 39.07758603777204, 40.910308906010215, 40.225213050842285, 38.929846491132466, 42.370670863560264, 46.65785183225359, 49.59196492603847, 49.83258104324341, 40.8478341783796, 44.194298539842876, 37.640427589416504, 38.999147823878694, 41.142243249075754, 46.9117112159729, 47.06095504760742, 43.90884222303118, 43.971685205187114, 45.185306208474294, 44.780917576381135, 37.17200435910906, 37.33810452052525, 34.98383944375174, 33.47588579995291, 30.47727952684675, 33.55597768511091, 43.502949305943076, 45.51234401975359, 41.55072437013899, 43.47775166375296, 42.80688224520002, 47.78980370930263, 53.055329254695344, 51.09896666663033, 43.93954283850533, 37.97306912285941, 39.79901054927281, 34.25023821422032, 41.94866507393973, 56.35803733553205, 50.008714403424946, 51.95055178233555, 55.722179889678955, 54.22311299187796, 43.3383013180324, 51.549852643694194, 45.53125006811959, 46.9652818271092, 51.31693860462734, 58.53928879329136, 55.66737249919346, 56.987738677433555, 55.48699378967285, 61.80157225472586, 42.88877371379307, 39.53887694222586, 66.2709732055664, 55.869971547807964, 55.69567598615374, 43.81137636729649, 44.3270959854126, 44.266594546181814, 51.81576715196882, 56.52915409633091, 60.704576764787944, 59.80326339176723, 64.81720161437988, 63.644039971487864, 63.30597536904471, 58.12862941196987, 59.5306647164481, 39.957075119018555, 8.666680915015084, 0.3774609698780945, 1.257213024156434, 4.1371893371854505, 10.467939734458923, 65.91002123696464, 61.04898507254464, 61.640422684805735, 35.04671369280134, 22.328619820731028, 18.14324038369315, 26.448953696659633, 28.815859283719742, 37.89804942267281, 67.80983243669782, 48.65990924835205, 57.94481481824602, 64.0979449408395, 72.91389574323381, 40.80346993037632, 1.4104799713407243, 0.23159597122243472, 0.22637806407042912, 0.14925673737057618, 0.16936611330934934, 0.189082943169134], [0.11357121688446828, 0.08494848598326955, 0.10737029569489615, 0.06578709131905011, 0.1994861742215497, 0.039008337006505044, 0.08440236707351037, 0.0790152061464531, 0.07617242940302406, 0.17830286733806133, 6.547082994665418, 67.98290511540004, 40.51168033054897, 62.18984454018729, 30.66899422236851, 39.86675548553467, 33.62229129246303, 64.49427018846784, 36.29711845942906, 0.8545888545257705, 34.52983372552054, 54.86204154150826, 59.16200719560896, 42.48860611234392, 48.83006020954677, 30.390802247183665, 0.3141926819724696, 0.19231585040688515, 0.1622695598219122, 0.27443812947188106, 0.11172123186822448, 7.300150905336652, 52.785169397081646, 61.63997800009591, 57.80483293533325, 54.11238649913243, 52.29349749428885, 49.431506701878135, 46.51693541663033, 47.35909877504621, 43.52458599635533, 50.21014962877546, 48.83037287848336, 56.41613817214966, 52.44635091509138, 52.88649150303432, 49.51196684156145, 46.49546200888497, 40.01620428902762, 45.1276535306658, 57.48717866625105, 54.485716683524, 53.30272681372506, 49.79614468983242, 47.43417406082153, 48.89005095618111, 51.644719873155864, 50.67309767859322, 53.969771248953684, 55.72431993484497, 51.557770115988596, 53.180476733616416, 52.728857721601216, 52.66349254335676, 40.93525641305106, 30.55323028564453, 27.711894750595093, 36.42325605664934, 52.200033800942556, 63.57052108219692, 60.285225187029155, 54.54565879276821, 50.841181550707134, 41.826637336185996, 37.70674467086792, 43.39448792593819, 44.99977888379778, 42.38308034624372, 39.95134285518101, 40.67502205712454, 42.39311701910836, 43.20209578105381, 41.26226643153599, 39.82742520741054, 42.03858518600464, 40.70133488518851, 42.83850697108677, 37.95953403200422, 36.01266963141305, 37.62375886099679, 36.91856186730521, 36.26821395329067, 44.81948355266026, 43.94707121167864, 40.383065700531006, 38.753831250326975, 40.783646719796316, 37.11825656890869, 34.80500323431832, 38.325954232897075, 40.44529724121094, 40.92195756094796, 47.94515153339931, 47.618971824645996, 41.72107335499355, 38.607863494328086, 37.826517718178884, 36.40424925940377, 38.85665764127459, 38.338697229112896, 44.35541336877005, 51.58168581553868, 53.304258891514365, 43.41163608006069, 29.132966382162913, 21.179961000170024, 17.08334653718131, 25.910386664526804, 43.90634087153843, 47.49714905875069, 44.50177369798933, 45.31090532030378, 45.30854640688215, 42.20366048812866, 41.622700759342735, 44.956126826150076, 46.1955360685076, 50.00511871065412, 46.79586737496512, 52.24424518857683, 49.40429408209664, 42.630133969443186, 37.040019852774485, 31.527326038905553, 55.597977365766255, 46.52771207264492, 45.62735407693045, 39.91681725638253, 42.08184119633266, 40.60333054406302, 44.31830998829433, 49.10325295584542, 57.317840644291465, 54.0829678262983, 58.45923164912632, 52.96849066870553, 55.36620283126831, 49.65354681015015, 52.22883755820138, 9.790156858307974, 0.7103629250611577, 0.23133375814982823, 0.4154681861400604, 0.3097525116588388, 18.353060347693308, 56.12886142730713, 51.71255166190011, 60.43876647949219, 50.354814597538535, 27.28749704360962, 10.812519141605922, 13.758661304201398, 27.242121832711355, 32.98359898158482, 42.8806790624346, 27.886728797640117, 31.348746912819998, 50.61758157185146, 56.07339743205479, 21.318871123450144, 0.981778615287372, 0.19434180669486523, 0.03829585827354874, 0.06448002931262765, 0.04431792102488024, 0.05499299695449216, 0.21429009842021124, 0.04063292286757912, 0.02844718541018665, 0.028453819786331484, 0.08789425755717925, 0.01526793188947652, 0.08996243907936982, 0.08346146970455136, 0.11773423956973211, 0.05309342459908553, 7.889649970190866, 76.17382376534599, 47.805607386997764, 61.85683822631836, 32.84019858496529, 47.819809504917686, 39.49559313910348, 76.24561255318778, 40.69192702429635, 3.8911788122994557, 35.350200584956575, 61.546524729047505, 60.44283812386649, 45.487907205309185, 54.66283668790545, 38.72756011145455, 0.3737667809639658, 0.14222852593021734, 0.1554962197052581, 0.23489541560411453, 0.2994871453515121, 7.415372882570539, 53.168049880436485, 61.56936345781599, 58.43197386605399, 57.496068886348176, 54.20939029966082, 50.804060799734934, 48.180549553462434, 48.57361957005092, 45.56586946759905, 51.46068641117641, 54.246500628335134, 60.29937866755894, 52.98971046720232, 49.54866027832031, 49.822905676705496, 46.62277037756783, 40.72937781470162, 46.282621315547395, 58.00699424743652, 54.5287503514971, 55.36572687966483, 51.780407769339426, 49.890511648995535, 50.505514076777864, 52.790238107953755, 52.23602546964373, 54.30309023175921, 55.349398612976074, 52.72410862786429, 55.89162213461739, 51.86742353439331, 51.29489891869681, 40.303408077784944, 34.53462103434971, 40.95590645926339, 47.40327194758824, 61.299036843436106, 62.4402437210083, 56.05145154680525, 50.30336666107178, 48.85971164703369, 43.01704093388149, 35.33476516178676, 40.179678031376426, 43.390169620513916, 41.999720437186106, 40.78197915213448, 41.08245400020054, 44.77341004780361, 43.25926208496094, 41.778152806418284, 39.13017347880772, 38.81243583134243, 43.94584832872663, 46.713284560612266, 38.366893018995015, 37.30661528451102, 36.19534124646868, 35.67040484292166, 37.22383792059762, 44.601817335401265, 44.26285988943917, 41.10805116380964, 38.20886319024222, 40.83509465626308, 36.977583340236116, 32.99043600899832, 34.42474569593157, 37.32864107404436, 37.56193378993443, 45.002759660993306, 45.21509313583374, 41.391242367880686, 37.81479958125523, 36.99672562735421, 38.00353349958147, 39.17808478219168, 37.58241013118199, 42.100820200783865, 47.849853515625, 52.96552378790719, 49.91850594111851, 35.71652351106916, 24.495738642556326, 18.33736436707633, 30.161039216177805, 44.33984245572771, 46.81267854145595, 45.55570772715977, 46.27673619134085, 47.461108752659385, 44.69606964928763, 42.12318297794887, 47.04801402773176, 47.85449143818447, 53.3746371950422, 51.108343260628835, 55.3491450037275, 52.73139728818621, 43.8591000693185, 40.751876081739155, 37.52991649082729, 59.70208372388567, 51.09655564171927, 49.859991686684744, 43.33939218521118, 44.69231762204851, 40.280350480760845, 46.16207701819283, 50.345118386404856, 58.991804122924805, 55.65526873724801, 60.04057216644287, 53.33146456309727, 57.549208709171836, 53.66752461024693, 56.31175538471767, 11.662024140357971, 0.2633001942719732, 0.02525852544100157, 2.374572055680411, 0.8467058518103191, 22.58740200315203, 60.98178904397147, 56.26243012292044, 64.38479437146867, 59.105330739702495, 31.10020637512207, 11.572147454534258, 17.828942094530376, 23.92076826095581, 24.93991265978132, 45.48117787497384, 30.545542103903635, 31.60673005240304, 52.85838256563459, 66.14957427978516, 26.783360072544642, 0.7369423359632492, 0.12954726283039364, 0.022774693722437536, 0.09801774897745677, 0.2037717742579324, 0.052746055381638665, 0.3205883630684444, 0.12650304261062825, 0.2714061364531517, 0.11109159208301987, 0.29121143370866776, 0.11381354888102838, 0.2952457586569445, 0.18440278859010764, 0.26480551064014435, 0.2700191837336336, 10.741301843098231, 91.75761876787458, 55.29553965159825, 77.38999475751604, 39.31697232382638, 52.56779500416347, 42.98852900096348, 70.43003286634172, 45.22183288846697, 6.934600097792489, 42.188777446746826, 67.43456717899868, 68.49734279087612, 54.35006005423409, 60.90922205788748, 44.338105406079976, 0.6916086514081273, 0.43366234270589693, 0.5705287456512451, 0.33369898955736843, 0.5224435744541032, 11.183176875114441, 57.873950140816824, 65.56491116115025, 62.432315826416016, 59.16073567526681, 58.77504117148263, 52.39951310838972, 50.047325542994905, 48.52653510229928, 47.590088163103374, 53.308556352342876, 52.702496256147114, 63.2948374067034, 57.94958823067801, 50.319236346653526, 53.32684053693499, 47.87490177154541, 40.48694821766445, 48.918274538857595, 60.93186623709542, 53.650963578905376, 56.73879861831665, 53.795524324689595, 52.02312919071743, 51.12291710717337, 55.27111325945173, 52.562934739249094, 55.62670121874128, 57.97112417221069, 54.97757618767874, 56.64455325262887, 52.7732115473066, 52.19954742704119, 46.48841653551374, 47.213269983019146, 52.81360142571585, 53.52982868467058, 59.96822057451521, 57.259951727730886, 53.967832701546804, 48.629590783800396, 50.85672467095511, 46.424882207598, 40.392866134643555, 42.50116845539638, 46.254074641636436, 45.99127640042986, 43.93446717943464, 42.480657373155864, 45.53130912780762, 44.582779271262034, 42.697979654584614, 41.75384105954851, 44.10283245359148, 47.41165147508894, 49.831754207611084, 41.202682154519216, 38.59444652284895, 39.916584491729736, 37.896381855010986, 38.19480698449271, 49.5007107598441, 48.00232825960432, 43.048189708164756, 42.352647236415315, 41.87339871270316, 38.080637659345356, 34.17756005695888, 37.27632461275373, 38.58835295268467, 41.55425405502319, 46.74668107713972, 44.142819336482454, 41.74161223002842, 38.39109012058803, 38.317737988063264, 39.78278303146362, 40.06243412835257, 38.69155107225691, 42.579151562282014, 45.21251882825579, 48.122830867767334, 50.061190673283164, 43.433026109422954, 37.02158628191267, 29.501186166490825, 34.61203438895089, 49.898359639304026, 51.15329810551235, 48.85641472680228, 49.867033685956685, 50.7618157523019, 48.169411591121126, 45.944160665784565, 49.095248631068635, 51.87414591653006, 54.60568080629621, 52.41584832327706, 56.295072759900776, 54.418305260794504, 52.689211300441194, 42.78895936693464, 38.27199452263968, 65.59778308868408, 53.411757946014404, 54.08487510681152, 46.38227585383824, 46.845001561301096, 43.9624788420541, 51.1348853792463, 55.862272943769185, 63.553734234401155, 58.15850666591099, 65.95022351401192, 57.55565316336495, 61.16956411089216, 57.88002634048462, 62.42857074737549, 18.391192061560496, 0.9330911764076778, 0.36135710829070633, 3.211466725383486, 2.8704332879611423, 23.16926326070513, 68.21531541006905, 59.33896391732352, 70.65767669677734, 60.22972297668457, 36.05010305132185, 21.139755249023438, 22.474556309836252, 36.61855949674334, 50.33115598133632, 61.39060715266636, 35.53924022402082, 45.42572430201939, 67.20098263876778, 77.25015531267438, 37.13772542136056, 1.200041726231575, 0.4321120801780905, 0.2307177297770977, 0.2806686008615153, 0.24434979685715266, 0.18144827069980757], [0.05550410684996417, 0.08223812534872975, 0.1722721837993179, 0.12441193339015756, 0.047446886875799725, 0.021380390772329907, 0.11960249074867793, 0.0338694181160203, 0.0613206277734467, 0.05586338096431323, 2.6355170820440565, 62.48794310433524, 50.63881874084473, 53.72602496828352, 26.3374959060124, 37.17736142022269, 46.847280570438926, 57.68780442646572, 16.8798303263528, 6.440724747521537, 24.85586551257542, 54.64411129270281, 50.737920897347585, 47.07277045931135, 45.17879574639456, 48.74511153357369, 4.315128360475812, 0.17936786876193114, 0.12245332848812852, 0.07638518405812127, 0.23443911437477383, 0.5123582099165235, 16.251435245786393, 50.030493531908306, 57.59701926367623, 57.87875829424177, 54.4319862638201, 46.69658803939819, 45.62152453831264, 41.20762232371739, 47.13456426348005, 49.74253238950457, 56.86243486404419, 27.875304222106934, 23.8515259878976, 80.07140186854771, 49.19494138445173, 42.8901355607169, 45.700153827667236, 44.63156257356916, 50.85077701296125, 52.972451141902376, 52.76341111319405, 51.773810454777305, 51.71070344107491, 51.08274609701974, 53.2661897114345, 53.611035755702424, 50.26524536950247, 53.89677694865635, 51.03233344214303, 54.79350103650774, 48.34511068889073, 40.04047087260655, 33.93083299909319, 47.59009511130196, 53.176283495766775, 72.3571365901402, 83.21867874690464, 63.019577571323936, 48.150623662131174, 47.82600729806082, 47.66728612354824, 47.51961953299386, 53.82400499071394, 52.18000561850411, 49.58930376597813, 46.249943937574116, 47.69440146854946, 45.79768221718924, 43.55510595866612, 43.94278417314802, 40.69030809402466, 40.7317784173148, 40.96622453417097, 39.66929462977818, 39.8077826499939, 42.50219331468855, 38.74986382893154, 41.130295821598594, 41.835993085588726, 40.849751881190706, 38.70091724395752, 37.96636758531843, 37.987611702510286, 40.292339597429546, 37.385470390319824, 36.234483923230854, 36.87421498979841, 36.76518038340977, 38.264292444501606, 39.617172718048096, 39.75757496697562, 41.249829156058176, 40.24934414454869, 44.030890805380686, 43.205364908490864, 44.076245171683176, 43.702425139290945, 41.50316047668457, 36.53495182309832, 37.03863716125488, 46.08480262756348, 50.588298388889854, 52.097103187016074, 33.03631843839373, 15.645430735179357, 12.220631514276777, 26.275040285927908, 46.87040417534964, 47.05826956885201, 40.758786065237864, 45.55932426452637, 42.829085213797434, 41.696011202675955, 41.118053095681326, 46.88356406348092, 47.47065905162266, 50.74192305973598, 51.87869003840855, 52.1375139100211, 23.468900850840978, 38.45984254564558, 49.03344440460205, 53.060578618730815, 52.16155815124512, 49.48454230172293, 42.49150698525565, 40.16767154421125, 39.892943246024, 44.990308489118306, 43.43771614347185, 53.9603078024728, 52.91322817121233, 53.63901962552752, 49.42424930844988, 54.22829982212612, 51.38266508919852, 55.60627351488386, 4.074199140071869, 0.1075751454170261, 0.20094936713576317, 3.2706708056586127, 0.32234758724059376, 28.204461233956472, 59.89559800284249, 51.8253938811166, 59.77045399802071, 45.12492288861956, 41.5910621370588, 9.436871358326503, 16.6331901209695, 35.252265725817, 46.920153277260916, 36.193048340933665, 33.9089982850211, 46.273213454655235, 44.357793126787456, 55.41942950657436, 14.53539000238691, 0.1914175378956965, 0.11892293792750154, 0.06225849887622254, 0.050340893013136725, 0.17706937209836074, 0.15382642644856656, 0.03177513674433742, 0.07717896146433693, 0.2562885119446686, 0.17394402623176575, 0.1147311521427972, 0.034781922187123976, 0.06231779605150223, 0.06035397321517978, 0.06594736129045486, 0.12533962646765368, 3.184953268085207, 69.91872882843018, 55.275268282209126, 50.27541405814034, 28.41125352042062, 47.936278683798655, 41.50083630425589, 47.64573628561837, 17.960919652666362, 9.495752998760768, 30.85071393421718, 62.155569076538086, 54.164650848933626, 52.68546969549996, 51.09483943666731, 54.76837287630354, 5.922197188649859, 0.11675070306020123, 0.05459368248869266, 0.06375448538788728, 0.10302591416984797, 0.22580597762550625, 17.439780439649308, 54.28121035439627, 60.63101618630545, 58.429597582135884, 56.29010132380894, 47.67573165893555, 47.13362625667027, 43.85661956242153, 51.556585448128835, 53.346302441188264, 59.49470778873989, 25.62459683418274, 26.84764133180891, 67.84303092956543, 46.50792360305786, 44.42152547836304, 42.73009770257132, 45.99873529161726, 53.18293987001692, 55.089938981192454, 51.83043132509504, 55.2220207623073, 50.39609037126814, 51.73998314993722, 54.392701148986816, 54.91355201176235, 54.14105824061802, 55.21335983276367, 51.710852827344624, 53.115458965301514, 48.25069161823818, 42.90901034218924, 41.08071347645351, 60.475105558122905, 65.28236961364746, 75.19621917179653, 70.7952023914882, 55.754885060446604, 47.16815185546875, 49.98532329286848, 47.03821359361921, 48.194605759211946, 50.0219680922372, 51.94880083629063, 47.403820855276926, 45.99358320236206, 47.5925304549081, 42.740513052259175, 44.22939736502511, 43.530380793980186, 41.99744490214756, 41.13825498308454, 41.96089390345982, 40.62880264009748, 41.0317634173802, 42.33832005092076, 37.586627687726704, 38.703262260981965, 36.69992985044207, 40.125423022678916, 40.2433374268668, 39.28987782342093, 38.75850738797869, 41.40519435065133, 36.226472650255474, 33.4642892565046, 34.931106090545654, 34.806413718632285, 37.76585299628121, 38.756867613111226, 42.93773419516427, 40.53014516830444, 40.74056788853237, 42.36454602650234, 43.17744704655239, 44.662152017865864, 46.46232604980469, 43.52412741524832, 40.298888274601524, 39.75479916163853, 43.30200392859322, 45.58730466025216, 48.730478627341135, 39.29234790802002, 25.046850647245133, 13.715933356966291, 28.444665670394897, 45.4381685256958, 48.77952596119472, 45.436028480529785, 47.833445344652446, 45.25989164624895, 43.64085020337786, 44.50249631064278, 49.20020464488438, 51.04176909582955, 54.31334924697876, 57.869850703648154, 55.83981984002249, 25.982316153390066, 40.85240261895316, 52.386756215776714, 56.380754470825195, 55.40432759693691, 51.711547647203716, 44.42760515213013, 40.673601150512695, 42.728558676583425, 44.49085112980434, 45.80254248210362, 54.52658598763602, 55.38515056882586, 56.92883879797799, 51.56079258237566, 56.91435875211443, 54.82227005277361, 58.92462199074881, 3.6023115813732147, 0.28768291590469225, 0.04323068740112441, 2.5421317730631148, 0.9358971629823957, 32.36864866529192, 67.89897782461983, 57.140352385384695, 63.43776879991804, 51.23790284565517, 45.447503430502756, 13.148718902042933, 20.76085434641157, 39.17541319983346, 53.501514775412424, 39.45295899254935, 37.070564133780344, 44.114265714372905, 50.59393685204642, 64.94931466238839, 21.157412358692714, 0.3473617807030678, 0.07373561337590218, 0.25375936765755924, 0.01931612948620958, 0.13464246370962688, 0.023440904848809754, 0.0911035585616316, 0.24307325535586902, 0.3152715526521206, 0.21050187812319823, 0.13934123728956493, 0.05650759568171842, 0.1824269081865038, 0.1830372368650777, 0.16455639925386223, 0.21190447786024638, 3.9857351098741804, 85.09767314365932, 63.62138884408133, 65.9127449308123, 36.78873477663313, 53.463740893772666, 65.72859682355607, 62.26299517495291, 21.80823622431074, 14.218401891844612, 35.9393835067749, 69.11542674473354, 60.31674221583775, 60.7666380746024, 57.482613699776785, 61.961839403424946, 7.402972085135324, 0.31384220506463734, 0.493270639862333, 0.24223765305110387, 0.33493699026959284, 0.9400116907698768, 21.32420560291835, 58.22748490742275, 64.61202825818742, 63.17846897670201, 60.10533632550921, 50.72063030515398, 50.961833545139854, 46.49810927254813, 53.03299427032471, 54.13751813343593, 63.40946878705706, 31.553840364728654, 27.894623688289098, 69.65929698944092, 44.606531688145225, 42.17991501944405, 42.62888329369681, 43.65222093037197, 54.83455099378313, 58.555610111781526, 56.03731196267264, 56.14583240236555, 51.62365640912737, 52.47787489209856, 54.93569592067173, 55.17933450426374, 55.441573415483745, 60.21115739004952, 53.847086906433105, 54.939479214804514, 49.687186513628276, 47.65422698429653, 50.48824085508074, 69.80492428370884, 68.04114491598946, 76.16561099461147, 71.22960376739502, 53.23903267724173, 48.485537256513325, 52.56858015060425, 52.97600861958095, 50.84727512087141, 56.859978675842285, 55.717653138296946, 55.345549310956685, 51.52904626301357, 52.09847893033709, 48.51761014120919, 49.27240685054234, 47.973993505750386, 44.98603534698486, 45.77622617994036, 45.36166885920933, 42.34208944865635, 43.891183376312256, 46.4149671282087, 40.75731652123587, 42.347675800323486, 43.58113738468715, 44.855110440935405, 42.758717332567485, 40.49443142754691, 40.78298316683088, 41.63413749422346, 36.54192781448364, 37.30411045891898, 39.573225361960276, 35.90024083001273, 41.592406613486155, 41.09264700753348, 44.46524701799665, 43.88668441772461, 41.535997663225444, 41.51918649673462, 44.75375359398978, 46.23567581176758, 47.45260763168335, 45.952734742845806, 42.74530383518764, 41.409978185381206, 41.639459814344136, 44.72529377256121, 47.4839266368321, 46.40489224025181, 36.61021818433489, 28.35962666784014, 35.300121443612234, 55.736107553754536, 50.28507205418178, 46.83236278806414, 48.15457023893084, 48.64665903363909, 46.50419242041451, 47.904490675245015, 48.986960956028526, 51.94163029534476, 55.85646077564785, 59.23717975616455, 55.02965988431658, 31.38598578316825, 41.352009364536826, 52.55497210366385, 61.860152517046245, 57.14212417602539, 55.0527035849435, 47.864889417375835, 46.99151127679007, 47.14014366694859, 51.053598403930664, 49.40054900305611, 60.099478994097026, 58.622111320495605, 60.52509784698486, 55.14843586512974, 60.907714298793245, 58.5743077141898, 64.69182137080601, 6.835781080382211, 0.5153920214091028, 0.6651680959122521, 10.052962047713143, 1.2443263956478663, 36.6096727507455, 70.69794150761196, 60.57037230900356, 69.70540523529053, 53.49778706686837, 53.843074321746826, 18.932034628731863, 24.830869368144445, 45.460510458265034, 66.69800254276821, 54.88493585586548, 47.27928134373256, 67.97006484440395, 59.38871301923479, 75.47765595572335, 28.787826776504517, 0.625107008431639, 0.1696240244699376, 0.2432326025196484, 0.16778199188411236, 0.23946271623883927, 0.3374035736279828], [0.11617975655410971, 0.03161006274500063, 0.24178838144455636, 0.10573770651327712, 0.034481409205389876, 0.012421117862686515, 0.020853560916813355, 0.06766957137733698, 0.27130796600665363, 0.09899339412472077, 0.5503452601177352, 60.564855439322336, 47.50195721217564, 58.07437787737165, 37.05185958317348, 36.99785818372454, 34.81171519415719, 29.036388158798218, 29.326195784977504, 3.392976688487189, 24.32408513341631, 50.79064382825579, 51.13003553662981, 51.96170711517334, 42.449307101113455, 51.431927817208425, 19.377546174185618, 0.09631046666098492, 0.2128966860473156, 0.1863289052354438, 0.18049110206110136, 0.7100063413381577, 7.493355120931353, 42.95516722542899, 63.794628279549734, 55.408388819013325, 54.600691999707905, 48.3799489566258, 45.180418150765554, 42.87224742344448, 48.23392561503819, 58.195665631975444, 43.583906241825645, 23.67608223642622, 39.798621450151714, 50.991095883505686, 56.43465859549386, 65.1344633102417, 45.172264439719065, 42.26344626290457, 45.501157420022146, 50.08124317441668, 52.230810846601216, 52.276738439287456, 53.85520935058594, 52.210751397269114, 52.7108862059457, 55.51358107158116, 55.90794692720686, 53.06822511128017, 48.49938154220581, 45.11564704350063, 38.66358457292829, 37.63439655303955, 52.89027827126639, 85.6709064756121, 121.69539151872907, 97.07697895595005, 61.38091441563198, 51.94591038567679, 51.46416745867048, 56.13908222743443, 49.74816043036324, 51.97394636699131, 53.931799343654085, 53.512249742235454, 61.56641742161342, 54.59634242738996, 51.880614689418245, 51.54859849384853, 52.87042726789202, 51.45495762143816, 52.54075608934675, 48.86991507666451, 40.292930194309776, 42.30393689019339, 38.97286626270839, 42.08493314470564, 40.43144948141915, 41.62273550033569, 39.592885289873394, 40.13117960521153, 41.592483043670654, 42.298649311065674, 41.81869207109724, 44.05166244506836, 47.64396449497768, 49.22550303595406, 47.54279177529471, 43.54326275416783, 47.35592344829014, 45.34126199994768, 43.33326039995466, 48.21321998323713, 45.17044748578753, 45.87904909678868, 48.29065418243408, 47.502117020743235, 49.256446838378906, 48.11387463978359, 45.728690079280305, 40.68485375813076, 43.009498664310996, 38.82608209337507, 52.185994965689524, 67.06670175279889, 45.42040893009731, 19.782714741570608, 15.489335979734149, 33.3819009917123, 48.830626487731934, 43.832940101623535, 45.502286502293174, 43.25697612762451, 44.71764728001186, 43.82444940294538, 46.76925924846104, 49.49299478530884, 50.9881637437003, 48.91073226928711, 51.86263969966343, 32.72162062781197, 36.662746565682546, 52.42281041826521, 51.92227608816964, 54.07013102940151, 48.678238596235005, 43.92028243201119, 39.729848180498394, 39.72666243144444, 41.287359850747244, 41.99162925992693, 44.667682783944265, 47.16161012649536, 50.18058851787022, 48.86305373055594, 52.05985736846924, 59.18547821044922, 47.27630056653704, 0.6631789026515824, 0.1312117635139397, 0.19643469367708477, 3.3083326475960866, 2.7472313046455383, 53.08755847385952, 50.94122518811907, 58.946140561785015, 52.6085844039917, 55.347008432660786, 41.240713119506836, 3.962871628148215, 19.993524823869976, 18.68789403779166, 25.347353288105555, 46.93221535001482, 26.294569935117448, 28.377493960516794, 48.01070083890642, 55.628580706460134, 10.908581461225237, 0.6033487245440483, 0.46221805470330374, 0.1918355833206858, 0.10778460917728287, 0.11801621158208166, 0.07182333884494645, 0.06646314289953027, 0.07034623596285071, 0.2050938590296677, 0.12957985965268953, 0.03912024439445563, 0.0919483278744987, 0.01578908071054944, 0.13863433950713702, 0.27883074805140495, 0.0510608695580491, 0.46287672221660614, 66.03675637926374, 54.464097363608225, 54.972003732408794, 31.97175713947841, 49.30643565314156, 34.92297669819423, 41.38224445070539, 32.51779522214617, 6.336373661245618, 24.36966531617301, 58.61696965353829, 55.60317114421299, 58.149960381644114, 48.21289341790335, 61.41867787497384, 25.058355127062114, 0.02564180612431041, 0.24338684710008757, 0.13926165870257787, 0.06525076366961002, 0.33684910195214407, 10.0015002148492, 46.627463885716026, 64.70694065093994, 56.42585175377982, 59.24011884416853, 50.096119267599924, 47.79336813517979, 47.0665066582816, 51.09030226298741, 61.56695243290493, 45.357315812792095, 32.998662676130024, 44.83749328340803, 45.08909102848598, 56.400452613830566, 59.00873688289097, 47.807316643851145, 42.60572494779314, 44.805434295109336, 52.316106932503835, 53.53592225483486, 53.73582887649536, 54.0735182762146, 56.02540275028774, 55.082504408700125, 56.847305161612375, 54.084611075265066, 52.036417620522634, 48.82009301866804, 46.94524669647217, 42.21704271861485, 46.82072455542428, 66.09093148367745, 91.63941601344517, 110.4580351965768, 77.49964427947998, 56.83912713187081, 52.514391149793354, 51.44414275033133, 55.5055559022086, 51.91420922960554, 54.494683333805625, 52.29124627794538, 54.66567850112915, 61.60217979976109, 59.38040297372, 53.593310901096885, 56.46213524682181, 54.80105720247541, 52.27282312938145, 52.34071397781372, 46.46703692844936, 40.87019695554461, 43.420258794512065, 39.469394956316265, 43.036878040858674, 41.13349199295044, 42.630818367004395, 37.728683607918875, 41.66216652733939, 41.02900498253958, 43.29744243621826, 41.12707533155169, 41.85480533327375, 43.380178110940115, 44.36074611118862, 43.71718658719744, 43.29983261653355, 44.34480694362095, 43.147594111306326, 43.958935260772705, 50.01244906016758, 45.25786624635969, 44.1981964792524, 50.11355229786464, 50.485107217516216, 49.823454584394185, 50.10312305177961, 46.8494553565979, 45.26542936052595, 44.60591329847063, 38.607759271349224, 44.00337246486119, 56.00710466929844, 52.19363451004028, 37.45335776465279, 21.008357865469797, 35.32224798202515, 49.81901468549456, 46.78576122011457, 48.346027851104736, 46.93736743927002, 48.72939818246024, 48.87717247009277, 50.94971588679722, 51.57806927817208, 53.71703052520752, 52.53969301496233, 55.878899982997346, 34.72806930541992, 37.632777622767854, 57.43470239639282, 53.32246664592198, 54.66898584365845, 49.16049568993704, 45.44385215214321, 41.64324310847691, 41.88102783475603, 42.45068631853376, 43.914258343832834, 49.593681131090435, 49.10220030375889, 53.30388021469116, 53.303744724818635, 54.88250746045794, 59.53493785858154, 49.30943727493286, 0.18827285378107003, 0.03036675588893039, 0.7322930682982717, 2.0905731235231673, 3.8788587876728604, 58.587286949157715, 56.688594409397666, 65.81625529697963, 58.08667618887765, 61.2241005216326, 40.060224601200645, 9.001061235155378, 23.867882047380718, 21.55625285421099, 29.433420385633195, 55.660893304007395, 30.958164351327078, 34.53409991945539, 51.95344223294939, 65.85173974718366, 14.468331200735909, 0.8931341490575245, 0.28704995129789623, 0.17153045002903256, 0.10046497373176472, 0.06690443493425846, 0.16718608886003494, 0.14582347231251852, 0.12436834430055958, 0.2930488522563662, 0.20736442719187054, 0.1325924058577844, 0.17251258875642503, 0.1753748801669904, 0.3423852691692965, 0.40084863347666605, 0.19287763669022492, 1.1091571173497607, 81.75959873199463, 61.8811708177839, 74.04725810459682, 51.35605696269444, 51.82917717524937, 49.5769533429827, 33.27736186981201, 36.593542507716585, 10.781917537961688, 35.85431323732649, 63.599800791059224, 60.312948499407085, 64.29994297027588, 56.74261665344238, 65.40557507106236, 25.000608648572648, 0.2530701660684177, 0.5860092235463006, 0.15865553303488664, 0.5100667157343456, 1.0462289111954826, 14.934973955154419, 52.04338318961007, 68.15544973100934, 59.14339297158377, 60.149471282958984, 50.646090030670166, 49.14006103788103, 47.98113972800118, 52.828241280147004, 60.971616881234304, 43.724499566214426, 29.23546620777675, 40.30661467143467, 62.49316814967564, 56.62946176528931, 54.34234060559954, 48.50126102992466, 42.45037017549787, 44.35868944440569, 52.823353222438264, 54.80794286727905, 55.513827732631135, 56.8030868257795, 56.543495178222656, 56.48878853661673, 60.1688289642334, 57.537365504673545, 55.04400096620832, 52.779253005981445, 52.509329387119834, 46.61578048978533, 51.41603033883231, 71.48151765550885, 91.23357173374721, 100.18029458182198, 68.62043012891496, 58.875164713178364, 59.26003932952881, 56.71761703491211, 60.42197963169643, 54.82818644387381, 57.214288166591096, 55.82646887642996, 57.184907708849224, 66.54129981994629, 62.320838928222656, 57.92395632607596, 59.84282643454415, 60.55488477434431, 59.72363008771624, 59.24975599561419, 55.56355251584734, 43.92120654242379, 46.191846575055806, 42.25352770941598, 47.001582690647666, 42.983112880161826, 44.33815751756941, 40.26930284500122, 45.074937547956196, 45.04931953975132, 47.854220458439414, 43.46900735582624, 43.84616947174072, 49.3452969278608, 50.70971815926688, 52.03259611129761, 47.28962026323591, 50.11594942637852, 47.42506497246878, 50.33027703421456, 56.84441818509783, 48.36270352772304, 47.606322629111155, 52.46641731262207, 55.1398617880685, 53.04702615737915, 52.36876038142613, 50.508029324667795, 49.06750447409493, 47.99544606889997, 39.323993478502544, 43.27860934393746, 55.33777775083269, 54.02859469822475, 47.66282538005284, 32.50817196709769, 42.43608120509556, 56.69980880192348, 49.269933291843955, 51.473533630371094, 47.42503717967442, 50.831019810267854, 50.85179839815412, 54.305403981889995, 52.98971741540091, 53.25978347233364, 53.278362955365864, 56.977326801845, 36.34547792162214, 39.59713411331177, 53.45973873138428, 55.61009155000959, 57.87484993253435, 56.47439881733486, 49.006909234183176, 42.88762378692627, 45.9810208593096, 47.31753117697579, 46.64162431444441, 50.42339331763131, 50.621872084481375, 53.76449366978237, 55.020839146205354, 57.09789889199393, 63.24052333831787, 53.99793577194214, 1.1766100121395928, 0.22408422215708665, 1.797877652304513, 11.367044448852539, 3.6015800663403104, 62.353627477373394, 62.713974952697754, 71.16307476588658, 64.10820743015834, 66.71049540383476, 51.81112575531006, 11.180992535182408, 28.55029218537467, 24.856087854930333, 36.936463900974815, 68.31952449253627, 35.26442159925188, 49.19360385622297, 61.02062252589634, 79.6091868536813, 21.705154487064906, 1.1366890285696303, 0.5625505851847785, 0.2701878403978688, 0.13615508111459868, 0.15270816002573284, 0.19077043261911186], [0.03694934284846697, 0.0601327707991004, 0.048612555755036216, 0.09813843321587358, 0.11398526573819773, 0.07405052826340709, 0.24211481107132776, 0.21378624545676367, 0.11291970113026244, 0.20012310147285461, 0.15350470585482462, 41.93253483091082, 55.448483398982454, 48.9258793422154, 50.36381598881313, 23.362409285136632, 33.21121154512678, 4.02775216954095, 27.912933928625925, 8.250812121800013, 3.739612979548318, 45.722627776009695, 57.14497988564627, 48.86169883183071, 51.83704948425293, 47.84723057065691, 16.311179331370763, 0.1361761564122779, 0.03350706006001149, 0.231532378920487, 0.11511467370603766, 0.20061651856771537, 4.253082684108189, 37.48942586353847, 63.38885348183768, 57.51428358895438, 57.652340820857454, 57.58144835063389, 45.0700112751552, 41.13533673967634, 43.333725929260254, 56.86743061883109, 55.79325301306588, 61.95906707218715, 51.033483369009836, 22.459614208766393, 44.675812176295686, 82.27172265733991, 47.2227577481951, 39.61013419287545, 43.15630367824009, 48.91087123325893, 53.07102870941162, 51.289409841809956, 50.92446960721697, 53.37689535958426, 54.992886543273926, 49.71003566469465, 50.516766684395925, 43.21869502748762, 39.64274556296212, 36.2392886025565, 43.6561918258667, 53.824585165296284, 76.25766767774309, 98.81432737622941, 76.58125223432268, 51.2964448928833, 52.313619477408274, 57.52814177104405, 54.68833310263497, 49.71915170124599, 54.54257379259382, 53.42399024963379, 49.86197887148176, 54.898474420819966, 58.35050623757498, 54.66910743713379, 45.95214067186628, 50.64741366250174, 50.41267572130476, 52.521808351789204, 48.53534541811262, 55.671680382319856, 48.30579778126308, 46.0019314629691, 34.51028496878487, 34.66054323741368, 43.72036191395351, 34.59120716367449, 22.944339650017874, 35.00242587498256, 46.22126177379063, 42.10722643988473, 45.731125422886436, 51.28729411533901, 56.16533599581037, 50.595941407339915, 52.96511384419033, 51.892937319619314, 51.18427664893014, 51.01952791213989, 52.877239976610454, 52.346376759665354, 51.441940171378, 50.023614815303254, 50.03305046898978, 48.298529965536936, 49.533759866442, 51.895004408700125, 52.45588731765747, 49.04543004717146, 47.07862779072353, 43.95809800284249, 42.034318992069785, 54.26301997048514, 87.9950372150966, 68.6649055480957, 30.861664295196533, 21.752350125994, 42.96312638691494, 45.226741790771484, 43.70544065747942, 45.21927942548479, 45.28159434454781, 49.31511395318167, 50.33931316648211, 48.35883338110787, 47.36385481698172, 48.16150106702532, 49.16097511563982, 39.32225295475551, 44.65639543533325, 53.34331471579415, 56.516077586582725, 49.72200741086687, 47.79511213302612, 45.384372098105295, 43.48581504821777, 43.01880577632359, 42.15723262514387, 42.47663089207241, 43.53786052976336, 47.16700887680054, 51.462121214185444, 54.631357874189106, 52.98814364842006, 61.30804170880999, 27.616456031799316, 0.30794014462402886, 0.2521117217838764, 0.1402779006000076, 1.0597508656127113, 8.676073142460414, 65.4389750616891, 43.828437668936594, 61.91502938951765, 42.52656064714704, 68.03725392477853, 8.421533703804016, 9.702547022274562, 26.618936164038523, 25.645905222211564, 41.17903396061489, 53.924399512154714, 25.91778302192688, 32.59119599206107, 41.658178261348176, 52.40162536076137, 4.487809334482465, 0.1562793848237821, 0.09124765904354197, 0.024189729310039963, 0.03125748237861054, 0.03896648496655481, 0.04521824199972408, 0.031236145844949142, 0.026805095041968992, 0.04302717778565628, 0.011853351989494902, 0.12253579763429505, 0.1476952518735613, 0.2524341887661389, 0.15458542214972631, 0.34471799113920754, 0.15416276268661022, 0.21914304872708662, 48.02805396488735, 64.0115579877581, 55.2443140574864, 39.333752223423545, 31.60572256360735, 39.304892880576, 6.519085228443146, 30.12925468172346, 9.476069620677404, 6.326687438147409, 47.45721428734915, 64.1209990637643, 53.18721648624965, 56.62960420336042, 52.749240262167795, 24.38398207936968, 0.203604786789843, 0.10939457600138017, 0.2817489371768066, 0.11924454995564052, 0.7661933835063661, 5.1809234108243665, 43.31081077030727, 67.94496100289481, 57.67712851933071, 60.59746333530971, 56.9772503716605, 47.87735448564802, 45.917229448046, 49.962012086595806, 57.589949471609934, 58.25410345622471, 57.86164140701294, 49.34594311032976, 26.109374386923655, 48.347605092184885, 72.64376367841447, 47.880317892347065, 43.62553637368338, 44.72983094624111, 48.55885464804513, 53.93717377526419, 53.44796848297119, 53.869904790605815, 53.96228803907122, 57.543163776397705, 52.09673145839146, 51.675910336630686, 41.33724444253104, 41.15316581726074, 43.47431230545044, 53.19001661028181, 66.17560917990548, 78.7140087400164, 82.25699942452567, 63.48588507516043, 48.62314632960728, 56.03693675994873, 54.92206702913557, 55.08268853596279, 54.754476479121614, 54.52801384244646, 53.68643760681152, 53.50463451657976, 58.83678981236049, 63.122911180768696, 55.35292829786028, 51.66795464924404, 56.55717618124825, 53.50285925183977, 58.02556678227016, 52.1926965032305, 56.7830308505467, 46.30264254978725, 47.30625772476196, 35.197381905147004, 35.60108266557966, 42.92585277557373, 35.78690876279558, 27.605151312691824, 38.68662479945591, 46.00093787057059, 44.70030457632882, 46.184735093797954, 48.240217208862305, 54.64000143323626, 51.036172321864534, 52.530827113560264, 48.94284336907523, 51.302597522735596, 54.668339661189485, 49.018999099731445, 52.0639568056379, 50.1091228212629, 52.08158785956246, 53.28749636241368, 51.26635571888515, 48.63431208474295, 53.916099888937815, 52.72498410088675, 46.250972270965576, 47.53342907769339, 50.00688355309622, 42.81491436277117, 43.687705380576, 70.32987458365304, 81.9174131665911, 55.356774125780376, 25.314787081309728, 42.16076578412737, 48.62511961800711, 48.43174777712141, 51.600831576756065, 48.884186676570344, 50.07189089911324, 52.2935391834804, 52.357490403311594, 49.357779366629465, 48.09088999884469, 50.431307315826416, 42.674560751233784, 45.756517614637104, 56.1038235936846, 57.794243880680625, 52.42116716929844, 50.27637638364519, 46.85409327915737, 45.13710308074951, 44.30930164882115, 47.24966812133789, 47.490909576416016, 46.13918965203421, 52.039301122937886, 55.64944267272949, 58.89751706804548, 56.78446912765503, 63.240474700927734, 29.36132935115269, 0.2163112371095589, 0.3137120349066598, 0.10887191404721566, 0.9225569473845618, 11.992219907896859, 71.14554446084159, 50.390239988054546, 69.51867934635708, 49.26642445155552, 66.12397016797746, 9.440361091068812, 13.998295988355364, 30.289094516209193, 28.01622584887913, 40.83337845121111, 62.49519007546561, 29.213874680655344, 35.84816060747419, 48.022724696568076, 58.118891511644634, 4.706033144678388, 0.355935450643301, 0.17868288766060555, 0.051697209876562865, 0.039082948717155626, 0.03915185734097447, 0.028820503503084183, 0.0927465632557869, 0.21293298767081328, 0.24272608969892773, 0.20203366609556334, 0.2060640419700316, 0.255721745214292, 0.3475565473948206, 0.5941882846610886, 0.39759321244699614, 0.446882783302239, 0.41158973425626755, 60.70058849879673, 74.3302721296038, 63.827729497637065, 60.759940011160715, 35.65128340039934, 47.81566143035889, 4.383369658674512, 35.559376103537424, 14.57629578454154, 10.760812384741646, 57.013551235198975, 69.51140458243233, 58.74192605699812, 62.674161774771555, 58.7339425768171, 26.075401169913157, 0.3570719153753349, 0.33981978254658834, 0.32694327778049875, 0.29673677150692257, 1.4796350662197386, 9.118940029825483, 47.61154072625296, 70.23172433035714, 59.87905434199742, 62.832295826503206, 61.941995348249165, 50.27595601763044, 49.01777621677944, 49.57162060056414, 60.93076842171805, 55.70034864970616, 50.464165346963064, 54.44173111234392, 26.959648030144827, 50.10555144718715, 74.69392694745744, 46.5447073663984, 43.94697741099766, 43.9867593220302, 48.99404117039272, 55.55967542103359, 54.37863104684012, 53.686027663094656, 54.277687617710654, 57.753350257873535, 54.500797748565674, 56.19465044566563, 45.67988245827811, 44.86791249683925, 46.17972544261387, 52.7784435408456, 61.19418157849993, 76.22922175271171, 77.75988210950578, 56.54288026264736, 53.53562348229544, 58.277042933872764, 57.432166303907124, 57.54828807285854, 59.13761901855469, 60.889801842825754, 57.10104295185634, 58.21064942223685, 62.763480867658345, 63.813805307660786, 55.588691098349436, 55.8199132510594, 60.125882148742676, 58.742857115609304, 61.945295742579866, 54.56570087160383, 62.016889980861116, 51.603867939540315, 50.860004220690044, 37.792801584516255, 36.460053716387065, 44.9412715775626, 39.212276867457796, 28.959085975374492, 44.57759938921247, 47.68791879926409, 47.085961614336284, 51.636864934648784, 51.893100602286204, 57.9528226171221, 55.46385281426566, 57.21085923058646, 57.42613526753017, 57.17456184114729, 59.423857007707866, 55.044480391911094, 55.154543331691194, 54.48069313594273, 56.501493317740305, 56.25138248716082, 55.00083875656128, 49.87743166514805, 55.00353813171387, 54.50075953347342, 52.13270575659615, 52.347571849823, 53.21507181440081, 43.93890013013567, 42.15244879041399, 65.67387975965227, 74.98987851824079, 65.5270573752267, 33.58764410018921, 50.19396380015782, 52.129123960222515, 50.79947846276419, 50.656929220472065, 51.0423457963126, 52.354738916669575, 53.312329224177766, 52.603734561375205, 51.98258645193917, 52.27368470600673, 49.765982559749055, 44.96460362843105, 44.14854465212141, 54.75909355708531, 60.77483694893973, 56.234154428754536, 50.48959922790527, 50.572453022003174, 48.03132656642369, 47.242838042122976, 47.85142033440726, 50.72881875719343, 49.02511004039219, 53.28962598528181, 57.34752682277134, 59.89386095319475, 59.94953686850411, 62.09899684361049, 36.05092988695417, 0.3532860699508871, 0.4142637593405587, 1.0109678890023912, 4.405461021832057, 11.161674806049891, 77.89492729731968, 54.70511300223214, 72.33242879595075, 53.138158730098176, 75.48395797184536, 14.435706802776881, 17.283147198813303, 36.69866875239781, 37.80943557194301, 65.18676934923444, 67.75879791804722, 34.48555285590035, 49.94603817803519, 56.237110887254985, 75.35734094892229, 11.010011264256068, 0.7598843106201717, 0.38175954350403374, 0.11060469570968832, 0.31698577638183323, 0.1673693068857704, 0.2089872658252716], [0.19335585460066795, 0.07473351447177784, 0.03170892529721771, 0.016100265351789336, 0.04785345827362367, 0.10434438913528409, 0.23746896322284425, 0.10767001818333354, 0.10050440340169839, 0.15946731876049722, 0.12428377169583525, 25.33301568031311, 66.76783888680595, 44.157851764133994, 53.320458616529194, 23.65750449044364, 39.381792068481445, 34.83441495895386, 19.37303853034973, 10.511254804474966, 19.949824128832134, 40.26625605991909, 59.11810152871268, 51.55047798156738, 50.93846675327846, 52.93074457986014, 30.308691910334996, 0.3497093218777861, 0.07424733056021587, 0.11152889433183841, 0.20911921374499798, 0.42192118987441063, 2.2831700231347765, 37.99107885360718, 57.56721843991961, 59.907924107142854, 53.90136970792498, 54.007715361458914, 47.850645610264365, 45.86160911832537, 42.77108860015869, 53.79787628991263, 60.67598492758614, 61.064632415771484, 49.318480355399, 46.90803214481899, 44.72910138538906, 56.36833456584385, 58.00591727665493, 44.0968257359096, 46.21706853594099, 44.408153670174734, 52.83732604980469, 50.25404487337385, 52.817058154514854, 53.16979387828282, 54.511834962027415, 46.576029845646445, 35.81893995829991, 32.61319746289934, 38.12498801095145, 46.97466189520699, 59.54085772378104, 65.03085177285331, 68.46560341971261, 54.77479648590088, 46.93927819388253, 56.218006815229145, 54.39164502280099, 50.451696804591585, 52.0834812436785, 49.487898281642366, 47.99212482997349, 49.04391533987862, 49.68039117540632, 45.02811711175101, 48.45882838112967, 48.49867630004883, 51.852738516671316, 50.019327776772634, 50.67141274043492, 49.97332027980259, 51.71159628459385, 49.94827897208077, 50.650985036577495, 47.77563285827637, 42.21284948076521, 25.753574507577078, 31.782133851732524, 41.85665702819824, 15.189481258392334, 39.47163922446114, 43.82686390195574, 44.63077047892979, 50.771261828286306, 55.114817006247385, 53.07870994295393, 50.42128106525966, 50.437609331948416, 49.98709855760847, 51.51102263586861, 48.41755608149937, 49.844024726322715, 46.56842851638794, 47.76685380935669, 48.20475360325405, 48.535633768354145, 48.440301009586875, 49.88726684025356, 47.78678124291556, 51.85347849982125, 52.31732634135655, 49.38791370391846, 44.883743967328755, 49.96184532982962, 45.037889753069194, 55.24849687303816, 92.05049228668213, 82.1323904309954, 26.750406503677368, 25.82848824773516, 51.759910583496094, 44.66745696749006, 45.28278596060616, 44.336149488176616, 47.30026142937796, 45.37862593787057, 47.247639247349326, 41.12174606323242, 41.120967864990234, 41.75943088531494, 44.53306143624442, 43.412574086870464, 49.1127268246242, 54.068574632917134, 53.97363097327096, 49.737633909497944, 47.915020670209614, 48.05615595408848, 45.123335225241526, 43.57739577974592, 43.869769028254915, 44.12354850769043, 51.126137597220286, 49.49076788766043, 56.452261856624055, 53.71347999572754, 62.55150522504534, 10.860784803118024, 1.1195473883833205, 0.1934685864086662, 0.1774012435759817, 0.23875934683850833, 19.89720368385315, 58.30473150525774, 47.27980245862688, 55.13836097717285, 45.85822534561157, 46.42564303534371, 3.56989106961659, 31.221118927001953, 17.696615389415197, 22.07884771483285, 39.876819951193674, 46.983979429517476, 23.23217919894627, 36.24264458247593, 45.684169496808735, 39.81342111315046, 0.2454808604504381, 0.1154674304915326, 0.034027781404022656, 0.09771687976483788, 0.027897809532337954, 0.05119500236053552, 0.14324019450162137, 0.04655196025435414, 0.07577448218528714, 0.06307023031903164, 0.06579128466546535, 0.1274513631526913, 0.04412794139768396, 0.06640869046428374, 0.11086473747023515, 0.11826513893902302, 0.18949820660054684, 0.15628627873957157, 30.49354178564889, 76.95762920379639, 45.31454965046474, 49.21735279900687, 28.27636293002537, 45.54114430291312, 16.327167136328562, 28.3367531980787, 13.71869787148067, 25.06354022026062, 48.92497955049787, 60.78735760280064, 58.994993346078054, 53.41273764201573, 55.173126288822715, 33.27121271405901, 0.6342666340725762, 0.22808183836085455, 0.08941686978297574, 0.5310032665729523, 0.3913779402417796, 2.5745281832558766, 43.53385836737496, 62.43482412610735, 61.971782275608604, 59.70050648280552, 53.86024332046509, 50.266027041843955, 47.792336327689036, 47.74980640411377, 57.22720834187099, 61.7940126146589, 55.95621953691755, 52.1797068459647, 48.066484451293945, 47.13134724753243, 54.693533829280305, 54.64398969922747, 46.32988296236311, 46.42254761287144, 45.453843661717, 51.34991822923933, 50.919963700430735, 54.34762471062796, 54.73894030707223, 54.663316113608225, 43.65693528311593, 34.33237634386335, 39.792517457689556, 46.64635256358555, 52.387023721422466, 63.83664403642927, 64.43102768489292, 60.474077224731445, 50.44818101610456, 50.28132002694266, 57.25934028625488, 53.632734979902, 49.29573195321219, 52.64150496891567, 50.89190340042114, 51.130501065935405, 51.12814910071236, 50.02096060344151, 46.69069249289376, 51.85242584773472, 51.12350422995431, 51.91947249003819, 53.879920618874685, 53.40305880137852, 53.60772841317313, 51.448162283216206, 49.76734093257359, 49.38106625420706, 49.46102612359183, 41.511661597660606, 30.54789059502738, 37.278204100472585, 44.361975942339214, 21.975093739373342, 46.12761742728097, 46.813067640577046, 45.230215890066965, 51.016939708164756, 52.64238044193813, 52.98364816393171, 52.347318240574424, 51.87444468906948, 52.09843029294695, 52.93107114519392, 53.217538424900596, 51.407702922821045, 52.87921673910958, 49.83349125725882, 49.39768287113735, 49.914215428488596, 49.371797357286724, 49.8565662247794, 46.864129952022004, 49.551456928253174, 50.68051140648978, 47.284565448760986, 48.125471183231895, 54.96715388979231, 46.83387054715838, 47.88173532485962, 69.64565767560686, 82.95742647988456, 35.482584612710134, 27.533435480935232, 53.144776889256065, 47.653837885175435, 51.77801411492484, 50.77570867538452, 51.11089324951172, 46.91034936904907, 49.91854763031006, 46.09958839416504, 43.783298696790425, 43.993843010493684, 42.421969413757324, 42.00457375390189, 53.72515991755894, 54.5642660685948, 57.454692363739014, 52.887238434382844, 49.48243352345058, 49.02845559801374, 46.658602237701416, 45.194411822727744, 47.564946106501985, 48.0974178314209, 56.77621814182827, 53.886917454855784, 59.316264152526855, 56.32661758150373, 67.04066685267857, 11.233598215239388, 2.0204056543963294, 0.02447858845282878, 0.5572021550365857, 0.31769080140760964, 24.099673952375138, 66.83352020808628, 53.662685189928325, 65.69040952410016, 49.30716521399361, 49.42219264166695, 6.348516506808145, 31.427129541124614, 23.039568185806274, 23.48496856008257, 45.5171799659729, 60.06402928488595, 26.980322395052227, 35.25478792190552, 54.40392248971121, 44.307352679116384, 1.2283275169985635, 0.14453570784202643, 0.06479170758809362, 0.018806709142934, 0.11329016089439392, 0.07212702397789274, 0.014294441090896726, 0.19340650045445987, 0.18810560846967356, 0.14074121788144112, 0.11167372763156891, 0.1878403284187828, 0.32747185656002586, 0.18202626039939268, 0.22635335182504995, 0.36438180027263506, 0.37018995146666256, 0.25905810190098627, 38.35397284371512, 88.46784823281425, 53.329727513449534, 67.62156404767717, 39.663666588919504, 55.106308937072754, 42.00160687310355, 26.868756907326834, 17.198054347719463, 28.5395085811615, 51.47608709335327, 71.07627092088971, 63.40504278455462, 63.3690858568464, 63.39822660173689, 40.18309654508318, 0.6647996242557253, 0.5878006645611354, 0.19823578345988477, 1.5048653866563524, 0.7973418863756316, 4.198662221431732, 53.195620332445415, 61.47538212367466, 61.35365663255964, 63.70932524544852, 58.51952811649868, 51.32330315453665, 51.207497528621126, 50.34434018816267, 58.20489631380354, 65.51974092211042, 59.91877719334194, 49.952562536512104, 49.989888259342735, 44.432746819087434, 60.5548152923584, 53.6293477330889, 44.62940168380737, 46.68993861334664, 45.202430043901714, 53.58659546715872, 56.09539195469448, 57.59957272665841, 57.490107331957134, 56.154173714774, 50.54516397203718, 41.8104966708592, 40.32213347298758, 47.37419373648507, 50.92314944948469, 60.614013944353374, 60.369305338178364, 58.83445521763393, 53.05295297077724, 54.491640022822786, 60.24216720036098, 55.79741498402187, 52.35255718231201, 56.298216819763184, 54.62363495145525, 54.187572956085205, 52.67538438524519, 53.773418630872456, 48.60503237588065, 54.18377576555525, 53.95646892275129, 57.548361028943745, 57.18259743281773, 58.35311876024519, 57.8911052431379, 56.89689792905535, 53.01407779966082, 54.10991988863264, 51.63325187138149, 46.97338342666626, 33.004836150578086, 40.463689122881206, 46.929071290152415, 30.64217417580741, 50.65116916384016, 48.166017396109446, 51.43928248541695, 55.15486294882638, 59.23003005981445, 57.772944177900044, 56.660297870635986, 57.782900946480886, 58.40664768218994, 58.920355796813965, 54.822127614702495, 57.716931274959016, 57.94216060638428, 53.784170968191965, 53.78440720694405, 55.36383696964809, 53.78795773642403, 52.31757647650582, 48.34954363959176, 50.9624901499067, 53.89332021985735, 51.71217993327549, 49.957381112234934, 55.17850766863142, 48.16687897273472, 46.25936222076416, 63.66104221343994, 72.31897708347866, 36.896515233176096, 29.847942965371267, 59.023369789123535, 48.49298225130354, 53.52698687144688, 49.86509166445051, 51.59595741544451, 50.28319256646292, 54.794560636792866, 50.12504114423479, 43.296372413635254, 42.556694984436035, 43.66414403915405, 43.40773466655186, 53.6289621080671, 57.1124518939427, 59.08877318246024, 56.21011018753052, 52.12515653882708, 53.23439475468227, 49.95050239562988, 47.82362754004342, 50.52366624559675, 51.92219270978655, 57.43782213756016, 55.22865629196167, 61.630354745047434, 58.43835926055908, 69.90176827566964, 16.922469684055873, 2.600498378276825, 0.23292714836341993, 0.5844428933092526, 1.1443715648991721, 24.403879983084543, 70.19669846126011, 55.1828224999564, 64.21894087110246, 51.750624316079275, 55.65094348362514, 9.64717161655426, 41.104597909109934, 24.28817684309823, 31.837410245622905, 59.2396741594587, 59.50137111118862, 31.58561795098441, 52.242678369794575, 63.969736780439106, 64.38968590327671, 3.281531491449901, 0.36995642685464447, 0.19934919157198497, 0.11362258198537997, 0.21302328711109503, 0.15269122379166739, 0.11650225067777292], [0.12934458442032337, 0.0717232074322445, 0.017922544086884176, 0.03775159176439047, 0.20372378826141357, 0.023508486936667135, 0.08420044183731079, 0.10217883105256728, 0.18342981008546694, 0.11156146401273352, 0.18543724236743792, 13.98457155908857, 65.19016701834542, 41.33669206074306, 49.683455330984934, 27.511635507856095, 36.31115729468209, 47.74912895475115, 49.282255922045024, 1.771886829818998, 21.58677281652178, 57.437102999006, 52.44232095990862, 54.92045852116176, 52.957720960889546, 50.37242828096662, 46.55538327353341, 1.4899897277355194, 0.02445717728031533, 0.09270259418657847, 0.7382238443408693, 0.0791158668164696, 1.729885186467852, 34.407104219709126, 47.210164138248985, 60.41100147792271, 54.847029958452495, 54.104416915348594, 51.83105318886893, 46.99273763384138, 45.053669112069265, 50.32632350921631, 54.27747917175293, 55.60991089684622, 62.49084745134626, 48.56763022286551, 46.78007411956787, 45.37565905707223, 53.9536896433149, 49.439010756356375, 45.69599533081055, 47.4090632711138, 44.06674003601074, 58.429743494306294, 58.46231664930071, 42.52321508952549, 44.98888063430786, 24.558734485081263, 26.05210038593837, 53.18206092289516, 55.45709221703665, 62.31233433314732, 56.559889452798025, 53.3562661579677, 51.232716015407014, 51.912180355616975, 51.541757992335725, 48.14892830167498, 50.32470110484532, 49.7981527192252, 51.06285340445382, 47.56165266036987, 51.41455732073103, 49.20722579956055, 43.720184734889436, 47.59483725684029, 48.219303131103516, 46.85050800868443, 48.46617610113961, 48.56338487352644, 46.27895614079067, 49.132181780678884, 48.965352058410645, 51.68548148018973, 53.01922641481672, 47.6689258984157, 45.74556377955845, 22.49416238921029, 27.9859299659729, 30.048454080309185, 34.273834296635215, 36.78153991699219, 35.30972385406494, 47.589403765542166, 52.446628843035015, 50.11764478683472, 50.10669789995466, 49.34728758675711, 48.07148020608084, 47.47184024538313, 45.04828078406197, 44.739447253090994, 40.939081396375386, 42.68447583062308, 43.666099957057405, 45.8436792918614, 47.85713522774832, 49.775168078286306, 49.8591057913644, 47.97186388288225, 49.79953193664551, 50.88520533697945, 49.85381473813738, 47.49114234106881, 46.718360219682964, 50.41096299035208, 48.3118496622358, 52.46340526853289, 73.55900818961007, 51.7423038482666, 24.074184485844203, 40.47093956811087, 44.40441901343209, 46.561726978846956, 45.36550426483154, 49.334892000470845, 46.806626660483225, 48.9393310546875, 42.21381180627005, 44.284920419965474, 38.557714870997835, 49.97654076984951, 69.1677188873291, 46.166325841631206, 55.41296073368618, 54.4384446144104, 52.82210949489048, 47.85728461401803, 46.30952821459089, 45.02447278159005, 45.032101903642925, 45.71996661594936, 47.107254368918284, 57.32130779538836, 51.70959520339966, 57.33169535228184, 57.270196846553254, 46.82527562550136, 1.3192659744194575, 0.5763433564986501, 0.39403120215450016, 0.2905012518167496, 0.20392654809568608, 24.605247463498795, 58.7020503452846, 50.55303280694144, 38.0962050982884, 51.34362316131592, 41.672112873622346, 4.367486945220402, 21.5474077974047, 19.426975658961705, 26.486711944852555, 43.369853087833945, 35.93278271811349, 15.503060409000941, 39.71635825293404, 38.02058437892369, 29.24150766645159, 0.4503721089235374, 0.05653386516496539, 0.10819332474576575, 0.08468245954385825, 0.05611395716134991, 0.0673993176647595, 0.019054522006107227, 0.013327458291314542, 0.06137073079922369, 0.06708904395678214, 0.04785569404651012, 0.2195999063551426, 0.11030395541872297, 0.01734785206748971, 0.07342553644308022, 0.11710211634635925, 0.08737933090222733, 0.2904561428087098, 15.545204707554408, 73.11422620500836, 47.796810967581614, 46.377214091164724, 34.11980315617153, 44.56055545806885, 46.107359954289024, 56.42713369641985, 5.791907608509064, 22.31466088976179, 63.645797865731375, 61.97766045161656, 58.068805422101704, 57.314873763493125, 52.094376019069124, 46.902650765010286, 2.5446190110274722, 0.19363117696983473, 0.30456334725022316, 1.3340637918029512, 0.02329122002369591, 1.140003102166312, 41.54053831100464, 54.26159906387329, 62.07777009691511, 58.51556069510323, 56.69491727011544, 53.60293763024466, 47.174502508980886, 48.603204999651226, 50.502745219639365, 57.60958855492728, 56.952667645045686, 60.67928532191685, 48.37620040348598, 49.405044487544465, 43.69766214915684, 45.95307520457676, 50.52083485467093, 44.08395072392055, 46.663094248090474, 46.43698249544416, 53.96141604014805, 57.39924226488386, 42.67684670857021, 48.57708324704851, 26.54140990121024, 39.48500408445086, 63.29857553754534, 59.95283031463623, 60.138347217014854, 54.30588340759277, 54.45441852297102, 50.1555472101484, 55.583872522626606, 52.42372063228062, 49.60434661592756, 50.964418275015696, 53.92252002443586, 53.514410631997244, 47.98605210440499, 50.32115057536534, 50.23306826182774, 47.24739606039864, 49.78065020697457, 47.770991461617605, 49.57584163120815, 50.92718635286604, 50.83146102087838, 52.26360286985125, 50.1414076260158, 51.462558950696675, 48.802166666303364, 49.39273227964129, 46.3919164793832, 50.65490729468209, 26.944249085017614, 27.92029901913234, 37.24713870457241, 33.0469457081386, 46.365089484623496, 44.46446534565517, 47.804099627903526, 54.7196694782802, 52.69111858095442, 52.2255163192749, 50.82611438206264, 50.546626567840576, 53.07450975690569, 52.01308904375349, 48.31782511302403, 47.80518702098301, 46.85207135336739, 47.85604783466884, 46.408043248312815, 50.339757851191926, 49.58053513935634, 50.81416000638689, 46.94154330662319, 48.9548533303397, 50.865715639931814, 46.59195164271763, 48.38702917098999, 50.56174584797451, 51.128121307918, 50.32405839647566, 46.848343644823345, 59.56424536023821, 56.32253551483154, 29.892199516296387, 42.2814108303615, 48.54577466419765, 48.32989065987723, 51.51072038922991, 56.25725024087088, 53.10148613793509, 50.39479453223092, 46.22394377844674, 48.90702887943813, 40.7061048235212, 45.59007004329136, 60.053197043282644, 52.09111383983067, 55.712403774261475, 56.831518854413716, 53.442868505205425, 48.03236184801374, 45.004455021449495, 47.641060147966655, 45.91299452100481, 47.770991461617605, 50.13134316035679, 61.106787136622835, 55.46629858016968, 60.078425952366416, 58.458251953125, 54.89189100265503, 1.5653092861175537, 0.9522521368094853, 0.13725057590220655, 0.3757706848638398, 0.11697566456028394, 30.312197276524135, 65.81231566837856, 58.49212442125593, 41.667843205588206, 54.99325827189854, 46.3741568837847, 5.534372627735138, 28.844649144581386, 23.69666280065264, 27.598962204796926, 45.99676547731672, 42.201680251530235, 20.016966308866227, 45.589576721191406, 48.33172498430525, 36.42172397886004, 0.7160136018480573, 0.16193614128444875, 0.15903893246182374, 0.11753171043736593, 0.06213207423154797, 0.02471621989804719, 0.043001702188381126, 0.270331934094429, 0.13533310379300797, 0.19581645328019345, 0.09604306279548577, 0.29855831233518465, 0.28297290578484535, 0.1587911043316126, 0.15686132359717572, 0.2264254122440304, 0.30618385172316004, 0.39360079382147106, 21.092724629810878, 87.78624384743827, 52.28048699242728, 63.0867805480957, 41.204721450805664, 56.03980984006609, 58.416521072387695, 57.92591224397932, 7.258356188024793, 30.710888385772705, 68.49489702497209, 65.58655479976109, 64.86012063707624, 65.00909001486642, 58.441062109810964, 57.972548552921836, 3.8432761941637312, 0.41953019531709806, 0.6391406868185315, 2.4713934659957886, 0.4816933668085507, 2.017518026488168, 46.516476835523335, 54.78683423995972, 63.759317534310476, 61.170168604169575, 57.892216954912456, 54.23122501373291, 49.43691240038191, 51.80515030452183, 53.97721971784319, 59.46993746076311, 59.465747697012766, 64.34489781515938, 49.32060997826712, 50.01580156598772, 49.68818358012608, 53.66465153012957, 48.86441905157906, 47.23792219161987, 49.539273262023926, 50.53193807601929, 60.489050592694966, 62.192484855651855, 44.96830701828003, 51.64956624167306, 29.311969348362513, 40.76064818246024, 60.88769653865269, 59.86132253919329, 60.72362872532436, 56.80854116167341, 56.32376534598214, 54.96367631639753, 56.54902941840035, 53.554859570094514, 52.41249234335763, 52.4099041393825, 53.82595048631941, 53.878857544490266, 53.78390693664551, 54.62511144365583, 56.1288023676191, 51.68077754974365, 53.161549840654644, 52.11782271521432, 53.11864818845476, 53.80526917321341, 54.81475905009678, 53.62062079565865, 54.817701612200054, 55.298763615744456, 54.58768844604492, 53.534341539655415, 51.57274348395211, 54.372950894492014, 34.36770445959908, 30.635406630379812, 42.097554547446116, 45.57087564468384, 50.666510786329, 48.98511273520333, 52.59739433016096, 60.84572941916329, 56.61219201769148, 60.03069182804653, 56.499940395355225, 56.13743897846767, 59.98062310900007, 57.98870658874512, 56.69826977593558, 53.18478809084211, 50.42208010809762, 51.91698503494263, 52.454938888549805, 51.82221508026123, 54.2071738243103, 53.7741516658238, 49.70079803466797, 49.35739721570696, 54.14597756522042, 47.680772577013286, 51.675055708204, 51.71138783863613, 52.76774678911482, 53.04290587561471, 47.43227372850691, 52.22494656699044, 45.70916911533901, 27.443630014147075, 44.23065498897007, 52.078138078962056, 50.94347293036324, 50.83081136431013, 56.87956912176949, 55.30324172973633, 52.59096724646432, 48.95855672018868, 50.411223547799246, 41.33525030953543, 47.413756779261995, 54.356598309108186, 52.35379048756191, 59.49039990561349, 60.90890938895089, 55.977884020124165, 52.190935134887695, 51.420574460710796, 50.26896960394723, 49.30905164991106, 50.92504630770002, 51.83641024998256, 63.26247269766671, 57.10876587459019, 64.28428173065186, 61.639588900974815, 61.16137913295201, 2.9546296043055396, 2.4912194992814745, 0.443260736231293, 1.0420202570302146, 0.21898106884743485, 32.61609833581107, 70.17196982247489, 62.27867031097412, 48.43101126807076, 61.20703574589321, 53.29630667822701, 10.065386295318604, 30.09849500656128, 23.972761631011963, 38.65679965700422, 59.993609292166575, 43.28110374723162, 24.410503353391373, 59.80590370723179, 55.48730298451015, 54.60793202263968, 1.360076653105872, 0.2982721062643187, 0.27193894929119516, 0.23296376211302622, 0.26225212908216883, 0.18272779775517328, 0.16090722435287066], [0.026118551613762975, 0.022826313273981214, 0.054280375729181936, 0.03429460512208087, 0.25418000508631977, 0.04758978635072708, 0.0899266531424863, 0.03690885805657931, 0.01866162478524659, 0.04554054613358208, 0.017239785187744668, 4.182222783565521, 62.0246650150844, 45.33511631829398, 46.134107044764924, 24.28996253013611, 38.152898924691335, 24.85320782661438, 34.48081418446132, 29.03035191127232, 0.8951477152960641, 42.63602604184832, 51.933532169886995, 56.803937980106895, 51.37500817435128, 52.70669991629464, 39.178765705653596, 3.8318993874958585, 0.4214305547731263, 0.13553257951779024, 0.27369480792965206, 0.3203216445233141, 0.15553029573389462, 31.78797033854893, 57.94193826402937, 54.33285631452288, 54.85543033054897, 55.42702388763428, 51.06193624223982, 52.372161524636404, 45.12434271403721, 48.2242294039045, 53.65603576387678, 57.74586009979248, 52.75462859017508, 62.43983377729143, 52.369170325142996, 40.49813134329659, 47.171869141714915, 47.64464889253889, 45.17050307137625, 45.61416987010411, 48.12255988802229, 51.584711756025044, 38.377482073647634, 44.91027218954903, 36.05583878925869, 25.38513238089425, 60.53408881596157, 63.08316053662981, 53.96875333786011, 53.578132561274934, 53.54761259896414, 49.41829817635672, 48.91472748347691, 44.834974561418804, 42.62223734174456, 49.91712324959891, 48.171555110386436, 48.86517640522548, 49.512988226754324, 53.03007255281721, 50.224421228681294, 50.41632352556501, 48.21392175129482, 47.57299559456961, 45.217695236206055, 45.72250270843506, 45.39337348937988, 48.31918001174927, 45.701182161058696, 49.925773756844656, 47.78865725653512, 48.958508082798545, 47.315425872802734, 46.402984959738596, 26.411589758736746, 23.263901199613297, 25.259168488638743, 33.70573220934187, 57.457179818834575, 46.42356552396502, 43.72254017421177, 45.08704478400094, 48.332579612731934, 44.99583230699812, 47.08445038114275, 49.24424927575247, 46.48886122022356, 44.20356396266392, 40.57922029495239, 40.66833094188145, 37.7225900377546, 38.521629401615684, 41.550654888153076, 44.79288237435477, 43.560223306928364, 47.11766277040754, 48.761658668518066, 46.790899412972585, 48.229534353528706, 46.70765651975359, 45.69073554447719, 48.0194798878261, 46.55706821169172, 44.58542306082589, 47.14033474240984, 49.80843257904053, 50.38772474016462, 54.55973931721279, 35.15133619308472, 36.97358465194702, 38.880118233816965, 43.41126435143607, 46.48002658571516, 47.49111802237374, 43.31945085525513, 47.29480709348406, 45.02339233670916, 46.2661714553833, 37.95454522541591, 59.832411084856304, 58.109528814043315, 48.54659455163138, 57.17794908796038, 55.857822622571675, 51.062499046325684, 46.577092920030864, 43.913879667009624, 46.01236418315342, 46.272657598767964, 47.238102844783235, 53.36453798839024, 54.51726150512695, 52.75152621950422, 57.2493348802839, 58.61681679316929, 30.80546031679426, 0.2538731172680855, 0.13385241824601377, 0.03516439202108553, 0.499332780284541, 1.9671318616185869, 47.79983343396868, 50.190284729003906, 51.33698763166155, 47.56084319523403, 66.89959062848772, 21.031549215316772, 2.8276669085025787, 31.2038665499006, 17.71858385631016, 30.268903051103862, 44.64471203940255, 37.11193370819092, 17.580227851867676, 39.45368160520281, 48.17256607328142, 22.304024934768677, 0.7169377665434564, 0.11589527396219117, 0.1158005233321871, 0.06581424629049641, 0.034160716592201164, 0.0622970260945814, 0.03760079414184604, 0.0442676347946482, 0.03202965522983244, 0.029044474342039654, 0.0881705027339714, 0.1550210416316986, 0.08686886222234794, 0.08187654082264219, 0.04649804046909724, 0.07190773503056594, 0.044464128358023505, 0.07475576363503933, 4.241977291447776, 69.2831562587193, 51.56548956462315, 44.05064105987549, 27.668444190706524, 45.821997438158306, 22.735721724373953, 35.318843364715576, 31.610193729400635, 3.0982078313827515, 40.27734885896955, 60.99118300846645, 62.442168372017996, 58.74043219430106, 54.32381670815604, 43.76535497392927, 3.229061084134238, 0.2392686823649066, 0.042166462899850946, 0.34830399442996296, 0.15154057767774376, 0.36590304864304407, 34.841408320835654, 59.341395786830354, 57.06621858051845, 58.87629726954869, 57.07794713973999, 54.687155382973806, 52.70620659419468, 46.4190422466823, 50.20081124986921, 56.02042089189802, 58.052991322108674, 53.82901464189802, 63.590900148664204, 52.99828454426357, 44.430398327963694, 42.21169260569981, 46.21778767449515, 45.512416975838796, 48.35048164640154, 50.994764532361714, 50.41045229775565, 41.81549589974539, 47.35269601004464, 36.692175660814556, 34.65300791604178, 70.97985771724156, 61.80149582454136, 55.31649889264788, 51.17414617538452, 52.57257536479405, 51.13514593669346, 51.999373299734934, 48.65841885975429, 49.75698811667306, 51.76675108500889, 49.53361048017229, 49.7079998425075, 50.34506280081612, 51.162768500191824, 51.491286277770996, 49.26940175465175, 50.53623901094709, 47.748454979487825, 46.994137695857454, 47.51763234819685, 45.30372783115932, 48.273627621786936, 47.22487000056675, 49.0962040083749, 48.02992303030831, 47.91183492115566, 48.70508990968977, 47.029632568359375, 37.15927178519112, 35.408332688467844, 33.617552621024, 32.22288588115147, 50.13985470363072, 45.64970643179757, 43.04676185335432, 48.26645360674177, 49.894944599696565, 50.13374376296997, 51.55573776790074, 49.911512579236714, 50.352455684116904, 50.13947950090681, 47.610283102308, 48.542741775512695, 47.85618332454136, 47.31584971291678, 48.690536907741, 47.15496417454311, 45.88594518389021, 48.955902508326936, 49.04786539077759, 46.46294443947928, 48.142956324986045, 44.705543518066406, 45.39514528002058, 48.173347745622905, 52.64692803791591, 48.197958265032085, 47.58270570210048, 53.61228295734951, 49.25709996904646, 54.83882066181728, 42.43100554602486, 37.810731410980225, 41.72729894093105, 45.2566294670105, 51.25235857282366, 52.894871030535015, 49.425975935799734, 49.69517694200788, 47.183934688568115, 48.89456728526524, 40.395231996263774, 54.39791924612862, 52.2726285798209, 49.5334471975054, 56.46911818640572, 57.09743683678763, 53.6384915624346, 48.477046557835166, 45.78432777949742, 48.03118412835257, 45.033731256212505, 46.97750718252999, 55.65378182274954, 59.43248667035784, 55.41138349260603, 59.974564279828755, 60.766311509268625, 35.07263742174421, 0.3689292605434145, 0.377172483929566, 0.13565884131406034, 0.3966586525951113, 2.871444685118539, 55.57258864811489, 53.828347614833284, 57.80859538487026, 45.99585178920201, 72.54800360543388, 21.28666796003069, 6.872998671872275, 34.92882708140782, 22.163850239345006, 26.316583565303258, 44.244891847882954, 44.61063807351248, 17.112247569220408, 44.852032388959614, 59.90477657318115, 26.480010407311575, 0.7081951956663812, 0.09565565322658845, 0.12379419510918004, 0.0836368574361716, 0.06612033343740872, 0.01908593139212046, 0.06711128633469343, 0.13669557496905327, 0.07427930991564478, 0.18646481579967908, 0.2117266881146601, 0.4115119198603289, 0.14770222721355303, 0.16731950241540158, 0.1264095404850585, 0.22316592000424862, 0.10013346866305385, 0.10167852682726723, 6.102547671113696, 87.44446890694755, 57.951401710510254, 65.26816054752895, 33.83140427725655, 56.96963862010411, 33.26242324284145, 40.91544362476894, 38.86638164520264, 4.9290594628879, 54.071954931531636, 67.63051332746232, 65.02136748177665, 65.44124712262834, 63.90665408543178, 51.69189119338989, 6.6586580361638745, 2.1811695992946625, 0.535640754870006, 0.7806576873574937, 0.6244261392525264, 1.4946246104581016, 37.41135937826974, 59.34969193594796, 57.64921760559082, 60.09287125723702, 58.23801490238735, 56.815576212746755, 54.70686742237636, 49.31822674615042, 51.65140751429966, 58.88940852028983, 63.21855313437325, 55.671131474631174, 62.13776084354946, 55.921982288360596, 49.474807875497, 41.36750384739467, 49.74335922513689, 45.872809614454, 51.53484800883702, 51.10778393064226, 55.996706690107075, 45.62468596867153, 46.337876864842, 39.15215757914952, 31.539342948368617, 58.88248116629464, 66.60610566820417, 55.640218939099995, 55.42140974317278, 55.54303101130894, 54.81911209651402, 53.95959561211722, 49.47547490256173, 52.38566882269723, 54.24824810028076, 50.730673926217214, 51.319120338984895, 52.757015296391074, 53.96496309552874, 56.62804433277675, 55.442167486463276, 56.64804819652012, 51.36996030807495, 50.57171303885323, 54.31138290677752, 49.803148474012104, 52.25836740221296, 50.27320105688912, 55.91515220914568, 51.901146616254536, 51.58047335488455, 52.534242153167725, 52.89917196546282, 39.95312854221889, 37.760815552302766, 37.215527875082834, 38.729665415627615, 60.60567610604422, 60.91781003134591, 54.44584444590977, 52.53396422522408, 54.86314630508423, 52.948278359004426, 55.886351925986155, 57.70116581235613, 57.12444448471069, 55.45303794315883, 51.49728604725429, 52.460358483450754, 53.071633202689036, 52.11842026029314, 54.5273676599775, 52.77180801119123, 48.58933639526367, 50.08056225095476, 52.63639456885201, 48.893278394426616, 50.81681769234793, 46.24654974256243, 46.69056395121983, 49.73127630778721, 52.45261819022042, 52.45744718824114, 48.823997906276155, 54.037196568080354, 50.80291782106672, 52.18118333816528, 33.80955914088658, 38.50440829140799, 42.42034353528704, 48.53033229282924, 53.49650512422834, 53.94696378707886, 52.05182525089809, 51.875083923339844, 50.945894377572195, 50.61549711227417, 40.40930209841047, 56.67761972972325, 65.100264276777, 50.56245803833008, 61.67469814845494, 59.88105542319161, 56.25526305607387, 52.074062960488455, 48.34154626301357, 51.41991785594395, 53.21508571079799, 50.772786957877024, 59.62624413626534, 59.68840272086007, 58.2634904725211, 65.41566385541643, 60.77013301849365, 43.57099996294294, 0.974277600646019, 0.9738171739237649, 0.4484644484307085, 1.0222459009715488, 3.8042555451393127, 58.70482267652239, 59.93896171024868, 63.40818337031773, 54.868829931531636, 79.64206572941372, 30.08082226344517, 8.511841177940369, 39.92121546609061, 24.181803396769933, 39.757203238351, 60.64965125492641, 50.8662610735212, 27.479310750961304, 55.37760135105678, 70.49181624821254, 42.16667522702898, 1.0370730310678482, 0.28952030731098993, 0.27954470259802683, 0.17485113255679607, 0.12947962645973476, 0.19188309434269155, 0.42155676228659494], [0.021331726240792444, 0.08587548016969647, 0.028535342376146997, 0.11639846196132046, 0.16390151796596392, 0.026273788551666906, 0.09620659652033023, 0.13712496549955436, 0.07065306949828352, 0.08977735508233309, 0.030995842668094804, 0.39398717880249023, 52.233183656420024, 50.33076688221523, 44.76969623565674, 34.11377559389387, 32.287872382572715, 42.551504680088584, 19.08696382386344, 52.887961047036306, 3.8648008448737006, 11.340813262122017, 58.807558740888325, 34.75213439123971, 59.895611899239675, 48.53499453408377, 49.26531621388027, 4.215737853731428, 0.1353483572602272, 0.11389390778328691, 0.2605285144277981, 0.19760679506829806, 0.5548951359731811, 26.66742069380624, 62.93011951446533, 54.28275980268206, 59.90649972643171, 56.23090614591326, 54.85783788136074, 47.87480449676514, 45.827340602874756, 45.55879620143345, 49.25525174822126, 52.605655738285606, 59.5005373273577, 53.43115036828177, 58.950934818812776, 34.504028115953716, 55.395704882485525, 52.11102042879377, 42.56107929774693, 51.17220762797764, 43.775478499276296, 41.99313007082258, 47.490822723933626, 35.23101813452584, 26.312456335340226, 55.547349316733225, 62.2566306250436, 54.8776159286499, 49.1751320702689, 49.571214130946565, 50.82535702841622, 48.42264911106655, 44.10521221160889, 46.28455638885498, 44.85271678652082, 47.76812185559954, 49.65956047603062, 50.673375606536865, 50.278488636016846, 54.994213649204795, 54.77907657623291, 52.85512386049543, 49.00636380059378, 48.3731119292123, 44.219860962459016, 44.352637563432964, 46.2730883870806, 47.863148893628804, 50.02420541218349, 48.65397201265608, 42.87292487280709, 44.38836867468697, 45.32826886858259, 40.02484437397548, 17.5380140713283, 14.934636967522756, 28.28715521948678, 28.94190308025905, 38.965122495378765, 55.22892379760742, 50.45539672034127, 43.0557667187282, 42.490485600062776, 43.168456077575684, 40.575294562748496, 43.60313538142613, 46.83874470846993, 42.10745225633894, 41.74059084483555, 37.75430509022304, 36.0468339238848, 38.10366398947579, 41.849938120160786, 43.54460375649588, 48.8816887991769, 48.0335430417742, 47.315787179129465, 48.04561901092529, 48.65147760936192, 48.55196898324149, 43.475559507097515, 44.44570173536028, 44.673359462193076, 46.34101397650582, 46.44333662305559, 45.36171402250017, 49.526168959481375, 49.598218304770334, 44.61177062988281, 34.9866395677839, 37.04597098486764, 36.88948713030134, 42.63468156542097, 44.71464218412127, 45.571233476911274, 44.51229674475533, 53.89056525911604, 43.297623089381624, 49.72523137501308, 39.74371331078665, 20.12279953275408, 51.38062926701137, 54.885651520320344, 53.465637751988, 54.578249318259104, 51.19404929024832, 44.91860655375889, 48.13928072793143, 45.54397569383894, 42.43828725814819, 51.595919200352256, 53.10273333958217, 55.412495204380576, 53.2423608643668, 54.75831535884312, 16.59665128162929, 0.19576438250286238, 0.07364914087312562, 0.07674151672316448, 0.1978233563048499, 6.645882036004748, 61.64974021911621, 44.38177830832345, 59.78115422385079, 54.54449149540493, 60.535679953438894, 10.076019644737244, 13.881845048495702, 36.83799055644444, 19.164993831089564, 31.966889926365443, 50.651672908238, 25.49617154257638, 39.53693492071969, 50.01951885223389, 46.85792521068028, 9.765846848487854, 0.7236876700605664, 0.36991851031780243, 0.10734318143555097, 0.03678384476474353, 0.017922513552808335, 0.03157732003767576, 0.14332323361720356, 0.02804077516442963, 0.07467707392892667, 0.04382483641217862, 0.010518752487509378, 0.08553209395280906, 0.021609493032363907, 0.11842971082244601, 0.05555204874170678, 0.09482885152101517, 0.05312129542497652, 0.03990653416674052, 0.3507407765303339, 57.126476832798545, 55.938522475106375, 43.97630228315081, 31.26368706566947, 36.55882583345686, 36.85353020259312, 21.448121513639176, 57.133911405290874, 7.812193189348493, 13.125233990805489, 59.76461751120431, 37.342304706573486, 64.4775389262608, 53.36276619774954, 53.630744321005686, 4.911239504814148, 0.19438175883676323, 0.2117795595633132, 0.43007723508136614, 0.3202043393892901, 0.2492071305002485, 29.225526809692383, 65.6217543738229, 59.8378723689488, 61.82200690678188, 57.313932282584055, 56.48064872196743, 49.95023488998413, 46.1412741116115, 46.359833172389436, 51.665446349552695, 52.95424338749477, 59.52254922049386, 56.09190395900181, 58.84613513946533, 39.92980343954903, 59.3689523424421, 50.81711299078805, 43.831765856061665, 50.451630796704976, 46.8546838760376, 45.37642683301653, 47.357358251299175, 35.32149062837873, 31.559006350381033, 68.87148938860211, 61.739226068769185, 56.995586667742046, 51.876998152051655, 52.5507823399135, 51.86976160321917, 50.596222809382844, 47.55818203517369, 53.34448896135603, 48.89922605242048, 47.136933599199565, 50.91716357639858, 51.85233204705374, 50.37256377083914, 52.05894715445382, 54.44426720482962, 52.68111317498343, 49.09329618726458, 49.65618017741612, 45.96833692278181, 46.454349517822266, 46.25611741202218, 48.089243275778635, 47.85243477140154, 47.73111227580479, 44.47694778442383, 47.1066255569458, 46.78822783061436, 47.959374495915, 30.525447913578578, 36.51683439527239, 33.89419862202236, 35.62130192347935, 42.15947341918945, 45.66108758108956, 48.286370618002756, 46.92684439250401, 47.848436083112446, 48.042096274239675, 46.626418181828086, 48.63366937637329, 49.02296652112688, 48.960884366716655, 47.957554067884175, 42.473035199301584, 45.98754174368722, 47.27911458696638, 49.7000024659293, 48.19483157566616, 48.29866892950875, 50.26698241915022, 49.07581451960972, 48.99531963893345, 48.698982443128315, 45.650613171713694, 44.56530802590506, 45.746185643332346, 45.71476241520473, 49.08634104047503, 49.75701590946743, 48.511999470846995, 53.11472593035017, 52.232662541525706, 47.82054601396833, 36.50662749154227, 39.214618410382954, 41.12334762300764, 45.517767088753835, 49.57921150752476, 48.55063840321132, 48.72159535544259, 54.534284591674805, 46.19381986345564, 51.27617352349417, 39.9098482131958, 22.566029344286235, 50.87024586541312, 56.85117530822754, 53.886000292641775, 56.03645038604736, 50.436049461364746, 45.8272294316973, 48.55707243510655, 45.43012945992606, 42.76618317195347, 52.42680215835571, 56.57155895233154, 59.01654665810721, 56.68633277075631, 58.29178006308419, 17.93693620818002, 0.29636675279055325, 0.391413794032165, 0.06509136900837932, 0.315631203353405, 8.635361909866333, 71.51454244341168, 49.96687582560948, 66.76713711874825, 57.18676635197231, 65.83682891300747, 13.202777624130249, 16.995246853147233, 38.879645756312776, 24.788334233420237, 28.77252163205828, 53.7057466506958, 34.99087449482509, 36.912669794900076, 54.443714823041645, 54.93076964787075, 10.377859813826424, 0.6359346359968185, 0.21021877974271774, 0.06569956030164446, 0.046809759456664324, 0.09361151898545877, 0.03832135422687445, 0.04505153612366744, 0.1732259869043316, 0.137159991477217, 0.12297954596579075, 0.19337559996971063, 0.21422499977052212, 0.1025641778750079, 0.1539194264582225, 0.19419028982520103, 0.19143220782279968, 0.12125472351908684, 0.226723831945232, 1.0064523198774882, 72.81801755087716, 64.69742856706891, 56.54669829777309, 46.95017991747175, 49.619768142700195, 55.70201621736799, 21.270449127469742, 66.12782641819545, 9.590370961597987, 18.91645676749093, 69.69707434517997, 43.476073673793245, 68.1013788495745, 61.328629221235005, 60.23257868630545, 6.135394845690046, 0.6388436513287681, 0.7901204281619617, 0.7463070963110242, 0.40278747943895205, 1.150892015014376, 35.90928738457816, 64.15311363765171, 62.140081541878835, 62.995286669049946, 62.287953104291645, 59.792451994759695, 52.62162617274693, 48.88622944695609, 48.79659421103341, 51.474853788103374, 56.69598381859915, 60.79416683741978, 58.94124208177839, 58.14952959333147, 47.3817846434457, 58.19075672967093, 46.36358172552926, 46.94175175258091, 50.566717284066335, 49.29848343985421, 45.76349360602242, 48.42841264179775, 39.379707608904155, 33.26205151421683, 53.226876803806846, 63.06361525399344, 58.80817713056292, 54.06164380482265, 55.38832242148263, 54.445170470646445, 52.78453016281128, 51.49123764038086, 55.470710686274934, 50.199862820761545, 50.979450702667236, 54.12663378034319, 54.28363527570452, 51.36573927743094, 58.302841595241, 56.11065019880022, 56.387459482465474, 53.56324257169451, 55.51176411764962, 50.40176704951695, 49.72802455084664, 52.10827241625105, 52.36824968882969, 56.23485272271292, 51.68277168273926, 46.61940744944981, 52.180036885397776, 52.89602095740182, 51.945298944200786, 35.128549575805664, 38.98457745143345, 39.52905566351754, 40.58845445087978, 41.50411237989153, 65.38446644374302, 65.43949617658342, 52.84447227205549, 50.464370318821494, 54.206704820905415, 49.21158926827567, 53.94353832517351, 55.76921224594116, 55.04452902930123, 53.953752177102224, 51.82863868985857, 53.51747131347656, 54.64610195159912, 56.416572434561594, 55.77650090626308, 53.1544383593968, 52.995974268232075, 50.51321962901524, 53.006768294743125, 50.33767686571394, 48.29761280332293, 43.74079656600952, 48.19746494293213, 47.13158696038382, 50.30410317012242, 51.24579947335379, 51.14192043031965, 54.6247501373291, 57.29525899887085, 44.094584941864014, 36.34398405892508, 39.45289993286133, 42.26632629122053, 47.56079455784389, 53.60609906060355, 50.06181948525565, 50.582778045109336, 54.85819223948887, 48.961648668561665, 50.336370604378835, 48.6228232383728, 32.87284469604492, 53.94189855030605, 61.38238743373326, 56.6594432422093, 62.08472524370466, 53.62378570011684, 48.54684121268136, 52.06907415390015, 50.538125446864534, 45.73137208393642, 55.36916276386806, 58.20182868412563, 62.54589802878243, 58.13875641141619, 60.94005816323416, 25.332640477589198, 0.33232145490390913, 0.9193747809955052, 0.21551922389439174, 0.6577282579881805, 8.91254118510655, 76.2865652356829, 52.77816561290196, 71.40606021881104, 64.63483224596295, 73.55678476606096, 16.72028057915824, 21.825664043426514, 46.99193164280483, 27.10679350580488, 45.04768671308245, 73.36830793108258, 34.48110600880214, 55.79348577771868, 64.42339161464146, 71.01461260659354, 20.33426100867135, 1.0869006259100777, 0.6168152019381523, 0.1661879774183035, 0.3296301950301443, 0.19920625138495648, 0.17625553719699383, 0.2210561917828662], [0.09951301624200173, 0.02808674591194306, 0.08345678781292268, 0.1527966952749661, 0.020022297843492458, 0.057720382032649856, 0.04258508507960609, 0.024065409820260744, 0.05909307873142617, 0.05980323348194361, 0.10624438218240227, 0.0346524882396417, 36.66815226418631, 60.232926096235005, 40.8662052154541, 44.068199157714844, 31.501193864004954, 33.24890899658203, 19.180109637124197, 32.90077992847988, 45.668053150177, 22.041457721165248, 43.25986310413906, 54.95589780807495, 46.58211299351284, 52.81540795734951, 50.95498609542847, 7.529376319476536, 0.06476884774331536, 0.09185557892279965, 0.04544593121058174, 0.2143555906202112, 0.37504400100026813, 28.81787599836077, 62.77841254643032, 57.2394962310791, 58.529026303972515, 56.76356894629342, 50.32573986053467, 44.301495347704204, 47.86932931627546, 46.58531263896397, 47.92911856515067, 48.91293484824044, 56.261054379599436, 54.46024806158883, 58.01387643814087, 41.761664731161936, 32.94221551077706, 69.2102279663086, 47.64990520477295, 48.575978483472554, 45.8671989440918, 40.6857396534511, 30.98688473020281, 28.642369713102067, 62.099462372916086, 59.82095350537981, 51.808686937604634, 52.400322573525564, 50.09716149738857, 47.94323035648891, 49.262995515550884, 46.23420279366629, 45.13673482622419, 46.96340233939034, 44.04189327784947, 46.08858939579555, 48.907313755580354, 52.449296951293945, 52.88901717322213, 53.699969223567415, 50.37632622037615, 50.01029164450509, 51.09642710004534, 47.627664021083284, 48.391555922372, 44.20967490332467, 47.339803627559114, 46.20105293818882, 50.909954820360454, 46.44404533931187, 42.76566553115845, 41.22156735828945, 42.980833871024, 25.75222134590149, 8.965140785489764, 24.936409030641826, 26.2993711403438, 25.66319407735552, 32.18409061431885, 40.192445346287315, 48.94758898871285, 40.79331513813564, 37.70049476623535, 40.81888798304966, 42.092218330928254, 45.934349809374126, 47.363017559051514, 41.844462939671104, 41.82067925589425, 38.02182810647147, 39.52469914300101, 36.844556604112896, 40.321838174547466, 40.25535781042916, 47.51852171761649, 48.14947026116507, 52.19204337256295, 51.99012872150966, 47.21704632895333, 49.00617272513253, 43.48597485678536, 42.657502923692974, 45.856418813977925, 45.37477316175188, 44.58188642774309, 46.45697593688965, 49.33214051382882, 49.38866063526699, 41.76829331261771, 36.30699184962681, 38.67609133039202, 35.63433674403599, 34.23858608518328, 36.40147692816598, 49.01998574393136, 46.9770381791251, 47.449241229466026, 43.87273243495396, 46.11503423963274, 29.35312352861677, 30.239633764539445, 48.75572490692139, 55.68144260134016, 54.06175150190081, 56.15878731863839, 49.793886525290354, 46.3586311340332, 45.635761397225515, 47.39500706536429, 42.173692907605854, 53.62882661819458, 51.15204742976597, 56.475183963775635, 43.77982112339565, 41.61593321391514, 9.03407907485962, 0.17278899678162166, 0.35108520090579987, 0.09571733884513378, 0.25798883927719934, 16.652292455945695, 62.738099098205566, 43.003092425210134, 60.294890131269185, 45.559338160923545, 57.28586850847517, 15.810625893729073, 12.117604494094849, 26.72615555354527, 20.03031553540911, 44.178887435368125, 48.679319041115896, 27.87162515095302, 34.73980481284005, 40.0029992376055, 42.961528301239014, 0.8361081119094576, 0.21179470446492943, 0.07342194020748138, 0.09106302966496774, 0.11959776814494814, 0.058216004366321225, 0.04053710354492068, 0.07910397209759269, 0.054139840948794565, 0.01208823621605656, 0.07320299052766391, 0.06303012889942952, 0.024998195303071822, 0.010432877095549234, 0.05974240281752177, 0.021856549328991344, 0.17877979603196892, 0.11143057460763625, 0.1512832771986723, 0.0540443371449198, 41.27376570020403, 67.63818413870675, 42.70028993061611, 34.46312754494803, 34.79052666255406, 32.56260762895857, 18.04079440661839, 42.59875937870571, 46.57187829698835, 28.336742775780813, 45.720168113708496, 60.347807611737935, 49.5076276915414, 59.260859216962544, 53.875393867492676, 9.983695455959865, 0.07390400541148015, 0.40782524911420687, 0.10839449680809464, 0.31234307693583624, 0.3775115343076842, 32.746234621320454, 68.11117580958775, 61.146155629839214, 59.008688245500835, 56.154396057128906, 53.04247161320278, 47.74666234425136, 48.12702063151768, 48.18355812345232, 50.743948459625244, 49.96489211491176, 56.462722369602744, 57.48064041137695, 60.30516651698521, 46.57258701324463, 39.124896321977886, 67.29398427690778, 48.0011887550354, 50.26293509347098, 45.47504608971732, 40.66874435969761, 32.09110982077462, 35.55156980242048, 73.80690601893834, 64.88744790213448, 51.947331292288645, 55.49146842956543, 52.16982650756836, 50.200950213841026, 48.54564612252371, 49.461008753095356, 51.460398060934885, 49.56142411913191, 46.88157687868391, 49.10009152548653, 51.35156495230538, 53.37508882795061, 52.61440004621233, 51.96922159194946, 50.72403839656285, 52.23551477704729, 50.738598346710205, 50.148935999189106, 49.44095972606114, 46.81178222383772, 49.80792188644409, 47.36640133176531, 49.4813357080732, 49.08926970618111, 46.047782625470845, 45.83587646484375, 48.64532150541033, 38.30861847741263, 25.117750065667288, 39.375858306884766, 40.59449938365391, 37.13689858572823, 39.03606360299246, 41.637298924582346, 47.41034868785313, 49.98566722869873, 47.08985955374581, 46.54190376826695, 44.621908051627024, 49.93871477672032, 49.45785774503435, 48.73644712993077, 47.750549861363, 47.930473463875906, 45.425078119550435, 46.45257772718157, 48.69436189106533, 47.05115113939558, 49.49026414326259, 46.856396606990266, 53.510537011282786, 50.64635406221662, 45.33529002325875, 49.0291017804827, 45.611004965645925, 45.07726519448416, 46.82979890278408, 49.33862318311419, 50.37529788698469, 50.61697013037545, 51.40906824384417, 52.4145142691476, 45.550361088344026, 40.36825908933367, 39.44742822647095, 37.76960849761963, 38.008987835475374, 42.499153477805, 48.61601052965437, 47.71392938068935, 47.55142143794468, 44.76738943372454, 45.83249616622925, 31.00320257459368, 32.72601883752005, 46.769023009708945, 56.020639760153635, 55.39578478676932, 56.244691371917725, 51.816823278154644, 46.7237138066973, 45.59139020102364, 46.7486891065325, 44.09789228439331, 55.20523738861084, 55.21454797472273, 60.09672750745501, 48.408745765686035, 47.899286474500386, 11.778742585863386, 0.3329472541809082, 0.5355154701641628, 0.0402656454326851, 0.4285638305757727, 21.242925575801305, 68.16744926997593, 48.375474316733225, 66.2244758605957, 50.18296480178833, 67.07280921936035, 18.439733913966588, 15.907673120498657, 31.386378356388636, 23.920728308813914, 33.37453242710659, 53.28152091162545, 31.482037680489675, 32.889982427869526, 46.69644212722778, 50.79108156476702, 2.0479398454938615, 0.18853142990597657, 0.1188280787318945, 0.056693724622683864, 0.09020379398550306, 0.08098548863615308, 0.058832025953701565, 0.060581031388470104, 0.2120902743190527, 0.10466640828443424, 0.1778988540172577, 0.16555395429687841, 0.15469691902399063, 0.1784286813012191, 0.11476731805929116, 0.1454964591456311, 0.2516783821795668, 0.2570059948733875, 0.31512428341167315, 0.09420068415680102, 50.55794170924595, 81.83588300432477, 52.73494781766619, 55.74377489089966, 48.031211921146934, 48.88162279129028, 21.040213618959697, 44.87686177662441, 52.19940151487078, 32.647483348846436, 52.9216285433088, 66.69282613481793, 55.28187949316842, 64.91986124856132, 63.82704857417515, 12.396245496613638, 0.1258349163191659, 1.3168324764285768, 0.12495850691837923, 0.543676455106054, 0.6817244589328766, 37.88763059888567, 69.47931085314069, 66.42166573660714, 61.55965682438442, 63.41016360691616, 56.21556452342442, 48.12661763599941, 49.68794386727469, 48.92783873421805, 52.450540678841726, 51.553479603358674, 57.59915236064366, 59.65314756120954, 60.85199669429234, 45.31586285999843, 46.86932373046875, 62.09899684361049, 45.29434428896223, 52.23426757540022, 46.3325788634164, 43.46463693891253, 38.71904509408133, 41.236714431217735, 64.80063710893903, 64.14715208326066, 54.88444948196411, 56.80734607151577, 54.94619812284197, 52.02748223713466, 50.5931829724993, 53.18423918315342, 52.835446562085835, 54.215143408094136, 49.1456960269383, 52.838625362941194, 51.09875474657331, 55.45545244216919, 54.44138022831508, 55.91011823926653, 55.2356253351484, 54.87257501057216, 54.737105982644216, 55.460396085466655, 56.0034499168396, 52.19378389630999, 55.90313529968262, 51.95122575759888, 58.77725764683315, 56.073376587459016, 51.27373817988804, 53.25464180537632, 54.830858026232036, 42.675408431461875, 26.060130766459874, 47.062629563467844, 38.34178222928728, 43.43885564804077, 47.5744686126709, 51.15576819011143, 62.94738578796387, 55.490339347294395, 52.840609073638916, 52.41376386369978, 53.3157616342817, 55.123057569776265, 57.4568532535008, 52.49031911577497, 53.477348940713064, 54.3975509916033, 54.332699980054585, 51.58446856907436, 58.7033566066197, 53.0720396723066, 50.340598583221436, 50.15548120226179, 55.14964485168457, 55.82885558264596, 46.23847246170044, 50.82616301945278, 44.449728216443745, 47.259909766060964, 50.368836062295095, 49.177424975803916, 51.56739684513637, 52.890257426670615, 54.74468994140625, 54.54593324661255, 43.291175161089214, 37.55062212262835, 41.15521553584507, 39.074747698647634, 40.01150730678013, 46.80327068056379, 53.9320182119097, 50.59163352421352, 51.308531284332275, 46.078163623809814, 47.298215184892925, 33.13301999228341, 37.23183182307652, 47.34125232696533, 60.06893471309117, 59.11417579650879, 60.606169428144185, 53.76633494240897, 51.24996491840908, 48.23081629616873, 52.490715163094656, 47.98786211013794, 57.82933228356497, 57.07168681280953, 64.20102841513497, 48.80337217875889, 53.41893196105957, 14.780258417129517, 0.22367763040321215, 0.9269022856439862, 0.30555753675954683, 1.5025126614740916, 21.092575243541173, 76.35883344922746, 52.19860247203282, 72.77640478951591, 54.49910933630807, 69.5491749899728, 22.212901047297887, 19.728378091539653, 35.905007294246126, 28.510265350341797, 62.84080042157854, 63.510988916669575, 40.61817537035261, 52.12934977667672, 50.32723372323172, 68.44454342978341, 5.711174752031054, 0.35707161681992666, 0.41655091089861734, 0.16372049839368888, 0.2698915648673262, 0.1327097788453102, 0.17422690748104028, 0.24879493404711994], [0.017982010895918523, 0.09509775494890553, 0.06252071194882904, 0.05354668599154268, 0.035550770216754506, 0.03249170704345618, 0.10886027038629566, 0.042873387823679616, 0.18718464645956243, 0.20096425419407232, 0.1957817394286394, 0.23735947481223515, 22.83211408342634, 66.39125347137451, 37.802654130118235, 40.993711607796804, 30.92779724938529, 38.612880093710764, 26.543850455965313, 25.450360332216533, 24.587826592581614, 47.20383085523333, 44.45546048028128, 53.0364579473223, 53.78771802357265, 47.56521361214774, 55.087093693869456, 17.25774805886405, 0.1440889196736472, 0.3745853384690625, 0.14951253150190624, 0.2780939947281565, 0.38605643436312675, 26.67686676979065, 62.004369327000205, 54.214771679469514, 56.371416091918945, 53.51475804192679, 45.55819518225533, 46.118518761226106, 53.08195127759661, 56.23898342677525, 50.73316832951137, 48.998897961207796, 49.3509875025068, 52.15962307793753, 53.116386549813406, 56.68392869404384, 34.99234403882708, 39.61669676644461, 61.04564993722098, 41.051576205662315, 41.74514191491263, 33.87464986528669, 46.31158140727452, 70.41393389020647, 60.25840514046805, 50.61927693230765, 56.055009024483816, 54.010459899902344, 51.78679663794381, 50.26936217716762, 47.342610699789866, 45.88354805537632, 45.113746711185996, 45.346733706338064, 42.52027252742222, 45.994521209171836, 52.475168568747385, 53.29540688650948, 54.59241669518607, 54.42417648860386, 51.80668933050973, 47.84644889831543, 42.98475612912859, 47.605335984911235, 48.42823198863438, 45.79588263375418, 45.65108912331717, 50.39900861467634, 50.16494117464338, 42.34126608712332, 37.857937472207205, 37.46289416721889, 39.15105281557356, 12.113269686698914, 8.95526044709342, 33.09869589124407, 23.861835377556936, 24.044401032584055, 28.698457309177943, 31.50227083478655, 39.33690670558384, 35.82684006009783, 34.422272137233186, 38.83799130575997, 39.14357655388968, 47.595997606004985, 41.8885110446385, 41.79340410232544, 39.88268423080444, 41.44985042299543, 41.9402299608503, 39.463495935712544, 38.03436265672956, 39.73032413210188, 45.767023290906636, 47.60246637889317, 50.12593746185303, 52.29054798398699, 49.042880058288574, 48.09254019601004, 43.26318086896624, 40.79417324066162, 45.779387610299246, 47.850715092250276, 47.78473847252982, 44.07285792487008, 50.38813120978219, 45.40084627696446, 35.81273174285889, 36.447988169533865, 29.50768620627267, 36.51571920939854, 45.470578398023335, 37.50644895008632, 37.679983683994834, 40.41538177217756, 41.197047165461946, 41.15766477584839, 36.26575081689017, 31.347826276506694, 52.25413247517177, 66.08747128077916, 51.61328969682966, 53.55124650682722, 55.268980162484304, 52.516774381910054, 47.37094892774309, 46.79479387828282, 48.216641971043174, 44.66846793038504, 47.33894205093384, 50.59342615944998, 55.21529838017055, 52.09635625566755, 46.22663273130144, 5.890574199812753, 1.257681918995721, 0.43873610187854084, 0.18324987616922173, 1.349996879696846, 23.205128124782018, 51.61130598613194, 40.29242297581264, 55.824686663491384, 50.13624164036342, 59.146533557346885, 11.426654781614031, 15.453738621303014, 22.51951810291835, 19.18409095491682, 54.32701635360718, 41.16056217466082, 26.683057614735194, 43.52214370455061, 48.7348872593471, 36.715243680136545, 0.884099536708423, 0.1006631330986108, 0.051568936223962476, 0.029877019846545796, 0.14517076233667986, 0.07398207086537566, 0.0595993608502405, 0.052980682613062005, 0.17466912232339382, 0.08296829688229732, 0.046875889479581795, 0.09492172260901757, 0.05537014028855732, 0.02504438827080386, 0.02795953755932195, 0.05016716090696199, 0.05516288176711116, 0.1468761379697493, 0.06083226576447487, 0.24453946096556528, 22.732874700001307, 73.79342651367188, 39.4207957812718, 39.71297100612095, 38.54107046127319, 37.65501185825893, 21.878624950136455, 37.1779693875994, 24.413572720118932, 46.8684378351484, 49.92705569948469, 57.296593053000315, 58.13426440102713, 52.183132307870046, 59.49395043509347, 18.992852210998535, 0.2185791182730879, 0.3088425690574305, 0.42460978989090237, 0.9326091451304299, 0.6159860864281654, 31.559114047459193, 67.28231130327497, 56.311362811497276, 60.09455272129604, 55.49852779933384, 48.141618796757285, 48.233543464115684, 56.082919938223704, 58.1852468081883, 52.57503502709525, 52.63632161276681, 50.08693374906267, 55.45109939575195, 55.350496428353445, 62.10461793627058, 38.782436983925955, 41.77280616760254, 57.09020376205444, 42.950810704912456, 46.187976428440635, 42.001228196280344, 55.60953222002302, 75.79598767416817, 61.324821608407156, 52.07304504939488, 57.863215173993794, 54.40498903819493, 54.79877124513899, 53.52554164613996, 50.41723721367972, 51.64336150033133, 49.78951958247593, 49.74306740079607, 48.0695937701634, 49.29278244291033, 55.10963017599923, 53.95187963758196, 53.10925074986049, 55.70024790082659, 52.87876163210188, 50.628997462136404, 48.48983819144112, 48.300989627838135, 50.29637677328927, 49.08106388364519, 47.116422516959055, 50.28009019579206, 54.06753935132708, 45.88280807222639, 43.14550270353045, 46.02631964002337, 47.913005692618235, 25.20877320425851, 24.49084884779794, 44.54908398219517, 37.22381360190255, 34.501585824149, 42.146466391427175, 36.70009313310896, 44.93891961233956, 44.881530966077534, 44.05581399372646, 44.970026697431294, 45.407791001456125, 49.239698205675396, 49.52503292901175, 48.92878368922642, 46.33164433070591, 47.035093852451865, 46.52263641357422, 47.33076402119228, 45.23515953336443, 47.961000374385286, 49.20909833908081, 50.76136064529419, 52.62571171351841, 52.03315544128418, 50.58053377696446, 49.384825229644775, 43.52287673950195, 42.37877593721662, 47.403845173971995, 50.77345745904105, 52.082140241350444, 46.74682004111153, 51.699551582336426, 47.9707521711077, 38.605358668736045, 38.502633026668, 30.604122366224015, 37.17486701692854, 45.12054552350725, 40.65593882969448, 42.07544885362898, 42.35387011936733, 43.283115250723704, 43.67003958565848, 37.82342576980591, 33.16441890171596, 45.038480349949424, 61.625511850629536, 52.4718473298209, 53.92285353796822, 57.6767463684082, 52.26097992488316, 47.696600573403494, 46.345606735774446, 47.12520156587873, 46.846568380083355, 50.88948195321219, 52.71815749577114, 58.30463423047747, 54.06042787006923, 50.548915999276296, 6.989077014582498, 1.0595521905592509, 1.557725327355521, 0.20945156019713196, 1.5278706550598145, 30.744274480002268, 59.90867451259068, 45.5437707219805, 62.797249112810405, 56.87491730281285, 66.95254979814801, 13.087356754711696, 20.79324858529227, 28.582851443971904, 21.242800508226665, 39.68322924205235, 53.937375273023335, 29.87045165470668, 45.842828137534006, 58.70767838614327, 45.05652829578945, 0.8540263761367116, 0.1542610145573105, 0.07358008636427776, 0.060160244682005475, 0.1598699071577617, 0.06966349402708666, 0.029968086031398604, 0.0377588045916387, 0.4066578431853226, 0.25153651407786776, 0.21046377159655094, 0.12732903685952934, 0.21091448169733795, 0.11330024392477103, 0.17701845483056136, 0.16016539558768272, 0.24428919010928699, 0.26235703059605187, 0.3491208420268127, 0.36725954871092525, 31.527715138026647, 88.96566581726074, 47.64043481009347, 54.28624432427542, 44.566975593566895, 54.708969252450125, 30.48474884033203, 35.8052659034729, 33.27380091803414, 56.17495925085885, 55.225856167929514, 63.325756890433176, 63.568929944719585, 59.44183199746268, 67.41327789851597, 22.543902805873326, 0.24926182042275155, 1.4877264606101173, 0.293091599962541, 1.7324138964925493, 0.6763532842908586, 36.423926557813374, 69.65606607709611, 60.3907961164202, 61.37350763593401, 58.68335969107491, 50.13148559842791, 49.45757981709072, 59.10658836364746, 60.79176276070731, 53.38134568078177, 51.16969238008772, 52.34431661878313, 55.027109895433696, 54.85692419324602, 60.20233317783901, 41.81066690172468, 52.689649036952424, 55.40698528289795, 43.40060928889683, 47.46356841496059, 48.57345976148333, 58.008804253169465, 67.9191414969308, 58.03065286363874, 53.49974298477173, 59.49133791242327, 57.29823630196707, 54.158213342939106, 53.81680318287441, 51.068710735866, 55.80669430324009, 52.75387471062796, 51.82465042386736, 46.892436913081575, 48.47035196849278, 55.258526597704204, 52.814324038369314, 54.02871281760079, 56.18963384628296, 54.170765263693674, 54.85019138881138, 52.6256491797311, 54.138334546770366, 54.08855070386614, 52.739394664764404, 52.11810064315796, 55.30999885286604, 59.0980281829834, 51.40960325513567, 48.79276922770909, 50.46433210372925, 54.58446795599801, 25.69638041087559, 30.29237754004342, 48.77083029065813, 37.862568446568076, 44.989193303244456, 47.09515060697283, 47.38363981246948, 55.42716632570539, 51.14420986175537, 48.21535655430385, 52.96531881604876, 52.55207123075213, 57.54122175489153, 54.18130915505545, 54.50409814289638, 51.11246354239327, 54.47405760628836, 54.06827933447701, 54.693912506103516, 53.42433418546404, 53.06824595587594, 52.269508838653564, 52.88157912663051, 55.95242582048689, 55.9755528994969, 50.10636786052159, 48.2436774117606, 45.6629809652056, 43.72926950454712, 49.4870262827192, 51.66020393371582, 54.42360326222011, 49.37647696903774, 53.712524618421284, 48.912194865090505, 41.5424872807094, 36.28721727643694, 32.83356652941023, 39.67670488357544, 47.54330594199044, 41.67779997416905, 45.94088111604963, 46.76432255336216, 43.61340134484427, 45.72156122752598, 39.874436719076975, 35.930621828351704, 41.97746883119856, 56.31956515993391, 57.31374815532139, 56.54023994718279, 59.42672661372593, 56.8747991834368, 51.511873790196006, 51.09587819235665, 51.16073267800467, 49.11867448261806, 54.274036339351106, 54.43986552102225, 62.45125661577497, 56.41013492856707, 57.11651659011841, 10.318218214171273, 1.5066631244761604, 2.1241361796855927, 0.31581386498042513, 2.2720824352332523, 30.793700490679058, 64.81402628762382, 49.25525869641985, 68.35288974217006, 59.76394353594099, 73.05515262058803, 17.756052017211914, 22.74961985860552, 30.10706560952323, 27.3110670702798, 73.56304509299142, 57.076262201581685, 37.622324057987754, 58.60280227661133, 63.583764348711284, 57.85228565761021, 2.126924578632627, 0.3095230039741312, 0.3021805765373366, 0.1851303545492036, 0.32771170511841774, 0.09814286404954535, 0.11737111476915223, 0.12676707415708474], [0.1793610155582428, 0.04675415011921099, 0.22832526958414487, 0.071426463712539, 0.1364788780254977, 0.037380256690084934, 0.08103194792887994, 0.17505393310316972, 0.08793935299451862, 0.028028965262430053, 0.12430716758327824, 0.20815300701984338, 8.533489159175328, 65.56968457358224, 40.0714042527335, 42.09856898444039, 25.820605516433716, 47.35627433231899, 23.70912092072623, 26.4518597807203, 7.6165458134242465, 12.619606631142751, 54.6273626599993, 52.06054176603045, 60.20033209664481, 47.4228241784232, 55.5686559677124, 30.917944703783306, 0.23366102469818933, 0.17560085946960108, 0.46995194256305695, 0.7920542529651097, 0.43068756375994, 22.502307415008545, 64.38667038508824, 54.934195109776084, 60.37162603650774, 50.225157737731934, 48.25179985591343, 50.951675278799875, 58.39091001238142, 56.19169051306588, 57.94334874834333, 50.967676980154856, 46.22375617708479, 49.825288908822195, 55.40123912266323, 53.01694393157959, 57.14892646244594, 34.847171851566856, 32.96559967313494, 48.62492854254586, 55.00491040093558, 68.52683094569615, 70.17759091513497, 59.57753726414272, 55.88596977506365, 60.835015296936035, 53.94186380931309, 56.58785595212664, 51.21889952250889, 51.324387073516846, 48.83737318856375, 47.013297353472026, 46.8003385407584, 44.043932574135916, 45.22286122185843, 45.76519591467721, 48.533017771584646, 52.51239354269845, 52.26911973953247, 53.753710065569194, 52.288116114480154, 52.34547001974923, 47.07060262135097, 46.443079539707725, 47.186849457877024, 46.29880714416504, 46.1839325768607, 46.86357409613473, 44.905008929116384, 39.47765636444092, 35.41219241278512, 36.116788387298584, 35.27165467398507, 4.056265839508601, 13.013723220144, 30.971869673047745, 18.801262583051408, 24.019354513713292, 25.034750359398977, 32.85713134493147, 36.64013017926897, 34.38074622835432, 30.46469633919852, 34.963647978646414, 35.80005822862898, 44.34956298555647, 40.25843933650425, 41.38661139351981, 42.29105493000576, 44.674551078251426, 41.73657478604998, 38.64533860342843, 37.585185936519075, 41.95194114957537, 47.43057836805071, 48.955103465488975, 48.03149332318987, 49.557588713509695, 48.7183574948992, 44.56841039657593, 43.33009549549648, 41.13113307952881, 44.79780169895717, 47.75479521070208, 45.475379603249685, 47.89837278638567, 45.03583656038557, 48.21090970720564, 48.35547392708914, 45.57895987374442, 36.64493833269392, 22.311358758381434, 29.035999059677124, 39.41329867499215, 40.96967431477138, 40.18989883150373, 41.9612968989781, 43.85871097019741, 48.95352622440883, 65.34353460584367, 74.36333165849958, 50.4954183442252, 55.21868562698364, 54.19386454990932, 57.4436343056815, 49.92027773175921, 45.04832942145211, 48.55765955788748, 48.33717584609985, 48.46924025671822, 50.9788635798863, 51.43639203480312, 53.91528000150408, 54.88047511237008, 44.95502553667341, 1.6928903715951102, 1.5003375496183122, 0.4312309617442744, 0.24528818364654267, 2.0210807153156827, 39.38323729378836, 46.80025168827602, 47.345525469098774, 53.68930721282959, 50.878211975097656, 45.90129722867693, 7.994814429964338, 15.125432763780866, 18.64207935333252, 18.714159965515137, 39.3888201713562, 32.310624258858816, 26.661777019500732, 49.13007647650582, 52.37038973399571, 29.399700777871267, 0.33592751568981577, 0.12379669211804867, 0.09725350820060287, 0.045822222983198505, 0.07779664546251297, 0.026652546799076453, 0.031972529366612434, 0.02039265922004623, 0.201681913541896, 0.03787680522405675, 0.0841798008020435, 0.07943770954651491, 0.05080455634742975, 0.022903919020401578, 0.018181396714810814, 0.07814462536147662, 0.07449059214975152, 0.024481663912800804, 0.01156603142486087, 0.1478967767740999, 8.019609076636177, 73.0789293561663, 44.015104498182026, 38.98259721483503, 35.38728312083653, 49.6235340663365, 16.603227751595632, 37.716454778398784, 11.755753602300372, 12.255324738366262, 54.22727148873465, 60.013536725725444, 59.82853399004255, 51.78194679532732, 58.903624534606934, 35.74019602366856, 0.4803118695105825, 0.3045015462807247, 1.4900972076824732, 0.8853632403271539, 0.41649822943976944, 26.658023255211965, 68.71300097874233, 54.556220054626465, 61.81913035256522, 54.22704914637974, 49.135054860796245, 54.64452471051897, 61.70069830758231, 56.70474897112165, 61.25214345114571, 53.50348458971296, 50.05871364048549, 53.52733080727713, 58.918632643563406, 54.59689828327724, 57.19477415084839, 35.08147553035191, 38.80965655190604, 54.5621086529323, 60.66576412745884, 68.70362785884312, 68.40938554491315, 55.17972707748413, 57.696152687072754, 61.27617032187325, 55.45424345561436, 57.96696220125471, 55.97909300667899, 55.43790476662772, 53.3133089201791, 50.485131536211284, 50.26497438975743, 47.89102506637573, 48.28462314605713, 50.874585015433176, 51.29075084413801, 54.324768611363, 55.54056092670986, 55.8040783064706, 53.77403007234846, 54.96568087169102, 48.665589400700156, 48.666676793779644, 49.44410726002285, 48.30376195907593, 50.64400904519217, 51.49760219029018, 49.73587254115513, 44.28627879279, 40.45101908275059, 44.29217781339373, 44.39435107367379, 20.74541371209281, 31.71677909578596, 46.03103746686663, 32.13782255990164, 37.22608913694109, 39.37023721422468, 41.8619168145316, 40.519142695835654, 45.39807047162737, 45.66924476623535, 43.426279408591135, 44.60314791543143, 51.29819583892822, 46.60340574809483, 49.56683676583426, 48.50644786017281, 51.42343364443098, 48.724774156297954, 47.814330850328716, 43.547153745378765, 48.7126703943525, 50.888439723423545, 50.39420393535069, 50.74808611188616, 51.07820544924055, 51.111918108803884, 45.60108641215733, 42.81398677825928, 44.24517672402518, 46.55635254723685, 49.980789593287874, 48.11466326032366, 50.64391524451119, 48.466558252062114, 49.39993756158011, 48.314048767089844, 47.94549199513027, 39.17250885282244, 23.886425052370342, 31.969294003077916, 41.31477744238717, 42.97836378642491, 41.459199224199565, 42.61655024119786, 43.48419959204537, 47.68937792096819, 54.774921553475515, 71.41101428440639, 54.065736293792725, 55.719720227377756, 56.63587842668806, 56.60503189904349, 48.39150728498186, 46.872561591012136, 49.66944081442696, 51.446178572518484, 49.86589070728847, 52.43577575683594, 53.59159469604492, 58.423774991716655, 56.67847783224923, 50.558768544878276, 2.0014537913458685, 1.2474392971822192, 2.443376375096185, 0.2542129818882261, 2.8191164987427846, 45.94826357705252, 55.25623369216919, 56.0583233152117, 58.61496162414551, 59.274192810058594, 51.10349341801235, 9.611216425895691, 24.400994743619645, 24.93711427279881, 20.55872082710266, 38.13267271859305, 43.84567962374006, 26.255705186298915, 47.273844378335134, 57.064874104091096, 32.13065896715437, 0.22379280493727752, 0.044099911116063595, 0.07772780808487109, 0.026559696067124605, 0.09658059823725905, 0.057118894665368965, 0.050835463617529185, 0.058692139174257, 0.5042707238878522, 0.16969850047358445, 0.35842263432485716, 0.2407461516559124, 0.14967915256108555, 0.164063728547522, 0.17115614297134535, 0.2637196374791009, 0.3374585892472948, 0.14934017003646918, 0.36312208643981386, 0.3427274136670998, 13.35563017640795, 92.96406923021588, 48.90951633453369, 55.683704239981516, 36.02356093270438, 67.84446225847516, 31.811931201389857, 33.88745539528983, 15.58149688584464, 18.454401561192103, 60.384619167872835, 65.21611159188407, 68.78059305463518, 57.465635776519775, 64.23128087180001, 39.42042057854788, 1.188653085912977, 0.22957382830125944, 1.4342878652470452, 2.0660438111850192, 0.5613589148436273, 34.355986322675435, 72.00318145751953, 60.721676281520296, 63.178545406886506, 59.26418740408761, 51.35511895588466, 56.09982490539551, 63.185979979378835, 60.0240215573992, 59.85842514038086, 55.39493015834263, 49.86587681089129, 52.927044664110454, 59.613633155822754, 57.77894047328404, 55.60250759124756, 37.701467514038086, 45.12867838995797, 54.4566593170166, 58.830598967415945, 68.39329351697648, 62.958669662475586, 55.990463733673096, 57.721089771815706, 65.38719013759068, 56.519655908857075, 58.37372016906738, 58.32340826307024, 58.73913982936314, 54.52614477702549, 55.582239695957725, 55.57351623262678, 48.44693653924124, 48.43917540141514, 51.349932125636506, 52.52295480455671, 53.27546208245413, 55.601381983075825, 59.24630274091448, 56.30853836877005, 57.04521765027727, 56.29830714634487, 51.53610563278198, 52.71961661747524, 51.913389342171804, 53.561575004032676, 54.0034943308149, 55.33207675388881, 47.68356575284685, 47.504371711185996, 48.74001502990723, 51.76941224506923, 19.861576795578003, 33.78579977580479, 46.53754029955183, 38.35219757897513, 43.752000536237446, 44.410863467625205, 52.97229133333479, 53.45394045966012, 55.56191968917847, 50.746915340423584, 48.880757740565706, 52.08405794416155, 57.595275265829905, 51.118428570883616, 52.148547649383545, 54.16141993658883, 59.34734344482422, 54.19697734287807, 51.949645042419434, 53.39622524806431, 53.035745756966726, 55.51882348741804, 55.048555510384695, 53.551441056387766, 52.2566477230617, 49.77174261638096, 46.41885117122105, 44.64920057569231, 43.41870239802769, 48.02683803013393, 52.18888194220406, 51.43737867900303, 50.73977606637137, 51.18548910958426, 53.30237940379551, 50.05597257614136, 48.1369982446943, 40.96083968026297, 29.31683656147548, 37.62287296567644, 42.48671620232718, 46.87757471629551, 44.19434717723301, 44.821599279131206, 44.24038246699742, 46.12939964021955, 49.30298934664045, 69.9148656300136, 64.09923035757882, 57.15780973434448, 60.74405642918178, 62.921538489205496, 54.31924131938389, 50.206095354897634, 53.05142436708723, 53.722780159541536, 51.972379548209055, 57.74543625967843, 58.34553827558245, 61.67956188746861, 61.24932248251778, 55.935777936662944, 4.178998385156904, 2.691784028496061, 3.163073390722275, 0.3663398894880499, 2.6951421797275543, 48.834260395595, 58.91561017717634, 56.762436389923096, 63.95653520311628, 61.98999350411551, 57.74705866404942, 13.610215646880013, 21.30001197542463, 26.135965142931255, 26.41671405519758, 57.92137507029942, 43.3404552595956, 38.2232529095241, 60.38671057564871, 65.89028835296631, 47.770484243120464, 0.6049929506012371, 0.20756171803389276, 0.29332794728023664, 0.12776886325861725, 0.22086910610752447, 0.11157392191567592, 0.1072793041488954, 0.20685140043497086], [0.14612566466842378, 0.13597959838807583, 0.035011389159730504, 0.07040950256798949, 0.0363473465799221, 0.05700467686567988, 0.05923720635473728, 0.026416486162426214, 0.050503310547875505, 0.016424683122230426, 0.06354155431368522, 0.07912926788308791, 0.9449557683297566, 58.767057691301616, 48.190867628370015, 42.384212902614046, 35.93701764515468, 41.13952650342669, 38.22203002657209, 21.73114596094404, 22.17233920097351, 5.732083184378488, 45.421819414411274, 55.08151429040091, 53.137585503714426, 51.432980469294954, 51.368935448782786, 43.88839714867728, 0.61587855219841, 0.3182730387364115, 1.2969089512314116, 0.1484247584428106, 0.30895200318523813, 10.655111176627022, 62.07082884652274, 54.600716318402974, 60.004858425685335, 51.70071193150112, 50.690551553453716, 51.2811519077846, 59.79302869524275, 56.06560502733503, 56.62003653390067, 51.039271218436106, 49.86961146763393, 46.623941149030415, 55.57818194798061, 53.276691913604736, 61.81403037479946, 37.99211760929653, 45.45348235539028, 56.49806438173567, 54.103819370269775, 51.72613191604614, 43.81378739220755, 52.661428928375244, 51.81944274902344, 52.069313866751536, 52.34669637680054, 53.061162267412456, 48.714605467660085, 54.95187480109078, 47.221312522888184, 46.31114019666399, 45.303439480917795, 42.51428665433611, 40.30631242479597, 41.404951163700645, 47.643227985927034, 49.045228549412315, 54.11897686549595, 53.61051116670881, 49.861819062914165, 52.38566534859793, 49.94383907318115, 47.927805355616975, 43.74730702808925, 43.92475012370518, 43.85128682000296, 48.09015348979405, 46.46890599387032, 38.20470469338553, 34.238506180899485, 34.1618640763419, 31.72079168047224, 2.3851802178791592, 15.337285075868879, 27.57348142351423, 19.18395893914359, 23.303664003099712, 27.91117603438241, 32.839823382241384, 32.45304495947701, 31.923439366476877, 30.100040980747767, 31.07205922263009, 33.74611861365182, 41.249460901532856, 41.24804694311959, 42.34238474709647, 42.1230857031686, 44.54981354304722, 40.98245552607945, 39.66378123419625, 37.86420127323696, 45.011743681771414, 44.661019461495535, 47.21173790522984, 48.615079471043174, 48.19062444141933, 49.37004293714251, 46.48559209278652, 41.48158632005964, 41.97778844833374, 45.04914583478655, 47.511309487479075, 50.076466287885395, 45.72794314793178, 46.38723339353289, 47.01876905986241, 49.73615394319807, 50.32653195517403, 52.06731973375593, 48.26284401757376, 37.180307456425254, 36.04376629420689, 39.0694705418178, 40.3151262147086, 47.39972141810826, 52.91529178619385, 57.51997763769967, 46.45489495141165, 28.149622576577322, 42.44786187580654, 58.39721202850342, 54.70856278283255, 54.584450585501536, 44.3646753174918, 44.55387823922293, 53.28868450437273, 51.38897752761841, 50.766286918095176, 49.58669471740723, 52.69997753415789, 52.473382881709504, 51.20643792833601, 33.23749658039638, 0.07637286186218262, 2.249378979206085, 2.0538779497146606, 0.1597029875431742, 6.293732566492898, 50.65587656838553, 45.853872299194336, 55.10718093599592, 51.00042731421334, 54.86038439614432, 38.251771790640696, 4.716328203678131, 26.96321940422058, 17.59839391708374, 23.316903795514786, 36.27233076095581, 30.176815101078578, 29.279886041368755, 40.11340611321585, 57.45955262865339, 14.298132470675878, 0.5958843507937023, 0.13366721889802388, 0.11584396314408098, 0.07296749816409179, 0.0486039790724005, 0.006283059125832681, 0.0930256379236068, 0.0383357391692698, 0.18234540256006376, 0.06925257321979318, 0.03875917216230716, 0.12166905057217393, 0.021632145923961486, 0.03425114156146135, 0.047537054001752815, 0.04093154612928629, 0.054131050527627976, 0.062338783139629025, 0.030649179127067327, 0.06258510492209877, 0.9833874489579881, 66.11873122623989, 55.1053500856672, 41.073383126940044, 36.2005523954119, 51.629756927490234, 25.173882825034006, 26.93206889288766, 27.70821394239153, 5.428331392151969, 48.52486058643886, 60.29454272133963, 59.83488464355469, 56.56360673904419, 55.178094250815256, 50.952102593013215, 1.7743837301220213, 0.5880025965826852, 2.818693961415972, 1.0878241934946604, 0.5036523342132568, 13.645687937736511, 70.08834130423409, 55.69023207255772, 63.17249352591378, 53.30009344645909, 52.54770776203701, 53.25582994733538, 61.773286138262065, 58.45036574772426, 59.942678996494834, 54.694975580487935, 53.862376417432515, 48.04115826742989, 59.27391488211495, 55.143954277038574, 64.5115225655692, 41.62858240944998, 52.56666592189244, 56.387751306806294, 52.816245215279714, 50.505354268210276, 46.34212221418108, 56.118918555123464, 55.94141639981951, 52.287952831813264, 55.734245436532156, 53.09888751166207, 54.11805622918265, 54.431767395564485, 53.23241799218314, 51.50739915030343, 49.840474196842735, 47.169777733939036, 47.50815500531878, 45.92469528743199, 51.15697022846767, 53.11399289539882, 54.00458172389439, 53.82368189947945, 52.16365998131888, 52.13227844238281, 50.848053319113596, 50.227947439466206, 47.31492907660348, 50.23036541257586, 50.62406424113682, 51.10961478097098, 50.40766259602138, 43.205048765454976, 40.88842208044869, 45.22990322113037, 42.25971508026123, 17.819678408758982, 35.59227582386562, 42.512660775865825, 29.20978913988386, 34.3992805480957, 36.93797166006905, 38.82300056729998, 40.265533447265625, 43.721623011997764, 41.93787104742867, 40.560863154275076, 42.9932086127145, 49.34348692212786, 47.097523416791645, 45.96508169174194, 46.17259659085955, 49.89556993756975, 47.79273584910801, 45.95493384769985, 43.713163580213276, 50.34294360024588, 48.27070937837873, 52.39471885136196, 51.17090484074184, 51.6228677885873, 49.86469561713082, 47.86246102196829, 42.4021566254752, 43.54279375076294, 45.75243902206421, 50.52539982114519, 51.63950177601406, 46.81742763519287, 47.51873016357422, 50.5315455027989, 52.88499764033726, 51.0682486806597, 53.09851230893816, 48.559566838400706, 43.177321978977744, 40.3426376070295, 42.1997833933149, 41.212767464774, 45.801107679094585, 49.4673524584089, 52.4063640322004, 47.30191510064261, 35.20205109460013, 43.67888811656407, 56.944677216666086, 54.46562944139753, 53.838269642421174, 45.69135740825108, 48.357183183942524, 54.67259195872715, 51.34454032352993, 52.8024982043675, 52.9226290839059, 56.221658093588694, 55.942003522600444, 55.73827886581421, 38.00026437214443, 0.1280933522752353, 2.7671691605022977, 3.5863800133977617, 0.8925662423883165, 9.42486139706203, 57.5347877229963, 48.15725571768624, 60.69240352085659, 54.90859794616699, 70.79768984658378, 35.786755902426584, 7.779626114027841, 34.80691051483154, 23.564923218318395, 21.953677654266357, 39.15623269762312, 40.94124228613717, 24.329331023352488, 45.61683797836304, 63.87257317134312, 19.36434633391244, 0.5283911781651633, 0.18677976461393492, 0.038747257087379694, 0.042242675953145535, 0.005655225940115217, 0.00960189222158598, 0.07470648163663489, 0.03500698207478438, 0.5862195151192802, 0.2243837546557188, 0.1474396748734372, 0.3346705974212715, 0.13855489662715367, 0.2342141664453915, 0.18642638357622282, 0.25338354068143026, 0.16428674943745136, 0.11360703674810273, 0.10298789585275309, 0.1835275734109538, 2.080234421151025, 85.96157046726772, 60.58151721954346, 58.101760728018625, 46.11376619338989, 62.01350620814732, 53.78356647491455, 25.59209837232317, 29.68061297280448, 8.741907324109759, 55.12594107219151, 64.68476894923619, 63.047766413007466, 62.298104422433035, 60.92798914228167, 54.834151472364155, 3.510295936039516, 0.5807487315365246, 3.6635931730270386, 1.4368174437965666, 0.7191968538931438, 17.871313946587698, 74.11579513549805, 60.84185232434954, 66.06256893702916, 57.78867489950997, 55.230733803340364, 55.959325381687705, 64.42141832624162, 60.61468097141811, 60.48707730429513, 55.481473445892334, 55.56350040435791, 49.08979776927403, 59.707232339041575, 56.42178358350481, 62.293268476213726, 40.94253117697579, 51.056384631565635, 54.91679334640503, 51.77029814038958, 50.40251745496477, 48.75418240683419, 57.44972092764718, 56.40881477083479, 54.1938784463065, 58.630358832223074, 56.57479681287493, 55.725754737854004, 58.58709934779576, 54.57158946990967, 55.78452260153634, 51.88854258401053, 48.93135799680437, 48.70526014055525, 48.20003925051008, 51.57499122619629, 53.6116680417742, 56.19650214059012, 57.634695870535715, 51.08014052254813, 55.35773992538452, 55.724323408944265, 54.083589690072195, 50.063876152038574, 50.523808683667866, 52.5291873386928, 56.60618530000959, 55.76874671663557, 50.18642847878592, 47.04619707380022, 50.535158566066194, 46.770086084093364, 17.180791548320226, 32.15155567441668, 47.13985531670706, 38.60656418119158, 42.475300312042236, 46.793171473911826, 49.92521095275879, 50.674706186567036, 51.51135267530169, 47.01453760692051, 47.499945708683555, 47.34791912351336, 54.704887185777935, 52.1246771131243, 49.50749914986746, 50.64965098244803, 55.57301943642752, 52.82837677001953, 53.17645372663225, 50.114941937582834, 55.96984148025513, 52.89938041142055, 54.521593706948416, 57.77413926805769, 50.512298992701936, 48.48608269010271, 48.16217851638794, 43.121663434164866, 45.67467825753348, 45.39992216655186, 52.059485639844624, 54.038971832820344, 49.76196302686419, 50.374967847551616, 53.49691159384591, 55.27380568640572, 54.285261154174805, 54.24579191207886, 47.81486586162022, 46.274700369153706, 46.04667091369629, 45.27454192297799, 45.48653841018677, 45.64055218015398, 48.86559329714094, 54.15627826963152, 57.73194285801479, 47.094761507851736, 47.573634828839985, 63.128483636038645, 59.75069332122803, 58.384955406188965, 48.50755957194737, 50.343256269182476, 59.781098638262065, 53.47264848436628, 55.86141831534249, 55.930556365421836, 56.92726503099714, 60.13267053876604, 59.399177006312776, 42.65132597514561, 0.6627358464258057, 4.3990625994546075, 9.517038805144173, 0.904303215444088, 8.873592189380101, 58.78318446023123, 53.87580728530884, 63.74421215057373, 60.86690752846854, 67.47736808231899, 44.71052190235683, 7.850897261074611, 36.66261454990932, 26.53505403654916, 33.61491925375802, 55.176325934273855, 44.386544772556846, 42.23000805718558, 53.307114601135254, 75.58408846173967, 28.234315906252178, 0.7586912289261818, 0.2775324120053223, 0.12670375326914446, 0.309694483344044, 0.23091787046619824, 0.17051358387938567, 0.178537179050701, 0.17816251915480408], [0.2782566531428269, 0.06821027557764735, 0.18370977363416127, 0.08191215712577105, 0.023895750620535443, 0.06414528084652764, 0.038997975776770284, 0.07493245415389538, 0.06799784661935908, 0.15377945825457573, 0.03298063562916858, 0.2811422725873334, 0.09382583427109889, 35.06752702168056, 55.06076349530901, 43.07915088108608, 46.14521721431187, 27.425628968647548, 44.25951780591692, 17.975877387183054, 20.893141099384852, 2.7278573385306766, 23.386359725679668, 60.05339159284319, 53.18621941975185, 65.94784723009381, 46.697960308619905, 52.38474471228463, 5.50320257459368, 0.6397772069488252, 1.5750543517725808, 0.48445994406938553, 0.30224883716021267, 2.7891526094504764, 56.745851039886475, 54.90042339052473, 59.11333506447928, 54.3294586454119, 54.58222368785313, 53.99377032688686, 58.18523291179112, 57.60177183151245, 59.8668463570731, 53.627405711582725, 51.39163521357945, 49.266594682421, 56.26664073126656, 53.1810291154044, 58.244431563786094, 41.43174341746739, 41.70738887786865, 48.98585966655186, 47.84756408418928, 49.87065369742257, 47.09834677832467, 53.26755155835833, 57.048073359898154, 54.967014925820486, 51.084024565560476, 50.50907850265503, 50.04065874644688, 51.70773656027657, 44.656860964638845, 45.146743706294465, 45.01853901999337, 43.25821985517229, 41.250332900456016, 41.37064790725708, 45.623181683676584, 50.99459777559553, 53.592977387564524, 51.48665877750942, 48.29057775224958, 54.82054342542376, 49.146279675619944, 49.90524183000837, 42.976182052067344, 44.84861734935215, 46.23731558663504, 48.606651306152344, 44.8399772644043, 37.38038778305054, 31.846060752868652, 34.07898596354893, 28.102557216371807, 2.700681848185403, 17.893888643809728, 26.641835689544678, 22.96170493534633, 22.250447375433787, 27.072915826525005, 36.9853583744594, 33.25094134466988, 31.13056652886527, 34.07726975849697, 33.825130053928916, 33.30641576222011, 39.12157160895211, 41.65503420148577, 42.16544539587838, 37.70393759863717, 41.681621483394075, 39.78642041342599, 40.20409747532436, 43.39590883255005, 45.70661565235683, 45.64458213533674, 44.18012421471732, 46.346721921648296, 47.18150976725987, 45.019487449101035, 44.26818915775844, 40.49307305472237, 41.588435717991416, 45.5888923236302, 47.42503717967442, 48.544600418635774, 48.30987637383597, 48.41134091785976, 47.68933623177664, 48.076406478881836, 50.404028688158306, 48.09130341666085, 54.55785288129534, 60.17070497785296, 59.281224387032644, 54.078409808022634, 48.07477365221296, 44.201715741838726, 39.758516447884695, 32.412067958286826, 26.64792057446071, 43.38175882611956, 58.015860148838584, 52.648685932159424, 54.58860213415963, 49.20238637924194, 45.42829860959734, 48.09015001569475, 53.87728377750942, 52.40258073806763, 52.93574033464704, 51.457236630576, 53.952174936022075, 47.720370360783164, 55.79878030504499, 14.630015781947545, 0.9108818024396896, 1.1179772040673663, 1.4413872957229614, 1.3418566307851245, 23.61109573500497, 47.80460684640067, 40.62344557898385, 60.685462270464214, 48.33437919616699, 45.914967809404644, 19.794702121189662, 9.344148516654968, 39.573465074811665, 12.393910033362252, 34.03019223894392, 42.19343621390206, 21.198437997273036, 33.517495087214876, 43.22895751680647, 51.355212756565635, 9.325365798813955, 0.7232820689678192, 0.15693324830915245, 0.044765805027314594, 0.09917936700263194, 0.056192982742296796, 0.05636085569858551, 0.06830965381647859, 0.0325244293947305, 0.11590121792895453, 0.00855003486919616, 0.07500100654682942, 0.09043389878102712, 0.09043436697018997, 0.03453407030818718, 0.10083843262067863, 0.046477796376815865, 0.06471738086215087, 0.02723159162061555, 0.05009796051308513, 0.2531354954200131, 0.07028661987611226, 36.033291884831016, 65.49328218187604, 44.68266657420567, 46.71876668930054, 42.75452062061855, 35.42583867481777, 18.123722893851145, 32.01081643785749, 2.920072738613401, 25.015920741217478, 65.85310854230607, 59.503115109034944, 69.17598724365234, 54.04893902369908, 57.05923564093453, 6.959728692259107, 0.6100288203784398, 4.146917683737619, 1.7839591077395847, 0.12569930431033882, 3.893544239657266, 61.32243142809187, 56.583530698503765, 62.74331719534737, 57.485201903751914, 59.01446219852993, 56.86484588895525, 60.99244063241141, 60.18508774893624, 61.99518380846296, 56.32137516566685, 54.94580902372088, 51.40668501172747, 59.51601096561977, 55.6655763898577, 59.59694358280727, 47.04762840270996, 43.71389314106533, 46.02273784364973, 49.323872157505576, 52.71409279959542, 54.328659602573936, 53.05778891699654, 58.72590351104736, 56.426553521837505, 53.43192856652396, 52.25045687811715, 52.29050629479544, 53.275010449545725, 49.817965507507324, 50.273093359810964, 49.57529272351946, 48.56100164140974, 44.158838408333914, 45.466402530670166, 50.60983780452183, 52.34651919773647, 51.70901502881731, 54.29060084479195, 50.71061100278582, 54.513995851789204, 50.63020992279053, 50.71853542327881, 46.23754487718855, 47.526769229343955, 52.16775941848755, 50.73284871237618, 50.84861612319946, 44.52787113189697, 40.5576947757176, 42.52222497122628, 37.78844158990042, 19.18185189792088, 36.89751924787249, 37.47505004065377, 28.96882734979902, 34.164174352373394, 36.77900382450649, 42.405790533338276, 39.561955383845735, 42.440027781895225, 42.21167523520333, 41.3795485496521, 38.85360390799386, 48.39134400231497, 49.198297364371165, 46.00167785372053, 44.6804188319615, 47.02456733158657, 45.69403593880789, 43.48276131493704, 47.53264045715332, 49.771127700805664, 49.411572320120676, 47.63357693808419, 49.38785811832973, 49.68256596156529, 47.2349796295166, 45.43393012455532, 41.500436782836914, 43.97340488433838, 49.60530546733311, 49.985979897635325, 50.216291836329866, 50.28210169928414, 49.20434577124459, 48.532399381910054, 48.6126059123448, 51.3633143561227, 52.10276596886771, 51.96929107393537, 55.32287039075579, 55.947912965502056, 58.22164147240775, 51.30579021998814, 46.4149740764073, 44.17612900052752, 37.635223388671875, 29.24838638305664, 44.95416743414742, 56.699287687029155, 52.8206330026899, 54.19843646458217, 50.349130971091135, 45.518375056130544, 49.12211384092058, 53.551746777125764, 56.68568658828735, 54.643343516758506, 54.48767607552664, 57.922580582754954, 48.22941623415266, 60.68997165134975, 16.19054123333522, 0.9547242841550282, 5.841030069759913, 2.464645028114319, 2.6813943002905165, 30.929666314806255, 57.008569376809255, 45.60336889539446, 67.24666704450334, 53.03751059940883, 50.5252434866769, 19.812446083341325, 17.14950728416443, 40.58484833581107, 18.939488308770315, 22.852703332901, 48.58572333199637, 26.33001443317958, 30.241527148655482, 50.04602970395769, 54.4384446144104, 10.457068409238543, 0.6653798531208719, 0.10471631453505584, 0.034600553169314346, 0.11363537237048149, 0.10362978319504432, 0.11418558284640312, 0.015396383657519306, 0.07303423208317586, 0.557346872985363, 0.1566135361790657, 0.1846103524523122, 0.23192326937402996, 0.2692809376333441, 0.13351036874311312, 0.18031726138932364, 0.19162282188023838, 0.11353207219924245, 0.2751432902046612, 0.13049407702471527, 0.43327660911849564, 0.17181994020938873, 52.22512722015381, 76.0665088381086, 54.61816324506487, 58.22831521715437, 43.42383711678641, 65.84684126717704, 20.06795219012669, 29.919155052730016, 5.604487333978925, 32.20037371771676, 72.63288279942104, 64.83912318093437, 75.89294283730644, 58.20011942727225, 63.30124364580427, 8.341171707425799, 1.5491738319396973, 5.585819261414664, 1.6793201054845537, 0.6116545360003198, 6.906339602810996, 73.90541757856096, 60.59343338012695, 66.07639585222516, 59.96309975215367, 61.603805678231375, 57.89591687066214, 62.763307162693565, 60.97789805276053, 63.56378132956368, 58.28997353145054, 57.192071301596506, 51.18020500455584, 59.37025165557861, 56.55920852933611, 58.73506818498884, 42.319573811122346, 44.66737011500767, 46.20793860299246, 49.465313162122456, 53.534692423684255, 54.47880322592599, 55.954472064971924, 61.06502151489258, 59.42178644452776, 56.29331486565726, 55.69290018081665, 55.833503927503315, 55.75497538702828, 53.19173628943307, 53.505492619105745, 53.98952497754778, 49.8344327381679, 45.85404600415911, 47.72358042853219, 54.248661518096924, 54.74587460926601, 55.29478924615042, 57.72781910215105, 51.33879763739449, 57.20828144890921, 52.45364999771118, 55.60434538977486, 49.00162165505545, 51.943454197474885, 54.69173077174595, 57.20893457957676, 55.38262837273734, 51.043144839150564, 45.520973682403564, 48.12707969120571, 42.82581608636038, 15.154894862856183, 29.37694890158517, 49.16154834202358, 39.48517778941563, 41.512443270002095, 44.34782941000802, 55.20985099247524, 51.088429723467144, 51.9902468408857, 50.49408081599644, 49.538759095328196, 44.876351084027974, 53.3095360483442, 52.40426567622593, 51.57633570262364, 45.428190912519185, 49.20365442548479, 50.10205997739519, 50.12171990530831, 53.988434110369, 53.5627874646868, 51.016460282461985, 49.99223327636719, 52.948518071855815, 47.31613458905901, 45.999753202710835, 46.61487374986921, 41.87079661233084, 44.38517945153372, 51.53203051430838, 52.82066774368286, 52.6920496395656, 51.56201893942696, 54.42619146619524, 50.93042073931013, 52.38090235846383, 54.49842146464756, 56.870501722608296, 54.338925565992085, 54.845417976379395, 56.471623011997764, 59.840936524527415, 52.21914482116699, 51.6032703944615, 48.95165021078927, 45.26237562724522, 35.7107321875436, 43.71976089477539, 59.737380572727744, 57.27455684116909, 58.088183947971885, 54.878373282296316, 47.42100027629307, 53.49568523679461, 57.04100704193115, 59.13574300493513, 58.04673099517822, 55.7282178742545, 59.39234692709786, 51.59597478594099, 66.02074078151158, 21.93799035889762, 1.0568236112594604, 7.204964927264622, 4.405304253101349, 3.6653528043201993, 30.30092035021101, 58.13175957543509, 49.22611100333077, 69.8236357825143, 54.20477669579642, 57.043341636657715, 25.51883830342974, 14.815042836325508, 50.03171294076102, 19.5285861151559, 46.38809149605887, 63.29956218174526, 29.739564963749476, 49.301978383745464, 54.079740388052805, 73.70241900852749, 19.464165891919816, 0.907298703278814, 0.4192524845046656, 0.30726220671619686, 0.37242368874805315, 0.28821344886507305, 0.20073443438325608, 0.17659523896872997, 0.23452097283942358], [0.17640466562339238, 0.07399699185043573, 0.09671490067350012, 0.16827585681208543, 0.06986634885626179, 0.020501265535131097, 0.06407363433390856, 0.07216992096177169, 0.0110095775785989, 0.13108080625534058, 0.0953131423198751, 0.12280706236405031, 0.1265956490699734, 14.986001525606428, 62.18550191606794, 45.447305406842915, 43.811220032828196, 22.038655860083445, 47.117947646549766, 21.55249908992222, 28.568763971328735, 6.545599120003836, 10.356913600649152, 63.86931446620396, 49.886464323316304, 53.509352343423025, 45.00473642349243, 50.745536123003276, 19.811521972928727, 0.14390886362109864, 1.889831849506923, 0.7652780126248087, 0.08571288960852794, 0.651228163923536, 24.89214379446847, 58.557117870875764, 56.918023926871165, 58.58292348044259, 57.76516566957746, 55.47318077087402, 59.59083611624581, 57.83047873633248, 55.385414600372314, 56.89364269801548, 52.46912016187395, 53.54212352207729, 53.88929026467459, 57.65776736395699, 47.00578982489449, 54.220903464726035, 47.71588182449341, 49.544922147478374, 55.41683782849993, 49.50008889607021, 47.359786646706716, 38.36637190410069, 41.569064140319824, 51.141913482121055, 51.11852584566389, 49.74713209697178, 51.69670282091413, 47.7367959022522, 43.03786815915789, 44.37921789714268, 43.66407455716814, 43.626877376011436, 40.42571026938302, 40.75627429144723, 40.999405656542095, 43.97826862335205, 45.18189116886684, 44.16879865101406, 46.210085596357075, 49.13648966380528, 50.15886844907488, 51.04867213112967, 44.499796935490195, 43.74204724175589, 44.25083950587681, 45.389774322509766, 43.09409645625523, 35.91157681601388, 31.28110272543771, 32.360807623182026, 31.76480504444667, 4.834465818745749, 17.745796476091655, 28.76836313520159, 23.2965247290475, 22.604070731571742, 24.308988434927805, 30.868463107517787, 32.963487420763286, 31.98801245008196, 32.737135955265586, 34.957123620169504, 32.10079908370972, 39.078496251787456, 41.1796419279916, 43.342147145952495, 37.46330063683646, 40.01329646791731, 40.54537909371512, 42.94832672391619, 45.99166897365025, 46.69011231831142, 44.50005054473877, 40.937330450330464, 42.62836217880249, 41.81885882786342, 41.79413366317749, 41.699346337999614, 41.020955494471956, 43.03591571535383, 47.03429133551461, 49.29727445329939, 51.17518840517317, 45.999433585575645, 49.45675992965698, 48.773397650037495, 49.09614494868687, 47.237595626286094, 50.146267890930176, 45.89713873182024, 46.82532773699079, 49.03251682009016, 47.462303842817036, 48.389596530369346, 44.60472863061087, 38.876929010663716, 47.52199581691197, 38.18479115622384, 43.9282728603908, 55.51241030011858, 51.05008956364223, 54.511070660182405, 48.749634810856406, 47.71156699316842, 52.17254325321743, 55.91374519893101, 55.40528644834246, 52.8539183480399, 51.07917472294399, 49.790697302137104, 54.09037808009556, 42.56298657826015, 1.526423909834453, 0.44887688915644375, 0.5701871982642582, 0.7387242774878229, 1.3836814207690102, 40.04076964514596, 56.44498709269932, 49.44751187733242, 57.941823618752615, 41.2285919870649, 56.06488241468157, 14.176731807844979, 12.010880163737706, 37.771515778132844, 12.788842167173113, 40.97163370677403, 35.062708445957725, 26.013513565063477, 34.74101032529558, 48.92898866108486, 34.96775088991438, 1.377056204846927, 0.13005874252745084, 0.09018942261380808, 0.04982786964891212, 0.09434732235968113, 0.04650877150041716, 0.027155292054106082, 0.08390154037624598, 0.052066485597086806, 0.06370812787541322, 0.0642170427100999, 0.045481164141425064, 0.10754745440291506, 0.040621682934995205, 0.06498652177729777, 0.06886201524840933, 0.029297978417681794, 0.12122303593371596, 0.10836437663861684, 0.08229712396860123, 0.0797401936724782, 0.19121625726776464, 17.278471061161586, 70.60945619855607, 50.88847099031721, 42.88633142198835, 29.72008568899972, 52.604849747249055, 15.696286337716238, 40.93004526410784, 8.464516997337341, 11.87932731424059, 64.30865601130894, 57.794855322156636, 60.79283973148891, 57.7855794770377, 55.3313958304269, 26.368194784436906, 0.3467949868312904, 2.3005294459206715, 3.9948828475815907, 0.09945470294249908, 0.21486792527139187, 31.143312999180385, 66.51928097861153, 59.13938386099679, 61.69296496255057, 60.6858583177839, 58.46176079341343, 60.28484303610665, 61.620099203927175, 56.2494786807469, 59.64535863058907, 55.88196413857596, 56.858564717429026, 56.2849839755467, 61.462889262608115, 48.18843575886318, 60.754166058131624, 49.666689327784944, 48.71298653738839, 57.5846723147801, 50.96928896222796, 49.335152557918, 45.1942902292524, 44.170143127441406, 53.89157969611031, 55.86260993140084, 52.45192337036133, 53.53700964791434, 50.454972880227224, 48.32140343529837, 48.52469382967268, 48.65983281816755, 49.718269280024934, 45.28948054994856, 42.98322057723999, 43.85446214675903, 47.00751992634365, 45.98367507117135, 46.95009306498936, 47.15272338049752, 51.15604611805507, 50.38790191922869, 51.97094127110073, 47.77918686185564, 47.51064246041434, 49.69014644622803, 50.680483613695415, 47.68827315739223, 42.58821548734392, 39.023143427712576, 41.31741080965315, 40.51037406921387, 24.43563325064523, 38.88438095365252, 36.052444594247, 34.20515135356358, 32.36174215589251, 33.256704875401084, 39.25764513015747, 39.99411596570696, 42.32629271915981, 43.55017968586513, 42.16464287894112, 38.31479542595999, 46.37150962012154, 48.74407625198364, 48.64311892645699, 42.916792324611116, 42.456932749067036, 44.73600442068917, 46.92328691482544, 49.129044669015066, 49.30178036008562, 47.930515153067454, 44.44917583465576, 47.913804735456196, 45.5984982081822, 43.22538961683001, 42.20900712694441, 42.63654368264334, 45.83301728112357, 50.05900893892561, 49.7020765032087, 51.51340239388602, 49.6280642918178, 51.56727177756173, 49.977558680943076, 49.83820908410208, 48.81073726926531, 52.33970996311733, 49.378815037863596, 49.917053767613, 47.693824768066406, 49.53881120681763, 49.55137354987008, 46.81776114872524, 42.098082610539024, 45.81900971276419, 38.37428937639509, 46.551728521074565, 55.00885697773525, 52.70947224753243, 53.08452558517456, 48.127642495291575, 48.65743568965367, 54.66882603509085, 56.892273902893066, 55.61975996834891, 54.108116831098286, 54.095311301095144, 54.08325270244053, 55.59044204439436, 45.112075669424875, 1.2498920112848282, 1.1237207587276186, 3.8741105624607632, 0.5639148748346737, 2.1698679200240543, 48.21776063101632, 59.820383753095356, 54.85368980680193, 63.52122361319405, 45.35098252977644, 62.542583738054546, 16.393543277467998, 16.80443021229335, 44.68921872547695, 17.354003190994263, 29.023968253816875, 45.27372898374285, 27.404523815427506, 34.33445732934134, 58.29138401576451, 41.2972297668457, 1.420355207153729, 0.16470493056944438, 0.056166265425937514, 0.044794150827718635, 0.017022877898333327, 0.01347060373518616, 0.12003325191991669, 0.05722849842693124, 0.158478530389922, 0.48907658777066637, 0.15760393946298532, 0.12999562520001615, 0.35145673954061096, 0.10610929943088974, 0.131589856797031, 0.19876677782407828, 0.14948533581835882, 0.25986045598983765, 0.25185632120285717, 0.23441441570009502, 0.2818676808050701, 0.2681685473237719, 23.299276215689524, 86.0621178490775, 55.86939137322562, 58.931924547467915, 31.386840411594935, 70.50326687949044, 27.42732606615339, 38.45721960067749, 10.977143679346357, 14.362035921641759, 69.7503878729684, 62.63727378845215, 63.29593522208077, 59.34173624856131, 60.33874716077532, 27.743013995034353, 1.3401655043874467, 5.7373903053147455, 3.8711289167404175, 0.19019004090556077, 0.859808688717229, 40.441041469573975, 70.99423354012626, 65.66106728145054, 63.614524023873464, 62.45746830531529, 58.792508942740305, 64.3690983908517, 61.57855592455183, 60.790922028677805, 60.980406352451865, 58.85964938572475, 57.77048451559884, 59.82294763837542, 57.83548491341727, 52.99456030981881, 54.78704963411604, 46.61562762941633, 50.27049820763724, 55.62185485022408, 51.8409925869533, 49.83295624596732, 44.65883425303868, 47.671434198107036, 57.45292404719761, 56.895796639578684, 56.10345881325858, 54.80393028259277, 51.615384578704834, 52.69429390771048, 51.165057931627544, 51.66345221655709, 51.50476230893816, 47.07633488518851, 44.693623883383616, 46.3399543762207, 45.297092301504954, 48.95786884852818, 48.85590403420584, 48.12501607622419, 52.8330911227635, 52.318267822265625, 56.257819993155344, 48.12560667310442, 50.030785356249126, 51.67572968346732, 54.43437991823469, 54.83826133183071, 46.71494518007551, 44.73084885733468, 45.879768235342844, 48.61437422888619, 17.414695705686295, 32.03891147886004, 49.790259565625874, 39.29483188901629, 40.274930885859895, 38.54125806263515, 43.68294933864048, 47.21702548435756, 51.034365790230886, 50.2291008404323, 51.788783822740825, 45.36734206335885, 52.449759006500244, 52.23401049205235, 54.12010594776699, 44.09880249840872, 48.67935378210885, 50.67836093902588, 52.51040288380214, 53.985078130449565, 54.21884332384382, 49.82160636356899, 44.48675169263567, 51.94630295889718, 43.93842417853219, 44.21212414332798, 43.533948693956646, 43.00091763905117, 47.119517939431326, 51.4945137160165, 52.789018699101035, 55.68855060849871, 49.472118922642295, 54.26529203142439, 51.91084630148751, 53.29942989349365, 53.63885981695992, 53.140757356371196, 50.481445516858784, 51.03408786228725, 50.59196008954729, 51.9032484463283, 52.63174622399466, 51.224715164729524, 45.04029382978167, 46.431778294699534, 37.6588750566755, 47.8427038192749, 60.8615574155535, 54.70423405511038, 58.33737414223807, 52.58339371000017, 51.36295304979597, 56.26575483594622, 61.623059136526926, 58.25723361968994, 58.27506269727434, 57.63753768375942, 56.67325278690883, 61.09060478210449, 52.770446164267405, 4.081872991153172, 0.6704141486968312, 3.1260572969913483, 3.518637465579169, 2.658405316727502, 50.710075991494314, 66.33114460536412, 58.358329909188406, 68.20531695229667, 51.00163630076817, 66.98467826843262, 20.09160906927926, 16.97404616219657, 51.009539876665386, 18.425962584359304, 58.626843043736045, 49.68300369807652, 34.376358440944124, 47.649644647325786, 61.00247383117676, 60.158990315028596, 3.739378912108285, 0.3838229684957436, 0.2247188152479274, 0.1015526382252574, 0.1561511552759579, 0.05366089700588158, 0.18967892761741365, 0.13533516653946467, 0.19931153287845], [0.05392022630465882, 0.06914056744426489, 0.11359791045210191, 0.01917917906705822, 0.07721780759415456, 0.08736844041517802, 0.08436191960104875, 0.09009589334683758, 0.0036957491205872168, 0.014443157307271446, 0.1576972651694502, 0.022832783105384027, 0.08193781932017632, 2.9137911328247617, 54.55743598937988, 43.44046415601458, 63.10674967084612, 34.0883069719587, 47.81368466785976, 28.10259543146406, 21.664535318102153, 13.12703617981502, 7.290980151721409, 67.64745998382568, 69.66014466966901, 61.450841086251394, 42.73400953837803, 37.348478181021555, 45.201874188014436, 0.5834959841200283, 0.7334723078778812, 1.9881429970264435, 0.1020527049633009, 0.28594814613461494, 2.710421919822693, 45.07757438932146, 52.23660217012678, 61.726594243730815, 57.13808379854475, 57.1142132622855, 58.708505221775596, 59.89028263092041, 55.50728600365775, 57.912967750004356, 53.900879859924316, 57.964839526585166, 54.19664035524641, 52.5045177595956, 55.95398221697126, 51.45055941173008, 62.89948490687779, 55.09898553575788, 47.713116441454204, 51.27437741415841, 51.852238246372764, 51.77016612461635, 43.14639207295009, 46.079414299556184, 53.2127754347665, 48.33512960161482, 49.72238956178938, 47.025543553488596, 43.691551208496094, 42.55199105398995, 42.20934411457607, 42.66057055337088, 40.29271480015346, 39.50552906308855, 40.471130643572124, 41.044607162475586, 41.19158935546875, 42.75523281097412, 42.443366391318186, 43.87580006463187, 49.2609874861581, 48.40283284868513, 46.843372208731516, 45.39000708716256, 44.47653784070696, 45.021436418805806, 42.36010612760271, 33.59360565458025, 28.284813676561626, 30.892684527805873, 32.34383317402431, 8.710391163825989, 18.935190847941808, 33.21844809395926, 26.213637317929948, 25.459761244910105, 20.724720239639282, 22.215713330677577, 32.324565819331575, 33.336164474487305, 34.2444121497018, 39.39403479439871, 32.209684303828645, 36.47158772604806, 42.07577541896275, 43.21387645176479, 41.844035625457764, 44.22283826555525, 43.81557307924543, 45.50642762865339, 44.4768887247358, 44.59248243059431, 43.77738925388881, 38.98773888179234, 40.07049751281738, 40.95035832268851, 39.88865620749337, 40.08316060474941, 41.84842341286795, 43.83738694872175, 47.85164267676217, 45.5692150252206, 47.457860469818115, 46.97917822429112, 47.88110998698643, 50.9943893296378, 48.830008098057334, 50.49635287693569, 48.9998950277056, 48.80596733093262, 44.1952782358442, 40.68639625821795, 43.773942947387695, 42.64183473587036, 44.96603148324149, 41.4488776751927, 43.41047920499529, 33.832658427102224, 51.831008025578086, 56.00617013658796, 54.89827987125942, 51.42251648221697, 48.34327289036342, 47.86049468176705, 52.562771456582205, 54.475954464503694, 54.652039187295095, 51.831112248556956, 54.51894991738455, 51.03166988917759, 47.935764517102925, 9.172747748238699, 0.1701024595115866, 0.1555421022432191, 1.30848063315664, 1.6520334439618247, 8.118561846869332, 47.49323027474539, 44.10469804491316, 52.52424716949463, 45.95479835782732, 50.48932129996163, 47.80631610325405, 3.782492918627603, 23.148397820336477, 19.125766038894653, 14.681880610329763, 41.78513922010149, 31.812309878213064, 24.555465357644216, 36.52054820741926, 53.20517757960728, 19.1981680052621, 0.20922080400799, 0.08169858144330126, 0.06037191368107285, 0.09268437552132777, 0.04862806706556252, 0.09762181700872523, 0.035779039575053115, 0.10497138263391596, 0.1498053465038538, 0.040805280940341096, 0.01907455235985773, 0.04978323561538543, 0.012389940026748394, 0.015948132711595724, 0.07776539892490421, 0.05871054782931294, 0.03174194281122514, 0.04530600032636097, 0.05318290640466979, 0.05968569086066314, 0.028321191635248915, 0.0779180218066488, 2.8560893833637238, 62.68791920798165, 51.2564823286874, 60.65149252755301, 36.45455421720232, 60.59268992287772, 19.537328686032975, 29.46026475088937, 21.78297257423401, 7.1012322306633, 71.88966178894043, 69.5354870387486, 68.0102949142456, 52.929205553872244, 42.290057863507954, 54.283913203648154, 1.3745980624641692, 0.4094349241682461, 3.388482289654868, 0.41093798780015534, 0.08045989541070801, 4.020905154091971, 54.921907220567974, 54.4244509424482, 63.76077665601458, 58.26521362577166, 60.42482144492013, 59.042776107788086, 62.61476162501744, 58.36349242074149, 60.05603190830776, 55.58302484239851, 61.17538670131138, 56.95984513419015, 56.92515277862549, 57.764008794512065, 54.045447553907124, 63.69621399470738, 59.01178714207241, 50.85824980054583, 54.26486471721104, 52.82057046890259, 55.11832932063511, 48.464782987322124, 50.557309423174175, 56.21408108302525, 52.68117570877075, 51.41415432521275, 49.471305983407156, 47.40367841720581, 45.83613354819161, 47.88080774034773, 46.17562600544521, 42.40629080363682, 44.30967685154506, 44.872748443058555, 41.90651730128697, 43.425977161952424, 45.861897468566895, 43.35279873439244, 44.28983279636928, 52.21581315994263, 50.37399509974888, 51.6689829826355, 47.36673484529768, 48.34068121228899, 51.33966963631766, 47.883823258536204, 42.244821616581504, 36.718776839120046, 39.97239589691162, 42.674157755715505, 36.58924157278878, 40.11884307861328, 39.63660682950701, 39.135297775268555, 33.69796412331717, 30.702633925846644, 30.29073429107666, 38.717950752803254, 44.53159884044102, 44.10099465506417, 46.73602948869978, 38.79761184964861, 43.02444771357945, 48.90708793912615, 48.21113552365984, 48.13750893729073, 47.077043601444785, 48.50901869365147, 49.623617444719585, 50.45742212023054, 48.169067655290874, 46.95069408416748, 40.111471039908274, 42.87064586366926, 42.37257466997419, 40.80958434513637, 40.82470709936959, 42.40338298252651, 45.74594940458025, 49.13295997892107, 49.02488422393799, 50.1982855796814, 48.77611092158726, 49.749852316720144, 50.75027826854161, 50.51160069874355, 49.90720122201102, 51.168455600738525, 51.064642565590994, 47.18937165396554, 43.64554023742676, 45.52107443128313, 41.795380864824565, 45.12462411608015, 42.76263264247349, 42.78034707478115, 37.30730663027082, 52.385616711207796, 55.341098989759175, 55.030222688402446, 51.604889324733186, 48.28369903564453, 50.408461638859336, 54.10894366673061, 55.19231721333095, 57.598738942827495, 53.50531544004168, 58.55156626020159, 53.83814804894583, 49.713235310145784, 10.025992614882332, 0.32904266512819696, 1.5121379792690277, 0.9625035524368286, 1.257601797580719, 12.859271713665553, 57.15876511165074, 49.46294035230364, 58.926435470581055, 48.19128104618618, 60.15898336683001, 43.49167585372925, 9.415952937943594, 28.5582218170166, 22.505289929253713, 17.277651173727854, 33.68998064313616, 44.379898820604595, 20.935842990875244, 39.710348061152864, 57.98158815928868, 18.633036272866384, 0.18485686422458716, 0.08771188770021711, 0.047163805458694696, 0.07882552168198995, 0.02035602681072695, 0.05368899174832872, 0.024691139547420398, 0.019761920208111405, 0.09529063531330653, 0.18118410344634736, 0.09557854450706925, 0.15196618198284081, 0.10246667239282813, 0.1844182727592332, 0.2135148857321058, 0.10047986079007387, 0.15738954953849316, 0.15238862431475095, 0.18801442693386758, 0.16280054061540536, 0.1260629990803344, 0.1753477794783456, 5.720341597284589, 86.8837423324585, 52.52910048621041, 78.80757318224225, 47.0641998563494, 67.48668561662946, 39.54222249984741, 28.568378346306936, 21.52137116023472, 12.425094417163304, 72.87573623657227, 71.65597302573067, 68.44145842960903, 51.23231649398804, 49.36895554406302, 58.27641412190029, 1.4287189926419939, 5.415626176765986, 6.093418606689998, 0.23389501071402005, 0.6177217247230666, 8.354803204536438, 65.72334398542131, 59.26747390202114, 67.84911755153111, 61.69826643807547, 61.59185477665493, 62.125809941973, 61.369241441999165, 58.827854428972515, 61.08435140337263, 56.66927146911621, 60.276803970336914, 58.226050104413716, 58.833267075674875, 58.37850052969796, 55.926800864083425, 59.392437253679546, 61.22815826960972, 50.941374574388774, 53.72339160101754, 53.55052042007446, 52.04723596572876, 45.89085061209542, 52.835866928100586, 57.84784575871059, 54.510976859501426, 54.654398100716726, 53.6491813659668, 50.329714230128694, 46.784218720027376, 51.04195669719151, 49.530157225472585, 44.59271172114781, 46.90031269618443, 46.58412797110421, 42.34762021473476, 43.80720049994332, 47.186078207833425, 44.790943826947895, 46.13429812022618, 53.9008138520377, 54.068925516945974, 51.390054498400005, 51.31483677455357, 49.934399945395334, 56.92661884852818, 52.94466529573713, 44.72573498317173, 41.908195291246685, 44.84120709555489, 51.45832749775478, 30.67326389040266, 35.260315213884624, 52.53257458550589, 46.84702001299177, 42.20305252075195, 34.79187461308071, 35.89736080169678, 42.51998765127999, 52.29379626682827, 50.19083363669259, 56.870088304792134, 45.47371550968715, 49.028921127319336, 51.98704719543457, 52.43390669141497, 53.41020154953003, 51.96796744210379, 53.43926239013672, 53.780106272016255, 51.94097021647862, 49.119636808122905, 50.40008211135864, 39.64392328262329, 45.86230393818447, 42.49911873681204, 42.139719690595356, 40.23923451559884, 44.95524787902832, 49.14418131964547, 52.72322620664324, 51.26454223905291, 50.093333039964946, 49.953292097364155, 52.956029074532644, 53.77523558480399, 53.22117928096226, 55.17573186329433, 54.59344155447823, 50.83223227092198, 49.073389598301475, 47.584661620003835, 49.49136543273926, 44.76860189437866, 46.313228130340576, 42.85795497894287, 46.41008949279785, 36.359999656677246, 51.912642410823274, 58.61774785178048, 59.06712259565081, 54.4110061781747, 53.510415417807444, 52.29805898666382, 57.85026025772095, 58.97519792829241, 60.468365805489675, 55.702533858163015, 61.2276371547154, 56.9611097063337, 54.826296533857075, 16.06780477932521, 0.48499522677489687, 2.1328932983534674, 8.418483444622584, 3.7068170479365756, 11.51905540057591, 58.486399105616975, 52.37396805627005, 61.872527258736746, 53.245810644967214, 59.00609656742641, 56.48117331096104, 8.312971574919564, 29.386266435895646, 26.9105155808585, 20.337241785866873, 61.42163780757359, 44.18211487361363, 34.379002230507986, 48.58859641211373, 68.05349881308419, 35.80801739011492, 0.4028027057647705, 0.1578951802636896, 0.28411124327353066, 0.15573129137711866, 0.1370028020547969, 0.15248627907463483, 0.10995682368853263, 0.15811369568109512, 0.3597862725811345], [0.27842384417142185, 0.05617222635607634, 0.07229521245296512, 0.03262877790257335, 0.04247397157762732, 0.18279740187738622, 0.06510415260813066, 0.03303306942273464, 0.057678177154489925, 0.1232347022742033, 0.09977016065801893, 0.05417113159117954, 0.23188117306147302, 0.11018497430320297, 31.353270190102712, 52.490722111293245, 48.92007064819336, 42.127935545785085, 29.93997185570853, 32.72078684398106, 20.881893702915736, 22.457145861216954, 1.51700573521001, 27.140619073595317, 78.29144709450858, 56.12785046441214, 50.54000840868269, 48.66175399507795, 50.89404691968645, 14.291760104043142, 1.6688641522611891, 3.825550905295781, 1.0046895401818412, 0.16482577765626566, 0.5376270168593952, 10.799078719956533, 50.0776926449367, 57.61031116758074, 65.64018099648612, 60.111388206481934, 58.40786361694336, 59.14738123757498, 57.94748987470354, 55.30158111027309, 54.84698826926095, 54.9877552986145, 54.77403218405587, 56.43920966557094, 60.222962379455566, 54.32319484438215, 54.44254405157906, 53.91268832342965, 55.968226024082725, 53.29875244413103, 53.89026996067592, 50.80440820966448, 60.198539461408345, 54.53550400052752, 52.22964007513863, 48.852544580187114, 46.12468181337629, 44.47503702981131, 45.802900314331055, 42.23665748323713, 42.33740636280605, 42.29651621409825, 39.36940343039376, 37.84128264018467, 40.433005877903526, 41.297608443668906, 40.082101004464285, 40.27976335797991, 42.558775969914024, 40.03421401977539, 44.882986613682334, 45.3973513330732, 45.92685617719378, 44.758245604378835, 44.70846176147461, 44.75296149935041, 42.058794021606445, 31.402796949659074, 27.13161073412214, 29.992507185254777, 32.0437057358878, 18.48753752027239, 19.395700080054148, 36.492150919778005, 28.661784717014857, 34.44001088823591, 11.681246331759862, 21.76899627276829, 42.42837217875889, 31.538773196084158, 37.172059944697786, 35.32795245306832, 35.36756760733468, 32.81027964183262, 39.426382132938926, 44.889368534088135, 45.83035612106323, 44.43620007378714, 45.455441747392925, 46.8224755014692, 46.6410093988691, 42.08938346590315, 36.82119328635079, 39.11849703107561, 37.64344310760498, 39.476040908268516, 38.68122952325003, 40.26561335154942, 38.24226318086897, 42.93174832207816, 44.52987221309117, 45.254687445504324, 46.697772707257954, 44.66387169701712, 45.44603736060006, 48.726156847817556, 47.35743120738438, 46.371273381369456, 44.12863458905901, 50.506535461970735, 41.000607694898335, 39.189535413469585, 42.64024359839303, 42.06560673032488, 43.19476195744106, 40.96957009179251, 40.863842827933176, 42.52984019688198, 52.130211353302, 55.78179195949009, 53.61473567145211, 54.551908697400776, 52.219464438302175, 54.45560666493007, 51.99307823181152, 57.33331775665283, 53.05488109588623, 52.85183388846261, 44.30560520717076, 42.905251366751536, 16.687095982687815, 0.21213887099708828, 0.31456731472696575, 2.8424018664019446, 0.709402716585568, 3.7469098908560614, 41.953268255506245, 48.884600094386506, 47.61745016915457, 48.48109040941511, 50.2906688281468, 54.88303552355085, 10.14381582396371, 4.601077565125056, 54.75553955350603, 17.832120895385742, 21.49761700630188, 39.91515663691929, 23.475314038140432, 29.85302904673985, 38.00800119127546, 51.55249990735735, 3.1522728502750397, 0.3224716777248042, 0.0557849287454571, 0.12901682486491545, 0.048217709442334514, 0.0545737301664693, 0.009916043757194919, 0.04762168088927865, 0.1562915306006159, 0.07112507202795573, 0.033219106761472564, 0.08264181975807462, 0.017723241388531666, 0.026278933543445807, 0.06251507332282406, 0.07427905207233769, 0.00486120383720845, 0.04647763352841139, 0.0677298524283937, 0.16095607887421334, 0.06951174645551614, 0.06305460365755217, 0.19698916535292352, 0.020324973655598502, 37.07538618360247, 63.34020219530378, 46.933882917676655, 38.25054543358939, 38.68851123537336, 27.154965366636002, 18.876786027635845, 35.19801071711949, 3.61682419691767, 26.31986311503819, 81.43966892787388, 52.4102897644043, 47.88447986330305, 55.482341970716206, 57.255140100206646, 23.670966625213623, 1.243006129349981, 1.6387936515467507, 1.8924940952232905, 0.03139929959018316, 0.41060056590608185, 17.523245675223215, 55.860240595681326, 58.76942007882254, 66.426849092756, 61.82849652426583, 59.917338916233604, 59.29849066053118, 59.68411568232945, 58.78388622828892, 57.93188074656895, 58.90823119027274, 59.82442760467529, 59.54244886125837, 60.883937563214985, 58.8776730128697, 56.067227431706016, 58.284453187670024, 59.79451560974121, 56.90705966949463, 55.110863481249126, 52.14287444523403, 62.127199581691194, 58.85459804534912, 55.040898595537456, 53.57719802856445, 49.04061841964722, 47.350670610155376, 48.18099076407296, 47.65610647201538, 46.53134250640869, 48.021112714494976, 44.22701760700771, 40.87828465870449, 45.43066447121756, 44.099146434238975, 41.468864168439595, 41.10854796000889, 45.14691741125924, 44.02559627805437, 47.438857146671836, 47.65876068387713, 51.26825257710048, 48.66689913613455, 47.981170994894846, 50.89450550079346, 49.119338035583496, 42.13554382324219, 33.93894154684884, 38.65539264678955, 40.89630133765084, 42.860258306775776, 40.74257591792515, 41.74436719076974, 40.12297378267561, 39.07871512004307, 22.228357315063477, 22.639817476272583, 45.255785260881694, 42.18558474949428, 46.49963092803955, 43.43997083391462, 41.4607834134783, 37.90085302080427, 47.527078424181255, 50.921360288347515, 48.54656328473772, 47.519883564540315, 51.47979048320225, 49.954455920628135, 48.346187659672324, 45.62731238773891, 41.61180945805141, 41.64781502314976, 40.10105916431972, 42.66545861107962, 39.42366191319057, 42.63810007912772, 40.56327070508684, 44.46590709686279, 48.00190789358956, 48.3029385975429, 48.06214877537319, 47.10392618179321, 48.52691725322178, 48.2408321244376, 50.2215689931597, 47.56422001974923, 44.99655491965157, 51.7643609046936, 44.077742508479524, 39.6572916167123, 42.3209148134504, 41.93886463982718, 44.24305404935564, 41.73575489861624, 43.10809012821743, 44.64317301341465, 53.43631635393415, 55.366935866219656, 53.69599832807268, 53.90152951649257, 51.80390657697405, 55.592728001730784, 50.93806375776018, 57.16526862553188, 53.22223540714809, 53.38176604679653, 47.880505493709016, 42.76187876292637, 17.99220391682216, 0.4439043945499829, 0.4777235026870455, 1.3526290527411868, 0.5160281072769846, 8.22404158115387, 49.65374830790928, 56.07906021390642, 52.71800116130284, 53.437699045453755, 55.170767375401084, 54.186218057359966, 10.97925158909389, 13.49242283616747, 49.68085323061262, 24.31397376741682, 15.300647224698748, 45.56056451797485, 33.48613091877529, 25.155353716441564, 44.80732420512608, 54.108346121651785, 4.435831163610731, 0.33708181232213974, 0.09313907540802445, 0.05786698630877903, 0.019134899568078772, 0.057319510328982554, 0.11642477554934365, 0.047971017858279605, 0.044263095395373445, 0.12971131902720245, 0.4407801479101181, 0.19039532489010266, 0.09826976366873298, 0.11467043682932854, 0.22689090083752358, 0.4774636509163039, 0.11162555164524487, 0.25323353015950745, 0.21569178892033442, 0.3109339496919087, 0.1563320527119296, 0.20067247056535312, 0.3839677135859217, 0.37272938234465464, 56.50602354322161, 69.23823615482875, 60.79724488939558, 58.166243485042024, 48.960832255227224, 48.17468179975237, 24.16210699081421, 32.29733235495431, 4.420056147234781, 38.50933109010969, 78.9323558807373, 59.76103918892996, 54.7073781149728, 58.89031873430525, 59.731078556605745, 18.22923128945487, 4.098774918488093, 17.08613623891558, 1.864382769380297, 0.1603020525404385, 1.3731309069054467, 26.465288911546978, 64.13217871529716, 63.770087242126465, 68.46381078447614, 68.18743228912354, 62.45605782100132, 61.961373874119346, 61.185822895595, 60.47454275403704, 57.848603112357004, 58.97152233123779, 60.93799454825265, 58.68240778786795, 59.39721761431013, 60.18499742235456, 56.74000065667288, 57.06619773592268, 58.11652217592512, 55.75913735798427, 57.33479077475411, 53.84750379834856, 57.21822084699358, 55.00803361620222, 56.55557114737374, 55.33535630362374, 51.82044676371983, 48.7776186806815, 50.36784594399588, 49.8680932862418, 46.558270250047954, 49.76631607328142, 44.639445304870605, 42.28205006463187, 46.51395116533552, 45.360953194754465, 44.45902490615845, 42.05010877336775, 46.1998404775347, 44.98145648411342, 49.19508729662214, 50.36532722200666, 52.444905689784456, 50.02232592446463, 51.47886637278965, 53.70448555265154, 53.95144884926932, 44.81789936338152, 40.302747998918804, 43.31144653047834, 46.37373651776995, 43.907424790518625, 43.35876028878348, 52.16039432798113, 45.04816961288452, 49.736261640276226, 24.02465946333749, 33.54416574750628, 55.47001934051514, 45.8851774079459, 52.3912239074707, 48.41708707809448, 47.987702301570344, 40.62000969478062, 51.171568393707275, 54.89882183074951, 53.74143954685756, 50.9708696774074, 57.50649813243321, 54.81468609401158, 55.01623249053955, 46.61789969035557, 42.72667224066598, 43.45670557022095, 40.410212312425884, 42.489189761025564, 38.697252069200786, 41.63600655964443, 40.17691959653582, 46.43794134684971, 50.05270692280361, 48.48457840510777, 47.504559312547954, 46.55170767647879, 47.445947783333914, 50.908096177237375, 53.54006338119507, 52.73258195604597, 46.32987254006522, 53.14038910184588, 43.44286128452846, 41.513780798230854, 42.56419556481497, 43.32761498859951, 46.29157059533255, 43.69936793191092, 42.406996045793804, 44.416814599718364, 56.74239431108747, 59.79876790727888, 57.04156289781843, 59.11398819514683, 55.03183467047555, 60.101278577532085, 54.517879894801546, 62.822589193071636, 55.91365834644863, 59.45490850721087, 53.78389304024832, 46.49148416519165, 29.100561720984324, 0.7715992991413388, 0.46996497043541496, 11.639340009008135, 8.928065197808401, 5.482708428587232, 54.39736339024135, 62.30728299277169, 56.94058820179531, 56.65447875431606, 57.470822606767925, 63.9413742337908, 15.046890326908656, 7.070606308323996, 63.84796960013253, 23.981934990201676, 29.33302239009312, 60.449244362967356, 33.443979672023225, 42.39969001497541, 49.38121911457607, 69.80517441885812, 9.817964417593819, 0.8678853724684034, 0.21708905537213596, 0.3227582909166813, 0.07347651477903128, 0.15966285898217134, 0.19790585259241716, 0.189740905006017, 0.35444047514881405, 0.20585662738553115], [0.147653141990304, 0.06664490207497563, 0.021820563224277327, 0.060036602030907354, 0.037966945208609104, 0.23565996172172682, 0.09129044746181794, 0.11992930035505976, 0.03372349576758487, 0.0744821240327188, 0.0679584237347756, 0.05734346940049103, 0.18705732614866324, 0.11612493092460291, 13.186161007199969, 53.491491998944966, 36.70609637669155, 37.05183873857771, 29.395229612077983, 36.91608483450753, 19.20680809020996, 39.25835384641375, 8.11380319935935, 2.3034809104033878, 39.96631274904524, 61.58011926923479, 53.08244112559727, 52.61704730987549, 42.36509493419102, 32.327449321746826, 8.350390229906354, 2.8300442780767168, 3.095899509532111, 0.041020189944122515, 0.11268480587750673, 0.5234190363969121, 14.734174489974976, 53.21402611051287, 45.92482382910592, 56.77366815294538, 52.66381216049194, 55.394228390284944, 59.89007418496268, 60.36991677965437, 56.4027281488691, 59.81734044211251, 58.05812604086739, 56.690032686506, 54.9153550692967, 55.55604151317051, 53.03958463668823, 52.48921087809971, 54.37552867616926, 51.976725646427695, 55.74798897334507, 53.10019377299717, 51.023019381931846, 56.38046612058367, 52.14724486214774, 49.190192290714805, 46.849149635859895, 43.33918373925345, 42.134682246616904, 43.10574858529227, 42.26756307056972, 40.93470403126308, 41.36036804744175, 40.09732103347778, 37.74416766847883, 41.42419767379761, 39.66930505207607, 40.32651431219918, 40.77264077322823, 41.69792890548706, 43.74436446598598, 45.11698457172939, 50.215082849775044, 44.9658716746739, 43.26016535077776, 45.60918801171439, 41.29843527930123, 31.0799697467259, 28.5406984601702, 30.731646129063197, 30.50246674673898, 29.653754711151123, 28.64131532396589, 37.14659827096121, 32.41288089752197, 34.07622752870832, 7.182367214134761, 18.445594719478063, 43.68474544797625, 33.53012343815395, 39.646379470825195, 37.80454751423427, 34.194770744868684, 33.731086186000276, 39.92839642933437, 46.46933330808367, 45.20554978506905, 46.62339571544102, 46.35611588614327, 44.62181772504534, 43.101433753967285, 38.26763105392456, 38.314788477761404, 40.35375819887434, 38.0420160974775, 39.193822452000205, 38.3047969681876, 38.40544509887695, 38.83655302865164, 39.015201636723106, 46.04291888645717, 43.600158078329905, 43.97700752530779, 47.19133799416678, 44.759934016636436, 48.95325524466378, 45.17666264942714, 47.694345882960725, 46.44779736655099, 41.96826246806553, 44.865650858197895, 44.863795689174104, 40.695981298174175, 45.05511433737618, 45.21932806287493, 46.35514313834054, 40.79683787482125, 40.698948178972515, 53.436945165906636, 56.9877074105399, 54.74559668132237, 54.803909437997, 53.75781645093645, 52.928976263318745, 50.009374482291086, 52.704629353114534, 42.95310708454677, 44.695055212293354, 29.697448457990372, 16.09169963427952, 0.7422853921140943, 0.10402994922229222, 0.44315749034285545, 0.8287958928516933, 12.812568528311592, 52.35656976699829, 46.89590059007917, 47.87893520082746, 43.98113822937012, 44.77386168071202, 49.606709003448486, 12.621595552989415, 0.47554665378161837, 27.122989756720408, 50.20360789980207, 13.136084471430097, 33.64199985776629, 37.351597922188894, 17.310231276920863, 31.734219074249268, 46.35510492324829, 35.5694579396929, 0.5121697943125452, 0.05070039104404194, 0.05691079476049968, 0.03623803458841784, 0.07218763072575841, 0.025936522720647708, 0.06814013541276966, 0.036522048991173506, 0.25907487528664724, 0.0695964072697929, 0.04633272558982883, 0.035976873245090246, 0.022508054905171906, 0.052306686993688345, 0.023836249884750162, 0.3340627114687647, 0.13332679787916796, 0.07305748547826495, 0.05125958193093538, 0.11286824103444815, 0.05839557187365634, 0.06530271909598794, 0.23885708302259445, 0.05459031016964998, 14.081770777702332, 61.421179226466585, 43.08744355610439, 32.092735699244905, 38.210318837847026, 35.56868668964931, 12.948977300098964, 46.47611822400774, 15.895798649106707, 3.4249286311013356, 39.057022844042095, 68.79376683916364, 54.17546224594116, 62.40813609531948, 48.834461893354145, 37.14977012361799, 12.692545345851354, 1.513604374868529, 2.3754903035504475, 0.29631040724260466, 0.04330682581556695, 0.4844374167067664, 21.38324965749468, 56.953355516706196, 46.539114066532676, 58.084223474775044, 51.22222423553467, 54.84713070733206, 62.83304623195103, 59.688298497881206, 59.94663252149309, 61.662066323416575, 59.96556636265346, 60.39058072226388, 59.336441721235005, 59.448870522635325, 56.004790919167654, 56.26656082698277, 57.15502003261021, 56.608707496098106, 59.86552619934082, 58.59168515886579, 53.13078669139317, 58.81520870753697, 55.18223885127476, 52.634066922324045, 50.96222959245954, 47.342968532017295, 44.24999182564871, 46.62622710636684, 47.70539699281965, 46.979261602674214, 44.10872800009591, 41.90623242514474, 43.38315541403634, 42.564404010772705, 43.939271858760286, 41.91197163718087, 42.80536753790719, 41.01055056708199, 43.54940843582153, 46.02704572677612, 53.47888796670096, 47.7367159979684, 47.52926363263811, 49.76458249773298, 48.88694511141096, 37.79363884244646, 34.69996384211949, 38.088027068546836, 39.203355380467, 41.75839212962559, 40.439926283700125, 46.68222958700997, 41.25810446058001, 42.00612320218767, 19.208388805389404, 26.256412165505544, 54.901747022356304, 41.89436490195138, 48.69056817463466, 46.41001306261335, 41.24076523099627, 35.960464341299875, 47.95620959145682, 51.06801591600691, 49.20583268574306, 49.204884256635395, 52.44867161342076, 49.36722891671317, 46.9516772542681, 41.09860508782523, 39.093424456460134, 43.4871768951416, 39.69105291366577, 41.47202212469918, 39.8013208253043, 39.46934284482683, 39.31990793773106, 41.23601961135864, 49.55442033495222, 48.18132427760533, 48.041279860905235, 49.53315884726388, 48.52641003472464, 48.92143596921648, 47.90608876092093, 47.31869500023978, 51.041713510240825, 43.796170234680176, 45.80093397412981, 44.175194467817036, 42.04776723044259, 44.253820283072336, 45.63040433611189, 46.37786027363369, 42.24092715127127, 42.38901063374111, 53.11584111622402, 55.50011198861258, 54.9916775567191, 54.651886326926096, 53.78943770272391, 52.99269471849714, 51.91909728731428, 51.05571413040161, 44.28384344918387, 44.950106212071006, 33.08129065377371, 19.023181097848074, 0.7194941065141133, 0.5660439005919865, 1.2797355013234275, 3.950149042265756, 22.024349519184657, 57.81999043055943, 52.00412934167044, 53.902964319501606, 52.30161646434239, 52.43752670288086, 54.59478603090559, 13.015701719692775, 1.8653820071901595, 30.668407099587576, 47.51281724657331, 16.81924029758998, 23.599879605429514, 48.320343835013254, 22.652404138020106, 30.810212884630474, 56.98883301871163, 35.95669494356428, 0.9491834214755467, 0.06682127368237291, 0.10149640124291182, 0.058146637731364796, 0.05564992402547172, 0.07148446488593306, 0.0641041344829968, 0.06941852931465421, 0.19327956012317113, 0.09102383069694042, 0.4026107074958937, 0.09509970234440905, 0.08899213400270257, 0.21714373172393867, 0.12560576147266797, 0.6195086059825761, 0.21003770588764123, 0.29706827657563345, 0.26407890820077484, 0.18792338110506535, 0.18645013230187552, 0.34119131895048277, 0.3982255256601742, 0.20590602473488875, 26.033444472721644, 83.37436008453369, 47.401882307870046, 47.61182907649449, 41.8845853124346, 55.21927274976458, 22.202350207737513, 53.46270561218262, 12.224098665373665, 6.6517263395445685, 48.28175354003906, 71.56005314418248, 61.04780387878418, 66.1113383429391, 54.0745153427124, 45.72755057471139, 12.784891247749329, 5.518302747181483, 8.376216684068952, 0.2902919373341969, 0.20507498218544892, 1.9103344636304038, 28.61739788736616, 69.69811657496861, 48.89533158711025, 56.759393078940256, 51.494809014456614, 55.07799850191389, 63.258018902369905, 64.15606662205288, 57.832146303994314, 64.34469631740025, 62.733957971845356, 59.43368870871407, 60.21247059958321, 58.511412620544434, 55.912480626787456, 57.441108635493684, 56.97084065846035, 56.58648368290493, 60.556503704616, 57.35433953148978, 55.50508689880371, 61.1612332207816, 57.17531224659511, 53.372896671295166, 52.03070967538016, 48.54845666885376, 46.61653436933245, 48.82451554707119, 47.482033252716064, 46.66984789712088, 45.675182001931326, 42.32007755552019, 43.778521810259136, 45.83381979806082, 43.400466850825715, 43.94413559777396, 46.09953280857631, 44.213489464351106, 46.08450732912336, 47.92511640276228, 53.96695375442505, 51.62864868981497, 51.40782104219709, 54.458392892565044, 52.81742640904018, 41.60691097804478, 39.47224024363926, 43.997685364314485, 43.17386525017874, 49.44234936577933, 46.963603837149485, 53.89233704975673, 49.357101917266846, 48.97622946330479, 19.072824239730835, 20.362816367830547, 63.45691108703613, 45.345208576747346, 53.53549146652222, 50.3192571912493, 46.43363693782261, 41.94537510190691, 53.12490504128592, 55.90717567716326, 53.815066133226665, 53.26800666536604, 56.32069076810564, 52.70776299067906, 51.16071878160749, 41.506057875497, 41.150963238307405, 46.3871500151498, 40.15380641392299, 42.8636976650783, 40.32617037636893, 39.826414244515554, 40.54948547908238, 43.26281608854021, 51.70491211754935, 47.40350471224104, 47.596477031707764, 48.11656011853899, 48.618220056806294, 53.24615110669817, 49.113591875348774, 49.113574504852295, 52.37033067430769, 47.96166740145002, 47.204626423971995, 47.58655500411987, 42.465951510838096, 46.913576807294575, 45.750549112047466, 48.36528130940029, 45.23088639123099, 42.80900839396885, 54.614616189684185, 59.938315527779714, 56.6954870223999, 57.947997093200684, 58.03094816207886, 55.30275535583496, 53.48010042735508, 59.785934584481375, 47.604005404881065, 53.66952569144112, 44.059993335178916, 27.150282280785696, 1.9415661820343562, 0.18035935770188058, 1.9455242667879378, 3.6007436769349233, 16.899226222719463, 61.632328033447266, 57.126476832798545, 59.439893450055806, 52.71077503476824, 53.64407444000244, 58.368766103472026, 17.95505711010524, 1.423701741865703, 33.33604288101196, 61.810125487191335, 17.194481236594065, 48.29965557370867, 56.16979326520647, 25.308493750435964, 45.49308361325945, 60.030962807791575, 54.85744530814034, 2.1028271402631487, 0.3346567824482918, 0.20749720292431967, 0.1425850825118167, 0.15322681862328733, 0.19979511121554033, 0.29993196576833725, 0.1444162313959428, 0.30507355130144526, 0.18241435528865882], [0.006716123075290982, 0.04891710262745619, 0.0324479686761541, 0.07891456583248717, 0.03285868592294199, 0.020976411378277198, 0.05497673247009516, 0.03223594344620194, 0.020705910000417913, 0.08846480372760977, 0.04513963371781366, 0.06034450765166964, 0.04960006508710129, 0.08083862651671682, 2.261451691389084, 40.37055546896798, 50.4321619442531, 40.40156875337873, 27.786937032427105, 38.548206261226106, 22.276871374675206, 25.303058522088186, 21.002246924809047, 1.10721227313791, 5.898133839879717, 43.7524209022522, 50.66596187864031, 55.93960639408657, 47.50530971799578, 62.501019614083425, 54.61534227643694, 34.44088636125837, 4.955572485923767, 0.8412634038499424, 0.13394411546843393, 0.10747890200998102, 0.2914212910192353, 14.998153924942017, 54.72299766540527, 50.255507469177246, 53.794600214277, 53.807812213897705, 55.327532632010325, 59.31082371303013, 59.22377668108259, 57.396442140851704, 57.49052422387259, 56.09440531049456, 54.875191007341655, 52.513251645224436, 51.57053395680019, 48.94997569492885, 51.07319232395717, 52.995828356061665, 51.42839118412563, 56.6017940385001, 58.52080658503941, 53.69059610366821, 53.074402059827534, 50.52829027175903, 47.52252040590559, 44.69022968837193, 42.65197563171387, 41.161131926945274, 40.278644698006765, 39.97180182593209, 38.85479552405221, 38.201605796813965, 41.22017771857125, 41.44287095751081, 40.848806926182334, 43.28907333101545, 40.611928939819336, 39.235362257276265, 45.181130341121126, 47.64083433151245, 51.49954768589565, 45.89958797182356, 43.143845558166504, 44.637541498456685, 39.48356580734253, 31.56737198148455, 30.935325622558594, 31.659692696162633, 32.25488233566284, 33.606213160923545, 36.16128117697579, 36.610968589782715, 36.693231787000386, 29.963724272591726, 13.262752737317767, 26.51312552179609, 39.593309129987446, 36.01994786943708, 37.15123619352068, 37.32344382149832, 36.1550486428397, 35.43256453105381, 39.78565263748169, 46.0541159084865, 45.269806725638254, 45.67271191733224, 45.9264531816755, 43.55145468030657, 40.133680956704275, 37.97961780003139, 37.12458985192435, 38.782350131443565, 42.239405495779856, 40.666955198560444, 39.686279501233784, 39.8204596383231, 37.08286244528634, 37.88413912909371, 39.09679433277675, 45.16027184895107, 43.2788143157959, 46.40558706011091, 44.32030759538923, 48.44291353225708, 45.84663922446114, 45.7582859311785, 44.25178098678589, 40.93454074859619, 47.7739166532244, 46.62291628973824, 49.46015065056937, 46.97941098894392, 45.3643022264753, 49.611305236816406, 47.423188958849224, 41.20701783043997, 53.525044849940706, 53.66197994777134, 57.18374735968453, 54.46776253836495, 53.51158618927002, 51.881222656794954, 52.15131998062134, 47.17900494166783, 37.1825795173645, 17.655202388763428, 4.678479194641113, 0.7069864262427602, 0.04205054197726505, 0.11102607274161917, 3.42776067342077, 39.41751970563616, 52.618562017168315, 47.75903013774327, 48.45391253062657, 52.537990706307546, 38.85058491570609, 51.36003133228847, 38.51471594401768, 5.939825636999948, 10.342343228203909, 58.87310109819685, 42.285965374537874, 15.181819132396154, 34.908475807734895, 31.31455830165318, 22.07250053542001, 30.50502368382045, 47.861828735896516, 17.026989698410034, 0.19754308063004697, 0.04819177922659686, 0.0856119914512549, 0.026521565791751658, 0.07323741939451013, 0.07536244179521288, 0.08107130295996155, 0.08368826324918441, 0.16426454777164118, 0.061696380110723634, 0.04629031036581312, 0.036463413387537, 0.04652156527819378, 0.06094440724700689, 0.03747833553435547, 0.05081864273441689, 0.01506043757711138, 0.05712589714676142, 0.03783768768023167, 0.0336270386220089, 0.04101818148046732, 0.04222890169226697, 0.1245037391781807, 0.027655258708234345, 2.153330773115158, 51.61654840196882, 58.705427169799805, 37.28506197248186, 32.462136677333284, 48.52346052442278, 14.516892160688128, 31.071506840842112, 21.66081976890564, 5.262730632509504, 7.155183255672455, 47.888600145067485, 55.08834784371512, 62.46247795649937, 52.79129770823887, 66.05994946616036, 58.301639556884766, 40.20030723299299, 8.501532656805855, 0.25096516045076506, 0.09422999008425645, 0.08116283054862704, 0.07623108197003603, 19.44888506616865, 61.82520307813372, 49.26671974999564, 53.69718994413103, 53.58551502227783, 56.56036540440151, 60.678423745291575, 61.90536444527762, 58.92298221588135, 59.01624093736921, 59.27007947649275, 59.82238483428955, 56.106734888894216, 55.59656688145229, 51.93494265420096, 56.06584126608712, 56.390666076115195, 55.201158796037944, 57.44282831464495, 60.97713375091553, 57.447643416268484, 55.773269993918284, 54.162444795881, 51.69568838391985, 48.095322949545725, 44.57832200186593, 45.33541509083339, 43.229127747671946, 43.79071242468697, 43.22282920564924, 42.72920833315168, 44.79994869232178, 43.55228499003819, 41.219625336783274, 44.392548016139436, 42.46196671894619, 41.44794314248221, 45.14661169052124, 47.31704132897513, 52.69746923446655, 50.457623617989675, 48.70195279802595, 49.736477034432546, 47.923355034419465, 37.69887931006295, 37.09410810470581, 36.53052929469517, 42.53464835030692, 43.39906678880964, 45.19414431708199, 44.28565345491682, 42.32816178458077, 37.595055852617534, 27.488148859569005, 46.94888755253383, 48.50032997131348, 44.40439122063773, 49.11869532721383, 45.296842166355674, 41.96250588553292, 38.638751711164204, 44.962230818612234, 51.311025687626426, 49.964944226401194, 50.926984855106895, 48.45777920314244, 48.7639376776559, 42.38145794187273, 42.00622047696795, 39.09196880885533, 41.04332521983555, 41.62543487548828, 42.78640242985317, 42.196423939296174, 39.90158680507115, 38.582488673073904, 41.08775894982474, 42.72062035969326, 49.1436219896589, 46.280040059770855, 48.34350912911551, 48.84389754704067, 50.05587877546038, 48.39964015143258, 48.90406199863979, 46.080668449401855, 43.651727608272004, 50.57460348946707, 48.222843238285606, 50.39555188587734, 48.05622543607439, 46.617045061928884, 49.38922691345215, 50.93206398827689, 42.45644290106637, 53.27341931206839, 54.62861680984497, 57.556532110486714, 54.2044084412711, 52.36860057285854, 53.08028718403408, 53.30029494421822, 48.20172071456909, 38.19078745160784, 21.438183852604457, 7.296069707189288, 0.491991682776383, 0.09565323764192206, 1.0868735930749347, 7.505767209189279, 49.0586142539978, 58.40346540723528, 52.434462547302246, 55.62016643796648, 58.85460499354771, 46.32372685841152, 58.40497316632952, 44.57921484538487, 7.187061590807779, 16.7902124609266, 55.912049838474815, 47.17065668106079, 15.25736689567566, 28.940421376909526, 48.49410785947527, 21.65108186858041, 31.55762713296073, 58.58565412248884, 17.725436517170497, 0.44800513450588497, 0.06419328719909702, 0.17048699887735502, 0.052566331811249256, 0.048582771460392644, 0.05565043292673571, 0.08135569055697747, 0.08227939384856395, 0.14504475838371686, 0.03279087652585336, 0.08002314956060477, 0.12969035229512624, 0.11935462190636567, 0.12931375178907598, 0.13041170287345136, 0.09236146749130317, 0.11128491349518299, 0.11551628501287528, 0.11820218445999281, 0.11602160361196313, 0.11358332194920097, 0.17312200819807394, 0.22055407586906636, 0.16100162214466504, 4.400779673031398, 72.8592620577131, 61.41467571258545, 55.21544429234096, 35.41765022277832, 61.144210134233745, 26.570507219859532, 33.57454674584525, 28.960908140454972, 4.064785199505942, 9.983995965548925, 53.94132879802159, 61.30952862330845, 68.73059381757463, 57.325712953295024, 70.94680513654436, 62.0378110068185, 41.444680963243755, 6.973611193043845, 1.6147954421383994, 0.3494695547435965, 0.3740864795233522, 0.7774218895605632, 22.366345064980642, 71.0410852432251, 58.810789653233115, 54.63255991254534, 53.53138855525425, 58.34618445805141, 61.406601905822754, 60.99211406707764, 61.22132124219622, 59.70308426448277, 59.32993820735386, 60.261316435677664, 57.07089124407087, 56.561355522700715, 53.44877447400774, 56.171141215733115, 56.65057734080723, 55.12585769380842, 59.51320389338902, 63.09711251940046, 59.114231382097515, 56.854892594473704, 57.3307260785784, 53.800026757376536, 51.197644983019146, 48.59636449813843, 46.833140986306326, 44.52526903152466, 45.88046652930123, 46.136028221675325, 41.32733978543963, 47.18595661435808, 45.31887837818691, 43.33964926855904, 46.83774764197213, 43.99309607914516, 42.97450753620693, 48.56541722161429, 49.83027424131121, 54.75009216581072, 53.4136061668396, 51.38641364233834, 54.3306884765625, 49.756053583962576, 41.9710556438991, 42.53678492137364, 41.33150175639561, 44.7795592035566, 48.65542071206229, 51.45080607278006, 49.07166297095162, 47.22582885197231, 41.32687425613403, 39.06169203349522, 52.665768078395296, 52.35390165873936, 49.36140285219465, 52.16857235772269, 49.034632546561106, 47.39988470077515, 45.0127511705671, 50.76662737982613, 55.17222302300589, 53.824251651763916, 54.74598230634417, 52.52329874038696, 49.58009392874581, 45.15848616191319, 44.569271973201204, 40.7017309325082, 43.25899805341448, 42.865796021052766, 43.49176618031093, 43.82842377253941, 43.99810573032924, 39.6821939604623, 42.26639229910714, 43.3766553742545, 50.06358085359846, 44.58056974411011, 50.24289648873465, 49.331230299813406, 51.512627669743125, 50.72681072780064, 52.09010635103498, 50.123224190303254, 46.10058546066284, 54.40684420721871, 50.786850111825125, 53.60148893083845, 50.12022256851196, 48.00596216746739, 50.94116612843105, 53.762242453438894, 44.48676906313215, 56.797378880637034, 58.430438314165386, 61.76419789450509, 59.46782520839146, 55.72258288519723, 57.05909320286342, 58.56619916643415, 55.42427587509155, 45.125211238861084, 27.11931242261614, 12.41564313002995, 1.34731758918081, 0.14015754205839975, 1.1071227065154483, 7.524014047213963, 46.76879719325474, 62.99628720964704, 55.54826647894723, 59.79126385280064, 61.04370444161551, 48.401953901563374, 61.812425340924946, 50.53848327909197, 10.286321640014648, 15.334887947354998, 67.94945648738316, 54.68939617701939, 18.786391701017106, 54.600243840898784, 45.19258792059762, 31.84214891706194, 42.656387737819124, 62.54125663212368, 31.337282385144913, 0.49955365700381144, 0.2223044383738722, 0.27049942367843216, 0.1782187968492508, 0.13718992844223976, 0.13539798531149114, 0.16430543629186495, 0.14337018824049405, 0.19881221252892697, 0.1115282429382205], [0.0565914422539728, 0.06632964791996138, 0.081839384245021, 0.005919459350739739, 0.03658083047983902, 0.05100516861836825, 0.028531864884176424, 0.04677337980163949, 0.05779625581843512, 0.03213692483093057, 0.038360889069736004, 0.07283295824059419, 0.1702793671616486, 0.02470455418473908, 0.14184030890464783, 29.84528875350952, 44.405103410993306, 33.61460311072213, 29.52189874649048, 28.601276329585485, 32.774600642068044, 12.861281480107989, 70.6917645590646, 17.343831028257096, 3.419242399079459, 35.23816435677664, 58.48357118879046, 51.793974127088276, 60.54087025778634, 45.678902762276785, 55.89698614392962, 60.257870129176546, 46.29408931732178, 7.406633785792759, 0.42243847783122745, 0.16728135517665318, 0.15181405443165982, 0.08999217926923718, 13.110789554459707, 50.61879750660488, 56.67010872704642, 58.36543096814837, 58.722200121198384, 58.46564483642578, 55.505323137555806, 62.262397629874094, 57.56822592871529, 55.68303721291678, 53.21143790653774, 54.086761542728965, 50.28681605202811, 45.49238531930106, 44.471344062260215, 48.41095181873867, 52.808887072971885, 54.16737106868199, 54.45699283054897, 53.976733343941824, 53.207050119127544, 52.25811031886509, 46.91944803510393, 46.79586737496512, 42.936917781829834, 38.33221108572823, 40.08464751924787, 39.173610142299104, 39.548972674778526, 39.046218395233154, 40.07467338017055, 42.52969775881086, 42.28952980041504, 40.300059046064106, 41.165867124285015, 40.30341502598354, 45.44123615537371, 52.13106598172869, 51.88893863133022, 47.92945555278233, 45.055024010794504, 43.64332376207624, 37.844287736075266, 32.69276475906372, 32.100083419254844, 32.64412042072841, 34.910730498177664, 37.79240206309727, 38.70873744147164, 35.9091032573155, 37.55721943719046, 31.55273907525199, 37.188457693372456, 41.022171429225374, 40.333962781088694, 40.26371649333409, 40.08261864525931, 35.97810581752232, 35.47709900992257, 33.067057268960134, 40.1253604888916, 45.0678642817906, 43.99102551596505, 47.2943172454834, 45.357986313956125, 46.502601282937185, 39.10181440625872, 36.59252807072231, 38.46402188709804, 40.004951681409565, 40.45583071027483, 43.42878770828247, 41.43106596810477, 41.812289306095664, 39.62420776912144, 35.46146903719221, 38.88787589754377, 41.544762815747944, 44.85186563219343, 44.04744141442435, 45.77071278435843, 45.302306924547466, 43.82519980839321, 44.354242597307476, 46.99809469495501, 49.32850660596575, 50.24508169719151, 48.821649415152415, 47.95660216467721, 50.44685738427298, 49.892141001565115, 49.82612269265311, 51.49364866529192, 52.84746694564819, 48.77515207018171, 55.00755419049944, 55.8931542124067, 57.59451443808419, 59.17272131783621, 52.18171487535749, 47.26163639341082, 21.562433276857647, 8.025365659168788, 10.897216813904897, 4.79652908870152, 0.5891977410231317, 0.17824618252260344, 1.020401805639267, 24.740858929497854, 49.477976254054475, 46.022185461861746, 53.363214356558665, 47.489589418683735, 46.52727433613369, 47.35375561032976, 53.34776851109096, 25.430062907082693, 2.8000113410609107, 17.143408502851212, 62.37256826673235, 29.423505306243896, 18.434930971690587, 40.590608392442974, 16.89863736288888, 25.417887926101685, 37.84706006731306, 47.12256472451346, 5.354586252144404, 0.41693219329629627, 0.12352603806981019, 0.0687860736091222, 0.014746825476842267, 0.10722736229321786, 0.045129893347620964, 0.06347019957112414, 0.0708165896524276, 0.04461786064452358, 0.007404208050242492, 0.0463640196248889, 0.0394427181620683, 0.0953875979674714, 0.07528991997241974, 0.017967173031398227, 0.01896221749484539, 0.04470980553222554, 0.032723769412509034, 0.013947479842629815, 0.05039867366264973, 0.008075760095380247, 0.0861737709492445, 0.038245707750320435, 0.029280326329171658, 0.02254742181061634, 29.43558474949428, 55.618283476148335, 35.526062965393066, 26.39689952986581, 42.12385695321219, 31.42010838644845, 16.230265821729386, 62.71888732910156, 20.68386309487479, 4.627830301012311, 36.27337646484375, 66.86357811519078, 56.040841647556846, 65.58988993508476, 50.70787341254098, 57.36440052304949, 62.02076012747628, 54.069807938167024, 10.786746535982404, 0.17313863230603083, 0.2633792571723461, 0.13196995854377747, 0.2351397696350302, 16.719387735639298, 55.329547609601704, 56.25552361352103, 58.186448846544536, 58.25874137878418, 59.151070731026785, 56.761946541922434, 62.58566951751709, 58.46688856397356, 58.86767455509731, 56.34072242464338, 57.38853856495449, 53.84980712618147, 48.54921054840088, 48.794353416987825, 52.06160136631557, 56.553886209215435, 56.16333144051688, 55.33822590964181, 57.156190804072786, 56.93888936723982, 54.0866573197501, 49.10366289956229, 48.232146876198904, 43.84846237727574, 43.77948066166469, 43.71248960494995, 41.13662910461426, 42.2925557409014, 41.81661108561924, 41.13408258983067, 43.573532581329346, 45.506500584738596, 42.433906418936594, 43.09003176007952, 38.27988420213972, 47.30981867653983, 53.18542037691389, 52.896587235586985, 47.79564019611904, 50.792870725904194, 47.93120302472796, 44.637367793491904, 37.85152428490775, 38.631240708487375, 39.67290769304548, 42.45816952841622, 44.93148851394653, 45.36855104991368, 44.11955329350063, 43.787422452654155, 31.917429174695695, 31.248922143663677, 42.01210560117449, 47.784905229296, 47.98177548817226, 46.09437377112252, 44.72055162702288, 39.576320784432546, 37.53700017929077, 44.99392850058419, 50.89949083328247, 49.26773418698992, 51.470747402736116, 51.016658306121826, 50.428528036390034, 42.833132539476665, 38.46799973079136, 40.154654094151084, 41.453230721609934, 42.50243302753994, 43.942909240722656, 43.99304396765572, 44.04643045152937, 41.82886075973511, 39.40089266640799, 42.94963298525129, 44.485890116010395, 46.754369258880615, 48.78674513953072, 46.822336537497385, 47.775594643184114, 46.48714501517159, 48.02661221367972, 49.337685176304404, 52.32807520457676, 51.719875063214985, 52.073677335466655, 49.254094873155864, 52.03342294692993, 52.52459110532488, 51.17161355699812, 51.83771998541695, 51.28574814115252, 49.110513823372976, 54.238166264125276, 53.39570413316999, 55.19267504555838, 58.23158434459141, 52.76415457044329, 50.30366195951189, 25.58409231049674, 9.308360082762581, 23.79612626348223, 6.738798558712006, 1.726043701171875, 0.8480766011135918, 2.1414858315672194, 31.96506949833461, 52.124579838344026, 52.87308495385306, 58.152600697108674, 53.867639677865164, 52.08322068623134, 52.347964423043386, 58.986905642918174, 24.704940216881887, 4.771430024078914, 28.438681534358434, 56.04425321306501, 43.99759503773281, 15.772810322897774, 40.535908699035645, 24.165508134024485, 19.807280097688945, 45.52773775373186, 52.86739785330636, 3.493820454393114, 0.4575869174940245, 0.06790602047528539, 0.05271899201241987, 0.030487765824156146, 0.058758879878691266, 0.05260360034714852, 0.038622233617518625, 0.07231788909328835, 0.027471779446516718, 0.08006072004458734, 0.1624466303203787, 0.13787197827228478, 0.14158888453883783, 0.1415406135576112, 0.09025702505771603, 0.15243647460426601, 0.10329499401684318, 0.1477618840123926, 0.11779141293040343, 0.09082214973334755, 0.13186899253300258, 0.23346229536192759, 0.2997495484139238, 0.122166226751038, 0.43734738496797426, 50.119673660823274, 64.97455746786935, 42.77483715329851, 40.50273452486311, 45.712740489414756, 46.66643980571202, 15.619616440364293, 84.98692580631801, 23.394718408584595, 6.99497560092381, 43.24310752323696, 70.36789512634277, 62.1228916985648, 71.08720738547188, 54.146078314099995, 65.19459302084786, 69.43152114323208, 58.53760732923235, 9.94662160532815, 0.43080571027738707, 0.5091046616435051, 0.2582453526556492, 0.3743430743260043, 16.724157673971995, 58.11537572315761, 59.88061768668038, 61.628701073782786, 59.62907900129046, 59.05051640101841, 57.06166751044137, 63.8136385508946, 58.90926647186279, 58.968298367091585, 57.9379152570452, 59.088523047310964, 55.87064552307129, 49.77007852281843, 48.125353063855854, 54.32770422526768, 57.595334325517925, 57.33534663064139, 57.70528262002127, 59.01037665775844, 58.82244178227016, 55.0872917175293, 51.090128558022634, 52.87350879396711, 46.28925337110247, 43.35737759726388, 45.34918989453997, 43.069249698093955, 43.71342066356114, 43.4784186908177, 41.94398546218872, 45.368498938424246, 47.67270571844918, 43.77566262653896, 44.941386222839355, 41.74302618844168, 49.22149045126778, 57.04335553305489, 56.33360052108765, 52.88692923954555, 51.84579726627895, 53.281079701014924, 47.90929535457066, 43.41306740897042, 43.10094043186733, 45.67180517741612, 48.46024233954293, 51.3697692326137, 49.092066356113975, 47.83337933676583, 48.08205883843558, 39.023126057216096, 50.95148767743792, 50.38769347327096, 51.26440327508109, 52.809272697993684, 51.19035284859793, 49.40089293888637, 43.00433962685721, 41.84389666148594, 49.395518507276265, 54.51927300861904, 53.078355584825786, 57.28519800731114, 52.35833460944039, 53.07403033120291, 44.65148305892944, 40.3038284437997, 42.587677001953125, 42.46468346459525, 42.39203657422747, 46.392163140433176, 45.288980279650005, 46.29549285343715, 43.921296869005474, 39.29296629769461, 43.546031611306326, 45.862137181418284, 48.992637634277344, 50.15578344890049, 49.18785074778965, 51.044020312173025, 49.33928673607962, 52.0806429045541, 51.45000008174351, 53.82732622964041, 53.87022788184029, 54.67438806806292, 54.003591605595176, 53.12147610528128, 53.95877572468349, 53.89862169538225, 53.90078953334263, 53.403816155024934, 51.35450404030936, 56.03401156834194, 57.98923812593733, 58.72537544795445, 60.610755239214214, 56.91386890411377, 58.07255744934082, 39.64279767445156, 16.73679644720895, 41.01085628782, 11.445882184164864, 1.3428380638360977, 0.38807681309325354, 5.4263303109577725, 29.32862765448434, 57.40657956259591, 56.2966638973781, 61.73878138405936, 57.2209723336356, 55.840459074292866, 57.65483522415161, 62.192047119140625, 34.00493206296648, 5.377469275678907, 23.522219589778356, 68.79398918151855, 43.89403213773455, 23.466534989220754, 61.85045978001186, 23.75651110921587, 38.15848527635847, 49.96810565676008, 67.43963241577148, 10.614916716303144, 1.2198767704623086, 0.23718045013291494, 0.26187168806791306, 0.14551040982561453, 0.44643750148160116, 0.12643673616860593, 0.19223308270531042, 0.20531208946236543, 0.2003406397998333, 0.098739357399089], [0.006448055517726711, 0.03568509300904615, 0.016643546288833022, 0.003135070757707581, 0.009410954163675862, 0.023527847237086723, 0.039791030543191094, 0.028172933430011784, 0.012021595595537551, 0.10400197322347335, 0.04562368363674198, 0.06425029092601367, 0.11519562293376241, 0.010653313615226319, 0.09965334406920842, 5.183913307530539, 49.379492487226216, 45.3560060773577, 32.87557186399187, 30.165447848183767, 35.124828815460205, 13.181785379137311, 41.90840721130371, 54.01852675846645, 2.949317706482751, 18.635610580444336, 52.56395959854126, 55.46524592808315, 50.599491936819895, 60.319458961486816, 50.414506571633474, 47.644325801304404, 51.32374089104788, 33.89561258043562, 0.5473480352333614, 0.17294254925634178, 0.29215204609291895, 1.8665510416030884, 12.721463748386928, 38.942648547036306, 32.33661052158901, 42.02634246008736, 52.06392206464495, 55.82791757583618, 55.677794797079905, 58.05902583258492, 59.33049406324114, 56.292404651641846, 57.34160695757185, 54.66998985835484, 49.1683714730399, 47.28663601194109, 43.992713928222656, 42.77401726586478, 46.37067583629063, 54.777572291237966, 54.7414242880685, 51.21852084568569, 52.253541878291536, 50.95662587029593, 47.64131028311593, 42.6846147945949, 39.14226681845528, 38.92922115325928, 38.81933191844395, 39.12369775772095, 43.22352055140904, 43.497734682900564, 45.98941775730678, 44.63300085067749, 44.413538524082725, 43.07032666887556, 41.55695343017578, 40.66497496196202, 44.79364667619978, 51.91690165655953, 48.760508741651265, 47.580708095005576, 47.07997921534947, 42.61656066349575, 35.348751885550364, 32.60143068858555, 34.13521078654698, 38.84738874435425, 39.80298491886684, 39.846918378557476, 40.59962715421404, 42.636519363948274, 41.355601583208355, 34.28112643105643, 42.82745933532715, 42.03878320966448, 40.48930018288748, 41.3140652520316, 37.83739512307303, 37.11108602796282, 34.599590165274485, 33.95039217812674, 39.34448719024658, 43.178600447518484, 44.058322293417795, 45.241114139556885, 47.14245394298008, 48.06279843194144, 41.52616596221924, 36.36791712897164, 37.86868633542742, 43.13179043361119, 42.403824193137034, 42.99246168136597, 44.19628919873919, 44.44663279397147, 40.834806306021555, 38.878700801304404, 37.257991790771484, 37.04828473499843, 40.25091096333095, 41.98043918609619, 44.19816173825945, 44.59116574696132, 46.8615209034511, 45.98063176018851, 46.24838754108974, 44.754934787750244, 44.10410049983433, 43.75206307002476, 47.164517947605674, 46.98329850605556, 50.75570828574044, 48.49492427280971, 51.074317932128906, 51.9944817679269, 44.391273021698, 45.084866523742676, 46.5875186920166, 46.47857093811035, 38.69552891595023, 39.355645997183665, 20.697674376623972, 1.5503205018384116, 5.29586615732738, 7.837509819439479, 0.7117034388439996, 0.16266263515821525, 0.5703921701226915, 4.561348634106772, 40.86226211275373, 48.48685046604702, 48.551385334559846, 48.72748742784773, 51.34137541907174, 52.77121046611241, 51.171592712402344, 46.012280804770334, 4.155503051621573, 2.963751937661852, 44.744189398629324, 57.071339402879985, 12.532491854258947, 19.962009532111033, 35.88516671316964, 23.449892316545757, 28.821324041911534, 42.22080169405256, 32.888179370335166, 0.2049281472074134, 0.10492581900741373, 0.08595379668154887, 0.08202077701155629, 0.013984940912840622, 0.039967402150588374, 0.056761713831552436, 0.11151972053838627, 0.023226981417142918, 0.020479699995900904, 0.06104274732725961, 0.016855895519256592, 0.028965143420334374, 0.02545363479293883, 0.03685480595699378, 0.05956389382481575, 0.0429192296495395, 0.04019753748018827, 0.036150774985019646, 0.031179264254335846, 0.12061566566782338, 0.04679371210347329, 0.03807299005399857, 0.08256374751882893, 0.09993889196110622, 0.10640039095388991, 5.904158796582903, 59.53403459276472, 54.292713097163606, 28.827573946544103, 37.42078460965838, 39.03277015686035, 14.253386071750096, 52.522287777491975, 46.71949277605329, 8.491233689444405, 16.023793152400426, 55.446246079036165, 61.96358340127127, 59.500870840890066, 62.08164024353027, 56.76773091724941, 54.79527630124773, 56.11211626870291, 36.79287937709263, 1.1882468334266116, 0.1248699173863445, 1.125441957797323, 2.4930284193583896, 15.294539758137294, 45.05414158957345, 38.44457735334124, 47.277891704014365, 54.7527185848781, 58.97014658791678, 58.991255215236116, 58.374963896615164, 61.363599504743306, 59.43878173828125, 58.89837864467076, 57.560082639966694, 50.35541909081595, 51.219837529318674, 46.99600328717913, 46.11997440883091, 49.92478363854544, 57.468748569488525, 57.57853705542428, 54.68186780384609, 54.34538391658238, 53.83896446228027, 49.29873357500349, 46.66603333609444, 41.52208736964634, 42.399432931627544, 41.34201438086373, 41.36706611088344, 44.550734179360525, 46.94383273805891, 45.268590790884836, 48.13033839634487, 45.73702791758946, 42.27862112862723, 42.90736709322248, 41.89080742427281, 46.94020925249372, 51.70368576049805, 51.34131635938372, 52.131114619118826, 50.290425641196116, 45.987590381077354, 41.838452747889924, 37.03856073107038, 39.13621841158186, 43.37513024466378, 45.769680976867676, 46.78790473937988, 47.690315927777974, 48.527632917676655, 45.488723618643625, 39.49203566142491, 44.12242637361799, 49.91976356506348, 47.85468251364571, 47.03173092433384, 45.03236940928868, 44.22673273086548, 41.36191749572754, 39.11593314579555, 45.043722765786306, 49.37674447468349, 48.99385009493147, 49.40642023086548, 51.99773352486746, 49.95167316709246, 42.854699747903005, 39.34770768029349, 39.847356115068706, 43.041595867701936, 43.896311146872385, 45.21860197612217, 45.050170694078716, 47.77919033595494, 42.672622203826904, 41.17234284537179, 39.694544383457725, 41.54197311401367, 41.76731014251709, 45.95618799754551, 47.782483782087056, 48.77483940124512, 50.13154465811593, 50.3989634513855, 50.03286286762783, 47.488859857831685, 46.23778459003994, 45.57714639391218, 50.401454380580354, 50.062969412122456, 50.8937029838562, 50.719636712755474, 53.91502291815621, 50.6878730228969, 47.672118595668245, 46.83818885258266, 52.481692927224294, 51.59820168358939, 42.92383084978376, 46.420814037323, 26.684516736439296, 1.467914649418422, 8.639256375176565, 12.245895164353506, 0.8089879900217056, 1.259792325752122, 2.1643436678818295, 8.335526296070643, 48.57065268925258, 52.99754803521292, 54.41958372933524, 52.75362804957798, 58.26159361430577, 57.68742227554321, 59.17686244419643, 43.070872102464946, 5.33937143427985, 10.29319167137146, 44.3401585987636, 56.32877847126552, 24.022363083703176, 16.941796098436626, 46.41955641337803, 26.534588507243566, 24.08414125442505, 49.5711863381522, 37.41125168119158, 0.8344009178025382, 0.12987669158194745, 0.044808104900377135, 0.02960071020892688, 0.08623675256967545, 0.05745159395571266, 0.0340930768288672, 0.0730876260037933, 0.028006288622106825, 0.01874849762368415, 0.042811312047498565, 0.0632234231701919, 0.10456538120550768, 0.13263790841613496, 0.1388377235936267, 0.11783215217292309, 0.11300670967570373, 0.18514980136283807, 0.1274470476699727, 0.18660664318927697, 0.1880366150289774, 0.13881470768579415, 0.14092740789055824, 0.18614966342491762, 0.17945576618824685, 0.28183720101203236, 13.05059209891728, 77.36229923793248, 56.458206040518625, 50.687129565647666, 41.98056425367083, 55.28263684681484, 15.522605691637311, 56.04216180528913, 59.252361570085796, 6.4178386841501505, 22.388853754316056, 65.88566780090332, 64.1978530883789, 66.32535675593785, 68.66142450060163, 65.53509644099644, 57.36882305145264, 63.1920040675572, 41.55352102007185, 1.4165449887514114, 0.2879740074276924, 2.1912542581558228, 3.0540329217910767, 20.565979957580566, 51.7120235988072, 42.94234085083008, 49.730696133204866, 55.40678378513881, 58.70511450086321, 61.4248617717198, 60.662533215114046, 60.572373390197754, 61.507232666015625, 60.73457908630371, 59.32759666442871, 52.3292807170323, 52.66701875414167, 49.581608636038645, 45.885000228881836, 50.39689983640398, 61.973310879298616, 60.239443506513325, 54.93150615692139, 54.15808480126517, 56.10844414574759, 55.45827341079712, 49.78945357458932, 43.602968624659944, 44.29546083722796, 43.38784892218453, 42.39763682229178, 47.41318007877895, 50.49925027574812, 48.701931953430176, 50.55332810538155, 48.90600054604666, 45.72798136302403, 45.245290006910054, 44.655068329402376, 47.89582627160208, 54.40971728733608, 52.60159799030849, 54.62547969818115, 55.40798929759434, 49.5402911731175, 44.84118972505842, 41.046545709882466, 42.13856281552996, 50.39367239815848, 51.97638518469674, 51.06897824151175, 53.18391261781965, 53.3478136743818, 52.896278040749685, 42.946471554892405, 54.11002063751221, 54.71424988337925, 50.62480769838606, 50.96352890559605, 48.44100277764456, 48.394303934914724, 43.01157964978899, 43.06863478251866, 47.756612164633616, 51.23870536259243, 52.548579760960166, 54.078917026519775, 55.445235116141184, 52.62342923028128, 46.29611471721104, 41.398881912231445, 41.55710629054478, 45.74336120060512, 46.76433992385864, 46.16236536843436, 47.04272297450474, 49.91016810280936, 46.340520654405864, 43.87693609510149, 41.99929659707205, 41.58100461959839, 44.549688475472585, 47.665465695517405, 50.76994514465332, 50.33572094781058, 50.64166055406843, 53.572438512529644, 54.24602815083095, 51.45216791970389, 49.988929407937185, 48.50355046136038, 52.01259224755423, 52.77507019042969, 53.46835102353777, 52.82611165727888, 55.969264779772075, 54.827109473092214, 51.584833349500386, 52.124579838344026, 55.41909946714129, 58.322518893650596, 47.35509661265782, 53.70660475322178, 36.20292520523071, 3.46340080669948, 15.186945165906634, 24.622633593423025, 2.815313445670264, 1.2371400041239602, 1.8339741953781672, 7.689295189721244, 48.8610839162554, 58.98551600319998, 59.63815334865025, 56.11698348181588, 61.95817770276751, 60.17142064230782, 61.60413224356515, 53.866663455963135, 7.27430317231587, 5.775072991847992, 53.89545679092407, 67.64287417275565, 19.420112575803483, 27.63269223485674, 55.20022426332746, 31.80824170793806, 45.101253850119456, 50.617317540305, 54.990148953029085, 1.5009624532290866, 0.27708775443690165, 0.22560137217598303, 0.13095284812152386, 0.11469187853591782, 0.17629863774137838, 0.1662631862397705, 0.1370386422744819, 0.09162598302853958, 0.13018195091613702, 0.12188277553234782], [0.046220248232462575, 0.007036997620681567, 0.04081593054745879, 0.014766319787928035, 0.014901697702173675, 0.029188510363123248, 0.02114140904242439, 0.04142839661134141, 0.05555762629956007, 0.032599085210157294, 0.0506876074442906, 0.0525301150046289, 0.00861418102535286, 0.0624847835195916, 0.027855255208643417, 0.2964145487972668, 31.620418003627233, 46.748195784432546, 35.93550293786185, 29.794601644788468, 34.83242777415684, 25.0667051247188, 17.578895534787858, 68.74663720812116, 15.14713546207973, 0.9456351718732289, 10.531930037907191, 44.81354979106358, 55.78130905968802, 55.035350458962576, 53.087332657405305, 52.49932050704956, 50.92866284506661, 45.695863315037315, 10.12298251901354, 0.2842309097094195, 0.15434573643973895, 2.7812043045248305, 30.797306605747767, 58.3446558543614, 34.10624027252197, 44.401764801570344, 46.92998497826712, 53.13536902836391, 55.6705721446446, 53.05113254274641, 59.58339459555489, 58.065769059317454, 54.05900348935808, 55.59923498971121, 52.96371725627354, 47.125107765197754, 41.51999248777117, 40.76204129627773, 42.841314043317524, 44.75944764273507, 48.42223916734968, 52.088966846466064, 49.8621004649571, 48.360355036599294, 44.755431583949495, 39.97362225396292, 38.671707017081125, 38.86700003487723, 38.741491249629426, 44.11259119851248, 47.62381819316319, 49.211974893297466, 48.26751668112618, 46.04684461866106, 45.53413357053484, 42.75103609902518, 41.34409189224243, 40.95429795128958, 43.11454847880772, 52.57844311850411, 50.12943587984358, 47.46375254222325, 44.46684510367257, 40.40744692938668, 33.445754936763215, 34.447045939309255, 37.864909989493235, 41.46656778880528, 41.752281188964844, 40.76247555868966, 41.53201634543282, 41.83975553512573, 41.40156739098685, 35.67975017002651, 45.96193068368094, 42.077554157802034, 41.38982146126883, 40.71378605706351, 40.56654678072248, 38.83016416004726, 34.018970898219514, 34.6830449785505, 37.53423827035086, 45.714911801474436, 46.95500891549246, 46.763912609645296, 47.446764196668354, 50.18395839418684, 40.20246464865548, 36.257722173418315, 37.773746149880544, 42.54015132359096, 45.76192331314087, 47.06441525050572, 44.77725240162441, 45.311277048928396, 44.02704497746059, 39.990766933986116, 36.67923811503819, 38.57532508032662, 36.70406402860369, 38.15538985388619, 39.440257685525076, 42.20520993641445, 44.738238266536165, 42.14849179131644, 44.3612185886928, 44.187704699380056, 45.94425099236624, 46.59216703687395, 44.201430865696494, 46.5215733391898, 48.8027468408857, 49.502124718257356, 48.20755025318691, 44.185269355773926, 42.633246762411936, 34.715715408325195, 23.717455284936086, 15.70560908317566, 16.00534221104213, 7.591408967971802, 1.1052305166210448, 0.18973087625844137, 1.332014290349824, 0.35682077599423273, 0.30464360437222887, 0.6937916885529245, 4.315095356532505, 18.482401064464025, 49.09447390692574, 45.349099567958284, 46.71936076028006, 51.510348660605295, 50.2369453566415, 45.25838736125401, 48.64767347063337, 17.08247106415885, 0.7254562037331718, 17.111825466156006, 61.904176303318565, 29.810513019561768, 8.33816921710968, 28.612659215927124, 26.063205344336374, 18.95295739173889, 30.241339547293528, 50.42883723122733, 21.581829173224314, 0.11151083172964198, 0.14739927489842686, 0.047834489827177355, 0.005903936589934996, 0.04430151065545423, 0.0166721736812698, 0.06475356713469539, 0.0372542663078223, 0.03840412532112428, 0.06019495853355952, 0.0370980811172298, 0.07951766132776227, 0.017348547565883825, 0.05146695241065962, 0.06369436039988484, 0.010260223860054143, 0.036791753090385876, 0.04221272881009749, 0.06816989595868758, 0.03547359364373343, 0.004118763118250561, 0.05973834517811026, 0.041600540945572514, 0.08200032596609422, 0.02662936465016433, 0.007137164656471993, 0.1000954367752586, 33.181469781058176, 56.56607334954398, 39.845535687037874, 29.99296576636178, 42.05059167316982, 20.09546705654689, 27.569757189069474, 67.72136797223772, 24.469363280705043, 3.4281154658113207, 9.715494990348816, 45.63324267523629, 58.949288095746724, 60.73437064034598, 58.93026392800467, 58.403263909476145, 57.56158345086234, 51.7546820640564, 12.629436595099312, 0.16317731754056045, 0.4875881533537592, 2.548146741730826, 35.992936747414724, 62.01889106205532, 38.37498419625418, 49.10124840055193, 49.467592171260286, 55.447729519435335, 57.836777278355186, 57.29338993344988, 61.26144708905901, 62.20015566689627, 59.32086385999407, 55.89230305807931, 56.95083679471697, 50.15830217088972, 45.10270602362496, 44.84717559814453, 45.8378358568464, 48.11771004540579, 51.00239365441458, 56.09036840711321, 52.3963759967259, 49.880811963762554, 47.5975227355957, 43.770520959581646, 41.110139097486226, 43.02219302313668, 40.10941437312535, 44.239291599818635, 48.40751246043614, 51.24432992935181, 50.907436098371235, 46.38692767279488, 46.18922363008772, 43.17970173699515, 41.034761565072195, 40.10355356761387, 45.06182977131435, 53.78700930731637, 52.95368753160749, 51.482865061078755, 50.32180718013218, 46.263600621904644, 39.41263164792742, 37.358705929347444, 42.12137992041451, 47.783279350825715, 47.03853668485369, 47.47024910790579, 47.84237725394112, 48.94408362252371, 47.29103422164917, 42.045133863176616, 47.295050280434744, 46.72273063659668, 45.7313095501491, 46.161601066589355, 44.94348110471453, 42.621247223445344, 39.28895023890904, 40.13756152561733, 43.51210355758667, 51.707997117723735, 50.9264428956168, 51.05433143888201, 51.81247023173741, 53.02196053096226, 45.37256710869925, 38.26500116075788, 39.93058511189052, 43.27042784009661, 45.62337623323713, 46.16412673677717, 46.79892805644444, 48.187136445726665, 46.75418165751866, 43.45460721424648, 38.51929133278983, 41.46051590783255, 40.000251225062776, 41.55863836833409, 42.01628841672625, 44.19661923817226, 45.815316745213096, 45.42201048987252, 47.51847308022635, 45.820701599121094, 48.15225648880005, 49.616801261901855, 46.58465256009783, 50.68053225108555, 50.71966797964913, 51.41363321031843, 52.08307477406093, 48.357527119772776, 45.85862486703055, 39.23678316388811, 27.409326757703507, 21.528995071138652, 19.758507217679703, 11.189353823661804, 2.050982505083084, 0.19527388310858182, 1.3710772799594062, 0.9674228770392281, 0.6195852532982826, 0.3017818693603788, 3.898668101855687, 22.26452442577907, 51.54045173100063, 49.129805496760774, 51.828968729291645, 57.751540252140586, 56.10370200020926, 51.11202927998134, 51.44856180463518, 15.009479488645281, 5.064799470560891, 23.250560658318655, 53.270987442561555, 38.1052690233503, 14.310545427458626, 24.162933826446533, 40.06255572182791, 21.21930343764169, 30.69501175199236, 59.502969196864534, 23.937681913375854, 0.39973442469324383, 0.027764441778085062, 0.043546596342431645, 0.04613456283030765, 0.017106332616614442, 0.024633774500606314, 0.04561215532677514, 0.02426323840128524, 0.016394121904990504, 0.08552182093262672, 0.04872959286772779, 0.17509051971137524, 0.09621490857430867, 0.1982117633202246, 0.1382769551128149, 0.12267444948000567, 0.10612071238990341, 0.12705805711448193, 0.1615653218967574, 0.16104574049157755, 0.11432039418390819, 0.12631788397473948, 0.21431413213057177, 0.12055493678365435, 0.11156024943505015, 0.1255983111581632, 0.9667199147599084, 61.5361510685512, 58.32798017774309, 51.500023637499126, 42.760930333818706, 52.789070810590474, 32.052140848977224, 23.89066171646118, 81.04282256535122, 21.106801680156163, 2.1017080460275923, 15.078723498753138, 55.07992662702288, 65.4915520804269, 65.51304285866874, 62.05835683005196, 64.70377227238247, 63.597306387765066, 56.30954933166504, 14.209351863179888, 0.4623698836990765, 1.586002107177462, 3.8121382764407565, 40.80608940124512, 67.58132702963692, 45.419220788138254, 55.36593879972185, 51.995940889631, 59.290917124067036, 59.896786144801546, 59.28853389195034, 62.565068108694895, 60.593176296779085, 60.86952699933733, 58.450185094560894, 58.464310782296316, 51.57069376536778, 46.95954261507307, 46.11749390193394, 47.40543283735003, 50.75185898372105, 53.30474526541573, 59.65869222368513, 54.791086537497385, 52.73813009262085, 48.60115875516619, 44.8718694959368, 42.57087973185948, 45.96393176487514, 44.634470394679475, 49.541715553828645, 50.77363811220442, 54.99242448806763, 53.01177447182791, 48.9879024369376, 48.89453601837158, 44.89051151275635, 43.15067563738142, 44.39686632156372, 46.12554686410086, 56.10348660605294, 55.08538096291678, 54.27964700971331, 52.88017559051514, 48.452144214085166, 41.89787374223982, 42.042045388902935, 46.01961462838309, 52.84747389384678, 52.02280262538365, 49.58215406962803, 49.89343336650303, 53.54680660792759, 49.773160048893516, 44.80428784234183, 53.084904261997764, 49.640821184430806, 50.975861958095, 48.64662776674543, 49.959687914167134, 47.61044985907418, 43.5338305745806, 42.688116686684744, 45.88514266695295, 55.662505286080496, 54.75249971662249, 52.90944487707955, 55.97288131713867, 56.14242778505598, 47.48925243105207, 40.08732952390398, 41.37276363372803, 44.67977959769112, 49.26593460355486, 47.848964146205354, 47.26150437763759, 47.675603117261616, 46.71557399204799, 43.14270952769688, 39.05335419518607, 42.2637346131461, 40.86320011956351, 42.63852391924177, 43.08309398378645, 46.3864551952907, 50.684214796338765, 47.0575921194894, 49.83599260875157, 46.64074189322335, 50.342561449323384, 53.57735783713204, 48.40824896948678, 52.85821580886841, 53.00450318200247, 54.19670288903372, 52.91470813751221, 52.95708172661917, 49.27030502046858, 44.73468426295689, 35.63950967788696, 28.734270061765397, 28.250960315976823, 20.311576877321514, 4.765881018979209, 0.7466130341802324, 3.994540648800986, 1.5896335180316652, 1.4617220674242293, 1.2829541457550866, 8.92896933215005, 23.04906289918082, 57.631583077566965, 52.859157289777485, 54.677320207868306, 59.92019462585449, 59.39775957380022, 54.5244494165693, 57.627810205732075, 21.756598949432373, 2.6982510643345967, 23.521792275565012, 70.7990586417062, 38.778441769736155, 11.449477008410863, 43.4400646345956, 41.20368616921561, 28.55112075805664, 43.40593160901751, 61.78857912336077, 39.36601618358067, 0.61993336890425, 0.2515672381435122, 0.1769094413944653, 0.1731110702135733, 0.10844981098281485, 0.11144743620284966, 0.2475518850343568, 0.15787671054048197, 0.1362633074500731, 0.28989898413419724, 0.16215733012982778], [0.033972579187580516, 0.06753748775060688, 0.07420943437942437, 0.11361444635050637, 0.028507936346743788, 0.007668630602503461, 0.06961299745099885, 0.0795041856222919, 0.01522444627646889, 0.0451201360140528, 0.17712605691381864, 0.07869814030293908, 0.1432248731809003, 0.10360545771462576, 0.11502381786704063, 0.4524232660021101, 8.761111276490347, 58.69809682028634, 44.66721030644008, 31.425305638994487, 34.685984066554475, 39.180992603302, 10.318654213632856, 45.15997307641165, 57.309259619031636, 8.789666635649544, 1.0385463748659407, 17.441920484815324, 45.573050430842805, 53.543061528887065, 43.96911089760916, 50.86099781308855, 50.03912666865757, 51.48458821432931, 18.56640304837908, 0.1456529428916318, 0.14752677162843092, 0.18129326616014751, 0.4038821192724364, 2.0620998399598256, 20.223894085202897, 43.82713835580008, 59.889379365103586, 54.2255448613848, 61.9163703918457, 54.99452631814139, 58.84877545492989, 58.688070569719585, 58.2722521509443, 54.14912509918213, 57.13329996381487, 50.477790764399934, 43.95218161174229, 41.21228109087263, 42.81987885066441, 41.73673459461757, 41.44931888580322, 43.08494915281023, 43.79462078639439, 42.96658311571394, 40.992718015398296, 38.9790049961635, 38.894000734601704, 40.79816150665283, 43.104984283447266, 48.48564495359148, 47.81504998888288, 50.508772781917024, 51.48917402539934, 48.39521762302944, 45.509766238076345, 45.32047298976353, 42.327988079616, 39.00472722734724, 42.65262876238142, 49.871414525168284, 48.82669728142874, 45.90257569721767, 41.99479763848441, 38.2264838218689, 33.40451042992728, 35.682911600385395, 41.63157360894339, 42.82998847961426, 42.668918813977925, 45.36758872440883, 42.70110634395054, 45.720466886247905, 37.33336237498692, 40.14062220709664, 49.767542430332725, 39.78086880275181, 42.53796264103481, 38.096483026232036, 38.90334953580584, 40.10090977805001, 36.10576507023403, 33.43878936767578, 37.72183963230678, 44.34065192086356, 48.798967020852224, 45.77699395588466, 44.66852004187447, 49.51440565926688, 42.702377864292686, 36.8111183983939, 37.11615473883492, 42.28539909635271, 45.06511626924787, 48.03301845278059, 46.200900077819824, 49.84461532320295, 44.22970655986241, 42.730153288160054, 39.22312647955758, 37.66890825544085, 38.39388677052089, 35.38126598085676, 39.67109768731253, 38.23702423913138, 39.94723299571446, 41.03892701012747, 39.83953244345528, 40.1042240687779, 39.816537380218506, 40.790796416146414, 43.29537534713745, 48.767606326511924, 48.36756031853812, 47.80185535975865, 49.35250220979963, 45.011889593941824, 37.350670337677, 33.036255904606406, 22.377012286867412, 22.41519784927368, 9.642347829682485, 9.663629293441772, 4.084517214979444, 0.30350198277405327, 0.5223320775798389, 0.854671581515244, 0.2585717279996191, 1.24532422210489, 5.302886009216309, 30.61085169655936, 51.76422888892037, 48.30088193075997, 48.92952714647566, 45.67826700210571, 38.206347942352295, 35.49500451769148, 29.75546244212559, 0.9697981838669095, 6.929886179310935, 50.220752579825266, 59.58476339067732, 19.82985132081168, 13.65164862360273, 32.7262863431658, 25.629655122756958, 18.646253483636038, 34.637662819453645, 48.16196659633091, 10.25136091027941, 0.39836877797331127, 0.13209692601646694, 0.11115242274744169, 0.07778163626790047, 0.06007490533271006, 0.013107807175921542, 0.1387937952365194, 0.07213293401790516, 0.13140243185417994, 0.028094413357653787, 0.03551695542410016, 0.012909250017920775, 0.05476683444742646, 0.12548808992973395, 0.03345957278673138, 0.05194653756916523, 0.04702911286481789, 0.012545846169814467, 0.047898764056818824, 0.10048824069755417, 0.10182435757347516, 0.1250389947422913, 0.03372253564053348, 0.03761108751807894, 0.04308304835909179, 0.10117831081151962, 0.2933052842106138, 11.346236331122261, 72.45719064985002, 48.44057546343122, 33.735348905835835, 39.644965512411936, 31.94716051646641, 12.144170062882559, 52.50509098597935, 51.93192366191319, 16.83161677633013, 2.1717046328953336, 19.181424583707535, 50.683766637529644, 59.271517753601074, 48.871804986681255, 55.825176511492046, 52.61194733210972, 57.90967777797154, 20.98093158858163, 0.18030058299856527, 0.09292630039687667, 0.8647340387105942, 0.41022395182933125, 4.624756157398224, 23.599834442138672, 46.20578466142927, 62.9990873336792, 57.538001264844624, 64.70018005371094, 56.57733637945992, 60.63937486921038, 59.40644482203892, 61.077966008867534, 57.2834609576634, 60.12845993041992, 55.61345795222691, 47.3294403893607, 44.48116186686924, 45.1617830821446, 44.68177720478603, 44.958784512111116, 45.89372021811349, 47.407711846487864, 44.84967694963728, 42.846476554870605, 43.19359118597848, 39.770161628723145, 41.47145584651402, 45.95722675323486, 50.941718510219026, 51.63853945050921, 51.871429170881, 50.41433981486729, 50.39552756718227, 45.05484683173043, 43.457407338278635, 43.43023293358939, 41.03700583321707, 42.447830608912874, 52.312323638371055, 52.06744827542986, 50.22144739968436, 46.30416767937796, 43.91613783155169, 36.1748058455331, 40.17602327891758, 45.69222593307495, 48.7578684261867, 48.22607067653111, 49.67099026271275, 48.45128958565848, 50.24443898882185, 44.98707757677351, 43.96520948410034, 54.44456250326974, 46.619782652173726, 46.573149817330496, 43.934897967747276, 45.18629632677351, 44.82717520850045, 39.80694191796439, 37.71562794276646, 41.435068130493164, 49.19492401395525, 52.257484980991904, 51.25830970491682, 50.31224993297032, 54.2705830846514, 46.78026519502912, 40.60206249782017, 41.05289288929531, 43.84537042890276, 47.20596047810146, 50.392178535461426, 47.433249950408936, 51.75223282405308, 46.61624601909092, 46.238656588963096, 41.0537440436227, 38.98505687713623, 40.2866907119751, 38.42460823059082, 41.05734668459211, 42.561805384499685, 42.574927057538716, 41.846161774226594, 42.012324469430105, 42.71547521863665, 42.45048482077462, 43.97512108939034, 46.48143707002912, 50.95963791438511, 49.74905674798148, 53.312433447156636, 51.07407474517822, 49.55014719281878, 40.353650501796174, 36.78470829554966, 25.970120327813284, 26.92729374340602, 11.771334069115774, 11.990333471979413, 5.113601446151733, 0.4334219784608909, 0.22395350917109422, 0.6236184111663273, 0.17217461046363625, 1.3222369807107108, 5.863586962223053, 38.03847599029541, 54.47739968981062, 53.829765047345845, 54.1701295035226, 52.1216824395316, 39.98175859451294, 40.55082995550973, 28.04213915552412, 3.8144251023020064, 10.79358182634626, 42.61724853515625, 55.57684094565255, 29.420531477246964, 15.02722692489624, 34.17120245524815, 36.30978502546038, 16.150924342019216, 38.62157923834664, 55.37047944750105, 9.35374745300838, 0.4656357541680336, 0.18567054984825, 0.11398317585034029, 0.07827873780791249, 0.01645825194594051, 0.04735371723238911, 0.03475674853793212, 0.0875950711114066, 0.10451111197471619, 0.040958120953291655, 0.06773684133908578, 0.19544028703655514, 0.23145136183926038, 0.1496447372649397, 0.1997156004820551, 0.10387249517121486, 0.14564746032868112, 0.16632338586662496, 0.1220942884683609, 0.14266995367194923, 0.2306819302695138, 0.35035042890480583, 0.21940132629658493, 0.35901955515146255, 0.12149696052074432, 0.4205818160304001, 0.5692504942417145, 21.027442829949514, 84.67151927947998, 54.423829078674316, 47.20303528649466, 49.12813445499965, 56.06312799453735, 11.065658518246241, 58.923579760960166, 61.594092096601216, 14.62068956238883, 2.8134055137634277, 24.00162444795881, 55.34229407991682, 66.8069850376674, 55.733977930886404, 60.82170254843575, 57.42147650037493, 62.886714117867605, 23.15465293611799, 0.39700793528131073, 0.20295412598976068, 1.812312426311629, 1.6467862512384142, 6.8812896098409375, 28.07509446144104, 50.96511656897408, 65.76667295183454, 59.24783829280308, 67.78142820085797, 56.25438410895211, 64.00663866315568, 60.34723785945347, 62.10682051522391, 59.82817963191441, 61.16789654323033, 56.487256458827424, 49.29838963917324, 45.69064174379621, 45.68284239087786, 46.514375005449565, 45.9190012386867, 47.54017925262451, 46.66210412979126, 47.72408069883074, 45.497391496385845, 46.461679867335725, 42.32456956590925, 45.30024330956595, 49.99467556817191, 52.30167899812971, 53.88273811340332, 55.96085745947701, 54.41351447786604, 51.36562115805489, 46.02443667820522, 46.94390916824341, 45.18793610164097, 42.15097924641201, 43.13201625006539, 53.18070602416992, 54.61211831229073, 51.74303340911865, 47.13638816561018, 45.73432854243687, 38.41131285258702, 44.98358958108084, 50.14018474306379, 50.775666986192974, 51.24885320663452, 52.613006932394846, 50.812242303575786, 53.69066558565412, 44.65093067714146, 43.99388122558594, 56.33677932194301, 49.54780912399292, 49.926253182547434, 46.16376543045044, 46.75235775538853, 46.90906047821045, 42.762052467891145, 40.76279864992414, 45.677839687892366, 51.74404089791434, 55.7140748160226, 53.29735585621425, 53.79691743850708, 54.6674850327628, 48.35329219273159, 42.70863471712385, 42.62399871008736, 45.53077064241682, 48.556523527417866, 52.203257765088765, 47.91119221278599, 52.21179710115705, 48.491161823272705, 47.15003442764282, 40.797015053885325, 39.42601040431431, 41.967869894845144, 39.77100930895124, 43.039108412606375, 43.307767459324424, 44.17480884279524, 44.01307215009417, 44.23982661111014, 47.163500036512104, 45.21255704334804, 46.29381833757673, 48.467801979609895, 54.916095052446636, 52.14100537981306, 55.45467076982771, 54.03591462544033, 51.03001274381365, 43.385417052677695, 39.17938756942749, 27.459319046565465, 31.44359677178519, 15.535207986831665, 13.081224969455175, 5.794171852724893, 0.8647957582558904, 0.9023366038288388, 2.042277063642229, 0.7804597179804529, 4.272970165525164, 9.743133187294006, 38.9191323689052, 60.4409065246582, 56.64241320746285, 56.85071325302124, 57.25660269601004, 46.27854272297451, 46.785573618752615, 34.73321097237723, 3.4997209949152808, 9.057093245642525, 61.125644547598704, 65.44875117710659, 30.353618962424143, 17.641747202192033, 52.587441035679404, 35.67958688735962, 28.928289822169713, 43.418139593941824, 65.10027122497559, 19.087436301367624, 0.6554104909300804, 0.290506761521101, 0.36657452689749853, 0.253644125269992, 0.15772245238934243, 0.1375885270535946, 0.19385693914123944, 0.21627944095858506, 0.2589140353458268, 0.2545672857335636, 0.16564356163144112], [0.014439652673900127, 0.07732424938252994, 0.01189843555247145, 0.012478531255120677, 0.030260575336537192, 0.022381976313356842, 0.02476788355436708, 0.03562553120510919, 0.057167681333209784, 0.03750626064304795, 0.00836687536710607, 0.0873991237687213, 0.11111703714621918, 0.03651223737480385, 0.028851471841335297, 0.21311791560479573, 1.9554319637162345, 48.76735619136265, 40.592804023197715, 40.233985151563374, 39.681221212659565, 44.71169267381941, 22.909351996013097, 22.703963245664323, 70.35547869546073, 40.75247710091727, 7.2519751361438205, 9.890178782599312, 47.258864062173025, 57.53118160792759, 49.331313678196494, 44.74992861066546, 55.8330522945949, 46.54961279460362, 23.997747353145055, 1.8449245563575198, 0.2455963742520128, 0.37921376153826714, 0.547941943364484, 0.48694984189101626, 7.529713307108198, 20.93267982346671, 48.250455379486084, 59.50815255301339, 57.71653175354004, 56.442777565547395, 58.58996895381382, 57.044380392347065, 59.313012395586284, 55.58674560274397, 56.54383216585432, 54.58588538851057, 46.98029341016497, 41.143334116254536, 43.41262967245919, 41.78178324018206, 41.65860904966082, 40.647034713200156, 39.393402508326936, 40.69994871956961, 40.857999392918174, 40.04543188640049, 37.03660828726632, 39.533804757254465, 46.96319041933332, 50.761450971875874, 51.84895869663784, 50.819687298366, 49.56268521717617, 48.75422409602574, 47.77607406888689, 43.48449141638619, 40.34025090081351, 40.76659236635481, 41.131720202309744, 44.96856757572719, 46.94477769306728, 44.85292523247855, 42.61430944715227, 36.702045576913015, 34.156562600817, 38.38125147138323, 41.237221649714876, 43.98849637167794, 42.93530232565743, 46.28520951952253, 43.27240807669503, 45.024403299604145, 36.60661901746477, 46.37150614602225, 44.39414957591465, 44.23223917824881, 45.960735593523296, 41.96185622896467, 43.60726955958775, 40.03514160428728, 35.76031800678798, 35.00595555986677, 37.50843613488333, 43.9867627961295, 47.48509046009609, 48.45507287979126, 46.57786069597517, 49.58390154157366, 40.401784147535054, 36.57764155524117, 35.75182383401053, 41.17418759209769, 47.14631366729736, 47.464075633457725, 47.78620801653181, 49.69721623829433, 47.53668083463396, 44.95009926387242, 41.84017242704119, 41.067511899130686, 37.65120424543108, 37.70142929894583, 35.83658490862165, 36.99719115665981, 35.90854740142822, 38.27280746187483, 38.99527767726353, 39.09077024459839, 40.504110268184114, 42.71723311288016, 43.413244588034495, 46.20892524719238, 48.20326321465628, 46.8898834500994, 42.59746701376778, 44.46598352704729, 43.365823132651194, 41.0443639755249, 35.81178331375122, 28.349852289472306, 19.848165035247803, 17.909207684653147, 4.562506811959403, 0.19823524063186987, 0.9865118584462574, 0.236445352435112, 0.15892793770347322, 0.2181899377277919, 13.485390390668597, 42.060944489070344, 48.68845592226301, 42.13097538266863, 44.34678370612008, 53.45492015566145, 47.42018733705793, 42.27477182660784, 12.518552899360657, 1.7138079234531947, 23.892694064549037, 63.00348554338728, 54.74821267809187, 15.95459430558341, 25.896097694124492, 28.148566450391495, 20.556033611297607, 30.750600814819336, 43.453710896628245, 48.6889978817531, 1.7887775748968124, 0.08526987409485237, 0.03583522905994739, 0.04483866611761706, 0.020433266148237244, 0.08859419357031584, 0.005488797415247453, 0.018609704981957163, 0.03972166730090976, 0.015647875876831155, 0.025266801871891533, 0.010275953149955188, 0.011762570789349931, 0.06701437117797987, 0.030004282481968403, 0.07362800450729472, 0.026257186496098126, 0.01978119569165366, 0.031087879158024277, 0.05568719934672117, 0.1051459221967629, 0.04364796947421772, 0.0095171143600185, 0.007853534787760248, 0.07867175207606383, 0.05311525646331055, 0.007011794285582644, 0.10738330321120364, 1.304921309862818, 54.93765878677368, 47.43675879069737, 41.198659147535054, 43.93821920667376, 44.70041922160557, 16.042732204709733, 34.6810473714556, 61.6302296774728, 40.448948519570486, 9.10968850340162, 10.461706331798009, 51.923318317958284, 63.58400058746338, 54.52193069458008, 48.49306910378592, 63.20640768323626, 52.34931237357003, 27.1171167918614, 1.9283005510057722, 0.13208834933383123, 0.7710215672850609, 0.8706451100962502, 1.7073305738823754, 8.2281688111169, 24.071710927145823, 52.769605432237896, 60.78619725363595, 61.33415303911482, 60.8379613331386, 60.0622991834368, 59.36647183554513, 63.01472078050886, 59.081199645996094, 59.132018770490376, 56.740490504673545, 49.91051551273891, 43.62508474077497, 46.4101311819894, 45.81706769125802, 43.51500790459769, 44.02870559692383, 42.21086924416678, 43.471255098070415, 42.5663286617824, 44.322273935590474, 39.592200892312185, 43.02668503352574, 49.604857308524, 53.98515108653477, 52.70540755135672, 53.76531703131539, 53.96042592184884, 49.77684954234532, 47.55757406779698, 45.0601761000497, 41.864546707698274, 40.516384260995046, 43.28131914138794, 48.03945943287441, 50.19949804033552, 48.44376816068377, 46.58348526273455, 41.49835927145821, 36.94947092873709, 41.79346316201346, 46.65057012013027, 49.576404435294016, 47.163711956569124, 50.93235581261771, 46.34010028839111, 50.690412589481895, 41.97375501905169, 50.443671635219026, 52.35587494713919, 45.696533816201345, 48.82564115524292, 45.696773529052734, 47.44340821674892, 46.35202687127249, 41.3084511075701, 37.575489725385395, 42.15550947189331, 48.37116643360683, 50.94078745160784, 51.69605316434588, 51.74030276707241, 51.535292693546836, 46.10311113085066, 38.94766514641898, 38.4685104233878, 43.10992097854614, 45.590042250497, 49.6157659803118, 48.133538041796, 50.42950425829206, 47.79530668258667, 46.83783796855381, 44.22274446487427, 43.02757092884609, 40.244994572230745, 39.28199856621878, 37.894099371773855, 39.80842883246285, 36.39596700668335, 40.97032049724034, 40.30801820755005, 42.30684123720442, 41.872464179992676, 45.962611607142854, 46.711672578539165, 48.54885966437203, 49.003289222717285, 49.81296975272042, 44.96795266015189, 47.80595132282802, 45.3024354662214, 45.344333103724885, 39.82569510596139, 31.63608271735055, 25.13267305919102, 19.913250548498972, 5.019712175641741, 0.22642518154212407, 0.6615253399525369, 0.3312302620283195, 0.2749318315514496, 0.7530643280063356, 16.3146082673754, 46.32439388547625, 53.220970835004536, 47.931449685777935, 48.73049252373831, 56.303969928196494, 51.53199577331543, 45.97668170928955, 14.222736699240548, 4.351170837879181, 20.397084883281163, 58.515831674848286, 57.25274644579206, 23.18394133022853, 20.743230240685598, 32.537514209747314, 18.749918869563512, 23.015541315078735, 50.853764738355366, 54.99485288347517, 1.9402775083269392, 0.13516729697585106, 0.05665411514097026, 0.05483456581298794, 0.025721834240747348, 0.029587682336568832, 0.06489642589752163, 0.022668630217335055, 0.04418203420937061, 0.009870497942236918, 0.04760576245774116, 0.034147648007742, 0.1307108011096716, 0.26968349888920784, 0.09760802239179611, 0.1254074799695185, 0.1361756000135626, 0.1105547012495143, 0.15143421052822045, 0.11392241982477051, 0.1793669323836054, 0.278777008077928, 0.1698022891900369, 0.05610012183231967, 0.1195437703281641, 0.09889559687248298, 0.16548520512878895, 0.24571074811475618, 3.472585673843111, 78.73438780648368, 50.13027661187308, 53.78603308541434, 53.25060837609427, 65.75998878479004, 26.462002413613455, 34.979566301618306, 78.74638039725167, 47.05849538530622, 12.30596147264753, 12.922561986105782, 55.105940682547434, 68.74462223052979, 59.19788769313267, 55.39799778802054, 68.38325337001255, 58.52927643912179, 30.657692977360316, 2.571662051337106, 0.49521287849971224, 1.4759619661739893, 2.409622026341302, 3.1182169062750678, 10.23296468598502, 25.19015203203474, 56.354083810533794, 61.98485878535679, 62.43758256094796, 61.3157958984375, 61.361369132995605, 61.85369069235665, 62.20785427093506, 61.84624917166573, 61.741206305367605, 59.311546325683594, 52.21944011960711, 45.64908456802368, 48.184409277779714, 47.224098750523154, 46.51226622717721, 46.25761474881853, 45.104074818747385, 44.69241837092808, 46.20413099016462, 46.34916421345302, 41.82688052313668, 44.69839382171631, 51.219441481998985, 58.11396523884365, 55.269914695194785, 56.757847104753765, 55.0669195992606, 51.38166107450213, 51.63199077333723, 46.18216078622, 43.70970685141427, 43.940995012010845, 44.59419168744768, 47.62116745540074, 51.22423921312605, 50.96357406888689, 47.98286982945034, 42.68616076878139, 40.48188992909023, 45.41297435760498, 48.83806800842285, 51.5988061768668, 49.390647820064, 53.82124655587332, 49.47884825297764, 52.037060328892295, 44.794490882328574, 51.08874934060233, 53.49740144184658, 49.681895460401265, 53.789555822099956, 49.976158618927, 50.84094878605434, 49.421133041381836, 43.3575895173209, 40.88018151691982, 46.36627762658255, 52.022826944078716, 53.72152253559658, 55.419835976191926, 54.622523239680696, 55.321289675576345, 47.6637772832598, 40.25211647578648, 39.216807092939106, 45.67863525663103, 47.80963386808123, 50.2410170010158, 48.993401936122346, 52.93142202922276, 48.25060823985508, 49.49657310758318, 44.464552198137554, 44.66762719835554, 41.643215315682546, 40.76168693814959, 39.78286293574742, 42.343110833849224, 38.79996034077236, 43.609256744384766, 42.878118651253835, 44.19312082018171, 43.74586180278233, 48.996608529772075, 48.22037315368652, 50.84042419706072, 52.41577189309256, 52.03850555419922, 46.66417816707066, 51.3384120123727, 49.19994756153652, 50.48251553944179, 45.8640444619315, 36.774463176727295, 27.302334921700613, 23.651027032307216, 6.160237695489611, 0.9128549822739193, 1.8014405582632338, 0.7206027784517833, 0.7528911658695766, 0.9419064862387521, 18.315922226224625, 49.721229212624685, 57.82870347159249, 52.42139645985195, 51.477966581072124, 60.49687426430838, 52.69916806902204, 51.2034467288426, 17.67983548981803, 3.9983499986784796, 31.75918047768729, 72.74045481000627, 62.37756402151925, 21.75728334699358, 35.85984747750418, 44.75170734950474, 26.935930354254587, 45.941773959568565, 55.09253413336617, 69.88431440080915, 5.437736213207245, 0.4958072208932468, 0.13969664036163262, 0.17811580880412034, 0.1165565334792648, 0.2250151043491704, 0.23999305920941488, 0.17768439623926366, 0.16500842571258545, 0.12329267630619661, 0.10155067047370331, 0.13416899554431438], [0.014662534464150667, 0.024828028898420076, 0.024460488531206335, 0.01139034004881978, 0.0268584075383842, 0.03938856428222997, 0.034254076225417, 0.09869102534971066, 0.07159278621631009, 0.07777345313557557, 0.006209783705084452, 0.04031291218208415, 0.06143825860427959, 0.1573261743677514, 0.06559374955083642, 0.26052037200757433, 0.17436218022235803, 28.797818286078318, 56.01221506936209, 42.9427855355399, 44.8417386327471, 35.65494510105678, 32.96371323721749, 10.655513303620474, 61.24117224557059, 65.81972939627511, 12.416602849960327, 6.814164800303323, 37.170962129320415, 57.83431761605399, 58.35219464983259, 52.27516119820731, 50.00779724121094, 49.14612334115164, 36.961984634399414, 6.249266701085227, 0.2138288981680359, 0.1743128371558019, 0.15844773847077573, 0.6482974354709897, 6.017486955438342, 34.31442567280361, 51.4648449080331, 61.24829414912632, 57.34315640585763, 56.537314755576, 55.36741876602173, 56.37656818117414, 58.5935959134783, 59.05987562452044, 54.38784783227103, 54.8384940964835, 51.539930616106304, 44.11797257832119, 41.24353061403547, 41.82442780903408, 39.698421478271484, 40.827104227883474, 41.41995232445853, 40.305614130837576, 40.00905459267752, 40.31822163718087, 38.96407331739153, 42.17170919690813, 48.27626098905291, 50.04635974339077, 52.29513726915632, 50.340657642909456, 49.77273620877947, 49.10058832168579, 45.134403705596924, 43.26413624627249, 39.30528545379639, 41.0754953793117, 39.65471730913435, 43.841746943337576, 43.793870380946565, 40.78252458572388, 39.079472473689485, 34.75318356922695, 33.93446690695626, 38.063218525477815, 44.01130035945347, 45.45059190477644, 45.25092499596732, 44.34555734906878, 47.974139417920796, 39.99613789149693, 41.81549937384469, 49.93151991707938, 45.76692601612636, 44.81156260626656, 43.81618799482073, 43.79324156897408, 42.62494713919503, 41.41749266215733, 35.651620388031006, 37.502109800066265, 36.241626671382356, 42.46224464688982, 47.42126430783953, 47.07739101137434, 47.01919289997646, 46.768689496176584, 41.52164615903582, 36.69567060470581, 37.76816674641201, 38.196571826934814, 45.709071840558735, 48.90380491529192, 47.28291177749634, 50.443706376211985, 50.04191984449114, 48.098401001521516, 43.632665225437705, 43.93218469619751, 43.94904102597918, 43.27878999710083, 43.97380787985665, 42.005584716796875, 37.95895733152117, 37.91679218837193, 38.28436231613159, 39.31809098379952, 37.404800278799875, 40.39574268886021, 42.22458846228463, 45.42627320970808, 45.70507662636893, 43.884537424360005, 48.31810998916626, 46.31256110327584, 47.34777321134295, 51.52045828955514, 45.619092668805806, 34.93453502655029, 23.725127833230154, 9.265053697994777, 7.923428637640817, 1.7916956011738097, 0.1418989071888583, 0.34962333792022293, 0.10511235506939036, 1.1707560462611062, 16.629551001957484, 46.32263946533203, 45.145510401044575, 44.18702030181885, 47.797676018306184, 48.483178343091694, 50.588444301060264, 38.68876484462193, 7.427647743906293, 13.741555707795278, 55.28160503932408, 58.411108425685335, 22.651773588997976, 10.271512423242841, 28.865929739815847, 30.868709768567765, 26.224460874285015, 21.186091048376902, 44.75801978792463, 28.81351774079459, 0.20975428181035177, 0.004119417480459171, 0.0031770858581044842, 0.027776981105229685, 0.06962910587234156, 0.023935952124052813, 0.0035833128994064672, 0.043291073625109026, 0.08745175094476768, 0.07628391949193818, 0.013388533228343087, 0.015916970990864292, 0.023192067397758365, 0.06757792843771832, 0.02157313373338963, 0.03527263192726033, 0.02795592605668519, 0.06176265262599502, 0.010246302017809024, 0.10577503272465297, 0.0486763719735401, 0.07450564884181533, 0.03980511353750314, 0.018324991688132286, 0.057368378421025615, 0.06600754734660898, 0.02303859973991556, 0.14999540416257723, 0.2065398578665086, 32.60520703451974, 66.31675488608224, 46.260334968566895, 47.144969190870015, 46.01693262372698, 24.87973952293396, 14.228574923106603, 63.96702003479004, 60.09811019897461, 21.65583096231733, 7.407329474176679, 38.7739497593471, 61.87576511928013, 61.75357409885952, 57.315189906529014, 59.36041995457241, 52.57682071413313, 41.37928451810564, 6.471510478428431, 0.0879098435065576, 0.28427718579769135, 0.3422448938446385, 0.8581149024622781, 7.308311564581735, 36.83353328704834, 54.691081115177695, 62.387096949986045, 60.188575744628906, 58.16255399159023, 58.05530507223946, 59.58914770398821, 60.94376155308315, 60.626902852739605, 58.51783275604248, 57.07366704940796, 54.47220938546317, 46.345537253788535, 42.58668688365391, 44.02587073189871, 42.646580355507986, 44.17865814481463, 44.469638279506135, 43.52486392429897, 42.444290501730784, 42.53110476902553, 41.8160274369376, 45.59591347830636, 51.24616772787911, 53.01628385271345, 53.74819319588797, 50.74865933826992, 51.29336336680821, 51.053358691079275, 46.05269152777535, 43.01970904214041, 40.69291714259556, 42.172303267887656, 40.24555390221732, 45.02843672888619, 47.62944623402187, 45.57027115140642, 43.56727225439889, 40.234026840754915, 38.71877064023699, 41.45465162822178, 49.01567786080496, 50.68171344484602, 49.66200624193464, 49.169604778289795, 52.09256253923689, 46.456562519073486, 45.811415331704275, 55.02508102144514, 49.916306836264475, 49.40565940311977, 47.09272915976388, 48.94782175336565, 47.376841000148225, 46.80411488669259, 40.931952544621055, 40.755211217062815, 40.15761750085013, 47.001541001456125, 51.06837027413504, 49.05113104411534, 48.68981776918684, 50.90041841779436, 43.93435600825718, 41.02494723456246, 40.46315063749041, 39.81589119774954, 47.74190630231585, 50.47383376530239, 48.90188026428223, 51.29861273084368, 50.52066462380545, 48.4639561516898, 44.41942364828927, 44.631513936179026, 45.82422086170742, 45.00901998792376, 46.019225529261995, 43.29972491945539, 39.34173222950527, 41.11762578146798, 40.68907478877476, 41.368869168417795, 40.592084884643555, 42.790470600128174, 45.24389341899327, 47.621115343911306, 48.729526724134175, 45.82631574358259, 49.862572942461284, 48.54669182641165, 50.645867688315256, 52.30854034423828, 48.652974946158274, 37.25762006214687, 26.639737333570206, 10.319982188088552, 9.659881608826772, 2.656475671700069, 0.3221033960580826, 0.19342498374836786, 0.16733210959604808, 2.0071851866585866, 19.341924497059413, 49.31188651493618, 48.988100460597444, 49.485171113695415, 52.3488746370588, 50.945765835898264, 54.27905641283308, 39.19380160740444, 9.074752960886274, 17.12795397213527, 52.09779453277588, 56.873527663094656, 31.16704109736851, 13.84330425943647, 22.779378993170603, 41.942960602896555, 22.31919632639204, 24.08659049442836, 55.60549879074097, 28.82974178450448, 0.26334172061511446, 0.09820506535470486, 0.04292504130197423, 0.04657448083162308, 0.07045495084353856, 0.05099987604522279, 0.05707563127257994, 0.046775805564331155, 0.04351908514010055, 0.029045424291065762, 0.03764754859730601, 0.06954337975808553, 0.10789151236947093, 0.17591806102011884, 0.11134378319340092, 0.07245869868035827, 0.13272106966802052, 0.19305045955947467, 0.15279315332216875, 0.1795420351305178, 0.16103913156049593, 0.16119467892817088, 0.14127822406589985, 0.10263802962643759, 0.16813473509890692, 0.2832222266920975, 0.19625155707555159, 0.3282307844076838, 0.2842015427138124, 49.64328779493059, 73.04158278873989, 57.31728826250349, 59.34850379398891, 54.66174234662737, 42.397202559879844, 12.920560904911586, 74.64087745121547, 69.40478447505406, 18.320881502968923, 10.529446056910924, 46.842684337071006, 68.45774500710624, 69.75366047450474, 63.297602789742605, 64.2856366293771, 58.97626795087542, 46.78420829772949, 7.882357835769653, 0.7518169635108539, 1.0016328756298338, 0.8431450085980552, 2.080747502190726, 8.777559399604797, 40.37766695022583, 56.755102566310335, 64.80733517238072, 61.71933337620327, 58.75557231903076, 59.71586200169155, 60.90154429844448, 61.67110592978341, 62.32276357923235, 59.73304489680699, 59.00755568913051, 56.87750898088728, 48.3474383354187, 46.897137369428364, 47.02775308064052, 45.52467359815325, 44.9257493019104, 46.82641165597098, 44.3645224571228, 44.8683363369533, 45.20294768469674, 44.576133319309776, 46.795770100184846, 54.01974964141846, 55.45970473970686, 56.66692297799246, 53.74335724966866, 53.12896973746163, 54.93428543635777, 49.09598166601998, 45.10778863089425, 42.15646832329886, 43.624758175441194, 41.906864711216514, 46.27653816768101, 48.13012647628784, 45.217010838644846, 43.90386036464146, 41.10904128210885, 39.675749506269185, 43.71726649148123, 51.95819827488491, 53.44425467082432, 50.73524236679077, 52.267723151615684, 54.37388890130179, 45.07962410790579, 47.06798662458147, 53.8291014943804, 54.3353020804269, 51.07025671005249, 52.26932123729161, 52.46016045979091, 51.430923802512034, 47.64506231035505, 42.563229765210835, 45.77062940597534, 42.67633949007307, 49.28429521833147, 54.05350399017334, 52.032714230673655, 53.725403104509624, 53.81969363348824, 47.088612352098735, 43.037840366363525, 43.74444784436907, 41.24801915032523, 50.18914869853428, 52.238742215292795, 49.22044127328055, 53.28300782612392, 51.86702053887503, 51.548275402614046, 45.44004453931536, 45.55545064381191, 47.179140431540354, 47.00723157610212, 47.35836574009487, 44.18647486822945, 41.84129108701433, 44.11918156487601, 43.679245948791504, 44.856604303632466, 42.63571684701102, 44.384119851248606, 47.68686614717756, 50.36318022864205, 51.69933271408081, 49.017505237034385, 52.76558937345232, 50.64453363418579, 53.26340695789882, 56.77063526426043, 49.76951571873256, 39.77460847582136, 31.166718006134033, 11.760758910860334, 11.229678562709264, 4.148124064717974, 0.9594722922359193, 0.7746823451348713, 0.7601204950894628, 3.113900120769228, 20.262854371752056, 53.780971322740825, 52.799642494746614, 53.66198342187064, 57.4546263558524, 56.80921513693673, 59.615863527570454, 44.480675492967876, 11.551921248435974, 19.014770303453716, 67.05364608764648, 63.88419055938721, 31.85020535332816, 13.06941042627607, 41.25038153784615, 47.685042245047434, 36.098584106990266, 34.28493404388428, 58.457584926060264, 47.25655378614153, 0.30311543494462967, 0.1940925536411149, 0.09149833023548126, 0.14152109889047487, 0.16107023560575076, 0.21248227757002625, 0.10964693674551589, 0.11377633123525552, 0.1456761352185692, 0.16435122383492334, 0.05848953540303877, 0.13221234482313904], [0.0461968896644456, 0.055379985831677914, 0.03518208482169679, 0.03810557330559407, 0.05551026455525841, 0.031400229183158705, 0.09717037409011807, 0.022296102617734244, 0.015781435317226818, 0.08219696541449853, 0.05362606441069927, 0.03507686439635498, 0.020137363811954856, 0.14037486325417245, 0.05061489563169224, 0.14000036620668002, 0.06588960438966751, 9.489614265305654, 56.225052288600374, 42.61783218383789, 46.56668451854161, 30.158961704799108, 40.09073066711426, 15.04661066191537, 25.472467763083323, 62.6373085294451, 20.89073702267238, 5.837888615471976, 27.903347151620046, 55.64573233468192, 53.181737831660676, 46.5236508505685, 55.631109850747244, 49.910543305533274, 43.50399848393032, 7.6242296525410245, 0.15311224120003836, 0.17244461311825685, 0.24887019715138844, 0.4542166883391993, 13.31112175328391, 36.14750984736851, 52.33549588067191, 58.53560624803816, 55.98371703284127, 52.07022408076695, 54.25184726715088, 57.82896055494036, 56.93963629858834, 58.7060455594744, 56.11110183170864, 54.44833190100533, 50.619103227342876, 44.80202272960118, 43.18662909099034, 42.707738399505615, 40.22099549429757, 40.33894116537911, 40.83186721801758, 39.62012570244925, 40.80990743637085, 38.64337573732649, 41.68519980566842, 47.06595080239432, 49.77595322472708, 52.52701950073242, 53.3684116091047, 51.70030198778425, 48.948860509055, 44.80491318021502, 42.94441488810948, 39.45909077780587, 38.468843936920166, 40.727171761649, 40.469400542122976, 41.672745159694124, 41.72196272441319, 40.91620792661394, 39.09201397214617, 35.83107498713902, 35.51692955834525, 41.019788197108674, 45.13290636880057, 45.90676546096802, 45.79795667103359, 47.7886746270316, 46.765250137874055, 38.98027304240635, 46.70638152531215, 47.84847777230399, 46.348445074898855, 48.67375700814383, 44.80604573658535, 44.81794800077166, 42.800976276397705, 40.515883990696494, 36.25710030964443, 36.26751218523298, 38.50464105606079, 39.962168148585725, 45.81049469539097, 47.63596364430019, 45.08885826383318, 45.75575678689139, 38.24343742643084, 36.61541543688093, 38.5325345993042, 38.411465712956016, 41.69188397271292, 48.337151527404785, 49.55023751940046, 49.82880817140852, 52.83219827924456, 50.061621461595806, 48.553487164633616, 48.47635868617466, 48.2223117010934, 49.00797230856759, 48.8285038130624, 49.06342240742275, 45.22668273108346, 38.973859855106895, 38.549040045057026, 39.14024141856602, 39.49858086449759, 41.18116010938372, 43.26272923605782, 43.8806985446385, 45.034168992723735, 43.44587332861764, 45.119353907448904, 45.59161949157715, 50.176888602120535, 50.40890979766846, 48.272700037275044, 42.386220932006836, 35.34586838313511, 22.780581031526836, 11.192895667893545, 8.237143278121948, 2.7442774517195563, 0.2081461131040539, 0.11119226632373673, 2.370417901447841, 25.330090488706315, 51.10296188082014, 47.76874371937343, 53.89995922361101, 51.936328819819856, 53.769402572086875, 51.9918657711574, 30.65267985207694, 7.199823694569724, 20.500996930258616, 53.3314437185015, 44.123732634953086, 15.835111345563616, 18.736996957233973, 37.15780918938773, 24.58814968381609, 29.819378920963832, 31.978392669132777, 53.17023161479405, 10.543371983936854, 0.4429220115499837, 0.031340552028268576, 0.04383517389318772, 0.0952012383245996, 0.06844717929405825, 0.06273927486368588, 0.014899304169895393, 0.06995072468583073, 0.05756433933441128, 0.03956413521830525, 0.05023887188040784, 0.03265215004129069, 0.039682749924915175, 0.014583469867440206, 0.020008267435644354, 0.03345597994380763, 0.018143717665225267, 0.03739850249673639, 0.11212000689868416, 0.03512072829263551, 0.029337838957352296, 0.07927437938217606, 0.015545342450163193, 0.031038603944970027, 0.06245189492723771, 0.03368744520204408, 0.09720031784049102, 0.051017864008567164, 0.1611083692737988, 9.885153497968401, 64.35181822095598, 50.91574961798531, 45.120608057294575, 39.5848114831107, 37.915013449532644, 12.470392329352242, 38.02246734074184, 53.12458889825003, 26.35690917287554, 8.259255051612854, 30.65262426648821, 60.97318022591727, 58.54730701446533, 51.24617120197841, 61.20249162401472, 54.035730498177664, 47.93704298564366, 8.741529515811376, 0.08719131563391004, 0.12157383853835718, 0.17070182306425913, 1.4897484949656894, 16.568669148853846, 36.988551071711946, 55.978311334337505, 61.06178365434919, 58.48322377886091, 54.61870867865426, 57.007530621119905, 59.35300622667585, 60.26667349679129, 59.03643240247454, 59.683358328683035, 57.29216357639858, 54.39007820401873, 46.069117069244385, 45.44860471997942, 44.47883769444057, 43.71881593976702, 42.82523938587734, 44.60610784803118, 41.3169834954398, 42.304319041115896, 42.24432482038225, 42.60882037026541, 49.80616399220058, 52.315068176814485, 54.510625975472585, 55.04612711497715, 53.63596241814749, 49.36526952471052, 47.065321990421836, 44.04345314843314, 41.52007239205496, 39.63789919444493, 40.25021961757115, 41.11413778577532, 43.11586863654, 44.1407869883946, 43.91251087188721, 43.05534635271345, 39.5751256942749, 40.875314303806846, 43.175546714237754, 49.248769078935894, 49.05721419198172, 51.387448923928396, 50.47473703111921, 51.075276783534456, 43.072098459516255, 53.03001349312918, 54.04857424327305, 49.30192974635533, 50.4135616166251, 48.29560129983084, 48.176530020577566, 46.17653969355992, 44.897008078438894, 40.93117782047817, 39.46982227052961, 40.57121597017561, 44.77144718170166, 50.43201950618199, 51.14346293040684, 49.0019725390843, 49.17297812870571, 42.7003733089992, 38.36059447697231, 40.24986525944301, 41.50112118039812, 43.98854153496878, 48.78222186224801, 49.52302489961897, 51.43303952898298, 51.781665393284385, 49.89272117614746, 51.026406628744944, 48.88933529172625, 50.04046767098563, 50.54039750780378, 50.16571937288557, 50.79133169991629, 46.40348523003714, 41.29313727787563, 42.263439314705984, 41.02720887320382, 42.38173586981637, 43.648830209459575, 45.946387563432964, 46.7680606842041, 47.24794149398804, 45.439370564052034, 47.495821952819824, 48.85997915267944, 51.93929917471749, 52.025484630039756, 51.27479430607387, 44.00967795508248, 37.612266540527344, 25.73963294710432, 13.251688599586487, 8.923971840313502, 4.132283474717822, 0.14961182831653527, 0.5145581832953862, 3.3550306218011037, 28.38965504510062, 53.681886536734446, 52.97744689668928, 55.23260286876133, 56.643490178244456, 56.208442619868684, 58.779258728027344, 32.01778200694493, 11.20284983089992, 26.89447566441127, 56.31001486097063, 46.12031487056187, 25.24709251948765, 15.910221372331891, 36.277823311941965, 36.15021269662039, 30.38142565318516, 35.22654002053397, 62.13109057290213, 13.682337079729352, 0.5141844462071146, 0.034259117740605555, 0.043263572600803206, 0.04669788260278957, 0.10905687590794903, 0.008717465929553976, 0.04876641696318984, 0.09360490326902696, 0.041526061549250565, 0.07776545999305588, 0.04596370431993689, 0.046459652350417206, 0.12395700280155454, 0.13684376701712608, 0.14143168154571736, 0.11462479856397424, 0.19239491330725805, 0.1296278049371072, 0.1774408564503704, 0.13198031298816204, 0.15184021874197892, 0.15839508415332862, 0.13009964461837495, 0.0998549707499998, 0.10763844594891582, 0.24382167948143824, 0.3109316426728453, 0.3400926893310887, 0.2995137439242431, 17.218398673193796, 85.17258862086705, 57.08729941504342, 60.410285813467844, 42.866042682102744, 54.92063570022583, 17.896504640579224, 37.316533837999614, 67.65524891444615, 26.367036172321864, 9.354743650981359, 36.646331446511404, 65.13013458251953, 65.66757079533168, 57.347578934260774, 66.57483182634626, 59.62983635493687, 54.48267337254116, 10.72150729383741, 0.23165584515248025, 0.7474330844623702, 0.5312530760254178, 2.2257987473692213, 20.824188913617814, 39.461463587624685, 60.769785608564106, 61.666575704302105, 59.65832396915981, 56.85041448048183, 59.00429698399135, 60.48296397072928, 61.97281060900007, 61.113554682050435, 62.95652961730957, 58.446516445704866, 56.66189595631191, 50.02758223669869, 48.319374561309814, 46.49123750414167, 45.45282575062343, 43.84437336240496, 47.64464889253889, 42.694522925785606, 44.99021816253662, 44.02345275878906, 45.63863795144217, 51.066358770642964, 54.996847016470774, 56.89538322176252, 57.37150853020804, 54.924318245479036, 52.47594329289028, 50.13770771026611, 45.36095666885376, 43.53485195977347, 41.23115587234497, 43.5033939906529, 43.683543409620015, 44.210477420261924, 45.24802412305559, 46.16231325694493, 44.28810964311872, 40.783354895455496, 42.64796999522618, 46.73175287246704, 53.22173513684954, 52.441243989127024, 52.65825360161917, 53.50133064814976, 52.89132744925362, 46.31900903156826, 51.16902535302298, 56.58894681930542, 51.077006884983604, 53.13792943954468, 51.85591384342739, 51.403638226645334, 49.10255813598633, 47.05215515409197, 43.34056643077305, 41.04312719617571, 43.67596639905657, 47.484065600803916, 51.116573401859824, 53.944827216012136, 49.949672085898264, 52.47757264545986, 44.482614040374756, 40.84710461752755, 43.623368535723, 42.56801707404, 44.77251720428467, 50.879420961652485, 52.49757998330252, 52.02686384746006, 53.82686070033482, 52.63129806518555, 50.79922137941633, 50.47055074146816, 51.70889343534197, 52.18601928438459, 52.02302844183785, 53.27977343967983, 48.460909366607666, 44.20189986910139, 43.49276672090803, 42.759377411433626, 42.67404311043875, 45.572237491607666, 48.96940285818917, 50.010298592703684, 49.17176914215088, 48.001199177333284, 51.19934729167393, 50.75140387671334, 53.53628008706229, 54.63607917513166, 53.482004233769004, 46.92083420072283, 39.117374897003174, 27.207790783473424, 15.884499141148158, 10.35775693825313, 5.498403974941798, 0.6911976763180324, 0.6487517282366753, 3.7765027029173712, 30.434165954589844, 59.83523205348423, 58.30513450077602, 61.258202280317036, 62.776335035051616, 62.527936935424805, 61.6254562650408, 36.65742424556187, 12.181297762053353, 27.599691765648977, 61.74086584363665, 51.73420572280884, 21.380487748554774, 24.325975043433054, 55.83438287462507, 35.05678163255964, 42.09062024525234, 42.56653710774013, 73.61683804648263, 24.536684376852854, 0.7332955630762237, 0.16153131372162274, 0.18405452370643616, 0.098184912864651, 0.15645120346120425, 0.10677725608859744, 0.09993389115801879, 0.28081030611480984, 0.18670610285231046, 0.20524035474019392, 0.1260842372264181, 0.1391533509429012], [0.06846666681979384, 0.07788263620542628, 0.05065637108470712, 0.057147779901112826, 0.02941183320113591, 0.0460263534582087, 0.06935986996229206, 0.027885675629866973, 0.02648390709821667, 0.05754150663103376, 0.07148470915853977, 0.026644977740943432, 0.05809228029102087, 0.09575507217752081, 0.04385073270116534, 0.04765834892168641, 0.0700436093445335, 0.6587307527661324, 40.92740842274257, 47.73454468590872, 40.73103496006557, 31.554625511169434, 39.19254398345947, 19.777552230017527, 19.517085109438213, 74.47624683380127, 47.779068742479595, 3.5040267067296162, 25.028932980128697, 53.49235357557024, 60.0504594530378, 54.92904996871948, 56.0769236428397, 53.90393706730434, 46.71896818705967, 10.387750574520656, 0.18115553712206228, 0.25772377635751453, 0.06369590745972735, 3.0226038311209, 9.194385307175772, 30.956785133906774, 56.74200521196638, 59.32764530181885, 56.31112657274519, 49.49952261788504, 52.430613245282856, 58.55829906463623, 58.57064601353237, 57.78834138597761, 57.14874233518328, 54.72492926461356, 53.88840436935425, 44.265385559626985, 40.51645026888166, 42.730101176670615, 39.94206006186349, 38.58465998513358, 40.13275337219238, 40.52466998781477, 39.775563853127615, 40.08613095964704, 42.79026562826974, 45.891635758536204, 51.67855760029384, 52.86304480688912, 53.41511045183454, 50.273378235953196, 49.86020360674177, 42.283516134534565, 39.50023453576224, 40.82482521874564, 39.93190179552351, 38.76291601998465, 40.16362769263131, 39.883250508989605, 41.37518160683768, 41.0240022795541, 38.13734538214547, 34.915886061532156, 38.415933404650005, 43.7159081186567, 45.39988742555891, 47.55236291885376, 44.868110520499094, 48.55263601030622, 40.55857024874006, 46.86380338668823, 50.78184740883963, 48.967940262385774, 50.09154387882778, 48.46440083639962, 44.81582532610212, 44.72194126674107, 43.454207692827495, 42.81814180101667, 36.81250803811209, 36.31936311721802, 37.867970670972554, 40.47669962474278, 43.84335197721209, 45.922805377415244, 44.48963866915022, 43.419237409319194, 37.39376653943743, 37.3179304259164, 36.179266589028494, 39.06214019230434, 38.78668928146362, 47.943445750645225, 50.192667961120605, 49.947948932647705, 48.99232496534075, 50.02093628474644, 50.742242676871165, 48.70774064745222, 50.21537814821516, 48.69198908124651, 50.57267883845738, 49.327148233141216, 47.44322061538696, 43.60783583777291, 37.2119391305106, 39.89313432148525, 40.22285066332136, 41.180496556418284, 41.375018324170796, 42.68277699606759, 43.785219873700825, 43.196867261614116, 43.54578495025635, 50.56566463197981, 53.05101442337036, 51.56515605109078, 50.70346130643572, 47.367658955710276, 44.12384728022984, 33.242996079581125, 22.57157400676182, 11.704390781266348, 5.110223318849291, 0.52865412405559, 0.6757315290825707, 5.788116497652871, 26.69078574861799, 49.94314772742135, 48.00383949279785, 49.38686800003052, 52.00213173457554, 48.912493637629915, 46.7779722894941, 17.869724546160015, 7.968767370496478, 35.25900895254952, 53.15816954204014, 25.74119802883693, 10.810069901602608, 27.42391450064523, 29.087653705051967, 21.229743106024607, 34.738550662994385, 34.856287888118196, 48.164617334093364, 2.5704333058425357, 0.30079840070434977, 0.038109573269529004, 0.08415931582983051, 0.02490210287006838, 0.03013097175530025, 0.051287554537079165, 0.07961279193737678, 0.09995033884687082, 0.04522752435877919, 0.043581819095249684, 0.02534998517616519, 0.015354758926800318, 0.024918536988220046, 0.08242900403482573, 0.0859713503824813, 0.015010553378877895, 0.019088119667555605, 0.024708611824150597, 0.03684195450374058, 0.03271036834589072, 0.028411446970754435, 0.08315963697220598, 0.04336037579923868, 0.011103242552573127, 0.02544344828597137, 0.06758296316755669, 0.0455213062731283, 0.10549772903323174, 0.03654023712234838, 0.8436305682573999, 45.265887941632954, 58.1870950290135, 39.48976012638637, 35.807284355163574, 44.35762289592198, 15.661732946123395, 26.362118584769114, 74.98566096169608, 41.91593905857631, 6.092638671398163, 27.083339861461095, 59.24416964394705, 65.17133740016392, 58.907536370413645, 60.85924366542271, 58.0109338760376, 49.39901692526681, 11.741911053657532, 0.05355903532888208, 0.1432606184056827, 0.340318071522883, 3.9044403178351264, 10.497549482754298, 34.21726553780692, 61.28655787876674, 62.03444807870047, 59.121256010872976, 51.37078366960798, 56.64916338239397, 59.843201637268066, 59.730626923697336, 60.25472954341343, 60.41975620814732, 57.24752140045166, 57.58645452771868, 46.29513502120972, 41.48136050360543, 44.20384883880615, 42.70036636080061, 41.79874031884329, 43.173326764787944, 43.13494144167219, 42.41967303412301, 43.696269035339355, 45.33760724748884, 47.47480712618147, 54.16654075895037, 54.52076687131609, 54.983853885105674, 53.041766371045796, 50.992808614458355, 44.7506616456168, 40.41709450313023, 39.47971303122384, 41.10817275728498, 39.2078925541469, 41.928570883614675, 41.989190442221506, 44.71427392959595, 43.12658623286656, 41.06309631892613, 40.0978456224714, 41.535990715026855, 46.39785371507917, 49.15683051518032, 52.926968233925955, 49.277524198804585, 51.72524949482509, 48.272880690438406, 49.219624859946116, 54.224266392844065, 50.78806257247925, 53.2112329346793, 50.50732408251081, 49.04149736676897, 48.141062940870015, 46.83329732077462, 47.19034787586757, 40.400557790483745, 38.7244473184858, 41.68189593723842, 43.535286222185405, 46.06548663548061, 48.692986147744314, 47.22582190377371, 46.81800433567592, 41.72562095097133, 39.53873103005545, 39.79033572333199, 40.43529530933925, 41.44159248897007, 49.067257813044954, 51.34829582486834, 49.94470064980643, 49.20581878934588, 52.52584525517055, 51.72412736075265, 50.259141377040315, 50.949382373264854, 50.49200677871704, 51.48243079866682, 52.354867458343506, 50.693243980407715, 44.803454058510916, 39.77531719207764, 42.33891412190029, 43.84402595247541, 44.62967266355242, 44.69070563997541, 45.168491567884175, 46.15229395457676, 45.77433279582432, 45.46550621305193, 51.407987798963276, 54.88398742675781, 53.35895511082241, 52.64871025085449, 50.188738754817415, 45.518246514456614, 35.61883183888027, 24.83250219481332, 13.957345911434718, 6.380058288574219, 0.8004929487194333, 0.4157935843936035, 6.355285789285388, 30.843810898917063, 54.23658902304513, 52.65775680541992, 54.2678142275129, 54.936897959027974, 53.151065008980886, 47.7633831841605, 19.220242432185582, 13.29091031210763, 34.016004017421174, 56.8932466506958, 27.912855761391775, 16.051010983330862, 21.205599852970668, 37.07477821622576, 26.88082766532898, 34.94671174458095, 39.89895691190447, 56.60330179759434, 4.35966066803251, 0.26048747662987026, 0.021562575728499463, 0.05072138491751892, 0.01911314234270581, 0.0069533592738610294, 0.014808751975319214, 0.09656624722161464, 0.07078868829246078, 0.02487919383150126, 0.008724677908633436, 0.028025170555338264, 0.032334429411483664, 0.1321103610098362, 0.22075258807412215, 0.16422064655593463, 0.11589171843869345, 0.10370763151773385, 0.09439997667712824, 0.1805034921105419, 0.09610900282859802, 0.11969866630222116, 0.166904320408191, 0.2249430710715907, 0.12219385669699737, 0.20328051490443094, 0.22244414873421192, 0.10746560950896569, 0.17761842906475067, 0.14925086125731468, 1.5201417612177985, 68.49951062883649, 66.68499551500592, 56.99536779948643, 43.04297161102295, 55.127695492335725, 26.10406075205122, 25.343920878001622, 84.92899172646659, 53.766136918749126, 6.365465334483555, 32.76582506724766, 64.3486498423985, 70.75872434888566, 65.79103333609444, 66.56249877384731, 65.5168296269008, 53.14097275052752, 13.352512172290258, 0.3438183622700827, 1.1126133033207484, 0.8641117406742913, 4.985586532524653, 12.458410160882131, 36.196049962724956, 62.61426135471889, 62.34950024741036, 61.383158683776855, 53.15430634362357, 59.08745302472796, 63.2358124596732, 61.384430204119, 63.889172417776926, 61.62608855111258, 59.008465903145925, 60.34547996520996, 47.50458015714373, 43.6620317867824, 47.59112344469343, 45.93461384092058, 42.30340882710048, 44.87201540810721, 45.4624559538705, 44.17877973828997, 44.68867676598685, 47.49675301143101, 48.59827525275094, 57.14064768382481, 56.67567423411778, 58.26615163258144, 54.34789221627371, 52.93857172557286, 46.245302540915354, 41.99777494158064, 42.45807572773525, 42.56602988924299, 40.31162084851946, 43.64199318204607, 43.0037316594805, 45.72488246645246, 44.82831471306937, 43.745437962668284, 39.89758811678205, 44.74122599193028, 49.81979635783604, 51.14188568932669, 54.58812270845686, 51.34038530077253, 53.05301897866385, 49.75483070101057, 52.45624514988491, 53.04895428248814, 53.5779310635158, 53.74114424841744, 53.058049474443706, 49.44509390422276, 52.16364261082241, 49.46010896137783, 50.01372752870832, 42.103411878858296, 40.778828144073486, 44.38422754832676, 46.3776935168675, 49.61005456107003, 51.123691831316265, 49.882580280303955, 48.23039245605469, 45.4389328275408, 43.480499676295686, 41.0148480279105, 42.82012203761509, 43.849438599177766, 52.114588328770225, 53.000021593911306, 53.01506791796003, 51.03040531703404, 52.22282041822161, 53.53283378056118, 50.56919084276472, 52.18527582713536, 52.42648948941912, 53.46657575879778, 52.00034604753767, 51.98320484161377, 47.6168144089835, 41.15275239944458, 42.9012804712568, 45.25765780040196, 46.823819977896555, 46.90108742032732, 47.485583782196045, 50.407989161355154, 48.73783329554966, 47.1690342766898, 54.95877088819231, 58.921377182006836, 55.00948231560843, 56.41505077907017, 55.07326330457415, 48.01184729167393, 37.724163804735454, 27.052569764001028, 15.274671384266444, 8.09271628516061, 1.4071248599461146, 1.2454637289047241, 7.63915090901511, 33.7971705027989, 60.28348813738142, 57.87578099114554, 59.80288124084473, 60.60781615121024, 56.545287813459126, 55.00457688740322, 22.785295384270803, 12.705537608691625, 40.973030294690815, 60.8124475479126, 32.443512031010215, 14.420254009110586, 37.26675346919468, 44.924415247780935, 30.02669927052089, 45.662748200552805, 43.82714877809797, 70.1634304864066, 9.8787750516619, 0.47916270260299954, 0.12477914297154971, 0.2113641332834959, 0.14933904366833822, 0.14421064885599272, 0.1931406097220523, 0.12657073326408863, 0.20053352016423429, 0.11613652030272142, 0.1527560238859483, 0.13153851883752005, 0.09849224851599761], [0.061797027210039754, 0.15404340837682995, 0.05210080589833004, 0.02811531562890325, 0.06206481784049954, 0.04526072507724166, 0.09471164816724402, 0.056614654936960766, 0.024710676266944835, 0.039496346177267175, 0.05063581147364207, 0.031910718219088655, 0.03740011401740568, 0.07042930221983365, 0.033009439440710206, 0.02846508686031614, 0.13697315007448196, 0.029228638924126114, 13.614857912063599, 49.09844132832119, 34.524952616010395, 30.4996839932033, 31.99201113837106, 31.592600890568324, 13.24172922543117, 29.607875755855016, 58.40519550868443, 14.282714418002538, 16.140592370714458, 53.177242347172324, 52.76484939030239, 53.63811983380999, 56.07159090042114, 53.642490250723704, 51.629756927490234, 13.881677423204694, 0.0901449853554368, 0.47692825964518953, 0.19719241373240948, 3.146704737629209, 12.841800468308584, 40.42014823641096, 58.50399889264788, 60.918692452566965, 54.3625876562936, 48.00753246034895, 54.635808195386616, 60.69551631382534, 53.83749144417899, 57.333439350128174, 59.61343860626221, 53.90800871167864, 50.199168000902446, 43.22449329921177, 41.848958424159456, 41.835854121616904, 42.57022312709263, 45.54211357661656, 47.20652328218733, 47.05573000226702, 44.623169149671284, 45.074722153799875, 44.910240922655376, 50.74921866825649, 50.29871136801583, 51.53638703482491, 54.5064640045166, 50.284137521471294, 49.45450176511492, 45.8585901260376, 39.74019404820034, 40.95372819900513, 38.499978814806255, 38.16464832850865, 39.91053261075701, 39.12572315761021, 39.92125020708357, 38.09865433829171, 38.66232000078474, 36.27322013037545, 42.783192362104145, 44.86656107221331, 46.42701530456543, 47.8608455657959, 51.35235357284546, 45.61740773064749, 45.22921187537057, 53.574627195085796, 47.69548886162894, 50.34692144393921, 48.39656557355608, 48.48728125435965, 45.27042164121355, 44.55877324513027, 43.063555649348665, 42.41867944172451, 37.37207426343645, 37.62812580381121, 36.312647683279856, 39.63525193078177, 43.324095726013184, 45.2589327948434, 42.360519545418875, 39.564390727451865, 37.72117607934134, 38.302160126822336, 37.572957106998985, 38.83149821417672, 37.547749042510986, 44.96738985606602, 48.66965062277657, 51.50809049606323, 49.47750725064959, 49.24106352669852, 51.09757007871355, 49.855218274252756, 50.15267065593174, 47.14437511989048, 44.10398585455758, 49.94614934921265, 53.14591986792428, 43.56001833506993, 39.6335391998291, 41.546579769679475, 44.60357175554548, 46.693589891706196, 44.755869320460725, 42.92209380013602, 40.392633369990754, 41.42693873814174, 42.75445113863264, 43.575922761644634, 50.87993860244751, 52.132083892822266, 50.592898096357075, 50.85318456377302, 50.175293990543906, 45.626989296504426, 33.075871058872764, 19.125064270836965, 7.407193984304156, 1.219200081058911, 0.2662712548460279, 7.662727015359061, 30.702286515917095, 50.92973634174892, 48.21563100814819, 50.25916916983468, 49.98896414893014, 53.94638361249651, 30.9762852532523, 8.239727139472961, 26.854613849094935, 55.54181160245623, 51.19396243776594, 23.271464313779557, 15.176477704729352, 29.779055050441197, 26.74330370766776, 40.78356681551252, 39.930081367492676, 42.56549835205078, 37.07371514184134, 0.33960997951882227, 0.10204938014170953, 0.04740482448999371, 0.04875964857637882, 0.04697869432025722, 0.036805669843618355, 0.032927513122558594, 0.019324923300051262, 0.056220460017876964, 0.0519561897298055, 0.06290780939161777, 0.012198363297751971, 0.06677442083933524, 0.012939623789861798, 0.01195792865473777, 0.052980326382177215, 0.03496755240485072, 0.01495983118989638, 0.010741898058248418, 0.06225695860173021, 0.06552383330251489, 0.04076900306556906, 0.11026601852583033, 0.09594602550246886, 0.04503852521468486, 0.037563291511365345, 0.041127591859549284, 0.04185323756454246, 0.09277810156345367, 0.10112989055258886, 0.16982397516923292, 15.501714195523943, 60.98945985521589, 38.7065418107169, 28.59454526220049, 42.201089654650005, 26.952755417142594, 16.95839360782078, 41.12595319747925, 49.453838212149485, 16.565287113189697, 19.74511456489563, 59.199082783290315, 58.29526111057827, 58.8114914212908, 62.001576151166645, 58.97389166695731, 56.06382976259504, 15.54116085597447, 0.02742683667955654, 0.0310458981964205, 0.24814104342034884, 4.040956786700657, 14.617309263774327, 44.41312163216727, 62.55877998897007, 64.99317864009312, 56.48298331669399, 50.95433643886021, 57.46659810202462, 62.335603850228445, 57.89790405545916, 59.85670893532889, 62.11146886008126, 57.21076542990548, 52.79929855891636, 46.79694781984602, 44.899710927690776, 43.81865460532052, 43.26756170817784, 46.580824102674214, 50.72244725908552, 47.04976149967739, 48.272297041756765, 45.055736201150076, 47.23435429164341, 50.738435064043315, 51.67394052233015, 52.82603522709438, 55.37261254446847, 51.900114808763774, 52.242042609623496, 47.59611572538103, 39.64590004512242, 40.71832323074341, 39.68725919723511, 37.94507483073643, 42.01733412061419, 41.21374716077532, 42.48161275046212, 41.887906551361084, 41.972980294908794, 40.12610742024013, 43.568112986428396, 47.62904323850359, 49.49700042179653, 51.53030388695853, 53.67597014563424, 51.23536327907017, 47.52888148171561, 56.996496881757466, 49.89509398596627, 53.79440219061715, 52.44978332519531, 49.22840738296509, 48.81899172919137, 47.43418795721871, 46.564996106284006, 46.156497614724294, 40.42485564095633, 41.55395875658308, 41.247324330466135, 41.71568502698626, 45.55789988381522, 46.863153730119976, 46.80697059631348, 43.90904024669102, 40.52544123785836, 40.95088291168213, 40.33325753893171, 40.81322520119803, 39.65993193217686, 47.86405215944563, 50.234711510794504, 51.29178612572806, 51.07826450892857, 49.364734513419016, 52.74064186641148, 51.68291412081037, 50.39387389591762, 47.580152239118306, 43.812418597085134, 51.01413263593401, 54.553406034197124, 46.013764245169504, 42.0967937197004, 43.63879353659493, 46.40227624348232, 48.81955105917794, 49.05905199050903, 46.14177090781075, 44.264642102377756, 43.70759112494332, 43.68369974408831, 46.05128104346139, 52.618871212005615, 53.3023863519941, 52.89929355893816, 52.03208541870117, 53.39087513514927, 47.2369772366115, 36.245639256068635, 19.517607961382183, 8.001753074782235, 1.509638256260327, 0.08621484267392329, 8.41387939453125, 32.99057149887085, 56.05423082624163, 51.886944498334614, 55.5618953704834, 53.31708526611328, 60.27963188716343, 32.02053001948765, 12.153764656611852, 31.255467346736364, 51.10342046192714, 49.23227058138166, 25.912259204047068, 17.348251819610596, 24.794714416776383, 35.47658831732613, 38.132971491132466, 44.479362283434185, 49.029080935886924, 42.92219802311489, 0.6571522088987487, 0.08641441339360816, 0.07977008314004966, 0.015920458660860146, 0.08609525766223669, 0.038890631536820104, 0.046102125463741164, 0.02146447992085346, 0.04466190774525915, 0.02657768063779388, 0.006853397494913744, 0.025883580025817667, 0.03894167094092284, 0.09427548585725681, 0.2984059133699962, 0.177421667480043, 0.10511352214962244, 0.1445541097117322, 0.11905222598995481, 0.18399160993950708, 0.1062400463436331, 0.12884993239172868, 0.2381897574024541, 0.12215626585696425, 0.09777112185422863, 0.123675831460527, 0.21142821413065704, 0.34300059186560766, 0.17344501800835133, 0.3095252567103931, 0.2837246411613056, 27.264588832855225, 76.34803594861711, 49.00405699866158, 43.12476927893502, 45.87230239595686, 42.000978061131065, 16.568677834102086, 40.158274105616975, 64.4403382710048, 18.889546394348145, 23.458190202713013, 65.09560203552246, 60.108601978846956, 65.80627073560441, 66.42327771868024, 63.58527210780552, 61.19582135336739, 18.758753504071915, 0.5327521498714174, 1.1803295782634189, 0.6789199379937989, 5.874101758003235, 17.1106755392892, 46.32384845188686, 63.358246667044504, 67.47624247414726, 59.55278778076172, 53.24863856179373, 58.97220325469971, 64.18834795270647, 58.38504573277065, 62.537198884146555, 64.2734842300415, 60.347960472106934, 54.28296824863979, 49.42793532780239, 46.802680083683555, 46.65601750782558, 45.969806466783794, 48.658453600747244, 51.54413775035313, 50.53276491165161, 50.67643281391689, 48.81530223573957, 49.84175613948277, 55.21662201200213, 55.066064970833914, 54.895076751708984, 58.28241736548287, 53.47218642915998, 54.37956210545131, 50.15847587585449, 44.69774416514805, 45.52067838396345, 41.67208160672869, 40.368641240256174, 43.69987515040806, 42.0944903918675, 44.59293406350272, 44.08470112936837, 43.69880860192435, 41.70937953676496, 48.708310399736675, 51.032760756356375, 51.90406485966274, 53.34753227233887, 56.94295753751482, 51.67604235240391, 52.1259104183742, 55.70465305873326, 52.43596683229719, 55.215402603149414, 52.89156716210501, 52.40819140842983, 51.316969871520996, 50.46225111825125, 49.718637534550254, 49.37736633845738, 43.591445037296836, 43.5130797794887, 42.20648145675659, 44.61045047215053, 48.873357909066335, 49.914059094020296, 47.6221957887922, 45.14271027701241, 43.091501304081504, 42.998624733516145, 41.79648215430123, 42.260892799922395, 40.99315922600882, 49.636138098580496, 50.249358313424246, 54.00277171816145, 52.76049634388515, 49.41946199962071, 53.8427095413208, 51.93681171962193, 52.20928185326712, 49.36476578031267, 44.79505716051374, 50.966353348323274, 57.76399837221418, 48.09423555646624, 44.50238513946533, 46.880937644413535, 48.40526124409267, 50.98513085501534, 50.52162347521101, 49.45224360057286, 47.14260680334908, 45.99651534216744, 46.2564891406468, 46.14157288415091, 55.73662519454956, 56.02438483919416, 55.15486642292568, 55.929020813533235, 55.79575089045933, 47.65331677028111, 38.72042431150164, 19.983099051884242, 9.010167717933655, 2.0673778653144836, 0.6232413628271648, 11.15154606955392, 39.06405789511544, 61.297869546072825, 57.1507225717817, 60.35815347943987, 60.28516265324184, 62.61859703063965, 36.487613746098106, 12.470327189990453, 33.73103754861014, 64.7959818158831, 60.18046719687325, 29.28712953839983, 19.626376799174718, 41.209446225847515, 40.866319860730854, 50.577271597726, 53.31661278860909, 55.38484137398856, 61.06018556867327, 1.609808155468532, 0.22952516376972198, 0.14697155356407166, 0.12895336826997145, 0.17856666818261147, 0.21833886259368487, 0.23472380052719796, 0.16397227559770855, 0.12220980226993561, 0.11656812285738331, 0.13285109054829392, 0.10697809566876718, 0.11319576988794974], [0.02227568380268557, 0.037055757495441606, 0.06774298208100454, 0.013858785137667187, 0.027857480803504586, 0.016443152845438038, 0.02303436568139919, 0.03751337169004338, 0.030451701687914983, 0.046989784975137026, 0.035287081330482445, 0.02527754138489919, 0.050939293046082766, 0.03131105611100793, 0.04217045607843569, 0.03291360654735139, 0.032933016041559834, 0.04881020622061832, 2.5013927476746693, 43.016419070107595, 42.25554963520595, 31.31601742335728, 34.23243692943028, 32.59500013078962, 19.552406276975358, 19.7970940385546, 78.30469036102295, 51.52689232145037, 8.256521803992134, 30.62704794747489, 60.61896800994873, 56.31990909576416, 58.853812898908345, 55.34129353931972, 50.197427477155415, 15.938863583973475, 0.7132578268647194, 0.20584587939083576, 0.4021061488560268, 2.8690429968493323, 15.878315244402204, 50.91056973593575, 62.03756781986782, 60.37894248962402, 53.957823821476524, 49.618590423039024, 55.03752524512154, 61.00576727730887, 57.04180955886841, 58.91119112287249, 60.09540734972273, 52.92123597008841, 48.657786573682515, 43.28086403438023, 43.88931083679199, 47.589205741882324, 51.451813561575754, 52.095466886247905, 55.454194818224224, 53.778226784297395, 53.098696436200825, 50.60865661076137, 51.38627815246582, 49.21699496677944, 52.105277742658345, 54.33080659593855, 52.02644000734602, 52.598040512629915, 50.91581909997122, 45.732806886945454, 40.533000877925325, 42.276894501277376, 40.06212840761457, 38.975371088300435, 38.89248602730887, 40.03538826533726, 39.16970525469099, 37.343058586120605, 37.741426604134695, 38.586751392909456, 43.33819709505354, 46.188587869916645, 46.22892911093575, 48.516672134399414, 48.40592132295881, 42.05199868338448, 54.52052368436541, 50.307549476623535, 48.89181579862322, 50.73072256360735, 48.81426000595093, 48.98176717758179, 43.24336460658482, 44.826574189322336, 45.37240035193307, 41.877661432538716, 39.75077615465437, 37.112941196986604, 36.29623603820801, 38.62144027437483, 40.26438004629952, 42.861533301217214, 40.79782451902117, 38.67865868977138, 37.5907757622855, 36.24588591711861, 37.00121763774327, 36.31126151766096, 38.323432036808555, 40.330103056771414, 48.16993965421404, 50.418091842106406, 50.62115294592721, 51.19027641841343, 50.08247300556728, 49.93207924706595, 51.029262338365825, 50.588419982365195, 48.268447739737375, 49.84401430402483, 50.386998653411865, 45.18616083690098, 41.212475640433176, 45.8708085332598, 47.09441409792219, 48.63490268162319, 49.986921378544395, 44.32614408220564, 41.77949728284563, 41.51992647988455, 43.551888942718506, 46.227098260607036, 48.55937576293945, 50.744841303144185, 51.41869497299194, 53.96619987487793, 55.01629849842617, 51.236756392887656, 43.08677305494036, 28.1575174672263, 13.114830800465175, 1.8827312248093742, 0.259575824120215, 4.918987614767892, 30.853423731667654, 52.86682115282331, 48.65484053747994, 50.4655966758728, 51.72403703417097, 48.93212577274868, 32.70886720929827, 22.283779621124268, 62.66598374502999, 70.72583157675606, 43.43948098591396, 13.54936592919486, 22.781437397003174, 38.82514408656529, 22.318324327468872, 38.57419599805559, 38.147274357931956, 48.356894833701, 13.930781211171832, 0.23853730303900583, 0.07674305699765682, 0.02751006239226886, 0.14423527967716965, 0.03714786523154803, 0.06651338841766119, 0.008056807764140623, 0.02305709999719901, 0.05477186239191464, 0.1164134575852326, 0.06667204347572156, 0.07876768335700035, 0.0008065954098128714, 0.03562559227326086, 0.018558828426258903, 0.023804845587749566, 0.01779389045467334, 0.04075555789417454, 0.01783279934898019, 0.03871841595641204, 0.17391326145402022, 0.03562638276655759, 0.04136015634451594, 0.016671959942738925, 0.03728971976254668, 0.034584108873137405, 0.044529396641467295, 0.05803195174251284, 0.036364476196467876, 0.048727608152798245, 0.017583658253507953, 3.511851463999067, 55.24022156851632, 51.106293542044504, 30.026619366237096, 37.47762434823172, 33.90501696722848, 15.006517818995885, 29.119450398853846, 67.44025080544608, 50.86259937286377, 11.861727527209691, 35.71753099986485, 65.29095758710588, 60.01038224356515, 62.755684988839285, 60.81462928227016, 54.15974889482771, 19.102536473955425, 1.2309042130197798, 0.215377220085689, 1.0413571383271898, 3.4355908589703694, 17.17572283744812, 53.59388760157994, 65.28202220371791, 64.05049569266183, 56.025979450770784, 53.08501195907593, 56.07188967296055, 62.85867813655308, 59.992184911455425, 61.65073381151472, 60.593551499503, 57.716305937085835, 53.202867303575786, 44.95709957395281, 43.93924406596592, 49.26882158006941, 53.10949393681118, 55.69302177429199, 57.07514354160854, 56.11191477094378, 54.60226576668875, 52.999882629939485, 52.12025111062186, 50.51838908876692, 54.370480809892925, 55.30900526046753, 53.728561060769216, 54.9372557912554, 52.496586390904014, 47.60886914389474, 42.25764799118042, 43.26936476571219, 40.53050994873047, 39.94455099105835, 40.08237198420933, 41.91594253267561, 40.56834289005825, 39.780580452510286, 40.56758901051113, 41.68481765474592, 45.10590219497681, 50.04547037397112, 50.679153033665244, 51.87436825888497, 52.91479498999459, 47.77449335370745, 54.366784368242534, 54.56765678950718, 50.296428884778706, 54.611777850559776, 52.62336669649397, 51.472769328526084, 48.02503497259957, 47.976143973214285, 48.64002002988543, 44.85129240580967, 42.439892292022705, 41.072167192186626, 40.91202163696289, 41.36475583485195, 43.593991552080425, 45.67819404602051, 44.42626762390137, 41.254817962646484, 39.05565752301897, 39.896747384752544, 40.71197257723127, 38.944611413138254, 40.39425924846104, 42.721801553453716, 50.3620719909668, 52.95138072967529, 51.85556990759713, 51.47601761136736, 52.199432781764436, 51.224048137664795, 51.46289593832833, 50.9548853465489, 48.2749616759164, 49.994870117732454, 50.455608640398296, 46.67286341530936, 41.439827646527974, 49.0268679346357, 50.057640143803184, 51.02462441580636, 50.77397509983608, 46.93804488863264, 43.801801749638145, 43.3579021862575, 44.48576157433646, 47.50578914369856, 49.622272968292236, 52.26635088239397, 51.97507197516305, 55.84073005403791, 56.516987800598145, 52.18859706606184, 45.96131576810564, 28.02023148536682, 14.256574426378522, 2.688885761158807, 0.29287973418831825, 6.136393649237497, 33.48293127332415, 57.737178325653076, 50.33708279473441, 56.04835612433297, 55.35550260543823, 54.02439103807722, 37.8214351109096, 24.00086883136204, 51.59359850202288, 72.87189388275146, 40.346695355006624, 21.26995233127049, 17.695453303200857, 35.959647927965435, 30.825255734579905, 34.18322631290981, 44.30255842208862, 56.83303008760725, 16.941083908081055, 0.29437869946871487, 0.1131779176316091, 0.1311447106833969, 0.08206378256103822, 0.03214419872633048, 0.01862294489650854, 0.027206623228266835, 0.01902788781028773, 0.04143506661057472, 0.042616976225482564, 0.031605336748595746, 0.06325365869062287, 0.029893789839531695, 0.16805031177188667, 0.08510732424578496, 0.2917562159044402, 0.1159019371760743, 0.15338841852332863, 0.11562136294586317, 0.13542815297842026, 0.32641179487109184, 0.09495436014341456, 0.12496664933860302, 0.08935420028865337, 0.12048972956836224, 0.13427085722131388, 0.14008826363299573, 0.19935301850949014, 0.09066736911024366, 0.1992046364716121, 0.1397316391978945, 6.238214288439069, 75.69688551766532, 56.86590896333967, 49.34260450090681, 44.10193613597325, 47.35406827926636, 22.886061634336198, 26.203341824667795, 84.88805988856724, 60.160275731767925, 13.143386159624372, 40.903749806540354, 72.97797897883824, 64.88673918587821, 67.90725312914167, 65.19003500257219, 61.258876255580354, 21.134823765073502, 1.560704258935792, 0.43581774990473476, 1.5869331657886505, 4.73544009242739, 19.59685042926243, 56.406195299965994, 66.82434858594621, 66.38785580226353, 58.28203174046108, 54.55765833173479, 59.57768317631313, 65.65188871111188, 61.119015966142925, 63.63395813533238, 64.01915236881801, 59.65612833840506, 55.83473028455462, 48.0177880014692, 46.76446846553257, 53.67497655323574, 56.174966199057444, 57.70378180912563, 58.11301333563668, 58.10426555361067, 56.67316940852574, 56.5750469480242, 55.04264259338379, 53.17130511147635, 56.89899281093052, 57.614876134055, 54.87417309624808, 57.02724266052246, 53.43874822344099, 50.76621743610927, 45.357968943459646, 46.60448966707502, 42.172421387263704, 42.65577629634312, 41.731057916368755, 43.45232473100935, 42.92212854112898, 42.178271770477295, 42.143773964473176, 44.122283935546875, 48.262538296835764, 53.75328969955444, 53.06046049935477, 55.16680690220424, 52.98229326520647, 51.687760489327566, 56.079310349055696, 52.70931591306414, 54.17227649688721, 55.21520457948957, 55.26802478517805, 52.155930110386436, 48.87104068483625, 49.95524106706892, 52.30108492715018, 47.68329129900251, 45.15203128542219, 43.2345403943743, 43.01676300593785, 43.78747803824288, 46.7251729284014, 48.99037946973528, 44.5446788242885, 43.89461578641619, 42.23982238769531, 40.999697480882915, 42.17367206301008, 40.32384967803955, 43.972157682691304, 44.02374805722918, 52.23319755281721, 54.790544578007285, 51.85523986816406, 52.41368395941598, 53.544409479413716, 53.96688774653843, 52.39803661618914, 52.86364582606724, 49.94802188873291, 51.243291173662456, 53.347025053841726, 46.74781015941075, 43.694733483450754, 50.472374643598286, 51.94304077965872, 54.286650793892996, 52.769768714904785, 49.488884925842285, 47.40702050072806, 45.70315544945853, 47.34063046319144, 49.40389803477696, 52.96262638909476, 55.72799205780029, 55.159056186676025, 58.2043057169233, 60.44854259490967, 54.75961814607893, 48.7796162877764, 28.891202075140818, 15.701563494546072, 3.581663489341736, 1.0853021059717451, 8.612973945481436, 40.539914335523335, 61.97618743351528, 56.278470039367676, 58.47303771972656, 60.345834323338096, 57.39927353177752, 41.69064719336373, 26.599512474877493, 67.29764597756522, 79.10552583421979, 51.922050271715435, 18.07851791381836, 29.75019223349435, 57.41367367335728, 33.79412719181606, 48.604087420872276, 50.0268109866551, 65.42295946393693, 27.38660614831107, 0.35542386238064083, 0.28468835087759153, 0.20166712147848948, 0.23318914430482046, 0.0614332306597914, 0.25193269710455624, 0.10429319366812706, 0.23486843705177307, 0.09677157870360784, 0.16306484357586928, 0.09411790288452591, 0.15940094446497305, 0.08244185548807893], [0.05129221607265728, 0.03385164049853172, 0.011033068460944508, 0.05281335248478821, 0.016617836596976434, 0.044154424619461806, 0.0346459098426359, 0.050305086720202646, 0.056552392563649585, 0.03596461211730327, 0.013243210535230381, 0.0060067448232855114, 0.009924488125501998, 0.010682268400809594, 0.06709961553237268, 0.05690361925267747, 0.05699913323457752, 0.10807015706918069, 0.15225792489945889, 26.07727197238377, 49.22044127328055, 35.513361658368794, 54.243818623679026, 56.69160645348685, 26.794482401439122, 20.205759286880493, 63.51583181108747, 81.66820212772915, 32.20101295198713, 12.417984672955104, 37.53072943006243, 61.1739901133946, 53.33654369626726, 57.78793839045933, 52.65362957545689, 28.320622955049785, 3.5019554921558926, 0.4654407703450748, 0.20688261304582867, 1.969041530575071, 28.517390727996826, 57.503795283181326, 63.709519795009065, 63.18714727674212, 56.50313656670706, 45.71937949316842, 52.029695238385884, 61.29023347582136, 62.42366531917027, 58.08781916754586, 57.268421581813264, 54.26673378263201, 48.831682613917756, 44.245756898607524, 48.22956562042236, 51.397902488708496, 53.835879462105886, 55.2784366607666, 55.77948515755789, 55.83927093233381, 55.31450475965227, 53.67013018471854, 51.359166281563894, 54.139467103140696, 52.785700934273855, 48.671936580113, 53.60473026548113, 52.224369866507395, 50.475862639290945, 46.212298597608296, 39.51607642854963, 41.191363539014546, 38.25862966264997, 39.86926031112671, 38.310928753444124, 38.23327568599156, 36.8979708807809, 39.26012911115374, 37.00022404534476, 39.99651656832014, 44.72501584461757, 48.08454629353115, 47.71218885694231, 50.1467091015407, 44.503441265651155, 53.84249414716448, 56.144036293029785, 46.726069246019634, 49.47322368621826, 48.77468306677682, 50.61944716317313, 47.55828625815255, 46.06888777869088, 44.69836255482265, 45.80098955971854, 44.220917088644846, 39.3300974709647, 37.84780352456229, 36.50318118504116, 37.93202958788191, 39.52820450919015, 40.09014007023403, 41.369623047964915, 38.24038369315011, 37.55981458936419, 37.40863568442208, 37.41239813395909, 39.3863639831543, 38.65494448798043, 39.34091581617083, 42.26413066046578, 48.046862738473074, 50.623268672398154, 49.32141249520438, 50.639503138405935, 52.7506959097726, 51.41786813735962, 50.265592779432026, 51.37909024102347, 51.429176330566406, 49.41102341243199, 46.33266224179949, 46.276138646262034, 45.06074932643345, 46.98853049959455, 54.40855693817139, 47.8405498777117, 46.74909905024937, 43.35393476486206, 42.266030992780415, 41.601890904562815, 45.46839666366577, 46.562473910195486, 47.50307934624808, 50.56814513887678, 51.62051929746355, 54.10528891427176, 55.90935741152082, 48.97358219964163, 35.31807906287057, 16.16159851210458, 2.9302646602903093, 0.6555557517068726, 6.786709427833557, 36.722007751464844, 53.57909836087908, 50.6129401751927, 46.18790694645473, 42.65005445480347, 51.06960357938494, 32.31545673097883, 37.26936599186489, 50.66721255438668, 44.519950185503276, 27.218855789729528, 7.5468631982803345, 37.18598760877337, 33.65094566345215, 21.439215660095215, 39.83474860872541, 41.4813882963998, 47.70440687452044, 3.0206683235509053, 0.11743088013359479, 0.02961796535445111, 0.04321622442720192, 0.0314897924129452, 0.027185888894434487, 0.013031402436484183, 0.06353333725460938, 0.04638178367167711, 0.03944478090852499, 0.03224458119698933, 0.017402391015951122, 0.04886963910290173, 0.024420526211283038, 0.05803125285144363, 0.01971166281561766, 0.014479579370734947, 0.02489134978636035, 0.013341982333388711, 0.03547943922291909, 0.07006456929125957, 0.050488270819187164, 0.052189107052981853, 0.016233887556674223, 0.04967876497123923, 0.015185893613046833, 0.041758693887719085, 0.03914157414276685, 0.04336848429271153, 0.03879658658323543, 0.028437156662611023, 0.028978761618158648, 0.1160221735813788, 31.159015927995952, 64.44519506181989, 34.663312094552175, 45.29301370893206, 60.57300567626953, 19.05032249859401, 24.130918264389038, 65.38942050933838, 74.48250716073173, 37.738689013889854, 18.009741170065745, 40.5725291797093, 65.3220021384103, 56.82324702399117, 63.63396508353097, 56.725072452000205, 31.2902569770813, 4.385762010301862, 0.37242990412882393, 0.12923846154340676, 2.261416516133717, 29.64380489076887, 59.71522971561977, 66.32179233006069, 65.84038639068604, 57.652059418814524, 49.11159079415457, 53.9035827091762, 63.4564733505249, 61.999714033944265, 60.52711977277483, 60.16201972961426, 55.6474346433367, 51.67071655818394, 45.057956150599885, 50.19672570909773, 54.3649708884103, 55.588913440704346, 58.87510217939104, 58.280534403664724, 56.53177356719971, 58.80184037344796, 55.2734409059797, 53.84911230632237, 54.848669733319966, 55.59397867747715, 50.091710635593955, 53.817657811301096, 53.92015763691494, 51.6498441696167, 48.46227816173008, 41.51563944135393, 42.97984027862549, 40.092193262917654, 40.31370530809675, 42.28307492392403, 40.40700919287545, 40.62718718392508, 41.93096801212856, 40.089330605098176, 42.96971675327846, 48.862167835235596, 50.03469719205584, 51.839832237788606, 54.363647256578716, 48.73010342461722, 51.58908217293875, 60.29089491707938, 50.90628964560372, 52.721138272966655, 53.549047401973176, 53.58993060248238, 49.93645313807896, 48.753904478890554, 48.90674747739519, 49.1373998778207, 46.17602552686419, 40.80058990206037, 40.8883387020656, 40.344614369528635, 40.95987735475813, 42.71042735236031, 43.399754660470144, 44.09433133261544, 41.918631485530305, 40.910232475825715, 38.51061650684902, 38.81150129863194, 39.22782693590437, 39.953368255070274, 41.66749232155936, 44.83969586236136, 50.10126093455723, 50.01614897591727, 50.877051625932964, 50.96678066253662, 52.88670342309134, 52.55376659120832, 52.257780279432026, 51.92035838535854, 52.24325507027762, 51.0325870513916, 46.505474363054546, 48.44755492891584, 47.31096165520804, 49.957971709115164, 56.34943199157715, 50.41215113231114, 50.296585219247, 44.772478989192415, 45.49714830943516, 44.89897094454084, 47.30559069769723, 47.25251340866089, 50.47862802233015, 51.42511510848999, 52.418193340301514, 55.90250996180943, 56.504460198538645, 52.79153047289167, 36.62875945227486, 17.830705199922832, 3.0835925127778734, 0.8971906485302108, 7.078426505838122, 41.14031512396676, 57.33958155768258, 54.81793090275356, 51.118814195905415, 48.08613395690918, 55.92554324013846, 35.438526085444856, 35.802969523838584, 49.80940532684326, 48.12671143668038, 32.517517294202534, 14.864776304789952, 23.11299327441624, 40.866531780787874, 22.07820153236389, 36.641179357256206, 50.70131083897182, 51.44006415775844, 3.099579232079642, 0.10831605137458869, 0.027413018313901763, 0.0411748755723238, 0.06459284933017832, 0.02612450915122671, 0.050158516370824406, 0.01095619298783796, 0.006351696759728449, 0.03610182207609926, 0.03354611653568489, 0.026716834599418298, 0.04761320937957082, 0.05643316378284778, 0.21450613039944852, 0.0982197013550571, 0.07452447140323264, 0.14599780152950967, 0.1000366077891418, 0.07506268538002457, 0.11183163630110876, 0.16537674809140818, 0.1279423510921853, 0.07487025284873587, 0.15344650112092495, 0.11875958740711212, 0.1741805635392666, 0.0853106269080724, 0.15669603246663297, 0.1678303171481405, 0.19026446262640612, 0.16362462139555387, 0.3661097032683236, 49.530963216509136, 71.31530284881592, 50.0961366380964, 67.39713028499058, 70.42631558009556, 37.063591616494314, 22.946431057793752, 75.90201023646763, 86.30432510375977, 40.15284408841814, 20.927618060793193, 46.081345898764475, 70.66276277814592, 62.61680439540318, 69.1777034487043, 62.43799250466483, 32.89539507457188, 4.702288934162684, 1.1749256168093, 0.6564337217382022, 3.0284835270472934, 32.59118904386248, 62.19317967551095, 68.17889990125383, 67.7809487751552, 63.79199491228376, 50.02110651561192, 57.87901537758963, 65.46620505196708, 64.94616018022809, 61.24682807922363, 64.266647202628, 58.89583560398647, 54.68382372174944, 48.864679609026226, 51.498359543936594, 57.73422186715262, 57.708089692252024, 59.051239013671875, 59.0145594733102, 59.058263642447336, 60.00006416865757, 57.71048334666661, 55.368797983442036, 57.75358649662563, 56.710349219185964, 52.24176468167986, 55.04306295939854, 56.70588500159127, 54.174572876521516, 49.99615206037249, 44.051724978855674, 44.30558436257498, 42.243563992636545, 44.12951353618077, 43.647972106933594, 40.67176335198538, 42.57070255279541, 44.03205810274397, 42.157149246760774, 45.51990018572126, 52.366828782217844, 52.74489068984985, 54.415869917188374, 54.087234020233154, 50.549548285348074, 58.75168827601841, 58.633839879717144, 51.65439871379307, 52.112455231802805, 54.232618127550396, 54.21346194403512, 52.594430923461914, 51.69414240973336, 50.86238397870745, 51.855483055114746, 49.01259980882917, 44.646852084568565, 44.06135170800345, 42.86814798627581, 42.61433029174805, 43.37911851065499, 46.676865577697754, 46.804705483572825, 43.625994954790386, 41.67876577377319, 42.41613640104021, 40.61085891723633, 41.0844863482884, 41.343167781829834, 42.318868568965364, 45.84072630746024, 50.71209791728428, 53.8042825290135, 52.65530409131731, 54.25556802749634, 56.30706535066877, 54.18098953792027, 53.36795997619629, 51.599059786115376, 54.62732444490705, 52.8017304284232, 48.77556548799787, 49.11554779325213, 48.867948736463276, 51.773605482918875, 57.15194545473371, 52.23566763741629, 51.24237401144845, 47.6346469606672, 48.11873490469796, 46.384923117501394, 51.138362952641074, 49.41510895320347, 52.934051922389436, 55.15545007160732, 55.741523674556184, 57.79095043454851, 60.21671594892229, 55.76324026925223, 38.23490851266043, 18.546499933515275, 3.8490909678595404, 1.609593738402639, 9.501612067222595, 45.171312536512104, 62.633042335510254, 58.92902020045689, 56.19838857650757, 52.9705125944955, 59.609929765973774, 39.07160016468593, 42.97904470988682, 58.46551282065255, 52.69509295054844, 36.22892189025879, 9.369942835399083, 51.48579025268555, 49.930772985730854, 28.573073591504777, 53.732066426958355, 54.73347554888044, 69.14681870596749, 7.148848235607147, 0.3262426225202424, 0.32181480154395103, 0.1368841262800353, 0.10677404661795922, 0.16309655830264091, 0.13592542415218695, 0.09492670305605445, 0.10822366883179971, 0.1491111373262746, 0.13065081861402306, 0.12741443727697643, 0.1130555709823966, 0.16117747128009796], [0.01646975820351924, 0.061561758763023784, 0.037903882163975916, 0.044971910039229054, 0.026065230635660033, 0.10991866287908383, 0.008034886842194413, 0.02553841095816876, 0.03926829734284963, 0.033765819389373064, 0.01236298437496381, 0.03909641085192561, 0.03993550082668662, 0.03893190682200449, 0.02807399963161775, 0.07151185734463589, 0.06584904156625271, 0.027466710789927413, 0.1657773551664182, 10.211038776806422, 63.61760207584926, 34.21903038024902, 54.76382180622646, 62.371671949114116, 34.043668270111084, 17.22030942780631, 42.00419855117798, 78.4658260345459, 44.51743493761335, 16.93275475502014, 27.643588747297013, 57.580499921526226, 55.56017221723284, 58.51944473811558, 54.71657752990723, 40.35344900403704, 13.430457064083644, 0.1455730250371354, 0.5122732030493873, 5.043850217546735, 37.406412260872976, 63.72505596705845, 62.55439567565918, 64.94496509007045, 57.85056945255825, 48.293777397700715, 52.3761636870248, 59.69637925284249, 62.80537155696324, 60.46994999476841, 58.13409069606236, 57.12175900595528, 52.57642466681344, 53.587335450308665, 55.3536821774074, 54.71880790165493, 56.830403668539866, 59.1888758795602, 55.78807313101632, 56.176373209272114, 56.308277811322895, 53.7232734816415, 53.11957229886736, 51.75503989628383, 50.49064145769392, 52.85911212648664, 54.34975780759539, 52.46398196901594, 50.97493437358311, 44.25543226514544, 39.54467521395002, 40.73392193658011, 40.05573606491089, 39.39626864024571, 38.074648312159944, 38.78460482188633, 38.358402320316856, 36.27698605401175, 39.06760147639683, 40.624070916857036, 46.96586200169155, 46.07772936139788, 50.77139731815883, 47.355735846928184, 47.34795386450631, 58.014661584581646, 50.19208778653826, 50.9102327483041, 48.58169337681362, 53.66588136128017, 50.565688950674875, 48.01427568708147, 45.18432651247297, 46.76234926496233, 44.67536401748657, 44.414886474609375, 41.283930914742605, 38.10705123628889, 36.524821349552695, 36.548917702266145, 38.45074735369001, 39.187913009098594, 40.28549214771816, 36.6862280028207, 36.476097106933594, 37.73390865325928, 36.3392836025783, 39.811374868665425, 40.42581101826259, 39.56056921822684, 40.681754861559185, 41.03916324887957, 44.33259201049805, 44.087219851357595, 46.84294489451817, 47.383222920554026, 50.57176167624337, 49.231422901153564, 53.06723846708025, 51.947647435324534, 48.4914744922093, 48.13926683153425, 48.19714879989624, 48.72705316543579, 52.15531519481114, 47.4209030015128, 51.45873049327305, 48.686830043792725, 46.11265795571463, 43.139687061309814, 44.413187640053884, 48.27799456460135, 47.469404901777, 48.140024185180664, 48.78897203717913, 51.68124655314854, 53.407908643995015, 53.85960408619472, 52.75496557780674, 40.31065157481602, 16.125855241503032, 2.621396605457578, 0.7012177386454174, 8.809444682938711, 38.72458628245762, 52.51501996176583, 49.77367768968855, 52.591318130493164, 47.52664763586861, 54.850656918116975, 37.01075056621006, 42.85763188770839, 49.56633996963501, 43.614297662462505, 15.932294062205724, 14.684701578957693, 46.858411584581646, 20.082692793437413, 34.60162598746163, 32.51350818361555, 50.86186981201172, 13.520695924758911, 0.4263368515031678, 0.04545440611296466, 0.04464324803224631, 0.03565688291564584, 0.0010920522825992002, 0.09136855362781457, 0.06317734385707549, 0.0033402432080557837, 0.06357372365891933, 0.09665156621485949, 0.0435043982496219, 0.031371493225118945, 0.05442871366228376, 0.04782203531691006, 0.024303071799554994, 0.035328706061201434, 0.0676045473664999, 0.010485283747714545, 0.024015430627124648, 0.0301885284882571, 0.05527637014165521, 0.022897720603006225, 0.08082101853298289, 0.06779575174940483, 0.05758560462189572, 0.011264734735180224, 0.01744290973458971, 0.019084791453289132, 0.0871800926647016, 0.060182805971375535, 0.033583008484648805, 0.07138025547776904, 0.09526476955839566, 11.697135993412562, 75.45219775608608, 39.89851917539324, 57.4270315851484, 72.33378369467599, 31.573885917663574, 16.763406310762676, 55.006835051945274, 76.63364165169853, 46.15812349319458, 17.66891986983163, 33.95481123243059, 60.57839747837612, 60.22244126456124, 61.65515981401716, 58.430077007838655, 46.08851643971035, 14.105744668415614, 0.20927853376737662, 0.4328692709761006, 5.825063977922712, 40.04574108123779, 64.46860354287284, 64.76588221958706, 67.19968332563127, 60.36071736471993, 47.360488414764404, 53.80420957292829, 62.587010519845144, 62.10456929888044, 62.70804813929966, 59.27571446555001, 58.724069186619346, 54.96364504950387, 53.09240484237671, 56.44825274603707, 57.569771902901785, 58.61305086953299, 59.961487770080566, 56.51855114528111, 57.2250474521092, 57.323631967817036, 54.09313651493618, 54.36656897408621, 53.295153277260916, 52.13156625202724, 53.711454595838276, 57.11276456287929, 53.68296003341675, 52.501769747052876, 46.123055934906006, 41.19406986236572, 40.8396874155317, 41.08061967577253, 40.07814053126744, 40.61037254333496, 41.446567399161204, 39.637614318302695, 40.02672038759504, 39.38377925327846, 42.78151784624372, 49.16917398997715, 50.29493154798235, 52.331285272325786, 52.05982610157558, 48.92156798498971, 59.85055977957589, 54.510994229997905, 54.142819608960835, 50.90151275907244, 54.903515338897705, 54.5977702822004, 50.02322571618216, 51.14888252530779, 49.815057686397004, 48.22645282745361, 47.848818234034944, 43.306971890585764, 41.14950064250401, 40.36963483265468, 39.95106840133667, 41.83010796138218, 42.966742924281526, 42.48835597719465, 40.82218142918178, 37.93314477375576, 40.45498303004673, 38.85965231486729, 41.90084062303816, 39.74121543339321, 41.06800174713135, 42.586124079568044, 43.943183694567, 46.78826951980591, 45.11612299510411, 47.057494844709126, 49.08698722294399, 49.757880960192, 50.73863308770316, 53.39941447121756, 51.988370827266145, 48.28957026345389, 51.202703271593364, 48.65154709134783, 50.13313579559326, 54.0524582862854, 48.44325399398804, 53.972738129752024, 52.059245926993235, 48.99924189703805, 45.75127519880022, 48.41904647009713, 48.30948380061558, 51.59662444250924, 49.952527795519146, 49.81362983158657, 53.210267135075156, 54.49577420098441, 54.36330679484776, 55.99312489373343, 41.16153839656285, 17.682767629623413, 3.1762777907507758, 1.203128463455609, 9.841131448745728, 41.38805661882673, 56.427025999341694, 55.97970792225429, 55.69095468521118, 51.21379607064383, 54.92506865092686, 40.33914961133684, 42.72119011197771, 53.27201577595302, 45.81480605261666, 27.017736707414898, 15.064807994025093, 32.08248015812465, 27.834506137030466, 27.21368980407715, 36.87940876824515, 58.547251428876606, 17.940412044525146, 1.0190974984850203, 0.06504102849534579, 0.05915067278380905, 0.04706134327820369, 0.013129216652097446, 0.07624356022902898, 0.03132188552990556, 0.020717331441119313, 0.015873783933264867, 0.08431987757129328, 0.05296317640958088, 0.012993505407523896, 0.053455836937895844, 0.03756076396842088, 0.07390118270580258, 0.14990591896431787, 0.1831568218767643, 0.08446017147174903, 0.06376695686153003, 0.21888880165559904, 0.1713716456932681, 0.07980152645281383, 0.13794013032955782, 0.24516333320311137, 0.10196718919490065, 0.07380118021475417, 0.13558669947087765, 0.09456474533570663, 0.1094445161787527, 0.3481863635991301, 0.1961597648582288, 0.10816210534955774, 0.1805527808942965, 19.011737414768763, 91.3358075278146, 46.97524206978934, 72.67320319584438, 73.86546543666294, 49.700176170894075, 20.44905740874154, 54.54306016649519, 87.82858616965157, 51.683831283024375, 21.929998193468364, 36.77916015897478, 66.96771771567208, 64.3262141091483, 67.70974363599504, 64.40616008213588, 51.64971910204206, 15.565312794276647, 0.8941065168806485, 0.5990012692553657, 7.122524985245295, 39.61475821903774, 67.34312888554165, 65.98645142146519, 71.28527968270438, 62.89116096496582, 52.126587867736816, 56.03563049861363, 64.89004652840751, 64.16744082314628, 64.22444384438651, 63.19826439448765, 61.22972856249128, 58.71805899483817, 56.556373664310996, 59.33368328639439, 60.66459683009556, 62.726752689906526, 62.59400735582624, 56.4994991847447, 58.426220757620676, 60.50763702392578, 56.64974355697632, 56.78995820454189, 55.91473879132952, 53.72554554258074, 56.414404596601216, 59.712033544267925, 55.95308589935303, 54.819178104400635, 47.983578545706614, 44.58837604522705, 43.015460218702046, 44.683093888419016, 41.837167331150596, 41.09243508747646, 41.96217584609985, 41.98347207478115, 41.55581739970616, 43.377047947474885, 46.34467567716326, 53.00552109309605, 51.57087441853115, 54.48866966792515, 53.135501044137136, 56.04166153499058, 58.13322911943708, 54.83189330782209, 56.428200244903564, 50.58040870938982, 57.015917096819194, 56.041623319898335, 52.64994008200509, 53.08533157621111, 51.63095201764788, 50.42471694946289, 50.79708480834961, 46.88440826960972, 44.64279086249215, 42.14352035522461, 41.56667743410383, 44.00272628239223, 44.90408829280308, 46.778215476444785, 42.43206167221069, 40.5088141986302, 42.792013100215364, 39.38610689980643, 43.4285340990339, 43.18016379220145, 44.538025924137656, 44.239771025521414, 43.638779640197754, 47.97172839300973, 44.96474606650216, 48.55961894989014, 51.74006652832031, 51.47172015053885, 51.80892317635672, 56.025347164699006, 53.124710491725374, 49.74802494049072, 52.40914331163679, 53.3166892187936, 52.8560653414045, 55.62934848240444, 50.90524046761649, 55.75949171611241, 53.37306342806135, 50.4040321622576, 47.2378249168396, 49.287599086761475, 51.94401352746146, 54.56351566314697, 52.855495589120046, 52.80669491631644, 58.25654227393014, 56.94945410319737, 58.41124044145857, 58.40119334629604, 44.85641670227051, 19.42162207194737, 3.7391613466399054, 1.9640162459441592, 12.448502898216248, 45.903701305389404, 60.92046424320766, 58.12881006513323, 61.40311391013009, 55.83129440035139, 63.356884820120676, 44.39629656927926, 50.982261248997276, 58.79663617270333, 52.67530795506069, 20.965888738632202, 17.46814124924796, 65.02138137817383, 29.01911493710109, 47.38103771209717, 46.30600200380598, 68.9884067262922, 31.068737983703613, 1.158245597566877, 0.16806544310280255, 0.11446698488933699, 0.09485686823193516, 0.07490381319075823, 0.21366140858403274, 0.11153531327311482, 0.09460865333676338, 0.1400572545826435, 0.21317202198718274, 0.09067398482667548, 0.11425829465900149, 0.1868296233671052, 0.16334174014627934], [0.015481337938191635, 0.08730516702468906, 0.07885689714125224, 0.019767993096528307, 0.09518651411469493, 0.0709038899679269, 0.038546939979174306, 0.04902335103335125, 0.014740376001490014, 0.0908941151574254, 0.017662515897037726, 0.05034911346488765, 0.03285267749535186, 0.13414502968745573, 0.04976841641057815, 0.005216186217564557, 0.018387345663670982, 0.030022148309009414, 0.03933104147602405, 1.2174649855920245, 45.523770332336426, 45.47925669806344, 62.88555376870291, 22.393444776535034, 31.47815363747733, 23.60257203238351, 22.512458733149938, 63.134417397635325, 63.38581711905343, 45.786255904606406, 19.325683082853043, 56.61958490099226, 58.62446675981794, 57.487202984946116, 53.77627781459263, 56.67449304035732, 27.592382260731288, 0.8326676679509026, 0.7824509197047779, 13.491875665528433, 43.60819367000035, 64.69334302629743, 65.47821153913225, 65.63278811318534, 58.408614022391184, 51.08947195325579, 50.10092394692557, 59.25691958836147, 61.38410363878523, 61.704068183898926, 57.405651978084016, 56.06713015692574, 56.242547852652415, 54.54557888848441, 52.990023136138916, 60.7850091116769, 58.17305966785976, 57.89642408915928, 55.78028072629656, 56.777527877262656, 57.06462744304112, 54.199259826115195, 51.96583434513637, 51.49009118761335, 54.535177435193745, 53.578622409275596, 52.633997440338135, 51.68152448109218, 47.27558490208217, 42.00607456479754, 40.740161418914795, 39.03859274727957, 40.291457176208496, 40.43980816432408, 38.02724422727312, 39.18263932636806, 39.137458665030344, 37.64166784286499, 40.41455146244594, 42.56028025490897, 49.88844108581543, 48.34288031714303, 51.503084318978445, 42.509985719408306, 56.72090700694493, 53.321521690913606, 50.59060171672276, 50.720428807394846, 51.22887366158621, 52.037755148751394, 50.59278345108032, 48.482799666268484, 47.14461483274187, 46.053167479378835, 44.65013510840279, 44.927972725459504, 42.84458317075457, 37.300490447453086, 37.51935870306832, 37.00037343161446, 38.80160706383841, 38.4011789049421, 37.58779845918928, 37.8514860698155, 37.560318333762034, 37.71883801051548, 38.560494150434224, 39.70768690109253, 39.66968025479998, 39.91699096134731, 40.659072467258994, 40.720668247767854, 39.916761670793804, 39.777742113385884, 43.96824584688459, 44.0368732043675, 48.637994629996165, 50.77145290374756, 51.360041754586355, 53.95510707582746, 54.215278897966655, 49.6063094820295, 49.15769209180559, 50.22030789511544, 48.36330107280186, 48.935766628810335, 51.99784122194563, 49.30270447049822, 46.86880956377302, 47.14950636454991, 50.817599364689414, 49.475843157087056, 49.157351630074636, 48.19643660954067, 46.46578972680228, 50.06513030188424, 50.861317430223735, 55.11270127977644, 53.18476377214704, 40.20906891141619, 11.082124011857168, 4.100455948284694, 1.4537865732397353, 13.892124908311025, 46.491470268794465, 51.261102880750386, 56.07087871006557, 39.338383197784424, 48.20973546164376, 52.00506387438093, 45.479006562914165, 61.650198800223215, 40.05512114933559, 25.670677287237986, 6.1370667559759955, 38.565632343292236, 34.523965971810476, 23.710918767111643, 29.795751571655273, 42.41860301154, 34.891317231314524, 2.5319307318755557, 0.15365342716021196, 0.04637667430298669, 0.027193257784737006, 0.11188962390380246, 0.01618656313179859, 0.06612434357936893, 0.03414997538285596, 0.003645613440312445, 0.022878514669303383, 0.015486250531726649, 0.051369789588664255, 0.018024968947949152, 0.04211279417255095, 0.026333078941596404, 0.018458052405289242, 0.09771419955151421, 0.0053454598611486805, 0.05149675366867866, 0.03868609054812363, 0.06369670134569917, 0.03266382084361144, 0.06320633765842233, 0.023044899937563708, 0.07576401917529957, 0.03543657955846616, 0.04707075795158744, 0.018521631136536598, 0.0368487228905516, 0.0332096004858613, 0.0375503586339099, 0.01754982989015324, 0.04454738799748676, 0.04450213988976819, 1.1161719752209527, 54.72648218699864, 52.75029986245291, 63.677731786455425, 23.34713888168335, 34.273681436266216, 17.793311732155935, 34.261838231767925, 66.39271259307861, 59.786587715148926, 48.43897042955671, 23.06790120261056, 60.08331053597586, 61.87206867762974, 61.960421970912385, 57.824472018650596, 60.768951824733186, 30.503984928131104, 0.9569429308176041, 0.7483703313129288, 15.448273863111224, 43.46761771610805, 65.01029900142125, 67.13962309701103, 67.16032872881208, 60.36378846849714, 53.82294886452811, 51.96017156328474, 62.07271180834089, 63.468146324157715, 62.40769835880825, 60.46033368791853, 59.61632905687605, 56.59966441563198, 56.475621700286865, 53.485249042510986, 63.425894328526084, 58.465012550354004, 59.20877552032471, 57.68789822714669, 59.62141513824463, 59.389803886413574, 56.95937613078526, 53.377638816833496, 52.65990727288382, 53.951566968645366, 55.63245432717459, 53.90771688733782, 52.89604180199759, 51.2742349760873, 41.75378894805908, 41.541872365134104, 41.79014539718628, 41.088637896946494, 41.67899506432669, 41.83084099633353, 40.38075195040022, 41.35626513617379, 39.501485211508616, 42.44539179120745, 46.51768582207816, 52.810978480747764, 53.317439624241416, 55.45372928891863, 48.66418586458479, 57.954222679138184, 57.18387590135847, 51.035119669778005, 54.40134470803397, 52.78746577671596, 53.86284194673811, 53.873333726610454, 51.36740684509277, 50.14838361740112, 49.023414679935996, 45.834705693381174, 48.16094521113804, 44.62960318156651, 41.62273897443499, 40.78083964756557, 39.91300964355469, 41.61413015638079, 40.6462391444615, 40.36334671292986, 41.62502145767212, 39.19322143282209, 39.51239388329642, 40.111950465611045, 41.92073678970337, 41.737516266959055, 41.64000524793352, 42.44154248918806, 42.48580946241106, 41.282318932669504, 41.89175932747977, 44.14560556411743, 45.323933192661826, 49.18113531385149, 51.830990655081614, 52.6679949760437, 53.1067841393607, 54.16610649653843, 50.570663860866, 50.90329844611031, 51.666432993752615, 49.55140829086304, 51.449576241629465, 55.929382119859966, 50.78323357445853, 50.432891505105154, 49.16300746372768, 54.66938883917672, 51.623548712049214, 50.54815517153059, 50.98087508337838, 50.16766139439174, 50.85958732877459, 52.689367634909495, 56.053584643772666, 53.805675642830984, 43.18713978358677, 13.250126991953168, 5.234642539705549, 3.4665602828775133, 16.92246273585728, 51.444465841565815, 54.172592639923096, 58.809031758989605, 44.080761500767295, 52.29591546739851, 54.61456407819475, 49.61452572686331, 62.18921225411551, 44.91477114813668, 33.31535114560808, 13.424425159181867, 24.162280695778982, 33.71597385406494, 28.571155888693674, 30.461910111563547, 50.25932550430298, 41.60109880992344, 3.6249722625528062, 0.11785933428577014, 0.11402276158332825, 0.07678607611783914, 0.04191100803603019, 0.017774816835299134, 0.023039067929078425, 0.09569678601941892, 0.024976660297917466, 0.09079705072300774, 0.025975068598719578, 0.026748936091150557, 0.018670359227274145, 0.030650329243923937, 0.032061936533344645, 0.15625512041151524, 0.4025788706328188, 0.13563430548778602, 0.14945193832474096, 0.15565629968685762, 0.1638479544115918, 0.11917571936334882, 0.13731810370726244, 0.17295046097465924, 0.15848165165100778, 0.12395209020801953, 0.13083205531750405, 0.14156782281185898, 0.20584635436534882, 0.12469100127262728, 0.1284648094858442, 0.06612770232771124, 0.07691915719104664, 0.07479872168706996, 3.5818059274128506, 80.81112793513707, 57.471861362457275, 80.04073946816581, 30.80357735497611, 46.345116887773784, 31.752260071890696, 29.09156380380903, 76.04404531206403, 66.60397257123674, 52.02665192740304, 27.11321885245187, 66.07830660683769, 67.68006093161446, 66.29506261008126, 62.92383139474051, 68.71030507768903, 30.81974928719657, 1.3126390214477266, 1.557818042380469, 18.306139162608556, 44.01952355248587, 66.308945110866, 70.6367278780256, 68.72774505615234, 62.435060364859446, 57.21924570628575, 55.55419329234532, 64.35537569863456, 65.09553950173515, 63.446058000837056, 63.42986174992153, 62.942751339503694, 58.88615676334926, 59.62690421513149, 57.79397290093558, 65.5194490977696, 61.43559673854283, 62.22994954245431, 58.65751934051514, 59.10059206826346, 60.25452109745571, 58.95626408713204, 54.429248673575266, 53.36115421567644, 58.867285455976216, 58.99907193865095, 58.204319613320486, 55.79624768665859, 52.49982425144741, 43.687236377171104, 43.351631437029155, 43.29136276245117, 44.94807733808245, 43.892013686043875, 42.48666409083775, 43.08181551524571, 44.68101290294102, 43.2948750768389, 46.912152426583425, 50.92417778287615, 53.45824486868722, 54.56038897378104, 56.92687245777675, 51.71165187018258, 59.436718123299734, 57.29529026576451, 53.791734082358225, 54.424239022391184, 56.14854914801461, 56.01996578489031, 55.80869885853359, 52.28352682931082, 52.678698675973074, 51.778260775974815, 48.80580752236502, 49.32457045146397, 48.27594832011631, 43.65199163981846, 43.10338967187064, 41.582699980054585, 43.77014575685774, 44.22349834442139, 42.36247546332223, 42.77232537950788, 42.521846294403076, 42.67919519969395, 43.286707469395225, 43.449003492082866, 42.534596238817485, 44.08614982877459, 45.389697892325266, 43.41259145736694, 42.56380646569388, 43.392320087977815, 48.14109420776367, 47.810488496507915, 52.676683698381694, 54.78975943156651, 53.44614110674177, 55.532077176230295, 54.75923599515642, 51.7812693459647, 52.89704234259469, 54.49149063655308, 49.934545857565745, 51.27722964968, 55.98374135153634, 52.970832211630686, 51.991494042532786, 51.19380610329764, 56.70734064919608, 53.26244463239397, 53.396013328007285, 52.03842217581612, 53.794700963156565, 54.03710624149868, 54.565857206072124, 60.24612767355782, 56.132794107709614, 43.994374547685894, 14.54599208491189, 6.38400616816112, 5.371924178940909, 19.150868143354142, 55.23614992414202, 59.086508069719585, 63.37888281685965, 49.457395689828054, 58.63127599443708, 60.634914125714985, 53.59810515812465, 69.38898427145821, 49.37604965482439, 33.91844088690621, 8.099135552133832, 51.48822212219238, 52.762848309108186, 32.09775924682617, 45.568916252681184, 55.58839232581002, 63.93867138453892, 6.887991147381919, 0.2917146895612989, 0.14608215700302804, 0.16553443962974207, 0.22900988427656038, 0.20400232688656875, 0.11589169129729271, 0.1356672958603927, 0.14544223062694073, 0.1396434432161706, 0.0852842251104968, 0.130206364606108, 0.177067635048713, 0.17544613991464886, 0.2062620927712747], [0.019799577205308845, 0.08163825968014342, 0.02564201138115355, 0.031335161067545414, 0.05844949505158833, 0.03300566678600652, 0.04912395063521607, 0.026499287790751884, 0.027281787944957614, 0.07192929887345859, 0.14499074699623243, 0.051657254341989756, 0.03335231675633362, 0.038968778414917846, 0.033052682477448664, 0.030251883302948306, 0.02297074793438826, 0.033461370904530795, 0.06909374852797814, 0.13237284549645015, 21.640617881502422, 50.74909707478115, 46.628735406058176, 44.32677289417812, 24.94436124392918, 38.85561888558524, 10.54015236241477, 54.00641604832241, 66.03083651406425, 52.84671654020037, 44.12765489305769, 48.585289069584434, 65.12712601252964, 57.946940967014854, 61.93934113638741, 57.25141933986119, 42.59834943498884, 5.503225590501513, 1.2652418847594942, 20.63953185081482, 51.80396911076137, 65.35102476392473, 68.43421840667725, 63.74862425667899, 60.90158598763602, 51.401682308741975, 49.986073698316304, 58.54078265598842, 61.33649458203997, 61.85398251669747, 58.47124508449009, 57.963297026497976, 54.75970499856131, 57.35125800541469, 55.07933950424194, 60.30996077401297, 56.901928424835205, 58.956680979047505, 55.833948612213135, 58.120566027505056, 55.63235010419573, 55.591202872140066, 51.373701913016184, 55.948812757219585, 55.50501046861921, 55.239318302699495, 51.23760754721505, 50.68817179543631, 42.12213727406093, 40.38970470428467, 39.075161116463796, 38.86375870023455, 40.6135687146868, 39.89136253084455, 38.213636602674214, 38.3715170451573, 39.21265207018171, 38.97963033403669, 39.11723593303135, 46.35699135916573, 48.02499328340803, 49.59004027502877, 42.540384088243755, 49.104809352329795, 57.07076965059553, 49.446462699345176, 52.02723210198538, 51.18370689664568, 51.98823186329433, 50.271919114249094, 50.78518949236189, 48.46247271129063, 48.917829854147776, 47.32410764694214, 46.92271716254098, 45.945710114070344, 44.98115076337542, 38.77734048025948, 36.34761449268886, 36.490160260881694, 36.99887262071882, 36.36455420085362, 37.72655398505074, 37.1227833202907, 34.15336642946516, 38.11717128753662, 39.55958604812622, 38.55504676273891, 43.47076177597046, 44.508791378566194, 42.122773034232004, 43.27527073451451, 42.6226681300572, 42.05630309241158, 41.70440810067313, 41.976360593523296, 44.754497051239014, 48.87581409726824, 50.94579015459333, 53.18267931256975, 52.16844729014805, 53.108614989689414, 49.77037034715925, 48.26272937229702, 47.893557684762136, 47.01963063648769, 46.216481413160054, 49.89990561349051, 48.89048521859305, 49.79571042742048, 50.77778271266392, 52.99494246074131, 51.675208568573, 49.110746588025776, 48.09798410960606, 50.245755672454834, 52.148829051426475, 54.227490356990266, 54.26137672151838, 42.91069875444685, 15.337825298309326, 7.4724966287612915, 4.138571160180228, 17.635203736168997, 42.32222802298409, 51.55351781845093, 52.42474201747349, 42.554457664489746, 51.581102166857036, 50.75131355013166, 57.88192319869995, 49.89841522489275, 43.200598444257466, 15.886246613093785, 15.780790328979492, 46.191992487226216, 26.40643072128296, 28.677942752838135, 32.30847726549421, 41.744471413748606, 6.912044942378998, 0.6938863034759248, 0.02315612879049565, 0.08021512747343097, 0.019259252984608923, 0.023765453237241933, 0.018964409162955623, 0.051439363176801374, 0.04579650989866682, 0.02798480959609151, 0.048352558099265606, 0.02952693309634924, 0.053626356180757284, 0.09424565745783703, 0.032672828395984004, 0.03921754631612982, 0.0031418522911345853, 0.042824899711247, 0.041762137452938726, 0.030506727485252277, 0.0305600806937686, 0.07158463701073613, 0.04631961290059345, 0.028734753640102487, 0.019972283027267883, 0.07194788394761936, 0.04699605463870934, 0.026435101770662835, 0.06118791989449944, 0.09289218365613904, 0.04411523582945977, 0.07516828578497682, 0.021610626185845052, 0.019849590325195874, 0.04152266548148223, 0.08167519912655864, 25.114407982145035, 61.6758029120309, 51.133450576237266, 41.08428832462856, 28.29900016103472, 30.878183637346538, 15.836466244288854, 63.97544125148228, 68.82291453225272, 55.61674792425973, 42.793249879564556, 54.54261548178536, 68.69822910853794, 63.649793079921174, 65.40085029602051, 62.48840168544224, 45.209155900137766, 6.664767674037388, 1.52692483152662, 23.26911061150687, 50.83629696709769, 68.57365485600063, 69.12012372698102, 67.01457636696952, 63.72629969460623, 52.97155482428414, 52.001680101667134, 61.811549867902485, 64.11263343266079, 62.76407841273716, 59.915247508457725, 61.41092368534633, 57.84930140631539, 59.35727936880929, 54.425156184605186, 61.71528952462332, 58.38798482077462, 60.547207014901296, 59.05271897997175, 59.915462902614046, 57.33575657435826, 56.72843190601894, 55.585456711905344, 57.12294019971575, 57.62997456959316, 56.95286219460623, 54.57078347887312, 52.42723642076765, 44.176170689719065, 41.815933636256624, 41.52558926173619, 41.3226705959865, 44.10772051130022, 41.903289863041465, 41.46656778880528, 40.17773600987026, 39.847390856061665, 41.17344413484846, 41.63858086722237, 49.34406362261091, 51.81003141403198, 53.716589314596995, 50.249469484601704, 51.61582926341465, 60.42077759334019, 52.956956659044536, 54.18798289980207, 54.14394521713257, 53.582412651606965, 52.970700195857454, 53.67844370433262, 52.79424721854073, 51.53573390415737, 49.92018045697893, 49.427143233163015, 48.43878630229405, 48.088419914245605, 41.73503228596279, 41.46213831220354, 38.962225096566335, 40.25472552435738, 41.96520178658621, 40.35637419564383, 40.13218361990792, 38.01502234595162, 40.896554946899414, 41.012464795793804, 39.710691996983115, 45.02358341217041, 46.29819222858974, 45.28521088191441, 43.693670409066335, 43.95852184295654, 43.58315931047712, 42.46587855475289, 45.37962647846767, 46.084458691733225, 50.53798300879342, 52.47461271286011, 52.7288681438991, 52.38835777555193, 53.307913643973215, 51.36007649557931, 50.655126162937705, 51.56277976717268, 49.838125705718994, 51.048102378845215, 52.28048004422869, 51.95923008237566, 52.59903063092913, 52.96478033065796, 54.432298932756694, 54.001552309308735, 52.534155300685335, 51.387104988098145, 52.271301473890034, 54.904081617082866, 57.389229910714285, 55.761669976370676, 46.23375116075788, 19.36820432118007, 9.421741655894689, 6.358286542551858, 20.911823068346294, 45.05065359388079, 55.901290552956716, 54.17009128843035, 45.921905585697715, 53.43526717594692, 54.84598078046526, 59.63737515040806, 54.60917922428676, 46.18474899019514, 21.995031595230103, 19.511781896863663, 29.200353486197336, 34.296440260750906, 26.47840016228812, 35.58348287854876, 54.05739498138428, 12.472424677440099, 0.798190923673766, 0.04788087787372725, 0.10578240161495549, 0.10377377511135169, 0.019222888596622006, 0.026153614910851632, 0.05445962771773338, 0.0357106194964477, 0.022597407789102623, 0.0885045048115509, 0.049581401981413364, 0.04329257318750024, 0.05964950458811862, 0.010255418135784566, 0.05627348752958434, 0.08980499181364264, 0.13848185911774635, 0.12839835376611777, 0.19037297394658836, 0.1287325865456036, 0.15945078964744294, 0.1873330149267401, 0.1245537336383547, 0.17479490914515086, 0.12504948489367962, 0.13961996590452536, 0.2264296327318464, 0.13568478849317345, 0.1728659969355379, 0.1381749441581113, 0.11140007445854799, 0.14711661078035831, 0.10352075618824788, 0.10269924027046987, 0.187329337266939, 41.69135243552071, 78.23219285692487, 61.85478155953543, 60.50903361184256, 34.758700438908164, 54.36174692426409, 12.167080879211426, 68.61872087206159, 71.96556391034807, 62.841675894601, 52.20383446557181, 59.98652212960379, 74.36610398973737, 67.71605260031563, 71.16540936061314, 68.42642947605678, 48.51164858681815, 6.4082410505839755, 1.906705984047481, 26.53362618173872, 55.550503798893516, 69.55871486663818, 73.50415910993303, 69.63130964551652, 66.45242541176933, 54.27410234723772, 54.685466970716206, 63.97192546299526, 67.80381529671806, 64.46847152709961, 59.018061365400044, 65.7290484564645, 59.69963100978306, 61.07670838492257, 56.529438972473145, 63.63818958827427, 59.875107765197754, 61.93030847821917, 60.25570229121617, 63.370586667742046, 59.88292448861258, 59.83532932826451, 55.599380901881624, 59.91149548121861, 60.50244671957833, 60.698017665318076, 57.17513159343174, 55.11751638139997, 43.46635661806379, 43.62297943660191, 42.90418134416853, 43.13143607548305, 46.57644326346261, 44.12296833310808, 41.42239809036255, 41.48528276171003, 41.65438107081822, 44.03880132947649, 44.510104588099885, 51.28502900259835, 56.21857309341431, 54.564787183489116, 50.07788372039795, 54.44215495245797, 58.660930906023296, 54.37423631123134, 56.95354311806815, 55.82034056527274, 53.3488107408796, 55.064060415540425, 53.69981983729771, 54.75230516706194, 54.003463063921245, 52.2355877331325, 50.77708441870553, 51.174295561654226, 51.184790815625874, 46.49824128832136, 43.20596592766898, 41.23085709980556, 43.29588256563459, 42.98422459193638, 44.29523154667446, 41.606924874441965, 39.80353035245623, 41.80522298812866, 43.18856416429792, 42.49589129856655, 47.68858930042812, 49.56490516662598, 48.695577825818745, 46.94415235519409, 46.65582990646362, 45.54686961855207, 45.50971760068621, 47.33921997887747, 47.01198066983904, 51.099380084446494, 52.233475480760845, 53.726716314043315, 54.902031898498535, 54.66572366441999, 53.165836879185264, 50.62401212964739, 51.83907835824149, 49.271270820072715, 53.60415703909737, 52.783779757363455, 53.83958980015346, 55.33170849936349, 55.854991231645855, 56.82836089815412, 56.07128517968314, 55.3270879473005, 54.726798330034526, 56.668475900377544, 58.36812686920166, 59.463225500924246, 57.459358079092844, 48.88547556740897, 20.40307423046657, 10.654399854796273, 8.400601387023926, 23.998291049684795, 49.17752225058419, 59.135944502694265, 58.01163216999599, 51.894274847848074, 58.757615089416504, 58.38540703909737, 65.9834428514753, 62.264523778642925, 51.70646851403372, 20.094221591949463, 19.79230672972543, 65.51133360181535, 37.535065105983186, 41.544804504939485, 44.76548910140991, 62.58508586883545, 28.148436171667917, 1.2129914313554764, 0.26377929427794045, 0.23055691697767802, 0.16505574674478599, 0.08751496326710496, 0.13662374525197915, 0.11706209635095936, 0.17773604632488318, 0.12469672810818468, 0.2309451475739479, 0.17968817800283432, 0.17190738980259213, 0.21756249639604772, 0.13044208767158644, 0.19296105578541756], [0.023220267313133394, 0.01152246693215732, 0.023940220109320114, 0.04606795444020203, 0.030040149843054156, 0.006315616084196205, 0.01432945519419653, 0.030209976980196576, 0.0188147904950061, 0.026429495375071253, 0.028200480255431364, 0.03594595579696553, 0.049978467103626044, 0.04748163126142962, 0.0036053245754114217, 0.04654159223926919, 0.014846882250692164, 0.007932299980893731, 0.06268279360873358, 0.026529574201309254, 2.5069558663027625, 46.803058760506765, 41.41995232445853, 34.28152247837612, 29.558255195617676, 37.4218407358442, 18.74579163960048, 26.678852217538015, 55.979992798396516, 58.84840720040457, 66.07119165148053, 50.771414688655305, 66.5106999533517, 55.613225187574116, 56.741511889866416, 58.66914367675781, 48.87404925482613, 14.856827565601893, 2.9509639952863966, 20.352498292922974, 52.318583965301514, 61.63725430624825, 68.75464153289795, 65.96777466365269, 58.27682753971645, 51.26991319656372, 50.26290035247803, 59.04146984645298, 61.28358404976981, 64.54659707205636, 58.57456479753767, 58.304092270987375, 60.903281348092214, 63.124238286699565, 62.62719890049526, 59.50064155033657, 59.836038044520784, 58.307357924325125, 54.60734142575945, 52.87578432900565, 50.15010677065168, 53.6075998714992, 53.76196799959455, 55.33022158486502, 54.559770584106445, 52.86248547690255, 48.02510445458548, 42.37757737295968, 41.312085015433176, 42.16955178124564, 41.394448961530415, 43.10458476202828, 41.03492832183838, 39.41399002075195, 40.17303555352347, 37.399731567927766, 37.768187591007774, 38.76491362707955, 40.56297888074602, 47.084839480263845, 50.86630971091134, 47.97921855109078, 45.25888763155256, 58.89159025464739, 50.40736729758126, 53.14208793640137, 51.69105046136038, 52.10921389716012, 48.8102057320731, 51.80860703332083, 52.66911711011614, 51.3322628566197, 47.855679580143516, 45.86713988440377, 47.556215694972444, 46.70566586085728, 46.87530265535627, 43.16730267660958, 36.38432877404349, 37.082869393484934, 36.443555218832834, 35.810886996132986, 37.44340099607195, 35.4461030960083, 37.18432004111153, 39.433167048863, 39.73771006720406, 44.65746545791626, 46.52901138578142, 44.30220406396048, 45.36935704095023, 42.41709177834647, 41.723605973379954, 44.053062507084434, 43.484401089804514, 44.037363052368164, 42.10262673241751, 45.19111490249634, 48.77590594972883, 51.6669019971575, 51.481638704027446, 52.81380639757429, 51.499738761356895, 49.63869503566197, 46.49318994794573, 36.715354851314, 31.108158588409424, 39.87655939374651, 48.54052530016218, 52.88876008987427, 51.51930488858904, 51.02360303061349, 50.87828493118286, 50.61806794575283, 47.11928864887783, 47.157316139766145, 48.804285866873606, 53.65776933942522, 55.036670616694856, 47.85244171960013, 29.119775227137975, 14.889485836029053, 6.9480995791299005, 19.51797100475856, 45.79337085996355, 53.5021470614842, 47.76076371329171, 51.671991552625386, 52.70732178006853, 55.35085078648159, 51.817399978637695, 51.58496536527361, 36.25407089505877, 9.869868329593114, 30.284671987806046, 33.56943981988089, 24.88815552847726, 29.994053159441265, 35.8297061920166, 41.81394297736031, 1.1023787153618676, 0.11152662123952593, 0.01745530148036778, 0.07604624903095619, 0.053623346877949576, 0.06028495263308287, 0.07491064603839602, 0.04881681854437504, 0.028405504700328623, 0.07617900440735476, 0.043317787548793216, 0.0320892713165709, 0.059288340753742626, 0.009194928969788765, 0.018148643829460655, 0.06337977120918886, 0.039284745031701665, 0.015306511694299323, 0.04285865682842476, 0.008371337583022458, 0.0629920834409339, 0.04291570805279272, 0.05415229885173695, 0.07827991167349474, 0.00566294215553041, 0.06333982585264103, 0.03436076907174928, 0.015844006423971484, 0.052786387503147125, 0.057891630700656345, 0.047980408782937696, 0.03262359728770597, 0.022456857741677334, 0.046789050567895174, 0.079074801877141, 0.0325648938305676, 3.822296108518328, 61.32575266701834, 50.74101979391915, 36.414268561771934, 31.11053487232753, 38.36389487130301, 14.79006232534136, 39.421810218266074, 58.573550360543386, 61.07324818202427, 67.92879949297223, 53.54164409637451, 70.03723035539899, 60.56699548448835, 62.778426442827495, 61.86427279881069, 53.78531742095947, 16.49947030203683, 3.0180749084268297, 22.700633321489605, 53.63286699567522, 64.59335150037492, 70.0701231275286, 66.49583080836705, 61.40545545305525, 52.91707399913243, 50.65555695125035, 61.61741719927107, 64.79691982269287, 66.1289311817714, 59.26754338400704, 59.09655516488211, 62.40681593758719, 64.28290598733085, 62.41028308868408, 62.605430194309776, 59.757627623421804, 59.71683474949428, 57.82679271697998, 56.46385145187378, 53.29067168916975, 56.42015423093523, 54.76865427834647, 56.58146013532366, 55.795000485011506, 55.023997102464946, 51.80830478668213, 46.75796147755214, 42.79359381539481, 43.856873171670095, 42.49472400120327, 44.47593682152884, 43.56000096457345, 41.26818282263619, 40.26751020976475, 40.12699678965977, 39.732293946402415, 41.9158695765904, 41.47506890978132, 51.41238600867135, 53.909968103681294, 53.275799070085796, 48.846913065229145, 60.56714139665876, 54.21579653876168, 54.64851992470877, 56.500659533909385, 53.478088923863, 53.46178844996861, 55.2904292515346, 56.833231585366384, 52.765961102076936, 52.36128759384155, 49.36285849979946, 51.47386714390346, 50.527956758226665, 48.876401220049175, 44.89934267316546, 40.68542698451451, 40.38494866234915, 39.808619907924104, 39.63437645775931, 41.8326301574707, 40.537503310612266, 40.26763875143868, 43.015724250248496, 42.22616222926548, 45.57016345432827, 48.99283913203648, 46.523970467703684, 47.85993535178048, 44.44987760271345, 43.23459597996303, 43.93778494426182, 44.51191806793213, 45.068486145564485, 43.96958337511335, 46.2440379687718, 50.49750280380249, 52.918797152382986, 52.08587837219238, 52.779784543173655, 53.85815191268921, 52.63896540233067, 48.52486753463745, 41.38684068407331, 37.31532832554409, 45.150026730128694, 52.76404687336513, 56.47244637353079, 54.98101554598127, 53.58565051215035, 53.43438128062657, 53.70109830583845, 49.32881580080305, 50.18670640672956, 52.1865508215768, 57.360023157937185, 56.581380231039866, 51.45392581394741, 31.8486385345459, 17.454140629087174, 10.698241250855581, 23.0593774999891, 47.076821259089876, 58.323908533368794, 51.56210926600865, 54.90623208454677, 55.65149239131382, 62.45573820386614, 53.95074013301304, 59.33404459272112, 37.22467170442854, 18.98842099734715, 22.904258966445923, 30.900952884129115, 35.800006117139546, 25.53737609727042, 44.60111556734358, 51.38841472353254, 2.926251641341618, 0.34438420619283405, 0.08836019398378474, 0.12358223434005465, 0.07151934837124177, 0.05339371366426349, 0.018010368570685387, 0.012350445895987962, 0.06629682718110935, 0.036453632305243185, 0.03881655586883426, 0.02791980085229235, 0.014938764373904892, 0.07310769028429474, 0.041321425565651486, 0.04693604160898498, 0.09971498897565262, 0.136852533689567, 0.13408658068094934, 0.06905379638608013, 0.13892373469259056, 0.10071616739566837, 0.07494987893317427, 0.20001167245209217, 0.10781669031296458, 0.1666404924222401, 0.1524222389395748, 0.11875836604407855, 0.10572593393070356, 0.12774420529603958, 0.09026634134352207, 0.1717569585889578, 0.11549352694834981, 0.12902004112090382, 0.15352246990161283, 0.14702663703688554, 8.536428247179304, 81.32650361742292, 57.73813022886004, 53.20144987106323, 40.716871057237896, 57.04538093294416, 23.207485301154, 36.63685062953404, 65.4560398374285, 68.83346189771379, 75.18911116463798, 60.36487933567592, 76.03533227103097, 64.87696307046073, 67.09976128169468, 68.22722462245396, 56.79106296811785, 17.985196658543178, 4.019240192004612, 25.621626479285105, 53.67745706013271, 65.40947995867047, 72.9068363734654, 69.98661967686245, 62.766232354300364, 54.11184801374163, 54.0831241607666, 63.39386313302176, 69.19720009395054, 67.467668397086, 59.50727013179234, 59.70480046953474, 62.451075962611604, 67.93765149797711, 64.64626203264508, 64.83844225747245, 63.0814026423863, 62.90910121372768, 59.76276929037911, 56.33804736818586, 55.94706181117466, 58.0419054712568, 58.20415980475289, 59.82109941755022, 56.872780731746126, 58.2827821459089, 53.698642117636545, 48.575130803244456, 43.545823165348594, 46.521132128579275, 43.42182561329433, 47.78539855139596, 45.221683502197266, 43.972717012677876, 43.1421536718096, 42.16429894311087, 42.101549761635916, 45.240606921059744, 44.101102352142334, 53.26033932822091, 55.51756238937378, 54.10784237725394, 53.95096942356655, 59.08710561479841, 55.868936266217915, 58.33517156328474, 58.526274817330496, 55.361686502184185, 53.10994209562029, 57.2223550251552, 58.0107775415693, 57.29430709566389, 54.08054290499006, 49.890400477818076, 54.54424483435494, 53.23340463638306, 52.32899931498936, 48.00670909881592, 43.8972178867885, 42.64129277638027, 41.39910078048706, 41.881090368543354, 45.144489015851704, 42.261768272944856, 43.33689430781773, 43.51628984723772, 42.85813910620553, 47.15000663484846, 49.96254014968872, 48.878082684108186, 49.43892042977469, 47.21769598552159, 44.61045742034912, 48.77227899006435, 47.315245219639365, 48.33141926356724, 44.4539145060948, 48.34080280576433, 52.55783476148333, 54.94965137754168, 54.20565216881888, 56.459463664463584, 56.05490827560425, 55.10752487182617, 53.30710070473807, 44.77483095441546, 42.44924109322684, 47.7142003604344, 52.85880640574864, 57.87488119942801, 55.4741222517831, 54.76433597292219, 57.3727696282523, 57.89130326679775, 53.354296343667166, 53.154914311000276, 55.765835421425955, 60.03704942975725, 61.30674239567348, 53.788954802921836, 34.01949201311384, 18.69563433102199, 12.88422964300428, 25.74585505894252, 51.80200277056013, 60.78097915649414, 55.94009971618652, 60.41505227770124, 59.081415040152415, 65.35852881840297, 60.51563440050398, 63.109438623700825, 42.63538680757795, 13.845807347978864, 38.35920136315482, 48.83758858272007, 35.626818793160574, 44.81548833847046, 49.71772732053484, 69.34339714050293, 7.021411325250353, 0.5325956525547164, 0.19066839452300752, 0.24780516858611787, 0.2068218027374574, 0.10921004161770854, 0.15591559505888394, 0.1766309299107109, 0.17437552022082464, 0.11437760825668063, 0.1948579140007496, 0.10553610697388649, 0.1896382426576955, 0.10480351307030235, 0.18630886131099292, 0.17137938099248068], [0.03713518680472459, 0.033132647829396386, 0.004194934187190873, 0.041902685804026465, 0.05017091320561511, 0.06021249866379159, 0.04676441974671824, 0.05433962879968541, 0.019914181769958565, 0.04363724522824798, 0.06303966231644154, 0.04987916011097176, 0.10868907600109066, 0.020125336778749312, 0.025238730878170048, 0.01672277203761041, 0.09942271001636982, 0.025615490839949677, 0.02492622987899397, 0.059289650326328616, 0.31681435129472185, 25.8382956300463, 56.74951621464321, 38.14212574277605, 38.749370506831575, 29.887360095977783, 38.11609084265572, 11.176065393856593, 71.29012952532086, 73.81897503989083, 62.87192835126604, 67.3202623639788, 59.30917004176548, 57.87153911590576, 56.361032009124756, 60.047694069998606, 53.238768645695274, 21.407438073839458, 3.0037297010421753, 20.840006487710134, 48.142073903764995, 62.57032094682966, 67.57868671417236, 65.71468652997697, 63.076823779514854, 55.48025056294033, 49.493686131068635, 59.521277700151714, 61.82593263898577, 61.96411146436419, 57.55705322538103, 56.511714117867605, 58.57921314239502, 60.95248849051339, 59.51690033503941, 58.477422033037456, 56.76647329330444, 52.499528953007285, 51.78552859170096, 48.62050254004342, 49.53069223676409, 51.47295345578875, 56.88292162758963, 54.72605834688459, 56.382290022713796, 49.488586153302876, 42.71161549431937, 40.60782950265067, 41.404746191842214, 41.73474393572126, 44.739930152893066, 44.39600474493844, 43.60038389478411, 39.33713252203805, 38.05275106430054, 37.609480312892366, 39.34865958350045, 38.622114249638145, 41.478810514722554, 46.84122174126761, 49.751043932778494, 42.090811320713584, 57.02670070103237, 54.341076033455984, 49.01725162778582, 50.23782082966396, 49.703375816345215, 53.25776154654366, 50.029326234545024, 51.42084196635655, 52.01576410021101, 51.569053990500315, 48.118793964385986, 47.30940873282296, 49.02588129043579, 48.01972654887608, 48.441287653786794, 43.201050077165874, 36.365950788770405, 37.053954465048655, 37.238790443965364, 38.089965615953716, 37.615945611681255, 38.55176721300398, 37.23166854040963, 39.59425755909511, 40.4243414742606, 42.84573309762137, 45.76302112851824, 46.55637686593192, 46.166503020695274, 44.17897776194981, 43.28312914712088, 44.04665279388428, 45.70899541037423, 44.361093521118164, 46.3042892728533, 47.64158126286098, 47.43357651574271, 47.81214911597115, 47.27466426576887, 50.652836731501985, 51.52158389772688, 51.45277936117989, 51.37574815750122, 45.22016879490444, 32.73470755985805, 22.751245737075806, 32.886824471609934, 42.39455182211739, 46.062874112810405, 46.453321184430806, 46.335340772356304, 50.27493463243757, 48.095573084695, 46.6651474407741, 52.38536657605852, 49.20392540522984, 54.242950098855154, 44.485949175698416, 31.933879034859793, 22.633152416774205, 14.629994937351771, 26.543895619256155, 41.516723360334126, 53.0087103162493, 47.8466226032802, 50.39135864802769, 49.85765361785889, 55.81324992861067, 47.889347076416016, 49.27109711510794, 12.668530634471349, 11.020894748823983, 41.65114321027483, 26.20339914730617, 26.27820519038609, 27.202579634530203, 42.96739952904837, 21.51151861463274, 0.3858446500131062, 0.04212896366204534, 0.049761631060391665, 0.03575299400836229, 0.06444095926625387, 0.07059903775474854, 0.041311895541314564, 0.03340736630239657, 0.022231288952752948, 0.028214702349422232, 0.0386925298454506, 0.02907854358532599, 0.020269834203645587, 0.018861256573083143, 0.02932149644142815, 0.016476820056725825, 0.058493599827800474, 0.015232700654970748, 0.018917613995394537, 0.011852377443574369, 0.03463900914149625, 0.08066549152135849, 0.028851098647075038, 0.08568940551153251, 0.0257702544996781, 0.022972849696608524, 0.014092675310426524, 0.018140374183920876, 0.06087850792599576, 0.01908989912564201, 0.027793924124645333, 0.08164079061576299, 0.04720584409577506, 0.07573079131543636, 0.08578809164464474, 0.010311057159144963, 0.2754465139337948, 30.501045840127126, 70.65687070574079, 41.82277066367013, 39.81243099485125, 35.30849749701363, 32.9757787840707, 16.116971969604492, 74.48272950308663, 75.89515931265694, 71.96935762677873, 69.0313674381801, 64.85081005096436, 60.67230238233294, 61.91198607853481, 64.60022326878139, 59.62698759351458, 23.22159709249224, 3.8803040129797797, 21.901583535330637, 50.46291119711739, 65.02918420519147, 69.4770735331944, 66.18383584703717, 66.91134003230503, 56.65770966666085, 52.5049798148019, 60.03963415963309, 62.077165603637695, 65.45647757393974, 60.70324271065848, 59.057138034275596, 62.51498549325125, 62.4241030556815, 61.19831575666155, 60.52796050480434, 57.45470973423549, 55.32667105538504, 51.86045796530587, 53.08582142421177, 51.887938090733115, 56.576106548309326, 58.67717579432896, 55.69449479239327, 56.43527351106916, 52.90955604825701, 44.21176978519985, 41.946657044546946, 44.13151114327567, 43.42810331072126, 45.84656279427664, 45.94586992263794, 44.88549491337368, 42.50676870346069, 40.00206470489502, 38.14360918317522, 41.446619510650635, 40.465832642146516, 44.217356136866975, 48.32369286673409, 52.97654710497175, 45.9019364629473, 59.239583832877024, 59.241848945617676, 53.60513326099941, 54.396731104169575, 54.07029431206839, 56.899381910051616, 52.35243558883667, 56.71302080154419, 53.46752766200474, 54.64333656855992, 51.868104457855225, 50.40626948220389, 51.22817884172712, 47.784095764160156, 50.60943480900356, 47.59144306182861, 40.13379907608032, 40.017399379185264, 40.93142795562744, 41.55508436475481, 40.719160488673616, 40.69777045931135, 39.95693268094744, 40.53791672842843, 42.58874702453613, 45.06533861160278, 47.75894675936018, 49.22527721949986, 47.233892236437114, 47.62464155469622, 45.73062515258789, 45.58391393933977, 46.8797356060573, 46.153506415230886, 47.6433287348066, 48.2653557913644, 46.85040031160627, 48.022005558013916, 48.22112703323364, 51.936954157693044, 52.0484345299857, 53.354664598192485, 53.881251198904856, 49.736664635794504, 38.35454954419817, 28.367500713893346, 36.6761600630624, 46.16322694505964, 48.8465621812003, 49.665490763528005, 52.56277840478079, 53.33972944532122, 51.43789979389736, 50.308174814496724, 54.37823499952044, 51.93955625806536, 57.92359501974923, 47.80139677865164, 34.81654419217791, 23.877795389720372, 18.178844690322876, 28.400560242789133, 44.129030636378694, 56.74749081475394, 51.75013794217791, 53.24753032411848, 54.849979468754356, 59.22096266065325, 53.24893733433315, 53.99804694311959, 19.66678057398115, 17.68386718205043, 27.017538683755056, 32.736767700740266, 27.606893573488506, 29.192898069109233, 54.56743444715227, 24.075059958866664, 0.4194762924952166, 0.04646850044706038, 0.045165455367948325, 0.07249261186059032, 0.08305736817419529, 0.019043312607599155, 0.03785994362884334, 0.04233208651255284, 0.018591744160013537, 0.0029838658021097736, 0.08801684169364826, 0.11530686196471963, 0.04335139199559178, 0.012895658961497247, 0.013369739504664071, 0.022645748320168683, 0.13611782954207488, 0.09581474254706077, 0.12706024199724197, 0.1263476445206574, 0.11291333647178751, 0.14289605511086328, 0.14672308761094296, 0.22865571613822663, 0.09304021964115755, 0.08295325376093388, 0.13746605148272856, 0.1776153620864664, 0.16134861138250145, 0.060499987165842734, 0.07401611975261144, 0.15029049904218741, 0.13773252575525216, 0.20630384981632233, 0.12129676554884229, 0.19285236804613046, 0.6094868066055434, 50.107420512608115, 79.23089218139648, 54.26224872044155, 56.27532945360456, 44.4365405355181, 54.481356688908164, 13.949629936899457, 84.48704460689, 79.95551286424909, 75.4770097732544, 76.08061368124825, 70.65307004111153, 66.02659116472516, 67.13738577706474, 66.93100343431745, 64.24904741559709, 26.08572793006897, 4.5819509114537915, 24.83260120664324, 52.98639965057373, 66.74393013545445, 70.07589708055768, 69.07167393820626, 68.95962033952985, 58.94765526907784, 52.75385386603219, 64.06106390271867, 66.7401225226266, 69.3805422101702, 61.17594255719866, 60.34923199244908, 64.35620253426688, 64.42416286468506, 63.10790307181222, 61.902230807713096, 60.82919270651681, 56.90556928089687, 55.25619895117623, 54.88382414409092, 55.474949087415425, 59.36155945914132, 62.83197620936802, 58.010152203696116, 60.220113618033274, 55.514143875667024, 47.17951910836356, 44.682260104588096, 45.55754899978638, 45.966453960963655, 47.98641341073172, 47.75452423095703, 47.167307649339946, 45.78007548195975, 40.91934503827776, 40.727307251521516, 42.98317541394915, 43.28183330808367, 46.04648331233433, 52.62802198954991, 54.354951586042134, 48.748033251081196, 60.44082314627511, 56.97360604149954, 55.39361000061035, 54.929515498025076, 56.233567305973594, 57.35150466646467, 52.75601822989327, 57.26898091179984, 56.63387734549386, 56.31814772742135, 54.15164729527065, 50.65671730041504, 54.28232206617083, 51.75253507069179, 51.84001636505127, 48.73413337979998, 42.540985107421875, 42.740513052259175, 42.7035208429609, 43.8454920223781, 42.237543378557476, 43.53087759017944, 42.315971170152935, 44.14626564298357, 45.09854057856968, 45.54208925792149, 50.30152191434588, 51.36579833711897, 48.95909867967878, 50.06375803266253, 47.71685804639544, 48.51587309156145, 49.150028228759766, 48.09841142381941, 50.90898207255772, 51.72330747331892, 49.62263427461897, 51.300082274845664, 49.17495141710554, 54.238850661686485, 55.59292949948992, 56.07246289934431, 57.35680614198957, 53.39010041100638, 42.40910829816546, 35.33153772354126, 41.04893241609846, 49.50915976933071, 52.3011474609375, 53.42387213025774, 54.427428245544434, 56.42748805454799, 54.196147033146445, 53.1170848437718, 59.51269667489188, 56.26712015696934, 60.41302340371268, 52.20671101978847, 39.70387234006609, 27.53272155353001, 22.49620168549674, 31.757606710706437, 47.86189821788243, 61.19841997964041, 54.76141078131539, 57.06944601876395, 60.39060851505825, 65.58800002506801, 58.692211696079795, 60.277894837515696, 17.042875017438615, 15.248012883322579, 54.49044493266514, 37.02558844430106, 35.7646085194179, 40.80868802751814, 61.40098776136126, 41.02787937436785, 0.7176199927926064, 0.23624507603900774, 0.15077805359448704, 0.21604314792369092, 0.16954566724598408, 0.18533329080258096, 0.16645578161946364, 0.16121191371764454, 0.08305172954819032, 0.07855762248592717, 0.14824942499399185, 0.1679442703191723, 0.14701850818736212, 0.10605297423899174, 0.056024801052574597, 0.2472908661833831], [0.07653596132461514, 0.022556873803426112, 0.10241598582693509, 0.03875093474718077, 0.010935840329953601, 0.04862196025039468, 0.015437038083161627, 0.0473862529865333, 0.06294466062848057, 0.020687397868771638, 0.03168751751737935, 0.01129832730761596, 0.024789725596617376, 0.04543794146073716, 0.053222851761217625, 0.04562893889046141, 0.031112733895757368, 0.07738379083041634, 0.04032903078145214, 0.1391451678105763, 0.049557829674865515, 3.983271539211273, 61.86908095223563, 43.27230037961687, 39.142096587589805, 36.55947549002511, 41.44889504568917, 15.213221515927996, 25.293324095862253, 72.98817198617118, 59.050947189331055, 72.65082999638149, 64.15661552974156, 62.85547501700265, 61.180528368268696, 55.94500514439174, 53.13389948436192, 30.784435067858013, 5.377091033118112, 13.713458061218262, 45.63860321044922, 58.73946639469692, 69.15894331250871, 65.38964979989188, 60.64145238058907, 56.05247988019671, 53.2869405065264, 58.13191590990339, 60.856888226100374, 61.359375, 54.979980264391216, 56.637125628335134, 56.053421361105784, 58.17997659955706, 56.321180616106304, 52.43642888750349, 54.29199048451015, 48.59321696417672, 47.770786489759175, 46.07802465983799, 50.126482895442415, 53.83774157932827, 55.27506331035069, 53.84113230024065, 51.203665597098215, 44.88275384902954, 43.19464731216431, 41.22593082700457, 41.373635632651194, 47.18549803325108, 49.884932245527, 48.59808417728969, 43.95138256890433, 42.840560163770405, 37.61393410818917, 38.978612422943115, 38.38649388722011, 40.249253817967, 41.95392138617379, 50.284054143088206, 44.768254484449116, 49.58742427825928, 56.59907381875174, 51.16284145627703, 54.27469294411795, 51.163223607199534, 53.397128513881135, 51.781915528433665, 53.137248516082764, 52.49794128962925, 53.146131787981304, 48.285133838653564, 49.27821901866368, 46.912381717136924, 49.35233545303345, 48.22812039511544, 48.84378637586321, 46.91207252229963, 40.3838334764753, 36.75448015757969, 36.65557255063738, 37.91941860743931, 36.77082232066563, 36.22208833694458, 38.6504351070949, 39.496416500636506, 43.100120544433594, 46.40309613091605, 47.150628498622346, 47.393245697021484, 45.37810482297625, 44.691094739096506, 45.866486753736226, 47.47400460924421, 50.6260027885437, 49.56323759896414, 48.6535690171378, 48.66447074072701, 51.207532269614084, 49.34563391549246, 49.484973090035574, 46.730794021061485, 51.02468694959368, 51.27219567980085, 55.52745662416731, 55.31782252447945, 53.519521032060894, 35.0340644972665, 19.7406416620527, 23.257821525846207, 31.529691900525773, 40.317697048187256, 48.0708965573992, 52.780350821358816, 51.25466537475586, 47.86369432721819, 49.2818147114345, 51.22606658935547, 53.45053584235055, 46.97660739081246, 36.136708872658865, 26.15192689214434, 21.618564299174718, 31.676410061972483, 45.432401520865305, 50.605262415749685, 49.92261232648577, 50.39564568655831, 57.54674904687064, 49.842860903058735, 50.88744265692574, 36.335687909807476, 6.179416460650308, 26.75932625361851, 37.40295900617327, 23.09928968974522, 28.021949427468435, 27.044878108160837, 45.95712947845459, 5.342545892511096, 0.17932950439197676, 0.07117737350719315, 0.031153082980641296, 0.06062468833156994, 0.03323644672387412, 0.032559238241187165, 0.061975922967706404, 0.13487859389611653, 0.031143641165856804, 0.029577402531036308, 0.015512660810989993, 0.08409454966230051, 0.04321165449385132, 0.058209476859441826, 0.05108602963654058, 0.06303956732153893, 0.015600241022184491, 0.05349436076357961, 0.0099107944406569, 0.06846925203821488, 0.030851016153714488, 0.06054645324391978, 0.06906667498073407, 0.0803090435053621, 0.05308775543900473, 0.052345560264906714, 0.03748936851375869, 0.039564796789948425, 0.027494488317253332, 0.021619776230571524, 0.027255932368072014, 0.07919287375573601, 0.0512215195090643, 0.042469791801912446, 0.01914116583897599, 0.11786082706281117, 0.10595297174794333, 4.987361797264644, 71.76136330195835, 48.97450631005423, 42.141807624271934, 40.07154321670532, 42.057883807591026, 20.751641035079956, 34.92106941768101, 78.3668211528233, 65.26233795710972, 76.52039991106305, 71.03027384621757, 67.17818559919084, 64.73150948115757, 59.28322546822684, 58.01195526123047, 34.06518336704799, 6.093106806278229, 14.311251538140432, 46.98441021783011, 63.62599549974714, 69.62201990400041, 67.71029949188232, 62.62228652409145, 58.240102836063926, 56.27827548980713, 62.9043208530971, 63.70026479448591, 62.22594043186733, 57.95809282575335, 62.06103188650948, 59.230613708496094, 62.527575629098074, 59.59731183733259, 53.41089984348842, 55.197222641536165, 50.8245267186846, 47.957005160195486, 47.505632809230256, 51.91429260798863, 55.40195478711809, 57.82071304321289, 56.374244008745464, 55.761093275887625, 47.50310713904244, 44.02698591777256, 43.05419989994594, 43.740966796875, 47.74790607179914, 51.271820477076936, 50.25235993521554, 46.31017787115914, 42.81897211074829, 40.89627354485648, 41.38120222091675, 40.67186757496425, 40.61437470572335, 44.574316365378245, 53.17318112509591, 49.503403186798096, 52.03852987289429, 61.44089126586914, 53.912156786237446, 58.79299531664167, 54.34546034676688, 56.52241434369768, 54.7239738873073, 55.93359620230538, 55.29381997244698, 57.436352593558176, 52.00247567040579, 53.26038449151175, 49.78042786461966, 51.72460331235613, 51.34105232783726, 53.636188234601704, 49.108411993299214, 42.67847258704049, 40.315407616751536, 39.99967105048043, 40.596219062805176, 40.584726742335725, 37.94090938568115, 41.516164030347554, 39.955188683101106, 45.80953584398542, 48.06804779597691, 48.435364314488, 48.27824469975063, 47.105374881199424, 47.30448940822056, 47.73508317129952, 48.26046773365566, 52.928906781332834, 50.32210942677089, 49.05171469279698, 49.664684772491455, 50.88605996540615, 49.13561419078282, 50.17363684517996, 49.2921119417463, 51.001976762499126, 53.3774025780814, 56.17564364842006, 56.86110428401402, 53.35064853940691, 38.115552357264924, 26.18644380569458, 25.959567751203263, 35.04957982472011, 46.37225655147007, 54.08163029806954, 55.879678181239534, 53.187035833086284, 50.007845878601074, 52.28099768502371, 53.73683983939034, 55.5714248248509, 50.70475367137364, 42.13777419498989, 28.163472073418752, 26.072955404009136, 34.61688423156738, 51.102030822208945, 54.70433827808925, 55.997144426618306, 52.333960328783306, 61.63206400190081, 54.30708197184971, 57.13748625346592, 40.099739006587434, 15.80786051068987, 22.248303856168473, 26.461149522236415, 28.048050335475377, 24.949763468333654, 33.574383463178364, 54.39274631227766, 7.5632922138486585, 0.45127062499523163, 0.12531613558530807, 0.04782406074394073, 0.02867621642404369, 0.11473607830703259, 0.04052606038749218, 0.10165450668760709, 0.046864157609109364, 0.018527134055537835, 0.033086154609918594, 0.01838642285604562, 0.07353597480271544, 0.04782630669485245, 0.03417655359953642, 0.04150907103238361, 0.010563289829795914, 0.10544173632349287, 0.10035419610462018, 0.2720750905573368, 0.1798440103552171, 0.08116476437343018, 0.13659493465508732, 0.12264439037867955, 0.23011462071112224, 0.17455826327204704, 0.1333220617047378, 0.11225074024072715, 0.13508281936602934, 0.14385338659797395, 0.11866730664457593, 0.1308436854077237, 0.20309630621756825, 0.17232441742505344, 0.13849859179130622, 0.11996602267026901, 0.21923755508448395, 0.2975370357079165, 12.578672187668936, 88.52839483533586, 55.68174484797886, 57.81728410720825, 46.89557749884469, 59.80744620731899, 18.315185717173986, 36.347135066986084, 81.53535951886857, 71.66349792480469, 83.09228406633649, 76.4618752343314, 69.50088500976562, 72.75898565564836, 64.47018078395298, 62.692407744271414, 36.429106439862935, 6.81210856778281, 14.703600679125104, 50.838259833199636, 63.84431484767369, 71.38492379869733, 69.46505314963204, 64.94151878356934, 61.547664233616416, 58.83884647914341, 64.7295639855521, 67.63452243804932, 65.67042650495256, 58.221992356436594, 64.81948062351772, 61.72196674346924, 64.9746755872454, 61.32696860177176, 55.6140068599156, 58.11898531232561, 54.01803691046578, 50.17704493658883, 50.244108949388774, 55.240614141736714, 57.360957690647666, 60.395347186497276, 59.95959786006382, 58.032539299556184, 51.135482924325125, 48.88273797716413, 46.68287229537964, 45.77551398958479, 50.55465521131243, 55.46000698634556, 54.1443065234593, 49.326067788260325, 45.855876854487825, 43.811751570020405, 43.18577446256365, 42.87761838095528, 43.9984461920602, 47.81852756227766, 54.66306945255825, 51.75795119149344, 52.453180994306294, 61.13866547175816, 57.24637147358486, 59.6856164932251, 57.47736780984061, 57.43617194039481, 55.08189296722412, 56.75409507751465, 56.45606599535261, 58.73162187848772, 55.2904292515346, 55.478127888270784, 52.67986944743565, 55.50421142578125, 55.38298967906407, 54.64835664204189, 52.85493973323277, 45.91714606966291, 41.31511443001883, 41.42842565264021, 43.57277175358364, 42.83374398095267, 40.223434312003, 43.23874058042254, 42.33616958345686, 46.85831083570208, 49.753857953207834, 50.135591983795166, 51.13613952909197, 49.549132755824495, 49.43437283379691, 49.86158977236067, 48.92038679122925, 55.12714658464704, 53.82316425868443, 51.416739055088584, 51.553559507642476, 53.331186635153635, 52.94052069527762, 52.928819928850444, 52.322033745901926, 53.72827271052769, 55.508863244737896, 61.12405341012137, 60.44335923876081, 59.8262619291033, 39.933767386845176, 29.98142828260149, 32.033953939165386, 39.770290170397075, 49.97768374851772, 58.77260930197579, 57.45824984141758, 58.279085704258506, 52.58678790501186, 56.1596280506679, 58.16902623857771, 60.613492829459055, 53.85235364096505, 44.99063158035278, 32.46859850202288, 29.55959619794573, 37.89230326243809, 55.13441440037319, 59.15196010044643, 61.11904375893729, 57.26540258952549, 66.70850821903774, 57.751686164310996, 61.83827958788191, 42.58466843196324, 10.664215922355652, 32.0176499911717, 50.762232644217356, 34.158139841897146, 40.80407789775303, 40.72235666002546, 68.36310359409877, 15.195788485663277, 0.9791641384363174, 0.2855972892471722, 0.09037639293819666, 0.11482922759439264, 0.24596088326403073, 0.19975194281765393, 0.17353757018489496, 0.21151651867798396, 0.12953966323818478, 0.15484299404280527, 0.08919667159872395, 0.21686952215220245, 0.1591687633522919, 0.12810677369790419, 0.12092138640582561, 0.10703625290521554], [0.07338306693626301, 0.022759470789294158, 0.04864002285259111, 0.02188939381656902, 0.03252561004566295, 0.05647083943975823, 0.04298020280631525, 0.09935275984129735, 0.07019627293837921, 0.04213193903810211, 0.06137400133801358, 0.06623214243778161, 0.011082679548832988, 0.037205618739660294, 0.047409564057098966, 0.030390935484319925, 0.0893133185537798, 0.030219642711537223, 0.08492832670786551, 0.12547025802944387, 0.021003115123936107, 0.1534841326730592, 39.544195788247244, 58.10910497392927, 33.587828227451865, 34.74982411520821, 40.183777468545095, 23.237647431237356, 13.792222840445381, 55.38754769733974, 70.34302752358573, 62.97827747889927, 64.98177664620536, 62.22408526284354, 60.656238147190635, 60.41318321228027, 59.71773106711251, 39.75946487699236, 9.726489646094185, 11.520548394748143, 36.91683176585606, 62.935497420174734, 70.22646454402378, 65.19627448490688, 63.476789883204866, 51.965424401419504, 53.27367639541626, 57.34777348382132, 63.969229561941965, 59.59705475398472, 58.798588616507395, 55.19372769764492, 56.02244281768799, 56.84340027400425, 55.541353021349224, 57.04087502615792, 59.02464130946568, 59.605531556265696, 55.488633564540315, 50.64567313875471, 50.867157391139436, 52.476401873997276, 52.51448147637503, 53.35517181668963, 50.23053216934204, 44.22672578266689, 43.45357193265642, 48.775238922664094, 54.94847365788051, 52.787774971553254, 54.2612829208374, 50.227551392146516, 47.86106095995222, 42.79124185017177, 37.31429304395403, 39.734652859824045, 39.250359943934846, 37.712442193712505, 43.46435553686959, 44.82921797888619, 45.28432151249477, 53.450004305158345, 51.13741452353341, 51.6632924079895, 51.04644175938198, 51.50772224153791, 51.507673604147776, 51.294902392796104, 51.446737902505056, 52.098006452832905, 52.41232211249215, 51.533236026763916, 48.539396217891145, 47.8065836088998, 48.45332540784563, 50.86892918178013, 47.702596868787495, 48.531791414533345, 41.80244370869228, 36.62765121459961, 37.60826437813895, 34.81832640511649, 37.34266948699951, 37.25860323224749, 39.198960644858225, 38.944215365818565, 44.30760976246425, 46.048116139003206, 45.87439032963344, 46.366385323660715, 46.036564758845735, 45.34198113850185, 50.44395303726196, 51.32591567720686, 54.10512910570417, 53.417076792035786, 52.80617380142212, 53.0306179864066, 52.714176177978516, 49.405791418892996, 51.17080756596157, 49.31817463466099, 48.40927035467965, 48.58015782492501, 51.11439861570086, 50.00422586713518, 53.84097249167306, 48.70942905970982, 35.41535036904471, 18.158017465046473, 22.431173494883947, 45.79131071908133, 54.408574308667866, 53.55163213184902, 49.62818935939244, 50.20775597436087, 51.61998428617205, 50.37226152420044, 51.25846603938511, 51.98992722375052, 44.104180404118125, 29.84989193507603, 28.693715163639613, 30.113186972481863, 45.77230739593506, 44.96585430417742, 44.53411408833095, 46.27194193431309, 54.29544026511056, 49.21323946544102, 55.03289427076067, 19.18803232056754, 10.162673234939575, 39.67306055341448, 31.75922564097813, 37.848119667598176, 41.882942063467844, 34.11877134868077, 32.46128552300589, 0.6377329709274429, 0.016196888738444874, 0.024066885633926307, 0.030186418244349103, 0.031660240409629684, 0.053647346661559174, 0.07217359862157277, 0.02982664540676134, 0.025266021556620086, 0.013306079349214477, 0.050205484564815245, 0.02755659293117268, 0.08063137478062085, 0.035189263722194095, 0.04471689622317042, 0.04968843409525497, 0.05279704728829009, 0.050159523995327096, 0.025657434482127428, 0.032753662272755585, 0.040480086247303655, 0.05231808977467673, 0.059766545093485286, 0.04310180985235742, 0.043946955752159865, 0.02101795468479395, 0.05869391693600586, 0.038545063829847744, 0.019530784039359008, 0.03125014741505895, 0.06362371811909334, 0.01807992180277194, 0.07939317050789084, 0.0598763320595026, 0.01293610134494624, 0.07831288847540106, 0.01913801234747682, 0.052189578634819815, 0.347248411072152, 42.293146337781636, 71.13651180267334, 35.87531764166695, 39.780521392822266, 40.2494865826198, 24.479844638279506, 26.357326064790996, 57.869294847760884, 78.37479073660714, 68.2778422491891, 70.90337889535087, 66.22606699807304, 65.72780472891671, 62.77976744515555, 63.991352626255576, 43.874340942927766, 10.925303169659205, 11.620595506259374, 41.63309179033552, 66.12115614754813, 71.05171598706926, 67.17052173614502, 65.8525526864188, 53.71156576701573, 55.23364857264927, 59.893930435180664, 65.57059478759766, 62.64477089473179, 60.123721258980886, 59.91241264343262, 58.80472387586321, 58.228134563991, 55.87074279785156, 56.72734451293945, 59.45652743748256, 59.88384165082659, 56.57788528714861, 50.704948220934185, 52.18717268535069, 54.81355006354195, 54.917123385838096, 54.729935441698345, 51.014608587537495, 45.123811176845, 44.839261599949424, 47.59618868146624, 54.23162800925118, 55.02852732794625, 54.34679440089634, 50.881262234279085, 49.288207054138184, 45.27985382080078, 39.280466488429475, 39.75564684186663, 40.27562917981829, 40.64511701038906, 45.35717337472098, 50.37281738008772, 47.036219460623606, 59.00709710802351, 55.43357603890555, 53.6193527494158, 54.36391128812517, 54.00707960128784, 55.298746245247976, 54.039426939828054, 55.77838386808123, 56.11376299176897, 53.92515686580113, 54.962974548339844, 52.405624049050466, 50.53899049758911, 52.40713875634329, 54.92312315532139, 52.0061616897583, 52.68934679031372, 45.49267714364188, 40.080238887241904, 40.353872844151084, 38.67859615598406, 40.704711709703716, 40.80116660254342, 41.56055954524449, 42.36973633084978, 47.56217724936349, 50.109664780753, 48.67365625926426, 47.93703951154436, 48.35929543631417, 48.04384027208601, 52.63615485600063, 53.057288646698, 54.94108077457973, 55.5681209564209, 55.51782642092024, 53.14519378117153, 53.870658670152935, 50.618088790348594, 51.64603655678885, 51.373462200164795, 49.25995915276663, 51.68879229681832, 51.57591881070818, 52.66731752668108, 53.46982751573835, 48.77916465486799, 40.86354405539376, 23.169754845755442, 26.98066633088248, 51.97373792103359, 57.51642710821969, 56.193034989493235, 51.26223891122, 53.11326333454677, 52.675071716308594, 52.04409537996565, 54.71396500723702, 57.41639389310564, 45.620034149714876, 34.78482566561018, 32.60833024978638, 34.43114151273455, 49.12612295150757, 49.40028149741036, 48.211225850241526, 50.35250084740775, 59.389616285051616, 54.47631924492972, 59.31467996324812, 27.00936586516244, 17.962793929236277, 24.387270314352854, 29.665097645350865, 43.49022715432303, 41.93214225769043, 41.75525849206107, 40.417407172066824, 1.3428190648555756, 0.08669557794928551, 0.09916536203984704, 0.023796833785516874, 0.015265655404488956, 0.016722726236496652, 0.05289317534438201, 0.036846660144094906, 0.009989705518819392, 0.022632167441770434, 0.02745053790775793, 0.057625780680349896, 0.07041232527366706, 0.01578476862050593, 0.045239408899630816, 0.019641344535297582, 0.0356431934716446, 0.11996600909956864, 0.08050290774554014, 0.12622398829885892, 0.08293693499373538, 0.1373839351747717, 0.12143498313214098, 0.171004911086389, 0.19082510897091456, 0.11459013899522168, 0.174232756452901, 0.127555124727743, 0.12028141931763717, 0.09570731009755816, 0.15684872998722962, 0.19596414321235248, 0.13697605420436176, 0.2368516863456794, 0.10503493422376257, 0.20672417511897428, 0.13567429834178515, 0.07299218326807022, 0.5480252131819725, 63.02407305581229, 75.38809367588588, 50.081052098955425, 47.0801112311227, 55.992701053619385, 33.54018790381295, 21.044377326965332, 67.50124904087612, 79.69599764687675, 74.13313089098249, 75.91189752306256, 74.14286531720842, 69.90460314069475, 69.2421966280256, 68.83202362060547, 47.40397718974522, 11.977638244628906, 13.874672770500183, 40.880879810878206, 68.0562572479248, 75.39616053444999, 70.99909033094133, 70.27414308275495, 57.12442364011492, 58.12286935533796, 63.909252711704795, 68.79250226702008, 66.77408531733921, 61.17025893075125, 63.74904809679304, 62.78016349247524, 60.200366837637766, 58.48553058079311, 60.046714373997276, 63.604671478271484, 63.590858459472656, 60.08123302459717, 54.882017612457275, 56.44206190109253, 57.58331741605486, 57.050175189971924, 55.88496576036726, 54.94907815115792, 47.21788011278425, 47.662318161555696, 51.52485997336251, 58.95811925615583, 58.77831377301897, 56.98472315924508, 52.69315092904227, 52.14118603297642, 47.27275698525565, 41.99440853936331, 42.66569137573242, 43.7490371295384, 41.46991334642683, 47.92335156032017, 51.81017732620239, 48.50350877216884, 55.549218382154194, 58.02320786884853, 55.25402416501726, 57.12384346553257, 55.76317426136562, 55.70047719138009, 55.39860575539725, 57.37423917225429, 56.420748301914756, 57.03278037479946, 56.132262570517405, 54.11534295763288, 53.603628976004465, 54.01956898825509, 54.89213766370501, 54.527534416743684, 54.663486344473704, 47.928972652980256, 42.83481052943638, 43.6606456211635, 40.60869107927595, 43.15040118353707, 41.09745168685913, 44.56146567208426, 43.34446437018258, 51.08481318610055, 49.61247253417969, 49.53510086877005, 50.64288343702044, 50.94683238438198, 50.130259241376606, 54.61523805345808, 54.933066027505056, 58.33890274592808, 58.08741617202759, 57.548180375780376, 55.20811741692679, 57.59298930849348, 52.24300146102905, 54.494308131081716, 54.43818405696324, 52.50802312578474, 54.94579512732369, 58.761165618896484, 58.4756224496024, 59.79033974238804, 54.14790569032942, 42.00722449166434, 28.814051015036448, 33.6981725692749, 55.93374558857509, 62.436095646449495, 59.57641165597098, 55.1782922744751, 55.21074383599417, 56.551513399396626, 56.173482758658274, 58.743148939950125, 61.398799078805105, 51.19979545048305, 39.19980485098702, 37.71909161976406, 37.278596673692974, 54.8277382850647, 52.75257192339216, 51.88537073135376, 54.265830516815186, 65.91276577540806, 58.11287089756557, 65.20021411350795, 25.995076520102366, 14.487826108932495, 50.90494516917637, 47.76486315046038, 49.18600252696446, 54.56128876549857, 48.27384301594326, 59.418187277657644, 3.4737985687596455, 0.24260715608085903, 0.2315234493996416, 0.10947703836219651, 0.14093770805214131, 0.17302682330565794, 0.11175811703183822, 0.11090198225740876, 0.14941615238785744, 0.13238281996122428, 0.11158013051109654, 0.12984059351895536, 0.20115762310368673, 0.0879920276680163, 0.15332796105316707, 0.08833322221679346, 0.1798888479492494], [0.045175185560115745, 0.021995657489502003, 0.035272489434906414, 0.007818490150384605, 0.08041918330958911, 0.09861410661999669, 0.08320944822792496, 0.0369138860010675, 0.04502393671178392, 0.01336513988540641, 0.04914080883775439, 0.04387484444305301, 0.07197938832853522, 0.05171613082555788, 0.02965395145916513, 0.0764437009181295, 0.043671775875347, 0.11590963176318578, 0.037867030927113125, 0.05132817842864564, 0.09977114453379597, 0.3171880883829934, 9.794399602072579, 68.44015216827393, 42.47831235613142, 38.352701323372976, 40.97132798603603, 49.610798018319265, 8.545536467007228, 28.75321432522365, 52.11116634096418, 69.07865687779018, 67.4758950642177, 61.813599586486816, 65.56880215236119, 65.70028291429792, 60.480240276881624, 44.05226346424648, 13.403504133224487, 7.913404124123709, 34.391307490212576, 61.38638264792306, 72.12583105904716, 64.60139751434326, 61.900688307625906, 54.2928729057312, 53.94822835922241, 59.37463596888951, 63.78255231039864, 58.76185349055699, 57.096189635140554, 57.39532348087856, 60.5072409766061, 58.61444050925118, 60.158219064985005, 61.79350539616176, 64.1023223059518, 61.098053250994, 59.41346250261579, 56.4147242137364, 52.49653775351388, 50.39762592315674, 50.749291624341694, 51.37346567426409, 44.50389984675816, 44.27662427084786, 50.5957225390843, 56.83476366315569, 54.36131266185215, 53.50003480911255, 54.39677626746041, 52.96661465508597, 52.37218236923218, 43.087044034685405, 39.4975004196167, 38.1774434362139, 38.08054733276367, 40.363565581185476, 44.90524516786848, 48.1161675453186, 49.36834062848772, 52.51192453929356, 49.92852176938738, 51.33006375176566, 51.97431114741734, 54.23982688358852, 50.34182146617344, 53.16771289280483, 53.633777209690635, 54.18370280947004, 53.32753883089338, 48.190704345703125, 52.92818764277867, 51.82127707345145, 50.280732904161724, 51.07431445802961, 50.24176740646362, 50.85469232286726, 46.944374697549, 38.86979668481009, 38.119988782065256, 37.72509486334664, 38.27619470868792, 37.51240355627877, 41.43633965083531, 41.21267713819231, 42.34588663918631, 44.7188458442688, 45.78938954217093, 44.96753576823643, 47.44229303087507, 48.23328638076782, 50.277964047023225, 52.979715483529226, 52.80776841299874, 51.441349574497764, 49.60010821478707, 50.26518978391375, 49.43741961887905, 48.016353198460166, 48.42735651561192, 49.72328587940761, 49.58440181187221, 50.25098419189453, 48.371812616075786, 50.234687192099436, 47.37660823549543, 50.44115291322981, 48.705291407448904, 29.140911647251674, 20.86649649483817, 51.29587861469814, 55.40284415653774, 53.64339004244123, 51.519711358206614, 52.586249419621055, 51.28328847885132, 53.86405440739223, 51.56567716598511, 52.06366845539638, 46.13348865509033, 37.18361479895455, 32.970091683524, 29.050004890986852, 44.832976954323904, 47.70407336098807, 49.8550306728908, 51.66364676611764, 49.595543248312815, 53.24294103894915, 41.400080476488384, 7.975703409739903, 20.924809251512798, 37.09529277256557, 31.214969771248953, 33.90263373511178, 40.090160914829795, 39.38566221509661, 15.11350096975054, 0.26812976226210594, 0.18179931757705553, 0.044552110601216555, 0.04922501503356865, 0.04387331434658595, 0.028571884879576306, 0.0549842404600765, 0.03696372439818723, 0.05303657354254808, 0.028201744026903595, 0.06577020258243595, 0.046744884723531346, 0.04485686442681721, 0.041054856298225265, 0.05241596166576658, 0.04953403684443661, 0.1222893265741212, 0.03628176956304482, 0.03917671886405774, 0.03725157252379826, 0.011086712591350079, 0.041563045100442, 0.08734198433480092, 0.050988212028252225, 0.0638830406325204, 0.056109319374497445, 0.031802837936473746, 0.01957825434926365, 0.06549655619476523, 0.060683598741889, 0.018513122307402746, 0.04021111496591142, 0.07539234483348471, 0.041317734335150035, 0.07592145287032638, 0.022881822527519295, 0.07796463716242995, 0.05281519131468875, 0.2633155291633946, 10.170169472694397, 74.76985686165946, 51.42968354906355, 40.76113108226231, 50.23761238370623, 36.68118013654436, 18.039185898644583, 41.665706634521484, 57.88856220245361, 75.45754786900112, 71.40515000479562, 69.75689138684953, 68.82470716748918, 70.38613414764404, 64.52222973959786, 49.5041674886431, 13.832297444343567, 9.868148650441851, 35.99615028926304, 63.721755572727744, 73.70288453783307, 66.500333241054, 63.11327402932303, 56.270236424037385, 54.45129878180367, 62.17206409999302, 66.85754013061523, 60.76816667829241, 61.702497891017366, 60.47582817077637, 59.996326037815635, 60.20398684910366, 62.60571507045201, 63.07243251800537, 63.11111313956124, 62.379328863961355, 60.68551785605294, 58.15882280894688, 54.679401193346294, 52.50823851994106, 53.41843516486031, 52.553492137363975, 46.840558188302175, 46.22845663343157, 52.092010157448904, 58.1232966695513, 56.64536271776472, 55.345392976488384, 56.50661761420113, 55.697843824114116, 53.73357766015189, 44.047354561941965, 40.79090758732387, 40.39227901186262, 40.432411806924, 41.75689131872994, 48.229558672223774, 50.29410471235003, 55.61352048601423, 58.15770762307303, 54.12445204598563, 56.837348393031526, 56.170661790030344, 57.38588087899344, 55.43925271715437, 58.105085441044395, 55.778706959315706, 56.64279883248465, 56.82554340362549, 51.39027336665562, 53.24977806636265, 53.71410880770002, 54.38159097943987, 53.73689889907837, 54.42427723748343, 54.97644363130842, 48.02945055280413, 42.05197089059012, 41.209171772003174, 39.38492570604597, 41.474926471710205, 40.216249874659944, 42.3744089944022, 43.5901700428554, 44.72762489318848, 46.68489074707031, 46.703029019492014, 46.34531838553292, 49.31662171227591, 52.0639637538365, 53.04599782398769, 53.11628580093384, 54.9152786391122, 54.81171573911394, 53.12110785075596, 52.98739671707153, 51.41912228720528, 51.23903540202549, 51.715105124882285, 48.54414531162807, 49.741990430014475, 53.85386834825788, 51.99364103589739, 54.01241929190499, 53.460878235953196, 52.35244601113455, 51.19717945371355, 31.309996809278214, 27.317007780075073, 52.64550713130406, 58.33353178841727, 55.09357636315482, 54.072569847106934, 55.62879957471575, 53.05324132101876, 57.0252172606332, 56.688038553510395, 54.74282782418387, 48.47176245280674, 39.60025038037981, 34.833032267434255, 33.330515589032856, 50.07439225060599, 52.34739467075893, 53.336435999189106, 54.0970344543457, 54.21112387520926, 55.8979206766401, 47.74489402770996, 17.551142692565918, 21.804795128958567, 22.641608374459402, 33.77525588444301, 33.13343341009957, 41.94029596873692, 50.68432944161551, 21.328494378498622, 0.3850174072597708, 0.12826092328344071, 0.03337757522240281, 0.042953451563205035, 0.0749455973772066, 0.10332834401300975, 0.06372854499412434, 0.021448235792507018, 0.04389297829142638, 0.01537435332180134, 0.051400435622781515, 0.027945839633632983, 0.030836152844130993, 0.029858431379709924, 0.06973928638866969, 0.03429938540128725, 0.06024970273886408, 0.09984701153423105, 0.13142209579902037, 0.11413200572133064, 0.158597219735384, 0.17150519495563848, 0.13902484998106956, 0.27093284470694406, 0.1680961807391473, 0.13208026119640895, 0.14097464749855654, 0.09790359903126955, 0.10539875113006149, 0.23446983844041824, 0.12354647554457188, 0.1960164311208895, 0.16611742334706442, 0.17074596855257237, 0.19056121313146182, 0.13710288597004755, 0.15788357731487068, 0.21528169592576368, 0.4685808132801737, 19.710974591118948, 88.74361528669084, 57.54133292606899, 55.63373626981463, 55.49419559751238, 67.45564106532505, 11.131108811923436, 43.29684141704014, 60.51669747488839, 82.68156215122768, 77.42060852050781, 73.65553951263428, 75.0699634552002, 75.9462285723005, 71.38493769509452, 54.88910477502005, 15.789293187005178, 11.769891449383326, 36.54294572557722, 67.05519553593227, 76.45162664140973, 70.27736704690116, 67.31480802808488, 59.665334701538086, 58.919188499450684, 66.24882929665702, 69.98768275124687, 63.519639423915315, 62.500804219927105, 66.09651783534459, 66.28985840933663, 64.82846464429582, 64.81122616359166, 65.59934643336705, 66.54909569876534, 66.06933648245675, 62.39362130846296, 62.4831280027117, 59.04141426086426, 53.581321784428184, 56.5048770904541, 56.45158788136074, 49.95837817873274, 49.10463912146432, 56.797670704977854, 60.91739313943045, 60.44385950905936, 58.073082038334434, 59.43586349487305, 56.887170451028005, 57.29879215785435, 47.81871863773891, 44.186624254499165, 43.3091709954398, 43.03472062519619, 46.65663242340088, 50.4621399470738, 56.0607829775129, 55.41176216942923, 58.047891344342915, 55.576615129198345, 58.67849595206124, 58.772150720868794, 61.553340911865234, 56.05313648496355, 59.207031522478374, 57.786253452301025, 58.77776486533028, 57.78146614347185, 52.702506678445, 57.693244865962434, 57.92165299824306, 55.26834440231323, 56.62010601588658, 56.20692443847656, 55.7435108593532, 51.67881120954241, 46.74142129080636, 43.963771206992014, 41.66537659508841, 45.12406826019287, 43.628454617091585, 46.85042463030134, 46.63986642020089, 46.571503094264436, 48.320858001708984, 49.10127966744559, 47.42931727000645, 52.21096331732613, 53.75175067356655, 54.33203295298985, 56.255624362400596, 57.064154965536936, 56.62261084147862, 56.24502488545009, 53.791192122868125, 52.03068535668509, 50.284550939287456, 54.67133433478219, 51.69746364865984, 52.799086638859336, 56.160663332257954, 57.318657057625906, 60.07752268654959, 61.84201771872384, 58.63614668164934, 56.52237960270473, 36.01853043692452, 33.30659294128418, 57.590498379298616, 60.12308897290911, 58.0027106830052, 57.91487850461687, 60.32810252053397, 58.786658559526714, 60.10154260907854, 60.02145072392055, 58.34182793753487, 52.13931001935686, 46.068370137895855, 38.33190883908953, 36.96310329437256, 54.5885500226702, 58.25386721747262, 57.81202779497419, 60.00955540793282, 57.75657074792044, 63.75341156550816, 50.20220783778599, 12.071652582713536, 25.10192206927708, 48.47380174909319, 46.0092305455889, 46.30639805112566, 55.09057821546282, 61.34237275804792, 36.590044089726035, 0.5754227744681495, 0.26633498285497936, 0.19561753395412648, 0.22899387085012027, 0.15134525458727563, 0.2748800186174256, 0.14951596488910063, 0.08749424759298563, 0.10484903598470346, 0.05775027150022132, 0.1315836278455598, 0.12120808102190495, 0.24329638481140137, 0.17299896265779222, 0.1456112265586853, 0.1317846370594842, 0.17959904564278467], [0.016442688048950264, 0.03966640401631594, 0.026089639236618365, 0.007241846494642752, 0.03956201479637197, 0.06980250549635716, 0.03369524156940835, 0.023179144698328207, 0.0034860334542047766, 0.004694252840376326, 0.007828032897253121, 0.06617036182433367, 0.02217421567599688, 0.07062243364219155, 0.008970341512135096, 0.02289877911763532, 0.03167743787967733, 0.07045866243009057, 0.024507638233314668, 0.03923121879675558, 0.0873761350022895, 0.0698525949514338, 0.15855116077831813, 44.508475235530305, 55.29598086220877, 46.76235621316092, 37.681967394692556, 46.7815123966762, 26.094784906932286, 11.82779165676662, 57.4010522706168, 55.13328879220145, 67.42766761779785, 65.84818226950509, 64.72155966077531, 61.01015159061977, 58.33772850036621, 48.687799317496165, 18.96328067779541, 8.219652925218854, 30.165281091417583, 62.449311120169504, 71.78206893375942, 64.18538802010673, 65.64990847451347, 56.99573605401175, 54.7467222894941, 63.638689858572825, 65.52964905330113, 63.80869838169643, 59.235123089381624, 59.477101053510395, 60.95742171151297, 62.100449017116, 61.80017566680908, 61.961339133126394, 62.22070149012974, 63.337047713143484, 61.597642626081196, 59.28758198874337, 56.92249509266445, 52.56883028575352, 51.58596937997, 50.24195500782558, 48.04488945007324, 53.845002446855815, 54.03485155105591, 54.78363459450858, 55.8279766355242, 56.387132917131694, 53.47648388998849, 56.2676864351545, 50.06734330313546, 41.441936424800325, 39.70853110722133, 38.33023084912981, 38.328955854688374, 38.82911845615932, 42.035375118255615, 47.096046924591064, 48.06579657963344, 50.657822063991, 51.139127254486084, 52.76004818507603, 50.32098729269845, 52.00025224685669, 49.698477336338584, 52.41760969161987, 53.77643414906093, 52.731317383902415, 53.93138245173863, 49.650242941720144, 49.617402281079976, 53.68844216210501, 51.7426130431039, 52.59462547302246, 50.925209590366904, 50.086746147700715, 48.17337901251656, 39.000572204589844, 36.07910483224051, 37.68642813818795, 37.405262334006174, 39.40555143356323, 37.713564327784944, 40.506257261548726, 41.48749228886196, 42.068441595349995, 44.34880215781075, 45.54774856567383, 49.716393266405376, 51.64981985092163, 50.35487365722656, 52.32696349280221, 50.601687567574636, 50.87202113015311, 47.796776226588655, 46.52635717391968, 41.65983888081142, 40.01376894542149, 41.84566845212664, 48.08659948621477, 48.44042607716152, 51.15806804384504, 51.53620638166155, 48.94061647142683, 48.098797048841206, 45.93728542327881, 45.53994573865618, 40.89229222706386, 26.066931315830775, 50.891476086207796, 60.463647978646414, 57.019022941589355, 52.275623253413606, 56.44792965480259, 52.89802898679461, 58.30874061584473, 52.11729465212141, 49.04659039633614, 39.283659185682026, 27.970939227512904, 14.669830696923391, 30.207616465432302, 41.42686925615583, 48.42285408292498, 53.01771170752389, 58.597570283072336, 45.03552736554827, 62.36762114933559, 20.972781351634435, 7.865181888852801, 33.60990265437535, 35.90653589793614, 40.13305214473179, 33.90708405630929, 25.58841061592102, 35.39792081287929, 3.6894982286861966, 0.17875981996101992, 0.08132616749831609, 0.008959629140528185, 0.07748183235526085, 0.034826875132109435, 0.023657586525327394, 0.011371553958659726, 0.019867603733603443, 0.062480393398020945, 0.014390893147460051, 0.023367679045934762, 0.07860117764877421, 0.008475493556553764, 0.03816564740347011, 0.04223222312118326, 0.042870317452720234, 0.05457536543586424, 0.017996326288474456, 0.037588885852268765, 0.033654980694076846, 0.013030642477263297, 0.08340037441147224, 0.05325129255652428, 0.04711338352145893, 0.029780410030590634, 0.013672042970678635, 0.04024430211367352, 0.02127258512856705, 0.03803877492568322, 0.028895817497479062, 0.04464675945096782, 0.03926089113312108, 0.043527142743446996, 0.03822074105430927, 0.045364934485405684, 0.10216827983302729, 0.028074182836072784, 0.12996792740055493, 0.04614917847460934, 0.08508204203099012, 49.81520012446812, 65.10499600001744, 43.14276163918631, 40.91709034783499, 35.77268580027989, 24.54277273586818, 30.17411572592599, 56.04271418707711, 64.48024872371128, 69.16023567744664, 71.97780663626534, 66.48978587559291, 65.93580600193569, 63.399595396859304, 56.14546414784023, 19.855491910661968, 10.10842170034136, 30.61873095376151, 63.97453103746687, 72.9774648121425, 68.16465609414237, 65.39494432721818, 58.28790296827044, 56.349327768598286, 65.51887239728654, 65.79977416992188, 64.55155113765171, 61.03316402435303, 60.98889010293143, 61.82055473327637, 61.34754916599819, 62.29387991768973, 62.05520234789167, 62.809693336486816, 62.5759003502982, 63.258713722229004, 61.26595646994454, 57.37695939200265, 55.10172660010201, 53.259008748190745, 49.65175764901297, 49.587816851479666, 53.0756562096732, 56.90233142035348, 55.614722524370464, 58.71698897225516, 58.30125740596226, 56.390777247292654, 58.039265155792236, 53.95808437892369, 44.79227440697806, 41.68533876964024, 41.825358867645264, 39.85803549630301, 41.744606903621126, 45.78440073558262, 52.617558002471924, 55.230358600616455, 54.40197352000645, 54.348698207310264, 53.5484151159014, 54.52309799194336, 55.191486903599326, 54.63013499123709, 55.2085725239345, 57.15355396270752, 56.25858429500035, 57.26309926169259, 51.97779219491141, 53.2234582901001, 55.915902614593506, 54.31418997900826, 54.73214149475098, 55.91766050883702, 54.925006117139546, 51.148055689675466, 42.13828488758632, 40.73223352432251, 41.04566328866141, 39.95713765280587, 42.58198990140642, 41.45316818782261, 44.1639974457877, 44.15995706830706, 46.145161628723145, 46.006399154663086, 49.023150648389546, 51.36849423817226, 53.90397528239659, 52.585460799080984, 55.81966659000942, 53.66873359680176, 52.57431936264038, 51.74731002535139, 51.01832587378365, 45.41371781485421, 43.90174811226981, 46.32268115452358, 50.690370900290354, 48.68001038687569, 52.766801834106445, 54.445952142987935, 52.80405112675258, 51.776485511234824, 51.076940877096995, 48.32733024869646, 41.34339707238333, 30.446547644478933, 53.14604493549892, 61.9059967313494, 58.60670716421944, 54.02899421964373, 58.77452005658831, 54.85422134399414, 59.911981855119976, 56.41524185453142, 55.3849629674639, 41.59318481172834, 28.348264626094274, 17.895552737372263, 35.000532490866526, 46.74417625154768, 52.780298709869385, 55.98016650336129, 59.451587268284385, 50.584827763693674, 61.152089391435894, 31.167159216744558, 14.981184686933245, 21.048257895878383, 26.5825606073652, 44.86501509802682, 31.27208743776594, 33.48536661693028, 46.06907190595354, 5.256065573011126, 0.14752382678644999, 0.05794944866959538, 0.04672130563163331, 0.08073143155447074, 0.02111477654294244, 0.0446008362009057, 0.00815495106923793, 0.04039359678115163, 0.05062542649518166, 0.03322529839351773, 0.030388458831501857, 0.029740854831678525, 0.05256955824526293, 0.06808004435151815, 0.04951216087543538, 0.027514613665906445, 0.009023510668027614, 0.1164861558271306, 0.15575050748884678, 0.1676899418234825, 0.15880078024097852, 0.20360963152987616, 0.15282188249485834, 0.15807146366153443, 0.10955859148608786, 0.16182191669940948, 0.13067912709500107, 0.1710684626762356, 0.13948530384472438, 0.12761148384639195, 0.12523150869778224, 0.0705844017543963, 0.17968606097357614, 0.18371073715388775, 0.16639590768941812, 0.11931749247014523, 0.11418200018150465, 0.2744223331766469, 0.18291607765214785, 0.48374514813934055, 74.15360028403146, 67.49969264439174, 67.50634901864188, 48.978334767477854, 67.04434939793178, 31.344362599509104, 20.998790196010045, 69.83950546809605, 62.89533683231899, 78.14406885419572, 77.72253554207938, 72.26987416403634, 69.16691289629254, 70.19100788661412, 61.63955415998186, 23.518366813659668, 10.887177535465785, 34.67293534960066, 67.96385315486363, 77.04222352164132, 70.88051932198661, 70.8062778200422, 62.22440487997872, 59.49847371237618, 70.75318663460868, 68.95875876290458, 68.42192704336983, 62.61060660226004, 66.4034058707101, 66.73811449323381, 65.6019172668457, 66.54152216230119, 64.68631839752197, 65.30310998644147, 64.6005220413208, 65.68988146100725, 64.20191778455461, 59.978781836373464, 58.9351624080113, 55.56807926722935, 54.9088967187064, 53.707473278045654, 58.48937293461391, 57.2805427142552, 57.487046650477815, 61.28072139195034, 59.59350422450474, 57.5267972946167, 60.50230080740792, 57.2939145224435, 47.1187675339835, 44.127248423440115, 43.78069312231881, 42.200644969940186, 43.535157680511475, 47.237227371760774, 54.95935801097325, 51.8847245488848, 55.93259913580758, 55.66183825901577, 55.69130209514073, 55.8953845841544, 56.81785869598389, 55.10347407204764, 58.99264485495431, 58.64424133300781, 56.175754819597515, 57.53959240232195, 54.3964010647365, 55.70542083467756, 57.78284536089216, 56.82041563306536, 56.529438972473145, 57.67515870503017, 55.82491595404488, 54.22014263698033, 45.712181159428184, 40.579043115888325, 43.79185192925589, 42.399947098323274, 43.2026481628418, 41.46352795192173, 46.73358372279576, 46.26977757045201, 47.0317656653268, 48.054787158966064, 50.6853404045105, 53.73578718730381, 57.64384664808001, 54.29085792813982, 56.08549771990095, 54.53824506487165, 52.57117877687727, 50.24342107772827, 50.596156801496235, 46.77261175428118, 46.32990033285958, 46.58197750364031, 51.957399232046946, 52.58818449292864, 56.34610380445208, 58.9328556060791, 58.91772242954799, 58.07382549558367, 61.04307215554373, 53.96920149666922, 46.05393178122384, 33.564291204724995, 56.182425090244834, 66.03743730272565, 62.10819625854492, 56.72133084705898, 62.44383593967983, 57.09929895401001, 65.68948541368756, 60.61398615155901, 60.32211317334856, 46.20423173904419, 35.36668171201433, 21.942319086619786, 37.90582793099539, 50.790348529815674, 56.27599648066929, 60.896215030125205, 67.77811391013009, 54.94041722161429, 71.90949194771903, 27.641561610358103, 10.569636174610682, 40.03986985342843, 53.01929242270333, 54.89911365509033, 48.03947332927159, 40.39225469316755, 66.49291951315743, 10.999152098383222, 0.48657800470079693, 0.20052018016576767, 0.11280193459242582, 0.24255238473415375, 0.08574953728488513, 0.12463914762650218, 0.12913440141294683, 0.160037437453866, 0.1904614684837205, 0.1734711823186704, 0.18921679098691258, 0.13978235290518828, 0.1300379250730787, 0.12730082337345394, 0.17365384394569056, 0.11705577240458556, 0.11721796941544328], [0.007586243728707943, 0.01779153254548354, 0.019596690145720328, 0.0353298256439822, 0.007628076260776392, 0.01940433564595878, 0.04903606677960072, 0.07159419756914888, 0.02971736734200801, 0.04010581990171756, 0.035023755460445366, 0.025634628920150653, 0.01898649717415018, 0.03860791313595005, 0.046220998013658185, 0.029947818190391575, 0.02535830401549382, 0.05027818959206343, 0.027297831905473555, 0.04823309522388237, 0.13861023794327462, 0.11345792189240456, 0.19869261394654, 14.733684641974312, 68.94595323290143, 36.76491982596261, 65.61280509403774, 59.70614147186279, 49.69436747687203, 9.44080490725381, 44.433879375457764, 66.87528582981655, 56.318422181265696, 70.17389447348458, 61.5586701801845, 66.97324848175049, 59.96304416656494, 56.15718923296247, 23.112397466387065, 4.589445846421378, 27.79129876409258, 61.337460381644114, 64.09521429879325, 68.5606061390468, 60.64835888998849, 60.70070661817278, 54.98879058020455, 61.148497172764365, 67.17658751351493, 63.86070564814976, 57.782504899161204, 65.39547933850969, 64.49482604435512, 62.268915040152415, 59.18070479801723, 57.806635992867605, 61.32001345498221, 60.18387876238142, 59.34821891784668, 60.507803780691965, 59.73194013323103, 55.51877137592861, 54.94827216012137, 50.82486718041556, 51.79348775318691, 54.51232828412737, 56.987749099731445, 54.718092237200054, 54.57482385635376, 55.05504165376936, 53.758615493774414, 54.803485597882954, 50.462365763528005, 42.83679076603481, 39.869093554360525, 40.62993172236851, 38.38000774383545, 39.06582621165684, 41.56767797470093, 45.95687239510672, 47.04515136991228, 48.721352168491904, 50.51389707837786, 51.61757673536028, 49.764891692570274, 50.709989139011924, 49.668019907815115, 52.75379133224487, 53.72836651120867, 55.332566601889475, 54.29900469098772, 53.74500049863543, 47.41801602499825, 53.94296857288906, 54.58499601909092, 53.04613331386021, 52.13644388743809, 48.61203268596104, 47.994125911167686, 39.840932505471365, 37.57967601503645, 37.96966450554984, 36.642096519470215, 39.27092661176409, 39.43523761204311, 39.46887036732265, 40.766623633248464, 42.020700522831504, 45.1531013080052, 50.539886815207346, 54.611555508204866, 54.50303854261126, 50.20425755637032, 47.19009774071829, 47.22453996113369, 43.056798526218955, 37.44277218409947, 31.150813579559326, 27.683077096939087, 30.236781529017858, 42.13502618244716, 44.169507367270334, 49.04292174748012, 50.535964557102744, 51.807033266339985, 52.360790797642295, 45.46177155630929, 40.41611133302961, 39.647432122911724, 38.52552386692592, 25.36063129561288, 44.01648718970162, 61.08369132450649, 56.66308409827096, 56.273710523332866, 52.80367939812796, 55.799200671059744, 57.47339691434588, 52.0410590171814, 44.66480622972761, 33.80541454042707, 9.606137292725698, 10.553817731993538, 36.2228422164917, 40.35130895887102, 48.66573878696987, 50.77724422727312, 53.454437255859375, 56.4681384904044, 48.56726891653878, 6.411611795425415, 23.62730588231768, 34.2662399155753, 42.4611051423209, 44.17792510986328, 29.104218210492814, 38.483299664088655, 10.663808584213257, 0.6071953124233654, 0.12516072392463684, 0.09562361958835806, 0.008887623004349214, 0.017293820323954736, 0.05356032793809261, 0.04218476638197899, 0.029964248915868144, 0.030324727429875305, 0.025397547088297348, 0.08399694918521813, 0.06518481006579739, 0.038959774255220375, 0.07700647107724633, 0.04615978058427572, 0.06709221271531922, 0.03791103731574757, 0.015040008584037423, 0.06464649430875267, 0.08912347124091216, 0.01762710145807692, 0.059112674822764735, 0.08052057001207556, 0.022549728829679743, 0.035154485409813266, 0.01837516256741115, 0.03382265687521015, 0.027904735678540807, 0.020419115300423334, 0.03831686571772609, 0.02871894377416798, 0.07120199075766973, 0.014276709274521895, 0.01765883314822401, 0.010150358862509685, 0.030254482092069726, 0.04074509488418698, 0.06679145206830331, 0.20756051024155958, 0.13715422392955848, 0.24802642528499874, 17.75755282810756, 79.14990397862026, 41.20491252626692, 54.245302064078196, 56.85170684541975, 32.048135212489534, 19.22649233681815, 62.709430830819265, 65.22909777505058, 66.384416443961, 76.09942245483398, 66.50988006591797, 70.45628316061837, 63.68594455718994, 60.36132880619594, 26.59449587549482, 4.868076426642282, 29.73014668055943, 63.41396427154541, 68.11994443620954, 69.15050819941929, 62.904577936444966, 63.351110867091585, 56.1043620790754, 63.855814116341726, 68.8759570802961, 65.61188098362514, 60.470665659223286, 65.77155753544399, 62.59812068939209, 62.735361507960725, 61.35882609231131, 60.5798704964774, 63.89278548104422, 63.10565880366734, 62.35227952684675, 63.415743010384695, 61.3250161579677, 57.508082321711946, 56.525881494794575, 54.00375141416277, 54.30160679136004, 58.466325759887695, 58.22502177102225, 58.86595835004534, 56.94399629320417, 57.668773310525076, 57.55895355769566, 58.190058435712544, 52.974914278302876, 44.00956678390503, 42.67574194499424, 42.738772528512136, 41.29957825796944, 43.545357636043, 45.99701908656529, 49.20966461726597, 53.00244998931885, 50.75210217067173, 54.2960273878915, 55.76548801149641, 53.809955733163015, 53.6730032648359, 52.890257426670615, 55.387773513793945, 58.05438791002546, 58.57954665592739, 56.50493267604283, 58.2895496913365, 50.51314319883074, 57.64873817988804, 56.99156366075788, 56.04026147297451, 57.11584956305367, 52.07526847294399, 51.857925346919465, 42.63536596298218, 41.30773196901594, 40.50526714324951, 40.03500264031546, 42.03105681283133, 42.06237581798008, 42.31807994842529, 43.07776124136788, 44.286379541669575, 45.129112652369905, 51.455586433410645, 56.896578311920166, 55.786287443978445, 55.03428043637957, 51.781957217625205, 50.983994824545725, 48.51157910483224, 42.35886934825352, 36.23292405264718, 32.86564983640398, 34.66543476922171, 45.073468003954204, 45.53014530454363, 50.68089008331299, 53.01147222518921, 55.16808884484427, 56.43145547594343, 49.81055872780936, 48.26936490195138, 45.76475122996739, 38.97435317720686, 27.82131324495588, 48.850967339106965, 62.47977202279227, 56.95166015625, 59.027587345668245, 55.44248710359846, 58.89987250736782, 61.09789344242641, 56.65093864713396, 49.97818749291556, 35.91342156273978, 10.917975425720215, 12.436488594327654, 41.66647093636649, 45.857395035879954, 51.49652521950858, 53.45527798788888, 57.77360078266689, 60.3149356842041, 54.49256760733468, 14.623984745570592, 23.485270806721278, 19.2333311012813, 40.106256416865754, 47.472542013440815, 30.468750613076345, 51.25255312238421, 17.483369963509695, 1.023467698267528, 0.11637445539236069, 0.09756734421742813, 0.081976740088846, 0.037747520554278574, 0.059460932921086035, 0.04085530932726605, 0.043099353555589914, 0.03358141053467989, 0.05248298056955848, 0.024498898702274476, 0.07113651212837015, 0.1048519876120346, 0.02281117006870253, 0.07580764219164848, 0.012388414171125208, 0.00966771096656365, 0.02972541137465409, 0.13915189887796128, 0.18193480744957924, 0.10185265248375279, 0.08542977087199688, 0.14973399176129273, 0.1417578804705824, 0.11517390981316566, 0.11566938965448312, 0.07574159359293324, 0.06037403749568122, 0.123898838779756, 0.129846510344318, 0.06845279756401267, 0.17116181552410126, 0.08387612923979759, 0.10290607810020447, 0.16934330096202238, 0.0988927266693541, 0.10912572007094111, 0.10427773664040224, 0.27369507934365955, 0.3001796581915447, 0.41509347196136204, 29.962449278150284, 91.67763805389404, 52.47921242032732, 83.34367683955601, 77.44855417524064, 68.06024551391602, 11.40346256324223, 58.425567626953125, 75.17647239140102, 70.02729443141392, 80.16968413761684, 71.72214072091239, 77.81600270952497, 69.77395616258893, 66.55864252362932, 29.4922125680106, 6.055404143674033, 33.16677781513759, 66.12613105773926, 72.07556779044015, 72.69852243150983, 64.57124928065709, 66.91256291525704, 60.68819291251046, 66.30743735177177, 74.12180532727922, 68.55528381892613, 64.42247445242745, 69.95187868390764, 66.86054870060512, 67.43073177337646, 65.46705968039376, 63.13762051718575, 64.81789643423897, 64.86593627929688, 63.0511918749128, 65.68751907348633, 64.91130106789726, 60.33910846710205, 60.78178514753069, 56.024721826825825, 55.778356075286865, 60.965829031808035, 60.87617642538888, 61.60360418047224, 58.60309410095215, 60.28112574986049, 58.38550431387765, 61.73401491982596, 56.168080534253804, 46.713166441236226, 45.59213713237217, 45.23830706732613, 44.172748701913015, 46.880948066711426, 47.14300979886736, 50.20469529288155, 53.09826912198748, 52.46943283081055, 55.55340467180525, 58.274284499032156, 55.19444336209978, 56.95443248748779, 55.8189891406468, 56.94814089366368, 59.058194160461426, 59.95018999917166, 58.28756250653948, 57.175913265773225, 52.319716521671836, 60.354992049080984, 58.18191167286464, 59.03510529654366, 56.78911747251238, 52.80329377310616, 52.615449224199565, 46.130789279937744, 44.243297236306326, 42.348447050367085, 42.40934106281826, 44.90604073660714, 44.671146460941856, 44.11059011731829, 44.84803370067051, 46.18164661952427, 48.313277517046245, 53.32225819996425, 59.261957032339915, 58.37456784929548, 56.73473392214094, 50.46573911394392, 50.1641525541033, 47.95247840881348, 43.58578225544521, 39.85663196018764, 37.08503723144531, 38.639814785548616, 48.77653476170131, 48.26177052089146, 53.71917404447283, 55.19124024254935, 58.40887805393764, 61.54586465018136, 57.55265154157366, 55.759498664310996, 51.26883275168282, 42.73302984237671, 31.258409908839635, 53.40561921255929, 68.72666113717216, 60.90990992954799, 63.72112328665597, 57.96915783200945, 63.17974744524275, 63.41579859597342, 60.74944823128836, 54.67817483629499, 42.426565647125244, 14.806473970413208, 13.587046010153633, 45.82403326034546, 49.37792566844395, 56.65477057865688, 58.79447528294155, 62.26626777648926, 65.6398127419608, 57.78824758529663, 9.655691845076424, 27.385449273245676, 48.00923129490444, 57.21659844262259, 58.97900554112026, 41.99878590447562, 63.79940169198172, 37.63177708217076, 1.336711815425328, 0.19930761094604219, 0.24125266447663307, 0.20778391111109937, 0.1606062397892986, 0.18482821647609982, 0.1862475217453071, 0.1349303118352379, 0.1480667226548706, 0.11960387496011597, 0.16733649293226854, 0.16618454403110913, 0.2574578177716051, 0.18037640250154904, 0.16213670266526087, 0.16755635184901102, 0.08246449141630105, 0.1746633547757353], [0.08637785392680339, 0.023367185411708694, 0.01306499755342624, 0.06390787501420293, 0.020854819599272947, 0.04593010326581342, 0.023810507962480187, 0.05203217547386885, 0.008079059471908425, 0.02621238791782941, 0.032022571324237754, 0.022056416907746876, 0.0385659186036459, 0.010956466098182967, 0.025616528998528208, 0.030921180067317824, 0.029485888513071195, 0.044247573906821866, 0.026674729805173616, 0.08715463403080191, 0.027189595391973853, 0.023813464678823948, 0.06333912696157183, 3.758156853062766, 72.39972904750279, 43.68372753688267, 58.05945314679827, 63.83287811279297, 52.496888637542725, 29.485455444880895, 10.781681299209595, 73.87577656337193, 56.3098064150129, 68.5461538859776, 64.55339935847691, 68.127121925354, 62.75939532688686, 54.941827705928254, 23.221042973654612, 4.150146424770355, 23.306589194706508, 55.30129623413086, 64.80019242422921, 68.30972058432442, 66.51779406411308, 62.2296507699149, 58.76503576551165, 61.6853358404977, 68.6300047465733, 65.90852737426758, 61.55684975215367, 65.82562841687883, 70.1195317677089, 63.025837898254395, 57.96170588902065, 54.882326807294575, 56.405003683907644, 59.2276885168893, 59.00041988917759, 60.62226840427944, 62.90229892730713, 59.57164519173758, 56.89720712389265, 55.40946231569563, 58.15010976791382, 55.95632028579712, 54.873047488076345, 53.488695349012104, 55.98041663851057, 53.42328153337751, 52.808220045907156, 50.38446603502546, 43.13546255656651, 40.686660289764404, 40.66609014783587, 40.49029377528599, 37.63242326463972, 40.01795523507254, 39.18703406197684, 44.80808155877249, 44.72041961124965, 47.166011810302734, 47.01603146961757, 47.527877467019216, 47.3937702860151, 48.08093670436314, 48.87288890566145, 55.59531273160662, 54.078284740448, 55.13613755362374, 52.26267875943865, 55.388826165880474, 53.33930213110787, 49.696702071598594, 53.53576592036656, 53.320079939705984, 52.962324142456055, 50.917417185647146, 49.35070610046387, 40.935614245278494, 38.73343481336321, 38.245904036930625, 40.21977261134556, 38.820280347551616, 38.807579040527344, 40.09510803222656, 39.92548166002546, 42.39242914744786, 50.36679676600865, 53.53729452405657, 54.2375339780535, 54.26767178944179, 52.71055269241333, 45.87317092078072, 32.13542890548706, 39.17639984403338, 36.94133458818708, 38.294982637677876, 36.01234654017857, 39.890730244772776, 43.733983857291086, 48.24134976523263, 46.16834429332188, 48.8135895047869, 48.77512775148664, 47.04493597575596, 46.71755770274571, 39.27808673041207, 38.80729416438511, 39.20785433905465, 26.02881349836077, 39.5006479535784, 55.85615158081055, 58.95378358023507, 57.09268079485212, 56.24499709265572, 58.50347777775356, 59.34260477338518, 54.1725127356393, 40.908387729099815, 15.567367724009923, 1.6258739105292728, 18.795830828802927, 36.19962133680071, 42.40041262762887, 49.73914514269148, 57.61881576265608, 46.94116810389927, 59.450260162353516, 20.068377767290386, 10.923310773713247, 37.2466801234654, 32.21590641566685, 54.92312315532139, 33.35893372126988, 30.008442878723145, 38.1305569921221, 2.1333735925810675, 0.38272224898849216, 0.08321049995720387, 0.09471878635564021, 0.0633306520591889, 0.03487442347354122, 0.08796945959329605, 0.0508584998814123, 0.013302871574913817, 0.07777379918843508, 0.04195376592023032, 0.13670093539570058, 0.0412669968791306, 0.037916211145264764, 0.0741990731496896, 0.005530564638320357, 0.03238352481275797, 0.04035667769078698, 0.046563644627375264, 0.01792016751798136, 0.009208118842382516, 0.03141281261507954, 0.067049851774105, 0.010140763529177223, 0.038293507149709125, 0.04775489766948989, 0.05144636905086892, 0.027327879132436853, 0.05067709693685174, 0.06631003825792245, 0.015841601017330374, 0.03510050455640469, 0.06227316201797553, 0.0820014930463263, 0.03389446284355862, 0.01884348234826965, 0.03734470484778285, 0.03970336042610662, 0.02158942535918738, 0.027330118297998394, 0.024620770376973918, 0.06660520777638469, 3.2929050411496843, 78.4901864188058, 50.75054924828665, 63.07123047964913, 81.40192631312779, 46.304720061165945, 24.42569211551121, 32.07892615454537, 80.20441123417446, 62.57169669015067, 74.806946345738, 69.14034298488072, 73.13636316571916, 67.54759352547782, 61.947303771972656, 27.748414482389176, 4.964559546538761, 24.874646493366786, 56.64242710386004, 67.85668413979667, 71.23685073852539, 68.17741993495396, 63.96365710667202, 61.45650386810303, 63.06148910522461, 68.79246752602714, 66.3190130506243, 62.98216152191162, 65.05162688664028, 69.86312239510673, 66.28900378090995, 59.311546325683594, 57.11104488372803, 59.21145057678223, 61.73486260005406, 60.38632147652762, 63.87432411738804, 63.67573765345982, 60.18148858206612, 59.831486974443706, 55.76318120956421, 59.76006644112723, 58.32737568446568, 59.08092171805245, 56.0869186265128, 58.139763900211875, 58.63406917027065, 54.28210667201451, 56.17729384558541, 48.16934558323452, 43.54424939836775, 43.698951039995464, 41.6885974747794, 41.97393567221505, 42.986757210322786, 43.27275896072388, 49.32251031058175, 51.006597314562114, 50.717778069632395, 51.425035204206196, 51.106574944087434, 50.90011617115566, 52.820824078151155, 54.10812030519758, 57.87450252260481, 56.418337277003694, 57.27124949863979, 54.940062863486155, 57.93912771769932, 55.468775612967356, 53.37850734165737, 59.346370697021484, 55.77574702671596, 55.79043204443795, 53.190502984183176, 52.27569273539952, 44.157167366572786, 42.15298727580479, 40.71641247613089, 41.14460563659668, 41.431802477155415, 40.94221155984061, 44.86590446744646, 44.00952509471348, 45.200140612465994, 51.631507873535156, 54.24282155718122, 56.275673389434814, 56.058642932346885, 54.585934025900706, 49.22296346936907, 39.63434519086565, 43.11675105776106, 39.95821809768677, 39.27558190482003, 38.497234276362825, 41.26566410064697, 44.76208101000105, 50.31484508514404, 49.56251846040998, 51.07689918790545, 52.82577466964722, 51.87295430047171, 50.25363145555769, 44.98427397864205, 44.00216347830636, 41.16522094181606, 26.371008804866246, 43.314896311078755, 60.55741391863142, 59.87842205592564, 57.809456961495535, 58.57856001172747, 60.888585908072336, 61.970489910670686, 56.53083903448922, 45.181713989802766, 15.145160436630249, 1.9484783368451255, 21.375184535980225, 41.35971144267491, 46.804490089416504, 55.15289660862514, 62.13079180036272, 51.174688134874614, 62.68920462472098, 29.41305521556309, 19.016661950520106, 25.882124866758073, 23.264814887728008, 59.04170608520508, 41.578968797411235, 33.46024540492466, 52.13523490088326, 3.1898250409535, 0.18304197303950787, 0.054885618787791045, 0.026809464807489088, 0.05049978216577854, 0.06253154136772666, 0.1135531814236726, 0.08681274059095553, 0.057457246152418, 0.02124197980655091, 0.033582448693258424, 0.03328576264902949, 0.009715584156635617, 0.03639186526249562, 0.04555673937180212, 0.07289353106170893, 0.04379966276298676, 0.05618207868454712, 0.0629531287455133, 0.19025002340120928, 0.09472578883703266, 0.11819166716720376, 0.14857251622847148, 0.10023956439856972, 0.07213260832109622, 0.11875699540334088, 0.22486035765281745, 0.07908019623053925, 0.15408203059009143, 0.1203712709248066, 0.1549877119915826, 0.11791926249861717, 0.2436865967299257, 0.2518328167498112, 0.11011792825801031, 0.1751142820077283, 0.10993384849280119, 0.14534644862370832, 0.15174500670816216, 0.1290304498480899, 0.20332414470613003, 0.22851097104804857, 6.987303921154567, 103.36523069654191, 56.24276672090803, 75.72119726453508, 69.29025036948067, 76.73193781716483, 35.68262325014387, 21.329177039010183, 84.32927186148507, 63.6069643838065, 80.18094716753278, 74.6336304800851, 76.62023162841797, 73.79803316933769, 64.90269224984306, 29.837232317243302, 6.074039646557399, 27.58188353266035, 62.18956661224365, 73.28263664245605, 74.95910494668144, 70.4830823625837, 67.25593594142369, 64.62072045462472, 66.38260991232735, 73.88273171016148, 72.99580110822404, 69.15360014779228, 68.29855482918876, 75.91521876198905, 70.63415704454694, 61.89210033416748, 60.86321803501674, 60.96074989863804, 62.537310055324006, 62.14479242052351, 65.21096297672817, 66.6439733505249, 65.2482192175729, 64.44715445382255, 59.287046977451865, 64.45643724714006, 61.582683154514854, 62.72846194675991, 57.854064396449495, 62.56069074358259, 60.84683418273926, 58.34117480686733, 56.531950746263774, 48.6052998815264, 45.6937232698713, 44.69672972815377, 44.55498995099749, 42.84605966295515, 44.37627533503941, 43.98316362925938, 50.176409176417756, 52.08400583267212, 54.71593829563686, 51.827037130083355, 52.60369982038225, 51.836719444819856, 55.032466956547324, 55.00311081750052, 59.97784382956368, 57.40650313241141, 58.81159564426967, 56.937204429081504, 58.63314505985805, 54.786118575504844, 53.908251898629324, 58.28150715146746, 57.17108079365322, 57.34641858509609, 55.239568437848774, 55.68439558574131, 45.57173374720982, 44.02112511226109, 43.06115157263619, 43.619272572653635, 43.11424970626831, 42.7566293988909, 46.12558855329241, 44.45703772136143, 48.74779353822981, 54.4255313873291, 58.367230551583425, 58.1322911126273, 59.20034735543387, 57.59138427461897, 54.32804121289934, 43.17040852137974, 44.741017545972554, 44.09069047655378, 46.19204459871565, 44.02322346823556, 47.32608093534197, 50.533265181950156, 53.64811829158238, 51.56474263327462, 55.33374432155064, 54.780615602220806, 54.8016790662493, 55.21096617834908, 51.63688925334385, 52.23119994572231, 42.73108434677124, 31.271642753056117, 47.87829944065639, 68.01462364196777, 64.54281030382428, 61.368546622140066, 61.293839590890066, 64.03033202035087, 63.686625480651855, 61.58048057556152, 50.58326094491141, 19.994320392608643, 2.837925272328513, 25.2312228339059, 45.231004510607036, 52.44331802640642, 56.379708766937256, 68.87254551478794, 55.34431947980608, 69.92638574327741, 26.255022525787354, 16.129841770444596, 45.168019090379985, 49.914958885737825, 68.4422435760498, 50.8728722844805, 39.47795166288103, 65.7022214617048, 9.331909264836993, 0.5902141321982656, 0.2886936073856694, 0.14804418172155107, 0.13863809859114035, 0.1173340803278344, 0.24352762954575674, 0.2128015961498022, 0.16345517763069697, 0.1208290649311883, 0.1290140835834401, 0.239481226674148, 0.09620821143367461, 0.09635655954480171, 0.12233537196048669, 0.24085732283336775, 0.12597117972161087, 0.15192754619887897, 0.1584746627403157], [0.03939167536529047, 0.04504157862226878, 0.03977187889228974, 0.02032270056328603, 0.10522854740598372, 0.06961619335093669, 0.014606100706649678, 0.04497351138187306, 0.11876957544258662, 0.044778134008603435, 0.050763684790581465, 0.04692314265828047, 0.008829455589875579, 0.0564791413157114, 0.03179315184908254, 0.011872627473037158, 0.031845392260168276, 0.12636228730635984, 0.01592905230687133, 0.06946124987942831, 0.028451148054695556, 0.02478607847089214, 0.06046831315117223, 0.0979381568197693, 33.69370487758091, 63.250626019069124, 30.767592634473527, 29.253618376595632, 35.44760043280465, 60.91548238481794, 12.639944008418492, 30.4734753881182, 71.40129375457764, 59.93115888323103, 70.26054545811245, 56.591368266514365, 70.10392611367362, 58.391438075474326, 35.238577774592805, 3.9570321014949252, 9.899305241448538, 47.09070723397391, 65.45989608764648, 66.49068914140973, 71.25376960209438, 62.15776470729283, 61.1393255506243, 61.67690767560686, 68.1646977833339, 67.8810167312622, 60.02696064540318, 66.08548409598214, 65.84112289973667, 61.852308000837056, 59.44993359701974, 57.41197483880179, 52.75321463176182, 57.11434875215803, 58.30470371246338, 60.249045916966026, 61.87232576097761, 62.54286861419678, 61.23680182865688, 60.30875178745815, 56.008761814662385, 54.93232604435512, 47.797213963099885, 50.28550631659371, 53.59119517462594, 54.81786836896624, 48.57224382672991, 45.482334750039236, 42.7107469694955, 42.331476075308665, 41.283725942884175, 42.6379576410566, 41.31697307314192, 38.95098985944475, 40.182842935834614, 45.099520274571006, 44.69244963782174, 43.548508644104004, 46.35003621237618, 45.96805899483817, 46.58710527420044, 49.56959867477417, 50.25361408506121, 53.449566568647114, 56.422506196158274, 55.00608812059675, 55.57601063592093, 53.20481627328055, 54.96225193568638, 50.24117680958339, 54.06405135563442, 53.4881568636213, 54.94506904057094, 49.755400453295024, 48.06860712596348, 42.60223695210048, 39.45863567079817, 39.533443450927734, 37.950042792728965, 38.825022493089946, 40.895637784685405, 41.05955273764474, 41.11946357999529, 46.53050872257778, 53.426095553806846, 55.563726220812114, 53.62802757535662, 52.821630069187705, 53.771872656685964, 49.22774382999965, 39.85698979241507, 44.732981954302105, 44.67166410173689, 44.2077328818185, 41.875128814152305, 44.46389559337071, 45.15997655051095, 44.48591096060616, 42.855290344783235, 38.77019773210798, 39.47357429776873, 39.89529173714774, 37.82620504924229, 39.73104327065604, 35.46520021983555, 36.25086430140904, 21.33498052188328, 29.272003310067312, 44.815596035548616, 52.51354694366455, 58.49900313786098, 57.43340308325631, 58.98465442657471, 62.962595394679475, 56.014976978302, 34.51923424857003, 2.202119069440024, 0.8347104383366448, 20.56167033740452, 29.82225547518049, 36.72445699146816, 55.108598368508474, 52.45996938432966, 48.22579274858747, 49.80113697052002, 8.109583037240164, 23.627278089523315, 35.50215073994228, 32.77672331673758, 45.68814386640276, 31.351053714752197, 42.673865931374685, 29.012668745858328, 0.19455079548060894, 0.041534628053861, 0.014916527085006237, 0.035488623194396496, 0.03424888203984924, 0.039091627180044136, 0.028106265668092028, 0.026068594473014985, 0.02831145465773131, 0.05272398603015712, 0.03457959661526339, 0.03582888475752302, 0.05580909816282136, 0.11738977448216506, 0.021184898048107113, 0.04073390584172947, 0.03933439343901617, 0.011470526772817331, 0.06047670662935291, 0.016403869060533385, 0.036580043379217386, 0.033562353878681145, 0.04023644807083266, 0.0898990435525775, 0.06476352802876915, 0.017147638435874666, 0.03810119675472379, 0.028874443644391637, 0.04663057192893965, 0.0135935432543712, 0.03299767703616193, 0.03998859619189586, 0.045410979871771166, 0.02544877478586776, 0.041103927950773916, 0.06698796259505407, 0.05148111343649881, 0.02860850541453276, 0.021701505773567727, 0.036074785848281214, 0.06832097856593983, 0.08404733041035277, 0.2220265647130353, 34.171643665858674, 72.04255689893449, 34.08307497841971, 37.2310015133449, 38.967568261282786, 40.70734160287039, 21.996858971459524, 50.43928037370954, 73.93208476475307, 66.58164800916398, 77.2209381375994, 62.79993806566511, 73.99279812404087, 62.05723122188023, 38.97606938225882, 4.8560104455266675, 10.386142935071673, 48.69381993157523, 68.91037150791713, 69.36090660095215, 72.29986258915493, 65.99552576882499, 62.48745673043387, 63.6901273727417, 69.25415447780064, 70.02108969007219, 62.423602785382954, 65.23742866516113, 68.42260796683175, 65.40431744711739, 60.83199283054897, 59.7035984311785, 56.39433819907052, 59.79309122903006, 61.62220450810024, 62.126963342939106, 64.00814642224992, 63.911809648786274, 63.76127692631313, 60.66940498352051, 59.73291288103376, 58.40364606039864, 53.112193311963765, 55.23215470995222, 57.6250969341823, 57.785944257463726, 52.78356783730643, 49.666612897600444, 44.55620241165161, 44.865477153233115, 45.00218643460955, 45.05362394877842, 43.775780745915, 42.87286581311907, 42.96451602663313, 48.057069642203196, 48.141816820417134, 48.93681928089687, 50.31160027640206, 50.786033698490684, 50.457769530160085, 53.49921144757952, 53.678547927311485, 57.573433603559224, 59.22334589276995, 59.055095263889854, 56.543863432747976, 55.939766202654155, 58.753515652247835, 53.096455642155235, 54.97951820918492, 56.239942278180806, 57.48102603639875, 51.878488540649414, 49.71149478639875, 44.054907253810335, 41.110281535557334, 41.85058082853045, 41.45037848608834, 43.59438065120152, 42.52435111999512, 44.54618658338274, 42.46939434323992, 48.50237621579851, 53.33207947867257, 56.105188914707725, 54.233406748090474, 55.985085827963694, 56.277816908700125, 50.08594363076346, 43.75815316608974, 45.692357948848176, 46.302448000226704, 45.42951454435076, 41.933389459337505, 45.72600112642561, 46.02756684167044, 46.25017670222691, 45.46985578536987, 41.984232902526855, 42.49483169828142, 43.25239379065377, 43.71752010072981, 44.63953215735299, 39.650169713156565, 36.61886869158064, 23.08330362183707, 32.87619720186506, 54.458806310381206, 57.04668719427926, 60.397466387067524, 59.77464376177107, 62.09212507520403, 63.373553548540386, 59.69382231576102, 36.431875297001426, 2.79420633826937, 1.2362009116581507, 25.20436109815325, 35.661118575504844, 42.63771445410592, 58.330828939165386, 56.2776049886431, 53.8568491254534, 56.740876129695344, 17.900352205548966, 26.55111653464181, 22.708180802209036, 31.472768783569336, 57.25672776358468, 38.894410678318565, 51.16590213775635, 33.94728980745588, 0.4568670189806393, 0.04822651343420148, 0.029647481627762318, 0.03769416056041207, 0.02201077016070485, 0.05415967792006476, 0.047231414687952826, 0.024288522312417626, 0.024837686148072993, 0.11713076409484659, 0.0009586527220173073, 0.030474412254989147, 0.046792528059865744, 0.04861275253019162, 0.0181121980172715, 0.02643327142245003, 0.013257039078910435, 0.07232457944857222, 0.08006485910820109, 0.1760902324957507, 0.13812630676797458, 0.11123634395854813, 0.09945473686925002, 0.1943970937281847, 0.15912749485245772, 0.11105590114103896, 0.1817386294049876, 0.20448281110397407, 0.19528647671852792, 0.1450748581971441, 0.16011715174785682, 0.08325328159012965, 0.13226471415587834, 0.08570415686283793, 0.10631873604974576, 0.183440910918372, 0.27614429220557213, 0.06796719719256673, 0.17283261301262037, 0.04950493108481169, 0.16820912967835153, 0.2251652641487973, 0.29558776744774407, 53.42969472067696, 81.81990214756557, 46.862201826913015, 43.206994261060444, 50.18469490323748, 80.47024236406598, 16.94116381236485, 45.10323061261858, 79.47586481911796, 72.22155639103481, 83.50862707410539, 67.95391723087856, 80.20817715781075, 69.30368818555559, 42.1260004724775, 6.595841978277479, 11.878603833062307, 52.55466985702515, 71.44477558135986, 74.04823085239956, 75.85209437779018, 69.38941505977085, 65.51701028006417, 64.66213866642543, 72.48409407479423, 74.40932178497314, 66.00122329166958, 67.71371105739048, 72.4118675504412, 70.8573887688773, 67.27331338609967, 62.696173667907715, 58.83751242501395, 62.379043987819124, 61.39617265973772, 66.03433840615409, 66.82456398010254, 67.3901265008109, 68.12446076529366, 64.2082336970738, 62.524379457746235, 60.391685485839844, 54.95515782492501, 58.939470291137695, 60.423987661089214, 59.15770626068115, 53.93538808822632, 51.52209806442261, 48.11854730333601, 48.29629611968994, 47.57839434487479, 47.92181600843157, 47.1067784173148, 44.55266577856881, 44.271691049848286, 51.70371355329241, 49.10039029802595, 51.190606457846506, 53.525996753147666, 53.07028872626168, 51.85658434459141, 55.6303768157959, 54.191217286246165, 59.88076359885079, 58.8885816846575, 59.015942164829795, 58.349804469517295, 57.27666909354073, 56.63506201335362, 53.962406158447266, 55.333455971309114, 57.6155674798148, 59.4964656829834, 52.89215428488595, 51.317567416599815, 47.16413232258388, 42.61984716142927, 44.03411476952689, 42.592787402016775, 44.517969948904856, 44.41334050042288, 46.51587234224592, 44.78745583125523, 50.370020730154856, 56.044340065547395, 57.558203152247835, 57.25313901901245, 56.854051862444194, 57.3873747416905, 55.634893144880024, 48.06325006484985, 50.12601736613682, 49.21836028780256, 48.94828380857195, 45.94706848689488, 51.32176065444946, 50.605495180402485, 51.139495509011404, 47.49695103509085, 43.296191760471885, 45.3691520690918, 46.87462520599365, 47.476304462977815, 48.63630621773856, 41.865498610905235, 39.905109541756765, 25.531687259674072, 36.774925231933594, 62.28916209084647, 65.01092433929443, 63.58425767081124, 64.23985494886125, 65.33545385088239, 64.81062167031425, 64.46990980420793, 40.82281024115426, 3.4196139105728696, 1.5622458904981613, 27.34426382609776, 38.96297550201416, 44.40220948628017, 62.045092718941824, 60.19607979910714, 54.405253069741384, 60.70235334123884, 12.495693325996399, 28.685425962720597, 45.73784780502319, 45.93312692642212, 65.05770656040737, 53.086537088666645, 59.00555460793631, 51.18172318594796, 0.990856545312064, 0.16754138336649962, 0.1737855611635106, 0.1234144326299429, 0.18912958566631588, 0.18349655078990118, 0.18094924890569278, 0.08277116888867957, 0.2540566474199295, 0.20233633342598165, 0.1142229429845299, 0.08632921653666667, 0.20927347189613751, 0.14716097339987755, 0.08580175733992032, 0.15238890929945878, 0.19627561792731285, 0.22753256426325866, 0.13087010756134987], [0.05166676061760102, 0.06489992713821785, 0.07599005276071173, 0.027602611176137413, 0.045254859142005444, 0.010012176902299481, 0.040188903122075965, 0.062222305818327835, 0.05508050761584725, 0.12465136125683784, 0.030216745367007594, 0.019894036065254892, 0.013524554054518896, 0.056836654631687064, 0.010839950609286981, 0.018121514303077544, 0.05108060135639139, 0.07035809675497667, 0.10203755327633449, 0.04230951165248241, 0.05260603968054056, 0.04898907144420913, 0.027326462690585425, 0.082914034436856, 4.2433061344282965, 70.78881004878453, 50.0379524230957, 43.369717597961426, 46.85026134763445, 46.88866751534598, 35.84158066340855, 8.965745278767177, 50.520942551749094, 62.02183709825788, 56.49301651545933, 64.02413422720772, 64.44103309086391, 62.193144934517996, 45.60549504416329, 8.542758056095668, 2.870154708623886, 36.914795943668906, 62.680908475603374, 65.87392534528459, 72.66365637098039, 65.52686282566616, 65.18553256988525, 65.68167563847133, 69.96628229958671, 66.90487820761544, 59.521277700151714, 62.26036875588553, 67.07255908421108, 62.65454701014927, 58.817341804504395, 55.28426272528512, 52.91259241104126, 51.21037755693708, 57.50589363915579, 59.82970823560442, 62.12752614702497, 64.65266827174595, 61.849493980407715, 59.32407392774309, 58.22617517198835, 50.800621441432405, 42.813496930258616, 53.58708184106009, 55.491180079323904, 54.597106729234966, 48.998845849718364, 46.84130859375, 45.96740239007132, 43.518419470105854, 42.1313019480024, 42.547134263174875, 41.707072734832764, 40.64206675120762, 40.973895345415386, 41.02710812432425, 41.829569475991384, 43.66932739530291, 45.03058024815151, 44.809248856135774, 47.62971026556832, 48.439067704336985, 51.700149127415244, 53.37255620956421, 54.66363573074341, 52.82939120701381, 53.66472796031407, 50.577931676592144, 56.61218159539359, 50.71147952760969, 52.578686305454795, 54.53071321759905, 53.442715644836426, 47.76347351074219, 45.99802310126168, 41.82558121000017, 38.45762607029506, 37.922354221343994, 38.61737905229841, 39.44276251111712, 40.29538638251168, 41.37894753047398, 42.89526333127703, 52.673546586717876, 53.56245742525373, 54.44390589850289, 52.092010157448904, 56.72128915786743, 54.60870327268328, 53.802889415196006, 49.886266299656455, 46.87949589320591, 43.69279841014317, 43.39529044287545, 36.33155025754656, 39.38364028930664, 41.08422926494053, 39.48372214181082, 32.55886949811663, 28.686049563544138, 32.31858689444405, 31.262012549809047, 29.54212842668806, 31.47440161023821, 30.73683990750994, 30.76365647997175, 17.032676798956736, 18.969157116753713, 33.11182451248169, 45.66847004209246, 59.5988404410226, 56.93847942352295, 58.92399665287563, 61.010283606392996, 55.42305646623884, 25.96136212348938, 0.9636242751564298, 1.4805681875773837, 23.070465087890625, 32.92135007040841, 39.346606390816824, 50.79279082162039, 40.54512201036726, 53.88985306876046, 20.670461756842478, 8.162581290517535, 37.10131686074393, 26.745365585599625, 42.0835018157959, 37.60977561133248, 33.234109333583284, 45.65986122403826, 8.255718418530055, 0.30155412586671965, 0.025874682735385637, 0.0919249862698572, 0.08220999328685658, 0.08230539531047855, 0.028122523367138844, 0.012993815837294927, 0.11311899365058967, 0.03367813570158822, 0.08755512575485877, 0.029084752180746624, 0.015164928577308143, 0.053271852167589326, 0.05314477612929685, 0.04983502480068377, 0.02160441759042442, 0.010681292158551514, 0.026271013343440633, 0.06563160501952682, 0.06510035959737641, 0.023068899721173302, 0.08262143656611443, 0.028045716595702937, 0.07083149028143712, 0.03960987187123724, 0.03127797752884882, 0.08607895246573857, 0.027105038054287434, 0.0209112737128245, 0.011443387916577714, 0.02110314306004771, 0.03102991191138114, 0.07751356065273285, 0.039410389361104796, 0.021524752490222454, 0.052064738369413784, 0.0408533721097878, 0.015084596816450357, 0.027990297248054827, 0.08186339081398078, 0.044590067850159745, 0.039934910501220396, 0.10819662921130657, 4.866736727101462, 78.55347755977085, 52.6264134815761, 37.07149519239153, 48.34015314919608, 37.52730744225638, 30.818967614855083, 26.101634093693324, 62.77964237758091, 70.27642904009137, 62.90450150626046, 67.39521953037807, 72.72186837877545, 65.3355302810669, 50.56044653483799, 10.251928925514221, 2.8083489622388567, 38.69819702420916, 65.82471820286342, 71.41849054609025, 73.60091972351074, 67.3440113067627, 67.63924721309117, 63.998898369925364, 70.82208497183663, 67.6452157156808, 61.524811608450754, 63.102156911577495, 66.87963540213448, 64.88256331852504, 62.99869128635952, 58.116157395499094, 54.77679409299578, 55.01792090279715, 63.3561691556658, 63.203635351998464, 63.13634899684361, 65.97124876294816, 64.94833496638707, 62.01024055480957, 61.83948857443673, 54.97993857519967, 48.91515132359096, 55.83673136574881, 58.67204802376883, 57.15294599533081, 53.000712939671104, 49.00162165505545, 48.662021500723704, 45.467910289764404, 44.12959691456386, 43.67611231122698, 42.76948356628418, 42.720481395721436, 45.27212742396763, 45.67234366280692, 45.742530890873496, 48.1130165372576, 48.971716608319966, 48.00592395237514, 48.65171037401472, 51.24618509837559, 54.7424977847508, 56.572031429835725, 57.65872968946184, 57.7665935243879, 56.92880753108433, 54.965455055236816, 59.72005871364048, 54.43497051511492, 54.098125321524485, 57.49593687057495, 55.41127232142857, 50.19426952089582, 49.732943875449045, 45.176405566079275, 41.482850892203196, 41.3285105569022, 39.168656076703755, 40.023704869406565, 42.68658808299473, 42.5454215322222, 44.69358914239066, 54.46147094454084, 56.65975938524519, 56.747987610953196, 54.36165312358311, 59.14897237505232, 58.13871124812535, 53.81266205651419, 51.35631057194301, 47.41209615979876, 45.97543798174177, 45.70049428939819, 38.782033988407676, 42.07748467581612, 44.22357824870518, 42.3106940133231, 36.252868856702534, 31.353537695748464, 33.475555760519846, 33.63012538637434, 34.463888372693745, 35.18372869491577, 34.47679117747715, 32.86666774749756, 18.647132430757793, 21.86244433266776, 42.27674511500767, 54.80307912826538, 61.52467959267752, 59.79850387573242, 60.88769653865269, 61.12543610164097, 56.35898576463972, 26.368616887501307, 1.2004718631505966, 1.6711437042270387, 26.238002913338796, 36.609169006347656, 43.16974149431501, 53.37924037660871, 50.256476742880686, 56.77140998840332, 28.204522030694143, 16.012359891619, 28.560724905558995, 18.99439992223467, 43.513719013759065, 47.40352555683681, 37.01916830880301, 57.27712072644915, 10.138581224850245, 0.34150404216987745, 0.1523518477167402, 0.07497351230787379, 0.05161977546023471, 0.037902854183422666, 0.03205387892999819, 0.017236278858035803, 0.032143628756914816, 0.05685486311891249, 0.0869402644623603, 0.00953533556977553, 0.014425610391689199, 0.03759561352697866, 0.017912839339779954, 0.025152981015188352, 0.030926964578351805, 0.044642057203288586, 0.06244724017700978, 0.059137570272598944, 0.11048513783940248, 0.13866006955504417, 0.16714847087860107, 0.1985759059233325, 0.1385768675910575, 0.17567963738526615, 0.1292171419731208, 0.18930060363241605, 0.205122941040567, 0.22147639494921478, 0.10529585807983365, 0.08461271971464157, 0.09189815699521985, 0.18186774104833603, 0.1143197835023914, 0.08452706823923758, 0.17590976932219096, 0.18044216611555644, 0.1732045451977423, 0.24214613224778855, 0.3250178396701813, 0.16317475267818995, 0.12954605503806046, 0.2923372047288077, 9.926926067897252, 100.05997957502092, 62.17778246743338, 63.53236852373396, 61.40555272783552, 66.77803189413888, 42.50998224530901, 14.80420364652361, 59.640592166355674, 73.82533958980015, 63.449726649693076, 77.10135269165039, 75.43675885881696, 73.16511481148856, 54.70288610458374, 11.631449460983276, 3.438155395644052, 43.21871587208339, 70.96373094831193, 74.90567329951695, 76.57671506064278, 71.30504035949707, 69.89993395124162, 68.44972678593227, 74.74833829062325, 72.32575157710484, 64.71771035875592, 64.5892173222133, 71.6295907156808, 72.42083072662354, 68.47805459158761, 62.35129288264683, 59.41909749167306, 57.48617465155465, 65.27198205675397, 63.10935524531773, 64.96615709577287, 71.32409926823208, 68.06230218069894, 66.6927774974278, 64.44301332746232, 56.38406876155308, 53.82334838594709, 60.27290603092739, 61.881935119628906, 60.17970984322684, 53.68481867653983, 50.83486563818795, 52.480647223336355, 48.860562801361084, 46.39290312358311, 44.88641207558768, 46.00288336617606, 44.65002393722534, 46.839898109436035, 47.04176412309919, 46.983472211020334, 51.4452405657087, 50.009860856192454, 50.7552809715271, 50.8887871333531, 53.012795857020784, 55.35002742494856, 56.976472173418315, 58.708387102399556, 58.860622133527485, 57.27766963413784, 56.46187121527535, 59.58926582336426, 52.40542255129133, 56.05615200315203, 57.550348213740754, 56.42676544189453, 51.443562575748985, 50.877909728458945, 47.02791288920811, 43.04464265278408, 41.92564569200788, 41.16173989432198, 41.69308253696987, 43.558715547834126, 44.66554968697684, 46.46834666388375, 57.57929788316999, 56.80194732121059, 58.549419266836985, 56.26943390710013, 60.528530257088796, 61.23771899087088, 58.15924317496163, 55.89736482075283, 48.663463251931326, 48.37127413068499, 48.12350484303066, 41.25823647635323, 46.8688234601702, 45.7818820135934, 45.57703174863543, 38.81338426045009, 32.9717001914978, 35.97385004588536, 35.56786332811628, 36.86313608714512, 40.23752178464617, 37.245960984911235, 34.42104230608259, 19.668121576309204, 24.764217036111013, 50.203413350241526, 65.64678873334611, 65.36093289511544, 64.02095890045166, 63.241725376674104, 65.93881457192558, 59.8994334084647, 31.155500139508927, 1.7259561972958701, 2.643375711781638, 29.04556151798793, 39.978503363473074, 44.66992705208914, 60.22775663648333, 49.53515298025948, 59.925787925720215, 27.12590105193002, 12.293869870049612, 43.80690172740391, 41.26223863874163, 55.48545823778425, 55.58299010140555, 45.782045296260286, 68.45147773197719, 21.382130997521536, 0.6220867133566311, 0.21410263276525907, 0.25526511828814236, 0.13928661522056374, 0.15654903464019299, 0.17717081308364868, 0.05569119591798101, 0.2565894015133381, 0.11013031830745083, 0.22990690757121357, 0.09207596709685666, 0.1155312399246863, 0.1374655765082155, 0.16576839850417205, 0.13669750200850622, 0.15028682138238633, 0.14472332277468272, 0.15803455135651998, 0.17546659096011094], [0.036544213337557654, 0.11055001935788564, 0.0625667709058949, 0.023034730393971716, 0.04004957952669688, 0.01847226432125483, 0.05714193771460226, 0.049129948884780915, 0.055850709322839975, 0.024426692398265004, 0.06214943115732499, 0.037060246004589965, 0.042856756930372546, 0.022711325337045958, 0.05650876954730068, 0.044641477055847645, 0.05623381697971906, 0.05591724307409354, 0.04629194902788315, 0.043181347727243385, 0.034638941287994385, 0.02327811242347317, 0.13429171538778714, 0.0413152916090829, 0.09023492517215864, 30.424633026123047, 62.947503907339915, 39.42297056743077, 46.543821471078054, 49.39106123788016, 52.82793208530971, 13.23042016369956, 17.56901867049081, 66.35919448307583, 58.98930971963065, 72.79444231305803, 47.42521783283779, 71.83577850886753, 57.57783876146589, 19.811231885637554, 0.6163879420076097, 20.309124163218907, 65.01485701969692, 69.40902287619454, 71.30438722882951, 70.38885089329311, 66.98048850468227, 70.63613033294678, 68.85470254080636, 61.80497687203543, 56.22000789642334, 56.17854104723249, 62.41593892233712, 59.28201648167202, 59.22534697396414, 57.42800433295113, 54.91180106571743, 49.55792570114136, 50.54133551461356, 58.88345391409737, 56.804938520704, 59.188132422310964, 58.00891195024763, 59.783037185668945, 52.91277306420462, 39.2311064856393, 51.6612148966108, 57.61392423084804, 55.84638588769095, 53.206244128090994, 51.44571999141148, 50.48935604095459, 50.10164655957903, 46.133440017700195, 43.191326073237825, 42.21440935134888, 43.197405747004915, 42.16843659537179, 40.749927112034385, 42.66338804789952, 43.79367930548531, 44.0975136075701, 48.32931743349348, 48.35091243471418, 48.65341963086809, 48.59455449240548, 49.47270951952253, 55.769257409232004, 53.60186760766165, 56.66868782043457, 55.1368636403765, 53.944174085344585, 54.96760899680001, 53.02516712461199, 51.87660557883126, 54.93078701836722, 51.47796310697283, 49.1812812260219, 46.08072056089129, 40.08055503027779, 40.84449904305594, 39.5473815373012, 40.190173285348074, 40.51702349526541, 40.817328112465994, 42.17409242902483, 50.12305743353707, 54.82944406781878, 55.78140980856759, 53.52347108295986, 51.868243421827046, 59.53307574135916, 53.52824796949114, 54.36968176705496, 51.77050311224801, 50.98674283708845, 43.69919075284685, 36.240167549678254, 28.96599074772426, 26.928742442812236, 25.579298053468975, 24.407157795769827, 24.411293710981095, 26.812804801123484, 24.845427581242152, 25.41001214299883, 26.52469253540039, 28.05285154070173, 23.58547077860151, 23.09153723716736, 13.465819920812335, 12.635224444525582, 17.887270484651836, 35.23174769537789, 58.5016781943185, 54.185429436819895, 56.00392239434378, 51.270225865500315, 42.9947372164045, 15.719295297350202, 0.03776550173227276, 0.7910989842244557, 24.57517739704677, 35.22240931647164, 52.17016349520002, 40.8120231628418, 40.65791211809431, 52.18728385652815, 7.031252145767212, 22.644002028873988, 37.94303553444998, 31.753868579864502, 42.5378167288644, 28.87020114489964, 38.17575849805559, 37.02183641706194, 0.3525974383311612, 0.05153726560196706, 0.07463790888765029, 0.030212619874094213, 0.009654024067068738, 0.0022473461493583663, 0.03527725275073733, 0.014717310899868608, 0.050411006036613665, 0.016543394520080516, 0.033815474582037756, 0.00630080493699227, 0.017417488420116048, 0.052277991747749705, 0.040698774691138945, 0.016743603062682917, 0.11109983628349644, 0.006721989434611584, 0.03494501147153122, 0.03952423057385853, 0.05477901754368629, 0.06160844875765698, 0.037827088963240385, 0.03357455054564135, 0.0329383018293551, 0.0236684261222503, 0.03928220391805683, 0.025509591879589216, 0.0737055746306266, 0.037409623685692034, 0.03289149309109364, 0.08659083928380694, 0.02706317074729928, 0.019905499914394956, 0.06854551258896079, 0.01750107036371316, 0.029818272284631218, 0.021961708686181476, 0.025846621919689432, 0.08384405488946609, 0.13816832165632928, 0.025892777567995445, 0.15044532716274261, 0.03463707870936819, 0.17811029909976892, 33.57524503980364, 72.26042461395264, 37.18730429240635, 49.3457624571664, 43.38593469347273, 29.68857213429042, 21.648326907839092, 35.080339499882285, 72.68523747580392, 64.36895942687988, 78.35222993578229, 53.03769472667149, 76.9721370424543, 63.62630122048514, 22.70354982784816, 0.7763476872018406, 22.784261839730398, 67.66112014225551, 71.89683927808488, 74.84211117880685, 72.94684410095215, 67.54884420122418, 72.01308958871024, 68.68795272282192, 64.23368494851249, 58.01032590866089, 58.37661061968122, 65.8825272151402, 63.340966497148784, 63.380439213344026, 59.68961865561349, 57.583286149161204, 55.9564905166626, 53.662323883601594, 61.86471053532192, 61.34710448128836, 62.3749098096575, 63.70981856754848, 64.3741705758231, 58.63861329214913, 45.63875259671892, 54.79742676871163, 62.221820150102886, 58.78153773716518, 57.0652562550136, 54.06653186253139, 52.85359525680542, 50.45349638802664, 47.58929259436471, 44.40459966659546, 45.6167893409729, 46.300175939287456, 43.83415603637695, 44.096874373299734, 46.22365195410592, 45.027154786246165, 47.52375718525478, 50.34229394367763, 51.4637644631522, 52.41820723669869, 52.36268418175833, 52.59233604158674, 57.16122824805123, 56.72463124138968, 59.970680236816406, 56.88796949386597, 56.172016688755576, 56.34950842176165, 56.53198548725673, 55.13249322346279, 58.73208045959473, 53.661604745047434, 51.14657572337559, 48.307635579790386, 43.61281074796404, 42.629942893981934, 41.42925248827253, 42.6630197933742, 43.15386833463396, 43.19961527415684, 44.25072486060006, 52.28228657586234, 57.98386369432722, 56.49318674632481, 55.0855963570731, 54.61517551967076, 60.75042792728969, 54.04160520008632, 54.855715206691194, 52.88656793321882, 51.30907324382237, 43.89861100060599, 39.214284896850586, 31.16406032017299, 30.808694703238352, 30.617678301674978, 28.655861377716064, 29.460907459259033, 28.989472184862407, 26.258585214614868, 26.892384256635392, 29.600389071873256, 29.364452566419327, 26.670411893299647, 24.56317959512983, 14.376363107136317, 14.65273812838963, 27.811247042247228, 45.7969457081386, 60.879039083208355, 56.52173689433506, 59.88999775477818, 53.36864784785679, 44.44605956758772, 15.307479040963308, 0.06581931494708572, 0.8909698937620435, 26.449111768177577, 38.86191047940935, 52.91596923555647, 45.996560505458284, 47.09241649082729, 52.243328026362825, 17.157450812203543, 24.602695737566265, 25.267857210976736, 29.28231791087559, 49.47306735174996, 33.344971316201345, 43.3808833530971, 45.62045798982893, 0.8703403121658734, 0.06182266226304429, 0.041066869760730436, 0.04779245119009699, 0.1019657507006611, 0.01978560956194997, 0.15725549816020898, 0.02939541604635971, 0.022763725203861083, 0.02375419294860746, 0.06205069752676146, 0.03533836839986699, 0.028909852994339805, 0.05867315376443522, 0.06083643196948937, 0.030443654262593815, 0.06484657392970153, 0.003373201562291277, 0.06055504349725587, 0.06148656351225717, 0.13266321777233056, 0.22310019710234233, 0.14257817502532685, 0.09539764707109757, 0.13733714339988573, 0.11971766528274332, 0.16089123806783132, 0.2106559191431318, 0.22301885432430676, 0.12331672358725752, 0.1377651768603495, 0.14487809661243642, 0.07397865104888167, 0.07093418655650956, 0.13667483893888338, 0.14183511132640497, 0.09888835011848382, 0.135149247944355, 0.13832331262528896, 0.14515404323382036, 0.19632999572370732, 0.11419726721942425, 0.2984834020691258, 0.16020694907222474, 0.30272145037140163, 52.313876560756135, 85.57308973584855, 53.39818116596767, 66.91293811798096, 68.22584193093437, 68.46097591945103, 15.056160960878644, 23.872627667018346, 77.47269221714565, 68.9571259362357, 81.30980709620884, 58.29902008601597, 81.79848779950822, 68.55679852621896, 22.69417323384966, 0.9663695735590798, 27.33769256728036, 72.22548212323869, 76.82855251857212, 78.68509033748082, 76.62745080675397, 70.57662596021379, 75.84743213653564, 71.6652558190482, 69.6150369644165, 61.87844712393624, 60.90841606685093, 69.0571938923427, 71.29637595585415, 69.59094061170305, 64.87307902744838, 63.725403376988, 59.299602372305735, 56.34272697993687, 62.76767063140869, 61.0607761655535, 63.14279692513602, 66.9082133429391, 68.36263806479317, 60.53296320778983, 51.44853401184082, 60.32409340994698, 65.38960116250175, 61.20741094861712, 59.708927699497764, 56.239966596875874, 55.01636103221348, 53.59208801814488, 49.99088879993984, 46.745819500514436, 48.62958036150251, 48.578139373234336, 46.40903336661202, 46.32655130113874, 49.081706592014854, 47.1997835295541, 49.90805237633841, 54.83623593194144, 54.82636601584298, 54.69297449929373, 53.1111649785723, 53.14269937787737, 59.278834206717356, 56.81919275011335, 61.550658907209126, 56.25272001538958, 57.67401920046125, 57.3615482875279, 54.301321915217805, 55.350426946367534, 59.115329197474885, 56.70520060403006, 53.27488885607038, 50.54910012653896, 44.438510349818635, 45.51551934650966, 42.920565196446006, 45.28202165876116, 46.311751638139995, 44.32257270812988, 45.63550083977835, 54.88714190891811, 58.92382294791085, 58.792001724243164, 58.457584926060264, 54.39462579999651, 64.43729496002197, 56.08280529294695, 58.68294974735805, 55.50539609364101, 55.83004719870431, 48.69948271342686, 40.768339838300435, 32.07874550138201, 33.43581206457955, 35.11517081941877, 31.963506153651647, 32.273434025900706, 30.161945956093923, 28.999244826180593, 30.703954083578928, 33.19345194952828, 34.54009968893868, 32.00493131365095, 27.65967730113438, 17.06774435724531, 17.1135607787541, 35.75245612008231, 55.772345883505686, 64.31864057268415, 60.9560181753976, 63.416993686131065, 56.355105195726665, 46.02052484239851, 18.77078604698181, 0.11430720346314566, 1.6023786855595452, 31.332453387124197, 42.27811738422939, 58.41833455221993, 50.387589250292095, 47.37168543679373, 60.10550308227539, 10.200695514678955, 29.23594215938023, 49.738783836364746, 46.24849871226719, 58.74125902993338, 41.78008093152727, 52.84948887143816, 63.00165121895926, 3.2015153850827898, 0.4369179808667728, 0.16059218054371222, 0.16814651446683065, 0.19525891462607042, 0.10043874835329396, 0.26710039749741554, 0.11730123923293181, 0.18837918021849223, 0.09234590868332557, 0.1640923898667097, 0.08879622058676821, 0.09396354295313358, 0.11456571173455034, 0.15840311800794943, 0.08490706142038107, 0.21341811306774616, 0.08728904503264598, 0.16722553888601915, 0.1991455089300871], [0.0469987857421594, 0.08795067095862967, 0.030383841400699954, 0.06706013836498771, 0.07347080829952445, 0.02199238016536193, 0.09106260897325617, 0.007964380268406655, 0.0488349625707737, 0.11582913036857333, 0.06050912703254393, 0.04165623849257827, 0.016589753728892122, 0.048867840985102315, 0.043512123370809216, 0.020540206659851328, 0.010746206755616834, 0.014664731221273541, 0.06921131829065935, 0.11304459228579487, 0.04968762324590768, 0.12759597253586563, 0.08901386747934989, 0.02943799751145499, 0.251782415168626, 4.970487228461674, 64.37766551971436, 48.92402764729091, 42.78218487330845, 58.55130222865513, 52.09367077691214, 47.429185254233225, 10.255275351660591, 42.695047514779226, 70.23740795680455, 60.926425797598704, 78.7409746987479, 63.839527538844514, 57.058005809783936, 31.55879443032401, 1.1508754044771194, 2.157342706407819, 42.09353848866054, 59.9710693359375, 78.24048900604248, 71.24219390324184, 73.05781378064836, 73.55919579097203, 66.32628781454903, 60.1319340297154, 49.01645605904715, 43.16716023853847, 57.02581827981131, 57.44454104559762, 56.654541288103374, 57.15298768452236, 55.42048215866089, 56.22092853273664, 52.82023000717163, 49.698779582977295, 48.63268968037197, 49.24021932056972, 44.1728390284947, 45.808309486934114, 33.73973669324602, 47.27380963734218, 62.58836541857038, 58.30086135864258, 57.734228815351216, 50.72676903860909, 51.765295437404085, 53.85325690678188, 50.57268578665597, 50.59729978016445, 47.526324544634136, 42.555135113852366, 44.98840468270438, 42.76648541859218, 40.777299540383474, 41.505171980176655, 41.42158167702811, 45.682592255728586, 50.24222251347133, 50.47348982947213, 50.07525382723127, 51.07373080934797, 51.92223787307739, 56.49719933101109, 50.592828614371165, 51.2477901322501, 56.15992682320731, 55.59426702771868, 55.93606628690447, 53.80490786688668, 52.01949528285435, 51.121833188193186, 49.35750838688442, 47.53643069948469, 44.18811811719622, 40.32847717830113, 38.419344970158164, 37.92028365816389, 39.58950499125889, 41.30175999232701, 41.51051861899239, 45.02340623310634, 54.749925409044536, 57.652709075382774, 53.69118670054844, 50.68482623781477, 55.824155126299175, 56.01545640400478, 54.927827085767476, 52.46600389480591, 54.14067956379482, 47.720731667109895, 42.96385594776699, 31.90272331237793, 19.029100963047572, 13.574291723115103, 10.532371248517718, 9.358915175710406, 13.54246028832027, 17.059345722198486, 21.628303936549596, 23.56994502885001, 23.992986100060598, 25.73116830417088, 21.79204171044486, 16.926735877990723, 11.31384209224156, 8.152905923979622, 10.21047510419573, 28.63266829081944, 45.829046385628835, 52.9610595703125, 48.79499612535749, 43.41282074792044, 23.802225044795446, 5.723733620984214, 0.22983503714203835, 0.6532903132694108, 19.08568709237235, 39.20710393360683, 58.2574142728533, 39.980417592184885, 62.41076946258545, 33.39834042957851, 4.559663261686053, 40.08554383686611, 29.547297886439733, 40.55747243336269, 29.37727894101824, 27.92376443317958, 41.98410088675362, 24.487619672502788, 0.40247122783746037, 0.03298068651929498, 0.02234232272686703, 0.03904033671798451, 0.012522835350994552, 0.048398087799016914, 0.06212537709091391, 0.07253155298531055, 0.02830471171598349, 0.052489477542362044, 0.04533134360930749, 0.054530890858066935, 0.04936829109543136, 0.014219143211708536, 0.028417421471593634, 0.061977592163852284, 0.06927131435700826, 0.04076158667781523, 0.023977347849203006, 0.10184645067368235, 0.04405105659472091, 0.05486609394262944, 0.06216178049466439, 0.0730596092928733, 0.032607180132929764, 0.05657918791153601, 0.0181248747477574, 0.011013396882585116, 0.03727090059380446, 0.040019432215818336, 0.05426584829443267, 0.06349573962922607, 0.03797290274607284, 0.047213698138615916, 0.03412161261907645, 0.035425628003265174, 0.04066421350996409, 0.02588307112455368, 0.06852409802377224, 0.08047395465629441, 0.058222945779561996, 0.06653151887335948, 0.1062423058652452, 0.042632976081222296, 0.26436533140284674, 6.341950459139688, 76.7415749686105, 52.91581290108817, 42.97392388752529, 61.31205081939697, 33.07188974108015, 32.44323410306658, 21.50192662647792, 53.44023513793945, 70.70638356889997, 66.74682058606828, 78.4825781413487, 71.17142650059291, 64.46301024300712, 36.48178768157959, 1.1864796025412423, 3.0780070296355655, 45.40755476270403, 65.96473135266984, 81.78238187517438, 71.57804203033447, 74.22314480372837, 72.76191084725517, 68.37954998016357, 60.8343482698713, 52.302696909223286, 46.845060620989116, 60.810251917157856, 62.80835233415876, 62.19443729945591, 61.65903690883091, 58.50979369027274, 58.39578069959368, 55.876325675419395, 54.612215587071006, 52.44004542487008, 52.92664166859218, 49.80916213989258, 51.201202460697715, 40.14875159944807, 47.84002876281738, 64.49228300367082, 59.46412181854248, 58.04100567953927, 55.35003089904785, 55.06012773513794, 54.88773250579834, 53.56852320262364, 52.98774412700108, 48.284303528921946, 44.821908473968506, 46.24204730987549, 45.15737097603934, 43.630608558654785, 44.75752646582467, 44.44951977048601, 49.46579606192452, 52.0299071584429, 54.000221729278564, 52.44939422607422, 53.929572446005686, 52.84188754217965, 59.819654192243306, 56.30992106028965, 55.53190347126552, 58.48817089625767, 58.72683456965855, 57.756369250161306, 57.95461177825928, 55.62483562741961, 54.09132998330252, 53.40052270889282, 49.95785706383841, 47.73697655541556, 43.51885025841849, 41.899450983319966, 39.93729359763009, 41.529695647103445, 42.97805459158761, 42.206339018685476, 46.52544348580496, 54.713110378810335, 60.069122314453125, 56.93966061728341, 54.649381501334055, 57.65993520191738, 58.53562709263393, 58.406453132629395, 54.94162968226841, 54.88614484242031, 50.93006638118199, 45.70170327595302, 33.284567151750835, 22.31758608136858, 16.99780379022871, 15.497284718922206, 15.219476631709508, 18.347678967884608, 19.886526039668492, 21.90669219834464, 25.270414148058208, 25.907002891813004, 27.856274843215942, 22.769555977412633, 18.229832308632986, 12.203380005700247, 9.601347378322057, 14.137012430599757, 38.77953611101423, 50.320361954825266, 54.12230505262102, 51.76671634401594, 43.089420318603516, 23.775660344532557, 6.467238204819815, 0.037216488870659044, 0.7443192058375904, 21.29937274115426, 41.569630418504985, 58.906438555036274, 45.67049544198172, 60.29698848724365, 40.0919257572719, 8.736755234854561, 28.385557344981603, 24.352729082107544, 38.322351591927664, 39.697028364454, 30.704568999154226, 53.64832673754011, 31.23211097717285, 0.7379808745213917, 0.08708751334675721, 0.02180401375517249, 0.06119433883577585, 0.05465987357976181, 0.027132783351199966, 0.07887058997792856, 0.05096367959465299, 0.03582293400540948, 0.02225484768860042, 0.04902669621099319, 0.02583021833561361, 0.0417904153998409, 0.06876851990818977, 0.0215118772882436, 0.025101536186411977, 0.011879195692017674, 0.04739478217171771, 0.021068215469962785, 0.10911152511835098, 0.2321912364235946, 0.10557614053998675, 0.19495338387787342, 0.19434785922723158, 0.21125543197350843, 0.19186607668442385, 0.14962409622967243, 0.10002901498228312, 0.14555682162089006, 0.2259898063327585, 0.2093832181500537, 0.2217265979519912, 0.1182113311120442, 0.10929198150656053, 0.13920217832284315, 0.11497541117881026, 0.1773680089307683, 0.057301725926143784, 0.2280673991356577, 0.21417603668357643, 0.2139176505484751, 0.2444289411817278, 0.2532558675323214, 0.18427166848310403, 0.5864881064210619, 12.373286042894636, 95.77601214817592, 61.82892036437988, 62.0435015814645, 79.28578989846366, 71.31951345716203, 55.572533062526155, 13.26297334262303, 51.406066622052876, 80.39274215698242, 71.79786913735526, 87.56832749502999, 73.62873336247036, 69.04918956756592, 38.39646107809884, 1.4104997302804674, 4.172768022332873, 49.74445356641497, 68.59358228955949, 84.88243879590715, 77.8030651637486, 77.90695462908063, 76.61133793422154, 75.04644380296979, 67.19644546508789, 56.57574871608189, 47.55354411261422, 63.36224882943289, 68.75941494532994, 64.60781764984131, 64.79168088095528, 61.37580748966762, 65.16938495635986, 60.93189402988979, 55.624352727617534, 53.50508267538888, 53.735189642224995, 50.81124871117728, 51.417958463941304, 41.671821049281526, 54.782707009996685, 67.92965412139893, 63.31083215985979, 61.88825798034668, 55.67674214499337, 57.38238593510219, 58.07777207238333, 54.65447105680193, 55.3590600831168, 51.60447243281773, 47.05765812737601, 49.59001248223441, 45.84680250712803, 44.916501249585835, 47.74826042992728, 45.94964279447283, 50.08147941316877, 55.40505715778896, 55.47667224066598, 54.16415057863508, 55.29940285001482, 53.56222813470023, 60.076452663966585, 58.770246914454866, 53.260843072618755, 58.747908455984934, 60.845375061035156, 58.46734019688198, 58.22746058872768, 54.73257575716291, 55.01927580152239, 54.64587613514492, 51.02360650471279, 47.66245365142822, 45.72849552971976, 42.502509457724436, 42.28250169754028, 43.82865653719221, 45.494768551417756, 43.893121923719136, 49.24602106639317, 57.308571747371126, 62.704921449933735, 60.214770453316824, 56.00642721993582, 58.51233673095703, 60.941739627293174, 61.04505934034075, 56.08166578837803, 58.20457322256905, 54.23029742922102, 49.49361317498343, 35.49087381362915, 23.19276033129011, 18.622692142214092, 17.850941828319005, 17.177439042500087, 21.702726091657365, 22.47730084827968, 25.548025948660715, 27.663048914500646, 30.92028624670846, 31.82385778427124, 27.109171526772634, 21.257641860416957, 15.61494551386152, 11.837223836353846, 17.958565950393677, 47.053044523511616, 54.4332925251552, 56.168028422764365, 52.21577147075108, 47.81682525362287, 25.103162322725566, 8.285402859960284, 0.417994209166084, 1.324853628873825, 25.04263482775007, 44.39329147338867, 67.63227122170585, 47.08831705365862, 68.98234094892229, 40.670401505061555, 8.291076064109802, 51.95700665882656, 41.533913203648154, 58.33223247528076, 42.311298506600515, 41.34448446546282, 60.910743713378906, 46.99681622641427, 0.9541928555284227, 0.19246398817215646, 0.1246064965214048, 0.12135545882795538, 0.09062430249261004, 0.20289153791964054, 0.17403499063636574, 0.21008337129439625, 0.1885973292269877, 0.12614375831825392, 0.13131757426474774, 0.16682209553463118, 0.17009722122124263, 0.2470128568155425, 0.1435871294566563, 0.14956403230982168, 0.18546738289296627, 0.1223825572856835, 0.07900910611663546, 0.2595525639397757], [0.07183212587343794, 0.01749637320504657, 0.04488897270389965, 0.06138760596513748, 0.040884075819381645, 0.006738629233690777, 0.02239629509858787, 0.05027491566059845, 0.052778791303613355, 0.03514799861503499, 0.08506226952054671, 0.05713026691228151, 0.01997004386170634, 0.022717386351100037, 0.08552807702549867, 0.02231767324597708, 0.04519630156989608, 0.019340068201667497, 0.04886795633605548, 0.03508116291569812, 0.07042170941297497, 0.05656271647395832, 0.04426842189526983, 0.01322365430782416, 0.11720844278378145, 0.6571625226310321, 35.82041992459978, 56.296278272356304, 31.555744171142578, 56.88218511853899, 52.93731410162789, 55.847567081451416, 33.782905851091655, 10.350636771747045, 63.981187411717, 72.68388257707868, 65.54417773655483, 56.04846729551043, 54.49169908251081, 31.867916311536515, 2.7936732811587195, 0.18273858646196978, 25.049932173320226, 51.43050691059658, 70.55239064352853, 73.65061323983329, 74.45388753073556, 68.2618544442313, 58.39563478742327, 53.752021653311594, 37.7977591242109, 33.27630574362618, 45.408680370875764, 48.994669982365195, 56.54020868028913, 57.83558913639614, 59.40132399967739, 56.56378391810826, 55.704402923583984, 42.574986117226736, 35.97954062053135, 25.69390164102827, 27.22197379384722, 28.672363349369594, 40.47412184306553, 60.09501130240304, 62.70396954672677, 61.99420411246163, 53.333201612745015, 50.49960115977696, 48.59347057342529, 50.0147419657026, 54.10519858769008, 55.106764044080464, 50.734644821711946, 44.807327679225374, 41.71385417665754, 44.180079051426475, 41.75465399878365, 42.365501403808594, 42.89955384390694, 48.80712073189871, 51.78950643539429, 53.432269028254915, 51.96353101730347, 54.22505848748343, 53.58285386221749, 56.817410537174766, 50.39999873297555, 54.312366076878135, 56.81118842533657, 55.305958475385395, 54.05165924344744, 54.17984308515276, 53.44681160790579, 49.43975421360561, 48.88689299992153, 46.59930978502546, 42.582316466740195, 40.42459160940987, 38.13871417726789, 40.1830861227853, 40.282803194863455, 41.49578496388027, 42.49269165311541, 48.891141823359895, 55.904066358293804, 55.58238908222744, 50.38475785936628, 53.85143647875105, 58.314021246773855, 54.43047503062657, 51.238858222961426, 50.4655237197876, 53.94348273958479, 46.5229560307094, 41.770197119031636, 30.8461628641401, 15.845959220613752, 7.303500805582319, 3.788563472884042, 4.128744236060551, 7.596589718546186, 14.417376586369105, 19.17070003918239, 20.920433623450144, 23.86309994970049, 20.958301305770874, 19.799505063465663, 12.325571026120867, 8.583114062036787, 6.11733387197767, 6.6111684015819, 20.521653924669536, 35.43889781406948, 34.620188099997385, 35.390309061322895, 24.162516934531077, 12.567526408604213, 0.34526803876672474, 0.10332802510155098, 0.5882129967212677, 14.711118630000524, 39.49758727209908, 52.95146063395909, 42.79583808353969, 74.66868414197648, 12.931386198316302, 50.789962904793875, 41.8367087500436, 31.098135811941965, 43.79393638883318, 41.40368659155709, 38.38477073396955, 42.306994097573416, 12.430255191666738, 0.18721805752388068, 0.16822849506778376, 0.02815220079251698, 0.12171938429985728, 0.033621678195361576, 0.1926549414971045, 0.04396632792694228, 0.036077761224337986, 0.020288556681147644, 0.06211839496557202, 0.07091037676270519, 0.10993179253169469, 0.023967393740479435, 0.09590921497770719, 0.0108047354899879, 0.0032290026928032084, 0.02041404664383403, 0.07350136951676436, 0.055903160079781494, 0.05853889204029526, 0.040894867918853245, 0.06131957604416779, 0.06174566889447825, 0.02707429023991738, 0.07117060851305723, 0.0317974367977253, 0.004222342761100403, 0.01533376844599843, 0.022369007812812924, 0.01734326856343874, 0.014179939154668577, 0.04828437211524163, 0.0798236331237214, 0.016446752473711967, 0.03417182081778135, 0.03329975064843893, 0.05968063577477421, 0.022343669618879045, 0.0769460339631353, 0.06175721077514546, 0.15354350448719092, 0.0821373425424099, 0.06004751965935741, 0.07146262962903295, 0.07970474021775381, 0.8414180012685912, 44.75588321685791, 67.46632044655937, 33.69098118373326, 65.75472899845668, 44.002941676548545, 28.08569393839155, 35.75430086680821, 24.20450142451695, 70.59594890049526, 77.9121310370309, 71.88602093287876, 62.03156457628523, 59.465351649693076, 39.20468248639788, 2.7640965368066515, 0.25828639045357704, 28.48022481373378, 54.604815755571636, 71.99149458748954, 75.62054565974644, 73.57615634373256, 72.71940871647426, 63.83376053401402, 55.83738102231707, 41.263273920331685, 35.856755529131206, 49.08085543768746, 53.45720263889858, 62.67826816013881, 60.0840539932251, 66.47959286825997, 57.55568095615932, 57.26004205431257, 45.98326512745449, 41.58293621880667, 31.611559050423757, 32.2723640033177, 32.05345058441162, 41.33241197041103, 58.51987552642822, 64.96497590201241, 62.526693207877024, 56.36871671676636, 51.91740192685808, 53.36007029669625, 54.71033804757254, 56.36294971193586, 54.28773123877389, 54.4732585634504, 48.00220666612898, 46.253647327423096, 46.39732565198626, 44.569212913513184, 45.51964657647269, 45.427607263837544, 51.179121085575645, 55.35149696895054, 56.75710712160383, 56.37839903150286, 54.88878515788487, 55.774635314941406, 57.86668232509068, 56.23048577989851, 58.115917682647705, 57.3882224219186, 58.21577719279698, 56.1127416065761, 57.77945811407906, 56.98385810852051, 52.27494232995169, 51.93267754146031, 48.812807832445415, 45.043833936963765, 42.711570331028526, 41.18535682133266, 42.19285256522042, 43.69616133826119, 43.15007809230259, 44.708809171404155, 49.47867454801287, 58.71716267721993, 58.370642117091585, 54.70952163423811, 54.04004880360195, 59.891547203063965, 56.307461397988455, 55.69978584562029, 52.470561913081575, 54.952559198652, 49.4135490826198, 46.523258277348106, 31.553531169891357, 17.333969797406876, 7.867166468075343, 3.9517866458211626, 5.319463976791926, 10.546475223132543, 16.12608974320548, 19.189967393875122, 22.411711590630667, 26.087765489305767, 22.867386613573345, 20.977137872150966, 13.510911124093191, 9.168767298970904, 6.499783567019871, 7.8190067665917535, 26.162799085889542, 39.29586022240775, 38.03392839431763, 37.28348820550101, 25.073606422969274, 12.442378061158315, 0.37572951135890825, 0.607358377959047, 1.0166659546749932, 16.77707862854004, 41.499088832310264, 56.732044969286235, 44.00154856273106, 72.88821520124162, 19.318451745169504, 37.27087722505842, 34.52200310570853, 26.2454948084695, 45.702846254621235, 43.921574796949116, 45.685805797576904, 53.98276090621948, 18.76689679282052, 0.44308439855064663, 0.17972085624933243, 0.04477076851097601, 0.11859369916575295, 0.028989998158067465, 0.18996267739151204, 0.08524845274431364, 0.09204887319356203, 0.04490303194948605, 0.040977238677442074, 0.07003880531660148, 0.04123885463923216, 0.04160150446529899, 0.060761467420629094, 0.032158726161079745, 0.06911918680582728, 0.027350937448708073, 0.053933797005031786, 0.06435636630547897, 0.11425020652157919, 0.18756337756557123, 0.16186858633799212, 0.19571992488844053, 0.1788437683135271, 0.11618966316538197, 0.1215523968317679, 0.13077356559889658, 0.18355987167784146, 0.23533027512686594, 0.18030303929533276, 0.14590678284210817, 0.14410506880709104, 0.1709052478628499, 0.1075730419584683, 0.15300055433596882, 0.24334713923079626, 0.13158172794750758, 0.0892212481370994, 0.20645605879170553, 0.11667412359799657, 0.30707113125494545, 0.26375625122870716, 0.19329614351902688, 0.1483061776629516, 0.21443788334727287, 1.4155442310231072, 65.6140696661813, 81.40988894871303, 45.91685424532209, 77.759249823434, 70.50182860238212, 69.75931630815778, 39.170747484479634, 15.920099973678589, 73.56342029571533, 85.68057141985211, 75.69477326529366, 66.8815392085484, 64.52846922193254, 38.360351290021626, 3.452808277947562, 0.34908466253961834, 32.69792379651751, 57.38038485390799, 74.74243927001953, 81.6670070375715, 78.88057095663888, 76.37783677237374, 66.551513671875, 60.22932692936489, 45.642449038369314, 39.96239743913923, 52.671403067452566, 59.35705702645438, 67.95993437085832, 65.29584217071533, 67.41067927224296, 62.1500244140625, 63.76607813153948, 50.46996361868722, 44.261911460331504, 30.273030281066895, 30.22280522755214, 32.45515373774937, 46.24388510840279, 65.63591480255127, 69.321670123509, 67.17898464202881, 59.06637219020298, 54.574080399104524, 54.241449287959504, 57.57454184123448, 61.06800924028669, 58.95333194732666, 58.37263625008719, 51.22344364438738, 48.3236859185355, 47.98683030264718, 47.047795159476145, 47.150378363473074, 46.96696329116821, 54.564373765672954, 57.448355606624055, 58.20740808759417, 57.07252754483904, 55.74353517804827, 56.84727042061942, 57.98713976996285, 55.90101957321167, 57.219853673662456, 57.953142234257285, 57.528784479413716, 58.35004070826939, 56.02129289082119, 57.63030808312552, 52.098218372889924, 54.02539505277361, 51.10809659957886, 47.53548921857561, 44.106504576546804, 42.339219842638286, 43.54852948869978, 45.44325808116368, 45.01927900314331, 46.18164314542498, 53.36658770697457, 61.05859443119594, 58.53284781319754, 55.39715705599104, 56.4383932522365, 62.745943614414756, 58.697707721165244, 54.89301661082676, 54.02057300295149, 58.49647399357387, 54.508472033909385, 51.97551318577358, 35.935457774571006, 19.90481890950884, 8.707034315381732, 5.2167287809508185, 6.930426401751382, 13.490018759455, 19.89246153831482, 23.449438946587698, 26.80768050466265, 31.80102947780064, 27.465417827878678, 24.43578611101423, 16.37435061591012, 12.07887784072331, 8.208126732281276, 11.66816634791238, 30.057375567299978, 41.330692291259766, 39.476530756269185, 39.441595213753835, 26.588534321103776, 14.998332841055733, 1.1269589449678148, 0.7271788684385163, 1.3638890428202493, 19.10814540726798, 46.71526479721069, 62.252913338797434, 47.831479004451204, 84.47248118264335, 18.067942755562918, 64.56802531651088, 52.50206504549299, 45.89921971729824, 62.47885486057827, 48.49768270765032, 55.80530118942261, 65.94116306304932, 29.622863020215714, 0.6155185486589159, 0.26213767379522324, 0.2012888246348926, 0.2619441013251032, 0.12866762360291822, 0.29915135194148335, 0.15566854045859405, 0.20977492284561905, 0.18151772554431642, 0.18337779359093734, 0.247351662921054, 0.3780247781957899, 0.15844874270260334, 0.21130313298531941, 0.07345199930880751, 0.08993282102580581, 0.16603256575763226, 0.23575202535305703, 0.12651849963835307, 0.3627539947628975], [0.09666717930563859, 0.10406551124261958, 0.04080879914441279, 0.04641953736011471, 0.043994232679584196, 0.07029756464596305, 0.05211806782920446, 0.033751546405255795, 0.08087424281984568, 0.13049285566168173, 0.03976419787587864, 0.031114976453994, 0.06336271283882004, 0.06869422710899796, 0.01672763204468148, 0.02741567138582468, 0.0409069424495101, 0.04544563604784863, 0.03550532872655562, 0.07353773220841374, 0.028239974386191795, 0.13348138172711643, 0.07181198016873427, 0.23876016108053072, 0.12218222660677773, 0.27121392105306896, 14.670150314058576, 64.29567677634103, 41.769801071711946, 34.63557835987636, 68.05197020939418, 36.70068720408848, 50.863033635275706, 12.186724305152893, 25.070844514029368, 81.27206448146275, 66.38775157928467, 75.57947485787528, 50.864593505859375, 30.744229316711426, 3.223348144974027, 0.10895430855453014, 8.027544787951879, 39.38264322280884, 56.01215600967407, 64.40998853955949, 67.18085370744977, 62.185752051217214, 55.952241693224224, 42.06992850984846, 29.863861288343156, 24.73916530609131, 31.60565655572074, 34.65172944750105, 49.282763140542166, 55.309978008270264, 59.624430656433105, 54.63155589784895, 51.22897788456508, 40.99803686141968, 26.694463082722255, 11.409318157604762, 9.630251015935626, 26.50150465965271, 45.656341961451936, 53.13409750802176, 60.02964959825788, 61.18432903289795, 57.311048780168804, 51.56538186754499, 47.40078796659197, 48.99175173895699, 55.89801795142037, 56.534994057246614, 54.46386807305472, 48.9650046484811, 42.6781564440046, 42.77890532357352, 43.89988252094814, 42.170924050467356, 43.713340759277344, 51.1851521219526, 53.62368842533657, 56.01304190499442, 54.32690518242972, 53.51518188204084, 56.413897378104075, 55.12872035162789, 48.0543737411499, 39.10835613523211, 57.711237226213726, 53.76913159234183, 53.229843684605186, 50.762163162231445, 52.822470801217214, 48.55787147794451, 47.66479172025408, 43.84940733228411, 41.93010296140398, 38.01636334827968, 38.9893022264753, 38.043589864458355, 38.660961627960205, 39.96174430847168, 41.994804586683, 53.90346111570086, 56.374587944575715, 54.23075948442732, 51.16509962081909, 58.31458405085972, 56.86981037684849, 51.47699383326939, 51.62831170218331, 52.7282532283238, 54.267647470746724, 45.21720886230469, 40.11924607413155, 32.83141606194632, 18.359576020921978, 6.806532638413565, 2.4959284237452914, 1.8397757240704127, 5.074834840638297, 7.409611088888986, 16.68508447919573, 18.123234782900127, 20.171758277075632, 19.90259896005903, 16.759077583040508, 11.018309150423322, 5.5770836387361795, 3.2282433680125644, 3.006295323371887, 12.591753040041242, 18.73009044783456, 21.758817161832535, 17.904872008732386, 11.399753093719482, 2.276920769895826, 0.1918765396944114, 0.26816398756844656, 0.3424711174198559, 6.160071807248252, 48.938643183027, 53.354595116206575, 58.779807635716026, 48.61577429090227, 16.321601629257202, 61.383596420288086, 32.95553868157523, 40.745563643319265, 50.51119075502668, 88.37194224766323, 34.52042933872768, 46.70740985870361, 5.538707435131073, 0.09527100529521704, 0.06350233498960733, 0.06679138421480145, 0.07752954015242201, 0.0813829405233264, 0.039627734305603166, 0.011775249216173376, 0.024174486020846025, 0.12583031585173948, 0.033148396627179215, 0.030183911057455198, 0.06543373063738857, 0.04896462382748723, 0.013370727621284979, 0.03245621966198087, 0.07460835190223795, 0.011410495931548732, 0.031431448579366715, 0.03802010503464511, 0.03123817127197981, 0.08391614923519747, 0.11432570032775402, 0.1212041862308979, 0.04210058393489037, 0.045371875898646455, 0.03705170664138027, 0.017539438126342635, 0.0497504691593349, 0.05770217015274933, 0.0510758821453367, 0.04752801591530442, 0.012981904155042554, 0.023397928137066107, 0.04556146536820701, 0.05745981101478849, 0.024013915797695518, 0.07783264853060246, 0.052653825509228876, 0.011101960969556655, 0.08230145980737039, 0.06717524504555122, 0.11126949039420911, 0.046319338093910895, 0.13027571088501386, 0.0907601248472929, 0.2789041926818234, 18.528966154370988, 81.01401533399309, 43.959074224744526, 44.23925338472639, 75.81242711203438, 28.66120627948216, 35.24247918810163, 23.399736745016916, 39.93727970123291, 79.07060418810163, 71.0456849506923, 71.29311725071499, 59.47778197697231, 35.74736309051514, 4.336505796228137, 0.048536620901099274, 9.724014350346156, 40.63549722943987, 59.381570271083284, 66.58886023930141, 72.55418750217983, 64.74264744349888, 60.80479758126395, 43.672874450683594, 30.162168298448833, 27.950579268591746, 34.838299001966206, 41.84574835641043, 56.64480686187744, 59.71003246307373, 62.95295129503523, 57.31623561041695, 52.845066343035015, 42.322565010615754, 29.72261483328683, 14.03673950263432, 12.67110754762377, 28.214268616267614, 47.101320607321604, 59.12256227220808, 62.83144814627511, 61.665915625435964, 58.19858040128435, 54.48672764641898, 52.41248886925833, 55.676217555999756, 56.15571621486119, 58.13691861288888, 55.91197688238961, 49.15320355551583, 44.52543578829084, 45.8509019442967, 44.97761065619332, 44.586826596941265, 46.38036509922573, 55.11314943858555, 57.122113364083425, 57.323336669376914, 57.14191573006766, 55.44074657985142, 57.906981876918245, 58.066404819488525, 52.739985261644634, 45.77547924859183, 58.032615729740684, 57.08829648154122, 55.779846463884624, 54.330674580165315, 55.694328035627095, 51.03505366189139, 50.68223108564104, 46.762884276253835, 44.41858639035906, 41.27844531195504, 41.1794056892395, 41.46461534500122, 40.48488807678223, 43.16357844216483, 45.371927874428884, 55.468122482299805, 59.91247517721993, 57.58097587312971, 55.96461296081543, 59.62331894465855, 57.66763380595616, 54.51257494517735, 55.29143674033028, 56.22327354976109, 55.81440332957676, 47.339959962027415, 42.042646408081055, 34.91648360661098, 18.539746284484863, 6.720094008105142, 3.347576290369034, 2.2596108530248915, 6.471939095429011, 11.560037612915039, 16.915875843593053, 18.88447768347604, 23.211216483797344, 21.879187754222325, 17.703549691608973, 12.02768177645547, 5.853139911379133, 3.661757980074201, 3.931214766842978, 15.590770993913923, 22.54201810700553, 22.69749273572649, 18.482890912464686, 11.298503943852015, 2.4738917776516507, 0.6077355348638126, 0.2637637693967138, 1.4884339826447623, 7.80319961479732, 48.84903226579939, 58.03226484571184, 58.0239964893886, 54.51757764816284, 17.495635271072388, 61.314969062805176, 28.840105022702897, 34.81927136012486, 59.923189299447195, 84.1424070085798, 44.75394466945103, 59.00514466421944, 7.312477878161839, 0.12628839484282903, 0.02223074103572539, 0.06837770409349885, 0.11292322951235942, 0.03784432036003896, 0.05210062947922519, 0.038309052386986356, 0.04058695212006569, 0.038120626604982784, 0.00802085897885263, 0.06414521299302578, 0.03412052696304662, 0.04930128236966474, 0.06809877870338303, 0.06198724771716765, 0.09805753148560013, 0.02311449557808893, 0.02914222070415105, 0.04335682706109115, 0.0567037974750357, 0.20180609902100904, 0.2228818309626409, 0.22253496386110783, 0.26558235181229456, 0.1095428087615541, 0.14741422981023788, 0.19824012608400413, 0.12171681943748679, 0.17658584804407187, 0.18290528894535132, 0.1143735506172691, 0.16166851350239345, 0.25584922837359564, 0.19312375491218908, 0.14186694818947995, 0.13338440550225122, 0.13447975101215498, 0.22099181238029683, 0.17012483759650163, 0.1535811631807259, 0.11549375765025616, 0.3465349179293428, 0.2037215762372528, 0.37518953319106785, 0.3015709806765829, 0.507331731063979, 28.56359451157706, 97.40979766845703, 59.03167288643973, 49.56912619726998, 84.94684859684536, 53.64696489061628, 59.514315605163574, 16.015839202063425, 32.86569152559553, 92.74975899287632, 75.46189049312046, 84.40799495152065, 59.58862658909389, 39.58001027788435, 4.569466735635485, 0.18762832693755627, 11.787636280059814, 45.97161994661604, 59.46294757298061, 72.37652901240757, 73.89268847874233, 69.80158220018659, 65.33828871590751, 50.69984129496983, 35.48608997889927, 30.881133147648402, 37.344746998378206, 47.02699225289481, 60.9982145854405, 63.173931803022114, 67.7396000453404, 61.651671818324495, 58.149272509983604, 47.62784814834595, 33.779508181980674, 15.853049857275826, 14.23784555707659, 31.741330555507115, 53.75864676066807, 61.93662439073835, 67.63387625558036, 66.37707219805036, 61.49482318333217, 58.60488673618862, 55.57794223512922, 57.43845789773123, 57.815915312085835, 60.222684451511924, 58.580324854169575, 52.65223298754011, 45.37357807159424, 46.74355786187308, 47.212019307272776, 46.81346716199602, 46.61820193699428, 55.198716504233225, 57.290436949048726, 58.24274662562779, 57.67540536608015, 56.31399965286255, 57.034347193581716, 59.6224365234375, 52.544098172869, 41.79942124230521, 59.799775396074565, 57.18397665023804, 57.86891617093767, 52.89605222429548, 56.01188155582973, 53.09639310836792, 52.74586691175188, 47.3661789894104, 46.721601554325645, 42.51624952043806, 43.43362365450178, 43.07519735608782, 42.08084065573556, 44.81667995452881, 48.72459697723389, 58.79477405548096, 64.18178190503801, 59.3221492767334, 59.01294749123709, 62.31266784667969, 60.58758299691336, 57.25691883904593, 57.12195355551583, 58.9694378716605, 59.38590594700405, 53.02348566055298, 46.78849881035941, 39.37291921888079, 24.63080988611494, 10.574208089283534, 3.8130150522504533, 4.489154245172228, 8.965886848313467, 16.096297604697092, 20.367146832602366, 23.415533474513463, 29.6785979952131, 27.012897287096294, 22.443815742220195, 15.3828079359872, 7.964210220745631, 6.357747622898646, 5.557072826794215, 18.460052183696202, 23.713810954775127, 25.503818035125732, 20.183200223105295, 15.141267708369664, 4.075522771903446, 1.4273854813405444, 0.6931089194757598, 2.1244462430477142, 9.482219644955226, 56.592417444501606, 61.684592383248464, 66.51922539302281, 55.98026377814156, 24.07487235750471, 73.23194258553642, 39.07936477661133, 61.8448942729405, 60.99588693891253, 86.79987757546562, 51.16220917020525, 75.56568268367222, 10.985450250761849, 0.39969270836029736, 0.2377741682742323, 0.18060053618890898, 0.22227764981133596, 0.14455045919333184, 0.10465456106300865, 0.13267294796449797, 0.08571537304669619, 0.2319361072565828, 0.09134685407791819, 0.12650473894817488, 0.23795414290257863, 0.32790793744581087, 0.1920407180275236, 0.13085961740996155, 0.21715434401163033, 0.13454223051667213, 0.14898389843957766, 0.14841945229896478, 0.13487465839300836], [0.06634292685027633, 0.026840110841606344, 0.02302984833451254, 0.10529143403151206, 0.02743484339277659, 0.03264025532241378, 0.03937530231529048, 0.06691682498369898, 0.030221654567867517, 0.04651495295443705, 0.04051225559253778, 0.037434902507811785, 0.06045014876872301, 0.08755489505295243, 0.03198600507208279, 0.041376407258212566, 0.04032700874709657, 0.12101563491991588, 0.05778353328683546, 0.0821874455681869, 0.14344252007348196, 0.08041499674852405, 0.018560609580682855, 0.07796660491398402, 0.08782358813498702, 0.15868403150566987, 2.330267301627568, 53.89855916159493, 55.434086731501985, 37.91621548788888, 41.597652503422324, 53.0281548500061, 43.83666433606829, 42.856270040784565, 15.275793518338885, 81.41807392665318, 67.28695964813232, 74.20447499411446, 44.95808274405343, 31.870424611227854, 1.4063453589166914, 0.12679720111191273, 1.7256559048380171, 18.71064417702811, 33.09670523234776, 47.61090496608189, 46.20178597314017, 47.910191672188894, 36.76580919538225, 27.250391926084244, 19.148361580712454, 15.313176563807897, 14.353940401758466, 21.416819878986903, 41.03284733636038, 56.13085903440203, 56.52016660145351, 51.3809940474374, 49.19475725718907, 35.719664096832275, 23.945522955485753, 2.238233200141362, 2.3693248629570007, 25.11521049908229, 40.6087258202689, 47.323770659310476, 55.86485767364502, 59.76174095698765, 53.82002019882202, 56.64642579214913, 45.891781670706614, 47.05728987285069, 59.71780054909842, 62.29827117919922, 60.218251500810894, 55.87519311904907, 49.24742112840925, 42.56804139273507, 44.23966332844326, 41.79009328569685, 46.24085916791643, 55.04781205313546, 55.57198068073818, 57.16821813583374, 55.29033545085362, 56.75126368658883, 55.417272090911865, 55.09871803011213, 46.73113448279244, 33.46427188600813, 59.26681382315499, 53.40546635219029, 53.692697933741975, 49.77022443498884, 47.802741255079, 47.083613123212544, 46.51407970700945, 40.85097476414272, 39.68336820602417, 39.23968403679984, 39.74738890784127, 38.62089484078543, 39.563164370400564, 41.84532451629639, 51.76644536427089, 53.14318227767944, 53.42268398829869, 51.29855019705636, 50.26584638868059, 60.640521321977886, 55.804561206272666, 51.27191775185721, 49.70466123308454, 55.92347615105765, 52.66651848384312, 46.79013858522688, 39.571602957589285, 33.27988753999983, 21.153931311198644, 13.561154416629247, 5.0164569446018765, 3.316593621458326, 2.16184144786426, 5.83147759948458, 11.740765469414846, 16.120899438858032, 19.24134237425668, 16.790948969977244, 14.683813946587698, 8.367981331689016, 3.403010321514947, 1.295904502272606, 1.379695108958653, 6.4148131779262, 10.580678599221365, 7.952238474573408, 4.740901376519885, 1.8184203271354948, 0.08755564144147293, 0.09668816639376537, 0.8896079382726124, 1.2637854771954673, 5.336535266467503, 52.113045828683035, 54.413924421582905, 63.75402995518276, 29.78236586706979, 33.586087703704834, 16.682025534766062, 32.84858506066458, 46.25690950666155, 58.63275596073696, 50.30092784336635, 45.93530171258109, 39.471093790871755, 0.27341842704585617, 0.13228770292231015, 0.010713528509118726, 0.05619769516800131, 0.002786292943970433, 0.0501550049521029, 0.06044741427259786, 0.03970503301492759, 0.02659831828038607, 0.013164697248222572, 0.040531814364450316, 0.0749574920960835, 0.011952119546809366, 0.029268231442464248, 0.02695428453651922, 0.06871277147105762, 0.08194343759013073, 0.03109516662412456, 0.05573803858299341, 0.033096200320869684, 0.020112151146999428, 0.14025438257626124, 0.02524878507080887, 0.07244779462260859, 0.11956605341817651, 0.11275915295950004, 0.06658138441187994, 0.018139731271990707, 0.03181416268593498, 0.059457363826887946, 0.07625071198812552, 0.1375129111111164, 0.07779214677533933, 0.030836960300803185, 0.06412313346351896, 0.06610968722296612, 0.03828845206382019, 0.022937957729612077, 0.09615037310868502, 0.09692791995725461, 0.022038143959694674, 0.12595439276524953, 0.14541928257261003, 0.020589839800127914, 0.19794817960688046, 0.017425106672037925, 0.2358657478221825, 4.493472116334098, 66.33425045013428, 65.39812660217285, 37.81845085961478, 54.85758079801287, 46.03130497251238, 31.791857855660574, 36.71042857851301, 31.638438156672887, 92.08114079066685, 68.81898880004883, 82.40281432015556, 51.21939284460885, 37.81332308905465, 1.447221611227308, 0.33616017177700996, 3.3222459810120717, 20.709508895874023, 35.77709790638515, 50.10073287146432, 51.70397063664028, 51.61101416179112, 41.20240075247628, 31.943953922816686, 19.361330815723964, 16.17386555671692, 19.983543736594065, 27.805023193359375, 46.13654933656965, 58.60931968688965, 61.97124031611851, 54.568834509168354, 52.276300702776226, 40.88709497451782, 29.168440410069056, 4.190915848527636, 4.0735125711985996, 31.15200866971697, 43.54692098072597, 52.49902868270874, 57.04205274581909, 62.842732020786826, 58.447732380458284, 57.890921115875244, 51.60531663894653, 52.47811460494995, 61.81021581377302, 63.32182421003069, 61.92637579781668, 56.943353584834504, 50.494702679770334, 47.91859551838466, 47.6325729233878, 43.852054595947266, 50.06226069586617, 58.39164652143206, 58.57234832218715, 59.970381464277, 59.207837513514924, 58.18846729823521, 58.326826776777, 56.82765218189785, 51.89313186917986, 36.70179196766445, 60.98106643131801, 56.36516271318708, 56.473759583064485, 53.624612535749165, 52.501467500414165, 52.49842071533203, 49.1648383140564, 44.847634179251536, 43.019076756068635, 40.1059159551348, 41.18059383119856, 40.53868103027344, 42.8192708832877, 43.75729506356375, 52.41356931413923, 57.781125681740896, 60.50061934334891, 57.08074378967285, 55.75307158061436, 62.330337115696494, 57.9181615284511, 56.42835657937186, 53.64463724408831, 57.42701768875122, 56.623920576913015, 50.31476170676095, 43.70996740886143, 35.02643190111433, 22.699879441942485, 12.635100245475769, 6.435243921620505, 4.27791337456022, 3.5119172547544752, 10.479246190616063, 12.211665732519966, 17.799744027001516, 19.72485535485404, 18.95796009472438, 14.766162259238106, 8.823209932872228, 3.546158628804343, 1.4049019792250224, 0.7881674958126885, 10.049057160105024, 12.376349329948425, 8.75664792742048, 4.945830242974417, 1.5256885950054442, 0.24283009554658616, 0.049652380137039084, 1.8076813433851515, 0.9559161173445838, 4.344285607337952, 56.12516498565674, 57.29870877947126, 68.02122443062919, 32.836085251399446, 33.81689991269793, 20.8466819695064, 26.02353981563023, 50.38912827627999, 60.27983338492257, 57.03413527352469, 54.579270703451975, 44.83665949957711, 0.29750715302569525, 0.09465102784867797, 0.0384759075407471, 0.041822734022779126, 0.040642826086176295, 0.0857735506391951, 0.04977710844416704, 0.09429814892687968, 0.06059929755117212, 0.07003194532756295, 0.037519383510308604, 0.07774572819471359, 0.040151953497635465, 0.11800816415676049, 0.0400131761229464, 0.07343391635056053, 0.0964352288948638, 0.03858120599761605, 0.036257091244416575, 0.05205864512494632, 0.019596696931070516, 0.19880571216344833, 0.14075535855122975, 0.2783842720091343, 0.18392204652939523, 0.25308493099042345, 0.12463534783039774, 0.18385327021990502, 0.15641771097268375, 0.17336581940097467, 0.20754459181002208, 0.18192567436822824, 0.2362736016511917, 0.22254735391054833, 0.1460356502128499, 0.10466934634106499, 0.14686039595731668, 0.14800558664969035, 0.233633286186627, 0.10344484847571168, 0.12552517865385326, 0.18808312181915554, 0.16481930443218776, 0.13396778276988439, 0.3346889450081757, 0.16581527170326027, 0.5053671821951866, 7.187568375042506, 86.83962821960449, 75.8853623526437, 55.992812224796836, 58.014001505715505, 71.22025149209159, 56.31909268242972, 49.74416869027274, 20.514056069510325, 96.68063286372593, 75.1394384929112, 86.65528556278774, 54.221942220415386, 39.63723564147949, 2.2653220551354543, 0.3754725365766457, 3.056129106453487, 23.23092678615025, 37.905143533434185, 51.014896937779014, 56.063541412353516, 54.38826125008719, 43.8262802532741, 35.030201298849924, 21.628557545798166, 16.81285490308489, 19.614396367754253, 30.89054795673915, 53.07052149091448, 65.26820918491909, 64.0715695789882, 60.966482162475586, 56.057263714926584, 46.129802635737825, 34.173283440726145, 8.03487513746534, 7.151905008724757, 38.92838389532906, 48.83538600376674, 57.559936727796284, 61.00802544185093, 66.66103117806571, 58.71159022194998, 62.90690558297293, 55.04468536376953, 57.60265077863421, 64.99621500287736, 67.29538086482457, 64.16385555267334, 61.844081333705354, 54.32024185998099, 49.088491507938926, 48.936718532017295, 46.609353406088694, 51.969489097595215, 60.615695408412385, 58.94058895111084, 60.45099530901228, 58.478040422712056, 59.77192006792341, 56.94099814551217, 57.927666664123535, 51.396134172167095, 39.83806984765189, 61.80775615147182, 58.00229031699044, 57.15884849003383, 54.9297274180821, 50.70081056867327, 53.31377444948469, 49.40908139092581, 45.15834719794137, 45.48017733437674, 43.575453758239746, 43.90515620367867, 42.793086596897666, 43.188147272382466, 48.095288208552766, 58.665217944553916, 60.6858583177839, 63.50040681021554, 61.28349372318813, 59.065996987479075, 64.27643026624406, 61.543453625270296, 57.690347467150005, 56.29186964035034, 59.45555468967983, 59.28904111044747, 55.70764773232596, 48.91533545085362, 40.43700109209333, 27.931725331715175, 16.762285913739884, 8.968005180358887, 5.908676428454263, 5.234437567847116, 15.360123804637364, 15.006776639393397, 23.309559549604142, 24.744425092424663, 24.53616326195853, 19.041842222213745, 13.14313428742545, 5.240739149706704, 2.167800613812038, 4.6113530823162625, 12.785974298204694, 15.749431371688843, 10.01715624332428, 6.818119193826403, 2.4731111909661974, 1.231043502688408, 0.45779438636132647, 1.808645623070853, 3.841725443090711, 7.208531958716256, 62.36949716295515, 59.686978340148926, 72.18537017277309, 37.39882830211094, 42.66027525493077, 21.597342763628276, 46.435182912009104, 65.35793127332414, 63.564462253025596, 68.21862970079694, 60.665534836905344, 57.657506806509836, 0.8840630586658205, 0.19571917849992002, 0.14441392437687942, 0.13858537642019136, 0.3138437792658806, 0.17945575261754648, 0.27180799203259604, 0.21915955069874013, 0.16910434806985514, 0.111931523441204, 0.1618833648306983, 0.1351600502218519, 0.11931723462683813, 0.18202244703258785, 0.0935387664607593, 0.203673373109528, 0.15546739553766592, 0.16121556423604488, 0.18065187414841993, 0.10862711896853787, 0.10345436153667313], [0.01188643990151052, 0.12312111551208155, 0.030994051335645572, 0.04763362989095705, 0.08831462357193232, 0.06252034553991896, 0.011709243874065578, 0.027600623068532774, 0.06353069775338684, 0.04513074830174446, 0.08986012956925801, 0.05727290854390178, 0.0943952337173479, 0.03883563966623374, 0.13681902763034615, 0.07022398430854082, 0.12050232317830835, 0.060455678829125, 0.10670549422502518, 0.07658210170588323, 0.2381100431084633, 0.04345144198409148, 0.2508299419922488, 0.03711179770263178, 0.37856136368853704, 0.14700819445507868, 0.34010256880096024, 36.53854751586914, 67.79517868586949, 56.975753034864155, 45.95193222590855, 61.53457382747105, 41.93053374971662, 56.34473500932966, 14.282040442739214, 38.62037025179182, 85.02686405181885, 61.74646609170096, 60.67275401524135, 33.3072703906468, 2.1916689787592207, 0.4478344965193953, 0.7026345197643552, 5.009277284145355, 22.225307055882045, 24.617597886494227, 28.876902682440623, 28.50286204474313, 22.741877828325542, 14.045796479497637, 6.831254763262613, 3.7178751059940884, 3.6488034980637685, 11.495223079408918, 28.23572986466544, 47.743198667253765, 51.1456481388637, 45.745230266026084, 47.605370725904194, 37.68527126312256, 18.802773816244944, 3.5102175516741614, 3.4279751990522658, 25.26114525113787, 38.54213700975691, 46.61166020802089, 50.36025851113455, 60.99942357199532, 60.822647503444124, 58.10950796944754, 47.68873521259853, 46.36980383736746, 52.76095839909145, 60.3646639415196, 55.988344533102854, 55.954162870134624, 50.864225251334055, 45.49021748134068, 44.37662969316755, 42.9879766191755, 45.84500987189156, 57.83147580283028, 58.052015100206646, 57.96618400301252, 54.5108448437282, 59.80557714189802, 56.73925025122506, 56.250326360974995, 44.80494792120797, 39.53427723475865, 58.283629826136995, 54.06651449203491, 52.4317284311567, 50.05295010975429, 47.21465614863804, 42.580106939588276, 42.92245858056204, 41.74903638022286, 38.89465386526925, 39.04208421707153, 39.17103583472115, 40.36303751809256, 39.65538433619908, 45.943549224308555, 53.93620102746146, 52.79912485395159, 51.08780091149466, 49.90441152027675, 46.497018405369346, 57.134786878313335, 52.98374196461269, 52.71597923551287, 55.50579214096069, 55.62518651144845, 50.57317910875593, 43.515108653477256, 36.89122765404837, 31.097757135118755, 22.536061763763428, 16.969797338758195, 10.6175822189876, 10.471676996776036, 3.917234991277967, 4.408738400254931, 8.989753910473414, 14.41568556853703, 14.656477996281215, 15.654048238481794, 11.391364880970546, 6.863080552646092, 2.278897966657366, 0.38641934203250067, 1.5184500919921058, 1.2554117036717278, 2.4247951550143103, 2.1167085553918565, 0.5779869311622211, 0.12212980299123696, 0.06724536485437836, 0.0864919563755393, 0.19673694031579153, 1.4789746616567885, 1.4894086846283503, 41.316097600119456, 72.76932457515171, 57.29498107092721, 24.297219923564366, 44.47145175933838, 40.32077162606375, 40.48502704075405, 41.21893399102347, 39.10287748064314, 35.8357754434858, 61.61752142224993, 10.6422552721841, 0.06144198376153197, 0.05711010085152728, 0.07983519536043916, 0.09454748340483222, 0.04832880258826273, 0.03501968764300857, 0.0277537277101406, 0.021180207674790705, 0.031252098203237565, 0.08587571087160281, 0.022929623623245528, 0.034803977967905145, 0.03801112801634839, 0.07166785254542317, 0.025195903444130505, 0.026961823060576404, 0.07106432278773614, 0.0333092026412487, 0.07756054920277425, 0.026643510408965603, 0.04454847704619169, 0.08118342408644301, 0.11759980821183749, 0.029272519783782106, 0.07700030319392681, 0.08028325917465345, 0.06579440592655114, 0.02728747746108898, 0.04620446211525372, 0.08306914075676884, 0.07069633967642273, 0.06545045652559825, 0.047296442091464996, 0.0626245481627328, 0.008683744435464697, 0.10438973563058035, 0.06405486605529274, 0.05564210730205689, 0.10447610635310411, 0.058893623362694464, 0.11237691382744483, 0.2433128325002534, 0.055416840461215804, 0.22712586394378118, 0.024714917110811387, 0.27854785323143005, 0.07580367276178938, 0.3125776600624834, 45.81087337221418, 80.30249895368303, 60.91114670889718, 48.609232561928884, 64.85995388031006, 26.258058888571604, 44.168322699410574, 19.355430058070592, 63.173681667872835, 87.88411617279053, 69.03578649248395, 61.05535657065255, 35.7360132081168, 1.7216129217829024, 1.3529082834720612, 1.2758957530770982, 6.241826483181544, 24.549140759876796, 27.657540730067662, 33.68114948272705, 31.92386668069022, 26.255128485815867, 16.07785361153739, 6.951437754290445, 5.168909106935773, 5.140670325074877, 14.686447313853673, 35.58208976473127, 52.87400559016636, 55.270592144557405, 50.29269422803606, 52.08613198144095, 41.34773622240339, 22.48238866669791, 4.500783792563847, 5.315727582999638, 31.881388868604386, 41.84114170074463, 49.81789255142212, 53.24452870232718, 63.48494012015206, 62.9289105279105, 60.59558037349156, 51.543112891060964, 51.103180749075754, 56.28415019171578, 62.370796476091655, 57.295460496629985, 57.17264066423689, 51.23728098188128, 47.28886638368879, 46.70781632832119, 46.76170308249337, 46.96112680435181, 59.78642095838274, 59.77986880711147, 61.61361653464181, 58.37196922302246, 61.776037624904085, 58.188814708164756, 57.643457548958914, 50.69452244894845, 41.41156932285854, 60.22336537497384, 58.362658636910574, 53.97503103528704, 52.05472264971052, 49.734555857522146, 46.6882779938834, 46.20794207709176, 44.11375502177647, 41.42744595663888, 41.87496205738613, 41.0982403073992, 41.216384002140586, 41.68925755364554, 49.09062460490635, 55.99088409968785, 56.823052474430625, 56.911336285727366, 55.8026157106672, 54.32895490101406, 61.92423575265067, 56.158280100141255, 56.64160026822771, 58.36414555140904, 59.0217855998448, 55.231626646859304, 48.3324475969587, 39.98147719247, 33.98562996728079, 25.74130572591509, 17.384729862213135, 11.591828227043152, 12.370428596224103, 5.755472557885306, 7.077848936830248, 11.614335179328918, 15.086297035217285, 16.04670136315482, 15.631412744522095, 11.500095503670828, 7.360105173928397, 2.376264810562134, 0.6643157473632267, 2.7852457676615034, 2.3002302391188483, 3.8002351437296187, 2.6356312930583954, 0.7217480369976589, 0.7636080565197128, 0.36322386669261114, 1.6963133364915848, 3.425964346953801, 1.6293848135641642, 0.9957023710012436, 47.24014214106968, 73.1693115234375, 61.13163389478411, 27.408275842666626, 42.37222726004464, 33.9469667162214, 39.32821798324585, 45.0951498576573, 42.909409863608225, 42.27755110604422, 70.31187874930245, 12.690889069012233, 0.21883181828473294, 0.03491692690710936, 0.03398478263989091, 0.0934627569679703, 0.0677936075787459, 0.04803951596841216, 0.047297093485082896, 0.0360026982879, 0.026723000786400268, 0.042420136609247754, 0.04113538822691355, 0.11282458409134831, 0.030749707482755184, 0.07508289215287992, 0.04551920620724559, 0.0605639119499496, 0.047148273792117834, 0.026555850469906415, 0.02487248820917947, 0.08785036991217307, 0.05043026286044291, 0.11645739951304027, 0.2799406142107078, 0.10605179358805929, 0.22246686608663627, 0.1854781173169613, 0.18906839537833417, 0.124429887426751, 0.06769931156720434, 0.17440703138709068, 0.14095891905682428, 0.11039025828774486, 0.1696937507284539, 0.1257459060954196, 0.12603958962219103, 0.24837725503104074, 0.1373435351997614, 0.3192221735204969, 0.3407509225819792, 0.21092115848192147, 0.1548530092196805, 0.3439120543854577, 0.16006827008511337, 0.27140385657548904, 0.17392977699637413, 0.4579846475805555, 0.2534393434013639, 0.4768371188214847, 63.57992894308907, 92.2129898071289, 76.87906592232841, 62.23774542127337, 83.45962142944336, 59.759454999651226, 67.95792634146554, 18.60420298576355, 48.75096191678728, 99.19647829873222, 71.7959236417498, 70.59223161424909, 39.62822035380772, 3.6719101667404175, 1.7508105550493513, 1.9247333024229323, 7.34273988859994, 27.52879408427647, 27.59430343764169, 33.20192527770996, 33.769065039498464, 26.93812598500933, 16.987470081874303, 8.329013228416443, 6.011352564607348, 6.161046292100634, 17.519512755530222, 41.66396958487374, 59.132901191711426, 60.632544789995464, 54.10246794564383, 58.09656000137329, 48.10899700437273, 28.62642707143511, 7.607445410319737, 9.487282276153564, 41.034709453582764, 46.439994539533345, 53.925813470567974, 56.224670137677876, 66.33586243220738, 66.31575434548515, 62.275029454912456, 56.74282162530081, 55.1716810635158, 57.849631445748464, 66.82986545562744, 60.70400701250349, 60.76570006779262, 53.44675254821777, 49.218037196568076, 48.26914950779506, 47.14274229322161, 47.62615973608834, 61.092758723667686, 61.014063426426475, 63.102844783238, 58.12204251970564, 62.18755163465227, 57.7637551852635, 57.334467683519634, 50.627249990190776, 47.03709840774536, 62.09213202340262, 60.255090849740164, 54.86489030293056, 54.65303972789219, 51.9704201562064, 48.16855001449585, 47.21068525314331, 45.99988521848406, 44.13660069874355, 44.38438040869576, 44.529698508126394, 44.310156277247835, 42.90594271251133, 52.330187456948416, 59.05242715563093, 58.870335715157644, 61.00517668042864, 59.96635150909424, 58.710144996643066, 62.73314503261021, 59.65211227961949, 59.84772491455078, 61.205215317862375, 60.71897343226841, 56.70298065458025, 50.52137334006173, 43.11438519614083, 36.41655799320766, 30.79775823865618, 21.81524348258972, 15.689734186444964, 18.18812574659075, 7.9976814304079324, 10.744429400988988, 15.46426340511867, 19.0662408215659, 20.18692966869899, 20.790048939841135, 14.63687539100647, 10.892074278422765, 4.573392033576965, 2.158787497452327, 5.456688293388911, 3.0959878819329396, 3.453338078090123, 3.804346740245819, 1.0481245751891817, 0.4695165944950921, 0.24781225249171257, 0.8939874746969768, 2.7105582782200406, 3.6450549449239458, 2.6042491027287076, 50.49316365378243, 75.02024214608329, 64.71146392822266, 35.33820799418858, 49.758495875767295, 49.22515562602452, 60.62661797659737, 48.710599831172395, 51.01499421255929, 47.6828396660941, 82.3269191469465, 18.474136182240077, 0.3950389895055975, 0.1907064060547522, 0.16479037169899258, 0.3162934806730066, 0.2190590189503772, 0.11263006167220217, 0.1506438393677984, 0.18119198802326406, 0.10409489180892706, 0.14384170222495282, 0.22475242987275124, 0.15940625060881886, 0.1251880417444876, 0.2912473146404539, 0.17681804272745336, 0.18796891080481665, 0.13170010516686098, 0.08919922289039407, 0.2551439862166132, 0.1738133810992752, 0.1370857868875776], [0.04202487639018467, 0.1276097060846431, 0.0677041495218873, 0.07621637133083173, 0.031913395039737225, 0.04617415534864579, 0.05980252780552421, 0.026671888439783027, 0.010037819588822978, 0.02390634424851409, 0.048768333824617524, 0.03748810304594891, 0.10751713067293167, 0.08170244230755738, 0.09350048351500716, 0.08457343932241201, 0.097898448950478, 0.09530322213790246, 0.08432517692978893, 0.1810931119003466, 0.060668752395680973, 0.1647825414048774, 0.08349294694406645, 0.10454881816570248, 0.15372438835246222, 0.1589753944426775, 0.17049104294606618, 7.2811393312045505, 50.80245923995972, 49.60319321496146, 46.549432141440256, 63.38433715275356, 65.43873187473842, 45.31616163253784, 75.05334336417062, 13.8746223960604, 56.028484276362825, 67.83371339525495, 66.11428437914167, 37.32072360174996, 0.20367295241781644, 0.8028849746499742, 1.957139483519963, 0.317820455878973, 6.779132851532527, 9.593207563672747, 9.515406847000122, 8.214974181992666, 7.287003176552909, 2.8231783722128188, 0.9766517132520676, 0.27246530247586115, 1.589555025100708, 8.708570735795156, 20.75646308490208, 36.16696827752249, 47.10987731388637, 42.772676263536724, 47.23426396506173, 33.97991507393973, 13.283044951302664, 5.915366240910121, 7.071259438991547, 22.41961169242859, 34.04243149076189, 39.515152318137034, 49.42566326686314, 52.702642168317524, 53.519625255039756, 53.3644129208156, 45.7339255469186, 40.79476383754185, 50.60280622754778, 54.65209477288382, 52.63061366762434, 56.7015597479684, 54.79922982624599, 48.262906551361084, 45.206901209695, 45.23243931361607, 48.37077733448574, 60.415302412850515, 58.66827515193394, 59.40762601579939, 58.97758116040911, 59.014330182756694, 55.91735478809902, 54.20968212400164, 49.442759309496196, 35.506872040884836, 59.29076426369803, 51.83844607216971, 53.3063850402832, 47.94311571121216, 45.34527111053467, 43.99370057242257, 44.250867298671174, 40.10431439535958, 39.54011024747576, 38.332617555345806, 39.03817238126482, 39.56578731536865, 45.60972302300589, 52.66557352883475, 55.374901975904194, 53.23342548097883, 49.04311282294137, 48.004141739436555, 45.87175348826817, 55.066718101501465, 54.4351372718811, 55.014759472438264, 58.26301452091762, 58.750361170087544, 50.708001954214915, 39.25328860964094, 34.49678461892264, 28.66441634723118, 21.950696877070836, 17.709796122142247, 14.499920317104884, 19.987233230045863, 16.107478993279592, 9.052011506898062, 4.937282221657889, 11.405421955244881, 11.34292812006814, 13.568526455334254, 10.403694084712438, 6.278711863926478, 2.172494121960231, 0.6522483548947743, 1.6910671208586012, 0.3818110578826496, 0.6229735857674054, 0.31946698895522524, 0.09284316628639187, 1.128701314330101, 0.2371611525969846, 1.901093793766839, 3.7071596809795926, 0.5348543599247932, 0.949094506246703, 32.544528416224885, 78.48747662135533, 45.51070424488613, 28.731002671378, 41.68870517185756, 30.464685916900635, 38.16797998973301, 36.99877882003784, 30.430535520826066, 55.262963022504536, 27.37573916571481, 0.14591185828404768, 0.05626960630927767, 0.013366589405839997, 0.056373171109173975, 0.03503383509814739, 0.022592101645256792, 0.05071183453713145, 0.05084664587463651, 0.02755785161363227, 0.042591571874384365, 0.09293745551258326, 0.10487087802695376, 0.021286652855841175, 0.048115925796862156, 0.07894243326570306, 0.025383905141747425, 0.05894224039678063, 0.04702522825183613, 0.025046751269006302, 0.05276563111692667, 0.04606568134788956, 0.15159757461931023, 0.14185371675661632, 0.017012004374659488, 0.06727075563477618, 0.07642737536558084, 0.08680868973689419, 0.10376380743192774, 0.05162058970225709, 0.12058925708489758, 0.0803624577820301, 0.08988980869097368, 0.07444922865501472, 0.037569856337670765, 0.08199791038142783, 0.03487866431740778, 0.1443547968353544, 0.035234627180865834, 0.04529577141095485, 0.05592391646600195, 0.03910963889211416, 0.17811557810221398, 0.1447827217302152, 0.1502432730048895, 0.19464313052594662, 0.08162098417856864, 0.21113763829427107, 0.2743971459567547, 0.3272772255752768, 12.415564094270978, 65.06459917340959, 57.86210346221924, 50.69984824316842, 70.19491277422223, 49.84965624128069, 26.806290864944458, 45.558566910879954, 27.27747426714216, 76.21545042310441, 70.38930252620152, 69.28228078569684, 34.80283887045724, 0.8414619703377996, 1.7531526408025195, 2.5986905438559393, 1.0699633061885834, 7.411654727799552, 9.665584342820303, 11.022766419819423, 10.999146018709455, 9.700695327350072, 4.163319775036403, 1.6212119949715478, 0.870706775358745, 1.6892325792993819, 9.329140407698494, 25.034514120646886, 41.03764854158674, 51.70649978092739, 47.87454741341727, 51.697036334446494, 36.88658973148891, 18.613253014428274, 7.1940792713846475, 8.995748468807765, 29.38218089512416, 35.82166365214756, 43.79146630423409, 52.23603589194161, 57.53788661956787, 58.29357269832066, 55.47094692502703, 51.62819010870797, 45.28902196884155, 53.30642672947475, 59.49189376831055, 58.413554191589355, 60.671322686331614, 56.03268446241106, 49.039965288979666, 47.70352445329939, 45.61024761199951, 50.108914375305176, 62.1048263822283, 63.28418581826346, 62.968306813921245, 61.49575424194336, 61.277691977364675, 59.99105930328369, 56.22737298692976, 51.20485026495797, 39.37679631369454, 60.85337243761335, 56.154111180986675, 56.30532830102103, 50.644158431461875, 48.905875478472026, 45.77141802651541, 47.26507575171334, 44.57883269446236, 43.79183108466012, 41.37355572836739, 42.0551427432469, 42.786155768803184, 46.97384895597185, 56.21131222588675, 59.27270589556013, 59.20902565547398, 55.837196895054404, 57.71851199013846, 53.221106324877056, 57.547315325055806, 56.83618456976754, 57.61959743499756, 60.302178791591096, 60.898883138384136, 55.19147300720215, 45.097838810511995, 40.16433988298689, 32.801330362047466, 24.515721661703928, 19.575743538992747, 16.792053733553203, 20.541723796299525, 18.271929706845963, 12.292299577168055, 6.906487252031054, 12.256959302084786, 12.041141305650983, 13.46810153552464, 10.839257546833583, 6.071679864610944, 1.7189791202545166, 0.8474940380879811, 2.7746363026755194, 0.5222626498767308, 1.1355967500380106, 0.3153211399912834, 0.48833611607551575, 1.7440133712121417, 2.286599176270621, 2.6196526076112474, 7.192565432616642, 0.868846666600023, 1.0635508788483483, 35.78107227597918, 79.02027838570731, 46.143070220947266, 35.10351174218314, 41.74126482009888, 28.54414129257202, 37.98494706835066, 39.8079320362636, 35.610792773110525, 63.20266955239432, 29.202774933406285, 0.30632569268345833, 0.10270407822515283, 0.02467052056454122, 0.01955554717486458, 0.026867542316072753, 0.0710951147068824, 0.053793492926550765, 0.10877928044646978, 0.04386389967320221, 0.1509901772120169, 0.09473968523421458, 0.13675562531820365, 0.013189544352436704, 0.048619850006486685, 0.06450776103883982, 0.07461960201284715, 0.00911820022988, 0.04265618197886007, 0.012770333543552883, 0.03450613162879433, 0.029747657145240476, 0.07284097173916441, 0.20158364810049534, 0.22582887139703545, 0.20402788051537105, 0.17961585974054678, 0.14985527311052593, 0.31810438207217623, 0.0954980431124568, 0.22221986576914787, 0.1589859795889684, 0.14905229476945742, 0.1293537446430751, 0.1041303181222507, 0.1980621734900134, 0.1384790635534695, 0.25288036625300137, 0.16683422774076462, 0.24162409454584122, 0.23823486641049385, 0.18761065788567066, 0.24089844205549785, 0.29232493681567057, 0.30232871430260794, 0.30503435911876814, 0.3526301165776593, 0.2718296508703913, 0.38029594346880913, 0.27742922039968626, 18.77614484514509, 87.03967380523682, 70.24210493905204, 65.43804400307792, 77.24817507607597, 88.38437257494245, 57.86493485314505, 86.60262516566685, 20.478201627731323, 69.73696395329067, 78.17845548902238, 76.73032583509172, 43.41576331002371, 0.7895900851913861, 2.4949723950454166, 5.475220876080649, 0.9532043657132557, 10.205448951039996, 11.788955569267273, 10.966879452977862, 11.818311708314077, 10.621602620397296, 4.801926536219461, 3.1778046573911394, 0.9034644918782371, 3.119813906294959, 12.360002824238368, 33.19930580684117, 46.042001724243164, 55.57483639035906, 52.652125290461946, 57.8926442691258, 43.026785782405305, 22.510438544409617, 9.931113226073128, 14.726432459694998, 36.818024907793315, 41.79580470493862, 48.08090196337019, 56.527698448726106, 60.13338620322091, 59.73979159763881, 56.52431467601231, 55.48706327165876, 47.98185191835676, 56.597527844565256, 64.46776281084333, 62.664024353027344, 64.83610766274589, 60.47963578360421, 53.343568325042725, 49.79329245431082, 48.19671106338501, 52.08994306836809, 64.28405938829694, 63.43411404745919, 62.6901078905378, 63.632554599217, 63.30263328552246, 59.10953439985003, 58.480944769723074, 53.586050033569336, 40.82086821964809, 60.79582050868443, 55.757817200251985, 58.84346008300781, 52.69300501687186, 49.34396287373134, 48.50743450437273, 48.62135716847011, 46.640154770442415, 45.27242619650704, 45.03040654318673, 45.249768120901926, 44.6575140953064, 50.46285213742937, 59.77759674617222, 63.3679324558803, 63.57815020424979, 59.09183038984026, 64.33234936850411, 58.414902142116, 59.77990354810442, 58.77871676853725, 59.61748940604073, 61.16539519173758, 63.27803666251046, 58.99873842511858, 46.373792103358674, 40.74665451049805, 36.07127768652779, 27.179857288088115, 24.097752775464738, 21.984958444322857, 24.6115460055215, 23.37301571028573, 15.339875016893659, 10.399999380111694, 16.102990456989833, 16.073118414197648, 17.688428674425396, 13.821492995534625, 8.628451926367623, 2.3678970081465582, 2.262795082160405, 3.3878232964447568, 0.6314551649349076, 2.1323676237038205, 0.7997917777725628, 0.4746754691004753, 1.4396086654492786, 1.8308750816753931, 2.7732477486133575, 10.240647656576973, 2.523493664605277, 1.4591663245643889, 42.046189989362446, 81.51072120666504, 55.552150521959575, 41.514482566288535, 43.50580154146467, 45.84015655517578, 51.465209688459126, 48.48224033628191, 44.74176100322178, 72.2509959084647, 45.78951460974557, 0.5805939712694713, 0.1481401672852891, 0.09576735366135836, 0.18006267505032675, 0.19447627876486095, 0.20645162117268356, 0.30868995296103613, 0.29628988834364073, 0.09880210153226342, 0.24166890499847277, 0.18877870163747243, 0.2815107171024595, 0.12224894016981125, 0.18798641700829777, 0.12635303208870546, 0.16305959171482495, 0.14188562147319317, 0.17666438168713025, 0.10958326301936593, 0.18586283310183457, 0.13215214519628457, 0.22198554048580782], [0.07677198973085199, 0.0646992436211024, 0.028211182449012995, 0.08131479525140353, 0.005827072991191277, 0.039311177363353114, 0.04956824179472668, 0.1400682061378445, 0.0578369814902544, 0.036385819515479464, 0.0305725318113608, 0.09126783867499658, 0.026798089167901447, 0.07064496100481067, 0.11947202203529221, 0.09701851116759436, 0.06279859239501612, 0.16331394735191548, 0.22040874723877224, 0.10313118887799126, 0.07464936255876507, 0.16530080645212106, 0.01805643261676388, 0.15843435776020798, 0.04976405343040824, 0.21173951242651257, 0.019677663122170737, 0.7891182590808187, 24.824117456163677, 55.316408566066194, 42.26560020446777, 44.14335782187325, 63.162766047886436, 46.67716087613787, 72.66747093200684, 20.198510578700475, 22.125141824994767, 65.0831995010376, 59.53854397365025, 34.63690199170794, 0.09167411151741232, 3.3691591322422028, 0.7914778238960675, 0.7782333631600652, 0.05427986682791795, 1.5014727115631104, 2.518016964197159, 3.659769058227539, 3.010143105472837, 1.0092691630125046, 0.8151535391807556, 0.7506447806954384, 2.231330599103655, 6.364372730255127, 18.296107700892858, 30.888609409332275, 39.025731631687705, 40.92447975703648, 40.81196410315377, 32.3625933102199, 11.996407066072736, 8.412040727479116, 9.696124281202044, 23.190219027655466, 32.57934236526489, 38.88788284574236, 37.795157023838584, 41.547173840659006, 46.0993069921221, 38.012524468558176, 31.3452867099217, 42.07277379717146, 47.49977200371878, 43.193341050829204, 51.87879078728812, 53.94513293675014, 53.521504742758616, 46.975592953818186, 47.50025142942156, 44.63379989351545, 48.98449087142944, 58.51585946764265, 59.78423922402518, 61.073352405003135, 57.31454372406006, 59.03882258278983, 55.8488837650844, 57.3973662512643, 50.504221711839946, 28.895419631685527, 61.993412017822266, 51.56142834254673, 54.86955254418509, 43.54181752886091, 45.36643532344273, 40.85365676879883, 41.71089424405779, 41.17386450086321, 39.81903525761196, 39.844740118299214, 40.85197877883911, 44.399784564971924, 48.17205190658569, 51.74911655698504, 53.8867506980896, 52.855495589120046, 48.21387311390468, 44.087452616010395, 45.412616525377544, 49.227650029318674, 54.38939380645752, 54.62610156195504, 61.09465558188302, 58.92143971579415, 49.032794748033794, 30.27704633985247, 23.0127238205501, 23.97348598071507, 22.94620176724025, 20.40365787914821, 17.05172007424491, 23.42612600326538, 26.242376804351807, 16.817333017076763, 6.215806782245636, 8.25965804713113, 8.486708675112043, 10.718779257365636, 8.485349433762686, 4.854964741638728, 1.8485109124864851, 0.8171065800956318, 0.87354212892907, 0.2180911430290767, 1.2507029963391167, 0.7406468114682606, 1.3968317551272256, 2.839028081723622, 2.0214365933622633, 7.746694258281162, 5.846517843859536, 1.4309971332550049, 0.1531344564365489, 32.86075135639736, 52.41942664555141, 40.236840861184255, 28.91967405591692, 28.83017257281712, 41.226441519601, 44.4499887738909, 33.94109548841204, 48.09746994291033, 41.830667291368755, 2.9016463330813815, 0.029239142646214793, 0.07666778032268796, 0.012462237932985383, 0.01342612152386989, 0.024450849941266433, 0.12593500023441656, 0.04506976496694343, 0.050564310846052, 0.06603927564408098, 0.009292432755630995, 0.05043118227539318, 0.03077557323766606, 0.08279517545763936, 0.03921865572088531, 0.023852712840640118, 0.054064062157911916, 0.0975500415744526, 0.041775250142174106, 0.10357523576489516, 0.10236044095030852, 0.10628097557595798, 0.018979705038613508, 0.09037825212414775, 0.04606018182156341, 0.1005561009847692, 0.06362681223877839, 0.04468736298648374, 0.14298240547733648, 0.04214183886402419, 0.07328936803553786, 0.07494633019502674, 0.05977198015898466, 0.04934654065540858, 0.10815056346889053, 0.019448416673445275, 0.10875133837440185, 0.0669109895825386, 0.07273081157888685, 0.045979704175676615, 0.03547502874529787, 0.09811572264879942, 0.09662819068346705, 0.1552450938948563, 0.1348482362393822, 0.017587027179875543, 0.10983708261379174, 0.10266559850424528, 0.11912971468908445, 0.08346274535038642, 0.998678697007043, 33.9153732572283, 71.22312109810966, 47.80602427891323, 51.03368139266968, 66.70670168740409, 37.169555119105745, 68.18950285230363, 32.09085968562535, 31.983833108629497, 69.56972081320626, 65.2545142854963, 33.84236853463309, 0.07715013729674475, 1.8843240993363517, 2.800525724887848, 2.0181464041982378, 0.2176408264786005, 2.567712434700557, 5.017302887780326, 3.6805315784045627, 3.1184798521654944, 1.4663492419889994, 1.0343386977910995, 0.1911919250019959, 1.3238898920161384, 7.469927532332284, 20.049676690782817, 33.44552217211042, 41.16398068836757, 45.38409069606236, 47.496388231004985, 35.39734411239624, 14.960937636239187, 11.41087715966361, 13.002534883362905, 27.630467074257986, 37.66422516959054, 43.62522717884609, 46.80214507239205, 47.941997051239014, 50.01069811412266, 44.66121053695679, 34.50376755850655, 43.899785246167866, 55.03567702429635, 55.29020690917969, 56.38018124444144, 58.28517232622419, 55.52069255283901, 50.11041866030012, 47.27157926559448, 47.32068913323538, 49.49147660391671, 61.56602832249233, 62.50627245221819, 64.99449184962681, 58.67809295654297, 63.21263326917376, 57.96230343409947, 60.40221200670515, 52.58807679585048, 33.766185011182515, 65.31782627105713, 56.24588993617466, 58.0962438583374, 47.30664682388306, 48.644751753125874, 44.83590909412929, 45.368832451956614, 42.5629448890686, 41.59146165847778, 43.5130033493042, 43.200664452144075, 45.619092668805806, 52.51447452817644, 55.14724424907139, 59.08379132407052, 57.603328227996826, 56.14521401269095, 53.494962624141145, 53.30438395908901, 54.29191058022635, 57.269821643829346, 57.66643871579851, 66.04012625558036, 62.57242625100272, 52.21167203358242, 37.144173349652974, 28.523894241877965, 27.92179635592869, 25.253630774361746, 22.81424331665039, 18.73933502605983, 25.823548078536987, 27.161864927836827, 19.72261803490775, 8.057166695594788, 9.388154932430812, 10.161762152399335, 11.568682040487017, 8.08784212384905, 4.947447436196463, 1.6486258953809738, 1.5148894659110477, 1.9586915373802185, 1.337732223527772, 0.7810874985797065, 2.151012680360249, 2.5734883419104984, 3.297262864453452, 3.2250228779656545, 6.515176866735731, 4.575835193906512, 1.2973694865192686, 0.31753468407051905, 34.12294026783535, 59.84124919346401, 47.59535837173462, 40.939491340092246, 29.08882795061384, 35.406890937260215, 47.03289474759783, 39.08850513185774, 53.88789715085711, 47.821466650281636, 3.30176442861557, 0.016451953444629908, 0.04668679194790976, 0.0747502539306879, 0.009430688506524478, 0.0696730681561998, 0.020339577425537363, 0.06998283974826336, 0.028630771541169713, 0.04138402720647199, 0.05113031422453267, 0.06811382861009666, 0.07213277795485087, 0.027711203920521905, 0.030696031970105002, 0.08719834525670324, 0.08139645694089787, 0.0363792750452246, 0.05636326449790171, 0.07856341038963624, 0.02334612707740494, 0.11326601183308022, 0.14097314115081513, 0.16788233364267008, 0.17099374239998205, 0.15824291589004652, 0.17298353277146816, 0.10864355308668953, 0.29866223675864084, 0.1303792010460581, 0.21870187882866177, 0.1409514280302184, 0.10033586887376648, 0.11502430641225406, 0.23318097474319593, 0.19179217065019266, 0.23273981841547148, 0.15473465914172785, 0.26885875314474106, 0.23906642464654787, 0.1969614675534623, 0.32927068003586357, 0.17385728231498174, 0.32113493659666603, 0.2182951106556824, 0.17365760302969388, 0.16106407450778143, 0.20387981060360158, 0.30984291966472355, 0.15478947120053427, 1.1061485473598753, 50.68039328711373, 84.42152309417725, 62.68992723737444, 61.275676999773296, 81.31316307612828, 64.38006264822823, 84.70996366228376, 30.084018434797013, 30.607766696384974, 76.8702278137207, 68.76732894352504, 41.61832686832973, 0.2088596469589642, 8.765754410198756, 2.5532940540994917, 2.2045222776276723, 0.2593663739306586, 2.6677732254777635, 4.321855519499097, 4.300713888236454, 4.618250472205026, 3.4427991807460785, 3.895321241446904, 1.067018898470061, 3.3390048188822608, 11.7398213829313, 26.89966596875872, 40.54995795658657, 48.78223575864519, 53.03726393835885, 54.17396143504551, 39.7307653427124, 19.31866713932582, 13.47284802368709, 16.638898066111974, 35.42108610698155, 41.90679175513131, 48.57391834259033, 48.73832661764962, 51.928928988320486, 50.041110379355295, 42.07526125226702, 36.05875355856759, 48.85922179903303, 61.03196893419538, 63.06735338483538, 62.61903476715088, 59.688958576747346, 59.55808230808803, 53.575176102774485, 51.237656184605186, 50.52690063204084, 52.30920042310442, 62.56178161076137, 63.90739754268101, 65.45562989371163, 60.10859503064837, 63.28629807063511, 59.45946652548653, 61.374258041381836, 54.473126547677175, 37.314150605882915, 64.8555417742048, 56.99303667885916, 59.63932759421212, 48.0656749861581, 50.17592280251639, 45.18919719968523, 47.388708523341585, 44.4624399457659, 43.584927627018516, 46.2162139075143, 44.8717166355678, 47.880460330418174, 53.891326086861746, 56.87485824312483, 60.58904211861746, 61.17084952763149, 60.14334297180176, 59.21275683811733, 56.62219047546387, 56.563877718789236, 57.99011707305908, 59.34372343335833, 66.65959984915597, 63.344009808131624, 55.202805519104004, 37.77105024882725, 30.98498092378889, 29.39471197128296, 28.600261892591202, 25.98965345110212, 23.31757950782776, 30.00064352580479, 30.335400785718644, 24.56910467147827, 12.819978782108851, 11.62063980102539, 12.302700161933899, 13.411259191376821, 9.550530859402247, 5.4420384509222846, 1.9284125907080514, 2.5423606293542043, 4.2827193566731045, 1.8283346465655734, 2.6420525142124722, 2.284121709210532, 2.368400969675609, 3.1768030311380113, 3.9293582950319563, 14.026065332548958, 13.125563161713735, 3.434230749096189, 0.5169776763234819, 41.80477135522025, 66.4574281147548, 52.65981347220284, 33.60028634752546, 36.55317347390311, 56.07817084448678, 55.619440351213726, 50.98904616492135, 61.34312316349575, 69.38862991333008, 6.669412110533033, 0.3739010766148567, 0.17524453358990805, 0.17081888392567635, 0.0843003425481064, 0.1659960334322282, 0.26649199585829464, 0.1808103799287762, 0.13781956822744437, 0.15023209074778215, 0.18014770905886376, 0.2506955920585564, 0.13833319209516048, 0.15976477494197233, 0.17782904633453914, 0.09128693265042134, 0.13500244010772022, 0.13599236841712678, 0.17165692895650864, 0.1788454239389726, 0.25329815383468357, 0.22614174389413425, 0.20857257236327442], [0.04473354068717786, 0.039550595052008114, 0.07253432140818664, 0.02370034610586507, 0.02047474499392722, 0.05148428898038609, 0.06402505801192351, 0.021278064298842634, 0.09373763150402478, 0.02805098711646029, 0.07059737534395286, 0.11381566591028656, 0.12902194101895603, 0.10301696429295198, 0.0612402485151376, 0.16381560186190264, 0.00899389770347625, 0.05986560442085777, 0.017192353893603598, 0.07882493135652371, 0.15361488637115273, 0.13959879561194352, 0.05903072136321238, 0.10547266394964286, 0.03547059451895101, 0.1171540514166866, 0.06524504361940281, 0.1209116562136582, 4.899317698819297, 52.085544858660015, 53.56443766185215, 62.04740646907261, 57.057415212903706, 39.57611928667341, 24.20587543078831, 32.97283622196743, 21.541639055524552, 60.40605436052595, 56.80510875156948, 35.899598121643066, 0.123491392071758, 2.705648724521909, 2.218032398394176, 2.748976171016693, 0.47503585261957987, 0.6734249985643795, 2.0554024279117584, 0.3454211705497333, 1.6313854604959488, 0.19996764910008225, 1.1821909355265754, 2.593972282750266, 3.59838650056294, 7.519568937165396, 13.841389162199837, 23.044180052621023, 32.310315064021516, 34.477805614471436, 33.52749701908657, 26.23055965559823, 13.525766372680664, 7.267936885356903, 9.690401571137564, 21.316732815333776, 27.326533760343278, 31.568768569401332, 29.9994831766401, 28.34915052141462, 21.727751765932354, 13.01041761466435, 25.806247064045497, 34.556379318237305, 27.910920688084193, 27.65199433054243, 48.61939777646746, 49.409289836883545, 52.16892671585083, 49.449009214128765, 47.6265001978193, 46.94634451184954, 48.16714300428118, 58.934891428266255, 60.29790564945766, 59.126453263419016, 58.24792650767735, 57.40207712990897, 56.94635173252651, 63.66716357639858, 47.6849866594587, 24.761588879993983, 61.664116042000906, 52.841661725725444, 54.769717352730886, 45.97916221618652, 43.31188774108887, 40.227905477796284, 41.74315125601632, 38.806842531476704, 39.66279111589704, 39.64539977482387, 43.32016651970999, 48.54397855486189, 51.70661790030343, 55.16392339978899, 56.746879373277935, 52.04705878666469, 48.464303561619346, 48.85436500821795, 48.49632780892508, 49.12931217466082, 53.90446860449654, 55.79983295713152, 61.566605022975374, 58.762263434273855, 47.55255399431501, 29.951874119894846, 20.91208709989275, 20.496629987444194, 21.424327407564434, 20.152909551348003, 18.344812835965836, 24.357137714113506, 32.404014996119905, 23.14443908418928, 6.562109776905604, 7.008861141545432, 7.553676775523594, 7.041363946029118, 6.80934796163014, 3.4392247668334415, 0.9145720558507102, 0.8178395607641765, 0.13539964093693665, 0.9987048613173621, 0.406733649117606, 1.1178267321416309, 1.1277768782206943, 3.0813949278422763, 4.103503601891654, 4.614299987043653, 4.498621165752411, 0.5395308232733181, 0.05396755412220955, 35.81493779591152, 52.77906193052019, 15.693790197372437, 18.740378992898123, 33.258268220084055, 45.55282769884382, 41.595297064099995, 43.508163928985596, 51.45649317332676, 12.693362627710615, 0.22529139023806366, 0.1325988790818623, 0.012511303648352623, 0.04461101083351033, 0.058455832568662505, 0.12694201405559266, 0.019401392500315393, 0.06594649955098118, 0.0400852161858763, 0.03954278511394348, 0.021073879541030953, 0.10896908026188612, 0.03642245701381138, 0.01874178521601217, 0.032923119608312845, 0.06621896528771945, 0.06826393412692205, 0.014026672512825047, 0.035248381085693836, 0.03974051021837762, 0.07060012341077838, 0.037856147225414, 0.038059622914131196, 0.06644656628902469, 0.046263820358685086, 0.031382251397839615, 0.15127780820642198, 0.04363842587918043, 0.05717097222805023, 0.022723822255751917, 0.09819538265998874, 0.050993619952350855, 0.05415753374940582, 0.054794291366956065, 0.09329715371131897, 0.17305616315986427, 0.09012468358767883, 0.1326658640589033, 0.09125016962311097, 0.09845089859196118, 0.03227176330983639, 0.06444053178919212, 0.1423065167452608, 0.042250608027513535, 0.13165741174348763, 0.05566489929333329, 0.06103984998272998, 0.0649370022916368, 0.09046329970338515, 0.044947404747030566, 0.2302574116204466, 9.165644083704267, 72.85305731637138, 62.300258363996235, 58.79879011426653, 67.19737652369908, 43.63711207253592, 25.57916256359645, 28.75748920440674, 35.027088505881174, 64.58734130859375, 64.03432723454067, 37.647382736206055, 0.15477571051035607, 2.237676692860467, 5.138926761490958, 4.396419678415571, 1.809260864342962, 2.5075377779347554, 2.8901561839239935, 0.8669412859848568, 4.595765233039856, 1.6785475526537215, 1.0609451958111353, 1.5261862597295215, 1.8741178469998496, 6.349856206348964, 13.818237764494759, 25.696830306734356, 35.38102279390608, 39.36795820508684, 39.0889949798584, 32.642362526484895, 16.40981595856803, 8.947983077594213, 12.789008055414472, 26.969872304371425, 32.363308974674766, 37.74650921140398, 34.63578680583409, 36.2153103692191, 28.18235206604004, 18.57809165545872, 27.90495044844491, 43.04012632369995, 40.54571608134678, 44.716605050223215, 59.10136331830706, 54.71832847595215, 56.616440841129844, 50.7195394379752, 51.90785162789481, 48.592914717538015, 50.31286137444632, 60.56562668936593, 63.80562727791922, 63.477373531886506, 61.13261359078543, 60.57675075531006, 59.16391100202288, 63.916756766183035, 48.79379756110055, 26.928230013166154, 63.85795416150774, 58.33732550484793, 57.23957960946219, 48.052310126168386, 47.52293382372175, 44.16223955154419, 44.42007677895682, 41.87049436569214, 42.66449281147548, 42.33780935832432, 45.79231473377773, 50.23260620662144, 54.91831847599575, 55.76782955442156, 60.10938017708914, 57.092461926596506, 56.898079122815815, 53.626954078674316, 52.51875114440918, 53.865933895111084, 56.04763698577881, 59.37788077763149, 63.07148061479841, 63.196457862854004, 52.10309600830078, 35.121990476335796, 27.253601993833268, 26.041452271597727, 24.831703151975358, 24.87338365827288, 20.837400913238525, 27.60978055000305, 36.173402309417725, 25.73083826473781, 8.65196897302355, 8.475667987551008, 8.332586339541844, 7.905051520892552, 6.989965515477317, 3.6134184939520697, 0.7258423173001834, 2.0636112902845656, 0.5401621865374702, 2.926258806671415, 1.861182689666748, 3.1061832777091434, 4.350564607552119, 6.320100545883179, 4.638338582856314, 4.359872588089534, 3.779190352984837, 0.9614499232598713, 0.08861763695521013, 36.6085193497794, 62.612093516758506, 28.879563842500957, 20.559301001685007, 31.070700849805558, 45.439492157527376, 49.187364373888286, 45.99874571391514, 62.68099185398647, 14.889619588851929, 0.2511946681354727, 0.11284909277622189, 0.03764614402981741, 0.04034827064190592, 0.050200456620327065, 0.07428348969135966, 0.07990698436541216, 0.04526218053485666, 0.1169114208647183, 0.06363608781248331, 0.06768779682793788, 0.04038594290614128, 0.07413832390947, 0.10116693856460707, 0.00614785126942609, 0.04276414029300213, 0.029391080207590545, 0.09172657584505421, 0.03154634152139936, 0.050239102582314184, 0.05655409907922149, 0.009596982172557285, 0.09675880188920669, 0.11042089414383684, 0.31375784959111896, 0.18531016632914543, 0.21903874432401998, 0.24514919253332274, 0.20917446006621632, 0.15739676915109158, 0.16129656774657114, 0.10719075532896177, 0.18739763860191616, 0.1356189434549638, 0.2465602196753025, 0.2444190074290548, 0.305841897215162, 0.1894787869283131, 0.3035806928362165, 0.18310689527009213, 0.14526476657816342, 0.18073183271501744, 0.2725508250296116, 0.19327679170029505, 0.19526622923357145, 0.20507929766816752, 0.23874604755214282, 0.12895655738455908, 0.15097044541367463, 0.11481773321117673, 0.4639538015638079, 15.056970426014491, 97.98597008841378, 72.10253374917167, 76.68735817500523, 75.00868034362793, 59.17275605882917, 35.76548399244036, 44.84944071088518, 30.779432364872523, 72.11135796138218, 67.25703375680106, 42.445551599775044, 0.4225527159869671, 7.06423567874091, 7.1619108489581516, 5.739073072160993, 1.2127370621476854, 1.8551863942827498, 3.6344504739556993, 1.0384995830910546, 2.9782906089510237, 1.559850499033928, 3.5449733095509663, 3.3439091614314487, 4.5722051944051465, 9.375745449747358, 18.463283096040996, 32.387071813855854, 39.642408575330464, 47.50011593954903, 49.329694747924805, 37.90518522262573, 20.22133367402213, 10.985844561031886, 17.149538551058086, 32.91481181553432, 36.236849784851074, 43.371447699410574, 39.79438304901123, 37.5894729750497, 27.14044884272984, 19.567782640457153, 29.37594141278948, 46.29360294342041, 47.813747201647075, 56.1066688810076, 63.95110171181815, 59.150077138628276, 59.136159896850586, 55.497172900608604, 52.52241979326521, 52.772728647504536, 51.52445002964565, 62.30460793631417, 66.88103199005127, 66.14111832209996, 62.82402747017996, 60.971533502851216, 62.175642422267366, 66.00314794267926, 49.604193755558555, 29.437933240618023, 65.4445892061506, 59.1898694719587, 59.862392561776296, 50.544052260262625, 49.83176462990897, 44.41995518548148, 45.1556339263916, 43.01845489229475, 43.65782812663487, 46.40154320853097, 49.38727446964809, 52.491305759974885, 58.01560653959002, 59.304618971688406, 62.29493604387556, 60.496929849897114, 60.508686201913015, 58.77219935825893, 54.04322760445731, 55.517524174281526, 56.24160289764404, 60.66684109824044, 64.17715440477643, 63.02189826965332, 53.62731538500105, 37.228527954646516, 30.845999581473215, 28.918631826128276, 28.334541933877126, 27.403356518064225, 23.995379754475184, 32.036931242261616, 39.17112963540213, 29.638774394989014, 12.377846666744777, 11.141531978334699, 11.45886663028172, 9.922117045947484, 6.920516099248614, 2.733734646013805, 0.6871165324534688, 3.3103691211768558, 1.6808677081550871, 2.3057753358568465, 1.9304881479058946, 1.8790575819356101, 3.7785650151116505, 6.561911753245762, 8.677523578916277, 14.398715462003436, 12.810187033244542, 1.893486384834562, 0.34886036600385395, 42.9995071547372, 66.15846797398159, 24.111769029072352, 21.451545238494873, 50.82342890330723, 57.23097079140799, 57.854425702776226, 53.25482245853969, 72.96777207510812, 29.529163088117325, 0.4343660649444376, 0.32769447032894405, 0.13142084729458603, 0.16012948751449585, 0.12483622133731842, 0.16264477611652442, 0.22743305031742367, 0.20107759668358735, 0.2153441754302808, 0.15233772061765194, 0.12203301675617695, 0.2773690479142325, 0.37831139138766695, 0.18053389047937735, 0.10885234509727784, 0.15353319075490746, 0.1284947193094662, 0.2307913372559207, 0.16921671346894332, 0.1540245586740119, 0.11020731167601687, 0.1618380115500518, 0.36768938707453863], [0.008192870150586324, 0.06896357158465044, 0.0093991120312629, 0.04203413839318922, 0.013388933564004089, 0.024211785090821128, 0.03738255353112306, 0.09783725866249629, 0.038541247070367844, 0.10354957357048988, 0.08861160477889435, 0.07515069815729346, 0.05037325234817607, 0.21407939972622053, 0.14050694688090257, 0.1157679400805916, 0.03309682118041175, 0.06982229836285114, 0.09052600990980864, 0.06513432027505976, 0.16872918605804443, 0.11279162086014237, 0.17276028117963246, 0.09147023888570921, 0.1105224233386772, 0.09501113316842488, 0.22943120024033956, 0.1618845590523311, 0.18233169615268707, 40.620082650865825, 61.29877281188965, 70.406144959586, 62.89043835231236, 52.41791888645717, 52.299608434949604, 47.07124532972063, 20.31436136790684, 41.56369318280901, 79.90172685895647, 28.313148430415563, 0.007961769604922404, 0.5642362290195057, 4.4468201739447455, 3.232753400291715, 1.8532760739326477, 1.732229660664286, 3.04216040457998, 0.2944736129471234, 0.6535547790782792, 0.15631982551089355, 1.001918403165681, 2.881618367774146, 2.262257899556841, 5.891732811927795, 8.312123894691467, 15.29305110658918, 22.52433841569083, 25.523556130273, 28.98863318988255, 21.15831388745989, 14.601128646305629, 5.646543477262769, 10.537198509488787, 17.617539678301128, 25.870118379592896, 25.49900814465114, 23.208251340048655, 14.193588137626648, 2.744713234049933, 3.889281519821712, 13.985757963997976, 26.41034255708967, 16.232685531888688, 19.205081462860107, 38.74972486495972, 47.66651487350464, 49.5113901410784, 51.177637645176475, 45.83133234296526, 47.56509896687099, 45.742847033909385, 57.46939475195748, 59.510250908987864, 60.671392168317524, 56.83409663609096, 57.64122370311192, 58.99402754647391, 61.537408692496165, 52.61327791213989, 21.976641450609478, 57.502551555633545, 55.32230063847133, 50.661292689187185, 49.547993251255576, 48.20029285975865, 43.64963967459542, 40.39610399518694, 42.27027286802019, 40.9919467653547, 41.732464926583425, 42.678152969905305, 50.78797571999686, 51.18082686832973, 55.08028793334961, 51.04347487858364, 50.65884344918387, 48.71345206669399, 47.91496161052159, 47.41096012932913, 50.94164555413382, 50.94184357779366, 57.14808225631714, 58.353257724217, 58.70942933218819, 49.59634576525007, 40.2272766658238, 31.104889460972377, 18.76763677597046, 17.9530542918614, 19.59062831742423, 17.806308337620326, 25.39068399156843, 31.7209758077349, 27.92577419962202, 9.55276644229889, 5.284605732985905, 6.684900079454694, 5.566570580005646, 3.9676567656653265, 1.373041557414191, 0.8703286413635526, 1.4695581155163902, 0.9255961328744888, 3.870244324207306, 0.8693590419633048, 4.637248584202357, 5.284892346177783, 5.303378897053855, 4.431058619703565, 4.04089902979987, 0.929368896143777, 0.9299820746694292, 0.10743913985788822, 39.41796439034598, 41.2443505014692, 12.657423070498876, 37.466462067195344, 47.90956286021641, 49.75151988438198, 32.9743891443525, 53.34322091511318, 42.64946733202253, 1.5458493360451289, 0.043114674876310995, 0.11868965758809022, 0.11635633850736277, 0.06469815117972237, 0.05585171016199248, 0.024412731540256312, 0.06148703170142003, 0.10074176852192197, 0.02869728154369763, 0.04928720955337797, 0.07937980336802346, 0.028459390558834587, 0.06868216954171658, 0.08256291970610619, 0.049203074603740654, 0.011153128447144159, 0.024345015441732745, 0.11674857246024267, 0.06555621977895498, 0.0912307295948267, 0.03693594517452376, 0.018039638875052333, 0.05412491996373449, 0.026185789345098392, 0.06667899167431252, 0.06750316744936363, 0.02717905943947179, 0.04849442620096462, 0.1171817627868482, 0.023451296612620354, 0.13112107052334718, 0.06455574025000844, 0.029241955173867087, 0.022258479547287737, 0.06020206279520478, 0.1275090386292764, 0.14473510214260646, 0.15277803556195327, 0.11970595376832144, 0.09631799839969192, 0.09022723737039737, 0.06501327641308308, 0.10529982750969273, 0.12989763117262296, 0.12815638817846775, 0.13895823141293867, 0.029375748708844185, 0.12829299084842205, 0.05839641325707946, 0.1299039822603975, 0.09209676419517823, 0.22466802011643136, 55.669460432870046, 73.3500828061785, 72.53145994458879, 69.25579425266811, 53.53954226630074, 43.11530930655343, 29.448063714163645, 25.222839832305908, 53.93982798712594, 78.9989265714373, 33.51857205799648, 0.035728811020297666, 2.1166940076010565, 8.638315762792315, 4.378922811576298, 4.800632868494306, 4.784842652933938, 3.5807191857269833, 1.2926377632788248, 2.894394802195685, 1.48595130443573, 0.6138097260679517, 1.6237716461930956, 1.0810714129890715, 4.655680418014526, 9.082529732159205, 16.307057312556676, 22.352723121643066, 32.25518110820225, 33.974860259464805, 22.532592875616892, 14.826458726610456, 7.403345550809588, 13.712994268962316, 23.11596015521458, 32.65110683441162, 32.54198884963989, 28.482005289622716, 18.423648834228516, 7.35662933758327, 5.725830239909036, 20.966585295540945, 35.48493310383388, 21.641613210950577, 35.71207666397095, 51.442294529506135, 55.320250919886995, 53.356964451926096, 55.51033278873989, 48.80128077098301, 51.031020232609336, 49.94737918036324, 62.14984376089913, 62.23860699789864, 62.92792388371059, 60.497992924281526, 60.7730165209089, 62.438068934849326, 64.49785545894078, 54.38437373297555, 24.083204984664917, 60.57415212903704, 58.324784006391255, 53.59931067058018, 52.773694447108674, 50.796918051583425, 45.42659977504185, 42.75343322753906, 43.937805788857595, 43.04936742782593, 44.06439849308559, 46.273731095450266, 53.045897075108115, 52.935768127441406, 58.45620918273926, 56.615662642887656, 56.40257181440081, 54.32740545272827, 52.85154553822109, 52.73108114515032, 56.05051006589617, 56.455485820770264, 61.84269169398716, 64.49018464769635, 64.86362252916608, 55.431995323726106, 43.83862025397164, 34.28426701681954, 23.14712803704398, 21.851685047149658, 22.561982018607004, 20.81210252216884, 28.15386097771781, 35.49257264818464, 32.180494921548025, 12.483238680022103, 6.873265743255615, 7.041847714356013, 5.845735302993229, 4.2736172165189465, 1.4950197892529624, 0.6155326079045023, 3.348243534564972, 1.3178687351090568, 8.095961093902588, 3.9803246344838823, 6.538329132965632, 7.392131158283778, 7.332956824983869, 5.387669665472848, 4.52329899583544, 2.416092102016721, 0.7248604499867984, 0.12099118051784379, 41.18450914110456, 47.47188540867397, 14.330819402422224, 34.32412535803658, 44.89598669324602, 49.497914109911235, 32.994570187159944, 58.756190708705354, 44.96792834145682, 1.337746228490557, 0.11544544595692839, 0.012457864774790193, 0.02460727601179055, 0.09238370308386427, 0.04929537232965231, 0.029983461634921174, 0.04396610401038613, 0.11196836110736642, 0.10080164245196752, 0.08104643465152808, 0.09719735264245953, 0.1410896863256182, 0.06613672684345927, 0.09184414560773543, 0.02495022287725338, 0.014224831879671131, 0.0590748397101249, 0.12314460639442716, 0.05866536418242114, 0.013177961759668375, 0.047108016309461424, 0.06735709921589919, 0.040141290319817405, 0.2884920010609286, 0.19925149609999998, 0.1797497754118272, 0.19529058864074095, 0.13516374145235333, 0.20152154857558863, 0.12436697365982191, 0.14196344943983213, 0.08763021244002239, 0.18902509127344402, 0.23091214363064083, 0.11909197457134724, 0.20023644396236964, 0.3938938123839242, 0.2208500528442008, 0.23465057302798542, 0.12992340193263122, 0.25081732124090195, 0.23922582609312876, 0.22674911416002683, 0.2518103708113943, 0.15061661654285022, 0.19639375087405953, 0.22514023977730954, 0.2046764242861952, 0.2142085927937712, 0.2959614231118134, 0.3429982577051435, 0.6750964203051159, 76.32497487749372, 83.98345306941441, 82.95964990343366, 74.45918900626046, 73.74007824489048, 69.11088957105363, 65.07499367850167, 29.042163848876953, 52.79912485395159, 90.9784825188773, 35.005076612745015, 0.0730648815099682, 1.5362328120640345, 10.341279285294668, 8.436961310250418, 6.484266068254199, 4.058795418058123, 5.217285071100507, 1.1889448016881943, 1.9409343302249908, 1.4600301810673304, 1.811478533915111, 2.7929122362818037, 1.733738396848951, 6.5675888657569885, 11.361768160547529, 22.057608808789933, 28.11027319090707, 43.15235710144043, 43.74302346365792, 28.029210294995988, 18.356722048350743, 9.677259922027588, 16.654852867126465, 27.6259594304221, 37.08967515400478, 36.073337827410015, 29.412256172725133, 18.621677705219813, 10.288033502442495, 8.379354664257594, 24.0342948777335, 41.56284897668021, 30.394390991755895, 53.85312141690935, 57.872167927878245, 61.293950762067524, 55.42019380841936, 58.9987245287214, 51.846922874450684, 54.719867501940044, 51.46124921526228, 63.90262413024902, 62.500804219927105, 64.47170938764299, 61.58171040671212, 62.76063905443464, 63.36481966291155, 66.87299987248012, 55.60376868929182, 26.19008466175624, 60.68918650490897, 61.56034469604492, 54.608838762555806, 54.928563594818115, 53.51895127977644, 50.09033489227295, 44.362062794821604, 46.5630019732884, 44.056675570351736, 48.36735534667969, 45.255347524370464, 55.24608237402779, 55.10393960135323, 59.64114107404436, 58.240874086107524, 56.78203725814819, 55.92932653427124, 54.90563801356724, 53.444428375789094, 55.992468288966585, 55.91868189402989, 62.91434710366385, 63.01743752615792, 65.67212881360734, 56.9782509122576, 46.720180647713796, 37.162370681762695, 26.722806521824428, 24.03157639503479, 26.41371590750558, 23.367118426731654, 33.38071632385254, 39.24600689751761, 36.42698376519339, 15.916007484708514, 9.274537120546613, 8.54833311694009, 7.20826575585774, 3.384004827056612, 1.0079411885568073, 1.009112502847399, 5.763737005846841, 1.382346498114722, 11.762834685189382, 4.249390150819506, 10.690905690193176, 12.45458778313228, 11.404602936335973, 10.356745106833321, 11.799083437238421, 3.5818769293172017, 2.5894529138292586, 0.19890659675002098, 46.751180035727366, 52.51242480959211, 19.981504440307617, 55.19564887455532, 62.62034102848598, 62.55034487588065, 43.00554861341204, 64.05975069318498, 63.918292318071636, 3.7161558611052374, 0.36272785759397913, 0.263426591775247, 0.2140950738851513, 0.1533624849149159, 0.22964149181331905, 0.130083563338433, 0.25508156099489754, 0.2322900311223098, 0.2842991431908948, 0.20471915842166968, 0.2996196768113545, 0.24132035513009342, 0.14926312917045184, 0.2471218023981367, 0.15191630965897016, 0.15010311481143745, 0.1872454703386341, 0.2633628909076963, 0.2472252111349787, 0.2876076528004238, 0.2432482631078788, 0.2485142376806055, 0.14783243808363164], [0.06120415723749569, 0.05334883535813008, 0.062006538467747827, 0.1296303290873766, 0.08464532332228762, 0.014320724144844072, 0.027767888735979795, 0.015779817011207342, 0.06335632782429457, 0.026456346702096716, 0.07895580719092063, 0.03368850710934826, 0.047439853860331435, 0.040083021125090976, 0.06611771429223673, 0.02776588366499969, 0.12112762033939362, 0.07039631863257714, 0.11832191874938351, 0.052109304549438615, 0.10008604585060052, 0.0800674171852214, 0.09120631590485573, 0.13373465170817717, 0.13194148721439497, 0.06567247996905021, 0.05599445018119045, 0.08642620633223227, 0.07261982360588652, 7.585662807737078, 83.84966550554547, 50.94365010942732, 46.93642943246024, 61.09052835191999, 57.83002362932478, 52.111333097730366, 41.237694127219065, 34.508051122937886, 96.96967097691127, 23.895468132836477, 0.033539382075624805, 2.177018484898976, 5.862198625292097, 2.793652219431741, 4.956224313804081, 3.7285866226468767, 1.249157999243055, 3.870215662888118, 7.257710439818246, 0.9372773574931281, 0.6790075504354068, 2.784619778394699, 1.6955781302281787, 3.791653249944959, 5.935076977525439, 8.390762737819127, 15.182300295148577, 16.862532785960607, 19.570400374276296, 14.809036118643624, 10.57175624370575, 4.4936918531145364, 8.185172489711217, 16.427436590194702, 21.2436203956604, 23.554968186787196, 16.485478367124283, 5.678345816476004, 4.7165344783238, 13.517280885151454, 21.956038304737636, 22.929090091160365, 14.931862899235316, 18.673535585403442, 27.915718419211252, 43.165232113429475, 46.13357898167202, 49.25259058816092, 48.31416688646589, 45.78311879294259, 46.076989378247944, 55.09444836207798, 58.950566564287456, 60.62485313415527, 58.61628178187779, 57.062438760484966, 62.28896059308733, 56.763259751456125, 59.06117493765694, 22.187401158469065, 52.26638214928763, 60.00838116237095, 53.09701149804251, 52.0262211390904, 50.524277687072754, 46.02065338407244, 38.632870061056956, 41.60624395098005, 42.12181765692574, 40.60239601135254, 44.42599664415632, 48.644418239593506, 49.86430999210903, 51.72122301374163, 50.985707555498394, 47.57123075212751, 44.3796660559518, 46.330581256321494, 49.040566308157786, 49.13834135872977, 52.90215621675764, 54.9990565436227, 56.41155930927822, 57.60992554255894, 49.82562242235456, 42.09722450801304, 40.25455181939261, 23.309514386313303, 12.932638611112322, 15.004143272127424, 15.176319633211408, 23.69911551475525, 34.84617478506905, 30.633304800306046, 12.811097247259957, 6.921883591583796, 4.823993580681937, 3.770212411880493, 2.6374202370643616, 0.9653657759938921, 1.4555723688432147, 1.1094872653484344, 0.7892391468797411, 4.368298147405897, 3.194232587303434, 5.73450767142432, 7.266596751553672, 7.346526656832014, 2.976106269018991, 1.1852163331849235, 1.9624609351158142, 0.23258682233946665, 0.056985420041850636, 41.165943554469514, 36.4704794883728, 33.25674656459263, 43.46658590861729, 55.748120989118306, 35.32806709834507, 43.3057142666408, 56.02894980566842, 9.143642612865992, 0.1851677961115326, 0.07215476927480527, 0.06755558427955423, 0.06781685418848481, 0.07682652359030076, 0.042995754828942676, 0.04726608104205557, 0.09704510974032537, 0.07969514573259012, 0.07463159851197686, 0.07133045779275042, 0.05229267185287816, 0.06232420142207827, 0.13729179011923925, 0.04270852417019861, 0.03507256248433675, 0.047660357385341606, 0.05766506107257945, 0.06368931888469628, 0.06032794461186443, 0.06473101263067552, 0.02769212012312242, 0.018731125430869203, 0.039148088078945875, 0.01605517161078751, 0.09632628331226961, 0.027644510713538954, 0.044096131676009724, 0.06821139516042811, 0.031240217055061033, 0.003713430046835648, 0.049636271715696366, 0.1683075986802578, 0.05536718526855111, 0.06046006895069565, 0.038979696043367894, 0.15883058149899754, 0.05473986607311027, 0.05701156399611916, 0.07329139006989342, 0.06043179439646857, 0.03610858367756009, 0.1854504466589008, 0.019594634184613824, 0.15381665554429802, 0.07095646286117178, 0.11610407275812966, 0.07885969270552907, 0.14604128205350467, 0.12647458485194615, 0.08709455654025078, 0.06099474097469023, 0.15821645302431925, 10.166579859597341, 95.2291819708688, 60.792395046779085, 48.87918744768415, 64.67447171892438, 59.38006946018764, 36.998678071158274, 33.292644432612825, 47.0864896774292, 91.53399099622453, 26.006127629961284, 0.06761591961341244, 2.4739580026694705, 9.688765270369393, 8.623323287282672, 7.7464727844510755, 8.296254209109716, 3.7139637044497897, 2.904181557042258, 6.213640681334904, 5.073054364749363, 0.1354726513049432, 1.5311966708728244, 0.3594857629920755, 2.6570033005305698, 4.996497375624521, 9.044451866831098, 16.287529400416783, 19.256836857114518, 23.89759601865496, 18.698528255735123, 11.713961924825396, 5.754432933671134, 11.542579395430428, 22.79106065205165, 28.01939422743661, 26.934417384011404, 22.285909243992396, 10.028240357126508, 8.890606590679713, 14.568219372204371, 26.455375569207327, 29.415897028786794, 18.977479321616038, 30.99543101446969, 45.908735275268555, 53.66340432848249, 53.044837474823, 53.89980983734131, 50.73307452883039, 48.58673776899065, 49.718932832990376, 58.00171709060669, 63.71283408573696, 65.44686126708984, 62.37426362718855, 59.38316835675921, 64.36950833456856, 59.762533051627024, 61.23314012799944, 23.788768121174403, 57.31098277228219, 63.9059453691755, 58.035217830113, 59.07067312513079, 53.86877223423549, 48.217552185058594, 41.34891741616385, 43.63390895298549, 43.81361368724278, 43.54882826123919, 47.08244235174996, 51.057062080928254, 53.86573934555054, 57.15552030290876, 55.692483288901194, 51.667169502803254, 50.179786000932964, 50.237713132585796, 52.612482343401226, 53.93170206887381, 58.45716108594622, 61.01081166948591, 63.51893070765904, 63.41609042031424, 57.22561720439366, 46.90694127764021, 45.156332220349995, 27.286162989480154, 16.864037070955547, 18.354293652943202, 18.460099084036692, 25.95510527065822, 37.48631307056972, 36.30749906812395, 14.975520168031965, 8.86940676825387, 7.143523309912, 3.829659027712686, 3.227918973990849, 0.67755624545472, 1.3024640360048838, 0.8858090649758066, 1.7295422277280261, 4.600185590130942, 6.087671143668039, 7.958552650042942, 8.698825018746511, 6.595003851822444, 4.9963931526456555, 2.896325315747942, 2.176896891423634, 0.15048306728047983, 0.02104063641412982, 47.772481850215364, 37.67089196613857, 34.61495958055769, 40.17021458489554, 54.31271696090698, 37.67551599230085, 45.7088668687003, 64.61562047685895, 7.491587672914777, 0.19288785542760575, 0.03711422685799854, 0.01952933706343174, 0.12451660420213427, 0.07050709625972168, 0.019057027496663586, 0.04539561444627387, 0.017539821498628174, 0.06268130083169256, 0.05142526661178895, 0.12703327701560088, 0.05365743308461138, 0.07939347584864923, 0.07102325106305735, 0.05083040513896516, 0.07595107092389039, 0.057428523765078614, 0.059148331837994714, 0.01873847226878362, 0.015124693147039838, 0.03605881313394223, 0.048464014261428795, 0.07527213556958096, 0.06765465717762709, 0.14600192702242307, 0.1926094660801547, 0.17991608434489795, 0.17770509155733244, 0.18772105553320476, 0.2341021810259138, 0.17484947693135056, 0.14284810982644558, 0.20412060911101954, 0.17122824410242693, 0.278124175965786, 0.2019138910940715, 0.35470906645059586, 0.16760557277926377, 0.2230136024632624, 0.14381181954273156, 0.22668440906064852, 0.1678014522684472, 0.3540911924626146, 0.17068538894610746, 0.2515259017901761, 0.19569803534873895, 0.2281810673219817, 0.3252999202481338, 0.20087632962635585, 0.18893747883183615, 0.215197693290455, 0.18511146413428442, 0.23542369582823344, 14.733458825520106, 114.30294595445905, 67.72014508928571, 66.45015335083008, 75.47289643968854, 79.94709859575543, 66.7394277027675, 52.91973515919277, 46.08575800486973, 110.8330989565168, 29.560832977294922, 0.21020970094416822, 5.536242127418518, 19.650202172143118, 9.775544796671186, 14.24820271560124, 11.044740097863333, 2.733672112226486, 8.321710671697344, 16.771278619766235, 8.880002771105085, 2.1428429016045163, 2.6797636449337006, 1.3800322051559175, 2.6864673537867407, 5.528911343642643, 10.99203280040196, 21.857931477682932, 28.260303906032018, 28.061086893081665, 21.59435330118452, 14.125045895576477, 7.8254121371677945, 14.331704429217748, 24.57878351211548, 30.08331319264003, 29.318987028939382, 23.169145141329082, 12.760815739631653, 13.761244297027588, 19.989163092204503, 35.85280547823225, 41.99011107853481, 34.67837578909737, 51.604468958718435, 55.88250262396676, 62.76817784990583, 58.84935910361153, 58.28606864384243, 55.14707749230521, 51.69639015197754, 52.9136381149292, 61.350536891392295, 65.83666910443986, 66.4746596472604, 62.56051703861782, 61.976791926792686, 65.7254284449986, 59.980609212602886, 60.75751508985247, 26.86516989980425, 57.82081726619175, 65.52061639513288, 59.66493170601981, 59.80800206320626, 57.200412614004954, 51.101697308676584, 42.086652823856895, 45.74101618358067, 47.291475432259695, 45.261267389569966, 49.841787406376426, 52.97368097305298, 54.28348241533552, 58.13269758224487, 55.826823234558105, 53.29088708332607, 52.76333120891026, 51.58508348464966, 54.77926417759487, 56.35233633858817, 59.19653279440743, 60.610602378845215, 63.51815945761544, 62.34751306261335, 56.86532531465803, 48.39588812419346, 49.074591636657715, 28.760273694992065, 19.45116060120719, 20.136285986219132, 22.30859511239188, 30.315389973776682, 42.1764999798366, 39.93802315848214, 19.158728293010167, 10.966788257871356, 9.146733692714147, 4.463801571301051, 3.0507310075419287, 0.5660975319998605, 1.9648374361651284, 3.2859883265835896, 2.7473314021314894, 14.019503627504621, 12.545372077396937, 11.612700615610395, 15.685692071914673, 12.68921889577593, 13.132591264588491, 5.049822194235666, 7.1725780708449225, 0.8816801522459302, 0.18797208634870394, 51.12252800805228, 49.40112917763846, 49.333870615277974, 58.859420095171245, 72.50664097922188, 49.86068650654384, 54.79075649806431, 76.47392341068813, 21.257621015821183, 0.4648173866527421, 0.2633584940007755, 0.26932658946939875, 0.3141790027064936, 0.14466340813253606, 0.24603497928806714, 0.11745689516620976, 0.23490771065865243, 0.23393702560237475, 0.17028392691697392, 0.25323108743344036, 0.19652440957725048, 0.2417720423213073, 0.2578244980956827, 0.13461578371269362, 0.1426561251282692, 0.15368507403348172, 0.18617505420531544, 0.3033940957060882, 0.24410357006958552, 0.1355864823396717, 0.16770101551498684, 0.13567170633801393, 0.1328378455447299], [0.12666461536926882, 0.081685363581138, 0.02666362897226853, 0.060932994287993224, 0.06517194504184382, 0.028908743589584316, 0.04414990557623761, 0.034416656608560255, 0.032003212720155716, 0.07117847273392336, 0.1277269705065659, 0.07256751534129892, 0.10788346494414977, 0.05111180378922394, 0.11486060305365495, 0.08985584801329033, 0.04826894222891756, 0.09480977790164095, 0.09150101044880492, 0.12482581261013236, 0.05725398420223168, 0.13369773940316268, 0.1381548052387578, 0.12811476684042386, 0.033043352620942254, 0.2577600915517126, 0.08712007624230214, 0.19073229895106383, 0.029973717872053385, 0.11672756501606532, 27.76748033932277, 91.5426276070731, 62.57560852595738, 40.63345793315342, 64.32761069706508, 48.56844316210066, 47.04086780548096, 23.62698973928179, 72.37340232304165, 25.168784584317887, 1.0252995256866728, 3.6170278659888675, 8.57989878313882, 5.163326663630349, 3.9261021954672675, 6.477319606712886, 4.433932134083339, 1.7924431839159556, 1.5644573718309402, 3.292251693350928, 0.4644501092178481, 1.470278991120202, 1.5050122759171893, 1.7523855162518365, 2.070913847003664, 3.706186498914446, 8.593838606561933, 11.255102021353585, 13.587169340678624, 10.520785127367292, 5.6123166510037015, 5.7117588349751065, 5.222646909100669, 11.521267533302307, 20.002003363200597, 18.190941504069738, 10.853844421250479, 8.945483463151113, 23.180467230933054, 35.6135824748448, 46.414789949144634, 35.813655853271484, 19.409778867449077, 23.54558985573905, 27.918457746505737, 36.89011594227382, 41.33011211667742, 46.30635983603341, 46.50217396872384, 46.308294909340994, 45.73897688729422, 49.283423219408306, 59.601432119097026, 59.14197553907122, 60.611853054591585, 55.42523125239781, 60.64068807874407, 55.37645837238857, 59.95758983067104, 19.622864484786987, 49.7314395904541, 53.42387907845633, 52.809067726135254, 55.8790146282741, 54.04280029024397, 48.54486097608294, 42.44814327784947, 43.89195115225655, 42.4674835886274, 42.12906462805611, 45.48609719957624, 46.47382531847273, 46.26810652869088, 47.13746861049107, 46.58627496446882, 45.02488967350551, 45.41871704374041, 44.67815719332014, 50.070032255990164, 48.077605043138774, 49.75329514912197, 51.7866507257734, 56.03455352783203, 53.340215819222585, 50.907255445207866, 46.55583838054112, 42.78146573475429, 27.995841571262904, 11.38887916292463, 6.999135400567736, 13.58168373789106, 22.591862746647426, 27.143749237060547, 26.10479552405221, 13.830245988709585, 7.99920916557312, 5.097445581640516, 3.0704428298132758, 0.9062031134963036, 0.5098184262003217, 3.8014254570007324, 0.6202627569437027, 2.8043155329568044, 4.818616543497358, 4.655862808227539, 5.164589498724256, 8.075169478143964, 5.118296691349574, 5.158705243042537, 1.3613001874514987, 2.167752193553107, 0.11911490905497756, 0.5965302618486541, 39.97876739501953, 30.99281849179949, 27.19808762414115, 62.87636130196707, 44.16477911812918, 34.51743466513497, 56.19662025996617, 28.188327516828263, 0.24479060034666741, 0.04172053986362048, 0.02268565466095294, 0.06751520466059446, 0.04740604246035218, 0.07880126405507326, 0.056723325712872405, 0.034448853095195124, 0.026411629548030238, 0.1380169540643692, 0.14216059100415024, 0.09813437557646207, 0.12634450968887123, 0.06448456871190242, 0.19316372062478745, 0.10892390340034451, 0.06466127958680902, 0.046325740071811845, 0.04708411491342953, 0.04310473433828779, 0.008952680941937225, 0.023119535396939943, 0.052411059250256846, 0.016266811772116592, 0.12408164968448025, 0.08027777661170278, 0.023374031830046858, 0.04393005683752043, 0.04832854474495564, 0.06795387755015067, 0.01760201941111258, 0.040162823628634214, 0.022526931749390702, 0.0708746247525726, 0.05218117158593876, 0.01045345451815852, 0.022640102908813527, 0.06247145709182535, 0.0424364282350455, 0.08153184503316879, 0.05388217406081302, 0.015741495049691627, 0.057272555705692084, 0.09536616304623229, 0.12997875681945256, 0.12646739238074847, 0.135215215118868, 0.1206177148435797, 0.12168785956289087, 0.0490569113753736, 0.25832216281976017, 0.027962560432830026, 0.1345987253423248, 0.03156402075131025, 0.17566846869885921, 33.52614906855992, 104.08140931810651, 65.32598345620292, 45.63045644760132, 68.11501121520996, 50.24559933798653, 35.42549821308681, 35.41819565636771, 91.5396259852818, 24.975909539631434, 0.7978992078985486, 3.705725746495383, 7.615645153181894, 8.83609710420881, 8.519296595028468, 6.839708115373339, 5.712652547018869, 4.118298053741455, 4.838152272360666, 3.419309275490897, 1.2035095287220818, 1.8032704315015247, 0.9690692744084767, 1.1216129575456892, 2.422547629901341, 4.1327581235340665, 5.052121613706861, 10.499743376459394, 16.315004314695084, 12.247124995504107, 6.630269433770861, 6.622267280306135, 7.494834218706403, 16.784930092947825, 24.865923030035837, 22.260517052241735, 14.693763766969953, 12.594550558498927, 26.365992205483572, 34.64904396874564, 48.50184120450701, 40.00670262745449, 25.36205915042332, 32.91138635362898, 42.14612940379551, 47.92669364384243, 50.08738885607038, 52.6264899117606, 52.18340676171439, 50.554102829524446, 49.04218176433018, 52.69903257914952, 63.00512531825474, 60.173602376665386, 62.74376882825579, 59.47321006229946, 65.59063339233398, 60.00451101575579, 63.581749371119905, 21.09130719729832, 52.88845436913626, 56.878123896462576, 57.18581792286464, 58.342620032174246, 58.82825742449079, 51.58376680101667, 46.390540736062185, 45.816543102264404, 45.6198639188494, 44.928136008126394, 48.082201276506694, 48.39021839414324, 50.598692893981934, 47.65850012642996, 50.95653554371425, 50.493785517556326, 48.30303587232317, 52.24819871357509, 55.85190970557076, 55.03636142185756, 56.76640381131853, 57.72576938356672, 61.767025811331614, 59.21552916935512, 57.825260639190674, 51.364637987954275, 47.270293848855154, 32.827167238507954, 14.86721338544573, 8.911262716565814, 18.243075575147355, 26.33228996821812, 28.709046363830566, 32.673886503492085, 18.548454114368983, 8.49058403287615, 5.915528655052185, 3.300713513578687, 1.0762756360428674, 0.37228065356612206, 3.395810033593859, 0.7018393852881023, 3.9366391386304582, 4.730553337505885, 8.79708296912057, 6.264803741659437, 8.376406891005379, 5.344163954257965, 5.76518223115376, 2.872877751077924, 1.0604457940374101, 0.12732748979968683, 1.2744170895644595, 44.86779090336391, 41.96283939906529, 32.278989110674175, 58.225619316101074, 53.49278783798218, 34.72329936708723, 63.02697740282331, 27.899414471217565, 0.40661691395299776, 0.07816397718020848, 0.07640818639525346, 0.03793455533949392, 0.02757193800061941, 0.09211237050060715, 0.050938824856919904, 0.024124673068789498, 0.07316069065460137, 0.09366543537804059, 0.06660693125533206, 0.13486358470150403, 0.13565832562744617, 0.04085412189098341, 0.10823441004114491, 0.05382904816152794, 0.053956901122416766, 0.04159506856064711, 0.06046989413776568, 0.06149701973689454, 0.03343070451436298, 0.040519580378064086, 0.04507151558729155, 0.00791202874721161, 0.03096275730058551, 0.22681493205683573, 0.13469688221812248, 0.07876178010233811, 0.19050944090953895, 0.13689731700079782, 0.1806100628205708, 0.09624051648591246, 0.099176822496312, 0.14141368679702282, 0.17982859403959342, 0.17661212091999395, 0.16054244392684527, 0.21815029771200248, 0.20960162500185625, 0.17003426674221242, 0.1838769239506551, 0.19137816929391452, 0.2477658949792385, 0.14561729266175202, 0.33101410791277885, 0.2808792452727045, 0.2846323310264519, 0.2019178673092808, 0.27104694715567995, 0.17153648899069854, 0.31207975106579916, 0.2883373222180775, 0.3032863443451268, 0.10324923361518554, 0.19421904613929136, 48.48088891165597, 118.91459737505231, 82.89127268110002, 59.3679587500436, 81.50793497903007, 68.45452104296002, 63.91380378178188, 33.288478987557546, 91.76109981536865, 32.33808701378958, 1.372427076101303, 8.541395340647016, 17.29762203352792, 15.287892069135394, 14.842524698802404, 19.188329356057302, 13.117973123277936, 6.655440585953849, 11.704453315053668, 9.865516151700701, 1.8331048020294733, 1.5325375646352768, 0.707862876355648, 1.5102782504899162, 1.4396641424724033, 3.5421275879655565, 7.233503350189753, 16.11508205958775, 19.64881600652422, 13.454161712101527, 8.31321563039507, 7.660207424845014, 9.48822202001299, 17.999355350221904, 26.00975980077471, 22.7554771900177, 18.160207884652273, 15.42148334639413, 31.76258509499686, 39.75316286087036, 52.834692682538716, 55.05355821337019, 49.03497995649065, 52.665048939841135, 55.15073224476406, 54.44767529623849, 55.613746302468435, 54.17414208820888, 56.226306438446045, 54.4601924760001, 52.61356626238142, 52.64372491836548, 64.10021005358014, 61.67498302459717, 65.29262515476772, 60.54593549455915, 65.46476677485875, 59.89588287898472, 62.98415565490723, 24.2566111768995, 52.29396302359444, 56.385479245867046, 58.48771926334926, 60.848501750401084, 60.90699863433838, 53.660652841840474, 48.1481431552342, 49.16229179927281, 47.02500854219709, 46.803684098379954, 49.0536984034947, 50.54579278400966, 51.85510785239083, 48.083246980394634, 53.186438288007466, 53.04616458075387, 49.97530051640102, 51.533691133771626, 56.50267103740147, 56.12414012636457, 56.80421243395124, 59.45160811288016, 64.0404485974993, 59.75215939113072, 60.34695298331124, 53.35317073549543, 50.322272709437776, 36.78325959614345, 18.080411297934397, 12.112621767180306, 21.321269989013672, 28.47973322868347, 37.4546605518886, 39.65485627310616, 22.546477113451274, 10.96066689491272, 7.517272557531085, 3.489905361618314, 2.052463774170194, 0.7095018912638936, 5.326533334595816, 2.1032779046467374, 9.079990165574209, 10.249629940305438, 12.92182113443102, 16.75640252658299, 16.5016450881958, 14.165774498667036, 9.726038881710597, 6.950342544487544, 5.092696922166007, 0.3536745991025652, 1.391165282045092, 53.57963684626988, 47.16254465920584, 43.24584511348179, 79.79038892473493, 60.41498974391392, 45.97163036891392, 68.4684591293335, 49.70335497174944, 0.4616934657096863, 0.1517945804766246, 0.1425425112247467, 0.18619754085583345, 0.13918741340083735, 0.19515900712992462, 0.12031525107366697, 0.07481219739254032, 0.2671909954931055, 0.23895910754799843, 0.1671023169266326, 0.32377432925360544, 0.2335359299821513, 0.1091572515932577, 0.41251395323446816, 0.1470015040997948, 0.21446976092244896, 0.1877826258007969, 0.1866939299340759, 0.1900500048484121, 0.10263211280107498, 0.18771592580846377, 0.133303985531841, 0.12815228982695512, 0.23879810475877353], [0.036423997288303714, 0.0826678890734911, 0.05420487513765693, 0.06401494105479547, 0.1411638366324561, 0.021617072268522212, 0.06281822241310563, 0.014594630072159427, 0.12748277932405472, 0.030756058570529734, 0.02415400104863303, 0.10332213541758911, 0.0941472766654832, 0.04377997846209577, 0.08792928353484188, 0.06886049532996756, 0.03901401973728623, 0.08542854950896331, 0.10595653405679123, 0.18092897427933557, 0.08007089128451687, 0.0987119988671371, 0.09442333185247012, 0.2091971638479403, 0.06701475794294051, 0.14387542541537965, 0.08494508652282612, 0.07943443900772504, 0.05752541856574161, 0.1605790305350508, 1.1060197885547365, 29.093229634421213, 70.39408983503068, 47.8052009173802, 54.4004727091108, 55.21031999588013, 49.737154483795166, 27.045930760247366, 40.30948427745274, 21.18922642299107, 1.9998468032905032, 3.129210476364408, 3.449488341808319, 13.2053701707295, 6.424598412854331, 7.102574970041003, 5.274566888809204, 5.510282354695456, 4.201985197407859, 2.5253885686397552, 0.5342695713043213, 1.198277969445501, 1.7892471211297172, 1.9116635237421309, 2.0183685294219424, 1.349000898855073, 2.396542693887438, 4.347775340080261, 4.350037847246442, 3.261673539876938, 3.1525062663214545, 3.0190443992614746, 5.950316982609885, 11.24694744178227, 18.212249892098562, 16.751385927200317, 12.065832597868782, 16.662405558994838, 32.6290636743818, 39.212791034153526, 49.597704138074604, 54.148437227521626, 41.592010566166465, 29.83830233982631, 32.7258312361581, 36.89146736689976, 42.82954032080514, 45.53711782182966, 49.516677720206125, 47.55668469837734, 46.956982203892295, 45.88472230093819, 54.977631773267476, 59.14688096727644, 57.50222151620047, 55.38781172888619, 60.83397306714739, 55.97855799538748, 58.51369857788086, 16.382156917027064, 47.119191374097554, 56.39693335124424, 50.971293517521445, 56.69416686466762, 53.27207830974034, 50.15381016050066, 41.29350553240095, 43.99668482371739, 42.90371234076363, 43.596280983516145, 44.54363659449986, 47.78510672705514, 49.51701123373849, 50.660872323172434, 49.938165869031636, 45.63109915597098, 48.068395205906455, 48.502421379089355, 47.99549470629011, 50.432978357587544, 46.338172163282124, 47.0472914150783, 46.557370458330425, 49.768060071127756, 50.74907623018537, 50.71922329493931, 46.39167676653181, 36.63516569137573, 10.041722467967443, 3.4673061285700117, 8.57420039176941, 21.145803655896867, 27.310879468917847, 21.32741219656808, 13.380055700029645, 10.938402261052813, 5.68470515523638, 2.2177692353725433, 2.301010174410684, 2.1488643842084065, 1.6445744442088264, 0.7209240783538137, 2.052005627325603, 2.915793082543782, 4.0698191693850925, 6.44108909368515, 5.076319583824702, 4.602146284920829, 2.2368717874799455, 1.4638993505920683, 0.18674198378409657, 0.032198539203298945, 0.9288715571165085, 33.613501821245464, 25.857587303434098, 52.266086850847515, 68.23434652600969, 27.042541776384624, 41.48679052080427, 53.66844177246094, 2.9948707478387013, 0.3009712371442999, 0.09446291758545808, 0.06562672635274273, 0.07582532481423446, 0.05964172179145472, 0.029385594251964773, 0.04212362698412367, 0.024275219633377025, 0.030572453779833655, 0.07703644196902003, 0.11131385979907853, 0.1261961276509932, 0.22317132114299706, 0.02455309159787638, 0.036740849393286874, 0.04331197589635849, 0.02530422986352018, 0.061928819066711834, 0.0733881423782025, 0.05222314236951726, 0.07808993543897357, 0.0281086914307837, 0.015184427977406552, 0.007360808950449739, 0.05970806894557817, 0.09042269616786923, 0.0656481816300324, 0.062228555125849586, 0.04228891132931624, 0.12498008433197226, 0.040143142720418315, 0.06237014502819095, 0.07748809523348298, 0.06991907781256096, 0.05521347673077669, 0.05326739079984171, 0.03790975488456232, 0.06971901854766266, 0.030403613911143372, 0.10442803893238306, 0.12865705202732766, 0.05836333467492035, 0.06929661692785365, 0.12725629790553025, 0.14299533835479192, 0.0969855615070888, 0.08330524380185775, 0.11241406361971583, 0.16593109763094357, 0.22471929022244044, 0.0816610109593187, 0.1027536384229149, 0.14296624277319225, 0.0847006578530584, 0.16472969709762506, 1.36546020422663, 33.98290279933384, 90.09717300959996, 48.494052273886545, 64.39316695077079, 57.81890651157924, 50.40839563097273, 21.71913078853062, 58.07983916146414, 21.769526072910853, 1.5347622909716196, 1.945355555840901, 4.298964244978769, 10.793041603905813, 6.747308799198695, 13.893724731036595, 10.134704998561315, 5.923917302063533, 3.9589632664408003, 2.037504085472652, 1.1928421982697077, 0.32684293602194103, 1.2213587995086397, 0.980970235807555, 1.5739255951983588, 1.477540835738182, 2.300226982150759, 4.570148961884635, 7.445216264043536, 5.889195416654859, 4.098047094685691, 3.975162122930799, 7.565394043922424, 14.297450678689138, 21.067929983139038, 21.164103473935807, 16.03337124415806, 21.16915307726179, 33.99297421319144, 43.78935752596174, 55.867365973336355, 59.06531606401716, 46.53752987725394, 39.40613508224487, 45.08637775693621, 48.439505440848215, 51.58670588902065, 51.00492974690029, 55.00365972518921, 51.38481903076172, 49.833960260663716, 50.08907379422869, 60.661942618233816, 62.311514445713584, 62.047545433044434, 60.002801758902415, 64.62270069122314, 61.11802932194301, 63.686180795942036, 18.236874307904923, 49.823659556252615, 59.55294064113072, 55.24435574667794, 62.24790368761335, 58.04667888368879, 53.24706826891218, 44.57599088123867, 47.44620486668178, 45.23165764127459, 46.37932634353638, 47.68296473366873, 49.606552668980186, 50.89995983668736, 53.95940106255667, 52.23677587509155, 48.636115142277305, 52.357268060956685, 54.019798278808594, 54.08429493222918, 57.18910094669887, 53.91206298555647, 55.45419829232352, 55.61313486099243, 59.62780053274972, 57.616971015930176, 58.340681484767366, 55.12415885925293, 42.07752289090838, 13.71326698575701, 5.377083216394697, 11.143216047968183, 27.289605821881974, 31.430468150547572, 27.4128668648856, 18.121678386415752, 13.983213186264038, 7.825398240770612, 3.3310817011765073, 1.7976763716765811, 1.4785737288849694, 2.595763615199498, 1.1061409477676665, 3.8791870900562833, 6.270657598972321, 5.995059038911547, 9.786105190004621, 7.743848102433341, 4.331817064966474, 1.6321288091795785, 1.6096988299063273, 0.35086779828582493, 0.03729174858225243, 1.3364548406430652, 35.46023573194231, 36.80940914154053, 44.335711751665386, 73.57469722202846, 28.496236937386648, 43.88066380364554, 58.81356198447091, 2.4171289035252164, 0.1498898376843759, 0.041980452702513764, 0.09897135530731507, 0.08354470559528895, 0.06264481600373983, 0.0648155648793493, 0.030757368143115724, 0.06628170942089387, 0.02174263178104801, 0.12894969061017036, 0.06994639563241176, 0.10484583329941545, 0.08559491951018572, 0.05500676443002053, 0.026408779700951915, 0.054964769897716384, 0.04233833921274968, 0.10442740110946552, 0.05143050829480801, 0.07222209351935557, 0.0545400951855949, 0.017505088987361108, 0.03367280241634164, 0.019095334191141383, 0.03681723547301122, 0.16838472097047738, 0.11827306422804083, 0.11924943540777479, 0.12204592249223165, 0.23024859066520417, 0.09379207715392113, 0.09993777237832546, 0.12710924579628877, 0.20014938791947706, 0.22514042976711476, 0.11845307956848826, 0.14129731804132462, 0.20507325870650156, 0.22124046832323074, 0.17813229720507348, 0.23508863523602486, 0.21692957250135286, 0.1437462866306305, 0.2156238539942673, 0.23256804049015045, 0.17234063441199915, 0.31381834777338163, 0.21951287745365075, 0.36676861505423275, 0.2495347543486527, 0.27036564371415545, 0.24881149030157498, 0.2049908031310354, 0.21306375493960722, 0.345638600311109, 2.4669943877628873, 59.20298072269985, 103.84549018314907, 65.86478151593889, 78.16650458744594, 67.9087747846331, 70.4831657409668, 38.682844979422434, 56.27294969558716, 25.611610651016235, 1.9766463339328766, 5.454955152102879, 14.26620636667524, 23.02548939841134, 17.780219588960918, 20.40414946419852, 19.34536906651088, 7.0327655502728055, 10.564894029072352, 8.41913570676531, 2.344701315675463, 2.5276793028627123, 1.9506183820111411, 2.6012744052069525, 2.0448937118053436, 1.4006065811429704, 1.0950655192136765, 4.009931342942374, 6.608260580471583, 6.641919391495841, 5.124551807131086, 5.04789320060185, 8.07540658542088, 15.551876715251378, 20.624033893857682, 22.207477978297643, 17.456225088664464, 23.58387095587594, 35.36754328863961, 45.81973579951695, 55.043392998831614, 62.86830139160156, 61.1159587587629, 55.55975185121809, 60.98781313214983, 59.62222112928118, 59.906638690403526, 55.81743621826172, 60.50043174198696, 55.05769239153181, 53.36228677204677, 52.40987982068743, 62.531056676592144, 64.92382866995675, 62.08894974844796, 61.15445177895682, 66.0873670578003, 63.024774823869976, 64.30671746390206, 22.320243767329625, 49.76071235111782, 61.74324212755476, 57.80285964693342, 63.938991001674104, 60.4775721686227, 57.19390215192522, 47.78473847252982, 50.7466721534729, 48.457365785326274, 49.96186964852469, 49.906280585697715, 53.596604347229004, 53.864877768925254, 57.010591302599224, 55.16069943564278, 52.55858516693115, 53.355856214250835, 55.71449518203735, 54.65414101736886, 57.79283339636666, 54.5996219771249, 59.48105457850865, 57.31065273284912, 59.770815304347444, 57.449172019958496, 55.827431201934814, 52.29924365452358, 40.79284960883004, 16.355255229132517, 7.657222305025373, 13.729993905339922, 26.903834887913295, 31.366767065865652, 34.69907099860055, 21.062312364578247, 14.447773218154907, 9.096856917653765, 3.782191106251308, 2.4377457286630357, 1.47344628402165, 4.9273476004600525, 3.443498343229294, 7.4895145041602, 11.165469391005379, 13.569765840257917, 16.276391438075475, 18.043811661856516, 14.550609162875585, 8.389781304768153, 3.7908047011920383, 0.7739085980824062, 0.22447960451245308, 2.093592332942145, 53.04464987346104, 40.97610834666661, 66.92522948128837, 83.40784345354352, 40.45722729819161, 52.009639263153076, 77.85635784694126, 8.403446674346924, 0.6546402179769107, 0.24020519639764512, 0.1930049027183226, 0.2945650523262364, 0.1275177781603166, 0.23913669373307908, 0.13519753249628202, 0.2605405109269278, 0.09061387340937342, 0.2432112693786621, 0.15389159295175756, 0.3281700962356159, 0.2531890725450856, 0.23272152511136873, 0.09028376612280097, 0.2288558025445257, 0.15586983465722629, 0.2554715557822159, 0.19548732308404787, 0.10900781104075057, 0.1527354507041829, 0.0945852981614215, 0.07510508024798972, 0.16096464198614868, 0.07875027893377201], [0.026940340641885996, 0.06986307153212172, 0.04526575980708003, 0.06051077587263925, 0.08840995095670223, 0.05203789213140096, 0.021524226625583003, 0.042841018310614994, 0.014087833963068468, 0.07833295275590249, 0.08119647231485162, 0.010031970616962229, 0.03253444117893066, 0.09278013038315944, 0.01376546367204615, 0.103420190513134, 0.038859133941254446, 0.09502800154898848, 0.08183565230241843, 0.04018971736409834, 0.1258533996130739, 0.07426252295928341, 0.09044774768075772, 0.009918681562079914, 0.03839842562696763, 0.027698963148785487, 0.10932649858295918, 0.08128933661750384, 0.13037025795451232, 0.013237808548313166, 0.18618691499744142, 3.6777748806135993, 52.03384678704398, 69.36272008078438, 42.831048079899375, 68.4526172365461, 49.652834619794575, 39.00155190059117, 38.70926897866385, 10.670265197753906, 0.2561820905123438, 1.472824203116553, 4.773889686380114, 6.3789891345160346, 7.368605426379612, 5.797420569828578, 5.061137335641043, 5.988165123122079, 3.204832281385149, 1.8745132429259164, 1.9596143450055803, 0.6227340357644218, 1.1740338589463915, 0.9614082340683255, 1.438777704324041, 1.2758421216692244, 0.7246109119483403, 1.7191911488771439, 1.7262320624930518, 1.401644902569907, 0.6728678941726685, 1.2637455250535692, 3.688813396862575, 8.425305707114083, 12.286159106663295, 13.108907461166382, 12.76423077923911, 18.086843592779978, 33.56377356392996, 37.02368116378784, 45.189516816820415, 59.047688484191895, 57.12723766054426, 44.60406160354614, 39.45544992174421, 41.212173393794465, 45.34492370060512, 48.10644701548985, 49.09617968967983, 51.20014633451189, 50.00587259020124, 47.785131045750205, 51.199309076581685, 54.62924214771816, 56.13748066765921, 53.34448548725673, 58.57921314239502, 56.78198862075806, 59.92152867998396, 27.125289610454015, 46.83601754052298, 58.01738180433001, 53.533587660108296, 54.11029509135655, 53.531089782714844, 47.76230273927961, 44.11185468946184, 44.6565066065107, 44.226103918892996, 46.18210172653198, 49.65472105571202, 58.72283240727016, 56.321396010262625, 60.077439308166504, 57.55964837755476, 53.1240017754691, 47.51157699312483, 50.941093172345845, 48.9591577393668, 47.85529048102242, 43.41896295547485, 42.019793782915386, 41.452973638262065, 43.959723881312776, 42.49305643354143, 39.78284209115164, 31.473335061754497, 25.603309290749685, 10.37949698311942, 2.2729107907840183, 8.67845984867641, 13.383866786956787, 20.89741771561759, 24.206780433654785, 20.807949236461095, 12.504851920264107, 5.374162367412022, 3.8067078249795094, 0.7924325498087066, 1.5829831148896898, 3.62292970929827, 0.8116869309118816, 0.944892474583217, 6.406174830027989, 7.694683517728533, 3.8815572943006242, 3.859797707625798, 2.621105649641582, 2.703253550188882, 1.7962565507207597, 0.12237890676728316, 0.037533025456858535, 0.4988678480897631, 22.31398344039917, 40.414381231580464, 63.68841116768973, 41.039503710610525, 38.62484836578369, 56.34591620309012, 24.242874588285172, 0.09200793717588697, 0.0522681529899793, 0.04761053595159735, 0.02846213523298502, 0.04555312278015273, 0.014446622924879193, 0.058827099789466174, 0.065930520051292, 0.045403102080204656, 0.0656459288937705, 0.03846066085887807, 0.06581971528274672, 0.05608473265809672, 0.14278568460472993, 0.042537994749311886, 0.03578606241249612, 0.06694135402462312, 0.044989419635385275, 0.039709779367383034, 0.04643970002819385, 0.03469562949612737, 0.01620804046147636, 0.03992524816255484, 0.027148642410923327, 0.08135535128946815, 0.06631511369986193, 0.04327342492927398, 0.017087881553119848, 0.019312129522274648, 0.013882672962998705, 0.04761107199426208, 0.03236325018640075, 0.11589593892650944, 0.022223562135228088, 0.07802964081721646, 0.035366144230855365, 0.04055399567420993, 0.07357448845037393, 0.0714518069954855, 0.08058657111333949, 0.09722997660615615, 0.06127304889793907, 0.12460071540304593, 0.05765302386134863, 0.05932028618242059, 0.06688872684857675, 0.11203968870852675, 0.15222912787326745, 0.13666646581675324, 0.10672215904508318, 0.26708340698054855, 0.052170026648257456, 0.047246115149131844, 0.04652390283133302, 0.063831831594663, 0.04432907274791172, 0.06691105743604046, 4.184066227504185, 72.23774569375175, 76.95110484531948, 46.30534887313843, 78.17912946428571, 51.319422585623606, 38.521486963544575, 35.69369520459856, 15.392436402184622, 0.6407297072666032, 1.2196640904460634, 2.882738981928144, 4.876551057611193, 6.627936141831534, 7.797575048037937, 8.281187908990042, 9.608606508799962, 5.714018302304404, 2.3784904054233005, 2.23766952753067, 0.9435052233082908, 0.09428201336413622, 0.395910554166351, 1.9700188381331307, 0.4547828308173588, 1.0439530504601342, 0.7894626834562847, 1.3273466208151408, 1.551692662494523, 1.8986143725258964, 1.9596658051013947, 5.261821287018912, 9.793377348354884, 15.913879598890032, 16.38720999445234, 16.34264772278922, 22.332288469587052, 40.09456259863717, 46.02679559162685, 52.381482533046174, 66.56835610525948, 63.29296834128243, 52.35138293675014, 49.29310553414481, 51.103385720934185, 52.246270588466096, 54.74878937857491, 54.81162888663155, 56.33205107280186, 53.388835838862825, 51.33528879710606, 54.3235422543117, 58.028193201337544, 59.60123062133789, 58.80609267098563, 62.57965932573591, 61.2613011768886, 64.87493419647217, 28.759276628494263, 50.17950112479073, 61.9913067136492, 58.83515698569161, 60.960263524736675, 58.70086220332554, 51.67272111347744, 46.97734042576381, 48.27990531921387, 46.68928895677839, 47.94816010338919, 51.19220454352242, 59.65537098475865, 59.06799112047468, 62.7238552910941, 60.61507701873779, 58.633617537362234, 52.288453102111816, 55.4984895842416, 54.76768847874233, 54.526249000004356, 51.75861474445888, 51.741490909031455, 51.38233157566616, 52.15319946834019, 50.97292981828962, 45.09620598384312, 38.16619430269514, 29.259965556008474, 12.841213345527649, 1.9982780303273882, 10.73471234525953, 17.31103379385812, 25.63714701788766, 29.873446328299387, 26.511207818984985, 15.822090421404157, 6.8936426384108405, 5.773566969803401, 1.641872029219355, 2.1565677651337216, 5.215120272977011, 2.953380448477609, 5.588248091084616, 9.759795836039952, 7.149000661713736, 6.066386205809457, 3.57637026480266, 2.5243504643440247, 4.348659932613373, 0.6336783713528088, 0.5464352699262756, 0.18357466374124798, 0.13578033979449952, 36.45789977482387, 42.41593837738037, 60.21757752554757, 50.93976954051426, 36.88649593080793, 65.08167089734758, 24.207595109939575, 0.18352020452065126, 0.11779135864760194, 0.03639782958530954, 0.04281981409128223, 0.03640471671574882, 0.02197242953947612, 0.04692526986556394, 0.030960453674197197, 0.0532815518256809, 0.045913682718362124, 0.08033644274941512, 0.05304588982835412, 0.020883528415911963, 0.06078535185328551, 0.06479803153446742, 0.056204002150999646, 0.03554609850315111, 0.03265871147492102, 0.04120185412466526, 0.004085889368850205, 0.0231332112702408, 0.05592154498611178, 0.04403872082808188, 0.05771691471870456, 0.05952461343258619, 0.018226833115997057, 0.15660447095121655, 0.22095978552741663, 0.22798228370291845, 0.13102364646536963, 0.12228750810027122, 0.1149732805788517, 0.16781753354838916, 0.05767495411315134, 0.14444422775081225, 0.15010757957186016, 0.10460214423281805, 0.16397363266774587, 0.10263942062322583, 0.2812346890568733, 0.16008787974715233, 0.15170172974467278, 0.1748299758349146, 0.20439179241657257, 0.1976766706045185, 0.10299810780478375, 0.27741369551845957, 0.17195610861693109, 0.32303974724241663, 0.22542849502393178, 0.5332567627940858, 0.10877415750707899, 0.29903773803796085, 0.16135971221540654, 0.16180998805378163, 0.11560446742389884, 0.4133179358073643, 7.844008990696498, 97.26031412397111, 91.6336281640189, 63.44216700962612, 87.98924241747174, 66.43654182979039, 55.44047907420567, 53.271314007895334, 17.79694390296936, 0.5900786966085434, 2.8740608990192413, 9.77301217828478, 19.03677351134164, 18.650781972067698, 15.034402676991053, 10.365761263029915, 16.56663853781564, 7.617120776857648, 5.715235539845057, 4.636803465230124, 0.6773839518427849, 2.0542872420379092, 1.4614554303033012, 2.95373198390007, 1.6964985494102751, 1.2177913337945938, 2.27704062632152, 2.3958313720566884, 2.8199253124850134, 2.2678438169615607, 2.7844297885894775, 4.861171220030103, 9.401458127158028, 15.526514053344727, 17.723247834614344, 19.254078422273906, 24.808233874184744, 40.273096561431885, 50.96542576381138, 55.360640798296245, 64.33110564095634, 65.5767856325422, 65.1486793245588, 61.156807218279155, 61.574067388262065, 59.87778282165527, 61.002043042864116, 56.63486746379307, 58.21405403954642, 57.419541427067344, 52.96405076980591, 54.40810530526297, 59.46334362030029, 61.30008602142334, 61.41865703037807, 63.83943026406424, 63.338652747017996, 65.6306619644165, 32.626277446746826, 52.0773320879255, 65.24195194244385, 60.764074189322336, 63.15055111476353, 60.276512145996094, 53.126023701259065, 50.29792274747576, 51.77975116457258, 48.59184469495501, 50.89844165529524, 53.177714824676514, 61.33707128252302, 60.76044028145926, 66.21852125440324, 64.42555945260185, 61.80742263793945, 54.031839506966726, 58.38609491075788, 55.56391382217407, 56.81256069455828, 54.95860760552542, 55.14315523420061, 53.9065773827689, 54.05405984606062, 54.9202743938991, 51.96095323562622, 43.80465745925903, 33.99271712984358, 17.9851393359048, 8.097795418330602, 15.254063027245657, 20.879705020359584, 25.715618235724314, 30.529915605272564, 27.058230808803014, 16.434820788247244, 7.500301582472665, 7.050173827580043, 2.1996259689331055, 1.9753834988389696, 7.963064636502947, 2.554525839430945, 6.972192457744053, 17.044724975313457, 16.785072531018937, 13.741791946547371, 14.01026165485382, 11.277344942092896, 12.647111075265066, 4.665599840027945, 1.6446247100830078, 0.324198060802051, 1.6574234004531587, 37.32300608498709, 55.18578590665545, 76.59612832750592, 58.44268798828125, 48.5803211075919, 72.13072259085519, 41.79491880961827, 0.2936814911663532, 0.2208599051726716, 0.17166394500860147, 0.2570077862058367, 0.128393522596785, 0.11028623886938606, 0.1619621698877641, 0.17264894715377263, 0.14109265830899986, 0.15675662564379828, 0.17847650444933347, 0.18903486217771256, 0.1499084566852876, 0.25988539893712315, 0.20083158702722617, 0.15169716998934746, 0.13505026325583458, 0.13639754881816252, 0.1537689273910863, 0.1166695367012705, 0.1328835788049868, 0.22178225139422075, 0.10867001595241682, 0.11842886943902288, 0.13999317373548234, 0.11222416880939688], [0.12179077975451946, 0.05089346479092326, 0.09397593978792429, 0.035681364459118674, 0.027472994024200097, 0.1176427323371172, 0.08631732860313994, 0.016573141495298063, 0.023015527852943966, 0.05179377219506672, 0.05832326718206916, 0.012850728917068668, 0.06486137277845826, 0.08834305418921368, 0.027897899438227926, 0.05891705996223858, 0.05226265685632825, 0.0797580120020679, 0.07288038105304752, 0.08052333843495164, 0.1597207515899624, 0.08539220038801432, 0.12427583283611707, 0.07178740363035883, 0.018537961778097918, 0.007310979035017746, 0.025179883232340217, 0.07674284665180103, 0.035608818887599876, 0.13829458345259937, 0.16958434374204703, 0.17478158271738461, 26.861523832593644, 78.68841157640729, 51.878908906664165, 41.24685532706124, 77.0619147164481, 33.18345349175589, 39.87292548588344, 8.926153574671064, 0.21602754161826201, 0.5908375158905983, 0.8494900709816388, 4.193029837948935, 3.526933397565569, 9.363595655986241, 6.042872198990413, 5.550898049558912, 5.921012086527688, 1.975648616041456, 0.8022816755941936, 1.3584242846284593, 0.71503710853202, 2.375060383762632, 2.4359763264656067, 1.2262927804674422, 0.9295253391776765, 1.1086400193827493, 0.12892314632024082, 0.4348414194371019, 0.6503977456263134, 0.397765967462744, 1.383643314242363, 5.65113536800657, 8.41190871170589, 8.706223113196236, 12.095973014831543, 18.64193344116211, 25.752254349844797, 30.21844870703561, 34.115623814719065, 53.38838768005371, 63.97339153289795, 52.90306643077305, 45.3400217464992, 47.14133875710623, 50.121949195861816, 53.080103056771414, 56.72736535753523, 56.6845748765128, 57.32474715369088, 49.826539584568565, 49.55960021700178, 50.75326599393572, 56.42174536841256, 54.42918961388724, 61.60957268306187, 55.400130884987966, 57.50243691035679, 42.53752837862287, 46.56565965924944, 55.64625692367554, 53.60520969118391, 53.615694522857666, 51.34348767144339, 47.838434151240754, 42.85977193287441, 44.29802124840872, 43.349213463919504, 49.683368478502544, 59.4535744530814, 59.515413420540945, 60.038869857788086, 57.69264384678432, 60.244022369384766, 56.65290151323591, 54.08684492111206, 49.51176534380232, 46.25166709082467, 40.824568135397776, 36.31154291970389, 34.18455689293997, 33.730495589120046, 33.304230553763254, 25.84192258971078, 17.818224498203822, 13.2979861838477, 9.807088749749319, 6.625310157026563, 0.48537151515483856, 3.1079531141689847, 5.768329330853053, 10.915857093674795, 17.570357935769216, 18.97285529545375, 15.294195822307042, 10.190428682735988, 1.8641039729118347, 0.7033686946545328, 0.4274746190224375, 5.17602493081774, 2.6232589398111616, 4.553071158272879, 5.101737831320081, 3.5834480907235826, 6.4743931123188565, 2.939004191330501, 1.072804142321859, 0.9051360221845763, 0.15790564327367715, 0.9424518112625394, 0.6686869242361614, 7.910574470247541, 27.477558067866735, 43.954630851745605, 57.23230137143816, 27.48452537400382, 49.44650091443743, 47.625298159463064, 2.898391970566341, 0.07848800479301385, 0.10996656745140042, 0.010011734158199812, 0.07207379290567976, 0.047784648037382534, 0.05107835540547967, 0.04615152620577386, 0.019756573352164457, 0.11497120426169463, 0.05484785492132817, 0.043594487344047854, 0.018501841662717716, 0.028160095547458956, 0.013254991599491664, 0.04426515135647995, 0.06325523289186613, 0.04722765899662461, 0.04767839623881238, 0.05113846003743155, 0.04898951588464635, 0.03962463340056794, 0.02594627157252814, 0.041970515557165654, 0.01284918694623879, 0.052204482656504424, 0.03803766891360283, 0.06912384155605521, 0.014991863131789225, 0.09860357575650726, 0.026967907823356133, 0.030469791431512152, 0.0739240629066314, 0.0024576521412070307, 0.028429477342537472, 0.08359586713569504, 0.07042970934084483, 0.1443583523588521, 0.0303997835809631, 0.10702853117670331, 0.029714558207030808, 0.0467758869885334, 0.05714484862983227, 0.03163582332698362, 0.008989761184368814, 0.012231103460570531, 0.04165477624961308, 0.07439775498850004, 0.02721030936975564, 0.17525658437183925, 0.10912257845380477, 0.03769135481810995, 0.013460502893264805, 0.05079255306294986, 0.04455616484795298, 0.04099166772461363, 0.201698578361954, 0.09479833101587636, 0.13414901947336538, 33.78672736031668, 96.35060732705253, 56.257107802799766, 55.15267079217093, 78.4725102015904, 34.28243964059012, 47.101688861846924, 9.603594252041407, 0.06392423449350254, 0.4808442752276148, 1.7407961381333215, 2.904142039162772, 2.1930727320058003, 7.0405453613826205, 6.2461400117192944, 8.900759645870753, 7.641006946563721, 4.146788273538862, 3.3218948798520223, 2.429695589201791, 1.7661784504141127, 3.148596167564392, 3.0969860340867723, 2.171233023915972, 0.97101129591465, 1.0480371798787798, 0.34211089674915585, 0.3309049723403794, 0.7192332233701433, 0.6530373554144586, 1.9872527590819766, 6.710558908326285, 10.923000710351126, 12.544301186289106, 15.211621693202428, 23.41261523110526, 32.174046993255615, 40.050611768450054, 44.78659078053066, 62.287411144801546, 70.00039100646973, 60.28608676365444, 57.37382575443813, 57.45045048849923, 58.75209127153669, 59.77765927995954, 61.19607148851667, 59.604989596775596, 61.357123783656526, 52.1381288255964, 53.002627168382915, 53.24731492996216, 62.55047689165388, 58.91722215924944, 65.4905445916312, 60.506671224321636, 63.343412263052805, 47.90992764064244, 53.92695297513689, 61.12569318498884, 60.04402542114258, 59.50938238416399, 57.05980886731829, 53.40783568790981, 47.15921647208077, 48.04848861694336, 48.02616058077131, 52.749316692352295, 64.52713516780308, 61.912111146109446, 65.31626292637416, 61.65171350751604, 65.2838773727417, 61.207709721156526, 59.279640197753906, 54.424798352377756, 55.17807688031878, 50.319767883845735, 47.135311194828574, 43.0138065474374, 42.50270400728498, 37.939016001565115, 27.772304126194545, 19.317426885877335, 11.801849688802447, 10.971275057111468, 9.116460391453334, 1.3295440971851349, 4.9343127352850775, 5.816815597670419, 11.4656845501491, 20.817143440246582, 23.159643479755946, 18.847895417894634, 15.098270518439156, 4.657535152775901, 1.7512880265712738, 0.6137378556387765, 10.882702027048383, 3.3999617993831635, 4.559579449040549, 9.278725147247314, 5.156281624521528, 4.905578025749751, 3.0156792998313904, 1.4804989227226801, 2.1244039024625505, 1.5522511239562715, 0.9792387230055672, 1.090732665998595, 15.857833692005702, 38.9833128792899, 38.00995363507952, 71.3013230732509, 30.69684260232108, 55.292961869921, 53.9580774307251, 2.1894527205399106, 0.21402757322149618, 0.1697450072637626, 0.10698453496609416, 0.08285541579659496, 0.03736825001292995, 0.04902139345982245, 0.09596150288624422, 0.06519248429685831, 0.032092857374144454, 0.04311147219102297, 0.0964152460385646, 0.04931393026241234, 0.020218820244606053, 0.03537958940224988, 0.05345178608383451, 0.013325228455609508, 0.02363095572218299, 0.049002197704144886, 0.07449699752032757, 0.05948179787290948, 0.05295306623780301, 0.021630364769537534, 0.054495718995375295, 0.01865069188975862, 0.09115005856645958, 0.05149190214329532, 0.22173091343470983, 0.09994147717952728, 0.28192456918103354, 0.18072662156607422, 0.09542391316166945, 0.20399791640894754, 0.19587583866502556, 0.07620572511638914, 0.21660888328083924, 0.143268489411899, 0.28382083028554916, 0.17324518944535935, 0.19363075627812318, 0.20100432847227367, 0.12909995897540025, 0.18471023280705723, 0.203412014991045, 0.1751909836062363, 0.12996978658650601, 0.11431284887450081, 0.1798169096665723, 0.2084414522562708, 0.37550133360283716, 0.185919246503285, 0.2383035612957818, 0.13410814452384198, 0.13575891165861062, 0.18129099985318525, 0.29725639362420353, 0.43434321188500946, 0.3225643384669508, 0.3435755824404103, 49.6542763710022, 110.67603492736816, 76.51822512490409, 65.37817137581962, 97.01758575439453, 50.030441420418875, 60.95030675615583, 17.759065798350743, 0.2887711503676006, 1.4061448382479804, 3.308235589947019, 7.777773550578526, 13.740296346800667, 22.410250731876918, 17.568181412560598, 16.675582817622594, 16.11233057294573, 3.8826937590326582, 3.4937110202653066, 3.8772941402026584, 0.6622660830616951, 4.323299007756369, 2.6531355423586707, 2.130024995122637, 1.602058959858758, 1.3509901463985443, 0.2873752409858363, 1.1090271643229892, 1.2117861360311508, 1.1311900722129005, 2.3980943134852817, 8.531540189470563, 10.561649220330374, 15.328372274126325, 19.548511811665126, 27.667283841541835, 35.798084940229145, 47.51037842886788, 51.60628938674927, 64.67798055921281, 70.87324455806187, 66.03607545580182, 67.7505156653268, 64.67012214660645, 66.11937046051025, 64.86368506295341, 66.9712474005563, 61.989646094185964, 63.77027484348842, 55.16102947507586, 54.68402869360787, 57.158719948359895, 63.316508838108604, 61.344380787440706, 68.17437662397111, 63.36387470790318, 63.0505040032523, 52.41538974217006, 57.424575396946494, 64.22412422725132, 65.17731979915074, 61.88949475969587, 61.510720661708284, 55.76381696973528, 49.89048385620117, 51.6141026360648, 50.48105641773769, 54.00528001785278, 67.29945945739746, 63.732879638671875, 65.6906874520438, 62.23891966683524, 68.32283183506557, 62.8333797454834, 61.93154525756836, 57.89423540660313, 58.87984085083008, 53.880358355385916, 53.61215788977486, 51.05424806049892, 51.93595709119524, 52.713137422289165, 45.364941460745676, 37.985287530081614, 33.421220847538535, 23.55145239830017, 12.471557889665876, 3.6454501237188066, 9.649965660912649, 14.567877173423767, 24.270589215414866, 27.970525809696742, 24.420630352837698, 17.878086703164236, 18.487964834485734, 6.8940291319574625, 1.9896390310355594, 1.783296097602163, 9.644665922437396, 5.661394383226122, 13.625959396362305, 11.933077710015432, 15.68460988998413, 17.3267662525177, 8.853515369551522, 6.367905020713806, 2.0408687506403242, 2.1893847584724426, 2.5478996464184354, 1.08724564739636, 14.268162284578596, 44.69029917035784, 55.73998812266758, 77.2390798841204, 44.21630001068115, 62.45708615439278, 70.27726282392229, 6.964805219854627, 0.6513303241559437, 0.41092935683471815, 0.2705247194639274, 0.24519107171467372, 0.1384059717612607, 0.16874821217996733, 0.17673359225903237, 0.08252765624118702, 0.27242326044610565, 0.18178259847419603, 0.14261603727936745, 0.12605446310979979, 0.08446305524557829, 0.16671529412269592, 0.11997634997325284, 0.12204293693814959, 0.19678261929324695, 0.2042877594275134, 0.32594032159873415, 0.2669330436204161, 0.17174052447080612, 0.13385221468550818, 0.21774905281407492, 0.1063485915905663, 0.1593170775366681, 0.1495580340602568], [0.036092261517686505, 0.04987719914476786, 0.06623284132885081, 0.1370610339300973, 0.026284034430448498, 0.09455655541803155, 0.03060018889872091, 0.05149587496582951, 0.024106557880129133, 0.004207881059431071, 0.08334136900625058, 0.03581779410264321, 0.09320743102580309, 0.014993735888440694, 0.08075034232544047, 0.05374987669555204, 0.07378169268901859, 0.1286177241376468, 0.08526460187775747, 0.045625922802303515, 0.06795104127377272, 0.10427578245954854, 0.14070836321583816, 0.05620501656085253, 0.07452910579741001, 0.01193591782690159, 0.08661224706364529, 0.06410923028098685, 0.07224196781005178, 0.01902666814359171, 0.025568115524947643, 0.18237855578107492, 4.87163781268256, 73.6579019001552, 69.82483782087053, 37.228983061654226, 52.48292623247419, 74.05735383714948, 33.07819523130144, 9.719490204538618, 0.6059104927948543, 0.4069918995457036, 0.9856922967093331, 3.1873684184891835, 0.9515352781329836, 5.250857029642377, 5.705996172768729, 4.975852106298719, 5.5936733313969205, 1.7651786697762353, 0.7224654385021755, 2.9514310445104326, 1.2676169744559695, 1.1975124733788627, 2.0975984036922455, 2.4160158889634267, 0.5872456771986825, 1.1921756054673875, 1.4999935052224567, 1.8599324481827872, 1.4659744735274995, 1.4853419257061822, 0.5547608946050916, 2.7650312866483415, 4.433233840124948, 4.195670587675912, 5.8122541052954535, 8.98187986442021, 20.225071804864065, 24.109248570033483, 28.895160811288015, 54.15649366378784, 66.32914352416992, 56.59817402703421, 51.9708057812282, 54.56996359143938, 57.24503741945539, 59.883007866995676, 59.98466696058001, 59.70851080758231, 63.53939315250942, 61.001862389700754, 52.90125642504011, 47.39331865310669, 49.50937863758632, 51.7944917678833, 57.961108343941824, 56.04814420427595, 58.32223401750837, 32.8833121572222, 38.75570378984724, 55.958331789289204, 49.90047189167568, 54.61612394877842, 49.964190346854075, 48.863967418670654, 44.54965026038033, 45.43396486554827, 47.95886032921927, 57.38930286679949, 61.23475211007254, 63.16762283870152, 62.25142642429897, 62.579138210841585, 59.64856175013951, 59.24934605189732, 53.763718945639475, 50.29142618179321, 43.752743993486675, 34.42123338154384, 27.7156936781747, 23.616779361452373, 19.54952277456011, 12.223852004323687, 6.689719957964761, 1.2629439852067401, 2.376437212739672, 2.4461827959333147, 3.2955698924405232, 0.3014211601444653, 0.4514221011527947, 0.8788259082606861, 0.6124463592256818, 5.152999034949711, 9.699024285588946, 12.546589749200002, 7.991373334612165, 2.2347161088671004, 0.3318390707884516, 0.6431341096758842, 1.288581209523337, 4.430375959192004, 6.117562294006348, 9.826651402882167, 5.260415145329066, 2.9855199924537112, 2.0109678293977464, 0.6075096641268048, 1.3505065952028548, 0.8073874073369163, 0.712862810918263, 4.942327048097338, 33.38765410014561, 36.18852506365095, 71.37358433859688, 27.109854187284196, 43.56773778370449, 50.495637212480815, 18.99705239704677, 0.05993649097425597, 0.0018673527561726847, 0.0409952978869634, 0.05494562842484031, 0.031368687482816834, 0.02066180183153067, 0.041105668393096755, 0.07402050987418209, 0.020174406734960418, 0.056334131596876044, 0.026179495932800428, 0.107253601242389, 0.054435366698141606, 0.05191308240007077, 0.06992608029395342, 0.0753762839095933, 0.06559790218515055, 0.04908382885956338, 0.04355223496843662, 0.06201296419437442, 0.06119272392243147, 0.02034948912582227, 0.04362123519448297, 0.04241149207311017, 0.029133518492536883, 0.03826911720846381, 0.03800660218777401, 0.019140833356816853, 0.06297704710492066, 0.05645550794101187, 0.1189806948282889, 0.022633431213242666, 0.06617399877203362, 0.1009627945188965, 0.023596577745463167, 0.06882118101098708, 0.05110350191327078, 0.13926022020833834, 0.04297862860507198, 0.042050005934600315, 0.03268398690436568, 0.05882857899580683, 0.032575061677822044, 0.04634583827906421, 0.08950272481888533, 0.09920586379511015, 0.11338815492178712, 0.14595719799399376, 0.07236212279115405, 0.10846053862145968, 0.01925327000208199, 0.10335015891385929, 0.09232103358954191, 0.03709318209439516, 0.1089822438412479, 0.060528743479933055, 0.08365523894982678, 0.0474178286136261, 0.15685232622282846, 8.06859040260315, 89.5327708380563, 82.58004202161516, 37.391980852399556, 70.99100957598004, 66.4359164919172, 46.95028414045061, 15.203243902751378, 0.9982704903398241, 0.8746700169784682, 1.2558326125144958, 1.8238938791411263, 2.2004558444023132, 3.680910689490182, 7.741477029664176, 10.873275927134923, 7.528824806213379, 3.819047825677054, 1.5724004656076431, 3.7347453321729387, 3.010958650282451, 1.8661599883011408, 3.7920536398887634, 5.514535086495536, 1.8668760870184218, 4.545502832957676, 4.610749891826084, 3.387227705546788, 6.46608567237854, 1.8621563059943063, 1.6125784239598682, 3.303359257323401, 5.518243253231049, 6.743502054895673, 8.685645154544286, 13.883011477334158, 29.27404260635376, 35.56921475274222, 40.61446850640433, 60.53593703678676, 71.06668935503278, 65.16401399884904, 60.38313225337437, 59.869722911289756, 62.233166558401926, 64.73296165466309, 64.47023636954171, 64.62639018467495, 68.60036373138428, 63.549085889543804, 54.90718051365444, 51.26152672086443, 54.804944719587056, 56.817695413317, 64.408536366054, 61.23804555620466, 65.11846855708531, 38.508504254477366, 44.9398124558585, 64.04317923954555, 55.56649507795061, 61.1988924571446, 55.16574035372053, 53.61603498458862, 50.031573976789204, 49.395886761801584, 52.044109276362825, 61.899673870631624, 64.72376918792725, 66.08457388196672, 64.78630297524589, 65.7594746180943, 63.661577224731445, 65.34916959490094, 60.046742166791645, 56.60266951152256, 52.11828824451992, 44.859730992998394, 38.469444956098286, 32.29193013054984, 27.059992177145823, 17.96201573099409, 6.453115122658866, 2.489116366420473, 3.643089473247528, 6.543413911546979, 8.146768059049334, 1.2460669193949019, 3.2508929755006517, 1.8658058473042078, 0.9826095764126096, 4.851858028343745, 10.14300114767892, 15.938997336796351, 10.75718629360199, 1.8065310908215386, 0.4828729320849691, 0.82819650215762, 3.7833601406642368, 9.072437473705836, 5.208098249776023, 5.638668562684741, 3.7925408823149542, 2.3658331760338376, 1.1092309419597899, 0.8608771370989936, 1.8050604611635208, 1.0070619157382419, 1.2299291853393828, 7.928960272244044, 56.68931007385254, 31.114651679992676, 79.01653330666679, 31.83639928272792, 43.72045224053519, 59.38630894252232, 20.303490911211284, 0.1627891140856913, 0.09023388022822992, 0.0457104207681758, 0.0775117761056338, 0.052940876356193, 0.059432013758591244, 0.039607561459498744, 0.0617242068318384, 0.026860673845346485, 0.06187016649969986, 0.12118069534855229, 0.03666234628430434, 0.09005364097122635, 0.02693664262603436, 0.03389891403328095, 0.07407538978649036, 0.05111632961779833, 0.04496969122971807, 0.03855005106223481, 0.04725999797561339, 0.02691190832826708, 0.005453910113179258, 0.072542375618858, 0.02278715162537992, 0.02063671299921615, 0.04449883881690247, 0.06174451538494655, 0.15144915186933108, 0.154756969373141, 0.1560632171375411, 0.2768022269010544, 0.16984625825924532, 0.15098515605287893, 0.2125301957130432, 0.13745566989694322, 0.20605106838047504, 0.20255288109183311, 0.3173964800579207, 0.1667410513120038, 0.16770218259521893, 0.21720060652920178, 0.16196149135274546, 0.1764742833163057, 0.1499736231884786, 0.16183769942394324, 0.27122317627072334, 0.20018855296075344, 0.29760423781616346, 0.34981400626046316, 0.3252171389758587, 0.1280224725071873, 0.21449804226202623, 0.18594336163784775, 0.2399441504052707, 0.3280732828591551, 0.23874051070639066, 0.18928556729640278, 0.19294368528894015, 0.26456769768680843, 11.873023561068944, 108.77888488769531, 95.73695632389614, 60.440496580941335, 75.16830825805664, 89.90802219935826, 53.515894072396414, 18.319905281066895, 0.7007022691624505, 0.9582253077200481, 2.6824352272919247, 7.131587607519967, 6.267367626939501, 16.03500928197588, 14.107453056744166, 17.644523007529124, 13.881093774523054, 3.931494866098676, 1.1840851881674357, 4.469831304890769, 2.403121986559459, 1.7192858180829456, 1.8469725378922053, 4.10558111327035, 3.177833752972739, 3.9706301603998457, 3.1128880722182135, 5.4166388767106195, 5.022668634142194, 4.37664076260158, 2.402441063097545, 4.543201676436833, 8.00825572013855, 10.675366044044495, 13.298383099692208, 19.221456629889353, 36.43645415987287, 45.903753416878835, 50.06172915867397, 65.63672079358781, 71.43299838474819, 71.30795165470668, 65.47252791268485, 64.1823377609253, 68.31272220611572, 68.05077511923653, 68.32215785980225, 67.09165968213762, 71.19284084865025, 65.59442710876465, 55.95114387784685, 52.32990605490548, 53.51746783937727, 58.04117243630545, 64.23572771889823, 63.00042833600725, 66.86267484937395, 42.96250799724034, 48.55451202392578, 66.25395706721714, 59.91507380349295, 64.10665103367397, 58.398441859654014, 56.48210436957223, 53.0944059235709, 54.168090207236155, 56.88987677437918, 65.42141696384975, 65.89766733986991, 68.19745853969029, 66.56674412318638, 67.78455489022392, 66.11162321908134, 67.35554531642369, 62.009559631347656, 59.859696660723, 57.357698985508506, 52.223074027470176, 49.4488285609654, 47.67481797082083, 43.713531834738596, 38.73354598454067, 32.23168230056763, 19.74719728742327, 13.506374818938118, 12.603827272142683, 12.694888625826154, 1.6683063421930586, 5.153665193489619, 7.718791161264692, 8.827527369771685, 17.381019524165563, 19.614095858165197, 22.059198209217616, 12.311472262654986, 5.71579486983163, 1.0836891468082155, 2.278030093227114, 3.4471120578902106, 12.010128021240234, 16.80610125405448, 20.784900324685232, 10.795577696391515, 8.946307693208967, 8.744279265403748, 5.597629027707236, 3.5348793140479495, 2.1226262492792944, 1.1751564272812434, 8.206838709967476, 57.22175400597708, 47.711702483040945, 91.27579593658447, 41.64342723573957, 57.41405929837908, 65.966461454119, 42.006689480372835, 0.27709939809782164, 0.17961889957743032, 0.19403132264103207, 0.18279624836785452, 0.17557310738733836, 0.12452912995857851, 0.15857207322759287, 0.20341255781905992, 0.06028484406747988, 0.2906607889703342, 0.18642750994435378, 0.1451387626252004, 0.1699613377984081, 0.12494942811982972, 0.10688187940312283, 0.13417206252259867, 0.16965173584009918, 0.18494845288140432, 0.10186719348920242, 0.12644867838493415, 0.1684459519705602, 0.14247437273817404, 0.25098418657268795, 0.12375638713794095, 0.19920557284993784, 0.11606862608875547, 0.1504164080002478], [0.06315999371664864, 0.02693510744055467, 0.04518089543229767, 0.07550110042627368, 0.03692348727158137, 0.06282205613596098, 0.10115087764071566, 0.05006035610235163, 0.07159080489405564, 0.07197989044444901, 0.0585714549358402, 0.04124394704454711, 0.029793393798172474, 0.12166282162070274, 0.015865619460652982, 0.048656779274876626, 0.04159624242622938, 0.09260685968079738, 0.11510731838643551, 0.04872475830571992, 0.16081103522862705, 0.1326909562838929, 0.13055821215467794, 0.03728319564834237, 0.14897566102445126, 0.07010880977447544, 0.0891440851347787, 0.08952460078788654, 0.016535286026607667, 0.07657904151294913, 0.15664568516824925, 0.05927363011453833, 0.19821649949465478, 29.955341270991735, 67.2284905569894, 58.961106981549946, 39.25352137429373, 57.23637648991176, 49.962696484157014, 22.287932906832012, 1.483747965523175, 0.3540404109018189, 0.48833394476345604, 0.6441597289272717, 0.7069747011576379, 1.4778392825807845, 4.483459762164524, 10.620953832353864, 6.312474463667188, 7.928663236754281, 4.321578460080283, 0.9604798895972115, 6.562293469905853, 0.6547668597527913, 2.6453038368906294, 1.8112548887729645, 1.1887629543031966, 1.2171862976891654, 0.7672806680202484, 0.7445705894912992, 1.5624473882572991, 0.6644660021577562, 0.04980848051075425, 0.3371784899915968, 1.2862613797187805, 1.3087238201073237, 1.8452287571770805, 7.0072113786424906, 20.357544422149658, 30.91884102140154, 38.454530647822786, 57.80292565482003, 67.90613446916852, 62.42124039786202, 59.001357895987375, 62.15335954938616, 62.073024477277485, 64.5457980292184, 64.90887614658901, 64.5804695401873, 66.46159703390938, 64.07149314880371, 64.90679168701172, 52.886227471487864, 51.32754502977644, 50.274722712380544, 59.77617236546108, 54.00797591890608, 59.013225419180735, 36.90093081338065, 36.66712045669556, 56.138540267944336, 51.44254813875471, 56.36058037621634, 52.05623040880476, 49.42801175798689, 44.99428285871233, 49.862409659794395, 56.870515619005474, 64.63237258366176, 65.27578966958183, 64.56384250095913, 64.4934641974313, 59.427893911089214, 61.228033202035085, 60.732070786612375, 55.888179302215576, 49.64263466426304, 37.52390282494681, 28.00068620273045, 17.861834866659983, 11.545071193150111, 7.192079492977687, 3.2650681691510335, 3.002894614424024, 2.918785801955632, 4.275882763522012, 3.749718265874045, 2.8299858697823117, 0.9325245725257056, 1.320338276880128, 1.820943283183234, 1.0688191332987376, 1.1516081137316567, 1.792487044419561, 6.120236481939044, 4.214564910956791, 1.4248919465712138, 0.5996307326214654, 0.6442669374602181, 6.707525585378919, 3.5877766013145447, 2.393136556659426, 6.467351981571742, 2.2889819741249084, 3.115305611065456, 0.05996360523360116, 0.8965225358094487, 1.9285776104245866, 0.9274532560791288, 2.8262596811567033, 29.88912841251918, 28.25471408026559, 74.73932647705078, 35.055530956813264, 27.0906754221235, 42.57904039110456, 37.06204216820853, 2.1833261464323317, 0.2646915167570114, 0.11175612892423357, 0.04248137439468077, 0.06394222245684691, 0.027489185566082597, 0.0334629756398499, 0.04367093449192388, 0.07617028523236513, 0.04977141892803567, 0.04591611526640398, 0.0738175871915051, 0.06327001816992249, 0.04932814557105303, 0.0345447029519294, 0.03248636018750923, 0.18534113466739655, 0.028934456674115996, 0.007031134229951671, 0.01884181484846132, 0.022983989545277188, 0.027769773366994092, 0.051523477770388126, 0.04728661351171987, 0.04547350348106452, 0.022064430406317115, 0.010425546372841512, 0.022262752621567676, 0.04587154569370406, 0.02587061152527375, 0.10433122555592231, 0.04498183700655188, 0.04103498879287924, 0.029948947951197624, 0.030951612362904207, 0.0709602694426264, 0.03939080344779151, 0.01735731084564967, 0.05339226499199867, 0.08397664741746017, 0.05382663596953664, 0.06115278535123382, 0.01184634696359613, 0.028749097870396714, 0.04071134455235941, 0.1429604073720319, 0.21401850799364702, 0.22886451493416513, 0.13047822644667967, 0.07156103756278753, 0.1365168895572424, 0.10999989709151642, 0.11282741358237607, 0.07383294922432729, 0.06810844104204859, 0.00954139488749206, 0.01526684284077159, 0.08964632997023207, 0.11306622398218938, 0.16326304365481648, 0.159366122047816, 35.48297718593052, 86.70026820046562, 66.82384831564767, 44.48463944026402, 75.44921003069196, 48.83502817153931, 37.6534936768668, 2.313051836831229, 0.4154957075204168, 1.0852397893156325, 1.07931829563209, 0.6858991863472121, 1.2930481412581034, 1.7082192919084003, 6.315992857728686, 6.810204327106476, 3.7380461607660567, 4.047922355788095, 3.6032018193176816, 8.426389626094274, 3.6910806809152876, 7.261947972433908, 3.5277819463184903, 2.0852846758706227, 2.8587144996438707, 4.503740685326712, 2.982450842857361, 1.812521523662976, 1.2087631268160683, 0.29622214340737885, 0.7626168525644711, 2.4836281580584387, 3.6697905319077626, 5.929946601390839, 12.449025750160217, 25.13425898551941, 38.58055707386562, 49.22818851470947, 64.11134801592145, 73.31623118264335, 66.44869422912598, 68.33797195979527, 68.99575792040143, 68.54598712921143, 71.39769458770752, 69.11018780299595, 68.41841125488281, 70.85242080688477, 69.7593718937465, 69.03504303523472, 56.40239463533674, 56.29232127325875, 54.73294053758894, 64.37318393162319, 60.05508000510079, 64.67465237208775, 45.43154341833932, 43.71697119304112, 64.93195111410958, 56.11069883619036, 62.11476925441197, 57.46079635620117, 54.37084559031895, 48.469566822052, 52.82400287900652, 57.29403959001814, 67.63125678471157, 67.33902250017438, 67.97349030630929, 68.28465843200684, 63.258414949689595, 61.59375163487026, 62.999177660260884, 58.41743128640311, 56.80802352087838, 50.031848430633545, 41.316858427865164, 30.615559101104736, 19.312057665416173, 10.432892152241298, 2.909786799124309, 3.262187272310257, 4.917441206318991, 5.9837586624281744, 7.189515607697623, 6.196684905460902, 1.7980502716132571, 2.8135268901075636, 4.470353288309915, 2.217348652226584, 1.4972099917275565, 2.434264029775347, 7.273425093718937, 4.3484245623861035, 1.5060519001313617, 1.106123794402395, 1.0613430887460709, 6.37722646338599, 4.941980506692614, 5.023293537752969, 5.884632621492658, 4.370494212423052, 3.468253472021648, 0.5047904817121369, 0.6299102221216474, 1.345789528318814, 0.9275388057742799, 3.0443592923028127, 52.861978258405415, 27.51498975072588, 76.75236552102226, 45.724865095955984, 30.996813705989293, 48.77870259966169, 41.34010362625122, 0.6969574072531292, 0.27091688556330545, 0.035366178157606294, 0.03573950133951647, 0.04543263531689133, 0.0465403810542609, 0.021514214841382842, 0.024194460395457487, 0.055835832442556105, 0.07469320270631995, 0.06423311041934149, 0.029561711408730065, 0.028765172364988496, 0.09969899590526309, 0.030452699134392396, 0.03814691644428032, 0.05993633491120168, 0.10607891463275466, 0.04532045651493328, 0.024001094878518155, 0.03236766405669706, 0.02657020996723856, 0.04081231734848448, 0.07048879617026874, 0.05644464459536331, 0.04147040132167084, 0.03911805611902049, 0.09623726630317313, 0.11593779096645968, 0.09863322773682219, 0.15391975215503148, 0.09424340472157512, 0.10126400978437491, 0.13145330840987818, 0.17161240348858492, 0.24798598459788732, 0.08973156753927469, 0.27689157639231, 0.18319929816893168, 0.12960877881518432, 0.09674801318241016, 0.1803958493151835, 0.09421249745147568, 0.16213469420160564, 0.16275226963417871, 0.19783858263066836, 0.31430249607988764, 0.36782256992799894, 0.3064368910023144, 0.23210329828517778, 0.3375429447208132, 0.22745842752712114, 0.331290244523968, 0.31510601724897114, 0.13642494806221553, 0.11956785832132612, 0.14261837143983158, 0.21963342598506383, 0.29761449726564543, 0.3343853955822331, 0.45050279476812904, 51.773588112422395, 106.73338385990688, 87.68065902165004, 63.431008202689036, 81.43837656293596, 66.70149053846086, 42.35175091879708, 2.369731115443366, 0.5078252702951431, 2.0728363267013004, 2.6828673183918, 3.6121752006667, 8.447153449058533, 18.206052098955425, 21.25262004988534, 17.33675949914115, 20.41979159627642, 15.402869122368948, 5.281390019825526, 11.012881738798958, 3.977118040834154, 10.297333666256495, 3.5579970564161028, 2.001924531800406, 2.297943630388805, 3.0242946318217685, 1.8192016737801688, 4.083434164524078, 2.399675680058343, 1.6312689696039473, 1.3671127898352486, 4.774834641388484, 5.190811565944126, 9.470392073903765, 17.567929540361675, 31.5159900529044, 44.917991638183594, 58.293190547398154, 69.08507006508964, 74.48988614763532, 70.82414858681815, 72.68199266706193, 75.5520989554269, 71.64456408364433, 73.29833957127163, 71.08793694632394, 70.53205326625279, 72.23721068246024, 70.535582951137, 72.25410870143345, 58.05436706542969, 59.06334972381592, 56.80659566606794, 67.19258226667131, 63.60226740155901, 67.8428989137922, 47.88652263368879, 49.08719219480242, 67.61446993691581, 61.6363718850272, 64.7682307107108, 59.86541502816336, 57.45559910365513, 53.88042436327253, 57.74085392270769, 61.98936816624233, 72.38528374263218, 71.52976594652448, 70.05994401659284, 70.01497527531215, 65.12985665457589, 65.43311078207833, 67.76341152191162, 64.60272462027413, 62.599315779549734, 56.89099543435233, 53.5533379146031, 47.77213791438511, 43.15865216936384, 36.35417706625802, 27.050898722239904, 14.72188833781651, 9.112352269036428, 9.683481165340968, 12.306378364562988, 10.975917322295052, 3.219776770898274, 5.4811928527695795, 7.3798754044941495, 3.725089507443564, 3.8770470448902676, 9.213604024478368, 14.18682667187282, 8.096126982143947, 2.666226382766451, 1.3491722153765815, 2.8172591584069386, 12.893669639314924, 10.302877460207258, 9.4120671578816, 13.700661216463361, 9.91667834350041, 9.388588326317922, 2.8359361333506445, 2.1317314292703355, 4.5981137241636, 1.7103507603917802, 4.020717552730015, 48.28594330378941, 39.10194294793265, 95.46546936035156, 55.62216057096209, 47.366175515311106, 60.02650901249477, 71.83978067125592, 3.39157879778317, 0.5176460604582513, 0.264306760260037, 0.2069783407662596, 0.19450956769287586, 0.1243804357945919, 0.10963411243366343, 0.22281582307602676, 0.1382991432079247, 0.22394706308841705, 0.23650495495115006, 0.18962168640324048, 0.11451674864760467, 0.18177540600299835, 0.1850512916488307, 0.15400532899158342, 0.1523755014474903, 0.19357599850211824, 0.12632336653769016, 0.09559906340603318, 0.13537658431700297, 0.10426821000874043, 0.08946550717311245, 0.176806168364627, 0.19931279495358467, 0.08336921608341591, 0.11797627301088401, 0.2651723809540272], [0.05120959425611155, 0.07596097074981246, 0.11244672151016337, 0.06149088578032596, 0.10631385059761149, 0.030484091557030166, 0.10846241816346135, 0.12693391234747, 0.044313995699797354, 0.05556224712303706, 0.011069498157926967, 0.06412214280239173, 0.0473841461353004, 0.05459803529083729, 0.10948933341673442, 0.03314638137817383, 0.12085342433835779, 0.0327546631119081, 0.031451523037893434, 0.03475684353283473, 0.07368838733860425, 0.16597725158291204, 0.07399585869695459, 0.02450589948732938, 0.103047383017838, 0.03879994533157774, 0.020251836062275937, 0.08604960582618203, 0.03538821018966181, 0.1181489737438304, 0.05371790751814842, 0.09043669434530394, 0.30838415079883164, 1.4210655518940516, 24.073288168225968, 65.13875729697091, 53.84828199659075, 30.823893887656077, 70.79876681736538, 40.632540770939414, 20.665905475616455, 0.8286543775882039, 0.35889880305954386, 0.15155995663787636, 1.536864555307797, 0.1119850869955761, 5.431683463709695, 3.842583545616695, 4.468549362250736, 2.8686771307672774, 2.453797370195389, 4.586589702538081, 5.884277394839695, 2.4533639763082777, 8.719388212476458, 3.834921419620514, 1.1321058230740684, 3.9741103393690924, 4.012460921491895, 2.1816164553165436, 7.166871862752097, 1.1837290929896491, 0.07206658686378173, 0.08872257239584412, 0.42848080503089087, 0.7236270904541016, 1.5749612024852206, 5.767743510859353, 20.83846398762294, 32.66609409877232, 41.02383552278791, 51.18908480235508, 65.73739324297223, 66.22621985844204, 67.27851063864571, 65.11461230686733, 63.560064043317524, 61.83767509460449, 67.57892990112305, 64.40581267220634, 65.55444022587368, 67.65314361027309, 65.929260798863, 62.980910846165244, 54.91652931485857, 49.051523617335725, 55.96590532575335, 57.87440177372524, 56.98663738795689, 41.80962119783674, 9.396133201462881, 50.833927631378174, 57.44813673836844, 57.639146191733225, 55.339726720537456, 49.564936433519634, 48.496546677180696, 53.82777091435024, 64.66472339630127, 68.94229848044259, 69.88903222765241, 67.56303242274693, 66.59077794211251, 67.02510983603341, 62.19531972067696, 65.97532040732247, 59.52330657414028, 48.09429809025356, 30.516675812857493, 17.347112315041677, 7.985232864107404, 5.1976572786058695, 3.2255424729415347, 2.8448949669088637, 2.452725176300321, 2.299437710217067, 3.040977256638663, 2.503526713166918, 2.1012933254241943, 0.18347002007067204, 0.5728231711047036, 1.3212454510586602, 0.823841392993927, 0.38375717774033546, 0.4408063936446394, 1.1353463977575302, 0.15663147664495877, 0.7012329378298351, 1.1808465676648277, 1.2810532706124442, 2.2180973206247603, 7.65211364201137, 2.900333992072514, 1.7411515819174903, 2.4954503008297513, 0.487262347979205, 0.49685086203472956, 0.10569086724093982, 1.4685780938182558, 2.497868925333023, 29.816523211342947, 22.875677551542008, 68.97478130885533, 41.52854572023664, 19.871853181294032, 40.922040939331055, 33.0476405279977, 2.6409095355442593, 0.10129505276147809, 0.03673283589471664, 0.09434399075273957, 0.022530907964599983, 0.04867628715666277, 0.07245950613703046, 0.031418169649051766, 0.08488442549215895, 0.0784066009468266, 0.029746798798441887, 0.08585175858544451, 0.026907694625801275, 0.05881228058465889, 0.16074543446302414, 0.04154016150693808, 0.03064743189939431, 0.08912624644913844, 0.02037199443605329, 0.04093996674886771, 0.08314680587500334, 0.03403400696281876, 0.007906304456160536, 0.08781200554221869, 0.04688220664060541, 0.06776979778494154, 0.06694770511239767, 0.10873834442879472, 0.0497519246169499, 0.0807322593671935, 0.029195763902472596, 0.10600145986037594, 0.06341743668807404, 0.14088206818061216, 0.059385093062051704, 0.03798166263316359, 0.041022941403623135, 0.07175796878124986, 0.02537195953274412, 0.04927651923415916, 0.07863574900797435, 0.03768698165991476, 0.0617798331326672, 0.05107585500393595, 0.06013520673981734, 0.12817611997681005, 0.07532160755779062, 0.16800204079066003, 0.024890954539711987, 0.05816737376153469, 0.12829578641269887, 0.09993655101529189, 0.08771082918558802, 0.05424095284459846, 0.013244502296272134, 0.03708825932283487, 0.09516904183796474, 0.024393447575026324, 0.1508927938661405, 0.1171728332660028, 0.11427911211337362, 0.3846794425376824, 1.6680698863097598, 32.97271810259138, 84.75748239244733, 58.82699980054583, 42.58664172036307, 78.82458932059151, 45.319653102329795, 39.71257495880127, 1.3896596942629134, 0.5817792905228478, 0.5167590251990727, 1.0055616476706095, 1.0933992543390818, 2.272757713283811, 6.250087457043784, 4.547053149768284, 4.524382480553218, 6.281949290207454, 4.598472859178271, 7.721785834857395, 5.14106376682009, 9.597346952983312, 8.965621079717364, 4.1025013242449075, 6.15241402387619, 5.781088829040527, 4.822872315134321, 3.490623631647655, 1.0589200130530765, 0.10996706278196403, 0.23906007355877332, 1.007361339671271, 1.9363954194954462, 3.7535224046025957, 8.989911113466535, 24.267530270985194, 33.693294933864046, 44.285976546151296, 55.940374170030864, 69.12353529248918, 73.58686351776123, 70.04599203382219, 68.9220027923584, 70.43112373352051, 68.93318939208984, 72.93785313197544, 71.026869228908, 73.20816584995815, 71.39208044324602, 70.95429529462541, 66.56893280574253, 59.35090787070138, 55.05276264463152, 60.87792042323521, 65.02614784240723, 64.9968125479562, 49.325091566358296, 11.744348134313311, 62.339675494602744, 61.84078788757324, 62.02556133270264, 59.578510011945454, 52.996255670275005, 52.92300428662981, 55.53930677686419, 64.61242430550712, 69.20421777452741, 68.06781210218156, 68.97066797528947, 67.73113019125802, 68.18659850529262, 63.60230909075056, 67.53527436937604, 64.43623883383614, 56.777100563049316, 40.75333867754255, 27.81024476460048, 15.809562819344656, 10.612462265150887, 7.069295270102365, 8.212524073464529, 5.923798314162663, 4.703535267284938, 4.324422878878457, 3.6128192118235996, 1.7373439690896442, 0.4373141638934612, 0.9895262909787041, 1.9215123781136103, 1.8234098936830248, 0.37205288293106215, 1.2150296419858932, 0.7485071239726884, 0.4859206942575318, 0.9078758923070771, 2.2049315699509213, 3.772438875266484, 6.290802163737161, 4.399134687014988, 5.440941504069737, 3.2834967459951128, 3.5555135096822466, 0.6574053296021053, 0.265684322054897, 0.45560494384595324, 1.1259764262608118, 1.7500690519809723, 53.234227997916086, 24.20931305204119, 66.5109222957066, 56.69759580067226, 27.358549322400773, 46.136636189052034, 44.35447188786098, 1.8591423077242715, 0.22119559001709732, 0.008982330377745842, 0.23701144063047, 0.07430402216102396, 0.01761871137257133, 0.05622809353683676, 0.04256838633279715, 0.008217590877653232, 0.00933882758753108, 0.04077657551637717, 0.07918070762285165, 0.009258530601593, 0.035856521488832574, 0.06064128529812608, 0.03500294139874833, 0.09256082786513226, 0.068717697635293, 0.059573834362838946, 0.054154843358056884, 0.02504983012165342, 0.0370607786545796, 0.03194601221808365, 0.02621874918362924, 0.0668366425005453, 0.035398503565894704, 0.028876794768231254, 0.07993510285658495, 0.03269199361758573, 0.1569654515811375, 0.20552278815635613, 0.1615545196192605, 0.16215195613248007, 0.23498894487108501, 0.1540855589721884, 0.1705060928527798, 0.3051958775946072, 0.17005478564117635, 0.15194935431437834, 0.19124038597302778, 0.1988666174667222, 0.1490252890757152, 0.13175076459135326, 0.16211777153824056, 0.2230952437967062, 0.2005877758243254, 0.14017063778425964, 0.24070831654327257, 0.2120448260435036, 0.20318832913679735, 0.25717443440641674, 0.20665885933807918, 0.1686909031122923, 0.1908711814986808, 0.13505354736532482, 0.21831978218896048, 0.2186246615435396, 0.13456296654684202, 0.2136734729366643, 0.22215877047606877, 0.35556184926203316, 0.5686017604810851, 1.8463013853345598, 55.65858997617449, 100.04587473188127, 79.95356736864362, 54.46263824190412, 94.4858706338065, 59.59002317701067, 42.41080365862165, 1.2423347596611296, 0.7806180066296032, 1.0983965290444238, 3.2974945434502194, 3.127005074705396, 13.29395796571459, 17.812033653259277, 15.102262258529663, 9.884195515087672, 9.973668336868286, 17.590234994888306, 14.300881351743426, 9.079834699630737, 18.85016053063529, 12.082912138530187, 2.689473318202155, 7.419935243470328, 8.576934507914952, 5.9450324433190485, 17.893489122390747, 4.25719905751092, 0.1974488321159567, 0.30000888449805124, 1.315028007541384, 4.2009889994348795, 6.1177776881626675, 12.512864930289131, 30.25022976739066, 38.62690155846732, 49.58157736914498, 58.59522874014718, 69.98752989087785, 73.23975236075265, 69.21696771894182, 68.23145607539585, 70.02204854147774, 69.09000328608921, 76.00503812517438, 69.9052632195609, 73.82815361022949, 68.64841052464077, 69.03581428527832, 66.49693557194301, 60.47200666155134, 55.66293260029384, 63.10088539123535, 67.58576692853654, 69.04575715746198, 52.934670312064036, 14.103585515703474, 69.84329223632812, 65.24507863180978, 64.67748723711286, 61.99134840284075, 56.21700627463204, 57.4569296836853, 61.455350467136924, 68.88974230630058, 73.52941581181118, 71.21959141322544, 69.43631540025983, 72.09196553911481, 71.97723688398088, 67.10224178859166, 69.69859600067139, 67.65824358803886, 65.61604990277971, 51.14562382016863, 46.510369368961875, 39.10708808898926, 29.420868464878627, 20.351874692099436, 15.66593313217163, 11.986594472612653, 8.67975308213915, 6.006339873586382, 5.539391832692282, 2.8512682020664215, 0.9860905153410775, 1.8275073766708374, 2.677139614309583, 2.8859080118792395, 1.869165084191731, 3.8155481048992703, 1.9325795556817735, 0.7972797325679234, 1.4718995498759406, 3.4072543680667877, 5.646820536681584, 9.4496716771807, 16.9549229826246, 8.97918917451586, 12.740736314228602, 5.651708594390324, 4.325223224503653, 0.8345214799046516, 1.4894270322152545, 2.305180613483701, 2.929449115480695, 47.558946337018696, 32.964189188820974, 88.74629034314836, 64.87815121241978, 39.75262784957886, 57.57899216243199, 67.75792244502476, 10.847571066447667, 0.2533003251467432, 0.16747131784047398, 0.2598455010780266, 0.1558401012527091, 0.14847191662660666, 0.19431800368641103, 0.13966048801583902, 0.18456073797174863, 0.252566964498588, 0.13186284500573361, 0.2402828208037785, 0.13644838466175965, 0.20958642581743853, 0.2496513266648565, 0.09823740433369364, 0.18332562781870365, 0.18071253517908709, 0.19465444849005767, 0.0666299539485148, 0.1934024156736476, 0.07518233145986285, 0.06679595075547695, 0.11983764384474073, 0.14899353363684245, 0.12331468798220158, 0.16845224877553328, 0.17833501632724488, 0.1874336145286049], [0.08289715927094221, 0.044979133044502566, 0.05945077525185687, 0.04422479548624583, 0.08004758360662631, 0.022710193879902363, 0.06366071863366024, 0.07685300002672843, 0.11738244630396366, 0.03863679158634373, 0.0774713082771216, 0.13905173353850842, 0.05553184875420161, 0.04394483872290168, 0.04600258098383035, 0.10783292087061064, 0.04330937371456197, 0.15165320092013904, 0.0523982315457293, 0.049156289614204846, 0.016556407125400643, 0.035272659068661075, 0.0632988762642656, 0.08635135034897498, 0.07042429463139602, 0.04076104384980031, 0.04527176823467016, 0.055584686276103766, 0.008707605967564242, 0.06995298420744282, 0.06944103632122278, 0.15666567480989865, 0.030829197860189846, 0.11782181129923888, 1.5080289883272988, 58.700375829424175, 59.91751956939697, 39.194861207689556, 35.149811063494, 60.28268214634487, 33.07116365432739, 21.140439646584646, 1.3208675341946738, 1.192539625934192, 0.36732330386127743, 0.8953224516340664, 0.4606537329299109, 1.827195793390274, 2.383950820990971, 3.320373007229396, 3.66057722057615, 4.402498917920249, 10.066915767533438, 5.0892024125371655, 4.99040423972266, 4.841604658535548, 3.1601820715836118, 3.6901396342686246, 5.082016672406878, 5.0287743636540005, 2.2911239734717777, 3.0764855912753513, 0.035261660016008785, 0.20146090111562184, 0.07703853864222765, 0.35163769125938416, 1.871764144727162, 2.890495777130127, 6.093577980995178, 13.736381036894661, 24.08997253009251, 34.708006381988525, 47.698994227818076, 57.15375198636736, 65.46643434252057, 70.83351475851876, 68.44653061458042, 68.62508542197091, 63.73151779174805, 67.90058980669293, 59.77086394173758, 65.92300742013114, 65.83508491516113, 67.8209148134504, 58.999210902622764, 56.85488564627511, 53.0800370488848, 61.15950311933245, 48.61933524268014, 54.53689364024571, 2.24813112616539, 34.25420216151646, 65.97200611659459, 54.925826004573274, 66.89442116873605, 51.407772404806956, 54.36197968891689, 58.35202094486782, 69.38990838187081, 72.80307197570801, 74.95462335859025, 72.7773358481271, 71.64363302503313, 56.507930823734824, 52.966079643794465, 56.423510210854666, 64.79685728890556, 49.58945662634713, 27.20265085356576, 9.90667120047978, 6.7392271757125854, 6.7996152724538526, 6.357811025210789, 3.9873214704649786, 2.759635793311255, 1.2001224990401949, 0.2864764263587338, 0.31430673013840404, 0.3207692876458168, 0.17096723882215364, 0.16451840129281792, 0.006316976546908596, 0.1855452244303056, 0.15383933218462126, 0.25438674113580156, 0.4115287475287914, 0.5389557512743133, 1.4776830566780907, 2.011620742934091, 0.992693692445755, 5.2591001987457275, 2.854176891701562, 4.497429983956473, 1.2232795421566283, 1.329015165567398, 1.8912275688988822, 0.33832730406097, 0.9078935885003635, 3.823139011859894, 32.110022817339214, 23.589839458465576, 61.09848403930664, 53.56714398520333, 18.414970534188406, 35.19954626900809, 38.440835748400005, 19.15652745110648, 0.42892961523362566, 0.054743648905839236, 0.022667933022603393, 0.0552114071989698, 0.06291558540293149, 0.038702755368181636, 0.02561866638383695, 0.03267420921474695, 0.06360772504870381, 0.04406924133322068, 0.05381845622988684, 0.021476206702313254, 0.03712844216663923, 0.08029393931584698, 0.057977085400904925, 0.050000923220068216, 0.055894461260842424, 0.09247120017451899, 0.010687359957955778, 0.04067244753241539, 0.08609652652272157, 0.02437197703069874, 0.036986930295825005, 0.11043122144682066, 0.05274978053889104, 0.014381388568186333, 0.09029149463666336, 0.1861578058451414, 0.0240150031500629, 0.07888732943683863, 0.06226247509143182, 0.06253686108227287, 0.06152390329433339, 0.021582170123500482, 0.04305740991341216, 0.026127260610727326, 0.05160665937832423, 0.10403163198913846, 0.06676749978214502, 0.03001305933243462, 0.12345354338841778, 0.023300636393417205, 0.02662928492229964, 0.03167098840432508, 0.017977997361283218, 0.06340869037168366, 0.056367976923606226, 0.04163552960380912, 0.047401574307254384, 0.0384710356593132, 0.015365087926121694, 0.04833320967320885, 0.0771402781829238, 0.06804503872990608, 0.06771846661078078, 0.06785873336983578, 0.03873742850763457, 0.06995518266090325, 0.018985358931656395, 0.040436157890196354, 0.03616808441334537, 0.07242151496133634, 0.11665979293840271, 3.289653067077909, 77.07116276877267, 76.57106617518834, 41.82580355235508, 50.52666439328875, 66.92809908730644, 42.20058938435146, 41.794804164341514, 2.1280039378574918, 1.366488971880504, 0.5172056640897478, 1.0530932971409388, 0.47357966218675884, 1.2426071507590157, 0.6098727030413491, 1.2019220824752535, 5.5603853804724555, 8.175583975655691, 6.87224566084998, 7.501175318445478, 6.62871173449925, 6.862111713205065, 10.044278536524091, 7.425635371889387, 11.861701471464974, 7.007319509983063, 3.4872402931962694, 1.7701845211642129, 0.5113674945064953, 0.3365766294300556, 0.355791872633355, 0.4745123492819922, 2.5527136623859406, 4.011283201830728, 5.635191423552377, 12.777005910873413, 26.66513126237052, 39.95821114948818, 56.24262775693621, 64.68401159558977, 72.63558564867292, 77.94535037449428, 76.42971202305385, 76.30728476388114, 69.40808486938477, 72.97520664760044, 66.89662374768938, 72.28419440133231, 72.18099975585938, 72.2254751750401, 62.66066837310791, 62.11560998644148, 58.38801261356899, 68.73757675715855, 56.33001177651541, 64.44869000571114, 2.798770001956395, 39.02054827553885, 72.310409954616, 59.08794634682791, 70.46400955745152, 54.45235143389021, 57.01229361125401, 60.01578099387032, 69.09970297132219, 73.73173345838273, 73.07385717119489, 71.35855538504464, 73.82315785544259, 58.774638175964355, 55.65736709322248, 55.980680670057026, 63.946856362479075, 57.996714387621196, 41.86169794627598, 25.96907809802464, 14.673287425722394, 13.024110777037484, 10.121582456997462, 6.681795971734183, 2.346217542886734, 1.4218880449022566, 0.4051890862839562, 0.3049983153385775, 0.19601748963551863, 0.24696052819490433, 0.23088250522102627, 0.09427467161523444, 0.25279826351574486, 0.12581203611833708, 0.3107573405972549, 0.5050910455839974, 0.6926107662064689, 2.004102574927466, 3.130039917571204, 4.246733333383288, 3.5148068368434906, 3.4296264818736484, 2.052586019039154, 2.9263675894056047, 1.3542595995323998, 0.9812206966536385, 0.38174046309930937, 0.8120471515825817, 3.9740161044257025, 61.38706357138497, 26.798423767089844, 55.91187613351004, 64.5807683127267, 27.78166161264692, 37.512188162122456, 53.355505330221995, 20.662992443357194, 0.44837702597890583, 0.0294207220098802, 0.028162923342149173, 0.011870817480874913, 0.06957434131098644, 0.02305718481407634, 0.01602604040609939, 0.00402101718022355, 0.02367130311072937, 0.02850338676944375, 0.027787532324769666, 0.02274181361177138, 0.02703947969712317, 0.05132013778867466, 0.039382623708141704, 0.03848392782466752, 0.06406833497541291, 0.0346433483729405, 0.019485848057749014, 0.052933446397738795, 0.04659373087010213, 0.03814463656661766, 0.0161901474930346, 0.03568926939208593, 0.02726710105447897, 0.07690895202436618, 0.03062707245615976, 0.11604532519621508, 0.05441660520487598, 0.34401193474020275, 0.31454226321407724, 0.24636434018611908, 0.1423246879130602, 0.19659636143062795, 0.20260987803339958, 0.2051615903952292, 0.1003979141158717, 0.343671120171036, 0.18661854469350406, 0.14326124265789986, 0.2899102478155068, 0.12204224483243056, 0.12381395404892308, 0.15705279260873795, 0.22515717601137503, 0.1150389899100576, 0.2712341142552239, 0.18300454504787922, 0.08755228947848082, 0.08392307029238769, 0.08263633719512395, 0.1808745286294392, 0.259712562497173, 0.13344187741833075, 0.16641793293612345, 0.15157735427575453, 0.23530541360378265, 0.12180292553135327, 0.18859542932893547, 0.16995437602911675, 0.3206627033650875, 0.15777127976928437, 0.33277002083403723, 7.58154513154711, 103.8069624219622, 88.14955125536237, 68.55758367265973, 58.13217646735055, 83.89396027156285, 51.456632137298584, 43.154497146606445, 2.7463200049740926, 2.258812244449343, 1.3650627455541064, 2.719616775001798, 2.0698036551475525, 6.204032625470843, 9.84288239479065, 13.418979508536202, 13.606467093740191, 15.551333018711635, 20.06350186892918, 18.68678058896746, 18.563203402927943, 9.481669000216893, 14.285927091326032, 10.397957478250776, 13.4214973620006, 12.790514945983887, 9.452331100191389, 6.503648936748505, 1.5668081428323473, 1.4017657360860278, 0.6425429156848362, 1.4332896045276096, 3.0005161591938565, 4.856616675853729, 6.034216914858137, 14.174327731132507, 28.431170531681605, 41.606410707746235, 56.98981271471296, 63.44614832741873, 70.48015022277832, 76.51179109300885, 75.20213903699602, 74.0082231249128, 68.96784005846295, 70.11468887329102, 65.20452199663434, 72.09679453713554, 73.02212088448661, 72.08247429983956, 64.97846930367606, 63.100141933986116, 60.73098686763218, 72.2597575868879, 58.20835651670183, 67.51798030308315, 3.4291917851993015, 42.363257135663716, 78.68805721827916, 61.131397656032014, 74.88171591077531, 57.6942731993539, 63.27584797995431, 65.49329607827323, 73.57375226702008, 74.71159621647426, 76.54602486746651, 76.00229358673096, 78.51689529418945, 62.68746757507324, 57.10281126839774, 58.84466906956264, 68.33019692557198, 64.1707203728812, 56.02587175369263, 43.8788503238133, 35.020717007773264, 25.897511652537755, 20.467586517333984, 15.505400214876447, 6.628854172570365, 2.4382032241140092, 1.021932146378926, 0.6082076866711889, 0.40939600339957644, 0.38466475903987885, 0.28811872537646976, 0.42276653594204355, 0.5707346403173038, 0.7749497964978218, 0.48624633678368157, 1.8369773370879037, 1.6001474452870232, 3.5247286473001753, 3.1995047501155307, 3.7074137244905745, 14.65991040638515, 8.00514553274427, 11.56802977834429, 5.1152850815228055, 4.877356614385333, 4.347666774477277, 1.4623851861272539, 1.9160536995955875, 6.045918115547725, 53.0757326398577, 36.41152054922921, 80.77603258405412, 73.59010832650321, 38.04222106933594, 50.60865313666207, 70.01246002742222, 44.10309648513794, 0.5795175975986889, 0.14550933774028504, 0.13467552193573543, 0.11769417886223112, 0.1600755439805133, 0.1417542299521821, 0.10822078505797045, 0.133390729448625, 0.2021187408162015, 0.14460828394762107, 0.12565734370478562, 0.13544757265065396, 0.19120465431894573, 0.2021466557468687, 0.10189519662942205, 0.06873531240437712, 0.1172353263412203, 0.15243589106414998, 0.07030103195990835, 0.12647006580872194, 0.14602689711110933, 0.09898417283381734, 0.12564477723624023, 0.17367497352617128, 0.10620461324495928, 0.2601659595966339, 0.1728928397808756, 0.16960585330213818, 0.15586999750563077], [0.0220008313190192, 0.16459473648241588, 0.13186181363250526, 0.067474872539086, 0.047584517526307275, 0.1549406759440899, 0.030616901216230223, 0.10644067557794706, 0.044177359103092124, 0.05688597734219261, 0.034932428039610386, 0.055028362199664116, 0.061616238339671066, 0.10707110246377331, 0.1033016572307263, 0.09514025838247367, 0.05547587300783821, 0.09579413543854441, 0.026041117197434818, 0.022012167942843268, 0.05289801669174007, 0.04524488467723131, 0.027095216259892498, 0.009662605838717093, 0.030882734273161207, 0.027636812733752385, 0.0167525495469038, 0.0779188699754221, 0.06026311737618276, 0.045236413167523484, 0.019242749316617846, 0.12319859064051084, 0.02249338837074382, 0.09112460671791009, 0.23169731721282005, 25.75241936956133, 58.63388156890869, 48.581731591905864, 33.251639638628276, 44.39651543753487, 64.05377524239677, 35.19958448410034, 26.925386462892803, 6.829819091728755, 1.2857073694467545, 0.06482518650591373, 0.603868482368333, 1.389700514929635, 0.5690077958362443, 2.2061455505234853, 4.164976920400347, 2.48320540360042, 2.287616001708167, 4.422935741288321, 3.762872074331556, 11.552735924720764, 10.083462902477809, 6.063457105840955, 7.875745756285531, 2.595820286444255, 1.539637755070414, 0.28977019818765776, 0.2723789113972868, 0.08124715888074466, 0.05183041308607374, 0.12646152983818734, 0.16785593863044465, 0.7331970940743173, 1.8498436638287135, 1.3812143760068076, 3.8317434872899736, 3.355575838259288, 6.551582387515476, 12.447121075221471, 22.41232303210667, 36.68395594188145, 48.763010093144004, 59.15356513432094, 60.23841517312186, 66.10714163099016, 62.58398805345808, 65.30934946877616, 66.31207874843052, 67.07756178719657, 59.74810859135219, 61.27366897038051, 52.55214418683733, 67.19388852800641, 52.26377657481602, 61.37625217437744, 4.5713067054748535, 25.141033479145594, 76.85403156280518, 60.132184164864675, 72.03294059208461, 59.869312967572895, 61.58489268166678, 70.23785958971295, 70.5145993913923, 74.44762025560651, 71.24179785592216, 71.18136937277657, 56.534316607883994, 37.06511674608503, 21.28894349506923, 20.039113691874913, 28.6332745211465, 28.230270317622594, 19.173138856887817, 6.92257102898189, 3.3555111331599097, 4.346941121986934, 2.140531757048198, 1.4521326848438807, 0.24412921869329043, 1.1509492290871484, 0.7456555398447173, 0.1538317868752139, 0.14439131559005805, 0.05749114576194968, 0.05112316246543612, 0.0947907789211188, 0.07434166049850838, 0.028757063871515647, 0.05805548333695956, 0.03575594563569341, 0.15531647577881813, 0.4006194786301681, 2.103974678686687, 5.2542138780866345, 5.189830567155566, 1.8749757323946272, 2.7809222510882785, 1.3235963306256702, 2.2020908423832486, 0.11514243935900075, 1.0913865566253662, 4.939334545816694, 34.61857264382498, 20.2633980682918, 56.66037082672119, 58.95135171072823, 25.99800865990775, 24.778665815080913, 34.71275894982474, 26.474267721176147, 0.8363668237413678, 0.18136770145169326, 0.09348020888864994, 0.0789595866309745, 0.07485550828278065, 0.042644497605838945, 0.06929509022406169, 0.07893866061099938, 0.06630591955035925, 0.0636377027258277, 0.009756292865079428, 0.035386008343526294, 0.05310970265418291, 0.06284034944006375, 0.07281006446906499, 0.04493980176214661, 0.14698752627841064, 0.047680075612983534, 0.03099667726616774, 0.08889042838875737, 0.008468126362588788, 0.0528153677337936, 0.01769532136885183, 0.086638798138925, 0.01067807590256312, 0.08913474170757191, 0.04629129084891506, 0.10642904548772744, 0.09645956794598273, 0.11116233614406415, 0.1186806330723422, 0.14748383393245085, 0.03162118732663138, 0.14787612216813223, 0.0355621696050678, 0.04969978259344186, 0.04689975016351257, 0.061399120704403946, 0.022713973319956234, 0.11305349466523953, 0.08372367599180766, 0.06969341742140905, 0.058541626536420414, 0.03740890443857227, 0.02759140686664198, 0.036091637265469344, 0.04482204879501036, 0.13863910282296793, 0.02976738555090768, 0.03080247375848038, 0.07812135839568717, 0.033570458979478905, 0.053621552152825255, 0.016496324545836875, 0.058524452815098424, 0.03693654567801526, 0.04390213172882795, 0.04219409284581031, 0.007087297421613974, 0.05238296450780971, 0.08662076946347952, 0.03160042415506073, 0.014070607655282532, 0.11369560592408691, 0.34168968935097965, 42.65269129616873, 79.16585009438651, 60.91157749720982, 37.23299217224121, 63.927116530282156, 62.02239295414516, 37.04053054537092, 51.96257563999721, 6.648174073014941, 1.5859658462660653, 0.3663751190262181, 0.6682002246379852, 0.8461628609469959, 0.6420264148286411, 1.4779045305081775, 1.6595398868833269, 3.4140336385795047, 5.244274045739855, 2.632104430879865, 8.729533450944082, 10.011636768068586, 8.983426707131521, 7.039103610174997, 9.155365960938589, 6.137099325656891, 1.5898854987961906, 0.5623624409948076, 0.07148902464125838, 0.1959783381649426, 0.23686571844986506, 0.027267358897786056, 0.3973309179501874, 0.8155804191316877, 1.2097227381808418, 2.2080096219267165, 5.941100631441389, 5.003496382917676, 9.18930356843131, 17.18198663847787, 28.08857570375715, 43.968805176871165, 57.04079164777483, 68.55781296321324, 68.85937867845807, 73.90022727421352, 68.55147620609829, 72.12412180219377, 70.46549647194999, 72.53846372876848, 63.61104992457798, 67.17523261478969, 59.279793058122905, 72.75799206324986, 58.279481751578196, 69.69049440111432, 4.843084624835423, 27.00875268663679, 82.61516516549247, 60.36954852512905, 72.59000546591622, 59.98993369511196, 65.19659410204206, 69.10583128247941, 71.5320658002581, 73.87460231781006, 71.45858860015869, 71.58338519505092, 62.533571924482075, 39.18880932671683, 24.05027747154236, 23.91213165010725, 30.87604706627982, 28.86269187927246, 22.525516135352, 10.24659618309566, 6.642710617610386, 4.5454016498156955, 0.8664699484195028, 0.602776475250721, 0.5019386261701584, 1.3101226879017693, 0.7130211538502148, 0.2475167912031923, 0.08531222825071641, 0.17184211473379815, 0.030309867512966906, 0.13082727843097278, 0.04684427992573806, 0.06972804984876088, 0.027212596032768488, 0.09657156015081064, 0.2204044046146529, 1.0108475983142853, 4.5843271953719, 4.519864414419446, 4.696708227906909, 3.0683129898139407, 1.7868080862930842, 0.7842380180954933, 0.9225530390228543, 0.1365030745842627, 0.7440885582140514, 4.3610073157719205, 66.20493057795933, 25.35498414720808, 49.063880988529746, 68.84751115526471, 33.480614049094065, 30.710440226963588, 50.20403521401541, 26.9099406174251, 0.5720697258199964, 0.1838252195822341, 0.04792753394160952, 0.052165331185928414, 0.04685665640447821, 0.03188154460596187, 0.022220632560285072, 0.005855009974246579, 0.06726504236991916, 0.024494345732299343, 0.08700180080320154, 0.017885038063728383, 0.04595673915797046, 0.02981363789045385, 0.0389667428098619, 0.09086618665605783, 0.0295849376624184, 0.006331634175564561, 0.04163179426853146, 0.054799078431512625, 0.029533677734434605, 0.048137666058859656, 0.061772878148726056, 0.05285028175317815, 0.049075825539018424, 0.05159394023939967, 0.04865557148254343, 0.11704404731946332, 0.0719488203259451, 0.09085946237402302, 0.17005637341312, 0.26718735854540554, 0.21110828486936434, 0.19790564903191157, 0.09987797987248216, 0.3890194339411599, 0.2047704556690795, 0.15956269364271844, 0.13846489574228013, 0.1471129059791565, 0.1980706551777465, 0.19189872778952122, 0.21003402822784015, 0.16461767096604618, 0.12303281096475464, 0.20200728465403828, 0.13888489534812315, 0.15356612684471266, 0.15770409123173781, 0.11256345667477165, 0.17964576956416878, 0.12337171206516878, 0.09413741076631205, 0.1293902633977788, 0.11191095704478876, 0.11124234899346318, 0.08752733296049492, 0.18493048527411052, 0.1645465197839907, 0.1279321459255048, 0.1806441117078066, 0.2290496735700539, 0.09489904596869435, 0.3484298491052219, 0.5995306351355144, 63.39587811061314, 100.29269559042794, 76.25700759887695, 60.50226606641497, 70.66272108895438, 90.16657856532505, 50.50449616568429, 49.41895825522286, 11.27668399470193, 2.112637996673584, 0.8841750983680997, 2.701335630246571, 4.307593473366328, 3.1127949229308536, 7.142048554761069, 14.798386267253331, 11.443707398005895, 15.079381840569631, 16.210307121276855, 17.944207498005458, 34.27878488813128, 17.98570213999067, 15.220293045043945, 16.718319450105938, 16.073788915361675, 12.402005553245544, 0.8031152965767043, 0.665973706969193, 0.22349735721945763, 0.220022321545652, 0.19731596138860497, 0.5323205473167556, 1.5430986093623298, 2.5762404799461365, 3.679367755140577, 6.490035678659167, 4.596810936927795, 9.087551542690822, 15.618671485355922, 25.217425448553904, 39.26810564313616, 53.00265148707798, 64.48873247419084, 67.75890908922467, 71.40938145773751, 62.75804737636021, 68.2656273160662, 69.18479755946568, 70.6987474986485, 65.77730369567871, 69.67074067252022, 62.272833824157715, 75.0709570475987, 61.661989893232075, 70.60998426164899, 5.554389953613281, 26.888178859438213, 84.13939149039132, 63.152510506766184, 76.70539569854736, 64.27043397086007, 68.0231351852417, 73.61683804648263, 76.49335057394845, 75.4893080847604, 75.5447130203247, 75.06730229513985, 67.82396507263184, 39.11359160287039, 24.738152606146677, 26.097268887928553, 32.40546022142683, 36.540857791900635, 35.972991943359375, 21.4865711075919, 17.214101212365286, 10.215096524783544, 4.46543960911887, 2.2361839158194403, 0.48175172082015444, 1.7222209977252143, 1.1160198748111725, 0.4530910530260631, 0.33584666145699366, 0.5240595734545163, 0.1758373017821993, 0.2321478101824011, 0.16715923244399683, 0.22368565068713256, 0.10765633891735758, 0.36055510704006466, 0.31946888885327746, 1.1193050699574607, 7.849276593753269, 14.255379336220876, 13.402219585009984, 8.647894723074776, 7.782119648797171, 1.9850219530718667, 5.280736889157977, 0.2122962096972125, 1.694207706621715, 7.3818851709365845, 55.1014313016619, 30.25609404700143, 72.18154866354806, 78.71601676940918, 43.089420318603516, 45.28695835386004, 68.5088837487357, 50.61261708395821, 1.3734013438224792, 0.25501693731972147, 0.3132601034428392, 0.16482361991490635, 0.1258918046951294, 0.1411882774638278, 0.19247869881136076, 0.17206759192049503, 0.18416086371455873, 0.09128110403461115, 0.225143931007811, 0.09368155737008367, 0.08806079719215631, 0.09964234501655612, 0.11187771561422519, 0.18705728543656214, 0.3269406993474279, 0.1015810484864882, 0.07274858241102525, 0.16768258650388035, 0.11227821412363223, 0.22030843262161526, 0.10551292821764946, 0.15465464629232883, 0.17210883327892848, 0.18729732398475918, 0.14425499790481158, 0.12340068551046507, 0.15813455384756836, 0.1984655489878995], [0.017611666482740214, 0.05384184193930455, 0.022346361706565534, 0.04882414332990136, 0.024384314493675317, 0.04535920764984829, 0.07247820656214442, 0.02463686522761626, 0.03477083153224417, 0.029019059812916175, 0.06423224189451762, 0.10981007013469934, 0.013699097010040922, 0.049563895777932236, 0.04548879087503467, 0.03203812673954027, 0.06776766718498298, 0.09965166808771235, 0.017042728440303887, 0.04668997088447213, 0.012816675788989025, 0.07986458949744701, 0.0575051914368357, 0.018643959126036082, 0.04021466709673405, 0.013592202299540597, 0.036383196977632384, 0.04038679786026478, 0.04218723624944687, 0.06462902881737266, 0.01986213813402823, 0.05933133273252419, 0.10840048148695912, 0.07736921589821577, 0.10304542205163411, 1.7855238637753894, 54.01025840214321, 51.18923071452549, 50.88334321975708, 30.05796616418021, 53.24971553257534, 79.93101351601737, 40.44389370509556, 35.11553907394409, 17.289706298283168, 0.44784117330397877, 0.143566596986992, 0.3000211524111884, 0.2016792536846229, 0.08249311202338763, 1.043613348688398, 4.834570475987025, 2.641292554991586, 0.8375901409557888, 3.574449522154672, 4.187645418303354, 8.55969168458666, 6.759586266108921, 10.549371753420148, 4.707995576517923, 1.1913625576666422, 0.2785707605736596, 0.21198568493127823, 0.09727906182940517, 0.05968597584537097, 0.04073728833879743, 0.07177970904324736, 0.19746863176780088, 0.25354861468076706, 1.229118525981903, 0.3385774663516453, 0.6312314655099596, 0.6553579451782363, 0.32498513428228243, 0.30347614416054314, 1.6657557019165583, 4.0561142819268365, 14.029895527022225, 21.102808203016007, 28.17462566920689, 43.07643066133772, 60.69072205679757, 65.59835978916713, 72.96092809949602, 64.25315380096436, 69.65487793513707, 61.637052808489116, 66.12756933484758, 54.23678009850638, 70.82054941994804, 1.0228439888783862, 27.205046245029994, 85.21525750841413, 66.36831746782575, 73.10276862553188, 65.13094752175468, 66.82065214429582, 69.72643743242536, 74.73860386439732, 76.829726764134, 64.36731270381382, 51.391530990600586, 42.12379789352417, 27.12820611681257, 11.516950964927673, 8.44367413861411, 8.055615510259356, 3.5960545114108493, 0.856930288885321, 0.22392197086342744, 0.10860271206391708, 0.11164153114493404, 0.035920239319758754, 0.20847824242498192, 0.660419436437743, 0.3713836302714688, 0.02044034835749439, 0.050057865878833194, 0.03656709353838648, 0.04671378746362669, 0.03603921364992857, 0.07873538509011269, 0.10252930796039955, 0.07101432832756213, 0.01245142038845058, 0.29266792269689695, 0.013155291056526559, 2.1675354966095517, 3.428538437400545, 6.022919578211648, 1.9081638029643466, 1.0565346096243178, 1.134486341050693, 1.7719724880797523, 0.6993478046996253, 1.1071046846253532, 7.622185145105634, 33.415488583701, 18.097415276936122, 55.075834138052805, 52.9187902041844, 27.383507251739502, 17.257412808282034, 35.78292397090367, 22.00524197305952, 2.162730165890285, 0.39505554576005253, 0.0840917948101248, 0.07140126292194639, 0.08993734006903001, 0.02734016061627439, 0.11356972410742726, 0.09619716488357101, 0.05335673689842224, 0.017324101645499468, 0.045785293714808564, 0.04357726612527456, 0.05942041759512254, 0.011425757032286907, 0.01853951223061553, 0.030797479740743126, 0.0967543235580836, 0.012200946819835475, 0.0766554649120995, 0.026674877386540174, 0.013119941078392523, 0.0330703888487603, 0.07085547649434634, 0.041800919121929576, 0.020323472396869744, 0.02917316529367651, 0.02417433335046683, 0.05382678185456565, 0.09972488201622452, 0.03899799274014575, 0.028639534820935557, 0.023986906711278216, 0.025056157460702316, 0.01040241087321192, 0.03708122630736657, 0.0395186224819294, 0.051186737804008384, 0.0062383203434624845, 0.015452120220288634, 0.030412784311920404, 0.03988231046657477, 0.03121711972302624, 0.04294687995154943, 0.03156397325385894, 0.04718485361497317, 0.05563881301454135, 0.03492195485159755, 0.06129505378859384, 0.15360153280198574, 0.14053536392748356, 0.015307008721200483, 0.004869469241904361, 0.059857740199991634, 0.04907470256356256, 0.01822552184707352, 0.056689836617027006, 0.008718649124992746, 0.009356373654944556, 0.02413515982750271, 0.03000898812232273, 0.032010842846440415, 0.04323055169412068, 0.09423948278916733, 0.0701741934088724, 0.05591326007353408, 0.13774016605956213, 3.8976141469819203, 76.55573844909668, 67.35626792907715, 64.18577711922782, 39.252701486860005, 77.92525618416923, 70.19925539834159, 37.857416357312886, 67.52572059631348, 18.270260402134486, 0.7644518826689038, 0.37297685763665606, 0.5030632029686655, 0.14518703360642704, 0.0839484678581357, 1.0736014481101717, 1.8803636261395045, 5.151377499103546, 6.901238756520407, 4.127110540866852, 4.7071895854813715, 9.393658774239675, 8.234806946345739, 10.74004508767809, 6.044246639524188, 4.71310510805675, 0.45392404975635664, 0.1743367758712598, 0.11157336551696062, 0.10381480612392936, 0.19426762924662658, 0.030542951077222824, 0.3077971637248993, 0.4270426907709667, 1.0181141112531935, 0.11585718100624424, 0.4289555081299373, 0.504926785826683, 0.20823409195457185, 0.29275469375508173, 1.9726009624344962, 4.463387284960065, 16.009790795189993, 23.04697322845459, 33.46500839505877, 50.7691148349217, 67.26967947823661, 72.19568824768066, 78.7375214440482, 68.16835253579276, 73.89361953735352, 66.53002984183175, 71.88075419834682, 60.14594159807478, 73.20348276410783, 0.9961641005107335, 28.445388283048356, 89.14120510646275, 66.64937210083008, 76.18517017364502, 65.2126235961914, 68.67293766566685, 72.27241720472063, 76.24465370178223, 78.20394842965263, 65.43967682974679, 59.238235882350374, 45.96266719273159, 30.04758902958461, 11.235416906220571, 7.614951201847621, 9.41064885684422, 3.3652047387191226, 0.02872733725234866, 0.2379719748028687, 0.1862772958619254, 0.22816985792347363, 0.33363878993051393, 0.4212298983974116, 0.7118562992130006, 0.02576827657009874, 0.1111548790442092, 0.13127858564257622, 0.020007565151900053, 0.0409704974320318, 0.02413759407188211, 0.0389102106647832, 0.0693377565060343, 0.10668964364698955, 0.05052448084045734, 0.2129460291138717, 0.23524836237941468, 3.9117363606180464, 4.107251286506653, 3.7602825675691878, 2.9002484423773627, 0.5938701331615448, 0.9041577918188912, 0.7742642047149795, 0.07811579440853425, 0.6709102392196655, 5.179083440984998, 65.3462860924857, 21.950519698006765, 38.26596696036202, 61.74073382786342, 35.86579860959734, 26.423394748142787, 45.304818698338096, 33.21739544187273, 1.4298957352127348, 0.2946567359779562, 0.11427734792232513, 0.09971802881253616, 0.15816995980484144, 0.044461098699165244, 0.042863454071006606, 0.047806873451918364, 0.034598717732088904, 0.049088181661708016, 0.05339037187929664, 0.030674135645053217, 0.013372891299825693, 0.13911160746855394, 0.015618398619283522, 0.02526584853019033, 0.060919267524565966, 0.019385066947766712, 0.05568238514076386, 0.07595365614231143, 0.02550130527067397, 0.07600736218903746, 0.06533840325261865, 0.033981593525303264, 0.06847606452980212, 0.048066558981580396, 0.018207247202683772, 0.07086396496742964, 0.02834141537147973, 0.07258646682436977, 0.008066123201777893, 0.08090924165610756, 0.14059411148939813, 0.11042957939207554, 0.19327521749905177, 0.13044967369309493, 0.1601248870470694, 0.11794577964714595, 0.0762760756271226, 0.16844070010951587, 0.15217495363737854, 0.10765796061605215, 0.1313071112547602, 0.070819405572755, 0.06478954984673432, 0.18513806270701544, 0.12159118189343385, 0.23590822411434992, 0.25001863124115126, 0.17745060021323816, 0.16036675763981684, 0.09682548831083945, 0.1444361260426896, 0.10832179178084646, 0.12753307233963693, 0.16912336062107766, 0.09170189074107579, 0.0964044573317681, 0.1351822383169617, 0.0817269781338317, 0.13963729568890162, 0.1309809259005955, 0.17434749672455446, 0.19840814492532186, 0.09478256864739315, 0.2826144764465945, 5.516140120370047, 99.35098539079938, 88.05839783804757, 85.25589057377407, 54.34586681638445, 78.81958661760602, 104.18928010123116, 55.76245859691075, 60.62996006011963, 30.692979403904506, 0.432587950357369, 0.444882082087653, 0.8459242880344391, 0.9719223784548896, 0.9789385391133172, 7.276049775736673, 14.539008276803152, 9.289729356765747, 14.558372906276158, 13.18665259225028, 14.662581988743373, 24.411192962101527, 23.05806950160435, 29.049323967524938, 17.848150389535085, 12.056724378040858, 0.5428669899702072, 0.3049010405583041, 0.39169077202677727, 0.1213526361222778, 0.4854742724980627, 0.24799187428184918, 0.5562071512852396, 0.9019545071891376, 1.5386031248739787, 0.8367428407073021, 1.3618749337536948, 0.8834067795957837, 0.6844949445554188, 0.6379953739898545, 1.948787965944835, 3.6697870578084673, 13.800057802881513, 21.689352546419414, 31.78810235432216, 49.72138902119228, 65.89062881469727, 69.95317799704415, 79.0108288356236, 69.41534573691231, 76.17922946384975, 67.98671272822789, 76.2186952318464, 62.824895995003835, 77.24666036878313, 2.3782276766640797, 30.509296825953893, 94.36167158399309, 65.36260046277727, 79.91151687077114, 66.76417023794991, 72.49380765642438, 74.04802240644182, 81.31064782823834, 79.91073172433036, 68.78900732312883, 61.83693858555385, 50.061030864715576, 37.68952356066023, 17.97419592312404, 8.459316270692007, 12.465169889586312, 5.696710339614323, 1.5963651282446725, 0.5089318794863564, 0.29757712355681826, 0.17737436001854284, 0.2904922680131027, 0.737581733082022, 1.3597450937543596, 0.49879304638930727, 0.29090726003050804, 0.23777264835579054, 0.0813929760562522, 0.12200229269053255, 0.12434688902326993, 0.16272615960666112, 0.10969304320003305, 0.18364983185061387, 0.20773032041532652, 1.0787981578281947, 0.23962000065616199, 7.661373853683472, 9.030556338174001, 14.207830207688467, 6.915403093610491, 5.264773402895246, 3.3880093778882707, 3.823323139122554, 0.765148819557258, 1.3170541673898697, 10.580465810639517, 53.88757405962263, 26.049939496176584, 70.83747523171562, 75.27735328674316, 43.91463354655674, 36.63608980178833, 62.67783042362758, 57.86379534857613, 3.274074988705771, 0.5711025691458157, 0.417606738529035, 0.19483424669929914, 0.2399099793817316, 0.09580280033073255, 0.2832939342728683, 0.13636796469134943, 0.15215186987604412, 0.1766271979681083, 0.1309184871081795, 0.14953908936253615, 0.17964442606483186, 0.19507725723087788, 0.10233271600944654, 0.0962927568969982, 0.20618826816124575, 0.2024942556662219, 0.12090841281626906, 0.297784402434315, 0.07309667766094208, 0.1693970002233982, 0.22923993478928292, 0.12254246084817819, 0.15269647565271172, 0.15232153077210697, 0.11960458063653537, 0.15739222296646663, 0.21293708602232592, 0.17009008303284645, 0.1710251992834466], [0.03370661720899599, 0.020151105842420032, 0.03128378239593335, 0.06820032146892377, 0.015230017048971993, 0.004277757019735873, 0.04450617378045406, 0.07781161394502435, 0.028202816112233058, 0.030985087888049226, 0.020513295961011733, 0.09591071454009839, 0.034980933115418465, 0.08547496808958904, 0.06092474330216646, 0.04483168059960008, 0.021964580585647906, 0.06055110799414771, 0.0655768947409732, 0.09903167028512273, 0.022195816838315556, 0.017706459521182945, 0.06594949867576361, 0.05898664372840098, 0.043460765055247715, 0.03640768191378031, 0.04243521365736212, 0.08128094992467336, 0.058506885543465614, 0.03901793149166873, 0.034805721802903075, 0.03782467677124909, 0.012632029447039323, 0.032231760277811966, 0.12710900152368204, 0.013718677834341568, 7.205048739910126, 56.6180875641959, 41.988228116716655, 47.139410631997244, 28.638897350856237, 58.017242840358186, 83.76274354117257, 32.26827846254621, 33.77167061397007, 28.262923376900808, 0.6461579874157906, 0.5155190431645938, 0.1445961788828884, 0.1674438507429191, 0.16697168536484241, 0.8388872827802385, 3.3119852287428717, 2.221536461796079, 4.5894006831305365, 2.0198441530976976, 3.6056250035762787, 1.4085181908948081, 4.124024672167642, 3.5171926745346616, 1.575066293988909, 0.20221007162971155, 0.10206458611147744, 0.05879993124731949, 0.013494433885041093, 0.064964917222304, 0.1156138719192573, 0.28336083782570703, 0.5753350534609386, 0.11667149088212422, 0.6161957266075271, 0.2579103192048413, 0.21006686932274274, 1.1871811534677232, 2.0106655827590396, 1.3981860024588448, 0.6796664893627167, 0.8387167262179511, 1.6248119218008858, 6.859424497400012, 14.481970514569964, 27.15238584790911, 46.36621509279524, 60.38221509116036, 65.61811351776123, 71.86375890459333, 69.97913646697998, 79.65294660840715, 77.54691982269287, 28.490106889179774, 0.8357914803283555, 20.77445544515337, 75.49884796142578, 68.47635228293282, 74.3474828175136, 73.88048049381801, 74.77946622031075, 77.97348363058907, 77.96430506025041, 70.74897602626255, 47.9192555972508, 35.83760281971523, 29.70035627910069, 25.602984462465557, 13.013136965887886, 7.5520526341029575, 4.536269111292703, 1.3471958871398653, 0.5244508438876697, 0.4893742746540478, 0.2876099869608879, 0.29588458580630167, 0.4875390817012106, 0.17802820993321283, 0.04284090295966182, 0.009833836695179343, 0.07063744283680405, 0.06396164212908063, 0.041467531118541956, 0.025660152014877115, 0.022955401168603982, 0.03523355848821146, 0.08263167565954582, 0.1210500637867621, 0.16022734583488532, 0.15189532935619354, 0.6933572090097836, 1.513412322316851, 4.232839107513428, 1.8873697987624576, 1.6075401114565986, 1.2343841748578208, 0.6025810571653503, 0.5908406642930848, 0.7824534709964479, 12.469539437975202, 45.03178923470633, 16.210666690553936, 61.75115612574986, 57.5207245690482, 50.93010459627424, 24.002513817378453, 27.786494084766932, 23.631337574550084, 4.458627768925258, 0.5953401114259447, 0.04277079672153507, 0.13848237480436051, 0.07442239259502717, 0.12008608265646867, 0.0420903278780835, 0.228586451283523, 0.054543888196349144, 0.04211076535284519, 0.037526793112712245, 0.03277943642543895, 0.09867807211620466, 0.008523731459198254, 0.05099950624363763, 0.049508296618504186, 0.014806818150516068, 0.02842073781149728, 0.02639482562829341, 0.01864182174072734, 0.04115908606243985, 0.03810967844245689, 0.037435991556516716, 0.06833978077130658, 0.04416854154052479, 0.007731116892370794, 0.036760713505957804, 0.06452768961233751, 0.04053727996402553, 0.028098074054079394, 0.01033907980724637, 0.0791231474972197, 0.040480642646018944, 0.00871906812036676, 0.04010485638199108, 0.024418573726766875, 0.04283778848392623, 0.013396461910035993, 0.03395187708416155, 0.018783150407086526, 0.03341023650552545, 0.012397918750398924, 0.041673106873141866, 0.0638639670131462, 0.034245038138968606, 0.04922316263296774, 0.07454144834939923, 0.03553672114919339, 0.039124234180365286, 0.006189401785377413, 0.0699725260159799, 0.06356026152414934, 0.024122676479497125, 0.030382762530020306, 0.054920512451125045, 0.022775843839294145, 0.05339929461479187, 0.06449920471225466, 0.07957521466804401, 0.07409287563392095, 0.015428860039849366, 0.003933101094194821, 0.07604573334434203, 0.06007822336895125, 0.051968810481152365, 0.07792448824537651, 0.15428940446249076, 0.04173481284773775, 11.977672985621862, 84.58136640276227, 63.63928740365164, 55.39642749513899, 38.64453608649117, 84.81240790230888, 75.70762743268693, 30.698145389556885, 66.74908569880894, 35.9683644430978, 1.2052505952971322, 0.5595596571053777, 0.09840399146612201, 0.3827878497540951, 0.08819472643413714, 0.33204637680734905, 2.1619754178183417, 2.996676193816321, 3.387446573802403, 3.6611825823783875, 7.680486610957554, 9.004736832209996, 7.452503187315805, 10.209441559655325, 5.051346889563969, 0.3869420854108674, 0.22755404668194906, 0.036319835377590995, 0.08601384024534907, 0.1933986430189439, 0.2619655430316925, 0.6035749752606664, 2.0250557363033295, 0.08103255182504654, 0.6686604342290333, 0.46574263700417107, 1.5386496995176588, 2.2492352383477345, 3.9178286279950822, 1.3662044214350837, 0.5076091161796025, 0.7929281517863274, 2.059941121510097, 6.59138514314379, 16.527297837393625, 33.97157028743199, 52.574159554072786, 67.7401350566319, 73.560300554548, 77.0685294015067, 74.66266005379813, 84.7757978439331, 79.69075175694057, 28.590313809258596, 0.6987440713814327, 22.890366043363297, 81.27569144112724, 72.4322257723127, 78.76762104034424, 77.7868550164359, 78.23070594242641, 77.64415986197335, 77.12699849264962, 73.35373061043876, 49.94169902801514, 36.91301025663103, 31.138285977499827, 27.7774110521589, 14.51164105960301, 9.8789096730096, 8.24860954284668, 2.7525744693619862, 0.5689169807093484, 0.18003763710813864, 0.5762179089444024, 0.2432579525879451, 0.3030193272445883, 0.10982552716242415, 0.09777017869055271, 0.06853142620197364, 0.02887338852243764, 0.025262347289494107, 0.060244539087372165, 0.05278153937043888, 0.07676263273294483, 0.07904206256249122, 0.06819738341229302, 0.10293900740465947, 0.4856798957501139, 0.4140407384506294, 2.691564074584416, 0.891601311308997, 2.2832900966916765, 2.8772134269986833, 0.6959804253918784, 1.65126990207604, 0.6391405782529286, 0.41652645649654524, 0.6183533051184246, 9.509240320750646, 82.6697085244315, 19.967496871948242, 39.933861187526155, 67.0235048021589, 67.56103134155273, 33.22518784659249, 29.388986655644008, 46.60730021340506, 7.63815210546766, 0.538833777819361, 0.24037320166826248, 0.22313883288630418, 0.10543305107525416, 0.10158047173172235, 0.0990428321861795, 0.18324560139860424, 0.11818984869335379, 0.09406030883214303, 0.051638866042984385, 0.05320090115336435, 0.027133171812498143, 0.05685656963448439, 0.041425601047064574, 0.08426642936787435, 0.023103745887055993, 0.04192143711926682, 0.005408589062946183, 0.005257610780453044, 0.03776261456576841, 0.03231955931654998, 0.01619853248952755, 0.02951382040711386, 0.01911170724114137, 0.029176211915910244, 0.08354730438441038, 0.03203492405425225, 0.055879458851580105, 0.031624888735158105, 0.03828929005456822, 0.08552705922297069, 0.19837184330182417, 0.07893486760024514, 0.09993212018162012, 0.12234051525592804, 0.18270908375935896, 0.09992082935890981, 0.0797238274078284, 0.11276989416884524, 0.13055334027324403, 0.12567590842289583, 0.1432143694588116, 0.12969008088111877, 0.10289697894560439, 0.19263810025794165, 0.1729885810720069, 0.10645685185279165, 0.10196177448545184, 0.15156670127596172, 0.17715991581124918, 0.15444754383393697, 0.10841693596116134, 0.07924222360764231, 0.17878221161663532, 0.11379615802850042, 0.19188165584845202, 0.16538738752050058, 0.2342831056032862, 0.26155369941677364, 0.12267203389533929, 0.11029212855334793, 0.15354339592158794, 0.2026985218482358, 0.13682518872831548, 0.13546275826437132, 0.20373347774147987, 0.09120003267058305, 15.866108996527535, 110.18693038395473, 83.5216202054705, 80.0063875743321, 52.800656931740896, 88.28446442740304, 104.79706682477678, 46.973001275743755, 58.90408311571394, 50.22340679168701, 1.0011593124696185, 1.5317506811448505, 0.24990262889436313, 1.47486241374697, 0.7117913226996149, 2.7581176119191304, 11.307448881013052, 8.661867550441197, 11.47322334562029, 12.800160782677786, 14.781172105244227, 14.67715757233756, 16.703330448695592, 19.087174006870814, 9.507935796465192, 0.6918534125600542, 0.2825727058308465, 0.27498483870710644, 0.07251986861228943, 0.18856955000332423, 0.40249017253518105, 1.852665935243879, 3.5274985900947025, 0.20715712117297308, 1.9207000902720859, 1.890760519674846, 2.766056145940508, 3.2302031942776273, 5.825054424149649, 3.0661369008677344, 1.264809250831604, 2.0720750646931783, 2.72596721138273, 8.180617077010018, 19.31123604093279, 40.28224386487688, 54.35206808362688, 69.39824622017997, 74.38550336020333, 79.19301755087716, 74.34506484440395, 84.52936608450753, 83.29094001225063, 32.086124488285606, 0.48352986254862373, 23.406261103493826, 82.74790355137416, 73.46294239589146, 80.4491684777396, 80.20287568228585, 78.96192046574184, 80.29549516950334, 80.25021375928605, 72.75108555385044, 51.17277043206351, 36.91870777947562, 33.54329374858311, 30.408902304513113, 21.46643696512495, 15.526274340493337, 12.842589088848658, 4.627724340983799, 0.796675022159304, 0.8502068210925374, 0.9947203951222556, 0.8016273507050106, 0.8783201553991863, 0.4028103324983801, 0.21529289175357136, 0.1408943496644497, 0.16842126686658176, 0.1762458612876279, 0.20069448224135808, 0.11981777633939471, 0.15037437954119273, 0.19961865139859064, 0.30928011557885576, 0.36780137249401634, 0.7636014883007322, 0.3433201547179903, 1.696311816573143, 5.752424470015934, 13.366967899458748, 8.101322497640338, 4.143140035016196, 6.392464731420789, 0.8812776995556695, 0.678946102304118, 0.9185854004962104, 18.896225350243704, 69.77027361733573, 24.28329747063773, 75.05174527849469, 82.13236958639962, 69.2335113797869, 44.49120896203177, 44.61756195340838, 71.27988093239921, 21.885390758514404, 0.7647300277437482, 0.5991262282643999, 0.1689610414739166, 0.25670239116464344, 0.18583702162972518, 0.2163528177355017, 0.25551172505531994, 0.34000903953398975, 0.208529512530991, 0.13084964294518742, 0.12211593373545579, 0.25582813950521605, 0.08110132134918656, 0.1076628528535366, 0.1469644018049751, 0.10984387474932841, 0.17798026464879513, 0.14671575943274157, 0.1426029551242079, 0.09738548326173, 0.10849081485399178, 0.09613722310002361, 0.1325301027723721, 0.15481944887765817, 0.1324507955993925, 0.1681562853710992, 0.08194683705057416, 0.1310367150498288, 0.09598898355449949, 0.16913477358009132, 0.14342858296419891], [0.023027371681694473, 0.021566251691962992, 0.11719803405659539, 0.02391283443596746, 0.07996200677007437, 0.012962554032648248, 0.036377212298767905, 0.053671970697385926, 0.02107601862267724, 0.06519391600574766, 0.033439762956861935, 0.03396674378642014, 0.01710841741545924, 0.05563250942421811, 0.06987159393195595, 0.09050279722682067, 0.05697983569864716, 0.03695221983694604, 0.011606847002570118, 0.0015383967526889006, 0.026713754050433636, 0.07572842322822128, 0.022858589488480772, 0.046169924682804515, 0.04980929475277662, 0.031823987873005014, 0.029344044160097837, 0.04895079189113208, 0.06465260790927069, 0.03225194669461676, 0.041747674479016235, 0.03227904738326158, 0.05610188602336815, 0.026903560651200156, 0.00570372211015118, 0.1396167225071362, 0.05700695674334254, 10.59489721911294, 46.00424868719918, 41.9837326322283, 43.646464347839355, 28.299542120524816, 54.78460039411272, 88.1349183491298, 43.47313111168997, 30.509626865386963, 46.21875694819859, 2.8467184347765784, 0.5869460904172489, 0.05062628144930516, 0.25843146124056404, 0.21595188496368273, 2.5707633452756062, 4.550855117184775, 0.7855149124349866, 3.162483662366867, 5.60537713766098, 7.442744442394801, 3.871855003493173, 3.354361206293106, 4.251198419502803, 1.564712283866746, 0.14024239964783192, 0.06731824630073138, 0.03969892280708466, 0.08982958870806865, 0.11088523601314851, 0.0423895889627082, 0.14446883143058845, 0.061157080477901866, 0.02960775340242045, 0.12033636708344732, 0.17765470354684762, 0.39968310030443327, 0.47060306476695196, 0.5927282944321632, 0.7173068353107998, 1.177176181759153, 0.7146285218851907, 1.20686094888619, 1.1297472353492464, 9.806552001408168, 27.39506905419486, 37.62714958190918, 45.86859553200858, 65.16468102591378, 66.29272106715611, 46.35374307632446, 15.461378165653773, 0.5426179404769624, 0.45381225432668415, 4.862452728407724, 53.46752418790545, 73.23328358786446, 73.63174888065883, 74.99484648023332, 74.89436858040946, 74.77788203103202, 61.81410680498396, 45.544969286237446, 33.36329024178641, 21.587410313742502, 13.77085278715406, 9.870684742927551, 4.769962217126574, 1.5618722076926912, 1.0029223092964716, 0.21243494296712534, 0.055877270576144965, 0.011009425756388476, 0.11831397988966533, 0.05678449903747865, 0.14336869546345302, 0.06908734994275229, 0.02735909852864487, 0.08174628245511226, 0.1730490792542696, 0.04662717246849622, 0.07873161243540899, 0.039155884446310144, 0.026480887617383684, 0.06916157488844224, 0.060435003867106776, 0.033535531389393976, 0.05322388991979616, 0.08601324313453265, 0.7363902798720768, 3.359618169920785, 2.3302553594112396, 0.6885567094598497, 0.525697936969144, 0.32099355704018045, 0.2331284289913518, 0.6012188302619117, 21.58729566846575, 34.08531577246529, 12.627314788954598, 51.28738096782139, 64.23819432939801, 27.609671115875244, 18.89263834272112, 34.262953417641775, 37.051852634974885, 5.766767288957324, 0.6070493459701538, 0.11281355111194508, 0.135332995227405, 0.06754632227654968, 0.0698408427249108, 0.07246439837451492, 0.06088721353028502, 0.024313600966706872, 0.034444008355161974, 0.06024170281099422, 0.010839419655634888, 0.011536718712055256, 0.035932741327477355, 0.03762377951560276, 0.09472453354724816, 0.08737656926470143, 0.016250749151887636, 0.023491333571395705, 0.012456113306273307, 0.004429673376892294, 0.03446574861715947, 0.045556915790906975, 0.02016380462529404, 0.03828057427225368, 0.023260107496753335, 0.06512813882103988, 0.015303996025717683, 0.016951718234590123, 0.021513320871495774, 0.022064179348360215, 0.07207137053566319, 0.07287497312894889, 0.016323925760973777, 0.0253587145291801, 0.04140105165008988, 0.03228265379688569, 0.029076066932507923, 0.0171863030575748, 0.0447990362798529, 0.042553299106657505, 0.04026648681610823, 0.017251364387837902, 0.051311438969735584, 0.025809495876144086, 0.047900931976203404, 0.034035509917885065, 0.029818479237811904, 0.04135859232129795, 0.08135940214352948, 0.06461955646851233, 0.11124139225908689, 0.03914194055167692, 0.05538499681279063, 0.022621794337672845, 0.03313976226906691, 0.03899676798443709, 0.11419103826795306, 0.020732276174905043, 0.0529482011417193, 0.012378713664864855, 0.028085870601769005, 0.03616487494270716, 0.12723600970847265, 0.05037585792264768, 0.10911587452782051, 0.06459368392825127, 0.06122591785554375, 0.14964161600385392, 0.08514919664178576, 23.16077777317592, 78.76386901310512, 58.79878316606794, 52.491159847804475, 42.67472403390067, 81.70371437072754, 78.55485330309186, 35.18417337962559, 62.62481566837856, 52.49042681285313, 2.6529307876314436, 0.172205565231187, 0.09368026815354824, 0.2133954092860222, 0.4193670212158135, 0.6945450795548302, 1.0286886181150163, 1.3198123850992747, 2.583358475140163, 1.977899398122515, 3.4392158644539967, 6.932898657662528, 5.001635134220123, 2.4766834335667745, 3.160205956016268, 0.46464541873761583, 0.20729695366961615, 0.03573299418868763, 0.049224495954279385, 0.0709681608048933, 0.23458299094012805, 0.3576256813747542, 0.0565631269876446, 0.19697084490742, 0.05289341283163854, 0.09657627596919026, 0.3382951415010861, 0.34705605996506556, 0.5521745362452098, 0.23077051980154856, 0.6349621596080917, 0.467707023024559, 1.9607371304716383, 3.4154640989644185, 11.20299574307033, 30.487312725612096, 38.56018842969622, 46.236367157527376, 67.53779656546456, 71.47485433306012, 45.256876128060476, 15.527896744864327, 0.47095780287470135, 0.32142833513872965, 6.220408226762499, 63.010572705950054, 81.13585894448417, 80.67493629455566, 80.19417653764997, 79.52382823399135, 81.96783624376569, 67.58516243525914, 49.590116705213276, 35.43745606286185, 25.91629958152771, 17.766562904630387, 13.842004077775137, 6.86814318384443, 4.042611760752542, 2.0598694682121277, 0.1899808214179107, 0.08122062816151551, 0.0708660412845867, 0.09966660264347281, 0.027777047262394, 0.19744248102818215, 0.058843452483415604, 0.1452127636543342, 0.03665491293317505, 0.034539471446935616, 0.030539761962635175, 0.009703911657977318, 0.006858945790944355, 0.03804246276350958, 0.11661836159016405, 0.08299095995192017, 0.048359177208372524, 0.09234112501144409, 0.5656450305666242, 2.4054815513747076, 1.5640681641442435, 2.2708167774336676, 0.17226295572306427, 0.7191535362175533, 0.3045302890241146, 0.478227898478508, 0.8595198499304908, 19.727976833071025, 66.2433054787772, 18.506922994341167, 27.872283492769512, 72.53578867231096, 44.34984786169869, 29.745130470820836, 42.99409450803484, 50.88155058452061, 11.762892007827759, 0.5085463087473596, 0.1375745628029108, 0.22759276389011315, 0.07252255561096327, 0.05818783837769713, 0.07268024714929716, 0.029043748309569697, 0.05463816385184016, 0.05890401851918016, 0.12473681595708642, 0.06485821080527135, 0.03385577956214547, 0.029046984921608652, 0.09266719501465559, 0.07921319587954453, 0.11266121321490832, 0.038377007669104, 0.021226234401443174, 0.06893991785390036, 0.04641837027988263, 0.060150032729974816, 0.027227488180090274, 0.02877006120979786, 0.05733482486435345, 0.017157784230741005, 0.04746008438191243, 0.021531183305861692, 0.05405656434595585, 0.003949919856885182, 0.07366221624293498, 0.03285204306510942, 0.0494626549604748, 0.06695856167269604, 0.1414181108453444, 0.14334911294281483, 0.11420635958867413, 0.08555404456066233, 0.15652920784694807, 0.19784360378980637, 0.211378436801689, 0.14863617638392107, 0.10933740264070885, 0.15833261821951183, 0.11999450757035188, 0.08244593348354101, 0.1471926609852484, 0.08196541533938476, 0.11202315281012229, 0.14729602900998934, 0.1704620152179684, 0.16054621658154897, 0.12273840819086347, 0.19035690623734677, 0.13610309176146984, 0.06726361066102982, 0.24284448048898152, 0.3224462462323052, 0.15083194284566812, 0.16261740401387215, 0.16271564231387206, 0.12440520232277257, 0.09294077354882445, 0.20152906674359525, 0.14543011199150765, 0.24887877383402415, 0.2461401250745569, 0.137124042691929, 0.3036887970353876, 0.14331956952810287, 30.145857402256556, 107.36603818620954, 78.52462863922119, 77.05521665300641, 52.27561630521502, 89.59080914088658, 113.79449067796979, 58.33081504276821, 50.00497627258301, 70.53217833382743, 5.746559756142752, 0.9457079108272279, 0.18123690704149858, 0.6175747811794281, 0.7966790390866143, 3.7289657337324957, 10.404119661876134, 7.062607194696154, 11.088929772377014, 14.761515651430402, 12.64421193940299, 14.527572410447256, 13.071567841938563, 10.548827188355581, 4.452158996037074, 0.46072951172079357, 0.4545209977243628, 0.16133908475083963, 0.26131094672850197, 0.394280767334359, 0.6891005145651954, 0.7903346823794501, 0.17791238400552953, 0.2610250392130443, 0.31889134698680466, 0.49101665509598597, 0.6504091450146267, 1.186869353055954, 1.6004803074257714, 1.612407650266375, 2.6687420649187903, 4.095806300640106, 3.873129563672202, 6.429038746016366, 15.398286785398211, 36.01321159090315, 43.79675040926252, 51.134659562792095, 72.43923650469098, 76.96231228964669, 48.98692274093628, 20.990825823375157, 1.311507442167827, 0.42371719064457075, 8.17025123323713, 66.9095126560756, 83.26175062997001, 81.87982341221401, 83.12086200714111, 80.39144284384591, 83.61815152849469, 68.0777897153582, 50.9714811188834, 38.09860222680228, 29.18558509009225, 18.638871022633143, 13.186240911483765, 6.327422644410815, 4.1451780285154065, 2.1123652798788886, 0.351216158164399, 0.17044742671506746, 0.2867883081947054, 0.1947379625801529, 0.1892187044556652, 0.4938773587346077, 0.16699775468025888, 0.41069653789911953, 0.15717928510691437, 0.2628536368055003, 0.14883496000298432, 0.14326178548591478, 0.07896262646785804, 0.0793964546173811, 0.18981563885297092, 0.21295812060790403, 0.19114802378628934, 0.20235521027020045, 0.32476227624075754, 2.8819829310689653, 9.774195977619716, 7.762066279138837, 4.872826388904026, 5.507711521216801, 0.6622453470315252, 0.872316694685391, 0.6575017358575548, 34.82033096040998, 52.435807023729595, 19.030191830226354, 65.07532024383545, 91.07021263667515, 47.299337318965364, 41.913983140672954, 55.748350279671804, 73.69595718383789, 33.21682916368757, 0.49951815605163574, 0.2129766988967146, 0.21146511286497116, 0.21320571803620883, 0.14180159169648374, 0.23796133537377628, 0.16827796027064323, 0.08558156594101872, 0.14600819668599538, 0.1644239356475217, 0.13325336681944983, 0.11064395574586731, 0.15150559241218226, 0.2600820655269282, 0.22838036662765912, 0.24272074284298079, 0.24568841074194225, 0.10835660062730312, 0.16700243657188757, 0.11075719645512955, 0.18067194521427155, 0.11853412379111562, 0.11228487733751535, 0.09498532848166567, 0.04695092527461903, 0.18623340821691922, 0.09653081412294082, 0.0900045150358762, 0.10607569837676627, 0.1732224313808339, 0.140991583732622, 0.1711475391473089], [0.060842396292303286, 0.01618847999322627, 0.010353943116829863, 0.020705653853448372, 0.05780738379274096, 0.06664771120995283, 0.06030647576387439, 0.05098169469939811, 0.034554813123707256, 0.056768974156251976, 0.009478836503278996, 0.025772018690726588, 0.05747159716806241, 0.021593689951779585, 0.022036104961963635, 0.03766140088971172, 0.015627967659384012, 0.03005396481603384, 0.08546978408204657, 0.05835461549993072, 0.07613774947822094, 0.07396336365491152, 0.04177912796980568, 0.012879337649792433, 0.04500112097178187, 0.0428938286911164, 0.02250631446284907, 0.013944049848110547, 0.04039674857631326, 0.06290951929986477, 0.08791797235608101, 0.048859942837485244, 0.13342162993337425, 0.04934227267014129, 0.15686532695378574, 0.08117852506360837, 0.3156425484589168, 0.26426773092576433, 22.18816719736372, 59.774907793317524, 45.30382163184029, 42.23033462251936, 32.686122281210764, 55.997804505484446, 87.79780564989362, 41.34868812561035, 28.927890300750732, 53.2711055619376, 11.040200318608965, 0.9229109798158918, 0.14024086615868978, 0.13835443024124416, 0.09722716068582875, 0.10887113373194422, 0.35845316840069635, 1.2770149558782578, 3.631278621298926, 6.074526454721179, 6.353763265269143, 6.3858756678445, 2.9123678377696445, 0.904606927718435, 0.056647350146834335, 0.3077686109713146, 0.7186261245182582, 0.054949448576995304, 0.30447027938706533, 0.48051266159330097, 0.037704684638551304, 0.06650135799178056, 0.04561119180704866, 0.04813224795673575, 0.03979891172743269, 0.05568601869578872, 0.12595097294875554, 0.020139904925599694, 0.08444737430129733, 0.08606835374874727, 0.2471755152302129, 0.9253786759717124, 0.6537872723170689, 1.7944228776863642, 3.824393595967974, 6.724658974579402, 8.203104053224836, 12.889622313635689, 11.016486985342842, 1.2996013781854083, 0.38091794294970377, 2.0334658793040683, 1.097507159624781, 0.22973491251468658, 14.62596845626831, 55.837950774601524, 73.66567693437848, 72.88771493094308, 68.56169700622559, 46.59983784811837, 33.17582436970302, 20.50651901108878, 9.071238909448896, 3.804111804280962, 0.36168796196579933, 0.28539104174290386, 0.06641521118581295, 0.12233667474772249, 0.16977328860333987, 0.0653007309883833, 0.11803644549633775, 0.08489872901035206, 0.07255730338926826, 0.036043060943484306, 0.005153711377975664, 0.03573783553604569, 0.074260724841484, 0.0189892961311021, 0.07725626695901155, 0.14343535474368505, 0.01368993763545794, 0.07215965472693954, 0.08258567098528147, 0.036859630340976376, 0.17166731054229395, 0.23077670804091863, 0.04974557692185044, 0.44593652550663265, 6.24454757145473, 0.6305183523467609, 0.3643018145646368, 0.8173062322395188, 0.4641926458903721, 0.6274739557078907, 0.0994709674268961, 34.32405240195138, 29.511302743639263, 19.296707357679093, 70.32435771397182, 71.73920549665178, 29.19737270900181, 12.357190540858678, 33.299488408224924, 28.56926597867693, 14.657283987317767, 0.4677685797214508, 0.06614557494010244, 0.025947252055630088, 0.015188310894050767, 0.10181483772716352, 0.09177146772188799, 0.09523197596094438, 0.009413306983853025, 0.0888893563034279, 0.027442624493102943, 0.020491742296144366, 0.03310858019228492, 0.017213910951146057, 0.019592997218881334, 0.030041042116603682, 0.01084002694447658, 0.03204917668231896, 0.01184725620052112, 0.017651045262547474, 0.036862731246011596, 0.14365453512540885, 0.017948723664241176, 0.049789953112070046, 0.026349772599392703, 0.033408133046967645, 0.08299966555620943, 0.029348447852368866, 0.017170708626508713, 0.025271716161764095, 0.04722311620467475, 0.04889568127691746, 0.023190744254472, 0.01714049855114094, 0.14457153449101107, 0.05677188167880688, 0.01706209043706102, 0.03214127424040011, 0.05219328004334654, 0.050907059240021875, 0.05092163077954735, 0.07341607766492025, 0.08287287450262479, 0.06498138526720659, 0.009293217311746307, 0.05665704980492592, 0.004641740167114351, 0.02791145656790052, 0.036861553987754245, 0.045262886211276054, 0.11463570940707411, 0.0833446734717914, 0.03850628894620708, 0.10865337827375957, 0.027959003212994764, 0.03375944455287286, 0.04134791896545461, 0.05824310505496604, 0.058175237982400825, 0.04704098044229405, 0.036194777980979, 0.044296564135168276, 0.07368513715586492, 0.06736659870616027, 0.05917391939354794, 0.03168092554967318, 0.087542654281216, 0.08766797969916038, 0.13175544648298196, 0.07060488672660929, 0.17788670824042388, 0.8130168595484325, 39.72877468381609, 81.10375131879533, 59.03370176042829, 48.54757424763271, 46.95265000207083, 82.63102095467704, 72.69267204829625, 28.305206639426096, 59.75222192491804, 69.50465093340192, 3.5532438371862685, 0.3078038676508835, 0.079283946725939, 0.4368761016854218, 0.4119360042469842, 0.2505089406456266, 0.12361645964639527, 1.9431514569691248, 2.1015128450734273, 6.396742216178349, 6.442204279558999, 5.221056640148163, 5.705631826605115, 2.426715680531093, 0.6129355558327266, 0.2907921262085438, 0.25168994441628456, 0.618206470140389, 2.069143359150205, 2.5821175702980588, 1.155693871634347, 0.0638917258807591, 0.012962863614250506, 0.08288067086998906, 0.014778172098366278, 0.0606671306969864, 0.11643043453139917, 0.04046739424977984, 0.1276005051497902, 0.15285559211458477, 0.08310634483184133, 0.4640842431357929, 0.43018075238381115, 2.212526168142046, 4.930965440613883, 8.413020423480443, 8.966007573263985, 15.206596408571516, 13.67819161074502, 0.8464941488845008, 0.2259497863373586, 1.2324160976069314, 1.7060358205011912, 0.6851259821227619, 17.58611297607422, 66.16710458483014, 79.44821098872593, 78.76955263955253, 72.80742154802594, 52.604505811418804, 37.95031377247402, 26.4073200907026, 13.842200364385333, 6.479639870779855, 3.0677067594868794, 1.474160211426871, 0.214260907843709, 0.341578871011734, 0.2712017074227333, 0.10002604978425161, 0.18374934579644883, 0.06733377118195806, 0.04156877872134958, 0.02649457536504737, 0.03473878093063831, 0.018756251582609754, 0.04368745003427778, 0.01983480335080198, 0.010988240196768726, 0.07106985963348832, 0.11620775290897914, 0.01893413462676108, 0.17872887876416954, 0.03698656049423984, 0.2688100886132036, 0.14161914720066957, 0.03533057542517781, 0.678224249609879, 1.8237477498395103, 0.25281069427728653, 0.48721989882843836, 1.0108977556228638, 0.0866771082260779, 0.5871036733899797, 0.48174987520490375, 33.127478803907124, 61.600248200552805, 21.69748888696943, 35.18321452822004, 83.25553894042969, 48.50697244916643, 19.515808377947124, 34.910115582602366, 48.5875437600272, 28.613395724977764, 1.099584236741066, 0.060456873050757816, 0.044073061485375674, 0.02717590255529753, 0.13930266935910496, 0.04317909159830638, 0.05991101198430572, 0.05357383078496371, 0.09219915512949228, 0.08367224303739411, 0.07438482889639479, 0.07342272730810301, 0.04036491171323827, 0.03476520986961467, 0.0265338693279773, 0.0709643881501896, 0.05648391820224268, 0.007542286533862352, 0.04390410626573222, 0.04974590940400958, 0.05491122669939484, 0.06371658920709576, 0.03726454950602991, 0.05823023324566228, 0.04229525223906551, 0.035003311200333495, 0.0233025464694947, 0.0356619210381593, 0.0437930640099304, 0.036668025622410436, 0.08524404226669244, 0.0294656037086887, 0.043702092819980214, 0.19118144842130796, 0.17633706996483461, 0.12330620629446847, 0.14624461185719284, 0.14413883270961897, 0.14785246843738215, 0.14643323102167674, 0.11889838853052684, 0.19188842762793812, 0.0890515126021845, 0.08646952400782279, 0.11584502165871007, 0.09916037480745997, 0.09904427068041903, 0.07639739090310675, 0.11678283847868443, 0.22291630054158823, 0.19295108132064342, 0.17767455748149327, 0.19499273890895502, 0.16593316037740025, 0.18670865414398058, 0.11375057404594761, 0.15573681465217046, 0.1461002060345241, 0.22182892103280338, 0.09235717914998531, 0.17899495948638233, 0.13160527311265469, 0.12058054469525814, 0.17368918204946177, 0.10086063428648881, 0.24524068619523728, 0.1883340576397521, 0.20573689309614046, 0.1446472725697926, 0.4797867919717516, 0.6749638617038727, 46.26937804903303, 108.35373851231166, 80.41376045772007, 72.69044167654855, 54.25668321337019, 85.82218960353306, 113.5748928615025, 56.63256761005947, 44.200979232788086, 77.2932688849313, 17.842187098094396, 1.1599052399396896, 0.36196502138461384, 0.42363161380801884, 1.8386377394199371, 1.744512447289058, 2.0429041385650635, 4.306185160364423, 11.506365384374346, 17.019985914230347, 13.631183573177882, 16.232381548200333, 13.809232899120875, 3.3377912725721086, 1.3544773821319853, 0.8341926889760154, 1.930532442671912, 0.31142615899443626, 1.6407113543578555, 2.1795044200760976, 3.1551268228462765, 0.11624660582414695, 0.26318212917872835, 0.15011521987617016, 0.14699930564633437, 0.15215371549129486, 0.27272238582372665, 0.16679614835551806, 0.3470634695674692, 0.3161539467317717, 0.6194719108087676, 1.763150012918881, 1.7993419851575578, 3.2546486939702715, 5.734430806977408, 9.024017214775085, 11.042586156300136, 16.080575568335398, 16.2585015637534, 2.251097789832524, 2.0056782960891724, 1.9058457102094377, 3.419457793235779, 1.37234000648771, 22.758737632206508, 68.85694680895124, 79.1493342263358, 79.08502864837646, 76.84895242963518, 54.64772088187081, 37.019929136548726, 25.74244523048401, 12.137969664164952, 4.577330793653216, 2.321895156587873, 1.0916755582605089, 0.21379179587321623, 0.39296191238931244, 0.6915197904620851, 0.32227886521390503, 0.24702241058860505, 0.3268212771841458, 0.20627498493662902, 0.23730717333299772, 0.25562004638569696, 0.09950213254030262, 0.1418458457504, 0.08650085196963378, 0.18042957250561031, 0.21601363165037973, 0.10295678502214806, 0.21107164397835732, 0.2988139029060091, 0.15403863149029867, 0.3480263107589313, 0.34025274217128754, 0.06804224995097943, 1.6950820939881461, 16.14344460623605, 1.8230299140725816, 1.8378480332238334, 4.959212039198194, 0.5269860135657447, 2.012880972453526, 0.2843343455876623, 50.2388630594526, 45.403441429138184, 27.52195531981332, 90.0170533316476, 96.20268017905099, 49.96601077488491, 31.173756531306676, 56.53361483982631, 66.6641926084246, 52.151007311684744, 1.190616711974144, 0.11717690447611467, 0.1849764763776745, 0.07833397055843047, 0.16142835281789303, 0.2157669977418014, 0.16423082458121435, 0.21471406067056314, 0.19254383817315102, 0.15187957377306052, 0.11559822490172726, 0.1823518215013402, 0.121241994202137, 0.11792129810367312, 0.12631466771875108, 0.1660039722919464, 0.17344642936119012, 0.07076704981071608, 0.09806964333568301, 0.11226980707475118, 0.30430675244757105, 0.1436640481863703, 0.13615053492997373, 0.15802684319870813, 0.07376407113458429, 0.14668770879507065, 0.09725084834332977, 0.1565514909369605, 0.07731561163174254, 0.2467138400035245, 0.12995472310909204, 0.11640854499169759, 0.12803469970822334], [0.038002232422253916, 0.028570039264325584, 0.06468442441629511, 0.024701419352952923, 0.021850971771138053, 0.05024544349206345, 0.03467011997210128, 0.0132620899239555, 0.07223628847194569, 0.03354704952133553, 0.016524782304518988, 0.07116481382399797, 0.04819081909954548, 0.07131131631987435, 0.023136597159983854, 0.03224628771256123, 0.04861716300781284, 0.08839041593351535, 0.03664136937420283, 0.07101423333265952, 0.10654736842427935, 0.11457472267959799, 0.03008483476670725, 0.043885521191571436, 0.016916595565687333, 0.025354319318596805, 0.06575479305216245, 0.03175940830260515, 0.07392739451357297, 0.0638177248516253, 0.0711949204227754, 0.04250014606597168, 0.05211744696966239, 0.0812619034466999, 0.039133418151842694, 0.04139234943847571, 0.09544300035174404, 0.08897863115583148, 0.33776968398264473, 34.25904853003365, 53.853090150015696, 47.83341755185808, 40.75715323856899, 49.10654987607683, 61.987401826041086, 89.13793250492641, 48.03099305289132, 23.69260331562587, 49.92267486027309, 19.677116019385203, 0.7498716307537896, 0.11634299850889615, 0.08770189287939242, 0.4303833357989788, 0.5450879707932472, 0.43281569385102814, 0.5989456293838364, 0.2809278555214405, 4.05579423052924, 1.966871738433838, 1.7522235363721848, 2.5379519973482405, 1.3608016542025974, 0.11838156197752271, 0.016453062849385396, 0.5189795717597008, 2.611530597720827, 1.984558377947126, 0.9489498968635286, 0.273155969700643, 0.03599339557279434, 0.025085139387686337, 0.04673554468899965, 0.036130961762475114, 0.047052753024867604, 0.061822302639484406, 0.0359938637619572, 0.02874671621248126, 0.025299215489732366, 0.043945164419710636, 0.07849708359156336, 0.15959723107516766, 0.21378834891532147, 0.9164136541741235, 0.6507380987916673, 0.4545786732009479, 0.7663650800074849, 0.6392007235969815, 0.5956743849175317, 0.48665796326739447, 0.23255981664572442, 0.3931322246789932, 1.6903851117406572, 15.519383464540754, 33.98849262510027, 32.432922976357595, 24.70549954686846, 13.215928827013288, 7.04238315990993, 3.422680671725954, 0.4059611234281744, 0.488214305468968, 0.3451204166880676, 0.12082255099500928, 0.14234798880560057, 0.08373301263366427, 0.08195315421159778, 0.03638956842145749, 0.025975350190752318, 0.021676206595397422, 0.062347420890416415, 0.09430253904845033, 0.027049323543906212, 0.11005672439932823, 0.03454000409692526, 0.02389842235217137, 0.026124320857759033, 0.05006692771400724, 0.11315063373850924, 0.07248792996896164, 0.047714775893837214, 0.09009762361113514, 0.25257187709212303, 0.08450188101934535, 0.26203269085713793, 1.901321130139487, 3.0995896543775285, 0.552951703114169, 0.11680881279919829, 0.04701963033793228, 1.4886189784322466, 2.0878318420478275, 39.14691516331264, 19.588295459747314, 18.8465005670275, 79.28182247706822, 73.27884292602539, 22.923079899379186, 14.422359313283648, 30.340928077697754, 23.3275397505079, 8.304460031645638, 1.3757403897387641, 0.02480818683813725, 0.20852081371205194, 0.02796452139903392, 0.051364418983991654, 0.11483100535614149, 0.07601387612521648, 0.034152808266558816, 0.015266569730426584, 0.0252183968799987, 0.04730270496968712, 0.026321794904236282, 0.04061720799654722, 0.0060041494268391815, 0.0593299213796854, 0.10442223745797362, 0.11313618772796222, 0.11800866627267428, 0.05494897360248225, 0.012718165226812874, 0.04697859932535461, 0.04308150808459946, 0.05534549928935511, 0.027065216530380503, 0.023929227842018008, 0.02015790476330689, 0.03629484154017908, 0.07850908009069306, 0.06917021942457982, 0.022995190462097526, 0.008550760901666113, 0.019006222187142287, 0.02509492725533034, 0.012566697550937533, 0.03863150919122355, 0.035715260675975254, 0.044788145792803595, 0.07238515905503716, 0.026648395861099874, 0.07422390753137213, 0.02197187822977347, 0.008733444581074374, 0.07594381738454103, 0.11701039198253836, 0.0728184918739966, 0.039870704125080786, 0.05161025222124798, 0.028537466190755367, 0.023166788575638617, 0.02985161210277251, 0.07469996091510568, 0.02687166441631104, 0.03926434148369091, 0.03912181181034871, 0.009702802253221827, 0.07977707883609192, 0.0525506440816181, 0.09421718612845455, 0.08731132812265839, 0.07487209167863641, 0.031024921286318983, 0.06465188866215092, 0.048091508714216094, 0.053398873923080306, 0.03329013580722468, 0.006932932825293392, 0.040974039384829145, 0.09075445229453699, 0.039532712261591635, 0.11583592928946018, 0.03236461064911314, 0.05861143421913896, 1.6464684797184808, 61.313211168561665, 77.4778060913086, 59.83047948564802, 49.743539878300254, 62.751759256635395, 95.99888951437813, 77.62529550279889, 32.13122871943882, 52.99330963407244, 78.26612091064453, 10.084331427301679, 0.4463419908923762, 0.22216347950909818, 0.0638647134016667, 0.26845692470669746, 0.46855644030230387, 0.6774158701300621, 0.10266236189220633, 1.5472610145807266, 3.927516153880528, 2.4283235371112823, 2.564541667699814, 2.2799480131694247, 1.3982177036149162, 0.10155322176537343, 0.10556661390832492, 2.6232856469494954, 2.7133156274046217, 1.570623789514814, 0.3288810652281557, 0.08314498740115336, 0.15551280310111387, 0.036157434806227684, 0.0324008274557335, 0.07461308129131794, 0.05367206908496363, 0.0075769919037286726, 0.03021435353106686, 0.03948575085295098, 0.045085798749434094, 0.12860343419015408, 0.08778257069310971, 0.15170550239937647, 0.33608048462441986, 1.1942788468939918, 1.1121258437633514, 0.5893569524799074, 0.42994627782276695, 1.275905198284558, 1.1332342539514815, 0.30331169441342354, 0.4809056690761021, 0.472339463021074, 0.13612838754696505, 17.816122668130056, 36.283739703042166, 34.62657349450247, 28.378145354134695, 16.169950246810913, 11.26920599596841, 5.081105155604226, 0.6920295059680939, 0.5563128941825458, 0.24667350788201603, 0.3136003209011895, 0.26094529777765274, 0.1049362209492496, 0.06253097818366118, 0.03148048969783953, 0.020373904512130787, 0.026233878818207552, 0.06518322907920394, 0.05371657419683678, 0.06909159078661885, 0.11383369458573205, 0.025598556302221756, 0.016404903826436827, 0.016419156454503536, 0.04189908617575254, 0.034348955777074607, 0.0834255480606641, 0.025616218568757176, 0.059563066012093, 0.510718217917851, 0.38899351390344755, 0.16846219609890664, 1.4949267485312052, 0.4811544471553394, 0.2700847844992365, 0.6292436836021287, 0.11023527410413538, 1.0975180161850793, 1.8426703001771654, 51.32363666806902, 49.25930602209908, 15.5964754649571, 44.58382844924927, 87.10003975459507, 44.81647498267037, 22.21840923173087, 35.21238306590489, 46.64575154440743, 28.698057787758962, 2.1343539399760108, 0.050468701869249344, 0.08607017222259726, 0.033850527701101134, 0.11232326884887048, 0.10987051403416054, 0.08014899066516332, 0.03265950536089284, 0.05162684579512902, 0.0084134118431913, 0.04937014688870736, 0.018046242717121328, 0.01564135854797704, 0.03949616636548724, 0.053607252027307234, 0.08899392533515181, 0.05588435108906456, 0.01649824988895229, 0.01869302399323455, 0.03165123964260731, 0.06872896131660257, 0.044165233682308874, 0.021498013121475066, 0.023242387554741333, 0.06932394831840481, 0.07580593228340149, 0.01772908866405487, 0.08372485664274011, 0.09047515371016093, 0.020131614924009358, 0.06620884154524122, 0.01799695223702916, 0.012913197395391762, 0.030903853675616638, 0.09914196615240403, 0.16765372162418707, 0.1922753011541707, 0.23386040542806896, 0.08437295258045197, 0.13479193140353474, 0.08255956095776387, 0.10115709302148648, 0.1373853058155094, 0.23683366445558413, 0.13920048198529653, 0.1323272343724966, 0.15567304593111786, 0.13192597590386868, 0.1894027774355241, 0.19464634678193501, 0.20550775182034287, 0.11225887587560074, 0.1565274436558996, 0.10305253309862954, 0.14833785167762212, 0.19064962624439172, 0.18546848211969647, 0.1952254899910518, 0.17354962096682616, 0.12073959330362932, 0.16062198180173123, 0.10467443535370485, 0.13078275296304906, 0.1705304929720504, 0.1690379466329302, 0.14229570089706353, 0.13232502234833582, 0.19949332598064626, 0.17159682432455675, 0.1870164240577391, 0.17586505386446202, 0.2504784065697874, 1.6869365253618784, 74.32630470820835, 100.31273419516427, 79.13707065582275, 72.08756732940674, 71.73715577806745, 91.15519605364118, 115.38179274967739, 68.8081635066441, 38.23890025275094, 80.66610513414655, 31.941991056714738, 0.544037435735975, 1.0315048098564148, 0.20135422183998994, 1.5211578266961234, 0.9857034789664405, 1.245056716459138, 1.4851535643850053, 5.743000541414533, 12.201756732804434, 8.698240501540047, 12.544322030884878, 10.665776661464147, 6.82709322656904, 1.1295320583241326, 0.1368614767811128, 1.844089686870575, 6.026328103882926, 8.84890958241054, 6.189009317329951, 0.5846296261463846, 0.2910348246140139, 0.11991971944059644, 0.09916182008704968, 0.3191627338528633, 0.1248229763337544, 0.12664290224867208, 0.15365730838051864, 0.08945517987012863, 0.18131906406155654, 0.23037034698895045, 0.2502796229507242, 0.2841821094708783, 0.5584653158273015, 1.7258532771042414, 2.190932252577373, 1.0924598361764635, 1.6748211468969072, 1.835279371057238, 2.501729301043919, 0.7088158109358379, 0.46109315220798763, 0.7915226072072983, 3.182844706944057, 21.637713534491404, 39.3856656891959, 38.3176337650844, 29.552620206560405, 16.882371629987443, 11.579712305750165, 5.665297533784594, 2.1485126316547394, 1.4113329712833678, 0.8610605586852346, 0.7800566138965743, 0.36808746999927927, 0.1967052798718214, 0.12968211487999984, 0.29196251769151005, 0.08360261855913059, 0.13668716113482202, 0.15244879680020468, 0.1346912368067673, 0.13769777119159698, 0.17829646196748528, 0.06917517273021595, 0.11393263856215136, 0.09459526584084545, 0.16242060171706335, 0.20645304609622273, 0.20493684602635248, 0.08605235389300755, 0.18822448780494078, 1.7016236058303287, 1.7597413786820002, 1.546323333467756, 3.187049452747617, 5.696757239954812, 2.167963896478925, 2.3871343987328664, 0.2755567894450256, 2.7616985397679463, 3.943934747150966, 57.45111404146467, 33.64187479019165, 27.098733595439366, 96.02345834459577, 98.37981482914516, 43.87610578536987, 32.5597380229405, 57.55718524115426, 66.70273426600865, 54.21932274954659, 3.101002527134759, 0.20223474316298962, 0.3475327172449657, 0.14747392732117856, 0.1887890967939581, 0.22515501827001572, 0.13711094696606907, 0.14294402753668173, 0.20003443051661762, 0.16569309468780244, 0.16632327730102198, 0.10169883538037539, 0.18096186965703964, 0.10705654788762331, 0.12773991695472173, 0.23221360093780927, 0.18734203944248812, 0.1281942097204072, 0.17777960827308043, 0.08579212214265551, 0.13358845455305918, 0.1106673584186605, 0.13868541962334088, 0.0939518314387117, 0.16678255051374435, 0.23644052126577922, 0.11670511907764844, 0.18586355234895433, 0.23139718760337147, 0.16548732215804712, 0.11438246656741415, 0.08563757222145796, 0.13819038761513575, 0.10641034506261349], [0.016530392092785666, 0.04333912068977952, 0.025721399978335415, 0.01640069012397102, 0.051916654886943955, 0.09031782179538693, 0.010475759660559041, 0.013267810822331479, 0.02968882137377347, 0.007143528466778142, 0.07519978338054248, 0.05120013887062669, 0.020239055855199695, 0.027113345019253235, 0.04735828377306461, 0.06177484590028014, 0.004246641100118203, 0.02013128244185022, 0.029530437729720558, 0.10187514591962099, 0.06389109484319176, 0.01813564818751599, 0.06173266816352095, 0.07805830892175436, 0.05573885282501578, 0.033782114407845905, 0.05715411063283682, 0.047778381766485314, 0.09794179376746927, 0.04071029960843069, 0.04156238692147391, 0.09560120079134192, 0.03997172781133226, 0.01781803951598704, 0.05171052612630384, 0.04224414498146091, 0.03776955597900918, 0.030608670586454015, 0.05919370547469173, 1.251103169151715, 30.208655221121653, 57.80063622338431, 53.45133488518851, 43.250281538282124, 14.389228565352303, 51.53510856628418, 91.65548719678605, 53.34659079142979, 21.918733426502772, 46.15866545268467, 43.44062396458217, 0.29319845565727776, 0.9926927153553281, 0.13555255558873924, 0.0803415249767048, 1.752682443175997, 0.6234497002192906, 2.0075714630740027, 3.6624098079545155, 2.412769777434213, 2.687996174607958, 0.9715623749153954, 0.8380713037082127, 0.6730955019593239, 0.6480258043323244, 5.037016664232526, 1.8551099640982491, 0.7357191815972328, 0.09283167868852615, 0.031339462979563644, 0.08039812836796045, 0.04412223491817713, 0.05447437567636371, 0.04940851804401193, 0.017289579480088184, 0.05205369860466037, 0.10894212206559521, 0.05204093196828451, 0.042035020488713465, 0.12831874803772994, 0.05069402638556702, 0.018211287878719822, 0.08373618817755155, 0.16309954385672296, 0.16053853556513786, 0.3431955485471657, 0.25950930054698673, 0.25828858890703743, 0.03409303950944117, 0.09191531036049128, 0.06973649760974304, 0.2915573780025755, 1.327986289347921, 0.8343196564487049, 0.49789814012391226, 0.6256426711167608, 0.2482418194413185, 0.43945852454219547, 1.0710650299276625, 0.8601633725421769, 0.34455758546079907, 0.6188533582857677, 0.1973834756229605, 0.1491746346333197, 0.06442390768123524, 0.07913009569581066, 0.08184173197618552, 0.08290556631982327, 0.05660051087449704, 0.08577036152460746, 0.08143026155552693, 0.04347978778449552, 0.04228574935612934, 0.03423509081559522, 0.05647342465817928, 0.10045767269496407, 0.08160083168851477, 0.054526039332683594, 0.037229601559894424, 0.07646848780236074, 0.0488946057989129, 0.05507509969174862, 0.029774540702679327, 0.0806409896218351, 0.1476512285215514, 0.3726254307797977, 0.5414810414825166, 0.10817800342504467, 0.2077985538968018, 0.662968068250588, 9.60118235860552, 38.75594350269863, 14.470154234341212, 31.698689460754395, 85.49848692757743, 68.22538334982735, 22.015726804733276, 25.105201619012014, 35.487385817936485, 13.094509056636266, 4.269230297633579, 1.502168508512633, 0.15683344937860966, 0.03744113824463316, 0.07512413351131336, 0.09347673478935446, 0.10376027226448059, 0.06177606047796352, 0.046798404173127243, 0.03162208638553109, 0.06250226258167199, 0.056844603669430525, 0.04121680225112608, 0.009059526458648699, 0.021682561075847064, 0.011678694531188479, 0.028237107575738003, 0.054216712181057246, 0.026916826010814736, 0.017315024543287497, 0.02262693254410156, 0.04134770183424864, 0.06907011515327863, 0.05199838103726506, 0.022571085719391704, 0.046793074280555756, 0.11325308574097497, 0.03124856303579041, 0.024744212860241532, 0.028148723300546408, 0.04553493804165295, 0.048049198663128276, 0.05288510077766009, 0.029229962067412477, 0.04050354320289833, 0.029567261825182607, 0.030462866981646845, 0.025769528467208147, 0.04260259806843741, 0.042800815110760074, 0.015697692221562778, 0.021178798018289462, 0.030756523367017508, 0.04459874631304826, 0.007419264742306301, 0.026799129022817527, 0.07337391349886145, 0.011803535644763281, 0.08116770921541111, 0.01404278856768672, 0.029427303799561093, 0.08002410629498106, 0.02141565762992416, 0.03387974202632904, 0.08098471510623183, 0.05322692636400461, 0.06853639986366034, 0.015141800711197513, 0.019612198063571538, 0.008940836265017944, 0.01234947728724884, 0.040951203288776536, 0.027115171974790946, 0.06111682978059564, 0.007421267268780086, 0.05724656102912767, 0.0625790659604328, 0.061322283398892195, 0.06388658937066793, 0.038954634352454116, 0.13390653819910117, 0.11525278272373335, 0.029281812320862497, 0.1537673803312438, 0.07081199597035136, 3.638366435255323, 52.9034173148019, 72.87921033586774, 61.50052070617676, 63.2338878086635, 40.39094148363386, 89.30684321267265, 78.76040881020683, 28.39313609259469, 43.117734227861675, 80.12484046391079, 21.895880801337107, 1.1853651766266142, 0.49179159637008396, 0.24893967913729803, 0.1380638951169593, 0.6054185277649334, 0.6006327388542039, 1.1482906746012824, 0.9048020743897983, 3.396790380988802, 2.506760231086186, 1.092136419245175, 0.27506118746740477, 1.060218674795968, 1.074996298977307, 1.6744159800665719, 1.2699297474963325, 0.5479838496872357, 0.0956612986379436, 0.006700400994824511, 0.101836286219103, 0.03660281840711832, 0.0379067014769784, 0.04437884668420468, 0.08510368051273481, 0.021758212641413723, 0.03141154036191957, 0.03613033751025796, 0.10942053675119366, 0.027952762387160743, 0.020070112509919063, 0.05800535995513201, 0.010078483344321805, 0.1335700119712523, 0.30261893730078426, 0.19920718776328222, 0.09990679725472416, 0.12283927920673575, 0.01174840806717319, 0.05071989553315299, 0.15018998086452484, 0.9168734295027596, 2.381240589278085, 1.6520609110593796, 0.5695831935320581, 1.792415282555989, 0.7741764837077686, 1.1731617514576231, 1.4542969401393617, 1.1811127705233437, 0.6728211023977825, 0.8636492512055806, 0.22599078342318535, 0.2709812649658748, 0.023125859343313744, 0.0686247790498393, 0.08861267007887363, 0.13345327680664404, 0.033429832596864016, 0.08102506079844066, 0.057476340127842765, 0.057284925399082046, 0.06415033593241658, 0.05734221411070653, 0.055844833209578476, 0.003167237134350996, 0.068039651161858, 0.027968249948961393, 0.07047537474759988, 0.033792404391403706, 0.023298005373882394, 0.06384690864277737, 0.07505972018199307, 1.0361213449920927, 0.2284821740218571, 0.24937934268798145, 0.23233128605144365, 0.11973491364291736, 0.1515887129519667, 1.0767578844513213, 5.043724715709686, 57.85666649682181, 34.07613720212664, 17.273353712899343, 55.217084067208425, 89.19254534585136, 42.890354428972515, 29.677819796970912, 40.04899978637695, 42.13790621076311, 21.4009119783129, 2.9409110375813077, 0.04040991554835013, 0.11698653469128267, 0.058127082352127345, 0.11813766935041972, 0.06788147786366087, 0.1348025979740279, 0.0992010258404272, 0.042696822833802016, 0.07059431515101876, 0.06295103885765586, 0.015731920920578495, 0.06396774215889828, 0.020726537464984825, 0.038198661524802446, 0.03535382203491671, 0.020342603691720536, 0.02207845063613994, 0.04406228634927954, 0.03477947946105685, 0.03439994429105094, 0.026035734718399386, 0.020113727044580237, 0.06375147269240447, 0.06972393792654787, 0.07737369422933885, 0.014433686654748661, 0.01446708754104163, 0.028912594275815145, 0.022454747497769337, 0.011712329512062882, 0.11409419775009155, 0.02041657588311604, 0.011245348989697439, 0.03813771211675235, 0.16518187283405236, 0.11928599487457957, 0.1793948880263737, 0.13101759393300327, 0.09716782958379813, 0.13294019576694283, 0.07443005325538771, 0.22530251821236952, 0.12943826296499797, 0.05919103883206844, 0.14879046167646134, 0.10835392041397945, 0.14751584721463068, 0.07118295106504645, 0.10969189647585154, 0.1380730824811118, 0.07661043732826199, 0.15893104539385863, 0.14955199509859085, 0.1997598816773721, 0.1504401160137994, 0.06672198365309409, 0.10538494294243199, 0.21309423473264488, 0.14484625974936144, 0.33605907005923136, 0.19863572557057652, 0.15172839617090567, 0.22996431163379125, 0.1571920279945646, 0.22876612735646112, 0.19389971398881503, 0.13136169261166028, 0.0900636018653001, 0.1247441577059882, 0.17860231841249125, 0.19885812220828875, 0.16823765529053553, 0.1287573937858854, 3.0146162254469733, 67.44487135750907, 96.55239691053117, 82.03510870252336, 74.39691925048828, 32.76361206599644, 79.7870259966169, 119.28300476074219, 71.68865040370396, 34.144906997680664, 70.9542258126395, 66.86446053641183, 1.1926389634609222, 1.7297647872141428, 0.5787749545914787, 0.0933490955669965, 3.969821563788823, 1.0675724744796753, 4.733564078807831, 9.127405541283743, 6.281752569334848, 9.745119503566197, 10.950618931225367, 3.6266487325940813, 2.0420753487518857, 6.564166009426117, 12.12988977772849, 3.145831218787602, 1.425084324819701, 0.3273492859942572, 0.10819775557943753, 0.31702100592000143, 0.12133156082459859, 0.15835294712867054, 0.1585819526974644, 0.1399673351219722, 0.16686438183699334, 0.10415098629891872, 0.08280611344213996, 0.15253190376928874, 0.27143140509724617, 0.07433675469032355, 0.11831992385642869, 0.21494879307491438, 0.32445758687598364, 0.5210822160754884, 0.42351979123694555, 0.498708039522171, 0.20416894794574805, 0.14029964086200508, 0.22671145546649182, 0.22120138470615658, 1.5195449760981967, 4.241187368120466, 2.9032570123672485, 1.2186999193259647, 2.1716101808207373, 1.3265895928655351, 1.597997520651136, 2.2239268592425754, 1.3625190534761973, 1.2056800808225359, 1.1306840479373932, 0.669861549777644, 0.3695838025638035, 0.22108429670333862, 0.20290020959717886, 0.25314684052552494, 0.37321437203458374, 0.1396479486886944, 0.26879659933703287, 0.11331154153283153, 0.16181878186762333, 0.056226970561380894, 0.15262489020824432, 0.16774243329252514, 0.19762989240033285, 0.24126908502408437, 0.1991101572556155, 0.11381354888102838, 0.16877037313367638, 0.13705156158123696, 0.08202410183314766, 0.46058283959116253, 2.5701223739555905, 0.4017772493617875, 1.2006058331046785, 0.8871518043535096, 0.16889174947781221, 0.24896519205399922, 1.4945166962487357, 13.097449013165065, 54.276429993765696, 22.493125370570592, 42.456286566598074, 103.19987746647426, 93.30840110778809, 43.59618370873587, 46.94693858282906, 67.36569663456508, 62.90182644980294, 43.4605826650347, 2.953761948006494, 0.16804630841527665, 0.19881685370845453, 0.13223770846213612, 0.2041204869747162, 0.19428939665002481, 0.43953954162342207, 0.25124178560716764, 0.112903056666255, 0.24181373151285307, 0.14149872080555984, 0.1265867059784276, 0.10286536599908556, 0.08828689184572015, 0.05156382006992187, 0.10623988349522863, 0.09453740037445511, 0.09971637318709067, 0.10938330553472042, 0.1712117964135749, 0.11415206321648189, 0.12566650392753737, 0.1333095630896943, 0.14942086142088684, 0.11941845848092011, 0.2925835943647793, 0.1602077768849475, 0.08936707888330732, 0.08921714978558676, 0.12784935108252934, 0.12409794809562819, 0.1732597779482603, 0.10809803807309695, 0.08420852997473308, 0.07169559105698552], [0.024705203882019435, 0.032289571461400816, 0.00997067685239017, 0.02790404696549688, 0.04244048926713211, 0.030930119766188518, 0.03238380301211562, 0.03979487783674683, 0.05943428006555353, 0.006344503440362002, 0.00864945721280362, 0.039516176363187175, 0.05286502292645829, 0.014420119347050786, 0.01100359798874706, 0.014574146796283978, 0.07664269488304853, 0.05479225915457521, 0.03059859773410218, 0.00625322139655639, 0.004694403390333588, 0.005189027429358768, 0.0649661725120885, 0.019223667215555906, 0.014574111173195499, 0.034074081241020134, 0.07333896216005087, 0.025417248352563808, 0.05418447158964617, 0.04939304066023656, 0.04837684965293322, 0.013654319635991539, 0.0535792047823114, 0.05571046631251063, 0.01549628097563982, 0.02693442890553602, 0.03841502937887396, 0.032928354505981715, 0.050134866032749414, 0.12342299574187823, 1.5513030205454146, 46.22021606990269, 81.35548455374581, 47.52747447150094, 45.22593927383423, 18.583547728402273, 49.002816745213096, 99.82358796255929, 64.62831483568463, 14.741612536566597, 29.125806263514928, 51.05828148978097, 9.393752574920654, 0.8915673845580646, 0.8738317819578307, 0.4062700468514647, 0.1447911084230457, 1.1988888680934906, 1.534894849572863, 0.519508666225842, 0.2531016229518822, 1.654442080429622, 0.7199109984295708, 0.2765275559255055, 0.039785229068781645, 0.04807868100968855, 0.21469618805817195, 0.10023170017770358, 0.07148487879229443, 0.02758512532870684, 0.017538469517603517, 0.05541628406250051, 0.05614274061684098, 0.08428719932479517, 0.037569839374295304, 0.04601999219240887, 0.031151688591177975, 0.044815928409142156, 0.05213973684502499, 0.03189273025574429, 0.08922185203326599, 0.05784926975944212, 0.04589934866609318, 0.03502144165603178, 0.03393801461373057, 0.04646293306723237, 0.044591584375926425, 0.05113141345126288, 0.002516138891223818, 0.05853054605956588, 0.003006487311462739, 0.8993630462459156, 0.7408309930137226, 0.07982503769121, 0.4029554847095694, 0.3485630048172814, 0.5123970221195902, 1.071162413273539, 0.5039970842855317, 0.062397897110453675, 0.03978614169838173, 0.06393540996525969, 0.011556294447343265, 0.028098501531141143, 0.06364032187099967, 0.037616610793130736, 0.047369700124753375, 0.05944979816143002, 0.5619857726352555, 0.08227387735886232, 0.029561494277524095, 0.07902089905525957, 0.047356044607503076, 0.19930328189262322, 0.007843662951407688, 0.07026741054973432, 0.03001394821330905, 0.06488804599004132, 0.04229891972084131, 0.03810949863067695, 0.04225083872941988, 0.0200348269926118, 0.02381343244841056, 0.9159670152834484, 0.1268813530249255, 0.23871858045458794, 0.13957431406847068, 0.7529228670256478, 0.318308132567576, 24.303937094552175, 40.227443422589985, 18.483007294791086, 53.81504528863089, 94.78048120226178, 62.72391087668282, 17.189515011651174, 26.674231665475027, 34.64366953713553, 26.016596828188213, 6.316799283027649, 1.1471669120447976, 0.0850374758509653, 0.09058496103222881, 0.10741482116281986, 0.07597736415586301, 0.08529330390904631, 0.032974135263689926, 0.0434542477263936, 0.06559805146285466, 0.004785532763760004, 0.0571809263367738, 0.03626844992062875, 0.012327124647397016, 0.023541770775669386, 0.025763268981661116, 0.026729699623371874, 0.012054144072213342, 0.025551314997885908, 0.049304546123104434, 0.043701665342918465, 0.03486527342881475, 0.047256310137787035, 0.02389315522408911, 0.011493350146338344, 0.10089664413992848, 0.12727509332554682, 0.03573418162497027, 0.09065065000738416, 0.03608495708821075, 0.0396059804729053, 0.030261650814541748, 0.011585857369937003, 0.01714371989614197, 0.057428788393735886, 0.05784342757293156, 0.017878420650959015, 0.04348406934046319, 0.011645781341940165, 0.04882502881810069, 0.013462147492516254, 0.033734111447951624, 0.07034647345010724, 0.08089124012206282, 0.0706852591995682, 0.0428110440261662, 0.014406682657344001, 0.04726969084835478, 0.03306957121406283, 0.06048108996557338, 0.0588895385818822, 0.014274792413094213, 0.042994930408895016, 0.017687112791463733, 0.024644167960754464, 0.05522434686177543, 0.01374379635256316, 0.06088770207549844, 0.042380835860967636, 0.05341310280242136, 0.036264538166246245, 0.06948254909366369, 0.07046917972287961, 0.042908854849104366, 0.05318185806806598, 0.10414038758192744, 0.057550687209836075, 0.04233460048479693, 0.04097367976126926, 0.02814044347698135, 0.0683498095188822, 0.045763926647071324, 0.021100576501339674, 0.08779524572725807, 0.07095279877207109, 0.01372344115017248, 0.14848388598433562, 4.264837299074445, 72.13079902103969, 92.65329020363944, 50.98958117621285, 28.612320491245814, 38.03693349020821, 88.48287023816789, 82.7569501059396, 33.671668665749685, 31.64846440723964, 76.19101360866001, 42.92179502759661, 4.952259497983115, 0.6032215942229543, 0.7184810808726719, 0.13761636056005955, 0.19394699430891446, 0.7913108499986785, 1.755340997661863, 0.8615291278277124, 0.5205096410853522, 0.9423168642180306, 0.0932693744876555, 0.49901745149067467, 0.064762903776552, 0.05135975066306336, 0.3181352418448244, 0.096519177247371, 0.09037786535918713, 0.07049822780702795, 0.00313448382491645, 0.09521025605499744, 0.07675774728081056, 0.08660375180521182, 0.04977323400921055, 0.03423353357772742, 0.09086231900645153, 0.03254038514569402, 0.10198966906006847, 0.0717134704547269, 0.03412209777161479, 0.10315544650490795, 0.05509613427732672, 0.006935823808557221, 0.08544499719781534, 0.02625441468054695, 0.040056412374334674, 0.02591716411656567, 0.05513077688270381, 0.04011417266779712, 0.07067501332078661, 0.9194947459868023, 1.4197973970855986, 0.16027928090521268, 0.5349887641412872, 0.22952896356582642, 1.28884328688894, 1.6348501145839691, 0.6965860586081232, 0.1830573622137308, 0.02705250756948122, 0.09008505714258977, 0.06712119294596569, 0.04018368858045765, 0.05420821013727358, 0.029462322991873537, 0.014885131269693375, 0.4964703395962715, 1.2257471297468459, 0.37712091526814867, 0.14074459698583397, 0.06562205803181444, 0.07442565634846687, 0.13298401555844716, 0.10024830392960991, 0.09474341717681714, 0.07791482590671096, 0.014358167403510638, 0.03822134155780077, 0.0543982202985457, 0.06635336950421333, 0.06967939888792378, 0.10946323017456702, 1.619347706437111, 0.3124898576310703, 0.7126449197530746, 0.15153502726129123, 1.1117266480411803, 0.6262208372354507, 21.640567507062638, 66.5955513545445, 25.386343104498728, 22.681187050683157, 74.74541309901646, 84.15152304513114, 35.524464879717144, 34.57108170645577, 45.94318791798183, 49.6219151360648, 20.064460720334733, 3.5959739557334354, 0.050132715076740296, 0.16719892674258777, 0.025361179307635342, 0.10553318248795611, 0.08672719089580433, 0.04496005942512836, 0.10939758191151278, 0.033027993980795145, 0.022937898357797946, 0.03666769992560148, 0.05282143722953541, 0.014076363328578216, 0.015420254519475358, 0.032353187512074194, 0.056058042483138185, 0.04791437714759793, 0.03828282022316541, 0.03906004137492605, 0.082543228619865, 0.10704810691199132, 0.029649401881865094, 0.037420683806496005, 0.07046776158469063, 0.1330488020820277, 0.05457515848268356, 0.022578495321795344, 0.02310517759594534, 0.055023775302938054, 0.0912037171157343, 0.038142217589276176, 0.050879463220813444, 0.011492692815539027, 0.027719658466854265, 0.02624223497696221, 0.024044368449332457, 0.10037520354879753, 0.1294417642056942, 0.20157781269933495, 0.0948152808206422, 0.09331174221421991, 0.24032171443104744, 0.14469158090651035, 0.20215699662055286, 0.1862608210316726, 0.21329026349953242, 0.10699316593153135, 0.08033512639147894, 0.13880876371903078, 0.1250065064855984, 0.1725364460476807, 0.1581184725676264, 0.15245414365615162, 0.16204207417156014, 0.06814040004142694, 0.07740255910903215, 0.15555336592452867, 0.10100640396454505, 0.1542156477059637, 0.08527375531515904, 0.14226630676005567, 0.1371955331414938, 0.181924575141498, 0.09206838107534818, 0.11609185912779399, 0.21277748101523944, 0.22876398318580218, 0.1468594324375902, 0.12897601776889392, 0.18273478666586535, 0.08872779033013753, 0.08832469303160906, 0.16714002990296908, 0.1494228020310402, 0.134944723919034, 0.23357680493167468, 3.1250137644154683, 78.74670696258545, 118.62742832728794, 75.86924253191266, 70.36969470977783, 34.77036646434239, 76.72200189317975, 125.87041119166783, 85.55035523005894, 23.964257035936626, 52.51969262531826, 76.62298311505998, 16.94209313392639, 0.7090371762003217, 1.7604104684931892, 0.4929780012794903, 0.3202359862625599, 3.2853195624692098, 3.0684567306722914, 1.79804527759552, 1.6586825443165643, 4.866358484540667, 1.1414078325033188, 0.6511814264314515, 0.11346579289862088, 0.2719261385500431, 0.5644986320819173, 0.20942122968179838, 0.16864181788904326, 0.18549662775227002, 0.13297694522355283, 0.22793991597635405, 0.2516128899795668, 0.1953421573021582, 0.10727747210434505, 0.15846675102199825, 0.09527477794992072, 0.13446244836917945, 0.28177322873047417, 0.2448366050209318, 0.11457987954573971, 0.14122219064405986, 0.17000392265617847, 0.10942460796130554, 0.1430128581289734, 0.16375328520578997, 0.25437697023153305, 0.15053497520940645, 0.16340860298701695, 0.20429772032158716, 0.0891347484929221, 2.769753021853311, 1.6003411263227463, 0.5920826547912189, 1.4407457815749305, 1.4895562252828052, 2.686621516942978, 2.202146645103182, 0.8517993156399045, 0.3086652542863573, 0.08827177408550467, 0.14004263893834182, 0.16300878301262856, 0.12341325197901044, 0.1774102138089282, 0.10616431505020175, 0.22680217559848512, 0.7168720300708498, 1.6411649414471217, 0.18048841506242752, 0.14592346123286656, 0.2098214024943965, 0.1803262723343713, 0.4250625627381461, 0.0893817963078618, 0.2453125294830118, 0.14815457936908516, 0.11907453622136797, 0.1624757530433791, 0.1724643720579999, 0.11485373627926622, 0.14447838520365103, 0.18533877336553164, 3.1884453892707825, 0.7707148151738303, 0.8523766675165722, 0.43165740743279457, 2.253007458789008, 0.8715654207127435, 39.02808707101004, 64.42785235813686, 27.67555740901402, 68.89916406358991, 111.92270156315395, 86.90412139892578, 35.803615706307546, 47.78917837142944, 64.80898884364537, 69.14900738852364, 37.18038388660976, 4.184976875782013, 0.10366074474794523, 0.3070687970944813, 0.14926525977041039, 0.22128812862294062, 0.19297381224376814, 0.09693326002785138, 0.17490038062844956, 0.23837296185748919, 0.11098332503544432, 0.16081946263355867, 0.12788680621555873, 0.07644092570990324, 0.09778675530105829, 0.08309406334800379, 0.15718775322394712, 0.1403126958757639, 0.13186972535082273, 0.17192675519202436, 0.2206823868410928, 0.15468414899493965, 0.1543242133089474, 0.1554592666881425, 0.18724473752081394, 0.13341054267116956, 0.2573903985321522, 0.16174433300537722, 0.15951514190861157, 0.21967564443392412, 0.15075708686241082, 0.09947516755866152, 0.1200390737503767, 0.08768735865929297, 0.09000012491430555, 0.09721006838870899, 0.1326267533004284], [0.11007833573967218, 0.03888784954324365, 0.028958917861538272, 0.036322532554290125, 0.017898978565686514, 0.011962854818973159, 0.016424813740221516, 0.01975691601234887, 0.008102789537848105, 0.052673750690051487, 0.0398383685387671, 0.04239572970462697, 0.035454706621489356, 0.027245031702997427, 0.05565372721425124, 0.07094103297484772, 0.020929962263575623, 0.09554009871291262, 0.03684444133458393, 0.040422783964978795, 0.01929446555940168, 0.0618974571781499, 0.03772624169609376, 0.019951129698061516, 0.012189633096568286, 0.05554765522746103, 0.03622636717877217, 0.08750265464186668, 0.02728482099649097, 0.045753775763192346, 0.01843269894431744, 0.07922486668186528, 0.050124297849833965, 0.03399483174351709, 0.050289426131972244, 0.027222526392766407, 0.11914080195128918, 0.0819252799930317, 0.06646477138357502, 0.04930273104192955, 0.05341210874861904, 2.9868738055229187, 29.37344353539603, 60.8285812650408, 55.5550513948713, 46.034935406276155, 20.860088518687657, 48.278453145708355, 113.90894140516008, 87.26821395329067, 30.434815611158097, 25.050418547221593, 51.75848967688424, 35.36566380092076, 3.333467104605266, 1.104674226471356, 0.27824547088571955, 0.2960452628987176, 0.41893916417445454, 2.4743408049855913, 0.07270917988249234, 0.18982656326677116, 0.07661591989121266, 0.6420314631291798, 0.038176826267902336, 0.049670877001647434, 0.07635402573006493, 0.03660116617434791, 0.014251708651759794, 0.024143305640401583, 0.04591520942215409, 0.044965657339032204, 0.015056966870490993, 0.04203852851475988, 0.06562038205031838, 0.050923479787473164, 0.08225225923316819, 0.048704429396561215, 0.03947247870798622, 0.0919137904420495, 0.050396736445171494, 0.027887222689709494, 0.03421320466856871, 0.027438195355768715, 0.030915894279522554, 0.06483924575150013, 0.06928977050951549, 0.00718760779792709, 0.0027318721030107035, 0.035735769396913905, 0.026919592737353275, 0.45409856896315304, 0.24449402626071656, 0.14694967759507044, 0.02772589590001319, 0.0772727621453149, 0.018746073557330028, 0.007120973962758268, 0.046750961004623344, 0.052931183483451605, 0.009253227850422263, 0.03987782195742641, 0.031128771070923125, 0.014034916713301624, 0.0559501486298229, 0.08875991217792034, 0.07240670254187924, 0.09560206931616579, 1.7734189076083047, 0.334732181259564, 0.2151693305266755, 0.11525171063840389, 0.019290694601035545, 0.015456983620034797, 0.05535351957327553, 0.036940532071249824, 0.04915933284376349, 0.04657097959092685, 0.047841668727674654, 0.030411545985511372, 0.10448228102177382, 0.0522828127390572, 0.1300463117659092, 0.9242801006351198, 0.5954606735280582, 0.5273424344403403, 0.4362935115184103, 8.784758601869855, 55.67289979117257, 41.55471958432879, 24.80190580231803, 79.71700205121721, 96.76026616777692, 50.928787912641255, 19.15250097002302, 25.84635032926287, 36.86163180215018, 30.829879760742188, 13.301508920533315, 0.6486311661345618, 0.14707832783460617, 0.08959840504186493, 0.06176806055009365, 0.032050574464457374, 0.08163433774773564, 0.048704409040510654, 0.029425526037812233, 0.014602497685700655, 0.052603352681866715, 0.054135579748877456, 0.0416511019824871, 0.05024115515074559, 0.014157772263778108, 0.023167141413848315, 0.021085411243672882, 0.047029255357171805, 0.06738599802234344, 0.04314660334161349, 0.05343227820204837, 0.07688054854848556, 0.023289128439500928, 0.010310217472059386, 0.0141687331488356, 0.05237848956936172, 0.09668326058558055, 0.07925598429782049, 0.04498534842527338, 0.07896542881748506, 0.05503663354154144, 0.050927730809364996, 0.024559736152046492, 0.0311256192757615, 0.016458379171256508, 0.023435174620577266, 0.07418867799320392, 0.052576557333980284, 0.08050735893526248, 0.06489286358867373, 0.020904074456276636, 0.04092969712136047, 0.03491767668830497, 0.0524685650930873, 0.0054927460649716, 0.07453164351837975, 0.038723535503127744, 0.1195073737097638, 0.02119609896492745, 0.02858366085482495, 0.017548103018530777, 0.036382131677653105, 0.023580764486853565, 0.05892972821103675, 0.03974114464862006, 0.02684868752424206, 0.053638288219060214, 0.030410161774073328, 0.039821486587503126, 0.015714350256270597, 0.10792948997446469, 0.03390048484184912, 0.03269941679068974, 0.038885586628956456, 0.025773411383852363, 0.030692761431315115, 0.032762646076402495, 0.02371854950407786, 0.11925105032111917, 0.06959167788071291, 0.04111155468438353, 0.017413832812703083, 0.06519376672804356, 0.05368625046685338, 0.09597875124641828, 0.0853483263137085, 0.060931854349161894, 0.005312842682802251, 0.13076057843863964, 7.627870508602687, 66.62467125483921, 87.02663203648159, 62.10041427612305, 33.07826123918806, 37.90483086449759, 86.14004189627511, 99.1287681034633, 34.397404534476145, 25.161370856421335, 57.569240365709575, 65.24295943123954, 13.819048098155431, 3.11432808637619, 0.31915236583777834, 0.6929576333080019, 0.29726953006216456, 0.5416541493364743, 0.7413324575339044, 0.4180963693984917, 0.4092340235199247, 0.20279412743236336, 0.6590350078684943, 0.09753045226846423, 0.09746332479906933, 0.08297000679054431, 0.051821544633380005, 0.04103828986574497, 0.019761131411152225, 0.0006755897525830992, 0.043781260893281014, 0.03679771062784961, 0.03742243781951921, 0.03825920041916626, 0.015912260261497328, 0.05341205446581755, 0.05169095717636602, 0.034834471331643205, 0.014951956791004964, 0.0729899373171585, 0.028349320304446986, 0.08843680737274033, 0.01712413059015359, 0.04627482958936265, 0.0676104166944112, 0.022662676072546413, 0.03162158426961728, 0.006337346168168421, 0.044720984396657774, 0.13641460718853132, 1.1201251745224, 0.15344905241259507, 0.09105201025626489, 0.0934328403589981, 0.008676175377331674, 0.012810949801600404, 0.044093610918415446, 0.08378384169191122, 0.03944835000272308, 0.07427742358829294, 0.04355287618402924, 0.07496149545269352, 0.04619792103767395, 0.05671214684844017, 0.04927660744371159, 0.09020604672176497, 0.019886614588488425, 1.4988492237670081, 2.332703948020935, 0.5848575053470475, 0.13560116583747522, 0.04705000156536698, 0.025078966415354183, 0.028509961773774455, 0.06232625059783459, 0.11025997277881418, 0.057954055922372, 0.039160101541451046, 0.04553534516266414, 0.09986281461481537, 0.1353355600897755, 1.0750969392912728, 1.4871910150562013, 0.4755016533391816, 0.26085687109402245, 0.3100646920502186, 8.048444969313485, 54.985399859292166, 61.11289460318429, 28.969360624040874, 48.613349369594026, 92.42342989785331, 75.18566485813686, 38.369026115962434, 33.029113156454905, 44.875691005161826, 53.771539143153596, 32.153594970703125, 5.577063228402819, 0.5043807551264763, 0.13745391927659512, 0.14955115371516772, 0.04507547483912536, 0.04080735047214797, 0.033179877259369404, 0.11165370406316859, 0.01625972447384681, 0.08040916134736367, 0.020904808970434324, 0.032843778508582284, 0.03947815126074212, 0.0655199588675584, 0.04474606644362211, 0.046602514505918534, 0.023031105320634584, 0.040158670994320085, 0.01019404294701027, 0.04707504629290529, 0.06059507706335612, 0.02235126751475036, 0.03537606102015291, 0.026310107138540064, 0.04372410788866026, 0.029489172622561455, 0.06956870947033167, 0.041601382328995636, 0.00594754730783669, 0.051744971956525526, 0.04197161478389587, 0.03790623668049063, 0.03464911252792392, 0.061221656655626636, 0.07919467865888562, 0.04815945042563336, 0.07421577189649854, 0.17609829349177225, 0.17080919444561005, 0.12507929972239903, 0.16224187559315137, 0.12121165011610303, 0.10453684880797352, 0.06874139207814421, 0.10839392683867898, 0.10819814912974834, 0.257845939802272, 0.06147194786795548, 0.11649508534797601, 0.14607172113444122, 0.09712048819554703, 0.10468534619680472, 0.23936910554766655, 0.11049892567098141, 0.13066096949790204, 0.14737760248993123, 0.16211959001209053, 0.1370293056326253, 0.1908303201198578, 0.15190444886684418, 0.08461638380374227, 0.13067843498928206, 0.09480798656919173, 0.1047431438096932, 0.12646106843437466, 0.07512661694948163, 0.06861104550106184, 0.20643495635262557, 0.18371621971683844, 0.11969507006662232, 0.15423428027757577, 0.1605785691312381, 0.22873461619019508, 0.2033507161374603, 0.14305690862238407, 0.12096030717449528, 0.0994937594181725, 0.16201345356447355, 5.489945411682129, 68.14209529331752, 111.82885919298444, 90.9684979575021, 74.1124461037772, 41.38437407357352, 72.99423081534249, 136.82319014413017, 109.68144198826381, 43.972484248025076, 43.99507284164429, 77.97804164886475, 53.07281787054879, 6.002061086041587, 1.391778352005141, 1.716158694454602, 0.48445191021476475, 0.8007171366895948, 6.489967499460493, 2.4177392593451907, 1.23513696874891, 0.2546288695718561, 1.3400949367455073, 0.2641728717301573, 0.20258988839175018, 0.24712964626295225, 0.29794157828603474, 0.12707557688866342, 0.06241586471774748, 0.13382682390511036, 0.15377412496932916, 0.1367298545581954, 0.13696989310639246, 0.1390414469476257, 0.1709741870207446, 0.20912749187222548, 0.11413740686007909, 0.11018461467964308, 0.1881125159561634, 0.15933235814528807, 0.09076496958732605, 0.13039810503167765, 0.10929305359189, 0.08413759592388358, 0.18165492532508715, 0.13167433440685272, 0.1764649466744491, 0.15258037831102098, 0.1326486292694296, 0.3930689852152552, 2.6953399862561906, 0.41329114724482807, 0.29621367529034615, 0.12752027516918524, 0.3320488195334162, 0.046199203468859196, 0.12044753826090268, 0.14091334864497185, 0.09370415258620467, 0.20995519602937357, 0.1404556089213916, 0.282547437186752, 0.10994662530720234, 0.17279831985277788, 0.09849964454770088, 0.29504822354231564, 0.2188772801309824, 6.359582815851484, 5.020620218345097, 0.43939536650265965, 0.23481361142226628, 0.10961130687168666, 0.11618499484445367, 0.10011515500290052, 0.21240246828113282, 0.14084724576345511, 0.23139859895621026, 0.15482425290559018, 0.2533100146268095, 0.27416516840457916, 0.31213186255523134, 1.1776889371020454, 3.4833323657512665, 1.0434748189789909, 0.6559797546693257, 0.4321202225983143, 13.710629275866918, 77.70364339011056, 58.05718803405762, 34.64058106286185, 98.78376225062779, 110.56968579973493, 73.45003264290946, 36.0225430216108, 50.35478333064488, 60.8481057030814, 73.38738768441337, 39.6344633102417, 5.877805147852216, 0.5041836542742593, 0.19317240587302617, 0.1697892884590796, 0.089533313177526, 0.2982548443334443, 0.08304543952856745, 0.2454961139176573, 0.07164352706500463, 0.1724057737737894, 0.11944428352372986, 0.20511429650442942, 0.1710593703069857, 0.14753310914550508, 0.15056362295789377, 0.12044776896280901, 0.13994323355810984, 0.25673992772187504, 0.11666585904146944, 0.15949459586824688, 0.22172194320176328, 0.11082061912332263, 0.19154004060796329, 0.10606319297637258, 0.1357136940849679, 0.1302615837859256, 0.19328464913581098, 0.1575921465243612, 0.14235702689204896, 0.18127521712865147, 0.1760093511215278, 0.10114063176193408, 0.10270037342395101, 0.10292749266539301, 0.15901225246489048, 0.16118285884814604, 0.15589485902871403], [0.02020914263890258, 0.04740217141807079, 0.029827066098472903, 0.02954280742311052, 0.02437421789259783, 0.019923593050667217, 0.04358577495440841, 0.014871798056576933, 0.02466891922189721, 0.06756106005715472, 0.04616482888481446, 0.019365330060411776, 0.02502510091289878, 0.07747241428920201, 0.015061236552095838, 0.020313777827790806, 0.033419579932732243, 0.07228998094797134, 0.09713118869279112, 0.01629294385202229, 0.082295732971813, 0.0534946152142116, 0.06109329818614891, 0.03985933866351843, 0.061695070538137636, 0.04718220393572535, 0.032922804089529176, 0.03449261521122285, 0.028797334924872433, 0.06536966336092778, 0.015364338144926088, 0.050496148610753674, 0.013122747668863406, 0.00620130286552012, 0.018509994260966778, 0.046698913976017914, 0.061192377869571955, 0.11193306371569633, 0.027776685942496573, 0.06674797154430832, 0.029911591205745935, 0.07429445481726102, 0.6947305096047265, 9.10813123839242, 49.66969789777483, 58.92437880379813, 56.15291609082903, 25.994682209832327, 41.98259660175869, 92.27953270503453, 117.99604552132743, 73.28862598964146, 35.06785706111363, 33.439407757350374, 52.03542750222342, 25.95982309750148, 1.1013887056282587, 1.094821246606963, 0.49189771924700054, 0.21457595165286744, 0.5109279666628156, 0.15399973786302976, 0.1600679172469037, 0.1168008739394801, 0.041544456633606126, 0.05357075023597904, 0.0665905446346317, 0.032530973864985366, 0.06306958571076393, 0.044557912075626, 0.05837641004472971, 0.08389035811913864, 0.05782966688275337, 0.056025717074849775, 0.0651004206655281, 0.07302264270505734, 0.1327186676540545, 0.03364091127046517, 0.037561964975403886, 0.020197186851873994, 0.18525337294808455, 0.077453639225236, 0.024549693833770495, 0.04029621682795031, 0.043629604923938, 0.04522693403331297, 0.07315357960760593, 0.05379677703604102, 0.030044282121317725, 0.05881038747195687, 0.0446990846789309, 0.2487174996307918, 0.11320309128080096, 0.0828495736100844, 0.08355515503457614, 0.011687524816287416, 0.09621662526790585, 0.06533146183937788, 0.09402606995510203, 0.042232966117028675, 0.028216452969770347, 0.029885511712304184, 0.06428886564182383, 0.07334027851798705, 0.024719766939857175, 0.05784929011549268, 0.04352701721446855, 0.04945105879700609, 0.06371724738606385, 2.0728634681020464, 1.229173134480204, 0.07917509613824741, 0.04547991563699075, 0.02516638208180666, 0.08377798593470029, 0.1722709217241832, 0.07951796666852065, 0.04178864781611732, 0.02420307100484414, 0.12632898480764457, 0.17180174190018857, 0.11203364974686078, 1.9741716895784651, 0.20530710901532853, 0.5786577037402562, 1.079264555658613, 26.93867662974766, 49.99778488704136, 38.14223691395351, 38.77003444944109, 86.06789875030518, 73.79574026380266, 37.36740854808262, 18.904761212212698, 33.870939527239116, 45.93227924619402, 54.710675035204204, 11.627110310963221, 1.45499002294881, 0.41044119160090176, 0.09262444730848074, 0.08037133302007403, 0.06354942531990153, 0.1333474117730345, 0.04173090787870543, 0.009517068558904742, 0.05880003981292248, 0.07626116142741271, 0.006758786812757275, 0.03718933050653764, 0.02202935523486563, 0.01503010536544025, 0.029491432144173553, 0.01923539738969079, 0.059043810303722105, 0.15944922901690006, 0.06849543670458452, 0.023287362552114894, 0.009088520259995545, 0.011970801312210304, 0.011116174581859792, 0.06620349468929426, 0.022442739124276807, 0.0554536408079522, 0.047270382954073806, 0.026903910096734762, 0.05372481161196317, 0.04107866948470473, 0.038938546287161965, 0.012921389857573169, 0.03326338795678956, 0.026884717733732293, 0.01719072710589639, 0.0498631263284811, 0.033294871981654844, 0.020804255169683268, 0.008222367764184517, 0.021195108303800225, 0.011527080122115356, 0.027192667459270785, 0.031891994045249054, 0.06519116793892213, 0.03119711990335158, 0.009107759272280549, 0.05781347703720842, 0.015118716949863093, 0.047937471086957624, 0.03177458034562213, 0.05633009770619018, 0.041012671776115894, 0.07655690091529063, 0.0728251143757786, 0.022936412366107106, 0.03689619320045624, 0.012826612086168357, 0.029375005712998763, 0.01330971290423934, 0.04500614891627005, 0.023469983467033932, 0.022845224044950943, 0.03902283729985356, 0.011170159676112235, 0.060292810068598816, 0.046077973009752374, 0.039439210136021884, 0.046119224546211104, 0.04100728760074292, 0.10221701900341681, 0.017487067097265805, 0.06493522452988795, 0.05962274316698313, 0.0524415051165436, 0.09727060049772263, 0.04241898649239114, 0.053701470007321665, 0.02180180003467415, 0.060304989772183556, 0.043533520972622294, 2.1167478561401367, 33.69588661193848, 83.00666836329869, 68.80108329227993, 43.34094858169556, 41.78469106129238, 81.92566067831856, 100.3025689806257, 70.7929789679391, 40.33744730268206, 51.88930688585554, 73.14024720873151, 55.10521806989397, 9.304754836218697, 1.5989723312003272, 1.1917068191937037, 1.1092710026672907, 0.15617083279149874, 0.6199079645531518, 0.2244324056165559, 0.23091059657079832, 0.16937178586210522, 0.08814489482236759, 0.0794892239251307, 0.03913681761228612, 0.022869507116930823, 0.04293132792892201, 0.0782277730426618, 0.01529458474500903, 0.07674986948924405, 0.043090261186340025, 0.05341314012184739, 0.041241558601281474, 0.032988730551941056, 0.049230314392064295, 0.06326852539288146, 0.055862363161785264, 0.03584662166291049, 0.02324642992711493, 0.05575604011703815, 0.055246002306895595, 0.11235283940498318, 0.027812275104224682, 0.08637300240142004, 0.017110826214775443, 0.01886320736126176, 0.01311074777705861, 0.0670656616400395, 0.039228789641388824, 2.474250478403909, 0.047852016386709044, 0.1196057205753667, 0.06203437875956297, 0.03613862242283566, 0.025330200791358948, 0.0354363081444587, 0.07099835561322314, 0.05467429244890809, 0.04069738708702581, 0.09676706644573382, 0.03860894790185349, 0.010595735678050135, 0.045301610204790316, 0.09176578159843173, 0.06605224923363753, 0.02739498115676854, 0.007499782252125442, 1.324693928871836, 0.30047015260372845, 0.09189124950873, 0.05168543050863913, 0.07585082416023527, 0.07945041172206402, 0.21356648153492383, 0.05809914706540959, 0.08785503144775118, 0.041421601083129644, 0.18709873035550117, 0.25806060114077156, 0.23731558716722898, 2.1486261912754605, 0.3040673924343926, 0.8206814282706806, 1.401104788695063, 27.3682507446834, 71.46210438864571, 59.78701850346157, 35.13323613575527, 67.60816097259521, 91.0404326575143, 64.91944435664585, 34.64603887285505, 36.05343471254621, 48.934481212071006, 67.46701526641846, 30.626064777374268, 5.091935660157885, 0.434411418225084, 0.17058687923210009, 0.07588460841881377, 0.041500263647841554, 0.05781076968248401, 0.023288287056077803, 0.06500640285334416, 0.04786463374538081, 0.03806620131113699, 0.04465501382946968, 0.08922846096434764, 0.026826214444424425, 0.04261226040710296, 0.03662391745352319, 0.03800154370920999, 0.04960657563060522, 0.0592756521488939, 0.021828505476670604, 0.02177774257558797, 0.05135685331853373, 0.02103521322299327, 0.02052483953801649, 0.03430581112791385, 0.09852886905095407, 0.028749915505094186, 0.0409978084665324, 0.028758651643459286, 0.03436704212799668, 0.08847148051219327, 0.06753216803606067, 0.02014098040360425, 0.03854641750720995, 0.021873051300644875, 0.03364167122968605, 0.0343207931811256, 0.08299322625888245, 0.028189779758187275, 0.08334996604493686, 0.1305707786232233, 0.07052329289061682, 0.07483169848897628, 0.15339717162506922, 0.1559598491128002, 0.17021926252969674, 0.150087779920016, 0.0885338175243565, 0.10924047391329493, 0.14203363710216113, 0.13998017300452503, 0.11328155028500728, 0.2789971519793783, 0.18126643688551017, 0.18261179540838512, 0.09788632352969476, 0.17271213233470917, 0.16325845675809042, 0.1420774704643658, 0.13396772848708288, 0.12004077008792333, 0.09044719128204243, 0.0777527035347053, 0.21070007820214542, 0.16143952150429997, 0.1336072092609746, 0.1868224037545068, 0.0954783113141145, 0.12505719305149146, 0.11462539567479066, 0.16056452345635208, 0.15646731188254698, 0.12914204171725682, 0.1281354214463915, 0.10085897187569312, 0.17357775302869932, 0.14923073590866157, 0.12081854763839926, 0.18757545548890317, 0.31038631764905794, 0.22551103202360018, 1.7822309604712894, 29.767187527247838, 103.35243211473737, 103.11094052450997, 85.00627653939384, 47.960427148001536, 65.20492499215263, 112.31781782422746, 142.05879674639021, 95.68740177154541, 53.92201280593872, 63.16431549617222, 81.52689661298479, 42.93946082251412, 2.200643011501857, 2.5023416110447476, 1.8284017401082175, 0.3577605741364615, 1.8029984746660506, 1.232183767216546, 0.35223306502614704, 0.2435119418161256, 0.3912740701011249, 0.19256008230149746, 0.14188161811658315, 0.223302889083113, 0.11474142516297953, 0.11622781040413038, 0.1577939564096076, 0.16229839756020478, 0.10365581179835967, 0.19832545864794934, 0.06889085977205209, 0.23653600471360342, 0.21362182285104478, 0.11039624975195952, 0.1212654850844826, 0.15937919063227518, 0.19000832922756672, 0.18636332053158963, 0.12194974693868842, 0.2304227298923901, 0.19821911863982677, 0.21234494208225183, 0.1599925455770322, 0.10711491546992745, 0.09483463263937406, 0.15872215160301753, 0.23806962956275257, 3.3212000599929263, 0.3242703654936382, 0.18727831143353665, 0.21191187389194965, 0.09679779729672841, 0.1795686065618481, 0.14430572518280574, 0.11562217718788556, 0.11621067060955934, 0.09021383630377905, 0.12399593714092459, 0.10607726579265934, 0.14620529753821238, 0.09181969120566334, 0.1819408464112452, 0.15979015215166978, 0.10735466903341667, 0.17708239997071878, 6.835974761417933, 1.6336860741887773, 0.21702540878738674, 0.24056834833962576, 0.14807725351835999, 0.19808896205254964, 0.3625126805688654, 0.2140134461224079, 0.17855961141841753, 0.16067379473575524, 0.2677659589265074, 0.28174399744187084, 0.1703967401491744, 2.2347349992820194, 0.44151052300419125, 1.0662104104246413, 1.5359851739236285, 44.7167648587908, 71.84620080675397, 51.58001824787685, 53.96017926079886, 104.57150050571987, 92.03839547293526, 56.722567626408164, 38.99784503664289, 54.848419598170686, 64.37610912322998, 88.91871683938163, 37.385459968021934, 3.974903302533286, 0.6957260561840874, 0.23745376403842652, 0.09958074082221303, 0.196193610184959, 0.2093065979757479, 0.16094462520309857, 0.312797342560121, 0.19418419658073358, 0.11349563486874104, 0.09602380597165652, 0.16943535102265223, 0.10934772994369268, 0.09293632235910211, 0.07513699853526694, 0.10625252460262605, 0.188890972041658, 0.15044972406966345, 0.2278771379164287, 0.15811913753194468, 0.1341199374624661, 0.08148350619844028, 0.1762735726577895, 0.1851562610162156, 0.1599222629198006, 0.09075543617031404, 0.1100467024371028, 0.07567086988793952, 0.1747696947838579, 0.12938993770096982, 0.13779216898339136, 0.10058849424655948, 0.2521299879465784, 0.07677274290472269, 0.07963804701077086, 0.13081589261335985, 0.15728517728192465, 0.08445485175720283], [0.030468749880258526, 0.0243068597212966, 0.06437069017972265, 0.03581936491121139, 0.033690675028732846, 0.02181714171144579, 0.07305978571197816, 0.04153676883184484, 0.018963866334940706, 0.018981693146218146, 0.02905320030237947, 0.042699068784713745, 0.011849886371887155, 0.08544284624180623, 0.020257605306271995, 0.004295082987352673, 0.06734010869903223, 0.028655015597386018, 0.03839811010818396, 0.00995545307107802, 0.006719980970956385, 0.04430341733885663, 0.06990880479237863, 0.0537036616754319, 0.015290460948433195, 0.04940051133079188, 0.010064759125400866, 0.01980807416007987, 0.06834343807505709, 0.0013164225030258031, 0.04670197077627693, 0.029957317680652653, 0.037557680026761124, 0.049739782232791185, 0.04650723461859992, 0.012885293490918619, 0.05322933516332081, 0.08935903145798615, 0.08652540815195867, 0.01691141495081995, 0.023273033588858585, 0.1111283211835793, 0.13520480639168195, 0.405808615897383, 1.076699041894504, 36.95671442576817, 62.48134231567383, 58.78279536111014, 43.40168625967843, 30.924107755933488, 68.87555408477783, 109.37578378404889, 98.16190542493547, 52.29548467908587, 34.88479634693691, 51.82070732116699, 56.6795791217259, 24.978860786982946, 1.3359036530767168, 1.4324421414307185, 0.26843111323458807, 0.5277569921953338, 0.17792987663831028, 0.06268372998705932, 0.12579291500151157, 0.04142245603725314, 0.07038787087159497, 0.039795159428779564, 0.2701210454106331, 0.22611116910619394, 0.0752337644142764, 0.09770151094666549, 0.0682273203773158, 0.08205016436321394, 0.014972221239336898, 0.09081955094422613, 0.1809229353176696, 0.0769249518801059, 0.04609932989946433, 0.06195808428206614, 0.05324748936774475, 0.04397511834810887, 0.06479570415935346, 0.05371103735108461, 0.044296078982629945, 0.02304513572848269, 0.049588414640831094, 0.005910415327109928, 0.03143419664619224, 0.02403968316502869, 0.21118623497230665, 1.671222631420408, 0.08550422651959316, 0.02081973085712109, 0.05120771810678499, 0.035943044881735525, 0.0478870287936713, 0.04417658218049577, 0.016757019396339144, 0.037624668396477184, 0.03617743801857744, 0.03700913196163518, 0.028112326682146107, 0.07704740030957119, 0.09762135560491256, 0.061660668812692165, 0.05829475514058556, 0.03967173390888742, 0.0669594369828701, 0.1955647167882749, 0.8010792029755456, 0.04682393744587898, 0.09915288378085409, 0.11551619001797267, 0.06314065546861716, 0.07997308046157871, 0.017477910267189145, 0.0557826726165201, 0.1415272057056427, 0.09092094443206276, 0.09673797764948436, 1.2592280017478126, 1.9499524406024387, 0.15411590305822237, 10.359308123588562, 46.7846668788365, 46.11348131724766, 36.04511077063424, 61.881657191685264, 91.55368219103131, 68.33253152029855, 31.258715629577637, 20.176319769450597, 38.09632321766445, 53.930409703935894, 60.85166318075997, 21.1791341645377, 0.5309303647705487, 0.13621570143316472, 0.09925742567117725, 0.06572558211960963, 0.05016808032191225, 0.04964331490918994, 0.039933957159519196, 0.06607102429760353, 0.05609384538339717, 0.037358611422990046, 0.042270869083170376, 0.10878595044570309, 0.0378976667832051, 0.035067982372960875, 0.060053891103182516, 0.05711801935519491, 0.05622862957950149, 0.020748581371403167, 0.044904429731624465, 0.05460629306201424, 0.04295391296701772, 0.039505438546517065, 0.016000020284471766, 0.04637732908927968, 0.050758785767746825, 0.030115243313567977, 0.041812661170427284, 0.10215453271354948, 0.03450382460973092, 0.04676218058115669, 0.016841949928285818, 0.042763417653207264, 0.033547690736928155, 0.03436087424467717, 0.05673772083329303, 0.11110293718853168, 0.055263176028217585, 0.0343129153895591, 0.03129152448049613, 0.032397265146885595, 0.051321840911571465, 0.07915448902973107, 0.03182340772556407, 0.03823534991326077, 0.06516880342470747, 0.03746233907129083, 0.07202344560729605, 0.07142231786357504, 0.0014814366004429758, 0.06756097184760229, 0.03132529516837426, 0.01773840664619846, 0.02649156775857721, 0.04774704023397394, 0.07050695376736776, 0.019595998040001308, 0.037743917533329556, 0.033271021475749354, 0.03900440150339689, 0.02699202804693154, 0.04837258845301611, 0.007994858365106796, 0.02014251728542149, 0.034715174697339535, 0.04522553285849946, 0.02967534227562802, 0.07277981537793364, 0.013432151155679353, 0.027612772238041674, 0.020125879606764232, 0.0327257948395397, 0.04129443344260965, 0.037798017130366394, 0.040554433329296966, 0.030413160898855755, 0.040542891448629756, 0.10931195079215936, 0.07971018206860338, 0.11676689290574618, 0.019237468617835214, 0.13509089393275125, 0.23806696970547947, 1.2205064509596144, 23.844537837164744, 78.64196981702531, 80.26016357966832, 55.04191303253174, 49.19564662660871, 64.0529761995588, 100.7338923045567, 104.94117941175188, 67.20729160308838, 42.98686490740095, 57.006811482565745, 75.75173459734235, 44.82893310274397, 9.284394877297537, 2.2399769808564867, 0.9196211163486753, 0.7952279512371335, 0.3739568793347904, 0.12970776350370475, 0.2529146187007427, 0.12500562439007418, 0.05546777469239064, 0.21769730773355278, 0.07031224135841642, 0.4274174863738673, 0.05921892662133489, 0.15288466055478367, 0.03356956331325429, 0.06360266996281487, 0.04739103326573968, 0.058857667792056284, 0.07355616121952023, 0.11787365137466363, 0.037022309111697335, 0.0495814834056156, 0.04213096194767526, 0.032844416331499815, 0.02742319803551904, 0.08626210942332234, 0.039494476813290796, 0.06328955319310937, 0.06168355579887118, 0.04591360468683498, 0.02357219628590558, 0.022917752653094273, 0.045589254769895754, 0.7315539536731583, 3.971507804734366, 0.07531280017324857, 0.03572646328913314, 0.05908142149980579, 0.015428905840963125, 0.06304970463471753, 0.09145396761596203, 0.055225520727357695, 0.03484154845188771, 0.027577700459265282, 0.011785002308897674, 0.020338649528899362, 0.05973669633801494, 0.10898065606930427, 0.06426462158560753, 0.037728033028542995, 0.05355866891997201, 0.04990868656230824, 0.15153764640646322, 0.9171744819198335, 0.10006226319819689, 0.03524133449952517, 0.1412557102739811, 0.10464563832751342, 0.35600702251706806, 0.16090617940894195, 0.06337627675384283, 0.10543876434011118, 0.13061519552554401, 0.6269114773188318, 1.6781770182507378, 2.11112784913608, 0.335546966109957, 15.419899157115392, 69.85670225960868, 73.9079953602382, 42.14336402075631, 49.35995067868914, 87.51892580304826, 88.70539324624198, 54.07265322549002, 31.97255618231637, 39.21652569089617, 59.78995759146554, 74.20906080518449, 43.07723665237427, 2.702470575060163, 0.35990767606667107, 0.3422720623867852, 0.060389134899846146, 0.10910045821219683, 0.037225414998829365, 0.044473522675356696, 0.0410029789033745, 0.00873373041395098, 0.035573585956756554, 0.09050287865102291, 0.05410127641100969, 0.03015831671655178, 0.043436687240110974, 0.003457235579844564, 0.037829236526574404, 0.024023566261998246, 0.00852812412527523, 0.04828712357474225, 0.0583854481311781, 0.023486332768308263, 0.05517534984807883, 0.0347940136811563, 0.03786249831318855, 0.016128655256969587, 0.0436819165812007, 0.03267882664554885, 0.025376593926921487, 0.011424499197996088, 0.021019494959286282, 0.07979278692177363, 0.02099455031566322, 0.030696204996534755, 0.05275827918999961, 0.041246159068707905, 0.057894568757287095, 0.07314076886645385, 0.05232409820226686, 0.06033511672701154, 0.13479014007108553, 0.10497394749628645, 0.2181922040347542, 0.1848097060407911, 0.190431395811694, 0.1637762061187199, 0.1470932284636157, 0.15981042677802698, 0.08601576728480202, 0.06134240874754531, 0.1242408747119563, 0.12946463083582266, 0.10890449051346097, 0.11279162086014237, 0.1313013844192028, 0.13771966073129857, 0.18052283035857336, 0.12079937223877225, 0.12205004798514502, 0.13214104436337948, 0.12426562766943659, 0.1050370376823204, 0.191719703110201, 0.2551741674542427, 0.13193205557763577, 0.18019123029495987, 0.08895353893084185, 0.12710201261298998, 0.08671553366418396, 0.19847525203866617, 0.12982196094734327, 0.09020251155431781, 0.105680539937956, 0.11528242113334791, 0.13459903746843338, 0.07636548618652991, 0.1257115586527756, 0.21837029233574867, 0.14819474864218915, 0.17842591287834303, 0.19568373183054583, 0.18459887163979666, 0.24620580726436206, 1.6574859342404773, 20.85624269076756, 91.60345213753837, 107.15272154126848, 89.83583736419678, 72.35148770468575, 55.38017565863473, 91.35169110979352, 133.86281285967146, 124.81022725786481, 70.44021892547607, 54.23557111195156, 73.70049435751778, 82.94264766148159, 38.12112481253487, 2.3406637609004974, 2.4446650488036017, 1.012084486229079, 0.806654155254364, 0.299265590097223, 0.19561655686369964, 0.39286767744592255, 0.1328784083681447, 0.41866791301539963, 0.1833343809204442, 0.8852730765938759, 0.43157438188791275, 0.1767505556344986, 0.15771996895117418, 0.13230568410030433, 0.16677043187831128, 0.11120361142924853, 0.1872789899685553, 0.24729550736291067, 0.12639926746487617, 0.1862709176327501, 0.14063035883009434, 0.13814040672566208, 0.162957350058215, 0.2209388730781419, 0.1349847303437335, 0.11432829233152525, 0.18336332722433976, 0.2437015516417367, 0.13684289849230222, 0.1621131439294134, 0.16831489971705846, 0.8491334329758371, 5.308462372847965, 0.26106838403003557, 0.11125307663210801, 0.14997735513108118, 0.10717967485210725, 0.08642932759331805, 0.20890848790960653, 0.10051445250532456, 0.11520776871059622, 0.08667362055608205, 0.36030556900160654, 0.07181706918137414, 0.21340577730110713, 0.19886458186166628, 0.10973781972591366, 0.14106306061148643, 0.08884861706090824, 0.13670964778534003, 0.432735165315015, 2.0860366012368883, 0.13164480456284114, 0.13538005841629847, 0.3053389127765383, 0.3397632198674338, 0.5699222439101764, 0.28551353088447023, 0.2495364099740982, 0.24365820682474545, 0.23356152432305471, 0.4907788964254515, 2.147505794252668, 3.7409913284437994, 0.30056370901209967, 17.552435057503835, 74.33984674726213, 67.87160192217145, 53.13805798121861, 78.59985678536552, 108.52366365705217, 83.94587721143449, 51.92492682593209, 39.80135556629726, 55.405873571123394, 76.29812703813825, 93.02462972913469, 40.03248044422695, 1.5977596534149987, 0.3578168654016086, 0.2739315080855574, 0.13082362791257246, 0.1804305903081383, 0.14611669443547726, 0.2798034687127386, 0.15196977821843966, 0.1381955309105771, 0.09214174428156444, 0.1519908263747181, 0.1982067014489855, 0.15899599476584367, 0.08427969472748892, 0.156169679281967, 0.12107393464871816, 0.09843871210302625, 0.11167164452906166, 0.1128886513678091, 0.16425650034632, 0.11519503939364638, 0.11220194000218596, 0.13986930038247788, 0.09030161837914161, 0.22167910050068582, 0.22057361767760345, 0.180225401318499, 0.08939205575734377, 0.10924660786986351, 0.14884934494537966, 0.1548791192471981, 0.16291378811001778, 0.12337962378348623, 0.1547074363167797, 0.09593637673450367, 0.23792881997568266, 0.14797816026423657, 0.11283740161785058, 0.11099042929708958], [0.04374943420823131, 0.01188566891609558, 0.05785840962614332, 0.061720529172037325, 0.028575080779514143, 0.04157599154859781, 0.0130746819444799, 0.024182954137878757, 0.029359066925410713, 0.05393844496990953, 0.05401209994618382, 0.07275659590959549, 0.02293825798135783, 0.07627171264695269, 0.08769781488393034, 0.03048047496538077, 0.05196956704769816, 0.02087121130898595, 0.0415290572813579, 0.06327972800603934, 0.03205098158546856, 0.035295987102602205, 0.0718064501083323, 0.06213794355945928, 0.04265941859089902, 0.020721784327179193, 0.0614324774859207, 0.013091767456249466, 0.021792293759062886, 0.08266373643917696, 0.030281016203973974, 0.061089898725705485, 0.08553957140871457, 0.1187365036457777, 0.04270725870238883, 0.020153283939829895, 0.038293938019445965, 0.024764704617804716, 0.014637421883110489, 0.04872512810730508, 0.00843135909443455, 0.10440030042082071, 0.0407858510900821, 0.22048384749463626, 0.5800097254770142, 0.8866573423147202, 31.145720549992152, 69.63263675144741, 66.73270879473004, 46.15360369001116, 34.93970101220267, 50.98802130562918, 100.39443111419678, 120.77062797546387, 98.68898882184709, 58.311429568699424, 36.65277590070452, 42.70638697487967, 46.481711523873464, 18.2267073563167, 0.08158841449767351, 0.9546351517949785, 0.12928754676665577, 0.350588106151138, 0.023562846073348607, 0.029251118789293935, 0.07403559370764665, 0.1768242581082242, 1.3329528399876185, 0.2467809064047677, 0.0780795199264373, 0.027808047831058502, 0.028123056017128483, 0.062338158887411864, 0.09610134216823749, 0.0505757577318166, 0.026372328799750124, 0.03846582790304508, 0.046571763298873387, 0.05547704687342048, 0.1341225973197392, 0.06554070168307849, 0.09328833275607654, 0.047713052414889844, 0.01797465727265392, 0.044862821964280944, 0.04329011689073273, 0.08048764070762054, 0.05193765554577112, 0.007535853173716792, 0.3428388291171619, 2.7556010612419675, 0.2841371904526438, 0.012688897466952247, 0.026865718753210137, 0.05306416277640632, 0.022749706670375805, 0.074549190433962, 0.04304675352094429, 0.00985204178972968, 0.12146942556968757, 0.023690191829310994, 0.029508080000856092, 0.04710053885355592, 0.00544255058879831, 0.023474970699420998, 0.002361977643366637, 0.080190313447799, 0.07764166806425367, 0.04519011333052601, 0.26544127081121716, 0.08289170384939228, 0.1690279178853546, 0.1571680349963052, 0.14460965458835873, 0.3324937756572451, 0.11708834208548069, 0.03552177641540766, 0.06996266011680875, 0.02117172089804496, 0.4746196120977402, 1.9123140488352095, 2.500669700758798, 24.97714110783168, 50.58672114780971, 31.425632204328263, 40.73251840046474, 87.76571886880058, 83.98965781075614, 47.80787944793701, 18.42624224935259, 29.033494234085083, 46.431969370160786, 59.870494161333355, 53.49560185841152, 9.687769072396414, 0.18835104815661907, 0.16671483271888324, 0.08901319572968142, 0.05610601830163172, 0.09862857298659426, 0.10342548308627945, 0.018417496367224624, 0.03562264743127993, 0.10400772720043149, 0.032782435550221374, 0.0206195409742317, 0.04499140435031482, 0.05346568926636662, 0.032582505206976614, 0.06010151069079127, 0.047234139006052694, 0.031948024074413946, 0.038557090863053284, 0.02707845644493188, 0.02864185201802424, 0.06975717935711145, 0.06126168343637671, 0.05616079304101212, 0.07404383790812322, 0.012133640386829419, 0.07260807137936354, 0.018779111427388022, 0.031509368148233206, 0.08678859152964183, 0.05911454079406602, 0.02572391225424196, 0.013359728568632687, 0.03226604325962918, 0.055711575717266114, 0.016090548730322292, 0.020375972347600118, 0.03135447556685124, 0.043091686109879186, 0.07150399990911994, 0.05873131100088358, 0.029741384088993073, 0.018163970239194374, 0.025559202967477695, 0.08620972651988268, 0.014846101935420717, 0.02011132163793913, 0.014443123380520513, 0.041561331799519916, 0.0559347357068743, 0.013910245233481484, 0.005293461178163332, 0.03411528867270265, 0.019108243319871168, 0.061882278349782736, 0.021904345335704938, 0.02835140340695424, 0.06011859620256083, 0.049397020268120935, 0.03044163901358843, 0.14010834826954774, 0.046367514080234935, 0.041607295761683157, 0.0424949654511043, 0.05909666818167482, 0.043385637657982964, 0.010970272589474916, 0.03229991572776011, 0.016879803700638667, 0.03411131924284356, 0.030966991359101873, 0.03417822958103248, 0.029328909436506883, 0.008956722466142049, 0.05454737925902009, 0.027513085265776942, 0.045501425197081904, 0.06515169077153717, 0.04821658646687865, 0.03965438376846058, 0.1063947726839355, 0.023991395220426575, 0.005880137822324676, 0.20726092346012592, 0.33566959095852716, 1.7786022637571608, 15.957257202693395, 61.53312860216413, 87.05112443651471, 68.4773736681257, 50.451999051230295, 58.472120557512554, 86.11640412466866, 112.97528416769845, 96.86054256984166, 64.28574780055455, 54.74124363490513, 61.74947466169085, 71.3293798991612, 50.31314972468785, 6.987419434956141, 0.4629387674587113, 0.9276509540421622, 0.4343342552227633, 0.11018213802682501, 0.03346416646880763, 0.3227837766919817, 0.2168356089719704, 0.0409705483221582, 1.4567050337791443, 0.2653006783553532, 0.01783385107825909, 0.1377307072814022, 0.03722729793350611, 0.09691314146454845, 0.059357910949204645, 0.040463604631700685, 0.06868334340729884, 0.029924727643706968, 0.03429212507658771, 0.04757446842268109, 0.10675508834953819, 0.011386340084884847, 0.016900560086859123, 0.009612148278392851, 0.012229311279952526, 0.0010351258450620143, 0.022987696042816554, 0.0804392679461411, 0.04373590082728437, 0.00687162676227412, 0.11966083118958132, 5.584885597229004, 0.2673544410083975, 0.06973115753914629, 0.036298827933413644, 0.06353896909526416, 0.024740508059039712, 0.021939186412574987, 0.027120836045859114, 0.008749976238634969, 0.06926788775516407, 0.013067378363172923, 0.008977689198218286, 0.10815707061971937, 0.0685974137325372, 0.02190770917305989, 0.011732217373459466, 0.07816390254135643, 0.2047422421830041, 0.009961001791193016, 0.2888905182480812, 0.13334384267883642, 0.11758231557905674, 0.6070973862494741, 0.5731848031282425, 1.0228853523731232, 0.4590189520801817, 0.06403858121484518, 0.3019460748348917, 0.20989009737968445, 0.837046987244061, 1.8996815724032265, 4.735595558370862, 40.72230454853603, 70.34501470838273, 44.47604104450771, 40.19220910753523, 76.40940938677106, 94.96381637028286, 74.63329001835415, 41.175942012241904, 35.77358211789812, 43.47531632014683, 62.58303615025112, 70.37444727761405, 27.733020748410905, 0.6507044434547424, 0.31384519061871935, 0.20983352112982953, 0.10048708040267229, 0.08296145724930934, 0.06035613774188927, 0.03170483712373035, 0.05365703614162547, 0.047764163065169535, 0.020574091002345085, 0.05334715598395892, 0.021600231029359356, 0.004074744431168905, 0.014935330986710531, 0.03583215190363782, 0.05130981048569083, 0.013933141549517001, 0.04317711027605193, 0.021697141097060273, 0.07388940333787884, 0.10677815854017224, 0.13143003465873854, 0.032821536130670986, 0.02322295940081988, 0.04381879745051265, 0.058289727196097374, 0.07612606510519981, 0.023449060839733908, 0.01331819374380367, 0.07159866911492177, 0.007215408225809889, 0.03093957854434848, 0.009735718835145235, 0.016025009032871042, 0.02755243011883327, 0.05242290307900735, 0.030073218247187988, 0.03202627951811467, 0.036617420480719635, 0.026207734863939028, 0.10917262041143008, 0.10089409963360854, 0.093577069762562, 0.2068927367883069, 0.09878030020211424, 0.07530856611473219, 0.15377658126609667, 0.15557802388710634, 0.1251200796770198, 0.12414927248443876, 0.16096956815038407, 0.1581951877368348, 0.11051993990050894, 0.13040362830672944, 0.12335747640047755, 0.09822347400976078, 0.1336616820522717, 0.21125245999012673, 0.14935277721711568, 0.23715398726718767, 0.13466075701372965, 0.07040449497955185, 0.13606617945645536, 0.19808612577617168, 0.12106470657246453, 0.10786250499742371, 0.09164230858108827, 0.13976524025201797, 0.17974735982716084, 0.15854228554027422, 0.07333808006452662, 0.1659969426691532, 0.19434134529105254, 0.2228496955441577, 0.09787614550441504, 0.10853529960981437, 0.13602853433362075, 0.10534536399479423, 0.18601099800850662, 0.24072709839258874, 0.16128374343471868, 0.14319150282868318, 0.21077367211026804, 0.3800518608519009, 1.070212247116225, 11.766051701136998, 65.80471433912004, 115.4700070789882, 100.06026445116315, 73.33180209568569, 60.17439447130476, 74.64761025565011, 120.41087804521833, 144.64342934744698, 119.18342317853654, 76.62498419625419, 50.53725344794137, 63.928256034851074, 65.76094068799699, 26.239423819950648, 0.27821007849914686, 2.5760402849742343, 0.47938499067510876, 0.44498834067157333, 0.12978036675070012, 0.4989110029169491, 0.3271154085440295, 0.6874668736542974, 4.291923548494067, 0.4071931801736355, 0.19221122030700954, 0.2745196350983211, 0.10667192709765264, 0.2109182272106409, 0.16811232987259114, 0.15402036532759666, 0.18345297527100357, 0.12153141652899128, 0.12620455505592482, 0.33660116525632994, 0.2073345309389489, 0.08179767469742469, 0.14076302599694046, 0.1294138899871281, 0.13921085000038147, 0.10266448570681469, 0.11585928446480206, 0.21374033577740192, 0.15498438716999122, 0.08403228728898934, 0.8533838306154523, 7.215336850711277, 0.3626005101416792, 0.1423339702721153, 0.13747147976287774, 0.20003486477902957, 0.11665395753724234, 0.15195833811802523, 0.12809683994523116, 0.1042687731928059, 0.21032651753297874, 0.09030464464532477, 0.14826535699622972, 0.16893371008336544, 0.12692454856421265, 0.21658227113740786, 0.13929934453751358, 0.16848738331879887, 0.37212678896529333, 0.22524842540068285, 0.751779236963817, 0.450098985007831, 0.1733808150248868, 1.0881497817380088, 0.34258345567754334, 1.3749558946916034, 0.749745423240321, 0.3197174498013088, 0.25486095568963457, 0.2197896654584578, 4.114193839686258, 2.478219202586583, 4.53961466891425, 41.41046803338187, 71.16420037405831, 41.63726765768868, 52.41915566580636, 106.99181515829903, 99.66435609545026, 70.73988083430699, 39.4211779321943, 46.99728175571987, 61.036610330854145, 81.30985573359898, 80.76969582693917, 19.167088712964738, 0.23097581735679082, 0.5412025164280618, 0.28179287910461426, 0.26516472707901684, 0.16962574794888496, 0.12146847562066146, 0.14721467266125338, 0.12740660698286124, 0.33582839529429165, 0.10229656366365296, 0.06599602582199232, 0.21264018623956613, 0.27103288791009356, 0.1163192226418427, 0.18693930176751955, 0.13971057747091564, 0.1125500216814024, 0.19037804938852787, 0.06936907768249512, 0.12170276019190039, 0.18905270764870302, 0.26934298287544933, 0.11968360282480717, 0.1461225976901395, 0.14509886476610387, 0.13839997351169586, 0.11073346130017724, 0.11412836877363068, 0.18512662260660104, 0.17653343799923146, 0.04667412709178669, 0.12791079921381815, 0.21493320034018584, 0.13011210252131733, 0.10662022272923163, 0.21258721979601042, 0.14085659597601208, 0.1457395511014121, 0.13691798517746584, 0.17169963595058235], [0.0629176888614893, 0.04662845150700637, 0.07501872988151652, 0.05235569079273513, 0.02768270205706358, 0.03826445906556078, 0.05604328095380749, 0.039659886687461815, 0.0431372633070818, 0.07702566683292389, 0.009346884342708757, 0.05581062147393823, 0.03950400005227753, 0.032333716949714084, 0.07839693182281085, 0.021209796890616417, 0.014897414449868458, 0.04641479779300945, 0.045142374999289, 0.03581096804035561, 0.02022683374317629, 0.02303405525162816, 0.019602515368855426, 0.042725741996296814, 0.061035609138863425, 0.031016185147953883, 0.030508797017059157, 0.06097441206553152, 0.030771152582019567, 0.034793596382119825, 0.05740050705415862, 0.12213026439504963, 0.005310079773023192, 0.05159111074837191, 0.07073765567370824, 0.03598806907289794, 0.015555934381804295, 0.07104214826332671, 0.03794521512463689, 0.018919473181345632, 0.04236325841130955, 0.018356302686567818, 0.14150809815951756, 0.06272624020597764, 0.06877839259271111, 0.2345869807260377, 5.181777170726231, 39.376956122262136, 69.153961454119, 73.20132882254464, 47.36388955797468, 29.293622629983084, 29.441973618098668, 68.62166690826416, 102.12438665117536, 119.66825457981655, 107.65839753832135, 65.41026510511125, 50.14981494631086, 40.660326617104666, 38.259126458849224, 3.746273262160165, 0.364906552114657, 0.15477632119187287, 0.07607921904751233, 0.07601431038762842, 0.16309758967586926, 0.05744982976466417, 0.42302429782492773, 0.2290180538381849, 0.5658490253346307, 0.06698061406080212, 0.09218697542590754, 0.1112490597047976, 0.119481874363763, 0.07930730190128088, 0.08958279873643603, 0.048190534114837646, 0.013125683180987835, 0.1634814233652183, 0.1197323352098465, 0.06316893002284424, 0.0755836306405919, 0.06770068220794201, 0.09255052770354918, 0.01266956006708954, 0.05228052268336926, 0.020446655340492725, 0.017893180483952165, 0.05443989931206618, 0.20108729973435402, 4.3823322057724, 0.14778213149734906, 0.039196783144559176, 0.05231010341750724, 0.07489541292722736, 0.05115364904382399, 0.032328309025615454, 0.030377249432993785, 0.005287473530708147, 0.01760419411584735, 0.06212436607373612, 0.010510841617360711, 0.07871207741222211, 0.04501838968800647, 0.10376294569245406, 0.010453976141954107, 0.04021922345938427, 0.027648585316325937, 0.03545789912875209, 0.04311494968299355, 0.03373245242983103, 0.11873207959745612, 0.159205770652209, 2.5389464582715715, 4.35321751662663, 0.9083068977509225, 0.5139417478016445, 0.7341400406190327, 0.9090523634638105, 0.17478755382554872, 12.126677972929818, 32.06321280343192, 49.06832783562796, 55.58156572069441, 75.00648471287319, 86.98648534502301, 60.24482141222273, 38.05935880116054, 28.628834622246877, 38.67847456250872, 61.300176348005024, 66.18136228833879, 29.700158255440847, 2.799697369337082, 0.1617493134524141, 0.1649027778101819, 0.09033796071474041, 0.032894495608551164, 0.08142074849456549, 0.004241597040423325, 0.05676831258460879, 0.07378818626914706, 0.002399574844665559, 0.032522627884255986, 0.02133421476797334, 0.020178228583452956, 0.0045434242596716756, 0.04583942723859634, 0.02863256965896913, 0.053492002854389806, 0.04181434054459844, 0.06445218223546233, 0.02652959625369736, 0.01915602745222194, 0.07901153527200222, 0.043908720303859027, 0.04633808940915125, 0.03289777632536633, 0.033864105186824284, 0.036403403750487735, 0.017041447705456188, 0.043473151712013144, 0.02458398529727544, 0.02264668300215687, 0.02198802905955485, 0.04699485023905124, 0.06395693309605122, 0.06293822811650378, 0.038851873616554906, 0.05125881179368921, 0.03683344228193164, 0.03667952339830143, 0.028201642246650796, 0.002752146517325725, 0.04690759063565305, 0.024535239341535738, 0.04412046054910336, 0.015302621992304921, 0.012490381869221372, 0.014743208885192871, 0.04078366281464696, 0.014997951287244047, 0.024640688772446344, 0.03765371987330062, 0.02439853658766619, 0.012221071320319814, 0.03618927506197776, 0.03462093636127455, 0.009726774895430675, 0.06252096979213612, 0.04137629529993449, 0.02996081892134888, 0.0483451824236129, 0.05013227402897818, 0.014157286263071, 0.04427025393982019, 0.02225643885321915, 0.020535904747833098, 0.06196828944874661, 0.035097149200737476, 0.06695765922112124, 0.05826648737170866, 0.03908764757215977, 0.029745255131274462, 0.06238597525017602, 0.06038801531706538, 0.07250090355851821, 0.013894317472087485, 0.030094093377036706, 0.012934524599196655, 0.026918027017797743, 0.02548652338529272, 0.019101715812991773, 0.02650129116539444, 0.060676983025457175, 0.010135702506106879, 0.11849765931921345, 0.0837220000103116, 0.16537080412464483, 0.3614460506609508, 0.8798757376415389, 17.466301713671, 69.018068586077, 90.15343952178955, 75.15516226632255, 54.25418186187744, 50.50775834492275, 66.49519157409668, 99.87681116376604, 111.27688734872001, 97.91251373291016, 61.66278893607003, 48.454409326825825, 59.48967729296003, 66.54915128435407, 37.918838432856965, 2.9214397966861725, 0.6621821075677872, 0.1895821142409529, 0.07980259175279311, 0.06036615970411471, 0.1538543278085334, 0.3204400624547686, 0.2601486162415573, 0.3671884653823716, 0.13230028296155588, 0.08089784905314445, 0.09341289821480002, 0.06485009552644831, 0.0519449464045465, 0.07437632685261113, 0.05989694595336914, 0.031841483898460865, 0.06158829626760312, 0.0601058126028095, 0.060562867006020885, 0.029636323119380643, 0.06891559237348181, 0.05697249394974538, 0.06193728039839438, 0.03251574753916689, 0.024097138117732744, 0.08793173983160939, 0.047193545648562055, 0.08059199260813849, 0.1736706444727523, 6.445693578038897, 0.4566013589501381, 0.12338476707892758, 0.05488121509552002, 0.08771238303078072, 0.01663716127430754, 0.017263964783134203, 0.037818949935691695, 0.043937337518270524, 0.02993301594895976, 0.08035512281847851, 0.03329771504338298, 0.07403100681092058, 0.025027893084500517, 0.17347431715045655, 0.03523777558335236, 0.009120755762393986, 0.02648572896474174, 0.049872177985629866, 0.06409776982452188, 0.021078893914818764, 0.11074515924389873, 0.1070506242769105, 2.372386630092348, 3.5183803822313036, 2.006835388285773, 1.4439915674073356, 0.666097417473793, 1.9794458065714156, 0.2931895804192339, 20.937310797827585, 48.07399892807007, 53.18163708278111, 45.87804855619158, 50.20518514088222, 84.03277833121163, 84.1706931250436, 61.237851006644114, 43.518898895808626, 35.93545430047171, 56.881931509290425, 76.16395037514823, 54.18244865962437, 10.637712018830435, 0.25755392547164646, 0.09594008832105569, 0.15007405994193895, 0.04025387963546174, 0.09477066714316607, 0.03120310797489115, 0.1411676499992609, 0.016705739112304788, 0.004397526084046278, 0.03973542120573776, 0.028046038899836794, 0.03164738556370139, 0.03255505846547229, 0.018244359675528746, 0.04080272625599589, 0.01570753606834582, 0.044604381546378136, 0.03240910558296101, 0.010184109194337257, 0.02741348819940218, 0.040571325458586216, 0.03408281737938523, 0.0022416483635814594, 0.01509462047501334, 0.013228898535349538, 0.023309355568406836, 0.04351764664586101, 0.06786659080535173, 0.04981037362345627, 0.014662346170682992, 0.08259922811495406, 0.06693781207182578, 0.03386216118399586, 0.03632682428828307, 0.02246054557950369, 0.024021454321752702, 0.026003244765368954, 0.02036099199072591, 0.023829284722783735, 0.02695857796684972, 0.061842353349285464, 0.12159944644996099, 0.17479712116931165, 0.1372289170644113, 0.08475881508950676, 0.10185626907540218, 0.11403369956782886, 0.08706892148724624, 0.1494688881295068, 0.11703490066741194, 0.12436094826885633, 0.1518611583326544, 0.12885808838265284, 0.14799770207277366, 0.16045077384582587, 0.1830545530787536, 0.1261172547404255, 0.12537389248609543, 0.14898397986377987, 0.07634518441877194, 0.15466012885527952, 0.13967918844095298, 0.1727952935865947, 0.12804267928004265, 0.1635196248867682, 0.1554168446787766, 0.23367945370929583, 0.07058373679007802, 0.17965657184166567, 0.07807132322341204, 0.11912814048784119, 0.2564078526837485, 0.24104386568069458, 0.1284849484051977, 0.1167162334812539, 0.24087124637195043, 0.09684701144163098, 0.18374287257237093, 0.08544714815382447, 0.1196720948708909, 0.09666266704776458, 0.0946988102846912, 0.18512184572006973, 0.2647590988448688, 0.2001315424484866, 0.24919174132602556, 0.47625281874622616, 11.41280094214848, 64.8306324822562, 111.91395378112793, 106.52365248543876, 75.25581387111119, 57.09740904399327, 50.35141345432827, 85.00414344242641, 121.48033087594169, 135.99703543526786, 128.05573081970215, 82.68476527077812, 65.1152445929391, 58.62629413604736, 58.21962996891567, 10.721560273851667, 0.670148814363139, 0.28887151926755905, 0.17930647491344384, 0.4107759807791029, 0.2949984462133476, 0.28715732267924715, 2.215266363961356, 0.8087145132677895, 1.0276995854718345, 0.38596534782222336, 0.2271211684814521, 0.22250746962215218, 0.17052203842571803, 0.28547908844692366, 0.15370118245482445, 0.09240319739495005, 0.24978347814508847, 0.303291772625276, 0.24067365697452, 0.12942001037299633, 0.20688589715531894, 0.17493964066462858, 0.1735562163272074, 0.13237489467220648, 0.21750549945448125, 0.1880766757364784, 0.09446215762623719, 0.17941873174692902, 0.27854057933603016, 8.747702990259443, 0.3900900807763849, 0.15932159657989228, 0.11912777407893113, 0.198433766407626, 0.23408136357154163, 0.14326969720423222, 0.17332060182733194, 0.07628383128238575, 0.10602774630699839, 0.1671300825795957, 0.14275916745620115, 0.17174566776624747, 0.12814080901443958, 0.2413236392395837, 0.08016739253486906, 0.06613750715873071, 0.11986481238688741, 0.2141669307436262, 0.2894825536225523, 0.1850860733538866, 0.3324079274066857, 0.3865566775202751, 5.26772769008364, 8.945515598569598, 3.7270185010773793, 1.6940243393182755, 1.8511913972241538, 4.16148545060839, 0.13700818962284497, 18.40159351485116, 49.783992290496826, 67.9494217463902, 67.23250661577497, 84.4719044821603, 106.49358068193708, 82.02369976043701, 59.848190443856375, 50.97193622589111, 54.546040943690706, 79.92920698438371, 96.55796241760254, 50.41470806939261, 4.367263734340668, 0.17272079044154712, 0.1913503222167492, 0.22506754153541156, 0.26383452702845844, 0.17901840965662683, 0.09813254353191171, 0.23443083624754632, 0.22839711287191936, 0.10538716175194297, 0.13149712820138248, 0.08749489898660354, 0.10821150948426553, 0.08554776132638965, 0.12732795120349952, 0.27213651154722485, 0.19549587262528284, 0.18410762585699558, 0.22674739068107946, 0.14392660052648612, 0.07763284032366105, 0.14316448356424058, 0.15765632236642496, 0.12843259264315876, 0.07330411260149308, 0.1619698509041752, 0.12215090543031693, 0.12962258021746362, 0.11378148810139724, 0.11081805426095213, 0.07448349467345647, 0.12458820321730205, 0.1993703075817653, 0.19943750969001225, 0.1267407469983612, 0.2685418501496315, 0.17559840317283357, 0.0852860300136464, 0.12424867786467075, 0.18206286057829857, 0.17253165559044906, 0.13395589483635767], [0.005152396292292646, 0.05730261480701821, 0.01848738038513277, 0.05545602246586766, 0.07589406041162354, 0.03579031343438795, 0.0398073900224907, 0.0424108271087919, 0.02557160998029368, 0.09556617481367928, 0.0210661238857678, 0.03817678216312613, 0.03984993077548487, 0.02323205685908241, 0.05821047430591924, 0.02633376935097788, 0.03883285767265728, 0.036115864358310185, 0.07087269771311965, 0.060043285600841045, 0.009009037516079843, 0.07011898101440497, 0.05581610403688891, 0.04681494685688189, 0.022560732971344675, 0.03299649977790458, 0.07254310165132795, 0.040798475234104056, 0.07248858136257955, 0.056828776840120554, 0.015921752966408218, 0.02413237444125116, 0.0399964095226356, 0.051294831825154166, 0.03728240854772074, 0.06404601795864956, 0.020807116891124418, 0.014439863019755908, 0.008211509507548596, 0.04730241998497929, 0.023415020434185863, 0.09411520231515169, 0.05220998896818076, 0.21289906091988087, 0.020232625039560453, 0.08048358985355922, 0.16571151012820856, 1.2695041703326362, 12.959152068410601, 52.46017435618809, 69.41367816925049, 67.35384995596749, 46.81776114872524, 31.787400586264475, 39.61857278006417, 63.365347726004465, 89.46664483206612, 124.74651227678571, 122.357971736363, 79.7728099822998, 36.32839230128697, 34.99607522147042, 6.577083579131535, 0.2875080167182854, 0.16074713080057076, 0.25831806446824757, 0.12237358705273696, 0.2354506743805749, 0.1633939194892134, 0.3241698880280767, 0.05974456734423127, 0.2160802095064095, 0.08605811465531588, 0.16806133118058952, 0.040560774239046235, 0.0573473031233464, 0.19659195095300674, 0.040730692978416166, 0.08051280757146222, 0.116641173937491, 0.11814212054014206, 0.06628588919660874, 0.11438857338258199, 0.08918528578111104, 0.11041735897638968, 0.05195087680060949, 0.042687750820602686, 0.12144744103508336, 0.048531440286231894, 0.08662857940154416, 0.025496850688276545, 4.430431544780731, 1.073891969663756, 0.15902485964553698, 0.1234799926834447, 0.028603545323546444, 0.06228917544441564, 0.06215263384261301, 0.059259828712259016, 0.019256555807909796, 0.1000471997207829, 0.06069201257612024, 0.06728366137083087, 0.04140507536275046, 0.040703134278633764, 0.033623398281633854, 0.05889994730906827, 0.057450650792036734, 0.049036806382771046, 0.08398530552429812, 0.10064478551170655, 0.030048373687480177, 0.08339413188930068, 0.12776199648422853, 0.08529721227075372, 0.12352344606603895, 0.17032434046268463, 1.5979894867965152, 0.4119981580546924, 5.004645006997245, 25.14792956624712, 49.56389767783028, 83.99524416242326, 94.41731275830949, 88.54037352970668, 75.71014962877545, 44.07053027834211, 22.63571456500462, 30.258682250976562, 54.34886496407645, 65.6982957295009, 55.10461010251726, 9.43450289113181, 0.027369478418092643, 0.022406530799344182, 0.09781720795269523, 0.039584026472376924, 0.044089454891426225, 0.029818781185895205, 0.07366538500147206, 0.07585659170789377, 0.06698165221938066, 0.054937679387096844, 0.041858234974954805, 0.03943742558892284, 0.031022736403558935, 0.06321291944810323, 0.024087102584806935, 0.01991158806984978, 0.06798698327371053, 0.03336689508120928, 0.043454668418105157, 0.07814642347927604, 0.03414778371474572, 0.03211896400898695, 0.02527840142803533, 0.017753288615494967, 0.032482458611152, 0.020230614879567708, 0.07846529422593967, 0.04276479507929512, 0.06662542811994042, 0.012475297187588044, 0.02461580858965005, 0.05077133866559182, 0.02866078993039472, 0.027262755037684525, 0.060486525031072755, 0.001486873998406476, 0.03835345232593162, 0.024043527065909336, 0.0018361870066395827, 0.028093113963093077, 0.037394624669104815, 0.045834928551422696, 0.028975324838289192, 0.024759254285267422, 0.0374297727830708, 0.0527269071234124, 0.018983185923259174, 0.02946468090106334, 0.10723787958600692, 0.02764329274318048, 0.06789765413850546, 0.01132329400362713, 0.013792886664824826, 0.053312228393874, 0.05935194662639073, 0.04085108205409987, 0.03616962129516261, 0.02952711290812918, 0.0184732346263315, 0.016105020185932517, 0.02239012042991817, 0.02751161963013666, 0.05513558769598603, 0.0866237957296627, 0.032064501395715136, 0.014989057389487113, 0.02030717907473445, 0.065890968245055, 0.004367883433587849, 0.021765618851142268, 0.02237232754539166, 0.09019939029323203, 0.014530075946822762, 0.040399696810969284, 0.01725002428117607, 0.020390718609892895, 0.006767223547545395, 0.014230495950739299, 0.09802460218114512, 0.034303086809813976, 0.022608761376302158, 0.025784208572336605, 0.005609284454424466, 0.016489756326856356, 0.049640315784407515, 0.01806936040520668, 0.11691028092588697, 0.10068105320845332, 0.042410409809755426, 0.5661893784999847, 9.161262375967842, 43.408241885049, 85.33585044315883, 74.41870185307094, 58.85463973454067, 46.1945355279105, 59.98645959581648, 75.83577305930001, 94.82144778115409, 113.91921779087612, 108.23640428270612, 81.34902272905622, 55.303127084459575, 59.7828426361084, 53.110254764556885, 11.140825867652893, 1.1401338151523044, 0.7538990889276777, 0.249474147600787, 0.263441655252661, 0.5984553471207619, 0.12214840842144829, 0.6713552496262959, 0.17835827650768415, 0.4331774615815708, 0.036099742366267104, 0.15249010601214, 0.07252146995493344, 0.08512255057160344, 0.12124252345945154, 0.022560220677405596, 0.053917318782103915, 0.07392121984490327, 0.05545922515115567, 0.05888073119734015, 0.06875009089708328, 0.2141724947307791, 0.12982406440590108, 0.029011470398732593, 0.045685097841279845, 0.05512858860726867, 0.04332896302055035, 0.15718391271574156, 0.06383939047477075, 4.059973571981702, 1.4490366109779902, 0.21095969927098068, 0.1384190403457199, 0.09400147306067602, 0.040852924276675494, 0.064284869070564, 0.017799883615225554, 0.025023263779335787, 0.06973567658237048, 0.027282101767403737, 0.06435918901115656, 0.021478299982845783, 0.05846441603664841, 0.07656269560434989, 0.04214759962633252, 0.08141593089593308, 0.016435704227270823, 0.09270920990301029, 0.11564405315688678, 0.02546368050388992, 0.06082236593855279, 0.1388748258884464, 0.26200047401445253, 0.21302488845373901, 0.7832043107066835, 1.9046931777681624, 0.5843606548649924, 11.18794594492231, 44.641588824135916, 61.88688918522426, 72.39667878832135, 82.80724811553955, 94.5767947605678, 103.88253102983747, 73.33889620644706, 45.14940139225551, 39.26798057556152, 48.952386719839915, 71.38451385498047, 76.26615837642125, 28.89103879247393, 0.37926693154232843, 0.027794360083394816, 0.02883077991594161, 0.046535783979509554, 0.11601483183247702, 0.07460903043725661, 0.059442449627178054, 0.07022927688168627, 0.03041678088318024, 0.08333263626056057, 0.05532799647854907, 0.008570812459635948, 0.05812231903629644, 0.08551167683409792, 0.03918915641094957, 0.0690310179655041, 0.06280457028853041, 0.02588497780795608, 0.036225247595991404, 0.08942108348544155, 0.05876910540142229, 0.02979934455028602, 0.013254866918681987, 0.02846811312649931, 0.029434615014387027, 0.04213957255706191, 0.03385002897786243, 0.042347943875938654, 0.025683390142928277, 0.0260670558948602, 0.03387218653889639, 0.037198283776108704, 0.050377747642674615, 0.00923218478315643, 0.07771830180925982, 0.0403449152862387, 0.015312684666631477, 0.06924530610974346, 0.03149635045390044, 0.05432779514896018, 0.0351393065814461, 0.024954779239903604, 0.02287345958341445, 0.08377362973988056, 0.11689835228025913, 0.14266965511654103, 0.21550996867673738, 0.23533814613308224, 0.1824682309691395, 0.09373966032373053, 0.12096162353243146, 0.11702169637594904, 0.1234053945434945, 0.15003640124840395, 0.1650046937699829, 0.0975036094231265, 0.10655821819922753, 0.17536858336201736, 0.07522242609411478, 0.1134209553045886, 0.10395343082823924, 0.11359746940433979, 0.09713794011622667, 0.1574404803769929, 0.14602996408939362, 0.11855229495891503, 0.09286525938659906, 0.15747113658913545, 0.13350016357643263, 0.108130750246346, 0.11212543517883335, 0.2288788998765605, 0.14958894811570644, 0.12608008459210396, 0.09942659123667649, 0.1609985823077815, 0.13774904129760607, 0.09897188456462962, 0.18961728949631962, 0.06970715097018651, 0.12369427404233388, 0.07803616153874568, 0.11944097227283887, 0.09050447999366693, 0.13816476613283157, 0.14282674954405852, 0.4939707794359752, 0.2820672243833542, 0.16670518395091805, 0.22286162418978556, 3.0277963067804063, 29.028710399355205, 92.6427914755685, 105.21640450613839, 93.35705239432198, 70.54569258008684, 57.94789287022182, 63.45062991550991, 85.51198032924107, 108.2172828401838, 146.34819766453333, 139.94359833853585, 95.7834050314767, 54.62243291309902, 63.44388321467808, 27.774188825062343, 2.063131647450583, 1.1853691935539246, 0.410719879503761, 0.44432055364762035, 1.786589218037469, 0.24066385892885073, 1.7580116029296602, 0.44892796927264755, 0.49403526740414755, 0.16967416820781572, 0.3563076135303293, 0.17355073376425675, 0.14163677554045404, 0.2580590269395283, 0.27280804408448084, 0.10589556090001549, 0.27137348534805433, 0.27879269580755917, 0.14028626015143736, 0.24606016650795937, 0.566271182681833, 0.23945766793830053, 0.20050743727811746, 0.12438304136906352, 0.27109762015087263, 0.1242563317396811, 0.21198462641664914, 0.09442440393779959, 6.654177316597529, 2.169695734977722, 0.42736730192388805, 0.2924722874803202, 0.11020779343588011, 0.11847980027752263, 0.13730698930365698, 0.12548290592219147, 0.06382567049669367, 0.1573534379048007, 0.15092239156365395, 0.1596558429300785, 0.09887819923460484, 0.13049153930374555, 0.16084637333239826, 0.10557934322527476, 0.14318603383643286, 0.18805332056113652, 0.3584734158856528, 0.4756859434502465, 0.10596961621195078, 0.17794982556785854, 0.4161408043333462, 0.2933335926915918, 0.20002090052834579, 2.1762331213269914, 3.4891223864895955, 0.4190587220447404, 9.649006809507098, 41.64744329452515, 81.22612994057792, 100.0070412499564, 102.91830866677421, 108.95016493116105, 105.20527349199567, 66.05653095245361, 47.11240298407418, 50.832496302468435, 72.31814329964774, 95.47429357256208, 80.63149615696499, 17.467988388878958, 0.137490519455501, 0.19094408330108437, 0.12842185821916374, 0.12414165932152953, 0.21464750995593412, 0.14861121986593517, 0.14577083156577178, 0.2204074173101357, 0.10910530295222998, 0.13198116794228554, 0.18372669629752636, 0.18000460602343082, 0.15778449763144764, 0.14470627797501429, 0.10802368420575346, 0.09915573362793241, 0.15659627424819128, 0.11058609706482717, 0.10170942731201649, 0.21383528996791157, 0.10270256509206124, 0.13308762785579475, 0.08557708760989563, 0.08784276353461401, 0.10298034375799553, 0.10299645896468844, 0.20428155761744293, 0.16978234026048863, 0.1422759419573205, 0.08721353765577078, 0.0948965082477246, 0.1831896629716669, 0.15538297221064568, 0.07421453017741442, 0.08424367130334888, 0.08008128644100257, 0.1311506682208606, 0.18401723142181123, 0.13250050507485867, 0.1318363957107067, 0.2087373070951019, 0.12423071025737695, 0.0866490915151579], [0.008945855727818395, 0.039057595256183825, 0.00584960841141375, 0.051946415432861874, 0.024589303315484097, 0.033199296931603124, 0.026424377524693097, 0.03387509745412639, 0.07555627889399018, 0.033754854263471704, 0.03698297104399119, 0.01491529554394739, 0.022368828001032983, 0.061980889844042916, 0.04211343199546848, 0.03410904275785599, 0.03160464803555182, 0.0264497784831162, 0.03808568883687258, 0.0685854647308588, 0.062443033259894164, 0.02435758530295321, 0.008252023137174547, 0.016648509772494435, 0.03739682651524033, 0.029128215741366148, 0.012383213200207268, 0.04303803434595466, 0.0482900073485715, 0.020154644402542284, 0.057788778362529616, 0.026746868255681226, 0.11326816957443953, 0.04017735445605857, 0.017461538913526704, 0.08649549832833664, 0.02389227652123996, 0.06285653928560869, 0.020006735642839755, 0.05849301628768444, 0.03148566013468163, 0.05668109030063663, 0.024286303502906646, 0.0224575040462826, 0.05069944788036602, 0.04417704697698355, 0.04297409938382251, 0.08234915403383118, 0.3754557631909847, 4.719644665718079, 29.65571062905448, 64.08270754132951, 82.22386346544538, 64.96574020385742, 42.946144989558626, 31.15576764515468, 42.10245997565133, 54.661408833095, 88.61585181100028, 115.37864521571568, 109.32275513240269, 65.06440462384904, 30.115090778895787, 6.744258974279676, 1.3971515893936157, 0.09643502533435822, 0.3629891478589603, 0.5135529743773597, 0.12715465335973672, 0.3233474764440741, 0.1878399620098727, 0.5400497668555805, 0.24965870912585938, 0.07672912667372397, 0.12516919204166957, 0.38873976894787377, 0.20030933219407285, 0.09338242520711251, 0.07766699099114963, 0.11041304349367108, 0.2041969443006175, 0.1389807994876589, 0.1547262045953955, 0.15307033487728663, 0.05224260953920228, 0.13565862418285438, 0.1390272927071367, 0.046201632624225955, 0.15694133644657476, 0.1462321946663516, 0.07767255497830254, 3.082972603184836, 0.8949018684881074, 0.21478080137499742, 0.06390087931816067, 0.12513132978762898, 0.03953477500804833, 0.15663588712257998, 0.0739919842619981, 0.07923999122743096, 0.019981792695554237, 0.07341611837702137, 0.10373544466814824, 0.18611607594149454, 0.03234238184190222, 0.05922803256128516, 0.0609888309346778, 0.03931401703240616, 0.08828576547758919, 0.02786885983576732, 0.15811339712568692, 0.06461952932711158, 0.0891614081338048, 0.030536437141043798, 0.048791024035641124, 0.3470992962164538, 0.13941493976329053, 4.599498152732849, 26.600688457489014, 45.29183251517159, 63.79315526144845, 90.03207533700126, 83.60218456813267, 70.22419943128313, 56.76575762884957, 23.8091767174857, 19.10002817426409, 38.7202228137425, 63.75507913316999, 53.06056819643293, 22.113255194255284, 0.958118370601109, 0.07357745364840541, 0.08991507054971797, 0.03478847344272903, 0.04820767390940871, 0.08247837424278259, 0.06275914915438209, 0.013680585726563419, 0.07306332766477551, 0.025292418265183057, 0.04502783150279096, 0.010843315294810703, 0.0608427423451628, 0.04561271172549043, 0.06809035808380161, 0.016670448505984883, 0.10930277699870722, 0.04400148282625845, 0.035713316673146825, 0.039763007046920915, 0.02865812328777143, 0.01283833377861551, 0.038780356025589366, 0.03665207326412201, 0.03949540979894144, 0.0369232226429241, 0.06466858062360968, 0.050517458003014326, 0.024017590064821497, 0.0614066253017102, 0.006637363819338913, 0.016612925699778965, 0.0382644997776619, 0.020424017715933065, 0.05189415127305048, 0.05340718258438366, 0.02468060189858079, 0.031184516115380184, 0.03407779961292233, 0.034638920931943824, 0.028562049514481, 0.022819704342899576, 0.024185135627963712, 0.021859434799158146, 0.01943344988727144, 0.02234770350956491, 0.004990734475930887, 0.04819383179502828, 0.046987294751618586, 0.034649176988750696, 0.02374730581816818, 0.04478652748678412, 0.029936330592525855, 0.020634024304204752, 0.04276242359940495, 0.023396097788853303, 0.02379207725503615, 0.0653005274278777, 0.05063779279589653, 0.03388354182243347, 0.04571915351386581, 0.04799862066283822, 0.0012577987737521262, 0.034848333802074194, 0.04780348416950021, 0.030677389220467637, 0.03452394995838404, 0.014487730272646462, 0.04392451659909316, 0.05179482392434563, 0.03800052929935711, 0.0156827203463763, 0.033601491778556786, 0.010869581385382583, 0.012451605289243162, 0.02521187106945685, 0.03772867763681071, 0.0377583533658513, 0.014859715044232351, 0.06344601658305951, 0.05901026353240013, 0.055066020893199105, 0.05478843900242022, 0.0699531470558473, 0.03859276823433382, 0.008749032226790274, 0.019941168803987757, 0.022403492658798183, 0.05929936694779566, 0.19000017323664256, 0.04774086556530424, 0.04121899391923632, 0.1392909578446831, 1.3576497776167733, 21.035553114754812, 65.55845628465924, 85.99046802520752, 74.73988233293805, 53.62630442210606, 51.63830321175711, 58.3090671811785, 69.34069429125104, 90.70098536355155, 111.25299249376569, 108.75784574236188, 68.1236686706543, 61.814600127083914, 50.15096834727696, 26.065791811261857, 6.895639376980918, 1.5486440317971366, 1.1413822110210146, 1.0352283929075514, 0.41678877813475473, 0.5599429479667118, 0.3290589228272438, 0.4443146368222577, 0.12093619203993253, 0.24627936046038354, 0.06493386067450047, 0.16061335083629402, 0.1888246384582349, 0.0930813660046884, 0.12864150000470026, 0.19007945326822145, 0.07026700342872313, 0.03704396794949259, 0.062263967868472846, 0.1881774788988488, 0.20578768822763646, 0.10947293322533369, 0.09493880812078714, 0.04668610662754093, 0.06563748113278832, 0.021409435463803153, 0.3025361288871084, 2.5938011833599637, 1.4291207939386368, 0.363458368395056, 0.08941254751490695, 0.06449064160031931, 0.049240997925932915, 0.07046089481030192, 0.056894496349351745, 0.01509229140356183, 0.03315961281103747, 0.07490471564233303, 0.07324964659554617, 0.046698137053421566, 0.11465371772646904, 0.13784227200916835, 0.1168995736432927, 0.11356409226677247, 0.0351523107050785, 0.026945712942896143, 0.10045016809765782, 0.11066450857158218, 0.108872144749122, 0.18362171335944108, 0.49053098687103813, 1.366142864738192, 0.15211516113153525, 9.033534509795052, 42.38107579095023, 68.60853481292725, 69.03506387983049, 85.22716672079903, 88.51870209830147, 94.25880350385393, 86.47409738813127, 48.338996274130686, 31.328110763004847, 41.29985966001238, 66.8236746106829, 76.82913616725376, 47.6354147366115, 6.931550272873469, 0.40006761252880096, 0.09463713145149605, 0.040672528956617625, 0.06649185850151948, 0.03330564711775098, 0.07894379033574037, 0.08914990017988852, 0.23325401225260325, 0.05237032000773719, 0.047286762789423974, 0.02813332394829818, 0.04210368823260069, 0.04226214651550565, 0.03991950097094689, 0.03944891318678856, 0.06386191783738987, 0.036007719447038004, 0.04444042034447193, 0.017661642283201218, 0.044057889442358694, 0.08228913082608155, 0.03445981143574629, 0.0555862265505961, 0.0722690210012453, 0.05226303683593869, 0.022062703534694653, 0.0472351432378803, 0.027919758443853686, 0.028350634966045618, 0.024517599127388427, 0.013343897498478847, 0.044639923210654936, 0.018457714834117463, 0.026192561124584506, 0.02950612242732729, 0.01591550026621137, 0.034189340591962845, 0.03847052675804921, 0.026835783484524915, 0.03417934916381325, 0.009174368510554944, 0.0021865833384384003, 0.010686380323022604, 0.043380772561899254, 0.1640039767537798, 0.18128221961004393, 0.14589995677982057, 0.24320692675454275, 0.16508203319140843, 0.11624742006616932, 0.14556129995201314, 0.12775800669831888, 0.14667100326291152, 0.10358262501124825, 0.11637969368270465, 0.09457787498831749, 0.17169347485261305, 0.1312434918114117, 0.11626190000346728, 0.2724202206092221, 0.16583636057163986, 0.09161311800458602, 0.092535857776446, 0.18762648132230553, 0.18848370175276483, 0.15386100459311688, 0.08570952407483544, 0.12094632935311113, 0.13414756740842546, 0.09924644018922534, 0.08610959510718073, 0.06778375525027514, 0.10876769106835127, 0.09044668916612864, 0.11489657898034368, 0.07342895625957421, 0.24525732387389454, 0.17881199930395397, 0.13529357234282152, 0.17145762965083122, 0.14420534271214688, 0.15290897924985203, 0.15266982279717922, 0.15923878816621645, 0.10978568358612911, 0.11171116240854774, 0.09820594745022909, 0.09797001403889485, 0.2849594663296427, 0.15232030940907343, 0.19126428397638456, 0.15752137532191618, 0.31976464869720594, 10.455463375364031, 60.69040938786098, 104.82482487814767, 105.92075729370117, 83.92278834751674, 67.85797650473458, 59.55112716129848, 68.4254845210484, 77.02108015332902, 111.45311450958252, 134.38284383501326, 129.91216441563196, 88.03949873788017, 62.07711001804897, 40.40503590447562, 19.070366314479283, 2.104573526552745, 1.170643572296415, 1.2337581855910165, 0.5498513409069606, 0.9693235350506646, 2.025372096470424, 1.362079905612128, 0.2291061005422047, 0.2556862442621163, 0.3047844411006996, 0.5551013020532471, 0.37832040233271463, 0.18743901566735335, 0.10905983432063035, 0.26486543885299135, 0.27081011129277094, 0.17803552454071386, 0.5150722414255142, 0.38091919145413805, 0.1988890634051391, 0.22594099252351693, 0.25876703751938684, 0.08877942005970649, 0.21218650415539742, 0.24146974139979907, 0.3730149098805019, 4.8826654723712375, 2.8172504731587003, 0.4459306358226708, 0.2025389846946512, 0.433354559221438, 0.13759824367506163, 0.37361443628157887, 0.13214377207415445, 0.19864838703402452, 0.11051780930055038, 0.19947526337844984, 0.2656571806541511, 0.34901051223278046, 0.2462322429886886, 0.23523172470075743, 0.1502744856157473, 0.16190707284424985, 0.1459802139018263, 0.3078259064682892, 0.42896823744688717, 0.23937461525201797, 0.1944124014782054, 0.20213080516883306, 0.4326164216867515, 1.8945713894707816, 0.1709985871400152, 8.992888416562762, 49.40595122746059, 74.31123406546456, 92.00407832009452, 95.83327920096261, 102.58510780334473, 95.87373856135777, 81.82914325169155, 45.07825183868408, 37.160310540880474, 59.629412514822825, 91.53466497148786, 91.92780794416154, 37.42000641141619, 2.2531824665410176, 0.33644260519317215, 0.19037975929677486, 0.10492381732910872, 0.09956080546336514, 0.21562518392290386, 0.17170861975422927, 0.2000694022114788, 0.27888226243002073, 0.13317771016487054, 0.15866625388818129, 0.08362256070332867, 0.14405108456100735, 0.18547310972852366, 0.10740047014717545, 0.21754678152501583, 0.22502137401274272, 0.11578816042414733, 0.09549098634826285, 0.1555919609963894, 0.165418111586145, 0.1625007502734661, 0.14749874813216074, 0.15245590784720012, 0.16909012597586426, 0.2587564252316952, 0.13764461475823606, 0.13813466631940433, 0.08408788644841739, 0.1036278357995408, 0.11140094976872206, 0.10783150273242167, 0.10684365074017219, 0.21198811408664497, 0.0903321931670819, 0.1491764938192708, 0.20809694645660265, 0.09129359586430447, 0.1513776478490659, 0.10742161329835653, 0.07831612508744001, 0.08662421642137424, 0.12318683841398784, 0.08960126845964364, 0.14778420781450613], [0.01793342100323311, 0.08043994648115975, 0.06661938915827445, 0.05927486504827227, 0.026594947657680938, 0.03947273315861821, 0.03741666009383542, 0.010511495555484933, 0.009495726936230702, 0.03243158884080393, 0.020295840754572834, 0.03876546218193003, 0.04372221816863332, 0.038709991944155524, 0.05060441226565412, 0.037407923955470324, 0.06641253775783948, 0.018765846067773442, 0.08925249467470817, 0.021801170693444352, 0.06617468409240246, 0.03509849948542459, 0.01473308853538973, 0.02628315063858671, 0.009879600489512086, 0.03899694440354194, 0.02411724819934794, 0.011861800598645849, 0.036247808885361464, 0.00855396528329168, 0.15638321425233567, 0.023054379071774225, 0.019282438526196138, 0.022484399478084276, 0.037611124837504964, 0.006663693946653179, 0.06924650711672646, 0.07856343074568681, 0.03398276399821043, 0.05615722733948912, 0.09613458359880106, 0.04205783283604043, 0.04659301840833255, 0.060279320792428086, 0.05153772022042956, 0.03830101513969047, 0.26843192747661043, 0.039936060618077, 0.06275640108755656, 0.029240160448742763, 1.0772011578083038, 10.799228974751063, 54.95661694662911, 79.1293512071882, 89.97957474844796, 68.17821897779191, 46.72583648136684, 39.4978790964399, 45.478131089891704, 72.16847215379987, 83.32450675964355, 103.90297263009208, 94.15125233786446, 51.574070589882986, 30.836216517857142, 23.94918291909354, 9.267006141798836, 1.5817158286060606, 0.10217216783868414, 0.6846716893570763, 0.06114765562649284, 1.149830243417195, 0.6382565828306335, 0.49038002640008926, 0.054928868609879694, 0.24284993591053144, 0.23748253392321722, 0.19267596251198224, 0.05653696607000061, 0.34416783494608744, 0.3031292227762086, 0.2798363912318434, 0.22245682376836026, 0.05730817200882094, 0.1145786853241069, 0.2090110552630254, 0.2899576095598084, 0.17078663994159016, 0.0923806293202298, 0.04904318800462144, 0.07999812518911702, 0.7716926655599049, 1.2743131922824043, 0.3018478501055922, 0.32181995841009275, 0.09486491565725633, 0.09716877274747406, 0.17598725802132062, 0.16561887652746268, 0.11083464444215808, 0.09870095231703349, 0.06001560815743037, 0.018013905434470092, 0.06153233748461519, 0.09581009458218302, 0.09302827742482934, 0.12141982465982437, 0.09202464949339628, 0.06992007525903837, 0.16888440772891045, 0.20403510012796947, 0.032295213480080874, 0.12267018828008856, 0.2941708506218025, 0.04192892814587269, 5.5953361221722195, 31.08578191484724, 55.20601558685303, 59.694676944187705, 74.8431534085955, 79.91635281699044, 82.8039060320173, 63.81964179447719, 34.71384286880493, 27.985980340412684, 32.87369932447161, 56.80892331259591, 54.73314550944737, 27.483599526541575, 2.5992772323744635, 0.07682815885969571, 0.06592180766165257, 0.05992026720196009, 0.03339496946760586, 0.041712146385439804, 0.09466273257774965, 0.039379444771579335, 0.045908301935664246, 0.011300667405261524, 0.09523077495396137, 0.030758877883532217, 0.028314721803846102, 0.034897123862590106, 0.02813122557875301, 0.05230675145451512, 0.040229944312678914, 0.011269920439060246, 0.07363155324544225, 0.05167150018470628, 0.03159277706540056, 0.016011085494288375, 0.04159037309831806, 0.018478396581485868, 0.021523101953789592, 0.07000052237084933, 0.005455781597577567, 0.006746056223554271, 0.039999771663653, 0.03625145261841161, 0.05469853311244931, 0.07931365298905543, 0.02118851972876915, 0.07695375569164753, 0.07508879540754215, 0.060706953917230876, 0.06541399205369608, 0.015169717338202255, 0.03586210922471114, 0.008872207536894296, 0.05608903796279004, 0.018495843413152864, 0.02433306983272944, 0.025295161242995943, 0.05409839942253061, 0.023705072102269957, 0.036624565454466004, 0.11884436357234206, 0.03029319251488362, 0.07784648385963269, 0.037401583045721054, 0.02561446794840906, 0.043131251486816576, 0.028332382374043976, 0.036082907912454436, 0.014965541062078305, 0.0289782323608441, 0.07705198720629726, 0.02563584689050913, 0.05656993269388165, 0.005411667067424527, 0.022706433099561503, 0.02613522152283362, 0.04240220292870488, 0.018642837846917764, 0.11611342297068664, 0.039355126076510975, 0.03529549516471369, 0.03759237012958952, 0.09380444684731108, 0.01316169133808996, 0.020025912738804306, 0.04076598358473607, 0.048085374757647514, 0.07458889151790313, 0.045800750742533376, 0.053625100890972784, 0.06464240952794041, 0.04321784273322139, 0.10417561033474547, 0.051494850377951346, 0.01599275995977223, 0.0317982917518488, 0.0631963631936482, 0.04420167440548539, 0.0408603508424546, 0.0485543815552124, 0.025230026970218335, 0.04165254726207682, 0.011879731734682406, 0.00030634787929427276, 0.026751731655427387, 0.08451474604329892, 0.012660881604201027, 0.016205473902768323, 0.05433334895808782, 0.13163496580507072, 4.7540695156369885, 34.609494822365896, 83.34578214372907, 87.36966460091728, 76.5362765448434, 57.57181814738682, 54.55382987431118, 54.92997407913208, 72.4472964150565, 96.81852681296212, 110.05688095092773, 100.89996814727783, 73.5588275364467, 54.86354235240391, 48.40617493220738, 39.060375349862234, 13.797593797956194, 2.6572273799351285, 0.45206109115055626, 1.5988522576434272, 0.3541214279830456, 0.8118743151426315, 1.916806276355471, 1.1353217533656528, 0.04604384269831436, 0.2836737238935062, 0.2683718635567597, 0.21229076784636292, 0.16280005207019194, 0.2661977559328079, 0.09220744004206997, 0.052967851515859365, 0.20497443686638558, 0.8219211931739534, 0.31628919233168873, 0.609219355242593, 0.17546004988253117, 0.11677850942526545, 0.0722259475982615, 0.24628617295197078, 0.12424376527113573, 3.9734276788575307, 0.9499267701591764, 0.348879690681185, 0.2408692921910967, 0.27569377209459034, 0.03988805087283254, 0.07135088169681174, 0.16357736821685517, 0.11803288997284003, 0.0768514054694346, 0.06517130043357611, 0.02203516349462526, 0.059191174539072175, 0.16387358946459635, 0.24382930621504784, 0.2874974315719945, 0.2428797371685505, 0.27709402410047396, 0.12810544376926764, 0.13005560769566468, 0.1776645015925169, 0.18693048081227712, 0.5425041637250355, 0.4008195921778679, 12.959893788610186, 42.705285685403005, 67.19611889975411, 71.0694477898734, 70.83559921809605, 80.95064776284354, 89.16166060311454, 86.3857649394444, 55.32199491773333, 41.60365922110421, 33.44247538702828, 54.62963819503784, 71.58968026297433, 54.31921352658953, 15.140734434127808, 0.8251111220036234, 0.09610681794583797, 0.022251799370029142, 0.02608165966479906, 0.02157543905611549, 0.07362018099852971, 0.053583476160253794, 0.02550880647530513, 0.10439113341271877, 0.09725037336881671, 0.061350476528917036, 0.03774538995432002, 0.02152879146992096, 0.08711210345583302, 0.041656903456896544, 0.12137684625174318, 0.0908338680331196, 0.08466726035944053, 0.036925400740333965, 0.007670500814648611, 0.060075013898313046, 0.010693513422406145, 0.028812093061528037, 0.023247427373592342, 0.007107665770620639, 0.03699937802074211, 0.024308513650404553, 0.04292645604748811, 0.010000012465752661, 0.043772436545363495, 0.054895569503839524, 0.010334561612190945, 0.05468194293124335, 0.09149366869990315, 0.06700951965259654, 0.06134949265314, 0.05824839084276131, 0.022725947766697834, 0.036899002335433445, 0.06363667135259934, 0.014110106026886829, 0.048886324279010296, 0.022631933347189, 0.05547690438106656, 0.06348504591733217, 0.014997240521812012, 0.1575516922665494, 0.16974168244217122, 0.14147312646465643, 0.09872353396245412, 0.13180279465658323, 0.11153200202222381, 0.0800523062103561, 0.14272175303527287, 0.10485264579100267, 0.11895290203392506, 0.126752784209592, 0.19670523915972027, 0.1059183461059417, 0.11956788546272687, 0.13441098827336515, 0.09608622440802199, 0.17759244117353643, 0.19676518094326767, 0.238819953586374, 0.1760607162224395, 0.1514516081660986, 0.12509937078825065, 0.21153228783181735, 0.11035858427307435, 0.20251995857272828, 0.10238741950264998, 0.16827766171523503, 0.20600091107189655, 0.1742308158427477, 0.11026212373482329, 0.23785119556954928, 0.14468881248363427, 0.1540988582585539, 0.10166911554655858, 0.14343053714505263, 0.11298980058303901, 0.17278778898928845, 0.0857060296194894, 0.11534652912190982, 0.1038492282054254, 0.2968798881130559, 0.16650431044399738, 0.09718125779181719, 0.20049419227455342, 0.09775012119540147, 0.2775260609175478, 0.38738174896155086, 0.15094874586377824, 0.15477505911673817, 0.12066096466566835, 1.0854902501617159, 22.034497363226755, 83.42989008767265, 114.86149774278913, 117.50528035845075, 91.13638033185686, 73.09265899658203, 66.13073076520647, 70.85858385903495, 91.97436782291958, 107.00491251264299, 130.17187418256486, 115.27482523236955, 79.76233904702323, 59.67634759630476, 57.860814571380615, 21.65047911235264, 4.048356183937617, 0.3339835400027888, 2.1740772255829404, 0.7956565682377134, 2.661559581756592, 1.011857909815652, 1.2792244830301829, 0.1163309205855642, 0.38948556035757065, 0.3068485717688288, 0.2425796075591019, 0.2286673869405474, 0.43611375402126995, 0.39427653327584267, 0.40493661697421757, 0.5497728479760033, 0.9727963315589088, 0.3021393487496035, 0.7940431748117719, 0.3189966013388974, 0.7199863429580415, 0.24526617197053774, 0.6524141345705304, 0.16294742987624236, 2.9613133370876312, 4.806487594332014, 0.8259417031492505, 1.4426886716059275, 0.789711244404316, 0.16805012178208145, 0.3650686948427132, 0.33059116346495493, 0.1640010183410985, 0.18733856534319265, 0.14900212389017853, 0.12358445993491582, 0.22501872772617, 0.3579632932586329, 0.3392259015568665, 0.3833007679453918, 0.48017116848911556, 0.5041723634515489, 0.4680891739470618, 0.3643126168421337, 0.30288003757596016, 0.2495174924177783, 1.125054921422686, 0.21981570763247354, 14.519810404096331, 49.87594822474888, 79.88104901994977, 79.05645765577043, 90.70426491328648, 90.33444704328264, 97.55207593100411, 83.49425819941929, 54.7740148135594, 48.640746116638184, 56.0722370828901, 84.81679916381836, 92.49576759338379, 51.36260911396572, 7.025861646447863, 0.2359548530408314, 0.10965578484215907, 0.18973208405077457, 0.22511566323893412, 0.06967553802366767, 0.23121322318911552, 0.16118475874619825, 0.20153347722121648, 0.16675713259194577, 0.3118163709129606, 0.1256724614650011, 0.11009975709021091, 0.13179193809628487, 0.21530730383736746, 0.10583169039871011, 0.17978558849011148, 0.17545030611966336, 0.14279644617012568, 0.09800649208149739, 0.1265477037855557, 0.11811002583375999, 0.10987516878438847, 0.06937497415180717, 0.18129432467477663, 0.13827646656760148, 0.10997909320784466, 0.07190188605870519, 0.12140857454921518, 0.1305038479289838, 0.1026400855875441, 0.19141908495553903, 0.090001305565238, 0.15987760174487317, 0.1511402962995427, 0.2040752558303731, 0.09367021904992205, 0.18111876052405151, 0.19656368318412984, 0.13133680394717626, 0.19340928244803632, 0.16422885682966026, 0.109393659979105, 0.12496991987739291, 0.16763530618378095, 0.12944952664630754, 0.1715924409883363], [0.09186828109834876, 0.05087690853646823, 0.056016665417701006, 0.03655213862657547, 0.07937799846487385, 0.05617568349199636, 0.04737694348607745, 0.06376251245715789, 0.06936940337930407, 0.019558461482769678, 0.044993575662374496, 0.015988977127043263, 0.03318221141983356, 0.06959721472646509, 0.03862517506682447, 0.016562505458880748, 0.031347771640866995, 0.008676531608216465, 0.06839449783521039, 0.01456248786832605, 0.10334264074585267, 0.05949905301843371, 0.01803945906327239, 0.022257544865299548, 0.05053022803206529, 0.021034383713932972, 0.008050509262830019, 0.04144190963623779, 0.01692781683855823, 0.02974521102649825, 0.021706667728722095, 0.05168322866250362, 0.013007533270865679, 0.015175308466755917, 0.028564074941511666, 0.025243355094322135, 0.07889328697430235, 0.04372550227812358, 0.025777648835043823, 0.03579924974058356, 0.04464374675548502, 0.03020063355298979, 0.04279653016211731, 0.0725785686767527, 0.09707947753901992, 0.04815321129613689, 0.04626254810552512, 0.050160911599440236, 0.008819688078282135, 0.09430277653570686, 0.11646552836256367, 0.26044622170073645, 0.6073227141584668, 15.369788748877388, 41.34449141366141, 55.091603074754985, 65.82159846169608, 70.6521737234933, 52.48334659848894, 50.640847614833284, 61.982572828020366, 80.06831686837333, 87.02878597804478, 99.3350601196289, 84.45526354653495, 69.15090424673897, 51.39929212842669, 38.00143166950771, 22.690996170043945, 6.810170020375933, 0.10056264884769917, 1.3106380488191332, 6.962711640766688, 0.7868340930768422, 0.466975887971265, 0.8425915954368455, 0.5147316711289542, 0.2982589698263577, 0.15442424294139656, 0.28248514767204014, 0.2616558053663799, 0.2626666325543608, 1.0112530908414294, 1.9443817223821367, 5.016024853502001, 4.634986511298588, 2.6016044446400235, 0.22966714043702396, 0.3445326153721128, 0.43494862797004835, 0.2693272408630167, 3.5566847154072354, 0.14301661721297673, 0.7332060507365635, 0.2358719360615526, 0.30701771697827746, 0.1876791627811534, 0.5503287581460816, 0.6188233941793442, 0.39667510028396336, 0.41813138180545395, 0.3812527321279049, 0.23036633006164006, 0.16097167160894188, 0.15892065023737295, 0.6446715071797371, 0.36491198039480616, 0.31788744085601395, 0.1775831181023802, 0.042760876539562426, 0.2614185352410589, 0.2883789842682225, 0.2638936681406838, 2.0717317802565436, 19.9638386453901, 57.01404455729893, 78.57954720088414, 78.38776997157505, 87.46459089006696, 73.35275786263603, 64.17067868368966, 44.07474088668823, 32.581718649183, 39.67508247920445, 55.75813681738717, 61.67530958993094, 40.47874934332711, 10.806498527526855, 0.2031872027686664, 0.09572193931256022, 0.06368967850825616, 0.025301128958484957, 0.0022043641365598887, 0.03330045632485833, 0.02548013667442969, 0.057995405846408436, 0.07772518215434891, 0.019341930780293684, 0.032301374578050206, 0.08674777764827013, 0.04221557865717581, 0.04618379733126078, 0.026781163111861263, 0.035667033799524815, 0.02492501530131059, 0.012613256079410868, 0.08554225162203823, 0.029910176460232054, 0.037283986141639094, 0.0248603729664215, 0.05121509717511279, 0.021855550186176385, 0.040525917895138264, 0.048602306483579535, 0.013421272542992873, 0.08092286663928203, 0.03777022094332746, 0.031603165436536074, 0.013640944014436432, 0.06778411487383501, 0.07454338895955256, 0.024485653698710457, 0.030301307793706656, 0.018680404938225235, 0.001329012932339018, 0.03795831763584699, 0.05587090591767004, 0.021416946846459593, 0.022714170095111643, 0.029752518848649094, 0.039818212656038146, 0.02626856043934822, 0.047535242313253026, 0.05078803401972566, 0.040147088401551755, 0.04370357541899596, 0.016956847959331105, 0.024751235697684542, 0.0445850229422961, 0.060997142988656244, 0.04102042743137904, 0.018255396047607064, 0.04267724370583892, 0.03919443202071956, 0.04588405109409775, 0.02739187516272068, 0.08732669694083077, 0.01965351914986968, 0.027189575035923293, 0.008601757049161409, 0.07452275470963546, 0.06493267323821783, 0.034390370161937814, 0.012963260557236416, 0.038647617612566264, 0.04399805961708937, 0.010117087746039033, 0.04086012692589845, 0.007902938074299266, 0.009844353987968393, 0.00917711403287415, 0.11651880693222795, 0.004706063166460288, 0.05587907887196966, 0.06886320947004215, 0.02857179327734879, 0.10545624340219156, 0.0262579023505428, 0.060198704046862464, 0.01872146309220365, 0.05452098424679466, 0.05161533784121275, 0.04833951326353209, 0.022746073115350943, 0.014582491080675806, 0.01882907874616129, 0.06883458886295557, 0.03411543795040675, 0.011075914554697062, 0.03166764661935823, 0.014545612702412265, 0.04737836162426642, 0.05747036223432847, 0.04717904535521354, 0.036638173474265, 0.1467728242278099, 0.049392141601336856, 1.5054820392813002, 6.178246123450143, 40.698486123766216, 83.53336266108921, 88.26514843532017, 72.19393035343715, 62.399763516017366, 57.24966491971697, 69.10862445831299, 76.0684334891183, 101.83621706281389, 108.2750779560634, 84.71955912453788, 70.29214586530412, 69.6229579108102, 64.16337612697056, 51.914772033691406, 31.309854371207102, 8.466447728020803, 0.28161844132202013, 1.863099741084235, 3.9011942063059126, 1.3089581046785628, 1.1260139899594444, 1.6380210987159183, 0.9253667337553841, 0.5594093480280468, 0.5265109847698892, 0.7407459861465863, 0.7421669470412391, 1.0772431726966585, 4.321494647434779, 4.755273725305285, 5.074913442134857, 5.301411688327789, 3.4562986620834897, 2.0999495003904616, 1.2002769878932407, 1.5451972910336085, 2.310934807573046, 3.2938693208353858, 0.26875705431614605, 0.6567921510764531, 0.26401032188108986, 0.24532601875918253, 0.28846977225371767, 0.8734383402126176, 0.5501272603869438, 0.6320858768054417, 0.48198166276727405, 0.05693113724035876, 0.4099310961152826, 0.41837975276368006, 0.22400182086442197, 0.5870025445308004, 0.3378285808222634, 0.11894021342907633, 0.06632573955825397, 0.11467590582157884, 0.4190408358616488, 0.5759570258004325, 0.36747757558311733, 5.234458846705301, 47.74124622344971, 85.7183209827968, 81.12694440569196, 75.9511409487043, 79.58459023066929, 81.82005500793457, 81.72630296434674, 71.87414646148682, 44.79186446326119, 43.43273081098284, 57.658979824611116, 76.812655040196, 73.03847694396973, 30.624529225485666, 2.1417667993477414, 0.31443627604416435, 0.04948231551264014, 0.06820217386952468, 0.04278167024520891, 0.0370382886113865, 0.04407230831150498, 0.07835611115608897, 0.05549010867252946, 0.027742131546671902, 0.08590178018701927, 0.04053771083376237, 0.03522932782237019, 0.07538970533226218, 0.09580670869243996, 0.05065060014437352, 0.02744162026127534, 0.013369619064698262, 0.009449057297648063, 0.011974620616196521, 0.05708080849477223, 0.038661782031080554, 0.028310972897868072, 0.10024395452014037, 0.060789714833455424, 0.031014790758490562, 0.037808452998953204, 0.012355853820086589, 0.026803868589922786, 0.0339554699270853, 0.030851779505610466, 0.04851735389924475, 0.010850051451208336, 0.020146742862250124, 0.02099810923183603, 0.007641854762498821, 0.10613965030227389, 0.07398190801697117, 0.08291327447763511, 0.10519416603658881, 0.032752508763223886, 0.027218758827075362, 0.04015385000301259, 0.027196777685146247, 0.10833904692637068, 0.04138915014586278, 0.05295416546453323, 0.07393478375992604, 0.195194168814591, 0.1648340015006917, 0.12126028750623975, 0.17491891820515904, 0.22215833621365683, 0.13897641615143844, 0.1239455762718405, 0.11782869164432798, 0.13174382996346268, 0.08671643611575876, 0.16508739361805574, 0.12544621074838297, 0.11880546994507313, 0.1651002722127097, 0.19841311180165835, 0.16546431982091495, 0.20291673871023314, 0.21430968094084943, 0.13762372945036205, 0.11129830777645111, 0.3401442308511053, 0.1575594139950616, 0.15319202334753104, 0.1015145859814116, 0.07357436631407056, 0.17871296033263206, 0.08488889025258166, 0.13544415283415998, 0.14520592402134622, 0.11954021480466638, 0.21397057627992971, 0.11791388850126948, 0.18681678548455238, 0.09807517339608499, 0.3035327339810984, 0.18201114263917717, 0.113081782790167, 0.111599285554673, 0.1143860492323126, 0.1432667930743524, 0.14663969565715107, 0.12346684267478329, 0.1988137595887695, 0.15024247233356747, 0.1444919966161251, 0.1475163357598441, 0.08312175436211483, 0.28266349381634165, 0.2210281818572964, 0.2880581457700048, 0.21830421659563268, 0.41060195011751993, 1.1313351158584868, 24.233610902513774, 77.3368479864938, 108.0688693182809, 107.23842062268938, 94.66974776131767, 75.66237381526402, 79.97830295562744, 87.61509581974575, 101.77250902993339, 113.17534364972795, 125.50531114850725, 115.47676072801862, 101.77836636134556, 74.7871926171439, 57.747131620134624, 37.140942437308176, 9.049577031816755, 0.22265070836458886, 3.120033425944192, 14.659121785845075, 4.078565648623875, 0.7303635318364415, 1.4986265557152885, 1.4044587058680398, 0.850463361612388, 0.49157451944691793, 0.46331098462854114, 0.8047348239592144, 0.5409404933452606, 2.3075314930507114, 6.433309282575335, 8.34634724685124, 8.781997561454773, 4.495760244982583, 1.9458925213132585, 1.15847347676754, 1.0531651675701141, 1.065630778670311, 7.783749001366751, 0.8745121625917298, 3.612112884010587, 2.67063045501709, 1.2959688816751753, 0.8727379835077694, 0.9166697604315621, 2.090126918894904, 1.0750843456813266, 0.9238437754767281, 0.48451390117406845, 0.7942432069352695, 0.6400478067142623, 1.0658057864223207, 2.6538644518171037, 1.5090949939829963, 0.7511576446039336, 0.162875518734966, 0.18090200929769448, 0.8885969210948262, 1.0048739931413104, 0.39684307841317995, 7.95094176701137, 47.75556298664638, 84.20892211369106, 106.16163049425397, 98.61387184688023, 100.53443036760602, 86.7346270424979, 87.17309311458042, 69.50747190202985, 52.693939549582346, 60.97698783874512, 87.95810059138707, 104.29829733712333, 78.87615885053361, 21.46133177621024, 0.5091774005975042, 0.3935490623116493, 0.16708557068237237, 0.07640490907111339, 0.17113725255642617, 0.10221302921750716, 0.21231777354010514, 0.20153545854347094, 0.17009396425315312, 0.10927365427570683, 0.20941162162593432, 0.12912009789475373, 0.12593855575791427, 0.1304185696478401, 0.20626959736858094, 0.07961837628058024, 0.10365801703717027, 0.08898034784942865, 0.18225793939615997, 0.13067540872309888, 0.19062430331749575, 0.16525150409766606, 0.08157645871064492, 0.15976154511528357, 0.13105812961501734, 0.16252019708710058, 0.08518328624112265, 0.09778323370431151, 0.1320669754807438, 0.09880379108445984, 0.12696450070611068, 0.17628280073404312, 0.1877459306269884, 0.0950641403240817, 0.14499876728015287, 0.11869755573570728, 0.16991181831274713, 0.13501975632139615, 0.21676168936703885, 0.15093544657741273, 0.1428094876131841, 0.0648466892806547, 0.0758245512843132, 0.09610437521977083, 0.13687982436801704, 0.17306271780814442, 0.21973114859844955, 0.15623513076986584], [0.06892170597399984, 0.0021684352832380682, 0.04547618369438818, 0.019944055970492106, 0.010127731415975307, 0.06229274453861373, 0.005803439192407365, 0.014138111711612769, 0.06073825473764113, 0.03273520612024835, 0.02139308107351618, 0.01724196837416717, 0.03398696752265096, 0.02128124493174255, 0.038812192888664346, 0.07411069396351065, 0.03504048474133015, 0.038056420228843174, 0.054705728976322074, 0.03333252728251474, 0.012807468916954739, 0.02723602415062487, 0.046252010456685505, 0.04860360587814024, 0.03777770857725825, 0.07024182977953128, 0.06215799426926034, 0.004433714901097119, 0.06977186964026519, 0.017171731518049325, 0.013542958468730961, 0.03173395645405565, 0.0309816375374794, 0.07396221693073, 0.01772334486512201, 0.04304912160815937, 0.1052152549049684, 0.03973446786403656, 0.03024305895503078, 0.056142472595508607, 0.018850583217239807, 0.035397872528327365, 0.051746617403945754, 0.06095839185374124, 0.052102732937783, 0.08185120432504586, 0.05051370909703629, 0.04023643110745719, 0.038667624217591116, 0.0882727579612817, 0.16335985703127726, 0.05684375889333231, 0.08611053148550646, 0.3956391673002924, 0.9406536391803196, 5.655223948614938, 21.643944331577845, 45.25049420765468, 72.58059760502407, 73.67634241921562, 61.994405610220774, 47.37035485676357, 49.30569566999163, 55.15159034729004, 70.58381039755685, 91.44203853607178, 90.12478515080043, 72.45978232792446, 69.39271545410156, 55.689429555620464, 42.33165325437273, 20.51901708330427, 6.906515044825418, 0.7904131753104073, 3.392069080046245, 3.836851281779153, 1.6743133855717522, 0.5444175781948226, 0.46547116871391025, 0.601393132337502, 3.0982069628579274, 1.3681709787675311, 7.493269136973789, 3.1106824534279958, 0.5630510726145336, 0.6076176869017738, 0.9990339236600059, 3.2381452023983, 3.378748731953757, 1.6007341338055474, 2.7587592346327643, 2.9084998624665395, 0.13577605145318167, 0.13409643300942012, 0.212365433839815, 0.11510343716612884, 0.1741028441382306, 0.7562120790992464, 0.7676354061279977, 0.9481420602117265, 1.3473234517233712, 0.4982726371714047, 0.19907713974160807, 0.8199449735028403, 1.0756481268576212, 0.6187073375497545, 0.7521671418632779, 0.7269858930792127, 1.0864926363740648, 0.7885911730783326, 1.6585678990398134, 1.5853252006428582, 3.1240599070276533, 25.18062084061759, 38.83944000516619, 68.93953309740338, 91.19054848807198, 79.23301138196672, 54.88435915538243, 52.561809131077354, 47.370281900678364, 43.79199436732701, 55.61085932595389, 64.27349117824009, 49.31479433604649, 16.53528652872358, 1.199246374624116, 0.17918747344187327, 0.04980508105031081, 0.03542327687942556, 0.08297263950641666, 0.11721965218228952, 0.17343124374747276, 0.03694558037178857, 0.07079522937004055, 0.13075151321079048, 0.094090144016913, 0.03431485599971243, 0.04774185622643147, 0.052104514092206955, 0.02919080720416137, 0.017958380913894092, 0.04331966369811978, 0.043819574373109, 0.0917892928368279, 0.033192755854023356, 0.05684995391805257, 0.00971832119726709, 0.017738630562754612, 0.009377646575947958, 0.06592693060104336, 0.056838337398533306, 0.024541037423270087, 0.0612823176862938, 0.03273833416668432, 0.062040003814867566, 0.03010189313707607, 0.03580068823482309, 0.0631286861108882, 0.011381671763956547, 0.05517249660832541, 0.02584587722750647, 0.00813946096293096, 0.043754136455910544, 0.07272088461156402, 0.07470975896077496, 0.07463974093220063, 0.03926432112764035, 0.07271658948489598, 0.039645576383918524, 0.0290395821045552, 0.031234079705817357, 0.024652905795457106, 0.053641972664211474, 0.11539171955415181, 0.0333323474707348, 0.045871111431292126, 0.03882960409724286, 0.0883987686995949, 0.03110341421727623, 0.05677049068201866, 0.00582717010651582, 0.0790233485666769, 0.026962986748133386, 0.05307365208864212, 0.0393518487523709, 0.016918230835082274, 0.04673606716096401, 0.035474723404539485, 0.06509136900837932, 0.032450492826423476, 0.013325080026074179, 0.0337090701130884, 0.05755588478807892, 0.058565069921314716, 0.0751932423029627, 0.03155876210491572, 0.006857845716045371, 0.10930352338722774, 0.028644779896629707, 0.06694259574370724, 0.014523361842813236, 0.028982310356306176, 0.02826677312675331, 0.04904765276504414, 0.04542643011414579, 0.044523975146668296, 0.10170467078153576, 0.059237097789134295, 0.01769700413569808, 0.04709940230739968, 0.03494930320552417, 0.04125905801941242, 0.03802827459626964, 0.07511761278978416, 0.03633849848327892, 0.03524485270359686, 0.027233360900676677, 0.021658060872661214, 0.044320974432464154, 0.016066884821546928, 0.06020692789128848, 0.029702415822872093, 0.051236481206225495, 0.06495534987854105, 0.11423232033848763, 0.11600692011415958, 0.09202538231121642, 0.10881411643432719, 1.5017982998064585, 4.808401823043823, 26.99118069240025, 57.28106382914952, 83.49209730965751, 80.9723539352417, 72.49081298283168, 76.76683861868722, 70.56719725472587, 75.98176860809326, 94.4451402936663, 100.04057325635637, 97.11449922834123, 81.08346257890973, 67.14768300737653, 74.77945927211216, 71.38288102831159, 55.78257015773228, 31.977454662322998, 10.876725707735334, 1.8605184853076935, 4.712240057332175, 2.168412923812866, 1.0942418319838387, 0.8704104455454009, 0.33317103503005846, 0.2797599881887436, 1.137812682560512, 1.908288436276572, 3.6331611488546645, 1.1262665135519845, 0.3326590939291886, 0.3149408618254321, 0.5936474651098251, 1.173181727528572, 2.1930857598781586, 3.10239976644516, 2.256932322468076, 2.2033345699310303, 0.1264918196414198, 0.09947259591094085, 0.1301046929189137, 0.09740429225244693, 0.17006834277084895, 0.5032431504556111, 0.45433882464255604, 0.5738100867186273, 1.4946662996496474, 1.0407027048724038, 1.7783387750387192, 1.9536163125719344, 1.1149616858788898, 0.6928781090038163, 0.8910366616078785, 0.6172101636018071, 0.5221249344093459, 0.4388769386070115, 2.2099926812308173, 8.508227246148245, 21.562049388885498, 50.91933141435896, 51.48659971782139, 58.89991419655936, 97.86430018288749, 98.27207606179374, 83.20693629128593, 76.60561261858258, 62.27671091897147, 48.35653352737427, 61.23526627676827, 77.41765553610665, 80.72555392129081, 42.847504888262065, 9.072950771876744, 1.009359923856599, 0.05304336907075984, 0.11329724479998861, 0.045251585210540464, 0.03957990776481373, 0.06233726322118725, 0.04123450183708753, 0.01989119639620185, 0.012176279527401286, 0.05484508989112718, 0.022246030126033083, 0.01809837795527918, 0.050946217495948076, 0.043779639194586446, 0.058346079529396126, 0.02269506933433669, 0.0061351473975394455, 0.0590109827795199, 0.01618975055004869, 0.05921134738517659, 0.07484873650329453, 0.01971730822697282, 0.01140735431441239, 0.02685880957038275, 0.007447404437698424, 0.04835288379607456, 0.05560540195022311, 0.07997890229203872, 0.06099662730204208, 0.012443786021322012, 0.030594217790556804, 0.06423879654279777, 0.014684295082198722, 0.008496288958537792, 0.006169025378767401, 0.05453882971778512, 0.03225858955244933, 0.03271407653976764, 0.036441693481590064, 0.03646967965843422, 0.04724989119651062, 0.07630672505391495, 0.03419645842430847, 0.060218761542013714, 0.01972579161104347, 0.06579475197941065, 0.039138055938695154, 0.02872847719117999, 0.0772231612354517, 0.17026916199496814, 0.15446761489978858, 0.20693913501288208, 0.14522268383630685, 0.10888270275401217, 0.16702575103512832, 0.23119791543909482, 0.16786971289132321, 0.13756936522466795, 0.07517777170453753, 0.13269700881625923, 0.1385313786034073, 0.0973768930083939, 0.18711751220481737, 0.1715608619685684, 0.17699204624763556, 0.11346746209476676, 0.12255609940205302, 0.1743170033608164, 0.14363978377410344, 0.09786430506833962, 0.2054653162402766, 0.23759704349296434, 0.10731827241501637, 0.1839709146214383, 0.17529211246541568, 0.16535441071859427, 0.1430254653096199, 0.2601090983620712, 0.19816247453647, 0.12545165259923252, 0.23441183726702416, 0.14517779195947306, 0.1326932225908552, 0.14544155209192208, 0.1296350924032075, 0.15764223597943783, 0.12956729318414414, 0.1301371676049062, 0.21051705016621522, 0.10994281872574772, 0.13251130735235556, 0.09157108276018075, 0.17971075964825495, 0.15349741838872433, 0.23512831596391542, 0.1180306508072785, 0.1856918287064348, 0.13413592374750546, 0.19474246805267675, 0.29866112396121025, 0.16340012129928383, 0.2819042131304741, 0.3896313096795763, 0.8188294076493808, 15.516131707600184, 51.22289473669869, 96.04362896510533, 113.97810377393449, 95.31285217830113, 87.60686220441545, 78.60541534423828, 72.83524908338273, 82.79087815965924, 88.27513994489397, 114.61478805541992, 113.70894445691789, 99.29906150272915, 97.21797180175781, 77.426771572658, 54.98305484226772, 26.66077995300293, 7.307944178581238, 0.7908087883676801, 8.04895305633545, 6.9926271098000665, 2.879371711186, 1.2579767831734248, 0.44735091818230494, 0.7565698570438794, 3.826670433793749, 13.674209424427577, 18.732416357312882, 3.3035238427775244, 0.5532123148441315, 0.8376372041446822, 1.2654982081481387, 4.059675233704703, 5.808115150247302, 7.757186906678336, 15.788327387401036, 7.697874477931431, 0.24079989162938936, 0.3429729076368468, 0.4187478172991957, 0.495107786996024, 0.6767631737249238, 0.8196826790060315, 1.1003392019442149, 1.5695207629884993, 2.2603132724761963, 1.399841410773141, 2.998061490910394, 2.710193497794015, 1.2818514449255807, 1.1319832525082996, 1.1864330278975623, 0.9323131952966962, 1.723871954849788, 1.2578995930297034, 3.553377155746732, 13.95702976839883, 30.12720843723842, 57.65176064627511, 61.7509754725865, 84.02301611219133, 109.43072319030762, 95.1068867274693, 77.30710969652448, 83.09610557556152, 68.31062385014125, 64.07029805864606, 84.08186735425676, 98.66588606153215, 95.63390759059361, 34.64525720051357, 3.3699890077114105, 0.37731307638542994, 0.13177483901381493, 0.1028436121663877, 0.2705473282507488, 0.24309779118214334, 0.24896660340683802, 0.27214690670371056, 0.15922968222626618, 0.1456343646028212, 0.2273638126041208, 0.1300414263137749, 0.15934550815394946, 0.1927774849214724, 0.09981639603418963, 0.1746700451310192, 0.2347673081925937, 0.09915688713746411, 0.15872128307819366, 0.20818037912249565, 0.16592858705137456, 0.11839320563844272, 0.10469696271632399, 0.08497501670249871, 0.16805876631821903, 0.10678258937384401, 0.09657373146287032, 0.2116470281034708, 0.18746477285666124, 0.1129697770146387, 0.1270167479025466, 0.11854591672973973, 0.12656413790370735, 0.1102343580818602, 0.14586201310157776, 0.08926076601658549, 0.18326750450900622, 0.15296832392258303, 0.11701647165630545, 0.14369268236415728, 0.12961492634245328, 0.20816435212535517, 0.135470751406891, 0.1824036751474653, 0.15022100348557743, 0.09911207668483257, 0.1310322502894061, 0.1371896163161312, 0.26698401517101694, 0.16011069209447928], [0.06339056670133557, 0.04662608341979129, 0.026202274353376458, 0.05202518656317677, 0.022560570122940198, 0.07455799781850406, 0.05598688451573253, 0.029499479569494724, 0.0149974983651191, 0.050044173042156866, 0.04294941767251917, 0.06133478879928589, 0.08061712554522923, 0.02848452010325023, 0.0867833803806986, 0.08278488208140646, 0.05369911888348205, 0.09114304251436676, 0.038341113166617494, 0.02711180135208581, 0.03187867779550808, 0.06043518028621163, 0.036670152829693894, 0.0680475425241249, 0.021504063957503865, 0.037975610100797245, 0.008976426274914826, 0.08430944848805666, 0.04081168291824205, 0.019438357391793813, 0.04719122166612318, 0.1299602599548442, 0.06677094674003975, 0.03235379480091589, 0.017847109652523483, 0.07295421923377685, 0.018796390321637903, 0.08120568003505468, 0.03530534410050937, 0.09730263413595301, 0.048216664498405795, 0.10849976473088775, 0.03523408096017582, 0.02120525579500411, 0.023405933153948615, 0.0889385568776301, 0.06256628914603166, 0.0024175549624487758, 0.03448932431638241, 0.07734945695847273, 0.05740831020687308, 0.04420636986781444, 0.09530891504670892, 0.0118281257538391, 0.04042256683377283, 0.2312525510787964, 0.6781851659928049, 7.005777878420694, 18.125520740236553, 62.635161536080496, 82.9628460747855, 67.816148349217, 60.80419308798653, 62.397637367248535, 48.82930285590035, 54.582091672079905, 76.00850527627128, 88.56535230364118, 96.69188894544328, 101.63569899967739, 73.3901252746582, 51.6389285496303, 44.122937066214426, 40.57223735536848, 27.31877783366612, 14.564310141972133, 4.8907835738999506, 1.8770888532911028, 0.9403687630380902, 0.8214449701564652, 1.3092602427516664, 4.000928648880549, 7.550359879221235, 9.477438415799822, 10.342486534799848, 11.01884068761553, 8.36295257295881, 5.838801000799451, 2.802387624979019, 1.514848536678723, 1.3153100609779358, 0.5359972843102047, 1.9186740389892032, 1.3537013552018573, 2.5791971555777957, 4.46955771957125, 4.193337729998997, 3.580245839697974, 4.636977170194898, 2.448726922273636, 1.218411460518837, 1.2302864747388023, 0.996748074889183, 1.471808789031846, 2.605676523276738, 4.681772640773228, 6.2984534331730435, 10.213905777250018, 10.309993284089224, 7.465450286865234, 11.294188244002205, 17.561479875019618, 39.06328664507185, 66.6937780380249, 101.71886198861259, 90.01820673261369, 62.12885325295584, 47.118413175855366, 47.411998885018484, 49.50857959474836, 56.95162194115775, 65.0932674407959, 64.63653455461774, 27.305737801960536, 4.650281233446939, 0.6458930873445102, 0.15827492917222635, 0.03763486338513238, 0.03342550354344504, 0.07846861904753105, 0.05753066364143576, 0.03156184943925057, 0.06887578272393771, 0.06455035946731057, 0.03916340600699186, 0.0016061228171955527, 0.04946785932406783, 0.03297543465825064, 0.023898459671597396, 0.025489206991291473, 0.16140734537371568, 0.046658978797495365, 0.03497701796836086, 0.004453214301195527, 0.004993699249877993, 0.014625907143844026, 0.06126454006880522, 0.03484595553683383, 0.029386866505124738, 0.043847112716840844, 0.04458214595381703, 0.04345014937488096, 0.05917114418532167, 0.01371649804059416, 0.03290522324719599, 0.0035931228194385767, 0.049497891283993206, 0.08726045156696013, 0.030330752820840905, 0.011622786638326943, 0.02430644242226013, 0.05197877476790121, 0.038047931755759885, 0.06422305453036513, 0.13593135454824992, 0.1356338169425726, 0.011208941345103085, 0.03685972872855408, 0.021909658264900957, 0.03175083840531962, 0.023031661719349877, 0.02351278715234782, 0.11962115046169076, 0.09872561706496136, 0.016801276842930486, 0.04517291586047836, 0.015886469145438502, 0.07082581772868123, 0.06861088943800756, 0.005179806986624109, 0.016051729741905416, 0.08615827320941857, 0.09022275903927428, 0.03700708278587886, 0.02982321541224207, 0.03183715484504189, 0.07631748661931072, 0.07927091206823077, 0.10271912134651627, 0.046095207799226046, 0.11491640577358858, 0.07475483404206378, 0.05636636201026184, 0.05680379657340901, 0.04957749701238104, 0.03622188206229891, 0.04069872719368764, 0.01666142399023686, 0.030008407974881784, 0.03471450634034617, 0.03581636917910405, 0.09214631082223994, 0.02698223339393735, 0.041520358462418826, 0.05902442455823932, 0.03117261461115309, 0.04990226762103183, 0.11518560775688716, 0.10209580550768546, 0.01678024565002748, 0.0864053074536579, 0.09526831829654318, 0.041787986244474135, 0.055897087191364596, 0.02907529000991157, 0.01812331242087696, 0.05170871443780405, 0.14406760010336125, 0.023585587174498608, 0.07826640204127346, 0.034917907390211306, 0.022471461511616195, 0.050011189454900365, 0.047749876510351896, 0.03930800181946584, 0.03358640455241714, 0.06416807283780404, 0.07566501413072858, 0.09920735657215118, 0.014497075396190797, 0.157574382477573, 1.4644114545413425, 4.345276594161987, 21.215125833238872, 56.60546963555472, 92.7710691179548, 85.58169160570417, 69.48280579703194, 60.695453780038015, 57.616380419049946, 59.28574766431536, 84.2360200881958, 96.74843338557652, 104.31811359950474, 98.09997613089425, 89.98893397194999, 76.11978067670549, 68.63855103084019, 64.441575050354, 63.58096422467913, 49.76402316774641, 29.908124787466868, 11.066837106432233, 5.103630781173706, 2.6263587049075534, 4.198581448623112, 3.879435053893498, 9.438319189207894, 16.253217458724976, 19.708073718207224, 20.90587888445173, 22.569037914276123, 19.935043573379517, 16.040463617869786, 8.93361941405705, 3.8037174940109253, 3.499825869287763, 6.07854642186846, 9.146068402699061, 9.591348920549665, 12.315234712191991, 14.478811689785548, 12.112651297024318, 10.559990337916783, 10.544821551867894, 6.857328312737601, 3.480851858854294, 3.230852850845882, 3.124763629266194, 3.504618606397084, 5.285623209817069, 10.68430142743247, 12.673933727400643, 19.308910131454468, 25.41815890584673, 30.69360474177769, 34.36725630078997, 45.70582703181675, 54.36207696369716, 68.45727252960205, 87.0671191896711, 103.2624043055943, 87.9792787006923, 66.24518844059536, 54.91460813794817, 59.36002390725272, 64.99035767146519, 78.26534271240234, 82.94408593858991, 59.04868902478899, 16.365828650338308, 1.5971320356641496, 0.18795718571969441, 0.03304887589599405, 0.0846114508541567, 0.004890907979902944, 0.0514696733360844, 0.08165073115378618, 0.07125507933752877, 0.05922470773969378, 0.09167777560651302, 0.009302879650411862, 0.04197831531720502, 0.0399247189052403, 0.06175019472305264, 0.05446729516344411, 0.12270798268062727, 0.019999580491068106, 0.02654168944406722, 0.02509826564762209, 0.036961878782936504, 0.015795935610575334, 0.08973899749772889, 0.051988226760710986, 0.04510027190138187, 0.04280679978962455, 0.029116259954337562, 0.07280796101050717, 0.06314501844878707, 0.0481551620843155, 0.046892408414610794, 0.015851024172401855, 0.04899764134149466, 0.022338550072163343, 0.02239679212548903, 0.057016564799206595, 0.021755591799904193, 0.06457551954580204, 0.05963011884263583, 0.05001615633123687, 0.042234367291842184, 0.15426048529999598, 0.058353373780846596, 0.017657109669276645, 0.05773058719933033, 0.022976133806098784, 0.05543799718309726, 0.040890752603965144, 0.08215752895921469, 0.045637189876288176, 0.055596845623637946, 0.038798388093709946, 0.1303926088980266, 0.1278922344957079, 0.17812152206897736, 0.13153091924531118, 0.12898021111530916, 0.2233741216893707, 0.14248387222843512, 0.0713851409299033, 0.1366438027471304, 0.17891584230320795, 0.11805251320557934, 0.11994409241846629, 0.1505387614348105, 0.14938879385590553, 0.39600953885487145, 0.20036137583000319, 0.12579092010855675, 0.18277601445359842, 0.11909228669745581, 0.13678178962852272, 0.17032820811229094, 0.11511250239397798, 0.1643469762057066, 0.13395679050258227, 0.12201217216040407, 0.19518465575362953, 0.09041604652468647, 0.14613528629498823, 0.19706575838582857, 0.10189714402492557, 0.23848312880311692, 0.16898599799190248, 0.14297768287360668, 0.13868669526917593, 0.21208111409630093, 0.11246798679764781, 0.21964772950325692, 0.16771280845361097, 0.16691608620541437, 0.2541059362036841, 0.15959852029170307, 0.25062323308416773, 0.1422472670674324, 0.16870823289666856, 0.12021565570362977, 0.24546175290431294, 0.116836564881461, 0.25143210110919817, 0.16999269968697003, 0.1556730323604175, 0.13885018149656908, 0.2730088361671993, 0.30840884947351044, 0.17382214777171612, 0.1890338443751846, 0.4319102567221437, 0.9807452878781727, 10.749346120016915, 44.190893922533306, 109.96483121599469, 115.11144529070172, 93.43768623897007, 82.00897652762276, 85.24263341086251, 72.6508230481829, 86.33576570238385, 97.56160885947091, 105.80604948316301, 111.3009420122419, 117.4565873827253, 100.98358276912144, 85.51417595999581, 75.33954661233085, 66.48082964760917, 45.269275188446045, 19.11487647465297, 4.274028028760638, 1.4542503654956818, 0.6071633398532867, 1.2958155870437622, 0.9742441624403, 4.887271693774632, 10.278524024145943, 15.927018642425537, 14.52193307876587, 16.470682178224834, 16.08783643586295, 15.177995886121478, 7.1550043395587375, 1.8281537762710025, 2.054115274122783, 4.972843102046421, 8.189920714923314, 11.938464300973074, 15.530113220214844, 17.892759561538696, 14.728774002620153, 8.633838517325264, 9.236545239176069, 4.442920063223157, 1.3787323491913932, 1.1206146968262536, 1.6676380123410905, 1.847590059041977, 3.203364691564015, 9.097773211342947, 10.908769062587194, 18.92092272213527, 26.650352443967545, 39.37742859976632, 54.500686577388215, 67.90565504346574, 80.51949119567871, 89.841354233878, 110.29732336316789, 104.72897447858537, 84.63386004311698, 73.00364562443325, 65.60755225590297, 66.80815928322929, 77.48150948115757, 103.64198439461845, 101.89705548967633, 56.362890652247835, 8.782713225909642, 0.5124973367367471, 0.3452335963291781, 0.3000224009156227, 0.10730637769613947, 0.25529057692204205, 0.2628114590687411, 0.14197381745491708, 0.20207242401582853, 0.11864416860044003, 0.18530632582093987, 0.11089094927800552, 0.12188772883798395, 0.11075096750365836, 0.11825679295829364, 0.12213795898216111, 0.26387914749128477, 0.1506179736128875, 0.10267955596957888, 0.0945867570117116, 0.18253107688256673, 0.08649937276329313, 0.2702506455991949, 0.1088390186695116, 0.15560393035411835, 0.10239898173936776, 0.14244063597704681, 0.19578297436237335, 0.14598444796034268, 0.10668372003627674, 0.20634300128689834, 0.18125566174941404, 0.1374936814286879, 0.1899192240089178, 0.1343691498041153, 0.14611927286854812, 0.141471728682518, 0.23847151228359767, 0.16506596548216684, 0.1159834156611136, 0.32725757520113674, 0.24903429406029837, 0.13822181735719952, 0.10866695575948272, 0.11773042620292731, 0.10907649235533816, 0.1886095699987241, 0.14820770866104535, 0.3242902329989842, 0.23188803983586176, 0.13494274259677955, 0.1489892452955246], [0.11012833019984619, 0.01502881445256727, 0.03867583449131676, 0.051984355718429597, 0.08152040493275438, 0.060142636698271544, 0.02174632640422455, 0.07876215329659836, 0.03980466570439083, 0.16113795340061188, 0.08583647119147436, 0.10019131377339363, 0.20069799705275468, 0.07962202001363039, 0.08708428352006845, 0.07870990610016243, 0.08650980863187994, 0.06854934631181614, 0.04844209418765136, 0.049587953237018416, 0.07026011629828385, 0.08619062575910773, 0.009357696798230921, 0.02523008294935737, 0.030793394959930862, 0.12025315154876028, 0.05582074521641646, 0.0703002041471856, 0.05701484810560942, 0.02794114077862884, 0.12275552084403378, 0.1016174451048885, 0.03454373264685273, 0.007910221299555684, 0.015582241184477295, 0.05575790948101452, 0.06275983447475092, 0.06758224392043692, 0.025411460448854735, 0.09816032954092536, 0.08368557625051055, 0.01688348305677729, 0.046416205753173144, 0.0702208834035056, 0.009089167412769581, 0.018614166349704777, 0.05900702692036118, 0.0825746583619288, 0.0840689010385956, 0.026509764371439815, 0.028519423944609504, 0.0920688221231103, 0.0026232291046263917, 0.1789743998753173, 0.2623450612383229, 0.07982012509767498, 0.06554478646389075, 0.12882231601646968, 0.21727004780301026, 5.9220960055078775, 42.2199262210301, 77.34364332471574, 100.68027305603027, 93.99870463779995, 70.55324527195522, 62.90958758762905, 56.54751818520682, 62.0996013368879, 63.97384316580636, 67.39632429395402, 57.05137028012957, 71.68818487439836, 81.84227534702846, 71.12328938075474, 40.78801366261074, 30.115386077335902, 35.059529645102366, 34.388288497924805, 36.201202051980154, 41.402217047555105, 42.817929880959646, 48.02744599751064, 58.35450145176479, 64.28741536821637, 63.332830156598774, 65.13493578774589, 57.67444651467459, 37.78533574513027, 20.000137771878922, 11.676822934831891, 14.588729585920062, 11.172190036092486, 6.815380735056741, 14.23892513343266, 15.752672706331525, 17.87567915235247, 19.577827998570033, 21.08635139465332, 26.443231855119976, 27.97237750462123, 32.05895355769566, 34.99873638153076, 37.044154030936106, 40.3699231828962, 48.172447953905376, 52.688912527901785, 41.47060816628592, 36.947716508592876, 36.00831658499581, 41.34987626756941, 47.19324180058071, 54.375789233616416, 66.396409034729, 71.96503584725517, 72.72484220777238, 69.66162463596889, 58.84597533089774, 57.96121951511928, 63.825756209237234, 77.36762155805314, 67.24449225834438, 34.75347886766706, 6.762849748134613, 0.5435920453497342, 0.3443733767739364, 0.15878586604126863, 0.01964379065403981, 0.006600947268972439, 0.04626078052180154, 0.01790908195211419, 0.01708848205661135, 0.07171059346624784, 0.02323810599877366, 0.019298284015219127, 0.08664001271660839, 0.12367963125663144, 0.04780737217515707, 0.042258350112076314, 0.027217608710218753, 0.08654991005148206, 0.035866797901690006, 0.042304395498441796, 0.029190600250980685, 0.01746130651528282, 0.05186608027932899, 0.05358971868242536, 0.03203199617564678, 0.03146567049303225, 0.02353231030117188, 0.04207164441634502, 0.024771427203501974, 0.10463044592844588, 0.02200310441133167, 0.07534247929496424, 0.038608971650579145, 0.020314249409628764, 0.050154078751802444, 0.022222359431907535, 0.029047670241977488, 0.02856680265228663, 0.1640301410640989, 0.09002928834940706, 0.12058875496898379, 0.17341242118605546, 0.12035373757992472, 0.14657786754625185, 0.12754519097507, 0.08115887468946831, 0.06588932619030986, 0.05584257368796638, 0.07960378099232912, 0.08348382743341581, 0.12692460284701415, 0.04105024226009846, 0.08456381769584757, 0.10094990913889237, 0.10748028622141906, 0.03523935656994581, 0.0611328635630863, 0.03468761260488203, 0.043155509113733254, 0.03689281748873847, 0.03959852337305035, 0.11146113582487617, 0.03299373474770358, 0.09417867926614625, 0.05427792961043971, 0.1085721372759768, 0.16376711374947003, 0.11712653003633022, 0.12901888761137212, 0.08581564695175205, 0.11338461296898977, 0.06732917071453162, 0.03340367507189512, 0.046973021767501316, 0.044867836338068755, 0.011841380087259625, 0.01613009544754667, 0.056282776673989635, 0.10230248048901558, 0.09207694418728352, 0.08652638524238553, 0.011447705095633864, 0.08668149834764854, 0.08633752180529491, 0.05363848838689072, 0.13245136556880815, 0.12304339611104556, 0.040890867954918315, 0.027930898292522346, 0.04514113328020487, 0.11617054204855647, 0.07329966141177074, 0.08397144983921732, 0.046330282863761695, 0.06546440042023148, 0.08059482209916626, 0.057804343955857415, 0.05498894949310592, 0.050641263502516916, 0.1229005509189197, 0.08840975418154683, 0.07365337493164198, 0.0621064052517925, 0.04714837896504572, 0.12273743110043661, 0.06337529287806579, 0.08832972097609725, 0.16519211871283396, 0.07836129516363144, 0.005384866206441075, 0.26878224153603825, 1.1080216297081538, 1.9742298807416643, 24.63366038458688, 71.12401894160679, 90.6398342677525, 95.46825558798653, 88.17004149300712, 65.29261820656913, 62.160995619637625, 66.31828348977226, 79.10627623966762, 93.32679993765694, 98.84054987771171, 84.5237033026559, 86.20642498561314, 93.87941101619175, 97.45172309875488, 74.19982664925712, 66.35098171234131, 68.79427405766079, 64.74329362596784, 64.8745173045567, 67.46192223685128, 71.34535380772182, 73.79654625483921, 84.42104366847447, 84.14699976784843, 85.23421219417027, 93.7008284160069, 95.43452208382743, 72.83610371180943, 54.9361822945731, 48.13329832894461, 46.08626869746617, 39.997909682137625, 39.71057735170637, 41.29356459208897, 44.31404032026018, 40.46350499561855, 37.566561290196006, 51.52029153278896, 50.185042313167024, 48.358142035348074, 54.249245166778564, 58.1677998815264, 54.065736293792725, 59.86230223519461, 69.44103322710309, 71.04225948878697, 61.14723954881941, 60.961326599121094, 54.719030244009836, 60.36790875026158, 67.25149604252407, 73.73434598105294, 80.90381690434047, 80.62207439967564, 88.67106219700405, 78.71084730965751, 62.673098700387136, 60.706876618521555, 67.58456489018032, 84.73501886640275, 86.4437198638916, 61.12947300502232, 25.65869164466858, 2.7916101004396165, 0.7767472086208207, 0.06910776027611323, 0.0306489416398108, 0.11566588841378689, 0.04828398874295609, 0.0861603088144745, 0.08664417892162289, 0.04943016331110682, 0.06631261669099331, 0.0604146613872477, 0.033643398101308515, 0.028694713288652043, 0.040689706070614715, 0.0015581479528918862, 0.02465194566840572, 0.0533828129991889, 0.03570859406941703, 0.048279201678399525, 0.057895559418414316, 0.0986088819003531, 0.08914255843098674, 0.04148757165031774, 0.049196309609604735, 0.051950289867818356, 0.04358239924269063, 0.03637134975620678, 0.03966966437708054, 0.010093121041011597, 0.10200769773551396, 0.1963771539075034, 0.07731525879353285, 0.055504921091986556, 0.10674169406827007, 0.11993429437279701, 0.08408714005989687, 0.04384972507666264, 0.09348443616181612, 0.08174204839659588, 0.1109330320198621, 0.2930999866553715, 0.15370267523186548, 0.2137918094439166, 0.1565212147044284, 0.11140242218971252, 0.09437830426863261, 0.05924657013799463, 0.08253707430724587, 0.06298346604619708, 0.2774482193802084, 0.13034653637026036, 0.024217269350109354, 0.10469557850488595, 0.2931402644940785, 0.17066666137959274, 0.17507690829890116, 0.13186118938028812, 0.12869560638708727, 0.17669551287378582, 0.12253794180495398, 0.15326317452958652, 0.1338799667677709, 0.23396082861082895, 0.17894349939056806, 0.2201097032853535, 0.26905769961220877, 0.19041234254837036, 0.23011073949081556, 0.20912555126207216, 0.23244484567216464, 0.1553850620985031, 0.14204908055918558, 0.12920883670449257, 0.15158460102975368, 0.14280699060431548, 0.1319600926446063, 0.22211424500814506, 0.17593351804784366, 0.21155284744288239, 0.20390368146555765, 0.11827926603811127, 0.1260852278875453, 0.152564405596682, 0.20529870875179768, 0.3301878965326718, 0.2433262403522219, 0.1530624638710703, 0.22894197649189404, 0.16848108651382582, 0.19562423788011074, 0.14829357048230513, 0.11910231544503144, 0.2244501153805426, 0.19891539056386265, 0.22632094499255928, 0.18459318551634038, 0.18114212927009377, 0.13619484326669148, 0.21219959988125733, 0.23048287523644312, 0.1802270705146449, 0.19035060943237372, 0.12772125724170888, 0.2567161518548216, 0.1320889735860484, 0.10725492438567535, 0.37593969436628477, 0.21107585089547293, 0.1376990604081324, 0.1790457953299795, 0.30855430024010794, 0.35646451796804157, 11.284102065222603, 61.506176539829795, 113.15822328839982, 131.24739973885673, 117.98125975472587, 91.83375017983573, 84.6017176764352, 81.19772570473808, 92.97702067238944, 94.6239869253976, 93.28520107269287, 73.37909153529576, 84.57429313659668, 113.74294199262346, 118.23653657095772, 97.4801412309919, 97.47288036346436, 95.31553418295724, 84.66921247754777, 79.5852781023298, 83.9064531326294, 82.34784017290387, 82.90706593649728, 95.00921589987618, 99.02667127336774, 105.50381674085344, 112.16150420052665, 107.15742547171456, 85.38028417314801, 69.35676547459194, 66.66922310420445, 65.92932333265031, 62.65194838387625, 54.1858845438276, 60.10678849901472, 64.9214871270316, 60.947520528520855, 68.4311056137085, 78.54957962036133, 70.53117779323033, 66.74718189239502, 74.06314863477434, 74.60320431845528, 66.82984461103166, 72.82156113215855, 85.22614533560616, 86.90260669163295, 81.8846663066319, 90.4732095173427, 81.78501524244035, 79.45543711526054, 76.54799815586635, 76.67775576455253, 89.0364054271153, 91.39003821781704, 97.7125723702567, 90.39840521131242, 75.90970189230782, 69.92940820966447, 81.87910079956055, 109.77549975258964, 102.18280710492814, 53.83985035760062, 14.1510260786329, 0.703481602881636, 0.5607434564403125, 0.17859355174005032, 0.1291811524757317, 0.31430423312953537, 0.12260639241763524, 0.17934618278273515, 0.12930444228862012, 0.19239764101803303, 0.1554357215229954, 0.185459986861263, 0.1646001919039658, 0.12682735520814145, 0.12242180375116211, 0.14896777644753456, 0.1351062695362738, 0.19013799726963043, 0.100457306286054, 0.16556737571954727, 0.13242910962019647, 0.16721255172576222, 0.09560937713831663, 0.15725587813981942, 0.2002701942941972, 0.14790747048599379, 0.11341473313846759, 0.059989016370049546, 0.10836597798126084, 0.1945569294371775, 0.23293216952255794, 0.3664391998733793, 0.1542234644293785, 0.11059020220169, 0.17743013559707574, 0.20114098542502948, 0.15067316565130437, 0.168573258710759, 0.34987059608101845, 0.15611044317483902, 0.20510934319879326, 0.49609947949647903, 0.2454433510346072, 0.27727554578866276, 0.25109052658081055, 0.25887234615428106, 0.23860029823013715, 0.20606144996626036, 0.1056980597121375, 0.2756571312035833, 0.3242917800588267, 0.1896488413746868, 0.19147771038115025, 0.26244768287454334], [0.017589486869318143, 0.09509274057511773, 0.08480336091348104, 0.053629256917962005, 0.08369274836565767, 0.050721147430262396, 0.06937648049954857, 0.14959400998694555, 0.11524366321308271, 0.1474661784512656, 0.29296916510377613, 0.23529450276068278, 0.23726103295172962, 0.1139165572822094, 0.03014517349324056, 0.05439156726268785, 0.05615611454205854, 0.031851136059101136, 0.07413649186491966, 0.11706680538398878, 0.05496418296492525, 0.1025180374937398, 0.05347379436716437, 0.08473030304802315, 0.07110175077936479, 0.04260655053492103, 0.0521600148640573, 0.09625950868108443, 0.1435003855398723, 0.1749959047883749, 0.12657648724104675, 0.04351189945425306, 0.029110516155404702, 0.02958220655896834, 0.021054319072780863, 0.029086122821484293, 0.06142135629696505, 0.04496269553367581, 0.0163438441564462, 0.031842752758945735, 0.02325842303356954, 0.011277639623066145, 0.010052431840449572, 0.02416589407117239, 0.003521166937259425, 0.10176457863833223, 0.06032409053295851, 0.008741154435223766, 0.003870363746370588, 0.03157425645206656, 0.009274611881534969, 0.04092840451214995, 0.06443428248167038, 0.12873733629073414, 0.029808206217629567, 0.07222189674420015, 0.0655384421614664, 0.17710298672318459, 0.06353121344000101, 0.17183418944478035, 0.5814906688673156, 9.620907425880432, 53.96359430040632, 100.2051065989903, 107.02984264918736, 93.29748548780168, 75.70978832244873, 66.64447362082345, 66.86258452279228, 67.51629189082554, 68.14809853690011, 61.17649146488735, 70.28664984021867, 59.82714435032436, 52.30012954984392, 62.95162418910435, 62.86006777627127, 64.92539201463971, 64.76782771519252, 62.94965784890311, 69.4208903993879, 89.68939018249512, 74.55829116276333, 94.42579650878906, 84.2774382999965, 48.27907848358154, 36.32571029663086, 44.50965295519148, 40.61959975106375, 35.23276560647147, 35.395367349897114, 33.200136116572786, 23.221730845315115, 40.88287394387381, 33.47467333929879, 48.686597279139924, 48.810448919023784, 37.46483966282436, 50.85946226119995, 53.778921604156494, 52.02781922476632, 58.75507204873221, 69.74967220851353, 61.96284689222063, 63.29859638214111, 70.86027227129254, 69.01890236990792, 51.36404044287545, 58.87617915017264, 58.41900157928467, 57.60731649398804, 67.04689243861607, 68.23752185276577, 67.88395581926618, 63.25413485935756, 57.837215014866416, 72.82386793409074, 93.55893230438232, 81.43217876979283, 41.514423506600515, 5.645909454141345, 0.15075376204081944, 0.23640996004853929, 0.024010928547275916, 0.015316713468304701, 0.26012174625481876, 0.10042171712432589, 0.03652961804930653, 0.025993317798046128, 0.098551389628223, 0.02271196655263858, 0.040641604723142724, 0.02648720986741994, 0.02315049694984087, 0.07072436317269291, 0.04676395495023046, 0.008753690369693297, 0.03351236620385732, 0.014444968995771237, 0.03898629140374916, 0.10556084636066641, 0.05757591514182942, 0.030040051455476453, 0.04054463528362768, 0.03179096696632249, 0.03144704809944544, 0.02343508810736239, 0.02283325299088444, 0.013198630784505179, 0.07083995161311966, 0.025495245952957442, 0.021468067674764564, 0.033704194838979414, 0.035402472995753796, 0.027284218796661923, 0.09875874314457178, 0.07988945780588047, 0.07148226643247263, 0.06288235075771809, 0.0730903876413192, 0.03150959545746446, 0.15364219062030315, 0.19354649579950742, 0.12194958409028393, 0.12337013786392552, 0.09916403889656067, 0.12084283919206687, 0.14284882907356533, 0.02406571855369423, 0.15985951200127602, 0.0352131074427494, 0.13669328152069024, 0.07616398842739207, 0.085787955937641, 0.02380624506622553, 0.040458776855043004, 0.058106821296470504, 0.014297070414093989, 0.017679667565971613, 0.09451952097671372, 0.0734371936747006, 0.07797823500420366, 0.01864149434758084, 0.04167109501681157, 0.15273231587239675, 0.09112616056310278, 0.09426450716065508, 0.12307960273964064, 0.04898739207003798, 0.1326521033687251, 0.09143804239907435, 0.03801209832142506, 0.03367816623566406, 0.012808026163838804, 0.05367476626166275, 0.032572893758437464, 0.035678124454404624, 0.028252437378146818, 0.05365231014522059, 0.053456919201250584, 0.036685589501368146, 0.055989873462489674, 0.046250344653214724, 0.026498655056846992, 0.13798850987638744, 0.07234978702451501, 0.08945523415293012, 0.10040497088006564, 0.037929890411240716, 0.043839445271130116, 0.07257750337677342, 0.10165582983089344, 0.13427563410784515, 0.1095890441377248, 0.05541697616821953, 0.0164519822823682, 0.018212935022477592, 0.05176091752946377, 0.055132988906864605, 0.05813654113028731, 0.010677347325586846, 0.08796639261501175, 0.09675000807536499, 0.09567881841212511, 0.032142505781458955, 0.034472367726266384, 0.016841435938009193, 0.013727628559406315, 0.11594552626567227, 0.03585335951564567, 0.03560809964048011, 0.27820030759487835, 0.16722996293434075, 0.12139332108199596, 0.1435853381242071, 0.756334975361824, 3.283727773598262, 29.289439814431326, 81.7273312977382, 112.16896656581334, 110.4857098715646, 96.99234294891357, 78.19055925096784, 67.1896779196603, 65.77029296330043, 71.52481188092912, 63.79915155683245, 67.10572978428432, 85.27711037227085, 77.29845224108014, 67.29093401772636, 93.86237403324672, 94.89990683964321, 103.87249783107212, 103.28481224605015, 103.94885158538818, 103.3458799634661, 123.20937619890485, 100.03461170196533, 112.89307308197021, 104.7149738584246, 68.00577163696289, 54.07642262322562, 65.8257395880563, 60.11854485103062, 60.66419383457729, 65.70484093257359, 63.68301936558315, 47.64364487784249, 74.15985366276333, 64.21209689549038, 84.35074874332973, 82.35912404741559, 62.43873596191406, 78.60175364358085, 77.59520980290004, 79.57195145743233, 81.74682794298444, 94.03951835632324, 85.0444916316441, 95.11307757241386, 87.3359727859497, 89.11422525133405, 78.46457535879952, 82.41131891523088, 75.43709237234933, 62.68674496241978, 67.3821360724313, 69.45629147120884, 71.34381130763462, 70.51007611410958, 67.20411627633231, 80.39556312561035, 98.38096823011125, 97.27848366328648, 69.21303503853935, 19.95463923045567, 1.8879378139972687, 0.8621920293995312, 0.06048677608902965, 0.041385218035429716, 0.025808557801480805, 0.048829564824700356, 0.03455791063606739, 0.056008136232516596, 0.07147810022745814, 0.045519816888762374, 0.04365857497655919, 0.038921165612659285, 0.09646908100694418, 0.07196964456566743, 0.016084648868335143, 0.0345050425800894, 0.009464494817491089, 0.029383056530995027, 0.09540304820984602, 0.03334481555170246, 0.0652446975665433, 0.05487208201416901, 0.016424944358212606, 0.012467486401354628, 0.032194868328848054, 0.052900523878633976, 0.05733207001217774, 0.024749656407428638, 0.004950824742471533, 0.01649826515599021, 0.05293999765334385, 0.10182989441922732, 0.09294408479971544, 0.04362502481256213, 0.06392733539853777, 0.06688200935189213, 0.11809583088116986, 0.0626757029177887, 0.06542778667062521, 0.08037429143275533, 0.18509090452321939, 0.11246468911745719, 0.1852910045002188, 0.26483167495046345, 0.15211892021553858, 0.22822468355298042, 0.13241986797324248, 0.14772479528827326, 0.12278249939637524, 0.09872899616935424, 0.10371756527040686, 0.10386300925165415, 0.18545713701418468, 0.0386707929761282, 0.07406844837324959, 0.13064464394535336, 0.18316322724734033, 0.10686630702444486, 0.172816043187465, 0.21365923727197306, 0.15608069619962148, 0.23324532700436457, 0.23025591884340557, 0.2452520313007491, 0.1420647818595171, 0.3831476904451847, 0.2472635076514312, 0.24855698538678034, 0.20073017318333897, 0.1516364953879799, 0.09238567762076855, 0.18937488964625768, 0.20046464885984147, 0.24837174532668932, 0.2035350605313267, 0.1378386350614684, 0.15881660367761338, 0.09925720853997128, 0.20409057715109416, 0.1995254885405302, 0.23798877532993043, 0.11961812419550759, 0.14414365030825138, 0.24173483146088465, 0.1944792236068419, 0.18566380521016462, 0.20484528451093606, 0.08768054616770574, 0.15446973192904676, 0.10535041908068316, 0.2750286992107119, 0.29102643792118343, 0.19824393945080893, 0.2221743632107973, 0.2158828643815858, 0.18398398320589746, 0.16753379734499113, 0.18048875432993683, 0.16360236544694218, 0.09036018273660115, 0.15714818106165954, 0.11298328664685998, 0.14180042461625167, 0.11372694745659828, 0.08876696894211428, 0.11755426494138581, 0.09269070625305176, 0.21225080213376454, 0.29530332556792666, 0.10315987055322953, 0.43831334742052214, 0.1699006496263402, 0.3172161525913647, 0.20960072933563165, 0.3848728250179972, 0.6052518795643533, 13.942937084606715, 71.50496087755475, 130.3552371433803, 143.76149450029646, 129.30259895324707, 99.3342193875994, 81.44785390581403, 84.17706462315151, 91.89558219909668, 94.43959563119071, 84.77062143598283, 88.4197666985648, 73.02187074933732, 62.69142804827009, 85.68088408878872, 93.36005401611328, 112.06050518580845, 119.57082693917411, 108.81296580178397, 110.82993752615792, 133.14555031912667, 101.56485516684396, 115.97804546356201, 101.73980385916573, 75.48556300571987, 69.70169489724296, 90.96271705627441, 84.02697658538818, 79.5566098349435, 79.82857622419084, 70.93882860456193, 48.60331964492798, 85.50897175925118, 71.04859624590192, 94.42543520246232, 94.87791579110282, 72.63800362178257, 89.46032891954694, 92.35686615535191, 80.37888744899205, 81.91177122933524, 102.45510700770787, 88.29355267116001, 88.43874222891671, 92.31646238054547, 90.23487935747418, 67.60073334830147, 83.31568254743303, 81.71360165732247, 84.4523036139352, 90.5340826851981, 88.41670949118478, 81.86518355778286, 75.92371640886579, 72.01251288822719, 96.56010246276855, 124.06021090916225, 108.84162017277309, 55.84236288070679, 9.763340285846166, 0.43311742480312077, 0.8644702785781452, 0.10542040318250656, 0.11982401886156627, 0.3926607242652348, 0.357214841991663, 0.09060596847640616, 0.14290531032851764, 0.206902236278568, 0.12975903360971383, 0.17371671700051852, 0.19625847813274178, 0.1707787417939731, 0.2031423651746341, 0.07422945794782468, 0.16758581383952073, 0.12334263005426951, 0.12273231494639601, 0.18272614212972776, 0.13275876907365664, 0.10984209020222936, 0.2233840554420437, 0.14139035876308167, 0.09936987927981786, 0.1282619953687702, 0.08713374872292791, 0.17790327806557926, 0.09691523813775607, 0.09203199124229805, 0.10043267546487705, 0.12724132942301886, 0.17991407588124275, 0.11441595905593463, 0.09913544543087482, 0.2595153802207538, 0.16767585543649538, 0.22824566385575704, 0.19054880951132092, 0.22310505541307585, 0.19950030132063798, 0.21609972417354584, 0.36317457790885654, 0.2077092994004488, 0.28209756846938816, 0.21244372321026667, 0.2977112020765032, 0.3051417576415198, 0.20972975955477782, 0.31637984461018015, 0.16074014188987867, 0.27362106474382536, 0.22864822511162075, 0.23748481380087988, 0.12950478653822625, 0.17072756668286665], [0.012431149154768457, 0.017301360544349467, 0.021635972861466662, 0.03373000291841371, 0.03517872268067939, 0.04463739227503538, 0.03357142249920538, 0.0428144061671836, 0.04123874607362917, 0.06865067194615092, 0.07411502980227981, 0.10367935017815658, 0.0934815863147378, 0.06937220572893109, 0.03289399688531246, 0.04594503442889877, 0.026824200891756585, 0.036622601095587015, 0.02084318781271577, 0.056718009391001294, 0.10514683821903807, 0.04393316792058093, 0.03514927086819496, 0.058546152364994795, 0.05245405801438859, 0.0495909727178514, 0.03823273076808878, 0.08394764683076314, 0.04394238581880927, 0.0378095115135823, 0.0715034231543541, 0.07963915302285127, 0.060651768664164205, 0.031903685203620365, 0.07616729289293289, 0.021241002716124058, 0.03092222161857145, 0.025502421460779648, 0.020869092583390217, 0.020845428674614856, 0.040993197821080685, 0.017248713012252535, 0.02412457637754934, 0.0535079178932522, 0.0030051279089613153, 0.01798362241658781, 0.016044623783922622, 0.003799523418170533, 0.023820543495405997, 0.056108440671648295, 0.06905649695545435, 0.04176748091621058, 0.035075839808476825, 0.07442812621593475, 0.04351419968796628, 0.03467040495680911, 0.04002059929605041, 0.04809647219787751, 0.08830342095877443, 0.0543385804630816, 0.052542030079556365, 0.4996914810367993, 0.32366918346711565, 4.657921212060111, 23.600108895983013, 61.000945227486746, 93.18424374716622, 115.50013446807861, 99.50486019679478, 76.6211279460362, 78.88798468453544, 66.00838688441685, 78.24507481711251, 72.46099826267788, 59.313234737941194, 50.450661523001536, 48.10757957186018, 52.97503934587751, 51.630649771009175, 51.68406752177647, 49.511049679347444, 47.073638984135215, 35.284515789576936, 48.04610538482666, 59.05661691938128, 50.30852917262486, 58.138058117457796, 49.730737822396414, 49.37313141141619, 53.10045085634504, 48.2864123071943, 39.42083052226475, 34.2148962020874, 44.73765809195382, 36.82682132720947, 73.79704652513776, 47.52379887444632, 22.151960134506226, 38.19367095402309, 37.271308013371055, 37.59298528943743, 50.62174006870815, 50.25349249158587, 45.9083183833531, 42.25693580082485, 49.661193302699495, 50.71908780506679, 49.07720763342721, 61.711329051426475, 62.56758335658482, 58.018031460898264, 65.67218439919608, 68.97815118517194, 77.79012761797223, 95.3036527633667, 91.0641121183123, 67.18642616271973, 26.804222038814, 2.2801783893789564, 0.13384716638496943, 0.16257281069244656, 0.03954460698046854, 0.011035286422286714, 0.11154578306845256, 0.12686626240611076, 0.04026776246194329, 0.05287655123642512, 0.04983525210991502, 0.01930547479007925, 0.040044385341129134, 0.10145477311951773, 0.05352484394929238, 0.012891888851299882, 0.07204076182097197, 0.07356353689517293, 0.061030370848519463, 0.04865817705701504, 0.015530245045998266, 0.0030552953955650863, 0.03494362386741808, 0.026619317242875695, 0.02520477698583688, 0.018234359765691415, 0.028958710908357586, 0.010738100806650306, 0.017771810925166522, 0.05596106286559786, 0.02720276914936091, 0.019632089317643216, 0.030435810397778238, 0.08393133484891482, 0.057902650109359195, 0.08795340545475483, 0.026067247581002966, 0.03337634028866887, 0.04822567205077835, 0.04227522188531501, 0.08023872692137957, 0.0877002440392971, 0.13244745720710072, 0.10367314158273594, 0.07167577104909079, 0.04838628128969243, 0.03326031419315508, 0.10537566736872707, 0.03748624385999782, 0.015214948482545359, 0.08177772576787642, 0.052598073679421625, 0.010247754930917705, 0.03061285036216889, 0.02798803772644273, 0.04905419384262391, 0.10138097565088953, 0.012821902204970164, 0.02583302407791572, 0.0385744036840541, 0.04190938633733562, 0.09281484423471348, 0.032218986856085916, 0.028591698102120842, 0.03774801588484219, 0.02012205945460924, 0.01622230326756835, 0.03753217389541013, 0.04659873506586466, 0.024795986778501953, 0.04131703883675592, 0.014165693311952055, 0.057145276106894016, 0.033877265373510976, 0.022272040069635426, 0.013701324301239635, 0.07787677366286516, 0.04030538722872734, 0.024597946155284132, 0.039786911835627894, 0.0458271966448852, 0.04724198626354337, 0.031069524785769836, 0.022762218856119683, 0.10365601535886526, 0.041402873516614945, 0.04657035533870969, 0.049848771920161586, 0.03906300657295755, 0.07944119721651077, 0.03645145760050841, 0.031125337683728764, 0.03113186519060816, 0.07320159953087568, 0.02260302097004439, 0.05201677612162062, 0.017806397551404576, 0.054140906248773844, 0.07639656987573419, 0.042132936484579525, 0.03830337304888027, 0.05495492774727089, 0.027799701850329126, 0.019006563150989156, 0.050398137619985, 0.006465821260852473, 0.013075034782689596, 0.04916710206972701, 0.01776960229368082, 0.019160663542736853, 0.035610898597432036, 0.041398330724665096, 0.05537219964233892, 0.05251753496538315, 0.023920574824192693, 0.05753911140241793, 0.07324881878282342, 0.1171131900378636, 0.03188791944246207, 0.17664892465940543, 1.0793528194938387, 3.8436214327812195, 25.50311974116734, 54.00785779953003, 93.07390635354179, 109.30332102094377, 114.56296839032854, 98.78023256574357, 82.114102772304, 85.5013495853969, 78.65963908604213, 73.30392592293876, 58.00011900493077, 42.92454998833792, 39.14105435780117, 44.35395424706595, 54.707829747881206, 58.03499896185738, 54.576227392469136, 50.99582413264683, 54.331122738974436, 35.19904947280884, 55.26069443566458, 58.20691476549421, 54.865397521427695, 55.478763648441856, 54.750543798719136, 55.61547292981829, 59.84527220044817, 53.73396328517369, 43.22749144690377, 35.13412550517491, 59.53279086521694, 42.37519761494228, 85.3395607812064, 63.62981700897217, 27.89101583617074, 43.04610872268677, 40.654948711395264, 33.91021074567522, 45.89108337674822, 54.95353889465332, 47.232537337711875, 38.471216746738975, 58.561877386910574, 54.18408843449184, 38.96932962962559, 58.78156552995954, 65.28937339782715, 64.36506148747036, 71.64478642599923, 73.61279419490269, 82.18095139094761, 93.00065149579729, 103.43269770486015, 87.07505403246198, 53.68741382871355, 11.443242737225123, 1.728073660816465, 0.4311080654816968, 0.13504305721393653, 0.08640878155295338, 0.10922939343644039, 0.1722472815641335, 0.023398591405046836, 0.05587058700621128, 0.09183423221111298, 0.05011461854779294, 0.029884161427617073, 0.06618867548448698, 0.06252309360674449, 0.020998195745050907, 0.04369714969236936, 0.11102608631231956, 0.053786232601851225, 0.057591636798211505, 0.07744242982672793, 0.020621099908437048, 0.027759985499350086, 0.028269100501867275, 0.026543109278593744, 0.059350542058902125, 0.015772577042558363, 0.049163234420120716, 0.06535502057522535, 0.05601089787004249, 0.048829934626285515, 0.010040873844575669, 0.020499367333416427, 0.06691990553268365, 0.01610505411268345, 0.023589059577456543, 0.017860863557351486, 0.05229522314454828, 0.016307264333590865, 0.06357940978237561, 0.012404057795980146, 0.061293472802000384, 0.022323729171018516, 0.08570146986416408, 0.07491972483694553, 0.005346861460046577, 0.08496471654091563, 0.05857108174157994, 0.10701763390430383, 0.04175112482958606, 0.08257572366190807, 0.05888442921319178, 0.07128954213112593, 0.06658619522516217, 0.06653801923883812, 0.03219251720500844, 0.10338757333478757, 0.03922984815601792, 0.03602555813267827, 0.13724715608571256, 0.09806435754788773, 0.2106652557849884, 0.16313918387251242, 0.1047153781567301, 0.10539816080459527, 0.11505652325493948, 0.10615622012742928, 0.1006664986323033, 0.14149854438645498, 0.1486473586410284, 0.22230145281979016, 0.23426057824066707, 0.08801216658736978, 0.10776484345218965, 0.14469816269619123, 0.19866715531264031, 0.18724124985081808, 0.11008970798658473, 0.1333145706781319, 0.2186785236533199, 0.18709122575819492, 0.10457420216075011, 0.11108536313154868, 0.17477160825261048, 0.07807829177805356, 0.11449255208883967, 0.16159391536244325, 0.10780426633677312, 0.06838531725640808, 0.18805473191397531, 0.16071917515780243, 0.11165789062423365, 0.1052685674013836, 0.18564420911882604, 0.27773426260266987, 0.1749555862375668, 0.039955507431711466, 0.14004448455359253, 0.22654929916773522, 0.15246669655399664, 0.1312379685363599, 0.1676660438201257, 0.21895320819956915, 0.1744653582572937, 0.16722902655601501, 0.12275374308228493, 0.03768551941694958, 0.20595884190074035, 0.11342442940388407, 0.13690165962491715, 0.09541489543127162, 0.10891181869166237, 0.15849682369402476, 0.12825854841087544, 0.1836759147367307, 0.1466781414513077, 0.1953990999609232, 0.19892053385930403, 0.3347854055464268, 0.19669977016746998, 0.7533573465687888, 0.6780830057603973, 9.01937929221562, 33.545732566288535, 87.94808823721749, 127.04783902849469, 156.1397102900914, 132.5191146305629, 102.39176722935268, 103.43526853833879, 88.91546508244106, 100.33867182050432, 91.29041494641984, 73.09352057320731, 64.12200655255998, 60.82541288648333, 70.7131233215332, 70.84204714638847, 74.8016379220145, 68.07848453521729, 64.26354830605644, 49.795703479221885, 75.46262005397251, 91.35510267530168, 74.38621207645961, 81.83459758758545, 69.81598581586564, 72.93546295166016, 79.56353024074009, 77.41513334001813, 69.59471348353794, 66.5535911832537, 90.70450810023716, 70.89591653006417, 111.74934400830949, 84.74147374289376, 50.29987866537911, 67.6622040612357, 62.148829323904856, 56.2627705846514, 71.23926176343645, 79.96388544355119, 66.1465448651995, 61.91332013266427, 75.15001365116665, 77.96702180589948, 66.31045286996024, 85.48725863865444, 79.33838081359863, 77.8909946169172, 85.44670895167759, 92.72211905888149, 106.172518321446, 127.01596069335938, 124.53578730991909, 87.54486342838833, 36.40962021691458, 3.9800015432494025, 0.4119190680129187, 0.6615019983478955, 0.21899145043322019, 0.24434111160891397, 0.3230060376226902, 0.34675823737468037, 0.17203666429434503, 0.13008122917796883, 0.17112560889550618, 0.2207828371652535, 0.07863642075764281, 0.25939739655171123, 0.13142027732517036, 0.08154677280357905, 0.2554078277732645, 0.30780150634901865, 0.2254451055611883, 0.16723406128585339, 0.20027650466987065, 0.1187671327165195, 0.14676541462540627, 0.14706990042967455, 0.12219152253653322, 0.1549477462789842, 0.11180685620222773, 0.15798128635755607, 0.05430979361491544, 0.13977444118687085, 0.13078040523188456, 0.18130249423640116, 0.09294943844101258, 0.16080355777272157, 0.16569078766873904, 0.1678936244653804, 0.13037198143345968, 0.16236276339207376, 0.15351336396166257, 0.09775128149028335, 0.12177271715232305, 0.17992181118045533, 0.14686191587575845, 0.1778998989611864, 0.303126508636134, 0.12051328830420971, 0.17285853305033275, 0.27722058445215225, 0.13668745969023022, 0.13158662697034224, 0.16261474415659904, 0.19319787807762623, 0.074086219205388, 0.1306812305535589, 0.16358089659895214, 0.1397259123623371, 0.2944446802139282, 0.12885004095733166, 0.12930607077266487], [0.02089313816811357, 0.015382689124505435, 0.043379910822425566, 0.026467584938343083, 0.05417522655001708, 0.10338802795325007, 0.11495448515883513, 0.032697808662695546, 0.1134783322257655, 0.046770645305514336, 0.09723199864051171, 0.08042158532355513, 0.13890706987253257, 0.051787797694227526, 0.09517860918172769, 0.07518866897693702, 0.028610181396028826, 0.038184571745140214, 0.038348658476024866, 0.020999602008877054, 0.03696349708895598, 0.05200613669252821, 0.025556120722155486, 0.07356267515569925, 0.11500130407512188, 0.12406091365431036, 0.032419663587851186, 0.17571109426873072, 0.030914849335593835, 0.028408624265076857, 0.08248526815857206, 0.03987455481131162, 0.05220872010769589, 0.025996545928397348, 0.025582200215597237, 0.037801850853221755, 0.024267011055988923, 0.04473055513309581, 0.021552886248433163, 0.11186321532087666, 0.014482361364311405, 0.01868513771998031, 0.031955800085727654, 0.04208252133269395, 0.01702214508051319, 0.06355214624532632, 0.06510494649410248, 0.03654220826657755, 0.06954557821154594, 0.023826835211366415, 0.06375365078981433, 0.07098927002932344, 0.03754444520122238, 0.1329553678099598, 0.01148455378799034, 0.0370231776365212, 0.04934066793482218, 0.04587041593289801, 0.018321215640753508, 0.10671977060181753, 0.13252873213163444, 0.09784634424639599, 0.058918023481965065, 0.245554902191673, 0.24255387751119478, 0.12642875659678662, 5.630427130631038, 25.273954255240305, 61.460915974208284, 94.97980417524064, 112.21385887690953, 97.69053268432617, 85.1182120186942, 73.2254251752581, 68.08175018855503, 68.04412569318498, 64.78806781768799, 70.75534752437046, 68.29182202475411, 65.15633623940604, 65.2472117287772, 62.697938510349815, 60.02557795388358, 60.9056715284075, 58.379466329302105, 64.94779995509556, 73.0883024760655, 90.06640638623918, 87.32099941798619, 75.21975272042411, 61.66357408251081, 58.939108984810964, 60.048875263759065, 59.04345008305141, 63.016784395490376, 66.11390917641776, 59.63431794302804, 63.12835162026541, 64.0266981124878, 67.40063912527901, 64.75335461752755, 57.67133719580514, 64.10742923191616, 62.52122497558594, 63.79009805406843, 62.72024917602539, 66.93725681304932, 64.08479894910539, 67.82171385628837, 76.8281912122454, 94.14823681967599, 90.56087493896484, 62.73336042676653, 40.86548260280064, 22.786721502031597, 4.6098509686333795, 0.24878877294915064, 0.3522932103702, 0.11156774046165602, 0.050981837191752026, 0.03838573023676872, 0.12724694769297326, 0.027661116161782826, 0.04982251600761499, 0.1202087075050388, 0.0801771634391376, 0.1132381579705647, 0.04443904970373426, 0.0815526692728911, 0.08201066683977842, 0.046489015953349214, 0.04012047965079546, 0.024954288998352628, 0.028531634182270085, 0.05607687182990568, 0.031615287464644225, 0.02758733565653009, 0.009070760454051197, 0.02301995868661574, 0.028637651886258806, 0.013929416392264622, 0.04142166215128132, 0.07036040377404008, 0.017347207459221994, 0.010461846300001656, 0.043235189480973144, 0.010300041143117207, 0.014333880938855665, 0.05854983002479587, 0.047603767564786334, 0.03609735731567655, 0.03155238048306533, 0.015393579611554742, 0.017471920499312024, 0.02918534160458616, 0.02609654333043311, 0.12311183315302644, 0.0687730253807136, 0.09020435038421835, 0.07839480122285229, 0.07733622552560908, 0.10805049312434026, 0.17406978591212205, 0.07996538587446723, 0.035054683086595366, 0.041627366827534776, 0.08294245826878718, 0.04364793894014188, 0.03426541793825371, 0.049518566246011426, 0.0364881629523422, 0.05714726421449866, 0.027945189936352626, 0.02479642104091389, 0.03557388111948967, 0.020613172923081687, 0.03504670690745115, 0.06797481035547596, 0.029556449369660447, 0.04853627145556467, 0.1010220916941762, 0.04144479001739195, 0.022641955309414437, 0.05004253098741174, 0.12167346104979515, 0.18294659815728664, 0.04714133237887706, 0.033110269744481356, 0.04113996833828943, 0.07054417141314064, 0.12371528148651123, 0.12436131467776639, 0.06494188774377108, 0.13713278222296918, 0.03831365963976298, 0.031190697569400072, 0.01980612167556371, 0.030220911572022096, 0.003225839447363147, 0.017201868650902594, 0.07059345341154508, 0.020418485959193537, 0.016971068356984427, 0.11436801377151694, 0.07335684834314243, 0.03163398449708309, 0.06557868607342243, 0.015150681038254073, 0.07791051042399236, 0.05104658639590655, 0.050535374720181735, 0.04700734206874456, 0.062042561891887865, 0.06412152533552476, 0.0417437762953341, 0.03798653790727258, 0.02292944211512804, 0.014910883369988628, 0.07505397299038512, 0.048730583528855016, 0.05951725132763386, 0.0347761885662164, 0.027476770071578876, 0.04908953533907022, 0.07067191920110158, 0.037918246750320704, 0.03866392620173948, 0.01812201981166644, 0.10834939458540507, 0.06977190356701612, 0.03063291124999523, 0.015510757520262684, 0.04058489615895918, 0.06163822287427528, 0.019572425733453462, 0.04398945240037782, 0.0972229673394135, 0.19611943273672036, 0.12827912159264088, 0.422760293419872, 1.717220466051783, 4.323639469487326, 22.37436502320426, 56.922661849430625, 92.91035965510777, 115.87623350960868, 119.91433198111397, 100.98036575317383, 101.42869131905692, 92.4019877570016, 85.41194016592843, 81.20227677481515, 72.05117961338588, 71.36326626368931, 63.77019146510533, 70.02794756208147, 67.13737188066754, 62.981668199811665, 69.65942205701555, 71.12135778154645, 74.16554423740932, 82.27728816441127, 95.14914567129952, 110.10920088631767, 102.83698000226701, 90.7740317753383, 77.95031833648682, 75.10348851340157, 74.912399155753, 74.42571258544922, 77.5754143851144, 74.65748364584786, 68.7416831425258, 78.87147576468331, 81.65775203704834, 82.19477135794503, 77.43235792432512, 70.94087832314628, 74.84341049194336, 70.0486809866769, 68.88094588688442, 67.6723484311785, 74.6669887815203, 77.20082310267857, 80.45182963779995, 82.8616941996983, 94.38052899496896, 98.15845217023576, 88.24763897487095, 69.0730983189174, 47.61693947655814, 15.70967377935137, 1.8950512494359697, 1.2999432512692042, 0.20250486795391354, 0.07783165108412504, 0.03617373321737562, 0.1191406391028847, 0.165134049685938, 0.011851963537212993, 0.024002840409853628, 0.05802704593432801, 0.13603472257299082, 0.005038668734154531, 0.07581966583217893, 0.05778504641992705, 0.09161977443311896, 0.023376729006745985, 0.1176805810204574, 0.03955980616488627, 0.01343550142233393, 0.02776817202435008, 0.01798779031793986, 0.05520610444779907, 0.0172564873272287, 0.04597886957760368, 0.01465079580832805, 0.020270114099340777, 0.07929799918617521, 0.039791648010058064, 0.07596513016947679, 0.017078621246452843, 0.022765044954472353, 0.030475267209112644, 0.0554456578434578, 0.0403013431600162, 0.06857678626797029, 0.05071058264002204, 0.0023332030936476906, 0.01692824431561998, 0.04272566057209458, 0.04838753318680184, 0.04072000265919736, 0.048605468456766436, 0.036116838056061945, 0.050851158132510524, 0.06325051707348653, 0.07100052692528282, 0.0779622555045145, 0.059084108498479636, 0.1071206151640841, 0.06020774891866105, 0.047703495249152184, 0.09739535594625132, 0.027042149732421552, 0.04350130752261196, 0.06087307286049638, 0.05359959475962179, 0.1202214096805879, 0.06917475882385458, 0.09358226734080485, 0.05466914236811655, 0.16496026329696178, 0.09697294075574193, 0.11406899695949894, 0.0965450769290328, 0.14623148898993218, 0.1813857504831893, 0.1151426157781056, 0.1101350069844297, 0.26935052818485666, 0.25895121906484875, 0.1857419724443129, 0.22209791945559637, 0.294952034418072, 0.20325504269983086, 0.20794534816273622, 0.17945698755128042, 0.22372451717300074, 0.22267194651067257, 0.1496259689863239, 0.09611591710043804, 0.08370324530239616, 0.10177842753806285, 0.1629844643175602, 0.1079897778108716, 0.1458877431494849, 0.27131211864096777, 0.12427419078137193, 0.3406071002994265, 0.17534153695617402, 0.14266577389623436, 0.19773536388363155, 0.2548435037689549, 0.1457529996654817, 0.14499906583556108, 0.1364232517246689, 0.1614562813192606, 0.10246697094823633, 0.19178866940949643, 0.1073403994419745, 0.12434315708066736, 0.11455214103417737, 0.0721385455025094, 0.14157045552773134, 0.1819703219724553, 0.11622277567429201, 0.13410114204244955, 0.17983400874904223, 0.12376786795045648, 0.19432663465184824, 0.10476751678756305, 0.09390759095549583, 0.13750580006412097, 0.11489952382232461, 0.4391788866903101, 0.13966761263353483, 0.18823123244302614, 0.15940867976418563, 0.29676640991653713, 0.18322411897991384, 0.22486905647175653, 0.47065810752766474, 0.3205346773777689, 0.2561730795672962, 0.5898789901818547, 0.48058138361998964, 0.7478237577847072, 9.098950062479291, 33.51222835268293, 79.74878311157227, 127.91339002336774, 149.65013449532645, 135.2358602796282, 125.61799703325543, 108.5902065549578, 98.33110100882394, 95.01083483014787, 87.35500390189034, 91.52858529772077, 85.64806774684361, 87.30534512656075, 84.92665713174003, 82.69604219709123, 90.08062934875488, 84.14659677233014, 85.11817727770124, 101.8093066896711, 123.22531536647251, 143.8396339416504, 132.00312750680106, 117.70058032444545, 99.65261363983154, 90.00979941231864, 93.39489228384835, 89.37507452283586, 93.88860348292759, 91.03132356916154, 86.09004265921456, 96.63759572165353, 98.51483917236328, 103.68478529793876, 95.91221073695591, 84.70373112814767, 88.53458568028041, 82.24105330875942, 84.47141810825893, 87.2047769001552, 94.35300718035016, 93.64113644191197, 101.58750629425049, 108.6015043258667, 127.21509606497628, 123.18760054452079, 99.75935881478446, 63.018660409109934, 30.720334461757115, 5.484825023583003, 0.28377243716801914, 0.7830048756940025, 0.35414645235453335, 0.12170646499310221, 0.1127205646729895, 0.2031176257878542, 0.2832969198269503, 0.11310848992850099, 0.16843721243952, 0.1516220833041838, 0.2835830716150147, 0.10793685886476721, 0.15899272422705377, 0.15299988937165054, 0.16448059332157883, 0.0814408738432186, 0.23433738840477808, 0.11317251649286066, 0.12239790574780532, 0.1849955160702978, 0.12260715237685613, 0.11990434383707387, 0.10498595078076635, 0.12039264477789402, 0.16386223078838416, 0.1312717052974871, 0.1348089219204017, 0.10487264900335244, 0.14157288468309812, 0.10609072114207915, 0.0938609688143645, 0.06696808830435787, 0.14847483432718686, 0.15743859404964106, 0.1648883657263858, 0.13789650052785873, 0.096309123161648, 0.1001201897327389, 0.0618469538167119, 0.09656876458653382, 0.15241077169775963, 0.18184083034949644, 0.1830905425761427, 0.19138241692313127, 0.10361918447805302, 0.16075348188834532, 0.3034362734428474, 0.1698087624141148, 0.18898714759520122, 0.08797162412000553, 0.18295077793300152, 0.13147059748215334, 0.11564038906778608, 0.16868802612381323, 0.15864509716629982, 0.14817470471773828, 0.19817574668143476, 0.13691863657108375, 0.17732589904751095, 0.12161552772990294], [0.040565486664750745, 0.014134452711524708, 0.05578712719891753, 0.0874505363670843, 0.03145828803202935, 0.04149694561160036, 0.056421479409826655, 0.08711825098310198, 0.10874907885278974, 0.04360723701704826, 0.020886474954230443, 0.08707144563751561, 0.09516923861312014, 0.009282208081068737, 0.05413280454065118, 0.07361891213804483, 0.017226969357579947, 0.039191633063767634, 0.02329362373399947, 0.033644538040139844, 0.021134321744154607, 0.048653356065707545, 0.036105017976037095, 0.0204708654699581, 0.06593290170920746, 0.05742785201541015, 0.022219507888491665, 0.06504723709076643, 0.020205529439928274, 0.00838417122473142, 0.028665655026478425, 0.0635723869449326, 0.06709776991712195, 0.04542793985456228, 0.034887410633798153, 0.028016368259808848, 0.010667536557385964, 0.05303868039378098, 0.027114345858405744, 0.09582866608564343, 0.05481182810451303, 0.03446882916614413, 0.025901016679459384, 0.020602279043357288, 0.0606089938165886, 0.036562347185931036, 0.04365315687443529, 0.03354895620473793, 0.016845841326617768, 0.019240566130195345, 0.04588084840880973, 0.0736368526039379, 0.04627765229504023, 0.0026422096374777277, 0.048508916316287856, 0.0522870298341981, 0.01774673566355237, 0.04956981599596994, 0.056404957082122564, 0.06810822391084262, 0.04471472830378583, 0.042863118196172376, 0.08707938449723379, 0.07487853776131358, 0.16650961658784322, 0.0315213714327131, 0.023120573555518473, 0.13908354326018266, 0.011500715643965771, 1.7350586631468363, 8.671782629830496, 27.780298028673442, 55.941465037209646, 82.99585001809257, 100.91134929656982, 109.13202708108085, 100.87567724500383, 103.62477370670864, 93.72850309099469, 88.80361992972237, 83.08953257969448, 80.24336283547538, 82.71253027234758, 93.42517253330776, 99.50349140167236, 79.80322224753243, 44.97707911900112, 23.675323145730154, 46.3936048916408, 69.38044493538993, 83.35059029715401, 91.19548865727016, 98.44002791813442, 98.68239498138428, 101.86023698534284, 111.59519127437046, 108.64971092769078, 88.92572757175991, 67.14183957236153, 65.48931476048061, 58.092637743268696, 102.04041072300502, 99.88961669376918, 100.92406449999127, 92.75137097494942, 96.64044448307583, 99.7092206137521, 93.23984323229108, 72.08823435647147, 49.4448368208749, 23.14627514566694, 6.0932996187891275, 0.485558736537184, 0.09623806018914495, 0.1741536935525281, 0.04759193052138601, 0.05380089913627931, 0.060833269996302466, 0.054838267221514664, 0.009803619834461381, 0.07125682995787688, 0.014019186575231808, 0.05069707979315093, 0.038586244120129516, 0.022263626235404184, 0.14447837163295063, 0.016376822654690062, 0.044812908928309164, 0.017961997505543486, 0.010518433576050614, 0.07276784602020468, 0.042478782390909534, 0.02058943946446691, 0.07212017077420439, 0.019753535211618458, 0.051692402455955744, 0.05599495908245444, 0.06142632995865174, 0.016530015505850315, 0.040131526200899055, 0.08450509727533374, 0.06761650315352849, 0.05581045862553375, 0.03841730247118643, 0.023842914794970835, 0.04594022022294147, 0.003606528975069523, 0.0130649542968188, 0.022601935314014554, 0.0074396326672285795, 0.021964626386761665, 0.060598809005958695, 0.037648766567664485, 0.03096187181238617, 0.03674140918467726, 0.0494631061862622, 0.10900811638150897, 0.07266525831073523, 0.013725714242484952, 0.027624392150236026, 0.06342468344207321, 0.037015160745275874, 0.06328791792371444, 0.034356063431394954, 0.07594377667243991, 0.0532400865506913, 0.03480453436662044, 0.06229875635887895, 0.058507408015429974, 0.03290709939652255, 0.05643100943416357, 0.016933377433036054, 0.0516107950492629, 0.012720808968879282, 0.03906546965507524, 0.022139584944982613, 0.09420227192874465, 0.051522836554795504, 0.0661228575876781, 0.008135181103300835, 0.04070033871435693, 0.0573917810938188, 0.04688328551128507, 0.0700696718745998, 0.04939748167193361, 0.05593722253771765, 0.0732035469263792, 0.007685112218106431, 0.06122853700071573, 0.04499807434954813, 0.07498223826821361, 0.04215592185833624, 0.036130425719810386, 0.04653734800272754, 0.04037640948912927, 0.02753096296718078, 0.037027750962546895, 0.016487992135807872, 0.03624078944059355, 0.010488790925592184, 0.039157234730997255, 0.037498152149575095, 0.023779271602896706, 0.018275456935433403, 0.02974380985168474, 0.011819296316908938, 0.03436054515519312, 0.07653897402009793, 0.01097658890232976, 0.07941345191959824, 0.022862801494609033, 0.011904840074878718, 0.032592757871108394, 0.030345415962593894, 0.02889732045254537, 0.004287902390517826, 0.03505214197295053, 0.030579381622374058, 0.013576504391884165, 0.046017719100096395, 0.08703701677066938, 0.02525986045865076, 0.05877485937838044, 0.06809867692313024, 0.047465051258248944, 0.014242156575034772, 0.04378650936165026, 0.06485150009393692, 0.02098902704061142, 0.053985433519950936, 0.04112011779631887, 0.04612385215503829, 0.01873532386629709, 0.03019115441877927, 0.09655609633773565, 0.051421012197222025, 0.03881454401250396, 0.14013721314924105, 0.19094503325011047, 0.021920329924406748, 0.17176867010337965, 0.0661315360505666, 0.15638735331594944, 0.9734530448913574, 1.8306748867034912, 9.930667672838483, 29.5944379397801, 61.59808036259243, 91.08991772787911, 106.23734501429966, 119.41804994855607, 121.70584160940987, 117.30854906354631, 113.74044064113072, 112.19325051988874, 109.05725751604352, 105.58272743225098, 105.02813611711774, 104.09490271977016, 106.86527456556047, 111.71105248587472, 100.44258907863072, 66.86296667371477, 33.18608338492257, 60.68498979296003, 88.2864168712071, 104.70070225851876, 109.38840866088867, 114.22905881064278, 112.3071106501988, 118.9038415636335, 131.4508568899972, 128.34403937203544, 103.94078472682408, 88.82793862479073, 89.84439059666225, 84.4285477229527, 116.86098779950822, 110.41486603873116, 114.18657057625907, 108.31482860020229, 107.71695695604596, 109.6970545904977, 102.54535021100725, 91.00289154052734, 75.97047083718437, 45.679597582135884, 20.728105749402726, 3.3808753149850026, 0.3529007706258978, 0.4149238110652992, 0.06353025670562472, 0.11164089332201652, 0.09567007888108492, 0.0328293630321111, 0.04828641450564776, 0.04618110015456166, 0.06893081869930029, 0.0167554350170706, 0.031136849030320133, 0.07847430517098733, 0.09471739535885197, 0.03685424955827849, 0.07798419254166739, 0.02956764859014324, 0.03694292390719056, 0.03455336784411754, 0.03698651299678853, 0.03767566030312862, 0.04717967300010579, 0.08667217527649232, 0.04052551416680217, 0.05722454935312271, 0.03755682507263763, 0.02923434540363295, 0.05174174552251186, 0.0659148051802601, 0.05207256866352899, 0.02360186692593353, 0.03129919871155705, 0.022428820674706782, 0.031779021357319186, 0.01533911021293274, 0.014867664081975818, 0.02769549922751529, 0.023741032761920775, 0.03927845501207879, 0.01746338283243988, 0.05252151118059244, 0.0649602489013757, 0.015076717328546303, 0.04728388919362, 0.08375033563269035, 0.038591441698372364, 0.010114645868140672, 0.03034866614533322, 0.061232411435672214, 0.06979006116411515, 0.08140350691974163, 0.03929487895220518, 0.059529159617211135, 0.08718775332506214, 0.05126911874062248, 0.06225308416677373, 0.10274732126189129, 0.03534953369359885, 0.0764587711808937, 0.014733443069936973, 0.024583450950948254, 0.02870742224955133, 0.16248597178075994, 0.08772176717008863, 0.16031835095158645, 0.11415722008262362, 0.10133094047861439, 0.15095904602536134, 0.07631665202123777, 0.1630397377801793, 0.15813406530235494, 0.16745689218597754, 0.13734491941119942, 0.17431698979011603, 0.2042916677892208, 0.13317578312541756, 0.16916555192853722, 0.1448421613978488, 0.2508673428424767, 0.11710891526724611, 0.13709895046693937, 0.08805655634828977, 0.1208642130451543, 0.10795778488474232, 0.16981691840503896, 0.1616403135870184, 0.1097454803862742, 0.13709786481090955, 0.1580179679606642, 0.12052710327718939, 0.09667054483933107, 0.1963723905916725, 0.14741896598466805, 0.0951701139232942, 0.11053771073264734, 0.14380573986896447, 0.13713973042156014, 0.20840227364429406, 0.0836461465805769, 0.1324640813150576, 0.08746899930494172, 0.13159539364278316, 0.12592484935053758, 0.12224837020039558, 0.13641900409545216, 0.12563553558928625, 0.1306263506412506, 0.17070159236235277, 0.20577099626617773, 0.0735818301992757, 0.10766741260886192, 0.20482804972146237, 0.06196098841194596, 0.13633516430854797, 0.13538687090788568, 0.12062937207520008, 0.11692693217524461, 0.1935045759060553, 0.09272935560771398, 0.1300472074321338, 0.07687818046127047, 0.2645486444234848, 0.14798365639788763, 0.15727364218660764, 0.14371823599295958, 0.1882850674114057, 0.3060997405222484, 0.27354911289044787, 0.24220226066453115, 0.10853255832833902, 0.2006208204797336, 0.28000005387834137, 0.2684726395777294, 2.4768232660634175, 13.301323924745832, 43.22008466720581, 84.12539087023053, 120.34424482073102, 150.37729127066476, 162.51732281276156, 158.48392132350375, 160.06352479117257, 150.6776341029576, 146.885098866054, 146.16193035670688, 143.64573751177107, 139.2519051688058, 144.5479610988072, 141.7166952405657, 119.74811717442104, 78.07448264530727, 35.596507276807515, 62.815481185913086, 96.77459335327148, 123.39672742571149, 135.5145664215088, 141.96919277736117, 142.05036163330078, 144.47743688310896, 156.13089997427804, 154.23084558759416, 125.54479081290108, 107.18244593484062, 102.19593225206647, 107.67168249402727, 141.34161758422852, 134.4341493334089, 143.7441517966134, 133.69779314313615, 129.41083799089705, 127.8663090297154, 119.76665496826172, 97.9942523411342, 70.90557452610561, 32.568325996398926, 10.730947290148054, 1.0125547924212046, 0.16361970880201884, 0.3639019674488476, 0.1989110615104437, 0.26476273579256876, 0.11841495947114059, 0.13867182178156717, 0.2117319128343037, 0.23390852713159152, 0.13631801094327653, 0.2412667508636202, 0.14880757432963165, 0.2699043484670775, 0.20589960579361233, 0.1369705173586096, 0.21254633127578668, 0.06925806256809405, 0.1543685487870659, 0.1317840399486678, 0.10956421654139246, 0.13899749144911766, 0.18060353531369142, 0.09870327290679727, 0.17877852038613387, 0.19991876743733883, 0.16811642822410378, 0.15507293598992483, 0.15612231753766537, 0.12789226163710865, 0.09901075105049781, 0.10002730507403612, 0.0996883496908205, 0.17249496041664056, 0.11949095316231251, 0.09034391146685396, 0.08899360642369304, 0.09831216532204833, 0.06900343551699605, 0.12664792340781006, 0.11376358834760529, 0.15188880184931414, 0.16552253812551498, 0.13010003816868576, 0.14213505094604834, 0.13952076408479894, 0.24036096089652606, 0.1143005538199629, 0.08480002252118927, 0.2524753894124712, 0.2331534805042403, 0.15162711803402218, 0.25001930977616993, 0.21219415803040775, 0.14584760101778166, 0.06969056757433073, 0.20284106848495348, 0.2144651333136218, 0.16072604193219117, 0.13195044387664112, 0.15271111843841417, 0.20273323569978985, 0.11174749117344618, 0.30314740751470837, 0.17770442659301416], [0.07164108433893748, 0.02486103114538959, 0.05033077605600868, 0.042493099479803016, 0.04150733398273587, 0.048163273970463445, 0.09770640996950013, 0.016306526426758085, 0.02473237581684121, 0.05645089729556015, 0.02668788659918521, 0.08187781646847725, 0.10089295969477721, 0.017856079885470014, 0.08953720796853304, 0.05009794354970966, 0.044818747722144635, 0.02119022115532841, 0.015134062019309827, 0.04937218249376331, 0.03479708065944059, 0.017963281633066278, 0.03494678244792989, 0.03223138369087662, 0.02637204890405493, 0.024492537436474646, 0.024223121714645197, 0.061347803100943565, 0.03991230171439903, 0.020285713619419506, 0.0682775726807969, 0.05738062597811222, 0.023167882713356187, 0.01664214172134442, 0.037058614127870114, 0.0313883819617331, 0.01787273961651538, 0.031747832495187006, 0.006657746163130338, 0.05485171917825937, 0.010300989395805767, 0.07097058996026005, 0.027961244074893848, 0.0045759137886177215, 0.05389145302719303, 0.06769399185265813, 0.013401126838289201, 0.06732977461069822, 0.025163552590778897, 0.07747148469622646, 0.014793503597112638, 0.03919452362294708, 0.05924881608890636, 0.04406313791072794, 0.02276161665629063, 0.010847339007471288, 0.02138529658051474, 0.06033025163092783, 0.017812063318810294, 0.09309555417192833, 0.026945974178878323, 0.06553228784884725, 0.07509247985269342, 0.02948052469374878, 0.05169524212500878, 0.0185048356984875, 0.028424866697085754, 0.05666586058214307, 0.05674387514591217, 0.08210737843598638, 0.14452057651111058, 0.35950747611267225, 0.08935576091919627, 0.9118910282850266, 6.083559547151838, 13.708068864686147, 16.963856628962926, 33.19093322753906, 40.10146910803658, 26.47557919366019, 22.528014012745448, 22.172945431300572, 17.111540590013774, 13.439209188733782, 7.975389003753662, 2.055719005210059, 0.06867752157683883, 0.5294936075806618, 0.23836256670100348, 0.4361322915979794, 2.1549981236457825, 2.8164926852498735, 5.9767496670995435, 10.354703204972402, 5.661654940673283, 9.235304985727582, 8.247853057725088, 1.6830342433282306, 0.6504645677549499, 0.3664301617869309, 0.452183336019516, 3.1921366197722296, 6.5025420018604825, 7.991955246244158, 4.137419496263776, 3.3487005957535336, 1.6179114920752389, 0.6569100533212934, 0.13558907434344292, 0.08246889510857207, 0.6901310735515186, 0.1868869052933795, 0.041149739242557964, 0.02961186532463346, 0.03322955280808466, 0.04212660236018045, 0.051401684127215824, 0.0680436205917171, 0.02481751160563103, 0.025968971961577023, 0.037824819263603, 0.01703710338499929, 0.022028639380420958, 0.04724278014951518, 0.04434783084850226, 0.03720609710684844, 0.03601283560107861, 0.008266260498203337, 0.029067395254969597, 0.03938446253804224, 0.0571746023904, 0.04487325444019266, 0.03051551790641887, 0.04366214407075729, 0.07155092060565948, 0.028065867389419248, 0.05557774825553809, 0.06283613573759794, 0.02703217017863478, 0.022007114553291882, 0.01596457022242248, 0.023462641718132154, 0.06810955383947917, 0.06936514217938695, 0.012326198447096561, 0.01953595956521375, 0.04036967163639409, 0.02405263639853469, 0.029300407573048557, 0.029125253936009746, 0.032754357771149704, 0.03719791736719864, 0.025781080525900637, 0.0260433580593339, 0.03201809299311467, 0.06467586808970996, 0.022712977569816366, 0.057522643357515335, 0.021596838354266117, 0.03221996733918786, 0.023638226224907806, 0.03552886710635253, 0.059562292482171736, 0.04168492695316672, 0.047045160218008926, 0.028378733101167848, 0.04829335591888853, 0.023659611952358058, 0.06636058233146157, 0.06186752699847732, 0.04162974848545023, 0.035982617044023106, 0.013019824932728494, 0.07106747119022266, 0.038368858463530026, 0.10937295787568603, 0.049003412281828265, 0.035017000644334724, 0.06475425245506422, 0.04604528458522899, 0.018549366255423853, 0.14686925762466022, 0.022317518879260336, 0.07475675429616656, 0.03149785001629165, 0.03376996184566191, 0.04746445414743253, 0.06435317719089133, 0.022860058516796147, 0.006944944167376629, 0.034081192288015566, 0.007238440248849136, 0.043680769857019186, 0.010381713858805597, 0.05613070001293506, 0.07403644866177014, 0.06538440792688302, 0.003480535836258371, 0.04158531801242914, 0.051343937404453754, 0.0318921704643539, 0.04200805889974747, 0.07269593487892832, 0.012887329944143338, 0.04167874549914684, 0.01438652677461505, 0.0048193327134608156, 0.015307329328996795, 0.020619216973760297, 0.08486056141555309, 0.01688895035269005, 0.027084946632385254, 0.013286199969505625, 0.016155391233041883, 0.02270765955160771, 0.04677632125094533, 0.038377319795212576, 0.03160963187526379, 0.019417902953656654, 0.017032538540661335, 0.02979977202734777, 0.06912465579807758, 0.009836681453245026, 0.047758348020059724, 0.012534025241620839, 0.03235705855435558, 0.021219533868134022, 0.07939808310142585, 0.05153410362878016, 0.05152513678850872, 0.07427401055714913, 0.03289549984037876, 0.0679599368678672, 0.01471027109905013, 0.02890346458713923, 0.09746065815644604, 0.10229369346052408, 0.03401454657848392, 0.05743730400821992, 0.06770012580922671, 0.1105309050264103, 0.02680631640500256, 0.07682749389537744, 0.07023129213069167, 0.0868911249563098, 0.07682791458708899, 0.2307436226734093, 1.1952101226363863, 1.5309977786881583, 7.307965891701834, 19.87614369392395, 34.457197257450645, 39.8984705380031, 62.41000516074044, 74.31810583387102, 54.51919310433524, 46.111101559230256, 43.55448409489223, 33.31358630316598, 31.33367279597691, 20.481382165636333, 5.889920200620379, 0.44376103367124287, 0.36440017500094, 0.12061049523098127, 0.8089549860783986, 4.863487575735364, 6.922039491789682, 13.479619911738805, 18.294049297060283, 12.056509852409363, 16.167183126722062, 14.785308020455496, 5.320768935339792, 2.380665408713477, 1.1510273963212967, 1.26481565620218, 9.824264696666173, 16.940571478434972, 18.874567815235682, 13.088528394699097, 12.437012314796448, 7.4216974803379605, 4.985589138099125, 1.7237442817006792, 0.45030680671334267, 0.2600919449967997, 0.3277931293206555, 0.07367985815341983, 0.0896580618407045, 0.037528852466493845, 0.03640175151771732, 0.10138082637318543, 0.08567306638828345, 0.043829511518457105, 0.07934948642339025, 0.03409587578581912, 0.05133521483678903, 0.03229208204096981, 0.07142923213541508, 0.09762475506535598, 0.022284976339765956, 0.05061768101794379, 0.024062488727005463, 0.047935208172670433, 0.029494753573089838, 0.05766753772539752, 0.034223871239061864, 0.030638502378548895, 0.04020384107051151, 0.025693529152444432, 0.04519774006413562, 0.04485656587140901, 0.026022314992068068, 0.05949095809566123, 0.02698844707837062, 0.016196381533518434, 0.07904758583754301, 0.025272542278149297, 0.02923083059223635, 0.01744124053844384, 0.027285250169890266, 0.047631115918712955, 0.00661480040954692, 0.026677408322159733, 0.02753152445490871, 0.03645646858162113, 0.04216594382056168, 0.009439364424906671, 0.023359745275229216, 0.017937894245343547, 0.08370208500751428, 0.05787038576922246, 0.02526771110881652, 0.0846170759094613, 0.07474710552820138, 0.011474452097900212, 0.024486218579113483, 0.023490307287179997, 0.018616083211132457, 0.050821960770658085, 0.039516424028468985, 0.01914023794233799, 0.03874223932091679, 0.07680362981877156, 0.044856596405484846, 0.06696629018655845, 0.027236648402842026, 0.01722554613037833, 0.009138004122568029, 0.022365693169246827, 0.073138991104705, 0.14062125289014407, 0.18336085735687188, 0.26315162224428995, 0.10737330839037895, 0.11437383560197693, 0.2948154860309192, 0.20506902464798518, 0.20601254116211618, 0.11355199398738997, 0.15533361557338918, 0.11525105924478599, 0.14085067915064947, 0.2358080723455974, 0.129741174568023, 0.1603961382061243, 0.1352458849017109, 0.13324280881455966, 0.08978952121521745, 0.22785843749131474, 0.16349556403500692, 0.15195376479199954, 0.102137705045087, 0.10083387286535331, 0.07450651058128901, 0.05389321043289133, 0.11418829698647771, 0.18253482239586966, 0.16342446713575295, 0.183673159884555, 0.16656988406819956, 0.17211206310561725, 0.1589046096695321, 0.19933723578495638, 0.11683199155543532, 0.1190459563263825, 0.19665278840277875, 0.151583230389016, 0.2974175864032337, 0.06327762454748154, 0.10952399977083717, 0.10483661200851202, 0.13914307792271885, 0.10767517504947526, 0.1399575099349022, 0.1107453763751047, 0.11172575091144868, 0.07581902800926141, 0.18060855647282942, 0.07067740176405225, 0.1420749191726957, 0.063023160344788, 0.16205322928726673, 0.19835694267281465, 0.10554566753229924, 0.1702453318451132, 0.17705088880445274, 0.1478078072624547, 0.11739247505153928, 0.07444764766842127, 0.26144043835146086, 0.18843625858426094, 0.17155577295592853, 0.1483841820486954, 0.27364823328597204, 0.3177044806735856, 0.1805705992238862, 0.15863747043269022, 0.24714088280286106, 0.1546474809625319, 0.23193190033946717, 0.25423713773489, 0.5135414121406419, 0.2577612857733454, 1.7288247176579066, 7.662898983274188, 17.111538852964127, 24.21154863493783, 44.56541919708252, 62.58717032841274, 42.65375437055315, 35.5309544972011, 34.04486336026873, 26.031431232179912, 23.37246332849775, 14.260507106781006, 3.5095561700207845, 0.31307413056492805, 0.7271669262221881, 0.2721171868698937, 0.6169982978275844, 4.082468364919935, 5.218745495591845, 12.338656221117292, 16.098929234913417, 10.259865505354744, 12.932212165423802, 11.11423076902117, 3.828448304108211, 1.5402816576617104, 0.6483750055943216, 0.6923179104924202, 6.20436874457768, 10.094389813286917, 11.083155819347926, 7.265264868736267, 6.35826222385679, 2.8681338684899464, 1.6162581465073993, 0.3948852877531733, 0.18397786282002926, 0.7569833834256444, 0.4112336119370801, 0.1147106196731329, 0.23503372818231583, 0.14811233377882413, 0.16650285837905748, 0.1422025923218046, 0.298757828772068, 0.09551060279565197, 0.10318818581955773, 0.21382460982671805, 0.09565525967627764, 0.21313493326306343, 0.11893136533243315, 0.19399815584932054, 0.11488720162638597, 0.14909407895590576, 0.1207315187369074, 0.10501398106238671, 0.08196440432220697, 0.1695152417357479, 0.10274161478238446, 0.13729816834841455, 0.07648924418858119, 0.10251359987471785, 0.1413424949028662, 0.13707586670560495, 0.1585066353103944, 0.1660130510904959, 0.15257423078375204, 0.055330374743789434, 0.15095349560890878, 0.11272731609642506, 0.14441169878201826, 0.07926397744034018, 0.08339453901031188, 0.07724596001207829, 0.08308448243354048, 0.11357159686407872, 0.11320596826928002, 0.10217508553926434, 0.08562109739120517, 0.06482151563146285, 0.051251076494476626, 0.06828914170286485, 0.13251335652811186, 0.0887830705781068, 0.1587916471596275, 0.20905583857425622, 0.16503786056169442, 0.1679097464574235, 0.200283357873559, 0.11121029499918222, 0.12025931264672961, 0.20141952405018465, 0.11739312644515719, 0.22690553005252564, 0.07780058775097132, 0.1518286293638604, 0.19731438718736172, 0.16195242612489633, 0.09755201611135687, 0.13190458848008088, 0.19556167695139134, 0.16473752739174025, 0.17671468827341283], [0.025951155328324864, 0.02984351378732494, 0.01849143802454429, 0.006306337117816189, 0.028324009251913855, 0.05416576437918203, 0.047974722659481425, 0.00928879835243736, 0.0603587365310107, 0.09545068136815514, 0.051975952062223635, 0.04688691567363484, 0.020613413803013306, 0.04619964112394622, 0.05115032082955752, 0.022679447761869857, 0.028187370958871076, 0.010371599446183868, 0.01461555269945945, 0.049676325637847185, 0.03247222291039569, 0.025488759158179164, 0.013326152959572417, 0.0337686115609748, 0.051383967577878914, 0.01976755035242864, 0.01693770139744239, 0.0025726642509523246, 0.04895405225189669, 0.018979564242597138, 0.020497170576293553, 0.02606393802644951, 0.012059953180141747, 0.028113622684031725, 0.038934709171631506, 0.07599497213959694, 0.037762431361313374, 0.029423415793904235, 0.048066182394645045, 0.0021435994172601825, 0.044916650147310326, 0.07238525404993977, 0.07342366368642875, 0.03491858592522996, 0.03718644334003329, 0.016619376871468763, 0.01997291576117277, 0.05072346802002617, 0.005946502363907972, 0.05255858972668648, 0.01738248619117907, 0.09904963789241654, 0.02972541137465409, 0.007844551832282116, 0.04142598441935011, 0.11964019015431404, 0.02604384151553469, 0.050062632587339194, 0.040285960771143436, 0.025906562006899288, 0.06338784577591078, 0.040002987919641395, 0.044752074871212244, 0.059115592523344924, 0.10085497530443327, 0.0331139134775315, 0.06441248793687139, 0.07254979879196201, 0.02303108835725912, 0.009215243460078324, 0.01771103623988373, 0.27899924186723574, 0.048026871468339644, 0.0844164127483964, 0.14919537066348962, 0.37097808346152306, 0.4445220242653574, 0.43410613174949375, 0.6138389302151543, 0.28593006996171816, 0.5685605598347527, 0.45455698722175186, 0.4213469592588288, 0.37348228480134693, 0.22585081521953854, 0.11233262584677764, 0.02891503700188228, 0.10133819401796375, 0.10465099875416074, 0.07868631343756403, 0.05515183860968266, 0.028489225743604556, 0.1326039545238018, 0.3481062150427273, 0.17328210175037384, 0.4469165472047669, 0.4877619668841362, 0.03147196051265512, 0.03359627045158829, 0.06488122671310391, 0.03432133261646543, 0.2009861980165754, 0.35119846197111265, 0.3500936169709478, 0.18774727412632533, 0.16197278217545577, 0.05912314461810248, 0.0750543868967465, 0.16122553870081902, 0.202189457735845, 0.1945908833295107, 0.06417156729315009, 0.05094176969890084, 0.02308909292332828, 0.045646149931209426, 0.04072931215965322, 0.04906211234629154, 0.07574597692915372, 0.039329569055033584, 0.05358918263976063, 0.08684268434132848, 0.022405270420547043, 0.02457812105837677, 0.059927330751504214, 0.017120485160765902, 0.02439740004150995, 0.07527814738984619, 0.05276527827871697, 0.015539578295179775, 0.050075640103646686, 0.06612017058900424, 0.02276317898317107, 0.04794065680887018, 0.027967584984643117, 0.0244825443119875, 0.034635887880410464, 0.043729929719120264, 0.01572075393050909, 0.02746963357952024, 0.04150406683662108, 0.04094462828444583, 0.015497750003955193, 0.040688562739108286, 0.013555223837361803, 0.014690574923796313, 0.011905155593662389, 0.00795625990057098, 0.041282213026923795, 0.03212539991363883, 0.021538316405245235, 0.024936874397099018, 0.027312301664746234, 0.061596615106931756, 0.0776149405698691, 0.0632850748619863, 0.023807576691199626, 0.035837349481880665, 0.030662067899746553, 0.018735612243680016, 0.024742774366001998, 0.031131648059402193, 0.055321933768157444, 0.022808710379259925, 0.016584225364827683, 0.023912970142971193, 0.010682789176436407, 0.02306328823656908, 0.06161703222564288, 0.025735577967550074, 0.06178898657006877, 0.06254680840564625, 0.02513895569635289, 0.014848405561809028, 0.025619804626330733, 0.015546677467812384, 0.020589352951252034, 0.05137997779196926, 0.03717940353921481, 0.02778560358897916, 0.03351575887895056, 0.05557727328102503, 0.03884328675589391, 0.011263901833444834, 0.04660802421026996, 0.05345355366755809, 0.03246395496119346, 0.010123845106655998, 0.03655249146478517, 0.04685231038768377, 0.017800229668085064, 0.06683852882789713, 0.032045020655329735, 0.03314099720280085, 0.06155574694275856, 0.016013607948220203, 0.07807268707879952, 0.058151462115347385, 0.016555399500897953, 0.02668732511145728, 0.03773286419787577, 0.03444778440254075, 0.08330392065857138, 0.08827973330127341, 0.031734414465193234, 0.027066817873024514, 0.0295904100473438, 0.0678031477811081, 0.028276683130700673, 0.04774232441559434, 0.02609127450601331, 0.0576148834079504, 0.044968147562550645, 0.0929898452013731, 0.06560429398502622, 0.05171121483934777, 0.03449471188443048, 0.031368107335375886, 0.013422547340659159, 0.035513674707284996, 0.04062299929293139, 0.03658204845019749, 0.033550717003111324, 0.01745782054162451, 0.04869071959650942, 0.012498981452413967, 0.03937115307365145, 0.022569195999364768, 0.006340754958468356, 0.030947025466178144, 0.0490711673961154, 0.04726193180041654, 0.021380763966590166, 0.014420173629852278, 0.03744803894577282, 0.0853535985308034, 0.005654046561435929, 0.14944804353373392, 0.005585636236771409, 0.09952871754233326, 0.02769265277311206, 0.16227215182568344, 0.04736459754141314, 0.04160513123497367, 0.1256488755877529, 0.02970043450061764, 0.021826980469216193, 0.01489283433849258, 0.14685726112553052, 0.12457313973988805, 0.08071214758924075, 0.09270812424698047, 0.354307373719556, 0.4220497044069426, 1.0562076100281306, 1.4980724368776595, 0.42693930917552536, 0.4019707946905068, 0.10619906961385693, 0.12678976436810835, 0.2987469993531704, 0.41167848663670675, 0.2597008916948523, 0.033003695641777346, 0.11057798857135431, 0.007236883859150112, 0.03701196823801313, 0.18335937815053122, 0.10378847217985562, 0.2721758937197072, 0.2839500776359013, 0.22412672559065477, 0.3257561943360737, 0.40436504621590885, 0.11082032056791441, 0.050453926769218276, 0.05268576754523175, 0.026922926040632383, 0.29417741884078297, 0.5202578774520329, 0.31152717928801266, 0.21703424331332954, 0.5098604410886765, 0.272763586470059, 0.13950685411691666, 0.11167439259588718, 0.1330464950629643, 0.058903000716652186, 0.18338711666209356, 0.0602520504700286, 0.05404548386910132, 0.05231668859986322, 0.028634466164346253, 0.02666900127327868, 0.10955411315496479, 0.030162496492266655, 0.04115506234977927, 0.038431829905935695, 0.027955873470221246, 0.028672467518065656, 0.07116347032466105, 0.025030157695125257, 0.092358841560781, 0.1029295554118497, 0.03127154162419694, 0.007484595790239317, 0.06167162036789315, 0.015045338476608907, 0.01495990582874843, 0.03039880988321134, 0.012656203105247446, 0.046000528415398936, 0.10204583818891219, 0.05465707462280989, 0.01783222598688943, 0.033007115458271334, 0.05486081833285945, 0.023566096256087934, 0.014604071886943919, 0.06994596136999981, 0.021395389788917134, 0.011506197358747678, 0.03715390419321401, 0.02134234531383429, 0.01219371787738055, 0.029911574242370467, 0.0486611626110971, 0.011101645450772983, 0.03936198606554951, 0.05981959296124322, 0.07273413640047822, 0.02936035953462124, 0.05048029803271804, 0.06959966423788241, 0.017592075480414287, 0.01902668341062963, 0.07708505900310618, 0.03138142019244177, 0.04229100121717368, 0.022824179281347563, 0.054760463003601344, 0.045622988138347864, 0.03233242094782846, 0.02100077417812177, 0.0370347737999899, 0.017986177100933025, 0.018399557597669106, 0.033783573258135996, 0.027394667334322418, 0.0372613434280668, 0.030070839981947626, 0.025702551971854906, 0.05043271237186023, 0.1678219847381115, 0.1857097963137286, 0.13429209536739758, 0.11487690146480288, 0.1936054333512272, 0.13987293733017786, 0.16810139188809053, 0.09619230657283749, 0.1676358761531966, 0.12410697261137621, 0.09868055555437293, 0.12000777971531663, 0.1645990383944341, 0.12755433762712137, 0.13984643375234945, 0.1015699612242835, 0.27078484264867647, 0.15822954875017914, 0.07605275618178503, 0.17411280503230436, 0.24915197917393275, 0.11304760498127767, 0.08476016537419387, 0.12091234831937722, 0.08381302548306328, 0.12393117775874478, 0.10507952754518815, 0.12491330291543688, 0.10198125522583723, 0.0965362899005413, 0.2795281463435718, 0.16587047731237753, 0.12024148074643952, 0.19187271275690623, 0.21027428390724318, 0.10384116720940385, 0.2454188966325351, 0.10797429364174604, 0.17963033967784472, 0.09138021764478513, 0.13963356374629907, 0.15086205622979573, 0.19156491570174694, 0.16208893379994802, 0.1074717298948339, 0.11536323465406895, 0.19741649313696794, 0.126318521797657, 0.07711889754448618, 0.12383254590843405, 0.08995264103370053, 0.08574531001171895, 0.10900417409305062, 0.1110047735273838, 0.18947269368384564, 0.16639621981552669, 0.08390884141304664, 0.11333248112350702, 0.1269693590168442, 0.14011459079171928, 0.2761024401656219, 0.12596522218414716, 0.24754879091467175, 0.18326291761228017, 0.35286836379340714, 0.19909136183559895, 0.1766669601202011, 0.177713844659073, 0.17313613529716218, 0.08978766202926636, 0.142417864341821, 0.46184350337300983, 0.20496862860662596, 0.14088695363274642, 0.19382290382470402, 0.3060179906232016, 0.4647086582013539, 0.7420707036341939, 0.9016695224813053, 0.38134341154779705, 0.8331964910030365, 0.5113850821341787, 0.34153335488268305, 0.528079269187791, 0.45382007105009897, 0.3694740155977862, 0.13728195136146887, 0.20867778600326606, 0.1353903314364808, 0.19473534343498095, 0.2507089456277234, 0.14165747085852282, 0.44434679938214167, 0.42606850447399275, 0.33535437073026386, 0.5559725952999932, 0.5067649643336023, 0.17795705875115736, 0.17221498329724583, 0.11314242346478359, 0.12304387108555861, 0.35004364965217455, 0.5599773089800562, 0.35047172382473946, 0.2647874616086483, 0.5573849252292088, 0.19677685174558843, 0.18965273616569384, 0.13652086577245168, 0.23575582514916146, 0.29927354252764155, 0.3276433359299387, 0.09906223828771285, 0.1195531069700207, 0.1312739308923483, 0.15182778798043728, 0.2227350366967065, 0.19343214907816478, 0.10613804217427969, 0.16093081023011888, 0.2369172599698816, 0.16013039675142082, 0.16610565754984105, 0.14927237081740583, 0.11757619519318853, 0.14719207744513238, 0.23584151055131639, 0.18115304011319364, 0.11810678243637085, 0.18859183309333666, 0.1599545476159879, 0.09031294991395303, 0.1522121780685016, 0.1892410825405802, 0.07036463104720626, 0.2312035065676485, 0.15592216327786446, 0.11549662106803485, 0.11817686153309685, 0.1680383017020566, 0.09595296691570963, 0.14444278925657272, 0.10360230252678905, 0.09248708467930555, 0.23402249387332372, 0.11779281071254186, 0.1427195274404117, 0.09233417002750294, 0.13757795547800405, 0.08714737370610237, 0.10003556963056326, 0.15204034586037907, 0.1826271302998066, 0.1690449762557234, 0.1219983029046229, 0.21847467816301755, 0.1569126479859863, 0.08328797508563314, 0.06531335173973016, 0.11926308753234999, 0.13387095582272324, 0.15747946899916443, 0.06879365284528051, 0.16014347890658037, 0.12197724117764405, 0.12382447134171214, 0.08994631030197654, 0.09001136823956456, 0.13614638229565962, 0.09582474415323564, 0.12374113367072173, 0.18151239225906984, 0.11087336165032216, 0.1379918618393796, 0.10446840498064246, 0.13031560874411038], [0.03541662384356771, 0.025593502912670374, 0.01787773024157754, 0.01059383577999792, 0.04071554129144975, 0.04042045998253992, 0.030966017661350112, 0.019957496052873985, 0.06158812663384846, 0.0407061775081924, 0.03958000275971634, 0.037077982909977436, 0.06511701084673405, 0.03355491374220167, 0.06859780049749784, 0.03883510362356901, 0.11273952294141054, 0.045864600887788196, 0.017113280815205405, 0.049445250537246466, 0.045290522942585607, 0.0499855679725962, 0.025251212529838085, 0.02653297535809023, 0.05068381104086127, 0.0271491835426007, 0.052985245761062415, 0.038440084284437556, 0.05777104824249234, 0.05401378949838025, 0.03516098238261683, 0.043098247543509514, 0.016125688362600546, 0.05608697860900845, 0.029988119777824198, 0.020330027045149888, 0.00333950000016817, 0.0453380644986672, 0.05529439203175051, 0.021866830830861415, 0.03740967457581844, 0.04383414591263447, 0.08371006457933358, 0.03906089972172465, 0.03356005025229283, 0.03190040787948029, 0.04095306247472763, 0.04493090616805213, 0.06475729229194777, 0.029844799611185278, 0.02314400506604995, 0.009680219759632434, 0.10621675902179309, 0.05128656726862703, 0.04838242721078651, 0.04273163168025868, 0.02171693735622934, 0.025347547539110695, 0.04257598253233092, 0.017948786428730403, 0.07660351627107177, 0.05641776443059955, 0.00565635400458372, 0.01620283440154578, 0.030496396789593355, 0.01782703010498413, 0.04579139035195112, 0.10323573076831442, 0.024845755625782267, 0.01715055444011731, 0.06479596200266055, 0.14490218460559845, 0.19996424285428865, 0.1034445363496031, 0.07926248466329915, 0.1854811164417437, 0.21868876953210148, 0.08715401656393494, 0.20903818309307098, 0.12411782917167459, 0.1283025989042861, 0.2945263758301735, 0.18898431131882326, 0.14299136213958263, 0.0692781200632453, 0.01771022878321154, 0.11219170769410473, 0.13969275914132595, 0.10033684596419334, 0.029489627241023948, 0.03682569680469377, 0.06514848808624915, 0.08101743406483106, 0.11991684245211737, 0.16184840670653752, 0.15888732059725694, 0.12144911023122923, 0.03553048201969691, 0.04512287390285304, 0.04091111883254988, 0.04416671288864953, 0.16716227228088038, 0.09321017909262862, 0.08282570274812834, 0.05303860914760402, 0.025371041814131395, 0.014603030335690294, 0.022437137817697864, 0.07285173330456018, 0.183973778039217, 0.07312439581645386, 0.02746988463747714, 0.015298291242548397, 0.05899873522243329, 0.04229703000081437, 0.006921647515680108, 0.041759667585470846, 0.007925731761913215, 0.023191410915127823, 0.06261844813291516, 0.0509423905584429, 0.055778927103217156, 0.04105862895292895, 0.00992740412974464, 0.032887988457722325, 0.04031935487208622, 0.043264356308749745, 0.0062945021948378, 0.03282043011859059, 0.057996464361037524, 0.020819866564124823, 0.07197323401591607, 0.02639289349982781, 0.06488340481051377, 0.04250046158475535, 0.03152561906192984, 0.13887615581708296, 0.08679125817226511, 0.021106223609032373, 0.040035330291305266, 0.015856153897142837, 0.016030740957441073, 0.04958018401105489, 0.016630077368712852, 0.029373987910470793, 0.07400985008903913, 0.005043889212954257, 0.04507640443210091, 0.05233531438612512, 0.052322775058980496, 0.007789342830489788, 0.05088977016774671, 0.06663128387715135, 0.07606648294521229, 0.050003501653139076, 0.02447778608516923, 0.03102929105183908, 0.06600019881235701, 0.03875203736658607, 0.023639086268043945, 0.026631396862545183, 0.03654121082010014, 0.03490489308855363, 0.02465542994572648, 0.013519502361305058, 0.030781571487230912, 0.06625334665711437, 0.03634090388992003, 0.005139382414719356, 0.03507589748395341, 0.015432050850774561, 0.02343642821402422, 0.045182951393404176, 0.029651254282466004, 0.021974153018423488, 0.10224067951951708, 0.005440428894611874, 0.029556490081761564, 0.08241180317210299, 0.04719215804444892, 0.020432623236307075, 0.06613015862447874, 0.013777058987346078, 0.019603945381407226, 0.011633201302694423, 0.07087611074426345, 0.05903929804584809, 0.0744638985821179, 0.002219287454084094, 0.052719188787575276, 0.025404656438955238, 0.030608059904937233, 0.05613032342599971, 0.02983461140788027, 0.02289987325535289, 0.047156711375074725, 0.02727920951188675, 0.041850133266832144, 0.020503967800842862, 0.06799589922385556, 0.07171393185853958, 0.009790909177224551, 0.029987193577523743, 0.0325710176091109, 0.041528684087097645, 0.049848642998508046, 0.03263752421896372, 0.015889040793159177, 0.07266814886991467, 0.04421255810718451, 0.08384146967104503, 0.04947045132783907, 0.006629751504598451, 0.07371483663363115, 0.04046404228678771, 0.005822891095054469, 0.05196475623441594, 0.007029093535883086, 0.032607668678143194, 0.006954544589721731, 0.01841503837411957, 0.012790224797624563, 0.044480721931904554, 0.00850885288257684, 0.019881369512794272, 0.010576190476837968, 0.04133072488808206, 0.020593222297195877, 0.04475504346191883, 0.04191986291802355, 0.041716448297458034, 0.09643459107194628, 0.040053755909736664, 0.012076744377346975, 0.03857260217357959, 0.04968661901408008, 0.027944994857534766, 0.03805931078802262, 0.025556688995233605, 0.01596544383625899, 0.14913375968379633, 0.05696305552763598, 0.0422238669624286, 0.1350929295378072, 0.053769282797085385, 0.06386186355458838, 0.02321257781503456, 0.15233795131955827, 0.11038188516561474, 0.08787497359194926, 0.015638659674940363, 0.0295075236021408, 0.027979718887114098, 0.09390164020338229, 0.11543028748461179, 0.043087852387023826, 0.13830508717468806, 0.08163747936487198, 0.05490242949287806, 0.1842822672000953, 0.09196556944932256, 0.04312746865408761, 0.003591504937503487, 0.08103952716503825, 0.027122437388503125, 0.043539078174425025, 0.09055298167679991, 0.10520779780511345, 0.02948809035920671, 0.08923895790108613, 0.05355431951050248, 0.07937002567840473, 0.15957017109862395, 0.028929673002234528, 0.02831388550943562, 0.058792365581861565, 0.02279409473495824, 0.09939323445515973, 0.11433882319501468, 0.04195802712014743, 0.020403883885592222, 0.19530274798827513, 0.08402803287442241, 0.027500890295154283, 0.034958202192293744, 0.05538474575483373, 0.117348438128829, 0.09134388887988669, 0.07089755245085273, 0.07737469167581626, 0.0202579801968698, 0.025862065376713872, 0.073495934451265, 0.01998208276927471, 0.02907157163800938, 0.04423680216340082, 0.036238811511014185, 0.025601433290700828, 0.06536568036036831, 0.025593462200569253, 0.007782286914464618, 0.012451285529615623, 0.0460939253680408, 0.01551605518242078, 0.044603051617741585, 0.053209216600017886, 0.020553275244310498, 0.05764864731047835, 0.01185256997788591, 0.05315203306132129, 0.040042329380022626, 0.05350693062480007, 0.027249718683638742, 0.05827677396259137, 0.005369040225299874, 0.0030704294830294593, 0.02696655584233148, 0.020653501651915054, 0.0911487489938736, 0.043793946105454645, 0.03478728600644639, 0.059131049551069736, 0.044448745969150744, 0.04000972916505166, 0.03961731879306691, 0.07826157765729086, 0.01455762786125498, 0.09384099952876568, 0.044186471828392575, 0.04033295610653503, 0.006736497361479061, 0.04413636880261557, 0.028415452023702006, 0.06183227031890835, 0.029898519228611673, 0.0748416186709489, 0.06912527326494455, 0.017754379360537444, 0.03822314306827528, 0.042515888078404326, 0.014053133682214787, 0.007550554483064583, 0.03715234016999602, 0.054168936530394216, 0.045581889272268326, 0.11195394223822014, 0.01592029581245567, 0.03196656843647361, 0.048707442092044015, 0.11204726115933486, 0.07792639492877892, 0.0238845497037151, 0.11156841221132449, 0.09648989167596612, 0.21901609482509748, 0.11399082972535066, 0.14965370749788626, 0.0868879561977727, 0.13122370573026793, 0.16416911860661848, 0.1143493540585041, 0.10424724327666418, 0.12474582690213408, 0.12766217041228498, 0.08677482405411345, 0.14788041050945008, 0.09410691740257399, 0.16812476063413279, 0.16797451941030367, 0.10410002153366804, 0.07938122150621243, 0.09606552230460302, 0.17650648658829077, 0.10958635035370078, 0.12230367080441543, 0.08497790726167814, 0.16992464262459958, 0.05996640079787799, 0.15967661967234953, 0.1460042204707861, 0.12694045342504978, 0.11127222489033427, 0.12792544199952058, 0.11117826814630202, 0.13848804735711642, 0.14463238551148347, 0.2159105757517474, 0.11340725568256207, 0.07061479333788157, 0.14060624369553157, 0.07706319660480533, 0.14324639631169184, 0.10962000569062573, 0.11725105478295259, 0.211031936109066, 0.081300403523658, 0.17238513273852213, 0.11483802140823432, 0.15900143661669322, 0.1321918394948755, 0.14248702063092164, 0.08675161815647568, 0.08614524533706051, 0.15156674198806286, 0.19184352218040399, 0.16491740702518395, 0.10723719426563807, 0.21792244565274033, 0.21522839021469864, 0.2758551005806242, 0.08252146800181695, 0.164405208081007, 0.12221911177039146, 0.1523740900946515, 0.13431388991219656, 0.16394152439066342, 0.2994924650660583, 0.21022876777819224, 0.10013409970062119, 0.2948515840939113, 0.11008035777402775, 0.1296341967369829, 0.20710283837148122, 0.32992997180138317, 0.3831891625055245, 0.2591040794338499, 0.11361441242375545, 0.12046686293823378, 0.31909192193831715, 0.15662074222096375, 0.26634507945605684, 0.22454057766922883, 0.25149414635130335, 0.2860803247562477, 0.24787877606494085, 0.33328171766230036, 0.19839241648358957, 0.12444360740482807, 0.16116748324462346, 0.33059914303677423, 0.22234025145215647, 0.1869922817817756, 0.20935443469456264, 0.18564051788832459, 0.21312280105693, 0.32441953463213785, 0.2734268680214882, 0.262259375836168, 0.2714735014098031, 0.11109782103449106, 0.07572710008493491, 0.14907912404409476, 0.09183960620846067, 0.2859064026602677, 0.24103846454194613, 0.11584457382559776, 0.21602239832282066, 0.19131252781621047, 0.15343134264860833, 0.11771294714084693, 0.23589647188782692, 0.2854345222668988, 0.4228459788220269, 0.14259725543005125, 0.10392295782055173, 0.15929993774209703, 0.2487170382269791, 0.13269348043416226, 0.1982596136097397, 0.1176700908690691, 0.14412287356598036, 0.11055487766861916, 0.1288824477898223, 0.11149063174213682, 0.1638237985649279, 0.08897103156362261, 0.0798758396080562, 0.1137508861720562, 0.1424719300121069, 0.07116885110735893, 0.18041625964854444, 0.12129211079861436, 0.10611026295061622, 0.19209125531571253, 0.16136146283575467, 0.142613255285791, 0.2647281033652169, 0.15485703971769127, 0.14718571278665746, 0.19689152416374, 0.06845062625195299, 0.17496604924755438, 0.1301713657698461, 0.13270715970013822, 0.10583297961524554, 0.1487714626959392, 0.07767199179423706, 0.14383043854364327, 0.11766600608825684, 0.17378129996359348, 0.21671320125460625, 0.1489525501217161, 0.10146320730979953, 0.1488590615668467, 0.16329844961208956, 0.1676730327308178, 0.1243193947843143, 0.12776875469301427, 0.09257582348904439, 0.16964934739683354, 0.13026767703039305, 0.12095871940255165, 0.10649790322141987, 0.1166866086423397, 0.12134703142302376, 0.09921442012169532, 0.07485252272869859, 0.09885690002036945, 0.12937893186296734, 0.09654680719333035, 0.11771794115858418, 0.17973532261593, 0.05091071654377239, 0.14567023196390697, 0.16363691645009176, 0.15013834434960568, 0.12913959899118968, 0.17807136476039886], [0.023131041654518673, 0.04820334146331463, 0.026076762338301966, 0.0417163159831294, 0.038312475596155436, 0.006415088893845677, 0.021875651786103845, 0.03956304616960032, 0.01474759731042598, 0.05762831840131964, 0.06097496167889663, 0.049635504971125295, 0.06184060951428754, 0.03749859659001231, 0.0071197246101551825, 0.05706291552633047, 0.03994594008794852, 0.01293038044657026, 0.04159196426293679, 0.07032956435744252, 0.03718627370627863, 0.01560946909843811, 0.031777484475501945, 0.027896649237456064, 0.06757365366710083, 0.06249720749578305, 0.030329548421182802, 0.009243259322829545, 0.055098007033978186, 0.10124958412987844, 0.10983289605272667, 0.06602429359086923, 0.012086488140214766, 0.036068349943629334, 0.05138932800452624, 0.011765624196933848, 0.05479630322328635, 0.012380964704789221, 0.015390248004613178, 0.03500317210065467, 0.04129734435783965, 0.023107946018821428, 0.019102908338287046, 0.008948507103403764, 0.024600449949502945, 0.02420993777923286, 0.043475000719938955, 0.009449779937442924, 0.04581378200756652, 0.01621892416317548, 0.04088524289961372, 0.05963298226041453, 0.029066282457539012, 0.11043568620724337, 0.030702037005020038, 0.020648439780675938, 0.06405316971774612, 0.016591655323281884, 0.02216722337262971, 0.06897390567298446, 0.06970890159053461, 0.02748331454183374, 0.0707136762461492, 0.04140934334801776, 0.023414175658087646, 0.035638599789568355, 0.05055302002334169, 0.033263893465378454, 0.029835904017090797, 0.012278404984889286, 0.05167508624227984, 0.05681448010727763, 0.06843628202165876, 0.0459954258320587, 0.04086367227137089, 0.24208321848085948, 0.12940437692616666, 0.14682201801666192, 0.19434260736618722, 0.08128080743231944, 0.15235484684152262, 0.14643700367638043, 0.1626105915222849, 0.07633404965911593, 0.07575974440468208, 0.01647754948187087, 0.011613047116303017, 0.04361647866400225, 0.02648721156375749, 0.031149904044078927, 0.06867908899273191, 0.031408062869949, 0.024006803054362535, 0.08891447566981826, 0.05966903282595532, 0.10728637448378972, 0.10822288851652827, 0.03733664045908621, 0.09390648494341544, 0.059251000971666405, 0.05481015890836716, 0.051415044481733015, 0.11646286850529057, 0.03955233549433095, 0.04616800103602665, 0.03774628901321973, 0.021218982558431368, 0.022437490655907562, 0.035473617392459085, 0.04708355851471424, 0.033683540233011754, 0.014245165877842476, 0.06448859920991318, 0.08147494308650494, 0.030685436645788804, 0.0365338012176965, 0.030851735400834253, 0.039477883239409754, 0.026575600927961723, 0.008241873949633112, 0.059653528300779204, 0.049086322475756915, 0.02679205359891057, 0.026768299784245234, 0.04173367290890642, 0.05036324056397591, 0.060781728476285934, 0.012816522270441055, 0.022550485396225537, 0.045667567889073064, 0.011068129213526845, 0.005708420965155321, 0.03498075669631362, 0.07267785192068134, 0.052855472546070814, 0.07596465519496373, 0.0428034647900079, 0.032095591870269606, 0.008530392128575062, 0.03917643727202501, 0.03463974195931639, 0.03896795738754528, 0.01897214785484331, 0.056285307609609196, 0.026807804093030945, 0.07407912851444312, 0.03926849411800504, 0.04870187131954091, 0.03093986352905631, 0.027052263296874504, 0.06657253631523677, 0.05475312464737466, 0.0346904929860362, 0.02081650951212006, 0.016951740286978226, 0.034641092244003496, 0.0516751032056553, 0.04916307496439133, 0.06647781961198364, 0.0576563011854887, 0.0494886089249381, 0.029207495772945027, 0.043322927451559474, 0.02593831066042185, 0.04271660552227071, 0.012399204574259264, 0.0363646661862731, 0.026225855141612034, 0.03688212038416948, 0.02554727771452495, 0.039030080661177635, 0.04017064713739923, 0.05125325119921139, 0.027135159920102785, 0.017685474129393697, 0.05077298750568714, 0.012532845438857163, 0.029738747980445623, 0.04829006841672318, 0.015487295475655367, 0.02107355893323464, 0.00419083795610017, 0.03876073279285005, 0.035819205455482006, 0.00908017173475985, 0.02912665850349835, 0.03149194676162941, 0.05174346221610904, 0.0248817858352725, 0.020996365396838104, 0.04584894708490797, 0.06993860605039767, 0.01983440131880343, 0.006546868452070547, 0.06822347308376006, 0.04282348496573312, 0.05528063473424741, 0.029910933026777844, 0.01985267935586827, 0.05679131152906588, 0.048725060253803215, 0.0370927614026836, 0.030845153611153364, 0.042803627638412375, 0.014665297798014112, 0.07279234791972808, 0.0387806376176221, 0.0121580981815766, 0.040696209828768454, 0.059851884442780695, 0.012468054674432745, 0.017492760006072264, 0.061724159334387095, 0.02630997312787388, 0.04462921932073576, 0.02319254237227142, 0.018406928184309175, 0.06005784696234124, 0.014511730056256056, 0.025689647932137762, 0.017013274931481907, 0.05180640312443886, 0.05013425195855754, 0.059519863687455654, 0.05953669814126832, 0.06091622090233224, 0.047943574509450367, 0.016122872442273155, 0.013321599989597286, 0.020224828672196184, 0.03154723040227379, 0.0399464048844363, 0.06101891717740467, 0.031184716283210685, 0.038628672914845605, 0.045030525286815, 0.011506904731504619, 0.01855318301490375, 0.04854439351973789, 0.03854525721232806, 0.0170145336139415, 0.050301273353397846, 0.030566950860832418, 0.03398619738540479, 0.07279191365731613, 0.04403393376352532, 0.06421118695288897, 0.03453317803463765, 0.0643074100038835, 0.06925521272101573, 0.043139183561184576, 0.02747922297567129, 0.13544669055512973, 0.09232570191047021, 0.030001083189355474, 0.06519838076617036, 0.06914136133023671, 0.13378383192632878, 0.08042132069489785, 0.1374782651130642, 0.1405290671225105, 0.045115884992160966, 0.02713798262578036, 0.03308861769203629, 0.12238194660416671, 0.029427914481077875, 0.12264942510851792, 0.019871583341487815, 0.03831278772226401, 0.11253554852945463, 0.11563201594565596, 0.135753904070173, 0.054799936778311215, 0.012690104411116667, 0.051571161818823645, 0.02915062096768192, 0.02582907161143209, 0.09283553955278226, 0.11588478381080286, 0.030535456657941853, 0.10987305175513029, 0.06525330139057976, 0.04434532705428345, 0.05771947279572487, 0.033261369315109084, 0.02931222426039832, 0.06508024103407349, 0.012542701160003032, 0.031196112278848886, 0.06514567895127193, 0.04629284130143268, 0.011926330127088087, 0.035572954919189215, 0.031970154494047165, 0.05271850007453135, 0.04436298592814377, 0.044792783579656055, 0.02787082249830876, 0.02528578049636313, 0.025992532393762043, 0.07473514974117279, 0.019093522502641593, 0.02480665165265756, 0.053740438273442645, 0.08350178147000925, 0.06927399457033191, 0.05380049201526812, 0.08965577517769166, 0.017260253196582198, 0.03778994595631957, 0.08015734343124287, 0.06349760560052735, 0.08144560323229857, 0.05226619880912559, 0.003914605501839625, 0.08874560187437705, 0.04518087846892221, 0.07127814274281263, 0.056967622068311484, 0.022964456218427846, 0.05980877032769578, 0.04616177886990564, 0.06112432759255171, 0.01157295163388231, 0.011713198036886752, 0.08435286115854979, 0.03264999908528157, 0.04873167936291013, 0.04308600337909801, 0.04168282010193382, 0.004122346631317798, 0.02494443327720676, 0.11326084139623813, 0.02237655990757048, 0.10273185066346611, 0.03129124628113849, 0.019987819782857384, 0.03738524731514709, 0.010586958827583917, 0.005259026374135698, 0.03677179059013724, 0.013061901737403656, 0.07086234326873507, 0.046790791010218005, 0.012233529223262199, 0.040653485871319256, 0.0164185474693243, 0.020230524973677735, 0.025041243260992423, 0.0158670647402427, 0.010560248296574822, 0.044960290127034695, 0.11667412359799657, 0.08958254767847912, 0.1367653419396707, 0.17399893328547478, 0.1277286804148129, 0.08116845560393163, 0.059878659434616566, 0.12876122072339058, 0.15974722802639008, 0.06538064205752951, 0.16439675353467464, 0.13346023857593536, 0.239608139864036, 0.09126966393419675, 0.16327178318585667, 0.12831581676644938, 0.12641670581485542, 0.13428336940705776, 0.14002722262271813, 0.18170698253171785, 0.16846405528485775, 0.07499249771769557, 0.11187320335635118, 0.1549914846462863, 0.11357503025127308, 0.14992611216647284, 0.1655879896134138, 0.12653638582144464, 0.1669859481709344, 0.20282620856804506, 0.17863644872392925, 0.16887239765908035, 0.04940703544499619, 0.1204810578908239, 0.13801395493958676, 0.12297950525368963, 0.12461862872753825, 0.07123248412140779, 0.06673796993813344, 0.12417144700884819, 0.15497441270521709, 0.12309713608452252, 0.26956866362265175, 0.19003747909196786, 0.12520253525248595, 0.1537652633019856, 0.11839051863976888, 0.22425587794610433, 0.09551879949867725, 0.08665439087365355, 0.1402364692517689, 0.1368892424340759, 0.0869524645219956, 0.22756685742310115, 0.07261592881487948, 0.1449708252080849, 0.22526826576462813, 0.14329435516680988, 0.1448021549731493, 0.08839267545512744, 0.1808224714228085, 0.15042080490716866, 0.09675399786127464, 0.20107317263526575, 0.14615558806274617, 0.09975743812641927, 0.1561165228486061, 0.15371277183294296, 0.14786317571997643, 0.08353490076426949, 0.11601742383624826, 0.15032628497907094, 0.1955601977450507, 0.08888149208256177, 0.15701440109738282, 0.3860147180301802, 0.2829923390277794, 0.2699285585965429, 0.3307905713362353, 0.19583157104040894, 0.2577099342431341, 0.24466051161289215, 0.3555014325039727, 0.39988166679229054, 0.2537637102816786, 0.15034950444740908, 0.10311212204396725, 0.092315361036786, 0.25773001887968605, 0.12541119834142073, 0.21260799653828144, 0.18777612543531827, 0.18431076567087853, 0.2170724719762802, 0.13569286305989536, 0.1932560828115259, 0.17071240821055003, 0.08879797120711633, 0.1504279023834637, 0.12093194441071578, 0.11255336007369415, 0.17066972835787705, 0.2697270065546036, 0.13229595390813692, 0.1548773143440485, 0.16168046928942204, 0.15580457315913268, 0.21740423488829816, 0.09792522394231387, 0.14889275761587278, 0.18743224388786725, 0.12268951295741967, 0.0924141150234001, 0.3530138417014054, 0.1963334155402013, 0.276341935885804, 0.09056491032242775, 0.09425071932907615, 0.12628763488360814, 0.1217314215110881, 0.13189511613122054, 0.21635037500943455, 0.09779656013207776, 0.13410480613155024, 0.15832761063107423, 0.12644852910723003, 0.17376061821622507, 0.09772877448371478, 0.09426431717084986, 0.10846680149968181, 0.14695738575288228, 0.13802075386047363, 0.07203027166958366, 0.19065863718943937, 0.17840580110039028, 0.25683807102697237, 0.1646777213151966, 0.24248911812901497, 0.16267148325485842, 0.13757905470473425, 0.16880092078021594, 0.1593567311231579, 0.1828592164175851, 0.12148485545601163, 0.15347309969365597, 0.1626206881233624, 0.14508879530642713, 0.09839588975799934, 0.07555503038955586, 0.18440684622951917, 0.11688166031880037, 0.2006487896932023, 0.2108044233173132, 0.13938668556511402, 0.10883400429572378, 0.1404210850596428, 0.19717524679643766, 0.13965325483254024, 0.17798794566520623, 0.09462869047586407, 0.10204357866730009, 0.20878285036555358, 0.09631246155393974, 0.04917655745521188, 0.1356314963528088, 0.09797463486237185, 0.16878089042646544, 0.07673185438449893, 0.15071323992950575, 0.3173754997551441, 0.08691063283809594, 0.10623028222471476, 0.11274398770183325, 0.07224853602903229, 0.1119951835966536, 0.10378288105130196], [0.017416857382548705, 0.05921970693660634, 0.05151024294484939, 0.013647894757533712, 0.024940440098622015, 0.05878408066928387, 0.03039565130269953, 0.039758382830768824, 0.008033053101306515, 0.015380124262134944, 0.03565259796700307, 0.07458366001290934, 0.03308446505772216, 0.05054248237450208, 0.0364138124776738, 0.032675824128091335, 0.018711783790162632, 0.019564709093953882, 0.020721918337845376, 0.058885847351380756, 0.07479460297950677, 0.02717100522880043, 0.029460358632994548, 0.02861115170110549, 0.03802840691059828, 0.027211342439321533, 0.04338362919432776, 0.043703605953071795, 0.010064743010194173, 0.044340020910437615, 0.04822133621200919, 0.013857238925993443, 0.060486599669924805, 0.06809822909001793, 0.024353098490142396, 0.06971212463187319, 0.05798370111733675, 0.06767970869051558, 0.049021447742623944, 0.01207262312527746, 0.033497848947133334, 0.07745642121881247, 0.04351661866530776, 0.025053227885759304, 0.03387120944846954, 0.0783938919859273, 0.0240016495808959, 0.041963913411434205, 0.06759904444749866, 0.046756372321397066, 0.01934306732644992, 0.060586161113211086, 0.061372121796011925, 0.034826389979571104, 0.0471556189336947, 0.01714732970244118, 0.04536084970459342, 0.03566623652087791, 0.010772629757411778, 0.09946080297231674, 0.035045441439641375, 0.03335583835308041, 0.03465200647977846, 0.036736004653253725, 0.07766719455165522, 0.12245461770466395, 0.010808905087677496, 0.05964385239141328, 0.036083766259253025, 0.025522809741752486, 0.024134033459371755, 0.07135530574513332, 0.07174979243427515, 0.030269833946866647, 0.018374468765354583, 0.0962936118511217, 0.09748275125665323, 0.08915456171546664, 0.10970290231385402, 0.12738973860229763, 0.1268004716507026, 0.10730115976184607, 0.031162270344793797, 0.12460318527051381, 0.07867260024483715, 0.03759658383205533, 0.015509415717263306, 0.061038642190396786, 0.006743301795462945, 0.016904687276110053, 0.04227548651397228, 0.013816408081246274, 0.015683519321360757, 0.023729791132999316, 0.008722578690919493, 0.0472928221071405, 0.07593202444591693, 0.09191150377903666, 0.02989079410742436, 0.05428495244788272, 0.04505348012649587, 0.0563932387823505, 0.016740868566557765, 0.02419831108168832, 0.010197474637867084, 0.03097327459337456, 0.09248768179012196, 0.033625830829675706, 0.06324865110218525, 0.07400184337581907, 0.07997734166149582, 0.09556429527167763, 0.09684644147221531, 0.04901649443698781, 0.06286053585686854, 0.021917836308213215, 0.05246919273797955, 0.04166940546461514, 0.03322708633329187, 0.057911104655691555, 0.03610523510724306, 0.029048861070935215, 0.05371908138373068, 0.08569037581660918, 0.04771937296858855, 0.014087685533533139, 0.07713121974042483, 0.021769657830840776, 0.07234222814440727, 0.021902335175712193, 0.06890527185584817, 0.023553616300757443, 0.024621837373290743, 0.032031758688390255, 0.014812463561871221, 0.05076759993763907, 0.019227316037618687, 0.050210427692426104, 0.02689093311450311, 0.061445959976741245, 0.015899239174489464, 0.044066981811608584, 0.11818625245775495, 0.043495190529418845, 0.05289592341120754, 0.026968671175252115, 0.08184889052063227, 0.02587237741265978, 0.012592263902271432, 0.04233988287991711, 0.03566476070721235, 0.047955248704446216, 0.039844570348837545, 0.025588953335370337, 0.016491081166480268, 0.014896522176318934, 0.05038143887317606, 0.013079776894301176, 0.05671306965606553, 0.014577968644776514, 0.04444778923477445, 0.04880919859611562, 0.022840219849188412, 0.02932007151788899, 0.037136679581765614, 0.058158254250884056, 0.026957495703494976, 0.06586251048637287, 0.022339223518169353, 0.02147875290497073, 0.04066062745239053, 0.02634746897300439, 0.008928478445990809, 0.028361691694174494, 0.018572887671845298, 0.03274054279817002, 0.017703748773783445, 0.040008148178458214, 0.04169489463259067, 0.03125502268916794, 0.06431095195668084, 0.02568186852814896, 0.0595608064904809, 0.04222641825409872, 0.019136071737323488, 0.035404457710683346, 0.029024644156119654, 0.11110491172543593, 0.02869252162054181, 0.006165099205515746, 0.0251145776294704, 0.06660200509109668, 0.01726221925179873, 0.026254767518756644, 0.029268757307103703, 0.0666083697495716, 0.05851415943886552, 0.017393052677756975, 0.028318631861891066, 0.13407070296151297, 0.02532521016629679, 0.025361038511618972, 0.06537437917930738, 0.00889264077081212, 0.04480977409652301, 0.03067907877266407, 0.026752427153821503, 0.032627203701330085, 0.03560043219476938, 0.09182418989283697, 0.026204413435022746, 0.02092657976650766, 0.04254456975364259, 0.03598362806120089, 0.04928888214219894, 0.02943466929718852, 0.02062535093032888, 0.05070139527586954, 0.027653540318299617, 0.04040881632161992, 0.030871358633573567, 0.02756101867583181, 0.033630767171936374, 0.026682789104857614, 0.02766671746836177, 0.027143146277272275, 0.05324473790824413, 0.06859050624604736, 0.04121719919411199, 0.019865503667720726, 0.028708575759083033, 0.025532349944114685, 0.010009735872569894, 0.023270015804363147, 0.038821339540715726, 0.005854962476795273, 0.042228925440992625, 0.029438587836921215, 0.008117393307786967, 0.061701469123363495, 0.05023407803050109, 0.06461843010038137, 0.006468184683139303, 0.02005077256555004, 0.03332808966349278, 0.07621837979448692, 0.02560884289310447, 0.12245953029819898, 0.08767547751111643, 0.06702604876565081, 0.05328264765973602, 0.013350302869054888, 0.04038058926484414, 0.04853088728019169, 0.1283362949533122, 0.04329085649390306, 0.023708391834848692, 0.047561901954135725, 0.062956392498953, 0.0793613607862166, 0.06755192019045353, 0.036620762265686474, 0.07510598269956452, 0.048190025213573656, 0.029299064073711634, 0.0025148057819543673, 0.016775791067630053, 0.003651082856647138, 0.07206860889813729, 0.09339265751519374, 0.05282104367922459, 0.010433371577944075, 0.0379339141239013, 0.0753009325957724, 0.0340228925592133, 0.10666227832968746, 0.10141393888209548, 0.05461027266989861, 0.10866176496659007, 0.03936575193490301, 0.02465161488258413, 0.02304850465485028, 0.061812457096363814, 0.01945982115077121, 0.05187458910846284, 0.045755404247237105, 0.015187306662223168, 0.026831164357385466, 0.09542773331382445, 0.023954547376238873, 0.03948418004438281, 0.034139987347381454, 0.00809727983349668, 0.03356988901006324, 0.03653601324185729, 0.010740003249208843, 0.013571032855127538, 0.039237678450133116, 0.03592307559613671, 0.0262695748492011, 0.05669233023322054, 0.040882600005716085, 0.054739981424063444, 0.03832044159727437, 0.012643679893309516, 0.08298882935196161, 0.034409019696925364, 0.0571091373318008, 0.07204388986740794, 0.03381461284256407, 0.005851465052858527, 0.01426927761973015, 0.021750996421490396, 0.006779359994522695, 0.041058822335409265, 0.09225020131894521, 0.012486063841996449, 0.030358403122850826, 0.00847654783033899, 0.012938657725628997, 0.051639744745833535, 0.03701919463596173, 0.05845248739102057, 0.0433115687753473, 0.07994475162455014, 0.04091221805928009, 0.03402949809761984, 0.07092187114592109, 0.021052415782053555, 0.03171216190925666, 0.07459501868912152, 0.036769008596560786, 0.038392787000962665, 0.034235664177685976, 0.02546303080660956, 0.022901420315195407, 0.01119367515535227, 0.012189845138761615, 0.03594861226156354, 0.05309177575899022, 0.02954515176159995, 0.05054300145379134, 0.030560867794390236, 0.04058707086369395, 0.05127124934058104, 0.028566266609621898, 0.030705568779792105, 0.045618553912000995, 0.15032553859055042, 0.049109742111925564, 0.10540557040699891, 0.01911793788895011, 0.08286184830857174, 0.1235992791397231, 0.13675296546093055, 0.1433577031961509, 0.14492928529424326, 0.1092135835705059, 0.15398016891309194, 0.1272160607789244, 0.10182119560028825, 0.19255751743912697, 0.12392522022128105, 0.25464735286576407, 0.12965230005128042, 0.11195392866751977, 0.13876784805740627, 0.1355521756091288, 0.11497663254184382, 0.13896152909312928, 0.15296525694429874, 0.167989705024021, 0.1493217410253627, 0.07859010395726987, 0.08478622111890997, 0.18212049534278257, 0.10166663889374052, 0.14221863288964542, 0.1345602659774678, 0.09400555784148829, 0.0965145021410925, 0.1170782454844032, 0.10174236340182168, 0.08713262235479695, 0.09955276482339416, 0.1840475755078452, 0.12643061578273773, 0.17425574521933282, 0.15312511979469232, 0.09483980307621614, 0.30360292164342745, 0.07177896944007703, 0.08997327528361763, 0.14163858044360364, 0.13799638088260377, 0.12596946981336388, 0.15023327139871462, 0.1286752096244267, 0.1714068888021367, 0.18319950172943728, 0.13049840607813426, 0.11456382540719849, 0.09235821730856385, 0.1372938800070967, 0.19230104477277823, 0.08508158741252762, 0.1662235733653818, 0.11392953087176595, 0.144800906468715, 0.1761295875268323, 0.14076363667845726, 0.16850180897329534, 0.12330890686384269, 0.10335589932011706, 0.14294853300920554, 0.17567372055990355, 0.12815280551356928, 0.27763932198286057, 0.0917440006243331, 0.1323334497532674, 0.18671885931066104, 0.09903084247239999, 0.1710988881864718, 0.36985369665282114, 0.19925392525536673, 0.21374157071113586, 0.14435586892068386, 0.15684872998722962, 0.23070706320660456, 0.22778078594378062, 0.3927627759320395, 0.14298410181488308, 0.2533699699810573, 0.21420275739261083, 0.10640936797218663, 0.20052612413253101, 0.20283629159842217, 0.1747852468064853, 0.09508208078997475, 0.19695431579436573, 0.10566308123192616, 0.13218930177390575, 0.12094969488680363, 0.1162508534533637, 0.13394017996532576, 0.24907902308872767, 0.06998821374561105, 0.14980879346174852, 0.19621581185076917, 0.15729577599891595, 0.14042990601488523, 0.23404474982193538, 0.2606603944940226, 0.1689281053841114, 0.18576007575861045, 0.1622782043580498, 0.06874697642134768, 0.10835576602923018, 0.13533109532935278, 0.10877629489238773, 0.14538749999233655, 0.2516242079436779, 0.15325904903667315, 0.27574485221079414, 0.23269275522657804, 0.1515037603676319, 0.13550665948007787, 0.22581946690167698, 0.10568437366081135, 0.07896795975310461, 0.16461183556488582, 0.09198094505284514, 0.16277292424014636, 0.08344205681766782, 0.14250683385346616, 0.13172447814473084, 0.20437026928578103, 0.10859305651060172, 0.1644741879510028, 0.18956421448716096, 0.16838504666728632, 0.1320592944643327, 0.15837060260985578, 0.16078806003289564, 0.1365392812128578, 0.2266696441386427, 0.08748253607856375, 0.08979271711515528, 0.09219408647290298, 0.1466511357575655, 0.10967874646719013, 0.22040512386177266, 0.0600636416514005, 0.15294274315238, 0.1963019043739353, 0.1139453271670001, 0.15946664022547857, 0.10584070812910795, 0.12473729093159948, 0.17129977526409285, 0.18034495918878488, 0.12533058838120528, 0.095129754660385, 0.11607199162244797, 0.12867599672504834, 0.11427418594913823, 0.14183315714555128, 0.13419411491070474, 0.1544008334832532, 0.1272137944719621, 0.18958640258227075, 0.06781966332346201, 0.12375990194933754, 0.11306269560009241, 0.09084775764495134, 0.1447710237864937, 0.11258464053805385, 0.1784149884645428, 0.09498361857341868, 0.11204732901283673, 0.1172838823071548, 0.09369905000286442, 0.15539727572883877, 0.1041425588939871, 0.222719009699566, 0.13610001121248516, 0.13992051620568546, 0.16141759125249727], [0.06301311802651201, 0.09037865245980875, 0.03087461899433817, 0.07170063257217407, 0.03520040187452521, 0.010214588139206171, 0.03663670105327453, 0.05141507162313376, 0.021971253977556313, 0.009174000405307327, 0.02831771075060325, 0.04449732907648597, 0.01331070950254798, 0.02780869074298867, 0.040293682499655654, 0.016552570009870187, 0.09699411104832377, 0.03467000462114811, 0.023850755267111317, 0.045142877115202804, 0.024194451913769757, 0.057024456161473475, 0.03241246772397842, 0.024157799148399915, 0.021695697513808097, 0.024369315477088094, 0.05613537511921354, 0.014585147545273815, 0.019586700413908278, 0.044354558523212156, 0.03336389595642686, 0.020391917920538356, 0.09695606558982815, 0.04592535352068288, 0.0489967660313206, 0.054680416227451394, 0.05370036060256617, 0.015835585804390054, 0.05724740241255079, 0.08879586774855852, 0.015870925604498813, 0.025932171614840627, 0.012807323880094503, 0.029637466450887065, 0.052705102400588136, 0.027752711603950177, 0.05871216952800751, 0.059223649225064685, 0.029194376298359463, 0.006216240389871278, 0.04031531419605017, 0.012181850299904389, 0.005728499240441514, 0.06550390472901718, 0.00878664427104273, 0.06524796810533319, 0.012765758521189647, 0.02558410689899964, 0.07499697604881865, 0.06279582397214004, 0.027164372548993145, 0.020078346532370363, 0.04410873885665621, 0.029713594687304327, 0.025370624515094926, 0.030555144351507937, 0.033248253233198605, 0.01659873074718884, 0.0850951038300991, 0.08332597304667745, 0.043449504766613245, 0.06472892952816826, 0.017355760393132056, 0.018711905926465988, 0.0738756697891014, 0.09585721883922815, 0.0815605538498078, 0.0843932611335601, 0.04031783834631954, 0.05306461739486881, 0.05250336715419378, 0.18872547735060963, 0.07156812146838222, 0.09534068405628204, 0.01421820089620139, 0.019671242484556775, 0.024159395402031283, 0.08351946409259524, 0.043380175451082845, 0.020904283105794872, 0.05865687570933785, 0.022260664430047785, 0.015921045593651276, 0.08255466872027942, 0.06642238330096006, 0.0402976756782404, 0.05048831831663847, 0.0832337737083435, 0.024273357054750835, 0.04545740184507199, 0.04489834666518228, 0.05165762075089982, 0.014094246967163469, 0.02077981094563646, 0.056083972698875835, 0.003224081193496074, 0.02113035231429551, 0.05234730409990464, 0.06751552357205323, 0.05265029373445681, 0.01918533507601491, 0.0036401694690409514, 0.023088131099939346, 0.027137287127386247, 0.06892693069364343, 0.030226041296763078, 0.05739934675927673, 0.0534807086390044, 0.06030454193907125, 0.18282710814050265, 0.05733947961458138, 0.035830221471509764, 0.05497300731284278, 0.027593082848138044, 0.026398633906085576, 0.07391045149415731, 0.034144163730421236, 0.02513590907411916, 0.03751373131360326, 0.055998029453413825, 0.02712565703716661, 0.05640577471682003, 0.01881769292854837, 0.03924294727455292, 0.0195368382680629, 0.041789879357176166, 0.027460646383198242, 0.01778876072993236, 0.03973061717780573, 0.052878593626831255, 0.04493978479877114, 0.030304907421980585, 0.01997202688029834, 0.02757630098078932, 0.03364798839070967, 0.01173161093278655, 0.048159830405243804, 0.11068635061383247, 0.0416229868839894, 0.005298589630651155, 0.04110578035137483, 0.04658020766718047, 0.00996675661631993, 0.048138463337506564, 0.027433063934690187, 0.040852666433368406, 0.017777563205787113, 0.010445559763216546, 0.02926476752119405, 0.08232277937765632, 0.04546152055263519, 0.021168530087119768, 0.022956237463014464, 0.022604744448991757, 0.031869225802698305, 0.018781845923513174, 0.013824159495665558, 0.024256244401580522, 0.02743907575495541, 0.046627881537590704, 0.03927545588729637, 0.036960009418960126, 0.01023472027320947, 0.02431642367238445, 0.02309710642189852, 0.05908167255776269, 0.05027437622525862, 0.056464389964405975, 0.05172733004604067, 0.04241198401099869, 0.04309833236038685, 0.05490434296163065, 0.01629898451002581, 0.050648255805884085, 0.020610994825671827, 0.03023305056350572, 0.03453714067914656, 0.05831258025552545, 0.01602524991280266, 0.041385343564408164, 0.059418192000261376, 0.035369004255958965, 0.048779220918991735, 0.055981245889727554, 0.048338095125343115, 0.025013335115675415, 0.04797223922131317, 0.14061027419354233, 0.01791057303281767, 0.05823798890092543, 0.03577893779480031, 0.032396610360592604, 0.052275932393968105, 0.05418658522622926, 0.05864095049245017, 0.08149430169058697, 0.04113884197015848, 0.026755388959177902, 0.024002604618934647, 0.018106427076937895, 0.05833551473915577, 0.03188395340527807, 0.053554275405726263, 0.03747225586058838, 0.056224802641996315, 0.014005767697069262, 0.029559869186154435, 0.01410090085119009, 0.01137278210704348, 0.03557009828676071, 0.03495176289496677, 0.028604396884994845, 0.0533243741707078, 0.012816693600533264, 0.04151340347847768, 0.04043914344427841, 0.06071242969483137, 0.01873336629276829, 0.040701733103820255, 0.08882561472377606, 0.014198572574449437, 0.01945958535985223, 0.06873769406229258, 0.020492858486250043, 0.06586936369006123, 0.03689437811928136, 0.04970464090417538, 0.0030731402304289596, 0.07584399131259748, 0.034546806410487206, 0.03088910910966141, 0.03560894102390323, 0.01741706263939185, 0.04197655791150672, 0.0238285739573517, 0.048600036783942153, 0.01570991942259882, 0.11280226028923478, 0.037482644231723886, 0.02831103396601975, 0.026226274136986052, 0.012479243716890258, 0.08867477638913052, 0.05552031705155969, 0.021078276447951794, 0.05306857664670263, 0.06777621672621795, 0.062355393676885536, 0.053357547747769525, 0.025942568467663865, 0.08724352890359503, 0.023344736080616713, 0.01835569370138858, 0.06554601461227451, 0.05214805229167853, 0.011076850933022797, 0.1377698044691767, 0.02706902820084776, 0.029734178047095026, 0.0353421783739967, 0.10423625779471227, 0.04359015489795378, 0.012198740732856095, 0.05383238994649478, 0.025843227548258643, 0.03020170224564416, 0.018405552454558865, 0.04628787442509617, 0.05117463952462588, 0.026070935418829322, 0.0293778996648533, 0.020969637902453542, 0.03353355685248971, 0.11842354972447668, 0.03323191071727446, 0.040721356336559565, 0.02141469919921032, 0.0385733010646488, 0.05734045670500823, 0.08856693681861673, 0.05564601566376431, 0.015144414767356855, 0.025314228077019964, 0.023891492813293422, 0.051161764322647026, 0.034297186947826824, 0.04524856912238257, 0.019844514883256385, 0.03834512330857771, 0.04022526581372533, 0.0061489581296752605, 0.08897973038256168, 0.01570697797329298, 0.040077087336352894, 0.018396539813173667, 0.023450748695592796, 0.024290461226233413, 0.014971345929162843, 0.0889639069459268, 0.06403727842760937, 0.020189960453925387, 0.034924434897090705, 0.051294214358287196, 0.05182501534000039, 0.0258503029721656, 0.08461298434329884, 0.02227700694597193, 0.040830179782850404, 0.014671138288187129, 0.06120599606739623, 0.016538091768909777, 0.019278716761618853, 0.023230100981891155, 0.05505273178485887, 0.034283443221024106, 0.03127866284921765, 0.031964692287147045, 0.030038925087345496, 0.05902691478175776, 0.02452608590413417, 0.02380315094654049, 0.002715162542049906, 0.026449288241565228, 0.027821806824899147, 0.031661967281252146, 0.0793360039325697, 0.040811920405498574, 0.014361102067466294, 0.062371631019881794, 0.017118827838982855, 0.05616890831983515, 0.04856372158974409, 0.06858897275690522, 0.0030610722730801043, 0.03445766047973718, 0.04357838570805533, 0.019281475006469657, 0.03446147384654198, 0.05355649082256215, 0.07753542983638388, 0.026078224581267153, 0.04844922898337245, 0.18498091399669647, 0.24725981642092976, 0.13300627150705882, 0.1661565476762397, 0.22243114800325461, 0.17515689400689943, 0.13130522492740834, 0.17991197242268495, 0.08065722696483135, 0.13099807926586696, 0.13388801419309207, 0.16409225415970596, 0.11644004258726325, 0.09766871734921422, 0.23609376272984914, 0.20164914030049527, 0.22569302868630203, 0.16057240803326878, 0.11147830954619817, 0.08781052633587803, 0.15442876198462077, 0.18482878644551548, 0.09373315995825188, 0.12981997962508882, 0.1192834707243102, 0.08946168702095747, 0.12583886539297445, 0.12329022000942912, 0.32421746690358433, 0.12574141419359616, 0.1279393383967025, 0.10457379503973893, 0.14365794137120247, 0.13821587339043617, 0.10578826415751662, 0.1039267915434071, 0.1468655935355595, 0.12686410466475145, 0.14634523860045842, 0.10582716457013573, 0.12503229081630707, 0.13941061070987157, 0.115576566063932, 0.16904777182000025, 0.17279931051390512, 0.178310860480581, 0.15436487112726482, 0.14872114253895624, 0.10294412355870008, 0.06797370434339557, 0.10328341142407485, 0.16632833917226109, 0.08880529938531773, 0.20513143629900046, 0.09437797178647347, 0.13529738570962632, 0.1345365715346166, 0.07692119279610259, 0.1606150743152414, 0.1347184596317155, 0.08912661964339869, 0.1285319301698889, 0.16296570960964474, 0.1409375180623361, 0.12273650829281126, 0.12692222797444888, 0.16283734435481684, 0.19825778156518936, 0.19387448605682167, 0.16185980609485082, 0.126042900873082, 0.21335073454039438, 0.11826527464602675, 0.09690723820988621, 0.11703648843935557, 0.24986058686460766, 0.123591598123312, 0.1835229458021266, 0.1583252628999097, 0.12385771955762591, 0.1146487101380314, 0.2119108425187213, 0.12893573993018695, 0.17468411794730596, 0.16145321434097631, 0.09758299802030836, 0.13389344247324125, 0.1588304050798927, 0.14015261589416436, 0.15740196672933443, 0.3062299106802259, 0.08258377108722925, 0.2489366393004145, 0.2745942196675709, 0.20270579574363573, 0.07202400879136153, 0.15379169902631215, 0.15479777646916254, 0.18822630627879075, 0.13648513411836966, 0.12883750163018703, 0.10887981898018292, 0.09507822671106883, 0.11562578699418477, 0.15463632584682532, 0.2104480295841183, 0.09148435241409711, 0.24085631860154016, 0.1669233058180128, 0.13341436960867473, 0.10330840865416185, 0.15069736221006938, 0.1487122265888112, 0.2015751799834626, 0.25754266179033686, 0.18413817350353512, 0.13987797206001623, 0.14260785414704255, 0.21124954228954657, 0.2748600425464766, 0.17816625109740666, 0.07214009934770209, 0.15984452994806425, 0.12631126147295746, 0.09134198219648429, 0.17560392644788536, 0.12305745535663196, 0.10435365792363882, 0.08463673306895153, 0.16790663876703807, 0.11796306871942111, 0.134527926998479, 0.1813822899545942, 0.10855572351387568, 0.09544784509177719, 0.12914003325360163, 0.15816117956170014, 0.13790662427033695, 0.14102755965931074, 0.15932395788175718, 0.09093993662723474, 0.1465571450867823, 0.0896360230232988, 0.1362199354916811, 0.1088672796530383, 0.11795466845589024, 0.12924310272293432, 0.19158000632056169, 0.10285687074065208, 0.07886764513594763, 0.11093853493886334, 0.12201393635145255, 0.1273957775639636, 0.1166712466095175, 0.13564251576151165, 0.09812136806015458, 0.0794723080471158, 0.09431010471390826, 0.15511785500815936, 0.16092340062771524, 0.14776727158044065, 0.07325222502861704, 0.08586057275533676, 0.09620870676423822, 0.14322780445218086, 0.11278580581503254, 0.1177715997078589, 0.043945442619068284, 0.10110272879579238, 0.19867685836340698, 0.12581415314759525, 0.15790115137185368, 0.09443406627646514, 0.18285376099603518, 0.09575025457888842, 0.13352152385881969], [0.03434406353959015, 0.033787200027810674, 0.0587132755400879, 0.04257429637280958, 0.03532964243952717, 0.04461166901247842, 0.04442344339830535, 0.022580273083544204, 0.07637114516858544, 0.052565429359674454, 0.0431550341392202, 0.032171167100646665, 0.00894395328525986, 0.022763379151001573, 0.010292164199719471, 0.046323361806571484, 0.036621125281921456, 0.030030646960117986, 0.05403661880908268, 0.07967772773866143, 0.037821982987225056, 0.019064236931236725, 0.05564667384273239, 0.056888677911566835, 0.07740308158099651, 0.013816416562934006, 0.028385959499116455, 0.05225386643516166, 0.028778939840516875, 0.04070404351555875, 0.03665426153955715, 0.01719859811211271, 0.04199335165321827, 0.054469792172312737, 0.04733360545443637, 0.02707898400590888, 0.051917754113674164, 0.028467519408357993, 0.017389688840402023, 0.021893207183373824, 0.013390388173450316, 0.01697490207983979, 0.022622859637652124, 0.0110001773240843, 0.05647820833006075, 0.04006329271942377, 0.051539114609892876, 0.04997149854898453, 0.025101407264758433, 0.06069201257612024, 0.036188097803720405, 0.08286161082131521, 0.025934275073398436, 0.04216006092195, 0.0401281912012824, 0.02589935257232615, 0.05120036617985793, 0.02646075209070529, 0.021232673698770146, 0.024194582531760846, 0.05970457449023213, 0.044644618672983985, 0.04653215720983488, 0.015672525357721106, 0.02463947080208787, 0.010431240129816746, 0.08355609819825206, 0.032599475367793014, 0.09470698663166591, 0.03906618211684482, 0.0345996235763388, 0.04376830765977502, 0.025453661934339573, 0.011188854164044772, 0.07518009229430131, 0.006760861857661179, 0.06020509584673813, 0.01175192542307611, 0.0897467735090426, 0.023753441471074308, 0.07033316059304134, 0.05942186966006245, 0.009048880244206105, 0.02704743212754173, 0.07206496516508715, 0.0317293627719794, 0.05002428518076028, 0.04214988289667027, 0.02464624258157398, 0.01673857681453228, 0.03686332157147782, 0.035413397409554036, 0.005120461889808732, 0.031178999625678574, 0.03186013682612351, 0.05760889194373574, 0.04219099533345018, 0.044033441825636795, 0.054484998142080646, 0.023420913510822823, 0.0433715614490211, 0.041843286848493984, 0.012861482000776699, 0.0497329459924783, 0.043095146638474295, 0.031284725559609275, 0.054587104091686864, 0.0663145776571972, 0.008189317171594926, 0.05022579990327358, 0.046607511916330883, 0.005579743160134447, 0.013842157637035208, 0.0612038518967373, 0.055039809085428715, 0.014503546923931156, 0.07376204910022871, 0.0435001336570297, 0.05403623204412205, 0.016179513152954832, 0.021631620059322034, 0.04789473355880805, 0.16125547566584178, 0.040137398921485455, 0.03846991268385734, 0.07755911070853472, 0.01963731912629945, 0.06894219094621283, 0.03869374442313399, 0.04016019091276186, 0.032151299595300636, 0.043765342461743524, 0.041763331674571545, 0.030589478223451545, 0.013612198726540166, 0.05551936710253358, 0.02865291213882821, 0.024919539523710097, 0.06570080880607877, 0.054131108203104565, 0.07059119388993297, 0.03351161302998662, 0.00704060445839007, 0.03349477857617395, 0.07696305162140302, 0.0072052522529182685, 0.02457555789234383, 0.032514848480267186, 0.05101879020886762, 0.05425232169883592, 0.017517852231061885, 0.022671466493713002, 0.020305905125236938, 0.02378829102963209, 0.012720374706467348, 0.01714004054000335, 0.00653672096086666, 0.03453458599480135, 0.09989006458116428, 0.040525208826043775, 0.012352178704791834, 0.03200933649869902, 0.06476990625794445, 0.06123039618666683, 0.05427464210827436, 0.015865356528333256, 0.033698698705328364, 0.07112267679933991, 0.06003232726028987, 0.025939045174579536, 0.039116207111094675, 0.0660751090784158, 0.016122577279540043, 0.04025163707722511, 0.03653202684862273, 0.010102162520135087, 0.056277558739696226, 0.018804827904594795, 0.03711621496560318, 0.019673422278304185, 0.032410269270517995, 0.07298322660582406, 0.027420592461047427, 0.07023271705423083, 0.03243510025952544, 0.07578529803348438, 0.027742827045066015, 0.0034204943928801057, 0.04085236448528511, 0.029771629787449325, 0.035959753806569746, 0.03795810728999121, 0.036154479786221466, 0.04005870582269771, 0.042766094473855834, 0.07715249181325946, 0.023409809285242642, 0.02780930820985564, 0.06817588063755206, 0.02871769866240876, 0.05239091015287808, 0.008446788980758615, 0.029322958684393337, 0.027320057320009385, 0.019531191160370196, 0.02710673269549651, 0.03125309564971498, 0.05297590572653072, 0.11983152345887252, 0.028474959544837475, 0.01539623098714011, 0.040656932829213996, 0.06058441727821316, 0.03906249767169356, 0.02855116581278188, 0.03867230950189488, 0.011085728715573038, 0.00932878187657999, 0.009284220785567803, 0.012001880760570722, 0.021977669526157633, 0.03759070771879383, 0.053335508930363824, 0.07495808242154972, 0.014288157856624042, 0.03707942140421697, 0.04531443451664277, 0.057527019908385615, 0.03205510029303176, 0.07834472533847604, 0.025632669650284306, 0.05759501590260437, 0.0688988800559725, 0.05255218774878553, 0.03912997119394796, 0.01408320720241006, 0.025362656817638447, 0.015550558688119054, 0.06686188400323902, 0.06351164449006319, 0.014785429030390722, 0.014504936224381839, 0.06551488342561892, 0.057397636851029735, 0.038357917086354325, 0.035842754013304196, 0.04482536343857646, 0.044121892257992706, 0.051118962333670685, 0.007017982100868332, 0.04257304447570017, 0.040903424245438406, 0.02040522908126669, 0.00914996415044048, 0.02730012874651168, 0.02057889163760202, 0.05707350067262139, 0.06837773123489958, 0.08421742556882755, 0.08446426982326166, 0.08590767665633134, 0.046721495621438534, 0.04957271673317466, 0.04321824646155749, 0.02992566062935761, 0.04920499146516834, 0.0349774522307728, 0.0352319808942931, 0.018110808716820817, 0.09160512486206633, 0.027394509574930583, 0.01353516973488565, 0.040703137671308856, 0.019666553807577918, 0.033571975505245585, 0.03504232696390577, 0.05859873204358986, 0.03565532907045313, 0.042538781849933524, 0.043255450536629984, 0.021000870869361928, 0.021491753635928035, 0.01854620428223695, 0.06335870269685984, 0.04712147165888122, 0.026493308200900043, 0.00980729579792491, 0.008511529703225409, 0.016796710302254984, 0.03215278219431639, 0.058552530594170094, 0.07217365968972445, 0.016739704879000783, 0.023754857912925736, 0.050479663602475605, 0.015018420992419124, 0.04006275328408394, 0.06536139201905046, 0.05907694316868271, 0.0241672952459859, 0.04535718222281762, 0.025940636339198266, 0.01936650731866913, 0.10201295638190848, 0.04718942015564867, 0.07091130635568074, 0.04886526255203145, 0.03676193147631628, 0.005557406635489315, 0.04304219037294388, 0.019188096713540808, 0.015181895345449448, 0.058283179333167415, 0.03656031158087509, 0.10450095430548702, 0.020240139814891984, 0.023593380149187784, 0.03538628654288394, 0.03453469116772924, 0.03373849478417209, 0.06972879623728138, 0.011171370861120522, 0.003273351105495489, 0.04326069221964904, 0.038576870158846886, 0.03675012835966689, 0.016614566058186547, 0.030906893512500182, 0.08638546708971262, 0.017731806196804558, 0.02808053053117224, 0.017824656928756406, 0.0694273706259472, 0.11468315257557801, 0.07866968254425696, 0.06665619289768593, 0.08765820200954165, 0.030779393389821053, 0.05143419273995927, 0.04192721484495061, 0.021744426506172334, 0.04108422668650746, 0.05811998487583228, 0.06804199889302254, 0.04419230044420276, 0.03765157570264169, 0.06980165054223367, 0.04650846276698368, 0.05318862306220191, 0.06478727675442185, 0.015218076528981328, 0.03700719474415694, 0.14730864976133617, 0.14168827634836945, 0.09537466509001595, 0.1501410584896803, 0.11853869711714131, 0.1317452277456011, 0.10099738623414721, 0.19893270677753858, 0.13218647906822817, 0.14485072450978415, 0.15458791915859493, 0.05712150702519076, 0.1190724599042109, 0.16450434204723152, 0.08600082594369139, 0.1719269316111292, 0.12185942035700593, 0.09918597593371357, 0.18543345614203385, 0.11878534459642001, 0.11521815029638154, 0.16801097031150544, 0.18761031861816133, 0.1032683208052601, 0.19138723452176365, 0.07102999570114271, 0.1286872604063579, 0.10833353722201926, 0.22954410846744264, 0.0978197321029646, 0.12931744301957743, 0.1294638030230999, 0.20364684239029884, 0.14603381816829952, 0.09462318755686283, 0.07499435011829649, 0.14392266502337797, 0.0760303305994187, 0.14792722942573683, 0.14057542463498457, 0.09956214217735188, 0.09496828368199722, 0.11442868837288447, 0.10893752838351897, 0.12556445226073265, 0.11275071198386805, 0.13001946892057145, 0.16819306196910994, 0.08777701349130698, 0.11495888206575598, 0.09678239455180508, 0.1929232749555792, 0.11646714327590806, 0.3225729965737888, 0.07849481049925089, 0.15391914147351468, 0.12933214008808136, 0.22335979102977685, 0.2266511201326336, 0.07359958746071373, 0.12278023308941297, 0.1023124617391399, 0.12466092860060078, 0.19113677367568016, 0.1390173453837633, 0.15327344754976885, 0.305107125214168, 0.24015498480626515, 0.1584892241018159, 0.10015444896583046, 0.13806939125061035, 0.1765643520546811, 0.18732502178422042, 0.13962400997323648, 0.18494653941265174, 0.15970559311764582, 0.14635685511997767, 0.10550282483122178, 0.17109084076115064, 0.11680243457002298, 0.11897067965141364, 0.149539374347244, 0.21068885523293698, 0.15585023856588773, 0.14033291621931962, 0.14888893067836761, 0.1887762589114053, 0.09608241782656737, 0.1327338804091726, 0.1433902457356453, 0.2297115166272436, 0.12474786250719003, 0.09553789347410202, 0.32214220826114925, 0.1434728777302163, 0.1281420032360724, 0.09976009798369237, 0.09825565692569528, 0.08521863791559424, 0.06467887399984257, 0.1680282186716795, 0.0942890497722796, 0.09585098988775696, 0.09417136465864522, 0.06203364594174283, 0.12943045981228352, 0.12376098760536738, 0.11746754816600255, 0.10580784667815481, 0.16579370786036762, 0.12379129097930022, 0.22543874090271337, 0.06987644545733929, 0.1374175362288952, 0.13810387440025806, 0.18675218895077705, 0.15957117533045156, 0.15130528887467726, 0.1543252853942769, 0.1270642996366535, 0.22224161960184574, 0.1270695243562971, 0.25153643265366554, 0.1351795784596886, 0.15393410995602608, 0.17850759492388793, 0.18029837097440446, 0.10913070730332818, 0.11825703723090035, 0.09401668581579413, 0.11540856079331466, 0.1138007856373276, 0.16557812371424266, 0.09792248944618873, 0.13801783615989344, 0.14251884392329625, 0.10037328329469476, 0.13833752114857945, 0.14923697843083314, 0.1272906589188746, 0.13044815377465316, 0.09283594667379345, 0.13653998688927718, 0.13234552767659935, 0.12115324182169777, 0.15475414666746343, 0.09753605696771826, 0.1473827322146722, 0.15625901520252228, 0.15950818013932022, 0.1437777570847954, 0.14046593622437545, 0.16940579403723988, 0.13254653689052376, 0.11245225835591555, 0.10282402964574949, 0.11572774366608687, 0.22647247543292387, 0.17236135687146867, 0.16596263593861035, 0.09128543308803014, 0.12427651137113571, 0.204312159546784, 0.1849629328187023, 0.12200366333127022, 0.16003428905137948, 0.1909648600433554, 0.19430718783821377, 0.13607764669827052, 0.06925390314842973, 0.1801938358694315, 0.12687228779707635, 0.08414830999182803, 0.1817805085863386, 0.13082387218517916, 0.11335878114082984], [0.08958690387329885, 0.09280603685017143, 0.033627401638243876, 0.018415939129356827, 0.03390364342236093, 0.08421819231339864, 0.04739907051303557, 0.03506058294858251, 0.04421304665239794, 0.03708715331075447, 0.10025878729564802, 0.024209710470001613, 0.022851510671898723, 0.0616954912298492, 0.0329419693111309, 0.0762369716539979, 0.03236764030797141, 0.023235612382580127, 0.029524419124105146, 0.038305106705852916, 0.056050541278507025, 0.04522394847923091, 0.02734281538453485, 0.011120992180492197, 0.019802377858598317, 0.033315546943673065, 0.01817564613052777, 0.019955864176154137, 0.022404715718169297, 0.03305052473608937, 0.028070890244894793, 0.031990269664675, 0.09535067209175654, 0.02697646414994129, 0.03749084772009935, 0.046413817309907505, 0.03698555626241224, 0.004385951972965683, 0.03849667410499283, 0.020374961330422332, 0.05174286510529263, 0.03635534990046706, 0.0220496027198221, 0.02804860545854483, 0.04523342761344143, 0.022986055684408972, 0.07030090982360498, 0.03436875203624368, 0.061428935533123355, 0.09498613593833787, 0.00867338405389871, 0.031025844093944346, 0.06583909424287931, 0.04016451318083065, 0.08390508911439351, 0.02190937497653067, 0.07553955979113068, 0.028808222019246647, 0.032981259881385734, 0.024363771845985736, 0.01637871067837945, 0.021266873560047576, 0.04829348823321717, 0.028289103714217032, 0.06787181552499533, 0.011713368518810188, 0.0851076567279441, 0.05106153112969228, 0.011944784583257777, 0.05199713931818094, 0.041107595432549715, 0.0381743326517088, 0.05753681116870471, 0.02993185565407787, 0.05037490458094648, 0.036716622300446033, 0.04116762542564954, 0.05354221783844488, 0.024691750228937184, 0.04727437273998346, 0.03556279046460986, 0.02457075725708689, 0.023189159875203456, 0.023967989154958298, 0.014493100877319063, 0.03366682791550245, 0.0756357421300241, 0.018765067448839545, 0.024631243564986756, 0.02997609952996884, 0.09017604190324034, 0.04773136607504316, 0.0376334961370698, 0.0464491113089025, 0.052691687763269456, 0.03673845755734614, 0.043514644128403494, 0.06892928521015815, 0.014282000151329806, 0.04081527915384088, 0.030454995975430523, 0.04033970752997058, 0.034075244928577116, 0.08157691332910742, 0.052400898188352585, 0.029237731293376003, 0.04595738037356308, 0.0526404074792351, 0.041351898573338985, 0.0025142093072645366, 0.04202635220385023, 0.06521676906517573, 0.024274133977347186, 0.05888490418770483, 0.014019866806588002, 0.037007975059428384, 0.0254791002121887, 0.015182785922661424, 0.010064536057013487, 0.04495626641437411, 0.07843668718955346, 0.027463818534410427, 0.023326256179383824, 0.024584329653797404, 0.04193674147661243, 0.05054696409830025, 0.07551372117762055, 0.03480449704719441, 0.0742167489869254, 0.04012114800778883, 0.028787116187491586, 0.015061770898423024, 0.05388011809970651, 0.012528326395632965, 0.03304032635475908, 0.02800901633288179, 0.05629502423107624, 0.0647370448069913, 0.04681261269641774, 0.020978972847972597, 0.040347748169941564, 0.051882785811488114, 0.06145904213190079, 0.012543754585619484, 0.032704875604914765, 0.03609374411670225, 0.023042716751141206, 0.041939560789614916, 0.008930766805341201, 0.03589408518746495, 0.021320696654064313, 0.045913764142564366, 0.07175090523170573, 0.05900019407272339, 0.012626321271194943, 0.011942098432752703, 0.03707295835816434, 0.013224024109409323, 0.031737919098564556, 0.031969706660934856, 0.0497639753988811, 0.02853436189304505, 0.03630492796323129, 0.08281158243439027, 0.036036343446799686, 0.02740511338093451, 0.03799044966165509, 0.08332617660718304, 0.014282878854178956, 0.016494255014029995, 0.01784145745581814, 0.0502831734317754, 0.034413175723914585, 0.08690873294004373, 0.028344816528260708, 0.03553308420149343, 0.00641759268806449, 0.025013635367421166, 0.08640431000718049, 0.07979571140770401, 0.03198146228013294, 0.02555600367486477, 0.03733125289103814, 0.036940613495452065, 0.04978796161179032, 0.0029053796565027107, 0.06844694180680172, 0.012296905242172735, 0.09720556970153536, 0.04613868832322104, 0.008901711935842676, 0.02592111488671175, 0.04841112245672515, 0.03239499544724822, 0.041582376563123295, 0.023538076152492846, 0.05552733310365251, 0.014743814477697015, 0.01514498473677252, 0.02127244433255068, 0.02836433458807213, 0.03355912744466748, 0.03223173313641122, 0.030243018242929662, 0.003767886298841664, 0.04538323796753373, 0.05111810737954719, 0.02113979073640491, 0.03704536233895591, 0.026691944238596728, 0.031785972948585234, 0.042405639708574326, 0.04224210259105478, 0.031937228582267246, 0.02254749644946839, 0.017040550342894027, 0.03195218010140317, 0.01626015025457101, 0.12175138401133673, 0.02131873568786042, 0.04065415762098772, 0.035428996929632764, 0.07933923375925847, 0.013646210294349917, 0.008558540305654918, 0.05661606628979955, 0.007764963067269751, 0.05247996787407568, 0.021150896658322642, 0.027916937434513654, 0.05314423669395702, 0.04044222060058798, 0.0329800215549767, 0.0221574134525976, 0.04245103370132191, 0.06104373120303665, 0.0591925655358604, 0.03870324730607016, 0.031006339604833295, 0.028846457467547486, 0.07773454593760626, 0.022362755112616078, 0.06310236573751483, 0.008150288685491043, 0.012242870954131442, 0.04250807474766459, 0.016464384206171547, 0.04184517656852092, 0.053191798606089184, 0.08655215600239378, 0.07627563457936049, 0.05043830689308899, 0.03401322004252246, 0.04949228319206408, 0.07321130936699254, 0.020888130579675947, 0.029593945214790956, 0.023920693567820957, 0.07189247477799654, 0.07616966098014798, 0.11484369396099023, 0.018278758008299128, 0.06387981759118182, 0.012255561255317713, 0.0293684612427439, 0.011670262885412999, 0.10429523605853319, 0.017525724933615754, 0.06964340260518448, 0.07851225563458034, 0.060537164099514484, 0.06560413792197194, 0.022952217143028975, 0.034845382174743075, 0.016674870857968926, 0.00918123867761876, 0.03965192747169307, 0.03004525921174458, 0.00118229775814273, 0.12669031827577523, 0.06330330709793738, 0.027657058522371308, 0.03365291455494506, 0.03214352358398693, 0.03374683397955128, 0.03504952961312873, 0.017139545209439735, 0.07974256175969328, 0.01991136754596872, 0.02817253309435078, 0.03211073337921074, 0.04185656238613384, 0.026755263430199454, 0.06133219679551465, 0.04571912976514016, 0.016894583889682378, 0.00571911976606186, 0.024252899223938584, 0.05148946959525347, 0.07056857831776142, 0.049671365546860864, 0.036930489752973826, 0.050628279734935076, 0.041980530734040906, 0.04176003060170582, 0.07576486734407288, 0.043914406427315304, 0.05156538409313985, 0.027288556331768632, 0.04409595186422978, 0.08511767869016953, 0.026742220290803483, 0.04171846354646342, 0.08053580990859441, 0.05494373191946319, 0.04852701284523521, 0.04269155400938221, 0.04488918983510562, 0.08401083879704986, 0.03526332242680447, 0.019801432998584848, 0.04429746997941818, 0.007850835914723575, 0.03896122632016029, 0.0724279610440135, 0.012116337743853884, 0.018066118704155087, 0.06558863339679581, 0.05399763697226133, 0.011600175306999257, 0.09633373362677437, 0.054073354694992304, 0.017914447467774153, 0.035402530671230385, 0.03503174181761486, 0.03594241723684328, 0.03683967123340283, 0.03202024394912379, 0.11036541033536196, 0.06495685622628246, 0.09210489304470164, 0.030729575348751884, 0.07472523634455033, 0.013299921643920243, 0.06265700927802495, 0.007724744600376913, 0.026594241981261542, 0.06567241211554833, 0.019039614591747522, 0.1409267700676407, 0.015368200705519744, 0.0038534410830054966, 0.18912081899387495, 0.16140297560819558, 0.2093365213700703, 0.14262054275189126, 0.09673197939991951, 0.173839572550995, 0.089984131843916, 0.24232369129146847, 0.13384232164493629, 0.14163791547928536, 0.13485014970813478, 0.10668643417635135, 0.09176737615572554, 0.14200520648487977, 0.13481049612164497, 0.21607604330139502, 0.13353809368397507, 0.1425462838794504, 0.069995270509805, 0.09870880296719925, 0.15426801703870296, 0.09899244417569467, 0.08689719105937652, 0.10687393375805446, 0.12959461100399494, 0.13725867761032923, 0.08012413592743022, 0.10454338988555328, 0.0716109573841095, 0.11163906127746616, 0.15607773778694017, 0.12191605088966233, 0.1355277890605586, 0.1358686172004257, 0.08103080120469842, 0.21417533100715705, 0.07536731367664677, 0.14103871477501734, 0.13967021820800646, 0.0798901499115995, 0.08845549422715392, 0.14557079944227422, 0.10599577373691968, 0.14478710506643566, 0.14834211287753923, 0.14870692044496536, 0.2163797148636409, 0.09577586927584239, 0.12135898721005235, 0.15828057458358152, 0.06641582186732974, 0.12756444779889925, 0.1400128241096224, 0.12081497854420117, 0.19515071543199675, 0.08778168181223528, 0.1176652189876352, 0.10509866223271404, 0.15259218482034548, 0.15910233477396624, 0.14571360392229898, 0.1736306380480528, 0.19852758065930434, 0.10311626789293118, 0.18899486932371343, 0.0918330651308809, 0.21006332736994537, 0.13650391596768582, 0.18693987173693521, 0.19489759472864016, 0.18089643173984118, 0.1717334677066122, 0.11760918556579522, 0.15869954281619617, 0.17404648501958164, 0.10211361026657478, 0.17259923767830643, 0.1566180552222899, 0.13008751241224153, 0.13973819384617464, 0.13824974585856709, 0.16636175023657934, 0.15377606557948248, 0.21320379099675588, 0.21060523257723876, 0.11163266947759048, 0.21450219489634037, 0.15020253376236983, 0.12778463241245064, 0.09040343934403998, 0.18727919352906092, 0.1214594646756138, 0.14919212726610048, 0.2484983599611691, 0.14651336600737913, 0.18878932749586447, 0.1088638666218945, 0.1483720905546631, 0.1319811272301844, 0.14914404627467903, 0.10857851550515209, 0.1152224929205009, 0.1312385249350752, 0.22277912790221827, 0.1701803689024278, 0.20326750060277327, 0.14225441882652895, 0.1970227256949459, 0.13076930439897946, 0.1035727591120771, 0.09636951277830771, 0.1570007489728076, 0.15202817294214452, 0.09469667968473264, 0.14625926821359567, 0.18213751300105027, 0.15407927573791572, 0.07756118702569179, 0.16662542894482613, 0.1733427220689399, 0.18869958445429802, 0.08445027843117714, 0.15384405478835106, 0.17005417495965958, 0.1322254812611001, 0.16351236456206866, 0.250905449369124, 0.14934642612934113, 0.16422057870243276, 0.16716236727578299, 0.1635934223553964, 0.15191692034048693, 0.1293256397226027, 0.1261308797236, 0.2041257524064609, 0.0968871603586844, 0.27539388675774845, 0.30885451127375874, 0.19050175989312784, 0.19373238725321634, 0.14336611703038216, 0.0971881245662059, 0.26656375772186686, 0.20547530427575111, 0.11493038359497275, 0.18874260357448033, 0.14819024316966534, 0.16399807349911757, 0.12093640917113849, 0.10223677115780966, 0.12607811684054987, 0.15889046899974346, 0.16885900337781223, 0.1127652937014188, 0.15499406307935715, 0.1414733843079635, 0.07874174974858761, 0.11503429444772856, 0.20040174866361277, 0.1241227417652096, 0.13732829530324253, 0.11002081632614136, 0.22868030624730246, 0.2240544751818691, 0.12046192320329802, 0.10875901939081294, 0.1107184181788138, 0.14693688042461872, 0.12284715021295206, 0.08730721620044538, 0.14212579572839396, 0.14807164881910595, 0.13314872314887388, 0.3081176493849073, 0.10573702797825847, 0.07105062995105982], [0.03576529924092548, 0.027188240018274103, 0.02410548409846212, 0.07342204198773418, 0.03803681395947933, 0.03855642929141011, 0.04615000628733209, 0.04785919189453125, 0.03157779161951371, 0.028055165195837617, 0.01789139084784048, 0.04504943945045982, 0.027025011634188037, 0.020053931146061847, 0.03446038140516196, 0.014383944948869092, 0.07511143133576427, 0.08747497719845601, 0.03584379217188273, 0.0038744743963304374, 0.027376406260633042, 0.060254981741309166, 0.02270295051857829, 0.049920923941369565, 0.03886806346209986, 0.0198579854997141, 0.04560412486482944, 0.029546413836734634, 0.03290350655359881, 0.021186689380556345, 0.017348488194069693, 0.03641527811331408, 0.020390708431867615, 0.01837573423316436, 0.02399627727988575, 0.07229770946183375, 0.06323058171463863, 0.03015724802389741, 0.022642694912584763, 0.02598567070838596, 0.03969531300078545, 0.01823560657378818, 0.020465294697455, 0.05715727260602372, 0.08126028174800531, 0.04374518997168966, 0.004788507291648004, 0.02043769528557147, 0.03576052913974438, 0.0672978088259697, 0.01661724118249757, 0.03446353320032358, 0.03664341176460896, 0.0700119828273143, 0.04073638927989772, 0.005381052415551884, 0.018338126429755772, 0.06013393787933247, 0.025164086937106082, 0.06327025565717902, 0.06351153592446021, 0.06416907706963164, 0.03802494298932808, 0.006587242982017675, 0.017961542887080992, 0.028036948226924454, 0.0486217499045389, 0.05158316510330353, 0.05268612377611654, 0.024821179087406824, 0.056063463977937184, 0.03539095147113715, 0.07095005070524556, 0.012318594614043832, 0.11856156374726977, 0.028180217503436973, 0.05609522959483521, 0.012378879905944424, 0.040375249194247384, 0.07082017910267625, 0.028599518218210766, 0.0409385655740542, 0.03402538617540683, 0.04242927647594895, 0.017579944970618402, 0.03247906254338367, 0.03275394725746342, 0.02932353883183428, 0.023150232321183597, 0.05820998576070581, 0.032468704706324, 0.03042128635570407, 0.019199048268741796, 0.00707036627656115, 0.03440798832369702, 0.004399084594167236, 0.027932659090895737, 0.027948453689792326, 0.016226632320987325, 0.028472886620355502, 0.02400505243401442, 0.06828059216162988, 0.014901821534814579, 0.027567066119185517, 0.010783699208072253, 0.04441349268225687, 0.02937084629333445, 0.0335371259466878, 0.03533967797245298, 0.025275531224906445, 0.04141973850450345, 0.03916050526978714, 0.01221444457769394, 0.06934887769498996, 0.018755951330864003, 0.05634869974372642, 0.02489013860135206, 0.034369104874453375, 0.029179970999913554, 0.09618299028703145, 0.03171238921848791, 0.030896159088505164, 0.06386066254760538, 0.013971511856652796, 0.006572542520838657, 0.013937626665990268, 0.023419571707823446, 0.03568521175267441, 0.12557233683764935, 0.08341727671878678, 0.03178098571619817, 0.028067933528551033, 0.028338731765480976, 0.02189926310841526, 0.03371108536209379, 0.04965038524408426, 0.004048829906553562, 0.05936439774398293, 0.045038715204490085, 0.020591461498822485, 0.045240867749920914, 0.025821148018751825, 0.04657464028735246, 0.017415227202166404, 0.0799270011484623, 0.050518709900123734, 0.028106971344511424, 0.04881602805107832, 0.011592937882856598, 0.04679790544988854, 0.1006851244185652, 0.034415665947433026, 0.0689537056854793, 0.014616640051826835, 0.06087358854711056, 0.05789932528776782, 0.03299084758119924, 0.05545797325404627, 0.06977935388152089, 0.02797511333067502, 0.028264476285715188, 0.0633213222026825, 0.049004162063023875, 0.03625044160123382, 0.020013912846999507, 0.009211575130133756, 0.04146628600678273, 0.0206082213137831, 0.03360176658523934, 0.015454428935689586, 0.037806305435619185, 0.050216697355998416, 0.0303017861608948, 0.04492613945954612, 0.027035612047516873, 0.04020043821739299, 0.023440021056947962, 0.042805473253663094, 0.006313183112069964, 0.05930561625531741, 0.08648874690490109, 0.05389332239116941, 0.029935614738081182, 0.06724823505750724, 0.01147478458005935, 0.042398216535470316, 0.020786828694066832, 0.012602788828579443, 0.026797768560105135, 0.03571936920551317, 0.07122485060244799, 0.022447288701576844, 0.024106883576938083, 0.03322329332253762, 0.012275149713137319, 0.0343224013091198, 0.03083743866799133, 0.057720436315451346, 0.06551429988550288, 0.01696643396280706, 0.008287460476692234, 0.06964815913566522, 0.029070923637066568, 0.0036925659431809826, 0.05505170380430562, 0.059023718881819925, 0.09451743108885628, 0.010595895981948291, 0.0389620235988072, 0.031111716093229394, 0.06159084755927324, 0.02286268614365586, 0.029793325944670608, 0.05216364502640707, 0.004242290418395507, 0.0767793111237032, 0.014909748520169939, 0.014215256902389228, 0.09707702124225241, 0.006656211401735033, 0.020914722367056778, 0.02222227631136775, 0.03661314910277724, 0.05451480279277478, 0.051593872385897806, 0.04233133333868214, 0.07057190992470298, 0.03387538922418441, 0.008786651904561689, 0.06286567236695971, 0.0171498809941113, 0.016413041157647967, 0.014774723444133997, 0.11930331108825547, 0.008550577697211077, 0.027599776596097008, 0.057103084799434455, 0.043418037705123425, 0.06937709796641554, 0.02682217376838837, 0.06064262879746301, 0.04092067260561245, 0.020357283796848993, 0.03505227767995425, 0.07926353639257805, 0.04718813433178833, 0.04314576195819037, 0.06645701572831188, 0.028141556274411932, 0.01751946035905608, 0.049688651226460934, 0.032730388521615944, 0.02215673152490386, 0.02202047830048416, 0.05666284788666027, 0.06754896856312241, 0.05894079511719091, 0.018241436885935918, 0.020128066185861826, 0.010709527697015022, 0.06156274263880082, 0.050849305731909614, 0.06125329674354621, 0.06497042014130525, 0.014542014770475882, 0.02244049826237772, 0.14783684856125287, 0.045733830226319175, 0.01941899030602404, 0.008276899079126971, 0.052305465630654774, 0.024769113399088383, 0.007860929971294743, 0.019073963730729053, 0.021415072393470576, 0.07578930139009442, 0.02221448503301612, 0.07049248061542, 0.03645476545872433, 0.034785362359668524, 0.0778179175353476, 0.03406597953289747, 0.02701169708078461, 0.03012795905981745, 0.019820621968912225, 0.052237917469548326, 0.00977880580882941, 0.01927858783996531, 0.005485633745723004, 0.02715715972174491, 0.03642795654013753, 0.06017419536198888, 0.047346691002271006, 0.005684860532970301, 0.01727020730530577, 0.02443158802842455, 0.009190560052437442, 0.027050733200407455, 0.04625561347763453, 0.04091476595827511, 0.017324590190712894, 0.03701791899012668, 0.010972856959727193, 0.07173371115433318, 0.025810079416260123, 0.018509483663365245, 0.04737930139526725, 0.051979246349739175, 0.021789464268035123, 0.03740744898095727, 0.039559918123164346, 0.028763248718210628, 0.0741087601387075, 0.023362852965614626, 0.0378257251078529, 0.015051428328401275, 0.08361055063349859, 0.010105603540848409, 0.023273942825783576, 0.04826737481302448, 0.06064970591770751, 0.03629002394154668, 0.01771500736608037, 0.028454286279156804, 0.05754368472844362, 0.03454327802839024, 0.055834000398005755, 0.058261160871812274, 0.010752353434717017, 0.01912754255213908, 0.0460550690601979, 0.053355284833482335, 0.047924002166837454, 0.04237450512924364, 0.015263431505965335, 0.019872328033670783, 0.04435718784640942, 0.04673730888004814, 0.06866758782416582, 0.07064197545072862, 0.012866414950362273, 0.05562777664246304, 0.025414720809619342, 0.01448929768853954, 0.05750553748969521, 0.02745539621849145, 0.02872881306601422, 0.07030144586626973, 0.011338446538762322, 0.016126080216573815, 0.024979247212676064, 0.020557614475754753, 0.15036030672490597, 0.09315070549824409, 0.06400853568421942, 0.2142822274139949, 0.16047866163509233, 0.13823029904493264, 0.12631708330341748, 0.1701872492475169, 0.09910316752003771, 0.08463759480842523, 0.09373269176908902, 0.09359526128641196, 0.1721310213740383, 0.11309589631855488, 0.11890992362584386, 0.2375154293009213, 0.10813332867941686, 0.11099763533898763, 0.09045465516724757, 0.10414481841559921, 0.1254858100520713, 0.16373786889016628, 0.14855506430779183, 0.23957242178065435, 0.07635256009442465, 0.11587319443268435, 0.12888539263180324, 0.10055847585733448, 0.10073655058762856, 0.08968509467584745, 0.21639329913471425, 0.13305359253925936, 0.12275348523897783, 0.07347280997782946, 0.11382833415908472, 0.11375927965023688, 0.13843088756714547, 0.14702997542917728, 0.1282759460487536, 0.20343689008482865, 0.18089492539209978, 0.07583094308418886, 0.24535598286560603, 0.21793756341295584, 0.18919727631977626, 0.18820562453142234, 0.1032655116702829, 0.1094526450282761, 0.0901245546660253, 0.20593398037765706, 0.22283205363367284, 0.14583517025624002, 0.09665508781160627, 0.14146613755396434, 0.0964811657156263, 0.10389211161860398, 0.11875459338937487, 0.2549145599561078, 0.10102254631263868, 0.14293345596109117, 0.23661596328020096, 0.19862948304840497, 0.1645546214921134, 0.08536923876298325, 0.1282338225947959, 0.11405584695083754, 0.15951755749327795, 0.1052421113210065, 0.11926688732845442, 0.18325793716524327, 0.13520940685910837, 0.20543050739381993, 0.10515252434249435, 0.10146144311875105, 0.3376955608172076, 0.12603276355990342, 0.1451946874814374, 0.13438738882541656, 0.22984041113938602, 0.1513876494552408, 0.10487103409000806, 0.14691797643899918, 0.1480388484363045, 0.100732818645026, 0.13404542074671813, 0.10928565077483654, 0.20539569854736328, 0.119367405506117, 0.18456976248749665, 0.10317793315542595, 0.2448897207421916, 0.12176172488502093, 0.07495612145534583, 0.11449565977922507, 0.06344765863780465, 0.19907408633402415, 0.086623734661511, 0.09209403648440327, 0.07426947794322457, 0.2094256944422211, 0.07452476995864085, 0.1700731332280806, 0.11531328090599605, 0.22343974959637436, 0.14830590624894413, 0.10816922996725355, 0.1726680411291974, 0.08464150317013264, 0.10615232533642224, 0.10781749776963677, 0.07893042998122317, 0.11606895178556442, 0.05805155461920159, 0.16247447739754403, 0.07835896100316729, 0.2380614871425288, 0.15634415777666227, 0.13672680115061148, 0.10386566910892725, 0.2074105404317379, 0.11635263370616095, 0.15254878572055272, 0.19867217647177832, 0.1217416131070682, 0.19804331021649496, 0.2086729412632329, 0.08961729545678411, 0.1345436011574098, 0.14313992059656552, 0.16808566344635828, 0.07250713929533958, 0.10229004294212375, 0.09126783867499658, 0.0713555703737906, 0.13167246165020124, 0.12704783837710107, 0.1259600653180054, 0.12128871812352113, 0.0780275645000594, 0.10342376639268228, 0.14742368858839783, 0.1046591547450849, 0.07161940514509167, 0.08623410628310271, 0.11770774956260409, 0.08922561111726932, 0.1046545407069581, 0.12056997311966759, 0.14114391484430858, 0.13099441517676624, 0.16479977619435104, 0.1297090391495398, 0.1027982249589903, 0.09553855165307011, 0.11860222156558718, 0.15906025203210966, 0.1293441230165107, 0.07908413173364741, 0.1572868600487709, 0.08781978833888258, 0.09931803920439311, 0.13852456611182007, 0.09831527979778391, 0.11828415149024554, 0.14934728108346462, 0.11158753332815, 0.1178804367248501, 0.12200198056442396, 0.15455331387264387, 0.07323089188763074, 0.10395705420523882, 0.12801506290478365, 0.16284631458776339, 0.14625801970916136, 0.14573530347219535, 0.14135704269366606], [0.04930348421580025, 0.01596868214463549, 0.009161955560557544, 0.048158524225332906, 0.05430840261812721, 0.033900345742170296, 0.05329758221549647, 0.06021234938608749, 0.025594407060582722, 0.043355944965566905, 0.033082860322403054, 0.04438599844330123, 0.047687091665076356, 0.04432556811454041, 0.0036417063508581904, 0.04498202021100691, 0.05555185875190156, 0.07057600827621562, 0.04315211643864002, 0.057081853438700945, 0.031440300068684986, 0.008705575451520937, 0.02484156227936702, 0.01796145298119102, 0.0237500572776688, 0.022884970930005823, 0.049608601057635884, 0.02861238324216434, 0.09071001503616571, 0.10254423573080983, 0.04418723518028855, 0.04710228947390403, 0.02835533212471221, 0.06908339408359357, 0.029303667933813164, 0.05157043917902878, 0.04266457545704075, 0.07715355711323874, 0.03787753125652671, 0.08112069352396897, 0.04049843383420791, 0.05013481514262302, 0.031998720818332264, 0.04252916361604418, 0.042111314966210296, 0.018988977219643335, 0.06601598153689078, 0.08210945475314345, 0.028223942300038676, 0.025454294668244462, 0.029964248915868144, 0.02357986373161631, 0.04094551716532026, 0.03266307445509093, 0.01937876166110592, 0.111264828858631, 0.04738798664350595, 0.0019535025307309945, 0.03932753684265273, 0.02215010393410921, 0.051632294431328773, 0.0504998975167317, 0.0401415956605758, 0.03721773398241826, 0.04097865342295595, 0.04394193459302187, 0.04305183235555887, 0.013660010848460453, 0.04803029807018382, 0.07891157349305493, 0.0025198263049657854, 0.012133908408161784, 0.05874353141656943, 0.0888356366860015, 0.03450930038733142, 0.06751504859754018, 0.027626517661181942, 0.06382617261260748, 0.03234531311318278, 0.008687948808073997, 0.017672875430434942, 0.040525039192289114, 0.03264912377510752, 0.044020705723336766, 0.029602766170033386, 0.03876073957820024, 0.10918829457036086, 0.04944336760256972, 0.023665342180590545, 0.032681842733706744, 0.03878519058759723, 0.006996766007172742, 0.018021834116162996, 0.020469230200563158, 0.020237172920522944, 0.011187063679764313, 0.07453213884894337, 0.016899594870795096, 0.014658239337482622, 0.052535763808659146, 0.038004193388457806, 0.020627291540482214, 0.02700257078478379, 0.01061073808731245, 0.08691604754754476, 0.027756835400526012, 0.028486677844609534, 0.029843629138278108, 0.05195854424632021, 0.10267503014100449, 0.023584455717355013, 0.044798978604376316, 0.04859071371278592, 0.046727856887238364, 0.03569529478305152, 0.008215299125627747, 0.09212440092648778, 0.0059416563516216615, 0.01553854183293879, 0.04435613950980561, 0.023685362356315767, 0.011452618537337651, 0.04926448541560343, 0.055949951854667494, 0.014502060932240315, 0.014875070291704364, 0.02769676299898752, 0.017868174772177423, 0.020389965436022197, 0.038256275933235884, 0.019798413517751863, 0.008304082888311573, 0.034764171711036136, 0.053847589130912504, 0.03301604497911675, 0.022272927254172306, 0.0027669243739053074, 0.028600994031876326, 0.044408417240317376, 0.035750232370836396, 0.05851787102541753, 0.05350715793403132, 0.0187009289262018, 0.028231243336839334, 0.044524236382650476, 0.048051312299711366, 0.015387311644319977, 0.007312742377897459, 0.06733219019536461, 0.03011817458484854, 0.025074452461142625, 0.0109150822473956, 0.02728683963817145, 0.016898405738174915, 0.011932867811992764, 0.022709727387077043, 0.095219009156738, 0.05977058916219643, 0.031940058073295016, 0.007607850828208029, 0.0380823131251548, 0.09159032601330962, 0.019732480269989798, 0.03474537289834448, 0.05218488995784095, 0.017951103625819087, 0.05972464555608375, 0.018377440748736262, 0.085707834522639, 0.07895300484129361, 0.019002656485619288, 0.040576540000204525, 0.02410624914669565, 0.04578973472650562, 0.034871325961181095, 0.05380315187254122, 0.07247773158763136, 0.02797205144140337, 0.013836524948211653, 0.05490162542888096, 0.020467364229261875, 0.017633700211133276, 0.025359896876450096, 0.0052337424630033115, 0.060620169288345745, 0.013747680965544922, 0.029753098996090035, 0.07845834602734872, 0.022872138136465634, 0.007095737549077187, 0.052861552219837904, 0.07816300687513181, 0.026640231388487985, 0.019256920520482317, 0.04089194343292287, 0.03054201809157218, 0.0261795858386904, 0.02027960341157658, 0.02855393084298287, 0.06075228684182678, 0.02216787137357252, 0.042509635378207476, 0.03132076933979988, 0.05128164788974183, 0.07016079234225409, 0.04679547290184668, 0.016383859062833444, 0.019909922266379, 0.013273812464571424, 0.016012927716864005, 0.10309899917670659, 0.06602449715137482, 0.07583585567772388, 0.010315546516462095, 0.03796046180650592, 0.054490646946110895, 0.021689095368076648, 0.025797005742788315, 0.03490828237097178, 0.03492244000413588, 0.024078570006947433, 0.01389329118787178, 0.03914111613162926, 0.021251635359866277, 0.026959824774946486, 0.06898922699370555, 0.032137359093342505, 0.020199822960421443, 0.013728491147048771, 0.01593859081289598, 0.04577670006879738, 0.02861760796180793, 0.051761847122439315, 0.033861547109803984, 0.018112340509625416, 0.05269921610930136, 0.060753535346261094, 0.009671114667850946, 0.03819884472925748, 0.03882945142686367, 0.022002541227266192, 0.048175545276275704, 0.014473530231043696, 0.054519528789179664, 0.08065502851137094, 0.04227886222569006, 0.029770652697022473, 0.01914663822390139, 0.06232810978378568, 0.02125116377802832, 0.08092705998569727, 0.029445980475949388, 0.010871303167992404, 0.0695675356047494, 0.008991051249073019, 0.012969090869384152, 0.08542398975363799, 0.04970942796873195, 0.025190948442156826, 0.05768406005310161, 0.03784276990752135, 0.03120292816311121, 0.03601867778758917, 0.02365219047559159, 0.03249566629528999, 0.01690774068369397, 0.03064432760168399, 0.0038294714093873544, 0.04221839118482811, 0.020811586740559766, 0.08347607856350285, 0.0014452896617253178, 0.01398955749547375, 0.03802802353831274, 0.01777193645414497, 0.060444225158010206, 0.033583066160125394, 0.01703048766856747, 0.06504762385572706, 0.015855024136336784, 0.13773708551057748, 0.04879870844472732, 0.00832701482743557, 0.04047888184764555, 0.06525632765676294, 0.004788858009435768, 0.028494854191584245, 0.013540380035660096, 0.04061000873999936, 0.013337286871059664, 0.04617923079058528, 0.012699759964432036, 0.015725595277867148, 0.007447133023690964, 0.04928452255470412, 0.0006598112688932035, 0.00785013532731682, 0.02327369007148913, 0.013637081453842776, 0.04732646726604019, 0.05378847855276295, 0.01796468789689243, 0.0712833267503551, 0.051208610380334516, 0.0607090030929872, 0.10328610520809889, 0.02844842373659568, 0.004833648954185524, 0.023511820239946246, 0.023597190123317496, 0.018680606802393283, 0.05564545247969883, 0.016728300401674848, 0.009432640991040638, 0.0498593095690012, 0.04965398147968309, 0.042770739046058485, 0.04123888856598309, 0.04520806058176926, 0.031196159776300192, 0.011055270126754684, 0.05836546527487891, 0.04310058509664876, 0.005763422589682574, 0.0563015687013311, 0.05922483666134732, 0.03534254139023168, 0.009287484539007502, 0.054932464845478535, 0.031746896116861274, 0.03241938878116863, 0.07557012779372078, 0.04559187391506774, 0.03757784269484026, 0.0475979593050267, 0.05239059463409441, 0.047135591972619295, 0.0653522317962987, 0.0027748201890582485, 0.011191475853723074, 0.026888274953567555, 0.017062952176534703, 0.04970298527872988, 0.023146575017433082, 0.05167263673086252, 0.042217047685491185, 0.052041508723050356, 0.021970117431400076, 0.07527449008609567, 0.048172234025384696, 0.01906725810840726, 0.020518466397853832, 0.12484262670789446, 0.1679698782307761, 0.11162420814590794, 0.11394770203956536, 0.1595900657453707, 0.15151710036609853, 0.13770157098770142, 0.1555914045976741, 0.0960423910458173, 0.14055500073092325, 0.1248566588120801, 0.1983509444232498, 0.1411590190338237, 0.09968606981315783, 0.09415861498564482, 0.11395774435784135, 0.1042244919974889, 0.17325950653425284, 0.09680227562785149, 0.10291411195482526, 0.14201604947447777, 0.1231455427727529, 0.09147910733840295, 0.18975773267447948, 0.08476970557655607, 0.15572837367653847, 0.11158969785485949, 0.16143367253243923, 0.11860895263297216, 0.1899048662079232, 0.1394612429929631, 0.10310243256390095, 0.11787317640015058, 0.1595929427338498, 0.1097832340747118, 0.12594342763934815, 0.14467482109154972, 0.21627006360462733, 0.15663419078503335, 0.2463513665965625, 0.12972422476325715, 0.0739139730909041, 0.09051121106105191, 0.11895226421100752, 0.1384292183709996, 0.08365886232682637, 0.16301867605320045, 0.21538899945361273, 0.1414904155369316, 0.2664988354912826, 0.08088546578905412, 0.13204799007092202, 0.12181945464440755, 0.09002912550100259, 0.1034847531201584, 0.17279789916106633, 0.13156021838741644, 0.1065678194697414, 0.1313876397907734, 0.15065331171665872, 0.19512896159929888, 0.08472672716847487, 0.07035955560526677, 0.1894352249801159, 0.08613450412771531, 0.14161460101604462, 0.12295002969247953, 0.11562805330114705, 0.1270471327006817, 0.24121824918048723, 0.18229802724506172, 0.1797153872570821, 0.12928104640117713, 0.1763675090457712, 0.12726591953209468, 0.19090771382408483, 0.09980243178350584, 0.1565470668886389, 0.122405898890325, 0.13636993244290352, 0.1594584435224533, 0.14240368295993122, 0.10746944323182106, 0.16536396449165686, 0.15174773441893713, 0.0953364432124155, 0.1481367474687951, 0.10844324276383434, 0.12147455529442855, 0.15021674228566034, 0.0528916248918644, 0.05624271935916372, 0.10376305425805704, 0.171202921175531, 0.15664875214653357, 0.053736977744847536, 0.1297573779842683, 0.10500828136823007, 0.12306033234511103, 0.12654728309384414, 0.11149950698018074, 0.06135006940790585, 0.09845695112432752, 0.0931980875985963, 0.36473526273454937, 0.16936063074639865, 0.17677959693329676, 0.15243401830749853, 0.260916853589671, 0.133341535659773, 0.11845449092132704, 0.1325925551354885, 0.13916955435914652, 0.11737563381237642, 0.11592495308390685, 0.16934872924217156, 0.13569955341517925, 0.09882331253694636, 0.11779473775199481, 0.14859004957335337, 0.09060221617775303, 0.0654814587906003, 0.0942173150501081, 0.13088230762098516, 0.09957208271537508, 0.08933743368834257, 0.19158698166055338, 0.15360363626054355, 0.13124047911592893, 0.18194604398948805, 0.08559235464781523, 0.2028298590864454, 0.07605484606964247, 0.09553436509200505, 0.12821248945380959, 0.12770426672484192, 0.10329523150409971, 0.1711171679198742, 0.09471839280532938, 0.11743618627744061, 0.14046794468803064, 0.0856206292020423, 0.06483389211020299, 0.07979020848870277, 0.09407082612493209, 0.28420026706797735, 0.19229406943278654, 0.10564251483551093, 0.13930975326469966, 0.09735009766050748, 0.07670281308570079, 0.0782581442700965, 0.1507621215922492, 0.15142773730414255, 0.19648964144289494, 0.1097512547192829, 0.20949193303074154, 0.1070615758321115, 0.08043630274810962, 0.12403902411460876, 0.23990867659449577, 0.2096795751047986, 0.09640134285603251, 0.12326450353222233, 0.15116764126079424, 0.1062547094853861, 0.16055199769990786, 0.13614134756582125, 0.1077458376863173, 0.16282590425440244, 0.11404575034976006, 0.11464176193944045, 0.11698136425444058, 0.09668476014797177, 0.09073237276503018, 0.1267014733914818], [0.02386328611256821, 0.04374233673193625, 0.07306800277105399, 0.07268151600978204, 0.022856635307627063, 0.04155046506119626, 0.01811491046100855, 0.044241918317441425, 0.012219646396780652, 0.03118934389203787, 0.02708188135043851, 0.03890942356416157, 0.023174325403358256, 0.04005467193201184, 0.03391011664643884, 0.03583426554022091, 0.05383364184360419, 0.05995627027004957, 0.027822554909757206, 0.04524413150336061, 0.022359180929405347, 0.05263389693573117, 0.050381303166172335, 0.013912307979938175, 0.026315518455313783, 0.043802573678216765, 0.014754080712529165, 0.02924121217802167, 0.032970203153256855, 0.024167724419385195, 0.06739006923245532, 0.009532444162427314, 0.01611741871706077, 0.06020163531814303, 0.0009846502611513383, 0.030398887914738486, 0.05366142287052103, 0.014302386735965098, 0.020676644785063605, 0.07070236506738833, 0.05355862820787089, 0.0851638869249395, 0.02646054683386215, 0.014892791930053915, 0.004666645794973842, 0.017754504889515892, 0.031183036909039532, 0.059661948920360634, 0.0557337231002748, 0.07827710932386772, 0.06353551535201923, 0.05479136348835059, 0.06847244115280253, 0.028848218265920877, 0.08342326139765126, 0.02032680400381131, 0.02882222019668136, 0.04106536680566413, 0.08128965552896261, 0.038642382714897394, 0.07240794426096336, 0.03411096640463386, 0.0316445187532476, 0.036369259868349345, 0.014494836230629256, 0.03778224458385791, 0.043176594589437754, 0.017269873126809086, 0.06667998912078993, 0.07528136364583458, 0.030261416719960313, 0.015115834872371383, 0.04064537398517132, 0.054705484703715355, 0.04076598019206098, 0.022841152834839056, 0.005172241745250565, 0.008984304066481335, 0.033942513300904205, 0.021187529067641923, 0.01477001780377967, 0.034876191057264805, 0.035633829688387256, 0.043356749029564004, 0.06257571399744068, 0.02890621604663985, 0.026747570539425527, 0.05258925611685429, 0.03357209424887385, 0.016147528708513294, 0.02868409760828529, 0.01022321401563074, 0.009664594794490507, 0.041851707468075414, 0.031477996081646, 0.009385716901826007, 0.025242790213919113, 0.03372119214119656, 0.028056506998836994, 0.03370102947311742, 0.057859135658613274, 0.0850683016968625, 0.009306932200810738, 0.06034347627844129, 0.05189199692436627, 0.03739704703912139, 0.021534382598474622, 0.005721872497815639, 0.07671649235167674, 0.021497019067672745, 0.047014965409679074, 0.004701481358746865, 0.03702108435598867, 0.07466970503862415, 0.013581866514869034, 0.03096364618145994, 0.07076449851904597, 0.021065038229737962, 0.015154390928468533, 0.04753725077690823, 0.009469240321777761, 0.06739051706556763, 0.038914298838270564, 0.03142265137284994, 0.017324629206476466, 0.0563556886544185, 0.06250583167587008, 0.02340067450755409, 0.002797794960705297, 0.050845645035484006, 0.04561455734074116, 0.010817611540135528, 0.003736881065248911, 0.06819966328995568, 0.03384330469582762, 0.04245729997221913, 0.03371586564130016, 0.01586627763962107, 0.02030151500366628, 0.037539420649409294, 0.03419395463008966, 0.05761570443532296, 0.06873512919992208, 0.056378131200160296, 0.00708932666540412, 0.016816800027819614, 0.006318968895357102, 0.039953800916139565, 0.024861652004931654, 0.0825251592323184, 0.004630967999608921, 0.008612652625223356, 0.01624157535843551, 0.07337061581867081, 0.027436970600060055, 0.05379721469112805, 0.017542058967852166, 0.08409494999796152, 0.08847940580121108, 0.05086323605584247, 0.04781219995181475, 0.05484658945351839, 0.010360016005246766, 0.0395518062370164, 0.06788845998900277, 0.01960721592019711, 0.03480774722993374, 0.046985537345920286, 0.010700289442736124, 0.0322884213445442, 0.0663448471043791, 0.06384929030069283, 0.06363276299089193, 0.05164893550266113, 0.031531926044928174, 0.010013796904656504, 0.02811765148570495, 0.06570196231561047, 0.0408693414314517, 0.023585780556978922, 0.05173578119969793, 0.019591864065400193, 0.020121168877397264, 0.08398335134344441, 0.018472186289727688, 0.027158774635089294, 0.08178763237914868, 0.01868090875047658, 0.028624152432062795, 0.07938751152583531, 0.04278468294069171, 0.033141886083675284, 0.055535394099674056, 0.0056154765105540195, 0.026216954458504915, 0.015771284433347837, 0.060816734097898006, 0.011756542005709239, 0.02001117665453681, 0.0362338853467788, 0.056378579033272605, 0.058623532498521466, 0.02103601219797773, 0.042952874808439186, 0.02414529205166868, 0.04349851195833512, 0.07023273741028138, 0.0198037926041122, 0.041401770897209644, 0.06464540186737265, 0.013395383039356341, 0.04384865299133318, 0.04805975666801844, 0.03160573708425675, 0.02049421555628734, 0.03797259061996426, 0.06483404138790709, 0.05484856738309775, 0.031161493422197442, 0.0591250445161547, 0.018405518527807932, 0.03276022370638592, 0.037451760710350106, 0.03125679027289152, 0.07495447940060071, 0.01730601699091494, 0.03786131087690592, 0.028907478121774535, 0.06608751948390688, 0.014764297753572464, 0.0728438962250948, 0.015116043521889617, 0.028075938545433537, 0.008609832464052098, 0.08227878316704716, 0.043256196925150495, 0.07161629066935607, 0.023719504542116607, 0.053260473135326586, 0.02822146564722061, 0.015540092285456402, 0.03200686663123114, 0.03599741928545492, 0.06911467454795327, 0.015508479338937571, 0.06097669194319418, 0.028768938234341995, 0.047611736958580356, 0.01007792609743774, 0.06808461089219366, 0.08048240241727658, 0.017841946001031568, 0.011443751780981464, 0.053537030438227315, 0.02263148551407669, 0.024458549617390548, 0.06653222454977886, 0.023204206389241984, 0.01516742049716413, 0.08209016400256328, 0.015145342663994856, 0.023025330987625887, 0.0038103396904521753, 0.04079917412517326, 0.08766106542732034, 0.01693416283732014, 0.00798861075392259, 0.01548464918908264, 0.03891071956604719, 0.004810758999415806, 0.0246325768862984, 0.009061153246355909, 0.013368622466389622, 0.041002364829182625, 0.018543120340577195, 0.025307922790359174, 0.01683420954006059, 0.04624550330585667, 0.02204383347582604, 0.004308181681803295, 0.006846948867730264, 0.022200213745236397, 0.03935088862531951, 0.06161750041480575, 0.04702071599396212, 0.032242521843207736, 0.007934400046776448, 0.049130607063749006, 0.01917320626255657, 0.027545354694926312, 0.030109034718147347, 0.031274737524134774, 0.041860708235097785, 0.008928496257535048, 0.09978810790926218, 0.06067873364580529, 0.09401099290698767, 0.03500885143876076, 0.024203788555626358, 0.010342434314744813, 0.03421738783695868, 0.03217329091525503, 0.04893525343920503, 0.031859105452895164, 0.03160918064947639, 0.006201095488255045, 0.03214074498308556, 0.007380600120606167, 0.021719439454110603, 0.07275534740516118, 0.02779017012965466, 0.01604068828081446, 0.07463051285594702, 0.04578288830816746, 0.0074492704089997065, 0.03064622071438602, 0.08642780088952609, 0.07733469203646694, 0.02569173103464501, 0.0595851048294987, 0.04257560933807066, 0.021083036371107613, 0.056826174658324034, 0.04865454350199018, 0.010178908223419316, 0.01822835812345147, 0.013446906747828637, 0.0927824034754719, 0.015624610607379248, 0.046117300899433236, 0.025470503173502426, 0.08419825695455074, 0.0872989245025175, 0.045247398649475405, 0.051134317581142695, 0.015341586865750807, 0.05356306582689285, 0.025139062565618327, 0.009530651981809309, 0.037161995723311386, 0.026168561340974908, 0.046218711350645335, 0.01952305213282151, 0.040376575730208836, 0.043746133135365586, 0.030900932582361356, 0.057376799040607045, 0.10527236719748803, 0.029482750288609947, 0.07157050312629767, 0.03850067746160286, 0.03506356171731438, 0.12225497913147722, 0.1111849042187844, 0.16393354481884412, 0.13726591079362802, 0.15776323234396322, 0.1584109075899635, 0.11991562108908381, 0.16468700367425168, 0.11163095956934349, 0.12042497018618242, 0.10440072111253228, 0.10480138925569397, 0.09178767792348351, 0.13715834942247185, 0.09879024074013744, 0.19683960266411304, 0.1779714844056538, 0.13616965604679926, 0.10751037924949612, 0.11549655321453299, 0.12458219139703683, 0.07799339347652026, 0.1184045100318534, 0.06671271486473934, 0.1501858282302107, 0.13892988221985952, 0.12720060375119957, 0.1289819074528558, 0.06909981463104486, 0.16232804954051971, 0.14145268898989471, 0.09294293129018374, 0.11638452485203743, 0.15603040318403924, 0.08566279336810112, 0.16350851048316273, 0.15835294712867054, 0.09358357012804065, 0.12904511977519306, 0.23997148179582187, 0.1537881027907133, 0.17628688551485538, 0.08878389160547938, 0.13950635200100286, 0.11895482907337801, 0.18139044594551834, 0.16562843030052526, 0.09394439469490733, 0.1200843048947198, 0.07588201641504254, 0.08973960817924567, 0.17655915447643825, 0.1255663793001856, 0.12406434704150472, 0.13840720669499465, 0.15620188255395207, 0.22026861618672097, 0.07784370865140643, 0.1640301410640989, 0.12330631486007146, 0.16795075711395058, 0.1260046043566295, 0.14175694409225667, 0.22355774683611734, 0.13967618931617054, 0.14234452827700547, 0.10978949016758374, 0.14581501776618616, 0.16984851099550724, 0.252657236797469, 0.067196449264884, 0.16606038569339684, 0.08099819081170218, 0.10461082948105675, 0.16889240087143012, 0.1569565763430936, 0.08238329791596957, 0.13887059182993003, 0.11286558117717505, 0.13427021939839634, 0.348532823579652, 0.17171932703682355, 0.14397142454981804, 0.1633024393979992, 0.15629328122096403, 0.17557803355157375, 0.15279239336294786, 0.17322164428021225, 0.1510846699987139, 0.11219219623931817, 0.22423747607639857, 0.13615083348538193, 0.08571487771613256, 0.11572122972990785, 0.2078446942780699, 0.0931075710271086, 0.1763467594449009, 0.1525231370968478, 0.14360246434807777, 0.18418480243001664, 0.0750052881027971, 0.19365882048649447, 0.11193651067359106, 0.11064415930637292, 0.10517302288540772, 0.10886859601097447, 0.1414776455078806, 0.12993176148406096, 0.16862336173653603, 0.139944549916046, 0.09861470373081309, 0.15407573378511838, 0.13038700419877255, 0.16166369590376103, 0.09152121722166028, 0.06916000068719898, 0.1615477478397744, 0.09766153166336672, 0.1846101896039077, 0.11858875943081719, 0.13423830111111912, 0.12543302002762044, 0.15132571277873857, 0.15177748139415467, 0.06597699970006943, 0.2118396099124636, 0.14613745760704788, 0.12822895071336202, 0.18337760360113212, 0.16067357760454926, 0.10621330527854816, 0.08183865142720086, 0.10989905321704489, 0.1814092413655349, 0.0755756985662239, 0.11380335049969809, 0.14935401215084962, 0.08830787893384695, 0.13937778318566935, 0.11861619938697134, 0.1888725430305515, 0.14544402195938996, 0.18271362994398388, 0.11291130086673157, 0.1528530136815139, 0.10319681678499494, 0.09065227849142891, 0.19855654053390026, 0.13263135376785481, 0.14856635513050215, 0.07806394754775933, 0.11328264951173748, 0.13204938785306045, 0.24335680156946182, 0.14789855453584874, 0.21402909313993795, 0.14571460815412657, 0.15117024683526584, 0.13255478787635053, 0.09197934371020113, 0.10003933549991675, 0.22761951174054826, 0.11461235423173223, 0.1504630504974297, 0.13924382680228778, 0.0872016293661935, 0.1567479403955596, 0.12135270397577967, 0.10820090398192406, 0.13656351848372392, 0.24116019372429165, 0.1533772498369217, 0.12619544911597455, 0.10638438431279999, 0.20031218204115117, 0.15976051374205522], [0.00752104414693479, 0.03522467307214226, 0.03399022449074047, 0.05623133014887571, 0.05036423461777823, 0.02517180357660566, 0.04217941952603204, 0.031765525295798264, 0.09856852942279407, 0.03981606848537922, 0.025106847419270446, 0.019576748001522253, 0.06132312478231532, 0.011775029540461088, 0.028769898361393383, 0.043334866275212595, 0.029619532770344188, 0.02673964185773262, 0.05201695254072547, 0.07912279465901, 0.05719306532825742, 0.012364241361085857, 0.053839813119598796, 0.04008069035730191, 0.017819903790950775, 0.027634951851463745, 0.011110346814218377, 0.06628830478127513, 0.04435936255114419, 0.031385878167514286, 0.01763457721764488, 0.04680894860731704, 0.0240539612381586, 0.039196406557623825, 0.03245581593364477, 0.007753941114060581, 0.02110085978970996, 0.02863373334652611, 0.054016893796090565, 0.06482827384024858, 0.09978452524436371, 0.0537126997618803, 0.06169450056872197, 0.0361229346932045, 0.0325666987337172, 0.058871347058032236, 0.07467338948377542, 0.022323983621650507, 0.058852694130369594, 0.01141949585040233, 0.0008517981405020691, 0.05226924203868423, 0.059131979144045284, 0.03579414376456823, 0.024182380775788, 0.009144004068470426, 0.03856083298368113, 0.046764114405959845, 0.01640202514162021, 0.03229795476155622, 0.02677739384983267, 0.0458926617034844, 0.021903980623132417, 0.030821391314800297, 0.07586813358856098, 0.018013006375570382, 0.012412878751222576, 0.031165513742182935, 0.05469116761482187, 0.045027899356292825, 0.009168129381058472, 0.006630370243718582, 0.057881303397672515, 0.03896417794749141, 0.05215533297242863, 0.053115134327007194, 0.05145643172519548, 0.02521621199723865, 0.03643328643270901, 0.016923326633072326, 0.07269691196935517, 0.058133670927158425, 0.028688603080809116, 0.07574525768203394, 0.05013461497479251, 0.020189385395497084, 0.043799635621586015, 0.06773247835891587, 0.009979261168544846, 0.06523841433227062, 0.06113779651267188, 0.012582497238846762, 0.020596094196662307, 0.02226520043664745, 0.020323355349579027, 0.019087763436670815, 0.05956983779157911, 0.022385409700551202, 0.023367444951353327, 0.019776573171839118, 0.029409590642899275, 0.03994322594787393, 0.02631948788517288, 0.03190706430801323, 0.049078207196933885, 0.039339336566627026, 0.08146241733006068, 0.0076520565365042, 0.04233399998130543, 0.07128346245735884, 0.048791851848363876, 0.056949986943176815, 0.023521046619862318, 0.03138096218130418, 0.01535065209359995, 0.05721981317869254, 0.05427580579583134, 0.005320520306538258, 0.06264500599354506, 0.035262935661843846, 0.03019556150372539, 0.04353789073814239, 0.01298998889978975, 0.028661845052348714, 0.08813045559717075, 0.024451335093804767, 0.0031438420950767715, 0.027687358503629054, 0.006557052414531687, 0.037605611740478447, 0.018866618696068014, 0.02622397899228547, 0.010396782425232232, 0.08133336675486394, 0.023217157926410437, 0.0591398501502616, 0.028445419522800615, 0.061639919211821895, 0.024384555373606936, 0.06490232915218387, 0.019024250862587775, 0.060802905554217954, 0.02835750174043434, 0.020296510807903748, 0.04368996061384678, 0.02859527398166912, 0.014162641600705683, 0.021267611466880356, 0.007763798531543995, 0.0657996442168951, 0.03698252660355397, 0.009303424174764326, 0.08119031121688229, 0.05036913364061287, 0.03985155247417944, 0.03151319508573838, 0.05758445789771421, 0.035765177104622126, 0.04680574592202902, 0.033884759792791944, 0.05611569421099765, 0.03272857344044106, 0.009313770985629941, 0.03903057599174125, 0.05553244247234293, 0.03345255334196346, 0.048423366621136665, 0.05486791241647942, 0.024019043826098953, 0.04147884229730282, 0.022665430924722126, 0.01722432137466967, 0.023278813010879924, 0.03430456940882972, 0.06344732615564551, 0.060509493441454, 0.03015380785135286, 0.07053564901330642, 0.042224905121007135, 0.04487763777641313, 0.06011472176760435, 0.024918852507003715, 0.04330048829849277, 0.04499821684190205, 0.017155002237164547, 0.031446603659008227, 0.03130526142194867, 0.032596075907349586, 0.018486103042960167, 0.012496413197368383, 0.019618669591311897, 0.09198536910116673, 0.06149267711277519, 0.02340764306219561, 0.038256574488644085, 0.0379452592294131, 0.05467046890407801, 0.08062769033546958, 0.028704002433057343, 0.01537236012518406, 0.03854786278679967, 0.022654285987040827, 0.04804746500615563, 0.03729967047859516, 0.030233888554253747, 0.004942214557169271, 0.05147839590374913, 0.03920260836769428, 0.04124185037133949, 0.02955038326659373, 0.0316583269408771, 0.047575798351317644, 0.028514463853623186, 0.04760370649663465, 0.020830141280644705, 0.00607049573279385, 0.015603521738999655, 0.026687369216233492, 0.00974880438297987, 0.031078440735914876, 0.08715907843517405, 0.06511064618825912, 0.01469208296787526, 0.009721498437491911, 0.008975896169431508, 0.03441350142072354, 0.010584777337498963, 0.08688115049153566, 0.04140395577996969, 0.0450902126197304, 0.05350145484719958, 0.03257748404783862, 0.03636749567730086, 0.03226497456697481, 0.033714824090046544, 0.020823221919792037, 0.04444075621930616, 0.06678699409323079, 0.0702633529103228, 0.032112260083002706, 0.03445409817088928, 0.035200727571334155, 0.03492562911872353, 0.03545464216066258, 0.03816654985504491, 0.05668314626174314, 0.02958323453952159, 0.020643924130126834, 0.04673473044697728, 0.01200433960184455, 0.03405840368941426, 0.0127127174387819, 0.04825979218419109, 0.006665851688012481, 0.06568681062864405, 0.004985930023914469, 0.06448448050234999, 0.05256201632853065, 0.04420133853065116, 0.08862922633332865, 0.03806576365604997, 0.047935208172670433, 0.10433223657310009, 0.04369865604011076, 0.03329940798825451, 0.03154918797580259, 0.059501041126038344, 0.045815003370600085, 0.03937989939004183, 0.01899034107503082, 0.012753197989825691, 0.06064813171646424, 0.03294172164584909, 0.013264072094378727, 0.028267148017351116, 0.023856824762853127, 0.007093894478332783, 0.03262898485575404, 0.03085649193131498, 0.047001733976815424, 0.023887263843789697, 0.0534773431053119, 0.03867615679545062, 0.038037193939089775, 0.030653080703424554, 0.06428894706602607, 0.042142832917826514, 0.006073393501407866, 0.06044509368283408, 0.010741898906417191, 0.060687554601047716, 0.06885834437395845, 0.08277063284601484, 0.026427561550268104, 0.029986650749508823, 0.05859004679535117, 0.04839922095249806, 0.01661470515786537, 0.02769568412830787, 0.036402898241898844, 0.11134785440351282, 0.029572435654699802, 0.018887263124010394, 0.05067075602710247, 0.029993242717214992, 0.03265491507149168, 0.027564275643921325, 0.021191520549889122, 0.039151942157851796, 0.042834548479212184, 0.04135860589199832, 0.02764064645660775, 0.010611807628135596, 0.03012692090123892, 0.05640315217897296, 0.03906382420765502, 0.04895937196644289, 0.0988679194290723, 0.050039009390664954, 0.03653188096359372, 0.01810882400189127, 0.016032647640843476, 0.00394577146341492, 0.06226636988243886, 0.0450474411648299, 0.04811585794336029, 0.05382311098011477, 0.046717536369604726, 0.061242847304259024, 0.019409801245533993, 0.021297254965507557, 0.021407957953800048, 0.05652472869093929, 0.05049851669796875, 0.031460713794721026, 0.061183624767831395, 0.03238489545349564, 0.04631367911185537, 0.04156007311706032, 0.01763664505311421, 0.03634895470791629, 0.02707800013013184, 0.049494037205087285, 0.040722065405654054, 0.03579537530562707, 0.05795142999184983, 0.06382448984576122, 0.024304120136158805, 0.020534715615212917, 0.020328883713643466, 0.07942731439002923, 0.055986205980713875, 0.139547837632043, 0.12935967503913812, 0.12806500308215618, 0.11205484039549317, 0.1761387748909848, 0.11515823565423489, 0.11668682577354567, 0.10169623659125396, 0.13416655281824724, 0.1338557159262044, 0.09007713185357195, 0.09381770542157547, 0.11370206557746444, 0.18169778159686498, 0.129103989473411, 0.34789605917675154, 0.19119695973183426, 0.08500522508152894, 0.13810285659773008, 0.1547798631446702, 0.1081883782254798, 0.1826933417469263, 0.1921370021466698, 0.13920068554580212, 0.07874358857848815, 0.08362363278865814, 0.1294220866901534, 0.186625601457698, 0.1279650413032089, 0.1140172111668757, 0.11755630054644176, 0.1478191523679665, 0.07693337249968733, 0.1091733667999506, 0.10767244055335011, 0.09098288789391518, 0.14201028192681925, 0.08776170574128628, 0.17393101193010807, 0.12894184674535478, 0.17401053623429366, 0.1332511683659894, 0.20497901019241127, 0.13327540563685553, 0.19670100510120392, 0.19685466614152702, 0.12128042642559324, 0.10596045598919902, 0.11456409682120595, 0.11770860451672759, 0.10937497991004161, 0.1423304554607187, 0.2560550144740513, 0.1087851429890309, 0.22904223682624952, 0.07974503841251135, 0.1488717230302947, 0.14574865704136236, 0.13475767895579338, 0.20921491432402814, 0.17446081207266875, 0.13431420203830513, 0.2835195064544678, 0.09753993140267474, 0.08123921323567629, 0.1347804098789181, 0.1463200513805662, 0.1051532503749643, 0.14661256782710552, 0.13842839055827685, 0.11932545847126416, 0.1612666579229491, 0.08326355461031199, 0.17302268424204417, 0.11527387159211294, 0.12336601237101213, 0.1722444724291563, 0.058236265421978066, 0.14942991307803563, 0.15498760342597961, 0.28672422734754427, 0.12691898457705975, 0.15130870869117125, 0.22914941821779522, 0.1821588868541377, 0.1665342202676194, 0.16310239370380128, 0.1911938384707485, 0.14280192873307637, 0.17681861269686902, 0.19671551217990263, 0.1564680989831686, 0.1295083827738251, 0.07505957090428897, 0.10970005925212588, 0.13228941283055715, 0.11901965630905968, 0.08409804411764656, 0.19072993764919893, 0.09438981900789908, 0.1287873171802078, 0.22078878113201686, 0.08056757891816752, 0.13000406617564814, 0.1377250211579459, 0.18016383105090686, 0.21883865791772092, 0.08159701832170997, 0.10079109123242752, 0.1127169548666903, 0.12680911618684018, 0.11027144002062933, 0.09827079504196133, 0.11303822762731995, 0.13953869097999164, 0.23305175453424454, 0.17716908960470132, 0.09990674297192267, 0.14602285304239818, 0.11944996964718614, 0.1502301637083292, 0.1230155626045806, 0.13848396257630416, 0.09128385888678686, 0.2205223882836955, 0.08345695066132716, 0.09419256887797799, 0.12327997413064752, 0.1042706798762083, 0.1661724661077772, 0.0686417424253055, 0.08310623626623835, 0.1131604453548789, 0.12069665560764925, 0.11813802218862943, 0.10226666062538113, 0.1393771589334522, 0.15063526268516267, 0.15592037194541522, 0.13112895510026387, 0.1517824482704912, 0.16768496137644562, 0.1336376347712108, 0.08937398636979715, 0.12128619397325174, 0.1526567813541208, 0.052260926592030695, 0.1146768829120057, 0.08515630768878119, 0.19431196472474507, 0.09747754010771002, 0.1334290531064783, 0.12158689355211598, 0.15512062343103544, 0.1571586983544486, 0.08738330033208642, 0.19250213541090488, 0.14612593608243124, 0.07314926412488733, 0.08627630437591247, 0.16831359692982265, 0.22243137870516094, 0.1422992699912616, 0.11498824906136308, 0.21312734724155494, 0.11017379204609565, 0.10750379067446504, 0.11215140949934721, 0.07745833468756505, 0.13373109618467943, 0.09826208265232188, 0.09503535008324043, 0.09588936104306153, 0.09675297327339649, 0.19860654856477464, 0.11637575817959649], [0.032477128718580515, 0.05352650975276317, 0.02364112187309989, 0.025736570325014845, 0.025371976496119584, 0.012586932313362402, 0.05904743368072169, 0.009126366398829435, 0.007310917118697294, 0.004817280569113791, 0.020727339832644378, 0.021180507926536456, 0.041967713207538636, 0.04327505002064364, 0.03532517428642937, 0.01228303853089788, 0.02937562657254083, 0.056733876932412386, 0.03787944472527929, 0.05322198323639376, 0.05770514213613101, 0.01550231484829315, 0.03921124951115676, 0.008471927006861993, 0.029082010899271284, 0.006822845183445939, 0.0068115234025754035, 0.01656775901626263, 0.021213725608374392, 0.05280647553237421, 0.03546078968793154, 0.024909561666260873, 0.02303743944503367, 0.03392919705116323, 0.0436943168086665, 0.02077727152832917, 0.026592618586229425, 0.045392211593155346, 0.08837105054408312, 0.042162629176995585, 0.03580549904810531, 0.06565508233117205, 0.023152047402358482, 0.01522393398252981, 0.05627279542386532, 0.0164026324304619, 0.008431070717051625, 0.06721028459391423, 0.023302875558978746, 0.04302008030936122, 0.08733724816037075, 0.05120141790913684, 0.027545542988393987, 0.05054775119892188, 0.025865254491301518, 0.04340276048917856, 0.04667126367400799, 0.05633889152003186, 0.021351943191673075, 0.06668650305696897, 0.018038638035899827, 0.03592055144586733, 0.0733586261048913, 0.031010892574808428, 0.014061399935079473, 0.005582591734959611, 0.05054492510056921, 0.06454947058643613, 0.03901690011844039, 0.021085555432364345, 0.022296194219961762, 0.04685526540768998, 0.03954881389758416, 0.06530767918697425, 0.0074131689533325175, 0.025967567394088422, 0.12013990405414786, 0.011434214123125588, 0.03646854989762817, 0.0584074394511325, 0.00985548535494932, 0.022757272335833738, 0.020954915388886417, 0.017285847537485615, 0.03758717594402177, 0.03851648732753737, 0.06932232661971025, 0.029259939744536365, 0.027024582460788742, 0.04937873714204345, 0.015226909358586584, 0.020166729111224413, 0.052829169136072905, 0.016021575645676682, 0.005189176282978484, 0.04806898135159697, 0.03365257528743573, 0.029278830159455538, 0.08200864480542285, 0.031195806938090494, 0.024218857122052993, 0.029088083787688186, 0.039604216281856806, 0.026314141029225926, 0.009547883378607886, 0.057574476647589884, 0.04296177040253367, 0.004665769212546625, 0.042250258581978936, 0.056251068732568195, 0.07687865543578352, 0.01367342209310404, 0.037100652764950476, 0.06724239965634686, 0.015371693464528238, 0.1026038382468479, 0.03155210228370769, 0.05801747180521488, 0.012166607858879226, 0.06142373795488051, 0.04461559773023639, 0.06357568462512322, 0.041845651543033976, 0.088675339573196, 0.04697031441277691, 0.008849912572519054, 0.03302110006500568, 0.04897090706175991, 0.033376849189932854, 0.009210620092095008, 0.08661858458071947, 0.03375013165974191, 0.014809952982302223, 0.033609522240502496, 0.02491874054872564, 0.08776403311640024, 0.007441273025636162, 0.015845913107373884, 0.03244791439335261, 0.03380705735513142, 0.011970187238018428, 0.017057013298783983, 0.018426739710516164, 0.043147152954978604, 0.020433104996170317, 0.0638754138989108, 0.0507865582060601, 0.028532679126198803, 0.018145620955952575, 0.031334228081894774, 0.04879412154800125, 0.012305452238901384, 0.03687810684953417, 0.03822127031162381, 0.037465433190975866, 0.03718104220128485, 0.05894659659160035, 0.03894040208043797, 0.07016654631921224, 0.015111734824521201, 0.025150997996596352, 0.009386610023544302, 0.056810184980609586, 0.01951656024903059, 0.03651721103649054, 0.02496878250635096, 0.023590584584910954, 0.041565443721732924, 0.06729424651712179, 0.038441746695233245, 0.05075863649004272, 0.06738607944654566, 0.0572439825960568, 0.07255962397903204, 0.10871944722852536, 0.07693500776908227, 0.010215680580586195, 0.03702407330274582, 0.0511510332913271, 0.06813562315489564, 0.030335957184433937, 0.03414164636550205, 0.025136830185406973, 0.045532349430556805, 0.040360467308866124, 0.050900657262120924, 0.05330977548978158, 0.004729818253378783, 0.040858393268925805, 0.07843113677310092, 0.06856153958610126, 0.03082773561722466, 0.06759598425456456, 0.015519838015149747, 0.06102860665747097, 0.023047325700255375, 0.04164853372744151, 0.04488200754193323, 0.055179896032703776, 0.02687410035702799, 0.011541226729085403, 0.012473358273772257, 0.0599948110591088, 0.02609534401978765, 0.020192099535571675, 0.03763506355296288, 0.05945321119257382, 0.016519593207963874, 0.03115190572238394, 0.02911012599776898, 0.03283388546801039, 0.028051524855462567, 0.05215939400451524, 0.01791705982759595, 0.05288749261360083, 0.07608958027724709, 0.03699879448062607, 0.03114913051415767, 0.03426448155992797, 0.011691933597571083, 0.08902586397847959, 0.03263982445267694, 0.049178945898477516, 0.03519166234348502, 0.0036731157368714257, 0.012871157061973853, 0.03223406390420028, 0.03883759045441236, 0.022236315200903585, 0.021258982197780694, 0.009114068799785205, 0.031759540616933785, 0.05880011445177453, 0.024043316720053554, 0.02513947307930461, 0.07496106797563178, 0.04133286905874099, 0.05020412749477795, 0.035306351725012064, 0.03775631436812026, 0.02058012317866087, 0.052682205236383846, 0.03144274618742721, 0.04846037392105375, 0.027775011657338058, 0.01662476613585438, 0.06661761818187577, 0.05558621297989573, 0.016034522093832493, 0.019530041043513587, 0.006619327086290079, 0.01815154287032783, 0.045657389863793335, 0.026374513682510172, 0.023150147504306266, 0.03783930598625115, 0.009009673642659826, 0.030674787038671117, 0.031488635510738404, 0.08699548364217792, 0.023453791925151433, 0.03411873223792229, 0.03357199925397124, 0.013062892398530883, 0.04076317784243396, 0.05862239934504032, 0.00916827526608748, 0.015548847083534514, 0.09892563561775855, 0.014510656274589044, 0.05972231139561959, 0.0019355762716648833, 0.05926466666694198, 0.015283758718786495, 0.0831205126430307, 0.009911917416112763, 0.04108423686453274, 0.028794502041169574, 0.03812115925497242, 0.049464816094509194, 0.023208347149193287, 0.05139001671757017, 0.1251389022384371, 0.03239184704476169, 0.024486328841054013, 0.06855171439903122, 0.05334423489070364, 0.07443845351891858, 0.035800267543111525, 0.034307761916092465, 0.037673275252538066, 0.014260617816554648, 0.03774646543232458, 0.047882733667003255, 0.04390753286757639, 0.03398057572277529, 0.04938383972538369, 0.014236402598076632, 0.014641603355162909, 0.06092534041298287, 0.03762088556374822, 0.06325300729700498, 0.049236509416784556, 0.04908575589901634, 0.04697441276428955, 0.017727280368230174, 0.010741575754114559, 0.01613511999935976, 0.018803815191079463, 0.06878350196140152, 0.03752005865265216, 0.03998276079073548, 0.013166983911235417, 0.06454180314072541, 0.06142086096640144, 0.0612070681527257, 0.04383092965664608, 0.04785496462136507, 0.041281442889677625, 0.006754361492182527, 0.01901847992225417, 0.04989853907110436, 0.06276547988610608, 0.04647600843704172, 0.014432560286617704, 0.050281273533723185, 0.021550808234938552, 0.013926222188664334, 0.049881772470793555, 0.032281205124620876, 0.009062681646485413, 0.0513218748383224, 0.034198131013129435, 0.01130415846793247, 0.05035226186737418, 0.060209146700799465, 0.031612295125211985, 0.0390311527465071, 0.053906367226902924, 0.04854149956788335, 0.053201074179794104, 0.013630205349597548, 0.046171288538191996, 0.027130774887544767, 0.04329853072496397, 0.020181999541819096, 0.015959365858829448, 0.0243135110608169, 0.028607209412647144, 0.02975289543558444, 0.07938521807747227, 0.0447748363284128, 0.12599549841667923, 0.16136934741267137, 0.14514719003013202, 0.12120639825505869, 0.11333119190697159, 0.1765922127025468, 0.20456219970115594, 0.12610945158771106, 0.12204831093549728, 0.0657571747100779, 0.16130564654512064, 0.11898442677089147, 0.12246516213885375, 0.2461591511964798, 0.1173157598823309, 0.13517097463565214, 0.149971709719726, 0.16667330637574196, 0.18094154074788094, 0.11918249114283494, 0.14961503100182327, 0.14457236230373383, 0.13902893476188183, 0.1041038077590721, 0.19413421569125994, 0.11332947521337441, 0.13258262138281549, 0.12075241761548178, 0.11758990160056523, 0.16520536371639796, 0.0997321694823248, 0.12585812221680368, 0.10449459643236228, 0.11851994240922586, 0.1527348943054676, 0.08864764855908495, 0.11147819419524499, 0.15557231062224933, 0.16130825211959227, 0.12490191709782396, 0.12328264755862099, 0.12478655257395335, 0.15172041659908636, 0.08315990838621344, 0.2578313377286707, 0.08633815962821245, 0.08268549027187483, 0.14440994816167013, 0.08377369759338242, 0.09411088683243309, 0.1519096600157874, 0.1428035707878215, 0.1317731019641672, 0.11401609836944512, 0.15219459044081823, 0.1543171972568546, 0.09716286270746163, 0.09912028017320804, 0.0829418950847217, 0.1645180620253086, 0.15681662171014718, 0.18203014161969933, 0.1967387180775404, 0.13668558693357877, 0.1117458219773003, 0.09099896238850695, 0.13680485981915677, 0.1613191629626921, 0.11432442468191896, 0.1441683896950313, 0.17154054663011006, 0.1583644686532872, 0.10555756903652634, 0.13578735584659235, 0.1189300896865981, 0.12164885737001896, 0.26982259856803076, 0.1308410255504506, 0.17287077382206917, 0.10901022662541696, 0.1019558644454394, 0.09358490684202739, 0.16973987753902162, 0.16870631942791597, 0.1380816591637475, 0.09976066116775785, 0.10841930404837642, 0.05817825746323381, 0.11907159137938704, 0.15068506715553148, 0.08869712054729462, 0.15849252178200654, 0.27372569484370096, 0.09620059148541518, 0.11938580737582274, 0.15366155600973538, 0.13344027607568673, 0.11951909879488604, 0.17674757008041653, 0.10864559547709567, 0.05312945480857577, 0.1055918282696179, 0.1357508370918887, 0.2621446762766157, 0.10977646908057587, 0.1658021488359996, 0.30596726334520746, 0.159343526831695, 0.14066026865371636, 0.12002604587801866, 0.19177625221865519, 0.14377531435872826, 0.110497928224504, 0.13567732460796833, 0.13168179829205784, 0.21787083627922194, 0.1242732001202447, 0.20883357764354774, 0.26098107014383587, 0.13157064068530286, 0.13669296939458164, 0.16341443838817732, 0.11205367331526109, 0.19601614613618168, 0.19155545692358697, 0.11207343904035431, 0.1512177578572716, 0.09393355170530931, 0.23026631399989128, 0.11161135669265475, 0.15606412637446607, 0.052148873319051096, 0.11618237569928169, 0.1891221489225115, 0.1733720347817455, 0.24690855241247586, 0.09184015582182578, 0.21929109149745532, 0.1253245087074382, 0.0932352848883186, 0.10285047894077641, 0.19662970464144433, 0.12725559222911084, 0.10865594992148024, 0.07503314196531262, 0.11485814675688744, 0.2722366361745766, 0.15396393835544586, 0.1925875629697527, 0.1341544341828142, 0.12142574148518698, 0.06489264645746776, 0.10581239964812994, 0.1830188485660723, 0.13107729144394398, 0.07401654722967319, 0.17224559879728726, 0.1394473873078823, 0.14012684513415608, 0.11296926132802453, 0.20895534753799438, 0.06690836365201644, 0.14392480919403688, 0.1901946413729872, 0.13397910073399544, 0.08704642126602785, 0.10522427263536624, 0.08012230388287987, 0.1500040351280144, 0.08897358285529272, 0.1308292326118265, 0.15842814237943717, 0.12857678133462155, 0.21154508500226907, 0.18440079369715281, 0.12303353021187441], [0.040002126180167706, 0.08198845838861805, 0.049580899865499566, 0.05544398186196174, 0.05105341585086925, 0.03761349292472005, 0.034945540728845766, 0.07729345067803349, 0.019400398446513072, 0.031745851172932556, 0.07371166108974389, 0.025875535993171588, 0.05258707801944443, 0.040202090450163395, 0.10084453265049628, 0.04839402337425521, 0.033328907298190255, 0.02302483226438718, 0.03864061513117381, 0.04124952120972531, 0.08126536397529499, 0.03014076640829444, 0.03326479930962835, 0.023505986535123417, 0.05303378137094634, 0.014780295912974646, 0.02919408113562635, 0.05590341453041349, 0.03448074763374669, 0.04493798668097172, 0.028488180799675838, 0.02597560973039695, 0.027982331246935895, 0.016399909808699573, 0.009266368529227163, 0.044075667059847286, 0.024867709626310637, 0.10185225214809179, 0.018157006773565496, 0.03776820569432207, 0.04785950741331492, 0.05280715746006795, 0.0026638614778806058, 0.07075704141919102, 0.017644383745001893, 0.09932598484946148, 0.04778189318520682, 0.13062545497502598, 0.024856405232899954, 0.04856489206265126, 0.13413052260875702, 0.027244219157312597, 0.0742475205500211, 0.03760071271764381, 0.06715466507843562, 0.05980678900544133, 0.004496956909341472, 0.010280577366107276, 0.01266223019255059, 0.036089679691940546, 0.06500240628208433, 0.047379759406404834, 0.03461891093424388, 0.02301670511120132, 0.030810785812458823, 0.0483966425194272, 0.03364040915455137, 0.09753293570663248, 0.010192506913361805, 0.017838673765904138, 0.024848306917452385, 0.023062623272250806, 0.01690851421361523, 0.036930174234190156, 0.04337474377825856, 0.04192961346624153, 0.028684854174831083, 0.02110255103824394, 0.09839128929057292, 0.03927085541986993, 0.02960309186684234, 0.039313199397708685, 0.050678939159427366, 0.06260142368929726, 0.033309094075645716, 0.050985708234033415, 0.07065618397401911, 0.047662192822567055, 0.04371101216280034, 0.015605129866993852, 0.04853827991921987, 0.06416589474039418, 0.014070175089208143, 0.10011826947863613, 0.05096539289557508, 0.009864224885989512, 0.04060311482420989, 0.026365726654018675, 0.00906068251268672, 0.018439604734469737, 0.030984952181045498, 0.04832973557391337, 0.03127972814919693, 0.03340852998995355, 0.02979218939851437, 0.01677068678795227, 0.054476601271224875, 0.0857389589239444, 0.04275091564548867, 0.04152927101988878, 0.02788797755991774, 0.025568836468404958, 0.017459074135071466, 0.06560991904033081, 0.02163390163332224, 0.07931891842080013, 0.0530518236170922, 0.03208421283800687, 0.025695099961012602, 0.038681018498859236, 0.040871427926634035, 0.05741599800863436, 0.028596254464771067, 0.016411984339356422, 0.05743218785417931, 0.09611269405909947, 0.012886950812701668, 0.05155720096081495, 0.038771107593285184, 0.01730277868253844, 0.03764408128336072, 0.06097577592091901, 0.038240730695958645, 0.039504417351314, 0.059929651341267993, 0.030067111432020153, 0.02461267206152635, 0.003140016853909141, 0.023619535977819135, 0.03090903429048402, 0.043599671351590326, 0.059102761426142285, 0.024925330820094262, 0.07591979724488088, 0.038676299287804534, 0.018555408609764915, 0.04154900960358126, 0.023056633504373685, 0.04605018360806363, 0.03736684883811644, 0.05170332686975598, 0.03962667918364916, 0.030173539649695158, 0.02452832506969571, 0.028572112188807557, 0.03023428888991475, 0.01952082653796034, 0.023276894453114698, 0.10086759605578013, 0.03959579226960029, 0.04158994222858122, 0.033329802964414866, 0.033003017106758695, 0.005613297140890998, 0.031108438769089322, 0.027689319469832947, 0.028772666784269468, 0.028890843835792372, 0.035364810909543715, 0.054454148547457795, 0.010378100659831293, 0.02884468649114881, 0.044434364419430494, 0.04260829097724386, 0.01762601749838463, 0.07577177483056273, 0.061477593279310634, 0.03933766397780605, 0.038386856604899676, 0.10751993302255869, 0.037771001258598905, 0.038247186956661086, 0.009635717192265605, 0.030546486244669983, 0.011281033146328159, 0.08199497232479708, 0.0336298511496612, 0.08089965395629406, 0.01162832009140402, 0.011001939818795239, 0.017825462689091052, 0.03058534933786307, 0.05180885263585618, 0.02656044245564512, 0.04439149796962738, 0.05098051065579057, 0.04619456228933164, 0.022547815360927155, 0.016687454289889762, 0.013647013510178243, 0.04061882969524179, 0.04450991250840681, 0.05036622951073306, 0.0453750684059092, 0.04963223443233541, 0.013107048064869429, 0.04319536626072867, 0.03098072830055441, 0.03147207586360829, 0.030550129977720122, 0.03026335733011365, 0.07915868237614632, 0.02736302385372775, 0.01907746327508773, 0.034923858142324855, 0.05266193061002663, 0.050084094649979045, 0.06208762340247631, 0.042208223337573667, 0.01885662048256823, 0.012318266372728561, 0.03076682352860059, 0.027322637449417795, 0.05035897597138371, 0.015494844177737832, 0.011736072300534164, 0.0586591080895492, 0.03062300124604787, 0.0727721004347716, 0.013561646171313311, 0.058876490353473594, 0.028923440658088242, 0.03402306219296796, 0.03533964404570205, 0.0390542432931917, 0.039535053207405975, 0.021367758146620223, 0.047695583530834744, 0.022052087854327898, 0.05044181152646031, 0.01226682832930237, 0.018200563632750084, 0.02088018154193248, 0.06503526094768729, 0.10982899447636944, 0.032937507943383286, 0.03666767278420074, 0.016256270730601888, 0.046032999708716354, 0.07336634104805333, 0.03499974889148559, 0.04554010508581996, 0.021264262896563326, 0.026872171621237482, 0.03962474535884602, 0.09141639034662928, 0.026200198036219393, 0.03620735462754965, 0.04250623591776405, 0.03631839009800127, 0.05283500114455819, 0.060272637222494395, 0.022489505454099605, 0.09331635625234672, 0.05651219954181995, 0.04090444544064147, 0.02034449341174747, 0.03609104694000312, 0.031604756601154804, 0.056270919274538755, 0.050733038756464205, 0.04485246412722128, 0.021068083155634146, 0.027383617391543727, 0.014109463963125433, 0.020224628504365683, 0.02773047940406416, 0.0259259087366185, 0.027811520234016434, 0.03934671902762992, 0.04224573275340455, 0.015358226240745612, 0.02621381962671876, 0.047094771305897405, 0.027340852721993412, 0.014875853999650903, 0.05729803469564233, 0.0981461006615843, 0.03563398575144155, 0.009815247380174696, 0.022785548586398363, 0.03470870486593672, 0.009927684025439833, 0.03272799329300012, 0.046621286177209446, 0.03540629314790879, 0.03672709548845887, 0.029924337486071245, 0.02460087912290224, 0.08002506981470756, 0.010944557808605688, 0.03644811920821667, 0.06711079100412981, 0.05490533023008278, 0.017130856568525945, 0.032808701640793254, 0.07688467404139893, 0.043476836157164404, 0.033106710828308544, 0.007043364823662809, 0.12038186964179788, 0.06537754115249429, 0.019018081282930713, 0.005615334018200103, 0.02491102390922606, 0.058561324408011775, 0.019552291903112615, 0.048653803898819854, 0.010527358007883387, 0.028553937628333057, 0.025725730728091936, 0.03434359535042729, 0.060464146946157725, 0.003416039386398292, 0.03562992811203003, 0.0461442794517747, 0.010958453357618834, 0.0336630857948746, 0.04027870723179408, 0.06815845585827317, 0.03392526154805507, 0.04542206713397588, 0.04527562909892627, 0.03116165966327701, 0.007415510747315628, 0.012835343983689589, 0.016912904335185885, 0.017704788628699522, 0.05348057971735086, 0.033787033786731105, 0.038704492417829375, 0.017849070618727376, 0.01349689781532756, 0.043769067618995905, 0.021528404704960327, 0.023801921101819192, 0.030007067868219953, 0.05310558394661971, 0.03177436999976635, 0.020898194950340048, 0.08105864149651357, 0.09735102725348302, 0.1014034826574581, 0.18422102262931211, 0.09178292139300279, 0.1610428635030985, 0.10027902799525432, 0.14948738499411515, 0.1624340774225337, 0.17920986509748868, 0.12518490691270145, 0.15113992989063263, 0.1358730819608484, 0.10060273669660091, 0.14463891301836285, 0.1019731399470142, 0.20419360590832575, 0.08442505049918379, 0.10133279966456549, 0.14376491920224257, 0.11020630065883909, 0.16944837889501027, 0.14849817593182835, 0.11762918877814497, 0.14182714532528604, 0.1036895282034363, 0.14346797870738165, 0.22944922213043484, 0.07726468757859298, 0.1850517259112426, 0.16243430812444004, 0.1750217162604843, 0.13099685790283339, 0.1408709944891078, 0.09347934714917626, 0.11248841748705932, 0.12706795015505382, 0.15293860408876622, 0.15020387726170675, 0.19751733701143945, 0.10478724180055515, 0.15701122555349553, 0.13574660303337233, 0.13268213532865047, 0.14570428085114273, 0.1639979649335146, 0.0882546410762838, 0.1576970208968435, 0.18044367246329784, 0.2100899259426764, 0.11399935212518487, 0.12316295398133141, 0.19230260540332111, 0.0922256519219705, 0.16384076194039413, 0.12843137128012522, 0.15512307972780295, 0.13134407784257615, 0.15149398946336337, 0.11712089819567544, 0.11453382058867387, 0.11772991051631314, 0.1675050003187997, 0.10890997307641165, 0.1087748563981482, 0.08244675451091357, 0.06349083382104125, 0.06768017009432827, 0.12485517960573946, 0.1250475849956274, 0.24170389026403427, 0.09454033843108586, 0.11486437570835863, 0.1900319286755153, 0.18793927239520208, 0.12722576382969106, 0.15657841520650045, 0.16880777398390429, 0.11351111903786659, 0.11770290482257094, 0.20633324395333016, 0.12874944135546684, 0.0773618198665125, 0.16978936988328183, 0.15392790814595564, 0.2294462365763528, 0.21431756551776612, 0.0982145784156663, 0.10108345840126276, 0.19497812326465333, 0.13709524566573755, 0.11068569922021457, 0.11910471745899745, 0.19177680861737045, 0.14417828273560318, 0.21808551118842193, 0.10058476230395691, 0.10665900779089757, 0.11615560070744582, 0.15085042613957608, 0.11167245198573385, 0.1310511135629245, 0.09760000210787569, 0.09070591668465308, 0.1256748634789671, 0.13395655980067595, 0.1245163870709283, 0.06362406417195286, 0.15962738517139638, 0.22130057295518263, 0.16090681723185948, 0.09126021872673716, 0.12409671316189425, 0.12455002883715288, 0.14641197930489266, 0.14872378882552895, 0.08569465737257685, 0.14351706393063068, 0.15808671712875366, 0.08470379947019474, 0.17961808533540793, 0.12188341335526534, 0.10071637095617396, 0.12469262975667204, 0.10950777599854128, 0.17061887894357952, 0.10583949355142457, 0.12247599155775138, 0.1611480907137905, 0.13737894115703447, 0.11237692061279501, 0.22635511601609842, 0.1396201287529298, 0.1231754661670753, 0.0781500061441745, 0.13578804795231136, 0.14915338291653565, 0.13398294124220098, 0.08779009564646653, 0.10747341266168015, 0.1463392674922943, 0.12985173506396158, 0.1352842085595642, 0.14489670204264776, 0.09241989614175898, 0.12128683179616928, 0.15429095152233327, 0.07169177090483052, 0.11862134268241269, 0.08320543808596474, 0.16381945594080857, 0.0827191456087998, 0.12824493699840137, 0.10973494273743459, 0.22110264429024287, 0.1088442298184548, 0.12354674695857934, 0.12936255202761718, 0.15294688221599373, 0.15239333334778035, 0.13069735254560197, 0.1441497164113181, 0.10839942297233002, 0.08975961817694561, 0.0965309226885438, 0.08157621443803821, 0.10458979489547865, 0.08804789145610162, 0.21381155481295927, 0.21309894376567431, 0.11508343395377908, 0.19286903286618845, 0.09182832217110054, 0.1253651258136545, 0.13818395510315895, 0.06363922942961965, 0.15971317913915428, 0.30567296913691927], [0.03336922245632325, 0.018378572205879858, 0.03820714660521064, 0.033565200333084376, 0.04703368619084358, 0.04465687980077096, 0.03994805711720671, 0.03863239807209798, 0.01823742504763816, 0.02841540622258825, 0.03684919107971447, 0.045367930217513015, 0.016079537803307176, 0.06335081133459296, 0.007350362055668873, 0.03037341571013842, 0.10372811648994684, 0.0343626180796751, 0.03235726550753627, 0.02390759444928595, 0.015418773616797157, 0.10457403931234564, 0.05315168022311159, 0.015594480259876167, 0.03767358059329646, 0.012639993751820709, 0.025569581160587922, 0.04226102354004979, 0.013474138902633317, 0.05459547382114189, 0.06515494773962668, 0.0186735195041235, 0.008361164646755372, 0.05858769906418664, 0.056846629096461196, 0.04022817672895534, 0.022600886977410743, 0.010165636078454554, 0.007063594921159425, 0.03966384933197072, 0.031099594065121243, 0.039556081007633886, 0.0028924399936970857, 0.05139309726655483, 0.012609609801854407, 0.038838625220315795, 0.03151187872780221, 0.08485635449843747, 0.09101855169449534, 0.06552840662854058, 0.0303549018821546, 0.022753241837822964, 0.037448466422834566, 0.023435654684102962, 0.021054261397304277, 0.051643317232706716, 0.03127028972708753, 0.010859786732388394, 0.04765686971534576, 0.008972636656835675, 0.05873713283134358, 0.058902593595641, 0.043906213116965125, 0.025717810528086762, 0.03546620100470526, 0.0484955898885216, 0.11535655786948544, 0.019476268839623247, 0.05378653794260962, 0.035551197693816254, 0.02639556523146374, 0.0399802909232676, 0.03731663046138627, 0.04017469459878547, 0.04710806380691273, 0.09007204284093209, 0.04410223509850247, 0.04446649644523859, 0.03948410540553076, 0.07941018138080835, 0.047563079212393077, 0.059141146152147224, 0.10142134848449912, 0.051026355874325545, 0.019627453227128302, 0.03692886805427926, 0.01311380457731762, 0.01689721321287964, 0.033927266619035175, 0.008755266267274107, 0.013765701159302677, 0.03350353167791452, 0.028538500956658806, 0.008606613663557385, 0.04589345898213131, 0.049444928233112605, 0.010532359659139599, 0.03977195353114179, 0.019215979413794618, 0.07064753265253135, 0.046900153891848664, 0.037967074130262644, 0.028917194743241583, 0.06224097910204104, 0.05091613803857139, 0.028738254880798713, 0.04717520823968308, 0.0250161798737411, 0.026164736099807278, 0.034094064097319327, 0.015991947414087396, 0.09023376487727676, 0.037656135457967005, 0.03193968827170985, 0.04899880163637655, 0.07005613510097776, 0.07263137905725411, 0.06016381377620356, 0.03528947995177337, 0.06874008250555821, 0.026814362133986185, 0.028669712665889944, 0.0816274234758956, 0.011499326343515089, 0.018620290128248076, 0.0634496874575104, 0.0471752014543329, 0.07254966987030846, 0.031050865072757006, 0.012361015775240958, 0.020812860690057278, 0.03066222396280084, 0.03657613501750997, 0.06147738971880504, 0.07342335834567036, 0.05711050797253847, 0.04338928817638329, 0.012584280937777033, 0.02963390074936407, 0.03598741089392986, 0.04129717472408499, 0.03580475265958479, 0.012652533927134104, 0.04890959124479975, 0.009991679207554885, 0.020405071321874857, 0.02579828308496092, 0.031206646535013403, 0.02579730429819652, 0.07206682435103826, 0.03192188351282051, 0.04350175196304917, 0.012497593848300832, 0.04406242884163346, 0.024178645440510342, 0.03785599455503481, 0.030621321871876717, 0.07583177089691162, 0.020542040400739228, 0.021870632323303392, 0.020309138344600797, 0.08347489112722022, 0.03279499862609165, 0.055586745629885366, 0.04607738268428615, 0.030743722803890705, 0.06966025741504771, 0.05411928133772952, 0.045067169570497105, 0.0437779055376138, 0.019427470297419598, 0.03402046340384653, 0.02749600653935756, 0.028195694887212346, 0.0354085458841707, 0.010493589016342801, 0.03531012437971575, 0.0431495617542948, 0.008665109319346291, 0.01159151126297989, 0.05308427794703415, 0.05357061452897532, 0.04313587909564376, 0.05402955186686345, 0.011722444772853382, 0.07572159716593367, 0.017900215195758, 0.029135520170841898, 0.03645060943173511, 0.03143570299393364, 0.038402666470834186, 0.04335492716303893, 0.09327796474099159, 0.004482040589209646, 0.02335994374672217, 0.04493837005325726, 0.04913711082190275, 0.03398740517773798, 0.04516589302303536, 0.011719409176813704, 0.019445561737354313, 0.025784127148134366, 0.03280318175841655, 0.025545985105314424, 0.0223372421959149, 0.03171673523528235, 0.014731526208509291, 0.021011657879820893, 0.042157031263091733, 0.05999462106930358, 0.018005366071260402, 0.039692758316440244, 0.03399379358493856, 0.041699990430580716, 0.015542065126023121, 0.01675278364148523, 0.023837654452238764, 0.09321942752493279, 0.013108236349320837, 0.046123295756323, 0.018743771627279263, 0.049975644397948465, 0.0405079265391188, 0.04461634072608181, 0.10283499477165085, 0.015044251124241521, 0.03280990943312645, 0.07280321126537663, 0.025329065941540257, 0.05437958433425852, 0.028508509708834544, 0.029714805872312615, 0.035276509754891903, 0.03145087164427553, 0.022061456726597886, 0.023804904959563698, 0.03125570461686168, 0.018558473891711662, 0.034793053554104905, 0.0394960815486099, 0.020955844981861965, 0.020234767513881837, 0.06930406724235841, 0.008977680716530552, 0.050294253908629925, 0.033045469650200436, 0.06525699262108121, 0.025879524082743695, 0.05592482570292694, 0.0983613251841494, 0.027101960897977864, 0.07228006755134889, 0.014215035530339395, 0.07005890352385384, 0.016058275908497826, 0.034653288910963705, 0.030790758851383413, 0.049900160769798925, 0.10561582805322749, 0.02634809661789664, 0.011343901960312255, 0.053063236576105864, 0.06756381490933043, 0.03960282528506858, 0.04155102145991155, 0.03978147677012852, 0.05318421258458069, 0.007995150983333588, 0.015131147711404731, 0.059612768702208996, 0.0262613408267498, 0.05985225085169077, 0.009367739116506917, 0.018837489187717438, 0.025183092702978423, 0.0356534868478775, 0.03447518703926887, 0.04642946093476244, 0.10219521767326764, 0.0617050314322114, 0.037116669584065676, 0.037650510402662415, 0.02960151427292398, 0.04558254745123642, 0.018035260627844503, 0.032595811278692315, 0.024705936699839573, 0.0253374797757715, 0.049256902786770036, 0.016857037154425467, 0.03901646585602846, 0.09111052033092294, 0.027289453694330792, 0.015640768222510815, 0.01349145341997168, 0.03751034203118511, 0.05346737203321286, 0.03883883556617158, 0.05571793019771576, 0.01243593282664993, 0.043771011621824334, 0.0956569356577737, 0.030510815658739636, 0.07645857440573828, 0.03570044825651816, 0.07927144132554531, 0.029018042010388205, 0.05198911564158542, 0.025818252370559742, 0.05409443338534661, 0.10407028134380068, 0.026014781557023525, 0.009225592815450259, 0.028097124105053287, 0.023874451406300068, 0.014951305397387062, 0.039780068809964826, 0.039191653419818194, 0.025213368935510516, 0.012200498138554394, 0.013291917475206512, 0.03764853247308305, 0.02372359610827906, 0.030391061013298373, 0.0284717331108238, 0.07994514517486095, 0.03245552755626185, 0.055722408528838835, 0.032328668649175336, 0.04142790128077779, 0.04530074167996645, 0.030343353216137205, 0.045136780478060246, 0.002890986020377438, 0.017295190964692404, 0.026142921198957732, 0.05150835322482245, 0.044214810843446424, 0.032034784954573424, 0.07002727700663464, 0.06094628678900855, 0.05540419935381838, 0.045093001398657045, 0.07629753090441227, 0.02967694022559694, 0.05212580991376724, 0.008604717158180262, 0.039936912179525406, 0.011299913383222051, 0.02587636889490698, 0.024190282316080162, 0.015925771590056162, 0.13272154464253358, 0.2130924162587949, 0.15212010086647101, 0.12188732171697275, 0.11400772524731499, 0.11502612488610403, 0.15434583143464156, 0.14759302378765174, 0.10743992695850985, 0.13355629199317523, 0.15198778653783457, 0.15123605116137437, 0.14811137025909765, 0.0720698641879218, 0.1653137800416776, 0.12161076441407204, 0.1688157535557236, 0.12944575399160385, 0.13200212110366139, 0.16170991770923138, 0.12620006315410137, 0.230041148939303, 0.1375724050615515, 0.14053149627787725, 0.1582997092711074, 0.10503559918808085, 0.06920589001051017, 0.12225126075957503, 0.0942497897361006, 0.1190082026379449, 0.05410468604947839, 0.1047180447993534, 0.16839731458042348, 0.2968991313661848, 0.1741114208208663, 0.12216797737138611, 0.16087310761213303, 0.10304990716810737, 0.11784950909870011, 0.17682036331721715, 0.09989395937217133, 0.1675021776131221, 0.08558094168880157, 0.1071580635117633, 0.1073739326425961, 0.11060531996190548, 0.11515641718038491, 0.1216832726661648, 0.2280166989990643, 0.16852179861494473, 0.1099975968578032, 0.13959357089229993, 0.10576232376375369, 0.13247014741812432, 0.12767876737884112, 0.1335140328322138, 0.1313500353800399, 0.11065329238772392, 0.21122599712439946, 0.06361804556633745, 0.19482811274273054, 0.22516799185957226, 0.16437692674142973, 0.1803658173552581, 0.09106865472027234, 0.09994428631450449, 0.14799029247037002, 0.09768359762217317, 0.26612675402845654, 0.22359939531556197, 0.14096223030771526, 0.131210827135614, 0.12115582025476865, 0.12385341764560767, 0.2177147732249328, 0.18320874337639126, 0.16711805893906526, 0.13380829989910126, 0.13716573188347475, 0.20316238195768424, 0.15000461866813047, 0.1280015871993133, 0.1916027779557875, 0.13779581950179168, 0.08841290936938354, 0.11088035056101424, 0.14474997563021524, 0.09114411459969622, 0.1385263167321682, 0.07885055962417807, 0.0774066031777433, 0.15620417600231512, 0.13244861071663244, 0.12009702064096928, 0.1349516585469246, 0.14374364034405776, 0.19508872447269304, 0.17198227292725018, 0.15095713255660875, 0.09196134217615638, 0.1215863371534007, 0.1354273251656975, 0.15735761768051557, 0.20074063619332655, 0.11662786108042512, 0.13665828268442834, 0.11098821727292878, 0.18264226163072245, 0.16166183671780995, 0.13419038296810218, 0.08370861929974385, 0.21440851635166577, 0.15441019726651056, 0.1384080345077174, 0.17010781993823393, 0.17752314917743206, 0.1982512811997107, 0.17237548397055694, 0.11228395452988998, 0.13540767479155744, 0.09781221393495798, 0.07455498512302126, 0.213339077308774, 0.11358689104339906, 0.198644329394613, 0.1485042284641947, 0.05646264612940805, 0.1864685206008809, 0.11325966074530568, 0.13998294142740114, 0.13158142939209938, 0.19297374439026627, 0.1272214754883732, 0.1354305957044874, 0.14803428868097918, 0.14690459572843143, 0.13834746847195284, 0.09787303102867943, 0.1210249579910721, 0.1364849034164633, 0.13075031898915768, 0.14701256422059877, 0.0729706601372787, 0.1499562526920012, 0.1603469444172723, 0.12571250860180172, 0.13126538135111332, 0.15324988881392138, 0.08072244775082384, 0.12853355865393365, 0.127501018345356, 0.23249152888144764, 0.12937437210764202, 0.12917123229375907, 0.17836173703627928, 0.10933664268148796, 0.12604816630482674, 0.10718608022268329, 0.09178889928651707, 0.10239814714129482, 0.20241709266390118, 0.22437458086226666, 0.1568914505520037, 0.2247921106006418, 0.1796603716377701, 0.10799616961074726, 0.11339646019041538, 0.1842545694006341, 0.09932762690420661, 0.14887289011052676, 0.08125218682523284, 0.27350921503135134, 0.10885079803743533, 0.23069707517113003, 0.0828255263290235, 0.08822056504764728], [0.013697024085558951, 0.04074659783925329, 0.06071202257382018, 0.08085817511060409, 0.057042159140110016, 0.020855910344315425, 0.028924112407756702, 0.10688628309539386, 0.015746818156912923, 0.030376601432050978, 0.038268832223755975, 0.06470495688595942, 0.058315043337643147, 0.04903446204428162, 0.04431866741340075, 0.021424485370516777, 0.02134987196352865, 0.01727031247823366, 0.04201665933110884, 0.039330800596092425, 0.03740790359941976, 0.020412759123636142, 0.04182355505015169, 0.04225348162331751, 0.025962846486696174, 0.05522255213665111, 0.0416049649938941, 0.04410737160859363, 0.10720678911145244, 0.04784441000914999, 0.01566299024437155, 0.054089703996266635, 0.03692250678847943, 0.06447379357580628, 0.023384118253099065, 0.07020774696554456, 0.058976574268724234, 0.04320858073021684, 0.016789831653503434, 0.03974644061444061, 0.03967535389321191, 0.03512427703078304, 0.04683098742472274, 0.01333410878266607, 0.04413818049111536, 0.04337413988209196, 0.07614899280347995, 0.042900770104357173, 0.018723025419084088, 0.05133642941447241, 0.034848934305565696, 0.014912359183654189, 0.05914306640625, 0.09973088026578937, 0.05168426003573196, 0.022585333258445774, 0.04124979940908296, 0.06038694323173591, 0.04826057589213763, 0.039749178503240855, 0.01167520007584244, 0.06511616267796073, 0.05281309803415622, 0.022038328860487257, 0.049901728185692, 0.008428301446006765, 0.04695808042639068, 0.06612141230808836, 0.02616720087826252, 0.06272271860923086, 0.06385366006621293, 0.04119110952264496, 0.05018757802567311, 0.024045174209667102, 0.023993620815287744, 0.024850907402911356, 0.02248863353660064, 0.04794189174260412, 0.06586238835006952, 0.023384459216945937, 0.03583314595744014, 0.009446987765841186, 0.04329145021204438, 0.1055825866226639, 0.032102041345621855, 0.04086930750470076, 0.026308616057836583, 0.003965725057891437, 0.033702925978494544, 0.036383237689733505, 0.07213531567582063, 0.04267409869602748, 0.034448802205068726, 0.061430618299969604, 0.06731297408363648, 0.04486092545890382, 0.0928789929353765, 0.042666441428342035, 0.016932870228109614, 0.02841323151785348, 0.03710529733715313, 0.03654278162866831, 0.022387316383953606, 0.01979194877536169, 0.02723227354830929, 0.08599297529352562, 0.027688215154090097, 0.04112958675250411, 0.04402044788002968, 0.05876772118998425, 0.05046124816206949, 0.042240830337894816, 0.04549908085859247, 0.03079962730407715, 0.05909902269818953, 0.029841949764106954, 0.040433616776551516, 0.06448029394128493, 0.021868679838787233, 0.019291427418855683, 0.04723299228187118, 0.02381347824952432, 0.022032717375883033, 0.0236357190380139, 0.011057992748517011, 0.005840659806770938, 0.013069659937173128, 0.04987607956198709, 0.06548791844397783, 0.05088922055438161, 0.03177608669336353, 0.00843697227537632, 0.02709528580973191, 0.04563088628596493, 0.010466875940827387, 0.021660077818004147, 0.015819183916651776, 0.038421132801366706, 0.03614068177661725, 0.0382273499853909, 0.025821288814768195, 0.020895786151023846, 0.025051302542643886, 0.04038744246853249, 0.029779924878052304, 0.030238105649394647, 0.019829173206484745, 0.052069135276334624, 0.08769246802798339, 0.006422551082713264, 0.024191108432465365, 0.02590626514782863, 0.048912084860993285, 0.057304887899330685, 0.05834193368043218, 0.05493482614734343, 0.07092783546873502, 0.04326138771804316, 0.038104521576315165, 0.012820564642814654, 0.0477269827388227, 0.025589455451284136, 0.08119641124669995, 0.03985526406073144, 0.04356650455987879, 0.013306014888387705, 0.024814867015395845, 0.0022556143106027904, 0.058105477797133584, 0.04931664100981184, 0.058844300652188916, 0.0380210176642452, 0.060836615173944404, 0.05284780849303518, 0.04603242973930069, 0.010871357450793897, 0.05805717967450619, 0.07116041013172694, 0.0659438329083579, 0.013622721108341855, 0.02091922953591815, 0.04595489354271974, 0.010661904716731181, 0.008488895471340843, 0.029761126065360646, 0.003471462762848075, 0.041616944529648335, 0.046202928626111577, 0.0068942728685215116, 0.03852974250912666, 0.022920054583145038, 0.02105605272975351, 0.07676355554057018, 0.06688853685877152, 0.04914277658930846, 0.020660398960379616, 0.024197780128036226, 0.03602081856557301, 0.0015100049391289108, 0.02852815669029951, 0.033794691054416556, 0.05390796178419675, 0.026830319581287246, 0.030135141352989843, 0.037776724701481204, 0.052872347711984596, 0.01255963060871831, 0.04916049653132047, 0.03269705209614975, 0.06416194566658565, 0.030593434082610265, 0.03452842489683202, 0.05218760749059064, 0.06877577344753913, 0.02088499574788979, 0.029705696539687257, 0.03458971017971635, 0.03611795424616762, 0.03750021828870688, 0.03006930310013039, 0.03880726672442896, 0.04279886092990637, 0.04536814734871898, 0.026810250211773173, 0.024179771808641295, 0.033240151525075944, 0.03229713373418365, 0.03857242575447474, 0.039421873566295416, 0.03674824203231505, 0.00914236540640039, 0.0667378952992814, 0.040337068028748035, 0.016886017385071943, 0.031442393349217515, 0.038591780965881686, 0.05088573627706085, 0.014527816425210663, 0.022575993223914077, 0.01058017008472234, 0.011023741997113186, 0.026485501655510495, 0.01277409602023129, 0.03673223199855004, 0.03256618983245321, 0.05912901394601379, 0.024676296593887464, 0.06741554143705539, 0.022306750528514385, 0.03306472647402968, 0.034810641181788275, 0.020087608535374914, 0.04565902852586337, 0.011850242602771946, 0.058067744464746544, 0.04227660270407796, 0.014841754222288728, 0.05866393247353179, 0.05621308773489935, 0.03241114118801696, 0.026615637886737074, 0.029347765924675123, 0.006725665398075112, 0.051458073779940605, 0.04278130044362374, 0.024866607006905333, 0.05112658228193011, 0.02900543822241681, 0.043303921685687134, 0.04145198927393981, 0.04374754448820438, 0.05868646662150111, 0.017730696792049066, 0.05704053065606526, 0.02442865675714399, 0.030843918677419424, 0.021809287668604935, 0.016136884190408245, 0.02310416318609246, 0.03304300996075783, 0.029747070212449347, 0.02870478614100388, 0.020709289104810784, 0.03864762779059155, 0.05269669535170708, 0.02741199202968606, 0.042995133969400606, 0.021049364070807184, 0.03471921198070049, 0.02626242478644209, 0.042141747261796675, 0.032766069285571575, 0.01747515711135098, 0.01864157068277044, 0.05981482964541231, 0.028154341570500816, 0.03941294404545, 0.029193232966853038, 0.04601920509178724, 0.026437254423009496, 0.005710208904929459, 0.02663538834479238, 0.04650193526010428, 0.03324128467855709, 0.02574812068736979, 0.016745314667267457, 0.05199121570746813, 0.005827195975663406, 0.03915109738175358, 0.020028806690658842, 0.03250933538324066, 0.017610803046928983, 0.02177415312533932, 0.01166391179763845, 0.1121695806671466, 0.02572283168722476, 0.03333312100065606, 0.0030366176589658217, 0.0459455738642386, 0.021150073934612528, 0.027292790390284996, 0.017955339380673, 0.04707674263045192, 0.0802614510591541, 0.047683444539351125, 0.05258129011573536, 0.03782451392284461, 0.037627233258847675, 0.0054098515621652556, 0.06618133373558521, 0.05959741345473698, 0.028358667124328867, 0.08274692483246326, 0.030089109537324736, 0.039691221434623, 0.021748648690325872, 0.00916728884580412, 0.05180296634456941, 0.0419591500956033, 0.0223894266278616, 0.011025396774389913, 0.03824105978544269, 0.03177984917004194, 0.026977090098495995, 0.04980241780036262, 0.02445131982676685, 0.03754498124388712, 0.06607278170330183, 0.09395295102149248, 0.04793816658535174, 0.03377578367612191, 0.03061524559078472, 0.14368863829544612, 0.096876120593931, 0.20178449446601526, 0.151734340137669, 0.15634223073720932, 0.15901553657438072, 0.15098750378404344, 0.1963639903281416, 0.09848335292190313, 0.09833771216550044, 0.17138186443064893, 0.10201704794807093, 0.12572721924100602, 0.12494499050080776, 0.09756137989461422, 0.1413750781544617, 0.14147586774613174, 0.18665350281766482, 0.13730830566159316, 0.11217060525502477, 0.13928561098873615, 0.0798603757949812, 0.10985224108610835, 0.11887116570557867, 0.14748844797057764, 0.11661891798887934, 0.12920659753893102, 0.1241305720593248, 0.21341657957860402, 0.11213876839194979, 0.10732954288167612, 0.15065910640571797, 0.10683031752705574, 0.12381255626678467, 0.14609534772379057, 0.1588156944406884, 0.18604757104601177, 0.20505165415150778, 0.1136081088334322, 0.08892515581101179, 0.1255809406616858, 0.12657544229711803, 0.08465868367680482, 0.10761247162840196, 0.07803862462086336, 0.1368761874203171, 0.17370900884270668, 0.16003342052655561, 0.08577876857348851, 0.15562861545809678, 0.15791918683264936, 0.07626359058277947, 0.17060281123433793, 0.12405887804925442, 0.08617603725620679, 0.1375833430460521, 0.15769497172108718, 0.1843365907136883, 0.1183784000043358, 0.19503137469291687, 0.18484726973942348, 0.09245793481490441, 0.10244567173400096, 0.1128895470340337, 0.11772806490106241, 0.16817087387400015, 0.13499816533710274, 0.18740916012653283, 0.12181498988398484, 0.14569327501314028, 0.18586866850299494, 0.35457924913082806, 0.0967142628505826, 0.08754694940788404, 0.10184866948319332, 0.109467050326722, 0.17208395818514483, 0.11804717992033277, 0.24122997426560946, 0.09849370058093752, 0.12374623625406198, 0.07693927575434957, 0.12635566480457783, 0.20283805578947067, 0.09796222445688077, 0.19048422654824598, 0.16949352861515113, 0.08780496234872512, 0.1064765565097332, 0.1257711611688137, 0.19890385546854564, 0.10770524093615157, 0.11814978798585278, 0.12288153836769716, 0.12345757388642856, 0.19020506367087364, 0.1517774678234543, 0.16852087580731936, 0.08087728265672922, 0.18326291761228017, 0.08368071115442685, 0.13179168025297777, 0.15697100199759007, 0.07597404611962182, 0.140848914959601, 0.19630197222743714, 0.1439645713461297, 0.14804139972797462, 0.15047457202204637, 0.16310061594205244, 0.13749919113303932, 0.11003311138067927, 0.17301636029567036, 0.07763499127967016, 0.10244856229318039, 0.10616658135716404, 0.06758850679865905, 0.1983509851353509, 0.1512234304100275, 0.10201002511062793, 0.159766837688429, 0.132982373503702, 0.11811582052281924, 0.13974827687655175, 0.09451289168958153, 0.07433585902409894, 0.09243106482816593, 0.13600532843598298, 0.09329915538962398, 0.11015984136611223, 0.20153307010020527, 0.08855909295380116, 0.15895809179970197, 0.090221693739295, 0.14631279105586664, 0.09643735270947218, 0.10420674152140107, 0.09324202952640397, 0.16694225051573344, 0.1461435779929161, 0.14071569139403955, 0.0750884764960834, 0.10427466966211796, 0.1103190528228879, 0.0926217535244567, 0.13419954319085392, 0.15317093447915145, 0.17507826536893845, 0.16036844040666307, 0.1494093398962702, 0.11574242716389042, 0.10441604921860353, 0.1341778707823583, 0.11881175317934581, 0.13256637725446904, 0.10551524202206305, 0.2340200782886573, 0.15359169404421533, 0.19658369996717998, 0.13384742422827653, 0.16456809719758375, 0.10370100901595183, 0.13172232040337153, 0.09188113255160195, 0.22322926803358964, 0.06510542146861553, 0.20905781989651068, 0.09631269225584609, 0.12706632167100906, 0.10239942957248006, 0.1394016540476254, 0.15884428790637425, 0.16183427960744926, 0.15529654041997024, 0.11346247486237969, 0.11219782807997294], [0.040813996722655635, 0.019123396703175137, 0.043229985117380104, 0.03038408906598176, 0.010941183793225458, 0.06739367225340434, 0.02386510119374309, 0.028101829745407616, 0.033519704560084004, 0.013988197880930133, 0.0576335091942123, 0.04023939969816378, 0.02159107250294515, 0.0483708853301193, 0.027065316614295756, 0.01328228906329189, 0.02680419598306928, 0.018208823100264584, 0.07229238974728755, 0.0791344926027315, 0.024131594125979712, 0.02951421056474958, 0.03601651665355478, 0.014952560687171561, 0.10596732276358775, 0.0440392636560968, 0.051301525573113134, 0.03653002856299281, 0.056110204862696786, 0.014161991903425326, 0.01737434377095529, 0.00512673452197175, 0.02022505258875234, 0.06804059432553393, 0.025428054022735784, 0.039483735603945594, 0.018390058107408028, 0.05236180439325316, 0.056389242211090665, 0.05268830865887659, 0.027355308910565715, 0.022994033559890728, 0.08682196188185896, 0.042999100006584606, 0.09420619386115245, 0.04686833059947405, 0.014188498873928828, 0.010115425335243344, 0.04855701427108475, 0.025652735627123287, 0.09785612193601471, 0.04810507602191397, 0.021035265809457217, 0.03990768428359713, 0.040565652905830314, 0.04526604139911277, 0.10882883385888167, 0.039588609976427894, 0.02759925921314529, 0.04666611698589154, 0.0512724265988384, 0.016945529995220046, 0.038818849317197285, 0.03218715677836111, 0.027718147030100226, 0.0070972095459832674, 0.016858957408528243, 0.03523937353332128, 0.0026956179769643185, 0.009665076554353749, 0.0726668800094298, 0.06070444333766188, 0.054326699314905066, 0.015259499395532268, 0.045976674516818354, 0.06047288647719792, 0.014333063304158193, 0.010185469657049646, 0.10118027177772351, 0.057525954608406336, 0.03645248558106167, 0.03957602993718215, 0.05655756300049169, 0.07691167294979095, 0.02382308630538838, 0.06187385773020131, 0.03896719742832439, 0.03232383747984256, 0.016295091415356313, 0.07896370533853769, 0.016684104023235183, 0.027652581887585775, 0.036574330114360364, 0.020060282233836393, 0.021699244555618082, 0.027154141937249472, 0.04790989542379975, 0.017369224224239588, 0.03496762365102768, 0.021168504642056565, 0.03882955659979156, 0.034273882662611346, 0.0352774664892682, 0.01413848320953548, 0.04121534340083599, 0.03661869612655469, 0.039544617158493826, 0.057328344854925356, 0.012748224328138998, 0.04041499438296471, 0.06961138253765446, 0.06788017507642508, 0.023321104402254735, 0.04668815919597234, 0.00790948508906045, 0.022625589044764638, 0.0111166605825669, 0.03189419928405966, 0.029698806016572883, 0.01841026488026338, 0.04539192321577242, 0.05482856756342309, 0.02303725284790354, 0.056728825239198546, 0.08215061468737465, 0.03837236648957644, 0.02046753725569163, 0.0879580873463835, 0.05545440076717308, 0.06464513723871537, 0.02845601484711681, 0.00935869339653956, 0.008444140149679567, 0.06520942053092377, 0.02252802249443318, 0.02137599725808416, 0.04878047960145133, 0.06150149806801762, 0.05701289392475571, 0.029137990038309778, 0.02062899975239166, 0.053578879085502455, 0.05682963518691914, 0.017719563728730594, 0.04534959959398423, 0.008845316345936485, 0.020071683318487236, 0.025631049647927284, 0.10169742402753659, 0.028209304603348886, 0.02809028107939022, 0.02390470389010651, 0.016070526858259524, 0.025846306400905763, 0.009276203894322472, 0.037079781027776856, 0.02006692000265632, 0.06508062779903412, 0.015645241464621255, 0.040146677887865474, 0.022422785105715905, 0.04735352384990879, 0.08082329841064555, 0.022321897126468163, 0.012238090674925064, 0.019965473928355744, 0.015951131836378148, 0.019241237879863808, 0.04283077921718359, 0.014838626175852758, 0.023903506275798594, 0.028463668722127165, 0.10312055623424904, 0.025705430656671524, 0.029500989309911217, 0.03809263364278844, 0.03912461076730064, 0.07087078424436705, 0.04313389438071421, 0.018432095048150847, 0.02311734203249216, 0.03099390205794147, 0.01868356860774968, 0.012878494570031762, 0.0356047408921378, 0.074943792474057, 0.053816223849675486, 0.035439795814454556, 0.03456867220146315, 0.00728269260642784, 0.028405759150960615, 0.03358962759375572, 0.052839703392237425, 0.008657275632555996, 0.052680573359663994, 0.08078000787645578, 0.044305639541042705, 0.022919187754658715, 0.04508588356631143, 0.01029634736810944, 0.07902988964425665, 0.050967652417187176, 0.037884767832500596, 0.02056670345232955, 0.03368485319827284, 0.061959000304341316, 0.045629915980888267, 0.02567468284230147, 0.02415495947934687, 0.021904503095096776, 0.021957880052338754, 0.011820156360045075, 0.04011474602988788, 0.020369874014120017, 0.07505427154579333, 0.03932803217321634, 0.03306849912873336, 0.0075345978839322925, 0.059582743527633805, 0.04571529943495989, 0.03333005062969668, 0.026636446859421473, 0.01571887099583234, 0.013636898249387741, 0.0529821414633521, 0.046573184829737456, 0.04941470628338201, 0.048274920122431855, 0.06082231844110148, 0.025825597512136613, 0.026641909066321592, 0.008614348114601203, 0.03791090500141893, 0.04261706443503499, 0.04431732052138873, 0.017673440310837965, 0.009413980429859033, 0.03621845206777964, 0.02062747474493725, 0.014678200141393712, 0.0370734299400023, 0.029330887366086245, 0.022399200924805233, 0.046403435724122186, 0.015997409620987516, 0.042314400497291765, 0.06736381671258382, 0.09949538790221725, 0.016530387003773024, 0.02176249759005649, 0.024106225397969996, 0.019216254220477173, 0.005514416353045297, 0.021790270028369765, 0.0649884081046496, 0.09272481620843921, 0.036900786882532496, 0.04806745464780501, 0.00787270933921848, 0.04242529347538948, 0.04240153117903641, 0.08537822935198035, 0.029905050128166164, 0.03385639363633735, 0.01307330621472959, 0.04603121516161731, 0.02846342444952045, 0.02402780032051461, 0.02911475021392107, 0.014651263997490917, 0.037476449207003625, 0.02893286890217236, 0.01871858610372458, 0.05769371560641697, 0.05582918619204845, 0.054605702736548016, 0.020816872528355037, 0.0008889778837328777, 0.05549411202913948, 0.008851753946925913, 0.029283149034849236, 0.02682858083530196, 0.04981282313487359, 0.02354335006592529, 0.05416192387097648, 0.029645272996276617, 0.06223810211356197, 0.00812927954497614, 0.033422691015792746, 0.047258579837424416, 0.02372763678431511, 0.039412333363933225, 0.07033056858927011, 0.03563780251092144, 0.060009854180472236, 0.02987443802079984, 0.0435079130610185, 0.05215546528675726, 0.022107780312321017, 0.04831524885126522, 0.03786649827712348, 0.02354720244849367, 0.023349385741832, 0.04818607274709003, 0.0444936514166849, 0.041438961401581764, 0.03230619217668261, 0.048371492618960996, 0.02171554466310356, 0.04849609539711049, 0.019978802052459547, 0.050536239852330515, 0.046503458571221144, 0.03264626714267901, 0.09796497930905648, 0.011420718061604669, 0.014987294894776173, 0.007714142490710531, 0.06490145384200982, 0.09098962574665036, 0.03561993668388043, 0.017944976454600692, 0.05183043683479939, 0.037049036606081893, 0.0728953495355589, 0.009197547266791974, 0.06187906887914453, 0.05942710116505623, 0.03245753262724195, 0.06619181031627314, 0.014507200835006577, 0.014595237361001117, 0.04641092675072806, 0.060456818767956326, 0.015968850082052604, 0.012331757345236838, 0.0065262303853939685, 0.01972668558093054, 0.021917892287352254, 0.03763275992657457, 0.016343811926032816, 0.02840189659036696, 0.013714598142541945, 0.07960011011787824, 0.02858402387105993, 0.02033498035078602, 0.03530317957379988, 0.018511989153921604, 0.055368091112801006, 0.023541239822017293, 0.01852495765446552, 0.0049940190095055315, 0.13227209661688122, 0.10768471525183745, 0.137665025091597, 0.11710652682398047, 0.07101312732057911, 0.11899338343313762, 0.13070603779384068, 0.11606923677027225, 0.11308113818189927, 0.11027950101665088, 0.16115935439510004, 0.12286439857312612, 0.07157731561788491, 0.1129433141489114, 0.09852169015045677, 0.05445991609511631, 0.1508721528308732, 0.10086658503860235, 0.1566911470144987, 0.299943745136261, 0.12467821767287594, 0.10911845296089139, 0.12719855457544327, 0.12437711097300053, 0.1872739280973162, 0.19402170101446764, 0.16185553132423333, 0.09735430457762309, 0.13392217164593084, 0.13698549941182137, 0.10549597841288362, 0.09454045378203903, 0.10176245482372386, 0.14550677287791455, 0.12197903251009327, 0.11579653354627745, 0.12588119240743773, 0.2867785915732384, 0.14503144552665098, 0.16920004864888533, 0.15196871970381054, 0.09915403729038579, 0.14454838287617477, 0.09445845282503537, 0.2053629524473633, 0.17958740198186465, 0.05660814778613193, 0.11867044147636209, 0.22137309477797576, 0.09011713149292128, 0.2006996391074998, 0.12704930401274137, 0.16087063774466515, 0.08724804794681923, 0.10293680216584887, 0.11914628451423985, 0.1807227132043668, 0.10585699296955552, 0.08021077127861125, 0.10526391943650586, 0.16889002599886485, 0.1568833759852818, 0.09223962974335466, 0.11843344276504857, 0.08348473667034081, 0.09947410904403244, 0.1099182761141232, 0.12854299029069288, 0.14353011894438947, 0.0694816398567387, 0.14424405992031097, 0.17321609386375972, 0.19197777711919375, 0.16302094236016273, 0.1378753302352769, 0.22822899903569902, 0.1158436510179724, 0.10352044406213931, 0.21222374215722084, 0.32157101748245104, 0.11030156019010715, 0.15468816592225007, 0.0955497474808778, 0.19573728181421757, 0.14041505966867718, 0.22346682314361843, 0.18069185343171867, 0.07381956172840935, 0.12558202631771564, 0.17168789729475975, 0.10967899073979684, 0.08255559831325497, 0.06688551737793855, 0.11807109149438993, 0.1027127295466406, 0.1356453113257885, 0.132217691679086, 0.12546169491750853, 0.16349887528589793, 0.13912017058048928, 0.15887934102543763, 0.1396754700690508, 0.19596978862370762, 0.0993399355294449, 0.22886997035571507, 0.09719778011952128, 0.1506755133824689, 0.10856637651366846, 0.19205141173941748, 0.14391302982611315, 0.15794545970857143, 0.12054042970495564, 0.06982066987880639, 0.12152658535965852, 0.12620703849409307, 0.12269663757511548, 0.14703456232590334, 0.07160618728292839, 0.12666806232716354, 0.18135510784174713, 0.16024605983069964, 0.13754420514617646, 0.1388270841645343, 0.1554460081138781, 0.13359909398215158, 0.11258147856486694, 0.19034382408218725, 0.15187935664185456, 0.18565054663590022, 0.14586638286709785, 0.07173744309693575, 0.13258279780192034, 0.13005828112363815, 0.13500268438032695, 0.05779937029417072, 0.07045828245048012, 0.10080725393657174, 0.137483096282397, 0.2746632402496678, 0.08294513848211084, 0.17844514256077154, 0.06857529349092926, 0.3017216697335243, 0.10893323325685092, 0.12978747779769556, 0.06007464070405279, 0.12061571995062487, 0.1502729385559048, 0.1450491010078362, 0.056751478130796125, 0.1879136102007968, 0.10546724245484386, 0.1005637887865305, 0.15695675276219845, 0.13399305141397885, 0.07773700901972395, 0.08113492918866021, 0.14948391089481966, 0.12242856195994786, 0.1119707359799317, 0.11761278180139405, 0.12881034665874072, 0.10933299216308764, 0.08145292462514979, 0.15777403462146009, 0.11756478223417487, 0.06905731798282691, 0.2012410829109805, 0.15731233225337096, 0.08832889316337449, 0.09858233082507338, 0.12132849384631429, 0.17396671644278935, 0.08715681212821177, 0.08318546880036592, 0.09782978120659079], [0.03307439559804542, 0.03005469763385398, 0.0438042123402868, 0.0386887673687722, 0.027498247401256646, 0.02674921089783311, 0.03341985473941479, 0.07989213123385396, 0.027561926216419255, 0.032553328201174736, 0.019086036565048353, 0.09530097618699074, 0.027165858540683985, 0.017423113475420644, 0.04919981763565114, 0.026326296984085014, 0.02641995856538415, 0.0322082490394158, 0.018197973325316395, 0.01339557218099279, 0.03025937093687909, 0.07027876922594649, 0.013011126113789422, 0.022059465226318156, 0.01585237615342651, 0.03720900462940335, 0.01957640703767538, 0.049419642625642676, 0.07337533842240061, 0.08535031442131315, 0.027309638414798037, 0.02050030540807971, 0.043604641620601924, 0.0044969988936957505, 0.03248383942991495, 0.06066344625183514, 0.04002656701153942, 0.0404977349431387, 0.05433437354596598, 0.03712671190234167, 0.03985996970108577, 0.04346326206411634, 0.12041690919016089, 0.0115749889352758, 0.04822440319029348, 0.02202745364047587, 0.025804797021139945, 0.024215196425627385, 0.04099606123885938, 0.025999606121331453, 0.017767469997384717, 0.02288172413994159, 0.1054209867226226, 0.013163737121171184, 0.026269001487110342, 0.0323550433053502, 0.053120169056845565, 0.0254331413390381, 0.011128501866811087, 0.06205437518656254, 0.03832741693726607, 0.04152558657473751, 0.05990577369396176, 0.050692014529236724, 0.07071157957294158, 0.02344859265057104, 0.038381058523165326, 0.04917485772499016, 0.005432597752327898, 0.012840829939315361, 0.03091517503240279, 0.018975211440452507, 0.028646408380674462, 0.018662422063893506, 0.035344234335103204, 0.019161891691120606, 0.01983802978481565, 0.05784464215061494, 0.04193774910111513, 0.07585483430219547, 0.0941815630399755, 0.07261964718678168, 0.059340872934886386, 0.06642072767551456, 0.039539019244589975, 0.04654333607426711, 0.012589917867444456, 0.0471370440375592, 0.030641087596969943, 0.029526512404637675, 0.0566201612486371, 0.011653581101979529, 0.014174763628813838, 0.006727070813732488, 0.03139960153826645, 0.039562591551137824, 0.07374168626431908, 0.05233109050563403, 0.018319449753367474, 0.03663610054978302, 0.020113141808126653, 0.016605215845629573, 0.0870768671323146, 0.11073304060846567, 0.030399308606450046, 0.03417471476963588, 0.057915650840316496, 0.04599860816129616, 0.018678382903869663, 0.014506233922605003, 0.034771988434450965, 0.04162540925400598, 0.08894244488328695, 0.023283262504264712, 0.08657829995666232, 0.08536535754267659, 0.021244000144568936, 0.026626102593062178, 0.05889562504099948, 0.008324754457654697, 0.02273863128253392, 0.017487492877990007, 0.0668118352602635, 0.022096460651872412, 0.05193632222445948, 0.041638308204710484, 0.04410291363352111, 0.04412137657137854, 0.06912739029420273, 0.03651545702346733, 0.008914139304709221, 0.046366258790450435, 0.011621760354111237, 0.03990988273705755, 0.045365165187312026, 0.04317307638536606, 0.06467482314578124, 0.0383100871528898, 0.04531788147453751, 0.07589439967913286, 0.01700962950209422, 0.058300264844936986, 0.028927145459290062, 0.0203276623506099, 0.022631258204845444, 0.027200458737622415, 0.0564782863615879, 0.03560452376093183, 0.005215173079964838, 0.03813617184226002, 0.028190215716936758, 0.02373977068678609, 0.02727564381036375, 0.09132881861712251, 0.029523720233035938, 0.02159333202455725, 0.004612175548183066, 0.05485369371516364, 0.05083158239722252, 0.0672512681090406, 0.03461464634165168, 0.027330267575702498, 0.01785801540661071, 0.09378404329930033, 0.034974235974784405, 0.01436669149968241, 0.02733547702830817, 0.04542593817625727, 0.0692242036706635, 0.05962392381791558, 0.0545962202096624, 0.047000370121427944, 0.08206125162541866, 0.012302917910606732, 0.017652095295488834, 0.01256162634984191, 0.017755853477865458, 0.013517426044147993, 0.03472749689327819, 0.006111198504056249, 0.005631465764184083, 0.03277665443186249, 0.08844372842993055, 0.023381823108398488, 0.06226500602705138, 0.015110572833301765, 0.011744893255776592, 0.06563995778560638, 0.03011944005265832, 0.021912202771220888, 0.03733459806868008, 0.07182951351361615, 0.028295749964724694, 0.04249588825872966, 0.008855287418035524, 0.060471291919904094, 0.022847858457160846, 0.03534557444176503, 0.0405573747786028, 0.010122343847927238, 0.026310185170067207, 0.030800672248005867, 0.0347271406623934, 0.017577076463827064, 0.007578189518036587, 0.04712437918143613, 0.04175421216392091, 0.0230755290083055, 0.08388394596321241, 0.02325019410013088, 0.014565017107608063, 0.03702379510338817, 0.053980436109538586, 0.05072931020653673, 0.028894246688910892, 0.024300301680341363, 0.018132574423881512, 0.0005509264893979499, 0.03443492616393736, 0.027742971233757477, 0.0037931248329446782, 0.018758131124611412, 0.02540472598879465, 0.033227021872465096, 0.022250605148396323, 0.0703334862898503, 0.0033879936256978127, 0.022147572998489653, 0.015502635456089462, 0.024898730551025698, 0.03502536019576447, 0.05350517321910177, 0.025339471276051233, 0.02324926620349288, 0.02210321377164551, 0.03196470925052251, 0.038377408004764996, 0.03184495799775634, 0.01023966509715787, 0.07904201506503991, 0.03423007644180741, 0.040059710054525306, 0.03207206027582288, 0.047561990163688145, 0.03171605330758861, 0.0450082320187773, 0.03525949888197439, 0.03413236739912203, 0.03783858673913138, 0.006321777182165533, 0.030984073478196348, 0.049234446670327864, 0.021435932256281376, 0.028508038126996586, 0.08568970406694071, 0.03293118738968458, 0.08029731163488966, 0.0035511993212691906, 0.036428770782159905, 0.05995203621153321, 0.015419231627934744, 0.08132553646074873, 0.01888236410117575, 0.049568961041846445, 0.014534332057727235, 0.03883319354749151, 0.08360485093934195, 0.026856180247185484, 0.022528933427695717, 0.08201764896512032, 0.08940590465707438, 0.027983150577970912, 0.019165077413033162, 0.016314519569277763, 0.056825974490493536, 0.06501951893525464, 0.06413780339062214, 0.04464455760483231, 0.03718830931133457, 0.04193330808941807, 0.009838412565711354, 0.009128752297588756, 0.03308761006753359, 0.028997597750276327, 0.0195707243068942, 0.04248178490836706, 0.05864039409373488, 0.03220157904018249, 0.045726759891424856, 0.046940282452851534, 0.05662647501698562, 0.030441747579191412, 0.027222767272698026, 0.03147512587851711, 0.01755428277621312, 0.10547471991074936, 0.02903630138774003, 0.0665256834721991, 0.0035326051292940974, 0.05376803768532617, 0.027464539477867738, 0.0753284471907786, 0.017294261371716857, 0.02471328353775399, 0.007027090585324913, 0.017254024245111004, 0.014189103618264198, 0.0528688362932631, 0.0035206118107972933, 0.029495221762252704, 0.0339559177601976, 0.00874944358864533, 0.059129644983581135, 0.02228829776868224, 0.04508515753384147, 0.002454794236525361, 0.026751711299376826, 0.04715932373489652, 0.005439402186311781, 0.017547030933201313, 0.011830348804193948, 0.021881295501121452, 0.004378005903812924, 0.04778851907966392, 0.021606373467615674, 0.05287110599290047, 0.009106641385837324, 0.03604956470163805, 0.02794311361919556, 0.12662293974842342, 0.05628928382481847, 0.019214435746627193, 0.06210377253592014, 0.03618305968120694, 0.0286185273767582, 0.05664622038602829, 0.01837006337674601, 0.026810767594724894, 0.042254071948783736, 0.01756192647319819, 0.02931374417884009, 0.017815445815878253, 0.028019927175981656, 0.02416805181253169, 0.05091872325699244, 0.028761572736714567, 0.02059334782617433, 0.045596403136317215, 0.03829249952520643, 0.014700069325044751, 0.0055846239473404625, 0.01755551092459687, 0.17235891414540155, 0.08135292213410139, 0.15546956684972557, 0.09386366938373872, 0.12817621497171267, 0.08487663591014487, 0.17270294497055666, 0.12440600299409457, 0.08026765286922455, 0.06202118803880044, 0.08150139238153185, 0.21021708340517112, 0.07211829801755291, 0.05913855414837599, 0.12470256350934505, 0.14203044798757347, 0.1134888766599553, 0.09991795915578093, 0.1124717594523515, 0.12913286792380468, 0.09069392697087356, 0.14626624355358736, 0.13228175895554678, 0.0805814413885985, 0.11777864290135247, 0.0619852663949132, 0.1283695295985256, 0.1275892143270799, 0.13861593763743127, 0.17370892741850444, 0.0759274714759418, 0.14104852639138699, 0.12628116165953024, 0.1031114435089486, 0.11212537411068167, 0.09267636880810771, 0.10510656716568129, 0.1233555900731257, 0.12725161601390156, 0.09254965239337512, 0.08882806423519339, 0.14689664329801286, 0.1984835708779948, 0.1520180899117674, 0.18214120423155172, 0.13775008624153479, 0.14196028746664524, 0.10933291752423559, 0.11605367117694446, 0.08260422213269131, 0.0858294754954321, 0.1092284841995154, 0.15909071825444698, 0.12223013117909431, 0.07698234915733337, 0.0921164145693183, 0.13940142334571906, 0.11278847245765583, 0.09620289850447859, 0.10776993925017969, 0.082716533248978, 0.11574162649256842, 0.11771817186049052, 0.20197821621383938, 0.10429632849991322, 0.20724885910749435, 0.13170223576681955, 0.1352116053125688, 0.17956434536193097, 0.10491064017904655, 0.11138015945575067, 0.12098024253334318, 0.13349914577390465, 0.09363355101751429, 0.09302588219621352, 0.22542445095522062, 0.09149652533233166, 0.14733984880149364, 0.1524733869092805, 0.15690845463957104, 0.2791262636227267, 0.14158660466117517, 0.1863092684320041, 0.15999581611582211, 0.12717441229947976, 0.15340998236622128, 0.08122068922966719, 0.18571975720780237, 0.06133748258330992, 0.17490313548062528, 0.15946469961532525, 0.047639665459947925, 0.13225943515343325, 0.12010096971477781, 0.2024852175797735, 0.19252132438123226, 0.12781592644751072, 0.15022512897849083, 0.12931209616363049, 0.11031737005604164, 0.1935971145118986, 0.13790164382330009, 0.23028034610407694, 0.22228577866085938, 0.10542120385382857, 0.09177597319441182, 0.18482764650668415, 0.12494633400014468, 0.09342783277056046, 0.18427041997866972, 0.11753271466919354, 0.14330568670162133, 0.15322580082075937, 0.12278581064726625, 0.1523660019572292, 0.21537016332149506, 0.1861870371337448, 0.10318221471139363, 0.1529149232166154, 0.22863688000610896, 0.1741592711103814, 0.128506281546184, 0.15129922277161054, 0.24021000042557716, 0.14851433863597258, 0.16471808057810577, 0.12316650950482913, 0.17717021597283228, 0.10445753484964371, 0.14214752241969109, 0.11286818675164666, 0.2001910363989217, 0.08695813028940133, 0.09652234600590807, 0.17207770209227288, 0.10942920842873198, 0.1261996967451913, 0.13513973488339356, 0.15214228896158083, 0.20119943443153585, 0.04964498410533581, 0.1023660795763135, 0.11250363702752761, 0.06848945881107024, 0.1866489837744406, 0.2524709110813481, 0.0961720115904297, 0.12969989249748842, 0.10843045237873282, 0.08204042060034615, 0.1330160695527281, 0.0998536136799625, 0.08058209278221641, 0.20599856334073202, 0.09729013552090951, 0.06736567589853491, 0.08312803081103734, 0.12300785444676876, 0.11502385857914176, 0.12501121551862784, 0.06165860606623547, 0.10863268295569078, 0.08972632924893073, 0.20466676194752964, 0.10777156773422446, 0.10215991349624735, 0.1141459835427148, 0.12150929628738336, 0.20514876608337673, 0.11785345817250864, 0.1379888898559979, 0.11457127572170325, 0.10828130359628371, 0.07359030510165862, 0.15513412627790654, 0.10081129800528288], [0.056468488315918615, 0.021955305011942983, 0.04450496259544577, 0.03349990151556475, 0.03387113141694239, 0.04518827450062547, 0.05088163114019802, 0.018146455554025512, 0.01443434483371675, 0.02268894385945584, 0.04279287625104189, 0.031354692698057206, 0.06938162379498992, 0.036183809462402544, 0.034095017439020534, 0.009000262361951172, 0.050536775894995244, 0.04775459911408169, 0.09388828663421528, 0.023826115964246646, 0.025801573979801366, 0.020931371920076863, 0.05134526054774012, 0.04065043246373534, 0.025575606551553522, 0.06149684331778969, 0.025332382281443903, 0.062457106076180935, 0.03820955879720194, 0.020535841983343874, 0.021269111029271568, 0.019621824779148613, 0.014857221428038818, 0.05368183320388198, 0.035925487788128, 0.006275999817132417, 0.07835369557142258, 0.01960951954658542, 0.019818866259551475, 0.024171710812619755, 0.08375892588602644, 0.035296791166599305, 0.04058777993278844, 0.031685783860406706, 0.05744056776165962, 0.020135029651490704, 0.03846403317792075, 0.01868022003743265, 0.027645384327375462, 0.027198350190051963, 0.01999341939309878, 0.012949345500341483, 0.01617718068882823, 0.04718142022777881, 0.018475178629159927, 0.04764627778370466, 0.027862739449899112, 0.029152049283896173, 0.047510509711823294, 0.04982649561549936, 0.013567119404407484, 0.022339245570557456, 0.023868298790018474, 0.03374120553157159, 0.05261667571695788, 0.05327198448191796, 0.04483119544706174, 0.01005502978140222, 0.04541964137128421, 0.049936306330242326, 0.013528645620681345, 0.010679991915822029, 0.0477958099384393, 0.03578002345083015, 0.07881554721721581, 0.03113727650738188, 0.03620540723204613, 0.03010188295905079, 0.04687846791265266, 0.03971480731187122, 0.012031380918675234, 0.020688361388498118, 0.053975367452949286, 0.0547949766873249, 0.10196372866630554, 0.056318718673927445, 0.036953444592654705, 0.019950944797268937, 0.06464423478714057, 0.043639402969607284, 0.020656782368730222, 0.10261554976126977, 0.02664809052034148, 0.024863528154258217, 0.07521861272730998, 0.0075246149374704275, 0.014277878051091517, 0.04010702430137566, 0.05405617418832012, 0.01780648067194436, 0.03633141457768423, 0.009983552054369023, 0.032392230417047224, 0.028762085030653646, 0.028838142020893947, 0.040467852260917425, 0.024985971494710872, 0.02678809773975185, 0.05654825010736074, 0.08912178847406592, 0.01718798921709614, 0.05126928837437715, 0.01528793849450137, 0.020524364563503435, 0.010304783254728785, 0.02431407424488238, 0.009961592116659241, 0.06279527435877494, 0.016198242415807078, 0.012859288636328918, 0.029675457626581192, 0.03186959560428347, 0.04457421727212412, 0.005600494457342262, 0.01949753751978278, 0.010566679960382836, 0.033915348151432614, 0.012547420371057732, 0.011953692899883857, 0.06103518166180168, 0.028696806569184576, 0.014558591380981463, 0.022755630281088606, 0.045507484514798434, 0.13369145616889, 0.081412653571793, 0.08777965299252953, 0.017050887823903134, 0.025485714232282977, 0.030255442219121114, 0.04125055597562875, 0.028069178640310253, 0.054037419480404685, 0.004115110055343913, 0.06320525200239249, 0.08413748735828058, 0.0929366344852107, 0.03491104400849768, 0.017705250032512204, 0.04753231443464756, 0.03094963782599994, 0.0518481533841363, 0.038466326626283784, 0.0760874632479889, 0.03411829458283527, 0.057211236496056826, 0.06697790670607771, 0.07214145641773939, 0.017304232443815896, 0.08126256162566797, 0.024323673819058707, 0.0337375380497958, 0.038188666703977754, 0.011828711838461459, 0.015527257795578666, 0.03798402054235339, 0.026292626380122135, 0.04175385932571121, 0.045211100418652804, 0.055428029503673315, 0.015206643213917102, 0.0033533088239242454, 0.06879336786057268, 0.019430801904361163, 0.10969137400388718, 0.04655291698873043, 0.015486165714849318, 0.05410694557109049, 0.05782291545931782, 0.08102246200931923, 0.07784485537558794, 0.024226975793551122, 0.02282694770422365, 0.04098243625568492, 0.033237420421625884, 0.03680066564785583, 0.04492742528340646, 0.02437328829962228, 0.045175969268062284, 0.018102707008698156, 0.05712886234479291, 0.015379428763740828, 0.061581422707864215, 0.04637406872851508, 0.04365649865940213, 0.032252896643642864, 0.04739543356533561, 0.10648250047649656, 0.027435045256944637, 0.03605803960402097, 0.0021356045784029576, 0.047968900829021416, 0.05928088365388768, 0.05615901867193835, 0.0416891542263329, 0.03812359858836446, 0.017673650656693747, 0.022205285794500793, 0.04602652648463845, 0.027165346246744906, 0.03463857827175941, 0.020658086852303574, 0.06537968532315322, 0.015277441557762879, 0.026284794389669384, 0.022262752621567676, 0.0355756215618125, 0.010588404107173639, 0.04920038081971662, 0.03207201956372176, 0.02417474895316575, 0.040994205445583375, 0.028398329192506414, 0.004617928252888045, 0.03072025567027075, 0.016535964561626315, 0.03873116223673735, 0.02550788197134222, 0.029095293222261325, 0.004695159532794995, 0.010360181398157562, 0.02116219257004559, 0.02913896373606154, 0.0073320823222664845, 0.03355040487700275, 0.01787913989807878, 0.04366276153762426, 0.056218424412821016, 0.07102144615990774, 0.02701325940766505, 0.008767740285423185, 0.025593172126848782, 0.03558009650026049, 0.02283956845557051, 0.04079008175592337, 0.018035560879590254, 0.028293962024950554, 0.024895755174968923, 0.023165590961330702, 0.01629275386221707, 0.08350337602730308, 0.05643998984513538, 0.04404923472819584, 0.019810296362265944, 0.0230177958562438, 0.039738888519683054, 0.007666909668062414, 0.02173700333306832, 0.030077540515256778, 0.08076045249721833, 0.03537990152835846, 0.0452432867272624, 0.04878476794276919, 0.016217782528006604, 0.06881159331117358, 0.027397254249081016, 0.0258719923440367, 0.10581890679895878, 0.07857677074415342, 0.05598279294957008, 0.046057138592004776, 0.06368763611785003, 0.03891516736309443, 0.034692481093640835, 0.03599159745499492, 0.07637624096657548, 0.03227359874706183, 0.031466973280268054, 0.05123516824096441, 0.0596997161794986, 0.03163484623655677, 0.0598761827817985, 0.021678786724805832, 0.017820785886475017, 0.046876547658549886, 0.0598294927871653, 0.05161756004339882, 0.07159860126141991, 0.04266542023313897, 0.07866565883159637, 0.09945412618773324, 0.03406960630257215, 0.025496117870456407, 0.013107475541931177, 0.07862701626228434, 0.012926572168778096, 0.010662064172460564, 0.040308162436953614, 0.024059618523876582, 0.056124572841716666, 0.03951162339321204, 0.012384436259578382, 0.01923859498596617, 0.03462815258119788, 0.04815394750663212, 0.09660762428705182, 0.061057030489402156, 0.02704929979518056, 0.0072771133522370034, 0.03316000975402338, 0.07648725608097655, 0.048266150057315826, 0.029891092662832568, 0.023621977007548724, 0.010350527541179742, 0.02589889456118856, 0.05052010428958705, 0.03447447457749929, 0.030049954674073627, 0.026494458317756653, 0.05004118409539972, 0.05797224744622197, 0.03730930906853505, 0.050278630639825544, 0.024047204725710408, 0.01471842369729919, 0.04645552007215364, 0.01049205637536943, 0.023791973778445805, 0.031024894144918238, 0.03564556495153478, 0.024902591415281807, 0.09917447476514749, 0.08792779754315104, 0.035163520103586574, 0.08506997089300837, 0.018575018271803856, 0.009572437016426452, 0.03487838951072522, 0.03724238515964576, 0.07286209453429494, 0.07418192656976835, 0.10217785396214042, 0.03954714809411338, 0.04040662804618478, 0.09241505818707602, 0.019294017726289373, 0.010893975567471768, 0.07197770556168896, 0.040018193889409304, 0.04232584059770618, 0.06021669201020684, 0.09576267855507986, 0.07392307224550418, 0.17178013734519482, 0.14506534513618263, 0.15877913497388363, 0.16796590201556683, 0.12040265995476927, 0.07878223114780017, 0.08597006795129605, 0.08373715169727802, 0.12899763589458807, 0.07842220046690532, 0.141882486641407, 0.19316841608711652, 0.10338446564440217, 0.1283026531870876, 0.16169992967375688, 0.1603013604347195, 0.16165761622999394, 0.09570796827652625, 0.16310837838266576, 0.1748246154082673, 0.12336080122206892, 0.14778584986925125, 0.12770043978733675, 0.1594364047050476, 0.14190234057605267, 0.14094036790941442, 0.20307802648416587, 0.07688660786620208, 0.12052375131419726, 0.11399690939911775, 0.10139829864991562, 0.14988628216087818, 0.10402731650641986, 0.11368237449122326, 0.18699899927846023, 0.09716974983790092, 0.10073591276471104, 0.08473417748297964, 0.20953409719680036, 0.10129172793988671, 0.13665954475956305, 0.11530611557619912, 0.16137953900865146, 0.12310522422194481, 0.15215801740331308, 0.13102995684104307, 0.050798541134489436, 0.17074541215385708, 0.13392299945865357, 0.08104004285165242, 0.13325803514037812, 0.11273809801787138, 0.07090455493224518, 0.16882841501917156, 0.09397129182304655, 0.11684499228639261, 0.21696552128664084, 0.10742837829249245, 0.12502706609666348, 0.13342112781746046, 0.15009723869817598, 0.08647395484149456, 0.11306063963898591, 0.17795369321746485, 0.13806567287870816, 0.0787837239248412, 0.10272634095911469, 0.09189592461500849, 0.1313045056802886, 0.10497256328484841, 0.18590393875326428, 0.16227200254797935, 0.14571139189813817, 0.1663002342517887, 0.13202857039868832, 0.10041430752192225, 0.14888283743390016, 0.11149088280009371, 0.10614749416708946, 0.1163121930190495, 0.15457858251673834, 0.12377738101141793, 0.16822286322712898, 0.14283771466995987, 0.11380930125181164, 0.1098503547587565, 0.17378602256732328, 0.10549814293959311, 0.1118214786318796, 0.21189007934715065, 0.08702750370970794, 0.09699438246233122, 0.1380718746887786, 0.15119186496096, 0.10965679585933685, 0.11657674025212016, 0.12958086388451712, 0.13284752145409584, 0.1444376188197306, 0.16384134548051016, 0.1597667969763279, 0.11366060708782502, 0.07144643299813781, 0.15864919551781245, 0.09774346476686852, 0.13159856918667043, 0.13373063478086675, 0.1531020360333579, 0.1650594515459878, 0.177786651466574, 0.09885455907455512, 0.18129873515239783, 0.15129333308764867, 0.14793953805097512, 0.13960503813411507, 0.13032810735915387, 0.12301966095609324, 0.08088235809866871, 0.09972914321614162, 0.08734015229025058, 0.16595469707889215, 0.10937117332858698, 0.12229584051030022, 0.10760836649153914, 0.10195274318435363, 0.17036003140466555, 0.10696946470332996, 0.18814820689814432, 0.2519050400171961, 0.11984159291854926, 0.11058471285338912, 0.1946801921086652, 0.17626038193702698, 0.1640382292015212, 0.22138438560068607, 0.053373391540454965, 0.08554092169340168, 0.08236463820295674, 0.14354147762060165, 0.09162555555147783, 0.13658088898020132, 0.06440393161028624, 0.11591245446886335, 0.16926961205899715, 0.1460292719836746, 0.15812624857894012, 0.20230858134371893, 0.11487084893243653, 0.10292520600238017, 0.10839391326797859, 0.15010156775159494, 0.1359262926770108, 0.10128821312849011, 0.1847856587597302, 0.1566238770527499, 0.16828306285398348, 0.10022728291473218, 0.1791789781834398, 0.08791362294661147, 0.165954181392278, 0.17954738198646478, 0.09907292521425656, 0.10711043713880436, 0.14603744154529913, 0.1704500594309398, 0.13347017232860836, 0.10344913681702954, 0.22902622339980944, 0.2297427292381014, 0.09943024854042701, 0.14594450938914502, 0.09007295207785708, 0.22027470943118843, 0.17452983265476568], [0.044248320295342376, 0.031530114356428385, 0.03342315920495561, 0.024891994394628063, 0.08977410489959375, 0.034059326497039626, 0.05342012903253947, 0.021932611408244287, 0.05307907358344112, 0.029896157926746776, 0.031163230471845185, 0.029750917506005083, 0.048822270573249886, 0.04523204679467848, 0.010654115134717097, 0.02168401992613716, 0.035757787858269045, 0.09117638572518315, 0.03257495311221906, 0.040479428068335564, 0.045587555039674044, 0.009028414779874896, 0.06444972593869482, 0.021548221320179955, 0.01348752130953861, 0.011710485593149704, 0.007413846640182393, 0.04526889803154128, 0.0626313267275691, 0.02659585859094347, 0.054685902183077166, 0.05369206890463829, 0.04561171427901302, 0.03667698907000678, 0.054072940788630924, 0.025012459805501357, 0.013895342908134418, 0.028275190353659645, 0.018010913095037853, 0.04955637760992561, 0.01851246752110975, 0.02936817965071116, 0.03500625264963933, 0.055985215319586654, 0.03640288467119847, 0.03868753582771335, 0.022476777833487307, 0.07593840267509222, 0.023166221998898045, 0.06151346742574658, 0.07710231414863042, 0.041178682153778415, 0.04904720832460693, 0.03410542955888169, 0.02523519910339798, 0.007070295030384192, 0.024630432715639472, 0.024253170637946044, 0.05398292633305703, 0.021234848403504918, 0.02346625830978155, 0.0954367442588721, 0.013529091757456107, 0.02684107605767037, 0.0207316960274641, 0.01938723656348884, 0.01532943599990436, 0.023077657911926508, 0.022595182194241455, 0.03188689485458391, 0.06717986586902823, 0.02124897380625563, 0.06559565623423882, 0.010339358006604016, 0.04640405658366425, 0.031052232320819582, 0.04952689865604043, 0.05223630934155413, 0.06081446100558553, 0.059783080991889746, 0.05804419929959944, 0.04828519992796438, 0.0393762488716415, 0.05326174878116165, 0.012186990202670651, 0.014330406839560186, 0.046555525955877135, 0.035116473878068585, 0.04761998115905693, 0.00861371198802122, 0.023332680209672878, 0.020126132361058677, 0.00932683702558279, 0.08522241057029792, 0.030154198008988584, 0.037034631307635985, 0.03253062441945076, 0.007927945482411554, 0.043948438351175616, 0.03572449553757906, 0.04000332040180053, 0.04653774155303836, 0.04662981875506895, 0.018710728668208634, 0.03914186252014978, 0.028995870878653865, 0.06150288227945566, 0.04930206947028637, 0.03359976490693433, 0.06488649214484862, 0.029697218244629245, 0.007855472853407264, 0.03631450887769461, 0.012084187906501549, 0.01081454286551369, 0.019288937195337245, 0.039024017950786014, 0.05030770247269954, 0.011138878363583769, 0.02870139346591064, 0.03275898198730179, 0.021379819106576697, 0.012135362169439239, 0.029770031837480407, 0.009294125700502523, 0.02318258147819766, 0.01981643880052226, 0.06330268963107041, 0.013885573700203427, 0.03419103353683438, 0.024787337153351734, 0.012215947532760245, 0.04912374707471047, 0.04516899732074567, 0.04759337240830064, 0.0586500700031008, 0.02014244264656944, 0.013281741146264332, 0.01541929948143661, 0.005462289172490793, 0.010451488462941987, 0.05873237630086286, 0.03175298596865364, 0.037765525480998416, 0.024685031035915017, 0.008430435438640416, 0.05999973722334419, 0.03927895712799259, 0.05537871018584285, 0.04509767311226044, 0.028502772695251873, 0.050090883392840624, 0.057397752201982906, 0.04400049216513123, 0.05228499083646706, 0.043962277072880945, 0.07132649514824152, 0.056283193973026106, 0.03220354000638638, 0.056238237635365555, 0.04133450432813593, 0.035545959403472285, 0.01808037642123444, 0.025104894934754287, 0.05994673685303756, 0.04953681544533797, 0.03567153248669846, 0.03684180861871157, 0.026549202523061206, 0.015973038339455212, 0.03027755567537887, 0.052580882994724173, 0.05820435392005103, 0.03335100379107254, 0.02870395832828113, 0.0170746755653194, 0.06336143719298498, 0.03869625161002789, 0.02923308332849826, 0.07419521228543349, 0.02277183030465884, 0.06064916987504278, 0.028390568448230624, 0.01938370818139187, 0.03427794708737305, 0.01709133868903986, 0.054705823971224685, 0.022319120221904347, 0.04192202065938285, 0.134258453601173, 0.030312649506543363, 0.031632277981511185, 0.044611021011535607, 0.034791632023240836, 0.024597418594307134, 0.05579176498576999, 0.07120790758303233, 0.03256945697856801, 0.03424451905967934, 0.07703977357596159, 0.05688867112621665, 0.05121545001332249, 0.06625948739903313, 0.0142388538058315, 0.0037744015072738485, 0.027507414409358586, 0.012315350368485918, 0.01267812487536243, 0.06124543930803027, 0.024323029210790992, 0.08711896344487156, 0.006179325964434871, 0.019082369083272557, 0.011592419651736106, 0.09781995601952076, 0.023147341762004153, 0.01778347833481218, 0.013715793212343539, 0.022157255693205764, 0.04807960042463882, 0.07785537945372717, 0.03510143414938024, 0.05187453143298626, 0.07546727545559406, 0.043029067505683215, 0.10684410535863467, 0.04790196334943175, 0.024570792880175368, 0.03149951242708734, 0.057276172297341485, 0.022161516893122877, 0.03265157328652484, 0.026895884723801698, 0.009895943005436232, 0.0410346088132688, 0.049485056794115474, 0.04738061775320342, 0.06620678558413472, 0.020192457462794015, 0.04182323274601783, 0.02777354941437287, 0.021033036821920956, 0.02689240892816867, 0.037979498106454096, 0.019884224448885237, 0.020637508581525514, 0.05276275073577251, 0.0043592257508342815, 0.024392438254186084, 0.03246880987925189, 0.026505660930914537, 0.00154028032349223, 0.061685720325580666, 0.05028364162093826, 0.028808442543127706, 0.03199914490271892, 0.051715638887669356, 0.07412569637277297, 0.05399542155542544, 0.04942662475098457, 0.01989654834116144, 0.04661691980436444, 0.06643720250576735, 0.008046219225174614, 0.07409018863524709, 0.0670810304582119, 0.04624833618955953, 0.06142612639814615, 0.011902978344421302, 0.029826418097530092, 0.040330611768045595, 0.015830132079177668, 0.06476863739745957, 0.05114935052448085, 0.03912525537556835, 0.01858310810556369, 0.02141127429370369, 0.04340631601267627, 0.005495088283039097, 0.027105669091854776, 0.01715916335316641, 0.02751354836592717, 0.02860842059765543, 0.01569601963274181, 0.017765232528160726, 0.013951197366363235, 0.059084692038595676, 0.012067875076484467, 0.05521852842399052, 0.011209270434587129, 0.03312913301799979, 0.05732609211866345, 0.01654353192342179, 0.03206784657335707, 0.0574412327259779, 0.05184686077492578, 0.0658381510792034, 0.015050546232877033, 0.013444676912123603, 0.05089784812714372, 0.023737689280616384, 0.01985872001387179, 0.026277549332007766, 0.02843810321896204, 0.04365241387858987, 0.053980252905083556, 0.028151296644604633, 0.037768592459282706, 0.01391449201452945, 0.011167459954906787, 0.03215909256998982, 0.0711966303310224, 0.05938472665314164, 0.02641869309757437, 0.01794823511902775, 0.06797450501471758, 0.019323768094182014, 0.057042362700615606, 0.020080880860665014, 0.03009759122505784, 0.03396493209792035, 0.03949717398998993, 0.039934177683400254, 0.039338739455810616, 0.05307146720588207, 0.048841873449938636, 0.006534165428352675, 0.013016332173720002, 0.047580490420971594, 0.05352898979825633, 0.03148873389831611, 0.01114363404589572, 0.10348368103482894, 0.011595517164096236, 0.012571681390649505, 0.03438119976116078, 0.020299272445429648, 0.0280276132814054, 0.002673631958064756, 0.06933151398386274, 0.014326174477381366, 0.02858975070661732, 0.018617526794384633, 0.03637213685682841, 0.04541234372715865, 0.020043495277475034, 0.022521218484533683, 0.015074939566797443, 0.03420382731461099, 0.020731020885120546, 0.021590332899774824, 0.04079100117087364, 0.13973144920808928, 0.07727256537015949, 0.14513739198446274, 0.1652120812130826, 0.1981930493244103, 0.13658650725015573, 0.1230070809168475, 0.14893569531185286, 0.10215194749512843, 0.07012355434043066, 0.09742491971701384, 0.09114313750926938, 0.15057196893862315, 0.21875389532319137, 0.060414776738200865, 0.12504370377532073, 0.09072522100593362, 0.25928693105067524, 0.10216517892799207, 0.14068403095006943, 0.13352776638099126, 0.10426797930683408, 0.1887022578822715, 0.18584019717361244, 0.11066637454288346, 0.11481025575527123, 0.12158701568841934, 0.100081988211189, 0.08254020913903203, 0.09112128189631871, 0.09029958277408566, 0.11096678235168968, 0.17364619007068022, 0.12132054141589574, 0.12422019296458789, 0.1361331915748971, 0.1864009385130235, 0.08374213892966509, 0.12983559950121812, 0.09596320600914103, 0.08114973482276712, 0.1462302676268986, 0.1285439809518201, 0.1548925270991666, 0.19899381564131804, 0.12059334186570984, 0.13622264963175568, 0.15412484614976815, 0.1475225104285138, 0.19503149682922022, 0.17810385301709175, 0.09507023356854916, 0.13739647450191633, 0.22027781712157385, 0.09986698081982986, 0.10029787769807236, 0.1136328550055623, 0.0834265590778419, 0.14937823585101537, 0.15779969681586536, 0.21373304831130163, 0.1795122338724988, 0.1398018675723246, 0.06631144961076123, 0.18305512304816926, 0.1382366908448083, 0.13685371434049948, 0.111182488634118, 0.12426820610250745, 0.14741948167128222, 0.13205069064029626, 0.11059975597475256, 0.13065217568406037, 0.10308586273874555, 0.12008175360304968, 0.11804076097905636, 0.16493044846824237, 0.15262951781707151, 0.0787791031013642, 0.12026836430387837, 0.18921042632843765, 0.19923108576663903, 0.09767970961651631, 0.1732319173003946, 0.06644936863865171, 0.1535212213971785, 0.18273246607610158, 0.14416152292064258, 0.12610025065285818, 0.1496191836361374, 0.0810689145166959, 0.16946961704109395, 0.09234090788023812, 0.19696213251778058, 0.2077147819633995, 0.10210515572024242, 0.13565772851662977, 0.05077710621325033, 0.2462910312627043, 0.11940038230802331, 0.0825926802520241, 0.12794936714427813, 0.1449479314365557, 0.09545249305665493, 0.10717964771070651, 0.06966328368123088, 0.18727228604257107, 0.13126741695616925, 0.11875752466065542, 0.14882782181458815, 0.13727393107754843, 0.09861080215445586, 0.15741420750107082, 0.11991294766111033, 0.07688423299363681, 0.15719491855374404, 0.26312999054789543, 0.11477531120181084, 0.11949551291763783, 0.1326086771275316, 0.13859878427215985, 0.06924075313976832, 0.07921584895146744, 0.10242110876632587, 0.10618764986949307, 0.1390953633402075, 0.08821998829288141, 0.06316968319671494, 0.10287510976195335, 0.0769719947129488, 0.07655403071216174, 0.12161567700760705, 0.120598987277065, 0.12630934800420487, 0.16494395131511347, 0.134364264351981, 0.12818785863263266, 0.10032228460269314, 0.14780911004969052, 0.13384142597871168, 0.07139187878263847, 0.14366130690489495, 0.1306201216897794, 0.10640110341565949, 0.22563152627221175, 0.1591467788176877, 0.16732544638216496, 0.14167250719453606, 0.13636896892317704, 0.13404018245637417, 0.06419372824685914, 0.1315566628639187, 0.10232261262301888, 0.08539289927908353, 0.09133030460881335, 0.12736574560403824, 0.24729919859341212, 0.1872712682400431, 0.09799856000712939, 0.15229958694960388, 0.133168631366321, 0.0649580911600164, 0.13070283510855266, 0.12266914333615984, 0.13721059661890778, 0.12053768842348031, 0.09043809212744236, 0.21876860596239567, 0.16316846944391727, 0.08532712887972593, 0.1303966122546366, 0.1770224039043699, 0.15893052970724447, 0.13838066240506514, 0.08185026116136994, 0.09034281224012375], [0.03952945190082703, 0.02081601757423154, 0.03762114001438022, 0.026097951290596808, 0.05280455527827144, 0.00822660606354475, 0.02020495438149997, 0.07088364926832062, 0.03404022912893977, 0.007847015762568584, 0.06394138107342379, 0.03969456321958985, 0.02823917880388243, 0.019288133131340146, 0.08031259224350963, 0.030397340854895965, 0.0870478597602674, 0.04533043097970741, 0.03334827608029757, 0.02771675433697445, 0.01651795793856893, 0.04970973330949034, 0.010825625038705766, 0.021246475101049458, 0.029534349484103065, 0.0032188166099201354, 0.02411701580110405, 0.05675348320177623, 0.014088069753987449, 0.05381439519780023, 0.057900763782007356, 0.0661268677296383, 0.0318673700094223, 0.06885503990841763, 0.0789544636915837, 0.05288090403856976, 0.020458979232768928, 0.07121733921979155, 0.011508075204411787, 0.024757405277341604, 0.021910633658990264, 0.03948519106156059, 0.0340165652201644, 0.04214645968750119, 0.05839880170034511, 0.03292181682107704, 0.025102274093244756, 0.03234328768615212, 0.017763084964826703, 0.11803915963641234, 0.043084860047591586, 0.047438557858445814, 0.03829222471852388, 0.028296341986528466, 0.034150538566921435, 0.024545814309801375, 0.02698723758969988, 0.043548991571047475, 0.03207544955824103, 0.028967165454689945, 0.0399825504448797, 0.07417402842215129, 0.03736114235860961, 0.03342573085267629, 0.01772131265274116, 0.03861893933000309, 0.025879116961732507, 0.040942239841180186, 0.09014310581343514, 0.058023449698729176, 0.018408383641924177, 0.02285749195808811, 0.013684538193047047, 0.045901862638337274, 0.015743637524013008, 0.025360217484246408, 0.05332178555961166, 0.020011375126029764, 0.06613583117723465, 0.01048001746780106, 0.0621537941374949, 0.020358995401433537, 0.031754533028496165, 0.027494585008493493, 0.054259965395820994, 0.03672903270593711, 0.024033094589997615, 0.022956318887216703, 0.022970988814319884, 0.06593467268560614, 0.022974111771743213, 0.0353714978721525, 0.06005407430763755, 0.008353360645872141, 0.011477430018463304, 0.02202611692648913, 0.032413095368870666, 0.03911648191777723, 0.06801923404314689, 0.014294064503961375, 0.04198404215276241, 0.057514670571046214, 0.03532051953620144, 0.016016332266320075, 0.04205357502879841, 0.03682775955115046, 0.035951092307056697, 0.04527685385463493, 0.05893837953252452, 0.059947951430720944, 0.07838628560836826, 0.030389666623835052, 0.05001097571636949, 0.02310914532946689, 0.03246839936556561, 0.03567902012062924, 0.05789063325417893, 0.01926426905473428, 0.0363054232937949, 0.025743930733629634, 0.048650401045701334, 0.013340651556583387, 0.020833540741088133, 0.016569891312558736, 0.05989605707249471, 0.014315289079344698, 0.023818506194012504, 0.0433298926135259, 0.04369379772937723, 0.019941460574045777, 0.04083458008244634, 0.040234697450484545, 0.022075789082529287, 0.04184302221983671, 0.030354250488536696, 0.061732953148228784, 0.04265726763488991, 0.0602807185745665, 0.029069067843790566, 0.013014361029490829, 0.027287323094372238, 0.005077415204141289, 0.025203323224559426, 0.03943643832047071, 0.06867677518831831, 0.017904456039624553, 0.027288408750402074, 0.015590565112818564, 0.09813412451850516, 0.011587876859786255, 0.07081008928694896, 0.06483457743057183, 0.019006619130128195, 0.03477803078879203, 0.06819443857031209, 0.0238746600558183, 0.03525862357180033, 0.03522576212084719, 0.04019021948001214, 0.02248503390832671, 0.024298600253782103, 0.06529790828270571, 0.04306506039574742, 0.01704017714863377, 0.05730830093047448, 0.03156896727159619, 0.03822043232087578, 0.05397451928417597, 0.0977476920400347, 0.04024044803476759, 0.026324161295113817, 0.015295828160430704, 0.03186691539095981, 0.03322403971105814, 0.033211401996335814, 0.08617079896586281, 0.026479340557541167, 0.029921942257455418, 0.024102866649627686, 0.026202939317694733, 0.045841160895568986, 0.055651474477989335, 0.03465039835178426, 0.05317838057609541, 0.022124457006741847, 0.04187073019732322, 0.047151208456073485, 0.012844387159150625, 0.012070590912896608, 0.016388607111626437, 0.014655825449153781, 0.05272612341546586, 0.038088860988084755, 0.024736077225367938, 0.029786248824426105, 0.025626666311706816, 0.03403149638324976, 0.028026037383824587, 0.02766698888236923, 0.005970397398674062, 0.12268042058816978, 0.036350444092282226, 0.04850239559475865, 0.08281705821199076, 0.04373255564964243, 0.06036500619458301, 0.037563627386199575, 0.06969738006591797, 0.0179139216031347, 0.05551314154373748, 0.009924976670715426, 0.08442291989922523, 0.05208942347339221, 0.043638941565794606, 0.027017942995631268, 0.04822624880554421, 0.032857939534421475, 0.04979980204786573, 0.06069170045001166, 0.0074690615791561344, 0.01277718335456614, 0.028723238900836025, 0.030706752823399644, 0.08996123128703662, 0.029497284508709396, 0.03278916322493127, 0.04299187021596091, 0.016859469702467322, 0.026043894101998637, 0.0318034621886909, 0.029023989369826655, 0.023583865391888788, 0.004045773530378938, 0.07298720282103334, 0.06082343802388225, 0.06621903314122132, 0.07757511734962463, 0.03823679180017539, 0.04875541451786246, 0.04037299985066056, 0.008627932385674544, 0.023508849952902113, 0.038546359831733365, 0.03650609324020999, 0.10088311415165663, 0.03746783859761698, 0.037235179117747715, 0.011657613296327847, 0.0374910207465291, 0.033420984500220845, 0.0074327625001647645, 0.038705279518451007, 0.04641827189230493, 0.034340348560363054, 0.033230075280049017, 0.008791446602637214, 0.011520342269380177, 0.02859905342172299, 0.07325118687003851, 0.08145248357738767, 0.05976615832852466, 0.06534014708761658, 0.02558420189390225, 0.05075984088970082, 0.015279628136860473, 0.08878469906215157, 0.02219086862169206, 0.014709236333146691, 0.02731531436022903, 0.03257438653547849, 0.018473451757537465, 0.018581094552895853, 0.005604969395790249, 0.02742614796651261, 0.039689277431794574, 0.004696136623221848, 0.02195799709962947, 0.04170181229710579, 0.011730506617043699, 0.059373591893485615, 0.015415623517973083, 0.04198505995529039, 0.008554730331525207, 0.025192724507568136, 0.013830448667119657, 0.026886220688798597, 0.07086572237312794, 0.01585265265644661, 0.029811927982206856, 0.03955088682206614, 0.029169779403933456, 0.029797057887273173, 0.08714187078710113, 0.04936592640089137, 0.005951714361019964, 0.0051210004769797835, 0.028520859046173946, 0.014341438122625862, 0.04098016655604754, 0.005987750931775996, 0.0361480370962194, 0.0358039994857141, 0.02756214843663786, 0.03427768585139087, 0.0752105178045375, 0.014045042152117406, 0.07506267180932419, 0.03325705383239048, 0.0713731919282249, 0.023019658434869986, 0.05716846164848123, 0.02157822953137968, 0.025335091332505857, 0.03483336192688771, 0.02912541339173913, 0.058774404759917936, 0.029067982187760726, 0.028957967912512164, 0.02436295081861317, 0.04772333222042237, 0.006120543203516198, 0.005631828356334674, 0.05608488872115101, 0.027914552383923104, 0.04828337127608912, 0.04061712996502008, 0.03941679473168083, 0.03906442131847143, 0.028210096792983155, 0.026224654134629027, 0.03847457421943545, 0.05690759886056185, 0.03101775934919715, 0.02455992274917662, 0.025729277769901922, 0.012850297199163054, 0.04240477118375046, 0.026642741968056986, 0.11228569836488791, 0.04974072539646711, 0.06349790415593556, 0.09410707346562829, 0.03274772169866732, 0.018535958403455358, 0.10414232140673058, 0.043703531314219744, 0.04081773205793329, 0.04959496928911124, 0.05999691451766661, 0.028283795874033655, 0.04800245777836867, 0.014704613813332148, 0.11511338448950223, 0.0882652330079249, 0.09085464477539062, 0.09001463199300425, 0.10989048331975937, 0.15095402486622334, 0.18554271385073662, 0.13548422711236136, 0.11760489722447735, 0.16366398999733583, 0.13127866706677846, 0.13206792542976992, 0.08041218082819666, 0.0977539142061557, 0.1929094192704984, 0.09395075935338225, 0.09600532267774854, 0.15111500051404747, 0.15334698717508996, 0.19206629879772663, 0.08124749814825398, 0.1463196985423565, 0.10838275136692183, 0.06507741154304572, 0.20697450025805406, 0.12158579432538577, 0.08562411687203816, 0.17680061794817448, 0.1272088818784271, 0.15996864757367543, 0.10748597234487534, 0.1957306864538363, 0.10067694807159049, 0.15460596819009098, 0.12812897536371434, 0.1350161600857973, 0.10187673369156462, 0.11896656772920064, 0.11423426094864096, 0.18413767138762133, 0.08425963044698749, 0.1147529873996973, 0.11402922123670578, 0.10921635877873216, 0.09984600730240345, 0.11247959653181688, 0.07654425302254302, 0.12068988382816315, 0.06237721536308527, 0.15660016903919832, 0.1408991536923817, 0.13889938885612146, 0.13564854115247726, 0.09178380348852702, 0.10050373165202992, 0.0735630551353097, 0.08835468427943331, 0.16689600156886236, 0.21140115415411337, 0.11438617136861597, 0.15185296162962914, 0.09328372550329991, 0.14570072532764503, 0.10536881416503872, 0.15371292111064705, 0.10993124291832958, 0.12739511259964534, 0.1433995823775019, 0.16895611530968122, 0.13565842062234879, 0.07897792743252856, 0.11774907234523978, 0.09769750759005547, 0.0929496284308178, 0.09608826001307794, 0.0853832708671689, 0.1993612287832158, 0.14175448779548916, 0.10147434885480575, 0.09345960178013359, 0.12703456623213633, 0.09926384461245366, 0.10496266345892634, 0.11218308351401772, 0.18036458242152417, 0.14747704858226435, 0.11585335406873908, 0.07554318995348044, 0.16113184658544405, 0.1651045876954283, 0.06892953626811504, 0.08908697284225907, 0.16524200460740499, 0.11522979395730154, 0.07892292538391692, 0.12903532172952378, 0.10898549402398722, 0.14183101297489234, 0.13423959032765456, 0.04462464938738516, 0.1276843042245933, 0.12833982333540916, 0.10659452660807542, 0.08346780043627534, 0.18635549023747444, 0.13990192434617452, 0.09345861790435654, 0.16638791454689844, 0.08628642133304051, 0.17046339942940644, 0.2471042690532548, 0.10878841352782079, 0.17869637693677629, 0.13684253208339214, 0.07974638191184827, 0.17412998553897652, 0.2463656429733549, 0.13420605712703296, 0.12344313466123172, 0.07675173546054534, 0.13271754128592356, 0.20410956256091595, 0.15393358069871152, 0.06906044602926288, 0.09321760905108281, 0.13049185142985412, 0.07475207918988806, 0.11052720701055867, 0.12134621718100139, 0.10338578200233833, 0.22563481038170202, 0.13974245504609176, 0.1753157526254654, 0.15308743395975657, 0.0895745273945587, 0.09118098619260959, 0.15580989287367888, 0.1812860601182495, 0.13061311920838697, 0.13893569047961915, 0.11424773665411131, 0.11279025700475488, 0.1549028679728508, 0.11276832675295216, 0.17714440450072289, 0.12228658529264586, 0.15368442263986382, 0.1013561887666583, 0.2327644628073488, 0.12478571119053022, 0.1803371696067708, 0.18305814931435244, 0.1845551332724946, 0.10591279568948916, 0.17412956484726497, 0.3077588943498475, 0.13562069407531194, 0.08347211591899395, 0.09623874550951378, 0.0614907161465713, 0.15608702014599526, 0.16870177324329103, 0.2933676008667265, 0.12160005713147776, 0.1504342941833394, 0.20650817028113774, 0.1158313559634345, 0.1523847295237439, 0.30500993185809677, 0.10362048047993865, 0.1217665153422526, 0.08903391140380076, 0.15105562869991573, 0.12011044206363813, 0.16036761259394033, 0.17205141564565046], [0.017058351709108268, 0.0009661977133613878, 0.02130857462595616, 0.04818565205537847, 0.053067653839077265, 0.09839404414274863, 0.06212513281830719, 0.023329976247623563, 0.04250231059268117, 0.07623138052544423, 0.03284023316310985, 0.029637137361403023, 0.013134666136465967, 0.023397797519075017, 0.02380982264211135, 0.02362320854860757, 0.02322655394008117, 0.03529551212808915, 0.02132600449424769, 0.016929983061605265, 0.009405950816082103, 0.009221627626435032, 0.05159532445083771, 0.038107965141534805, 0.0255149217721607, 0.03353032363312585, 0.06724286106015955, 0.037452561381672106, 0.06582928941185985, 0.04620801763875144, 0.046543064660259655, 0.03457117260300687, 0.0438510007224977, 0.014820173416020615, 0.019886002210634093, 0.05431551027244755, 0.028698896457042013, 0.018820709016706263, 0.038608917367777655, 0.009095297128494297, 0.030691726665411676, 0.0426556154021195, 0.01889620621555618, 0.035632001036512, 0.037927284836769104, 0.06650200260004827, 0.01794749721219497, 0.013533481879026761, 0.055866383481770754, 0.05298011603632143, 0.026386956318414638, 0.022294406280187622, 0.038080389478376934, 0.01676336539510105, 0.039809754717030695, 0.04845411104283162, 0.03297022690198251, 0.018088260998151133, 0.07254389553729977, 0.026923482439347675, 0.017354896957320825, 0.03124331117474607, 0.00828473870309868, 0.07223803230694362, 0.02221180821236755, 0.0469380873920662, 0.04392321041918226, 0.012068674051468926, 0.03665191041571753, 0.02743807661214045, 0.024248168138521056, 0.05225469085520931, 0.02410148922353983, 0.03734042329181518, 0.05683189470853124, 0.002246436700391184, 0.043131994482661994, 0.045785090154302974, 0.01890344957688025, 0.0050505282540273455, 0.008382920175790787, 0.0481287060039384, 0.06278878756399665, 0.037579081021249294, 0.02137097779528371, 0.03185812496979322, 0.060554378532937596, 0.022533130166786056, 0.04223504243418574, 0.05716808845422097, 0.009343877584407372, 0.0543235203783427, 0.00724092623152371, 0.026050713378936052, 0.014600536719496762, 0.0332231033327324, 0.03908987655969603, 0.01906069497843938, 0.01956499068598662, 0.019297144076387798, 0.009643575475950326, 0.038133986959499974, 0.008786458522081375, 0.015994714140625935, 0.04368822017152395, 0.02196237025782466, 0.01380639460070857, 0.027321914809622934, 0.034259589322443516, 0.024499770619773438, 0.04257663053327373, 0.03815800370648503, 0.016247212288102934, 0.06118553823658398, 0.049860011852745495, 0.04270203059007015, 0.020551086968875358, 0.021409922312679033, 0.02443271439655551, 0.024000647045405846, 0.036187029111066034, 0.052437505152608664, 0.0132196806371212, 0.02885016905409949, 0.015309159677209598, 0.024458569973441105, 0.03837775405762451, 0.04971209121868014, 0.019700631532551985, 0.02962732913770846, 0.01584644745370107, 0.02404830734511571, 0.02796380893726434, 0.016295646117734056, 0.07246759427445275, 0.024769467933635627, 0.050243445206433535, 0.020078375370108655, 0.015954767087740556, 0.01567658130079508, 0.057855559779064994, 0.056640391770218096, 0.05658008697043572, 0.06585723826927797, 0.025710860633158257, 0.029463462930704867, 0.014880295011347957, 0.0429075859886195, 0.036096020601689816, 0.022966515572209443, 0.03148784501744168, 0.09266836209488766, 0.0428510572362159, 0.046312566314424784, 0.06171341812504189, 0.022174220765009522, 0.07229340076446533, 0.0407461398281157, 0.0135915602357792, 0.02088052929112954, 0.04372694416503821, 0.029923021128135066, 0.02859891771471926, 0.0253907447747354, 0.04821859493053385, 0.06006988417357206, 0.052654480295521874, 0.0023804089869372547, 0.032521223316767385, 0.004512206135716821, 0.054975321117256365, 0.03960192622616887, 0.05505699977012617, 0.041108226470117054, 0.02165284293836781, 0.03220866973112736, 0.07538067403116397, 0.009605939682972218, 0.04192421572016818, 0.06079259182193449, 0.020196969720668027, 0.0353150200098753, 0.055415344291499684, 0.03678277607208916, 0.030151904560625553, 0.03883539878630212, 0.10050277491765362, 0.015542139764875174, 0.05885061102786234, 0.04610430356115103, 0.044055331365338395, 0.05159167732511248, 0.02927550194518907, 0.03504447113456471, 0.018688990102548684, 0.0480087715467172, 0.08668683163289513, 0.061894417341266356, 0.06719304301909038, 0.051892237804297886, 0.04454088763200811, 0.006359046990317958, 0.029098964096712213, 0.028561588110668317, 0.04757834625031267, 0.03882571609158601, 0.0025392570033935563, 0.055123672621058564, 0.05596064556656139, 0.011149712023325264, 0.03415236721879669, 0.052638894346143515, 0.03677164809778333, 0.019383993166099702, 0.008180251943745782, 0.060034077880637984, 0.05311872038458075, 0.0502013929986528, 0.04843447423939194, 0.0424570115948362, 0.0097424889182938, 0.01545312614845378, 0.0319255068898201, 0.010207812967044967, 0.02176571893505752, 0.04656092030927539, 0.030208480810480456, 0.03195079928264022, 0.026067649613001516, 0.06979290422584329, 0.04285271964701159, 0.030627818844680275, 0.028403545430462276, 0.03948957100510597, 0.019331918996093527, 0.022730475291609764, 0.058718622396034856, 0.045074107591062784, 0.04576110054871865, 0.11410322226583958, 0.02365769848360547, 0.0677292010347758, 0.0248215421036418, 0.021993730450049043, 0.02211542909831873, 0.011622891811254834, 0.02937233228502529, 0.048820679408631155, 0.027379435919491307, 0.007605379264402602, 0.03989391341539366, 0.02244926493481866, 0.014266975689679384, 0.1127444626763463, 0.022402557976809994, 0.028207109542563558, 0.002814990098288815, 0.03987669898197055, 0.03218135530395167, 0.030149835028818676, 0.07506766582706145, 0.004580620701225209, 0.049308278065707, 0.10694520029106311, 0.012749893524284874, 0.07153834735176393, 0.03116351206387792, 0.06461964467806475, 0.021029964754624025, 0.017457347263449004, 0.08001274083341871, 0.035318456789744754, 0.004627342502187405, 0.08357238982404981, 0.023965943371877074, 0.0670578381312745, 0.047739915616278134, 0.04513270587527326, 0.033184046857059, 0.039513801490621905, 0.008367471629753709, 0.057099251076579094, 0.05372912370200668, 0.021774682382653867, 0.06792269208069358, 0.032841030441756756, 0.03903836557375533, 0.04153313866949507, 0.07759422489574977, 0.035528297136936865, 0.1076951375497239, 0.02865409278976066, 0.028528404355581318, 0.051304446666368415, 0.007693448020810527, 0.01570116462452071, 0.009189014688932469, 0.012590180799764181, 0.03625618200749159, 0.03374296972262008, 0.02194158673020346, 0.056028936723513265, 0.031163915792214017, 0.04233130619728139, 0.07180311171604054, 0.043184679334184954, 0.03095006869573678, 0.03296635925237622, 0.013365040649659932, 0.03335876623168588, 0.031187101333801235, 0.04261027229949832, 0.021047028214005486, 0.034035191006426296, 0.00990125847913857, 0.06274337321519852, 0.06486667892230408, 0.015160677555416311, 0.03327061774741326, 0.07572840965752091, 0.031055122879999023, 0.02112284941332681, 0.01312362467537501, 0.05328921927139163, 0.031807655535106144, 0.033502975279199224, 0.06319749634712934, 0.0715777702363474, 0.010292336377980453, 0.03678136471925037, 0.050221107833619626, 0.06873687303492002, 0.003973765273778034, 0.019549570977687836, 0.04439602379820176, 0.006798532425558993, 0.04731835537989225, 0.031529612240514586, 0.019965360273740122, 0.045254394345517666, 0.03674745832436851, 0.03622377856767603, 0.042964657569038014, 0.027973720637549247, 0.03548056898372514, 0.03757063326026712, 0.04219286469742656, 0.04521033367408173, 0.0358314089077924, 0.050056630945099254, 0.03540180463876043, 0.05342012224718928, 0.09293551490242992, 0.12422315137726919, 0.16563529707491398, 0.1079246113076806, 0.15828512076820644, 0.17694351742310183, 0.12921387143433094, 0.18593834047870977, 0.09777644835412502, 0.21779351042849676, 0.1271115799567529, 0.08038352629435913, 0.1604299156793526, 0.08924564147101981, 0.11480526173753397, 0.14554075391164847, 0.14427619533879416, 0.12434768969459192, 0.1158959117851087, 0.12075228190847806, 0.15374253237886087, 0.15543937204139574, 0.14713365558002675, 0.11050376362566437, 0.07805797643959522, 0.109806528181902, 0.15347221759813173, 0.12015511680926595, 0.15347722518656934, 0.13457098683076246, 0.140181711475764, 0.14606477293585027, 0.11009133647062949, 0.14233751222491264, 0.07935234984116894, 0.1912394088826009, 0.12434824609330722, 0.12340208329260349, 0.10439339971968106, 0.0911336380190083, 0.14855514573199408, 0.1631172943328108, 0.10132455546408892, 0.09503317198583058, 0.11995703886662211, 0.13347304931708745, 0.18806239935968602, 0.10840872568743569, 0.08857385109045676, 0.16922238602169923, 0.11619541714234011, 0.09361810756048985, 0.14359730748193605, 0.17743822373449802, 0.07930876075157098, 0.07759134790727071, 0.09622818750462361, 0.1353337009038244, 0.21982391790619918, 0.11307457674826894, 0.20593640953302383, 0.1675236193197114, 0.13728291488119534, 0.21976845445377485, 0.14300893619656563, 0.14762304217687675, 0.11326599147702966, 0.060069382057658265, 0.15521731467119285, 0.06440710036882333, 0.10540243557521276, 0.14616404260907853, 0.16794745943375997, 0.11565193773380347, 0.18305444451315062, 0.1980396189859935, 0.10727748567504541, 0.18775545725865023, 0.1281969781432833, 0.14374122475939138, 0.06930230305130992, 0.13741931399064405, 0.0989498593179243, 0.10257158069206135, 0.12664166731493814, 0.07670469941305262, 0.174070003043328, 0.1897369966443096, 0.09861678683332034, 0.1900556366890669, 0.10432948850627456, 0.1413461725626673, 0.10786177217960358, 0.06912702388529267, 0.2040695154241153, 0.1573083017553602, 0.10459703486412764, 0.15856800201748097, 0.07600860390812159, 0.09291482636971132, 0.12374980534826006, 0.09641726807292018, 0.08078429621777364, 0.14121099481625216, 0.09475400910845824, 0.09849483373441867, 0.17853344710809843, 0.14177655375429563, 0.14381346159747668, 0.15193913557699748, 0.08988252801022359, 0.11269415609006371, 0.1712204273790121, 0.1226905986134495, 0.18872291248823914, 0.17684564553201199, 0.08334302463169609, 0.1498077078057187, 0.11366151632475001, 0.08290974609553814, 0.07808313651808671, 0.12750103191605636, 0.08355752312179122, 0.10120155742125851, 0.07059504118348871, 0.20192492407347473, 0.1242939904332161, 0.11644997633993626, 0.13512121087738446, 0.09178795612284116, 0.11652445234358311, 0.1017498272870268, 0.13207585071878775, 0.09481087034302098, 0.2014854233711958, 0.07594321348837443, 0.08052031216876847, 0.08295950306845562, 0.25456468015909195, 0.08972133523119347, 0.15405389852821827, 0.16439296730927058, 0.15064838555242333, 0.15494615850704058, 0.11326766067317554, 0.11485722394926207, 0.11085998772510461, 0.1888061687350273, 0.09363142041755573, 0.08058543795985834, 0.180708857519286, 0.1714697889983654, 0.12291227600404195, 0.137756898733122, 0.1456837212400777, 0.18638071816946777, 0.14586090030414717, 0.0927340646407434, 0.10976120204265628, 0.08669221241559301, 0.11718253631676946, 0.21883635089865752, 0.11898977362683841, 0.1569135029401098, 0.09282104604478393, 0.1596204505435058, 0.11125729711992399, 0.057915467635861466, 0.09675134478935174, 0.08582212017582995, 0.13382199273577758, 0.20991193263658456, 0.14997523810182298, 0.10086966558758702, 0.0857180804014206, 0.107611345260271]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02384774257162852, 0.024434057895892432, 0.05534148236204471, 0.05237494422388928, 0.018393218384257386, 0.02441674337855407, 0.036935636441090276, 0.03226087282278708, 0.05252823206995215, 0.04411634184154017, 0.04514923838100263, 0.020890692049371343, 0.02593398160700287, 0.05819790783737387, 0.07904450528855834, 0.051253244413861206, 0.017009503973115767, 0.1339049775685583, 0.03569841604413731, 0.052957934726561816, 0.05540998725752745, 0.03482442222801702, 0.011553055290797991, 0.05198935652151704, 0.040452880385730944, 0.05327822361141443, 0.011357395477326853, 0.03344082147149103, 0.03460652767015355, 0.019894066599330733, 0.05072623983557735, 0.04775510462267058, 0.07355820360992636, 0.048762780015489886, 0.09449090036962714, 0.011012831154013318, 0.0529922312790794, 0.08887877115713698, 0.031530524870114665, 0.02873791561328939, 0.022384476714900563, 0.016420281126296947, 0.006887233491787421, 0.03903830450560365, 0.03512262479801263, 0.045782342087477446, 0.023203439644670913, 0.0333437909638243, 0.003188687322628019, 0.03374798748908298, 0.01741832641086408, 0.01710795601164656, 0.018503668618255427, 0.0394695270806551, 0.04188894886257393, 0.04184846067801118, 0.04963209193998149, 0.04600156657397747, 0.062488888656454425, 0.04557866623092975, 0.048502534694437466, 0.059165593768869124, 0.08113377567912851, 0.0072122521898044, 0.05295897627781544, 0.013496292222823416, 0.03288781203861747, 0.04669844239417996, 0.03996189244623695, 0.05788156802632979, 0.01672181869590921, 0.012732176974947964, 0.026870573671268563, 0.018736596119457057, 0.014194575155020824, 0.05719548091292381, 0.03416044178551861, 0.050687953497150114, 0.027233145465808253, 0.09712248987385205, 0.015959788246878555, 0.10097439068236522, 0.08937687014362641, 0.018476059028346623, 0.0400044399845813, 0.011426260844538254, 0.036438816493110995, 0.04142419647957597, 0.012584745734264808, 0.0342847019034837, 0.02974485818828855, 0.048628698103129864, 0.01367311760051442, 0.02408089059671121, 0.05551391846633383, 0.018339763395488262, 0.06977689079940319, 0.049179916203554185, 0.014071320117052113, 0.02184983861765691, 0.02513942218917821, 0.0619500232860446, 0.03683717083185911, 0.01793453380066369, 0.03931177108149443, 0.026215919692601477, 0.06620687379368714, 0.027770701263632094, 0.03500244946085981, 0.033666848271553, 0.019406639272347093, 0.0051628283441199786, 0.018477117542975714, 0.03689216948779566, 0.05679782207256981, 0.04709344816261104, 0.04706485808960029, 0.038246213258909326, 0.023634439999503747, 0.030691119376569986, 0.014990964072889515, 0.027952365444174836, 0.05490388834316816, 0.04445177562800901, 0.04387832193502358, 0.041065054679555554, 0.019326548391420926, 0.03095297621829169, 0.0679598350876144, 0.07340527538742338, 0.044500572473875115, 0.022592376451939344, 0.01918771503759282, 0.013128455844707787, 0.027343305626085827, 0.06270336000514881, 0.02802078552278025, 0.028372840024530888, 0.03946091986394354, 0.007519335935025343, 0.00904995487404189, 0.05286528416244047, 0.10016230640134641, 0.034317895836595974, 0.05330150414790426, 0.026113625449527587, 0.07982083755944457, 0.053973433628146134, 0.0273851118649223, 0.014772876132545727, 0.026480090338736773, 0.03487301890605262, 0.041844355541148355, 0.007544506191542106, 0.0487807442301086, 0.042874117248824666, 0.044744536347155056, 0.02212828733692212, 0.0629703431789364, 0.032034974944378646, 0.03731550070058022, 0.027360379263492565, 0.02902193001604506, 0.020038136547165256, 0.040659229670252116, 0.02523638484334307, 0.021475044711093818, 0.023689124832994173, 0.05511009852801051, 0.06996168981173209, 0.048970415123871396, 0.011729377704406423, 0.04020648057173405, 0.03844767709129623, 0.05488216504454613, 0.03245053353852459, 0.03728753827246172, 0.11743660696915217, 0.13828823236482485, 0.05618843995034695, 0.02386978647804686, 0.03529063006862998, 0.024332881539261768, 0.02828702570072242, 0.030150221793779304, 0.03521159430965781, 0.03877765545621514, 0.016195587647546614, 0.032174607273191214, 0.04458721800308142, 0.07725125258522374, 0.021098366173516427, 0.035385987987475734, 0.08252553921192884, 0.036178951151669025, 0.03196940132017646, 0.026483211599822556, 0.04355178713532431, 0.029104300774633884, 0.058915797887103896, 0.03875607804262212, 0.03704790684527584, 0.053255160206130574, 0.03045989839094026, 0.019350264886660234, 0.012238386685826948, 0.045148434317005534, 0.04164032006104078, 0.015767415087403994, 0.05662650215838637, 0.04524948514465775, 0.023706512292847037, 0.050703095006091256, 0.05790486891887017, 0.023023556618552123, 0.03572622240920152, 0.009422783573557223, 0.009592544553535325, 0.06574356329760381, 0.054395255100514205, 0.02512992269891713, 0.015663511019998362, 0.07968993458364691, 0.006754405596958739, 0.029394554306886027, 0.020045732746699026, 0.09339179577572004, 0.031188115743654113, 0.053455786047769446, 0.008533790740849716, 0.029869091164852892, 0.05976275208273104, 0.018052527647731558, 0.02134218585810491, 0.043529979019824944, 0.08772598765790462, 0.029304550029337406, 0.03019868615748627, 0.026224347097533088, 0.017337299151612178, 0.08011611564350979, 0.03571603759857161, 0.028874138303633248, 0.02100285728062902, 0.04296670674479433, 0.04212952345343573, 0.046011785311358314, 0.014557712678132313, 0.018709415702947547, 0.015655126023505415, 0.031271745184702535, 0.022060905416895236, 0.014878027008048125, 0.029239129075514417, 0.03177460070167269, 0.03328768629580736, 0.035311647690832615, 0.042091912257352045, 0.09644839925957577, 0.039622753858566284, 0.016978382964485457, 0.07041462550738029, 0.011540853534825146, 0.01739362603984773, 0.07623178764645543, 0.03306508609758956, 0.02281614881940186, 0.05042020357879145, 0.034933435664113076, 0.0193717931064644, 0.0213785892618554, 0.02406904167894806, 0.052817403338849545, 0.0284061696646469, 0.037530928783650906, 0.02073797756539924, 0.004480250953097961, 0.003346299981265994, 0.034418020463947735, 0.04987867835110851, 0.021016741803448116, 0.017507530017090694, 0.06848673788564545, 0.0428886582542743, 0.06357102308954511, 0.03433825188715543, 0.004511314710336072, 0.014144796977884002, 0.01584308022367103, 0.04718160343223384, 0.027480992255732417, 0.04079800704494119, 0.05843532724039895, 0.03441386104428342, 0.07833224029413291, 0.044508725072124174, 0.04870934538277132, 0.03238502776782427, 0.022221314487978816, 0.017519585888034532, 0.0812134560463684, 0.031180736675326313, 0.015958521082731228, 0.02160228868680341, 0.010190129496290215, 0.07444614132067987, 0.040684332073267014, 0.03938269156164356, 0.010759632419129568, 0.004680508689489216, 0.059779939374753406, 0.015702426699655395, 0.035378934615956883, 0.02643125786978219, 0.01326377353897052, 0.018869916376258646, 0.036839250541691265, 0.07255146798810788, 0.08150802845401423, 0.05387356345142637, 0.06634664522217852, 0.02585958533122071, 0.09411694615014962, 0.042714576702564955, 0.041198210391615114, 0.029024209893707718, 0.02328316411668701, 0.07068343394036804, 0.03819872937830431, 0.028154166847733513, 0.023336625890806317, 0.051486473863146136, 0.012329766693125879, 0.045235629459576945, 0.03948266012594104, 0.01964827237783798, 0.04953418272946562, 0.024467552080750465, 0.0608672917421375, 0.012341870909689792, 0.05681987785335098, 0.04666378961077758, 0.037132252140768936, 0.034178925079426596, 0.03993682057729789, 0.06786513195506164, 0.026445323900718774, 0.08110915842865195, 0.06026915633784873, 0.04554895996781332, 0.04401450730594141, 0.04389619115473969, 0.12741949914821557, 0.16112974312688622, 0.19627331090824945, 0.14600533326821669, 0.07274761889129877, 0.12426663190126419, 0.11081958096474409, 0.18396148298467907, 0.07286204025149345, 0.11600207537412643, 0.12991760724357196, 0.06513434063111033, 0.13896436536950724, 0.13032311334141664, 0.135169224015304, 0.13721956685185432, 0.16201808117330074, 0.20270479151180812, 0.12807835665132317, 0.11457795250628676, 0.1912845450320414, 0.11107046250253916, 0.1079844580963254, 0.1356065534055233, 0.05624611881960716, 0.11225627030112914, 0.0989252013553466, 0.0954541622528008, 0.12021565570362977, 0.0746830382517406, 0.1730449537613562, 0.09112056943454913, 0.1331110101725374, 0.112790698052517, 0.12326393356280667, 0.11550943180918694, 0.117996357647436, 0.16005678927259787, 0.06344027617680174, 0.10848751038845096, 0.06369284726679325, 0.05157056810068233, 0.13722192815371922, 0.1286877082394702, 0.16797282307275704, 0.08766900428703853, 0.14213387029511587, 0.0924376059057457, 0.07347441810582366, 0.14878552194152558, 0.13255891336926393, 0.09759641944297723, 0.1781316865235567, 0.11189172057701008, 0.10269827675074339, 0.14667742220418795, 0.1605899278074503, 0.11846043488809041, 0.09303729515522718, 0.2008726926786559, 0.10237437127424137, 0.14766535562063965, 0.136607148285423, 0.060791031191391606, 0.2647589088550636, 0.08713261556944676, 0.09031677685145821, 0.10354587555463825, 0.12916819245687552, 0.0937627712264657, 0.1313970714275326, 0.2031585414494787, 0.11151067566658769, 0.07947558537125587, 0.09386238695255347, 0.12612059313271726, 0.11973509006202221, 0.10708071051963738, 0.0913356514647603, 0.3262734551514898, 0.1175963883953435, 0.1762482225894928, 0.2325391891811575, 0.2128557703856911, 0.08658095981393542, 0.13623080562267983, 0.1350264059645789, 0.13114164370511258, 0.13964994358164923, 0.18281186824398382, 0.11603554072124617, 0.11398274158792836, 0.08044031289006982, 0.1255590104098831, 0.07198405664946352, 0.16234691281403812, 0.10156133704419647, 0.09327346605381795, 0.1427281176937478, 0.1017941627651453, 0.06032067071646452, 0.14012757795197622, 0.06701928377151489, 0.1380091780530555, 0.20908018441072532, 0.16055359904255184, 0.21751288191548415, 0.11956309500549521, 0.14070821393813404, 0.1456400914383786, 0.09178636835089751, 0.0938222583915506, 0.08269429087106671, 0.14554956129619054, 0.12951108334319933, 0.11554292429770742, 0.10716700660330908, 0.1258194050086396, 0.13334141352346965, 0.12167164257594518, 0.11154333355703525, 0.06860588184956994, 0.13113377269889626, 0.14819212949701718, 0.14327307630862507, 0.14486867854637758, 0.09334825418357338, 0.10689049679785967, 0.14517171228570597, 0.1507356587265219, 0.12058560656649725, 0.09026446180152041, 0.0769938842526504, 0.14431128916995867, 0.1779042687267065, 0.11405309209866182, 0.12054937279650144, 0.15940630489162036, 0.094566177044596, 0.09528450135673795, 0.14321027110729898, 0.1794971161122833, 0.1883782438401665, 0.142343564757279, 0.1403826799775873, 0.18510306387075356, 0.17932053415903024, 0.2368956282734871, 0.1352828379188265, 0.10880890528538398, 0.09875769820064306, 0.12546759817217076, 0.11600595659443311, 0.12682484462857246, 0.2210486057613577, 0.2107524611055851, 0.15155702536659582, 0.05916925785796983, 0.11738349124789238, 0.0753768878057599, 0.07938772187169109, 0.1423068560127701, 0.11105045250483922, 0.13246919746909822, 0.06453530277524676, 0.10344583913683891, 0.11856460358415331, 0.06318115722388029, 0.10464850174529211, 0.14272437218044484, 0.1629819401672908, 0.1551948958741767, 0.10191543732902833, 0.10652891905712229, 0.13250548552189553, 0.14817037566431931], [0.03483966890988605, 0.01709499429645283, 0.01710179152100214, 0.05752730489309345, 0.02511096273415855, 0.040304756191159995, 0.019697152344243865, 0.003864910021158201, 0.025248411876548613, 0.06375988652663571, 0.04418544384783932, 0.006997998396400362, 0.05085260680477534, 0.02761265858342605, 0.0633908991834947, 0.05413202761805483, 0.019858002463089566, 0.015456091346485274, 0.05280951536925776, 0.02801156253553927, 0.04197724323187556, 0.015363371232524514, 0.0037863967341503924, 0.04622807852657778, 0.15318427447761807, 0.06949749043477432, 0.04078050084146006, 0.030339963933719055, 0.07111748600644724, 0.08467168440776211, 0.02033335356307881, 0.0862187035381794, 0.012257400933387024, 0.04993913582127009, 0.07281119083719594, 0.0421028807759285, 0.036291852593421936, 0.03598964327414121, 0.03864295268431306, 0.059973505059523244, 0.03208265560013907, 0.018295080168172717, 0.08903403354010411, 0.017595744658527628, 0.03328919603622385, 0.02911825823996748, 0.02092070534958371, 0.03211797334785972, 0.018123831500166228, 0.020880218861358504, 0.11217629137848105, 0.019661390156086003, 0.0466063482287739, 0.05516143988019653, 0.04132932371326855, 0.027282853244936893, 0.023110461687403064, 0.03264791937544942, 0.07274989876896143, 0.06907143829656498, 0.09482526207076651, 0.028806579964501516, 0.02057581448129245, 0.014865636958607605, 0.03274819667318037, 0.03902661334723234, 0.03052476973139814, 0.039602194247501235, 0.025918955449014902, 0.027730175759643316, 0.09035626758954354, 0.028048252620335137, 0.03029155046013849, 0.04486698138394526, 0.028933510117764984, 0.009916508553682693, 0.0239478824660182, 0.01738808919409556, 0.06294852827808686, 0.012609059340320528, 0.023054871009662747, 0.07963081382747207, 0.019846984750724266, 0.011420824930870106, 0.03001263185537287, 0.018109678956014768, 0.02872828720137477, 0.029561714801405157, 0.01630167829404984, 0.023860595721219267, 0.10069651023617812, 0.009293833930444504, 0.06636245508811303, 0.05338408525234886, 0.03319222320403371, 0.04266097582876682, 0.05134251926626478, 0.074606825198446, 0.018941417003848722, 0.016739601402410438, 0.038586335722357035, 0.04469083708577922, 0.06309292053005525, 0.04006543010473251, 0.022817471962688223, 0.04122355367456164, 0.012563625483640602, 0.037496601697057486, 0.03636674250343016, 0.07226066144981555, 0.06505793080266033, 0.0040665816548945645, 0.04070652016837682, 0.02196466879520033, 0.026591877286721553, 0.03561605207089867, 0.0653174975886941, 0.026391375277723585, 0.013094781848069812, 0.04003820049443415, 0.06221539154648781, 0.06940505360918385, 0.0063215240037867, 0.028343795333057642, 0.028479207174054215, 0.0194941143106137, 0.033881923516413996, 0.04916948372764247, 0.008535063842178454, 0.033567049341010194, 0.06648784157420908, 0.011666316356110786, 0.036345785949379206, 0.07174150073634726, 0.016736315596582632, 0.02666797159638788, 0.04613081053165453, 0.03282126471666353, 0.02421620405013008, 0.0380451633328838, 0.04604971541890076, 0.0583195352394666, 0.02393515993441854, 0.024394904728978872, 0.03694815541218434, 0.07934366459293024, 0.024761583356718932, 0.02903516823425889, 0.019522748488400663, 0.009729661213766252, 0.03343459252001984, 0.033756431857390065, 0.017789425694250634, 0.034130379291517396, 0.06054362375289202, 0.04290952320609774, 0.05110289801710418, 0.017150907278327004, 0.05281881129901324, 0.053300079224365096, 0.045334200241736004, 0.022855966950633695, 0.018275304265054207, 0.011433177660884601, 0.024052722911749567, 0.017660797507103, 0.025273351431159035, 0.00744170304720423, 0.04348692597289171, 0.05461304787812488, 0.04595505299844912, 0.027288169566808, 0.030977712212396518, 0.02555757448343294, 0.029070163677845682, 0.060419065079518726, 0.02118374962758805, 0.029500283633491824, 0.031265679081635814, 0.04197931615635753, 0.1076110942023141, 0.04824199081797685, 0.029443137414221252, 0.044660367470766814, 0.015725931152701378, 0.02868254037041749, 0.0315826702862978, 0.01248971011955291, 0.09293684483106647, 0.026006930906857764, 0.04251061586130943, 0.04683925198124988, 0.016520385397598147, 0.033732991865170855, 0.047338358592242, 0.07060857795711074, 0.02571303703423057, 0.02336292590812913, 0.05156327724190695, 0.010747170275343316, 0.10207347492022173, 0.036081947785403044, 0.047612581734678576, 0.01835960545577109, 0.06255258273865495, 0.05636640950771315, 0.029684784090412513, 0.044580866915306876, 0.02027494866134865, 0.027053367612617354, 0.03255187952890992, 0.010383624783051866, 0.022110477489020144, 0.056319505774549077, 0.05462831152336938, 0.01598223079262035, 0.032257690493549616, 0.019956122019461224, 0.02511367348155805, 0.03571441929255213, 0.04779898887500167, 0.030106975364365747, 0.03510769024225218, 0.024751848075538874, 0.03118574426376394, 0.03459113510325551, 0.043010363687894175, 0.04030893935954996, 0.053555432307933054, 0.056293850365493975, 0.016541635418044667, 0.0982414416170546, 0.0578009852075151, 0.02970167961237686, 0.02202508894593588, 0.02697786023574216, 0.04689187576462116, 0.01717526329282139, 0.014947089998583709, 0.03308266693992274, 0.03833641091893826, 0.046535936649888754, 0.0036098771213021663, 0.025651794159784913, 0.028796239090817313, 0.038862496082271845, 0.054425677218075307, 0.024337456561625004, 0.005026469522688005, 0.03219784709757992, 0.03145497338846326, 0.016833890628601824, 0.0222412532395018, 0.055458689108490944, 0.0444322032853961, 0.05147518304043582, 0.019744006883619086, 0.008769552822091749, 0.011343868881730097, 0.014873989724687167, 0.011590797953041536, 0.09115685748734645, 0.032211404227252514, 0.012443147350235708, 0.011578017745965292, 0.016038888466677496, 0.05594580600570355, 0.04262342570083482, 0.0638780262587326, 0.027238236174785664, 0.02303085256634014, 0.03278994354020272, 0.022835914544495087, 0.02503786246026201, 0.013304841022805443, 0.01569273043423891, 0.04041557792308075, 0.011029434057750871, 0.06384686114532606, 0.07252166673008885, 0.022942446238760437, 0.0014966771330883993, 0.025167698439742838, 0.018575220135971904, 0.03882132936269045, 0.037230500618794134, 0.056621535282049856, 0.04784000292420387, 0.02793775319254824, 0.024414092002968703, 0.0466733705252409, 0.03524228784122637, 0.03197633255539196, 0.04737899266183376, 0.019218637574730173, 0.04100667013387595, 0.001640742097931382, 0.026902227329888513, 0.05692008390490498, 0.00494398468539917, 0.01803132682107389, 0.02544669677237315, 0.03595516351716859, 0.022632101284606115, 0.013316252285481563, 0.03201942292175122, 0.07669489458203316, 0.02696046599053911, 0.019684862378718596, 0.10075006021984986, 0.0050067025253416175, 0.03685577626207045, 0.042172434008015056, 0.04148378881758877, 0.05242044338956475, 0.016598320233502557, 0.036781893976564915, 0.11561559539820467, 0.013027128514035471, 0.02656394539267889, 0.028902423035885607, 0.016522916333217706, 0.02044157311320305, 0.05513446132785507, 0.05015307112729975, 0.021357130591890643, 0.025926614413037896, 0.049877996423414776, 0.009994540080827261, 0.05859843348818166, 0.0545960200418319, 0.037199600134044886, 0.01592054856675012, 0.04521740061630096, 0.03089640675378697, 0.026143187523952553, 0.0370758421319936, 0.05149001242326839, 0.05028659664094448, 0.036011478531041315, 0.02628457386578832, 0.06260271290583269, 0.0372421646357647, 0.04820138049711074, 0.07914152901087489, 0.03377132909372449, 0.019014013465493917, 0.012111367474842285, 0.03253121135224189, 0.06659504332180534, 0.06986011311944042, 0.028140631770449023, 0.12456995062530041, 0.16808332928589412, 0.08462639898061752, 0.18463140060859068, 0.2005285532878978, 0.15067950316837855, 0.14730346575379372, 0.12384352460503578, 0.16458259070558207, 0.18379089928099088, 0.1219619062862226, 0.1108242425003222, 0.1303434015384742, 0.07727289106696844, 0.10426914638706616, 0.1669711425368275, 0.1240452259246792, 0.12731879098074778, 0.15963414338018211, 0.14890099503099918, 0.1533515876425164, 0.07456874581319944, 0.11123668322605745, 0.08339465436126504, 0.20726392258490833, 0.16218345372804574, 0.11526878257947308, 0.15014935018760817, 0.15497889103634016, 0.14405461294310434, 0.12524560865546974, 0.17823884077370167, 0.15196323714085988, 0.11976236716977187, 0.09421597833612136, 0.12694824300706387, 0.15251958157335008, 0.13471398130059242, 0.09275049197354487, 0.11628271745783941, 0.07152804719018084, 0.0930048068985343, 0.1157340540417603, 0.1293982429695981, 0.12362966393785817, 0.07900509597467524, 0.1701966266014746, 0.11329110405806984, 0.1745547213192497, 0.19140582638127462, 0.1450468889836754, 0.12824500485190324, 0.14506020184074128, 0.17965497049902165, 0.09598660868193422, 0.09439568833581038, 0.1020239961466619, 0.09842418466827699, 0.13622323317187174, 0.11704362662775175, 0.31481747701764107, 0.1291124847318445, 0.14658119236784323, 0.08943795186600514, 0.2221066454159362, 0.13237102702260017, 0.11176277178206614, 0.13988407887518406, 0.12473106198012829, 0.1439937754933323, 0.14118810104472296, 0.07719436420926026, 0.1404451730528048, 0.10452131035604648, 0.08803328938250031, 0.12594504255269254, 0.1504311729222536, 0.18310352973639965, 0.20058978428798063, 0.12807017351899827, 0.09873772891504423, 0.32201724925211495, 0.08333106205931731, 0.1348612776824406, 0.17275004887155124, 0.16313828820628778, 0.08212133590131998, 0.13033966959587165, 0.08125448705894606, 0.06273991947195359, 0.22182320776794637, 0.1354487668722868, 0.13799745296793325, 0.16790734444345745, 0.13609537003295763, 0.1648072400795562, 0.11358994445098297, 0.12287225600864206, 0.07836556993424892, 0.09455544262060098, 0.13552544132939406, 0.0909687675801771, 0.1491710248270205, 0.09114067442715168, 0.08373654101576124, 0.10329945877726589, 0.11945979483425617, 0.1277279747383935, 0.16260912588664464, 0.1127292024237769, 0.17366464622318745, 0.10205949031348739, 0.12937549847577298, 0.16249410063028336, 0.1514810701566083, 0.12656704203358718, 0.1909572740218469, 0.14347727463713714, 0.09609315903591258, 0.11156875147883381, 0.10633390130741255, 0.17920983795608791, 0.07003262386258159, 0.08021526996578489, 0.14503534031765802, 0.13601693138480186, 0.1255630273371935, 0.11957872845232487, 0.08493213328932013, 0.10365767776966095, 0.17655038780399732, 0.10016160072492701, 0.12136807957930223, 0.15514500997960567, 0.12281873316637107, 0.2063898066324847, 0.15512940367417677, 0.12440612513039793, 0.10471826871590954, 0.0861932991870812, 0.1367214542946645, 0.15951032430997916, 0.09551080635615758, 0.09961031816367592, 0.08498562899019037, 0.1441607086786202, 0.08577062615326472, 0.1178554394947631, 0.1495278663933277, 0.08042273204773664, 0.09987963549792767, 0.07220141855733735, 0.11226809038115398, 0.11952599271067552, 0.07143938301929406, 0.14170350267418794, 0.1179324532193797, 0.10642804804125003, 0.0999880111111062, 0.10692884759711367, 0.18459511255579336, 0.15707061093832764, 0.07320539254162993, 0.08989151181387049, 0.1445745743278946, 0.15556225473327295, 0.11887037860495703, 0.1497945442263569, 0.09068513994238206, 0.17318448770259107, 0.11937789565750531, 0.1894877843026604, 0.0984634922019073, 0.1375926932586091, 0.16153900830873422, 0.10281163959630898], [0.026602017992575253, 0.04588030218811972, 0.0054030814790166914, 0.022545701724344065, 0.011647609993815422, 0.042161954034652026, 0.04314375349453517, 0.019032342392685156, 0.016213149830166782, 0.04022449906915426, 0.020674963714554906, 0.012860271663937186, 0.024691331233563166, 0.01829878836204963, 0.01056836696807295, 0.03984699611152921, 0.06115444776202951, 0.0785860191764576, 0.009418712363445332, 0.034840795278017006, 0.034865025763532946, 0.028383513380374228, 0.005074685797028775, 0.03704282122531107, 0.025127608894503543, 0.044574464937405925, 0.039886605593242815, 0.048637156042137315, 0.07984537338571888, 0.05016439587676099, 0.02285563277213701, 0.03470648605642574, 0.013774282930951034, 0.04072905092367104, 0.05880986499999251, 0.03438965770016823, 0.0273454514930823, 0.018955270992591977, 0.08629489623542343, 0.07840414465005908, 0.007658607792109251, 0.0582461856039507, 0.051502259980354986, 0.04150265548378229, 0.031465819770736356, 0.011118361160957387, 0.07355360992785011, 0.03402552188241056, 0.07203775591083936, 0.020968984812498093, 0.018757310097238848, 0.04191507585346699, 0.02629139314272574, 0.012932028438496803, 0.008202959966313626, 0.021266300197956816, 0.05856481886335781, 0.014758314771045531, 0.045801829613213024, 0.02805244766308793, 0.028063880978152156, 0.07291145795690161, 0.08573005654449974, 0.03040136117488146, 0.05850427318364382, 0.03401497405554567, 0.002827378239349595, 0.04455030569806695, 0.01268602641565459, 0.06009484069155795, 0.05027081730908581, 0.013506445651208716, 0.057127423850553374, 0.03134347651419895, 0.057201472377138476, 0.048882561802331886, 0.04482496649559055, 0.03796586633792945, 0.012800451168524367, 0.02550074378294604, 0.1013522736196007, 0.050060128793120384, 0.03344484179147652, 0.06956421756850821, 0.03149423003196716, 0.0004849762252498684, 0.036628514528274536, 0.02372990987662758, 0.06731132524354116, 0.06288634054362774, 0.002680099244961249, 0.03346174409879105, 0.019234796886199286, 0.010620508143412215, 0.050338738664452515, 0.014449662761762738, 0.041479032287108045, 0.02137748833878764, 0.03726366062515548, 0.03523665600057159, 0.029963723051228693, 0.034849361782627444, 0.07772139592894486, 0.053542136414242644, 0.022804459357368093, 0.01292048062064818, 0.018752555263095667, 0.04706203877659781, 0.0249793540819415, 0.03884748349498425, 0.01513718328039561, 0.027604141272604465, 0.05627964184220348, 0.049161212385765145, 0.015650327084586024, 0.026494553312659264, 0.025230228834386383, 0.032684502590979846, 0.032730670113648684, 0.007252591944831822, 0.025586086524916545, 0.04753016008596335, 0.05315995495766401, 0.02780562376470438, 0.04108431828873498, 0.05522080151630299, 0.07247932614492518, 0.036192101160330434, 0.009382734740419047, 0.04709515807085803, 0.06413916046065943, 0.04043132672086358, 0.04292466810771397, 0.024739196790116172, 0.010452018568425306, 0.008992138601440405, 0.13732251418488367, 0.05595949884237988, 0.05988090538552829, 0.011976050628748323, 0.026567131114591445, 0.016653390135616064, 0.008947580054934536, 0.020899813256359527, 0.03615621344319411, 0.028356059853519713, 0.03440106387383171, 0.013463736112628664, 0.042899368929543664, 0.02394341261658285, 0.029611556591199975, 0.022541671226333295, 0.017660507433382527, 0.11242029257118702, 0.012540452664584985, 0.08996062739087002, 0.024859117676637003, 0.028748320947800363, 0.03449278145230242, 0.026846334704064896, 0.007664059820984091, 0.024158028153968707, 0.042600755845861774, 0.04131990225453462, 0.05020640737244061, 0.01888386535990451, 0.04459381336346269, 0.05237653199583292, 0.0575871720377888, 0.033844505702810626, 0.022720780722530823, 0.014789188114394034, 0.04161820660478302, 0.028201090936948146, 0.014480851623894913, 0.05472751334309578, 0.026192087846408998, 0.015231832130146878, 0.030937305452036004, 0.023512307088822126, 0.007567209973266082, 0.028272466035559773, 0.056510482848222764, 0.003549769732801776, 0.032141834031790495, 0.0380855259884681, 0.04973448287429554, 0.0312278337909707, 0.008333857004929866, 0.022411796231088892, 0.02475286927074194, 0.009135884548803526, 0.03253503489707198, 0.04738273138978651, 0.019110745417752435, 0.04102630015196545, 0.043059974775782654, 0.026536549541300962, 0.08719132241926023, 0.018224039248057773, 0.025317615663100566, 0.04526203125715256, 0.08053196940038886, 0.011602607855041112, 0.11191745741026742, 0.040975762863776514, 0.0714649637894971, 0.0165853975340724, 0.03386047841714961, 0.02291672127986593, 0.02241125001039888, 0.0676550982253892, 0.03719311333926661, 0.04597513763500111, 0.031060798825430017, 0.06246614416262933, 0.05682596431246825, 0.045719859190285206, 0.0448253939726523, 0.018373137140380483, 0.03479248697736433, 0.01863424589724413, 0.08989323529281787, 0.016252146934026053, 0.11181347191865955, 0.031651300710758994, 0.058081776568932195, 0.021959035258208002, 0.02626487090518432, 0.04493698923449431, 0.06548644602298737, 0.036932847662163634, 0.051641966948019605, 0.054042192974260876, 0.01814542757347226, 0.05431868242365973, 0.039752177628023286, 0.02377752776789878, 0.01821280949349914, 0.03164054253803832, 0.026745923395667757, 0.027519288772184933, 0.010260219619210278, 0.030186933930963278, 0.02050257850039218, 0.06179851320173059, 0.024338464186127697, 0.007476869820883232, 0.009966201913942183, 0.028021520036937933, 0.026022432039358785, 0.043185748026839325, 0.031657583945031674, 0.012408249446057847, 0.023937139560335448, 0.058951699174940586, 0.044700740304376395, 0.028556543202804666, 0.011169796659877258, 0.045939487405121326, 0.05231310932763985, 0.03704236999952367, 0.027391103329136968, 0.03913686850241252, 0.07138514771525349, 0.027544213059757437, 0.06595048933689084, 0.07131593714335135, 0.02984846370028598, 0.05856109370610543, 0.02434090860853238, 0.04296567876424108, 0.06971825858844177, 0.03334375025172319, 0.029759124387055635, 0.022848796531824127, 0.04248259915038943, 0.028005448935021247, 0.08191170929265873, 0.028991026138620715, 0.02984702181337135, 0.06737472755568367, 0.026043503944362913, 0.031705539407474656, 0.012399529422899442, 0.02862902431349669, 0.0350578280964068, 0.057101103477180004, 0.048304982616433075, 0.026485683163627982, 0.011217162645022784, 0.03664639053334083, 0.022320587553882172, 0.024293996393680573, 0.005127142491151712, 0.025358848539846282, 0.021633562365812913, 0.006826471953120614, 0.056385360990784, 0.028240836125665476, 0.021244261380551115, 0.0791778170636722, 0.012322323163971305, 0.04142292422641601, 0.028761779689895253, 0.03631408818598304, 0.024469348502212336, 0.013341816092309142, 0.09430566030953612, 0.007835625704111797, 0.031407747351165326, 0.06811931795839753, 0.013076500418329877, 0.01311196489924831, 0.03504295800147312, 0.014574469100417835, 0.010335398754770202, 0.05215190297790936, 0.013467637688985892, 0.012610034734409834, 0.028382656729913185, 0.040872666253043075, 0.03409025412318962, 0.012250340776517987, 0.04804706806316972, 0.020783078091751252, 0.051102575712970326, 0.0544900396572692, 0.055975393525191715, 0.028785983034010445, 0.03691571465294276, 0.11520542097943169, 0.024768426382382, 0.0314456163905561, 0.06268620663987738, 0.04101555894262024, 0.06360342313668557, 0.05667138724986996, 0.04733390400984457, 0.02701426872850529, 0.05752713525933879, 0.02897940283375127, 0.05209231063989656, 0.024568942175912004, 0.04618072356762631, 0.03253475669771433, 0.010471508638667209, 0.005939933720843068, 0.053531154324965816, 0.05412075375871999, 0.024398244817608168, 0.03777392913720437, 0.14484754896589688, 0.169602935601558, 0.18990363127418927, 0.07839313202670642, 0.1339598439101662, 0.14084734075835773, 0.14615699941558496, 0.09244168390120779, 0.1605736565377031, 0.12911221331783704, 0.16368085837789945, 0.10867273687784161, 0.08264246436634234, 0.08105577807873487, 0.1202850698360375, 0.07144270105553524, 0.12198633354689394, 0.1736832923654999, 0.12905065662094525, 0.13940629522715295, 0.1558398026973009, 0.1635089718869754, 0.1482209943767105, 0.09706299592341695, 0.17891999493752206, 0.15796463510819844, 0.13902092804866178, 0.11077633114265543, 0.18053484042840345, 0.09966771544090339, 0.12946529580014093, 0.1852767959769283, 0.08398304600268602, 0.12975946787212575, 0.1564333579902138, 0.17568121158650943, 0.12036041436450821, 0.14607024192810059, 0.09882375358470849, 0.23239012860826083, 0.12629470521850245, 0.1155896210776908, 0.1422986321683441, 0.12276416538017136, 0.1350437628903559, 0.10197607121829476, 0.31828536093235016, 0.1132955416770918, 0.19842008714165005, 0.14787681427385124, 0.1435590109654835, 0.11708830137337957, 0.09005021436938218, 0.17865727974900178, 0.1581057839627777, 0.06760396382638387, 0.15957534153546604, 0.09357713761606387, 0.1510104654090745, 0.08769727205591542, 0.1297789282564606, 0.11370819274868284, 0.1975656622754676, 0.1257209495774337, 0.1277869258608137, 0.15698827749916486, 0.13182715406375273, 0.12579959178609507, 0.11199935658701829, 0.16499908907072885, 0.16676336154341698, 0.10118065854268414, 0.1681800883795534, 0.1322648905749832, 0.10766793508082628, 0.11921160029513495, 0.14177977001028402, 0.1296715433044093, 0.10282471496611834, 0.14926933098052228, 0.20126491306083544, 0.08912804456693785, 0.06236438426588263, 0.17747457964079721, 0.10117187151419264, 0.11308552151811974, 0.12967399960117681, 0.10649850033223629, 0.1733214296400547, 0.11542936467698642, 0.14964294593249047, 0.21993187282766613, 0.1476879779781614, 0.0754966288805008, 0.07550823861466986, 0.12493374039019857, 0.1347778043044465, 0.16123290759112152, 0.09902434889227152, 0.09559478863541569, 0.13525344378181867, 0.14363816886075906, 0.170632503926754, 0.09109128386314426, 0.2151705247483083, 0.11605703671063695, 0.10672192834317684, 0.11449275564934526, 0.18473822916192667, 0.1427564261747258, 0.06476753138537918, 0.11377420742064714, 0.19181477943701403, 0.21702618231730803, 0.1117637963699443, 0.06756523304751941, 0.08025687094777822, 0.14047112023191793, 0.0911027646756598, 0.1408326979726553, 0.07750722992100886, 0.12646246621651308, 0.11957739852368832, 0.1619007353271757, 0.10999101506812231, 0.10612688027322292, 0.11898397893777915, 0.09514601914478199, 0.053215523583016226, 0.07928947678634099, 0.1598583720624447, 0.07089618859546525, 0.18057486042380333, 0.14799239592892782, 0.0751835596082466, 0.11980116580213819, 0.17391240649989673, 0.1675420076187168, 0.14320792337613447, 0.0585067430511117, 0.1031102832140667, 0.11477228493562766, 0.17428870845053876, 0.09366179164499044, 0.07945771954421486, 0.11484653023736817, 0.12517049482890538, 0.10181213037243911, 0.19960533854152473, 0.09569064527750015, 0.1626188289374113, 0.16775783603744848, 0.20529351117355482, 0.30633402509348734, 0.13733486352222307, 0.15298722790820257, 0.09133974303092275, 0.1668914553842374, 0.16028510273567267, 0.11443209461867809, 0.1182691151542323, 0.09316838133547987, 0.10888503691447632, 0.11887139640748501, 0.10548113206667559, 0.12087743090731756, 0.15256990173033305, 0.13047080327357563, 0.10797064312334571, 0.14417210806693348, 0.08855569349335772, 0.08453256437288863, 0.18530148108090672, 0.16445015424064227, 0.06354832609317132, 0.1305639118488346], [0.04731776166175093, 0.0052229088032618165, 0.025484426712085093, 0.019977682469678775, 0.021993871246065413, 0.05092869432909148, 0.027912053678716933, 0.06729731349540607, 0.04383019344615085, 0.0711071179913623, 0.07151323477072374, 0.019445254700258374, 0.04335988725402525, 0.05619587330147624, 0.0681758602815015, 0.030247198018644537, 0.02057167372134115, 0.06510718565966402, 0.02012878543298159, 0.03263733083648341, 0.0303047988563776, 0.02651261761119323, 0.04654348535197122, 0.035036966537258456, 0.019368424180096815, 0.03770766679995826, 0.021090936215062226, 0.027816902713051865, 0.016429286982331957, 0.07988514232316188, 0.03479520111743893, 0.014649506591792618, 0.07031967131687061, 0.044710860654179535, 0.029857532320810214, 0.014975903988150614, 0.022873237363195846, 0.015420956803219659, 0.031528652113463194, 0.05282306571358016, 0.05891108885407448, 0.017646035977772305, 0.026688997700278248, 0.025083534652367234, 0.021070580164502774, 0.012942384579218924, 0.05735029546277864, 0.069179467856884, 0.027448936565113918, 0.006824486814106682, 0.035409092104860714, 0.013900373397128922, 0.04359917602102671, 0.09623812125729662, 0.052140510374946256, 0.03692124471334474, 0.04021013787548457, 0.03300845556493316, 0.026679092785343528, 0.024571135540359786, 0.016001109333176698, 0.032353007700294256, 0.029576954697924, 0.04778284991958311, 0.04137681098654866, 0.03502842378137367, 0.049805593344249895, 0.008195248415826686, 0.02734725809256945, 0.05357065863375153, 0.005244647368921765, 0.037048103620431254, 0.0327826730374779, 0.05339419881680182, 0.016271174752286503, 0.018830973555200865, 0.03242553970111268, 0.0512037961743772, 0.047231916803866625, 0.08273751355175461, 0.07067055534571409, 0.05778873086507831, 0.027692108248759593, 0.059616900980472565, 0.05014525779656001, 0.013989886584957796, 0.07259621058723756, 0.06071074692798512, 0.03642540864114251, 0.056698908630226336, 0.0020315064923904303, 0.0362610471035753, 0.03768349059724382, 0.02608412953226694, 0.026190936033214842, 0.03751558371420417, 0.04819936524810536, 0.020946301386824677, 0.027168191004810587, 0.050953396396445375, 0.012164736798565303, 0.006211751032554145, 0.035538604083870134, 0.04729064740240574, 0.03970913815179041, 0.02493295246469123, 0.022717588215268085, 0.03068381833976933, 0.047204059548676014, 0.05020547777946506, 0.018610536187355007, 0.0755957764174257, 0.036165085288562944, 0.037606863637587855, 0.04074303213773029, 0.07020514817642313, 0.008039990273703421, 0.054112882752503665, 0.06680201007319347, 0.024521449813619256, 0.017597342608496547, 0.029215163218655756, 0.05451965092548302, 0.0626912210136652, 0.04265984267528568, 0.02441809535957873, 0.014459321707753199, 0.009488269836375756, 0.037677407530801635, 0.04747770932902183, 0.02682973604117121, 0.01116040234254407, 0.020031308788540106, 0.041222759788589816, 0.022155698455337967, 0.03319219606263297, 0.039416509746973, 0.04223576846665569, 0.03973016255934324, 0.08077652020645992, 0.0353591485348131, 0.04828965451036181, 0.07252282702497073, 0.05504886752792767, 0.018298298120498657, 0.0342872090903776, 0.031327228993177414, 0.013462893881036766, 0.07575212445642267, 0.02722620914158012, 0.0382558179220983, 0.04884111349071775, 0.04486771080909031, 0.0178486312673028, 0.032923625116901736, 0.02684082160703838, 0.04536246122526271, 0.028311583579384854, 0.03196010539042098, 0.03772588885788407, 0.04204423499426671, 0.031719435804656575, 0.017288751667365432, 0.02940088843128511, 0.023784838982724717, 0.05980562871055944, 0.011527436353000147, 0.03790697628366096, 0.011421039517569755, 0.03682835326929178, 0.05213253419580204, 0.025886738606329476, 0.004074662158797894, 0.020689903359327997, 0.05196080716060741, 0.02545291045680642, 0.055136344262531826, 0.04346857499331236, 0.04615087141948087, 0.01524080236309341, 0.04502596553148968, 0.07475210633128881, 0.007924840336532464, 0.0819370322195547, 0.01998040678777865, 0.04072153275566442, 0.07512538880109787, 0.02576590339387102, 0.01021840320234852, 0.03471433331391641, 0.054772683419287205, 0.012962447163382811, 0.018138380987303596, 0.06421795873237507, 0.10682753553347928, 0.1026319567380207, 0.0837655280317579, 0.0381939660624734, 0.02248155980903123, 0.026575529681784765, 0.052950691365237744, 0.02992705162614584, 0.05118480397920523, 0.02528312403176512, 0.05738566070795059, 0.05244887400684612, 0.07349304389208555, 0.02955767073269401, 0.06527935713529587, 0.05671653697001083, 0.045622258713202815, 0.026352462990741645, 0.027022121075008596, 0.013134005412991558, 0.05397493997588754, 0.05527561357510941, 0.059465838729270866, 0.015456739347428083, 0.05981188480343137, 0.006071739996384297, 0.02164367084125323, 0.07116246609283344, 0.042326634483678, 0.017766954310770546, 0.022510024353063533, 0.04772082164085337, 0.03478106384032539, 0.054411309239055426, 0.0014406715947968352, 0.03886097277115498, 0.0017209518285069081, 0.025538816382842403, 0.016012160972292935, 0.04385169961356691, 0.04734239926827805, 0.03024469083175063, 0.025583270604589155, 0.06226105695324285, 0.050313975528946946, 0.02741233808254557, 0.030450405686029365, 0.019013107621244023, 0.023112073208072355, 0.01802859571762383, 0.010948721469113869, 0.047027046725686104, 0.032123971597424576, 0.07726812775113753, 0.010488942747802606, 0.0501945669363652, 0.01833376514592341, 0.0390969163605145, 0.040582962334156036, 0.021362701364393746, 0.04261080155681286, 0.009876295175802494, 0.05652982448892934, 0.047173847776970694, 0.08655170816928148, 0.054829571795250685, 0.04551862605980464, 0.027967931037502627, 0.025537364317902496, 0.03109126504776733, 0.08384784790022032, 0.06139345493699823, 0.021548567373039465, 0.011756435136443802, 0.03676272875496319, 0.05308524485943573, 0.06166325403111322, 0.01482106908224523, 0.01909069131527628, 0.015530441821153675, 0.046473233228815455, 0.03861871202077184, 0.011071572778746486, 0.018446585163474083, 0.07682024035602808, 0.019191516530034796, 0.005288180479380701, 0.009488659994011479, 0.02215182571671903, 0.0530530789068767, 0.05262834991195372, 0.0464664818053799, 0.02310616147172238, 0.04317507467099598, 0.02993307023176125, 0.05591531603464058, 0.020056575736297027, 0.04288118758371898, 0.02864500381318586, 0.041669754910149744, 0.02149081047225211, 0.03818751997979624, 0.02007519982622138, 0.017524006543681026, 0.07710053638688155, 0.053288778223629506, 0.027397333976945708, 0.029317394697240422, 0.04283010407484003, 0.061929104051419666, 0.005966336790671838, 0.04245216006945286, 0.08564092418445007, 0.03539042899917279, 0.007001823213483606, 0.06184860944215741, 0.06630110873707704, 0.01508434406215591, 0.03222271201333829, 0.0642631288085665, 0.022483284984316145, 0.024120191344991326, 0.015053367242217064, 0.07557651959359646, 0.06741677637078933, 0.0399525286629796, 0.054506585733698945, 0.04631410658891712, 0.019426221792985286, 0.026462702878883908, 0.09814694883035761, 0.010776744224131107, 0.09124036479209151, 0.03426145190106971, 0.02691923820280603, 0.02460632606276444, 0.09488426747598819, 0.021109382189544182, 0.008563667485889579, 0.04293180290343506, 0.015442310300256525, 0.04258154991215893, 0.01858510808753116, 0.06773656313972813, 0.024517560111624852, 0.009575075669480222, 0.023894335875021558, 0.051965193889502964, 0.02849234700469034, 0.019840206185887967, 0.03877303802541324, 0.025901286397129297, 0.05240885740412133, 0.04948355383904917, 0.03324846697172948, 0.007677723819922123, 0.06267202525798764, 0.026505852617057304, 0.2649045224700655, 0.14400526987654821, 0.1615676696279219, 0.15075887819486006, 0.14721870315926416, 0.1322640356208597, 0.15316686326903955, 0.08155932570142405, 0.1544393878430128, 0.20205453783273697, 0.16177332002137387, 0.0827679390619908, 0.11075513370867286, 0.13820801595492022, 0.21445499600044318, 0.12893047449844225, 0.11733807011374406, 0.09962738331939493, 0.25139315319912775, 0.13950470994625772, 0.1868102986897741, 0.11558868469936506, 0.1552132841731821, 0.09825070362005915, 0.09613157768866845, 0.13206852254058632, 0.15072714989738806, 0.09684380197099277, 0.10060385627938168, 0.18416782548385008, 0.12561270967125893, 0.07678516688091414, 0.2036167968596731, 0.11346829669283968, 0.18897411972284317, 0.07261408998497895, 0.114704146449055, 0.10803563999278204, 0.14805070922843047, 0.11475410019712788, 0.15192811616829463, 0.1255903858691454, 0.08801515214145184, 0.15714883245527744, 0.09302461333572865, 0.14095159087862286, 0.14377387586448873, 0.12719014074121202, 0.12957865186035633, 0.1414846751306738, 0.10162444758628096, 0.18195373857659952, 0.11143208774072783, 0.1812941346849714, 0.16017751422311577, 0.15219290767397198, 0.16111507319978305, 0.07426608526813132, 0.08891735265829734, 0.11558785688664232, 0.13461327313312463, 0.16039541895900453, 0.14719575510493346, 0.087667056891535, 0.2077967489936522, 0.21180666025195802, 0.11960591056517192, 0.185024123106684, 0.07307558879256248, 0.11160473419087273, 0.0924789761858327, 0.24108284073216574, 0.062216884323528836, 0.11483774999422686, 0.12883368826338223, 0.10659282348517861, 0.13435856465782436, 0.0781256128102541, 0.10455369004713637, 0.14812796722565377, 0.11061704504702773, 0.10771551395633391, 0.17757390359682695, 0.18409854705844605, 0.18179725483059883, 0.1465298408376319, 0.21214421785303525, 0.17352138033935002, 0.20706933231226035, 0.11847249924072198, 0.06597915744142872, 0.13095411019665854, 0.11015665903687477, 0.13792672247758933, 0.1952808177364724, 0.07733197111104216, 0.13558213971555233, 0.10310252077345337, 0.12454503481941563, 0.11600196680852345, 0.11237847445798771, 0.04835745712210025, 0.17011719729219163, 0.09307025160108294, 0.1317319284592356, 0.1381174043885299, 0.08075756193803889, 0.1113393252183284, 0.09308520651289395, 0.15402168168553285, 0.1123701963307602, 0.167605545637863, 0.1304253821394273, 0.16105533497674124, 0.08123500631856066, 0.1349081780229296, 0.15327701664396695, 0.12777761636035784, 0.11450268940201827, 0.10660471141870533, 0.1472621022590569, 0.09285005341683115, 0.20869400299021176, 0.22557032241352967, 0.0848074931917446, 0.12045207087482725, 0.08786907033728701, 0.11761268680649144, 0.15656317530998162, 0.1201678461262158, 0.18453442438372544, 0.07895634323358536, 0.17616325643445763, 0.17532320293997014, 0.20821461799953664, 0.161952996094312, 0.17498165555298328, 0.10645862282919032, 0.12056883318083626, 0.15744307238076413, 0.16063863305108889, 0.1258077206356185, 0.10184580606541463, 0.12433498751904283, 0.13597841773714336, 0.11629221694810049, 0.17089753970503807, 0.09694811315940959, 0.16335836425423622, 0.10449836230171577, 0.0896394903372441, 0.12011197555278029, 0.14576171205512115, 0.1677387963448252, 0.17205027570681913, 0.10292294648076807, 0.1153232960828713, 0.15207720388259205, 0.13969486259988376, 0.1331509216023343, 0.10825918335467577, 0.1981473703469549, 0.10451301865811859, 0.09099093531923634, 0.12381870379405362, 0.26032538818461554, 0.08110032390270915, 0.09556597803852387, 0.18056845505322727, 0.10867007023521832, 0.11955652678651468, 0.16077329511088984, 0.1002432352730206, 0.08493526812110629, 0.15727567779166357, 0.11411629085029874], [0.0314027397627277, 0.036128122093422074, 0.04338870802894235, 0.016611575415091853, 0.0624648549460939, 0.02552731182160122, 0.013486175265695368, 0.02810371946543455, 0.011760117885257517, 0.12221962745700564, 0.020489029852407317, 0.03209492012060114, 0.016012883612087796, 0.06708111188241414, 0.060144658732627115, 0.01769073447212577, 0.029929036341075386, 0.05356238050652402, 0.07641923973070723, 0.026495952791135226, 0.07197745450373207, 0.1014262746487345, 0.021617923829970614, 0.01911314234270581, 0.04250911629891821, 0.022136461987559284, 0.04162316330309425, 0.03828017393659268, 0.05668580272634115, 0.0656841304153204, 0.019706382116835033, 0.03736851124891213, 0.04919757507741451, 0.032703416754624674, 0.024321129312738776, 0.0637336882895657, 0.005125748101688389, 0.03223283575581653, 0.05100863253963845, 0.026424017901133214, 0.0031967665542781886, 0.06431919615715742, 0.021484087886554853, 0.030395739512251954, 0.010440272279083729, 0.052044314465352466, 0.020997417126117007, 0.027480430768004487, 0.022097554789589982, 0.02944704916860376, 0.01252418733201921, 0.008149516003738557, 0.04283219396269747, 0.05130306924028056, 0.032143489657236, 0.0552598037091749, 0.04486823667372976, 0.0871145258258496, 0.01771249678651137, 0.038290474098175764, 0.046259593085518906, 0.0919618917895215, 0.06713618178452764, 0.04098514700308442, 0.00922561826051346, 0.03884971248252051, 0.049581999092229774, 0.01414561121990638, 0.0403941158604409, 0.027919003573645438, 0.019426316787887896, 0.028057073575577567, 0.048856560340417285, 0.03498274141124316, 0.07103659784687416, 0.07805638188230139, 0.01678064768202603, 0.039509628500257216, 0.02386556938290596, 0.05484642321243882, 0.013721074759294944, 0.054785555228590965, 0.047537315237734995, 0.05324655638209411, 0.01680335824910019, 0.08501882970865283, 0.03975908511451312, 0.02153517648444644, 0.009126849006861448, 0.04662027516003166, 0.03014403016173414, 0.01607932067210121, 0.037458885328045914, 0.05101209646090865, 0.02868641141269888, 0.05363265637840543, 0.04776448876197849, 0.03833672643772193, 0.07769886856632573, 0.03071945160627365, 0.034774271704788716, 0.025250498371730958, 0.045697667702500305, 0.0576950591057539, 0.039991951547563076, 0.04303253481962851, 0.04917703242972493, 0.024509526257004057, 0.04906601731532386, 0.03866884558062468, 0.013779404174004282, 0.010306610210266496, 0.03586166139159884, 0.020048480813524554, 0.04960535087489656, 0.01823368631968541, 0.07451684466962304, 0.04685441045356648, 0.041400478287999115, 0.037867682320731025, 0.0060862441064922935, 0.014094395396698798, 0.01702893043069967, 0.057299330697527955, 0.013980384550190397, 0.0572379572050912, 0.036461544023560624, 0.018032558362132738, 0.08965206359113966, 0.10671350093824522, 0.05183712040473308, 0.0490482261271349, 0.04779525353972401, 0.009405987287339355, 0.03597569937950798, 0.04030484100803733, 0.04120950460700052, 0.03403200189183865, 0.10019228407847029, 0.027457101037725806, 0.016767155013180206, 0.0647160577188645, 0.024894219989489232, 0.028209796541237404, 0.04143504286184907, 0.013104179558078093, 0.013876661990902253, 0.02024057916631656, 0.021149483609146306, 0.025730712871466364, 0.06163411095206227, 0.02296675305946597, 0.08799115914319243, 0.0039485420067129386, 0.01844240538775921, 0.01294337269583983, 0.02756407038707818, 0.031231189146637917, 0.030350111424922943, 0.03133976153497185, 0.03998654701613954, 0.048715727004621706, 0.03240332107192703, 0.04764641009803329, 0.008952835308653968, 0.0460056174280388, 0.05228779318609408, 0.01464906384769295, 0.04871146919737969, 0.05440100907747235, 0.05313922232016921, 0.042370393207030635, 0.05171363042401416, 0.040311884201530895, 0.026392158985670124, 0.02485903285975967, 0.05092160024547151, 0.021174842159130743, 0.01440451473795942, 0.019269066297316124, 0.05914113936679704, 0.027416015742346644, 0.02432486804069153, 0.041364770382642746, 0.02318222015830023, 0.03921071007581694, 0.04098242607765964, 0.04978388700900333, 0.014580156920211656, 0.0495711934220578, 0.016061543054612618, 0.045872397255152464, 0.027267302918647016, 0.022518382208155732, 0.048530917814267535, 0.03285495737301452, 0.026957867201417685, 0.006870840085736875, 0.01450511094714914, 0.040599664473640065, 0.015665838395112326, 0.039044279006442854, 0.030751960219017098, 0.013103885243513753, 0.06399163337690489, 0.023049425766138092, 0.013654440924126123, 0.07802111163203206, 0.11207136950854744, 0.018587944363909106, 0.039505065352256806, 0.06940408330410719, 0.015896385934736048, 0.007173363651548113, 0.020629052338855605, 0.03279710208464946, 0.03266795651455011, 0.040506426976727586, 0.024925570003688335, 0.02989241241344384, 0.03850435512140393, 0.010271577447253679, 0.024760326370596886, 0.021531279997101853, 0.014434870698356202, 0.04149002455441015, 0.05867837169872863, 0.030682736076414585, 0.051735452110213895, 0.041197002599281926, 0.010740896370927138, 0.03211110996614609, 0.04260442332763757, 0.03873561342645969, 0.03930417488196066, 0.022690348426944444, 0.04151182249188423, 0.06762484913425786, 0.04552023418779884, 0.047562532991703065, 0.025649729716990675, 0.022258214918630462, 0.1145657795880522, 0.06490538255976779, 0.05181320883067591, 0.002572923154470378, 0.06215743108519486, 0.022049405944666693, 0.012364053067618182, 0.09610635654202529, 0.08367060776799917, 0.06426667076136384, 0.03584158693307212, 0.023051281559414098, 0.0199611279115613, 0.02565959222348673, 0.030866201767431836, 0.0335344660894147, 0.015663821449769393, 0.015884214712839042, 0.031881008563297134, 0.10240346685584102, 0.04738241587100284, 0.016455542894878557, 0.003254812256532854, 0.10896772319184882, 0.02189324450279985, 0.048860746901482344, 0.019313807200108255, 0.027111638503681337, 0.034695904302809916, 0.006037971428928098, 0.04102596088445612, 0.043120869901031256, 0.02917137396122728, 0.010400114880342568, 0.029351555542754273, 0.020496566680126956, 0.04500140934916479, 0.027852083057431237, 0.022578892264781252, 0.05235734302550554, 0.08745802060833999, 0.08385475538671017, 0.032271854912063906, 0.03484937196065273, 0.03166990274829524, 0.02470411144063941, 0.025873167905956507, 0.0074268108998824444, 0.053106642461248806, 0.018229932324694734, 0.03290749294683337, 0.025266620363774042, 0.029058570907052075, 0.030382949127150432, 0.036863009445369244, 0.004944424460908132, 0.08154703743223633, 0.04952740755730441, 0.035548218925084384, 0.05770322188202824, 0.03675819614103862, 0.045170133866901906, 0.034138196014932225, 0.0675610668425049, 0.0098549806945292, 0.04412876921040671, 0.019164427715752805, 0.026946118367569785, 0.03350798286763685, 0.02570331871642598, 0.022392388433218002, 0.03787406733525651, 0.06865441067410366, 0.024307867345799292, 0.05583536086071815, 0.016985478744442974, 0.07002963830849954, 0.03523108183539339, 0.006792653767791177, 0.05576668293880565, 0.019766395146559392, 0.01057768240571022, 0.0261152997346861, 0.022977017597960572, 0.03137526927249772, 0.0164998512315963, 0.04688096492152129, 0.013660795404575765, 0.030769391783646176, 0.06428319987441812, 0.02704883160601769, 0.039292826383773766, 0.029131506636206592, 0.011821113942590143, 0.04566735754321728, 0.04486412135884166, 0.03588403947651386, 0.07306617072650365, 0.005032927479727992, 0.03366212906049831, 0.04291279035221253, 0.022150304101939713, 0.005879197203155074, 0.062256259710661004, 0.03047969125743423, 0.033502432451184304, 0.04884419064702732, 0.013166602235287428, 0.008067656690920038, 0.03192652129967298, 0.25334041299564497, 0.13007191967751297, 0.07033620042992489, 0.1449848437415702, 0.277564384575401, 0.07536737474479846, 0.1684110074170998, 0.10850860604218074, 0.09692969771900348, 0.1318240463733673, 0.1405851819685527, 0.07004763984254428, 0.08287935451205287, 0.13784081994422845, 0.11519737355411053, 0.11861248101506915, 0.11578202646757875, 0.08930301839219672, 0.19020917559308664, 0.14805889236075537, 0.1292923100824867, 0.12624950121556008, 0.10407839662262372, 0.07636274490505457, 0.1218434205012662, 0.13527878027941498, 0.11653078986065728, 0.07397417950310878, 0.13265221193432808, 0.2311049018587385, 0.07005283063543694, 0.13767232612839767, 0.16992290557495185, 0.08934636320918798, 0.1103157890694482, 0.19509454630315304, 0.09816978153373514, 0.148609794942396, 0.07642714466367449, 0.14466248532491072, 0.052832066480602534, 0.10438651258924178, 0.05211326040859733, 0.13940272613295487, 0.09364427187080894, 0.15575708927852766, 0.09982626193336078, 0.10758149650480066, 0.09259882582617657, 0.16733922064304352, 0.10883037413337401, 0.10582329013517924, 0.11939156135278088, 0.10822661367378064, 0.08040456766528742, 0.1500898426664727, 0.0938153780464615, 0.24616479660783494, 0.07603778091392346, 0.14417289516755513, 0.1680354925670794, 0.11629191839269229, 0.171548295500023, 0.11307456317756857, 0.13794076815247536, 0.08150346191333872, 0.22925100848078728, 0.13315048733992235, 0.1348498375820262, 0.09957324979560715, 0.1497851533016988, 0.09817257031266179, 0.15632830719862664, 0.2028421134288822, 0.17132041629936012, 0.11521380767226219, 0.09874110123408691, 0.13769739121198654, 0.09920053729521376, 0.17140523317669118, 0.07589997045163598, 0.13204866860594067, 0.12896201280610903, 0.15460936086518423, 0.09913123172840901, 0.23049400321074895, 0.10408047972513096, 0.11240811286760227, 0.14789740102631704, 0.17402478546968528, 0.0726579437032342, 0.12571282072791032, 0.09250094036438636, 0.18076422597680772, 0.12476420163043908, 0.12646117699997766, 0.16515736414917878, 0.13231320226831095, 0.12056941672095231, 0.1310222486832312, 0.11321556275444371, 0.15200940466352872, 0.09602135646023921, 0.17243432652737412, 0.0780681273234742, 0.16010778796459946, 0.26317165259804043, 0.1924516252641167, 0.13556223149810517, 0.11512059053140027, 0.1214752881122487, 0.11883499978908471, 0.25030348024197985, 0.17531381201531204, 0.14278831732060226, 0.09259766553129468, 0.1523978795324053, 0.16894464806786605, 0.16683434987706797, 0.06837338861078024, 0.12756021374038287, 0.07531100884079933, 0.1565326140927417, 0.1807804565344538, 0.10779834951141051, 0.09411126002669334, 0.17637669640992368, 0.21275443796600613, 0.15299140768391745, 0.2681559537138258, 0.11053897959313222, 0.14318452748869145, 0.12458376559828009, 0.10956086457840034, 0.10693507654858486, 0.0698629833225693, 0.094393272751144, 0.07598619189645563, 0.2363290243915149, 0.14229753294161387, 0.1199592508907829, 0.07872236400310482, 0.17906077738319123, 0.12574358550565584, 0.19310543446668557, 0.1113002212452037, 0.09772271516599826, 0.13822972907551698, 0.12097560135381562, 0.14417703423116887, 0.15298722790820257, 0.09400909300893545, 0.25376821575420244, 0.08477604309363024, 0.1086056704765984, 0.14029466041496821, 0.05708773633731263, 0.1229930759540626, 0.13651260121592454, 0.14465936406382493, 0.12247578799724579, 0.1909460917647396, 0.16268301835017546, 0.10462684290749685, 0.12049027239637715, 0.1521974809999977, 0.08354290747748953, 0.12061596422323159, 0.1724956389516592, 0.0852802556806377, 0.07712678890675306, 0.14368213792996748, 0.08282022697052785, 0.1888645091759307, 0.09453016719115631, 0.11341387818434409], [0.03598890367097088, 0.06670243505920682, 0.030810453330299685, 0.012238653010821767, 0.00611413613660261, 0.01966901688969561, 0.047560534706073146, 0.016228349014584507, 0.029987125724021877, 0.09783259712691818, 0.05101435937519584, 0.015008405815543873, 0.07166243105062417, 0.04069556861317583, 0.04310859180986881, 0.021649816672184637, 0.018332067112039243, 0.041380464897624085, 0.04458848007821611, 0.045295964793435166, 0.042140854988247156, 0.032408023319606266, 0.021450702267299806, 0.016715209764827575, 0.05264577469123261, 0.002136248762586287, 0.028511977022779838, 0.00988442826616977, 0.07523729958172355, 0.023307228361123374, 0.04756449395790696, 0.020026716802801405, 0.02801737418797399, 0.045434433434690745, 0.03281838433550937, 0.015636797096314173, 0.037266269592302184, 0.03082235822720187, 0.016979729856497476, 0.021375378094879643, 0.007748720635260854, 0.023866861992116486, 0.010467556172183581, 0.04907501129699605, 0.10357114419873271, 0.014502573226179396, 0.024302076049415127, 0.0457614296382027, 0.03413097300965871, 0.010649687693720418, 0.026497927328039492, 0.017276354832574725, 0.07272064033895731, 0.03645679767110518, 0.05930051367197718, 0.010965130142202335, 0.03328486019745469, 0.014082882353769881, 0.03691485630614417, 0.007211225057419921, 0.015825550271464244, 0.026488848529489975, 0.023401217335569005, 0.03908967299919043, 0.030925186816602945, 0.03658790760008352, 0.018538692899580513, 0.057799757059131346, 0.054539342011724196, 0.060287768553410254, 0.03256860202444451, 0.049961880315095186, 0.029846170251922946, 0.03416941201846514, 0.030179534506584917, 0.039327357030872784, 0.03430256773052471, 0.027426704365227903, 0.07182841428688594, 0.046245652583560774, 0.023093125117676597, 0.035880487345691235, 0.038971241497035534, 0.07253205510122435, 0.022095760064465658, 0.03392873904002564, 0.024264344413365637, 0.027977715512471538, 0.02665193102854703, 0.04911257838830352, 0.05509462792958532, 0.023989249353430102, 0.03274421367262091, 0.04993743269837328, 0.016725206281989813, 0.011889452596993318, 0.035467201843857765, 0.01988335931673646, 0.046158979912953715, 0.014205158604974193, 0.005246381025894412, 0.08712058514356613, 0.030836950122777904, 0.04006851404639227, 0.08736099010067326, 0.017799047320815067, 0.027266083251950995, 0.021117166682545627, 0.014395810830007707, 0.036748479519571574, 0.01737615037044244, 0.05769797680633409, 0.02539430369090821, 0.05645573525024312, 0.047306898316102367, 0.027252571923392158, 0.03667678211682609, 0.06549513127122607, 0.05018269257353885, 0.013808944196041142, 0.04471072494717581, 0.01708061613940767, 0.012669884915729719, 0.04324956424534321, 0.007702635384963027, 0.02060069127141365, 0.018302844305123602, 0.025650859477796724, 0.03687997960618564, 0.012175115839844304, 0.027656296866812875, 0.018114089433635985, 0.015541725858513798, 0.031428904073046784, 0.07068405140723501, 0.04404729072536741, 0.015495850105902978, 0.027367522540901388, 0.031205014658293555, 0.012848689071168857, 0.08503715693950653, 0.06426663004926272, 0.02248012979647943, 0.015816442635176436, 0.01459426705592445, 0.018140068843162487, 0.06691260449588299, 0.029048589656927755, 0.0163478610837566, 0.0722452179927911, 0.010072757356933184, 0.07976576765733105, 0.0389150825462171, 0.007206233584188989, 0.05891104135662317, 0.0143821587054325, 0.014299134856888225, 0.05927517717438085, 0.0628643695797239, 0.02256432411793087, 0.05482674230422292, 0.07800109484898192, 0.03638120887002774, 0.05449539329856634, 0.039564179323081455, 0.01406299788504839, 0.06739152129739523, 0.013321587267065687, 0.04819413035043648, 0.030040326262159005, 0.02719819582333522, 0.04412592275600348, 0.04072964803448745, 0.06701403869582073, 0.06136765703558922, 0.011846115413521017, 0.017712021811998317, 0.09956145007163286, 0.0422106151735144, 0.041813298993344815, 0.022550746632207717, 0.04655078299609678, 0.0606631680524775, 0.06936333049088717, 0.011750589557258146, 0.08300767226942948, 0.058474186940916946, 0.05246057873591781, 0.03637071193328925, 0.049744436983019114, 0.05197391984984279, 0.0345882750781519, 0.031108187711132423, 0.05748507965888296, 0.0384540654984968, 0.002552583431159811, 0.028986205147313218, 0.04542901872524193, 0.061985001766255925, 0.06414768964584384, 0.05821103070463453, 0.026333572575822473, 0.029370822544608797, 0.010617754139405276, 0.03795089107006788, 0.0375216939220471, 0.033521631599536965, 0.01650681808990027, 0.039146123720066886, 0.03193779515900782, 0.10600601283035108, 0.07049353913004909, 0.03379938990942069, 0.03411605202459863, 0.08399069987769638, 0.016315135339807187, 0.05279032300625529, 0.08973204251378775, 0.006506611393498523, 0.007863970656347061, 0.012881415663287044, 0.018979608347373347, 0.030106079698141133, 0.030226529841976504, 0.04060053639113903, 0.01957167255958276, 0.10942033319068806, 0.012413433453600322, 0.05942781362682581, 0.07784285369728293, 0.026572717154132466, 0.023937149738360728, 0.038730588874646595, 0.05128510841833694, 0.051306801182883124, 0.06243632933390992, 0.022871284878679683, 0.03187330040548529, 0.038758741292570315, 0.03436785637001906, 0.054306787704782825, 0.04619038590629186, 0.030651163841996874, 0.04837311431765556, 0.04035278629245503, 0.055929507594555616, 0.027373117062130144, 0.05384954331176622, 0.023490694052140628, 0.010906713366109346, 0.05879048603985991, 0.032731267224465094, 0.04008177601333175, 0.04357389719890697, 0.0814175254532269, 0.062317863905004094, 0.04827790567651391, 0.032021974213421345, 0.03419785959912198, 0.013735148423750485, 0.03971978097355791, 0.016042416848774468, 0.033836308999785354, 0.010991419981499868, 0.01718865248507687, 0.04390676273033023, 0.03827647931341614, 0.040715873773608885, 0.05102293605783156, 0.06861476387296404, 0.04366831534675189, 0.056244839781097004, 0.005523704649281821, 0.02896764382187809, 0.027028933566595827, 0.023393100360408425, 0.027446268226153085, 0.06355377472937107, 0.01766951328941754, 0.027668459607022147, 0.06808972704623427, 0.027111864116575037, 0.030096960187490498, 0.036862073067043505, 0.046991861292294095, 0.026423546319295253, 0.012027210472816867, 0.026950069137715867, 0.03421959646844438, 0.038421000487038066, 0.041908012303922854, 0.01616242594484772, 0.029576679891241447, 0.028901856459145035, 0.019246815437717096, 0.02746962509783251, 0.028214064526504705, 0.023689993357818042, 0.03849404478179557, 0.047251353439475806, 0.03641076585544007, 0.014584151795133948, 0.04589951490717275, 0.005324700506337519, 0.06315357477537223, 0.00278084515593946, 0.027242368453049233, 0.038842550545398674, 0.0366618170269898, 0.014481268922931381, 0.02829787547567061, 0.056359892178859027, 0.016912683811304823, 0.017786774318665266, 0.028377036763621227, 0.030947300272860696, 0.055217045824974775, 0.009467522780011808, 0.019694428026143993, 0.00258089615298169, 0.04498306176226054, 0.0651463574862906, 0.011184661665798297, 0.01720427066486861, 0.04353286957900439, 0.05580297099160297, 0.038439629665975056, 0.011980399190049087, 0.0183140655779945, 0.0341179756713765, 0.022819042771256397, 0.064771236186581, 0.022137947979250124, 0.05862413639468806, 0.01653170505804675, 0.027155873897884573, 0.06658661591687373, 0.020298288569652607, 0.012331712392291852, 0.021877134385119592, 0.059341449689652236, 0.048121628883693895, 0.050487822986074855, 0.02176059938834182, 0.013657535891979933, 0.030771223828196526, 0.032417190327708206, 0.05512012727558613, 0.023994211140753965, 0.1045391693977373, 0.017919217568955252, 0.017814438191375563, 0.10382682297910963, 0.2547377608716488, 0.10747120742286954, 0.10849964937993459, 0.12720745695488794, 0.0948962571897677, 0.18946490410183156, 0.10253742323922259, 0.05865419549601419, 0.2145601010748318, 0.14387226344219275, 0.08879809334341969, 0.12781310374183313, 0.1628683941172702, 0.1342538259923458, 0.11092391250921146, 0.06513639659221683, 0.12101353146135807, 0.11298124425645385, 0.08416121572788272, 0.04582883869963033, 0.13268152464713368, 0.19986742947782787, 0.10754523559340409, 0.116888377815485, 0.07303010659026248, 0.10099368143294539, 0.09424845302211386, 0.19001229187207563, 0.1342350441430296, 0.10122103137629372, 0.1754803652209895, 0.10568288766912051, 0.19162222476942198, 0.1569318776684148, 0.17176401535315172, 0.09926811938307115, 0.10731652858001844, 0.14005363120564393, 0.15142335396792206, 0.07462555955031089, 0.21904700888054712, 0.08522325873907123, 0.1557567228696176, 0.2475240650985922, 0.05388658793110933, 0.1848018757466759, 0.0897648428965892, 0.06287022533693484, 0.08154760061630181, 0.20803800890488283, 0.12622044634606155, 0.17107538373342582, 0.1636854859867266, 0.19877778366208076, 0.1274237467774323, 0.20182296740157263, 0.08585855072098118, 0.11673865227827004, 0.1012909272685647, 0.11161771456577949, 0.09584362099745444, 0.17526779377034732, 0.16211865363376482, 0.13292353094688483, 0.12917842476495675, 0.1590576328869377, 0.12643438843744143, 0.16354117515896047, 0.08936560646231685, 0.13911520370415278, 0.1314315138650792, 0.12648952619305678, 0.06650686769613198, 0.08039761946669646, 0.11118503992578813, 0.13110808336309024, 0.11782460686351572, 0.131088025867939, 0.20355844284806932, 0.1320061380309718, 0.09831150714308023, 0.12014470808207989, 0.13026671351066657, 0.1740778876202447, 0.1224259292440755, 0.14827729921255792, 0.10354124794581107, 0.10964520648121834, 0.13371582914675983, 0.17086019313761167, 0.13994805115674222, 0.09186015903417553, 0.17542673381311552, 0.08111814223229885, 0.1319371445902756, 0.13311386001961573, 0.12306987254747323, 0.09267833655966179, 0.11976954607026917, 0.06968579747314964, 0.25626565888524055, 0.15407700943095343, 0.08724002766289882, 0.14177115261554718, 0.0632032435387373, 0.09541579109749623, 0.1999665227319513, 0.15882494965834276, 0.10976817738264799, 0.14877022776220525, 0.11310755355017525, 0.2180534436234406, 0.16078221106103488, 0.1855149617684739, 0.21103774436882564, 0.09732894093862601, 0.11615796200931072, 0.09240937206361975, 0.09233299616192069, 0.13459576692964348, 0.07704099493899516, 0.13687290331082685, 0.11069498836461987, 0.08640965007777725, 0.0667349775987012, 0.10623826858188425, 0.10766361959810768, 0.09001608405794416, 0.07833379413932562, 0.08952951338142157, 0.12084851174482278, 0.0782914806955627, 0.13179831632546016, 0.14378756870116505, 0.24080735551459448, 0.11551795420902115, 0.1166201393519129, 0.19504046706216677, 0.10497368965297937, 0.16482303637479032, 0.1051976808479854, 0.12131033624921526, 0.08435309186045613, 0.0935288802055376, 0.1692741582436221, 0.0943036111337798, 0.16984724892037256, 0.13663407255496296, 0.14013880092118466, 0.09737761225551367, 0.12531781835215433, 0.1199141690241439, 0.16183277325970785, 0.09798300798450198, 0.19528787450066634, 0.09165580464260918, 0.1444334661854165, 0.14805620536208153, 0.08144003245979548, 0.15812255734843866, 0.10736372069056545, 0.08262102944510323, 0.12137620842882565, 0.19184131015624317, 0.07580670581332274, 0.22014428142990383, 0.06365722417831421, 0.12378989319716181, 0.09119110993508782, 0.13967072032392025, 0.19937090469258173, 0.16334134659596852, 0.16262082383036613, 0.13309767017407076, 0.08810805715620518], [0.03855173382908106, 0.0033764305408112705, 0.012279695897762264, 0.05908050547753062, 0.03415624504642827, 0.008704573764199657, 0.03713903749095542, 0.030517112463712692, 0.03421834796401007, 0.061340502064142904, 0.09287794799144779, 0.03897099383175373, 0.023211393771427016, 0.030268252960273197, 0.036058080316122086, 0.009971876163035631, 0.04207263847014733, 0.026049466570839286, 0.019170441232355576, 0.03870057048542159, 0.03735891676374844, 0.023264986163537418, 0.05833292952073472, 0.03894040547311306, 0.012177657801657915, 0.01681001976664577, 0.017423859863941158, 0.01500573578024549, 0.03680008210773979, 0.07000994722225837, 0.029845067632517645, 0.060784836166671345, 0.015124691450702292, 0.047816681675612926, 0.013003869181764978, 0.043379988853952715, 0.013890237780287862, 0.046916601580700705, 0.032104959046202045, 0.0542560434634132, 0.060357589806829176, 0.07093806777681623, 0.043930233256625276, 0.057846955955028534, 0.0431510172119098, 0.06337638531944581, 0.02563950589059719, 0.03843497491574713, 0.042826202498482804, 0.06352199893444777, 0.007859306576262628, 0.02527134636017893, 0.04657737139080252, 0.025825154768036943, 0.06065345143101045, 0.06037941149302891, 0.0701962865090796, 0.0724060715043119, 0.024701281949611645, 0.03775312525353261, 0.029084630044443265, 0.0361085293947586, 0.002982875140982547, 0.04247978323006204, 0.03391992826280849, 0.052610687645418305, 0.015080890318910991, 0.05274862702935934, 0.08419533246862036, 0.08011840230652265, 0.0221510386160974, 0.03208210937944906, 0.059776926679270606, 0.11235616422657456, 0.032351694735033174, 0.034389457532337735, 0.022496823454275727, 0.05514516521777425, 0.065990265059684, 0.015787942468055656, 0.028731116692402532, 0.09687055660677807, 0.011802593329256135, 0.012785580225421913, 0.0664087583177856, 0.03804528546918716, 0.021194823319092393, 0.06997610868087836, 0.029620489504720484, 0.020699621677132587, 0.0637906648750816, 0.016270375777302042, 0.07896469599966492, 0.06465277754302536, 0.014779239094683101, 0.03031359945556947, 0.052646195382944176, 0.027083806693553925, 0.059579262642988136, 0.04778110947726028, 0.08017185729529176, 0.08300221006252936, 0.023458553544644798, 0.05731813968824489, 0.041414133805249415, 0.03231536936280983, 0.03909553214907646, 0.05698402225971222, 0.020421678466456275, 0.018732024489768913, 0.05876808759889432, 0.05650812493903296, 0.011996466899290681, 0.07428066020033189, 0.07022922259888478, 0.08773716991501194, 0.04877276805096439, 0.05874322607581105, 0.04297972443912711, 0.05064333981967398, 0.04667687515861221, 0.04025494832811611, 0.034281061563108645, 0.04471875201644642, 0.032482217731220384, 0.04849293342392359, 0.026938549309436764, 0.019990550886307443, 0.026792094311011688, 0.03642317626093115, 0.01300190991189863, 0.0329951834199684, 0.013946393338431205, 0.057683042250573635, 0.0806851147540978, 0.05351945298856922, 0.0860589492533888, 0.06648504600993224, 0.062262529374233315, 0.037250313841338666, 0.054689505204026184, 0.022817220904731324, 0.03272841737738677, 0.06008824533117669, 0.021786599153918878, 0.000471033549859255, 0.008348995121195912, 0.029616306336330514, 0.02196904195339552, 0.02766843416195895, 0.021121972406815206, 0.02553884861325579, 0.07000614742615394, 0.028446303314662406, 0.023418745591438243, 0.021758134609886577, 0.04360221925058535, 0.02954923314973712, 0.04138434272525566, 0.08780365277613912, 0.05459936521947384, 0.041195520000266175, 0.034259250054934194, 0.01758586349231856, 0.015223737207374402, 0.046583959965833595, 0.008340585527808538, 0.013625079017531658, 0.03456579860565918, 0.03009526724261897, 0.06958113344652311, 0.034510626923292875, 0.027911856903561523, 0.03163040861753481, 0.04702938427882535, 0.05204721520255719, 0.029420399705746343, 0.03467540575989655, 0.07198775466531515, 0.06909157721591846, 0.02984784623341901, 0.013215639112916375, 0.029253588656761816, 0.03580103089500751, 0.022091495471873453, 0.015343234009508575, 0.028248584995578443, 0.06899426172354392, 0.02053564690452601, 0.0287718966470233, 0.013557478269961263, 0.03966122679412365, 0.02750320579590542, 0.03729042883164116, 0.03760528604366949, 0.025009114627859423, 0.038645880562918525, 0.03333265959684338, 0.06372538980628763, 0.03720284692410912, 0.029020555982632295, 0.04170775626386915, 0.037225621952010055, 0.021304535646257654, 0.02872300480625459, 0.06840627041778394, 0.007072025294681745, 0.02736670320986637, 0.0366342040444059, 0.011999675521760114, 0.04403305506067617, 0.013670707104860671, 0.022691847989335656, 0.02700629424569862, 0.005975084803399763, 0.014745775443900908, 0.007952192931302955, 0.05193591510344829, 0.07043513083564383, 0.03974135499447584, 0.04374786000698805, 0.040098152456006834, 0.058658402413129807, 0.0620937030762434, 0.018091161735355854, 0.09383276889898948, 0.02175835852644273, 0.061312593918825896, 0.008377603005750902, 0.007438396037157092, 0.03981127463547247, 0.018344063611168946, 0.033387515760426006, 0.004864443417838109, 0.023533009192241088, 0.039983066131493876, 0.05260656554518001, 0.04702694494543331, 0.015320162122536982, 0.019682283945647732, 0.05949332618287631, 0.016354570098753487, 0.04571091609873942, 0.057889086194336414, 0.006228990486956069, 0.009311616636945732, 0.02337469340169004, 0.03346343365098749, 0.010778987630536514, 0.08727873808571271, 0.024121809651010802, 0.019532432879454324, 0.01587380768199052, 0.007603532800983105, 0.06591380094843251, 0.07098293251224927, 0.02908776487622942, 0.010446118706438159, 0.027206207625567913, 0.0516901666830693, 0.038079059549740384, 0.01833616546355188, 0.0924414260579007, 0.05184424162975379, 0.07946965497519289, 0.08910950020487819, 0.012821416204263057, 0.06356668046542577, 0.03116720329437937, 0.07257266542209045, 0.027144617001925195, 0.02362064198989953, 0.05689142258571727, 0.06826417839952878, 0.058633812304053984, 0.05309488005670054, 0.11688560939260892, 0.056036152943436585, 0.054775977706802745, 0.09197621566376515, 0.07444941185946975, 0.05399967257731727, 0.02031112814854298, 0.03241505633507456, 0.06907792509134326, 0.03361748145627124, 0.04234703124633857, 0.023947658549462045, 0.01880642755090126, 0.03378355290208544, 0.013729508949576743, 0.09097039606422186, 0.035050286179674525, 0.10254446643271617, 0.05199497479147144, 0.06106650283826249, 0.08003442002726452, 0.017123704809429388, 0.03175188674192343, 0.039315350353717804, 0.0441172782198659, 0.07441359878118549, 0.018527115395824825, 0.04044189151110394, 0.012931219285487064, 0.011476944865924972, 0.021943956513756087, 0.06097932465906654, 0.025896114263949648, 0.054355163858937364, 0.034105046186596155, 0.033091711811721325, 0.08878425122903925, 0.06679904487516199, 0.032610705122351646, 0.04461926860468728, 0.019420118370492543, 0.03097808879933187, 0.06198405181722982, 0.057914734818041325, 0.012148670785661255, 0.023856946899156486, 0.04991273402369448, 0.014449851055230414, 0.01305272285493889, 0.024997716935883676, 0.01339770871813276, 0.015608756636668528, 0.016162965380187546, 0.04217354002009545, 0.04489932714828423, 0.03275896502392633, 0.06882185276065554, 0.04211371698017631, 0.0358468693281923, 0.09668829531541892, 0.03337358882916825, 0.05660558970911162, 0.03249036693679435, 0.025892731766881685, 0.034771089375551255, 0.08312847864414964, 0.03195480603192534, 0.06644642379667078, 0.04782912940053003, 0.013632140022569468, 0.05165828910789319, 0.023114422635574425, 0.01721945627858596, 0.048085656349680254, 0.015137656558571118, 0.03876345032559974, 0.09305687767586537, 0.12285408484084265, 0.17447542771697044, 0.14915801052536282, 0.1536446197756699, 0.10554003569164447, 0.09192481663610254, 0.08250778195049081, 0.2157569554235254, 0.1538908737046378, 0.2624057222689901, 0.2140070271811315, 0.10397622281951563, 0.16324314900806972, 0.15257167949208192, 0.08994561819625752, 0.13783436029085092, 0.1435372842741864, 0.0976911632876311, 0.1263785178640059, 0.10804025403090886, 0.12190332157271248, 0.23577968244041714, 0.09939917842192308, 0.13875543086656503, 0.1004763324079769, 0.1343916907374348, 0.16471863697682107, 0.16493643314710685, 0.19930397399834224, 0.09589639745120491, 0.20079732100878442, 0.12936196848750114, 0.1258242768900735, 0.10330540274402925, 0.17863746652645723, 0.09910887399954454, 0.075392100560878, 0.060385952570608685, 0.2258451155253819, 0.1926368246121066, 0.14272441289254598, 0.12534506831850323, 0.09947050602308341, 0.10260415715830666, 0.10376196860202722, 0.09257495496422052, 0.1994293536990881, 0.10267137962260417, 0.19285980478993484, 0.06894615359072175, 0.2941708234804017, 0.1409354146037783, 0.10005358473530837, 0.14843514002859592, 0.23428755679300853, 0.08572416686053787, 0.2083344337131296, 0.09082686555172716, 0.16874547089849198, 0.136230520637972, 0.17813495706234658, 0.07840571206595216, 0.10313175884740693, 0.1272683758288622, 0.20114144682884216, 0.12690136980797562, 0.12479948545140879, 0.2122539369655507, 0.14320548065006733, 0.14093848158206257, 0.11826900658862931, 0.17268254820789608, 0.1766404972544738, 0.10304730837898594, 0.1613855372582163, 0.166458414335336, 0.13094819337129593, 0.15802372193762235, 0.18628001000199998, 0.14561959968081542, 0.1923704317637852, 0.05408607044124177, 0.1314345129898616, 0.19769808516970702, 0.12406830968601362, 0.1984680595674685, 0.2705675757357052, 0.19746407201247557, 0.14712807802217348, 0.14341425230460508, 0.1289143796477999, 0.18461423367261887, 0.16258065455726214, 0.1202430956597839, 0.1213826545115028, 0.19946527534297534, 0.08537766616791487, 0.2336323090962001, 0.13626815219010624, 0.18882121864174092, 0.14302036272627966, 0.14984276092478208, 0.20370155945420265, 0.09558369458786078, 0.10991975532046386, 0.06328993317271982, 0.12582629892442906, 0.1448112337716988, 0.07109377120754548, 0.21190592992518628, 0.13108312684510434, 0.14842025297028677, 0.14434050688786165, 0.19365351434264863, 0.1979469039610454, 0.14118318845118794, 0.22092535666057042, 0.12228226980992726, 0.09601989082459893, 0.11275333791439023, 0.05639928113669157, 0.15637357905507088, 0.10525248612144164, 0.16649490594863892, 0.154802159805383, 0.09368041064590216, 0.12359923842762198, 0.10806486449603524, 0.16240959587906087, 0.0762019796030862, 0.13303652059819016, 0.07009315597159521, 0.10083710269204207, 0.13096588956458227, 0.14527062912072453, 0.22455637396446296, 0.12224419042468071, 0.11899863529418196, 0.12040584906935692, 0.1225516889244318, 0.1023069384640881, 0.14645703403013094, 0.13682840498430388, 0.0780354422916259, 0.04263692854770592, 0.07984813502324478, 0.09187049990785973, 0.21293152203517302, 0.11275782981621367, 0.13434204911547049, 0.1152229407536132, 0.11194601694920234, 0.15523554012179375, 0.12347993840064321, 0.1156598087400198, 0.18465296445148333, 0.09752983480159726, 0.10244992614856788, 0.22358722239732742, 0.12306140443044049, 0.12601893501622335, 0.12064444912331444, 0.0765064043392028, 0.10388821682759694, 0.17004688749355928, 0.07752782345882483, 0.10492459764438015, 0.16088568765137876, 0.15647696065051214, 0.14741033501923084, 0.08408220032496111, 0.11250202211418323, 0.11070930545351335, 0.21089768117027624, 0.16412635732974323], [0.03723187804488199, 0.01297461668894227, 0.03801528743601271, 0.05036322699327554, 0.030996158186878477, 0.06388639938086271, 0.021619776230571524, 0.015236140827515295, 0.06312730189945016, 0.07134612516633101, 0.037673743441700935, 0.019908867144425, 0.033394121298832555, 0.029485773162118027, 0.06096144526132515, 0.0723305641274367, 0.0373277109382408, 0.033286329225770066, 0.023120819524462734, 0.027810733133394803, 0.09654488693922758, 0.020215841475874186, 0.023969904320048432, 0.058070478960871696, 0.021622237616351674, 0.043704616970249584, 0.09745997283607721, 0.015287229425406881, 0.0877175670383232, 0.05701813900044986, 0.029317031681005443, 0.030816471935915093, 0.07187569460698537, 0.06611539370247296, 0.016959933597328405, 0.052509721634643416, 0.03550623457080551, 0.039009256421455314, 0.018424062889867594, 0.03342822786154492, 0.018342377451647605, 0.044909522136939425, 0.027282897349713103, 0.02807056963709848, 0.027456805874992694, 0.036971307027020624, 0.023245383286848664, 0.02835071299757276, 0.03627949647073235, 0.023675494760807072, 0.05334060812102897, 0.023490526114723513, 0.022063946950116327, 0.048743787820317915, 0.06786538301301853, 0.03371933974059565, 0.03954110573977232, 0.08912313875875302, 0.03938900532999209, 0.0924068818401013, 0.061678941760744364, 0.05158603869910751, 0.05413766285138471, 0.017389643039288263, 0.018037418369203806, 0.04471089458093047, 0.039971554784902504, 0.06745410936751536, 0.008420353256432074, 0.02714009626236345, 0.036854534542986324, 0.04318663351503866, 0.033660497183778455, 0.08626713058246033, 0.02755393646657467, 0.1217319236270019, 0.02267341728189162, 0.022142847002084767, 0.007527906680479646, 0.05099554359912872, 0.03134648581700666, 0.02397252176888287, 0.03745142144284078, 0.04646724515727588, 0.024167456398052827, 0.00996547842597855, 0.04633819797475423, 0.10015157876270157, 0.03715811450300472, 0.09873466193675995, 0.05673081673947828, 0.0233419557833778, 0.013315041100473275, 0.025970776864726628, 0.04695097277207034, 0.00589558424793982, 0.05541822806532894, 0.034932014133249006, 0.03187136997335723, 0.019527818841327513, 0.021247966181752936, 0.019267785562468425, 0.02543436609474676, 0.029749933630228043, 0.007312739833391139, 0.03354317847905414, 0.056314488008086167, 0.01765376279529716, 0.05039697393242802, 0.034447916716869385, 0.029366025302026953, 0.027129516205085174, 0.049859377422503064, 0.011424719721877148, 0.037643195795161385, 0.01900211365760437, 0.020468434618253793, 0.009227679310632604, 0.054339530412107706, 0.015835752045469623, 0.016233906216387237, 0.07065690322113888, 0.03291134702573929, 0.04501595374728952, 0.027086227367232953, 0.0567876881520663, 0.036866432654538324, 0.065015929485006, 0.026315367481272136, 0.007445360350954745, 0.03625607004921351, 0.025184273353910873, 0.053497278464159796, 0.02511514929522361, 0.031103051201041256, 0.0220642370238368, 0.05955005171043532, 0.05768020597419568, 0.07284773673330035, 0.07518678943493537, 0.050903018563985825, 0.05318258749321103, 0.0017114025083303983, 0.034698411489703825, 0.08590094558894634, 0.036303669280771694, 0.02335949082459722, 0.008808627109309393, 0.022819158122209564, 0.009150293239924525, 0.016293949780187438, 0.03086437311555658, 0.026897212956100702, 0.014003995872501816, 0.04714709992653557, 0.013924223054865641, 0.07953253481537104, 0.02382649085484445, 0.01972494344227016, 0.08179023116827011, 0.0433007732832006, 0.020588397913213288, 0.021191398413585763, 0.03502053581178188, 0.02794509324511247, 0.036166544138853035, 0.02287305924775345, 0.036930995261562724, 0.04728374330859099, 0.04482045423771654, 0.016708359953814318, 0.016799085174820254, 0.02603665243701211, 0.044243529838110716, 0.01618913817219436, 0.016360052661704164, 0.02954652240233762, 0.0350762028247118, 0.007715558084393186, 0.049173561723104546, 0.04173460589455707, 0.05625540457133736, 0.06572551426610776, 0.004406636264840407, 0.03418842117701258, 0.033153617954147716, 0.011215268684151982, 0.08248555314327989, 0.042090300736682754, 0.0635038549080491, 0.04524356831929513, 0.023955103774954165, 0.005903238971118948, 0.04261798045731016, 0.019150203925424387, 0.03225180759493794, 0.08572632460189716, 0.06361875124275684, 0.04422845618267145, 0.02568156149105302, 0.0495733511634171, 0.04781304133523788, 0.0160112245939672, 0.005201758442646158, 0.04206032645223396, 0.08043196012399026, 0.054783811393593035, 0.05043174545945866, 0.05682762333058885, 0.028653522820344994, 0.07056523314011948, 0.02748273778706789, 0.061017838306725025, 0.046096005077872954, 0.026733577451003448, 0.05577255226671696, 0.018641472295192734, 0.009218083977300142, 0.054032405106616874, 0.006112638270548944, 0.01606719525131796, 0.020808105855914097, 0.03420336591079831, 0.03899449149944952, 0.05555286976907935, 0.03758202925590532, 0.030209200057600225, 0.05775316205940076, 0.07480577166591372, 0.020289759384468198, 0.035952551157346795, 0.017537716343732815, 0.03533045328887446, 0.06960466504096985, 0.03489915268229587, 0.10036073039684977, 0.028170819793428694, 0.05285718923966799, 0.02980244206264615, 0.024570557089256387, 0.025022568280941675, 0.03939834875719888, 0.03918674082628318, 0.06675392908177205, 0.03363974419023309, 0.039507345229919465, 0.0394639020253505, 0.035085787131850205, 0.07428081626338617, 0.05465665393109832, 0.018914446933194995, 0.04806291185585516, 0.004628374723584524, 0.013098556199111044, 0.025085487136883394, 0.0541605091254626, 0.03567499980064375, 0.08024319846715246, 0.05153404934597867, 0.022932943355824267, 0.03699371903868658, 0.031096666186515774, 0.043789681512862444, 0.09145204736185925, 0.017517138072954755, 0.04941930335813335, 0.07521323872996227, 0.0530028232107205, 0.05917535110243729, 0.08013265832726445, 0.04613900384200471, 0.10735880809703044, 0.03293778614274093, 0.012502948337766741, 0.036034375695245605, 0.013663703775299447, 0.07232987880706787, 0.022488631840263094, 0.04892151989042759, 0.013097762313139225, 0.02333039354666003, 0.0042239555540228525, 0.0427662607149354, 0.015205384531457509, 0.009959323265190636, 0.03699868591502309, 0.0401076078414917, 0.05788387504539319, 0.02764072618447244, 0.028620888678623096, 0.022446077516568557, 0.05927312121327434, 0.015853307442739606, 0.017265762900933623, 0.0373721414112619, 0.029489101376384497, 0.0261396998539567, 0.005659696637719337, 0.04766339382955006, 0.012212878858138407, 0.03758888245959367, 0.004663709434680641, 0.06441653200558253, 0.01399368977373732, 0.045539253524371555, 0.009859071412522877, 0.017128145821126442, 0.012483405681060893, 0.03622257077534284, 0.007411475160292217, 0.04395321863038199, 0.033113407968942604, 0.06352711508848838, 0.017637208237179687, 0.03878781312544431, 0.019808810370575105, 0.038037248221891265, 0.047152297504778416, 0.012967210479213722, 0.04123588604852557, 0.028286876423018317, 0.011046131108222263, 0.021072671748697758, 0.02602406052340354, 0.017606302663417797, 0.05750819734696831, 0.020194189423429112, 0.049361193619136295, 0.012488860254442053, 0.02922684759167688, 0.044802079509411535, 0.03961523908323475, 0.03301187198875206, 0.03341264530484166, 0.014233895411182727, 0.030866897265825952, 0.05276701193568962, 0.040204221050121954, 0.02026984777434596, 0.03111401293426752, 0.002883110349232863, 0.058483740713979514, 0.02282359404489398, 0.017028385906347206, 0.044528334734163115, 0.026195763809872524, 0.046330584811844995, 0.03649226130385484, 0.0059305271050626674, 0.04533335207296269, 0.035064854326524904, 0.018849283822679093, 0.13344081890370163, 0.09745443599032504, 0.1739517886723791, 0.12744810618460178, 0.11655436216720513, 0.12994663497166975, 0.13269167553101266, 0.08621969419930663, 0.10381994941937071, 0.17039686228547776, 0.10387095489672252, 0.16688217302518232, 0.1398587016654866, 0.14589634697352136, 0.1367361649338688, 0.16975637951067515, 0.10263417554753167, 0.10182977228292397, 0.11116604773061615, 0.08481609023043088, 0.20578012934752873, 0.11181494433965002, 0.10113989215876375, 0.08453713769891433, 0.0756197694156851, 0.11168963249240603, 0.15502607636153698, 0.11300442301269088, 0.19580772731985363, 0.15050524180488928, 0.11011505126953125, 0.1270520317235163, 0.1636066266468593, 0.14543897365885122, 0.11341070264045681, 0.08335751135434423, 0.0952513413503766, 0.14469182517911705, 0.11862202121743134, 0.13021578267216682, 0.1819284970739058, 0.08893237542361021, 0.13600037513034685, 0.08130057994276285, 0.06824776463742767, 0.11716768997056143, 0.12281542191548006, 0.08244432535554681, 0.20885024246360573, 0.09771268641842262, 0.19087707118264266, 0.12507013949964726, 0.10910746747893946, 0.14328595490327903, 0.19514018456850732, 0.12509851583412715, 0.16319665578859194, 0.1778954342007637, 0.13598495881472314, 0.17988708375820092, 0.11769711013351168, 0.11440130269953183, 0.10978367512247392, 0.0935865081846714, 0.0906550536996552, 0.2188343017229012, 0.1294014592255865, 0.21495644694992475, 0.12260116769799165, 0.12874414878232138, 0.15041191609842436, 0.1391694186521428, 0.20746836518602713, 0.18399783889097826, 0.0925657336733171, 0.15906223335436412, 0.11192024618919406, 0.06317686209721224, 0.0678787569382361, 0.16802337393164635, 0.1114433989194887, 0.148741946422628, 0.1612862404435873, 0.12068103573151998, 0.08383118308016232, 0.1768725969429527, 0.15512348684881413, 0.25650265759655405, 0.10504632682672568, 0.1993597631475755, 0.14343801460095815, 0.14522177459938185, 0.2213895424668278, 0.23650918900966644, 0.15251487254032067, 0.1437130926975182, 0.11882482176380497, 0.11939887596028191, 0.07471247988619975, 0.08727902307042054, 0.2159419919231108, 0.09488921399627413, 0.1654202150447028, 0.10530081138546978, 0.1386809277215174, 0.0817108154296875, 0.16394398068743093, 0.07299663445779256, 0.13532010306205067, 0.08899576416505234, 0.20480611946965965, 0.19510266158197606, 0.10859661203409944, 0.14701639115810394, 0.08223004399665765, 0.12714609024780138, 0.1850603704473802, 0.09056326826768261, 0.19248673266598157, 0.10851244655038629, 0.039319204432623725, 0.14923631346651486, 0.11576283749725137, 0.18150074859814985, 0.10245506944400923, 0.15381373784371785, 0.15092824053551468, 0.07436750589736871, 0.12496799283793994, 0.1528797208198479, 0.05570285654227648, 0.09860162157565355, 0.1993523399744715, 0.1557029014719384, 0.16344620739775045, 0.1767007375934294, 0.1456656450671809, 0.08569551232670035, 0.1291407932128225, 0.19303524680435658, 0.13852273406726973, 0.17343211227229663, 0.07301198291991438, 0.20326262872133935, 0.23005968651601247, 0.10800453594752721, 0.09805640511746917, 0.06751264658357416, 0.12791033781000546, 0.1512880947973047, 0.14286022846187862, 0.10220582317560911, 0.1008475317752787, 0.08570374295647655, 0.09786055955503668, 0.06271818599530629, 0.2236584685742855, 0.07076450530439615, 0.10000916783298765, 0.13652037722723825, 0.11439234603728567, 0.11992560912455831, 0.13219466220055306, 0.13827827147075109, 0.11532860222671713, 0.11439774717603411, 0.08077165511037622, 0.17165661683040007, 0.10568568323339735, 0.1146394277789763, 0.1358676672513996, 0.13881259065653595, 0.10098447371274233, 0.0872869212180376, 0.08327374620629208, 0.09890978503972292], [0.05517586214201791, 0.040754842039729865, 0.04788664202871067, 0.034604444567646296, 0.051878429616668394, 0.018630639483620013, 0.040445022950215, 0.014200319802122456, 0.03471030620858073, 0.06392363738268614, 0.03974254582343357, 0.015558511118537613, 0.029207387207342044, 0.031550317736608643, 0.024371071186448847, 0.0571985478912081, 0.06820374128541776, 0.016027999675965736, 0.028648053828094686, 0.023756184448887194, 0.022157109808176756, 0.0047572302199634054, 0.06156395043113402, 0.05475086512576256, 0.09497318949018206, 0.017647661069141965, 0.03659299661272338, 0.036172606849244664, 0.02681464033334383, 0.040437728698764525, 0.0655500858223864, 0.03907720831089786, 0.009300528526572245, 0.06632071839911596, 0.029331515010978495, 0.09034984864826713, 0.045217692386358976, 0.030170876399746964, 0.038089162936168056, 0.10194753882076059, 0.021680491544040184, 0.020752567764637724, 0.05795225780457258, 0.07153057134045021, 0.021946763952395747, 0.01958140275175018, 0.04666405423943486, 0.024808029078745415, 0.03533649903589061, 0.01530212496540376, 0.023683118101741587, 0.021182229709146277, 0.04065302786018167, 0.007018963856223438, 0.02443615117642496, 0.06909425742924213, 0.013812419143505394, 0.07654587472123758, 0.006144127384426871, 0.04490753063665969, 0.04559049988165498, 0.05839941238186189, 0.02060092706233263, 0.017647255644468323, 0.030042456862117563, 0.05314292712137103, 0.03278210985341242, 0.06972832126276833, 0.04296191628756268, 0.027358004390927296, 0.05589093627142055, 0.05716749134340456, 0.028922395714159523, 0.014862892284457172, 0.027672578314585344, 0.03054596038003053, 0.04425154672935605, 0.017430657088490467, 0.04468624679637807, 0.033643920573272874, 0.04000009396778686, 0.05842556990683079, 0.02836775779724121, 0.07320531111742769, 0.044044254281158955, 0.06565265317580529, 0.02252230922957616, 0.07156233356467315, 0.1124869722074696, 0.08647014826003994, 0.03718028563473906, 0.017426356872809783, 0.030389965179243257, 0.028484859370759556, 0.0920722826517054, 0.04009891580790281, 0.09240967061902795, 0.022090448831607188, 0.07163007171558482, 0.02942655062569039, 0.04725180466526321, 0.028362904575520327, 0.025800469664058516, 0.005833304063084402, 0.024235527031123638, 0.009465895144135823, 0.026834336508597647, 0.02386116229795984, 0.03056742244267038, 0.016954501924504126, 0.11046001168766192, 0.01984858948604337, 0.05163417736600552, 0.01885579097350793, 0.025761954320062484, 0.09700121530996901, 0.06105870647089822, 0.08212628242160593, 0.03525917657784053, 0.052723697652774196, 0.034602643057171784, 0.01793931407987007, 0.011360507408556129, 0.01537415654664593, 0.02649263645123158, 0.04356707452929445, 0.01236263323309166, 0.018989146853398, 0.03501636960676738, 0.04126029634582145, 0.03597524815372058, 0.075496418534645, 0.031674051989934275, 0.028872441966086626, 0.01923032703676394, 0.051837106834032705, 0.040397040346371274, 0.017001936611320292, 0.09892857367438929, 0.029081651275711398, 0.03725017134898475, 0.02844857131796224, 0.05612991630498852, 0.031012426063950573, 0.037957123414214165, 0.025145330532853092, 0.02414663046199296, 0.023147877804668884, 0.05459216596292598, 0.06054724034454141, 0.02256901279490973, 0.055400453840515444, 0.016710565192624927, 0.013007194851525128, 0.012486320837134761, 0.0409969060149576, 0.041856274008750916, 0.08339448472751038, 0.0534078645120774, 0.022004714235663414, 0.015566894418693014, 0.00783263421284833, 0.07308702210762671, 0.045074572387550554, 0.031202147847839763, 0.014683143269004566, 0.036707122810184956, 0.021837056714243124, 0.0433561010286212, 0.028158277073608975, 0.07809087860264949, 0.04624968308157154, 0.03269054155264582, 0.028234033812103525, 0.033110435985560925, 0.08653963703129973, 0.0587912934965321, 0.06166029561843191, 0.06374926066824368, 0.011205570722397949, 0.024457229866779277, 0.023268003948032856, 0.034640420494335036, 0.03892273302855236, 0.03312056312071426, 0.046272295261068006, 0.03586598365966763, 0.023168630798214247, 0.02079288801178336, 0.05896274572504418, 0.016169419944552437, 0.036364662793598006, 0.04451817027958376, 0.019784663005598953, 0.025718550131257092, 0.031181279503341233, 0.08597347419708967, 0.09153737992580448, 0.050720791199377606, 0.02647038219895746, 0.044783389262322865, 0.034966398895319016, 0.020037600504500524, 0.013274516444653273, 0.03000255561034594, 0.019057517738214562, 0.023080209203596627, 0.015228215538497483, 0.04684192880189844, 0.028030069578172903, 0.056422917904066186, 0.03522090381011367, 0.030531704359288727, 0.06069317965635231, 0.056828088127076626, 0.0853092698380351, 0.05746743096304791, 0.054813578724861145, 0.052181103732436895, 0.007546741116259779, 0.023454796156979034, 0.011835798288562467, 0.037316949372845035, 0.056902401282319, 0.022582013525867035, 0.03621290843667729, 0.04904341192117759, 0.021847029482679706, 0.04367656972525375, 0.017215883791712776, 0.01985210090476487, 0.07214030969355788, 0.03281737331833158, 0.03407521778717637, 0.037530796469322274, 0.043082624274705134, 0.019354375112535696, 0.05979566103113549, 0.014751383535830038, 0.024821935653952614, 0.002456681412045977, 0.0653093619538205, 0.0230020809852119, 0.02107019000686705, 0.004301800059952906, 0.027448597297604595, 0.05317474362839546, 0.03032827956069793, 0.02810822833063347, 0.0103637521886932, 0.10420061435018267, 0.03883768544931497, 0.0038573973662486033, 0.021801822087062255, 0.07977851733033146, 0.004532219950176243, 0.0283126149526132, 0.04149435021515403, 0.023311917038102235, 0.08307055210960762, 0.032986596559307406, 0.1028668044933251, 0.057478341806147776, 0.09541608286755425, 0.05969183838793209, 0.02545080699824861, 0.08242588955909014, 0.003601579486192869, 0.060236797002809386, 0.014722135283851197, 0.0424310576303729, 0.027504810531224524, 0.04197554689432893, 0.026252792981852378, 0.010833991375485701, 0.009004627886627401, 0.027476098321910416, 0.0199988815999989, 0.09659381609942232, 0.011739926379440086, 0.032058319941695244, 0.04063875148338931, 0.03172245867816465, 0.02449163159222475, 0.02961654043091195, 0.041009306242423396, 0.01729036488437227, 0.03877887681924871, 0.024356251981641566, 0.02112545838047351, 0.06779337687683956, 0.056656764820218086, 0.028586517487253462, 0.027928760907213603, 0.024596300707863908, 0.03446329232039196, 0.04942758148536086, 0.023166283067049723, 0.023202754324302077, 0.05358254995995334, 0.059856206710849486, 0.08579671582473175, 0.01388828020675906, 0.02500896026114268, 0.03314555695812617, 0.0028933201808415887, 0.048134185174213986, 0.04686344854001488, 0.010220320911944976, 0.03981850103342107, 0.061945470316069465, 0.06131754043911185, 0.016283919336274266, 0.01665745964939041, 0.09969845307724816, 0.018979986630646244, 0.11139333660581283, 0.016420652624219656, 0.056998305421854766, 0.0157774285679417, 0.05219133264784302, 0.024157030707491294, 0.05409522387864334, 0.04274028300174645, 0.026759862201288342, 0.02859706531411835, 0.05336942211059587, 0.008805968100205064, 0.029540425765195062, 0.019931185857525895, 0.04574720075886164, 0.02203251381537744, 0.02441319972941918, 0.05001275347811835, 0.06768988671579532, 0.03395844869581716, 0.033253304926412444, 0.005801005372112351, 0.020737726507442336, 0.03873013764885919, 0.04844456744779434, 0.05309292248317173, 0.021616924687155654, 0.029192242305725813, 0.01189187666334744, 0.006885447248350829, 0.07030053662934474, 0.05074805134375181, 0.04274355014786124, 0.047225240019283125, 0.015035494629825865, 0.0722020020974534, 0.10854530800133944, 0.21400002469973906, 0.11309257828231369, 0.13896474534911768, 0.0984886862071497, 0.10194349475204945, 0.08355114489261593, 0.14599530452064105, 0.16414471848734788, 0.1570888635303293, 0.1381033044308424, 0.12296506602849279, 0.08215126608099256, 0.11721441389194556, 0.1563341018876859, 0.16946013112153324, 0.13569085459624017, 0.1388763865189893, 0.1452841591089964, 0.1363855523190328, 0.20639727051768983, 0.14236428721674851, 0.17972738375621183, 0.10692851511495453, 0.14869849304003374, 0.1851635349116155, 0.10520509045038905, 0.11152761190065316, 0.12446430272289685, 0.12289293775601046, 0.11988949749086585, 0.18386067982230866, 0.10527670303625719, 0.17034035388912472, 0.2209673851196255, 0.13718977916453565, 0.15149411159966672, 0.13149958449815, 0.11356351551200662, 0.18694922194949218, 0.12934965986226285, 0.06670032481529883, 0.2080823172416006, 0.152546030868377, 0.08871307290558304, 0.08953862610672202, 0.12913147014166626, 0.11542974465659686, 0.07831717003136873, 0.08422501159033605, 0.1423564162105322, 0.11748786350446087, 0.09726398478129081, 0.12426192286823477, 0.0794022221650396, 0.14044247248343059, 0.1865790539554187, 0.18964658863842487, 0.23881916648575238, 0.15933797641524247, 0.10042694862931967, 0.21192604170313903, 0.07329292355903558, 0.0920216232272131, 0.12724302576056548, 0.09937485972685473, 0.20324652029999665, 0.11166944607560124, 0.11374200414866209, 0.1353184338659048, 0.11692465229758195, 0.14780453672366484, 0.1823165783924716, 0.07334536753062691, 0.08711544863347497, 0.16034019977918693, 0.13163465367896215, 0.12105412142617361, 0.1557370996368783, 0.11893045609550816, 0.17687470040151052, 0.10305080283433199, 0.10441630706191063, 0.12170023604163102, 0.215824727501188, 0.14328585990837642, 0.12147631948547703, 0.17022418869393213, 0.17663449900490896, 0.11596787720918655, 0.18892077329967702, 0.04990120232105255, 0.10861722592796598, 0.1184457785316876, 0.27049187836902483, 0.10750296964709248, 0.20639053945030483, 0.13801684549876622, 0.12861868765737328, 0.10060944062258516, 0.12739883097154753, 0.0745869984052011, 0.16789528009082588, 0.08839814444737774, 0.08102284198892967, 0.10395040456205606, 0.12472967776869025, 0.08283087997032063, 0.1347106157668999, 0.08743636177054473, 0.1537876142454999, 0.1371176237506526, 0.09290633111127786, 0.09992109398756709, 0.2538893206843308, 0.22748478182724544, 0.14457017742097378, 0.2015873800430979, 0.11478342648063387, 0.12898166318024906, 0.15718039790434496, 0.07759498485497066, 0.13507268205285072, 0.11530091799795628, 0.12268590315112046, 0.1583964955061674, 0.11244157821472202, 0.08136964123696089, 0.11693734090243067, 0.15981038606592587, 0.15615783206054143, 0.12925428498004163, 0.13059675294373715, 0.1269478765981538, 0.08018395557467427, 0.15535243813480648, 0.09983831271529198, 0.14615276535706861, 0.18457392869251116, 0.12672725772219046, 0.1445084171635764, 0.1108391567000321, 0.11894227617553302, 0.11776383726724557, 0.24306817991392954, 0.1738241562353713, 0.1535357827586787, 0.15329590705888613, 0.12638866874788487, 0.08185194392821618, 0.07468256327722754, 0.13360492938331195, 0.11003509948828391, 0.09675720733191286, 0.14737558045557567, 0.10866291169077158, 0.108088070393673, 0.11838034061448914, 0.13560818188956805, 0.11784819274076394, 0.0863691143957632, 0.13619020208716393, 0.15446560643613338, 0.11027219997985022, 0.12243803430880819, 0.11967554182878562, 0.11038603779992887, 0.10493759837533746, 0.12290682058249201, 0.14804304178271974, 0.13012887590697833, 0.11321490457547562, 0.170430381915399, 0.13748024643531867, 0.1212884738509144, 0.18844589378152574], [0.04915476291041289, 0.03569941009793963, 0.033008760905691555, 0.05603811051696539, 0.05035674698384745, 0.026355490953262364, 0.03715261158400348, 0.039173193874635866, 0.02526198427325913, 0.01723403629979917, 0.030186011123337915, 0.013444659100579364, 0.04073386512962835, 0.017928272618779113, 0.04027319413476756, 0.02510743435206158, 0.04184111553643431, 0.031876167215939076, 0.019227692624554038, 0.017896111755232726, 0.01134905543377889, 0.04250523507861154, 0.05125150057886328, 0.05773650402469294, 0.06407431965427739, 0.06431889081639902, 0.02070499737081783, 0.03524078827883516, 0.04824358198259558, 0.03495974246678608, 0.03415745623143656, 0.028791655586766343, 0.04468586681676762, 0.01818779869271176, 0.041631651776177545, 0.030949057678558996, 0.06323217627193246, 0.0340594384553177, 0.031963457353413105, 0.1003210496689592, 0.04270817133198891, 0.019646989946652735, 0.05137973691203764, 0.021315365065155283, 0.047013842434223206, 0.028697654737957885, 0.005276384572165885, 0.09433545478220497, 0.038785380577402453, 0.07262023072689772, 0.027085564099252224, 0.019512733311525414, 0.02674908027984202, 0.037174769145037444, 0.06572582639221634, 0.027958255128136704, 0.03264939518911498, 0.03892157951902066, 0.056923890486359596, 0.0281792505910354, 0.007063366339675018, 0.013983489696069487, 0.05109304229595831, 0.045460119377821684, 0.08198389184794255, 0.02294614425461207, 0.017613864936200634, 0.07672123531145708, 0.0900566333106586, 0.03161992185882159, 0.012915074392887098, 0.04227443139201828, 0.0384089836318578, 0.045357433280774524, 0.005824668432718941, 0.02433101556796048, 0.07090371354882206, 0.025326402691592063, 0.05080010176503232, 0.03132299832733614, 0.01441670292323189, 0.04349092593682664, 0.0413249810891492, 0.038747911873672686, 0.008699488144234886, 0.02014539427390056, 0.04321286567885961, 0.05594070002968822, 0.060113568258072646, 0.009931502481257277, 0.0062045471110780325, 0.011027400149032474, 0.04335561926875796, 0.017282478611118028, 0.03651949430682829, 0.03125948405691555, 0.04404243241463389, 0.05740647816232272, 0.03763137571513653, 0.07294960519565002, 0.012195020664616354, 0.005685100140648761, 0.04263851971232465, 0.014862139110586472, 0.022790758039004037, 0.0692196846274393, 0.029062285886279175, 0.02281910553574562, 0.03971597778477839, 0.07790946548006364, 0.041728499079389234, 0.03661185649356671, 0.02358610795012542, 0.019321389828941653, 0.007725533397336091, 0.0480530018519078, 0.06025455426424742, 0.07028190405773264, 0.024303919968328307, 0.07223532495221921, 0.03891361351790173, 0.008809348052766706, 0.07274098960416657, 0.02531155464904649, 0.038809125910380056, 0.03872259573212691, 0.05818848977131503, 0.0640194940247706, 0.06953986494668893, 0.010046895842866173, 0.035784725698509386, 0.036163908030305586, 0.03131882194429636, 0.0118207212404481, 0.03998934258041637, 0.05880752405417817, 0.030397432457123483, 0.026598316584048525, 0.04241171259699123, 0.04904708618830357, 0.02899374027869531, 0.027032660420185754, 0.009903547686657735, 0.07359044080866234, 0.02458504041922944, 0.017282951889293532, 0.06420906313828059, 0.011579167862821902, 0.01523351828966822, 0.04614832012781075, 0.021567961600209986, 0.033350874869419, 0.02529871676649366, 0.026851800303640108, 0.05745882713901145, 0.069209995147373, 0.014745877224153705, 0.035151343792676926, 0.025395650582920228, 0.04682173899241856, 0.0133785986275013, 0.03015513438731432, 0.036178540637982745, 0.0045537439291365445, 0.04399818514606782, 0.025582042456205403, 0.04085558752662369, 0.03816907061263919, 0.019240206506635462, 0.03413897293752857, 0.042880044252212556, 0.08538732172123023, 0.052221944755209346, 0.029079937974789312, 0.023274619664464678, 0.0455615230436836, 0.06333627711449351, 0.05946988279798201, 0.019750337615343075, 0.0861863170617393, 0.01925870676391891, 0.042698410605745654, 0.05244273326492735, 0.013917542877607048, 0.01254103790103857, 0.047820060780005794, 0.017459625444774116, 0.04211050411686301, 0.02996400125058634, 0.024695458422814096, 0.0515343852208129, 0.05409463355317712, 0.014083802616888923, 0.030500746199062893, 0.11300978343933821, 0.028367047031809176, 0.03538091933088643, 0.004391074488272092, 0.02482200350745448, 0.029071938046919446, 0.06264162688915219, 0.013906280044466257, 0.045563555256064446, 0.02420222622874592, 0.06465182759399925, 0.012397921294905245, 0.0019192210332091364, 0.01867773151025176, 0.01388344818925751, 0.08538540146712746, 0.0320287222441818, 0.016375046589278748, 0.06581225139754159, 0.04336602799594402, 0.033733212389051914, 0.06198124268225261, 0.01535637553648225, 0.04486870825556772, 0.039324551288570674, 0.035228642502001355, 0.010298837591627879, 0.0391879859380424, 0.02972004416265658, 0.048470416239329746, 0.06006392663610833, 0.050720971011157544, 0.024996677080967596, 0.029033977405301163, 0.04652404871636203, 0.01723449431093676, 0.05766920692154339, 0.04925989851887737, 0.03675792472703116, 0.10120874310710601, 0.04175295687413641, 0.05747343599796295, 0.05044692089515073, 0.04250822741804378, 0.08974652923643589, 0.02409773183587406, 0.02754173640693937, 0.007825825962104967, 0.027727380195366483, 0.030571256165525744, 0.016767585882917047, 0.028554894362709353, 0.0512380859415446, 0.06526472113494362, 0.11991720886102744, 0.03149144464571561, 0.032281730989260335, 0.020535368705168366, 0.031771961200450144, 0.021922165361632193, 0.11919964450810637, 0.011388060171157122, 0.11304827673094613, 0.030296724289655685, 0.05009579937905073, 0.013939329788887074, 0.01903497171588242, 0.024652379930817654, 0.05625008485679116, 0.07193816732615232, 0.04668469188202705, 0.06587980634399823, 0.026761195522599986, 0.045900363075946055, 0.03949038863980344, 0.04613155692017504, 0.009721973412004965, 0.03366596956870385, 0.019233773994658674, 0.06124126631766558, 0.019983892761436955, 0.018572765535541942, 0.11873487516173295, 0.03725272264065487, 0.043711280184132714, 0.04261190756889326, 0.027077883082841123, 0.07200895209929772, 0.026003935174750428, 0.014025258615479937, 0.029241928032466342, 0.051482317836156914, 0.012736271933785506, 0.028512475746018544, 0.03930057186101164, 0.03374337684363127, 0.010498660217438425, 0.007243290926063699, 0.05708834023347922, 0.01617027659501348, 0.030665630208594457, 0.017174561009077088, 0.006655807673398937, 0.03388249348582966, 0.021314718760550022, 0.032692003795611005, 0.02300570096953639, 0.02569420768746308, 0.03985520299257977, 0.12008448131382465, 0.016547277436724732, 0.011098514011661922, 0.028982775152793953, 0.018693449773958752, 0.04310817790350743, 0.03722357277625373, 0.03729480877518654, 0.08364101685583591, 0.025704015911157643, 0.02638611663132906, 0.01315068974093135, 0.015641156683808992, 0.009027584422645825, 0.10781037315194096, 0.01944154141736882, 0.02620945155753621, 0.018843375479004214, 0.07467767103974308, 0.057922368337001116, 0.032399551809898446, 0.07520876718418938, 0.05074174436075347, 0.040102417048599036, 0.034048232449484725, 0.020502074688140835, 0.027914148655587008, 0.02584322415558355, 0.07392421896968569, 0.01690439889872713, 0.008787166743007089, 0.00899018781326179, 0.029498756929699863, 0.027347933234913007, 0.02954676667494433, 0.018473285516457896, 0.02551443831595991, 0.0611627869574087, 0.034823658876121044, 0.0331485526902335, 0.04924495717776673, 0.003860234914879714, 0.012500070501118898, 0.031820272893777916, 0.013748795459313052, 0.01704947986373944, 0.026762557681649923, 0.030984185436474423, 0.014201318096768643, 0.16852417348751, 0.12762725300022534, 0.1465701051056385, 0.1404761956738574, 0.08662361252520766, 0.15906322401549133, 0.08741812953459364, 0.14464990528566496, 0.10991146362253598, 0.1187164732920272, 0.10047453429017748, 0.15255635817136082, 0.10685537582529442, 0.1127527950863753, 0.1083838234522513, 0.1370859361652817, 0.16632842059646333, 0.14785871095955372, 0.1966312245598861, 0.08731176238507032, 0.14921720592038973, 0.11385407777769224, 0.12594065921647207, 0.13100447106574262, 0.12858933423246655, 0.12799999942736967, 0.15475786503936562, 0.07663803334747042, 0.10796868215714182, 0.1158865751432521, 0.11494049376675061, 0.07036801015159913, 0.06540186663291284, 0.156057938135096, 0.15998736156948976, 0.12593202825103486, 0.18726186374468462, 0.17783135335360253, 0.07998735005302088, 0.13694660578455242, 0.07197444180824927, 0.10708907685641732, 0.15700372095618928, 0.1553447571183954, 0.1253777194236006, 0.16456965782812663, 0.10736823294843946, 0.14622513790215763, 0.10553169649626527, 0.17614569594817503, 0.12239315600267478, 0.10687693966818707, 0.0945084404998592, 0.09268118640674011, 0.15826423546033247, 0.2043573364083256, 0.11648816429078579, 0.2246624425585781, 0.16672155021556787, 0.193661860323378, 0.08328500988760165, 0.10961683014673845, 0.1786298126514469, 0.09440828873110668, 0.20486622410161154, 0.1299817016614335, 0.12788314212645802, 0.18424072728625365, 0.14042895606585912, 0.12338332858468805, 0.11149173096886703, 0.15130884439817496, 0.16681178180234774, 0.2199941894837788, 0.08837381218160902, 0.083683045314891, 0.09429489874414035, 0.10554211200880152, 0.24669391821537698, 0.10689408624810831, 0.23214493319392204, 0.14682668633759022, 0.08740870468318462, 0.11452137625643186, 0.0856003477903349, 0.07427557797304221, 0.09368290086942059, 0.22203763840453966, 0.14407564752868243, 0.08578137414796011, 0.10143672408802168, 0.1009648572653532, 0.11867690112973962, 0.09348828345537186, 0.14527262401367935, 0.09412786377859966, 0.13026819271700724, 0.10545614840728895, 0.08844895314957414, 0.1258455150361572, 0.23799523498330796, 0.16066719937537396, 0.1004859743905919, 0.07081672535943133, 0.09370785738740649, 0.13563773887498037, 0.08749272088919367, 0.09763963533831493, 0.1255070346274546, 0.11176338924893311, 0.12705819282148564, 0.1634912078401872, 0.09155601928276674, 0.13548519063208783, 0.053790405592215915, 0.15917970133679255, 0.1692589319178036, 0.14379014713423593, 0.22833596329603875, 0.1513399620141302, 0.08698556346020528, 0.07598881782697779, 0.11327279039791652, 0.11781551449426583, 0.11943557113409042, 0.07776662707328796, 0.1633493397384882, 0.21173250994512013, 0.1479822586157492, 0.11265864156718765, 0.12530150637030602, 0.097209267717387, 0.09732197238398449, 0.0941131938514965, 0.19637225488466875, 0.19860505578773363, 0.10230045166930982, 0.044035199231335094, 0.0651425373341356, 0.09414980081575257, 0.09130426243479763, 0.20526502627347196, 0.10997318995318242, 0.12246821554643766, 0.09705355071595737, 0.1103374750486442, 0.15841801863695892, 0.0858895190592323, 0.11057933207069125, 0.1302038947386401, 0.12961780333093234, 0.09390531107783318, 0.15816332373235906, 0.128614820007767, 0.13684915458517416, 0.18924887212259428, 0.08432573332850422, 0.12930844564523014, 0.09741451777517796, 0.14535520172544888, 0.09572923356401068, 0.09410822697515998, 0.12162968197039195, 0.10901841654309205, 0.12016353064349719, 0.11303256864526443, 0.10629457341773169, 0.10962917948407785, 0.10714439781648771, 0.06427237724087068, 0.16304729666028703, 0.1726026710655008, 0.08968525073890175, 0.09912304859608412, 0.1547121996326106, 0.10091949719935656], [0.0387394234005894, 0.02552700648084283, 0.039532824219869714, 0.009794217035440462, 0.08041659809116807, 0.03069054601447923, 0.03656785689028246, 0.06131574232131243, 0.01845281072227018, 0.05207681629274573, 0.038395236512379985, 0.03806694091430732, 0.03730122771646295, 0.02916487359574863, 0.045017086900770664, 0.08244752125548464, 0.02391536028257438, 0.08545637623007808, 0.05317840093214597, 0.010353431671059557, 0.014547431176262242, 0.02146078020866428, 0.07992204784282617, 0.027228655260322348, 0.05334709830848234, 0.07448736910841294, 0.019006770104169846, 0.040841779338994195, 0.03343182070446866, 0.014970621593030435, 0.058034238405525684, 0.017682714188205342, 0.028155355980353694, 0.027226789289021065, 0.05509777972474694, 0.026419012009033134, 0.023479413407455598, 0.022350958781316876, 0.042688425962946246, 0.1256142295897007, 0.010107778245583177, 0.012927297353079277, 0.03813979182658451, 0.018807307950087955, 0.015425438527017832, 0.026211582157494764, 0.020570175855287483, 0.021897475168641125, 0.046121942078960795, 0.05744545999914408, 0.027533459976049404, 0.06612789231751647, 0.0237206614443234, 0.04807518655434251, 0.11155995087964193, 0.03958565156374659, 0.019071422617084215, 0.0516061742257859, 0.029939177046929086, 0.018801842350512743, 0.028412208626312867, 0.03562345828062721, 0.004323330400179007, 0.005665373007234718, 0.016449860164097378, 0.018998217170259783, 0.02911526250786015, 0.02756168194381254, 0.002543710313537823, 0.042294329431440146, 0.03893528931907245, 0.012430702169824923, 0.019496894607852613, 0.02007072319143585, 0.02120905728744609, 0.02792648272588849, 0.028470365862761225, 0.016397202453975166, 0.038883452636322806, 0.03158702987379261, 0.01590196179625179, 0.0028623168556285755, 0.027901772176846862, 0.02835412772505411, 0.07060798084629433, 0.060402468112962585, 0.011981272803885596, 0.005692038585298828, 0.036159772359366925, 0.01017107708113534, 0.022815829907943095, 0.04948914496760283, 0.019508283818140626, 0.011131234666598695, 0.010291437319080745, 0.044764081548367224, 0.04089817238439407, 0.0411542413224067, 0.044470879781459055, 0.03520395739802292, 0.036922578034656386, 0.0539916726494474, 0.020961115502619317, 0.028279602527618408, 0.007899338446025337, 0.00833108603754746, 0.011936531901093466, 0.04136661260521837, 0.05657496742372002, 0.0268430200604988, 0.055568805163992305, 0.02009124887574996, 0.01202167193072715, 0.005138747984476919, 0.0495714444800147, 0.021009668075878705, 0.03835519276825445, 0.00835676519532821, 0.03264449955895543, 0.04456468385511211, 0.03283039101266435, 0.043033766360687356, 0.037440944862152846, 0.024148169040147747, 0.027631727113787617, 0.01810561283491552, 0.04656153777614236, 0.030563938165349618, 0.021936562178390365, 0.0436160511869405, 0.04189541869397674, 0.03541250852867961, 0.036491501344633956, 0.0048685778165236115, 0.03244826723156231, 0.015994020338569368, 0.09745381852345807, 0.02422687570963587, 0.0476755226430084, 0.03315646440855094, 0.02028364408761263, 0.018770809551434856, 0.020632380553122078, 0.020551829964720776, 0.04561775324067899, 0.010148088314703532, 0.018226855168385164, 0.03537597620327558, 0.03868581913411617, 0.07777899676667792, 0.03624971217608877, 0.02174272168693798, 0.009973763338556247, 0.0777594753141914, 0.010802788942653154, 0.10069490889353411, 0.038671749710504494, 0.028281359933316708, 0.06843132193067245, 0.012560716264748147, 0.020797410447682654, 0.01372520364488342, 0.032921562370445044, 0.04943120486236044, 0.0402304023238165, 0.02565755322575569, 0.06897294215325799, 0.023439853119530847, 0.03843444226575749, 0.026160722565171973, 0.014529036091906684, 0.01116822924398418, 0.03723584408206599, 0.027301287345056022, 0.04855772673285433, 0.025320492651579634, 0.04444621503353119, 0.08011955581605434, 0.0303516381287149, 0.04953642189502716, 0.0725125065073371, 0.02494733571074903, 0.049726367595472505, 0.05824026877858809, 0.02573883323930204, 0.024874830851331353, 0.022233558652390326, 0.028176064869122844, 0.028849222497748475, 0.05640873991485153, 0.03882475257185953, 0.046013379868652136, 0.0016643325340867574, 0.018286193055765967, 0.030748235061764717, 0.03455435850524476, 0.01519416325858661, 0.04099468381277152, 0.04592169960960746, 0.02254057369594063, 0.05793749288256679, 0.016094789574188844, 0.04411001450249127, 0.04590369468288762, 0.0062122845307125574, 0.04150278440543583, 0.06806247707988534, 0.08950406831822225, 0.03213682983602796, 0.04479350961212601, 0.05533231196126767, 0.02082328298794372, 0.008383687768530632, 0.02933523677555578, 0.03874466847628355, 0.036492899126772366, 0.011923650761933198, 0.031688158732971976, 0.023402401379176548, 0.02295591006986797, 0.04732892695548279, 0.014652604104152747, 0.03731697990692087, 0.033977213581757884, 0.026019573710592728, 0.027388745419947163, 0.05281440760674221, 0.024335071511034454, 0.05709935285683189, 0.03882010121430669, 0.1123448937599148, 0.005165606945021344, 0.01783418864943087, 0.018775689914556484, 0.022799278742500713, 0.02446562673763505, 0.0076144215916948655, 0.030154333715992312, 0.031691296957433224, 0.03578883083537221, 0.07290243344115359, 0.02754117831188653, 0.017901994653844407, 0.007598959474957415, 0.02038216228330774, 0.02263134132538523, 0.047934458391474824, 0.015508621831291487, 0.03499729259471808, 0.045999592037073204, 0.04545367668781962, 0.1416573351515191, 0.030315770767629147, 0.03483797935768962, 0.04115523198353393, 0.009842999462437416, 0.006634098793646055, 0.024786528000341992, 0.012179399940318294, 0.040575362741947174, 0.05919122203652348, 0.12504995986819267, 0.02741458572979484, 0.01626549711051796, 0.030375071335583925, 0.006029396442629929, 0.010890265677257307, 0.06204533710011414, 0.023815971865717853, 0.048026355781725476, 0.0566048976033926, 0.02026587664814932, 0.01850667452838804, 0.013823268070284809, 0.0017810850861548844, 0.039368031812565665, 0.04914619979847755, 0.05402327202526586, 0.02112228114024869, 0.019610252364405563, 0.05313845218292304, 0.01945680845528841, 0.0382449715398252, 0.0429840467071959, 0.06116491077201707, 0.012008074088953435, 0.0191179412816252, 0.023253488387646418, 0.03932900247829301, 0.06589104288390704, 0.04986840872360127, 0.05115767954183476, 0.05572811500834567, 0.01636838846440826, 0.024126920716038773, 0.07862390857189894, 0.056168976173337014, 0.09050832050187246, 0.03294205752068332, 0.034505256318620274, 0.013553128012322953, 0.02070630355072873, 0.07099328695663384, 0.0504380490497819, 0.030647998476134877, 0.017622209220592464, 0.03875363192387989, 0.027781406849888817, 0.03213305378864918, 0.02652993891388178, 0.032310986026589356, 0.04826425015926361, 0.09567818058920757, 0.06724561591233526, 0.08390710436339889, 0.012822112550825944, 0.027099328182105507, 0.013013291488667684, 0.01391208915239466, 0.0772125150210091, 0.04514409169288618, 0.028947335268769945, 0.04137067702998008, 0.06126131024211645, 0.03450206381135753, 0.027116262719833424, 0.030598068476787636, 0.06614321363823754, 0.03636113441150103, 0.038951472379267216, 0.05666103280548539, 0.04561865569225379, 0.013835100872841264, 0.023386918906388537, 0.03841638644891126, 0.033510184713772366, 0.026496977379013385, 0.0371691678384585, 0.09246375664536442, 0.05503778026572295, 0.014856378348278148, 0.07609730879110949, 0.018216275111106888, 0.022967507929674218, 0.028927769711507217, 0.03482649515249899, 0.044413024493094, 0.0021501358299117, 0.09722937270998955, 0.03658784313925675, 0.0386998614163271, 0.05652871508417385, 0.12510766248617852, 0.12460049827183996, 0.11331390283469643, 0.3075079449585506, 0.16477494181266852, 0.05420383019372821, 0.06873655412346125, 0.20329420774110726, 0.1218082316751991, 0.17275721420134815, 0.13574258610606194, 0.0953324737825564, 0.09680197028709309, 0.17852105705865792, 0.15654135362378188, 0.16975848296923296, 0.14810303784906864, 0.1488606629094907, 0.10687001182564668, 0.10087166726589203, 0.05600444839469024, 0.12384413528655257, 0.2004384845495224, 0.13851381811712468, 0.12814736366271973, 0.16268417185970716, 0.1100100479753954, 0.09202209141637598, 0.08336525343890701, 0.04349700900326882, 0.15397685766220093, 0.18687805719673634, 0.08958243232752595, 0.16635747546596186, 0.12773193738290242, 0.14260725703622612, 0.0719307984358498, 0.09159971015261752, 0.09094721052263464, 0.2039105753813471, 0.1350947751530579, 0.06234777372862611, 0.13175704782562597, 0.19231624395719596, 0.1973920658762966, 0.05262997161064829, 0.0954435228237084, 0.12935021626097815, 0.1548064752881016, 0.1472561311508928, 0.17020533899111406, 0.10356522058801991, 0.1743627909038748, 0.11054652490253959, 0.22731434740126133, 0.0905641842899578, 0.15921582654118538, 0.08096137350159031, 0.056904935610613654, 0.1096476831340364, 0.15643685923091002, 0.1389820479920932, 0.12325176064457212, 0.08813183302325861, 0.15330665505358151, 0.14533074732337678, 0.08262510065521513, 0.1304738838225603, 0.13570150759603294, 0.10078018038932766, 0.15503322812063353, 0.1433550026267767, 0.06909059334014143, 0.12413840235344001, 0.08926782278077942, 0.4189591131040028, 0.084642025642097, 0.0981003131185259, 0.15668699438018457, 0.127722207190735, 0.0991318899073771, 0.0749677854723164, 0.1279164446251733, 0.08510114279176507, 0.19534711060779436, 0.2973704146487372, 0.07786907907575369, 0.09035155177116394, 0.14768248184451035, 0.09584478129233633, 0.06441818763102804, 0.15415335819125175, 0.0862962193787098, 0.12337853812745639, 0.18566696718335152, 0.08679308343146529, 0.13813024227108273, 0.08030097572399036, 0.14674273798508303, 0.07932662657861199, 0.09040921367704868, 0.15232440776058606, 0.09652638328926903, 0.14892589726618358, 0.1745065724743264, 0.06607932956623179, 0.07668971735984087, 0.12506556617362158, 0.16906905067818506, 0.1076369056744235, 0.1493596439915044, 0.09692773675279957, 0.15764300950935908, 0.12730874866247177, 0.21513521378593786, 0.0870539258633341, 0.14313247028206075, 0.08342666085809469, 0.2129013000854424, 0.14769567256527288, 0.10563707298466138, 0.21392506015087875, 0.16992952807673387, 0.10562765491860253, 0.0886510955169797, 0.10324275360575744, 0.14058816752263478, 0.11040749307721853, 0.0987133491518242, 0.09764405260128634, 0.14131486495690687, 0.14923558064869472, 0.18742330079632147, 0.09684203777994428, 0.1163183676877192, 0.15416044209684643, 0.12675475196114608, 0.1807058041117021, 0.15879949102444307, 0.1195866401706423, 0.12830117398074695, 0.11213627816843134, 0.058128222290958674, 0.14351747105164187, 0.10505323431321553, 0.16712142447275774, 0.1809364924473422, 0.22143059383545602, 0.15413107510123933, 0.1820179551307644, 0.18286225625446864, 0.1473962486322437, 0.04099640729171889, 0.1634515542536974, 0.20362856265689644, 0.13918064162135124, 0.1643437056669167, 0.13582909932093962, 0.17924229907138006, 0.06737255624362401, 0.12548317733619893, 0.11281185477439847, 0.16625984784747871, 0.12157584700201239, 0.14305831997522286, 0.16507243870624475, 0.14517077590738023, 0.16004043657864842, 0.1527236034827573, 0.1111172339213746, 0.12633853858070715, 0.2204057209725891, 0.15565201134553977, 0.09062769516770329, 0.1742091162928513, 0.10168961408947196], [0.08775658280189548, 0.056852050591260195, 0.017736152213599, 0.023269384766795805, 0.018828293341877203, 0.011796126890528415, 0.008633199513756802, 0.027204650387700115, 0.02898772506575499, 0.0690252436324954, 0.028941550757735968, 0.01859452954626509, 0.02379977353848517, 0.06617145426571369, 0.048314058022307496, 0.01981147701319839, 0.020908663049340248, 0.019539805162431936, 0.029633551303829466, 0.02190877277670162, 0.009451986872591078, 0.012154770815478904, 0.008139313381564404, 0.019852124653490524, 0.03739512339234352, 0.025083707678796988, 0.04995133588090539, 0.06971670474324908, 0.07286635573421206, 0.054632993414998055, 0.03580448803092752, 0.05454790512365954, 0.011404529912397265, 0.010034977375263614, 0.05761934816837311, 0.05018108783821974, 0.05918035190552473, 0.04227005823382309, 0.08295446833861725, 0.041251526280705414, 0.05918315425515175, 0.02933040221354791, 0.04348816090662565, 0.03805985361603754, 0.12232965869562966, 0.037837148244891844, 0.02098417721156563, 0.022779684347499694, 0.04009082767048052, 0.04291162666465555, 0.03022676732923303, 0.01671936409547925, 0.006157869838976434, 0.07747953890689782, 0.03162186246897493, 0.059554007569594045, 0.0036780402047692663, 0.018450116938246146, 0.06985397916287184, 0.015834250786740865, 0.037400609347969294, 0.022130567214584777, 0.09674711751618556, 0.010332947547015334, 0.03347213246992656, 0.038981104003531594, 0.005315816786605865, 0.001318088942623165, 0.05536740579243217, 0.03521211338894708, 0.03453295751075659, 0.019210912453542863, 0.015253680957747357, 0.02950320133407201, 0.05870371498167515, 0.045295890154583116, 0.048182968449379714, 0.08085001911967993, 0.07825871423951217, 0.025086605023326616, 0.029009200699095215, 0.06996075343340635, 0.024149546466235603, 0.04738401721364685, 0.03624192598674979, 0.06694720299648386, 0.017039776812972765, 0.0457359743969781, 0.030229199877274886, 0.11150082333811692, 0.015025460793237602, 0.08022298490894691, 0.0017320422713445233, 0.02046919797014977, 0.013514529547787138, 0.07164721829550606, 0.02749567405719842, 0.043412348188992055, 0.016053558393780674, 0.016337362450680563, 0.008073419997734683, 0.03464235431913819, 0.047982033874307356, 0.05248364553387676, 0.03814134906445231, 0.05785768359367337, 0.028228620798992257, 0.0024709847181968924, 0.04628865474036761, 0.03212177992931434, 0.016993361625022123, 0.056030527888131995, 0.10096414480358362, 0.019174337719700167, 0.008670646165098463, 0.03230186651593872, 0.00986828761441367, 0.025913510205490247, 0.012919728294946253, 0.0583788256293961, 0.02756577859898763, 0.06450931488403253, 0.025911849491032105, 0.09497415300990854, 0.014063593299527253, 0.05267629519637142, 0.03818650217726827, 0.07601656312389032, 0.010884933240179504, 0.028437875909730792, 0.040745322193418226, 0.0232534222304821, 0.0693277684705598, 0.02484326370592628, 0.02985301667026111, 0.01152263317323689, 0.01967505754769913, 0.05157272923471672, 0.043103920096265416, 0.04159981830577765, 0.08453570599002497, 0.060020608960517814, 0.0680203807673284, 0.032439548056572676, 0.021971869748085737, 0.062141675502061844, 0.01580795755476824, 0.048131169086056094, 0.05172083307323711, 0.019250844239390323, 0.03920049473111119, 0.009315027123583215, 0.07870341930538416, 0.022641020627426248, 0.0532022819721273, 0.022086543862574866, 0.014782604628375598, 0.029197131150535176, 0.026997542840295603, 0.03590687217989138, 0.02655753493309021, 0.021160467394760678, 0.035559156909585, 0.013176256940434021, 0.04457101797951119, 0.057087071372994354, 0.028082555958202908, 0.0474500115295606, 0.031856187752314975, 0.01160924816836736, 0.027358920413202474, 0.034544669025178464, 0.026620847339342748, 0.01848664926365018, 0.02223188097455672, 0.029296577242868285, 0.03766980115324259, 0.022002729520733868, 0.03409373161516019, 0.06914420439196484, 0.02995652040200574, 0.044041506214333434, 0.006521817787350821, 0.04502025226663266, 0.024540039976792674, 0.02696668476398502, 0.016486633369433026, 0.02275132667273283, 0.031986917701682875, 0.018088981941608444, 0.018563561208013977, 0.06225137425852673, 0.014742745785042644, 0.04204623667257173, 0.027416969084047844, 0.05350407399237156, 0.040467350145003626, 0.015126706699707677, 0.04548135752390538, 0.07026939865733896, 0.03432399925908872, 0.013740925301265503, 0.03638719694156732, 0.05284828346754823, 0.03344172053039074, 0.06442667610411133, 0.04014752605663879, 0.036593824425446134, 0.030585929485304014, 0.049821698372917514, 0.026630618243611286, 0.04345134359651378, 0.07050865010491439, 0.025910709552200775, 0.08921586735440151, 0.039043977058359554, 0.06591331918856927, 0.02556144552571433, 0.03177732162709747, 0.016427987587771246, 0.04193269740790129, 0.023756097935672318, 0.02573303855024278, 0.07191918191633054, 0.02099835011176765, 0.0016040404568359787, 0.05215167227600302, 0.015149230669651712, 0.057189102683748515, 0.01139192103541323, 0.023620396020955274, 0.010860896985312658, 0.06416983702885252, 0.01946961071475276, 0.06425452498453003, 0.004402365310982401, 0.026270285614633133, 0.024481935326808264, 0.06135839503258467, 0.03617533456001963, 0.04461467831528612, 0.022885221987962723, 0.0403764434158802, 0.026335538631039004, 0.03396714412208114, 0.02939585709412183, 0.03351144000355687, 0.02106797798270626, 0.03656892219026174, 0.025525505222114067, 0.02090206429628389, 0.06685926485806704, 0.05586038862488099, 0.049457912000694444, 0.014606850487845284, 0.01353199249466083, 0.04975462179364903, 0.033104603977075646, 0.05978601226317031, 0.024195184731589894, 0.03564914422375815, 0.036198051912443976, 0.010912655636535158, 0.06184325580086027, 0.03834329126402736, 0.020084526290052702, 0.03617225740371006, 0.02338446260962103, 0.019181060305397426, 0.01795015367679298, 0.0015217951212045072, 0.023719524898167168, 0.004281524585426918, 0.06783360721809523, 0.05335762577929667, 0.03344009204634598, 0.01991406811534294, 0.05634025537541934, 0.04684458865917154, 0.06513482239097357, 0.04660784100581493, 0.027245038488347615, 0.08829608599522284, 0.012860536292594458, 0.048085585103503296, 0.09349281606929642, 0.007146305371341961, 0.07184684329799243, 0.00924528220535389, 0.03756863836731229, 0.051842212810048034, 0.021208673915160552, 0.04181537531050188, 0.03662530505763633, 0.021314102990020598, 0.056521241020943434, 0.07727717262293611, 0.0926988215318748, 0.05542259104549885, 0.03453593627948846, 0.036718349172068496, 0.02523568255959877, 0.01997096327665661, 0.03441340642582093, 0.03742235300264188, 0.05388081699077572, 0.014012611570901104, 0.026910325645336082, 0.049849107794995816, 0.05752392578870058, 0.0387471553071269, 0.030035501878176416, 0.00938450062780508, 0.050861285267663855, 0.030400743708014488, 0.027702181101111428, 0.11888848191925458, 0.07014093840760843, 0.007705531881323883, 0.05705948213913611, 0.07627573635961328, 0.017068088686625873, 0.03492195485159755, 0.05044383016814079, 0.03905149522636618, 0.016496819876400486, 0.04311158414930105, 0.03268028888851404, 0.0324219638215644, 0.023785022187179754, 0.012011951916585011, 0.02470613517133253, 0.038417930116078684, 0.009559164023292916, 0.06174591316708496, 0.03298699010961822, 0.03563498659059405, 0.038535713617290766, 0.004337773442135325, 0.022241075124059404, 0.02762539468572608, 0.024488617200404406, 0.018350504604833465, 0.07417418448520557, 0.03107405061434422, 0.031620654676641734, 0.04877337873248117, 0.0437349305222077, 0.042728978608335764, 0.04356403808508601, 0.020583186764270067, 0.05734814450676952, 0.19380211351173265, 0.2360586960400854, 0.10672266794634716, 0.1628939884581736, 0.13290383986064366, 0.08897156082093716, 0.06482623823519264, 0.15167338055159363, 0.1169098602341754, 0.12583970677639755, 0.07716102099844388, 0.06735490754778896, 0.10107441352946417, 0.12309826245265347, 0.20754793020231382, 0.18527843803167343, 0.13062348722347192, 0.1566420482205493, 0.07599459894533668, 0.12427465218518462, 0.13184683157929353, 0.10538286662527493, 0.11854996079845087, 0.14480923887874397, 0.12341957592538425, 0.06745028243001018, 0.12396036833524704, 0.3613910350416388, 0.17804864740797452, 0.09509984483676297, 0.1257153313074793, 0.08533153257199697, 0.21037891400711878, 0.187129142295037, 0.12827187483864172, 0.1569404543510505, 0.17034818418323994, 0.12510045644428047, 0.23748071544936725, 0.13921581687671797, 0.13553990769599164, 0.09054047627640621, 0.09219932476324694, 0.16460073473198072, 0.1249819706593241, 0.10416005152676787, 0.0803108009110604, 0.1310360093734094, 0.15570318645664624, 0.23334683584315435, 0.1355439924768039, 0.1264267617038318, 0.13640707544982433, 0.09989020028816802, 0.14518832282296248, 0.12987042191837514, 0.12461906298995018, 0.12143142760864326, 0.25788163074425285, 0.09765630694372313, 0.13147299949611935, 0.07915680283414465, 0.18635782439793858, 0.0920504948922566, 0.15659426578453609, 0.10354489846421139, 0.12196490541100502, 0.07587106485984155, 0.1444113730852093, 0.1171771487487214, 0.15172705267156872, 0.05254224721076233, 0.150319119649274, 0.18754364576722893, 0.12449760522161211, 0.17423384210893086, 0.11734518116073948, 0.17691332261477197, 0.1809495881732021, 0.15648103186062404, 0.1094569130135434, 0.11857647794697966, 0.14319049859685556, 0.1355438974819013, 0.17099493662161486, 0.20905746705830097, 0.08819371541695935, 0.18221574808870042, 0.1901721954345703, 0.13718124319400105, 0.11681517745767321, 0.20314450934529305, 0.17084020349596227, 0.09927003285182373, 0.0810619934595057, 0.19529520267886774, 0.05002915027684399, 0.16798623092472553, 0.08135744796267577, 0.09982381242194346, 0.08689305878111295, 0.13679510248558863, 0.13433523662388325, 0.2657077722251415, 0.14021581464580127, 0.19180840120783874, 0.12695926241576672, 0.08375527536762611, 0.10153151543012687, 0.23438298595803125, 0.04107352279658828, 0.17057299640561852, 0.17796061427465507, 0.11329054765935455, 0.1061837211517351, 0.10536155384033918, 0.08954368119261094, 0.109921288809606, 0.13745358000908578, 0.15946117123322828, 0.16163005413753645, 0.15534441785088607, 0.2074130510113069, 0.17936676953520092, 0.13022654423756258, 0.11886123195290565, 0.118845598506076, 0.14377645429755959, 0.11376005318015814, 0.1275633621428694, 0.09408100415021181, 0.10654241511864321, 0.13546019340200083, 0.11488273686596326, 0.16017431153782777, 0.11445935815572739, 0.12638698598103865, 0.13758195883461408, 0.07173348723777703, 0.11542540203247752, 0.23433046734758786, 0.22043024322816304, 0.1384441325707095, 0.09354179951229266, 0.12853336866412843, 0.0986095265086208, 0.1544907393732241, 0.11996704047279698, 0.1131028105903949, 0.14261079898902349, 0.10900669824331999, 0.11307072266936302, 0.17649434081145696, 0.12433660243238721, 0.10910650395921298, 0.11338095566523926, 0.16001987696758338, 0.1306599516953741, 0.1274960514690195, 0.14216420081044945, 0.07823392735528094, 0.2661399447492191, 0.08772572302924735, 0.17326732325766767, 0.1247807036020926, 0.11065749251948935, 0.07952729652502707, 0.0976522085922105, 0.11246901817087616, 0.1547283080539533, 0.14342429462288106, 0.13393416814506054, 0.14240432078284876, 0.18901916087738105, 0.07017836639923708, 0.15755081017102512], [0.024450030610231415, 0.021555542713031173, 0.03461043263918587, 0.016455329156347683, 0.05443261184596589, 0.050131371577403376, 0.029216930802379335, 0.013026311727506774, 0.04222255399716752, 0.019184378341638615, 0.0033482804553516743, 0.009192070641022707, 0.026840723219460676, 0.03211377660876938, 0.0034207751367440714, 0.015728015951546173, 0.04280651141224163, 0.039204640580075126, 0.02832474885508418, 0.01901544856705836, 0.03268528969160148, 0.054508438134299855, 0.040068799031100104, 0.05873097851872444, 0.04259237933105656, 0.07762144093534776, 0.027774204200665866, 0.021130854430209314, 0.06550171306090695, 0.045846958977303336, 0.029599594018821205, 0.0375649708855365, 0.1400202065706253, 0.028982351068407297, 0.04013131585504327, 0.022458811922531043, 0.05426907812112144, 0.03209627719063844, 0.042200342153332064, 0.009427443412797791, 0.03314846448068108, 0.03753503392051373, 0.02901189787579434, 0.07967885410679237, 0.04099393403157592, 0.0346657400285559, 0.009259762990820621, 0.013050120673142374, 0.03536607977002859, 0.02778378681146673, 0.051610350608825684, 0.033077157235571315, 0.03804879688790866, 0.020210867814187492, 0.042992379117224894, 0.052597496924655776, 0.0029160667950886166, 0.015352813227634345, 0.013652883686258324, 0.041911893524229527, 0.03257754850866539, 0.03733727828200374, 0.049433708656579256, 0.011910419329069555, 0.031132903349186693, 0.015098876585917813, 0.05673867756766932, 0.024664513833288635, 0.015361045553748096, 0.12798121757805347, 0.034407113013522964, 0.05437354876526764, 0.029944082855113914, 0.014097704103083482, 0.043427835750792704, 0.04293299712506788, 0.05290240681331072, 0.008122142204748732, 0.02291299612261355, 0.021770460198500326, 0.06150772701948881, 0.04554627636181457, 0.0673981166577765, 0.007496099503311727, 0.0715395687147975, 0.06626575706260544, 0.03331889890666519, 0.02971929098878588, 0.020755819643714597, 0.01276009445012148, 0.028396704101136754, 0.03578929902453508, 0.04330709044422422, 0.04533383044015084, 0.07275872650955405, 0.05425772623025945, 0.0045850392364497694, 0.02993666646736009, 0.028707554563879967, 0.06026389090610402, 0.010701109621939915, 0.024322430403637033, 0.06931464560329914, 0.04537512608138578, 0.039899606324200115, 0.026442974473216703, 0.05117240035906434, 0.011839447958794023, 0.06252234721822397, 0.022046754569081322, 0.04449856401021991, 0.020103744098118374, 0.012972015355314528, 0.019794337218627334, 0.0036471091859441784, 0.026571146345564296, 0.054080258788807054, 0.03757658401238067, 0.03849635858620916, 0.0631775881296822, 0.06121693405189684, 0.02701641459550176, 0.04330708705154913, 0.026570047118834088, 0.047663085096116574, 0.00258772454773342, 0.05131856358743139, 0.025576319013323103, 0.035560137392686944, 0.013194110044943435, 0.034866179273064644, 0.010800030697802348, 0.01920559273899666, 0.029176086386931793, 0.03672655944579414, 0.024915649821715694, 0.024047652558822716, 0.020033778656007986, 0.03586876904591918, 0.04379227012395859, 0.011734864508200969, 0.035579842049628496, 0.0213173412983971, 0.016620048621137227, 0.060497537654425414, 0.036144227122089694, 0.07866832547421966, 0.061306907795369625, 0.07491694284336907, 0.04730996868706175, 0.017777196796877042, 0.018452125401901345, 0.04239542097119348, 0.03984723359878574, 0.04285999693508659, 0.039008845907769034, 0.05653956485912204, 0.008437854370900562, 0.030148233686174666, 0.009100666036829352, 0.05996269599667617, 0.057424405057515414, 0.03859427797475031, 0.04694440794576492, 0.0045723077990779916, 0.07681409282875912, 0.041666918633771796, 0.061484256493193765, 0.023250518100602285, 0.02662570565007627, 0.043649838838194094, 0.0669921695121697, 0.08234643989375659, 0.031166246560003077, 0.027898934204131365, 0.06215893064758607, 0.03955440841881292, 0.045913852352116785, 0.015897815947287848, 0.024481780960091522, 0.010826285762180175, 0.015280133645449365, 0.045261912513524294, 0.02662731547440801, 0.05013398054455008, 0.027796244714409113, 0.05252732961837735, 0.025458104642374173, 0.0647447801062039, 0.02936740272811481, 0.09567640282745872, 0.012900988005899956, 0.05180363130888768, 0.045301857870072126, 0.02124727577237146, 0.027699070018050925, 0.019090469095057676, 0.07158422988972493, 0.01539068396336266, 0.024014268635905216, 0.03212436514773539, 0.06461600094501461, 0.07621742984546082, 0.06152527393507106, 0.037794984078833034, 0.01281478097994945, 0.019329883391037583, 0.01544968767224678, 0.12092648898916585, 0.0454813473458801, 0.08032755394067083, 0.03154016685272966, 0.06251882562147719, 0.06019490425075803, 0.03293536377272435, 0.055272699267204316, 0.01972618855402938, 0.013580293161794543, 0.0013620641610551892, 0.07896197507424013, 0.006286302523221821, 0.027790097187140157, 0.01188333984464407, 0.030554347072861025, 0.05205581224124346, 0.027494842851800576, 0.009788066115496414, 0.038784169392394166, 0.011156238682035888, 0.024711107136681676, 0.03917820824842368, 0.011408790264145603, 0.04582139177780066, 0.012286701771829809, 0.03971793535830719, 0.05212433749277677, 0.024958918303517357, 0.043601727312696834, 0.07215611277414219, 0.04900010781628745, 0.011258344631642103, 0.04887535576043384, 0.009588701500823455, 0.045545801387301514, 0.04329676314124039, 0.012993398538258458, 0.012790618347935379, 0.03824936166139586, 0.0554956624816571, 0.04551943012380174, 0.03699856377871973, 0.03230941182534609, 0.011047748566072966, 0.04824399928163205, 0.04048491741663643, 0.030670552980154753, 0.061233856715261936, 0.031060642762375728, 0.021100574805002128, 0.02756562762494598, 0.051006712285535674, 0.04020533384755254, 0.039573665242642164, 0.007557869090565613, 0.02850258949079684, 0.021471872559881637, 0.02158567645320935, 0.045037409024579186, 0.044654834017689736, 0.04225351555006845, 0.012419507190185999, 0.01912425844264882, 0.03509973781183362, 0.04657747656373041, 0.09664528976593699, 0.06750407668628863, 0.045322692287819724, 0.02372254098632506, 0.04910249875060149, 0.06887137903166668, 0.03088488183649523, 0.029127289541065693, 0.03530750523454376, 0.0444574040759887, 0.01666420089480068, 0.04217279702425003, 0.07920761153634105, 0.03178979988609042, 0.01994663949257561, 0.02595389830613775, 0.028114367376214693, 0.06671978519963366, 0.09305754942553383, 0.030036614675607, 0.057661729465637884, 0.022140945407695005, 0.034715717525354454, 0.022007906742926155, 0.014620704476588538, 0.03183926169627479, 0.008758800586552491, 0.009621859810847257, 0.057371370760457854, 0.02754024023722325, 0.08450675290077925, 0.046532326843589544, 0.02472194334092949, 0.03181176406464406, 0.04914310567879251, 0.018538647098466754, 0.016426773010087863, 0.04677398369780608, 0.019270287660349692, 0.021057340249951397, 0.019808515207841992, 0.03689358423330954, 0.05285525880753994, 0.026656948795009936, 0.03241834383723991, 0.01158183959445783, 0.03294114828375833, 0.08490731247833797, 0.026582645817792842, 0.07306849131626741, 0.04587802570313215, 0.009381294549841965, 0.043927800708583424, 0.02129430673085153, 0.0238423312548548, 0.033147029379116635, 0.05138607442911182, 0.05227104354915874, 0.045840448433799405, 0.023585634671949914, 0.0428745515112366, 0.057733627036213875, 0.019796679860779216, 0.02266411965579859, 0.025383708366592015, 0.014686044006209289, 0.025046730912955742, 0.06278897076845169, 0.046719456623707495, 0.051737545390746424, 0.05362256317000304, 0.04210701644686716, 0.038351128343492746, 0.04667542309367231, 0.030405659694224596, 0.07511242878224168, 0.045944552669035535, 0.11844187016998019, 0.1154409676258053, 0.10008834608431373, 0.10723003572119133, 0.06981565550501857, 0.1096532064090882, 0.11943542185638632, 0.08790914461548839, 0.1034880168735981, 0.11238891711192471, 0.14618167094886303, 0.13987284233527525, 0.11222967851374831, 0.12531599987830433, 0.07495090352105242, 0.19822727463075093, 0.1354063991457224, 0.12296484889728682, 0.2061417478003672, 0.15984372927674226, 0.10454936777906758, 0.1951229769204344, 0.13640185073018074, 0.10325518436729908, 0.08798011259308883, 0.1238381370369877, 0.12006240178431783, 0.255371132599456, 0.1615597850510052, 0.15565828100911208, 0.13008964301220008, 0.10622154947902475, 0.09088571489389453, 0.2000457349100283, 0.1435226822005851, 0.2243214515703065, 0.09341895753251654, 0.13757323287427425, 0.10047353005834989, 0.1089667257453714, 0.10893440712243319, 0.14569427924496786, 0.0994345708084958, 0.13289656596524374, 0.23491379033241952, 0.12590665104133741, 0.15475653511072907, 0.1835986160274063, 0.11059018863098961, 0.20653417174305233, 0.10456270777753421, 0.12795331621808664, 0.10444921601031508, 0.10942525256957326, 0.10382021404802799, 0.09236483302499567, 0.12173463776707649, 0.09831978527030774, 0.0660733991701688, 0.14891832481537545, 0.19667451509407588, 0.1137964633692588, 0.14641845252897057, 0.1176271667437894, 0.15974793370280946, 0.11432875373533793, 0.10805125308356114, 0.13441797718405724, 0.1520295842949833, 0.15222414742623055, 0.23612101269619806, 0.09450343291142158, 0.14273229746946267, 0.10904209741524287, 0.1125000204358782, 0.11671223012464386, 0.16166388589356626, 0.15574060087757452, 0.11039527266153268, 0.09447491408458777, 0.1363720087600606, 0.13576613127120904, 0.13828241053436482, 0.19015577488711902, 0.1061431515429701, 0.14403897949627467, 0.18021311983466148, 0.12759135849773884, 0.14249909855425358, 0.1372922243816512, 0.10509212794048445, 0.15805748584015028, 0.1161692664027214, 0.14585103440497602, 0.12205563911369868, 0.26478241330810953, 0.09266332736504929, 0.06680610163935594, 0.1875463327659028, 0.1441948525607586, 0.1640034882085664, 0.13090149659131253, 0.1365860594170434, 0.30772765459758894, 0.16298755843724522, 0.15008062816091947, 0.08255280274897814, 0.16972239847694123, 0.10577014048716851, 0.1381215705935444, 0.1343909307782139, 0.22320847772061825, 0.11990511736699513, 0.07902862078377179, 0.2143378672855241, 0.14627498308462755, 0.13204421741621836, 0.11086076125502586, 0.11803529198680605, 0.08527913609785692, 0.22843008967382566, 0.18368537351489067, 0.14792083762586117, 0.11070026058171477, 0.1076726441138557, 0.10067691414483956, 0.09520058014563151, 0.16158714358295712, 0.14739368376987322, 0.18293872715107032, 0.12555474920996598, 0.1828566108431135, 0.10239984347884144, 0.09409313635634524, 0.05182977526315621, 0.10715804994106293, 0.13204413599201612, 0.06094621893550668, 0.09488925470837525, 0.11982718083475317, 0.09393370776836361, 0.21878567790346487, 0.08379423684839692, 0.0929412485233375, 0.11076633632183075, 0.1649524194321462, 0.15086464823356696, 0.1823415213397571, 0.23564848090921128, 0.11546093012605395, 0.1317053163158042, 0.07358351296612195, 0.11026020348072052, 0.08592471467064959, 0.11207248230597802, 0.09631752342517887, 0.10565817542374134, 0.09500631556979247, 0.1276399823171752, 0.09820682276040316, 0.09554490952619485, 0.13559504545160703, 0.15719637061868394, 0.10514794423111848, 0.16831179202667304, 0.06771322153508663, 0.17156540815319332, 0.17647977944995674, 0.1907747345311301, 0.13012865877577237, 0.1655043533870152, 0.21021883402551922, 0.12721084962998117, 0.10305400551962, 0.12067156338265964, 0.12734901293047837, 0.16999225185385772], [0.05264580183263336, 0.0247506301051804, 0.054213078626032384, 0.02833822456055454, 0.05168973920600755, 0.05442257631304009, 0.04408106141324554, 0.018968515996155993, 0.03530735595683966, 0.026044450500713925, 0.017441583198628256, 0.06236843511994396, 0.05679695354774594, 0.01806786084281547, 0.01679480022617749, 0.01997778085725648, 0.0028086966859908508, 0.009837219192247306, 0.03863056602754763, 0.03963833302259445, 0.08405372899557863, 0.0452970538421401, 0.029768006410449743, 0.030006178987345526, 0.021870306626494442, 0.11761389459882464, 0.10389197591160025, 0.026098809637395397, 0.03429862544206636, 0.021360687811725905, 0.025470404785924723, 0.02646697934583894, 0.05505150702915021, 0.026584805255489688, 0.024393237229170542, 0.02113342098891735, 0.044792220395590575, 0.03719976976779955, 0.011801954658169831, 0.049955006755356274, 0.06718241716069834, 0.015945496603048274, 0.014405815828857678, 0.014982546845983182, 0.010246855872017997, 0.02668444812297821, 0.023897703105051602, 0.019508986101884927, 0.15121310310704367, 0.024086220489282693, 0.09631381862397705, 0.028294299596122334, 0.032556391786783934, 0.05942680260964802, 0.02999000610517604, 0.04746334474267704, 0.10415846375482422, 0.06427043663071734, 0.03315561284710254, 0.03610591024958661, 0.017421617305704525, 0.03252486365714243, 0.032374293343829255, 0.03607994610709803, 0.02982015521930797, 0.040700348892382214, 0.04005270078778267, 0.0462597966460245, 0.05987559924168246, 0.042041704058647156, 0.04167262850595372, 0.03079398867807218, 0.06652480816202504, 0.03798263972359044, 0.014730048698506184, 0.06925880217126437, 0.03238691409517612, 0.03170058610183852, 0.023193382059356997, 0.020172645936587026, 0.04588902475578444, 0.01949602777936629, 0.020306437775226574, 0.017053001460486224, 0.028753691552472965, 0.03291549626737833, 0.012648132779369397, 0.0069432919346062195, 0.04857028302337442, 0.03619002145049827, 0.05795632901468447, 0.03011891758069396, 0.07734875806740352, 0.022398814159844602, 0.06790058540978602, 0.006546916373606239, 0.037807367342923365, 0.022490697979394878, 0.05331540393776127, 0.04372701541121517, 0.031208536255040338, 0.04387738216402275, 0.026944654428267052, 0.06019117909350565, 0.054781141358294656, 0.03896047314628959, 0.03698047064244747, 0.053620310433741124, 0.018098306709102223, 0.04518850180985672, 0.03908942533390863, 0.025883602078205774, 0.09571970693234887, 0.014688166124480111, 0.0231552246425833, 0.024864306773192117, 0.03825091211391347, 0.020964872890285084, 0.05495141293587429, 0.039014257224542756, 0.06760699009256703, 0.04678088779162083, 0.01159026360671435, 0.012861325089553637, 0.039013578689524105, 0.05643317735354815, 0.01747174238386963, 0.007367461138138813, 0.021310018209208335, 0.04342360169227634, 0.07589279833648886, 0.003627523696715278, 0.06398222209619624, 0.022984427200364213, 0.009276657664616193, 0.019479352781283002, 0.026782889983483722, 0.024352050153538585, 0.025836827266695242, 0.018623743871492997, 0.027884781659979905, 0.02044246199407748, 0.04366185908604946, 0.026701559079810977, 0.02898008136876992, 0.010149840631389191, 0.034553971740284135, 0.06406294740736485, 0.05675256039415087, 0.03996092214116028, 0.004498825001064688, 0.04962295885863049, 0.05966623726167849, 0.02570054181186216, 0.05253953646336283, 0.027619574551603625, 0.004888499604671129, 0.03363816998898983, 0.0112440758883687, 0.036018833850643465, 0.024796953690903525, 0.016776880116334984, 0.04047446119199906, 0.04682535219139286, 0.03453300840088299, 0.028396108686657887, 0.017046585911884904, 0.012030222320130892, 0.06669006536581687, 0.03815412587885346, 0.03391195208366428, 0.02218361508234271, 0.0065564637854030085, 0.04140486840956977, 0.03994909866846033, 0.039656897740704675, 0.01617261584449027, 0.04581644186483962, 0.014070358293663179, 0.01881221715094788, 0.02467448660172522, 0.03640883881598711, 0.08475822476404053, 0.0376288787062679, 0.015129436106820191, 0.007580804422364703, 0.026137006069932665, 0.05380551656708121, 0.0554343602353973, 0.010238141786041004, 0.04827822458797267, 0.07141895232988255, 0.03299898321607283, 0.04626442425485168, 0.021286162614290203, 0.02162146069375532, 0.14259399846196175, 0.05832337574767215, 0.04099039886412876, 0.10369998442807368, 0.052453895165984116, 0.0171676518262497, 0.08046267061893429, 0.045204016513058116, 0.02072392001615039, 0.05067371783245887, 0.05059832241386175, 0.07715205755084753, 0.026622504661125795, 0.011846698105468281, 0.04129122057929635, 0.04507110168093017, 0.007577033463998565, 0.008906720372449075, 0.02848311553576163, 0.032317103019782474, 0.038132137951574156, 0.04155815286295755, 0.04926778988114425, 0.013931981254635113, 0.02004972762162132, 0.03375101036259106, 0.10499341466597148, 0.03160882102591651, 0.2312381932778018, 0.05071638072175639, 0.016348741482943296, 0.07718493935785123, 0.03106006940028497, 0.028219855822888867, 0.035493332227425914, 0.026451057521626353, 0.02279414901775973, 0.02998644718900323, 0.06354164252323763, 0.03200114658102393, 0.014885903103277087, 0.0349505449246083, 0.03135692847094365, 0.09172912713672433, 0.0028438768183280316, 0.02040561754256487, 0.02116085585605885, 0.07057017966040544, 0.05382233066484332, 0.039407994132488966, 0.03520017456529396, 0.01807831706745284, 0.05706781454916511, 0.028303051001525352, 0.06721217092126608, 0.08344301355204412, 0.026206143699320297, 0.01985905079969338, 0.08374194215450968, 0.030409897145416056, 0.03756093360217554, 0.013095863263255783, 0.02465583197772503, 0.026073854815747057, 0.05619581562599965, 0.05721922285322632, 0.038303871772118976, 0.029473936118717705, 0.030101363879761527, 0.039416618312575986, 0.042914764889116795, 0.03692751098424196, 0.08221953348921877, 0.041727002909673114, 0.06907842720725707, 0.031796917718436034, 0.025259840102600198, 0.03366118589682238, 0.032960812228598764, 0.028018902588103498, 0.02423889426115368, 0.015699073040325726, 0.02555064664089254, 0.010109345661476254, 0.04432375981871571, 0.016000965144485235, 0.048327788178409846, 0.09868931544146367, 0.033311730184193165, 0.04252730103741799, 0.06089447385498455, 0.0557324169203639, 0.029657883569598198, 0.014375899219885468, 0.018136319937184453, 0.014779005000101668, 0.05028322771457689, 0.023358542571908662, 0.04475282465240785, 0.05625586597515004, 0.003907993602167282, 0.05113017173217876, 0.01989780871995858, 0.03611994913912245, 0.03821071909208383, 0.1137832658631461, 0.04287346585520676, 0.037452544418296645, 0.0037479581494283465, 0.02976878672572119, 0.07306024033044066, 0.01694353001325258, 0.02165358593421323, 0.03073935303837061, 0.012056122849961477, 0.0446145426082824, 0.04447188062061157, 0.049979125282594135, 0.019316010742581317, 0.041121848060616424, 0.053788400521235805, 0.023052457121333907, 0.03386902117303439, 0.04968986580414431, 0.05129459773057273, 0.001400922907383314, 0.05123615890209164, 0.05162980420781033, 0.05569211533293128, 0.024362375760184865, 0.029137755943728343, 0.08586043026298285, 0.07384844696415321, 0.0025773018257625934, 0.008444264830489243, 0.007115443902356284, 0.03332646117944803, 0.025528248199926953, 0.023265742730083208, 0.04794421911771808, 0.021226985878976326, 0.0422908383687692, 0.023281744282160486, 0.05852323823741504, 0.0706615104739155, 0.049189256238085885, 0.08505768262382064, 0.03666000194581492, 0.02730279878181006, 0.01904516670453761, 0.05161774664052895, 0.024950675799378326, 0.025610386560271894, 0.09949441759714059, 0.08297616788851363, 0.03139108931645751, 0.19482436722942761, 0.1060324078425765, 0.08202351150768143, 0.08001655420022351, 0.1853974259325436, 0.10396829074514763, 0.18142849818936416, 0.1700258529079812, 0.10490599899951901, 0.08154553786984511, 0.09942916288439717, 0.1640493707465274, 0.12065025738307408, 0.07782185303845576, 0.10040541192782776, 0.09764290587710482, 0.07999845088592597, 0.11158344176198755, 0.12451895193329879, 0.14462351027343953, 0.26583009851830347, 0.12533746872629437, 0.15755291362958296, 0.25512379301445826, 0.12159078834312302, 0.19383058484111512, 0.2230771676238094, 0.12927246971854142, 0.19583812568868908, 0.1423838154545852, 0.16096362418362073, 0.12344586237200669, 0.14426081973527158, 0.06433031056076288, 0.08690012911600725, 0.10561299177684955, 0.08745270089379378, 0.09954156899558646, 0.08178748988679477, 0.12808360851236752, 0.20556255030844892, 0.11956337999020304, 0.1402833288801568, 0.09260360271270786, 0.09343015336032424, 0.16177937255374022, 0.1502604806529624, 0.13672473840415478, 0.3500848231571061, 0.1116738294118217, 0.24112241289445333, 0.11199139058589935, 0.08501182044191019, 0.16044567126248563, 0.16169060660260065, 0.08066608184682471, 0.19060809990125044, 0.14409783562379225, 0.13672012436602796, 0.16711535836969102, 0.1153284665197134, 0.09612450735377413, 0.08322189256016697, 0.14497192443481513, 0.11924483494034835, 0.1167754695883819, 0.22127522288688592, 0.10943027372871127, 0.11951913950698716, 0.15204250360173838, 0.0933851393471871, 0.1334177487130676, 0.18099775058882578, 0.1290349553206137, 0.22410022201282637, 0.206312643630164, 0.10956827418080398, 0.11166065904710974, 0.13534818084112235, 0.12318985110947064, 0.10231340490281582, 0.11585120989808015, 0.1042202307975718, 0.052587376574852636, 0.1648950967937708, 0.2417062244244984, 0.08764146255063159, 0.12593068475169794, 0.17705977761319705, 0.20536497448171886, 0.15293943190148898, 0.10917430317827634, 0.23871046517576489, 0.1925392784178257, 0.12751339482409613, 0.1392677112349442, 0.10523060336709023, 0.12162862345576286, 0.13986866255956037, 0.09667714019971234, 0.16787366196513176, 0.14565713623804705, 0.05483050138822623, 0.1552055895860706, 0.08267629612237215, 0.07856668771377631, 0.11411732222352709, 0.24340934732130595, 0.14078824035823345, 0.17760168282049044, 0.17101351491042546, 0.11929265808846269, 0.23150336476308958, 0.09615505500031368, 0.09092188759573869, 0.06315773419503655, 0.21282505989074707, 0.1439797841012478, 0.2802341484597751, 0.1301551352122, 0.115298543125391, 0.08144119275467736, 0.1946925821581057, 0.1495838048202651, 0.16408724657126836, 0.2100878767669201, 0.1713291694011007, 0.05065408442169428, 0.08833218405821494, 0.09375973817493234, 0.22323181932525976, 0.06174078344234398, 0.15413529558905534, 0.10991708867784057, 0.13402887806296349, 0.11513097211718559, 0.0850878774321505, 0.1550379235829626, 0.09091613361878054, 0.08986720668950252, 0.07074059373033897, 0.07444715912320785, 0.1730490792542696, 0.14622458150344236, 0.1284755031977381, 0.19945874783609593, 0.10418900461601359, 0.10006345063447952, 0.17883760721555778, 0.09724421905619757, 0.1250858272292784, 0.10844417235680989, 0.17878929552223, 0.0852100680183087, 0.15112250511135372, 0.1367042466465916, 0.15281359079693044, 0.13080986722239427, 0.07118307998669998, 0.15365848903145107, 0.14772768584745272, 0.11566876540226595, 0.12426052508609635, 0.11487075393753392, 0.13256094897431986, 0.12545611735965523, 0.11982810364237853, 0.09189755309905324, 0.10774797507162605, 0.17451837898365088, 0.13033375277050904, 0.09225192479789257, 0.10459349291133029, 0.3167605570384434, 0.11411471664905548, 0.11136039373065744], [0.07144361707781043, 0.10454598867467471, 0.0295378473321242, 0.0036536824939373347, 0.029488449982766594, 0.015076663045744811, 0.018708118004724383, 0.04964456341362425, 0.028943413336362158, 0.016317903762683272, 0.031899868444140465, 0.023880105299342955, 0.03382909617253712, 0.035389156746012826, 0.011190693842114081, 0.02954246137025101, 0.029708400501736572, 0.03706341476312705, 0.00625518151459151, 0.06375242942678076, 0.01847925323194691, 0.01679432185898934, 0.034243331623396704, 0.0890014570738588, 0.015439764097599047, 0.01872256231893386, 0.050711322243192365, 0.021037907007017305, 0.03638235220153417, 0.02110350437994514, 0.05708124954253435, 0.0308480984531343, 0.005212184981376464, 0.008686638387319232, 0.06966531250093665, 0.11271658845778022, 0.02004548508141722, 0.03938973814781223, 0.02679564813817186, 0.03733321724991713, 0.03487462703404682, 0.015056605550593563, 0.046630714421293566, 0.0014481153359936017, 0.03740408005458968, 0.09177134558558464, 0.03883229448859181, 0.04914605730612363, 0.027705175136881213, 0.03757045005581208, 0.08846089536590235, 0.03148945653811097, 0.01682526814485235, 0.0728137217728155, 0.050464457632707696, 0.04250973037311009, 0.03897269695465054, 0.04058046532528741, 0.027093348592253666, 0.01735643044646297, 0.06401238297777516, 0.021115755329706838, 0.027287816728598306, 0.03807224027280297, 0.05363344008635197, 0.039729327961270294, 0.02347538630211992, 0.030786728353372643, 0.02971113160518663, 0.031116906886122057, 0.02678838442079723, 0.017782893098358597, 0.03275142310719405, 0.0077318166316087756, 0.0973282013354557, 0.04258398585287588, 0.0572970983173166, 0.035441308947546143, 0.021504686513383473, 0.02334555032263909, 0.01999530232777553, 0.041030347613351684, 0.029800976427005868, 0.05189263813995889, 0.015085075183638504, 0.05400994220482452, 0.044717652789716206, 0.04700372547709516, 0.09316345517124448, 0.05700582358986139, 0.018123426075492586, 0.005306751558756722, 0.019186374930930988, 0.052475876307913234, 0.03215344037328448, 0.03411781282297202, 0.09847599760230098, 0.04855872417933174, 0.025653380235391002, 0.042249800570841343, 0.04033449298835226, 0.029089142302317277, 0.02711352313469563, 0.0626768632126706, 0.06506639213434287, 0.07355387455650739, 0.05349492394764509, 0.014583371479862502, 0.06203028719340052, 0.05579195497557521, 0.05038294522091746, 0.04336231980206711, 0.02259340273615505, 0.044142431513007195, 0.016654469006295716, 0.028874274010636976, 0.07997674455067941, 0.023009517729016285, 0.11215138914329664, 0.04006685163559658, 0.06393458215253693, 0.04230612915541444, 0.0073748139132346424, 0.09871577152184077, 0.03465945340160813, 0.043999640603682826, 0.032680360134691, 0.04682164399751595, 0.03901987888717225, 0.00277451633259521, 0.06675561863396849, 0.11046180980546133, 0.042123135046235154, 0.02584791792157505, 0.03552700113505125, 0.037435374089649746, 0.007350824307650328, 0.04468873023454632, 0.024171327440334216, 0.014188666811345943, 0.02601224722872887, 0.010812913533300161, 0.02098186171081449, 0.016531291151685373, 0.03513173752331308, 0.03838168277538248, 0.009089602523350289, 0.09147554502955504, 0.02851078619382211, 0.051485048939606974, 0.007732347585260868, 0.020418748891513263, 0.012155027810617216, 0.09000739202435527, 0.00978167770829584, 0.04790627204680017, 0.019478652193876247, 0.03943250281736255, 0.021703275053628852, 0.033351448231509755, 0.05896257609128952, 0.009566431133342641, 0.03793149175388472, 0.028361045389569232, 0.028963229951581786, 0.1057747138131942, 0.028452042024582624, 0.023331942302840095, 0.03384810533108456, 0.013851961619885904, 0.017152496746608188, 0.04267517417403204, 0.03172397181125624, 0.06180430789078985, 0.042654729913920164, 0.046856843001608334, 0.06959402561187744, 0.036901489166276794, 0.04683119437790342, 0.013301511112201427, 0.03102438524365425, 0.007699224898325545, 0.030518971649663787, 0.04221642004059894, 0.027763149168874537, 0.023269730819655315, 0.0523331668227911, 0.028306988200971057, 0.0046464224828274125, 0.019460550575916256, 0.021283589270231978, 0.028583331765340905, 0.04826242150738835, 0.048868024189557345, 0.027421106451324055, 0.027661964330556135, 0.017700932853456055, 0.04627845635903733, 0.02691803210681038, 0.07292439761970725, 0.02488789434677788, 0.06312943249940872, 0.0738701940115009, 0.05255062033289245, 0.02158811069758875, 0.02857426314481667, 0.05397666684751, 0.0632231178294335, 0.021410013914906552, 0.03871283161320856, 0.021373810678986565, 0.01387607675444867, 0.00910793908406049, 0.03549185980643545, 0.018414892489090562, 0.044589148435209475, 0.03750108002818056, 0.03990444767155817, 0.03560139910717096, 0.05212722805195621, 0.022593180515936444, 0.030236321102295603, 0.015030648193455167, 0.034396154672971795, 0.005262603101852749, 0.01947714584613485, 0.10544670998517956, 0.026392978316705142, 0.09742262626865081, 0.020906635925972035, 0.039140101721776385, 0.01667341709669147, 0.05199562279241426, 0.031221760902553797, 0.06587781823639359, 0.026919536758214235, 0.037174192390271595, 0.05348876963502594, 0.049877297532345564, 0.029374266109828438, 0.035209389070847204, 0.02482012566179037, 0.04025800173570003, 0.0825688908142703, 0.020618204260244966, 0.03885839094540902, 0.03914278193510004, 0.006945248659966248, 0.017790881151865636, 0.002007373546283426, 0.0618978100163596, 0.02696903419148709, 0.03452528327969568, 0.009308802412955888, 0.05935139022767544, 0.027608972441937243, 0.016374686965718865, 0.05979358471397843, 0.02369985756065164, 0.05974498125059264, 0.008288852321649236, 0.03502116684934922, 0.023529477417469025, 0.03791424000103559, 0.11998487237308707, 0.0316732886380383, 0.027170180808752775, 0.024216163338028958, 0.06034295380647693, 0.024594232872394577, 0.015404035836192114, 0.009663374279625714, 0.02318270700717611, 0.03503919552479472, 0.024646963525031294, 0.026508117227682045, 0.028670530300587416, 0.03228193794244102, 0.044726019126496146, 0.07413167426628725, 0.1658377583537783, 0.0470940690221531, 0.06634121694202934, 0.04160130429746849, 0.009531716433619815, 0.037156757432967424, 0.044236082916281054, 0.02183115345958088, 0.030101614937718426, 0.009562696646233755, 0.02707839707311775, 0.020706712368077466, 0.050659034334655316, 0.0435789488921208, 0.03438439226842352, 0.08526724137898002, 0.0380039966133024, 0.09381304388599736, 0.059149919609938345, 0.059426144430679936, 0.03197365573474339, 0.03397170048473137, 0.06878307448433978, 0.008394425585200744, 0.05768434503780944, 0.028790461365133524, 0.028081599223826612, 0.03501632210931607, 0.03650081763044, 0.029536761676094363, 0.019116266996466687, 0.018559931045664207, 0.0144054782576859, 0.07681970431336335, 0.0487193978790726, 0.024512308250580515, 0.01480346279484885, 0.024800760272358145, 0.06542483504329409, 0.025672019592353275, 0.02411842715394284, 0.04230275344369667, 0.04161969259647386, 0.039125933910587, 0.030560582809682404, 0.06646454068166868, 0.025535172649792263, 0.04224677091198308, 0.02405467369992818, 0.02187249150925449, 0.01738311892508396, 0.0077783098510865656, 0.023713703067707162, 0.003961772167323423, 0.03625557811132499, 0.04423647985926696, 0.050095375294664075, 0.05647608790812748, 0.022401889619816626, 0.02657618446807776, 0.03181022718282683, 0.02833595316457961, 0.0548112411717219, 0.007526101777330041, 0.03473501166860972, 0.06464988698384591, 0.010374665576299387, 0.04199979095054524, 0.05048960414049881, 0.07578535910163607, 0.04961259423622063, 0.07482825153108154, 0.20320754524852547, 0.15194324749921048, 0.17387322788791998, 0.0974908054673246, 0.10608829877206258, 0.057545313212488375, 0.13451104504721506, 0.12194072242294039, 0.14164997983191693, 0.10984012923602547, 0.09799120468752724, 0.10397658244307552, 0.14023676780717714, 0.19792540797165462, 0.12867583387664386, 0.09472861832806043, 0.1273709838943822, 0.11734751532120363, 0.14802431421620504, 0.20259695872664452, 0.09307787154934236, 0.09906865722898926, 0.12721466299678597, 0.17899972280221327, 0.10138779492782694, 0.15271996653505734, 0.1445337129490716, 0.09265964970524822, 0.18219483563942568, 0.10782792685287339, 0.15268469628478798, 0.16363760855581078, 0.21310248571847165, 0.10328402210559164, 0.19651805848947593, 0.1767736936786345, 0.06812921099896942, 0.12345557899347373, 0.07181537284382752, 0.14160654002002307, 0.12485617026686668, 0.1604951907481466, 0.0904823529667088, 0.14051913336983748, 0.16596224238829954, 0.14341119889702114, 0.1255994782383953, 0.14932450944823877, 0.09736222308129072, 0.07998492089765412, 0.24319900146552495, 0.06971079470323664, 0.22104095188634737, 0.14941832369991712, 0.11572744511067867, 0.09709467672343765, 0.1099865028102483, 0.09999584819057158, 0.17356974631547928, 0.10560386548084871, 0.11227583925106696, 0.1467994363712413, 0.11825112040553774, 0.1518136201692479, 0.1878827368574483, 0.09597212195928607, 0.09407093469053507, 0.22803594225219317, 0.17447651337300027, 0.12197392992675304, 0.14156143101198332, 0.0821182621376855, 0.07827771322003432, 0.12556328518050058, 0.2535347454249859, 0.18524889461696148, 0.10273902956396341, 0.14200289946581635, 0.12996340835733072, 0.08265266274767262, 0.09507964484925781, 0.1177571469119617, 0.11595263731266771, 0.10211714543402195, 0.08335370477288961, 0.1445935597377164, 0.14942904455321177, 0.11607722991279193, 0.23090014713151114, 0.11004931479692459, 0.1238563624875886, 0.09056733947779451, 0.14738683056618485, 0.1376553898943322, 0.14970079782818044, 0.09133813490292855, 0.11825069971382618, 0.12700783195240156, 0.09946627196456705, 0.11702289059758186, 0.1443151703902653, 0.1420348041823932, 0.06889485634331192, 0.20736738560455187, 0.28071577261601177, 0.2161041482218674, 0.24351142612951143, 0.10879941258047308, 0.13633555785885879, 0.09651000345391886, 0.09706351161003113, 0.10342928288238389, 0.13511042217058794, 0.12715759820171765, 0.1302247257637126, 0.19739521427878312, 0.199565359258226, 0.1277026789528983, 0.16628105885216168, 0.1307077205606869, 0.20579524710774422, 0.3097585913326059, 0.08571440952696971, 0.13158053372587475, 0.12316353752144746, 0.10273567760097128, 0.13058671062546118, 0.08704337464379412, 0.11877195031515189, 0.12784958178443567, 0.1184112410992384, 0.2552264689334801, 0.2122467580650534, 0.09457245349351849, 0.11752770708075591, 0.11892068519123963, 0.15364604469920906, 0.15571860277226993, 0.14200334729892866, 0.08604887979371206, 0.07570333100323166, 0.15562235936522484, 0.11970615732882704, 0.08970019886536257, 0.1302454210817814, 0.11229714525065251, 0.06409551030290978, 0.1840548494032451, 0.06759146521134035, 0.15963398053177766, 0.1404936747359378, 0.15533133569572652, 0.09933428333273955, 0.14259694330394268, 0.0999376027445708, 0.1101604588329792, 0.10710050338613135, 0.07837006183607237, 0.11530197651258536, 0.08696144154029233, 0.1295313715402569, 0.10742155223020486, 0.12805114739707538, 0.160629540681839, 0.10988084133714437, 0.16461662602211746, 0.1222200481487172, 0.08185522125235625, 0.1313099611018385, 0.15211544611624309, 0.05554338724219373, 0.0996316648753626, 0.1251711869346244, 0.13004875449197634, 0.15434101383600915, 0.11993353441357613], [0.029032739078892127, 0.010498915516239191, 0.08311849060867514, 0.04436018357851675, 0.043466804016913684, 0.028636298208896602, 0.028105677038963352, 0.016808549041992853, 0.051674299141658206, 0.03701997834390827, 0.025268708555293933, 0.03432676089661462, 0.023813384950959256, 0.002031537450550656, 0.0647731428699834, 0.046169507383768044, 0.07265115156769753, 0.05636865545862487, 0.04228148476353713, 0.06398969955210175, 0.06649075927478926, 0.041943245234766176, 0.04103032725730112, 0.034275731670537164, 0.04090857432622995, 0.043884231975036006, 0.030832987478268997, 0.030564341893685714, 0.04366125858255795, 0.005700853179275457, 0.0169241663201579, 0.08937413564750127, 0.016690957226923535, 0.0385255593407367, 0.02971670577036483, 0.05371837231463619, 0.04498762491026095, 0.051116173554744036, 0.0330211882745581, 0.038108412974647114, 0.07473753139908824, 0.02029726737444954, 0.05668038801689233, 0.012749125931545027, 0.021750229676919322, 0.025583983066358736, 0.009161946230701037, 0.11079974060079881, 0.048735445232263634, 0.022811765483181392, 0.022750739739941697, 0.030781279717172896, 0.02040634866404746, 0.0411237174245928, 0.03841166723785656, 0.04500809631177357, 0.043572672443198304, 0.041922366712242365, 0.044110160387520275, 0.10677332058548927, 0.020843391373221363, 0.03529860624777419, 0.014333853797454919, 0.059598621247070174, 0.05103007085355265, 0.02608946112117597, 0.02337554157046335, 0.039107233485473056, 0.025764809256153445, 0.03799965398918305, 0.05584327597171068, 0.01610113387661321, 0.00791128320685987, 0.013631290157458611, 0.0271921331129436, 0.01578087722217398, 0.0317162093706429, 0.030938245223036835, 0.04284631766911064, 0.01165980496443808, 0.04435837867536715, 0.03668036478172455, 0.023039547992604117, 0.04673253877886704, 0.046725468443972726, 0.009560821345075965, 0.07679691232208695, 0.03180735358702285, 0.042747444938868284, 0.016039816363315498, 0.06691442296973296, 0.05842925435198205, 0.026012812109131898, 0.009807222855410405, 0.0767195186178599, 0.02026400389149785, 0.011180659157357045, 0.015093193855136633, 0.011106153467803128, 0.09645795303263835, 0.019082545502377406, 0.033833391299205165, 0.05233785889244505, 0.02664233823972089, 0.03611037840268441, 0.01802497573329934, 0.028535223632518734, 0.028874453822416917, 0.0412884351930448, 0.02763891958498529, 0.040032300632447004, 0.049551641435495446, 0.07296725389148508, 0.12442762111978871, 0.039722630820636234, 0.0688580661746008, 0.04677751207990306, 0.05189994935478483, 0.0152562950139067, 0.04907625301608017, 0.014170470198483338, 0.022475824491786103, 0.031418688728341033, 0.02847806384254779, 0.03859619822885309, 0.011476722645706363, 0.009610872632557792, 0.009012544693957483, 0.020714985406292335, 0.025087244542581693, 0.0451730990649334, 0.019894843521927084, 0.02735283225774765, 0.028654214926064014, 0.05298347817733884, 0.053223917061196904, 0.04383980489469, 0.032034133560955524, 0.03622382267245224, 0.013183859077149203, 0.026057882101408074, 0.022196636169350574, 0.026117152135287012, 0.009816918272658117, 0.018791189350719963, 0.026588513449366604, 0.02868370745064957, 0.0442622641899756, 0.07617379325841155, 0.04204752588910716, 0.0601502905732819, 0.05642344376870564, 0.02532202105170914, 0.028115841493542706, 0.047784254487071715, 0.0468114761502615, 0.055177497411412854, 0.06652401427605323, 0.03554125037044287, 0.01908840804493853, 0.027114585041999817, 0.03301632996382458, 0.04244654179949846, 0.041866876118417294, 0.034924699525747976, 0.011742336026925062, 0.05632254561143262, 0.0342434334036495, 0.010268430741104697, 0.04866509132885507, 0.0382857345310705, 0.049539217459303994, 0.028298435267060995, 0.051617634682250876, 0.05623089249378868, 0.057058566116860936, 0.03467650498662676, 0.044480928885085244, 0.007906837954318948, 0.012281371031089552, 0.03448008606210351, 0.058989988906042914, 0.07900851579116923, 0.04508515753384147, 0.03596522958417024, 0.0405043608375958, 0.0207542369607836, 0.031163043874715055, 0.03449305286630988, 0.04286819024543677, 0.01425596306632672, 0.01983424525574914, 0.060919600006725104, 0.06385781948587724, 0.052981096519423385, 0.0206896268563079, 0.041945338515298705, 0.0580296107966985, 0.013947637602021652, 0.042460282133626084, 0.03619070677086711, 0.0217478819457548, 0.019938349490985274, 0.03357922565191984, 0.04479068351377334, 0.04598091196800981, 0.0317643039327647, 0.11089904420077801, 0.013665281369217804, 0.0025789769590898815, 0.04368848819285631, 0.05331453202026231, 0.030141014073576246, 0.09940557022179876, 0.046631155469055684, 0.10374853360865798, 0.10070314630866051, 0.0532750243188015, 0.010394142924009689, 0.06307805382779666, 0.0303147393944008, 0.07857182422386748, 0.01987710831287716, 0.08273589185306005, 0.04631282415773187, 0.018239229950787764, 0.08123010051037584, 0.028053563853193606, 0.043628217319824865, 0.016510785823421817, 0.04897452365340931, 0.0324217636537339, 0.07119663711637259, 0.032087680151952166, 0.011238223523832858, 0.006209276500158012, 0.07356722812567439, 0.023216686344572475, 0.05043490743264556, 0.030118371360003948, 0.05123274587094784, 0.04211814781384809, 0.04016570740246347, 0.020008287791694914, 0.04263805830851197, 0.038221480657479594, 0.06774589978158474, 0.005001610968195434, 0.010038148678307022, 0.043896913794534545, 0.03465537540614605, 0.010506362438068857, 0.0718044348593269, 0.029312139443520988, 0.009188973976831352, 0.04793923527800611, 0.031547793586339266, 0.031174270236598592, 0.02854375960305333, 0.01939002364607794, 0.09854527602770499, 0.01503579827424671, 0.0060994068376852995, 0.045907698039497645, 0.022295724334461347, 0.0378416401467153, 0.05164633332086461, 0.008306113404354878, 0.08394291744168315, 0.023414411449006627, 0.11069290526211262, 0.03892239715371813, 0.0023119006987794167, 0.06033164941306625, 0.009587371572186905, 0.017910518750016178, 0.03955444913091404, 0.02297088873040463, 0.03972773340397647, 0.08339275446321283, 0.018288832556988512, 0.02181843262431877, 0.017467606712930968, 0.025367416740794266, 0.04012358394850578, 0.010598185189467455, 0.03287998513717737, 0.03573450392910412, 0.03722121486706393, 0.06226825620979071, 0.06807718771908965, 0.054225600989801545, 0.043086522458387275, 0.044689235743135214, 0.040117137865828614, 0.027206709741481712, 0.04638573613816074, 0.009385537090046065, 0.05438789638823696, 0.05505665032459157, 0.03246078280998128, 0.04168450286878007, 0.03419361196990524, 0.046713281955037794, 0.013089897244104316, 0.01123935158830136, 0.013730562375193196, 0.03521409810387662, 0.012687981444677072, 0.03579975864184754, 0.023026974738708565, 0.02730719229605581, 0.017802251702440635, 0.03787318863240736, 0.010513484511258346, 0.031472418523792706, 0.04658688784443906, 0.02232602940473173, 0.02914230552102838, 0.027173103598345603, 0.03575046307274273, 0.023502191828031625, 0.03405907204640763, 0.03034584004698055, 0.07254194814179625, 0.053446089782352955, 0.04616244722689901, 0.03609651593225343, 0.021590432983690074, 0.028756429441273212, 0.053506177450929365, 0.04552961154175656, 0.01512516981789044, 0.06316893680819444, 0.018426417406382303, 0.023762849359107868, 0.02073019476873534, 0.005648285799127604, 0.030524192976632288, 0.04385148248236094, 0.034740412807358165, 0.05156497357945357, 0.02872950177905815, 0.023211716075560877, 0.048807994196457524, 0.08043142408132553, 0.026163988014949218, 0.09858373539256197, 0.0458998372113066, 0.012123967021969813, 0.04982363559039576, 0.04355475911870599, 0.086552854893463, 0.16230253662381852, 0.1338611442063536, 0.09021600761583873, 0.1624230444431305, 0.14201596805027553, 0.22943008744290896, 0.07852691877633333, 0.10151017550379038, 0.14896450590874466, 0.10479022735463721, 0.09068285327936922, 0.1481701313917126, 0.0792249548914177, 0.08823317901364394, 0.1466129749481167, 0.1281233299523592, 0.21142871624657086, 0.17278844038290636, 0.15169722427214893, 0.16731319203972816, 0.14830384350248746, 0.1234123156006847, 0.12991836720279284, 0.07239510637841054, 0.21800026004867895, 0.10284644165741545, 0.11473522335290909, 0.11709974147379398, 0.1513127934719835, 0.13046091023300374, 0.2448306339127677, 0.08313369657844305, 0.09794066061398812, 0.1050961177263941, 0.11878979578614235, 0.1170168516359159, 0.14470368597124303, 0.09968743366854531, 0.14355606612350258, 0.16446752473711967, 0.12689655220934323, 0.13699455106897013, 0.13956856009151253, 0.10121089406311512, 0.13620721974543162, 0.1233056363250528, 0.2761321599994387, 0.1146344066198383, 0.09569094383290835, 0.17720084504357406, 0.11961749994329043, 0.13897828890808991, 0.1122824956795999, 0.1380588739578213, 0.07816088984587363, 0.11559093743562698, 0.20734373187380178, 0.07097336516848632, 0.1281667019107512, 0.13002146381352628, 0.17215994053653308, 0.11969325159277235, 0.09825307170727424, 0.156008635780641, 0.1436270001743521, 0.14035971835255623, 0.13161389050739153, 0.09756895913077251, 0.14430964711521352, 0.21165948600641318, 0.07987805841756718, 0.11486829764076642, 0.09683109979544367, 0.12742989430470125, 0.1672749226646764, 0.15574543204690727, 0.11529757960566453, 0.09933735709637403, 0.13636363563793047, 0.1336334821368967, 0.1441358607262373, 0.07461992092430592, 0.15879284138126032, 0.1530282385647297, 0.08186683098652534, 0.12047256263239042, 0.14464134217372962, 0.20738946513405868, 0.10985499593828406, 0.16468917498631136, 0.13669402790921076, 0.2249630878546408, 0.05663632734545639, 0.22974631190299988, 0.0822131959721446, 0.09240207781216928, 0.1331098430923053, 0.12371933912592274, 0.13062275440565177, 0.059959194755979946, 0.10985190860394921, 0.1371109333953687, 0.12979552522301674, 0.09442658203520946, 0.10023605637252331, 0.09956051369330712, 0.10531455850494759, 0.2148218256022249, 0.18043624929019383, 0.08588266585554395, 0.13573254378778593, 0.18615849795086042, 0.2162306271493435, 0.1808953189424106, 0.2191342277718442, 0.17761249866868767, 0.12607259356549808, 0.07954905035772494, 0.18084081900971277, 0.1139658053538629, 0.18826450780034065, 0.09125871237899576, 0.16246906268809522, 0.12241668759712152, 0.13790737065885747, 0.121004724076816, 0.12582560681871005, 0.08745399011032921, 0.07180321349629334, 0.07391305028327874, 0.09300268986927611, 0.08647320845297404, 0.1407490074634552, 0.14884881568806513, 0.09008730987885169, 0.1722198144665786, 0.16653123471353734, 0.09688144709382739, 0.12774601019918919, 0.11126828260187592, 0.11593996227851935, 0.13276688435247966, 0.06394287385046482, 0.12126180742468153, 0.1061997345781752, 0.156680968989219, 0.10902499833277293, 0.18814328073390893, 0.11246810893395118, 0.15060194661574705, 0.21922791988721915, 0.10021734916205917, 0.10013015741216284, 0.1679083351045847, 0.17459647836429731, 0.11019632619406496, 0.14950338484985487, 0.2279882819524833, 0.1402730287185737, 0.10767636248575789, 0.08458922204694577, 0.12386056940470423, 0.2712099855499608, 0.15217267375971588, 0.14047245016055449, 0.12518076784908772, 0.07594141537057501, 0.07152006761836154, 0.19766407699457236, 0.12647868320345879, 0.1613779512367078, 0.10639106788273368, 0.18735113181173801, 0.16884691188377993, 0.10922350375247852], [0.08488501581762518, 0.0340664646854358, 0.038328302425465414, 0.025343992015612975, 0.05252609468464341, 0.03621460138154881, 0.0696395824530295, 0.034289241302758455, 0.031858637263732295, 0.0623160522165043, 0.021594828194273368, 0.0353990565719349, 0.029170474902327572, 0.013939345055924994, 0.033047247411949296, 0.03807405196130276, 0.05591828801802226, 0.0758502541908196, 0.02301575685851276, 0.02381912705355457, 0.04664190685642617, 0.054318129417619536, 0.029731562294598137, 0.006102116736916027, 0.037336504752082486, 0.05170122680387326, 0.005342859799774098, 0.010535523328664047, 0.08432565190430198, 0.025389073882251978, 0.03226896435288446, 0.03494917428387063, 0.034577639041734595, 0.04209061625546642, 0.024305679070364152, 0.03956961438858083, 0.07703008409589529, 0.05771507588880403, 0.033444068261555264, 0.011832049382584435, 0.05736881268343755, 0.02362156310118735, 0.04373418752636228, 0.04154580013294305, 0.06181027899895396, 0.03690186236053705, 0.05582400896985616, 0.022160488912569623, 0.051774247349905114, 0.054620084286268265, 0.04663569486833044, 0.04074056227026241, 0.033090154573853524, 0.025421621510758996, 0.009239642731180149, 0.04902753759441631, 0.040078732783773115, 0.017979313719219396, 0.04618571080001337, 0.1083758370950818, 0.04363840891580496, 0.027644047613388727, 0.049751453035111935, 0.05825763927506549, 0.04438647681048938, 0.02201156913568931, 0.018374249937811067, 0.0537681191095284, 0.058260095571832995, 0.05236307325373803, 0.02722528633395476, 0.02915168966033629, 0.02592186297156981, 0.05267502633588655, 0.034549517157886706, 0.014250604336016943, 0.022993098877902542, 0.043050017274383984, 0.06359983368643693, 0.02146269198107932, 0.06687270663678646, 0.06973639582949025, 0.006252600961098713, 0.02093495797765042, 0.05999907225902591, 0.04901034351704376, 0.044415959157049656, 0.014509660524449177, 0.07229407929948398, 0.06234039805297341, 0.04378534906676837, 0.07722884057355778, 0.01162693927264107, 0.06205491801457746, 0.03876713137807591, 0.03738658742180892, 0.004758410870895854, 0.07154385705611535, 0.06626664594347988, 0.03988941472822002, 0.03716590069234371, 0.021671136242470572, 0.05411401251330972, 0.04298255393015487, 0.02239831374026835, 0.022748132469132543, 0.034130823731954606, 0.04761776913489614, 0.01781958996850465, 0.013962750273224498, 0.03179393555702908, 0.03371162819010871, 0.033749171532690525, 0.041215200908482075, 0.02963215352169105, 0.0226972236830209, 0.024585189696933542, 0.012288801837712526, 0.02396424364165536, 0.0646407064050436, 0.027073538762384226, 0.023740807149027075, 0.016370100068992803, 0.052124398560928445, 0.017070039474804486, 0.034649740172816176, 0.03388299899441855, 0.07699701908443655, 0.03723128093406558, 0.006206036919528353, 0.03546721202188304, 0.015600819473287888, 0.013600776437669992, 0.02149684095223035, 0.02302230641778026, 0.028179796811725413, 0.00952751630185438, 0.0461771612587784, 0.02547818249357598, 0.021971988491714, 0.012886096706746944, 0.024263460621503845, 0.057434379522289546, 0.024304242272462164, 0.040995426808616946, 0.005736164989814694, 0.03932135199595775, 0.021188277152499983, 0.05930247463818107, 0.02891874858843429, 0.026394493146134273, 0.03723594246964369, 0.04426190795909081, 0.04906145755999854, 0.042799648030528, 0.038800104787307124, 0.02880261731999261, 0.03482732975057193, 0.019593417910592895, 0.029437417364014045, 0.03335991634854248, 0.030773089799497808, 0.026171172004459158, 0.045684907851474624, 0.012335074533309256, 0.039686339375163825, 0.04125601818252887, 0.03702420222439936, 0.039033184958887954, 0.035999095266950984, 0.06223260597991092, 0.032430923876485655, 0.21044744604400226, 0.030580311215349605, 0.03926245176366397, 0.02896427150283541, 0.04300286587593811, 0.015098293045801776, 0.04988509389970984, 0.020327407899977903, 0.05820136158061879, 0.0821132884759988, 0.059759637606995444, 0.027028265209602456, 0.045726722571998835, 0.017560399769406234, 0.008096879497835678, 0.038647787246320925, 0.006762214262770223, 0.033351336273231676, 0.02715792816265353, 0.047506377433559725, 0.02477041618632419, 0.08115259145519563, 0.05121791309544018, 0.03380992077291012, 0.010485078490871404, 0.0736482927043523, 0.019729440433106253, 0.025495334162509868, 0.05736251587846449, 0.06891173150922571, 0.015755983468677317, 0.027251289492206912, 0.01644654043151864, 0.030026962514966726, 0.011497119408366936, 0.03613599309963839, 0.035173077269324234, 0.024481412854843905, 0.04467098993648376, 0.09251581385199513, 0.013092876012836183, 0.08751879698996033, 0.03556348257032888, 0.011114958307838865, 0.03978723074708666, 0.06526368976171527, 0.04617774819156953, 0.012220416534026819, 0.008250588883778878, 0.03616786049678922, 0.033938944206706116, 0.03091872377055032, 0.05282567468072687, 0.07094251218118838, 0.02910390722432307, 0.04555557229157005, 0.007714988114977521, 0.027033642599625245, 0.03446795724864517, 0.034637685998209884, 0.055495302858097215, 0.06345326333705868, 0.022633984219282866, 0.013754013393606459, 0.01413349258447332, 0.10123720086578812, 0.06017016486397811, 0.05186651114906583, 0.06891694265816893, 0.003911245905328542, 0.03727006260305643, 0.06092069923345532, 0.02057665925739067, 0.00848714230648641, 0.02418240113183856, 0.037392473713095696, 0.027368136615093266, 0.02608861125606511, 0.05467180222538965, 0.01109348691534251, 0.03765219316950866, 0.011893118382431567, 0.1320303345897368, 0.013844167797027953, 0.027736240166372488, 0.05380779305206878, 0.04618319682776928, 0.03570367469053183, 0.035494719831539054, 0.07951260624187333, 0.02245021827651986, 0.029019643353032212, 0.013307900367570775, 0.029303084393697124, 0.02197439898736775, 0.03857910593173333, 0.07025403662451676, 0.053961464270417175, 0.024219342274591327, 0.0057017424842342734, 0.04972579423338175, 0.08652803408248083, 0.07936547270842961, 0.031121992506086826, 0.018812709088836397, 0.040125334568853886, 0.048036550770380666, 0.012793271419858294, 0.027764496060886552, 0.01641863737521427, 0.05108455043019993, 0.058363884288285456, 0.01296057949574398, 0.027710055500002842, 0.030339265042649846, 0.04742844429399286, 0.09086103657526629, 0.05665309733844229, 0.03502124488087637, 0.07698903272726706, 0.006298717593641153, 0.050511486894850216, 0.03514687563957913, 0.0447456695006362, 0.0671351436259491, 0.02518877373742206, 0.03269130151186671, 0.057368269855422635, 0.03541218622454575, 0.02605167859500008, 0.022238240544019, 0.05411004647612572, 0.013577040434548897, 0.05221430105822427, 0.06698859363262143, 0.004432153846469841, 0.016605935092749338, 0.02775858262819903, 0.022344899463600347, 0.03826499171555042, 0.02075432177766093, 0.08928567503712007, 0.026399627959887897, 0.04220906472099679, 0.029598803525524478, 0.014503857353702188, 0.021642315467553477, 0.0700131431221962, 0.010067833737204117, 0.07472210151276418, 0.043481979452605755, 0.01829366372632129, 0.04023062624037266, 0.05579218228480645, 0.01196438745994653, 0.00962656714753913, 0.02769585376206253, 0.02735778217070869, 0.004176444532017091, 0.06491675480668034, 0.052000107908887525, 0.0600592718858804, 0.0334388265785362, 0.033580799853163104, 0.022629080107435584, 0.018508825484397154, 0.029250094201415777, 0.05273363140544721, 0.031069439968892505, 0.04863082870308842, 0.03221946183059897, 0.06031233152108533, 0.016195078746282628, 0.01605706472348954, 0.03627324716321059, 0.053163680114916394, 0.120739362601723, 0.030071403166013103, 0.025524506079299108, 0.07101422654730932, 0.11250823749495403, 0.18286104846213544, 0.13137366196938924, 0.10819348759417023, 0.15962720875229153, 0.1333029813000134, 0.13799287964190754, 0.09581609961709806, 0.10709996055811644, 0.0880215439413275, 0.12468623795679637, 0.16074913926422596, 0.13303972328347818, 0.08947650622576475, 0.15493713399129255, 0.13724938168057374, 0.15392988946821007, 0.12739714820470127, 0.1721415115254266, 0.06743527323539768, 0.13839762578053133, 0.19869489382420266, 0.09373216929712466, 0.08121628553739615, 0.08314901111381394, 0.1433383242360183, 0.1085276525201542, 0.1405528158481632, 0.215919220287885, 0.13498494747493947, 0.11609099060297012, 0.11107502225786448, 0.15197450082216943, 0.21963132252650602, 0.12918697430619172, 0.14388717764190265, 0.13203587143548898, 0.2510238673005785, 0.06682104976581675, 0.043323399033397436, 0.17346643257353986, 0.15394947198884829, 0.0972853722050786, 0.10456432947622878, 0.15726087215755666, 0.11187380046716758, 0.21871946645634516, 0.1689395997673273, 0.1489086760474103, 0.10717780209545578, 0.1592422622655119, 0.13739823869296483, 0.12447279798133032, 0.0997250923620803, 0.11561634178672518, 0.08719333766826562, 0.2694357250417982, 0.15250419239912713, 0.1255194382475955, 0.18258071850453103, 0.10040531014757496, 0.165224321984819, 0.3047338495297091, 0.14054086006113461, 0.18276437079267843, 0.10358972927289349, 0.16052459845585482, 0.11995526110487324, 0.26626628796969143, 0.14654954549457344, 0.22532071652156965, 0.13174507846789701, 0.17447192647627421, 0.14082884389374936, 0.1342905754489558, 0.1404754085732358, 0.12612271016197546, 0.16031065636447497, 0.24583565284098896, 0.09918201328920466, 0.1666928617549794, 0.1593804391367095, 0.18235032872429915, 0.1319496567760195, 0.14399898664227553, 0.22041707964880125, 0.14366332893925055, 0.07309061155787536, 0.10584691672452859, 0.07867802852498633, 0.12708575491394314, 0.14845134344484123, 0.16778400034776755, 0.1661733074912003, 0.08377877303532191, 0.07827436804239239, 0.16070126183331013, 0.15618493274918624, 0.17890554214162485, 0.16512564942240715, 0.09017064754984208, 0.09741922002285719, 0.12054250602211271, 0.1760078990565879, 0.11621350688593728, 0.14421203306743077, 0.16847169558916772, 0.1303671502641269, 0.08335163524108273, 0.11150793438511235, 0.1408204436302185, 0.1493151592356818, 0.16359667932348593, 0.17728282564452716, 0.18494112470320292, 0.15384013285594328, 0.07973239051976375, 0.17270111292600632, 0.09767981139676911, 0.11055398878774472, 0.10428591298737697, 0.06502690139625754, 0.08770655441497054, 0.10391472719077553, 0.19147087074816227, 0.16594878025352955, 0.09449239314666816, 0.13060261548629828, 0.1257405456687723, 0.167171500357134, 0.14835629425942898, 0.11309425426380974, 0.0661204420030117, 0.07525832059660129, 0.10498606613171951, 0.1128479799787913, 0.12509772873350553, 0.18250982516578265, 0.08074999627258096, 0.09925637394189835, 0.08893044838415724, 0.07566513626703195, 0.13407276570796967, 0.16813046032828943, 0.09545387048274279, 0.15510883049241134, 0.2132586980504649, 0.15116556494363717, 0.12451181374490261, 0.1185861945684467, 0.0978512093424797, 0.11388185700135571, 0.10239174177071877, 0.09505515652043478, 0.09766896162182093, 0.15425652265548706, 0.08494867597307477, 0.12367564147072178, 0.1542003806680441, 0.07177897622542721, 0.21682993641921453, 0.10643185462270464, 0.12580371727900846, 0.11797910928726196, 0.06718114151486329, 0.15127641042428358, 0.14413493791861193, 0.0903167293540069, 0.08340781794062682, 0.12832466486309255, 0.244315788682018, 0.08639607937740428, 0.39066138012068613, 0.142866172428642, 0.13472228656922067, 0.19865513167210988], [0.0039654778166940165, 0.022171431986082877, 0.00976626987435988, 0.05451522009181125, 0.016501384720738446, 0.05597779893183282, 0.03197807978306498, 0.04203630631257381, 0.009684839734940656, 0.041327970035906346, 0.005291027781952704, 0.042155423135097535, 0.037732630103294335, 0.04453846526199153, 0.08374217964176621, 0.029339240132165805, 0.027754039836249182, 0.09828003668891531, 0.00891112576105765, 0.024694488117737428, 0.06907813543719904, 0.088791409773486, 0.043149660141872506, 0.023822640168613622, 0.053210729733109474, 0.027449085842818022, 0.013425264873408845, 0.01730713657369571, 0.011233623904575194, 0.03993626757125769, 0.02839729781927807, 0.02350179827772081, 0.015130691396604692, 0.03727282763325742, 0.03469037763508303, 0.03762675489165953, 0.019892880859385644, 0.013080797241335469, 0.053776200461600504, 0.03290576607521091, 0.04163134304274406, 0.01256038123808269, 0.0411051934185837, 0.022306864183130007, 0.0455123733596078, 0.10034928351108517, 0.004129034866179738, 0.043376226377274306, 0.03575229850996818, 0.04703645122104457, 0.04606865672394633, 0.03299857270238655, 0.013926384188900036, 0.04116194948021855, 0.023076428067205206, 0.022413685951115828, 0.03920343618041702, 0.012692033146907176, 0.04574703451778207, 0.015111051200489913, 0.010091546839768333, 0.05437242578981178, 0.029013451720987047, 0.07092381175607443, 0.04396364771361862, 0.10068745857902936, 0.01528248137661389, 0.04564379541469472, 0.04386358415441854, 0.058981011887746196, 0.05420637130737305, 0.01681975504782583, 0.007178678277081677, 0.0693103436912809, 0.0282973038099174, 0.06676320465547697, 0.029964812099933624, 0.007541800533155245, 0.05389609420672059, 0.030343868902751377, 0.046219576482794116, 0.07988533909831728, 0.03566921868228486, 0.04621688948412027, 0.07721147686243057, 0.0754375895485282, 0.05449101335502096, 0.02479419544605272, 0.008533950196579099, 0.04511770685868604, 0.07488851222608771, 0.051396303344517946, 0.002150177814265979, 0.033442239609680006, 0.03673341943483267, 0.02526940744636314, 0.06725469471088477, 0.057738661766052246, 0.014863754023930855, 0.03409732785075903, 0.08186233908470188, 0.048464672440396886, 0.018598733070705618, 0.034912784450820515, 0.05417202725740416, 0.05003217315035207, 0.012901557975315621, 0.0056620876254913, 0.07478580238031489, 0.03821311092802456, 0.04379821748339704, 0.047816247413200993, 0.08214140018182141, 0.028435573979680027, 0.014954657360379184, 0.046814441348293, 0.047560124192386866, 0.036569923029414246, 0.028592882145728384, 0.062038144628916464, 0.04228500975295901, 0.04042904005785074, 0.039041642897895405, 0.046932370734534094, 0.02114105111520205, 0.019198407053149173, 0.03487802649449025, 0.024687505992395536, 0.03143588619838868, 0.0769538167597992, 0.04621638736820646, 0.0362224893511406, 0.0050061885350649905, 0.03458142187446356, 0.00893169385381043, 0.07519649927105222, 0.07209545174347502, 0.06336803933871643, 0.03115270978638104, 0.04597711217190538, 0.03166935992028032, 0.06279105387095894, 0.013757537534859563, 0.050224663357117345, 0.07898364748273577, 0.024756962533241937, 0.03148288492645536, 0.0585747661867312, 0.022571752380047525, 0.03070214557062302, 0.0073848638650295985, 0.033902985243392844, 0.019734088397983993, 0.06254987538393054, 0.05025086159418736, 0.06388824499611344, 0.013017116729835314, 0.03721008010740791, 0.03940442164561578, 0.029866475412356, 0.033605254255235195, 0.057718882470258644, 0.02056011657363602, 0.0426164571461933, 0.03620227240025997, 0.0792301253282598, 0.08001542783209256, 0.05401034593316061, 0.022941240142764788, 0.014934672807742442, 0.026591649977490306, 0.030204962606408765, 0.035325116610952785, 0.06408503372222185, 0.03392533618690712, 0.030964473994182687, 0.04955263548929777, 0.02225640831914331, 0.027123538311570883, 0.013258416504998292, 0.01538708433508873, 0.0683863079175353, 0.03281789239762085, 0.04751496429422072, 0.00787818172414388, 0.009116706604670202, 0.02561433733041797, 0.013458435905964246, 0.04390382128102439, 0.024206791073083878, 0.07601979295057909, 0.03729329903477004, 0.015532882850883263, 0.07387032971850463, 0.020175902904676538, 0.028958429316324846, 0.05945540964603424, 0.09347282642764704, 0.027923295307638388, 0.011731327644416263, 0.043892214939530404, 0.03295949926333768, 0.0031740583196681526, 0.0609346159866878, 0.00951535186530756, 0.03426350446950112, 0.04026381678080984, 0.017549801052414944, 0.03857409834329571, 0.02132015721872449, 0.035099971906415055, 0.004945340483183307, 0.01610113218027566, 0.04290186933108738, 0.022836754231580665, 0.049287372401782444, 0.02794407374624695, 0.039124495416347466, 0.051464886271527836, 0.04045018320903182, 0.04042988822662404, 0.06125941712941442, 0.013556372257880867, 0.05125192127057484, 0.02416393649764359, 0.025864338469026343, 0.07753672583826951, 0.039740313443222215, 0.007039581990933844, 0.039107308124325106, 0.06679504151855196, 0.007112444353489471, 0.011435724711710853, 0.05549686688131519, 0.024019057396799326, 0.06041016948542424, 0.053816614007311206, 0.018601635504247885, 0.09048252260046345, 0.014930258937446135, 0.013987050308579845, 0.013536350385818099, 0.01878193922207824, 0.02514829912355968, 0.027947651322132776, 0.03540701239502855, 0.039035973737814596, 0.02437643500577126, 0.0582578835476722, 0.029947580703135048, 0.011117405274749866, 0.03499302121677569, 0.008842725190334022, 0.04775806303535189, 0.08814040970589433, 0.03765717700922063, 0.043146443885884116, 0.05780356364058597, 0.017106000134455304, 0.06820831461144344, 0.006386734611753906, 0.07216512371918984, 0.03533335741875427, 0.05696181380855186, 0.04654167027079633, 0.12185391065265451, 0.04602764606741922, 0.04953421665621655, 0.0173808644924845, 0.04854997107759118, 0.02585906794826899, 0.08985759184828826, 0.009148805551896138, 0.03615167743659445, 0.057467756659856865, 0.029915506352803538, 0.030818951981408254, 0.031561333752636395, 0.02601842359373612, 0.09529167347188507, 0.05232342305992331, 0.057678292505443096, 0.012144792958029678, 0.048833564788635285, 0.0957895214004176, 0.04292688352454986, 0.06326076973761831, 0.015794541221112013, 0.12391947981502328, 0.013440805021673441, 0.0570687712835414, 0.039438073589865646, 0.046830604052437205, 0.030694929350699698, 0.0319768618127065, 0.011751223987500583, 0.09085182206971304, 0.013389255019969173, 0.030667842232755253, 0.0026131664302998354, 0.019924392025651674, 0.04948049025343997, 0.022502726708937968, 0.04620418730857117, 0.029749305985335792, 0.08377835234361035, 0.08405583245413643, 0.05823187530040741, 0.039139742098216496, 0.03005225830046194, 0.03759689595816391, 0.03439322000901614, 0.08230385503598622, 0.027138664553474103, 0.030061181035957167, 0.054787275314863236, 0.008037247295890535, 0.09938399280820574, 0.043368701423917494, 0.014759217222620333, 0.05399402038061193, 0.01817254861816764, 0.06988846231251955, 0.052316003279494386, 0.03232091299391218, 0.019921384419181516, 0.04184117999726108, 0.04064401352245893, 0.054162083326705864, 0.040539108615900786, 0.03179189655929804, 0.09417023150516407, 0.04484446419935141, 0.012875170596609158, 0.01539808847675366, 0.007750824941987438, 0.05973992616470371, 0.12806336102741106, 0.019377175585499833, 0.020950979885778258, 0.04188183781557849, 0.050349045611385784, 0.06689674713249717, 0.05501576180436781, 0.01674641728667276, 0.06536471005529165, 0.03736486751586199, 0.01809358410537243, 0.0456431033089757, 0.025978805630334785, 0.03587601240724325, 0.07407373416104487, 0.1626269713576351, 0.08764037010925156, 0.08153056260198355, 0.13072697738451616, 0.09573173057287931, 0.15988498420587607, 0.11923619040421077, 0.18176526868981974, 0.11517731605895928, 0.11281975970736571, 0.08600942976772785, 0.1121390126645565, 0.060852017918867726, 0.09135966481907026, 0.2463200997029032, 0.08206577745399304, 0.07727852290762321, 0.269293449819088, 0.06119716154145343, 0.08145622230534043, 0.18016262325857366, 0.14052237676722662, 0.058314310519823005, 0.06123883716229882, 0.18017713033727237, 0.10082437337509223, 0.25503281503915787, 0.14379966019519738, 0.12904624614332402, 0.10682587990803377, 0.12686018273234367, 0.10654326328741652, 0.08901739586144686, 0.17929405772260257, 0.1296512143952506, 0.09382589533925056, 0.07820120161133153, 0.06572043203881808, 0.11717546598187514, 0.15774611969079289, 0.15889041471694196, 0.11050576530396938, 0.0810895012691617, 0.12105938685791832, 0.20809668861329556, 0.1790373950664486, 0.12433733525020735, 0.18057062636528695, 0.17373909508543356, 0.11843756825796195, 0.18716144056192466, 0.13024544822318213, 0.11514855974486896, 0.16339379735291004, 0.15329893332506928, 0.1888099278190306, 0.1342393731964486, 0.11104806406157357, 0.22396021309707845, 0.15391623734363488, 0.12258351221680641, 0.11004189840917077, 0.12816131434270314, 0.1695058915231909, 0.17703225623284066, 0.1754956186882087, 0.13850273085492, 0.10548039924885545, 0.1071167950119291, 0.14250316976436547, 0.12663722969591618, 0.10394292710615055, 0.13930288649031095, 0.13175594859889575, 0.07284956877785069, 0.24398061952420644, 0.10837073451174156, 0.0829471198043653, 0.20524414096559795, 0.05888786938573633, 0.1569558163838727, 0.1277200494493757, 0.1270258402717965, 0.13641038670071534, 0.1553059991981302, 0.25426685756870676, 0.1800487515117441, 0.09975610141243253, 0.13438432184713228, 0.1564931369253567, 0.15827589269195283, 0.10073615703731775, 0.09161666674273354, 0.1007454190403223, 0.12036961529936109, 0.18209226828600678, 0.1411323526075908, 0.22825801319309644, 0.19478503933974675, 0.06952313905847923, 0.18281498950506958, 0.1345541455915996, 0.0792013079460178, 0.11260389736188309, 0.1345627358449357, 0.1266259660146066, 0.10033372470310756, 0.14230100704090937, 0.23699119314551353, 0.09399678438369717, 0.1975519558680909, 0.17338937813682215, 0.28324559543813976, 0.08599258852856499, 0.10836192034184933, 0.1598907924656357, 0.22467158921062946, 0.12319635147494928, 0.14567644734467777, 0.1641732169581311, 0.1745640036783048, 0.10652289366615669, 0.08547271535332714, 0.06860523724130221, 0.09350255983216421, 0.11847468412348203, 0.15690006794674055, 0.12655279279819556, 0.16391744996820176, 0.27816931211522644, 0.14448557767484868, 0.161094622154321, 0.14227880537509918, 0.08294014446437359, 0.14418132257248673, 0.16991910577884742, 0.2079039846679994, 0.23130569394145692, 0.0875481775562678, 0.130659693852067, 0.14982161777360098, 0.1569212925221239, 0.0942075170044388, 0.11622542196086474, 0.2001782256577696, 0.10347711281584841, 0.13096417965633528, 0.17332772644502775, 0.15805679373443127, 0.09674842708877154, 0.10294543991663627, 0.16465184198958532, 0.13533317164650985, 0.18076612587485993, 0.07315551343240909, 0.22592681114162716, 0.11609474968697343, 0.23702199863536016, 0.0802944889292121, 0.0862668455977525, 0.11220016902578728, 0.2266466146601098, 0.10980633819209677, 0.1314791063112872, 0.18224464010979446, 0.17111248602824553, 0.1534841869558607, 0.15668681796107972, 0.11795351494635854, 0.17962759839636938, 0.16036293070231164, 0.18148584796914033, 0.18371809247348989, 0.17228508953537258, 0.1435944169227566, 0.13234769898865903], [0.03952739933239562, 0.0700728338477867, 0.03309762863708394, 0.01900943335411804, 0.025491554722455994, 0.06796594190278224, 0.050561192977641306, 0.06505449063011579, 0.039872654913259406, 0.022847130728353347, 0.009105390336896692, 0.010530285038320082, 0.04071418082873736, 0.028609994798898697, 0.02299301915003785, 0.033561254651950936, 0.04395915920447026, 0.030607174416737895, 0.016548459783994725, 0.014403028746268578, 0.006806961102743766, 0.05143311047660453, 0.0045469051443173415, 0.03640003821679524, 0.04351360596982496, 0.002665590469924999, 0.0593101420838918, 0.041121084708720446, 0.02767727547325194, 0.03928189518462334, 0.04615604864167316, 0.04438460744651301, 0.02008908604537802, 0.011289396938601775, 0.0467198060692421, 0.04973190104854958, 0.024659238223518645, 0.035000037268868515, 0.015496557478659918, 0.04084635266501989, 0.04276620643213391, 0.005550107719110591, 0.028392069706959382, 0.03293521110234516, 0.08773660673094646, 0.018979484514732445, 0.024829849068607603, 0.05990702898374625, 0.03979624169213431, 0.029173579200037887, 0.031517619134059975, 0.02288837717579944, 0.022846474245722805, 0.06020091607102326, 0.028923036929752146, 0.017756272473239472, 0.024562094061236297, 0.0020582831805638436, 0.028805470559746027, 0.07355089578777552, 0.04596914277811136, 0.02728810001696859, 0.028258730790444782, 0.06601284670510463, 0.0543881779802697, 0.07417529049728598, 0.08502460404166154, 0.07511742958532912, 0.04275910556316376, 0.030447108005838733, 0.02599891910462507, 0.041377900035253594, 0.05068405531346798, 0.01682646575916026, 0.02313784566441817, 0.03241826919838786, 0.023004294705710242, 0.01600477172593985, 0.007295510981098882, 0.0506695346640689, 0.008529937510112566, 0.03991410322487354, 0.0874690128756421, 0.006851706246379763, 0.08448888707373824, 0.04349505482241511, 0.008199823438189924, 0.011606339797643679, 0.042557360138744116, 0.0398345008891608, 0.011318968342883247, 0.029128924810460637, 0.050005632253097634, 0.04879698496577995, 0.016777329645784836, 0.05265550488340003, 0.0021090583800936914, 0.03581178228237799, 0.06276208042566266, 0.03731720043080194, 0.04173707915470004, 0.01596805449974324, 0.06986193837864058, 0.018332849123648236, 0.010586807853542268, 0.006650623665856463, 0.06001141481101513, 0.007154245927397693, 0.02465442062488624, 0.023637620632403662, 0.011836017116105981, 0.012806204297313733, 0.026421281708670512, 0.06210833229124546, 0.04746534302830696, 0.05350009099181209, 0.010643620742484927, 0.02798844315111637, 0.027023964993921772, 0.011406673234887421, 0.017574944167530963, 0.03821950272790023, 0.042540556219007285, 0.036527168537889204, 0.018830802225108658, 0.03970185068569013, 0.02699716286068516, 0.044709401803889444, 0.05313443186293755, 0.034222602378576994, 0.02814899301821632, 0.03827229275235108, 0.03364666524742331, 0.011328857142611273, 0.02960130731974329, 0.03240568915914212, 0.022414591795365726, 0.022386279921712618, 0.06018877707953964, 0.0513065636956266, 0.06419498353664364, 0.012536298333933311, 0.0644594222041113, 0.03526477109906929, 0.08102580718696117, 0.07369485377733197, 0.0270668246583747, 0.03871766956789153, 0.031148489298565046, 0.023347155057958195, 0.020835990252505456, 0.05095490274418678, 0.013135259006438511, 0.01792188930059118, 0.029289371200970242, 0.013264173874631524, 0.0180163871763008, 0.02506132789754442, 0.03810342913493514, 0.02432263226780508, 0.05861289985477924, 0.029372451028653553, 0.02761786464335663, 0.02587643844474639, 0.029516307237957205, 0.010373929365804153, 0.03294521949387022, 0.045312795854572735, 0.013830788782797754, 0.025499215382816534, 0.0812968887122614, 0.05760721596223967, 0.04635269148275256, 0.016836358799732158, 0.029378123581409454, 0.018582068250647614, 0.08035522459873132, 0.01785775417062853, 0.03722746078191059, 0.038985087004091055, 0.0761960492070232, 0.07333621409322534, 0.014757541241124272, 0.0134445403569511, 0.02884496808318155, 0.009928302340475577, 0.03796419035643339, 0.027034460234322717, 0.014630275213026574, 0.10794512342129435, 0.03246059960552624, 0.020774172319631492, 0.053624117015195746, 0.009799628352214183, 0.03295157736699496, 0.027562804919268404, 0.004467444876874132, 0.019480194164706126, 0.01295894168184272, 0.03632383194885083, 0.01994963692102049, 0.013951701178614582, 0.11445884246911321, 0.08667155102427516, 0.033985691876815896, 0.04037962913779276, 0.022439069946163466, 0.06814032540257488, 0.0895713654213718, 0.01481688761019281, 0.014304748037829995, 0.057625611046595235, 0.03267369352813278, 0.009624710506094354, 0.04659009052972708, 0.028174534772655795, 0.06627122605485575, 0.015333054287891303, 0.020256926771253347, 0.053138462360948324, 0.07008198049983808, 0.037641075373228104, 0.026308714445414286, 0.019863020229552473, 0.008932931332050689, 0.010478397465444036, 0.022885666428399936, 0.021136033348739147, 0.017073096275063496, 0.03936973154278738, 0.06019737411822591, 0.044822754471429756, 0.04146360918613417, 0.009326414637533682, 0.04790900654292532, 0.029213755258492062, 0.062467806573425017, 0.01978843905297773, 0.04884854344917195, 0.06243081284420831, 0.03002944595313498, 0.09057533940566437, 0.042252351862511466, 0.04375059111043811, 0.00925567905817713, 0.04671187738754919, 0.05081884290224739, 0.020929614514378563, 0.05442632861169321, 0.05870441387274435, 0.0132117740078164, 0.12849538427378449, 0.024140929071498767, 0.0748861034267715, 0.03056774813947933, 0.02351014256211264, 0.009006535418198576, 0.016906639760626212, 0.027666578368682946, 0.06690539166863475, 0.0836081893316337, 0.028429053258150816, 0.03211717606921281, 0.030447501556149552, 0.015719992274950658, 0.058424816732960086, 0.04511886376089283, 0.019802489816876392, 0.052424989574189694, 0.031921160873025656, 0.05129516091463821, 0.04854162170418671, 0.021329310656126057, 0.09363116935959884, 0.03444964698116694, 0.023779293655284812, 0.05675160365977457, 0.04665773707841124, 0.041347630588071685, 0.0330574865053807, 0.04971159588811653, 0.007392929101895008, 0.07743460631796292, 0.00968209930163409, 0.03379544762096234, 0.007922567244219993, 0.0174602361262909, 0.012671133420164031, 0.021848306824852313, 0.024299733407263244, 0.08145434954868895, 0.03504610979663474, 0.0034358706325292587, 0.08750805578061513, 0.043669502783034525, 0.023387733148410916, 0.027936692981581603, 0.02216022089123726, 0.03629232756793499, 0.07851148889000927, 0.05063149259824838, 0.06833496995802436, 0.02192546134548528, 0.02642984821328095, 0.09608741184430462, 0.010037662677599915, 0.015993374033964107, 0.037412436213344336, 0.01899274987434702, 0.0930656511336565, 0.029375572289739336, 0.035704753561211486, 0.030888155767960206, 0.027838303707540035, 0.05125903231757028, 0.01861882279627025, 0.00983551437301295, 0.04397934901395014, 0.05039582381557141, 0.007532810792326927, 0.05799565690436533, 0.015302752610296011, 0.06163911854049989, 0.025403838804257766, 0.015039730384679777, 0.024774302495643497, 0.077482456607478, 0.03530471306294203, 0.04241002643746989, 0.02990596954311643, 0.030028105846473148, 0.0446738296055368, 0.03828760389504688, 0.03874871254499469, 0.02880187432414719, 0.04735036866207208, 0.019914824681888734, 0.022403536763574396, 0.04063908735822354, 0.051304334708090336, 0.024048666968675594, 0.004530633450485766, 0.04974785001416292, 0.03221775870770216, 0.018055195986692394, 0.021848379767366817, 0.031684433575719595, 0.018140986561775208, 0.06405208406171628, 0.04817119586680617, 0.01814985671080649, 0.015427182362015759, 0.25258414500526016, 0.12914783640631608, 0.11505133924739701, 0.0970161295096789, 0.13540245007191384, 0.15591569005378655, 0.10810763255826064, 0.10247946277792964, 0.13874517141708306, 0.09753727833075182, 0.12164201773703098, 0.15345754767102854, 0.08984835020133428, 0.14744975790381432, 0.07099259485091482, 0.057260403143508096, 0.14909315614828042, 0.12303024610238415, 0.10880155675113201, 0.07735971640795469, 0.10910103496696268, 0.10735893023333379, 0.08423657382705382, 0.15536547957786492, 0.13235091524464743, 0.08173529018781014, 0.11640695721975394, 0.1330587358347007, 0.10971658836518015, 0.16225980248834404, 0.11144569236785173, 0.1254797846611057, 0.24660820567182132, 0.06553143968007394, 0.12904292132173265, 0.10518625431827136, 0.09643628062414271, 0.06858826708048582, 0.09941035389368023, 0.10073788051626512, 0.14580060568239006, 0.1259646929268326, 0.08723649249545165, 0.14411200343498162, 0.17983590864709445, 0.13841925747692585, 0.08287841813372714, 0.10116967306073223, 0.057287877026413164, 0.10137132688292436, 0.14627864717372827, 0.06895451992750168, 0.08814157000077621, 0.1759769171476364, 0.14025929516979627, 0.11842650813715798, 0.12949022517672606, 0.054325477951871495, 0.09355415563498225, 0.15312190353870392, 0.1271257341972419, 0.12071528817926135, 0.1432119267327445, 0.13101112070892537, 0.10772824327328376, 0.15937112963625363, 0.1458530564393316, 0.17882607212024076, 0.10963498095848731, 0.1129320233262011, 0.13039402025086538, 0.13802568002470902, 0.1096595371408122, 0.1483876561479909, 0.07765483164361545, 0.20762867586953299, 0.1143823851432119, 0.16411418441150868, 0.21059690016720975, 0.19981352665594646, 0.10716517455875874, 0.07158798897372824, 0.1705938410013914, 0.20133964690778935, 0.2630688138306141, 0.24199639313987323, 0.09652032397155251, 0.12681723146566323, 0.1842190141656569, 0.12278916261025838, 0.09727079727287803, 0.17962378502956458, 0.20023719035089016, 0.1566957203405244, 0.18910390990121023, 0.11465829105249473, 0.13369912361460073, 0.14143967468823704, 0.07146051259977476, 0.1776217267449413, 0.155586234160832, 0.05739338243646281, 0.08074617612042598, 0.13217540537672384, 0.11847950172211442, 0.13313403965107032, 0.20332901658756392, 0.06903736905327865, 0.07086760191512959, 0.11501726321876049, 0.09565802131380353, 0.1002846530505589, 0.18534729576536588, 0.2078735184456621, 0.12349927664867469, 0.14606119027095182, 0.13530038483440876, 0.18620416335761547, 0.06656623951026372, 0.11498991825750896, 0.11906871439090796, 0.14132682074393543, 0.18094344064593315, 0.11926873294370514, 0.09972612373530865, 0.2185882513544389, 0.13398131275815622, 0.16889430076948234, 0.2307762194957052, 0.1398031296474593, 0.07692511472851038, 0.20193791123373167, 0.14387484187526361, 0.12574369407125882, 0.09400367829948664, 0.07353522841419492, 0.09132319356181792, 0.10140685497650079, 0.1326651040996824, 0.21045174795602048, 0.18276671852384294, 0.1230557318776846, 0.10713450477591582, 0.10499329252966813, 0.21134734632713453, 0.15798938806567872, 0.11836488358676434, 0.14532487121011528, 0.06666753121784755, 0.09759840076523167, 0.09789863215493304, 0.1311593670397997, 0.1280672558184181, 0.1354027757687228, 0.0955358442983457, 0.10376019762562853, 0.08356588945857116, 0.15849191110048974, 0.05482751922681928, 0.16912116216761724, 0.1922708906765495, 0.11407240320529256, 0.08770156039723329, 0.08245721752090113, 0.10169986675360373, 0.12781163810619287, 0.07248777390590735, 0.1364379623638732, 0.1793902875589473, 0.09131834203643457, 0.20891962945461273, 0.08011136589837925, 0.15219720958599023, 0.14413351299507277, 0.0887950263651354, 0.11205697099545173], [0.025162439793348312, 0.046201520665947876, 0.04843029446367707, 0.040732541986341984, 0.051779166728790314, 0.01744904538749584, 0.06931980246944086, 0.018622832938230464, 0.042167300890598974, 0.051675177844507356, 0.029771375336817334, 0.035694667138159275, 0.013288193166122904, 0.03507175163498946, 0.02034728049433657, 0.024693801101031046, 0.021765150661979402, 0.0324052990015064, 0.011589729260387165, 0.017044948946152414, 0.07899354730865785, 0.008952247527694064, 0.011837954333584224, 0.041912582237273455, 0.08635515014507941, 0.025818734130422984, 0.043075391091406345, 0.03103759971314243, 0.028206895804032683, 0.03765231191313692, 0.022489590270976936, 0.024159057830859507, 0.01934751681983471, 0.011370747350156307, 0.05668447958305478, 0.02099516778253019, 0.01762620748818985, 0.023036246919738393, 0.04278843184666974, 0.0666225782728621, 0.08336114151669399, 0.037677651803408346, 0.09670847494687353, 0.034993692966444154, 0.029131292897675718, 0.012645191330063556, 0.02095724785301302, 0.0691989485972694, 0.013693651766516268, 0.07869319378265313, 0.0397494567025985, 0.02764388985399689, 0.07539493683725595, 0.041526550094463995, 0.03750966349616647, 0.052305129755820544, 0.026343570789322257, 0.008434427769056388, 0.033432791009545326, 0.016231578841273273, 0.02458911502201642, 0.0958049309306911, 0.048847227091235776, 0.03913352671744568, 0.01633086717421455, 0.008479483342463416, 0.06513975534055914, 0.04537106844197426, 0.0574916343071631, 0.030111558868416717, 0.060375028156808445, 0.03368132481617587, 0.03333273084302034, 0.04033217918393867, 0.049662252821560414, 0.03143606601016862, 0.06099364174796002, 0.08109076334429638, 0.04430626379325986, 0.04281057583700333, 0.057399903157992024, 0.04980628884264401, 0.02793569553510419, 0.021306047083011696, 0.011814118246547878, 0.021815101017377207, 0.03777138463088444, 0.03145188605412841, 0.06447977146932057, 0.05814840192241328, 0.015008353229079927, 0.06575714756867715, 0.07080471528960125, 0.09755252501262085, 0.03493135256160583, 0.02620043552347592, 0.03153140018028872, 0.04493265678840024, 0.014256212427946073, 0.05615843852449741, 0.015843192181949104, 0.020928164145776203, 0.023880614200606942, 0.004011298438334572, 0.013870645081624389, 0.019296948997569934, 0.019316506073144928, 0.013019814754703214, 0.07004531246743032, 0.0465685945403363, 0.009499350313230284, 0.0447494353699897, 0.04575919386531625, 0.050615743800465546, 0.04076388691152845, 0.05053033999034336, 0.0183038994270776, 0.022071534667962363, 0.02121212087305529, 0.015420174791610666, 0.03287031601316162, 0.02807451701456947, 0.054033416123794656, 0.013779146330697196, 0.062455423309334686, 0.03590818514515247, 0.04936369402068002, 0.0247740259926234, 0.03934566390567592, 0.03329088558842029, 0.017980920150876045, 0.008066069767145174, 0.029678684060594866, 0.0285047166980803, 0.022578520766858543, 0.012120367393695881, 0.05550445968817387, 0.03976986364328435, 0.07171413541904517, 0.017988029501533935, 0.02533673508358853, 0.0070088587734582165, 0.03420042785416756, 0.037378438216234953, 0.032562155941767354, 0.02573071965681655, 0.06817448964076382, 0.03791268276316779, 0.02966036361509136, 0.034129571834845204, 0.038627621185566695, 0.07583671741719757, 0.04886823792808822, 0.014930370895724212, 0.08652257866093091, 0.05084422689729503, 0.003119642779763256, 0.05248918577230402, 0.052139346687389274, 0.010884137657870139, 0.05368428950064948, 0.017043015121349266, 0.008091164536641111, 0.043381410384816785, 0.023952255624213388, 0.03176638024992176, 0.01274260860269091, 0.020836936808856468, 0.06043284612574747, 0.034909995671893866, 0.03799329950873341, 0.005856353897667889, 0.0063320930348709226, 0.011741568434185215, 0.061454468805875094, 0.02311254309357277, 0.021149437808032547, 0.03964695041733129, 0.04434607005012887, 0.007455856439524463, 0.028807109221816063, 0.015756346484912292, 0.10088977736553975, 0.03997645041506205, 0.05811072965817792, 0.07169175733413015, 0.051393517958266396, 0.012630686795871173, 0.062092434215758524, 0.040134406582053216, 0.012820845386678619, 0.05288090403856976, 0.013831875286996365, 0.04558408433305366, 0.024191037186288407, 0.027348973089829087, 0.01885174520845924, 0.04225654181625162, 0.07144692832870142, 0.042269376306129355, 0.06294704228639603, 0.02854577824473381, 0.01144305119357471, 0.05204983774040427, 0.020308123934747915, 0.03678705084270664, 0.031110511693571295, 0.043728287664375136, 0.05256637252335038, 0.02994734321587852, 0.00889641766635967, 0.018259686085262468, 0.036963337633226595, 0.04199717180537326, 0.03750330562304173, 0.03620073212576764, 0.03780478212450232, 0.03965752199292183, 0.053756265102752616, 0.025936158008075187, 0.02369835290924779, 0.040221449054245434, 0.040106067566999366, 0.09676996379026345, 0.03858012034158621, 0.0576087087392807, 0.03988615097478032, 0.04579596367797681, 0.02278480219787785, 0.014770150118108307, 0.029437953406678777, 0.08569798897951841, 0.03785451874136925, 0.012956544756889343, 0.02528984492112483, 0.037073826882988214, 0.03130904086200254, 0.09802393721682684, 0.046666408755949566, 0.01737086458264717, 0.010403463450659598, 0.01177257324369358, 0.03147731415395226, 0.05494683621717351, 0.023311455634289553, 0.0422865194933755, 0.01696541446394154, 0.07904335177902665, 0.028800279766853367, 0.07075757746185575, 0.026966364156188707, 0.07066298968025617, 0.07029072501297508, 0.09357308676200253, 0.07087637537292071, 0.014762765960767865, 0.025814941119668738, 0.06023985041039331, 0.06708864362112113, 0.03860872059262224, 0.04880993141393576, 0.07675294325287853, 0.051626184223485846, 0.010680701833085289, 0.07256286059107099, 0.13300403234149727, 0.026561372048620666, 0.04699603767533388, 0.009262597570861024, 0.04363697042156543, 0.06451531313359737, 0.019920817842440944, 0.03346930637157389, 0.030184328356491666, 0.027039793519569293, 0.0482846876340253, 0.051623015464948754, 0.01436863889518593, 0.052655026516211886, 0.03856262092345527, 0.029711362307092974, 0.03195594597075667, 0.011265450589624899, 0.03822561972109335, 0.034498219910476885, 0.040676345716097524, 0.040666059125214815, 0.02836035328385021, 0.05784798054290669, 0.0144240277087582, 0.061764939289007864, 0.02239636973743992, 0.026620979653671384, 0.03966119286737271, 0.03642380051314831, 0.03336474412520017, 0.037860408425331116, 0.008384205999651125, 0.014509400984804546, 0.012125732061187071, 0.03028449708861964, 0.0335750289128295, 0.018649272055232098, 0.048635469882615974, 0.032518716129873476, 0.020908337352531295, 0.03973174015326159, 0.015519519103690982, 0.05682630357997758, 0.017369977398110286, 0.0645247854824577, 0.05957405149404492, 0.014552515099889465, 0.04061105368392808, 0.0845606964347618, 0.051441273252878866, 0.008374488530015307, 0.027891885921625153, 0.018310627101787498, 0.024077314717162932, 0.07949291515563216, 0.011060706888591605, 0.04702418330790741, 0.032121440661805015, 0.03129290869193418, 0.04221780085936189, 0.03149222496098705, 0.10225602798163891, 0.08722548665744917, 0.025509576612551297, 0.04343485180288553, 0.06795172659414155, 0.03032384194167597, 0.09449289526258196, 0.037776972366763015, 0.07420050485857896, 0.03509986673348716, 0.06822325595255409, 0.02751699023480926, 0.029712441177772622, 0.007230549734751028, 0.02216474841614919, 0.026606755863342966, 0.0439272612732436, 0.05367315813366856, 0.02368911635130644, 0.02830259977573795, 0.03103202554796423, 0.12509003414639405, 0.02543759761777307, 0.029055778735450337, 0.047465424452509196, 0.13518993290407316, 0.10333266628107854, 0.17219822348228522, 0.12087449963603701, 0.11614614192928586, 0.04861730210749166, 0.22194974097822393, 0.13589364157191344, 0.12236273049243859, 0.11548162544412272, 0.18106894248298236, 0.11614363134971686, 0.1611512933990785, 0.13530479531202996, 0.09257933830044099, 0.09185182662414652, 0.13758654573134013, 0.14494715790663446, 0.06818832496979407, 0.061603963641183715, 0.21824107212679728, 0.07318464294075966, 0.17111241817474365, 0.10808615692492042, 0.16122557941292012, 0.09187068311231476, 0.10301013823066439, 0.2131384209330593, 0.08823088556528091, 0.20402644202113152, 0.08965162254337754, 0.10328204078333718, 0.13365538524729864, 0.14268790770854267, 0.1816015381898199, 0.09528789403183119, 0.13597662640469416, 0.13877832463809422, 0.1715658288449049, 0.08001456609261887, 0.1741130900170122, 0.15479233461831296, 0.2571894164596285, 0.19230641877012594, 0.06241555937698909, 0.13977133349648543, 0.16207270324230194, 0.12900281990213053, 0.13904804230800696, 0.10409240837075881, 0.11058746092021465, 0.1278487675424133, 0.2698756057236876, 0.10842355167759316, 0.17224311535911901, 0.1985390479011195, 0.11932689696550369, 0.15424878735627445, 0.09576462595058338, 0.15384155777948244, 0.10906875705612556, 0.32895621976682116, 0.10013799449162823, 0.11513204420251505, 0.07348024672163384, 0.07687166652509145, 0.10620318153606993, 0.26325418959770885, 0.15185385729585374, 0.15616423743111746, 0.09350277017802, 0.13440375509006636, 0.10867171228996345, 0.15739872333194527, 0.16036417920674595, 0.21524489218635218, 0.14617780329925673, 0.2122798298618623, 0.10970781490738903, 0.0967140660754272, 0.0854226258982505, 0.12826286389359406, 0.09723609020667416, 0.19049188042325632, 0.1421959019665207, 0.1958172810929162, 0.11026383364307028, 0.2723697376038347, 0.19869861219610485, 0.22283703408070973, 0.06523603267435517, 0.17058527788945607, 0.19546418503991195, 0.21077103939439568, 0.15053209822092736, 0.11626360991171428, 0.08517488597759179, 0.143210854647415, 0.07748546251761061, 0.24554203716771944, 0.10542849131992885, 0.10232429538986512, 0.18251442563320908, 0.11121467833540269, 0.11108471852328096, 0.08672947077346699, 0.10648286688540663, 0.07905611502272741, 0.1332966980657407, 0.10290508065372705, 0.14183322499905313, 0.09142093653125422, 0.15284245567662375, 0.1661164733980383, 0.12210766917892865, 0.2196167204529047, 0.11157711781561375, 0.08520533862922873, 0.14553372428885528, 0.11493346414395741, 0.13529279881290027, 0.10500537723835025, 0.09173664530473095, 0.07404232477503163, 0.13508847834808485, 0.1436865348368883, 0.1166996636560985, 0.25970404009733883, 0.13981747387775353, 0.20476681872137956, 0.14353037678769656, 0.1191198080778122, 0.1390808019787073, 0.12699176424315997, 0.09952460562012025, 0.12899998362575257, 0.12350520704473768, 0.13509862923196383, 0.1492274517991713, 0.10533986107579299, 0.10439873300492764, 0.08532958517649344, 0.15108510426112584, 0.10280463711491653, 0.1431156833256994, 0.13425708296043531, 0.11902473175099917, 0.12317237204739026, 0.13696842747075216, 0.09462590169693742, 0.13666843356830732, 0.22283562272787094, 0.2870136361036982, 0.09444419001894337, 0.21728321138237203, 0.15155452835772718, 0.11098607310226985, 0.2102030377302851, 0.10250726235764367, 0.1512646989098617, 0.14915460427956923, 0.1468348694699151, 0.13161117636731692, 0.08568838092365436, 0.11276802819754396, 0.11738776601850986, 0.10154355942670788, 0.179190228294049, 0.2905850373208523, 0.18930114646043095, 0.22474906433905872, 0.1074669122962015, 0.20556535944342613, 0.08369092310645751, 0.16376781942588942, 0.14999533630907536], [0.02590121854362743, 0.012100156379996665, 0.04732504573517612, 0.006395211210474372, 0.01709196633393211, 0.04628844439451184, 0.062101078751896105, 0.05144407220983079, 0.03989838156849146, 0.04646137243668948, 0.03576093965343066, 0.022237923328897784, 0.06493860363428082, 0.03692325656967504, 0.016695835893707614, 0.08022841318909611, 0.06482473188745123, 0.008591004813622152, 0.01679784175939858, 0.030725025771451846, 0.05675904718892915, 0.056906038230018954, 0.02929602423682809, 0.04664624948054552, 0.030796254985034466, 0.0402296016524945, 0.006249596747303647, 0.019590030324512293, 0.07247518029596124, 0.048370983717697005, 0.03580770089424082, 0.01812610968149134, 0.04312542287100639, 0.051312412667487345, 0.06056533008813858, 0.018211216632542864, 0.015522117892812406, 0.006959662864184273, 0.015778655019987906, 0.024995311529242566, 0.03823267648528729, 0.025378812736432468, 0.01550045226966696, 0.016051600820251873, 0.03171572082542947, 0.07234114248837743, 0.07967692028198924, 0.025514803028532436, 0.035681157505937984, 0.03534213087654539, 0.008179559838026762, 0.01577005458862654, 0.003036509941531611, 0.07559756774987493, 0.018212797619136314, 0.03109607586104955, 0.015420990729970592, 0.05464217738647546, 0.030711326149425337, 0.01690470254314797, 0.07006985507905483, 0.025665368252832974, 0.050029523471104245, 0.015133315630789314, 0.024695629752906303, 0.019058197969570756, 0.021537271461316516, 0.0665118277871183, 0.03513738293466823, 0.040460232312658, 0.03812120335974863, 0.021259728586301208, 0.05936385491596801, 0.028210916124018173, 0.01110932816352163, 0.09259857476821967, 0.024341802578419447, 0.07882341143808194, 0.02202777424827218, 0.0547098307205098, 0.04743617959320545, 0.04249333357438445, 0.030373734621597186, 0.03827150225905435, 0.04382815105574472, 0.03732717489557607, 0.05353769200987049, 0.01309688191395253, 0.022337975013735037, 0.026408408203029206, 0.02282986370846629, 0.02280572143250278, 0.009853694022500088, 0.028572929823505025, 0.026526005107111165, 0.08784630548741136, 0.03390432195737958, 0.009226961759850383, 0.04825635201164654, 0.06224091803388936, 0.05630841851234436, 0.04201168227674706, 0.039537614677101374, 0.04742468860266464, 0.037673071692032475, 0.004929465308253254, 0.03141353864754949, 0.06386536479528461, 0.016336797570277537, 0.040346536984933276, 0.015943966506581222, 0.037334068811365535, 0.06932437579546656, 0.02520978287793696, 0.02815750184735017, 0.050931754522025585, 0.0060169843408013025, 0.004742657832269157, 0.004817464197653213, 0.053061485955757756, 0.05185329667957766, 0.011033528168419642, 0.00743092706293932, 0.05808179692498275, 0.04670392834980573, 0.029323738999664783, 0.008805722131260803, 0.05401469534263015, 0.06330847753477947, 0.008598669714826559, 0.02271996987318354, 0.033358949436140914, 0.010299642503793751, 0.024898990090670328, 0.07109238699610744, 0.011407215214733566, 0.030936209617980888, 0.0734721857256123, 0.0659764161599534, 0.041989975941500494, 0.016301009937056472, 0.07709380531949656, 0.12243073327200753, 0.048644243340407095, 0.011909655977173575, 0.016999724587159495, 0.03568639579628195, 0.04595647792198828, 0.016830482686470662, 0.02837324544920453, 0.049134233833423684, 0.00784688938542136, 0.036246580736977715, 0.05943896874253239, 0.010380104034473854, 0.0232881123333105, 0.017136457875104885, 0.04643955075048974, 0.023635883582755923, 0.04505514253729156, 0.06821622632976089, 0.042133781260677745, 0.08665008217628513, 0.02435070156518902, 0.014936457354841488, 0.045944589988461564, 0.026638350150148784, 0.026241990704355494, 0.04609403732631888, 0.042065836156585386, 0.023695625198472823, 0.04569105198606849, 0.030702664649912288, 0.012718472263908811, 0.022831312380731106, 0.08727348622466836, 0.007396288698406092, 0.021224081749096513, 0.024447555653750896, 0.010712095952060605, 0.0549469379974263, 0.060890925116837025, 0.0552915320066469, 0.02835285716823169, 0.022573921995769654, 0.03326223444725786, 0.008896152189533626, 0.03126198445845928, 0.05090899645750012, 0.08452634220676762, 0.04069356354219573, 0.0486536817625165, 0.032810930628329515, 0.03620378553335156, 0.024203515445281352, 0.05492813918473465, 0.029929036341075386, 0.06704394173409257, 0.009926724746557218, 0.03640050640595811, 0.040680969932249615, 0.007911625867044287, 0.019044678159324185, 0.04025775407041822, 0.04043785083506789, 0.06889632197895221, 0.04231415283200996, 0.029222749240164245, 0.04229810887149402, 0.03049829668764557, 0.023860326003549353, 0.025576760061085224, 0.046985011481280835, 0.025518881023994515, 0.049272709260029454, 0.019390291667410305, 0.0471116939692625, 0.012994541869764882, 0.05208146765029856, 0.01598441058636776, 0.06086957161980016, 0.08805905335715838, 0.052795143997562785, 0.06023743482572692, 0.02685110310890845, 0.06478095280804805, 0.05737419346613543, 0.032550200154738765, 0.06412478908896446, 0.04862550898854222, 0.05709108151495457, 0.023399843302156245, 0.00852568818455828, 0.061314948435340605, 0.032694324385374784, 0.012865847525452929, 0.07224591009851013, 0.0438915160484612, 0.052579987328499556, 0.021955013241884962, 0.042939198935138326, 0.04398743715137243, 0.04587555244298918, 0.06344373670539685, 0.07841898421091692, 0.030860529214675938, 0.05116335887994085, 0.07558421418070793, 0.031315463195954046, 0.021901666818718826, 0.00661343231331557, 0.09054136515728065, 0.05371766324554171, 0.06288593342261654, 0.053976805947188816, 0.015463628174204911, 0.04742845107934304, 0.04830896561699254, 0.023790864373690317, 0.04338777504329171, 0.043801260712955675, 0.09041920171252318, 0.0719264354556799, 0.04124286138851728, 0.031545920829687796, 0.03047490758555276, 0.04045796600569572, 0.04000108802158918, 0.08645703217812947, 0.0272611859254539, 0.025003057006480436, 0.017410979572949663, 0.026396778112809573, 0.05565162714836853, 0.02234888755317245, 0.014438852002578122, 0.07642432874334709, 0.06163650618067809, 0.021585260850510428, 0.021879258199727962, 0.000639328099038851, 0.07916035835764237, 0.028769776225090027, 0.041726402406181605, 0.006111630646046251, 0.05901535933039018, 0.05850662091480834, 0.010397622112317808, 0.05832125193306378, 0.040638052592320104, 0.040688111513320885, 0.016889111504756978, 0.017993074409397583, 0.026140403834038546, 0.04800995559032474, 0.046202477400324175, 0.0265959213554327, 0.04814092641962426, 0.013958626476648663, 0.012491015451295035, 0.02577007468789816, 0.04032439638727477, 0.009905786004050501, 0.030229311835552965, 0.06366610620170832, 0.023656580597162247, 0.046429057206426344, 0.002612811471668205, 0.039006376040301154, 0.05176569102331996, 0.0657325235328504, 0.03663354925811291, 0.013722156174480915, 0.036052112600633075, 0.077719618167196, 0.057051115802356174, 0.012656466885735946, 0.032515740753816705, 0.019973204138555696, 0.05562706757336855, 0.01421210341089006, 0.032776973343321254, 0.01991803415252694, 0.07744650782219001, 0.11969277661825929, 0.05754683313093015, 0.015211184309529406, 0.02984329665611897, 0.03663826507649251, 0.041185287692184956, 0.058468650095164776, 0.01935916387342981, 0.0006087746743495309, 0.005839729789711002, 0.021706068921568136, 0.04759292457518833, 0.04620294558948704, 0.017068098864651153, 0.024390631654698933, 0.04324333529387202, 0.017952699879450456, 0.060430511965283325, 0.043712532081242116, 0.015985116262787154, 0.027576189022511244, 0.00914847815874964, 0.017075627210683057, 0.03670265804976225, 0.0336235747007387, 0.008328689960762858, 0.041578688725296936, 0.02381874537760658, 0.12125939184001513, 0.15724259242415428, 0.2178566006145307, 0.11969105313931193, 0.20800263008901052, 0.1461717914789915, 0.14441587855773313, 0.12508343878601277, 0.10093504243663379, 0.13864861588392938, 0.17603981734386512, 0.09543683246842452, 0.1244477057563407, 0.1547939631023577, 0.12323316878506116, 0.12201564625969955, 0.1875468755939177, 0.08886891204331603, 0.08146522646503788, 0.1182241282824959, 0.11394790560007095, 0.1809213746871267, 0.06946346190358911, 0.10795452791665282, 0.12503226367490633, 0.11188798184905734, 0.10530982911586761, 0.16532389021345548, 0.22452741408986704, 0.20881198665925435, 0.1966631699885641, 0.16088032722473145, 0.20024373142846993, 0.1426318200039012, 0.10548600394810949, 0.08297817635216884, 0.1603987437805959, 0.10244508140853473, 0.18351781607738563, 0.11799341280545507, 0.09067773033997842, 0.10703566936509949, 0.1259636344122035, 0.08194765129259654, 0.15239946730434895, 0.1382160090974399, 0.19202287255653314, 0.13218976317771844, 0.07928100188395806, 0.20391924705888542, 0.1533176473208836, 0.09386227160160031, 0.24074664020112582, 0.1219714464885848, 0.11884257223989282, 0.06911061690854174, 0.027394928570304598, 0.1393103368048157, 0.14416340924799442, 0.11268722824752331, 0.1264333299228123, 0.11414466718477861, 0.17989263417465345, 0.10948905521737677, 0.12394017513309206, 0.2593340756637709, 0.13838491003428185, 0.12450566621763365, 0.22378920870167868, 0.18191868545753614, 0.12259888782032899, 0.24647806265524455, 0.13996653445065022, 0.1214033905416727, 0.254886875727347, 0.19726693044815743, 0.14865715668669768, 0.14969786655689987, 0.14038832538894244, 0.1353777785386358, 0.1875648024891104, 0.11698513690914426, 0.1655521493937288, 0.15763243793376855, 0.10307572542556695, 0.20318641566804477, 0.16608523364577973, 0.12427754274436406, 0.11860995686479978, 0.1161379859383617, 0.1348312185811145, 0.16369718393044813, 0.12795194557734899, 0.1708397285214492, 0.18018608699951852, 0.20087577322764055, 0.16126155533960887, 0.08559671084263495, 0.17854312301746436, 0.08910231451903071, 0.145234259643725, 0.1279383205941745, 0.09932981178696666, 0.09684104033346687, 0.16923055558332376, 0.2849832150552954, 0.19139567549739564, 0.16714811804039137, 0.11145861845995698, 0.126007169219, 0.1888260498110737, 0.13952398034078733, 0.28588363102504183, 0.1561680372272219, 0.13208152327154363, 0.09196466021239758, 0.09284404838191611, 0.06139435060322285, 0.0977827858711992, 0.11667902262083121, 0.08212520355092627, 0.11817698366940022, 0.13066628921244824, 0.10587097079093967, 0.1267507350338357, 0.08848929205643279, 0.09070259864841189, 0.1431156833256994, 0.15705735236406326, 0.10760587626802069, 0.15217275518391812, 0.09201320939298187, 0.1883356725530965, 0.14403173274227551, 0.1107461770464267, 0.10318045730569533, 0.16279926496957028, 0.11807556982551302, 0.14479344258350985, 0.14287371773804936, 0.09065818853144135, 0.1658576258591243, 0.18488754757813045, 0.1794654285269124, 0.14256252800779684, 0.09753124615443604, 0.10865128838590213, 0.18170999522720063, 0.16164667824549334, 0.15208417922258377, 0.14783749995487078, 0.13169872095542295, 0.09919498009341103, 0.0918671547302178, 0.11284320309226002, 0.10659016362790551, 0.15488932441387857, 0.12018191894250256, 0.074062823317945, 0.13389340176114015, 0.18760322114186628, 0.12969481705554894, 0.1794970618294818, 0.12872126858149255, 0.057199674259339056, 0.16301315277814865, 0.18212652073374816, 0.096481118218175, 0.14291660115122795, 0.12383823203189032, 0.1797012872993946, 0.20108697403754505, 0.15176654340965406, 0.17200233042240143, 0.1114752289972135, 0.16842927357980184], [0.07320655283651181, 0.04729637423796313, 0.08347592928579875, 0.012546279584057629, 0.023919187220079557, 0.016610184418303624, 0.04600472515448928, 0.054123342369816134, 0.02519962690504534, 0.011119021884431797, 0.034462637534098964, 0.06019364896097353, 0.038793818160359345, 0.03683448044051017, 0.03032092424109578, 0.11657813803425857, 0.027010876053412045, 0.0576076570100018, 0.14134949738425867, 0.03526030294597149, 0.07640869529651743, 0.026154860022610853, 0.043618337849953344, 0.02033206434654338, 0.06582958118191787, 0.07423914742789098, 0.033906371133135896, 0.07472113120768752, 0.00957825206153627, 0.06260860937514476, 0.0020503498339426835, 0.0361660623789898, 0.06798265422029154, 0.07605426252952643, 0.03232582898012229, 0.045117642397859266, 0.04428459817011442, 0.08282635414174624, 0.06715389154851437, 0.010837886166492743, 0.022500650391780903, 0.016451429276328002, 0.02946938993409276, 0.056636222172528505, 0.061962270843131204, 0.03819784389010497, 0.04456854811204331, 0.013505054654420486, 0.04591142998210021, 0.02674015754434679, 0.06658572025064911, 0.02651520791862692, 0.07010246547205107, 0.05629383000944342, 0.08991176608417716, 0.03679010085761547, 0.09219321116272892, 0.05943257694265672, 0.04294775865439858, 0.022263839973935058, 0.07520823792687484, 0.0388878224018429, 0.018237559058304344, 0.029179224611393044, 0.05108529681872044, 0.053041425067931414, 0.04278687121612685, 0.07800496928393841, 0.029705767785864215, 0.0521341592871717, 0.05456962163693138, 0.09061299809919936, 0.022545552446639965, 0.004941898614301213, 0.009505228970998099, 0.0756239899035011, 0.014072178463850702, 0.08521612055067505, 0.03631527562226568, 0.0570285612983363, 0.0433914425250675, 0.05859409086406231, 0.047426870092749596, 0.02330518257804215, 0.0066143915921981844, 0.05071114243141242, 0.04064339944826705, 0.09460445999034814, 0.08638163336685725, 0.04745481555749263, 0.10757313695337091, 0.04178976739889809, 0.00893450468512518, 0.025116647161277275, 0.022561676135020595, 0.06460781102733952, 0.04279697460255452, 0.03401662289564099, 0.06097341461905411, 0.05162020293729646, 0.021135517662124972, 0.05816983684365239, 0.014944294434306877, 0.11276456766894885, 0.04887375781046493, 0.1458268921290125, 0.024511772207915783, 0.059004808110850196, 0.013132470227511866, 0.02189285434516413, 0.06138519038047109, 0.029738656378218105, 0.05539590087054031, 0.03783879029963698, 0.014505263617528337, 0.062319207404341014, 0.06075994750218732, 0.030899986026010344, 0.028869768538113152, 0.03601298148610762, 0.05388337167512093, 0.03470985159011824, 0.017359794283817922, 0.025843748323885456, 0.023100061441904733, 0.020138654724827836, 0.06821733912719147, 0.010774685718518282, 0.047636632408414564, 0.04393375146069697, 0.008046519476920366, 0.026967103759359037, 0.014079622841174049, 0.038431714554982524, 0.07077926344105176, 0.014334856332944972, 0.05222670467836516, 0.050763664434530904, 0.04178453250122922, 0.009525231335179081, 0.06782847749335424, 0.04965428342776639, 0.03216558275744319, 0.025363532127812505, 0.030081492981740406, 0.07174257960702692, 0.01773657969066075, 0.01808065122791699, 0.02836369167614196, 0.02077596534841827, 0.013928298505821397, 0.01665859958822174, 0.014279299581955587, 0.05041924684441515, 0.03668548432844026, 0.01596693491696247, 0.009319838785034205, 0.016729966205145632, 0.010187446738460233, 0.07920008658298425, 0.03902272873425058, 0.04348451038822532, 0.03532176125528557, 0.06207007648689406, 0.06269922772688524, 0.039657756087503264, 0.0839923487177917, 0.02802878205797502, 0.033948782964476516, 0.031037816844348396, 0.021787347238776938, 0.02004262335997607, 0.02632893478897001, 0.033807461083467515, 0.033897445004965575, 0.020280729779707532, 0.0526659611080374, 0.023531652122203792, 0.021822329111663357, 0.04362111305817962, 0.04745301065434303, 0.017389598934512054, 0.04566978330590895, 0.03729943299133863, 0.015566994502608265, 0.03521445094208632, 0.05823471157678536, 0.017012106154912283, 0.10761232235069786, 0.02905279996671847, 0.05870826795165028, 0.048301593334014924, 0.030296100037438527, 0.03134768682398966, 0.06033816334924527, 0.038101437634655407, 0.019637855168964182, 0.010959136133481349, 0.022638542278270637, 0.03706020868516394, 0.008622823865152895, 0.04922748490103653, 0.0052230585050503054, 0.017371180101430843, 0.0650450929201075, 0.025082550776590194, 0.014054728239508612, 0.0670203355007938, 0.05454374909667032, 0.02127183704370899, 0.02923255067850862, 0.030259452361081327, 0.06699052067207438, 0.024565654673746655, 0.027150572843051383, 0.018341658204527836, 0.051862623143408976, 0.015649341512471437, 0.0372025551540511, 0.04600631631910801, 0.01884954675499882, 0.06824950168707541, 0.06026844387607915, 0.01710352348163724, 0.03365297223042164, 0.018256875253947716, 0.020989803963207772, 0.006424568452140582, 0.05380172694900206, 0.028822735883295536, 0.07866681234112807, 0.04991319203483207, 0.02361261492062892, 0.019458743976429105, 0.01567071706189641, 0.07817974633404187, 0.0733446686395577, 0.038715135239596875, 0.036785880369799476, 0.021216025842087607, 0.06265474975641284, 0.058278470300138, 0.016528767001416002, 0.03556987437020455, 0.06027272543204682, 0.020665194506623914, 0.01745857371549521, 0.014422429758789284, 0.015860691600080048, 0.037558857285018475, 0.041346636534269364, 0.10225996348474707, 0.04435399533914668, 0.07506810687482357, 0.05535002511792949, 0.034580539778939316, 0.046922640542366674, 0.043150610090898614, 0.06790170499256679, 0.023451245722493956, 0.0373077314746167, 0.013773074290449066, 0.030683889585946287, 0.019428233649315577, 0.10318311037761824, 0.010265261982567608, 0.08589983957686595, 0.06386431985135589, 0.06300863291003875, 0.07068833296320268, 0.0518772218243352, 0.044613677476133616, 0.021726611569257717, 0.03522298012727073, 0.026014094540317143, 0.05644958433029907, 0.007218497256482286, 0.02795916436506169, 0.030725629667618444, 0.08651169495923178, 0.047745082660445144, 0.06764646725995199, 0.04998070966186268, 0.04606427338772586, 0.025696874330086366, 0.044666355542306385, 0.06068731711379119, 0.029403429544929947, 0.02013547918094056, 0.059037133519138606, 0.014785444297428642, 0.049894898730729303, 0.05410778695451362, 0.03658235039828079, 0.040398014044123035, 0.04937951406463981, 0.02857928430395467, 0.0422472662425467, 0.02574740144025002, 0.04812723019027284, 0.028124375767739754, 0.017886286568162695, 0.014796399245304721, 0.03246785993022578, 0.05004791855545981, 0.02930547622963786, 0.031112197853092636, 0.051261278268482, 0.009142840380913444, 0.017878697153979113, 0.060613098953451426, 0.01549518683792225, 0.053343033883720636, 0.027448834784861122, 0.04955801287932055, 0.03395271846758468, 0.06111272464373282, 0.04457659214468939, 0.006493952474556863, 0.03695040136309607, 0.036344978492707014, 0.07261186439011778, 0.0375542262835162, 0.013307668817495661, 0.02310784423856863, 0.04247354070789047, 0.033028350211679935, 0.04585735074111393, 0.017402664126296128, 0.049760433446083746, 0.0578389899539096, 0.025194051043529595, 0.09823912102729082, 0.06958422756620816, 0.03903382278180548, 0.0996513423909034, 0.019074121490120888, 0.07116940072072403, 0.04517698707059026, 0.058175047992595603, 0.004024588394843574, 0.04663091119644897, 0.030102564886744534, 0.0802052751449602, 0.016004951537719796, 0.03230542543211153, 0.036013646450425894, 0.022211058431171944, 0.04087678835328136, 0.02219557765472148, 0.039078948753220696, 0.0192494244048638, 0.13973564255450452, 0.09190402632313115, 0.14257752363170895, 0.0887714744146381, 0.10820152823414121, 0.0982264799198934, 0.2455596247954028, 0.07937881270689623, 0.10994004351752144, 0.12768260788704666, 0.10974732600152493, 0.18205298110842705, 0.1981690020433494, 0.12283447517880372, 0.10980628390929528, 0.24948918393680028, 0.0854717789750014, 0.11911703965493611, 0.21602371468075685, 0.106071613595954, 0.14969573595694133, 0.10567257393683706, 0.17878464077200207, 0.08384593443146773, 0.13429797148065908, 0.22319326496550015, 0.08919625769236258, 0.10549442456769091, 0.15871774112539633, 0.13612139863627298, 0.07160164788365364, 0.16410513275435992, 0.14890597547803605, 0.1914555358567408, 0.16222602501511574, 0.13630559375243528, 0.26808326904262814, 0.21469533310404845, 0.11732550364519868, 0.08780595300985233, 0.12084825390151568, 0.07169388114873852, 0.19852531435234205, 0.08460043823080403, 0.09154248250914471, 0.13503948811973843, 0.18144728003868035, 0.09560734153326068, 0.33877193448799, 0.06638539635709353, 0.09364769168730293, 0.14493320722665104, 0.16812355284179958, 0.08809367899916001, 0.15452210126178606, 0.11806270480155945, 0.16172287772808755, 0.18227252789906093, 0.14429644282375062, 0.24206769359963282, 0.11625987796911172, 0.2025159959282194, 0.09943911020777055, 0.17085184715688229, 0.3223155603877136, 0.10338206363043614, 0.12752537775252545, 0.22174004651606083, 0.12367845060569899, 0.07950442989489862, 0.09135596001786844, 0.19592541243348802, 0.13814447793577397, 0.15640699011938913, 0.10187982781124966, 0.303053118288517, 0.2119601991559778, 0.16958779069994176, 0.1839300532426153, 0.17628806616578782, 0.17589721642434597, 0.08056810139013187, 0.23405245797974722, 0.19045500883034297, 0.10501607773559433, 0.12191618659666606, 0.1490187072860343, 0.13175726495683193, 0.2056114591125931, 0.15899990312755108, 0.21862097031303815, 0.12757752995405877, 0.16186580434441566, 0.27824161680681364, 0.16481589818639414, 0.0938642325678042, 0.1530616089169468, 0.11861082538962364, 0.09511654358357191, 0.13517173459487303, 0.17440950125455856, 0.14183773047157697, 0.10410034044512681, 0.23825324113879884, 0.15289540854947908, 0.28272817177431925, 0.19962241048259394, 0.1952858388956104, 0.09622121894998209, 0.14035412722400256, 0.188885733751314, 0.14483971867178166, 0.12007363832422666, 0.1508807973670108, 0.07931574287691287, 0.14032195109341825, 0.20174827426671982, 0.20601947579000676, 0.08963826897421054, 0.15195126778313092, 0.09238165390810796, 0.14683420450559684, 0.16790354464735302, 0.1747018684233938, 0.168554992548057, 0.16469395187284264, 0.11973104599331107, 0.11892044091863291, 0.12545929290354252, 0.10086250704314027, 0.11322372553071805, 0.1280583670096738, 0.09473348342414413, 0.14214415688599857, 0.15154211116688593, 0.1596914931599583, 0.09923050140163728, 0.15288704899804934, 0.19354496231036528, 0.07658897526562214, 0.20617046340235642, 0.10955525309379611, 0.14552178207252706, 0.2185838815889188, 0.18379612400063447, 0.20640819493149007, 0.13759272040000983, 0.11583579358245645, 0.0800197704562119, 0.12236087130648748, 0.12806063331663609, 0.07690650929829904, 0.13795347032802446, 0.18867510291082518, 0.19777363325868333, 0.06618832264627729, 0.1440019586256572, 0.22265984144593987, 0.14365161742482865, 0.2097701866711889, 0.06764614156314305, 0.19524102844297886, 0.10363970337701695, 0.16543111231710228, 0.22643350038145268, 0.12498647613184792, 0.16229267072464737, 0.11988222359546594, 0.14413147739001683, 0.2181179994451148, 0.08446714002639055, 0.13322638826710836, 0.13615782239607402, 0.1900835516197341, 0.07295576629361936, 0.06360334171248333], [0.05309338727965951, 0.035789811318474155, 0.009930261610341924, 0.016681096416765025, 0.027903717876012837, 0.023847313398229222, 0.046128187993807454, 0.03882875253579446, 0.03221093603808965, 0.01237555084350918, 0.04116239392065576, 0.05486381406496678, 0.044634779915213585, 0.022352465129058276, 0.030025615622954707, 0.036621311879051585, 0.025202926281573515, 0.036009174904653, 0.025506099120580723, 0.05306767758780292, 0.03695883555337787, 0.008934471606543022, 0.02846847953540938, 0.025183925604713813, 0.06180733415697302, 0.0026886634171075586, 0.0239093756037099, 0.035553626849183013, 0.03704463969916105, 0.08244705985167197, 0.031192146241664886, 0.0426107812007623, 0.027755581807079058, 0.024926667534080998, 0.05486308124714664, 0.010795470094308257, 0.03710042545571923, 0.013631611613423696, 0.034229153634182045, 0.037766943619187386, 0.02852646374542798, 0.0723729929221528, 0.03993158907230411, 0.06074466010821717, 0.020852643198200634, 0.07480380391435963, 0.03797352699828999, 0.046799340551452975, 0.02393390973364668, 0.047627339871334176, 0.03538059702675257, 0.025993992940389683, 0.025259365128087144, 0.03856279394988503, 0.008603005553595722, 0.04249803242938859, 0.023911306035837958, 0.06077423744968005, 0.12695189352546418, 0.046376284145350964, 0.034370448373790295, 0.048986856027373245, 0.0473528181734894, 0.03938049989353333, 0.031642208341509104, 0.05493962338992527, 0.02008634985291532, 0.047414649677063735, 0.03943598370200821, 0.02302102737927011, 0.04272291589794414, 0.030757232436111996, 0.048508054576814175, 0.024517017283609936, 0.01733542130594807, 0.06968423005725656, 0.05046830492626343, 0.045714692146118195, 0.05165314581245184, 0.04526489128225616, 0.05421450015689645, 0.0642414903268218, 0.014490610653800624, 0.017555198798488294, 0.06994503177702427, 0.11465149213160787, 0.058131384264145575, 0.05576641491747328, 0.05196604884362646, 0.07066495743181024, 0.027800826522122537, 0.07157940550574235, 0.05996369344315358, 0.04762580977486713, 0.056774694206459184, 0.05354628904855677, 0.06753100774117879, 0.018722626779760634, 0.02123025302509112, 0.0013359599646979145, 0.025651029111551385, 0.050145586886044057, 0.03272239198642118, 0.03988654452509113, 0.03425032392676387, 0.028846311582518474, 0.023514753207564354, 0.02092444577387401, 0.04785689505349312, 0.045846002242927036, 0.04719927587679454, 0.023700790546302284, 0.042315655787076266, 0.01687426006953631, 0.01999991975857743, 0.040452982165983746, 0.01973387805212821, 0.006450612746578242, 0.04364635456087334, 0.027790967408301573, 0.012602868556444134, 0.025221355292680006, 0.05453877204230853, 0.04275880361508046, 0.03374097482966525, 0.008231170907882708, 0.01521050916718585, 0.03688741295731493, 0.041424576459186416, 0.0730477145739964, 0.028875661614750112, 0.015194258253489221, 0.024772024314318384, 0.027811253909021616, 0.05445898989481585, 0.01828021346591413, 0.0671433810410755, 0.020747582228588204, 0.026879124908841083, 0.018151933027963554, 0.01290914399682411, 0.0395846914366952, 0.04559628439268895, 0.06365922585661922, 0.05316039600542613, 0.008036352477834692, 0.07338251732289791, 0.03818588810307639, 0.042701297772250006, 0.018268322139712315, 0.05093146614464266, 0.029689954527254616, 0.04208064179069229, 0.06672072836330958, 0.025308463922036544, 0.005254531927805926, 0.027746036515704224, 0.05050383980519005, 0.044799721600221734, 0.023291097887392555, 0.017474826325529387, 0.00998544940791492, 0.053783219906368425, 0.0560254524461925, 0.030128780087190013, 0.05230673449113965, 0.02574626828676888, 0.03014674430180873, 0.037317977353398285, 0.039218089144144735, 0.0007654995653345914, 0.04483318694734147, 0.07496327321444239, 0.08161966782063246, 0.032059300424797196, 0.054480414638029676, 0.02234161026509745, 0.010698552393088383, 0.010499510930718055, 0.021521498914808035, 0.04870140652305313, 0.035634956056518216, 0.029195607839418308, 0.023065637664071152, 0.018433767636971812, 0.014494530889870865, 0.06375143198030335, 0.014929095249889153, 0.0656022990920714, 0.015787311430488313, 0.060191389439361434, 0.02508616567190204, 0.022010783731405224, 0.07088314036705665, 0.0178669551054814, 0.06815630490226404, 0.028564404030995708, 0.017288775416091084, 0.05597400592107858, 0.018397796799295714, 0.019580161032666053, 0.005341355996539018, 0.07268442013966185, 0.09161646318222795, 0.02287773265769439, 0.09890590381941625, 0.06487152366233723, 0.05221185493948204, 0.04656215863568442, 0.03161023237875529, 0.034409362357109785, 0.06350069972021238, 0.007359341618471912, 0.025627621349745562, 0.041574722688112936, 0.029697272527430738, 0.08679543794797999, 0.030061350669711828, 0.0235890544884439, 0.0642717122765524, 0.02295862590628011, 0.023451096444789852, 0.018395516921633055, 0.06824521334575755, 0.05486078101343342, 0.03387721787605967, 0.018965513478698473, 0.03480167094884174, 0.03553732504535999, 0.01698598594936941, 0.056697490492037365, 0.04018186332125749, 0.018810615808303868, 0.056053367376859696, 0.07373125718108245, 0.008887295611202717, 0.06659906703446593, 0.026397134343694364, 0.058802428256188116, 0.034692762685673575, 0.019709939336670295, 0.02664275553875736, 0.06996774912944861, 0.01789374027534255, 0.03976848960987159, 0.0777543523748006, 0.04160520248115063, 0.02890746115839907, 0.05902420064168317, 0.056608212246958695, 0.021631168833534633, 0.08787632387663637, 0.03992247973967876, 0.04772355952965362, 0.06097431707062891, 0.09009141501571451, 0.03744871748079147, 0.040510725496070724, 0.061024067258196216, 0.07285031516637121, 0.07395993705306735, 0.14184178811098846, 0.03179894993081689, 0.05586587118783167, 0.08898210525512695, 0.06604933153305735, 0.028157218558979884, 0.04456877202859946, 0.03517302977187293, 0.024020217691681216, 0.041388936407331905, 0.08992868874754224, 0.08478376482214246, 0.041592568159103394, 0.08955543341913394, 0.05164070148020983, 0.039162398382489166, 0.06069860115115132, 0.051270156899201016, 0.039090259931981564, 0.04152725577088339, 0.08260579633393458, 0.03607792407274246, 0.06197559727089746, 0.02064210226360176, 0.04195504495874047, 0.07179608209324734, 0.01543566065707377, 0.05625125193702323, 0.036341650278440545, 0.044047548568674495, 0.055231373091893535, 0.02199432416819036, 0.02684098106276776, 0.016379419747473936, 0.04078100974272404, 0.027586127864196897, 0.004040493679765079, 0.053142055203872066, 0.039229722627039464, 0.018777040199243596, 0.003347033859297101, 0.009732371112996978, 0.009852361549357218, 0.040733776920075924, 0.06351026027862515, 0.011275084938720932, 0.05664569791406393, 0.0415021465825183, 0.015986853312434893, 0.03433106280863285, 0.04379379004240036, 0.026602635459442223, 0.025094286039737717, 0.02018265432811209, 0.031332131408687146, 0.010840564683478857, 0.03905439257089581, 0.06536487290369612, 0.013989265725415732, 0.020009310683235526, 0.0497032770487879, 0.022902731584118943, 0.049522586565996916, 0.01980190458042281, 0.009905223668153797, 0.021571434003167918, 0.005409224341357393, 0.008106334883320545, 0.029006269427814653, 0.052098990817155154, 0.04927294335461088, 0.07750844449869224, 0.06613638757594995, 0.019379857495161038, 0.03782174889264362, 0.030327628167080026, 0.0060192951766241875, 0.05352504411712289, 0.06920093670487404, 0.01733885978215507, 0.03526546320478831, 0.0773212027602962, 0.008567714099107044, 0.05389452679082751, 0.044410435881997855, 0.0579564647216882, 0.07430152515215532, 0.05326086329296231, 0.033381412337933264, 0.02789350931665727, 0.033259740831064324, 0.1077744107959526, 0.07975945049630744, 0.147103718615004, 0.0963163020621453, 0.07012381896908794, 0.12869080235915525, 0.07686904059456927, 0.13937753891306265, 0.1498582993767091, 0.08906107994594745, 0.17570679235671247, 0.12165155793939318, 0.1424963301313775, 0.08640589099377394, 0.1404037688459669, 0.11201539036950894, 0.09140880432512079, 0.18189512672168867, 0.0874293932159032, 0.22518555234585488, 0.13454662742359297, 0.1015734149675284, 0.1598713185106005, 0.10662177657442433, 0.11247222764151436, 0.15280174357550486, 0.1458280049264431, 0.1314335223287344, 0.15621159917541913, 0.22020648952041352, 0.21138579212129116, 0.12058632581361703, 0.11722939594515733, 0.09866490853684289, 0.19269140596900666, 0.114795110853655, 0.06563763041049242, 0.0784186924408589, 0.09084199688264302, 0.09369340459150927, 0.11921696072178227, 0.09193836698042494, 0.09864898331995521, 0.18102894962898322, 0.14804127759167127, 0.1518823421959366, 0.08610662312379905, 0.13822409723486218, 0.14261180322085107, 0.2152996635330575, 0.1448911109140941, 0.14872879641396658, 0.14991693837302073, 0.13991508792553628, 0.14898009864347322, 0.14234688957887037, 0.15508723950811795, 0.2738889775105885, 0.17466609605721065, 0.14771142814840588, 0.1566138890172754, 0.16795233131519385, 0.19840756138520582, 0.12036285709057536, 0.10443259868770838, 0.1629593042390687, 0.10746175543005977, 0.13944516171302113, 0.11652936493711812, 0.1701119997139488, 0.17656812470938477, 0.11713330181581633, 0.14890885246651514, 0.1104737248803888, 0.1990084855684212, 0.15173286093132837, 0.1419419805918421, 0.14803318945424898, 0.14597032086125442, 0.14707570868943418, 0.14871069309966906, 0.16829526291361876, 0.15213794633746147, 0.131483720349414, 0.14390992213572773, 0.3270973323711327, 0.1079164349607059, 0.23038220778107643, 0.1315343254911048, 0.15579947057579244, 0.11766759386020047, 0.13722255240593637, 0.1872895344027451, 0.15138455533555575, 0.1932216810860804, 0.1491453219205141, 0.1687782034277916, 0.11544343749327318, 0.11854221192853791, 0.1435445174574852, 0.09775663513158049, 0.18238832668534347, 0.13510194048285484, 0.1921764114605529, 0.13038122308041367, 0.20558457555515425, 0.14118849459503377, 0.16027898234980448, 0.11178913286754064, 0.22832315255488667, 0.1816927468670266, 0.10926541007523026, 0.15529483051172324, 0.14945124621902192, 0.11452740164739744, 0.27509212866425514, 0.07481770031154156, 0.12699077358203276, 0.18178907169827394, 0.10222373650010143, 0.04747440486348101, 0.13976275681384973, 0.16071817092597485, 0.12228575747992311, 0.17672703761075223, 0.07661838975868054, 0.0518359567171761, 0.11687198440943446, 0.1481903110231672, 0.17053543270698615, 0.14092086681297847, 0.19736643082329206, 0.10561890181686197, 0.11193444114178419, 0.1010154081242425, 0.15193913557699748, 0.12705840995269163, 0.05522975139319897, 0.15220601697053227, 0.1447467186621257, 0.09491703393203871, 0.08571123398308243, 0.13555767174277986, 0.11201100703328848, 0.16147893081818307, 0.14314933866262436, 0.12209417990275792, 0.07866164868963615, 0.1391206184136016, 0.10549481811800174, 0.12197657621332578, 0.1504171815301691, 0.09373733973396675, 0.16435070814830915, 0.11475752001362187, 0.10851462464779615, 0.1913102072264467, 0.19703352797244275, 0.1529441409345184, 0.126032166449087, 0.13596764260104724, 0.04244818724691868, 0.18279337137937546, 0.18624845812363283, 0.04825251489611609, 0.15711713129920618, 0.14007615856826305, 0.06375073308923415, 0.23376858606934547, 0.19877709155636175, 0.17164608596691064, 0.14662004528301104, 0.1011393629014492, 0.18927123663680895, 0.07600303992096867, 0.09922308501388345], [0.06802522550736155, 0.04273585556074977, 0.06275095923670701, 0.019806968147999475, 0.0200572661456785, 0.04231533009026732, 0.047419965998934846, 0.013146907756371158, 0.020966065415580357, 0.046581249218434095, 0.05211729769195829, 0.025760256286178316, 0.012958940833673945, 0.09430158231407404, 0.037856649341327805, 0.05925744705434356, 0.04108319192060402, 0.05193652578496507, 0.03441274146150265, 0.03190980898216367, 0.036771135803844245, 0.056647950650325844, 0.026634865872828022, 0.02483373537792691, 0.0586447502885546, 0.01965046065327312, 0.012896070323352302, 0.01146008157437401, 0.04320623299905232, 0.054989621242774386, 0.029922539368271828, 0.04984878549086196, 0.09384124380137239, 0.08837340506059782, 0.08609158000243561, 0.053980507355715544, 0.03927841429997768, 0.027816767006048133, 0.053621155209839344, 0.041907645895012786, 0.048733816748218875, 0.05273345159366727, 0.0344235132049237, 0.06688964965620212, 0.04124513787350484, 0.04739356080868414, 0.03737937459456069, 0.0399201998620161, 0.03744576246078525, 0.022503722459077835, 0.0511331131814846, 0.04372198746672698, 0.029573745227285793, 0.045710878779313395, 0.03361220923917634, 0.02659487471516643, 0.1172831766307354, 0.010197589988820255, 0.057315642679376264, 0.0763401361182332, 0.0561160674052579, 0.0623184610158205, 0.08928758850587265, 0.028513530867972543, 0.054749745542981794, 0.01323085865338466, 0.040000928565859795, 0.08008188355181899, 0.08803601709327527, 0.03341258762936507, 0.04399502656555601, 0.05359655831541334, 0.06444419587829284, 0.032585243095776865, 0.06055008340626955, 0.15634536556899548, 0.03173957811668515, 0.1247198118695191, 0.09878822549113206, 0.12226974405348301, 0.030827691512448446, 0.11936520705265657, 0.04779772340719189, 0.05310475274122187, 0.014586482562923005, 0.07313792580472571, 0.06865111977926322, 0.08848523441702127, 0.1005856240434306, 0.1521491693066699, 0.14303880530808652, 0.017013851686247757, 0.054793728182890584, 0.022144404239952564, 0.12948912594999584, 0.0637474421943937, 0.0389677945391408, 0.01855669273728771, 0.013013524735080344, 0.03936036775953003, 0.018270406938557113, 0.04839798262608903, 0.03708957568077104, 0.010502627950959971, 0.10643264850867645, 0.015803460563932146, 0.037090060833309374, 0.04696074706901397, 0.02105782031347709, 0.013782910503713148, 0.006799719861841628, 0.05139674778495516, 0.04822669324598142, 0.010118113182085966, 0.026544498579044427, 0.07918956929019519, 0.04093463685629623, 0.05619254169453468, 0.052098285140735764, 0.007210508354806474, 0.032049906107464006, 0.00210367378063633, 0.03661441117791193, 0.055263060677264414, 0.012072585805851434, 0.04875917699454086, 0.015909059272546853, 0.033039556217512915, 0.0135390102430912, 0.022591546942879046, 0.042066226314221106, 0.04454598682267325, 0.04240398408312883, 0.05035354769123452, 0.05968016080026116, 0.053506872949323485, 0.005799194107696946, 0.010863471177539654, 0.020074460223051052, 0.023182193016899482, 0.030233020029429878, 0.020341653742694428, 0.039701250182198625, 0.031839539895632436, 0.0677481796592474, 0.04895407260794725, 0.02388693136163056, 0.008636464115365275, 0.012603220546485057, 0.0023574494823281255, 0.0936945445303406, 0.020357273618823717, 0.017361047877264873, 0.03444315340103848, 0.03771565654980285, 0.027522710285016468, 0.07048857225371258, 0.032856816558965614, 0.03492690137188349, 0.024296825884708335, 0.025694711499714425, 0.03690741956233978, 0.04148465734241264, 0.014865983011467116, 0.02901376723977072, 0.028613930302006856, 0.044459565210023096, 0.02509299343052719, 0.03369260885353599, 0.03356356845636453, 0.05043286843491452, 0.034581211528607776, 0.011486820943121399, 0.03722779665674482, 0.01095218284587775, 0.030333758730973517, 0.05474387960774558, 0.04383596099380936, 0.05308747384697199, 0.011299787006074829, 0.058644316026142666, 0.021190560422837734, 0.020500749848516922, 0.0268235393201134, 0.0290416889557881, 0.022806023380586078, 0.063668277513768, 0.032193202525377274, 0.015273794432037642, 0.12043140269815922, 0.04228086729667016, 0.10438641080898897, 0.04438356250258429, 0.05719267177794661, 0.030885862319597175, 0.021825652236917188, 0.023247792086164867, 0.03014843046133007, 0.018428956823689596, 0.03428129226501499, 0.07869296308074679, 0.05404076465804662, 0.02385679422877729, 0.023242021145831262, 0.0731585193425417, 0.05596228762130652, 0.03386513656005263, 0.07262772853885378, 0.046879170196396966, 0.02928292511829308, 0.04323741168315921, 0.06100071208285434, 0.0407828383945993, 0.03912312138293471, 0.02209221980800586, 0.007472336358789886, 0.0019184430504018174, 0.05038729802306209, 0.03798319272963064, 0.0408316352404654, 0.026193524644310986, 0.03774746287880199, 0.004254145697424454, 0.055361519501145394, 0.06290757868971143, 0.010005507751234939, 0.04553960636258125, 0.05545366794935294, 0.0441252102942339, 0.029055558211569275, 0.05714134060378585, 0.015028407331556082, 0.0727447419028197, 0.05576687632128596, 0.01174502048109259, 0.052300193413559876, 0.03224015375599265, 0.073719633876213, 0.07628263027540275, 0.047748641576617956, 0.03710900553103004, 0.042959643195250204, 0.05125191787789975, 0.040632739663124084, 0.02787298702501825, 0.06654781049915723, 0.04009263596630522, 0.07691121154597827, 0.011920511689303177, 0.06386327490742717, 0.05982725362160376, 0.12948335840233735, 0.06667791958898306, 0.11092215510351316, 0.07760991941073112, 0.09711707516440324, 0.1711236954267536, 0.13747769514364855, 0.05971207908753838, 0.03656213344740016, 0.07401903745319162, 0.08636490069329739, 0.10220012348145247, 0.04110041313937732, 0.08741650105054889, 0.09202573514942612, 0.05319661959739668, 0.05080203219716038, 0.09655771803643022, 0.07677101942577533, 0.08009550174964325, 0.08662377537361213, 0.02821817305604262, 0.05011987719418747, 0.08243637971047844, 0.09237798303365707, 0.06629331236971275, 0.05519196377801044, 0.03424655466473528, 0.03730966529941984, 0.05511815273868186, 0.03039195667952299, 0.016113931047064916, 0.01453907841018268, 0.07252057428870883, 0.02330262110834675, 0.08604135484035526, 0.026857084395097833, 0.019636486224564056, 0.07655821048787662, 0.012049077111961586, 0.043611138593405485, 0.01145918675631817, 0.025219272190172757, 0.02358683228625783, 0.03727875463664532, 0.03647854132577777, 0.045650750398635864, 0.05887799670121499, 0.030159046141696826, 0.02689845297884728, 0.07132286498589174, 0.05230692448094487, 0.024563183109941225, 0.015258966745542628, 0.062417913893503804, 0.06738248321094684, 0.01193547508280192, 0.031567776442638466, 0.0337002830845969, 0.06707387191376515, 0.09510918147861958, 0.022187991633212993, 0.10103632057351725, 0.036597644577601125, 0.01654993899033538, 0.03982518121067967, 0.04542064221043672, 0.046390282322785685, 0.02781248714641801, 0.032686602656862566, 0.014046866563148797, 0.03080210056422012, 0.030544199581657137, 0.010697520171691264, 0.01588936479363058, 0.041324020962097814, 0.03721842948081238, 0.04508963247228946, 0.04889735047306333, 0.04391003666179521, 0.04971854069403239, 0.04578699344503028, 0.031206225843301842, 0.06541315745562315, 0.040545955034238954, 0.027793664585000703, 0.014563992519729903, 0.021076234057545662, 0.03967752520527158, 0.059984843379684856, 0.026237006864643524, 0.036652585558061085, 0.03358544781804085, 0.039384214872760434, 0.03717039259416716, 0.009686643789921488, 0.01571836887991854, 0.03474249590986541, 0.02507215053109186, 0.02893909446096846, 0.00395519589073956, 0.17947285170001642, 0.11356283697698798, 0.1470885601426874, 0.08993623405694962, 0.1481805129774979, 0.18857149061347755, 0.16891511822385447, 0.09382184448518924, 0.10409274085291795, 0.08955983032605477, 0.10647151499454464, 0.09580984352422611, 0.13096134337995732, 0.2032953476799386, 0.07747751008719206, 0.14908436233443872, 0.13697271581207002, 0.10088661539235286, 0.18122828964676174, 0.08909818224076714, 0.13207589143088885, 0.1391794066876173, 0.10356931893953256, 0.10621525267405169, 0.18258483042674406, 0.08870502548026186, 0.144886049042855, 0.13724057429603168, 0.12429461468543325, 0.0745621979502695, 0.08091843580561024, 0.10399265015231711, 0.13586727370108875, 0.1418911718896457, 0.10406442558658974, 0.16902547515928745, 0.14721885243696825, 0.17378518118390016, 0.10918439977935382, 0.10633366382015602, 0.15719495926584515, 0.09912828688642808, 0.11476174050143786, 0.20130034615950926, 0.08724923538310186, 0.1251463796943426, 0.17360424303582736, 0.20331578515470028, 0.12631008082202502, 0.13477080182305404, 0.16894394239144667, 0.12328347537134375, 0.12104661682886736, 0.14122675039938518, 0.2026228787643569, 0.26370259267943247, 0.19369643846792833, 0.1596961071980851, 0.1686987198357071, 0.15188815045569623, 0.11668567226401397, 0.207042503037623, 0.16278044240815298, 0.10067618132701942, 0.12907365895807743, 0.2052647548594645, 0.21640435925551824, 0.11737213257168021, 0.17157627828419209, 0.14723186673862593, 0.18259937821754388, 0.18299619906714984, 0.1827559976705483, 0.1745177683021341, 0.20110125041433743, 0.31640535752688137, 0.15410064959100314, 0.2655197094593729, 0.20744760201445647, 0.1497002685708659, 0.2668707812471049, 0.21926551072725228, 0.1248020910258804, 0.22472652340573923, 0.11629879873778139, 0.16613298894039222, 0.213571000578148, 0.29835678743464605, 0.2769947408565453, 0.1941995993256569, 0.20004995539784431, 0.22016385037984165, 0.17849338640059742, 0.17663231412214891, 0.32563256525567597, 0.15771728195250034, 0.10818273281412465, 0.11941236523645264, 0.16102072969079018, 0.17759092125509465, 0.1857471971639565, 0.16088939245258058, 0.1538272678319897, 0.1292163955846003, 0.20792491068797453, 0.10572917732809271, 0.18540689828140394, 0.13046974475894654, 0.12273516479347434, 0.12466790394059249, 0.17792140852127755, 0.20799603472862924, 0.1954902136432273, 0.21415901902530873, 0.10539818794599601, 0.20857612788677216, 0.1360404629792486, 0.13036481610366277, 0.16179406962224416, 0.14223162004990236, 0.12744659983686038, 0.12150008178183011, 0.15640485951943056, 0.08459085053099052, 0.06780382631612675, 0.10848307955477919, 0.12662588459040436, 0.17694111540913582, 0.10794272140732833, 0.11858722594167505, 0.1396441896046911, 0.12190439365804195, 0.14727488585880824, 0.1250329286392246, 0.17963204958609172, 0.16449466613786562, 0.10153790723000254, 0.10320549524788346, 0.1309491161789213, 0.1637395652277129, 0.11368725315800735, 0.13182913538600716, 0.0905703521732773, 0.11891521619898932, 0.13474353828600474, 0.1022691847756505, 0.1101397703002606, 0.12331061677208968, 0.0983408402119364, 0.08090280235878058, 0.13029532054705278, 0.13371709122189454, 0.09487639646977186, 0.11892167585236685, 0.12699217136417115, 0.10312694803412471, 0.12868587619491986, 0.10064502299896308, 0.11621263836111341, 0.1444661444319146, 0.11294590615268264, 0.08754608766841036, 0.15424624963530473, 0.16773993628365652, 0.1129941228511078, 0.08037401323339768, 0.11173993229333844, 0.10991913785359689, 0.11302596649953298, 0.09266657754778862, 0.1561075390449592, 0.09096748514899186, 0.14676080058727944, 0.0595181334231581, 0.11938861651079995, 0.09046726913324424], [0.03324119646900466, 0.035317150609833856, 0.014518125248806817, 0.03809913740094219, 0.039782850803541284, 0.07187045631664139, 0.009919632359274795, 0.0325555062985846, 0.02459108786258314, 0.020900271267497113, 0.019358368291120445, 0.04869793242375765, 0.025858123088255525, 0.053721354476043155, 0.055649079249373505, 0.02862077672034502, 0.010140118072740734, 0.04055605502799153, 0.02695430998158242, 0.06372276387576546, 0.06394655151026589, 0.03094434186017939, 0.02744813759012946, 0.047502465679177215, 0.01679617425959025, 0.07298362694148507, 0.05016632970156414, 0.007200824811921588, 0.08357757383159228, 0.043183576714779646, 0.011700999673588999, 0.018201371089422276, 0.06539223822099821, 0.029810920357704163, 0.0195199444424361, 0.05235733284748026, 0.028322256935228194, 0.027638802537694573, 0.04762660366083894, 0.01921970966005964, 0.06819651488746915, 0.04203550224857671, 0.020349501000185097, 0.02857592555561236, 0.03327274156202163, 0.048257861752063036, 0.01632157463713416, 0.02163203226934586, 0.018801494601315687, 0.04695479631690042, 0.026281386447538222, 0.06851162655012948, 0.018593243722404753, 0.028522321289139133, 0.046625357387321334, 0.042040560727140734, 0.019380709056609442, 0.052909334655851126, 0.02736930369532534, 0.008447395421431532, 0.07952408705438886, 0.06531426776200533, 0.05263362891439881, 0.07740656246564218, 0.04361662794170635, 0.010493454157507845, 0.04643027517678482, 0.05415562706600342, 0.03161179640197328, 0.09046800195106439, 0.05868320965341159, 0.11303298255162579, 0.07094813045114279, 0.02404044142791203, 0.11421918390052659, 0.21256250755063125, 0.06757912265935115, 0.09416789734469992, 0.0376448446352567, 0.04634049481579235, 0.05296580573277814, 0.08297181169369391, 0.003881345411563026, 0.04671125992068222, 0.007727449410595, 0.058132510632276535, 0.13503791391849518, 0.05412133390616093, 0.09164310246706009, 0.09130510381822075, 0.04376632633752056, 0.03126148912789566, 0.053413574384259324, 0.08173202643437044, 0.12126890490097658, 0.17921609404895986, 0.03310802040089454, 0.07696010677942208, 0.026042482749159847, 0.07798582102571215, 0.02798159503644066, 0.03943275726799454, 0.08746490773877927, 0.037701546414090056, 0.07017697540244885, 0.05764047774885382, 0.06440522082682167, 0.0341437803581357, 0.04939856054261327, 0.06712296392236437, 0.05540949192696384, 0.029327789853726114, 0.04396402430055397, 0.006064788405118244, 0.0246945780236274, 0.045716639541621716, 0.018485482183418105, 0.01559530128724873, 0.06516926482852016, 0.07084167509206704, 0.08031544209058795, 0.039030246902257204, 0.020350686740130186, 0.04049033551876034, 0.02934949958164777, 0.03842703266335385, 0.034064371404903274, 0.032031049619295766, 0.03211154083588293, 0.06175365525164774, 0.03516592211755259, 0.047992306894489696, 0.009862672737134355, 0.08811032346316747, 0.02130374515296093, 0.06490132492035627, 0.042344985463257344, 0.04188221440251384, 0.055131119542888234, 0.025690088979899883, 0.0363887100746589, 0.03077408724597522, 0.0618591063788959, 0.01573358672404928, 0.03442764887586236, 0.04743568765531693, 0.02190113247239164, 0.04688458829852087, 0.008785080247824746, 0.013090091474753405, 0.010254129767417908, 0.027875227886917334, 0.012554266789395894, 0.046879821590014865, 0.04235644931239741, 0.011473665845447352, 0.030298573297581503, 0.013825923686714044, 0.006295463170057961, 0.05288939251165305, 0.07152387419981615, 0.017647727226306285, 0.029449583496898413, 0.052860374961580546, 0.043680037039199045, 0.023081639216148427, 0.03814550509144153, 0.03530132378052388, 0.02277512798484947, 0.011265939134838325, 0.010034772966589247, 0.0724846390741212, 0.006274941302503326, 0.09061767320547785, 0.03974253225273319, 0.017251898734165088, 0.0071247508583058205, 0.01489756372757256, 0.03935196749599917, 0.05208103678056172, 0.03811108979529568, 0.033793897168444734, 0.017500301922804544, 0.02674480720556208, 0.028065752038466077, 0.021421654183151465, 0.03532741005931582, 0.05585298241515245, 0.03950411879590579, 0.01696933470001178, 0.05455206793599895, 0.05162468466109463, 0.035950189855481894, 0.01806284986170275, 0.03635140082665852, 0.037451231453035555, 0.06085366675896304, 0.03457160347274371, 0.04673509007053716, 0.026222036685794592, 0.07248135496463094, 0.019791093821238195, 0.006865779062666531, 0.014723434678411909, 0.08027563922639404, 0.1122064319040094, 0.02491501539147326, 0.020622390821310024, 0.04491820399250303, 0.04145352276308196, 0.020362355846113393, 0.07113707531243563, 0.021751032044578875, 0.026608341938949058, 0.05299758831305163, 0.000572345030377619, 0.008861434097135705, 0.023192633974498937, 0.04370342953396695, 0.059184043136026175, 0.037151183267789226, 0.05815714145345347, 0.017840514292142222, 0.019792936043813825, 0.03220162993030889, 0.05447986502466457, 0.04076665872707963, 0.0681215435532587, 0.02707956754602492, 0.036957162964556894, 0.044297405518591404, 0.028392169790874635, 0.04635215883276292, 0.04014953452029398, 0.07970976137689181, 0.033241932679499896, 0.055875944040183506, 0.03619590434910996, 0.030568121333739588, 0.06782759539783001, 0.03611069392146809, 0.08359647781721183, 0.01627382273519678, 0.05768789377595697, 0.020050633465871215, 0.06599251101059572, 0.06897191756537982, 0.15731157229415008, 0.008613352364461337, 0.01743996998162142, 0.07218031611825738, 0.2440138134573187, 0.0815653782337904, 0.14229114114173821, 0.0848414810108287, 0.02225182142241725, 0.15766043428863796, 0.03871852112933993, 0.04130031634122133, 0.04923221089744142, 0.02126656991562673, 0.05066811313320484, 0.10357457080057689, 0.11399604087429387, 0.11640884354710579, 0.059495565348437855, 0.0750292811010565, 0.08442021932985101, 0.07646398232983691, 0.05003783891775778, 0.19223115566585744, 0.2001558340021542, 0.055162495002150536, 0.017355885922110507, 0.02606967673636973, 0.10772110508488757, 0.0769478999344366, 0.08332179327096258, 0.017025720960061465, 0.04448292377804007, 0.0349624939262867, 0.07606571620064122, 0.04597980595592942, 0.06801161409488746, 0.030506215191313198, 0.06412052788904735, 0.028630238891180073, 0.024104490044659803, 0.002134291613141873, 0.029044263996183872, 0.05315874716533082, 0.011305965067419623, 0.026494532956608703, 0.023796326580590436, 0.10117436852306128, 0.010850538300084216, 0.08507429316107716, 0.015614893985912204, 0.0724068246781826, 0.02367489934632821, 0.01910125440917909, 0.035144850212548456, 0.03527069131710699, 0.025164858770689795, 0.044436908925750425, 0.02223324652628175, 0.0538266088281359, 0.042808618263474534, 0.007718622518171157, 0.014939987433276005, 0.03526494412549904, 0.005433118103870324, 0.09426815767905541, 0.04232648859864899, 0.0734993474824088, 0.027767568128183484, 0.03400229223604713, 0.053146886373204846, 0.03475659586755293, 0.03708182681085808, 0.09505662894142525, 0.025449589027890136, 0.06612575493220772, 0.03448291555313127, 0.04984352345179234, 0.01205590826326183, 0.011530591540836861, 0.011023523169569671, 0.033957610705069134, 0.0205589732421296, 0.035037302412092686, 0.027864965044760277, 0.0521646322948592, 0.023769476949902515, 0.021871524596852914, 0.061780470955584726, 0.04224025358312896, 0.050979883010898314, 0.029694341256150177, 0.027999182664124028, 0.05045913791816149, 0.036778155248612165, 0.005791895191318223, 0.038411626525755437, 0.02761746261135808, 0.04234531455274139, 0.022603755484202077, 0.023831113374658992, 0.018339688756636212, 0.06755880732089281, 0.012476885807700455, 0.04267264323841248, 0.09844920903976474, 0.11074562064771142, 0.07588222676089831, 0.14939218653099878, 0.10591329102005277, 0.12267165391572885, 0.10673740572695221, 0.16681184965584958, 0.22432056947478227, 0.10936767208789076, 0.12752217506723745, 0.12213357564594064, 0.17188991074051174, 0.12154510936566762, 0.15044937123145374, 0.08933073654770851, 0.09428378434053489, 0.11661380183483873, 0.13138835903789314, 0.10686911615942206, 0.11839572978871209, 0.15226480524454797, 0.14214456400700978, 0.14630125596054963, 0.15977272737239087, 0.1256142703018018, 0.0845624470551099, 0.10478823924703257, 0.11486656059111867, 0.14622207092387335, 0.06273128850651638, 0.1235570606908628, 0.1347760943961995, 0.1371058172413281, 0.15081791074148246, 0.11565938804830823, 0.2226326593330928, 0.0851097669718521, 0.09623449788029705, 0.10773152738277401, 0.15607373443033012, 0.10431614172245775, 0.1431627193731921, 0.1562588523541178, 0.06865047517099551, 0.14355218490319593, 0.09891048393079213, 0.09742998158825295, 0.086133655958942, 0.14393555718873227, 0.20861314875738962, 0.12764258789164679, 0.07229675272745745, 0.1482655062739338, 0.157277876245124, 0.16211484026696, 0.14192442010555947, 0.12099317541079861, 0.19644310751131602, 0.14071508071252278, 0.21797805838286877, 0.28009977138468195, 0.08837289615933384, 0.22154149359890393, 0.19799601632569516, 0.14468053435640676, 0.1256697473249265, 0.14053673456822122, 0.16951957078916685, 0.2303623402757304, 0.22541961978588784, 0.2557426712342671, 0.13167734710233553, 0.1534175141049283, 0.23252010877643312, 0.3662322466926915, 0.218043306310262, 0.2641785985657147, 0.1365293338894844, 0.0983246232249907, 0.22369673794933728, 0.1252625041774341, 0.10658371075987816, 0.1243184855473893, 0.10428777217332806, 0.299906778548445, 0.27708414463060244, 0.20032976966883453, 0.23631941633565084, 0.128314893958824, 0.16263210108237608, 0.16468561946281365, 0.16951536387205124, 0.13946618272789887, 0.35897460899182726, 0.32149339307631764, 0.20757235746298516, 0.14849931587065968, 0.2161892093718052, 0.30269249049680574, 0.2578205625925745, 0.17478684814912931, 0.14735062393758977, 0.2907834138189043, 0.20166509944413388, 0.10563330032995769, 0.16269177145191602, 0.2868123011929648, 0.22973464110067912, 0.18850556415106567, 0.1309289229767663, 0.09185838127242667, 0.17019729156579289, 0.12987640659723962, 0.11516404391399451, 0.09789942604090486, 0.16497958797429288, 0.11020720989576407, 0.11885099964482443, 0.08104670606553555, 0.19080258160829544, 0.17615993161286625, 0.22173826875431196, 0.11903823459787027, 0.09573315549641848, 0.21511926821299962, 0.15026361548474856, 0.20057405584624835, 0.15107726039631025, 0.11183686780610255, 0.10037867764809302, 0.1765099742582866, 0.10750258966748204, 0.16584345804793493, 0.08514068102730171, 0.09293776763869183, 0.22147495645497525, 0.18637332213776453, 0.12643844607685292, 0.09574620372482709, 0.1292779387107917, 0.07642675111336367, 0.06746129505336285, 0.11146230969045844, 0.1880744637123176, 0.12942733855119773, 0.1347895429602691, 0.12093430571258068, 0.15253579856029578, 0.0855163587257266, 0.09571948980114289, 0.09517921307789427, 0.1040272011554667, 0.11327272932976484, 0.07204582369221108, 0.1059784439525434, 0.10610925193343844, 0.10731842169272048, 0.09245813837541, 0.1389429508043187, 0.20722160914114543, 0.10055140552244016, 0.11612387240997382, 0.18160047967519077, 0.16019685247114726, 0.16504252888262272, 0.1704574826040438, 0.16052107007375785, 0.1064492929726839, 0.1448277086019516, 0.07514514095549073, 0.17433801080499375, 0.14772149760808262, 0.31682034954428673, 0.09245361933218581, 0.10574089562786476], [0.06263341661542654, 0.02662357165744262, 0.01016850967425853, 0.03463635267689824, 0.03359477088919707, 0.0399007700117571, 0.03864039121461766, 0.047347851297152896, 0.03494369850627013, 0.04695418902805873, 0.022946252820215056, 0.049238514487764666, 0.04168435698375106, 0.06864675001374312, 0.10436859926474945, 0.01757521558153842, 0.07085559184529952, 0.026670609401272874, 0.007437949052213558, 0.03178981684946588, 0.030520057305693626, 0.06653248239308596, 0.04534404917753168, 0.03837728586846164, 0.03595571652320879, 0.011034451824213778, 0.022222625756902353, 0.03725974887077298, 0.05050164135172963, 0.017705682598586594, 0.016287283173629215, 0.05219687627894538, 0.021222288720309734, 0.02701383107341826, 0.020257420405479412, 0.04635992466605135, 0.04440045802454863, 0.06391753735286848, 0.027852595351370316, 0.015568124263414314, 0.11632558730031763, 0.010191436524369886, 0.04866737120651773, 0.09543191987488951, 0.07913059781172446, 0.009955526861761297, 0.0459122408314475, 0.03104667172634176, 0.04271964875182935, 0.0190682674292475, 0.05111750687605568, 0.0738121589113559, 0.029735419766179154, 0.0456023844225066, 0.016691138735041022, 0.0373504045419395, 0.043136859578745704, 0.02708540633986039, 0.020093783204044615, 0.02465000336191484, 0.07190426771662065, 0.08895730480019536, 0.01843867514149419, 0.04387333470263651, 0.09262824031923499, 0.047225667496344874, 0.02941289510844009, 0.08699093745755297, 0.04005567277116435, 0.1269826175911086, 0.019849534346056835, 0.01922764003809009, 0.010106427960896065, 0.19257703210626329, 0.38378049220357624, 0.5874543945704187, 0.25271759927272797, 0.2506389208137989, 0.1107171628890293, 0.04496276338717767, 0.09007217854793582, 0.3353706012879099, 0.4635590027485575, 0.4340446836182049, 0.5705035584313529, 0.11547429726592132, 0.10181804041245154, 0.1198897689048733, 0.07763687082167182, 0.09196403596018042, 0.08724896396909441, 0.01884678511747292, 0.1966782741780792, 0.1505528071096965, 0.4183591252991131, 0.5035297093646867, 0.20081372798553535, 0.14252766487853868, 0.01885655941441655, 0.07115831345851932, 0.11356153418975216, 0.018343748092385273, 0.04040454155100243, 0.039276402443647385, 0.0701573793111103, 0.06006107000367982, 0.043836530963225026, 0.05173085842813764, 0.02575421393183725, 0.054357226605394056, 0.04675091689984713, 0.038150000385940075, 0.10404787611748491, 0.019222724051879983, 0.021808829657467346, 0.041911869775503874, 0.02925564461786832, 0.03499857841857842, 0.06752526733492102, 0.02845399790177388, 0.05023885152435728, 0.04721128594662462, 0.01281771225123001, 0.009021097627867545, 0.06059742479452065, 0.04658153420314193, 0.05849515367299318, 0.03221361625141331, 0.01640413368919066, 0.03974150427217994, 0.015034069706286703, 0.015479651778670294, 0.042746413565639935, 0.022894714692873613, 0.0590724309108087, 0.0393150992957609, 0.01865061555456902, 0.04058387835643121, 0.037241133262536356, 0.008520827329318439, 0.0437668623801853, 0.05548455147072673, 0.04044801868232233, 0.02728118235245347, 0.007690170696670455, 0.04805489496460982, 0.048902056113417657, 0.04036255041137338, 0.1289360656269959, 0.015213002783379384, 0.011975964115533446, 0.03643124743497797, 0.03647072120968785, 0.020046974465783154, 0.019881905555459004, 0.008858430731509413, 0.06048506618078266, 0.027842958457767963, 0.0187706874151315, 0.08080081176012754, 0.08612476036484752, 0.025910948735794852, 0.01039896221897964, 0.023443420517391393, 0.02588503378709512, 0.030971781816333532, 0.06690739334693976, 0.010209807859999793, 0.02730166562832892, 0.017166153960196034, 0.007352108435173119, 0.0495385117828846, 0.0443299887701869, 0.04740976083225437, 0.035919024742075374, 0.015013835792030607, 0.040831150087927065, 0.013916760865998055, 0.08307984125401292, 0.016840119580073015, 0.015698516641610434, 0.018662718922964165, 0.01635164052381047, 0.0046468503839735475, 0.020298448025381992, 0.01063790578129036, 0.024022572208195925, 0.03574340970122388, 0.024953808934826936, 0.043800643246088705, 0.032354537796761305, 0.005695200134401343, 0.032983448156820874, 0.025604868374232734, 0.01231329355921064, 0.007287568728705602, 0.048489031847566366, 0.014253223481188928, 0.04188893868454865, 0.029958108173949376, 0.017301360544349467, 0.04404501424037984, 0.01621378934942186, 0.06281839883221046, 0.035824009483414035, 0.015683616012600914, 0.03801750624552369, 0.03565428073384932, 0.024116391548886895, 0.038673120351242166, 0.07178693544119596, 0.03915757399850658, 0.04919950211686747, 0.03747236781886645, 0.02526721408191536, 0.016161518404260278, 0.04524622478389314, 0.060300233241702826, 0.07876180724373885, 0.08817741700581141, 0.02594038867391646, 0.037701353031609736, 0.00757014294088419, 0.09422196980033602, 0.025579686243353144, 0.07973832770117692, 0.03148610118244376, 0.05400279044572796, 0.026755818132577196, 0.027934255344527106, 0.026057091608111347, 0.05149632279894181, 0.013967046248061317, 0.03135186999237963, 0.0258133279026619, 0.02447793197019824, 0.06058084818401507, 0.10676061162458998, 0.016707311617210507, 0.025619857212794677, 0.07327296784413712, 0.11306920275092125, 0.035819205455482006, 0.024137346406600306, 0.013057889899105897, 0.18624098066772732, 0.0852163919646825, 0.16498521981494768, 0.03841120922671897, 0.1757902114519051, 0.3358055150934628, 0.5498487896152905, 0.19938554747828416, 0.21024548688105174, 0.11487952060997486, 0.061609948320048194, 0.04810560527922852, 0.0873946590082986, 0.6667690585766519, 0.7097856274672917, 0.5133779123425484, 0.2885879730539662, 0.07151588105729648, 0.06362094969621726, 0.1484887578657695, 0.03505407240507858, 0.159377874274339, 0.024095782744032995, 0.15521115357322351, 0.055577690580061505, 0.2207015079579183, 0.22547128344220774, 0.12938881133283886, 0.1782763230481318, 0.08544944838753768, 0.09538993891328573, 0.10654742270708084, 0.1385958937129804, 0.018632564826735427, 0.16033686138689518, 0.09891268916960273, 0.08870725786047322, 0.05397207655810884, 0.11319773085415363, 0.04917432846767562, 0.07808439859322139, 0.04778993043250271, 0.01655960132900093, 0.06608930403100592, 0.06861540169588157, 0.044162356693829806, 0.023033503941925507, 0.04894705655585442, 0.12236491537519864, 0.05426606542563864, 0.05275868291833571, 0.024315290518903306, 0.04980400896498135, 0.022527477970080714, 0.005793507136071899, 0.04387806409171649, 0.04559837428054639, 0.02879041386768222, 0.04599832656926342, 0.03130703579102244, 0.016185245077524866, 0.023309806794194237, 0.02414972797435309, 0.016125693451613188, 0.02134718157217971, 0.028844679705798626, 0.025176675458039557, 0.018383474621389593, 0.02617474618766989, 0.018232990821291293, 0.0403025950571256, 0.01419896527659148, 0.02216507920197078, 0.030378307947622876, 0.028457332901390534, 0.02549304749949702, 0.03134265548682638, 0.03710037117291774, 0.046179332570838075, 0.04578730217846377, 0.08566371617572648, 0.02891687922445791, 0.04487907287797757, 0.030434304050036838, 0.0529325914436153, 0.05694589537701436, 0.008467341806473476, 0.0303499825032694, 0.04129533589418445, 0.03869928805423634, 0.06971125610704933, 0.01976663602649101, 0.03155267903847354, 0.01991813423644219, 0.030604925073151077, 0.025716319447383285, 0.03874653784025993, 0.05429096087547285, 0.024321129312738776, 0.0620626804551908, 0.02205240846212421, 0.012533636780322661, 0.04450432477252824, 0.04050495794841221, 0.09102431245680366, 0.03939133270510605, 0.014153645074527179, 0.11549902308200087, 0.21644238435796329, 0.19427176831024034, 0.08701971412769385, 0.2367505846279008, 0.06432818674615451, 0.11635673205767359, 0.08387734381748096, 0.1114538415734257, 0.09026811231992074, 0.0904056920803019, 0.09301875757851771, 0.07804460251437766, 0.194662319496274, 0.16223647445440292, 0.07788394577801228, 0.14339077499295982, 0.13136523456445762, 0.10023343722735133, 0.1124259719092931, 0.11820312083831855, 0.13629940551306519, 0.11097602399864367, 0.1380195596388408, 0.08237242778497082, 0.0981004216841289, 0.07525376084127597, 0.11858821660280228, 0.09886427569602217, 0.10999942890235356, 0.20410483995718615, 0.14894809893199376, 0.20280902806137288, 0.11555517864014421, 0.15018301909523352, 0.2130911270422595, 0.10317804172102894, 0.1586448528936931, 0.10500463763517992, 0.11596913928432123, 0.13994016657982553, 0.1494646540709904, 0.17321819732231752, 0.19975684184048856, 0.18504741042852402, 0.08723514899611473, 0.176425428794963, 0.20583903975784779, 0.21415581634002073, 0.16202606074512005, 0.16911008847611292, 0.1673448524836983, 0.12795016781560012, 0.15309345935072216, 0.25624874979257584, 0.08531904752765383, 0.14465746416577271, 0.1115423021838069, 0.15919652900525502, 0.06146040598728827, 0.19711576641670295, 0.23690246790647507, 0.18039789849093982, 0.16579165868461132, 0.13926737196743488, 0.17469923570752144, 0.2200814897992781, 0.15554514208010264, 0.12381166060056005, 0.32389318144747187, 0.15369336573140963, 0.22820850727813585, 0.17957408912479877, 0.4335185204233442, 0.6119822412729263, 0.9371919163635799, 0.2390709844018732, 0.286740702177797, 0.19347839802503586, 0.37435971200466156, 0.09993255444403205, 0.6917288878134319, 1.3427284125770842, 1.6442569983857018, 1.5229413424219405, 0.5646800994873047, 0.22382513034556592, 0.21171010471880436, 0.40921586592282566, 0.08831702558589832, 0.2912469618022442, 0.08443185620542083, 0.3018652748848711, 0.18028410816831247, 0.40366721366133007, 0.5043104588985443, 0.3485941088625363, 0.3283718925501619, 0.1326979316238846, 0.20305951604885714, 0.32980300432869364, 0.27615314030221527, 0.14739219099283218, 0.30716547476393835, 0.270198506968362, 0.12491280079952308, 0.24346930267555372, 0.15784530793981894, 0.14215183790240968, 0.28414598426648546, 0.24471954415951455, 0.08848372128392969, 0.24491851776838303, 0.15902133126343998, 0.149437458387443, 0.20962879354400293, 0.20369025506079197, 0.19573496122445377, 0.17233996944768087, 0.07036866833056722, 0.11302729642816953, 0.10502844064363412, 0.10054403663213764, 0.06812123142715011, 0.15992007803704056, 0.061154474903430255, 0.19370162247547082, 0.1602398580206292, 0.12310939042695931, 0.09968110293682132, 0.11520516313612461, 0.13513999272670063, 0.1821973326482943, 0.06884313840419054, 0.11318137816020421, 0.14741189564977372, 0.08675618469715118, 0.134788593011243, 0.14397901057132653, 0.12597998710615294, 0.09951925876417331, 0.111416847844209, 0.13628943104829105, 0.18924805788057192, 0.07293412102652447, 0.17796924524009228, 0.14515887440315314, 0.12184332550636359, 0.19918081989245756, 0.09998402132519654, 0.11846791234399591, 0.21612024307250977, 0.20736612352941716, 0.07229652202555112, 0.07894880470952817, 0.049956865941307375, 0.14178546970444067, 0.1224932534886258, 0.12920367983835085, 0.18980147104178155, 0.12921586632728577, 0.07812821838472571, 0.14376905826585634, 0.1517114056540387, 0.11479866637715272, 0.1030416086848293, 0.17792987663831028, 0.06873161438852549, 0.2399574496916362, 0.08372751650001321, 0.10672616918704339, 0.13455118717891829, 0.1686771831342152, 0.1540415763322796, 0.21762649581900664, 0.13094652417515004], [0.008645287615114024, 0.032397733336048465, 0.015386003768071532, 0.03257316856512001, 0.04210888920351863, 0.05148999885256801, 0.015974666823499968, 0.033503647028867684, 0.03345181034611804, 0.020502554751666527, 0.022414174496329257, 0.08130919733749968, 0.0365453464910388, 0.004636443353125027, 0.08331599858190332, 0.017721010704657862, 0.05727949033358267, 0.03817145227055464, 0.07193708845547267, 0.013645141601695545, 0.058528965072972436, 0.03326347955901708, 0.044523208402097225, 0.0031832471681160052, 0.003523477985124503, 0.004019436193630099, 0.013163253664970398, 0.0416100879332849, 0.08222488034516573, 0.038434164066399844, 0.04870993570823755, 0.10685651576412575, 0.0725407674908638, 0.09535065852105618, 0.019274413153263073, 0.06814004041786705, 0.015515763412362762, 0.01387827266340277, 0.03101914356063519, 0.026561840237783532, 0.026552381459623575, 0.025775107721398984, 0.0852695144712925, 0.05177143821492791, 0.04517364189294832, 0.020524032081344297, 0.027673546923324466, 0.05242175296215074, 0.005543793950762067, 0.03326144056128604, 0.02731294966568904, 0.04752352401348097, 0.035920520911791494, 0.03665171364056213, 0.1004929972280349, 0.03104768952886973, 0.0320857531124992, 0.06743344119084732, 0.0053268993838823265, 0.020396767749584148, 0.0561649151412504, 0.10419836839927094, 0.11566751689783164, 0.06627919205597468, 0.2113942602383239, 0.040680834225245883, 0.05082158757639783, 0.09092186723968812, 0.23670018304671558, 0.16920711898377963, 0.036530876731766124, 0.023332469863817096, 0.39131491790924755, 4.493615422930036, 10.925430842808314, 17.99537229537964, 20.773930856159755, 37.460212162562776, 48.299645151410786, 63.711819648742676, 64.9289355959211, 78.46042033604213, 91.5972821371896, 88.48023687090192, 80.00994505201066, 81.12055901118687, 61.00711522783552, 60.53646509987967, 72.24685478210449, 50.46431820733206, 54.54705538068499, 55.675623485020225, 41.718408720833914, 41.1432055745806, 40.91651017325265, 21.40000523839678, 13.369407585689, 4.071810696806226, 0.43226399059806553, 0.04961505053298814, 0.24150475380676134, 0.325978048145771, 0.07305548379995994, 0.028183082617553215, 0.08834928314068488, 0.1595572517918689, 0.07151613890060357, 0.05941404615129743, 0.029058991598763635, 0.07939428330532142, 0.030367393711847917, 0.06315214306648288, 0.06588948903871433, 0.1419177297502756, 0.03289639889927847, 0.048312097056103606, 0.05351015027346356, 0.01208454413738634, 0.04430702035980565, 0.03034690534695983, 0.027433316688984632, 0.05933186877518892, 0.021066112011404972, 0.013056951824442616, 0.06650271506181785, 0.03172426697398935, 0.0296067763119936, 0.06594405682491404, 0.05092836184693234, 0.02928508964500257, 0.0253478460945189, 0.03603107462237988, 0.019056521988074695, 0.062013079545327594, 0.029379178703363453, 0.029158393586320535, 0.04557292243199689, 0.015000762118558799, 0.05881715925144298, 0.02337262386988316, 0.03459366264619997, 0.06311173630612237, 0.04298265231773257, 0.02371432731992432, 0.08010460090424333, 0.02531644349385585, 0.02573370690723615, 0.0800120894398008, 0.033758148550987244, 0.01662517834587821, 0.031120048503258398, 0.04166397379179086, 0.03317867285971131, 0.04231338948011398, 0.02770095125639013, 0.060251181945204735, 0.030198791330414157, 0.024469061821166958, 0.03317284085122602, 0.008996815404056438, 0.02697917489734079, 0.007088646434047925, 0.04924430578414883, 0.054929506432797225, 0.039698987267911434, 0.0394175173714757, 0.07358981655644518, 0.04161783341052277, 0.04931723812062826, 0.06390353917543377, 0.009187649137207439, 0.07641949757401433, 0.04121941800362297, 0.01737554817061339, 0.010885135952516325, 0.09580142968999487, 0.06208693129675729, 0.055102817847260406, 0.057569075508841445, 0.0775417944948588, 0.01040334640336888, 0.05246527759092195, 0.030918387895716087, 0.009564967194039906, 0.011415969164642905, 0.004825204161794058, 0.013833216241826969, 0.01607017741272492, 0.017749794160148928, 0.010358764956306134, 0.03293354529887438, 0.010945316919657801, 0.03831663840849485, 0.0116404794389382, 0.009896210178599825, 0.0179129173713071, 0.039405073039233685, 0.02028778993657657, 0.05064135171206934, 0.07443351378398282, 0.05172591530052679, 0.005081309571063944, 0.016711074093888913, 0.025887912471911738, 0.02825560444034636, 0.05824452319315501, 0.02708426470469151, 0.0348674583115748, 0.04082416456991008, 0.027469550458980457, 0.03394476942984121, 0.012346916665722216, 0.018239414851580347, 0.06345755167837654, 0.054119505254285674, 0.015594285181058305, 0.05056150171107479, 0.04891700763255358, 0.034059153470609865, 0.07471480726131371, 0.018670739206884588, 0.051831288396247795, 0.020545319421216846, 0.013080616581386753, 0.031040819361805916, 0.06148522001292024, 0.06699795741587877, 0.06534299014934472, 0.07808222728116171, 0.05947902945003339, 0.053891422493117194, 0.038098255305417945, 0.03551415307447314, 0.04913037636184266, 0.08304486955915179, 0.1245271757777248, 0.035447914485952685, 0.11388918517955712, 0.05051119851746729, 0.0842914062419108, 0.203180675261787, 0.09872947792921748, 0.05834782336439405, 0.14440325780638627, 0.10856436126466308, 0.3150647080370358, 0.04861520882695913, 0.08224940260073968, 0.6951992958784103, 5.883860502924238, 14.277071612221853, 21.136599029813492, 26.572855710983276, 44.311358315604075, 61.00821999141148, 78.81479236057827, 80.09440735408238, 96.52797399248395, 110.50611673082624, 103.83030142102922, 101.17203875950405, 98.78691673278809, 80.15113244737897, 78.9866143635341, 92.74288027627128, 70.54446274893624, 70.0719644001552, 70.306535584586, 55.39079598018101, 54.95024197442191, 53.627843448093955, 28.788542440959386, 20.771141154425486, 7.332939454487391, 0.9885705879756382, 0.07344004352177892, 0.2440863081387111, 0.3220707449529852, 0.08913594949990511, 0.048930303526243994, 0.10855459036039454, 0.18744690024427005, 0.18856553307601384, 0.14789079209523542, 0.0262915882215436, 0.0686914451154215, 0.043547871988266706, 0.06083799260003226, 0.145482047061835, 0.18275487130241735, 0.06438029145023652, 0.041559472613568814, 0.04356967671109097, 0.06700299893106733, 0.04886600894055196, 0.06483269110321999, 0.059293110854923725, 0.053070442618003914, 0.026145735422947576, 0.03835607486377869, 0.06611700861581735, 0.03628652609352555, 0.041486798120396476, 0.07134059510592904, 0.04273816257981317, 0.0324182488423373, 0.021025881670149307, 0.057033453535820754, 0.016905357329440967, 0.04704676495332803, 0.03767143302996244, 0.05450388177164963, 0.03092477291024157, 0.010278115132158356, 0.09916292609913008, 0.028546684088983705, 0.04307077026792935, 0.04110722902363964, 0.03558428645400064, 0.03496595106220671, 0.028124275683824505, 0.02668796293437481, 0.039202262314834764, 0.06702269001730851, 0.07278763210134846, 0.0034698686296386378, 0.012362867327673095, 0.02970249724707433, 0.009614154197541731, 0.013510816264897585, 0.07419760751404933, 0.04156124358996749, 0.028118221455120614, 0.04684739779414875, 0.03496095704446946, 0.05343037491132106, 0.041832698309527974, 0.033885733490543704, 0.03469458794487374, 0.05187126767954656, 0.0527597414329648, 0.02341423842257687, 0.06192590815148183, 0.048211891004549604, 0.06217805176441159, 0.07087345088699035, 0.04028053588366934, 0.041524382175079415, 0.06436594043459211, 0.047168368606695106, 0.07332742027938366, 0.05572681900646005, 0.1535598300397396, 0.18077031922127518, 0.0839108159499509, 0.1602892010871853, 0.16823713960392134, 0.1863076128065586, 0.14380457278873238, 0.05350779914962394, 0.06485766119190625, 0.10826708150229283, 0.07962569767343146, 0.11605326405593328, 0.1045016192698053, 0.07243250044328825, 0.14400752261281013, 0.09514153402830873, 0.1337417084723711, 0.07604362310043403, 0.1523368385221277, 0.08440358843654394, 0.10114910666431699, 0.09311365070087568, 0.0958301860040852, 0.19520133414438792, 0.12343618646264076, 0.10955437099827187, 0.13240365098629678, 0.16578312271407672, 0.2065834469561066, 0.13535700179636478, 0.14947008235113962, 0.13157336839607783, 0.11570023585643087, 0.15052595069365843, 0.12044660188257694, 0.18585064661289963, 0.09860160800495318, 0.1179691483931882, 0.23296775189893587, 0.07421942920024906, 0.1488349192908832, 0.12014924069600445, 0.17880613676139287, 0.22553178162447043, 0.09028432252151625, 0.09351889895541327, 0.15666944746460232, 0.13576058085475648, 0.09875693824142218, 0.12983794723238262, 0.183063699730805, 0.13215986692479678, 0.14856123897646153, 0.13637061097792216, 0.15588048765701906, 0.10959129008863654, 0.11045293456741742, 0.1302158912377698, 0.1904205121099949, 0.1774994275931801, 0.14434961282781192, 0.25401835090347696, 0.21844275987574033, 0.1343263206737382, 0.33823483330862864, 0.1841014376176255, 0.19201417373759405, 0.23942547823701585, 0.2549560048750469, 0.3970751645309584, 0.11682323845369474, 0.1384583953768015, 1.3181746729782648, 8.247312835284642, 20.202676023755753, 27.99940947123936, 35.27576105935233, 58.132749693734304, 75.99201720101493, 97.62153012411935, 101.45522648947579, 116.13305282592773, 128.2796573638916, 125.51563617161342, 115.8470858165196, 118.08790070669991, 96.32047993796212, 95.21108191353935, 109.03472450801304, 87.13860920497349, 84.89677987779889, 81.6572517667498, 64.89886379241943, 66.10230568477085, 61.71324675423758, 34.742924554007395, 23.62758728436061, 8.361077427864075, 1.1188982746430804, 0.1871986107102462, 0.5014164799026081, 0.536766417324543, 0.264058063605002, 0.15065537446311542, 0.1464587575090783, 0.25243256028209415, 0.30958374642900055, 0.17765136515455587, 0.15487496661288397, 0.20017298736742564, 0.11297057090061051, 0.1193455159664154, 0.2583944946527481, 0.29453259121094433, 0.17678038403391838, 0.151253611647657, 0.14526294810431345, 0.12850242746727808, 0.10558110741632325, 0.1493310776672193, 0.17486395686864853, 0.14451555535197258, 0.0967598400477852, 0.1253661843282836, 0.21209997736981936, 0.12209742330014706, 0.10516401194036007, 0.22273822581129415, 0.19242820223527296, 0.102016613685659, 0.08455051162413188, 0.11227744059371096, 0.07096661374505077, 0.1779682274375643, 0.0858976479087557, 0.1205393983317273, 0.21149195571030888, 0.06762247426169259, 0.205592935106584, 0.16608884345207894, 0.11349522096237966, 0.14997172329042638, 0.14565458494637692, 0.1677529098732131, 0.14765098424894468, 0.1336194228913103, 0.10958198737353086, 0.24369487485715322, 0.1295222384589059, 0.10609921640051262, 0.12401831522583961, 0.1644066194338458, 0.09860491925584418, 0.13598205468484334, 0.14740163620029176, 0.04760072433522769, 0.1532979290932417, 0.22169887301112923, 0.07440637916858707, 0.10033121412353856, 0.12496466801634856, 0.08361289157931294, 0.19346991633730276, 0.12663816607424191, 0.16838352674884455, 0.07916519631232534, 0.20751183213932173, 0.13038139949951852, 0.13265803376478807, 0.2620348350277969, 0.10652416931199175, 0.18802434711584023, 0.15573190205863544, 0.1244939954153129, 0.22100617018129143, 0.1795720535197428], [0.04092387868357556, 0.016014464598681246, 0.04792319131749017, 0.0123835236299783, 0.022223750428695763, 0.02727192034944892, 0.01808487341207053, 0.02486937034076878, 0.08372560303126063, 0.04606587133769478, 0.026319679571315646, 0.03182712609746626, 0.06854747355516468, 0.04162739057626043, 0.02790501218156091, 0.027911178368542875, 0.030194370674767664, 0.004447710109941129, 0.020781105251184533, 0.04080755063997848, 0.06340715009719133, 0.034061589411326816, 0.06069199900541987, 0.034050702316952605, 0.044970074602003605, 0.06200766483587878, 0.030524725626621927, 0.03995881528992738, 0.036460946912744215, 0.05476973518463118, 0.04988838140187519, 0.0410396774698581, 0.0678690674581698, 0.024984326047290648, 0.023689815242375647, 0.026931589236482978, 0.02946837552423988, 0.02798857376910746, 0.0526310708373785, 0.01736361443597291, 0.022748319066262672, 0.04544636208031859, 0.008292854830090488, 0.029384678229689598, 0.004065713130070695, 0.014101860978241478, 0.07578984421810933, 0.024235628811376433, 0.023119404778948853, 0.02843396076267319, 0.0816470602793353, 0.03081743206296648, 0.04872626465346132, 0.07246082249496665, 0.10734423316482987, 0.044764760083385875, 0.04379085198576961, 0.03910328441166452, 0.04206511012411543, 0.035553460608103445, 0.01978439498426659, 0.09772654888885361, 0.019600383072559322, 0.3919039134468351, 0.5947378437433923, 0.22778567139591488, 0.5195555665663311, 2.5133288843291144, 4.912898821490152, 19.298123053142003, 44.97084658486502, 48.50719826562064, 64.75279876164028, 88.8712467466082, 96.80488749912807, 101.74364621298653, 105.0553730555943, 96.65318747929165, 92.93964631216866, 87.7900584084647, 101.38785675593785, 94.36181054796491, 97.3755430494036, 88.62946333203996, 92.67839404514858, 92.48395565577916, 102.28892694200788, 102.36875479561942, 104.95562471662248, 105.94397122519356, 111.62299796513149, 103.53561442238944, 117.58628245762416, 122.23860168457031, 117.81914438520158, 125.52080563136509, 116.94304602486747, 109.62588419233049, 69.9061039515904, 37.351059436798096, 18.209204844066075, 8.280861343656268, 2.2563914486340115, 0.5331774556211063, 0.17776548117399216, 0.3423073733491557, 0.2594918757677078, 0.10176290944218636, 0.050028241039919, 0.09976173325308732, 0.1070723170414567, 0.017534179479948113, 0.08458832638072115, 0.05784753270979438, 0.007487620360084942, 0.1244621178401368, 0.038670273896838935, 0.028786033924136843, 0.02227961421678109, 0.05967961797224624, 0.04133518625582967, 0.03950077361826386, 0.019913279318383763, 0.0350489426803376, 0.010842370434797235, 0.07962683761226279, 0.01750281759138618, 0.08802728434758526, 0.07952033475573574, 0.05036604630627802, 0.04637101532093116, 0.03537484983514462, 0.011961366282775998, 0.020526859876034514, 0.05507111329851406, 0.0360093750724835, 0.051287832736436806, 0.03323724400252104, 0.0460026081252311, 0.05732356118304389, 0.026376730795683603, 0.00875975816909756, 0.010168283213196056, 0.07806890763874565, 0.025457083447171108, 0.031405355515224595, 0.06371704382555825, 0.059745700497712405, 0.04171323882681983, 0.03422448531325374, 0.02966849585728986, 0.033789133852613826, 0.10344744047948293, 0.04523827235347458, 0.051328934995191436, 0.0400451045882489, 0.013282172864169946, 0.015350294166377612, 0.04363672275628362, 0.04186226547296558, 0.015137378359213471, 0.0338392979465425, 0.027532477796609913, 0.08747752849012613, 0.040538307944578786, 0.004010697934843067, 0.025312214524352124, 0.02296983021577554, 0.026304387088332857, 0.046932835531021865, 0.05230550973543099, 0.04663694337276476, 0.02855548808085067, 0.04999137623235583, 0.055692983857755146, 0.019160899333655834, 0.021156513231939504, 0.06362382668469634, 0.0065315628224717715, 0.016076333421681608, 0.019100251873689036, 0.011919827217103114, 0.06848346056150538, 0.004338281495230538, 0.04160930422533836, 0.0367941551043519, 0.01000795726265226, 0.017549831586490785, 0.027441749182928885, 0.03917821503377386, 0.03481159113081438, 0.006538525864016265, 0.06642187439969607, 0.030165383658771003, 0.0055874352027396, 0.05509364405380828, 0.00524820077199755, 0.055184845945664814, 0.04179572493636182, 0.04124388936907053, 0.019134382185127054, 0.026674149657732675, 0.029664797841438224, 0.05347597585724933, 0.026213666956339563, 0.032861345780215094, 0.06331723063652005, 0.12405545823276043, 0.027261665988979594, 0.020230333287534968, 0.006772207811341754, 0.07148272783628531, 0.055555746757558415, 0.04260539024003914, 0.03566851979121566, 0.011410502716898918, 0.04055241808029158, 0.018936305938820754, 0.022483033926359246, 0.07609192800841161, 0.017880580088655864, 0.04797523834609559, 0.0493812748630132, 0.019005799799093177, 0.012236611468584409, 0.032863591731126816, 0.031852126720228364, 0.05829265846737793, 0.02913837001792022, 0.04967351650286998, 0.07139242839600358, 0.052748484537005424, 0.04315341244052563, 0.016474582587501833, 0.06669721712491342, 0.04602649934323771, 0.07730774062552623, 0.20729932854218142, 0.003563240561301687, 0.3459649213722774, 0.41788930765220095, 0.10819815591509853, 1.2178605986492974, 3.5704671187060217, 7.79928343636649, 26.46297516141619, 54.802498953683035, 60.60484232221331, 79.10173211778913, 109.4564037322998, 118.77313205174038, 123.51670891898019, 127.33539717538017, 120.20358548845563, 111.24186842782157, 108.62253652300153, 119.13385472978864, 115.46908991677421, 117.83299909319196, 106.04829147883824, 111.18504605974469, 114.998717716762, 121.53137234279087, 122.16927255902971, 123.19314520699638, 125.36145564488002, 141.84468105861117, 126.68109921046666, 135.90609741210938, 147.14435005187988, 141.7299940926688, 146.41064807346888, 146.93715476989746, 136.51892852783203, 95.90371309007917, 57.701933588300435, 31.949700083051408, 13.94789809840066, 3.976947375706264, 1.0402126397405351, 0.17068229482642241, 0.3828396355467183, 0.32890402685318676, 0.2425631055874484, 0.01502168644219637, 0.14843477361968585, 0.16718569530972413, 0.06389743236026593, 0.07547411508858204, 0.05907088385096618, 0.025391682849398682, 0.05662366248933332, 0.0557630392057555, 0.040547709047262154, 0.029155954252928495, 0.027934674339901124, 0.050368336361965964, 0.04700374583314572, 0.10218892765364476, 0.037021766283682415, 0.030636829789727926, 0.055184455788029094, 0.009508955824588026, 0.061731399303036075, 0.06985197069921664, 0.05326623050495982, 0.04209832102060318, 0.05605852424300142, 0.040690642448940446, 0.05950260175658124, 0.026035999347056662, 0.11144687301878418, 0.02510188054293394, 0.057425904619906626, 0.029268207693738595, 0.0426563176858638, 0.022443580507699932, 0.042129136688475094, 0.011222217730911714, 0.009562898510401803, 0.022673568255933266, 0.02533043658227793, 0.006784780217068536, 0.05402436446664589, 0.0458691165383373, 0.037748497644705434, 0.0526162109204701, 0.0843822213688067, 0.02021160232834518, 0.017700680099161606, 0.030566279111163955, 0.03935705650863903, 0.0318864470214716, 0.02485455452863659, 0.006177080861691917, 0.05028788585747991, 0.02981000772810408, 0.013634381732637329, 0.015677186893299222, 0.02630857364939792, 0.08317982338901077, 0.007863517734222114, 0.008683700330688484, 0.03445079709802355, 0.007189643402983035, 0.05458284967711993, 0.021422046037124734, 0.028467532979058366, 0.04575698523383055, 0.017775824459801828, 0.03676647426826613, 0.030901807892535414, 0.12879684381186962, 0.16578108710902079, 0.19316639405276093, 0.1612209246626922, 0.09660575153040034, 0.12351761066487857, 0.16118276385324343, 0.1648836974054575, 0.1483545164976801, 0.06663418800703116, 0.07157718669623137, 0.12704414714659962, 0.1015065046293395, 0.13319419856582368, 0.11899597543690886, 0.13983668998948165, 0.1771765670606068, 0.12989004515111446, 0.10709546187094279, 0.1235290914773941, 0.14792774511235102, 0.1449429238481181, 0.09892851260623761, 0.0983999813241618, 0.12655394630772726, 0.1693035659513303, 0.14541318932814257, 0.10164358227380685, 0.15354404731520585, 0.15431999282113143, 0.09795620585126535, 0.19079232215881348, 0.18815382516809873, 0.14984645215528353, 0.16923211621386663, 0.11389217073363916, 0.11946800510798182, 0.17019916432244436, 0.15762097069195338, 0.06644753659410135, 0.11186514236032963, 0.1615455900984151, 0.1730760442359107, 0.10775008531553404, 0.11672231315502099, 0.15000527006174835, 0.1432322556419032, 0.13436490217489855, 0.11858679167926311, 0.17065652406641416, 0.23109206397618565, 0.19350735789963178, 0.12533296325377055, 0.13394275839839662, 0.29798899431313786, 0.1735354938677379, 0.1639083575989519, 0.20963210479489394, 0.34541072111044613, 0.13002041886959756, 0.14556138137621538, 0.3717395354594503, 0.10160897698785577, 0.4984925910830498, 0.7735590168407985, 0.18089641816914082, 2.1049450380461554, 5.115379316466195, 10.954297133854457, 34.0066864831107, 65.01392596108573, 72.03509453364781, 95.6867903300694, 125.04007366725376, 134.14472906930106, 135.05164963858468, 140.69166919163294, 132.02619552612305, 123.98997851780483, 118.15168516976493, 129.60151045663017, 120.16855267116001, 121.79102652413505, 116.26536042349679, 120.09034374782017, 118.58819879804338, 132.0777372632708, 138.31120245797294, 137.40557425362724, 141.10760225568498, 148.94101524353027, 138.25187873840332, 152.09378814697266, 159.97479629516602, 154.26875495910645, 160.4480242047991, 161.6089153289795, 151.10268320356096, 105.10106440952846, 64.32754816327775, 34.94894559042794, 13.82639581816537, 4.129760410104479, 1.2318670813526427, 0.3030917133603777, 0.44411987013050486, 0.7114888046469007, 0.4596458641546113, 0.22882285288402013, 0.32694061792322565, 0.2420437006013734, 0.24287791869470052, 0.31920659435646875, 0.4603666311928204, 0.08712779118546418, 0.22741605980055674, 0.11682975238987378, 0.11870621384254523, 0.1419876188571964, 0.10362115901495729, 0.1091570005353008, 0.16487232515854494, 0.19884107740862028, 0.1495350588645254, 0.15978257970086165, 0.22572927602699824, 0.07298348444913115, 0.20234518152262482, 0.15836657211184502, 0.19259349336581572, 0.1855411667908941, 0.11760725852634225, 0.07110738940536976, 0.11912178940006665, 0.07710468902119569, 0.23891391711575644, 0.1440726484039, 0.16062183252402715, 0.07732380833476782, 0.10586453149361269, 0.10335460331823144, 0.1876427118799516, 0.03598031681030989, 0.14307384485644953, 0.1278472069118704, 0.14704943581351212, 0.12273147356297288, 0.13988371246627399, 0.23134865877883776, 0.24164583480783872, 0.1392546155090843, 0.17457479238510132, 0.13946298004261085, 0.17636436064328465, 0.07781494555196591, 0.2506755617048059, 0.06881382569138493, 0.1631125852997814, 0.07185402898383991, 0.10264842478292328, 0.14011512004903384, 0.11854701595646994, 0.10461317721222128, 0.1625328856919493, 0.1233809944242239, 0.04361683489488704, 0.08577720115759543, 0.08073076659015246, 0.07006442001355545, 0.11439784217093672, 0.18655462669474737, 0.0939672477543354, 0.1978274139442614, 0.06427240438227143, 0.12686470177556786, 0.11949198453554086], [0.015475473699292966, 0.02337337195474122, 0.06938040243195635, 0.026736802188679576, 0.007598305536833192, 0.06790982027138982, 0.0370048063008913, 0.045590496488979886, 0.05807682326329606, 0.055999359382050376, 0.02917988957571132, 0.06896587181836367, 0.01679239481953638, 0.03392214367964438, 0.058115974733872075, 0.050702565748776705, 0.037353227247617075, 0.02412395551800728, 0.038107293391866345, 0.004575798013580165, 0.031696633635354896, 0.06404063717595168, 0.042468628114355464, 0.038482119528842826, 0.05456174723803997, 0.01862970649796937, 0.016847549538527216, 0.0654692112335137, 0.0038150215820808497, 0.01231098229930337, 0.08205735683441162, 0.048011197309408865, 0.0337623860021787, 0.031190185275460993, 0.05791738788996424, 0.034730926887797456, 0.03286388689385993, 0.024056493870115707, 0.09895799495279789, 0.03210911846586636, 0.02525565354153514, 0.014042416221595235, 0.030054616209651743, 0.07282167420323406, 0.028567518506731306, 0.03102899928178106, 0.04739815788343549, 0.03133730523820434, 0.023183690882953148, 0.023120385262050798, 0.027814744971692562, 0.010707678689089204, 0.04652260682944741, 0.05017618542271001, 0.04626164226127522, 0.02118956297636032, 0.09704597826514925, 0.0164968385361135, 0.2547025584748813, 0.051901387849024365, 0.20359945350459643, 0.46873280512435095, 0.0988989488354751, 5.210653015545436, 15.730084112712316, 30.66487741470337, 60.861022404261995, 77.63736452375139, 88.47969491141183, 90.8151581627982, 97.86001314435686, 91.68915121895927, 85.55844293321881, 66.73431382860456, 82.49475288391113, 73.06107248578752, 58.84995664869036, 72.78218569074357, 73.2616878237043, 59.00046157836914, 69.54996013641357, 98.3331298828125, 68.71723937988281, 64.01603957584926, 61.23197283063616, 77.82311766488212, 64.44963496071952, 69.3443351473127, 82.36140305655343, 71.50282083238874, 55.34599052156721, 67.1144358771188, 72.91420146397182, 79.15551812308175, 73.49382019042969, 81.96405642373222, 80.44399206978935, 89.28624875204903, 101.31764520917619, 114.52942248753139, 113.00280598231724, 105.703535761152, 86.93756307874406, 77.45268140520368, 65.55947766985211, 40.15508835656302, 15.059985944202968, 3.2011686265468597, 0.13414118917925016, 0.3702844849654606, 0.4157542293625218, 0.04591852067304509, 0.06319508754781314, 0.1318678254527705, 0.02667110982084913, 0.07181142377001898, 0.03603395161085895, 0.021991923850561892, 0.022254776442423463, 0.10449849122336932, 0.024416904530621, 0.08422542549669743, 0.022521179468770112, 0.06866344197520188, 0.0025231888700675753, 0.010528162071880485, 0.025607436629278318, 0.018715361366048455, 0.0316798602496939, 0.05711913215262549, 0.03217142155127866, 0.06182620421584163, 0.013327485432715287, 0.02249877424245434, 0.015203552486907159, 0.03572397645828979, 0.046024005727044175, 0.007068524902154292, 0.04170546281550612, 0.02268471149727702, 0.008297803046713983, 0.05095460758145366, 0.016162208813641752, 0.056281677447259426, 0.02513106263774846, 0.048609716085983176, 0.032702310742544274, 0.1256078513605254, 0.01327185658738017, 0.03954798608486142, 0.014534189565373319, 0.014854415685736706, 0.029034391311662536, 0.02703174270157303, 0.022596529086253474, 0.06294139008969069, 0.009851241966576448, 0.05666524650795119, 0.02688362359601472, 0.07581752844687019, 0.04215750963027988, 0.020660500740632415, 0.0038027714804879254, 0.026984038297086954, 0.03027179491307054, 0.036679119669965336, 0.03814408356057746, 0.04011806406612907, 0.05480332945340446, 0.01770958417494382, 0.08828888673867498, 0.060698987916111946, 0.03072760420452271, 0.043060761876404285, 0.043056103733501265, 0.03792714234441519, 0.033602462083633454, 0.035103710634367805, 0.023125859343313744, 0.04424460531611528, 0.007956281952959086, 0.030732265740100826, 0.03662984445691109, 0.037868978322616646, 0.02156307784441326, 0.018103485627632056, 0.03895503808079021, 0.026965130918792317, 0.023953192002539123, 0.06713486542659146, 0.016321028416444148, 0.035934305350695334, 0.13391659408807755, 0.07075676321983337, 0.028558955394795964, 0.05109206520553146, 0.02989364056182759, 0.07692537935716764, 0.054437989235988686, 0.049073637263583283, 0.03621392284653016, 0.032729251975459714, 0.09666992058711392, 0.0036050077843745904, 0.024330683085801344, 0.012093935910213207, 0.01932223460503987, 0.021010053144501786, 0.07481711677142552, 0.01691021733651204, 0.14079803840390273, 0.1038248280861548, 0.029883024881460836, 0.06325017102062702, 0.030471270637852804, 0.01909373284849737, 0.04546728470761861, 0.020119492895901203, 0.04647748764338238, 0.032646148399050744, 0.07519009390047618, 0.05314405009682689, 0.06569593692464487, 0.043063733859785965, 0.006011237997362124, 0.019775816605293324, 0.007292519489835415, 0.011140459350177219, 0.02550774796067604, 0.027009546124775494, 0.025245397484728267, 0.02066045324318111, 0.0859183839389256, 0.02165893279016018, 0.13897014648786613, 0.015498398004898002, 0.2263150553085974, 0.2823129897671086, 0.1375021224043199, 7.793417419706072, 20.415676525660924, 39.929636682782856, 75.80582632337297, 94.08887835911342, 104.63195678165981, 112.084073475429, 118.17548969813755, 117.67678969247001, 111.4673513684954, 86.60049901689801, 107.78616796221051, 99.29516356331962, 93.98511396135602, 96.63353102547782, 99.34598268781389, 88.11979212079729, 101.0936700275966, 124.8516663142613, 106.52209608895438, 85.03329808371407, 99.55048206874302, 106.60288279397147, 99.91966765267509, 107.03262192862374, 118.02729851858956, 96.30660438537598, 88.53074332645961, 96.60661370413644, 107.90689986092704, 104.80113846915108, 101.50271742684501, 107.3631477355957, 101.54936763218471, 106.07005323682512, 119.18734196254185, 129.27766881670271, 136.67260878426688, 127.79664639064244, 112.79084423610142, 101.45428848266602, 86.87584917885917, 53.1862576348441, 24.6994719845908, 6.307040972369058, 0.13777399781559194, 0.2338121480175427, 0.45133497725640026, 0.06548763345927, 0.166250470493521, 0.26614990564329283, 0.06735109418098416, 0.11283471461917673, 0.03079005317496402, 0.0662855092169983, 0.0395186733720558, 0.05074156794164862, 0.003606592587727521, 0.08702247576521975, 0.025936168186100464, 0.08857673486428601, 0.020865633751132658, 0.013935971040544766, 0.010962762054987252, 0.008526895976891475, 0.04612484620884061, 0.07922353675322873, 0.012647361793954457, 0.02124645813767399, 0.057660501317254136, 0.06602609170866863, 0.03864914770903332, 0.012230457155965269, 0.06300386959420783, 0.05241242649831942, 0.05536186894668, 0.036118883839143176, 0.020192618614860942, 0.035890628051544936, 0.03601597382553986, 0.0632303510127323, 0.0210077613924763, 0.02521500420490546, 0.017180094462154166, 0.06223707752568381, 0.0234678901865014, 0.03172923045765076, 0.003146814290500645, 0.032948557886161974, 0.014331797836348414, 0.0629294818001134, 0.016648886359429786, 0.024633978061111908, 0.032889874785074165, 0.05220363448773112, 0.08207434735127858, 0.052712993762855015, 0.003452394868613088, 0.022137900481798818, 0.0044736644984888175, 0.004519259931320059, 0.028921374518956457, 0.02984342897044761, 0.044912419481469054, 0.07865539259676423, 0.014695121108421257, 0.03520240694550531, 0.021724184110228504, 0.06984122948987143, 0.043000077097011466, 0.05860036052763462, 0.0043986791694935945, 0.020938745899392024, 0.08863234759441443, 0.08354562161756413, 0.12199576518365315, 0.08562261052429676, 0.10923393962106534, 0.20722015707620553, 0.13186558628720896, 0.10082824781004872, 0.22914447848285946, 0.12383862558220114, 0.1772990154900721, 0.18922821751662663, 0.1288587533469711, 0.15286122395523957, 0.17862344799297197, 0.09881869171346937, 0.25673574794616016, 0.11765555664896965, 0.11395409383944102, 0.10822589442666088, 0.14973765585039342, 0.12851477680461748, 0.13642935853983673, 0.10289214777627162, 0.24212737753987312, 0.1723185141703912, 0.1639469526708126, 0.174357267628823, 0.13958206293838366, 0.12733236168112072, 0.08897718587624175, 0.10029599815607071, 0.16549505745725973, 0.11605882804308619, 0.20604117533990315, 0.23724159970879555, 0.08006826535399471, 0.18949215406818049, 0.2416326440870762, 0.14633401563124998, 0.19839350213961943, 0.0849281842155116, 0.1271165061209883, 0.16991677161838326, 0.13349246898932116, 0.0867316760122776, 0.12232740595936775, 0.14387132706386702, 0.0705055288438286, 0.12319954058953694, 0.14459915086627007, 0.05983915512583085, 0.13081062718161515, 0.1016438536878143, 0.14146582542785577, 0.1185708325356245, 0.2030354823384966, 0.12103611310677868, 0.45715401215212687, 0.14473630993493966, 0.31010374852589195, 0.43321833653109415, 0.5623884424567223, 11.01813110283443, 25.477583374295914, 48.40737349646432, 89.9133653640747, 108.5762128829956, 123.31158420017788, 124.17596789768764, 128.3095485142299, 123.19443757193429, 113.9584264755249, 91.40262835366386, 110.79073578970772, 97.26113401140485, 80.49922330038888, 95.64030688149589, 100.66705063411167, 84.08488287244523, 98.47053745814732, 128.17257172720772, 97.70705550057548, 93.51333822522844, 92.2571942465646, 106.75024018968854, 94.63302653176444, 96.86290495736259, 113.84843649183, 99.85271481105259, 81.09626810891288, 93.15009335109166, 100.78939451490129, 102.47855717795235, 99.88476685115269, 105.72436646052769, 101.42189598083496, 113.02451910291398, 131.76502663748605, 145.29221044267928, 148.5700648171561, 144.18119348798479, 122.05126435416085, 111.4845620564052, 97.16037123543876, 59.943144525800435, 30.134941782270158, 7.548529028892517, 0.21945797039994172, 0.44168504221098764, 0.7996955886483192, 0.15938171478254454, 0.26078839333994047, 0.31532132998108864, 0.14956636647028582, 0.19130460252719267, 0.16662838735750743, 0.09236783214977809, 0.10773008888853447, 0.2887854810271944, 0.09938738548329898, 0.2035992092319897, 0.08780776469835214, 0.26113355053322657, 0.08779069275728293, 0.08926286268979311, 0.10419510464583125, 0.13924731447228364, 0.0834324759032045, 0.1672377118042537, 0.20748209873480455, 0.20210004039108753, 0.12740427282239708, 0.13687279474522385, 0.13581909771476472, 0.14365885060812744, 0.14796525452818188, 0.12600463149803026, 0.12114739284983703, 0.12660015454249723, 0.09032242904816355, 0.12233516839998108, 0.12858945636876992, 0.22554945067635604, 0.15195760530020508, 0.15703692846000195, 0.09511513223073312, 0.1620465117905821, 0.1343531228069748, 0.1710518385682787, 0.1143208420170205, 0.22165806591510773, 0.10620397542204175, 0.19017379677721433, 0.10451299830206803, 0.11834093130060605, 0.17082727061850683, 0.20532692223787308, 0.1475041357002088, 0.1394905557057687, 0.1596762261220387, 0.11722098211092608, 0.18965165050966398, 0.14141888437526567, 0.08980810628937823, 0.09867344450737749, 0.13670868426561356, 0.16968418338469096, 0.1419386693409511, 0.1118478804294552, 0.15408300768051827, 0.24143372476100922, 0.05013042841372745, 0.12333417550793715, 0.09139823274953024, 0.17265179700085095], [0.04169556977493422, 0.03199076160256352, 0.04215305844055755, 0.0053348149189592475, 0.03207601952765669, 0.007515915270362581, 0.021363544444154416, 0.024634417412536483, 0.03815996128001383, 0.022937742294743657, 0.04207058929439102, 0.024893093621358275, 0.05317448578508837, 0.06882249058357306, 0.042337301054171154, 0.02285706448102636, 0.024753625837287734, 0.061985076405107975, 0.035486709725643904, 0.04329758756128805, 0.013621894991956651, 0.031847892661712, 0.05837900883385113, 0.02174651639402977, 0.05744968048696007, 0.028364673855581453, 0.05165540533406394, 0.014778482528137309, 0.019451454813991274, 0.03542088843615992, 0.04864968519125666, 0.023269691803891743, 0.08039025057639394, 0.04199283935927919, 0.0792450395279697, 0.05275089333632162, 0.046761345983083756, 0.030877920067203895, 0.016087622548054372, 0.04120370652526617, 0.04649456297712667, 0.054217217689646144, 0.0467438058528517, 0.02695097158929067, 0.05217581455196653, 0.024026227815608894, 0.02852603966104133, 0.05329027778602072, 0.11216107183801276, 0.010617341929381447, 0.08943379923169102, 0.055098532898617644, 0.13298104357506546, 0.09012559282460383, 0.03519778272935322, 0.05498867468642337, 0.19204237365296908, 0.04471874523109623, 0.2131801779781069, 0.07864760980010033, 8.610317996570043, 27.63544372149876, 55.46414811270577, 78.24902834211076, 89.07398128509521, 89.15410096304757, 98.05849538530622, 78.39702497209821, 60.95190484183175, 48.181581360953196, 45.311575821467805, 44.80608742577689, 46.478511878422324, 78.17288998195103, 53.2831780569894, 40.15692615509033, 44.91480588912964, 51.372263635907856, 30.227029732295446, 23.131642239434377, 23.41522601672581, 33.15282235826765, 25.66871268408639, 29.643756253378733, 31.660297189440044, 25.102342435291835, 35.83805445262364, 37.328505584171836, 31.384283474513463, 41.22628171103341, 42.46914073399135, 52.334870542798726, 33.936249119894846, 44.737904753003804, 47.70822490964617, 38.81769214357649, 72.52811786106655, 72.41471631186349, 62.238231795174734, 61.27655247279576, 61.36588546207973, 91.70922456468854, 92.82006781441825, 92.97633974892753, 91.67352472032819, 106.12100437709263, 99.3734211240496, 81.76954855237688, 44.942028931209016, 33.178860732487266, 4.31925949880055, 0.20400471532983439, 0.9247545323201588, 0.35714758560061455, 0.05208597651549748, 0.10089583668325629, 0.0402623816792454, 0.018261175469628403, 0.09480088230754648, 0.01328478946483561, 0.0397963977551886, 0.04761088200445686, 0.03967981865363462, 0.03967597136007888, 0.09016912084605012, 0.05827701823519809, 0.029176340837563788, 0.06583436485379934, 0.07586584692554814, 0.05987719379897628, 0.01986771060286888, 0.03585345111787319, 0.029676197229751518, 0.03754499481458749, 0.041216381559414525, 0.026271744464923228, 0.05167245013373239, 0.060264426948768754, 0.04826675056080733, 0.08286651662950005, 0.024764231339629208, 0.05820263044110366, 0.0246911904375468, 0.05417870404198766, 0.013914278275998575, 0.020520464683483754, 0.08397323438631636, 0.013629481013465141, 0.03574399324133992, 0.09346844309142657, 0.02591171208769083, 0.042591534554958344, 0.048295408487319946, 0.02479789685457945, 0.04589583385469658, 0.0038237093748258693, 0.012518618255853653, 0.07550300710967608, 0.007406707603617438, 0.04492235662681716, 0.06433409000081675, 0.07292284377451454, 0.021373252583933727, 0.0708940037127052, 0.006391621336141335, 0.019653973768332174, 0.03244781939845, 0.027756628447345326, 0.02270277070679835, 0.018999224794762473, 0.02976280204685671, 0.04244201936359916, 0.024930099224937812, 0.04476618839960013, 0.029690103804958717, 0.02167672906736178, 0.08998579425471169, 0.01626272190229169, 0.013427491316438785, 0.023202294616826942, 0.05731101507054908, 0.0486025236147855, 0.029908171389251947, 0.0571366994242583, 0.05627086838441236, 0.05413232956613813, 0.020322551285581927, 0.012491759295309228, 0.019513033563271165, 0.03011368607570018, 0.07038857654801436, 0.004359699877178562, 0.019794773177376816, 0.12968271199081624, 0.04095655693007367, 0.025401299386950474, 0.036097625337008915, 0.023357484057279568, 0.08722827543637582, 0.01620769949762949, 0.018122213194146752, 0.04278310873944845, 0.046254578711731095, 0.020288973980184113, 0.05522443846400295, 0.02922038793829935, 0.04978428055931415, 0.03143808125917401, 0.041713893613112826, 0.09015883425516741, 0.06660548597574234, 0.021628025520060743, 0.034417762620640655, 0.11216776897864682, 0.061741014144250324, 0.04458646143653563, 0.10535799831684146, 0.026191193876521926, 0.012319095033620085, 0.025714226166850755, 0.07059259845742158, 0.004011185207803334, 0.05229947416644011, 0.03601025377533265, 0.04895070368157966, 0.024235160622213568, 0.09227972437760659, 0.04645952003608857, 0.020497867771025215, 0.06749599533421652, 0.05904448205339057, 0.02025018722218062, 0.2016040584338563, 0.060868438466319015, 0.06930266946022, 0.10151354103748288, 13.081739136150905, 37.1177111353193, 68.33414350237165, 92.80264173235211, 103.98758779253278, 104.85859312329973, 117.92250578744071, 100.17907864706856, 84.44946180071149, 71.31720665522984, 78.57658726828438, 75.2186826978411, 70.49182319641113, 89.82687418801444, 88.72875308990479, 74.40518065861293, 57.65336915424892, 73.09065791538784, 52.15616634913853, 38.64902809688023, 41.439261368342805, 55.80953959056309, 43.891138213021414, 52.3793112209865, 46.39257655824934, 56.39914287839617, 57.04351186752319, 65.48987061636788, 58.211170537131174, 68.15289279392788, 70.00197519574846, 81.02593149457658, 66.50573893955776, 81.23537799290249, 75.78427301134381, 80.98723002842495, 112.58360726492745, 112.71655409676688, 105.94303321838379, 104.0568265914917, 97.03996590205601, 115.27195562635148, 110.61818422589982, 111.63478210994175, 112.02461774008614, 118.84339223589215, 118.58939388820103, 103.9272426877703, 64.66575867789132, 48.204552105494905, 7.687545112201145, 0.24911645108035632, 0.6763663121632167, 0.5406132223350661, 0.12029250657984189, 0.05690747672425849, 0.09461706038564444, 0.0306883000635675, 0.06503169863883938, 0.04517965032053845, 0.015612554736435413, 0.08747203914182526, 0.061360037087329795, 0.018280525592022707, 0.05542963084631732, 0.014896401736353124, 0.02374447463080287, 0.07119495434952633, 0.1229428236505815, 0.040607837427939684, 0.07611725772065775, 0.03716537822037935, 0.03813376643561891, 0.027117602826495255, 0.04673024533050401, 0.016738715914211104, 0.08062033501586743, 0.016892186964729, 0.08240220190158912, 0.04727949907204934, 0.10132975304233176, 0.05024629505351186, 0.045855060685426, 0.05251971645546811, 0.046422607731074095, 0.02490497985854745, 0.04864471492224506, 0.008867359404186053, 0.05231820173295481, 0.03400685199137245, 0.02736695935683591, 0.08365992084145546, 0.09139986801892519, 0.02804656815715134, 0.0709010333354984, 0.03762545210442372, 0.10054932920528309, 0.046726065554789135, 0.030984697730413506, 0.04332715133205056, 0.05515587589304362, 0.023336546162941625, 0.11585047708026, 0.027586574000971656, 0.06616762732820851, 0.011175291945359536, 0.027225092951474444, 0.032828681104417355, 0.05455635627731681, 0.058464158193341324, 0.034413905149059634, 0.006463052413892001, 0.012675049415390407, 0.003916798442203019, 0.02552665364263313, 0.028639388935906545, 0.16357831816588128, 0.14080546157700674, 0.13718893778111252, 0.13735682091542653, 0.11016092702214207, 0.19339102985603468, 0.12617708795836993, 0.1599819061479398, 0.14962583327932016, 0.10763245448470116, 0.1792576475335019, 0.15124534709112986, 0.1167433884527002, 0.08563550947500126, 0.1350552165614707, 0.22296071744390897, 0.054159671134714565, 0.22136761221502507, 0.16236350978059427, 0.13628738187253475, 0.11327879543283156, 0.18549503998032638, 0.15796738996037415, 0.14942536689341068, 0.11533321626484394, 0.13854964476610931, 0.11529477047068731, 0.10809893373932157, 0.18888406455516815, 0.19689602963626385, 0.11983259554420199, 0.14799874701670238, 0.18226587825587817, 0.13481019756623677, 0.29992276483348435, 0.1943883541971445, 0.11411414667963982, 0.11195206948156868, 0.11536258326045104, 0.12832520769110747, 0.1314561175448554, 0.08769608461963278, 0.11858225906533854, 0.11511428015572683, 0.19939781539142132, 0.11866147124341556, 0.19673071136432035, 0.18624535043324741, 0.2107445765286684, 0.08910069282033614, 0.202451725091253, 0.2446237892976829, 0.22092532951916966, 0.2512624130717346, 0.19856541577194417, 0.1473290872360979, 0.3689733924610274, 0.18624768459371158, 0.46411377297980444, 0.2617623625057084, 17.29685946873256, 47.08517299379621, 82.63025665283203, 107.25697231292725, 115.82751968928746, 115.51558726174491, 122.73202105930874, 99.26813507080078, 82.53806100572858, 68.66569069453648, 63.01432473318917, 62.05800942012242, 65.2265408379691, 104.17485564095634, 74.47077165331159, 54.914319787706646, 62.976331983293804, 70.09241989680699, 42.77351352146694, 34.98099763052804, 37.11797864096505, 46.537880761282786, 37.232342515672954, 44.68031460898263, 46.459314005715505, 35.362557956150596, 48.502112184252056, 56.725433758326936, 46.48565810067313, 60.98272010258266, 60.54563672201974, 70.72697802952358, 46.93552269254412, 66.03526251656669, 68.34013284955705, 61.62355940682547, 94.82406725202287, 101.08401897975376, 87.38046210152763, 84.6655090876988, 83.37117780957902, 114.94405623844692, 113.60395022800991, 115.72358158656529, 116.38364655630929, 135.0579447065081, 131.15839331490653, 116.93197059631348, 73.4476216179984, 53.50242846352713, 9.466392517089844, 0.3523136478449617, 1.2102176887648446, 0.8546666960631097, 0.26971590572169846, 0.21852569042571954, 0.20629103907517024, 0.15939603187143803, 0.3031186919127192, 0.12036521839244024, 0.18390872010162898, 0.21798584796488285, 0.16320185336683476, 0.12950247951916286, 0.14894242637923785, 0.15433874752904686, 0.10586903696613652, 0.23509140365890094, 0.27860675007104874, 0.15974017126219614, 0.24629556387662888, 0.07395456305571965, 0.0938258749832, 0.1464096587151289, 0.12461446252252374, 0.08494978877050535, 0.19520262336092337, 0.13459419272840023, 0.18000581381576403, 0.17021238218460763, 0.16346116230956145, 0.16452655728374208, 0.11573979444801807, 0.12338430567511491, 0.2020542664187295, 0.09029307562325682, 0.20656315875904901, 0.07941850022013698, 0.16900738541569027, 0.15240592695772648, 0.10575682084475245, 0.1848131258572851, 0.1922615540346929, 0.0959128654961075, 0.16458520985075406, 0.12592616570847376, 0.13730902490871294, 0.15596264467707702, 0.13306819461286068, 0.11911170636968953, 0.13604621695620672, 0.2015916005309139, 0.22254088068647043, 0.1498482706291335, 0.12109492852219514, 0.09948359496359314, 0.14454657797302517, 0.1131391122138926, 0.11386268160172872, 0.10536384050335203, 0.10666094161570072, 0.13811082259884902, 0.13433693296142987, 0.08682365821940558, 0.10871952186737742, 0.15148717697177613], [0.026371329656935165, 0.04373742753107633, 0.019620072462462952, 0.07032621917980057, 0.03813947630780084, 0.0381890941810395, 0.05028902579631124, 0.07164580694266728, 0.011405081222099918, 0.04824439622461796, 0.14576020570737974, 0.05715877216841493, 0.04297260321410639, 0.025369820451097827, 0.07718276804579155, 0.047787603057388744, 0.07816276938787528, 0.02044389709564192, 0.04311807433675442, 0.014095019648915954, 0.03990309399419597, 0.002441463991999626, 0.05589368094557098, 0.03972327203622886, 0.04877481044137052, 0.08657843566366605, 0.0419364564919046, 0.06533050510500159, 0.01740592618339828, 0.033065313406820805, 0.08475352930171148, 0.03049708210996219, 0.04393220779352954, 0.03616411837616137, 0.02889327299115913, 0.04252520775688546, 0.052054655339036665, 0.025515339071197168, 0.03539110414151635, 0.05074090637000544, 0.04253070389053651, 0.02344726781094713, 0.03175940490993006, 0.07494721229055099, 0.06727389725191252, 0.031858864572963545, 0.02683304389938712, 0.03660901003916349, 0.012028503930196166, 0.018452982052362392, 0.04529215821198054, 0.019515201482655745, 0.015263864072039723, 0.053952877409756184, 0.05510514522237437, 0.13422802809093679, 0.2050480714866093, 1.5975453449147088, 18.907286882400513, 44.96820279530117, 69.52617645263672, 79.44991329738072, 79.37383052280971, 78.70299584524972, 72.76180662427629, 64.75328513554165, 51.90008354187012, 51.92007350921631, 44.51330075945173, 41.300985268184114, 40.14643437521798, 49.948060103825156, 50.04354224886213, 35.96111052376883, 37.351820264543804, 53.39568676267351, 78.83928476061139, 43.87753711427961, 59.18645095825195, 73.18762002672467, 65.44173349652971, 57.46894311904907, 95.19337095533098, 46.304667949676514, 78.41865471431187, 72.02002389090401, 69.93427194867814, 75.16875989096505, 71.35556765965053, 56.672627449035645, 54.696733474731445, 45.58637012754168, 57.77830123901367, 32.04797887802124, 56.292866706848145, 44.48324285234724, 28.400212832859584, 37.71219553266253, 31.73979500361851, 37.0872745513916, 33.56120620455061, 54.597433294568745, 55.481087820870535, 50.661508083343506, 66.34793145315987, 64.42383629935128, 69.57263905661446, 85.66178349086216, 88.72573757171631, 84.44608497619629, 75.93622316632951, 51.647749287741526, 22.51147903714861, 4.279864949839456, 0.4828789031931332, 0.4399966842361859, 0.04065810330212116, 0.09962959534355573, 0.028684694719101702, 0.014986251647185003, 0.03344825482262032, 0.1457645483314991, 0.050746694273714504, 0.05801174496965749, 0.0025176401499525775, 0.009456816345586308, 0.01803687384485134, 0.01935152865813247, 0.021655674125733118, 0.04598870494269899, 0.07157210446894169, 0.012815509556925722, 0.0031697979679198135, 0.029539574203746657, 0.05464860311310206, 0.054010854834424596, 0.015330769321216004, 0.05981611207659755, 0.026825958297454884, 0.004443900559895805, 0.03650297876447439, 0.023175373739962066, 0.012984850693361034, 0.04850098763459495, 0.030921471837375845, 0.04150839249736496, 0.054047125923846445, 0.044782944821885655, 0.020473448992041603, 0.013374856506873454, 0.08104984768267189, 0.03097680297547153, 0.021508552466652224, 0.010057951722826277, 0.020860599021294286, 0.06531808112881013, 0.06283875488276992, 0.04644513848636832, 0.025720651893477355, 0.028787838827286447, 0.047430761491081545, 0.042462606116064956, 0.039010752591171434, 0.003330064334607284, 0.023429161103974496, 0.041342595858233314, 0.05941724883658545, 0.005511974475146937, 0.025929337034800222, 0.033730796804385524, 0.0698629290397678, 0.044582356299672804, 0.05324200341211898, 0.007553806362141455, 0.003431613037329433, 0.015925625705027154, 0.014878223783203533, 0.03878464436690722, 0.018222358177549074, 0.032981314164187224, 0.032761109194585254, 0.03881279339215585, 0.04980994275371943, 0.0279372205425586, 0.003608225312616144, 0.03711261873000434, 0.02877156077218907, 0.016422645820836936, 0.056116935930081775, 0.03571886708959937, 0.0878276050622974, 0.0473643634468317, 0.07139301193611962, 0.023496327589132955, 0.03699439078835504, 0.06805778840290648, 0.02954977937042713, 0.0064985525178989124, 0.0010319255982592168, 0.024735256197995374, 0.02799671788566879, 0.05565361525597317, 0.024441900064370463, 0.015870873018034866, 0.014597020211762615, 0.03205818423469152, 0.03901721224454897, 0.01609303386482809, 0.03741090272420219, 0.03488143613295896, 0.04005028859579137, 0.03139110627983298, 0.017321343400648663, 0.04796174228457468, 0.026571757027081082, 0.07606628617005688, 0.028096454051722373, 0.031348836940846274, 0.014888221996703317, 0.056100474670529366, 0.07136817755443708, 0.04884764778294733, 0.027514372785974826, 0.03478781526376094, 0.10097363072314433, 0.05286280072427221, 0.01814089495954769, 0.030434456720416034, 0.08363944943994284, 0.09814689454755612, 0.06072060604180608, 0.1399469112179109, 0.1644451195108039, 2.696272999048233, 25.598594938005718, 61.18626063210623, 85.73061234610421, 95.469131061009, 91.93882083892822, 93.11316367558071, 91.75950172969273, 85.32219723292759, 79.21213204520089, 70.54865946088518, 53.420728070395334, 50.297165393829346, 43.12211854117257, 43.432348660060335, 38.41614532470703, 36.180260181427, 23.16639539173671, 24.654192311423166, 44.91812712805611, 25.552128859928676, 25.179179089409963, 28.099731036594935, 27.5500625201634, 25.665721484592982, 38.8657146181379, 26.749433755874634, 38.0994360106332, 18.806930576051982, 29.60484286717006, 32.00185326167515, 30.009985378810338, 32.749913692474365, 22.976761681692942, 22.134636538369314, 23.635179928370885, 17.154115676879883, 34.71842173167637, 26.137410368238175, 27.706197227750504, 37.70159258161272, 29.322353431156703, 42.20721449170794, 51.25640937260219, 83.14933572496686, 93.36988571711949, 85.58629131317139, 102.01000540597099, 97.95826762063163, 92.87805053165981, 104.14210183279855, 95.54231643676758, 99.3631169455392, 94.45900194985526, 71.35273974282401, 34.93488591057913, 10.74999577658517, 0.9845884016581944, 0.16590352196778568, 0.038067276789141555, 0.07048733053462845, 0.02354591492829578, 0.02857695014349052, 0.01693317387253046, 0.13070354078497204, 0.0264557275388922, 0.025267453265509436, 0.0401968182330685, 0.02696135317507599, 0.09341976498918873, 0.03540079022890755, 0.0077014233517859665, 0.03688739599393947, 0.020036513152133142, 0.01740116286756737, 0.008815599056626005, 0.1364364153040307, 0.020568523622517074, 0.04192849049078567, 0.04279253359085747, 0.03305555268057755, 0.04792620062029787, 0.021944857268993343, 0.01533472687671227, 0.02839093655347824, 0.03350981830486229, 0.061330778657325676, 0.041176266569112024, 0.02875430223398975, 0.04502257964174662, 0.054574530837791305, 0.04958414665556379, 0.030684954885925566, 0.07771849179906504, 0.04424056124740413, 0.035561508033424616, 0.014951802424288221, 0.06415908903415714, 0.013598781544715166, 0.010469908992360746, 0.0050644382219096375, 0.052464653338704786, 0.04823704769036599, 0.024119945376047065, 0.028519020216273408, 0.0725219449294465, 0.042187623014407497, 0.032773590846253295, 0.018547781876155307, 0.04413562919944525, 0.05568911960082395, 0.012978314704793905, 0.01842598314397037, 0.024285816654030765, 0.028611996477203708, 0.01873847735779626, 0.04540071363693901, 0.040894925594329834, 0.014336099748366644, 0.08721393120608159, 0.21444834635726043, 0.07910164472247873, 0.11244145607841866, 0.17597729712724686, 0.12160106136330537, 0.12947706159736427, 0.09907916773642812, 0.07941896162394967, 0.08654872940054961, 0.25474099069833755, 0.11815022224826471, 0.13147617504000664, 0.2792846065546785, 0.20149603565888746, 0.12475171658609595, 0.1472780614026955, 0.1504493983728545, 0.13084789232483932, 0.1358970342470067, 0.16221985034644604, 0.09754957338528973, 0.14278249549014227, 0.1994844778840031, 0.10786476451903582, 0.18428325786122254, 0.11516131620321955, 0.21472935484988348, 0.07550172467849084, 0.17565848066338471, 0.1613508912601641, 0.08476495583142553, 0.14278696025056498, 0.11088842512773615, 0.1483702856515135, 0.1058067474514246, 0.09048688558063336, 0.1780331903802497, 0.1240500978061131, 0.1601546068808862, 0.11499679860259805, 0.114887785166502, 0.07490850865308728, 0.11769310677690165, 0.1768886103693928, 0.13756601326167583, 0.16536070752356732, 0.15781515384359018, 0.19042295483606203, 0.11654854033674512, 0.08119725941547326, 0.12119204045406409, 0.2737409754523209, 0.15630470775067806, 0.18353826712284768, 0.18496555196387426, 0.2731449231505394, 3.3821468353271484, 29.780705247606548, 74.59141322544643, 99.50835514068604, 107.73236111232212, 98.32933616638184, 102.00070871625627, 91.99120330810547, 85.80568068368095, 68.09650816236223, 71.749495778765, 61.624052728925435, 58.97839409964425, 52.25728348323277, 64.49134499686105, 69.81251866476876, 52.092645917619976, 55.87180587223598, 73.49656472887311, 111.18477507999965, 67.37297139848981, 86.76159994942802, 102.9278346470424, 94.62431349073137, 82.63063880375454, 141.41697774614607, 67.60933521815709, 119.2032950265067, 99.83064038412911, 98.44988741193498, 106.00333663395473, 104.06592178344727, 79.13625771658761, 74.47207791464669, 68.95145620618547, 82.21358707972935, 45.25315189361572, 80.87306417737688, 60.59154347011021, 37.31322996956961, 53.344013009752544, 42.3860958644322, 49.13228600365775, 48.25537122998919, 75.30142184666225, 80.82309968130929, 73.40040860857282, 91.50784492492676, 87.82379191262382, 96.07463877541679, 110.59733268192836, 116.86603219168526, 113.18228490012032, 108.73427745274135, 79.7545223236084, 42.10766417639596, 11.951250723430089, 1.3322965609175819, 0.6319946816989354, 0.09837090609861271, 0.1071314038708806, 0.11507504726094858, 0.16270477218287333, 0.2835659182497433, 0.29076552763581276, 0.14082574977406434, 0.23895587772130966, 0.12422973316695009, 0.14723247742014273, 0.13464344080005372, 0.1359067644391741, 0.13099312596023083, 0.13151706356023038, 0.12566856667399406, 0.07599208836576768, 0.13010025529989175, 0.21145805610077723, 0.08323811633246285, 0.17764023718025002, 0.13748225489897387, 0.10560650498207126, 0.18819265094186577, 0.054980505124798844, 0.13403693905898503, 0.10253221887562956, 0.12127502528684479, 0.16761827495481285, 0.1500008867255279, 0.10961247395191874, 0.10834374917404992, 0.12541980216545717, 0.07711575592734984, 0.1145983085568462, 0.1625562680086919, 0.2146246297551053, 0.2251729994480099, 0.07109273304896695, 0.20126279603157723, 0.13404677781675542, 0.17487562767096929, 0.09302347339689732, 0.2050192608897175, 0.09341107974095003, 0.13493260528360093, 0.07829090394079685, 0.13899599867207663, 0.07323252037167549, 0.10613975208252668, 0.11507645861378737, 0.1393799680684294, 0.12592604357217038, 0.10328182365213122, 0.08044937133256878, 0.17252803221344948, 0.10004459414631128, 0.12107297112899167, 0.08640955508287464, 0.10561047441193036, 0.06967039472822632], [0.07720683568290301, 0.025115273127864515, 0.07111380834664617, 0.035703722187983136, 0.02231795823068491, 0.016760240741340176, 0.010765241359227469, 0.027810371813497374, 0.03246943413146904, 0.06145412275301559, 0.010122484643943608, 0.0176132305059582, 0.057243582260395796, 0.047610352747142315, 0.028053138072469404, 0.04553050042263099, 0.010983699101156421, 0.02093712080802236, 0.03538536712793367, 0.042320541239210537, 0.1418175236987216, 0.02542490222757416, 0.0063312554682072785, 0.006961841809762908, 0.01704792771488428, 0.03264696603374822, 0.026739489187353423, 0.04306845646351576, 0.025399280745269995, 0.01600245283251362, 0.0780099429456251, 0.019226774905941317, 0.07049210742115974, 0.016844577555145537, 0.02463900770193764, 0.04255773672567947, 0.04967310938185879, 0.01857189361804298, 0.021888654213398695, 0.009635439841076732, 0.015906940546951125, 0.00860172142607293, 0.07122827720429216, 0.06482114922255278, 0.04183862870559096, 0.05805236207587378, 0.027113144851422737, 0.02587291515166206, 0.02537469911788191, 0.0765327111418758, 0.030790110850440602, 0.040939915858741315, 0.13308438445840562, 0.17745296151510306, 0.06512396583067519, 2.8491051409925734, 27.00971848624093, 62.67311954498291, 83.05465262276786, 82.54507868630546, 70.18384429386684, 80.42164666312081, 59.223186084202354, 50.40163850784302, 52.49777453286307, 53.30519689832415, 33.279755524226594, 56.418167046138215, 88.49337591443742, 57.065791266305105, 81.55069419315883, 86.86852577754429, 57.78870269230434, 48.01622813088553, 87.35597664969308, 113.15288707188198, 65.29870482853481, 69.8995726449149, 79.02975572858537, 63.98269517081124, 58.66465514046805, 66.27631637028286, 55.40365709577288, 56.97842114312308, 45.114646502903526, 88.66983931405204, 70.40183707645961, 72.50315298352922, 74.50679806300572, 78.6905655179705, 107.05164609636579, 94.5072363444737, 118.68388938903809, 110.73709569658551, 115.33624035971505, 158.04585129874093, 110.4917825971331, 86.97379098619733, 98.2013920375279, 101.50915145874023, 80.15106296539307, 50.59461430140904, 43.86226497377668, 38.369686194828574, 34.084502833230154, 32.22656147820609, 41.363088267190115, 51.66847923823765, 81.32581574576241, 64.5934557233538, 70.8067294529506, 85.3692990711757, 82.23604365757534, 70.23556668417794, 61.95655877249581, 32.59283229282924, 2.1100867050034657, 0.02884826237069709, 0.10981055867991277, 0.15699722059071064, 0.02795611774282796, 0.15377014875411987, 0.05264666357210704, 0.007407543049859149, 0.07192273743982826, 0.03549327455194933, 0.0771461950082864, 0.07715833399977003, 0.06217752929244723, 0.0036115717625112404, 0.028603623355073587, 0.034757752769759724, 0.00944607937708497, 0.02942161089075463, 0.06824872815715415, 0.03534140145140035, 0.06548854269619499, 0.00859075375566525, 0.12261418199964932, 0.09523658999907118, 0.0396492540437196, 0.07065753425870623, 0.029714955150016716, 0.03519840698157038, 0.04447685767497335, 0.0469024473402117, 0.030140101443976164, 0.027447401379634227, 0.018698287728641714, 0.018153553030320575, 0.08718588056841067, 0.013373321321393763, 0.008099364632341479, 0.03211024483399732, 0.05198626918718219, 0.02884354315964239, 0.0914734076442463, 0.010149118839763105, 0.02997924793245537, 0.051921567480478964, 0.06149134718413864, 0.05477056639002902, 0.051876991122428856, 0.00481285948938291, 0.017989610488127385, 0.02616072595784707, 0.008949258580936916, 0.053197094571909735, 0.07769833930901118, 0.036084346406693966, 0.027704879974148104, 0.04534140628363405, 0.05445226900545614, 0.029255461413413286, 0.043007089756429195, 0.0382375924714974, 0.05084621500489967, 0.0519530277566186, 0.02950086717360786, 0.035119520500302315, 0.055530562930341275, 0.011150527113516415, 0.013485587484735464, 0.025800639297813177, 0.049351259866463285, 0.0401095654150205, 0.0049406581674702466, 0.022964274710310355, 0.028884190799934522, 0.045364937878080776, 0.0362774133682251, 0.03025460083569799, 0.05026618291490844, 0.09029186104557343, 0.06289615215999739, 0.03288208520306008, 0.046250795879002125, 0.08138882342193808, 0.0342886136578662, 0.03825667626889689, 0.03307355421462229, 0.03372958901205233, 0.0234260211831757, 0.05909062922000885, 0.020742571247475486, 0.023337565661807145, 0.04646214596661074, 0.004757874828231121, 0.039161668957344124, 0.017713599405916672, 0.06767577997275762, 0.04648476153878229, 0.05646318556474788, 0.02772966007302914, 0.04284501488187483, 0.0033713328344414806, 0.02297416266186961, 0.040551495272666216, 0.018372606186728393, 0.04325009010998266, 0.03617750247940421, 0.1029616297621812, 0.009851580385916998, 0.03483262232371739, 0.03954299206712416, 0.08572383437837873, 0.018233913628916656, 0.09163625604872193, 0.04769656401393669, 0.09324088958757264, 0.01990454487635621, 5.054331575121198, 36.68981327329363, 82.33270004817417, 98.47836112976074, 96.09441334860665, 84.30566883087158, 101.56841959272111, 89.37938935416085, 83.57932499476841, 79.79849747249058, 69.53583444867814, 37.00890234538487, 52.16849940163748, 73.85707896096366, 41.751624584198, 51.36119862965175, 59.01284326825823, 54.850104536329, 46.746597698756624, 70.25468117850167, 91.59461402893066, 70.69314725058419, 67.0846003123692, 74.1537114552089, 66.69268022264752, 65.73543385096959, 62.428292819431846, 59.421807289123535, 49.622290338788716, 51.702448981148855, 71.84583950042725, 65.59026513780866, 66.07710456848145, 73.5967994417463, 72.44804682050432, 78.69689532688686, 76.77382155827114, 89.43441213880266, 75.29172216142926, 102.57164914267403, 105.95019681113106, 60.46738610948835, 58.52753938947405, 58.87578310285296, 56.625549929482595, 37.33536345618111, 32.472044808524, 32.97679322106497, 31.156486783708843, 44.79070063999721, 49.15649005344936, 75.50109222957066, 76.81430176326207, 116.81265613010952, 92.68707234518868, 88.84560789380754, 101.04723521641323, 100.52680819375175, 88.11711706433977, 81.5232001713344, 46.39384113039289, 4.6461140513420105, 0.15893620226000035, 0.04066757904365659, 0.42796894535422325, 0.05975534926567759, 0.13977583896900925, 0.03228563256561756, 0.08594932513577597, 0.08198720988418375, 0.03271666854353888, 0.06732484844646283, 0.08445926223482404, 0.04614288166963628, 0.019909518538042903, 0.042190761238868744, 0.03319802128576806, 0.020828762158219303, 0.019810162351599762, 0.018391740874254277, 0.06085216041122164, 0.04638024000450969, 0.06572081201842853, 0.07595792412757874, 0.02764597295650414, 0.020854147849604487, 0.06289927342108317, 0.05139754845627716, 0.05616930187014597, 0.012563245504030159, 0.043235372685428174, 0.039676595612296035, 0.030633745848068168, 0.010652264430453735, 0.02859528755236949, 0.07209579101098434, 0.027980054761948328, 0.027560318088425056, 0.01568877966409283, 0.03483927875225033, 0.01814372105790036, 0.07070527598261833, 0.0256479841856552, 0.1196765596313136, 0.015305653347500732, 0.035373815069241185, 0.06095276001308646, 0.03979708307555743, 0.03378006862476468, 0.005297136717542473, 0.02387563375357006, 0.03332287172919937, 0.01523717220074364, 0.00413518154527992, 0.05840149548436914, 0.05012902384623885, 0.028599949087947607, 0.03028876507388694, 0.014890764806685703, 0.0568649495419647, 0.11763517345700945, 0.13808199843125685, 0.11557683747793947, 0.1060084623417684, 0.09748566895723343, 0.13952297610895975, 0.13932857582611696, 0.08002419450453349, 0.1317698857081788, 0.1390327209872859, 0.15795734764209815, 0.14072956064982073, 0.12448190392128058, 0.30285756449614254, 0.08858651255390473, 0.11172902145023857, 0.15691784556422914, 0.14516074715980462, 0.250247270401035, 0.1479925587773323, 0.11454736414764609, 0.18330181123954908, 0.19606995396316051, 0.09863269847950765, 0.1404899970761367, 0.11126343786184277, 0.09676429802285773, 0.19044621501650127, 0.1804735551455191, 0.1587856217686619, 0.10119891792003598, 0.23942403974277632, 0.14529806907687867, 0.12393775954842567, 0.2132958546280861, 0.12142916130168097, 0.19518731561090263, 0.11453101145369665, 0.18811404944530555, 0.1452707512570279, 0.08833389396646193, 0.13436358581696237, 0.04806005861610174, 0.1906326628689255, 0.14865670885358537, 0.14475292047219618, 0.15963107640189783, 0.11589079563106809, 0.06675956092242684, 0.12765268449272427, 0.170057282650045, 0.12236710025795869, 0.22251597845128604, 0.24951895805341856, 0.43549981553639683, 0.17538087841655525, 5.537653914519718, 42.706991468157085, 95.40398475102016, 110.3177719116211, 103.74912561689104, 86.19411277770996, 97.11800806862968, 81.78063787732805, 66.42321518489292, 68.89527307237897, 68.94262504577637, 53.68370001656668, 79.89904485430036, 108.79946545192173, 82.50863538469586, 113.4789799281529, 115.98691136496407, 84.85897472926548, 72.96871008191789, 129.18261745997836, 164.06834139142717, 96.2648596082415, 106.51690578460693, 116.36947917938232, 97.55232606615338, 90.83266762324742, 98.60557569776262, 85.3319594519479, 86.3322777066912, 66.88314424242292, 128.7635438101632, 101.70942633492606, 103.9589125769479, 113.59072085789272, 117.72469057355607, 156.24408612932478, 133.11207389831543, 171.65835898263114, 153.73035294669015, 158.63548932756697, 212.73893002101352, 154.96162932259696, 121.36765888759068, 137.6415628705706, 143.34228188650948, 110.96956852504185, 69.35658482142857, 57.90262883050101, 49.47994259425572, 49.290968963078086, 46.74996410097395, 61.292151178632466, 72.98183522905622, 109.216447693961, 89.70092419215611, 94.99674388340541, 108.77976730891636, 111.84485394614083, 100.32568563733781, 91.94180161612374, 53.26696790967669, 5.775161147117615, 0.22640193493238517, 0.14266220480203629, 0.5540975044880594, 0.1520932444504329, 0.32704440663967815, 0.11480769089290074, 0.12154139099376542, 0.23740395956805774, 0.1917028483003378, 0.2451614604464599, 0.238739940736975, 0.1407796772462981, 0.1535244376531669, 0.1565361831869398, 0.10923715587705374, 0.12889425429914678, 0.084840327501297, 0.191011746813144, 0.12228106201759406, 0.13097859174013138, 0.16190026035266264, 0.23037417392645562, 0.15814550540276937, 0.07984329028321163, 0.13400324300995894, 0.12548834777304105, 0.12297726608812809, 0.10861563137067215, 0.10931693802454642, 0.1062995402940682, 0.0885079110573445, 0.14511662881289208, 0.06206685344555548, 0.18193659878202847, 0.16739119642547198, 0.09212321349020515, 0.16643317283264228, 0.11341826152056456, 0.14882639689104898, 0.13712550832756928, 0.11949062746550355, 0.16819246485829353, 0.21501079760491848, 0.13504373574895517, 0.1644543068749564, 0.16358301362821034, 0.15473536481814726, 0.11922451960189001, 0.09698339019502912, 0.08274656520890337, 0.11107382125088147, 0.2158312007252659, 0.09929760172963142, 0.13290872531277792, 0.15332239706601414, 0.07282334339937993, 0.08377317512141806, 0.1366458519228867, 0.16569886223546096], [0.060961228130119186, 0.031711035541125705, 0.035772301722317934, 0.04243466065132192, 0.004067015493222113, 0.07246479192482573, 0.01721964796472873, 0.011823832323508603, 0.05803811962583235, 0.019104426560391272, 0.01391571168122547, 0.02880226108910782, 0.040092524008027146, 0.043972811329045465, 0.043735710837479146, 0.018222197025482143, 0.0675599676157747, 0.10515567274498087, 0.027632661795775806, 0.038927231715726, 0.03320778201201132, 0.07240546082279511, 0.09655613026448659, 0.043087825245623074, 0.10400081971394164, 0.10699315236083098, 0.015725435822137764, 0.06414412733699594, 0.02176972568434264, 0.053243994912398715, 0.07145840235586677, 0.03082440740295819, 0.012725292389015002, 0.02182337744826717, 0.01018436364496925, 0.029907499639583484, 0.022192458089973246, 0.01563010334835521, 0.05898747832647391, 0.03445484795208488, 0.09581563142793519, 0.023097038568396653, 0.07283606593097959, 0.12350345642438956, 0.030798640035625015, 0.013999967918997365, 0.04343325046024152, 0.047504874478493414, 0.04945555069882955, 0.06671343411185912, 0.06672623806766101, 0.12917728482612542, 0.03567759180441499, 2.606394576174872, 22.69818581853594, 59.09937613351004, 74.36480467660087, 75.08791760035923, 65.65082563672746, 62.008975982666016, 46.51286724635533, 50.90140506199428, 39.26339129039219, 30.05857413155692, 46.26022727148873, 47.42557219096592, 70.70272186824253, 73.7015574319022, 69.69463552747453, 57.77622372763497, 48.92278044564383, 31.71204389844622, 20.258758408682688, 14.299620253699166, 8.17089741570609, 4.278024111475263, 2.6471540118966783, 1.3351256719657352, 0.8082711313452039, 0.3186408318579197, 0.29065221228769844, 0.8148571008018085, 0.7246617206505367, 0.8641854024359158, 0.6285567890320505, 1.622339448758534, 0.7214681548731667, 0.41088758621897015, 0.5688716002873012, 1.1387170340333665, 2.343851898397718, 4.682216891220637, 7.656113198825291, 13.019954017230443, 11.061149137360708, 17.62232003893171, 32.52097054890224, 38.141323225838796, 40.67797156742641, 53.53266702379499, 79.39177077157157, 99.03234795161656, 97.41928890773228, 101.11167975834438, 78.7927804674421, 50.783111980983186, 33.25497824805123, 39.280080863407676, 35.13724177224295, 37.61043569019863, 52.10041052954537, 55.52773802621024, 76.97235938480922, 79.61838626861572, 75.74026312146867, 85.18720068250383, 79.17508425031389, 45.97867236818586, 20.146404300417217, 5.746887624263763, 0.25987473236663, 0.5527655131050518, 0.05195218298052039, 0.026346198416181972, 0.07849329058080912, 0.02708730284523751, 0.05553298869303294, 0.10636336329792227, 0.05110536788457206, 0.051123522088996, 0.0504252484866551, 0.018780071554439406, 0.009921331241327738, 0.02232703533289688, 0.05109306943735906, 0.07535683709595885, 0.021472556183912923, 0.020622153334053497, 0.029392847791314125, 0.013886343837449593, 0.0029043962048100574, 0.011840386881626077, 0.04196290239425642, 0.03431845223531127, 0.044843612637903006, 0.016941102554223368, 0.03220017786536898, 0.05340310458892158, 0.036160858015396764, 0.012720072758384049, 0.017702284834480712, 0.031216607429087162, 0.016368824423157742, 0.02927687597860183, 0.012554962287790008, 0.053838238918355534, 0.052055520471185446, 0.017223274734403406, 0.02974638489208051, 0.03591923848060625, 0.025054673165349022, 0.024716269091836045, 0.004203946828576071, 0.019943328241684606, 0.05206155264750123, 0.01691487887209015, 0.016769173654860685, 0.03059208719059825, 0.0073095201847276515, 0.017723575567028353, 0.021935642763440098, 0.018961437179573944, 0.01791039831005037, 0.09785159610744033, 0.03915557571287666, 0.0556641427267875, 0.013862468734649675, 0.030491521515484368, 0.055015860191945515, 0.05981584744794028, 0.05464029445179871, 0.03074476435514433, 0.054664365481585264, 0.010431757512768465, 0.05897698138973542, 0.060840319975146225, 0.008460277408760573, 0.02887519681826234, 0.0331609529176993, 0.03462047156478677, 0.058733733370900154, 0.04368411164198603, 0.0691103862066354, 0.04236428978453789, 0.03927158484501498, 0.04409387554707272, 0.06207570154219866, 0.029627922855849777, 0.10372431669384241, 0.03911209518888167, 0.024855129587064897, 0.06076991518161126, 0.03486790614468711, 0.0353827411974115, 0.018771562725305557, 0.018448807365660156, 0.031805735281003375, 0.054908200433211665, 0.020970177337793366, 0.02800540822292013, 0.05401299561240843, 0.03553999847333346, 0.03884694066696933, 0.04862374819016882, 0.03937105129339865, 0.03904407883861235, 0.11559249806616988, 0.028202548090900694, 0.0076946575094812685, 0.054135053884238005, 0.06475540596459593, 0.02753673051483929, 0.0325443104707769, 0.04394393627132688, 0.058116687195641656, 0.02847367032830204, 0.02104061096906662, 0.08705883845686913, 0.07274166813918523, 5.4867227503231595, 34.49965075084141, 75.40553365434918, 87.37882927485875, 85.45264271327427, 81.66521440233502, 94.46337931496757, 75.50172451564244, 85.3376430783953, 56.45335619790213, 27.780761820929392, 34.49054513658796, 32.549440792628694, 48.68722261701311, 65.05417687552315, 76.93536717551095, 61.404663358415874, 54.60638952255249, 39.18011713027954, 24.39867925643921, 18.19680404663086, 11.352071949413844, 5.988979799406869, 3.7656266008104597, 2.033582478761673, 0.7492210513779095, 0.18740400326039108, 0.12264295188444001, 0.4245407421674047, 0.577059346650328, 0.26151494149650845, 0.38199008256196976, 0.4950335281235831, 0.19076423080904142, 0.042956596573016474, 0.335712555795908, 1.2278153044836861, 3.1546198214803423, 5.6546255350112915, 8.709229946136475, 13.788052184241158, 11.963258079120092, 20.27467325755528, 34.12179034096854, 42.69354322978428, 45.14557293483189, 61.66622829437256, 77.06423541477749, 89.66040924617222, 76.93811866215297, 69.82212802342006, 41.370644433157786, 22.53187026296343, 20.063074554715836, 41.07532514844622, 48.46834741319929, 50.9792457308088, 86.94652625492641, 82.7492515019008, 89.68866062164307, 95.76939746311733, 89.99565982818604, 100.99364376068115, 100.97791998726981, 64.40841824667794, 32.385723863329204, 12.390165822846548, 0.7620917207428387, 0.7484883421233722, 0.040696138582591496, 0.05722557394100087, 0.07249050840203251, 0.04826742909582598, 0.054416360932269266, 0.13110384930457386, 0.021849297485979538, 0.025694401069943393, 0.07649309148213693, 0.07122404993112598, 0.004305345405425344, 0.05068996535348041, 0.059673287240522246, 0.030476033953683715, 0.026841052308944718, 0.06572415719607047, 0.07522710120039326, 0.0902348030358553, 0.03885847915496145, 0.034828802171562395, 0.025705776709531034, 0.04037690142701779, 0.08583531089659248, 0.039314098456608396, 0.0543864714646978, 0.013555910005899412, 0.051915118005126715, 0.008665897268136697, 0.014692959974386861, 0.0355211521631905, 0.04255205399489828, 0.05563017187107887, 0.05830185940223081, 0.08072288879858595, 0.023448312754875848, 0.05776841552661998, 0.033544925706727166, 0.027615296388311044, 0.06236034698252167, 0.034022563469729254, 0.04688967052581055, 0.0511652893120689, 0.04496057850441762, 0.051182904081153016, 0.030027400170053755, 0.015509032344977771, 0.021068123867735267, 0.06175442199621882, 0.03942100843414664, 0.008159596489609351, 0.06269099709710904, 0.14745937953037874, 0.058796592855027745, 0.01530101556064827, 0.0972332607156464, 0.10600537500743355, 0.12235089684171335, 0.13317442605538027, 0.14390624447592668, 0.10538946198565619, 0.12418083793350629, 0.11058820730873517, 0.1822212713637522, 0.1998803759259837, 0.08645743929914065, 0.15452539894197667, 0.17485334458095686, 0.1440374595778329, 0.1346651403499501, 0.09919648644115243, 0.24048667986478123, 0.10751117313546793, 0.10945562379700796, 0.15887902889932903, 0.129804631162967, 0.11421808467379638, 0.19726254711193697, 0.13277582744402544, 0.17301857231983117, 0.23012219316193036, 0.12488910635667187, 0.11296828423759767, 0.088801051756101, 0.12850370311311313, 0.15261454933456012, 0.1309742084039109, 0.08992456325462886, 0.16629184755895818, 0.13982877827116422, 0.11898239116583552, 0.11896309362990515, 0.141670322311776, 0.148230765280979, 0.12274399931941714, 0.1628476038042988, 0.13248063756951264, 0.1900245055024113, 0.2344091231269496, 0.12574509185339722, 0.09009576442518405, 0.12999551663441317, 0.22512202789740904, 0.16396820438759668, 0.19314635012831005, 0.12207971353616033, 0.14055679206337246, 0.19090213626623154, 5.743308433464595, 40.12327602931431, 86.91204929351807, 99.15581744057792, 96.0377299445016, 82.10315241132463, 82.51338795253209, 62.943515641348704, 65.78839996882847, 52.042712688446045, 40.26574189322335, 61.47775840759277, 67.21625477927071, 95.79527255467006, 97.0285986491612, 93.53123678479875, 84.18511758531842, 72.80366257258824, 48.48805250440325, 31.84839882169451, 23.929887771606445, 13.350654397691999, 6.302716153008597, 5.174158036708832, 2.511268960578101, 1.1008101595299584, 0.3526407560067517, 0.4594388838325228, 0.9776728813137326, 0.9519908194031034, 1.0285675674676895, 0.7293673338634628, 1.5437631394181932, 0.8786214792302677, 0.51413152047566, 0.4287910855242184, 1.7044176501887185, 3.3239904131208147, 7.582941719463893, 10.903010743004934, 17.93126126698085, 16.648137433188303, 25.177132844924927, 46.134082726069856, 54.95662042072841, 60.56992762429373, 83.18133912767682, 120.4685480935233, 141.6183921269008, 141.61883681161063, 145.38114738464355, 110.50963946751186, 73.92676244463239, 50.14067111696516, 61.877793993268696, 51.707121644701274, 55.98220579964774, 75.38988631112235, 75.70376423427037, 98.46669510432652, 100.96144580841064, 98.66967282976422, 110.04722990308488, 113.11849348885673, 70.14662279401506, 38.720174176352366, 15.182293346949987, 0.8234842121601105, 0.9107937557356698, 0.1758076769432851, 0.1730802104409252, 0.2961143920464175, 0.08018305990844965, 0.08954484827284302, 0.2170441092125007, 0.183223141889487, 0.15453252355967248, 0.17721185088157654, 0.1477478247668062, 0.09619687989886318, 0.09692821172731263, 0.21234931184777192, 0.15556350323770726, 0.08458293202732291, 0.11566641767110143, 0.16197479063911097, 0.14295294348682674, 0.22096644874129975, 0.09092881543827908, 0.19335721167070524, 0.061814465560019016, 0.1388530313436474, 0.134452935308218, 0.15182252254869255, 0.08731396762388093, 0.12189432419836521, 0.11306903990251677, 0.10987961318876062, 0.09399115932839257, 0.09746251055704695, 0.14116279168852738, 0.12235651511166777, 0.31949421178017345, 0.13654386810958385, 0.07826427822666508, 0.13685423002711364, 0.1467259917408228, 0.11234589120639221, 0.11963412405124732, 0.12301506048866681, 0.12726948862629278, 0.17348103464714118, 0.0926669846687998, 0.15779643984777586, 0.0649073842380728, 0.15847380778619222, 0.10076990736914532, 0.15227601464305604, 0.09366886876523495, 0.12745159385459764, 0.19796245598367282, 0.1423257328569889, 0.13659257335322245], [0.05693435349634715, 0.1020481384226254, 0.013666629957567369, 0.0059920409694314, 0.11367706834737744, 0.03071986211995993, 0.06293759707893644, 0.06003607277359281, 0.05045670876279473, 0.020149928584162678, 0.08341040315904788, 0.018620612432381937, 0.026736617287886993, 0.027631827197702866, 0.01351077385645892, 0.06744541733392648, 0.018007031874731183, 0.03775208370227899, 0.0785451577976346, 0.028470186050981283, 0.0503419617057911, 0.03652976732701063, 0.07321324319179569, 0.10129339713603258, 0.08268813655844756, 0.10399917087384633, 0.03241643376116242, 0.04206966309409056, 0.05787602439522743, 0.03638822152944548, 0.027407093006851416, 0.030636795862976993, 0.04887536593845912, 0.022699028586170504, 0.0305927148354905, 0.06610389253390686, 0.03335460002667137, 0.05419105677200215, 0.02652118241946612, 0.024958136291908364, 0.14990336767264775, 0.09711502598864691, 0.04195714841729828, 0.061428467343960486, 0.02164552154551659, 0.06503433135471173, 0.04263258931626167, 0.0033396450370284064, 0.019815817940980196, 0.04725231695920229, 0.04783670524401324, 4.664901980331965, 38.58644219807216, 73.97094603947231, 85.09761060987199, 75.86459418705532, 78.61291939871651, 76.39699295588902, 48.924079758780344, 43.476108414786204, 50.52304090772356, 43.76463236127581, 58.22417756489345, 65.22071824754987, 73.44974776676723, 64.24651827130998, 60.510770661490305, 40.06629385266985, 14.987446750913348, 4.56591750894274, 0.29617765865155626, 0.29438220070941107, 0.5211689599922725, 0.7677408776112965, 0.3508599544210093, 0.17174090445041656, 0.17225352408630507, 0.04489137471786567, 0.16645940499646322, 0.10462910921445914, 0.2097877471574715, 0.30746261881930487, 0.2815616615116596, 0.1947339049407414, 0.20425179707152502, 0.6027890145778656, 0.21983059469078267, 0.15983452834188938, 0.08715681891356196, 0.017667114668126618, 0.1467121903385435, 0.07887467475874083, 0.1296962419790881, 0.40571959210293634, 0.1608211589711053, 0.18751932707216057, 0.4920365203704153, 0.1975788258548294, 0.30620152077504564, 0.9128840778555188, 2.7408782626901353, 5.244607993534633, 15.77649634225028, 30.91409887586321, 68.99305507114956, 82.21360792432512, 85.90359469822475, 52.971954345703125, 57.393610749925884, 46.390908990587505, 39.1328798021589, 52.83850029536656, 62.63180555616106, 50.687146936144146, 60.798467772347585, 78.03167479378837, 64.71896798270089, 84.64965329851422, 86.496915272304, 87.39813137054443, 46.761699608394075, 9.704911146845136, 0.20737445593944617, 0.22647710304175103, 0.07003292241798979, 0.044302385965628285, 0.04467955983376928, 0.047396397085062096, 0.05141330064673509, 0.05500653712078929, 0.007409055334781962, 0.0040643471542612785, 0.03880500720281686, 0.022984023472028117, 0.03080315568617412, 0.02651035300056849, 0.038905939286840815, 0.06292967857526881, 0.003300164476968348, 0.059377160987683704, 0.031164465405579125, 0.0491349768292691, 0.010110699338838458, 0.032459469844720194, 0.014065266736516995, 0.05858895435397114, 0.035646531863936355, 0.010859135338770491, 0.0437256922679288, 0.020194745822144405, 0.018713503876434903, 0.062289277224668434, 0.0026684487986910555, 0.032454974550221644, 0.0445792486092874, 0.03860542630510671, 0.035281208609896045, 0.022743757614599805, 0.054929340191717656, 0.05769563586051975, 0.031044941462044204, 0.0359967271797359, 0.007358857314102352, 0.030263540534568683, 0.028335590148344636, 0.017166058965293423, 0.025700574042275548, 0.02407967601902783, 0.02128985384479165, 0.055577968779419146, 0.019554354649569308, 0.020795597062845315, 0.03522227105817624, 0.040080697142652104, 0.03986635471561125, 0.06269012178693499, 0.014436278658519899, 0.013166825303674808, 0.08648676558264665, 0.039222713360296826, 0.03311760470803295, 0.022067185258492827, 0.026818743773869107, 0.04295838112011552, 0.03463624071862016, 0.03120581532961556, 0.037744083774409125, 0.008524825596915824, 0.005406159059410649, 0.020817876760182635, 0.011698020056688359, 0.02684754758541073, 0.03423385927453637, 0.061302884082709036, 0.05248310949121203, 0.025229207639183317, 0.04258569236844778, 0.03602382108303053, 0.017566835674058114, 0.03368689898135407, 0.015979503081845384, 0.029497725556471517, 0.03773257242781775, 0.024152377653600912, 0.01608374641676034, 0.026305447299299494, 0.019209545205480287, 0.07383880498153822, 0.022285931377804706, 0.01881781336851418, 0.022516212592433606, 0.02431936512169029, 0.011049388076311775, 0.03574055985414556, 0.012936642476623612, 0.058309275789984634, 0.029124317557684014, 0.07501274520265204, 0.020870827936700413, 0.05018479263942156, 0.011740976412381445, 0.01899528589897922, 0.037451926951429675, 0.01882267337558525, 0.056683085193591456, 0.07987993117421865, 0.08205327883894954, 8.50629825251443, 53.39934498923165, 93.95311055864606, 99.85345132010323, 86.13925674983433, 94.27709811074394, 106.73837266649518, 80.1738530567714, 62.179047039576936, 48.52128921236311, 26.650041512080602, 30.267350128718785, 38.47213043485369, 62.361020360674175, 64.34736442565918, 66.3140867778233, 45.64077452250889, 18.09936077254159, 5.421135663986206, 0.307209525257349, 0.41418301367333954, 0.8857508738126073, 1.1926163818155016, 0.5626010139073644, 0.2104672456958464, 0.152773950781141, 0.07406608028603451, 0.1411030398947852, 0.08999539552522556, 0.24133484863809176, 0.3169097533183438, 0.06911016907542944, 0.09789983316191606, 0.1926596233887332, 0.35316626780799454, 0.23648780158587865, 0.19674957463783876, 0.2541550078562328, 0.24586805967347963, 0.2780448687928063, 0.21643234203968728, 0.32468429899641443, 0.5026137413723128, 0.2754267549940518, 0.4782910836594445, 0.8104213273950985, 0.2862940090043204, 0.24386524142963545, 0.4482159417654787, 2.0369920900889804, 6.222525690283094, 18.84041394506182, 36.98252003533499, 66.6968560900007, 81.80011367797852, 65.67153126852853, 44.612253529684885, 35.0285267829895, 29.373061384473527, 35.85121086665562, 58.539719581604004, 100.5040875843593, 89.33848530905587, 86.39158752986363, 96.77869279044015, 77.59397997174943, 95.34955256325858, 101.7101697921753, 105.03092929295131, 65.90528951372418, 19.736809730529785, 0.8908517201031957, 0.4313681886664459, 0.11133640751774822, 0.052027161100081036, 0.031480221676507165, 0.06177440485251801, 0.02241283778234252, 0.07650407017873866, 0.04521864912073527, 0.03345539979636669, 0.04280433670750686, 0.06904590502381325, 0.03709573677874037, 0.03515879749985678, 0.05999886869852032, 0.03401211742311716, 0.035244360765708346, 0.051072282517062764, 0.024351950069623332, 0.011207816673309674, 0.022808405038501536, 0.03592352003657392, 0.11317644521061863, 0.023196728933336477, 0.031804513917969804, 0.007830110910747732, 0.03259576378124101, 0.046521646702396016, 0.021703073189460804, 0.04432595827217613, 0.023651561134361794, 0.011912488012707658, 0.051856998088104386, 0.08388570336891071, 0.037018583954444954, 0.007960671226360967, 0.02755618072114885, 0.03346905870629208, 0.015213832292439682, 0.03285186664600458, 0.035209256756518564, 0.009893602059621896, 0.026487379501174604, 0.017691584337236624, 0.050028268181319745, 0.01466097722628287, 0.06979749112256936, 0.08338482238884483, 0.022768242550747733, 0.025215689525274292, 0.02069890751902546, 0.04218226937311036, 0.041273677056389194, 0.01943914618875299, 0.20085102027016027, 0.25830164392079624, 0.1265336445399693, 0.26848691595452173, 0.15060637066406862, 0.07076339250696556, 0.15479226676481112, 0.13884355899478706, 0.12411269944693361, 0.10553397637392793, 0.11413672832506043, 0.1135287880897522, 0.10535106368895088, 0.0875201133478965, 0.11414533214909689, 0.13274887603308472, 0.08415033881153379, 0.2517369533223765, 0.13988454027899674, 0.1220867567296539, 0.21171102752642973, 0.08808194712868758, 0.13972004981977598, 0.11486289650201797, 0.14504349630858215, 0.1586359098021473, 0.10924824992460863, 0.09158953891268798, 0.15052482432552747, 0.10523145832121372, 0.11007725686899253, 0.17148930366550172, 0.10981672656323228, 0.07205936725118331, 0.15971777960658073, 0.15074472395437105, 0.16463505503322395, 0.1052525539749435, 0.2095158038926976, 0.13687283545732498, 0.24611640349030495, 0.19246970143701347, 0.10474602758352246, 0.1533083649618285, 0.0982007295159357, 0.17258276284805366, 0.16723478053297314, 0.12898580224386283, 0.30280181605901035, 0.17404367588460445, 0.15453282211508068, 9.002183369227819, 61.12158679962158, 106.25526441846574, 110.7455586024693, 96.66015652247837, 96.37412697928292, 96.67988245827812, 64.36955002376011, 51.65263387135097, 60.93597262246268, 58.107694489615305, 83.26330702645438, 96.20709228515625, 109.56084210532052, 93.33139964512416, 87.88602692740304, 62.869607652936665, 26.007529429027013, 7.334990041596549, 1.2792397907802036, 0.4937985401068415, 1.3106166613953454, 1.667354004723685, 0.698574491909572, 0.19295302193079675, 0.3145696488874299, 0.11218598764389753, 0.29387395083904266, 0.22158383418406757, 0.47581464797258377, 0.7797231003642082, 0.5277794652751514, 0.4378126971423626, 0.37458145724875586, 0.9781299425022942, 0.5838221151913915, 0.3913578013224261, 0.6901705914310047, 0.36457075870462824, 0.25767283194831436, 0.24985217303037643, 0.281463871044772, 0.6234753759843963, 0.3322896451822349, 0.3876557414020811, 1.041256606578827, 0.45242071471043993, 0.6297535619565419, 1.692538401910237, 3.7507426909037997, 8.314255254609243, 25.21199369430542, 47.66430187225342, 102.3281147820609, 115.60733822413853, 121.99021748134068, 76.54858875274658, 81.90438529423305, 72.25497027805874, 57.063863141196116, 71.57562405722481, 79.50401197160993, 67.28288800375802, 81.61623655046735, 96.5375416619437, 80.15537084851945, 107.61347048623222, 111.48774433135986, 118.46472930908203, 73.79649066925049, 22.7663129057203, 0.9766535588673183, 0.4443431081516402, 0.255133862474135, 0.11550209006028515, 0.08910299305404935, 0.1750729592250926, 0.15411561807351454, 0.23511528809155735, 0.11402349440114838, 0.08937108902526752, 0.09877367770033223, 0.20393395769808972, 0.12126144101577145, 0.15703776984342507, 0.15446355726037705, 0.10834407487085887, 0.0783209494714226, 0.13430163556975977, 0.11929351304258619, 0.13072036845343454, 0.10006203249629055, 0.07800359864320074, 0.27697617613843506, 0.09282500190394265, 0.11862060986459255, 0.16400399032448018, 0.16590956092945167, 0.32541098285998615, 0.12299872136541776, 0.1654075671519552, 0.12340088907097067, 0.07959042742316212, 0.12512306523110184, 0.10010168608278036, 0.09141445652182613, 0.11366492935589381, 0.09710765709834439, 0.18929920585027762, 0.13985309696623258, 0.10108588755662952, 0.18254899020705903, 0.07844487710722856, 0.11960618197917938, 0.06353044669542994, 0.14608983801943914, 0.10017072702092783, 0.23773071489163808, 0.1565460083740098, 0.10693604685366154, 0.0879422231976475, 0.11297068625156369, 0.15970933863094874, 0.11835374204175812, 0.13778716139495373], [0.02574937936982938, 0.029483082770769085, 0.05433754908985325, 0.035023311020008156, 0.0423768901798342, 0.030259554141334126, 0.00754808122292161, 0.04471003623413188, 0.022936836450493762, 0.08791262550013405, 0.05236146851841893, 0.02346033469906875, 0.029293327060128962, 0.04602696413972548, 0.05491510113435132, 0.0529349493528051, 0.019320886016690304, 0.07449011038988829, 0.047948605846613646, 0.01640530246576028, 0.09317182150802442, 0.046618270089051554, 0.01907228266022035, 0.055198786447622945, 0.033543147944978306, 0.03867992266480412, 0.055516327265650034, 0.005465886256258402, 0.014920900243201425, 0.11842836732310907, 0.049100636171975305, 0.03630529097946627, 0.04411432319985969, 0.07789573871663638, 0.04458071763760277, 0.03246936627796718, 0.040493388926344256, 0.04455156438052654, 0.015706141678882495, 0.059625023044645786, 0.03131542926920312, 0.018201220115380626, 0.035463317230876, 0.08096735139510461, 0.08226712593542677, 0.024123127705284526, 0.017795698750498037, 0.0461031636223197, 0.1729698535054922, 1.2171127987759454, 31.460765770503453, 71.9996587208339, 80.21092169625419, 75.1832468850272, 57.64045940126692, 56.834475312914165, 43.19625234603882, 32.79516383579799, 38.0081992149353, 47.93980489458357, 59.5973813193185, 84.5318465914045, 66.96657126290458, 48.23918192727225, 28.080302136284963, 16.674149751663208, 4.668357406343732, 0.5538048659052167, 0.10981928464025259, 0.15272850250559195, 0.06112807310585465, 0.1950445654136794, 0.07465616147965193, 0.41161142023546354, 0.3530658446252346, 0.08482458548886435, 0.08415121412170784, 0.1411178998116936, 0.2042354443775756, 0.07123805489391088, 0.2886840264712061, 0.30631413044674055, 0.23938959730522974, 0.16205956680434092, 0.2986730933189392, 0.5407297675098691, 0.26831711935145514, 0.513126691537244, 0.14543716875570162, 0.1180425930236067, 0.18153900440250123, 0.3092171475291252, 0.18436348784182752, 0.23111130722931453, 0.21619380983923162, 0.2616086064704827, 0.33783113211393356, 0.10730151938540594, 0.06798173819801637, 0.06128300979201283, 0.07193399433578763, 0.0141265621974266, 0.1675684976258448, 0.13389868076358521, 0.7139410844870976, 5.485844237463815, 26.53361749649048, 49.45419257027762, 58.94596685682024, 53.59016336713518, 59.44798810141427, 55.556138787950786, 26.522161654063634, 29.68227011816842, 39.35825157165527, 51.15916933332171, 61.68874045780727, 68.2298093523298, 56.73631811141968, 76.38390254974365, 76.10089547293526, 83.85378578730992, 40.17107616152082, 1.6744836164372308, 0.2612581295626504, 0.03480951820633241, 0.012041368105980967, 0.2238159022693123, 0.06102666604731764, 0.036632667162588665, 0.02391494467987546, 0.07382286619395018, 0.03711606229522398, 0.055807795375585556, 0.013928851511861597, 0.039498595520853996, 0.017530199872063737, 0.043335724622011185, 0.028918568776654344, 0.014993177793387855, 0.05544184786932809, 0.04218373840142574, 0.018684864609635303, 0.014141182082572153, 0.049245472864380906, 0.05746735632419586, 0.030530187833522047, 0.018161164496892264, 0.05755814430969102, 0.03466321587828653, 0.02969225136829274, 0.030424977586205517, 0.05898490667875324, 0.018146430108962313, 0.05716294515877962, 0.0176039922516793, 0.017422216112858484, 0.0782157222607306, 0.06886611359992198, 0.031837456793125184, 0.050122109574398825, 0.10607402239527021, 0.01826841543827738, 0.007472293102182448, 0.019727447236488973, 0.06999495838369642, 0.049555607472679446, 0.05283170007169247, 0.03495859574260456, 0.016067695670894215, 0.04792119303186025, 0.047077804537756104, 0.032525152034525356, 0.028830250658627068, 0.028168421172137772, 0.012470332855757858, 0.04138390507016863, 0.06506103170769555, 0.10397044170115675, 0.0873048956106816, 0.09342469115342412, 0.04163721576333046, 0.007246406249968069, 0.01888011645392648, 0.09089718213570969, 0.02074274936291788, 0.016611831562061394, 0.01821369498169848, 0.007480135270660477, 0.022792584994541745, 0.03739849231871111, 0.01293769505407129, 0.009299941593781114, 0.03863418261919703, 0.04389348719269037, 0.018928445110629712, 0.059667431483311315, 0.0406635587236711, 0.00681658654606768, 0.02316444762982428, 0.03177572028445346, 0.026713056855701973, 0.08358506485819817, 0.014479409736980284, 0.012655733219747032, 0.08614408504217863, 0.05512775061652064, 0.016845797221841555, 0.05112888590831842, 0.015729635953903198, 0.024567668226414492, 0.026175270355971794, 0.045964891756219525, 0.006031497356681419, 0.007305824713382337, 0.048891650778906684, 0.04928540125755327, 0.015404169846858298, 0.0480759431208883, 0.024223187871809517, 0.014362009608053734, 0.03497136916433062, 0.005144995595661125, 0.031037134916654656, 0.10792872322989361, 2.64688954608781, 45.763882705143516, 90.65459224155971, 92.63807364872524, 85.33427320207868, 80.34558473314557, 95.57670307159424, 70.84488895961216, 51.309792382376536, 35.565824031829834, 26.938089506966726, 45.37511362348284, 59.85431180681501, 65.78368214198521, 53.92882204055786, 37.59386771065848, 19.58406400680542, 5.6060910650662015, 0.41435281027640614, 0.1965380481311253, 0.18380529779408658, 0.007119603322020599, 0.11752723210624286, 0.11784503076757703, 0.45547336233513697, 0.5411268462027822, 0.10782770293631724, 0.10143378603139094, 0.04711858449237687, 0.15472967869469098, 0.15980672197682516, 0.4276222139596939, 0.3191104323736259, 0.41028629562684465, 0.25747809239796227, 0.5736934872610229, 0.967056250997952, 0.5307929749999727, 0.4132989639682429, 0.12873827266905988, 0.15961361091051782, 0.05430630933759468, 0.28149771637150217, 0.15630994604102202, 0.28953257522412706, 0.19208205438085965, 0.34985849101628574, 0.41592185465352877, 0.3407311093594347, 0.034679890876369815, 0.06236845547599452, 0.036185661863003454, 0.2989840523472854, 0.48723232958998, 0.08597975743136235, 0.07998190820217133, 6.42545564685549, 28.660778965268815, 50.81427812576294, 64.51262038094657, 59.62262412479946, 42.85408135822841, 41.24701860972813, 23.784925767353602, 32.305736201150076, 59.2496726172311, 83.89242471967424, 97.34466525486538, 94.96636635916573, 68.16335678100586, 89.17587661743164, 88.96398435320172, 99.98796149662563, 58.33041204724993, 5.479138791561127, 0.27313379517623354, 0.06167568479265485, 0.10941111189978463, 0.266968625996794, 0.045000815631023476, 0.10348452920360224, 0.04388628454346742, 0.018390894401818514, 0.044227024473782094, 0.02527097486225622, 0.027988139506695524, 0.04484925465658307, 0.03508194662364466, 0.027760664034368734, 0.05089784812714372, 0.04291477167446699, 0.014378189275573407, 0.032935221280370436, 0.029592798490609442, 0.028580529415713887, 0.050391888312463246, 0.0709552550688386, 0.0068140865686083475, 0.025785906606220772, 0.01032047946604767, 0.025965918553993106, 0.05227298076663699, 0.020090845147413865, 0.0338918097716357, 0.02514214481094054, 0.04538309208250471, 0.0319086351165814, 0.08296481599765164, 0.04756514195884977, 0.09530094904558999, 0.021420626202598214, 0.011693430615455976, 0.03644720997129168, 0.030730874743312597, 0.037528014475745816, 0.04323549482173153, 0.027948323071801236, 0.02606720686890185, 0.06410583760589361, 0.06016428196536643, 0.034628742906664095, 0.059945671553058286, 0.045893954312694926, 0.03121860232204199, 0.04201649309002927, 0.013073430047370493, 0.02266565993029092, 0.1817949070994343, 0.09252961525427443, 0.18737139286739485, 0.21692022228879587, 0.12338889257184096, 0.1703948945339237, 0.0596113573493702, 0.11903523547308785, 0.1355339094464268, 0.12657008187047072, 0.10950700246862002, 0.0793775234903608, 0.1350217376436506, 0.10120908915996552, 0.13065864890813828, 0.10539428636963878, 0.10188906945820365, 0.1319855105664049, 0.1250522533165557, 0.06714291285191264, 0.16039962587612017, 0.11994827219418117, 0.08791527178670679, 0.1827393735625914, 0.12104577544544425, 0.1271930041589907, 0.17226454349500792, 0.04585594956630042, 0.11697961363409247, 0.1815467532724142, 0.10459591528134686, 0.13298402912914753, 0.12869161660117762, 0.1219787746667862, 0.059642569960228035, 0.07226717538599457, 0.1514739862510136, 0.12207326745348317, 0.0851134310609528, 0.12912275775202683, 0.10920741568718638, 0.11984573198216301, 0.12029941406633173, 0.15828011317976884, 0.14707082323729992, 0.12230402364262513, 0.09233591386250087, 0.21190127517495835, 0.2532174624502659, 2.6919093132019043, 49.58220270701817, 104.44725281851632, 100.55870737348283, 91.69807965414864, 74.73164176940918, 76.2323692866734, 60.60473115103585, 40.90741845539638, 49.86244092668806, 72.67994989667619, 84.30217388698033, 116.47447340829032, 95.23080090114048, 68.65915243966239, 43.812196254730225, 25.425480570111954, 8.098645704133169, 0.7680563149707658, 0.37731722901974407, 0.3428498756672655, 0.14116823353937694, 0.29325841101152555, 0.30105952812092646, 0.905198338840689, 0.7875631653836795, 0.22950665333441325, 0.3142346425780228, 0.2616913877427578, 0.3624611661902496, 0.20570908673107624, 0.4911569761378424, 0.6600979736873082, 0.39732586964964867, 0.4357968238847596, 0.5023835822939873, 0.6288038300616401, 0.6786132401653698, 0.7083255829555648, 0.26889178422944887, 0.2434818148612976, 0.41879175922700335, 0.6893332792179925, 0.45978911646774834, 0.6049716717430523, 0.3209065959921905, 0.7985170547451291, 0.7660132188882146, 0.5361390709877014, 0.14762116942022527, 0.1304591189005545, 0.14478007544364246, 0.41858377467308727, 0.6123551641191755, 0.6563805245927402, 1.0129357491220747, 9.987129603113447, 39.887909276144846, 75.04627704620361, 85.74259104047502, 77.87848091125488, 86.31673458644322, 78.25410052708217, 36.92085129874093, 43.725260393960134, 52.77900287083217, 66.27980436597551, 82.83423491886684, 85.59185682024274, 71.98244108472551, 93.43965952736991, 96.34158856528146, 113.80022294180733, 66.23947007315499, 5.816892027854919, 0.4245397379355771, 0.08263533974864654, 0.1674834093345063, 0.40613925244127, 0.1209692366953407, 0.27701083570718765, 0.1289062372275761, 0.1959194413253239, 0.1313280372747353, 0.14767435299498693, 0.08803309939269509, 0.28814423829317093, 0.11226907425693103, 0.11842231479074274, 0.0821676594870431, 0.05997775268873998, 0.12478455768099853, 0.12424596372459616, 0.1113346093999488, 0.162553214601108, 0.11503460657383714, 0.18869137418057236, 0.10114164956446205, 0.11796963693840162, 0.11154703835823707, 0.21166642063430377, 0.14821829380733625, 0.14663267960505827, 0.11713498458266258, 0.13165608181485108, 0.11405001154967717, 0.20010501172925743, 0.14976175741425582, 0.20098668656178884, 0.23040530511311122, 0.10604418721050024, 0.10297854564019612, 0.16650091776890413, 0.11853302456438541, 0.09706882453922715, 0.10206307297838585, 0.1960287397461278, 0.15584862365254334, 0.13569652714899608, 0.16960862172501429, 0.06604435787137065, 0.13527949952653476, 0.1433186060083764, 0.05951066953795297, 0.11561374978295394, 0.13272001115339144, 0.10787415544369391], [0.009172164968081882, 0.04754518963662641, 0.007101212478508907, 0.06606434751302004, 0.007410916217070605, 0.03987450392118522, 0.03696890501305461, 0.05111606838181615, 0.03036622323894075, 0.05312722582103951, 0.06056876347533294, 0.022013625096795813, 0.039844529636736424, 0.02891144755163363, 0.05935590248554945, 0.016159903490915895, 0.005188536339639021, 0.007435844745486975, 0.1059289855350341, 0.031839645068560324, 0.015348394268325396, 0.04271740619359272, 0.01723327803691583, 0.0484781176117914, 0.05543817360220211, 0.05862290146095412, 0.10029471572488546, 0.06456857134721108, 0.02926034347287246, 0.029297096322157552, 0.047699827767376385, 0.05353039775842002, 0.056134387850761414, 0.05070016373481069, 0.03843853722459503, 0.021978181820096712, 0.09101262129843235, 0.013800213146688682, 0.06587629831795182, 0.03260168060660362, 0.03703914356551, 0.08483527920075826, 0.03719624477837767, 0.03665871272927948, 0.017051564662584236, 0.057942812597112994, 0.1239387502095529, 0.7625760861805507, 14.765578610556465, 58.3103734425136, 78.6182417188372, 68.03384235927037, 66.20351314544678, 68.1491755076817, 39.164855412074495, 24.833290815353394, 32.942253725869314, 48.11543451036726, 65.67722184317452, 64.1384390422276, 52.64241170883179, 31.007110936301096, 14.488930003983633, 4.471561840602329, 0.6910175116998809, 0.1803602533681052, 0.4051218841757093, 0.07070728444627353, 0.04948696687019297, 0.13233061347688946, 0.02772366182346429, 0.1016213127544948, 0.14678027454231465, 0.534605473279953, 0.039098493954432864, 0.14167322644165584, 0.13507340129997047, 0.11228898247437817, 0.0513053559032934, 0.017560689843126705, 0.17643013782799244, 0.06116446293890476, 0.09187949728220701, 0.0396571318352861, 0.13704154640436172, 0.3380654981093747, 0.21322042867541313, 0.15897837999675954, 0.13091879923428806, 0.09509694749223334, 0.09243687308792557, 0.10836619511246681, 0.13108479604125023, 0.12372393959334918, 0.05683756726128714, 0.14730907045304775, 0.4033812518630709, 0.08412491410438504, 0.3663251245660441, 0.10366461239755154, 0.19042912950473173, 0.07354665494390897, 0.10033168231270143, 0.07459929345973901, 0.13686130036200794, 0.22533708278621944, 0.21368057041295938, 0.6013757618410247, 8.963518381118774, 27.769516161509923, 53.36486802782331, 57.83499159131731, 85.08713967459542, 56.77688864299229, 34.81939990179879, 28.03985493523734, 19.63421436718532, 37.862919330596924, 71.3097095489502, 61.00365502493722, 66.5678766795567, 71.6599473953247, 80.81797191074916, 65.96924073355538, 13.707024897847857, 0.290780563971826, 0.08667255525610276, 0.04147906621385898, 0.07348022636558328, 0.09107331625585045, 0.0768264082393476, 0.06485841436577694, 0.013613450623649572, 0.039607917690383534, 0.01858640069674168, 0.06669619253703526, 0.04149702025045242, 0.05624786265460508, 0.0035648007677601917, 0.03014145851401346, 0.009724117582663894, 0.02232601074501872, 0.06265441727425371, 0.029506617757890905, 0.01398014706293387, 0.030729751767856733, 0.11082217296851532, 0.038066618610173464, 0.03636822510244591, 0.01614049230036991, 0.04389548887099538, 0.021210114105737636, 0.04133752720164401, 0.0040369292504952425, 0.03582482033276132, 0.05018505387540374, 0.038392244172947745, 0.049202535168400834, 0.054221991183502335, 0.045758562827748914, 0.02757005506594266, 0.06434755892093692, 0.025763092562556267, 0.03752217907458544, 0.05465131725317665, 0.03814132192305156, 0.01656199655761676, 0.06585618653999907, 0.042395054562283416, 0.0026183266891166568, 0.05143353456099119, 0.01562656818090805, 0.008779999716872615, 0.04620631790852972, 0.037001182923891714, 0.03674516826868057, 0.01800059766641685, 0.021653451923547045, 0.015578400676271744, 0.05100777758551495, 0.01908954798376986, 0.022232111676463058, 0.018091877589800527, 0.024896432013650025, 0.044745842527065954, 0.01212294158592288, 0.027426225998039757, 0.039713470597884486, 0.036506218769188435, 0.04147327831014991, 0.06424782784389597, 0.02005766817767705, 0.050885848235338926, 0.05960812073733125, 0.06209280741001878, 0.030667492787220647, 0.003997122569541846, 0.046147661948842664, 0.054370040739221234, 0.03653673588165215, 0.026511743997356722, 0.051795573705541234, 0.003957509271068764, 0.011527454164544386, 0.029721703180777173, 0.02361759027865316, 0.027831937352727567, 0.026077400161219493, 0.07225646131805011, 0.026609597228733555, 0.03428672733051436, 0.037050702409552674, 0.05147126450070313, 0.04357576656288334, 0.021113963997257606, 0.033432278715606244, 0.02359104429238609, 0.04847569524177483, 0.058346527362508435, 0.032840284053236246, 0.034048585287694416, 0.0854812173971108, 0.14308368361421994, 1.8635040393897464, 24.03382240022932, 79.61279296875, 90.08701474325997, 77.63416140420097, 94.30403627668107, 99.95180307115827, 62.935087476457866, 37.59289148875645, 30.52397836957659, 22.629221473421367, 44.814824785505024, 48.74694585800171, 53.267516817365376, 37.85101011821202, 18.982266630445206, 5.17351576260158, 0.4906231590679714, 0.40416669685925755, 0.4173208310135773, 0.06901407494608845, 0.1707402959998165, 0.012631529875631844, 0.11363889396722827, 0.37141636280076845, 0.4233443763639246, 0.9520347884723118, 0.18147147659744534, 0.3417354497526373, 0.5107507875987461, 0.47118161086525234, 0.40041917509266306, 0.6317548059991428, 0.9285979717969894, 1.197055955018316, 1.5251649831022536, 1.0861813787903105, 1.265249701482909, 1.604316690138408, 0.884380287357739, 1.2748412553753172, 1.1814829792295183, 0.7133356684020588, 0.6552624074476106, 0.5451150579111916, 0.9807430080005101, 0.7011522193040166, 0.6446538109864507, 0.6004587624754224, 1.1087824574538638, 0.42721433298928396, 0.7364485796008791, 0.5159821840269225, 0.19079609481351717, 0.08128986587481839, 0.07247688341885805, 0.04230975931776421, 0.018623894845534648, 0.08885574846395425, 0.46584658856902805, 0.9123898872307369, 8.960347396986824, 30.821726049695695, 60.37726102556501, 59.68579714638846, 53.39244195393154, 32.152771609170095, 27.950641802379064, 32.37055941990444, 29.3189731325422, 63.16875539507185, 107.60084560939244, 88.20307322910854, 89.94085243770054, 87.24629238673619, 92.74467985970634, 87.07583223070417, 26.532573529652186, 0.17972248473337718, 0.1889767117266144, 0.11452221763985497, 0.03897393528105957, 0.1091439523068922, 0.03628277379487242, 0.052620339806058576, 0.0262814220706267, 0.04804987719814692, 0.021635233258296336, 0.06394928600639105, 0.06944100239447185, 0.045900441107473204, 0.03479921804474933, 0.05486482508214457, 0.05552309565246105, 0.04533346742391586, 0.055557592372809134, 0.026831240692575063, 0.03376556493874107, 0.05250683446813907, 0.06638003593044621, 0.025036128803289363, 0.06849837476121527, 0.020339743666616932, 0.0048184612200462395, 0.02292096382007003, 0.029560279699840715, 0.026600942514570694, 0.0018911002095722193, 0.062973966555936, 0.02530058952314513, 0.023374128521287015, 0.06544705027980463, 0.04111330869740673, 0.027452096841963272, 0.0485292757595224, 0.04310950443946889, 0.016220230343086377, 0.03895385064450758, 0.012409630264820797, 0.02717637922614813, 0.020101594838446805, 0.024256322433107665, 0.02150387905671128, 0.03259614376085145, 0.01738796875412975, 0.04094240268958466, 0.018910806592819945, 0.03270892306630101, 0.046980319411626885, 0.08195233318422522, 0.14408452276672634, 0.12049039453268051, 0.21846654931349413, 0.09723764405186687, 0.10797876518751894, 0.13302271919591085, 0.11980131507984229, 0.1445518434047699, 0.11193293479404279, 0.20486536914748804, 0.12532475298004492, 0.1245374216565064, 0.08097308501601219, 0.17522134126297065, 0.13037229355956825, 0.14540872456771986, 0.15010258555412292, 0.1595049910247326, 0.13352609718484537, 0.08849051341946636, 0.08880255131849221, 0.1222073459731681, 0.1515244556857007, 0.12548202382666723, 0.13855786861053535, 0.1496231191392456, 0.13355702481099538, 0.10231837856450252, 0.10735118136342083, 0.20003210992685386, 0.10224318331373589, 0.18254011496901512, 0.11371381780398743, 0.07017550976680857, 0.14374562166631222, 0.10960587180618729, 0.08831334792609725, 0.14194241485425405, 0.08183029187577111, 0.21474417405469076, 0.20788385931934628, 0.1758400702050754, 0.17738779501191207, 0.14561300432043417, 0.24694079639656202, 0.13211904625807488, 1.8062066967998232, 25.688131162098475, 88.28991181509835, 106.27922180720738, 83.4180850982666, 85.16034589494977, 89.11505208696637, 53.48205981935774, 31.35427073069981, 47.05048411233084, 68.78490093776158, 98.65959099360875, 91.4831371307373, 76.87279169900077, 48.52880368913923, 23.21928334236145, 8.6102545942579, 1.7635012226445335, 0.6653533088309425, 0.6398392521909305, 0.14628049278897898, 0.43311310932040215, 0.5032993874379567, 0.40184933692216873, 0.4052270028207983, 0.6284216791391373, 0.7452499930347715, 0.19397310433643206, 0.484984533063003, 0.5629377301250185, 0.26093973379049984, 0.30852618174893515, 0.2970164907830102, 0.4991632008126804, 0.8301214245813233, 0.5101555223975862, 0.398549241146871, 0.3576875366270542, 0.42943075405699865, 0.4084905119878905, 0.45224239570753916, 0.6255301428692681, 0.33650275053722517, 0.2464422902890614, 0.21868699177035264, 0.3854241211499487, 0.35221417461122784, 0.4976915940642357, 0.5292136711733681, 1.0120160898991992, 0.42609013617038727, 1.1379647829702921, 0.49671569785901476, 0.48051108739205767, 0.17405426103089536, 0.26801544268216404, 0.26005614548921585, 0.19554647776697362, 0.30860413185187746, 0.46905470213719774, 1.9868584488119398, 17.65672925540379, 45.69785744803292, 81.35274001530239, 81.62248992919922, 120.87526784624372, 82.77564076014927, 50.799388136182515, 41.63807364872524, 25.254101514816284, 49.05468157359532, 91.63282217298234, 79.60285704476493, 85.31693744659424, 87.9543068749564, 100.91765826089042, 96.22637353624616, 26.994918823242188, 0.24091665393539838, 0.2394895048013755, 0.26788288408092087, 0.11496706519808088, 0.2480075348700796, 0.19833126690770897, 0.144007481900709, 0.08984920515545777, 0.18063630855509213, 0.10968035459518433, 0.2276671856109585, 0.18186113211725438, 0.2609700235937323, 0.18812319609735692, 0.1084089292479413, 0.18141875442649635, 0.07946434204599687, 0.11714856885373592, 0.11895204707980156, 0.10691339056938887, 0.13723752088844776, 0.19627974342022622, 0.16133487783372402, 0.15152251507554734, 0.1038298492452928, 0.12725800781377725, 0.09304456226527691, 0.13678147750241415, 0.15580620164317743, 0.13718893778111252, 0.1508210048611675, 0.10530088602432183, 0.13981228987021105, 0.16709003544279508, 0.10083168119724308, 0.12768122367560863, 0.14973659733576433, 0.1433308603508132, 0.14033530466258526, 0.14095045093979153, 0.11677285044320992, 0.12095025128551892, 0.14886504624571117, 0.12946308377598012, 0.07870474244867053, 0.22803026969943727, 0.042286455032548735, 0.1154440346040896, 0.12554999946483544, 0.19557599404028483, 0.15141788497567177], [0.08933286714766707, 0.012189538949834449, 0.011765566521457263, 0.0399270768144301, 0.027101216205794896, 0.031023062100367885, 0.038125400098838975, 0.019651670141943862, 0.009934782349903668, 0.007711886361773525, 0.017619696944685917, 0.027792539913207293, 0.053660849508430274, 0.044850106218031476, 0.0042154458767202285, 0.013005188084207475, 0.03820691251062921, 0.05989044558789049, 0.003474975665864934, 0.03685804596170783, 0.060202279926410744, 0.0029849684215150774, 0.03450879148606743, 0.06210080733788865, 0.017389537866360376, 0.027285511405872445, 0.09149136168083974, 0.025905437335105877, 0.06151523840214525, 0.04811895884839552, 0.05508974587012615, 0.09024884192539112, 0.04425932952601995, 0.03812544420361519, 0.047225335014185736, 0.01142814547555255, 0.03318124111475689, 0.035310789344034026, 0.05870194400527647, 0.047158879294459305, 0.04289984390405672, 0.06513317355087825, 0.031058244141084806, 0.12889045450304235, 0.04697424991588507, 0.01749626124676849, 6.867127878325326, 48.64067663465227, 79.36490903581891, 67.18385532924107, 67.58778190612793, 60.623123032706125, 38.25957114355904, 26.504389899117605, 34.57256514685494, 52.712856020246235, 59.42068862915039, 83.59657042367118, 49.33405474254063, 28.951076439448766, 8.920051319258553, 2.1058624173913683, 0.20753878355026245, 0.16708449859704289, 0.15354163173053945, 0.03575008987848248, 0.16426551129136766, 0.1677924006112984, 0.05480119885344591, 0.05909786240330764, 0.06906999301697526, 0.03595471568405628, 0.06191368095044579, 0.11217644744153533, 0.22471553113843712, 0.17401148618331977, 0.0568054080940783, 0.0821511982274907, 0.6450163658176149, 0.37186902708240915, 0.4429559111595154, 0.08978965692222118, 0.5816386437841824, 0.7053223326802254, 1.7768259133611406, 2.7879327663353513, 1.3234327222619737, 0.6497103625110218, 0.0855023537629417, 0.05904563556292227, 0.07168588800621883, 0.15501470411462442, 0.050106170786810775, 0.1194021464990718, 0.18921445682644844, 0.010445750601190542, 0.04404665629512497, 0.0461572835754071, 0.02876425634271332, 0.04717433632218412, 0.10764154006860085, 0.08076258309717689, 0.11480218118854932, 0.2383101023733616, 0.15641490183770657, 0.15266781433352403, 0.10496321985764162, 0.041866804872240336, 0.20843652609203542, 0.2120810326720987, 3.1885778393064226, 19.544400215148926, 42.88217987333025, 55.32505907331194, 56.26342371531895, 72.08141817365373, 68.33257320949009, 31.98969391414097, 19.581168345042638, 32.95352022988455, 44.51966878346035, 65.99395547594342, 66.58626161302838, 67.92442907605852, 72.44316918509347, 30.313441004071915, 1.5998399874993732, 0.2956473156809807, 0.12961542845836707, 0.06431908759155444, 0.015032985746594412, 0.05779830499419144, 0.01792776880652777, 0.022403149998613765, 0.057640952723366876, 0.025329013355076313, 0.03439329464786819, 0.07124963748667922, 0.04576471374769296, 0.048686695883848836, 0.03276454258177962, 0.023269243970779434, 0.06057183723896742, 0.03819710089425955, 0.04454535239243081, 0.03876191005110741, 0.0568479793811483, 0.027820534571739178, 0.0407185268455318, 0.08512761922819273, 0.035882020834833384, 0.0502861827345831, 0.04299302711816771, 0.02540868693696601, 0.02887853521055409, 0.033657060403909, 0.03784404216068132, 0.00657723967950525, 0.034989876206964254, 0.042337952447789054, 0.04698577822585191, 0.017439761332103183, 0.08368877893579857, 0.04704565554857254, 0.0717229088768363, 0.05174080914418612, 0.05634445889985987, 0.09105293984924044, 0.1334379690566233, 0.017649554181843996, 0.030545156316033432, 0.03535419183650187, 0.088082944575165, 0.031159915828279088, 0.030014301051518748, 0.014505614759400487, 0.05062363177005734, 0.019758249333660518, 0.023979502197887217, 0.059293782604592185, 0.05963807127305439, 0.04531677546245711, 0.034864065636481555, 0.020494147702785473, 0.022609821587268795, 0.0195823713604893, 0.04002946774874415, 0.022933917053576027, 0.013100368735779609, 0.025293458120099137, 0.050943693345678706, 0.04247275021459375, 0.03505734294386847, 0.04680732012327228, 0.046610616214041195, 0.07193351936127458, 0.020857292859415923, 0.0420723025953131, 0.04134613781103066, 0.01455418938504798, 0.04774698595117245, 0.09105484653264284, 0.05605538262586508, 0.009507704775647392, 0.10429932762469564, 0.0723965313019497, 0.023828355129808187, 0.03657288822744574, 0.008936458865978887, 0.05819926490741117, 0.06125369029385703, 0.03690945856007082, 0.034285495789455514, 0.08730432564126593, 0.02666686728064503, 0.043357441135283024, 0.051090314585183344, 0.11901017038949899, 0.011552657499643309, 0.12328819797507354, 0.05111590214073658, 0.003988095933371889, 13.300927008901324, 65.44959190913609, 96.40394169943673, 78.03096607753209, 85.15805993761334, 91.32829652513776, 64.38109792981828, 44.297937870025635, 30.591848373413086, 23.46407185282026, 41.401772362845286, 71.40585177285331, 51.324970722198486, 33.98334053584507, 11.771730984960284, 2.006737244980676, 0.2684654471065317, 0.29418908964310375, 0.10344571700053555, 0.05388931564188429, 0.2443351676421506, 0.0922071279159614, 0.13309484746839317, 0.2922800992216383, 0.2991300459418978, 0.4343228286930493, 0.38810913850154194, 0.7028875861849103, 0.8550797338996614, 1.023681898202215, 0.8583821366940225, 0.8748527871710914, 2.227750974042075, 2.003614898238863, 1.905329155070441, 1.2074005199330193, 4.451449411255973, 4.717944528375353, 8.293923957007271, 10.120901533535548, 5.43656587600708, 3.821603459971292, 1.7434656577450889, 2.178205758333206, 1.326576890689986, 2.1859564738614217, 1.9800600707530975, 1.679672075169427, 1.247729818735804, 0.9242693526404244, 0.5784503434385572, 0.7536295748182705, 0.6688839708055768, 0.6047623572604997, 0.5464098112923759, 1.2852460741996765, 0.6658870173352105, 0.4275408983230591, 0.17393226043454238, 0.17748243707631314, 0.3848887298788343, 0.12031268621129648, 0.2510831169784069, 0.06796124644045319, 2.7343180775642395, 23.351274796894618, 51.246265002659385, 45.24047143118722, 35.0681106703622, 41.442454065595356, 36.93132223401751, 31.964166232517787, 33.757840224674766, 59.56800433567592, 70.08685438973563, 89.01509530203683, 82.4342132295881, 77.89339174543107, 88.08965083530971, 47.25649125235421, 5.38576021364757, 0.16204524971544743, 0.2576449577297483, 0.14876395809863294, 0.029492826533636878, 0.07173235408429589, 0.048379197384097745, 0.06064771781010287, 0.029214097918676477, 0.028775482704596858, 0.0753894882010562, 0.0454346573512469, 0.03421159314789942, 0.04770031970526491, 0.03002636201147522, 0.03296946015741144, 0.03988132319812264, 0.08218174587403025, 0.04464393335261515, 0.04931269872135349, 0.024469921864303093, 0.022901074262335896, 0.0176417204950537, 0.0877355889284185, 0.03137810894155076, 0.027355848345905542, 0.03911166771181992, 0.051289854770792384, 0.0284661114481943, 0.033293379204613824, 0.0345926482363471, 0.06219965631940535, 0.035265398743961535, 0.024941279785707593, 0.011182373306447906, 0.022749180805736353, 0.051501455916357894, 0.015442607159327184, 0.02475862155136253, 0.03851160526807819, 0.032277517286794524, 0.013251794851385057, 0.06541772399629865, 0.028789888003042767, 0.013970414326260132, 0.04065443242767027, 0.0380723725871316, 0.02795000414230994, 0.01691418337369604, 0.007487064809538424, 0.15888304582663945, 0.10101497386183057, 0.08887784834951162, 0.2736629710665771, 0.12789941339620522, 0.11944102655564036, 0.11503821638013635, 0.13055248531912053, 0.10156233449067388, 0.12268933653831482, 0.15193407370575837, 0.09189519179718834, 0.07082530882741724, 0.14653383062354156, 0.13852690027228423, 0.10766919715596096, 0.08695459512195416, 0.2177128190440791, 0.08976609140102353, 0.12511743339044706, 0.13861639904124395, 0.145761888474226, 0.17426717174904688, 0.15329719627542154, 0.21138976833650044, 0.26462792445506367, 0.1634136512875557, 0.0469653000389891, 0.1629636740045888, 0.20296935231557914, 0.19644916004368237, 0.20351444663746016, 0.12667005722011837, 0.10999556125274726, 0.09963036887347698, 0.10477905866823026, 0.17479847823934896, 0.243649494435106, 0.1837524263454335, 0.1642312995557274, 0.16546486264892987, 0.2715291955641338, 0.09641644026019744, 0.304941535528217, 0.12770630232989788, 0.09878808299877814, 13.34398238999503, 73.3468518938337, 109.56433704921177, 84.12524495806012, 86.61907155173165, 82.08775520324707, 48.82062108176095, 32.96659326553345, 50.065873759133474, 82.51051139831543, 82.23678016662598, 112.57230949401855, 72.21575464521135, 47.18182243619646, 16.557388748441422, 3.813379398414067, 0.47234879966293064, 0.6167090247784341, 0.2698607050946781, 0.12203859431403023, 0.5784244505422456, 0.35586510013256756, 0.21519288926252297, 0.17244692013732024, 0.19310614014310495, 0.3115255779453686, 0.2567662548805986, 0.5149510822125843, 0.4237916666482176, 0.41633481106587816, 0.32087720185518265, 0.3654714732297829, 1.1211650158677782, 1.3179969510861804, 0.9827763331787926, 0.46173477492162157, 2.5898917359965186, 1.8210014743464333, 4.642340745244708, 6.048287017004831, 4.10313708441598, 2.7134428662913184, 0.598197449530874, 1.2185876624924796, 0.49924109663282124, 0.8993272738797324, 0.6756786576339177, 0.5783161563532693, 0.3850392560873713, 0.3846178044165884, 0.2661100620669978, 0.3428836395697934, 0.30626516735979487, 0.280488626233169, 0.29204014209764345, 0.6952417993119785, 0.41179174770201954, 0.566628526364054, 0.3367645836302212, 0.48799939985786167, 0.457533774631364, 0.21426538617483207, 0.5463357152683395, 0.44263490981289316, 6.476289102009364, 33.231076444898335, 67.39929812295097, 81.64719772338867, 77.63507161821637, 100.65676730019706, 95.50051607404436, 46.34959500176566, 26.591958045959473, 41.9969550541469, 53.05261598314558, 82.29997403281075, 84.35289573669434, 84.79696205684117, 102.75412968226841, 52.113045828683035, 4.443092465400696, 0.5471827441028186, 0.3047706532691206, 0.28122236686093466, 0.17172016842024668, 0.25666645595005577, 0.10895686663155045, 0.0908093254214951, 0.12357847525605134, 0.07224168961069413, 0.1606883289558547, 0.19495471380650997, 0.15598309572253907, 0.14821540324815682, 0.11823988386562892, 0.13148355750100954, 0.11241203480001007, 0.1547122403447117, 0.11550575414938585, 0.12748837045260838, 0.15187597753746168, 0.0863043007307819, 0.1143948837582554, 0.2503054072814328, 0.1769717037677765, 0.12404097829546247, 0.11239139376474278, 0.10951113474688359, 0.09052841870912484, 0.12057656848004886, 0.09900737194610493, 0.14437820629349776, 0.2500738368502685, 0.17734123393893242, 0.12404739723673888, 0.06795648312462227, 0.1317027107413326, 0.09549403975584678, 0.1649474118437086, 0.09823823893176657, 0.12704329219247612, 0.14684549532830715, 0.2199043785887105, 0.06138341940407242, 0.08685321520481791, 0.1570367927529982, 0.13465623797050544, 0.1770261222762721, 0.11028784699738026, 0.151529124006629], [0.030934224903051342, 0.015182058193853923, 0.01760629757440516, 0.057747285946139267, 0.02012042248887675, 0.0515860420917826, 0.029603112222892896, 0.0529514173977077, 0.05023855296894908, 0.03431270504370332, 0.05483034871784704, 0.05610983506111162, 0.05509266017803124, 0.03620564132662756, 0.01264552296405392, 0.06759935657360724, 0.08790624727095876, 0.053550404363444874, 0.04520626924932003, 0.03142980652462159, 0.07941894805324928, 0.06247206777334213, 0.05213138407894543, 0.03432313412693994, 0.1288234152431999, 0.027847496160705174, 0.026491220009380152, 0.008919796590427203, 0.04603987326845527, 0.07341747544705868, 0.0370522460767201, 0.07084700159196343, 0.06477495455848319, 0.014395008462348154, 0.02738627724881683, 0.04448779905214906, 0.07539818701999527, 0.04846215846815279, 0.017722337240619317, 0.04176852246746421, 0.0633118294977716, 0.11237162803964955, 0.034871719511491914, 0.3155163952282497, 0.9691737145185471, 30.90749113900321, 82.95541150229317, 78.7029333114624, 61.91725281306675, 79.60846424102783, 69.70878205980573, 23.661072390420095, 41.382897581372944, 54.094995158059255, 47.0402181489127, 54.69849484307425, 43.607557909829275, 21.213458265577042, 5.782654779297965, 0.0811446797368782, 0.1448103381054742, 0.22468388426516736, 0.010457243288068898, 0.03386722984058516, 0.14615957784865583, 0.10979839933237859, 0.16735808391656193, 0.15304191783070564, 0.14546782496784413, 0.21999486801879747, 0.14240738776113304, 0.37504101544618607, 0.34605394516672405, 1.2424494049378803, 0.2998080109911305, 0.8354548726763044, 0.537858207310949, 1.3436138736350196, 0.7383604198694229, 3.4856057294777463, 2.990544408559799, 1.9685403917516981, 7.758345518793378, 8.523397769246783, 10.06324017047882, 12.192825692040579, 4.491418055125645, 6.546481106962476, 4.6422282712800165, 3.306464884962354, 3.7008650473185947, 3.0673315567629675, 4.6833841885839185, 1.5613559782505035, 1.8885268909590585, 1.8009130379983356, 1.0802764956440245, 0.4453098848462105, 0.8537375373499734, 0.3571297808417252, 0.03259798259075199, 0.17218415066599846, 0.04853932825582368, 0.10088738213692393, 0.09375118184834719, 0.09143610178892102, 0.16043245340032236, 0.10299679144684758, 0.19561944742287907, 0.06974919299994196, 0.11116483993828297, 0.15261121094226837, 1.958373440163476, 24.732665266309464, 52.07690477371216, 59.778791836329866, 83.68672330038888, 60.860577719552175, 54.7862297466823, 30.54131065096174, 33.6791866166251, 48.70055273600987, 55.45097085407802, 60.023972920009065, 65.11673845563615, 78.76502241407121, 62.602637018476216, 22.157404048102244, 0.7380865631358964, 0.19327333117169992, 0.030279133269297223, 0.054570028757942576, 0.0640635241621307, 0.07649800407567195, 0.006645675873317356, 0.05561808037704655, 0.05820977541485003, 0.008299492598910416, 0.03987163032538124, 0.044597477452563386, 0.033588436764797995, 0.019450124885354723, 0.031841032672673464, 0.013058716015491103, 0.012213273256617998, 0.10700831083314759, 0.06227443766381059, 0.03798287721084697, 0.022515970016164438, 0.07718705638710942, 0.018103336349927952, 0.04077441777501788, 0.04586381378716656, 0.04928848519921303, 0.037189211762909374, 0.0082145442554195, 0.03416083872850452, 0.02614687366544136, 0.04118554214281695, 0.044915262543197186, 0.06575398559549026, 0.02818232774734497, 0.023699033140603985, 0.03219397605529853, 0.011327215936034918, 0.036484709209097285, 0.043049722111650875, 0.008652928767592778, 0.012562812089786997, 0.0202826279814222, 0.015930076894749488, 0.041779664012470415, 0.026668896100350788, 0.06404516978987626, 0.03041212274027722, 0.007479788369632193, 0.026501437050423453, 0.01123338726548744, 0.04092861825068082, 0.038732515914099555, 0.012464667088352144, 0.10866446553596429, 0.015146253597257393, 0.0114426924181836, 0.05193014755578978, 0.004320080641524068, 0.019950910870518004, 0.0679575212832008, 0.09570935248796429, 0.011418776603282561, 0.057162049492555, 0.028238250907244425, 0.08029124553182296, 0.049464928052787266, 0.00778607144353113, 0.055236387465681346, 0.039816658810845444, 0.026028455733986836, 0.04446530222360577, 0.029640404507517815, 0.05094089438872678, 0.016309418682275072, 0.026824572389679294, 0.048296059880937846, 0.07275843473949603, 0.07794175017625093, 0.019293398563084856, 0.03863124795524137, 0.04458355391398072, 0.009116428405312555, 0.026269206743953482, 0.029236231730984788, 0.021266983821988106, 0.10414678616715328, 0.03773327810423715, 0.03621672858883228, 0.045306980809462924, 0.07934717940432684, 0.06787425146571227, 0.17236321605741978, 2.8554369040897916, 48.602260044642854, 104.67609173910958, 90.89102554321289, 80.41762365613664, 118.91424996512276, 97.55038057054792, 36.144914695194785, 27.755147286823817, 25.165173258100236, 27.181778464998516, 46.12818023136684, 46.98155450820923, 27.361066307340348, 6.23520702123642, 0.16478763041751726, 0.7727606253964561, 0.3710674600941794, 0.08645528834313154, 0.08853393966065985, 0.42906415515712326, 0.44027778772371157, 0.5581616035529545, 0.5153159712042127, 1.2612033528941018, 1.597964625273432, 1.6452450539384569, 2.268290021589824, 4.3719563739640375, 4.903837936265128, 2.374691043581281, 3.6591359036309377, 5.62692437001637, 7.579957468169076, 4.8415807741028924, 6.384304506438119, 7.06362076316561, 5.685657058443342, 8.444792798587255, 12.039201021194458, 12.753349031720843, 12.935447420392718, 9.729450447218758, 9.923414622034345, 8.419422319957189, 8.686676962035042, 10.296193293162755, 10.184190937450953, 6.518876782485417, 4.883829295635223, 5.303141355514526, 7.401438270296369, 6.281683955873762, 3.1839679266725267, 4.016932087285178, 1.9872586216245378, 1.5295646041631699, 1.0643918280090605, 0.5590569983635629, 0.7540655199970517, 0.3739936016499996, 0.3373202495276928, 0.5199684415544782, 0.31186099137578693, 0.6806221380829811, 0.13330196349748544, 0.16337804176977702, 0.29588303874645916, 1.4548064385141646, 25.547164372035436, 53.58406284877232, 53.414853368486675, 72.19907202039445, 40.32599319730486, 35.52182456425258, 20.715671948024205, 43.204472064971924, 79.35720348358154, 83.80824034554618, 82.7444989340646, 79.20608711242676, 90.84754371643066, 87.97811835152763, 40.39486721583775, 3.6630538191114153, 0.14261397453291075, 0.055969690438359976, 0.07841958810708352, 0.10538047818200928, 0.020988016023433635, 0.0852524968130248, 0.021559919263901453, 0.055133949033916, 0.02804967075852411, 0.03383895867903318, 0.03083323175087571, 0.015738892867895107, 0.012445523919138526, 0.019061137722539048, 0.029041095237646784, 0.026749874165813838, 0.024713543077398623, 0.02037106653941529, 0.09542248823813029, 0.019002558098041585, 0.03294516521106873, 0.029142984056047032, 0.0329581320152751, 0.055509687800492556, 0.11930154689720698, 0.038478411334965906, 0.018780439659687023, 0.011500295800422984, 0.0432861644242491, 0.07638046145439148, 0.024540170594783764, 0.05634582614792245, 0.01962216235032039, 0.038073709301118336, 0.023229347808020454, 0.010588271792845001, 0.046604482257472615, 0.009463072438458247, 0.07194897638899939, 0.021865180294428552, 0.03167761090610709, 0.038795412717653174, 0.023235010182751075, 0.0300468062715871, 0.0651717007692371, 0.03177255152591637, 0.03327303672475474, 0.12494413554668427, 0.1411620317293065, 0.15578115013028893, 0.16716850123235158, 0.08289910666644573, 0.18991823334779057, 0.1544483309345586, 0.10847673525235482, 0.1271508535636323, 0.08466989986066308, 0.0914063887404544, 0.17664464988878795, 0.12317619898489543, 0.11049303598701954, 0.1066459392064384, 0.17396833135613374, 0.1798258934702192, 0.17363973041730268, 0.12601251607494696, 0.07916172221302986, 0.11624903497951371, 0.113590236221041, 0.15776194312742778, 0.14303910386349472, 0.2610539990876402, 0.13504009880125523, 0.08959944320044347, 0.17899506805198534, 0.22018321576927388, 0.15941769070923328, 0.18559349541153225, 0.10986434615084104, 0.14690922333725862, 0.07815179069127355, 0.1050605760621173, 0.10808939353695937, 0.14952478584434303, 0.17214117225791725, 0.10169221966394357, 0.11711365144167628, 0.11096553384725537, 0.22678149385111673, 0.16176376624831132, 0.30703459892954144, 2.5186396964958737, 54.66159643445696, 118.3327135358538, 100.53620215824672, 79.29608018057687, 102.3530866077968, 88.16867269788469, 32.62409223828997, 58.434357098170686, 80.81769398280552, 71.5210737500872, 83.2566020148141, 63.85136726924351, 34.59006765910557, 11.451168894767761, 0.2910336303923811, 0.9483782989638192, 0.5871012306639126, 0.19680720940232277, 0.3877149096557072, 0.45199052350861685, 0.32011973964316504, 0.35504787255610737, 0.23539131613714354, 0.566581517457962, 0.5076265952416829, 0.563758866063186, 1.070647052356175, 2.9177733191422055, 3.4865574155535017, 2.136177624974932, 2.4291864165237973, 3.465026685169765, 5.53303553376879, 6.922407746315002, 9.581131594521658, 8.474575383322579, 10.41497448512486, 18.499877520969935, 21.28432641710554, 25.724091563905986, 27.79945421218872, 14.983758994511195, 16.82007234437125, 10.427262374332972, 13.426548702376229, 11.368389793804713, 8.107701812471662, 10.937536341803414, 3.889476937907083, 5.1059592962265015, 5.257696662630353, 4.844013946396964, 1.5778904110193253, 1.8934507753167833, 1.187164000102452, 0.4986742213368416, 0.31012657444391933, 0.20992038718291692, 0.4005055661712374, 0.21571712541793073, 0.22849221634013311, 0.2234600242227316, 0.3307788462511131, 0.6199004735265459, 0.24869651932801518, 0.33453782168882235, 0.33479284229023115, 3.453264036348888, 39.42098685673305, 78.19872338431222, 84.78893688746861, 111.81592859540666, 84.17698124476841, 74.75207642146519, 41.859488419124055, 45.4165700503758, 58.00494105475289, 71.5620333807809, 80.38072872161865, 82.17337785448346, 102.51484067099435, 97.96256160736084, 42.20503970554897, 2.334199982030051, 0.3542950243822166, 0.08968022279441357, 0.13721271364816598, 0.17027104832231998, 0.16115133411117963, 0.1613989043980837, 0.19020351661103113, 0.19949287814753397, 0.08750019155974899, 0.16744053949202808, 0.0788811683388693, 0.15306243672966957, 0.06958221910255295, 0.13421339887593473, 0.12351134100130626, 0.1573024663541998, 0.18046254930751665, 0.1283538690102952, 0.1601174095911639, 0.10126702247985772, 0.30940436891147066, 0.0819586164184979, 0.0983508350327611, 0.10040387843868562, 0.19356218352913857, 0.21378866104143007, 0.08868297987750598, 0.1445046037967716, 0.12598660960793495, 0.21249663537102087, 0.16091452538967133, 0.18528634974999086, 0.13441679653312477, 0.09888054696576935, 0.13240240248186247, 0.08483192723776613, 0.24845143247927937, 0.1155229482267584, 0.16788459994963237, 0.11639794627470629, 0.09678823673831564, 0.0883848180196115, 0.09408270727310862, 0.11458597279020719, 0.15266625370298112, 0.09335865612540926, 0.09047940133937768], [0.014505981168310558, 0.029910257884434292, 0.0028818005646046784, 0.038927876323993714, 0.0741886372811028, 0.06215857780937638, 0.04339724060680185, 0.029574562861983265, 0.029886821284890175, 0.03958509855770639, 0.037641095729278665, 0.06177302064107997, 0.027511575525360446, 0.06319271946059805, 0.024096396818224872, 0.02891812433621713, 0.02035333133036537, 0.01989587489515543, 0.06272785511932202, 0.03136150858231953, 0.03886529503922377, 0.026372388171564256, 0.04656234862548964, 0.01143856522893267, 0.043711897650999684, 0.009900361964745181, 0.018241569200264554, 0.018151766786883985, 0.009042246716230043, 0.08127285500190087, 0.04668132634833455, 0.05157072077106152, 0.018818722605439167, 0.025995845340990593, 0.03710159253595131, 0.03867399566141622, 0.05328949068539909, 0.03500018993924771, 0.06045856260295425, 0.10897885116615466, 0.03080670103164656, 0.27617585765463964, 0.5145860303725515, 19.35950517654419, 58.71826049259731, 83.96314348493303, 61.126005853925435, 67.24473544529506, 61.599226815359934, 31.2691969871521, 34.4158797945295, 47.52858965737479, 58.17019353594099, 60.52335384913853, 51.91066912242344, 34.34873240334647, 9.660375799451556, 0.4772232866712979, 0.31210024282336235, 0.05098814756742545, 0.21107403242162295, 0.15255496038922242, 0.07826307721968208, 0.0260091955174825, 0.014135808085224457, 0.08558057527989149, 0.10420219533677612, 0.09122267538415534, 0.5322429771934236, 1.2237190157175064, 0.8770930926714624, 1.4400122037955692, 1.9265337543828147, 1.7874727249145508, 1.9411510271685464, 5.195548066071101, 4.345988350255149, 4.7940429363931925, 6.441572427749634, 4.405396750995091, 4.908155807426997, 4.169131074632917, 8.643054434231349, 13.333785908562795, 17.38829949923924, 20.101260117122106, 6.389549962111881, 5.60143620627267, 6.125388136931828, 4.233932146004268, 5.954706507069724, 11.442436746188573, 8.083929419517517, 6.57443197284426, 8.53604175363268, 4.197576131139483, 6.289371269089835, 4.155534752777644, 4.3966811043875555, 2.635679713317326, 1.9676284406866347, 3.7385355745043074, 1.7416442526238305, 0.986067607998848, 0.3169733184788908, 0.24203357685889515, 0.4736642347914832, 0.15070967083530767, 0.1085959334990808, 0.08278756229473011, 0.05614070501178503, 0.2933770189327853, 0.22186143643089704, 0.5801790335348674, 1.6436405628919601, 24.64402883393424, 39.62441621507917, 61.1490113394601, 68.3178082874843, 86.48489488874162, 71.38593128749302, 25.955883468900407, 23.156181539808, 44.86838844844273, 59.801123346601216, 52.14841563361031, 55.18856518609183, 63.9772686277117, 52.87468303952898, 10.616387128829956, 0.1858513115772179, 0.0269932528026402, 0.022253643288942318, 0.07234382948705129, 0.022418378020769784, 0.08101751548903328, 0.031055594461836984, 0.07591666241309472, 0.020663338713347912, 0.048178334055202346, 0.023585156304761767, 0.011458236807292061, 0.17438792384096555, 0.03529289298291717, 0.047759786514299254, 0.014532374484198434, 0.012030915274018688, 0.05279127974063158, 0.048487254085817506, 0.004511036935062813, 0.08594919621412243, 0.03527893212490848, 0.08649773070854799, 0.013715799997693725, 0.014333594257810285, 0.05341461932818804, 0.01945795857214502, 0.012839072533617062, 0.025030615706262842, 0.013446618370445711, 0.04450811778328248, 0.046217591767864566, 0.0383488925706063, 0.016742385092324445, 0.020848619485540048, 0.037088048976979086, 0.05259713730109589, 0.0832714324018785, 0.03832077407943351, 0.017800780977787714, 0.02240344346500933, 0.04503406384693725, 0.020714642746107917, 0.023795522516593337, 0.02980087125407798, 0.028145943003307496, 0.016831744761605347, 0.09641480499080249, 0.03225025714242032, 0.016272555571049452, 0.04520362974809749, 0.018150877906009555, 0.023104397280673896, 0.04404991665588958, 0.04060395620763302, 0.051682923321745226, 0.04582002792241318, 0.0669234881975821, 0.06867657841316291, 0.07890748871224267, 0.019381350272202065, 0.051424418443015645, 0.06884132671569075, 0.028295687200235467, 0.06990737986883946, 0.031801823526620865, 0.010602213991140681, 0.013108176129337932, 0.05157878855243325, 0.04886911663093737, 0.014337670556934816, 0.026430687900366526, 0.12589090902890476, 0.0067392734178741065, 0.039116621017456055, 0.03391502923997385, 0.06310545307184968, 0.027172754152811, 0.025840084234784757, 0.0318400114774704, 0.06530020173106875, 0.03810713054346187, 0.02450283250904509, 0.09092696982302836, 0.023802611511200666, 0.10894765891134739, 0.028172383816646676, 0.22843568080237933, 1.818825928228242, 30.593338762010845, 78.80872658320835, 97.42516708374023, 70.8141153880528, 99.29530947549003, 90.73485783168248, 42.86213779449463, 37.03628519603184, 26.883259534835815, 39.521687098911826, 51.02011850902012, 56.93247617994036, 40.22539717810494, 12.367704033851624, 0.28236355419669834, 0.4566078728863171, 0.16216537755514893, 0.22694173668112072, 0.17976587026246957, 0.16846288820462568, 0.41118668445519035, 0.26730653643608093, 0.6503905260137149, 0.9119273977620261, 1.6308283018214362, 2.366203167608806, 3.85730026449476, 5.634557834693363, 2.2275184265204837, 3.9187744515282765, 8.389805623463221, 4.044108663286481, 5.012872976916177, 6.781042737620218, 8.365598099572317, 8.788389904158455, 9.397779056004115, 8.36363697052002, 8.829376459121704, 14.269738657133919, 19.768328496388026, 17.57326923097883, 19.588731459208898, 11.330882549285889, 8.190805741718837, 6.270294555595942, 10.246663059507098, 5.853657552174159, 13.345785447529384, 17.156828948429652, 13.052482008934021, 15.630261080605642, 12.805874807494027, 10.68721445969173, 5.890728362968989, 6.642638095787593, 2.619121721812657, 3.5175112060138156, 3.6461323499679565, 2.712418006999152, 1.1918620680059706, 0.8541029148868152, 0.7418195913944925, 0.3619703682405608, 0.716707607465131, 0.3987974763980934, 0.1557651502745492, 0.29983401245304514, 0.2597616884325232, 0.20570335989551886, 0.612571752497128, 1.6618284497942244, 25.144451992852346, 40.49611636570522, 41.45497819355556, 48.34700059890747, 46.571082728249685, 38.528414317539756, 18.544478007725306, 37.58046463557652, 70.34960051945278, 79.46255207061768, 72.80971445356096, 63.60886124202183, 75.95747770581926, 73.95123400006975, 23.735673461641582, 0.05671190257583346, 0.113310503374253, 0.0342533739416727, 0.013432248695088285, 0.05325905838981271, 0.10298753622919321, 0.04083300927387817, 0.047654203072722466, 0.042958465936992846, 0.030674929531025033, 0.01784168815772448, 0.026778270856344273, 0.01306499755342624, 0.055341580749622414, 0.015922809784699763, 0.06132951658219099, 0.02775866405240127, 0.008533571065137429, 0.037769464376781664, 0.027430921460368803, 0.09087894989975862, 0.07225760804223162, 0.10027528926730156, 0.033156963131789646, 0.019664163667974726, 0.06859201937913895, 0.04572566405736974, 0.0656620373151132, 0.08448973524251155, 0.009712461199212288, 0.03286705565239702, 0.006469919612365109, 0.027054273456867253, 0.11920237221888133, 0.030237203197819845, 0.07931128490184035, 0.008120931867909218, 0.04732228070497513, 0.015650396634425436, 0.04658020766718047, 0.014064035195458149, 0.04483396726261292, 0.011537370953841932, 0.042359841987490654, 0.06767835840582848, 0.054067614288734536, 0.08786948424364839, 0.12104745821229049, 0.0818771922162601, 0.11026840696909598, 0.18366640167576925, 0.12003754026123456, 0.08623369916209153, 0.14566914630787714, 0.0931217727650489, 0.20857025177351066, 0.20095921946423395, 0.10310312466961996, 0.15723286223198685, 0.20911013494644845, 0.11168362745749098, 0.0882227092183062, 0.20791917028171675, 0.14825615606137685, 0.20554682186671666, 0.07106327784380742, 0.13438232695417746, 0.19358924350568227, 0.1096706244030169, 0.14083583280444145, 0.13023199965911253, 0.11229296547493764, 0.1404525555138077, 0.13599918090871402, 0.15789786726236343, 0.1806895871247564, 0.16378291004470416, 0.118307018120374, 0.21916048707706587, 0.1796146383775132, 0.11364935019186564, 0.15918933653405734, 0.08201104003403868, 0.2151361908763647, 0.14975136225777014, 0.2712286045508725, 0.22360422648489475, 0.34900760810290066, 1.6899632258074624, 33.12111077989851, 91.81602532523019, 108.13078471592495, 75.25755786895752, 84.65701838902065, 79.56976972307477, 38.906365053994314, 45.77733441761562, 75.5945941380092, 90.89693846021379, 94.10429641178676, 77.79032911573137, 54.91454560416085, 18.033556120736257, 1.1769337547676904, 0.8339458650776318, 0.2289195576948779, 0.5308841158236776, 0.40769127916012493, 0.14393398298748902, 0.23134298622608185, 0.21882618644407817, 0.28260201854365213, 0.3832438795694283, 1.1049242530550276, 1.3384240035499846, 3.060863652399608, 6.584052622318268, 5.235618761607578, 6.725694256169455, 7.24780057157789, 8.549763577325002, 13.574422870363508, 14.049445152282715, 18.051529373441422, 16.410863399505615, 16.010765280042374, 15.970380612782069, 17.556664773396083, 24.18987546648298, 35.01872982297625, 36.825699193137034, 40.267326082502095, 21.47936929975237, 17.066184486661637, 24.11767499787467, 20.736884798322404, 21.195917538234166, 25.990570613316127, 23.839941603796824, 21.6989323752267, 24.805506706237793, 19.3329039982387, 20.484425476619176, 13.206196137837, 12.814527051789419, 9.778680171285357, 6.58789758171354, 11.6189991576331, 5.248043009213038, 2.6563047894409726, 1.7047777622938156, 1.6850614888327462, 1.3506167892898833, 0.45508735733372824, 0.1457754863159997, 0.1701186222157308, 0.2503344757216317, 0.5400307135922569, 0.30191754922270775, 0.6588346500481878, 3.721675770623343, 38.059574195316856, 61.476834297180176, 85.57978085109166, 92.32725293295724, 119.84165382385254, 90.28208541870117, 33.4517616544451, 30.161709717341832, 56.85267959322248, 77.13109098161969, 67.63361917223249, 70.17046901157924, 88.90773173740932, 83.87982763562883, 21.439102751868113, 0.2169031910598278, 0.23778282638107026, 0.12285204923578671, 0.13536019091095242, 0.13610237251435006, 0.25133355068308966, 0.22196971704917295, 0.13645089524132864, 0.09527288483721869, 0.09210242317723376, 0.1480523512831756, 0.06318564234035355, 0.3143308859850679, 0.09804400828267847, 0.11083966560129609, 0.10134250950068235, 0.10241490017090525, 0.1312270848346608, 0.12028511054813862, 0.11241756486041204, 0.1987281148987157, 0.09170142933726311, 0.1423909943550825, 0.05983532140297549, 0.1846493003623826, 0.18124856427311897, 0.12510338771556104, 0.13553734283362115, 0.0837393230093377, 0.06863216829619237, 0.12869751985583985, 0.09521868345992905, 0.09836017167461769, 0.21077288500964642, 0.09368929945464645, 0.27748008338468416, 0.13942574204078742, 0.1706529956843172, 0.15623769563223633, 0.1163716326866831, 0.06262120977044106, 0.11956993463848319, 0.12323367090097495, 0.1778075774865491, 0.1302905436605215, 0.09957658140254871], [0.02639490705249565, 0.06013015165392842, 0.02415116477225508, 0.02371598973072001, 0.00932015006297401, 0.027135414370734776, 0.018207430407138805, 0.11220044043979474, 0.04926155414432287, 0.027317348268947432, 0.031961961183696985, 0.037112774793058634, 0.061139906756579876, 0.0632914463058114, 0.03994178066828421, 0.020035451244828955, 0.049595959950238466, 0.04938182108370321, 0.0023768027853553315, 0.05171001043968967, 0.03543812322563358, 0.028430247479783635, 0.028305176512471268, 0.03582171264237591, 0.021088357781991363, 0.05814523994922638, 0.007947489835454949, 0.0478552021086216, 0.06506709781076227, 0.02307262657476323, 0.002646112274045923, 0.02073929731601051, 0.030705497533615147, 0.01263725501485169, 0.019140885943280797, 0.006855982713334794, 0.028711255972406695, 0.0887137446552515, 0.032887048686721494, 0.1676769953753267, 0.2743466358099665, 12.254363281386238, 62.91266563960484, 86.76198904854911, 69.88706588745117, 70.25962829589844, 78.03555188860211, 41.942960602896555, 37.94798960004534, 57.156875201633994, 53.76529966081892, 52.754409721919465, 46.351488385881694, 33.39416108812605, 9.890739849635533, 0.6324494087270328, 0.5544698302234922, 0.06394015971039023, 0.2076006523732628, 0.12324159618999277, 0.13347498992724077, 0.05293214700317808, 0.199154384168131, 0.05373418896592089, 0.7610802150198391, 0.5775657509054456, 2.1834924689361026, 1.9651318660804202, 5.111802731241498, 8.620035920824323, 5.857665794236319, 4.513609298637935, 6.177774080208369, 11.645379730633326, 5.813007116317749, 4.900436793054853, 13.504535283361163, 12.578435948916844, 3.567480913230351, 6.912990765912192, 14.223582642418997, 6.192931575434549, 7.007512756756373, 9.35729103428977, 6.127067429678781, 6.153533552374158, 9.144709161349706, 7.96817764214107, 9.033968772206988, 9.223353215626307, 10.72409723486219, 13.786950026239667, 4.595698356628418, 9.129708869116646, 5.342093825340271, 12.565025925636292, 8.16167802470071, 6.0175186565944125, 10.89722376210349, 4.32325427872794, 6.148992904594966, 5.151133877890451, 6.373444037778037, 3.137127948658807, 4.454129244600024, 4.439093342849186, 4.431023878710611, 0.7360996497528893, 2.7977242980684554, 0.9813653060368129, 0.7901130457009587, 0.04081765741908124, 0.15794463189584868, 0.17456124882612908, 0.12590783169226988, 0.2901105513530118, 7.450591564178467, 40.171041420527864, 56.21664496830532, 56.90621198926653, 69.60296794346401, 93.48111248016357, 46.44951704570225, 28.98374513217381, 40.48142439978463, 43.96391364506313, 60.14487157549177, 70.35998112814767, 61.83205400194441, 66.14898368290493, 22.185684953417095, 0.5773983427456447, 0.21821730983044418, 0.06906738744250365, 0.02537836829599525, 0.041290647217205594, 0.09441702147679669, 0.047941158924783976, 0.043426532963556905, 0.05565715042342033, 0.05164709667276059, 0.04342661438775914, 0.08664584133241858, 0.005608983778594328, 0.04375879120613847, 0.011635117315953332, 0.008236840067963516, 0.008191277289630046, 0.040395469537803104, 0.0530943949041622, 0.029644723382911513, 0.02071476827508637, 0.04393353772216609, 0.08055834405656372, 0.04616441837112818, 0.00910206975614918, 0.020579147784571563, 0.014715024236855763, 0.030062188660459857, 0.04525024849655373, 0.02181498905909913, 0.008658494451083243, 0.03523435576685837, 0.06792780144938401, 0.03469990087406976, 0.0377214546315372, 0.04972248637516584, 0.06620797980576754, 0.054684565469090424, 0.04654051676126463, 0.042627252638339996, 0.06075522489845753, 0.04374671667548163, 0.04775008007085749, 0.030491484196058342, 0.015150867635384202, 0.03132402630788939, 0.057872156745621135, 0.038176154518233876, 0.05332405525924904, 0.026385470326723795, 0.031093792590711797, 0.04019549848245723, 0.06722859825406756, 0.025963146738441925, 0.03305746275665505, 0.09332105171467577, 0.030125170280890803, 0.016113948010440384, 0.049732874746301343, 0.04805751410978181, 0.05892082583159208, 0.019721399793135266, 0.01681846922396549, 0.040067903364875486, 0.03994591633922287, 0.05968733291540827, 0.01064488451395716, 0.01912172750702926, 0.044418520626745055, 0.021918301104700992, 0.017588713339396884, 0.03180444606446794, 0.03385261419628348, 0.02311739292261856, 0.04513448702969721, 0.03076648765376636, 0.044376780545072894, 0.018322377631972944, 0.02473760732183499, 0.02507028286345303, 0.022442766265677552, 0.04914395724024091, 0.12212476826139859, 0.02649177810443299, 0.24903795814939908, 0.5739334172436169, 23.176498072487966, 84.52583639962333, 103.57294014522007, 82.79008606501988, 95.7596630368914, 111.8142957687378, 58.55112852369036, 35.55279963357108, 28.72151664325169, 37.52968372617449, 50.600777353559224, 48.971963269369944, 40.35136801855904, 11.756913951465062, 0.5459151864051819, 0.8164647402507919, 0.049898254086396525, 0.1673904907490526, 0.09672677503632647, 0.45551478011267527, 0.24986514661993298, 0.48681820609739845, 0.6709658248083932, 2.052904333387102, 0.9126241718019757, 2.526611234460558, 1.5065681295735496, 1.9012555565152849, 1.3375707864761353, 0.7984753655535834, 0.7645271729145731, 3.3314914277621677, 5.140352010726929, 2.3189065626689365, 4.556864874703543, 1.0056475230625697, 1.5992294145481927, 4.059644835335868, 9.052833999906268, 25.28104489190238, 13.363073434148516, 12.879213912146431, 17.296633652278356, 15.332412651606969, 7.704794883728027, 2.663769108908517, 1.0948580503463745, 1.3212957169328416, 1.2470757109778268, 2.490874694926398, 6.96144837141037, 8.835817439215523, 17.538177353995188, 9.602110811642238, 7.095797436577933, 4.576718049389975, 1.5159877155508314, 0.09255790337920189, 0.540459927703653, 2.0546461599213734, 1.5334234599556242, 2.3366140467779974, 1.9863277801445551, 0.26061105142746654, 0.9188729907785143, 1.0684196118797575, 1.117204325539725, 1.2819322177342005, 1.3560065286500114, 3.208935192653111, 0.2075641607599599, 0.1744092841233526, 0.026706636218088012, 0.2590584818805967, 0.3496816105076245, 7.593805227960859, 41.55669287272862, 48.77010072980608, 57.67178882871355, 48.37284789766584, 52.70222875050136, 25.76868510246277, 31.570258957999094, 70.10630239759172, 76.64347335270473, 98.39522593361991, 94.16555867876325, 74.1385018484933, 80.3267342703683, 40.445165225437705, 3.2630518887724196, 0.08831596707126924, 0.010726382506878247, 0.02707582033638443, 0.20514523770127976, 0.13789894325392588, 0.05031066427805594, 0.03898618283814617, 0.03781308739313057, 0.030003909287708144, 0.03827183474121349, 0.031421816774777005, 0.01460576822449054, 0.003129618728832741, 0.030640806004937206, 0.02035787751499031, 0.05548874820981707, 0.05576603154518774, 0.05172763538679906, 0.04697703190946153, 0.009637623875668007, 0.023511486061449562, 0.03799673628860286, 0.04950685812426465, 0.026904741302132607, 0.04261474045259612, 0.03593037663293736, 0.06782714077936751, 0.06196433358958789, 0.017584165458434393, 0.027084290149754713, 0.036930676350103955, 0.05159550426261766, 0.015526365522029144, 0.04511578660458326, 0.02422700123861432, 0.0578010869877679, 0.024561011797881553, 0.03003958665898868, 0.013223194600349026, 0.05150786807228412, 0.019516136164643934, 0.03779213083907962, 0.048425029031932354, 0.0024088351513325635, 0.05976200569421053, 0.09572235321892159, 0.14841513681624616, 0.18218076282313891, 0.09886673877813987, 0.0827656320429274, 0.07016993899430547, 0.20101097811545643, 0.10988565893577677, 0.13012830593756267, 0.1696503380579608, 0.13816970586776733, 0.14021894947758742, 0.2062202135899237, 0.21777267940342426, 0.13532946684530803, 0.10658542745347534, 0.11388947016426496, 0.11245523033929722, 0.11096090623842818, 0.14735337878976548, 0.06840138496564967, 0.11591050028800964, 0.14762540347874165, 0.049241333800767145, 0.14174538185553892, 0.08699572791478463, 0.15999664392854485, 0.08836534406457629, 0.15913535228797368, 0.1548228415527514, 0.0890312311904771, 0.1191690561494657, 0.08593449236026832, 0.12879041129989283, 0.06218122730829886, 0.2467246422810214, 0.18747189747435705, 0.0962905991556389, 0.4187291440154825, 0.7074565695864814, 27.18631042752947, 92.2308258329119, 117.40069607325962, 89.49761990138462, 89.14898708888462, 101.2047369820731, 53.13173859460013, 47.71626050131661, 82.95473752702985, 79.33596978868756, 80.70787075587681, 69.20021561213902, 51.861646107264924, 16.692213330950054, 1.5902273718799864, 1.2488519528082438, 0.23736297605293138, 0.5356189331838063, 0.12058032756405217, 0.403033299105508, 0.17098522000014782, 0.5025165751576424, 0.7491852790117264, 3.6338186221463338, 3.0420709465231215, 8.032708168029785, 8.477561371667043, 14.294746960912432, 25.183460916791642, 21.195679562432424, 20.041132143565587, 24.188282591956003, 28.874823434012278, 14.355847682271685, 19.88998624256679, 28.04797043119158, 24.971850054604666, 14.12718333516802, 20.7781240940094, 30.910593509674072, 17.31528261729649, 25.656334468296595, 23.604296922683716, 28.46386875425066, 25.34722822053092, 28.695997646876744, 23.664890425545828, 26.401461022240774, 21.142331293651036, 30.18378414426531, 32.586384364536826, 15.332624571663992, 25.241160494940623, 20.916129214423044, 27.60311722755432, 25.728941406522477, 23.43109049115862, 23.776878016335623, 16.287882021495275, 18.836224181311472, 21.600457293646677, 18.864444289888652, 13.969656382288251, 10.355910454477582, 6.8190294078418185, 7.754402416093009, 3.532606818846294, 5.646263812269483, 1.6817999609879084, 1.6733449803931373, 0.2132200486958027, 0.24942263322217123, 0.2902772266949926, 0.3791455551981926, 0.38964865303465296, 12.293117727552142, 63.284192766462056, 79.59863948822021, 79.39409146990094, 102.56777204786027, 128.03036989484514, 62.287779399326865, 40.64641284942627, 52.029285294669016, 56.05866725104195, 80.45280933380127, 92.2797133581979, 80.7800486428397, 95.34102712358747, 45.101149627140586, 2.055985208068575, 0.4574135382260595, 0.1671577939497573, 0.12741286307573318, 0.2962774575820991, 0.26424770057201385, 0.12593900359102658, 0.1414308130208935, 0.2286450495677335, 0.12978343372898443, 0.1426316842968975, 0.20111786095159395, 0.09487941595060484, 0.18281500307576998, 0.13282963527100428, 0.07704704068601131, 0.15473570408565657, 0.1341870038637093, 0.13498918153345585, 0.21274381210761412, 0.1475348597658532, 0.11195637139358691, 0.21871565308954033, 0.1419395785778761, 0.07309218575911862, 0.09381004476121493, 0.06974287583891835, 0.09870432463607617, 0.20650453333343777, 0.13425461309296743, 0.11790308622377259, 0.11806982941925526, 0.1085435166688902, 0.12312841654888221, 0.12751141350184167, 0.11450612278921263, 0.1691416132130793, 0.11681335898382322, 0.09948187148464577, 0.11419843429965632, 0.133461025676557, 0.1111799373424479, 0.11553296340363366, 0.07854177869324173, 0.15071797610393592], [0.05121843217472945, 0.06132702635867255, 0.014704700326547027, 0.017477810183273892, 0.0364307317483638, 0.0327309652763818, 0.07463995127805642, 0.06085399924112218, 0.05536622174882463, 0.03442997285830123, 0.04639476065390876, 0.038616601776863844, 0.007887947539399778, 0.011164854380435177, 0.005367955417438809, 0.056705100262271504, 0.038461088335939815, 0.053872867953032255, 0.02128757905614163, 0.022962223838216493, 0.03580972971394658, 0.014981659661446298, 0.015886954297976832, 0.033760129873241694, 0.028370098743055547, 0.045828302656965594, 0.03462016283135329, 0.04716255356158529, 0.0158582047692367, 0.04474951000884175, 0.016909019722204124, 0.021662344124966433, 0.04879068137545671, 0.026138571789488196, 0.06305370799132756, 0.028410076330016767, 0.02376956176677985, 0.4036519059113094, 0.425125177949667, 12.738218460764203, 48.66515861238752, 90.27679783957345, 76.19205583844865, 73.6429146357945, 63.476643971034456, 44.18780892235892, 35.969931261880056, 50.666017464229036, 60.35503373827253, 54.3602808543614, 46.3970616204398, 34.11523471559797, 17.5475070476532, 1.5442959793976374, 0.07485697391842093, 0.029419724563402787, 0.1947898840797799, 0.026405868785721914, 0.051247446332126856, 0.3559815367417676, 0.10051154159009457, 0.3929517886468342, 1.318039943064962, 1.7997158850942339, 4.277169048786163, 3.42286935874394, 5.036177234990256, 3.5401356262820105, 6.499073547976358, 7.588287489754813, 8.253114581108093, 4.467047682830265, 8.94754707813263, 23.8060257094247, 14.873119354248047, 8.755764637674604, 5.1518174069268365, 3.6411229159150804, 5.395788635526385, 10.89170776094709, 9.824355023247854, 4.479167512484959, 6.832754271371024, 16.633858885083878, 10.98974163191659, 11.583219408988953, 5.129141092300415, 4.798934033938816, 1.3390275197369712, 7.189902535506657, 0.9013343804648944, 9.049533605575562, 15.424163614000593, 10.760954822812762, 12.68296377999442, 8.45125983442579, 7.730483242443629, 4.116453741277967, 6.073362197194781, 5.730122489588601, 15.475701877049037, 11.383522970335823, 14.947357382093157, 21.358729464667185, 36.076245648520334, 37.84555230821882, 19.228877305984497, 5.1876566495214185, 2.5770167240074704, 0.4396400462303843, 13.044536743845258, 0.7211314929383141, 0.6052048706582615, 0.3802300712891987, 0.16646720814917768, 0.047114635418568335, 0.43583094062549727, 0.16675424203276634, 17.283499819891794, 65.04656859806606, 63.70831775665283, 52.397039549691335, 60.84202602931431, 53.01516171864101, 20.603357791900635, 23.39250888143267, 18.169014726366314, 37.28463813236782, 59.889379365103586, 61.97823715209961, 64.01065472194126, 53.778956345149446, 9.637881875038147, 0.18765960740191595, 0.019238401603485857, 0.11245136947504111, 0.029769882559776306, 0.05347872731674995, 0.06686676945537329, 0.02836056362970599, 0.03570655846436109, 0.0077767034194299155, 0.05916228251797812, 0.025169959657692483, 0.011998506745190492, 0.03934495483658143, 0.028967816848307848, 0.056174088934702535, 0.03836118423246911, 0.0345867721230856, 0.02471317327581346, 0.06290446421397583, 0.07150651727403913, 0.061134254559874535, 0.035738198552280664, 0.01735839819801705, 0.06085539702326059, 0.023104941805026362, 0.02041263529099524, 0.03006575096930776, 0.005187416332773864, 0.048070331636284075, 0.05182789232847946, 0.05225251954314964, 0.04414332378655672, 0.044405234911079915, 0.05301211914047599, 0.03072864914845143, 0.056399013115359206, 0.03285098794315543, 0.039483026534851105, 0.054235103872737715, 0.02116187196224928, 0.04285298427566886, 0.04109507646145565, 0.04463634733110666, 0.07998193534357206, 0.03995701038677778, 0.0409948941586273, 0.050375257419156175, 0.03801230527460575, 0.033128305205277035, 0.042231737968644927, 0.06160179911447423, 0.020702201806541, 0.019621546579790965, 0.057412306778132915, 0.010355283223491694, 0.0533859240822494, 0.012187024977590357, 0.011660756609801735, 0.0353924815676042, 0.0580375428710665, 0.02668308257125318, 0.004150351467874965, 0.03303250963134425, 0.03910089596839888, 0.046956536759223254, 0.013343783843863224, 0.02387136237562767, 0.031377179348575215, 0.023027329273255806, 0.048891878088137934, 0.061993700585194995, 0.03605526100311961, 0.08033904153853655, 0.044946895845766575, 0.071074941860778, 0.0457394892083747, 0.09925843668835503, 0.055213279955621274, 0.051624983216502836, 0.020935075024941137, 0.4608202182820865, 1.4275322620357787, 22.495275838034495, 67.86407007489885, 110.79561342511857, 87.18426581791469, 91.71431064605713, 96.1792994907924, 81.29021317618233, 51.364182880946565, 36.52830934524536, 45.468295914786204, 50.75064304896763, 48.53572409493582, 41.9214837210519, 22.67100099154881, 1.6855866206543786, 0.14723869280091353, 0.09886120871773788, 0.1282546536198684, 0.14524555046643528, 0.2893470637500286, 0.36500637818660053, 0.23787733273846762, 0.36461005945290836, 0.7454714125820568, 0.8644889518618584, 1.9060465565749576, 0.20222157958362783, 1.6721327368702208, 1.9901716538837977, 3.326611186776842, 7.673691272735596, 8.89431779725211, 10.071504184177943, 15.625954934528895, 26.27311216081892, 21.641946724482946, 14.491078734397888, 5.2643022281782965, 0.5652429578559739, 0.6914929204753467, 5.975486397743225, 8.343715616634913, 12.67084264755249, 15.303214584078107, 13.778779813221522, 3.789468910012926, 0.9418958468096597, 0.46858982422522133, 0.994450175336429, 1.2548521565539497, 0.5920674013239997, 0.7387371967945779, 0.5372608793633324, 1.8200111389160156, 4.589977383613586, 4.19674061025892, 0.7641608725701059, 2.3172049054077695, 4.472038226468222, 8.901029757090978, 11.42184054851532, 21.999549661363872, 20.67414777619498, 25.443196739469254, 33.9875476700919, 49.949508803231375, 53.231893403189524, 32.55163642338344, 11.64141230923789, 2.653767611299242, 1.4924224657671792, 8.827352796282087, 0.28274763215865406, 0.5173067386661256, 0.2515701694147927, 0.36521346707429203, 0.06507503667048045, 0.75263440821852, 0.12255463376641273, 17.522573437009537, 61.64539759499686, 63.454777990068706, 50.3786677633013, 39.0893041746957, 28.88857044492449, 17.826638766697474, 21.711286272321427, 23.650809901101248, 63.28454712459019, 88.07030705043248, 81.54697690691266, 78.42604064941406, 75.56149986812046, 20.931524685450963, 0.06722411992294447, 0.006737197524801428, 0.205411698403103, 0.025933304768321768, 0.030012591143271754, 0.01611594290339521, 0.09580666798033885, 0.06951832824519702, 0.0804349999608738, 0.05159790627658367, 0.0551505629638476, 0.059155476811741076, 0.0350498451319124, 0.023118985783574835, 0.05235238293451922, 0.06415596777307135, 0.052700746205768416, 0.006206961423491261, 0.05829895527235099, 0.05213756553296532, 0.0898070681307997, 0.03874249037887369, 0.06446820244725261, 0.040922446974686215, 0.026844076878790344, 0.01231753355490842, 0.03608887902061854, 0.013679142143311245, 0.06626163156969206, 0.025971412991306612, 0.08128882093088967, 0.03570681970034327, 0.044792613945901394, 0.02941912066723619, 0.020628814851599078, 0.022520173540604965, 0.012988236583104091, 0.048643666585641246, 0.01570387028290757, 0.02804145878846092, 0.04673666087910533, 0.021182967615979056, 0.03184471033247454, 0.11348743138036557, 0.1528293735214642, 0.06010575153465782, 0.0907963179051876, 0.09967919625341892, 0.15819355925279005, 0.1830496811973197, 0.15171885596854345, 0.11518919042178563, 0.0874194051804287, 0.19365282223692962, 0.17543938170586312, 0.15287554104413303, 0.07546962318675858, 0.09265315612511975, 0.11559781778071608, 0.10656990935759884, 0.10893923150641577, 0.060566612519323826, 0.0955320852143424, 0.1511844146464552, 0.10588013779904161, 0.13516796194016933, 0.11364943840141807, 0.18152331667287008, 0.16945817694067955, 0.18286993727087975, 0.11903519476098673, 0.11928626628858702, 0.12416349457842962, 0.13730352877506188, 0.19429420067795686, 0.10881531065596001, 0.15346688431288513, 0.1846144643745252, 0.18987773837787764, 0.12697078394038336, 0.5177633113094738, 1.8596786218030112, 26.242170095443726, 82.14548778533936, 123.76125771658761, 93.94333444322858, 91.2224337714059, 81.83334691183907, 58.54475702558245, 41.153982230595176, 67.54965019226074, 87.96208885737828, 79.39534214564732, 72.10345091138566, 54.72624594824654, 31.768953119005474, 4.3785558598382135, 0.40855369716882706, 0.2626343885702746, 0.4873469205839293, 0.2904472132878644, 0.360567890639816, 0.5281931002225194, 0.38562415327344624, 1.7666198781558444, 2.7875953444412778, 7.021187245845795, 14.261039512498037, 13.680430667740957, 14.364436524254934, 14.262416124343872, 18.53563642501831, 22.299612828663417, 17.60415049961635, 12.357051576886859, 17.038841588156565, 32.40719032287598, 21.1762523991721, 13.46996625832149, 15.794995920998709, 15.56504876273019, 18.59513211250305, 23.54432875769479, 16.57105585506984, 17.424428394862584, 23.801102910723003, 35.10424130303519, 29.42371027810233, 31.587580817086355, 23.135871955326625, 14.945538691111974, 9.495495915412903, 14.820954016276769, 10.689029676573616, 27.996871641704015, 37.52981226784842, 28.075495719909668, 27.415931020464214, 23.327683925628662, 20.197742802756174, 12.534930671964373, 11.81296420097351, 8.842110770089285, 21.00189777782985, 17.50681839670454, 21.623426301138743, 25.71379954474313, 39.39283275604248, 42.09848213195801, 22.45209104674203, 8.264996000698634, 16.627638510295323, 7.8647502320153375, 19.47300226347787, 1.4505902933222907, 0.8216814260397638, 0.4195851837950093, 0.6076354373778615, 0.19396844958620413, 0.9076995817678315, 0.23273672429578646, 26.50715180805751, 82.82640429905483, 80.93504210880825, 74.48531423296247, 93.94467544555664, 73.64611775534493, 29.335454259599956, 34.81007194519043, 25.419923748288834, 52.775987352643696, 78.42506095341274, 81.66613851274762, 88.93182809012276, 87.30205168042863, 18.428483043398174, 0.21612234653106757, 0.08959869002657277, 0.23173591228468077, 0.21847066123570713, 0.08214570887918983, 0.1609333208096879, 0.1683387298669134, 0.1596129595168999, 0.18690021815044539, 0.17109928173678263, 0.11591090740902082, 0.11018757987767458, 0.089114114243005, 0.07252533760453973, 0.17832006141543388, 0.22852066052811487, 0.12300496388758932, 0.14391925877758435, 0.111839649799679, 0.16846534450139317, 0.23225176174725803, 0.14480261637696198, 0.17560940901083605, 0.10428501732115235, 0.1218923700175115, 0.11074417536812169, 0.06891521917922155, 0.10066020182733025, 0.11927498903657709, 0.1256172287144831, 0.10404302459210157, 0.09847853532327072, 0.11603480790342603, 0.16119212763650076, 0.1101985653596265, 0.1630746823336397, 0.1390613687357732, 0.08665611435260091, 0.15788490724350723, 0.11352563968726567, 0.29362815831388744, 0.25828261779887335, 0.10818181000649929], [0.0160704895388335, 0.045832119416445494, 0.06722686120441981, 0.05076913342678121, 0.03340963939470904, 0.0329916686085718, 0.033176345484597344, 0.03965207335672208, 0.056721978820860386, 0.051180620810815265, 0.06596725593720164, 0.02860448509454727, 0.05018037537645016, 0.04027894471905061, 0.04124596907890268, 0.016165682912937233, 0.046499438251235654, 0.06765923050365277, 0.04797128587961197, 0.033180871313171725, 0.10512895203594651, 0.005635146392575864, 0.05312362280009048, 0.028902253402130942, 0.01562072429805994, 0.032382934487291744, 0.04877814883366227, 0.03269228878031884, 0.0717393769217389, 0.028092815407684872, 0.0478764368620302, 0.04710176700193967, 0.07119829274181809, 0.03597806068137288, 0.05396477212863309, 0.07535016031137534, 0.1852223231856312, 8.06922789982387, 47.88094670431954, 94.35035991668701, 80.90310818808419, 68.54867608206612, 68.54149859292167, 61.6636574608939, 36.74127858025687, 29.093300853456768, 49.631309100559776, 50.50270005634853, 47.253513949257986, 42.577094895499094, 25.184701170240128, 6.755776916231428, 0.31014758188809666, 0.2033837472221681, 0.03417853831446596, 0.02093084605543741, 0.07188864105514117, 0.07438996540648596, 0.17815249040722847, 0.8939898631402424, 1.1253735614674432, 4.079710798604148, 5.674108283860343, 6.557421479906354, 8.62981811591557, 14.044141939708165, 28.59823649270194, 36.24289124352591, 47.20114190237862, 52.435233797345845, 74.52308464050293, 82.35254410334996, 94.84475203922817, 97.39908354622978, 110.07639844076974, 98.21988814217704, 73.52703257969448, 13.507460474967957, 1.1759581842592783, 4.020878664084843, 12.835501057761055, 14.0782402242933, 12.183966738837105, 13.341098019054957, 9.775662047522408, 2.8734726905822754, 1.5299472979136874, 5.408138624259403, 10.782226732798986, 9.198012266840253, 1.6039679774216242, 0.828583755663463, 6.295942527907235, 14.226838741983686, 5.219614454678126, 3.770933287484305, 8.243030139378138, 30.837765966142925, 61.88232421875, 80.39902332850865, 91.8685050691877, 103.0239907673427, 104.41479778289795, 118.52159336635044, 124.88922827584403, 121.99813842773438, 120.59984125409807, 103.16585908617292, 50.579442909785676, 9.319247909954615, 3.6193759228502, 1.5509142471211297, 0.9128555251019341, 0.4424758069217205, 0.27727920987776344, 0.20015469406332287, 0.25208661598818644, 0.12417709242020335, 1.0748055492128645, 1.4332712569407053, 31.763589109693253, 59.06238392421177, 57.77957623345511, 52.93875585283552, 86.050201688494, 158.6458282470703, 112.99243927001953, 28.513624804360525, 27.540606021881104, 41.59272970472063, 54.183859143938335, 63.339972904750276, 59.55978461674282, 15.3355393409729, 0.29568783779229435, 0.24580710008740425, 0.06562681456229516, 0.03092316138957228, 0.03212498939995255, 0.011304920123490905, 0.02258056485360222, 0.06422190780618361, 0.05275563629610198, 0.04877696139737964, 0.04773676382111652, 0.00785398601354765, 0.12110841779836587, 0.04102976746591074, 0.034930501000157425, 0.03908458059387548, 0.06422485943351473, 0.006645023207446294, 0.06510844094944851, 0.06515424206320729, 0.02662002800830773, 0.03500731455694352, 0.00823588333358722, 0.03346683650410601, 0.015728859031306844, 0.028898948936590126, 0.00774703617207706, 0.024921247735619545, 0.03518828323909214, 0.015168404372941171, 0.01424476723851902, 0.07760327655289855, 0.04448524436780384, 0.01730471250734159, 0.07535443508199283, 0.03902339369856885, 0.03690421348437667, 0.017970804890085543, 0.00823169422801584, 0.02507449486958129, 0.05558668116905859, 0.032331175836069245, 0.021416673736114587, 0.04191301649968539, 0.060206018654363494, 0.019415151494156038, 0.017268013940857987, 0.06418228814644472, 0.006973524910530874, 0.03309642084475074, 0.027447823767683337, 0.016668826807290316, 0.0215488269126841, 0.028043930352266346, 0.03544997723240938, 0.05779559763946703, 0.04133723543158599, 0.027215608728251288, 0.014013318943658044, 0.030775837866323333, 0.02597247320227325, 0.024049832352570126, 0.05540344278727259, 0.006181484129878559, 0.015202373532312257, 0.0509399783664516, 0.02255340648948082, 0.037155783735215664, 0.022697881861988987, 0.024902089299368005, 0.03329818323254585, 0.029787171632051468, 0.00573979048723621, 0.015431580965274146, 0.07794752450925962, 0.0340206296449261, 0.09625196337167706, 0.16041388868221215, 0.2682836540043354, 18.462636913572037, 70.34867640904018, 111.71301187787736, 97.94045938764299, 83.07561533791679, 96.93376963479179, 105.00870200565883, 60.90264211382185, 18.789956126894268, 16.989495481763566, 34.41307619639805, 47.65592234475272, 44.02940041678292, 29.793045248304093, 7.900801828929356, 0.1489288421081645, 0.05055345767842872, 0.00808652166077601, 0.046001817631934366, 0.3212030886539391, 0.2974818300987993, 0.23933927714824677, 0.6724361830524036, 2.699799209833145, 7.956616708210536, 10.744188819612775, 12.594481076513018, 15.577133417129517, 24.102258682250977, 38.731055055345806, 47.61997931344168, 61.33615412030901, 66.06737014225551, 86.19830254146031, 95.49415152413505, 107.48700632367814, 115.09438051496232, 121.96232741219657, 113.03924928392682, 89.84475885118756, 23.72712196622576, 2.188348174095154, 1.071615023272378, 2.185514177594866, 5.532851840768542, 4.920040266854422, 1.5736592837742396, 0.9630181533949715, 1.0355923048087528, 2.338213000978742, 9.952946203095571, 19.13132459776742, 16.403616428375244, 3.4295077111039842, 0.913852374468531, 1.5874893473727363, 1.8259570598602295, 0.20323708866323742, 5.249307581356593, 14.455151336533682, 42.72653327669416, 76.51049872807094, 95.47195897783551, 106.30412415095738, 112.63794217790876, 109.07939447675432, 120.42976324898856, 129.3942040034703, 125.62944766453334, 125.7757350376674, 120.73070362636021, 71.97939082554409, 19.358377831322805, 6.940836540290287, 3.5948034014020647, 0.4697889855929783, 0.1996933173920427, 0.28052179302488056, 0.1316896150154727, 0.29010951997978346, 0.07610989561570541, 1.6397407778671809, 1.7251848386866706, 35.29146746226719, 58.33073166438511, 61.09312002999442, 43.449406487601145, 36.466157708849224, 104.6821505682809, 71.74455560956682, 28.32279426710946, 50.7288361276899, 69.05633231571743, 73.5582160949707, 72.61436585017613, 77.5929377419608, 32.64519739151001, 0.9783035389014653, 0.6512029224208423, 0.12449388684970991, 0.07591221800872258, 0.018634249289919223, 0.08410497874553714, 0.039421181460576396, 0.04786673041858843, 0.0165196305273899, 0.020947972279308096, 0.06808174068906478, 0.03242680856159755, 0.050744753663561175, 0.02204685295665903, 0.02377810452266463, 0.0035911241097242703, 0.017293338564091494, 0.037685600841151815, 0.0673878707789949, 0.034825646983725686, 0.02503129424128149, 0.04610189815450992, 0.05535291228443384, 0.06690345105848142, 0.045975755101868084, 0.08053707198372909, 0.052854441172842465, 0.04307324352807232, 0.04599942240331854, 0.007303942626874361, 0.009660200432075985, 0.06154047990483897, 0.07975778808551175, 0.020212250329287987, 0.03185514620106135, 0.013531632022932172, 0.030812203950647796, 0.023312510756243552, 0.019369569207940782, 0.03815038375822561, 0.01978148746171168, 0.05544817181570189, 0.09422703845692532, 0.1861014874385936, 0.1528153685586793, 0.11296837244715009, 0.12859567174954073, 0.18699802218803338, 0.10540953305150781, 0.2088290857417243, 0.19201762069548878, 0.17859587232981408, 0.14968854348574365, 0.07897417513387543, 0.17453095902289661, 0.16397367337984697, 0.1227923652955464, 0.0848379119166306, 0.13371410566781247, 0.13620898393648012, 0.12379777777407851, 0.113614032444145, 0.30235444435051506, 0.1602776117090668, 0.09410716167518071, 0.15382652144346917, 0.09399856214544602, 0.09933429011808974, 0.15638472060007708, 0.15187459332602365, 0.12590327193694456, 0.1295756527355739, 0.09358433008726154, 0.16038590589804308, 0.12522641968514236, 0.19589577402387345, 0.2218028652880873, 0.20331670796232565, 0.4414447051073824, 21.9858877658844, 82.73497990199498, 128.44908223833357, 104.00352001190186, 84.87530994415283, 90.8642749786377, 79.68796552930559, 44.29555116380964, 40.4168895312718, 74.5982780456543, 72.72516877310616, 66.58271803174699, 62.21683829171317, 41.47763974325997, 12.097318359783717, 0.5721841539655412, 0.3393653540738991, 0.08112671891493456, 0.23772105255297252, 0.38177946529218126, 0.21296383387276105, 0.6096606744187218, 1.1904707998037338, 4.595710515975952, 9.094926186970302, 10.398033908435277, 12.393294249262128, 15.696201222283499, 20.566263096673147, 34.367905957358225, 44.321853569575715, 55.59397867747715, 61.757291385105674, 85.94027423858643, 91.2274364743914, 103.52735301426479, 114.21088927132743, 123.90666961669922, 111.43650831495012, 83.00821781158447, 18.58833851133074, 6.621529034205845, 13.90246730191367, 30.9548431124006, 34.875951290130615, 26.985868794577463, 40.05891139166695, 29.866213253566197, 9.970811758722578, 3.0727187991142273, 9.360122425215584, 18.626447643552506, 16.04228057180132, 2.7933538811547414, 4.50071474484035, 20.593171732766287, 35.551420416150776, 16.91962092263358, 10.67860564163753, 11.663002099309649, 35.682532923562185, 70.62069838387626, 93.29959774017334, 105.00501946040562, 113.93433012281145, 108.9591281073434, 124.66054916381836, 139.74814551217216, 138.2847854069301, 136.2828982216971, 120.33476747785295, 57.455533095768516, 11.377102834837777, 9.696925061089651, 6.566055050918034, 1.2211390627282006, 0.2892916410097054, 0.41666023646082195, 0.47340400304113117, 0.4768725654908589, 0.18176582508853503, 1.6116138185773576, 4.087377267224448, 48.447968346732004, 74.98256206512451, 77.58714989253453, 76.19314670562744, 106.42152786254883, 174.8841574532645, 135.72066388811385, 40.32608004978725, 37.38223947797503, 60.03325571332659, 72.80162675040108, 81.86519050598145, 92.97943864549909, 35.17192370550973, 0.5196836739778519, 0.7719372095806258, 0.2694177845759051, 0.17650614732078143, 0.15881397096174105, 0.16380156975771698, 0.2219718069370304, 0.12273958884179592, 0.15898239692406996, 0.15686790538685663, 0.23454314736383303, 0.07738122596804585, 0.31100997275539805, 0.1331304298447711, 0.18118324849222386, 0.0738573425582477, 0.10131807545466082, 0.10941643161433083, 0.1336459128984383, 0.17026754708162375, 0.0764377840927669, 0.15972670912742615, 0.06924922125680105, 0.20427298093480722, 0.11603510645883423, 0.1943226448659386, 0.13545188813337258, 0.15900735344205583, 0.15841596946120262, 0.12706337682902813, 0.11810706742107868, 0.19100502931645938, 0.19332481840891497, 0.08186543320438691, 0.16378597702298844, 0.10033164838595049, 0.1501050011387893, 0.07110243609973363, 0.10488229777131762, 0.1817973091134003, 0.10442021542361804, 0.13787104189395905], [0.029406564376716102, 0.02657540754548141, 0.03231863311624952, 0.05005759785750082, 0.008147711100588952, 0.07033124712428876, 0.019014466387618865, 0.0393119882127004, 0.09110129225466933, 0.07864967254655701, 0.055584475930247984, 0.03593232402844088, 0.1000426263947572, 0.050580799247005155, 0.008447426803676146, 0.03673889521243317, 0.08951801899820566, 0.05404508353344031, 0.03404028341174126, 0.012720455282500811, 0.013825277382108783, 0.05444732587784529, 0.02405041758902371, 0.0824136080752526, 0.05452137779710548, 0.03913204751110502, 0.07622057146259717, 0.05911504290997982, 0.03472139686346054, 0.018524028061489974, 0.03770538352962051, 0.06499942751335246, 0.03365990346563714, 0.09323690658701317, 0.11759356568966593, 2.461235851049423, 50.364152976444785, 93.89916474478585, 94.94024808066231, 76.04043919699532, 71.5686480658395, 65.0840402330671, 37.54518515723092, 30.559806755610875, 52.143291337149485, 91.62091296059745, 74.34043039594377, 59.487988880702424, 32.07678263528006, 7.486003058297293, 0.08577498913343463, 0.6568614159311567, 0.05465851990239961, 0.04855239684028285, 0.12968077138066292, 0.08039139730057546, 0.0685038844655667, 0.20547913121325628, 0.7468471016202654, 22.00550253050668, 66.41573892320905, 95.14123862130302, 104.06532423836845, 105.48805822644914, 104.3856222970145, 110.7294179371425, 108.42667375292096, 108.00429276057652, 106.61050496782575, 104.29899910518101, 93.57531615665981, 108.0284446988787, 98.42031587873186, 98.57369041442871, 89.3509920665196, 97.3650095803397, 101.1480188369751, 109.86361680712018, 33.14554064614432, 2.190157094172069, 2.486385290111814, 9.82857084274292, 11.852390885353088, 8.161041396004812, 1.7584965654781886, 4.668738688741412, 33.572257314409526, 55.001780237470356, 65.9829912185669, 61.722314153398784, 47.841411454336985, 22.174586943217687, 1.48240370622703, 2.426795367683683, 7.264689036778041, 27.92883661815098, 73.9004774093628, 103.36683573041643, 111.28255013057164, 102.38451331002372, 104.02651854923793, 102.1082181930542, 96.16402040209088, 95.70121479034424, 96.5083453314645, 87.0570512499128, 88.52750546591622, 95.73329462323869, 119.20522662571499, 113.74586718423026, 76.74201965332031, 68.6651417868478, 48.49904455457415, 23.883451223373413, 3.589270681142807, 0.25606706525598255, 0.17579490691423416, 0.14095285295375756, 0.3402744010090828, 0.1636643156941448, 0.2901133197758879, 8.72986262185233, 56.05110413687569, 74.4972095489502, 68.55598558698381, 83.86357579912458, 83.08431448255266, 41.209376743861604, 26.251484155654907, 25.617068461009435, 44.45056894847325, 59.110236167907715, 59.75391033717564, 63.38517093658447, 32.29445232663836, 2.912666610309056, 0.5172772088221141, 0.023970581158729534, 0.0363737992676241, 0.10835187802357332, 0.043530433638287444, 0.05388443697510021, 0.03795288596302271, 0.053021092766097615, 0.028020480182021856, 0.021411876493532742, 0.08685485047421285, 0.03940257603036506, 0.03744144019271646, 0.021837988003556217, 0.04380576279280441, 0.004835341050888279, 0.0566388854224767, 0.05889259198946612, 0.017189709303368415, 0.019505457719787955, 0.03513849573209882, 0.032130868905889134, 0.13233222839023384, 0.11931781816695418, 0.03796516405418515, 0.07657756909195866, 0.029625564946659973, 0.026752802044419304, 0.04377877406243767, 0.030355427746794054, 0.02772376360371709, 0.055378387881709, 0.005362558519534234, 0.025825499124558907, 0.038176771985100846, 0.04741054114752582, 0.0169296641501465, 0.004031863562496645, 0.056227794981428554, 0.051039716228842735, 0.013210392340884676, 0.033032390887715986, 0.04624322682086911, 0.047854842485061715, 0.07029582759631531, 0.05662691606474774, 0.027350796652691703, 0.039157886124615154, 0.08398147858679295, 0.16198917558150633, 0.022461266522961, 0.0667761443182826, 0.07021637793098177, 0.04570596957845347, 0.023865978200254694, 0.0707086550870112, 0.08779309477124896, 0.04670330070491348, 0.01642302580044738, 0.026082329718129973, 0.009728590824774333, 0.02340035220342023, 0.015883352973365357, 0.024926085690302507, 0.03634434745513967, 0.039512512274086475, 0.04135562712326646, 0.05083727191335388, 0.045140169760478396, 0.022523662906938365, 0.06603900423007351, 0.062315081911427636, 0.03389481228909322, 0.03331828483247331, 0.15912606992891856, 7.160173799310412, 70.86282920837402, 111.95642811911446, 106.62467929295131, 93.44401604788644, 90.94856357574463, 95.96782411847795, 65.76415770394462, 29.230202947344097, 18.128857612609863, 52.39653580529349, 70.05932562691825, 63.58845438276018, 37.52452816282, 9.151502762522016, 0.1431286297738552, 0.8660909458994865, 0.023810699648622955, 0.1379675024322101, 0.20816234366169997, 0.36767929047346115, 0.18643626304609434, 0.12112843458141599, 1.9502733605248588, 33.14367158072335, 81.19248676300049, 109.98962238856724, 115.4292072568621, 117.41443961007255, 116.35513114929199, 116.45838138035366, 111.71622889382499, 114.27281856536865, 109.31684221540178, 107.30231625693185, 99.3183844430106, 110.08953748430524, 106.4370709827968, 101.20451463971818, 93.4065305164882, 98.71106324877057, 104.74488585335868, 118.35016741071428, 46.66012389319283, 5.33862841129303, 1.5193776765039988, 3.6491461311067854, 5.2075198122433255, 1.8899441063404083, 0.917030849627086, 8.072322453771319, 44.74367870603289, 69.11444704873222, 78.66196673257011, 79.86952195848737, 67.65729863303048, 32.271134172167095, 3.5799564038004195, 0.9354397760970252, 10.005623970712934, 38.75229917253767, 87.79624925340924, 109.10243470328194, 114.28643008640834, 103.56952163151333, 104.99101884024483, 104.70220306941441, 98.05023397718156, 99.9295688356672, 100.02989387512207, 92.21585246494838, 94.13378456660679, 97.80597005571637, 118.15442276000977, 121.41592107500348, 99.30442551204136, 87.54402964455741, 67.11259460449219, 36.056575298309326, 9.379203915596008, 0.08720791938581637, 0.21714487166277, 0.07628302382571356, 0.3810884452291897, 0.24599391434873852, 0.703166545501777, 9.020903553281512, 58.54824502127511, 81.28579412187848, 68.19936234610421, 81.23347418648856, 80.21932206835065, 29.194728919437953, 28.89072264943804, 43.26138823372977, 72.7746399470738, 79.18188653673444, 70.93866879599435, 78.90481322152274, 53.83091844831194, 10.087715200015477, 0.45160807403070585, 0.09366544216339077, 0.02497027358705444, 0.10112136815275465, 0.04153839053053941, 0.03368274634703994, 0.011287000861817172, 0.02784576080739498, 0.03615357394197157, 0.03314111255375402, 0.04805441659742168, 0.02178671789754714, 0.022101334229643856, 0.029922912562532083, 0.026412265674610223, 0.01134011912758329, 0.05339615639033062, 0.031038631086370776, 0.035759392593588145, 0.030266733041831424, 0.03859851203326668, 0.11049412164304938, 0.07806861586868763, 0.09102537097143275, 0.07639223403696503, 0.05355446200285639, 0.017520230496302247, 0.021785435466361896, 0.03415205848536321, 0.052282178308814764, 0.03023368160107306, 0.058092178510768075, 0.027481796319729516, 0.04227368839617286, 0.02822014589660934, 0.06480976340493985, 0.012153408656428968, 0.0015800348420660676, 0.044894180460167785, 0.05501618588875447, 0.11749462171324662, 0.08903314465922968, 0.1275237085563796, 0.11523280665278435, 0.13082669489085674, 0.1450460883123534, 0.15119132213294506, 0.15446541644632816, 0.1898848358541727, 0.1975439220134701, 0.10616186553878443, 0.12804457917809486, 0.17323689774743148, 0.09678195350404296, 0.07407167141458817, 0.15312773893986428, 0.1956338052238737, 0.20699145006281988, 0.12604077027312346, 0.1167573934154851, 0.11125249309199196, 0.10949901611145053, 0.08729093135999781, 0.1594753119030169, 0.11418590854321208, 0.14229826575943402, 0.09284952415951661, 0.0936991653538176, 0.14146019358720097, 0.05394799195762191, 0.21680048799940518, 0.18484948176358426, 0.09440357291272708, 0.21548446933073656, 0.2601708450487682, 8.85134666306632, 84.91818032945905, 127.9792172568185, 117.21473448617118, 93.95418058122907, 93.32042149135044, 83.33341435023716, 48.01658248901367, 36.506523268563406, 71.3668862751552, 135.83419745309013, 101.15410545894078, 82.82058865683419, 51.100721086774556, 13.487447925976344, 0.6941761736358915, 0.9923478024346488, 0.2135971106056656, 0.4135266803205013, 0.273230852825301, 0.19531433736639364, 0.3271082160728318, 0.8443769567779132, 4.854835331439972, 24.883203199931554, 72.95055443899972, 105.67751475742885, 116.36898585728237, 115.47710118974958, 114.09481266566685, 119.76830863952637, 119.1779202052525, 119.96046801975795, 116.02915641239711, 115.8090374810355, 107.6812640598842, 118.51836940220424, 113.82114396776471, 111.34820365905762, 99.62493896484375, 108.0883103779384, 115.67174802507672, 124.26116670880998, 42.136374132973806, 5.951653642313821, 12.687321169035775, 25.42381647654942, 32.10498884746006, 20.202874047415598, 4.607847716127123, 7.555041228021894, 52.66306522914341, 78.2493062700544, 89.34613527570451, 89.51888833727155, 84.02938066210065, 34.45721810204642, 2.012955665588379, 5.820279708930424, 10.206181117466517, 34.57314532143729, 83.19107355390275, 111.32068879263741, 122.43519401550293, 110.47767080579484, 115.7783750806536, 109.74644933428083, 101.88506289890834, 103.1989255632673, 104.45904391152519, 94.73410197666713, 97.59080518995012, 106.79330512455532, 135.745427267892, 127.90817887442452, 90.53801536560059, 74.47342586517334, 54.30943741117205, 26.80211673464094, 5.6804176824433465, 0.26179010101727074, 0.3554581148283822, 0.34019780797617777, 0.6144132422549384, 0.7092987107379096, 0.7871009473289762, 16.627829585756572, 75.82858167375836, 91.45727593558175, 88.52861022949219, 98.30456583840507, 95.72818769727434, 52.28744561331612, 36.89655344826834, 34.78268562044416, 61.922331946236746, 80.88008880615234, 77.51451342446464, 95.01396151951381, 59.92185524531773, 7.461595773696899, 0.6374797959412847, 0.16703582049480506, 0.1427129456507308, 0.18299934746963636, 0.11387595374669347, 0.10326252611620085, 0.11901148674743516, 0.17650906502136163, 0.14145357108541898, 0.09332357586494514, 0.2225240801594087, 0.21852917809571537, 0.08878616469779185, 0.07178492019219057, 0.09838150481560401, 0.08998487144708633, 0.25227978133729523, 0.1557487297270979, 0.20228822529315948, 0.10291439015418291, 0.08671649718391043, 0.15639978407749108, 0.1419851625604289, 0.12278967829687254, 0.11592853574880532, 0.09377255570143461, 0.18407953450722353, 0.18843430440340722, 0.10855581172342811, 0.16502350276069983, 0.09956175541239125, 0.13411714189818927, 0.09570910143000738, 0.12462535979492323, 0.11796865984797478, 0.16440025477537087, 0.12747832813433238, 0.0552612116693386, 0.11008151806890965, 0.11509864670889718], [0.03929839715627687, 0.031970439478755, 0.04196394733818514, 0.061460107431880066, 0.0635292592591473, 0.08096159741814647, 0.02877244626038841, 0.025711303377257924, 0.03216675662302545, 0.04730528340275798, 0.043854617314147096, 0.01986518475626196, 0.11885256027536732, 0.13090364076197147, 0.009974219653356289, 0.025684726856915013, 0.12408782435314995, 0.06659800851983683, 0.04830689947786076, 0.0420635189594967, 0.04899028941456761, 0.021155281690880656, 0.05992760216551168, 0.015131054412839668, 0.13935015323970998, 0.10186831985733338, 0.0375080384047968, 0.04298699494185192, 0.0730288920125791, 0.040930138169122596, 0.06551354671163218, 0.054464798154575486, 0.06040811352431774, 0.16825180953102453, 6.150239237717219, 79.70928260258266, 91.91789286477226, 72.62334292275565, 69.918714932033, 60.02326420375279, 57.52066898345947, 32.873893874032156, 36.00897666386196, 77.48586600167411, 92.61974430084229, 66.92270728519985, 48.320093699863975, 15.258532455989293, 0.11915225562240396, 0.8762509492891175, 0.06175600976816245, 0.40427002417189734, 0.045689739020807404, 0.061848813002663, 0.14679007258798393, 0.08037418286715235, 0.6040438700999532, 1.60429747402668, 59.71918324061802, 121.80652100699288, 110.86836106436593, 102.1157500403268, 97.06119959694999, 101.93395737239292, 99.8331139428275, 98.62378692626953, 92.15433311462402, 92.73698125566754, 90.5413852419172, 93.92094734736851, 86.48365116119385, 91.91045829227993, 98.88460840497697, 89.43931756700788, 86.68978336879185, 78.80319581712995, 82.0923410143171, 88.7028363091605, 96.36710929870605, 51.153697626931326, 5.972612014838627, 1.6365424352032798, 2.009762316942215, 0.26896930006997927, 6.28918149641582, 44.26200178691319, 60.24562740325928, 71.544892174857, 79.29087597983224, 82.46094294956752, 79.39939294542584, 63.90135955810547, 55.17808035441807, 27.847657339913503, 54.62087304251534, 93.87491553170341, 112.57613795144218, 107.22263431549072, 99.91918822697231, 98.66187695094517, 95.53808498382568, 106.37546825408936, 101.44734723227364, 102.80143301827567, 105.42896379743303, 95.29774679456438, 90.79115908486503, 96.58792304992676, 91.86408601488385, 91.27625451769147, 103.74936185564313, 112.69200611114502, 117.38648005894252, 117.33857917785645, 102.52501283373151, 37.85122551236834, 0.4753933591502053, 0.07135563822729246, 0.28665192265595707, 0.028923488155539547, 0.07978522804166589, 0.4751908300178391, 0.5878273174166679, 19.70845934322902, 46.76455184391567, 43.72039665494646, 29.293907506125315, 39.28698737280709, 67.60106686183384, 29.57343700953892, 27.230295998709543, 41.157567501068115, 52.81323317119053, 58.56952040536063, 63.86868912833077, 56.886055265154155, 17.73358154296875, 0.14486376595284256, 0.18049074922289166, 0.1310862616768905, 0.031789925415068865, 0.07237456712339606, 0.017224468956036226, 0.01998709883940007, 0.04985435626336506, 0.060390234126576355, 0.03711779595219663, 0.06835229295705046, 0.10851068914468799, 0.026133582860763584, 0.03844613003145371, 0.04868438207943525, 0.05853118388248341, 0.05646737212581294, 0.05088909502540316, 0.09251699450292758, 0.10806987208447286, 0.04381146927231124, 0.005905518848781607, 0.18458752653428487, 0.22054456280810492, 0.08367261623165437, 0.07903249521872827, 0.018706413185490028, 0.05060946395886796, 0.019636813617710556, 0.0819992810221655, 0.03379134587677462, 0.07396681739815644, 0.050665320961603096, 0.01121692855044135, 0.057349386225853644, 0.042322034016251564, 0.06343431185398783, 0.0749382149162037, 0.049809372784303765, 0.0372078239784709, 0.03437442798167467, 0.05700660390513284, 0.04921236374814596, 0.064681873124625, 0.0780688804973449, 0.028599436794008528, 0.0867278626454728, 0.01578950649127364, 0.08102322875389031, 0.03070422528045518, 0.048070243426731656, 0.11879890172609262, 0.09936352140669312, 0.05045272915491036, 0.09686945738004786, 0.18138868175446987, 0.10054858281676259, 0.021232253007058586, 0.09464001522532531, 0.024092759870524918, 0.035619553311594894, 0.0597453544448529, 0.16375992127827235, 0.20087352049137863, 0.03732782628919397, 0.019210206777123467, 0.03987122320437005, 0.12958099959152086, 0.05031628594068544, 0.08055374358913728, 0.08844272419810295, 0.13683474250137806, 0.0917818085955722, 14.53840638910021, 102.17030034746442, 103.69686821528843, 85.1887709753854, 91.42762102399553, 93.33361612047467, 96.10981750488281, 52.08496468407767, 20.65437494005476, 37.488157817295615, 73.01662485940116, 75.58238615308488, 57.57551111493792, 19.200038807732717, 0.21216977148183755, 1.1745193643229348, 0.08107407816818782, 0.5476106011441776, 0.07892050301390034, 0.29904989738549503, 0.3275144142763955, 0.2307688370347023, 0.6672488642590386, 4.020652847630637, 74.63067054748535, 125.56305067879813, 112.63605226789201, 100.38700348990304, 100.29286234719413, 104.39479391915458, 103.11248997279576, 101.30653503962925, 94.42872170039585, 97.2620233808245, 96.1780696596418, 98.97281578608921, 99.50118459974016, 96.7455220903669, 103.51003810337612, 97.72243186405727, 96.23908179146903, 87.81336961473737, 89.23497104644775, 94.94989218030656, 104.76256207057408, 62.90529360089983, 9.422670977456228, 0.6595556885004044, 0.9139975266797202, 0.2885028304798262, 11.103465403829302, 59.569248063223704, 76.49883965083531, 83.21939441135952, 89.49599402291435, 88.79513617924282, 94.30974769592285, 85.58632605416435, 71.46609960283551, 39.59962851660592, 67.30488600049699, 100.33623300279889, 107.91429969242641, 109.8621437890189, 103.72877434321812, 102.98437213897705, 97.55873230525425, 111.23602499280656, 107.04713671548026, 106.76215635027204, 111.58182294028146, 101.13993808201381, 92.96684850965227, 103.45651612962995, 101.8686443056379, 95.755355153765, 101.16286018916539, 110.5884598323277, 118.2270175388881, 125.23378944396973, 115.08153329576764, 54.15290491921561, 1.95857515505382, 0.05468944074319942, 0.5421499684453011, 0.08370792040867464, 0.1504446214863232, 0.8350048139691353, 0.434969499707222, 18.649192571640015, 51.428662163870676, 46.968345982687815, 34.102658476148335, 24.56664674622672, 24.406945875712804, 24.623825209481375, 40.111651693071636, 69.62166554587228, 81.88770266941616, 72.43167686462402, 76.20418739318848, 74.73841626303536, 35.074739251817974, 0.31871693634561127, 0.26855115965008736, 0.15068170162183897, 0.019894236233085394, 0.013503851102931159, 0.02570182933206005, 0.0501738817963217, 0.04353313081498657, 0.0823025590341006, 0.04357561728517924, 0.07179825340530702, 0.08842987953019993, 0.04453648054706199, 0.03348627992506538, 0.02970195441905941, 0.05565197320122804, 0.08095647447875567, 0.09411613869347743, 0.06671055033802986, 0.06748234320964132, 0.04871923842334321, 0.0648593914562038, 0.2078435000564371, 0.24881938844919205, 0.12125682697764464, 0.12161784831966672, 0.009841725512939905, 0.10062914527952671, 0.07178774968321834, 0.15313171515507357, 0.043357274894203456, 0.015255509609622615, 0.010590371010558946, 0.052316678421837945, 0.026689598203769753, 0.027336925700572983, 0.07499253164444651, 0.0714731537071722, 0.04901498808924641, 0.11752369015344552, 0.10113199401114668, 0.1756950808422906, 0.1426586221371378, 0.19688733081732476, 0.1744524932333401, 0.07707823294081859, 0.2594870717397758, 0.14430249535611697, 0.21656108727412565, 0.11189130667064871, 0.11954231826322419, 0.1921641028353146, 0.1645421093063695, 0.1430544794670173, 0.14476581263755048, 0.21659722604921886, 0.20369442126580647, 0.09626275207847357, 0.2387388822223459, 0.10583831968584231, 0.05795970133372715, 0.12139055265911988, 0.1819114794156381, 0.27139020445091383, 0.1506264145885195, 0.11579960052456174, 0.14721231135938848, 0.21970134734043054, 0.18223039087440285, 0.14015454293361732, 0.17828712532562868, 0.15559280237981252, 0.15025830934090273, 18.843302658626012, 122.33272198268345, 116.67648533412388, 91.09193965366909, 89.08848912375313, 80.99544974735805, 74.53165176936558, 44.709066254752024, 48.823699133736746, 114.6669898714338, 134.89748300824846, 85.29496724264962, 69.14525536128453, 27.170029061181204, 0.4999653377703258, 1.34517482987472, 0.12407893554440566, 0.836923493870667, 0.1662151731018509, 0.2779761196247169, 0.19486270445798123, 0.3711445416722979, 1.9861451728003365, 5.857875977243696, 66.66038499559674, 134.0428684779576, 122.91855239868164, 109.88029248373849, 106.9903838293893, 111.10934543609619, 111.64523914882115, 104.33492129189628, 97.729400907244, 98.65511635371617, 97.43315056392125, 101.44896616254533, 99.90683432987758, 101.84663241250175, 107.86725343976701, 101.15851061684745, 100.23241996765137, 90.85662501198905, 91.8730491910662, 102.58052894047329, 113.5298546382359, 65.50175203595842, 8.524530325617109, 6.241907690252576, 9.195815767560687, 0.7000522326145853, 10.397260921342031, 73.51174654279436, 83.49038805280412, 88.42441504342216, 90.26816122872489, 90.5911065510341, 96.01316111428397, 106.72123146057129, 85.01523276737758, 36.64342015130179, 68.96529006958008, 104.03485638754708, 110.56664943695068, 115.63993917192731, 109.65709550040108, 107.97977256774902, 103.58969920022147, 115.97726726531982, 111.16092191423688, 109.86047622135708, 117.00046593802315, 108.213134765625, 100.21727984292167, 106.02598776136125, 104.64313643319267, 100.45059340340751, 113.14099870409284, 127.09383610316685, 131.55759511675154, 133.95773914882113, 112.8452069418771, 43.32126086098807, 1.181618251970836, 0.22756962584597723, 0.5618946318115506, 0.1968266155038561, 0.13008686101862363, 1.20719533094338, 1.4244259830032076, 29.414986814771378, 63.369704246520996, 60.4973258972168, 42.675109658922466, 56.04442344393049, 87.79835455758231, 42.31144094467163, 34.284058570861816, 55.08544002260481, 72.71328735351562, 74.19560214451381, 87.15584768567766, 88.6609525680542, 32.699653897966655, 0.2559580925319876, 0.20703480845051153, 0.268346079226051, 0.24293336857642445, 0.14534994986440453, 0.12392209896019526, 0.19981724502784864, 0.2209224525306906, 0.10289229026862554, 0.09125661570578814, 0.228862072208098, 0.25456706860235756, 0.13843555588807377, 0.10673020647040435, 0.14762813118951662, 0.11860015881913048, 0.2273470799305609, 0.15644424169191293, 0.09997052526367561, 0.14517969185752527, 0.12280753733856337, 0.12330461852252483, 0.329997825303248, 0.4058993496000767, 0.193080925781812, 0.21900609321892262, 0.11550043443483965, 0.22552559338510036, 0.1475330005799021, 0.20225315860339574, 0.09913872954036508, 0.1984701223139252, 0.08244005737027951, 0.1106809698311346, 0.13249834733349936, 0.12474813392119748, 0.15501786608781132, 0.21020656611238206, 0.19373685201363905], [0.021072556397744586, 0.14477964118123055, 0.0672229528427124, 0.030865519839738096, 0.06555121897586755, 0.011687002344323056, 0.07497528328427247, 0.04570352006703615, 0.024829379183107188, 0.044373618571885994, 0.09539897699973413, 0.13236896427614347, 0.0443090525721865, 0.08092613039272172, 0.0960388355223196, 0.14631812434111321, 0.05633593650002565, 0.04043926218790667, 0.05050992626430733, 0.031634595178599866, 0.028782291803508997, 0.06888499722949096, 0.09655049163848162, 0.12445462681353092, 0.05644238507375121, 0.037206599222762246, 0.04125827091879078, 0.015179600200748869, 0.05894487311265298, 0.06642186761434589, 0.05003556582544531, 0.017762550618499517, 0.10233914173607316, 6.903843896729605, 77.38269914899553, 79.38356494903564, 80.77863815852574, 76.37244497026715, 58.94329180036272, 41.168920857565745, 23.703074250902446, 41.88487018857683, 72.8506532396589, 69.17213794163295, 60.70774514334542, 43.055846623011995, 6.771915410246168, 0.306760416499206, 0.022510066761502197, 0.28191135131887024, 0.035650779493153095, 0.20685693728072302, 0.10602837055921555, 0.18197902079139436, 0.5450367278286389, 1.11689849623612, 0.4085414563970906, 64.0733483178275, 110.33307184491838, 86.04742240905762, 89.7719486781529, 88.47290652138847, 96.78070776803153, 96.9051708493914, 97.6333976473127, 99.72455528804234, 97.69783524104527, 98.31401538848877, 95.66800240107945, 99.98193046024868, 99.89561993735177, 83.49501555306571, 87.40026446751186, 84.38806056976318, 80.26464516775948, 85.43715517861503, 80.63304560525077, 91.55978965759277, 85.59389264242989, 94.04314531598772, 53.817209652491975, 11.005762440817696, 1.2020963302680423, 7.952638864517212, 44.85894584655762, 62.91032409667969, 83.3645144871303, 89.27468694959367, 95.22015626089913, 97.62791551862443, 99.60552569798061, 89.53858648027692, 76.2350651877267, 69.17400700705392, 95.26078932625907, 92.44474697113037, 99.67823164803642, 111.26631219046456, 95.6113189969744, 90.05204445975167, 81.45319707053048, 92.25770146506173, 99.67130429404122, 96.28930337088448, 97.40854699271065, 98.0705783026559, 80.3511710848127, 77.37165846143449, 101.1897497177124, 104.79764352525983, 94.14173330579484, 86.47841221945626, 82.89970779418945, 86.5511668069022, 88.65379592350551, 113.48119640350342, 55.866653782980784, 0.16930091966475758, 0.15522629847483976, 0.11475152176405702, 0.06727917625435761, 0.0969705998099276, 0.060850104450115135, 0.44264424645474976, 2.7933662576334815, 26.050326858248027, 57.026370661599294, 71.65538937704903, 74.28629003252301, 69.92651775905064, 41.89859635489327, 16.152503320149012, 22.94670898573739, 49.61645385197231, 60.284704072134836, 65.38158988952637, 61.167208671569824, 40.01578392301287, 0.5229002013802528, 0.4095368944108486, 0.07002788768815142, 0.03151152249691742, 0.08560017137123005, 0.049285482681755505, 0.013570988750351327, 0.04629778442904353, 0.06669098817344223, 0.02798818700414683, 0.008007892174646258, 0.0179673867699291, 0.05324091775608914, 0.03618045071406024, 0.028852798377296755, 0.017990864081574336, 0.11085086821445397, 0.06453578453511, 0.06636265186326844, 0.04557810643953936, 0.15176093871040003, 0.1943770633744342, 0.1914365640176194, 0.14410741653825554, 0.03787561778777412, 0.05192198817219053, 0.07773300566311393, 0.008351168977761907, 0.04662295876603041, 0.032212605234235525, 0.06857217901519366, 0.09363332710095815, 0.05558126645960978, 0.05325067508965731, 0.04426563650901828, 0.07719418100480523, 0.0399279283758785, 0.03312547232157417, 0.03483860021723168, 0.0523826659524015, 0.06643310415425471, 0.028299354682011262, 0.0896235719057066, 0.08441430250448839, 0.18010014375405653, 0.08462719286658935, 0.10464044074927058, 0.060250075933124335, 0.039172535695667775, 0.11982239037752151, 0.0651832969327058, 0.05807678933654513, 0.07193299688931022, 0.06285735352763108, 0.07937246840447187, 0.12949072729263986, 0.0714290150042091, 0.05012589579980288, 0.0036816292309335297, 0.061288946973426, 0.05896768545997994, 0.08584194018372468, 0.055337312764355114, 0.011163687300203102, 0.05694967481706824, 0.12399851557399545, 0.06499084404536656, 0.07702207738267523, 0.19709365974579537, 0.06740595373724188, 0.07525056494133812, 16.567164863858903, 99.70343971252441, 94.46225370679582, 97.99096584320068, 94.7893818446568, 86.55638490404401, 60.988862310137065, 26.83778010095869, 23.407200847353252, 48.71724230902535, 71.49622699192592, 71.01805891309465, 51.30930948257446, 8.625801188605172, 0.37157128591622623, 0.016589119298649684, 0.3721068671771458, 0.03529973261590515, 0.3514951174812657, 0.16225798401449407, 0.5416397643940789, 0.9688588742698941, 1.2978194909436362, 2.8170930530343736, 78.69900063105992, 112.75155217306954, 90.32452501569475, 97.78245735168457, 96.45996502467564, 103.40743405478341, 103.29782622201103, 104.84256362915039, 104.17105497632707, 103.59284673418317, 102.85949216570172, 101.60374423435756, 105.06571197509766, 101.50521877833775, 88.30674035208565, 92.57293428693498, 86.10459218706403, 83.7151483808245, 91.27947153363908, 87.17649773189, 97.8135574885777, 89.89766938345772, 98.99752358027867, 63.99134567805699, 18.24464065687997, 3.937949308327266, 14.015412875584193, 55.5326886177063, 71.19489751543317, 89.5436100278582, 97.88315064566476, 100.15359960283551, 102.77130562918526, 104.73884092058454, 102.68693365369523, 92.55899620056152, 74.31092139652797, 97.41115256718227, 90.84189483097622, 103.07412202017647, 112.15213802882603, 99.31107493809291, 93.93430873325893, 84.70173004695347, 95.60421098981584, 103.2678586414882, 98.232679775783, 100.95975044795445, 103.06454740251813, 87.7297272000994, 77.19161673954555, 101.22568580082485, 108.89967932019914, 103.009003502982, 96.02685601370675, 90.38776057107108, 87.40132754189628, 90.30889851706368, 116.63354546683175, 71.42796788896833, 0.977683520742825, 0.25310569416199413, 0.2446508492742266, 0.19769499105002197, 0.27886307345969336, 0.07231241331568786, 0.6788950221879142, 2.6760413646698, 27.89305339540754, 63.54390253339495, 75.40991101946149, 62.11278206961495, 34.625433989933555, 33.57944869995117, 30.584410326821462, 43.846273694719585, 76.2649632862636, 79.80241625649589, 77.11334528241838, 72.52447700500488, 60.36276708330427, 3.293987440211432, 0.6023043234433446, 0.05555312761238643, 0.025211526712934886, 0.04386233564998422, 0.058754686532276015, 0.0245686181754406, 0.05406326827194009, 0.07949251481997115, 0.05806148158652442, 0.019258660962805152, 0.04913006762840918, 0.03417528813172664, 0.021798018898282732, 0.03332431022343891, 0.06496377049812249, 0.09925889809216772, 0.06921186790402446, 0.03251046853672181, 0.05234995038647737, 0.14731436302619322, 0.14908255743128912, 0.1343359694417034, 0.14732241045151437, 0.032864361868372986, 0.04053112904408148, 0.05224338985447373, 0.03215004430551614, 0.032653222126620154, 0.040871092051799805, 0.0332733081387622, 0.11527737283280917, 0.12015124915965966, 0.05852921613092933, 0.06846542510070971, 0.023378101343821203, 0.05299034155905247, 0.01259966756749366, 0.0588353711313435, 0.21183043611901148, 0.22395520550864084, 0.19180563278496265, 0.23065506028277533, 0.15265969905470098, 0.2500750310719013, 0.11773699442190783, 0.15064548142254353, 0.1412043994558709, 0.11580428241619042, 0.20422457424657686, 0.13406921018447193, 0.20434870544288838, 0.21265223702149733, 0.27626048454216545, 0.18348393003855432, 0.14124473157737935, 0.2902277750628335, 0.19904849199312075, 0.11606657691299915, 0.11904196654047285, 0.157876493409276, 0.1719174456915685, 0.14591321535408497, 0.13679025774555548, 0.1341518557497433, 0.1663178083087717, 0.299026827194861, 0.12855947869164602, 0.2527514174580574, 0.09582894428500108, 0.18555604027850287, 21.428847210747854, 121.3478843144008, 101.53443595341274, 107.12640176500592, 99.85004670279366, 73.56412206377301, 50.647417136601035, 33.31803662436349, 60.78707272665841, 112.1545421055385, 90.17554868970598, 77.44297477177211, 68.15269129616874, 15.11921238899231, 0.7407062511358942, 0.13374651250030312, 0.5570490232535771, 0.27692987290876253, 0.3335584242429052, 0.2756272756627628, 0.5758130135280746, 2.325841950518744, 5.781075366905757, 2.2680259900433675, 74.36855670383999, 123.39854785374233, 94.98871871403286, 101.13567188807896, 99.04448645455497, 107.56297097887311, 105.12010942186627, 107.03500516074044, 106.36335754394531, 108.81029769352504, 105.29339054652623, 103.47374766213554, 109.65251663752964, 109.70337745121547, 94.56444086347307, 98.86860670362199, 94.80673149653843, 92.22949872698102, 99.0785882132394, 95.20997020176479, 104.19251101357597, 95.70188181740897, 103.37191486358643, 67.37770312173026, 17.82540372439793, 3.328714971031461, 11.465956398418971, 66.52926553998674, 77.23971911839077, 96.78060354505266, 99.89516830444336, 105.82563645499093, 108.53554507664272, 107.94833891732353, 102.13268974849156, 103.32352760859898, 89.37365014212472, 104.49095698765346, 100.00463717324394, 107.87000492640904, 116.94422721862793, 108.21004281725202, 99.77626378195626, 91.32591329302106, 100.799455506461, 110.75568212781633, 102.65419374193463, 104.19073922293526, 105.90515163966587, 91.92194366455078, 85.73414897918701, 114.89544664110456, 116.00704724448067, 104.9633024760655, 96.04551887512207, 91.4687752042498, 92.69138022831508, 98.39200891767229, 126.78455788748605, 62.47535296848842, 0.6398311097707067, 0.38774395095450537, 0.4431392513215542, 0.2424665093421936, 0.5124580902712685, 0.2697059448276247, 0.7694444347705159, 5.607749513217381, 39.06207765851702, 77.68948990958077, 94.15032127925328, 109.44822570255825, 94.9713829585484, 56.20741081237793, 22.421366112572805, 29.497243063790457, 67.94717053004673, 78.50369371686662, 83.90349320002964, 89.15489305768693, 63.4012907573155, 2.125137588807515, 0.5992790343505996, 0.2412937565573624, 0.061922712251544, 0.1338683231068509, 0.167239869545613, 0.1401855248425688, 0.16329141998929636, 0.19760991632938385, 0.220479762713824, 0.07173776200839452, 0.11801927856036595, 0.1433023347386292, 0.14275194784360273, 0.174497425822275, 0.1626948927130018, 0.21524951979517937, 0.20467571860977582, 0.11931488689567361, 0.12045653563524995, 0.35015126530613216, 0.28820481789963587, 0.23570960334369115, 0.24288350982325418, 0.1121083360963634, 0.13016650745911257, 0.19775912617998465, 0.10362419206649065, 0.12381004568721567, 0.10217701936406748, 0.11994843504258565, 0.2120337387812989, 0.21557513517992838, 0.13579750673047133, 0.26358216628432274, 0.19442772279892648, 0.13585820847323962, 0.09004915585475308], [0.029784440528601408, 0.05638140852430037, 0.041328960697033575, 0.041402334081275124, 0.019894712903935994, 0.022765211195551922, 0.0554920967801341, 0.030698715576103756, 0.06354074685701303, 0.010347464803739317, 0.04843223846650549, 0.09144070904169764, 0.05720980478716748, 0.20301763686750615, 0.06271588576159307, 0.07925415225327015, 0.034724172071686814, 0.05688963464594313, 0.010057605669966765, 0.009619830142972725, 0.08423057557748896, 0.0558449214191309, 0.13515637256205082, 0.013883678042995078, 0.0239434143129204, 0.08216398182724204, 0.03660118992307356, 0.0710040485220296, 0.100815450639597, 0.04799860369946275, 0.229982496372291, 0.01534059620462358, 9.431403994560242, 88.80234840938023, 85.39169311523438, 86.85194042750767, 77.2707428250994, 60.114313398088726, 26.30331424304417, 42.63879142488752, 74.2753883089338, 69.19519206455776, 72.83396366664341, 72.0507766178676, 36.7228102684021, 2.5010221047060828, 0.5684877123151506, 0.03805368234004293, 0.039875908488673825, 0.12664126019392694, 0.056362246695373736, 0.5661054030060768, 0.028418731044179628, 1.4400783202477863, 5.185972579887935, 2.4074127163205827, 70.79306234632219, 103.25654697418213, 85.56402233668736, 97.24653584616524, 86.70149803161621, 88.36913517543248, 88.61407307216099, 94.30213941846574, 93.05394417898995, 91.48627771650041, 93.25791549682617, 93.80188301631382, 93.14870371137346, 95.38948386056083, 86.34108802250454, 85.29072189331055, 77.3218468257359, 80.6075804574149, 85.41496958051408, 89.82301098959786, 77.80404485974992, 75.97987869807652, 87.1758723940168, 85.05206516810826, 82.32882295336042, 53.85121761049543, 37.09124197278704, 49.51562506811959, 57.05655711037772, 82.08339173453194, 83.41748060498918, 84.11824812207902, 81.5328929083688, 82.92046901157924, 91.30210181644985, 117.32622528076172, 102.92855725969586, 72.23651586260114, 90.92559977940151, 92.93936143602643, 93.71019458770752, 101.5719770703997, 96.89398424965995, 85.63843754359654, 80.60256385803223, 82.44564301627022, 100.00210108075822, 98.11729104178292, 98.47135734558105, 100.64693559919084, 103.09081854139055, 81.13984026227678, 71.50706618172782, 80.04073251996721, 87.2458963394165, 83.18238830566406, 86.53162152426583, 83.99248572758266, 88.84854698181152, 76.66595077514648, 106.84000396728516, 31.067146846226283, 1.0444065289837974, 0.17751189906682285, 0.04072659123422844, 0.22890020587614604, 0.04492386636723365, 0.1566166574401515, 0.2707108280488423, 0.15025540521102293, 4.199701411383493, 25.75136498042515, 40.97852979387556, 53.21278933116368, 52.797999245779856, 47.246506690979004, 25.635350908551896, 19.587063891547068, 40.70101179395403, 49.48616470609392, 57.07797840663365, 70.53997421264648, 42.39941208703177, 3.534990485225405, 0.1240505049271243, 0.05127848591655493, 0.026105377856375914, 0.01851965829596988, 0.05575032685218113, 0.050093723061893664, 0.057572705671191216, 0.02793951059824654, 0.009663107106462121, 0.04225333234561341, 0.021400086947583725, 0.0673264701451574, 0.07235495067600693, 0.020186533852081214, 0.057954490184783936, 0.003905738745483437, 0.022251222615263293, 0.06230016092636755, 0.19956226513854095, 0.2374085464647838, 0.05889206273215158, 0.045450304368776936, 0.03635659161955118, 0.11713636879410062, 0.06324995388942105, 0.054359184178922854, 0.03610698233491608, 0.029859045453901802, 0.02589258418551513, 0.03798004771981921, 0.17138555566115038, 0.024755878573549644, 0.044355980054076226, 0.023261176189407706, 0.07641315327158996, 0.028396230822961246, 0.02827977725038571, 0.029191865718790462, 0.025032486766576767, 0.036437055694737604, 0.055534247375492535, 0.07763047902179615, 0.08216469428901162, 0.20112459201897892, 0.06757898695234742, 0.043018434861941, 0.07175434540425028, 0.03342501160555652, 0.03999327469084944, 0.06944617961666413, 0.1237929058926446, 0.11590024083852768, 0.1869150780673538, 0.043726523473326645, 0.011082202029813613, 0.03460129616515977, 0.012151968465851886, 0.07382992295814411, 0.09541101421096496, 0.020212642183261256, 0.023014223369370614, 0.07174008259815828, 0.08411352150142193, 0.07224058359861374, 0.1452023684978485, 0.010431604842389268, 0.21992022916674614, 0.10901788728577749, 18.040144750050136, 110.88132640293666, 96.4843670981271, 109.05941840580532, 98.22034672328404, 95.12317330496651, 47.69171946389334, 29.994344983782085, 33.716217041015625, 48.785324232918875, 80.82906818389893, 81.20320088522774, 44.517170906066895, 2.594807369368417, 0.504866531917027, 0.03951633921159165, 0.0882490160209792, 0.2666116351527827, 0.031209652445146015, 0.5118768843156951, 0.26475842030985014, 1.2347414642572403, 1.7976390251091547, 5.435046826090131, 83.95636204310826, 106.25198486873082, 93.45625182560512, 101.76021071842739, 88.98523889269147, 90.954587663923, 93.75001471383231, 99.93446731567383, 96.85606792994908, 96.26143414633614, 97.01421587807792, 96.88827977861676, 98.6597021647862, 100.20366137368339, 90.64894335610526, 90.17620876857212, 82.45801080976213, 85.90891701834542, 91.73646845136369, 96.3118155343192, 83.77550043378557, 79.09624304090227, 91.13094684055874, 86.88572256905692, 88.18575137002128, 63.30795560564314, 47.46313762664795, 61.20839064461844, 66.86431462424142, 91.90731075831822, 91.68064662388393, 90.9049983705793, 89.90134498051235, 91.20960739680699, 98.81430653163365, 123.52556092398507, 110.25364003862653, 80.54305253710065, 94.79888698032924, 99.5359742300851, 95.2453226361956, 102.0306624003819, 101.640138898577, 91.59207098824638, 84.56999914986747, 85.22137192317417, 102.87686961037772, 102.09240409306118, 102.58526066371373, 103.34975011008126, 107.59386961800712, 88.96393571581159, 75.38533524104527, 84.60921478271484, 87.22926930018834, 84.529630116054, 90.73694229125977, 88.13616902487618, 93.9483232498169, 80.2505681174142, 110.03577927180699, 43.72484350204468, 0.6472514601690429, 0.051796136889606714, 0.11540241326604571, 0.2729433168257986, 0.08539419528096914, 0.1775457715349538, 0.22592330990093096, 0.16321447411818163, 3.380712900842939, 28.202401093074254, 47.425846644810264, 49.70216335569109, 32.63484110151018, 27.957954781396047, 24.220854009900773, 34.52207258769444, 68.6175605228969, 75.66962078639439, 76.20012269701276, 81.35182980128697, 63.35406385149275, 9.940564513206482, 0.01850557021264519, 0.053147836322230954, 0.038917481167508025, 0.06013626525444644, 0.051983063109219074, 0.043855421378144195, 0.05164180749229022, 0.040727622607456784, 0.03191065375826188, 0.04587229547489967, 0.028646557658378567, 0.07585622529898371, 0.010148253707614328, 0.016916948403897028, 0.0452913303992578, 0.030396662319877317, 0.02048048540018499, 0.14523064983742578, 0.18009748389678343, 0.25189296209386414, 0.018725181464105844, 0.04058086905362351, 0.018691885750740767, 0.05045018804126552, 0.08044503549379961, 0.06450116567845855, 0.0912200358829328, 0.04439097210498793, 0.03895478363015822, 0.053445940504648855, 0.12982202880084515, 0.07810785554881607, 0.051286709760980945, 0.03721303852008922, 0.04601864190772176, 0.06378734005349022, 0.10027092628713165, 0.1125723183421152, 0.08832387878958668, 0.17354184495551245, 0.09124150473092284, 0.14319100071276936, 0.12016156289194312, 0.37006062269210815, 0.1841138412377664, 0.1336591307606016, 0.1919694718505655, 0.17648011871746608, 0.1856262143701315, 0.26375831397516386, 0.2061399428972176, 0.2227699269673654, 0.3391113377043179, 0.14697345346212387, 0.11913382661129747, 0.11981734207698277, 0.12964999303221703, 0.17106084951332637, 0.2648089575980391, 0.1416293659380504, 0.08952466185603823, 0.1526160692530019, 0.10629455984703132, 0.17119775073868887, 0.3766400510711329, 0.07306326659662382, 0.23420610544936998, 0.3204320828829493, 25.377511944089616, 132.89567920139856, 106.22340692792619, 112.54008374895368, 97.04930428096226, 73.10927213941301, 36.88384171894619, 63.25903333936419, 99.1251619883946, 97.12046773093087, 92.52259458814348, 94.8013744354248, 61.157390866960796, 4.899490535259247, 1.0452854761055537, 0.14807491935789585, 0.17449942071522984, 0.31564618540661676, 0.17431019086922916, 0.8710882206048284, 0.5318673944899014, 5.320289075374603, 11.5091872215271, 4.542910286358424, 84.25864342280796, 116.71871648515973, 97.02759116036552, 107.95499529157365, 96.33446666172573, 97.1651724406651, 99.18509020124162, 106.33593300410679, 101.39446449279785, 102.23707948412213, 101.97803674425397, 100.63822950635637, 102.6945766721453, 102.6639837537493, 96.23758792877197, 95.07236112867082, 85.86666502271379, 91.43651471819196, 97.93696444375175, 102.11107390267509, 86.71239280700684, 86.35878508431571, 98.61117594582694, 95.03322192600795, 91.77794919695172, 68.53364018031529, 49.64362130846296, 66.42229107448033, 81.15853786468506, 97.40632356916154, 96.54578917367118, 96.696259362357, 95.73364203316825, 96.2839115687779, 106.84142139979771, 130.15751920427596, 112.96242305210659, 84.6476800101144, 100.74241774422782, 105.90486676352364, 104.04869719914028, 104.41469355991909, 102.72307123456682, 95.2798204421997, 88.69051020486015, 91.08703422546387, 109.58200631822858, 108.3833725793021, 105.01982607160295, 110.71810626983643, 112.39605454036167, 91.10800388881138, 78.68634796142578, 87.96976661682129, 95.57091522216797, 92.28227724347795, 99.79897744315011, 95.2158066885812, 96.85048157828194, 85.48558412279401, 123.99755205426897, 39.1813782283238, 1.3253136213336671, 0.5701379094805036, 0.1894011760928801, 0.5358755822692598, 0.18701057508587837, 0.3339860641530582, 0.566885663994721, 0.42292422748037745, 7.612012113843646, 37.89842809949602, 52.90386199951172, 78.66617039271763, 73.33682564326695, 59.18632589067732, 34.88667236055647, 25.199021407536097, 54.49124050140381, 69.08621651785714, 75.15359197344098, 95.8204597745623, 72.43141283307756, 8.33643651008606, 0.17919381095894746, 0.19885638515864099, 0.1175180718834911, 0.17839755011456354, 0.16310466001076357, 0.15431459168238298, 0.10786021833441087, 0.12327841350010463, 0.0834842413397772, 0.1982156988233328, 0.13592014514974185, 0.18320317938923836, 0.19358492802296365, 0.10125364855464015, 0.16351053251751832, 0.07341925999415772, 0.15883782825299672, 0.1798810583672353, 0.3847512315426554, 0.36704798149211065, 0.14427770168653556, 0.15498316580695765, 0.14639942640704767, 0.16007481116269315, 0.3175872841051647, 0.19111318779843195, 0.1548412162810564, 0.18957721521811827, 0.19746884889900684, 0.20314450934529305, 0.2812212812049048, 0.20370689273944922, 0.19169804427240575, 0.14107120303171022, 0.12124685251287051, 0.14834773114749364], [0.03149193997627922, 0.04162066290155053, 0.054146019010139365, 0.033917241264134645, 0.06976083666086197, 0.014623092919854181, 0.04222167868699346, 0.005217084004211107, 0.05712754598685673, 0.018796263096321906, 0.03893157773252044, 0.027093826959441816, 0.042096105603767295, 0.045034766130681546, 0.03106800147465297, 0.055828989416893036, 0.03758018703332969, 0.06563607656529971, 0.058521066925355365, 0.019180191780573556, 0.0235544152757419, 0.06660817297441618, 0.04011543135025671, 0.05336395651102066, 0.04695955624005624, 0.057387811663959704, 0.053207907027431896, 0.1198860505329711, 0.05477581825107336, 0.07090585771948099, 0.22595905512571335, 3.7750731110572815, 76.66676371438163, 75.91692107064384, 67.60622937338692, 59.25703770773751, 53.41674675260271, 32.97755752290998, 48.3508186340332, 71.55592591421944, 70.06131281171525, 85.98520129067558, 81.48079531533378, 22.71895398412432, 0.517211092369897, 0.042541509560708485, 0.10704550133751971, 0.03105826788981046, 0.1041272511439664, 0.2638167765523706, 0.09149502576994044, 1.3434809893369675, 1.2446441671677997, 5.517400784151895, 27.909112419400895, 92.44293349129813, 101.71658992767334, 88.07703985486711, 94.35753740583147, 75.365567616054, 76.24919782366071, 87.93991715567452, 97.6110313960484, 95.60250173296247, 99.23827171325684, 97.90465532030377, 100.14512974875313, 95.93616812569755, 98.7388004575457, 91.40697792598179, 85.10535785130092, 73.86663273402623, 77.83026736123222, 78.01722254071916, 83.24560996464321, 88.63195773533413, 85.95161369868687, 71.2974112374442, 84.17877388000488, 82.91570254734584, 97.8456929070609, 65.86619200025285, 48.50664588383266, 52.97820772443499, 71.46937915257045, 91.27094609396798, 87.43440096718925, 83.62680898393903, 85.22610364641461, 88.48923478807721, 94.68826471056256, 100.64075170244489, 84.25119495391846, 85.07076971871513, 93.1295475278582, 92.42468057359967, 95.90460245949882, 87.1535130909511, 94.73696463448661, 89.92427403586251, 80.85012817382812, 74.3715374810355, 82.38819531032017, 96.50227955409459, 95.24078546251569, 91.9552116394043, 88.43165506635393, 94.03808007921491, 85.13485990251813, 80.50828375135148, 72.21066161564418, 70.62069838387626, 72.96572235652378, 75.93195002419608, 80.26757035936627, 91.18434374673026, 82.99073614392961, 90.08463845934186, 25.03368728501456, 0.29347966771040646, 0.5618427374533245, 0.04006920615211129, 0.13251650493059838, 0.06249702429132802, 0.07759702724537679, 0.15485750112150395, 0.19815959754799092, 1.8022899755409785, 15.696296760014125, 41.34983457837786, 79.42188426426479, 75.30840478624616, 67.36267416817802, 33.647950989859446, 19.414646080562047, 27.71909134728568, 33.83040721075875, 50.68860605784825, 69.48709283556256, 60.77545533861433, 25.6331570148468, 0.38703414904219763, 0.031078362704387734, 0.13118342789156096, 0.07056526028152023, 0.11294127175850527, 0.011102101765573025, 0.02751585029597793, 0.11243695739124503, 0.03994044056162238, 0.05791929457336664, 0.016825571789273193, 0.031114311489675726, 0.04659036872908473, 0.044593341781624725, 0.0437624417245388, 0.029995556521628584, 0.13840469611542566, 0.01692305861173996, 0.02466496845175113, 0.07844793730016265, 0.0175080287403294, 0.017185527831315994, 0.03143525516082134, 0.04704381332599691, 0.0879519126777138, 0.020423096604645252, 0.025456523655780723, 0.023034314791272794, 0.040833100876105685, 0.021478842810860703, 0.06784158000456435, 0.06359364544706685, 0.1072299542969891, 0.0500262359689389, 0.1373732007507767, 0.12677518943590776, 0.04242378712764808, 0.013107722359044211, 0.1364598519035748, 0.017309396095307808, 0.016894229355135133, 0.03868138151509421, 0.04395279793867043, 0.05441095979352083, 0.050772811086582284, 0.014959435943248016, 0.04116078579266157, 0.052267552486487796, 0.038980130305779834, 0.06723608249532324, 0.08710653268332992, 0.05899170559964009, 0.04362315884126084, 0.03553232763494764, 0.047193009605897326, 0.04483507666736841, 0.04560373470719371, 0.15996079013815948, 0.07625863049179316, 0.021105495880224874, 0.030400594430310384, 0.02895164057346327, 0.16778556097831043, 0.047010290303400586, 0.13108156621456146, 0.2540676125458309, 7.094014355114528, 98.55762617928642, 88.23433317456926, 87.9081916809082, 85.8367669241769, 87.2089319229126, 47.83228152138846, 21.199520179203578, 40.59572574070522, 63.51351111275809, 91.82948398590088, 89.1088126046317, 27.197232995714458, 0.3284852350396769, 0.14424085723502295, 0.1690215260854789, 0.3016413854701178, 0.1963296021733965, 0.5216889349477631, 0.16985753551125526, 1.380116234932627, 2.05937180348805, 10.866943512644086, 37.836498805454795, 104.68196991511753, 107.6452307019915, 94.05256012507847, 97.04570511409214, 78.36934334891183, 79.93395955221993, 95.08665357317243, 101.40109307425362, 100.14243384769985, 102.39365713936942, 102.42081069946289, 104.02102252415249, 100.82595593588692, 101.97792557307652, 94.37930611201695, 86.70367281777519, 77.55159596034459, 83.42781257629395, 82.63814980643136, 88.04020745413644, 91.84071227482387, 90.61152730669293, 74.44026906149728, 84.0427906853812, 88.02606092180524, 100.69104276384626, 72.00154863085065, 52.47045769010271, 60.98512417929513, 81.61240114484514, 94.94894027709961, 91.40507411956787, 89.27890450613839, 89.58176953451974, 95.84516062055314, 100.58299827575684, 106.20336832318986, 90.12876646859306, 89.11483669281006, 94.86145550864083, 92.87342997959682, 100.24232809884208, 91.01972702571324, 98.16573388235909, 94.47767870766776, 87.94883169446672, 78.97391305650983, 84.19324697766984, 100.76006616864885, 97.23013114929199, 95.41275337764195, 94.49302727835519, 98.31281335013253, 89.12714195251465, 83.70863097054618, 78.35287611825126, 78.19979340689522, 78.71416854858398, 79.66842719486782, 84.65919317517961, 97.99140357971191, 88.53932435171944, 93.5993013381958, 39.39799526759556, 1.4191201648541858, 0.4865400610225541, 0.08401752236698355, 0.037327727901616266, 0.19469563556568964, 0.11714308629078524, 0.07554294568087373, 0.018176697859806672, 1.5639356055430003, 16.826247555868967, 45.93493345805577, 63.145659582955496, 45.65134968076433, 26.107453210013254, 20.88813144820077, 29.35266147341047, 51.27950171061924, 63.12578773498535, 66.46046447753906, 80.82929052625383, 80.30758503505162, 43.40360743658883, 3.1067443447453633, 0.033057700243911574, 0.060917917239878855, 0.022812562761828303, 0.03210498958027788, 0.15198443457484245, 0.07547384367457458, 0.06434318915541683, 0.040892588041190586, 0.1224150862544775, 0.016624272501628314, 0.07646053537194218, 0.05605017486959696, 0.03607528796419501, 0.06409960186907224, 0.015003016551158257, 0.09933827990399939, 0.04352986706154687, 0.03633157403341361, 0.08210618421435356, 0.04686754010617733, 0.04036980734339782, 0.03064200361924512, 0.048224240341889005, 0.06769667885133199, 0.018124484590121677, 0.020735933478655558, 0.026717784548444406, 0.06270113441028766, 0.08248407393693924, 0.2514270528086594, 0.07986530874456678, 0.07612003292888403, 0.11438220872410707, 0.08045521351907935, 0.21986799554101058, 0.07898460421711206, 0.11679566279053688, 0.17654248965638025, 0.1640405362205846, 0.08379669314516441, 0.20872145651706628, 0.08082245024187223, 0.1196627039462328, 0.14815459293978556, 0.13439695616917952, 0.08265362626739911, 0.19721320404538087, 0.12779654748737812, 0.11478922116969313, 0.10804477985948324, 0.12357937092227594, 0.19474405582462037, 0.11358653141983918, 0.12846357455211027, 0.0779041118387665, 0.15261623210140637, 0.2058626799178975, 0.1547991878220013, 0.1362291228558336, 0.1468421976481165, 0.0849336057103106, 0.25238761412245886, 0.2234851164477212, 0.22232896062944615, 0.4485957313861166, 11.469305430139814, 119.49518884931291, 95.49563149043492, 93.89906747000558, 75.0457489831107, 72.76807389940534, 44.40162583759853, 66.9479570388794, 95.05205154418945, 96.05091762542725, 105.22184494563511, 104.8620741707938, 38.01672812870571, 1.0432239238704955, 0.3412336323942457, 0.5180034041404724, 0.5503309294581413, 0.3123648443392345, 0.6733913432274545, 0.2991201121892248, 2.581853538751602, 4.523368912083762, 10.060832619667053, 32.63004337038313, 106.40083612714494, 117.24743270874023, 97.62243338993618, 104.3736297062465, 83.75015340532575, 83.78573513031006, 99.04370825631278, 106.88420145852226, 104.765383039202, 107.37586293901715, 105.67312349591936, 109.77336665562221, 105.28489984784807, 106.66853632245744, 100.33847032274518, 94.93286909375871, 84.02763666425432, 89.3475318636213, 88.82461043766567, 95.44270706176758, 96.00294726235526, 97.75879178728376, 78.43627534593854, 91.4573106765747, 92.34793077196393, 105.63064220973423, 76.15117263793945, 65.81376089368547, 74.55217674800328, 86.34276253836495, 98.43951375143868, 96.08665915897915, 95.48022038596017, 98.49930300031389, 102.69222818102155, 106.97052587781633, 110.52648884909493, 97.0791676385062, 97.39515086582729, 101.88502815791539, 98.71325193132672, 105.00085748944963, 95.90374088287354, 103.78162928989956, 100.22065666743687, 92.71223872048515, 83.88747760227749, 89.09849452972412, 106.50811631338937, 100.36913967132568, 96.67494923727853, 98.54096439906529, 104.26473058973039, 95.96737248556954, 88.59363842010498, 80.66000461578369, 79.1165943145752, 80.63723536900112, 83.40693323952812, 91.30158764975411, 103.61310768127441, 89.7877002443586, 97.4094363621303, 33.94049446923392, 1.3710989930800028, 0.6224082303898675, 0.4142826497554779, 0.12654589888240608, 0.4052581340074539, 0.30674614012241364, 0.2401887487087931, 0.20697494809116634, 3.6510403837476457, 29.43004356111799, 60.486243520464214, 103.01188005719865, 111.53825773511613, 88.21768529074532, 46.64735310418265, 27.324167898723058, 38.94201626096453, 47.30032743726458, 66.66758332933698, 87.15811279841832, 92.48698507036481, 43.01171513966152, 2.6431470726217543, 0.23731157023991856, 0.17165747178452356, 0.19618558990103857, 0.20505310621644768, 0.3290611212807042, 0.20592084393969604, 0.24178507019366535, 0.1630732166979994, 0.19932192803493567, 0.11839908175170422, 0.15645384974777699, 0.10470591937857014, 0.19258312535073074, 0.1212585097444909, 0.16954896492617472, 0.3256146247897829, 0.06480665571455445, 0.16411516150193556, 0.3391763413591044, 0.1746251939662865, 0.09358368547899382, 0.1363333865467991, 0.23769016563892365, 0.2595073735075337, 0.09422773734799453, 0.13907420661832604, 0.10921587023351874, 0.24276864741529736, 0.09245143444942576, 0.3297913335263729, 0.2668187511818749, 0.15519470588437148, 0.2380468850689275, 0.21190664917230606], [0.03329173714986869, 0.040866654432777844, 0.030228216001497846, 0.013542402918184442, 0.02921964494245393, 0.005808259759630475, 0.0415400529413351, 0.030097631937158958, 0.028651382042361156, 0.0322493173714195, 0.018703035777434707, 0.05380338257444756, 0.08285854384303093, 0.06957791040518455, 0.03830234506832702, 0.05306308051305158, 0.07863450050354004, 0.02661342077356364, 0.09220055291163069, 0.024528233467468193, 0.031098674650170972, 0.038015619918171845, 0.021699683907042657, 0.03208000592089125, 0.04389033539752875, 0.036261766350695064, 0.06182954939348357, 0.15808607930583612, 0.07940917036363057, 0.05369933262201292, 3.304277070931026, 53.79216834477016, 85.83605125972203, 83.9449600492205, 67.76725387573242, 58.531110763549805, 28.160060507910593, 66.13120324271065, 106.71786853245327, 73.55328982216972, 88.9862950188773, 69.68016242980957, 17.58432728903634, 0.18012037766831263, 0.02410534330244575, 0.08270545277212348, 0.11496166405933243, 0.09713110726858888, 0.1922519188374281, 0.45460046774574686, 0.32825168328625814, 22.19651198387146, 65.41437149047852, 102.86445317949567, 114.18604946136475, 96.7201681137085, 92.74334580557687, 95.51712921687535, 80.63645717075893, 83.84737954820905, 77.28012289319719, 86.63173116956438, 93.34933989388603, 93.16128689902169, 92.4803773335048, 94.01608903067452, 94.1944979258946, 91.88519464220319, 87.389084815979, 80.44420746394566, 79.10700580051967, 79.39530045645577, 77.37078298841203, 83.33173288617814, 85.95741544451032, 87.5790763582502, 79.57320213317871, 65.47876044682094, 78.00104713439941, 81.97083786555699, 90.01537881578717, 78.66091060638428, 52.29994889668056, 64.92380782536098, 87.1932498386928, 90.41055066244942, 80.37847750527519, 74.96851975577218, 77.55083860669816, 82.81768430982316, 89.89567525046212, 99.55953557150704, 82.30138451712472, 80.50861031668526, 89.3300085067749, 86.61855043683732, 96.3770730154855, 101.81302397591728, 88.72523730141776, 93.92424774169922, 86.30196966443742, 81.45122378213065, 72.61072499411446, 86.45266914367676, 97.3098339353289, 101.58875002179826, 100.90827124459403, 95.835294178554, 82.43087114606584, 73.32231085641044, 80.1407379422869, 87.34960515158517, 93.49687794276646, 91.16288076128278, 87.61982754298619, 87.43340737479073, 93.72263186318534, 82.44655323028564, 85.98074749537876, 56.66266025815691, 7.057775156838553, 0.675954034285886, 0.07071828349892582, 0.08785179483571223, 0.13011184467801026, 0.05965656813766275, 0.040166246837803295, 0.3060084639915398, 0.12361229344138078, 10.137606739997864, 66.75986235482353, 102.6154853275844, 72.31149387359619, 72.17811625344413, 44.80901609148298, 21.677469389779226, 26.107694659914287, 47.104999678475515, 50.99631398064749, 61.73082569667271, 72.0148891721453, 59.737589018685476, 5.2903618812561035, 0.34103927282350405, 0.10681603436491319, 0.023423381681953157, 0.08576981869659253, 0.03461994230747223, 0.05385024220283542, 0.028681047593376467, 0.10687016788870096, 0.04432991073865976, 0.0373660142400435, 0.04313694439562304, 0.03402683145499655, 0.08607733076704399, 0.02833601592906884, 0.0038909538915114744, 0.053026517653571706, 0.011931543820537627, 0.0348872884974948, 0.045160593664539714, 0.08245269169232675, 0.08156021458229848, 0.031044480058231523, 0.07559460255184344, 0.05754370508449418, 0.01939903968013823, 0.03897636104375124, 0.028884238297385827, 0.07875232132417814, 0.033679292603795014, 0.040163831253136904, 0.025234288170135448, 0.018229128260697638, 0.025254966524828757, 0.023013007095349685, 0.020972913530256067, 0.049952411358909946, 0.03799419517495802, 0.026657571350889545, 0.06923445633479527, 0.04212514011721526, 0.07678447477519512, 0.031434776793633185, 0.05670757691508957, 0.057900139529790194, 0.024095051622550403, 0.05056954235104578, 0.055250104051083326, 0.017612414567598274, 0.07398036774247885, 0.05756385757454804, 0.14070469912673744, 0.06934558001479932, 0.0026255558436137755, 0.07160115933844022, 0.05709168541112116, 0.04259273556194135, 0.034100126807710955, 0.04610884635310088, 0.05632648789989097, 0.01891139182927353, 0.06802633830479213, 0.1348779967853001, 0.008127246484426516, 3.974395649773734, 75.11088834490094, 93.926408631461, 100.9880713054112, 93.4250683103289, 75.96292509351457, 44.67093106678554, 38.3883455821446, 70.38388293130058, 72.22290434156145, 93.2072422845023, 78.14615331377301, 20.66039034298488, 0.0985241396618741, 0.05155555551339473, 0.05379969473662121, 0.24984183215669223, 0.041821570335222144, 0.07216601260006428, 0.6826911270618439, 1.8805592613560813, 31.02548197337559, 79.46162796020508, 111.57063634055001, 116.97532735552106, 100.25895513807023, 98.47929913657052, 98.20873628343854, 85.0629529953003, 89.53987884521484, 81.2106215613229, 88.36800261906215, 96.11508423941476, 95.80228328704834, 96.97689710344586, 97.20528439113072, 95.23173890795026, 96.13122490474156, 88.88596303122384, 84.88796261378697, 82.74724347250802, 82.74943910326276, 82.61708981650216, 89.06734575544084, 92.59366771153041, 93.95471559252057, 83.1403169631958, 67.92082296098981, 80.16321536472866, 86.34258188520158, 90.60749040331159, 85.29399449484688, 58.667045320783345, 74.1625565120152, 94.84181989942277, 97.156341280256, 86.69818374088833, 80.0727150780814, 85.938294001988, 88.54191602979387, 95.74690614427838, 103.62271009172711, 89.2292457308088, 86.58207239423479, 93.36059597560337, 89.83967971801758, 98.72937175205776, 103.42506858280727, 91.54482323782784, 97.21093327658517, 93.24896621704102, 85.31046867370605, 77.97539438520158, 88.70435101645333, 98.83387960706438, 103.7704496383667, 106.66943958827427, 100.14132908412388, 87.60373551504952, 75.53102506910051, 81.26974378313336, 92.01451451437813, 97.22487831115723, 98.44097287314278, 93.99942725045341, 89.91343484606061, 96.29878071376255, 85.10200187138149, 91.80603381565639, 76.17476177215576, 16.136430399758474, 0.17401418675269398, 0.07188910245895386, 0.0902433322210397, 0.22100460955074855, 0.09853947455329554, 0.0066177626389877075, 0.39047616720199585, 0.06441114443753447, 10.003397941589355, 67.58193152291435, 91.10732991354806, 65.10113280160087, 40.579084805079866, 21.289285693849834, 26.3731940133231, 34.50883279527937, 80.33132702963692, 75.92260469709123, 76.05488450186593, 81.51290988922119, 81.34847382136753, 13.683394942964826, 0.5054844873292106, 0.07306648285261222, 0.13437814717846258, 0.105365658977202, 0.033922180999070406, 0.013970566996639329, 0.020891535129132013, 0.08699999590005193, 0.04353234710704003, 0.05026662735534566, 0.022584954975172877, 0.03893055992999247, 0.03545961242967418, 0.04977915083457317, 0.028440218551882675, 0.052581894011901956, 0.05491324873375041, 0.023951604230595485, 0.04924607336787241, 0.04463992999600513, 0.041534577163734605, 0.049828697461634874, 0.04936945478298834, 0.06631891349596636, 0.039625895475702624, 0.06479607735361372, 0.059481512888201644, 0.06593277957290411, 0.04158693292577352, 0.013555893042523946, 0.043196370492556264, 0.03238931271646704, 0.026867537227060114, 0.11701743517603193, 0.10077355110219546, 0.14393038675189018, 0.07569222338497639, 0.0858844029051917, 0.12981240717428072, 0.17748124285468034, 0.19232919040535176, 0.11502191796898842, 0.1446705191795315, 0.08512398228049278, 0.11416145414113998, 0.12888886673109873, 0.19872317516377994, 0.2185024166745799, 0.13694957776793412, 0.1532659022403615, 0.25411646706717356, 0.14098017077360833, 0.10188279979463134, 0.16096807537334307, 0.14694285153278283, 0.17197084639753613, 0.12696545065513679, 0.1774937143283231, 0.12045907335621969, 0.13009186860706123, 0.30941468264375416, 0.4221905411354133, 0.11354037746787071, 6.411981787000384, 94.47116129738944, 109.8882759639195, 110.99745859418596, 91.1713923045567, 74.9863279887608, 35.027748584747314, 90.48147787366594, 144.08705929347445, 96.78803811754499, 103.44724028451103, 93.38376126970563, 30.199434961591447, 0.4732641162616866, 0.15040043528590882, 0.3469211400619575, 0.4594894211207117, 0.24499568077070372, 0.29538331127592493, 0.9362986385822296, 1.7257656646626336, 28.078717947006226, 72.2681440625872, 112.1820569719587, 122.956545148577, 104.43375941685268, 101.50775487082345, 107.02976621900285, 89.86315768105644, 94.13812719072614, 85.8050206048148, 94.01497037070138, 101.97123445783342, 103.1405051095145, 101.61259623936245, 101.52340916224888, 101.50021607535226, 101.21529824393136, 95.1366319656372, 89.35322938646588, 88.61479568481445, 87.48096084594727, 89.19927815028599, 94.7584067753383, 96.30577754974365, 98.89234869820731, 90.43449415479387, 73.7402936390468, 86.15935094015938, 91.02814824240548, 96.80534608023507, 91.2693896974836, 63.777480125427246, 81.51544598170689, 99.25414139883858, 103.35382175445557, 94.53106866564069, 89.06985405513218, 94.57305662972587, 97.24520179203579, 103.06313691820417, 112.4781197139195, 95.3610657283238, 90.90433829171317, 99.56113365718296, 94.93692684173584, 103.61462933676583, 106.5407520021711, 95.01806095668248, 100.78156389508928, 96.54296820504325, 88.74876390184674, 82.15240124293736, 95.4901841027396, 105.8937565939767, 108.20387976510185, 108.18767656598772, 104.98646082196916, 89.47607353755406, 78.24255956922258, 85.03684861319405, 96.51924705505371, 104.3185374396188, 103.60395690373012, 96.62825734274728, 92.08257211957658, 102.26861040932792, 88.76275757380894, 96.60200704847063, 71.22152996063232, 10.90160460131509, 0.9646887608936855, 0.36276140436530113, 0.1946637308491128, 0.3997075818479061, 0.14584312268665858, 0.11295587383210659, 0.581154115498066, 0.23445919901132584, 18.873551641191753, 86.25106021336147, 117.05955341884068, 100.51413467952183, 102.71434429713658, 63.106846945626394, 31.837851456233434, 31.678991317749023, 64.10383006504604, 69.51442010062081, 77.776015826634, 96.55962998526437, 93.84685175759452, 14.11168885231018, 0.618757603423936, 0.19390089463974747, 0.2240366975643805, 0.22081407691751206, 0.124353877933962, 0.1821435248213155, 0.10413438933236258, 0.203330292233399, 0.10849565280867474, 0.21961598763508455, 0.24631689701761517, 0.10348804401499884, 0.267366030386516, 0.11300892169986453, 0.1366859126303877, 0.15115644543298654, 0.19555641151964664, 0.07909504936209746, 0.1323274786451033, 0.18698869911687716, 0.15068999331976685, 0.09219821196581636, 0.11898376180657319, 0.15347233973443508, 0.06395786268902676, 0.10253654792904854, 0.17325103841722012, 0.20622988949928964, 0.11270919242607695, 0.09150115294115883, 0.09304954271231379, 0.08476420265755483, 0.13931146317294665], [0.010285931007404412, 0.08500443119555712, 0.06363179947116546, 0.04786091198080352, 0.0647627477134977, 0.055812324596835036, 0.0506129075240876, 0.06444003645862852, 0.028855549836797372, 0.027282118730779206, 0.040474328877670426, 0.00841709628834256, 0.06498702389321157, 0.06571949566049234, 0.013594540700848614, 0.02199704509361514, 0.03015838117737855, 0.00470117135306022, 0.021281704639217684, 0.037654659644301446, 0.040146437007933855, 0.02077107480727136, 0.06491800331111465, 0.13135257310100965, 0.046981106512248516, 0.012979865157311516, 0.01878879581844168, 0.12294249795377254, 0.08365046884864569, 0.5343036066208566, 32.06972326551165, 82.07885456085205, 87.78049768720354, 69.96565696171352, 55.675185748508994, 45.128883361816406, 60.95030675615583, 70.87150750841413, 70.29751682281494, 82.42733451298305, 50.841181550707134, 16.021463768822805, 0.24414121519242013, 0.08493131904729775, 0.07362897481237139, 0.040491126012057066, 0.06501281500927039, 0.21979536515261444, 0.4322302538369383, 9.947484919003077, 78.79175213405064, 109.40847505841936, 103.68119307926723, 88.09745366232735, 83.66854681287492, 95.43114525931222, 94.47487163543701, 88.75044536590576, 89.6744862965175, 79.99656976972307, 80.23403835296631, 76.71530382973808, 88.25572667803083, 93.08037512642997, 90.48869705200195, 93.63384083339146, 91.78821168627057, 86.16447871071952, 80.53830691746303, 77.0460867200579, 74.41418552398682, 79.43866416386196, 84.59843117850167, 86.05496120452881, 87.35706056867326, 84.52489144461495, 75.45469215938023, 69.85127571650914, 73.57329368591309, 82.75442790985107, 89.56400993892125, 93.86114420209611, 62.179588999067036, 61.52527018955776, 86.25405488695417, 91.43364511217389, 90.91872801099504, 85.24389103480748, 88.63037354605538, 86.97705663953508, 88.77492386954171, 84.05023915427071, 84.77778502873012, 93.00155476161412, 87.24640355791364, 86.38256181989397, 89.90087945120675, 95.47411986759731, 93.81983021327427, 87.74616663796562, 90.24270302908761, 79.77586024148124, 75.06790678841728, 67.00130530766079, 80.97645337241036, 88.13880239214215, 92.60601466042655, 93.44714968545097, 87.71600450788225, 73.25775514330182, 81.77799756186349, 85.50667885371617, 86.56337479182652, 88.23900236402238, 92.13927636827741, 93.65592220851353, 89.12036745888847, 90.8861062186105, 86.05360630580357, 91.76047447749546, 93.67498806544712, 27.983069045203074, 0.22615580313972064, 0.10863003666911807, 0.08316174043076378, 0.07910999748855829, 0.0814871092193893, 0.22384628706744739, 0.09463307381208454, 0.2091439531317779, 4.096854610102517, 55.41795301437378, 76.05455098833356, 41.61681910923549, 64.31923116956438, 70.2116231918335, 45.83346891403198, 16.48814821243286, 21.233149460383824, 33.827395166669575, 56.30423048564366, 70.26147651672363, 53.55603381565639, 4.453941208975656, 0.4163243887679917, 0.02311281281124268, 0.053685378549354415, 0.11265942188245909, 0.03623236882101212, 0.04072918663067477, 0.03705672101516809, 0.026821391756779382, 0.05668980947562626, 0.027978017460554838, 0.06521455704101495, 0.08012837677129678, 0.04323816824970501, 0.03833645163103938, 0.009258844424039125, 0.09058578884495155, 0.055598871050668616, 0.07484791547592197, 0.08236277223165546, 0.029707019682973623, 0.006365389172320387, 0.01046686661097088, 0.0725651201126831, 0.05185676060084786, 0.056165834556200674, 0.053822201743189774, 0.04927109773936016, 0.08305755816400051, 0.04253722121939063, 0.007608257949219218, 0.0369964196080608, 0.020379571975874047, 0.04708520056945937, 0.03817816298188908, 0.06861736944743566, 0.04654528007709554, 0.05489825650251337, 0.029613263106771877, 0.02443334204144776, 0.061814465560019016, 0.09781714009919337, 0.0206658306332039, 0.06283839525921003, 0.04674260823854378, 0.07233939186802932, 0.05540990583332522, 0.011493445141240954, 0.02399705589881965, 0.02218842419928738, 0.010982702502847781, 0.016318005542936068, 0.010594092775136232, 0.0569778543763927, 0.012206915383493262, 0.05422915651329926, 0.1424176607813154, 0.039509309588798454, 0.054590971741293154, 0.057912319233374934, 0.13188572520656244, 0.11347685301942484, 0.6205902450851032, 49.38432495934622, 95.72127423967633, 107.84225382123674, 91.81359345572335, 81.33019311087472, 60.09901346479143, 20.380014896392822, 51.858835560934885, 76.48659692491803, 92.46559156690324, 61.263774735586985, 19.49444787842887, 0.1802328516330038, 0.02145929930598608, 0.06805558316409588, 0.09637650847434998, 0.12950432513441357, 0.10613876142139946, 0.3177972228399345, 15.934953485216413, 94.46201051984514, 114.97867911202567, 110.3079263142177, 90.57929461342948, 90.61470263344901, 102.23406396593366, 99.68113599504743, 93.52334363119942, 92.75035653795514, 84.96155098506382, 85.96707344055176, 84.17886420658657, 91.40656103406633, 95.60697637285504, 93.60347720554897, 96.11273574829102, 94.78436524527413, 88.56841645921979, 86.40370518820626, 79.65783814021519, 77.84720706939697, 81.54125159127372, 89.00897393907819, 89.51719297681535, 90.46708120618547, 88.68660531725202, 79.70196614946637, 73.17054830278668, 76.35364314488002, 86.05261966160366, 93.70933995928083, 96.04263537270683, 66.77990790775844, 65.31130886077881, 89.18515246255058, 92.66587339128766, 95.64027908870152, 91.68598978860038, 95.0044424874442, 92.1657281603132, 97.50405693054199, 92.10721737997872, 90.58859130314418, 95.35197748456682, 90.20728806086949, 87.69331169128418, 91.01778847830636, 97.99159812927246, 94.97473893846784, 88.7051500592913, 93.77809238433838, 84.12674576895577, 77.82853725978306, 69.80015781947544, 84.20668479374477, 90.3290274483817, 93.7301150730678, 93.40221568516323, 88.60429000854492, 76.10569667816162, 87.26398944854736, 89.67204053061349, 90.13704872131348, 89.84739221845354, 95.62919671194894, 97.71251678466797, 91.03947380610875, 94.39236872536796, 89.63666725158691, 91.70673016139439, 102.43608978816441, 43.378086703164236, 1.1769499310425349, 0.1758501532354525, 0.1808078150664057, 0.049901246425828764, 0.059736947395971844, 0.10511723373617445, 0.11531583219766617, 0.3945440117801939, 3.5904316817011153, 59.18862574441092, 81.3071598325457, 42.46853276661464, 46.74150814328875, 28.541831016540527, 21.35243092264448, 18.003487791333878, 39.98668139321463, 64.89176968165806, 71.27774783543178, 77.29756981985909, 71.80299690791539, 12.760317206382751, 0.3916404518697943, 0.07938895680542503, 0.06586856301873922, 0.0905404287789549, 0.030518255795219114, 0.03349521623126098, 0.006280788153942142, 0.06981205248406955, 0.004917985767990882, 0.021209946168320518, 0.020377098715731075, 0.02180833602324128, 0.07900659553706646, 0.0551681336281555, 0.02187243213744036, 0.022379465733787844, 0.037868374426450045, 0.02341433850649212, 0.07650728643472705, 0.02873560520155089, 0.03504264587536454, 0.008691642583081765, 0.08753058314323425, 0.014414657140150666, 0.07544545376939432, 0.018488533894664476, 0.06463497278413602, 0.05941404615129743, 0.052364830659436326, 0.04209882992186716, 0.030192060263029168, 0.0577653417629855, 0.14057727025023528, 0.14026727474161557, 0.2116481409009014, 0.13671074701207026, 0.17055436383400643, 0.1933946939451354, 0.10023998509028129, 0.14523401537111827, 0.2033220005354711, 0.11830241765294756, 0.2681335620582104, 0.1506120160754238, 0.12906399661941187, 0.17497611870723112, 0.1969223160828863, 0.12487550851489816, 0.09227553781654153, 0.07451844601226704, 0.12730878937457288, 0.14069465680846147, 0.11520121406231608, 0.14866574694003376, 0.1395949415330376, 0.312324512217726, 0.0838382194883057, 0.07991793592061315, 0.12670004846794264, 0.31398762868983404, 0.356800447085074, 1.6471528772796904, 67.2983477456229, 111.83217348371232, 112.67289856501988, 92.15882165091378, 70.08149732862199, 65.15878895350865, 83.11543546404157, 104.75090299333844, 90.63277489798409, 98.46235248020717, 75.15418951851981, 30.133548668452672, 0.5145448297262192, 0.11989739563848291, 0.16272238695195743, 0.18858523773295538, 0.39787209033966064, 0.385694042380367, 0.7690641837460654, 13.974719882011414, 93.58512006487165, 122.7012266431536, 120.94481931413922, 97.83663940429688, 93.7000571659633, 106.251540184021, 106.56387560708183, 97.05928884233747, 97.4454836164202, 89.2665992464338, 90.22797284807477, 87.33484022957938, 98.14487539018903, 101.05954047611782, 97.98359380449567, 102.22572612762451, 102.24257550920758, 93.90652983529228, 90.7326135635376, 86.02884987422398, 82.83301203591483, 88.63545962742397, 92.97019059317452, 95.00414371490479, 96.7751214163644, 95.28640038626534, 87.49924155644008, 78.34018175942558, 78.50261674608502, 91.51755850655692, 99.56741482870919, 101.14243248530796, 73.10779217311314, 74.28894424438477, 96.04694325583321, 96.55395330701555, 102.2766147341047, 96.47185339246477, 101.72513621194022, 97.58010496412004, 102.04664325714111, 99.74191188812256, 98.90471649169922, 103.48571940830776, 96.48490905761719, 92.01796776907784, 98.24756281716483, 106.02942017146519, 98.50679315839494, 91.55670465741838, 100.31874438694545, 91.5929742540632, 81.93383175986153, 75.12693173544747, 91.36435767582485, 95.32669298989433, 98.77621650695801, 98.56160054888043, 94.64499827793666, 79.39019353049142, 89.92385714394706, 94.38084861210415, 94.24036993299211, 93.79043933323452, 101.03113624027797, 104.26025594983781, 93.9234139578683, 97.22223799569267, 94.03436974116734, 100.44441645486015, 107.45947061266217, 34.25343438557216, 0.732725702226162, 0.44465463714940207, 0.3414496236613819, 0.16582046928150312, 0.11856632706310068, 0.32949834210532053, 0.2409655355981418, 0.5223304490957941, 7.712296332631793, 73.84756687709263, 87.4936968939645, 63.24348327091762, 93.19319997514997, 96.51321601867676, 67.37593133108956, 21.69761916569301, 30.924917221069336, 49.41153410502842, 71.77658680507115, 86.12747260502407, 86.3289703641619, 12.197804944855825, 0.5709288098982402, 0.30835690083248274, 0.1791077455771821, 0.20554265566170216, 0.10620580068124191, 0.19381305149623326, 0.08470808102616242, 0.1528518194598811, 0.12428375812513487, 0.07699250004121236, 0.17094058596662112, 0.1603947268532855, 0.09391677153429814, 0.1525807718613318, 0.1198845441852297, 0.20225661913199083, 0.13597430581493036, 0.15111919386046274, 0.16644280802990707, 0.09903955486203943, 0.13882279582321644, 0.11269454285502434, 0.17005346928324017, 0.10154576466551848, 0.14871943263070925, 0.16540015754955156, 0.10508066748401948, 0.2504287649478231, 0.09046736412814685, 0.10339203130986009, 0.07064798048564366, 0.11759941466152668], [0.026029936636665037, 0.0451302767199065, 0.02138331186558519, 0.05577792287138956, 0.04356361400069935, 0.021701521040605645, 0.09307110655520644, 0.08222861907311849, 0.026894639612042477, 0.0405345861800015, 0.009914687535326396, 0.07651065875376974, 0.0035405796121007627, 0.053447345072137456, 0.04809292006705489, 0.10533165758741753, 0.03373696129502995, 0.020277652623397962, 0.07919771849576916, 0.036555911281279156, 0.08326242824218102, 0.02171166513913444, 0.01745276545573558, 0.012115425114253802, 0.07018842228821345, 0.24295253040535109, 0.01621899371301489, 0.12566308411104338, 1.085388632757323, 39.33335617610386, 84.24615056174142, 85.24236243111747, 67.5941881452288, 67.68224266597203, 37.073360783713206, 41.87732097080776, 91.18002891540527, 74.92263385227749, 93.10634749276298, 46.421352522713796, 12.382849369730268, 0.010240173150253083, 0.023615841354642595, 0.03587765106931329, 0.0010693246461284745, 0.13810728064605168, 0.08849439463977303, 0.560028606227466, 10.937797767775399, 107.53806168692452, 95.32367052350725, 80.94392885480607, 78.20441395895821, 96.71204566955566, 100.67453384399414, 94.47929763793945, 91.80035018920898, 88.18773160661969, 80.69710104806083, 80.9484451838902, 82.56811891283307, 82.04989446912492, 74.21936498369489, 79.51100185939244, 82.3088607788086, 81.09951986585344, 76.85613686697823, 75.42337662833077, 74.03122861044747, 70.48082419804165, 74.62620980398995, 81.59111186436245, 88.48493385314941, 92.04207106998989, 85.96255016326904, 79.69253744397844, 66.03344208853585, 66.98349012647355, 70.66058799198696, 80.83878176552909, 85.3504833493914, 90.74459225790841, 68.90483379364014, 50.7872565814427, 62.33177539280483, 73.25179358891079, 72.11959157671247, 78.52483708517892, 75.10234900883266, 80.00235761914934, 80.03919001988002, 78.90410450526646, 84.42292663029262, 85.58929988316127, 82.41022109985352, 76.44319152832031, 82.67257118225098, 92.67594133104596, 89.89903817858014, 90.83989374978202, 91.20902374812535, 89.29485757010323, 78.53587777273995, 68.95871012551444, 70.86447593144008, 73.27202674320766, 81.05795574188232, 78.36611243656704, 73.14543751307896, 67.5491499219622, 81.80525534493583, 91.42494596753801, 85.94326196398053, 93.97515719277519, 89.94269371032715, 89.08123520442417, 90.13951533181327, 86.62984125954765, 84.38743523189, 81.60193020956856, 77.29637472970145, 94.31467396872384, 42.78731959206717, 0.71425918170384, 0.2341885721044881, 0.03473469275715096, 0.011496496852487326, 0.12357405120772974, 0.10887458747518913, 0.20331509304898127, 0.2727454831557614, 3.5911438720566884, 56.915418352399556, 83.93954045431954, 42.897590977805, 69.06584439958844, 67.43114866529191, 56.028133392333984, 23.617248364857264, 24.71774227278573, 50.26694072995867, 54.42226920809065, 71.17209352765764, 63.136543546404155, 14.544327991349356, 0.13836880161293916, 0.10042081467275109, 0.03054597055805581, 0.019366751591275846, 0.01279080324872796, 0.0659232936533434, 0.03978261670895985, 0.054138514412833114, 0.018492795094581585, 0.022017636935093572, 0.02147842551182423, 0.0923940846696496, 0.02203261898830533, 0.012721360278581935, 0.032564737767513306, 0.08144273981451988, 0.04886313534474798, 0.01826163687344108, 0.026779892555038844, 0.02007515911412026, 0.05043043588687267, 0.02387016306498221, 0.038305327229733975, 0.02125160482579044, 0.01948510336556605, 0.021612663487238542, 0.017241006550778235, 0.042364520486444235, 0.06469426317406551, 0.050769035039203506, 0.01764164924887674, 0.026473766392362968, 0.04157538086708103, 0.04615501726844481, 0.0409597019398851, 0.01553716610318848, 0.028627697777535235, 0.12828369491866656, 0.08435816051704542, 0.05419460211747459, 0.07139930874109268, 0.04481157899967261, 0.04291441883625729, 0.01819128466637007, 0.038530851913882155, 0.013413002049284322, 0.06617194281092711, 0.07527983015669243, 0.022094397905415723, 0.055597106859620125, 0.019701438989224176, 0.03768749734652894, 0.006254055570544941, 0.06606467999517918, 0.16696002813322203, 0.04292845433311803, 0.20080076796667917, 0.037756205802517276, 0.1435799641268594, 1.349590192948069, 56.487197399139404, 102.41820512499127, 105.82692187173026, 88.7638692855835, 89.05308805193219, 58.40371554238455, 25.248212916510447, 58.64055183955601, 77.31022248949323, 97.46019990103585, 56.540389333452495, 14.60215697969709, 0.25325757744056837, 0.014567090032090033, 0.14883709060294287, 0.054713399814707894, 0.31906209353889736, 0.2973230257630348, 0.6229336336255074, 16.75692711557661, 116.87363352094377, 96.781736101423, 85.8562010356358, 84.41670799255371, 102.40833868299211, 106.30172007424491, 97.8647518157959, 95.17070593152727, 92.91105447496686, 85.09362929207938, 84.30286870683942, 84.0853692463466, 83.56937517438615, 76.6953763961792, 83.25351701463971, 85.08371421269008, 83.12696947370256, 78.14192880902971, 80.12220014844621, 77.2648924418858, 75.15316118512834, 80.07744680132184, 86.46154199327741, 92.92090702056885, 96.51418876647949, 89.14529759543282, 84.07949107033866, 68.05629893711635, 68.7326157433646, 73.20319788796562, 83.15240682874406, 86.57089274270194, 93.32679298945835, 76.75254617418561, 57.928927762167795, 66.37916360582624, 76.24723843165806, 74.90176146371024, 80.46797030312675, 79.82909733908517, 85.70955235617501, 85.56907367706299, 83.3180240903582, 88.98658684321812, 88.84376662118095, 85.3980437687465, 78.8699541091919, 85.3630873816354, 95.42899826594761, 93.30803285326276, 91.58403887067522, 95.12169333866665, 92.75559547969273, 84.33944402422223, 74.18927233559745, 72.7031638281686, 77.02521433149064, 83.4631928035191, 80.30965559823173, 76.60613373347691, 70.51026371547154, 83.47429602486747, 93.90407712118966, 89.61321708134243, 96.90663691929409, 92.02903624943325, 92.57135704585484, 93.55551379067558, 90.64641421181815, 88.35980374472481, 86.80592250823975, 82.72323049817766, 99.56679643903459, 59.93935080936977, 3.8191364152090888, 0.04674782956551228, 0.10438557621091604, 0.20162992418876716, 0.16347151675394603, 0.3132762254348823, 0.11992087295012814, 0.3244738717164312, 2.3258198031357358, 60.08103847503662, 89.69940253666469, 49.68772152491978, 66.89913204738072, 43.97602435520717, 19.360208681651525, 9.906781503132411, 29.789654527391704, 85.89427716391427, 77.04371738433838, 79.90873064313615, 82.556654385158, 29.578985146113805, 0.022398798892806684, 0.18981329112180642, 0.06460497475096158, 0.006496379933586078, 0.08471555848206792, 0.07124553913516657, 0.06406616366335324, 0.04345336223819426, 0.08631552369999033, 0.01699505796256874, 0.017483274086511562, 0.018013742586065615, 0.025735561004174606, 0.02033818812508668, 0.014706652811063188, 0.07640703288572175, 0.019349506623776894, 0.04592309399907078, 0.060550259825374396, 0.05357921156766159, 0.03503545340416687, 0.02224070192979915, 0.05417685503406184, 0.04098213770027671, 0.04448800600532975, 0.05604506889358163, 0.033460733081613264, 0.026755249859499078, 0.047255546785891056, 0.02409571658686868, 0.05302523522238646, 0.1353355600897755, 0.23190584459475108, 0.05083637624712927, 0.1377401389181614, 0.08102736103215388, 0.23297722424779618, 0.21970746772629873, 0.16764749267271586, 0.1147964136408908, 0.11556887147682053, 0.15566214865871839, 0.16698164625891618, 0.08923789260110684, 0.1524916530719825, 0.15412248484790325, 0.14055555712963852, 0.18082491414887564, 0.08408049041671412, 0.12243047542870045, 0.14476197212934494, 0.1107532541666712, 0.16772712554250443, 0.1518609547721488, 0.2508373515946524, 0.1903839526431901, 0.34343672703419414, 0.0976066178243075, 0.26688131211059435, 3.8286854113851274, 78.36720330374581, 118.8110831124442, 113.14497307368687, 94.30006885528564, 87.46805109296525, 50.24534920283726, 57.96936280386788, 138.94383593967981, 96.96853147234235, 112.10845470428467, 70.3956948689052, 23.954857860292705, 0.4472374128443854, 0.10738385282456875, 0.18685631693473884, 0.138486649574978, 0.3919723912009171, 0.44369600287505556, 0.812712333032063, 14.879869529179164, 120.16008976527623, 107.62129415784563, 92.26850591387067, 86.62292780194963, 107.6308479309082, 112.74815450395856, 103.7814416885376, 102.1393461227417, 98.89737224578857, 92.26089763641357, 91.34267929622105, 91.42427894047329, 88.61479568481445, 80.67237935747418, 88.87520721980503, 91.77036871228898, 89.61822673252651, 82.72553730010986, 84.06942313058036, 81.53153800964355, 80.35931437356132, 83.44696181161063, 91.66648619515556, 96.42224325452531, 99.59382493155343, 97.19734954833984, 89.4965568270002, 73.99728666033063, 73.01813956669399, 78.4718987601144, 87.63056250980922, 93.10946723393032, 100.12442411695207, 80.85136495317731, 62.4397087097168, 72.9505752835955, 85.70086710793632, 83.89133385249546, 91.32185554504395, 89.43626730782645, 94.78833266666958, 97.74496487208775, 94.72907842908586, 94.51362868717739, 93.32995441981724, 89.87715830121721, 83.37265082768032, 92.38666697910854, 101.09155082702637, 98.4441829408918, 94.76306901659284, 97.65288734436035, 97.66592216491699, 87.8875207901001, 79.5810466493879, 79.12368147713798, 82.62838063921247, 90.1330326625279, 85.07254150935582, 80.95330197470528, 74.9915669304984, 89.40995447976249, 101.00315584455217, 93.78656223842076, 102.6083356312343, 95.98909950256348, 96.26891735621861, 98.97032833099365, 96.23030621664864, 92.6520117350987, 88.04721123831612, 87.88310173579625, 108.8227071762085, 53.80807971954346, 2.582189223596028, 0.3062585177166121, 0.14940092606203897, 0.20073690425072396, 0.3627042717167309, 0.26205388829112053, 0.3114713222852775, 0.5499611550143787, 6.8405914051192145, 78.2729023524693, 95.76678494044712, 62.3912033353533, 100.26164409092495, 97.36052799224854, 86.21796594347272, 37.13612733568464, 29.3487183707101, 67.29103824070522, 73.15690898895264, 87.65570804050991, 94.78634548187256, 29.851027965545654, 0.20914292175854954, 0.3649641733084406, 0.1498206949659756, 0.1463137681462935, 0.14604616750563892, 0.1742167023143598, 0.1404842430991786, 0.1425915150237935, 0.09356453722076756, 0.09825222353850092, 0.07733796936060701, 0.17914843053690024, 0.15916242583521775, 0.1115137901423233, 0.09589750346328531, 0.1859683995800359, 0.15439588017761707, 0.12182086599724633, 0.1672086976468563, 0.20385285919266088, 0.13037078721182688, 0.10525589236723525, 0.18417900774095738, 0.1141504483031375, 0.16370672413281032, 0.11103016430778162, 0.06268085299858026, 0.10956720209547452, 0.14167771834347928, 0.1327391458409173, 0.11537193347300802], [0.08455102731074605, 0.020425865027521337, 0.05472603074408003, 0.027352016319387724, 0.009787906659767032, 0.019872577395290136, 0.046621954534202814, 0.022469961949224983, 0.0782774757327778, 0.03658232664955514, 0.12058948778680392, 0.013362800635929619, 0.056057163780289035, 0.11259916797280312, 0.07516504238758769, 0.10525564809462853, 0.12035293690860271, 0.14746062803481305, 0.07260326735143151, 0.09955600143543311, 0.01740322561402406, 0.0880117526810084, 0.09858855977654457, 0.1605801840445825, 0.04332275103245463, 0.20757975349468843, 0.30669210159352844, 11.864900248391287, 60.89581898280552, 84.4403944015503, 72.17563574654716, 60.46708038875035, 66.30572809491838, 44.73197446550642, 56.419796398707796, 77.60280418395996, 71.37724603925432, 99.0773514338902, 51.72403008597237, 14.477051189967565, 0.06453308396573577, 0.06475973501801491, 0.09717665053904057, 0.08056629648698227, 0.0897237847426108, 0.013027902892125505, 0.27931495064071243, 1.6566791832447052, 95.41705431256975, 90.09975773947579, 82.27436297280448, 82.95068672725132, 77.1427709034511, 80.47705854688371, 74.58868258340019, 79.8708073752267, 75.85051713671002, 71.93834781646729, 72.71295383998326, 70.71845953805106, 74.51517064230782, 78.22922597612653, 74.49468735286167, 73.87756225040981, 75.20455006190709, 75.02067293439592, 76.48843819754464, 72.67883123670305, 71.17391395568848, 76.03150381360734, 78.9875384739467, 82.79932716914585, 89.50096198490688, 86.67312853676933, 84.61212607792446, 72.49660778045654, 64.85575716836112, 65.3399910245623, 68.5049580165318, 75.12527111598423, 85.01256465911865, 86.63385731833321, 85.6691346849714, 60.17927210671561, 49.893454211098806, 64.5541775567191, 71.9870616367885, 70.35009384155273, 74.82136385781425, 82.34954248155866, 79.78117561340332, 70.04447037833077, 80.99477577209473, 88.00478553771973, 80.13753482273647, 72.71259253365653, 79.02967235020229, 83.6179917199271, 87.6541030066354, 84.34418269566127, 84.72472163609096, 85.8657478604998, 81.25017070770264, 71.67543492998395, 67.39353111812046, 67.69874463762555, 67.4397783279419, 69.70222296033586, 71.99624020712716, 70.16928781781877, 73.01977934156145, 85.25949668884277, 83.43401731763566, 83.07284995487758, 83.84966550554547, 88.69747229984829, 81.01874705723354, 82.29497827802385, 78.20372608729771, 77.64779376983643, 81.59929684230259, 73.81038011823381, 86.44055148533413, 44.19521222795759, 0.8103160187602043, 0.05589455286306994, 0.24461203707115992, 0.004344305613942976, 0.12634763094995702, 0.17318078290138925, 0.053316167289657254, 0.2261795654360737, 3.5444728221212114, 52.90260437556675, 86.42422321864537, 52.31332417896816, 96.68467671530587, 99.96685981750488, 90.94322041102818, 50.87735734667097, 14.33203273160117, 30.094784668513707, 46.89064080374581, 65.03683417184013, 68.94816276005336, 30.006907326834543, 1.7602063651595796, 0.20527958763497217, 0.051113944567207775, 0.11159785384578363, 0.030233403401715413, 0.029459802234279256, 0.04238639645544546, 0.014521429714347635, 0.0882858604724918, 0.07807434948959521, 0.08081589559359209, 0.0868820868698614, 0.03263801276417715, 0.08164232410490513, 0.12716192725513661, 0.018496881571731398, 0.026608613352956514, 0.06580100807228259, 0.027153068155582463, 0.012101150433798986, 0.04569361684843898, 0.0390871793829969, 0.04400282632559538, 0.04032902738877705, 0.03898627444037369, 0.02264047271039869, 0.01927054550365678, 0.023445970112723962, 0.02532878265316997, 0.0563587522400277, 0.10016881355217525, 0.073798954619893, 0.08271635682987315, 0.008837228208514196, 0.033509747058685334, 0.044356353248336484, 0.1562821939587593, 0.051344758431826315, 0.08065426855215005, 0.028106810192444494, 0.07020183014018194, 0.02321757692178445, 0.08584753809762852, 0.06482387014797755, 0.029307267562087094, 0.1655671043055398, 0.058377298925604136, 0.12534828457449163, 0.023477918934077024, 0.06431029377771275, 0.03269961356584515, 0.05426762605618153, 0.0275885112184499, 0.20130730792880058, 0.07539533717291695, 0.27607470165405956, 0.16654249839484692, 18.02232435771397, 80.85327570778983, 100.35663291386196, 87.81639208112443, 83.11751297542027, 97.63458578927177, 72.38958467755998, 35.33153772354126, 47.16353825160435, 81.8613828931536, 108.18244457244873, 62.661925997052876, 17.05089671271188, 0.27946683391928673, 0.06958314191017832, 0.0562672823268388, 0.15510782626058373, 0.5753817909530231, 0.9814130749021257, 0.5204489529132843, 3.371065978493009, 103.85705893380302, 94.34769180842808, 90.97029754093715, 87.67209884098598, 82.7474032810756, 81.18531622205461, 79.6085684640067, 83.39662906101772, 77.79872948782784, 74.77572808946881, 75.35508278438023, 74.27594416482108, 79.6399256842477, 83.02115535736084, 78.73991162436349, 76.61200496128627, 79.269545010158, 77.98919350760323, 80.09668636322021, 75.71722984313965, 75.05774852207729, 76.90412112644741, 80.97045012882778, 85.68187768118722, 93.2929413659232, 89.97188309260777, 88.16430228097099, 74.37865243639264, 67.85006945473808, 69.77930627550397, 71.10622460501534, 77.90351527077812, 90.06145926884243, 89.7131599698748, 89.98759991782052, 63.528540066310335, 52.46947104590279, 68.83927059173584, 78.00263132367814, 78.32415921347481, 83.80541937691825, 91.65580681392125, 84.75724615369523, 74.469083241054, 84.04297828674316, 88.68383298601422, 82.18008286612374, 75.84497247423444, 80.0649608884539, 84.67902333395821, 89.45216478620256, 86.94194044385637, 87.02369989667619, 90.43083245413644, 84.5759676524571, 75.24493994031633, 71.16896683829171, 70.42550264086042, 70.29801709311349, 71.93285179138184, 73.14244978768485, 72.79690197535923, 77.55060236794608, 87.0471361705235, 86.3461880002703, 84.75114563533238, 85.59844371250698, 88.98302241734096, 81.55516883305141, 84.14290033067975, 79.9980775288173, 78.75860227857316, 85.36106545584542, 79.64095401763916, 89.06032807486397, 58.66458565848214, 3.637758902141026, 0.10480026967291321, 0.18567147265587533, 0.05192046486107366, 0.05094317426638944, 0.2975321502557823, 0.043316420300730636, 0.2445493404354368, 2.4924347826412747, 58.33528273446219, 90.88266686030796, 56.33103663580758, 97.75028719220842, 97.15921088627407, 62.96609033857073, 22.420622655323573, 27.073278869901383, 51.55688074656895, 67.53364154270717, 70.64121641431535, 83.80040972573417, 48.406060286930625, 4.721652260848454, 0.22641389071941376, 0.09175970871001482, 0.022498891289745058, 0.012310980602965822, 0.02591683841975672, 0.02633796269739313, 0.04268891790083476, 0.040379927693200965, 0.027241259048293744, 0.027292532546977912, 0.09742145918841873, 0.05076417333579489, 0.06026116319532905, 0.10197806611124959, 0.10626625815140349, 0.07151052741599934, 0.030739403928497007, 0.00720309281522142, 0.06789789841111217, 0.05383054093856897, 0.014119983800420803, 0.028396464917542677, 0.012562562728167644, 0.060539464333227704, 0.012639629039248186, 0.02590500476903149, 0.023020835693127344, 0.01726032783543425, 0.08855835335063082, 0.17221245914697647, 0.1423103301120656, 0.1284715269825288, 0.12635677760200842, 0.10026060576949801, 0.10826161251004253, 0.17517222889832088, 0.11678654327988625, 0.13963751282010758, 0.10659959526466471, 0.2046579002801861, 0.08041570921029363, 0.2082800559167351, 0.12436546731208052, 0.22788834731493676, 0.2423484713903495, 0.3816999409879957, 0.2388126254081726, 0.13219638567950043, 0.21786535371627125, 0.13528682770473616, 0.1165781244635582, 0.22638817424220697, 0.2725777221577508, 0.2394895048013755, 0.5684392920562199, 1.0150352993181773, 24.700797353472026, 102.83920342581612, 111.31045409611293, 95.85237979888916, 85.24368258884975, 86.3117457798549, 54.81700331824166, 73.32047653198242, 123.85191781180245, 93.34537247249058, 117.28284072875977, 75.23745673043388, 27.90431989942278, 0.4259555148226874, 0.20146296386207851, 0.24699716908591135, 0.2708046830126217, 0.4597332051822117, 0.41374560285891804, 0.9516497062785285, 3.389498463698796, 110.41763142177037, 100.98230430058071, 93.90213162558419, 90.7657356262207, 87.85433619362968, 88.57697663988385, 83.24738870348249, 89.11159188406808, 86.59824085235596, 80.24114636012486, 79.69665772574288, 78.30660806383405, 82.2040194102696, 87.53518458775112, 83.68339511326381, 80.29201412200928, 84.68484592437744, 80.6746027810233, 83.96668706621442, 80.09568582262311, 80.3488712310791, 83.59347152709961, 89.86209460667202, 91.62850734165737, 97.07171222141811, 97.2530324118478, 94.16894245147705, 80.61698831830705, 71.51789147513253, 73.19151101793561, 75.3319730758667, 83.75939450945172, 95.2487758908953, 93.17509296962193, 92.99007633754185, 69.12989289419991, 59.537869998386924, 70.88914203643799, 81.80192020961216, 82.40316867828369, 91.05079242161342, 101.44637448447091, 95.58959197998047, 80.56588431767055, 90.7518948146275, 93.92536640167236, 88.88224574497768, 79.64681134905133, 87.3144542149135, 91.13544232504708, 95.2226367677961, 92.42667470659528, 91.63165487561906, 94.29654611860002, 90.72818061283657, 79.77870205470494, 74.2895278930664, 73.77137987954276, 74.73747825622559, 77.22258486066545, 78.26522459302629, 76.38909980228969, 81.77658707754952, 90.93448652539934, 89.56637232644218, 90.44628524780273, 91.33627305712018, 96.24444580078125, 86.72811658041817, 90.4858066013881, 86.90508719852993, 88.247909954616, 90.9788716179984, 84.9233011518206, 99.14802850995744, 54.414136341639924, 2.593543231487274, 0.11547638715377875, 0.41351452097296715, 0.12359584575252873, 0.18206395980502876, 0.40971716759460314, 0.12829365581274033, 0.35665768331715036, 7.133402390139444, 72.02046857561383, 99.61712224142892, 65.22203840528215, 104.81098406655448, 120.76026126316616, 118.31948416573661, 71.96926730019706, 21.286687067576818, 40.8839613369533, 65.29358400617326, 81.42355605534145, 100.48331247057233, 52.519904545375276, 5.531320197241647, 0.3851023869855063, 0.2041199848588024, 0.2126602708761181, 0.11592101758079869, 0.17554023915103503, 0.11971362121403217, 0.13430877375815595, 0.13750791709337915, 0.14618465650294507, 0.11762768243040357, 0.24886520313365118, 0.16659253356712206, 0.18235909539674008, 0.19328352276768002, 0.15818335408610956, 0.18171849048563413, 0.18717661260494164, 0.1178639754652977, 0.11127896952841963, 0.16787062212824821, 0.09694947701479707, 0.13415093294211797, 0.1122023199817964, 0.19149067040000642, 0.13036226481199265, 0.1285132026033742, 0.1964238371167864, 0.08614416646638087, 0.19678457347410067], [0.08783018349536828, 0.12709087106798375, 0.028517615648784807, 0.08223806428057806, 0.06995403593672173, 0.03154156802754317, 0.02733210301292794, 0.08933007836874042, 0.030365456494369676, 0.05280400227223124, 0.04086812685376831, 0.05379615278382387, 0.025106201114665185, 0.07727305391537291, 0.0222459470054933, 0.06421985863042728, 0.02238385415902095, 0.028068761341273785, 0.028947766138506786, 0.006289838962922139, 0.011919650797998267, 0.041310477403125594, 0.10216127056628466, 0.2162978971110923, 1.8479079391275133, 17.822075537272863, 52.97330229622977, 91.1766242980957, 89.83131408691406, 81.78197887965611, 69.39195810045514, 74.20970003945487, 35.17665890284947, 47.60802493776594, 92.58812999725342, 86.05810179029191, 103.13172258649553, 65.44720867701939, 18.353508506502422, 0.1900066328900201, 0.057037083698170524, 0.21704999889646256, 0.14456918675984654, 0.18280118810279028, 0.13893788893307957, 0.24992846750787326, 2.734241864510945, 29.093813283102854, 110.68579019818986, 82.92461013793945, 89.30667645590646, 63.753349031720845, 74.52507877349854, 67.35155010223389, 75.16256904602051, 66.04231493813651, 67.05008860996791, 68.75708729880196, 71.0772784096854, 68.75284194946289, 73.24436596461705, 69.78266920362199, 73.40762778690883, 66.17388602665493, 69.50819451468331, 70.0748062133789, 73.26828861236572, 69.2588723046439, 73.96735382080078, 70.96318204062325, 77.78596564701625, 89.4303057534354, 85.41060611179897, 86.85110664367676, 78.52335711887905, 62.0056061063494, 64.28335067204067, 65.15900434766496, 70.98622226715088, 66.56639671325684, 78.31211103711809, 80.93349266052246, 87.79334490639823, 72.73361083439418, 46.019621576581685, 44.019989081791465, 52.13663496289934, 71.83227661677769, 79.35035950796944, 76.67974989754813, 68.60513714381626, 66.41414083753313, 84.43933132716587, 83.84712246486119, 77.03077289036342, 70.167738369533, 71.8311996459961, 79.73263549804688, 84.3360880443028, 84.02507277897426, 82.16910471235002, 85.93581349509103, 79.56415557861328, 77.32644653320312, 73.15025956290108, 74.55268396650041, 73.94837829044887, 71.50922012329102, 62.98835931505476, 64.95847933632987, 67.98726858411516, 75.69295978546143, 77.62348897116524, 76.3200694492885, 77.85250159672329, 71.69395882742745, 73.98600278581891, 71.07187271118164, 67.28861331939697, 67.61438655853271, 71.77020835876465, 82.92499228886196, 77.6569584437779, 80.37705312456403, 36.579003402165, 0.31199620983430315, 0.07254728821239301, 0.09553367977163621, 0.11025742827249424, 0.09474788872259003, 0.04565386487437146, 0.07623896654695272, 0.17876245267689228, 4.437168257577079, 51.28543547221592, 95.20018018995012, 81.00275925227574, 79.0934568132673, 102.76411424364362, 92.66162109375, 43.22336074284145, 18.563319785254343, 37.48562172480992, 72.26297460283551, 59.46164131164551, 74.71350697108677, 63.33982004438128, 15.689306872231619, 0.5231629301394735, 0.025090686411463788, 0.020790340112788335, 0.04706005406166826, 0.06687837240419217, 0.03245085244998336, 0.0358484265660601, 0.014850721062560166, 0.04547583424885358, 0.028823896178177426, 0.03816656681842037, 0.020758247102743814, 0.03386804068993245, 0.013551075443891543, 0.017451754438557794, 0.022802084484802823, 0.08027495390602521, 0.03843316322724734, 0.04441102960013917, 0.08370949460991792, 0.016210956465719, 0.009929789180335189, 0.06486217344978026, 0.09162660049540655, 0.05167211765157325, 0.04184415876599295, 0.014148395757989159, 0.0613240883020418, 0.053295387154711146, 0.05309853396777596, 0.023918300035542676, 0.004691234207712114, 0.03309402561613491, 0.021739184823153273, 0.02254373058011489, 0.10328081942030362, 0.009989577445334621, 0.06164076059524502, 0.025987760596243397, 0.03068982676735946, 0.03766549245587417, 0.025480262203408138, 0.08090506866574287, 0.06448057892599277, 0.022572636171909313, 0.058077230384307246, 0.017977776837402155, 0.009147903100321335, 0.03410800459927746, 0.035975543316453695, 0.14539081124322756, 0.3195139435785157, 1.69333972462586, 27.69931329999651, 67.95413957323346, 111.93699400765556, 105.02142415727887, 107.87406267438615, 97.26982620784214, 106.91162599836076, 49.27512012209211, 21.63585489136832, 50.78889288221087, 92.6001364844186, 114.09989179883684, 70.9019614628383, 21.591544491904124, 0.14098162283854826, 0.06764369883707591, 0.17728374845215253, 0.1855919619223901, 0.5867719511900629, 0.4554986038378307, 2.7086861729621887, 2.3183791509696414, 35.909818921770366, 114.71065929957798, 88.2052480152675, 94.04459748949323, 68.96279566628593, 79.14540154593331, 72.65961946759904, 80.42719827379499, 69.81080940791539, 70.06951863425118, 71.45230742863247, 75.79343073708671, 72.68879495348249, 75.55917222159249, 71.5692525591169, 75.66544491904122, 69.28172492980957, 71.63476017543248, 71.68011801583427, 77.10829394204276, 75.16711316789899, 77.25572081974575, 76.26251752035958, 83.9762269428798, 92.72377967834473, 88.68817561013358, 90.08720929282052, 82.71103640965053, 66.80073165893555, 68.88259260995048, 68.39277935028076, 73.94517517089844, 69.02224445343018, 81.22764464787075, 83.75991562434605, 89.98972606658936, 78.14242907932827, 53.12084034511021, 47.247743470328196, 55.525156770433696, 73.54898193904332, 85.80290835244315, 81.15691198621477, 74.64835371289934, 72.77598094940186, 89.51067556653703, 87.52805573599679, 81.77550315856934, 74.53145721980503, 75.38926097324916, 82.00719084058488, 89.33066163744245, 86.7420963559832, 85.44214398520333, 91.4155797958374, 85.6862758908953, 81.97022642408098, 77.79651301247733, 77.2281573159354, 80.00172533307756, 75.07938521248954, 67.49767766680036, 67.26126520974296, 70.84612573896135, 76.28635678972516, 79.93843419211251, 81.16192163739885, 81.67686653137207, 74.22008759634835, 77.74402632032121, 73.6289279120309, 69.04630606515067, 71.51190212794712, 76.35224655696324, 86.09357929229736, 86.83333315168107, 84.82858330862862, 48.76805101122175, 1.9322875142097473, 0.08363940872784172, 0.14097894941057476, 0.1449610543038164, 0.045670431306851764, 0.061287562761987956, 0.11766299339277403, 0.07029326273394482, 3.208327442407608, 53.39415468488421, 95.28818607330322, 86.58688749585832, 79.8915685926165, 111.43497276306152, 76.95097977774483, 26.76069504874093, 30.35324375970023, 56.53445209775652, 90.41624818529401, 67.78234536307198, 82.55476447514125, 81.42155497414726, 29.34589045388358, 0.4704877680965832, 0.033557264866041284, 0.05606723323996578, 0.03900953462081296, 0.04582404824239867, 0.03448697319254279, 0.045404316657888036, 0.01454277303335922, 0.0290798429798867, 0.0462916233310742, 0.009395300360795642, 0.046011954945112975, 0.033284212196511884, 0.027267801641885723, 0.006671796502944614, 0.032142465069357834, 0.03645903005131653, 0.023607081467551843, 0.006158764657032276, 0.0232579921638327, 0.01845178783072957, 0.060900092124938965, 0.04775682470894285, 0.023702127260289023, 0.045344805744077475, 0.04484682550121631, 0.046142552580152235, 0.017246499291754196, 0.247513941356114, 0.24013403164488928, 0.09231519818838153, 0.13806857700858796, 0.08013051415660552, 0.11069393663534097, 0.18266792382512773, 0.1981921943702868, 0.12698052770325116, 0.11548634804785252, 0.11668081395328045, 0.13153303627456936, 0.14364681339689664, 0.1332405696489981, 0.1524220760911703, 0.19941281101533345, 0.1240601401243891, 0.17888245838029043, 0.11465260492903845, 0.13075133679168566, 0.12651049292513303, 0.1938610239220517, 0.2234057549919401, 0.402966314128467, 3.7695223689079285, 41.06430530548096, 89.27226202828544, 129.7165309361049, 116.54559516906738, 107.67323194231305, 91.94618592943463, 93.2269195829119, 43.162341662815635, 65.26735455649239, 142.3726190839495, 114.01441505977085, 121.93153299604143, 86.31636633191789, 33.398350851876394, 0.43660322204232216, 0.15109452232718468, 0.5638820880225727, 0.20879327266344003, 0.6708382059420858, 0.15075258138988698, 2.147614142724446, 4.93472615310124, 36.87487506866455, 120.62532724652971, 90.58533954620361, 99.85438932691301, 73.68371445792062, 83.04538372584751, 74.95349775041852, 85.86690820966447, 74.62106813703264, 75.33368928091866, 76.5394240788051, 81.07600021362305, 77.52317782810756, 82.20322036743164, 77.26292610168457, 81.01081916264125, 73.82928616659981, 76.89538029261998, 78.51952866145542, 80.97693279811314, 77.7358899797712, 82.77684279850551, 79.90529823303223, 86.37454359872001, 95.07616179330009, 93.53144523075649, 95.20023577553886, 86.91791357312883, 69.98391682761056, 72.06766074044364, 72.57182897840227, 78.03362723759243, 74.4988910130092, 87.34194128853935, 88.28322764805385, 95.26708439418248, 82.00296633584159, 60.803748403276714, 57.851903506687705, 64.31086553846086, 80.82642786843437, 90.44024726322719, 91.83094310760498, 83.88836697169712, 78.06516511099679, 93.7192828314645, 92.7134963444301, 87.87518773760114, 79.84040900639125, 77.57208619798932, 87.63483565194267, 92.21800640651158, 89.51257937295097, 87.2154562813895, 93.23067855834961, 88.43723446982247, 87.49118859427315, 80.7417710168021, 81.48224748883928, 81.6702379499163, 78.51265689304897, 70.16391686030796, 70.08358873639787, 75.27714484078544, 84.11847046443394, 86.3469523021153, 85.13001005990165, 87.15853663853237, 79.86592973981584, 85.36797196524483, 78.92760331290108, 73.3103460584368, 73.34130028315953, 82.05762781415666, 92.8284751347133, 88.896135193961, 91.34868948800224, 45.927050726754324, 1.5451397512640273, 0.7580716450299535, 0.2507472964269774, 0.3402124100497791, 0.2081210751618658, 0.1616359573921987, 0.22508846755538667, 0.21301966373409542, 8.50848867212023, 70.34622369493756, 111.44998087201799, 87.26745659964425, 82.720048223223, 111.35185146331787, 109.88461426326207, 64.17504215240479, 22.348420449665614, 48.05510677610125, 90.57318019866943, 75.18877070290702, 96.365309715271, 95.4436033793858, 35.82644053867885, 0.4802339736904417, 0.10071551600205046, 0.13876726451729024, 0.08309176311429058, 0.13605543146175997, 0.12215876286583287, 0.10505600273609161, 0.11715394285108362, 0.15842698886990547, 0.12035468752895083, 0.11654179569865976, 0.18582623292292866, 0.18747786858252116, 0.11030916656766619, 0.08441656881145068, 0.12408825861556189, 0.16530661471188068, 0.10392994673124381, 0.19299870090825216, 0.18941682311041014, 0.12244688240545136, 0.15731039164321764, 0.12427758345646517, 0.11473807319998741, 0.24043671254600796, 0.16065281443297863, 0.15483951994350978, 0.0913955932483077], [0.020982526675132767, 0.12739741961870873, 0.022663668430011188, 0.0689270935420479, 0.043023571372032166, 0.016046174236440232, 0.07779052507664476, 0.030025642764355456, 0.0431066919118166, 0.026088373768808584, 0.03441986268652337, 0.008837046700396707, 0.03966619027778506, 0.03571328953174608, 0.055152333940246275, 0.06621406626488481, 0.07348039599933795, 0.006588915994923029, 0.06376845642392125, 0.09373598266392946, 0.046308284758457115, 0.05925581178494862, 0.503811599952834, 23.559421982084, 70.91522557394845, 89.15573378971645, 91.8673516682216, 75.82581629071916, 64.10367720467704, 42.47596386500767, 49.96215452466692, 31.418360914502824, 58.01503331320626, 101.7440492085048, 92.01048455919538, 100.97693334306989, 56.97951895850045, 22.93673484666007, 0.1586373754377876, 0.05367596387597067, 0.056147449649870396, 0.09334551968744823, 0.1980715508439711, 0.18491866519408567, 6.699787897723062, 9.625798089163643, 0.33227219326155527, 67.53250898633684, 105.92059053693498, 87.44646303994315, 82.24211638314384, 80.30958611624581, 81.98959800175258, 80.35461044311523, 80.81485216958183, 83.22569642748151, 79.27641677856445, 69.68333775656563, 70.61533437456403, 64.68147550310407, 61.42888477870396, 63.91933454786028, 66.41665608542306, 66.01941367558071, 66.32748290470668, 70.76318509238106, 74.7854972566877, 78.0734612601144, 80.48023387363979, 82.37012304578508, 91.01843466077531, 85.90508161272321, 85.11445999145508, 82.65725040435791, 67.8766393661499, 64.3666387285505, 65.53021880558559, 68.94217341286796, 71.17237145560128, 69.15508706229073, 75.76723602839878, 79.67742511204311, 80.65045779091972, 84.52527359553746, 74.09326212746757, 61.66105188642229, 58.39870589120047, 45.405501570020405, 51.3761476789202, 63.66310582842146, 61.25673621041434, 75.55480180467877, 82.82022735050747, 84.25291115897042, 76.06448691231864, 70.5311222076416, 68.48971366882324, 73.92331613813127, 82.69909245627267, 84.65609427860805, 80.4673102242606, 89.57636383601597, 90.68894413539341, 81.11607047489711, 79.51886027199882, 78.2051087788173, 79.4155683517456, 78.08113207135881, 71.82592596326555, 64.40352671486991, 64.0043943950108, 64.58861977713448, 64.93318094526018, 70.0430668422154, 71.57335894448417, 72.72048568725586, 67.48357282366071, 65.6820786339896, 67.48775563921247, 71.62665162767682, 79.20435006277901, 73.34606674739292, 83.18160315922329, 81.23110485076904, 84.31233215332031, 26.389746359416417, 0.7627492483173097, 0.2713624930807522, 0.1982508333665984, 0.22400731699807302, 0.048106891103088856, 0.07888810296675988, 0.038531974889338017, 0.10281718322741133, 3.3891323804855347, 40.291172300066265, 76.138916015625, 78.01103169577462, 54.18056569780622, 55.52981901168823, 82.07796519143241, 44.64510808672224, 29.902847630637034, 40.64169502258301, 59.3134640284947, 57.73061227798462, 71.54392637525285, 81.80490793500627, 21.752570731299265, 0.4005833534257752, 0.0987913671082684, 0.13360404728778771, 0.021601908707192967, 0.01670649567885058, 0.02306333234134529, 0.06826248206198215, 0.03819857331525002, 0.010762513648452503, 0.08915070763656072, 0.016890365098203932, 0.05655162242640342, 0.04730437755850809, 0.050897410472056696, 0.021201106553365077, 0.03318345653159278, 0.06528785239372935, 0.051953597726034265, 0.024507329499881183, 0.03629698231816292, 0.022998890174286704, 0.10097523885113852, 0.032819514096315415, 0.030056451646877185, 0.07305795366742782, 0.05976941529661417, 0.012991787865757942, 0.024995930692447082, 0.06831532636923449, 0.05760104129356997, 0.014849296139021004, 0.022830857762268612, 0.03995482211134263, 0.011872555378691425, 0.04005281613873584, 0.03057890325518591, 0.06788762539092984, 0.01852650980332068, 0.019210608809122016, 0.03082513004275305, 0.061692960294229646, 0.033502999027924876, 0.028693441035492078, 0.06884298912648644, 0.012951602477447262, 0.013039934166174914, 0.09825663401612214, 0.052601554564067295, 0.02543996231231306, 0.17634404530482634, 31.42038631439209, 90.99608925410679, 106.24362618582589, 109.74622004372733, 87.8742149897984, 99.21013845716203, 64.0542060307094, 61.76360729762486, 51.472470555986675, 25.13897681236267, 71.25420733860561, 96.58691556113106, 109.73797253199986, 65.3541236604963, 25.866729395730154, 0.24126525808657917, 0.017628377103911977, 0.10002769183899675, 0.02961595349812082, 0.4259195253252983, 0.9777881779841014, 8.159049000058856, 4.0318659373692105, 0.37727757543325424, 72.53800514766148, 110.51359299251011, 93.62394659859794, 87.42942605699811, 87.12039797646659, 86.8609105518886, 86.27382946014404, 86.27665737697056, 89.39730181012834, 84.88257081168038, 74.2460252216884, 75.08298437935966, 69.27699320656913, 66.77191747937883, 67.72224344526018, 68.83779062543596, 69.41875730242047, 68.4088922228132, 73.53102779388428, 79.38635117667062, 84.13393020629883, 84.77098969050816, 86.3643992287772, 95.49983515058244, 90.24645505632672, 90.5883481161935, 84.86160809653146, 69.85493046896798, 65.24478680746896, 68.01488767351422, 73.34455898829869, 75.8493150983538, 71.13512216295514, 79.44117941175188, 80.77471937452043, 82.74421405792236, 86.7454731804984, 80.65352889469692, 71.12435940333775, 67.95470237731934, 50.87937927246094, 54.58292198181152, 72.55845369611467, 65.7920755658831, 80.01313427516392, 87.23739174434117, 87.9636869430542, 78.96159390040806, 73.63466712406704, 71.66027396065849, 78.4196344103132, 86.1153757912772, 87.2721118927002, 81.85401780264718, 90.84101240975517, 93.59577860151018, 85.26350579942975, 82.13194574628557, 81.01682240622384, 80.88874626159668, 81.31233624049595, 73.23720237186977, 67.10814080919538, 67.05745370047433, 68.4146592276437, 67.92527675628662, 73.32613236563546, 75.43136705671037, 76.19242409297398, 70.26799392700195, 69.45254639216832, 71.63100119999477, 75.00788130078996, 81.75553403581891, 75.99650573730469, 84.94091483524868, 84.55219091687883, 89.06081444876534, 40.635125500815256, 1.3404775219304221, 0.28542893113834517, 0.2957538456789085, 0.37560240817921503, 0.07490652054548264, 0.0610833169360246, 0.08778473521981921, 0.14156753782715115, 2.298177480697632, 42.84416627883911, 83.24349076407296, 89.48191697256905, 57.28785916737148, 60.028649057660786, 48.436965874263215, 28.82132751601083, 43.22280141285488, 62.45182636805943, 82.32448727743966, 74.80657809121269, 76.99594851902553, 96.51655115400041, 37.55809143611363, 0.34394969950829235, 0.05390883370169571, 0.10386446810194425, 0.02262152631634048, 0.04805843013205698, 0.0542982144148222, 0.043475770857185125, 0.0651753648583378, 0.01819366971696062, 0.015900458841185485, 0.017184521903150847, 0.03920311726895826, 0.020951792431463088, 0.0794109074132783, 0.014919616115678633, 0.012824718125297554, 0.009788709027426583, 0.021359091558094536, 0.04334822323705469, 0.11115624289959669, 0.059038388808923106, 0.02176487076628421, 0.06596633991492645, 0.03159066003614238, 0.03148867283016443, 0.02999013502682958, 0.04162815392815641, 0.1235771860395159, 0.21099140042705194, 0.18083456291684083, 0.13228008975940092, 0.16863986370818956, 0.14599074476531573, 0.21573754932199204, 0.2018853383404868, 0.12564844132534095, 0.14430306532553264, 0.058573728028152666, 0.0729048897379211, 0.1087654654734901, 0.11134577808635575, 0.12758232041129045, 0.16302258441490786, 0.1921970389251198, 0.09853922349533864, 0.15663731204611914, 0.21013384072908334, 0.17786479155932153, 0.20516843002821716, 0.605705738067627, 44.82854400362287, 113.93474701472691, 125.92966542925153, 122.56174850463867, 97.34093407222203, 88.4734137398856, 62.14441721779959, 64.44060230255127, 40.93962682996477, 84.89539023808071, 148.39392798287528, 119.98631531851632, 116.65559904915946, 79.44513988494873, 36.06762988226754, 0.39101690532905714, 0.12232615745493344, 0.41220616975000923, 0.2719312954161848, 0.8368593315993036, 0.2871976005179541, 11.787425228527614, 18.4442971433912, 0.536629896078791, 78.25166170937675, 113.81135395595005, 97.81642709459577, 92.7667542866298, 90.62903676714215, 90.31874411446708, 90.44886302947998, 89.44519574301583, 94.3588992527553, 86.94878441946847, 79.24658121381486, 78.31680107116699, 73.19678470066616, 70.14551108224052, 71.69119344438825, 73.68759155273438, 72.97412272862026, 73.31776673453194, 78.19975866590227, 82.482253074646, 88.06430380684989, 88.36705766405377, 91.98847266605922, 97.81640625, 96.57523563929966, 95.04069818769182, 90.79488331930978, 74.9806443623134, 69.67386041368756, 72.56413732256208, 77.06919642857143, 80.31961931501115, 78.4138743536813, 83.86037962777274, 87.11096927097866, 88.23542404174805, 90.20710045950753, 84.68901484353202, 72.91991288321358, 69.05814579554966, 56.01365682056972, 64.55380235399518, 78.67924690246582, 71.64359828404018, 80.75363853999546, 90.77766568320138, 94.52393286568778, 84.87026555197579, 78.07600430079869, 75.7737534386771, 83.7734854561942, 90.12407643454415, 92.95555073874337, 84.43291813986642, 92.82964243207658, 96.9299898147583, 88.60754871368408, 87.0262359891619, 85.46742153167725, 86.97309616633824, 86.80499839782715, 78.16842923845563, 71.52578462873186, 71.27584402901786, 71.78799574715751, 70.6697665623256, 77.74567999158586, 79.80628640311105, 82.81496756417411, 74.29927621568952, 74.57368837084088, 76.52538871765137, 80.6262572152274, 87.8892022541591, 80.70681462969098, 93.14290196555001, 91.50926235743931, 96.67693642207554, 38.17417083467756, 1.609781014067786, 2.4379515690462927, 0.38623231063996044, 0.4959988391825131, 0.2617480589875153, 0.1928421085966485, 0.1989383657595941, 0.384949228061097, 6.779709117753165, 55.03444719314575, 90.72763865334647, 97.53892299107143, 67.60188674926758, 74.40434687478202, 109.33649172101701, 57.40691655022757, 38.28417818886893, 52.73897777284895, 80.30478491101945, 76.34222030639648, 87.36201463426862, 110.69473252977643, 46.21807949883597, 0.4949629604816437, 0.2225686056273324, 0.22746297371174606, 0.15569359197148255, 0.1170213163963386, 0.12280197335141045, 0.1493956334888935, 0.10432462341019086, 0.1992490126618317, 0.19020874133067472, 0.07709323535008089, 0.14329466729291848, 0.15604124617363724, 0.10925000733030693, 0.1036661391013435, 0.10846026720745222, 0.19244382211140224, 0.10098863313240664, 0.051967198960483074, 0.1985481809824705, 0.1646151603864772, 0.16881883410470827, 0.10348009836993047, 0.11564722870077405, 0.11156359461269208, 0.10340435350579874, 0.12046033543135438], [0.04691851504945329, 0.032715779662664445, 0.044121800655765195, 0.025206720988665308, 0.002876638185365924, 0.0464327450442527, 0.009340780072047241, 0.03396184815626059, 0.009123881264323635, 0.027884956382747208, 0.06522410402872733, 0.02992661057838372, 0.01692447335725384, 0.036401592061987946, 0.019982065805899243, 0.020966589583882263, 0.06285539256142718, 0.002075419370417616, 0.011361107912047632, 0.034461758831249814, 0.1521496307104826, 1.1652765231473106, 57.459493568965364, 110.1299134663173, 99.21384184701103, 92.94431550162179, 74.15912410191127, 82.10828713008335, 47.61388226917812, 70.33473137446812, 176.41276114327567, 83.03749752044678, 68.89813573019845, 76.25610433306012, 101.36562252044678, 65.7076063156128, 20.36306129183088, 0.17507053006972584, 0.019242308268855726, 0.11733152903616428, 0.05819973309657403, 0.10953679694128887, 0.10554909413414341, 6.694816027368818, 48.3629640851702, 6.732457458972931, 1.7418972104787827, 92.93394878932408, 95.74314716884068, 96.31934043339321, 88.4497412272862, 86.35264982495988, 85.7489069529942, 93.01660455976213, 92.81057657514299, 89.49381228855678, 86.59356471470424, 88.13090229034424, 74.17981583731515, 72.48571300506592, 67.68395887102399, 68.49422999790737, 64.95123931339809, 64.98190866197858, 61.64596734728132, 66.3434498650687, 75.49979986463273, 83.0341693333217, 84.72669492449079, 88.61525426592145, 80.17212295532227, 83.24728448050362, 85.8492875780378, 70.93893282754081, 63.15408774784633, 61.491078104291645, 63.82727786472866, 71.10604395185197, 72.78615311213902, 70.71099717276437, 69.50581128256661, 74.46542154039655, 76.63182817186627, 76.78864206586564, 81.62674917493547, 87.01264531271798, 87.0271531513759, 79.8631226675851, 45.832235608782085, 53.11072376796177, 56.458445753370015, 79.38371086120605, 84.8785617010934, 81.05127852303642, 73.91198362622941, 64.82660252707345, 64.09766006469727, 70.71697262355259, 75.45427526746477, 83.9918464933123, 76.52926581246513, 77.16885444096157, 91.422500201634, 82.96682739257812, 86.0277590070452, 82.38221985953194, 85.38972677503313, 82.17628914969308, 73.1753078188215, 62.91691793714251, 64.27910532270158, 64.41431031908307, 66.54173755645752, 66.16833441598075, 65.61110278538295, 63.762798581804546, 67.95122132982526, 70.20358412606376, 70.89952959333147, 70.75341592516217, 70.4541848046439, 76.14694118499756, 68.39202894483293, 80.93202659061977, 82.81352233886719, 89.22875935690743, 28.33736637660435, 0.5255529476063592, 0.028076737520417998, 0.07384927477687597, 0.1372884110148464, 0.1336509883403778, 0.03989642060228756, 0.05374304724058934, 0.07515216379293374, 5.027979663440159, 43.46516152790615, 73.4087256022862, 84.36924484797886, 42.467393262045725, 62.02722890036446, 72.80444771902901, 25.98514928136553, 24.61294780458723, 27.740915639059885, 38.88443306514195, 68.36627892085484, 69.13140760149274, 79.14401885441372, 26.761059829166957, 0.40978336547102245, 0.0373345878906548, 0.07454951613077096, 0.03545278636738658, 0.08671108247446162, 0.049739015488220115, 0.010519886489159294, 0.04249695695138403, 0.02196065865324012, 0.05822126979806593, 0.03819906186046345, 0.02052594724643443, 0.0025221398973371834, 0.022920794186315367, 0.040120025032332966, 0.009219730272889137, 0.08251869279359068, 0.03848889809367912, 0.030447002832910845, 0.08055043233824627, 0.03952978777566126, 0.0349612861339535, 0.052837891703737636, 0.032980608487767835, 0.08669027859078986, 0.043618755148989816, 0.025334921698751192, 0.031773294521761794, 0.03460535719724638, 0.03745257495237248, 0.013932414668878275, 0.03379499300249985, 0.04287114187276789, 0.02971587795764208, 0.06438127532601357, 0.022294463955664208, 0.06023917866072484, 0.029902400448918343, 0.00585237386569913, 0.012486047726789755, 0.028710353520831892, 0.02651935037491577, 0.034446142347795625, 0.02206229471734592, 0.05420219153165817, 0.05886808330459254, 0.09558697869735104, 1.4843052327632904, 68.89384869166783, 125.37451825823102, 109.43851906912667, 103.06228923797607, 88.99715505327497, 112.06620270865304, 72.41090175083706, 63.109257970537456, 137.65344429016113, 38.22467381613595, 55.86986037663051, 90.29145853860038, 110.36427620479039, 74.2676271711077, 24.139021600995743, 0.26992812433413094, 0.02709862420202366, 0.08383265550115279, 0.23498528078198433, 0.17565921348120483, 0.5698122669543538, 10.205688663891383, 45.90059198651995, 3.874580434390477, 3.7482517617089406, 100.28175912584577, 99.01515116010393, 100.84654344831193, 93.13323702130998, 90.89176900046212, 91.87608555385044, 98.66443388802665, 97.13779653821672, 94.71658556801933, 91.4134189060756, 92.70432472229004, 79.26022747584751, 77.229387147086, 71.36095946175712, 72.70651980808803, 68.28717367989677, 68.01163591657365, 66.71467821938651, 71.11099106924874, 77.40473883492606, 86.01987280164445, 88.36178398132324, 91.54712309156145, 84.69493470873151, 88.42949417659214, 88.33884797777448, 73.8547374180385, 64.58162988935197, 66.0444688796997, 67.42743832724435, 74.63604150499616, 75.6910629272461, 72.73894705091203, 73.18079689570835, 76.18205043247768, 81.11832863943917, 79.10787432534354, 82.51381874084473, 89.43241105760846, 89.52420370919364, 86.38019943237305, 52.78687865393502, 56.076419898441856, 59.22920322418213, 80.16769695281982, 87.60276971544538, 85.31998075757707, 79.6419267654419, 67.33654199327741, 66.73912893022809, 74.25254958016532, 79.30935818808419, 87.62107821873256, 78.81515366690499, 76.3566586630685, 91.79176221575055, 87.17021656036377, 88.5608081817627, 84.14460958753313, 88.22950417654855, 83.57759489331926, 78.2793641771589, 66.83998203277588, 66.87050546918596, 67.504716191973, 70.4903154373169, 70.33172280447823, 69.00096906934465, 67.7747996194022, 73.1487101146153, 75.57263088226318, 74.59292098454067, 74.5244881766183, 74.23034313746861, 77.19889845166887, 72.47155952453613, 82.29155281611851, 85.19227286747524, 93.89669813428605, 41.789909158434185, 0.9179870954581669, 0.3260551297238895, 0.08558791702879326, 0.36032356375030106, 0.19011990752603325, 0.09468754660338163, 0.014416197414642997, 0.21332780005676405, 4.89014390536717, 46.19769695826939, 78.84198066166469, 89.5290743964059, 48.79358564104353, 60.144128118242534, 38.74659470149449, 25.668356588908605, 39.017251355307444, 52.48963819231306, 55.04006133760725, 79.1694701058524, 75.39859935215541, 93.82662555149624, 42.44632632391793, 0.3662606365978718, 0.017226306089599217, 0.03116710829947676, 0.05950373491006238, 0.02084451774135232, 0.025816498357536535, 0.0019552639652309673, 0.012289834059109645, 0.05027691733890346, 0.016505595030529157, 0.06786659759070192, 0.017855252072747265, 0.046716186084917614, 0.01960120240359434, 0.03932914497064693, 0.04287956249234932, 0.03408452728763223, 0.04107383153002177, 0.05362291261553764, 0.0431274245493114, 0.018968692415260842, 0.01003041592360075, 0.018732358668265597, 0.04279214682589684, 0.04326591354661754, 0.020768331829458475, 0.07208433733986956, 0.1159619332424232, 0.16328862442501954, 0.09138138472501721, 0.06312760045485837, 0.13833697832056455, 0.11667261725025517, 0.1668244432657957, 0.15998639804976328, 0.09657608597938504, 0.14826207288673945, 0.10216538248849766, 0.13142259791493416, 0.11336507794580289, 0.1449998936482838, 0.09195037026490484, 0.18445248449487345, 0.1348244468016284, 0.11018659600189754, 0.20489914662071637, 0.4150041767529079, 3.387709302561624, 92.90108380998883, 146.01355852399553, 122.53178787231445, 116.81011308942522, 95.20968532562256, 110.31226199013847, 62.21264852796282, 79.17479937417167, 186.56538554600306, 106.95968668801444, 105.25965009416852, 96.5790571485247, 119.90390968322754, 86.44288608006069, 36.80777978897095, 0.5947389293994222, 0.08538473650280919, 0.1922558679112366, 0.27498432302049225, 0.4324050987405436, 0.24072267434426717, 8.397736992154803, 62.67191055842808, 9.825384225164141, 3.886142671108246, 103.49584293365479, 101.76431710379464, 107.59120845794678, 97.8012591770717, 96.21330397469657, 95.50903456551688, 102.8524397441319, 102.54363400595528, 101.12837627955845, 95.38522461482457, 95.06291852678571, 81.6753101348877, 81.77985273088727, 76.25967570713588, 75.8382466179984, 71.53135708400181, 72.51647268022809, 70.88534832000732, 75.20629405975342, 83.11776311056954, 89.97195952279228, 94.1531422478812, 93.7335752759661, 86.08575562068394, 92.92325551169259, 94.84023571014404, 79.7415361404419, 69.04302651541573, 69.47409275599888, 70.37212657928467, 79.35752310071672, 82.56852190835136, 76.37446689605713, 77.78756373269218, 81.24631445748466, 84.93961552211216, 84.13120651245117, 90.13593700953892, 95.15059784480503, 96.58786746433803, 87.37072072710309, 57.620330469948904, 69.23786790030343, 65.70893342154366, 86.11369432721818, 91.6599131992885, 89.68215015956334, 83.28638199397496, 71.5307525907244, 69.47622585296631, 78.68291555132184, 82.06937721797398, 92.16791684286935, 81.3551857812064, 78.39890098571777, 97.30246884482247, 91.25570869445801, 93.41802978515625, 87.6850711277553, 93.06479031699044, 87.68224321092877, 80.4583192552839, 70.29619666508266, 72.59406321389335, 70.68174525669643, 74.87845025743756, 75.43682834080288, 74.08158220563615, 73.14922428131104, 78.36274256025041, 80.45906966073173, 81.13079370771135, 79.60605321611676, 80.40885502951485, 83.88316971915108, 77.16123921530587, 89.0269558770316, 91.54664366585868, 101.07132462092808, 39.607823916843955, 1.6019805754934038, 1.4524971395730972, 0.15004298303808483, 0.5551815863166536, 0.23506955483130046, 0.27598429364817484, 0.1543552495007004, 0.32126985649977413, 9.677218232836042, 59.570165225437705, 84.08703681400844, 102.554765020098, 56.580633299691335, 94.0988768168858, 99.94197137015206, 33.85295064108712, 30.244407176971436, 37.92057548250471, 54.79573835645403, 89.27358218601772, 83.98673956734794, 106.67916011810303, 52.726248673030305, 0.5495168502841676, 0.15911864675581455, 0.11378718779555388, 0.14502140320837498, 0.18356340005993843, 0.09414738523108618, 0.08981828431465796, 0.1442544957888978, 0.1340277652655329, 0.1396438774785825, 0.12635466057275022, 0.077429843002132, 0.08400762254106146, 0.09093933951641832, 0.10462535013045583, 0.13022183520453318, 0.12089334933885507, 0.16150193315531525, 0.1100071913429669, 0.15427358102585587, 0.0772933896098818, 0.1357648420546736, 0.15145323665014335, 0.10057669452258519, 0.1843150540121964, 0.09249264188110828], [0.019964405235701373, 0.01585191305327628, 0.020750348955126743, 0.06525328103452921, 0.011013325636408158, 0.04094065885458674, 0.03727583015071494, 0.11484890510993344, 0.01125338369248701, 0.0802325318966593, 0.03855987624930484, 0.07417635579726525, 0.04146746665771518, 0.045345161974962266, 0.052132893819361925, 0.021228926489129663, 0.09953007461237055, 0.003738469261276935, 0.030382189167929546, 0.050404967074947696, 1.247166471821921, 76.1814876283918, 110.75083228519985, 90.69043799809047, 91.67932646615165, 63.171096937997, 72.86616161891392, 42.43000153132847, 36.64063392366682, 45.053377287728445, 134.413457598005, 112.13409355708531, 73.70266219547817, 105.18893132890973, 71.18030629839215, 29.152966771806987, 0.29043915229184286, 0.06286742977265801, 0.056947551002459865, 0.2193305143820388, 0.38689610787800377, 0.40670542206083027, 0.5716700415526117, 18.05017273766654, 13.43074541432517, 1.0889980047941208, 40.692646162850515, 95.13914026532854, 98.83683953966413, 94.28340707506452, 93.74524130140031, 96.07479858398438, 94.72292927333287, 92.72311959947858, 84.63880716051374, 89.80619634900773, 93.58405699048723, 87.47062192644391, 88.42217772347587, 71.84614522116524, 67.18807983398438, 65.73444025857108, 66.46883705684117, 64.46214171818325, 68.75557259150914, 62.85322380065918, 68.73950140816825, 74.76017802102226, 86.83907236371721, 81.32724012647355, 83.63686997549874, 85.59512942177909, 70.78073624202183, 61.77331393105643, 62.640518597194124, 65.15896960667202, 69.40947450910295, 72.39692892347063, 71.61671570369175, 67.51971040453229, 68.32083770206997, 73.46032292502267, 72.7899398803711, 72.78189386640275, 74.27597890581403, 73.56435830252511, 73.5720499583653, 85.97082546779087, 74.4622392654419, 43.88680253710066, 53.11698409489223, 72.59019306727818, 85.35512474605015, 82.14593247004917, 74.74332863943917, 67.19113009316581, 63.43439197540283, 65.2810286113194, 77.776015826634, 80.24327945709229, 82.70907701764787, 77.86126327514648, 80.82568441118512, 81.43852247510637, 84.72982856205532, 82.89656720842633, 81.77697617667062, 79.59773622240338, 80.88132558550153, 67.23265947614397, 60.86854730333601, 59.1165520804269, 63.420801298958914, 62.17218916756766, 64.66991370064872, 66.88621534620012, 69.34302193777901, 70.5956779207502, 70.05038329533168, 73.49828093392509, 77.31334223066057, 70.94990403311593, 73.24014145987374, 71.07392242976597, 79.62818322862897, 79.52894905635289, 90.3742185320173, 25.32564537865775, 1.2045243999787738, 0.10657056075121675, 0.11826656386256218, 0.10941181079085384, 0.031638452650180886, 0.024289149957309877, 0.011315575667790003, 0.1773847280336278, 10.037986942699977, 46.89009884425572, 76.27259935651506, 99.73490115574428, 58.66683687482561, 61.53346906389509, 63.2185948235648, 32.06874704360962, 25.625112737928117, 33.21424443381173, 54.55563988004412, 69.56726115090507, 59.1548297064645, 74.74833134242466, 9.77845869745527, 0.19566429858761175, 0.11422085309667246, 0.01169524569663086, 0.13308069322790417, 0.05674922200185912, 0.011762233218178153, 0.04134841090334313, 0.023104702621432285, 0.06266441888042859, 0.04930819324882967, 0.0641413317727191, 0.031242164450564554, 0.06769076881131955, 0.06200693201805864, 0.04692026227712631, 0.020056304322289567, 0.021603664416553717, 0.03738444325114999, 0.03215318592265248, 0.054012557957321405, 0.048332334363034794, 0.03402124711179307, 0.013929065250392472, 0.07710175096456494, 0.04675271162497146, 0.08868674574685947, 0.0420965534368796, 0.0635879932503615, 0.025578522555796162, 0.016752927830176692, 0.050639763940125704, 0.05512909411585756, 0.03555313491129449, 0.05291648302227259, 0.06670004661594119, 0.11767117652509894, 0.054308585822582245, 0.020616441765534024, 0.05011966684833169, 0.0473008593544364, 0.02975632543010371, 0.05350575675921781, 0.0691244997350233, 0.021891146133254682, 0.0411332067368286, 1.3218484244176318, 93.62156336648124, 128.1586197444371, 103.87497138977051, 100.68566485813686, 90.34179823739188, 95.46929086957658, 70.23591409410749, 59.70439747401646, 55.426627840314595, 138.21465029035295, 94.28440066746303, 80.38673196520124, 115.76795973096574, 80.29294518062046, 34.99038117272513, 0.12502296774515084, 0.0688202649887119, 0.01607172786524253, 0.2597899426306997, 0.43663785446967396, 0.6253296222005571, 0.8346945334758077, 10.217336450304304, 9.644361938749041, 0.3861664113189493, 54.99594375065395, 96.88930116380963, 102.54697608947754, 99.13344424111503, 98.71123000553676, 97.9860395703997, 99.3260691506522, 95.5005577632359, 88.47719355991909, 95.61229869297573, 96.40539387294224, 91.63754694802421, 93.4149169921875, 77.63717692238944, 71.30253900800432, 70.5388902936663, 71.34511756896973, 67.61043303353446, 70.95297513689313, 66.40521240234375, 71.2182365145002, 78.20697089603969, 89.22303404126848, 84.19055802481515, 86.8760506766183, 86.27467019217355, 73.84814357757568, 63.91710417611258, 64.55433736528668, 68.06471320561, 73.43660177503313, 75.75697353907994, 74.95529733385358, 70.03759860992432, 71.17816625322614, 74.12359796251569, 75.50708852495465, 74.95465115138462, 77.74344961983817, 77.28615392957414, 77.30913857051304, 86.1863099506923, 78.88761643001011, 51.30888911655971, 57.87722274235317, 74.44880839756557, 88.2607502256121, 84.62689794812883, 77.62450340815953, 70.80292184012276, 67.63034657069615, 68.09326335362026, 81.10945578983852, 84.79959542410714, 84.66133322034563, 81.0238539831979, 85.75016457693917, 85.66639014652797, 86.51602976662772, 84.91204507010323, 83.08853203909737, 84.20428071703229, 85.69594083513532, 71.1431473323277, 65.40790271759033, 63.860795974731445, 66.17911802019391, 66.46514061519078, 67.01131766183036, 71.92137336730957, 72.69361005510602, 73.68092128208706, 75.32870047433036, 77.29736832209996, 81.69363948277065, 74.9652818952288, 76.97327654702323, 74.1084508895874, 83.33689539773124, 83.9335858481271, 96.92961461203438, 38.77021510260445, 0.5294933904494558, 0.1384323803441865, 0.1386738031038216, 0.24749578375901493, 0.02002715615422598, 0.09211111521082264, 0.11122885293194226, 0.45436311619622366, 11.152263471058436, 51.41551964623587, 78.93354402269635, 105.30327088492257, 66.75260843549455, 49.72752775464739, 21.5399489062173, 23.3475627217974, 38.17491429192679, 50.73115682601929, 69.51191180092948, 82.76120240347726, 66.15481322152274, 90.55679634639195, 18.845727579934255, 0.21743960013347013, 0.0813962398096919, 0.07854915436889444, 0.024827011095892106, 0.09821480911757265, 0.04332225909456611, 0.04624084855562874, 0.04267440064411078, 0.040453277328716855, 0.03886957998786654, 0.029380318642194782, 0.021645982949329273, 0.05885146598198584, 0.02124563032495124, 0.024572436631258045, 0.07725204647119556, 0.07764164770820312, 0.04238026589155197, 0.03237058514995234, 0.03457936252068196, 0.020917930141357437, 0.010973451526037284, 0.047958410677633116, 0.018053589555035745, 0.03148481196590832, 0.14546417444944382, 0.16884862179202692, 0.17625104529517038, 0.14744392250265392, 0.10154822774763618, 0.23597656616142818, 0.12100726179778576, 0.09126997606030532, 0.10249519121966191, 0.15118982935590403, 0.16127482748457364, 0.11441138572990894, 0.1143647160913263, 0.12277466910226004, 0.09332006783889872, 0.11152311321347952, 0.1813209911010095, 0.16791773959994316, 0.11180863396397658, 0.21624304434018476, 3.4061602439199175, 117.34734780447823, 139.6576382773263, 114.1433458328247, 116.10754598890031, 90.18833337511334, 92.61683300563267, 55.21068825040545, 51.52330705097744, 52.55202259336199, 141.45585986546106, 157.83600180489677, 92.66465745653424, 131.01157787867953, 90.66186700548444, 53.50573928015572, 0.41391678367342266, 0.29718294899378506, 0.18672044708260468, 0.4091321075601237, 0.887556211224624, 0.5361295714974403, 0.998531156352588, 32.86454159872872, 18.188810144151958, 1.4216254247086388, 53.6142840385437, 95.15956102098737, 104.31247166224888, 101.57972431182861, 103.60346358163017, 101.64769159044538, 103.04180594852993, 99.54149804796491, 93.37259551456997, 99.50713920593262, 102.98050894056047, 95.43318802969796, 97.85945728846959, 79.84962231772286, 73.42130184173584, 75.50845037187848, 74.02226543426514, 72.12633827754429, 74.54959201812744, 70.02163859776088, 76.46801049368722, 84.40027550288609, 96.44445664542062, 88.15240001678467, 89.76329122270856, 93.67288276127407, 78.15387971060616, 68.88306508745465, 68.39161205291748, 72.59557792118618, 78.81931563786098, 81.51564747946603, 80.25017901829311, 74.93648161206926, 75.05917985098702, 79.3107269832066, 79.14085047585624, 79.40610490526471, 80.79274994986397, 78.7947815486363, 82.06645202636719, 94.38571235111782, 79.53261075701032, 58.91531835283552, 62.91676507677351, 76.8279549734933, 94.78515039171491, 88.37197004045758, 82.82318033490861, 75.09292030334473, 71.63277299063546, 72.10814789363316, 88.37782737186977, 89.35534163883754, 85.69350896562848, 82.90877519335065, 92.62976360321045, 87.56633336203438, 90.59503923143659, 87.95434856414795, 87.34702736990792, 89.23482513427734, 89.68895244598389, 73.87505395071847, 68.58580030713762, 66.71773542676652, 70.36977113996232, 68.82765320369175, 74.07518291473389, 78.3241800580706, 77.44587217058454, 79.6352356501988, 77.63273007529122, 82.46589701516288, 86.611727305821, 78.6641971043178, 82.21704033442906, 78.04591860089982, 88.31181948525565, 90.54151030949184, 101.55034732818604, 36.78743198939732, 2.3007869635309492, 2.327227247612817, 0.2539852926773684, 0.5236523981605257, 0.1260226805295263, 0.20803790033927985, 0.3249208905867168, 0.5821457537157195, 17.777325664247783, 66.99024377550397, 88.28044836861747, 117.30647850036621, 72.47508920942033, 87.9104220526559, 80.63558864593506, 41.11977277483259, 33.74200528008597, 45.47541781834194, 72.49396051679338, 93.26018060956682, 74.8988710130964, 104.72333254132951, 26.332600900105067, 0.35565103590488434, 0.2651335687509605, 0.18807568507535116, 0.2246912531554699, 0.2314184121787548, 0.09377354636256184, 0.16263317316770554, 0.10094535616891724, 0.1530555428138801, 0.11658455697553498, 0.17971663576151642, 0.07742019423416682, 0.11818531607942921, 0.14396147722644465, 0.14059564497854027, 0.15014340622084482, 0.21491236931511334, 0.1160637406366212, 0.12680990328746183, 0.24749119686228888, 0.2602042832544872, 0.11300146460000958, 0.17492281299616608, 0.11921208884034838, 0.16011214415941918], [0.012673119831431125, 0.030279533604958227, 0.027148990160120384, 0.023255337395572236, 0.06195754145405122, 0.03336859820410609, 0.059418544838471074, 0.045825652977717776, 0.02737759878592832, 0.06076264807156154, 0.026135647303557823, 0.08447214761482817, 0.05147186161151954, 0.04533538428534355, 0.06149174751979964, 0.011770077082993729, 0.030776913344327892, 0.038048287986644676, 0.015201830704297339, 0.02011842081057174, 59.27479730333601, 115.7768325805664, 84.15782506125313, 95.08609076908657, 75.58375494820731, 66.19706521715436, 26.113199370247976, 34.42935929979597, 39.011585099356516, 36.87950951712472, 43.087523460388184, 63.38321154458182, 102.12431716918945, 66.62557452065604, 24.803467409951345, 0.8805157861539296, 0.02088989137804934, 0.055394252030445, 0.010361956615400101, 0.17997762747108936, 0.44190353048699244, 0.04880903235503605, 3.609697299344199, 2.2772241021905626, 0.41651258724076407, 45.71124315261841, 100.06826877593994, 97.21083600180489, 91.65240914481026, 97.62558092389787, 96.95060511997768, 92.56909888131278, 88.04469599042619, 86.07021250043596, 84.57970578329903, 85.44169235229492, 85.47253540584019, 90.15730272020612, 86.8958808353969, 86.02955164228166, 72.91220038277763, 64.58354759216309, 65.94475528172084, 64.31277629307338, 64.51242583138603, 64.6686977658953, 60.586221149989534, 69.9446803501674, 87.57784652709961, 82.95515441894531, 85.93415982382638, 76.76373972211564, 65.55950546264648, 61.625629970005576, 61.62447656903948, 61.538221631731304, 68.48305034637451, 66.11010156358991, 66.31237752096993, 64.60704639979771, 64.90572166442871, 66.05773993900844, 70.45915971483502, 68.59620176042829, 74.29182079860142, 75.63285091945103, 83.89518315451485, 74.68935503278459, 87.04168878282819, 54.02873018809727, 57.081278800964355, 80.10389164515904, 77.44976316179547, 82.88257353646415, 73.19211551121303, 72.23704392569405, 64.74593394143241, 66.12502629416329, 72.24115031106132, 81.8749110358102, 80.66138730730329, 82.5547297341483, 82.03561592102051, 82.99976185389927, 80.2125197819301, 82.66949313027519, 80.9662812096732, 81.2950074332101, 79.1176643371582, 74.22957188742501, 66.35891655513218, 61.90949167524065, 61.57686751229422, 64.07132639203752, 60.160122871398926, 62.42431150163923, 68.01989037649972, 72.13398824419293, 75.0032468523298, 77.39052976880754, 74.34844166891915, 79.93625245775495, 71.91870525905064, 71.49543489728654, 71.69258308410645, 82.65817451477051, 76.51866980961391, 94.83513573237828, 20.631464992250713, 1.0626355622495924, 0.30207309659038273, 0.1339702254959515, 0.03968100608991725, 0.04693842665957553, 0.05570074290569339, 0.0365034774877131, 0.0981095547654799, 5.443359911441803, 28.11091763632638, 63.953123637608115, 95.76117079598563, 76.25233840942383, 74.7134930746896, 73.52362796238491, 48.93459933144705, 21.700328963143484, 22.632115398134502, 52.26931428909302, 63.22848905835833, 67.24659061431885, 59.06133474622454, 3.3045582558427538, 0.12185457561697279, 0.10363643962357726, 0.025707408586250882, 0.03851699283612626, 0.04028224579191633, 0.015793006035632322, 0.02070440534901406, 0.005786241722359721, 0.05810581027929272, 0.05103962462661522, 0.04728255247963326, 0.021952577301168015, 0.0386270681795265, 0.11790544752563749, 0.03600387215348227, 0.026132212220025913, 0.025150872467617904, 0.050448047263281684, 0.048792730551213026, 0.01785141495721681, 0.06518478292439665, 0.051465442670243125, 0.0444876769158457, 0.005673364453416849, 0.025413825143394724, 0.06464873347431421, 0.053808641220842085, 0.03860132795359407, 0.0801766545378736, 0.006410383253491351, 0.047486079058476856, 0.03176182388727154, 0.046299345059586425, 0.03650349784376366, 0.08310351534081356, 0.04467551915773323, 0.06857530027627945, 0.044685720931738615, 0.09851988524730716, 0.008046910482724863, 0.023487526989941086, 0.08521871933979647, 0.06107243323432548, 0.061697106143193584, 73.67345196860177, 131.4743001120431, 92.43372017996651, 110.9702980858939, 94.86240046364921, 86.97748742784772, 51.81422812598092, 51.64105122429984, 21.880969967160905, 23.294445480619157, 50.31677321025303, 73.44553021022251, 116.13732596806118, 76.06333351135254, 28.989083085741314, 0.24023556762507983, 0.05999521139476981, 0.1126263840124011, 0.15879924675183638, 0.19653811598462717, 1.3954936840704508, 0.39596779538052423, 3.1280503443309238, 1.506464557988303, 0.8979586958885193, 57.41033853803362, 102.69092886788505, 98.75373213631767, 92.42581312997001, 97.5364077431815, 99.30725342886788, 94.14312989371163, 90.35287366594586, 90.5488476072039, 91.7928113937378, 89.31859261648995, 90.23565060751778, 93.22612748827252, 91.97654955727714, 90.10838740212577, 76.79802213396344, 69.59754834856305, 69.26036616734096, 67.17392635345459, 67.79679761614118, 68.33936854771206, 64.16205596923828, 73.59719548906598, 90.38662801470075, 86.8179428918021, 89.13212381090436, 78.58748204367501, 66.77695492335728, 62.66530976976667, 63.14568737574986, 65.54168333326066, 70.73584393092564, 69.90431826455253, 68.94849627358573, 67.80628885541643, 68.62416131155831, 69.2094497680664, 73.3716847555978, 71.03222629002163, 75.25381973811558, 80.21707780020577, 86.23003496442522, 78.65814522334507, 90.33902590615409, 60.11805847712925, 62.755386216299875, 82.31689289637974, 81.68455123901367, 86.97637571607316, 77.24006652832031, 75.60330717904228, 67.68636294773647, 69.39631462097168, 75.68048082079206, 86.01018701280866, 84.77351188659668, 86.43898814065116, 84.82834706987653, 84.70887279510498, 83.19081647055489, 85.58819511958531, 83.61118248530796, 84.01838166373116, 81.76936095101493, 78.0431045804705, 69.77426883152553, 65.92439011165074, 65.40966061183384, 67.79904188428605, 64.80590384347099, 64.84198583875383, 72.23156179700578, 76.6020759854998, 77.48586600167411, 81.57081617627824, 77.07870156424386, 82.8600891658238, 73.83947917393276, 76.21711799076625, 74.55396243504116, 87.22910254342216, 80.61589050292969, 99.53271552494594, 31.266862392425537, 0.25662264972925186, 0.22221454605460167, 0.7721269279718399, 0.7340778868113245, 0.17589214098240646, 0.07634785106139523, 0.09506188080246959, 0.1104209619973387, 4.434877089091709, 32.37554475239345, 67.48963860103062, 99.80342429024833, 81.22525446755546, 57.28616728101458, 29.515461240495952, 27.76646590232849, 29.226864337921143, 41.8396235193525, 63.56370489937918, 76.03174005235944, 73.49535574231828, 75.45629719325474, 7.434985910143171, 0.17622900647776468, 0.1257719211280346, 0.07621413216527019, 0.034362238100064654, 0.04408220135207687, 0.027352903503924608, 0.017710135484646474, 0.012816135505480426, 0.013663763147113579, 0.032068983119513304, 0.07111091100211654, 0.031675731364105425, 0.018953355827501843, 0.06532134488224983, 0.013489260055523897, 0.029879350614334856, 0.0513719303666481, 0.037124788255563805, 0.037414529493876865, 0.009478656691499054, 0.07435238813715321, 0.047319861727633646, 0.038279173097440174, 0.049510688454444916, 0.13286486480917248, 0.18878174147435597, 0.13259332866540977, 0.13362088852695056, 0.2390520397041525, 0.09382336440363101, 0.10674036413963352, 0.20123688956456526, 0.09046705878738846, 0.1182145473680326, 0.1785194014332124, 0.19686981104314327, 0.14324331576270716, 0.14153585024178028, 0.16992100567689963, 0.08576944550233227, 0.12360191185559545, 0.22759676724672318, 0.10841902584901877, 0.25591244069593294, 94.50328976767403, 142.54383659362793, 105.11696188790458, 122.95721217564174, 97.38007327488491, 88.36759267534528, 38.04989882877895, 45.70874180112566, 53.649445397513254, 49.055174895695274, 65.8054369517735, 81.94827011653355, 127.87574468340192, 85.17544433048793, 41.742609296526226, 2.943192000899996, 0.13039517376039708, 0.3704685579453196, 0.16718633313264164, 1.4553206052098955, 3.3055629219327654, 0.14889325973178658, 11.590674826077052, 9.67581730229514, 0.6854211177144731, 54.043776512145996, 104.77727140699113, 100.41913196018764, 94.13712665012905, 99.79694856916154, 105.72847979409354, 100.73710932050432, 95.33348137991769, 96.35261535644531, 95.90850039890834, 94.09729262760708, 94.17756516592843, 98.07540730067662, 95.05883298601422, 94.20562894003731, 81.9335607801165, 72.70102378300258, 71.53002302987235, 71.5159251349313, 71.03283078329903, 73.34595557621547, 67.59261785234723, 77.50440379551479, 94.87081473214286, 90.63740934644426, 92.42162336621965, 84.00577068328857, 69.33799144199916, 65.09617178780692, 67.90194470541817, 68.42704091753278, 75.66974585396903, 74.4194244657244, 72.90679468427385, 72.18436963217599, 71.39631189618791, 73.90041487557548, 77.57796437399728, 75.5397172655378, 80.41300310407365, 83.4628106525966, 90.92290387834821, 82.88461630684989, 94.7549535206386, 66.37528651101249, 66.86320986066545, 84.4086480821882, 86.92126955304826, 90.58378314971924, 80.7914992741176, 80.4548590523856, 72.69925894056047, 73.21169553484235, 79.62192984989711, 90.8390599659511, 88.52742903573173, 88.78994587489537, 89.11546897888184, 89.88220269339425, 87.72059031895229, 89.89335455213273, 86.69186088017055, 88.93054962158203, 86.62386580875942, 82.05432741982597, 73.29522677830288, 69.0148515701294, 68.97376687186105, 71.80508831569126, 69.05305971418107, 70.23802634647915, 78.47749205998012, 80.72319153376988, 81.54282188415527, 85.09247589111328, 82.06419386182512, 88.5670268195016, 79.36342906951904, 82.21334389277867, 79.48958056313651, 90.15510014125279, 84.68997369493756, 101.4269334248134, 28.863226890563965, 2.253455183335713, 1.9212442210742404, 0.4438239745795727, 0.5217988033379827, 0.30530509459120886, 0.22177313188357012, 0.24296335982424871, 0.38603960669466425, 12.220973713057381, 44.67274454661778, 77.67658015659877, 109.63067844935826, 96.09911727905273, 107.72250161852155, 97.45302936008999, 58.86320686340332, 30.875428676605225, 36.125431946345735, 66.51805114746094, 88.27916295187813, 83.87838935852051, 91.4615421295166, 11.771433080945696, 0.39023338737232344, 0.27586804702878, 0.28455389237829615, 0.1477584506251982, 0.13723304255732469, 0.1622141913643905, 0.11914111407739775, 0.15715880692005157, 0.2104813592242343, 0.11610381491482258, 0.12268366398555891, 0.17242659122816154, 0.11158884968608618, 0.13444828055799007, 0.09998229784624917, 0.1429617101592677, 0.2233529242553881, 0.13772583539996827, 0.09925055889678852, 0.16065947764686175, 0.18842103225844248, 0.12961493991315365, 0.10178938587861401, 0.15327084197529725], [0.07241512316146068, 0.031083397434226105, 0.07626616223050015, 0.017218830330031257, 0.08905779583645718, 0.058836226085467, 0.07047578186861106, 0.03913145040028861, 0.04844704070793731, 0.0314785490876862, 0.05172593904925244, 0.11080944365156548, 0.019840426709769026, 0.021941591819216098, 0.0362661157601646, 0.062047114861863, 0.04564674364935074, 0.1808971238455602, 0.5234605627400535, 24.55251063619341, 109.17186110360282, 85.51506532941545, 89.55365712302071, 50.72526822771345, 50.07270731244768, 38.53268051147461, 40.972582135881694, 42.761854444231304, 103.07292693001884, 95.9703949519566, 73.36766869681222, 105.87421825953892, 68.17947660173688, 22.681513616016932, 0.8657211171729224, 0.11868014452712876, 0.09459437695997101, 0.06420702753322464, 0.2864663840404579, 0.16578954165535315, 0.14561521634459496, 0.11832227158759322, 1.6530955412558146, 0.3078129328787327, 52.173012256622314, 103.88898590632847, 95.33189719063895, 102.66396290915353, 97.85213388715471, 92.13922078268868, 87.7899750300816, 87.34521389007568, 87.2637323651995, 86.27756064278739, 91.19478688921247, 89.37166990552629, 86.76779079437256, 86.0858598436628, 92.80984006609235, 84.64100973946708, 80.28632354736328, 67.47522803715297, 64.30980941227504, 67.83133016313825, 64.89440304892403, 63.0285199029105, 61.231361389160156, 75.51154232025146, 81.51755128587995, 78.71721185956682, 82.41463320595878, 71.30625629425049, 60.61853722163609, 59.49375588553292, 62.45457785470145, 64.33260645185197, 70.86265550340924, 70.84581307002476, 71.90576771327427, 66.01233346121651, 66.34010778154645, 65.45372608729771, 67.66393416268485, 65.8859943662371, 70.34676565442766, 65.20327132088798, 73.20120375497001, 74.5358554295131, 86.61470808301652, 59.085035051618306, 61.20191492353167, 78.83872890472412, 74.34857368469238, 80.70790549686977, 73.89453669956752, 71.67283630371094, 60.168439865112305, 65.81736006055559, 69.26478522164481, 78.13966369628906, 82.47681263514927, 83.10393619537354, 76.70934227534703, 73.86033766610282, 74.65362739562988, 76.10830920083183, 78.22275025503976, 75.42628792354039, 80.52697440556118, 76.77457891191754, 69.7151188169207, 65.84716088431222, 61.106849670410156, 60.26499203273228, 57.66767202104841, 58.569930349077495, 63.961065428597585, 70.3211476462228, 69.74977643149239, 75.24207033429826, 75.06817776816231, 73.90855816432408, 73.66888005392892, 67.38424832480294, 69.95672157832554, 71.13677583421979, 81.42770412990025, 78.96755545479911, 91.6965024130685, 10.41573965549469, 1.6567431283848626, 3.2791591158935, 0.07338413902159248, 0.10784572482641254, 0.010258333291858435, 0.07952608873269387, 0.034380253204809766, 0.09200939602617707, 1.6386189694915498, 16.334266458238872, 50.66597924913679, 88.03479480743408, 65.98614570072719, 80.53774411337716, 86.40166241782052, 38.471602371760774, 20.886269330978394, 32.79766518729073, 54.87517711094448, 65.3586677823748, 71.65312426430839, 39.38055181503296, 1.3555715062788554, 0.02149612849046077, 0.03296933462843299, 0.09702501153307301, 0.03659041817965252, 0.03028000518679619, 0.07127470935561828, 0.022011852424059595, 0.06278192757495812, 0.026925704641533748, 0.029110003861465623, 0.03983503693182554, 0.04227842117792793, 0.016363362216257622, 0.03975772465180073, 0.0025180018939343946, 0.0157495645274009, 0.024251847494659678, 0.05437490922798004, 0.019677384922813092, 0.10380035332803215, 0.03395777355347361, 0.10843919190977301, 0.043469368879284175, 0.061216608355087895, 0.06865764728614263, 0.048133357361491234, 0.04564387344622186, 0.054917048529854844, 0.025254501728340983, 0.09929320482271058, 0.03379524406045675, 0.038052009751221964, 0.01923454413190484, 0.045701314828225544, 0.04379212763160467, 0.019504110827775936, 0.0392383909119027, 0.02685000218584069, 0.07680897667471852, 0.06212822015264204, 0.15426275160695824, 0.6901354704584394, 30.876252038138254, 126.49680519104004, 95.4733555657523, 102.11637537819999, 65.40302508217948, 75.46773392813546, 67.75763756888253, 50.86840806688581, 20.702133383069718, 44.90988656452724, 86.50910936083112, 85.23094654083252, 116.62145560128349, 76.72648348127092, 26.831832442964824, 0.20528205750244005, 0.13061117859823362, 0.04420163369338427, 0.21462914879832948, 0.50945923690285, 0.9363015698535102, 1.3035810674939836, 0.8541066061173166, 0.6966853418520519, 1.1152017244270869, 66.41545404706682, 107.59533568790981, 101.1876027243478, 105.24704606192452, 103.29035690852574, 93.5850783756801, 92.13419028690883, 92.98578235081264, 93.66638619559151, 92.04088292803083, 93.5625662122454, 93.26816408974784, 90.44258880615234, 91.20304829733712, 93.81468854631696, 90.54681873321533, 86.33505698612758, 70.67090606689453, 68.9555973325457, 70.23542772020612, 67.71078586578369, 66.02308927263532, 65.6510340826852, 76.93977928161621, 83.88343375069755, 81.64068726130894, 84.59393569401333, 73.21087564740861, 65.33622510092599, 61.33022035871233, 65.19091742379325, 67.92370646340507, 74.920382635934, 74.88029847826276, 75.06184795924595, 68.86357539040702, 71.51600156511579, 68.12926891871861, 69.17374992370605, 68.9549719946725, 73.89144475119454, 67.45489065987724, 75.22151061466762, 77.57228769574846, 91.19364043644497, 62.98910277230399, 64.32809012276786, 79.24107129233224, 76.5408067703247, 84.43206351143974, 77.9374085835048, 74.24098777770996, 63.80142361777169, 69.12962191445487, 72.47683320726667, 80.30925260271344, 85.20381382533482, 86.10768413543701, 80.11817019326347, 76.91423770359584, 78.14233875274658, 78.74531037466866, 79.87246104649135, 80.07976055145264, 81.58408723558698, 80.33610044206891, 75.51859474182129, 71.55541174752372, 66.26962525503976, 62.64137322562081, 60.938765798296245, 63.5171936580113, 66.03046131134033, 72.55283260345459, 74.59116309029716, 78.25986058371407, 79.56574671609062, 77.72093745640346, 77.44731739589146, 72.05837099892753, 73.36365958622524, 74.54112911224365, 86.6248038155692, 82.38595799037388, 96.40800639561245, 19.082777534212383, 2.2346557463918413, 5.0692888753754755, 0.13642106684190886, 0.5272460824676922, 0.06242136085139854, 0.1811645616378103, 0.05168141697400382, 0.10050147891576801, 1.6768580547400882, 18.49793028831482, 56.00914396558489, 92.61613123757499, 78.50727203914097, 75.9404546192714, 44.31414801733834, 32.57187305177961, 35.01363679340908, 46.38293245860508, 64.19724859510148, 75.9944212777274, 80.38909435272217, 58.476984296526226, 2.0431510167462483, 0.06488812741424356, 0.08305170240678958, 0.025775290925854018, 0.03701491986534425, 0.016409889362486343, 0.024262056054015244, 0.018777727215949978, 0.07531519540186439, 0.0223904308596892, 0.07065344947789397, 0.06387738165046487, 0.0334098090284637, 0.05651108335171427, 0.026592403151361004, 0.012936599220016172, 0.014861458879230278, 0.03484981640108994, 0.07055858349693672, 0.01946481177583337, 0.04999705217778683, 0.06205306561397655, 0.05206080965165581, 0.05191692290827632, 0.16608330660632678, 0.18358678237668105, 0.25768887251615524, 0.09553831416581358, 0.09961607892598424, 0.10287558473646641, 0.1242379570113761, 0.16424468026629516, 0.1522305527968066, 0.13898198013859137, 0.13550131262413093, 0.32799408425177845, 0.12792093652699674, 0.22158059078667844, 0.17284667225820677, 0.15967184278581822, 0.10306242613920144, 0.3084173175905432, 0.8014275899955204, 43.969447885240825, 143.92073331560408, 105.90786143711635, 118.50031798226493, 73.2447898047311, 72.49234853472028, 52.954462255750386, 53.7184271131243, 59.21894073486328, 141.85583986554826, 140.27694511413574, 95.28554575783866, 130.7593721662249, 87.28564003535679, 40.83721385683332, 1.384892035807882, 0.4041373298636505, 0.3177620747259685, 0.43177332835538046, 0.7652074449828693, 1.7529678621462412, 1.4756185731717517, 2.99864861369133, 3.8999626381056647, 0.9120324892657143, 63.759831701006206, 112.61143480028424, 105.23987552097866, 108.74787507738385, 106.78488390786308, 98.3683294568743, 95.89945384434291, 96.86302307673863, 100.22385283878872, 96.98669406345913, 99.15511567252022, 94.286269732884, 93.97819355555943, 94.47990213121686, 100.48288863045829, 93.60916083199638, 90.27643653324672, 74.81636810302734, 71.37302848270961, 74.8707377570016, 70.76151057652065, 68.76053360530308, 68.89481449127197, 82.03298950195312, 89.11030646732875, 87.0769647870745, 90.11004107339042, 78.40099934169224, 68.06564426422119, 64.59813186100551, 70.62322752816337, 71.03740269797188, 78.02685274396623, 78.22719710213798, 78.73987688337053, 71.5559606552124, 74.51755387442452, 71.93553379603794, 73.7030165536063, 72.191741670881, 78.2103407723563, 71.57108688354492, 79.20560073852539, 82.18140997205461, 95.23087038312639, 69.47649683271135, 69.20771271841866, 81.31840896606445, 78.72086661202567, 87.58257825034005, 81.01994214739118, 80.08586801801408, 66.75048923492432, 72.93733896527971, 77.43305969238281, 85.17122677394322, 91.94033554622105, 92.42329788208008, 86.28286906651088, 82.44863768986293, 81.8081180027553, 82.49878978729248, 85.54642254965646, 81.82985196794782, 87.27005522591728, 84.42912442343575, 78.77603530883789, 73.73508249010358, 69.06280108860561, 64.67371436527797, 66.11663287026542, 68.06771482740129, 71.27562863486153, 77.8526336124965, 77.79297637939453, 84.35597378867013, 83.81303460257394, 82.54351534162248, 79.28419181278774, 74.82009233747209, 79.16828196389335, 79.3971278326852, 91.66203934805733, 88.11565794263566, 103.33452660696847, 15.937625067574636, 4.949056812695094, 7.248146678720202, 0.2571031610880579, 1.032919636794499, 0.23703841918281146, 0.32618114724755287, 0.18218316483710492, 0.85991497444255, 5.520971289702824, 31.282794611794607, 66.5784935270037, 98.87764630998883, 83.01271329607282, 107.79328291756767, 116.74705123901367, 49.57676574162075, 32.88743591308594, 48.32888317108154, 70.05097389221191, 88.48090389796666, 89.67285346984863, 77.60343647003174, 4.565215740885053, 0.20282687353236334, 0.19034792243369988, 0.11907179493989263, 0.19701637460717134, 0.12553729728928634, 0.2011940875755889, 0.0680101348885468, 0.27721716463565826, 0.11469791749758379, 0.21601653578025953, 0.14932673504309996, 0.13006311229297093, 0.10443164873868227, 0.13822652639022895, 0.06730206324053661, 0.10791365296712943, 0.09862376895866223, 0.14278392041368143, 0.16331506014934608, 0.1865496462477105, 0.17493308601634844, 0.18767001612910203, 0.16648921982518264], [0.03759536925437195, 0.043949405263577185, 0.05316217715985008, 0.1301393931997674, 0.014674120449594088, 0.04257123278720038, 0.02548704924993217, 0.04273693782410451, 0.021478400066761032, 0.04022381714146052, 0.035492891179663796, 0.042815264513982196, 0.07176584657281637, 0.01902111094178898, 0.021350772718765905, 0.08210043023739542, 0.0364012120823775, 0.11901131032833032, 2.537052639893123, 85.93126242501395, 92.71455941881452, 97.6442437853132, 63.01187201908657, 70.09645680018834, 38.478488036564414, 27.775408233915055, 51.135312693459646, 86.05256407601493, 72.21494170597622, 82.14170796530587, 91.6326345716204, 69.36914021628243, 22.783278669629777, 0.9578788748809269, 0.034534531711999855, 0.12910537368484906, 0.02346388852622892, 0.05437115014397672, 0.20921992191246577, 0.28360103922230856, 1.1065076823745454, 2.2081705161503384, 1.2976364493370056, 49.21805804116385, 108.66582380022321, 89.5637320109776, 93.76628044673375, 93.41149847848075, 98.0020204271589, 95.74341814858573, 88.12279374258858, 89.41318539210728, 87.31396784101213, 91.95035484858921, 91.03254645211356, 85.55373205457414, 91.35453292301723, 88.1591467176165, 85.0902316229684, 87.67002132960728, 84.71251365116665, 69.2983728136335, 63.40243026188442, 61.67544160570417, 62.27179159436907, 61.12430354527065, 59.34143052782331, 73.57179287501744, 75.27653339930943, 74.90581226348877, 78.02558122362409, 65.49857670920235, 61.57199682508196, 62.0756231035505, 62.78616673605782, 66.22895744868687, 75.58028084891183, 76.7658589226859, 77.91195733206612, 71.22603934151786, 70.310544695173, 66.3921150479998, 68.78051662445068, 69.93835054125104, 74.257566179548, 66.02839769635881, 70.21759169442313, 74.17256886618478, 80.89540958404541, 64.86061395917619, 64.57172870635986, 79.50283077784947, 76.29365934644426, 79.6446782520839, 75.43702983856201, 71.15233285086495, 60.5508895601545, 62.54484190259661, 62.24565941946847, 73.19422081538609, 77.048463003976, 78.23921748570034, 69.19975703103202, 62.95031792776925, 64.6923633302961, 73.50538894108364, 77.15770953042167, 79.04308932168144, 73.68935639517647, 79.22495147160122, 75.75335352761405, 73.0740864617484, 67.20861176082066, 65.67081560407365, 57.30132825034005, 56.792362281254356, 56.29370743887765, 64.0849448612758, 70.92206260136196, 74.02204309191022, 70.49506105695451, 74.99797316959926, 70.31242765699113, 73.88478142874581, 68.84931073869977, 71.73305634089878, 73.45113740648542, 81.66376917702812, 74.80746746063232, 86.76671382359096, 1.093833082488605, 3.41422558256558, 4.461293271609715, 0.26953823811241556, 0.28706460765429903, 0.06762479485145637, 0.08823555388620921, 0.11684828996658325, 0.06585566406803471, 0.1090999628816332, 9.5008008650371, 44.879995414188926, 83.19162246159145, 74.84172902788434, 62.831045150756836, 57.80969320024763, 30.854260989597865, 23.241701705115183, 41.72990798950195, 59.05134323665074, 62.08202239445278, 72.28477805001395, 20.478681053434098, 0.8000731798154967, 0.10942313554031508, 0.08481031589742218, 0.02582844396653984, 0.07915551361760922, 0.012216717670006412, 0.0455751242781324, 0.017201773655999984, 0.0844707769740905, 0.10102080247764077, 0.012571935841281499, 0.031291107181459665, 0.061007531359791756, 0.07665091872747455, 0.052451428691191335, 0.031078813930175135, 0.026595461647957563, 0.05565006991050073, 0.03124462753268225, 0.06873036588409118, 0.07766174591545548, 0.07928222324699163, 0.025333305089069263, 0.04613811835380537, 0.024215440698234097, 0.02125851231228028, 0.03128403006121516, 0.013098473926740033, 0.07294885880712952, 0.03268101831365909, 0.043089436766292365, 0.024954241500901322, 0.0065916806010396355, 0.019163805159873197, 0.07014164408402783, 0.08246362289147717, 0.05161895104018705, 0.1056985075452498, 0.07918392387884003, 0.03589413607759135, 0.16608304876301969, 3.646968739373343, 100.16773223876953, 107.56683417728969, 107.0520907810756, 74.7233942576817, 81.50630215236119, 55.23555932726179, 28.96586046900068, 20.371567623955862, 43.445435592106406, 79.46927792685372, 93.72038064684186, 96.1092894417899, 80.77533081599644, 29.544515132904053, 0.43772047066262787, 0.051032774815601964, 0.00984873902052641, 0.07348150201141834, 0.12071925082377025, 0.5911734721490315, 1.1628167522805077, 1.6962923833302088, 0.9681462496519089, 2.0237905127661566, 61.8986177444458, 110.64754731314522, 91.86052853720528, 98.21631676810128, 95.75461169651577, 100.30197143554688, 100.67957823617118, 91.186997958592, 92.21384443555559, 90.45464393070766, 93.68811321258545, 93.28766768319267, 88.63938535962785, 93.37067781175885, 90.74858747209821, 89.29882499149868, 90.66872487749372, 88.56508132389614, 72.76161902291435, 65.11322961534772, 65.33266762324742, 65.36330223083496, 63.2278915132795, 64.41417135511125, 76.99962411608014, 78.41067123413086, 79.7984835760934, 80.19127219063895, 68.53595393044608, 62.6420749936785, 63.84302248273577, 64.16114575522286, 69.4632466179984, 78.72595269339425, 81.5651672908238, 81.96030439649309, 75.49451923370361, 72.50296538216728, 68.74103696005685, 70.94343526022774, 72.0703844342913, 77.42303344181606, 68.46659006391252, 70.50801944732666, 75.98992579323905, 84.67454869406563, 68.21314062391008, 66.00592722211564, 82.52463708605084, 79.03493213653564, 82.12297562190464, 78.59130355290004, 73.52867930276054, 63.45698056902204, 64.53544521331787, 64.69945744105748, 75.43456322806222, 78.71548870631626, 81.18508693150112, 72.71602494376046, 67.22163268498012, 66.04303060259137, 76.5174399784633, 80.91141823359898, 82.90814985547746, 79.50315734318325, 81.76904828207833, 80.24653121403286, 77.88828481946672, 73.57270308903286, 70.92906638554165, 59.78412110464913, 60.208503178187776, 58.76242324284145, 68.58479281834194, 73.08792727334159, 76.58401761736188, 74.5005794252668, 78.86537524632045, 74.94045598166329, 76.4937744140625, 70.28716400691441, 75.15505804334367, 75.32143265860421, 85.52419526236397, 77.92710440499442, 96.9043857029506, 3.410611216511045, 0.8238874248095921, 3.1520146812711443, 0.9236617109605244, 0.27451358256595476, 0.06891984000269856, 0.033727953742657385, 0.28596546234829084, 0.19893714439656052, 0.34419725622449604, 10.0444062096732, 50.41819953918457, 85.97873946598598, 85.22730568477085, 60.99899278368269, 31.241466726575577, 25.67782003538949, 36.2025534766061, 57.21803671973092, 69.33229391915458, 69.65578814915249, 84.56906114305768, 32.66417639596121, 0.9292842149734497, 0.14591196684965066, 0.12065801982368742, 0.02128808626106807, 0.11966754868626595, 0.03239276645971196, 0.034708195964672735, 0.042352812364697456, 0.027890935972599045, 0.03371596402887787, 0.017306904175451825, 0.011996042814904025, 0.06287754672978606, 0.10666378467742886, 0.098106793127954, 0.048064313030668666, 0.07272034856889929, 0.030452563427388668, 0.01134583748145295, 0.078675178677908, 0.033540678077510426, 0.014350464334711432, 0.04567907923566444, 0.11492422249700342, 0.17535737396350928, 0.07424003630876541, 0.1632094258176429, 0.09109406585672072, 0.12220754953367369, 0.19022035785019398, 0.11698833959443228, 0.09851198031433991, 0.11333852687052318, 0.16045978479087353, 0.146237812936306, 0.18176452230129922, 0.15901924137558254, 0.2413756964462144, 0.1364622132054397, 0.14439371760402406, 0.5010878518223763, 5.497901099068778, 120.70524542672294, 116.8952146257673, 121.85432461329869, 85.33503750392369, 96.72458021981376, 52.51792083467756, 39.06491599764143, 70.68047373635429, 130.16334179469516, 103.00221511295864, 92.79861177716936, 102.89023099626813, 93.22543961661202, 43.354528835841585, 1.1612764235053743, 0.10849112698010036, 0.3551444416599614, 0.3152714440865176, 0.26728007357035366, 1.3816154173442294, 1.3326869628259113, 2.7802573953356062, 8.07613354069846, 3.1236241246972765, 62.395413943699424, 117.83770997183663, 96.17494297027588, 101.1091228212629, 101.91828918457031, 105.4912474496024, 102.9133129119873, 95.3690492085048, 95.88834367479596, 95.10992309025356, 97.86384160178048, 97.5761444909232, 93.81580025809151, 99.27938420431954, 94.00242887224469, 93.07241943904332, 95.56080559321812, 93.23555619376046, 75.30865492139543, 68.88727569580078, 69.64111355372837, 69.26311765398297, 67.59208978925432, 66.9973726272583, 81.37035369873047, 82.43050289154053, 84.25496782575334, 83.7021552494594, 72.15154634203229, 65.75438853672573, 67.16071782793317, 66.57816001347133, 72.48917320796421, 83.6149206161499, 85.83317470550537, 85.21475723811558, 78.3712124143328, 75.41054330553327, 74.1095973423549, 72.4274593080793, 75.29213210514614, 81.23687185559953, 73.39890779767717, 75.85252516610282, 79.30172211783272, 87.04136221749442, 73.09457669939313, 69.77955641065324, 84.7083099910191, 83.2475276674543, 82.64721025739397, 83.24841008867536, 79.02362741742814, 64.40165764944894, 68.4715997150966, 67.72760050637382, 79.61565562656948, 84.62199251992362, 87.95933042253766, 77.93484469822475, 69.88198675428117, 71.90514237540108, 81.81945051465715, 84.29448223114014, 86.75870255061558, 82.08023030417306, 86.91244534083775, 83.68667466299874, 82.47889709472656, 76.33834321158272, 75.05046680995396, 64.10525444575718, 65.76650619506836, 64.08989892687116, 74.79332092830113, 77.7232859475272, 82.9812935420445, 79.75056879861015, 83.10530499049595, 78.26597499847412, 81.83067880358014, 73.26310525621686, 79.2982897077288, 78.37248393467495, 91.99444116864885, 80.5251887185233, 106.36691502162388, 2.1241162036146437, 6.097109402929034, 12.442703757967267, 0.7116274972047124, 0.7539176536457879, 0.19196094945073128, 0.2971434582556997, 0.42893911472388674, 0.6478665928755487, 1.188913426228932, 20.551364421844482, 63.17175006866455, 98.22543975285122, 87.8767649786813, 84.12944861820766, 79.10519232068742, 40.17826407296317, 34.757724217006135, 58.685103688921245, 79.55031476702008, 82.220778465271, 96.11201313563755, 48.367025307246614, 1.7186740509101321, 0.22536308424813406, 0.16027231913592133, 0.1344179907547576, 0.18976812783096517, 0.13018960479114736, 0.2742707755948816, 0.14814028942159244, 0.19639968127012253, 0.15875336421387537, 0.09244753287306853, 0.09235475677996874, 0.14781262486108712, 0.23716402958546365, 0.1888565296041114, 0.12452484161726066, 0.18217226756470545, 0.21553052828780242, 0.1375102512538433, 0.25461567885109354, 0.13819137827626296, 0.1446816607245377, 0.1298625102000577], [0.07812216585235936, 0.06107849933739219, 0.03172164782881737, 0.025674947470958744, 0.05523193966863411, 0.021215157317263738, 0.04334931567843471, 0.08138068778706448, 0.0561477957027299, 0.009369355726188846, 0.051987972310079, 0.044551174222890816, 0.0454894286979522, 0.039299340319952795, 0.0660394656338862, 0.05535741436428257, 0.19920481289071695, 0.4472561404109001, 15.484189101627894, 101.6295359475272, 90.95588697705949, 71.68179253169468, 50.1357934815543, 35.473975794655935, 34.07813480922154, 64.47259180886405, 92.02739647456578, 80.08536774771554, 86.00458676474435, 120.32919502258301, 91.26674243382045, 31.803103515080043, 1.7249765012945448, 0.021000007433550696, 0.061505263937371116, 0.06099986391408103, 0.07588960243655102, 0.04508752901373165, 0.27977977426988737, 1.060513430408069, 0.7937508619257382, 1.6654475927352905, 24.45402339526585, 95.68221146719796, 96.0507925578526, 92.69814777374268, 85.61438288007463, 87.87969711848667, 91.9136961528233, 93.94392504010881, 89.56863049098423, 91.79231807163784, 86.3342718396868, 83.84515612465995, 80.77061993735177, 83.45069994245256, 80.67793791634696, 80.47294521331787, 83.05734157562256, 79.52025685991559, 79.63557611192975, 71.45324543544224, 62.98459339141846, 63.16177940368652, 63.66401604243687, 62.42112227848598, 64.97773279462541, 71.86138262067522, 76.44753415243966, 75.01476001739502, 68.66614927564348, 61.37673160008022, 59.71575083051409, 61.2887396131243, 58.97951275961739, 60.94002342224121, 74.3391032900129, 78.62586389269147, 82.44175897325788, 81.98636708940778, 78.22470269884381, 72.85979012080601, 75.07074165344238, 77.23714828491211, 82.08359323229108, 71.09858158656529, 65.07429191044399, 76.19926112038749, 85.2288898740496, 57.00733607155936, 60.76574870518276, 78.90253421238491, 77.05315998622349, 82.56634712219238, 76.7203482219151, 70.90053013392857, 61.40639345986502, 59.89702238355364, 59.01562254769461, 60.84206077030727, 62.732359886169434, 64.17230456215995, 60.677548272269114, 60.536694390433176, 57.20859064374651, 63.33774948120117, 71.85366317204067, 77.6911644254412, 76.53370571136475, 74.68593651907784, 75.98967565808977, 76.75265734536308, 71.58253056662423, 68.69809709276471, 61.936026845659526, 57.46220684051514, 56.113651820591514, 56.328066280909944, 60.00754043034145, 69.71429198128837, 70.44264384678432, 71.08069692339215, 72.14129080091203, 72.02939701080322, 67.79490075792584, 70.61291640145438, 69.26905141557965, 77.51956476484025, 77.18837887900216, 82.62094606672014, 46.07668365750994, 0.21502159988241537, 0.31071869124259266, 0.36083148792386055, 0.04352237942761608, 0.19731053310845578, 0.11621521679418427, 0.12976292840072087, 0.05076043800051723, 0.05307775383282985, 0.08890357161206858, 6.0161628893443515, 36.16888945443289, 77.11746556418282, 69.6722275870187, 90.15286976950509, 70.71786199297223, 25.202351331710815, 17.145326205662318, 56.70213992255074, 61.46096461159842, 64.95087105887276, 63.833955083574565, 8.396996140480042, 0.3374045507184097, 0.22225304613155977, 0.029812501344297613, 0.09309509955346584, 0.052061189631266255, 0.056681755264954906, 0.035851547827145884, 0.03127367900950568, 0.02445350810220199, 0.03149349721414702, 0.026551850505971482, 0.07737071546060698, 0.02317848482302257, 0.041997829984341345, 0.06399406931762185, 0.05720352155289479, 0.06584625278732606, 0.026976240233385136, 0.017286266532859633, 0.03755871479266456, 0.031182694248855114, 0.04171246190422347, 0.015561581489496996, 0.03323224659210869, 0.03481521450781396, 0.04501522092946938, 0.033942157070019414, 0.042526785350803814, 0.1191138776817492, 0.048703567657087526, 0.0162902517643358, 0.026118183508515358, 0.0305970812083355, 0.07194771431386471, 0.04915600802217211, 0.010017924942076206, 0.07060141262731381, 0.16907232121697494, 0.20644722426576273, 0.5591730549931526, 19.974995715277537, 119.49856567382812, 97.13290500640869, 91.53035708836147, 71.46361214773995, 64.95970221928188, 50.421812602451865, 31.427674974714005, 51.6275508744376, 86.50250857216972, 91.40521308353969, 122.09545489719936, 101.56514004298619, 41.53047037124634, 1.4838529484612601, 0.10260375003729548, 0.031586517579853535, 0.14161096406834467, 0.18464360066822597, 0.17125554835157736, 0.36768762288349016, 2.281073187078748, 0.7082353106566838, 1.4071269226925713, 35.648875849587576, 102.94411427634103, 97.36976909637451, 95.98928015572685, 89.00668103354317, 92.47395024980817, 95.2894367490496, 97.02386692592076, 93.31478650229317, 96.10994257245744, 91.71575587136405, 87.06424263545445, 84.40103285653251, 86.16295705522809, 84.35747459956578, 84.8054666519165, 85.81087793622697, 80.96315452030727, 83.56579685211182, 73.30791418892997, 66.24076243809291, 65.02395915985107, 66.50555828639439, 63.482508250645225, 69.41280964442662, 76.4274469103132, 79.33335726601737, 76.35185745784214, 70.17852197374616, 63.6222573689052, 63.725625719342915, 62.32200622558594, 59.62315913609096, 62.53814383915493, 75.13802106039864, 80.95839500427246, 85.05955532618931, 84.39885112217495, 81.84365109034947, 78.40795448848179, 79.38042436327252, 79.25490515572685, 85.47279943738664, 74.20104953220913, 67.9721006665911, 78.56004360743931, 89.99523598807198, 59.216182300022666, 63.54854393005371, 82.2067014149257, 79.24499702453613, 84.75162506103516, 80.50895772661481, 74.84813526698521, 64.01743616376604, 62.563789640154155, 62.82716110774449, 63.30335589817592, 63.521133286612375, 66.15447970799038, 62.82028933933803, 64.03457736968994, 59.82180118560791, 65.21305438450405, 72.71485069819859, 80.01075104304722, 80.34744685036796, 79.21267400469098, 79.06999274662563, 82.41936492919922, 75.06585012163434, 72.29930673326764, 65.1691209248134, 61.18500995635986, 60.53671523502895, 60.483853340148926, 64.4943744114467, 73.22424398149762, 74.25928238459996, 74.19400405883789, 75.52313191550118, 75.61407688685826, 71.5239155633109, 73.06069728306362, 74.11074379512242, 81.20245047977993, 80.93711962018693, 85.43680776868547, 57.349854469299316, 0.4245869368314743, 0.332240817802293, 0.4507418562258993, 0.29832291496651514, 0.25487116085631506, 0.056300269306770394, 0.2484048306941986, 0.07378601495708738, 0.13572620627071175, 0.14139774122408458, 5.827211405549731, 43.358913149152485, 78.08801773616246, 76.05562795911516, 71.08859702519008, 53.225813729422434, 32.419280188424246, 29.66285685130528, 63.58443137577602, 72.12384387425014, 72.84239183153424, 81.06741224016461, 14.114811199051992, 0.4134429490992001, 0.12203961211655821, 0.17671909875103406, 0.11846749165228435, 0.0252870748019112, 0.01644480847088354, 0.04810669432793345, 0.11107280344835349, 0.016845045744308403, 0.030688724147954156, 0.019307427274595414, 0.061786883111510954, 0.006799764814786613, 0.04828552223209824, 0.05491810025913375, 0.09026608350021498, 0.023698807527710284, 0.06055139297885554, 0.01791157217563263, 0.07276263487126146, 0.08556730313492672, 0.031229862610676458, 0.19157237958695206, 0.13811722796942505, 0.1083541511158858, 0.14643342101148196, 0.11932359928531305, 0.14606062030153616, 0.2421228177845478, 0.16835181202207292, 0.22870766477925436, 0.13262004937444413, 0.2090351161147867, 0.1959728691726923, 0.24969122452395304, 0.1050908455092992, 0.20391430732394966, 0.2256990133651665, 0.3640932871827057, 0.69670819491148, 28.148283311298915, 135.1205896650042, 111.12880039215088, 97.87139429364885, 71.75091321127755, 55.46933841705322, 45.97043527875628, 90.48923901149205, 121.411376953125, 108.07221140180314, 101.04433781760079, 136.82152257646834, 112.7446595600673, 57.781716278621126, 3.427143369402204, 0.19589225921247685, 0.38994802268488066, 0.4315987548657826, 0.4474894478917122, 0.6743272872907775, 1.6111450323036738, 3.194320091179439, 4.269845647471292, 4.378631421497889, 37.308696269989014, 110.45164285387311, 101.40647097996303, 103.17450959341866, 93.59224891662598, 96.3715353012085, 100.15694168635777, 103.54296561649868, 96.81683145250592, 101.17767374856132, 96.91801806858608, 94.80512646266392, 88.05570193699428, 92.17831829616001, 88.67530754634312, 89.58343710218156, 90.26834883008684, 87.91951724461147, 86.81627532414028, 79.0646287373134, 70.04601287841797, 68.38897173745292, 68.65310750688825, 67.15074021475655, 73.33756910051618, 78.2655997957502, 84.59913294655937, 81.62189933231899, 75.1264453615461, 68.01241411481584, 67.1954379762922, 66.78873211996896, 62.76926176888602, 66.3888771874564, 80.12331186022077, 85.02826063973563, 89.48235470908028, 88.94255610874721, 85.07773876190186, 80.40114947727749, 80.78739288875035, 84.15435791015625, 87.04955414363316, 78.16101551055908, 70.59736633300781, 84.08319446018764, 91.79596587589809, 64.85534722464425, 67.93838800702775, 82.91241604941231, 83.73021902356828, 88.36306939806256, 85.01541342054094, 78.59937735966274, 67.33415876116071, 65.8522539138794, 66.4149329321725, 67.29448454720634, 68.26566900525773, 71.98116261618478, 67.83212920597622, 68.36206831250871, 64.02817807878766, 70.10312012263707, 78.60112830570766, 86.04118987492153, 84.37665162767682, 82.19282586233956, 81.61128248487199, 86.31909002576555, 79.89957986559186, 76.87739835466657, 69.9661294392177, 64.87190478188651, 63.974183627537315, 64.02186911446708, 68.6294002532959, 78.14399242401123, 79.36160169328961, 77.96083790915353, 80.77908979143415, 80.14897850581578, 76.87689808436802, 77.38002409253801, 78.65608855656215, 88.95218631199428, 85.550779070173, 91.64154216221401, 61.38665362766811, 0.48253138469798224, 3.8371418033327376, 1.3050627708435059, 0.2947048848228795, 0.7149754432695252, 0.32482212302940233, 0.8231311025364059, 0.25063199975660866, 0.28845476305910517, 0.26682830495493753, 11.26565112386431, 56.007903712136404, 89.53733580453056, 87.10673781803676, 113.08301598685128, 92.78683458055768, 33.56118883405413, 27.940426213400706, 73.78807640075684, 84.56472546713692, 83.98179939814976, 97.65559019361223, 23.508185965674265, 0.6083710236208779, 0.32666673404829843, 0.2409210508423192, 0.2606496193579265, 0.15234781721872942, 0.12766835865165505, 0.14542419516614505, 0.22478172901485646, 0.09062792586960963, 0.1388365158012935, 0.10235124680080585, 0.12244856517229762, 0.08703424156244312, 0.12852920245911392, 0.10595296496259314, 0.16337116142468794, 0.09384267551026174, 0.12898554440055574, 0.13215812987514905, 0.09820617136678525, 0.09682272667331354, 0.155153681657144], [0.05877063889056444, 0.03873428010514804, 0.03979713735835893, 0.04061615287459322, 0.027984853700867722, 0.04413576490644898, 0.01185423493318792, 0.06531844075237002, 0.017143567225762775, 0.04685818310827017, 0.026803714223206043, 0.12440938209848744, 0.015138229920661874, 0.050191791728138924, 0.039698559790849686, 0.05795126035809517, 0.04455870256892272, 0.20886203540222986, 44.12356587818691, 98.07823521750313, 82.70069054194859, 60.35078144073486, 47.15803527832031, 30.61109835760934, 37.849311283656526, 71.42042909349713, 82.3867083958217, 95.4558322089059, 109.01294885362897, 86.05935941423688, 34.52425084795271, 1.8681026612009322, 0.12375447366918836, 0.07787610869854689, 0.09323339177561657, 0.06771219694720847, 0.043379876895674636, 0.19179738179913589, 0.34593984271798817, 0.4028553600822176, 3.1812381531511034, 18.041812317711965, 89.51675524030412, 86.2467314856393, 94.97760159628731, 87.87265164511544, 83.88814462934221, 80.19407926286969, 87.84826346806118, 86.04276016780308, 92.65249116080147, 83.64563165392194, 82.85790048326764, 76.93144144330705, 77.14215251377651, 68.95329053061349, 69.62914875575474, 69.57910088130406, 71.32244559696743, 75.25181865692139, 76.45207132611955, 64.54215717315674, 62.1144357408796, 61.38432598114014, 62.73001834324428, 60.39888381958008, 65.72402490888322, 66.6101564679827, 69.01119681767055, 66.1568351473127, 61.32364041464669, 59.1231598172869, 60.93424252101353, 57.23287807192121, 58.14233820778983, 55.619673115866526, 61.92081723894392, 69.2153765814645, 76.91381386348179, 78.6269200188773, 80.71067782810756, 80.20158331734794, 80.47081211635044, 74.61558600834438, 83.31873975481305, 70.23663670676095, 68.4041188103812, 70.19088976723808, 79.93324388776506, 47.9569148336138, 58.307281494140625, 81.44670745304653, 74.65049375806535, 81.48373440333775, 76.31611592429024, 72.30291979653495, 64.68477589743478, 60.43477821350098, 57.47028759547642, 56.74901247024536, 57.03474671500069, 57.536535194941926, 58.488490513392854, 59.562612533569336, 57.92358112335205, 56.71735300336565, 61.33591788155692, 70.06126417432512, 73.06929220472063, 75.66778646196637, 75.24102810450962, 76.97327654702323, 72.52017607007707, 68.09058134896415, 62.97062751225063, 59.37501117161342, 57.00867012568882, 56.47254712241036, 54.85169219970703, 60.65147863115583, 64.36046872820172, 68.59979397909981, 68.91843141828264, 72.86381312779018, 69.70323739733014, 68.34062617165702, 69.67873110089982, 72.60719530923026, 75.49340057373047, 77.26740074157715, 70.8633850642613, 12.868181041308812, 0.25380558946302956, 0.7904232176286834, 0.4760507238762719, 0.19603518582880497, 0.062484586744436195, 0.032153637148439884, 0.32793749443122316, 0.013831740428161408, 0.08814066076385123, 0.07282473439616816, 4.8123644675527295, 38.154031481061665, 64.26988506317139, 77.74583980015346, 66.33595970698765, 41.763096060071675, 22.919319186891826, 29.576164177485875, 51.40738330568586, 56.29379429136004, 68.29255853380475, 58.51421969277518, 3.973840228148869, 0.22533797845244408, 0.05250521616211959, 0.06772622905139412, 0.028944176688258137, 0.02901134147707905, 0.08986200232590948, 0.0158381235253598, 0.04371567369837846, 0.01539510122633406, 0.05204437214082905, 0.03030026963512812, 0.08921043907425233, 0.028913218528032303, 0.049971325522554774, 0.04004723858088255, 0.07238102677677359, 0.023760727240837047, 0.05191994917445949, 0.01656194227481527, 0.0618234086515648, 0.04803396894463471, 0.040989703365734646, 0.035557894834450314, 0.02107975904696754, 0.02983301685058645, 0.024582582426124384, 0.059677385592034886, 0.008439877253424908, 0.03497647174767085, 0.03419858902426703, 0.04993614008916276, 0.040856839423733096, 0.035152968884046586, 0.06256208901426621, 0.07371109790567841, 0.05985123983451298, 0.03886371744530542, 0.0805724575849516, 0.25391323225838797, 54.66321536472866, 113.2796083177839, 92.67922782897949, 69.39950384412492, 50.67139884403774, 35.28416837964739, 34.969918727874756, 49.61196878978184, 90.96148027692522, 102.03192697252545, 118.35396112714494, 96.60404287065778, 40.714581625802175, 1.659726728286062, 0.0921226842328906, 0.06659982699368681, 0.07195105270615645, 0.08943200789924179, 0.050916205892073255, 0.2011831903031894, 0.6534749290772847, 0.4592423258083207, 1.1880098347152983, 28.01589928354536, 101.89121900285993, 92.60767527988979, 100.14470590863908, 91.78394549233573, 85.19503825051444, 82.86855207170758, 91.34674399239677, 89.26333359309605, 95.59466416495187, 84.35480649130685, 84.53121430533272, 79.19318430764335, 79.48319516863141, 71.41055570329938, 73.10654149736676, 72.92472798483712, 75.94979299817766, 77.74340793064663, 78.44189643859863, 67.87040683201381, 64.07040228162492, 64.77758298601422, 65.3359819139753, 63.579150744846885, 68.21749714442662, 68.80129173823765, 74.08894034794399, 68.6694427217756, 63.31227738516671, 62.716399874006, 64.76130335671562, 60.462911469595774, 61.00983197348458, 59.442248889378135, 63.30079896109444, 71.61356816973004, 77.6957015991211, 79.01940986088344, 83.11459473201207, 81.99344035557338, 83.51988315582275, 76.05059746333531, 82.60428428649902, 72.79222583770752, 71.05647550310407, 73.7791062763759, 82.8498614174979, 51.881344250270296, 62.110607283455984, 83.28817462921143, 76.81195327213833, 83.82035800388881, 78.9318208694458, 76.09531606946672, 67.70598466055733, 62.1719251360212, 60.54268373761858, 61.390044348580496, 59.05357360839844, 62.153922353472026, 61.398291860307964, 62.35407216208321, 60.07604966844831, 60.80635397774832, 63.25858170645577, 73.10342870439801, 75.99518557957241, 79.26912811824253, 78.42748587472099, 79.06047371455601, 75.07831518990653, 70.83284078325543, 66.52282455989292, 63.64320618765694, 60.94490105765206, 60.49826390402657, 57.06475945881435, 63.26052025386265, 67.38998753683907, 72.01761286599296, 71.88306100027901, 75.51099341256278, 72.62590680803571, 72.70800672258649, 72.5957863671439, 74.58245004926408, 81.06545284816197, 82.58765724727085, 80.61100591932023, 21.454289776938303, 0.6918838109288896, 0.7414174101182393, 0.6466880589723587, 0.3031280556959765, 0.1584263239055872, 0.12896540548120225, 0.41735424207789557, 0.020017203741839955, 0.04492107419563191, 0.0738121046285544, 4.500990067209516, 42.79103340421404, 67.15734795161656, 84.78822122301374, 58.08154494421822, 33.47827598026821, 28.69021848269871, 47.41032089505877, 63.103358949933735, 66.57713862827846, 79.26404898507255, 78.43567780085972, 6.026984708649771, 0.30913830175995827, 0.12039998652679579, 0.09015643902655159, 0.01587581614564572, 0.014251120022631117, 0.08653751321669136, 0.06309256769184556, 0.08950149667050157, 0.030545651646597043, 0.04978321525933487, 0.010581923249576772, 0.07028901510472808, 0.03043583414650389, 0.05021001717873982, 0.036613172851502895, 0.04082122651327934, 0.02002665234197463, 0.049906274370316944, 0.03772464035344975, 0.0489416452390807, 0.010753400923152055, 0.13346992805600166, 0.09939700710986342, 0.1266229668898242, 0.1405043548771313, 0.05240698125479477, 0.13294274705861295, 0.149430727320058, 0.1428768661405359, 0.10302960540034942, 0.14660859161189624, 0.1550555383520467, 0.21734991137470516, 0.15155345627239772, 0.20602725180132048, 0.23596511249031338, 0.0997292110696435, 0.17127884924411774, 0.2740649352116244, 69.91166945866176, 123.80412810189384, 107.03097520555768, 81.4304278237479, 65.85082953316825, 41.52787174497332, 54.99383497238159, 98.80395371573312, 109.23184490203857, 113.67933818272182, 124.69508171081543, 105.35536847795758, 53.29942641939436, 4.111262568405696, 0.45457731613091057, 0.20330097952059337, 0.28992427991969244, 0.3768218984561307, 0.2608872151800564, 0.6565465756825039, 1.8426190572125571, 3.494966038635799, 6.694522900240762, 26.264736107417516, 104.82450526101249, 95.18761089869908, 105.01298904418945, 96.85453932625907, 91.28462709699357, 87.92654882158551, 95.58315099988664, 92.97506128038678, 101.32874148232597, 91.36641434260777, 89.3735111781529, 85.06055586678642, 84.94367327008928, 78.71263299669538, 77.33927290780204, 78.16600431714738, 80.03484044756208, 83.50092152186802, 83.13334097181047, 71.5175301688058, 67.53127915518624, 69.08296476091657, 69.11624663216728, 67.36469609396798, 71.94408702850342, 72.21490696498326, 78.25819301605225, 73.35214642116001, 67.14990643092564, 66.37915665762765, 66.97181715284074, 62.44742121015276, 63.3749223436628, 62.39355182647705, 66.70048999786377, 75.73597608293805, 84.64931283678327, 85.52689116341728, 86.06648131779262, 86.50590624128068, 86.62749276842389, 79.14962605067662, 89.20992973872593, 76.35046781812395, 73.94560595921108, 78.10460308619908, 84.13487516130719, 57.76546791621617, 66.97424902234758, 86.70240824563163, 82.29174736567906, 86.88787651062012, 82.64609854561942, 78.00694615500313, 70.21700109754289, 64.23292064666748, 64.11571148463658, 64.2362835747855, 62.720457621983115, 63.48186901637486, 64.57573781694684, 65.02680097307477, 63.598369462149485, 63.20435101645333, 68.44942106519426, 78.42065579550606, 80.97716903686523, 83.51310171399797, 82.64657797132219, 84.19234371185303, 79.18825108664376, 75.98618766239711, 71.1845030103411, 67.36819103785923, 65.39816134316581, 63.41718128749302, 62.709951945713584, 68.37785461970738, 72.37133175986153, 76.73630128587995, 75.86923558371407, 79.60165500640869, 76.58783217838833, 75.61907958984375, 76.12472084590367, 79.06920065198625, 84.71608502524239, 87.23507799421037, 87.13041033063615, 25.58049488067627, 1.2637343427964618, 3.164246116365705, 1.3678897938558032, 0.6073039323091507, 0.4888020253607205, 0.3181536708559309, 0.9054667672940663, 0.10414126289210149, 0.21120857234512055, 0.2312970629760197, 8.892744030271258, 55.17869874409267, 77.56978634425572, 94.28991753714425, 87.3926214490618, 56.55035652433123, 33.584434032440186, 47.2056200163705, 71.25849437713623, 78.42349066053117, 89.87546988895961, 94.92642116546631, 9.007752350398473, 0.41766045136111124, 0.21493845220123017, 0.22285335963325842, 0.09208617904888731, 0.1844587405877454, 0.20276606322399207, 0.09154932892748288, 0.18312235229781695, 0.12254429289272853, 0.11596337173666273, 0.10646883478122098, 0.12721922275211128, 0.10395619925111532, 0.15233359512473854, 0.17298194499952452, 0.1614254079759121, 0.051197326342974386, 0.11840004527143069, 0.13694600867373602, 0.10806353456739869, 0.13248981136296475], [0.0301684472443802, 0.012142982965867435, 0.01817988358171923, 0.02741522355271237, 0.04820608274478998, 0.02140792572338666, 0.02315066149458289, 0.012881000060588121, 0.01305755741694676, 0.05117248517594167, 0.06007141087736402, 0.058253228797444274, 0.025317230594477484, 0.03037856239825487, 0.040188149948205264, 0.0323525836159076, 0.0799743425367134, 2.514923930168152, 79.71124199458531, 92.73366696493966, 81.90071664537702, 67.83354663848877, 59.98076902117048, 87.37895434243339, 96.28246634347099, 90.4907398223877, 88.6936229978289, 102.03294835771833, 94.51495579310826, 55.691104071480886, 2.600371790783746, 0.14713703468441963, 0.023932885145768523, 0.1313530887876238, 0.045469958135592084, 0.07468862259494406, 0.16123871585088118, 0.06506454651909215, 0.07055270738367524, 3.274577647447586, 18.365068571908132, 109.22488280705043, 96.33711392538888, 98.83476202828544, 89.01887512207031, 84.87757505689348, 70.98636817932129, 72.7939350945609, 74.38823400224958, 79.29389149802071, 78.28016321999687, 75.82498250688825, 68.99330520629883, 68.87623500823975, 63.166504178728374, 63.68437426430838, 59.786664145333425, 61.83579213278634, 67.85444681985038, 65.7148254939488, 63.16995743342808, 61.560143198285786, 61.42699486868722, 61.81806032998221, 62.876125063214985, 60.161741801670615, 62.39405904497419, 64.06799125671387, 65.22592939649309, 60.66097681862967, 56.934247970581055, 57.396706172398154, 56.33586910792759, 59.861447606767925, 63.725007329668315, 65.54007135118756, 64.01014750344413, 67.54940005711147, 71.50078501020158, 76.87771102360317, 76.0297737121582, 71.69313199179513, 69.2656329018729, 80.40388011932373, 78.3269384929112, 64.67666040148053, 65.40321963174003, 73.63068580627441, 78.84869262150356, 46.77840307780674, 59.279278891427175, 77.56406797681535, 68.98443235669816, 79.42941611153739, 74.96712316785539, 76.87024865831647, 67.13384914398193, 62.66335732596261, 57.594528334481375, 57.757338523864746, 55.42486994607108, 58.376652308872764, 55.955545561654226, 58.506944928850444, 55.95788363048008, 56.49339519228254, 54.004116194588796, 58.0025543485369, 63.70048018864223, 66.23919214521135, 65.71657643999372, 67.65306023189, 65.3198412486485, 66.33951718466622, 60.459694453648154, 60.374405315944124, 56.65395416532244, 58.3896176474435, 51.87797784805298, 56.376175607953755, 58.52059119088309, 65.99852739061627, 66.99088300977434, 72.80776895795549, 69.85702187674386, 71.1512975692749, 68.75261265890938, 72.36200032915387, 71.99325942993164, 77.09627355848039, 74.72490896497453, 47.73069538388933, 2.63926129255976, 0.9582271533352988, 0.40698218292423655, 0.11972189934125968, 0.26584163361362045, 0.17261259124747344, 0.03309421221326504, 0.10064876172691584, 0.03489152934136135, 0.1268334620233093, 0.5176876410841942, 9.54382758481162, 36.7671606200082, 57.310312271118164, 82.62978417532784, 70.69417558397565, 31.54881681714739, 15.386302879878453, 40.55474526541573, 61.40775530678885, 65.97147110530308, 66.70488125937325, 38.15825251170567, 1.3543201791388648, 0.09063217349882637, 0.037333953460412364, 0.08966681494244508, 0.04498464614152908, 0.020519036367269497, 0.05212112802213856, 0.017878210305103233, 0.06878473689513546, 0.01750113652087748, 0.11169244841273342, 0.015130528548200215, 0.03317579926390733, 0.05106687120028904, 0.05341374062533889, 0.05370418414739626, 0.042204698348151784, 0.10520574862935714, 0.017710691883361766, 0.027528962985213314, 0.06998506534312453, 0.05768021954489606, 0.017428714781999588, 0.02204054088464805, 0.046084483553256304, 0.06612070663166897, 0.04438788477065308, 0.0442655279434153, 0.05430265881919435, 0.016519096181062714, 0.07548262391771589, 0.053526214590030055, 0.038229785926107845, 0.03763041558808514, 0.1054468456921833, 0.09689332824200392, 0.026758701906406453, 0.23397448073540414, 3.5462734912123, 93.252211025783, 102.19486917768205, 91.9947121483939, 75.11872591291154, 64.48718302590507, 79.81652109963554, 59.78573308672224, 84.08372252328056, 99.07029206412179, 108.46235275268555, 104.17523084368024, 60.91897732870919, 3.915206117289407, 0.42411429647888454, 0.01458036556972989, 0.17987229169479438, 0.08424239565751382, 0.22929516753980092, 0.09640493230628115, 0.10055036736386162, 0.40935729976211277, 1.380543114883559, 26.37088894844055, 115.05333750588554, 98.16916629246303, 101.11516775403703, 94.51221820286342, 88.68762670244489, 73.85876042502267, 75.01544788905552, 77.42631993974958, 83.11182240077427, 81.80925055912563, 79.54030936104911, 72.94629519326347, 71.59417574746269, 67.53074414389474, 66.18291868482316, 63.26888588496617, 64.14328193664551, 70.93723051888603, 69.8672843660627, 65.56836441584996, 66.97524956294468, 63.891083172389436, 64.665543283735, 67.29690252031598, 63.84392574855259, 64.53916944776262, 68.04789161682129, 67.78628499167306, 64.4250522341047, 59.8410199029105, 59.27784756251744, 59.13153239658901, 62.77874605996268, 66.82140949794224, 68.03654520852226, 69.06904751913888, 71.80694348471505, 75.42261232648576, 80.0513563156128, 78.67556435721261, 72.29331043788365, 70.94512367248535, 81.2101560320173, 80.2018404006958, 66.0593797138759, 67.38941083635602, 78.91977964128766, 81.98727035522461, 49.9468754359654, 61.457247325352256, 79.19979899270194, 72.38170542035783, 84.03837163107735, 78.19457530975342, 80.21338135855538, 70.27021040235246, 67.49015971592495, 61.250156266348704, 61.34799385070801, 59.03759275163923, 60.555961745125906, 59.33707400730678, 60.09185682024275, 59.17074802943638, 59.47155639103481, 57.23547669819423, 60.80255331311907, 65.64788654872349, 68.7748052052089, 67.99758665902274, 69.96314866202218, 68.1720072882516, 67.71667098999023, 63.2987631389073, 63.147681508745464, 59.456277302333284, 61.800870486668174, 55.36510501589094, 59.75574466160366, 62.00555052076067, 70.21180384499687, 70.84913430895124, 75.37156391143799, 72.8939266204834, 74.66413307189941, 71.18982533046177, 76.45517022269112, 73.3423911503383, 80.51099354880196, 79.77428994859967, 61.41819150107247, 3.4569515756198337, 0.4916107803583145, 0.4376935192516872, 0.2308452943606036, 0.2757481906030859, 0.08389829697885684, 0.18316016026905604, 0.06159567194325583, 0.06957395454602582, 0.11027791324470725, 0.7056136141930307, 8.865477561950684, 40.50577783584595, 57.91917943954468, 67.0075239453997, 50.102310112544465, 35.25173418862479, 27.19513463973999, 52.76549209867205, 72.33932835715157, 75.77656745910645, 76.82029805864606, 51.648940903799875, 2.0967090342726027, 0.08923749905079603, 0.033850622696003745, 0.16845565502132687, 0.06905115688485758, 0.0828406373038888, 0.044019389365400584, 0.04064621197591935, 0.0229773059753435, 0.0029354222185377565, 0.026858024166098664, 0.051007411176604886, 0.04928314173594117, 0.00805010977533779, 0.12105954970632281, 0.08211636902498347, 0.05980978813022375, 0.038382687007210085, 0.023978815181180835, 0.03764189640060067, 0.026283383036830595, 0.08662230973797184, 0.1754237211176327, 0.09038828087172338, 0.12871318044407026, 0.08339932268219334, 0.1363603922405413, 0.13559872311140808, 0.13983667641878128, 0.13771234612379754, 0.18174719251692295, 0.17449545807072095, 0.20081007746713503, 0.148591528779694, 0.1736231470214469, 0.26809119433164597, 0.2149445183042969, 0.5695012807846069, 7.049951485225132, 112.09560748508999, 111.432297706604, 105.724581854684, 90.77351760864258, 78.57218905857631, 97.19231905255998, 121.9201101575579, 117.85730389186314, 107.58369745526994, 118.75559479849679, 112.83534744807652, 76.95218876429966, 5.459978265421731, 0.4115270919033459, 0.12954030106110231, 0.3875912534339087, 0.2739097135407584, 0.3988080344029835, 0.394050662538835, 0.281597406736442, 1.8137601486274173, 7.805325763566153, 23.279244559151785, 119.11659540448869, 104.17227785927909, 107.58218274797711, 101.56775256565639, 95.24674006870815, 79.50328241075788, 79.90866116115025, 84.40732792445591, 87.89584473201207, 85.7343852179391, 81.60304192134312, 76.35424068995884, 78.23959963662284, 72.2189438683646, 71.48729855673653, 68.51300403050014, 68.69400460379464, 76.44303866795131, 73.50190094539097, 69.30777372632707, 70.53964069911412, 68.26721845354352, 67.88299001966203, 68.73186533791679, 65.95671313149589, 67.2180404663086, 71.33825969696045, 72.27949741908482, 67.97345556531633, 64.30524444580078, 63.79324558803013, 62.60435322352818, 67.1995096206665, 69.4557078225272, 71.0051908493042, 71.28880241939, 75.0130924497332, 79.82018974849156, 84.36803586142403, 78.5866482598441, 76.7918312890189, 76.76781831468854, 82.59572410583496, 84.60997213636125, 69.95563765934536, 70.82866491590227, 81.17842360905239, 87.94714328220913, 55.92722817829677, 68.06272602081299, 81.17240646907261, 76.31408010210309, 86.6932783126831, 80.13846588134766, 83.82080963679722, 74.24228709084647, 69.68859754289899, 64.74744864872524, 64.1867846080235, 63.506007058279856, 63.590066364833284, 63.34442670004708, 64.01082842690604, 62.43000207628523, 61.20969690595354, 61.98732539585659, 64.89060238429478, 73.26409190041679, 74.77932725633893, 73.05962031228202, 76.84907749720982, 73.43838051387242, 74.11942209516252, 68.26423072814941, 68.2593183517456, 63.977761949811665, 65.31733989715576, 60.17479746682303, 63.72384698050362, 65.84781401497978, 73.85188865661621, 76.06270122528076, 79.53203405652727, 76.62907668522426, 79.21587017604283, 75.7643803187779, 81.58475426265171, 79.37138475690568, 83.95363140106201, 85.77347578321184, 71.19022832598004, 2.96137587087495, 1.9678197332790919, 2.8931096025875638, 0.4247486724385193, 0.7626760751008987, 0.37663272289293154, 0.3370403674032007, 0.17428212666085788, 0.22543423543018953, 0.29950904846191406, 0.8612457716039249, 15.863055263246808, 55.64517647879464, 72.40566280909947, 99.59183774675641, 94.66322340284074, 46.920427731105256, 22.602523020335607, 60.50287750789097, 83.38046060289655, 89.54219954354423, 89.3586003439767, 67.1832160949707, 3.1793953606060574, 0.13353874507759297, 0.10991094793592181, 0.1800399576979024, 0.2907032924039023, 0.14514474730406488, 0.23288779333233833, 0.10289674145834786, 0.1499550991824695, 0.10421623422631196, 0.12514149424220833, 0.09027166105806828, 0.11579297802277974, 0.13226527055459364, 0.3146134008254324, 0.21900983873222554, 0.18792989504124435, 0.11838328545647007, 0.06031981576234102, 0.145700141787529, 0.11555981981967177], [0.09422032774559089, 0.014533210778608918, 0.008176110335625708, 0.02512576158291527, 0.0032987732681379256, 0.06931525628481593, 0.021537042455747724, 0.04398064162316067, 0.038612170943192074, 0.02932618511840701, 0.032199319518570385, 0.04383867513388395, 0.018395703518763185, 0.05458432888346059, 0.049233323694872, 0.16629624446587904, 0.49076217732259203, 17.30650704247611, 90.1370348249163, 84.95550605228969, 66.00901222229004, 51.291629791259766, 31.559888771602086, 28.46521496772766, 77.54384871891567, 71.30107988630022, 108.1022206715175, 94.81130341121128, 69.24087647029332, 5.004180780478886, 0.4016725378377097, 0.014977349267740334, 0.09474794300539152, 0.20813323450939997, 0.0734679652377963, 0.07139256410300732, 0.10724298216934715, 0.22360334438937052, 0.9584562267575945, 9.22134518623352, 111.9992846080235, 89.54092107500348, 91.97848115648542, 87.52679116385323, 87.60618128095354, 71.93317140851701, 68.69037764413017, 68.41784150259835, 63.91918863568987, 66.20654950823102, 67.33065686907086, 63.00887734549386, 62.14101954868862, 59.78979083469936, 60.87514114379883, 59.246900285993306, 61.25080244881766, 60.29884365626744, 60.69620418548584, 60.38764163425991, 62.22489125388009, 60.03333909170968, 61.41996329171317, 59.31016363416399, 61.66872269766671, 61.133836473737446, 61.55673163277762, 63.412706647600444, 61.209981782095774, 57.500665119716096, 55.11410828999111, 57.48020267486572, 63.74633135114397, 64.76961340223039, 73.42829867771694, 75.39586176191057, 76.7128997530256, 75.34561933789934, 76.99694211142403, 76.62509536743164, 77.4210045678275, 69.34603745596749, 67.40601008278983, 77.49982493264335, 73.0964527130127, 62.47683988298689, 70.72172519138881, 76.7806099482945, 72.82055364336286, 45.62314346858433, 51.65400961467198, 75.07532051631382, 67.47926494053432, 75.12812682560512, 72.90680858067104, 75.20334107535226, 68.90775203704834, 70.37342589242118, 67.19264480045864, 66.3051097052438, 64.78841522761753, 63.11351721627371, 57.57119975771223, 57.11192730494908, 54.761261395045686, 56.65370403017317, 53.86429412024361, 54.57193340573992, 52.53051444462368, 56.33812379837036, 54.68241671153477, 56.501913683755056, 55.83130482264927, 58.495758329119, 56.255402020045686, 55.10877554757254, 58.08334800175258, 57.02386236190796, 54.844337531498496, 53.555373736790244, 52.414462157658164, 63.124418939862935, 66.25465188707624, 70.4086115700858, 73.4605244227818, 70.95639365059989, 66.06682818276542, 69.25306361062187, 69.11972767966134, 79.94707775115967, 69.88409205845424, 71.60507052285331, 18.551933424813406, 0.24836053592818125, 0.13669252156146935, 0.05632847261482051, 0.053516765989895375, 0.01848350086116365, 0.06973357990916286, 0.13316726072558335, 0.08086943200656346, 0.032034900305526595, 0.10061953043831245, 0.512776078922408, 15.216271775109426, 30.261701243264334, 73.80407115391323, 74.4447853905814, 47.08023977279663, 24.050485917500087, 25.997174876076834, 46.16685390472412, 52.76961932863508, 60.71513107844761, 54.10516037259783, 13.245593292372567, 0.10156470257788897, 0.09292541151600224, 0.04858167562633753, 0.07319554021315915, 0.020635377981566956, 0.05855740926095417, 0.06720470703606095, 0.06638864653983287, 0.048593336250633, 0.06073839044464486, 0.04860706640673535, 0.0370563105014818, 0.013536981423385441, 0.09143598643796784, 0.03118325743292059, 0.11374865379184484, 0.0460993977529662, 0.030251143699777976, 0.04046490741893649, 0.01931003963441721, 0.04854111958827291, 0.032948988755898814, 0.01793232516917799, 0.08361998227025781, 0.07567502252225365, 0.06454749604953186, 0.028600271392081465, 0.005940334904672844, 0.09255914509828601, 0.06926938731755529, 0.04138829179906419, 0.05393532370882375, 0.05442386892225061, 0.03899806398632271, 0.03467850327225668, 0.09538058870072876, 0.4369418110166277, 24.16357479776655, 105.51355116707938, 90.78059782300676, 80.55559403555733, 59.61120823451451, 47.17375905173165, 31.574007511138916, 55.81504603794643, 79.6422255379813, 115.25576632363456, 105.0852781023298, 78.52360030582973, 6.665208884647914, 0.6490995724286351, 0.04674989909731916, 0.21002181459750446, 0.10003678420824663, 0.09674465443406786, 0.13540934398770332, 0.1729692021118743, 0.18191190010734967, 1.14470551269395, 13.856927939823695, 117.90765053885323, 92.6387198311942, 97.40471853528703, 92.88971655709403, 90.8789565222604, 73.71346664428711, 74.18706280844552, 69.9264691216605, 69.08343723842076, 69.55786718641008, 70.32186331067766, 65.61092908041817, 65.60924066816057, 63.12631579807827, 64.3801668712071, 62.43105820247105, 63.9892612184797, 62.842732020786826, 65.46412059238979, 62.90217385973249, 65.12336703709194, 61.84997340611049, 63.31424372536795, 64.21329198564801, 66.56247098105294, 64.03787776402065, 64.5676987511771, 65.21975939614433, 65.07721710205078, 60.96120153154646, 59.0294703074864, 60.93648678915841, 65.64690685272217, 69.93444565364292, 78.12084102630615, 78.39188330514091, 80.7646097455706, 80.1881663458688, 80.58907045636857, 79.16449519566127, 79.74910967690604, 73.74471269335065, 71.21146896907261, 79.78973579406738, 74.32574885232108, 64.45461681910923, 75.33386298588344, 78.26170880453927, 77.04274463653564, 50.858941146305625, 53.84253236225673, 78.62213965824672, 70.86026532309396, 77.2519201551165, 75.10627474103654, 79.5665249143328, 73.66100079672677, 74.98834296635219, 71.2660470690046, 71.77275139944894, 69.55010604858398, 68.06865283421108, 60.91304356711251, 60.20592539651053, 58.7533141544887, 59.040107999529155, 58.36421503339495, 56.90682690484183, 55.61357259750366, 56.736144406454905, 57.8152482850211, 59.51646259852818, 59.787178312029155, 61.27291856493269, 59.54062843322754, 57.15935223443167, 62.108891078404014, 58.66355037689209, 57.661217144557405, 57.25915615899222, 56.80383028302874, 64.41925048828125, 69.7462467466082, 73.1630025591169, 74.52695478711809, 74.7004999433245, 70.3176804951259, 71.63178634643555, 73.37345654623849, 81.51014450618199, 77.19283267429897, 81.73960876464844, 24.958856923239573, 0.34710730292967384, 0.21469617448747158, 0.16163355537823268, 0.06398688363177435, 0.33499143591948916, 0.12577559878783567, 0.17114814982882567, 0.06923527736216784, 0.08500264664845807, 0.13014077741120542, 0.7784019112586975, 15.778580801827566, 36.88091652733939, 74.01943751743862, 59.307287079947336, 39.621407645089285, 32.5840289252145, 38.13543462753296, 56.521146297454834, 62.51597213745117, 70.74510587964738, 67.57808916909354, 18.597037655966624, 0.06510766063417707, 0.06481554452329874, 0.020839284540020993, 0.061999203504196236, 0.11419983208179474, 0.02882681048608252, 0.028810905625245402, 0.08033868191497666, 0.042927317786961794, 0.044986647819834094, 0.02220166241750121, 0.03872298588976264, 0.025260243830936294, 0.04206025181338191, 0.09954604054135935, 0.05137761649010437, 0.01655980828218162, 0.06199400592595339, 0.05454058373080833, 0.014266142787943994, 0.09278121603918926, 0.11142505133258444, 0.09551375119813851, 0.23152149521878787, 0.1030212254928691, 0.1493162177503109, 0.08334415099982705, 0.1571457926183939, 0.212980715824025, 0.1843715759792498, 0.10850173248244183, 0.11811582052281924, 0.1443053044910942, 0.12559365640793527, 0.15787204221955367, 0.28798415831157137, 0.5102389007806778, 35.74132858003889, 120.7593857901437, 104.27642440795898, 93.1762672151838, 73.06498432159424, 49.19362817491804, 38.372243131910054, 106.51468930925641, 85.08798040662492, 131.38042994907923, 112.80410139901298, 94.55123928615025, 8.876191684177943, 0.7663044461182186, 0.3605605624616146, 0.2595726485763277, 0.2916843183338642, 0.17928382541452134, 0.5206521334392684, 0.361249248364142, 0.7141506703836578, 1.922256921018873, 11.906239424433027, 123.21857561383928, 96.02293722970145, 100.43950407845634, 98.65173952920097, 96.3336398260934, 77.03986808231899, 77.7526490347726, 75.39726529802594, 73.28288677760533, 72.69958550589425, 75.79477868761334, 69.38096605028424, 68.89975466047014, 66.1581483568464, 69.70224380493164, 66.5023273740496, 68.9094682421003, 65.83166640145438, 69.13781384059361, 66.80603313446045, 69.48741940089634, 64.99072592599052, 66.32210499899728, 66.36391230991909, 68.30060454777309, 66.78235367366246, 67.25262859889439, 68.56592845916748, 69.1759455544608, 63.505201067243306, 60.9224305834089, 64.20165375300816, 68.8269236428397, 70.73461409977504, 80.07045691353935, 81.58640098571777, 84.45694501059396, 81.51347964150565, 85.39503519875663, 82.36732986995152, 82.85491970607212, 75.53425598144531, 75.45719351087297, 80.92245197296143, 78.34480925968715, 69.09194878169468, 78.53751059940883, 82.4555789402553, 81.35919489179338, 55.2178692136492, 60.028183528355186, 82.28195040566581, 74.651841708592, 82.17462158203125, 77.61648518698556, 84.19249657222203, 74.55499076843262, 75.39352021898542, 75.09683213915143, 73.3582260949271, 72.778781073434, 70.88315268925258, 63.9538323538644, 64.13953685760498, 63.14200483049665, 62.99300071171352, 61.4247019631522, 60.20907987867083, 58.972099031720845, 62.73732089996338, 61.61937659127371, 63.753494943891255, 63.46509606497628, 66.57469981057304, 63.583166803632466, 61.38306835719517, 66.74316583360944, 63.549377713884624, 61.554959842136924, 61.72087587629046, 61.187205587114605, 68.99950299944196, 75.81176008496965, 79.28008542742047, 78.6370574406215, 78.92695713043213, 74.20171655927385, 76.21876471383231, 76.83273533412388, 86.39848709106445, 79.33275972093854, 91.16326986040387, 26.076778650283813, 0.7893483638763428, 1.3288631737232208, 0.5356949833886964, 0.31140536868146484, 0.5058750520859445, 0.5730484990136964, 0.31525966471859385, 0.245399571955204, 0.3278959680880819, 0.3083493012402739, 0.9953413903713226, 23.813277891704015, 47.92515809195382, 90.6635137285505, 90.59894411904472, 65.43040793282645, 34.8641219820295, 38.97574629102434, 66.0843584878104, 76.58624104091099, 81.51104082380022, 83.87383134024483, 28.296596084322246, 0.2579918791140829, 0.17507214498307022, 0.12604855985513755, 0.161812620769654, 0.25590123129742487, 0.18750216013618878, 0.1768315862864256, 0.15653509753090994, 0.11340386979281902, 0.15117175318300724, 0.128975474940879, 0.08741093706339598, 0.08778400240199906, 0.1334626813020025, 0.2474890255502292, 0.24527819561106817, 0.08081115941916193, 0.10489532564367567, 0.14949168690613338, 0.08476588542440108], [0.012366231165028043, 0.009286302191737508, 0.022718239608885984, 0.013962211686053445, 0.03669216111302376, 0.026729948984991227, 0.013903390333455588, 0.019507717241400054, 0.056540735332029204, 0.029086635115423372, 0.0073439134284853935, 0.019158614366980534, 0.025379111291840672, 0.05333245213010481, 0.07737410813570023, 0.1713860984891653, 0.9179010029350008, 57.964283670697895, 83.89118794032505, 85.00464371272496, 75.6733728136335, 38.31067514419556, 23.4741085256849, 62.57633808680943, 65.16809953962053, 88.12876919337681, 100.32556056976318, 76.34749398912702, 12.879773242133004, 0.16109044237860612, 0.20834358036518097, 0.10966633606169905, 0.060892607883683274, 0.008227655248317336, 0.07200492838663713, 0.04516096007344978, 0.055772715115121434, 0.18770945258438587, 0.238200451114348, 78.7475893838065, 98.07411493573869, 92.98743602207729, 91.13807569231305, 78.18324279785156, 73.22854491642543, 66.92725835527692, 70.28365516662598, 67.10980142865861, 69.39244447435651, 63.96801362718855, 63.69280937739781, 62.041535241263254, 61.75224699292864, 58.84851142338344, 61.7734112058367, 58.8389368057251, 58.357232093811035, 57.62222385406494, 59.78027875082833, 57.494036538260325, 59.16364002227783, 58.62629413604736, 60.313608578273225, 61.880107743399485, 61.88248402731759, 63.10551983969552, 61.559267725263325, 60.51779529026577, 58.392362185886924, 55.7696465083531, 56.930148533412385, 61.10254873548235, 67.00319521767753, 70.73589951651437, 77.6714871270316, 79.63038580758231, 76.8576237814767, 77.33993993486676, 78.95351314544678, 75.53264399937221, 75.52102661132812, 75.23276669638497, 70.24905313764299, 76.36023003714425, 70.15364742279053, 58.59043448311942, 71.81558009556362, 72.70287895202637, 78.20302431924003, 56.695438385009766, 51.41046830586025, 70.8921297618321, 65.82562841687883, 69.64738777705601, 70.08884157453264, 69.7220183781215, 73.21548925127301, 71.99048709869385, 69.25757993970598, 70.45726980481828, 73.42387962341309, 72.59220804486955, 68.92732511247907, 57.94489124843052, 56.809367997305735, 56.371363980429514, 55.51418556485857, 54.969999177115305, 55.69196564810616, 52.98796646935599, 54.14824615206037, 53.74313490731375, 52.921041420527864, 53.990702697208945, 52.93681035723005, 54.476975849696565, 53.98925052370344, 54.571784019470215, 54.733812536512104, 51.99046570914132, 53.89968129566738, 53.4222914150783, 60.68528161730085, 68.27194322858537, 70.20948314666748, 70.1100822176252, 68.61116123199463, 67.10803658621651, 69.39367430550712, 73.32313074384416, 76.84831319536481, 71.66199016571045, 50.00499711717878, 2.7790675163269043, 0.1665436111922775, 0.09083072641598326, 0.18440147223217146, 0.5601839093225343, 0.08590038919023105, 0.11528852794851575, 0.07336845129196133, 0.05759392346122435, 0.061554165956165106, 0.05239194491878152, 0.14381910700883183, 24.29919842311314, 38.62094695227486, 59.08666787828718, 55.255646569388254, 36.53691816329956, 18.87453133719308, 38.788579191480366, 49.29323754991804, 57.880234786442344, 61.017169271196636, 47.12840468542916, 4.63712351662772, 0.06327694601246289, 0.04435981377693159, 0.038712088617363145, 0.03243530382003103, 0.046473494464797635, 0.004430024518764445, 0.022404381539672613, 0.0473357496250953, 0.06146852805146149, 0.06685290019959211, 0.057903301502977095, 0.04021687912089484, 0.053968164803726335, 0.01208923535887152, 0.020163791054593663, 0.08109138081116335, 0.054439560044556856, 0.014999730745330453, 0.037210110641483746, 0.04907736920618585, 0.012955817028081842, 0.01679958389805896, 0.01702617048951132, 0.03285764776436346, 0.04500261374882289, 0.040425627026706934, 0.028437197374712144, 0.04605119462524142, 0.016203265271282623, 0.014421230448143823, 0.019707998726516962, 0.03387667504804475, 0.05636454014373677, 0.10042528621852398, 0.16616737709513732, 1.1143246229205812, 69.78452437264579, 94.78453200204032, 95.54295567103794, 84.12429305485317, 51.43629823412214, 36.08980853216988, 47.381489345005576, 59.9406292779105, 102.57427556174142, 108.16473361424038, 89.22913455963135, 17.145183767591202, 0.16924428913210118, 0.18515060203416006, 0.21313276195100375, 0.06616764089890889, 0.09055107499339751, 0.008362560732556241, 0.03624473512172699, 0.10107144833143268, 0.220316100067326, 0.699799926153251, 87.10813440595354, 102.29938398088727, 96.51261847359794, 94.92897810254777, 83.02683898380825, 76.34203965323312, 71.36662224360875, 73.85906614576066, 70.46386364528111, 72.25980622427804, 68.04625879015241, 66.92598683493478, 66.1928129196167, 64.5894535609654, 64.36102458408901, 65.54071753365653, 62.69431849888393, 62.146459988185335, 60.651985849652974, 63.284484590802876, 61.040014948163716, 61.33564690181187, 61.51994786943708, 63.44950430733817, 63.86915465763637, 65.31919506617955, 65.98436001368931, 63.62811470031738, 64.3833977835519, 62.09193747384207, 57.83438014984131, 60.40231622968401, 63.84209837232317, 70.5013074874878, 73.05516651698521, 80.74465451921735, 81.93153190612793, 80.30965559823173, 80.68503897530692, 81.33621719905308, 79.13451371874127, 78.38021727970668, 79.07895592280796, 74.92897060939244, 79.07530117034912, 74.84142330714634, 61.08189174107143, 74.99568721226284, 74.75724588121686, 78.72527871813092, 58.26068687438965, 57.626323291233604, 74.99743121010917, 70.06354318346295, 73.00010899135044, 72.18731566837856, 73.64625671931675, 75.28576060703823, 75.70675890786308, 74.69068213871547, 74.11573260171073, 77.67166778019497, 76.47750173296247, 73.23206765311105, 60.17103154318673, 58.64860480172293, 57.82357570103237, 57.77226325443813, 58.233543736594065, 60.21844605037144, 57.621866021837505, 57.7825083732605, 57.67733349118914, 56.162129402160645, 57.25121089390346, 56.48525537763323, 58.23574978964669, 56.91129459653582, 56.918159416743684, 57.67209454945156, 55.5266158921378, 58.33880547114781, 55.91089991160801, 63.58766923631941, 71.75966099330357, 73.59487479073661, 72.57123143332345, 72.62677533285958, 70.2040079661778, 73.4390822819301, 75.39827278682164, 81.20480591910226, 77.59377152579171, 59.2224634715489, 4.254681638308933, 0.09268305916339159, 0.11230878891157252, 0.0393286055353071, 1.2035526292664664, 0.08503007981926203, 0.1137900919254337, 0.02068524352008743, 0.015498513355851173, 0.19903120292084558, 0.013566099905541964, 0.06545091114406075, 28.018829686301096, 42.12414182935442, 48.56887742451259, 33.31118222645351, 30.756465094430105, 30.22877720424107, 49.2586806842259, 59.634213720049175, 68.77831404549735, 74.74336338043213, 59.925926889692036, 6.6691328798021585, 0.09240321096565042, 0.03117804628397737, 0.0060617354216187126, 0.04527915408834815, 0.07569664743329797, 0.05050447423543249, 0.014926621989746178, 0.04513665834175689, 0.04324784076639584, 0.040824103501758406, 0.03236425781090345, 0.010497998645795243, 0.01628497276189072, 0.06800039112567902, 0.021968192088284662, 0.02834855525621346, 0.024658413803470985, 0.021056904291201915, 0.03880924126133323, 0.11863808892667294, 0.10155527094112975, 0.13181146633412155, 0.08532037745629038, 0.11692158531929765, 0.1546578761190176, 0.20468683301338128, 0.11685445106455258, 0.17882395509098256, 0.12388707298253264, 0.09336331766098738, 0.08502259557800633, 0.13589213522417204, 0.19975287919597967, 0.1364935343819005, 0.4028657280973026, 2.8598205660070692, 91.52329077039445, 103.12807478223527, 110.08709171840123, 95.33056313650948, 60.295696122305735, 34.11107621874128, 89.2171767098563, 86.30142770494733, 114.36790466308594, 115.7146531513759, 99.81383963993618, 23.213113342012676, 0.31318853156907217, 0.606195748916694, 0.533236352460725, 0.27232156161751064, 0.22095378727785178, 0.29520710930228233, 0.23346044974667685, 0.2629924107875143, 0.6895356455019542, 0.9708646237850189, 88.16754708971295, 109.32688236236572, 103.92506095341274, 100.95034953526088, 86.02931540352958, 80.62079593113491, 73.28124005453927, 79.83423205784389, 74.99354021889823, 78.0311814716884, 72.01592445373535, 70.7326477595738, 70.15054157802037, 69.55266298566545, 66.71025916508266, 70.09032154083252, 65.2324607031686, 67.07187121255058, 63.74806145259312, 66.60858617510114, 64.12096432277134, 66.31935351235526, 66.33332633972168, 67.36587033952985, 67.50377123696464, 68.44276469094413, 69.15371131896973, 67.44378049033028, 66.29862703595842, 65.55173737662179, 62.19470133100237, 63.824554170881, 68.5539914539882, 75.30074787139893, 76.07730633871896, 84.31560475485665, 87.47187955038888, 83.35585703168596, 84.18640300205776, 86.49603979928153, 81.96109649113247, 84.07388387407575, 83.27860695975167, 78.71632943834577, 81.729339327131, 79.14202472141811, 62.73641068594796, 79.5389266695295, 78.64473520006452, 80.59812395913261, 61.42730753762381, 60.85998017447335, 76.8260303224836, 72.27776731763566, 78.04220131465367, 74.38635104043144, 76.11543805258614, 80.84110246385846, 77.67532253265381, 76.42602947780064, 76.65032427651542, 82.21237809317452, 80.45799268995012, 76.63676139286586, 64.29832404000419, 61.29438155038016, 61.241213934762136, 62.56258760179792, 60.964217049734934, 63.95081683567592, 59.865908350263325, 62.7734306880406, 61.60297189440046, 58.52007702418736, 60.5135360445295, 59.61796883174351, 60.549812589372905, 59.43598856244768, 60.617925780160085, 61.43017714364188, 59.338505336216514, 61.17787415640694, 60.5757224219186, 67.74832698277065, 75.73096643175397, 76.24919782366071, 77.72430733272007, 76.91229220799038, 75.35121958596366, 75.6542444229126, 79.80542482648576, 85.63464382716587, 81.28420298440116, 63.3492556980678, 3.576705949647086, 0.372894076364381, 0.20942146038370474, 0.23304540344646998, 2.097455531358719, 0.41230550727673937, 0.4262645739529814, 0.14021478327257292, 0.19033428387982504, 0.15935259205954416, 0.17897824038352284, 0.38522180914878845, 39.02599913733346, 53.975044931684224, 76.07807758876255, 73.58540439605713, 50.822720187050955, 27.039797237941197, 56.1150484085083, 69.85463864462716, 79.96143272944859, 84.74694197518485, 75.59818635668073, 11.06473353930882, 0.1303465770823615, 0.1917479708790779, 0.18355912528932095, 0.19515087828040123, 0.22273043622928007, 0.06854875598634992, 0.08052639184253556, 0.20977663275386604, 0.14435164843286785, 0.1359331323099988, 0.10824593835111175, 0.24626752680965833, 0.13378003213022435, 0.1359562160713332, 0.09028177122984614, 0.09443050396761724, 0.11778499398912702, 0.15310898423194885, 0.13422508324895585], [0.04283339836235557, 0.0387097001740975, 0.016848333246473755, 0.07155823521316051, 0.08462387483034815, 0.017066931784419075, 0.05920996317373855, 0.07068047552768673, 0.022511182951607873, 0.06624116016817944, 0.04060505543436323, 0.029195936928902353, 0.07580197642424277, 0.06928320907588516, 0.08642440821443285, 0.24632935492055757, 19.556467499051774, 84.8402840750558, 83.9505672454834, 63.281677518572124, 52.07582432883126, 43.33818667275565, 27.02056462424142, 55.90435470853533, 70.7680766241891, 96.55112539018903, 92.21496309552873, 30.387533119746617, 0.6176398662584168, 0.09888529671089989, 0.1683547297226531, 0.14570934272238187, 0.0603732436097094, 0.056271027840141735, 0.11187760026327201, 0.18699496878044947, 0.5432506065283502, 0.6856446542910167, 19.646900040762766, 110.00474861689976, 86.7705214364188, 92.47909191676548, 74.87397561754499, 71.68690640585763, 63.434266907828196, 70.51134763445172, 65.88937813895089, 67.78272751399449, 63.86744540078299, 66.11044897351945, 62.12619209289551, 64.39244433811733, 62.339557375226704, 58.63466671534947, 58.79238387516567, 59.22773020608084, 58.17291028159005, 58.800791195460725, 58.5876829964774, 61.39705508095877, 59.213840757097515, 59.63508224487305, 59.675562449863975, 59.98386096954346, 59.9990427834647, 60.427968978881836, 61.4581366947719, 61.61898749215262, 60.071581976754324, 58.08075632367815, 57.422296387808665, 65.26718085152763, 71.07115704672677, 72.37747396741594, 71.49606718335832, 77.05409104483468, 73.66341182163784, 76.64938626970563, 71.69104753221784, 71.18623311179024, 65.18147482190813, 70.32715088980538, 68.67894785744804, 76.91113185882568, 71.08763122558594, 60.020380701337544, 68.9999337877546, 73.47555337633405, 77.45776053837368, 65.40406036376953, 68.24360847473145, 70.34376403263637, 66.69516767774309, 63.37404687064034, 67.99508530752999, 64.99210166931152, 65.7951466696603, 74.44476454598563, 76.22185666220528, 71.27237687792096, 72.12190532684326, 67.87622942243303, 70.98990481240409, 62.97089154379708, 56.67460421153477, 57.6053466796875, 60.16639709472656, 61.121399198259624, 61.00997788565499, 61.058698654174805, 60.27291297912598, 55.02991349356515, 54.6553395816258, 52.709277697971885, 53.054610116141184, 53.13840191704886, 53.381349154881065, 51.40315532684326, 55.41369376863752, 54.808707169124055, 53.9086514200483, 54.23556068965367, 55.82760143280029, 62.521864209856304, 68.20216941833496, 66.69320133754185, 67.82008102961949, 63.92804064069475, 67.46662616729736, 71.3628841127668, 75.617495400565, 74.29687908717564, 79.3119707107544, 31.8380321093968, 0.08046691824815103, 0.2694539912045002, 0.15315486676990986, 0.5084944686719349, 0.10842668650937931, 0.10700470781219856, 0.005746215789778424, 0.13190825256918157, 0.10159557592123747, 0.09339512738266162, 0.20879456187997544, 3.55306014418602, 34.80658047539847, 17.960773740495952, 71.59363378797258, 66.99241856166294, 25.37234422138759, 16.903179747717722, 37.3438333102635, 51.67635154724121, 53.25064659118652, 59.066031728472026, 29.332553386688232, 5.966078971113477, 0.07631120338503804, 0.05350752095026629, 0.050130693042384725, 0.09917811171284743, 0.04123051205117788, 0.02890112703399999, 0.03699294890144041, 0.06116636962230716, 0.0442828984398927, 0.0601414560473391, 0.03936270870534437, 0.024050448123099546, 0.06924444437026978, 0.05047886971650379, 0.12665610654013498, 0.030895287171006203, 0.04771361220628023, 0.026015283672937324, 0.052311436738818884, 0.042975978925824165, 0.03147484089380928, 0.018992568366229534, 0.15244695118495397, 0.018895792309194803, 0.07307045228247132, 0.0562489584886602, 0.05051336982952697, 0.09253902653498308, 0.015219777955540588, 0.03487927160624947, 0.05935594319765057, 0.07370034312563283, 0.07075641716697387, 0.30576796403953005, 24.301600762775966, 99.45813356127057, 92.6860579081944, 74.96557371956962, 66.78111689431327, 53.74111992972237, 32.095264843532014, 57.54642595563616, 81.37417520795549, 105.4164709363665, 101.2991977419172, 37.38247224262783, 0.43840446110282627, 0.082890638549413, 0.1718766793076481, 0.2128606286964246, 0.0462181787006557, 0.09825114466782127, 0.22470338536160334, 0.24499834062797682, 0.5229191460779735, 0.7807104502405439, 24.42371187891279, 117.71461568559918, 91.30193505968366, 97.23697512490409, 78.16969381059918, 76.04695660727364, 68.23444380078996, 73.34719930376325, 69.07270227159772, 73.36500058855329, 65.97878755841936, 68.5003444126674, 65.20646749223981, 67.52515084402901, 65.26878588540214, 63.09229046957833, 62.25312178475516, 64.34197262355259, 59.07172230311802, 63.6224102292742, 60.641104970659526, 63.98902497972761, 61.80121094839913, 62.58456475394112, 62.47433158329555, 64.09821592058454, 63.17284093584333, 63.86811242784773, 63.54169995444161, 64.27616623469761, 61.062033789498464, 59.74481514522007, 59.099980626787456, 69.13269301823208, 74.33225236620221, 76.92242268153599, 75.26400579724992, 77.58484309060233, 76.55363314492362, 78.30571869441441, 74.50355325426374, 75.07614735194615, 69.8585296358381, 71.4717971256801, 72.70690890720913, 79.37856224605015, 73.20080770765031, 62.831746918814524, 71.2908799307687, 75.02688462393624, 78.56109278542655, 67.43321922847203, 72.32065854753766, 74.05166326250348, 70.4733201435634, 67.89822741917202, 71.0034260068621, 66.32650320870536, 68.08360535757882, 76.73310511452812, 78.26767035893032, 76.50717748914445, 75.92730862753731, 73.12268216269356, 72.30217633928571, 67.07961845397949, 58.98115253448486, 61.24944060189383, 62.97058582305908, 66.90153612409318, 65.27046734946114, 65.44998100825718, 62.711230414254324, 58.7243401663644, 57.93923888887678, 56.249714919498985, 57.017907755715505, 56.00266477039882, 57.17154632295881, 55.45295803887503, 56.73006820678711, 58.88262013026646, 57.24151815686907, 58.086384364536826, 57.908767563956125, 66.14788586752755, 69.51002189091274, 70.0514394215175, 70.19525323595319, 67.90754495348249, 68.81414590563092, 74.4525534766061, 77.08011899675641, 80.27419894082206, 83.44653797149658, 43.855167388916016, 0.5163136890956334, 0.18668380619159766, 0.22156934067606926, 0.20417713107807295, 0.027490786908726608, 0.04889468722311514, 0.06778590620628425, 0.11157774885318109, 0.4665479766471045, 0.2170183520231928, 0.37405887671879356, 3.260656714439392, 41.81058699744088, 21.516014099121094, 49.86672101702009, 48.73953907830374, 28.084907054901123, 28.724671125411987, 51.0268999508449, 59.35106073107038, 63.96911144256592, 72.84464304787772, 42.00502191271101, 6.456687799521855, 0.03907414472528866, 0.06803295402122395, 0.020461774797045758, 0.06786823964544705, 0.04108560411259532, 0.026381107346553887, 0.09291040232138974, 0.0481761966698936, 0.028620352635958364, 0.0839424424671701, 0.007902278198993631, 0.0883695034842406, 0.09635810660464422, 0.04818984879446881, 0.03995414696899908, 0.05398256331682205, 0.04356660634013159, 0.05416410196838634, 0.22020848441336835, 0.1223063442323889, 0.10112807886408907, 0.19286863931587764, 0.2887957404766764, 0.11941948985414845, 0.22547012993267604, 0.20691773401839392, 0.1702255593346698, 0.18746513926557132, 0.20234030964119093, 0.1291721686720848, 0.15421646194798605, 0.15342740714550018, 0.28958050693784443, 0.36365802053894314, 38.67002902712141, 114.59770243508476, 104.16216823032924, 88.25839478628976, 74.35987840379987, 62.14229106903076, 43.715261936187744, 76.8468679700579, 90.33807400294712, 114.3962950025286, 110.08023384639195, 49.53307894298008, 0.6774321549705097, 0.2281259431370667, 0.6244743423802512, 0.3253412837428706, 0.23469725623726845, 0.20326484074550016, 0.5153086973088128, 0.3895509982747691, 1.1153586017233985, 0.9796982812029975, 24.39475699833461, 122.24919073922294, 94.9195841380528, 101.62726388658795, 82.20747961316789, 81.14177880968366, 70.10274491991315, 76.34898090362549, 72.6339111328125, 77.18282726832798, 68.90520899636405, 73.3531608581543, 69.72137914385114, 72.99674606323242, 67.99041611807687, 66.05548872266496, 66.17034244537354, 67.71810926709855, 62.4759852545602, 67.65073953356061, 65.461195400783, 68.12284878322056, 65.2269924708775, 67.89076505388532, 66.09650393894741, 67.05960764203752, 65.79409054347447, 67.10483346666608, 65.75585460662842, 68.98691286359514, 66.19302136557442, 63.86142826080322, 63.376075744628906, 72.1276375906808, 76.73922647748674, 78.73271329062325, 77.12002944946289, 81.61929375784737, 80.22196238381522, 82.65989766802106, 77.81879588535854, 79.36636120932442, 72.49509307316372, 74.88082654135567, 76.47199181147984, 82.46946144104004, 77.27350125994, 66.44820090702602, 74.90754931313651, 78.61240523202079, 78.91655567714146, 65.88988535744804, 73.5942633492606, 77.7283581324986, 74.28936808449882, 71.17353875296456, 73.77930082593645, 70.20771830422538, 70.97447981153215, 79.03380652836391, 81.87576566423688, 78.93085506984166, 77.90207699366978, 77.93802002498082, 75.9174143927438, 69.6681489944458, 62.11152444566999, 65.42786489214215, 65.92994172232491, 69.31125477382115, 67.44598306928361, 67.80114024026054, 66.24688380105155, 62.515270369393484, 62.00179154532296, 59.99206679207938, 61.45577430725098, 58.19045448303223, 60.419839586530415, 56.9871689251491, 61.86509268624442, 61.772619111197336, 61.627860341753276, 61.91058949061802, 63.09895379202706, 71.77524580274309, 74.16594723292759, 73.69475514548165, 74.82221153804234, 69.98530646732875, 73.7581227166312, 79.03539766584123, 82.29872335706438, 85.52857957567487, 87.95058264051164, 41.4651712008885, 0.7151787323611123, 0.34868310551558224, 0.43042844480701853, 1.4336230094943727, 0.2918120457657746, 0.29641066757696016, 0.23790800252131053, 0.40610068451081005, 0.47935041253055843, 0.47865504984344753, 0.4066049445952688, 5.770170603479658, 55.58158656529018, 28.7618978364127, 95.34164551326207, 87.12335096086774, 36.08022001811436, 27.32460563523429, 59.45511000497, 73.59452043260846, 78.20877047947475, 83.9418750490461, 58.38166890825544, 8.24108030114855, 0.10050251028899636, 0.1418915247278554, 0.13302362843283586, 0.1850989248071398, 0.14908057610903466, 0.09764838844005551, 0.25180868804454803, 0.1299059907240527, 0.17165919526347093, 0.17361846512981824, 0.10430556336151701, 0.11060734878161124, 0.18095212589417184, 0.21855220757424831, 0.21352230890520982, 0.11220676438616854, 0.09685123192944697, 0.12521700161908353], [0.012071377165349466, 0.023653930917914425, 0.036687849022980244, 0.06405072699167899, 0.019967964151874185, 0.024259945810107247, 0.049201303627341986, 0.041984191430466514, 0.05582019221037626, 0.01211385685019195, 0.04145895104323115, 0.054578181356191635, 0.04613687324204615, 0.06013815836714847, 0.030108909189168895, 1.1758421276296889, 50.930761201041086, 85.06671891893659, 64.8284021105085, 62.77052634102957, 45.65227031707764, 45.93713256290981, 64.029616355896, 63.53812163216727, 88.74776336124965, 101.34645244053432, 56.07289368765694, 3.9580452357019698, 0.0959191962278315, 0.1626162776457412, 0.03941104414739779, 0.07741346995213202, 0.07950914571327822, 0.1923823468387127, 0.07998078861939055, 0.08022467446114336, 0.06366904425833907, 0.6626155557376998, 69.40397153581891, 98.67512021745954, 87.4545646395002, 79.95201792035783, 69.63541603088379, 72.40958159310478, 71.32117407662528, 76.49849918910435, 76.51051957266671, 75.96445369720459, 67.17258535112653, 61.36026436941964, 60.980878829956055, 65.03060858590263, 63.06493541172573, 63.973294258117676, 57.38200725827898, 65.46790736062187, 58.620318685259136, 62.371671949114116, 60.72697080884661, 60.34632764543806, 57.027503217969624, 57.598895277295796, 59.55998611450195, 58.26763159888131, 59.277270862034385, 61.61374855041504, 61.078035490853445, 58.87240627833775, 56.43111848831177, 57.40019416809082, 61.32627378191267, 70.57286698477608, 73.69440078735352, 72.67306423187256, 68.50125462668282, 74.60689381190709, 71.0319344656808, 75.00738797869, 71.32109069824219, 72.310715675354, 64.12442452566964, 67.72037437983921, 65.92163167681012, 79.581588608878, 64.24692126682827, 60.06664875575474, 67.11100346701485, 74.83673327309745, 80.45595686776298, 83.38545635768345, 72.51445770263672, 68.46761144910539, 66.04187025342668, 68.27646650586809, 67.38121891021729, 65.55071599142892, 67.34519944872174, 70.68625463758195, 69.5125927243914, 71.99596227918352, 67.99395969935826, 69.98823165893555, 70.92681516919816, 59.680905614580425, 54.09689201627459, 57.18432753426688, 59.03272901262556, 63.77730642046247, 69.9938735961914, 69.35688359396798, 68.23240103040422, 67.8983177457537, 63.233255522591726, 58.30536379132952, 50.90778003420149, 52.781163760593955, 51.4812912940979, 54.14039816175188, 54.64581707545689, 53.07037557874407, 54.27736105237688, 56.30316046306065, 54.465938636234824, 53.542752334049766, 60.129036630902974, 66.93819481985909, 65.66818918500627, 66.59941455296108, 64.59385177067348, 70.55512823377336, 71.97855009351457, 75.14227335793632, 73.20339938572475, 85.40447780064174, 13.422777567590986, 0.4370295320238386, 0.22838812906827244, 0.06004967740071671, 0.0818638861445444, 0.06164623637284551, 0.08871295076927968, 0.0585408801478999, 0.19577850960195065, 0.10589737937386547, 0.24708456439631327, 0.6905532308987209, 15.273877552577428, 30.156769548143657, 33.91193042482649, 71.27269649505615, 49.058273792266846, 18.893996715545654, 22.472909586770193, 59.311178071158274, 54.102936949048726, 60.52643884931292, 55.72851317269461, 27.245106084006174, 3.824559049946921, 0.05838775515024151, 0.06552244230572667, 0.09983498110835042, 0.08719941734203271, 0.03792446891644171, 0.05789621081203222, 0.026436869354386414, 0.028367854488481368, 0.07819154605801616, 0.0232608267438731, 0.07763747471783843, 0.008661100025554853, 0.09268485049584083, 0.025351508487282053, 0.009547230288652437, 0.07963278836437634, 0.09674113283732108, 0.04092816023954323, 0.04440762335434556, 0.08117452849234853, 0.051528529463601966, 0.06149408168026379, 0.03152647401605334, 0.03168944116415722, 0.0013385926805702703, 0.024708160598363196, 0.013280156766995788, 0.028035360454980816, 0.05468369694426656, 0.06127885037234851, 0.008007181409214224, 0.06957759827907596, 1.3469156793185642, 64.71506309509277, 97.29036508287702, 76.08024542672294, 75.34305545261928, 55.55845601218087, 54.57064798900059, 51.858620166778564, 48.236451285226, 96.98746531350272, 108.82437474387032, 66.47801562717983, 4.58798976455416, 0.10000328493437596, 0.12079292615609509, 0.04836655966937542, 0.05706550753010171, 0.08032703146870647, 0.26980612373777796, 0.20925748561109814, 0.14147988467344216, 0.07776577211916447, 1.2303395633186613, 78.06494276864188, 102.27770560128349, 91.25404807499477, 83.31561306544712, 73.40873255048479, 74.850754737854, 76.7475643157959, 81.39508928571428, 81.11379841395787, 81.76774202074323, 72.37855093819755, 64.29290444510323, 65.07923902784074, 69.1229863848005, 66.58660207475934, 67.86671733856201, 61.85515676225935, 69.44413907187325, 63.00835623059954, 65.87179224831718, 65.07529939923967, 64.09449168613979, 60.93941198076521, 60.86169637952532, 61.434797695704866, 62.70403208051409, 61.41182000296456, 62.84296131134033, 63.95661163330078, 61.988652501787456, 59.31350571768624, 60.73461382729666, 65.66204002925328, 73.63741166251046, 77.43367113385881, 76.28134713854108, 72.88556793757847, 78.00889859880719, 75.04884093148368, 75.76448454175676, 75.09635271344865, 75.57065064566476, 69.54768112727574, 69.57718317849296, 69.64890943254743, 81.32818508148193, 68.04913534436906, 64.23977157047817, 70.85472760881696, 76.18550368717739, 84.2102631160191, 82.02269921983991, 75.97709941864014, 70.48889105660575, 69.76629229954311, 71.93450546264648, 69.63586071559361, 66.31174523489815, 71.01421655927385, 74.49807807377407, 72.70144067491803, 73.21322413853237, 71.94337136404855, 72.69087246486119, 72.35373892102922, 59.59631824493408, 56.68911552429199, 59.01918697357178, 62.262105805533274, 69.31962040492466, 70.06969928741455, 73.88433674403599, 72.5262279510498, 72.45463371276855, 67.81962939671108, 60.78464780535017, 55.492125034332275, 55.24499150684902, 54.84612669263567, 56.459303855895996, 57.56230953761509, 57.17952632904053, 58.032011236463276, 57.27591173989432, 57.84351355688912, 56.64374726159232, 62.83117716653006, 69.42778301239014, 70.50138391767229, 70.17351232256208, 68.9734889439174, 72.30907590048653, 75.09122494288853, 80.18864577157157, 76.43414497375488, 90.92126410348075, 20.1576794896807, 0.7692991197109222, 0.1902472549783332, 0.21080811454781465, 0.04640117280983499, 0.31948492942111834, 0.14974250059042657, 0.1154250627649682, 0.2553771308490208, 0.6645328785691942, 0.13793371138828142, 0.7357454544731549, 15.060621704374041, 36.21833283560616, 35.30316128049578, 50.50265141895839, 31.06313078744071, 25.202535458973475, 29.320946420942033, 68.65605354309082, 66.07816069466728, 70.76749297550747, 72.4133266721453, 37.71437726702009, 4.2342183249337335, 0.07681831331657511, 0.07668485904910735, 0.04569085521091308, 0.06871676125696727, 0.0398545855257128, 0.04990519889231239, 0.019841917790472507, 0.02208471012168697, 0.059013975118952136, 0.021344687955986177, 0.07267455424049071, 0.03920698491856456, 0.09243336506187916, 0.029763422906398773, 0.03769409949226039, 0.017169792604233538, 0.020608319701360803, 0.15756097462560448, 0.083212033446346, 0.15694109217396804, 0.16001241308237824, 0.11176305676677398, 0.06597963920129196, 0.13934826691235813, 0.15279334331197397, 0.11517416765647275, 0.1039251834154129, 0.15243473755461828, 0.1498629676976374, 0.2220034809517009, 0.14921332470008306, 0.2689738598253046, 2.133952898638589, 81.699052129473, 107.48456055777413, 87.73281914847237, 84.58024079459054, 66.42662675040108, 60.18180819920131, 83.03864397321428, 81.02404853275844, 111.77136979784284, 115.79029818943569, 78.58113139016288, 6.42717228616987, 0.14035560643034323, 0.4639057070016861, 0.14187386924667017, 0.2935905674738543, 0.4271458280938012, 0.7642988594514983, 0.4018030608338969, 0.5160662138036319, 0.5186608231493405, 1.396153762936592, 77.9971352985927, 105.59704072134835, 95.3296320778983, 88.31357737949916, 78.26662118094308, 78.81648077283586, 78.37856360844204, 85.3299514225551, 85.43682861328125, 85.29388332366943, 75.88816942487443, 67.91509764535087, 67.80330113002232, 71.53895146506173, 71.02477782113212, 71.92315210614885, 64.30029038020542, 72.70720767974854, 67.66959694453648, 69.6629170009068, 66.99101502554757, 67.8970809664045, 63.57484980991909, 62.92587416512625, 66.45469052450997, 65.50732449122837, 64.46818665095738, 67.92458193642753, 66.9481793812343, 65.71371378217424, 62.78880705152239, 64.54329667772565, 68.17794799804688, 77.51843220846993, 82.37461158207485, 78.09401403154645, 76.9243334361485, 81.90912396567208, 80.27356665475028, 80.05978448050362, 79.264465876988, 79.18302604130336, 72.03045313698905, 75.43938527788434, 74.26365280151367, 86.37678786686489, 71.36835929325649, 65.05015386853898, 73.6359177998134, 80.45727702549526, 76.68311282566616, 77.90644046238491, 75.2607957295009, 74.64241300310407, 74.5620779309954, 76.35479654584611, 70.7404783793858, 68.25498962402344, 74.17916965484619, 76.64673205784389, 75.53818171364921, 78.20984745025635, 74.1890847342355, 78.03850487300328, 78.65734618050712, 64.5460203715733, 58.8576135635376, 62.33722278050014, 67.14215918949672, 73.29742240905762, 75.74076339176723, 76.97417981284005, 76.4790233884539, 75.67415796007428, 71.25886957986015, 63.902068274361746, 58.35537692478725, 57.51783759253365, 56.918013504573274, 59.65694127764021, 61.04723412649972, 59.59346253531319, 61.54830346788679, 62.794282232012065, 61.99926240103585, 59.855805669512065, 67.16906261444092, 74.10187094552177, 75.19480173928397, 76.06789152962821, 72.0394093649728, 77.31626047406877, 81.12689576830182, 82.65637493133545, 80.22408158438546, 95.12891946520124, 16.89006675992693, 1.1856715487582343, 0.448063135679279, 0.5304680924330438, 0.23381125235131808, 0.7842494174838066, 0.48817989017282215, 0.32586823403835297, 0.833252945116588, 0.4689628556370735, 0.46758879508290974, 0.9210515767335892, 24.312660557883127, 46.41979265213013, 49.67991869790213, 90.8203832081386, 66.86908108847481, 29.210772309984478, 36.34263610839844, 80.41282939910889, 79.42553901672363, 82.48425415584019, 85.57194328308105, 51.04484019960676, 6.7701127869742255, 0.2227774994181735, 0.21404616508100713, 0.13060936012438365, 0.20396445106182778, 0.13895934421036923, 0.15946771231080803, 0.14321006754679338, 0.11261687773678984, 0.1813336389937571, 0.17239324801734515, 0.1410531268588134, 0.11612236606223242, 0.14457686777625764, 0.14467304332980088, 0.06705340051225253, 0.17509639582463674, 0.14481200730162008], [0.053160253513072214, 0.05584160338288971, 0.08783943192767245, 0.09474782765443836, 0.06695766600647143, 0.02425874480312424, 0.036701263660298925, 0.02536259574948677, 0.12247654795646667, 0.004403509914741984, 0.08256890438497066, 0.04382860228153212, 0.09135077601032597, 0.029854112504316226, 0.12969633697399072, 9.149623274803162, 76.46075657435826, 80.46879019056047, 65.84373542240688, 42.12544114249093, 46.69377054486956, 63.53639847891671, 75.15168816702706, 78.40900366646903, 99.2719635282244, 76.33455644335065, 19.296497174671718, 0.14238800880100044, 0.033814836759120226, 0.09919606574944087, 0.09907709141927105, 0.04234218989898052, 0.11948145367205143, 0.15207174846104213, 0.08608001098036766, 0.11399591873799052, 0.539074467761176, 16.821675641196116, 98.57356534685407, 86.9652099609375, 83.8605602809361, 66.61738954271588, 71.52697277069092, 77.0699051448277, 86.62890325273786, 84.23230975014823, 86.73195893423897, 83.94165965488979, 79.94209589276994, 71.45646245138985, 67.57094642094204, 71.32832377297538, 71.03871590750558, 73.32060854775565, 71.56455557686942, 67.37559781755719, 67.16208662305559, 65.37994316646031, 61.74420097896031, 60.56598799569266, 57.96216794422695, 58.329807553972515, 58.271272454942974, 54.823697907584055, 55.90945816040039, 56.10480328968593, 58.316070965358186, 56.232393060411724, 57.06716700962612, 57.978628226688926, 63.97492013658796, 71.53371252332414, 72.7382035936628, 72.50621019090924, 69.99247006007603, 73.49976784842355, 70.5541763305664, 71.51605715070451, 70.80946704319545, 75.9317068372454, 65.67328916277204, 65.99583843776158, 64.1444422858102, 67.21655355181012, 58.41515227726528, 65.41047355106899, 69.54369286128453, 68.21886593954903, 74.27310929979596, 81.36174488067627, 69.67659800393241, 67.03205108642578, 63.52943638392857, 69.135666847229, 66.28177070617676, 67.85995674133301, 72.57382311139787, 65.92293793814522, 68.22200652531215, 65.26702799115861, 63.5095089503697, 63.277904646737234, 57.98655959538051, 55.324041162218364, 50.93728903361729, 53.47297157560076, 58.272783688136506, 62.587080001831055, 66.78757177080426, 71.71494238717216, 68.79851245880127, 70.15521771567208, 69.18384565625871, 64.16452257973808, 56.59163924625942, 50.39784826551165, 53.007532596588135, 54.35638986315046, 55.82359232221331, 53.284862995147705, 57.82163715362549, 55.548606940678184, 52.89757735388619, 52.25568192345755, 56.57918460028512, 57.922931466783794, 63.32343619210379, 64.8207243510655, 62.26088292258126, 67.30239159720284, 67.18266023908342, 72.82113034384591, 73.43064022064209, 77.47183758871896, 68.29545593261719, 1.8706739289419991, 0.13934480638376304, 0.050138940635536394, 0.03474288606750114, 0.05842015519738197, 0.01847871040393199, 0.04437831064153995, 0.32616269109504564, 0.019055743369140794, 0.10575340781360865, 0.07594030257314444, 0.16670949943363667, 26.789147921970912, 24.232443605150493, 75.96596145629883, 76.85436507633754, 31.667405196598597, 23.533632005964005, 26.991776500429424, 52.34755447932652, 51.21938937050955, 58.50948796953474, 56.05691283089774, 42.930872849055696, 7.853380373546055, 0.08808621511395488, 0.0867831361080919, 0.024741388458226408, 0.06459671019443444, 0.02899522627038615, 0.023342259427798644, 0.040561652941895385, 0.03444076495777283, 0.027686288114637136, 0.01247344393881836, 0.02513348331142749, 0.08797431790402957, 0.13779117832226412, 0.028580454776861837, 0.1214330153805869, 0.08352713832365614, 0.0722822660048093, 0.017155690950208476, 0.025288543830226575, 0.02886303068537797, 0.030624931678175926, 0.021198417858353684, 0.034138419931488376, 0.06905676836946181, 0.015216090117714234, 0.025201803306117654, 0.05382913637108036, 0.012606350289258574, 0.04631111424948488, 0.10571187468511717, 0.3430487678519317, 10.917419569832937, 87.52415779658726, 92.28582082475934, 75.9427683694022, 56.165259565625874, 53.858190127781455, 57.210748059409006, 53.89262539999825, 74.097382409232, 111.27990286690849, 86.5906673158918, 26.28407120704651, 0.18717011223946298, 0.04570005614576595, 0.09824674776090042, 0.06643321950520788, 0.2788286310221468, 0.037105850343193324, 0.17981373412268503, 0.38584152875202044, 0.20021962986460753, 0.5248992198279926, 21.4322726726532, 105.86119733537946, 90.91171033041817, 90.45185770307268, 70.84174142565045, 78.34512192862374, 80.49832003457206, 90.79587691170829, 88.23378426688058, 90.3473151070731, 88.5134562083653, 84.79200799124581, 76.13135637555803, 73.37515885489327, 75.13895906720842, 74.62742573874337, 78.51656178065709, 76.55043697357178, 71.2992525100708, 70.20038100651333, 68.36322171347481, 65.22563062395368, 64.18707643236432, 60.027995926993235, 60.063918113708496, 60.77453817640032, 58.757066181727815, 57.35627113069807, 59.855812617710654, 60.10605198996407, 59.31941168648856, 58.20773465292794, 61.44000884464809, 66.79798712049211, 74.39170115334647, 77.3074848992484, 76.0934956414359, 73.80230631147111, 75.5367295401437, 73.40607833862305, 76.00135557992118, 74.02018792288644, 77.82930156162807, 68.33150318690709, 70.38679422651018, 69.85973167419434, 72.57093960898263, 62.71783120291573, 69.45139299120221, 71.53409467424665, 67.33719512394497, 77.31619794028146, 82.46115139552525, 75.60310568128313, 69.24659483773368, 67.5094826562064, 71.05427987234933, 68.10718754359654, 72.49844210488456, 74.76579216548375, 70.07293019975934, 72.62465613228935, 68.85580035618374, 67.11894525800432, 64.4193616594587, 60.55670520237514, 56.80253791809082, 54.00743395941598, 55.80010046277727, 61.362182072230745, 64.46767943246024, 69.66086728232247, 73.01089259556362, 71.7661714553833, 72.44020925249372, 72.53335680280412, 65.50610160827637, 60.94963278089251, 55.06733301707676, 55.41537870679583, 56.391277517591206, 57.75338152476719, 56.97276183537075, 60.87230627877371, 57.62988076891218, 56.69518824986049, 57.27106537137713, 57.834248134068076, 59.84091567993164, 65.67358098711286, 66.28830896105084, 66.06060259682792, 68.35251453944615, 70.34138774871826, 75.2143748147147, 78.35419627598354, 78.38216277531215, 77.37828009469169, 4.048471697739192, 0.3941470687942845, 0.14478025186274732, 0.290406772600753, 0.09660605687115874, 0.06671257915773562, 0.0256162813332464, 0.40622431359120775, 0.8653024882078171, 0.5076932002391134, 0.058386798415865214, 0.03905278444290161, 29.456130572727748, 32.221312114170615, 63.54720292772566, 58.31400735037667, 27.152658564703806, 31.856149537222727, 42.63022082192557, 61.82380649021694, 62.560836655753, 68.68825844355992, 68.98765632084438, 51.619904381888254, 8.837635261671883, 0.1485943921974727, 0.11202110363436596, 0.05318763579374977, 0.020979283277743628, 0.062205898841576915, 0.05225880956277251, 0.04305438703990408, 0.030919595688049282, 0.04544477770105004, 0.045471515373459885, 0.03783615758376462, 0.09752909519842692, 0.051668307677443535, 0.053659638323421986, 0.05869156920484134, 0.10522370266595057, 0.17537293955683708, 0.1394648120871612, 0.13617489433714322, 0.27702538349798744, 0.14691129965441568, 0.10862024540879897, 0.1423456139330353, 0.13137974164315633, 0.2781213532601084, 0.196889814255493, 0.17513309099844523, 0.2397411870104926, 0.29119460604020525, 0.3225005018923964, 0.7861412273985999, 16.611635071890696, 103.84303746904645, 100.37307235172817, 88.18705763135637, 61.00649683816092, 67.2660664149693, 76.4159823826381, 93.82363782610211, 99.69148186274937, 115.00816031864711, 96.55072239467076, 33.37820455006191, 0.43605757132172585, 0.15176277075495037, 0.2330972978046962, 0.31907856836915016, 0.552694782614708, 0.306503061737333, 0.5236280251826558, 0.4234760392989431, 0.5095732850687844, 0.6455210873058864, 20.715456553867885, 108.14114448002407, 96.36580303737095, 93.12153625488281, 71.50376578739711, 79.63598605564663, 84.54795251573834, 95.76545783451625, 92.06582696097237, 94.37444237300328, 92.12711007254464, 87.50646073477608, 77.79295553479875, 76.52271366119385, 78.75915813446045, 77.54564135415214, 80.87095192500523, 78.73825100490025, 75.143127986363, 72.07535934448242, 72.60644490378243, 69.57826709747314, 67.93367018018449, 64.42800521850586, 64.67065020969936, 64.96089036124093, 62.34289945874895, 60.371792793273926, 61.80445575714111, 65.59222452981132, 61.8522732598441, 62.52701282501221, 63.67625182015555, 70.64744894845145, 78.27031067439488, 79.59763894762311, 77.14956624167306, 76.42819036756242, 80.86085619245256, 77.17950602940151, 77.41212477002824, 75.67094789232526, 81.97706345149449, 69.97380719866071, 72.96103232247489, 74.11133439200265, 75.38717651367188, 66.6601904460362, 70.24426582881382, 79.02456542423793, 71.70969649723598, 68.87101691109794, 74.70006220681327, 70.72319820949009, 77.8023008619036, 70.77730383191789, 76.0047185080392, 68.34353051866803, 71.0604498726981, 77.00216020856584, 74.54034396580288, 75.7707587650844, 73.87440776824951, 69.68143395015171, 69.6074217387608, 65.94121170043945, 61.548942702157156, 56.57792002814156, 59.801651409694124, 65.49055848802838, 68.73024640764508, 73.03140367780412, 77.67138290405273, 74.32483169010708, 77.13019466400146, 76.72130012512207, 70.41246782030377, 61.823493821280344, 57.32056086403983, 58.826207705906455, 60.68125861031668, 61.08087035587856, 58.41616671425955, 61.65710530962263, 60.705959456307546, 59.545436586652485, 60.826739992414204, 60.3290822165353, 63.91113567352295, 69.9963402066912, 69.45833424159459, 68.93985966273716, 74.48571028028215, 74.4552424294608, 81.12266431535993, 81.60127707890102, 81.47108173370361, 75.29873984200614, 2.991741670029504, 0.7774267750126975, 0.319213406848056, 0.3825974256864616, 0.2814467991037028, 0.3978172375687531, 0.1790538698967014, 1.372120378272874, 1.6399967755590166, 0.2520533949136734, 0.18365051038563251, 0.32315512533698765, 41.15739379610334, 40.12210873195103, 94.42458752223423, 98.42941801888603, 47.542795249394004, 35.572692326136995, 46.613487584250315, 75.8271017074585, 72.93344102587018, 81.02853012084961, 80.4587014062064, 62.16423348018101, 13.311948588916234, 0.21140768166099275, 0.21788941456803254, 0.1302406306245497, 0.1034341004810163, 0.15239091776311398, 0.09409232211432286, 0.15865045759294713, 0.11917476941432271, 0.1266455621059452, 0.12020592551146235, 0.2245576088981969, 0.2722807680921895, 0.17550540316317761, 0.10635426414332219, 0.2309720175606864, 0.22962436558944838], [0.03730567551351019, 0.06125063688627311, 0.06855700697217669, 0.047697290046406646, 0.02051775393608425, 0.06275235023349524, 0.028073821516175355, 0.07298658535416637, 0.13030321869466985, 0.07273490993039948, 0.028046128805726767, 0.12786030263773032, 0.026253944795046533, 0.13997460901737213, 0.5210006290248462, 29.029924597058976, 80.13292121887207, 69.83249473571777, 51.11999191556658, 43.78807210922241, 57.33310236249651, 55.32779318945748, 85.06066008976528, 83.37406131199428, 87.48977810995919, 55.2158716065543, 3.215261744601386, 0.2281583228281566, 0.03511146968230605, 0.023042972898110747, 0.08402111860258238, 0.028344616360430206, 0.19762618759913103, 0.07523776777088642, 0.11415221249418599, 0.39932103401848246, 0.8918961212038994, 55.73733391080584, 96.39854294913155, 86.15793350764683, 73.72364575522286, 74.46210724966866, 83.67600222996303, 86.48206002371651, 87.59395245143345, 86.47119304112026, 87.55404199872697, 82.18093054635185, 80.74571064540318, 76.29817567552838, 75.85350486210415, 76.30579090118408, 79.10101645333427, 78.43496213640485, 79.82442814963204, 75.9766616821289, 69.4092104775565, 65.99311474391392, 61.617285183497835, 56.875035422188894, 56.45815045492989, 55.39373854228428, 55.951480865478516, 53.863936288016184, 56.88069472994123, 56.00958170209612, 54.329569816589355, 54.343719823019846, 57.04159416471209, 58.75555147443499, 64.1113132749285, 71.7411162512643, 72.67587130410331, 72.15672969818115, 74.11174433571952, 72.6378299168178, 71.020108631679, 73.01164994921002, 71.8032123020717, 74.29734461648124, 69.32601969582694, 65.15302889687675, 63.064588001796174, 54.65479414803641, 59.74943569728306, 68.06459508623395, 71.42197159358433, 57.37771674564907, 62.483593532017295, 73.44375841958183, 59.6262788772583, 62.90775326320103, 64.47874096461705, 64.36063548496791, 69.83060482570103, 67.01752935137067, 63.93047251020159, 66.90916524614606, 62.213683809552876, 61.08355236053467, 53.75803879329136, 50.3371661731175, 50.3680648122515, 54.756929193224224, 50.47223915372576, 50.295536041259766, 50.50670569283621, 56.84790618079049, 65.40360178266252, 67.73642471858433, 67.006669316973, 66.94943700517926, 69.7066489628383, 64.40026106153215, 56.034487519945415, 51.61703130177089, 52.00486585072109, 52.82138340813773, 53.394050461905344, 56.30210781097412, 54.043064321790425, 50.27341645104544, 54.530810492379324, 54.935886996132986, 55.16498647417341, 51.88960913249424, 54.89464248929705, 57.715757029397146, 62.21946471078055, 62.10553509848458, 65.12348515646798, 63.47965254102434, 72.51768166678292, 70.53858457292829, 83.33210114070347, 37.709673336574006, 0.2447654131267752, 0.3026702074067933, 0.0627323402357953, 0.15966922364064626, 0.039976701473018954, 0.14740971076701367, 0.4473008694393294, 0.38200319185853004, 0.387454162218741, 0.12021303655845778, 0.3513428813644818, 5.159014003617423, 29.31996325084141, 46.62267310278756, 88.86244337899345, 73.66678864615304, 25.679108926228114, 18.021975210734777, 33.05219507217407, 49.21039765221732, 58.74362141745431, 57.45784684589931, 55.8217579977853, 46.06669909613473, 8.848353726523262, 0.0833715298878295, 0.09181269550962107, 0.040459699662668366, 0.0828919413366488, 0.07196108145373208, 0.05973061666424785, 0.05711759866348334, 0.007821719128904598, 0.0264261824278427, 0.028420793790636317, 0.08786949781434876, 0.038899686586643965, 0.06551340421927826, 0.1707417480647564, 0.11900205511067595, 0.08425456179039818, 0.06703803169408015, 0.03816828351201756, 0.06271404014634234, 0.010243690506156002, 0.057405643564249785, 0.05948436952063015, 0.045971324268196306, 0.046156845920320065, 0.04518304978098188, 0.01885980959715588, 0.07983353294964347, 0.035328631422349384, 0.1295968365988561, 0.4760344390358244, 37.140195505959646, 92.7468546458653, 79.31260994502476, 61.81501701899937, 46.33894688742501, 55.16097041538784, 57.63922957011631, 75.83283397129604, 91.95501708984375, 96.64482879638672, 66.55627318790981, 4.1199182868003845, 0.45558746478387285, 0.29543821832963396, 0.19287355190941266, 0.017344518764210597, 0.1259932999632188, 0.43465362808534075, 0.7222301768405097, 0.2870450115629605, 0.7060238836067063, 2.3626997556005205, 62.392766680036274, 101.8907812663487, 89.88421072278703, 78.92850657871791, 81.71810409000942, 90.12807164873395, 89.98098523276192, 92.06364522661481, 90.55785247257778, 91.00381565093994, 86.1767144884382, 85.08697291782924, 81.95543370928083, 81.11878027234758, 78.8639578138079, 83.49838542938232, 82.93283680507115, 84.96150929587228, 80.84998226165771, 73.4108725956508, 68.93902587890625, 64.27552005222866, 59.27363000597273, 59.52297306060791, 58.22347232273647, 58.95696585518973, 56.21753781182425, 57.886821678706575, 58.60838862827846, 56.173208304813926, 57.40475566046578, 58.80277838025774, 62.638058934892925, 66.80337197440011, 73.69374765668596, 75.82859557015556, 74.07267461504254, 75.88229819706508, 75.8007402420044, 73.75877584729875, 75.8532964161464, 73.45677934374127, 77.26341247558594, 74.07269545963833, 69.15656008039201, 67.24949496132987, 58.24428217751639, 64.69394057137626, 72.71029267992292, 72.16085692814418, 61.57752759116036, 69.93524469648088, 78.28578431265694, 69.7089627129691, 64.39055442810059, 67.37577152252197, 67.0925212587629, 74.18649305616105, 70.90520627158028, 66.8978396824428, 67.63221563611711, 64.79760074615479, 62.43648474557059, 56.34476975032261, 53.249437604631694, 52.78687865393502, 55.6681889125279, 54.886183057512554, 53.97784505571638, 53.596270833696636, 57.90742656162807, 68.49525138310024, 69.52231325422014, 68.599043573652, 68.99560506003243, 71.27664307185582, 67.40367548806327, 59.699214117867605, 55.52380881990705, 54.18507855279105, 54.94556583677019, 56.50484234946114, 58.65337821415493, 56.04614312308175, 53.077497482299805, 57.096533570970806, 58.27665383475167, 58.23407874788557, 55.921492440359934, 57.44172007696969, 60.38978167942592, 63.35411248888288, 64.99651377541679, 67.25899314880371, 69.38986669267926, 74.99966158185686, 76.17084993634904, 85.89413125174386, 48.153274399893625, 0.13522517601294176, 0.17398293342973503, 0.3113616710262639, 0.22989010704415186, 0.3308406743620123, 0.2575593537517956, 0.3234863861330918, 1.0866753522838866, 1.5012692596231187, 0.7086262011102268, 0.4750538745096752, 4.695792368480137, 36.68585280009678, 53.138217789786204, 78.2410101209368, 53.19669730322701, 31.788731166294642, 28.64964621407645, 48.17531061172485, 61.143147059849326, 70.20829500470842, 65.93346445901054, 65.90717247554234, 55.81121410642351, 9.996465376445226, 0.06675588326262576, 0.07181912514248065, 0.03257081065593021, 0.027327831634985547, 0.03582644203145589, 0.08068575257701532, 0.023350825932409083, 0.025129875201465826, 0.06820446731788771, 0.01099904247426561, 0.05026696662285498, 0.0310353062647794, 0.052013485226780176, 0.12943283468484879, 0.12918293023748056, 0.24084185223494256, 0.2304785597537245, 0.16268855519592762, 0.1671349408903292, 0.10817092630480017, 0.13568828973386968, 0.18588276846068247, 0.21917967604739325, 0.3771521550204073, 0.2062127904168197, 0.10317631824208157, 0.2464941032230854, 0.1439761607242482, 0.2326754932957036, 0.6039558776787349, 49.31632988793509, 102.10748863220215, 88.43171760014125, 70.88435472760881, 58.630754879542756, 69.10796437944684, 71.89879172188895, 109.19603388650077, 101.84404073442731, 104.22547326769147, 82.15084484645298, 5.803156307765415, 0.5118324809840747, 0.15138117623116287, 0.28434957191348076, 0.2743739400591169, 0.4980135996426855, 0.672309866973332, 1.0011958990778242, 1.0790552411760603, 2.280762038060597, 2.5076304929597035, 61.44749205453055, 106.15305641719273, 93.50170694078717, 81.19089562552315, 82.60827950068882, 93.49473789760044, 93.38344860076904, 97.8303999219622, 94.1322420665196, 96.33897604261125, 88.82316521235875, 87.96749455588204, 85.54882662636894, 84.74737971169608, 81.10960865020752, 86.89633246830532, 86.66286604745048, 89.48901108333042, 83.0910542351859, 75.89469378335136, 72.46198490687779, 68.48685101100376, 62.082335063389365, 64.35890538351876, 60.4574293409075, 63.33381680079869, 59.02497482299805, 62.9579678944179, 61.10056849888393, 59.88772569383894, 60.11322947910854, 62.639990534101216, 65.012953213283, 71.84590203421456, 76.87017222813198, 78.61228016444615, 76.95518343789237, 78.63246468135289, 80.5393977846418, 77.4444477898734, 77.33477047511509, 76.25497872488839, 79.83963775634766, 76.45799119131905, 71.90202958243233, 70.36037022726876, 62.71377345493862, 65.91332857949394, 75.06163951328823, 79.89042908804757, 65.70516749790737, 65.1231585911342, 74.80548027583531, 65.59499686104911, 70.76125349317277, 72.89190469469342, 69.76142856052944, 75.23879773276192, 72.00284099578857, 70.00068977900914, 72.27457809448242, 69.17698083605084, 67.7320751462664, 60.60494654519217, 56.928331579480854, 54.72158718109131, 59.479560715811594, 58.24031823022025, 56.93894495282854, 58.01535293034145, 62.430780274527415, 71.70762593405587, 73.88311386108398, 71.7753986631121, 70.86558764321464, 74.40603528703961, 71.46698202405656, 63.66393266405378, 57.56590175628662, 57.15784794943673, 59.27962630135672, 57.98565980366298, 63.034703799656455, 59.43509224482945, 55.4877233505249, 59.78626114981515, 61.18596880776541, 60.98409584590367, 58.40722438267299, 62.16241305215018, 63.83679689679827, 67.7930247443063, 69.28301729474748, 71.06427138192313, 71.42313194274902, 77.60706342969621, 77.08775506700788, 88.59040055956159, 45.37420340946743, 0.38909933822495596, 0.7374339210135596, 0.2486296429165772, 0.3462177978030273, 0.2184846933398928, 0.5454074793628284, 0.914299121924809, 2.651877701282501, 0.9738396470035825, 0.532574970807348, 0.6104322501591274, 7.451163922037397, 46.58083799907139, 60.29438986097063, 102.84547070094517, 93.07460812159947, 38.84317813600813, 26.165225744247437, 56.648385184151785, 67.22720514025006, 80.90946578979492, 75.81855542319161, 75.63253130231584, 67.17001451764787, 15.300442252840314, 0.1971821542829275, 0.12441156698124749, 0.1097930253350309, 0.17567543046815054, 0.15110065628375324, 0.1676568700266736, 0.16457201912999153, 0.11493034288287163, 0.1686702077942235, 0.10034276957490615, 0.19734375418296882, 0.13297108268099173, 0.1788504450981106, 0.2244781931596143, 0.205577070957848], [0.03530150019962873, 0.044668394540037425, 0.02561688862208809, 0.0715368545747229, 0.045235293584742715, 0.021224497351795435, 0.028258820696334754, 0.05887739959039858, 0.05559105093457869, 0.09918850686933313, 0.14016204753092357, 0.1131387050928814, 0.0478175976978881, 0.04255448315026505, 0.8192424454859325, 56.752507414136616, 76.49194008963448, 68.33904893057687, 46.67711918694632, 37.08013180324009, 78.01712526593889, 75.05036953517369, 65.23027896881104, 94.31498663766044, 75.28440570831299, 27.207797731672013, 0.265398984508855, 0.07608928172183888, 0.2715371751359531, 0.05789710647825684, 0.18821961592350686, 0.025284869563100592, 0.14392949108566555, 0.15366946772805282, 0.36879903610263554, 0.08750175219029188, 12.064269253185817, 77.18360546657017, 92.86134706224713, 82.60078239440918, 79.14443574632917, 86.76009219033378, 87.83249800545829, 87.91327776227678, 91.6249429157802, 90.50078691755022, 86.56723799024309, 82.5056129183088, 81.28395284925188, 80.2376514162336, 78.97241919381278, 79.75099263872418, 80.11088153294155, 81.87491798400879, 83.76705837249756, 76.62654754093715, 76.78305571419853, 66.25119863237653, 57.2440299306597, 57.3222735949925, 55.550691400255474, 52.977269717625205, 54.650701659066335, 55.47280556815011, 61.445935658046174, 60.63091891152518, 59.81048951830183, 57.954865387507844, 53.49093614305769, 55.42227479389736, 60.65917723519461, 68.98537731170654, 75.72313581194196, 68.64825071607316, 73.26774665287563, 74.0431239264352, 70.43348612104143, 68.4280206135341, 70.59312098366874, 76.19000611986432, 69.70323739733014, 64.24694211142403, 60.86280114310128, 53.60294805254255, 62.64329787663051, 70.36285768236432, 71.0632222039359, 44.65499537331717, 34.37784535544259, 42.93640014103481, 43.45845651626587, 62.044828687395366, 59.06567737034389, 64.89655699048723, 65.84116458892822, 61.86317498343331, 58.202912603105815, 64.97542599269322, 62.77181870596749, 59.1620488848005, 52.349197728293284, 50.77555234091622, 50.24258381979806, 51.841187136513845, 49.384335381644114, 50.5087936265128, 47.92295898709978, 50.60073913846697, 57.38389022009713, 68.54369422367641, 66.15700885227749, 69.07605825151715, 66.93024608067104, 67.32222870418003, 54.024599484034944, 51.347906725747244, 52.63912173679897, 52.16693605695452, 54.44732788630894, 52.180026463099885, 51.19828769138881, 60.14141137259347, 56.34314039775303, 56.388678891318186, 55.02208634785244, 54.29182025364467, 54.52267415182931, 54.24632692337036, 56.441304547446116, 65.7076757975987, 62.927479199000764, 67.50773865836007, 68.06975759778703, 75.10230731964111, 70.7863712310791, 82.7268921988351, 6.3020864725112915, 0.41701638592141016, 0.22543855091290815, 0.025118440190064054, 0.33471890911459923, 0.24113166811210768, 0.23673611826130322, 0.5118069680673736, 1.1032583138772418, 0.1754034464912755, 0.026432708238384554, 0.14119122230580874, 16.892340557915823, 40.92974649156843, 78.6156917299543, 84.37330259595598, 46.690800189971924, 18.90569748197283, 20.07371919495719, 27.478859118052892, 42.178778988974436, 51.571940967014854, 54.91883264269148, 52.497249943869456, 48.955242429460796, 7.331020883151463, 0.07556387848619904, 0.015797090816444585, 0.03479248697736433, 0.07147817486631018, 0.02600620487438781, 0.01998794191916074, 0.05868641233869961, 0.035319298173167875, 0.008207872559848641, 0.02829373301938176, 0.041218400201095004, 0.031364273612520525, 0.05190219869837165, 0.0929704662412405, 0.04773040934066687, 0.0635353389329144, 0.024450822799865688, 0.01241967682394066, 0.0498564461512225, 0.025468937453946898, 0.008198109289099063, 0.016014595216672336, 0.03777544905564614, 0.09945742386792387, 0.03331498715228268, 0.05293117669810142, 0.05043451388233474, 0.08127127401530743, 1.094439529946872, 67.04976899283272, 88.3980188369751, 79.45913355691093, 53.840329783303396, 42.2678097316197, 87.2990083694458, 57.056650911058696, 71.65819644927979, 106.33109010968889, 86.14664268493652, 33.24406262806484, 0.03367951312767608, 0.2337769999035767, 2.0239118891102925, 0.291199654340744, 0.29546164135847774, 0.1366885317755597, 0.3866341662194048, 0.6852906218596867, 0.6063221735613686, 0.14749270917049476, 14.625405652182442, 83.10039956229073, 98.00054740905762, 85.64726175580705, 83.21995026724679, 91.3580139705113, 92.48742975507463, 92.75378894805908, 93.36898245130266, 93.29993125370571, 88.35380744934082, 86.34623663766044, 85.45474106924874, 85.30368723188127, 82.10545921325684, 84.30635670253209, 84.94993359701974, 84.45570823124477, 86.46833038330078, 80.15513460976737, 79.99757031032017, 68.55891077859062, 59.985736983163015, 58.95870985303606, 56.78136328288487, 56.38454818725586, 57.06708015714373, 59.105115345546174, 63.897016933986116, 64.23003019605363, 63.719476563589915, 59.64307962145124, 56.50804894311087, 56.794266087668284, 63.771268435886924, 70.61252035413469, 75.86943708147321, 73.05768871307373, 74.40706362043107, 76.75517954145158, 71.35618604932512, 71.78939928327287, 73.60879898071289, 77.43786089760917, 70.69692012241909, 69.1541976928711, 63.14868204934256, 58.005941595349995, 65.71700722830636, 74.26114450182233, 69.67097691127232, 52.73866510391235, 43.79936988013131, 53.836212975638254, 51.647850036621094, 65.13187163216728, 62.74530438014439, 66.51484107971191, 68.21202196393693, 68.10265731811523, 64.14645031520298, 68.61813027518136, 66.3324647630964, 64.04926586151123, 57.94705213819231, 52.85872997556414, 51.91451495034354, 53.45233195168631, 52.121647698538645, 54.404669421059744, 51.94020244053432, 54.37799876076834, 59.391485350472585, 73.19725022997174, 68.84636470249721, 72.57225976671491, 71.46830912998745, 69.1727215903146, 58.05598946980068, 54.32544953482491, 55.49105848584856, 55.12796994618007, 57.00060326712472, 52.86131817953927, 54.82860333578927, 62.798597063337056, 61.56825174604143, 58.8969612121582, 57.99795116697039, 58.20449679238455, 56.00338043485369, 57.04816716057913, 59.5454991204398, 68.03486374446324, 66.47593116760254, 70.61566093989781, 71.05469676426479, 79.63350554874965, 73.78588771820068, 88.91039984566825, 11.17583089215415, 0.5671144660030092, 0.4248490956212793, 1.559855927314077, 0.949047714471817, 0.8247409132974488, 0.2650983934955937, 0.6087431322251047, 0.8166339940258435, 0.8545761523502213, 0.09774652495980263, 0.0698988778250558, 17.085139172417776, 50.81226314817156, 81.03168460300991, 77.34356689453125, 38.922898292541504, 26.13798359462193, 27.641533817563737, 37.781910283224924, 51.84077719279698, 58.951594897678916, 63.81393732343401, 61.7432073865618, 58.98501573290144, 8.719156316348485, 0.0759395629699741, 0.040488150636000295, 0.05595055575083409, 0.037184855568089654, 0.016963969184351817, 0.0370948682539165, 0.0449447245337069, 0.01187106005714408, 0.05104464239307812, 0.03554746914388878, 0.05583413949768458, 0.0652400835284165, 0.04946016473695636, 0.059336326750261445, 0.13625699707439967, 0.1784935085369008, 0.09401130503309624, 0.18099644780158997, 0.11739878542721272, 0.15223214056875023, 0.09259450355810778, 0.14753800816833973, 0.16687367776674883, 0.32094869230474743, 0.21043154118316515, 0.1717667837760278, 0.13126060446458204, 0.16950253956019878, 2.552897138254983, 83.7757088797433, 97.56534004211426, 90.1783835547311, 66.41830280848912, 52.17796284811837, 85.82688658578056, 89.32281712123326, 82.8219574519566, 112.7034775870187, 97.0730254309518, 43.593751839229036, 0.578237554856709, 0.18630005392645085, 1.35039108140128, 0.32164177511419567, 0.5872546338609287, 0.3241262989384787, 0.9107579290866852, 1.9366692219461714, 1.6311047098466327, 0.4319514302270753, 14.549992510250636, 87.59766278948102, 101.8348274230957, 90.42856039319719, 87.18828882489885, 96.45928410121373, 94.81635475158691, 96.61704989842006, 96.84314428056989, 97.85444068908691, 90.76311615535191, 88.36614050183977, 87.27344594682965, 87.62414932250977, 88.02120413099016, 87.87504877362932, 87.62407289232526, 89.81681319645473, 91.04095377240861, 83.68472916739327, 84.85106767926897, 73.4078779220581, 64.56119523729596, 64.83428028651646, 60.66138676234654, 58.525392396109446, 61.37638419015067, 63.03491224561419, 68.45634147099086, 67.76535701751709, 65.28596183231899, 64.31799439021519, 59.81214318956648, 60.23004259381975, 68.0454250063215, 76.55763530731201, 79.9706529889788, 73.86056695665631, 77.55301339285714, 79.67825889587402, 76.56122057778495, 73.8575792312622, 76.82889992850167, 81.97923823765346, 74.09451975141252, 70.62333175114223, 65.11408424377441, 59.758871350969585, 69.39484855106899, 75.50201633998326, 77.5182237625122, 56.427540166037424, 46.100991930280415, 57.0115327835083, 50.5281582559858, 76.11225577763149, 66.35185718536377, 69.34303583417619, 70.96247332436698, 69.74102864946637, 64.90230315072196, 71.01525184086391, 70.73904010227749, 68.27822440011161, 59.50934764317104, 55.89992870603289, 55.99996886934553, 59.33712959289551, 56.32210125241961, 58.519326618739534, 52.669634750911165, 56.96811696461269, 63.662390163966585, 76.87413964952741, 72.56049646650041, 77.66783237457275, 74.29343972887311, 76.03947339739118, 61.7834860937936, 58.348414829799104, 60.29297937665667, 60.73121615818569, 59.87127930777413, 58.00457280022757, 57.43067244121006, 67.24188668387276, 64.16479355948312, 61.72771290370396, 60.60117367335728, 60.646927561078755, 58.785588536943706, 60.428851400102886, 62.33526338849749, 71.68523188999721, 70.43342358725411, 75.07222856794084, 73.75353690556118, 82.2857232775007, 75.91423906598772, 91.21486023494175, 9.248444029263087, 0.7162257390362876, 1.4554894247225352, 1.0801824778318405, 0.6587093653423446, 0.9440318750483649, 0.6527364658457893, 2.786177694797516, 4.4596617477280756, 0.5079559832811356, 0.25092941522598267, 0.19757517533642904, 26.638672522136144, 58.122424670628135, 94.5380585534232, 100.21047755650112, 65.73362037113735, 29.425964968545095, 29.0820152418954, 42.624054295676096, 62.18455001286098, 70.48841163090297, 73.78713839394706, 70.26433917454311, 69.20713601793561, 11.7223926952907, 0.22659325466624328, 0.10239660686680249, 0.17272228321858815, 0.195826224184462, 0.0736165711922305, 0.057901958003640175, 0.10143752475934369, 0.09228811107043709, 0.24655712555561746, 0.15490704774856567, 0.16514601904366696, 0.12332390248775482, 0.06935246035988842, 0.14747242097343716], [0.015250937979934471, 0.029697157176477567, 0.03952776574130569, 0.04592063091695309, 0.05925222233469997, 0.06374248210340738, 0.02144135205474283, 0.05795163355235543, 0.028938483779451678, 0.14702608063817024, 0.048035461721675735, 0.13403286784887314, 0.2328147015401295, 0.29952264630368775, 18.305015291486466, 81.48465851375035, 63.78322628566197, 59.626820836748394, 40.46111134120396, 35.145298208509175, 34.183410440172466, 71.93499183654785, 92.30979210989815, 82.73853043147496, 54.12820407322475, 4.691933512687683, 0.3086596360164029, 0.3644681642098086, 4.915154380457742, 0.3609904551080295, 0.045335716767502685, 0.038702826614358594, 0.3539593123963901, 0.6148317083716393, 0.11778438330761024, 0.5637785707201276, 29.397359234946116, 85.94021170479911, 86.67895112718854, 84.17616830553327, 87.26018878391811, 86.299530846732, 90.20340401785714, 94.7684886114938, 87.52679811205182, 85.42660086495536, 85.83327198028564, 81.9930443082537, 87.3120779309954, 80.9370015008109, 80.48121356964111, 80.3511710848127, 80.69704546247209, 79.91433089120048, 79.1114387512207, 76.00929042271206, 69.50200366973877, 56.94976677213396, 56.85862725121634, 54.49726806368147, 52.228563104357036, 52.86439275741577, 60.16282572065081, 62.597516196114675, 67.69396427699498, 69.49171338762555, 70.76787512642997, 61.46557821546282, 58.26883711133684, 53.26960475104195, 56.619452885219026, 61.31981890542166, 68.88574709211076, 73.12416907719204, 69.1396620614188, 73.00693907056535, 71.64268112182617, 68.95752198355538, 72.69784150804792, 67.90206282479423, 73.67722484043666, 68.16643483298165, 66.56128978729248, 60.474660873413086, 67.77019991193498, 66.16216441563198, 72.41281250544957, 42.668626989637104, 18.313724858420237, 21.28861345563616, 32.44015952519008, 54.63924755368914, 54.79008599690029, 66.26351778847831, 61.564944403512136, 59.24608039855957, 57.73616736275809, 66.06064428601945, 63.233964238848, 61.95171587807791, 58.99395111628941, 57.39731413977486, 53.50443301882063, 54.60598652703421, 53.912789072309224, 54.99054847444807, 54.9508638381958, 51.23501934323992, 53.084904261997764, 63.05101816994803, 66.2757396697998, 70.32765810830253, 68.35327189309257, 64.71077605656215, 55.90540736062186, 48.380369322640554, 51.438445227486746, 51.00019454956055, 53.45527451378958, 52.008009910583496, 56.236895493098665, 61.25654860905239, 65.81939588274274, 62.949331283569336, 56.83885267802647, 53.5528758593968, 52.18336507252285, 54.292952810014995, 60.19207763671875, 64.15024403163365, 65.97274262564522, 67.10263783591134, 67.43968800136021, 74.36715316772461, 70.3591126033238, 81.81346811567033, 47.21897445406233, 0.13461837571646484, 0.9368215990918023, 2.061663406235831, 0.2515743491905076, 0.49931687542370384, 0.2608990216893809, 1.096951955131122, 2.568964413234166, 1.991284885576793, 0.09494973253458738, 0.17794928273984364, 1.9941475433962685, 43.68843494142805, 59.563640866960796, 75.89800807407924, 81.05336298261369, 50.73495749064854, 21.25909229687282, 24.288157735552105, 35.519698415483745, 50.24526235035488, 58.609590666634695, 55.127876145499094, 59.908424377441406, 51.39961174556187, 3.8561707479613165, 0.06885629519820213, 0.10048150284481899, 0.04978296080870288, 0.04411995504051447, 0.06045972289783614, 0.03164966544136405, 0.04348217622776117, 0.0391059069495116, 0.03541677312127181, 0.03466246948976602, 0.013390342372336557, 0.03932466324684875, 0.03483048833108374, 0.029953460209071636, 0.06890001999480383, 0.035510149717863114, 0.028351764726851667, 0.032262063651744805, 0.07722259126603603, 0.03172857227868267, 0.06046128352837903, 0.06440142103071723, 0.11810461112431117, 0.08662997718368258, 0.07646968880934374, 0.30604760189141544, 0.5674556876931871, 21.916949476514542, 94.52200126647949, 73.456529208592, 67.93877015795026, 49.800181593213765, 38.354056222098215, 39.0978296143668, 72.03849220275879, 97.75878483908517, 93.60842432294572, 60.674650873456685, 6.505382512296949, 0.6787125776920999, 0.2470923811197281, 4.221878324236188, 0.47104530675070627, 0.13063344811754568, 0.05119166396824377, 0.7285190565245492, 0.1408809825245823, 0.3358666103865419, 0.8512789607048035, 33.85342311859131, 88.13636357443673, 90.60799067361015, 88.0393180847168, 91.58147498539516, 90.89153970990861, 94.55119064876011, 97.10549436296735, 90.79343809400285, 88.36144351959229, 89.98450796944755, 85.92518275124687, 89.54925196511405, 85.1110623223441, 84.06351021357945, 82.92014939444405, 85.06799043927873, 84.45466600145612, 80.56045082637242, 80.03677899496896, 72.27115263257707, 59.77221189226423, 58.95011493137905, 54.87879017421177, 55.95668159212385, 56.865773473467144, 63.39327948434012, 65.0138773236956, 71.1460794721331, 71.9298015322004, 74.66684981754848, 65.64182771955217, 60.96127101353237, 56.61899430411202, 58.46274743761335, 62.669103486197336, 70.91767828805106, 76.36390563419887, 71.73245879581997, 76.35555389949253, 74.00334548950195, 71.75017670222691, 74.73764501299176, 72.94146619524274, 75.05997889382499, 70.8895102909633, 70.04059328351701, 61.52882071903774, 69.02626051221574, 70.6919174194336, 74.95858383178711, 50.27164118630545, 27.911271572113037, 32.2685181753976, 41.33832141331264, 58.64457484654018, 58.229461669921875, 66.79852907998222, 66.76621995653424, 62.230171884809224, 61.3809700012207, 69.20587839399064, 67.30988870348249, 66.58981214250836, 61.85472597394671, 60.98282432556152, 56.92690372467041, 57.03571251460484, 56.85789769036429, 58.91178866795131, 59.661165782383506, 54.87369367054531, 56.08996541159493, 65.73168877192906, 70.36691543034145, 73.78423404693604, 71.886152948652, 67.13008322034563, 59.13634055001395, 53.29971824373518, 54.8464914730617, 53.22824559892927, 54.457777976989746, 54.01402085168021, 58.857516288757324, 65.70966298239571, 69.06439917428153, 64.62362480163574, 60.2123316356114, 56.97887972423008, 54.663958821977886, 56.27615976333618, 63.117436000279014, 66.38086591448102, 69.26436832972935, 70.85706220354352, 71.65743214743478, 75.53971031733921, 73.62984507424491, 81.49988896506173, 55.33949395588466, 0.24733849934169225, 0.6916019203407424, 2.6204607699598585, 0.8182653550590787, 1.127331976379667, 0.5942655833704131, 1.3148121791226524, 0.9151928339685712, 3.729279705456325, 0.9582199880055019, 0.23205677792429924, 1.5850668145077569, 47.11445270265852, 66.19855907985142, 74.82697105407715, 65.29981654030937, 40.6509986604963, 26.544738088335308, 33.56856434685843, 45.00813409260341, 59.245038168770925, 67.49477331978935, 64.1643488747733, 69.24594865526471, 60.04617936270577, 4.912567479269845, 0.11027053078370434, 0.11511277380798544, 0.038401041379464526, 0.03471529683364289, 0.019408250793016384, 0.030505353451839516, 0.030167392122426202, 0.026045305454837422, 0.07033603758152042, 0.04165619778047715, 0.030722053788070167, 0.07558897749653884, 0.07470724838120596, 0.11142654410962548, 0.18732551032943384, 0.10814795110906873, 0.10571538271116358, 0.11273153658424105, 0.12854533802185739, 0.1405371959720339, 0.24586795110787663, 0.16750557028821536, 0.23130327835679054, 0.2878830023109913, 0.3366222269833088, 0.38642876009855953, 0.6790346375533513, 27.6454439163208, 108.90961524418422, 82.93009921482631, 81.49348967415946, 60.123943601335796, 51.194393226078574, 41.25712129047939, 91.0373615537371, 114.06627641405377, 99.35747500828334, 76.11814090183803, 9.557162914957319, 0.6157864885670798, 0.9494122777666364, 8.956224509647914, 1.0446048783404487, 0.3661796466580459, 0.2410948100898947, 1.5957790911197662, 2.369750874383109, 1.7714577785560062, 0.7930281407066754, 34.52432380403791, 95.90239988054547, 94.64191327776227, 90.80219977242606, 93.74947275434221, 93.99413967132568, 97.95024939945766, 102.1906863621303, 93.875839642116, 90.72943128858293, 93.40810775756836, 88.7558719090053, 93.30579553331647, 84.83289119175502, 87.34367833818708, 86.35272625514439, 87.55400030953544, 88.14643151419503, 84.49348558698381, 83.51765973227364, 77.84489331926618, 63.00413867405483, 63.733101981026785, 59.679293632507324, 58.11005687713623, 59.730189187186106, 67.10575062888009, 69.66228471483502, 73.37631920405796, 77.16360855102539, 78.69986915588379, 67.32472310747418, 63.55514471871512, 60.57813344682966, 62.53025763375418, 67.67341150556291, 76.7171937397548, 79.00477000645229, 76.16388089316231, 77.86750970567975, 76.62527602059501, 76.13273211887905, 78.85327843257359, 75.42744132450649, 80.35374191829136, 77.11688191550118, 71.6664092200143, 65.65198598589215, 72.90061773572648, 74.6288640158517, 80.45905576433454, 52.3254348891122, 27.505456822259085, 34.39631019319807, 41.16241039548601, 67.0759220123291, 61.27647604261126, 71.80021068028041, 68.3716846193586, 65.01034763881138, 63.24665859767369, 72.08180727277482, 68.97073745727539, 67.80863734654018, 62.92934826442173, 62.28438867841448, 59.91324642726353, 61.52922371455601, 59.004394258771626, 62.1765387398856, 63.15280927930559, 58.292016301836284, 60.036271231515066, 68.64422076089042, 72.00546741485596, 75.42637130192348, 75.4018372126988, 71.26556764330182, 62.916271754673545, 55.77005992616926, 56.7183952331543, 56.237402711595806, 59.32426847730364, 57.20907701764788, 61.36376626150948, 68.63679313659668, 71.07540239606584, 67.12459414345878, 63.33064842224121, 60.78391129629952, 57.480873176029746, 61.38016401018415, 65.46755300249372, 69.39673846108573, 73.35526616232735, 72.93069648742676, 74.21047128949846, 79.28695024762834, 76.30289350237165, 86.72089740208217, 55.91004875728062, 0.24668591150215693, 3.4821828731468747, 6.300207419054849, 4.055220569883074, 1.4836031390087945, 0.8557776478784425, 3.1258727354662756, 7.981045705931527, 4.966501133782523, 0.4613533296755382, 0.2841048107615539, 3.2913740490164076, 61.98130825587681, 70.66978740692139, 89.43772642953056, 98.39678233010429, 69.85716084071568, 32.18677609307425, 36.55992712293352, 51.790437494005474, 67.92379678998674, 77.73281192779541, 72.85269601004464, 77.45356382642473, 68.82053130013603, 5.576121747493744, 0.20702258124947548, 0.28967989874737604, 0.23106766385691507, 0.12675731682351657, 0.12946434585111483, 0.07328674210501568, 0.2065476474485227, 0.13916536101273128, 0.2218544203788042, 0.15330383234790393, 0.12296410250876631, 0.1527841423771211, 0.1619618306202548], [0.025051365307133113, 0.013124466906966907, 0.06167995956327234, 0.06681819313338824, 0.07306667962776763, 0.05610943811812571, 0.033217630947807004, 0.014648856894512261, 0.03394158370792866, 0.0505266080477408, 0.014642746686669332, 0.029205656943044493, 0.10450921886201416, 0.018410734765763794, 46.12142310823713, 72.43588747297014, 67.95948273794991, 52.71598270961216, 36.18074655532837, 28.27381294114249, 25.462333815438406, 53.248384952545166, 87.94626086098808, 76.85243347712925, 24.216363736561366, 0.15442796131329878, 0.0069669961313983154, 1.0198682057006019, 2.8341002890041898, 0.4994536138006619, 0.391677554164614, 0.22632454122815812, 0.16778699947255, 0.3352331300931317, 0.05528076026322586, 2.2940932427133833, 41.31357192993164, 83.38547025408063, 87.51836994716099, 89.27569443838937, 89.10723536355155, 90.93518134525844, 92.30765206473214, 87.67971406664167, 88.53874765123639, 83.28943920135498, 80.03185967036656, 79.48009627205985, 80.34360449654716, 79.78550434112549, 81.53117670331682, 79.33620602743966, 75.75832843780518, 74.94941915784563, 75.69416877201625, 65.5340472630092, 58.14092424937657, 54.60525696618216, 56.837674958365305, 53.647190707070486, 54.299470220293315, 57.22173316138131, 63.47410787854876, 63.198000362941194, 70.06801782335553, 67.53209904261998, 73.09440994262695, 67.67128535679409, 61.23530796595982, 58.17663104193551, 54.90495014190674, 56.93747888292585, 62.87856388092041, 68.90639019012451, 71.65224184308732, 71.17414324624198, 73.575503213065, 70.01638575962612, 67.30184268951416, 66.01421642303467, 66.73578684670585, 65.14241899762834, 67.72996289389474, 60.58369895390102, 64.72708347865513, 61.89340659550258, 66.70944622584751, 42.76617622375488, 20.96683543069022, 16.039857387542725, 28.490082570484706, 53.81922810418265, 52.092892578669954, 64.91391359056745, 61.07256725856236, 58.22754744121006, 55.10869564328875, 62.37462493351528, 63.8825021471296, 67.8767157963344, 67.62487139020647, 63.433141299656455, 62.213329451424734, 60.9205823625837, 61.01488331386021, 65.23705346243722, 64.02356447492326, 57.849940640585764, 56.045566422598704, 63.528831890651155, 67.62658064705985, 68.3331082207816, 68.08143057141984, 64.78635161263603, 59.47491237095424, 48.55832658495222, 49.28695637839181, 50.40346935817173, 51.22814757483346, 52.16369819641113, 61.677338463919504, 67.5485315322876, 70.68274579729352, 63.069931166512625, 59.27258082798549, 54.161572796957834, 53.81574705668858, 51.27351931163243, 60.50344031197684, 64.3752475466047, 65.29091589791435, 67.25979219164167, 69.89783559526715, 67.10331181117466, 73.0761639731271, 69.67500686645508, 78.3574549811227, 11.952533534594945, 1.3318263632910592, 1.5270191750356128, 3.78412835087095, 0.844976293189185, 0.2095865343830415, 0.07160424667277507, 0.766121621642794, 1.3812029766184943, 0.6011908746191433, 0.12994812774871076, 0.29273148785744396, 16.226908104760305, 42.26088237762451, 59.67857101985386, 89.62730802808488, 74.28563690185547, 32.61702939442226, 15.061830690928868, 16.242710045405797, 27.2583806174142, 59.0028726032802, 62.19605622972761, 51.65247406278338, 63.23228277478899, 34.83350474493844, 0.16904105432331562, 0.10611618656132903, 0.09026438037731818, 0.08185523482305662, 0.01361696289053985, 0.05772414790200336, 0.004691780428402126, 0.05560181249997445, 0.01236796991101333, 0.04854721622541547, 0.019638009535680925, 0.04303007173751082, 0.04323028028011322, 0.01954541664703616, 0.01865492934095008, 0.05018088427771415, 0.06752200358148132, 0.033098649832287004, 0.05437113318060126, 0.021691285339849334, 0.04828374786302447, 0.06589284100170646, 0.11506390571594238, 0.03899137702371393, 0.03106358421168157, 0.05203617883047887, 0.042766918893903494, 54.29396724700928, 83.66806738717216, 76.22704001835415, 66.75039196014404, 40.351027556828086, 27.504074130739482, 24.053845371518815, 60.3975567136492, 97.23216697147915, 88.05661909920829, 27.8202988079616, 0.11073850281536579, 0.07297174579330853, 1.9054540055138725, 4.024573368685586, 0.5334483268005508, 0.5677374697157315, 0.4748741441539356, 0.16211732370512827, 0.677907183766365, 0.15082413969295366, 3.170347720384598, 46.17313507625035, 88.19012873513358, 93.21616377149309, 91.84873744419643, 91.92312485831124, 93.92454651423863, 94.26386874062675, 90.95884690965924, 91.30512428283691, 87.71578216552734, 84.76307569231305, 81.64027731759208, 84.94215856279645, 82.91631398882184, 85.09229523794991, 82.69784872872489, 79.71607794080461, 78.8682587487357, 78.00095680781773, 67.29053102220807, 59.766236441476, 57.411182744162424, 57.405909061431885, 56.505172388894216, 57.60613530022757, 60.432881355285645, 64.81267833709717, 65.26178210122245, 71.53925718579973, 70.64067445482526, 75.33437020438058, 70.5708589553833, 64.80561896732875, 60.23312759399414, 57.73207834788731, 58.751167161124094, 65.644259589059, 69.52542604718889, 75.8146505355835, 72.99502985818046, 75.9580683026995, 72.25235775538853, 70.0468327658517, 69.51683112553188, 69.1705607005528, 69.56921359470913, 69.54605524880546, 63.60454641069685, 67.36244487762451, 64.14798586709159, 66.62718650272915, 46.55483436584473, 26.821387563432964, 24.548628330230713, 34.70305926459176, 57.799295221056255, 56.73103053229195, 67.69977991921562, 64.92936638423375, 62.18375791822161, 57.63629395621163, 66.99565642220634, 67.38568660191127, 70.65828119005475, 70.51055553981236, 67.06035109928676, 66.38336726597377, 65.66421481541225, 65.79170731135777, 69.41788182939801, 67.29284477233887, 63.451665197099956, 60.18025180271694, 65.7312718800136, 68.79351670401437, 70.07809965951103, 70.3279846736363, 70.01567009517125, 63.80878176007952, 52.87967879431588, 52.441740785326274, 53.43023668016706, 53.70846687044416, 55.991502489362446, 64.90830639430455, 70.10581602369035, 72.8182121004377, 65.06272315979004, 62.47260843004499, 57.51550299780709, 56.32021829060146, 54.88537359237671, 62.3669193812779, 67.80535779680524, 68.63162367684501, 70.16364588056291, 73.58230549948556, 71.61015660422188, 77.04034055982316, 73.65256568363735, 81.22339235033307, 18.834952660969325, 1.2728862059967858, 2.114807354552405, 2.3624266045434132, 2.1758479305676053, 0.7854641037327903, 0.430318467851196, 0.743065381688731, 1.9518327968461173, 1.9405196096215929, 0.39841198708329884, 0.25439985043236185, 13.395026462418691, 48.66527325766427, 64.85789721352714, 84.0745370047433, 57.50724853788103, 32.94930962153843, 22.50882135118757, 25.951426199504308, 36.25433145250593, 67.67938695635114, 69.72590936933244, 57.40752451760428, 74.65615653991699, 40.21775415965489, 0.07819825676935059, 0.0644248847716621, 0.06315248911934239, 0.04528738811079945, 0.06188775412738323, 0.05443883061941181, 0.03252078566168036, 0.07451005253408637, 0.061538037178771834, 0.029416630443717753, 0.026590369242642607, 0.04655789743576731, 0.06547094149781124, 0.09568867074059588, 0.11331876793078013, 0.13645841340933526, 0.21266211649136885, 0.14523738090481075, 0.18267051582889898, 0.23175222426652908, 0.17766421660780907, 0.08205754003886666, 0.17434148490428925, 0.1439705424542938, 0.1246112191251346, 0.1721900132085596, 0.1636338359011071, 65.60450199672154, 93.63218716212681, 86.67910398755754, 72.2357793535505, 52.16401086534773, 38.755057607378276, 39.222490719386506, 72.99423776354108, 103.34619263240269, 97.22117492130825, 38.24210337230137, 0.7406702616385051, 0.12880516265119824, 3.2866929173469543, 11.397944825036184, 1.4496162427323205, 0.6291238814592361, 0.7257237093789237, 1.2799145260027476, 1.4677938159023012, 0.4812157324382237, 3.4243975281715393, 49.345988273620605, 93.82096971784318, 97.73074190957206, 96.93758419581822, 96.52189431871686, 97.29781355176652, 98.04796886444092, 96.2432507106236, 96.46593352726528, 91.37680884769985, 88.13564096178327, 86.01478672027588, 86.84875120435441, 86.41933168683732, 87.09208406720842, 85.61247212546212, 81.77343954358781, 82.7277398790632, 84.43405764443534, 72.0201975958688, 63.74194008963448, 59.30327102116176, 62.79915986742292, 59.51476723807198, 62.286097935267854, 63.579692704336985, 70.37011160169328, 70.13888944898332, 76.12965406690324, 73.82923058101109, 80.5832965033395, 74.30306298392159, 68.76047107151577, 63.60189914703369, 61.00407886505127, 63.10851451328823, 69.39323656899589, 73.41322803497314, 77.71865844726562, 77.85648291451591, 78.23472200121198, 74.5766830444336, 76.26162120274135, 72.54754502432687, 71.92976679120744, 72.53861658913749, 72.54461983272007, 66.31971481868199, 71.05912276676723, 66.69363907405308, 73.48994309561593, 49.07597085407802, 23.69121888705662, 22.241677011762345, 34.91482298714774, 64.81766714368547, 58.93668406350272, 71.72234221867153, 65.66964135851178, 64.6564689363752, 61.969468525477815, 69.63977255140031, 70.79477855137416, 73.78642967769078, 72.22259167262486, 68.88515649523053, 67.99405697413853, 68.00185285295758, 69.85559054783413, 71.96857942853654, 69.46327441079276, 64.65072277614048, 63.39867128644671, 70.2425843647548, 72.88997309548515, 73.99917657034737, 73.7744996207101, 73.90881524767194, 67.97472013745988, 56.219104630606516, 55.24764224461147, 56.82793705804007, 56.41901820046561, 59.14584568568638, 68.55711814335415, 72.1503929410662, 73.8558908190046, 69.5469446182251, 65.28697626931327, 59.812337739127024, 58.39988013676235, 56.82777377537319, 65.13373374938965, 71.19272272927421, 71.70411014556885, 73.23222746167863, 76.20873151506696, 73.04721082959855, 79.35688386644635, 76.3878560747419, 83.08382810865129, 17.848141704286846, 3.151909589767456, 8.865236112049647, 10.81207185132163, 5.097223239285605, 1.0466481915542056, 1.3694840797356196, 2.8951606239591325, 5.837188150201525, 1.2569854706525803, 0.3961545010762555, 0.5609790437987873, 23.175226552145823, 58.655184745788574, 74.96087673732212, 103.18728038242885, 90.28196729932512, 47.37075785228184, 21.491436583655222, 28.23964170047215, 42.59763029643467, 75.47753783634731, 79.1480210168021, 66.72474615914481, 83.20526872362409, 45.2341867855617, 0.24704881917153085, 0.21733513288199902, 0.1696665957570076, 0.1201895321054118, 0.1524465304932424, 0.1970262269356421, 0.09012978617101908, 0.18424540917788232, 0.15837528450148447, 0.1362304799258709, 0.1555242296308279, 0.16973203367420606, 0.1397942951215165], [0.07088725228926965, 0.03350715844758919, 0.015995302769754614, 0.13446129485964775, 0.07462365286690847, 0.081309645170612, 0.027460602278422033, 0.0802535664822374, 0.02927696079547916, 0.03770741234932627, 0.005471325562601643, 0.026089824137410948, 0.10424403380602598, 1.175941356590816, 67.90885121481759, 69.36458219800676, 57.73324564525059, 39.24007313592093, 40.43407242638724, 23.293323346546718, 43.31610877173287, 84.80252061571393, 92.52096176147461, 53.747613021305625, 4.267217057091849, 0.009197028187502707, 0.060538432959999354, 0.38939612944211277, 1.5432144488607134, 0.22132474237254687, 0.060549608431756496, 0.05775767431727477, 0.053863439708948135, 0.06448310986161232, 0.14466028687145027, 8.980178424290248, 55.015499455588206, 85.06082684653146, 89.55114187513078, 89.03022847856793, 90.29669053213937, 87.78379113333565, 88.20793001992362, 84.79330035618374, 81.86581584385463, 78.55668067932129, 77.54432814461845, 74.825240952628, 81.6652352469308, 78.46315097808838, 83.74820096152169, 80.43755108969552, 75.00760337284633, 68.0393453325544, 63.56396893092564, 55.10520417349679, 54.79269504547119, 53.67828736986433, 56.00092772075108, 54.207722731998985, 55.626419816698345, 57.13728475570679, 61.52895968300955, 62.47119099753243, 66.53902081080845, 69.88794136047363, 72.03007098606655, 68.21178572518485, 61.990667479378835, 58.496432304382324, 56.676785945892334, 54.57180833816528, 59.468214307512554, 64.40356840406145, 70.08350535801479, 69.93811430249895, 71.42655045645577, 70.93542398725236, 67.7265374319894, 62.8000978742327, 68.72157505580357, 70.7930553981236, 67.07472692217145, 62.4506173815046, 63.1454997743879, 57.88301059177944, 61.50402954646519, 47.410001277923584, 34.30592802592686, 27.975728273391724, 32.610720430101665, 56.41430732182094, 55.78614500590733, 64.69143227168492, 61.681479590279714, 59.970464842660085, 54.50006471361433, 57.586398942129954, 64.00085081372941, 66.92478479657854, 69.88352230616978, 69.38887310028076, 64.14280251094273, 64.9958745411464, 64.42897101811, 66.84946632385254, 65.27852031162807, 64.6547110421317, 63.90337453569685, 61.222794260297505, 65.77152279445103, 69.7478587286813, 66.00766427176339, 65.59644903455461, 57.895652839115684, 49.81975466864449, 49.657139028821675, 51.600626604897634, 49.38835144042969, 57.99983760288784, 63.96164212908064, 70.88807896205357, 68.18909290858677, 64.47704560416085, 58.66739967891148, 55.29617888586861, 51.14780902862549, 54.216925621032715, 58.89102745056152, 62.60499940599714, 65.21464552198137, 67.20171914781842, 69.41886847359794, 70.93065057482038, 72.11019761221749, 73.94123554229736, 70.84802954537528, 61.44997950962612, 1.0231364646128245, 0.7818276988608497, 0.1746927217713424, 1.0237032856260027, 0.4046605889286314, 0.42144179131303516, 0.3920916776571955, 2.7918652296066284, 3.1385000007493153, 0.144917668774724, 0.12065515640590872, 0.4057173393666744, 22.56916298185076, 45.443796566554475, 75.51619066510881, 84.89211763654436, 66.49075862339565, 39.61559895106724, 21.723754814692906, 24.40288117953709, 41.94343655450003, 48.5085323197501, 57.05731098992484, 56.257580280303955, 61.94922842298235, 5.144885276045118, 0.10030490053551537, 0.19683554502470152, 0.06814515657190766, 0.009250141364256186, 0.012835363491571375, 0.04487947660631367, 0.10035104770213366, 0.035420393105596304, 0.020494434383830855, 0.03445537042404924, 0.0578174532524177, 0.020199305577469722, 0.030835196109754697, 0.03144643063257847, 0.04419537420783724, 0.10395807200776679, 0.015938187084559883, 0.028601937195552245, 0.030301484212811505, 0.04176415270194411, 0.0435640923678875, 0.07280670572072268, 0.03204643540084362, 0.025499379927558557, 0.03771096448014889, 1.6034744381904602, 78.40619659423828, 78.84916509900773, 67.43357358660016, 47.12259251730782, 41.19207225527082, 24.188949619020732, 42.49095112936837, 88.22371632712228, 104.17683587755475, 61.37147181374686, 5.550211914948054, 0.0881643212799515, 0.9563103190490178, 1.2568422726222446, 3.0326869700636183, 0.9736892836434501, 0.22773638261216028, 0.42685432944978985, 0.20801052823662758, 0.1159713648791824, 0.25599234497972895, 11.148792845862252, 59.1104793548584, 89.37248284476144, 94.02856799534389, 91.94101646968296, 93.20795794895717, 90.7194675718035, 91.30866091591972, 85.96894945417131, 85.16932991572789, 81.07267897469657, 80.52539716448102, 78.86501393999372, 84.817535672869, 81.61779989515031, 87.2355157307216, 81.49241965157645, 78.33257348196847, 72.28454181126186, 64.86670058114188, 57.508888312748496, 59.25611359732491, 57.20840999058315, 57.76053122111729, 57.40332085745675, 59.10744299207415, 60.600902693612234, 63.23616681780134, 65.61386816842216, 68.32430485316685, 72.95265974317277, 74.16156986781529, 73.05600030081612, 63.726285798209055, 61.23666286468506, 59.49064309256417, 57.916775362832205, 61.344054222106934, 68.29493481772286, 70.34598050798688, 72.96543748038155, 75.40186500549316, 73.55233791896275, 72.00393186296735, 65.18481690543038, 71.10425131661552, 71.65371486118862, 71.74379130772182, 67.23286097390312, 65.67384501865932, 60.698969568525044, 63.595221928187776, 51.48103073665074, 37.66703919001988, 34.00635296957833, 39.488825593675884, 59.32138497488839, 58.04889188494001, 68.56573390960693, 66.83866882324219, 63.56918007986886, 56.501132011413574, 59.45971666063581, 65.97150584629604, 67.42388779776437, 70.84168584006173, 69.83148724692208, 67.90478651864188, 69.76229708535331, 67.55320072174072, 69.86231640407017, 67.26855387006486, 68.67689813886369, 67.22040285382951, 65.26269231523786, 66.61729226793561, 71.45758805956159, 69.4092799595424, 69.00651373182023, 61.90405123574393, 52.88762058530535, 52.00819403784615, 53.227776595524375, 52.41049473626273, 60.75667435782296, 66.8630153111049, 73.35250772748674, 69.63293552398682, 67.01752240317208, 60.3119410106114, 59.23572063446045, 53.948162351335796, 57.23751252038138, 60.98137215205601, 64.54658317565918, 67.61371953146798, 71.7481130872454, 70.7567788532802, 73.56188474382672, 72.94003486633301, 76.02909973689488, 69.45515891483852, 65.88973944527763, 4.025279479367392, 1.5265678678240096, 0.5116719667400632, 0.8601691808019365, 0.8685053363442421, 1.0342166700533457, 1.100525174822126, 3.309791986431394, 4.571392255170005, 1.2009994919810976, 0.17405654090855802, 0.06477515133363859, 23.07473996707371, 49.88854878289359, 80.92291055406842, 77.07741614750454, 51.3879839352199, 24.872435229165212, 30.150213922773087, 35.49568544115339, 50.68108810697283, 57.286660603114534, 65.69398784637451, 64.51171711512974, 75.16500786372593, 5.669234122548785, 0.13914856048566954, 0.19159147356237682, 0.10656984150409698, 0.03601301202018346, 0.024902611771332364, 0.02983001433312893, 0.07945898161934954, 0.019183944079226682, 0.05193163015480552, 0.008511130215733178, 0.029642301012894938, 0.03014253399201802, 0.10541351605206728, 0.07613436358847789, 0.1450452876410314, 0.1611670489822115, 0.197546975421054, 0.12803828237312181, 0.11349381639489106, 0.1235954114901168, 0.15652846145842755, 0.13936398178339005, 0.07845792533563715, 0.1729877804006849, 0.2686816283634731, 2.25515684059688, 89.98083932059151, 90.52172183990479, 78.29823548453194, 56.92535775048392, 55.7006960596357, 36.42732422692435, 59.8503235408238, 107.8943236214774, 108.3374102456229, 77.15016378675188, 8.1198924268995, 0.1130485413596034, 0.44212967263800756, 2.3568354759897505, 5.623481971876962, 1.1014778379883086, 0.37299900501966476, 0.7157920194523675, 0.7739340567163059, 0.2776030067886625, 0.6499571864094053, 11.555718438965933, 64.40980093819755, 96.191757610866, 97.32652350834438, 96.19683674403599, 96.84082358224052, 94.90513883318219, 95.92983136858258, 90.5720545904977, 89.77531855446952, 85.58642332894462, 87.64493833269391, 83.80857385907854, 86.74942670549665, 84.31583404541016, 91.21300506591797, 85.45322636195591, 82.6989882332938, 75.57897458757672, 69.97134058816093, 59.93807234082903, 61.6110873903547, 58.72145666394915, 59.59394196101597, 61.788335936410085, 63.38250977652413, 64.89133194514683, 68.2184282030378, 69.81906386784145, 73.49362564086914, 76.39640930720738, 79.74828284127372, 74.97776780809674, 67.65110083988735, 64.88417530059814, 62.7935665675572, 59.73193318503243, 64.21723161424909, 71.8750080381121, 75.2239077431815, 75.79329872131348, 79.21628706795829, 76.29937076568604, 75.6231998716082, 69.53429194859096, 75.89206736428397, 75.87566266741071, 73.06376143864223, 69.19202368600028, 70.09066200256348, 62.3563164302281, 68.79539271763393, 54.06912701470511, 37.326018129076274, 32.72194371904646, 40.927022797720774, 65.07258265359062, 62.51379040309361, 72.36555085863385, 67.92094108036586, 68.01142052241734, 58.15627976826259, 64.20473875318254, 71.56570202963692, 72.04319613320487, 74.65977655138288, 74.1207492010934, 70.38763495853969, 71.60626561301095, 70.49244853428432, 71.3979377746582, 70.96217455182756, 72.72749641963414, 71.656799861363, 67.59052644457135, 71.33169364929199, 74.3644711630685, 72.12660925728935, 72.04749011993408, 67.64163739340646, 55.309446471078054, 55.06475176130022, 57.07545273644583, 55.48985992159162, 63.02795015062605, 70.33819157736642, 77.55224214281354, 72.17567743573869, 69.40185233524868, 64.49429103306362, 61.394261905125205, 55.19720874513899, 61.17535196031843, 66.296952520098, 67.13578769138881, 71.45254366738456, 74.0055341720581, 75.05471910749162, 79.84286866869245, 77.32743317740304, 77.62454509735107, 71.25518703460693, 66.09544781276158, 2.284061129604067, 3.541901554380144, 5.653870786939349, 3.597191844667707, 2.7328748064381734, 1.7683902574437005, 3.1518127492495944, 11.326318451336451, 6.831565260887146, 0.7001468475375856, 0.2261804746729987, 0.52533065953425, 37.01285934448242, 60.45053672790527, 90.19954081944057, 99.43439156668526, 84.69783210754395, 53.70232118879046, 34.77559845788138, 37.262914589473176, 58.57735102517264, 66.24304144723075, 75.08688231876918, 73.24205221448625, 83.44769137246269, 6.754227467945643, 0.2726006566413811, 0.35804916865059305, 0.18419314841074602, 0.08232412966234343, 0.1590060642255204, 0.12900818032877787, 0.24025358951517514, 0.20709975782249654, 0.16288151698453085, 0.07446676878524677, 0.08327162239168372, 0.08503282788608756], [0.020441876757623892, 0.029045668563672473, 0.10098728963306972, 0.03382979167093124, 0.084281262143382, 0.019644872917394553, 0.05549479734950832, 0.011541662687834884, 0.0963306598631399, 0.13955227525106498, 0.13420718349516392, 0.10416675545275211, 0.639098020536559, 9.137855631964547, 79.64708232879639, 64.08461134774345, 62.12069606781006, 49.71694564819336, 21.6053957257952, 20.04864662034171, 59.56134101322719, 81.13415663582938, 76.53252451760429, 24.80984238215855, 0.2905137911438942, 0.05571395058983138, 0.7086187643664223, 2.2579332973275865, 1.6606500787394387, 0.42112746675099644, 0.32112855836749077, 0.3742252806467669, 0.051587382198444436, 0.41102934575506617, 0.7065407644425119, 18.996350628989084, 61.834068979535786, 90.73483698708671, 91.2759210041591, 92.61133003234863, 90.58695152827671, 86.49034922463554, 84.78938852037702, 79.843674659729, 78.67814213888985, 72.18901102883476, 65.84142167227608, 67.85835865565709, 73.16560118538993, 78.88979816436768, 83.57406520843506, 76.93454728807721, 76.11081750052315, 68.35158348083496, 57.23899596078055, 55.669769627707346, 55.64752844401768, 55.761899266924175, 55.299517495291575, 54.304135935647146, 55.379633699144634, 56.63358204705374, 59.16124289376395, 58.10727759769985, 61.490279061453684, 68.74144690377372, 69.84812123434884, 71.18389156886509, 65.25249930790493, 61.024388449532644, 57.29469619478498, 58.640065465654644, 61.92540305001395, 66.5177662713187, 70.57532664707729, 67.62658759525844, 67.0257351739066, 72.93747792925153, 65.40836129869733, 60.917636326381135, 63.98571068899972, 64.13913386208671, 64.94173417772565, 57.25599125453404, 57.69751453399658, 56.84925413131714, 57.64087976728167, 56.13337080819266, 49.43952144895281, 42.142016070229666, 40.65302406038557, 52.89928661073957, 53.92190510886056, 58.12120178767613, 62.21178000313895, 62.903007643563406, 55.499618666512625, 51.54114655085972, 55.87912579945156, 60.80357469831194, 63.95679923466274, 65.87902532305036, 67.90313284737724, 66.14363356998989, 65.84334632328579, 65.90007836478097, 66.14243153163365, 66.94578225272042, 61.35494204929897, 69.46509483882359, 65.3414431980678, 63.722888129098074, 66.10671084267753, 63.809490476335796, 55.55264384405953, 48.83046667916434, 48.962093353271484, 49.64925282342093, 51.859436580113, 61.88342898232596, 64.53534099033901, 67.27730860028947, 64.22927979060582, 68.16193240029472, 59.05950042179653, 58.592852456229075, 53.443316664014546, 50.61244337899344, 55.275917938777376, 61.01363958631243, 63.79523972102574, 65.04604748317173, 68.29878411974225, 65.38559205191476, 66.26093305860246, 70.1347552708217, 68.2348051071167, 72.07711723872593, 55.891170501708984, 1.185406540121351, 0.7865818408983094, 1.0196127508367812, 0.6438959687948227, 0.09956265786396605, 0.4919875030006681, 1.5426442623138428, 3.443276869399207, 1.4688205208097185, 0.3121306411921978, 0.3167736120522022, 6.510033028466361, 34.91083124705723, 63.56005014692034, 78.12566307612828, 90.02200044904436, 82.01446560450962, 37.285895756312776, 17.018344402313232, 14.80706456729344, 28.858262402670725, 51.046893392290386, 53.3574195589338, 70.39774458748954, 18.52065784590585, 0.13705780410340854, 0.1422661303409508, 0.08058603507067476, 0.01008450279810599, 0.07123298623732158, 0.14042206215006964, 0.05406198584075485, 0.05487420243610229, 0.1252863071858883, 0.05216981290972658, 0.06013821943530014, 0.03128324635326862, 0.04890498059934803, 0.06453394570520946, 0.0701503429029669, 0.02825912264441805, 0.023832643471126045, 0.07303263752588204, 0.10577244750623192, 0.05939988512545824, 0.018387983486588513, 0.12955273182264396, 0.13624088865305695, 0.15931535405772074, 0.5810731798410416, 10.350967679704938, 91.05127879551479, 70.08613872528076, 74.1571021761213, 48.95504787990025, 32.1590701511928, 23.94872954913548, 54.1339293888637, 91.04956953866142, 84.97874777657645, 30.4846967288426, 0.1856019092457635, 0.24292997590133122, 2.1898057758808136, 5.121715639318738, 2.851598241499492, 1.7856296066726958, 1.0650441987173898, 0.15057815717799322, 0.06787238549441099, 0.25301781030637877, 1.1441397773368018, 22.282237121037074, 69.0279072352818, 94.94793278830392, 95.65167413439069, 97.15628569466728, 92.53722054617745, 90.59353147234235, 87.73565401349748, 83.74925708770752, 81.26788861410958, 75.57363142286027, 67.87489536830357, 71.35112081255231, 76.31443446023124, 81.64858736310686, 85.5737498147147, 80.81968116760254, 78.71826103755406, 72.73881503513881, 59.13843195778983, 57.84977388381958, 58.56214141845703, 58.51370552607945, 57.713544028145925, 57.42633676528931, 58.466951097760884, 58.57910891941616, 59.651167324611116, 59.445945331028526, 64.35069261278424, 71.55846895490373, 72.71057755606515, 73.62902518681118, 66.78479249136788, 65.59057085854667, 61.8457419531686, 62.392440114702495, 65.97202696119035, 70.24202850886753, 69.47650378090995, 69.25391129084996, 69.74844932556152, 74.91002287183488, 65.71415846688407, 61.02408272879464, 66.02016408102853, 67.23868356432233, 66.36899144308907, 60.71917493002755, 61.37582833426339, 57.632517610277446, 59.904588971819194, 59.43684319087437, 52.30732440948486, 46.10617528642927, 46.15037625176566, 55.2357816696167, 56.98406308037894, 63.44089548928397, 64.84835733686174, 64.92828941345215, 58.752258028302876, 54.02293191637312, 57.5849016053336, 63.438408034188406, 67.1377957207816, 67.84590748378209, 69.97579438345772, 68.34688649858747, 67.24358204432896, 67.84458037785122, 67.54778807503837, 68.98539120810372, 66.72708770206997, 72.17207826886857, 67.60875156947544, 65.82598972320557, 68.18529224395752, 66.82879543304443, 60.18137046269008, 49.417162145887104, 53.3478136743818, 51.34172977719988, 54.84014776774815, 65.37851183755058, 67.32075568607875, 69.22789028712681, 67.80289118630546, 70.4254401070731, 63.04871136801583, 62.138768332345144, 58.42402512686593, 53.021338667188374, 57.23969078063965, 62.94580159868513, 66.11052540370396, 69.01528235844204, 73.06341402871269, 69.085556438991, 69.23202446528843, 71.68950503213065, 71.03683294568742, 72.30566433497837, 65.22434520721436, 4.4227867892810275, 0.4337096501673971, 0.2653775428022657, 1.4075196044785636, 1.4575452229806354, 1.1251651155097144, 2.4755484887531827, 3.451519169977733, 2.732097693852016, 0.5502846805112702, 0.3398597889712879, 5.163620225020817, 39.89797026770455, 67.26182801382882, 84.04025459289551, 77.1706679207938, 68.30071571895054, 29.08408406802586, 19.115140506199428, 19.610253504344396, 34.44453763961792, 59.66404928479876, 60.22292069026402, 81.84329673222133, 22.679434367588588, 0.32402891559260233, 0.1593449788966349, 0.12019719955112253, 0.010214248023528074, 0.09398096773241248, 0.11421972672854151, 0.06177798073206629, 0.019902485522574613, 0.09550122544169426, 0.07895195989736489, 0.05618309648707509, 0.07367516947644097, 0.09041720681956836, 0.15592487741793903, 0.20197075232863426, 0.10028600333524601, 0.12752708766077245, 0.1917879908744778, 0.15252142718860082, 0.1740083513515336, 0.15120416001549788, 0.2076432236603328, 0.28038122771041735, 0.35628780030778473, 1.2062439705644334, 12.404413104057312, 104.02756772722516, 78.58739866529191, 82.85735852377755, 67.05698122297014, 34.15532234736851, 29.476130962371826, 82.36598191942487, 98.22020775931222, 92.85942935943604, 39.54176044464111, 0.8787095259342874, 0.21543310422982487, 2.664204456976482, 6.967928435121264, 6.852780716759818, 1.5130557928766524, 1.9870829624789101, 3.0228580917630876, 0.14543554027165684, 0.7236171024186271, 1.380215355328151, 23.598205089569092, 77.64245755331856, 100.27340044294084, 99.90656335013253, 101.44572830200195, 98.11150319235665, 94.13584123338971, 92.80107838766915, 86.88021264757428, 87.3590338570731, 78.07320417676652, 71.73808683667863, 74.43974794660295, 79.72319984436035, 87.88784040723527, 89.97025721413749, 81.84604127066476, 84.63148375919887, 75.83069392613002, 61.950930731637136, 60.28063242776053, 62.65954276493618, 61.77340425763811, 63.37353965214321, 60.89665971483503, 62.9500469480242, 62.28177615574428, 64.46314225878034, 62.454848834446494, 67.94575309753418, 76.76886749267578, 75.06971332005092, 78.69196210588727, 70.13494287218366, 68.6725972039359, 62.432107380458284, 66.77780955178397, 69.87260668618339, 72.72184753417969, 74.11176518031529, 72.37360382080078, 72.07121126992362, 77.10033825465611, 71.33525112697056, 65.37357861655099, 69.76035158974784, 69.31306825365338, 71.29789761134556, 65.0715195792062, 64.42391967773438, 60.88321495056152, 63.70571913037981, 60.99317019326346, 54.27625281470162, 47.31731925691877, 48.446870531354634, 59.75076975141253, 60.137756620134624, 66.58783885410854, 69.12890625, 68.73845223018101, 63.306802204677034, 57.277607100350515, 61.720375605991904, 67.21961770738874, 70.8186456135341, 71.02520860944475, 73.91858441489083, 71.5704823902675, 70.58344909123012, 70.00100244794572, 71.6294448035104, 71.25233827318463, 68.9721132005964, 75.69053486415318, 70.80010087149483, 68.54441683632987, 70.42862238202775, 71.58191912514823, 63.164273806980674, 53.57558952059065, 56.833909034729004, 54.811528137751985, 58.262184211185996, 68.65548379080636, 70.63499777657645, 73.78474126543317, 71.71668638501848, 73.18754359654018, 66.96618216378349, 66.79252583639962, 59.56238324301583, 54.68335124424526, 61.179840496608186, 65.87669767652238, 70.52983679090227, 69.77902834756034, 76.25310271126884, 71.08337892804826, 72.96038614000592, 75.43447984967912, 74.05584607805524, 76.57594381059918, 62.55333260127476, 2.3539875830922807, 1.986189250435148, 5.0540223802839, 2.2673515805176327, 1.5225511576448167, 1.1814240281070982, 8.073309966496058, 7.531490308897836, 3.835485960756029, 0.6508837938308716, 0.5940577345235007, 10.152041622570582, 53.24606772831508, 76.00100816999162, 91.82728835514614, 106.20732184818813, 105.85315826960972, 50.20959724698748, 25.37235985483442, 30.55948713847569, 45.396163191114155, 69.43040943145752, 68.5480854851859, 93.60935538155692, 25.267230136053904, 0.5320921795708793, 0.2599518139447485, 0.2282665084515299, 0.12974987338696206, 0.17757383574332508, 0.25991319173148697, 0.1952219344675541, 0.1278432442673615, 0.21296981855162553, 0.23154399544000626, 0.1678266123469387, 0.17540548209633144], [0.06374168143208538, 0.05138119236965265, 0.011746047613477069, 0.1026131273912532, 0.03648297555212464, 0.03645508437018309, 0.03207155815990908, 0.14228518360427447, 0.0841909966298512, 0.08720397709735803, 0.08778289638991867, 0.17979086749255657, 0.6324649336082595, 17.159495319638932, 83.87404673440116, 60.706473623003276, 48.53954560416085, 41.20741040366036, 23.13572951725551, 40.81674446378435, 70.10537133898053, 86.68518366132463, 59.46735967908587, 8.874630945069448, 0.18499054919396127, 0.2916927050266947, 4.698513891015734, 1.6183396748134067, 2.3647464343479703, 1.0195032081433704, 0.7189134976693562, 0.36716973781585693, 0.11825568016086306, 0.03884853522426315, 3.3596092675413405, 25.879715578896658, 76.36112635476249, 85.7465237208775, 88.62924793788365, 84.08620303017753, 85.34289591653007, 81.27706718444824, 79.69673415592739, 72.14826679229736, 65.42978954315186, 63.23561791011265, 62.04100717817034, 64.07432801382882, 73.65847165243966, 78.50046975272042, 82.1733570098877, 79.96159948621477, 77.47513798304966, 72.33372116088867, 57.97195100784302, 55.217966488429475, 55.54085969924927, 55.28003127234322, 51.97797284807478, 53.579515252794536, 54.64843307222639, 52.68197475160871, 54.04414824077061, 53.426335266658235, 59.80532700674874, 68.40657152448381, 69.56787259238106, 70.87976891653878, 66.2392268862043, 65.28063256399972, 63.22360447474888, 65.06380707877022, 66.35656806400844, 67.97160039629254, 69.87824167524064, 69.72907079969133, 64.30875328608921, 70.52129745483398, 63.6431644984654, 60.69187545776367, 61.41595418112618, 69.92434992109025, 56.088176250457764, 59.28571292332241, 54.198901993887766, 56.629451342991416, 54.89754683630807, 56.81024694442749, 57.28582681928362, 55.94674914223807, 51.671091760907856, 52.262758663722444, 49.99040937423706, 56.15879079273769, 59.09340068272182, 59.17179025922503, 57.66419097355434, 54.15803268977574, 49.130149432591026, 48.69028329849243, 54.219274112156455, 61.513451303754536, 63.41443674904959, 67.22375188555036, 65.52238818577358, 68.30190386090959, 66.49277360098702, 67.19046306610107, 66.43867492675781, 59.03251361846924, 58.3687869480678, 65.4225217274257, 65.63055774143764, 59.17134557451521, 52.155485425676616, 48.57576656341553, 47.486243861062185, 48.26126677649361, 49.397422313690186, 59.25739901406424, 67.47767380305699, 66.19751685006278, 64.42708805629185, 66.01641205378941, 62.42182404654366, 60.69013840811593, 58.203607422964915, 53.9893547466823, 53.23918553761074, 54.31104939324515, 63.04655047825405, 66.4731171471732, 71.32298755645752, 72.00122206551688, 69.08821065085274, 67.13225105830601, 71.09556606837681, 70.68970789228166, 75.82468373434884, 63.714793477739605, 4.407796485083444, 0.6818977839180401, 0.07777888820107494, 0.4843984416552952, 0.6178416897143636, 1.7896447969334466, 4.033271210534232, 2.5839371298040663, 0.28461360345993725, 0.04845697106793523, 0.07860819370086704, 15.639059237071447, 42.402240003858296, 67.3802878516061, 81.2547356741769, 53.15660967145647, 76.23970658438546, 73.45297173091343, 60.77663653237479, 32.37479087284633, 45.56145388739449, 56.07920265197754, 62.91497244153704, 39.24212632860456, 0.16829786848809036, 0.12167483169053282, 0.057916722925645966, 0.04783310561573931, 0.1019470774169479, 0.04403065304671015, 0.0038645677850581706, 0.036223228954310925, 0.04935196215020759, 0.06348486271287714, 0.04134674509987235, 0.026980872931224958, 0.057297532579728534, 0.05770227193300213, 0.04493678906666381, 0.03757516587419169, 0.016911055327260067, 0.07469231382544551, 0.018219852686992714, 0.1761304424809558, 0.13220607515956673, 0.13618013262748718, 0.16132220279957565, 0.23612611527953828, 0.8141642351235662, 19.841948134558542, 95.83686447143555, 68.31484140668596, 61.59081254686628, 47.80160869870867, 35.74386814662388, 34.44717100688389, 67.4198578425816, 99.14446408408028, 67.29285866873605, 9.738077504294258, 0.37891197630337303, 0.7735206389001438, 4.880261395658765, 3.9895553163119724, 3.3172398039272855, 2.1929383277893066, 1.2880460896662302, 0.46928437267030987, 0.5114141234329769, 0.06121149898639747, 4.506407056535993, 28.956426552363805, 81.79301956721714, 91.95232118879045, 92.86593287331718, 88.21563557216099, 87.53895051138741, 84.42827674320766, 82.38190719059536, 74.40959971291679, 67.79614448547363, 65.39760548727853, 63.29571982792446, 68.24030113220215, 76.62978540148053, 81.75309521811349, 83.82533291407994, 83.7365974698748, 79.35114465441022, 76.2252334867205, 62.13478006635393, 58.85490376608712, 58.28583935328892, 58.438129970005576, 56.23504032407488, 57.003073351723806, 58.026254653930664, 54.912030356270925, 56.23196227209908, 55.98167773655483, 63.9857245853969, 71.26048156193325, 70.84093543461391, 72.93610218593052, 69.98819691794259, 67.77184663500104, 66.93688855852399, 68.19657611846924, 69.54506860460553, 70.29899678911481, 72.9465731212071, 70.32539299556187, 69.21827398027692, 74.92208494458879, 66.27283532278878, 64.6634657723563, 65.6747135434832, 73.71805245535714, 61.91846179962158, 60.48989132472447, 56.82014117922102, 57.799611364092144, 58.73913982936314, 58.00169277191162, 59.90756280081612, 61.31939506530762, 57.62879337583269, 55.44221264975411, 52.6861367225647, 59.20743451799665, 61.641367639814106, 62.442098890032085, 59.0832702091762, 57.235973494393484, 52.18319831575666, 51.30515098571777, 56.278633322034565, 63.144200461251394, 66.26927089691162, 68.63390268598283, 66.6815492085048, 70.21065739222935, 67.22956057957241, 69.76625061035156, 66.308027948652, 60.05344023023333, 58.894612721034456, 68.2676214490618, 67.96942561013358, 62.20534597124372, 55.12673316683088, 49.724984713963096, 50.56704037530081, 50.282938957214355, 52.12977014269148, 62.85867813655308, 70.42261219024658, 69.59414373125348, 68.39825453077043, 69.44323580605644, 65.740964617048, 63.069924218314036, 61.37555040631975, 58.39772619519915, 54.55441699709211, 57.134821619306294, 62.71252972739083, 68.6026496887207, 72.20852157047817, 76.20331192016602, 72.73664024897984, 71.70816094534737, 72.85996382577079, 75.85071863446916, 77.35824148995536, 74.36638191768101, 9.409993120602199, 0.5063894359128815, 0.38184696595583645, 1.089223712682724, 0.9307391026190349, 3.841672028814043, 5.758931457996368, 3.870035009724753, 1.6454018226691653, 0.14796838935996803, 0.12682659524892057, 15.884896925517491, 49.27117007119315, 71.29666083199638, 86.1314400264195, 52.20245524815151, 61.059803417750764, 47.903667313711985, 62.574740001133506, 42.12765761784145, 51.63826847076416, 62.871879713875906, 71.96674510410854, 45.02522666113717, 0.11680255670632635, 0.13332947130714143, 0.04708231340295502, 0.061113226759646616, 0.04986536210136754, 0.037189140516732416, 0.0558449723092573, 0.04099079580711467, 0.025415472287152494, 0.030307109268116098, 0.02211469119148595, 0.05808189191988536, 0.11442627278821808, 0.1873768890010459, 0.13072127769035952, 0.19662035442888737, 0.09698634860771042, 0.16453966658030236, 0.1293278924588646, 0.22650950987424168, 0.2250760096524443, 0.18665671907365322, 0.20523130308304513, 0.3559441901743412, 1.0287997892924716, 24.209427697317942, 108.362548828125, 78.17359869820731, 68.63692515236991, 58.781232016427175, 34.41756125858852, 58.341153962271555, 94.07769870758057, 100.91319751739502, 84.77151775360107, 13.965433614594595, 0.4331583268940449, 0.5839784496596881, 10.651340910366603, 6.743751755782536, 7.588591473443167, 3.5292923109872, 2.940541914531163, 2.1269558455262865, 0.5561290926166943, 0.2485454502914633, 5.1460182666778564, 32.97403131212507, 93.00100585392543, 98.3761739730835, 101.37302235194615, 90.13754204341343, 92.88601316724504, 87.07745810917446, 88.5076961517334, 78.3750547681536, 74.10073144095284, 69.45146942138672, 66.46377182006836, 71.83112321581159, 80.06220245361328, 86.14211940765381, 88.0998785836356, 87.69522244589669, 86.72936725616455, 78.74115535191127, 65.96235506875175, 61.480315344674246, 61.267186301095144, 61.587581634521484, 59.417492457798545, 60.18772806440081, 63.47082832881382, 57.40933799743652, 61.50446728297642, 58.44949722290039, 67.01825196402413, 76.47500038146973, 73.86215114593506, 74.20524624415806, 73.69708279200962, 72.33087239946637, 70.61906555720738, 71.77992194039481, 73.72702257973808, 73.16587911333356, 73.83490031106132, 72.43263571602958, 70.85249028887067, 77.84707505362374, 68.2842206954956, 67.38039902278355, 69.3427231652396, 78.2093471799578, 64.53470870426723, 65.41842229025704, 58.73876462663923, 58.68707002912249, 60.14535794939314, 60.798870767865864, 62.43319129943848, 62.404960768563406, 58.79571206229073, 58.22922543116978, 55.894283294677734, 62.032530375889365, 66.40118939535958, 65.6774719783238, 62.52289949144636, 59.83868530818394, 55.52319737843105, 53.855480330330984, 62.005717277526855, 67.9219138281686, 69.39705113002232, 72.88066250937325, 69.34684344700405, 72.60835565839494, 70.03898130144391, 71.73341764722551, 67.96859182630266, 64.24198109763009, 62.5361636025565, 70.08189337594169, 72.79720074789864, 66.12173284803117, 59.51177256447928, 52.797707421439036, 53.08310120446341, 53.26006834847586, 55.15989691870553, 65.729889188494, 74.26335402897426, 70.81921536581856, 72.90343870435441, 73.07371820722307, 67.04841409410749, 66.45813683101109, 64.23958396911621, 60.24469634464809, 58.595451082502095, 59.82909679412842, 67.66173158373151, 71.54427378518241, 75.49062129429409, 78.73085117340088, 73.5630589893886, 73.81636251722063, 77.01506996154785, 77.36143766130719, 82.5873932157244, 72.61651979173932, 6.3838024990899225, 2.3596464565822055, 2.9577460885047913, 2.2663903406688144, 2.3042918954576765, 5.468797700745719, 9.538637280464172, 6.728645937783377, 1.3879359981843402, 0.157061708558883, 0.20458128010588034, 23.490798098700388, 59.96448244367327, 78.98948396955217, 94.72295706612724, 67.07649176461356, 97.29789693014962, 91.40881225040981, 75.29627323150635, 46.49665709904262, 61.82347297668457, 70.87413392748151, 81.54503141130719, 52.55330106190273, 0.2852093572063105, 0.2257873857659953, 0.12394260428845882, 0.1866796671279839, 0.17311294297022478, 0.13935537795935357, 0.14609526629958833, 0.14430938927190645, 0.16934761644474097, 0.20597876368888787, 0.1121121019657169, 0.10067742304610354], [0.045324771997651885, 0.015771124977618456, 0.0431131142457681, 0.03565109161926167, 0.04817313986963459, 0.026706137494849305, 0.06040586757340601, 0.0766464743231024, 0.03401961184239813, 0.05447536973016603, 0.07920086689825569, 0.07165758631059102, 0.2738938629627228, 21.537280797958374, 81.18883895874023, 55.99802337374006, 59.412837164742605, 36.469030788966585, 27.568525620869227, 32.13879183360508, 72.5530479976109, 75.94639532906669, 32.96361943653652, 0.7663822333727563, 0.0337866334510701, 3.1811315417289734, 2.7512886183602467, 3.343187851565225, 1.0686718097754886, 2.1574241306100572, 0.6524641290307045, 2.830252072640828, 3.2329918103558675, 0.15698797894375666, 11.217553087643214, 43.97543723242623, 80.25221484048026, 85.92637089320591, 84.34614903586251, 86.78530720302037, 81.33724553244454, 74.45850113459996, 64.36551312037876, 62.38151059831892, 62.443342617579866, 62.472198486328125, 58.83439268384661, 62.59702982221331, 68.63044943128313, 80.08784825461251, 78.31585611615861, 76.35537324632917, 75.26429762159074, 74.21755150386265, 61.8808650970459, 54.289489133017405, 57.83543280192784, 53.225480215890066, 55.48104613167899, 51.91169050761631, 52.52544920785086, 53.06782211576189, 53.33409098216465, 53.27074425561087, 59.88564123426165, 64.05471324920654, 67.06410312652588, 72.5127762385777, 68.97842911311558, 69.63441549028668, 67.24253981454032, 70.3386640548706, 69.14732592446464, 71.30784743172782, 69.308913230896, 68.51119055066789, 69.08611924307687, 67.08521175384521, 61.92102568490164, 61.549199785505024, 62.14714091164725, 63.771733965192524, 61.77162551879883, 52.95114796502249, 53.94724171502249, 65.01113278525216, 57.04574223927089, 54.040931224823, 65.79441016060966, 64.4486483165196, 61.273912157331196, 57.02083642142159, 49.772208145686555, 49.170789446149556, 55.78293146405901, 58.66529437473842, 60.467559814453125, 56.928262097494944, 54.39888504573277, 52.13746179853167, 48.03334501811436, 48.36609077453613, 55.15050295421055, 60.62137903485979, 64.47234167371477, 62.565179279872346, 63.68199798039028, 62.29263619014195, 56.60094288417271, 58.66273743765694, 62.98428072248186, 63.472614015851704, 62.27058260781424, 57.00499105453491, 51.749957289014546, 48.8640855380467, 47.356184005737305, 46.79906702041626, 47.55429451806204, 53.63659470421927, 63.84547519683838, 67.96548598153251, 67.77955913543701, 66.24001898084367, 65.37912327902657, 64.12313216073173, 62.85041672842843, 57.963682651519775, 51.06090790884835, 52.358518736703054, 53.96388612474714, 60.456206457955496, 63.747783524649485, 70.51779556274414, 72.55613994598389, 72.82958630153111, 68.5856682913644, 72.54866368430001, 69.51346819741386, 73.86482620239258, 63.96657535008022, 2.2824480618749345, 0.7783762354935918, 1.6604651915175574, 1.4217412642070224, 0.06762757005968265, 2.798585657562528, 2.1024853757449558, 0.9743720527206148, 0.10831518284976482, 0.15036958908396109, 2.110250856195177, 24.626366513116018, 43.27383245740618, 59.688298497881206, 78.44778851100376, 99.36454132625035, 121.07379177638462, 49.50976078850882, 18.758468627929688, 50.22329214641026, 47.283749035426546, 61.64517525264195, 44.559429849897114, 0.2844159597797053, 0.015552414481395056, 0.02491734446292477, 0.05923734206174101, 0.07072498742491007, 0.010194480602097298, 0.08252381573298148, 0.05638929310121706, 0.04000512869762523, 0.04409900866448879, 0.02799254998431674, 0.10553655480699879, 0.02202652913651296, 0.051943497732281685, 0.07893136635954891, 0.021758579050323794, 0.007167710606673998, 0.016967811388894916, 0.0592977927465524, 0.009784726026867117, 0.025969720046435083, 0.055758628728134293, 0.06201656721532345, 0.11674383628581252, 0.46877069451979225, 26.01504216875349, 91.08540139879499, 64.75388962881905, 64.26970441000802, 41.75903136389596, 30.606314522879465, 35.0958548273359, 83.77236679622105, 84.2578513281686, 37.31988981791905, 1.2453491921935762, 0.03683188504406384, 3.879848037447248, 2.871583431959152, 3.781154956136431, 2.4977662222726003, 2.734027121748243, 0.3333815708756447, 5.194819808006287, 3.000004598072597, 0.3680398368409702, 12.423351287841797, 57.356566429138184, 91.09036241258893, 91.38034548078264, 89.88815729958671, 89.99462454659599, 83.72677966526577, 77.2429986681257, 65.70299965994698, 64.89718232836042, 65.55484322139195, 63.63316604069301, 61.972831453595845, 63.80614144461495, 72.97644342694963, 82.66131510053361, 81.14204978942871, 78.75709451947893, 80.40738201141357, 78.32566697256905, 64.90278257642473, 56.88011455535889, 59.71823133741106, 56.87191915512085, 57.674210275922505, 56.395290102277485, 55.93462453569685, 56.56456906454903, 55.83942379270281, 57.07676247188023, 60.916573251996724, 64.25706563677106, 69.08611924307687, 76.31701224190849, 70.92384134020124, 73.52543449401855, 71.64222948891776, 72.76876177106584, 72.57667187282017, 75.99064145769391, 71.04007080623082, 71.37556457519531, 71.45266873495919, 69.2223595210484, 65.23963124411446, 62.81238923754011, 66.07219914027623, 64.61075673784528, 64.62115819113595, 54.88102402005877, 56.69310031618391, 67.2889746257237, 58.161119188581196, 55.923712389809744, 66.0061982018607, 68.03528758457729, 65.85964679718018, 59.71645259857178, 52.312504291534424, 51.678241457257954, 56.87104715619768, 62.803182874407085, 63.904090200151714, 60.42751734597342, 58.663786615644185, 54.638069834027974, 52.281223501477925, 50.46361296517508, 55.50030653817313, 61.84180927276611, 64.93312535967145, 65.11953163146973, 66.68285546983991, 66.62922927311489, 62.223550251552034, 64.13568755558559, 61.816462244306294, 66.91552979605538, 65.52003274645124, 60.821389879499165, 56.42106097085135, 50.404921531677246, 49.01559795652117, 48.6546425138201, 51.06384004865374, 56.25735446384975, 67.23106139046806, 70.6756169455392, 70.64968626839774, 69.93056855882917, 67.91855784824916, 67.2654549734933, 64.09460980551583, 60.72936793736049, 53.48730918339321, 52.90749243327549, 57.08790738242013, 60.7471900667463, 66.12615885053361, 74.35152666909354, 73.95722334725517, 74.60424654824394, 71.87274292537144, 71.700302532741, 74.39887864249093, 74.15872110639299, 72.55275617327008, 5.463372460433415, 1.064422226377896, 0.6140541072402681, 2.6956261651856557, 2.204403506858008, 4.539974238191332, 2.9104659855365753, 2.909224429300853, 1.9298078758375985, 0.38554044919354574, 1.493633189371654, 29.243637289319718, 49.52522053037371, 67.06002453395298, 83.17591258457729, 100.9752310344151, 113.45345224652971, 54.31911972590855, 22.784445966993058, 55.97855799538748, 52.97084263392857, 69.12179129464286, 53.69155148097447, 0.3305736029786723, 0.05722940766385623, 0.053626206903053183, 0.03780227154493332, 0.01010280628023403, 0.04144233372062445, 0.09949471615254879, 0.11712817209107534, 0.010983788158877619, 0.09428782840924603, 0.025043580814131668, 0.03524168733773487, 0.1483208883021559, 0.1476810569209712, 0.12787084707192012, 0.11625073131706033, 0.11143264413944312, 0.04785543620320303, 0.08718659303018025, 0.18511485680937767, 0.1721955771957125, 0.1147114203444549, 0.1877537202090025, 0.2276870666870049, 0.5327575238687652, 28.766582659312657, 103.36999716077531, 71.79207433973039, 77.98188400268555, 50.52208205631801, 39.11286551611764, 49.24855715887887, 95.91665063585553, 88.81452860151018, 49.844309602464946, 2.4105465710163116, 0.1761352600795882, 8.465019873210363, 6.622105300426483, 8.716394407408577, 6.992974953992026, 11.484660949025836, 2.743854262999126, 5.4325915064130506, 4.8668487668037415, 0.5352677777409554, 14.205229844365801, 64.17374978746686, 99.23179599217006, 95.60760865892682, 94.48383481161935, 91.79670238494873, 88.12321063450405, 79.93267413548061, 69.37950692858014, 68.08181967054094, 69.49525002070835, 66.45502403804234, 63.46963323865618, 67.40193843841553, 76.27439199175153, 87.35775538853237, 84.19755486079625, 80.18874999455043, 81.93816743578229, 82.62995093209403, 68.49662017822266, 59.88311903817313, 64.8419302531651, 59.1852628162929, 61.48859759739467, 58.24161754335676, 59.059694971357075, 57.99455002376011, 58.43863024030413, 60.434493337358745, 64.89390277862549, 69.45968914031982, 73.71467563084194, 78.08422401973179, 75.87081282479423, 76.74262414659772, 76.05889361245292, 77.92538125174386, 76.22763061523438, 77.03469167436872, 75.12135928017753, 73.22017233712333, 74.69471904209682, 73.44206305912563, 70.07395158495221, 67.20799337114606, 68.03313364301408, 68.24740219116211, 68.85040855407715, 58.12848697389875, 58.626731872558594, 67.15035806383405, 60.140098163059776, 59.10824203491211, 69.16620418003627, 68.94880199432373, 66.29496533530099, 62.828446524483816, 56.97573913846697, 53.95882436207363, 62.376292501177105, 68.1660943712507, 68.10700689043317, 63.40718977791922, 60.3539011819022, 58.78854846954346, 54.28000136784145, 53.90956858226231, 59.85266508374895, 66.20869650159563, 70.7719259262085, 69.16965048653739, 69.81713226863316, 69.41510254996163, 66.00835214342389, 64.02418981279645, 62.65851443154471, 70.56072153363908, 70.32810974121094, 64.0997792652675, 58.54277678898403, 53.72063316617693, 53.071938923427034, 51.30315685272217, 53.98748220716204, 59.42465605054583, 71.42712715693882, 75.0568938936506, 73.68397154126848, 73.34990910121373, 69.09952231815883, 71.91490459442139, 66.79678508213588, 63.39430086953299, 57.39780398777553, 55.761951378413606, 59.50337219238281, 64.7357895714896, 69.34089578901018, 77.94077845982143, 76.85426085335868, 78.59049756186349, 76.57577010563442, 76.30296298435756, 76.4901613507952, 79.3535487311227, 71.47054644993374, 2.9342453266893114, 4.122696697711945, 5.459525329726083, 5.6197603430066785, 4.030388576643808, 8.286436404500689, 8.069552728107997, 2.702323794364929, 1.3258058577775955, 0.2569261448723929, 3.838581817490714, 40.24223613739014, 59.50583185468401, 73.86106722695487, 91.79005295889718, 108.38335173470634, 127.797452381679, 57.61220802579607, 30.970507826123917, 68.6094172341483, 63.93872697012765, 78.7918563570295, 61.054592268807546, 0.5506845276270593, 0.11227005134735789, 0.16157146942402634, 0.16020882182887622, 0.133217133049454, 0.13391846684472902, 0.24032972114426748, 0.22721111508352415, 0.1181837690195867, 0.10924624146095344, 0.11492268900786128, 0.12162320874631405], [0.04106299871844905, 0.049742737252797396, 0.033389687072485685, 0.030444149593157426, 0.07078729051032237, 0.07343477130468402, 0.02918905658381326, 0.059296252472060065, 0.047983435049120865, 0.07821163069456816, 0.10418597834983043, 0.0916415418365172, 0.2719750202127865, 16.54206449644906, 71.94949272700718, 65.71176133837018, 56.75147908074515, 28.323122569492885, 41.80483736310686, 46.16140651702881, 78.93249484470913, 61.025958742414204, 15.473193577357701, 0.06028555652924946, 0.063471576997212, 2.281714592661176, 1.096037615622793, 2.807605939252036, 1.3187313973903656, 2.2538336430277144, 1.4951036018984658, 3.850874049322946, 0.3722868689468929, 5.6024727906499585, 55.02646023886544, 86.50446796417236, 88.14848123277936, 87.3411283493042, 82.67927619389125, 80.24484974997384, 68.42196873256138, 63.13549436841692, 62.258451053074424, 64.49830709184918, 63.665864263262065, 59.03282628740583, 59.28758198874337, 59.32031495230538, 63.528977802821565, 72.8542732511248, 77.41079071589878, 73.80366121019635, 76.2187716620309, 74.9424501146589, 65.98959200722831, 56.581328119550435, 53.280874729156494, 53.27658421652657, 55.24080869129726, 51.28797156470162, 52.877952166966026, 51.306464195251465, 53.10789932523455, 54.081130027770996, 60.880942889622276, 65.25598730359758, 75.40771538870675, 68.60554708753313, 64.61551625388009, 67.45949036734444, 70.46387754167829, 70.78978974478585, 71.04542786734444, 72.86939947945731, 66.39793069022042, 66.65620912824357, 63.991310937064036, 60.42451572418213, 57.31766693932669, 60.54007816314697, 62.61310795375279, 59.62803677150181, 57.70340313230242, 55.20570291791643, 63.48780277797154, 67.11549200330461, 54.78606298991612, 54.45410932813372, 63.728592600141255, 64.43444619859967, 63.05874456678118, 54.79854195458548, 49.385485308510916, 49.04323441641671, 53.00493049621582, 58.00957897731236, 60.02870464324951, 59.534527914864675, 57.10125487191336, 55.181359904153005, 52.42338017054966, 48.38493081501552, 47.69473498208182, 50.84634058816092, 53.78556408200945, 57.30515323366438, 58.617059980119976, 63.48026398250035, 61.747140066964285, 64.69476740700858, 64.99256025041852, 66.04126576014927, 62.799778257097515, 58.30762195587158, 54.44537891660418, 48.14567307063511, 50.0221209526062, 46.01464319229126, 46.348229680742534, 48.59298767362322, 57.24612481253487, 64.03272914886475, 65.238602910723, 64.28108555930001, 66.14591257912772, 64.42985343933105, 61.08326053619385, 57.773965563092915, 56.185840129852295, 49.58636815207345, 52.03170674187796, 52.42233099256243, 55.68034826006208, 58.65524727957589, 65.55932480948312, 63.70122364589146, 66.35538687024797, 65.4498073032924, 72.67735127040318, 70.90188503265381, 78.4349343436105, 42.26510688236782, 0.3196074185626847, 0.660480124609811, 0.7033214143344334, 1.7725978259529387, 4.12016190801348, 1.8624811342784335, 2.7007039955684116, 1.1181044429540634, 0.11366615750427757, 0.20916947961917945, 10.209690826279775, 34.27227790015084, 57.280813694000244, 102.55514717102051, 107.48453276497978, 77.70096138545445, 28.775723014559063, 32.68724094118391, 33.49148103169033, 52.13525227137974, 56.12952845437186, 51.93615511485508, 0.3064022585749626, 0.007423709994847221, 0.04406952292525342, 0.010352224726895136, 0.09354250518871204, 0.08369448541530541, 0.08348240250987665, 0.01905996724963188, 0.02306966985841947, 0.020429717410089712, 0.023141335030751567, 0.046626290372971974, 0.06525148970207997, 0.048038043547421694, 0.075542409638209, 0.03306306745590908, 0.027400141415585364, 0.017598477458315234, 0.010167025378905237, 0.08327748493424483, 0.01624874577724508, 0.056055141745933464, 0.11427459307014942, 0.2050555625132152, 0.44061586101140293, 22.900727544512065, 83.35457856314522, 73.24897262028286, 57.53573267800467, 29.9104037966047, 29.45618268421718, 36.06425653185163, 89.96682480403355, 69.82921518598283, 19.283929620470317, 0.153840268562947, 0.3948682158121041, 3.921645360333579, 2.119258327143533, 5.834118349211557, 2.614638613803046, 3.60855301788875, 1.3925164895398277, 3.8169572864259993, 0.12361270056239196, 9.382941177913121, 66.72937365940639, 92.58781038011823, 93.09315286363874, 91.39622906276158, 84.550676209586, 81.08754811968122, 70.43154757363456, 66.65311023167202, 66.81279373168945, 65.49166325160435, 66.64130524226597, 62.74017660958426, 62.49657276698521, 61.7190762928554, 66.55501556396484, 75.32211358206612, 80.71074731009347, 78.85486262185233, 79.18893201010567, 77.65312303815568, 69.48657866886684, 59.39015824454171, 55.790942737034385, 55.32767159598214, 56.772358417510986, 55.29170772007534, 55.9358161517552, 53.990480354854036, 55.73408562796456, 58.16750805718558, 64.12384782518659, 69.31389508928571, 75.43330560411725, 72.66669273376465, 66.21233735765729, 69.97546781812395, 71.84305327279228, 73.08776746477399, 71.03621455601284, 73.76284054347447, 67.81218787602016, 69.84297956739152, 66.15404891967773, 63.6962765284947, 60.56018624986921, 64.32853480747768, 64.8797492980957, 63.94604342324393, 60.51602349962507, 55.01265069416591, 68.60374055589948, 69.20828941890171, 56.43688896724156, 55.988455704280305, 65.85854203360421, 68.1284281866891, 65.25790500640869, 55.80597863878523, 52.453094141823904, 53.58003289358956, 55.731893471309114, 61.161705698285786, 62.9282990864345, 61.07504081726074, 59.79323019300188, 58.346031597682405, 57.82227986199515, 51.36099713189261, 49.2607547215053, 51.4221100125994, 54.886245591299875, 60.48706340789795, 61.01639107295445, 64.6922938483102, 64.45608983721051, 66.6151522227696, 67.39456639971051, 70.24817071642194, 66.14099325452531, 61.741789954049246, 58.94502190181187, 51.62622376850673, 50.95907163619995, 49.00245543888637, 49.861760003226145, 51.09245273045131, 59.569727488926475, 66.53223936898368, 65.9138149533953, 67.37909276144845, 67.13504423413957, 68.52412809644426, 65.86031382424491, 60.66063635689871, 59.50862503051758, 52.21305125100272, 53.20300279344831, 55.30020536695208, 58.00371469770159, 60.94867392948696, 66.74079649788993, 65.28669139317104, 68.87412970406669, 67.25340679713658, 74.99807044437954, 73.5964103426252, 80.25407000950405, 50.57135173252651, 0.8374423831701279, 1.0050318475280489, 1.1513901140008653, 3.6303506025246213, 2.8592573276587894, 3.5201547784464697, 3.5861018683229173, 4.19009769814355, 0.273152658449752, 0.2635704411992005, 9.632242543356758, 40.71428632736206, 61.434901918683735, 104.88696956634521, 105.31482573917934, 76.30877862657819, 26.81921798842294, 34.36341742106846, 38.48365749631609, 58.312923431396484, 62.5721344266619, 59.87127930777413, 0.4424461413707052, 0.08818825999540941, 0.014873107629162925, 0.0028613208934465157, 0.02649555415181177, 0.04881870487172689, 0.08084332876439605, 0.013613331031852534, 0.02552381736625518, 0.07567948049732617, 0.07000572673444237, 0.06473216614020721, 0.10661028897655861, 0.06732985603490046, 0.16965974255331925, 0.08798996492155961, 0.10465948722724404, 0.17782873420843057, 0.11046676989644766, 0.16782216115721635, 0.1535808646253177, 0.12496538726346833, 0.18701775398637566, 0.23084922986371176, 0.8140999100037983, 26.708368165152415, 95.03456987653459, 82.96950244903564, 72.1381641115461, 41.201608657836914, 55.85390036446707, 67.13568346840995, 95.77831895010812, 82.73513276236397, 26.969439779009136, 0.3928741913821016, 0.18970309703477792, 7.3908726658139905, 4.795694436345782, 10.902146560805184, 6.831645599433354, 14.285225323268346, 5.177114060946873, 9.03259129183633, 0.5540031066962651, 9.713271566799708, 72.65998772212437, 97.23980304173061, 94.23479052952358, 95.05887467520577, 87.65174756731305, 85.6774377822876, 76.32300853729248, 70.66397871289934, 68.44189616612026, 69.11856733049665, 69.53192956107003, 66.5044743674142, 65.05021640232631, 64.59116281781877, 70.1097000667027, 78.35157680511475, 84.76923874446324, 80.57341616494315, 82.04170254298619, 81.89561666761125, 71.95129925864083, 62.33423505510603, 57.62513862337385, 56.70583289010184, 61.1011313029698, 57.71415894372122, 59.14489378247942, 57.3670825277056, 58.089531898498535, 60.38313920157296, 66.79744516100202, 72.66194016592843, 78.35845552171979, 75.98053182874406, 71.1293898991176, 70.64205714634487, 75.52982997894287, 72.72463376181466, 75.02635656084333, 78.73897361755371, 73.82602746146065, 74.8253173828125, 69.72344970703125, 67.5526796068464, 63.70895004272461, 66.7982233592442, 69.5311027254377, 67.92656912122453, 64.6476308277675, 57.10374232700893, 69.42555958884103, 71.74125521523612, 58.54343686785017, 60.76779842376709, 68.81613309042794, 69.87085574013847, 67.83908435276577, 57.53236974988665, 54.98708132335118, 56.76084525244576, 58.9034230368478, 65.1067955834525, 67.48214844294957, 64.66330596378872, 62.452826908656526, 60.98412363869803, 60.59535803113665, 54.13497509275164, 53.68616315296718, 55.29016521998814, 59.78452410016741, 62.56490135192871, 64.05822208949498, 67.13368933541435, 68.41445078168596, 72.99662099565778, 71.52864728655133, 71.7644760949271, 68.72855104718889, 64.81098297664097, 60.866066796439036, 53.754859992435996, 55.55439479010445, 52.53797333581107, 52.318577017102925, 54.17872095108032, 62.27087443215506, 71.53051635197231, 70.49635342189244, 69.6646887915475, 71.35196849278041, 69.94165788378034, 69.47729587554932, 63.82405390058245, 62.912061146327424, 54.24100112915039, 56.93760742459978, 58.466172899518696, 61.34937654222761, 63.7595329284668, 72.17593451908657, 68.04682854243687, 72.27054813929966, 70.7569386618478, 80.63984094347272, 76.275726045881, 85.26151861463273, 50.36933633259365, 0.8346530614154679, 4.68583299432482, 3.9230701753071378, 10.310270343508039, 11.725631424358912, 8.891517673219953, 9.445329053061348, 3.927147899355207, 0.3683463175381933, 0.436066527983972, 15.656697239194598, 53.899472849709646, 70.17676407950265, 106.699476650783, 103.10707037789481, 81.6342671258109, 42.633621965135845, 48.55097886494228, 48.926282337733674, 69.2201430456979, 73.55485316685268, 69.54128183637346, 0.595565602183342, 0.12935050124568598, 0.09348839202097484, 0.10676302720925637, 0.2749751763684409, 0.1966265155268567, 0.15439881144889764, 0.12391630427113601, 0.1450345939291375, 0.15782250916319235, 0.12848356419375964, 0.14587571950895445], [0.035171041664268286, 0.10185301210731268, 0.05947537214628287, 0.023181504303855554, 0.05618242473740663, 0.04756371703531061, 0.054958415417266746, 0.04675176506862044, 0.02702180894890002, 0.025278396339022687, 0.08323897807193653, 0.09367473130779606, 0.2581543203975473, 16.276714529309952, 73.33779839106968, 53.129452637263704, 60.85305976867676, 42.64178957257952, 40.98804882594517, 66.90085520063127, 80.91728946140834, 41.450013705662315, 3.745223649910518, 0.12410846538841724, 0.11686978595597403, 2.065331620829446, 1.1833044929163796, 2.25748188155038, 1.2171669730118342, 0.4188063070178032, 0.8212551431996482, 0.027824230891253268, 3.5018008947372437, 65.52347905295235, 90.59965978349958, 86.24981648581368, 88.42378970554897, 80.89558328901018, 78.31358405521938, 71.0054965700422, 66.46063123430524, 66.67124502999442, 67.58702455248151, 67.04436329432896, 65.38561289651054, 62.02310167040144, 57.445149012974326, 58.4739340373448, 59.745391845703125, 67.1095860345023, 75.39909267425537, 75.69709396362305, 73.02559498378209, 74.6001957484654, 68.12849766867501, 54.39497320992606, 53.05989422116961, 54.49136209487915, 51.215661661965505, 51.52215712411063, 52.16817283630371, 56.19684955051967, 60.91223062787737, 63.50405461447579, 64.72490174429757, 66.17822170257568, 76.80053738185337, 62.51419339861189, 57.6702949660165, 68.72386796133858, 72.37930134364537, 69.59895883287702, 66.73650251116071, 63.04595988137381, 61.79461710793631, 56.679950850350515, 53.19079828262329, 55.88519157682146, 57.34321893964495, 63.656379972185405, 57.99707221984863, 56.747824328286306, 54.41846854346139, 57.12661232267107, 65.72906930106026, 60.9574008669172, 55.224508217402864, 54.353509834834504, 58.50561087472098, 64.35807854788644, 63.10652732849121, 55.78699616023472, 51.946747643607004, 53.10920558656965, 53.32182741165161, 55.06442172186715, 60.62754208700997, 60.59912395477295, 61.12663813999721, 60.28070190974644, 57.695551667894634, 52.533272879464285, 47.63898263658796, 47.629998615809846, 46.46018600463867, 50.83603640965053, 53.313378402165, 56.75269154139927, 57.73155723299299, 57.500852721078054, 62.346192904881065, 65.05320412772042, 65.86821392604283, 59.315756934029714, 58.421134676252095, 53.884440422058105, 48.141921043395996, 45.998644965035574, 46.81281055722918, 47.90523413249424, 48.23566266468593, 59.42858873094831, 62.65207345145089, 62.54974038260323, 67.29747227260044, 66.65175533294678, 64.71374988555908, 59.797656195504324, 55.745143686022075, 53.55896942956107, 52.03518084117344, 52.1822429384504, 50.426700660160606, 53.26785033089774, 52.44390862328665, 54.111097608293804, 54.58204303468977, 58.95335974012102, 61.994697434561594, 69.20416218893868, 74.01815904889787, 72.20752797807965, 9.8705119064876, 0.491343654692173, 1.475731155702046, 3.569630946431841, 3.450055488518306, 1.7239624985626765, 3.45475920183318, 5.05880925485066, 0.45072595136506216, 0.03620055570666279, 0.8971109613776207, 23.755494935171946, 51.40100138528006, 101.85740212031773, 92.1029303414481, 72.61289978027344, 35.45120654787336, 21.91975654874529, 39.31570775168282, 53.07498918260847, 51.4723732812064, 52.15572166442871, 0.7125999193106378, 0.04706488183832594, 0.07182762718626431, 0.03601055233074086, 0.011726593166323645, 0.06969598906912974, 0.011405328887381723, 0.034497303888201714, 0.05182555477534022, 0.027443138483379568, 0.015220677014440298, 0.030163812850202833, 0.09831755967544657, 0.1600714727704014, 0.023642238063205565, 0.04820338896076594, 0.0623886961756008, 0.08739014675042459, 0.04239618432308946, 0.07119982623096023, 0.05569435449849282, 0.05367395541231547, 0.08999563301248209, 0.2349908176277365, 0.3666210472583771, 19.071418966565812, 81.7806795665196, 61.98388603755406, 64.24706717899868, 45.657842772347585, 39.251680101667134, 66.59034715379987, 91.48622907911027, 48.79911640712193, 4.104413381644657, 0.3306791287447725, 1.578506086553846, 5.730508548872812, 2.349530747958592, 4.476360874516623, 3.699707303728376, 3.1637562683650424, 0.2922726624778339, 0.12048390773790223, 6.615865818091801, 75.24641295841762, 96.84117099217006, 88.82547896248954, 91.24376474108014, 85.12891919272286, 80.56017289842877, 74.85355486188615, 70.90062740870884, 71.14227185930524, 70.91302299499512, 70.48930100032261, 68.46369961329869, 63.97683089120047, 60.69726725987026, 60.45761694226946, 61.981440271650044, 69.37590081351144, 77.99753134591239, 77.77719007219586, 76.03318527766636, 77.09284809657505, 71.92436109270368, 59.608213560921804, 55.44368914195469, 57.20774643761771, 54.333745683942524, 52.85966450827462, 53.54938438960484, 57.86551850182669, 65.52647372654506, 67.72656522478376, 70.05895042419434, 69.57765565599713, 82.58348137991769, 66.98970181601388, 62.76376574380057, 68.97833183833531, 76.21067701067243, 70.6378812789917, 70.48558371407645, 65.19173731122697, 63.74904114859444, 59.003233909606934, 55.936361585344585, 58.547918455941335, 60.96098613739014, 65.48987061636788, 62.51106670924595, 59.47064617701939, 56.76154007230486, 61.377224922180176, 68.83879811423165, 60.90790884835379, 56.81123011452811, 58.437615803309846, 59.886864117213655, 64.51172406332833, 65.17001029423305, 57.14356940133231, 52.36180523463658, 55.70804377964565, 54.632778780800955, 57.93690429415022, 64.25493253980363, 61.7981606892177, 60.791255542210166, 63.39426612854004, 61.86722578321184, 53.59334216799055, 51.676758016858784, 49.49583659853254, 49.25958742414202, 51.876893929072786, 56.155320167541504, 59.30222879137312, 61.578243255615234, 62.02922303336007, 64.36851474217006, 67.88767310551235, 67.47867434365409, 63.60326099395752, 61.57331003461565, 56.321670464106965, 50.04023143223354, 48.86072955812727, 49.02954299109322, 49.558523246220176, 49.211373874119346, 60.68576104300362, 66.718916620527, 66.70604855673653, 70.15145179203579, 70.0800312587193, 68.90589686802456, 62.81729466574532, 57.994688987731934, 56.1002904347011, 54.128190176827566, 54.77034616470337, 52.533477851322715, 55.177389008658274, 53.89572082247053, 56.61804240090506, 55.87542240960257, 61.50314712524414, 64.12964957101005, 71.53724220820835, 76.46645409720284, 78.41708442143032, 12.876714297703334, 0.11119310092180967, 0.7394595923168319, 2.554915155683245, 2.401599896805627, 2.0950251817703247, 3.3894674139363423, 4.209713331290653, 0.9816261891807828, 0.07818078449262039, 0.44614147022366524, 26.410882779530116, 56.5995636667524, 103.5662281853812, 96.60329941340855, 75.77104364122663, 41.99738584245954, 28.389404909951345, 42.517941406794954, 60.7181396484375, 56.8272248676845, 62.71941539219448, 1.020935948405947, 0.06850118389619247, 0.03936008956017239, 0.05825724572475467, 0.011681895520138954, 0.020913438239533986, 0.04894722618960908, 0.02735113592020103, 0.0109009500592947, 0.03718224660094295, 0.040751663103167496, 0.04661120314683233, 0.19958842944886002, 0.2807808576950005, 0.1563241681350129, 0.20104741544595786, 0.15929600223898888, 0.18358641596777098, 0.19706647763294832, 0.12807963229715824, 0.09066444462431328, 0.21582704809095177, 0.22367756254971027, 0.3573545930641038, 0.6219229421445301, 22.17647511618478, 93.70984717777797, 68.24965340750558, 76.2625731059483, 62.13851819719587, 59.12648800441197, 93.35120895930699, 94.91818755013603, 61.36438465118408, 6.609863877296448, 0.30896318544234547, 1.8869083949497767, 6.590028507368905, 5.434238229479108, 7.073856328214918, 8.443192975861685, 8.06720336845943, 3.6115789583751132, 0.31029677816799706, 6.204340951783316, 78.53673240116665, 99.24445561000279, 92.78805746350969, 95.18126719338554, 90.26321411132812, 84.87400368281773, 77.20178195408413, 74.7114919934954, 72.53416279384068, 74.3310294832502, 74.57643985748291, 72.00544657026018, 67.03399658203125, 66.95276519230434, 62.6496068409511, 65.80508954184396, 71.94357981000627, 81.14557947431291, 82.07961886269706, 78.37637492588588, 80.29833698272705, 74.44155447823661, 62.50156157357352, 58.394509179251536, 61.43456840515137, 57.79540422984532, 55.401246070861816, 57.55968311854771, 58.765383175441194, 67.65119116646903, 71.75882720947266, 75.05348927634103, 71.9070600782122, 77.96898119790214, 71.49837398529053, 63.01731940678188, 71.46070085253034, 78.52779701777867, 72.81951836177281, 73.82099001748222, 70.25377096448625, 67.81381375449044, 63.035982268197195, 59.28237778799874, 63.36628573281424, 64.86359473637172, 68.88035529000419, 65.08093438829694, 64.62913472311837, 58.869272640773225, 60.325316292899, 70.85870892660958, 63.465624128069194, 57.13086462020874, 60.50130026681082, 63.20425374167306, 67.58231367383684, 66.9763126373291, 58.159024306706016, 53.071570668901714, 56.95487022399902, 59.730849266052246, 61.38786956242153, 67.97925731113979, 66.58366993495396, 64.61890697479248, 66.3155597959246, 64.91842991965157, 57.443245206560405, 54.866828850337434, 52.98895311355591, 51.60806465148926, 56.14906678880964, 59.15664318629673, 64.08097743988037, 65.35959189278739, 64.41986887795585, 69.79851804460797, 70.8436313356672, 70.76831981113979, 64.81261580330985, 64.83820601872036, 59.728910718645366, 53.585619245256694, 52.447101320539204, 51.68313993726458, 51.658320971897666, 52.28064680099487, 65.73830345698765, 69.14227458408901, 69.78212029593331, 72.05459117889404, 71.70571517944336, 70.96102115086147, 63.352903502328054, 61.254804611206055, 58.06318780354091, 57.688898767743794, 57.440681321280344, 55.63811016082764, 58.329592159816194, 57.13496058327811, 60.500077383858816, 60.87465476989746, 66.00367600577218, 68.21424538748605, 75.94237232208252, 80.90903500148228, 79.8336831501552, 13.579814672470093, 1.6001776265246528, 7.98939049243927, 8.650730456624713, 10.38512589250292, 7.241727411746979, 12.922062584332057, 11.077309778758458, 0.7620806470513344, 0.1840669951800789, 1.3499610530478614, 38.70336300986153, 64.51220348903111, 108.89646925245012, 97.40817873818534, 86.23972075326103, 48.08928843906948, 34.83900424412319, 53.79703555788313, 67.91663319723946, 66.84988321576799, 72.69581263405937, 1.1024252900055476, 0.22872633806296758, 0.17517510588679994, 0.13191995051290306, 0.11662678899509565, 0.16677287460437842, 0.12332949361630849, 0.1092450540246708, 0.16054842860570975, 0.20426874687629087, 0.08052984558578048, 0.16407014748879842], [0.004754777315870992, 0.019904733169823885, 0.11765262537768909, 0.02107454789802432, 0.01985944265366665, 0.024192202570182935, 0.021719056081825068, 0.04232878204701202, 0.047493390273302794, 0.04338118646826063, 0.03518306191212364, 0.08738282535757337, 0.16343912349215575, 9.086964419909886, 70.71406827654157, 56.95169489724295, 54.51787294660296, 40.438741615840364, 30.195964336395264, 59.47104222433907, 75.71654891967773, 25.51720895086016, 0.1471589920776231, 0.10308286361396313, 1.5151344984769821, 3.8000879287719727, 0.6610608963029725, 3.2424246413367133, 0.8705852361662048, 1.6365893355437686, 1.5141493741955077, 1.2166890672274997, 48.5808595929827, 87.91290255955288, 75.98430470057896, 88.14747374398368, 81.85042558397565, 83.64131682259696, 79.12351472037179, 77.53289140973772, 77.1878091267177, 78.70572648729596, 76.10682923453194, 76.83440290178571, 70.72183636256626, 64.31843907492501, 57.70747825077602, 58.84596838269915, 55.26403999328613, 61.09918580736433, 63.80265344892229, 69.8260884966169, 70.67230960300991, 69.8622191292899, 66.45865794590541, 55.15613099506923, 53.148928437914165, 53.85873556137085, 52.68759931836809, 49.24406514848982, 57.3693128994533, 66.71388612474713, 66.82449449811662, 68.03203582763672, 64.28776277814592, 77.75238500322614, 64.04479122161865, 56.10962881360735, 66.86257757459367, 68.3785285949707, 69.8157982145037, 66.48248331887382, 62.624009677342, 56.07558264051165, 49.9448778288705, 50.485416412353516, 52.581611497061594, 58.05826847893851, 62.767510822841096, 62.11434541429792, 55.540102345602854, 53.62576593671526, 59.27746541159493, 65.02855886731828, 65.00120380946568, 58.75428690229143, 55.22373696735927, 51.21818038395473, 51.49271065848214, 57.40106269291469, 54.48597724097115, 50.181356293814524, 49.44304765973772, 50.86074767793928, 47.39282185690743, 52.83880254200527, 55.00344780513218, 58.7237982068743, 58.693490164620535, 59.166481835501536, 58.80670411246163, 58.091890811920166, 50.15407419204712, 47.93266214643206, 49.164852210453574, 47.84788022722517, 50.21045534951346, 50.19538123267037, 57.66558061327253, 60.621955735342844, 59.98004640851702, 61.32382106781006, 61.68348067147391, 67.35226576668876, 60.96826784951346, 58.991797174726216, 51.60190159933907, 47.713460377284456, 45.05100447790963, 46.54135486057827, 45.67508125305176, 51.57280254364014, 60.86840833936419, 64.51330130440849, 65.24604443141392, 64.2310515812465, 64.54643726348877, 67.96629197256905, 58.22688388824463, 58.0127786227635, 54.570755686078755, 53.494594369615825, 54.38690982546125, 55.628924642290386, 54.953250544411794, 53.88095242636544, 55.52064044134957, 63.519132205418174, 61.930565561567036, 73.35946982247489, 66.63716411590576, 81.92869704110282, 23.981134210314067, 0.06638252615396466, 0.2759895319385188, 1.9533260081495558, 0.8108421276722635, 1.1547343688351768, 2.282098046370915, 5.61630665404456, 0.6033125721982547, 0.24814630885209354, 0.131643271073699, 9.117353234972272, 32.82662180491856, 58.99347169058663, 78.74879837036133, 36.169962951115195, 27.651580912726267, 36.51477425439017, 40.46966804776873, 52.99686016355242, 51.79703480856759, 56.72265795298985, 1.577263770358903, 0.0668591834338648, 0.0037473869077595218, 0.07883487189454691, 0.021335052758721367, 0.02344719147575753, 0.03408648146848593, 0.04247616324573755, 0.023001380397805145, 0.04035355982237628, 0.053347932906555276, 0.05730123059558017, 0.03685391368344426, 0.009298381811406995, 0.05632881188232984, 0.009779469924978912, 0.03606931007068072, 0.027957897200914364, 0.04612185386940837, 0.03179910938654627, 0.029873216657766273, 0.12926180314804825, 0.043889487228755436, 0.17398597326661858, 0.32799625556383816, 12.664741260664803, 80.89196327754429, 64.98938492366246, 62.01971789768764, 42.27279159000942, 26.224436555589946, 62.21913119724819, 84.87906891959054, 30.259932926722936, 0.1427435204386711, 0.2186692412942648, 3.4750885452542986, 6.152561238833836, 1.9140875765255518, 8.732158132961818, 3.0506641311304907, 1.4117707077945982, 0.41489007430417196, 1.760518274136952, 58.76681450435093, 90.42218889508928, 84.78259318215507, 93.01590973990304, 85.95307282039097, 85.9532812663487, 81.86909539358956, 79.80327088492257, 81.6228025981358, 82.53592096056256, 79.42977046966553, 81.59309210096086, 75.13077408926827, 68.03179958888462, 63.25945717947823, 61.521698815482004, 58.8340174811227, 62.57556683676583, 68.16061919076103, 73.85047817230225, 73.87119770050049, 72.38582570212228, 69.73081479753766, 59.683789116995676, 55.48512125015259, 56.77960538864136, 56.15061623709542, 51.829552377973286, 61.215804372514995, 70.00946535382951, 70.08269241877964, 73.58429963248116, 69.17365264892578, 84.33820029667446, 70.00075926099504, 59.881437574114116, 71.32257761274064, 70.29366057259696, 73.79949923924038, 67.83137880052838, 64.26908602033342, 57.11837175914219, 53.35738134384155, 54.41076646532331, 57.33527020045689, 61.97524247850691, 65.7849189213344, 64.99446405683244, 60.62427643367222, 56.91470963614327, 62.03261375427246, 66.67944390433175, 67.84387166159493, 60.779575620378765, 55.78880616596767, 53.6069015775408, 52.78671189716884, 54.020809241703574, 53.59424195970808, 49.20550612040928, 50.312017168317524, 52.5479405266898, 49.63715253557478, 54.05065522875105, 56.396915980747764, 63.13662692478725, 60.93497903006417, 62.7911833354405, 62.77968406677246, 61.492551122392925, 52.7500010899135, 51.18912649154663, 51.46958357947213, 49.950075081416536, 50.73523889269148, 52.98048325947353, 58.17693676267351, 60.93468720572335, 63.967228480747764, 63.992554664611816, 61.69989231654576, 68.23358222416469, 63.88144602094378, 62.333658354622976, 54.24982534136091, 50.15509557723999, 47.9872784614563, 49.900048051561626, 48.51558821541922, 53.54743194580078, 62.78101117270333, 66.14095156533378, 67.9429599217006, 67.23745373317173, 66.83864103044782, 69.10247530255998, 60.37847696031843, 59.78892925807408, 57.04847982951573, 56.37804119927542, 57.11549520492554, 58.41126128605434, 57.600006989070344, 58.337527002607075, 59.879686628069194, 65.81736006055559, 64.81305353982108, 75.4444227218628, 68.7532102039882, 82.79947308131626, 29.862933703831263, 0.085922000530575, 0.5421289610011237, 1.5224653908184596, 3.463930823973247, 1.8538247644901276, 3.5154734296458106, 3.5745530937399184, 2.588301249912807, 0.9276835237230573, 0.19468393762196812, 8.419783626283918, 40.748617376599995, 62.07952104296003, 82.99710069383893, 42.2535902432033, 26.8504136630467, 29.15069818496704, 43.851033210754395, 57.841957160404746, 58.31284005301339, 66.59384904588971, 2.436161973646709, 0.06893650482275657, 0.078797179274261, 0.08991386954273496, 0.03738675705556359, 0.004575816249208791, 0.025266537243234258, 0.02550980052910745, 0.022155109826209288, 0.019687603660193936, 0.022175962903669903, 0.02839069058453398, 0.06780905782112054, 0.10671236099941389, 0.14644393830427102, 0.09651310435895409, 0.11759409494698048, 0.09776885554726635, 0.10968053101428918, 0.12070998203541551, 0.17621114743607386, 0.23697773101074354, 0.1242239520485912, 0.22074204363993236, 0.4599429539271763, 15.510767698287964, 93.06730556488037, 69.37590081351144, 73.10746560777936, 52.23990951265608, 45.83147130693708, 73.56949996948242, 93.86850234440395, 43.47325965336391, 0.6199657214539391, 0.32896571925708223, 3.1929819115570615, 11.494973812784467, 4.26388452734266, 16.073792389460973, 8.15300406728472, 9.187263403620038, 5.136919600622995, 2.135074164186205, 64.03074196406773, 99.02442005702427, 90.88757228851318, 96.8573533466884, 90.57369436536516, 88.0196338381086, 83.18926007407052, 82.22095911843437, 85.43951061793736, 86.48489488874162, 83.73540932791573, 82.75520610809326, 79.58760574885777, 71.93268503461564, 66.71524102347237, 63.92922183445522, 61.807929856436594, 66.99594129834855, 73.03915786743164, 76.5850112097604, 77.4206988470895, 75.51921313149589, 72.0740669795445, 63.09308951241629, 60.738664627075195, 60.46291841779436, 59.09092712402344, 56.40498978751046, 63.08929579598563, 70.91685145241874, 74.25181307111467, 74.81297043391636, 73.57960959843227, 77.68181215013776, 71.85462897164481, 65.25703648158482, 73.21913010733468, 76.39999457768032, 77.4006324495588, 73.39817128862653, 69.12304197038922, 62.634800229753765, 55.602848052978516, 57.245159012930735, 57.99300752367292, 65.23516355242047, 69.57409123011998, 70.65712084089006, 63.4744552884783, 60.892365728105815, 64.4894550868443, 68.38637311117989, 70.29356329781669, 60.74935095650809, 57.797228131975444, 56.71112741742815, 55.8358975819179, 58.64019053322928, 55.756497042519705, 51.501600878579275, 50.90480967930385, 54.26237031391689, 52.7861247743879, 57.472649982997346, 61.047720500401084, 67.19427067892892, 64.64504609789167, 66.30180931091309, 66.23421723502022, 64.39921883174351, 54.603589398520334, 53.77958515712193, 53.67026914869036, 53.58670316423689, 55.55555166516985, 55.40077359335763, 62.99073559897286, 65.1746516908918, 65.22384493691581, 65.34142235347203, 66.96683529445103, 71.16581235613141, 66.83686229160854, 66.03450516292027, 58.549349784851074, 53.70181744439261, 52.76465136664254, 52.42325857707432, 50.76336520058768, 58.57103511265346, 67.34341376168388, 67.92078821999687, 70.32646996634347, 71.15978826795305, 68.85607133592877, 74.31871727534703, 63.372754505702424, 62.89259924207415, 61.37713459559849, 58.182999065944124, 60.35256017957415, 61.0886037009103, 59.35608427865164, 59.799226488385884, 63.40905884334019, 68.26011044638497, 68.47310052599225, 80.8121701649257, 73.73350524902344, 87.98348236083984, 32.34165491376604, 0.31866205643330303, 4.005103647708893, 6.050276807376316, 6.4231762034552435, 6.314298800059727, 8.650046059063502, 12.721597501209803, 3.940750300884247, 0.8132299738270896, 0.27445824124983376, 14.609219823564802, 50.91040645326887, 69.65221677507672, 87.62182167598179, 49.24773032324654, 39.93506669998169, 50.231675148010254, 56.634141377040315, 65.47614792415074, 66.37480013711112, 78.13293089185441, 3.2204346784523556, 0.2894466726907662, 0.20606155853186334, 0.16861650853284768, 0.14346503386540072, 0.1771511219974075, 0.09713116155139037, 0.11278102892850127, 0.15197156955088886, 0.09868120016264063, 0.15123902314475604, 0.176521522924304], [0.026572681531043987, 0.002813956392596343, 0.08407445824039833, 0.018564165104180574, 0.03810896258801222, 0.004266402584367565, 0.017514201712661555, 0.04185236903971859, 0.008654814246775848, 0.0775664931695376, 0.10924890131822654, 0.08676985039242677, 0.3224896996148995, 7.6806716067450385, 62.51989092145647, 52.03887728282383, 56.667739391326904, 52.929129123687744, 55.072565010615754, 73.50170639583042, 61.58392688206264, 10.92292775426592, 0.061430265461759906, 0.15337019307272776, 2.4802022618906836, 5.009630339486258, 2.2782024954046523, 2.9254130806241716, 1.7356666305235453, 1.1063992253371646, 0.09747078868427447, 31.637798922402517, 74.12344510214669, 56.61037506375994, 77.86751665387834, 84.43437031337193, 83.3428430557251, 80.85409559522355, 84.27154622759137, 80.88646725245884, 81.2353571483067, 79.91298988887242, 80.81904888153076, 77.48817975180489, 76.6146661213466, 72.06416579655239, 60.216486658368794, 56.620731353759766, 56.74512495313372, 54.583644594464985, 59.93610600062779, 62.992180824279785, 67.20283085959298, 68.7329353604998, 60.15666266850063, 54.331636905670166, 52.9746606690543, 55.349596636635916, 51.83365528924124, 50.63649109431675, 66.37659972054618, 70.18636648995536, 70.97508430480957, 69.08871786934989, 76.1069334575108, 69.0145458493914, 52.713394505637034, 65.72371918814522, 64.81868158067975, 64.80176966530937, 60.90742942265102, 58.29903398241316, 50.62835127966744, 51.47672980172293, 53.003829206739155, 55.54378489085606, 56.45774051121303, 59.64669268471854, 60.82451656886509, 57.181221689496724, 54.51593787329537, 55.855411597660606, 64.42347499302456, 64.96924209594727, 62.725001743861604, 56.88582944869995, 51.186274256025044, 51.28682163783482, 46.759187834603445, 52.29393523080008, 48.57483550480434, 50.653017384665354, 51.67649745941162, 52.24676043646676, 48.869953291756765, 50.51628725869315, 52.552380425589426, 55.94026299885341, 57.891188621520996, 57.98831401552473, 59.98978083474295, 57.74745123726981, 51.7507563318525, 49.58683715547834, 46.223641531808035, 49.68751655306135, 49.01822090148926, 47.984943866729736, 49.50537994929722, 53.18758474077497, 60.30846691131592, 61.70525632585798, 62.78324849264962, 59.75402845655169, 62.29589489528111, 60.134164401463096, 54.19279452732631, 49.04772295270647, 46.11508982522147, 46.41921247754778, 45.41732392992292, 46.982760020664756, 55.87851783207485, 63.447899273463655, 64.60758141108921, 66.91751003265381, 67.58664934975761, 65.27645669664655, 59.12347943442208, 57.4662298474993, 56.76309994288853, 58.85865579332624, 58.321969985961914, 60.146226474217, 61.620974676949636, 65.00628294263566, 66.06550107683454, 67.74933447156633, 67.09479331970215, 68.68586131504604, 69.85451357705253, 73.34606674739292, 57.83798279081072, 2.2676853111812045, 1.0488992993320738, 0.2763917403561728, 0.9128219783306122, 1.1464795832123076, 1.9798876685755593, 2.890161829335349, 2.760993080479758, 0.4404560795852116, 0.1027666934366737, 1.0865434450762612, 26.13570805958339, 30.437184946877615, 71.05335576193673, 47.784943444388254, 45.00813756670271, 39.13812569209507, 33.55296564102173, 50.409385749271934, 46.22922093527657, 49.60913739885603, 2.2902315642152513, 0.05108508308018957, 0.0747718381296311, 0.025723598431795835, 0.04264988178121192, 0.018755717236282568, 0.0938275306086455, 0.05341517233422824, 0.01084484369494021, 0.02016490894103689, 0.009386682117890035, 0.011716901141751026, 0.03786073072946497, 0.019447848400367156, 0.03936045257640736, 0.028159793599375656, 0.02314202204745795, 0.02167273249610194, 0.0973904976355178, 0.016971751981015717, 0.03664726923618998, 0.10111604843820844, 0.0702643571421504, 0.08116317660148654, 0.2756071910262108, 9.496602416038513, 72.35268974304199, 57.34662703105381, 62.71651104518345, 57.43757895060948, 42.41699797766549, 78.6030182157244, 72.7558103288923, 11.487043312617711, 0.16591766263757432, 0.9116120146853584, 4.558463394641876, 4.618349484034947, 3.375001698732376, 1.6469581105879374, 2.0359902467046465, 0.4374820605984756, 0.11196209144379411, 41.8267102922712, 79.58328396933419, 66.02184554508754, 85.22187219347272, 87.05353546142578, 86.96987915039062, 84.33848517281669, 86.67993082318986, 86.2212802342006, 87.2809430531093, 86.4937468937465, 85.0609519141061, 80.89959934779576, 81.80076680864606, 77.39551162719727, 63.24843733651297, 58.43574673788888, 57.00534541266305, 58.30228573935372, 63.180629866463796, 68.20984717777797, 70.10997104644775, 72.32531384059361, 63.20043223244803, 55.93663951328823, 55.793635163988384, 57.64179345539638, 54.42402710233416, 52.693130084446494, 70.0859511239188, 71.12357425689697, 74.3846070425851, 72.00370952061245, 77.00885827200753, 73.94573102678571, 57.35994325365339, 70.32103647504533, 66.73288249969482, 66.94870049612862, 63.04291657039097, 59.536612374441965, 52.94920594351632, 53.135285649980815, 55.89606898171561, 60.78657940455845, 60.312066078186035, 62.33136544908796, 63.447968755449565, 59.90866756439209, 57.93681396756853, 57.22691651753017, 67.2252596446446, 66.52823720659528, 63.19494315556118, 57.84965576444353, 51.191197054726736, 51.733583859034944, 49.71500710078648, 53.80075979232788, 48.38257190159389, 52.6199586050851, 53.98111070905413, 52.82973166874477, 50.051331179482595, 53.078911440713064, 56.43162570680891, 57.3589322907584, 60.69858046940395, 62.148433276585166, 64.3321200779506, 60.58137130737305, 52.55856779643467, 51.91459138052804, 50.41413484300886, 51.145352840423584, 52.42102473122733, 49.995464188711985, 53.51548760277884, 54.993605681828086, 61.361153738839285, 64.08193629128593, 63.85817650386265, 62.094709805079866, 64.53619561876569, 63.221575600760325, 57.91087286812918, 50.53940044130598, 48.70705624989101, 49.348062310900005, 49.18961559023176, 48.92855439867292, 57.95448671068464, 64.84368119921002, 66.33764117104667, 68.71367495400565, 71.03067684173584, 68.55458899906704, 62.740273884364534, 60.03156730106899, 60.21032360621861, 61.988979067121235, 62.097822598048616, 62.980243819100515, 64.49024718148368, 67.97282327924455, 68.39157036372593, 68.92643574305943, 69.43481458936418, 71.4030863898141, 74.69203703744071, 74.7966560636248, 62.54315349033901, 5.828724375792912, 1.3722457715443201, 0.2977237142622471, 1.2195042818784714, 2.9866959750652313, 3.939560421875545, 5.403646179607936, 2.626535449709211, 2.3600474979196275, 0.1057199424664889, 0.7526077553629875, 30.015512670789445, 35.81191880362374, 76.39021151406425, 57.730445521218435, 39.78455482210432, 44.33951589039394, 41.788641112191335, 54.8605546270098, 53.31031424658639, 61.71157223837716, 4.186961455004556, 0.24392245550240788, 0.07136367886726346, 0.03769657614507845, 0.04201742607567992, 0.0703850956633687, 0.07446382394326584, 0.0454938459609236, 0.0631139347595828, 0.06038839529667582, 0.04321993601375392, 0.024964044635583247, 0.1547598870737212, 0.08043266580040966, 0.3027631938457489, 0.08720009587705135, 0.17903683866773332, 0.20451273449829646, 0.20671565271914005, 0.09651727056396858, 0.11008948407002858, 0.2871870696544647, 0.2347145453095436, 0.21150571640048707, 0.5031881619776998, 13.163218923977443, 83.81408378056118, 64.92347431182861, 73.29203060695103, 63.78109318869454, 81.66940416608537, 90.99883379255022, 84.54688249315534, 16.981204543794902, 0.30677108306969914, 0.7617169522813388, 6.438912570476532, 10.685480884143285, 5.573152261120932, 11.752001575061254, 10.645096216882978, 6.289494165352412, 0.13910305792731897, 43.18413816179548, 83.82979365757534, 70.37935270581926, 89.69442067827497, 89.83864443642753, 92.07814611707414, 87.45375864846366, 92.56549276624406, 89.77966812678746, 90.25782230922154, 90.290513583592, 87.3097711290632, 85.34218720027378, 83.8925358908517, 80.79326411655971, 65.99845096043178, 63.49149227142334, 61.678359849112375, 61.477681977408274, 66.69119330814907, 69.87508719308036, 74.2278139931815, 75.76144817897251, 65.5249034336635, 58.1290636743818, 56.79281044006348, 60.89277567182268, 55.434687750680105, 55.94317429406302, 72.5176191329956, 72.85708727155412, 76.0226309640067, 75.19468361990792, 79.8960849217006, 73.31766251155308, 60.719980921064106, 71.03784043448312, 71.78548744746617, 69.57916341509137, 66.07722268785749, 64.15330818721226, 54.93171460287911, 57.56614146913801, 58.286846842084614, 62.76400893075125, 62.47953578404018, 64.36724322182792, 68.19894545418876, 65.01439843858991, 62.74927180153983, 58.4123660496303, 70.30942603519985, 70.65591880253383, 66.08393464769635, 59.83279323577881, 52.6794490814209, 54.34015539714268, 50.873056411743164, 54.372419357299805, 49.069918973105295, 52.433680874960764, 55.224372727530344, 52.68806137357439, 51.65527071271624, 54.80318682534354, 60.1300163269043, 62.64957209995815, 65.10094520023891, 65.38869789668492, 68.4662218093872, 65.51687131609235, 56.09235559191023, 55.72388914653233, 51.949148246220176, 54.66016510554722, 54.251225403376985, 51.892527375902446, 55.69379997253418, 56.51099845341274, 67.15621539524624, 67.71655981881278, 66.86482184273856, 64.13007341112409, 68.67089489528111, 66.1955018724714, 61.312300954546245, 54.690216064453125, 52.60252904891968, 52.190754481724326, 51.58573661531721, 52.63231945037842, 60.60402243477957, 67.72435569763184, 70.4095287322998, 71.23309871128627, 73.29599802834647, 71.72027860369, 65.35576343536377, 62.34539386204311, 62.87969643729073, 63.82583958762032, 64.57397992270333, 63.98894854954311, 66.85947867802211, 70.43643910544259, 70.78498853955949, 71.41300146920341, 73.19468634469169, 75.26829978397915, 77.27238954816545, 78.55994633265904, 65.10519749777657, 4.9656243579728265, 3.068068717207227, 4.283069806439536, 3.7975040674209595, 7.945518698011126, 8.153308050973074, 8.896967666489736, 9.3222964320864, 3.041051298379898, 0.1331909687391349, 1.5790326297283173, 41.68460920878819, 48.61330073220389, 83.65101650782994, 64.17835644313267, 63.16386386326381, 51.793373107910156, 45.69014842169625, 65.85999420710972, 60.99239199502127, 76.50138963971818, 6.053407405103956, 0.5254426449537277, 0.3613578682499272, 0.07754093275538512, 0.09206012330417122, 0.1676018951194627, 0.20732759631105832, 0.119216295757464, 0.12676547281444073, 0.14492817249681267, 0.14219512843659946, 0.0872048931196332], [0.01186050205225391, 0.03333564854360052, 0.03360152570530772, 0.028165939430307065, 0.048940929384636025, 0.037738282299999676, 0.05149495215820415, 0.025350212485396435, 0.04696940178317683, 0.033750721985208135, 0.04200313612818718, 0.022401372236864905, 0.09048550136919532, 4.531744965485164, 59.196338244846885, 56.3693767956325, 54.837785380227224, 18.0109657900674, 46.51629965645926, 74.2889928817749, 39.15491601399013, 1.492423334292003, 0.04531532000484211, 0.13358249701559544, 5.63146675484521, 3.9115696038518633, 1.565253917660032, 8.53260326385498, 2.7554994438375746, 0.7441856701459203, 50.17397730691092, 87.45431450435093, 64.33141830989292, 80.76251138959611, 85.16987187521798, 83.91137245723179, 84.0711532320295, 84.49708475385393, 80.05673422132219, 82.98638657161167, 82.61579050336564, 84.72033037458147, 83.07438550676618, 81.39834104265485, 77.4693431854248, 77.98936026436942, 64.61839280809674, 55.17011424473354, 55.3835038457598, 56.28961147580828, 58.604831150599885, 63.10189288003104, 64.05745778764997, 61.639401299612864, 58.50230353219168, 54.17147397994995, 53.57545403071812, 51.895039149693076, 50.78294175011771, 52.9450717653547, 65.57906464168003, 70.68993023463658, 73.56276716504777, 66.26517840794155, 64.6256467274257, 52.62497520446777, 66.13476766858781, 70.16183240073067, 62.742796080453054, 62.482572146824424, 54.436280250549316, 52.10477747235979, 53.10651315961565, 58.845030375889365, 60.045025961739675, 58.424796376909526, 61.81803253718785, 61.4785852432251, 59.63499886648995, 55.433642046792166, 57.90817696707589, 59.246684891836985, 64.92403711591447, 63.43890830448696, 61.86526639120919, 53.17282676696777, 49.57055057798113, 53.15706477846418, 54.09056568145752, 55.24649926594326, 51.052920954568044, 52.90319149834769, 54.85179989678519, 57.974410670144216, 52.26023299353463, 48.109410422188894, 51.85249532972063, 51.695031779153005, 54.51112624577114, 59.276277269635884, 59.94718837738037, 58.715856415884836, 51.383821964263916, 49.426448413303916, 51.2690029825483, 56.897255761282786, 58.066634110042024, 47.895666463034495, 47.98968253816877, 53.65904433386666, 56.53644623075213, 59.31731333051409, 62.68978827340262, 61.98827035086495, 59.63301862989153, 62.579499517168315, 58.59627096993582, 51.35377447945731, 46.476146016802105, 45.0844635282244, 47.249199117933, 45.879254068647114, 53.789246627262656, 61.084990637642996, 63.856550625392366, 62.658493586948936, 66.35533823285783, 63.33174623761858, 62.94379356929234, 60.35683332170759, 62.501276697431294, 63.606283460344585, 64.47629519871303, 63.652822494506836, 63.07723372323172, 65.66520145961216, 69.04121998378209, 68.84512097494942, 70.96320288521903, 68.92246832166398, 71.02012947627476, 64.44276319231305, 65.3854878289359, 50.100698130471365, 4.32875942332404, 1.0603454794202531, 2.2622902521065305, 0.25911227613687515, 2.0568433105945587, 0.9481142674173627, 2.0623263078076497, 2.6823527174336568, 0.31796188971826006, 0.3672620728611946, 18.660961083003453, 26.28579957144601, 46.43051719665527, 69.83401639120919, 21.613822153636388, 19.85115623474121, 22.804764236722672, 41.88913985661098, 47.80831371034895, 50.31527239935738, 2.7018732471125464, 0.04261478116469724, 0.12654508464038372, 0.03417360536488039, 0.014923359932644027, 0.008871780059832548, 0.08688864830349173, 0.05107708993766989, 0.044836114825946946, 0.06644373679799692, 0.02817447709717921, 0.023468117495732646, 0.03631975056071367, 0.05015311862475105, 0.013449550489895046, 0.026009078470191786, 0.02750063075550965, 0.06457175367644855, 0.02841715345026127, 0.015180346589269382, 0.020253018409545933, 0.0236623277887702, 0.020247003196605613, 0.06278388854116201, 0.07923828810453415, 6.280998255525317, 71.30157320840019, 62.88501875741141, 61.67996488298689, 28.446286337716238, 50.30483273097447, 80.03236688886369, 44.192359992435996, 1.4462377897330692, 0.2027336699622018, 1.4623084302459444, 5.864528008869716, 5.410135362829481, 1.5465931189911706, 2.7630078409399306, 0.7409723997116089, 2.1915966740676334, 64.76228305271694, 92.13867882319859, 77.54102775028774, 86.7696042742048, 85.1252088546753, 84.88054193769182, 86.57431125640869, 88.60148988451276, 83.78656891414097, 85.74655151367188, 86.75472123282296, 85.2550915309361, 85.6064897264753, 83.71366146632603, 81.02413885934013, 79.90766062055314, 68.31007494245256, 57.325052874428884, 58.98256996699742, 58.024017333984375, 61.671884128025596, 66.52185876028878, 67.16455323355538, 65.10514191218785, 59.90374823978969, 56.186628750392366, 56.71079042979649, 53.76224592753819, 52.575000286102295, 53.74379498617989, 67.8824828011649, 71.11022676740373, 74.67501395089286, 67.72020762307304, 68.49272223881313, 59.85267898014614, 67.42667402539934, 70.31292792728969, 67.07131535666329, 65.4075414112636, 55.45658499853951, 53.62364673614502, 54.044099603380474, 62.69446441105434, 63.50848756517683, 62.34056486402239, 65.10405104500907, 64.48595319475446, 61.41323743547712, 58.93996361323765, 60.209788594927105, 62.647946221487864, 68.85147857666016, 64.98825931549072, 62.760152680533274, 53.90049423490252, 48.124359471457346, 52.24143116814749, 56.80753367287772, 57.70068986075265, 52.430557659694124, 50.184656688145225, 55.51372698375157, 58.681761605399, 53.690717697143555, 50.538066387176514, 56.51937450681414, 52.81583527156285, 56.9486585344587, 62.25754083905901, 64.09404005323137, 60.8621758052281, 54.95581790379116, 51.547125475747244, 54.7644054549081, 60.69059004102434, 62.41055406842913, 51.716126510075156, 48.89179842812674, 55.0211136000497, 59.962988580976216, 62.28135926382882, 62.38619368416922, 64.22292913709367, 64.37179429190499, 65.35449886322021, 61.200678144182476, 54.06817511149815, 49.67057684489659, 47.66937058312552, 48.10535267421177, 47.89125435692923, 56.25213636670794, 63.914741788591655, 66.68396718161446, 64.16654450552804, 67.75332273755754, 66.64555059160504, 65.13504695892334, 63.58882958548409, 67.01206806727818, 65.41825553349086, 68.62926823752267, 66.64644690922329, 66.91209738595145, 68.3799946648734, 72.08695588793073, 72.57801982334682, 74.40793214525495, 72.11611747741699, 71.83896773202079, 64.7472471509661, 66.05405739375523, 60.37134116036551, 9.919539264270238, 1.3736004531383514, 1.4443183498723167, 0.8624088891914913, 1.9593648612499237, 3.556070451225553, 3.127620424543108, 4.2300923977579385, 0.6699755436607769, 0.3399880863726139, 19.660205841064453, 34.66186339514596, 50.406550884246826, 75.36308710915702, 26.843585320881434, 34.43950366973877, 30.539076805114746, 48.319760186331614, 53.485718045915874, 61.3693665095738, 3.626584461757115, 0.2128578331321478, 0.2074769554393632, 0.010427792323753238, 0.03605731017887592, 0.025383126522813524, 0.055150535822446854, 0.02653688032712255, 0.029077824338206222, 0.05238354126257556, 0.04584074020385742, 0.021843380660616925, 0.14389723353087902, 0.13803298106150969, 0.09886842154498611, 0.09626909638089792, 0.08625187711524111, 0.09098938825939383, 0.11857166034834725, 0.11109685072941439, 0.09805159430418696, 0.16767281559961184, 0.1655368280730077, 0.16100502839045866, 0.3076143121080739, 8.083113874707903, 84.55180181775773, 67.47852148328508, 69.34561361585344, 25.653360639299663, 64.7924382346017, 86.28614166804722, 57.243665150233674, 2.911958762577602, 0.1281941147255046, 1.3720587130103792, 14.554123214312963, 9.682052442005702, 6.183819447244916, 20.766428538731166, 9.897129586764745, 1.5278844428913934, 64.75720391954694, 95.10083484649658, 76.68027101244245, 87.5265201841082, 88.2846450805664, 88.11034951891217, 88.56601933070591, 90.79429967062813, 84.32510294233049, 88.31243092673165, 89.48078441619873, 89.30216707502092, 89.64246899741036, 87.55344445364815, 84.70190375191825, 85.84682791573661, 71.70627798352922, 59.93429946899414, 62.10210268838065, 63.508397238595144, 65.37359251294816, 71.48485973903111, 70.96840708596366, 69.88987295968192, 63.78328881944929, 58.77297755650112, 61.094044140407014, 57.19612904957363, 56.63288722719465, 56.922515937260215, 71.44403212411063, 75.02061734880719, 78.1562420981271, 72.07251753125871, 66.93215683528355, 57.639076709747314, 72.54830237797329, 74.40487493787492, 68.50275543757847, 68.92264897482735, 60.57031672341483, 57.512987749917166, 57.20977183750698, 65.35823004586356, 65.97593879699707, 66.54440566471645, 70.125458581107, 68.2915232522147, 66.07101794651577, 64.58547919137138, 63.62204892294747, 64.21596009390694, 74.21795449938092, 67.8315247126988, 66.98481723240444, 55.017410210200715, 50.25468063354492, 54.41268764223371, 57.73604576928275, 58.88788686479841, 53.64020776748657, 52.735083307538716, 57.87124381746565, 61.84856292179653, 53.96066216060093, 53.282118456704275, 58.57464817592076, 56.98813819885254, 61.67241219111851, 66.97918224334717, 67.6798802784511, 66.92953736441476, 59.33750479561942, 53.38976689747402, 56.78662306921822, 63.17630808694022, 63.64043385641915, 52.09692253385271, 53.41981438228062, 58.541401045663015, 62.80182102748326, 64.95262895311627, 68.10346330915178, 66.85542093004499, 67.87518719264439, 68.55846609388078, 64.1193106515067, 57.19285644803728, 52.88276032039097, 49.51775469098772, 51.58378069741385, 51.861072880881174, 59.50572068350655, 66.98219776153564, 70.34701578957694, 65.72365665435791, 71.66804204668317, 68.60556098393032, 67.47694424220494, 65.97172818865094, 69.16031210763114, 67.73077583312988, 71.12069075448173, 69.07094437735421, 67.17295360565186, 70.56498772757394, 74.44352081843785, 75.54975741250175, 76.71626962934221, 74.72456155504499, 75.80175467899868, 68.2482498713902, 71.45370401654924, 61.16540213993618, 7.545747143881662, 4.247508926051004, 7.6595065253121515, 2.8577017996992384, 8.42704623086112, 7.422233360154288, 8.385805198124476, 5.237438321113586, 0.5227445725883756, 0.44659082325441496, 28.88609341212681, 46.567962987082346, 58.16768176215035, 82.09051363808769, 31.68980618885585, 28.272702966417583, 34.16175637926374, 58.27250576019287, 60.772752489362446, 73.2999723979405, 5.367949375084468, 0.48159397499901907, 0.39049283202205387, 0.14211982462022985, 0.23733119347265788, 0.1348692708249603, 0.23502694283212933, 0.15039189931537422, 0.15231984800526074, 0.15534928973231996, 0.09539608644055468, 0.05665145528369716], [0.04316474397533706, 0.045509262276547294, 0.07242842923317637, 0.06800258279378925, 0.04431638753573809, 0.036500118739370785, 0.00873434279180531, 0.024583936103486588, 0.019016254327393005, 0.07445600721985102, 0.08037256116845778, 0.05309482238122395, 0.11015871499798127, 3.7197102989469255, 58.6203464780535, 51.2915290423802, 53.74582733426775, 36.905853612082346, 60.11058221544538, 63.65782519749233, 18.36993752207075, 0.11574638980839934, 0.06553131075842039, 2.137372280870165, 5.524927854537964, 1.8589940071105957, 3.5054699778556824, 1.526637892637934, 2.6754889828818182, 72.07590130397251, 98.78838975088937, 85.72007192884172, 90.04352596827916, 86.11431271689278, 84.52371025085449, 81.3797824042184, 83.8423490524292, 82.14796829223633, 84.85479191371373, 83.74856921604702, 79.66069384983608, 81.02486842019218, 78.76975413731166, 75.99888896942139, 79.44690472739083, 77.34469945090157, 66.73347309657505, 54.71567078999111, 55.36114454269409, 55.18252720151629, 57.93337460926601, 59.74996376037598, 61.824959891183035, 60.669384138924734, 54.99308456693377, 54.390185901096885, 51.498171942574636, 51.795679909842356, 50.02490370614188, 52.51380402701241, 60.22829859597342, 69.24644197736467, 67.3278706414359, 69.30503613608224, 64.31388800484794, 61.68883078438895, 66.21615191868374, 65.77080712999616, 67.10322148459298, 60.06272997174944, 57.21580287388393, 49.71789060320173, 59.50024550301688, 62.81011717660086, 65.99369144439697, 62.98781735556466, 60.283140727451865, 60.81350367409842, 55.69181626183646, 53.12850768225533, 57.503427028656006, 61.77368218558175, 64.47023636954171, 63.06993811471121, 58.04231194087437, 51.89123501096453, 53.365066051483154, 54.19623735972813, 57.971047742026194, 57.07404225213187, 60.71335233960833, 55.19229984283447, 51.600379943847656, 54.79875387464251, 56.48335157121931, 53.744166714804514, 51.67795310701643, 53.335268701825825, 51.90023987633841, 58.03510665893555, 59.184213638305664, 54.96754993711199, 50.95223113468715, 50.172584193093435, 54.875493253980366, 59.990281105041504, 61.55683585575649, 54.02708346503121, 46.32210792813982, 48.872183663504465, 54.60059125082833, 55.94174643925258, 59.249943596976145, 61.72097315107073, 62.27479321616036, 60.266263553074424, 60.078537123543875, 53.74271106719971, 47.506473541259766, 43.37141643251692, 46.23440776552473, 47.376472745622905, 49.423363413129536, 59.085153170994346, 63.758073806762695, 63.70954063960484, 65.75210952758789, 65.89018412998745, 62.91570200238909, 64.70554406302315, 65.48356860024589, 67.10354804992676, 64.71163763318742, 65.77422564370292, 68.19949436187744, 68.56096744537354, 68.12883118220738, 68.15339306422642, 67.69499261038644, 64.82373986925397, 61.723328590393066, 64.19875635419572, 63.964727129255024, 60.29322951180594, 61.31967299325125, 5.0993680613381525, 1.5000159783022744, 0.7183759893689836, 2.029967895575932, 3.6649849840572903, 0.524177855678967, 2.2185205093451907, 0.25129102010812077, 0.12583733190383228, 3.5875581673213413, 43.14867455618722, 24.56222074372428, 66.17396940503801, 31.181020872933523, 30.08804838997977, 40.442368575504844, 60.95984663282122, 46.12784324373518, 50.32323850904192, 2.1497122815677097, 0.10460592367287193, 0.006381327535824052, 0.09344586823135614, 0.025684299379853264, 0.04729730383093868, 0.05735189002007246, 0.07597792733992849, 0.01610990733440433, 0.03540695132687688, 0.04934014546285782, 0.05065008785043444, 0.0338624902734799, 0.04104643567864384, 0.042660979221441915, 0.021222821370299374, 0.06730688762451921, 0.10402088399444308, 0.032698551658540964, 0.009231361211277544, 0.035569104232958386, 0.046425840950437954, 0.010103310940654149, 0.08260201010853052, 0.12818118184804916, 6.294739186763763, 70.2735594340733, 55.11235734394619, 60.73380783626011, 23.323455946786062, 57.757602555411204, 77.03171784537179, 20.104525770459855, 0.048346173084740124, 0.3533768036535808, 2.048689599548067, 5.626034566334315, 2.5772953033447266, 1.7525537929364612, 0.4029820832823004, 5.737790260996137, 85.98523603166852, 99.05242824554443, 89.56642096383231, 90.86614404405866, 87.01119313921247, 85.82836655208042, 83.53776781899589, 83.6622656413487, 82.28661959511894, 85.54622105189732, 85.6363947732108, 83.2339230946132, 80.7473087310791, 80.46894999912807, 78.1392468043736, 81.98305974687848, 81.42715522221157, 70.08142784663609, 57.125629152570454, 57.622619901384624, 57.49480431420462, 60.740130696977886, 62.28577831813267, 64.56405789511544, 63.51347637176514, 57.419440678187776, 55.781288215092246, 55.41101871218, 53.354372773851665, 51.71605007989066, 54.80477796282087, 62.18791988917759, 69.54524230957031, 70.1925573348999, 69.33123084477016, 70.18574810028076, 65.15962968553815, 68.15213544028146, 69.24045263017926, 70.31077398572648, 64.96883215223039, 59.55212770189558, 52.642581939697266, 61.51859991891043, 66.8242026737758, 67.93009880610875, 66.93123967306954, 64.86794430868966, 64.7184955051967, 59.27975136893136, 56.48135396412441, 61.25328990391323, 64.65940802437919, 66.72223785945347, 65.33887236458915, 57.71449245725359, 53.16182082039969, 56.200365339006694, 56.396085671016145, 60.844061851501465, 59.56929670061384, 63.92959703717913, 57.651003292628694, 51.55724900109427, 55.28455454962594, 59.05448382241385, 56.005367619650706, 54.377220562526155, 56.00859158379691, 56.32854570661272, 60.17581190381731, 61.21421323503767, 57.87506880078997, 52.89222724097115, 51.76399612426758, 58.06689466748919, 62.79520634242466, 64.08178343091691, 56.65492343902588, 49.35562195096697, 53.174807003566194, 55.43977730614798, 59.190654618399485, 60.97837053026472, 63.28333813803536, 66.48993178776333, 62.26922770908901, 62.886199951171875, 56.64931276866368, 50.487629413604736, 45.71679128919329, 48.96790204729353, 49.47624962670462, 51.912110873631065, 61.74803638458252, 66.80819402422223, 68.02402455466134, 66.51202011108398, 65.89491585322789, 66.77547495705741, 66.99596214294434, 67.5273881639753, 69.28176661900112, 67.35026468549455, 68.22949668339321, 71.1692030770438, 70.52038029261998, 70.60027762821743, 70.13255964006696, 67.3691359928676, 65.56969152178083, 63.804397446768625, 65.39678559984479, 67.46481268746513, 62.1710844039917, 71.48873683384487, 10.41926326070513, 1.2826404997280665, 0.647677363029548, 1.7571898698806763, 3.1473913065024783, 2.1479359311716895, 3.5459881808076585, 0.8710736728140286, 0.16125614063016006, 2.362989625760487, 52.55699402945382, 31.279768671308243, 75.08873053959438, 35.45810958317348, 21.19028949737549, 41.59401164736067, 66.24846799033028, 53.87152719497681, 60.25388881138393, 3.438339740037918, 0.2067108079791069, 0.11442007097814764, 0.06308357710284845, 0.052256061495946984, 0.020688642980530858, 0.039464933398578844, 0.01322709278403116, 0.01989344065077603, 0.03335887479728886, 0.04664693480091436, 0.024932102599580373, 0.13116631523839065, 0.10128214702542339, 0.16100270780069487, 0.07119293231517076, 0.16268573249025003, 0.15776365303567477, 0.096746588258871, 0.08933348461453404, 0.12774595591638768, 0.25352209753223826, 0.19036519793527468, 0.15229038601475103, 0.42476870279226986, 9.458384718213763, 82.25206620352608, 63.85758590698242, 68.75340475354875, 52.49333463396345, 79.98611273084367, 82.69566699436733, 31.650329998561315, 0.28323134620274815, 0.44801455257194384, 6.379244480814252, 13.7501289163317, 6.657079926558903, 12.474324141229902, 5.527682815279279, 3.937228866985866, 83.57047298976353, 103.5716894694737, 93.46670191628593, 96.27266243525914, 90.94206701006208, 89.35591139112199, 87.06309618268693, 89.83870697021484, 85.38868454524449, 90.24127864837646, 87.01583453587124, 86.57128879002163, 84.94650118691581, 83.4907146181379, 81.61531938825334, 84.92794949667794, 83.9947577885219, 72.67686489650181, 60.17602729797363, 59.9327917098999, 61.562345777239116, 63.135668073381694, 66.81446824754987, 68.56049496786935, 66.00120939527238, 61.97424193790981, 59.461613518851145, 58.20614004135132, 57.34831544331142, 54.9777637890407, 58.25625739778791, 68.7506880078997, 75.24479402814592, 73.92562294006348, 73.52521909986223, 69.49823079790387, 65.46759469168526, 71.7511077608381, 70.76380348205566, 74.27563844408307, 66.27341202327183, 62.26180703299386, 55.04104103360857, 65.4471183504377, 67.8515077318464, 71.44433089665004, 69.48559897286552, 67.79174627576555, 68.12491239820207, 63.45617457798549, 60.63094670431954, 64.09467233930314, 67.20308099474225, 68.74023791721889, 67.87391567230225, 61.16567311968122, 53.61201892580305, 55.829942975725444, 59.15878323146275, 63.938066891261506, 61.81685134342739, 66.45528806958879, 59.40389483315604, 51.963100228990825, 57.12506634848458, 60.97349289485386, 60.44618020738874, 57.397668497903005, 62.446747234889436, 59.576898029872346, 64.70619024549211, 65.2929447719029, 62.1015259878976, 57.48687294551304, 53.05938352857317, 61.05554417201451, 65.56928852626255, 67.25116947719029, 60.73890781402588, 52.15697234017508, 54.718547344207764, 59.30097116742815, 63.13623087746756, 65.26604829515729, 67.5576753616333, 68.95351982116699, 64.0428248814174, 65.56458459581647, 59.70048563820975, 53.31201308114188, 47.947958605630056, 51.20303331102644, 51.21000235421317, 54.553638798849924, 64.08573000771659, 72.47292137145996, 68.84204292297363, 69.34089578901018, 69.41806943075997, 69.8226352419172, 70.29275730678013, 69.38381481170654, 73.32206072126115, 68.5214877809797, 72.18794795445034, 74.94962760380336, 73.36853722163609, 74.10482392992292, 72.88269138336182, 70.99328163691929, 67.6223839351109, 65.55223069872174, 64.46204444340297, 68.63199193137032, 64.50499820709229, 73.06043325151715, 9.113835709435598, 4.524733364582062, 5.921437229428973, 7.668785844530378, 9.156984891210284, 4.382182385240283, 7.973281962530954, 0.7633093925459045, 0.25201431129659924, 4.910919453416552, 62.62259919302804, 39.162402697971885, 81.3332850592477, 45.79410736901419, 41.120530128479004, 52.86754723957607, 75.19997119903564, 59.56800433567592, 72.11270591190883, 5.271790649209704, 0.3653711314712252, 0.26667788731200354, 0.20022902078926563, 0.1273650670690196, 0.20943584532610007, 0.1870377707694258, 0.23745381832122803, 0.11131556292197534, 0.12987689514245304, 0.11715122871100903, 0.1082541011273861], [0.05360032757744193, 0.03901540734139936, 0.06225722323038748, 0.0939982228779367, 0.044746748371315856, 0.0626624036314232, 0.019933625190917934, 0.04317072865420154, 0.04406749749822276, 0.08825930939721209, 0.04745370954541223, 0.17854348942637444, 0.3680413839008127, 8.239098327500479, 60.16081769125802, 52.52220787320818, 38.98910072871617, 48.601731981549946, 69.58315862928117, 46.715556621551514, 6.606709395136152, 0.13489744359893457, 0.36002470978668755, 3.4942610136100223, 1.7186012033905302, 4.352561780384608, 0.733599872461387, 1.090645922081811, 80.87441212790353, 92.38636125837053, 82.4034674508231, 86.13585213252476, 83.24315725054059, 83.15440790993827, 86.73995631081718, 83.08284841264997, 83.23154681069511, 80.89173398699079, 80.81979233877999, 81.53583199637276, 83.23736245291573, 79.66117327553886, 78.47607462746757, 75.64848436628068, 77.70286519186837, 73.43637248447963, 65.8669215611049, 55.491892269679475, 53.72553859438215, 53.14304678780692, 56.958893230983186, 58.964073862348286, 61.92570877075195, 57.33552728380476, 52.72505010877337, 52.91780008588518, 54.71856471470424, 51.07244191850935, 50.29610231944493, 51.022463526044575, 54.596026284354075, 58.020647457667756, 65.7244348526001, 68.43492712293352, 64.66541126796177, 60.008666038513184, 67.20456790924072, 68.10549218314034, 68.15716593606132, 64.09750720432827, 59.46829768589565, 50.84892531803676, 61.39549173627581, 65.21741785321916, 62.01233891078404, 60.86202989305769, 60.488689286368235, 59.07496016366141, 52.95047746385847, 54.4850948197501, 59.37331581115723, 63.37039906638009, 61.136448996407644, 58.31381280081612, 52.69724341801235, 55.25091484614781, 62.082814489092144, 60.588632174900596, 61.896074703761506, 58.986245564052034, 61.23603057861328, 60.867935861860005, 59.26153319222586, 53.988798890795024, 54.85687902995518, 52.17770576477051, 48.12690946034023, 51.68937594549996, 57.02507829666138, 53.99589647565569, 54.92495747974941, 54.297455242701936, 51.85534756524222, 54.375083991459434, 57.26703889029366, 60.13518578665597, 59.327728680201936, 55.73902579716274, 50.4422333581107, 50.850151675088064, 50.63732835224697, 53.597934927259175, 57.90447357722691, 60.54540743146624, 61.65085193089077, 62.249863079616, 61.11771665300642, 58.29089069366455, 52.76410593305315, 45.00879417146955, 46.26881177084786, 46.74872037342617, 47.04212890352522, 57.52304874147688, 61.23247310093471, 62.1470297404698, 64.77194799695695, 64.61044406890869, 65.73989459446499, 63.732184818812776, 65.53813280378068, 66.3824153627668, 65.6089905330113, 66.35080800737653, 64.77116285051618, 64.72635391780308, 66.5630407333374, 67.10939843314034, 64.55772808619908, 65.65696089608329, 66.97311646597726, 72.17109857286725, 70.74250725337437, 70.25882925306047, 58.5757668358939, 55.09986448287964, 3.026209729058402, 0.63315991631576, 0.9703221214669091, 1.647454906787191, 3.467008658817836, 2.7456271392958502, 2.8301254851477484, 0.4538941670741354, 0.7433379356350217, 35.145451068878174, 42.13071829932076, 39.35092122214181, 55.953238759722026, 48.193355083465576, 28.561133112226212, 39.69900165285383, 52.3109895842416, 41.791837283543174, 1.1490633359977176, 0.04507581749930978, 0.07125489613307373, 0.030358905238764625, 0.0487611176046942, 0.07395285993282284, 0.0571335374510714, 0.08554314050291266, 0.0328119416455073, 0.03367612723793302, 0.019253256431381618, 0.08098738174885511, 0.017347733323861445, 0.021403963078877757, 0.017768409768385545, 0.045935962415699444, 0.06783695918108736, 0.049968967613364966, 0.09304922380085502, 0.07538850432527916, 0.06465939325945717, 0.020057720764140998, 0.07244752320860114, 0.19793193547853402, 0.4860264914376395, 12.449565104075841, 69.94201224190849, 59.994644573756624, 56.602481910160606, 38.942509583064485, 71.58444826943534, 55.162707465035574, 6.720400163105555, 0.3426837974361011, 0.566878932927336, 4.1690546444484164, 3.157272296292441, 1.2467166845287596, 0.4780086502432823, 2.8930527142116, 93.5375804901123, 92.94348171779087, 89.82243428911481, 89.03413336617606, 86.60938576289585, 88.2220765522548, 88.86590358189174, 84.49306869506836, 86.30635397774833, 82.71294716426304, 81.411910874503, 81.91569001334054, 84.92884581429618, 82.19030366625104, 80.65787151881626, 77.85411357879639, 81.32639244624546, 75.4499465397426, 69.0350569316319, 57.80723353794643, 57.168204239436555, 55.74657848903111, 60.87432125636509, 61.2436249596732, 62.95836394173758, 59.20466913495745, 54.7923789024353, 54.71967642647879, 55.10831349236624, 52.88131856918335, 52.907520226069856, 54.49937684195382, 56.77270235334124, 61.99587862832205, 64.91922896248954, 68.3488597869873, 67.73040063040597, 66.69688388279506, 69.32244832175118, 69.91269084385463, 69.78373227800641, 67.40291118621826, 63.58422292981829, 52.162937368665425, 63.80266039712088, 68.47868687765938, 66.10853127070835, 63.55317143031529, 63.47542108808245, 60.27439294542585, 55.29544585091727, 57.78169890812465, 61.65653555733817, 65.54160690307617, 63.803007807050435, 58.837706974574495, 52.99584225245884, 56.39053406034197, 65.84783485957554, 62.92779186793736, 64.01420525142125, 63.139656339372905, 64.74005576542446, 62.022566659109934, 62.95269421168736, 54.35319716589791, 55.92442805426461, 51.0271327154977, 49.98251969473702, 52.578856536320274, 59.47840731484549, 58.89998367854527, 57.897712979997905, 58.34040355682373, 56.53378507069179, 58.95989104679653, 60.65654386792864, 62.72871903010777, 61.97404044015067, 59.5126827784947, 53.52421106610979, 52.928229331970215, 55.393870558057515, 55.84872743061611, 59.81843825748989, 62.591068267822266, 63.36764063153948, 65.44985594068254, 65.29896191188267, 61.35947922297886, 56.06465312412807, 49.006391593388145, 49.830743244716096, 48.875501428331646, 51.01374006271362, 60.832930837358745, 63.12168829781668, 64.72053132738385, 65.66877283368791, 67.37084524972099, 67.08885955810547, 65.85064888000488, 67.66129384722028, 69.47634397234235, 67.21385070255825, 68.11508764539445, 68.25174481528146, 66.43226173945835, 67.34313583374023, 67.4977263041905, 65.15231323242188, 68.75761536189488, 69.11648981911796, 74.8771231515067, 69.57342420305524, 74.57992090497697, 61.88761874607631, 66.88377652849469, 7.189595511981419, 0.2940664105117321, 0.3430946096777916, 2.156895633254732, 4.705350049904414, 3.5632114623274123, 5.598520568438938, 0.5491780713200569, 0.9144165899072374, 33.9169157573155, 49.68165227345058, 41.80722059522356, 55.77957201004028, 30.089820180620464, 40.11479227883475, 45.211476598467144, 59.298782484872, 48.40387855257307, 2.11056678209986, 0.06355003600141831, 0.07621227976466928, 0.06236884902630534, 0.055078142921307256, 0.025158918196601526, 0.04043813581977572, 0.10625353561980383, 0.07785961351224355, 0.07705630268901587, 0.0657687708735466, 0.07125846522727183, 0.1896195150911808, 0.12009868983711515, 0.20419747355793202, 0.13901085858898504, 0.1669955833681992, 0.14160784280725888, 0.13769270932035788, 0.15853463166526385, 0.22125850378402642, 0.17100909086210386, 0.19506768988711493, 0.3654804570334298, 0.7788531099046979, 15.796713863100324, 80.46675436837333, 67.61698518480573, 50.83297920227051, 72.69543743133545, 87.24900218418666, 65.5893896647862, 10.63635972567967, 0.5292465665510723, 0.6406436690262386, 9.488324505942208, 5.972263302121844, 13.325970922197614, 3.6549960800579617, 1.7874326642070497, 94.65988826751709, 97.69125529697963, 95.03739084516252, 93.61231531415666, 90.77414989471436, 91.63897827693394, 93.41516712733677, 90.32064097268241, 91.08041954040527, 85.68232236589704, 84.59836169651577, 87.19047055925641, 88.99331269945417, 85.72806235722133, 85.79571001870292, 77.71814428056989, 84.03881631578717, 79.06519848959786, 72.22323090689522, 60.967406272888184, 59.077822821480886, 60.54547691345215, 64.24983256203788, 64.29049342019218, 69.01079382215227, 61.83142866407122, 58.33942386082241, 57.84497267859322, 60.638985770089285, 55.31904888153076, 54.70377894810268, 55.75260952540806, 60.834945814950125, 64.55925668988908, 68.98743397848946, 72.64580644880022, 66.66056564876011, 66.29201235089982, 72.09345245361328, 74.82420567103794, 73.78363650185722, 69.559465272086, 66.55431379590715, 55.256528990609304, 66.76837389809745, 70.5636328288487, 69.87765107836042, 66.56306852613176, 66.04597663879395, 65.02976785387311, 61.139784131731304, 61.627756118774414, 63.776979855128694, 66.87607097625732, 66.26344830649239, 60.897125244140625, 54.93148878642491, 56.34200784138271, 68.63484069279262, 65.74651622772217, 67.8436632156372, 65.43161691938127, 68.01733343941825, 63.845384870256694, 63.706407002040315, 55.33137151173183, 58.856015477861675, 53.62471328462873, 54.16367810113089, 56.596033981868196, 63.237869126456125, 61.39343506949288, 60.442650522504536, 60.72934709276472, 58.30990096500942, 60.670773778642925, 63.66038908277239, 64.92390510014125, 65.37213339124406, 63.70030648367745, 56.18333183016096, 55.151475702013286, 57.50029339109148, 58.47672026497977, 63.57120200565883, 66.16426277160645, 65.68340573992047, 65.76929937090192, 67.92903573172433, 63.21763597215925, 58.81664003644671, 52.740117277417866, 52.46458298819405, 52.48585837227957, 53.0074075290135, 62.88793700081961, 65.18818678174699, 67.745603288923, 69.02057688576835, 69.20450959886823, 70.77206489018032, 68.48801136016846, 70.18323285239083, 71.84037821633476, 70.04432446616036, 71.06508432115827, 68.45188072749546, 67.40101432800293, 70.34409754616874, 69.69573334285191, 67.97057206290108, 69.96790817805699, 72.57221807752336, 76.44098200116838, 74.31295721871513, 75.57766832624162, 62.944682938711985, 66.0930506842477, 6.523961995329175, 2.078735347305025, 6.040717388902392, 7.4660956008093695, 8.155218805585589, 8.973342265401568, 6.841738726411547, 0.8567493643079485, 0.9720542856625148, 42.74105848584856, 58.71760041373116, 49.81208038330078, 71.34563868386405, 66.26917362213135, 39.293827874319895, 53.42293759754726, 66.08107893807548, 59.849065916878835, 3.1145258929048265, 0.3025594704917499, 0.20083126133041723, 0.12182383798062801, 0.18169091482247623, 0.15233469435146876, 0.2325866866324629, 0.2673888291631426, 0.10745440011045762, 0.21093411850077765, 0.2747305509235178, 0.2633326825286661], [0.010400647530332208, 0.009886515609520887, 0.03887117454516036, 0.04389430143471275, 0.06503982748836279, 0.008286630967631936, 0.05058562023831265, 0.01830957706884614, 0.023379178518163304, 0.023397502356341908, 0.06860749676291432, 0.15256603408072675, 0.26765820756554604, 20.708782809121267, 67.10108838762555, 39.21734210423061, 25.444605486733572, 35.35533530371529, 64.58978707449776, 31.542327199663433, 0.8016863018274307, 0.03813356287511332, 0.30721538779991014, 0.7356210382921355, 3.1126472737107957, 1.5227854422160556, 0.13793278858065605, 51.40113340105329, 94.65107100350517, 77.69809177943638, 86.95794214521135, 79.30243083408901, 83.49613421303886, 79.1810805456979, 84.24845736367362, 80.36277457645961, 82.59807954515729, 80.91446154458183, 78.57648999350411, 75.14434392111642, 78.48246002197266, 76.01588426317487, 79.90351949419293, 73.89921283721924, 76.70966189248222, 70.28743498665946, 64.547486441476, 54.8809232711792, 53.66297354016985, 55.66161939076015, 57.66208566938128, 55.50447545732771, 59.53107466016497, 53.15194048200335, 53.96342754364014, 51.693239143916536, 53.24918746948242, 49.46592460359846, 50.04215260914394, 51.65865795952933, 52.15362330845424, 55.022840227399556, 62.05008152553013, 66.01842703138078, 64.58882127489362, 61.326551709856304, 65.39577811104911, 62.976839201790945, 66.6302992956979, 64.84794739314488, 60.11334065028599, 50.368492126464844, 59.62859957558768, 62.02034323556082, 63.995125498090474, 56.89676243918282, 54.01434046881539, 52.19309255055019, 50.001397950308665, 56.5287823677063, 59.470847674778526, 58.05038227353777, 60.95599038260323, 57.52243035180228, 58.99555615016392, 59.35873849051339, 60.16336073194231, 58.09208188738142, 57.61397286823818, 58.50633348737444, 59.81978620801653, 61.933358737400596, 59.853901863098145, 56.1195056779044, 58.58762046269008, 48.5953048978533, 47.97809294291905, 46.2219739641462, 54.077416215624126, 58.78357355935233, 55.588767528533936, 56.14065252031599, 56.80494546890259, 56.13712630953108, 59.314290864127024, 59.523063387189595, 59.818528584071565, 56.51725878034319, 53.027890818459646, 50.4275552885873, 54.20799023764474, 54.537373065948486, 56.446182182856965, 59.41301086970738, 62.12255123683384, 62.16310092381069, 60.053155354091096, 58.43261310032436, 57.69602761949812, 48.011371340070454, 44.0134334564209, 46.445716381073, 45.91282429013933, 55.53988347734724, 60.457380703517366, 61.40830421447754, 63.442840984889436, 65.4264474596296, 60.53419998713902, 64.2679534639631, 64.19638007027763, 65.70368753160749, 63.021731512887136, 64.32868766784668, 65.99646377563477, 65.46685123443604, 66.87211745125907, 66.82097176143101, 68.15390028272355, 70.60849039895194, 68.09006023406982, 70.27326760973249, 66.93718038286481, 71.92906502314976, 70.89300523485456, 70.40244156973702, 47.955612046378, 1.6114159034831184, 0.38622544386557167, 2.3595450563090186, 1.561572240931647, 2.463483593293599, 1.650701886841229, 0.1788625365921429, 0.13336288237145968, 5.437343639986856, 60.23028578077044, 31.938082695007324, 57.72774962016514, 34.057877336229595, 27.66144561767578, 35.24692256110055, 44.51715700966971, 39.05685608727591, 0.9570649585553578, 0.11420855804213456, 0.0262318466058267, 0.1049713147804141, 0.02014955708623997, 0.03966696380770632, 0.08899819332041911, 0.05036570364609361, 0.041969677566417625, 0.04769938671961427, 0.038999526229287894, 0.05208458212603416, 0.0034812039812095463, 0.08085248898714781, 0.04507819237187505, 0.06782612976218973, 0.04675216540428145, 0.03569182746910623, 0.033730460929551294, 0.027282173013580695, 0.04012066964060068, 0.04349863070196339, 0.02784611194926713, 0.2071763372847012, 0.2652048149279186, 29.709375040871755, 72.54263959612165, 47.7739166532244, 30.141723224094935, 34.46264811924526, 75.78113242558071, 35.95019837788173, 0.838841088116169, 0.11021330314023153, 2.193678310939244, 2.2793205039841786, 1.6117516968931471, 1.1932025275060107, 0.5886503532528877, 65.37631620679582, 97.13638605390275, 83.15805571419853, 88.23236683436802, 81.50580188206264, 85.21969740731376, 83.11046750204903, 87.18396009717668, 81.83526461465019, 85.0915448325021, 82.50610624040876, 84.00207424163818, 79.89996896471295, 82.63587774549211, 79.28947939191545, 82.03457369123186, 78.2307823726109, 80.05758884974888, 70.95817933763776, 68.67696762084961, 57.66494137900216, 56.31428105490548, 58.966686385018484, 60.815907750810894, 60.216743741716655, 61.93654796055385, 56.69665779386248, 56.25211899621146, 53.35700961521694, 56.37626246043614, 52.06581892286028, 54.06518043790545, 53.094235692705425, 54.28344072614397, 58.997300148010254, 64.90190710340227, 68.99345806666783, 67.97785377502441, 65.50043882642473, 66.64364678519112, 63.308622632707866, 67.062470299857, 67.93430941445487, 62.89608028956822, 53.76761341094971, 62.84444127764021, 65.6431965146746, 65.68856825147355, 58.638154711042134, 53.57365444728306, 55.21255384172712, 53.75060074669974, 58.873260906764436, 61.00330761500767, 58.535766056605745, 61.46470274244036, 59.34475176674979, 59.71976688929966, 64.05986881256104, 60.49287210191999, 61.413042885916575, 59.05884729112898, 59.39153398786272, 64.0127044405256, 62.5626014981951, 61.28707899366106, 58.10727759769985, 59.73073809487479, 52.40781273160662, 48.75080558231899, 49.02775730405535, 57.3819169316973, 60.118669918605256, 59.610659326825825, 58.751382555280415, 60.37338393075125, 60.561756542750764, 62.27193750653948, 61.44137763977051, 63.18905108315604, 59.252285139901296, 56.93666941779, 54.800320693424766, 56.52382482801165, 57.43008531842913, 58.06475462232317, 62.642742020743235, 64.60990905761719, 63.80951132093157, 62.485684939793174, 61.76405198233468, 61.8538088117327, 52.32354497909546, 47.846487113407676, 49.68492487498692, 50.006629943847656, 56.62551518848964, 63.896356855119976, 63.591518538338796, 66.17588015965053, 65.86342661721366, 63.77947425842285, 66.62551198686872, 64.48315307072231, 67.61057199750627, 65.55574648720878, 66.19812134334019, 68.83230154854911, 68.04891995021275, 69.7297169821603, 69.45800072806222, 72.39108548845563, 71.28086757659912, 70.57003906794957, 72.91530622754777, 70.78235517229352, 70.65631484985352, 74.2871446609497, 68.79706028529576, 57.87855332238333, 4.35970105443682, 0.33868052225027767, 0.8550202399492264, 3.1657666862010956, 2.776769833905356, 2.861117273569107, 1.0860690133912223, 0.06342241034976073, 5.057815228189741, 65.71125411987305, 39.22709390095302, 59.57025555201939, 28.6850802898407, 31.60074417931693, 44.52645022528512, 49.06069523947579, 48.84795529501778, 1.9132129720279147, 0.1335321090051106, 0.07809201854148082, 0.03176773053460887, 0.046446047723293304, 0.034331164588885646, 0.05003689914675696, 0.02069892787507602, 0.03153144767774003, 0.040764874179980586, 0.04748487465881875, 0.02178522172783102, 0.1068694961390325, 0.17549004113035543, 0.14234161057642528, 0.12795616606516497, 0.15930383253310407, 0.07945316657423973, 0.15225522433008465, 0.08290216685937983, 0.04816799318151815, 0.20058802009693213, 0.23372442701033183, 0.31742326862045694, 0.558842689863273, 32.88780764171055, 86.01077760968889, 51.5184120450701, 34.18528297969273, 51.303195067814414, 80.99538721357072, 50.19696889604841, 1.6716383291142327, 0.12116453264440809, 2.6366264053753445, 2.4874094980103627, 7.510131546429225, 9.061199631009783, 0.530206666461059, 64.77803461892265, 102.57104464939663, 86.40624128069196, 90.94263676234654, 84.92219638824463, 89.22484752110073, 86.26415756770542, 90.6724213191441, 86.91464097159249, 88.10811219896588, 87.54210499354771, 85.33085468837193, 82.03144005366734, 87.35615035465786, 83.20964608873639, 85.45503289358956, 79.40210274287632, 82.8807600566319, 75.53609030587333, 71.41600309099469, 61.63938740321568, 59.66320855276925, 61.52430438995361, 63.61685167040144, 63.52870682307652, 66.0123404094151, 58.74696350097656, 59.25004087175642, 57.239277362823486, 59.60093879699707, 54.92432519367763, 55.503864015851704, 57.76258441380092, 57.51997763769967, 61.86163943154471, 68.8308354786464, 74.13325595855713, 67.8100895200457, 66.86293888092041, 69.56891482216972, 64.54154573168073, 67.53132084437779, 70.3670960835048, 66.36593423570905, 57.313973971775596, 66.32732309613908, 69.21646744864327, 68.42799282073975, 59.377644538879395, 56.31439570018223, 59.67763301304409, 58.05088601793562, 61.900188037327354, 62.63220855167934, 58.90324933188302, 64.74938024793352, 59.99392890930176, 61.843414306640625, 65.99237128666469, 64.33314146314348, 63.651731627328054, 62.64301994868687, 61.92670236315046, 66.80514376504081, 67.56860487801688, 62.88553292410714, 60.01038919176374, 63.940269470214844, 51.10728018624442, 51.71268367767334, 54.51019866125924, 60.22984109606062, 65.30180372510637, 62.09926782335554, 61.527632577078684, 63.45666095188686, 63.79222420283726, 65.81955569131034, 63.97144603729248, 65.21770967755998, 62.52414321899414, 60.26612458910261, 55.586314814431326, 58.45726530892508, 61.33230481828962, 60.657447133745464, 64.7543204171317, 67.65272671835763, 65.56413296290806, 67.48353113446916, 64.77248300824846, 62.51560388292585, 53.74925627027239, 51.14138889312744, 51.640321663447786, 52.01528467450823, 60.6138402393886, 65.21088654654366, 63.93126460484096, 69.09448487418038, 69.76292242322648, 68.14800821031842, 68.92690127236503, 68.73847307477678, 70.08062880379813, 69.2373606818063, 69.31355462755475, 71.2672699519566, 70.71660436902727, 74.37539373125348, 71.18232127598354, 74.87341281345913, 76.06818335396903, 74.3944456917899, 76.45143904004777, 73.3530774797712, 73.94214575631278, 78.36907236916679, 73.244247845241, 60.2007976259504, 3.232027964932578, 3.4867510965892246, 9.072241187095642, 7.749625529561724, 4.8842136178697855, 6.412601045199803, 1.4370699673891068, 0.29088665970734184, 8.281181829316274, 76.16655594961983, 46.82728712899344, 72.14005402156285, 50.42051676341465, 35.919775690351216, 49.559294496263774, 57.67840003967285, 56.49643850326538, 2.3605286606720517, 0.21921422705054283, 0.14759246738893644, 0.20045042676585062, 0.1203948568020548, 0.12674602600080626, 0.15661445898669107, 0.10950247664004564, 0.1139180093471493, 0.16765115676181658, 0.1374301298388413, 0.09870045698646988], [0.032717431895434856, 0.03681814131726112, 0.015607737137803009, 0.08055621345660516, 0.05887500436178275, 0.053467192221432924, 0.012152674990440053, 0.04715563589707017, 0.005639175618333476, 0.06341154700411217, 0.020013733035219566, 0.033346691701029024, 0.06494479865900107, 36.085660457611084, 54.9603932925633, 31.933847767966135, 35.863519600459504, 46.08767570768084, 63.74118273598807, 14.28622760091509, 0.11318762068237577, 0.13312976488045283, 3.19868095432009, 1.901762557881219, 1.8613459723336356, 1.3492182471922465, 21.243750674383982, 91.70908560071672, 80.72856943947929, 85.39484759739467, 74.70851816449846, 78.73942525046212, 77.86095755440849, 86.61439541407994, 82.15326281956264, 81.9289332798549, 78.47667217254639, 80.32647718702043, 79.13529886518205, 78.49407741001674, 75.6613871710641, 76.90608746664864, 76.69753033774239, 80.27336515699113, 74.78505257197789, 66.85314886910575, 59.79543277195522, 56.02437094279698, 53.14549602781023, 54.59435524259295, 57.756376198359895, 58.49955899374825, 53.88284928458077, 53.080464363098145, 50.83571331841605, 51.244121483394075, 49.75223207473755, 51.14700651168823, 50.70958614349365, 49.11246974127633, 51.54527030672346, 57.72826378686087, 62.45794078281948, 65.80028138841901, 65.89800780160087, 61.96165180206299, 64.12773881639752, 62.05904470171247, 64.85839748382568, 65.07725184304374, 56.824605396815706, 51.5616854258946, 55.179456097739084, 59.18010030473982, 61.84836837223598, 60.06625270843506, 51.50597129549299, 50.73787225995745, 52.45576919828142, 56.53206539154053, 53.88188001087734, 60.85067653656006, 62.277343205043245, 63.69494942256382, 60.150944301060264, 57.601198605128694, 57.454796586717876, 57.674012252262656, 57.22516904558454, 55.64808429990496, 53.45031002589634, 56.451772008623394, 56.02173062733242, 60.32262734004429, 57.66489621571132, 57.84972872052874, 54.47600310189383, 47.55607325690133, 51.60847112110683, 53.940314361027305, 54.73508753095354, 57.95786353519985, 59.18631199428013, 61.7442843573434, 61.777204922267366, 54.69580589021955, 57.97530003956386, 57.49415118353707, 55.77896056856428, 54.98572295052664, 56.388609409332275, 56.51221786226545, 57.949129649571006, 58.43039662497384, 59.60983943939209, 59.02209826878139, 58.27408994947161, 60.10663563864571, 59.96601104736328, 53.529675824301584, 46.16442550931658, 46.57823242459978, 46.36050714765276, 51.42847803660801, 60.31087098802839, 59.75929519108364, 64.79878193991524, 56.56371096202305, 61.561650957380024, 63.50054577418736, 64.16331359318325, 63.704392024448936, 64.67119216918945, 65.78903920309884, 65.73956108093262, 64.75489711761475, 68.03471783229283, 61.94571263449532, 66.2642820903233, 63.30334200177874, 67.30146053859166, 64.30131871359688, 70.00613716670445, 65.83999034336635, 69.83929007393974, 61.90822015489851, 66.01099940708706, 30.256910460335867, 0.28640417594994816, 1.0922241402523858, 2.7017292891229903, 2.6805585622787476, 4.05948372398104, 0.3170247514333044, 0.06583382202578442, 0.2681242525577545, 45.37251499720982, 52.04397031239101, 41.40271036965506, 57.92724282400948, 41.27418606621878, 41.91238505499703, 35.30849749701363, 47.47657196862357, 1.8427382622446333, 0.08881097872342382, 0.09967009709881884, 0.05456669036565082, 0.045732513868383, 0.05041641735338739, 0.05900672157960279, 0.02167209467318441, 0.05280145098056112, 0.0811821755820087, 0.06500826203929526, 0.0192843146755227, 0.09162566411708083, 0.028339062551302568, 0.020750018169305155, 0.02124321474028485, 0.04225681323025908, 0.048145014593111615, 0.06837731054318802, 0.014604757207312753, 0.01661971953165318, 0.08395734988152981, 0.044850978135530434, 0.06174976724599089, 0.0905829593539238, 47.19932842254639, 59.866498947143555, 40.95005260195051, 36.85209192548479, 52.000693457467214, 75.94986248016357, 15.229714802333287, 0.044748498991663964, 0.3622380910175187, 3.793454570429666, 2.6409527446542467, 1.2647521453244346, 1.123264348932675, 29.524177755628312, 95.83122948237828, 82.4229988370623, 88.71407849448067, 76.42423684256417, 82.40038939884731, 81.11031736646379, 88.26145199366978, 84.32265717642647, 85.45554011208671, 82.10090119498116, 81.28089564187187, 80.88501507895333, 80.61648109980992, 79.85398578643799, 81.17556095123291, 78.18335396902901, 82.26115444728306, 77.91239506857735, 71.52511065346854, 62.06499235970633, 59.62069252559117, 57.14054693494524, 58.5556309563773, 61.4538357598441, 60.105197361537385, 54.88615526471819, 54.55927031380789, 53.29548331669399, 54.1087977545602, 54.33931813921247, 55.451478072575156, 52.11188895361764, 51.59422036579677, 53.87453229086739, 62.15218530382429, 66.21027374267578, 65.76428277151925, 69.57987907954625, 65.31365040370396, 66.60411153520856, 64.7966696875436, 68.325117792402, 65.611373765128, 60.446868079049246, 53.491842882973806, 57.73706020627703, 63.14234529222761, 64.08864130292619, 63.52606650761196, 53.89777748925345, 54.356598309108186, 55.95408296585083, 57.080695152282715, 56.39671448298863, 62.3210334777832, 63.58393110547747, 64.93626594543457, 62.65375491550991, 61.22284984588623, 58.90744604383196, 59.96363476344517, 58.49432700020926, 58.42859704153878, 55.425734996795654, 57.21798113414219, 57.78753539494106, 61.64091600690569, 61.577770778111045, 59.957277161734446, 56.063704695020405, 49.88944162641253, 56.1330303464617, 55.320681708199636, 56.355706214904785, 61.136261395045686, 60.52763393947056, 63.27673734937395, 64.31922422136579, 57.44022968837193, 60.540842464991975, 60.871423857552664, 58.70500332968575, 58.299374444144114, 61.737572397504536, 59.73007106781006, 60.65017236982073, 60.61835656847273, 61.42836366380964, 61.211149079459055, 62.21994413648333, 62.32837077549526, 62.37359660012381, 55.30063615526472, 46.92683049610683, 48.07693454197475, 48.52128921236311, 52.804078919546946, 61.935519627162385, 63.08337593078613, 67.02446365356445, 60.84548623221261, 64.07384163992745, 63.51975754329136, 66.26021044594901, 65.34283283778599, 66.97331796373639, 68.57011822291783, 66.56718185969761, 66.87764821733747, 67.72409166608537, 65.26934174128941, 66.18307154519218, 67.50878088814872, 69.97040258135114, 67.65269197736467, 71.27277987343925, 70.71189349038261, 70.35340813228062, 69.04075445447648, 68.48170934404645, 40.03031955446516, 0.660112304346902, 0.7596255987882614, 0.9611704753977912, 3.0146068888051167, 3.029397649424417, 1.6542963853904178, 0.06753515359014273, 0.11061950812914542, 45.98088189533779, 58.707546370370046, 46.299825055258616, 50.884993416922434, 34.66432305744716, 50.63326365607125, 39.439305782318115, 56.04949215480259, 2.64459142940385, 0.054116794506886175, 0.017357619579083154, 0.03420570007126246, 0.03794137800910643, 0.04155886532472713, 0.022062279450308, 0.04234116191842726, 0.032368044036307504, 0.021299253251137476, 0.055305699817836285, 0.026245118750791465, 0.1647053784025567, 0.1897730947073017, 0.11157291089849812, 0.14617844112217426, 0.1762441106672798, 0.11257239298096725, 0.16613030194171838, 0.10671715824199574, 0.12007257980959755, 0.26386565821511404, 0.14195279644003936, 0.17265081991042408, 0.20574997525129998, 54.365300927843364, 70.43324293409074, 43.277980531964985, 51.211426734924316, 65.5053859438215, 84.14823654719761, 22.38190381867545, 0.18627239683909075, 0.3191978819668293, 9.826942358698163, 7.411309923444476, 8.505345480782644, 2.8830286349569048, 28.64614084788731, 99.19898659842355, 84.8822581427438, 95.30251325879777, 80.982574735369, 87.64137390681675, 83.9520958491734, 90.11238956451416, 88.71609347207206, 89.68852165767125, 84.38571207863944, 84.50196933746338, 83.06636728559221, 86.08253165653774, 81.85649136134556, 83.79228033338273, 83.44348076411656, 84.21710014343262, 81.54714366367885, 75.06796932220459, 65.93431213923863, 63.11723450251988, 60.13292762211391, 61.456691469464985, 66.39635344914028, 66.29007380349296, 59.21514007023403, 59.073139735630576, 56.99075766972133, 58.1046268599374, 58.376645360674175, 57.985916887010845, 56.312804562704905, 55.02260051454817, 57.24472822461809, 63.2946081161499, 68.26129164014543, 71.19296591622489, 70.15503011431012, 64.77842371804374, 68.22433417184013, 65.84580598558698, 71.69621699196952, 69.44771044594901, 63.793196950639995, 57.47334827695574, 61.94497612544468, 67.47984858921596, 67.84551838466099, 66.18424579075405, 57.29381029946463, 59.58570834568569, 59.8666170665196, 61.634308270045686, 57.380707945142476, 63.51893765585763, 68.06220490591866, 67.84347561427525, 66.01160390036446, 64.03252765110561, 62.59383365086147, 62.70428916386196, 60.78207697187151, 61.633682932172505, 56.11031321116856, 61.394261905125205, 60.41490636553083, 64.81306048801967, 63.08997671944754, 63.01283087049212, 57.10377011980329, 52.5022873878479, 58.66186891283308, 59.66930212293352, 60.87088884626116, 64.72371360233852, 64.8354823248727, 65.32614326477051, 67.73000458308628, 59.75697449275425, 61.39467879704067, 63.13013730730329, 61.81601061139788, 60.67050974709647, 62.34888185773577, 63.96495641980852, 62.85403673989432, 60.577396937779014, 63.98004790714809, 62.699807575770784, 64.0829507282802, 63.635653495788574, 65.5265223639352, 58.7016612461635, 51.755769457135884, 50.76591171537127, 51.775894914354595, 56.26313883917672, 65.0586793082101, 66.2896499633789, 70.891740662711, 63.132909638541086, 65.3544293812343, 68.35435581207275, 68.81236716679165, 68.63881506238664, 70.50531659807477, 71.55339676993233, 69.92320346832275, 71.21194839477539, 73.38024493626186, 67.89003549303327, 67.46624401637486, 71.24123505183628, 72.52571378435407, 72.00186824798584, 75.47432776859829, 75.17174761635917, 72.58189691816057, 71.904294695173, 70.60769830431256, 44.77897902897426, 0.471568158694676, 3.859622265611376, 5.996760044779096, 7.797619342803955, 10.094751119613647, 1.6671791055372782, 0.12175888860864298, 0.4440465612070901, 55.116435936519075, 63.475101470947266, 55.59680659430367, 76.18155711037772, 51.80061660494123, 54.951398849487305, 47.50317662102835, 66.40912423815045, 4.098905197211674, 0.26197786522763117, 0.17250827327370644, 0.15444879233837128, 0.15183481760323048, 0.17243495077959128, 0.12361405763242926, 0.0727949942063008, 0.20869085458772524, 0.17035662515887193, 0.1053075220968042, 0.07515541397567306], [0.027580070242817913, 0.029272760663713728, 0.013962434754440827, 0.048889974797410626, 0.07369721507919685, 0.002409979118965566, 0.11028327367135457, 0.04546469609652247, 0.062473533408982415, 0.04184684915734189, 0.09281607916844742, 0.08240755554288626, 2.158299603632518, 51.16374472209385, 47.0123975617545, 32.9272768838065, 36.27606194359915, 61.63194588252476, 48.792244638715474, 4.946403035095759, 0.2520223722926208, 1.1821982094219752, 1.8843668741839272, 1.7280904884849275, 1.325148058789117, 2.2210131755896976, 66.76683834620884, 86.13355922698975, 82.26268999917167, 75.14106437138149, 77.30105781555176, 77.91547312055314, 81.21103845323834, 80.37164742606026, 77.73694610595703, 78.83246857779366, 81.97075448717389, 78.3062606539045, 77.88872950417655, 76.29825210571289, 72.94186919076103, 76.66791711534772, 82.01116521017892, 74.04620197841099, 72.73078291756767, 64.60353061131069, 57.8040269442967, 55.85119751521519, 53.67361123221261, 54.33557653427124, 56.257965905325754, 55.5907164982387, 53.317182540893555, 50.30699014663696, 51.303782190595356, 50.951744760785786, 50.75865432194301, 49.44894668034145, 48.996719700949534, 51.925093582698274, 53.59282800129482, 61.35011999947684, 61.075429916381836, 67.57130077907017, 70.07491043635777, 67.67159802573067, 63.38197476523263, 68.68445777893066, 65.02473040989467, 61.262496267046245, 56.54059777941023, 50.11667898723057, 56.50552674702236, 58.97967256818499, 60.71286596570696, 59.23327486855643, 48.57666288103376, 47.65248646054949, 52.26433590480259, 53.48336260659354, 57.54695054462978, 62.2235780443464, 59.72936929975237, 60.25129018511091, 59.93969127110073, 57.45510230745588, 59.492706707545686, 58.57036113739014, 56.26173530306135, 56.086196013859336, 59.08193615504673, 59.14084298270089, 55.86182478496006, 58.72541018894741, 59.17283248901367, 57.12324939455305, 54.08829362051827, 53.272693225315635, 50.36747074127197, 51.78313841138567, 49.66888495853969, 51.78340939113072, 54.355055809020996, 60.177625383649556, 56.81130654471261, 56.51031058175223, 58.10279948370797, 61.074227878025596, 55.69507149287632, 65.76933411189488, 60.43105397905622, 58.26392820903233, 59.240355082920615, 61.19405651092529, 61.57806955065046, 62.25271878923689, 59.58626420157296, 60.1853517804827, 60.302873611450195, 53.83845029558454, 44.98537874221802, 46.158717564174104, 47.234208379473, 50.61843272617885, 56.46165929521833, 61.988437107631135, 63.11532374790737, 59.60551071166992, 62.47274044581822, 63.234839711870464, 59.72328962598528, 61.8126893724714, 60.0333251953125, 62.46012946537563, 61.78238827841622, 65.66858523232597, 61.40876974378313, 63.20610196249825, 62.764801025390625, 61.96300670078823, 61.541251046316965, 66.48792375837053, 63.674403599330354, 70.10838685716901, 68.86269296918596, 71.00016730172294, 59.41647802080427, 62.34667927878243, 12.025822264807564, 0.8216155267187527, 1.6963803214686257, 2.4604313799313138, 2.3589407801628113, 0.5767934694886208, 0.27496203993047985, 0.2141182662120887, 18.085552964891704, 66.993453843253, 39.16518892560686, 42.51489462171282, 38.013285296303884, 36.99817085266113, 37.80592325755528, 48.08048507145473, 2.352509353842054, 0.14067447717700685, 0.024618107127025723, 0.02624742068084223, 0.055008345416613987, 0.009323815848412258, 0.02082452640336539, 0.04636477958410978, 0.047549254061388116, 0.007601870390187416, 0.007880412408017685, 0.0654158987370985, 0.06151726722185101, 0.022120082152209113, 0.028458167499463474, 0.011745261361024209, 0.0483869530393609, 0.049160873118255816, 0.06531560447599206, 0.023454109140272652, 0.04675397030743105, 0.03125972493684717, 0.03243624698370695, 0.1498701058860336, 3.2553374341556003, 62.75149522508894, 51.2730016708374, 44.4483003616333, 32.66004569189889, 67.44104290008545, 55.85045405796596, 5.073806072984423, 0.38489844650030136, 1.6731418541499545, 2.5857844821044376, 2.5175308074269975, 0.7733473681977817, 6.019292618547167, 74.07942131587437, 90.43050588880266, 85.27205903189522, 78.16127954210553, 79.0683946609497, 78.70158536093575, 83.16164098467145, 81.62544986179897, 80.05375344412667, 83.87157317570278, 85.36114883422852, 80.14348248073033, 81.56989206586564, 78.84223774501255, 75.66855076381138, 78.27351379394531, 83.5083144051688, 78.19338716779436, 75.34691865103585, 68.50046253204346, 61.80413614000593, 57.8224709374564, 57.07473359789167, 57.81166648864746, 59.48942020961216, 57.78837612697056, 56.27887998308454, 55.01358870097569, 54.367666789463584, 52.999962534223286, 51.595971311841694, 51.17505986349923, 51.63540581294468, 56.19100611550467, 58.700410570417134, 62.805232592991416, 63.99393040793282, 69.59724262782505, 73.19618020738874, 69.02400929587228, 66.86038194383893, 71.06874602181571, 68.2443380355835, 64.57270840236119, 58.11225945608956, 52.98009763445173, 59.262102944510325, 61.449889183044434, 65.01153578077043, 62.0722393308367, 53.060269423893516, 51.84451184953962, 54.56146594456264, 55.09536552429199, 61.48285838535854, 63.44685009547642, 62.492056437901084, 62.03993715558733, 62.95718274797712, 60.10803917476109, 60.81087725503104, 60.7381226675851, 58.542679514203755, 57.67416858673096, 59.81631905691964, 62.34239224025181, 58.33568572998047, 61.71528952462332, 61.616951669965474, 58.345003264290945, 56.85193266187395, 55.35216052191598, 53.165076051439556, 54.613167490277974, 52.09496314185006, 53.36023357936314, 56.49209587914603, 59.882285254342214, 58.743843759809224, 59.48099204472133, 60.54928452627999, 62.155979020254954, 60.3898720060076, 69.66953863416398, 63.21664932795933, 60.44984885624477, 62.00249331338065, 61.38299887520926, 62.02125344957624, 64.06145995003837, 60.217653955732075, 62.07132911682129, 63.0020055770874, 55.27822126661028, 47.83231626238142, 50.21815742765154, 48.23555844170706, 51.280891350337434, 59.23477567945208, 64.63130950927734, 63.90530613490513, 60.29581424168178, 65.36139842442104, 66.246383530753, 62.589567456926616, 63.78665174756731, 62.175767489842, 64.40671593802315, 65.37360640934536, 67.68686321803501, 65.14153657640729, 65.38684272766113, 64.66075597490583, 63.92750562940325, 62.7826509475708, 68.96230234418596, 67.35446834564209, 73.05080999646867, 71.43388775416783, 70.54936817714146, 63.77042075565883, 66.22412150246757, 17.962985004697526, 0.7258391146148954, 0.5456389412283897, 1.6471600426094872, 2.385068395308086, 2.1680212191173007, 0.7882159160716193, 0.26143501007131165, 17.49557794843401, 75.64858164106096, 49.47525256020682, 42.37651082447597, 31.36845895222255, 42.592804772513254, 45.61468403679984, 56.4237916128976, 3.960927435329982, 0.1365339072155101, 0.0401261827376272, 0.021433981468102763, 0.004884893615131399, 0.03229956288955041, 0.05346407774569733, 0.03088503789954952, 0.03797002915026886, 0.04811191565490194, 0.02816720150544175, 0.011123479859504317, 0.20622912954006875, 0.16853736420827253, 0.0943546641085829, 0.12478951098663466, 0.22857331484556198, 0.11856629992169992, 0.13859695222760948, 0.12068414342190538, 0.21878309947039398, 0.15495785645076207, 0.19701348404799188, 0.28407582374555723, 3.89650764635631, 73.00085244859967, 60.080260276794434, 44.78854322433472, 50.3554573059082, 76.29736968449184, 67.29693726130894, 9.085018055779592, 0.49637963303497856, 3.608712826456342, 6.997328434671674, 6.621120827538626, 5.473460376262665, 6.836551896163395, 76.50057670048305, 95.28407968793596, 90.7901863370623, 80.89669500078473, 84.07880319867814, 85.01379449026925, 85.37380150386265, 86.8001902444022, 82.50133977617536, 85.13501971108573, 88.31512682778495, 84.55970886775425, 84.15245410374233, 82.53295407976422, 78.82173361097063, 81.70766789572579, 83.99380588531494, 82.20362336294991, 80.84720298222133, 72.07503277914864, 63.862296785627095, 62.935386248997276, 60.17237254551479, 62.46024758475167, 63.472363880702424, 62.17309938158308, 59.65037522997175, 57.421806539808, 58.360344886779785, 58.00535447256905, 55.510270254952566, 55.15540490831648, 53.780481474740164, 59.80066476549421, 60.62789644513811, 66.1400066103254, 65.72999341147286, 73.30318246568952, 73.87153816223145, 73.26232705797467, 69.89904458182198, 75.69318212781633, 69.4819164276123, 67.41290964399064, 62.085955074855256, 55.94025952475411, 63.48204966953823, 66.67206491742814, 65.9712974003383, 65.44599274226597, 57.63479314531599, 57.52061339787075, 58.68230356488909, 55.99096747807094, 61.65330464499337, 67.76963015965053, 65.11538355691093, 65.0936495917184, 65.0551426751273, 62.05067907060896, 63.56602559770857, 64.65439837319511, 60.79466710771833, 60.52413899557931, 63.61325945172991, 63.747929436819895, 60.00148854936872, 63.49295139312744, 62.4949677331107, 61.71228790283203, 58.32966859000069, 57.970439774649485, 56.93403952462332, 56.67560127803257, 55.04853119168963, 58.17782265799386, 61.780873571123394, 63.09420122419085, 62.071565355573384, 62.12810284750802, 61.92473602294922, 64.91808945792062, 62.537344796316965, 68.3846777507237, 66.00436387743268, 63.59673663548061, 65.24883065904889, 65.54361493246896, 64.76439530508858, 67.97387245723179, 63.60257312229702, 64.94144235338483, 64.72744478498186, 59.51487840924944, 48.816743986947195, 52.216066769191194, 50.25020251955305, 56.63026428222656, 63.25651114327567, 66.45061193193708, 68.35710035051618, 64.26128319331578, 67.57383687155587, 68.41055284227643, 65.0622228894915, 67.4740537915911, 65.051835332598, 68.59819589342389, 69.14125319889614, 70.97901003701347, 65.53001730782645, 69.68007210322789, 68.62898336138043, 69.00640256064278, 66.41582230159214, 71.20852988106864, 68.96233013698033, 76.73593997955322, 74.54913343702043, 75.18237141200474, 67.7002454485212, 71.02750151497978, 18.50972138132368, 1.8390908922467912, 7.001093055520739, 5.470678491251809, 7.708374074527195, 3.5684586550508226, 0.5445912288767951, 0.2568384238651821, 22.44433512006487, 82.27253559657505, 53.143012046813965, 58.69686004093715, 51.61200428009033, 48.29973895209176, 49.794470173971995, 69.14176736559186, 5.122884239469256, 0.28628646369491306, 0.19188286364078522, 0.14263295994273253, 0.14887310724173272, 0.1175232423203332, 0.24827767323170388, 0.13155880703457765, 0.11773415814552989, 0.11194595588105065, 0.10360117615865809, 0.18846505561045238], [0.013282331471730555, 0.006784805238047349, 0.06552898338330643, 0.057442013041249344, 0.06266873436314718, 0.009712539230739432, 0.0646324757752674, 0.06876908987760544, 0.07529447972774506, 0.12739451548882894, 0.2184605374932289, 0.3345279150775501, 7.8883011511393955, 63.100906235831125, 51.00542654309954, 35.35282352992466, 49.77765553338187, 72.61107240404401, 29.505285603659495, 1.300786371741976, 0.08330064333443131, 0.8190060981682369, 0.6603003942540714, 1.2070536528314864, 0.8953901422875268, 24.039603301456996, 86.1872479575021, 84.08463273729596, 81.4524814060756, 73.97023037501744, 70.10476684570312, 78.17422403608049, 80.2869975226266, 79.36978667122978, 73.54204763684953, 78.4301539829799, 77.63204220363072, 78.67566858019147, 78.78160081590924, 80.27565806252616, 75.81215613228935, 78.32483318873814, 73.04425784519741, 69.38125092642647, 68.19809082576207, 61.68935884748186, 55.323134422302246, 53.52985995156424, 53.07992240360805, 54.7581798689706, 53.896881171635215, 55.00403840201241, 50.793676716940745, 48.958518505096436, 51.294124194553916, 49.83369970321655, 50.43796369007656, 47.19373859677996, 52.523041657039094, 54.00107288360596, 58.89289651598249, 61.13341958182198, 65.41717161451066, 66.98394175938198, 68.40406322479248, 62.555451801845, 62.16811057499477, 64.96549006870815, 66.514313016619, 60.156641823904856, 54.72933094842093, 52.36018977846418, 59.28343391418457, 60.8350430897304, 62.58764975411551, 55.09354509626116, 50.4304735319955, 48.13765137536185, 55.18081099646432, 57.90111064910889, 63.284936223711284, 63.15619305201939, 60.693626403808594, 60.038661411830354, 57.614594732012065, 60.34117208208357, 60.02168696267264, 57.39822087969099, 56.62180137634277, 55.614253520965576, 57.68223544529506, 54.890626430511475, 55.46588168825422, 57.03104679925101, 58.35479327610561, 58.965873445783345, 54.426955768040244, 52.30288798468453, 50.55648258754185, 49.07363625935146, 50.645926748003276, 49.6024671282087, 53.898100580487935, 55.58293798991612, 56.87174545015608, 57.25622401918684, 60.83967753819057, 57.22302900041853, 67.37246417999268, 59.20771939413888, 53.40864167894636, 60.41889463152204, 59.53857176644461, 57.45294141769409, 58.958147048950195, 60.69521754128592, 59.67714663914272, 58.80845505850655, 56.201515265873496, 48.77851847239903, 45.00833559036255, 44.53024394171578, 45.593040398189, 46.557353087833945, 53.52413463592529, 61.166444369724815, 62.10446507590157, 61.484789984566824, 61.910394941057476, 63.12120887211391, 59.40571526118687, 54.74973085948399, 59.243245533534456, 60.54280185699463, 59.578398840767996, 61.90004907335554, 59.10750552586147, 59.048932211739675, 59.07564803532192, 59.252472741263254, 62.61621379852295, 65.51193809509277, 66.08379568372453, 69.87839453560966, 69.24432277679443, 68.29837417602539, 65.32257189069475, 57.57743229184832, 52.023375851767405, 1.209688431450299, 0.6809374668768474, 2.3124412638800482, 1.344064638018608, 1.6294941391263689, 0.567579832460199, 0.20755057648888656, 3.222275299685342, 63.02631037575858, 50.72150577817644, 42.7470999445234, 47.61696032115391, 63.54372188023159, 40.16427387510027, 46.17458030155727, 4.989303818770817, 0.27131654268928934, 0.05124858966363328, 0.057672714947589805, 0.09784957407308476, 0.040981150431824584, 0.008698471189875687, 0.059263716717915874, 0.028883899029876505, 0.03418564596878631, 0.018802568382982696, 0.0020366044108024134, 0.013626953470520675, 0.0035975392342412044, 0.03450516132371766, 0.019962432395134653, 0.05521488808361547, 0.05750766808965376, 0.020259186292865446, 0.021643467280747633, 0.0444940517523459, 0.03484976211828845, 0.13109648041427135, 0.3542182685009071, 11.471131069319588, 71.53888198307583, 57.29494980403355, 44.039628165108816, 35.6894394329616, 79.84585639408657, 31.469416277749197, 0.9751962827784675, 0.2841955173228468, 2.4644478729793002, 1.8157644867897034, 2.4994750448635648, 0.05837186386010476, 30.69714137486049, 92.68273666926792, 83.12230028424943, 85.60897718157086, 75.72179480961391, 74.95822947365897, 82.9467887878418, 80.8625237601144, 84.87643555232457, 77.12776279449463, 79.53741196223667, 79.7160154070173, 80.72376823425293, 82.25350448063442, 82.26346819741386, 80.21548666272844, 79.59251117706299, 75.97341687338692, 73.77698707580566, 70.97896139962333, 64.37795039585659, 58.98457104819161, 54.529636246817454, 56.1580091203962, 56.75540828704834, 58.089240074157715, 59.03598076956612, 54.71585839135306, 53.75761495317732, 53.2638829095023, 51.90223748343331, 52.56459535871233, 50.060085909707205, 53.88194949286324, 58.4317376273019, 61.151971272059846, 65.67557512010846, 68.34939479827881, 68.41647270747593, 70.79469517299107, 64.25690582820347, 65.97143636431012, 67.80306489127022, 67.65044770921979, 61.99496146610805, 57.134915419987266, 55.175881249564036, 63.26888588496617, 64.76175498962402, 64.29125077383858, 58.471314566476, 54.88062449863979, 52.55350603376116, 56.57423400878906, 57.619371618543354, 65.06054837363106, 66.00721958705357, 65.55138301849365, 61.05728816986084, 60.00132179260254, 63.13231209346226, 60.272635051182334, 59.11449541364397, 57.42559330804007, 58.46231664930071, 59.56321702684675, 56.804163796561106, 59.1196996143886, 58.486649240766255, 59.8105103628976, 61.62955570220947, 56.971063000815256, 54.84458071844918, 53.225813729422434, 53.12437697819301, 53.91085399900164, 54.03251348223005, 56.67029632840838, 56.87858942576817, 59.78145299639021, 57.2371894291469, 62.67255674089704, 59.91656766619001, 71.26732553754533, 61.29206780024937, 55.46193511145455, 63.22085298810686, 60.85714530944824, 61.266192708696636, 61.305262429373606, 61.346534729003906, 59.703125953674316, 60.642105511256624, 56.20284237180437, 52.11608566556658, 48.119103159223286, 47.56383786882673, 47.785971777779714, 47.923893519810264, 57.599426814488, 63.305954524448936, 64.20063931601388, 63.93234852382115, 63.5269558770316, 63.8224002293178, 60.89310918535505, 56.70137562070574, 60.020644732883994, 63.25015354156494, 62.6887321472168, 62.37697342463902, 61.011999811444966, 60.85453278677804, 60.59710897718157, 61.17333003452846, 65.40959807804653, 67.12576838902065, 70.29563386099679, 71.4204568862915, 71.3844860621861, 70.40353243691581, 69.3664026260376, 61.09985978262765, 59.751144954136436, 2.524454904454095, 0.9405078355755124, 0.9321504554578236, 2.6677925501550948, 3.7619001950536455, 0.9958702134234565, 0.2541234152657645, 2.4247476032802036, 66.48408140454973, 57.94080918175833, 47.61548382895333, 37.42575257165091, 63.666920389447895, 45.319799014500205, 54.30153036117554, 6.857525902135031, 0.33166118604796274, 0.26436853408813477, 0.06011950543948582, 0.13144299467759474, 0.029312987612294297, 0.05061683624184557, 0.0637018039290394, 0.0627005576555218, 0.026815174679671015, 0.05126090168154665, 0.04897162630887968, 0.10893036305372204, 0.12357957448278155, 0.2067261157291276, 0.10226775985211134, 0.13085440626101835, 0.16717709148568766, 0.10955310892313719, 0.14852121898106166, 0.1910483469920499, 0.3477921076118946, 0.34291113380874905, 0.49112022668123245, 13.161885738372803, 82.4363602229527, 66.34026064191545, 46.22947801862444, 66.05810124533517, 89.21733651842389, 44.433417320251465, 1.8486629043306624, 0.14257945067116193, 3.5281671370778764, 3.843141572816031, 7.306492005075727, 2.37606201001576, 33.27703530447823, 96.91102123260498, 89.95822293417794, 89.56554549080985, 80.5869026184082, 79.18701430729458, 86.6862050465175, 84.40041446685791, 89.02514934539795, 80.17577075958252, 82.33812659127372, 82.87507643018449, 82.50220830099923, 85.5538432257516, 83.01229640415737, 83.02691541399274, 82.92327608380998, 81.394686290196, 77.07778440202985, 73.61763014112199, 67.41566807883126, 60.83767645699637, 58.46026693071638, 59.25256306784493, 61.34251867021833, 60.56681483132498, 62.3415584564209, 58.825068201337544, 55.43405893870762, 56.19395562580654, 54.70648527145386, 55.08303247179304, 52.94926847730364, 56.98434795652117, 60.54063401903425, 64.32886832101005, 69.70424488612584, 70.30333941323417, 72.17326641082764, 72.45151397160122, 65.84206785474504, 68.0545688356672, 72.0800563267299, 71.67203031267438, 65.36221136365617, 59.96992288316999, 58.19518273217337, 68.64213630131313, 68.26894855499268, 68.74639402117047, 64.12211772373745, 60.56408418927874, 57.87027454376221, 58.85344464438302, 62.90128449031285, 68.79115431649345, 69.39526544298444, 67.82359681810651, 65.34148488725934, 65.06571783338273, 67.35782432556152, 63.247874532427105, 61.07339409419468, 61.88969625745501, 61.230562346322195, 64.38407870701381, 59.55451093401228, 62.07411534445626, 63.16509369441441, 62.1635525567191, 62.50858620234898, 59.57559871673584, 57.31101751327515, 56.193017618996755, 54.71938112803868, 56.382536683763774, 55.27488613128662, 58.849935804094585, 61.82531424931118, 62.33573586600167, 62.809630802699495, 66.07942526681083, 62.62164034162249, 67.28609807150704, 65.31976481846401, 58.51813847678048, 64.48745400565011, 64.83193179539272, 62.02019732339041, 64.21190234592983, 63.48463439941406, 63.868925367082866, 63.75811549595424, 61.07820919581822, 55.22597081320626, 50.62702069963728, 50.075538703373496, 50.885326930454795, 51.2844557762146, 59.77697835649763, 67.3656063079834, 67.95122132982526, 66.42090143476213, 67.28769615718296, 67.234952381679, 65.4005515234811, 60.43334688459124, 64.60744244711739, 65.7521790095738, 65.31515121459961, 66.06114455631801, 64.45413044520787, 64.98021330152238, 63.88893617902483, 63.92802674429757, 68.73780604771206, 69.87904071807861, 71.98788152422223, 75.05931186676025, 74.28655406406948, 72.84598405020577, 69.24763011932373, 64.32241344451904, 61.8565741947719, 2.191005425793784, 3.161443821021489, 7.0742137261799405, 6.383456826210022, 6.2748213069779535, 1.4794597327709198, 0.33475826414568083, 4.152942206178393, 74.69646303994315, 61.89939594268799, 59.35474327632359, 62.50309017726353, 72.75900650024414, 50.77013622011457, 66.14145183563232, 7.7510499102728705, 0.5386403139148439, 0.2836000621318817, 0.14787989482283592, 0.22502327391079494, 0.13540797334696564, 0.1314926498702594, 0.18078709260693618, 0.1659670735576323, 0.1199630099747862, 0.21601641364395618, 0.1492670782442604], [0.04324217499899013, 0.06778019294142723, 0.03367441054433584, 0.04030338555042233, 0.04068267305514642, 0.020266916503065398, 0.07401041327310459, 0.032869559446615834, 0.1094074681667345, 0.07116572984627315, 0.08820611225175005, 0.17317568031804903, 18.40260100364685, 64.07117353166852, 37.731125899723594, 33.87731449944632, 52.89200489861624, 60.72868701389858, 13.719337105751038, 0.02986806318429964, 0.21642835225377763, 1.2325898025717055, 0.9677130728960037, 2.2423219978809357, 0.3053141055362565, 45.36685568945748, 86.58679022107805, 82.35107803344727, 75.19287014007568, 68.42082227979387, 66.88490908486503, 70.5734645298549, 75.71883487701416, 84.9707087108067, 83.50080340249198, 75.79227038792202, 80.81032194410051, 77.20660400390625, 80.65115261077881, 77.26014682224819, 75.85749312809536, 71.6232886995588, 72.26699760981968, 70.31657573154995, 66.74156774793352, 59.36039216177804, 54.33117485046387, 52.495835985456196, 54.584089279174805, 52.709930828639436, 53.14892496381487, 53.89093698774065, 51.37680080958775, 50.33946255275181, 51.43182359422956, 51.11611829485212, 48.5518091746739, 51.15981898988996, 54.46759230749947, 59.89677919660296, 61.13541371481759, 64.75680092402867, 63.640892437526155, 65.46276569366455, 62.369476318359375, 63.82276153564453, 63.32262325286865, 63.98238250187465, 61.326329367501394, 56.45809139524187, 56.3239529473441, 57.449119908469065, 60.31927830832345, 61.107878003801616, 57.8777369090489, 51.682587555476594, 49.92514147077288, 48.23539515904018, 57.818128313337056, 60.6706417628697, 62.08988775525774, 58.562537465776714, 58.78887503487723, 52.89997795649937, 56.20048345838274, 55.521237986428396, 52.129561696733745, 54.47451271329607, 54.82653624670846, 57.17752524784633, 55.24398054395403, 50.29352453776768, 47.96996007646833, 51.89800255639212, 54.2052526473999, 57.750459807259695, 59.49404770987374, 51.19517837251936, 50.99291631153652, 51.54137931551252, 52.5330296925136, 55.95243624278477, 55.26973404203142, 54.505685806274414, 53.31461518151419, 53.34602798734392, 56.10065521512713, 61.61791052137102, 51.37404237474714, 49.493686131068635, 61.22596958705357, 57.34605380467006, 57.74627004350935, 55.30184166772025, 54.958499908447266, 52.77294404166085, 52.41227000100272, 51.1214336667742, 50.05841834204537, 48.32989065987723, 46.428536960056846, 44.78903654643467, 44.9145314352853, 45.489331586020334, 51.639585154397146, 59.41583183833531, 60.953224999564036, 60.74744020189558, 60.97493117196219, 59.66667570386614, 54.74741016115461, 50.386911800929475, 50.83178063801357, 54.76679563522339, 56.50071164539882, 58.12379346575056, 56.7762702533177, 60.400433267865864, 58.1763322693961, 63.0582651410784, 63.96261487688337, 66.61363056727818, 66.91081196921212, 68.29394122532436, 71.10276440211705, 65.9851382119315, 67.23027624402727, 61.534226417541504, 61.42121396745954, 31.842607498168945, 0.26460037593330654, 0.3756535697196211, 3.455967536994389, 1.2837655650717872, 1.332115690623011, 0.167874544060656, 0.1795276366174221, 42.912522656576975, 62.64714023045131, 42.60890374864851, 43.20749453135899, 18.529339620045253, 31.35335009438651, 50.13331297465733, 6.96522775718144, 0.2364341158952032, 0.09840924332716636, 0.05464810438986335, 0.05547460414735334, 0.04806153782244239, 0.0556958201341331, 0.07461692858487368, 0.05420626274177006, 0.03407895990780421, 0.027336028338010823, 0.09077139531395265, 0.01843951313224222, 0.06352918462029525, 0.07016105018556118, 0.037759269388126473, 0.006924574546116803, 0.01482820387796632, 0.0950730155621256, 0.024958657067535178, 0.1278021793280329, 0.036707041385982714, 0.21378655758287224, 0.20347129181027412, 25.203994580677577, 69.61643355233329, 48.45892218181065, 43.9804607800075, 43.89964975629534, 69.39135360717773, 12.942484208515712, 0.0845513055101037, 0.8483800962567329, 4.3314231889588495, 1.6208181189639228, 0.3226856333868844, 0.711376927793026, 54.05273968832833, 89.67315224238804, 85.12010192871094, 78.8651876449585, 71.13332952771867, 68.35394586835588, 73.46095521109444, 77.57323265075684, 83.58755166190011, 85.35004561288017, 79.03052003043038, 83.89425904410226, 81.58544213431222, 83.43534442356655, 78.9868506022862, 78.42203153882707, 74.90338734218052, 74.62249946594238, 76.02818257468087, 68.97855418069022, 61.14887237548828, 56.86852843420846, 55.41303021567208, 55.9899252482823, 56.66871908732823, 57.88501514707293, 57.16641160420009, 55.074812752859934, 52.74237196786063, 52.64468724387032, 51.900622027260916, 51.769662380218506, 53.86986657551357, 58.099297591618125, 63.567206791469026, 63.312207903180806, 67.15533992222377, 67.00963619777134, 66.10547406332833, 65.82170268467495, 67.29806981767926, 65.18068272726876, 65.81431674957275, 65.22036388942173, 59.086542810712544, 58.174897466387065, 59.925565583365305, 62.769303458077566, 65.99196134294782, 60.902065413338796, 54.219739641462056, 53.204597405024934, 50.875543866838726, 61.9487281526838, 63.449254172188894, 64.14453261239188, 59.24637917109898, 59.46283640180315, 55.582163265773225, 59.69829000745501, 57.419266973223, 52.141147817884175, 57.86277396338326, 57.34910406385149, 57.79943765912737, 57.98945352009365, 55.0514702796936, 51.441498960767476, 54.750550746917725, 56.9326742036002, 60.17317853655134, 61.53054387228829, 55.142609800611226, 55.12251213618687, 55.02545275006975, 53.65879072461809, 58.19594703401838, 56.639929226466585, 57.577936036246165, 55.99108559744698, 55.91994299207415, 58.629476411002024, 62.16676262446812, 55.89973068237305, 52.65737812859671, 62.29926477159773, 59.564335686819895, 59.96795654296875, 58.71974045889718, 57.45396975108555, 55.37890066419329, 52.978711468832834, 52.85618346078055, 52.87147297177996, 50.962135791778564, 48.777542250497, 46.924329144614084, 47.53845957347325, 47.83798599243164, 55.22845132010323, 61.66655485970633, 62.959336689540315, 64.35289519173759, 63.33232293810163, 62.186328751700266, 56.68349095753261, 52.490944453648154, 52.565971102033345, 58.9034160886492, 61.298237800598145, 60.78926140921456, 61.279408182416645, 60.920200211661204, 61.418434688023154, 64.72291455950055, 66.6538953781128, 69.0036927631923, 69.06146703447614, 69.1369800567627, 70.15438393184117, 67.70632512228829, 67.72013814108712, 64.97936562129429, 66.42083195277623, 39.34922933578491, 0.26568060368299484, 1.0029498849596297, 2.138320709977831, 4.868826397827693, 3.2511704691818784, 0.22445631719061307, 0.2095659069184746, 44.951478481292725, 70.32105037144252, 50.197323254176546, 34.21551806586129, 24.86304473876953, 39.426528045109336, 57.15059750420706, 9.209705216544014, 0.31934987381100655, 0.16288417684180395, 0.11668042040296964, 0.018531576763572435, 0.04015234365527119, 0.07472923970116035, 0.010768369405663438, 0.0716564870838608, 0.11630934317197118, 0.06167225819081068, 0.05371702202994909, 0.10515233435268913, 0.1394311703209366, 0.11908878545675959, 0.14983012660273484, 0.11330513616225549, 0.1448453233710357, 0.16638604179024696, 0.12256667097764355, 0.28601154844675747, 0.21900667675903865, 0.24414919476423944, 0.35492326638528277, 26.6994240965162, 82.98317650386265, 49.5451340675354, 46.20109115328108, 69.8964181627546, 78.26202147347587, 23.106637409755162, 0.17295556355799946, 0.7753039374947548, 5.56921740940639, 4.163563396249499, 6.280981753553663, 1.264521443418094, 59.31540257590157, 93.77493790217808, 88.42705535888672, 82.92593029567173, 76.06659916469029, 72.16125992366246, 76.30525588989258, 81.73027038574219, 86.2170626776559, 89.09625720977783, 81.39772960117885, 86.46148640768868, 83.09118625095913, 86.87131200517926, 85.63876410893032, 81.76979173932756, 80.76440129961286, 77.58873408181327, 78.06656169891357, 73.24138518742153, 64.19326727730888, 59.64590753827776, 58.476546560014995, 60.26020472390311, 57.8489123071943, 58.68499946594238, 61.32506479535784, 57.65018687929426, 54.15700435638428, 56.308739866529194, 56.58987440381731, 54.01365954535348, 56.18486043385097, 60.89098998478481, 67.10880783626011, 67.34838172367641, 69.63745185307094, 69.71603597913469, 69.72524234226772, 68.55611065455845, 70.40986919403076, 69.88981737409318, 66.55778789520264, 67.2381763458252, 62.870198249816895, 61.30537360055106, 63.06336511884417, 65.55617032732282, 67.34885420118059, 64.9795810154506, 58.7626108442034, 60.553217206682476, 56.343477385384695, 63.33255222865513, 66.32366139548165, 68.32468700408936, 62.17942224230085, 62.99453626360212, 58.719566753932405, 61.617069789341514, 59.39580018179757, 56.98966680254255, 61.36227239881243, 60.676922934395925, 62.90486281258719, 60.47700241633824, 56.859016350337434, 51.50508540017264, 57.075678552900044, 61.00648294176374, 64.78715065547398, 61.862452370779856, 55.478617736271445, 57.13866744722639, 59.10123130253383, 58.44760036468506, 61.34648609161377, 61.84633255004883, 61.243312290736604, 61.111115864345, 58.32550661904471, 63.18898160117013, 64.0728827885219, 55.1452396937779, 56.69789457321167, 64.68426173073905, 63.7759028843471, 62.05971867697579, 62.381309100559776, 60.82115364074707, 58.560661452157156, 58.12126432146345, 57.570880140577046, 54.897605895996094, 54.05391045979091, 51.35276351656233, 50.07360363006592, 49.276700837271555, 49.95651953560965, 57.18663781029837, 65.47582135881696, 64.88211863381522, 65.50879056113106, 66.17861774989537, 65.52423640659877, 60.291019984654014, 54.824083532605854, 55.192268575940815, 61.626470702035085, 64.03223582676479, 64.94656317574638, 62.77257605961391, 64.77346965244838, 62.285500390189036, 69.02065331595284, 69.43812888009208, 72.90096514565604, 72.3189423424857, 72.7106887272426, 74.73931952885219, 70.18185710906982, 70.49025290352958, 65.18007128579276, 69.12204142979213, 39.004921776907786, 0.4117722330348832, 3.2101522130625586, 9.287136810166494, 8.923664382525853, 3.630324763911111, 0.28555459582379883, 0.22136070472853525, 54.24517004830496, 75.68189130510602, 57.925582204546245, 56.50105210712978, 26.040625435965403, 44.21031066349575, 67.78750092642647, 10.121671915054321, 0.43170343924845966, 0.22977383328335627, 0.2495050887976374, 0.20893953767205986, 0.1555538001869406, 0.14551962433116777, 0.23013706664953912, 0.11967099564416067, 0.14946776176137583, 0.1578218713402748, 0.20186085679701396], [0.046302937902510166, 0.04788287615935717, 0.07219080626964569, 0.033123901513006, 0.025906933504821997, 0.030697792768478394, 0.01587249302039189, 0.05217772462804403, 0.02909023135102221, 0.02614444959908724, 0.03814474852489574, 0.09367698404405798, 29.378112724849156, 64.26846068246024, 37.41020597730364, 28.09801309449332, 37.41929769515991, 50.509682995932444, 4.595183321407863, 0.07864332145878247, 1.4800012579986026, 2.5603929417473927, 0.4516145336840834, 1.2284300029277802, 2.691577102456774, 59.46868678501674, 85.96198041098458, 82.67291859218052, 77.76872021811349, 69.87570558275495, 61.339294706072124, 62.96322768075125, 71.34677124023438, 76.35125296456474, 81.5715387889317, 84.52728162493024, 77.93037005833217, 76.6760117667062, 74.36252566746303, 76.21179567064557, 72.5798749923706, 72.87427711486816, 72.18682929447719, 69.7361649104527, 62.61420576913016, 57.93378802708217, 53.01822934831892, 53.967137881687705, 51.47095584869385, 54.16389349528721, 52.30827283859253, 53.581985337393625, 52.523618357522146, 49.0172620500837, 46.05324043546404, 48.64670072283064, 50.36252014977591, 52.04563788005284, 58.23853254318237, 60.616209575108115, 60.075424330575125, 63.933272634233745, 65.98631245749337, 60.12730652945382, 62.42507580348423, 62.00324371882847, 62.54629407610212, 64.82822840554374, 59.087418283735005, 58.10963651112148, 57.23543153490339, 57.72478968756539, 62.73240852355957, 64.13711193629673, 53.11916582924979, 54.08320753914969, 44.672845295497346, 50.74150269372122, 60.991245542253765, 60.57791110447475, 57.30681037902832, 55.46717405319214, 59.57161739894322, 60.08183751787458, 62.917842047555105, 51.31576088496617, 51.85538578033447, 54.685689313071116, 56.423159326825825, 56.67862374441964, 56.43868160247803, 58.04226677758353, 61.23544692993164, 62.21641445159912, 58.80468218667166, 53.339083262852256, 58.59008707318987, 53.72178309304373, 50.77680649076189, 53.202301025390625, 54.609189646584646, 53.40954841886248, 53.70646578924996, 51.76569495882307, 50.588367870875764, 49.68798208236694, 56.30421658924648, 55.138920307159424, 45.30794538770403, 55.91260916846139, 59.658817291259766, 54.90999105998448, 52.59460462842669, 48.2246914591108, 47.06523513793945, 46.59879214423043, 46.725694043295725, 47.54245478766305, 47.73656661169869, 46.30364309038435, 44.37437152862549, 42.7870659828186, 45.188196659088135, 45.0289682660784, 50.751949310302734, 60.50592776707241, 58.80813544137137, 62.802522795540945, 59.03058201926095, 59.91954844338553, 52.11582510811942, 49.31750760759626, 48.91024242128645, 54.35190827505929, 54.88254567555019, 60.36241272517613, 57.89623301369803, 61.05250086103167, 60.002468245370046, 66.12789590018136, 63.04608494894845, 68.87836810520717, 63.90267971583775, 69.30641187940324, 64.5584784916469, 70.40632561274937, 61.56288773672921, 73.75778225490025, 56.983368260519846, 65.08569390433175, 10.627043928418841, 0.24669763658727917, 0.610591570181506, 3.131636049066271, 0.30983152027641025, 0.15944485925137997, 0.06866726891270705, 18.89800235203334, 70.68448284694126, 42.19975560052054, 41.10246133804321, 27.10902908870152, 33.9848621913365, 48.63695934840611, 10.286778484072004, 0.3482043040650231, 0.19362458160945348, 0.07053522153624467, 0.03729464592678206, 0.028864174016884396, 0.05817147211304732, 0.06654082158846514, 0.060785582555191855, 0.025777636960680996, 0.07036780659109354, 0.08115812151559762, 0.05454121816105076, 0.02674840174482337, 0.026997736222775917, 0.10150501863764864, 0.019217702892741988, 0.02814889802331371, 0.030982770690960542, 0.03073829791641661, 0.06665451013083969, 0.017321784448410784, 0.09227954117315156, 0.11023341491818428, 37.134998253413606, 69.93840612683977, 48.56977721623012, 28.03319161278861, 37.76567929131644, 58.831120082310264, 4.350474715232849, 0.05329232356910195, 1.913258569581168, 5.122558108397892, 1.9434319904872348, 1.1946595864636558, 4.121139866965158, 67.04291112082345, 87.84964615958077, 86.30513109479631, 81.4327346256801, 72.65731266566685, 64.28183596474784, 67.12385763440813, 71.97868905748639, 80.39493083953857, 80.85958467211042, 85.63443538120815, 78.53172274998256, 79.68355342320034, 76.61438819340297, 76.61711188725063, 78.49912180219377, 73.9832512991769, 74.22452749524797, 72.32646724155971, 65.86521230425153, 59.72021157400948, 55.69975110462734, 57.99326113292149, 53.63633067267281, 55.67683594567435, 55.75573968887329, 56.19818360464913, 53.932921477726524, 52.07261078698294, 49.480189255305696, 52.22981378010341, 53.49228061948504, 55.56133951459612, 61.434429441179546, 62.85414096287319, 63.773123604910715, 67.36321612766811, 68.93589918954032, 65.08652073996407, 64.25720460074288, 65.08531175340924, 64.93901743207658, 66.62044675009591, 61.063430377415244, 60.367040225437705, 58.555095945085796, 61.82571724482945, 64.15161977495465, 65.62082331521171, 56.667815821511404, 57.2675461087908, 48.72126531600952, 54.36087839944022, 62.95099885123116, 64.18472099304199, 60.09239183153425, 58.211684703826904, 64.12516798291887, 62.41453538622175, 65.42160456521171, 55.09882572719029, 55.82263347080776, 56.50849710191999, 58.53563404083252, 59.36608968462263, 59.68875013078962, 60.51716300419399, 62.23444502694266, 63.041547775268555, 61.10135364532471, 55.45660236903599, 59.860495703560964, 55.55864708764212, 52.114984376089915, 54.63890014375959, 57.77818659373692, 56.96324627740042, 55.898261138371055, 54.55071013314383, 54.20902899333409, 52.25617871965681, 59.77756200517927, 57.68800939832415, 51.53888143811907, 58.47349630083357, 61.582592827933176, 59.02088928222656, 53.81886679785592, 51.2235061781747, 49.684091091156006, 48.5564922605242, 48.828819956098286, 50.61273520333426, 50.50479146412441, 48.59891101292202, 47.60009356907436, 46.608366761888774, 47.65013102122715, 47.57998200825283, 52.620868819100515, 62.935087476457866, 62.15895284925188, 65.04552636827741, 61.7643438066755, 60.33427252088274, 53.06903805051531, 51.07568672725132, 50.34752593721662, 58.32265785762242, 58.55622155325753, 60.837071963718955, 60.735260009765625, 62.831892830984934, 61.05154895782471, 68.60239260537284, 65.46958187648228, 70.94647857121059, 66.69609178815568, 70.54257978711809, 65.97290243421281, 72.05898938860211, 62.65346309116909, 72.88173253195626, 61.581203188214985, 71.3446798324585, 15.727909326553345, 0.427546245179006, 0.9496770692723138, 3.2623564175197055, 3.234476987804685, 1.9881990168775832, 0.25714590879423277, 19.83946589061192, 74.15621280670166, 53.54106044769287, 40.523242133004324, 26.798913615090505, 43.14173330579485, 57.15891102382115, 13.037102171352931, 0.3775140041751521, 0.2140559631266764, 0.09168383492422955, 0.0557443150319159, 0.045525129817958386, 0.09054114802607469, 0.026339942323310033, 0.039567436291170974, 0.018929393363318274, 0.07067178349409785, 0.08714105654507875, 0.10522930057985441, 0.08952878734895162, 0.22392643562385015, 0.275198007268565, 0.09001006545232874, 0.10009201017341443, 0.12356314036462988, 0.11271219833620957, 0.12695753893681935, 0.09729238147182123, 0.14892797358334064, 0.17114026525190898, 41.12947246006557, 79.31423582349504, 50.0032183783395, 36.98724133627755, 51.44618899481637, 71.7060695375715, 7.860841001783099, 0.21077839471399784, 4.217365034988948, 7.198482257979257, 5.198102397578103, 3.5419953550611223, 6.579738225255694, 72.31509304046631, 92.49200166974748, 91.39454759870256, 83.71620450701032, 77.29552704947335, 69.28248923165458, 70.98875835963658, 77.72018010275704, 83.81104046957833, 85.99511637006486, 89.64123916625977, 83.57951259613037, 81.00792176382882, 80.75265884399414, 81.96231937408447, 79.18512439727783, 77.30349663325718, 79.08010932377407, 75.68009866986955, 68.71692671094621, 64.1012383869716, 60.5762574332101, 61.624163900102886, 57.40265730449131, 61.95528725215367, 57.88129438672747, 59.61986568995884, 57.812132017953054, 55.18207904270717, 52.51262283325195, 55.10030916758946, 57.449710505349294, 58.41968250274658, 65.44340106419155, 65.16609151022774, 65.4879459653582, 70.46604537963867, 71.20323535374233, 67.5121021270752, 68.52538572038922, 66.55899688175747, 67.51915454864502, 68.11266967228481, 64.187472479684, 62.97239235469273, 63.420398303440635, 63.70141819545201, 69.6984222957066, 69.35420158931187, 60.322356360299246, 63.309254918779644, 52.867147718157085, 56.95010723386492, 64.84926755087716, 68.17698914664132, 63.355356216430664, 62.18379960741316, 66.36148738861084, 64.486147744315, 68.30009732927594, 56.99686861038208, 56.84615870884487, 59.35272135053362, 60.916538511003765, 61.466627393450054, 61.13177980695452, 64.07294532230922, 64.61578723362514, 67.0590100969587, 64.98345811026437, 58.59313038417271, 63.293357440403526, 57.718671798706055, 55.73519386563982, 58.435781478881836, 60.61229773930141, 58.06158971786499, 58.85197857448033, 59.83142444065639, 56.153725555964876, 55.258735043661936, 61.4467624936785, 59.67191464560372, 50.3344007900783, 59.559068952287944, 67.13293198176792, 62.08838694436209, 58.362721170697895, 53.9360169001988, 51.351311343056814, 51.632577896118164, 50.91800430842808, 54.34494965417044, 53.351270403180806, 51.03403227669852, 50.21871675763811, 48.46558550425938, 50.9548019681658, 50.780103410993306, 56.21121495110648, 67.51030254364014, 64.2362835747855, 68.12580871582031, 64.70152105603898, 65.37755298614502, 57.14143630436489, 53.55532162530081, 52.69507558005196, 61.761161531720845, 61.80036326817104, 65.02361174992153, 62.84278065817696, 65.40244838169643, 63.978644371032715, 72.85544749668666, 69.45334543500627, 74.4521713256836, 68.57009043012346, 74.72729914528983, 68.98380701882499, 74.62985066005162, 63.56665093558175, 76.29265880584717, 63.20847129821777, 77.30007117135185, 14.293987001691546, 0.6097415015101433, 3.8510195272309438, 9.020979114941188, 2.606121859380177, 0.9494496243340629, 0.30902835194553646, 23.52777467455183, 81.86195264543805, 54.9572422845023, 55.50235973085676, 36.91832562855312, 45.864648955208914, 66.06227016448975, 15.88836407661438, 0.5768819504550525, 0.32187614110963686, 0.21907049976289272, 0.16303513731275285, 0.10436163749545813, 0.19689285409237656, 0.15801104690347398, 0.15509626402386598, 0.11776177452078887, 0.1431259699165821, 0.2583819553256035], [0.03204396553337574, 0.014993914003883089, 0.060630530518080504, 0.05162896282438721, 0.06599532014557294, 0.03427695303357073, 0.02404986967199615, 0.04369321758193629, 0.0018825137729956104, 0.033437225235892196, 0.0382691714912653, 0.03038899487416659, 37.573797839028494, 56.8017840385437, 32.55823373794556, 44.62665367126465, 45.627235957554404, 28.51743241718837, 1.0378523149660654, 0.21569263030375752, 1.550183383481843, 3.748785035950797, 1.3441964366606303, 0.35778882833463804, 6.118586719036102, 71.02510438646588, 85.75546605246407, 80.971193586077, 80.28231443677629, 77.61042635781425, 67.60939080374581, 59.478129386901855, 63.85469545636858, 72.93071038382394, 73.64018399374825, 76.42993436540876, 78.07729666573661, 73.83153043474469, 74.44380569458008, 71.34168515886579, 71.78438963208879, 67.97215625217983, 69.1590266908918, 66.2878086907523, 60.3166310446603, 53.662299564906526, 53.466151918683735, 51.4908207484654, 52.60321692058018, 51.625605378832134, 52.31393909454346, 50.8400559425354, 49.986633028302876, 47.3197546005249, 47.87974466596331, 49.78781379972185, 50.25418036324637, 55.73542315619332, 58.9175626209804, 61.12130192347935, 62.65132999420166, 65.81537982395717, 61.362321036202566, 60.890719005039756, 61.67870031084333, 59.206260272434776, 63.96877098083496, 63.73040607997349, 56.14194141115461, 55.70309666224888, 59.75360461643764, 61.01633548736572, 66.28011703491211, 59.02960927145821, 51.136872564043315, 51.32963991165161, 45.84722982134138, 53.183169160570415, 62.40098639896938, 56.69677938733782, 56.803357805524556, 57.762824126652305, 60.151458467756, 51.710998739515034, 56.87993042809622, 55.63453878675188, 61.032226017543245, 56.13214445114136, 56.29446826662336, 57.62561804907662, 58.41396413530622, 55.907995564596995, 49.830784933907644, 48.97347450256348, 58.948044368198936, 58.702467237200054, 54.52467523302351, 53.11360032217843, 48.37115601130894, 52.24005542482649, 52.48691102436611, 54.13499941144671, 54.26496546609061, 49.19368723460606, 49.07217713764736, 49.23784303665161, 50.03473193304879, 57.32671349389212, 46.094311237335205, 54.96374232428414, 55.92897565024239, 53.97410692487444, 52.72867012023926, 46.674989564078196, 44.76001739501953, 44.74691309247698, 43.801760060446604, 46.071767807006836, 47.968709400721956, 46.925350529806956, 44.04322385787964, 44.70781210490635, 45.46897336414882, 44.81705515725272, 50.64696897779192, 59.22421441759382, 61.39444950648716, 63.138711384364534, 61.30376161847796, 55.600127833230154, 48.79585770198277, 47.95233597074236, 47.98966864177159, 50.312889167240684, 55.17489113126482, 59.10836015428816, 60.47006116594587, 61.30820151737758, 64.46969441005162, 65.04412978036063, 66.76090458461216, 64.28530311584473, 65.18058545248849, 68.08181967054094, 67.72810077667236, 66.22282218933105, 67.7320681980678, 69.00298404693604, 67.53102902003697, 59.441957065037315, 48.94934688295637, 5.496608734130859, 0.4349411369434425, 3.6186893539769307, 2.4863846387181963, 1.2452970807041441, 0.30865917461259024, 5.988960691860743, 64.28949982779366, 54.14090190614973, 41.75953163419451, 42.03403064182827, 30.450921535491943, 53.76764815194266, 11.826164041246686, 0.2404452892286437, 0.14129535028977053, 0.019584252598828504, 0.03916735847347549, 0.06162878445216587, 0.10064509763781514, 0.03517733507656625, 0.12223740507449422, 0.08841221726366452, 0.047862526894147904, 0.06682024909449474, 0.023270655323618224, 0.03604436033804502, 0.04333163644852383, 0.01887573142136846, 0.07155049312859774, 0.024708294609029378, 0.047858808522245715, 0.03317602318046348, 0.036962163767644336, 0.04823077802679368, 0.0795487110902156, 0.14733649683850153, 48.48176438467843, 60.586068289620535, 46.86127076830183, 34.27005100250244, 45.27360391616821, 34.885313987731934, 0.7440575627343995, 0.2063201210860695, 3.9676446063177924, 3.5613721438816617, 5.010313434260232, 0.39493867488844053, 7.799838423728943, 76.13536548614502, 87.90751075744629, 85.19938087463379, 83.03019496372768, 80.10155010223389, 68.64896638052804, 62.954174177987234, 66.50695487431118, 74.71757166726249, 77.76047270638603, 79.35440335954938, 80.11201408931187, 75.40153844015938, 76.60833631243024, 74.56149428231376, 75.43109607696533, 71.384096963065, 71.85665089743478, 70.01194586072648, 63.371580260140554, 56.708785874503, 55.64211579731533, 54.4208448273795, 55.57443339484078, 54.67230013438633, 54.0927335194179, 53.39667688097273, 52.511792523520334, 50.84705625261579, 50.25348554338728, 52.180901936122346, 54.69625404902867, 57.535763944898335, 62.06681973593575, 63.34070246560233, 65.40038476671491, 67.27554375784737, 65.20170102800641, 63.27629266466413, 64.6596929005214, 64.09097589765275, 65.67925071716309, 67.39332267216274, 59.68267045702253, 57.66462871006557, 62.14309706006731, 65.39675780705043, 67.17865112849644, 62.061823981148855, 55.80335569381714, 54.681238991873606, 49.53457627977644, 55.939158235277446, 63.38685934884207, 60.30310985020229, 60.93095602308001, 60.93871021270752, 63.206518854413716, 52.76529407501221, 57.35456187384469, 59.68790939876011, 63.21479415893555, 58.54716110229492, 57.34380258832659, 60.17394283839634, 60.195266859872, 56.29585443224226, 50.88913106918335, 49.45817388807024, 61.410152435302734, 61.863591875348774, 58.2362048966544, 55.04243414742606, 49.45777784075056, 55.08281012943813, 55.18421908787319, 56.19579689843314, 55.15419592176165, 52.23716844831194, 53.2434413092477, 51.54588174819946, 50.88059173311506, 60.4903290612357, 49.68581771850586, 58.92989567347935, 59.84149932861328, 57.91242926461356, 55.96077060699463, 50.43887390409197, 48.13378470284598, 47.40048571995327, 46.491873264312744, 47.85199008669172, 49.409599031720845, 50.84525319508144, 46.01696041652134, 46.92032698222569, 46.418270996638704, 46.46684237888881, 53.979151317051475, 62.22773306710379, 62.94726072038923, 63.520334243774414, 63.67819036756243, 60.10719149453299, 52.07155466079712, 50.476283005305696, 49.78206416538784, 53.94291993549892, 58.346941811697825, 60.50544139317104, 63.28627027784075, 66.39327539716447, 67.49068777901786, 68.03364780970982, 67.43538706643241, 64.89221436636788, 66.98835386548723, 70.76577677045549, 71.03445666176933, 67.48340606689453, 69.46397617885044, 69.0793308530535, 71.58667169298444, 64.13767474038261, 57.20565502984183, 8.730898771967206, 0.5707971198218209, 1.4794671152319228, 2.4966553790228705, 3.1458946210997443, 0.6209284269383976, 5.157171862465995, 65.74231951577323, 63.082590784345356, 43.23610026495797, 34.89983919688633, 35.941148349217, 60.082490648542134, 15.61212454523359, 0.30514509603381157, 0.09054905295904193, 0.03893357941082545, 0.05340396972107036, 0.030359454852129732, 0.024592663760163953, 0.06897035693483693, 0.04281363942261253, 0.07608748360403947, 0.06050861134592976, 0.02727766754105687, 0.07985494072948184, 0.08851055055856705, 0.16356613167694636, 0.11870583386293479, 0.12564633786678314, 0.145588183509452, 0.07326688138501984, 0.15613385263298238, 0.10501490387001208, 0.24181023027215684, 0.19152277867708886, 0.3335762561431953, 53.34448201315743, 71.38738346099854, 43.44758605957031, 59.3807156426566, 62.296638352530344, 43.58610534667969, 1.8719385010855538, 0.34219248379979816, 5.725334746497018, 9.151144930294581, 8.512218117713928, 0.7617503904870578, 9.410488179751805, 81.43147700173515, 91.82917131696428, 85.91728959764752, 86.97390910557338, 86.25645201546806, 72.33857795170375, 67.02662454332624, 70.95071002415249, 78.53179223196847, 82.28606373923165, 82.52193423679897, 85.34281253814697, 78.53757313319615, 79.54800796508789, 76.43732030051095, 80.4327290398734, 76.46009649549211, 75.59560162680489, 73.42337240491594, 67.6524348940168, 59.18148994445801, 58.88132776532854, 57.642120020730154, 58.1198399407523, 55.61951330729893, 58.372059549604145, 56.06560502733503, 55.875460624694824, 53.35675253186907, 53.70058413914272, 55.188315050942556, 58.44473075866699, 61.06858594076974, 64.78435053144182, 67.1258100782122, 66.51937130519322, 70.40437316894531, 67.42513847351074, 67.03619221278599, 67.66149534497941, 67.035733631679, 66.57765974317277, 69.7048007420131, 62.00250720977783, 60.72078691210066, 66.11753613608224, 67.96377672467912, 71.5211432320731, 62.98822035108294, 59.57944107055664, 60.53785473959786, 53.20097739355904, 57.29439047404698, 67.68776648385185, 61.33058861323765, 63.78634602682931, 63.49493857792446, 66.01079790932792, 54.49599654333932, 60.92093672071184, 61.57486643110003, 65.49895886012486, 60.58103779384068, 57.62881422042847, 62.796213831220356, 63.50859178815569, 58.57116712842669, 54.69813701084682, 52.79849256787981, 63.01422051021031, 63.640816007341655, 59.08825901576451, 56.77041987010411, 51.360274519239155, 57.60715668542044, 57.94531856264387, 59.697525705610005, 60.244397572108674, 56.85039710998535, 54.507169246673584, 54.971173422677175, 54.45257377624512, 63.363047872270855, 51.196623597826274, 58.07053899765015, 61.801016398838584, 61.08351067134312, 58.11836692265102, 52.98994670595442, 51.338988712855745, 50.374623911721365, 49.80062975202288, 51.12439359937395, 53.84482874189104, 54.620445728302, 49.45648547581264, 48.52808455058506, 50.71820190974644, 49.05956615720476, 57.00506748471941, 63.84976918356759, 65.50694928850446, 67.4645278113229, 67.57576152256557, 60.47058922903878, 54.68289613723755, 54.48582785470145, 53.069607802799766, 57.65450518471854, 60.91073676518032, 63.929492814200266, 66.42011628832135, 68.46711812700543, 71.97108772822789, 71.37755870819092, 71.59475244794572, 67.91101210457938, 70.97746058872768, 73.43304429735456, 72.7783294405256, 71.11343683515275, 72.31662164415631, 71.98504665919712, 74.32708290645054, 66.45311328342983, 60.40984112875802, 6.565569111279078, 1.5662349164485931, 12.35164327280862, 7.419793673924037, 4.028736208166395, 0.6355380458491189, 8.28233001913343, 75.8779764175415, 66.57122571127755, 54.65392214911324, 58.0791061265128, 41.07294886452811, 69.69232872554234, 18.47098343712943, 0.5015142975108964, 0.24074335609163555, 0.10910552008343594, 0.16369987092912197, 0.12266393218721662, 0.17265905732555048, 0.15862539250935825, 0.243043345532247, 0.1871762733374323, 0.11949925843094077, 0.17220050335994788], [0.07337375743580715, 0.010934054934685784, 0.024085238309843198, 0.023287846008315682, 0.032680461914943795, 0.03197647165507078, 0.0864179553464055, 0.04532335385946291, 0.10753258091530629, 0.13882878050208092, 0.13813431348119462, 2.439107141324452, 54.26593821389334, 48.80633211135864, 19.578104189464025, 44.41581058502197, 51.43161514827183, 15.264917850494385, 0.03931313493688192, 0.04668080387637019, 0.8820406443306378, 5.0368468676294595, 0.6273639787520681, 0.26756356550114496, 16.106478452682495, 80.03088692256382, 85.28207833426339, 84.39921242850167, 81.65636934552873, 78.74616500309536, 74.55649852752686, 64.27265044621059, 56.98015124457223, 61.807012694222585, 70.48274884905133, 74.05243451254708, 72.26052188873291, 71.14904635293144, 69.53800923483712, 66.10448741912842, 67.53992966243199, 64.85414518628801, 64.68233013153076, 60.11928136008126, 55.45940944126674, 50.97956187384469, 53.24534164156233, 53.418473379952566, 52.035722800663535, 50.70946455001831, 49.364390577588765, 49.92105940410069, 48.39348404748099, 47.34197841371809, 48.679273877825054, 49.60802221298218, 51.94093200138637, 58.827486174447195, 61.577326093401226, 60.265304701668875, 62.128033365522114, 64.52171557290214, 64.88687814985002, 63.28578390393938, 60.432256017412456, 60.21444388798305, 62.05311094011579, 61.238545826503206, 59.080900873456685, 58.27752930777413, 61.336320877075195, 61.64996256147112, 62.608939034598215, 57.150736468178884, 50.97905118124825, 48.64214270455496, 45.383538314274375, 58.51838861192976, 61.098101888384136, 58.70126519884382, 57.43260751451765, 61.70019803728376, 53.5612519127982, 49.2358523777553, 59.1708869934082, 58.194998604910715, 54.308165890829905, 53.06458078111921, 55.59978042330061, 56.46137094497681, 55.475306919642854, 54.18220547267369, 53.285797527858186, 47.77898188999721, 46.714955602373394, 57.14284678867885, 60.13912541525704, 54.84751285825457, 49.56859813417707, 50.69964674540928, 51.81475966317313, 50.93711532865252, 53.935325554439, 47.174123832157676, 51.42965228216988, 48.06002957480294, 47.177879333496094, 57.62533664703369, 51.450465611049104, 50.093579701014924, 61.850953102111816, 55.701005254473, 57.22394616263253, 56.22398574011666, 50.616369111197336, 46.75437273297991, 46.43957069941929, 43.70907803944179, 46.8943441935948, 44.00060360772269, 45.12526682444981, 42.578689507075715, 43.75184767586844, 44.18929236275809, 51.33301673616682, 58.38514995574951, 60.27615083966936, 60.98495742252895, 60.77721323285784, 54.45897306714739, 45.69766289847237, 47.65807628631592, 48.67246811730521, 52.029153278895784, 57.65601989201137, 62.507974760872976, 61.44173199789864, 62.10117857796805, 66.18218217577252, 66.04025132315499, 64.47999858856201, 60.385529381888254, 64.52837194715227, 63.4342599596296, 66.84356730324882, 66.42679350716728, 68.80944892338344, 68.5885031563895, 74.29482936859131, 60.86111273084368, 61.625518798828125, 29.56113522393363, 1.528761001569884, 3.155744561127254, 7.36943747316088, 5.542220183781215, 0.09258114998894078, 0.7528173412595476, 42.545838424137656, 65.49768733978271, 40.53103453772408, 49.73804037911551, 33.28017936434065, 55.40701654979161, 12.100187965801783, 0.16789283736475877, 0.06611445732414722, 0.047861709259450436, 0.05086714441754988, 0.023848164959677627, 0.016049994388595223, 0.03879218967631459, 0.015587491349184086, 0.028047270440895642, 0.03461775403203709, 0.01198078680317849, 0.13939531653055123, 0.08255862457943813, 0.047631509469023774, 0.03363569672884686, 0.08367805129715375, 0.039394162196133814, 0.06069978180208376, 0.07817113572465521, 0.04749817394518426, 0.14246214553713799, 0.26267200655170847, 3.915377650942121, 63.91476958138602, 57.55512857437134, 30.828142711094447, 39.85494702202933, 58.15566137858799, 18.095613956451416, 0.019704497485820736, 0.2803274877369404, 1.7845660980258669, 7.271315881184169, 3.6056124099663327, 0.17315955832600594, 19.553554466792516, 82.35257189614433, 85.88650212969098, 86.8778155190604, 85.17622252873012, 82.12332998003278, 78.39330768585205, 66.94881166730607, 59.043769700186594, 63.896759850638254, 71.77436338152204, 76.25493703569684, 74.54003129686627, 75.14644227709088, 72.99175030844552, 69.84674549102783, 69.13562515803746, 67.32839870452881, 66.76749842507499, 62.13799013410296, 59.020041601998464, 54.80994742257254, 55.376663344247, 55.171962465558735, 53.56251301084246, 53.05639927727835, 51.247380188533235, 51.746851444244385, 52.066774300166536, 49.22469357081822, 51.95553364072527, 53.87320518493652, 53.234551089150564, 61.07005895887102, 65.22486632210868, 62.30711623600551, 66.08178765433175, 66.32744121551514, 67.77092947278703, 64.37770026070731, 62.5974189213344, 63.3002986907959, 65.66238743918282, 63.21840722220284, 64.11835180010114, 61.490939140319824, 65.22428962162563, 64.25628743852887, 64.00558948516846, 60.20053359440395, 56.94857515607561, 53.43102877480643, 50.19137907028198, 61.009693009512766, 61.76266234261649, 62.86835697719029, 60.41234942844936, 65.31900746481759, 53.68469360896519, 51.351655278887065, 63.37076037270682, 58.91103826250349, 56.865259306771414, 56.67043876647949, 58.87291349683489, 59.2878668648856, 58.071438789367676, 56.69269732066563, 58.28194488797869, 52.562847886766704, 45.26256670270647, 58.293843678065706, 63.59530530657087, 55.90128360475813, 49.16127041407994, 53.268896034785676, 54.9892178944179, 53.76266629355294, 56.049898624420166, 51.508048806871685, 54.778274059295654, 50.621795654296875, 49.84660945619856, 58.15308359691075, 55.733199732644216, 53.28605113710676, 62.98599692753383, 58.65464973449707, 59.8302640914917, 58.82004465375628, 54.650461946214946, 50.05526385988508, 48.60065848486764, 46.945406505039756, 49.038652079445974, 47.67724289212908, 47.91681677954537, 43.91491494859968, 46.232003688812256, 46.49371453693935, 52.98344666617257, 61.99752535138811, 60.798829078674316, 62.39277362823486, 62.653511728559224, 56.704356397901265, 47.61474731990269, 50.760617188044954, 49.95828090395246, 55.83630405153547, 60.06976154872349, 64.30365330832345, 64.24265507289341, 63.63571602957589, 67.14751625061035, 69.50249699183873, 65.28674003056118, 62.59338896615164, 66.22075162615094, 67.16602625165666, 66.74338817596436, 68.08584267752511, 69.73568548474992, 72.43401145935059, 74.3873724256243, 66.79436016082764, 64.51071657453264, 38.751145771571565, 2.132341350827898, 0.5540113576820919, 3.2182846452508653, 4.415224543639591, 0.17121624760329723, 0.20049553577389034, 43.7298983165196, 73.22607830592564, 46.476298877171104, 42.54322590146746, 39.325463022504536, 62.58577374049595, 16.184176683425903, 0.30141008645296097, 0.08041469140776566, 0.030477923673710654, 0.03913469719035285, 0.02594203581767423, 0.0005729840195272118, 0.06617852460060801, 0.07139969550605331, 0.041106360498815775, 0.09103900952530758, 0.01841475678208683, 0.3676998093724251, 0.14512588403054646, 0.08585182643894639, 0.12143929861485958, 0.12159308179148606, 0.1530750167689153, 0.17698945424386434, 0.13917480622019085, 0.25816514981644495, 0.27995578625372475, 0.45405267285449163, 4.02618795633316, 74.29116766793388, 62.637100083487375, 27.782306058066233, 57.06127493722098, 72.45015907287598, 24.301592077527726, 0.24967936373182706, 0.26637550496629303, 3.794405605111803, 11.064416527748108, 4.99083719934736, 0.8767508396080562, 20.57969743864877, 87.38387366703579, 91.15838527679443, 92.01063741956438, 88.05974578857422, 86.82531493050712, 81.24221502031598, 72.45687103271484, 61.684738295418875, 69.34682260240827, 76.41856016431535, 81.12854943956647, 78.1448609488351, 77.67022950308663, 77.10820361546108, 72.58321707589286, 73.45701558249337, 71.21787520817348, 70.83931650434221, 65.55636487688336, 63.287423678806846, 57.50823170798165, 59.857160568237305, 60.20087405613491, 57.7851938520159, 56.33190516063145, 53.29113721847534, 54.44198819569179, 53.37285845620291, 52.58175393513271, 55.260722228458945, 56.59577342442104, 57.02856281825474, 64.52230616978237, 69.18286596025739, 64.6819896697998, 67.627852167402, 69.19437912532261, 70.40897982461112, 65.88984366825649, 63.61655984606062, 67.6531366620745, 67.01572976793561, 68.53576632908413, 66.40587942940849, 65.36892332349504, 66.47436087472099, 65.61855125427246, 68.17220878601074, 63.34280776977539, 58.28034332820347, 58.68695190974644, 54.44361407416207, 62.306852204459055, 65.91816452571324, 65.15753827776227, 63.23205348423549, 68.95600727626255, 56.20462111064366, 52.47022492544991, 66.67687307085309, 60.97657094682966, 60.238533292497905, 60.74109649658203, 62.61733940669468, 60.58219119480678, 61.673933846609934, 60.17857033865792, 58.43284933907645, 51.191513197762625, 47.38149629320417, 61.39746502467564, 67.70887511117118, 57.468223980494905, 51.40290171759469, 55.87375136784145, 58.548689705984934, 56.12595360619681, 59.675701413835796, 54.7111370904105, 57.938050746917725, 52.38636711665562, 51.98347929545811, 62.303412846156526, 56.58536849703108, 52.51575299671718, 63.53500883919852, 60.441017695835654, 62.56659671238491, 60.83693299974714, 57.64791481835501, 52.28827939714704, 52.924095153808594, 50.08031906400408, 53.254634857177734, 50.467417103903635, 50.22398696626936, 47.285308906010215, 48.45176553726196, 49.888388974326, 56.66591548919678, 63.66236931937081, 63.26928193228585, 63.919786180768696, 67.82150541033063, 60.34192248753139, 51.10526173455374, 55.13728748049055, 51.946591309138704, 57.40487725394112, 62.92306709289551, 68.5406995500837, 68.22445923941476, 67.16503265925816, 70.80868884495327, 70.25991317204067, 69.58304745810372, 64.20517648969377, 68.57008348192487, 69.24977016448975, 69.30320181165422, 69.74535042898995, 71.5448157446725, 75.25985772269112, 79.30925396510533, 68.41399220057896, 69.17898886544364, 41.83855349676949, 2.6817792739186967, 6.277380849633898, 16.247723170689174, 11.437047549656459, 0.22390067843454226, 1.147518664598465, 52.58897311346871, 77.86447334289551, 53.441315582820344, 65.35653468540737, 43.96068620681763, 71.23220934186662, 19.32645606994629, 0.45309544993298395, 0.24860993825963565, 0.1361709859754358, 0.1222851060863052, 0.10146199951746634, 0.12830186608646596, 0.15182428673974105, 0.1469176100300891, 0.14114688682769025, 0.24066157905118807, 0.12106908990868501], [0.025037317935909544, 0.003621287959893899, 0.015020590608141251, 0.015884849143081477, 0.03462338926536696, 0.024481333126979213, 0.012993576653700854, 0.06399611170802798, 0.0282030977042658, 0.07089186632739645, 0.3219618265117918, 12.39727817262922, 64.70305660792759, 35.98740250723702, 48.973609992435996, 55.81210000174386, 43.372007029397146, 11.78300530569894, 0.13366009428032807, 0.10498877348644392, 2.7867454929011206, 2.4304520743233815, 2.473816215991974, 0.23670276147978647, 33.274877888815745, 85.53197029658726, 79.96618529728481, 82.3663432257516, 79.60443428584507, 78.22880213601249, 75.95471927097866, 73.1560891015189, 62.01258904593331, 55.66962718963623, 58.86874457768032, 64.09891768864223, 69.6908209664481, 67.8695660999843, 68.89428642817906, 65.76729134150914, 64.04785537719727, 58.13595628738403, 56.87561559677124, 54.1393072945731, 51.932642800467356, 51.230694089617046, 52.82767152786255, 51.00912993294852, 49.921090670994346, 51.31701850891113, 51.08034896850586, 47.87272351128714, 49.942296573093955, 47.33851473672049, 47.37919296537127, 48.619352613176616, 55.31144755227225, 58.874171120779856, 61.303469794137136, 63.284748622349326, 62.582765170506065, 64.20675373077393, 59.22417272840227, 62.639045579092844, 56.66904565266201, 62.09585625784737, 65.69278580801827, 56.64543914794922, 60.336530685424805, 59.70666258675711, 63.76197174617222, 60.07734203338623, 58.755746023995535, 59.56865746634347, 56.284626143319265, 48.212605067661826, 49.784975460597444, 59.02319608415876, 59.55390644073486, 55.58542891911098, 61.895164489746094, 54.845417976379395, 46.918961661202566, 50.729791504996165, 57.88651248386928, 54.98066813605172, 55.2808963230678, 55.29837104252407, 54.228209495544434, 56.81881407329014, 55.676377364567344, 56.17869390760149, 58.00061927522932, 58.06428214481899, 50.187331744602744, 48.9985088620867, 57.65413345609392, 58.95857088906424, 49.902466024671284, 50.89279276984078, 47.9609169960022, 54.651156766074045, 51.06084884916033, 49.30483409336635, 54.41285787309919, 52.57514272417341, 46.26161691120693, 51.724641527448384, 56.41406066077096, 52.1839348248073, 52.36589077540806, 61.82754462105887, 60.11685643877302, 55.99501827784947, 53.660962036677766, 51.067970752716064, 47.85988671439034, 45.26388338633946, 42.831496238708496, 44.483385290418354, 43.697391169411794, 44.767670835767476, 44.60281787599836, 43.139009611947195, 47.82057728086199, 61.79022584642683, 58.3657922744751, 62.775348390851704, 59.07516860961914, 53.71700273241316, 45.641069820949006, 49.45757286889212, 48.23244564873831, 53.02570561000279, 60.34225600106375, 64.82849938528878, 62.68077645983015, 66.3185475213187, 63.62904575892857, 63.29642159598214, 61.621162278311594, 64.77608217511857, 63.389444078717915, 66.6113029207502, 66.84743050166539, 69.02843529837472, 67.45045770917619, 69.13554872785295, 67.72535623822893, 69.93325056348527, 59.25484902518136, 56.192579882485525, 5.8044365133558, 0.6663571063961301, 1.492824484195028, 2.8201413580349515, 0.6605147027543613, 0.2408494789685522, 23.082422937665665, 73.4945775440761, 45.46260186604091, 44.87211963108608, 31.257263456072124, 52.4484075818743, 17.022336142403738, 0.15298387594521046, 0.08990787129317011, 0.09509139707578079, 0.09255284150796277, 0.0719051973095962, 0.011076005308755806, 0.04498101258650422, 0.04943514715081879, 0.04275593341195157, 0.02839789493009448, 0.09292609683637108, 0.07471096675310816, 0.03185787391183632, 0.016848489309528043, 0.04508239250364048, 0.05112017351867897, 0.05955077095755509, 0.030195262948317186, 0.08783502145005123, 0.053725059277244976, 0.15268985315092973, 0.38880710676312447, 17.62167385646275, 70.64499623434884, 45.86408615112305, 42.181169169289724, 44.532578536442344, 55.60458857672555, 11.55477695805686, 0.1837194495435272, 0.7986173150794846, 3.969353428908757, 3.0238228057112013, 0.17141283276890004, 0.5664450504950115, 39.378481251852854, 88.43203026907784, 83.25296115875244, 84.33426761627197, 81.96279185158866, 80.73168223244804, 79.67057418823242, 75.14002214159284, 63.42400441850935, 59.462343079703196, 61.40665749141148, 64.65656621115548, 72.30191230773926, 69.39281272888184, 70.70584160940987, 68.61669199807304, 65.82236971173967, 59.71584810529436, 59.039559091840474, 58.04159280232021, 55.104088987622944, 55.13764531271798, 55.099423272269114, 52.25292348861694, 53.92714057649885, 53.31876673017229, 53.42931604385376, 51.81994996752058, 52.5176602772304, 50.436855452401296, 51.20038257326399, 50.42735379082816, 58.489400727408274, 62.11000973837716, 65.33090278080532, 64.67500673021588, 67.40501649039132, 67.7040044239589, 63.439617020743235, 65.88517447880336, 59.63856329236712, 63.59763295309884, 67.99041611807687, 60.301379748753135, 64.58033752441406, 62.625232560294016, 67.41158948625836, 62.73472227369036, 65.13972309657505, 60.686198779514854, 60.758480889456614, 53.13086312157767, 53.84030893870762, 60.80320644378662, 61.460825647626606, 58.37588105882917, 63.146389143807546, 55.57164716720581, 47.95078304835728, 53.80639130728585, 62.048490388052805, 57.08943598611014, 60.280861718314036, 58.34674726213728, 57.030616010938374, 58.59305395398821, 58.1581939969744, 59.265729904174805, 56.66459880556379, 59.59868063245501, 52.87010070255825, 51.20105307442801, 57.39998919623238, 61.241151400974815, 50.99534123284476, 53.41193165097918, 52.636217389787944, 57.573843547276084, 53.618376527513774, 55.08555119378226, 56.454853534698486, 53.46410914829799, 49.77221509388515, 53.017840249197825, 57.21892956324986, 56.3042756489345, 53.911288261413574, 60.60955320085798, 61.60785647800991, 57.851107937949045, 56.49326317650931, 53.748891489846365, 49.10476071493966, 48.31023073196411, 45.09141867501395, 47.6530944279262, 45.969507694244385, 46.69739750453404, 47.34920801435198, 45.92601891926357, 51.6002652985709, 64.88049275534493, 60.591015407017295, 64.32480362483433, 62.46485424041748, 54.774914605276926, 46.86184746878487, 52.091308389391216, 49.96805354527065, 55.45050185067313, 61.5655905859811, 67.35596915653774, 64.98387500217983, 66.18551731109619, 66.25778552464077, 63.96367795126778, 62.362479482378276, 66.07740334102085, 65.35975170135498, 67.84849221365792, 69.01171793256486, 71.31713717324394, 69.18292849404472, 71.96313204084123, 68.0180630002703, 72.15983554295131, 62.702100481305806, 63.423212323869976, 8.638913307871137, 0.27523348107934, 0.7940181504402841, 4.227032150541033, 0.8992007406694549, 0.34047532879880493, 22.615696804864065, 79.52543326786586, 54.52686391557966, 39.55912399291992, 35.59538514273507, 61.10666901724679, 21.94525817462376, 0.12406098150781222, 0.046648797379540544, 0.03301833164212959, 0.08832153784377234, 0.042303828921701224, 0.09669624096048729, 0.02698581775517336, 0.038619916420429945, 0.0711312127698745, 0.012646950432099402, 0.051954462858183045, 0.17169880813785962, 0.12417679386479513, 0.05249740622405495, 0.0870172849723271, 0.14169555024376937, 0.1447954646178654, 0.11446720202054296, 0.1705636733344623, 0.16147903938378605, 0.32027846255472725, 0.5347158302153859, 18.217004196984426, 83.84334959302629, 48.20377738135201, 60.67914635794503, 68.27502822875977, 64.13930756705147, 17.959533487047466, 0.4500509447285107, 1.4120349564722605, 8.904679298400879, 9.18413758277893, 6.149475370134626, 0.7799633560436112, 42.51374816894531, 92.56671564919608, 88.94521726880754, 89.07473169054303, 86.65756457192558, 82.80878366742814, 82.46192959376744, 79.11471830095563, 66.67314883640834, 62.04398100716727, 65.72292014530727, 68.58227062225342, 76.5707118170602, 73.90330532618931, 74.06040409633091, 73.51188550676618, 69.87280123574394, 63.28757653917585, 62.89221709115164, 59.912565503801616, 58.66798332759312, 57.19615684236799, 58.106794697897776, 54.82897506441389, 56.626220430646626, 57.507592473711284, 57.54847567422049, 52.658531529562815, 56.22202287401472, 53.16175133841378, 54.67431858607701, 54.18189280373709, 60.64384950910296, 64.4000804083688, 67.67883110046387, 67.55316598074776, 71.4259946005685, 69.95603370666504, 66.50960213797433, 66.53695024762834, 60.76258727482387, 67.62935297829765, 72.5498240334647, 62.69425596509661, 68.01347718920026, 66.25957815987724, 69.24266910552979, 64.22039304460797, 66.92249189104352, 65.9929757799421, 64.97952542986188, 59.0925668988909, 55.21336678096226, 60.999701499938965, 66.68846961430141, 58.82549898965018, 68.66463456835065, 57.02220869064331, 48.93316452843802, 53.48378644670759, 65.43764795575822, 61.361994470868794, 61.211656297956196, 59.52388327462332, 57.69414465767996, 60.00014754704067, 60.703659602573936, 61.268436976841514, 61.27240439823696, 62.26586478097098, 52.67579780306135, 51.14821202414376, 60.49005808149065, 64.5686923435756, 51.328920773097444, 54.260813917432515, 57.207881927490234, 60.44237954275948, 57.86299283163888, 56.685464245932444, 59.8311882019043, 56.74451698575701, 51.964208466666086, 58.01313298089163, 59.920576776777, 59.20389788491385, 57.105048588344026, 61.99852589198521, 62.201670374189106, 60.38682174682617, 57.60265077863421, 56.155921186719624, 54.041646889277864, 51.07015596117292, 48.823890209198, 50.97647687367031, 48.36928694588797, 50.872507504054475, 49.309086390904014, 48.23797294071743, 52.23638677597046, 66.80677659170968, 64.80586910247803, 68.80574553353446, 66.38198457445417, 59.09367861066546, 49.69527769088745, 56.745552267347065, 52.91793210165841, 57.68025173459734, 64.5106679371425, 70.67719418661935, 66.36867877415249, 71.82409163883754, 68.89332062857491, 67.96767466408866, 64.83910233633858, 68.93730272565568, 67.62926265171596, 70.87072931017194, 70.60753849574498, 74.62566089630127, 72.64111641475132, 74.94116469791958, 72.13702460697719, 75.3520255770002, 67.9368177141462, 69.8709738595145, 9.028994730540685, 1.117672677550997, 5.188961608069284, 10.358229415757314, 2.5921994064535414, 0.27212006385837284, 29.51785489491054, 86.59095914023263, 57.402101448604036, 63.00618839263916, 40.277109146118164, 67.77360452924455, 25.38209080696106, 0.278767074325255, 0.18695633299648762, 0.20088771544396877, 0.22459325912807668, 0.21978357221399034, 0.17431521202836717, 0.1632874302033867, 0.14379189775458404, 0.13625006244650908, 0.10611833751733814, 0.2204692182796342], [0.022372056131384203, 0.07910146830337388, 0.05152840393462351, 0.06557363777288369, 0.03597474943048187, 0.11014975155038492, 0.006583755736106208, 0.03740359150937625, 0.08111607270049197, 0.03845294252304094, 0.12170438867594514, 27.89179229736328, 58.25091770717076, 21.871780974524363, 48.93296650477818, 45.23709808077131, 40.04628651482718, 4.161618334906442, 0.21448683286351816, 1.181986723627363, 2.782088245664324, 6.549332473959241, 1.6606956762926919, 3.4186769894191196, 62.43787438528878, 83.45533439091274, 79.07614190237862, 79.20273808070591, 77.30831173488072, 77.7585758481707, 76.85180813925606, 77.39007118770054, 66.51345143999372, 57.42487416948591, 57.404185908181326, 57.31174012592861, 57.632104192461284, 58.65859631129673, 54.98218979154314, 57.1002265385219, 54.395674977983745, 54.16493225097656, 52.627233369009836, 53.52180698939732, 52.255848680223735, 51.583193574632915, 51.51181820460728, 51.54160860606602, 51.06545203072684, 51.072532245091026, 49.265493392944336, 47.973993505750386, 47.230206217084614, 45.527633530753, 47.73898458480835, 49.40095199857439, 58.36841174534389, 59.52032579694475, 60.58425480978829, 59.505011967250276, 63.06951427459717, 59.054643630981445, 67.41495936257499, 61.662656920296804, 54.20626013619559, 62.86022063664028, 55.62194517680577, 60.05982562473842, 59.48104763031006, 65.29765565054757, 62.54256289345877, 58.39291109357561, 57.78289747238159, 56.58361060278756, 55.402538435799734, 46.47394691194807, 54.049856185913086, 58.91689559391567, 57.5683023588998, 61.51746736254011, 56.54389469964163, 47.820580754961284, 55.24997336523873, 61.20169258117676, 58.83478873116629, 60.087472506931846, 58.86096954345703, 54.35453816822597, 54.70546736036028, 53.698402404785156, 52.09877075467791, 56.953824520111084, 54.20703486033848, 54.23252432686942, 56.8063976424081, 60.02654375348772, 50.91123676300049, 57.49429014750889, 55.170159408024375, 44.42304365975516, 47.945366927555625, 50.520376273563926, 46.77334826333182, 52.15827512741089, 55.41420446123396, 55.03325210298811, 50.42982040132795, 46.020024572099956, 52.262904575892854, 60.291596685137065, 54.51005622318813, 47.58856998171125, 51.974220820835654, 61.52966145106724, 57.1547976902553, 53.03442907333374, 49.93367385864258, 46.58009801592146, 44.099028314862935, 45.1696206501552, 43.970486640930176, 42.82177570887974, 45.125332832336426, 41.314287594386506, 43.85446909495762, 55.93571192877633, 57.93341282435826, 58.9461544581822, 55.23141820090157, 49.82679319381714, 47.641213008335654, 48.232268469674246, 49.32134301321847, 59.34002004350935, 60.98374148777553, 65.37565612792969, 61.39420631953648, 62.17697647639683, 61.109962463378906, 61.67406586238316, 65.41603210994175, 66.04283605303083, 64.9184090750558, 66.88388769967216, 65.30156748635429, 69.42072364262172, 66.47678579602922, 69.60024424961635, 66.19971248081752, 73.9060776574271, 61.06882912772042, 67.49147987365723, 24.29780183519636, 0.5740248837641307, 1.1455788144043513, 2.833705327340535, 0.16677267104387283, 0.19111462629267148, 7.235576084681919, 68.61486462184361, 52.40150376728603, 42.28546510423933, 27.971594095230103, 48.66615220478603, 31.033503668648855, 0.11931526687528406, 0.1094559630645173, 0.11279957329056092, 0.030349531277481998, 0.05090658087283373, 0.017530099788148488, 0.0704244506944503, 0.02724047703668475, 0.026880003611690233, 0.057958303551588736, 0.017997683358511755, 0.04223686769338591, 0.04285206825339368, 0.022638045251369476, 0.018145234190991948, 0.02651489239984325, 0.11393772757479123, 0.04129447415471077, 0.10463045949914626, 0.0170625518408737, 0.08654854619609458, 0.10936556184398276, 36.06538561412266, 63.00886344909668, 35.793332372392925, 36.89751924787249, 39.4758220400129, 50.10504770278931, 4.141685255936213, 0.22584504767188004, 0.7390860723597663, 5.2122454558100015, 2.8317022919654846, 0.9532497461353029, 5.106854311057499, 70.9198739188058, 84.11983231135777, 84.54169913700649, 79.1309631892613, 81.8925038746425, 80.9210901260376, 81.1500471660069, 78.83444881439209, 69.81691687447685, 61.12460926600865, 59.752062116350444, 58.31181866782052, 60.374544279915945, 59.75053351266043, 58.754940032958984, 58.83771392277309, 58.237667492457796, 55.57709108080183, 56.10371937070574, 56.230645588466096, 53.81851591382708, 52.31070123400007, 53.5913028717041, 54.510240350450786, 54.693971565791536, 52.98513855252947, 52.92442866734096, 50.78019026347569, 49.341965266636436, 47.743671144757954, 50.706956250326975, 53.406373092106406, 61.34852191380092, 63.697763442993164, 63.99972520555769, 64.35962104797363, 66.08893735068185, 61.62752682822091, 71.60270118713379, 64.37714440482003, 57.13242449079241, 64.34599563053676, 61.257410185677664, 63.83911759512765, 63.034335545131135, 67.25286483764648, 61.27903297969273, 61.84574890136719, 62.56703444889614, 60.387440136500764, 58.15326772417341, 50.31551211220877, 57.94789287022182, 61.76568480900356, 58.79692799704415, 64.29901191166469, 58.49051243918282, 49.78495461600167, 59.02195930480957, 64.65414128984723, 61.34577737535749, 61.09161227090018, 58.11298901694161, 55.257533005305696, 55.48600367137364, 54.238166264125276, 53.2550448008946, 57.69793837411063, 58.27396835599627, 57.7058766910008, 56.43338360105242, 62.056661469595774, 53.064222948891775, 56.371339661734446, 59.540746552603586, 48.31678983143398, 48.92376708984375, 53.79519428525652, 49.414622579302105, 53.667083399636404, 58.575204031808035, 57.615647384098594, 51.83308901105608, 47.57694911956787, 53.886729853493826, 60.64931774139404, 57.656235286167686, 49.74631220953805, 52.72520991734096, 66.41814994812012, 58.03717027391706, 55.3456882749285, 52.979430607386995, 48.93355710165841, 46.80577550615583, 46.98148850032261, 45.27987119129726, 45.14363438742501, 46.89501469475882, 43.904516969408306, 44.86153405053275, 57.24046203068325, 60.9261965070452, 61.16894572121756, 57.68163790021624, 50.81247854232788, 50.22521332332066, 49.18014172145298, 49.97413321903774, 60.240034103393555, 63.53334127153669, 65.74599511282784, 64.41578333718437, 64.60795661381313, 62.5267140524728, 66.61995342799595, 68.28923034667969, 68.48478739602226, 66.20355483463833, 67.82165132250104, 67.1444729396275, 71.48219857897077, 67.58259854997907, 71.49801267896379, 68.13306958334786, 75.56087453024728, 63.97855404445103, 71.99603870936802, 29.403845378330775, 0.8471416884234974, 2.527058307613645, 4.610056374754224, 0.7479446998664311, 0.30640423989721705, 6.515535567487989, 70.62957123347691, 62.654025895254954, 43.66649947847639, 28.50685031073434, 55.676141125815256, 40.349655287606375, 0.03401070607027837, 0.040217768001769266, 0.044755460760955296, 0.03639650304934808, 0.020844088567953025, 0.027122963253142576, 0.12423037098986761, 0.008137943588995507, 0.01620265967877848, 0.053115035939429484, 0.03431185348225491, 0.18337900138327054, 0.14362868294119835, 0.11672057610537324, 0.127371377444693, 0.09593128093651362, 0.30505444375532015, 0.15162767443273747, 0.2039358711668423, 0.21152736166758196, 0.1548182682267257, 0.2020089809915849, 38.95864677429199, 75.48235293797084, 30.247040544237407, 60.21540968758719, 60.287789072309224, 57.45980971200125, 8.700662817273821, 0.4953010880521366, 3.292873557124819, 5.309163706643241, 16.22531349318368, 6.101173230579921, 4.737503707408905, 76.89856256757463, 89.10741601671491, 87.06578513554165, 84.39388316018241, 86.12595789773124, 84.91626957484654, 84.72017751421247, 84.63159493037632, 75.22449139186314, 63.8486088344029, 62.9797921861921, 61.62832587105887, 63.82386629922049, 63.56020300728934, 61.475194522312705, 63.539268084934776, 60.03541660308838, 60.4683449608939, 58.89247267586844, 61.21956334795271, 58.053300516945974, 55.91097981589181, 56.014327321733745, 55.991370473589214, 56.92011533464704, 56.97787570953369, 56.42518125261579, 55.37272718974522, 51.28389297212873, 49.84861053739275, 53.45800168173653, 55.68920373916626, 63.78991740090506, 67.93874931335449, 67.27257687704903, 66.35997268131801, 69.20421082632882, 66.21267781938825, 71.64585644858224, 65.06122234889439, 61.969253131321494, 67.57626179286412, 64.11035442352295, 65.70960739680699, 65.60877513885498, 72.5627337864467, 64.6836016518729, 64.74423858097622, 64.83223751613072, 62.80856772831508, 61.48715932028634, 56.90268925258091, 62.08608709062849, 62.732283455984934, 63.61123752593994, 68.73960563114711, 61.06504235948835, 49.347923346928184, 59.43386241367885, 66.53489358084542, 63.23864037649972, 62.05239527566092, 62.33791760035923, 59.76035131726946, 57.96660089492798, 58.79198782784598, 56.21749264853341, 60.8836943762643, 59.17507675715855, 59.63452638898577, 60.4404479435512, 65.0400789805821, 53.323331696646555, 60.27890232631138, 58.39189665658133, 50.26079852240426, 54.766851220812114, 56.853315353393555, 54.642992632729666, 56.79409238270351, 61.60686983380999, 60.31087793622698, 55.70507342474801, 50.46415145056588, 58.25625739778791, 64.21029731205532, 60.72249616895403, 50.512959071568076, 54.163646834237234, 67.15299837929862, 60.27846458980015, 57.76793452671596, 54.6004627091544, 51.775679520198274, 49.66931922095162, 50.62340068817139, 48.54982893807547, 49.09080525806972, 51.14966419764927, 46.18106991904122, 48.91468926838466, 61.176248277936665, 62.92920930044991, 64.20086860656738, 60.46847002846854, 54.82052258082798, 53.179712431771414, 52.399919578007285, 53.21671158926827, 64.01378835950578, 64.75805159977504, 68.10431793757847, 66.67669241768974, 66.86364064897809, 65.05439226967948, 67.32414640699113, 71.25308173043388, 72.14499419076103, 70.27928474971226, 71.51359748840332, 69.50706890651158, 75.15677424839565, 71.13461494445801, 74.5199510029384, 70.16376399993896, 78.8677932194301, 68.02490697588239, 78.15123244694301, 30.654149396078928, 1.322870678135327, 4.329168498516083, 7.142449813229697, 0.5912514222519738, 0.39166683331131935, 9.201435123171125, 80.38102749415806, 63.93544742039272, 57.11107962472098, 36.70279598236084, 62.98142501286098, 47.29658930642264, 0.1645288507321051, 0.22127651210342134, 0.1793854156775134, 0.11719713839037077, 0.24455428017037256, 0.131807734391519, 0.3029003122023174, 0.08740337139793805, 0.08022337167390756, 0.10993122934762921, 0.07778684741684369], [0.027994782364528095, 0.009943141901333417, 0.06436668682311263, 0.037785820463406186, 0.02864505470331226, 0.06320865146283593, 0.021644401962735822, 0.005615444704225021, 0.03847791939707739, 0.057249024111245356, 0.12667912244796753, 43.29251616341727, 48.192490032741, 25.051816872188024, 34.71525682721819, 47.518785749162944, 32.85583550589425, 0.31067314797214096, 0.10333405049251658, 0.5304763977016721, 2.565581943307604, 6.265229318823133, 1.126056004847799, 20.874422652380808, 80.53766768319267, 77.6654908316476, 77.20695836203438, 79.79684380122593, 78.72658497946603, 75.81676973615373, 77.87543065207345, 75.88231904166085, 75.90529673440116, 64.86801379067558, 56.234237807137625, 54.10614354269845, 55.503461020333425, 54.09635353088379, 53.11668879645211, 54.08520862034389, 53.55529383250645, 56.64527586528233, 53.86387722832816, 54.221073695591514, 51.456135341099326, 53.02289853777204, 52.47507129396711, 55.69771180834089, 50.004931109292166, 48.78646373748779, 49.07387249810355, 48.277699266161235, 45.077174867902485, 44.77709606715611, 45.585647514888215, 51.07521424974714, 59.43346636635916, 58.83458028520857, 60.8366550718035, 61.565277917044504, 65.96273721967424, 68.57208456311906, 58.90685544695173, 47.499261311122346, 60.823731422424316, 58.70582321711949, 59.85450635637556, 60.2568348475865, 63.16520486559187, 57.636186259133474, 58.20040430341448, 57.67232731410435, 55.87575592313494, 54.27440806797573, 57.68403502873012, 47.487984384809224, 51.887031350817, 58.877582686288015, 61.83058098384312, 58.65638678414481, 50.792450359889436, 60.00270448412214, 61.95958818708147, 51.056815419878276, 54.308860710689, 49.91740812574114, 48.08363260541643, 47.59617131096976, 54.030877181461875, 48.16463817868914, 51.75371279035296, 39.07710313796997, 55.637182576315745, 59.22992583683559, 56.17831870487758, 54.57561942509243, 56.89809996741158, 50.76316370282854, 55.42073229381016, 50.516843114580425, 47.94910158429827, 46.938176904405864, 45.042899404253276, 49.620539392743794, 56.29381513595581, 56.51811340876988, 52.18420927865164, 41.97996323449271, 46.499641350337434, 53.618720463344026, 59.34329959324428, 55.184993812016074, 44.174430165972026, 48.34478759765625, 60.43352058955601, 58.312228611537385, 48.70470775876726, 48.66588469914028, 45.68154655184065, 44.92265040533883, 43.24726949419294, 42.040332657950266, 42.24716663360596, 44.38151775087629, 43.760796955653596, 48.20792545591082, 57.31280320031302, 54.75977100644793, 51.79743432998657, 46.79962287630354, 46.38119193485805, 46.787717138017925, 51.95056915283203, 58.398205620901926, 63.47633130209786, 59.61871228899275, 58.235968657902305, 65.17135824475969, 65.2861077444894, 64.02689961024693, 63.52169609069824, 62.80704607282366, 63.49825981685093, 65.41875580378941, 64.55653299604143, 66.2211685180664, 66.99427373068673, 67.97567204066685, 67.07621383666992, 69.85786955697196, 69.12958022526333, 63.3975248336792, 47.39450332096645, 2.190598956176213, 2.1799866684845517, 1.4977396833045142, 0.23010522978646414, 0.053245039856327434, 0.48136897278683527, 51.285539695194785, 62.613962582179475, 46.309232916150776, 44.435053621019634, 36.16486644744873, 47.411321435655864, 0.7571434091244424, 0.06589173498962607, 0.04328944853373936, 0.03148789590756808, 0.0922669204218047, 0.035665273001151424, 0.054222360985087495, 0.034596563383404694, 0.012424791281643723, 0.05310236769063132, 0.018832288216799498, 0.01970285373473806, 0.01900923148994999, 0.09965235340808119, 0.13081141428223678, 0.013529028144798108, 0.0036995620633076343, 0.03671225253492594, 0.030615846094276224, 0.04326047169576798, 0.03189885064161249, 0.36295144845332417, 52.81388977595738, 55.72903776168823, 34.362795557294575, 28.362367732184275, 53.547821044921875, 36.25037792750767, 0.5193699193852288, 0.17878169593002113, 1.6624028703996112, 3.911070202078138, 8.89516634600503, 1.6043660874877657, 24.952389887401036, 85.33490548815045, 81.03216402871269, 80.90272603716168, 80.2137565612793, 83.3907230922154, 79.55723517281669, 81.05744852338518, 79.3290215900966, 78.44739941188267, 67.53480884007045, 59.30087389264788, 56.43717731748308, 57.721861021859304, 56.22182832445417, 56.37522023064749, 55.831186703273225, 56.4409293447222, 57.49947350365775, 56.40822417395455, 58.046182087489534, 53.72776549203055, 55.49683938707624, 53.930548667907715, 56.76593828201294, 53.85476813997541, 53.32430444444929, 50.70753642490932, 50.46998446328299, 48.291376795087544, 46.98001895632063, 49.162931033543174, 53.181376525333945, 61.43996715545654, 61.15386813027518, 62.73116479601179, 63.818689891270225, 68.51645033700126, 71.0765905380249, 62.48533058166504, 50.560363156454905, 64.99445016043526, 61.991188594273154, 63.504839760916575, 63.31341688973563, 65.536055292402, 61.26178755078997, 60.91309220450265, 61.0426413672311, 59.34491157531738, 57.7043411391122, 61.08596338544573, 49.60555212838309, 55.04838875361851, 61.57251099177769, 65.80510343824113, 56.65012918199812, 52.02636705126081, 62.90130533490862, 62.33924470629011, 52.00973653793335, 56.983819893428254, 50.68129307883126, 50.549652508326936, 51.9722649029323, 56.779817308698384, 52.31908423560006, 55.03103910173689, 43.799522740500315, 56.5510687146868, 61.17733914511544, 57.496833188193186, 56.65462466648647, 58.137398038591655, 52.19943625586373, 57.495363644191194, 54.78608730861119, 49.91055720193045, 51.86630140032087, 51.528740542275564, 53.290744645254954, 57.352185589926584, 58.26650946480887, 54.43829870223999, 45.08253192901611, 47.84220354897635, 56.468947955540244, 60.80902903420584, 58.50625705718994, 46.218934127262656, 50.02926370075771, 64.05064160483224, 61.10402175358364, 53.167768478393555, 52.10802228110177, 48.77703850609915, 46.8603640283857, 46.22242907115391, 44.92795188086373, 44.450773920331685, 46.17540366309029, 47.13615887505667, 48.98246199744088, 56.816920689174104, 57.01586498532976, 55.60801403863089, 48.35242019380842, 48.184409277779714, 48.8866081237793, 53.139128003801616, 60.743722915649414, 64.57525839124406, 61.634419441223145, 61.7175407409668, 66.06864166259766, 67.55664008004325, 66.56959983280727, 65.62011459895542, 63.257831301007954, 66.75265707288469, 64.76167855943952, 66.20200538635254, 67.03437873295375, 70.20575891222272, 69.74335629599435, 70.24183395930699, 71.3397605078561, 71.03069073813302, 67.87512465885708, 55.765904903411865, 3.461267275469644, 1.6848379522562027, 3.7958521332059587, 0.4283092985195773, 0.027608599247676984, 0.17089544981718063, 52.85695818492344, 71.33377810886928, 50.226634229932515, 38.49037640435355, 40.64974798474993, 59.291000502450125, 1.7440111999000822, 0.07756376545876265, 0.04732841466154371, 0.02345413967434849, 0.002712688221695966, 0.037880686444363425, 0.03911578641938312, 0.04271731119869011, 0.013283287357938076, 0.02776014495507947, 0.019550364863659655, 0.14106240921786853, 0.11961228879434721, 0.2188518757798842, 0.1713202263095549, 0.16166081891528197, 0.1696232102279152, 0.14018713975591318, 0.1001520198104637, 0.110030736508114, 0.11370408761182002, 0.4701405210154397, 58.68452698843819, 61.24434757232666, 32.47535562515259, 46.24651847566877, 65.10170255388532, 47.66712284088135, 2.192862114736012, 0.22571501322090626, 2.6802322140761783, 7.462229796818324, 17.30521294048854, 2.057228935616357, 25.720410755702428, 94.56500366755894, 84.3915763582502, 84.51072406768799, 84.82189914158413, 87.28165871756417, 80.79395198822021, 86.82519681113106, 83.81010941096714, 83.47217682429722, 71.03337274278913, 62.0068359375, 59.36622864859444, 61.7197711127145, 60.11774580819266, 60.41564287458147, 60.86275250571114, 60.395826612200054, 63.33144746507917, 59.77469934735979, 60.47706495012556, 56.45121267863682, 58.42872210911342, 58.21871280670166, 59.71429170880999, 54.760104519980295, 54.82517439978463, 53.608791487557546, 54.87417309624808, 50.831124033246724, 48.72752216884068, 52.4570963042123, 57.30685554231916, 63.103178296770366, 64.77838202885219, 65.02914251599992, 67.26250198909214, 71.38898154667446, 67.27507128034318, 64.94607680184501, 58.85475090571812, 65.94814600263322, 64.11343247549874, 66.41969244820731, 65.96516908918107, 71.03251811436245, 62.866029330662315, 63.35548823220389, 63.595409529549734, 61.785077231270925, 62.00316034044538, 64.23013441903251, 55.77803993225098, 58.30696882520403, 64.95559583391461, 67.96177564348493, 61.40900598253523, 52.98725427900042, 65.32335703713554, 68.39900493621826, 56.74795286996024, 60.41844994681222, 55.47088091714041, 52.56978218896048, 53.52990164075579, 59.542844908578054, 54.12461880275181, 55.521839005606516, 45.96313967023577, 61.343317713056294, 62.07603999546596, 59.897335052490234, 59.22952284131731, 61.385173661368235, 53.52679579598563, 62.48546954563686, 55.58074583326067, 53.071581091199604, 55.11024856567383, 54.160596575055806, 54.74315438951765, 59.93441758837019, 61.68467576163155, 55.71010044642857, 46.523720332554404, 50.170510155814036, 58.27749456678118, 63.674174308776855, 61.587032726832796, 49.39100912639073, 53.293249470846995, 61.24698788779122, 63.257490839277, 55.352796282087056, 53.85496268953596, 51.261394705091206, 49.7612612588065, 48.756402356284006, 48.29973547799246, 47.068598066057476, 48.645300660814556, 48.688973563058035, 52.515436853681294, 61.66015556880406, 59.82919406890869, 57.14961086000715, 53.056308950696675, 51.363807678222656, 51.75205911908831, 56.56312383924212, 62.65699277605329, 67.64785603114537, 65.39583369663784, 63.613016264779226, 68.76115894317627, 70.67196219308036, 70.39566707611084, 69.74936648777553, 68.04398672921317, 68.52661555153983, 68.86869621276855, 71.21414402553013, 70.3032351902553, 73.50112969534737, 73.77085181644985, 73.96559592655727, 74.39225006103516, 75.33277906690324, 72.73508385249546, 57.8097939491272, 3.4471120578902106, 5.512644307953971, 6.020116414342608, 0.5837577357888222, 0.20028068444558553, 1.0534164969410216, 62.4762145451137, 75.73097337995256, 60.443908146449495, 57.64024748120989, 45.44583238874163, 69.85424954550606, 1.4711039811372757, 0.17338304061974796, 0.10981549841484853, 0.18367492407560349, 0.09949582894997937, 0.20018069552523748, 0.10516346911234514, 0.1392026940094573, 0.08969755936414003, 0.17969926526503904, 0.0962246319811259], [0.04831924542252507, 0.004919928074481764, 0.04727205215021968, 0.0645592754174556, 0.0535751403575497, 0.023191343061625957, 0.043037956314427514, 0.046618975765470944, 0.06718216610274144, 0.008552734590401607, 1.133298090526036, 55.71853903361729, 35.52034112385341, 31.39405264173235, 36.19219371250698, 46.01355927331107, 21.04706106867109, 0.12744404854519026, 0.28348202418003765, 0.1386711568172489, 5.684324307101114, 10.138045345033918, 12.880622659410749, 47.56243085861206, 87.03460162026542, 75.36254514966691, 79.4410821369716, 72.72233390808105, 78.69121864863804, 76.20357595171247, 77.10499354771206, 74.75593267168317, 74.08832890646798, 72.19179725646973, 60.62223366328648, 55.88799517495291, 54.905606746673584, 53.953005245753694, 54.75907618658883, 52.45230552128383, 52.285673822675435, 52.28279032026018, 53.643727030072895, 51.93209041867937, 52.47475167683193, 50.25774826322283, 53.12482513700213, 49.979969705854145, 50.093117645808626, 50.996557167598176, 47.60702787126814, 45.658280508858816, 44.86121790749686, 46.69605302810669, 45.93878623417446, 53.51426471982683, 61.92772374834333, 58.78996590205601, 62.73090076446533, 62.47147587367466, 60.160824639456614, 43.797222886766704, 57.86680391856602, 58.19525568825858, 58.04733896255493, 61.300502913338796, 58.40181868416922, 59.348343985421316, 57.240107672555105, 60.73388426644461, 59.208928380693706, 54.80279425212315, 55.15848296029227, 56.79622547967093, 54.69394029889788, 50.29948609215872, 53.66013867514474, 60.87536348615374, 55.391879899161204, 49.93059580666678, 60.117606844220845, 58.826756613595144, 50.09143270765032, 55.102657658713206, 54.519585677555625, 44.72328921726772, 57.588320119040354, 59.475683620997835, 54.909799984523225, 54.44636903490339, 56.01076289585659, 53.69311482565743, 48.79972437449864, 59.472633361816406, 57.206766741616384, 54.51897423607962, 57.996422563280376, 55.74108941214425, 51.1305809702192, 53.37191697529384, 49.43163176945278, 46.88876479012625, 51.78521244866507, 48.387487752096995, 52.167412008558, 57.78175796781267, 53.04099859510149, 43.43365144729614, 43.653436865125386, 51.281322138650076, 55.531413623264854, 57.20354972566877, 54.479275703430176, 49.72854913984026, 48.05764634268624, 59.61031191689627, 55.56451484135219, 50.881039891924175, 49.401341097695486, 42.8198892729623, 42.6111410685948, 40.61037254333496, 43.83994041170393, 43.500906535557334, 44.82603570393154, 41.434043271201, 46.73105110440935, 47.8005108833313, 50.09678282056536, 45.519934926714214, 45.70321103504726, 46.075624057224815, 51.823472704206196, 60.92586299351284, 64.00904273986816, 57.80127545765468, 64.91155120304653, 62.208674158368794, 63.35174315316336, 60.449536187308176, 63.21647562299456, 59.81360231127058, 61.11802932194301, 60.7921518598284, 63.78285108293806, 63.35331344604492, 67.66209983825684, 66.26677649361747, 69.40049048832485, 68.1723963873727, 71.85165514264787, 62.588393211364746, 65.03497205461774, 11.535285523959569, 1.6022916159459522, 3.7589741349220276, 0.46930212314639774, 0.11798020851399217, 0.19172681415719645, 27.919696262904576, 74.0908511025565, 40.17610665730068, 47.634549685886924, 28.137828009469168, 53.297887393406455, 5.307785357747759, 0.19946893943207605, 0.10112082532473973, 0.027372112830302546, 0.051865822436021905, 0.06332257749246699, 0.04356434681851949, 0.044902804640254805, 0.036158785090914795, 0.0052333154100259495, 0.033284307191414494, 0.03576460374253137, 0.07914720834898097, 0.03939653706869908, 0.059628463217190335, 0.043816212232091596, 0.032108813125107966, 0.0344061393157712, 0.05930761114827224, 0.015207503257053239, 0.0127089897370232, 2.385122460978372, 64.10833249773297, 41.25274045126778, 33.26899971280779, 32.39360659463065, 58.021727902548655, 21.079960788999283, 0.46491721272468567, 0.20245230863136904, 1.556863967861448, 3.715405021395002, 17.530245985303605, 16.824335064206803, 54.36201442990984, 89.70214012690953, 78.24741636003766, 81.0784112385341, 75.89977291652134, 81.859541620527, 78.72309698377336, 78.84460708073208, 79.23880617959159, 76.88542352403913, 76.89332362583706, 64.21187455313546, 58.04925666536604, 58.34542710440499, 56.17033175059727, 57.25297573634556, 55.51859767096383, 54.58641692570278, 53.6078256879534, 56.00993606022426, 53.41001394816807, 55.85663448061262, 52.823561668395996, 54.888694831303184, 52.05750887734549, 50.76213536943708, 52.37855039324079, 50.21461384637015, 48.313499859401155, 49.276690414973665, 51.27668074199131, 48.488055978502544, 56.37338938031878, 63.88931138174874, 63.23552758353097, 65.71363040379116, 65.17593710763114, 63.980256353105815, 48.24240241731916, 59.20475946153913, 63.71519647325788, 60.05735901423863, 64.04354054587228, 62.39036955152239, 62.613371985299246, 60.93307522365025, 64.58257484436035, 61.38898822239467, 57.767069475991384, 58.10255977085659, 60.3181665965489, 57.05774525233677, 53.37722192491804, 56.431580543518066, 62.54122189113072, 56.09103543417794, 53.40616117204939, 64.66814191000802, 62.236585072108674, 54.10084901537214, 59.3555075781686, 57.17146989277431, 50.37732328687395, 62.675843238830566, 60.93866852351597, 54.97035353524344, 56.66533184051514, 57.88338579450335, 57.835321630750386, 51.86846923828125, 59.840088844299316, 58.28218460083008, 56.6311571257455, 58.70123740604946, 58.238654136657715, 53.75952570778983, 54.52171182632446, 52.505174364362446, 51.81823376246861, 52.31564835139683, 47.751491342272075, 55.501939364842, 57.769119194575715, 55.87940720149449, 46.84888907841274, 46.222588879721506, 51.6256331716265, 57.7849680355617, 57.89997809273856, 55.99886063167027, 52.40419619424002, 51.3058249609811, 63.08118724822998, 58.26598140171596, 53.382749216897146, 52.83868094852993, 46.5656909261431, 45.18478856767927, 42.880005087171284, 46.92724738802229, 45.80719082696097, 47.39241886138916, 45.566345419202534, 47.88184649603707, 48.605744566236226, 51.45441566194807, 48.924263886043, 48.503175258636475, 48.48569359098162, 53.7726925441197, 63.04298605237688, 64.06988116673061, 61.058441570826936, 66.40993022918701, 63.80599553244454, 64.07233388083321, 61.60327066693987, 65.76956340244838, 61.787245069231304, 63.12853227342878, 62.85373796735491, 65.21486786433628, 66.67690781184605, 69.36197662353516, 68.10904271262032, 72.30643558502197, 69.43377235957554, 73.65981265476772, 65.36093984331403, 70.27127347673688, 14.709524018423897, 1.357504516839981, 1.7186507093054908, 1.0566248276403971, 0.05374686400006924, 0.36568418038742884, 27.50613079752241, 80.18240628923688, 46.3598644392831, 42.88061305454799, 39.14674840654646, 65.47451509748186, 7.7682579926082065, 0.2241646692688976, 0.06650177189814192, 0.01839195122011006, 0.023946533877668635, 0.04626825797770705, 0.038337041956505606, 0.029029644959207093, 0.03408835083246231, 0.050253450205283504, 0.0364685329342527, 0.16333441196807794, 0.1143387146294117, 0.13444536285740988, 0.13362968234079226, 0.1424481270036527, 0.11179957552147762, 0.07916151186717407, 0.1317299199955804, 0.11540854722261429, 0.13735554526959146, 2.7840689165251593, 76.44563729422433, 44.33687904902867, 42.603525842939106, 51.54604850496565, 64.71871089935303, 26.17880426134382, 0.6551902113216264, 0.5510560391204697, 2.13239563362939, 12.571184635162354, 23.10242853845869, 19.08899964605059, 57.488846233912874, 97.19404220581055, 81.91536344800676, 89.17400755201066, 78.31250013623918, 87.1907901763916, 82.56535352979387, 83.44751071929932, 83.21462794712612, 81.57956395830426, 78.40965679713658, 68.11168302808488, 61.36146640777588, 61.3087990624564, 60.47809328351702, 61.183578627450125, 58.941339356558665, 58.86017050061907, 56.97909164428711, 59.30313205718994, 59.26641082763672, 58.329814502171104, 56.630816664014546, 58.92994431086949, 54.000520501817974, 55.35786499295916, 55.42820855549404, 54.3283052444458, 52.09034258978707, 52.00970179694039, 55.43384007045201, 50.48786217825753, 60.23603194100516, 65.32090432303292, 65.27232251848493, 68.53913620540074, 68.29848534720284, 61.21118382045201, 49.73850243432181, 61.8811708177839, 64.13629899706159, 66.84540162767682, 64.49083083016532, 66.60728686196464, 64.15501049586705, 62.144618715558735, 64.74976934705461, 63.56809616088867, 59.916970661708284, 62.378661836896626, 62.973656926836284, 62.460782596043174, 57.51783759253365, 59.80056749071394, 65.01683030809674, 59.26974596296038, 52.311809471675325, 68.99497277396065, 66.63701820373535, 56.34062167576381, 59.52170154026577, 60.13371276855469, 50.57907118116106, 64.02797658102853, 61.49582372392927, 58.593734877450125, 58.74346160888672, 61.202977997916086, 58.37574209485735, 55.605231285095215, 64.70198658534459, 61.22988142286028, 57.017153876168386, 61.612768854413716, 60.7342803137643, 54.59598459516253, 56.45854997634888, 56.3631477355957, 54.51244987760271, 53.38837725775582, 48.78970159803118, 56.01598446709769, 62.106209073747905, 56.733563150678364, 48.55900056021554, 48.0973414012364, 54.77050944737026, 62.23985767364502, 61.25870949881417, 55.76881272452218, 53.736568859645296, 55.21513162340437, 61.3048038482666, 58.48389080592564, 55.028746196201865, 55.29015827178955, 47.52786009652274, 47.99764517375401, 45.833812849862234, 49.113008226667134, 49.55382626397269, 50.3245656149728, 47.71606247765677, 51.968467712402344, 51.69943693705967, 56.187313147953574, 52.71841805321829, 51.96870742525373, 52.239256381988525, 56.63762937273298, 66.55284077780587, 69.15897110530308, 63.0146096093314, 69.88211182185582, 65.58314323425293, 68.31236784798759, 65.63421944209507, 70.24928937639508, 65.18386500222343, 66.62123884473527, 66.63779640197754, 68.23472867693219, 69.4730783190046, 71.35670021602085, 71.09157085418701, 74.61289705548967, 73.08485616956438, 76.67803369249616, 68.66247367858887, 75.72330256870815, 14.765754052570887, 2.1839134863444736, 11.609352452414376, 2.339625222342355, 0.3494037368467876, 0.38978045167667524, 35.282750947134836, 87.26420484270368, 50.548426151275635, 62.842363766261506, 38.821788106645855, 76.26406002044678, 8.746738927704946, 0.38559432487402645, 0.1987404099532536, 0.1566518462662186, 0.16484568587371282, 0.12916929168360575, 0.1422001767371382, 0.12229041223015104, 0.14881549961864948, 0.10884029431534664, 0.0855427198112011], [0.0256680654295321, 0.04021620737122638, 0.04977563263050147, 0.04757932334073952, 0.031906195783189366, 0.054688236343541315, 0.02530586513291512, 0.05529710277915001, 0.09539468187306609, 0.10999383098844971, 4.212083535534995, 52.29778800691877, 34.026877948216026, 38.8873929977417, 28.88340445927211, 59.167739459446494, 11.74542944771903, 0.5747385940381459, 0.3717386669346264, 1.2485352669443404, 3.429724842309952, 1.1994183425392424, 25.461843967437744, 75.63607488359723, 78.77399253845215, 75.09980596814836, 75.75827980041504, 74.92330782754081, 73.36473655700684, 74.82034942081997, 77.60288756234306, 73.17120838165283, 74.78376020703996, 74.84493909563336, 66.1122624533517, 53.99956512451172, 54.03929144995553, 54.589182308741975, 53.2143109866551, 51.919906752450125, 56.85626138959612, 53.37833016259329, 54.653942993709016, 52.35074370247977, 51.27822324207851, 49.55856146131243, 51.862177644457134, 50.960353578839985, 49.60811253956386, 48.822444983891074, 45.90219007219587, 46.58230406897408, 45.53064904894148, 48.589141845703125, 46.74641357149397, 58.022909096309114, 60.71135820661272, 63.52068860190255, 59.76588903154646, 60.40614468710763, 45.9506641796657, 53.72648354939052, 61.911096709115164, 63.26491846357073, 54.77838870457241, 53.57059723990304, 62.65623542240688, 61.55178451538086, 61.83289473397391, 60.89817442212786, 57.44854668208531, 52.40742710658482, 53.9289436340332, 57.678702286311555, 53.31344093595232, 49.71209233147757, 55.26554775238037, 57.33573920386178, 51.315357889447895, 61.52038560594831, 56.12263931546892, 52.021958419254844, 56.424719197409495, 62.73354802812849, 49.49130637305123, 57.36295182364327, 61.63281440734863, 54.23622076851981, 50.76535585948399, 55.24357754843575, 55.246137959616526, 57.44603490829468, 54.65653119768415, 49.06133099964687, 56.82461929321289, 52.42010062081473, 57.336107458387104, 53.80233703340803, 55.9453421320234, 47.227128165108816, 44.11021491459438, 43.035516193934846, 43.80136053902762, 49.09522083827427, 56.966543197631836, 56.684248311179026, 52.16797481264387, 43.670036111559185, 44.379839760916575, 50.504676818847656, 53.67107513972691, 55.21642746244158, 56.102222033909385, 54.42341218675886, 52.16368430001395, 46.187695026397705, 59.665744645254954, 54.89302355902535, 52.41165508542742, 45.39426633289882, 40.29474714824131, 41.63564872741699, 41.16975811549595, 42.85000971385411, 42.910139424460276, 44.40538133893694, 44.411155291966026, 44.353273323604036, 45.04548413412911, 45.413029943193706, 46.99719837733677, 46.03988599777222, 50.51327868870327, 56.91106183188302, 57.408267974853516, 62.477729252406526, 61.148608343941824, 59.6832332611084, 57.30661582946777, 56.27634389059884, 59.6085262298584, 58.70639991760254, 59.13577774592808, 59.466449465070454, 64.74657317570278, 65.44763251713344, 67.68461894989014, 64.8121085848127, 71.25135857718331, 65.38066577911377, 73.18057455335344, 64.05075972420829, 66.30570725032261, 34.478688035692485, 0.29823790809937883, 1.1705737646136964, 1.270292682307107, 0.20213893401835645, 0.4793685972690582, 10.581793785095215, 75.28107057298932, 48.67877360752651, 35.71599197387695, 11.561419435909816, 51.512853486197336, 13.19772367818015, 0.24554092437028885, 0.08635650042976652, 0.04270801866160972, 0.05878183471837214, 0.016758084696318423, 0.08774322923272848, 0.05007094464131764, 0.02733707328193954, 0.05924091794128929, 0.048927721700498035, 0.01937380835546979, 0.04591557243838906, 0.03974108697314348, 0.014078020650361265, 0.03979457249598844, 0.07115794704960925, 0.04090155827413712, 0.06431096552738122, 0.10679721858884607, 0.19565338774451188, 7.617184179169791, 60.132955414908274, 42.92292758396694, 38.364697388240266, 26.483018977301462, 73.18785626547677, 12.128252608435494, 0.4928438141942024, 0.18651406387133257, 2.065563734088625, 1.7217597024781364, 1.1779945492744446, 25.5912697996412, 82.66206550598145, 80.34388937268938, 79.96420506068638, 77.06164373670305, 77.67247377123151, 76.96794033050537, 76.74998923710415, 79.0654764175415, 77.09093734196254, 75.64472539084298, 78.20127337319511, 68.00179726736886, 56.63544069017683, 55.48609052385603, 56.98290620531355, 53.78334065846035, 54.201198373522075, 58.33902781350272, 55.992252894810264, 57.41792597089495, 55.62228216443743, 53.89267751148769, 51.58367300033569, 53.014032636369976, 53.20404502323696, 52.2707873071943, 52.008524077279226, 47.39061580385481, 48.45189755303519, 47.9260960987636, 50.34833887645176, 47.507366384778706, 60.40861824580601, 62.50975349971226, 66.4054069519043, 62.33882086617606, 64.54678467341832, 48.50399514607021, 57.39195013046265, 63.764528683253694, 63.73820890699114, 61.46425805773054, 57.36880915505545, 64.1204640524728, 62.931356293814524, 64.74054213932583, 62.196806635175435, 58.051851817539756, 56.837167739868164, 57.17056662695748, 59.57311820983887, 56.26279837744576, 52.86081790924072, 59.76782063075474, 59.397426060267854, 52.205682686397004, 64.46572698865617, 58.86050401415144, 54.33303001948765, 60.438488551548545, 64.21236787523542, 50.95653554371425, 60.830992289951865, 61.95373085566929, 52.874849796295166, 53.98776708330427, 56.191336154937744, 56.829639366694856, 59.835190364292686, 59.445722988673616, 51.348552908216206, 57.99361549104963, 55.07020957129342, 58.63265173775809, 56.26110996518816, 57.02442169189453, 47.97901010513306, 46.96479892730713, 46.87163053240095, 44.366822310856406, 51.269402503967285, 58.51165580749512, 58.252494948250906, 55.210795947483604, 45.93247726985386, 45.73540898731777, 51.08965260641915, 56.261516434805735, 57.43113102231707, 57.45651626586914, 56.694580282483784, 54.688239301954, 49.38913311277117, 63.1732508795602, 57.56843090057373, 55.06921945299421, 47.96000330788748, 42.88633489608765, 44.96283878598894, 45.841282163347515, 46.636312416621614, 44.95899990626744, 46.55012696129935, 45.908992358616416, 46.53311082295009, 46.99000351769583, 47.48667812347412, 49.04423148291451, 48.22504581723894, 52.99668298448835, 59.73822825295584, 60.79417378561837, 63.59894616263253, 63.37713187081473, 63.43438502720424, 58.954811913626536, 59.192190170288086, 60.46179975782122, 62.82280458722796, 61.943100111825125, 61.652873856680735, 66.17603302001953, 67.0578636441912, 68.66002096448625, 68.12215396336147, 71.42125592912946, 67.4892772947039, 73.30557959420341, 68.36256858280727, 68.94486931392125, 40.82119131088257, 0.3128154458744185, 0.383669836712735, 0.1780816920633827, 0.0578000827559403, 0.4049434837486063, 9.576071568897792, 79.61871978214809, 56.30179514203753, 38.709154333387104, 18.63088754245213, 62.313661439078196, 20.002211809158325, 0.2983917455588068, 0.10583572089672089, 0.028959915308015685, 0.007227702432179025, 0.03016526491514274, 0.026280346592622142, 0.04830061624358807, 0.014663689670019915, 0.008680747855188591, 0.07712572360677378, 0.19332556479743548, 0.09787317352103335, 0.11332870168345315, 0.23719374941928045, 0.06894059638891901, 0.16088141288076127, 0.11194250213780574, 0.2519518860748836, 0.2056699488312006, 0.28452352115086144, 8.299705726759774, 72.1403250013079, 45.47734941755022, 48.367421354566304, 40.06872224807739, 81.56789098467145, 14.847827911376953, 0.9483839443751744, 0.5417561467204774, 3.1773675722735266, 9.53716252531324, 2.7509574932711462, 30.25041389465332, 85.72872938428605, 84.20078577314104, 82.42020566122872, 82.92678492409843, 81.14442607334682, 80.0148435320173, 80.74149308885846, 83.478652545384, 80.26585415431431, 82.46984359196254, 81.5031407220023, 73.05950914110456, 60.96259117126465, 59.099876403808594, 61.29394381386893, 59.23272596086775, 58.48220934186663, 63.50980772290911, 60.74509171077183, 60.738588196890696, 60.27954156058175, 58.191962242126465, 54.377693040030344, 57.69013902119228, 55.81995841435024, 54.17375993728638, 52.675071716308594, 52.110593114580425, 50.92951052529471, 51.423763683864046, 53.14579132625035, 50.8245336668832, 62.95211751120431, 66.37515449523926, 68.80559267316545, 64.66247912815639, 65.31621428898403, 50.44413021632603, 59.11017363412039, 64.93461227416992, 62.714343207223074, 60.28099373408726, 59.91940253121512, 64.5886892591204, 64.64905520847866, 65.71698638371059, 66.70502022334507, 62.44849818093436, 57.55758128847395, 60.60616247994559, 63.29665783473423, 59.24318994794573, 57.71285268238613, 60.75164386204311, 62.357678277151926, 52.100816999162944, 66.91737106868199, 61.94639355795724, 56.79917846407209, 62.62452384403774, 68.51565824236188, 54.39664772578648, 61.99870654514858, 67.13328633989606, 55.83906248637608, 54.1715087209429, 58.017781325748985, 60.55272388458252, 62.87867505209786, 60.13649204799107, 55.30716398784092, 60.56400775909424, 55.23857137135097, 60.10992213657924, 56.933511461530415, 59.33252988542829, 49.0413236618042, 50.15494966506958, 50.360817841121126, 44.88712774004255, 52.979388918195454, 60.81257956368582, 62.888548442295615, 58.985251971653526, 48.47119270052229, 48.663772446768625, 54.66214534214565, 58.31952422005789, 59.703063419886995, 60.49772194453648, 57.659271648951936, 56.11522558757237, 53.724538053785054, 61.86317498343331, 58.86028861999512, 60.374023165021626, 50.80973400388445, 45.256070137023926, 46.20951236997332, 47.74212864467076, 48.15990645544869, 49.32060997826712, 48.60347597939627, 48.79957846232823, 49.96320717675345, 50.14415563855852, 51.672092301504954, 52.81759316580636, 51.02308191571917, 55.902284145355225, 61.29314477103097, 62.60200473240444, 67.75929818834577, 68.11888136182512, 66.34479086739677, 63.447524070739746, 62.75576836722237, 65.64259896959577, 66.27835219247001, 64.6450947352818, 65.35706274850028, 68.97715759277344, 70.38123566763741, 73.50711904253278, 69.43798991612026, 75.09772150857108, 70.58378955296108, 78.55702808925084, 71.62435177394322, 75.75752939496721, 42.59797770636422, 0.5983518841011184, 6.619929211480277, 2.6405949124268124, 0.32261305728128975, 0.8230681344866753, 15.078912837164742, 87.79642295837402, 63.569110597882954, 49.997770990644185, 17.355597802570887, 71.98900713239397, 23.426329238074167, 0.4153653745140348, 0.16955116337963513, 0.15089047327637672, 0.13021891750395298, 0.20303451881877013, 0.12595994318170206, 0.1691467972206218, 0.08476262167096138, 0.10714319680950471, 0.21872884381030286], [0.048026484703379016, 0.04446069157815405, 0.025047092232853174, 0.049728253922824345, 0.046963871722774844, 0.036574404753212414, 0.07755927355693919, 0.037327853430594714, 0.06487579843295471, 0.20529591318752083, 10.521117772374835, 61.994009562901084, 22.484784058162145, 34.8184688431876, 30.874160630362375, 56.767279284340994, 8.564532841954913, 0.6493182235530445, 0.302358189863818, 2.220731339284352, 0.6732176382626806, 0.15164501778781414, 35.15324694769723, 87.5134506225586, 76.52331120627267, 77.89940193721226, 70.97933660234723, 75.03809206826347, 73.72301346915108, 79.17165184020996, 75.23303072793144, 75.6557035446167, 75.9867296218872, 73.15824999128068, 68.94358389718192, 58.481736864362446, 53.08528641292027, 54.95564767292568, 52.72593947819301, 53.611338002341135, 51.36573927743094, 53.049173150743755, 53.4574944632394, 53.22256197248186, 50.73949466432844, 50.52641078404018, 51.06792906352452, 48.21558584485735, 48.226188795907156, 48.021585191999165, 45.03687184197562, 45.00512899671282, 46.77078785215105, 45.808893135615754, 49.463673387254985, 56.103045395442415, 60.91346740722656, 57.89488853727068, 61.621787616184776, 57.2321971484593, 53.71913930347988, 58.69702679770333, 56.947734424046104, 58.85032490321568, 64.18442916870117, 60.54668590000698, 61.574136870247976, 56.88058008466448, 56.18536417824881, 55.86021280288696, 54.02582584108625, 52.95412526811872, 56.55629028592791, 59.08139419555664, 52.69546120507376, 49.85948099408831, 58.81959996904646, 56.25288329805647, 59.33061218261719, 57.55572959354946, 54.166554655347554, 57.360690185001914, 60.35881355830601, 50.465110301971436, 50.15630456379482, 57.68601179122925, 54.02159438814436, 53.76907253265381, 54.73678636550903, 56.51740121841431, 57.09307336807251, 55.86653913770403, 58.442458697727744, 52.43341336931501, 48.819481577192036, 56.926212378910606, 54.828585965292795, 54.40529128483364, 55.85159356253487, 53.28073229108538, 44.03035231998989, 49.1287076813834, 51.94740424837385, 55.6953251021249, 55.87384169442313, 52.83948693956648, 49.063154901777, 43.89586993626186, 45.06489740099226, 48.92180074964251, 51.4580773626055, 53.042218003954204, 57.47593995503017, 52.18864222935268, 51.242631094796316, 48.23344618933541, 48.10632194791521, 60.59341253553118, 52.73002849306379, 51.402814865112305, 41.880273955208914, 42.47342429842268, 41.16596439906529, 42.980403082711355, 43.74423245021275, 46.66181925364903, 42.65175676345825, 44.474012170519146, 44.488040583474294, 45.39765705381121, 44.86354207992554, 45.92026581083025, 48.54274524961199, 56.11447518212454, 56.61918190547398, 56.04288094384329, 55.90367725917271, 53.44810397284371, 52.79435838971819, 55.256984097617014, 55.59564624513899, 58.179399899074006, 60.86314160483224, 61.025917053222656, 63.265161650521414, 67.26959609985352, 67.78381143297467, 68.28697913033622, 70.188784463065, 70.26248400551933, 69.21508475712368, 73.42100306919643, 64.03586973462785, 55.88322523662022, 2.514474034309387, 0.36347202051963123, 0.24851730465888977, 0.1511063559779099, 0.19691806845366955, 1.8687284333365304, 68.36463914598737, 52.65028749193464, 43.76992688860212, 22.762291635785783, 45.044031960623606, 19.92267577988761, 0.4242639813039984, 0.04944497233788882, 0.04885430081880518, 0.07552504592708179, 0.03347822232171893, 0.07807516373161759, 0.050503164662846496, 0.013118571285823626, 0.03178451409829514, 0.030874320438929966, 0.03958271350711584, 0.04609088892383235, 0.04889469061579023, 0.06935009905802351, 0.0502044531915869, 0.05709103401750326, 0.04864823651899185, 0.05514495147924338, 0.17903497948178224, 0.3733699194022587, 15.740504673549108, 68.68463843209403, 33.85987799508231, 30.037270954677037, 32.127191816057476, 68.08971977233887, 7.362766333988734, 0.45128682841147694, 0.09473852493933269, 0.8053334004112652, 1.2712184212037494, 0.04897023531209145, 41.38318593161446, 90.41232245309013, 79.04643140520368, 80.64832469395229, 72.73311751229423, 76.21280315944126, 76.22501809256417, 81.93294933864048, 80.01611505235944, 76.99071652548653, 75.68765830993652, 77.21584510803223, 72.00357055664062, 61.78358336857387, 56.075467995234895, 57.07703692572457, 54.35733481815883, 55.64966154098511, 54.37505619866507, 56.17798866544451, 56.2028979573931, 56.451834542410715, 53.90057066508702, 53.3286783354623, 52.05395139966692, 51.28715862546648, 50.54927383150373, 50.25587919780186, 46.87649427141462, 46.283093793051584, 48.786953585488455, 49.25930254799979, 51.68667657034737, 59.17520877293178, 63.133590562003, 62.01486110687256, 65.52110971723283, 60.39741080147879, 59.57095037187849, 60.781667028154644, 59.72611059461321, 60.22108636583601, 66.52958515712193, 64.36431803022111, 61.626838956560405, 62.810617446899414, 59.411225182669504, 59.23413644518171, 56.61269923618862, 54.44973543712071, 60.57581969669887, 61.21068355015346, 57.04707629340035, 52.82751866749355, 61.97506182534354, 58.7104993547712, 60.99225303104946, 60.013682637895855, 58.44356346130371, 60.11495958055769, 62.81302152361189, 53.106839724949424, 55.15421676635742, 58.71004772186279, 55.236257621220176, 56.87319414956229, 57.71531581878662, 57.71734469277518, 59.709323746817454, 57.52526869092669, 59.77314295087542, 56.662406648908345, 49.789394514901296, 61.03773593902588, 56.813363211495535, 56.55550513948713, 58.47993728092739, 53.782017026628765, 46.31957183565412, 52.14152302060808, 54.7258950642177, 58.39896297454834, 56.90130656106131, 56.185687269483296, 50.72153009687151, 45.615556035723, 46.88352237428938, 50.22824273790632, 54.44811650684902, 55.17854240962437, 60.53317165374756, 55.4273122378758, 54.230252265930176, 51.35610212598528, 52.68407310758318, 63.926901136125835, 54.955849170684814, 54.21549081802368, 44.45330653871809, 44.86627967017037, 43.16122300284249, 44.108787059783936, 44.74800048555647, 49.02016292299543, 44.17453786305019, 46.115364279065815, 46.95811128616333, 48.15014771052769, 47.49494300569807, 48.97802209854126, 51.41110406603132, 58.604935373578755, 58.6687684740339, 57.168805258614675, 56.826509203229634, 55.43074812207903, 54.16309445244925, 57.16952787126814, 59.52939319610596, 60.65487630026681, 64.36152485438755, 63.8799660546439, 64.92759459359306, 70.25848184313092, 69.34046500069755, 72.13175787244523, 71.0652163369315, 71.7383508682251, 70.67513057163784, 74.35982976640973, 66.95748996734619, 60.04005799974714, 3.292566967861993, 0.28617599819387707, 0.20358688703605107, 0.05743940746677773, 0.43082791194319725, 1.9263641749109541, 70.4517251423427, 59.74457890646798, 46.99774728502546, 25.069840499332972, 56.33849900109427, 27.673333985464915, 0.1502472356493984, 0.07411042933485337, 0.05759910746876683, 0.02543290894079421, 0.04282195147659097, 0.07480032981506415, 0.015093392326629587, 0.0369484234335167, 0.014777732746941703, 0.07747229215289865, 0.1350665616669825, 0.1403206754475832, 0.20414019163165772, 0.10729322090212788, 0.13190813043287822, 0.08051518244402749, 0.16213230575834, 0.26111712998577524, 0.1822029102061476, 0.45186276893530575, 16.81616571971348, 83.13705130985805, 31.689309392656597, 48.84200068882534, 45.56552900586809, 73.04596015385219, 10.079666580472674, 0.775579639843532, 0.4108513524489743, 4.404006242752075, 3.906582534313202, 0.3038451043622834, 42.80942528588431, 96.08303914751325, 84.18476322719029, 85.75640405927385, 77.42192867824009, 82.9457118170602, 80.086090360369, 87.3531139918736, 82.14251395634243, 82.80034160614014, 81.77597563607353, 79.67040743146623, 75.08459636143276, 65.20102705274309, 58.309185300554546, 62.441077504839214, 58.960231508527485, 59.13308184487479, 57.96654878343855, 58.985071318490164, 60.241097177777974, 60.784988267081125, 56.891019753047395, 57.6138026373727, 56.107599939618794, 54.79155206680298, 52.80310269764492, 52.91579205649239, 48.73354973111834, 49.67070886066982, 51.27318579810006, 52.16968059539795, 54.76976599012102, 60.51796204703194, 66.23903928484235, 64.58224133082798, 66.95216764722551, 62.46129676273891, 59.58710493360247, 62.08880383627755, 61.721466473170686, 63.380918639046804, 67.91757120404924, 64.97999790736607, 67.69421441214425, 63.61999225616455, 63.55818802969796, 62.3584634235927, 59.6716228212629, 57.44895315170288, 62.55673027038574, 63.984133447919575, 60.81312152317592, 57.30435071672712, 65.53319263458252, 60.29052666255406, 65.22843769618443, 64.25309126717704, 60.318514006478445, 60.35880661010742, 65.9365564073835, 57.33759784698486, 55.32743535723005, 63.12360600062779, 57.36090210505894, 57.313973971775596, 61.92664677756173, 62.522746631077354, 62.80147361755371, 59.006047930036274, 62.00457082475935, 58.431716782706125, 51.72396060398647, 62.57380199432373, 58.5118989944458, 59.65501662663051, 63.152982984270366, 56.99596187046596, 48.062694208962576, 54.08782809121268, 57.54700265611921, 61.702532632010325, 60.59795665740967, 58.658874239240376, 53.95141758237566, 47.924042906079976, 51.009171622140066, 54.16218423843384, 56.324303831372944, 58.79856777191162, 63.04173537663051, 57.993480001177105, 55.989021982465474, 55.36403846740723, 53.929346629551475, 63.13673114776611, 58.88788686479841, 56.0496415410723, 47.45492485591343, 47.26214361190796, 47.41363171168736, 46.70939356940133, 49.48959364209856, 51.164251940590994, 47.18589755467006, 49.647630419049946, 49.90109722954886, 51.26343747547695, 49.712550912584575, 52.29245179040091, 54.21650872911726, 62.09171513148716, 62.045342854091096, 59.44785608564104, 61.54877594539097, 58.27699082238333, 57.93867261069161, 60.034805161612375, 62.17499623979841, 64.50010667528424, 67.70380292619977, 67.73195007869175, 68.3559261049543, 74.17188099452427, 72.2643017087664, 75.42223017556327, 74.93741267068046, 75.80569430759975, 74.8113237108503, 79.57756560189384, 73.53100000108991, 64.78542750222343, 3.068051129579544, 0.8681250853197915, 0.890809705214841, 0.2286196452166353, 0.9496866230453763, 3.525316421474729, 79.05884088788713, 63.592727524893625, 59.37231527056013, 32.98671872275216, 59.903706550598145, 35.29266950062343, 0.4166341264333044, 0.24970275961927005, 0.24930169114044734, 0.1533755806407758, 0.14151951111853123, 0.20846795583409922, 0.11272012362522738, 0.19073651943887981, 0.058362669710602076, 0.13342686822371824], [0.06816712753581149, 0.03352896995576365, 0.028164070066330687, 0.049344247207045555, 0.03315708526809301, 0.007281266834719905, 0.08223399985581636, 0.049506104950393946, 0.03796652112422245, 0.2106892623539482, 17.085464000701904, 59.42168916974749, 35.01756599971226, 49.630589962005615, 36.3521169253758, 61.67871420724051, 2.591023858104433, 0.1458522014852081, 0.08474713071648564, 2.141895992415292, 0.29982106600488934, 3.1164379503045763, 63.76381301879883, 82.77218750544957, 78.09094292776925, 73.51289994376046, 70.80945314679826, 72.65070492880685, 74.05378941127232, 78.35195200783866, 76.17849295479911, 72.77569607325962, 77.03068951198033, 75.38678046635219, 71.72223799569267, 58.831662041800364, 54.436005796704976, 53.864374024527415, 51.4345611844744, 51.27664252689907, 50.14001451219831, 51.37539727347237, 52.110516684395925, 49.80028234209333, 49.97495310647147, 49.53634459631783, 51.54603460856846, 51.07971668243408, 46.65962014879499, 46.14653737204415, 45.24006496156965, 47.101956367492676, 46.547886167253765, 45.806228501456125, 50.15437296458653, 57.88463994434902, 60.31402547018868, 58.99395111628941, 60.05358614240374, 59.03414644513811, 59.228223528180806, 58.47192600795201, 60.87476594107491, 60.511215346200125, 60.52698080880301, 60.279513767787385, 56.80357319968087, 58.86502729143415, 56.510300159454346, 56.96613325391497, 50.1706873348781, 54.354788303375244, 54.131841455187114, 56.93612051010132, 49.52520315987723, 47.94056919642857, 54.08479172842843, 54.5807124546596, 57.73020928246634, 54.09071159362793, 53.59513132912772, 60.942496980939595, 53.66938672746931, 51.83033752441406, 58.32945319584438, 51.729692867824006, 55.39742456163679, 53.60020351409912, 53.446710859026226, 56.00149399893624, 54.85096263885498, 53.71626622336251, 52.48919350760323, 60.821139744349885, 51.19674866540091, 52.63507093702044, 57.42776462009975, 55.54875980104719, 54.53134897777012, 49.54966081891741, 46.91450091770717, 45.29821443557739, 53.968409402029856, 54.09213250023978, 51.85265861238752, 49.02238982064383, 47.67879581451416, 43.03864288330078, 42.84833867209298, 45.45794309888567, 49.66237102236067, 53.376916204180034, 54.39746413912092, 57.0043865612575, 50.33022492272513, 54.36693722861153, 46.4096691267831, 53.136022159031455, 57.17966876711164, 51.86049965449742, 44.15678174155099, 42.524048873356406, 42.33300815309797, 41.11242158072335, 43.569450514657156, 43.3932546206883, 42.52620281491961, 43.235961300986155, 45.818162032536094, 46.80124875477382, 43.208623613630024, 46.96199532917568, 46.26118959699358, 48.90043156487601, 48.96711342675345, 50.85074574606759, 47.63525840214321, 51.15662281853812, 52.478434222085134, 56.93495668683733, 58.94342381613595, 61.21024581364223, 59.52806609017508, 62.35766438075474, 62.39919376373291, 66.01443181719098, 66.38959980010986, 67.76214000156948, 67.75298922402519, 72.35933222089494, 70.4861534663609, 75.41130760737828, 62.2921359198434, 69.75120081220354, 10.86096545628139, 0.36911976603525026, 0.3452209212950298, 0.01310714051526572, 0.12916470478687966, 0.23380563408136368, 57.2176684652056, 59.0178598676409, 45.48539890561785, 29.84960011073521, 38.05342503956386, 28.289927550724574, 0.3248445689678192, 0.022048813922862922, 0.053254206864429374, 0.03718873339572123, 0.09271249401250056, 0.02520537918566593, 0.034034743173313994, 0.058318517436938624, 0.11550876684486866, 0.03212274684171591, 0.014388262127925242, 0.010484323620663157, 0.09374979763690915, 0.032317591564995904, 0.034133968741766045, 0.03476574930495449, 0.02729878355083721, 0.050520368918244324, 0.05736309263323035, 0.19375693665019103, 24.601842846189225, 65.2902558190482, 40.249163491385325, 38.56958586829049, 41.387733527592246, 71.28629411969865, 1.8913660986082894, 0.25266795765076366, 0.028782458044588566, 0.11851954885891505, 0.18640662463647978, 3.7165401833398, 69.43432126726422, 85.13433183942522, 82.38516589573452, 75.76772935049874, 73.70187704903739, 74.69073077610561, 77.06757055010114, 79.6576783316476, 77.5239977155413, 77.9934388569423, 79.49586173466274, 75.58431775229317, 72.5813410622733, 61.289052282060894, 57.6176449911935, 55.93694870812552, 55.24225739070347, 54.44177974973406, 53.46361582619803, 55.71332441057478, 56.23135083062308, 53.16380800519671, 53.26692622048514, 53.237622192927766, 53.60782221385411, 52.424814973558696, 47.950067383902415, 48.54751171384539, 47.38978896822248, 49.88049929482596, 49.71879734311785, 48.48488759994507, 53.30760097503662, 61.19044344765799, 62.85563482557024, 64.9408517565046, 64.40098367418561, 60.85091972351074, 61.418281827654155, 59.64209992544991, 62.362701824733186, 61.43932097298758, 61.75360883985247, 60.07661942073277, 60.3291586467198, 61.44206551143101, 58.79971422467913, 59.002969878060476, 53.47894007819039, 56.47780343464443, 57.4208059992109, 59.25290352957589, 54.08279412133353, 51.763280459812705, 55.10334553037371, 57.11300080163138, 60.51987974984305, 55.814208780016216, 57.461491176060264, 61.70463793618338, 54.976745877947124, 53.4142975125994, 61.912333488464355, 54.30406297956194, 55.94617591585432, 54.368570055280415, 53.69858653204781, 58.494410378592356, 56.576252460479736, 54.52657903943743, 52.82529524394444, 63.793523515973774, 54.66977793829781, 54.00491871152605, 57.44169923237392, 56.97818143027169, 56.75588423865182, 51.814648491995676, 48.94204085213797, 49.53013290677752, 55.83825649533953, 55.0853705406189, 55.12477030072893, 50.975625719342915, 48.598334312438965, 46.072028364454, 45.10334873199463, 49.062595571790425, 53.183033670697895, 55.77526412691389, 57.9040184702192, 59.52249363490513, 53.46459552219936, 53.03408861160278, 50.591928822653635, 56.1169695854187, 58.770906993321006, 53.99684490476336, 47.26987000874111, 44.79983057294573, 45.33753776550293, 43.13131448200771, 45.76165233339582, 46.350769247327534, 45.42899342945644, 45.11033167157854, 46.371186528887065, 48.40561212812151, 46.40709481920515, 49.17642790930611, 48.82187523160662, 49.54516880852835, 51.1362750189645, 52.215604713984895, 50.61513928004673, 52.66757113592965, 55.74403197424752, 57.96292529787336, 61.12314319610596, 62.90881633758545, 62.62408610752651, 65.16652229854039, 65.3595085144043, 66.69800254276821, 69.0552761895316, 69.96109199523926, 69.06684494018555, 74.07258428846086, 69.23107951028007, 77.43458829607282, 65.39520835876465, 74.58158847263881, 13.32814918245588, 0.48042119507278713, 0.22212763928941318, 0.06571264924215418, 0.3692854100040027, 0.30344837850758005, 58.707296235220774, 67.3852071762085, 50.60374423435756, 28.792476858411515, 50.1350222315107, 41.53945091792515, 0.326497561697449, 0.04038695392331906, 0.03747009811922908, 0.033210241701453924, 0.03468357192884598, 0.010268194950185716, 0.01823938262116696, 0.03486041172540613, 0.03909642102995089, 0.02098982092658324, 0.17863399242716177, 0.12152718247047492, 0.18544520836855682, 0.1438994455550398, 0.14551928506365844, 0.13898876548877784, 0.19842480974537985, 0.17758694503988537, 0.18274742098791258, 0.3780977614223957, 30.34869268962315, 77.42356845310756, 47.52980211802891, 68.08672509874616, 50.99097776412964, 77.60033757346017, 3.416337617806026, 0.8454604957784925, 0.43923656216689516, 4.674085761819567, 1.002633850489344, 4.795949348381587, 72.01315907069615, 90.28271770477295, 89.19765227181571, 80.4872168132237, 78.31659957340786, 78.18789809090751, 80.82975605555943, 81.23880345480782, 82.93337876456124, 82.02673612322126, 83.8132916859218, 79.27005917685372, 76.89250373840332, 65.04866000584194, 61.87039416176932, 59.45378984723772, 58.777542522975374, 57.61761372429984, 57.2218200138637, 59.38736506870815, 58.7616936819894, 55.845996788569856, 57.20812858854021, 55.67285462788173, 57.00546700613839, 55.961847577776226, 50.68444756099156, 51.374028478349956, 51.03692620141165, 53.2967791557312, 52.50198514120919, 50.23152576174055, 55.74858999252319, 63.302876472473145, 64.28852707999093, 66.05124337332589, 66.10514054979596, 64.81793117523193, 63.992492130824495, 61.384187017168315, 64.48803070613316, 65.2037160055978, 65.05483000619071, 64.41922964368547, 62.266239983694895, 65.72751985277448, 60.83652305603027, 62.20645073481968, 54.671178000313894, 60.71927915300642, 59.999612535749165, 61.00562136513846, 57.41349649429321, 55.822987828935894, 58.075444425855366, 59.32346248626709, 63.755773953029085, 59.67898791176932, 57.78985261917114, 62.715767587934224, 58.420231410435264, 56.16505806786673, 64.89193643842424, 56.862233366285054, 58.428826332092285, 58.843487875802175, 58.197739669254844, 62.832844734191895, 58.58100577763149, 57.95718608583723, 56.23568303244454, 65.67350455692836, 56.42138058798653, 57.03769275120327, 61.05663503919329, 58.64251817975725, 58.82168442862374, 54.240250723702566, 52.0739483152117, 51.83905751364571, 59.96658774784633, 57.45059640066964, 56.56785903658186, 52.90482085091727, 51.66234745298113, 48.532649517059326, 47.14463220323835, 50.78069748197283, 54.25458138329642, 57.72750990731375, 59.96851934705462, 62.93989562988281, 54.196094921657014, 56.48918458393642, 53.6603992325919, 56.472345624651226, 61.73657185690743, 57.301574911390034, 49.76376608439854, 47.478517464229036, 47.880606242588584, 46.626296588352744, 48.6976101739066, 48.029815333230154, 46.75396626336234, 46.216071469443186, 50.10661799567086, 52.24466902869088, 48.71665518624442, 52.25151300430298, 50.934551443372456, 52.47491495949881, 54.02876145499093, 55.56548758915493, 54.06672988619123, 56.84045076370239, 57.24379369190761, 61.635072571890696, 66.10875361306327, 67.473206111363, 65.655640738351, 67.9957731791905, 68.47796426500592, 72.39542811257499, 71.59314046587262, 72.67724704742432, 74.75691236768449, 77.29354681287492, 76.16823046548026, 81.97930077144078, 68.74989591326032, 80.66088008880615, 13.839791076523916, 0.6148880539195878, 0.7055409838046346, 0.31535039842128754, 0.7855172465954507, 0.8099062378917421, 68.99300643375942, 71.0258617401123, 62.74639524732317, 43.348115648542134, 51.872829232897075, 48.967332295009065, 0.4637637031929833, 0.14419217913278512, 0.1374030698622976, 0.1210288256406784, 0.12214817771954195, 0.12432491805936609, 0.07497132742511374, 0.1821040612246309, 0.21352430379816464, 0.12446822465530463], [0.05211311113089323, 0.009783233249826091, 0.0531610134722931, 0.033613583272589106, 0.05190822069666215, 0.04098894001383867, 0.020736177751262273, 0.017001293699390123, 0.025712163420394063, 0.13085579047245638, 22.532940285546438, 49.4693535396031, 37.029437746320454, 40.70693513325283, 42.19985634940011, 59.400976589747835, 0.4329249651304313, 0.1951385018016611, 0.015191374479659965, 0.061482553370296955, 0.056347359637064595, 9.18509817123413, 74.07216739654541, 78.28387355804443, 75.89709091186523, 69.31802231924874, 72.79229531969342, 73.92589391980852, 77.87734140668596, 78.41060175214494, 74.19911793300084, 78.43640041351318, 72.79727022988456, 72.4502146584647, 71.05920614515031, 60.47643961225237, 55.310415744781494, 54.424496105739046, 52.30726882389614, 51.50007227488926, 50.291565145765034, 50.728565147944856, 50.18221092224121, 51.18444340569632, 51.36124031884329, 48.847065925598145, 50.77813012259347, 50.27410084860665, 46.88231338773455, 45.85214567184448, 45.84494733810425, 46.6619929586138, 46.95383466993059, 46.93483134678432, 48.50198711667742, 58.414658955165315, 61.29690374646868, 60.18747098105294, 62.34967395237514, 60.52397223881313, 58.60843031747, 60.244724137442454, 58.689133644104004, 58.724361010960166, 59.69246046883719, 59.58834171295166, 57.5896645954677, 57.31877865110125, 53.75646502631051, 50.888029779706685, 48.21538782119751, 51.47822366441999, 53.228738921029226, 58.01073932647705, 51.16244888305664, 52.63029752458845, 51.02955068860735, 53.90735905511038, 55.496273108891074, 56.064225809914724, 56.07966470718384, 57.1345089503697, 49.30581726346697, 56.43722595487322, 55.984022753579275, 49.80724443708147, 51.73176343100411, 53.1409866469247, 57.98090723582676, 54.88555424554007, 53.7147410937718, 51.92611844199044, 54.751123973301475, 54.39398309162685, 58.10548843656267, 49.56367186137608, 53.97468709945679, 57.629283223833355, 55.54609169278826, 52.0247620173863, 45.96885803767613, 47.95922858374459, 51.624611786433626, 56.68228891917637, 49.81080191476004, 48.55238587515694, 46.721671036311555, 43.52112231935774, 42.393405369349885, 46.9635899407523, 47.98157746451241, 51.73315307072231, 55.07791859763009, 55.947707993643625, 51.674048219408306, 48.12548507962908, 50.15015888214111, 48.54792513166155, 58.15939256123134, 53.16092797688076, 47.64680283410208, 41.10598407472883, 42.87264347076416, 41.56305742263794, 41.00120523997715, 43.85387849807739, 43.12859426225935, 45.148157664707725, 45.27648047038487, 42.9046642439706, 44.149190834590364, 45.00621638979231, 46.015282426561626, 46.13783475330898, 46.16800730569022, 47.18083231789725, 49.28969049453735, 52.37719202041626, 55.97149167742048, 57.57668883459908, 60.92731516701834, 62.542542048863, 62.40767751421247, 60.99280193873814, 61.31913798195975, 66.42458398001534, 65.68314170837402, 70.53862626211983, 66.86498859950474, 71.02057416098458, 67.74834087916783, 74.5398645401001, 63.64588124411446, 70.93279061998639, 23.515453781400407, 0.27175938178386005, 0.1885417029261589, 0.04977349524519273, 0.39998217139925274, 0.07374676170625857, 42.46427352087838, 67.83793095179966, 49.628206729888916, 35.31405258178711, 28.739521162850515, 39.81421668188912, 1.3607555138213294, 0.0682905191289527, 0.09554138792944805, 0.01264190043522311, 0.037348925335598845, 0.009949498078120607, 0.03943509482113378, 0.025556965498253703, 0.06891338713467121, 0.09278459514358214, 0.04562520694785884, 0.01822818848969681, 0.021216851958472813, 0.044745676285986385, 0.02757909145605351, 0.031922843639871905, 0.012201733920457107, 0.019901420222595334, 0.047311512354229174, 0.044058357631521564, 33.07916450500488, 56.9464316368103, 43.07827540806362, 36.94238029207502, 53.36599711009434, 62.47579765319824, 0.5699255551610674, 0.32704112253018786, 0.04821211152843066, 0.20971008203923702, 0.1082878853859646, 11.553444640977041, 80.04106603349958, 80.02001993996757, 80.93601485661098, 73.13481371743339, 75.51561396462577, 77.05097130366734, 79.81409617832729, 80.83581488473075, 78.03759465898786, 79.89734254564557, 76.30997371673584, 72.96770259312221, 74.08018561771938, 63.294489996773855, 57.53893232345581, 55.96966430119106, 54.28340598515102, 52.5739997455052, 53.01858370644705, 53.850738184792654, 53.06641163144793, 53.96657855170113, 54.55705731255667, 52.41708510262625, 52.537414005824495, 51.70155961172921, 49.092504092625205, 48.402210984911235, 47.650912693568635, 49.49238681793213, 49.55830437796456, 50.01656239373343, 52.19379084450858, 61.12809726170131, 62.92529746464321, 62.33540235246931, 63.05142116546631, 61.968064989362446, 64.22962025233677, 62.16588715144566, 57.65398754392351, 63.550406047276084, 63.935655866350444, 62.275432450430735, 60.8316593170166, 58.93272359030587, 56.71784285136631, 53.57045132773263, 52.30650452205113, 55.142522948128835, 56.430173533303396, 61.3111058643886, 56.3300221988133, 54.16831602369036, 53.517721448625835, 56.61426605497088, 59.244669914245605, 58.28081233160836, 58.83337824685233, 58.308386257716585, 53.21388019834246, 59.7358797618321, 59.14082213810512, 51.34611756461007, 54.819185052599224, 57.130183696746826, 60.435632841927664, 57.86945118222918, 55.58369186946324, 54.9207364491054, 55.87625619343349, 56.576266356876914, 59.652299880981445, 53.148129395076204, 54.313387462071006, 57.58119821548462, 56.37602622168404, 52.68837751661028, 46.71499034336635, 51.994485242026194, 56.854635511125835, 58.705434117998394, 52.52661997931344, 50.13944475991385, 46.26104021072388, 47.0185467175075, 45.826458181653706, 47.29963609150478, 52.0467461177281, 55.357906682150706, 58.04558801651001, 57.560072217668804, 53.69358035496303, 50.214294229234966, 53.23384237289429, 50.985999379839214, 60.79918343680245, 56.957941327776226, 49.6973169871739, 42.834918226514546, 44.850361347198486, 45.53790296827044, 43.21635695866176, 44.947827202933176, 45.43989167894636, 46.07869863510132, 45.755676882607595, 44.42856052943638, 47.28076478413173, 47.126959460122244, 47.330371447971885, 48.628739629473, 48.10408810206822, 48.23397772652762, 53.28714895248413, 54.04404401779175, 57.418377603803364, 59.61135414668492, 62.728406361171174, 64.08178343091691, 64.26913465772355, 63.90864821842739, 63.424164227076936, 67.99068014962333, 68.27559103284563, 73.14019857134137, 68.02603953225272, 72.87710503169468, 68.49575860159737, 73.99681418282645, 66.50869887215751, 74.34174360547746, 28.00069488797869, 0.2948909391249929, 0.1582717943404402, 0.2152262053319386, 0.6197712261761937, 0.2527489204491888, 45.06256628036499, 74.67460400717599, 55.5685795375279, 35.725959164755686, 33.15099845613752, 50.50885616030012, 2.000357061624527, 0.153418559048857, 0.07063136316303696, 0.047767979824649434, 0.06443495423133884, 0.05922496558300086, 0.007980532794525581, 0.028590256215206215, 0.05695411243609019, 0.015238183217921426, 0.16944387342248643, 0.3083795639021056, 0.09001212819878544, 0.08409320616296359, 0.12211749436599867, 0.13231727347842284, 0.163899265229702, 0.15284238782312187, 0.1871897354722023, 0.14593259431421757, 45.29925319126674, 63.33178097861153, 49.90597139086042, 56.42452117374965, 60.50387804848807, 70.45326764242989, 0.8259367634143148, 1.1554563300950187, 0.14057298190891743, 0.762881046959332, 0.21387856693140098, 12.591663581984383, 85.05553231920514, 87.02045508793422, 85.12924575805664, 75.04494994027274, 80.25888511112758, 82.2883358001709, 85.55505221230644, 84.30115944998605, 82.32720402308873, 85.00509534563336, 79.72595133100236, 77.15331826891217, 78.3759024483817, 65.49360179901123, 62.146453039986746, 59.3483578818185, 58.82883412497384, 57.82553161893572, 57.46927663258144, 59.36670807429722, 57.06234843390328, 57.68732500076294, 58.67853764125279, 55.339907373700825, 56.460700443812776, 56.280106340135845, 52.24170562199184, 52.27530016217913, 50.78052030290876, 52.42160143171038, 50.970563956669395, 50.90663358143398, 52.8656781741551, 63.283136640276226, 66.70133072989327, 65.92108276912144, 66.64247253962925, 66.69334724971226, 64.35080378396171, 61.92937741960798, 62.149941035679404, 65.2389920098441, 65.09354536873954, 64.81721551077706, 64.63293538774762, 61.807269777570454, 58.94305556161063, 56.596058300563264, 54.10742548533848, 58.26873288835798, 58.38361440386091, 64.18358843667167, 60.23226601736886, 57.80682359422956, 54.54544687271118, 59.043067932128906, 60.54506002153669, 61.209808077131, 60.97566073281424, 62.64090769631522, 55.440621512276785, 60.64218194144112, 60.254104205540244, 55.026988301958355, 56.87388549532209, 58.49535533360073, 64.21940640040806, 61.4669748033796, 59.26692499433245, 57.13611051014492, 59.47608661651611, 59.12434101104736, 64.12411880493164, 55.00806488309588, 55.96942458833967, 61.288162912641255, 59.627758843558176, 57.05997909818377, 49.89722013473511, 55.74026952471052, 58.00542048045567, 60.841977391924175, 55.042124952588765, 53.500896385737825, 51.431840964726035, 49.99111461639404, 47.34908989497593, 50.154362542288645, 54.11539854322161, 56.47751161030361, 59.300331933157786, 61.715574400765554, 55.16712999343872, 51.0429607118879, 53.81635849816458, 53.404410226004465, 65.08014229365757, 57.51618044716971, 53.111505440303254, 46.012204374585835, 47.97386843817574, 46.13062947137015, 46.4801481791905, 49.388948985508506, 47.171980312892366, 48.727126121520996, 49.183994497571675, 46.70103488649641, 49.95912511008126, 50.25593825748989, 50.416796003069194, 52.35288027354649, 52.11081198283604, 52.20954588481358, 56.290038790021626, 57.32347215924944, 60.84185232434954, 63.033230781555176, 67.54963629586356, 67.68911443437848, 68.92224597930908, 66.7943115234375, 65.35624980926514, 71.875230380467, 71.26476165226528, 75.66850212642125, 72.59257629939488, 75.42533602033342, 72.64996147155762, 77.97321265084403, 69.33697700500488, 81.22936085292271, 29.769351891108922, 0.4246052029941763, 0.3355637123542172, 0.30969190491097315, 1.560917916042464, 0.6195935585669109, 51.594213417598176, 78.1410185950143, 64.29268210274833, 51.72012519836426, 39.844792229788645, 62.42596517290388, 2.299118527344295, 0.19663425082606928, 0.1883051927600588, 0.0979671302650656, 0.14132336021534034, 0.13614008549068654, 0.15154494744326386, 0.13442655386669294, 0.23511821936283792, 0.137785315779703], [0.020526466325723698, 0.036639920701938014, 0.04754960350692272, 0.06106126454791852, 0.02572665692839239, 0.03161196942840304, 0.05392230940716607, 0.029553558810481002, 0.018284783399264728, 0.05754798664046185, 24.676634992871964, 40.47642517089844, 31.419531685965403, 39.869024072374614, 50.87820850099836, 59.37527520315987, 0.0745711342564651, 0.1542157291301659, 0.03626976627856493, 0.21649758996708052, 0.16186189598270825, 24.773871558053152, 80.65040220533098, 77.73670986720494, 75.21108831678117, 69.45192105429513, 71.23675346374512, 74.09417234148297, 77.69328362601144, 72.31610747746059, 73.02578258514404, 75.71306787218366, 74.11415536063058, 70.34410449436733, 66.2219467163086, 61.09407888139997, 55.254128387996126, 53.13394464765276, 52.7765223639352, 51.426817417144775, 52.45016547611782, 49.63477277755737, 48.26647792543684, 50.151833398001536, 49.77614777428763, 50.14027854374477, 50.76306990214756, 45.88239118031093, 43.875994614192415, 44.27625601632254, 44.45012773786272, 48.17017936706543, 47.846685137067524, 46.399219036102295, 50.05619144439697, 60.73985971723284, 58.95986325400216, 59.52129854474749, 58.707921573093955, 60.39004571097237, 58.06852749415806, 64.7985179083688, 58.96508829934256, 60.40857655661446, 59.37205123901367, 57.208517687661306, 56.42274938310896, 53.076212065560476, 51.71214171818325, 49.288498878479004, 50.336909089769634, 53.26322283063616, 56.99411712374006, 55.018473284585134, 51.828607422964915, 51.66600567953927, 54.07298673902239, 57.23887436730521, 57.87374516895839, 55.163589886256624, 56.0416441644941, 52.24505465371268, 56.50389739445278, 58.97713647569929, 53.36604227338518, 54.01938138689314, 57.23655366897583, 56.17124891281128, 55.239412103380474, 55.263029030391145, 56.587956701006206, 53.45786271776472, 53.906751087733674, 51.968005657196045, 56.68013497761318, 54.809978689466206, 52.660348483494346, 54.00784042903355, 54.06324536459786, 47.92092316491263, 44.919388226100374, 46.058138915470664, 52.210761819567, 53.66136155809675, 49.3218606540135, 46.4085886819022, 45.21077830450875, 44.08391945702689, 44.45093372889927, 47.03694554737636, 49.0121933392116, 52.8914247240339, 51.65003177097866, 54.73615755353655, 52.44985975537981, 50.736291544778005, 50.871572971343994, 44.64139774867466, 56.04717493057251, 54.09812184742519, 49.34588752474104, 44.12114790507725, 40.66251182556152, 39.87171649932861, 41.634846210479736, 42.521537099565776, 44.026516914367676, 45.14795964104788, 42.33636065891811, 44.97915315628052, 43.637810366494314, 45.50992604664394, 44.1481659752982, 44.1425518308367, 45.10482175009591, 48.00107410975865, 49.00030844552176, 50.22680098669869, 54.49254328863961, 58.65960380009243, 59.169962882995605, 62.42044135502407, 59.431916918073384, 63.82851464407784, 61.52226161956787, 66.48331710270473, 63.72401373726981, 68.46746553693498, 68.2208114351545, 70.25970472608293, 71.34955051967076, 69.77210099356515, 67.18209048679897, 65.77110590253557, 38.62011316844395, 0.1265818476676941, 0.08131326854761158, 0.14634103168334278, 0.26798949550305096, 0.28595259732433725, 29.2711660521371, 77.7371962411063, 45.07799128123692, 41.23644692557198, 21.48737015042986, 38.59931721006121, 4.789353770869119, 0.23679905916963304, 0.04712102043309382, 0.03776159676324044, 0.08202182874083519, 0.012025759256045734, 0.03280010120943189, 0.04517533823049494, 0.06337211733417851, 0.0701205755716988, 0.09783530448164258, 0.027382591107328023, 0.0102829378198034, 0.09778051277888672, 0.08337013889104128, 0.022505503613501787, 0.047382928164941926, 0.028324567346966693, 0.03773587350068348, 0.1533581151493958, 40.26992818287441, 47.72332681928362, 28.883993319102697, 40.50552075249808, 60.74530015672956, 63.200411387852256, 0.09103936914886747, 0.6356383061834744, 0.028487451374530792, 0.1285558281732457, 0.11880039450313364, 26.227429492133005, 83.51220539637974, 79.4820556640625, 79.11464187077114, 69.47626754215786, 75.02352169581822, 77.5735661642892, 80.87449550628662, 74.14136450631278, 75.31889656611851, 77.01926667349679, 76.27553844451904, 70.12169960566929, 69.18161528451103, 62.811562401907786, 56.05905287606375, 55.1357102394104, 55.14242219924927, 54.78780003956386, 54.67661149161202, 51.87321833201817, 52.28630610874721, 52.60324818747384, 51.92921039036342, 52.68733876092093, 51.9078620501927, 48.71254185267857, 47.729882444654194, 47.03386402130127, 47.98433589935303, 50.83317027773176, 49.24523591995239, 47.95030014855521, 54.033562660217285, 62.780212129865376, 62.802807671683176, 61.53687368120466, 60.92330605643136, 63.164197376796174, 59.90661089760916, 68.24212850843156, 59.93083231789725, 62.71934591020857, 61.62667219979422, 59.915171078273225, 59.20333508082798, 54.85010801042829, 53.08063459396362, 51.41706214632307, 52.94648919786726, 55.676009110042024, 59.333224705287385, 57.677253586905344, 55.153473309108186, 54.29281037194388, 54.576811041150776, 60.18752656664167, 59.36333819798061, 56.99310268674578, 57.70023822784424, 54.19154732567923, 58.229968888419016, 60.39160210745675, 55.5311530658177, 55.37337337221418, 59.00288649967739, 56.67758846282959, 56.0689366885594, 57.47196905953543, 59.714118003845215, 55.76730496542794, 55.98746906008039, 53.38221767970494, 57.42963368552071, 57.97888878413609, 54.859317847660606, 56.08020666667393, 56.79400553022112, 49.82672371183123, 47.32831130708967, 47.418078558785574, 53.57917479106358, 54.67713955470494, 53.36427048274449, 48.282236439841135, 46.62773486546108, 45.682693004608154, 46.471181528908865, 49.10303061349051, 50.91259513582502, 55.02130120141165, 56.01389305932181, 56.31452424185616, 54.58475283214024, 50.8275283404759, 53.45990548815046, 48.23178904397147, 58.948801721845356, 55.67839581625802, 51.98801646913801, 46.578628471919465, 43.730165822165354, 42.55471822193691, 43.4403703553336, 45.89215687343052, 45.22618246078491, 45.80728810174124, 44.350702490125386, 46.77109704698835, 46.46498373576573, 48.61356128965105, 47.08044127055577, 47.31395285470145, 49.085774762289866, 50.81863464627947, 52.13759381430489, 53.80403239386422, 58.19941071101597, 60.36661638532366, 63.447683879307334, 62.94986629486084, 62.14691162109375, 64.15391268048967, 64.70293848855155, 67.84530993870327, 67.58028479984829, 69.6024329321725, 68.94527230943952, 70.2502690723964, 72.70952142987932, 72.46313830784389, 68.28536020006452, 69.78314862932477, 46.67903688975743, 0.07616595617894616, 0.0705133591379438, 0.23604108127100126, 0.4447780762399946, 0.46167012410504477, 32.14728948048183, 81.84108025687081, 53.944174085344585, 44.41807222366333, 29.603446279253276, 51.085876260484966, 6.7846236654690335, 0.21082868772958005, 0.013775472063571215, 0.009543560262370323, 0.011125129547768405, 0.07469312806746789, 0.01376495392261339, 0.03758071629064424, 0.029163177258202007, 0.02512959700210818, 0.19298039403344902, 0.1060373340068119, 0.11208922855023827, 0.2268694048481328, 0.18001443121050084, 0.08077856259686605, 0.2338084296456405, 0.13433805932956083, 0.07878388677324567, 0.18878050654062203, 53.632071426936555, 53.59803567613874, 42.71996375492641, 56.75640535354614, 66.6305980682373, 71.67073794773647, 0.23741845307605608, 1.1484217132840837, 0.09771698154509068, 0.3886837219553334, 0.3443680299179894, 28.275982516152517, 88.43717888423375, 84.21192373548234, 84.50627027239118, 74.97967161451066, 79.45802879333496, 81.2638795035226, 86.4318037033081, 76.08574840000698, 80.11233370644706, 82.71552494594029, 81.84221976143974, 74.77832671574184, 73.96301119668144, 67.3658425467355, 60.96409893035889, 59.45520033155169, 59.810989788600374, 58.0594288281032, 59.19515010288784, 54.3494416645595, 53.74106087003435, 55.91059071677071, 56.52181679861886, 57.872803688049316, 55.89728839056832, 52.767006805964876, 49.562323910849436, 49.85186924253191, 50.415388992854524, 53.37562383924212, 52.5785299709865, 50.102601936885286, 56.55640493120466, 64.85277639116559, 66.44077328273228, 63.43867206573486, 62.76530129568917, 66.65717492784772, 63.843592235020225, 68.75678157806396, 59.22914069039481, 67.573121207101, 62.593750272478374, 63.57966491154262, 61.92287390572684, 58.08735711233956, 54.84473010471889, 54.83909511566162, 57.36532810756138, 59.62360382080078, 63.73603412083217, 61.07021181924002, 58.22941998073033, 59.117420605250764, 58.548543793814524, 61.62540067945208, 62.885463442121235, 60.29029737200056, 59.454512459891184, 58.042332785470144, 59.82963180541992, 64.48045022147042, 58.259095736912315, 61.38761247907366, 60.551834515162874, 61.747570855276926, 58.395023345947266, 60.91879667554583, 61.3118006842477, 57.5428580556597, 58.46315738133022, 56.68189287185669, 61.060025760105674, 61.20588929312569, 54.733468600681846, 57.56238944189889, 58.611827986580984, 50.87866013390677, 49.78017772947039, 53.07113293239048, 56.416332721710205, 58.95856394086565, 54.96491656984602, 51.345540864127024, 49.02678803035191, 49.01333979197911, 50.05731357846941, 53.18054621560233, 52.13658632550921, 57.71082033429827, 58.72020598820278, 58.82139260428292, 56.270691531045095, 53.326736313956125, 52.07612657546997, 48.90754304613386, 60.49896567208426, 59.41424764905657, 54.63771547589983, 50.4952654838562, 45.774499552590505, 45.00125190189907, 48.24042912891933, 49.14258323396955, 48.21065957205636, 50.23049742834908, 47.215121677943635, 50.343343121664866, 48.51634209496634, 51.084253856113975, 49.82319402694702, 49.83934511457171, 50.32700443267822, 53.83576481682913, 55.860824244362966, 55.49228484289986, 60.624443190438406, 63.960120473589214, 65.83268083844865, 66.88174070630754, 65.32487869262695, 68.2772308077131, 69.99639579227993, 71.2654356275286, 71.03998742784772, 73.93789345877511, 76.01768384660993, 75.06556524549211, 77.91307599203927, 76.82935156141008, 73.0291941506522, 75.17783423832485, 49.250356742313926, 0.17161062572683605, 0.25593988065208706, 0.41759072510259493, 1.1418618538549967, 1.1299945477928435, 36.0596707207816, 89.17919090815953, 58.5065141405378, 58.81659834725516, 36.8387895992824, 65.25957257407052, 8.85537314414978, 0.4741791614464351, 0.17041398850934847, 0.11185746812926871, 0.15886070845382555, 0.08847252545612198, 0.11721340966011796, 0.09436630776950292, 0.166911852146898, 0.10900534795863287], [0.018349615723959038, 0.04951735506100314, 0.03222799440845847, 0.05803370914821114, 0.034189021680504084, 0.0389735179820231, 0.08201872105044977, 0.027755161115367497, 0.04754050435232265, 0.33891923086983816, 29.733155250549316, 32.86289487566267, 34.98326621736799, 42.81737402507237, 56.28903130122593, 52.74734687805176, 0.01799096416548959, 0.8513462170958519, 0.04969913119982396, 0.125456144501056, 0.08492323769522564, 33.278556959969656, 80.89101832253593, 75.6636939729963, 75.0357644217355, 67.0454819543021, 69.77624211992536, 74.83873435429165, 76.93368571145194, 76.54848452976772, 75.46465587615967, 75.2296677998134, 72.38846601758684, 69.50091975075858, 66.9208173751831, 62.11392157418387, 55.39407900401524, 53.20918321609497, 53.89729806355068, 50.77067470550537, 51.465654373168945, 51.224510192871094, 49.30239527566092, 47.805902685437886, 47.88233286993844, 48.11310338973999, 47.056275435856406, 44.106858934674946, 43.763402530125205, 45.669762407030376, 46.74921022142683, 47.28396790368216, 46.20365156446184, 44.91771718433925, 49.65233434949602, 58.139996664864675, 62.134370122637065, 58.89943477085659, 60.17077445983887, 59.88252149309431, 57.77339581080845, 55.968604700905935, 68.14485372815813, 58.69624859946114, 57.87056984220232, 59.117566517421174, 54.444374901907786, 55.107931341443745, 49.6040825843811, 50.54562950134277, 48.1255441393171, 53.342984676361084, 54.63291079657418, 57.1095301764352, 53.009290490831646, 51.07467923845564, 51.81424897057669, 59.276277269635884, 57.32900639942714, 55.365890162331716, 55.7946218081883, 55.591571126665386, 57.08103561401367, 55.749225752694265, 54.50625555855887, 56.63266141074044, 50.05418341500418, 48.32660068784441, 46.57293789727347, 47.84552826200213, 53.92016111101423, 52.397494656699045, 54.97151041030884, 51.57823256083897, 52.4264269556318, 54.72426918574742, 52.36759308406285, 53.40164136886597, 55.5763441494533, 50.337503160749165, 40.31527212687901, 47.1905563218253, 51.70937286104475, 54.30060625076294, 49.70727375575474, 45.81622348512922, 43.182658195495605, 43.669674805232454, 42.85934114456177, 47.287428106580464, 45.899362155369346, 49.586868422372, 51.64345530101231, 54.21613352639334, 46.9371520451137, 51.863508224487305, 49.71312761306763, 40.6658365385873, 56.24107136045183, 51.92313419069563, 53.13286072867257, 42.19836943490164, 43.57657241821289, 39.498869214739116, 41.0375199999128, 39.98416614532471, 42.1754994392395, 42.82346759523664, 45.10600989205496, 42.630363259996685, 44.52075270244053, 43.83653232029506, 46.18107686723982, 45.67699200766427, 47.09873587744576, 46.32922635759626, 49.017147404806956, 52.59356587273734, 56.61751433781215, 57.66419097355434, 58.96039131709507, 61.77983134133475, 62.6123297555106, 61.07713222503662, 63.3718512398856, 63.85439668382917, 65.64443329402378, 66.40462875366211, 67.11967481885637, 64.14234392983573, 68.24842357635498, 62.32094315120152, 70.4312835420881, 62.39942305428641, 60.15586362566267, 1.1572691585336412, 0.12863244834755147, 0.02539672945359988, 0.7735018570508275, 0.2519230619072914, 22.496929509299143, 76.60478578295026, 50.0448763029916, 41.17790140424456, 21.44253863607134, 31.561132499149867, 7.746733341898237, 0.09118174615183047, 0.023255544348752925, 0.020588236761146357, 0.013779534791995372, 0.08859434284801994, 0.017346362683123777, 0.05386462714523077, 0.043705159798264503, 0.0621557008208973, 0.01963417242015047, 0.039941064813839536, 0.030320350879005024, 0.03717330350939717, 0.044540327840617726, 0.014866057650319167, 0.008228075091860123, 0.048511080842997344, 0.012049853186389166, 0.9152526536158153, 45.71492917197091, 40.74095351355416, 35.55859095709664, 46.360889298575266, 62.63645390101841, 57.932116985321045, 0.6078698305147034, 0.9609849367822919, 0.07889988233468362, 0.15396575682929584, 0.05383109055193407, 36.25369569233486, 85.0311302457537, 78.13458456311906, 78.554901940482, 70.98142106192452, 71.80910437447685, 77.90326513562883, 80.97054045540946, 77.69577802930559, 77.45708656311035, 77.39720003945487, 75.13784735543388, 71.06425748552594, 70.68621989658901, 65.86418397086007, 58.58746065412249, 56.356599058423726, 54.74930354527065, 54.286452770233154, 52.89786917822701, 53.773244925907676, 52.83533539090838, 50.774457999638145, 53.32088940484183, 51.76004607336861, 50.433853830610005, 46.75054080145699, 45.64417219161987, 49.043293476104736, 48.73135757446289, 49.66213130950928, 47.62870972497122, 49.10131440843855, 50.595760754176546, 60.26777826036726, 62.10306848798479, 63.2379594530378, 61.1483929497855, 60.763414110456196, 59.76246356964111, 59.72208758762905, 67.06824425288609, 56.92968300410679, 62.27458477020264, 63.16387775966099, 57.640191895621165, 59.67281791142055, 52.76838254928589, 52.039092676980154, 51.47564588274275, 54.79183694294521, 56.846471377781455, 58.55011408669608, 55.80654839106968, 54.46330526896885, 55.90266282217843, 61.29158837454659, 60.4597361428397, 58.17081887381417, 57.39937080655779, 56.45798717226301, 60.5066225869315, 56.3770615032741, 56.22679281234741, 59.59643636431013, 53.65902348927089, 49.31925507954189, 48.47621972220284, 48.295208726610454, 53.788072381700786, 54.78074066979544, 56.25204951422555, 53.668181215013774, 51.96492760522025, 56.94485092163086, 54.85113286972046, 54.54614864076887, 57.24203927176339, 48.45308222089495, 42.25146409443447, 50.33337245668684, 54.08348894119263, 56.54533992494856, 51.42323909487043, 48.987725257873535, 46.93910101481846, 47.81612695966448, 47.10376637322562, 49.2016533442906, 49.01801940373012, 51.956308364868164, 52.999163491385325, 57.01449966430664, 50.03047268731253, 51.32952874047415, 50.87535973957607, 45.056232997349326, 58.24608523505074, 54.728597913469585, 55.457293714795796, 45.94314275469099, 44.74068055834089, 42.6647881099156, 42.120302949632915, 42.93741805212838, 45.17280639920916, 45.27329472133091, 47.75893286296299, 44.677545751844136, 47.64767483302525, 45.800454548427034, 49.77725601196289, 48.61770589011056, 48.3801018169948, 49.714072568076, 52.665194852011545, 55.44214316776821, 60.09517111097063, 59.68781212397984, 61.323584829057964, 62.722139086042134, 64.47537803649902, 64.23899337223598, 65.74236815316337, 66.7373571395874, 69.23306669507707, 68.24849305834088, 69.79728126525879, 66.25515910557338, 71.84433174133301, 65.63303824833461, 74.66799627031598, 64.47374520983014, 68.90943350110734, 1.5275935956409998, 0.050272293122751374, 0.18478518378521713, 1.6690101729972022, 0.2478448221726077, 24.33134252684457, 78.83709607805524, 57.847043241773335, 42.69177491324288, 27.998261281422206, 46.40656328201294, 8.122321690831866, 0.13532825905297483, 0.046096307025956254, 0.05863886060459273, 0.054942303603248935, 0.020622653753629754, 0.023909465509599874, 0.043714968021959066, 0.028596892287688594, 0.07974122504570655, 0.14961186902863638, 0.18456103652715683, 0.08356113971344062, 0.21387035665767534, 0.1350383617516075, 0.10132396513862268, 0.1898724322340318, 0.14178666392607348, 0.14329959345715387, 1.5022046608584267, 63.156714166913716, 44.3426182610648, 47.18116583142962, 57.04834433964321, 71.86707319532121, 63.89168766566685, 1.3359482735395432, 2.896173758166177, 0.23970191340361321, 0.3777502972100462, 0.21360256602721556, 39.61196504320417, 88.48905413491386, 82.78634098597935, 81.60732201167515, 75.34689780644008, 76.16883495875767, 81.87865611485073, 86.5743807383946, 82.61039175306047, 80.29017979758126, 80.95287813459123, 78.60911873408726, 75.71005930219377, 73.96326133183071, 69.5248840876988, 60.826482909066335, 60.91948454720633, 58.68527739388602, 58.08100298472813, 58.218622480119976, 57.04595763342721, 55.623737812042236, 52.8972681590489, 55.793996470315115, 54.74253599984305, 52.99517175129482, 49.30689076014927, 48.06887463160923, 52.76521069662911, 51.92333568845476, 53.76318046024868, 49.01259980882917, 51.77764933449881, 51.765225955418174, 63.06408078329903, 66.21114226749965, 66.01704433986119, 64.60284273965019, 63.44646099635533, 62.68450764247349, 64.41457435062954, 65.20398003714425, 56.385427134377615, 65.58375467572893, 63.19877856118338, 60.93326282501221, 60.99663039616176, 55.27298927307129, 56.44111694608416, 56.72814008167812, 58.3573363167899, 59.463225500924246, 63.112704277038574, 60.9454916545323, 56.08631065913609, 58.622882570539204, 64.92689282553536, 63.02940232413155, 58.808302198137554, 62.39528887612479, 59.616926601954866, 61.15921129499163, 61.01878820146833, 60.483867236546104, 62.92228889465332, 55.58489390781948, 50.956132548195974, 50.38796097891671, 50.68052530288696, 57.48214817047119, 57.38521385192871, 57.861551080431255, 55.15028061185564, 56.38430152620588, 58.5444860458374, 55.98954309735979, 58.8156464440482, 58.8304808480399, 50.99615069798061, 46.20298106329781, 52.92058631352016, 56.38240466799055, 60.96768420083182, 53.198382241385325, 51.39885091781616, 48.242558751787456, 51.2650077683585, 48.83599744524275, 51.5881267956325, 52.165747914995464, 55.07321119308472, 55.357708658490864, 59.6098324911935, 54.662732464926584, 51.58562197004046, 52.277568749019075, 47.90554680143084, 61.52582604544503, 58.701869692121235, 56.990854944501606, 48.28703417096819, 47.97013030733381, 45.76047461373465, 44.293855803353445, 45.28412348883492, 47.89121961593628, 48.15806518282209, 48.8420284816197, 47.23709535598755, 50.47306598935808, 49.27116659709385, 53.30854940414429, 51.807922635759624, 52.104933806828086, 52.9912633895874, 55.83306966509138, 57.71490934916905, 62.666226931980674, 62.682812282017295, 66.12414387294224, 65.58261517116001, 67.85940088544572, 67.82076890127999, 68.26950441087995, 70.10885238647461, 73.14322798592704, 70.86489282335553, 72.65424156188965, 69.02020863124302, 76.85637310573033, 68.35667651040214, 79.86531135014125, 68.66901193346295, 73.01476969037736, 1.409593967454774, 0.21813089161046914, 0.5340936407446861, 3.7708976779665266, 0.6349733418651989, 27.89107142175947, 89.26305566515241, 62.66307939801897, 58.84155627659389, 32.30842515400478, 60.10892159598214, 12.499750205448695, 0.2646848128310272, 0.13349181759570325, 0.13852623530796596, 0.19166767304497107, 0.12988898663648538, 0.08275321485208613, 0.2533968399677958, 0.0926840091124177, 0.19268206932715007], [0.01869046761255179, 0.08469365537166595, 0.020013051107525826, 0.08501782547682524, 0.04983355916504349, 0.07825021898107869, 0.019858926967052475, 0.09445653935628277, 0.0749643724411726, 2.403905613081796, 36.230763162885395, 25.391387496675762, 38.309198651994976, 40.309480803353445, 61.30744416373116, 51.40709842954363, 0.27169986069202423, 0.3982485958508083, 0.056866177690348456, 0.1733307662819113, 0.028594900787408863, 40.170433453151155, 84.19993114471436, 75.62194919586182, 74.3365671975272, 67.4270214353289, 71.3592085157122, 73.81536197662354, 73.08033984048026, 73.68282508850098, 72.68739141736711, 73.62086800166539, 72.16988958631242, 69.49604211534772, 67.71808842250279, 65.06670447758266, 59.5710129056658, 53.655952385493684, 50.6203921181815, 50.38467795508248, 51.286105973379954, 50.09597682952881, 50.80623211179461, 50.448250498090474, 49.00203854697091, 48.187952859061106, 45.27903045926775, 44.585944175720215, 44.54812513078962, 44.16001960209438, 45.944167613983154, 46.902675083705354, 47.7145790372576, 46.11457218442644, 51.48178114209856, 60.19061156681606, 60.73059776851109, 58.322984422956196, 59.594588143484934, 60.264318057468955, 61.078042439052034, 55.09386123929705, 53.550648961748394, 75.25712708064488, 59.93958009992327, 57.8612835747855, 53.602520738329204, 52.69985246658325, 48.38588966642107, 45.91271659306118, 49.39361122676304, 52.022295406886506, 54.3692683492388, 57.20949738366263, 52.52625172478812, 48.60480655942644, 47.70468132836478, 57.464923586164204, 50.327615874154226, 53.51954187665667, 57.098534652165, 53.614398683820454, 55.6977778162275, 52.90277460643223, 54.71856471470424, 53.12076391492571, 51.372089930943076, 49.34757246289934, 47.090550899505615, 48.69212457111904, 51.03074925286429, 46.636100496564595, 52.3122888973781, 55.444401332310264, 51.388855934143066, 55.897885935647146, 53.758539063589915, 51.70504413332258, 55.443289620535715, 46.8921103477478, 39.081411021096365, 45.832614285605295, 51.0508017539978, 54.28656741550991, 50.155099051339285, 46.455926758902415, 41.777107102530344, 42.779204096112935, 45.29834992544991, 46.68575232369559, 47.50246443067278, 50.55551331383841, 52.44915451322283, 55.11034236635481, 50.05507625852312, 57.92160783495222, 38.290469782693044, 47.86371169771467, 54.83532919202532, 50.624324798583984, 50.91049330575125, 47.31453650338309, 43.7599527495248, 41.69056034088135, 41.469670159476145, 40.25638614382063, 41.73613010134016, 42.815039430345806, 43.19159705298287, 44.21451084954398, 44.57298231124878, 44.48534120832171, 43.5793308530535, 46.041762011391775, 45.20348269598824, 46.248912130083355, 51.405625411442344, 53.21260172980172, 56.31869663511004, 58.21365451812744, 60.207002367292134, 59.37582411084856, 64.32396984100342, 61.26280198778425, 64.97501604897636, 62.18304225376674, 64.8702163696289, 59.91677611214774, 62.652226311819895, 57.095512185777935, 67.06399890354702, 61.29916885920933, 70.0054770878383, 60.2028751373291, 69.77909782954625, 6.635753733771188, 0.2875986418553761, 0.16155936435929366, 0.664715051651001, 0.3544833314205919, 19.34992187363761, 75.47343839917863, 50.59276955468314, 48.313972336905344, 22.69835431235177, 22.828110183988297, 7.884629896708897, 0.24875120925051825, 0.045119494798460176, 0.09892676877123968, 0.03269146775294628, 0.016113308491185308, 0.012377354898490012, 0.03285163255142314, 0.0421215031695153, 0.05164736808676805, 0.01679389607826514, 0.01781383259887142, 0.03442048693874052, 0.008397399264919971, 0.08875949148620878, 0.08537242109222071, 0.02332861239223608, 0.07001451376293387, 0.15075009795171873, 3.8061180966241017, 50.482029165540425, 34.55428443636213, 44.301213945661274, 47.48629249845232, 69.56603131975446, 55.934819085257395, 0.4375001367713724, 0.7930738468255315, 0.08546732778527907, 0.115830392443708, 0.09608566800930671, 41.07674258095877, 86.01152801513672, 79.02783107757568, 75.24121570587158, 71.0259381702968, 74.63833441053117, 75.79447296687535, 76.67806148529053, 75.51868506840297, 74.86953571864537, 74.13112980978829, 74.90892505645752, 72.75038378579276, 69.94677870614188, 67.33946023668561, 64.57811410086495, 57.34968771253313, 54.122794900621685, 53.46921260016305, 52.77899244853428, 52.697281633104595, 53.79038960593087, 52.52097804205758, 50.58231251580374, 51.95607212611607, 48.64947305406843, 47.1724910054888, 46.28874267850603, 47.01735510144915, 48.066328116825645, 49.41503599711827, 49.0009719984872, 47.631214550563264, 52.98675748280117, 61.99536446162632, 62.47353948865618, 59.3136933190482, 60.933089120047434, 62.419135093688965, 62.19258907863072, 58.64938299996512, 56.727910791124614, 71.34660448346818, 58.733081000191824, 61.064298902239116, 56.81057698386056, 53.96454272951399, 49.25632177080427, 49.94813305991036, 50.300139222826274, 54.783308029174805, 56.991153717041016, 59.83494022914341, 55.132541860852925, 53.22095346450806, 47.931887422289165, 57.0359001159668, 52.989661829812185, 56.75475863048008, 58.47127982548305, 57.17604875564575, 57.11353928702218, 55.08026361465454, 57.411964416503906, 53.63623687199184, 55.25135258265904, 52.39995084490095, 48.02747031620571, 49.544682434626985, 50.41573987688337, 48.73822239467076, 52.95419822420393, 59.1539750780378, 53.51996224267142, 57.908645970480784, 56.386782033102854, 54.41483463559832, 55.861706665584016, 47.74344880240304, 40.41351270675659, 49.52619327817644, 51.92172370638166, 55.79871429715838, 52.19621923991612, 48.83824866158621, 44.37200914110456, 45.744855063302175, 47.86765480041504, 50.2513177054269, 49.82911736624581, 52.95255150113787, 53.800728525434224, 55.611953667231965, 49.51217876161848, 56.04611185618809, 41.45776442119053, 50.20796094621931, 57.14045660836356, 52.661043303353445, 55.49181931359427, 50.57826171602522, 46.127634797777446, 42.46876900536673, 44.345077923366, 40.86962372916085, 42.29021767207554, 45.210740089416504, 45.35014527184622, 46.29126487459455, 47.15395668574742, 48.201439312526155, 48.33451816013881, 49.59876373835972, 48.38040753773281, 50.06196192332676, 52.193756103515625, 55.04903841018677, 58.77759116036551, 60.31085014343262, 62.426896231515066, 62.676982743399485, 65.84502778734479, 62.946732657296316, 68.24517181941441, 64.16307735443115, 67.8507364818028, 61.9750896181379, 63.41948114122663, 59.15303012302944, 71.69851684570312, 63.217510904584614, 73.04313223702567, 63.904222215924946, 76.60434109824044, 8.077176639011928, 0.35208348876663614, 0.07892175151833467, 1.163062327674457, 0.2374088993029935, 21.92553918702262, 82.18962969098772, 56.28658900942121, 52.190566880362375, 22.16324574606759, 40.48176833561489, 13.551400882857186, 0.34281812022839275, 0.06754231891993966, 0.07769411882119519, 0.05323721295488732, 0.042195779005331654, 0.10719942022114992, 0.14200927769499166, 0.01950783428869077, 0.0565592627307134, 0.07404102877314601, 0.16213108439530644, 0.10356025371168341, 0.10696160726781402, 0.13908078840800694, 0.17384504154324532, 0.07950106436120612, 0.2468401017997946, 0.1851757892540523, 4.634570487907954, 60.45114122118269, 38.73141288757324, 46.236391476222444, 54.256259373256135, 77.41290991646903, 62.89763668605259, 0.9986183345317841, 2.268464812210628, 0.2598579318395683, 0.3189115401889597, 0.3413887454995087, 45.59634774071829, 93.60816723959786, 84.3785067967006, 81.80132961273193, 74.71501473018101, 80.0797119140625, 80.61784294673375, 82.50439698355538, 76.76913847242082, 78.98197296687535, 78.48518371582031, 78.92243385314941, 75.63198239462716, 75.13729844774518, 70.23887402670724, 67.88922950199672, 60.752915382385254, 56.64985472815377, 56.28780147007534, 56.237267221723286, 56.85680334908621, 57.26494748251778, 57.61552231652396, 54.34089885439192, 54.22732360022408, 51.821044308798655, 50.56672770636422, 49.67480829783848, 49.91609491620745, 50.453378268650596, 53.22689764840262, 51.3321065221514, 50.16596255983625, 56.11480869565691, 65.0194011415754, 66.4246951511928, 61.65676484789167, 63.588628087724956, 65.50253718239921, 64.91212095533098, 60.45462921687535, 64.78744942801339, 71.87502888270787, 59.63097585950579, 65.18519905635289, 56.493919781276155, 58.7220333644322, 52.350285121372764, 50.38036659785679, 54.30961806433541, 58.2249105998448, 59.61120128631592, 64.88030515398297, 58.19373403276716, 55.1936616897583, 53.08478266852242, 60.50054291316441, 54.382966722760884, 58.1735634122576, 60.98862607138497, 59.36945261274065, 58.535724367414204, 57.39652551923479, 59.92232772282192, 55.47441407612392, 55.586238384246826, 52.3784670148577, 49.832320485796245, 50.59335320336478, 52.84298883165632, 49.44133145468575, 54.90311929157802, 61.66055161612374, 55.392807483673096, 61.52490888323103, 57.561833586011616, 56.50919886997768, 59.56942176818848, 49.904901368277415, 43.95552716936384, 53.222614083971294, 57.25141933986119, 59.23956993647984, 54.1978771345956, 53.12070485523769, 45.11731808526175, 47.36320516041347, 51.52237599236624, 52.51321690423148, 51.95047882625035, 55.48361349105835, 57.31832354409354, 58.389972005571636, 49.50290986469814, 58.731580189296174, 48.168546540396555, 51.71447631290981, 60.62837587084089, 54.6843934740339, 56.644004344940186, 52.453764642987935, 49.67307819638933, 47.04485607147217, 46.67524317332676, 44.71052885055542, 45.810831683022634, 49.20082303455898, 47.72120067051479, 49.47500589915684, 49.06316532407488, 50.497412477220806, 48.955353600638254, 52.48964166641235, 50.51296949386597, 52.71798379080636, 56.313457693372456, 58.89955289023263, 62.067646571568076, 64.73090498788017, 64.09692355564663, 66.0530846459525, 70.38586316789899, 65.45560210091728, 73.44104862213135, 65.61247158050537, 71.44892365591866, 64.26110254015241, 66.90894290379116, 62.31983143942696, 75.12786974225725, 67.53395421164376, 77.42679241725376, 67.39833927154541, 82.23065880366734, 8.511746508734566, 0.3182475801025118, 0.22710514148431166, 2.279558479785919, 0.6483911818691662, 23.68821379116603, 92.91020679473877, 57.96396752766201, 72.01000458853585, 34.60506534576416, 50.83411175864083, 20.5067708832877, 0.5360757772411618, 0.30753112371478764, 0.19080931267568044, 0.1348004809447697, 0.16096993455929415, 0.14766089086021694, 0.17532791197299957, 0.11434157804719039, 0.2624759099313191], [0.06785853659468037, 0.043042013953839026, 0.012342881078698804, 0.036605352735412974, 0.04918169057262795, 0.044518740248999426, 0.19026705463017735, 0.07470092443483216, 0.11263008881360292, 6.172823922974723, 47.73465585708618, 34.16693278721401, 32.879080704280305, 46.4494823047093, 60.941767420087544, 51.31071996688843, 0.2595229798129627, 0.3953624335782868, 0.08889489993453026, 0.05266483813258154, 0.08414142964673893, 40.99289172036307, 81.68708733149937, 73.7398350579398, 69.61166013990129, 63.35902486528669, 69.36914716448102, 68.81125545501709, 72.99646813528878, 73.92449733189174, 74.57978888920375, 73.73828560965401, 73.04755823952812, 72.13364778246198, 68.94391741071428, 67.06030941009521, 63.41368634360177, 57.80975920813424, 50.87831967217581, 50.22831221989223, 49.99081236975533, 50.367154598236084, 50.3536889893668, 51.6003452028547, 48.67315598896572, 49.01829733167376, 43.182811055864605, 42.56849649974278, 43.07840394973755, 44.66016830716814, 46.64220448902675, 48.41048281533377, 44.73839112690517, 45.86508321762085, 51.954807553972515, 59.252729824611116, 59.033771242414204, 61.76268318721226, 55.535231658390586, 54.96585805075509, 54.30714797973633, 58.639106614249094, 46.25488410677229, 49.97177430561611, 67.6822704587664, 59.33108466012137, 58.73159408569336, 52.686442443302695, 49.127724511282786, 50.97537211009434, 49.41549457822527, 53.308427810668945, 54.560524463653564, 56.2798353603908, 53.468688011169434, 51.81358541761126, 45.167949608394075, 49.425204685756135, 47.64277982711792, 55.46606928961617, 54.790871143341064, 53.94634887150356, 56.37992416109358, 55.41539607729231, 51.983552251543315, 49.76311295373099, 51.26904814583914, 52.66394765036446, 52.54546349389212, 51.131418228149414, 55.13190957478115, 49.12604652132307, 46.93561996732439, 54.57725919995989, 51.7081048148019, 55.15289660862514, 53.905354499816895, 53.49627235957554, 53.02444103785923, 46.83495099203927, 42.053905963897705, 45.10306732995169, 49.95918764386858, 52.8277861731393, 50.31430312565395, 46.60938467298235, 45.15022822788784, 44.686738218579976, 45.3876690183367, 47.764164856501985, 49.76390504837036, 49.567142486572266, 50.7578934941973, 49.257430008479524, 50.378243923187256, 39.94133744921003, 40.58543198449271, 52.64785214832851, 52.0959324155535, 51.4754513331822, 51.436961787087576, 51.10291324343, 44.781921591077534, 41.128061975751606, 41.0856397492545, 39.793135847364155, 41.0841771534511, 38.634419509342735, 40.45691810335432, 44.24738277707781, 44.27433136531285, 43.8115222794669, 44.16882644380842, 45.15685680934361, 47.12364516939436, 45.39990827015468, 51.352238927568706, 53.4395055770874, 57.98306117738996, 57.1019983291626, 61.130508286612375, 58.06279175622122, 62.46235983712332, 59.83094501495361, 61.831338337489534, 61.12112127031599, 63.02556691850935, 62.735173906598774, 66.77027075631278, 61.87518841879708, 67.69053881508964, 60.52108178819929, 68.68257481711251, 62.44380119868687, 75.29698889596122, 16.33995529583522, 0.4793149658611843, 0.2101182887064559, 1.5853033789566584, 0.2839607713477952, 17.18396861212594, 70.78850432804653, 55.93869965417044, 47.74543251310076, 32.24669735772269, 22.5662899017334, 11.612087437084742, 0.28794521040150095, 0.07567414721207959, 0.05338453647813626, 0.015400504061420048, 0.07671472816062824, 0.19981278026742594, 0.07802007347345352, 0.0964254919173462, 0.032041302283427546, 0.08186477502541882, 0.048268545285931656, 0.06649051500218255, 0.05558450985699892, 0.0220374789953764, 0.05077607484002199, 0.1838401880647455, 0.11066265617098127, 0.36052628287247246, 12.885837282453265, 57.7024199622018, 41.731460911887034, 33.22836317334856, 50.915718351091655, 65.53476987566266, 55.714856488364084, 0.4416261725127697, 1.6237707776682717, 0.035240560969603915, 0.07500693015754223, 0.07401679828763008, 44.594712802342, 83.08994947160993, 77.73830795288086, 74.36645834786552, 67.19503498077393, 71.58983312334333, 70.75463880811418, 75.83474472590855, 77.08748408726284, 74.21549483707973, 75.90558855874198, 74.78059877668107, 74.88127817426408, 71.7186666216169, 69.19697080339704, 67.20406763894218, 60.152111598423545, 52.64100817271641, 53.789906706128804, 52.75819649015154, 52.783710275377544, 53.255750043051584, 52.35359941210066, 51.7657470703125, 52.04942117418562, 46.25283786228725, 45.19772611345564, 45.358292034694124, 46.23870522635323, 50.30178247179304, 50.6253843988691, 48.96648808888027, 47.244130407060894, 52.87075730732509, 61.33066504342215, 60.894123622349326, 63.50859178815569, 60.34584821973528, 58.94166592189244, 56.496646949223106, 61.29620197841099, 50.06530400684902, 49.34639821733747, 63.65382998330252, 60.71451963697161, 60.78496047428676, 54.24146318435669, 51.3992851802281, 52.92996638161795, 53.190416131700786, 55.36534125464303, 57.864205292293, 59.65363393511091, 57.177389757973806, 54.63576650619507, 48.34537124633789, 50.42628376824515, 49.48142603465489, 58.134507587977815, 55.78037800107683, 57.16644287109375, 57.39720644269671, 56.51504577909197, 53.555092334747314, 53.8748345375061, 50.359000887189595, 55.091113226754324, 53.23471089771816, 53.615718841552734, 55.543249879564556, 51.6828932762146, 46.48539406912667, 56.93099273954119, 53.756729057856965, 56.32522446768624, 56.69946486609322, 54.26098067419869, 54.74922711508614, 48.109222820826936, 42.72881228583199, 48.154226303100586, 53.568349497658865, 55.14905425480434, 51.48786776406424, 48.68028484072004, 47.44319977079119, 47.317562443869456, 48.890610286167686, 49.29917131151472, 51.10624490465437, 51.77993181773594, 51.48939289365496, 48.99553155899048, 48.34673656736101, 43.83062982559204, 46.407091345105854, 56.86819839477539, 56.38955783843994, 54.24784857886178, 54.17204025813511, 55.269640241350444, 46.28327097211565, 42.74615846361433, 42.634368896484375, 42.54865591866629, 41.93353884560721, 41.44159596306937, 43.935446875435964, 47.40479360307966, 47.81654037748064, 46.19157212121146, 47.45588370731899, 46.53384385790144, 48.97579867499215, 46.29273789269583, 54.19731780460903, 55.777008124760215, 60.44852869851248, 58.73415102277483, 63.83046708788191, 60.905511719839915, 63.99200575692313, 62.47123268672398, 63.98392500196184, 63.92171777997698, 68.32412420000348, 64.40326963152204, 70.30484717232841, 64.01824215480259, 72.05435494014195, 64.42624732426235, 74.15074457441057, 63.90044934409005, 80.44788306100028, 19.115541764668055, 0.5051784408943993, 0.1143989549683673, 2.6643662197249274, 0.32941317238977974, 18.503582647868566, 78.09938498905727, 60.187477929251536, 55.965193135397776, 32.96557535443987, 39.179443155016216, 23.70221962247576, 0.27717960093702587, 0.09323223148073469, 0.12344333822173731, 0.008639288517380399, 0.09253076197845594, 0.029901576028870683, 0.07706475044999804, 0.03488789917901158, 0.0638619517641408, 0.15416302052991732, 0.11168672157717602, 0.14371748960443906, 0.17853317569409097, 0.18885646175060952, 0.2531436378402369, 0.23057236043470247, 0.15401288787169115, 0.4081919294382845, 12.357439807483129, 70.6269726072039, 43.28799983433315, 42.74698529924665, 58.966130529131206, 74.11355086735317, 62.248070444379536, 1.0951703935861588, 3.484062795128141, 0.21369399183562823, 0.20772577423070157, 0.2871689663401672, 47.825632095336914, 88.1182496207101, 84.14449841635567, 80.59990269797188, 74.60685212271554, 77.18856648036412, 75.2683414731707, 80.36398356301444, 81.144898550851, 76.96018614087785, 80.1457336970738, 77.57126631055559, 80.27458109174455, 75.54516465323312, 72.69598633902413, 70.14968000139508, 65.33254255567277, 55.94120447976248, 55.85976116997855, 55.79100179672241, 56.00482218606131, 57.48579250063215, 55.45724507740566, 54.53451040812901, 57.311392715999055, 50.519441740853445, 48.12782314845494, 49.46284655162266, 49.064516748700825, 51.868344170706614, 54.545919350215364, 51.006100518362864, 47.50493104117257, 56.14043712615967, 63.81212384360177, 63.985530035836355, 66.61088602883476, 63.42386545453753, 63.17248657771519, 60.983401026044575, 66.72756712777274, 52.82213381358555, 62.70658901759556, 69.13019861493791, 61.91256972721645, 62.61258683885847, 56.344790594918386, 56.186302185058594, 55.19867134094238, 53.80381005150931, 59.26475020817348, 60.17255319867815, 62.33884171077183, 59.80567441667829, 57.78149046216692, 50.73704889842442, 54.898498739515034, 53.153243269239155, 58.70712947845459, 59.121665954589844, 58.18605279922485, 61.85351698739188, 59.37536552974156, 56.8802604675293, 54.13107715334211, 52.52762746810913, 56.08088411603655, 57.147540296827046, 55.31808655602591, 58.94952433449881, 50.95646606172834, 49.2752035004752, 58.81427070072719, 56.74071284702846, 58.72220706939697, 58.15207263401577, 56.02569110052926, 57.822842666081016, 49.15298816135952, 45.97317286900112, 50.29657827104841, 55.16077586582729, 58.23475272314889, 55.32312747410366, 52.08082355771746, 50.16074793679373, 50.65170764923096, 50.395273957933696, 53.32739986692156, 54.409387247903005, 54.34088495799473, 55.490856988089426, 52.28083092825753, 53.19720799582345, 49.23028687068394, 47.3340539932251, 58.04676921027047, 58.6089722769601, 57.929132734026226, 55.32212345940726, 56.487173080444336, 48.91104146412441, 45.87947988510132, 46.903564453125, 45.97844655173165, 46.5344865662711, 43.988527638571604, 45.64912278311593, 48.37199674333845, 49.23556750161307, 48.12486668995449, 48.52256073270525, 50.75522886003767, 52.08918571472168, 49.05265964780535, 56.90670878546578, 58.756190708705354, 63.51852076394217, 61.289052282060894, 66.34902232033866, 62.95934363773891, 68.74424702780587, 66.77186884198869, 68.17338303157261, 66.83839784349713, 70.6884572165353, 68.07817881447929, 73.47241279057094, 65.33290386199951, 75.7866770880563, 67.3225622177124, 77.72279957362584, 67.26641382489885, 86.10720470973423, 20.684940065656388, 0.5608937655176435, 0.5893795341253281, 3.949326983519963, 0.34209488332271576, 20.814550025122507, 87.0977121080671, 63.316793714250835, 70.57714012690953, 48.220501695360454, 49.55791527884347, 31.575185230800084, 0.4773935175367764, 0.19153351310108388, 0.24074552740369523, 0.13242332850183758, 0.23044702144605772, 0.20348558175776685, 0.15442530145602568, 0.19968009952987942, 0.16970471585435526], [0.04856566559257252, 0.002906953221619395, 0.025417465483769774, 0.029937049839645624, 0.06116905662098101, 0.0433709575528545, 0.12634901516139507, 0.13798533433250018, 0.3808272363884108, 16.323036432266235, 45.199977329799104, 31.059882504599436, 47.41402081080845, 39.71941893441336, 66.44700581686837, 51.42419794627598, 0.06036941667220422, 1.330050989985466, 0.051852804741689136, 0.12613579231713498, 0.26297113192932947, 44.03193303516933, 81.98887538909912, 70.58759716578892, 69.04957171848842, 59.83470399039132, 66.3876473563058, 67.83505439758301, 69.24968678610665, 69.69762325286865, 69.77519989013672, 71.34422125135148, 73.05563204629081, 71.05513450077602, 68.96784700666154, 68.58027648925781, 69.88736465999058, 64.3923887525286, 56.9827880859375, 49.2145630972726, 48.697874205453054, 49.68849624906267, 49.45895903451102, 48.212563378470286, 49.247108459472656, 48.157474585941856, 42.35814673560006, 40.884267057691304, 42.25805098669869, 44.10392679486956, 47.72562319891793, 47.9934276172093, 43.95909506934029, 46.060893876211985, 52.22760425295149, 58.77640996660505, 60.184149742126465, 56.98894418988909, 55.291568756103516, 57.13988338197981, 55.81155456815447, 53.15842662538801, 57.86752653121948, 45.170770577022004, 40.05687209538051, 58.69761044638497, 56.3596111025129, 55.928291252681184, 49.18532855170113, 52.344438212258474, 52.53668097087315, 53.472050939287456, 52.02965007509504, 55.527668544224326, 52.7506229536874, 52.10359280450003, 45.20795733588082, 45.108063084738596, 52.65103094918387, 53.97802223478045, 52.96006597791399, 56.94191183362688, 52.725810936519075, 52.18861791065761, 53.98751694815499, 55.38907977512905, 55.36073807307652, 54.27839633396694, 51.78932578223092, 51.10123872756958, 52.751185757773264, 53.682383332933696, 43.791813714163645, 54.16835423878261, 51.10527563095093, 53.42594269343785, 55.348550932747976, 50.74261787959507, 54.384245191301616, 44.41669300624302, 41.297052587781636, 45.529120445251465, 48.79734461648123, 53.071838174547466, 49.11944573266165, 48.37803472791399, 44.590318066733225, 44.45635332380022, 47.19487462724958, 48.107986041477744, 49.349014214106965, 51.19796807425362, 49.5506648336138, 46.93813521521432, 42.96835143225533, 48.98770441327776, 53.531200953892295, 53.24637344905308, 51.26507030214582, 52.37857471193586, 52.95089782987322, 53.334445340292795, 49.523118700299946, 40.90196411950247, 39.159592151641846, 39.567830085754395, 40.01152120317732, 38.773835114070344, 41.14187846864973, 43.398948669433594, 46.272056579589844, 44.223324639456614, 43.51227726255144, 43.52701786586216, 46.496796063014436, 47.99071781975882, 47.57637936728341, 53.08291360310146, 55.14354433332171, 56.927643707820344, 59.5715548651559, 58.6678443636213, 62.14010238647461, 59.92346027919224, 63.86039297921317, 64.38632992335728, 64.5349588394165, 65.55701800755092, 69.01670673915318, 69.29847008841378, 73.2075891494751, 66.01492513929094, 73.77062252589634, 66.34485340118408, 70.3549575805664, 33.51684890474592, 0.3257614869092192, 0.2940441817045212, 1.1384814466748918, 0.2884093283542565, 14.894141129084996, 68.53752422332764, 59.06657368796212, 45.32672984259469, 31.089520045689174, 19.816955464226858, 20.888025488172257, 0.38176822875227245, 0.0862852678235088, 0.08628608206553118, 0.04436835314014128, 0.06407258938997984, 0.04658501508778759, 0.03648926217907241, 0.03647939967257636, 0.06310698656099183, 0.05422686645761132, 0.02329183749056288, 0.01640775876252779, 0.0674929962094341, 0.054401416198483536, 0.0444340590786721, 0.13162054015057428, 0.09627151196556431, 0.5290065822856767, 22.14454640660967, 56.963419982365195, 36.0263923236302, 44.36346285683768, 44.78162281853812, 72.50351428985596, 56.56063291004726, 0.1756464977349554, 1.912844066108976, 0.004381188657134771, 0.2857563649969441, 0.2691311171012265, 45.22748524802071, 83.85682909829276, 75.37968635559082, 74.55273260389055, 63.1610289982387, 71.53254522596086, 72.95743315560478, 73.46064949035645, 73.31829479762486, 71.32068770272392, 75.19955430712018, 75.48106057303292, 74.48204857962472, 69.6669955934797, 71.28259767804826, 70.64623996189663, 66.85742895943778, 58.89317444392613, 52.19060509545462, 51.688959053584504, 52.451235498700825, 52.033367361341206, 53.58557408196585, 51.69546604156494, 50.922697816576274, 46.105518681662424, 44.25739165714809, 47.56853832517351, 47.34334373474121, 49.984315804072786, 50.8867895262582, 45.99733522960118, 47.79218694141933, 56.268600123269216, 60.53301184517996, 60.75219276973179, 60.456275939941406, 59.58251217433384, 60.29407719203404, 58.6932122366769, 57.80037219183785, 61.75777081080845, 50.117213998522075, 42.6564085824149, 57.166633946555, 57.8532966205052, 56.59800379616873, 50.522467681339805, 54.220382349831716, 55.83770063945225, 55.753599643707275, 55.73262650626046, 58.920286314828054, 57.20417506354195, 55.35309852872576, 46.75959777832031, 46.36551679883684, 57.56707600184849, 55.69502632958548, 56.59732287270682, 60.50041784558977, 55.148689474378315, 55.349228382110596, 56.694340569632395, 58.25062935692923, 56.18712902069092, 55.4805006980896, 54.55933632169451, 51.494044712611604, 56.188730580466135, 55.724392890930176, 44.16444560459682, 55.752116203308105, 52.519477231161936, 54.593118463243755, 57.07879829406738, 53.501573835100444, 54.77614443642752, 47.057929107121055, 44.375389439719065, 49.281366552625386, 53.08226047243391, 54.55276679992676, 50.4137943812779, 51.29257474626814, 47.94535650525774, 46.63803209577288, 48.13920429774693, 51.51052931376866, 52.02196536745344, 53.3820926121303, 51.587223529815674, 50.018632956913535, 48.573869705200195, 53.429920537131174, 56.44051592690604, 55.2671354157584, 53.15519571304321, 53.76837076459612, 55.83877066203526, 56.856066840035574, 51.03138153893607, 43.94539322171892, 43.10344178336007, 41.95285483769008, 43.66353954587664, 42.181725025177, 42.13862534931728, 44.876333713531494, 48.06502185549055, 45.54597677503313, 46.978413922446116, 46.44255495071411, 48.11299221856253, 48.54883534567696, 50.46776451383318, 55.80217797415597, 57.78893893105643, 60.14802605765206, 62.361458097185405, 61.50714233943394, 64.22743851797921, 60.99394144330706, 66.18525327954973, 66.82958057948521, 69.00768102918352, 67.0406460080828, 70.18014785221645, 70.04013470241001, 74.92059803009033, 67.49014581952775, 75.37496852874756, 68.1800046648298, 73.78110735757011, 37.830797808510916, 0.23538216948509216, 0.15127730609050818, 1.8176584137337548, 0.23364148288965225, 15.859570741653442, 78.38781860896519, 61.62631089346749, 56.844835077013286, 31.782095636640275, 33.68950121743338, 33.89237471989223, 0.27371253126433914, 0.08354938748691763, 0.025320826830076318, 0.08702890827719655, 0.011428483046724327, 0.025923189507531266, 0.036739146270390065, 0.04412429087928363, 0.0783072430640459, 0.11036222122077431, 0.11012365509356771, 0.08931647374161653, 0.17235124669969082, 0.1840543065752302, 0.11414086738867418, 0.19947383845491068, 0.27979443062629017, 0.7286531893270356, 27.983065571103776, 70.00720024108887, 37.4937024797712, 61.05066653660366, 55.156370707920615, 80.0595760345459, 63.9937983921596, 0.7073698256696973, 3.573767295905522, 0.1774409921573741, 0.5030953383871487, 0.5921979514615876, 50.52464941569737, 90.426253591265, 80.31565884181431, 79.52407836914062, 69.41891711098808, 78.05559744153703, 79.47949872698102, 78.15027359553746, 77.47965431213379, 73.21412740434918, 77.71358626229423, 78.64635413033622, 77.03489317212785, 73.50924519130162, 74.17110279628209, 75.91972814287458, 72.81262574877057, 62.80868584769112, 55.15922294344221, 56.35253436224801, 55.81936434337071, 55.1809777532305, 55.38537291118077, 54.25474466596331, 53.521598543439595, 50.12249115535191, 47.01251915522984, 50.91754572732108, 49.9073714528765, 53.025368622371126, 52.37437799998692, 48.341653960091726, 50.99578939165388, 58.07422154290335, 63.82742377689907, 63.58386857169015, 62.06586783272879, 62.58081272670201, 61.7937068939209, 60.20504297528948, 60.752651350838796, 61.69344438825335, 52.259117807660786, 52.55546195166451, 61.85774149213518, 61.1351774760655, 58.63213062286377, 52.86333315713065, 56.97044113704136, 57.97390692574637, 59.789346149989534, 58.158603940691265, 62.01064355032784, 59.553725787571494, 57.30843278339931, 50.07887731279646, 48.68120200293404, 59.18792397635323, 58.32554830823626, 58.7585391998291, 63.612884249006, 56.672703879220144, 56.6835743359157, 56.15285355704171, 60.06004796709333, 59.84860038757324, 58.924865177699495, 56.83442667552403, 55.11879137584141, 59.45024626595633, 58.70032024383545, 45.44058649880545, 58.179886272975374, 55.29647765840803, 58.45708465576172, 57.51496451241629, 53.81830051967076, 58.37530435834612, 48.69581753867013, 47.16228757585798, 54.22159481048584, 55.26760441916329, 57.16934721810477, 52.96967533656529, 54.41439689908709, 50.021523407527376, 48.468573229653494, 51.852985177721294, 54.460230691092356, 54.29316125597273, 54.64629302706037, 53.93865026746477, 54.227969782693044, 49.318334443228586, 53.94675186702183, 57.943727425166536, 57.43508454731533, 55.332795892442974, 58.8450095312936, 58.442014013017925, 61.108135087149485, 56.30989326749529, 45.965255396706716, 43.69883986881801, 44.889729840414866, 46.54668065479824, 44.9535698890686, 44.635304178510395, 47.64170285633632, 49.90534257888794, 47.513446058545796, 48.95415851048061, 47.85164267676217, 51.85716799327305, 52.14326701845442, 53.87877416610718, 59.17891911097935, 59.71638311658587, 63.12568351200649, 65.9304141998291, 64.0715834753854, 67.45188208988735, 64.17442376273019, 69.59483855111259, 70.85306004115513, 72.88736057281494, 70.12754304068429, 74.24906853267125, 74.82814529963902, 79.75105517251151, 69.7046548298427, 79.1461797441755, 71.18037578037807, 77.77753053392682, 42.38671425410679, 0.3871449130986418, 0.3092676576759134, 4.898268955094474, 0.3393777848354408, 18.387726647513254, 86.62247616904122, 65.6647845676967, 65.02367428370884, 44.77243035180228, 45.86255407333374, 42.83290324892317, 0.4783733221037047, 0.23264661484530993, 0.25004734684314045, 0.17401772870549134, 0.12775291768567903, 0.11069047610674586, 0.13608502915927342, 0.1686095739049571, 0.1897858375949519], [0.0425242340591337, 0.1107860409787723, 0.04883819918281265, 0.037822077982127666, 0.035770452714392116, 0.020411607310441986, 0.08301400300115347, 0.057755272303308756, 0.22798719629645348, 20.637061766215734, 52.43532412392752, 34.72026647840227, 45.83642189843314, 41.21904516220093, 73.2475551877703, 48.29081746510097, 0.31163099514586584, 0.3519321211746761, 0.08298725515071835, 0.10979552912924971, 0.4225812687405518, 48.0517612184797, 79.48518235342843, 68.85245132446289, 66.79621532985142, 61.953862871442524, 61.69683510916573, 62.37010165623256, 65.10567692347935, 65.79217978886196, 69.32315008980888, 72.73988505772182, 70.42270251682827, 69.22984967912946, 73.48256410871232, 69.62782859802246, 67.44271741594586, 64.5610910143171, 65.27333000728062, 54.86892025811331, 50.9057685307094, 49.12652594702584, 48.46904918125698, 48.562745639256065, 51.59069068091256, 47.41570922306606, 42.767565863473074, 39.96599660600935, 41.94912018094744, 45.91985239301409, 49.48919759477888, 48.714751379830496, 44.41319458825247, 45.069302558898926, 51.93296589170183, 58.867799622671946, 56.54695190702166, 57.55486454282488, 61.179333278111045, 60.1174817766462, 57.99465077263968, 59.933410099574495, 55.96742698124477, 59.51619856698172, 48.78057861328125, 46.14160762514387, 56.5903434072222, 56.66192374910627, 50.86974906921387, 51.222641127450125, 51.43432494572231, 52.95462901251656, 54.62676511492048, 55.16293675558907, 54.62993696757725, 52.44169562203543, 44.643527371542795, 45.940898486546104, 54.01420497894287, 50.20932279314314, 56.39259420122419, 57.814765385219026, 54.91384036200387, 53.556575775146484, 55.21423530578613, 48.939164297921316, 50.818106583186555, 53.727942671094624, 53.8666877746582, 55.78587055206299, 54.18083667755127, 47.65718691689627, 46.515514510018484, 52.244272981371196, 52.5135816846575, 50.08600269045149, 52.58817407063076, 54.72533573423113, 50.99430595125471, 42.10353347233364, 42.453611510140554, 45.65907607759748, 52.66991267885481, 51.71150595801217, 50.7463629586356, 48.348348549434114, 47.298677240099224, 46.2009973526001, 47.178216321127756, 47.869718415396555, 48.397434098379954, 50.42350448880877, 54.23833302089146, 53.49575471878052, 54.52555070604597, 53.71378919056484, 52.015718936920166, 54.365165437970845, 53.81571231569563, 49.80346809114729, 52.247187750680105, 52.57088347843715, 49.43357031685965, 41.68174307686942, 41.318463461739675, 40.550041334969656, 39.33973462241036, 38.24589361463274, 40.53856985909598, 40.299927030290874, 45.84164694377354, 45.25500706263951, 44.68593222754342, 43.08196142741612, 44.10132816859654, 44.73219680786133, 47.9873548916408, 49.994487966809956, 56.12236833572388, 57.009392738342285, 59.336406980242046, 58.3993034362793, 63.318259784153526, 61.134218624659944, 63.5085084097726, 64.0844167981829, 64.11281408582414, 63.837943349565776, 66.01117311205182, 66.28310476030622, 66.9259729385376, 67.36573832375663, 70.75556291852678, 68.27832862309047, 71.67938845498222, 39.15234170641218, 0.5338779208915574, 0.15928331363414014, 1.5149004310369492, 0.4521360828408173, 12.122552480016436, 67.10905797140938, 61.32484245300293, 49.658090932028635, 36.85414859226772, 20.10840286527361, 27.510329246520996, 0.35553698773894993, 0.10611602371292454, 0.07324553467333317, 0.04437096889263817, 0.06123162433505058, 0.01733894120635731, 0.03935127539028015, 0.0375514646459903, 0.04627055821142026, 0.04688407939725688, 0.022498190702338303, 0.0328505468953933, 0.0054088617492068026, 0.04170502516041909, 0.02070884805704866, 0.04402117391249963, 0.0426004912172045, 0.08062859957239457, 31.128909383501323, 62.56718036106655, 40.70643833705357, 45.45621994563511, 48.35964632034302, 78.6857990537371, 55.002249240875244, 0.3058396987617016, 0.4972260647586414, 0.13217084562139852, 0.056292958091944456, 0.311817293720586, 53.63683441707066, 83.47471291678292, 73.99727971213204, 68.93553788321358, 67.13044452667236, 66.25742421831403, 67.4041062763759, 67.9227545601981, 68.57766396658761, 72.09409863608224, 76.69646031515938, 72.8755555834089, 72.27211148398263, 74.63260909489223, 73.8565092086792, 69.22884913853237, 67.8441217967442, 66.87620299203056, 59.5313595363072, 52.1873950277056, 53.11664710726057, 51.26567479542324, 51.04426349912371, 53.47327382223946, 49.17506258828299, 45.27457318987165, 42.93325955527169, 46.76981163024902, 47.10718836103167, 51.3475593158177, 51.07079866954258, 46.60833549499512, 47.091836316244944, 55.318201201302664, 62.11142717088972, 59.230724879673545, 60.83822536468506, 63.6908916745867, 61.76121016911098, 59.2815648487636, 61.52908475058419, 57.81971250261579, 62.50173527853829, 54.426545824323384, 49.10109901428223, 59.531123297555105, 60.79182529449463, 55.25120319638933, 52.745474338531494, 53.272401400974815, 56.389345918382915, 59.01146752493722, 58.27414206096104, 57.140859603881836, 56.127708026341026, 47.18836416516985, 47.33424506868635, 56.152190004076274, 54.03397955213274, 58.11812373570034, 59.06723376682827, 58.406015396118164, 56.27026769093105, 56.61733715874808, 50.84368290219988, 49.51409299033028, 56.64701638902937, 55.54122795377459, 58.92019598824637, 54.79746845790318, 47.68609489713396, 46.33253370012556, 52.357389654432026, 53.80869116101946, 52.35876192365374, 54.56862606321062, 57.498521600450786, 52.03216879708426, 42.796157700674875, 46.086525780814036, 47.23895399911063, 55.21868910108294, 53.18322822025844, 54.89459037780762, 51.6207138470241, 49.680231366838726, 49.40900843484061, 48.510067871638704, 48.75960200173514, 50.55599968773978, 50.92670692716326, 55.50336027145386, 56.09873056411743, 55.8630302974156, 54.78066076551165, 54.17524685178484, 56.94218281337193, 55.29751641409737, 53.54539264951433, 54.98277691432408, 55.041221686771934, 50.83634213038853, 43.06086322239467, 42.97997229439871, 44.133404527391704, 42.5843140738351, 39.28289835793631, 42.67747204644339, 43.55571392604283, 47.5365001814706, 47.773006439208984, 47.60807357515608, 46.29808105741228, 47.48699426651001, 46.83282484327044, 50.61336054120745, 53.324050835200715, 59.20097964150565, 60.3822637285505, 62.06957817077637, 61.472547258649556, 65.36863844735282, 64.24110562460763, 67.25273282187325, 64.07113184247697, 66.41135460989815, 66.36344678061349, 68.70347499847412, 68.12940093449184, 71.33951037270683, 69.15556648799351, 73.58200672694615, 70.05223151615688, 75.47146511077881, 44.202271597726, 0.5580774109278406, 0.2262662143579551, 2.3795254698821475, 0.3914843616741044, 14.46548330783844, 76.2037079674857, 64.72904981885637, 57.97806542260306, 38.60227714266096, 32.40373011997768, 40.28001349312918, 1.2694068955523627, 0.15570949683231966, 0.09203792842371122, 0.038796325347253253, 0.02703060954809189, 0.0360486385013376, 0.029432409775576422, 0.007958943506569734, 0.11372288981718676, 0.17341730663818972, 0.19965781643986702, 0.11978828720748425, 0.23474692500063352, 0.153420268957104, 0.10840720576899392, 0.15482926049402781, 0.3065412768295833, 0.28385467561227934, 38.12205239704677, 74.3767694745745, 46.054067271096365, 61.64969852992466, 57.82372161320278, 86.11538273947579, 61.22923524039132, 0.7032074204513005, 1.69129521719047, 0.34989271632262636, 0.45511341307844433, 0.6979686415621212, 60.419693674360005, 90.80451352255685, 82.80292633601597, 75.34381280626569, 75.96484279632568, 69.82576887948173, 71.37636361803327, 70.75931494576591, 74.41669382367814, 77.2491408756801, 83.33602687290737, 75.90655435834611, 73.82972390311105, 77.81217425210136, 77.74451964242118, 71.85067544664655, 69.91074534824916, 69.70913641793388, 62.443419047764365, 55.63007804325649, 56.08215911047799, 55.12174783434187, 54.195101329258506, 57.293400355747764, 53.32269593647548, 49.918165479387554, 45.572296551295686, 49.43132952281407, 51.540378774915425, 54.942060470581055, 52.833931854793, 48.13627910614014, 50.911660603114534, 56.38688278198242, 62.22927556719099, 60.897785323006765, 63.6284065246582, 66.38300595964704, 63.86024011884417, 61.49467032296317, 64.47245979309082, 60.86814430781773, 63.91894544873919, 53.19650622776577, 53.44102723257882, 62.44277286529541, 63.43309266226632, 55.570629256112234, 56.540990352630615, 57.20116996765137, 57.675151756831575, 61.78099863869803, 61.12596416473389, 59.7482545035226, 57.14911753790719, 49.10484756742205, 50.07677548272269, 58.33041899544852, 57.305458954402376, 60.039029666355674, 63.74122442517962, 60.89197662898472, 58.396961893354145, 58.64044761657715, 53.21530110495431, 50.971463748386924, 55.83745050430298, 59.48379216875349, 61.61509650094168, 56.498672349112375, 50.42822926385062, 47.52557066508702, 55.859132358006065, 56.73293433870588, 55.23558712005615, 57.93811675480434, 61.25995322636196, 54.559864384787424, 43.62668282645089, 48.177353382110596, 51.66592924935477, 57.949841839926584, 56.1399507522583, 57.28932523727417, 54.56873723438808, 53.03372035707746, 52.55838714327131, 51.98564713341849, 52.28467328207833, 53.683599267687114, 55.08411291667393, 58.100867884499685, 58.44353566850935, 57.535444327763145, 56.70136867250715, 57.406517028808594, 59.42629582541329, 58.80218778337751, 57.460747718811035, 58.29610879080636, 56.371937206813264, 52.78645133972168, 45.68328707558768, 46.76760557719639, 44.93158578872681, 44.85851853234427, 42.55369683674404, 46.0413555417742, 45.91178900854928, 50.27779729025704, 51.85245711462838, 50.99330193655831, 48.903818811689106, 49.71656002317156, 48.49027245385306, 52.37217889513288, 55.47080101285662, 61.3515304837908, 63.56808921269008, 64.86043330601284, 64.45973764147077, 69.49754292624337, 67.21398966653007, 70.63278130122593, 68.35024942670549, 71.42692565917969, 69.20689977918352, 70.99139867510114, 71.04663685389927, 73.89243834359306, 73.0758443559919, 77.64994771139962, 73.03967203412736, 79.50829206194196, 49.53966930934361, 0.7172090719853128, 0.28293976613453453, 4.561940968036652, 0.48257823075566975, 17.057438441685267, 84.05160794939313, 69.27634702410016, 66.76396874019078, 54.5441267149789, 46.71245772497994, 51.02539913994925, 2.4146774922098433, 0.37797996774315834, 0.18053783955318586, 0.13066015525587968, 0.09274631219783, 0.1930492381964411, 0.10336736656193223, 0.14133325325591223, 0.256023856145995], [0.02283411642669567, 0.03835908077391131, 0.0650504669174552, 0.05851512295859201, 0.06528035458177328, 0.09124688551362072, 0.11250958099429097, 0.01239618000441364, 0.04827663342335394, 31.731217452457972, 44.39307260513306, 37.88152313232422, 39.93149185180664, 45.072724546704976, 68.917542048863, 54.19904443195888, 0.12355012606297221, 0.12437507536794458, 0.28724813780614306, 0.06376239032085453, 2.790471247264317, 46.78480931690761, 69.06402397155762, 63.26013810294015, 63.28473472595215, 63.543888636997764, 67.18591199602399, 66.83534063611711, 66.51035949162075, 60.65389660426548, 62.391634123665945, 66.8904676437378, 67.84738050188336, 68.74483067648751, 69.91385119301933, 68.25892925262451, 67.8490411213466, 65.14358629499162, 66.56718185969761, 63.12762900761196, 50.25480570111956, 48.46985864639282, 49.69314806801932, 47.80292190824236, 49.40877914428711, 45.07742152895246, 41.88984162466866, 40.62372350692749, 43.25350202832903, 45.93996047973633, 48.94710956301008, 47.51208768572126, 43.730725152151926, 45.82940421785627, 54.618545395987375, 59.68773569379534, 57.6083413532802, 57.311632428850444, 59.63159424918038, 57.66215515136719, 60.08046177455357, 56.69606024878365, 58.75674656459263, 56.06027923311506, 56.725982666015625, 55.98458555766514, 57.933378083365305, 56.65509366989136, 53.90785585130964, 51.55750608444214, 49.45855256489345, 55.34964527402605, 54.76127529144287, 54.60681683676583, 56.68585681915283, 57.668849740709575, 49.261790003095356, 48.77230678285871, 51.72137587411063, 51.49324566977364, 54.26937409809658, 55.69035366603306, 55.126281533922466, 55.20803056444441, 56.01073162896292, 54.335434096200125, 48.31302738189697, 53.349502086639404, 51.568049975803916, 53.47904430116926, 47.87232746396746, 43.464456285749165, 39.949383463178364, 49.04578440529959, 53.81028924669538, 54.12988206318447, 52.773565905434744, 50.536985942295615, 51.472241265433176, 38.05424492699759, 42.72816957746233, 46.43801082883562, 50.57478414263044, 51.172158990587505, 51.96225949696132, 49.08677877698626, 47.986125060490195, 47.44200815473284, 44.99075664792742, 46.44892297472273, 49.31570455006191, 49.90694413866316, 49.64100531169346, 53.28590522493635, 52.15199395588466, 51.93410192217146, 53.729957648685996, 51.91335112707955, 54.4680300440107, 51.541973386492046, 50.66939776284354, 54.4854804447719, 51.08658150264195, 42.62632983071463, 39.53486435753958, 42.66248825618199, 41.57612351008824, 38.439480849674766, 38.227991580963135, 38.00876201902117, 43.700479643685476, 44.34785025460379, 44.54066971370152, 43.917593479156494, 45.0746248790196, 45.31977122170584, 47.562733105250764, 47.57665729522705, 52.59219012941633, 56.701278345925466, 57.76898717880249, 58.87027318137032, 58.3757073538644, 59.15428079877581, 58.3099148614066, 58.902485030038015, 58.661695207868306, 59.33651120322091, 64.21712739127022, 65.47951085226876, 68.38954843793596, 67.34399046216691, 70.15309851510185, 66.91871207101005, 71.55332728794643, 41.79303584780012, 0.5777032492416245, 0.23764999636581965, 0.5339798639927591, 0.5468484163284302, 17.661221265792847, 69.84393841879708, 61.73555047171456, 52.3833064351763, 38.73769753319876, 22.603839703968593, 28.035583530153545, 0.736722924879619, 0.052765376666294675, 0.023469299843002642, 0.06557737650083643, 0.04704302961805037, 0.032890102094305415, 0.018754002239022936, 0.01997794709833605, 0.04531915033502238, 0.05222888616845012, 0.07251604167478425, 0.048501486357833655, 0.04024930291676095, 0.019019899756780694, 0.08736033870705537, 0.017865738831460476, 0.024945786954568963, 0.09622350561299495, 46.985289164951865, 48.725514139447895, 37.34533759525844, 37.729892594473704, 52.57533379963466, 73.58471652439663, 61.86446040017264, 0.11597646746252264, 0.2565576732158661, 0.4968859830072948, 0.04775648544143353, 2.9805099070072174, 51.34738908495222, 77.70938260214669, 73.54938493456159, 67.67274447849819, 68.38453878675188, 70.13139234270368, 70.68934658595494, 68.93866457257951, 63.732261248997276, 65.56189564296177, 69.31973157610211, 70.83856609889439, 69.54388046264648, 71.08294813973563, 71.39899390084403, 70.75888415745327, 68.1406500680106, 70.43211732591901, 64.99315084729875, 51.93454313278198, 51.66567216600691, 52.784346035548616, 50.2985063961574, 51.921834877559114, 49.38368919917515, 45.505538259233745, 43.29824842725481, 46.745989731379915, 48.93408863885062, 50.844426359449116, 49.30198185784476, 46.42978763580322, 48.32739973068237, 54.297128677368164, 60.864823068891255, 59.11196626935686, 57.912978172302246, 60.37248066493443, 59.12698827471052, 62.12186336517334, 58.0485965864999, 60.09568527766636, 58.80863571166992, 60.324517250061035, 59.9034286226545, 61.126186507088796, 59.74972752162388, 56.234307289123535, 55.23683432170323, 52.65160764966692, 57.714676584516255, 56.20854336874825, 59.11842114584786, 56.36089651925223, 60.77783162253243, 50.43983275549752, 49.7920035634722, 53.91515493392944, 54.954862526484895, 58.09294693810599, 58.90720285688128, 54.652032239096506, 54.937568460192, 57.92543976647513, 55.66306114196777, 48.30886888504028, 54.663847650800435, 52.63536623546055, 54.73053298677717, 49.878480843135286, 44.47478689466204, 38.28183317184448, 49.1001158441816, 55.94069378716605, 56.71499061584473, 54.63402598244803, 53.738806179591585, 52.01101500647408, 40.28490849903652, 43.984052998679026, 49.98504536492484, 53.934964248112266, 53.59536061968122, 54.412774494716096, 52.376580578940256, 49.05059950692313, 51.26573732921055, 49.766712120601106, 49.67761884416853, 49.83903591973441, 52.119709151131765, 51.75955622536795, 54.072288445064, 55.23214428765433, 52.31681564876011, 54.55174194063459, 54.09544679096767, 56.904725074768066, 54.76919623783657, 52.363191400255474, 57.41061994007656, 54.08169978005545, 45.59387418201992, 42.74591180256435, 42.781879152570454, 42.072676522391184, 41.08462878635952, 40.6599931035723, 41.02431147439139, 46.260908194950645, 46.88120515005929, 46.700260162353516, 44.84323944364275, 47.09967735835484, 48.5311313356672, 48.65019219262259, 48.302462645939414, 54.14633192334856, 57.86232927867344, 59.74080603463309, 59.8037497656686, 60.79725183759417, 60.68804700034005, 60.98563139779227, 60.70468098776681, 62.0667085647583, 62.56628404344831, 67.7841032573155, 68.08967808314732, 72.29924419948033, 69.62726579393659, 71.93508216312954, 70.50478853498186, 73.80257729121617, 47.04301132474627, 0.6919126893792833, 0.220179035993559, 0.37977246727262226, 0.4246050130043711, 20.391680921827042, 78.36731447492326, 65.83247934068952, 61.93494987487793, 39.70675236838204, 32.84769916534424, 41.58056688308716, 2.032946067196982, 0.14082675400589192, 0.07238116926912751, 0.027406541697148765, 0.06486626501594271, 0.04021103014903409, 0.016121742681467106, 0.02810017072728702, 0.09870355110615492, 0.11406544143600122, 0.1707198042422533, 0.10612378615353789, 0.12655022793582507, 0.1479262387646096, 0.2251965988959585, 0.1631857313747917, 0.16846583304660662, 0.08999833358185631, 53.48880304609026, 60.21843910217285, 45.9588109425136, 53.13349996294294, 61.53428200313023, 80.48768929072789, 69.79495361873082, 0.4758278929761478, 0.9607871302536556, 0.9722728282213211, 0.15805847650127752, 2.88599898985454, 63.19849368504116, 85.19246741703579, 84.63399900708879, 75.03896754128593, 76.18552453177315, 76.56866904667446, 76.2588836124965, 73.46861212594169, 68.78569998059953, 69.61241749354771, 73.79215499332973, 71.85662310464042, 73.06858348846436, 75.33410617283413, 73.84801156180245, 73.14315850394112, 71.65650803702218, 73.35171563284737, 70.7999827521188, 56.28079073769705, 54.92986985615322, 55.80832365580967, 53.96704755510603, 56.235651765550884, 52.46141113553728, 49.086493900844026, 45.50153957094465, 49.12309353692191, 51.50516530445644, 53.905507360185894, 52.33935213088989, 48.01181602478027, 49.60472876685006, 56.49484041758946, 62.418030330113, 62.6379269191197, 62.80157784053257, 62.14106123788016, 63.076670919145855, 63.66210528782436, 61.95386981964111, 64.10845061710903, 61.86632946559361, 63.532931327819824, 61.002925464085166, 67.13803890773228, 62.82051862989153, 58.25802224023001, 57.43311125891549, 54.235525948660715, 61.21121161324637, 59.971382004874094, 60.454893248421804, 60.924883297511506, 61.27437768663679, 51.29558679035732, 51.81063938140869, 54.9535527910505, 55.603327478681294, 60.30255399431501, 59.69728946685791, 56.36763974598476, 55.891205242701936, 61.174316678728374, 58.75985935756138, 50.7749547958374, 57.82832132066999, 53.80560616084507, 57.562278270721436, 50.7646540914263, 44.663437434605186, 38.89140905652727, 50.23607683181763, 59.14640154157366, 58.86881405966622, 55.45227711541312, 55.416962896074565, 53.2371358190264, 40.184618200574604, 44.29107304981777, 54.296965394701274, 57.87772648675101, 53.79354061399187, 57.34338917051043, 55.39406163351876, 51.81496810913086, 53.84295620237078, 50.73134095328194, 51.32017299107143, 54.00815657206944, 55.07762329918997, 54.388584341321675, 56.783461638859336, 57.65855598449707, 54.88198634556362, 58.59704221997942, 57.26485020773751, 59.19214153289795, 57.19677523204258, 56.807874134608674, 59.52472400665283, 56.394105434417725, 47.875506264822825, 43.68185499736241, 46.299984863826204, 45.46689237867083, 42.89392927714756, 44.694739069257466, 43.40090111323765, 49.21519538334438, 49.24270330156599, 49.81565523147583, 48.4299099785941, 49.31536061423165, 51.66239261627197, 52.717664173671174, 51.82455662318638, 56.85928733008248, 61.97754233224051, 62.965520586286274, 63.43469769614083, 65.04860442025321, 65.62930706569126, 65.53014237540108, 64.83309214455741, 65.42487021854946, 64.15330818721226, 73.10025337764195, 72.52162824358258, 76.2595853805542, 72.14090170179094, 78.0475514275687, 72.43137114388603, 78.20144707815987, 52.123902388981406, 0.6977823429874012, 0.2987338900566101, 2.1997314946992055, 0.4860978733216013, 22.67369168145316, 87.0026468549456, 71.91976833343506, 70.73593425750732, 53.0849598475865, 41.527242933000835, 54.813928740365164, 3.7191496661731174, 0.4843036638838904, 0.14013192057609558, 0.15602895111909934, 0.13964671375496046, 0.11150781903415918, 0.13348444870540074, 0.09988129790872335, 0.1027782896001424], [0.07985096451427255, 0.03527113236486912, 0.01883583695494703, 0.013038146226400775, 0.031095723022839854, 0.05047292235706534, 0.024636130713458573, 0.053367654526872296, 0.7567337911043848, 46.79858064651489, 36.03862115315029, 25.339745010648453, 37.56680795124599, 48.465349265507285, 69.57901055472237, 54.416880880083355, 0.10791047063789197, 0.2670641637274197, 0.3862549737095833, 0.021103943731369715, 13.704638191631862, 51.28574814115252, 57.023910999298096, 58.96311501094273, 59.349351474217, 65.66923836299351, 67.0047516141619, 70.24702426365444, 71.01619679587228, 63.048176356724326, 59.16493933541434, 64.65436363220215, 65.65278502873012, 67.44134862082345, 65.60594722202846, 67.05313886914934, 65.76521383013043, 66.57820170266288, 65.65969848632812, 63.46018368857247, 54.737946714673726, 47.94312613351004, 48.629906926836284, 47.694672448294504, 48.958087716783794, 43.02039343970162, 39.16669321060181, 40.745796407972065, 44.43173238209316, 47.795198985508506, 47.69465160369873, 48.09442663192749, 46.979407514844624, 45.84011486598423, 56.632564135960166, 58.63067844935826, 55.90298243931362, 55.40323325565883, 58.73284476143973, 56.28204836164202, 59.682545389447895, 54.876538957868306, 55.282949515751426, 56.44452851159232, 57.59745352608817, 55.2382378578186, 57.933593477521626, 56.41909463065011, 54.75179100036621, 52.96736853463309, 49.351029191698345, 52.669051102229524, 54.35435404096331, 54.42662225450788, 56.405212129865376, 59.11581557137625, 49.92772272654942, 45.68497201374599, 48.806283473968506, 54.75983006613595, 56.974405084337505, 55.02562992913382, 54.68653351919991, 55.02776302610125, 56.401943002428325, 43.855757985796245, 43.57122230529785, 55.29137420654297, 54.153561523982454, 53.63874169758388, 51.379972662244526, 42.66620554242815, 40.53696135112217, 36.935428619384766, 52.34935406276158, 56.842931270599365, 52.429529326302664, 55.289286272866384, 50.56215579169137, 41.4179755619594, 38.52426624298096, 44.037953649248394, 50.685604436056956, 50.83675554820469, 49.48290252685547, 51.89475079945156, 50.02261080060686, 47.46630253110613, 48.52088621684483, 47.68184954779488, 46.650445052555625, 47.71283851351057, 52.431672845567974, 52.96216433388846, 54.21702984401158, 51.444601331438335, 51.714247022356304, 52.98406505584717, 52.98850842884609, 52.23232207979475, 49.21596315928868, 52.2311235155378, 53.5016850062779, 44.39518485750471, 40.685836928231375, 41.28523022787911, 40.561908858163015, 40.64718409946987, 38.623521259852815, 36.32387944630214, 41.11593042101179, 43.13150208336966, 43.70169905253819, 44.33817488806588, 43.42048808506557, 43.98121813365391, 44.89266892841884, 46.39189910888672, 45.49807936804635, 49.87051820755005, 49.931422642299104, 50.498465129307334, 49.48180818557739, 50.51015894753592, 51.48721463339669, 52.55834892817906, 53.063861642565044, 59.01160648890904, 62.775320598057334, 63.764514786856516, 64.78198119572231, 67.23175621032715, 68.74239880698067, 69.84370218004499, 65.62201145717076, 46.43726737158639, 1.0273300281592777, 0.32376151851245333, 0.5660649080361638, 0.18261986997510704, 15.301573072160993, 67.22511373247418, 61.37490422385079, 54.745930194854736, 34.48962450027466, 22.914891447339738, 29.75767891747611, 2.4135173601763587, 0.07173085452190467, 0.029955322787697827, 0.01580238338959004, 0.01799805316009692, 0.043116361035832336, 0.033189984038472176, 0.03761108751807894, 0.002107498809761767, 0.044094001076051166, 0.04197193708802972, 0.07771849858441524, 0.03769711897309337, 0.03534858713724783, 0.025388156163639257, 0.038569443593067784, 0.09719647054693528, 1.1022983768156596, 61.231958934238975, 45.69338280814034, 25.66587781906128, 37.22570698601859, 54.885849543980186, 76.9453934260777, 60.40982028416225, 0.2993533382458346, 0.3248419091105461, 0.8187968922512872, 0.0419717979883509, 15.43400400025504, 63.98218100411551, 67.79533154623849, 69.95670768192836, 68.02422605242047, 72.41930907113212, 72.4347757611956, 73.48138291495187, 72.02091326032365, 67.15448529379708, 61.8774813243321, 66.8751677104405, 67.86148534502301, 69.25119454520089, 65.56375081198556, 69.73560210636684, 67.66745689937046, 67.96519415719169, 68.4737606048584, 65.45798533303397, 58.01025990077427, 51.13932875224522, 52.494283063071116, 50.66416229520525, 51.699565478733604, 46.250833306993755, 42.19021919795445, 44.409268856048584, 48.617361954280305, 49.30599791663033, 52.31374454498291, 49.55578565597534, 49.780973298209055, 48.04534108298165, 56.37399387359619, 61.06707123347691, 59.131803376334055, 56.871821880340576, 58.62336894444057, 58.36875915527344, 61.0094359261649, 59.14449773515974, 57.886161599840435, 60.453239577157156, 59.77462986537388, 59.99941798618862, 60.50899192265102, 59.12918390546526, 55.367210320064, 53.00357212339129, 51.64211082458496, 55.6730318069458, 55.30341196060181, 56.97503389630999, 59.2404454095023, 60.208482333592, 53.0278491292681, 46.97329657418387, 51.24884973253523, 57.20755883625576, 59.285219601222444, 57.07642201014927, 56.588196413857595, 57.83143411363874, 58.49658516475132, 43.33666501726423, 43.364099979400635, 53.262326513017925, 54.8107464654105, 54.41535922459194, 50.67459848948887, 41.857515130724224, 40.41087586539132, 35.697051184517996, 50.95368678229195, 60.15244511195591, 53.67109251022339, 56.093356132507324, 51.27450942993164, 44.33542340142386, 39.19203329086304, 45.69685690743582, 52.6672272000994, 54.77437611988613, 52.473605224064414, 53.38036598478045, 54.171922138759065, 51.25420331954956, 51.570151805877686, 50.37903254372733, 48.94727979387556, 50.626853942871094, 54.92459964752197, 57.468515804835725, 55.092419488089426, 51.56328351157052, 53.17894812992641, 55.32208177021572, 55.296310901641846, 54.63296290806362, 52.85871607916695, 55.03935956954956, 54.77560247693743, 47.66545179912022, 43.72257144110543, 43.59943546567644, 42.13358790533883, 44.298729964665, 40.83110639027187, 41.3861597606114, 43.520021029881065, 46.34313317707607, 46.35401405606951, 45.85629374640328, 46.734285490853445, 48.74782133102417, 48.82966068812779, 49.48261765071324, 47.30580261775425, 51.545496123177664, 52.00291688101632, 52.99662739889962, 52.98141431808472, 53.51993097577776, 54.46978793825422, 56.10864216940743, 56.604146003723145, 61.62395545414516, 65.74157605852399, 66.5933279309954, 69.0084731238229, 70.04263605390275, 73.14205374036516, 71.62610271998814, 68.75533635275704, 52.165146895817344, 1.4593940951994486, 0.3259430628802095, 0.5553854182362556, 0.12518356341336453, 13.459306853158132, 75.5142799104963, 64.72545760018485, 63.70108468191964, 38.75523131234305, 32.07906859261649, 43.75980683735439, 5.301465971129281, 0.11240859462746552, 0.028172354978908385, 0.07478616878922496, 0.026619300279500227, 0.04779657329033528, 0.04245586147797959, 0.02280069518435214, 0.09488198759832553, 0.20966352096625737, 0.11740991340151855, 0.2084295643227441, 0.22457263166350977, 0.1965799137417759, 0.17066022886761598, 0.14695046469569206, 0.09131485436643873, 1.180856772831508, 76.37924030848912, 48.497008732386995, 31.651730060577393, 51.832963943481445, 64.57828085763114, 83.40361200060163, 70.18528951917375, 0.41196162572928835, 0.875810335789408, 1.5957844108343124, 0.09207038275365319, 18.70793785367693, 75.21010862077985, 77.6355232511248, 81.1794797352382, 75.79599462236676, 80.68214852469308, 77.94260583605084, 81.42476504189628, 78.48742798396519, 70.32566397530692, 65.75744574410575, 70.85927173069545, 73.0182021004813, 71.43337358747209, 70.80536760602678, 71.89913218361991, 71.6508799961635, 71.74828679221017, 71.72728933606828, 68.38025174822126, 61.60759939466204, 52.99400792803083, 55.110898222242085, 52.841748578207834, 55.07326677867344, 49.69055986404419, 44.594143050057546, 47.96431119101388, 52.37183495930263, 52.27945518493652, 53.63064009802682, 52.37291887828282, 52.37872757230486, 49.657951968056814, 60.08684022086007, 63.48432173047747, 62.67059734889439, 59.672074454171316, 61.31106417519705, 60.90535191127232, 65.48641041346959, 59.19151619502476, 59.8054381779262, 61.47130353110177, 61.347236497061594, 63.50285257611956, 62.41962146759033, 61.19947610582624, 56.973751953669954, 56.91003349849156, 54.71906498500279, 58.60872909000942, 61.08892331804548, 59.9160396030971, 62.89995043618338, 63.55089936937605, 52.98992933545794, 47.97993074144636, 51.390971660614014, 59.153189931597026, 61.76649080004011, 61.09350912911551, 58.793252399989534, 59.04005241394043, 61.46338258470808, 43.13391310828072, 43.58843299320766, 56.35065834862845, 59.596790722438264, 57.61273261478969, 51.00241449901036, 42.2768771307809, 40.47160312107631, 38.33666140692574, 54.81375503540039, 61.89474759783064, 58.21919223240444, 58.100576060158865, 53.01387977600098, 44.72485951014927, 41.460905006953645, 47.621518339429585, 54.249675955091206, 57.011835030147004, 55.73117085865566, 56.50392518724714, 55.38397979736328, 52.59111315863473, 54.73045308249337, 54.149191107068745, 52.543486731392996, 52.59431280408587, 57.72351121902466, 58.90748773302351, 58.16906097957066, 54.63124670301165, 56.176724093300955, 56.38023683003017, 59.638063022068565, 57.207058565957205, 57.248219694410054, 56.06298555646624, 59.234525544302805, 48.89779124941145, 46.91813482557024, 46.26779038565499, 44.77231918062483, 46.755408014569966, 43.852190085819785, 42.22422020775931, 47.66126550946917, 47.61125585011074, 48.92861345836094, 48.74512890407017, 48.63353041240147, 50.336516516549246, 51.2087482043675, 51.60502828870501, 51.38992943082537, 55.808316707611084, 56.46062053952898, 56.7815717288426, 57.38162163325718, 56.6436082976205, 58.28344917297363, 59.721232959202354, 58.44233363015311, 65.03832108633858, 69.50278186798096, 68.13062381744385, 70.47715554918561, 72.2488489151001, 75.36959062303815, 74.19726971217564, 72.30390644073486, 57.525154045649934, 1.9725299605301447, 0.4945706586752619, 1.4192506607089723, 0.22835539653897285, 19.14366286141532, 84.97836562565395, 71.22428839547294, 70.67915357862199, 50.72905152184622, 44.681478432246614, 55.364139216286794, 7.559285708836146, 0.48365009895392824, 0.1479343269020319, 0.19906768096344812, 0.08656201511621475, 0.14848611157919678, 0.124040815447058, 0.14448013582399913, 0.16435674710997514], [0.03572278902200716, 0.05338073328935674, 0.04018166993877717, 0.007940104829945734, 0.06232402500297342, 0.04028411176321762, 0.04740868874692491, 0.20560951850243978, 1.1831597749676024, 47.7875212260655, 36.401647159031455, 27.43359681538173, 36.42666414805821, 49.86836426598685, 69.84866319383893, 52.3312748500279, 0.2795715183019638, 0.2877360044845513, 0.9639116483075278, 0.031295368381376774, 3.3904822851930345, 33.89691884177071, 49.12941639763968, 51.81736871174404, 60.61802305494036, 65.11114515577043, 69.27566610063825, 69.56488486698696, 69.07949760981968, 66.13165487561906, 55.89791372844151, 59.12567506517683, 62.39598369598389, 65.99683203016008, 62.92917455945696, 64.6324907030378, 63.41210215432303, 62.305316652570454, 63.41734109606062, 62.60514531816755, 54.20470026561192, 48.39153855187552, 46.70629814692906, 49.27064200810024, 51.405111244746614, 43.14667694909232, 39.31676040376936, 42.91870655332293, 44.62837682451521, 47.843631403786794, 48.89562341145107, 44.37666096006121, 44.68285070146833, 49.345620019095286, 54.42764016560146, 59.0054086957659, 55.80056251798357, 56.36490910393851, 58.21460294723511, 55.66262687955584, 55.73675373622349, 53.49236052376883, 50.43615368434361, 48.775634969983784, 51.017033508845735, 55.71900803702218, 53.4081448827471, 53.521341460091726, 53.207977703639436, 53.33810009275164, 48.65687983376639, 52.678785528455464, 51.279057025909424, 55.420607226235525, 55.677176407405305, 61.42493125370571, 53.10287925175258, 44.81490468978882, 54.05820097242083, 55.00729363305228, 53.43892887660435, 56.67598342895508, 55.19949817657471, 55.158840792519705, 46.846630913870676, 45.67757913044521, 46.20744180679321, 39.40468290873936, 43.37238918031965, 44.76252916881016, 42.72246510641915, 41.98910011563982, 37.871135575430735, 38.450326987675254, 42.764658042362754, 58.082121644701274, 55.594548429761616, 50.78198984691075, 49.50137431280953, 39.20313998631069, 42.613600730895996, 40.7888856615339, 49.934983594076975, 53.49180466788155, 52.31139605385916, 51.906785079411094, 53.207977703639436, 52.03812687737601, 49.77404247011457, 48.22980533327375, 46.05313621248518, 48.77542652402605, 49.62005649294172, 50.617053508758545, 50.59328024727957, 53.26481744221279, 53.55795151846749, 53.64801754270281, 50.92757197788784, 52.624648639133994, 50.52978413445609, 54.49759462901524, 52.9220871244158, 45.88958951405117, 41.909550189971924, 42.44755615506853, 41.356629916599815, 40.337402139391216, 38.11198098318917, 37.96411289487566, 38.996490137917654, 43.547720023563926, 44.56058325086321, 44.934424127851216, 42.97208261489868, 45.27421883174351, 44.1875170980181, 44.13904646464756, 45.89698934555054, 45.468167373112266, 46.439831256866455, 45.80508552278791, 44.99389375959124, 48.66884463174002, 50.561589513506206, 52.896639347076416, 56.7800327028547, 62.134217262268066, 62.605027198791504, 68.3517849785941, 66.65323529924665, 68.72277709415981, 66.19505023956299, 64.52307741982597, 57.725474085126606, 53.976288659232004, 0.9441093908888953, 0.15640209109655448, 0.3532417209020683, 0.16213701479136944, 3.8270821145602634, 64.55708885192871, 63.44213921683175, 56.47099767412458, 36.30173553739275, 25.36102213178362, 32.41109868458339, 5.153646954468318, 0.21041543276182242, 0.07047406517501388, 0.04699071796078767, 0.07272457584206547, 0.029067883800183023, 0.04939735953563026, 0.047342456943754635, 0.03352591994085482, 0.008666436703476523, 0.003166461696049997, 0.02626743576755481, 0.039479308162948916, 0.04919916284935815, 0.032079554695103846, 0.049411690195224116, 0.10138119956744568, 1.9785820586340768, 56.711464405059814, 43.80993114198957, 30.02568483352661, 42.70222847802298, 57.48626497813633, 77.2447635105678, 61.405024664742605, 0.6244559405105454, 0.5018915629812649, 1.7825659939220972, 0.07361022010445595, 3.3108120688370297, 47.457860469818115, 64.27304649353027, 66.45043822697231, 68.05415194375175, 73.65271854400635, 74.10993780408586, 73.3046624319894, 73.32567378452846, 70.68546254294259, 59.739319120134624, 61.26230866568429, 64.93980257851737, 68.55728490012032, 66.22066824776786, 67.19511835915702, 66.53144032614571, 66.6927080154419, 64.98092896597726, 65.68781089782715, 57.50408015932356, 51.00766386304583, 50.756535121372764, 51.339502879551475, 52.26181370871407, 46.656920773642405, 42.69681235722133, 44.80155720029558, 48.18899508884975, 49.36640555518014, 49.82145697729928, 47.03425312042236, 48.81790781021118, 51.11941868918282, 57.58992167881557, 61.667270524161204, 59.09242793491909, 58.83142580304827, 59.00635365077427, 58.16959251676287, 56.182862826756065, 54.839939321790425, 52.90884038380214, 49.40624305180141, 51.56404433931623, 59.23155171530587, 54.59091241019112, 56.84701681137085, 55.94438328061785, 55.41575738361904, 53.24677644457136, 54.10137013026646, 53.56608785901751, 58.547327859061106, 57.47569676807949, 60.95175892966134, 54.19683837890625, 45.31517846243722, 55.69779518672398, 58.87961850847517, 55.438915729522705, 56.760153906685964, 54.4417484828404, 55.9375045640128, 47.063803809029714, 44.53975255148751, 50.265109879629954, 40.840868609292166, 44.24272400992257, 44.69331816264561, 41.88467563901629, 43.99063989094326, 37.811905656542095, 37.884066173008506, 41.01502868107387, 56.64400781903948, 58.97405842372349, 53.5886868749346, 50.62029136930193, 39.621046338762554, 42.22989688600813, 41.24444430215018, 49.369490555354524, 54.617447580610005, 54.45522798810686, 54.093751430511475, 55.16790819168091, 54.599378790174214, 53.033643926892964, 51.44796078545706, 47.676148550851, 49.741792406354634, 52.32826975413731, 53.51834331239973, 51.71352788380214, 54.09241737638201, 55.11565426417759, 56.707959038870676, 53.83141871861049, 55.13136414119175, 53.62419216973441, 55.79752268110003, 55.802237033843994, 48.948731967381065, 45.398108686719624, 45.102223123822895, 43.59165000915527, 42.08770547594343, 40.06946917942592, 40.811884198869976, 40.47672394343785, 45.524326188223704, 46.564495835985454, 48.81754650388445, 46.126467500414165, 47.91009439740862, 48.055732113974436, 47.55460718699864, 47.631978852408274, 47.64811951773507, 48.96514013835362, 48.798511913844514, 47.73029933656965, 52.6947420665196, 54.793983936309814, 57.17822354180472, 59.14397662026541, 65.51876122610909, 64.23066248212541, 73.33401162283761, 70.59018884386334, 71.67868668692452, 69.47216115679059, 66.68804577418736, 61.395095688956125, 59.14489378247942, 1.585847292627607, 0.22349879571369716, 0.08733374013432435, 0.20062234039817536, 3.833399764129094, 72.54781600407192, 68.38840198516846, 65.5900080544608, 44.34117650985718, 34.594135829380576, 44.123826435634065, 9.105769719396319, 0.42526962448443684, 0.10275759428207364, 0.04332189268565603, 0.03176690272188612, 0.09062461461871862, 0.057334030978381634, 0.06862541687275682, 0.04184290347620845, 0.08730583198900733, 0.10211280959525279, 0.1679366842976638, 0.15036060528031417, 0.08919711943183627, 0.1094181008104767, 0.143600944429636, 0.43183540073888643, 2.8630714544228146, 70.71650709424699, 53.998522894723074, 35.731507301330566, 48.82923337391445, 68.31631442478725, 83.64618056161063, 69.57519599369594, 0.5783996975847653, 0.8149157262274197, 2.7480818075793128, 0.18739728576370648, 3.9586219361850192, 59.821266174316406, 75.8643023627145, 78.35063185010637, 78.73092065538678, 79.72549969809396, 77.94691371917725, 78.1901354108538, 78.27427114759172, 73.51320566449846, 64.04202583857945, 64.57423700605119, 67.41220787593296, 71.17660985674176, 68.94410501207624, 68.56801986694336, 66.96402127402169, 69.97892802102226, 69.61827482495988, 70.51145880562919, 60.831603731427876, 54.56410278592791, 52.62503773825509, 53.97827236992972, 55.2844294820513, 49.090440477643696, 46.34442206791469, 49.98814426149641, 50.786037172589985, 51.222161701747346, 51.399048941476, 49.648752553122385, 49.60512481416975, 52.05918339320591, 59.3655755179269, 66.2836606161935, 62.31617668696812, 60.57781382969448, 61.941231046404155, 61.07054533277239, 59.92713587624686, 59.554080145699636, 56.37034259523664, 53.51764849254063, 57.247372014181956, 62.458718981061665, 58.92219706944057, 59.54706941332136, 58.36557688031878, 57.5945839200701, 53.812269483293804, 57.35686867577689, 57.765037127903526, 62.905543736049104, 61.02693149021694, 64.20860889979771, 57.589949471609934, 46.60448619297573, 57.10704272133963, 60.246836389814106, 58.050820010049, 59.91387176513672, 58.38825580051967, 60.18947901044573, 49.22700384684971, 42.920290742601665, 52.40769113813128, 45.32536104747227, 46.14156593595232, 45.90905836650303, 47.961333887917654, 46.123629161289756, 37.44931043897356, 38.382901668548584, 42.18374695096697, 59.75448703765869, 60.175916126796174, 55.032178606305806, 51.57824993133545, 41.07735749653408, 42.56326450620379, 42.36698831830706, 53.22256197248186, 57.793663706098286, 58.094583238874165, 55.45990971156529, 58.582965169634136, 56.150612762996126, 54.31789336885725, 55.03007330213274, 49.96304389408657, 52.415226459503174, 54.02791724886213, 56.78551830564226, 55.02375044141497, 57.6558427129473, 57.291559083121165, 57.59775924682617, 54.92631237847464, 56.57379974637713, 58.31289563860212, 59.45628425053188, 58.33139174325125, 51.366062368665425, 49.148878301892964, 47.21179001671927, 47.55951261520386, 44.80268975666591, 44.06784132548741, 42.870784827641074, 43.6036947114127, 47.21956157684326, 49.848252705165315, 50.41539246695382, 47.82804659434727, 51.199864932468955, 49.09520346777779, 47.69854259490967, 50.1641525541033, 51.33175563812256, 52.32116174697876, 52.74553687231881, 51.27005216053554, 55.491301672799246, 57.24758046013968, 62.12061268942696, 62.924581800188335, 68.12637846810478, 67.6699582508632, 75.99896539960588, 73.38246835981096, 74.43289007459367, 72.39343397957938, 68.07427392687116, 61.643243653433665, 61.05373764038086, 2.1668133182185034, 0.3673854576689856, 1.516244581767491, 0.3313962316938809, 6.131083922726767, 81.0298433303833, 74.38766424996513, 72.0591630935669, 53.47809934616089, 44.96930061067854, 59.58877944946289, 12.269678848130361, 0.7342635882752282, 0.3200940638780594, 0.1617045844239848, 0.15758950023778848, 0.19831050373613834, 0.16674406400748662, 0.27849821160946575, 0.13564020874244825], [0.05264294520020485, 0.025345835934526155, 0.009720361043166901, 0.03847524257642882, 0.04568728272403989, 0.02518251764455012, 0.10993372635649783, 0.1689793619194201, 0.8985279596277645, 40.455934933253694, 33.588067940303254, 22.308754920959473, 37.46423864364624, 52.809126785823274, 67.25529670715332, 55.58482095173427, 0.9826501799481255, 0.2810511046222278, 0.5581363077674593, 0.1571276078798941, 0.7585379885775703, 19.047744716916764, 46.22373185838972, 49.29505450384957, 63.00655664716448, 63.5023592540196, 67.81354972294399, 68.3278831754412, 70.60755934034074, 66.3120231628418, 57.85847997665405, 57.56485257829939, 60.817665645054404, 58.00219999040876, 61.54284913199288, 61.60675866263253, 61.57611015864781, 60.805061612810405, 60.6986916405814, 59.143851552690776, 52.69007635116577, 47.81078379494803, 49.19560841151646, 47.380280358450754, 48.68914726802281, 42.03882489885603, 38.64855909347534, 42.53672586168562, 44.0736083303179, 46.80277735846383, 48.60467454365322, 46.1428860936846, 47.427152906145366, 49.666279384068076, 52.09561627251761, 57.32660232271467, 55.487657342638286, 56.550106389181956, 55.56941679545811, 51.18928630011422, 48.263587474823, 48.8026738848005, 46.744756426130024, 49.48204789842878, 45.574464389256065, 44.429901531764436, 48.864113330841064, 51.7789694922311, 49.84054020472935, 48.25818872451782, 48.000525202069966, 49.174913202013286, 53.03962285178048, 55.933780329568044, 52.61969109943935, 60.205793380737305, 46.54487064906529, 42.28420400619507, 51.967397689819336, 52.978343214307515, 56.015209742954795, 54.670955657958984, 38.289184365953716, 38.3029591696603, 40.03673621586391, 44.245218413216726, 41.278827462877544, 37.32140105111258, 40.539330686841694, 43.967683042798726, 36.61868803841727, 40.141303130558555, 39.56274400438581, 39.1640112059457, 41.61918497085571, 43.55214255196707, 50.91375895908901, 56.63374880381993, 52.99157953262329, 39.657708508627756, 39.45113161631993, 42.65730490003313, 41.96759196690151, 48.71264260155814, 53.385139397212434, 55.11911794117519, 54.46529940196446, 53.853010245731895, 50.65684584208897, 49.2878075327192, 45.355540548052105, 47.81045722961426, 50.765421867370605, 50.73543691635132, 52.08132382801601, 53.163679463522776, 52.161151681627544, 54.01746020998274, 50.425998892102925, 52.181252820151194, 48.145169326237266, 51.101155349186485, 51.27959551130022, 46.85238054820469, 41.18370662416731, 43.077337401253835, 43.73460224696568, 38.27068478720528, 40.11607074737549, 38.007445335388184, 37.233808585575645, 42.05156789507185, 43.650862557547434, 43.80843033109392, 45.46673951830183, 44.95445578438895, 45.8570511000497, 43.61111191340855, 44.74863971982683, 46.063697474343435, 46.57011692864554, 46.80707481929234, 45.2391026360648, 50.42319876807076, 53.13993399483817, 55.215822969164165, 58.97560787200928, 63.23353345053536, 63.16230051858084, 66.29324913024902, 65.44701412745884, 66.61725752694267, 62.90379279000418, 69.26315239497593, 63.78596387590681, 71.47074099949428, 12.831808090209961, 0.5677934352840696, 0.3613117007272584, 0.3111964613199234, 1.717880653483527, 55.6795631136213, 62.00507804325649, 57.050209930964876, 32.951439244406565, 32.05033779144287, 29.0166882787432, 8.344921129090444, 0.19625653752258845, 0.07782031276396342, 0.03156184943925057, 0.07442108980779137, 0.022507739386388233, 0.038038018359137435, 0.071511097385415, 0.022391387594065497, 0.011251970643310674, 0.05215197761676141, 0.030347896008087055, 0.06289292911865882, 0.023926457722804377, 0.0528339426299291, 0.04804565331765583, 0.1633399488138301, 2.355483182838985, 54.36247648511614, 38.933410917009624, 23.824038914271764, 43.768745694841655, 59.05456025259835, 74.64139856610979, 64.78696305411202, 1.295849893774305, 0.19773122482001781, 0.7559335540447916, 0.1466431561857462, 0.747948228248528, 22.822193792888097, 63.55028097970145, 60.38200664520264, 73.03872013092041, 72.98649747031075, 74.63139316013881, 71.95864350455147, 73.36209624154228, 70.19369683946881, 60.580975260053364, 59.559499740600586, 64.51909610203334, 62.52066911969866, 65.45326750619071, 63.90507684435163, 64.7434047971453, 63.69503974914551, 62.99461964198521, 62.4623042515346, 57.198449747903005, 50.49662038258144, 53.701692376817974, 51.43269211905343, 51.8273845400129, 43.56445475987026, 41.65232787813459, 45.84145239421299, 47.192157881600515, 48.95346369062151, 50.442434855869834, 46.34114251817976, 49.74455084119524, 51.12585619517735, 54.33493382590157, 59.74312673296247, 56.807231426239014, 58.816938808986116, 57.47675289426531, 52.46712602887835, 50.16995777402605, 50.78361919948033, 50.256490639277864, 52.8094915662493, 47.347710677555625, 47.803352696555, 50.714217117854524, 53.81601108823504, 51.90200124468122, 50.28273745945522, 49.841950689043315, 52.05526460920061, 55.1828224999564, 57.05398627689907, 56.25628096716744, 61.00847707475935, 49.677924564906526, 44.09624208722796, 52.50179059164864, 55.142359665461946, 57.120105334690635, 56.4264041355678, 40.156405040196006, 38.98190239497593, 40.21514858518328, 43.26731852122715, 44.38300813947405, 40.04660613196236, 41.00356762749808, 43.400637081691194, 41.41183682850429, 41.544710704258506, 37.94029099600655, 38.41553735733032, 40.643828119550435, 44.256940024239675, 49.497247082846506, 56.36411353519985, 54.689649786267964, 41.200528212956016, 38.85607746669224, 43.393153871808735, 43.89484160287039, 49.55977044786726, 55.41809892654419, 56.96968378339495, 57.95659548895699, 55.89270952769688, 54.84167637143816, 52.261115414755686, 46.85581643240792, 49.67740345001221, 52.287817341940745, 52.656454018184114, 53.5863105910165, 54.02805968693325, 54.4748010635376, 55.940374170030864, 52.552766050611226, 54.2920286996024, 50.97246081488473, 54.320523262023926, 53.710620812007356, 49.225471769060405, 43.86131307056972, 45.530596937452046, 46.028556959969656, 41.8805935723441, 42.629171643938335, 41.18630525044033, 39.16697808674404, 45.08597823551723, 46.24302353177752, 46.86665562220982, 46.7002705846514, 48.78886434010097, 46.994884627205984, 46.34212221418108, 44.940621920994346, 49.17789050510952, 48.16178594316755, 48.698228563581196, 48.387015274592805, 54.38369975771223, 55.85769755499703, 59.8988219669887, 62.51861245291573, 68.25835950034005, 67.94562108176095, 71.0990332194737, 66.9530917576381, 69.1444285256522, 63.75996371677944, 71.80457414899553, 66.84535993848527, 78.7145437513079, 18.33960689817156, 0.7025293739778655, 0.2535381109586784, 0.3543198587638991, 1.7127531000546046, 62.299167496817454, 68.27632754189628, 65.92382035936627, 37.364521571568076, 39.30036265509469, 41.55158247266497, 10.629859685897827, 0.24122861719557218, 0.026262231403961778, 0.09783644442047391, 0.08555558483515467, 0.06305646962885346, 0.048884000296571424, 0.07232202815690211, 0.07497036390538726, 0.1428327749350241, 0.11796624426330839, 0.06957088756774153, 0.1407414214419467, 0.1999030661370073, 0.08606335294565984, 0.18390815013221332, 0.27207175216504503, 4.10124283177512, 66.01953874315534, 50.0678505216326, 31.20442587988717, 51.60348578861782, 68.23251220158168, 81.10595389774868, 73.90209633963448, 1.8150487137692315, 0.6958354903118951, 1.6923544917787825, 0.35809411481022835, 0.7270129801971572, 28.81536075047084, 81.43381159646171, 72.9912361417498, 81.16644491468156, 75.84299223763603, 76.1937928880964, 76.1348443712507, 79.1222779410226, 74.48942756652832, 62.474720682416645, 63.503637722560335, 69.0947766985212, 65.51584298270089, 67.52999373844692, 69.5311096736363, 68.89570386069161, 66.49851281302315, 66.215026310512, 65.71746580941337, 60.76731204986572, 53.27217558452061, 55.77924197060721, 53.85338544845581, 54.472518580300466, 47.701248918260845, 45.08263267789568, 48.71845129558018, 48.452102524893625, 51.72107015337263, 52.50576148714338, 48.265918595450266, 53.81882510866438, 52.81562682560512, 56.72276912416731, 62.64217226845877, 58.55410235268729, 61.41928931644985, 61.04142543247768, 54.82137720925467, 53.803566864558626, 54.66630036490304, 51.59754507882254, 56.456934520176475, 50.42635325023106, 49.700117111206055, 52.8718238558088, 55.93760183879307, 54.54073599406651, 53.12489809308733, 53.278543608529226, 56.22603893280029, 58.8795142854963, 62.10745974949428, 57.39762333461216, 65.18134280613491, 52.437050751277376, 43.72076838357108, 53.03189298084804, 56.788075242723735, 58.865826334272114, 59.69230760846819, 42.33824362073626, 39.1613187789917, 41.32141644614083, 42.6280460357666, 48.94298928124564, 40.40791245869228, 42.79634182793753, 45.07881811686924, 45.85206576756069, 43.132554735456196, 37.23446519034249, 40.46022197178432, 41.72257416588919, 44.470548493521555, 52.709072726113455, 59.467769622802734, 58.494570187159944, 41.013110978262766, 40.66886942727225, 43.32976198196411, 44.05754062107631, 52.38482461656843, 57.06129925591605, 59.081449781145366, 61.251983642578125, 59.0137117930821, 55.28479773657662, 54.838000774383545, 49.45329277856009, 52.748587131500244, 55.219175474984304, 55.452179840632844, 55.23876592091152, 56.836910656520296, 58.11101572854178, 59.68212849753243, 54.40041364942278, 54.937161990574424, 52.98108427865164, 56.42392362867083, 56.22016423089163, 51.06043543134417, 47.7922112601144, 47.457106590270996, 48.15514693941389, 43.528675011226106, 46.2628675869533, 44.019245624542236, 41.44139099121094, 49.06580216544015, 48.445713656289236, 49.13807037898472, 50.0836090360369, 51.70997040612357, 50.548057896750315, 49.18225049972534, 48.26483120237078, 50.37120887211391, 52.95878403527396, 52.9162471635001, 51.88147626604353, 56.64604016712734, 59.19634519304548, 63.614121028355186, 65.37913717542375, 72.02521419525146, 70.32624762398856, 73.12817818777901, 69.4155194418771, 73.05875178745815, 64.96208545139858, 74.7281746183123, 68.27843979426792, 78.24394920894078, 16.793849842888967, 0.7660610963191304, 1.0078717065708978, 0.5699415685875076, 3.0710507971899847, 69.95979268210274, 74.42931175231934, 71.28337587629045, 46.20242173331124, 51.63421072278704, 59.45251832689558, 16.03271985054016, 0.6719104541199548, 0.17955979917730602, 0.23010854103735515, 0.14946116640099458, 0.133394841370838, 0.23859619987862452, 0.13673483500523226, 0.08676225758556809], [0.035212401766330004, 0.06440125139696257, 0.1621489298662969, 0.04427191295794078, 0.01056415241743837, 0.016870107435222183, 0.05019118104662214, 0.12230147235095501, 1.5375550325427736, 42.02742985316685, 33.90671927588326, 26.828412192208425, 44.62608739307949, 48.13566766466413, 66.12801401955741, 61.33612632751465, 1.9934655342783247, 0.1905824648482459, 0.29774887434073855, 0.12581861790801796, 0.3395456001162529, 13.083630783217293, 43.090122086661204, 49.14236783981323, 59.04185894557408, 61.30928543635777, 68.26920563834054, 67.106431552342, 68.06811087472099, 64.54968902042934, 57.63855906895229, 55.481671469552175, 59.52432795933315, 58.21235520499093, 60.620885712759836, 59.28959001813616, 59.79680156707764, 56.876366002219065, 58.34933199201311, 56.69342688151768, 51.047004563467844, 46.180583545139854, 47.691045488630024, 49.08810935701643, 50.087791851588655, 41.53294045584542, 39.1247295652117, 42.752415316445486, 44.14329181398664, 46.838980947222026, 48.713292258126394, 45.24031162261963, 49.45969206946236, 48.47731406348092, 52.27247224535261, 52.92882687704903, 53.18691423961094, 54.42769922528948, 50.32098381859915, 49.37462180001395, 45.447534697396414, 45.8868727684021, 50.63141196114676, 50.11266987664359, 51.95616592679705, 46.310157026563374, 43.04273884637015, 45.223913873944966, 44.81331007821219, 46.421720777239116, 48.734981060028076, 47.21679271970476, 48.309452533721924, 54.74628802708217, 55.150103432791575, 54.882146154131206, 40.08038132531302, 39.50056804929461, 45.147490637642996, 50.28621155875069, 53.319986139025005, 43.80577611923218, 41.89128337587629, 39.19232164110456, 40.976355007716585, 39.64944362640381, 41.71998248781477, 41.771239348820274, 39.02821213858468, 39.185901505606516, 40.73447779246739, 37.676711082458496, 40.387651511601035, 35.802028042929514, 37.50144624710083, 40.03609003339495, 39.254751205444336, 45.13847187587193, 48.502504757472444, 41.58213370186942, 40.65579639162336, 41.90851490838187, 42.975508076804026, 49.0360221862793, 51.121899196079795, 52.58157328196934, 53.19108315876552, 54.73688016619001, 53.526236465999055, 49.941490582057405, 45.76491798673357, 45.55653803689139, 45.44614158357893, 47.401753766196116, 48.14753518785749, 50.04663419723511, 51.011415890284944, 51.07599244798933, 53.0405330657959, 50.117075034550254, 51.280651637486045, 49.944304602486746, 50.81252023151943, 44.3541453225272, 42.447601318359375, 43.78148521695818, 44.65617309297834, 40.51094382149832, 38.896984985896516, 38.495330469948904, 35.52945021220616, 40.51905584335327, 45.35461296354021, 44.65050336292812, 45.011351108551025, 42.858191217694966, 44.75326722008841, 44.05633858272007, 45.82073981421334, 45.449525356292725, 45.60589803968157, 44.109540939331055, 50.53001689910889, 52.99824285507202, 56.091983863285606, 58.88727542332241, 63.745191846575054, 63.19380365099226, 67.8254519871303, 63.01604093824114, 67.05885028839111, 66.47179698944092, 69.01078687395368, 68.32126849038261, 71.58667864118303, 66.67121723720005, 67.2768222263881, 1.4228721920933043, 0.19512765881206307, 0.0550591439407851, 0.555389869425978, 54.87452050617763, 63.55036435808454, 56.64592899594988, 36.058527742113384, 30.384566238948278, 33.302413599831716, 7.895905085972377, 0.06277749674128634, 0.04451298287936619, 0.0259245805043195, 0.013255095076082008, 0.012004628827396249, 0.05374311509409121, 0.052832351465310366, 0.045299927437944074, 0.022939550590568354, 0.022298446956223676, 0.05825246883822339, 0.059698372680161677, 0.047275505893464596, 0.058516839652189186, 0.03932258353701659, 0.22591879085770675, 3.570524875606809, 55.79609135219029, 40.02170031411307, 33.83542381014143, 50.431599140167236, 56.563071727752686, 71.4339085987636, 72.6717232295445, 2.9659093533243452, 0.22016769088804722, 0.5327103521142686, 0.05037561025736587, 0.209326139784285, 16.111330032348633, 62.066472326006206, 62.30829048156738, 69.39794049944196, 69.0254545211792, 73.43183531079973, 70.83513368879045, 72.8607976096017, 65.85569327218192, 61.103222710745676, 57.49493980407715, 62.69187273297991, 61.87797464643206, 62.0992956161499, 60.814288820539204, 62.16844408852713, 60.61095673697335, 61.907872744968955, 60.31125313895089, 53.69882277079991, 49.59267711639404, 49.80993338993618, 51.39464030947004, 53.90340205601284, 44.90251105172293, 42.012230668749126, 46.1136063848223, 47.19338423865182, 49.14914928163801, 49.7886197907584, 47.12558371680123, 50.11045340129307, 51.3278021131243, 52.90981313160488, 55.40536287852696, 53.9043504851205, 54.65702451978411, 51.30700268064226, 51.85606322969709, 48.11366619382586, 49.09080525806972, 53.33720030103411, 53.75953613008772, 55.01286608832223, 49.66679702486311, 46.66507795878819, 47.19865097318377, 46.73878444944109, 49.412975856236045, 52.44770581381661, 49.81938294001988, 49.890126023973735, 57.24708366394043, 56.82173579079764, 58.60920851571219, 41.785184383392334, 40.1790075302124, 44.828425884246826, 51.72968591962542, 53.49297891344343, 43.64506081172398, 41.9903438431876, 39.68379899433681, 43.516060556684224, 40.8200865473066, 43.59510326385498, 41.03968783787319, 40.021999086652485, 38.647857325417654, 39.53984274183001, 37.56263208389282, 38.58316264833723, 35.16843223571777, 38.7876272882734, 39.3128833089556, 38.92186648505074, 43.452734674726216, 49.92738226481846, 42.492646489824565, 41.14227451596941, 41.52945246015276, 45.60322298322405, 50.959735189165386, 52.58855274745396, 55.09751599175589, 56.38063287734985, 58.60401126316616, 55.26262603487287, 52.87207399095808, 49.17404120309012, 48.68848718915667, 48.36747694015503, 48.55093022755214, 50.180730955941335, 52.853206157684326, 52.77807181222098, 53.20162010192871, 52.21081393105643, 51.56578138896397, 54.227952412196565, 52.45605754852295, 53.44039494650704, 47.3980781691415, 44.31401252746582, 45.804734638759065, 47.09696061270577, 43.707716192517964, 42.02801350184849, 42.46334593636649, 39.01354449135916, 44.311573709760395, 47.6770726612636, 45.81998940876552, 46.949592794690815, 44.43356670652117, 47.34480633054461, 45.47789485113961, 49.27653408050537, 46.6669921875, 48.767547266823904, 48.40870755059378, 55.37176833833967, 55.63824217660086, 61.24380561283657, 60.81998634338379, 66.07156685420445, 67.14971882956368, 69.12869085584367, 65.19862297603062, 68.8953217097691, 69.5004472732544, 73.84134823935372, 69.82335785457066, 76.40578937530518, 70.79076944078717, 77.48681790488106, 3.020779060465949, 0.19835622342569487, 0.19992385644997868, 0.46785174097333637, 63.693149839128765, 68.62650980268205, 68.9032426561628, 41.30567182813372, 39.487720830099924, 45.9113130569458, 10.136298741613116, 0.14174179919064045, 0.03596578937556062, 0.036701358655201535, 0.05186659596594317, 0.01569450310697513, 0.04939701687544584, 0.04053032158740929, 0.017203185008838773, 0.13432218161012444, 0.10264986327716283, 0.17468029100980076, 0.19006284273096494, 0.11989302587296281, 0.09309385104903153, 0.1671286712267569, 0.3595489210316113, 5.040531584194728, 71.25661141531808, 47.971634592328755, 39.39460802078247, 56.89158603123256, 63.33156558445522, 78.62712846483502, 84.01533140454973, 3.5669218003749847, 0.2518801513527121, 1.1115820386580058, 0.2955309876373836, 0.6909047120383808, 19.414338622774395, 75.08959906441825, 73.3645350592477, 79.03394549233573, 74.93666921343122, 80.491288457598, 75.46090384892055, 76.55726705278668, 70.00472668239048, 64.66089493887765, 60.31768022264753, 67.20994581495012, 64.45228917258126, 66.68027768816266, 65.46760163988385, 65.57539599282401, 63.884968757629395, 64.39470250265938, 63.4744552884783, 57.505191871098106, 53.171600409916465, 53.38226631709507, 53.782600675310405, 58.493465423583984, 47.40439060756138, 44.78054237365723, 48.387915066310335, 50.19223369870867, 51.67841168812343, 53.249962193625315, 49.06159850529262, 53.49222503389631, 52.68212761197771, 56.153940950121196, 57.095296791621614, 56.16786514009748, 56.60565028871809, 54.76369326455252, 55.59405510766165, 49.44282879148211, 51.8476003238133, 55.87410225187029, 56.72594097682408, 58.76477173396519, 50.79518795013428, 49.04186909539359, 50.949014118739534, 48.55006865092686, 51.28589057922363, 54.78792858123779, 52.37908887863159, 53.88019854681832, 59.43746852874756, 59.99725709642683, 60.3961740221296, 43.918434211185996, 41.646275997161865, 43.73680830001831, 53.5968336377825, 58.44243090493338, 45.99619919913155, 40.95894282204764, 39.43653345108032, 40.725941930498394, 41.439716475350515, 42.37212651116507, 40.94743660518101, 40.513879435403005, 39.31402628762381, 40.48711150033133, 36.838938985552105, 39.94146251678467, 34.261306694575715, 39.31741353443691, 39.016626017434255, 40.51930945260184, 46.908438614436555, 52.24991839272635, 43.828361238752095, 42.237234183720176, 43.965299810682026, 47.69831330435616, 52.77406964983259, 55.73931067330496, 56.92848096575056, 59.6528765814645, 60.75855731964111, 57.910188470567974, 56.29231085096087, 52.399853570120676, 50.17517934526716, 52.06501988002232, 50.79169995444161, 53.495570591517854, 54.281085286821636, 56.018555300576345, 56.02175842012678, 56.49548660005842, 54.03548731122698, 56.560858726501465, 55.62282064982823, 56.53814506530762, 50.319048745291575, 47.688651834215435, 48.0366975239345, 49.59691899163382, 45.91387346812657, 44.594837869916645, 44.37592445101057, 40.75089291163853, 45.881612982068745, 50.172684941973, 48.92936038970947, 49.64039387021746, 47.487442425319124, 50.47009563446045, 49.178960527692524, 49.7211458342416, 51.77432462147304, 51.93753433227539, 51.30730840138027, 57.98037222453526, 59.215855734688894, 63.83328110831124, 63.13139493124825, 70.47668307168144, 68.60668659210205, 72.491028376988, 67.65533924102783, 72.34472710745675, 70.98587485722133, 77.33567374093192, 72.91912078857422, 79.36319283076695, 73.84280041285923, 78.70000811985561, 2.442508718797139, 0.40019647989954266, 0.2879325625087534, 1.1317641671214784, 71.80158642360142, 74.75999736785889, 75.54864570072719, 50.464071546282085, 51.175341265542166, 60.80413750239781, 15.629573208945137, 0.36717247909733225, 0.1793301829269954, 0.18119767414672033, 0.15523729074214185, 0.11057636008730956, 0.12090150532977921, 0.23424461909702846, 0.17386822029948235], [0.022725352352218967, 0.04210585954466036, 0.0646222841792873, 0.017122992347659807, 0.034972811051245244, 0.08153142434145723, 0.1094973740567054, 0.11070150230079889, 1.7689184291022164, 35.81267615727016, 30.450883320399694, 18.34396341868809, 42.404543331691194, 53.44287197930472, 62.515013286045615, 63.885698318481445, 5.073731814111982, 0.20164186640509538, 0.5334782909069742, 0.14909345470368862, 0.34132979437708855, 6.874354873384748, 39.35480873925345, 49.4153208732605, 63.14330414363316, 59.70691272190639, 68.58452183859688, 66.39035020555768, 65.76841694968087, 59.953073501586914, 54.61371292386736, 54.34153808866228, 58.315376145499094, 55.24262564522879, 58.263118743896484, 56.68272318158831, 57.42524937220982, 55.35453333173479, 56.18973112106323, 53.77127511160714, 49.6977755682809, 47.13978583472115, 47.76178509848458, 45.84070198876517, 49.36472061702183, 42.08849062238421, 40.62235123770577, 42.83911493846348, 44.64868293489729, 44.84264537266323, 48.99217905317034, 46.642301763807026, 48.44813162939889, 46.20355428968157, 49.37620946339199, 49.710278851645334, 52.97086000442505, 50.72941977637154, 48.93571104322161, 45.50932502746582, 49.052913257053916, 48.92089400972639, 49.35583734512329, 51.77361937931606, 52.97653668267386, 51.929307665143696, 48.03588111060006, 44.21648413794381, 44.04939733232771, 46.25122240611485, 45.000227042606895, 44.605812549591064, 46.72384582247053, 49.74759415217808, 52.9566023009164, 54.75770044326782, 43.230823108128135, 39.79492153440203, 42.39041416985648, 51.33030693871634, 45.11446932383946, 48.42620311464582, 41.863990851810996, 40.71337611334664, 44.95868723733084, 47.98434632165091, 53.4227534702846, 49.62960679190499, 48.09223794937134, 43.96579313278198, 42.75269324438912, 41.99592672075544, 45.61564288820539, 50.31742634092058, 44.38920940671648, 38.32957771846226, 35.61647987365723, 37.23318324770246, 45.578994614737375, 44.09695775168282, 42.21205391202654, 41.22334957122803, 51.58870349611555, 53.86290795462472, 55.899171352386475, 54.257829666137695, 54.75455290930611, 54.61305979319981, 51.83041395459856, 46.72273758479527, 43.07779598236084, 41.629374504089355, 44.62477765764509, 43.450149944850374, 45.70213406426566, 44.621967111315044, 47.61701590674264, 47.48649399621146, 46.16444635391235, 48.76791204724993, 48.77952596119472, 48.44137103216988, 48.0411547933306, 47.61328819819859, 41.62616443634033, 43.36541666303362, 45.06744391577584, 41.38944625854492, 40.39635065623692, 37.6976911681039, 36.958993434906006, 38.5927129473005, 44.86774921417236, 44.29657254900251, 44.67343241827828, 43.116407121930806, 44.639966419764924, 45.490050724574495, 43.76669250215803, 43.284324237278526, 46.85561146054949, 46.068655014038086, 52.43686662401472, 53.96085671016148, 59.564849853515625, 58.35552283695766, 63.26897621154785, 61.76723425728934, 63.16621930258614, 63.690912519182476, 67.13638523646763, 66.60978126525879, 70.59769984654018, 65.20742634364537, 72.14426462990897, 63.312284333365305, 81.2891570499965, 29.633386066981725, 0.4094760976731777, 0.1569626967289618, 1.1701337482248033, 58.169262477329795, 61.99486419132778, 56.76048047201974, 43.95458916255406, 30.152319226946148, 26.97093711580549, 7.533390641212463, 0.1133907265695078, 0.08338617267353193, 0.015280398274106639, 0.036991961632988284, 0.06648879152323518, 0.03448304786745991, 0.06365483573504857, 0.109501689539424, 0.037165005026119094, 0.030438843449311595, 0.04394428910953658, 0.0004985113025343578, 0.017460037654797946, 0.05544338135847023, 0.09851723896073443, 0.17136103340557643, 4.757745112691607, 50.19154930114746, 38.26351077216012, 26.44004610606602, 51.88845573152815, 62.5011168888637, 69.46196814945766, 75.87043762207031, 7.228154540061951, 0.18815477511712483, 0.5009436767016138, 0.08203916531056166, 0.5992162834320749, 8.83568455491747, 56.94634825842721, 59.69457966940743, 73.7937113898141, 67.12105751037598, 76.12269892011369, 69.83655248369489, 70.81968784332275, 62.997127941676546, 58.873302595955984, 57.34716204234532, 62.91804354531424, 58.93263326372419, 62.562698772975374, 59.24391950879778, 61.59928240094866, 60.01461369650704, 59.08825206756592, 54.98772055762154, 52.72405651637486, 49.13615615027291, 51.52957432610648, 47.49957398005894, 53.99394750595093, 43.41800062997, 43.834586824689595, 44.683194637298584, 47.12946081161499, 47.238943576812744, 50.775291783469065, 48.720108440944124, 51.40264810834612, 48.47000803266253, 49.63913972037179, 50.806718485695974, 54.96449967793056, 53.59980746677944, 50.532323701041086, 48.509598868233816, 51.17769323076521, 52.75541026251656, 51.53935044152396, 54.586757387433735, 55.21249825613839, 53.75065633228847, 51.693763732910156, 47.98790379932949, 46.23447724751064, 47.447663988385884, 46.602905477796284, 48.29078619820731, 47.9260960987636, 51.9283800806318, 55.8438845361982, 56.386448519570486, 45.61511482511248, 41.963016578129356, 44.9263642174857, 54.20442928586687, 46.11564915520804, 50.36443785258702, 42.018702915736604, 40.65665449414934, 48.08648484093802, 48.653190340314595, 57.01866858346121, 51.5831275667463, 49.78882128851754, 44.550657749176025, 41.992831298283164, 44.648484911237446, 47.26038571766445, 51.7113287789481, 47.20820127214704, 38.48716286250523, 34.95656776428223, 38.36955417905535, 44.43224654878889, 42.85188920157296, 43.036502838134766, 41.37848547526768, 54.18853875568935, 55.610487597329275, 57.66696677889143, 56.71650879723685, 57.74257360185896, 54.70448071616036, 54.32511254719326, 49.14745739528111, 45.074659620012554, 44.272667271750315, 48.21711097444807, 45.53628403799874, 46.49278347832816, 47.30841861452375, 49.24152210780552, 49.830340249197825, 49.51571192060198, 51.26280518940517, 52.441792896815706, 51.74213709150042, 49.56822293145316, 50.2326339994158, 43.96726267678397, 46.40963438579014, 46.81377635683332, 43.322348254067556, 42.89089638846261, 40.963476521628245, 40.518805708204, 40.802365166800364, 46.691623551504954, 47.999253681727815, 45.91380746023995, 45.89060395104544, 46.98544897351946, 45.86907843181065, 47.50071348462786, 46.840026651109966, 48.23067385809762, 49.35631677082607, 55.9690181187221, 56.2892119543893, 61.76269013541085, 61.95988695962088, 65.38580049787248, 64.74465547289167, 66.72316196986607, 68.17491858346122, 70.47748906271798, 69.98260361807687, 73.49703025817871, 68.11388560703823, 75.41557380131313, 66.56570884159633, 85.35696601867676, 38.95340435845511, 0.3690979443490505, 0.08231833497328417, 1.2355402899639947, 67.75647027151925, 67.21438571384975, 65.95902688162667, 51.211211340767996, 38.03412989207676, 38.87673446110317, 12.5468042748315, 0.18262128132794583, 0.0694089958976422, 0.08698074586157288, 0.029256014419453483, 0.058586036653390954, 0.05005522298493555, 0.0875615786228861, 0.06293786170759372, 0.18917810092014925, 0.31676495394536425, 0.12294731555240494, 0.1152457802423409, 0.11903448908456735, 0.1492801196873188, 0.29688990328993115, 0.2893325431006295, 7.826363171849932, 70.12724426814488, 44.525025844573975, 25.82179365839277, 54.480123383658274, 72.84406634739467, 72.62504523141044, 85.37039688655308, 7.786940830094474, 0.33860854325549944, 1.5407686829566956, 0.25305602539862904, 1.3627055691821235, 11.625238639967781, 74.58613954271588, 67.41731480189732, 85.1205883026123, 71.30184418814522, 81.01464762006486, 72.22459275381905, 73.91401250021798, 64.80944047655377, 59.828784125191824, 59.60346099308559, 65.7365733555385, 61.37625912257603, 63.94234003339495, 61.17513656616211, 66.65138707842145, 61.95281369345528, 62.090721539088655, 58.26988976342337, 56.66377196993147, 52.607979910714285, 53.25582994733538, 49.20493289402553, 55.27245773587908, 47.43663024902344, 48.405049324035645, 47.40895209993635, 50.46381793703352, 48.438261713300435, 54.0063430922372, 51.24634838104248, 54.168955257960725, 49.8272066116333, 52.83357402256557, 53.51827383041382, 57.1121426991054, 55.763413974217, 52.30608763013567, 50.24474818365914, 53.68780640193394, 53.12286227090018, 54.3899427141462, 55.95431573050362, 58.01578719275338, 55.12578821182251, 53.79693480900356, 52.16432006018502, 48.28128801073347, 51.63795927592686, 49.458896500723704, 50.008196762629915, 51.48613766261509, 56.00319283349173, 58.17138862609863, 61.108142035348074, 45.46893514905657, 42.5918459211077, 46.90373815808977, 53.466648714882986, 46.122274262564524, 49.5174628666469, 42.328047139304026, 42.271061488560264, 50.133104528699604, 50.881331716264995, 59.32144750867571, 51.5456211907523, 50.345792361668174, 43.85500063214983, 42.74831240517752, 43.52935593468802, 47.947461809430806, 53.22677952902657, 46.234112467084614, 39.453205653599326, 36.07244150979178, 37.269320828574045, 45.26438365663801, 42.63547713415963, 45.233335631234304, 42.08717393875122, 55.8120687348502, 58.463067054748535, 59.95653370448521, 59.79930986676897, 59.91346182141985, 58.642733573913574, 56.968026638031006, 52.0063909803118, 49.06291171482631, 46.90097624914986, 49.84130450657436, 48.260207176208496, 50.28162227358137, 49.54118054253714, 52.910959584372385, 52.16337857927595, 51.99331447056362, 53.55862201963152, 55.175141266414094, 52.99462284360613, 51.8430666242327, 53.882296902792795, 45.520202432359966, 48.85418088095528, 50.374933106558665, 48.2731169291905, 45.90053292683193, 44.74676718030657, 44.226875168936594, 44.255585125514436, 49.31179966245379, 49.786684717450825, 50.24057926450457, 49.274557318006245, 49.564474378313335, 49.86014454705374, 48.92587586811611, 48.59681960514614, 51.89769683565412, 51.15171044213431, 58.753724098205566, 59.52491855621338, 65.00146784101213, 64.78733130863735, 69.88303593226841, 68.7275505065918, 68.79776205335344, 70.37207099369594, 72.956800869533, 72.01617458888462, 77.1141721180507, 71.76280852726528, 79.86549200330461, 68.17393888745988, 88.3024741581508, 36.39435502461025, 0.5099197179079056, 0.26110323358859333, 1.8489265016147067, 75.24913665226528, 71.5135419028146, 73.01767403738839, 60.81728349413191, 49.49205330439976, 54.37413208825247, 20.14725719179426, 0.46688713559082573, 0.16868608551365988, 0.23432951739856175, 0.10174776454057012, 0.1861320622265339, 0.14474844214107307, 0.1552445917789425, 0.19929406738706998], [0.03283299997981105, 0.036104139273187945, 0.07783360526497875, 0.050911466324968, 0.09284509332584483, 0.12614173628389835, 0.06761974655091763, 0.19749330330107892, 4.263335185391562, 32.50068875721523, 27.159023114613124, 30.953790460314067, 35.151058265141074, 56.42784588677542, 63.250542640686035, 70.38484873090471, 17.317577259881155, 0.3737723449511187, 0.7879824457424027, 0.24336480828268187, 0.669571191072464, 8.138887933322362, 54.947771889822825, 56.34046534129551, 64.39042936052594, 62.90812151772635, 66.99803965432304, 62.16633183615548, 60.96153504507882, 52.515266622815815, 52.61607108797346, 52.17105981281826, 56.23246949059622, 56.41367156164986, 56.8102399962289, 54.137254101889475, 56.539892537253245, 52.80687556947981, 53.99429838997977, 50.58690527507237, 46.36710793631417, 47.35323102133614, 45.04419524329049, 45.901971203940256, 47.27738101141793, 41.55282967431204, 37.53971345084054, 40.59025403431484, 42.25584145954677, 45.18118592670986, 47.31440101351057, 46.91656800678798, 47.76583589826311, 45.61549002783639, 48.61321040562221, 47.72613041741507, 52.39048739842006, 50.30765717370169, 45.03805998393467, 50.649880273001536, 54.30128717422485, 53.22346871239798, 53.37948703765869, 54.73660223824637, 50.941614287240164, 54.236571652548655, 53.18936000551496, 48.0075672013419, 45.267506871904644, 43.986133984157014, 44.971416337149485, 42.56672818320138, 45.3984317779541, 47.41351359231131, 52.66956179482596, 51.52867453438895, 41.80933632169451, 46.673280307224815, 51.082402161189485, 46.062804630824495, 40.14737933022635, 43.70074020113264, 44.05423675264631, 49.59865256718227, 51.14590522221157, 54.07694721221924, 52.097395011356895, 54.99368558611189, 56.50211865561349, 55.458982127053396, 52.41229779379708, 51.99857425689697, 51.98753356933594, 52.54657520566668, 46.98128700256348, 41.14429644175938, 34.099083627973286, 38.95348078863961, 43.32900810241699, 43.24896832874843, 37.91748700823103, 43.596360887799946, 54.08248840059553, 51.018551690237864, 52.40285171781267, 51.33812018803188, 50.420645305088584, 51.17760637828282, 44.85547522136143, 44.794424874441965, 42.42061104093279, 43.11224167687552, 45.12191431862967, 44.35027517591204, 44.26986714771816, 44.02254254477364, 43.86396380833217, 43.2562187739781, 47.042889731270925, 45.89396687916347, 47.33618361609322, 47.046527113233296, 47.035017422267366, 46.04433284487043, 45.19192089353289, 44.205360071999685, 45.04611989430019, 41.5099002293178, 42.04184736524309, 38.391124861580984, 36.25943143027169, 36.88561003548758, 43.06136696679251, 44.72142015184675, 43.68923051016671, 44.33035469055176, 43.67360748563494, 44.5558237348284, 45.53741659436907, 43.97871330806187, 45.063427856990266, 45.380435943603516, 49.41718993868147, 53.674483231135774, 57.447702475956504, 60.6844756262643, 62.400055340358186, 61.91454996381487, 64.31502750941685, 67.09277139391217, 67.01953738076347, 65.49499838692802, 67.3047261919294, 67.5894911629813, 66.59182017190116, 69.34314700535366, 74.15965911320278, 67.1832855769566, 1.7638810936893736, 0.12931882723101548, 2.1548509086881364, 57.58581876754761, 64.39517498016357, 56.49237380708967, 39.08527421951294, 38.94120332172939, 29.661724294934952, 6.184230693749019, 0.19664712942072324, 0.024969732455377067, 0.054346091845738034, 0.041140144757394276, 0.04646132493923817, 0.014302346023863979, 0.03658229950815439, 0.011443029141186603, 0.05404421500861645, 0.008862585910329861, 0.024780236284381578, 0.03736783949924367, 0.02067559475212225, 0.05693571735173464, 0.11149217201662914, 0.42356994854552404, 7.822346244539533, 50.747481618608745, 31.14318445750645, 28.415490184511455, 42.52456651415144, 65.51241752079555, 68.3308014188494, 81.3786290032523, 20.22594380378723, 0.28331388320241657, 1.141774132847786, 0.20811110069709166, 0.5399132456098283, 11.23250126838684, 69.21142305646623, 64.05856949942452, 76.02488218035016, 67.74752793993268, 74.35450049809047, 66.3692068372454, 65.72531727382115, 56.83412790298462, 58.448600905282156, 56.636594091142925, 61.1921318599156, 58.9390811920166, 59.53576469421387, 56.34172643933977, 59.4591121673584, 56.32897996902466, 59.826845577784944, 53.11816528865269, 50.28307792118618, 49.95780495234898, 48.26044341496059, 49.58684062957764, 49.283739362444194, 43.11795309611729, 41.37274278913225, 42.991131101335796, 46.10704033715384, 48.065668037959504, 48.60796104158674, 47.82878657749721, 50.47291660308838, 47.27877412523542, 49.42074741636004, 51.180288382938926, 54.77953168324062, 52.83443907329014, 46.914407117026194, 52.61879130772182, 57.074434825352256, 57.21504552023751, 57.87459979738508, 57.47638463973999, 53.7797658102853, 56.098087855747764, 56.525058133261545, 51.079511710575645, 47.55977317265102, 46.20095566340855, 48.440540722438264, 45.4083433832441, 48.46625600542341, 48.56279080254691, 56.66494968959263, 55.041131360190256, 43.37160750797817, 47.992694582257954, 51.620564460754395, 45.19227177756173, 39.453695501599995, 42.127369267599924, 46.75506060464041, 53.02836677006313, 53.10975796835763, 53.423736640385215, 53.77900845663888, 55.83884014402117, 57.40623215266636, 57.851535252162385, 51.959250926971436, 53.038188048771445, 54.57366003308977, 52.874248777117046, 47.02781561442784, 42.71307461602347, 34.57224552971976, 40.24858679090227, 41.80631732940674, 44.90409524100167, 38.086130210331504, 45.06087786810738, 55.58100291660854, 53.37783684049334, 52.102376869746614, 53.70198767525809, 51.60115466799055, 52.33553409576416, 47.57428101130894, 47.35789673668997, 44.90743037632534, 45.04908677509853, 48.87696402413504, 47.33100373404366, 44.443645068577354, 46.15168251310076, 47.29736403056553, 46.141062191554475, 48.21919890812465, 49.27828850064959, 50.51312582833426, 48.617379324776785, 47.54950720923287, 48.17085681642805, 48.1119430405753, 45.73194531032017, 47.342179911477224, 44.15435682024275, 42.740922995976035, 42.491034507751465, 38.85152987071446, 40.90576131003243, 46.03551210675921, 46.84130164555141, 45.628000259399414, 47.32977042879377, 46.15928384235927, 46.85857834134783, 48.03626673562186, 46.989260060446604, 47.6979797908238, 48.716182708740234, 52.69732332229614, 58.21454388754708, 60.530691146850586, 64.16255623953683, 65.22497054508754, 64.9317843573434, 66.51724515642438, 69.72341496603829, 69.5850693838937, 68.53642640795026, 69.99602058955601, 71.62630421774728, 69.85966914040702, 74.5283374786377, 76.19764219011579, 77.53437832423619, 3.1985721715859006, 0.23334870859980583, 2.3073113220078603, 65.54062720707485, 68.58522360665458, 63.6871257509504, 47.03589289528983, 44.946427140917095, 46.03514037813459, 14.421882493155342, 0.2232770368989025, 0.07617561173226152, 0.07494821652237858, 0.024883745105138848, 0.031461304120187245, 0.030852322333625386, 0.013353799020738473, 0.06896915592785392, 0.22926672335181916, 0.08262324825461421, 0.19262870933328355, 0.13698537727551802, 0.21444552365158284, 0.2355803017105375, 0.22070857829281262, 0.47221640391009195, 11.589590907096863, 67.0420981815883, 41.52214295523507, 39.40917491912842, 47.59117208208357, 76.50740677969796, 72.89337076459611, 90.66953781672886, 24.10566677365984, 0.34021835401654243, 1.4421869899545396, 0.2931097304182393, 1.231436075908797, 16.275767837251934, 84.57969188690186, 70.79486887795585, 82.41197899409703, 71.55186816624233, 79.23287241799491, 68.24546364375523, 70.14417007991246, 60.3336124420166, 60.56983034951346, 58.98741980961391, 62.85207734789167, 62.418183190482004, 64.03973293304443, 60.03453418186733, 61.99768515995571, 59.59915310995919, 62.23750223432268, 54.835343088422505, 52.455598967415945, 52.56204536982945, 50.462518623897004, 52.40123973573957, 52.242025239127024, 46.44089085715157, 44.07933364595686, 47.04016603742327, 48.40091514587402, 49.604589802878245, 52.44383566720145, 50.45157173701695, 51.52357108252389, 47.85664537974766, 52.10487127304077, 52.25393097741263, 57.30215161187308, 54.380197865622385, 48.46454674857003, 54.36693722861153, 58.548905100141255, 59.432722909109934, 57.160307611737935, 59.46215547834124, 56.98992388589041, 58.51711709158761, 60.34628595624651, 53.62441103799002, 48.95566279547555, 48.494281564440044, 52.02138866697039, 48.18485743658883, 51.20650393622262, 52.073100634983604, 59.305133138384136, 58.85409082685198, 45.07149124145508, 46.95112834657942, 53.16986683436802, 48.074791022709434, 40.75252226420811, 43.31902354104178, 46.84424073355538, 53.465988636016846, 55.53194168635777, 58.369092668805806, 55.448775223323274, 57.707481724875315, 59.552905900137766, 59.455610275268555, 54.48065144675118, 56.562359537397114, 56.04435396194458, 55.52923536300659, 47.20033591134207, 41.724019391196116, 35.520153522491455, 40.62011044366019, 45.418817792619976, 44.33160536629813, 39.28422893796648, 47.27454962049212, 59.745537757873535, 57.452420302799766, 56.46271194730486, 57.4852158001491, 55.391786098480225, 53.58142948150635, 50.64265067236764, 49.3739686693464, 47.39689697538103, 46.52457843508039, 51.575356006622314, 48.954933234623496, 47.31390074321202, 48.761502334049766, 49.50494916098458, 48.63485057013375, 52.826938492911204, 51.021424770355225, 53.416955198560444, 50.99018219539097, 51.82912506375994, 49.96225527354649, 49.41022089549473, 49.34565128598894, 49.94722284589495, 46.37491076333182, 47.82332181930542, 44.21529599598476, 42.24885504586356, 43.29651485170637, 48.78677640642439, 48.657032694135395, 48.079012053353445, 51.47079951422555, 49.068518911089214, 50.5222418648856, 51.783989565713064, 50.55676398958479, 50.2326374735151, 51.904693671635215, 55.26811858585903, 61.009484563555034, 62.63837160382952, 67.73054654257638, 67.68596690041679, 68.08375126974923, 70.34434768131801, 73.22117982591901, 73.49746104649135, 72.06140041351318, 73.44070816040039, 74.59640898023332, 73.55442932673863, 77.20936938694545, 80.9170949118478, 78.34220368521554, 3.0985991018159047, 0.237248602190188, 2.7432667059557776, 72.71781063079834, 75.18146119798932, 69.91276727403913, 55.1702219418117, 55.437345436641145, 64.81267138889858, 20.40556515966143, 0.3448951973446778, 0.16979927649455412, 0.15869771077164582, 0.11177493112960032, 0.222305849726711, 0.09339135472795793, 0.20725432809974464, 0.14563984716577189], [0.053705134096422365, 0.04854758602700063, 0.05436770997143217, 0.05944137754184859, 0.03531292672934277, 0.03304467576422861, 0.02693750606184559, 0.16273875321660722, 4.671410271099635, 36.21836410249983, 26.744215658732823, 33.67964172363281, 37.74497365951538, 56.3148820740836, 63.277793475559776, 67.51536778041294, 15.152332714625768, 0.18041644963834966, 0.8001137290682111, 0.06408899636673075, 0.519492327102593, 26.700825895581925, 67.33099038260323, 57.305278301239014, 64.88953930991036, 60.577751295907156, 66.40866565704346, 59.68785381317139, 61.32428659711565, 52.45088114057268, 54.24274860109602, 52.38314662660871, 53.442336968013215, 50.11724179131644, 52.88514355250767, 51.978132656642366, 51.96748801640102, 52.04723596572876, 50.26830952508109, 45.39610760552542, 45.44357769829886, 45.22491094044277, 46.125387055533274, 45.40354912621634, 45.720251492091585, 41.787741320473806, 40.210541929517476, 40.679885796138215, 42.91639280319214, 44.387684277125764, 46.65242528915405, 47.50182867050171, 49.83955008643014, 47.24876832962036, 47.04172938210623, 50.10523877825056, 53.34084810529436, 48.90031691959926, 48.85185670852661, 56.03482103347778, 57.54566165379116, 54.72893837520054, 55.29974331174578, 55.43084192276001, 52.50063371658325, 52.711070333208355, 53.73489086968558, 52.23313849312918, 47.32266936983381, 44.387006827763145, 44.17303010395595, 43.432925360543386, 43.56747375215803, 47.253298555101665, 50.90175594602312, 50.57203265598842, 44.623513085501536, 46.31423561913626, 42.88304839815412, 39.695961815970286, 40.738083907536094, 43.967988763536724, 47.62886953353882, 48.97164017813546, 46.81033699853079, 51.22279051371983, 52.900943756103516, 54.874246052333284, 53.06409093311855, 53.56388528006417, 56.686989375523154, 50.70122051239014, 50.6937928880964, 45.55826813834054, 46.489601203373496, 49.09094074794224, 42.82701465061733, 40.62058639526367, 36.97173295702253, 40.77043472017561, 43.64490795135498, 49.58388417107718, 54.22635085242135, 48.570617948259624, 48.394425528390066, 44.40653126580374, 45.421930585588726, 43.41957439695086, 43.33371550696236, 41.50840984072004, 44.83830622264317, 45.09713356835501, 48.749085903167725, 48.32475594111851, 45.94203104291643, 44.45070096424648, 43.83187355313982, 42.217991147722515, 42.23474325452532, 43.08829471043178, 47.808397088732036, 46.724398204258506, 45.86070932660784, 47.86235679898943, 46.239994117191856, 43.068874495370046, 43.605028765542166, 40.7580634525844, 40.95127548490252, 39.79690177100045, 37.19559696742466, 37.6531150000436, 44.55189105442592, 44.86275693348476, 44.18687091554914, 42.112757205963135, 44.917814459119526, 42.4722535269601, 43.310084683554514, 45.503102915627615, 45.44503682000296, 46.10835007258824, 45.02540731430054, 50.30152191434588, 55.77023363113403, 59.60533005850655, 58.95535387311663, 65.17621503557477, 63.14659064156668, 64.41587366376604, 65.27395534515381, 65.43967682974679, 63.142102105276926, 63.31676592145647, 61.549026080540244, 71.61054570334298, 66.32320976257324, 84.37975747244698, 10.839080367769514, 1.0224574953317642, 2.8960821287972585, 55.07009145191738, 63.86201190948486, 54.92850453513009, 43.451223441532676, 28.62940958568028, 27.179395232881816, 9.9912577016013, 0.12138080889625208, 0.05855703606669392, 0.14360794691102846, 0.07178643332528216, 0.047042015208197493, 0.07107174596084015, 0.020213999253298556, 0.058597354617502005, 0.055231593615774593, 0.047101000257368596, 0.04846623307093978, 0.03312108898535371, 0.021351893997884223, 0.1203371270426682, 0.172556177846023, 0.27027151733636856, 10.004541788782392, 53.11226626804897, 34.82064710344587, 34.00313595363072, 41.19586944580078, 68.01800046648297, 68.00261715480259, 77.73480606079102, 16.27542563847133, 0.13581057531493052, 0.8369353275213922, 0.05915321050477879, 0.5310713914888245, 29.16347244807652, 81.09775502341134, 63.34270354679653, 73.42590154920305, 66.00211266108921, 72.94015298570905, 63.89951828547886, 66.9899172101702, 54.64578580856323, 56.30008241108486, 54.81983470916748, 56.96666131700788, 53.24672085898263, 56.16630526951381, 54.98982586179461, 56.8708803994315, 53.722067969185964, 53.35627310616629, 49.16991744722639, 49.495857443128315, 48.745003836495535, 49.39384399141584, 49.18071494783674, 47.54881933757237, 44.79039491925921, 42.139132567814414, 42.95795692716326, 45.249535356249126, 44.76339421953474, 47.79871129989624, 49.237467833927695, 52.1779420035226, 49.320648193359375, 48.856977530888145, 51.37224973951067, 54.2086364201137, 51.44147464207241, 51.678481170109336, 59.117927823747905, 58.84771238054548, 58.01224708557129, 57.12621627535139, 58.43145969935826, 55.30634062630789, 56.40660524368286, 55.33170502526419, 54.52199322836739, 51.90060118266514, 48.245386668613975, 45.48387030192784, 46.46819380351475, 47.262484073638916, 49.58504452024187, 54.358759198869976, 51.3123527935573, 46.89897516795567, 47.466090611049104, 43.18862669808524, 39.09538732256208, 41.38105630874634, 45.189172880990164, 49.82085943222046, 51.742512294224326, 50.79471199853079, 51.37528262819563, 54.807626724243164, 58.46130221230643, 53.485238620213096, 55.73995338167463, 57.412426471710205, 52.91511113303048, 52.17280033656529, 50.157687255314414, 49.30584505626133, 49.80866534369332, 43.656521865299766, 40.487340790884836, 37.567117146083284, 41.74120923451015, 45.060339382716585, 50.102549825395855, 53.632783617292134, 49.86640139988491, 51.196418625967844, 47.67862210954939, 47.02447353090559, 45.40953847340175, 45.95463160106114, 43.826645033700125, 46.20726810182844, 48.517307894570486, 50.604977539607454, 50.30414138521467, 48.829108306339805, 47.03472907202584, 47.29583542687552, 45.630873339516775, 45.87575217655727, 46.11598266874041, 49.67123344966343, 49.88982377733503, 47.95380204064505, 50.229875564575195, 49.084204469408306, 46.302798884255544, 46.3604029246739, 44.728962421417236, 43.518641812460764, 42.46780667986189, 38.90950911385672, 41.53765133449009, 46.631358351026265, 47.59816196986607, 46.99514518465315, 45.806534222194124, 46.57811777932303, 46.17516395023891, 46.02868897574288, 47.22310515812465, 48.78732878821236, 48.7443402835301, 47.664274079459055, 54.899794578552246, 59.18455410003662, 63.155623299734934, 61.32115295955113, 67.5904847553798, 66.59360585893903, 69.6519249507359, 68.08112485068185, 69.86135060446603, 66.22994409288678, 67.47656209128243, 63.796712739127024, 75.42369624546596, 68.38048103877476, 90.85037163325718, 12.999165875571114, 1.0219492997441972, 3.6385794409683774, 65.54801314217704, 67.39253752572196, 63.54802976335798, 49.97050278527396, 33.016773155757356, 38.0679155077253, 20.82264815058027, 0.27162929305008476, 0.03727316011541656, 0.12913896116827214, 0.0843451733567885, 0.05971340901617493, 0.05662479564281447, 0.022614177782088518, 0.044686694629490376, 0.15939837960260256, 0.16778838368398802, 0.1972551510802337, 0.12088333416197981, 0.18943766770618303, 0.1445882943059717, 0.3167980121714728, 0.41037507514868465, 14.351496372904096, 70.74582849230084, 41.60417686189924, 45.354494844164165, 49.66250303813389, 77.22564206804547, 71.55360521589006, 86.86735848018101, 19.03986372266497, 0.13510246974016937, 1.434015691280365, 0.1211143210530281, 0.7286448840584073, 35.87527942657471, 92.37187426430839, 68.23408944266183, 77.17611530848912, 69.37327439444405, 76.87850311824253, 67.16128063201904, 72.95372281755719, 57.78376947130476, 60.507511956351145, 58.8583778653826, 60.9990622656686, 55.756653376988, 58.59180327824184, 58.594394956316265, 60.302588735307964, 57.65125690187727, 56.004558154514854, 51.5203332219805, 51.564086028507774, 50.5185558455331, 50.483787059783936, 52.31379665647234, 49.9384194782802, 48.27331147875105, 46.51492738723755, 46.68777424948556, 48.22752979823521, 47.376326833452495, 49.55955157961164, 51.47391925539289, 54.16998359135219, 50.084758962903706, 49.09449822562081, 52.888124329703196, 56.50028085708618, 53.60720035008022, 52.79897894178118, 61.34495053972517, 61.424576895577566, 59.038940702165874, 58.74569198063442, 59.08901636941092, 56.07871627807617, 58.185153007507324, 58.1807860646929, 56.121124608176096, 54.74832732336861, 49.767629282815115, 48.062881810324534, 48.870262486594065, 48.59614215578352, 51.30146844046456, 56.89143664496285, 53.69036333901541, 46.572934423174175, 48.580411434173584, 44.69948468889509, 40.118870871407644, 41.87436103820801, 46.69763721738543, 53.61609057017735, 55.52351352146694, 52.51712874003819, 55.59986727578299, 57.42031962530953, 57.70230531692505, 57.8153976712908, 58.43092468806675, 60.986340114048545, 53.75295966012137, 56.21737452915737, 51.659272875104634, 50.545990807669504, 53.749558516911094, 42.75217907769339, 41.15328393663679, 39.27248648234776, 42.36830152784075, 45.55298055921282, 51.43473836353847, 58.534807205200195, 51.94832141058785, 53.48135805130005, 49.75223554883684, 50.87598507744925, 49.04016331263951, 48.7477205821446, 45.7256988797869, 50.56275681086949, 48.9846784727914, 53.50543703351702, 54.646053314208984, 51.19448702675955, 49.479470116751536, 48.41775063105992, 47.91060161590576, 48.83404847553798, 48.847785064152305, 54.544154507773264, 52.44877931049892, 50.98990079334804, 52.825851099831716, 52.99084302357265, 48.044239793504985, 48.132461071014404, 45.46432154519217, 45.88259615216936, 46.445612158094136, 42.687929085322786, 42.99998310634068, 48.635138920375276, 50.46424525124686, 48.47147757666451, 47.376041957310264, 48.62357364382063, 47.85553019387381, 49.02571453366961, 49.957714625767295, 52.25168323516846, 51.215078013283865, 51.402189527239116, 57.17884540557861, 61.80374009268624, 66.09940828595842, 63.15719359261649, 72.1609194619315, 67.37169292994908, 73.44027737208775, 71.3801086970738, 71.98248972211564, 68.5279426574707, 70.28234195709229, 66.03946617671421, 78.29230867113385, 70.83600221361432, 93.39487143925258, 13.597860881260463, 0.9728670077664512, 4.143443584442139, 68.19375514984131, 74.53592491149902, 68.95986352648053, 62.33111531393868, 45.225456374032156, 53.026198932102744, 29.406002793993267, 0.5539781908903803, 0.2665388419159821, 0.2647148312202522, 0.17920206194477423, 0.20195492889199937, 0.1901100551975625, 0.16509179052497658, 0.17531081289052963], [0.052123014349490404, 0.036313029671353955, 0.04963145072438887, 0.067301968245634, 0.03211569007752197, 0.030831403099000454, 0.02867021817447884, 0.3449265999453408, 5.786827606814248, 37.97429200581142, 20.04987645149231, 29.020713022777013, 52.61011300768171, 50.405546869550435, 66.56761959620884, 62.834088461739675, 3.0238193316119055, 0.2870255240372249, 0.13091194603059972, 0.08255499441708837, 0.8589001031858581, 50.79221412113735, 62.53164727347237, 59.82686642238072, 66.79332487923759, 62.44856766292027, 62.874415806361604, 58.93950503213065, 57.766982623508994, 52.54833657400948, 51.401605878557476, 49.92906372887747, 50.83285066059658, 52.495835985456196, 50.03704220908028, 50.140726702553884, 50.14000061580113, 47.97350365774972, 47.126650265284944, 44.94038568224226, 45.82484967367989, 45.169082164764404, 47.30254738671439, 46.46464327403477, 47.71581929070609, 41.73246145248413, 37.815671580178396, 40.56971515927996, 42.589879580906455, 45.06638778959002, 47.24160473687308, 48.74601132529122, 51.6097982270377, 48.6454187801906, 47.64872053691319, 50.34687628064837, 54.077433586120605, 46.52738898141043, 52.73866162981306, 54.97779158183506, 55.84709460394723, 56.29853296279907, 55.917101178850444, 54.962359632764546, 53.391966002328054, 55.50699070521763, 54.21546649932861, 50.44644396645682, 48.11180407660348, 44.218103068215505, 44.12794671739851, 44.10037279129028, 45.43013988222395, 46.62863118307931, 52.42498173032488, 49.71333258492606, 46.794852937970845, 41.539232049669536, 40.096824237278526, 38.78018924168178, 46.088137762887136, 45.25290175846645, 42.769556522369385, 47.77447598321097, 51.07015943527222, 51.000878947121755, 51.584075995853965, 54.786181109292166, 47.84575407845633, 46.382369654519216, 54.74593366895403, 52.42733716964722, 49.61781569889614, 49.60274853025164, 46.2362768309457, 46.036564758845735, 46.71161699295044, 43.30877494812012, 35.691666330610005, 41.35133538927351, 48.06623779024397, 49.740069253104075, 50.81010225840977, 45.84724719183785, 44.36740595953805, 42.91166802815029, 43.93014887401036, 44.39994089944022, 41.85193920135498, 41.97239664622715, 45.81905140195574, 49.64932230540684, 44.504573822021484, 47.03100831168038, 46.76646954672677, 45.70027542114258, 45.93115711212158, 43.77969952992031, 44.64864124570574, 42.90592186791556, 44.243543897356304, 46.226455552237375, 46.6041179384504, 44.242112568446565, 46.1065331186567, 43.61864376068115, 44.03424678530012, 40.512010369982036, 40.17211839130947, 38.742613383701865, 36.459317207336426, 38.25294951030186, 43.32553052902222, 45.20120368685041, 44.451500007084434, 44.06985282897949, 43.06589719227382, 44.51732724053519, 43.27325228282383, 43.65204375130789, 44.35060868944441, 44.7960854939052, 44.37783520562308, 47.332987444741384, 50.70358289991106, 57.047038078308105, 59.03393799918038, 60.76600578853062, 62.09204169682094, 62.068042618887766, 61.968801498413086, 61.973970958164756, 59.15584414345877, 60.234683990478516, 61.559531756809776, 70.18833977835519, 68.47043241773332, 83.21738638196672, 19.50393738065447, 1.2668966416801726, 4.0673747062683105, 59.48279162815639, 62.471288272312705, 54.07932697023664, 41.96210983821324, 32.28733737128121, 27.79396687235151, 13.9524986743927, 0.1319062712469271, 0.06727314407804183, 0.02586259293769087, 0.06667140565280404, 0.047555554259036265, 0.028976617447499717, 0.044710731732525995, 0.06183851284107991, 0.0029126009654386765, 0.09041355630116803, 0.00786873566851552, 0.04508423472621611, 0.07385773610855852, 0.0720700134656259, 0.0759035259751337, 0.3218813251171793, 10.642868450709752, 56.17054714475359, 23.974481310163224, 27.125517163957866, 57.932846546173096, 60.15424469539097, 72.50237478528703, 69.71358326503209, 3.774036092417581, 0.40219889102237566, 0.19824474012213095, 0.04335315279396517, 1.1729238842214857, 56.84411941255842, 74.66202081952775, 68.10646493094308, 74.56528799874442, 68.08790629250663, 66.71146120343889, 64.18422767094204, 61.59710761478969, 55.55932106290545, 55.50075469698225, 53.21064581189837, 54.224693707057405, 53.5282028062003, 54.03172486168997, 52.75426033564976, 54.44999599456787, 49.88077374867031, 51.068245206560405, 47.575347559792654, 47.9569912637983, 47.963779653821675, 49.486519064222065, 50.24090930393764, 51.06929438454764, 44.67202888216291, 41.646797112056184, 42.54895469120571, 46.178141253335134, 48.43547548566546, 49.14499078478132, 50.79780742100307, 51.54386677060808, 50.35523496355329, 48.52263368879046, 50.869995730263845, 57.02877126421247, 47.63614082336426, 56.99859871183123, 57.28470468521118, 57.6499992779323, 59.479560715811594, 58.97187668936593, 58.200647490365164, 57.28272097451346, 55.38493170057024, 56.86292471204485, 55.76697145189558, 52.46491302762713, 47.28965153012957, 48.62588391985212, 46.151053701128276, 47.214600563049316, 50.55542646135603, 56.05676691872733, 51.77022518430437, 47.50846767425537, 42.125996998378206, 40.23326253890991, 38.86926167351859, 46.94903693880354, 47.19649355752127, 46.55636296953474, 48.909047331128804, 51.232778549194336, 52.92998375211443, 54.28541054044451, 57.0885466166905, 47.50623382840838, 46.84904541288103, 56.86462354660034, 55.53308466502598, 53.000782421657014, 49.113300051007954, 48.64777421951294, 46.14207662854876, 47.83905601501465, 44.00051328114101, 36.01260362352644, 40.22147492000035, 48.73151738303048, 51.64904165267944, 51.943155424935476, 48.65683467047555, 47.25352784565517, 44.85816764831543, 45.861289501190186, 46.60408319745745, 43.23750032697405, 44.9891585622515, 48.07488134929112, 52.777161598205566, 47.23369073867798, 48.61170959472656, 47.94742012023926, 47.59842600141253, 47.72298288345337, 45.95572941643851, 47.40056562423706, 43.85378817149571, 45.92568193163191, 47.84930460793631, 49.08480896268572, 48.638123171670095, 49.238694190979004, 45.94524111066546, 46.62343740463257, 43.20530584880284, 43.809246744428364, 42.9012769971575, 39.476520333971294, 40.80322674342564, 45.61070271900722, 47.80403014591762, 47.57765088762556, 47.68097060067313, 44.926183564322336, 48.327281611306326, 46.61548171724592, 46.314503124782014, 47.92946597508022, 49.24794224330357, 48.54975945608956, 50.464672565460205, 53.83522285733904, 59.92336995261056, 62.713710921151296, 64.97647517068046, 65.67388670785087, 66.72639288221086, 64.10364246368408, 65.27985436575753, 63.06308719090053, 63.44222954341343, 62.68740504128592, 76.76183591570172, 69.41897964477539, 89.69123145512172, 21.885581833975657, 1.8177757731505801, 4.840909404414041, 67.97635296412876, 67.83193465641567, 61.759000641959055, 50.651801449911936, 40.73115307944161, 42.118235860552105, 21.878750017711095, 0.3197845976267542, 0.0920544100393142, 0.13326837601406233, 0.05348383668544037, 0.08800360347543444, 0.06589782823409353, 0.05555401649326086, 0.062305887761924944, 0.11810090632310935, 0.13527329771646432, 0.1523964681795665, 0.20257099797683104, 0.23954530752130918, 0.18088781434510434, 0.14414447812097414, 0.3598158024251461, 16.269771541867936, 74.92781026022774, 28.19745397567749, 39.209327357155935, 65.25834969111851, 68.28180967058454, 78.16457298823765, 76.26122515542167, 4.676257073879242, 0.4525155467646462, 0.41987722526703564, 0.43797345565898077, 1.799234179513795, 61.81578826904297, 80.63151700156075, 71.82141658238002, 80.39731407165527, 70.81622764042446, 71.85753331865583, 64.85235949925014, 65.79112366267613, 58.228631360190256, 60.546623366219656, 55.091165338243755, 57.3547077860151, 56.77355350766863, 57.03391293116978, 56.41415793555123, 56.64968449728829, 53.586063929966514, 53.60723161697388, 49.67945664269583, 50.64396735600063, 50.894088608878, 52.080305916922434, 53.03838259833199, 54.180027212415425, 47.36044672557286, 44.413719177246094, 44.19774832044329, 49.41168001719883, 50.46857050486973, 51.77083315168108, 53.29154716219221, 53.6718498638698, 51.21437277112688, 49.18221228463309, 52.729986803872244, 58.016478538513184, 46.28968415941511, 57.65509925569807, 57.60352625165667, 60.93805708203997, 59.69776889256069, 61.27993624550955, 58.73269190107073, 59.8729190826416, 60.24406405857631, 60.22503294263567, 56.16482530321394, 52.19096987588065, 47.84379121235439, 50.06761428288051, 50.09242630004883, 49.13972405024937, 51.735199315207346, 58.77935600280762, 53.27652515683855, 49.30605697631836, 43.46754476002285, 40.02512925011771, 39.815755707877024, 46.55155481610979, 49.75802687236241, 48.416308879852295, 51.948300565992085, 55.230351652417866, 55.45408017294747, 56.29309252330235, 59.90863282339913, 50.112256458827424, 49.34039844785418, 57.07348987034389, 57.07805483681815, 55.376298563820974, 52.2311304637364, 50.128800119672505, 51.14427934374128, 51.62266629082816, 43.79804972239903, 37.961559431893484, 42.713981355939595, 52.640900475638254, 54.012356758117676, 55.23883540289742, 50.1233423096793, 50.56654010500227, 45.622778688158306, 47.8137263570513, 48.80230910437447, 46.858119760240825, 47.40874712807791, 52.18352140699114, 53.673361097063335, 49.15188339778355, 51.34984179905483, 50.79616069793701, 49.78787980760847, 50.755406039101736, 46.95593302590506, 49.378196648189, 46.53364930834089, 48.51628998347691, 50.85974713734218, 51.15013320105416, 49.64337464741298, 52.48994043895176, 49.09172242028372, 48.77344281332833, 45.06436933789934, 46.12585605893816, 45.19064242499215, 42.42964022500174, 43.34857075554984, 48.66614873068673, 48.83806106022426, 48.80903843470982, 51.57202434539795, 46.85363122395107, 52.155450684683665, 49.387698309762136, 48.77604143960135, 49.05871500287737, 51.378659452710835, 50.539542879377095, 53.26030458722796, 55.745168004717144, 64.2159114565168, 65.58843776157924, 67.06096948896135, 69.11336312975202, 69.55446951729911, 66.25412382398332, 69.4723209653582, 64.94704260144914, 68.24780518668038, 65.41463552202497, 78.4535277230399, 73.02294772011894, 93.40776034763881, 23.88973065784999, 1.7053324239594596, 5.438988626003265, 73.34296090262276, 75.28420421055385, 66.12139238630022, 61.37755148751395, 49.347968510219026, 53.76482718331473, 32.11847530092512, 0.6184290296265057, 0.21582223049231938, 0.2927979842892715, 0.17233397119811603, 0.12516778068883078, 0.12426956317254476, 0.08526622357645205, 0.17084403043346746], [0.07365990243852139, 0.03792805497401527, 0.016391536686569452, 0.020075142150744796, 0.05353295922811542, 0.059391070955566, 0.0669862459014569, 0.19331856231604302, 3.6473695635795593, 37.84923832757132, 32.3098703793117, 38.42449011121477, 31.334669862474712, 57.28789390836443, 61.660489082336426, 64.69007737295968, 5.880226595061166, 0.26162950534905705, 0.37344550820333616, 0.33124565120254246, 3.7947313019207547, 65.77859606061662, 60.85071127755301, 61.9758608681815, 62.216219902038574, 63.73812552860805, 59.00400515965053, 59.742494446890696, 54.68438305173601, 51.18013552256993, 49.728990350450786, 50.57945680618286, 48.8902906690325, 48.52508987699236, 48.230580057416645, 47.227677072797505, 48.30234800066267, 45.281726360321045, 46.78586891719273, 46.904759543282644, 47.658406325748985, 45.04406322751726, 45.559563977377756, 44.85213661193848, 46.698835781642366, 44.030512128557476, 39.296186787741526, 39.35399580001831, 40.49606772831508, 43.288044997623985, 45.07897097723824, 47.29157270703997, 49.1111078943525, 48.54658760343279, 45.94623817716326, 51.95876802716936, 56.95844159807478, 49.269016129629954, 56.50184072766985, 54.97966759545462, 56.935602869306294, 55.89366837910244, 55.128143651144846, 52.65776375361851, 51.66129132679531, 52.722614765167236, 56.45360285895211, 54.44974933351789, 50.23215109961373, 48.82708290645054, 47.17544051579067, 45.815198625837056, 47.24133375712803, 49.218662534441265, 55.141855921064106, 47.15706600461687, 37.485715525490896, 41.06770992279053, 41.53650140762329, 39.30386802128383, 49.54418216432844, 44.025735242026194, 43.21023212160383, 47.59154033660889, 46.82448353086199, 52.223101820264546, 54.12988206318447, 57.221799169267925, 42.25475754056658, 40.73002052307129, 57.16104759488787, 54.132372992379324, 51.8374524797712, 47.53120565414429, 47.97674151829311, 44.0392564364842, 42.78681237357003, 46.605521474565776, 35.533393314906526, 37.051630292619976, 39.004758494240896, 50.572206360953196, 49.50531741550991, 46.75729445048741, 44.06904683794294, 42.12661191395351, 43.02415936333792, 41.38371052060808, 43.20751190185547, 45.07726519448416, 47.841995103018625, 44.72444609233311, 47.14735589708601, 45.7678987639291, 47.77726221084595, 47.1960141318185, 48.12189980915615, 46.265883105141775, 47.79336813517979, 45.49568918773106, 43.05652754647391, 44.77276733943394, 43.95799725396292, 46.690904412950786, 46.85791826248169, 43.717405455453054, 44.22283131735665, 41.27375875200544, 41.42077221189226, 39.83333117621285, 36.66666534968785, 39.995450019836426, 43.38789061137608, 45.62820175715855, 42.846921239580425, 43.22502483640398, 44.54484558105469, 45.80413361958095, 42.88685948508126, 44.24390172958374, 42.45133597510201, 44.27593987328665, 44.16473395483834, 47.10691390718733, 46.04526390348162, 51.56059455871582, 53.9894311768668, 56.064955370766775, 57.597804410117014, 59.20917156764439, 55.72807196208409, 57.86603266852242, 54.74889360155378, 57.55105692999703, 61.08112743922642, 73.90327753339494, 66.75482491084507, 85.63911151885986, 26.030587026051112, 1.6163973276104247, 6.362797660487039, 63.6106538772583, 59.63056591578892, 52.48437145778111, 43.10893433434622, 34.101609298161094, 29.84500387736729, 14.661136763436453, 0.16430292571229593, 0.11796802202505724, 0.047918750305793116, 0.04425539741558688, 0.06383637099393777, 0.03353850676545075, 0.03897202181230698, 0.07553854877395288, 0.06739171128720045, 0.02331076013589544, 0.02697792130389384, 0.04296349048880594, 0.1002964527745332, 0.040859214296298366, 0.275189891989742, 0.46169563702174593, 7.931275759424482, 54.05137436730521, 34.293772152491975, 25.807245867592947, 37.202100481305806, 66.04160622188023, 68.96230234418596, 69.15631689344133, 7.619946088109698, 0.39739670870559557, 0.5631094809089388, 0.343586194728102, 4.546761325427464, 75.37208502633231, 69.57221521650041, 69.2557178224836, 68.58847536359514, 70.28289086478097, 63.1242104939052, 63.907202993120464, 57.393096583230154, 54.853436197553364, 52.06646163122994, 53.940168448856895, 52.37045226778303, 48.89358064106533, 51.57396636690412, 50.62933792386736, 51.49736247743879, 49.25957005364554, 51.025583267211914, 48.02465976987566, 50.47553607395717, 48.19289650235857, 48.89189222880772, 47.91664654867989, 47.80630915505545, 48.52364812578474, 42.05131775992257, 43.76941967010498, 43.9446428162711, 46.86045782906668, 46.224867888859336, 50.44989027295794, 51.999811036246165, 50.39059782028198, 48.09633738654, 55.4130197933742, 59.18547821044922, 49.40974146979195, 60.02562659127371, 54.704828126089915, 58.7780636378697, 56.95413718904768, 58.11689043045044, 56.63197353907994, 54.32911123548235, 54.789672579084126, 59.394389697483604, 57.13133709771292, 53.4991523878915, 51.39617586135864, 49.51588215146746, 49.55551815032959, 50.31104442051479, 51.70248024804251, 56.70229278291975, 48.28105872017996, 37.2461451121739, 40.429920877729145, 40.901418685913086, 41.67655277252197, 51.2477936063494, 45.21717759541103, 46.400334221976145, 49.102099554879324, 49.18118742534092, 55.60498462404524, 55.964797088078086, 58.92733873639788, 42.023813315800254, 41.607960156032014, 59.2535149710519, 55.670471395765034, 55.02547706876482, 48.97281094959804, 49.819938795907156, 45.1296511377607, 46.75758280072893, 48.60816253934588, 37.57097339630127, 37.169513429914204, 39.9357510975429, 51.19823905399868, 51.61236558641706, 50.08455399104527, 46.75780861718314, 43.923732212611604, 45.200800691332134, 43.61505849020821, 45.890298230307444, 46.549216747283936, 50.63895075661795, 47.863294805799214, 49.3795793397086, 47.638034207480295, 50.57549285888672, 49.48210000991821, 49.17456579208374, 49.701593603406636, 49.23476845877511, 47.641136578151155, 44.73524359294346, 46.16676010404314, 45.19172286987305, 49.36277859551566, 48.44352844783238, 48.15100581305367, 46.060525621686665, 43.651043210710796, 44.48862075805664, 42.27141237258911, 40.08206626347133, 42.82928671155657, 45.58096442903791, 48.54608733313424, 46.47090360096523, 46.510112285614014, 48.12163577760969, 47.61709233692714, 44.82142557416643, 46.46831539699009, 45.98222289766584, 46.58888053894043, 47.00438281467983, 50.453138555799214, 49.665560245513916, 54.30164153235299, 57.30450357709612, 60.835640634809224, 61.306290762765066, 63.89056205749512, 59.260900906154085, 61.545760427202495, 57.139744418007986, 61.665769713265554, 64.60278715406145, 76.94269057682583, 69.78729670388358, 87.21282291412354, 28.555843796048844, 1.8013871439865656, 7.426733187266758, 70.94609642028809, 64.73217650822231, 57.70683554240635, 54.715691634586875, 43.58870049885341, 40.25713654926845, 21.770709003720963, 0.3090903971876417, 0.07158012475286211, 0.1567401915256466, 0.06494910057101931, 0.0372564240491816, 0.041374816093593836, 0.04998142212363226, 0.05065541435033083, 0.14377428298549993, 0.08993550123912947, 0.12519250650491032, 0.2312260339302676, 0.18493965906756266, 0.14093442394265107, 0.4307539244847638, 0.5566042299781526, 16.27459532873971, 68.95974540710449, 43.71081856318882, 52.94481120790754, 43.421836035592214, 74.97343908037458, 73.28886222839355, 76.51575156620571, 8.658990996224539, 0.5412746582712445, 0.87781744237457, 0.5240822093827384, 5.852111577987671, 79.91923631940568, 74.7636799131121, 73.7912517275129, 73.96392835889543, 72.76482909066337, 66.81715720040458, 65.9819142477853, 61.72049372536795, 57.499146938323975, 55.86552817480904, 58.55899388449532, 57.2603234563555, 51.348052637917654, 54.16103778566633, 52.92077391488211, 54.48736340659005, 50.434520857674734, 54.47993925639561, 51.51793956756592, 55.279718603406636, 50.97937427248274, 51.921966893332346, 50.898740427834646, 51.179517132895334, 50.10264710017613, 45.78639486857823, 45.3422521182469, 47.963248116629465, 49.04081644330706, 49.04311282294137, 51.505821909223286, 53.44171857833862, 51.06615727288382, 48.37949732371739, 54.342618533543174, 60.4830265045166, 52.83798265457153, 61.150428771972656, 58.04748140062605, 61.55368832179478, 59.05424758366176, 61.48829187665667, 58.897100176130024, 56.260102476392476, 58.080193519592285, 60.58356693812779, 59.41871534075056, 55.62232732772827, 55.14758818490164, 52.419221673692974, 50.478718348911826, 53.57699653080532, 55.22557129178728, 60.46886607578823, 48.74953753607613, 39.266052450452534, 42.811798095703125, 42.20561988013131, 41.742762156895225, 52.63491460255214, 47.75670249121529, 48.46855933325631, 52.63330609457833, 52.359547070094514, 57.55996104649135, 57.32833242416382, 60.73488480704171, 44.03683498927525, 42.000276293073384, 59.70088168552944, 58.820739473615376, 55.66119902474539, 51.83871010371617, 52.45089503696987, 48.19724954877581, 47.28013597215925, 51.9245342527117, 36.62818969999041, 37.31824656895229, 41.64641843523298, 53.39852162769863, 55.02030413491385, 52.69088929040091, 48.47901289803641, 46.23129497255598, 46.891349520002095, 45.697468348911826, 48.34152889251709, 50.39600351878575, 53.581231457846506, 49.559878144945415, 52.08218193054199, 51.206434454236714, 52.46943283081055, 50.2194949558803, 52.52781159537179, 51.98801646913801, 52.63961158479963, 48.81485060283116, 46.586886405944824, 47.90369858060564, 47.569622244153706, 51.06605652400425, 50.473899773189, 51.0403481892177, 50.19973775318691, 46.396391119275776, 46.14547429765974, 45.91892828260149, 42.266638960157124, 47.05272838047573, 48.982844148363384, 50.43871062142508, 47.90145083836147, 48.13631732123238, 52.22940731048584, 51.41071496691023, 46.92336334500994, 48.57225424902779, 47.77625124795096, 49.80363484791347, 49.79920537131173, 52.818329674857004, 52.418519905635286, 56.489417348589214, 59.3661869594029, 61.854837145124165, 64.67889772142682, 64.53700160980225, 62.159564290727886, 65.23997170584542, 59.19090475354876, 63.612835611615864, 66.42087364196777, 79.6213184084211, 72.86176340920585, 91.31549794333321, 31.282495839255198, 2.1033413069588796, 8.515638368470327, 77.23778751918248, 70.07929474966866, 61.543300764901296, 63.80175018310547, 51.72567680903843, 60.45216260637556, 32.080524240221294, 0.5720958901303155, 0.13806702994874545, 0.1707474613296134, 0.21741715419505322, 0.16098942208502973, 0.15851878108722822, 0.1732496949178832, 0.1741322111338377], [0.0380322609895042, 0.04534000510882054, 0.034669994443122826, 0.026510181670476283, 0.06886804063937493, 0.07417694612273149, 0.10915212186851672, 0.22507546682442936, 4.72883756671633, 38.97310944965908, 33.23331029074532, 47.44207068852016, 65.04565838405064, 50.85375779015677, 63.78678376334054, 64.5411079951695, 5.12371107510158, 0.2927747783916337, 0.35819125388349804, 0.3724454290100506, 14.239918725831167, 72.19006715502057, 59.13634055001395, 69.77584607260567, 58.477164949689595, 61.65852274213518, 57.8384622165135, 58.02636929920742, 50.514029094151084, 49.491723264966694, 49.44543784005301, 47.60589531489781, 47.89791073117937, 48.285776547023225, 47.78487048830305, 46.02926220212664, 45.8586665562221, 45.76762778418404, 44.231891768319265, 44.85763611112322, 45.11703668321882, 45.39350550515311, 44.275231157030376, 45.51211472920009, 43.79544414792742, 45.83747107642037, 41.52198314666748, 38.40530266080584, 42.72616154806954, 45.741398334503174, 45.73771578924996, 47.37745244162423, 47.58565868650164, 48.31383684703282, 51.711985383714946, 60.30928679874965, 56.48002338409424, 51.779334272657124, 59.19060598100935, 53.87413624354771, 56.28143344606672, 55.17049292155674, 56.31780726569039, 54.98542765208653, 51.40239797319685, 51.84286512647356, 52.10733093534197, 51.98077992030552, 51.02645526613508, 47.76255982262747, 48.292832442692344, 48.33238853727068, 48.310543400900706, 52.86974287033081, 52.6254893711635, 41.489024366651265, 43.32221623829433, 43.35000555855887, 40.20184973308018, 46.041984353746685, 46.90781675066267, 43.81463507243565, 47.34923580714634, 48.11630303519112, 49.043849331992014, 52.301039763859336, 53.466151918683735, 57.510149410792756, 41.67861638750349, 36.96862711225237, 56.79426956176758, 51.66281993048531, 55.382576261247905, 46.74735157830374, 48.892052037375315, 44.734079769679475, 44.76861579077584, 44.96902615683419, 39.60921703066145, 39.868065220969065, 38.722161361149375, 41.636663164411274, 54.53868280138288, 45.15092304774693, 45.481692041669575, 42.031654357910156, 42.1997903415135, 40.957688672201975, 44.87643098831177, 43.61631958825247, 49.29322712762015, 49.79521363122122, 47.229820592062815, 47.98202909742083, 50.90449006216866, 49.64849199567522, 51.034681933266775, 48.30697202682495, 53.1225391796657, 49.036730902535574, 46.85118545804705, 47.40032591138567, 46.2839275768825, 46.283427306583945, 46.24452434267317, 43.72863721847534, 42.63847180775234, 41.69984313419887, 39.791659355163574, 39.63570008959089, 38.20664324079241, 40.012942109789165, 44.27983086449759, 45.268107891082764, 44.98340197971889, 45.44388689313616, 44.31799384525844, 44.21577542168753, 43.334379059927805, 46.83026443208967, 43.70742784227644, 43.16594082968575, 44.123388699122835, 45.58229848316738, 45.26833370753697, 46.881093978881836, 47.50192594528198, 53.63383626937866, 55.19326564243862, 57.3792279788426, 53.979950359889436, 55.94270529065813, 54.07808671678816, 58.39322376251221, 60.84283202035086, 73.07847772325788, 66.76071003505162, 83.8567179271153, 26.760913916996547, 1.0930459818669727, 7.866488150187901, 66.49320438929966, 57.25879485266549, 50.8020076070513, 41.84125634602138, 22.33916023799351, 27.805282013756887, 13.592935476984296, 0.19080909554447445, 0.01014075250298317, 0.07401381273354803, 0.012735197303949721, 0.04059662463675652, 0.06378030364534684, 0.08055713626423053, 0.028400137488331114, 0.032801482028194835, 0.03309525376451867, 0.025052805497710193, 0.0349857337506754, 0.01109162942572896, 0.04532715365556734, 0.11515919917396136, 0.42033504641481806, 7.464907458850315, 58.311929838997976, 36.98172099249703, 45.38089452471052, 70.78296661376953, 56.3901241166251, 71.50621155330113, 71.01154845101493, 6.718467695372445, 0.3286241175872939, 0.33136808606130735, 0.5678715482354164, 17.500076907021658, 83.10368606022426, 69.23429652622768, 75.5454842703683, 64.64666502816337, 68.42724936349052, 61.60115841456822, 60.718014580862864, 53.41297735486712, 54.055352210998535, 52.808716842106406, 49.92456129619053, 53.93327930995396, 49.66285044806344, 50.82090323311942, 50.39928306852068, 48.78323629924229, 47.94648906162807, 47.86167587552752, 47.798860686165945, 47.468758719308035, 48.57988684517996, 47.915371554238455, 48.625164781297954, 47.73485735484532, 48.17033222743443, 43.865780762263704, 41.92325203759329, 44.40043422154018, 45.44274044036865, 46.76385702405657, 48.415270124162944, 48.06080082484654, 49.55207879202706, 52.96122980117798, 62.528881890433176, 57.37459005628313, 52.14667163576399, 61.232862200055806, 55.83671746935163, 57.4519339288984, 57.42569753101894, 59.59665175846645, 57.011939253125874, 56.51660564967564, 54.402268818446565, 57.11527633666992, 53.53999737330845, 54.27859435762678, 51.75947284698486, 52.146188735961914, 50.35639531271798, 50.97803674425398, 57.387513705662315, 55.46437392915998, 42.088976996285574, 44.31752831595284, 45.484408787318635, 41.061425277165, 46.63506868907383, 48.13834272112165, 47.11800670623779, 47.506602082933696, 51.28321552276611, 51.178273405347554, 53.263063022068565, 53.47011934007917, 59.31651428767613, 42.584786551339285, 38.43860190255301, 58.809254101344514, 54.569324357169016, 56.68319913319179, 49.314061301095144, 50.447479248046875, 46.74433258601597, 45.39288364137922, 45.921179498944966, 42.487028871263774, 40.734029633658274, 39.38066298621041, 42.990057604653494, 55.984915597098215, 48.34899125780378, 46.97452987943377, 43.779800278799875, 46.209911891392295, 42.492827142987935, 46.94134528296334, 46.4751489503043, 52.88595649174282, 50.296640804835725, 51.81433929715838, 48.443921021052766, 53.12232378550938, 51.65525334221976, 54.699929646083284, 50.73118461881365, 55.58560957227434, 50.72397933687483, 47.69489131655012, 49.4082476070949, 46.804945196424214, 48.04535150527954, 48.71063804626465, 48.5901597567967, 44.23164163316999, 42.56814214161464, 43.16385637010847, 40.62645762307303, 40.07016747338431, 40.98676340920584, 45.139145851135254, 47.25394821166992, 46.80584151404244, 47.41050154822213, 45.32007694244385, 46.31378051212856, 46.25892448425293, 48.6464957509722, 46.91658885138375, 48.4555036681039, 45.61206109183175, 47.934013571058, 47.83620030539376, 49.166867188044954, 50.6240816116333, 55.70727947780064, 57.44581951413836, 61.310216494968955, 57.551446029118125, 59.077426774161204, 58.744934626988, 62.674974714006694, 65.11895493098667, 77.35010514940534, 69.16737842559814, 88.73233836037772, 28.95420660291399, 1.3174570543425423, 10.097593801362173, 73.91767420087541, 63.599390847342356, 57.16930552891323, 48.03103126798357, 35.38960729326521, 44.66794681549072, 18.624328442982264, 0.2915390846984727, 0.04366315169525998, 0.007831049833579786, 0.0389876247250608, 0.03747758575315986, 0.11321051445390497, 0.049795642628201416, 0.02611006992602987, 0.07748204948646681, 0.1070244192544903, 0.0715436806370105, 0.09886069981647388, 0.16778132691979408, 0.17335357862923825, 0.27313992913280216, 0.44030408774103436, 11.34190239225115, 76.34098352704729, 43.204472064971924, 60.230660983494346, 79.80405603136334, 65.5241391318185, 75.0716449192592, 75.66732788085938, 7.931394747325352, 0.4966081093464579, 0.6064837191786084, 0.5813566446304321, 19.574590138026647, 86.42769731794084, 74.97301524026054, 80.79408400399345, 67.81825365339006, 70.29110363551548, 66.64309787750244, 62.353620529174805, 57.37290511812483, 56.099025862557546, 55.99947207314627, 51.19771099090576, 56.4050418989999, 53.08708947045462, 54.142131737300325, 52.1386707850865, 51.232108048030305, 53.221585750579834, 49.757752418518066, 49.41308355331421, 49.169389384133474, 50.4752824647086, 49.07265656335013, 52.98902259554182, 51.157512187957764, 51.67983954293387, 46.40458651951381, 44.63019725254604, 49.059173583984375, 48.214720794132774, 48.81255769729614, 50.1067395891462, 50.814642906188965, 51.139255796160015, 54.63759388242449, 63.758004324776785, 57.521801539829795, 55.19726433072771, 64.14929212842668, 59.21598775046212, 61.37255573272705, 61.419344902038574, 61.55349377223423, 59.30730792454311, 59.210359709603445, 56.90672615596226, 56.88600662776402, 56.47927645274571, 54.85099043164934, 52.7271762575422, 53.17191307885306, 54.3539753641401, 52.33962658473423, 59.38753877367292, 56.95482506070818, 41.842920439583914, 45.30075747626168, 46.06108842577253, 40.872225829533164, 48.90440593447004, 51.66526917048863, 47.481039660317556, 51.039003712790354, 53.16367598942348, 53.6768456186567, 56.23876108442034, 55.72058180400303, 62.0793125970023, 43.859419686453684, 39.65439421789986, 60.244606018066406, 56.799567563193186, 59.44406236921038, 51.75575903483799, 53.727855818612234, 49.40208455494472, 49.53670242854527, 47.47819784709385, 43.03367839540754, 41.66128063201904, 38.54034090042114, 46.45833778381348, 58.89593982696533, 50.024945395333425, 49.767424310956685, 45.30754934038435, 47.37642758233206, 44.7550424848284, 48.48015587670462, 48.17932319641113, 55.76439714431763, 53.49263497761318, 54.11082662854876, 51.553396224975586, 54.500481605529785, 54.87295716149466, 56.508816719055176, 51.66067641122, 58.57357815333775, 53.42824602127075, 50.390257358551025, 51.41874361038208, 50.1287966455732, 49.771555015019004, 50.95670230048043, 50.24989332471575, 46.55630390984671, 47.3947673525129, 46.98624801635742, 43.35688427516392, 44.656482287815635, 44.04708010809762, 48.403565883636475, 51.01380607060024, 49.032495975494385, 50.12858819961548, 49.97333417619978, 47.41216564178467, 48.894160815647666, 52.57814087186541, 49.508530957358225, 50.349919591631206, 49.5691157749721, 50.289970534188406, 50.64313357216971, 50.8955512046814, 53.77982486997332, 59.110055514744346, 61.06716850825718, 62.96583325522286, 60.4792605808803, 60.88982268742153, 62.297590255737305, 64.0889470236642, 67.43909045628139, 78.73889023917062, 72.24055276598249, 91.17302513122559, 33.28206580025809, 1.3972426759345191, 10.954649754932948, 79.3686888558524, 68.38713046482631, 64.66233321598598, 60.16326345716204, 35.84327949796404, 61.0304194859096, 31.22365501948765, 0.608293887759958, 0.14471273762839182, 0.2684235136423792, 0.25948818453720635, 0.16517824945705278, 0.17725326865911484, 0.17546830086835793, 0.1616210024803877], [0.0798676021929298, 0.019306394205029522, 0.04648268861430032, 0.021555074523868303, 0.11580547663782324, 0.045610231679997275, 0.15138550528458186, 0.3756806568375656, 6.257775638784681, 43.64181252888271, 33.31411436625889, 24.291287899017334, 37.35362679617745, 53.4794716153826, 62.567048345293315, 65.8203547341483, 6.884338131972721, 0.5217766016721725, 0.4087269407297884, 0.42801223588841303, 25.988790137427195, 75.1684958594186, 63.31886427743094, 64.45924431937081, 60.374321937561035, 59.260748045785085, 54.77171148572649, 54.98125525883266, 48.84315061569214, 49.02357448850359, 47.21450328826904, 48.77403341020857, 45.51979596274239, 48.577479294368196, 46.50910479681832, 46.94429131916591, 44.74764960152762, 45.654858521052766, 46.38250861849104, 45.38929489680699, 46.11245993205479, 46.24529906681606, 44.601584570748464, 44.89866869790213, 46.099181924547466, 43.936843463352744, 41.89430931636265, 38.64050613130842, 39.99760743549892, 42.373700278145925, 42.6708538872855, 46.235571588788716, 47.23275968006679, 49.10921451023647, 54.189785957336426, 61.06939888000488, 54.39873218536377, 51.58162675585066, 53.74572311128889, 51.73667580740792, 55.51091296332223, 55.682397978646414, 56.1125887462071, 56.626157896859304, 54.46049124853951, 49.534659658159526, 50.594388484954834, 52.92105531692505, 51.05875744138445, 50.504461424691335, 49.605534757886616, 48.91375126157488, 52.40637445449829, 50.399724279131206, 52.423630305698936, 45.540439060756135, 39.76762901033674, 42.29362228938511, 44.80736936841692, 45.02310398646763, 43.027164459228516, 46.33336400985718, 47.84813036237444, 49.78686189651489, 48.538162912641255, 50.010117939540315, 55.25186674935477, 54.74846976143973, 49.0184189251491, 47.68983997617449, 55.14352696282523, 51.511967590876985, 51.42754350389753, 47.12680312565395, 48.10112816946847, 47.60096556799752, 45.54567800249372, 44.820379870278494, 43.39367151260376, 37.93737622669765, 39.796891348702566, 47.66896063940865, 49.94650370734078, 50.6530555997576, 45.98220552716936, 44.23435490471976, 44.31948075975691, 43.49347196306501, 45.42199311937605, 47.371456146240234, 45.86949184962681, 47.86459411893572, 50.32345390319824, 51.03680113383702, 52.41445173536028, 52.71012537819998, 51.77523136138916, 52.245033809116904, 50.21498557499477, 49.49958167757307, 48.279130595070974, 46.84940324510847, 45.400467600141255, 47.613128389631, 48.646106651851106, 43.337807995932444, 42.37401989528111, 40.40156527927944, 38.36606618336269, 38.44035979679653, 37.28083051953997, 39.531299931662424, 42.98778206961495, 43.40296472821917, 43.63149445397513, 46.32933405467442, 43.670480796269004, 44.941323689052034, 44.039642061506, 44.39052956444876, 43.50707653590611, 45.48645503180367, 44.2729868888855, 47.275765555245535, 44.941077028002056, 47.77585520063128, 47.232169083186555, 48.26883683885847, 49.83023950031826, 50.71342849731445, 51.978150027138845, 53.552434648786274, 55.51363318307059, 58.187067236219136, 62.39017500196184, 73.46710436684745, 68.1655524117606, 80.23205811636788, 23.907790763037546, 0.9269199818372726, 9.5222247668675, 67.97635296412876, 54.95032187870571, 45.41711548396519, 40.195207255227224, 28.939860309873307, 27.937813690730504, 7.6848327091762, 0.07368961548698799, 0.02389815941985164, 0.06566618316407714, 0.07113732637039252, 0.024032251510236944, 0.03302493039518595, 0.022521142149344087, 0.1331255715340376, 0.012066578226430076, 0.0361561184482915, 0.029577684123069048, 0.044874611510229964, 0.10399763738470418, 0.042150113598576615, 0.15036958908396109, 0.5503547053251947, 7.828309535980225, 60.73994309561593, 35.42506047657558, 28.570103236607142, 47.6984418460301, 58.46212904793875, 69.66639110020229, 71.58284323556083, 9.083895921707153, 0.58950623018401, 0.4949902104479926, 0.35467679532510893, 30.512371403830393, 81.90783854893276, 68.55285194941929, 71.75638839176723, 65.15319565364292, 64.6088946206229, 58.20828356061663, 58.66170910426548, 54.08753279277256, 52.38602665492466, 51.415832315172466, 51.60900960649763, 49.94874102728707, 50.05612543651036, 49.72740963527134, 49.798062392643516, 48.711124420166016, 47.45723860604422, 49.59402159282139, 48.992304120744976, 48.81074769156319, 49.215396881103516, 47.64585787909371, 46.93306997844151, 47.96197312218802, 45.814218929835725, 43.92837708336966, 41.43286902563912, 42.728336334228516, 44.0926707131522, 45.99515002114432, 47.015621525900706, 48.61465910502842, 49.79944855826241, 57.279827049800325, 62.422025544302805, 55.14241872514997, 52.07230854034424, 54.98879752840315, 54.14305237361363, 58.6434075491769, 57.13740634918213, 59.72560337611607, 58.2751738684518, 57.405026640210835, 52.107515062604634, 53.83468089784895, 53.296549865177695, 55.07087312425886, 52.38883720125471, 52.97811392375401, 52.26664618083409, 55.125253200531006, 49.46690777369908, 51.64017922537667, 46.59775686264038, 42.8825238091605, 42.8135073525565, 44.97314296449934, 45.71027735301426, 45.81499712807791, 48.59985596793038, 50.472020285470144, 50.90101596287319, 51.015473638262065, 52.042782170431956, 55.471304757254465, 55.971109526497976, 51.27902923311506, 50.485440731048584, 56.3343266078404, 51.68483182362148, 52.66619886670794, 50.259843145098, 50.962858404432026, 48.930413041796, 45.74754401615688, 46.02755989347185, 46.15383298056466, 39.8873291015625, 41.82241977964129, 46.73467806407383, 52.662672655923025, 53.36451366969517, 48.19720785958426, 45.744125502450125, 46.56069169725691, 45.77736221040998, 49.14771795272827, 48.15191602706909, 49.21435465131487, 49.65232392719814, 50.90997913905552, 53.536252294267925, 54.036213397979736, 54.05953502655029, 56.55690172740391, 55.48285961151123, 53.48851122174944, 54.46625477927071, 51.342469760349815, 48.75600630896432, 46.39236463819231, 48.42422635214669, 49.59757559640067, 46.17651884896414, 44.49812241962978, 43.235283851623535, 40.082323346819194, 40.59705632073538, 40.18812009266445, 43.04588638033186, 44.34114524296352, 45.059241567339214, 45.57003838675362, 48.39326170512608, 46.58996098382132, 46.378259795052664, 46.12418154307774, 48.7608630997794, 45.39376606260027, 48.628124713897705, 47.31216369356428, 50.15242052078247, 46.87323209217617, 50.702429498944966, 50.15452582495553, 51.65712935583932, 53.39471748897007, 55.21275881358555, 55.0337176322937, 56.332714625767295, 57.79661321640015, 61.762558119637625, 65.56278501238141, 76.39179570334298, 70.90829127175468, 83.55711160387311, 27.75982689857483, 1.1590591881956374, 11.251515013831002, 74.68505409785679, 60.2151734488351, 50.75277614593506, 47.9521483693804, 38.579660756247385, 41.1350588117327, 18.177555799484253, 0.22532277926802635, 0.07592722720333508, 0.04183266099010195, 0.01694851215662701, 0.03979562083259225, 0.02718037410107042, 0.013350785477086902, 0.011956880318133958, 0.15232613123953342, 0.163045912448849, 0.22461883989827974, 0.14120699145964213, 0.2243047867502485, 0.18340995615082129, 0.37179854086467196, 0.6072955184749195, 12.665112989289419, 73.85762092045375, 43.0444689478193, 32.728871073041645, 49.799889768872944, 66.76121725354875, 75.09497697012765, 76.31756114959717, 10.369649648666382, 1.0341632557766778, 0.9003894797393254, 0.647136814892292, 32.90573399407523, 86.18619183131626, 73.84453051430839, 71.48121888296944, 70.34428514753068, 66.67450373513358, 60.14630290440151, 60.29248605455671, 57.115648065294536, 54.62391287939889, 52.7207213810512, 56.09934547969273, 52.21351678030831, 54.419274534497944, 52.69202879496983, 52.04637786320278, 51.35254117420742, 50.05354765483311, 52.8926545551845, 50.53601666859218, 51.88648591722761, 51.751454625810894, 50.02807903289795, 49.997666767665315, 50.724010603768484, 48.94874586377825, 47.48489591053554, 43.543029989515034, 44.88790941238403, 47.04270212990897, 47.60849046707153, 50.072311265128, 49.397738456726074, 51.649917125701904, 60.53845228467669, 65.29933711460659, 56.53361483982631, 53.332145486559185, 56.62365307126726, 58.88796329498291, 59.989218030657085, 60.97536196027483, 61.91627311706543, 61.97024672372, 59.59555394308907, 55.43923534665789, 54.05613040924072, 57.78223391941616, 55.04117999758039, 54.73412867954799, 54.69250202178955, 54.625215666634695, 57.11688484464373, 54.156719480242046, 51.22484023230416, 46.01651920591082, 45.58519240788051, 44.74625996180943, 46.35257230486189, 48.9486312185015, 48.456868989127024, 50.01179245540074, 54.06573976789202, 54.74758734021868, 53.32240063803536, 53.43975918633597, 59.59799970899309, 59.67319311414446, 53.218886375427246, 51.533517428806846, 59.9842917578561, 54.63811847141811, 55.37557942526681, 52.941417012895855, 53.38127619879586, 51.58807815824236, 47.79081467219761, 49.282992431095664, 48.25116409574236, 41.685317925044465, 43.85079002380371, 47.93183878489903, 55.62963335854666, 56.29717806407383, 48.75318534033639, 49.29013170514788, 47.19989122663225, 48.52422482626778, 50.39884533200945, 50.507077421460835, 51.22041770390102, 52.42917149407523, 52.55983236857823, 55.095077174050466, 55.359605516706196, 57.48665407725743, 59.2567389351981, 57.88276393072945, 55.84852940695626, 54.55570241383144, 51.56527764456612, 52.08412047794887, 49.20677416665213, 50.85553305489676, 52.12871401650565, 49.01570912769863, 47.74450492858887, 45.664582524980815, 42.79595620291573, 45.0683992930821, 42.99341705867222, 46.60687984739031, 47.72667932510376, 46.4100512777056, 48.745656967163086, 51.994596413203645, 48.89002316338675, 49.54790987287249, 49.778392042432515, 49.7837803704398, 48.05576685496739, 50.94077008111136, 49.74085439954485, 53.425015108925955, 50.08162532533918, 54.05877767290388, 53.64175721577236, 53.10903535570417, 56.520031111580984, 55.6259890283857, 56.91977834701538, 58.702349117824006, 61.40974249158587, 62.97558157784598, 69.89927387237549, 80.09945869445801, 75.26008006504604, 84.83164051600865, 30.08682550702776, 1.3677150032349994, 12.740427987916128, 79.88829599108014, 68.3904447555542, 57.8715043749128, 58.820162773132324, 46.28320843832833, 53.63977003097534, 29.101859297071183, 0.45045977564794676, 0.14249193322445664, 0.1832611941333328, 0.1523981373757124, 0.09813134931027889, 0.1469087212213448, 0.17701620209429944, 0.18792624452284404], [0.0644952692091465, 0.024547670103077377, 0.022923742420971394, 0.017676897446757982, 0.03403587632679513, 0.05712177843919822, 0.06106503041727202, 0.244380955185209, 3.159812731402261, 46.46802704674857, 38.92245013373238, 29.18864229747227, 26.735273327146256, 52.499838147844585, 62.16572734287807, 67.49185507638114, 11.155590789658682, 0.7321872711181641, 0.39789719613535063, 0.3662271441093513, 37.52560860770089, 70.81802722385952, 59.914837564740864, 65.02888543265206, 58.85705770765032, 56.76314510617937, 55.97536529813494, 53.78136389596121, 50.63458728790283, 49.530396938323975, 48.08713449750628, 47.03210612705776, 46.99349846158709, 46.704470770699636, 47.52918372835432, 44.98287044252668, 47.90379932948521, 45.596118450164795, 46.07880285808018, 45.85225336892264, 46.124845096043174, 45.973801680973594, 44.36142703465053, 43.88580199650356, 45.94679055895124, 44.51485368183681, 43.48788561139788, 39.77867317199707, 38.4848039490836, 41.71450730732509, 44.17787299837385, 46.38064997536795, 45.480712345668245, 48.029113565172466, 56.60670294080462, 62.1165896824428, 54.78258194242205, 51.093824999673025, 50.62152467455183, 51.1375778062003, 55.01584686551775, 53.9985784803118, 53.056145668029785, 55.028746196201865, 55.09509107044765, 51.63272728238787, 43.312724999019075, 46.96608434404646, 49.68245826448713, 49.38439791543143, 51.718579224177766, 50.67279543195452, 45.63675498962402, 50.94431018829346, 54.27991451535906, 40.21109083720616, 36.36631209509713, 40.81938130514962, 45.395913055964876, 40.43279048374721, 46.493975094386506, 47.353964056287495, 46.549223695482524, 51.0103771345956, 50.427996499197825, 48.36082404000418, 51.029800823756624, 51.44290597098214, 52.37744562966483, 50.87446689605713, 52.52784981046404, 50.0157425062997, 49.99543987001692, 47.917386531829834, 47.993337290627615, 45.15428250176566, 44.81393889018467, 43.623979977199006, 43.8290491104126, 38.95919220788138, 42.59761292593819, 45.33977855954851, 51.96474347795759, 50.972203731536865, 49.11844171796526, 48.4190742628915, 46.107731682913645, 46.753691809517996, 45.06441797528948, 48.82777772630964, 48.326704910823274, 48.56103638240269, 47.69134773526873, 51.270062582833425, 51.64018964767456, 50.796428203582764, 49.747382232121055, 53.80961527143206, 53.411285468510215, 50.101358209337505, 53.38441331045968, 48.916721616472515, 43.04976347514561, 44.8501980645316, 49.00338649749756, 43.953463554382324, 42.108657768794465, 40.435972758701865, 38.50523165294102, 37.65627990450178, 38.19402183805193, 39.098979541233604, 42.877482891082764, 41.61610344478062, 42.530357837677, 44.15074028287615, 42.94908060346331, 44.500707149505615, 45.26871933255877, 43.79083054406302, 43.410628591264995, 44.33341884613037, 44.10000801086426, 46.28512961523873, 46.526395389011924, 44.97341047014509, 47.022062505994526, 49.09443916593279, 49.361319473811555, 50.692875725882395, 51.53817272186279, 54.03441728864397, 55.21021229880196, 57.15078163146973, 62.8050171988351, 71.82887894766671, 69.17803696223667, 76.74363163539341, 25.9185733795166, 0.7115124719483512, 8.437538879258291, 67.35009098052979, 53.70500666754586, 42.82184519086565, 41.238277775900706, 22.649928842272075, 26.7984585080828, 12.577268651553563, 0.10977539020989623, 0.07693511633468525, 0.04107563304049628, 0.09952760474490267, 0.03403980504455311, 0.03443608645881925, 0.03156666025253279, 0.02362916269339621, 0.05428130192948239, 0.06397726200520992, 0.01807724667846092, 0.10255620508853878, 0.05316594981455377, 0.0970291845234377, 0.04001918455053653, 0.27388919464179445, 2.829301255089896, 59.426247188023154, 44.78375244140625, 26.481978484562465, 33.89637688228062, 58.6397944859096, 68.40255546569824, 75.05273192269462, 12.437515190669469, 0.6816131249070168, 0.542093134352139, 0.4161546735891274, 41.44331564222063, 80.1873117174421, 67.11510290418352, 72.12230832236153, 63.05163655962263, 61.61503396715437, 60.260246413094656, 56.18805660520281, 53.21611404418945, 53.788586548396516, 52.098749910082134, 50.29819025312151, 50.43400321687971, 49.91529587336949, 50.277689593178884, 46.968113218035015, 51.28224972316197, 49.15528801509312, 48.891503129686626, 49.431979179382324, 47.510871750967844, 48.27318641117641, 47.19280753816877, 46.759566511426655, 47.96196269989014, 47.49535294941494, 45.17263616834368, 42.53033699308123, 41.72079542704991, 43.96986130305699, 47.183281557900564, 48.664731298174175, 48.33832924706595, 48.12159408841814, 58.38291263580322, 61.62881919315883, 56.87566076006208, 52.1703337260655, 53.06541109085083, 53.341431753976, 55.93589605603899, 54.69511801855904, 54.72755568368094, 59.65631593976702, 57.49695825576782, 52.34543180465698, 47.342548166002544, 49.04333169119698, 51.233369146074565, 52.91892569405692, 52.94286571230207, 52.60613168988909, 46.496608461652485, 49.49432536533901, 54.0929593358721, 43.641569341932026, 37.86079665592739, 41.39326776776995, 47.29924004418509, 42.09486212049212, 48.49402100699288, 49.05717945098877, 51.572090353284565, 52.031744956970215, 49.7408960887364, 48.09293624332973, 52.7689905166626, 51.88947016852242, 54.00166695458548, 52.74194812774658, 54.51482268742153, 53.181591919490266, 52.252246039254324, 48.83246428625924, 49.52293109893799, 47.2950815473284, 47.79871824809483, 43.89997632162911, 46.63698986598423, 42.641021796635215, 45.841514928000315, 45.15944153921944, 49.81373405456543, 52.80543729237148, 52.50189134052822, 48.39380019051688, 50.683315004621235, 49.94064290182931, 47.62795237132481, 50.013018812452046, 51.23358106613159, 52.854613167899, 50.51310150963919, 52.52480302538191, 54.25378581455776, 55.08184780393328, 53.190819127219065, 55.95077909742083, 53.775190421513145, 51.562741552080425, 54.05551201956612, 50.50712605885097, 44.52158996037075, 46.70036438533238, 50.794044971466064, 46.38669490814209, 44.667321477617534, 43.107794829777305, 41.33399963378906, 40.9503617967878, 40.595215048108784, 42.145462376730784, 44.889642987932476, 43.70793853487287, 44.815766266414094, 47.15969589778355, 44.65055200031826, 47.680807318006245, 47.05696330751692, 46.123663902282715, 46.07208742414202, 46.68948003223964, 47.14684520448957, 47.11391421726772, 49.685616220746724, 48.73110049111502, 50.103140422276084, 51.50990744999477, 51.73378883089338, 53.62922961371285, 53.87981986999512, 57.33858101708548, 57.221291950770784, 61.5502906526838, 64.76118523733956, 76.3057700565883, 72.77922575814384, 81.73826776232038, 30.197524206978933, 0.7822607127683503, 9.037272640636989, 73.47052982875279, 60.88479219164167, 49.19617816380092, 45.867299692971365, 27.459862743105205, 37.6700234413147, 24.481465305600846, 0.2604700247091906, 0.09514534739511353, 0.07729736582509109, 0.024131794293810214, 0.011822045231903238, 0.03784196584352425, 0.050892430025019815, 0.023724892110164677, 0.13408869771020754, 0.1315165614443166, 0.10405567927019936, 0.13194394351116248, 0.2059454611901726, 0.1516284751040595, 0.18465730707560266, 0.6433963498898915, 7.17283775976726, 73.97597653525216, 53.99706029891968, 38.93579067502703, 38.19567550931658, 68.1801575251988, 71.8536353792463, 80.10596915653774, 13.57825653893607, 0.9929996303149632, 0.6656469787870134, 0.43534171687705175, 44.14618573869978, 83.29545634133476, 70.35298429216657, 73.2403985432216, 66.23757321493966, 63.6893561226981, 63.48671885899135, 60.519011225019185, 56.34744480678013, 55.50984641483852, 55.38966689790998, 52.43486901691982, 53.68228605815342, 51.683567251477925, 54.2832670211792, 49.587215832301546, 54.6782443182809, 50.73866088049752, 52.32376732145037, 51.6923463003976, 51.38727521896362, 51.270892892565044, 51.118873255593435, 49.40991517475673, 51.67350625991821, 49.928817067827495, 48.654295103890554, 45.159351212637766, 44.579426765441895, 46.871814659663606, 49.58277940750122, 50.55506862912859, 49.56195913042341, 50.01024648121425, 59.997243200029644, 67.30676896231515, 57.19248819351196, 51.25698954718453, 54.64149529593331, 54.26154695238386, 60.033019474574495, 59.385808672223774, 58.33809675489153, 59.436419350760325, 59.66229139055525, 55.73285232271467, 47.64521517072405, 51.728105204445974, 53.811060496738975, 54.016497884477886, 53.875616209847585, 54.6359714780535, 48.66442905153547, 50.0407977104187, 55.89920956747872, 47.20963260105678, 37.62747267314366, 40.533438614436555, 48.83016790662493, 45.978665419987266, 51.46835027422224, 51.77238259996687, 52.90193387440273, 56.553142751966206, 54.39265945979527, 53.67780099596296, 55.67327846799578, 54.799608503069194, 55.845260279519216, 54.6491904258728, 56.42150565556118, 55.37587819780622, 55.2573037147522, 52.13201788493565, 52.22391823359898, 49.19907556261335, 49.90346656526838, 46.60238436290196, 48.04890203475952, 43.47558729989188, 46.378756591251914, 47.88870784214565, 50.81074496677944, 55.06327526909964, 53.305888244083945, 51.18014594486782, 52.113191740853445, 51.647259439740864, 48.45975596564156, 52.46579892294747, 53.652377537318635, 53.73975460869925, 52.23248188836234, 54.72648566109793, 56.71874959128243, 54.50643968582153, 54.83125754765102, 59.27112865447998, 56.041991574423655, 53.88850164413452, 56.78892292295183, 52.25378506524222, 45.41319669995989, 48.09928342274257, 53.92636585235596, 49.82259995596749, 46.48226390566145, 45.7893374306815, 46.040295941489084, 42.75404814311436, 42.13257346834455, 45.820614746638704, 47.68175227301461, 44.98956503186907, 47.031261920928955, 50.330770356314524, 47.52572699955532, 51.20887327194214, 50.703388350350515, 47.92985854830061, 48.240234579358784, 47.86806127003261, 49.688729013715474, 50.334810733795166, 53.472228118351524, 51.8171637398856, 52.461900983537944, 53.88546180725098, 54.52839599336897, 55.32932526724679, 55.70420489992414, 59.58559717450823, 59.93782915387835, 63.61754649026053, 68.52160590035575, 77.40029198782784, 76.44134330749512, 82.54284136635917, 31.895410333360942, 0.9964749238320759, 11.23865910938808, 80.3091344833374, 67.75155789511544, 55.78749990463257, 61.226858956473215, 37.833320004599436, 52.33279650551932, 34.225447041647776, 0.5008139950888497, 0.25552138739398544, 0.24616550228425435, 0.23171675045575413, 0.1309481662298952, 0.10890949131654841, 0.18977548315056733, 0.14372898398765496], [0.02255086537583598, 0.10495923007173197, 0.04284932357924325, 0.034241930448583195, 0.06226674307669912, 0.05625020020774432, 0.015695005222888928, 0.07479410764894315, 1.2685810370104653, 46.272622857775005, 42.416018281664165, 37.61332961491176, 47.02669695445469, 49.923567703792024, 61.50608621324812, 67.59949656895229, 11.045498320034572, 0.6360451014978545, 0.3745560800390584, 0.142252491787076, 39.578617164066856, 72.1420134135655, 63.966561453683035, 64.4666997364589, 59.44698756081717, 57.282477787562776, 52.84988839285714, 50.585307189396445, 48.628354004451204, 49.1601448059082, 47.574680532727925, 47.41798823220389, 48.544517040252686, 46.29610429491316, 47.435476848057334, 49.17441293171474, 47.61772462299892, 48.63428429194859, 48.3830999646868, 47.331264291490825, 47.826351233891074, 47.75007390975952, 49.031141076769146, 49.55646310533796, 45.64128521510533, 46.10744333267212, 43.16360623495919, 40.76278475352696, 39.06836230414254, 40.42460550580706, 43.70697620936802, 44.13565921783447, 45.079016140529085, 46.51361765180315, 54.140596185411724, 60.48396451132638, 54.06881087166922, 52.81174973079136, 49.827595710754395, 49.4485193661281, 50.539490767887656, 47.79275321960449, 51.505012444087434, 52.931203160967144, 52.11585637501308, 45.116748332977295, 44.45774296351841, 43.92337785448347, 43.900528703417095, 55.96544327054705, 47.74415751865932, 40.78974028996059, 45.80502298900059, 53.59351934705462, 38.89581421443394, 35.809479985918315, 42.121623107365195, 44.06472158432007, 45.312023980276926, 39.3238718850272, 45.13551541737148, 48.30972351346697, 46.57493550436837, 49.40996381214687, 44.59076622554234, 47.21657732554844, 48.01121500560215, 48.60975020272391, 51.63520431518555, 49.95324345997402, 48.139329365321565, 47.31275429044451, 44.132591588156565, 46.27724688393729, 47.45571347645351, 47.08651052202497, 45.449355125427246, 43.31742892946516, 42.136235169001985, 47.348235266549246, 40.8675149508885, 38.17310081209455, 47.04952873502459, 55.96602691922869, 51.42442028863089, 49.768136501312256, 49.64315230505807, 48.91217054639544, 47.50494493756975, 48.38381215504238, 47.339626448495046, 49.39619248253958, 49.88509552819388, 50.720505237579346, 51.34207371303013, 50.97083493641445, 50.00450379507882, 50.42298684801374, 52.665802819388254, 50.1141984803336, 52.989574977329795, 50.216993604387554, 48.45692457471575, 50.65940972736904, 48.586046423230854, 42.98248406818935, 42.07492773873465, 40.23637185777937, 37.705615588596885, 37.26436676297869, 40.22634560721261, 40.57159117289952, 42.902308804648264, 41.91205848966326, 42.40279933384487, 42.024185044424875, 43.414033208574565, 44.68839536394392, 43.876981258392334, 43.66719429833548, 43.74679980959211, 45.119089875902446, 44.539012568337576, 46.051684038979666, 46.686780657087056, 45.47541087014334, 47.90539394106184, 47.760812350681846, 48.74133518763951, 49.60124771935599, 50.58851725714547, 52.96617691857474, 53.64709690638951, 56.16605860846383, 59.0037967136928, 69.95668683733258, 68.34657382965088, 75.16592502593994, 31.84099551609584, 0.4898901783994266, 7.0798982211521695, 70.16613333565849, 52.7610695702689, 48.49391678401402, 37.99426112856184, 35.346702166966026, 33.44481692995344, 17.402423449925013, 0.10362842612500701, 0.08820291635181222, 0.08879450389317103, 0.040283691071506054, 0.08288743586412498, 0.08836806499000106, 0.044118601363152266, 0.026636131340637803, 0.013831765873224607, 0.0819789996104581, 0.016314434752400433, 0.04611103802121111, 0.00677584348678855, 0.05677559326535889, 0.0796169920691422, 0.2889808176883629, 1.4081526505095618, 57.44068826947893, 44.86292369025094, 31.99781288419451, 49.45945930480957, 57.539005279541016, 67.1805201939174, 74.64813831874302, 13.23358506815774, 0.603801714522498, 0.45005232893994873, 0.04680110134982637, 43.08225672585623, 78.59269319261823, 67.75922175816127, 70.21299198695591, 61.22132819039481, 60.83946214403425, 55.638297762189595, 54.11474193845476, 52.100389684949604, 52.83168758664812, 51.57485573632376, 49.48269060679844, 51.14915350505284, 49.18254579816546, 50.78786107472011, 51.25614881515503, 51.62491055897304, 52.235490458352224, 51.63104581832886, 50.404198919023784, 51.745652879987446, 52.49019752229963, 52.42036117826189, 52.72770779473441, 46.645240851810996, 48.46370254244123, 47.66783503123692, 42.22039869853428, 41.725277015141074, 43.33460487638201, 46.553100790296284, 46.98770366396223, 48.238038948604036, 48.63411406108311, 55.3711291040693, 61.562714031764436, 55.59782450539725, 54.30579308101109, 52.47381019592285, 51.94047689437866, 52.261712959834504, 50.543888977595735, 52.12834923607962, 54.53377389907837, 54.28560161590576, 48.1436824117388, 44.91236012322562, 44.27729824611119, 44.83206326620919, 54.77383763449532, 49.076683044433594, 41.2585699898856, 46.3986805507115, 53.68993255070278, 40.50560760498047, 39.946100439344136, 42.628931931086946, 43.746379443577354, 48.572601658957346, 42.29512310028076, 48.121493339538574, 50.35448803220476, 49.439722946711946, 50.44710404532296, 48.79561798913138, 48.47972508839199, 51.449482440948486, 50.60175704956055, 52.2290494782584, 51.97452654157366, 50.96320928846087, 49.63640213012695, 46.45637491771153, 47.34315265927996, 49.8909250668117, 49.28123453685215, 50.00447947638375, 46.40615333829607, 45.40974344526018, 48.777966090611045, 40.16272095271519, 41.736863136291504, 47.11416782651629, 52.40085758481707, 52.2840826851981, 53.044569969177246, 52.630377428872244, 49.13569756916591, 49.454112665993826, 50.983848912375315, 48.64845166887556, 53.56351702553885, 51.31377370016915, 54.66294091088431, 53.59201506205967, 53.478516238076345, 52.54726307732718, 54.72853537968227, 53.53854519980294, 52.07077646255493, 54.58882795061384, 54.24843570164272, 51.75764199665615, 53.49487229755947, 49.1558403968811, 44.4303948538644, 43.91211829866682, 42.760645457676475, 39.93641812460763, 40.27041803087507, 41.48014804295131, 43.32476970127651, 45.698566164289204, 44.32500805173601, 45.868303707667756, 45.55152143750872, 45.341605935777935, 45.53871938160488, 46.41429315294538, 46.963433606284006, 45.815403597695486, 48.09929384504046, 48.52642045702253, 49.63417870657784, 49.74395677021572, 49.74809094837734, 50.93976606641497, 51.11542694909232, 51.63338736125401, 53.259050437382285, 53.48941796166556, 56.32508897781372, 57.041489941733225, 59.604002952575684, 61.08505317143032, 72.64879417419434, 71.02569498334611, 82.46083177839006, 36.65436356408255, 0.39610542942370686, 7.995329465184893, 76.61515944344657, 59.31911986214774, 56.27212980815342, 46.92396783828735, 32.3990991456168, 48.45654589789254, 27.896504913057598, 0.19641102637563432, 0.03846930878769074, 0.0971412852938686, 0.014995803723910024, 0.043404595926404, 0.029085067699530294, 0.0399536855651864, 0.08572426864079066, 0.158536165154406, 0.3502830368067537, 0.19409981396581444, 0.14286713594836847, 0.13846845126577786, 0.15347360180956976, 0.18011292735380785, 0.4974965016756739, 2.438087058918817, 75.90059975215367, 52.661421980176655, 51.912565980638774, 63.04202025277274, 65.1216299874442, 72.59940637860979, 80.1616381236485, 14.356682334627424, 1.0391357775245393, 0.7943822251898902, 0.24279220615114483, 45.39511053902762, 80.40478338514055, 73.20256560189384, 72.26393345424107, 65.37120928083147, 63.44667639051165, 57.78791754586356, 54.54102087020874, 55.183812618255615, 54.000624724796836, 53.719316482543945, 51.8522903578622, 54.993734223502024, 51.269326073782786, 53.75380039215088, 54.744009017944336, 54.29142073222569, 52.070651394980295, 55.35044779096331, 53.05318226133074, 54.9760719026838, 54.005478041512625, 54.727955205099924, 55.44608974456787, 49.89988476889474, 51.95816700799124, 50.6893356187003, 46.00605869293213, 44.817388670785085, 45.56043250220162, 48.70900869369507, 49.746868065425325, 50.650762694222585, 51.11850847516741, 59.83910914829799, 64.74689974103654, 59.14358752114432, 56.95148645128523, 52.63276413508824, 54.525005272456575, 52.95077623639788, 54.29114280428205, 54.48145396368844, 56.588564668382915, 56.70134435381208, 49.96267563956124, 44.02201100758144, 47.277019705091206, 45.58954545429775, 54.7547960962568, 51.569807870047434, 43.40817935126168, 45.70727573122297, 55.623668330056326, 46.05716616766793, 39.15366186414446, 41.59790958677019, 44.56025321143014, 51.154760701315745, 44.216543197631836, 51.416516712733674, 54.6097628729684, 51.3945951461792, 53.458415099552695, 50.99601520810808, 51.06685209274292, 54.88194465637207, 54.49940463474819, 55.453972475869314, 53.52824796949114, 52.757248061043875, 51.96810293197632, 49.51906442642212, 51.03879526683262, 53.55954613004412, 50.85500846590315, 50.52153662272862, 48.276816844940186, 48.30298376083374, 48.42948613848005, 40.34131050109863, 43.599473680768696, 51.54487773350307, 53.00990193230765, 53.347348145076204, 57.54219797679356, 54.145338330950054, 53.33986840929304, 50.48952627182007, 53.79214402607509, 48.99203314099993, 54.187847409929546, 54.16312919344221, 55.2061892918178, 53.60063430241176, 57.45214237485613, 55.30291863850185, 57.00149611064366, 56.89536237716675, 54.45895569665091, 57.625586782182964, 56.004096099308555, 53.06632477896554, 53.706854888371055, 53.0256986618042, 46.29679911477225, 46.4195807320731, 45.06125654493059, 42.81834329877581, 42.60834094456264, 44.9199093409947, 45.86787639345442, 48.837143898010254, 45.75755637032645, 48.07281426021031, 46.888511180877686, 48.13122429166521, 49.28482328142439, 49.0788300377982, 49.58170938491821, 47.84380510875157, 50.04942389896938, 49.527068751198904, 51.58386060169765, 52.318361622946604, 51.3428692817688, 53.825689928872244, 52.502075467790874, 53.60474763597761, 54.93268040248326, 55.23752914156233, 58.1053911617824, 59.0994873046875, 62.42999512808663, 63.89905275617327, 75.53227574484688, 73.86982890537807, 83.63105433327812, 37.423939091818674, 0.5440588231597627, 9.655817781175886, 82.650726045881, 65.9836790902274, 64.19403852735246, 55.14113678250994, 54.76447146279471, 66.74595206124442, 38.534956046513145, 0.3481823466718197, 0.13470905513635703, 0.17134062307221548, 0.09248199566666569, 0.19064680353871413, 0.18311247282794543, 0.09162550126867634, 0.0772527250062142], [0.05919471649186952, 0.02969658381438681, 0.04759094664560897, 0.056233152015400786, 0.023512301999809485, 0.03753234352916479, 0.01750301436654159, 0.0675706070448671, 0.4331474703337465, 40.206063815525596, 43.76732131413051, 32.21657344273159, 37.03949873788016, 51.01823207310268, 56.82612705230713, 69.68716621398926, 18.623506818498882, 0.44056657222764833, 0.3068835570343903, 0.08802558122468845, 38.620196546827046, 67.76133401053292, 63.83370494842529, 66.58662291935512, 60.269112314496724, 57.76768439156668, 55.495084966932026, 51.64779445103237, 51.172596727098735, 47.28158119746617, 48.10537699290684, 45.042343548366, 47.17428364072527, 48.87080444608416, 49.05190576825823, 50.97352041516985, 54.07909073148455, 54.46622698647635, 52.23106792994908, 52.53657674789429, 51.65722663061959, 53.32301902770996, 51.82570307595389, 51.357811382838655, 49.08855404172625, 43.33335420063564, 45.16019194466727, 41.60056727273123, 37.96841382980347, 38.32126767294747, 45.001171997615266, 42.88821785790579, 44.03936413356236, 46.43144130706787, 50.33402211325509, 56.98638030460903, 54.85892874853951, 47.84773431505476, 54.56562096732003, 47.903941767556326, 46.48892722811018, 46.062575340270996, 45.71482842309134, 45.80011408669608, 45.672805718013215, 44.751057692936485, 41.234501429966514, 40.03542300633022, 43.45555911745344, 44.6925608089992, 39.37633078438895, 39.74569354738508, 50.48006282533918, 36.95703056880406, 32.21793181555611, 40.42120088849749, 39.80525350570679, 42.92564780371529, 44.962189129420686, 42.19772325243269, 46.757259709494456, 46.62768275397164, 48.05058349881853, 45.059800897325786, 44.6438296181815, 43.78524419239589, 45.95033066613333, 44.35832118988037, 46.72171967370169, 47.23489972523281, 42.81165565763201, 44.187343393053325, 46.1746324130467, 45.30995341709682, 44.845275265829905, 48.58288846697126, 43.47113003049578, 44.76832396643502, 41.89542102813721, 45.01715980257307, 36.59705829620361, 34.34400068010603, 36.532342774527415, 42.57668495178223, 55.748350279671804, 48.96544933319092, 46.58288771765572, 49.83198002406529, 46.87454182761056, 49.874440465654644, 49.84356961931501, 49.58570807320731, 45.72043909345354, 44.443999426705496, 49.697817257472444, 53.225066798073904, 52.19257838385445, 48.92122057506016, 51.55738796506609, 48.99754306248256, 51.85580962044852, 47.49101727349417, 48.45026472636631, 49.53434004102434, 46.40238046646118, 44.13143471309117, 39.34769378389631, 38.98397643225533, 37.244116238185335, 38.16844204493931, 40.327118805476594, 41.77285827909197, 42.89311981201172, 44.02393218449184, 44.815321581704275, 45.03372083391462, 43.33681092943464, 44.820484093257356, 44.45809384754726, 45.79288101196289, 45.69796861921038, 46.28447995867048, 46.565628392355784, 49.419416836329866, 48.80753067561558, 48.066689423152376, 50.09205109732491, 47.169392108917236, 50.50177942003523, 53.07610436848232, 53.35763495309012, 53.67659548350743, 55.391806943076, 56.082972049713135, 56.09914745603289, 63.33262171064104, 68.25221729278564, 73.05479826245988, 42.153824533735005, 0.23919998747961863, 7.196217579501016, 73.17311913626534, 46.944385119846885, 43.74235643659319, 39.216077532087056, 30.349050521850586, 32.48636851991926, 15.481415033340454, 0.17462988942861557, 0.030678603798151016, 0.0460805684061987, 0.01024690252130053, 0.08085518955652203, 0.01604780102414744, 0.027794933445485573, 0.05775325705430337, 0.05256587040743657, 0.03817847850067275, 0.007694973876433713, 0.06571475948606219, 0.04545318814260619, 0.02496515234400119, 0.013860027704920088, 0.03479512308591178, 0.13763739514563764, 47.404411452157156, 48.05935559953962, 32.42184059960501, 47.686859198978965, 57.20477955681937, 61.925083432878765, 77.84031445639474, 21.64546946116856, 0.380610675151859, 0.1384606481130634, 0.04588765072237168, 41.23931653159005, 76.81252997262138, 69.97824014936174, 71.30855614798409, 63.69622789110456, 60.490815435137065, 56.57794087273734, 55.71926859446934, 53.20871421269008, 52.24598571232387, 51.86017656326294, 49.713812010628835, 49.67116396767752, 51.48026296070644, 51.896112646375386, 52.21528509684971, 56.87625483104161, 56.982200963156565, 56.74364151273455, 55.07800545011248, 54.09093393598284, 54.981835433415, 55.13744728905814, 55.25952019010271, 50.72578239440918, 48.57497099467686, 48.54989494596209, 44.44078935895647, 39.82696315220424, 41.885745661599294, 45.53961917332241, 44.17815440041678, 46.74332162312099, 48.3908611025129, 53.330498763493125, 59.59282330104283, 55.826385498046875, 52.60651731491089, 55.439360414232524, 50.80942133494786, 48.91033622196743, 48.01041943686349, 48.96153402328491, 48.96054737908499, 47.917522021702354, 46.404259954180034, 41.45797981534685, 40.384472710745676, 43.72596911021641, 45.289862700871055, 41.380298955099924, 39.25080462864467, 50.68365546635219, 38.95782688685826, 35.239349024636404, 41.46584865025112, 38.74318661008562, 42.72906936917986, 48.845575537000386, 43.10042626517159, 50.44234105518886, 48.450396742139546, 50.563903263636995, 47.73073707308088, 45.113413197653635, 46.54249089104788, 48.919104848589214, 44.16974360602242, 49.27234084265572, 49.82429879052298, 45.00874553407942, 47.3246739251273, 47.6486371585301, 46.39267383302961, 47.44292879104614, 49.163532052721294, 48.04606369563511, 46.78430904660906, 43.313093253544395, 46.13237346921648, 37.45101622172764, 36.77664838518415, 38.64624881744385, 41.75756529399327, 53.835809980119976, 50.65768657411848, 49.6743358203343, 52.00525494984218, 49.73119292940412, 50.8953983443124, 51.87078298841204, 49.57486540930611, 47.25422961371285, 46.87801592690604, 52.149523871285574, 53.584952218191965, 54.61559935978481, 51.42316961288452, 53.06709950310843, 51.77143069675991, 54.68461234228951, 50.924052715301514, 52.01989827837263, 50.808545861925396, 50.185455730983186, 46.80152668271746, 41.826286452157156, 41.15287399291992, 39.52414328711373, 41.055779865809846, 42.375749996730256, 44.73373930794852, 44.882972717285156, 47.184233461107524, 47.727996008736746, 47.89502722876412, 45.47784273965018, 47.98908151899065, 47.063411235809326, 47.90010983603341, 47.55348852702549, 50.728811808994834, 49.84763431549072, 53.96170439038958, 53.01035009111677, 51.26506682804653, 52.574406215122764, 52.99019684110369, 53.081065382276265, 56.21330983298165, 55.57051113673619, 55.890194279806956, 59.182928221566335, 58.729120526994976, 59.566461835588726, 66.49092538016183, 72.52802753448486, 77.74763938358852, 47.34933655602591, 0.16938512586057186, 7.950956531933375, 79.29562854766846, 52.90797880717686, 50.93145602090018, 49.62777246747698, 37.28991181509835, 46.4661579813276, 26.253379276820592, 0.2910653586898531, 0.10758612411362783, 0.05708280338772705, 0.025976211930226003, 0.0941150462520974, 0.06507367281509296, 0.03764776912118707, 0.07972933711217982, 0.17559855245053768, 0.1336899905332497, 0.09502796083688736, 0.16363375447690487, 0.15069881427500928, 0.14990697747894696, 0.06174634064414671, 0.2125779510076557, 1.0024752361433846, 61.243680545261924, 57.51915775026594, 41.167426994868684, 49.365846225193565, 67.97424765995571, 64.75761386326381, 82.56113597324916, 24.181601899010793, 0.5019894891551563, 0.47502201050519943, 0.1417278213692563, 45.60000249317714, 77.38991137913295, 72.45863587515694, 74.6795163835798, 65.57146331242153, 62.68308326176235, 59.650069509233745, 56.19033214024135, 57.410067558288574, 54.69806752886091, 53.058459418160574, 51.16664212090628, 52.23081432070051, 53.8712284224374, 53.60646731512887, 55.74206215994698, 60.85986205509731, 60.10465540204729, 58.52855382646833, 58.32085132598877, 57.82604578563145, 59.23777035304478, 58.778376306806294, 58.68588188716343, 54.384655135018484, 49.45751033510481, 51.50008269718715, 47.45675918034145, 43.348588126046316, 44.802116530282156, 49.23720727648054, 46.32653740474156, 49.119577748434885, 51.00864355904715, 55.54268707547869, 63.9564448765346, 57.58056592941284, 56.671220438820974, 56.05497775759016, 52.57465287617275, 50.61350992747715, 48.93253919056484, 50.890756947653635, 49.865960189274375, 50.46633318492344, 48.99242224012102, 40.68577439444405, 42.54067243848528, 44.388413837977815, 47.76790993554251, 44.87316533497402, 39.94406114305769, 53.25281095504761, 45.7344640323094, 38.0055866922651, 40.638912269047324, 39.42200824192592, 45.73047924041748, 51.18519033704485, 45.31191975729806, 53.10081563677107, 51.5330171585083, 53.6075234413147, 48.620644978114534, 49.21224239894322, 49.91558074951172, 50.667219502585276, 47.29049226215908, 50.84432908466884, 51.53698805400303, 48.02144970212664, 49.23419523239136, 50.61898510796683, 47.77795008250645, 50.2458564213344, 53.45354093824114, 48.99868951525007, 48.4146899495806, 45.92401783806937, 48.822677748543875, 37.3087831224714, 37.96967840194702, 42.12537513460432, 46.90315798350743, 53.02750866753714, 51.896317618233816, 52.598648480006624, 54.122992924281526, 50.73284176417759, 53.30321666172573, 54.65786177771432, 52.00803770337786, 49.16345909663609, 49.724470547267366, 54.48630033220564, 57.2412645476205, 57.1843900680542, 52.75414916447231, 55.45310395104544, 54.6066882950919, 56.89384766987392, 53.34171315601894, 53.461322920663015, 53.476073946271626, 53.60092960085188, 49.83979327338082, 44.34419897624424, 43.86906726019723, 41.05925396510533, 44.833928857530864, 45.06151362827846, 46.91460861478533, 47.26253965922764, 51.07210145677839, 49.89765787124634, 49.01586546216692, 48.39880289350237, 50.432832445417134, 49.267730712890625, 50.88771711077009, 51.262214592524934, 52.877233028411865, 52.879314013889854, 55.710475649152485, 54.93039444514683, 53.486732482910156, 54.84662001473563, 52.46080664225987, 55.247131552015034, 59.15123053959438, 58.01505068370274, 57.216233662196565, 61.169327872140066, 61.70829963684082, 62.027353967939106, 69.99091366359166, 76.51869760240827, 81.37843445369175, 48.69172852379935, 0.27085454176579205, 10.14714401108878, 86.53458145686558, 56.965685095105854, 59.27701377868652, 57.069258417402, 49.34969513756888, 62.555187770298545, 36.596888065338135, 0.3390651158988476, 0.16170386517686502, 0.10755651963076421, 0.10970909733857427, 0.2526116392442158, 0.17777169655476296, 0.12643240711518697, 0.12683377414941788], [0.14511909868035996, 0.04392566332327468, 0.015642254214201654, 0.028451248138610805, 0.039694383407809904, 0.03723425631012235, 0.07675083979432072, 0.03116883517109922, 0.200367482645171, 28.384846891675675, 48.42135674612862, 27.206599167415074, 24.97273073877607, 49.13012511389596, 52.947694710322786, 66.67946474892753, 32.96742704936436, 0.17286785612148897, 0.3021580491747175, 0.18456864969006606, 32.60061774935041, 66.9101379939488, 64.45006574903215, 64.51295389447893, 60.16365255628313, 58.06881237030029, 54.534010137830464, 52.05463579722813, 50.00385761260986, 48.14241436549595, 45.92366347994123, 46.65908513750349, 47.76496737343924, 49.02497455051967, 52.9250922203064, 57.856200967516216, 56.9600362096514, 57.46583380017962, 56.75862182889666, 54.693544251578196, 52.44158445085798, 55.16667488643101, 55.29043272563389, 52.248320307050435, 49.34757593699864, 45.75519398280552, 44.57762370790754, 43.585681506565635, 38.471373081207275, 38.464966842106406, 41.62652226856777, 44.62332895823887, 41.41665540422712, 46.45010069438389, 53.60778399876186, 54.83971697943551, 55.19821970803397, 45.167762007032124, 47.45113113948277, 50.12628487178257, 47.7262624331883, 41.75549473081316, 45.24343831198556, 44.67462750843593, 47.5325014931815, 43.59067031315395, 40.056823457990376, 43.87586954661778, 37.82687555040632, 42.00693266732352, 34.48911033357893, 45.57830326897757, 39.30679668698992, 30.871370928628103, 39.434657437460764, 40.65733541761126, 44.94039610454014, 45.613895416259766, 44.87754270008632, 40.915575640542166, 45.3812905720302, 44.94458934238979, 46.18479415348598, 42.877990109579905, 42.465857710157124, 43.96887813295637, 44.47080210277012, 41.33080346243722, 45.82028123310634, 45.235472202301025, 41.501475538526265, 42.632284436907085, 41.9429988179888, 41.843042033059255, 43.95829255240304, 46.599174295152935, 43.7900766645159, 44.26590320042202, 43.34907102584839, 42.537785461970735, 42.480879715510774, 38.406233719417024, 32.45164837156023, 30.96855538231986, 38.84258753912789, 57.04647874832153, 49.77702324731009, 44.263106550489155, 47.65077025549752, 46.40249163763863, 45.97163036891392, 46.38179990223476, 44.575483662741526, 38.756179741450715, 47.60375526973179, 49.7874698638916, 49.12488269805908, 44.31688560758318, 46.95872272763933, 45.39619793210711, 50.83665132522583, 49.37353440693447, 49.95896182741438, 50.41400630133492, 44.9198329108102, 43.21642296654837, 39.41862794331142, 39.58752475466047, 37.37662533351353, 39.01822410311018, 41.98746728897095, 41.09420687811715, 42.46284219196865, 43.82526929037911, 44.88807269505092, 46.196439334324424, 45.933363165174214, 45.3081989969526, 45.74052286148071, 45.363989557538716, 46.58531263896397, 48.1438387462071, 51.32589135851179, 50.600023474012104, 53.976861885615754, 54.87195314679827, 53.82939679282052, 54.75449732371739, 53.137248516082764, 53.57069451468331, 57.80038608823504, 58.867111751011436, 58.57100731985909, 59.274297033037456, 60.00649125235421, 61.8117652620588, 66.51429217202323, 72.41712038857597, 49.442415373665945, 0.10235111109380211, 8.18176179272788, 73.89336245400565, 49.93574442182268, 43.85261740003313, 42.3218423979623, 22.28729714666094, 34.71957860674177, 18.836446523666382, 0.13332263167415345, 0.07456535992345639, 0.06394550656633717, 0.040950134596122165, 0.035083344405783076, 0.08706847365413393, 0.046551580274743695, 0.046208926875676425, 0.08010088931769133, 0.01652867200651339, 0.019432808671678816, 0.04703796435413616, 0.03880962124094367, 0.04079583573288151, 0.12035727953272206, 0.04486190594200577, 0.235548519130264, 33.46756533214024, 55.133768217904226, 31.55016824177333, 37.268368925367085, 57.04892798832485, 56.45601040976388, 74.23480388096401, 37.16339554105486, 0.10688464782599892, 0.2570029821779047, 0.2156301915113415, 35.60301079068865, 75.27466433388847, 68.46020466940743, 71.10353565216064, 63.57019451686314, 63.06128065926688, 56.61937992913382, 55.87369230815342, 52.14863102776663, 52.35506895610264, 49.39206872667585, 51.22038991110665, 51.31763342448643, 53.64398063932146, 56.128934383392334, 60.644328934805735, 59.07987254006522, 61.61449200766427, 58.01967818396432, 57.388125147138325, 56.403332642146516, 56.90778923034668, 56.96029329299927, 56.33700166429792, 52.00399732589722, 47.186585426330566, 46.74521848133632, 47.94731937135969, 39.27313266481672, 41.519096170152935, 44.25892720903669, 46.62721375056675, 45.35904938834054, 49.01985025405884, 56.02892896107265, 56.97769505637032, 56.67751898084368, 49.1128762108939, 50.01430422919137, 53.08115570885794, 49.462790966033936, 44.75045667375837, 46.218298367091585, 45.405046463012695, 49.969960825783865, 48.220863001687185, 40.7336231640407, 44.038401808057515, 39.781118937901084, 41.91038397380284, 35.955704825265066, 46.81844902038574, 40.75879648753575, 35.65180451529366, 41.70975821358817, 40.99927364076887, 47.09642212731497, 46.71930170059204, 45.907637459891184, 43.49231161390032, 48.22352416174752, 45.70360708236694, 47.25385093688965, 44.3031907081604, 45.1955999646868, 43.612070764814106, 46.02790035520281, 44.06702143805367, 47.23489972523281, 46.0335944039481, 45.5779002734593, 45.07701505933489, 45.879983629499165, 44.686265741075786, 46.123663902282715, 47.02375439235142, 46.194785663059776, 46.873107024601524, 43.38730696269444, 43.49980524608067, 43.99121311732701, 38.38384314945766, 36.045941080365864, 35.33039127077375, 41.19674491882324, 52.717424460819785, 49.52004412242344, 46.40405150822231, 49.38176107406616, 46.91074194226946, 47.606475489480154, 47.337104252406526, 46.117865630558555, 42.8622385433742, 48.85887091500418, 50.617105620247976, 49.811517579214915, 47.15416513170515, 48.186108112335205, 49.416637556893484, 53.35976110185896, 52.40300457818167, 51.938507080078125, 50.06947292600359, 47.97446250915527, 44.72351155962263, 42.6157477242606, 42.76420293535505, 41.00733355113438, 41.75839907782418, 44.66230835233416, 44.66560527256557, 46.423134735652376, 46.062815053122385, 47.37741075243269, 48.81826216833932, 47.590852464948384, 48.034025941576274, 47.04048565455845, 47.611030033656526, 49.094845635550364, 50.44081245149885, 54.64554609571184, 53.43747322899954, 56.28375761849539, 57.914871556418284, 57.06232064110892, 58.18259259632656, 55.86212008340018, 56.63651418685913, 61.249100140162874, 62.71931116921561, 62.188051904950825, 63.32677827562605, 63.91983481815883, 66.58414241245815, 70.16495214189801, 75.2252904347011, 54.39776985985892, 0.08500983911965575, 8.521498305456978, 80.95327418191093, 55.18023429598127, 55.0587728364127, 50.84010805402483, 33.767796993255615, 47.459437710898264, 30.97410351889474, 0.11393536627292633, 0.016263715956094008, 0.08926991945398705, 0.027532852687207714, 0.053989263850131204, 0.014368460779743535, 0.033792404391403706, 0.020434913291995014, 0.2725557376231466, 0.09862434571342808, 0.13410002924501896, 0.19442513079515525, 0.12697732501796313, 0.1632342194872243, 0.18281949497759342, 0.06154400150158575, 0.4406479692884854, 49.51593426295689, 65.0280099596296, 36.36555821555001, 34.610755920410156, 66.11212348937988, 61.1140410559518, 77.2715835571289, 39.25171831675938, 0.16147851012647152, 0.3541605658829212, 0.43128481028335436, 38.56241185324532, 78.03926917484829, 70.41348920549665, 74.21814210074288, 66.07074696677071, 64.59364332471574, 57.53119203022548, 58.99147060939244, 56.283003738948274, 54.53155394962856, 52.43154430389404, 51.74132762636457, 52.78563840048653, 56.35465703691755, 58.60553291865757, 62.87976591927664, 62.03347533089774, 61.68166719164167, 60.03662558964321, 59.71063000815255, 59.562619481767925, 59.33576079777309, 61.39053767068045, 57.746179716927664, 54.19196074349539, 49.622728075299946, 49.74786513192313, 49.907680647713796, 42.527665410723, 43.46801723752703, 47.17969628742763, 49.59725250516619, 44.6649625641959, 49.892012459891184, 59.00774329049246, 60.04988970075335, 60.15457820892334, 52.540443420410156, 53.131384236471995, 54.962641034807476, 51.22307538986206, 48.459870610918315, 51.018096583230154, 48.96623795373099, 52.99976798466274, 50.337937423161094, 44.740923745291575, 43.22449329921177, 44.017056941986084, 45.99674463272095, 35.11740466526577, 50.542631353650776, 50.30318948200771, 41.459088053022114, 44.03863109861101, 41.79199014391218, 47.54011671883719, 49.28592804500035, 49.085284914289204, 44.784554958343506, 51.494406018938335, 49.21745007378714, 51.06522968837193, 48.285168579646516, 45.97231476647513, 49.212009634290425, 49.16118008749825, 46.41167368207659, 51.33020966393607, 48.5680262701852, 48.48164626530239, 47.37014641080584, 45.6423795563834, 47.68565716062273, 49.161826269967214, 49.36106933866228, 48.68179954801287, 48.06339945111956, 46.59226083755493, 46.073310307094026, 43.66167395455496, 40.6845098223005, 37.305482728140696, 38.772706031799316, 49.06828614643642, 54.066962650844026, 48.793557848249165, 48.965258257729666, 49.866099153246196, 49.88863216127668, 49.18653406415667, 49.932829652513774, 48.83783176967076, 44.280383246285574, 49.908510957445415, 52.99083260127476, 52.38279226848057, 48.42550482068743, 50.265898500170024, 51.691352707999094, 55.10816758019583, 55.985454082489014, 54.56113937922886, 52.32445519311087, 50.23519441059658, 47.65239265986851, 45.18280138288225, 45.426679679325645, 42.57588243484497, 44.78154638835362, 46.6591476712908, 46.94628545216152, 48.116049425942556, 48.4894768851144, 49.85550662449428, 51.514548846653526, 51.08534124919346, 50.76154129845755, 49.78491292681013, 49.627237456185476, 53.27970743179321, 53.89245169503348, 57.24380758830479, 53.18212693078177, 59.62179034096854, 60.74558503287179, 59.83475957598005, 59.65484986986433, 58.21024642671858, 58.25082043239048, 63.336818422589985, 65.74592563084194, 64.48928833007812, 65.46093136923653, 66.54042434692383, 66.93816007886613, 73.47633157457624, 77.51305430276054, 56.99719170161656, 0.09836989508143493, 9.819238543510437, 87.69143567766461, 61.49542072841099, 61.702025413513184, 58.02014371326992, 37.7116049357823, 59.62247821262905, 43.52223750523159, 0.21204368610467228, 0.20845700427889824, 0.20381845746721539, 0.11454748628394944, 0.20289304426738194, 0.13278391558144773, 0.11451232459928308, 0.13533328021211283], [0.04220365001154797, 0.03754171409777232, 0.028049114359808818, 0.07062662020325661, 0.08721946805183377, 0.08983593979584319, 0.08350488916039467, 0.10317950057131903, 0.3347678179187434, 16.097800152642385, 47.94034685407366, 35.95054578781128, 29.110686983380997, 44.582223415374756, 52.89799771990095, 64.96240506853376, 37.62781660897391, 0.08745724707841873, 0.337803203612566, 0.27872698647635324, 33.43456833703177, 66.68316119057792, 64.58647973196847, 65.56609235491071, 62.70867347717285, 57.9837976864406, 55.87629093442644, 51.073588371276855, 47.581170150211875, 48.905462060655864, 47.49085399082729, 49.556688921792166, 54.7289731161935, 57.67232036590576, 58.05423852375576, 56.75277839388166, 74.21440396990094, 78.785630771092, 54.44745990208217, 58.411212648664204, 53.61495106560843, 56.978257860456196, 53.89096130643572, 55.28129584448678, 50.648369039808, 46.092098236083984, 43.626887798309326, 43.70118488584246, 39.82533032553536, 41.21364293779646, 41.35234982626778, 42.795480251312256, 43.51480988093785, 45.124610219682964, 50.94185400009155, 52.51173346383231, 50.43688324519566, 45.87151377541678, 42.77800900595528, 45.54612268720354, 47.65295198985508, 40.97787666320801, 41.33561508996146, 43.48506464276995, 43.11232852935791, 46.87130396706717, 29.652969564710343, 38.392017705099924, 38.12442173276629, 33.091344697134836, 46.90025363649641, 34.00203119005476, 28.378353800092423, 34.37510429109846, 38.84517921720232, 43.67510829653059, 40.993669918605256, 41.64060974121094, 42.86566400527954, 40.05077505111694, 47.421837534223286, 45.49379580361502, 44.94646883010864, 44.915754318237305, 42.96099328994751, 42.58583572932652, 39.47765636444092, 40.89089216504778, 43.10968473979405, 41.02978318078177, 41.15551430838448, 40.746626717703684, 42.51443951470511, 42.08437728881836, 43.909345967429026, 46.907788957868306, 45.62406063079834, 45.326385906764436, 40.35612753459385, 41.5934488432748, 47.95267295837402, 41.152172224862234, 39.85029867717198, 31.645212650299072, 30.873535292489187, 34.91725138255528, 57.84373589924404, 42.992690971919465, 36.7733862059457, 41.107686383383616, 46.83751835141863, 45.11370154789516, 40.14970350265503, 43.01636348451887, 45.1429499898638, 46.37435490744454, 45.131600107465474, 43.63939108167376, 42.71744155883789, 43.69591815131051, 50.272568770817344, 47.433326380593435, 49.62924895967756, 48.82601983206612, 43.77236918040684, 42.925547054835725, 39.62684113638741, 38.71910067967006, 38.18006985528128, 39.42865071977888, 40.868230615343364, 43.119158608572825, 43.46513026101248, 45.022704465048655, 46.61973748888288, 47.855835914611816, 43.73886496680123, 45.180762086595806, 48.12768765858242, 46.873940808432444, 47.77661255427769, 48.80018642970494, 51.12992089135306, 55.65866640635899, 55.94017962047032, 54.55587959289551, 56.88605179105486, 60.196420260838096, 59.12567506517683, 57.72602299281529, 58.42932660239083, 59.785865102495464, 60.97659873962402, 62.33749376024519, 63.965977805001394, 66.44162096296037, 68.89776052747453, 72.38522815704346, 54.03774894986834, 0.04825626040941902, 7.488751070840018, 78.38975020817348, 43.48109374727522, 44.173391410282676, 45.15515102658953, 21.45684323992048, 38.93249028069632, 23.924129452024186, 0.16365358127014978, 0.027511115817885314, 0.030407936179212162, 0.10438730647521359, 0.06050544937274285, 0.043639742237116606, 0.02525533123740128, 0.014816144614347389, 0.030141679037894522, 0.05080839007028511, 0.018426217238551805, 0.09444606956094503, 0.04973337346954005, 0.05786477428461824, 0.05044723980660949, 0.05207571706601551, 0.42664202941315515, 22.623390197753906, 55.71170200620379, 33.511064529418945, 32.93720585959298, 53.678634779793875, 56.292567934308735, 73.17586367470878, 40.669734477996826, 0.05420660540195448, 0.3088264742067882, 0.5689117152776036, 36.87587560926165, 75.21933582850865, 69.00643035343715, 71.46036733899797, 64.73385102408272, 62.520717757088796, 57.17643090656826, 54.952503613063264, 51.36083732332502, 53.02450704574585, 50.0860721724374, 51.93632534572056, 56.79228932516915, 60.74898270198277, 61.10211099897112, 60.659892899649485, 72.64388179779053, 78.17628070286342, 57.677003451756065, 62.26779638017927, 56.690539905003135, 60.887342180524556, 56.78957952771868, 58.77540247780936, 51.99248416083199, 49.07968814032418, 45.740196296146934, 47.67005845478603, 43.15041160583496, 44.89071995871407, 41.925114154815674, 46.364516258239746, 47.07753692354475, 48.45726156234741, 53.070309570857454, 57.00839567184448, 52.46098729542324, 50.70997176851545, 44.17538206917899, 47.87481491906302, 47.97833612986973, 45.59368658065796, 42.45806877953665, 45.849953515189036, 47.3843207359314, 50.05551746913365, 30.055972031184606, 37.46005582809448, 39.68043259211949, 34.57535137448992, 48.396523884364534, 35.94197171075003, 31.481721537453787, 39.67943899972098, 41.34925092969622, 44.542062827519004, 42.964255469185964, 43.08693633760725, 44.92706251144409, 41.522552898951936, 48.25509330204555, 47.66458674839565, 47.461570807865684, 47.655071190425325, 44.15569087437221, 45.73213638578142, 40.52110208783831, 43.17446974345616, 45.30763619286673, 43.71588379996163, 42.9702274458749, 43.12652022497994, 44.07070050920759, 43.814270292009624, 46.83184862136841, 49.541604382651194, 46.872964586530415, 46.43144130706787, 42.5445808001927, 44.2034284727914, 50.1690023967198, 42.92114884512765, 40.788559096200125, 35.42064489637102, 35.49325009754726, 38.221859795706614, 56.18289409364973, 45.9983948298863, 38.00464521135603, 41.53697041102818, 48.6630984715053, 45.92819023132324, 43.093234879629954, 45.02203743798392, 46.733264105660574, 48.70538173403059, 46.12808295658657, 45.4395546913147, 45.57824420928955, 46.24185970851353, 52.8214042527335, 51.29679230281285, 52.23419461931501, 49.743182046072825, 44.78658383233206, 43.40131800515311, 41.85096992765154, 41.15079995564052, 41.23135389600481, 42.89660085950579, 44.29375505447388, 45.691722188677105, 45.73117406027657, 47.35183095932007, 49.5173899105617, 48.76105070114136, 48.64879560470581, 46.126846177237375, 50.64935220990862, 49.20260872159685, 50.155244963509695, 51.04428781781878, 54.23363256454468, 56.97717046737671, 58.52580233982631, 56.21472726549421, 58.60667937142508, 63.54302706037249, 61.23222296578543, 60.73582976205008, 61.13394069671631, 62.876604488917756, 66.55545330047607, 66.35451834542411, 68.22185366494315, 70.3517336164202, 72.4742762701852, 74.08918353489467, 59.39944103785923, 0.061841199839753766, 9.66521087714604, 83.10100405556815, 50.029079573495046, 51.833415576389854, 51.29347106388637, 32.02459471566336, 51.030978543417795, 33.89129427501133, 0.19460807740688324, 0.012658021579097425, 0.13009661835219177, 0.1194151472300291, 0.10733199239309345, 0.023348973531808172, 0.06705928341086421, 0.036377585493028164, 0.09360275231301785, 0.121445717556136, 0.07311619911342859, 0.17098500286894186, 0.1514836893017803, 0.17101910603897913, 0.19099983173821652, 0.32070208553756985, 0.48514917279992786, 33.82654401234218, 65.92146492004395, 49.313616616385325, 38.76711968013218, 60.19467626299177, 62.59741197313581, 78.28885541643415, 43.26266322817121, 0.1332732071833951, 0.4526594233300005, 0.5669809845941407, 39.0328813280378, 81.66171251024518, 71.49075181143624, 74.0790183203561, 68.48525987352643, 64.56396756853376, 59.42391259329659, 57.738439423697336, 53.786769594464985, 56.29084130695888, 52.81607845851353, 54.04343952451433, 59.05005781991141, 61.46095071520124, 62.07720034463065, 61.869192123413086, 71.15810680389404, 79.60653959001813, 59.881472315107075, 63.95753574371338, 58.57704530443464, 61.062909262520925, 61.20959963117327, 61.778261048453196, 56.10019315992083, 51.067380155835835, 48.82382072721209, 50.31874997275216, 44.51569788796561, 48.01358781542097, 46.4234230858939, 47.74248647689819, 48.91216707229614, 50.37955018452236, 55.630519253867014, 59.66272217886788, 55.9646372795105, 51.838769163404194, 50.23146670205252, 51.82087060383388, 50.83247545787266, 45.523110253470286, 47.89120919363839, 47.06935541970389, 50.13230895996094, 51.84885447365897, 38.43924461092268, 41.76817866734096, 39.31239346095494, 39.62896728515625, 49.19208220073155, 44.49274451392037, 38.476191656930105, 42.598842757088796, 41.29819556644985, 49.520450592041016, 44.8875481060573, 46.380980014801025, 47.296731744493755, 44.67128542491368, 52.23010213034493, 51.50703089577811, 49.83364759172712, 50.60562719617571, 46.82054737636021, 49.14221150534493, 43.18243932723999, 46.714966024671284, 48.37120464869908, 46.2800053187779, 45.40829821995327, 46.80425385066441, 48.44640152794974, 46.55424724306379, 48.208703654153005, 52.96525280816214, 49.88144077573504, 50.06418882097517, 45.227763175964355, 46.02528435843331, 52.45444209235055, 43.36660133089338, 41.32170132228306, 37.36578961781093, 39.69263015474592, 47.49661404745919, 57.85396712166922, 44.16649879728045, 40.225296429225374, 42.78685406276158, 52.292111328669954, 48.03084714072091, 44.95909718104771, 47.58627707617623, 50.458738803863525, 51.34598554883684, 50.19684730257307, 48.16019133159092, 47.21382236480713, 48.98062072481428, 54.213211808885845, 54.24358238492693, 54.77770430701119, 51.99086175646101, 47.556979996817454, 47.6454097202846, 44.198276383536204, 44.33442633492606, 44.10296794346401, 44.07849986212594, 47.255004337855745, 48.92602178028652, 47.54466431481497, 50.31222561427525, 51.03983749662127, 51.57153797149658, 50.21101120540074, 48.07014267785208, 54.31826857158116, 51.01459469114031, 53.082343850817, 53.637939180646626, 57.0274441582816, 59.62301322392055, 60.617745126996724, 58.829792976379395, 61.929036957877024, 66.36041041782924, 63.89363316127232, 62.26410688672747, 65.29462623596191, 64.69621958051408, 69.9037207194737, 69.97398785182408, 72.52485915592739, 71.1901866367885, 76.74643870762416, 76.4923152923584, 64.43969903673444, 0.24204698471086367, 10.137941990579877, 90.92200756072998, 55.165643078940256, 60.811870847429546, 62.81515462057931, 36.259146554129465, 63.89714894975935, 45.090286118643625, 0.26021256138171467, 0.09786294121295214, 0.2703273200563022, 0.21142149663397244, 0.16614436118730477, 0.13304812354700907, 0.1109235461003014, 0.16380250613604272], [0.021144971351272294, 0.06364719543073859, 0.046998575396303616, 0.0066172999629218665, 0.08257675503513642, 0.019556293563385094, 0.10281943596367325, 0.22875111816184862, 0.3184727451631001, 14.812062059129987, 49.411270073481965, 35.24067265646798, 42.300389834812705, 47.16968740735735, 48.15222522190639, 64.88644736153739, 41.92755992071969, 0.18517749916229928, 0.6014628314546177, 1.197818085551262, 36.71470866884504, 66.77799715314592, 65.45998641422817, 65.6039183480399, 58.49695341927664, 58.62435558864048, 52.94314364024571, 52.129999433244976, 46.7390832219805, 49.406236103602815, 50.34212371281215, 58.51911817278181, 57.81547062737601, 58.9401581627982, 62.49244553702218, 66.1790554864066, 60.187637737819124, 51.6487637247358, 59.096360615321565, 60.11403547014509, 57.152442250932964, 57.60863317762102, 54.765736034938264, 55.58265658787319, 50.11623430252075, 44.61268779209682, 43.76823500224522, 44.45427581242153, 39.737147263118196, 38.9873810495649, 40.44868796212332, 41.36247682571411, 41.93803433009556, 46.242085524967735, 50.27122776848929, 51.571572712489534, 48.95990814481463, 52.190935134887695, 40.4926700592041, 38.96412542888096, 42.051984786987305, 44.24019486563546, 37.4458988734654, 42.66884585789272, 44.83490507943289, 49.01032427379063, 35.45098767961775, 31.043474333626882, 40.26130199432373, 37.96384538922991, 38.55936506816319, 28.60666639464242, 32.54853057861328, 40.125773906707764, 39.459851605551584, 41.07024254117693, 37.65452201025826, 42.1480575289045, 43.257966245923726, 41.214421136038645, 43.991015093667166, 44.46476411819458, 44.60078205381121, 42.827869279044016, 39.4491548538208, 38.6221524647304, 39.7287677356175, 37.403462750571116, 43.44393825531006, 42.79222502027239, 38.46184710093907, 38.00049018859863, 39.925433022635325, 40.77791098185948, 44.27648183277675, 45.194481304713655, 44.89893620354788, 43.25617013658796, 39.422171524592805, 39.61732905251639, 43.52770921162197, 42.60451248713902, 41.2398168018886, 37.90394149507795, 33.67466681344168, 29.827223437173025, 33.27564566476004, 56.81916148321969, 41.82921511786324, 41.4197473526001, 42.19159494127546, 37.61027935573033, 48.14894219807216, 40.68993983949934, 44.14210367202759, 45.148039545331685, 44.32746423993792, 42.86693899972098, 45.06918791362217, 44.86187103816441, 47.88406644548689, 44.952138560158865, 55.05583722250802, 49.36836494718279, 42.468987873622346, 41.739958558763774, 39.77829449517386, 37.39651802607945, 37.20129796436855, 40.91544362476894, 41.53462191990444, 42.64262683050973, 45.93309218542916, 46.258948802948, 47.69964735848563, 47.384987762996126, 48.65966953550066, 46.18135479518345, 45.323728220803396, 46.83687564304897, 47.165421213422505, 49.55122763769967, 49.78402355739048, 54.395237241472515, 56.652748652866904, 58.42398343767439, 59.034653663635254, 58.24491446358817, 59.317507880074636, 57.52862467084612, 56.25176116398403, 57.59442063740322, 59.294835908072336, 60.226922852652415, 63.34262711661202, 68.51336533682687, 68.81982258387974, 77.2171652657645, 52.29456056867327, 0.2742391015802111, 12.199825133596148, 74.56940828050885, 47.57613270623343, 42.10967220578875, 38.759834493909565, 25.377294812883648, 37.68455907276699, 26.00375655719212, 0.15515395307115146, 0.039593624350215705, 0.051746820964451344, 0.03506889160988586, 0.03889928964365806, 0.03626110817172697, 0.08108802884817123, 0.03415574971586466, 0.024000431610537425, 0.03864350908302835, 0.06763618745441947, 0.03540270369766014, 0.04961459252185055, 0.010103809663892856, 0.1715494490095547, 0.08555189360465322, 0.5365559086203575, 18.79057625361851, 58.627093178885325, 38.52557945251465, 43.91896227427891, 56.5063396862575, 51.18320662634713, 72.49081993103027, 45.90914174488613, 0.25138028817517416, 0.26244836140956196, 1.6590670836823327, 39.0299630846296, 74.12883690425328, 69.2813080378941, 70.63714476994106, 60.93584755488804, 62.43542167118618, 55.820879050663535, 55.672434261866975, 49.13146264212472, 52.32669251305716, 52.75537552152361, 61.1810633795602, 59.890671730041504, 63.180483954293386, 63.401679856436594, 64.67578492845807, 62.2580897467477, 57.14063031332833, 61.63813672746931, 62.72560623713902, 59.140266282217844, 60.022576332092285, 57.383681774139404, 58.9088773727417, 52.12884603227888, 46.8642133304051, 45.333931650434224, 47.26344639914376, 42.88549416405814, 40.842001165662495, 41.94890478679112, 45.50507967812674, 44.19541025161743, 47.029941763196675, 51.04491662979126, 54.7672472681318, 53.34800474984305, 54.488697460719514, 46.88156645638602, 41.186009952000205, 44.97572422027588, 45.66588531221662, 40.12527016230992, 45.13890961238316, 45.63151952198574, 52.01729270390102, 40.328501496996196, 33.916912283216206, 41.822864464351106, 39.37727573939732, 39.938596384865896, 33.28237846919468, 37.65963588442121, 42.78104189464024, 43.573695863996235, 41.74129261289324, 39.85336283275059, 44.99760757173811, 44.84297888619559, 43.34355763026646, 46.72681270326887, 46.16099309921265, 45.8780311856951, 43.64639833995274, 40.314584255218506, 40.01849719456264, 41.306595938546316, 40.663095474243164, 44.53188371658325, 46.108263220105854, 39.74570744378226, 40.654177461351665, 41.48488324029105, 42.33533579962594, 45.707862854003906, 48.638293402535574, 47.672538961683, 44.576056889125276, 41.590485436575754, 41.41761078153338, 45.33012751170567, 44.95703704016549, 43.69867311205183, 40.55378988810948, 39.2932824407305, 36.50278166362217, 37.48905413491385, 54.02872323989868, 43.799651282174246, 41.540079729897634, 42.25698791231428, 40.879114968436106, 49.587379114968435, 43.74210630144392, 46.71482358660017, 45.86474970408848, 45.2418714932033, 43.55401856558663, 45.071925503867014, 47.223834718976704, 48.23583984375, 48.96311126436506, 56.27251543317522, 51.63222353799002, 44.66898557118007, 43.68756641660418, 43.49584477288382, 39.585461139678955, 40.56410101481846, 43.00610099520002, 43.16197688238961, 45.90916953768049, 49.49275854655674, 49.58227913720267, 50.33074951171875, 50.42840991701399, 50.55231714248657, 49.70898996080671, 47.64126859392439, 48.62501539502825, 47.7194254057748, 51.729383672986714, 53.142567362104145, 56.947866439819336, 60.20159666878836, 60.599110058375764, 61.457066672188894, 60.81747109549386, 64.10778359004429, 61.28227778843471, 61.70338726043701, 62.44175842830113, 62.928208759852815, 64.01236397879464, 66.05969933101109, 72.28777272360665, 71.88511766706193, 78.6695750100272, 54.173044272831504, 0.43527334768857273, 14.378534419195992, 81.27817194802421, 54.70605100904192, 49.22837611607143, 48.029259477342876, 31.877886976514542, 47.839566707611084, 38.722394125802175, 0.16290314868092537, 0.050793340163571496, 0.029100124391594102, 0.045110117444502454, 0.1134067399959479, 0.06402079002665621, 0.11714611255696841, 0.061115866260869164, 0.09805094969591924, 0.22102598340383597, 0.13204562876905712, 0.05972334955419813, 0.09674133639782667, 0.24141372154865945, 0.249514316873891, 0.36406706858958515, 0.8186634651252201, 26.43090053967067, 69.82292011805943, 51.74620873587472, 55.719890458243235, 62.273931639535085, 59.60298156738281, 76.40197481427873, 50.02533449445452, 0.31757515189903124, 1.1268586303506578, 2.813816108873912, 40.82655879429409, 78.60348374502999, 71.3622796194894, 71.30720819745744, 61.394115992954795, 66.61581924983433, 57.447730268750874, 58.231254305158345, 50.58677325929914, 56.575797353472026, 54.98557356425694, 64.3175358091082, 64.10421916416713, 64.9351611818586, 65.46511418478829, 62.34045369284493, 62.40293189457485, 63.15358052934919, 63.122327532087056, 64.62208230154855, 60.38450104849679, 62.473518644060405, 60.52156121390206, 60.04974378858294, 53.2494341305324, 48.98545319693429, 47.34924970354353, 50.5165547643389, 43.67647361755371, 41.60021638870239, 45.21602072034563, 46.32143742697579, 47.044810908181326, 51.269986152648926, 54.102353300367085, 58.210253374917166, 56.91076305934361, 56.856563636234824, 48.288316113608225, 46.526628153664724, 48.10343844549996, 46.97280672618321, 42.18973977225167, 49.057082176208496, 49.60830708912441, 54.03794002532959, 41.56107371194022, 35.58586958476475, 42.36589397702898, 41.69319370814732, 49.13425929205758, 38.48409175872803, 43.53600188664028, 47.41119984218052, 45.76204490661621, 48.18460382734026, 42.0665899004255, 48.77525281906128, 49.397953850882395, 47.33753504071917, 49.412350518362864, 49.69263390132359, 50.02600499561855, 46.172867570604595, 44.951151915958945, 43.04958282198225, 46.483538900102886, 43.82768031529018, 47.14014366694859, 47.93167550223214, 41.19148860658918, 44.68267699650356, 46.0026193346296, 45.83403171811785, 50.22836780548096, 49.974119322640554, 51.10888522011893, 47.382552419389995, 44.2906631061009, 43.2958790915353, 49.21458394186837, 48.22594908305577, 44.24536779948643, 41.01499046598162, 40.7294716153826, 38.5023307800293, 48.344165733882356, 56.20279720851353, 42.72490392412458, 43.069214957101, 39.995679310389924, 43.51405600139073, 51.53358343669346, 46.97291442326137, 47.754697935921804, 47.39211661475045, 48.0242463520595, 48.227800777980256, 49.59222895758492, 49.099167415073936, 52.07929842812674, 52.9346147264753, 58.001105649130686, 51.97436325890677, 47.04889644895281, 45.661983898707796, 44.73377057484218, 42.87914003644671, 43.0038115637643, 45.17378262111119, 45.25796699523926, 47.26397098813738, 51.01839882986886, 53.18545511790684, 52.00753395898001, 52.554787976401194, 52.859007903507774, 51.34126772199358, 51.10388599123274, 50.99722766876221, 50.72604990005493, 54.260358810424805, 56.21440417425973, 58.726375988551546, 63.03587804521833, 62.9562794821603, 65.15387657710484, 63.12079892839704, 67.29891054970878, 64.52125004359654, 63.92051574162075, 64.65789331708635, 67.34025927952358, 65.91576739719936, 69.023606300354, 73.83492115565709, 75.44107369014195, 80.89677837916783, 59.622193336486816, 0.393624841102532, 14.730794191360474, 88.65411554064069, 58.58702291761126, 57.80203628540039, 52.77350337164742, 40.961333002362935, 59.207545689174104, 46.91110324859619, 0.16702432611158916, 0.10979900322854519, 0.0792036217504314, 0.122311514669231, 0.14762961039585726, 0.12189881610018866, 0.2950139710945742, 0.17468593642115593], [0.006075484661518463, 0.028875318954565694, 0.020925275282934308, 0.051971039468688626, 0.05992296098598412, 0.015995374015931572, 0.06227339950523206, 0.06454476155340672, 0.36788561940193176, 10.635754363877432, 49.61091613769531, 33.617413657052175, 27.688052007130214, 44.43567201069423, 51.16619743619646, 63.92974294934954, 51.63818161828177, 0.8293710191334996, 0.27952119814498083, 1.5338458887168338, 41.04979051862444, 69.30078383854458, 64.29364790235246, 65.09907613481793, 57.07106147493635, 57.89092806407383, 52.390598569597515, 48.73614488329206, 47.55508313860212, 52.446715695517405, 56.28659248352051, 58.19568647657122, 60.1104154586792, 68.86903667449951, 59.105483600071494, 51.37224626541138, 47.37052856172834, 54.83200447899954, 57.47221572058541, 59.16962242126465, 56.31510441643851, 55.03330768857683, 55.31837490626744, 59.40843200683594, 51.39108630589077, 48.39352573667254, 45.49431691850935, 44.31323780332293, 41.731968130384175, 42.50909982408796, 40.44836834498814, 42.28006287983486, 42.091533933367046, 44.705328123910085, 50.271234716687886, 46.38339103971209, 48.371691022600444, 50.65816599982125, 44.39932598386492, 33.90413802010672, 38.15189838409424, 42.681627069200786, 40.886170864105225, 39.00046798161098, 43.63391937528338, 45.947572231292725, 47.37016030720302, 41.224951131003245, 44.17559746333531, 37.48595871244158, 32.619311877659385, 41.19522326333182, 37.40891013826643, 38.55120093481881, 34.854589053562705, 36.79307740075247, 36.24573653084891, 45.18927362986973, 43.134576661246165, 38.86583273751395, 40.07125834056309, 38.877672467912944, 39.699012075151714, 39.736125877925325, 37.55497516904558, 39.049230439322336, 38.261693818228586, 37.985690525599885, 38.954019274030415, 42.81299665996006, 37.097224371773855, 38.08239207948957, 37.25924594061715, 37.805252756391255, 37.08672216960362, 41.61341796602522, 42.24446031025478, 39.67930350984846, 39.68986824580601, 41.06931495666504, 46.4998254776001, 39.86890247889927, 41.89894029072353, 39.278375080653596, 40.1026155608041, 36.485400744846885, 29.82156412942069, 33.24927377700806, 49.54798977715628, 34.85377958842686, 58.10888263157436, 50.56272554397583, 42.76065240587507, 44.010146958487375, 42.36746426991054, 44.063793999808176, 40.21786880493164, 40.10994938441685, 38.801353454589844, 44.40406118120466, 44.60250520706177, 42.28198405674526, 52.21020596367972, 50.33881984438215, 40.231053011757986, 38.68292488370623, 40.44756930215018, 36.93015146255493, 37.77332925796509, 41.162841183798655, 42.720755849565776, 42.48025785173689, 46.660624163491384, 47.862686838422505, 49.87996080943516, 48.59966836656843, 48.57308803285871, 49.021889550345286, 49.8180593081883, 46.953063419886995, 46.88205977848598, 46.953150272369385, 48.38788727351597, 51.34726401737758, 56.95488064629691, 58.250657149723594, 59.69103608812605, 59.0091746194022, 59.865845816476, 60.34343719482422, 60.723184040614534, 61.052104813711985, 58.70450305938721, 62.005939619881765, 61.78652245657784, 68.65180819375175, 68.23671586172921, 75.75575065612793, 39.46776212964739, 0.7085525393486023, 18.62762883731297, 74.4801447732108, 44.934886183057515, 42.05527823311942, 39.137802600860596, 24.69590061051505, 51.53035599844796, 29.310697828020366, 0.017130206871245588, 0.09963269624859095, 0.03873612232772367, 0.0810615863384945, 0.031636464542576244, 0.048820414779973884, 0.03440236666106752, 0.034362462016620805, 0.08520206809043884, 0.017956492890204703, 0.07227215583303145, 0.03980579546519688, 0.026642160124278495, 0.009921709524600633, 0.0775072095649583, 0.12182529004556791, 0.39517743779080255, 12.348804933684212, 59.0009549004691, 34.44910955429077, 28.50887049947466, 51.53276354925973, 55.927408831460134, 70.52035944802421, 55.38393463407244, 0.9748448559216091, 0.09770716992872101, 2.511089393070766, 43.905201366969514, 76.70038604736328, 69.4088213784354, 69.04632690974644, 61.26490034375872, 61.161823817661826, 55.591647556849885, 53.2216100692749, 51.352478640420095, 56.338290555136545, 57.97099910463606, 61.75030149732317, 61.97445733206612, 70.0927186693464, 60.71864686693464, 54.83184119633266, 49.65925128119332, 56.48994888578142, 60.67621421813965, 59.73689419882638, 58.5952912739345, 56.42630338668823, 58.27481951032366, 60.68797057015555, 55.82954345430647, 50.86291551589966, 45.65064096450806, 45.63171754564558, 44.33768851416451, 42.80309200286865, 40.57508611679077, 43.736537320273264, 44.580729552677695, 47.35458244596209, 51.48665530341012, 47.40192747116089, 51.361396653311594, 50.43601124627249, 50.44250781195504, 41.397099699292866, 38.018301895686555, 44.35035855429513, 43.69891629900251, 40.62806960514614, 44.87350927080427, 47.05522278376988, 48.667680808476035, 44.62472207205636, 42.41496562957764, 40.84726095199585, 39.344421182359966, 45.24557488305228, 41.18343217032296, 39.45400469643729, 38.14928238732474, 39.36231279373169, 40.71090950284685, 49.51357882363455, 45.568857192993164, 41.75901051930019, 41.588435717991416, 40.27260323933193, 41.40907839366368, 41.561400277274, 39.50654002598354, 39.82747384480068, 39.966653210776194, 40.49957309450422, 42.73565626144409, 44.26468031747, 38.500065667288645, 42.17560713631766, 40.56964567729405, 41.44331564222063, 39.00896910258702, 42.413343225206646, 43.04766859327044, 42.26856361116682, 40.99069956370762, 42.528318541390554, 47.39474998201643, 42.23448964527675, 43.02210964475359, 40.26666252953665, 39.61714145115444, 40.26702036176409, 34.98969330106463, 35.91777808325631, 44.19677209854126, 37.220346450805664, 51.48279210499355, 45.846031257084434, 46.295725618089946, 45.053599630083355, 45.43105009623936, 42.501581873212544, 42.94748946598598, 43.755926268441335, 42.08896309988839, 47.00505331584385, 48.15162072862898, 48.265334946768625, 54.38177858080183, 51.029519421713694, 44.386853967394146, 42.05917269842965, 41.81648254394531, 40.9839528628758, 41.80889163698469, 44.729268142155235, 44.46024431501116, 45.081152711595806, 47.3316707611084, 49.642742361341206, 52.86120353426252, 51.99116052900042, 52.108824798039024, 52.356951917920796, 51.95212207521711, 51.06123794828142, 48.751170362745015, 50.21422127314976, 50.383892808641704, 52.102008615221294, 58.871864318847656, 60.537076541355674, 61.58658109392439, 62.36879539489746, 62.81641224452427, 64.39655767168317, 63.99657767159598, 62.911248207092285, 62.8442189352853, 64.68769414084298, 67.35410009111676, 71.22492068154472, 70.80775778634208, 78.62131977081299, 42.55333205631801, 0.7774076131837708, 21.37634835924421, 79.24582386016846, 52.42678826195853, 48.43633358819144, 47.35907793045044, 27.24447900908334, 56.61489486694336, 36.97718729291643, 0.1770067433161395, 0.07154851859169346, 0.024290069372260144, 0.010972208110615611, 0.06620082804667098, 0.10080155424241509, 0.047837519486035616, 0.0937836565343397, 0.2474320557500635, 0.12970043532550335, 0.15416349550443037, 0.13273294403084687, 0.09193840769252606, 0.1574950481631926, 0.21802239386098726, 0.27819436362811495, 0.6590534097382, 20.789208207811626, 72.03234999520438, 44.55678258623396, 39.348364285060335, 59.28713035583496, 65.77253723144531, 75.57136631011963, 60.48686191013881, 1.2244988424437386, 0.6837388394134385, 2.8971022112028937, 47.42170899254935, 79.1703872680664, 71.88656984056745, 71.83405535561698, 61.20213726588658, 63.890423093523296, 57.41743264879499, 53.73492213657924, 53.76395171029227, 58.55598531450544, 59.45112173897879, 64.27311597551618, 64.30351434435163, 71.63738659449986, 59.7524859564645, 57.73021623066494, 55.97907911028181, 58.33818013327462, 60.97983660016741, 63.750270979745046, 61.17769350324358, 60.22565828050886, 59.3498934337071, 62.20637430463518, 55.744553089141846, 53.928644861493794, 49.059541838509695, 47.157899788447786, 47.96661799294608, 46.85364164624895, 45.1654725755964, 47.112760816301616, 45.60558189664568, 49.30608824321202, 56.476674352373394, 52.187297752925325, 54.82498679842268, 55.70752961294991, 50.70280122756958, 44.35033423560006, 46.63154942648751, 45.5448442186628, 46.65356479372297, 43.84231669562203, 48.83560139792306, 49.746225357055664, 52.01148748397827, 46.408831868852886, 47.74027000154768, 47.18042237418038, 42.74831587927682, 46.225118024008616, 44.16047123500279, 43.91464744295393, 40.15350764138358, 41.43362290518624, 43.779206207820344, 52.45339986256191, 51.4075083732605, 46.099643979753765, 43.67431272779192, 43.58781112943377, 45.666288307734895, 43.4489756992885, 42.18030064446585, 42.7194322177342, 43.541838373456685, 45.335140636989046, 44.03398275375366, 47.088723523276194, 42.253739629473, 44.839254651750835, 42.72118663787842, 43.070813042776926, 40.37460626874651, 45.44464077268328, 46.26940584182739, 43.99733100618635, 43.320072719029014, 45.83035959516253, 51.851546900612966, 45.34751190458025, 47.62129947117397, 41.05533518110003, 42.819712093898225, 42.121418135506765, 39.944922719682964, 47.319865771702354, 46.34666633605957, 37.45589733123779, 52.94713885443551, 47.61553594044277, 49.074890409197124, 46.271146365574424, 46.95961904525757, 46.69346135003226, 45.88261352266584, 46.01149565832955, 44.29524891717093, 49.832577569144114, 51.153721945626394, 51.33242613928658, 58.3075316292899, 54.68374381746565, 46.185464654650005, 45.40478590556553, 44.93561921800886, 42.081886359623496, 43.747102056230815, 46.42321463993618, 46.6707581111363, 47.3219849722726, 50.97268663133894, 50.69762829371861, 55.394728660583496, 53.77821636199951, 55.241024085453574, 55.57101140703474, 54.901851245335166, 53.09202963965279, 50.94373001371111, 52.90354585647583, 53.74728298187256, 55.68769250597273, 62.44874136788504, 62.16382353646414, 64.44851630074638, 63.10533223833357, 65.52369444710868, 66.94057805197579, 64.84047807965959, 67.19446522848946, 65.9439423424857, 67.07182257516044, 70.00633866446358, 73.46501295907157, 75.73314816611153, 81.79201902662004, 46.72974484307425, 0.6711044630834034, 23.162700687135967, 86.5325734274728, 56.80079739434378, 58.85529981340681, 54.7181339263916, 39.464291504451204, 69.87748432159424, 44.276346342904226, 0.17102876837764466, 0.1710135420518262, 0.23863984325102397, 0.24262954773647444, 0.1692453883588314, 0.13544822404427187, 0.13490679381149157, 0.20643912255764008], [0.03922622477901833, 0.025107804153646742, 0.020469576253422668, 0.038813112303614616, 0.01136296455349241, 0.05112279944920114, 0.024948536717732037, 0.0800721397889512, 0.2516119400305407, 4.765927050794874, 47.871125425611226, 42.913405077798025, 32.218560627528596, 43.26869773864746, 44.528892517089844, 55.433186939784456, 60.78397383008684, 1.9621866984026772, 0.0727325893406357, 2.947662515299661, 46.9419914654323, 69.65441935403007, 61.1900543485369, 65.53042030334473, 57.66012627737862, 54.749494620731895, 48.897829464503694, 50.26846238545009, 48.421179567064556, 59.04778575897217, 59.40868214198521, 70.06918512071881, 84.7282304763794, 55.437345436641145, 48.26961503710066, 51.35022742407662, 56.164543901171, 56.03053399494716, 55.534227643694194, 55.68685177394322, 56.68424483707973, 54.16261502674648, 57.56246239798409, 53.65192243031093, 50.26818445750645, 47.24808740615845, 42.418609959738596, 42.22714539936611, 43.86924096516201, 40.56451790673392, 39.454525811331614, 37.94075999941145, 43.2375420161656, 44.687019620622905, 43.31544521876744, 42.529690810612266, 46.33168601989746, 46.80984715053013, 46.12801347460066, 41.96978064945766, 33.1070476259504, 36.32528993061611, 42.410821029118125, 39.789560999189106, 42.723378794533865, 43.747932365962434, 40.00408663068499, 43.66814272744315, 40.13520608629499, 33.27800110408238, 47.199582031794954, 39.41239193507603, 36.42266198566982, 36.88256325040545, 37.422445229121614, 37.74258695329939, 42.75951637540545, 47.41459403719221, 42.270668915339876, 40.74243000575474, 37.56346934182303, 40.577917507716585, 40.52340194157192, 39.67458915710449, 40.76171473094395, 40.0190634727478, 36.920962469918386, 38.6044727734157, 39.788167885371614, 42.70135300500052, 37.64816440854754, 37.593412603650776, 35.40549087524414, 39.35580580575125, 38.28437621252877, 39.23169360842024, 38.734932150159565, 38.50622524533953, 38.797188009534565, 41.19656426565987, 48.003182888031006, 41.69529901232038, 34.907756669180735, 36.41818387167794, 36.58432224818638, 37.638937200818745, 32.813823223114014, 30.71685688836234, 36.2926299231393, 44.62124449866158, 27.04900186402457, 32.36903429031372, 44.522514070783345, 43.36525338036673, 42.210007667541504, 38.83109869275774, 39.73352377755301, 40.35681193215506, 37.749118259974885, 44.94445385251726, 40.95976618358067, 41.192159107753206, 45.77833148411342, 46.40563917160034, 42.92765930720738, 40.57766737256731, 38.23304986953735, 37.602004051208496, 39.53808832168579, 40.82261916569301, 42.96526643208095, 43.3481434413365, 47.13144799641201, 47.75025108882359, 49.832167625427246, 54.123017242976594, 54.348316056387766, 54.555045809064595, 50.97028602872576, 52.03823804855347, 48.179333618709016, 50.30407190322876, 48.84651354381016, 50.237754821777344, 49.60363095147269, 55.78380346298218, 57.93472950799124, 59.530247824532644, 60.33555098942348, 62.29806968144008, 57.63034629821777, 59.137883050101145, 58.158152307782856, 61.65241527557373, 62.63056182861328, 70.96306392124721, 68.0344329561506, 74.40625068119594, 35.13290957042149, 0.5052065051027707, 22.027464049203054, 74.10888862609863, 42.83166299547468, 46.55018949508667, 30.764028208596365, 29.694971425192698, 52.68271126065935, 30.29833562033517, 0.08421485392110688, 0.041771094115184884, 0.06826159318110772, 0.024751987175217698, 0.04050011320837906, 0.04352415718936494, 0.06649155994611126, 0.021580819838813374, 0.11917862349322864, 0.011033590084740093, 0.049422478902020624, 0.08943192647503954, 0.051452645499791415, 0.03919546339394791, 0.11405085293310029, 0.04641524901879685, 0.23096164954560144, 6.895797882761274, 59.01034886496407, 45.44044753483364, 34.109457288469585, 51.60053627831595, 49.86137090410505, 61.12081554957798, 62.536907059805735, 3.1807313689163754, 0.19098786238048757, 4.235641837120056, 51.21963255746024, 77.41414669581822, 67.20948028564453, 67.48862416403634, 61.6450640814645, 59.85769557952881, 54.016789708818706, 52.28415216718401, 54.27506467274257, 60.31925746372768, 62.43583161490304, 72.28497954777309, 80.23262092045375, 60.28692054748535, 52.3145956993103, 54.08163029806954, 57.39182506288801, 58.63921083722796, 58.56719275883266, 59.857890129089355, 58.14696223395211, 58.63028935023716, 59.280119623456685, 56.54281772886004, 53.830682209559846, 50.162422452654155, 43.885624817439485, 45.47066872460501, 45.19074664797102, 43.17868382590157, 41.279136657714844, 41.00728838784354, 44.77444532939366, 47.117075647626606, 44.73209605898176, 44.82347876685006, 49.56831325803484, 51.08966997691563, 48.89215278625488, 46.77823632104056, 39.24829980305263, 37.77461120060512, 44.77993788037981, 40.38147108895438, 45.104210308619905, 46.64663396562849, 43.208571502140586, 44.373364039829795, 43.708265100206646, 39.12369775772095, 48.166006973811555, 42.12968301773071, 39.57315935407366, 38.9241281236921, 40.48597199576241, 40.3784625189645, 46.29863691329956, 49.846348898751394, 45.302699497767854, 43.60180132729666, 39.6892602784293, 41.98485129220145, 41.4680164882115, 41.78414910180228, 42.35556547982352, 41.02572890690395, 40.388909135546, 40.03646176201956, 42.13870872770037, 44.50758934020996, 37.94662080492292, 41.64438608714512, 39.461008480616975, 40.706511293138774, 40.50699029650007, 41.16938986097063, 39.782320976257324, 39.544703006744385, 39.83934136799404, 44.69433259963989, 48.92967305864607, 44.55076197215489, 38.95374829428536, 39.42845269611904, 38.82917056764875, 39.768240451812744, 35.92951011657715, 36.97474152701241, 36.098420824323384, 45.17321981702532, 28.91737593923296, 27.716801915849956, 48.96240949630737, 43.82910469600132, 43.547393458230154, 39.8293776512146, 43.05737522670201, 42.22491502761841, 40.0816320010594, 45.71597140175955, 43.65860979897635, 46.65849106652396, 47.531820569719585, 46.86279937199184, 45.12681974683489, 41.47266483306885, 40.82696526391165, 39.51723330361502, 42.72170427867344, 44.89419058391026, 44.4376175062997, 44.48290239061628, 49.14674173082624, 50.29852376665388, 54.02277210780552, 56.3503908429827, 55.437216894967214, 57.06384229660034, 55.37894582748413, 54.331001145499094, 51.67115429469517, 54.1220167023795, 51.04770285742623, 52.094730377197266, 52.28872408185686, 58.07815422330584, 60.318944794791086, 62.34830515725272, 63.15162808554513, 65.0035731451852, 60.64951923915318, 62.919857025146484, 60.6714060647147, 64.67058767591203, 65.10042408534459, 73.41470800127301, 69.93746812002999, 77.48130103519985, 40.97900921957833, 0.5881346666387149, 25.89761413846697, 80.56231989179338, 49.3222462790353, 55.25324249267578, 37.47527238300869, 29.883229391915457, 62.57361439296177, 36.308572564806255, 0.11721093979265008, 0.07638274133205414, 0.05652941058256796, 0.056653582490980625, 0.0851185065028923, 0.006577721863452877, 0.03213029893647347, 0.07054900258247342, 0.16215262109679834, 0.08820000543658223, 0.14254044847829, 0.2139191161841154, 0.12561801581510476, 0.14754803691591534, 0.19829028339258262, 0.23742293140717916, 0.5547264250261443, 12.689812098230634, 72.5782699584961, 58.101930958884104, 45.38972915921892, 59.22501346043178, 58.9688264301845, 64.78726877485002, 71.10737800598145, 2.987016894987651, 0.20442768691905908, 5.355982405798776, 52.576157161167686, 79.41407448904855, 67.93772097996303, 70.27501160757882, 63.88407938820975, 60.58869470868792, 54.51910972595215, 54.54105908530099, 55.69367837905884, 63.23943247113909, 65.81025205339704, 70.20955957685197, 71.02559076036725, 61.527382441929404, 53.9464704649789, 57.44274493626186, 58.531617982046946, 61.96852357046944, 60.860647201538086, 62.253538676670615, 61.083600997924805, 59.694197518484934, 62.1586332321167, 59.51400293622698, 55.618891443525044, 52.737664563315256, 45.02236747741699, 48.011937618255615, 48.875716822487966, 46.37793322971889, 43.88708393914359, 42.328047139304026, 47.313772201538086, 49.5186961718968, 48.441433565957205, 48.795100348336355, 53.95522519520351, 52.89669493266514, 54.001319544655935, 48.262427125658306, 43.03807313101632, 43.91388314110892, 46.957840306418284, 43.748311042785645, 47.55346768242972, 48.77810852868216, 45.273836680821006, 50.445109912327354, 48.20342302322388, 41.8060428755624, 51.62006419045584, 45.24928174700056, 43.49686963217599, 41.334996700286865, 43.01562697546822, 43.345353739602224, 49.58029195240566, 53.38661936351231, 48.94285726547241, 45.98149333681379, 42.087048871176584, 45.148852484566824, 44.805614948272705, 45.40213169370379, 46.11212641852242, 44.362861837659565, 44.4402300289699, 43.40932927812849, 45.429278305598665, 46.30354928970337, 40.808027948652, 42.08855663027082, 41.28967707497733, 42.29211105619158, 42.80712890625, 44.07242366245815, 41.88288300377982, 41.652140276772634, 43.1100286756243, 47.31240688051496, 53.746737548283164, 46.40632356916155, 41.408067430768696, 41.26065444946289, 40.47971861703055, 44.546891825539724, 41.37058884756905, 44.6680406161717, 45.31277091162545, 45.38939217158726, 35.14102854047503, 35.21973078591483, 50.43025466373989, 46.691092014312744, 47.36946201324463, 44.567430700574604, 44.73703622817993, 44.08785213742937, 41.442322049822124, 47.70634889602661, 49.698453017643516, 49.466278961726594, 50.99591098512922, 49.71362788336617, 47.65461260931832, 43.40965584346226, 44.30914878845215, 42.197539125170024, 44.44527094704764, 45.39095204217093, 48.01075989859444, 47.41815846306937, 52.22239657810756, 51.86254937308175, 55.258450167519705, 58.34164728437151, 57.57593148095267, 59.47935226985386, 58.63443047659737, 56.095732416425435, 53.10704469680786, 55.677110399518696, 54.81684698377337, 54.932037694113596, 55.643689564296174, 59.78283568790981, 65.35669449397496, 65.344055720738, 68.34157807486397, 66.17732538495744, 64.01009191785539, 64.12404932294572, 63.89106927599226, 67.65071174076625, 69.69084875924247, 76.55211148943219, 74.69026524680001, 78.0020476749965, 47.6477130481175, 0.4171470174832003, 26.67483615875244, 85.82978398459298, 53.817748137882774, 65.29090894971574, 42.09296873637608, 44.81095116479056, 74.10458074297223, 43.55375105994088, 0.14084424663867268, 0.15728924849203654, 0.11039095039346389, 0.23855043947696686, 0.1555438121514661, 0.13201339835567133, 0.15223182844264166, 0.09212155107940946], [0.010950198130948203, 0.031147586846990243, 0.05767169714506183, 0.055949392063277106, 0.1016252753990037, 0.054322913089501004, 0.10073914259139981, 0.026295055535488894, 0.27532521901386126, 2.0626218233789717, 48.115337235586985, 37.449845450265066, 31.48770046234131, 36.285306521824424, 45.62380007335118, 50.23369359970093, 65.86136995043073, 5.605096169880458, 0.29926911847932, 2.6102384499141147, 50.88735580444336, 71.66976519993374, 64.17335374014718, 64.89124161856515, 55.22915308816092, 56.148906980242046, 48.349036421094624, 51.89132186344692, 53.174490860530305, 60.6025424684797, 57.125722953251426, 76.08966023581368, 77.02474185398647, 54.17287751606533, 60.99496977669852, 61.01675932747977, 57.35464525222778, 56.52640608378819, 56.53034571238926, 57.859768867492676, 57.688728536878315, 56.43161875861031, 54.86106879370553, 52.638482502528596, 50.44448804855347, 45.287934575762065, 45.424873147692, 42.80279670442854, 42.05469111033848, 42.22093023572649, 37.684315885816304, 38.45907824380057, 39.60263361249651, 41.29182059424264, 43.68820217677525, 42.813111305236816, 47.04663828441075, 47.93804700034005, 45.06928171430315, 45.51772192546299, 39.83070475714547, 31.86156565802438, 35.1476605960301, 38.003321579524446, 42.71662514550345, 43.28172908510481, 46.38834857940674, 45.21495764596121, 39.217557498386924, 40.69571379252842, 39.62184190750122, 36.81690277372088, 37.747120652879985, 37.73598269053868, 36.26627540588379, 35.357815810612266, 42.542322635650635, 43.87919078554426, 42.175586291721885, 42.48530224391392, 40.007685797555105, 42.455956527165, 38.857956954411094, 37.61329139981951, 37.37579502378191, 37.141189098358154, 37.894116742270334, 38.30868795939854, 38.91900382723127, 42.842609882354736, 37.477791104997905, 37.47377504621233, 37.753502573285786, 39.77822501318795, 39.28994730540684, 38.73128434589931, 42.0053311075483, 39.8651157106672, 41.03855875560215, 39.906645093645366, 45.88130726133074, 41.837191649845664, 37.83834702627999, 37.60174349376133, 36.262763091496055, 36.845491136823384, 33.19219779968262, 30.513653346470424, 26.459726878574916, 40.17236852645874, 29.853303500584193, 25.271409477506364, 44.66271134785244, 40.091724259512766, 43.37044715881348, 37.61047043119158, 40.70722000939505, 35.09268297467913, 43.48036418642317, 39.3980439049857, 37.82663583755493, 41.75824621745518, 44.77992050988333, 44.39708171572004, 43.40737336022513, 40.06148222514561, 39.67269924708775, 36.56766741616385, 40.080968448093955, 40.10224730627877, 42.27106843675886, 44.21209635053362, 49.95107562201363, 49.92747606549944, 53.22352082388741, 54.1179450580052, 56.47975935254778, 56.56761932373047, 56.144953455243794, 55.535085746220176, 55.41336372920445, 53.623240266527446, 52.185282775333945, 49.79583202089582, 48.97478076389858, 49.75084938321795, 53.72832482201712, 56.02498933247158, 54.495833260672434, 55.76908023016793, 56.951493399483816, 57.059944357190815, 57.07035623277937, 58.8795142854963, 62.60588182721819, 67.58569049835205, 70.48429829733712, 74.02015318189348, 30.840826647622244, 1.2647273923669542, 25.40254282951355, 70.91924163273403, 49.448324816567556, 39.78980071204049, 37.401239327022004, 33.61184120178223, 49.06569446836199, 32.237202644348145, 0.22319070010312966, 0.04589764215052128, 0.05420704305704151, 0.08625718325908695, 0.0556636406108737, 0.014703014167025685, 0.02550225521970008, 0.03773868942101087, 0.04091003317652004, 0.06645521761051246, 0.09845160426838057, 0.028346378855141144, 0.030446436256170273, 0.05672069299700005, 0.0894166390810694, 0.10783603534634624, 0.3617735116609505, 3.634285454239164, 62.686112676348, 40.54098088400704, 37.479951994759695, 46.94629240036011, 51.65238721030099, 57.417912074497764, 70.98372091565813, 7.27081343957356, 0.5774087650435311, 3.549820112330573, 55.37628814152309, 78.46245615822929, 68.08276462554932, 68.53439753396171, 60.9382655279977, 59.58881419045584, 52.6892842565264, 54.8825352532523, 55.96626663208008, 63.55756269182478, 60.42928218841553, 74.81755624498639, 80.98061534336635, 55.508786814553396, 60.679674421037944, 60.75951617104666, 60.16894013541085, 57.706519399370464, 60.83632155827114, 59.89145687648228, 61.102798870631624, 58.65321145738874, 58.055374554225374, 56.70132350921631, 53.565681389399934, 48.72936691556658, 47.21878685270037, 45.62671136856079, 43.55293117250715, 43.88840757097517, 39.853522641318186, 41.02826499938965, 42.07725191116333, 44.3169516154698, 44.44358600888933, 46.9776530947004, 48.41577386856079, 47.661522592817036, 47.995275838034495, 46.026034763881135, 43.93242788314819, 38.547983918871196, 39.68336125782558, 39.73896074295044, 44.94009038380214, 45.46372400011335, 46.749335289001465, 48.54437460218157, 42.49717671530587, 41.96264137540545, 41.525012561253135, 39.06726448876517, 39.36334807532174, 38.92550039291382, 39.26625394821167, 39.13460990360805, 45.135331290108816, 47.040669781821116, 46.8805832862854, 43.868115356990266, 41.78237036296299, 43.585622446877615, 41.103395870753694, 38.15210335595267, 38.656605107443674, 39.59032140459333, 39.59774555478777, 39.42992918831961, 41.82534844534737, 44.528044836861746, 39.92080552237374, 39.57379511424473, 38.7326010295323, 40.05126142501831, 40.247509820120676, 41.43321990966797, 45.04390689304897, 43.47892243521554, 42.73615653174264, 44.112344537462505, 50.19540555136544, 46.78538949148995, 38.71673829214913, 38.47399255207607, 37.63671030317034, 38.58757128034319, 36.00419282913208, 34.82088334219796, 31.600292546408518, 39.58451965876988, 34.62296043123518, 30.094819409506663, 45.06298317228045, 41.83529479163033, 44.72771521977016, 39.077551296779085, 42.34080750601632, 39.00841672079903, 44.90466151918684, 41.93158640180315, 41.65035111563546, 46.81153208868844, 45.74585212979998, 45.66643074580601, 43.037847314562114, 41.748695918491904, 40.823230607169016, 39.12336424418858, 42.36812782287598, 42.507929052625386, 44.13112551825387, 48.19920546667916, 51.71207571029663, 53.27035515648978, 55.649779660361155, 56.752899987357004, 58.70144585200718, 60.36255168914795, 58.752855573381694, 58.847406659807476, 55.83501863479614, 56.48401165008545, 54.31743826184954, 53.61659778867449, 51.01743303026472, 52.72726658412388, 54.495173181806294, 58.331301416669575, 58.239734581538606, 57.63718332563128, 59.01639379773821, 60.57838358197893, 60.94474819728306, 62.21580995832171, 66.39386599404472, 71.13568496704102, 72.40345328194755, 76.824341910226, 33.15435096195766, 1.13443238394601, 27.97480763707842, 76.5040646961757, 53.87080110822405, 44.81464760644095, 44.4745853969029, 36.102297919137136, 58.11480597087315, 37.14749458857945, 0.209471536268081, 0.053473607770034244, 0.0675152860847967, 0.047533125283994844, 0.04935892731217401, 0.04549986456653901, 0.009522848829094852, 0.06537479308566876, 0.18049043709678309, 0.12288220333201544, 0.14817269625408308, 0.17717208872948373, 0.1470774050269808, 0.15083923031176838, 0.22937317192554474, 0.19586579634674958, 0.6160709847296987, 7.252879270485469, 75.89268575395856, 48.066699845450266, 44.92941795076643, 48.65237045288086, 61.80603994641985, 60.1064966746739, 78.32659108298165, 7.476992113249643, 0.7365575794662748, 4.85854002407619, 57.520696776253835, 79.46619987487793, 70.44466577257428, 68.7809613091605, 62.632965905325754, 61.72009767804827, 54.32550859451294, 54.84915610722133, 59.97968510219029, 63.98138196127755, 63.882370131356375, 70.74029772622245, 75.93475709642682, 59.71638311658587, 60.779936926705496, 64.67949526650565, 61.267686571393696, 59.64586584908621, 62.964304651532856, 62.773256983075825, 61.72822707039969, 60.29209695543562, 59.883834702628, 58.90404142652239, 56.92197397777012, 49.054646832602366, 50.787228788648335, 48.19667632239205, 45.917396204812185, 48.07006624766758, 41.54275826045445, 44.217415196555, 44.62421832765852, 45.68307515553066, 45.94285787854876, 49.669058663504465, 51.12613064902169, 52.21200902121407, 50.48033727918352, 49.674530369894846, 45.93079233169556, 41.67612198420933, 44.093737261635916, 44.02196931838989, 48.799029554639546, 47.36096784046718, 50.631717681884766, 52.515051228659495, 47.11618627820696, 46.38252946308681, 46.43142393657139, 41.38492298126221, 43.619751998356406, 42.67737129756382, 42.022322927202495, 41.33306162697928, 50.43693535668509, 50.070452622004915, 48.87459121431623, 49.28747401918684, 45.385091236659456, 45.63917643683297, 44.90467888968331, 42.201166084834504, 41.13840784345354, 43.71421275820051, 42.85866716929844, 41.079910959516255, 44.512720584869385, 46.17291273389544, 41.38832759857178, 42.289595808301655, 41.744099685123985, 43.30930648531233, 44.57203735624041, 45.08244160243443, 49.599006925310405, 44.555073329380576, 46.98442758832659, 45.18342672075544, 54.40846313749041, 47.63297591890608, 42.00769349506923, 40.41947078704834, 40.7742805480957, 41.78300264903477, 38.007334164210725, 38.393980571201865, 39.27366072790963, 51.06999962670462, 35.214189597538535, 29.468998636518204, 49.530893734523225, 44.111538546425955, 49.57600491387503, 41.028115613119944, 45.48472840445382, 40.60706867490496, 45.8950959614345, 46.70778158732823, 48.58079705919538, 48.593727656773154, 49.76382861818586, 47.36636659077236, 46.18932090486799, 45.62327895845686, 44.87622949055263, 40.06394188744681, 46.416318552834646, 44.93303796223232, 46.253508363451274, 49.662339755467, 54.64353459221976, 54.09292459487915, 58.184895924159456, 58.75078501020159, 61.674996920994346, 60.426475116184776, 60.751407623291016, 60.63178743634905, 59.02475248064314, 57.900370665958945, 57.10320036751883, 55.591157708849224, 54.993862765175955, 54.68197202682495, 58.739160673958914, 61.04783167157854, 60.75766100202288, 59.7563213620867, 64.21931607382638, 62.99343844822475, 63.858968598502024, 63.69782597678048, 68.80197266169957, 73.50596564156669, 79.13040733337402, 75.11657891954694, 45.749100412641255, 0.6873800211719104, 30.40218687057495, 85.0006137575422, 61.383012771606445, 55.09402799606323, 50.842067446027485, 49.91619566508702, 65.43576499394008, 48.616024426051546, 0.368662243442876, 0.2272623987602336, 0.20241851758744034, 0.15399702372295515, 0.12861007026263646, 0.14900033255772932, 0.16517463965075357, 0.19317839055189065], [0.06983460020273924, 0.0608631730345743, 0.06048733927309513, 0.050315600620316606, 0.05020333360880613, 0.04963146768776434, 0.11900889474366393, 0.05150321332205619, 0.2791959084570408, 2.813542957816805, 50.39523574284145, 40.7080329486302, 36.96112653187343, 31.5447382245745, 47.38015529087612, 43.55709661756243, 71.85545580727714, 12.742983187947955, 0.18427888809570245, 2.64139569231442, 57.27448041098458, 73.50747340066093, 62.10285309382847, 65.24627372196743, 56.11226565497262, 54.36654118129185, 48.90656335013253, 54.75836052213396, 58.39365455082485, 62.35735866001674, 58.92949962615967, 71.47891208103725, 55.82835531234741, 58.29258605412075, 56.672196660723, 56.66702025277274, 57.848679542541504, 56.82335819516863, 59.42530918121338, 55.07182502746582, 54.192735467638286, 56.31806434903826, 51.39031505584717, 47.36383049828665, 47.43277399880545, 46.205027307782856, 43.90808834348406, 43.681090695517405, 43.460502760750906, 41.62719971793038, 38.71865946905953, 39.288647992270334, 39.87823043550764, 39.36088841302054, 42.3137651171003, 42.34532036100115, 42.42717014040266, 46.87832512174334, 44.05967719214303, 41.02623265130179, 41.54144852502005, 35.483460085732595, 38.7394380569458, 37.64636829921177, 39.7887167930603, 43.28343139375959, 40.4551602091108, 39.937436035701204, 37.374176093510215, 35.53720440183367, 37.6857020514352, 36.76335300718035, 36.72944579805647, 36.48850311551775, 36.85082040514265, 37.22445978437151, 39.9940117427281, 39.16509859902518, 45.251164708818706, 41.97966793605259, 41.74732712336949, 41.248112951006206, 37.67451197760445, 36.68519966942923, 35.36231476919991, 36.57003675188337, 35.78601939337594, 36.72629131589617, 41.170386927468435, 42.20646756035941, 36.33065046582903, 37.060145309993196, 37.93163006646292, 38.67396865572248, 37.32564640045166, 39.102985177721294, 40.622028146471294, 42.69144834790911, 40.812339305877686, 44.18656866891043, 44.76568712506975, 41.95731210708618, 41.11424548285348, 36.77221196038382, 38.29440246309553, 36.54967853001186, 35.169231278555735, 32.56182943071638, 29.462627138410294, 28.158380780901226, 43.90809876578194, 45.05699035099575, 37.88045310974121, 42.044164589473176, 40.68169232777187, 38.574988092694966, 37.941468715667725, 37.59391982214791, 40.50083419254848, 36.40351969855172, 39.04513100215367, 43.17061696733747, 41.46260731560843, 41.16378961290632, 39.51261969975063, 36.661690439496724, 37.62140689577375, 36.63535329273769, 39.81382063456944, 42.6191314969744, 41.2395145552499, 46.87039375305176, 51.6619861466544, 52.959784575871055, 52.403678553445, 54.78973511287144, 53.883127212524414, 51.86447054999215, 53.69081497192383, 55.70975998469761, 55.590233598436626, 55.51156609398978, 55.95961025782994, 56.1471768787929, 55.04665865216936, 50.43578542981829, 49.11944920676095, 50.14000061580113, 51.76465620313372, 51.645133290972026, 52.8899690764291, 55.59785229819161, 56.84757266725813, 65.20475823538644, 65.31061404091972, 70.51026371547154, 68.34951291765485, 78.35613482339042, 16.569615840911865, 1.5624637816633498, 28.171931505203247, 69.08440998622349, 48.04864842551095, 42.51297344480242, 36.620984418051584, 31.551887920924596, 53.93890735081264, 31.437020301818848, 0.17825205863586494, 0.04582636883216245, 0.045756652751671414, 0.015965942559497695, 0.05350268638825842, 0.07242377448294844, 0.017853584572938935, 0.02751994355847793, 0.050759888387152126, 0.028254240584958876, 0.07724504398980311, 0.04068101742970092, 0.05673734424635768, 0.027625905283327614, 0.10005402578307049, 0.06151533339704786, 0.16797996126115322, 4.673515575272696, 66.45614269801548, 41.03523751667568, 44.85356099264962, 40.48048291887556, 51.068846225738525, 49.02399138041905, 76.05696896144322, 15.420173610959734, 0.1411517858505249, 3.746258931500571, 61.00177901131766, 77.06197725023542, 65.38067967551095, 70.90909726279122, 59.96267591203962, 57.75356912612915, 50.84603139332363, 55.26640238080706, 60.38906601497105, 64.85198429652623, 60.23927674974714, 76.70641013554165, 63.01665932791573, 58.53209740774972, 61.87299278804234, 57.976946762629915, 61.66970239366804, 58.91111469268799, 60.581600597926546, 57.188527720315115, 57.35103218896048, 56.63287680489676, 54.97234072004046, 50.52004623413086, 51.570061479296, 48.89215626035418, 47.444217681884766, 44.46806451252529, 45.35162871224539, 44.19916922705514, 41.95641231536865, 42.24992854254586, 42.193689823150635, 42.83162825448172, 44.059711933135986, 42.99907636642456, 44.72969198226929, 46.24717855453491, 47.824989386967246, 44.8380526133946, 43.22625119345528, 40.20752988542829, 43.68051746913365, 40.919209548405235, 40.953332151685444, 45.82785129547119, 43.35857268742153, 41.96434368406023, 40.8781943321228, 37.93875197001866, 39.64202989850725, 37.258874211992534, 38.71546329770769, 38.031465257917134, 40.11116879326956, 39.34839902605329, 43.93246957233974, 43.36206068311419, 48.858676365443635, 44.68306262152535, 44.586826596941265, 45.058831623622346, 39.962237630571636, 38.239053113119944, 39.396025453295024, 37.70974629265921, 39.289606843675884, 39.02902160372053, 42.904726777757915, 44.6229224886213, 40.253235135759624, 40.057928221566335, 40.26006521497454, 39.09067644391741, 38.649017674582346, 41.437288079942974, 42.7646233013698, 45.583941732134136, 42.35684394836426, 47.38881969451904, 48.14953279495239, 45.54388536725725, 41.876699107033865, 38.22162703105381, 39.70003693444388, 38.793321337018696, 37.209799085344585, 36.046927724565776, 33.97268894740513, 32.6633426121303, 43.203607014247346, 44.84911414555141, 40.6309357370649, 43.90123047147478, 43.34632996150425, 40.5925851549421, 40.306659834725515, 39.687283515930176, 42.481515475681846, 41.820585455213276, 43.822941643851145, 45.051723616463796, 45.27701200757708, 43.37041589191982, 40.75266817637852, 40.54448972429548, 39.4509996005467, 38.86780602591378, 42.839667320251465, 44.806077003479004, 42.44698640278408, 50.684471879686626, 53.427245480673655, 56.01667581285749, 54.549984046391074, 59.40143517085484, 57.18370567049299, 56.505419049944194, 56.58074794496809, 57.234997272491455, 58.517339433942524, 57.814952986580984, 58.94252749851772, 61.12214265550886, 60.046165466308594, 53.55392503738403, 52.88733570916312, 54.340006010872976, 53.13033505848476, 55.6805636542184, 55.97655691419329, 58.168904645102366, 59.0485292162214, 68.45962796892438, 68.05032348632812, 74.21265302385602, 71.25162260872978, 78.31793362753731, 18.726729256766184, 1.4246583133935928, 31.07069042750767, 76.3328332901001, 52.84554924283709, 45.90245062964303, 44.800125871385845, 36.22318615232195, 60.15810094560896, 40.30658687864031, 0.1990216898598841, 0.03813165279903582, 0.031080137073461498, 0.050569328612514904, 0.057363587963793955, 0.034791014556373866, 0.028090493121583546, 0.04633467637800744, 0.18624482117593288, 0.19191335700452328, 0.20429330984396593, 0.10593182859676224, 0.17246123722621373, 0.08447900760386672, 0.16701792074101313, 0.1664932638938938, 0.46912950383765356, 6.922726494925363, 76.3119261605399, 51.08921486990792, 52.77526126589094, 40.77340507507324, 64.50213554927281, 52.606128215789795, 83.68704986572266, 16.232127938951763, 0.2598271534911224, 4.543031879833766, 63.956486565726145, 77.61629063742501, 67.00748225620815, 72.49204976218087, 59.615752356392996, 59.00309494563511, 52.930011544908794, 58.68834154946463, 65.01001412527901, 66.02690383366176, 63.04409081595284, 70.43053313664028, 64.40113653455461, 60.72246837615967, 63.896134512765066, 62.607625825064524, 63.38793631962368, 62.488054275512695, 62.49053478240967, 59.12252058301653, 59.838991028921946, 61.744089807782856, 56.31369045802525, 51.65028190612793, 54.52001646586827, 51.95427254268101, 51.0046136038644, 47.30308239800589, 48.99864435195923, 47.85647862298148, 44.08780002593994, 43.959133284432546, 45.109202589307515, 43.584291866847444, 45.98295940671648, 47.04202468054635, 47.07181160790579, 51.1016069820949, 50.66177558898926, 45.43732779366629, 48.1368453843253, 40.17837177004133, 46.50559595652989, 42.75392654963902, 44.356636251722065, 49.12981939315796, 47.843992710113525, 44.7725693157741, 43.79893561771938, 40.894918646131245, 44.427250794001985, 40.05262327194214, 41.65264402117048, 39.38204915182931, 42.48833165849958, 42.46878637586321, 46.87559795379639, 46.598180702754426, 52.71790388652256, 47.64361361094883, 48.91594341823033, 49.71432270322527, 43.621631486075266, 41.505213669368196, 41.581529208592, 40.80577673230852, 42.37615646634783, 41.959698813302175, 47.17546830858503, 47.566575459071565, 42.85884434836251, 41.76873104912894, 41.74644470214844, 42.30529873711722, 42.65091255732945, 45.56820406232561, 45.85650566646031, 47.472538539341514, 44.43451166152954, 50.13404253550938, 51.61584663391113, 48.16299145562308, 46.3131308555603, 38.84830938066755, 41.25960179737636, 42.17041335787092, 39.0797712462289, 37.996727739061626, 36.61383472170149, 37.8566381590707, 50.271682875497, 46.61975138528006, 41.94366931915283, 46.965181078229634, 46.05662073407854, 43.0207964352199, 43.065726961408345, 40.48968928200858, 46.57243415287563, 44.61563382829939, 46.43444292885916, 47.624912534441265, 46.79561723981585, 45.601135049547466, 44.17647293635777, 42.329916204724995, 42.84556981495449, 41.783016545431956, 45.20578602382115, 46.889317171914236, 45.297401496342246, 51.23620401109968, 56.707003661564414, 58.98511300768171, 57.054239886147634, 60.979961667742046, 60.31057916368757, 59.41589437212263, 58.89715576171875, 60.021221433367046, 62.23202705383301, 60.463529859270366, 59.834891591753276, 62.04737867627825, 59.449419430324006, 55.617220401763916, 54.03581387656075, 56.417524337768555, 55.930264541081016, 56.83542374202183, 57.726398195539204, 60.68419075012207, 61.352114132472444, 72.84187071663993, 70.58434540884835, 77.48694297245571, 73.76008905683244, 85.81704098837716, 28.29614097731454, 1.5729667437928063, 35.17467519215175, 81.04665102277482, 61.902925627572195, 57.24307107925415, 51.583638259342735, 47.40559612001692, 68.94376455034528, 46.99443299429757, 0.331836248082774, 0.21070066174226149, 0.1299395239246743, 0.1602922137826681, 0.127166853419372, 0.21893804972725256, 0.09407622726368052, 0.20635901471333845], [0.08748992532491684, 0.041402690312159915, 0.08863134336258684, 0.05244936255205955, 0.034555674863180945, 0.08345313050917216, 0.0931992478934782, 0.09436447572495256, 0.1735976476754461, 2.3444922183241164, 49.69219616481236, 41.26224906103951, 32.45595278058733, 30.796125411987305, 49.713426385607036, 45.229159763881135, 69.30905219486782, 19.727096148899623, 0.47280070398535046, 2.503786184958049, 59.95833328792027, 73.62764249529157, 64.19426086970738, 65.02446637834821, 57.45166294915335, 55.50462831769671, 50.94267041342599, 54.75342730113438, 59.85678536551339, 61.20880058833531, 63.2162880216326, 65.73919977460588, 48.067255701337544, 61.838432448250906, 58.10922656740461, 60.81770733424595, 55.75696604592459, 59.301804951259065, 57.55132443564278, 56.79339061464582, 53.59210886274065, 52.63109309332711, 48.64260823386056, 50.05018472671509, 50.72037322180611, 49.98167201450893, 44.62163012368338, 42.114737442561555, 42.6908403805324, 41.45585019247872, 40.50613219397408, 38.05680881227766, 37.19939068385533, 39.68110309328352, 41.53333650316511, 40.779512541634695, 40.74296154294695, 44.787254333496094, 44.30590050561087, 42.652666977473665, 42.38567202431815, 41.037377561841694, 40.956111431121826, 38.607015814099995, 38.376634393419536, 39.28887380872454, 43.51760653087071, 40.25596925190517, 36.270336627960205, 38.06562260219029, 36.36953605924334, 37.791394574301584, 39.70157248633248, 38.390166010175435, 36.9100399017334, 38.378152574811665, 38.1775198663984, 41.218475409916465, 47.11244467326573, 41.6599292073931, 40.21727473395211, 39.88432400567191, 38.019219057900564, 37.53364767347063, 35.53223296574184, 37.00395175388881, 36.995933532714844, 38.874552726745605, 39.15508624485561, 42.56114877973284, 37.54513999394008, 39.40190710340227, 36.913277762276785, 37.17124353136335, 35.604952812194824, 38.682202271052766, 38.57378258023943, 42.53785146985735, 40.51608548845564, 46.01058891841343, 42.0403847694397, 45.0280476297651, 38.34965801239014, 38.73377180099487, 37.29315314974104, 36.87994377953665, 35.09120995657784, 35.8440055847168, 32.05435732432774, 30.19944190979004, 31.334301607949392, 40.73195907047817, 40.41013240814209, 39.29903554916382, 40.04910748345511, 36.299018791743684, 37.17338010243007, 34.618190492902485, 36.52837882723127, 38.36125455583845, 43.161323751722065, 44.02513769694737, 41.59349748066494, 40.42118351800101, 39.72199324199131, 39.24123348508562, 39.11415440695626, 37.396636145455496, 39.13659014020647, 40.82030194146292, 41.41796166556222, 46.43857363292149, 50.942274366106304, 53.499346937452046, 54.46035923276629, 55.114514759608674, 54.01477473122733, 54.72278227124895, 55.35288660866873, 54.96526745387486, 53.9059624671936, 55.4684282030378, 58.20091152191162, 59.027253832135884, 60.45772116524832, 58.20496926988874, 56.82756532941546, 52.72009604317801, 50.39920316423689, 51.40253693716866, 51.88704177311489, 56.33459063938686, 60.32260649544852, 64.6981372833252, 66.84282384599958, 71.07074710300991, 68.18519496917725, 66.57769448416573, 11.564936092921666, 0.992199176124164, 32.97248533793858, 69.72067042759487, 46.09662846156529, 38.25006948198591, 31.610516820635112, 33.01722131456648, 56.975356987544465, 35.24268415996006, 0.05703451205044985, 0.07351812933172498, 0.05196816926555974, 0.032635841452117474, 0.026851963152044585, 0.07802347971924714, 0.024131745100021362, 0.01932812768167683, 0.0699355797842145, 0.07547803023563963, 0.04155570674421532, 0.023178498393722942, 0.05010054912418127, 0.05019720643758774, 0.06989792109067951, 0.0469031971214073, 0.18028873577713966, 2.3282128061567033, 58.889339038303916, 45.940102917807444, 39.37224871771676, 41.854096617017476, 53.203364099775044, 50.87396315165928, 76.40382303510393, 22.959120205470494, 0.47656494485480444, 2.5389735996723175, 64.73619951520647, 75.37551048823765, 70.19361346108573, 67.84807532174247, 61.69352081843785, 58.55843802860805, 54.81150034495762, 58.18283230917794, 63.62402221134731, 63.98310511452811, 65.82503087180001, 74.86158697945731, 52.901242528642925, 63.59176172528948, 62.4390903200422, 61.05790655953543, 58.01748602730887, 61.1049736567906, 59.96227291652134, 58.54944705963135, 56.81264407294137, 55.023274489811485, 53.104310580662315, 52.62650033405849, 53.13223191670009, 51.79530470711844, 47.97000871385847, 44.765714917864116, 44.08128956386021, 42.981657232557026, 41.373267378125874, 41.365943976810996, 39.43215261186872, 42.5338180405753, 42.977283341544016, 43.12992484228951, 43.945754528045654, 44.54362964630127, 46.77487339292254, 46.161531584603445, 46.09942511149815, 43.02984993798392, 43.82636015755789, 41.97511339187622, 41.007545471191406, 43.35658550262451, 44.70180886132376, 43.91746146338326, 38.737075669424875, 38.620193072727744, 38.939560072762625, 38.881257738385884, 42.41358641215733, 39.02167388371059, 40.94845799037388, 40.352038519723074, 42.08862958635603, 44.21206855773926, 49.386899266924175, 44.71388135637556, 42.11307334899902, 42.317009925842285, 39.49705226080758, 39.539943490709575, 39.286188329969136, 40.47064079557146, 40.30672236851284, 41.20437404087612, 40.09119272232056, 44.37502465929304, 39.67367199489048, 41.31405482973371, 38.99635117394583, 39.876218932015554, 37.45730434145246, 41.7417060307094, 40.930034841809956, 42.448886735098704, 43.436097213200156, 49.08756739752633, 46.392041546957834, 45.79851252692086, 40.41311318533761, 39.95487948826381, 39.19963114602225, 38.72940138408116, 38.23710066931588, 38.717943804604666, 34.10493401118687, 35.8188670022147, 35.978446279253276, 40.65381962912423, 43.027702944619314, 41.96345084054129, 42.97049147742135, 38.96403510229928, 38.998498167310444, 37.85558203288487, 40.643664836883545, 41.734181131635395, 44.700499125889365, 44.509229115077424, 43.15526492255074, 42.68859611238752, 41.10489320755005, 41.70863260541643, 39.73372180121285, 40.29180111203875, 41.260459899902344, 43.049561977386475, 43.18073354448591, 49.901753834315706, 55.12931094850813, 55.27749170575823, 56.61292157854353, 59.2481301171439, 57.152820927756174, 55.83708224977766, 57.3900636945452, 57.541534423828125, 55.37459972926548, 58.403625215802876, 61.1094274520874, 61.97827884129116, 63.47483743940081, 61.799063955034526, 61.872756549290244, 56.46293428965977, 51.225361347198486, 53.29926661082676, 55.105409145355225, 58.421502930777415, 62.484934534345356, 67.33979375021798, 69.24835968017578, 75.80609730311802, 69.23563752855573, 69.95438698359898, 14.992280960083008, 0.9629609393221992, 37.282963616507395, 74.87794303894043, 49.75449023927961, 38.759327275412424, 40.3984385899135, 36.727093832833425, 63.46028791155134, 40.14924839564732, 0.09706454976860966, 0.034737077807741504, 0.0269233704810696, 0.08076070355517523, 0.04124910730336394, 0.05197918867426259, 0.05137739257354822, 0.052154949600143094, 0.18732697596507414, 0.19959518765764578, 0.15940384859485285, 0.11043658865881817, 0.1471219440656049, 0.21185065646256718, 0.1471861877611705, 0.17857406421431474, 0.4236535169184208, 4.448116447244372, 73.51053060804094, 54.23414325714111, 45.21170588902065, 40.03440162113735, 67.45570359911237, 55.20187446049282, 82.03870092119489, 24.07346534729004, 0.5860423360552106, 3.311337309224265, 69.07352910723004, 78.62817069462368, 71.12474850245884, 69.73471968514579, 64.19385092599052, 60.70022719247, 56.214678628104075, 58.81300612858364, 66.01928165980748, 66.27090372358049, 65.48499298095703, 66.39344215393066, 59.31122670854841, 66.76583780561174, 63.318947655814036, 63.66347408294678, 60.48369353158133, 63.830731119428364, 65.68249552590507, 61.44646372113909, 61.204992975507466, 57.269057341984336, 53.590517725263325, 54.56678826468331, 55.39482593536377, 54.708600997924805, 50.34732443945748, 44.69759825297764, 47.510024070739746, 45.0411936214992, 43.70045185089111, 43.51782192502703, 40.314889975956504, 44.910994802202495, 45.45179394313267, 44.98993328639439, 45.12542315891811, 49.44155727113996, 50.848755087171284, 48.81154326030186, 49.09040921075003, 46.518019335610525, 47.396125725337434, 43.04325648716518, 43.55256291798183, 44.85980742318289, 49.2246310370309, 47.022736481257844, 40.92686993735177, 42.45793676376343, 43.878464698791504, 41.58956132616316, 46.24553183146885, 42.60654830932617, 43.72256449290684, 43.10675607408796, 44.96297427586147, 48.38835627692086, 53.88462107522147, 48.218643052237375, 45.51583548954555, 46.10260043825422, 43.175411224365234, 42.161891392299104, 42.735315799713135, 43.677943161555696, 44.718071120125906, 44.53617770331246, 42.22742680140904, 47.11702701023647, 43.32009703772408, 43.96965980529785, 41.56691714695522, 42.30783135550362, 42.04252134050642, 44.71164403642927, 43.79767451967512, 44.669902733394075, 46.116194588797434, 51.92054598672049, 48.729790755680625, 50.48168870380947, 43.16127164023263, 42.11473396846226, 40.83253424508231, 39.617909227098735, 41.57378544126238, 41.07594701222011, 36.515139034816194, 36.801345757075715, 39.86385808672224, 45.414162499564036, 46.402682713099885, 45.64231007439749, 45.487323556627544, 41.289572851998464, 43.14689234324864, 41.27292496817452, 44.78252261025565, 44.61401489802769, 49.14589057649885, 48.086651597704204, 46.902727195194785, 45.945470401218955, 43.91584253311157, 44.56814636502947, 43.555102484566824, 44.17649030685425, 42.62141745431082, 44.71818923950195, 46.24033457892281, 52.27065181732178, 56.53650181634085, 58.59232439313616, 59.19599778311593, 59.51433644975935, 58.813020024980815, 57.15247699192592, 60.24085399082729, 59.686540603637695, 58.13601187297276, 60.63515731266567, 63.07570511954171, 64.66252081734794, 66.47256823948452, 63.25734492710659, 61.26303127833775, 59.31733417510986, 54.06983920506069, 56.23093741280692, 57.835550921303884, 61.71720722743443, 67.11146899632045, 69.91525472913469, 72.11098970685686, 78.07320417676652, 71.68248735155377, 73.34202289581299, 19.68890711239406, 1.157537315573011, 41.115027155194966, 82.74144867488316, 57.62938397271292, 51.33814450672695, 46.23056888580322, 46.236898694719585, 73.99106107439313, 46.9316143308367, 0.17784858814307622, 0.1687411011329719, 0.10523780262363808, 0.13429551518389157, 0.09609349151807171, 0.20899254482771668, 0.16811889809157166, 0.1292930564710072], [0.021627362252080014, 0.029618358904761926, 0.05012280846546803, 0.039081639144569635, 0.05949484610131808, 0.016514141179089035, 0.006148559066267418, 0.018340148464111344, 0.023032665951177478, 1.0226246863603592, 42.55215433665684, 51.76015724454607, 42.09784984588623, 29.142407246998378, 46.97142056056431, 37.641747747148784, 70.59355177198137, 28.440699986049108, 0.3427927430186953, 0.8793723732233047, 56.06329127720424, 69.33187007904053, 67.2405526297433, 65.62540217808315, 58.672395433698384, 52.26359592165266, 55.08793442589896, 57.47315372739519, 61.83502088274275, 56.57912901469639, 67.51750782557896, 50.96176406315395, 47.9566091128758, 62.3984364100865, 52.472715854644775, 56.466967718941824, 53.7630866595677, 59.171943119594026, 56.024120807647705, 54.6806275503976, 52.51522145952497, 53.39153173991612, 50.401096548352925, 55.1907399722508, 53.800092765263145, 53.925358363560264, 47.33482871736799, 43.61540242603847, 42.1375275339399, 39.94452319826399, 39.827341829027446, 38.705885205950054, 37.61112356185913, 41.25476237705776, 39.00548458099365, 40.85997268131801, 38.88524253027779, 41.53104707172939, 42.217393602643696, 42.337399414607454, 43.02397871017456, 43.79854999269758, 44.45325790132795, 41.2523444039481, 38.73619324820382, 40.655671324048726, 40.45296457835606, 37.623543466840474, 36.774831431252615, 38.75119093486241, 38.65468740463257, 38.56877987725394, 35.78908702305385, 38.64757244927542, 37.61438226699829, 36.43869842801775, 38.21078436715262, 41.04529850823538, 45.89428302219936, 45.511319160461426, 41.0766453061785, 41.274755818503245, 38.71309048788888, 37.894022941589355, 34.41581378664289, 35.24594981329781, 37.19599648884365, 39.55771003450666, 40.43672316414969, 43.76091160093035, 36.790402344294954, 37.95291239874703, 37.79915223802839, 37.753276756831575, 34.83655847821917, 37.956202370779856, 38.92146348953247, 41.72665275846209, 42.80779593331473, 45.85888889857701, 43.09401307787214, 42.13312585013253, 41.207073416028706, 36.47633334568569, 38.55075625010899, 37.94904225213187, 37.681185722351074, 34.602692535945344, 34.044696603502544, 32.29995877402169, 35.888130119868684, 42.375551973070415, 40.95171322141375, 42.57077898297991, 40.215197222573416, 38.763169629233225, 38.52908829280308, 34.566600118364605, 39.09940685544695, 42.518542425973074, 42.05837712969099, 39.997301714760916, 41.55572359902518, 38.37732573917934, 38.901803561619346, 39.29359858376639, 41.34969214030674, 37.37630919047764, 38.153343609401155, 41.25967475346157, 42.91412769045149, 45.4582314491272, 52.348047801426475, 55.124384675707134, 52.254382610321045, 53.794853823525564, 54.799876008714946, 55.32283912386213, 53.65781797681536, 55.241197790418354, 54.03898572921753, 57.62749753679548, 57.19085884094238, 60.077362877982004, 60.92266682216099, 61.125317982264924, 60.96200752258301, 60.86957563672747, 57.81160395486014, 54.35052905763899, 51.558221748897004, 52.75769969395229, 56.00607633590698, 63.54605647495815, 65.37094524928501, 72.05322238377163, 68.29522664206368, 76.85134955814907, 13.576734014919825, 0.8315447739192418, 38.856998103005544, 65.85243456704276, 46.08846432822091, 33.48937225341797, 35.65941626685006, 33.841750144958496, 61.04143238067627, 29.477645669664653, 0.1830863356590271, 0.018270968426285044, 0.025619548479361192, 0.03633973680968795, 0.03539168428895729, 0.04056362408612456, 0.024058171547949314, 0.016174758318811655, 0.05573551104004894, 0.03465358068102172, 0.06809314686272826, 0.06473418817456279, 0.08320206576692206, 0.05341962352395058, 0.023847238759377172, 0.058948123295392306, 0.010225444699504545, 1.060687569635255, 52.89489534923008, 54.57299995422363, 41.22090033122471, 35.142466817583355, 54.63102783475603, 41.06617784500122, 76.28530761173793, 30.77609028135027, 0.24013058468699455, 1.0101883879729678, 59.36606189182827, 70.753249168396, 71.82653740474156, 68.83241966792515, 60.982789584568565, 54.65027434485299, 57.94459594999041, 59.43394579206194, 65.53977257864815, 57.48899562018258, 73.45613316127232, 63.15658215114048, 49.22389800207955, 63.68688951219831, 54.2891069820949, 59.72864668709891, 56.25851828711373, 63.69979926518032, 58.1652637890407, 57.49457154955183, 53.6950672694615, 56.59505775996617, 53.19494983128139, 57.70697798047747, 55.603782585689, 55.71294225965227, 51.589787415095735, 44.76874780654907, 44.61287539345877, 42.42725351878575, 41.01248564038958, 42.75540999003819, 39.7616639818464, 40.80771180561611, 40.81401382173811, 42.27517134802682, 41.10147816794259, 44.07357358932495, 43.5621132169451, 45.763882705143516, 45.53744438716343, 46.27867473874773, 46.54012155532837, 43.34230695452009, 40.5392473084586, 43.056242670331685, 42.253722258976524, 41.79344579151699, 38.66920566558838, 41.42107098443167, 40.87060342516218, 40.02831499917166, 36.385002749306814, 39.99156945092337, 39.86856549126761, 40.24465758459908, 41.05806929724557, 44.266208921160015, 48.86719833101545, 47.135766301836284, 44.34406001227242, 44.64884621756417, 40.412150859832764, 39.18219811575753, 39.215028354099815, 38.37904889242989, 40.20823860168457, 41.15323182514736, 42.48691770008632, 47.790630544934956, 39.779190812792095, 41.051534516470774, 39.58761508124215, 40.32520110266549, 38.467916352408274, 40.02013349533081, 41.52447407586234, 44.08112628119332, 44.58678143365042, 50.25164079666138, 45.511016913822715, 42.09105798176357, 42.9490840775626, 37.466246673039024, 40.11189488002232, 38.98510204042707, 39.55784899847848, 38.03922292164394, 37.740321840558735, 35.96738822119576, 37.242497307913645, 42.00196123123169, 44.369841303144185, 44.283600262233186, 43.511773518153596, 42.255567005702424, 41.48557111195156, 40.997998646327424, 41.216109548296245, 45.39611455372402, 43.83700132369995, 41.87583753040859, 44.311865534101216, 41.28796434402466, 41.10211740221296, 40.896367345537456, 42.77697719846453, 40.978046894073486, 41.029119627816335, 43.31116165433611, 43.97598614011492, 49.36970247541155, 56.66351836068289, 57.43526867457798, 56.260126795087544, 56.478039673396516, 58.43294661385672, 57.03975289208548, 56.1936742237636, 57.29615184238979, 56.09296008518764, 59.947139739990234, 58.539128984723774, 64.36615930284772, 63.14653505597796, 63.613460949489046, 65.38817678179059, 64.6130426951817, 61.56723730904715, 59.03284018380301, 54.58595487049648, 56.76728275844029, 58.21498162405831, 65.9556986945016, 68.59541661398751, 75.92385537283761, 68.88132803780692, 80.45921557290214, 15.486794676099505, 0.7310235021369798, 42.278044428144185, 73.49555029187883, 49.60678195953369, 41.56689977645874, 42.03741441454206, 37.101897035326274, 69.67427730560303, 32.87905291148594, 0.1992858164012432, 0.07771271746605635, 0.04925754739503775, 0.015234234144112893, 0.03797326236963272, 0.01815533248840698, 0.021312008013150523, 0.03985356093783464, 0.1817212046257087, 0.09550889288740498, 0.1260528481964554, 0.17197870383305208, 0.12722345681062766, 0.13214907821800026, 0.08206256119800465, 0.11836417791034494, 0.11357640767736094, 2.291534785713468, 65.32027203696114, 64.42870698656354, 54.90206316539219, 35.55119112559727, 64.75812802995954, 48.334320136478965, 83.3474427631923, 33.692360401153564, 0.39118336353983196, 1.8364049792289734, 63.477769579206196, 70.32625457218715, 73.6327702658517, 68.84546143668038, 64.83061163766044, 57.566402026585166, 61.598789078848704, 62.74219158717564, 67.7963946206229, 61.47825172969273, 64.75156198229108, 60.0822057723999, 55.136262621198384, 63.78144754682268, 58.48177855355399, 61.748536654881065, 58.90821034567696, 63.69132941109793, 62.12375327519008, 60.50423240661621, 57.8844975062779, 59.510584422520225, 55.799113818577354, 58.62873990195138, 57.98762614386422, 59.12561253138951, 53.543516635894775, 47.9291741507394, 47.903872285570415, 43.54763664518084, 44.48215198516846, 45.75578457968575, 42.69696174349104, 45.91364417757307, 42.46238361086164, 44.22712877818516, 42.90692588261196, 46.593970094408306, 47.970227582114084, 46.807411806924, 48.56569167545864, 48.80839572634016, 47.85329634802682, 45.33468900408064, 42.84336028780256, 45.25476387568882, 44.955904483795166, 43.957434449877056, 40.99342325755528, 44.58739982332502, 44.42107037135533, 43.38455547605242, 38.88023287909371, 43.410131795065745, 41.71353108542306, 41.716334683554514, 44.67279665810721, 47.798165866306846, 54.11904287338257, 53.90972491673061, 47.82996777125767, 50.43155745097569, 43.439414978027344, 43.84047889709473, 43.90215458188738, 42.94422728674752, 44.16140924181257, 44.33372804096767, 44.76865400586809, 49.576616355351035, 43.31200933456421, 43.50027424948556, 42.59610169274466, 43.047157900674, 40.091960498264854, 44.39124175480434, 46.37381989615304, 47.629189150674, 50.05161605562483, 54.89466680799212, 49.146331787109375, 48.052497727530344, 44.58676058905465, 39.624291147504536, 41.781984737941194, 41.65075758525303, 43.200973646981375, 38.98731851577759, 40.149706976754324, 38.06926345825195, 42.883031027657644, 46.83718831198556, 47.617735045296804, 47.365657874516074, 46.8747433253697, 44.996172768729075, 44.45329959051949, 43.25082697187151, 44.569351877485005, 50.358889716012136, 46.417947905404226, 44.8311356816973, 46.076346669878276, 42.99552583694458, 42.969206060682026, 44.360502924237935, 46.285459654671804, 43.416544982365195, 43.63275555201939, 44.38394962038313, 47.043119021824424, 50.52889129093715, 60.516016551426475, 59.548007420131135, 58.49608489445278, 57.87364442007882, 60.16823141915457, 60.53918184552874, 58.92627566201346, 59.49547209058489, 57.5648421560015, 62.53642763410296, 61.55148574284145, 64.47615623474121, 65.84213733673096, 67.37477793012346, 65.84509032113212, 67.29948030199323, 61.90547561645508, 61.16660417829241, 57.79370192119053, 59.23015512738909, 61.91678033556257, 68.23046248299735, 72.52091952732631, 77.55053288596017, 73.18838432856968, 81.09376675742013, 16.36149297441755, 0.8850531226822308, 45.47987161363874, 80.18301773071289, 59.93336146218436, 47.910862173352925, 48.69861418860299, 47.26928636005947, 78.05548627035958, 41.09452649525234, 0.4850492381623813, 0.1665427019553525, 0.11776068886475903, 0.08209177213055746, 0.15467011689075402, 0.08896082639694214, 0.14141583096768173, 0.12959777297718184], [0.057156220876744816, 0.042227083218417, 0.027268478480566825, 0.05493004247546196, 0.1298231008861746, 0.08488828635641507, 0.03147005043657763, 0.029741061784859215, 0.0183995609903442, 0.04228943719395569, 35.94902760641915, 54.6346652167184, 52.55281121390206, 35.91345630373274, 42.4841696875436, 43.61828245435442, 65.10003498622349, 40.30381454740252, 0.25546577466385706, 0.7152408318860191, 45.26619713647025, 70.5188238961356, 62.722618511744905, 67.18719741276333, 57.950269154139924, 54.33609070096697, 54.429547446114675, 61.34488800593785, 58.76609883989607, 62.436019216264995, 60.71046188899449, 37.67196546282087, 53.391615118299214, 56.16015611376081, 55.38919442040579, 60.723976135253906, 58.28953579493931, 58.66834463391985, 53.32782718113491, 53.23351580756051, 53.062808990478516, 51.60816192626953, 56.21344184875488, 52.58781623840332, 51.16366829190935, 56.84197589329311, 50.39445407049996, 42.23455217906407, 40.586144174848286, 42.97055401120867, 40.29055391039167, 38.4212453024728, 37.1324691091265, 37.86028943743025, 40.34378753389631, 38.04542766298567, 40.00136988503592, 40.78631135395595, 40.98942804336548, 40.08344895499093, 44.705199582236155, 42.47199991771153, 47.10338074820382, 40.51695053918021, 37.33863605771746, 39.66352762494768, 37.309314659663606, 39.395810059138704, 37.93266882215227, 40.14973824364798, 35.16169595718384, 36.99055562700544, 35.24424403054373, 38.649399825504844, 35.36801924024309, 37.15469987051827, 37.189645835331504, 42.54398325511387, 44.706116744450156, 44.07070745740618, 40.93211235318865, 41.41587373188564, 38.98479284558977, 34.85858774185181, 36.37188107626778, 35.55932051794869, 37.9787631716047, 37.632829734257285, 41.35497277123587, 46.47554152352469, 36.8627713067191, 38.44792638506208, 36.08600786754063, 37.38171141488211, 35.524767126355854, 37.43050513948713, 37.58856623513358, 41.356647287096294, 41.68686737333025, 45.69588763373238, 42.942990507398335, 40.261614663260325, 38.129059655325754, 36.255578654153005, 38.99366569519043, 35.96097503389631, 36.75655419485909, 36.16200378962925, 36.141690731048584, 34.03612947463989, 32.67382396970476, 38.07069478716169, 41.56434631347656, 38.77890729904175, 39.80745261056082, 35.785949911390034, 41.31428412028721, 40.72843285969326, 40.54253380639212, 41.633463518960134, 40.937372139522004, 37.151396002088276, 39.17305081231253, 38.62880883898054, 38.295795576913015, 37.87329299109322, 36.93742275238037, 38.37181234359741, 38.851373536246165, 41.06855412891933, 40.69514056614467, 45.21423850740705, 52.51443631308419, 56.6699732371739, 53.978414808000835, 55.400353227342876, 56.002998283931184, 54.14218037469046, 54.98098080498831, 54.72036082404, 55.337110723767964, 54.494308131081716, 57.928917339869905, 58.79038279397147, 59.6777789252145, 62.17027146475655, 60.50265516553606, 61.110295976911274, 62.108877182006836, 61.68300124577114, 58.63992650168282, 52.909844398498535, 53.814861161368235, 61.19748197283064, 61.8855481828962, 68.17328575679234, 68.36436121804374, 82.41310460226876, 19.050817557743617, 1.0687347778252192, 40.721168518066406, 65.81795760563442, 45.26458168029785, 26.300753831863403, 36.0675117628915, 35.102816922324045, 62.71084131513323, 23.671261923653738, 0.2500213182398251, 0.10081112158617803, 0.028463940136134624, 0.02617579622061125, 0.03135687418814216, 0.05618197351161923, 0.0769862032362393, 0.029216815451426164, 0.06242942184742008, 0.057865534243839126, 0.017444584019748226, 0.06122402474284172, 0.054587141411112886, 0.035516792575695684, 0.02006699633784592, 0.008357824558126075, 0.07295385961021696, 0.04705193539017013, 43.82763515199934, 59.558367184230256, 45.56235715321132, 34.14418091092791, 51.78864138466971, 48.123560428619385, 70.42401572636196, 44.63986914498465, 0.2602527577962194, 0.6726814327495438, 49.75899267196655, 73.16425323486328, 67.4103318623134, 69.74305057525635, 61.43782016209194, 58.46425519670759, 57.291298525674, 63.392932074410574, 63.00350638798305, 64.20164680480957, 73.91857746669224, 43.524387972695486, 55.20528255190168, 57.375312668936594, 59.91954844338553, 62.42183099474226, 57.968879904065815, 59.79119437081473, 56.51651879719326, 55.03584030696324, 55.97178002766201, 55.42220531191145, 59.62396512712751, 55.21978344236101, 53.11052574430193, 57.913867541721885, 52.61884689331055, 43.30743047169277, 43.49782500948225, 43.538392066955566, 41.900461946214946, 41.608759198869976, 40.17366783959525, 39.32815892355782, 42.30438504900251, 39.99391794204712, 40.839298316410606, 43.02570186342512, 42.91093846729824, 41.493596281324116, 46.52322701045445, 44.76325525556292, 50.19942855834961, 42.80761528015137, 40.737333502088276, 41.77577652250017, 40.93311289378575, 41.93840258462088, 40.5773686000279, 41.4548704964774, 38.317206450871055, 38.703880650656565, 38.6081622668675, 39.586937631879536, 37.235893045152935, 40.056503840855186, 40.212007999420166, 45.81748110907418, 48.65240519387381, 45.81999288286482, 43.849567140851704, 43.72669519696917, 41.503754547664094, 38.54430832181658, 38.02019875390189, 38.07023968015398, 41.32724251065935, 39.56201444353376, 44.31901523045131, 48.94118969781058, 38.79092768260411, 40.75093807492937, 40.14977298464094, 40.3316525050572, 39.547558716365266, 41.080039501190186, 41.64268377849034, 43.73250041689192, 45.530013288770405, 48.72163009643555, 46.59460932867867, 42.63766929081508, 41.38148362295968, 36.58776160648891, 39.34338590076992, 37.19414479391915, 39.93702956608364, 37.38468871797834, 36.24161277498518, 37.011490549360005, 36.64720344543457, 40.54102952139718, 43.3936367716108, 41.84424754551479, 42.56643288476126, 39.84208938053676, 44.08274173736572, 42.66579907281058, 43.25770221437727, 43.69044991901943, 42.25314903259277, 41.12817314692906, 40.89605467660086, 42.727975027901785, 40.21254301071167, 40.277015345437185, 39.79320880344936, 41.60049084254673, 42.246245997292654, 43.5312180519104, 42.538171086992534, 46.679961000170024, 55.42848648343767, 59.81946659088135, 57.04990768432617, 56.517046860286165, 56.51635898862566, 56.01452534539359, 57.646629401615684, 59.14235074179513, 59.61796883174351, 58.68245642525809, 60.21477740151541, 61.910763195582796, 63.11232212611607, 64.49292918613979, 63.07438496180943, 65.21848092760358, 64.5187347957066, 66.06433377947126, 61.02891867501395, 58.656067167009624, 56.22316237858364, 62.88401821681431, 63.089184624808176, 70.76260839189801, 68.45595932006836, 84.84916387285504, 21.140481335776194, 0.9496479736907142, 43.89907305581229, 71.0831218447004, 48.342560700007844, 34.915833950042725, 44.40321002687727, 36.492543492998394, 70.83369541168213, 26.663072858537944, 0.2767208569816181, 0.0802386590678777, 0.018771121677543436, 0.02200947585515678, 0.07109092136046716, 0.059639048363481245, 0.043495024288339276, 0.0070980008874487665, 0.1582393060837473, 0.2367852713380541, 0.18737143357949598, 0.19024053748164857, 0.17213361337780952, 0.13468878050999983, 0.09083257203123399, 0.11362406797707081, 0.1558552732957261, 0.45460345329982893, 57.155763489859446, 68.75588526044572, 65.72510882786342, 46.442787715366904, 58.68404756273542, 55.886410985674175, 76.79610443115234, 47.95512219837734, 0.3792709213282381, 1.7601980056081499, 52.79307992117745, 73.63127640315464, 69.11391203744071, 72.63999080657959, 65.31642968314034, 58.53653730664934, 59.36337988717215, 65.96910176958356, 65.07661260877336, 63.872406414576936, 60.298732485089985, 46.39434487479073, 59.576974460056846, 60.07538264138358, 62.43760340554373, 63.53335516793387, 62.247160230364116, 62.32253428867885, 58.7952812739781, 58.39302921295166, 60.06701701028006, 55.71901151112148, 60.94555418831961, 56.83103595461164, 56.2508578981672, 61.428127425057546, 56.15184954234532, 46.36031607219151, 46.51783520834786, 46.905548163822715, 44.75659193311419, 43.81330796650478, 41.7117349760873, 41.479359422411235, 46.05905955178397, 41.180368014744346, 42.96783031736101, 44.86514016560146, 46.28774561200823, 43.98431355612618, 50.65916306631905, 48.59365817478725, 52.25033528464181, 45.54736294065203, 43.09991904667446, 46.47497524533953, 44.21599776404244, 45.18752268382481, 42.85392154966082, 44.27633592060634, 39.873165198734824, 39.81839949744088, 40.839322635105674, 42.16201993397304, 38.66533204487392, 43.13186338969639, 43.64057922363281, 50.1721499306815, 53.43191467012678, 50.64420706885201, 48.345760345458984, 47.60826117651803, 46.09591279711042, 41.669976302555625, 42.25135292325701, 41.12077331542969, 44.744456904275076, 41.75120421818325, 48.3717222894941, 51.16646841594151, 41.824716159275596, 43.10474109649658, 45.83082512446812, 44.99731922149658, 44.09688826969692, 45.49343797138759, 45.01115655899048, 45.92802347455706, 47.58037110737392, 52.506501470293315, 50.43933943339756, 46.66189220973423, 44.57487569536482, 38.52319622039795, 43.29306854520525, 37.432728563036235, 41.37097447259085, 39.42751121520996, 39.40665967123849, 37.81624480656215, 40.69748558316912, 45.029437269483296, 47.02128083365304, 45.152934551239014, 48.45759507587978, 40.870537417275564, 45.18435777936663, 44.58975178854806, 47.56784003121512, 46.31658411026001, 45.31105818067278, 42.4880085672651, 42.318663597106934, 43.985449586595806, 42.353178773607524, 43.003015995025635, 41.28805467060634, 43.99974550519671, 44.709007195064, 45.48360627038138, 44.239805766514365, 48.80371958868844, 57.88750607626778, 61.91004058292934, 60.582114764622276, 59.56614916665213, 59.111486843654085, 58.49054718017578, 60.82638563428606, 61.12317098890032, 63.63511848449707, 59.85326262882778, 63.33093329838344, 62.82726533072335, 65.90534509931291, 66.10792677743095, 66.52216448102678, 66.35294805254254, 68.3257222856794, 67.30086994171143, 63.70828301565987, 60.003427096775596, 60.986666679382324, 66.97064290727887, 65.67351845332554, 73.88284288133893, 74.65075778961182, 87.93242699759347, 23.087797369275773, 1.2117499836853571, 49.70417138508388, 77.67582280295235, 58.87911128997803, 38.660728863307405, 47.88280534744263, 48.72945376804897, 78.93270329066685, 34.606614794049946, 0.34073287355048315, 0.12880461982318334, 0.21915659228605883, 0.16408331106816018, 0.22768106843744004, 0.11609876661428384, 0.32289416076881544, 0.23044845994029725], [0.1074789087953312, 0.05304167612588831, 0.035478574090770314, 0.013398489033404206, 0.020401071357939924, 0.05588079895824194, 0.08076911738940648, 0.029084158462605307, 0.06687049461262566, 0.05488728119858673, 30.8882828439985, 55.09621320452009, 43.63287714549473, 44.87753575188773, 39.97568934304373, 45.77365187236241, 63.24927112034389, 48.732090609414236, 0.4554036089352199, 0.49191764103514807, 40.490477902548655, 68.70674065181187, 60.78969914572579, 67.298583984375, 57.665761266435894, 55.63718605041504, 55.562895911080496, 63.06904179709298, 58.7312536239624, 67.28486129215786, 38.34733731406075, 39.74933440344674, 56.8223090171814, 55.816456522260395, 60.823453494480674, 56.72797679901123, 56.13677542550223, 54.12128019332886, 52.94600977216448, 53.43790054321289, 54.31852912902832, 54.77948651994978, 53.001195839473176, 50.13449764251709, 52.31738887514387, 54.2080979347229, 49.66051932743618, 41.36744826180594, 40.17221566608974, 40.0790889603751, 40.27317646571568, 38.98370892660958, 37.24288640703474, 38.510630403246196, 37.7786237852914, 37.04376840591431, 39.27021442140852, 37.84745611463274, 40.20307261603219, 41.42173801149641, 39.73959302902222, 43.33045332772391, 48.161007744925364, 38.719350814819336, 37.97936766488211, 36.94733088357108, 34.92654807226998, 39.7994760785784, 41.07529040745327, 38.70605891091483, 37.86102942058018, 38.34013203212193, 36.04717785971505, 37.34979139055525, 36.75861086164202, 37.90611628123692, 40.60676295416695, 41.0571278163365, 42.94404315948486, 43.403298241751536, 41.553329944610596, 42.680984360831125, 38.827266761234824, 37.82543727329799, 37.553474358149934, 38.22369064603533, 38.93055520738874, 39.84891251155308, 44.34649535587856, 45.49952111925398, 39.827519008091514, 38.524787357875276, 38.27767467498779, 37.6289769581386, 36.63797276360648, 39.52301073074341, 38.714608669281006, 41.353913170950754, 43.26869426454817, 44.48053305489676, 43.34968246732439, 41.803364345005576, 39.316430364336284, 39.83381060191563, 37.5927768434797, 37.911945819854736, 34.05569560187203, 35.528685910361155, 38.14935881750924, 35.491401876722065, 32.08648579461234, 38.00915806634085, 38.242954526628765, 35.75779233660017, 36.80880812236241, 39.858511447906494, 43.84374107633318, 41.44183220182146, 41.24444777624947, 41.21945858001709, 39.984920024871826, 36.74674333844866, 41.13337387357439, 40.026147161211284, 37.87491886956351, 38.515619209834504, 39.06450605392456, 40.22855166026524, 39.748278277260916, 41.158620153154644, 41.16935511997768, 45.49045719419207, 54.21384756905692, 53.77589218957083, 50.37722601209368, 51.54886947359358, 57.72788511003767, 56.35225296020508, 56.81174080712454, 55.23074075153896, 55.964237758091514, 55.01691688810076, 57.57109900883266, 56.380469594682964, 59.4215988431658, 61.25934873308454, 61.20113672528948, 62.720964840480256, 62.264996256147114, 63.742885044642854, 61.76890182495117, 58.322150639125276, 53.79733433042254, 55.02183621270316, 59.20826135362898, 67.84017521994454, 64.84420231410435, 81.87787096840995, 21.22685786655971, 0.42229633831552094, 49.11832012448992, 56.59528705051967, 44.43337910515921, 19.420393977846416, 27.323879548481532, 39.7618932723999, 63.60253143310547, 20.879442725862774, 0.4559926858970097, 0.03343988848584039, 0.021786275153447474, 0.06092301303786891, 0.021495977516419122, 0.011452393772612725, 0.03546811108078275, 0.06649185171616928, 0.04432613808395607, 0.028718770747738223, 0.03583042163934026, 0.07068262648369585, 0.017490254515515904, 0.0761526772486312, 0.043486529029905796, 0.012100919731892645, 0.0561054754736168, 0.0814840015290039, 35.931358337402344, 61.800634247916086, 35.18380512510027, 46.67841502598354, 49.10976341792515, 50.214738913944785, 70.08766732897077, 54.552739007132395, 0.5016481588993753, 0.4675428175500461, 45.72101926803589, 72.5757269178118, 64.68028736114502, 68.99279103960309, 61.26297569274902, 58.815472739083425, 58.58572360447475, 67.92916079929897, 59.94523593357631, 78.0843004499163, 49.83782345908028, 42.63366365432739, 61.797313008989605, 57.49834789548601, 63.56717899867466, 56.85625096729824, 59.202556882585796, 57.34014088766915, 56.70080934252058, 56.611271381378174, 59.271879059927805, 57.694224561963765, 56.153374671936035, 51.631007603236604, 57.33178915296282, 55.891351154872346, 50.321390288216726, 43.064097608838765, 43.8561748777117, 43.98388624191284, 44.219517026628765, 40.63299240384783, 40.236111300332205, 40.99808897290911, 40.48367214202881, 39.7811849457877, 42.11798225130354, 39.19850206375122, 40.404424462999614, 42.20363964353289, 43.92090082168579, 45.67013413565499, 51.32994563238961, 40.849828311375205, 40.282264709472656, 37.80387353897095, 38.58187028339931, 40.30657993044172, 43.18128940037319, 40.3878356388637, 38.56011894771031, 40.19556508745466, 38.16219561440604, 39.57235336303711, 39.68255179268973, 40.08730173110962, 42.87488079071045, 44.55768585205078, 44.93962138039725, 47.388416699000764, 44.527746064322336, 45.512184211185996, 43.70479794910976, 42.30495480128697, 41.14209386280605, 41.02657311303275, 41.201445375170024, 42.70076935631888, 45.63957943235125, 46.29032686778477, 41.003977571214946, 40.960843154362266, 40.88213743482317, 40.369669573647634, 40.000251225062776, 42.434333733149934, 42.56330966949463, 43.98134667532784, 46.69654287610735, 45.87275750296456, 44.08584063393729, 43.04715442657471, 41.45020825522286, 41.3788606779916, 38.77712508610317, 39.8266087940761, 37.16498320443289, 38.03799309049334, 38.777472496032715, 36.375973565237864, 36.16387285505022, 41.16210814884731, 39.75169331686837, 38.18623290743147, 39.23378154209682, 40.93602071489607, 45.24493564878191, 43.69380242483956, 41.96858555930001, 42.108581338609966, 41.270083154950825, 40.95791448865618, 42.17808416911534, 43.20067834854126, 40.42914962768555, 41.53125899178641, 41.78599732262747, 43.85734564917428, 42.25329841886248, 43.73892402648926, 43.25788981573922, 47.900332178388325, 57.32745695114136, 57.633236748831614, 52.25559854507446, 51.84535952976772, 59.23568589346749, 60.59674767085484, 60.19613538469587, 57.90777744565691, 58.520014490400044, 57.89326613289969, 59.08715425218855, 59.57963562011719, 61.029113224574495, 63.34678908756801, 64.34924738747733, 65.24370983668736, 64.0318467276437, 66.8456517628261, 63.956236430576865, 63.20159952981131, 55.90247522081648, 59.05085686274937, 61.49722031184605, 72.03693580627441, 67.13138948168073, 86.42935793740409, 21.465380838939122, 0.21899614589554922, 58.232685634068076, 62.52067606789725, 51.507225445338655, 31.113004956926616, 31.95006138937814, 37.47612006323678, 71.7365026473999, 24.1754093170166, 0.36325754917093683, 0.08591820751982075, 0.015631796293226734, 0.03010120103135705, 0.04225629415096981, 0.05747249961963721, 0.04179745180798428, 0.01997912266025586, 0.19755142661077635, 0.13390098778264864, 0.14655703652117932, 0.19309299013444356, 0.14651008189788886, 0.18170990023229802, 0.0863974771595427, 0.14580550470522471, 0.11944633269948618, 0.1695541760751179, 46.42742872238159, 70.26671545846122, 53.90777942112514, 57.75863436290196, 53.96861089978899, 58.15774931226458, 74.61567633492606, 58.95274829864502, 0.534836012337889, 0.7468462330954415, 50.65390675408499, 73.05768871307373, 68.27396515437535, 70.84414550236293, 63.412998471941265, 58.04726253237043, 63.28593676430838, 69.12373679024833, 63.77396433694022, 67.15656280517578, 49.69398185185024, 48.13516739436558, 61.57237202780587, 59.5168308530535, 66.20697334834507, 59.647832189287456, 59.70885821751186, 59.39311817714146, 60.12488855634417, 58.133100577763145, 60.56113120487758, 58.644929204668315, 58.256910528455464, 54.8874545778547, 57.37049756731306, 58.4238166809082, 53.6429557800293, 45.39144536427089, 44.69631283623831, 45.38409417016165, 47.50401735305786, 44.0463991846357, 43.14704867771694, 43.387949671064106, 43.29388843263899, 40.37091677529471, 44.266424315316335, 43.287225110190256, 43.31234632219587, 44.24507597514561, 44.96208838054112, 46.5973608153207, 52.82676478794643, 43.00991208212716, 42.14880793435233, 41.41376495361328, 41.144164425986155, 43.73301458358765, 47.330229009900776, 44.46347175325666, 41.869511195591514, 42.733248710632324, 40.18081406184605, 40.86832441602434, 41.680832862854004, 43.261068616594585, 46.24973896571568, 49.36862203053066, 49.66732856205532, 52.75813743046352, 47.9005788394383, 50.65626914160592, 47.10461057935442, 45.95210940497262, 46.04311343601772, 45.601426873888286, 44.41039446422032, 45.97881828035627, 49.550445965358186, 48.54190799168178, 43.76185655593872, 44.08364847728184, 44.87123026166643, 44.57744652884347, 43.9606271471296, 46.864036151341026, 45.99607065745762, 47.14256164005825, 51.40540654318673, 49.30962140219552, 48.205497060503276, 46.64033194950649, 42.84007031576974, 43.72388117653983, 41.15634114401681, 41.67142847606114, 38.140558923993794, 39.51905025754656, 41.642252990177695, 39.549170698438374, 38.14316102436611, 45.56415326254708, 44.941083976200645, 43.35455662863595, 42.00535890034267, 42.51684011731829, 47.94643695013863, 47.03257513046265, 46.01095717293875, 45.46488782337734, 43.30949408667428, 41.50676311765398, 44.30644246510097, 44.70410871505737, 43.19625929423741, 44.167190143040244, 46.330730642591206, 45.7396856035505, 43.725277764456614, 44.24871335710798, 45.64812224251883, 50.547971044267925, 60.448222977774485, 57.52140201841082, 55.06290006637573, 55.61597320011684, 62.5849677494594, 63.47920090811593, 63.41917542048863, 60.49517890385219, 61.36881760188511, 60.72906916482108, 63.567283221653526, 62.37869657788958, 64.72013528006417, 66.0773686000279, 67.36899008069719, 69.23431737082345, 68.08853857857841, 68.27460438864571, 66.84847273145402, 64.74406487601144, 59.1709634235927, 61.51060254233224, 66.90931810651506, 72.83979320526123, 72.39455263955253, 87.08332238878522, 25.146388803209575, 0.48879301441567286, 62.154922894069124, 67.65185124533517, 61.76100172315325, 30.31209305354527, 35.90358986173357, 52.373467785971506, 81.16718142373222, 28.066329308918544, 0.5328092010957854, 0.195642585467015, 0.24978241963045938, 0.1094674031649317, 0.22102191219372408, 0.1351869609206915, 0.10939177365175315, 0.15753494602228912], [0.038248211544539244, 0.013586498364540083, 0.021341983993936862, 0.015250803969268287, 0.04918833003778543, 0.028682316453861337, 0.14086852462163993, 0.04935492734823908, 0.13009082366313252, 0.059359858344708166, 26.307179178510392, 52.1960003716605, 44.1478567804609, 22.6649751663208, 38.34262990951538, 40.09414570672171, 51.77844490323748, 65.65486948830741, 2.4946267221655165, 0.5568013851131711, 31.031162125723704, 64.42109176090786, 66.07470049176897, 65.92267390659877, 59.552252769470215, 57.645653179713655, 58.00150864464896, 60.54157897404262, 59.88170855385916, 44.048389843532014, 33.9026198387146, 60.38221509116036, 56.11606631960188, 60.63307285308838, 54.51718160084316, 57.849853788103374, 53.224861826215474, 52.98629195349557, 54.768994740077424, 56.08396216801235, 53.566188607897075, 53.162119592939106, 50.701936176845, 54.71273865018572, 51.66172906330654, 55.03714656829834, 44.531842027391704, 39.81971618107387, 41.0814916746957, 39.507478032793315, 39.29030513763428, 39.227479525974815, 37.91716391699654, 38.875160694122314, 37.777501651218955, 41.88713877541678, 42.14936031614031, 40.234832831791465, 39.76657983234951, 40.040238107953755, 41.65654196058001, 44.06113631384713, 45.16668503625052, 42.366505418504985, 35.919549873897004, 37.64724724633353, 37.98656252452305, 39.30239847728184, 40.26387282780239, 40.259314809526714, 34.295863560267854, 37.142269543239046, 36.09158379690987, 37.39720937183925, 36.64337846211025, 37.65291002818516, 40.477050508771626, 42.38864932741438, 43.489563601357595, 41.10689081464495, 44.05564376286098, 42.92388296127319, 38.84971291678292, 41.28460489000593, 37.92146485192435, 41.67034455708095, 37.178386279514854, 41.22075094495501, 41.428800855364116, 43.57304620742798, 41.1980060168675, 41.16420303072248, 39.68846123559134, 39.25569616045271, 39.64833191462925, 38.4295449256897, 40.559713227408274, 42.85974414008004, 41.54476976394653, 44.25045040675572, 40.729047775268555, 39.870705536433626, 39.904758657727925, 37.62360947472708, 36.232621806008474, 37.64424909864153, 35.519621985299246, 35.239821502140586, 35.952703203473774, 38.32095847811018, 31.82993745803833, 39.57341643742153, 37.5532728603908, 33.51665782928467, 37.61827673230852, 42.6934494291033, 46.45184121813093, 42.210754598890034, 38.49008458001273, 38.67611912318638, 39.94599274226597, 38.42162050519671, 39.545800822121755, 36.32530035291399, 38.96046372822353, 39.425218309674946, 39.8083176612854, 40.70983600616455, 41.791024344308035, 41.98777995790754, 40.2165972845895, 44.00218432290213, 53.98250034877232, 54.44462851115635, 51.83005959647042, 49.91484771456037, 51.36672592163086, 54.96183156967163, 56.92558356693813, 58.834510803222656, 55.695450169699534, 57.35173395701817, 58.811046736580984, 59.24879019601004, 57.0674866267613, 59.27955681937081, 59.49612522125244, 62.61499091557094, 62.12121718270438, 64.3531105858939, 61.71786730630057, 61.291643960135325, 56.422273431505474, 55.50211306980678, 56.54992921011788, 70.16680036272321, 62.75768607003348, 84.80678680964878, 15.070884193692889, 0.10137257538735867, 59.0567558833531, 55.29229136875698, 44.13343579428536, 22.929142202649796, 50.11830833980015, 47.43513986042568, 67.59254837036133, 16.80009801047189, 0.2724644068096365, 0.05791917922241347, 0.04326887535197394, 0.0634250362802829, 0.03411721571215561, 0.018526603101885745, 0.02706224115432373, 0.07624233208064522, 0.009479867028338569, 0.04981782054528594, 0.03721779505056994, 0.0506502574841891, 0.041342897806316614, 0.06388453340956143, 0.11103217955678701, 0.02112392319499382, 0.07876102692846741, 0.1174685252564294, 30.567998681749614, 59.970944268362864, 43.26931612832205, 31.446799891335623, 47.00748865944998, 49.93074171883719, 57.75713355200631, 70.77647699628557, 3.1105652025767734, 0.6077510054622377, 36.436349936894004, 66.53265626089913, 68.91087177821568, 66.92946788242885, 62.65858391353062, 60.83828789847237, 62.60820252554757, 62.714197295052664, 67.90547439030239, 55.0699976512364, 38.995934282030376, 64.22791794368199, 57.295700209481375, 62.07419177464077, 57.08392953872681, 61.68216746194022, 56.687642506190706, 56.505558013916016, 57.77532046181815, 57.40075349807739, 56.73037045342581, 55.83737754821777, 52.969956738608225, 57.03953749792916, 55.08694430759975, 57.40112175260271, 46.46760320663452, 41.58382558822632, 42.23017133985247, 42.39073726109096, 44.79310819080898, 41.276958397456575, 41.05365719114031, 41.05156578336443, 41.62606021336147, 44.64641087395804, 45.60321256092617, 40.69264268875122, 40.43193932941982, 41.7999666758946, 44.17598308835711, 45.50722319739205, 48.23949459620884, 42.854394027165, 38.990479946136475, 39.40508590425764, 39.14422621045794, 41.65289763041905, 41.47035455703735, 42.51171234675816, 36.78175531114851, 39.05208614894322, 36.85698345729283, 39.91550057274954, 37.48702526092529, 39.71035153525216, 42.4365154675075, 44.615442752838135, 46.11350563594273, 45.525177342551096, 45.44953577859061, 46.18039246967861, 45.329019274030415, 44.62156064169747, 40.398421219417024, 42.52085270200457, 41.20473187310355, 44.03788069316319, 42.56030804770333, 45.55070155007498, 42.999517577035085, 43.364812169756206, 43.768582412174766, 43.518402099609375, 41.70928226198469, 41.46885027204241, 42.655487946101594, 44.71794605255127, 43.23220232554844, 47.17294611249651, 44.428015095846995, 43.55891009739467, 41.393521377018516, 39.2971247945513, 37.05706378391811, 40.10273020608084, 37.41777603966849, 36.621755668095176, 37.45103359222412, 41.21064131600516, 36.01089784077236, 41.149257455553325, 39.01362786974226, 35.96133286612374, 37.97258274895804, 45.90085254396711, 47.64087949480329, 44.42405114855085, 41.3694806098938, 41.43731239863804, 42.157090187072754, 40.199254580906455, 40.90805074146816, 39.40505116326468, 41.828231947762625, 41.43508897508894, 41.2031546320234, 40.63083151408604, 43.24804074423653, 44.173933369772776, 42.562739917210166, 46.794911997658865, 56.094540800367085, 57.709590503147666, 54.62792198998587, 52.45530366897583, 52.649568353380474, 56.26717574255807, 59.192412512642996, 63.54808534894671, 60.6086916242327, 60.472395760672434, 61.96862084524972, 59.935091563633506, 60.087138993399485, 61.89261450086321, 62.57870742252895, 65.72777693612235, 65.17898736681256, 66.5059334891183, 64.37920801980155, 65.54484476361955, 60.658649172101704, 58.65158557891846, 59.00467913491385, 73.83209323883057, 65.88016482761928, 87.82646002088273, 15.769661051886422, 0.15756256239754812, 67.39540018354143, 57.30675826753889, 52.806965896061485, 22.25304079055786, 50.72778000150408, 44.25289964675903, 74.78930486951555, 17.531371593475342, 0.3951129769640309, 0.09447359772665159, 0.04290228323744876, 0.028509720893842832, 0.03426186241475599, 0.04653338875089373, 0.02328306233643421, 0.0721159502863884, 0.14449557928102358, 0.12331794495029108, 0.13284243244145597, 0.10647974562432085, 0.09484125514115606, 0.10066010683242764, 0.30810985980289324, 0.2707157949251788, 0.26241999864578247, 0.25266339789543835, 41.52994925635201, 67.60249819074357, 58.79098728724888, 32.042854581560405, 50.45088039125715, 56.03191668646676, 60.89850793566023, 78.1201878956386, 2.9181511274405887, 0.7843821932162557, 42.0021835735866, 70.05101558140346, 71.16231741224016, 69.8446957724435, 65.41212722233364, 64.36198343549455, 65.67755535670689, 65.11225686754499, 64.4824721472604, 48.27645206451416, 43.33362865447998, 66.24848188672746, 58.11587946755545, 65.52130426679338, 58.54498631613595, 65.47789192199707, 59.16903182438442, 58.41612502506801, 60.37239728655134, 58.12197651181902, 60.21997465406145, 56.44641842160906, 54.656729221343994, 58.56264863695417, 58.817564146859304, 59.97798974173409, 48.815722601754324, 45.38971873692104, 44.400514125823975, 44.46070637021746, 46.90738943644932, 43.63115746634347, 42.80309200286865, 45.995018005371094, 43.80398348399571, 47.32727255140032, 48.2465226990836, 44.28521571840559, 42.11166981288365, 43.8225143296378, 45.10895592825753, 48.83599049704415, 51.50224706104824, 44.05000182560512, 40.34111942563738, 43.16758060455322, 43.35669319970267, 44.96536445617676, 44.98472908564976, 44.40472820826939, 37.95809575489589, 40.25837332861764, 39.00311524527413, 40.6079615184239, 40.06774950027466, 42.88863822392055, 47.578050409044536, 48.072623184749055, 50.423838002341135, 48.3515898840768, 52.39773089545113, 49.70162834439959, 47.84368004117693, 47.098610809871126, 43.845835958208355, 48.07405798775809, 42.65419558116368, 45.79307903562273, 44.770182609558105, 47.51445354734148, 45.68258530752999, 48.12734719685146, 48.56863423756191, 47.5618645804269, 47.71262311935425, 45.209617955344065, 47.05199187142508, 48.4339781488691, 46.48538017272949, 50.405435698372976, 48.19628027507237, 45.766557761601035, 46.25827830178397, 41.34054136276245, 38.655267579214915, 42.6968366759164, 41.10076597758702, 38.04652547836304, 39.4063470023019, 42.89650011062622, 38.07771941593715, 46.331258705684114, 44.217220646994456, 40.98786817278181, 40.73820202691214, 47.939520018441335, 49.68670013972691, 47.94949068341936, 43.52808094024658, 44.229386942727224, 44.21731792177473, 42.83175332205636, 43.26784658432007, 40.596010616847444, 46.317077432359966, 43.983750752040315, 43.50640950884138, 44.814668451036724, 46.49197401319231, 46.07489102227347, 44.67762565612793, 50.39754949297224, 58.76379203796387, 59.93170779091971, 57.02796874727522, 53.520191533224924, 55.28561414991106, 58.79234218597412, 62.21363517216274, 64.93346582140241, 61.76323209490095, 66.10159002031598, 65.69300815037319, 64.31074741908482, 62.850458417619976, 63.570396014622276, 65.05325971330915, 68.48342554909843, 69.45746571677071, 70.67510277884347, 67.38028090340751, 70.3179097856794, 62.198557581220356, 60.58558191571917, 62.92390782492501, 76.45916543688092, 69.3489556993757, 90.80488872528076, 19.47752206666129, 0.24369604193738528, 72.15272058759416, 65.15025656563895, 59.47789314814976, 32.80434588023594, 70.3702644620623, 60.43809945242745, 87.38338034493583, 22.795834064483643, 0.5529728734067508, 0.20662181132606097, 0.22939998762948172, 0.13210280212972844, 0.12697690432625158, 0.10669515335134097, 0.08767813736838953, 0.1943747563553708], [0.09457236528396606, 0.03739490965381265, 0.05665809814152973, 0.02871277928352356, 0.15024677424558572, 0.016467332440827574, 0.053423850797116756, 0.07741082366555929, 0.21162294011030877, 0.20329646047736916, 19.69851299694606, 58.24394518988473, 40.64486687523978, 31.059621947152273, 23.770664589745657, 44.267563819885254, 47.04313291822161, 70.91008390699113, 9.166152170726232, 0.34715490894658224, 22.89612783704485, 57.12100165230887, 63.38185664585659, 63.5631559916905, 56.74339485168457, 57.817544664655415, 57.78662518092564, 61.17897891998291, 46.521201610565186, 35.65765489850725, 57.426788398197715, 58.63565335954939, 57.5570775440761, 58.30352946690151, 54.491796357291086, 53.612658160073416, 54.74007633754185, 55.9145963532584, 55.76803452627999, 53.74665764399937, 52.88795409883772, 54.00239304133824, 55.28287655966622, 54.57638372693743, 54.06447866984776, 48.535057067871094, 39.53670563016619, 40.076990604400635, 40.69205904006958, 42.6705446924482, 38.843296255384175, 40.49483789716448, 38.001862457820344, 37.375138419015066, 38.75952182497297, 41.258649894169395, 40.6918888092041, 40.65242998940604, 39.790829045431956, 38.95371355329241, 40.749138491494314, 42.828810759953086, 41.42863409859793, 44.77415003095354, 41.30047457558768, 38.108597210475374, 37.00762735094343, 37.045078141348704, 39.17357540130615, 37.80663544791085, 37.843040534428184, 38.16924803597586, 35.48590932573591, 36.1899459702628, 37.78952898297991, 39.6615161214556, 40.38285378047398, 41.09467935562134, 42.67363664082119, 42.09322581972395, 42.636314392089844, 42.67838226045881, 43.35685995646885, 42.326518535614014, 41.17900964191982, 40.386699608394075, 41.879665987832205, 44.25714152199881, 42.05030332292829, 41.060633182525635, 44.46570559910366, 40.60760716029576, 41.82751628330776, 41.20358542033604, 39.60259192330496, 39.1889865057809, 39.401660442352295, 43.01265662057059, 41.79413366317749, 42.84852627345494, 41.00204944610596, 39.885456562042236, 38.42249250411987, 38.13160964420864, 36.341569559914724, 36.633803844451904, 35.847236497061594, 36.21100943429129, 37.262195450919016, 37.33860131672451, 33.73342078072684, 43.04121719087873, 34.62548610142299, 34.27385514123099, 38.73379264559065, 44.80637925011771, 45.41967936924526, 40.61087628773281, 40.818804604666575, 37.31758649008614, 40.013636929648264, 38.78775930404663, 40.51064157485962, 38.58916241782052, 38.88788979394095, 38.05599239894322, 37.78067697797503, 40.86798742839268, 40.797511850084575, 41.952007157461985, 41.9168701171875, 41.90022570746285, 50.731573717934744, 56.6134010042463, 53.005482878003804, 56.326662744794575, 53.03231334686279, 52.92809384209769, 52.688964639391216, 57.14140156337193, 58.03704868044172, 58.904784883771626, 58.59441580091204, 57.17145252227783, 58.440068517412456, 61.3881196975708, 59.08836323874337, 60.13962568555559, 60.0060396194458, 62.27893434252058, 60.18387876238142, 62.98626095908028, 55.592943395887104, 57.701909269605366, 56.421502181461875, 72.38949435097831, 61.68696171896798, 86.06652300698417, 6.684729414326804, 1.3380298018455505, 59.56424536023821, 52.24170562199184, 37.40802076884678, 43.17030777250017, 44.29459926060268, 36.4138377734593, 65.27698475973946, 8.45242886883872, 0.30303892333592686, 0.001731522343886484, 0.04238671197422913, 0.033990950523210425, 0.07682171956236873, 0.020745119146470512, 0.06744754114853484, 0.016214629036507437, 0.15743961185216904, 0.08551639265247754, 0.05303657693522317, 0.0480188613624445, 0.014585663231887987, 0.009781931310759058, 0.06824078929743596, 0.07693028516535248, 0.21988848729857377, 0.26393950996654375, 22.36120339802333, 69.50704111371721, 39.72777761731829, 35.08666583469936, 35.32218197413853, 54.59380633490426, 51.423652512686594, 76.39249052320207, 11.816286308424813, 0.4319109081157616, 25.738203355244227, 63.10756261008126, 64.9128088269915, 68.68315846579415, 57.932401861463276, 62.2783784866333, 62.813104901994976, 65.9743824005127, 54.03308323451451, 40.777740750994, 58.52522563934326, 60.422917638506206, 60.96479375021798, 60.31602655138288, 57.2492584500994, 57.00861801419939, 56.609086172921316, 60.02585588182722, 58.398427963256836, 58.4327312197004, 55.68879726954869, 56.754744734082905, 57.23220409665789, 57.96325881140572, 56.5896555355617, 50.5166346686227, 41.08193288530622, 42.85714898790632, 42.31914302280971, 45.5516916683742, 42.96394280024937, 43.25193520954677, 40.395909445626394, 38.98906251362392, 41.18294579642159, 41.90272011075701, 42.295588629586355, 42.571202823093955, 42.34388555799212, 39.871452467782156, 40.700494153159006, 46.49810232434954, 46.04841143744332, 44.804079396384104, 42.38737085887364, 40.38551146643502, 39.50398656300136, 41.523966857365195, 40.01729168210711, 38.9858524458749, 38.472915581294465, 39.68985434940883, 37.03557995387486, 37.274139404296875, 40.05843891416277, 41.448026520865305, 43.51734944752285, 46.012520517621724, 45.39730964388166, 45.44732972553798, 46.70728826522827, 47.177236625126426, 45.4451584134783, 45.29534830365862, 44.66337490081787, 43.842372281210764, 44.06394338607788, 46.238983154296875, 42.071766308375764, 41.402602672576904, 44.5114039012364, 44.561562946864534, 45.70599378858294, 43.2357736996242, 42.2764185496739, 42.984846455710276, 44.034826959882466, 47.4847743170602, 45.129053592681885, 47.53499589647566, 45.342429297310964, 43.949298109327046, 39.621313844408306, 38.29714352743966, 37.0566086769104, 37.51414408002581, 37.64578117643084, 38.13593142373221, 39.76640265328543, 38.739587443215505, 38.55361195972988, 42.98461021695818, 36.76514911651611, 36.69210270472935, 40.042079380580354, 47.2055401120867, 47.414142404283794, 42.95921107700893, 43.496004581451416, 39.793042046683176, 40.92117588860648, 41.352857044764924, 42.969744546072825, 42.41925266810826, 41.02484648568289, 42.16506324495588, 41.124980449676514, 44.8329039982387, 42.64805684770857, 43.20380851200649, 42.863079275403706, 44.57963868549892, 53.49326031548636, 60.004816736493794, 56.493200642721995, 58.53201402936663, 56.6571364402771, 55.00239862714495, 53.37116656984602, 58.4177439553397, 60.68747724805559, 62.58866419110979, 61.394657952444895, 61.96853746686663, 60.95152963910784, 63.77786922454834, 61.674732889447895, 62.16676957266671, 63.3631659916469, 67.00580774034772, 63.52913761138916, 65.16295092446464, 58.60200323377337, 62.506223814828054, 60.932838984898154, 74.98809283120292, 66.61387375422886, 88.30681678227016, 6.102651459830148, 1.8101049619061607, 69.31324890681675, 54.580305985042024, 46.881830487932476, 41.357001645224436, 46.18951198032924, 44.03851645333426, 69.96783869607108, 10.998703939574105, 0.34842830204537933, 0.017287794932989136, 0.050673327674823146, 0.05439401338143008, 0.0287981050621186, 0.025393207856853093, 0.03741710453427263, 0.04168843497921314, 0.24262558509196552, 0.21359834553939955, 0.120112219825387, 0.09695156690265451, 0.27953539309757097, 0.17630874791315623, 0.18634424012686523, 0.22156623298568384, 0.3515523315540382, 0.33136626758745735, 31.151129722595215, 77.7909266608102, 50.31368473597935, 40.38963522229876, 37.29877424240112, 58.92314897264753, 54.77517516272408, 82.56040641239711, 11.521670528820582, 0.433807087796075, 31.952461991991314, 65.80122634342739, 67.08909579685756, 69.96047360556466, 61.84641592843192, 65.29595334189278, 64.11307116917202, 68.730315889631, 50.700900895254954, 41.43906681878226, 61.94395474025181, 60.79617486681257, 64.91506004333496, 63.132339886256624, 58.60088457380022, 59.79781600407192, 59.81249754769461, 60.79081085750035, 61.248947279793875, 59.33787305014474, 57.128279890332905, 58.416013853890554, 59.17209597996303, 60.94929231916155, 59.77558871677944, 53.19218097414289, 44.55223151615688, 45.33853830610003, 44.68038756506783, 47.96209124156407, 43.77965784072876, 45.93643774305071, 43.412428174700054, 41.776526927948, 45.306687763759065, 45.49545642307827, 43.910707814352854, 45.47110646111624, 44.60937697546822, 41.88299070085798, 45.98862566266741, 46.86543273925781, 49.269530296325684, 46.634460721697124, 44.33471121106829, 44.09795134408133, 42.09937497547695, 43.18809516089303, 44.058509894779746, 40.73536368778774, 41.408640657152446, 42.18928466524397, 39.97394534519741, 39.39999982288906, 42.24654129573277, 45.60312223434448, 47.64386027199881, 49.13709415708269, 50.974639075142996, 50.15099614007132, 50.98292132786342, 51.471570764269146, 50.18987478528704, 48.232053075517925, 46.67199836458479, 47.13683632441929, 45.51712785448347, 48.88307843889509, 45.34283229282924, 42.41073417663574, 46.843372208731516, 45.161630221775596, 45.98844500950405, 47.84261696679251, 46.697310652051655, 46.19508443559919, 45.88728271211897, 50.55915764399937, 49.94346039635794, 52.549642835344585, 49.38537066323416, 46.46970156260899, 42.99396596636091, 40.87586668559483, 40.1002253804888, 40.41659770693098, 38.929912499019075, 39.76144511359078, 43.29182481765747, 41.893899372645784, 41.755730969565256, 49.42305074419294, 42.58710030147007, 40.260940687997, 43.05271993364607, 50.07979794910976, 51.2870682988848, 45.370864800044465, 45.54437868935721, 41.71430580956595, 43.635819707598, 43.775742530822754, 46.50723573139736, 44.35027517591204, 45.42937558037894, 45.251129967825754, 42.62655217306954, 46.10980224609375, 45.52810948235648, 45.58519240788051, 45.249792439596995, 47.06531851632254, 55.62454727717808, 62.80846350533621, 59.08722373417446, 61.081217765808105, 57.32953446252005, 56.949363776615684, 54.96521534238543, 61.646724700927734, 62.49525955745152, 65.16492421286446, 64.80014378683907, 63.568492208208355, 61.26624829428536, 65.97671699523926, 63.41130311148507, 66.5346017565046, 64.98915563310895, 69.80548013959611, 65.16462544032505, 69.26905141557965, 62.6823467527117, 66.15641825539726, 63.31522342136928, 79.463073185512, 67.94531536102295, 93.97587285723004, 8.531940579414368, 1.6353365970509393, 72.55547986711774, 62.66699818202427, 53.813120637621196, 65.0360003880092, 66.65107440948486, 50.69885465076992, 84.12121500287736, 14.115792632102966, 0.5322034050311361, 0.10978839094085352, 0.24689810297318868, 0.17624307929405145, 0.09591927765203373, 0.06823343397783381, 0.15838447186563695, 0.1496962516435555], [0.09868761910391705, 0.04551607137545943, 0.02664226868988148, 0.08682179903345448, 0.05510633944400719, 0.012573057120399815, 0.03755702184779303, 0.08437913403447185, 0.2266195953956672, 0.20350795984268188, 10.589381217956543, 56.139141287122456, 53.75369964327131, 40.037750652858186, 17.536579268319265, 35.20248883111136, 46.16300460270473, 69.88090283530099, 24.50374644143241, 0.6820004869784627, 6.419360339641571, 60.359855788094656, 61.679207529340474, 63.08327170780727, 59.145539964948384, 57.63266352244786, 59.86116967882429, 57.286063058035715, 44.22623593466622, 54.21704374040876, 57.36984096254621, 56.17734595707485, 57.91345064980643, 55.190663542066304, 54.39049857003348, 55.58160393578665, 54.96538209915161, 55.48811592374529, 54.635721342904226, 54.694127900259836, 53.43483291353498, 52.613673959459575, 53.43917901175362, 51.7635931287493, 47.257095745631624, 39.17379774366106, 40.29285029002598, 40.35812514168875, 42.61745350701468, 43.37548112869263, 42.664082867758616, 42.67450516564505, 40.18773446764265, 37.90648800986153, 38.55300746645246, 44.31194543838501, 45.10524211611067, 43.49902357373919, 40.381203583308626, 38.674225739070344, 40.98653064455305, 42.22551604679653, 44.40962321417672, 45.15502943311419, 38.90622956412179, 37.67321613856724, 39.19564288003104, 39.56245565414429, 37.980812890189036, 42.55096966879708, 39.43584210532052, 36.99134424754551, 37.80824742998396, 37.67189598083496, 36.79956007003784, 39.30655697413853, 39.41715839930943, 42.01957491465977, 40.12677444730486, 40.48332820619856, 43.8862293107169, 43.27229690551758, 42.44768817084176, 44.61177410398211, 44.05903448377337, 43.679614203316824, 47.30708456039429, 42.77898175375802, 38.201956680842805, 39.434838090624126, 44.28334665298462, 47.39763348443167, 41.98466716493879, 44.687790870666504, 42.06986945016043, 42.0777382850647, 40.71754503250122, 42.89739295414516, 41.79663501467024, 44.385248933519634, 41.32217379978725, 40.70455190113613, 37.70516395568848, 36.25439746039254, 34.96915790012905, 36.49383238383702, 36.21698835917881, 36.528552532196045, 37.24888270241873, 35.065470354897634, 34.735076563698904, 42.77404853275844, 30.92583785738264, 34.561406339917866, 40.724065916878835, 45.62442888532366, 43.821673597608296, 41.5811505317688, 39.05534832818167, 37.75661884035383, 39.02165303911482, 44.103468213762554, 40.94783265250069, 39.79337903431484, 38.70671551568167, 39.59978485107422, 39.84288842337472, 42.91945001057216, 42.51425191334316, 42.70637307848249, 40.00068201337542, 41.31774084908621, 42.7956782749721, 52.885157448904856, 54.13620492390224, 55.40159695489066, 54.341729164123535, 58.106217997414724, 55.58028725215367, 52.81577968597412, 52.03918647766113, 52.52383375167847, 53.49405935832432, 59.16429315294538, 58.8418550491333, 60.12972450256348, 60.79605674743652, 60.745251519339426, 61.61540222167969, 64.38633687155587, 59.02632277352469, 60.70297867911202, 53.74315227781023, 62.33646542685372, 58.733435358319966, 69.86570712498256, 62.69678510938372, 77.86511257716587, 1.3210119264466422, 7.6650260005678446, 69.22073364257812, 52.04906334195818, 30.46674258368356, 84.14529051099504, 55.27880491529192, 29.29442514692034, 63.708783285958425, 7.211947432586125, 0.05421742464282683, 0.05508737099756088, 0.04128771933860012, 0.015226151095703244, 0.011713062329883022, 0.008169975530888354, 0.04558629296453936, 0.03067719583798732, 0.05011498834937811, 0.06971117468284709, 0.06377518749130623, 0.02654967749757426, 0.028609153415475572, 0.025463264901190996, 0.03792074036651424, 0.062185956697378836, 0.23606417860303605, 0.13176884076425008, 12.797194770404271, 65.71208790370396, 52.476280280521934, 40.04609891346523, 23.557914222989762, 44.287338393075125, 52.0840996333531, 76.05787222726005, 29.022015810012817, 0.7502245775290898, 6.527004872049604, 66.23097242627824, 66.13105733054024, 65.16060243334088, 61.72357177734375, 60.71828556060791, 62.45288944244385, 60.083887236458914, 47.390268393925254, 57.25972243717739, 60.12470095498221, 59.723525864737375, 58.65715108598982, 58.404146330697195, 56.232393060411724, 58.91373416355678, 57.55505909238543, 57.030890464782715, 58.72452776772635, 57.61320161819458, 55.216945103236604, 55.5745723588126, 54.73758888244629, 55.91579839161464, 48.973783697400776, 41.52082279750279, 42.72732884543282, 44.23858635766165, 45.10984182357788, 45.2752228464399, 45.31082889011928, 45.119037764413015, 43.98095062800816, 40.02146407536098, 41.55203063147408, 45.16281488963536, 48.61717782701765, 43.69379200254168, 42.730702195848735, 40.70040382657732, 43.67795705795288, 43.65955127988543, 46.15404142652239, 46.03289610998971, 40.102243832179475, 40.2667042187282, 41.74882098606655, 42.79641825812203, 39.39887768881661, 41.98085607801165, 40.30240058898926, 39.706807953970774, 39.98806408473423, 38.76796736036028, 38.54946388517107, 40.65924964632307, 42.48121322904314, 44.698577948978965, 44.45305640356881, 44.75472286769322, 45.44012791769845, 45.14686182567051, 45.137415749686106, 47.60943194798061, 47.79207924434117, 46.47555889402117, 50.292412825993125, 45.26272651127407, 38.12099627086094, 38.810365268162315, 43.75047540664673, 47.94006545203072, 44.96975571768624, 47.231071267809185, 45.60230234691075, 45.0578727722168, 45.96875034059797, 47.73159864970616, 45.628427573612754, 48.07339096069336, 43.68528740746634, 42.52088049479893, 42.740947314671104, 38.34151472364153, 37.476891313280376, 37.87572833469936, 38.44025904791695, 37.48913056509835, 37.733022757938926, 38.9544882774353, 38.94787359237671, 43.37699236188616, 34.934913703373496, 37.18905176435198, 41.883532660348074, 48.37698554992676, 45.96208701814924, 42.84250913347517, 39.72329255512783, 40.669748374394004, 42.26308843067714, 44.63201420647757, 44.24063607624599, 41.86869478225708, 41.33793231419155, 42.213096141815186, 41.52869510650635, 46.27576691763741, 45.22287164415632, 44.95720727103097, 41.2822459765843, 43.83067498888288, 43.74236338479178, 54.68795095171247, 56.530613218035015, 58.70724759783064, 56.35281229019165, 59.82055745806013, 59.24073028564453, 55.27253416606358, 55.00524044036865, 55.036455222538535, 57.202007225581575, 60.75566686902727, 59.76138659885952, 63.28986249651228, 61.68734386989048, 64.85589613233293, 65.53080245426723, 69.19865226745605, 60.54294776916504, 65.31665202549526, 57.74628741400582, 64.29650361197335, 62.123558725629536, 73.46569388253349, 64.98213795253209, 79.18543011801583, 0.7676761725119182, 9.590489949498858, 75.71273435865129, 57.93234974997384, 40.21348449162075, 87.76296738215855, 64.72117750985282, 32.20239911760603, 70.16740485600063, 7.820904493331909, 0.09291353036782571, 0.035018293253545246, 0.024246914545074105, 0.04085837630555034, 0.029225575338516916, 0.03058618393593601, 0.03354539389589003, 0.015320447107244815, 0.23739863985351153, 0.13903855638844625, 0.24132838898471423, 0.17814084674630845, 0.20009080320596695, 0.11813571516956602, 0.18171956257096358, 0.17255378940275737, 0.39266653252499445, 0.4530868189675467, 17.98407105037144, 75.603821345738, 65.85757623400006, 52.575257369450156, 28.225625446864537, 49.8323587008885, 54.98964868273054, 80.5503967830113, 30.556763444628032, 0.774738256420408, 10.56655204296112, 68.07552460261753, 67.04059042249406, 67.51511069706508, 63.55645098005022, 63.60754803248814, 64.46133572714669, 60.582038334437776, 50.23422861099243, 61.75308772495815, 61.7619605745588, 62.601177896772114, 61.41445337023054, 61.505370548793245, 60.14278711591448, 61.56699412209647, 60.06398759569441, 61.06417383466448, 58.70820644923619, 61.92962755475725, 57.04223687308175, 56.863914830344065, 58.2310597555978, 58.169331959315706, 52.05891241346087, 43.83727577754429, 43.86846276691982, 46.40111936841692, 47.32359348024641, 47.36754431043352, 47.533911977495464, 46.730331965855186, 45.48291145052229, 43.15288169043404, 43.41118444715227, 48.50937305177961, 51.62219033922468, 46.71059908185686, 46.15436451775687, 41.838529178074424, 46.73729058674404, 47.56696803229195, 50.08480065209525, 49.49795579910278, 41.58745602199009, 44.16648490088326, 45.84319291796003, 44.69065005438668, 41.722466468811035, 45.648674624306814, 42.87965767724173, 42.64623989377703, 42.78312635421753, 41.79007591520037, 41.963582856314524, 43.03456081662859, 46.16467564446585, 48.40856858662197, 49.81857347488403, 48.31393412181309, 51.732607637132915, 49.32114151545933, 48.58273908070156, 50.77701146262032, 50.80564498901367, 49.05983713694981, 53.73882702418736, 48.05974817276001, 37.904834338596885, 38.97960948944092, 46.58165788650513, 50.335203307015554, 47.39779676709856, 51.66411229542324, 49.71825885772705, 49.30276353018624, 48.76515361240932, 50.49485901423863, 50.183044706072124, 53.53143719264439, 48.81992973600115, 46.404614312308176, 43.36529854365757, 39.89901944569179, 38.46029765265328, 39.33698313576834, 40.97285311562674, 41.89461156300136, 40.29372576304844, 41.84863533292498, 41.85696274893624, 48.049951212746755, 42.01244606290545, 39.63444593974522, 44.36823626926967, 50.2885913167681, 47.248504298073904, 45.72102274213518, 42.33818803514753, 43.48213945116316, 43.80015502657209, 47.225377219063894, 47.14107125146048, 45.155223982674734, 43.476803234645296, 45.03174407141549, 45.75142458506993, 48.36279385430472, 47.89488131659371, 48.636969770704, 43.9227420943124, 47.00937162126814, 46.78613642283848, 58.39325850350516, 58.58842645372663, 61.854038102286204, 59.85304028647286, 62.844239779881065, 60.533956800188335, 56.0716221673148, 58.23295313971383, 57.320515700748985, 58.83965247017996, 64.88112504141671, 63.66786534445626, 66.90059811728341, 64.123993737357, 66.79210894448417, 67.25497014181954, 71.98918083735875, 63.91656916482108, 68.50883511134556, 60.75567381722586, 68.283449445452, 64.79802458626884, 75.71012878417969, 66.24233967917306, 86.12884140014648, 2.1722442039421628, 8.357008389064244, 85.31369263785226, 64.18433884211949, 46.27447802679879, 96.86964470999581, 72.4851085117885, 38.253929206303184, 85.75588294437954, 12.676701716014318, 0.18676567822694778, 0.08104868738779, 0.12021522144121782, 0.1016497298010758, 0.09846890691135611, 0.10024574585258961, 0.16260383331349917, 0.13212081044912338], [0.07669125084898301, 0.044513308576175144, 0.0386346474156848, 0.0060274829738773406, 0.04122354688921145, 0.05264010213847671, 0.04967772002731051, 0.06155793861086879, 0.16133888119033404, 0.23302352747746877, 5.4756859711238315, 51.72909532274519, 40.00307566779, 28.598592587879725, 29.948306219918386, 38.12514434541975, 36.59951795850481, 62.44125120980399, 39.22423471723284, 0.30298290348478724, 0.5055617317557335, 53.84869541440691, 64.6117503302438, 61.217603955950054, 58.256747245788574, 57.58417899268014, 56.47811957768032, 54.91079010282244, 54.45434209278652, 56.35202366965157, 53.95770570210048, 55.94181244713919, 54.590752601623535, 54.779601165226524, 52.47616216114589, 54.448960712977815, 52.199561323438374, 55.9192863873073, 53.84135464259556, 55.33356019428798, 53.193056447165354, 53.01622131892613, 48.65061950683594, 43.433661869594026, 40.02530642918178, 40.61710187367031, 41.5517874445234, 40.53730876105172, 42.41175208772932, 43.44833646501814, 43.21098600115095, 43.13570921761649, 41.142243249075754, 37.535614013671875, 38.42327765056065, 40.29941633769444, 45.26360198429653, 46.185832909175325, 42.62721225193569, 39.334499154772075, 40.16134173529488, 40.72234623772757, 44.243314606802805, 49.146192823137554, 46.008480140141074, 36.669972692217144, 38.994843414851594, 41.63334192548479, 36.14519262313843, 41.01483760561262, 42.673779078892295, 39.52692256655012, 36.718585763658794, 37.60220554896763, 36.976502895355225, 38.5200834274292, 39.56629800796509, 42.34639385768345, 38.39739213671003, 39.78839717592512, 42.151740074157715, 42.41720642362322, 44.66276693344116, 46.397502831050325, 46.72479772567749, 47.10050071988787, 46.138456617082866, 40.0480409349714, 39.36196538380214, 36.96128634044102, 40.916843686785015, 42.079006331307546, 46.28612320763724, 45.19434234074184, 44.672956466674805, 41.849583762032644, 43.389978545052664, 42.54852737699236, 42.36587313243321, 39.105826990945, 44.92324447631836, 38.706322942461284, 38.660808767591206, 35.04132883889334, 37.05125856399536, 34.94788599014282, 36.64122452054705, 33.570954527173726, 37.48519441059658, 33.12973696844918, 38.98460177012852, 41.03757905960083, 27.24486984525408, 36.113349028996055, 43.15792955671038, 46.398628439222065, 42.980788707733154, 43.988725662231445, 39.477705001831055, 39.53089346204485, 42.41800546646118, 46.672630650656565, 41.0686479296003, 38.04021998814174, 38.43420716694423, 40.34945726394653, 41.043405124119346, 43.644841943468364, 44.622036593300955, 43.26087406703404, 40.34278351919991, 42.076133251190186, 41.32559926169259, 44.08625405175345, 49.80732781546456, 52.93035895483834, 52.85423796517508, 55.48302984237671, 57.89861624581473, 57.98965501785278, 56.20142841339111, 55.44710070746285, 58.890110288347515, 58.382426261901855, 57.17949158804757, 59.19291973114014, 60.52233246394566, 61.81369686126709, 63.79014669145857, 61.646544047764365, 59.389796938214985, 59.82682473318917, 56.00664956229073, 57.88601916176932, 62.85193143572126, 68.45865522112165, 69.58424949645996, 61.28910786764962, 0.3429940507880279, 17.02919748851231, 71.0225613457816, 43.195272650037495, 33.87822471346174, 25.26644846371242, 22.460164853504725, 37.39453084128243, 45.40478243146624, 4.149592740195138, 0.06195485445537737, 0.08495527811880622, 0.06308710548494544, 0.07279846152024609, 0.018498108023777604, 0.02101165957615844, 0.04021137959456869, 0.07494012838495628, 0.059864885173738, 0.0410760265908071, 0.012722667306661606, 0.02262506657280028, 0.06479938860450472, 0.027967359371749417, 0.049999793459262164, 0.043375659800533733, 0.20952040436012404, 0.16639559556330952, 7.4415024518966675, 60.18413584572928, 44.077461106436594, 27.51450685092381, 28.59313998903547, 43.74538237707955, 42.04847594669887, 67.70005784715924, 45.91012838908604, 0.4182145159159388, 0.8477889565484864, 56.58848476409912, 67.70551218305314, 66.89953504289899, 59.909459659031455, 61.20034463065011, 57.72442143304007, 58.167737347739084, 59.209407806396484, 59.50267737252371, 55.59518418993269, 58.349839210510254, 55.90052972521101, 56.542327880859375, 56.332509653908865, 59.616127559116904, 55.79717179707119, 58.487385749816895, 57.35986334936959, 58.53218078613281, 55.33045434951782, 56.46255561283657, 50.909037658146445, 46.041376386369976, 41.94788340159825, 44.53573996680123, 42.50958619798933, 42.03089700426374, 45.72270768029349, 45.937549454825266, 45.237108503069194, 44.96680620738438, 43.703908579690115, 41.1568865776062, 41.25773968015398, 41.43870203835623, 46.33540678024292, 49.52985497883388, 43.37997661318098, 42.12494087219238, 40.89588097163609, 44.68660272870745, 47.419238907950266, 49.96902281897408, 49.23421260288784, 39.07764162336077, 40.8204721723284, 43.83338826043265, 37.4864033971514, 42.04309456689017, 42.85548489434378, 39.70534535816738, 39.44688279288155, 38.88971022197178, 38.90579877580915, 39.46265867778233, 41.28572702407837, 44.31915072032383, 41.51618834904262, 43.22663681847708, 45.2833696092878, 46.76308577401297, 47.45936475481306, 48.556683335985454, 48.42915609904698, 47.83282348087856, 45.6589857510158, 42.53179611478533, 39.51695190157209, 39.14925670623779, 42.311305454799104, 45.272909096309114, 48.43941511426653, 49.02260174070086, 47.93377038410732, 45.18117897851126, 46.54932444436209, 45.34702205657959, 44.8976924760001, 43.35325731549944, 47.61191592897688, 40.387248516082764, 38.994023527417866, 39.05333335059029, 36.28730412891933, 36.9563878604344, 38.402693612234934, 36.14465413774763, 40.138972009931294, 36.61552660805838, 41.265528610774446, 40.64541578292847, 33.132787227630615, 38.65923152651106, 45.58912508828299, 48.62870141438076, 43.867041860307964, 46.03601237705776, 40.288420813424246, 41.78476749147688, 45.776969637189595, 49.066556044987266, 45.0001471383231, 40.48632287979126, 41.478973797389436, 41.02612495422363, 43.624254431043354, 45.54270417349679, 46.94228328977312, 46.26466369628906, 43.518537589481895, 43.544426577431814, 43.91110038757324, 47.222479820251465, 51.981947217668804, 54.44748074667794, 54.409018993377686, 58.345962115696494, 59.33151544843401, 59.949516023908345, 59.77751336778913, 60.67074598584856, 60.18790871756417, 60.1716707774571, 59.01034886496407, 63.451477595738, 63.14948109218052, 64.21189539773124, 70.94450528281075, 65.60509954180036, 60.87649604252407, 63.00442355019705, 59.68766621180943, 61.057267325265066, 67.18757956368583, 71.95423834664481, 75.49547808510917, 64.0836455481393, 0.4127677253314427, 19.00903456551688, 75.83959456852504, 50.592793873378206, 43.44886800221035, 32.51540504183088, 29.826101303100586, 41.16213594164167, 54.56116369792393, 5.919159088815961, 0.1806418996836458, 0.023201465107766644, 0.05840756158743586, 0.013738201831334403, 0.0347118295196976, 0.05437565900917564, 0.06210359611681529, 0.051708063044186146, 0.1520398301737649, 0.14028229750692844, 0.15136076589780195, 0.10356682193066392, 0.1446060040699584, 0.13667741737195424, 0.13506505531924112, 0.13367997535637446, 0.3645046693938119, 0.36370641365647316, 10.254128898893084, 72.60622256142753, 51.75515801565987, 38.74837344033377, 39.3483121735709, 55.01254994528634, 45.762399264744346, 73.51769420078823, 47.372769355773926, 0.4134852354015623, 1.919057926961354, 61.749266215733115, 69.64062023162842, 70.92860085623605, 63.2760842187064, 65.15650299617222, 60.810925892421174, 62.69947406223842, 62.13006223951067, 61.44525473458426, 59.33416271209717, 61.269236019679475, 60.091655322483604, 60.618217604500906, 58.94104058401925, 60.724281855991904, 55.7073107446943, 60.97240202767508, 58.21268177032471, 60.966558592660085, 58.48718425205776, 60.70452812739781, 54.77069704873221, 48.410048552921836, 44.965190751211985, 46.38689293180193, 45.74000174658639, 44.91502128328596, 48.29457991463797, 47.165105070386616, 47.86879083088466, 46.556932721819194, 45.958265508924214, 43.29608406339373, 42.8617730140686, 45.19793108531407, 47.67286205291748, 51.797531604766846, 46.806247983660015, 43.53141260147095, 44.55525050844465, 46.54843854904175, 49.76987702505929, 53.885315895080566, 52.83749975476946, 42.030907426561626, 43.20918641771589, 46.910839217049734, 38.20060873031616, 45.03480127879551, 45.1653162411281, 43.80910430635725, 41.65867158344814, 42.069633211408345, 40.914776597704204, 43.08909027917044, 44.788293089185444, 47.48956509998867, 45.15607861110142, 49.33530541828701, 50.60829530443464, 50.51695775985718, 51.75914280755179, 52.68273210525513, 52.997586250305176, 51.70146928514753, 48.066939558301655, 43.17857960292271, 41.34358467374529, 39.11799676077706, 43.23575285502842, 46.12773902075631, 51.472609519958496, 52.47564104625157, 51.538534028189524, 50.259030205862864, 50.9046186038426, 51.19611637932913, 50.62783016477312, 46.42202649797712, 50.454441343035015, 44.05957644326346, 41.96863767078945, 40.54073074885777, 38.40130049841744, 38.70765699659075, 40.03211218970162, 38.408464091164724, 40.19049637658255, 41.02039269038609, 42.18371220997402, 48.612654549734934, 37.12592390605381, 38.006990228380474, 49.02440479823521, 49.90205608095442, 48.64661039624895, 47.718716689518516, 42.09735999788557, 42.63708911623274, 47.17162248066494, 50.24326474325997, 46.0188433783395, 42.36290972573416, 42.691212109157014, 44.807484013693674, 45.35341787338257, 47.26424544198172, 50.034231662750244, 49.19143254416329, 45.93058041163853, 46.77161468778338, 46.636166504451204, 50.681907994406565, 54.88546044485909, 57.82964842660086, 56.78903062002999, 62.98200866154262, 63.33626256670271, 62.50660596575056, 60.801650047302246, 60.49921580723354, 63.65537248338972, 63.40324320111956, 61.00696931566511, 65.57111590249198, 66.09133447919572, 66.66366454533168, 67.90963636125836, 69.92260592324394, 63.59805679321289, 66.36001437050956, 60.84078924996512, 66.13724817548479, 70.28677490779332, 76.41060447692871, 76.32129233224052, 70.09369141714913, 0.5965100143636975, 17.994069508143834, 87.77103424072266, 53.416253430502756, 51.82559190477644, 32.80978284563337, 30.40798166819981, 54.146658488682334, 66.29519462585449, 8.800286088671003, 0.3335687108337879, 0.21545563159244402, 0.11078743876091071, 0.15725640739713395, 0.1545317228883505, 0.18933025561273098, 0.1094803089009864, 0.20191231689282826], [0.005822312643951071, 0.06233509869447776, 0.055412165354937315, 0.12844809038298471, 0.060387893180762015, 0.017198681232652495, 0.04983390182522791, 0.053800037396805625, 0.18856341604675564, 0.15266134110944612, 5.797421004090991, 52.40421009063721, 43.30673565183367, 56.27807746614729, 44.95020696095058, 31.865321159362793, 29.935646602085658, 54.09837198257446, 47.0082494871957, 4.130763556276049, 0.26650467089244295, 34.81217377526419, 63.078421865190776, 62.297006607055664, 57.90735707964216, 59.598805700029644, 53.91892780576433, 56.11980792454311, 51.56576749256679, 53.28303214481899, 50.07605634416853, 52.481435843876426, 50.99937466212681, 54.70601626804897, 54.05366727284023, 54.27461998803275, 54.37385068620954, 52.862266608646934, 55.97838429042271, 54.15307167598179, 48.17401129858834, 46.45631585802351, 42.53495407104492, 40.2285030228751, 40.53209066390991, 41.12934739249093, 40.32059097290039, 42.44002430779593, 46.45919588633946, 48.22880826677595, 46.82257277624947, 44.30648415429251, 41.2396639415196, 40.235135078430176, 37.65705810274397, 40.28911215918404, 45.918862274714876, 47.81596367699759, 43.880507469177246, 42.587951455797466, 41.16548497336251, 41.47059774398804, 43.96914216450283, 46.249954359872, 48.39872298921858, 42.95092535018921, 37.769872529166086, 41.056679657527376, 36.509431089673726, 39.22686461039952, 40.321014813014436, 43.22667155947004, 36.85764353615897, 38.97445740018572, 35.98773602076939, 39.43229852403913, 38.38134527206421, 39.63627331597464, 37.87477643149239, 41.75587340763637, 38.73084660938808, 43.19330283573696, 41.25754860469273, 46.245740277426584, 46.619970253535676, 48.27728584834507, 41.62284319741385, 42.12791470118931, 38.99524293627058, 40.863405091421946, 40.67422996248518, 39.55165120533535, 44.29781627655029, 49.21839502879551, 45.019661154065815, 41.332773276737754, 39.76059743336269, 37.24587760652815, 39.11635003771101, 39.93295792170933, 42.06860487801688, 39.28990561621529, 37.2220070702689, 38.064496994018555, 36.39141246250698, 35.825662340436665, 33.44432013375418, 37.456088406699045, 33.304925373622346, 38.466648306165425, 44.646560260227744, 26.922153813498362, 32.29264579500471, 39.617850167410715, 47.336228779384065, 46.44295447213309, 45.924076897757395, 43.88785171508789, 41.37858969824654, 42.57612909589495, 46.64437927518572, 47.91697311401367, 40.65022393635341, 38.36468696594238, 40.008457047598704, 40.429601260593955, 44.77562652315412, 48.64304597037179, 47.36672789709908, 45.41597597939627, 43.05220576695034, 40.26937232698713, 40.98298706327166, 41.202477182660786, 43.587081568581716, 46.04765408379691, 50.324562140873496, 54.28667163848877, 55.48281792231968, 55.879431520189556, 58.87138489314488, 56.477334431239534, 57.911578110286165, 57.339776107243125, 58.97240475245884, 55.28546128954206, 58.50545801435198, 62.469092641557964, 64.58709117344448, 58.65077958788191, 59.56569753374372, 56.83933905192784, 59.7809944152832, 57.22041300364903, 65.8286578314645, 62.57872826712472, 77.43374061584473, 41.1184595652989, 0.5859200369034494, 26.909023455211095, 66.23456464494977, 40.66762222562517, 34.014892305646626, 24.756631340299332, 29.62884889330183, 42.03718164988926, 44.01262746538435, 3.506568444626672, 0.2752530500292778, 0.023719957464241555, 0.09610838536173105, 0.060561089244272025, 0.06386636902711221, 0.02603604514817042, 0.051350522586809735, 0.02997206903195807, 0.02911867553900395, 0.033954787999391556, 0.05855014215090445, 0.0398879185585039, 0.08762224643890347, 0.029790798401726142, 0.08787581497537238, 0.05277174471744469, 0.17987223741199287, 0.23891540989279747, 7.762059330940247, 62.28597286769322, 47.68119989122663, 57.42891454696655, 47.935298987797324, 33.87931210654122, 35.10362638745989, 60.52398613521031, 54.093278953007285, 4.885700532368251, 0.34272855360593113, 35.087715012686594, 65.72155829838344, 64.63237953186035, 62.26473222460066, 62.58451611655099, 58.5486410685948, 59.517720222473145, 55.19140352521624, 56.617017541612896, 52.43833269391741, 55.40512316567557, 54.81163583483015, 56.87912791115897, 56.88196625028338, 58.164110388074604, 58.4443416595459, 56.66498095648629, 56.76219667707171, 56.788203784397666, 52.687067781175884, 48.45042453493391, 43.24465697152274, 43.10604040963309, 42.28341885975429, 44.479438713618684, 43.889140605926514, 45.232564381190706, 48.41183076586042, 49.81037112644741, 48.5312876701355, 47.07633488518851, 42.71087203707014, 43.14874056407383, 41.513815539223806, 42.104669502803254, 48.62524468558175, 51.309875760759624, 45.7506811278207, 44.749428340366904, 43.35142993927002, 44.13991151537214, 45.798029627118794, 48.92112677437918, 50.21946021488735, 45.288045746939524, 41.79240008762905, 43.30936207090105, 39.51459993634905, 40.12548555646624, 41.469968932015554, 44.657399450029644, 37.78686087472098, 40.232268946511404, 35.834323269980295, 39.59087726048061, 40.31617886679513, 40.96669701167515, 42.194992610386436, 45.498850618089946, 42.20844432285854, 45.67898266656058, 43.95580857140677, 49.89969021933419, 47.57670940671648, 48.64014509746006, 41.63304662704468, 42.808230195726665, 40.456518581935335, 41.510049615587505, 40.81156458173479, 39.94508252825056, 46.042620113917756, 50.992381300245015, 49.28475379943848, 46.070676939828054, 42.894429547446116, 42.56879179818289, 43.170290402003694, 44.640362467084614, 43.73341063090733, 41.35137707846505, 37.92088120324271, 38.6626535143171, 39.27731895446777, 38.057823249271934, 35.92329495293753, 39.40037849971226, 37.800792012895855, 38.75257362638201, 43.99671956471035, 31.45226812362671, 36.64434426171439, 43.01890999930245, 48.783542019980295, 48.63957534517561, 47.41118941988264, 45.52522250584194, 42.71442951474871, 45.88991955348423, 48.90369374411446, 51.723064286368235, 43.03617627280099, 39.9375194140843, 41.42216879980904, 42.926165444510325, 48.57085418701172, 49.37100178854806, 49.83961609431675, 48.67511885506766, 46.49772364752633, 43.54956824438912, 44.63541534968785, 43.44668279375349, 45.68084825788225, 48.76367712020874, 52.21963814326695, 56.84702723366873, 60.20295851571219, 57.884619099753245, 62.30944388253348, 60.09085627964565, 59.94902965000698, 61.04681028638567, 60.86974934169224, 59.186110496520996, 60.65475818089077, 68.19909136635917, 72.86529309409005, 59.808085441589355, 63.421273776463096, 58.68010098593575, 63.494403566632954, 58.078720501491, 70.12687601361955, 64.86670058114188, 82.48159299577985, 37.26900121143886, 0.5687327448810849, 30.895557607923234, 73.45627212524414, 43.83526427405221, 38.89646734510149, 28.96662129674639, 36.02866785866873, 52.02461610521589, 54.083065101078574, 5.264422518866403, 0.4668270988123757, 0.11278624686279468, 0.18105527678770678, 0.016958529029839804, 0.1030134901936565, 0.043019415345042944, 0.06830837138529335, 0.052590569082115374, 0.10819495322981051, 0.17744122285928043, 0.20530292923961366, 0.2928577225123133, 0.35406548955610817, 0.28755849972367287, 0.18506100827029773, 0.21803015630160058, 0.36656396889260834, 0.39404138017977985, 9.820536988122122, 74.0592576435634, 56.776600292750764, 68.8081774030413, 55.933026450020925, 47.98026425497872, 40.376308577401296, 66.33172130584717, 57.18914610998971, 5.390259172235217, 0.2655449781034674, 42.82906436920166, 66.96876689365932, 68.11128003256661, 64.10433033534459, 67.1770669392177, 61.566368784223286, 61.85439246041434, 56.62637676511492, 60.73986666543143, 56.37387228012085, 58.81368705204555, 57.24792439596993, 60.769215856279644, 60.419957705906455, 58.66491917201451, 60.77200903211321, 58.97130693708147, 61.69544546944754, 59.04470770699637, 53.1946336882455, 51.34063196182251, 47.16929483413696, 43.80198587690081, 44.78170967102051, 46.33610507420131, 45.585303579057964, 48.17070048195975, 50.520633356911794, 51.78383323124477, 51.271803106580464, 50.21429770333426, 45.87631845474243, 46.33995785032, 42.7556323323931, 44.85417938232422, 50.00675848552159, 54.002528531210764, 48.38475711005074, 48.73607540130615, 46.20795944758824, 46.72621863228934, 48.91812515258789, 50.08877502168928, 51.83803265435355, 49.63260841369629, 44.03713376181466, 46.18454054423741, 40.97910302025931, 43.94853728158133, 43.33906214577811, 45.46414089202881, 39.35825851985386, 44.2396285874503, 38.05796568734305, 44.25028712408883, 44.8269806589399, 45.381033488682334, 45.4481600352696, 51.146089349474224, 46.228880473545615, 53.78909376689366, 49.474436146872385, 56.55408770697457, 52.355586596897666, 52.52297912325178, 44.83321666717529, 42.035760743277415, 40.97037260872977, 42.74199301855904, 42.58797924859183, 42.08812236785889, 48.615989685058594, 53.812477929251536, 52.38765253339495, 50.07771348953247, 46.87188761574881, 47.38633918762207, 47.95408691678728, 45.382148674556184, 48.0215539251055, 45.86125823429653, 41.34756946563721, 41.35189471926008, 41.55335078920637, 40.30568013872419, 38.90217876434326, 40.39654867989676, 41.30170093263899, 39.94384227480207, 47.02649893079485, 37.767496245247976, 41.47838320050921, 45.604289531707764, 50.822317191532676, 49.86903824125017, 51.135399545942036, 48.27160917009626, 44.801181997571675, 49.01593494415283, 52.26574291501726, 54.62999602726528, 45.12302950450352, 42.74122176851545, 44.92455768585205, 46.68085731778826, 51.81588527134487, 54.14636319024222, 51.89162758418492, 50.47534499849592, 47.58250420434134, 45.984307357243125, 48.24586956841605, 45.13336494990757, 48.38832153592791, 51.62516416822161, 55.539563860212056, 58.746984345572336, 61.91088826315743, 62.33738258906773, 64.81710433959961, 62.653775760105674, 62.52651950291225, 62.04391152518136, 63.955173356192454, 59.73907593318394, 64.05135032108852, 66.32354327610561, 70.61362511771065, 65.38899666922433, 65.46675395965576, 64.57192325592041, 65.47763483864921, 62.69434629167829, 72.44074426378522, 70.80438096182687, 83.12979739052909, 46.546197754996165, 0.5277415215969086, 31.838313511439733, 82.10770348140171, 51.4720710345677, 49.067375932421, 35.53966753823416, 42.487553460257395, 59.97246592385428, 68.06069714682442, 7.929886988231114, 0.5428399571350643, 0.2086709870823792, 0.31784417746322496, 0.18406962789595127, 0.23101720799292835, 0.1527028131697859, 0.14515122052814278, 0.15106617313410553], [0.04440932308456727, 0.07381967029401235, 0.060463943385652134, 0.04412090838221567, 0.04557355686223932, 0.024472357805020044, 0.11198837789041655, 0.04394778356488262, 0.08072839850293738, 0.1196916231087276, 6.2323265586580545, 45.112287589481895, 35.47942318235125, 17.90610878808158, 20.536312886646815, 30.743214879717144, 28.649588891438075, 49.81345612662179, 51.4148074558803, 9.069613030978612, 0.655249108161245, 4.83029385975429, 51.40462139674595, 66.28361197880336, 56.75872605187552, 61.0450940813337, 53.310501847948345, 57.14318725040981, 53.06672430038452, 56.28413282121931, 52.208812849862234, 52.55449615206037, 51.78627552304949, 54.32048504693167, 54.29645470210484, 56.29173762457711, 51.23830584117344, 54.88728434698922, 53.74534790856497, 52.04149675369263, 48.75542613438198, 47.91074752807617, 45.745025294167654, 42.26065656117031, 41.04904358727591, 39.425885336739675, 40.2000675201416, 46.83822011947632, 48.020470006125315, 49.57709925515311, 47.88603278568813, 46.378860814230784, 43.26956626347133, 41.139252049582346, 38.88386678695679, 38.06821428026472, 43.1056478364127, 49.255185740334646, 45.17538070678711, 44.028247015816824, 43.59548888887678, 46.88016292027065, 45.71377577100481, 48.40736307416643, 50.08907379422869, 49.909924915858674, 43.61328322546822, 41.12658200945173, 37.18791225978306, 39.633865765162874, 36.92578451974051, 39.2573880468096, 40.69647114617484, 35.5399489402771, 39.014413016183035, 36.90752812794277, 39.0220490864345, 36.66517496109009, 39.89448574611119, 38.093693324497764, 39.77123512540545, 37.11141954149519, 38.534879616328645, 42.2868651662554, 49.61737101418631, 42.720686367579866, 44.426601137433735, 42.689145020076204, 39.26043135779244, 43.454370975494385, 39.2700719833374, 38.83946084976196, 44.0792989049639, 47.80209854670933, 42.187248843056814, 38.597152846200125, 39.500376973833355, 39.98789037976946, 40.07147026062012, 40.66822324480329, 39.90307371956961, 38.48391457966396, 38.734261648995535, 37.61270775113787, 36.060285636356895, 36.050057888031006, 39.042025157383506, 37.95206124441964, 38.69710963112967, 49.41820437567574, 32.789539269038606, 28.866292783192225, 37.690576212746755, 45.14191818237305, 49.266177790505544, 49.98728615897042, 44.65100710732596, 42.65180540084839, 43.768026556287495, 46.88759749276297, 48.87259708132063, 46.44332620075771, 39.84168291091919, 38.431222915649414, 40.45381920678275, 42.830714566367014, 47.390956265585764, 50.458360127040315, 48.27485397883824, 47.64564595903669, 47.57639673777989, 42.19138649531773, 40.50377675465175, 42.9327905518668, 43.072689056396484, 45.471221106392996, 45.29502173832485, 48.314621993473594, 52.87582949229649, 54.28747068132673, 54.50974702835083, 53.54334987912859, 55.986242703029085, 57.46934264046805, 57.06655556815011, 55.588611194065635, 55.28519378389631, 64.03082534245083, 58.262535095214844, 58.50800800323486, 59.77993828909737, 55.43635184424264, 57.522704805646626, 55.542589800698416, 67.28588267735073, 61.11666052682059, 76.50901181357247, 15.33121235030038, 0.1559792145022324, 40.88130712509155, 63.276987484523225, 38.23933104106358, 31.7944530078343, 39.53037234715053, 41.294332368033274, 40.83608824866158, 42.040492466517854, 5.6740314194134305, 0.2778250777295658, 0.12036350848419325, 0.1155203969350883, 0.08009138304208006, 0.04240845223622663, 0.08990512322634459, 0.06092558468558958, 0.03243575165314334, 0.03973210656217166, 0.08610726773206677, 0.046291114429810216, 0.045317996825490675, 0.08824696684522287, 0.04628772175471697, 0.07395447484616723, 0.05657833295741251, 0.1396009669240032, 0.1296137049794197, 7.4990057434354505, 56.65041753223964, 40.67517144339425, 22.13909207071577, 31.817420278276714, 31.065976074763707, 34.049303259168354, 54.756168365478516, 59.80594539642334, 11.629689829690115, 0.5286756743277822, 3.849427955491202, 48.14969955171858, 70.32421180180141, 58.925302914210725, 65.58273329053605, 57.98445776530674, 61.16834817613874, 58.13790873118809, 58.37248338971819, 54.86357361929757, 57.01869290215628, 53.928912367139546, 58.73375497545515, 56.06351361955915, 57.53592375346592, 53.75628784724644, 54.65058353969029, 55.49123566491263, 56.05533906391689, 50.640104157584055, 51.26397596086775, 47.29297971725464, 45.24174295152937, 42.14833198274885, 42.88386481148856, 43.82924713407244, 48.08675234658377, 50.1736090523856, 52.57798106329781, 50.64801468167986, 50.47538321358817, 45.837293897356304, 43.89211790902274, 41.798354693821494, 41.511981214795796, 46.133165563855854, 51.526649134499685, 48.18971422740391, 46.287870679582866, 46.54403339113508, 47.79631069728306, 49.22720881870815, 50.439391544886995, 52.277200494493755, 51.07186869212559, 44.51303672790527, 43.323418276650564, 39.630395139966694, 41.87000104359218, 39.75006743839809, 41.591162885938374, 41.86080162865775, 36.9295608656747, 38.26313556943621, 36.96139056341988, 39.1941351209368, 39.306320735386436, 43.545705045972554, 41.268735204424175, 43.28306661333357, 42.44966493334089, 42.54638385772705, 46.49042109080723, 49.24208491189139, 45.564313071114675, 43.49702944074358, 41.990389006478445, 39.516892841884065, 44.012874126434326, 41.50564445768084, 40.046592235565186, 44.345605986458914, 48.88241836002895, 45.900803906576975, 42.715437003544395, 43.67783893857683, 42.49857677732195, 42.30371454783848, 43.803003787994385, 41.99916805539812, 39.88324008669172, 39.93438925061907, 39.74737501144409, 37.86006014687674, 37.904080459049766, 40.73102453776768, 40.20191921506609, 40.2577931540353, 48.1241579736982, 36.426139559064595, 33.783677101135254, 39.57479565484183, 48.61511421203613, 52.176871980939595, 52.05048772266933, 47.085284164973665, 46.88649272918701, 45.85865960802351, 50.59774793897356, 52.438912868499756, 47.561680453164236, 42.18702302660261, 41.81631578717913, 42.60375165939331, 48.153204917907715, 50.186150550842285, 52.08831718989781, 50.877121107918875, 52.989019121442524, 52.232756342206685, 46.118459701538086, 44.024192741939, 46.43209096363613, 44.97900377001081, 48.462785380227224, 48.65913105010986, 50.44443941116333, 53.13741874694824, 56.505558013916016, 57.865650517599924, 57.39420829500471, 60.06193787711007, 60.93897424425398, 60.58853490012032, 59.58240100315639, 57.56686755589077, 70.3282139641898, 67.7459854398455, 60.8166720526559, 63.339604650224956, 56.88053839547293, 62.092590604509624, 58.40403515951974, 72.81225749424526, 62.51627785818917, 79.84960842132568, 13.272064191954476, 0.15753573312291078, 46.211259841918945, 67.35526738848004, 41.215765612465994, 39.751123564583914, 38.33803367614746, 36.08960008621216, 51.377596378326416, 52.936726978846956, 9.557816045624868, 0.40535445883870125, 0.19542548140244825, 0.10656041665268795, 0.08488593862525054, 0.03493135595428092, 0.04615519368754966, 0.06621097893054996, 0.04812669414760811, 0.10698859939085585, 0.14865727882300103, 0.18630875274538994, 0.10410098505339452, 0.1712395484958376, 0.17149299489600317, 0.1796527856162616, 0.19898859092167445, 0.30379643983074595, 0.39945302265030996, 10.733783023697988, 70.39578519548688, 50.00477824892317, 28.786529200417654, 30.310686043330602, 47.657909529549734, 41.6148875100272, 63.73744460514614, 64.21513325827462, 12.28982949256897, 0.8439988227827209, 6.830487855843135, 57.956324509211946, 71.70080280303955, 62.36967086791992, 69.02145235879081, 59.61914307730538, 64.73461532592773, 60.61433356148856, 62.203727040972026, 58.33275359017508, 60.75033760070801, 57.576004437037874, 62.20254584721157, 59.09737505231585, 61.00753211975098, 56.28639098576137, 58.51779106685093, 60.32102230616978, 56.00680242265974, 53.34757743562971, 54.47511373247419, 50.43319375174386, 47.63851363318307, 44.56377942221505, 45.670749051230295, 44.53475679670061, 50.6647424697876, 52.30520520891462, 55.902482169015066, 51.827335902622764, 51.89347233091082, 47.84848819460188, 46.26488256454468, 45.29502521242414, 43.55950764247349, 49.26807812282017, 53.78055790492466, 50.93248782839094, 48.74084881373814, 49.04422106061663, 51.49460751669747, 50.13385146004813, 52.59833581107003, 55.288883277348106, 56.39829172406878, 46.114617347717285, 46.09496784210205, 41.460408210754395, 43.91362953186035, 40.04190567561558, 42.18592521122524, 44.6907890183585, 38.89580031803676, 41.07192053113665, 40.63533394677298, 42.81041540418352, 42.34719637462071, 46.959427969796316, 46.69394077573504, 48.56533036913191, 46.52417196546282, 47.27710655757359, 51.667899063655305, 53.480823040008545, 49.0247209412711, 43.526409898485454, 44.54164593560355, 39.59296866825649, 44.63028063092913, 41.27696187155587, 41.763599804469514, 47.45404938289097, 53.59725052969796, 49.79003374917166, 46.08798837661743, 48.61348833356585, 48.69694314684187, 46.32794441495623, 47.94529744556972, 46.01879126685006, 43.21126740319388, 42.13924026489258, 42.19999531337193, 39.80582673209054, 40.17306334631783, 43.82824659347534, 44.06978334699358, 40.72719260624477, 51.16323055539812, 47.33686106545584, 38.47516679763794, 42.93446854182652, 51.53184291294643, 53.1186968258449, 56.2556208883013, 49.696556159428184, 47.74028737204415, 48.190756457192556, 51.13700457981655, 55.11736004693167, 50.53235844203404, 45.91894565309797, 43.31878730228969, 45.85414327893938, 49.79427215031215, 52.45529324667794, 55.25001852852957, 54.20460646493094, 52.682395117623464, 53.41802869524275, 48.351214681352886, 46.953886781420024, 47.910104819706504, 47.82201555797032, 51.11603839056832, 50.28201137270246, 54.35572978428432, 56.833617210388184, 59.13024697984968, 60.93848787035261, 59.32968807220459, 61.416343280247276, 62.7134816305978, 64.91040475027901, 58.962434087480815, 61.8994584764753, 67.43395573752267, 67.86318070547921, 64.86535957881382, 66.7472791671753, 58.86903640202114, 65.65500150408063, 61.720993995666504, 75.8767396381923, 66.31879070826939, 84.43541949135917, 19.135241644723074, 0.2800126203468868, 49.966076782771516, 75.73132078988212, 48.92725508553641, 48.33161728722708, 53.87545640127999, 55.33214623587472, 58.778042793273926, 66.60832909175328, 11.205984336989266, 0.6673057526350021, 0.3181892532323088, 0.2419267754469599, 0.23598462715744972, 0.13809731975197792, 0.1701939803149019, 0.18702014242964132, 0.17123755360288279], [0.034766302310994694, 0.09092264076960938, 0.0283956506755203, 0.0744495882785746, 0.03184205726055162, 0.029071955010294914, 0.03971086163073778, 0.04243307966472847, 0.1468042946819748, 0.13637698920709745, 3.5071913940565924, 42.05170338494437, 43.566261291503906, 38.50020810535976, 23.441639593669347, 31.153460843222483, 31.514398915427073, 40.40375396183559, 52.12175192151751, 22.07798613820757, 0.011999684003447848, 0.0913538294179099, 7.634017058781215, 62.65553365434919, 56.70739276068551, 61.141500336783274, 55.83833292552403, 61.347896575927734, 53.2522794178554, 57.74279594421387, 54.20709392002651, 55.57323135648455, 52.854310921260286, 56.45889738627842, 54.16440418788365, 56.42433704648699, 51.74040699005127, 52.0544308253697, 53.11078977584839, 54.49514191491263, 52.039290700639995, 51.90534332820347, 46.48379250935146, 47.700967516217915, 39.71951273509434, 40.05744532176426, 42.81721421650478, 49.16385166985648, 51.19565779822213, 51.592326981680735, 49.922598430088584, 50.54464980534145, 45.956181049346924, 41.73304162706648, 39.23573398590088, 40.44631167820522, 40.80521740232195, 47.82327665601458, 47.62666695458548, 48.660583223615376, 45.637477602277485, 45.780596596854075, 46.352158887045725, 51.14642981120518, 51.937152181352886, 50.54720674242292, 49.20287275314331, 45.15711389269148, 41.23695066996983, 38.18984597069876, 38.83003909247262, 39.26992607116699, 42.30141469410488, 38.779178278786794, 35.384389196123394, 38.961933272225515, 37.40363992963518, 39.808606011526926, 39.10225214276995, 38.55285113198416, 38.536001750401084, 37.81229475566319, 37.77753986631121, 40.086259501320974, 43.40360743658883, 45.56972919191633, 48.08600541523525, 45.254131589617046, 42.63210725784302, 39.795185565948486, 41.83254330498831, 44.17227969850813, 44.078406061444966, 44.04961967468262, 43.346013818468364, 36.16082954406738, 36.47940444946289, 36.87125505719866, 40.59600019454956, 41.071274348667686, 41.526058265141074, 37.15458869934082, 36.84903819220406, 37.890781606946675, 37.60065957478115, 40.65313523156302, 37.792207513536724, 39.19062975474766, 48.015279701777864, 31.08563600267683, 28.165002414158412, 34.65707261221749, 42.8965140070234, 51.76231813430786, 51.321274280548096, 49.474488258361816, 46.91658885138375, 43.73605442047119, 46.197717802865164, 49.59367070879255, 50.87930284227644, 44.2586874961853, 39.8732624735151, 39.819118635995046, 42.154543672289165, 44.8955454826355, 51.76880080359322, 50.674480370112825, 49.32787084579468, 52.81911482129778, 50.26431083679199, 45.406693186078755, 42.65889951160976, 40.564806256975444, 43.51633153642927, 43.47783851623535, 45.888634136744905, 46.42705004555838, 49.56424856185913, 48.41796949931553, 52.096943378448486, 50.26788221086775, 54.75478914805821, 55.40826722553798, 60.588805879865376, 53.92220040730068, 57.82165452412197, 56.98264217376709, 52.26695190157209, 60.611040115356445, 60.03804302215576, 57.574291706085205, 58.22165189470564, 59.208567074366975, 68.85291685376848, 59.917776652744834, 70.9951229095459, 5.327195584774017, 1.4594201509441649, 55.62580837522234, 56.77321999413626, 43.328452246529714, 35.924833978925435, 42.129109791346956, 36.41631828035627, 35.24950729097639, 51.1633243560791, 10.868933303015572, 0.567086184663432, 0.07230251348976578, 0.1165319297994886, 0.06465904720659767, 0.1021136034812246, 0.02066327934153378, 0.07515285589865275, 0.04225538152136973, 0.022277889041496173, 0.0255630163342825, 0.06606316686208759, 0.005541490748458142, 0.045748198205339055, 0.04518253070169261, 0.19396483977990492, 0.0286960907147399, 0.11522743265543665, 0.18903342368347303, 5.1055185198783875, 53.462799412863596, 51.18641669409615, 42.93514946528843, 32.86749805722918, 41.1868576322283, 37.26721205030169, 48.70296376092093, 57.22281013216291, 27.068720851625713, 0.056866008056593795, 0.09120633626090628, 5.663372448512486, 61.82837840488979, 61.94900608062744, 65.1818083354405, 59.39109625135149, 64.0712708064488, 55.99108559744698, 62.54671791621617, 57.709316049303325, 56.17257601874215, 55.0080475125994, 59.16948345729283, 55.926526410239084, 57.71943957465035, 52.63468878609793, 55.9442651612418, 55.529686995915, 58.0067823273795, 55.32097700663975, 54.76925877162388, 49.365109716142925, 47.69102464403425, 43.06274618421282, 42.20669337681362, 45.20874943052019, 51.65758098874773, 54.012200423649375, 54.88452591214861, 49.76343951906477, 52.97434452601841, 48.36358594894409, 44.93299279894148, 42.45182234900338, 42.911706243242534, 43.12728452682495, 49.59845106942313, 50.35437338692801, 51.31774459566389, 45.550378458840505, 47.51311949321202, 48.553125858306885, 54.201514516557964, 53.695425101688926, 52.53465904508318, 52.462467261723106, 47.16552543640137, 42.98598248617989, 40.429104464394705, 40.870297704424175, 38.80433075768607, 43.217524256025044, 39.807508196149556, 36.33065046582903, 41.49515962600708, 39.92657947540283, 41.53402090072632, 43.755641392299104, 42.97218336377825, 41.197735037122456, 42.70360769544329, 41.22139712742397, 43.67118256432669, 45.10588482448033, 47.8310238974435, 46.790777819497244, 46.35750552586147, 40.98987967627389, 39.31532212666103, 41.17253392083304, 45.784042903355186, 46.87416662488665, 47.037546566554475, 47.15990434374128, 39.77279847008841, 39.98630271639143, 41.345363412584575, 42.57097005844116, 44.1901330947876, 43.559365204402376, 39.64150530951363, 39.18877458572388, 38.55434152058193, 39.97105489458357, 41.23604045595442, 40.83416707175118, 39.54664502825056, 47.1972404888698, 35.32724373681204, 32.70490326200213, 38.79078524453299, 47.045849663870676, 52.556271416800364, 54.83195236751011, 51.471973759787424, 48.903259481702534, 46.49723727362496, 48.170398235321045, 50.66838332584926, 54.70766993931362, 46.634523255484446, 42.07093947274344, 42.89235551016671, 44.78589596067156, 49.284246580941335, 52.57167904717581, 52.88333354677473, 52.76235498700823, 54.40401629039219, 54.138289383479524, 48.291342054094585, 45.65570967538016, 42.3291414805821, 45.858253138405935, 46.536025592258994, 47.90087413787842, 48.39295598438808, 51.30100638525826, 51.858165059770855, 55.258450167519705, 54.43968486785889, 59.135062081473215, 58.642879486083984, 64.07516179765973, 56.6180910382952, 60.69266060420445, 68.33069719587053, 59.15696280343192, 61.93631172180176, 64.76954392024449, 59.32067625863211, 63.34606647491455, 62.23492445264544, 72.00257696424211, 63.545966148376465, 74.05453981672014, 4.207908970969064, 2.386174027408872, 63.33875696999686, 63.18315206255232, 47.47763156890869, 49.032263210841585, 52.8202543258667, 28.58831099101475, 50.24274015426636, 62.6700553894043, 18.439226695469447, 0.4211169087461063, 0.15099466911384038, 0.19738000152366503, 0.10450797714293003, 0.03384048877550023, 0.0853729299934847, 0.014189333472001766, 0.021209812157654336, 0.09732508685972009, 0.17491891820515904, 0.2215431627950498, 0.2792188972234726, 0.15622731404645102, 0.19068552074687822, 0.2787422942263739, 0.19234700873494148, 0.2215036449155637, 0.3678185801420893, 7.112273786749158, 66.14163943699428, 58.08231619426182, 51.89746407100132, 31.938718455178396, 46.42486136300223, 43.44638054711478, 55.13729790278843, 63.50367246355329, 31.24041407448905, 0.21843605594975607, 0.1678141951560974, 10.99543046951294, 68.79517037527901, 62.96745218549456, 69.34283433641706, 59.54040609087263, 66.91323689052037, 57.03910323551723, 66.58485807691301, 61.43061488015311, 59.26453481401716, 59.509410176958355, 61.851731300354004, 59.50544275556292, 60.47659247262137, 54.041553088596885, 58.3350464957101, 58.06436552320208, 61.13239819662911, 56.87606028148106, 58.15372977937971, 50.69090243748256, 52.254768235342844, 45.368756021772114, 43.94472272055489, 47.71383558000837, 53.3003956930978, 53.76755435126168, 55.76090914862496, 52.47036388942173, 56.265727043151855, 52.46904373168945, 46.63660076686314, 43.15461526598249, 46.335549218314036, 45.96908038003104, 51.70618711199079, 51.64526530674526, 55.17736121586391, 48.26676280157906, 50.99305527550833, 50.7998606136867, 56.70394992828369, 56.46217346191406, 54.91026898792812, 55.109713554382324, 49.14263187135969, 44.73064388547625, 41.608682768685476, 43.34033714021955, 42.092082841055735, 46.14114556993757, 41.891971247536794, 39.50903442927769, 45.489835330418174, 42.30895348957607, 44.84182548522949, 47.247288363320486, 47.609803676605225, 46.00223370960781, 46.142771448407856, 47.24133375712803, 47.36443151746477, 48.38990919930594, 47.853313718523296, 50.50554186957223, 48.04943009785244, 42.927579402923584, 42.007561479296, 43.70598609106881, 46.55814518247332, 48.92584112712315, 49.44459015982491, 50.357628617967876, 45.145656313214985, 44.18501922062465, 46.72882073266165, 48.513920647757395, 49.210738113948274, 48.49255493709019, 41.94396809169224, 41.72413056237357, 39.63411937441145, 41.12180859701974, 43.91667284284319, 45.22174603598458, 41.54299102510725, 50.31150994982038, 44.05564028876168, 37.09201669692993, 41.77232674189976, 49.399864605494905, 57.955407346997944, 56.81888355527605, 55.57761219569615, 51.67047684533255, 48.010085923331125, 50.281695229666575, 56.38367618833269, 57.92130558831351, 50.77189411435808, 44.20434216090611, 44.824805872780935, 48.08519942419869, 50.852211815970286, 55.61518805367606, 53.88807780402047, 54.34122889382498, 57.665959290095735, 57.42244577407837, 50.24475860595703, 49.02684014184134, 45.72476782117571, 49.02738210133144, 49.95967749186924, 52.1416654586792, 50.64703151157924, 56.017672879355295, 54.20536034447806, 58.36440263475691, 55.83773538044521, 62.28123419625418, 60.57448564256941, 67.33390862601144, 60.05625425066267, 62.3089714050293, 62.01433999197823, 63.35961546216692, 65.50164086478097, 69.18210860661098, 63.12961619240897, 67.69241482870919, 63.37228897639683, 78.26777458190918, 63.21312659127371, 81.11095660073417, 6.794311625616891, 1.7488796072346824, 69.99209485735211, 69.02539198739188, 55.45796421595982, 50.97342314038958, 58.476852280753, 50.51473781040737, 55.498788356781006, 71.84409550258091, 22.30627962521144, 0.6781858716692243, 0.2506042341036456, 0.2894940344350678, 0.19012951558189733, 0.2066627134169851, 0.17524753271469048, 0.1952786057123116, 0.129386450030974], [0.06297567646418299, 0.05230921453663281, 0.0316804641458605, 0.05744360759854317, 0.03847780404612422, 0.03647188828991992, 0.009625010757840105, 0.015489554997267467, 0.09644383950425045, 0.02430194373508649, 3.369009963103703, 48.92062302998134, 40.52935307366507, 40.39372771126883, 25.388642958232335, 27.068689584732056, 27.22251922743661, 42.93734162194388, 48.923232078552246, 40.100624901907786, 1.1338552492005485, 0.026539609734235064, 0.348307305680854, 16.26644856589181, 57.94678463254656, 57.83379302706037, 61.1825225012643, 56.88677440370832, 58.6607016154698, 53.96311487470354, 56.639567920139854, 50.81331580025809, 58.27764742715018, 52.40985550199236, 55.95804343904768, 51.77071850640433, 47.597421986716135, 52.786506925310405, 55.61971480505807, 53.08684628350394, 53.905861718314036, 52.047764028821675, 51.191891874585835, 44.5589017868042, 40.21187250954764, 40.00282900674002, 47.90362562452044, 50.337176595415386, 57.57226283209664, 55.61340584073748, 47.828651087624685, 50.581527369362966, 45.69158322470528, 43.62716225215367, 39.93887778690883, 41.13424587249756, 39.65359170096261, 42.05041102000645, 49.83999477113996, 48.03681216921125, 44.62219640186855, 47.14691468647548, 48.82846212387085, 50.019379888262065, 51.278654030391145, 52.11167008536202, 49.9426509312221, 51.30507108143398, 42.60314021791731, 42.45807572773525, 39.01604584285191, 40.241944313049316, 39.16606092453003, 41.09566947392055, 42.55114337376186, 37.59950269971575, 39.725811277117046, 35.446999413626536, 37.788493701389854, 39.67735801424299, 37.264491830553325, 36.22083418709891, 38.55853475843157, 44.765516894204275, 47.10726826531546, 45.99655703135899, 46.71762718473162, 45.671683583940776, 47.62784814834595, 43.457990986960276, 47.393280438014436, 45.75439146586827, 45.6403854233878, 47.54392780576433, 44.09550210407802, 38.175657749176025, 37.24653421129499, 38.631984165736604, 37.694144112723215, 37.934360708509175, 41.58365535736084, 37.43527855191912, 38.52101101194109, 36.67076826095581, 41.132157938820974, 36.39761025565011, 35.51803779602051, 48.59271321977888, 35.8110294342041, 28.254634175981792, 37.210389682224815, 44.17850875854492, 50.994354588644846, 50.56659916469029, 51.44173519951956, 49.04468311582293, 49.202327319553916, 47.21659469604492, 45.86375611168997, 49.69674376079014, 49.46634496961321, 41.11897720609392, 39.828474385397776, 40.912400313786094, 41.547496931893484, 45.897802284785676, 50.63672733306885, 56.332012857709614, 50.581638540540425, 51.39900030408587, 53.51132563182286, 47.884097712380544, 45.352736949920654, 40.49890954153878, 44.288943426949636, 43.544193812779014, 45.704499925885884, 45.04516451699393, 48.799491609845845, 46.95860808236258, 49.579892430986675, 53.745709214891704, 57.609216826302664, 55.183836936950684, 57.25223575319563, 51.273765972682405, 56.843282154628206, 47.380256039755686, 55.90265934807913, 60.68232863289969, 57.48450708389282, 56.16765322004046, 59.4186805997576, 61.83144950866699, 63.08813544682094, 67.88012041364397, 50.9850127356393, 1.2607127449342181, 9.908866831234523, 64.05615152631486, 49.30020659310477, 35.31351409639631, 17.501754896981375, 31.53990227835519, 30.87024532045637, 38.491918904440745, 49.41518538338797, 25.264409167425974, 0.07349707439009633, 0.022634265811315606, 0.05970791966787406, 0.013522893340060753, 0.06587300742311136, 0.0380260354307081, 0.0744400005787611, 0.038679610538695536, 0.013804939143093569, 0.041750721101249964, 0.03798594079645617, 0.019597763927387338, 0.05376243298607213, 0.10128506472600357, 0.029678243012832742, 0.03130497643724084, 0.12410355279488222, 0.043568876039768965, 7.260460189410618, 61.53351075308663, 47.424863474709646, 48.540546144757954, 22.57039976119995, 35.01271268299648, 33.670407567705425, 50.89524548394339, 48.91299043382917, 49.56316464287894, 1.4874360476221358, 0.12671127143715108, 0.29625525591628893, 14.180861643382482, 60.11023480551583, 60.43026188441685, 64.4058404650007, 58.53100654057094, 61.04542759486607, 57.42256736755371, 59.83712196350098, 56.381105354854036, 61.35162775857108, 55.78150360924857, 58.47371169498989, 51.41211155482701, 48.96294103349958, 53.04485831941877, 57.13937963758196, 55.862102712903706, 55.930368764059885, 54.736591815948486, 54.24061550412859, 47.11780868257795, 42.991534096854075, 44.53855051313128, 50.75032343183245, 52.63711370740618, 59.18265724182129, 56.92150150026594, 50.958870138440815, 53.28388329914638, 49.032846859523225, 45.88897112437657, 42.33707979747227, 44.25083255767822, 41.57188163484846, 44.940931115831646, 51.5088061605181, 49.2545291355678, 48.681035246167866, 50.68513890675136, 50.64207744598389, 52.76895924976894, 54.976902212415425, 52.88613714490618, 52.99201379503523, 53.75108017240252, 44.04541254043579, 43.447613852364675, 39.54288605281285, 41.82805129459926, 39.67995664051601, 41.951319285801475, 43.75997706821987, 39.90924719401768, 40.81167227881295, 38.14415461676461, 41.857800006866455, 43.14916787828718, 40.44667298453194, 38.578920773097444, 42.22129501615252, 46.70870222364153, 47.73307514190674, 47.631610597882954, 48.47466679981777, 46.26142236164638, 48.28260122026716, 41.64139836175101, 47.03426701681954, 48.469139507838655, 47.42018733705793, 49.25442143848964, 46.194750922066824, 39.594893319266184, 39.11726025172642, 41.25784737723214, 42.195336546216694, 41.93407385689871, 43.95750045776367, 38.96695681980678, 41.05362245014736, 36.85019506726946, 40.716210978371755, 37.33845887865339, 37.68027203423636, 49.336733273097444, 39.14996542249407, 35.012570244925364, 40.88599715914045, 46.808613845280235, 52.66916227340698, 52.22269882474627, 53.35529688426426, 51.90859855924334, 51.146811962127686, 52.12716804231916, 49.909719944000244, 53.14858797618321, 50.95455183301653, 43.459206921713694, 43.28876066207886, 43.41771922792707, 45.343596594674246, 47.225085394723074, 53.82541200092861, 57.1949200630188, 52.41438920157296, 52.94981391089303, 57.697601386478965, 50.13451501301357, 49.14476496832711, 42.41101210457938, 47.364560059138704, 45.75762585231236, 48.76797110693795, 47.14122411182949, 52.28427028656006, 48.53014121736799, 54.04685456412179, 58.22858967099871, 60.512306213378906, 58.29898534502302, 63.613419260297505, 53.39589173453194, 61.14437689099993, 60.43864836011614, 59.82784611838204, 64.77028737749372, 61.50011076245989, 60.288261549813406, 62.172751971653526, 63.42725617544991, 67.2718403679984, 72.41924653734479, 49.16719027927944, 0.858923173376492, 13.683382783617292, 69.34594018118722, 57.539689677102224, 40.86055632999965, 20.99154496192932, 41.64147826603481, 27.835388558251516, 48.48735768454415, 56.18832411084856, 35.72718899590628, 0.23489400425127574, 0.03206658449822238, 0.01748291276661413, 0.07792261548872505, 0.017333842015692165, 0.04791402091671314, 0.06266074122062751, 0.12115843939994063, 0.1056165269442967, 0.10487058625689574, 0.12457058844821793, 0.10688523136611496, 0.11644351668655872, 0.12450128288141318, 0.1695140339434147, 0.07717860184077706, 0.26040993364793913, 0.10048169961997441, 10.194425633975438, 75.86927727290562, 53.93112536839077, 53.365041732788086, 36.98027924128941, 40.94179466792515, 39.23051936285836, 59.9201112474714, 59.17470155443464, 54.87612206595284, 1.500386187008449, 0.10034673221941505, 0.510400826377528, 21.09789408956255, 64.19103690556118, 60.55346039363316, 64.796357018607, 63.346017837524414, 64.99939727783203, 61.58842236655099, 61.03622123173305, 60.39864758082798, 63.61018834795271, 58.84757341657366, 62.3237293788365, 55.11552919660296, 50.56765876497541, 55.33909790856497, 59.78840119498116, 57.64180040359497, 58.13403163637434, 57.025908606392996, 59.65000697544643, 49.74721547535488, 45.299013478415354, 46.95018686567034, 50.828858920506065, 53.9392443384443, 61.23994936261858, 60.27121761866978, 54.20488439287458, 56.38258184705462, 49.77376454217093, 47.27535213742937, 44.221122060503276, 46.130678108760286, 44.506779875074116, 46.47978687286377, 53.90917253494263, 52.62788649967739, 50.52747733252389, 52.83453982216971, 53.33824947902134, 55.62927552631923, 55.963115624019075, 56.07873364857265, 55.08565889086042, 57.646493911743164, 47.24861894335066, 46.5155040877206, 43.02459362574986, 44.5160140310015, 43.05126428604126, 42.1129343850272, 45.624272550855366, 41.806581360953196, 44.20683309010097, 40.28406776700701, 45.95569467544556, 47.67095824650356, 43.815284729003906, 43.018434047698975, 47.57081733431135, 50.37144858496529, 49.884115832192556, 51.625674860818044, 51.002692426954, 49.304330348968506, 50.88311045510428, 45.153493881225586, 49.83867113930838, 51.73151329585484, 50.05225528989519, 51.96200588771275, 49.50959750584194, 43.636782033102854, 43.05062505177089, 47.149325711386545, 47.764216967991416, 46.304480348314556, 46.651053019932334, 39.366957664489746, 42.779933656964985, 40.18988840920584, 44.021041733878, 39.71611854008266, 38.82299361910139, 50.14454821177891, 47.18969127110073, 39.443248885018484, 44.23697784968785, 49.83104201725551, 54.49687549046108, 54.851779052189414, 54.67860215050833, 54.75062370300293, 53.25654213769095, 53.60935429164341, 52.67477641786848, 56.853555066244944, 53.33816262653896, 47.54092618397304, 46.11696236474173, 45.81467751094273, 46.58555930001395, 50.96675634384155, 57.260490213121685, 62.06418636866978, 55.69991438729422, 54.040653296879356, 58.025559834071565, 50.630164759499685, 51.73229496819632, 44.986900397709434, 50.319469111306326, 49.194851057870046, 51.398579938071116, 49.695281164986746, 54.72754873548235, 49.967087745666504, 56.128378527505056, 60.87329987117222, 64.38869231087821, 59.69777584075928, 64.99740314483643, 58.13079030173165, 60.34807859148298, 55.333508082798545, 64.29649666377476, 65.62656252724784, 66.18152904510498, 62.89184883662632, 67.25460188729423, 67.80988107408795, 72.97321251460484, 70.73643452780587, 60.35410267966134, 0.980129286646843, 11.73128638948713, 77.23765550340924, 61.49688679831368, 49.35162673677717, 28.082968507494243, 44.22882413864136, 40.63343014035906, 54.09841367176601, 65.63107190813336, 43.56120300292969, 0.42050082609057426, 0.1371212742690529, 0.15888995331312927, 0.2300998829305172, 0.23396530694195203, 0.1311077440955809, 0.16252242268196174, 0.2739624764238085], [0.04490670282393694, 0.08570581927363362, 0.06578597173626934, 0.02816981725793864, 0.049154684878885746, 0.042139579342412095, 0.025514165205614905, 0.02713536348060838, 0.028571114742330143, 0.08189606906047889, 11.217447996139526, 56.278692381722585, 41.057072230747764, 39.212224755968364, 54.6005391393389, 68.04962866646903, 27.67220664024353, 40.81733853476388, 48.96388946260725, 53.18401684079851, 6.006265180451529, 0.30885934244309154, 0.25157945177384783, 4.376597336360386, 30.89965009689331, 55.0704562323434, 57.06990112577166, 55.82688576834542, 54.97977876663208, 55.76736749921526, 54.822144985198975, 52.50046348571777, 59.953219413757324, 58.14739997046334, 49.69504145213536, 48.11337436948504, 51.86328935623169, 53.44806923185076, 53.223951612200054, 53.67680392946516, 54.81224032810756, 50.61671304702759, 47.44629519326346, 41.913264002118794, 38.96345145361764, 42.78752108982631, 50.57749394008091, 51.49303374971662, 56.95355354036604, 47.60445008959089, 52.463290623256135, 54.17890507834298, 49.10790824890137, 42.51812553405762, 42.22363655907767, 43.25480134146554, 41.74886614935738, 39.89649377550398, 46.83955069950649, 51.10707174028669, 49.270551681518555, 48.64303207397461, 49.01082454408918, 49.67400230680193, 52.365706648145405, 53.03213964189802, 50.48264408111572, 50.35954284667969, 47.938714027404785, 38.49422918047224, 41.880308696201865, 36.37505292892456, 38.25365127835955, 34.08000040054321, 38.420230865478516, 42.68757472719465, 37.9292642048427, 36.905426297869, 36.65612145832607, 38.91368498120989, 37.7949207850865, 37.71363728387015, 39.90120118004935, 47.8259482383728, 46.182789598192485, 45.02095699310303, 47.87799719401768, 43.15408025469099, 45.79872792107718, 46.97638157435826, 44.66763414655413, 45.69034991945539, 44.77906240735735, 45.97237730026245, 45.76053714752197, 37.811690262385774, 36.7500958442688, 37.06926482064383, 40.75465536117554, 37.94927501678467, 41.825324126652305, 38.14689220700945, 39.41011292593819, 38.25447811399187, 35.1958498273577, 34.20958777836391, 42.600291456495015, 38.54835912159511, 28.218793630599976, 38.05229595729283, 42.59010192326137, 51.67708110809326, 48.06118297576904, 52.0342879976545, 53.11160618918282, 51.15596968787057, 46.91483095714024, 48.08245141165597, 48.35073178155081, 50.28613860266549, 42.89765698569161, 39.649714606148855, 40.69084657941546, 41.41514417103359, 42.97081804275513, 45.373831680842805, 49.65626008169991, 56.64621039799282, 51.142823696136475, 48.58780084337507, 55.66789013998849, 49.95575870786394, 46.78517409733364, 43.811133180345806, 43.659436634608674, 41.71397924423218, 45.18349620274135, 46.07646826335362, 47.38645730699812, 47.47025605610439, 51.97499207087925, 55.42621789659773, 55.072113377707346, 59.34862886156355, 54.64220748628889, 51.06864125388009, 50.34505237851824, 43.3042551449367, 58.51010635920933, 60.12765393938337, 59.29696205684117, 59.39051955086844, 57.01585108893258, 63.899434907095774, 60.0302540915353, 71.57995973314557, 20.403546707970754, 0.9087210755263055, 26.07599697794233, 63.42608887808663, 46.04677513667515, 38.68753501347133, 38.06005014692034, 42.546627044677734, 22.638337509972708, 30.65055022920881, 53.24700573512486, 29.98100791658674, 0.3198325021990708, 0.11050949724657194, 0.043009427309568436, 0.043390149915856976, 0.05766467430761882, 0.04686668515205383, 0.008276267193390854, 0.04990920564159751, 0.03725005599803158, 0.08790410988565002, 0.05611343129671045, 0.017853481096348593, 0.04331710222842438, 0.03266462830028363, 0.062294440876160345, 0.020539024312581335, 0.0534572143639837, 0.16544910706579685, 16.389080796922954, 64.93680790492466, 50.75338411331177, 35.475150040217805, 40.83403158187866, 72.71480206080845, 31.753705297197612, 48.7991372517177, 49.27207681110927, 59.87036909375872, 7.758979541914804, 0.5765475141150611, 0.15134872868657112, 4.375335369791303, 31.810802119118826, 57.11473785127912, 61.459741728646414, 58.11279099328177, 58.45833533150809, 58.4794648034232, 58.95941856929234, 56.47135898045131, 63.123876980372835, 59.72378989628383, 50.10880667822701, 50.11890241077968, 53.90292610440935, 56.00467279979161, 55.54298932211739, 55.80927555901663, 57.0464301109314, 53.34670891080584, 48.427113328661235, 44.36080864497593, 41.950197151729036, 45.07505219323294, 54.86986173902239, 52.4087507384164, 57.76258441380092, 50.69875042779105, 56.31224523271833, 54.28585522515433, 50.851774079459055, 43.63875879560198, 44.368357862745015, 43.92657055173601, 43.70181369781494, 41.54893520900181, 49.9947624206543, 52.78347751072475, 52.752422537122456, 50.87588780266898, 50.72322198322841, 53.1999386378697, 54.512804235730854, 52.67293861934117, 53.43494755881173, 51.88146236964634, 48.721876757485525, 42.86267280578613, 43.99925913129534, 39.550911222185405, 41.13615662711007, 36.04011501584734, 37.62267146791731, 43.29460757119315, 39.675141538892476, 39.52940307344709, 37.31937912532261, 41.30735329219273, 38.442604064941406, 39.36059658867972, 42.021860871996196, 49.72359160014561, 49.46494838169643, 48.08097491945539, 48.65975638798305, 44.57411139351981, 47.076459952763145, 49.453581128801616, 45.95562866755894, 46.855041708265034, 47.74047497340611, 46.46391371318272, 48.12112855911255, 40.82966463906424, 39.216685499463765, 40.47796419688633, 41.32555757250105, 40.43408284868513, 41.47089304242815, 39.7852600642613, 41.24062974112374, 41.53852333341326, 36.89324957983834, 36.20598241261074, 44.78514902932303, 40.584528718675884, 33.917718274252756, 42.11269467217581, 44.61855901990618, 53.90229729243687, 51.13400295802525, 53.527678217206685, 52.272142205919536, 51.85017115729195, 50.275896957942415, 49.660019057137625, 51.07533236912319, 53.27881111417498, 46.79986258915493, 43.59984540939331, 42.062643323625835, 44.371296950748985, 46.33239821025303, 49.910432134355815, 51.65187651770455, 57.640699114118306, 52.23467404501778, 51.57515103476388, 59.52248668670654, 53.919639996119905, 49.2055721282959, 45.9143876348223, 46.01681797845023, 45.14664990561349, 46.38642392839704, 49.56827851704189, 48.40649454934256, 50.60189948763166, 53.115003858293804, 58.555832454136436, 59.28274604252407, 62.09625925336565, 58.30116013118199, 53.297164780753, 56.603333064488, 57.223581382206504, 58.82773630959647, 65.7038264955793, 61.02893257141113, 62.266163553510395, 61.02531255994524, 68.78101689474923, 61.9969208581107, 73.82839679718018, 17.139790228434972, 0.6568277605942318, 30.747498444148473, 72.3497645514352, 50.63550445011684, 49.10212734767369, 39.92005164282662, 43.08846146719796, 23.539555345262798, 38.08676944460188, 63.18681376320975, 39.6726575578962, 1.9242690759045737, 0.22883056104183197, 0.09447889029979706, 0.060170755189444335, 0.04703043261542916, 0.05468467064201832, 0.07862886187753507, 0.018055718458656753, 0.17655562609434128, 0.23154670958008083, 0.20680919555681093, 0.07846010343304702, 0.11812682636082172, 0.12126730355833258, 0.2125519902578422, 0.13522917936955178, 0.1593849988920348, 0.19314333743282727, 21.006382840020315, 79.43903241838727, 54.07186460494995, 51.43135806492397, 70.03879370008195, 84.57908739362443, 37.72661304473877, 54.63844156265259, 58.65595599583217, 66.6918533870152, 7.931252309254237, 1.0232295053345817, 0.42121776619127815, 4.566311819212777, 38.34255000523159, 56.25097254344395, 62.45578684125628, 59.7343442099435, 61.578020913260325, 63.235645702907014, 60.559442792619976, 57.25420209339687, 64.89148480551583, 59.152133805411204, 51.26238134929112, 51.18351582118443, 56.08516073226929, 58.446697098868235, 57.45617233003889, 58.49428531101772, 60.31999397277832, 55.383159909929546, 52.63085338047573, 46.2370411327907, 43.593991552080425, 47.299073287418906, 55.732049805777415, 54.60635825565883, 59.37784603663853, 55.18518488747733, 58.46784046718052, 58.50798715863909, 53.8506999697004, 46.00205653054373, 48.18940503256661, 46.670038972582134, 46.39604023524693, 43.93951504571097, 51.29345716748919, 56.08275318145752, 53.91221932002476, 52.76578739711216, 54.16722863061087, 55.01077120644705, 57.33839341572353, 58.234922954014365, 54.92464133671352, 54.39829444885254, 52.79937498910086, 43.91357742037092, 49.090061800820486, 43.61552401951381, 44.90686757223946, 37.83122859682356, 38.860034465789795, 46.23982388632638, 42.10354389463152, 43.91665547234671, 41.58482265472412, 46.240834849221365, 44.08269657407488, 44.91470514025007, 46.72986991064889, 51.43424504143851, 52.261497565678184, 51.683911187308176, 53.86052819660732, 46.79309504372733, 49.702604566301616, 51.850688798086985, 48.905298777988975, 49.60902622767857, 51.08520923342024, 48.543255942208425, 50.06120456968035, 46.46459811074393, 41.55395875658308, 43.90309258869716, 45.877881799425396, 42.526140281132285, 46.70531497682844, 43.03753464562552, 43.86605174200875, 42.68015405109951, 39.18281997953142, 40.07456220899309, 45.684527329036165, 46.99757358006069, 41.708351203373496, 45.57166426522391, 47.02926083973476, 57.665069920676096, 52.89206395830427, 55.56224972861153, 57.67735433578491, 53.91227143151419, 52.27940654754639, 51.1655547278268, 54.541222367967876, 55.63417400632586, 49.00059332166399, 45.74456671306065, 45.51965005057198, 47.27825648444039, 48.69338914326259, 52.36262512207031, 54.569338253566194, 61.03988293239048, 55.6453640801566, 54.67580550057547, 61.67365591866629, 53.763708523341585, 51.382619925907676, 50.054829597473145, 49.328732422419954, 48.3175437109811, 50.705514499119346, 52.90800312587193, 51.568307059151785, 53.80214595794678, 56.42950998033796, 62.673578126089915, 60.972339493887766, 65.32464940207345, 59.451441356113975, 57.78517300742013, 54.75649840491158, 52.55090740748814, 63.8571412222726, 68.25719915117536, 66.03565161568778, 66.80863176073346, 64.41388647896903, 72.21504592895508, 65.44459615434918, 76.7779209954398, 27.41316737447466, 0.9733795459781374, 31.349618911743164, 76.55482823508126, 59.29207747323172, 55.17243146896362, 50.46693420410156, 59.90779209136963, 31.26327017375401, 47.77643190111433, 70.40035711015973, 53.5413453238351, 2.701002768107823, 0.33094677009752815, 0.1628109086304903, 0.13908982649445534, 0.07735316854502473, 0.17183288665754454, 0.1415565727012498, 0.2665871264679091], [0.03922538339559521, 0.09495813279811825, 0.09291214615638767, 0.02159762884756284, 0.03839703123750431, 0.0606699941147651, 0.08592818876994507, 0.07284422192190375, 0.023293527042759315, 0.05534950264596513, 17.898870502199443, 56.49118219103132, 37.882822445460725, 56.53504269463675, 78.65694318498883, 77.77718312399728, 34.85529082162039, 33.01799603870937, 52.23899235044207, 59.288846560886924, 20.556504351752146, 0.6929885202220508, 0.24812462287289755, 2.617417458977018, 20.652099405016216, 47.35842827388218, 61.40567084721157, 53.92708846500942, 58.56426756722586, 54.58347436359951, 57.416181973048616, 53.61025060926165, 55.11320155007498, 56.073178563799175, 51.775620460510254, 54.27340405327933, 56.17944083895002, 54.11158050809588, 54.73636599949428, 53.28928552355085, 53.02927350997925, 48.77513469968523, 43.23204599108015, 39.2188846043178, 39.9191449029105, 47.2036988394601, 52.468633787972585, 52.928340503147666, 50.240249225071494, 46.71662317003523, 54.4574305670602, 51.47996766226632, 50.308834893362864, 43.5502804347447, 44.11435604095459, 42.48843240737915, 41.71484429495675, 41.19949293136597, 43.29375989096505, 45.80536692483084, 50.35762166976929, 48.762867655072895, 50.17161839348929, 49.227837630680625, 51.15757819584438, 51.831907817295615, 52.66058472224644, 50.278558118002756, 49.38212238039289, 46.14148255756923, 39.32009206499372, 36.53225939614432, 36.247449261801584, 29.76343550000872, 31.973761694771902, 45.61502797263009, 40.424278940473286, 38.68041658401489, 38.63746282032558, 39.97922250202724, 37.62116370882307, 38.338311604091096, 47.000133991241455, 50.83849259785244, 47.79780803407942, 45.62838241032192, 44.96797350474766, 46.220091002328054, 46.53184972490583, 45.35333102090018, 45.3153452192034, 45.21654183523995, 43.33508430208479, 47.95609147208077, 48.7227418082101, 42.91536794389997, 40.62283066340855, 41.07769101006644, 39.01356186185564, 37.58039515359061, 38.58958625793457, 41.02655226843697, 40.78361892700195, 37.23450687953404, 32.23626463753836, 32.638426371983115, 39.13811526979719, 30.900796549660818, 34.34727675574166, 45.6735074860709, 48.6290522984096, 50.87275069100516, 53.251077379499165, 51.12856946672712, 51.54617357254028, 48.39365080424717, 50.1826034954616, 50.014585631234304, 48.38977370943342, 45.35669394901821, 40.94609560285296, 41.88953937802996, 43.232907567705425, 45.14558335712978, 42.34232568740845, 47.21039342880249, 52.48180409840175, 54.821474484034944, 51.39319508416312, 47.72943428584507, 54.19132150922503, 54.91467414583479, 51.47189385550362, 44.71279048919678, 41.70078808920724, 41.7018963268825, 43.14346688134329, 45.62003067561558, 46.03384453909737, 46.34951162338257, 49.44711583001273, 56.572847843170166, 54.61408117839268, 60.71488094329834, 52.621990953172954, 51.40834910529, 45.40644999912807, 39.8611969266619, 64.42726870945522, 56.56409658704485, 60.076522145952495, 57.85046870367867, 59.456930433000835, 61.392066274370464, 66.44581767490932, 60.80127484457833, 3.0449481521333968, 0.1498008274606296, 44.355340412684846, 61.01659951891218, 33.60116529464722, 16.824244737625122, 13.536159140723091, 42.430401052747456, 29.71163320541382, 33.12589461462838, 43.52180324281965, 39.26933200018746, 2.684938967227936, 0.16995814868382045, 0.08882413551743541, 0.04531049562085952, 0.050262712208288055, 0.0655980311068041, 0.044058079432163916, 0.08410974884671824, 0.026811108558571765, 0.05397338613069483, 0.14148405087845667, 0.0299855074180024, 0.022577580995857716, 0.027097134817657725, 0.05296810596649136, 0.030717890975730758, 0.04083292106432574, 0.03172251296096614, 26.12723994255066, 68.44651671818325, 42.17110470363072, 45.26071848188128, 75.73626095908028, 82.74863311222622, 38.08589049748012, 39.64899546759469, 57.32140507016863, 66.17158617292131, 22.858385222298757, 0.6552488367472376, 0.13223555072077683, 2.4696225438799178, 21.737444502966746, 49.836968830653596, 64.98923206329346, 56.12569304874965, 60.545233726501465, 58.394655091421946, 60.12420763288225, 57.42497839246477, 57.249376569475444, 57.951307909829275, 53.25143868582589, 55.86993333271572, 59.98948901040213, 56.12963267735073, 57.40959160668509, 56.34929650170462, 56.9113849231175, 50.095184734889436, 47.59957592827933, 42.1850323677063, 42.73346063068935, 50.41831765856062, 54.142354079655235, 54.27691636766706, 51.56926243645804, 49.70003720692226, 56.32963309969221, 52.499452522822786, 51.67513561248779, 46.209706919533865, 45.7898759160723, 44.398943832942415, 45.77182797023228, 43.804702622549875, 45.061968735286165, 48.07886961528233, 53.371659891945974, 50.64730249132429, 51.506547995976035, 52.6163455418178, 54.62422554833548, 54.22433934892927, 54.73149183818272, 52.285357679639546, 51.12087433678763, 48.9604674748012, 40.34735195977347, 39.67588152204241, 39.029480184827534, 32.84643806729998, 33.86124679020473, 44.34724923542568, 41.89131464276995, 40.408190386635916, 40.04898936407906, 41.95817715781075, 40.18258932658604, 40.005962644304546, 48.663574423108784, 50.96673897334507, 50.63285023825509, 47.73472881317139, 48.44294132505144, 47.837860924857004, 47.87562438419887, 46.53475407191685, 47.169777733939036, 45.54734557015555, 45.126461914607454, 49.689938000270296, 51.14727054323469, 45.344426904405864, 41.2980010168893, 41.96550055912563, 40.49544933864048, 39.230877195085796, 38.922418866838726, 42.37667063304356, 40.62205593926566, 39.668648447309224, 35.13522679465157, 37.06840671811785, 41.04389149802071, 35.348366260528564, 39.73594175066267, 45.571344648088726, 50.3674498966762, 52.80079589571272, 52.41555997303554, 53.00085537774222, 53.0927974155971, 51.43454033987862, 54.511383329119, 50.9514980997358, 50.69313975742885, 47.30639321463448, 43.181946005140034, 45.71841369356428, 45.36741154534476, 45.0554860660008, 44.52188525881086, 48.379709243774414, 54.04854645047869, 55.53316804340908, 53.31360421861921, 51.88999475751604, 55.252363545554026, 55.7956223487854, 53.80472721372332, 47.88768993105207, 42.41177293232509, 44.705335072108674, 44.28859601702009, 49.10313136237008, 48.36070939472744, 49.60866839545113, 52.45436218806675, 58.64118412562779, 57.4073612349374, 61.575060980660574, 54.14134659085955, 55.1174955368042, 50.175293990543906, 53.034502029418945, 63.76198564256941, 61.848687989371165, 62.28106049128941, 63.149251801627024, 62.27819088527134, 64.90261581965855, 69.46220438820976, 60.04083619798933, 1.897842253957476, 0.354009958250182, 52.543597902570454, 67.46540328434536, 38.994819096156526, 24.881433146340505, 13.762098056929451, 47.94932740075247, 28.432032108306885, 40.28475216456822, 54.33633736201695, 53.89665535518101, 6.781512175287519, 0.33867243411285536, 0.12577995498265537, 0.01694322467249419, 0.040509700908192565, 0.032814184203743935, 0.025850733841902444, 0.0583482508414558, 0.1670088012303625, 0.24681236328823225, 0.22278959091220582, 0.17578357537942274, 0.11127345982406821, 0.24204562764082635, 0.23232099946056092, 0.11180112936667033, 0.16361569187470845, 0.2576792101774897, 32.74558843885149, 78.86350618089948, 50.278186389378135, 75.56973348345075, 86.75492967878068, 87.05801704951695, 48.18425294331142, 47.63511943817139, 63.30134786878313, 72.96370737893241, 26.14483278138297, 1.1290917162384306, 0.5249039424317223, 2.5990342625549863, 24.235662358147756, 50.46115330287388, 64.32019696916852, 58.654337065560476, 64.77226066589355, 60.86430890219552, 63.305183274405344, 58.59917531694685, 61.06040096282959, 60.997109821864534, 54.967032296316965, 57.82065398352486, 62.67285551343645, 58.21722936630249, 61.579271589006694, 58.463067054748535, 59.988335609436035, 53.73284462520054, 50.95140082495553, 44.076919146946494, 45.35463728223528, 52.17549623761858, 56.5732056753976, 55.33283410753523, 52.73614985602242, 53.638290064675466, 57.750980922154014, 54.46495546613421, 54.54921279634748, 49.341819354466026, 51.01025206702096, 47.15500586373465, 46.985737323760986, 46.40435028076172, 48.56229053224836, 49.874631541115896, 54.34029088701521, 53.07589939662388, 54.61270196097237, 55.258946963718955, 56.18847697121756, 57.29809386389596, 56.81940119607108, 56.686846937452046, 54.17291225705828, 50.36846085957119, 44.808144092559814, 42.680744647979736, 41.20158086504255, 34.832827295575825, 37.260343755994526, 47.439399106161936, 43.80597414289202, 42.817877769470215, 44.47380372456142, 46.98652247020176, 43.75676352637154, 42.993959018162315, 51.77872977937971, 55.19308498927525, 53.7925956589835, 50.47625173841204, 50.8785593850272, 49.91926676886422, 51.21237516403198, 48.74108157839094, 48.07957138334002, 50.746453285217285, 48.43551370075771, 54.0150283404759, 51.51700503485543, 47.4197496005467, 44.44889790671212, 46.14103092466082, 44.008156299591064, 40.24930245535714, 40.887286049979075, 44.16531760351998, 40.779887744358604, 41.82695695332119, 38.12863234111241, 38.19074576241629, 48.93518645422799, 43.30962610244751, 42.91597938537598, 48.76623405729021, 53.41919251850673, 55.90282610484532, 54.45273705891201, 56.647134508405415, 55.82607977730887, 53.47402422768729, 57.313015120370046, 53.43008381979806, 54.02735791887556, 50.39667749404907, 45.53456783294678, 48.26249313354492, 48.129459449223106, 49.44769947869437, 47.39539269038609, 51.056454113551546, 57.28600399834769, 59.62691811152867, 56.246688979012625, 53.83935008730207, 57.20739555358887, 58.5630099432809, 55.58329929624285, 49.77829476765224, 45.016187054770334, 44.86808272770473, 45.91980028152466, 50.63486174174717, 49.66511903490339, 50.667466163635254, 54.94598272868565, 63.00281851632254, 59.97554397583008, 64.19081456320626, 56.213966437748496, 57.58929634094238, 52.412860597882954, 48.99583033152989, 66.33099174499512, 64.12221499851772, 65.96298735482353, 64.96444089072091, 66.95343916756767, 69.00182369777134, 71.03760419573102, 70.05609471457345, 4.6335460628781995, 0.22548082364456995, 56.414411544799805, 72.69225515638078, 49.128916127341135, 28.37612169129508, 22.289975677217754, 65.64755303519112, 40.67383391516549, 49.7475003514971, 62.09602301461356, 64.30375753130231, 9.354627268654959, 0.44391606535230366, 0.19261631928384304, 0.14826311783066817, 0.23293040533150944, 0.1732850737337555, 0.12383116169699601, 0.17019913718104362], [0.048692717882139344, 0.03988751143749271, 0.025642784911074808, 0.06898250271167074, 0.05540006707555481, 0.0015251057359689313, 0.07488021374280963, 0.042972182522394826, 0.021348195982032588, 0.31058569837893757, 33.17600849696568, 57.74975456510271, 35.66984551293509, 48.37616218839373, 75.61984389168876, 77.30933312007359, 32.71011788504464, 26.35823106765747, 56.881775174822124, 57.54801361901419, 53.26842703138079, 0.9337403987135205, 0.1480679711593049, 1.8544985226222446, 20.01377534866333, 42.39136954716274, 56.3277188709804, 58.10195875167847, 55.54729373114449, 56.31205415725708, 51.753497396196636, 53.65656730106899, 52.30523647580828, 48.97308192934309, 55.42966420309884, 55.737587520054404, 55.664065156664165, 56.08275318145752, 53.06478575297764, 52.20903866631644, 47.066847120012554, 43.05365099225725, 39.47401898247855, 39.761184556143625, 42.46059097562517, 48.25849791935512, 51.37521314620972, 53.98222589492798, 47.778999260493684, 49.170872824532644, 53.92221430369786, 52.584397724696565, 51.27816765648978, 43.347618852342876, 42.946711267743794, 44.01255450929914, 43.845210620335166, 42.88067558833531, 41.31104973384312, 40.81066131591797, 42.618652071271626, 46.76544121333531, 49.56432499204363, 50.301528862544465, 50.55989762714931, 52.045148032052175, 50.44167750222342, 50.55483586447579, 50.604609285082134, 52.313070569719585, 45.00788048335484, 36.21216630935669, 35.33606447492327, 34.09193393162319, 36.80227334158761, 38.13875239236014, 41.001483167920796, 43.33298594611031, 41.01170744214739, 40.492982728140696, 40.92009891782488, 45.38542127609253, 50.559779507773264, 48.9088180405753, 47.94206305912563, 45.46194526127407, 48.397486209869385, 49.808842522757395, 45.553946358816965, 42.705198832920615, 45.80783006123134, 47.12578174046108, 48.43618420192173, 45.32415900911604, 49.13803563799177, 47.422643525259836, 41.70677743639265, 38.055311475481304, 40.88494103295462, 41.20013216563633, 41.72295979091099, 40.773123673030305, 38.55337572097778, 33.39315012523106, 35.62961891719273, 35.060394695826936, 38.4187022617885, 34.22945615223476, 37.51566573551723, 49.60063975197928, 50.66260589872088, 52.81689139774868, 52.16746064594814, 53.45999928883144, 51.98509475163051, 48.30833387374878, 49.58445392336164, 44.83186524254935, 42.42687831606184, 39.62150839396885, 42.11856589998518, 42.62809467315674, 43.191326073237825, 40.768631662641255, 43.4007100377764, 48.223743030003135, 52.090151514325825, 52.939652170453755, 50.472398962293354, 48.93520729882376, 52.286118507385254, 55.47562306267874, 52.76215696334839, 47.64838007518223, 43.89212833132063, 42.71610403060913, 44.07260084152222, 45.59149094990322, 46.26841572352818, 46.94636535644531, 49.89747721808297, 54.41951772144863, 57.25200646264212, 57.85513094493321, 52.46056692940848, 52.87848717825753, 41.72120884486607, 36.361542156764436, 64.52668353489467, 60.19829627445766, 59.94173404148647, 58.554838861737935, 61.20418003627232, 60.70359706878662, 73.03954696655273, 19.70093444415501, 0.6269186969314302, 4.694279398236956, 51.03639119012015, 42.42578050068447, 25.736799819128855, 16.256354570388794, 39.15067761284964, 45.815917764391216, 39.5293995993478, 32.554169041769846, 46.107551029750276, 50.458662373679026, 7.105940937995911, 0.18986221349665097, 0.06360083791826453, 0.027552726977903928, 0.0322997189526047, 0.08130797597446612, 0.04058341695261853, 0.039752326905727386, 0.14295801892876625, 0.06812058681888239, 0.047187503294220993, 0.0915680429232972, 0.0427991968047406, 0.01953293669170567, 0.05554080202377268, 0.04014590096526912, 0.021913062814357023, 0.4489560606224196, 45.05639280591692, 63.35960851396833, 44.36608580180577, 56.28399385724749, 81.7109682900565, 81.14109788622174, 38.96218340737479, 31.543737683977398, 63.58796106066023, 62.49172987256731, 59.536945887974326, 1.1903914383479526, 0.13108513530875954, 1.9246870534760612, 19.3232581615448, 43.6989232472011, 59.273859296526226, 62.01074777330671, 57.989741870335166, 58.892854826790945, 54.82587616784232, 55.64640283584595, 53.35859033039638, 54.078625202178955, 57.912033217293875, 59.40209524972098, 57.19358948298863, 56.406556606292725, 55.55908482415335, 53.5512569291251, 49.68129096712385, 45.42714173453194, 41.58765751974923, 42.41873502731323, 46.167663369859966, 51.58624035971505, 53.53754118510655, 54.931203910282676, 50.46423135484968, 51.95112500871931, 56.67415952682495, 56.46298292704991, 54.616811820438926, 45.84399543489729, 45.804418495723176, 46.864671911512104, 46.59133325304304, 44.6308399609157, 44.6050169808524, 43.78921856198992, 43.28812837600708, 49.23729065486363, 51.92347812652588, 50.46338714872088, 52.26858125414167, 53.13033158438546, 53.80177422932216, 52.21871403285435, 51.35125575746809, 52.444391523088726, 46.02932473591396, 38.77883434295654, 37.094170638493125, 35.50049706867763, 38.723877566201345, 40.02961083820888, 42.18756151199341, 41.771086488451274, 41.470027991703574, 43.653023447309224, 41.44717189243862, 46.46634905678885, 51.867802211216514, 50.852972643715994, 47.61131838389805, 46.85440247399466, 48.93452984946114, 51.91002641405378, 46.52675322123936, 41.140957832336426, 47.16691855021885, 48.9752984046936, 48.862466607775005, 48.57190683909825, 49.51314456122262, 49.819525378090994, 41.98255491256714, 41.800001416887554, 41.91021374293736, 42.51025322505406, 42.08167443956648, 39.88750628062657, 39.72019713265555, 35.103278977530344, 36.98150559834072, 38.354202134268625, 39.2646141733442, 36.52900069100516, 40.56900644302368, 51.594067505427766, 52.982682364327566, 54.086719853537424, 54.06448561804635, 54.703705992017476, 52.07499401909964, 48.92698063169207, 51.99439491544451, 47.09219067437308, 43.14762537819998, 40.82762534277779, 45.450192383357454, 45.18391309465681, 45.62304966790335, 44.79673515047346, 45.23347806930542, 50.23517009190151, 53.223798751831055, 54.586740016937256, 52.10009091241019, 50.26451233455113, 55.81234666279384, 55.691548756190706, 54.95030798230852, 49.00517565863473, 45.74082858221871, 44.640362467084614, 46.851241043635774, 47.357083797454834, 48.94787733895438, 49.520030226026265, 50.055934361049104, 56.50324426378523, 59.01080744607108, 62.182673999241416, 54.65820918764387, 55.67658928462437, 46.17129727772304, 45.586769648960654, 64.72554792676652, 63.58692577907017, 63.604706219264436, 61.55887862614223, 63.95681313105992, 65.4598891394479, 69.34751742226737, 14.705120597566877, 0.5674454825265067, 6.436819425651005, 58.49559852055141, 45.68314116341727, 29.83004093170166, 18.387511253356934, 35.16417646408081, 64.0343828201294, 40.228489126477925, 42.869329180036274, 56.29524646486555, 58.924483026777, 16.4976863520486, 0.1957423301147563, 0.006831107619551143, 0.07469580149544136, 0.050866801757365465, 0.015524591152955378, 0.05059262950505529, 0.054702543254409514, 0.27147298572318895, 0.1619116190288748, 0.11933795708630766, 0.13724001789731638, 0.0956555310902851, 0.11225140520504542, 0.13299247010477952, 0.1524704284965992, 0.10146273912063666, 0.7059038643326078, 51.432945728302, 75.29284082140241, 49.91210317611694, 62.56369931357247, 84.0062153679984, 84.29448223114014, 46.80099514552525, 38.20178644997733, 67.2802963256836, 67.01821027483258, 62.24098328181675, 1.2817466791187013, 0.3870299964078835, 2.716507239001138, 22.96321964263916, 45.52790798459734, 63.65604645865304, 62.6468414579119, 59.91547679901123, 61.86459936414446, 59.01210675920759, 56.894664083208355, 58.35162489754813, 56.39090231486729, 62.075372968401226, 61.00029904501778, 61.14668369293213, 59.69305106571743, 58.769517353602815, 56.20471838542393, 52.084294182913645, 47.741569314684185, 43.9501770564488, 43.80293083190918, 48.37282705307007, 52.673418045043945, 56.373875754220144, 55.94008581978934, 53.329915114811485, 55.57184171676636, 58.38801956176758, 60.01350893293108, 57.345376355307444, 49.778426783425466, 47.358098234449116, 49.958701269967214, 49.628908497946604, 47.56807974406651, 47.09022086007254, 46.388088021959575, 45.22989279883248, 50.20425408227103, 55.30873428072248, 54.798871994018555, 54.30567148753575, 55.48736899239676, 56.67111621584211, 55.796216419764924, 55.266305106026785, 55.30780322211129, 48.23986632483346, 41.478501319885254, 40.80967467171805, 38.08549445016043, 41.68515811647688, 41.909671783447266, 44.81245197568621, 47.06394624710083, 43.946268694741384, 47.549830300467356, 44.65695823941912, 49.224870749882285, 55.025668144226074, 52.973601068769185, 52.685782364436555, 51.72635773250035, 51.60352400371006, 54.770856857299805, 48.705086435590474, 42.34639038358416, 50.248243127550396, 51.58119944163731, 51.791820185525076, 51.820957456316265, 50.678100381578716, 50.91523545128958, 43.88144547598702, 43.46105514253889, 44.8230618749346, 44.97803797040667, 44.350744179316926, 44.039499623434885, 42.7834529195513, 37.02928141185215, 40.707550048828125, 42.46774067197527, 45.32842172895159, 42.255997794015066, 42.446253367832725, 55.626857553209575, 53.06153399603707, 58.00940179824829, 59.35912758963448, 58.59749385288784, 56.964132172720774, 52.23393406186785, 55.47293063572475, 50.49527938025338, 48.27732058933803, 44.49901178904942, 48.64600590297154, 45.92182568141392, 48.11591741016933, 46.80202347891671, 47.85340404510498, 54.22080271584647, 55.09532730919974, 57.10474634170532, 55.26631900242397, 53.57254620960781, 57.83824334825788, 59.8169652393886, 58.571792466299875, 52.26793507167271, 48.419737815856934, 47.41376025336129, 50.23721286228725, 50.187804222106934, 50.81304482051304, 51.42144993373326, 54.29070159367153, 58.442152976989746, 61.410187176295686, 64.17168617248535, 57.303030558994834, 58.87030792236328, 45.79829018456595, 40.9819587298802, 71.30321993146623, 65.69441863468715, 67.20268494742257, 66.05732999529157, 70.26597894941057, 66.8451236997332, 72.85266126905168, 25.811550276620046, 0.49334137035267694, 5.386720367840358, 64.93141610281808, 53.944757734026226, 39.59958335331508, 27.05581978389195, 48.34695543561663, 66.50867802756173, 50.05980103356497, 48.83611903871809, 62.468175479343955, 73.33472033909389, 22.620317356927053, 0.32794091424771715, 0.28804120953593937, 0.17119198319103035, 0.14281437306531838, 0.13146807333188398, 0.10774190896855933, 0.13130978468273366], [0.12758278181510313, 0.01901458004223449, 0.019717069043378745, 0.023457288076835017, 0.043570338282734156, 0.04617618077567645, 0.05931429471820593, 0.02220518740692309, 0.12021416292658874, 0.9930396910224641, 40.40188489641462, 56.2219603402274, 36.21702657427107, 26.14517150606428, 79.78808907100132, 52.86712339946202, 23.60548506464277, 25.822266135896953, 61.3835060937064, 48.1712771824428, 64.05055127825055, 13.419459802763802, 0.5350692655358995, 0.4805983198540551, 14.69454196521214, 35.98444952283587, 52.802241121019634, 58.67716189793178, 56.03801373073033, 51.12928513118199, 49.45644726072039, 51.947168009621755, 52.94334166390555, 57.15765339987618, 51.459143911089214, 55.343516962868826, 51.706736019679475, 52.7329397882734, 49.90618331091744, 44.808442865099224, 41.69760581425258, 39.8690379687718, 40.117953709193635, 41.54802846908569, 47.14785269328526, 51.26972559520176, 54.041733741760254, 47.81796128409249, 41.81307445253645, 50.95674746377127, 51.16129895618984, 54.058378151484895, 49.3668988772801, 44.642863818577354, 40.7228604044233, 45.39145578656878, 44.440104961395264, 43.71003341674805, 43.688712869371685, 42.96978276116507, 38.64975070953369, 42.36182928085327, 43.6768661907741, 48.25247383117676, 48.47428117479597, 53.34885243007115, 50.431244782039094, 52.3201334135873, 49.19289166586739, 51.419563497815815, 47.776987757001606, 47.829234736306326, 39.34989288875035, 33.85987104688372, 30.92282928739275, 37.727954047066824, 36.2977785382952, 38.19439704077584, 40.543885231018066, 43.13445159367153, 45.019358907427105, 49.47008310045515, 50.00162376676287, 51.75671788624355, 45.157746178763254, 45.75540937696184, 52.84182848249163, 51.920507771628245, 42.57168224879673, 35.772126470293315, 43.99667092732021, 51.86214985166277, 48.10560628346035, 44.44869293485369, 47.322596413748606, 52.39905105318342, 47.98268570218767, 44.361968994140625, 39.464892523629324, 42.81684596197945, 43.02673019681658, 38.13642821993147, 36.07836137499128, 35.22416026251656, 35.429066113063264, 39.640984194619314, 37.13663108008248, 39.03215871538435, 46.29791777474539, 51.09688915525164, 49.05186060496739, 52.5938264301845, 50.12481880187988, 50.89950472967965, 49.89954778126308, 49.75322914123535, 44.24778577259609, 38.159517083849224, 38.25343935830252, 40.36902339117867, 43.28476892198835, 43.904464857918875, 43.93227849687849, 43.75185809816633, 41.16701010295323, 48.02817208426339, 53.09235967908587, 51.79378999982561, 51.34046173095703, 52.44183111190796, 50.422500474112375, 54.36251817430769, 52.58060053416661, 52.73230055400303, 42.479003701891216, 44.109078884124756, 41.791163308279856, 46.30017941338675, 44.56301859446934, 49.94676079068865, 49.563001360212056, 55.23595190048218, 52.792294774736675, 60.74151338849749, 55.71094812665667, 57.26014975139073, 36.73454924992153, 36.20716708047049, 58.515984535217285, 59.55114105769566, 55.636453015463694, 60.15636389596121, 54.78668137959072, 67.01138019561768, 36.46070337295532, 0.2875544827963625, 0.31661885178514887, 13.1888074023383, 58.90652193341936, 50.67609235218593, 30.679955005645752, 15.417105981281825, 39.109801360539024, 34.09507104328701, 35.743100370679585, 23.90726443699428, 41.6527030808585, 47.072808674403596, 22.508359295981272, 0.22163214587739535, 0.05909526361418622, 0.05831566080451012, 0.06413793231227569, 0.06235563116414206, 0.059724374142076285, 0.0510564489024026, 0.08871124764638287, 0.04078076886279242, 0.040799482858606746, 0.02463529950806073, 0.06367633850978953, 0.07148109935224056, 0.0429308292056833, 0.04633554829550641, 0.0674942040017673, 1.5695735258715493, 52.15217808314732, 62.97265638623919, 46.67705317905971, 35.37909466879708, 86.98073918478829, 59.922237396240234, 29.612482411520823, 29.691782202039445, 69.7734489440918, 50.72834627968924, 69.86697169712612, 15.670494624546595, 0.5495290639145034, 0.7893433698586055, 13.599536265645709, 37.33792039326259, 57.01327330725533, 60.09137739453997, 58.26543944222586, 52.719449860709055, 51.55487619127546, 56.19074208395821, 55.4013363974435, 58.39664922441755, 53.811567715236116, 56.94644553320748, 52.97899981907436, 54.54451928819929, 50.98195552825928, 47.127098424094065, 45.24063471385411, 43.014292921338765, 41.98214149475098, 44.27427577972412, 50.95301628112793, 54.159196513039724, 56.515639850071494, 52.086531502859934, 46.165947164808, 53.08160734176636, 53.885948181152344, 55.65540075302124, 50.266138213021414, 45.698642594473704, 44.4144035748073, 45.76709624699184, 45.22779444285801, 47.5894524029323, 46.724742140088765, 45.76491798673357, 41.76570510864258, 43.07062891551426, 46.613598755427766, 51.20463834490095, 51.85679279054914, 54.75985091073172, 54.51669175284249, 54.64261743000576, 52.27785015106201, 53.92976004736764, 52.01819249561855, 49.78893593379429, 40.71004097802298, 35.829202447618755, 34.16504635129656, 37.98082678658621, 38.721039227076936, 40.45856482642037, 41.5617025239127, 44.96964454650879, 46.80977766854422, 52.15323073523385, 51.139394760131836, 53.96327815737043, 45.19040271214077, 46.730359758649556, 52.59914180210659, 50.65148878097534, 40.20728669847761, 35.54722717830113, 44.655752726963584, 52.453900132860454, 48.7126738684518, 46.50608580453055, 48.49419123785836, 53.61953687667847, 46.62729018075125, 47.06311246326992, 39.351178305489675, 44.44873114994594, 41.98999990735735, 39.63002341134207, 37.709708077566965, 37.93437460490635, 37.35402284349714, 42.201020172664094, 38.0772191456386, 41.47276210784912, 48.472391264779226, 52.68572677884783, 51.772198472704204, 53.87822873251778, 52.854998792920796, 52.78301892961775, 50.595270906175884, 50.926693030766074, 46.80455609730312, 40.82736131123134, 40.65496260779244, 44.14410822732108, 46.117222922188894, 47.05188764844622, 45.2152772630964, 45.29698460442679, 44.06533302579607, 51.16187913077218, 52.78347403662545, 55.13480349949428, 53.325277192252024, 52.63391406195504, 52.59066847392491, 56.91797528948103, 54.88037436349051, 55.582309177943635, 45.40792301722935, 46.253209590911865, 44.699085167476106, 49.20286580494472, 46.21410165514265, 53.32395356042044, 51.6798221724374, 58.09437131881714, 55.474546091897146, 62.688600131443565, 58.36776556287493, 59.34253529139927, 42.680657795497346, 39.865688937050955, 59.899231910705566, 62.7943308694022, 58.25743859154837, 64.50909764426095, 57.87436008453369, 68.12307807377407, 32.248983315059114, 0.45539769210985726, 0.34148987435868805, 17.78144073486328, 65.93535436902727, 54.251242773873464, 35.02155079160418, 13.059086271694728, 39.98896040235247, 47.285635471343994, 36.09128849846976, 23.501137018203735, 57.997537749154226, 56.77735764639718, 35.95080634525844, 0.08819457715643303, 0.03297107167808073, 0.038583122859043736, 0.03460939448060734, 0.018434982214655195, 0.05473904165306261, 0.05409511870571545, 0.18904658726283483, 0.15001073905399867, 0.11811109791908946, 0.15550075231918267, 0.19221759853618486, 0.1484101563692093, 0.2414496567632471, 0.15437977175627435, 0.2871676906943321, 1.9606678656169345, 59.777951104300364, 72.12731797354562, 50.94643633706229, 35.10398421968733, 91.73352936335972, 62.31953961508614, 35.57794516427176, 38.986922468457905, 75.70481341225761, 54.86465059007917, 75.13138553074428, 16.072597299303325, 0.7554987488048417, 2.198366607938494, 15.591861861092703, 43.162949630192344, 57.42023277282715, 62.97347627367292, 61.17956256866455, 54.82641812733242, 55.482710225241526, 59.18631894247872, 58.83009869711739, 61.750912938799175, 57.31290394919259, 60.65193721226284, 55.45138079779488, 56.20877613340105, 54.42877967017037, 50.96642630440848, 48.39803511755807, 44.910018580300466, 43.97540249143328, 47.13178498404366, 51.211878367832725, 56.60246453966413, 59.29676750728062, 50.589111328125, 47.59182173865182, 54.69144589560372, 57.633674485342844, 57.827900954655235, 52.665417194366455, 49.735608509608674, 46.298195702689036, 48.693569796425955, 48.889436040605815, 48.430750710623606, 49.52215984889439, 47.68024451392037, 43.850487777165, 44.96234198978969, 48.2554372378758, 53.66785117558071, 54.55719975062779, 58.21026727131435, 56.155285426548545, 56.960248129708425, 54.081727572849815, 55.27684552328927, 53.993471554347444, 52.03254747390747, 43.72914791107178, 37.978658948625835, 37.03126164845058, 41.777614321027485, 42.50365243639265, 44.254212856292725, 46.052583830697195, 47.095737729753765, 49.7740980557033, 54.754830837249756, 54.50897577830723, 56.127596855163574, 50.74726275035313, 51.54255356107439, 54.933521134512766, 53.3784031186785, 42.53525284358433, 36.876146589006694, 44.58041688374111, 52.6356372152056, 50.96187176023211, 48.25180333001273, 51.78316273008074, 56.73997981207711, 50.13347625732422, 48.481934615543906, 42.49586003167288, 45.11915935788836, 43.52977977480207, 40.7505316053118, 40.581572260175435, 39.87140730449131, 39.06181015287127, 46.66770090375628, 47.25533437728882, 48.54288073948452, 52.27161066872733, 56.316337721688406, 55.11890254701887, 58.58109610421317, 53.85069302150181, 56.08528232574463, 54.38358858653477, 55.71571806498936, 48.71568938664028, 42.67899717603411, 44.50064461571829, 47.35021897724697, 48.17228119713919, 50.246106556483674, 49.490000111716135, 47.304673535483225, 45.54188428606306, 53.360400336129324, 56.290337562561035, 58.06954887935093, 55.66010468346732, 54.82064764840262, 54.43803467069353, 59.037141118730815, 57.2869176864624, 58.445634024483816, 48.31731789452689, 48.248579365866526, 48.4109275000436, 52.87196976797921, 50.29326745441982, 56.45950187955584, 55.97473996026175, 60.4674972806658, 57.79830162865775, 67.21916607448033, 60.00335761478969, 61.61201844896589, 44.350494044167654, 41.0655003956386, 60.38281263623919, 67.19754328046525, 62.27967085157122, 65.50817911965507, 61.7834860937936, 67.78020531790597, 44.389073916843955, 1.8657437477793013, 0.40503777297479765, 17.528472457613262, 72.90342480795724, 58.902561460222515, 48.38423946925572, 25.485912527356827, 48.413119656699045, 49.67554828098842, 48.13550785609654, 32.80999823978969, 57.74236168180193, 64.97935172489711, 45.35401541846139, 0.253052822713341, 0.1324802983020033, 0.14111034093158586, 0.12478942956243243, 0.12491844621087823, 0.1583463924803904, 0.12386278142886502], [0.01632419547864369, 0.03723425631012235, 0.07014269581330673, 0.02126504830084741, 0.12491537923259394, 0.09579068848064967, 0.05597628579874124, 0.11007022046084915, 0.026152171327599456, 2.4451342693396976, 53.24483094896589, 49.17191852842058, 38.41183049338204, 32.65794733592442, 47.63276399884905, 35.465769972120015, 28.133269991193497, 21.026544775281632, 59.07172230311802, 58.44953196389334, 58.52927643912179, 44.43803439821516, 0.12956252986831324, 0.038643543009779284, 5.522125559193747, 28.47607500212533, 49.47477660860334, 55.52669579642159, 49.431961808885845, 49.26608051572527, 50.53104175840105, 52.61260741097586, 51.1782351902553, 53.0180139541626, 51.63711854389736, 48.25709090914045, 47.510621615818565, 46.507402488163535, 42.531577246529714, 41.251722540174214, 40.524760314396445, 40.60463680539812, 41.68085023335048, 43.448874950408936, 48.383079120091026, 53.89590147563389, 53.82209423610142, 46.62231527056013, 52.17574289866856, 51.647766658238, 51.5098796572004, 54.24718155179705, 49.294863428388325, 42.918824672698975, 41.81661108561924, 43.95629147120884, 44.610770089285715, 42.7195086479187, 45.824828829084126, 44.75130087988717, 38.86858769825527, 38.609440735408235, 39.9392842565264, 44.122276987348286, 48.179410048893516, 50.54580668040684, 49.45317118508475, 50.64679527282715, 50.895422663007466, 51.789468220302034, 49.77153764452253, 44.68204818453108, 44.358025891440256, 40.18093565532139, 36.79746866226196, 37.25439609800066, 38.23444645745413, 35.20721360615322, 38.144974504198345, 43.85827670778547, 44.78380455289568, 50.38695349012102, 49.48504952022007, 50.19841064725603, 43.0473871912275, 45.61139753886631, 56.74600737435477, 51.73954193932669, 39.5772831099374, 37.42152806690761, 41.7108108656747, 55.10290779386248, 52.95039061137608, 45.34711585726057, 45.37633998053414, 52.56457798821585, 50.67436572483608, 48.75806644984654, 45.68586833136422, 42.045133863176616, 39.50239542552403, 39.13594395773751, 39.0055262701852, 37.19908148901803, 37.16586562565395, 38.03393881661551, 33.981033733912874, 46.762429169246126, 47.15273380279541, 47.34984030042376, 51.06618159157889, 48.399132932935444, 49.00820507322039, 48.16144895553589, 48.907991204942974, 45.759595666612896, 39.35055991581508, 38.040925230298726, 36.817225864955354, 43.95408889225551, 44.43558863231114, 41.681406089237754, 46.3023750441415, 42.05179371152605, 41.096958364759175, 46.45565230505807, 52.27814544950213, 52.77848523003714, 53.88212667192732, 54.15011174338204, 50.78962591716221, 55.01132706233433, 55.21215779440743, 54.01528542382376, 47.81677661623274, 44.07557119641985, 43.47983612333025, 43.473332609449116, 43.47960683277675, 47.8245655468532, 48.13080392565046, 52.52742249625069, 54.537543296813965, 56.37737764630999, 55.16561528614589, 61.32052067347935, 49.58180318559919, 34.224939823150635, 50.66476331438337, 60.268709318978445, 58.39100728716169, 61.67424651554653, 55.187859943934846, 52.666584491729736, 5.797927354063306, 0.06316746438720397, 0.07388941012322903, 28.89673284121922, 61.87905856541225, 52.82950585229056, 38.0662270954677, 12.958214930125646, 27.767925024032593, 32.283088547842844, 47.0430634362357, 27.781505278178624, 29.599711622510636, 58.292822292872835, 37.84256458282471, 0.7451079892260688, 0.07643781123416764, 0.03534843785954373, 0.05471593075032745, 0.0567621854133904, 0.047511649650654623, 0.09586920176765748, 0.08330138972295181, 0.10736853150384766, 0.02085796800175948, 0.052091004459985664, 0.010631561478865998, 0.06455042053546224, 0.025683396928278462, 0.11596981781933989, 0.07137480684156929, 3.7817373020308356, 64.58227607182094, 57.65111098970686, 43.145287309374126, 36.85550001689366, 56.52208430426461, 39.08056334086827, 40.94692243848528, 26.29442228589739, 65.61600821358817, 63.393877029418945, 64.77378232138497, 49.9036020551409, 0.3520809646163668, 0.17497237319392817, 5.139326282909938, 28.393801382609777, 49.053000109536306, 57.65162168230329, 52.04125009264265, 51.26655721664429, 54.02499205725533, 54.452073505946565, 55.66952296665737, 55.806395530700684, 55.44449860709054, 51.54664952414376, 48.604723181043354, 48.66086115155901, 44.69262681688581, 43.58356230599539, 43.91608919416155, 43.01405668258667, 43.31956550053188, 45.56746755327497, 52.46134512765067, 53.93326193945748, 57.50387518746512, 48.34171996797834, 53.477804047720774, 53.26643289838518, 54.82131814956665, 56.22668511526925, 52.23800918034145, 46.06656360626221, 43.936228547777446, 44.76178571156093, 47.6949052129473, 46.66111748559134, 47.24910184315273, 47.597713811056956, 41.96755027770996, 40.396381923130576, 44.68334402356829, 46.46386854989188, 51.11615998404366, 52.407003266470774, 52.21661220278059, 52.04787867409842, 51.19065856933594, 55.049163477761404, 51.18331779752459, 46.49160575866699, 46.464810030800955, 44.145247731889995, 37.67605447769165, 38.6617363521031, 38.604323387145996, 37.37405102593558, 39.7436021396092, 46.08745683942522, 47.873842171260286, 50.67090899603707, 50.520984240940635, 51.23790284565517, 44.61273642948696, 48.003637995038716, 56.88149724687849, 53.65064743586949, 39.293886934007915, 37.7110664503915, 40.928669520786826, 56.15097059522356, 52.7981972694397, 45.91867119925362, 47.71439143589565, 53.560119356427876, 51.35196099962507, 49.91041128976004, 46.44050523212978, 43.98125982284546, 39.814932346343994, 40.09001152856009, 38.88302952902657, 38.422537667410715, 38.60416010447911, 39.841422353472026, 39.172230924878804, 46.23772553035191, 48.54720251900809, 50.26918499810355, 53.23468657902309, 51.25046866280692, 51.853732109069824, 50.752275875636506, 51.53982291902815, 47.9921178817749, 42.959489004952566, 39.55897460665022, 39.71028552736555, 47.27755471638271, 47.62382514136178, 45.61045605795724, 48.989337239946636, 45.28318200792585, 44.173846517290386, 48.35137448992048, 53.66702086584908, 54.540784631456646, 54.34141302108765, 57.50276000159127, 54.53039707456316, 58.214926038469585, 56.909644399370464, 56.775950636182515, 50.41282858167376, 46.39038092749459, 46.81022582735334, 45.51512677328927, 47.99757916586739, 49.66574089867728, 50.230827467782156, 56.17248221806118, 55.87516532625471, 57.408129010881694, 57.29344204493931, 63.44452244894845, 53.23404734475272, 40.013140133449006, 51.624535356249126, 61.90249483925955, 61.04938111986433, 64.68057223728725, 59.89311054774693, 51.1170528275626, 4.365473704678672, 0.08268559205212764, 0.016827263037807176, 34.5438551902771, 67.29886191231864, 57.44951248168945, 43.43862288338797, 14.962122304098946, 31.56784793308803, 46.77012777328491, 52.77601514543806, 20.529939651489258, 35.28405720846993, 67.69119194575718, 51.82130834034511, 1.0882973223924637, 0.02895688564915742, 0.045455203391611576, 0.016285474877804518, 0.0328644059731492, 0.04738325386175087, 0.02135902879360531, 0.383840121861015, 0.20626316485660418, 0.1639446456517492, 0.17382608327482427, 0.16930083824055536, 0.16440110972949437, 0.16836782544851303, 0.23963734401123865, 0.14335543688918861, 4.08551949262619, 76.38127613067627, 64.04374204363141, 51.49516337258475, 43.70866114752633, 61.03959805624825, 49.17692123140608, 44.232878412519185, 34.62445081983294, 71.40180792127336, 68.80960178375244, 70.422452381679, 52.76373073032924, 0.499957412481308, 0.34688539483717507, 7.437002624784197, 32.806072507585796, 54.663666997637065, 63.363228525434224, 55.16894694737026, 57.62198066711426, 58.09910304205758, 59.94145611354283, 57.32284682137625, 60.530698095049175, 57.70543895448957, 54.678431919642854, 52.357413973127095, 51.72418989453997, 47.10293953759329, 45.733175141470774, 45.66791418620518, 45.77245678220476, 46.22258540562221, 47.032658508845735, 55.372800145830425, 57.71655607223511, 57.583852427346365, 51.87448985236031, 55.63855137143816, 55.46646533693586, 56.575196334293906, 57.64096661976406, 54.54648910249983, 48.506896018981934, 47.745804241725374, 48.89141280310494, 49.54080186571394, 49.39427477972848, 50.278710978371755, 50.8642634664263, 44.73126574925014, 43.61208118711199, 46.45889711380005, 49.43252113887242, 54.53729316166469, 56.5893428666251, 53.88917909349714, 55.08157682418823, 54.13987357275826, 58.94402136121477, 53.1711869921003, 49.46341977800642, 49.005363259996685, 47.251248836517334, 41.04068490437099, 42.807055950164795, 43.11058105741228, 41.05817699432373, 42.6790006501334, 49.3472250529698, 49.9222788129534, 55.828615869794575, 54.015407017299104, 52.38686391285488, 47.58103813443865, 52.06061124801636, 60.262344769069124, 54.784266880580354, 40.207616737910676, 38.650636604854036, 41.191370487213135, 56.96053300585066, 54.96164396830967, 49.52915668487549, 49.099733693259104, 58.42207963126046, 52.95810658591134, 53.12024974822998, 48.32580164500645, 45.338930879320415, 44.008378641945974, 44.08313431058611, 43.549231256757466, 39.89643471581595, 41.027215821402415, 45.46680552618844, 44.34766960144043, 56.502761363983154, 53.07864740916661, 54.65417923246111, 54.55979837690081, 53.24542154584612, 54.108269691467285, 54.434313910348074, 53.53485918045044, 50.27652924401419, 46.90701423372541, 42.17223726000105, 42.341568333762034, 49.97143384388515, 50.04722826821463, 47.35992213657924, 50.57900864737374, 48.2741904258728, 46.677296366010395, 50.68511806215559, 58.02416672025408, 56.52605519975935, 57.02780546460833, 58.36161640712193, 55.45336103439331, 61.256340163094656, 58.37242085593087, 60.17051042829241, 52.94136837550572, 49.056283133370535, 49.55442033495222, 47.6748492377145, 49.01955495561872, 51.751558848789756, 55.10440513065883, 58.701800210135325, 58.56870746612549, 61.65162318093436, 60.292513847351074, 67.6975564956665, 52.343246596200125, 41.92425952638899, 56.29880741664341, 63.29465675354004, 64.3667221069336, 67.23553603036063, 61.64821856362479, 57.7637482370649, 7.641823359898158, 0.13768953377647059, 0.24581562248723848, 35.581523486546104, 77.23475115639823, 62.972329820905415, 53.05978304999215, 22.069637877600535, 37.91225848879133, 47.1543527330671, 64.01686641148159, 40.574669224875315, 45.55863986696516, 72.61526216779436, 63.97045939309256, 2.5425799318722317, 0.23301158526114055, 0.22172794145132813, 0.15180745907127857, 0.18381004753921712, 0.117567224960242, 0.12568733495260986], [0.05390922725200653, 0.012830625620803662, 0.06388202282999243, 0.04610858850979379, 0.0094295595938872, 0.11658276564308576, 0.04212224277268563, 0.10554808990231582, 0.04242964627753411, 3.2197415956429074, 60.037299564906526, 46.05140263693673, 51.00670153754098, 35.96317761284964, 45.73003455570766, 45.12320320946829, 18.28014247758048, 12.254369361060006, 45.433523654937744, 60.79889856066023, 50.13386535644531, 65.7474125453404, 18.281236818858556, 0.10854519943573646, 0.9912290338959012, 11.559097869055611, 29.41697747366769, 44.1792174748012, 47.6576246534075, 39.165765626089915, 51.61720500673567, 51.22749097006661, 52.65209402356829, 49.594883169446675, 47.871990476335796, 44.48216935566494, 45.076924732753206, 44.883278438023154, 41.448394775390625, 42.239037241254536, 41.28614044189453, 39.92947687421526, 43.86145550864083, 45.83598068782261, 48.61781358718872, 54.830531460898264, 49.944450514657156, 51.627380643572124, 53.952630043029785, 52.821407726832796, 54.07064519609724, 53.20108509063721, 50.810998576028005, 43.31680359159197, 40.60505369731358, 42.871976443699424, 45.589660099574495, 45.11639744894845, 42.72070721217564, 47.92804854256766, 42.50341272354126, 40.8258500780378, 39.161992754255024, 42.24530799048287, 46.93828112738473, 48.50162928444998, 48.74011925288609, 48.08804818562099, 50.155314445495605, 48.43701451165335, 48.77528061185564, 48.76588664736067, 42.87959166935512, 42.99762419291905, 49.469909395490376, 41.03966351917812, 35.778685569763184, 39.63513381140572, 38.221234457833425, 39.037137099674766, 43.417437825884136, 49.39283650262015, 49.14103031158447, 52.29039512361799, 46.23723568235125, 48.271946157727925, 57.278301920209614, 52.0510435785566, 39.73133856909615, 35.65165860312325, 44.891855989183696, 56.04334647314889, 54.11437020983015, 48.04741859436035, 46.212948254176546, 52.963345527648926, 49.595140252794536, 51.14935500281197, 48.19506434031895, 41.9675954410008, 38.095763887677876, 36.201556410108296, 37.29459490094866, 41.880155835832866, 43.9053681237357, 40.94704055786133, 32.708127226148335, 38.72269984654018, 50.50787993839809, 47.52674491064889, 47.78534991400582, 48.277021816798616, 50.08741317476545, 47.23798125130789, 47.48158509390694, 41.75466094698225, 38.80767631530762, 39.935132707868306, 39.997576168605256, 47.80771269117083, 44.182156562805176, 42.6068331854684, 44.59134987422398, 42.632482460566926, 42.549955231802805, 45.96714530672346, 52.8560722896031, 53.258383410317556, 52.83665207454136, 54.14625549316406, 57.01581982203892, 54.338692801339285, 56.40200206211635, 55.343826157706125, 51.01771443230765, 47.31541197640555, 44.208993979862754, 43.11035871505737, 45.54191902705601, 46.74950899396624, 45.92085640771048, 50.35650300979614, 54.911790643419536, 54.28283970696585, 57.23928778512137, 59.32881954738072, 62.075442450387136, 54.9993622643607, 52.23303427015032, 58.98088155473982, 53.59944616045271, 55.209381989070344, 55.36507722309658, 23.997075114931377, 0.22421827353537083, 0.02394061705230602, 0.6120030315858977, 48.20140109743391, 55.649727548871724, 55.104446819850374, 29.869371209825786, 16.04970645904541, 22.200894560132706, 22.762060608182633, 42.82356139591762, 39.271086420331685, 50.06034646715437, 39.963154792785645, 55.707574776240754, 2.9002223866326466, 0.0911424725449511, 0.08661091034965855, 0.043770041316747665, 0.13375955394336156, 0.049595193205667396, 0.08156170057398932, 0.018616476761443273, 0.0880132590287498, 0.058727239790771685, 0.025707106638167585, 0.015184845276443022, 0.12010821646877698, 0.03370301418804696, 0.06293271841215235, 0.04471382245953594, 4.4780944500650675, 69.6110417502267, 53.508185046059744, 49.60342945371355, 41.6603148324149, 62.892647879464285, 44.623579093388145, 33.52109772818429, 27.648789473942347, 47.40965039389474, 69.98161002567836, 53.08900717326573, 74.5560746874128, 23.621165411812918, 0.03957990437213864, 0.8610308659928185, 10.553240162985665, 28.24459229196821, 43.85255486624581, 51.06554583140782, 45.56946168627058, 55.08496754510062, 55.40228830065046, 55.74254853384835, 52.5620835849217, 49.86030088152204, 47.40715251650129, 47.60917139053345, 45.90037659236363, 43.659120491572786, 44.79542888913836, 43.29100840432303, 41.97824355534145, 46.49871029172625, 47.75107792445591, 53.03378289086478, 55.13244111197335, 50.50559050696236, 53.31849227632795, 54.94818530763899, 56.89410127912249, 55.883214814322336, 54.29433897563389, 52.97296183449881, 45.00104693004063, 43.507726192474365, 44.50048133305141, 49.84184994016375, 47.584678990500315, 45.47219385419573, 49.75778021131243, 45.49144383839199, 44.102439880371094, 44.04425913946969, 45.95687239510672, 47.5721618107387, 49.735525131225586, 51.394994667598176, 49.934879371098106, 53.27500350134713, 50.22715881892613, 50.754068510872976, 49.46319396155221, 44.74596813746861, 43.87926721572876, 49.054792744772776, 42.65765578406197, 36.36131634031023, 41.98204074587141, 39.82198476791382, 42.3915502003261, 45.9595057623727, 51.4059693472726, 50.82565927505493, 53.99426712308611, 46.240619455065044, 50.85600553240095, 57.50607776641846, 52.21349246161324, 40.68957158497402, 34.5312511580331, 43.03757633481707, 57.7533745765686, 55.30103915078299, 48.00379432950701, 48.70686864852905, 54.47118105207171, 50.826725823538645, 50.633072580610005, 50.172945499420166, 43.057837281908306, 40.05036163330078, 36.96881818771362, 39.568781988961355, 41.238951751164024, 42.726345675332205, 41.96443748474121, 37.148092133658274, 39.21377420425415, 51.24495874132429, 48.64695085797991, 49.713659150259836, 50.757514817374094, 52.587819712502615, 49.95508473260062, 48.40514659881592, 45.58259725570679, 41.54250465120588, 41.37935747419085, 44.22613865988595, 50.691357544490266, 46.60617460523333, 45.61315195901053, 47.39147390638079, 44.73631361552647, 45.878034659794395, 48.39935874938965, 54.13809483391898, 56.41907031195504, 54.20612464632307, 55.84053203037807, 57.29434183665684, 56.05593660899571, 57.637086050851, 57.241743973323274, 53.217684337071006, 49.64861011505127, 47.84871053695679, 44.912023135593955, 46.320113795144216, 49.061848640441895, 48.752952575683594, 53.35406705311367, 56.88387353079659, 57.25228091648647, 58.22176653998238, 61.36962359292166, 61.42438929421561, 56.524550914764404, 56.453008787972585, 57.96107012884957, 58.44379275185721, 57.177636419023784, 57.21193620136806, 20.098199435642787, 0.6005824729800224, 0.41044108303529875, 0.9752498056207384, 54.818208830697195, 59.59640857151577, 61.19399397713797, 35.78366047995431, 19.752637726919993, 28.963944503239222, 32.553241457257954, 52.363920961107524, 39.037446294512065, 57.12003585270473, 47.53583662850516, 69.29368277958461, 8.138877511024475, 0.24143310050879205, 0.07176491019449063, 0.01836083360415484, 0.051616172439285686, 0.07574336456933192, 0.038605589153511186, 0.10215540802372353, 0.20085811774645532, 0.1703303794243506, 0.23787708846586092, 0.05943527751203094, 0.25103575523410526, 0.1512554029801062, 0.15859301281826838, 0.2703547328710556, 5.259417644568852, 81.89851406642369, 62.13036796024868, 66.55390385219029, 46.15855428150722, 56.54113279070173, 64.91973618098667, 26.452665771756852, 23.557037012917654, 56.914459500994, 70.37061187199184, 60.02158273969378, 77.9236650466919, 24.535852330071585, 0.4567174698625292, 1.7345862942082542, 12.540613429886953, 32.84225525174822, 49.32868378502982, 56.09255708966936, 46.785354750497, 57.5530058997018, 60.68207154955183, 59.829298291887554, 54.6638719694955, 54.17213405881609, 51.666637965611045, 51.8541316304888, 49.111851351601736, 46.94133138656616, 47.364792823791504, 47.7867499760219, 44.905172211783274, 50.148248127528596, 49.89833879470825, 54.867652211870464, 57.871087482997346, 54.3306884765625, 56.788700580596924, 56.54852219990322, 57.953982966286794, 57.8469147000994, 56.71126985549927, 56.1849889755249, 47.11819430759975, 45.9575845854623, 46.496469497680664, 52.378164768218994, 48.70979036603655, 48.10764905384609, 52.51451621736799, 47.51792764663696, 46.27550983428955, 43.95753867285592, 48.142522062574116, 49.05889565604073, 53.02064037322998, 54.8740827696664, 53.4522624697004, 54.657886096409385, 53.11365590776716, 54.91785294669015, 53.0900285584586, 48.61171654292515, 47.10055977957589, 51.949620723724365, 45.71449143545968, 40.31076622009277, 44.228025095803396, 42.42820542199271, 46.07290036337716, 49.41561269760132, 53.77290446417672, 53.31749520983015, 55.9276693889073, 48.85375009264265, 53.99281842367989, 62.29302528926304, 54.21369123458862, 41.689177649361746, 34.844385623931885, 44.4529104913984, 58.41666003635952, 56.95562757764544, 50.74338218144008, 50.624581881931846, 57.155641896384104, 52.91122709001814, 52.80797685895647, 53.53008576801845, 46.80294411523001, 41.31147009985787, 37.27713060379028, 41.858612946101594, 45.06861468723842, 45.2065885407584, 43.55915675844465, 42.593447480882915, 48.948443617139546, 51.733670711517334, 51.60323217936924, 53.761109897068565, 53.64369228907994, 54.78375618798392, 51.8706613949367, 51.220633098057334, 48.41731289454869, 43.888497897556846, 47.09592880521502, 45.834594522203716, 53.433540548597065, 47.867102418627056, 48.18606642314366, 49.680300848824636, 48.05554798671177, 49.32764155524117, 51.00120551245553, 57.08595493861607, 58.37720816476004, 55.913071223667686, 58.273700850350515, 58.732823916843955, 57.630742345537456, 60.04705483572823, 59.64660235813686, 55.226801122937886, 51.60998582839966, 50.42888934271676, 48.99699068069458, 49.58992910385132, 53.224920885903494, 52.075914655412944, 56.85292625427246, 61.10668986184256, 59.61006872994559, 62.91374955858503, 66.52824415479387, 65.52738394056047, 54.83351223809378, 57.09910440444946, 64.87858894893101, 61.61672237941197, 60.847911153520855, 60.67289992741176, 28.43294405937195, 0.7565829934818404, 0.3878641873598099, 0.9433208789144243, 57.37659461157662, 65.53283132825578, 67.16688088008335, 42.08190720421927, 30.656932149614605, 29.09310109274728, 34.64235980170113, 61.55192347935268, 51.56284230095999, 64.50102383749825, 53.91347346987043, 79.66764899662563, 11.556117960384913, 0.4085189290344715, 0.18473482291613305, 0.09802327225250856, 0.26638820714184214, 0.3174789084919861, 0.2525728541825499], [0.03284804988652468, 0.11554097011685371, 0.08801896550825664, 0.07537383439817599, 0.03879835755963411, 0.13324310736996786, 0.09260745679161378, 0.11061806284955569, 0.07879729462521416, 1.4895462372473307, 59.69740758623396, 50.4940356527056, 42.09098849977766, 28.41047705922808, 30.631362778799875, 42.62839344569615, 26.48335075378418, 6.580009205000741, 25.66785979270935, 58.24318436213902, 58.39354337964739, 49.996329239436555, 57.41602911267962, 3.2381156725542883, 0.3216539616031306, 1.6617519110441208, 13.758618746485029, 25.82237904412406, 33.461183411734446, 43.36907836369106, 49.32886096409389, 50.473041670663015, 50.51591205596924, 51.51453495025635, 51.774817943573, 45.51109334400722, 43.46743358884539, 43.44488321031843, 43.199987002781455, 40.75951215199062, 40.21151467732021, 44.48367364065987, 43.70555182865688, 49.309225354875835, 49.343045711517334, 50.26838942936489, 49.67723321914673, 54.26741818019322, 52.514509269169395, 55.50577129636492, 52.155294350215364, 52.192717347826274, 49.39843675068447, 43.79179981776646, 40.35405349731445, 45.010142121996196, 43.945813587733674, 45.92301034927368, 43.45233167920794, 45.040335518973215, 46.64876011439732, 42.67298003605434, 42.72563001087734, 41.90695851189749, 45.30413777487618, 47.1814090183803, 47.693095207214355, 47.75343336377825, 47.41456971849714, 46.34254258019583, 45.77198430470058, 44.8797105380467, 42.3309063230242, 46.388070651463096, 48.32217468534197, 40.88946431023734, 44.985135555267334, 41.10893358503069, 41.10837772914341, 39.49701404571533, 39.80042450768607, 44.09420279094151, 52.41468450001308, 50.77940859113421, 50.76687751497541, 52.11884410040719, 56.47575371606009, 53.44545323508126, 39.74653080531529, 35.752188614436555, 41.69984660829817, 53.959720679691856, 54.22836930411202, 51.3544727734157, 49.63135426385062, 51.46854829788208, 52.666000843048096, 46.820689814431326, 42.3356727872576, 40.78454303741455, 39.619340556008474, 41.233577319553916, 44.72118043899536, 42.25494514192854, 45.71035725729806, 40.718587262289866, 41.381466252463206, 34.22874396187918, 39.60097994123186, 49.13004520961216, 48.592681952885215, 45.99624783652169, 46.08080046517508, 47.56223283495222, 42.74995218004499, 43.544384888240266, 42.70897170475551, 41.79756259918213, 44.795536586216514, 48.195307527269634, 42.094219412122456, 41.817444869450156, 44.372929777417866, 43.42242315837315, 41.809555189950125, 43.98973315102713, 49.10567092895508, 51.3719197000776, 51.507756982530864, 54.54540170942034, 53.87773541041783, 56.727389676230295, 56.93878514426095, 50.51636021477835, 55.89465849740164, 52.22854920795986, 47.55306121281215, 46.356907980782644, 45.32110180173601, 43.5093138558524, 46.33571250098092, 45.94373682567051, 49.84339244025094, 51.785004002707346, 56.5866573878697, 55.98120525905064, 59.13508292606899, 58.2612601007734, 58.698798588344026, 50.25973892211914, 51.96506656919207, 54.15071276256016, 35.19348396573748, 3.13320569055421, 0.06534065598888056, 0.6993437334895134, 3.7149803127561296, 51.695528575352256, 54.907159669058665, 58.240342548915315, 32.3448371887207, 10.177643128803798, 20.988783052989415, 27.514357464654104, 45.967339856284006, 34.02448429380144, 76.3749532699585, 44.37283597673689, 61.04803316933768, 17.50125115258353, 0.31016516951578005, 0.21073711264346326, 0.09501144529453345, 0.02537778645221676, 0.022859522474131415, 0.04108810451413904, 0.05953306797891855, 0.039987120378230295, 0.03208829761881914, 0.06796287492449794, 0.03547974456367748, 0.0897146380905594, 0.06025515137506383, 0.04642247880942055, 0.018869349799518074, 2.366529081548963, 69.28916645050049, 58.500934737069265, 43.34545796258109, 31.3963212285723, 35.54253019605364, 56.8199987411499, 18.59976829801287, 18.996734516961233, 34.76950488771711, 59.95759677886963, 66.03827803475517, 53.95747641154698, 66.56494453975132, 4.135238196168627, 0.3065444252320698, 1.0660296486956733, 11.272090366908483, 26.479091508047922, 36.45671510696411, 47.35502365657261, 55.0627680506025, 53.98980985369001, 54.125959805079866, 55.0771473475865, 53.4719362940107, 48.442034585135325, 46.97785459245954, 45.99722753252302, 44.7292994090489, 43.20026840482439, 42.11772864205496, 45.605568000248496, 45.62349087851388, 51.18694128308977, 53.58326728003365, 54.38144506726946, 51.17848879950387, 53.37197950908116, 54.26800530297415, 56.48004422869001, 53.72148084640503, 55.418161460331504, 51.319662298474995, 45.95856428146362, 42.69696174349104, 47.233378069741384, 46.27610737936837, 48.05551324571882, 45.46102115086147, 47.60739612579346, 48.90318999971662, 44.75545937674386, 45.09234973362514, 44.51568399156843, 48.96877057211739, 48.99425656454903, 49.8737803867885, 50.22811419623238, 50.95186982836042, 49.2493006161281, 48.35554688317435, 48.41387701034546, 46.103142397744314, 47.69832025255476, 49.47254971095494, 44.25546700613839, 46.41965021405901, 42.55628504071917, 42.867922169821604, 42.184281962258474, 41.53957251140049, 44.63705859865461, 52.16817283630371, 52.128394399370464, 51.679818698338096, 53.4445013318743, 57.246263776506694, 54.05811064583914, 39.55610500063215, 35.56605332238333, 41.87599733897618, 53.74192244665963, 56.57929229736328, 51.54118129185268, 50.48940815244402, 52.72104099818638, 52.204425062452046, 48.5239851134164, 42.67367485591343, 42.75049066543579, 40.35782289505005, 41.53743941443307, 44.530066762651714, 44.756418228149414, 46.56578472682408, 41.51369741984776, 43.2461438860212, 37.89480808803013, 42.103915623256135, 49.09176410947527, 49.05378178187779, 49.87530204227993, 50.08705186843872, 49.58097634996687, 46.46820075171334, 46.15058817182268, 46.6665301322937, 45.28524909700666, 47.82026808602469, 49.39475073133196, 44.709649903433665, 46.58512851170131, 47.80822338376726, 45.368721280779155, 45.08403273991176, 46.57821158000401, 51.382529599326, 52.660021918160574, 54.44404138837542, 54.60715382439749, 55.83577251434326, 55.07741485323225, 56.178586210523335, 52.159240927015034, 56.76096337182181, 52.95328801018851, 50.45701912471226, 47.64120953423636, 46.20544072559902, 45.27131795883179, 47.19035134996687, 47.71253974097115, 50.986103602818076, 53.31856870651245, 57.40608276639666, 58.77027470724923, 60.78436292920794, 58.544444356645855, 58.6777594430106, 54.23434475490025, 56.71978139877319, 53.39860848018101, 32.34536525181362, 2.1741230402673994, 0.508253453033311, 0.8418304962771279, 4.070735897336688, 60.07543822697231, 56.8902450289045, 68.21894931793213, 33.18388428006853, 22.198283774512156, 25.972180468695505, 33.98134292875017, 56.28245830535889, 35.14044141769409, 89.61912305014474, 48.18967948641096, 72.68911457061768, 25.44372480256217, 0.2987378255597183, 0.058232370630971024, 0.013173055103314775, 0.011175240207064365, 0.025417857337743044, 0.04863494401797652, 0.11439971492758819, 0.2842323210622583, 0.13114670557635172, 0.1702087995197092, 0.11381616802620036, 0.18276537502450602, 0.19728768004902772, 0.12512617292148726, 0.19195562973618507, 2.9087693222931454, 79.7736507143293, 66.07655566079276, 57.071186542510986, 38.611678055354524, 39.13442577634539, 61.47432599748884, 35.27341604232788, 12.670094847679138, 38.97761535644531, 65.98406818934849, 69.24226611001151, 61.529244559151785, 68.55759062085832, 4.1997396264757425, 0.5957389271685055, 3.1871078610420227, 15.094369104930333, 29.635463578360422, 41.32890313012259, 51.43003443309239, 58.55895219530378, 58.90423597608294, 59.38360609327044, 58.4589398247855, 57.53238364628383, 52.17177547727312, 48.19327865328108, 49.13459627968924, 47.958822114127024, 45.878566196986604, 44.035202162606375, 50.05889081954956, 48.113416058676584, 54.87094565800258, 53.60613032749721, 55.932418482644216, 53.92398609433855, 57.964103017534526, 56.62455286298479, 60.75875881740025, 55.49377523149763, 55.341595785958425, 52.849989141736714, 49.04043081828526, 45.25017459051949, 50.420871121542795, 48.85617848805019, 51.793946334293906, 48.728161403111045, 49.50257287706648, 49.70490789413452, 47.892244475228445, 47.821473598480225, 46.53778001240322, 51.99124738148281, 54.656190735953196, 54.535107953207834, 54.68828099114554, 54.70701680864607, 53.614134652274, 51.07033314023699, 53.92568492889404, 49.83835847037179, 51.57099601200649, 52.61149917330061, 46.80200610842024, 47.456960678100586, 47.21113688605172, 45.78996276855469, 44.53501388004848, 44.26626798084804, 47.00216981342861, 55.22431366784232, 56.04490286963326, 56.65048006602696, 56.6764246395656, 59.62379142216274, 57.31284141540527, 40.76387562070574, 35.194758960178916, 42.373700278145925, 56.875594752175466, 59.74061843327114, 54.24937718255179, 53.65666457584926, 56.99777882439749, 54.926180362701416, 51.51976694379534, 43.81848784855434, 44.57849570683071, 44.899495533534456, 46.60116842814854, 47.26481866836548, 45.244682039533345, 48.024319308144705, 43.52188662120274, 46.63922718593052, 44.992219243730815, 53.427818707057405, 53.32881382533482, 51.71207571029663, 51.73859698431832, 53.941321849823, 52.37552097865513, 48.526628902980256, 48.30876466206142, 49.6521189553397, 46.898877893175396, 50.46674312864031, 50.550399439675466, 47.06999117987496, 46.982416084834504, 51.11758783885411, 48.15684229987008, 47.41996499470302, 47.576608657836914, 54.154558590480256, 55.243417739868164, 55.734624113355366, 56.59158713476998, 59.31741060529436, 55.842335087912424, 58.71657902853829, 55.1765969140189, 60.54041167667934, 56.35322918210711, 52.67499876022339, 49.93241970879691, 48.87367752620152, 48.627815519060405, 52.62305402755737, 51.71518155506679, 55.966572352818076, 56.73277800423758, 62.317913736615864, 62.39669936043875, 64.84179128919328, 60.75144931248256, 60.922242982046946, 58.276865754808696, 61.82535593850272, 57.39214468002319, 41.420754841395784, 3.628788994891303, 0.22172270316098416, 1.401612332889012, 5.207578871931348, 64.66414669581822, 67.16467135293144, 68.07027176448277, 46.74182081222534, 22.605849470411027, 26.64540011542184, 40.46234464645386, 60.88470186505999, 43.878423009599956, 87.36335563659668, 57.39794642584664, 83.29105118342808, 31.324337891169957, 0.4755531134349959, 0.36090436258486336, 0.1963569199932473, 0.13318522833287716, 0.16302679133202347, 0.17561035895986216], [0.10635205890451159, 0.06555775326809712, 0.09381863501455102, 0.03211301664954849, 0.06993096574608769, 0.02502994904560702, 0.20406172584210122, 0.12069327650325638, 0.09762763205383505, 0.8208975823862212, 53.12180267061506, 52.25985084261213, 45.5089567729405, 51.80969442640032, 50.810199533190044, 27.00320281301226, 63.099488803318565, 22.594463109970093, 4.446696409157344, 27.608050448553904, 59.02368245806013, 48.1599029813494, 55.03355087552752, 25.585860627038137, 0.6881721700940813, 0.12185363923864705, 2.9749552564961568, 14.697875363486153, 26.019855533327373, 33.682858739580425, 31.166200365339005, 51.550530093056814, 49.12969432558332, 54.55089773450579, 51.059268133980886, 50.897958755493164, 42.38361883163452, 43.52405793326241, 43.11657040459769, 42.38758625302996, 42.74962561471121, 45.3746793610709, 48.72340188707624, 49.446487018040244, 48.91196557453701, 52.77071366991316, 54.03953811100551, 54.242574896131245, 54.05664110183716, 52.66543109076363, 51.231086662837434, 52.15792771748134, 50.13232980455671, 45.06575550351824, 41.4194381577628, 43.741706780024934, 44.39920786448887, 48.797115325927734, 44.090864181518555, 44.419413225991384, 47.327498367854524, 48.2801901953561, 45.33465773718697, 41.308020319257466, 43.257295744759695, 46.9273863519941, 45.96929924828665, 45.09013673237392, 47.889715330941335, 42.60881689616612, 45.05082035064697, 43.69385801042829, 43.533365045275005, 42.301411220005576, 42.80926547731672, 40.5844383920942, 42.155075209481375, 48.81772715704781, 44.3930343900408, 43.22190509523664, 48.30456100191389, 42.59420483452933, 48.52044153213501, 50.37389782496861, 55.48209530966622, 50.95740059443882, 54.51985318320138, 48.32920626231602, 38.85688345772879, 34.17121982574463, 41.80744988577706, 53.32296691622053, 54.41662727083479, 51.28654023579189, 53.19082954951695, 50.74893726621355, 47.05541385923113, 42.96360581261771, 42.97477504185268, 41.296614851270405, 44.94663211277553, 41.531418800354004, 44.297107560294016, 47.86956555502755, 42.821709700993125, 45.49860743113926, 45.570159980228965, 33.26808255059378, 34.55575745446341, 36.48556055341448, 46.746743610927034, 49.55303069523403, 48.9565486907959, 43.9948296546936, 46.16975130353655, 43.229794774736675, 43.64818402699062, 43.84312963485718, 49.33952644893101, 44.23791585649763, 42.11448730741228, 44.351136752537315, 42.323364053453716, 42.16963863372803, 41.94675431932722, 46.52020454406738, 49.88729463304792, 49.97298329217093, 51.44004678726196, 56.07148667744228, 53.77663564682007, 55.10652780532837, 62.24515914916992, 61.175414494105745, 55.25388867514474, 53.90239804131644, 51.60301678521292, 46.29103210994175, 44.76684400013515, 43.17056138174874, 43.23278250013079, 43.18869965417044, 46.44706085750035, 48.145700863429475, 53.98316042763846, 53.51110328946795, 59.1844915662493, 53.55400841576712, 53.633631297520225, 45.21698304585048, 40.78979934964861, 26.152590445109777, 7.952966298375811, 0.01954226485187454, 1.4419797382184436, 0.686862163245678, 7.205789157322474, 60.84336008344378, 56.95364039284842, 49.38382468904768, 13.56248152256012, 9.182820899145943, 28.20514042036874, 24.496478625706263, 51.784489836011616, 26.078345469066075, 17.004482746124268, 48.363075256347656, 53.176728180476594, 26.742905923298427, 0.6270957674298967, 0.08601395559630223, 0.08412652901772942, 0.05333151575177908, 0.10303177671240908, 0.038498112599232366, 0.06299418689949171, 0.0963965727548514, 0.0687412495857903, 0.024208183766209652, 0.030335936828383377, 0.04005369484158499, 0.07096932788512536, 0.0614203792065382, 0.09864641167223454, 0.9075650147029332, 62.11676338740757, 63.507848330906455, 51.58657734734671, 54.1642096383231, 46.137324060712544, 40.19206319536482, 62.27887180873326, 14.689617429460798, 6.8154120019504, 27.39576734815325, 65.47690527779716, 55.83125965935843, 63.066269465855186, 29.933572564806255, 0.26669634346451077, 0.40919252431818415, 2.5684302704674855, 12.477024384907313, 26.6652980191367, 39.44786943708147, 37.861067635672434, 54.86950043269566, 52.374718461717876, 56.35156856264387, 54.074689047677175, 53.97824457713536, 44.342375074114116, 46.08814123698643, 46.277048860277446, 42.91099752698626, 43.71600539343697, 48.98603684561593, 50.1294949395316, 52.41887773786272, 51.77979980196272, 55.21075773239136, 53.93500941140311, 57.62062924248831, 56.41332067762102, 54.312581471034456, 54.52145821707589, 54.247966698237825, 49.92293541772025, 46.353736128125874, 42.49728441238403, 45.788364682878765, 45.77374914714268, 49.43739182608468, 47.30365909848894, 46.497549942561555, 49.70721122196743, 49.95431695665632, 47.80303307941982, 45.411143507276265, 47.32332597460066, 48.844595840999055, 49.17787313461304, 48.77979694093977, 49.82483032771519, 47.61233629499163, 46.74663591384888, 47.07759598323277, 44.330076762608115, 45.43055330004011, 43.67030361720494, 42.617373602730886, 42.249271937779014, 48.454551764896934, 45.665767192840576, 45.669411523001536, 49.417582511901855, 45.281966073172434, 48.9321084022522, 54.089447021484375, 54.729883330208914, 53.97480174473354, 56.27039623260498, 48.464390414101736, 39.34296553475516, 34.63706874847412, 40.96650941031319, 54.67841454914638, 54.905742236546104, 53.42062037331717, 55.1456253187997, 52.872654165540425, 50.77242912564959, 42.49943835394723, 44.63986219678606, 41.011085578373496, 44.31101090567452, 42.214673382895334, 45.046748706272666, 49.226903097970144, 43.74918304170881, 45.514765466962544, 45.61772387368338, 39.39382982254028, 39.890445368630544, 40.443852015904014, 49.18995952606201, 50.51794440405709, 52.501328536442344, 47.705407415117534, 49.720662934439524, 46.72905349731445, 46.73613371167864, 47.20864595685686, 51.89823184694563, 45.5178678376334, 44.814668451036724, 47.44269602639334, 43.821447781154085, 43.41291454860142, 43.983837604522705, 48.63014663968767, 53.646092891693115, 53.67155109133039, 53.78429256166731, 55.774642263139995, 55.887293406895225, 54.311285631997244, 59.27888979230608, 64.49859891619, 57.960284982408794, 54.290010247911724, 52.98467649732317, 50.25126906803676, 47.70579998833792, 44.39274256569998, 43.898524148123606, 44.501728534698486, 47.50393744877407, 50.471196923937114, 55.406766414642334, 56.08226333345686, 60.923236574445454, 56.88150072097778, 55.36892999921526, 47.622511931828086, 48.24256222588675, 28.10676782471793, 4.317368720258985, 0.14386687587414468, 4.772285086768014, 1.1551202109881809, 11.429341997419085, 65.68849182128906, 64.3988436290196, 52.7018118585859, 16.681374141148158, 17.375024965831212, 18.885611976896012, 27.677759987967356, 61.68680885859898, 24.25347580228533, 21.796217577798025, 53.40975686482021, 60.80764634268624, 36.727326597486226, 0.30512954401118414, 0.08690750479165997, 0.11050558209951435, 0.10362520308366843, 0.05695698263921908, 0.03372871370187827, 0.12429848233503954, 0.17835108403648647, 0.2144239598086902, 0.146349554083177, 0.15229453864906514, 0.1735967384385211, 0.2676077517015593, 0.16945116088858672, 0.20068456205938542, 1.111253302012171, 74.78867258344377, 68.77377687181745, 59.31608349936349, 62.51388072967529, 67.53912367139543, 37.60419273376465, 78.3950447354998, 32.147598675319124, 8.81908791405814, 41.10327775137765, 69.02661487034389, 60.60702405657087, 64.63271999359131, 32.14821359089443, 1.0708630979061127, 0.5612334130065781, 3.420026025601796, 17.350367546081543, 28.651812314987183, 45.77620880944388, 43.46099608285086, 61.17414992196219, 55.89841399874006, 61.46641199929373, 56.48291383470808, 57.4533965247018, 46.76463174819946, 50.31034960065569, 50.628132411411826, 46.16403293609619, 47.65482452937535, 52.66604600633894, 54.71469109398978, 57.01625408445086, 53.60603305271694, 57.37925229753767, 56.20838008608137, 58.55306012289864, 58.38919380732945, 55.54950325829642, 55.718181201389854, 56.49017470223563, 51.808944020952495, 50.9049972806658, 44.59731837681362, 48.23583984375, 48.08429615838187, 52.05297865186419, 48.973026343754356, 50.53511687687465, 52.413152422223774, 52.059673241206575, 51.18132366452898, 48.77950859069824, 50.41795635223389, 52.03703253609793, 49.85042054312569, 52.19328710011074, 53.67318739209856, 50.30892869404384, 48.89210067476545, 49.9676262310573, 48.399337904793875, 49.05896513802664, 46.54084416798183, 46.32712800162179, 44.862545013427734, 48.868118967328755, 47.026742117745535, 49.994196142469136, 53.65841899599348, 47.799819537571494, 50.45210674830845, 54.89948885781424, 59.66873237064907, 56.98534849711827, 59.47944259643555, 51.1628657749721, 39.890497480119976, 33.313322271619526, 42.37554155077253, 56.53963892800467, 58.080725056784495, 54.33359282357352, 57.12400327410017, 54.2821170943124, 53.304363114493235, 48.093109948294504, 48.486704553876606, 43.82123933519636, 45.360060351235525, 44.91771718433925, 48.195060866219656, 50.70433677945818, 46.087495054517476, 47.392790590013774, 49.13719490596226, 42.73600714547293, 43.02535792759487, 46.51851265771048, 53.96551547731672, 54.38139295578003, 54.383095264434814, 50.0931384904044, 52.70495939254761, 50.69368519101824, 50.18078654153006, 49.48583814076015, 54.956543990543906, 48.473582880837576, 46.48138843263899, 48.948124000004356, 47.351956026894705, 45.56804425375802, 45.726119245801655, 50.41501726422991, 54.51707737786429, 55.74414314542498, 55.19524587903704, 56.679283823285786, 58.008651392800466, 54.194253649030415, 58.68166433061872, 59.963516644069124, 60.29769025530134, 56.742147650037495, 55.36502858570644, 51.67368343898228, 51.12983751296997, 46.51336056845528, 46.856473037174766, 46.85066434315273, 52.47159719467163, 52.61299998419625, 59.02058356148856, 58.37226799556187, 64.55488627297538, 58.84320994785854, 59.21832234518868, 51.49519463947841, 59.09194156101772, 36.99853563308716, 9.649852752685547, 0.16792428067752294, 3.3828857328210558, 2.2765097405229295, 9.913374475070409, 75.56525189535958, 66.70170593261719, 60.81217656816755, 24.84182494027274, 19.037834848676408, 36.5610214642116, 38.19425112860543, 70.01246697562081, 38.549130371638704, 25.755751030785696, 65.26467950003487, 68.19570064544678, 47.08960941859654, 0.6941892557910511, 0.16957616060972214, 0.20266774349978992, 0.25206129306129044, 0.21842095176024096, 0.19748136108475073], [0.16849969194403716, 0.0698223187189017, 0.10178353012140308, 0.08377069168324981, 0.03555954367454563, 0.07691593414970807, 0.03640086602951799, 0.04480361978390387, 0.14401848773871148, 0.22278505829828127, 49.46111645017351, 55.728937012808665, 42.24500574384417, 23.031767095838273, 31.098187923431396, 32.452575956072124, 26.976587738309586, 56.34377268382481, 4.735903016158512, 10.325122117996216, 44.53901604243687, 56.7456043788365, 43.385719299316406, 61.57378946031843, 3.1620787126677374, 0.1662243740367038, 0.1457438665841307, 2.1962335109710693, 10.436797039849417, 24.809746844427927, 29.864882673536027, 40.630261761801584, 52.451054845537456, 51.461065087999614, 54.936804158346995, 50.200686182294575, 45.19082307815552, 43.112259047372, 43.31129714420864, 45.13548762457711, 44.45094415119716, 49.3632858140128, 45.64365107672555, 49.03631748471941, 52.287087781088694, 55.65373318535941, 52.28645896911621, 51.415540490831646, 53.172937938145225, 52.11920888083321, 52.42881713594709, 49.668183190482004, 48.599053450993125, 45.591539587293354, 42.16800928115845, 43.28484535217285, 44.914986542293, 42.332709380558555, 45.73627751214163, 44.266139439174104, 43.42881550107683, 51.07822976793562, 50.276414598737446, 49.46966273444039, 46.17022378104073, 49.55321134839739, 47.97018589292254, 46.87362813949585, 44.078395639147075, 46.488750049046104, 42.8254200390407, 43.09173059463501, 38.06627573285784, 34.862100056239534, 41.022525787353516, 36.468064989362446, 28.958889688764298, 30.978289808545792, 44.82043545586722, 43.67853028433663, 44.809155055454795, 47.32126235961914, 48.28590161459786, 49.72408839634487, 53.768846716199604, 52.061524936131065, 54.08076524734497, 52.75624057224819, 37.75887700489589, 35.27419771466936, 39.6369959286281, 53.97818204334804, 51.52275814328875, 52.973198073250906, 53.578691891261506, 48.3405248778207, 45.84141765322004, 43.68747609002249, 42.3477383341108, 45.48580537523542, 43.073324816567556, 45.279489040374756, 46.188893590654644, 29.602824415479386, 36.03236777441842, 39.14285741533552, 36.44617121560233, 36.93041549410139, 33.546486445835654, 33.838960443224224, 32.09434768131801, 40.43446499960763, 46.1843147277832, 45.7190911429269, 42.87535326821463, 44.28516360691616, 43.94841916220528, 44.70675597872053, 44.76543698992048, 42.06124326160976, 42.58849341528756, 40.923892634255544, 41.45465857642037, 44.105184418814524, 42.607906682150706, 45.17777436120169, 51.24053621292114, 49.38581534794399, 50.754023347582134, 53.458585330418174, 55.402538435799734, 62.4418557030814, 71.20108141217912, 72.96935626438686, 55.49818386350359, 55.11864198957171, 56.799737794058665, 51.53259331839425, 47.500317437308176, 43.95481845310756, 43.069611004420686, 41.42863409859793, 47.56206955228533, 48.81435033253261, 54.301648480551584, 52.82725811004639, 56.53072438921247, 56.41881322860718, 60.53163610185896, 36.563668727874756, 21.796241896493093, 7.633395195007324, 0.2536216793315751, 0.14530680860791886, 2.7070186053003584, 0.6851177854197366, 31.040959085736954, 65.19746957506452, 45.73327589035034, 24.97154085976737, 5.584137797355652, 30.641284806387766, 67.39030715397426, 34.263314723968506, 40.8450687953404, 36.29846640995571, 33.89248936516898, 40.84334216799055, 58.06905208315168, 32.985832827431814, 0.5015274882316589, 0.10702659056654998, 0.17610563524067402, 0.07114653409059558, 0.16440512665680476, 0.015070978618626083, 0.04146222836737122, 0.03363796303580914, 0.04410098320139306, 0.024515078369794146, 0.05544820574245282, 0.03842599450477532, 0.19835984680269445, 0.0650950941656317, 0.14444665690617903, 0.16456896572240762, 58.30379349844796, 62.060107776096885, 48.64932714189802, 31.019266809735978, 40.07420437676566, 30.054832526615687, 25.70146128109523, 48.693604537418906, 2.3729125218732015, 15.668898275920323, 46.368230070386616, 62.929487228393555, 47.956369400024414, 68.15219797406877, 3.7299254536628723, 0.30690204032829826, 0.38407204513038906, 1.285469067948205, 8.430876425334386, 25.08755145754133, 34.683454922267366, 45.28611414773123, 55.70027916772025, 56.09125082833426, 55.46755967821394, 54.09151758466448, 46.82625879560198, 46.26553916931152, 46.46536588668823, 48.00953701564244, 48.10959802355085, 52.399492263793945, 47.38209383828299, 51.85146699632917, 53.5445727620806, 57.59294761930193, 52.700557708740234, 54.218930176326204, 56.27613891874041, 55.74248947416033, 56.12459870747158, 51.850087778908865, 50.495876925332205, 46.573132446834016, 45.311568873269216, 45.483081681387766, 46.1060015814645, 44.970176083701, 48.34183461325509, 47.78127826963152, 45.09601490838187, 52.75978415352957, 52.41771044049944, 51.66519621440342, 48.064056055886404, 49.59171479088919, 49.25275387082781, 51.48146847316197, 45.920502049582346, 48.11967291150774, 42.80224779673985, 44.03129727499825, 39.22776787621634, 38.26780128479004, 43.59898035866873, 38.004968302590505, 33.372145720890586, 33.91535588673183, 46.353770869118826, 43.25987005233765, 45.9158467565264, 49.29232038770403, 50.59721292768206, 50.01995658874512, 53.370211192539756, 53.44087437220982, 54.5744104385376, 51.513030665261404, 38.74614306858608, 34.5576890536717, 40.04797492708479, 53.472401823316304, 53.74634150096348, 55.15850727898734, 55.879903997693745, 50.03805317197527, 46.89592490877424, 45.8856429372515, 43.43331445966448, 45.2610068321228, 45.49862480163574, 44.16159336907523, 47.57612575803484, 32.93059464863369, 38.738593850817, 41.20212629863194, 41.108259609767366, 40.139976024627686, 37.30269302640642, 36.848586559295654, 37.21649367468697, 41.67262356621878, 46.17090123040335, 46.21619653701782, 45.88674075262887, 47.323829718998496, 48.480715206691194, 48.21021836144583, 47.768695081983296, 44.69052498681204, 45.227676323481965, 44.059864793504985, 43.10789557865688, 47.235368728637695, 44.090047768184114, 47.37930761064802, 52.12492724827358, 52.6069724219186, 53.35716594968523, 57.1939195224217, 55.772516114371165, 58.7705317905971, 62.84088379996163, 69.03691904885429, 59.56081295013428, 56.86644050053188, 58.675612449645996, 52.564022132328574, 51.436763763427734, 46.277604716164724, 44.7153856413705, 43.05778169631958, 48.96358721596854, 51.40042468479702, 55.78364365441458, 57.940708432878765, 57.35539218357631, 57.28943640845162, 59.32169764382498, 43.77031946182251, 28.353395870753697, 7.733627302306039, 0.19310236748840126, 0.4024896839899676, 3.8859450817108154, 0.24415169177310808, 36.95267752238682, 67.31426606859479, 52.93875585283552, 26.069783551352366, 11.381357737949916, 25.676380021231516, 50.737490109034944, 36.14180537632534, 55.65552582059588, 35.62552990232195, 30.837345600128174, 50.25369051524571, 66.49988855634416, 45.22267362049648, 0.2872287859874112, 0.08665638576660838, 0.21127635799348354, 0.055370632226445844, 0.0927404360845685, 0.020531319547444582, 0.22680335624941758, 0.09463739608015333, 0.12956006000084536, 0.09513474189277206, 0.2826035927448954, 0.13860183767974377, 0.2733853416783469, 0.2336482953812395, 0.3000431912285941, 0.266709669892277, 66.5296060017177, 71.89638069697789, 56.71075916290283, 35.192188126700266, 42.33692693710327, 50.41770274298531, 31.889858722686768, 66.1110256740025, 8.813254032816205, 20.57232539994376, 54.09697192055838, 67.3825877053397, 52.764700004032676, 72.51979391915458, 4.451733418873378, 1.1705532457147325, 0.19235730889652455, 2.5606415569782257, 11.600321531295776, 32.24729142870222, 42.054625102451865, 51.29439170019967, 60.0724435533796, 58.97232832227434, 59.51893615722656, 57.137805870601106, 50.029472146715435, 49.65561389923096, 48.83590017046247, 51.60778324944632, 50.67012732369559, 56.27826854160854, 49.87772348948887, 53.14624295915876, 55.0929718698774, 59.135875020708355, 54.21081468037197, 56.667569160461426, 59.36605494362967, 58.70925562722342, 57.732304164341514, 53.75418601717268, 54.30963543483189, 48.450497491019114, 47.900297437395366, 47.6919070652553, 50.4919616154262, 47.36427518299648, 50.91286958966936, 51.03309079578945, 46.30793360301426, 55.79161671229771, 55.56567866461617, 55.411817755017964, 51.155712604522705, 53.1433698790414, 53.64455386570522, 54.15964119774954, 47.7575466973441, 51.54343945639474, 44.94616658346993, 47.70726258414132, 45.69273662567139, 42.52757508414132, 47.71646547317505, 40.8100220816476, 32.63294076919556, 40.37695475987026, 49.91684532165527, 44.5450644493103, 48.87258318492344, 54.38257762363979, 53.20834248406546, 54.69575725282942, 56.93978221075875, 54.64733178274972, 55.826385498046875, 52.792079380580354, 38.62027645111084, 36.993380069732666, 42.21004588263375, 56.17437560217721, 54.587236813136506, 59.410009247916086, 59.49236624581473, 53.86966160365513, 50.19758381162371, 47.85575253622872, 46.03142656598772, 50.12305048533848, 46.935220445905415, 47.296603202819824, 48.853927271706716, 34.92128133773804, 41.231329577309744, 44.32043266296387, 46.051253250667024, 44.02471733093262, 43.155216285160606, 40.92203746523176, 41.13053900854928, 45.07779325757708, 51.72116047995431, 50.207724707467214, 49.555584158216206, 48.86708715983799, 51.26876326969692, 49.60905054637364, 52.00104086739676, 48.10631499971662, 48.189290387289866, 46.74736894880022, 46.57119042532784, 48.370878083365305, 45.59877266202654, 49.25138854980469, 55.738935470581055, 55.64622565678188, 56.40676852634975, 58.13264199665615, 58.524190357753206, 58.92408003125872, 65.11083248683384, 71.18699046543666, 59.3148467200143, 59.30690492902483, 60.8728551864624, 57.14629656927926, 54.14173916407994, 48.728335108075825, 47.312889780317036, 47.84322493416922, 52.963258675166536, 55.23557322365897, 59.26968342917306, 61.05389744894845, 61.3414625440325, 61.79807036263602, 66.9858455657959, 51.187337330409456, 42.111093112400596, 9.561909403119769, 0.5188308911664146, 0.16244318336248398, 6.605091333389282, 2.5209831936018805, 38.44295147487095, 79.08318042755127, 56.83250897271292, 36.02782365253994, 15.013709204537527, 43.569398403167725, 78.96117006029401, 46.964625222342356, 55.44103493009295, 51.56866489137922, 46.320937156677246, 57.84772763933454, 75.4680118560791, 57.66089752742222, 0.47527165710926056, 0.18807518295943737, 0.23037585669330188, 0.11780145524867944, 0.27963475776570185, 0.1328232977539301], [0.06091702835900443, 0.023878939915448427, 0.05219721893912979, 0.08841652596103293, 0.12649988063744136, 0.030582068621047905, 0.05245772549616439, 0.028941822171743427, 0.15236030226307257, 0.4569341668060848, 45.06860426494053, 58.9385461807251, 45.16874170303345, 39.31417914799282, 36.54556867054531, 50.672868388039724, 53.456059660230366, 30.408019883292063, 7.877992630004883, 26.543098313467844, 45.44362980978829, 56.22233901705061, 42.28139345986502, 61.61800084795271, 19.376140901020594, 1.2809046443019594, 0.2723809470023428, 0.06536179914006165, 0.18878399421061787, 3.638273068836757, 10.706606013434273, 41.55785322189331, 52.06287636075701, 52.755455425807405, 52.48461464473179, 50.959846360342844, 45.57724019459316, 43.69622734614781, 46.056735379355295, 47.307126249585835, 50.95560448510306, 51.00029877253941, 55.54781484603882, 51.64428561074393, 56.428895064762656, 57.57434729167393, 50.22140918459211, 51.441328729902, 51.23676681518555, 54.06265129361834, 55.43554585320609, 50.04699550356184, 50.471196923937114, 45.51769413266863, 46.81200109209333, 45.041593142918174, 44.59073495864868, 43.451550006866455, 44.30767229625157, 49.48570612498692, 47.44545446123396, 47.860901151384624, 51.76566021783011, 49.23948975971767, 53.929072175707134, 51.47211272375924, 48.128823689052034, 45.74385799680437, 50.489891052246094, 42.4046927179609, 37.82473203114101, 35.34761585508074, 28.23546062197004, 25.694681576320104, 32.11876712526594, 25.894720213753835, 14.47226996081216, 20.509178434099468, 24.22927348954337, 38.92596244812012, 49.099219526563374, 44.48782866341727, 49.94236258098057, 52.85495015553066, 53.746515205928254, 51.59545367104666, 56.105928897857666, 52.36710671016148, 37.973128182547434, 35.16545145852225, 39.09184374128069, 51.23400490624564, 51.224510192871094, 50.687035764966694, 48.28120115825108, 44.833473750523154, 44.30805792127337, 42.17409242902483, 40.42608894620623, 42.61819349016462, 38.58752959115164, 36.72397756576538, 27.856556245258876, 21.4065226486751, 20.796194621494838, 31.211693695613317, 28.799994809286936, 27.450800555092947, 22.65954167502267, 26.235908031463623, 28.681380374091013, 28.01213162285941, 30.97641032082694, 40.885038307734895, 40.41908516202654, 46.22306830542428, 45.56700202396938, 44.12440313611712, 39.67933130264282, 44.07983044215611, 39.598579338618684, 41.5665454183306, 38.48278897149222, 43.289024693625315, 42.105569294520784, 44.85675368990217, 45.397646631513325, 49.950220993586946, 47.71376262392317, 56.11501714161464, 49.81920576095581, 67.62501730237688, 36.522702148982454, 25.11438192640032, 51.36800439017159, 50.69595030375889, 52.77000147955758, 48.63393340791975, 51.48051656995501, 48.754779951913015, 46.3916072845459, 41.03405979701451, 44.63934803009033, 50.434864793504985, 54.10842602593558, 55.9200576373509, 57.725943088531494, 59.316847801208496, 52.67325128827776, 36.337112290518625, 6.347357026168278, 0.7318949582321304, 0.18003537080117635, 4.037082731723785, 5.548536530562809, 2.2638720529420033, 67.7714922768729, 46.83791092463902, 52.177573748997276, 18.552723782403127, 10.739101869719368, 20.815573147365026, 71.39137867518834, 38.20302670342581, 24.405160188674927, 30.64260843821934, 38.5804181098938, 43.86790691103254, 56.043217931474956, 31.872172083173478, 0.6330890229770115, 0.09020864551088639, 0.3149269925696509, 0.22594551156674111, 0.15736528512622627, 0.015974973860595907, 0.043581113418830295, 0.024142606749332378, 0.011291092427979623, 0.06521032976784877, 0.04948126378336123, 0.06627884600311518, 0.0801269586331078, 0.04796187459890332, 0.22668933522488388, 0.191010837576219, 52.13077415738787, 66.20813369750977, 51.312578610011506, 33.61629499707903, 33.69661617279053, 58.572904178074424, 42.878709248134065, 34.184112208230154, 8.466335688318525, 33.28655433654785, 50.82549946648734, 63.42370564596993, 50.130259241376606, 68.98131956372941, 23.026429142270768, 1.0164839987243925, 1.1351169986384255, 0.08099755977413484, 0.2943500652909279, 2.885820073740823, 15.61103367805481, 47.57445124217442, 54.147388049534385, 57.14951358522688, 55.07388516834804, 55.59904391424996, 47.931602546146934, 47.497298445020405, 47.430616583142964, 50.31370905467442, 52.136086055210654, 55.12453406197684, 58.24137783050537, 56.3212605203901, 57.376257623944966, 56.094763142721995, 51.70116009031023, 52.4925216947283, 55.15116650717599, 56.360542161124094, 56.60075528281075, 51.25975840432303, 51.91174609320504, 47.07287120819092, 49.42298126220703, 48.55529022216797, 46.12781892504011, 46.6076545715332, 45.53227840151106, 50.533539635794504, 48.14849056516375, 50.55956758771624, 53.46637773513794, 52.22100346429007, 54.11707305908203, 54.15921040943691, 49.81351866040911, 48.994114126477925, 51.90187617710659, 46.30731521333967, 40.223284925733296, 37.7670897756304, 33.58238778795515, 32.29319470269339, 37.52515697479248, 29.536371844155447, 17.48992211478097, 27.0477112361363, 25.516196250915527, 40.75206020900181, 48.90874855858939, 44.12499025889805, 49.37255123683384, 52.354950836726594, 53.719917501722065, 53.75575631005423, 55.25406238010952, 54.31835542406355, 37.66317251750401, 35.792946747371126, 38.648142201559885, 54.83628804343087, 51.900177342551096, 53.63737290246146, 51.178144863673616, 47.27826343263899, 45.55219541277204, 43.53086716788155, 40.821351119450156, 42.519039222172324, 41.82706117630005, 38.41907051631382, 31.17036928449358, 27.506068263735088, 26.55966455595834, 37.019199575696675, 37.280896527426584, 36.584513323647634, 30.96846158163888, 30.205580643245153, 31.0991050856454, 32.11299664633614, 37.42564140047346, 42.42111478533064, 41.64419501168387, 47.407215050288606, 49.242234298161094, 48.29346472876412, 43.10946239743914, 46.60868637902396, 43.49472958700997, 43.61987359183175, 40.27185978208269, 47.44599642072405, 43.6940838268825, 46.260685852595735, 47.65821177618844, 51.11608702795846, 51.254727908543174, 57.79081147057669, 52.34785672596523, 58.46303926195417, 36.677709511348176, 26.925676550183976, 50.4016558783395, 53.36081722804478, 55.66620520183018, 48.50002425057547, 51.49341590063912, 52.940072536468506, 49.175013950892854, 45.19410957608904, 46.174483026777, 52.935347761426655, 55.44765656335013, 58.71251433236258, 60.01831708635603, 63.01875073569161, 53.20209952763149, 43.76950652258736, 7.061075985431671, 0.46308630811316626, 0.2865529108260359, 2.705923395497458, 2.242693509374346, 4.341337399823325, 71.94112014770508, 53.91344567707607, 58.25800486973354, 23.95083311625889, 13.39296805858612, 18.437828370503016, 63.82112176077706, 34.33450249263218, 34.96633693150112, 41.403099468776155, 40.69409486225673, 47.91869626726423, 65.17670835767473, 41.46399348122733, 0.45342882775834625, 0.14287075932536805, 0.15887068291859968, 0.22343969531357288, 0.08261743999485459, 0.08794233854860067, 0.1580252961388656, 0.16513498606426374, 0.17314492911100388, 0.180126905175192, 0.2530857180910451, 0.2182518879749945, 0.1553860256182296, 0.12860969028302602, 0.48216937269483295, 0.7470500650150436, 61.74203314099993, 78.65585231781006, 57.847050189971924, 52.27838168825422, 51.65810905184065, 65.311934198652, 58.6860625403268, 37.214558601379395, 14.414697187287466, 36.758659499032156, 55.09880835669381, 67.13346699305943, 52.170104435511995, 75.79340989249093, 23.74222387586321, 1.4299719482660294, 0.8085029189075742, 0.16065670922398567, 0.41514474206737106, 3.7745780519076755, 20.836883272443497, 54.0546851839338, 57.22671849387032, 59.7196626663208, 57.95823526382446, 58.97725459507534, 52.32478870664324, 52.31585332325527, 52.13548503603254, 56.50204222542899, 57.149485792432515, 59.52814252035958, 64.09242112295968, 58.647930826459614, 58.179528440747944, 60.72002261025565, 54.6866968018668, 55.539046219417024, 57.118038245609824, 57.88075590133667, 59.377311025347026, 52.55915144511631, 55.406526701790945, 49.894079548971995, 52.986403124673025, 49.894044807979036, 50.88945763451712, 49.525199685777935, 47.4652533531189, 54.39031791687012, 49.767757824489046, 53.828847885131836, 56.923856939588276, 56.472578389304026, 58.83091163635254, 56.12509202957153, 52.3165967805045, 49.94055952344622, 52.82736580712454, 50.11476823261806, 45.792429379054475, 41.52136823109218, 36.93412583214896, 35.374168395996094, 43.16678156171526, 30.63423933301653, 14.930448940822057, 27.141678673880442, 29.946148804255895, 44.79267045429775, 51.54924815041678, 45.87800339290074, 50.81670304707119, 58.08754471370152, 55.18358680180141, 53.214734826769146, 58.89287567138672, 57.01107767650059, 39.04758371625628, 36.707149028778076, 39.80650418145316, 55.8361998285566, 55.85829857417515, 57.93489279065813, 53.379789284297395, 51.82479286193848, 50.62476600919451, 47.448570728302, 40.66133757999965, 43.18353019441877, 41.83727502822876, 43.10925047738211, 37.61310379845755, 28.860758543014526, 26.095620427812847, 38.87236057009016, 38.15924610410418, 38.85442379542759, 33.07348435265677, 37.72800963265555, 37.45716190338135, 37.0557644707816, 38.29138694490705, 46.818115506853374, 45.17436974389212, 52.354009355817524, 51.719475541796, 49.10170350755964, 46.25889669145857, 48.14594752447945, 43.71668284279959, 43.38397182737078, 42.023882797786165, 48.643824168613975, 46.810100759778706, 48.26588385445731, 48.22602898733956, 54.25157976150513, 52.33055223737444, 61.78967693873814, 53.59577751159668, 64.72105244227818, 47.03487845829555, 33.191836493355886, 53.22314214706421, 58.05289057322911, 57.67155606406075, 51.47086552211216, 55.929680892399375, 57.180151666913716, 52.66550404684884, 48.76784256526402, 50.04055799756731, 60.25279099600655, 59.37485136304583, 62.142388343811035, 62.34896523611886, 68.12492629459926, 58.28490482057844, 52.3355827331543, 11.671554463250295, 0.8947721325925418, 0.2962549030780792, 8.40052843093872, 12.460845504488264, 3.181265728814261, 81.45900576455253, 58.32148361206055, 65.13789572034563, 30.91138560431344, 19.24429014750889, 29.140281098229543, 79.0900730405535, 45.65626205716814, 35.06476163864136, 49.33172014781407, 55.64069141660418, 57.87434271403721, 71.36238384246826, 54.90980345862252, 0.766201091664178, 0.3633942875478949, 0.41311423959476606, 0.22585369220801763, 0.2714556152267115, 0.12475097019757543], [0.2052366363682917, 0.07130197967801775, 0.10916785031024899, 0.05601728966991816, 0.09523596574685403, 0.02643155981786549, 0.06420325487852097, 0.014453793343688761, 0.09656559582799673, 0.051643765065819025, 36.05398709433419, 59.856979915073936, 40.895662103380474, 41.93408080509731, 44.81196560178484, 37.4218442099435, 68.44919872283936, 42.40306336539132, 1.192527140889849, 36.767980507441926, 57.53798042024885, 51.79377957752773, 38.41422414779663, 52.31605134691511, 38.08387204578945, 0.30347006448677605, 2.288068503141403, 0.09994944318064622, 0.24727251859647886, 0.07896000053733587, 1.623768606356212, 40.607624530792236, 57.83296619142805, 53.1077812058585, 56.74997826984951, 48.829761437007356, 42.51039913722447, 44.08124440056937, 44.74559988294329, 46.88928937911987, 47.79432003838675, 51.808891909463064, 52.88755805151803, 57.55113336018154, 64.94411740984235, 63.56852694920131, 50.767728669302805, 51.61573198863438, 54.58551018578665, 55.0295660836356, 53.1816405568804, 52.39374262945992, 50.75119890485491, 46.719381604875835, 44.63079827172415, 48.08376462118966, 44.12536546162197, 44.81571762902396, 44.62588936941964, 47.130673272269114, 47.39563587733677, 43.08531740733555, 48.804153851100374, 50.435695103236604, 46.463694844927105, 46.183414936065674, 46.38618768964495, 45.382079192570274, 47.298868315560476, 37.70238120215279, 37.91957146780831, 29.153682436261857, 29.857569694519043, 35.38802310398647, 43.5904792376927, 49.0214135987418, 40.24518912179129, 41.31130681719099, 29.89922067097255, 20.944033179964336, 26.792993749891007, 36.46319777624947, 45.31672443662371, 49.40413774762835, 57.78908831732613, 53.614655767168315, 56.95858751024519, 46.9957184110369, 33.88823706763131, 36.42411068507603, 38.662142821720664, 48.2997076851981, 54.810301780700684, 49.66870083127703, 51.16657611301967, 50.240044253213064, 44.770780154636924, 35.11448294775826, 30.01620749064854, 29.982710225241526, 35.72478839329311, 41.18823684964861, 52.56324045998709, 54.46658134460449, 45.63122074944632, 43.105265685490195, 40.486465317862375, 41.93038783754621, 35.814086641584126, 23.408091953822545, 21.144645043781825, 23.73044146810259, 26.828806502478464, 31.403387546539307, 40.09658799852644, 48.74348218100411, 46.77004439490182, 43.038646357400076, 42.18949658530099, 47.470527035849436, 41.809239046914236, 39.65656552995954, 39.33368274143764, 40.23714658192226, 42.57589633124215, 45.1845314843314, 45.1114433833531, 50.23546539034162, 50.92678683144705, 49.71807125636509, 51.90565947123936, 42.797641141074045, 26.298316751207622, 35.981739725385395, 46.077194350106375, 53.400772844042095, 52.43129416874477, 50.64096226011004, 47.2553517477853, 48.43600354875837, 46.12042604173933, 45.472405774252756, 43.8763871874128, 46.58971084867205, 52.26413093294416, 57.76717022487095, 55.11097812652588, 56.436562401907786, 59.76654216221401, 32.527130126953125, 0.457978187927178, 0.32826946090374676, 0.021359909192792008, 1.887081231389727, 1.9774844603879111, 17.381057739257812, 68.66368961334229, 48.183929852076936, 56.21769414629255, 32.83228458677019, 26.447131531579153, 11.123850549970355, 28.672644751412527, 38.60903426579067, 32.846083709171836, 26.527100086212158, 17.959679399217876, 39.17611149379185, 60.372897556849885, 31.452365398406982, 0.37011007432426724, 0.05114047867911203, 0.29643772755350384, 0.14964040821152075, 0.2705017849802971, 0.0792128633973854, 0.02608757988283677, 0.09084585774689913, 0.01832298661715218, 0.062858697026968, 0.06319894162671906, 0.01899099925399891, 0.06838577187487058, 0.06263417657464743, 0.14668358330215725, 0.05322088061698845, 41.53468097959246, 70.40382426125663, 44.196852002825054, 38.66070107051304, 51.44367027282715, 47.01828268596104, 87.58252961294991, 42.32845708302089, 3.2235789554459706, 39.85797643661499, 63.78708948407854, 55.44517605645316, 42.82969665527344, 56.77771895272391, 42.45912837982178, 0.7709651131715093, 2.4228168725967407, 0.3013871791107314, 0.1746395653379815, 0.05268221202173403, 1.6026656244482314, 45.06018999644688, 59.0613625390189, 56.95678097861153, 56.842990330287385, 51.089089802333284, 45.788639136723106, 47.52724865504673, 46.772806303841726, 50.498451232910156, 49.82768256323678, 54.673321519579204, 53.87313570295061, 61.33450044904436, 62.2148927961077, 57.15880332674299, 52.4970623425075, 49.44630983897618, 55.78297662734985, 58.523787362234934, 55.2301709992545, 54.71989182063511, 53.64114230019705, 48.053227288382395, 47.10165064675467, 49.384258951459614, 44.31834125518799, 45.24503639766148, 46.9698155266898, 49.64475039073399, 48.04824890409197, 45.61157471793038, 51.92202247892107, 53.8799866267613, 50.74394498552595, 50.23151533944266, 48.23936952863421, 47.13450867789132, 48.39615215573992, 41.83626059123448, 43.591247013636995, 39.84765836170742, 41.42881127766201, 45.994691440037315, 46.664011410304475, 54.53502804892403, 46.76301976612636, 46.48218400137765, 39.29317126955305, 25.01921418734959, 29.50652585710798, 37.780110699789866, 47.145827293395996, 48.335206031799316, 54.45713526862008, 53.27430868148804, 53.9464704649789, 45.15707220349993, 35.123550346919465, 36.06693506240845, 40.18351343699864, 50.857614040374756, 56.59637444359915, 51.866388252803254, 52.887394768851145, 50.62424142020089, 45.231338024139404, 38.27105304173061, 36.20704896109444, 37.27218001229422, 39.56909465789795, 44.95494910648891, 58.08919838496617, 57.8200147492545, 49.91132150377546, 45.245488030569895, 45.80336931773594, 49.388476508004324, 49.53732081821987, 41.67429460797991, 31.504650592803955, 27.010262182780675, 29.522277423313685, 35.89858715874808, 43.800714356558665, 49.53992291859218, 51.30410180773054, 45.304346220833914, 47.52690124511719, 50.73992197854178, 43.96338210787092, 42.812406063079834, 40.984897817884175, 42.44030223573957, 45.38972568511963, 46.398472104753765, 48.95314407348633, 53.83766862324306, 53.20098434175764, 52.701450552259175, 54.99108001164028, 41.39736025674002, 29.179418563842773, 37.81964594977242, 48.14992536817278, 55.56265272412981, 53.143217018672395, 54.42365189961025, 49.96562514986311, 49.7519610949925, 49.48327078138079, 48.183738776615684, 47.441771915980745, 48.889950207301546, 53.902363300323486, 58.466172899518696, 57.92824683870588, 58.47612271990095, 62.890625953674316, 37.91999878202166, 0.5285859448569161, 0.2849927959697587, 0.10773719315017972, 3.627590213503156, 1.0018094033002853, 21.600003923688615, 71.37498787471226, 53.97898803438459, 62.60591656821114, 42.7589362008231, 32.27960402624947, 16.193212815693446, 35.102344444819856, 41.24169281550816, 42.88622719900948, 33.03106907435826, 18.47571689741952, 44.10754680633545, 69.21477208818708, 42.615330832345144, 0.11462654918432236, 0.019418681572590555, 0.027801759507773176, 0.05750952049025467, 0.1836633618388857, 0.16193771548569202, 0.38019459747842377, 0.1360456876988922, 0.25853378432137625, 0.21067075191863946, 0.23978569890771592, 0.08196742380303995, 0.1964429175215108, 0.17455324211290904, 0.28846361115574837, 0.1194424107670784, 50.18377774102347, 79.76707771846226, 56.35446943555559, 58.06184680121285, 63.911740166800364, 49.780459131513325, 70.52706445966447, 50.50833504540579, 6.650508667741503, 46.031909465789795, 67.33946023668561, 61.94044589996338, 48.862414496285574, 63.22854464394705, 45.65519550868443, 0.9326053453343255, 3.7638226747512817, 0.4991296540413584, 0.3437120222619602, 0.2131140615258898, 3.0156380449022566, 51.595738547188894, 62.906891686575754, 61.922297205243794, 61.702643803187776, 56.585976464407786, 48.899246897016255, 52.65653044836861, 51.79534292221069, 57.40232726505825, 55.109602383204866, 60.62743091583252, 54.374767848423545, 63.04244409288679, 66.66654804774693, 62.51650020054409, 55.29483093534197, 52.648540019989014, 57.80318968636649, 59.1596656526838, 58.261548451014924, 59.110819816589355, 55.65013401848929, 52.186835697719026, 53.171548298427034, 51.59945930753435, 48.47406578063965, 49.46395478929792, 50.26655510493687, 50.94981663567679, 50.83566468102591, 50.695731435503276, 56.827082429613384, 60.25470869881766, 55.6817170551845, 54.74984550476074, 50.10530478613717, 51.44922535760062, 53.883874143872944, 50.564942019326345, 46.62582063674927, 42.29473400115967, 42.84051152638027, 49.626500947134836, 51.20522894178118, 50.25127254213606, 41.85863726479666, 42.121727330344065, 37.69949769973755, 32.703881876809255, 33.473648480006624, 41.43515845707485, 48.57998411996024, 47.632475648607524, 57.525755064828054, 55.8026886667524, 53.55807311194283, 49.312741143362864, 34.67662136895316, 37.73976251057216, 42.49505056653704, 53.47308274677822, 61.18348135266985, 58.68534687587193, 56.668708665030344, 54.23774937220982, 46.66298655101231, 37.31730508804321, 37.869891847882954, 43.386778899601524, 47.371164321899414, 51.63079220908028, 55.250261715480256, 50.61299576078142, 43.74448605946132, 49.82939876828875, 46.09291812351772, 46.58733803885323, 45.40515763419015, 40.652231965746196, 35.2863118989127, 34.24897016797747, 35.272905349731445, 39.84319761821202, 44.97825683866228, 51.744200706481934, 52.34223910740444, 48.50006941386631, 47.75793579646519, 52.98852232524327, 46.5610008920942, 44.41115876606533, 42.96647194453648, 46.54231718608311, 46.78142901829311, 50.488021986825125, 51.14542927060808, 56.36853953770229, 54.24692446844918, 56.97500957761492, 54.156743798937114, 51.84221199580601, 32.599589415958945, 35.3741579736982, 50.32040364401681, 57.58742380142212, 53.99082776478359, 54.532776832580566, 51.1800799369812, 52.483409132276265, 52.03172063827515, 52.69751787185669, 52.459302357264924, 53.21673590796334, 58.47560855320522, 62.56288637433733, 59.83324486868722, 61.36099393027169, 65.38520990099225, 42.526234081813264, 1.502161668879645, 0.4494855893509728, 0.2763294508414609, 7.485175354140146, 5.926290546144758, 20.75520372390747, 77.38200432913644, 57.27535588400704, 71.76182188306535, 45.81690788269043, 33.452967166900635, 21.8136818749564, 39.53279032026018, 44.53805719103132, 50.117307799203054, 40.70537873676845, 27.150150265012467, 54.700297900608604, 74.13480540684291, 54.24876921517508, 0.47437012834208353, 0.10128095280379057, 0.42212760022708345, 0.28539239881294115, 0.3760174001966204, 0.21507658836032661], [0.20065287447401456, 0.11744500723268304, 0.2125460598617792, 0.19512718383755, 0.3049880016062941, 0.12821908481419086, 0.29171762083257946, 0.08692037660096373, 0.12538808743868554, 0.7764729719076837, 23.65986340386527, 58.15848582131522, 41.92167132241385, 27.15933230945042, 17.595887354442052, 44.086191517966135, 21.36675637108939, 34.181044578552246, 5.0709225705691745, 29.936042649405344, 59.45806993756975, 56.73597070149013, 59.02254295349121, 48.88682699203491, 54.60395417894636, 2.1795856271471297, 5.420044362545013, 0.5641242978828294, 0.10108420478978328, 0.35106202214956284, 0.41085450085146086, 42.22103098460606, 66.89296899523053, 52.12612928662981, 52.65804862976074, 46.864234175000874, 39.9374429838998, 41.07898684910366, 43.614957741328645, 45.78117329733712, 48.13113396508353, 48.71051645278931, 58.35260459354946, 54.92405768803188, 67.07994501931327, 71.2888719013759, 44.52342081069946, 43.129810197012766, 45.05133104324341, 55.9108373778207, 53.82847615650722, 55.48972790581839, 49.76770918709891, 46.9787335395813, 44.64200224195208, 46.54023620060512, 40.357527596609934, 44.762188707079204, 41.43486663273403, 41.69403444017683, 45.21845606395176, 41.984000137874055, 42.87569720404488, 50.70058822631836, 49.56622185025896, 51.12222923551287, 52.20278181348528, 46.570638043539866, 39.96756342479161, 38.45310626711164, 46.66709988457816, 51.64313220977783, 70.13504014696393, 51.29242535999843, 45.83949300221035, 50.20967367717198, 55.47301401410784, 65.87136840820312, 65.62608310154506, 52.0746431350708, 30.048186574663433, 21.081352165767125, 24.6812972341265, 34.43466077532087, 45.26055172511509, 48.93723617281233, 52.73332888739449, 46.4840669631958, 39.931693349565776, 34.93266248703003, 36.488145283290315, 48.87476144518171, 53.21896627971104, 55.27195399148123, 49.56608983448574, 32.63056101117815, 24.294485807418823, 26.80012607574463, 39.09873635428292, 47.94483191626412, 55.96460253851754, 56.22190475463867, 55.777393749782014, 51.33074467522757, 53.533730098179404, 43.379285267421174, 51.61401925768171, 56.983152866363525, 62.826653889247346, 60.728520257132395, 48.15691525595528, 25.748641286577495, 22.099509920392716, 22.121049336024694, 32.33060727800642, 35.16216843468802, 46.87259285790579, 45.267319270542686, 43.44447674070086, 44.880089214869905, 42.89063235691616, 39.42241471154349, 39.80847746985299, 38.227453095572336, 42.021516936165945, 41.542438643319265, 44.09856973375593, 47.683301721300396, 51.166833196367534, 51.81891468593052, 56.21889271054949, 31.736765589032853, 36.74718802315848, 46.342452253614155, 49.588219846997944, 52.52669293539864, 52.585255827222554, 52.83839954648699, 48.89047827039446, 49.88272966657366, 46.71482358660017, 48.646648611341206, 46.6251814024789, 45.543312140873496, 48.86659036363874, 51.64691202981131, 55.06583915437971, 53.835382665906636, 65.04126712254116, 24.874224390302384, 0.6747893967798778, 0.5893401248114449, 0.17031987570226192, 0.4535445858325277, 0.08101342392287084, 34.24751104627337, 61.813099316188264, 53.23895277295794, 60.73890086582729, 47.80770574297224, 33.07574251719883, 12.455258284296308, 16.603272914886475, 20.664230959756033, 38.39535631452288, 37.52853032520839, 41.841197286333355, 38.79040309361049, 60.00335761478969, 29.22308451788766, 0.5096810364297458, 0.055132934624063115, 0.038470387658370395, 0.07508494811398642, 0.10373339549239192, 0.10385367939514772, 0.15077623512063706, 0.12209093650536877, 0.18713590050382273, 0.12006759936256067, 0.2774093257529395, 0.08006881496735982, 0.11534068015004907, 0.12168549826102597, 0.16356705448457173, 0.6582087693469865, 28.079331125531876, 68.41844599587577, 45.13598789487566, 27.62065100669861, 30.680104391915457, 48.50380059650966, 32.03804990223476, 38.42306573050362, 7.503546391214643, 35.608270577022004, 62.56065600258963, 59.48130471365792, 57.18999031611851, 53.62574856621878, 59.673290388924734, 3.6531283174242293, 2.228645988873073, 0.7387635782361031, 0.1987176247473274, 0.1811725954924311, 0.7156928447740418, 46.48596034731184, 69.15759536198208, 55.067610945020405, 54.611228942871094, 49.522670541490825, 44.985753944941926, 47.32066828863961, 47.85996314457485, 50.447684219905305, 49.94755983352661, 51.909383705684114, 61.18339102608817, 56.0290401322501, 63.4583215713501, 59.44287422725132, 42.91752188546317, 42.514442988804404, 46.42007752827236, 59.31096962520054, 55.576083592006135, 56.20038618360247, 50.27968372617449, 48.68665633882795, 47.0298444884164, 48.61605569294521, 42.43034546715872, 46.93719720840454, 44.51386703763689, 45.20301021848406, 48.208727972848074, 45.772116320473806, 47.139514854976106, 51.788835934230256, 53.361362661634175, 53.51946544647217, 52.697754110608784, 49.2672895022801, 42.74260793413435, 46.051899433135986, 55.56351082665579, 62.496947969709126, 73.65830489567348, 55.52294029508318, 48.53903143746512, 50.80636412756783, 62.42061505998884, 68.16314833504813, 70.49088518960136, 60.27080767495291, 37.07836348669869, 24.052509580339702, 27.10291119984218, 38.87743970326015, 46.88500234058925, 51.35449709211077, 53.85782882145473, 45.37092733383179, 35.94565773010254, 34.491542203085764, 37.259388378688264, 50.275299412863596, 56.871512685503276, 59.820460183279856, 55.91271686553955, 37.493191787174766, 29.300751481737407, 32.85137128829956, 41.255599634987966, 49.60827234813145, 58.802180835178916, 57.476534026009695, 59.135291372026714, 53.86833797182356, 57.05960389545986, 46.59623868124825, 53.01536669049944, 58.05670166015625, 64.62384714399064, 70.5537941796439, 62.97605405535017, 47.90230546678816, 35.26493229184832, 28.98522162437439, 35.60316365105765, 40.63167919431414, 49.45065941129412, 50.09466361999512, 48.90070949281965, 48.89039489201137, 44.24110507965088, 42.28205353873116, 41.465897287641255, 40.35528332846505, 44.85483946119036, 44.0034419468471, 47.715089729854036, 50.98112869262695, 52.899373463221956, 54.36986242021833, 56.798184871673584, 32.61183214187622, 37.905282497406006, 48.52018444878714, 53.94005380358015, 53.3440477507455, 54.25751352310181, 52.911174978528706, 49.843159675598145, 50.30005237034389, 48.081096512930735, 48.56917272295271, 47.064686230250764, 48.159249850681846, 52.54915298734392, 53.603267669677734, 59.88009657178606, 57.99663100923811, 66.60780797685895, 26.881652763911656, 0.8136449115616935, 0.2336126315806593, 0.36243171777044025, 1.597805033837046, 0.42001958191394806, 38.71782915932791, 67.4544598715646, 56.28898613793509, 68.85681479317802, 57.321839332580566, 41.61907727377755, 14.585086992808751, 26.485971961702617, 20.379038674490793, 41.06732429776873, 40.04053340639387, 38.302674293518066, 44.91842590059553, 68.88840130397251, 36.96317972455706, 0.4713657924107143, 0.09569080812590462, 0.08316019337092127, 0.039947907839502604, 0.024360279086977243, 0.039679004411612234, 0.13476157374680042, 0.2321967732693468, 0.2408600098320416, 0.20658926878656658, 0.4612492152622768, 0.3862561950726168, 0.4782732789005552, 0.19941578299871512, 0.42698810941406656, 1.1273477183920997, 34.349837166922434, 78.74678339276994, 55.63963181631905, 42.72047792162214, 27.787320920399257, 64.83181367601667, 24.98065342221941, 41.03670358657837, 11.828627177647181, 38.71033205304827, 69.71619578770229, 66.66711780003139, 65.99576200757707, 58.52637904030936, 64.51041085379464, 3.48802587389946, 12.258288145065308, 2.417590741600309, 0.30867255532315796, 0.615895542715277, 1.9302087000438144, 49.98663650240217, 71.26821490696499, 57.455713748931885, 58.424580982753206, 53.26465763364519, 47.25698110035488, 50.53771897724697, 49.78336347852434, 52.370361941201345, 53.51064123426165, 56.35883290427071, 68.12736511230469, 59.87712969098772, 70.39757783072335, 64.7491648537772, 45.40270144598824, 44.087956360408235, 50.167981011526926, 62.738842555454795, 59.40028871808733, 60.60057612827846, 55.89088562556675, 53.47831474031721, 51.06692852292742, 52.779527459825786, 45.840750626155305, 51.12413304192679, 46.05829177583967, 46.732339995247976, 50.34932204655239, 46.779726709638325, 49.78922775813511, 56.39400121143886, 55.908930097307476, 56.093467303684776, 56.488097190856934, 57.03175204140799, 46.933365276881624, 49.102888175419395, 54.77296216147286, 61.26027979169573, 69.65987368992397, 61.478189195905415, 53.91491869517735, 55.59965188162667, 57.991249629429404, 57.958485398973735, 59.61040224347796, 55.19139657701765, 42.86051191602434, 34.53310285295759, 32.389052050454275, 40.922794818878174, 46.81906393596104, 52.03358275549752, 54.87560442515782, 48.17031833103725, 37.19193526676723, 35.42931972231184, 38.26092951638358, 54.614195823669434, 61.12478297097342, 63.94716208321707, 54.6246771812439, 36.506815092904226, 34.73220348358154, 41.22273465565273, 45.67056144986834, 50.3251770564488, 51.588251863207134, 53.232143538338796, 55.184111390795024, 51.75850704738072, 58.866701807294575, 50.526035581316265, 54.3765743800572, 55.96432113647461, 56.32346657344273, 61.060755320957725, 55.655181884765625, 46.93012046813965, 41.3764704976763, 33.82548788615635, 42.54486567633492, 44.95161049706595, 49.06446116311209, 50.71248354230608, 47.97778722218105, 49.75381278991699, 46.08898891721453, 45.024813243321006, 43.89474432809012, 43.261249269757954, 46.21746110916138, 46.72299466814314, 48.94344786235264, 51.17682818004063, 54.53333963666643, 56.348007610866, 55.82554824011666, 37.89753178187779, 38.37708255222866, 48.1512906891959, 54.54801075799124, 56.264886311122346, 57.40902532849993, 56.53450768334525, 51.526923588344026, 51.866030420575825, 50.13063791819981, 52.995185647692, 49.06608009338379, 52.565884249550955, 55.84879343850272, 55.7357497215271, 62.424040521894185, 61.37785720825195, 68.1239674431937, 32.09311785016741, 0.9840291802372251, 0.5607685350946018, 0.4728960788675717, 2.96716154898916, 0.6526596556816782, 43.041846002851216, 71.06962844303676, 63.008620262145996, 71.1775826045445, 59.48757893698556, 45.35748256955828, 25.803653648921422, 25.29668528693063, 25.993101494652883, 56.953678607940674, 51.7396114213126, 57.198328154427664, 52.13791690553938, 78.79681737082345, 49.49539886202131, 0.5751553773880005, 0.14223604409822396, 0.16838297035012925, 0.11561243342501776, 0.10467318684927054, 0.10555699906711068], [0.13924447819590569, 0.11528167474482741, 0.11505520689700331, 0.17212848365306854, 0.31802249646612574, 0.08552699136946883, 0.19422964485628263, 0.05616834174309458, 0.12745392801506178, 0.13410540324236664, 16.66767750467573, 68.97630991254533, 38.722779750823975, 36.55579989297049, 21.80354619026184, 41.63076066970825, 30.210048334939138, 13.989476987293788, 8.573720097541809, 35.558253969464985, 57.328662463596885, 53.18543079921177, 57.484851019723074, 48.79318611962454, 56.04408993039812, 9.117134366716657, 1.2305034973791666, 0.5414513487901006, 0.08950508612075023, 0.43812137629304615, 0.07870018269334521, 29.17200483594622, 64.35277707236153, 53.51297582898821, 55.32199491773333, 49.11145530428205, 45.470696517399375, 47.16027954646519, 49.02504750660488, 48.87888520104544, 47.797676018306184, 54.05696766717093, 47.49652719497681, 50.644106319972444, 45.39709077562605, 55.51230607713972, 52.85183736256191, 40.739397117069785, 45.53944199425833, 55.408149106161936, 57.88500819887434, 54.03300680433001, 49.78633383342198, 43.85470185961042, 43.01414353506905, 42.05582366670881, 41.61591236931937, 41.81017705372402, 43.68630184446062, 44.63075658253261, 43.74153307506016, 46.594647543770925, 49.08119589941842, 47.93206460135323, 49.72798980985369, 53.40109593527657, 53.154990741184776, 49.5679588999067, 47.030164105551584, 66.19256278446743, 63.80501583644322, 60.94998019082205, 60.65921197618757, 52.29357392447335, 49.32652636936733, 54.68094369343349, 48.37550558362688, 50.703259808676584, 55.80766705104283, 65.79127652304513, 70.24653788975307, 53.46589136123657, 29.183375562940324, 20.53216133798872, 26.34616378375462, 40.27986758095877, 46.98467077527727, 44.99946621486119, 45.00244351795742, 44.26780700683594, 44.94191428593227, 48.52150808061872, 50.6857190813337, 37.798665864127024, 22.757592916488647, 26.661672796521867, 42.98888335909162, 55.98622533253261, 55.49555049623762, 55.10555158342634, 53.67610910960606, 51.5945017678397, 44.73155409949166, 41.997531754629954, 40.66805648803711, 41.37547690527779, 47.12327344076974, 43.975510188511436, 48.47275257110596, 58.471675872802734, 59.50744383675711, 68.94216646466936, 57.28698022024972, 30.509866578238352, 25.6161721433912, 32.75145966666085, 38.96648781640189, 43.92627872739519, 46.97425195149013, 44.397641045706614, 41.161142349243164, 40.45012971333095, 40.150266306740896, 38.14744111469814, 43.51261077608381, 42.895329339163645, 47.168745926448274, 50.86504513876778, 50.47055768966675, 51.46702316829136, 53.64212547029768, 39.63974394117083, 44.19209943498884, 54.709782191685264, 51.72744165148054, 51.46725593294416, 52.15276173182896, 49.124688148498535, 46.88192081451416, 47.12888758523123, 50.48383569717407, 49.926690919058665, 49.54979978288923, 47.390664441244944, 50.5127853666033, 50.46258463178362, 55.50788354873657, 53.20315217971802, 62.92891747610909, 15.654345273971558, 0.5497547718031066, 0.246571917619024, 0.9388347310679299, 1.285711060677256, 1.1758095579487937, 51.073432036808555, 52.99030801228115, 56.88857398714338, 40.988146100725444, 44.96744196755545, 38.16441903795515, 8.352506824902125, 11.14064347743988, 23.675522906439646, 46.770231996263774, 27.773631232125418, 26.297099079404557, 40.488400391169954, 64.38965811048234, 16.911835466112407, 0.7251010313630104, 0.04667028319090605, 0.2707799029137407, 0.3144479197050844, 0.11563884200794355, 0.012105882367385285, 0.16052040510943957, 0.036553661937692335, 0.032923865996833356, 0.09487016073295049, 0.10408047293978077, 0.04799266991072467, 0.10637718505625214, 0.05564558818670256, 0.11931951450450079, 0.08776835538446903, 20.34304700578962, 76.8201243536813, 43.90821688515799, 38.182998520987375, 31.908504213605607, 50.98097930635725, 27.227256161826, 20.212511198861257, 10.227169888360159, 43.91359479086739, 64.63092041015625, 58.989935057503835, 61.30930628095354, 53.4475793838501, 59.18658297402518, 11.406868049076625, 2.5690449689115797, 0.6384059691003391, 0.1590230818837881, 0.07786097058228084, 0.2921992449888161, 31.590995856693812, 66.00201538630894, 57.099232946123394, 57.71883160727364, 53.03577702386038, 46.89537252698626, 48.84427622386387, 53.77708380562918, 55.33319888796125, 55.481372697012766, 60.11700929914202, 51.475197723933626, 55.86147390093122, 46.46691533497402, 49.428626673562185, 43.851967743464876, 37.04018313544137, 46.67280435562134, 56.70564528873989, 58.73071166447231, 53.64223664147513, 51.67100143432617, 45.03961638041905, 45.557802609034944, 46.67015361785889, 43.013108253479004, 42.87074661254883, 46.890077999659944, 48.614499296460835, 46.035998480660574, 48.70789350782122, 50.58677325929914, 50.57960271835327, 52.07893017360142, 55.571487358638215, 55.47484139033726, 56.921814169202534, 62.375048773629324, 80.50179413386753, 72.94400923592704, 60.59100151062012, 55.41316223144531, 47.71720198222569, 50.33642618996756, 54.836569445473806, 47.62839010783604, 54.20375531060355, 56.7632771219526, 68.82250458853585, 79.90263707297188, 63.455993924822124, 35.03046533039638, 22.738289083753312, 31.513179506574357, 43.0177982875279, 47.853108746664866, 43.86180639266968, 45.19631562914167, 43.345854009900776, 42.867098808288574, 46.64674513680594, 54.13720546449934, 43.330442905426025, 27.414072377341135, 28.82530014855521, 45.220130579812185, 55.83286816733224, 55.63935388837542, 51.4246426309858, 51.16161509922573, 51.60251998901367, 48.44995205742972, 46.415450028010774, 45.07776893888201, 45.258668763296946, 48.284817695617676, 44.49577740260533, 45.83248226983206, 53.425015108925955, 60.74927452632359, 79.05447741917202, 75.95392717633928, 56.278021880558555, 42.15406424658639, 38.537881238119944, 43.0825902393886, 49.00665215083531, 51.11800125667027, 48.691923073359895, 44.012050764901296, 42.76058292388916, 42.05267265864781, 42.53140006746565, 46.73659576688494, 45.74002953938076, 50.90545586177281, 54.402202810559956, 55.51038490022932, 53.16155678885323, 54.43247958592006, 42.12137297221592, 42.564695835113525, 58.52845655168806, 53.80096476418631, 56.13044909068516, 54.10219349179949, 51.66159009933472, 49.64744281768799, 47.45320865086147, 50.01785823277065, 49.964687143053325, 48.27741091591971, 46.36043766566685, 52.13534607206072, 51.39621755055019, 58.841326986040386, 54.74976907457624, 66.25823020935059, 15.6279490675245, 0.5194660542266709, 0.11253099555947951, 2.049655399152211, 3.118296810558864, 1.9351536461285181, 58.29594898223877, 57.07730443137032, 62.869829995291575, 48.21298374448504, 49.95652995790754, 40.99634150096348, 13.654632874897548, 21.682565893445695, 24.11025432177952, 52.507623604365754, 37.127271856580464, 26.002354758126394, 46.39251055036272, 73.3673004422869, 24.39304253033229, 0.7100199120385307, 0.12100810318120889, 0.17114999544407639, 0.15723792410322598, 0.021856754585834484, 0.07561117916234902, 0.4847786383969443, 0.22507736672248158, 0.163477664281215, 0.3131602502294949, 0.37547788343259264, 0.12256937154701777, 0.2818533772868769, 0.33455359084265573, 0.3032995622072901, 0.3684048615396023, 22.71670276778085, 91.58294105529785, 48.05535691125052, 52.767100606645855, 34.41260371889387, 60.83956636701311, 38.919844559260774, 19.50305495943342, 19.029465743473597, 48.816445214407786, 70.74020739964077, 64.81714602879116, 67.27550901685441, 57.65935155323574, 62.99699592590332, 11.489748767444066, 5.912497937679291, 1.650280000908034, 0.3423472169254507, 0.7335984611085483, 0.9783661812543869, 36.220848083496094, 66.74372168949672, 58.67446599687849, 61.21710368565151, 55.42929594857352, 51.32224702835083, 52.828817980630056, 57.45367445264544, 56.80782202311924, 57.406774112156455, 61.67313480377197, 52.94836173738752, 54.36962965556553, 57.0179876599993, 61.32143088749477, 42.052954060690745, 37.97160652705601, 46.49322121483939, 61.65839767456055, 61.08409432002476, 58.23037188393729, 54.86755493709019, 50.584938934871126, 48.754832063402446, 48.23431124005999, 46.25227505820138, 46.9832672391619, 48.37098230634417, 52.51717390332903, 47.95911741256714, 51.29868221282959, 53.08501195907593, 53.733421325683594, 54.653797081538606, 56.96829761777605, 59.526759828839985, 61.51445879255022, 63.88030651637486, 76.68150779179165, 66.23086820329938, 57.96757016863142, 58.54009478432791, 54.24711901800973, 56.13104663576399, 58.16170283726284, 56.15296472821917, 58.45119258335659, 51.58089372089931, 58.35366766793387, 67.4790425981794, 64.96465628487724, 50.16084173747471, 33.286523069654194, 36.81895249230521, 44.16101666859218, 46.73822859355381, 46.174677576337544, 46.94777584075928, 47.4727817262922, 45.78803811754499, 48.316984380994526, 54.79432092394148, 41.952660288129536, 31.840898241315568, 41.05055482046944, 50.342227935791016, 54.853908675057546, 48.027320929935996, 49.53622300284249, 58.61774090358189, 56.45187275750296, 48.52795600891113, 50.82008681978498, 48.104258332933696, 51.55448361805507, 49.18054819107056, 46.2525703566415, 49.73192596435547, 52.46423557826451, 54.87474284853254, 68.59587519509452, 65.63798536573137, 52.211515699114116, 45.84409270967756, 46.967977728162495, 47.95963157926287, 48.131259032658164, 49.97007894515991, 49.44472564969744, 44.55254418509347, 43.93177475248064, 45.14293609346662, 43.32118443080357, 49.23077324458531, 47.48936012813023, 52.29976824351719, 58.1510443006243, 56.19975389753069, 56.73594985689436, 56.87797451019287, 41.727080072675435, 43.598879609789165, 56.51592820031302, 54.408779280526296, 57.38861152103969, 56.7638190814427, 52.34039783477783, 50.32545151029314, 48.9587790625436, 54.352248736790244, 52.1862416267395, 55.13562338692801, 51.24159581320626, 53.927342074257986, 54.034743853977744, 61.30232334136963, 57.63278859002249, 68.8754984991891, 20.368404456547328, 0.5476569043738502, 0.6009684236986297, 2.0325393804482053, 6.210377633571625, 2.147025282893862, 61.98845100402832, 63.91932759966169, 68.50238023485456, 53.47582728522164, 56.54625708716256, 48.57882029669625, 21.287512166159495, 18.077699763434275, 31.274849346705846, 67.65998063768659, 43.28794424874442, 38.251094341278076, 52.66429853439331, 82.56359563555036, 37.61928769520351, 0.8164137687001909, 0.23443284471120152, 0.18358685023018292, 0.2498513859297548, 0.17645559646189213, 0.13749442781720841], [0.1263258092637573, 0.05983209836163691, 0.15750104641275747, 0.0769507090694138, 0.06834034395537206, 0.2282628986452307, 0.07176793646067381, 0.011285209529367941, 0.17963464158986295, 0.049685434970472536, 10.29818742615836, 71.54138333456856, 40.37148652757917, 41.575744833265034, 21.306053434099468, 39.54432085582188, 36.47215747833252, 30.654795578547887, 6.459256895950862, 23.580231836863927, 63.201335498264854, 52.61414296286446, 58.1353691646031, 46.98648425510952, 60.3765036719186, 27.49946400097438, 0.5843566922204835, 0.0014584988301586626, 0.12361531970756394, 0.09664689789393119, 0.440895960267101, 15.288300275802612, 59.42120279584612, 52.88334744317191, 59.449162346976145, 54.41279533931187, 47.18431683949062, 45.363190514700754, 51.90399885177612, 53.966488225119456, 55.26322705405099, 57.87169892447335, 58.61876923697335, 43.75893483843122, 42.345014640263145, 22.268231289727346, 56.33500058310372, 51.88242816925049, 38.83115080424717, 51.30938938685826, 54.43663460867745, 53.9706779888698, 50.184521198272705, 46.7028032030378, 42.99886097226824, 46.70201458249773, 41.06793226514544, 44.0616956438337, 44.86883313315255, 47.71863331113543, 46.29054226194109, 45.75341524396624, 46.741702692849294, 46.50731563568115, 47.629140513283865, 49.95384447915213, 51.56946740831648, 57.44504826409476, 74.46635259900773, 64.49564593178886, 51.68943500518799, 49.87923124858311, 52.94842079707554, 51.02447502953665, 54.044387953622, 51.33237055369786, 54.50255911690848, 51.09869221278599, 47.703058923993794, 48.45731714793614, 54.00074284417288, 67.24571514129639, 69.1840818950108, 40.41044160297939, 22.01148840359279, 24.270318235669816, 38.90534366880144, 39.88129806518555, 41.425128732408794, 41.470236437661306, 40.713476862226216, 41.1223019191197, 26.738665785108292, 19.056652307510376, 37.47562674113682, 54.848770482199534, 54.10807861600603, 46.763714585985454, 46.229172297886436, 48.05585023335048, 44.77186407361712, 42.600572858537944, 50.29163115365164, 51.06392690113613, 43.54217536108834, 53.17016908100673, 53.65454190117972, 52.455942903246196, 48.39857707704817, 47.50668546131679, 45.012928349631174, 49.94968945639474, 64.05918094090053, 70.23203699929374, 55.730677536555696, 44.51047631672451, 43.766070638384136, 41.89280155726841, 43.15844372340611, 43.129601751055034, 42.85098940985543, 41.819484165736604, 40.57246664592198, 39.58712175914219, 43.146565777914866, 40.582576274871826, 51.55973993028913, 51.08805104664394, 51.565479142325266, 54.55307946886335, 54.301193373543875, 47.27606085368565, 44.603283405303955, 54.57530675615583, 54.936355999537874, 51.45133760997227, 51.13208872931344, 48.62263216291155, 48.33235032217843, 49.44913080760411, 49.58765704291207, 48.32856355394636, 47.26492983954293, 44.03271818161011, 50.66221679959978, 52.36474084854126, 59.52942793709891, 52.03502450670515, 60.75153269086565, 6.373785802296229, 0.2912183276244572, 0.048912139143794775, 0.7135524739112172, 1.217529799257006, 5.886201177324567, 64.07768399374825, 50.380780015672954, 58.28748607635498, 27.382590089525493, 68.71539115905762, 31.168392521994456, 3.8952825920922414, 23.417977503367833, 32.363121373312815, 47.638332980019705, 33.500763825007844, 36.28702967507498, 45.533692359924316, 63.586251803806846, 7.5746820483888895, 0.6843477295977729, 0.1125221678188869, 0.13247349938111647, 0.14013067207166127, 0.0908670076834304, 0.09990347243313279, 0.012160133786632546, 0.0355531824087458, 0.09747681407524006, 0.04131213981392128, 0.04014510029394712, 0.15188498848250934, 0.04237908184794443, 0.10357948339411191, 0.37756964404668125, 0.0910289129242301, 10.294644713401794, 76.98319857461112, 47.124027320316856, 36.50960826873779, 26.832341398511613, 48.047832012176514, 27.655032430376323, 28.610904795782908, 9.259199840681893, 23.60005157334464, 71.10793386186872, 61.36860915592739, 61.88686139242989, 56.159086091177805, 62.487255232674734, 29.04187897273472, 0.7748200606022562, 0.09645437715309006, 0.15687079594603606, 0.10599704259740454, 0.9832366513354438, 20.18517698560442, 63.25572599683489, 58.83340603964669, 60.785877636500764, 53.61476346424648, 48.156692913600374, 47.28112609045846, 55.946617126464844, 58.30057648250035, 58.26610994338989, 60.53422083173479, 63.29141194479806, 48.408290658678325, 44.082046917506624, 21.66985763822283, 51.58686917168753, 47.4331179346357, 40.435760838644846, 52.25418111256191, 55.02716548102242, 53.837223938533235, 51.72388069970267, 47.13809394836426, 43.62560238157, 47.54519237790789, 43.72512837818691, 46.02555881227766, 45.69229541506086, 46.170268944331575, 49.77754783630371, 45.43536145346505, 46.982683590480256, 46.34521416255406, 48.92033467973982, 52.29303196498326, 60.083512033735005, 70.49969550541469, 79.29967934744698, 65.05813734872001, 50.272596563611714, 48.38228007725307, 52.721871307918, 49.56531858444214, 51.793981075286865, 52.37514230183193, 58.880257742745535, 53.21199376242501, 47.21420798982893, 50.45079353877476, 56.288621357509065, 73.95328371865409, 78.94610636574882, 47.47344527925764, 23.050852060317993, 28.359862906592234, 41.680002553122385, 41.17125197819301, 41.99244219916207, 41.545252663748606, 41.82873569216047, 42.003962312425884, 32.69869157246181, 22.814802646636963, 37.27099534443447, 56.36241817474365, 55.37630898611886, 48.99888406481062, 46.3348057610648, 50.21181372233799, 49.50463301794869, 48.61658375603812, 55.40004055840628, 54.312529359545024, 48.93837915148054, 53.810813835689, 55.16118928364345, 54.238030774252756, 49.17435734612601, 47.636575085776194, 44.985872064317974, 47.83788871765137, 64.5676223209926, 77.0250267301287, 76.30609662192208, 64.03092956542969, 50.1900589125497, 46.34366471426827, 47.66637590953282, 47.377518449510845, 48.99133137294224, 46.11616332190377, 43.15359040669033, 41.27952575683594, 44.8212171282087, 43.42717572620937, 51.977128641945974, 52.20550203323364, 54.40584019252232, 56.53295128686087, 58.12655537469046, 49.1536864553179, 43.567769050598145, 54.8089816229684, 57.180648463112966, 53.595628125326975, 51.24148464202881, 50.80910519191197, 49.369500977652415, 52.348596709115164, 50.37131309509277, 48.43575341360909, 48.36764022282192, 44.25760357720511, 50.78730174473354, 52.4900655065264, 61.51262446812221, 54.351873534066335, 63.55556855882917, 8.197380474635533, 0.373833847365209, 0.04668778260903699, 1.704815325992448, 1.4090469053813388, 6.665769951684134, 68.98546763828823, 55.014109815870015, 64.87603896004813, 30.378465720585414, 70.37760870797294, 28.762304306030273, 9.910933920315333, 28.050727128982544, 38.996903555733816, 61.10625907352993, 40.26896585736956, 32.69541549682617, 51.770767143794465, 70.42209107535226, 10.069258178983416, 0.7003632187843323, 0.09142527915537357, 0.10037006025335618, 0.25101102941802567, 0.051617536294673166, 0.04283581394702196, 0.15878605603107385, 0.2066993543079921, 0.2602843775280884, 0.13741278648376465, 0.11893253241266523, 0.25367902911135126, 0.23662133727754864, 0.180135346150824, 0.44620894374591963, 0.38904918091637747, 12.902785675866262, 92.38075406210763, 51.258879457201274, 54.99215350832258, 28.5695595400674, 55.668550218854634, 51.130938802446636, 37.177034854888916, 17.158338444573538, 34.22022894450596, 75.05792222704206, 64.69819981711251, 66.8903147833688, 57.52649504797799, 69.96011229923793, 31.972017696925572, 1.4060569001095635, 0.3124312864882605, 0.22632986094270433, 0.4122967677456992, 1.285069763660431, 23.757846900394984, 64.10615771157401, 58.65341295514788, 64.86781229291643, 59.454957144601, 51.190245151519775, 51.22627503531319, 58.23557608468192, 61.22111279623849, 61.369984899248394, 63.220901625497, 66.42656421661377, 49.47876140049526, 46.111435072762625, 28.639628648757935, 56.34875801631382, 46.98766197477068, 41.20649324144636, 53.61898796898978, 59.386357579912456, 57.91815110615322, 55.88184601919991, 51.76366261073521, 48.38074452536446, 51.405097348349436, 46.943648610796245, 48.37039518356323, 49.450510025024414, 49.17373200825283, 52.95562260491507, 48.5062289919172, 50.3593795640128, 50.477182797023225, 49.54146541867937, 55.39978347505842, 63.29981231689453, 66.88399192265102, 73.04375757489885, 62.492737361363, 54.08985001700265, 54.19116864885603, 56.19317395346505, 51.60805422919137, 56.92307874134609, 56.69137716293335, 64.0703466960362, 58.034832205091206, 57.644763810294016, 53.38832514626639, 55.954677036830354, 59.31726469312395, 70.84103965759277, 58.945181710379465, 35.457915033612935, 33.316442012786865, 44.93855830601284, 42.821084363119944, 43.971737316676546, 41.857935496738975, 40.588009766169954, 41.13432925088065, 33.40653930391584, 31.073122297014507, 48.45821346555437, 51.35757514408657, 51.42301675251552, 49.83490521567208, 53.94681440080915, 56.89541448865618, 51.34748983383179, 49.451524462018696, 61.33993394034249, 59.40937001364571, 53.92522982188633, 55.86227989196777, 59.52619702475411, 59.19049480983189, 51.18301902498518, 52.623766217912944, 48.69552571432931, 50.563079902103965, 60.92123549325125, 68.0875380379813, 67.96431173597063, 63.405897412981304, 53.531666483197895, 47.919092314583914, 49.01812015260969, 45.22715520858765, 47.98309217180525, 48.44340338025774, 45.77247762680054, 42.23878363200596, 48.56738703591483, 46.70886550630842, 54.56164312362671, 55.578442505427766, 58.142372948782786, 58.22610221590315, 59.60866519383022, 50.0071371623448, 43.30643687929426, 55.24068709782192, 57.73099095480782, 53.48838268007551, 52.49879591805594, 53.29951327187674, 51.620599201747346, 55.70040076119559, 54.675663062504356, 52.8326290675572, 51.998772280556814, 47.05563620158604, 52.39417689187186, 53.920181955610005, 62.629741941179546, 56.50382791246687, 66.03630474635533, 12.028387887137276, 0.417740599917514, 0.0777975886261889, 1.8415535943848746, 5.766024265970502, 7.1131466541971475, 73.23753588540214, 59.587084089006694, 71.87777342115129, 38.06312125069754, 79.98798874446324, 44.10462161472866, 11.596906491688319, 35.25958217893328, 43.29761266708374, 66.17092609405518, 50.47166245324271, 50.376083033425466, 57.01558705738613, 80.44884886060441, 18.117050886154175, 1.2126618261848177, 0.25035597171102253, 0.2484435343316623, 0.3304482911314283, 0.1610996297427586, 0.20503602070467813], [0.05485447742311018, 0.18663900930966648, 0.12409102703843798, 0.11795234786612646, 0.03797943364562733, 0.1141908618488482, 0.05226890277117491, 0.05843884205179555, 0.022562804199489098, 0.0301454041951469, 2.7059427201747894, 61.73871190207345, 44.20057276317051, 42.69773646763393, 31.243995870862687, 41.895348072052, 67.66427462441581, 80.67000307355607, 11.739705869129725, 7.4027784040996005, 46.36575998578753, 51.541104861668174, 53.03451245171683, 54.520169326237266, 54.75511571339199, 39.74237925665719, 0.40816847926803995, 0.39331445204360144, 0.13839508805956158, 0.39219858763473375, 0.6804307369249207, 6.222483566829136, 52.9423063823155, 58.39102118355887, 55.44035053253174, 54.27684688568115, 47.17071226664952, 47.342635018484934, 52.374888692583355, 56.88200446537563, 56.506263256073, 55.559783118111746, 30.809577124459402, 35.122796467372346, 48.30401904242379, 42.68982941763741, 31.75798191343035, 37.98684740066528, 45.16607359477452, 44.646563734327046, 53.20545203345162, 53.343620436532156, 50.768920285361155, 47.46641370228359, 47.47560269492013, 48.146388735089985, 47.86872134889875, 44.81492900848389, 46.47273097719465, 47.108095100947786, 50.547224112919395, 45.31658894675118, 49.91418416159493, 46.63911254065377, 45.250556741442, 49.52024909428188, 58.4607116154262, 60.77929769243513, 53.8420946257455, 49.4013341494969, 53.20727940968105, 54.37149177278791, 48.93178183691842, 51.886333056858604, 46.031238964625764, 59.619448798043386, 63.61669186183384, 53.17483132226126, 57.19966220855713, 50.77945722852434, 48.120294775281636, 50.12227923529488, 63.84756660461426, 73.61328056880406, 52.996495383126394, 22.576284885406494, 24.81388623373849, 40.613891805921284, 41.17232200077602, 42.8464800289699, 40.26460586275373, 26.0035012108939, 25.901882069451467, 58.80580084664481, 58.472996030535015, 49.505178451538086, 43.29777247565133, 45.67410503114973, 49.77898958751133, 50.884479250226704, 56.03161791392735, 70.0396066393171, 52.7698347227914, 47.79126977920532, 56.119818346840994, 53.51554666246687, 52.65566887174334, 51.15286384310041, 51.85782807213919, 51.8181608063834, 52.28254018511091, 50.29114825384957, 43.49627208709717, 54.35078614098685, 67.250155040196, 68.0034578868321, 57.10551759174892, 48.349012102399556, 45.01989391871861, 43.92075490951538, 44.54382072176252, 43.12506110327584, 43.02261338915144, 42.4757901600429, 42.5476519039699, 44.55746003559658, 51.34516218730381, 53.98003026417324, 45.3910527910505, 50.22921201160976, 54.278573513031006, 45.46156658445086, 49.07254539217268, 50.642476967402864, 55.83640480041504, 51.476399762289866, 53.55526256561279, 49.500436305999756, 52.38108648572649, 49.456818989345, 49.894069126674104, 46.34989724840437, 45.202277183532715, 42.27901370184762, 50.921488830021445, 54.181576660701204, 59.73608820778983, 55.2405481338501, 61.93513747623989, 2.899766845362527, 0.41313958966306275, 0.20644432013588293, 2.279748035328729, 0.8236928209662437, 15.931649616786412, 58.4176675251552, 53.58944075448172, 55.331031050000874, 50.7558924130031, 58.1090042250497, 2.551007228238242, 18.447243179593766, 26.836955002376012, 17.736979212079728, 46.594501631600515, 38.92435394014631, 41.66786057608468, 42.311805725097656, 54.42373875209263, 3.988736731665475, 0.27131277003458565, 0.16479749631668839, 0.30374953949025696, 0.014483859230365072, 0.03391798086730497, 0.052087357334260426, 0.043345753369586806, 0.13533933274447918, 0.029819703993520567, 0.051450477580406835, 0.05175299902579614, 0.09777258070451872, 0.06762072364134447, 0.033400910041694126, 0.09033744502812624, 0.049107821857822795, 3.474098426955087, 69.41340718950543, 49.23793683733259, 42.907933371407644, 26.558728286198207, 53.816438402448384, 39.92203187942505, 65.72808265686035, 15.625812496457781, 11.873751384871346, 48.63699408939907, 58.65941619873047, 56.83386387143816, 60.557677950177876, 58.720546449933735, 46.93186099188668, 1.0600575634411402, 0.2780663919235979, 0.06516836916229554, 0.2077150805188077, 0.5321156297411237, 8.29065135547093, 57.43143674305507, 63.05151844024658, 55.93279715946743, 58.49516773223877, 50.931428228105815, 49.744349343436106, 55.11424377986363, 59.52427932194301, 59.09492233821324, 60.04736750466483, 29.261018208095006, 36.04525668280465, 51.41249023165022, 43.86521795817784, 30.76045683452061, 37.84699058532715, 45.17964342662266, 46.37796449661255, 55.02251713616507, 53.94453191757202, 50.58662039893014, 44.70390721729824, 46.468284130096436, 48.473231996808735, 46.61968885149275, 45.649018560137065, 46.56074728284563, 46.189393860953196, 48.881813866751536, 45.92608840124947, 50.52949925831386, 47.229150090898784, 46.29876545497349, 51.48542547225952, 58.35864952632359, 58.45561858585903, 55.46948432922363, 51.185520376477925, 53.27600056784493, 55.563417025974815, 50.928162574768066, 51.2065942628043, 47.95808560507638, 56.372006688799175, 59.39863504682268, 54.89217240469796, 60.14742156437465, 54.79437303543091, 49.85258143288748, 52.26735837118966, 67.24941853114537, 80.98337377820695, 60.56553636278425, 25.01983778817313, 27.973489216395787, 39.613184452056885, 40.47808231626238, 39.486744608197895, 40.05226196561541, 31.747538770948136, 26.90960189274379, 56.2015187399728, 62.415549823216026, 50.65970155170986, 44.78606966563633, 47.980681146894185, 55.502356256757466, 56.36315468379429, 55.36665793827602, 61.07431820460728, 53.21589865003313, 49.93460839135306, 56.422506196158274, 55.353171484810964, 53.13996178763253, 52.13909115110125, 52.309648581913535, 55.23069211414882, 54.35518435069493, 50.21715688705444, 44.70595693588257, 50.41935988834926, 66.15214511326381, 71.89672810690743, 67.65266418457031, 53.38933610916138, 47.77155426570347, 46.16127797535488, 49.01815141950335, 47.00709956032889, 48.83997528893607, 45.134976931980674, 44.48790509360177, 47.439749990190776, 53.815340587071006, 53.70223781040737, 47.78630876541138, 51.2660083089556, 57.711984157562256, 42.975865909031455, 46.69430208206177, 56.849823883601594, 55.40093687602452, 50.74988569532122, 53.15195785249983, 49.44154684884207, 54.748174462999614, 50.24082939965384, 52.80386005129133, 48.9902092388698, 47.393381186894004, 41.03943075452532, 49.891616412571494, 54.62191179820469, 61.28447341918945, 55.431814670562744, 63.62932368687221, 2.769743468080248, 0.5714791289397648, 0.1652974137770278, 2.1984373927116394, 1.3364842619214738, 20.773675509861537, 63.61768545423235, 59.36099665505545, 57.51109436580113, 52.69425916671753, 57.62947429929461, 4.553898862430027, 17.851947580065044, 24.633971316473826, 26.151235546384537, 51.65177576882498, 49.450357164655415, 44.40681266784668, 49.54293496268136, 66.75630487714494, 6.299936873572213, 0.4095027505287102, 0.06566803556467805, 0.15408060566655227, 0.10669958418501274, 0.07917643963758435, 0.09820078379873719, 0.13645880695964607, 0.21994411359940255, 0.18340846337378025, 0.20805339807910578, 0.15192560558872564, 0.17970189798091138, 0.1536603346467018, 0.15275454467960767, 0.32024640856044634, 0.18284496718219348, 5.537212269646781, 81.93588842664445, 54.395143440791536, 55.73102147238595, 38.13799156461443, 59.32738821847098, 84.94961397988456, 87.48140553065709, 21.674426078796387, 17.546852179936, 57.54673515047346, 60.41787324632917, 64.00945963178361, 65.08363028935024, 63.0727173941476, 46.78514977863857, 1.7633331630911147, 0.7119464629462787, 0.30295554495283533, 0.4194395973214081, 1.0512718920196806, 10.18250686781747, 61.013396399361746, 67.11422048296247, 59.41620009286063, 58.22430958066668, 55.087263924734934, 52.059596811022075, 59.672519138881135, 64.22847379956926, 62.84560857500349, 61.34422097887312, 31.25915684018816, 33.175928592681885, 52.85824012756348, 38.78335414613996, 36.17454181398664, 44.46522964750017, 43.96698127474104, 49.60003873280117, 57.457040854862754, 59.050064768110005, 53.34576048169817, 50.74364273888724, 47.61044985907418, 50.37414796011788, 49.98184224537441, 49.18272992542812, 49.899902139391216, 49.89120299475533, 54.796335901532856, 51.17436851773943, 53.95969983509609, 50.89232724053519, 48.47057778494698, 52.38056537083217, 57.11014856610979, 56.969819273267476, 55.26275110244751, 56.7741163117545, 57.43164866311209, 60.81870787484305, 53.900963238307405, 55.18347563062395, 52.738932609558105, 63.46022537776402, 71.72560787200928, 64.08378451211112, 64.919187273298, 58.316328048706055, 56.61655896050589, 55.4788852419172, 58.80916377476284, 67.05019283294678, 70.0912595476423, 41.04897410529, 35.82127455302647, 42.01724031993321, 45.812530517578125, 42.18481002535139, 40.7337760244097, 33.35708550044468, 44.250123841421946, 64.91789490836007, 55.48325218473162, 50.662904671260286, 49.500950472695486, 53.057288646698, 59.868993350437705, 55.08342157091413, 67.17816475459507, 74.14957727704729, 52.04783698490688, 55.59661899294172, 61.76909637451172, 61.13722024645124, 57.33018411908831, 54.3083951813834, 56.511036668504985, 55.377379008701865, 57.33640275682722, 54.24694183894566, 48.56128304345267, 49.95120416368757, 60.37858813149588, 66.53809670039585, 66.28461251940045, 55.216225964682444, 49.35150861740112, 48.28854193006243, 49.106028761182515, 47.65118714741298, 50.313980034419465, 46.20278998783657, 45.92945827756609, 50.9382826260158, 58.806905610220774, 56.8739584514073, 50.86841154098511, 54.84735999788557, 62.07725593021938, 42.28985289164952, 47.220103536333355, 55.36721379416329, 56.50794472013201, 53.90556641987392, 57.17559017453875, 51.137164388384136, 58.5418735231672, 52.370514801570344, 54.28452117102486, 50.82433911732265, 50.62974091938564, 42.328036717006135, 52.79804788316999, 57.33186558314732, 61.71521309443882, 56.16844878877912, 68.83367729187012, 5.079602173396519, 0.6657534273607391, 0.28990063975964275, 6.970549643039703, 5.603056873594012, 18.30582649367196, 72.99990054539272, 61.4923426764352, 67.95870453970772, 58.66541944231306, 69.34792736598423, 9.651603698730469, 29.64867557798113, 37.077203137534006, 27.39684431893485, 61.86980356488909, 51.24044588633946, 58.54320757729666, 56.72852223260062, 79.6243964603969, 10.73621576172965, 0.8009405104177338, 0.2970050913946969, 0.43727489028658184, 0.165063862023609, 0.16478537768125534, 0.16032295141901287], [0.12307867993201528, 0.231248425585883, 0.11756130813487939, 0.02222637296654284, 0.01205287266722215, 0.1079134154798729, 0.051470273839575906, 0.07386307617915527, 0.060840917085962634, 0.0647169601704393, 0.5103837272950581, 51.02433259146554, 51.8269259589059, 43.91537700380598, 40.43480198723929, 32.442723410470144, 74.85380499703544, 61.05912249428885, 8.181967633111135, 20.15584169115339, 47.78064945765904, 54.164359024592805, 56.03020395551409, 53.97889770780291, 54.11933469772339, 38.34481511797224, 0.38460979770336834, 0.1798439153603145, 0.23108649998903275, 0.38618600741028786, 0.4458531199821404, 3.505022253308977, 43.6988468170166, 61.77557209559849, 54.022362164088655, 57.32589013235909, 51.67371470587594, 42.890535082135884, 45.877228668757844, 56.736186095646445, 55.415059089660645, 59.006013189043315, 41.29386336462838, 39.94271319253104, 41.0899441582816, 35.668459347316194, 52.50100197110857, 25.268621512821742, 48.57348755427769, 44.73181118283953, 51.242870807647705, 52.75960002626692, 53.51541812079293, 48.00359630584717, 53.078835010528564, 50.361443178994314, 50.85660307747977, 47.02666916166033, 46.06116485595703, 46.41603020259312, 49.055897508348735, 46.462194034031455, 52.59603943143572, 49.702267578669954, 47.48643841062273, 48.74443061011178, 51.83469404493059, 50.942851066589355, 49.27153832571847, 47.77938488551548, 53.02672004699707, 53.170057909829275, 46.71739789417812, 48.711430140904014, 47.3817846434457, 49.28121369225638, 67.51892525809151, 63.88120978219168, 48.68605184555054, 54.664507729666575, 49.924530029296875, 53.35231263296944, 50.25743212018694, 57.24842814036778, 76.25862652914864, 62.11671475001744, 26.200972488948278, 27.817034891673497, 40.339948654174805, 36.971889291490825, 29.629703521728516, 33.84673547744751, 78.06742327553886, 62.46964154924665, 49.670198168073384, 50.45408698490688, 53.971873079027446, 49.96451691218785, 54.18191712243216, 39.83723953792027, 58.885128429957796, 65.36110660008022, 38.528834683554514, 54.36520365306309, 46.713763986315044, 54.78892912183489, 53.38012627192906, 51.545565605163574, 51.97155271257673, 50.274354457855225, 49.58415862492153, 52.61128030504499, 50.27142926624843, 46.8823481287275, 46.369925430842805, 59.873537472316194, 60.74571010044643, 51.369432244982036, 41.667002473558696, 37.50911011014666, 43.11712278638567, 45.28640597207205, 43.336380141122, 43.724881717136924, 43.416426862989155, 48.343943391527446, 50.30264752251761, 51.96777984074184, 47.262584822518484, 50.65159995215279, 45.54281881877354, 54.813473633357454, 59.15298843383789, 47.37144224984305, 53.04646682739258, 49.700315134865896, 52.53976944514683, 53.29518454415457, 51.072910921914236, 51.06403807231358, 53.19411257335118, 53.18282869883946, 45.309946468898225, 41.44255134037563, 50.01229272569929, 56.14610685620989, 59.10307952335903, 59.55409404209682, 42.59937082018171, 0.49135662828172955, 0.029940747855497257, 0.10559743296887193, 0.8581295588186809, 0.5099673239248139, 34.2627067565918, 57.07817643029349, 54.786122049604145, 51.019041538238525, 50.05265481131417, 40.7103397505624, 6.287870458194187, 36.619653838021414, 22.92933327811105, 30.47365951538086, 53.15670347213745, 31.74602406365531, 32.652208123888286, 45.882262638636995, 45.750135694231304, 0.6576987824269703, 0.2840617916413716, 0.043825491198471615, 0.02487664932518133, 0.202142883092165, 0.17960201762616634, 0.05171343704153385, 0.10463393359844174, 0.2424108423292637, 0.02455470142220812, 0.05950032866426876, 0.03366029362327286, 0.03943744255229831, 0.039531819988042116, 0.10871065341468368, 0.036149261851928065, 0.09316960948386363, 0.5124434881976673, 58.2122996194022, 61.24891948699951, 45.803782735552105, 33.83153976712908, 39.304983207157676, 65.47407736097063, 66.92297826494489, 14.347328322274343, 23.88538977078029, 57.92804534094674, 56.45349863597325, 62.987136432102744, 60.227437019348145, 57.01615333557129, 43.039924825940815, 1.5432538581745965, 0.4048062568264348, 0.020124783772709112, 0.09088248506720577, 0.3381734937429428, 4.2936601638793945, 45.814236300332205, 65.44488103049142, 57.41501814978463, 59.37046010153634, 53.52378722599575, 45.0333525793893, 48.54667098181588, 59.0154835837228, 57.221114771706716, 60.17683328901018, 41.57672105516706, 42.546849387032644, 43.03290367126465, 41.8372437613351, 52.88980579376221, 24.243835176740372, 50.33031177520752, 45.53581850869315, 51.55671051570347, 55.320115430014475, 53.18246739251273, 46.7131838117327, 51.94670942851475, 48.65277344839913, 50.04944474356515, 49.4966321672712, 47.03567055293492, 48.73807995659964, 51.77168083190918, 48.95902919769287, 51.047501359667095, 49.90800721304757, 48.74803672518049, 49.815134116581504, 51.10221494947161, 50.61747734887259, 50.72513621194022, 54.44669560023716, 54.213951792035786, 53.06559869221279, 46.84840270451137, 49.46564320155552, 49.08204705374581, 51.144015312194824, 69.68194811684745, 62.14149897439139, 50.935739585331504, 53.392636503492085, 54.08109876087734, 54.84277071271624, 48.56409706388201, 58.8846629006522, 85.78541278839111, 70.56226403372628, 25.141533749444143, 31.449124063764298, 40.01156289236886, 39.608595166887554, 35.972227641514365, 35.321747711726594, 69.45664582933698, 62.144368580409456, 51.94554213115147, 53.49912459509713, 56.14335189546858, 52.25344807761056, 54.44081742422921, 43.656403745923726, 63.14520795004708, 75.03367301395961, 39.335701193128315, 55.44872311183384, 51.369532993861604, 56.860878467559814, 53.13980197906494, 54.99404341833932, 53.586487770080566, 51.80645309175764, 50.99227360316685, 52.938898290906636, 51.830886432102744, 49.011675698416575, 46.456475666591096, 53.99221740450178, 60.36075210571289, 56.799428599221365, 46.080821309770855, 39.633928298950195, 45.5822046824864, 46.527298654828755, 46.45014933177403, 45.13190235410418, 48.94728674207415, 49.99812534877232, 52.63320187159947, 51.29248789378575, 51.90961994443621, 52.29436254501343, 48.75825752530779, 48.35232291902815, 53.23866094861712, 51.7253954069955, 54.98440626689366, 51.00979001181466, 54.5663401058742, 52.714989117213655, 54.44470841544015, 52.40761818204607, 56.44991683959961, 52.856558663504465, 47.33198343004499, 43.280259541102815, 50.6809526171003, 56.91782590321132, 60.241798945835654, 61.55649539402553, 44.913610798971995, 0.19406252168118954, 0.05111139666821275, 0.18684045278600284, 1.2366018444299698, 0.6341979120458875, 38.657692500523154, 63.95738983154297, 63.070952551705496, 56.34210511616298, 52.386585984911235, 46.40117495400565, 9.154069253376552, 34.507088797433035, 30.191590445382253, 32.55533981323242, 53.1819497517177, 38.40090445109776, 40.30541263307844, 52.37798064095633, 55.46114649091448, 1.5706541878836495, 0.11627807627831187, 0.05252981644922069, 0.15884620137512684, 0.1051797064553414, 0.04786622151732445, 0.07586495804467372, 0.20817345806530543, 0.46641791505473, 0.21612803265452385, 0.14336037662412437, 0.12988990944411072, 0.15161881276539393, 0.09064511994698218, 0.2204758950642177, 0.1550972546849932, 0.23016545655471937, 0.8751449372087206, 73.07688658578056, 69.76474285125732, 57.228024755205425, 52.91721991130284, 43.94578232084002, 90.74896267482212, 61.24134595053536, 15.386146545410156, 28.616030829293386, 59.131039074489046, 67.18456404549735, 66.40907560076032, 66.45769214630127, 63.06547737121582, 48.321740422930034, 1.652932150023324, 0.39011233672499657, 0.3350519341017519, 0.3325363333736147, 0.8892265473093305, 6.3080445528030396, 50.74972241265433, 66.06713390350342, 61.95586395263672, 62.33474922180176, 56.0456428527832, 47.6437143598284, 52.70067582811628, 61.87090832846505, 64.94591699327741, 61.897797857012065, 37.71031951904297, 42.942483288901194, 41.76850175857544, 49.5588915007455, 50.40445252827236, 30.280930382864817, 50.62918506349836, 46.19113091060093, 53.14986297062465, 56.6496775490897, 55.283130168914795, 50.44538089207241, 54.76112590517317, 54.969193186078755, 54.891776357378276, 51.37774576459612, 48.99017449787685, 52.6461637360709, 52.74051679883684, 52.84607730593, 55.875512736184255, 53.37966421672276, 50.15944514955793, 49.65264354433332, 53.993756430489675, 51.779292583465576, 55.242406776973176, 54.86742639541626, 58.2176844733102, 56.53927067347935, 51.915842056274414, 53.67345142364502, 55.889516830444336, 48.59680918284825, 68.16421835763114, 66.57281684875488, 59.20525973183768, 62.21162019457136, 59.62481280735561, 59.30627959115164, 55.20631088529314, 56.691467489515034, 68.1366548538208, 77.46507004329136, 45.57408571243286, 36.24060181209019, 37.607593876974924, 37.53307792118618, 38.472863469805034, 57.1647891998291, 74.87460095541817, 52.8938843863351, 54.879068102155415, 58.40532752445766, 61.06334005083357, 58.292238644191194, 59.12887123652867, 47.45343099321638, 56.019524574279785, 65.8027479989188, 38.429353850228445, 62.25988933018276, 52.95290585926601, 59.54517255510603, 56.50430733816964, 58.169804436819895, 52.01789719717843, 55.696686949048726, 52.85497794832502, 56.14469984599522, 53.41117082323347, 53.557399136679514, 48.88430479594639, 54.800431864602224, 59.06110545567104, 56.12399768829346, 47.42984880719866, 42.47105148860386, 46.33110237121582, 48.03902169636318, 46.40768541608538, 46.282854080200195, 49.07033239092146, 52.21507665089199, 54.86296565192086, 57.800556319100515, 54.078771114349365, 56.09537805829729, 49.95413282939366, 49.76794195175171, 53.05182041440691, 52.26553794315883, 57.06509297234671, 53.29832860401699, 56.634304659707205, 57.72250720432827, 54.90249047960554, 55.08208056858608, 57.49091679709298, 56.47838360922677, 49.8288950238909, 44.736018317086355, 52.447615487234934, 60.16704327719552, 63.46949427468436, 63.141671316964285, 49.58467626571655, 0.9877881556749344, 0.18008442888302462, 0.2657082879117557, 4.7127173117228915, 1.4086128601006098, 41.19675186702183, 70.4711662020002, 64.65618406023297, 61.25996017456055, 58.246356214795796, 53.756899288722444, 14.603352069854736, 47.41043554033552, 30.46073239190238, 43.07189001355852, 69.11099379403251, 43.13068219593593, 48.07609380994524, 56.633036613464355, 72.12251676831926, 5.204219417912619, 0.7059586899621146, 0.15044120166982922, 0.3083763069340161, 0.17868268410009996, 0.25630414539149826, 0.12114184243338448], [0.02787615917623043, 0.0661670845001936, 0.15466823056340218, 0.10129055407430444, 0.07025494586144175, 0.00388516005062099, 0.035658579253192456, 0.21802938277167933, 0.13323755695351533, 0.3034612978143351, 0.16563863546720572, 32.39938054765974, 56.61454050881522, 46.80271829877581, 32.34077249254499, 33.60767575672695, 24.206641469682964, 28.56559385572161, 14.158722945622035, 11.669679318155561, 69.12856578826904, 52.70298957824707, 56.54613201958792, 49.709882804325645, 51.066324029650005, 46.89757163184029, 4.0908209681510925, 0.13007523092840398, 0.0825122534962637, 0.21706408528344973, 0.44846420415810173, 1.1173974637474333, 32.31445966448103, 55.64975186756679, 62.42577757154192, 54.69218240465437, 55.498048373631065, 44.68437235695975, 44.865220069885254, 52.01391240528652, 56.58526079995291, 54.27647863115583, 67.50805132729667, 47.516729082380024, 48.750638825552805, 30.290980952126638, 44.108571665627615, 53.24614415849958, 45.296466963631765, 58.09603541237967, 51.75798940658569, 54.76587847300938, 53.45441293716431, 56.38656316484724, 49.85599994659424, 48.51046391895839, 51.06500734601702, 50.71388360432216, 47.30856105259487, 50.935089928763254, 47.319483620779856, 48.385094097682405, 48.45235613414219, 49.89566721235003, 48.36609772273472, 50.756562914167134, 47.82499980926514, 46.18467950820923, 46.48551218850272, 46.023686272757395, 49.4123227255685, 48.45921400615147, 52.14487552642822, 48.15099886485508, 51.60282570975167, 48.1940255846296, 50.511458260672434, 45.863648414611816, 56.12345920290266, 53.59656613213675, 50.19550977434431, 51.757947717394146, 52.73225539071219, 51.39764193126133, 51.84273658479963, 78.07080704825265, 61.51934337615967, 31.097635541643413, 35.286454336983816, 33.68905305862427, 39.32743631090437, 85.3569312776838, 57.51169885907854, 50.000126429966514, 49.14086355481829, 48.973783697400776, 51.086466857365195, 54.38479062489101, 51.029005255017964, 55.76378570284162, 41.64853416170393, 41.5168970652989, 51.06865515027727, 49.74355724879673, 46.37291663033621, 48.2140850339617, 50.295921666281565, 51.51098442077637, 48.3411363192967, 49.289794717516216, 47.8579238482884, 50.510388238089426, 45.80967828205654, 47.00689806256975, 48.73142358234951, 47.863037722451345, 49.342291831970215, 49.78935282570975, 42.420048236846924, 30.102820260184153, 32.7355899810791, 46.26639379773821, 44.51887321472168, 46.519940512520925, 46.32960850851876, 46.24541023799351, 50.33243792397635, 50.80306025913784, 51.467148235866, 54.659362588609966, 44.95245817729405, 52.7353959764753, 60.019762311662944, 54.54872989654541, 56.01964616775513, 51.735188892909456, 50.96229560034615, 51.84546027864729, 52.83574186052595, 51.17397594451904, 53.82083313805716, 50.92486565453665, 42.97814491816929, 46.90996721812657, 47.70340633392334, 57.48463562556675, 56.901841572352815, 69.65329374585832, 29.254462582724436, 1.6204115407807487, 0.10464251706642763, 0.1502445622214249, 0.4685748421720096, 2.339306039469583, 43.06891965866089, 54.32339634214129, 50.78264992577689, 52.9345452444894, 61.33978107997349, 42.98265082495553, 5.197042797292982, 28.95940211841038, 14.237518991742816, 42.83987576620919, 83.95324230194092, 34.228730065482004, 34.670354093824116, 53.40049491609846, 40.711847509656636, 0.35733108861105783, 0.06972108807946954, 0.05043572846001812, 0.11756419869405882, 0.04075301338785461, 0.1650042730782713, 0.08796460128256253, 0.015280961458172117, 0.040576706241284094, 0.10599960067442485, 0.07424870798630373, 0.04956803823422108, 0.049400874347026856, 0.05271530417459352, 0.2868587129882404, 0.15096530211823328, 0.20463601074048451, 0.16497595102659293, 35.24286828722273, 66.40403120858329, 48.118304116385325, 32.76427909306118, 47.5892265864781, 31.937030042920792, 38.98491791316441, 23.2984459059579, 11.750182884080068, 74.3135895047869, 57.0355110168457, 63.534758704049246, 56.00849083491734, 58.09684487751552, 45.97300263813564, 3.9696600181715826, 0.25534065280641827, 0.22521649354270526, 0.02750918029674462, 0.3390502424112388, 1.5101294070482254, 38.211833545139854, 58.48633657182966, 65.67513043539864, 58.50458254132952, 60.050591468811035, 45.7356139591762, 48.080693517412456, 52.89654902049473, 57.26833472933088, 56.022877080099924, 70.86812373570034, 49.33129630770002, 50.06358780179705, 31.774258068629674, 44.409168107169016, 51.796544960566926, 47.34501825060163, 57.630325453622, 53.04066160746983, 56.05549539838518, 53.42404236112322, 57.842499119894846, 50.4366261618478, 49.60722664424351, 52.13663843699864, 48.89468193054199, 48.52771282196045, 51.38367257799421, 49.09772566386631, 50.1869079044887, 50.04500831876482, 51.712892123631065, 49.40914045061384, 51.65541662488665, 50.054159096309114, 47.80017042160034, 50.402194363730295, 45.514946120125906, 51.371985707964214, 51.15284994670323, 52.79144014630999, 47.565908432006836, 52.182263783046174, 47.15050343104771, 47.8546929359436, 45.71374103001186, 55.478857449122835, 52.76564843314034, 52.198213372911724, 50.19141728537423, 52.7448524747576, 54.17256484712873, 52.193832533700125, 84.18847356523786, 63.42034271785191, 29.59892300197056, 38.3590658732823, 35.39648253577096, 38.60108552660261, 71.87793322971889, 55.35714932850429, 48.619439465659006, 50.411685603005544, 51.688684599740164, 51.08647380556379, 54.803106921059744, 52.799781458718435, 57.490930693490164, 42.82672282627651, 44.12126949855259, 50.986704621996196, 55.072565010615754, 47.36273963110787, 48.612630231039866, 50.67989649091448, 49.87883172716413, 49.14357335226876, 52.00183991023472, 50.12644468035017, 50.68660150255476, 47.09742266791207, 47.649359771183555, 50.93686866760254, 47.914471762520925, 47.542121274130686, 48.05123315538679, 45.079544203622, 32.24186488560268, 35.41211598260062, 49.05149582454136, 44.57734925406319, 47.84591736112322, 46.901347977774485, 49.25931644439697, 53.64874710355486, 51.17501470020839, 53.361070837293354, 57.498330524989534, 49.62129674639021, 50.29470920562744, 54.790579319000244, 58.76623780386788, 54.584742409842356, 55.048194204057964, 53.597538879939485, 53.45636190686907, 53.67675181797573, 54.25225373676845, 53.46841355732509, 51.510734285627095, 45.263341426849365, 49.052048206329346, 48.922373976026265, 59.900739669799805, 58.97293281555176, 71.04676192147392, 30.29699809210641, 2.1021946370601654, 0.03995078143530658, 0.29040747827717234, 1.7221133006470544, 2.2385567256382535, 49.80927331107003, 58.45033795492989, 58.58217307499477, 55.51279592514038, 66.62563705444336, 43.6927740914481, 7.585476943424769, 37.64757033756801, 18.389215299061366, 40.30980042048863, 84.3656804221017, 34.091836656842915, 37.59657750810896, 60.631405285426546, 47.42879268101284, 0.9085162122334752, 0.032324119071875296, 0.14070452270763262, 0.11175958945282868, 0.029847788557942425, 0.1121898213667529, 0.0330640140122601, 0.1208935800407614, 0.20668727638466017, 0.15797099976667336, 0.22108116187155247, 0.11231431897197451, 0.10606301655726773, 0.10732334107160568, 0.40010075217911173, 0.2717030362359115, 0.9097486489585468, 0.24355895072221756, 48.35434831891741, 76.72048718588692, 59.32638072967529, 46.59438698632376, 50.82108041218349, 34.180846554892405, 30.498037270137242, 21.05700741495405, 17.28546963419233, 80.40724304744175, 58.97744219643729, 66.36219610486711, 58.95688942500523, 61.45188331604004, 53.95831714357649, 6.23508369071143, 0.3578229450753757, 0.30063880926796366, 0.3754721294556345, 1.2643918160881316, 2.6523047983646393, 43.83724103655134, 59.41782597133091, 67.54046467372349, 59.99018383026123, 64.0479873929705, 48.03346313749041, 52.052940436771934, 58.86043453216553, 61.50921985081264, 60.68723406110491, 74.91469900948661, 49.00615188053676, 47.85915715353829, 32.78418220792498, 53.77846302304949, 48.94181503568377, 48.8014475277492, 60.0667599269322, 54.76392255510603, 57.25997257232666, 58.75896998814174, 59.96147387368338, 56.46155159814017, 53.16108431134905, 57.89631291798183, 52.001551559993196, 52.64546891621181, 54.4834098815918, 53.137971128736226, 50.97462865284511, 53.61041736602783, 52.272305488586426, 53.993249211992534, 54.16033601760864, 52.92323357718331, 48.599268845149446, 51.89534139633179, 49.002302578517366, 56.04968670436314, 51.019340310777935, 54.411075660160606, 53.73416130883353, 57.233298437935964, 56.95844854627337, 50.23005969183785, 48.141934939793174, 65.10144547053746, 56.62884684971401, 59.95386559622628, 56.83095605032784, 58.181859561375205, 60.728881563459126, 51.35022742407662, 66.73773234231132, 74.31690379551479, 48.76675864628383, 50.61612592424665, 42.42979308537075, 62.523906980242046, 77.75406646728516, 45.38071039744786, 56.5932651247297, 51.62118285042899, 57.635012013571604, 52.34321880340576, 61.07656247275216, 52.61886773790632, 66.73386219569615, 53.39228909356253, 48.428537709372385, 62.174468176705496, 58.044914041246685, 52.23801960263933, 51.47708763395037, 55.67647116524832, 53.733456066676546, 52.19182103020804, 53.50671202795846, 52.8440796988351, 52.14372212546212, 48.38119615827288, 47.30505568640572, 53.280103479112896, 52.60157019751412, 49.99933433532715, 49.71873133523123, 45.13501862117222, 33.333506788526265, 37.814445223127095, 51.88385602406093, 45.4219514301845, 50.31208317620413, 48.05957446779524, 51.84862865720476, 55.238453251974924, 55.341852869306294, 55.60755545752389, 60.63734599522182, 48.4418226650783, 56.00559343610491, 62.70652648380825, 57.869930607931956, 60.88979489462716, 56.600571155548096, 58.19075672967093, 55.75787625994001, 54.65177168164934, 54.728726455143516, 56.753817149571006, 55.63920450210571, 44.9604103905814, 53.33247552599226, 52.859077385493684, 62.23424352918352, 61.023839541843955, 71.24401433127267, 33.06844343457903, 3.9181877630097524, 0.22260185384324618, 0.5116138841424669, 3.807317529405866, 3.1316592821053097, 53.99551779883248, 63.67541108812605, 61.59070832388741, 62.563136509486604, 69.71958650861467, 54.07880238124302, 11.400064025606428, 39.56484236036028, 19.465659754616873, 59.35152626037598, 102.07693045479911, 46.47507946831839, 47.67007235118321, 65.20207623073033, 61.7190762928554, 1.859473432813372, 0.1637562843305724, 0.29699678612606867, 0.18584011574941023, 0.10516501617218767, 0.22706343872206552, 0.1936204018337386], [0.0320321386680007, 0.06198478463504996, 0.07389123538242919, 0.12208887375891209, 0.3406959612454687, 0.11947170990918364, 0.12041631207934447, 0.13732782032872948, 0.03371162140475852, 0.20074784223522457, 0.3845264193202768, 16.72757966177804, 61.290803228105815, 45.36444813864571, 34.689621448516846, 22.221666199820383, 35.748485224587576, 27.18634864262172, 21.49267336300441, 1.6161410042217799, 42.94350814819336, 56.59561708995274, 47.4852363722665, 59.284767968314036, 46.96554238455636, 54.849611214229036, 9.121346712112427, 0.3347865454852581, 0.15115970240107604, 0.22467776387929916, 0.027319458512855426, 0.180556146427989, 22.487526859555924, 59.82538645608084, 61.076027461460654, 55.54249252591814, 58.97219630650112, 48.68503393445696, 43.34300177437918, 45.89376538140433, 51.493763310568674, 55.7528075490679, 52.47085721152169, 56.87262787137713, 46.81697947638375, 47.65592234475272, 34.70677655083792, 50.881032943725586, 55.83578988483974, 52.985527651650564, 57.632267475128174, 56.946706090654644, 53.44852433885847, 54.1485310282026, 53.92806816101074, 51.88940416063581, 52.32616444996425, 47.952718121664866, 49.698710100991384, 49.130469049726216, 45.78847932815552, 48.457810470036094, 44.76040302004133, 45.839277608054026, 48.63589627402169, 49.64626509802682, 50.85007177080427, 48.1058737891061, 45.76655428750174, 51.55698496954781, 48.40248196465628, 49.29125383922032, 46.62791204452515, 48.922502517700195, 48.83557707922799, 49.91140488215855, 49.74824380874634, 53.75803531919207, 52.98259898594448, 51.70234475816999, 51.40892233167376, 46.95117003577096, 49.796485151563374, 49.553867953164236, 53.076500415802, 51.16216400691441, 81.56508391244071, 58.50633348737444, 45.52765090124947, 35.02281188964844, 63.73341464996338, 59.36549908774239, 47.451944078717915, 49.45735052653721, 47.25785657337734, 51.0416579246521, 48.15500450134277, 50.58248274666922, 52.18720047814505, 49.94918918609619, 54.94861957005092, 51.48228488649641, 47.18485532488142, 45.51259762900216, 43.760960238320486, 46.11866119929722, 44.89584078107561, 46.895309993198936, 47.18953493663243, 49.29198340007237, 46.82040841238839, 48.47845704214913, 49.70479324885777, 44.08378744125366, 48.47550058364868, 46.071055616651265, 46.53242295128958, 44.66558790206909, 45.80967480795724, 33.93071835381644, 17.108844688960485, 41.74864033290318, 46.65235233306885, 45.24677692140852, 50.93019839695522, 47.39818934031895, 51.04697677067348, 48.23878240585327, 53.97800486428397, 51.304508277348106, 57.549114908490864, 30.891882010868617, 33.00659057072231, 57.35038253239223, 47.97179440089634, 54.060177734919954, 48.72846712384905, 51.43969937733242, 52.76586382729666, 52.9918783051627, 53.020404134477886, 49.93649135317121, 42.64523935317993, 48.82839264188494, 50.0274988583156, 57.60184131349836, 60.15719073159354, 66.15837069920131, 11.218161923544747, 1.2294408572571618, 0.12169294857553073, 0.34252979712826864, 0.6118195557168552, 3.8623993737357, 60.94097532544817, 54.49681643077305, 48.739900384630474, 48.32796948296683, 66.02399948665074, 17.332651376724243, 5.771181132112231, 37.689554827553884, 17.64829761641366, 57.36914961678641, 77.28506306239537, 39.97943442208426, 34.96578107561384, 55.43260676520211, 35.76083217348371, 0.07291853507714612, 0.09575290086546115, 0.05085693246551922, 0.1355213972606829, 0.14780376319374355, 0.048789527865925005, 0.009560795051843991, 0.04143579603571977, 0.03465054762948837, 0.020397872065326998, 0.04637815011665225, 0.04076610572103943, 0.14692229192171777, 0.1051855825686029, 0.20231031839336666, 0.1030302635793175, 0.12567791688655103, 0.3667017657841955, 19.773240872791835, 68.90128326416016, 49.41635962894985, 29.803582191467285, 26.49400407927377, 42.60000658035278, 20.051969596317836, 20.361357246126445, 3.1544128954410553, 46.440182140895296, 61.480683599199565, 54.993425028664724, 64.80221435001918, 55.75301946912493, 60.69990757533482, 10.840165155274526, 0.4489279149898461, 0.2910841405391693, 0.18717221569802078, 1.1525097510644366, 0.3112402403993266, 26.2404591015407, 62.477215085710796, 65.45805481501988, 59.19316291809082, 63.15201718466622, 50.65399013246809, 47.606065545763286, 48.57265724454607, 55.47623103005545, 58.8231018611363, 55.2325507572719, 56.37299680709839, 47.583410944257466, 47.74637051991054, 35.09410735539028, 50.971929277692524, 57.62006991250174, 53.55257708685738, 56.91144050870623, 55.29755462918963, 56.12211125237601, 54.5632620538984, 54.05421270642962, 53.4511889730181, 53.62629052570888, 47.78938681738717, 50.50915840693882, 50.25201252528599, 47.08584349496024, 48.376228196280344, 45.958077907562256, 45.98395994731358, 48.86305373055594, 48.327212129320415, 49.349392890930176, 48.85659885406494, 47.842808042253765, 50.445113386426655, 47.92253514698574, 50.91749708993094, 47.55477046966553, 48.87072801589966, 47.03665024893624, 54.107470648629324, 53.91812876292637, 53.365573269980295, 52.72436571121216, 49.87668820789882, 50.25149141039167, 51.7239362852914, 49.03444147109985, 48.543700626918245, 51.21856253487723, 51.75136429922921, 78.59463174002511, 51.67239802224295, 49.018116678510395, 41.287405014038086, 54.9770759173802, 57.47321973528181, 48.091088022504536, 57.17801856994629, 49.60373517445156, 51.264882700783865, 52.980990477970664, 53.26315682274954, 50.60349062510899, 52.45875344957624, 56.1640088898795, 53.5878461429051, 53.01359837395804, 48.32919931411743, 48.284508500780376, 49.27984489713396, 50.778043270111084, 46.84232303074428, 49.53019891466413, 50.749559129987446, 47.55108445031302, 51.702681745801655, 51.676216057368684, 47.68543134416853, 48.93945264816284, 45.986374446323936, 48.233296803065706, 48.42648451668875, 47.311378547123496, 37.994549478803364, 21.286674908229283, 40.703408922467915, 49.66433388846261, 46.92206055777413, 52.91109160014561, 48.89870841162545, 50.89196940830776, 50.82346364430019, 55.3147931098938, 52.299882888793945, 57.81779827390398, 31.53031723839896, 32.82586792537144, 60.79670292990548, 50.26111466544015, 56.0285051209586, 49.97488709858486, 55.83190584182739, 55.22779471533639, 57.46859918321882, 54.01966626303536, 51.63294962474278, 44.93114457811628, 51.37983022417341, 51.052768094199045, 59.56538486480713, 61.30007907322475, 68.40598787580217, 12.575181586401802, 1.3733993896416254, 0.1712660656443664, 0.4004978580134255, 0.7971053762095315, 4.358228036335536, 65.9033509663173, 55.372893946511404, 53.19184398651123, 47.77547652380807, 70.99752698625836, 19.31835447038923, 9.897197331701006, 41.38965123040335, 22.766781909125193, 54.964725494384766, 83.09400027138847, 38.32718753814697, 36.19953795841762, 63.438630376543315, 36.495718819754465, 0.33843462115951944, 0.025796444255060384, 0.042150578395064385, 0.06490424940628664, 0.02781247696839273, 0.049248108972928355, 0.07476352607565266, 0.05685440171509981, 0.19883551342146738, 0.17825853185994284, 0.13036465325525828, 0.3468466911997114, 0.24637943080493382, 0.19802509833659443, 0.28758265557033674, 0.4215267167559692, 0.3542621290045125, 0.5497418524963515, 26.248763935906545, 83.0209538596017, 59.515184129987446, 49.53464923586164, 37.29174266542707, 52.243303707667756, 31.35740089416504, 29.231603009360178, 5.189933487347194, 52.661564418247764, 64.54816041673932, 56.767022200993125, 65.62155982426235, 59.188973154340474, 64.22654220036098, 12.338672723088946, 1.5296403829540526, 0.7227291986346245, 0.40424149855971336, 2.9657645268099646, 1.0876260612692152, 29.53474596568516, 61.46272250584194, 68.03214699881417, 60.489502225603374, 66.82295894622803, 53.00987066541399, 50.164367948259624, 53.87766245433262, 59.04257461002895, 60.58783313206264, 54.40676777703421, 59.44311046600342, 48.72954756872994, 50.07582705361502, 40.55489812578474, 55.681018761226106, 55.1072677884783, 55.09411137444632, 59.43626649039132, 58.927832058497835, 56.30252817698887, 55.540967396327424, 57.131743567330496, 55.98253583908081, 56.82007169723511, 50.95513548169817, 53.98134694780622, 54.49353688103812, 50.330683503832134, 50.739866392953054, 48.21345622198922, 49.90935516357422, 52.15052441188267, 52.44921704701015, 53.96231583186558, 52.17130299976894, 51.23764228820801, 54.485952922276084, 53.76916980743408, 52.84754337583269, 48.130025727408274, 51.2863005229405, 53.98884405408587, 56.71975360597883, 57.50459085191999, 57.7502235685076, 56.451754638126914, 54.26539625440325, 56.4905811718532, 54.49362025942121, 57.71416589191982, 51.498189313071116, 60.76497745513916, 49.74563823427473, 64.60210623059953, 67.91903727395194, 62.59181867327009, 44.72823633466448, 60.94237886156355, 52.03184570584978, 53.77930722917829, 55.52130052021572, 53.684457370213096, 54.91699831826346, 55.941343443734304, 53.34370034081595, 55.48544086728777, 51.567827633449006, 63.57327256883894, 59.949522972106934, 55.29717247826712, 53.027803965977256, 50.01496778215681, 53.159451484680176, 52.80323123931885, 51.19503940854754, 53.08122866494315, 54.17180054528372, 50.949743679591585, 54.2979450907026, 54.204988615853445, 49.72662796292986, 54.16683258329119, 49.855749811444966, 50.4275552885873, 50.35574913024902, 47.58155230113438, 36.760080405644004, 21.11387668337141, 45.88349941798619, 50.13584211894444, 50.07648713248116, 55.531125273023335, 52.05556338174002, 54.63805941173008, 52.515384742191856, 57.80459322248186, 57.752242020198274, 59.31793866838728, 40.857933385031565, 42.05341958999634, 61.29442323957171, 53.296747888837544, 58.04757867540632, 53.81885984965733, 57.17216123853411, 58.00619867869786, 57.057720933641704, 60.02432032993862, 53.46914659227644, 46.31454481397356, 52.43762397766113, 54.40305743898664, 61.41423102787563, 64.72358158656529, 69.50002343314034, 19.001183101109095, 4.692208835056849, 0.4197616028998579, 0.487369393663747, 2.81059952718871, 4.985018517289843, 72.38196250370571, 63.18459728785923, 59.24216856275286, 57.39723423549107, 78.38637338365827, 27.663601296288626, 11.695338147027151, 47.521669251578196, 23.825438976287842, 78.77139391217912, 78.91225474221366, 52.19283546720232, 48.725736481802805, 70.38390377589634, 52.466945375714985, 0.7332875292216028, 0.22173951725874627, 0.17282536625862122, 0.15542937043522084, 0.14617806114256382, 0.16314438145075524, 0.21417466604283877], [0.07290943592254605, 0.11423777576003756, 0.05169095717636602, 0.025342841898756366, 0.16890613442020758, 0.08094704284199647, 0.08857636167002575, 0.06788112502545118, 0.06729717100305216, 0.14961310396237032, 0.1253768644694771, 6.18069623197828, 60.83544608524868, 43.0565310205732, 49.95634235654558, 29.99115228652954, 36.913698128291536, 34.05482360294887, 53.430333954947336, 5.706136005265372, 15.112168652670723, 69.43532180786133, 38.551173142024446, 51.91771112169538, 51.763169288635254, 57.590522697993684, 13.116030233246939, 0.9866997855050224, 0.21651221918208258, 0.03496129631197878, 0.39864822583539145, 0.0448097265990717, 15.027054956981114, 48.436976296561106, 53.07546860831124, 57.67968545641218, 56.086984634399414, 56.586035524095806, 41.55022757393973, 45.547651290893555, 50.251741545540945, 57.26260593959263, 61.25127492632185, 58.96549824305943, 54.583429200308665, 45.67486585889544, 40.89709690638951, 41.82690831593105, 55.46361310141427, 52.831593785967144, 56.96784598486764, 57.08524622235979, 55.378372601100374, 55.94588756561279, 54.87712608064924, 53.69258328846523, 48.77180651256016, 44.1129664012364, 48.07862990243094, 47.82169941493443, 49.11291790008545, 47.0451374735151, 47.55872399466378, 46.5875951222011, 48.01159715652466, 47.05423961366926, 51.307509899139404, 45.983973843710764, 46.157244546072825, 49.6628817149571, 49.503608158656526, 47.58081579208374, 46.654982226235525, 49.07555743626186, 45.54350321633475, 45.295876366751536, 45.46093429837908, 44.06094871248518, 48.49699831008911, 46.71340962818691, 49.212266717638286, 46.22879362106323, 46.93373353140694, 47.3301317351205, 48.77862269537789, 49.728740215301514, 61.78021349225725, 76.06092248644147, 42.16347905567714, 37.7939897264753, 50.530357360839844, 52.32958991186959, 44.95218024935041, 47.833907399858745, 50.66273444039481, 47.19128588267735, 48.400397505079, 52.620069776262554, 50.99793291091919, 48.70643091201782, 44.362198284694124, 46.8957963671003, 46.087203230176655, 46.287082059042795, 44.41514355795724, 42.47031150545393, 44.736539431980674, 45.25066096442086, 45.29173871449062, 47.039613655635286, 47.24117047446114, 45.516815185546875, 48.25636829648699, 46.84719719205584, 47.4424980027335, 47.05800206320626, 42.078936849321636, 45.09800556727818, 42.7083672114781, 46.48312895638602, 17.65696723120553, 24.561935867582047, 53.926251207079204, 48.401411942073274, 49.43188885280064, 45.407995973314556, 51.37882620947701, 49.14719336373465, 53.472349711826865, 47.98003149032593, 53.09136608668736, 33.39862877982003, 23.706565720694407, 59.79653058733259, 51.10467461177281, 51.973046575273784, 50.02080079487392, 52.443293707711355, 52.63154820033482, 55.038247857775005, 51.29649005617414, 50.161067553928916, 44.276207378932405, 50.755208015441895, 50.69938966206142, 60.02170780726841, 59.97562735421317, 52.2783955846514, 6.9149892415319165, 0.476945195879255, 0.35462864648018566, 0.09874927079571144, 1.3212163554770606, 7.183981367519923, 58.986092703683035, 48.73543964113508, 61.75126729692732, 55.07409361430577, 56.239570549556184, 12.520370721817017, 13.226839235850743, 31.889375822884695, 17.161974089486257, 42.399203641074045, 37.804335594177246, 27.286477395466395, 38.89190237862723, 56.61595099312918, 12.804992386272975, 0.4967802401099886, 0.19200467424733297, 0.02737799403257668, 0.09475208885435547, 0.12288510746189527, 0.056240015397114415, 0.10306260255830628, 0.07259584417832748, 0.12647252210548945, 0.07035365235060453, 0.06768912675657443, 0.05889704996453864, 0.10321384801396302, 0.04475218004414013, 0.07018992863595486, 0.08081502028341804, 0.15876462789518492, 0.07711041585675307, 5.624587169715336, 68.64381776537213, 49.52182980946132, 44.928281920296804, 35.42906958716256, 46.239136014665874, 24.064139127731323, 53.66495725086757, 7.4075770037514825, 21.802467482430593, 69.0534279687064, 43.3683522769383, 60.607781410217285, 57.517069816589355, 63.073919432503835, 16.28001492364066, 1.0212049739701408, 0.4543659117605005, 0.18313109182885715, 1.34476694890431, 0.0356992743909359, 17.649765423366002, 51.81737913404192, 56.772872584206716, 59.40650040762765, 57.45567553383963, 58.943173680986675, 46.180190971919465, 47.2146874155317, 51.641537598201204, 57.58283799035208, 63.73039218357631, 60.42847619737898, 55.802650451660156, 43.602440561567036, 40.96355642591204, 43.58998244149344, 54.91465677533831, 53.81291219166347, 55.98970985412598, 56.013000215802876, 57.06394304547991, 56.32839284624372, 54.89987448283604, 54.74902561732701, 48.10719742093767, 44.82993016924177, 49.67746945789882, 48.03632232121059, 49.986330781664165, 47.01103918892996, 48.96412222726004, 46.76027522768293, 47.83847236633301, 48.72925227028983, 50.30578810828072, 48.63290160042899, 47.83654076712472, 49.132390226636616, 46.983951636723106, 49.43262536185128, 48.34893914631435, 46.55085999625069, 44.803214345659526, 48.63844278880528, 47.608337606702534, 49.14105115618025, 49.27576977866036, 49.44687611716134, 49.559871196746826, 46.70369257245745, 47.996099199567524, 48.75711107254028, 50.035895756312776, 49.7660277230399, 56.15613310677664, 69.09383174351284, 50.866153376443044, 39.6132469858442, 50.431324686322895, 49.57788440159389, 53.815073081425254, 49.06401300430298, 55.76505374908447, 49.66117593220302, 50.667827469961985, 51.70670475278582, 53.50648621150425, 49.28009850638253, 47.53556217466082, 48.48465483529227, 48.57338680539812, 48.403308800288606, 48.17325741904122, 47.59591770172119, 46.83021926879883, 47.084488596235005, 45.14332171848842, 49.17503132138933, 48.80670731408255, 48.27724763325283, 47.09349693570818, 48.624205929892405, 48.77349492481777, 48.068044321877615, 43.48460258756365, 47.75918994631086, 46.28571326392037, 52.850107261112754, 25.043399129595073, 25.142959867204937, 55.505090372903005, 50.24576609475272, 52.200950963156565, 46.28622743061611, 52.756435121808735, 51.305939606257844, 55.14982550484793, 49.06342935562134, 56.1185051373073, 37.841122831617085, 28.087959051132202, 60.69983809334891, 54.17949914932251, 55.414322580610005, 51.952208927699495, 53.87012365886143, 56.3948905808585, 56.328212193080354, 53.34778935568673, 51.78645270211356, 46.26965945107596, 53.53126348767962, 54.6495795249939, 59.82219723292759, 59.19170379638672, 57.63694361277989, 9.168861099651881, 0.8164212597267968, 1.010835981794766, 0.080554388197405, 1.1599019829716002, 8.835042715072632, 59.90079525538853, 52.37567036492484, 67.05837781088692, 58.575787680489675, 60.12712587629046, 16.930275985172816, 14.773080927985054, 35.545347690582275, 19.938580206462316, 40.47448314939226, 48.40870755059378, 32.158184255872456, 40.47879103251866, 64.26912076132638, 13.435980881963458, 0.7185911663940975, 0.18701068365148135, 0.08757354119526488, 0.13258978671261243, 0.08557465166917869, 0.020944954494812658, 0.05689616893817272, 0.11668701576335089, 0.27710295362131937, 0.2629119093929018, 0.12478269849504743, 0.1646716280707291, 0.23909660588417733, 0.15025411599448749, 0.27444635331630707, 0.19873490024890217, 0.28842099915657726, 0.17915877141058445, 7.915333117757525, 84.10396262577602, 54.34095096588135, 69.3200511932373, 41.67329406738281, 59.66752338409424, 41.16589491707938, 65.98144177028111, 11.76998177596501, 24.081214325768606, 75.93980843680245, 49.007294859204976, 61.293262890407014, 61.64987918308803, 67.97481741224016, 17.265182631356375, 3.9328484620366777, 1.2114444800785609, 0.3659905253776482, 2.9701069337981085, 0.1278836035302707, 23.49963273320879, 52.747576168605256, 58.67926720210484, 60.99407345908028, 62.236661502293174, 62.62910270690918, 48.546438217163086, 49.79891702107021, 56.011985778808594, 63.044736998421804, 68.05189377920968, 62.897185053144185, 58.22925322396414, 44.09042297090803, 43.87817634854998, 47.607858180999756, 59.326957430158345, 55.593064989362446, 61.357749121529714, 58.491895130702424, 61.219834327697754, 58.89021451132638, 57.481884138924734, 56.29601076671055, 51.86210468837193, 49.89104666028704, 51.42315919058663, 50.639666421072825, 52.87836211068289, 50.05065720421927, 51.69484070369175, 49.900544847760884, 50.50496169498989, 50.20637328284127, 54.67395380565098, 49.29170199802944, 49.08724430629185, 52.586697578430176, 53.02070985521589, 52.97103370938982, 50.506535461970735, 50.31404256820679, 49.639705998556956, 53.05318226133074, 50.1895933832441, 51.34230300358364, 53.070097650800435, 55.45510503223964, 54.66962507792881, 54.38226842880249, 51.52157694952828, 54.88852112633841, 52.990905557359966, 57.659143107278005, 53.16663244792393, 71.71981307438442, 58.550808906555176, 43.587321281433105, 53.499628339494976, 56.67700481414795, 51.907222815922324, 57.866946356637136, 59.54344940185547, 50.81331580025809, 53.141914231436594, 55.30682005201067, 56.70286948340279, 55.623685700552805, 52.20103781563895, 54.7703982761928, 52.651868207114084, 55.158239773341585, 51.28865596226284, 50.46973780223301, 51.92793539592198, 50.578782830919536, 47.648692744118826, 53.41029535021101, 47.87195226124355, 52.58117028645107, 49.8880033493042, 50.301184926714214, 50.38942357472011, 50.83543886457171, 43.895411355154856, 49.97568266732352, 47.79741198675973, 51.34845215933663, 19.32212907927377, 26.944725036621094, 59.5202910559518, 52.52466753550938, 51.826978070395334, 50.651259490421836, 57.15145213263375, 54.659001282283235, 56.97035081045968, 51.597360951559885, 56.379416942596436, 40.25415577207293, 28.01518883023943, 63.31691878182547, 57.20293133599417, 58.93563488551548, 55.30139698301043, 54.637812750680105, 58.132381439208984, 59.392298289707725, 56.807783808027, 55.36185673304966, 49.90402242115566, 56.06714405332293, 57.154947076525005, 65.40855584825788, 62.525560651506694, 64.54807703835624, 12.91858240536281, 2.039928355387279, 2.1570497964109694, 0.4155632624668734, 4.345473315034594, 8.888582059315272, 70.53938361576625, 57.86848190852574, 71.67813083103725, 65.01323808942522, 65.21888392312187, 20.842573847089493, 20.92380002566746, 39.69641692297799, 24.583042757851736, 58.17953538894653, 47.4463403565543, 39.695100239345, 52.196139335632324, 73.9308271408081, 26.030595711299352, 0.8866917576108659, 0.3723023938281195, 0.1714692325996501, 0.3257415922624724, 0.2783852762409619, 0.21263669856957026, 0.19049839435943536], [0.0152421628258058, 0.06758970780564205, 0.036364360845514705, 0.0414480809122324, 0.13297626668853418, 0.03412625040592892, 0.04351678490638733, 0.05101960784356509, 0.02385541849902698, 0.05566577121083226, 0.061222050205937455, 0.31788412960512297, 46.98793642861502, 44.075498240334646, 38.12035008839199, 20.09642243385315, 35.62620040348598, 35.42555032457624, 34.416595458984375, 22.20043076787676, 27.564599888665335, 58.992756026131765, 49.34453957421439, 43.31258603504726, 49.209563868386404, 55.28288003376552, 23.735181876591273, 0.5962481541293008, 0.7445634241615022, 0.04225769193310823, 0.22782714345625468, 0.09019832499325275, 7.703185507229396, 46.927278654915945, 55.72581032344273, 57.98840086800711, 58.60041209629604, 54.17753280912127, 48.33207934243338, 45.66546147210257, 46.89077976771763, 51.664418016161235, 53.168942723955425, 56.97766031537737, 59.88136114392962, 51.55295154026577, 43.40136316844395, 43.463698932102744, 49.05103724343436, 53.70863710130964, 53.36832128252302, 54.11269569396973, 56.6932601247515, 55.691573074885774, 56.496073722839355, 49.97218424933297, 43.14496421813965, 52.4562486239842, 54.97187171663557, 48.80189916065761, 47.01158114842006, 45.71051359176636, 45.615080084119526, 47.019540309906006, 46.71225275312151, 48.0963408606393, 47.598620550973074, 47.47707223892212, 47.10429096221924, 49.83175768171038, 45.00018187931606, 46.38917194093977, 48.32036467960903, 46.0365960257394, 46.526836599622456, 46.09479413713728, 44.8920053754534, 45.86325931549072, 45.70545530319214, 47.243352208818706, 43.92276988710676, 47.26453726632254, 43.76406955718994, 46.26836013793945, 47.84312071119036, 49.852643966674805, 49.10983984810965, 65.95045280456543, 49.75346885408674, 36.495520796094624, 49.94673299789429, 47.687915325164795, 47.95235334123884, 46.17395148958479, 45.0853841645377, 46.19172150748116, 46.608436243874685, 47.545532839638845, 48.177193573543, 45.61503839492798, 48.68229634421212, 43.335681847163606, 41.544738497052876, 42.562243121010916, 41.12870815822056, 43.090431281498496, 43.81787988117763, 43.69203063419887, 43.4126227242606, 45.36365256990705, 43.649139404296875, 47.35917520523071, 45.621131965092246, 47.642251764025005, 45.34289482661656, 45.46458905083792, 43.060460226876394, 43.65724100385393, 46.11072983060564, 49.16903155190604, 32.861526080540244, 14.928850855146136, 46.320009572165354, 53.4112229347229, 49.194489751543315, 49.27649586541312, 51.15093919209072, 49.659352030072895, 51.17916277476719, 53.04705395017351, 54.465966429029194, 49.47261571884155, 43.114538056509836, 47.52869735445295, 52.69675357001168, 54.38391167776925, 49.73237412316458, 49.90462691443307, 51.6782032421657, 52.24640260423933, 51.89080769675118, 49.63486657823835, 45.901540415627615, 52.60249430792672, 54.395907742636545, 58.84357820238386, 59.98454189300537, 40.41703544344221, 4.5584690400532315, 0.694002305822713, 0.481043275977884, 0.2843004459781306, 1.1597185071025575, 27.136094059262955, 59.68526908329555, 49.77351788112095, 60.58235100337437, 47.49155575888497, 60.1197121483939, 19.641426597322734, 11.129601052829198, 32.91055951799665, 23.449395520346506, 58.93612125941685, 29.0743305342538, 22.61148272241865, 44.76313018798828, 50.232404708862305, 5.249223334448678, 0.5108836718967983, 0.0787783974249448, 0.04190873833639281, 0.0596123140837465, 0.08286256755569152, 0.10620012812848602, 0.10272745375654527, 0.010083799666192914, 0.07048935935433422, 0.017907930138920034, 0.04854274807231767, 0.031172838527709246, 0.023968783040930117, 0.009956487836981458, 0.06721318193844386, 0.03027257862101708, 0.04289668532354491, 0.0771009638639433, 0.4529086085302489, 53.30193819318499, 52.15540552139282, 39.04239688600813, 25.91320937020438, 47.3322092464992, 28.863298109599523, 45.93266487121582, 24.59676718711853, 33.07312652042934, 65.81954179491315, 52.044050216674805, 46.22676474707467, 55.575260230473106, 60.309842654636924, 27.76664134434291, 0.3462925452206816, 1.430033179266112, 0.4161169199006898, 0.3371766715177468, 0.11359848042151757, 10.17514090878623, 49.939253262111116, 57.034010205950054, 63.232095173427034, 61.12158679962158, 55.85400806154524, 49.851375920431956, 48.851808071136475, 48.899434498378206, 55.07419088908604, 54.78674043927874, 59.27696514129639, 57.9559006690979, 52.197657517024446, 44.29730558395386, 43.45463153294155, 50.82743106569563, 52.83570711953299, 54.68902792249407, 55.68243619373867, 55.61897134780884, 55.46620825358799, 57.287553446633474, 51.37309741973877, 43.94284323283604, 52.982769216809956, 54.063961029052734, 51.17980548313686, 48.23099347523281, 46.82021386282784, 47.16870423725673, 48.08394180025373, 47.31900766917637, 48.70286648614066, 49.24331821714129, 46.07661764962332, 46.59905270167759, 49.408535957336426, 46.90934535435268, 47.127456256321494, 49.20617314747402, 46.14984471457345, 44.97388294764927, 47.060013566698345, 46.91847876140049, 47.653879574366975, 47.78494691848755, 47.50616782052176, 47.46254702976772, 48.66355357851301, 44.40067393439156, 48.53768696103777, 50.29633855819702, 50.298141615731375, 50.03120224816458, 58.957862172807964, 43.265525885990684, 39.577321325029644, 54.02749340874808, 49.89408649717058, 52.34586954116821, 51.31020927429199, 47.81961495535714, 49.5384464263916, 50.067134857177734, 50.09665775299072, 48.16857085909162, 49.026364190237864, 52.43540750231062, 48.54234225409371, 47.362187249319895, 46.134169578552246, 44.66612638745989, 47.09642907551357, 47.083508900233674, 47.30409683500017, 45.22285427365984, 47.218140670231406, 45.48408917018345, 48.164172649383545, 47.37530892235892, 47.940204416002544, 46.343633447374614, 46.139151436941965, 43.69671024594988, 45.472034045628135, 47.66752931049892, 51.85338122504098, 45.89497436795916, 20.615586621420725, 45.293044975825715, 53.76034559522356, 51.95837197984968, 51.049061230250764, 53.25992938450405, 52.81803090231759, 54.49191100256783, 54.798573221479145, 57.70747825077602, 52.88975715637207, 43.97385304314749, 51.17214856828962, 54.12415327344622, 56.84929929460798, 52.811787945883616, 54.10381589617048, 53.66045134408133, 55.12982164110456, 52.97163125446865, 51.421654905591694, 48.13134935923985, 55.718764850071494, 56.558544976370676, 60.11807932172503, 59.86868762969971, 45.07019887651716, 4.827489827360425, 0.44439744523593355, 0.9020885857088226, 0.08312148294810738, 0.5465067603758403, 32.48735516411917, 63.633791378566194, 55.03023658479963, 62.820282391139436, 51.99650021961757, 63.65668569292341, 22.529047557285853, 12.044085604803902, 41.10540042604719, 19.736748933792114, 60.182433537074495, 38.69803374154227, 21.83014042036874, 47.97301728384835, 56.62114129747663, 6.076871037483215, 0.5562862413270133, 0.0484051750972867, 0.09123582539281674, 0.009946442126030368, 0.05241497100463935, 0.05235821155032941, 0.05769032971667392, 0.1106236811195101, 0.13913019932806492, 0.2232135667332581, 0.11163491542850222, 0.1714751494250127, 0.07869662716984749, 0.1186771589730467, 0.16703561693429947, 0.13978950466428483, 0.10898451693356037, 0.17730719862239702, 0.9139535576105118, 69.95326137542725, 56.818397181374685, 52.64279385975429, 28.36719846725464, 54.61908040727888, 44.89168228421892, 46.48365354537964, 34.223181928907124, 39.669582980019705, 70.79894747052873, 60.74299335479736, 52.12005308696202, 59.9493979045323, 65.75323513575962, 29.662530285971506, 1.1730808700834001, 2.0799211008208136, 0.899026167179857, 0.8785060197114944, 0.2210762628487178, 13.31332606928689, 54.39518512998308, 57.33551686150687, 64.91261427743095, 65.15412671225411, 60.23785931723458, 52.629547119140625, 51.96157162530081, 52.422758306775776, 58.00784192766462, 55.266433647700715, 64.390547479902, 62.85696193150112, 52.884511266435894, 45.58821487426758, 48.04124859401158, 53.530120509011404, 54.62679985591343, 57.091669831957134, 59.47883115495954, 58.12165342058454, 58.21892472675869, 60.92613397325788, 54.99984169006348, 47.41738026482718, 56.92959615162441, 59.415143966674805, 53.55219841003418, 49.97427565710885, 46.96739060538155, 49.20429713385445, 51.60335029874529, 49.924109663282124, 52.63131890978132, 51.254189423152376, 50.50102206638881, 51.212093761989046, 52.59990610395159, 46.36619077410017, 49.62513910021101, 51.837070328848704, 49.20152480261666, 47.54697111674717, 54.22916487285069, 51.173267228262766, 51.67527110236031, 51.37818350110735, 50.90371881212507, 49.53243276051113, 52.73783132008144, 48.313346999032156, 51.5758284841265, 53.5714761870248, 54.14656468800136, 53.7979735646929, 61.957336970738, 51.47035830361502, 42.77110249655587, 58.65746375492641, 52.88267346790859, 56.22957903998238, 52.140682288578574, 49.06431177684239, 52.25191599982125, 54.97335515703474, 52.451523848942344, 52.23716497421265, 51.37983022417341, 56.17837429046631, 53.18913418906075, 51.309576988220215, 51.26460129874093, 47.03544473648071, 51.44612298692976, 50.42270197187151, 50.7932459286281, 48.24179792404175, 50.51766300201416, 47.347880908421104, 50.77124793188912, 46.72718790599278, 51.537557806287495, 49.43604734965733, 47.53437750680106, 44.191355977739605, 47.375433989933555, 50.170586585998535, 53.69527224131993, 37.140872955322266, 17.22165390423366, 50.219328199114116, 55.957953112465994, 53.952758584703716, 52.65125676563808, 56.613758836473735, 53.31254461833409, 55.25585501534598, 56.90507595879691, 60.91403021131243, 53.377715247017996, 44.156448228018625, 50.59215463910784, 54.09474154881069, 60.82571165902274, 54.05263893944876, 55.67320898600987, 57.67643369947161, 58.86975901467459, 57.13041646139962, 54.57199593952724, 50.705702100481304, 58.009568555014475, 59.196991375514436, 62.486810547964915, 61.165193693978445, 51.879475184849326, 7.522958789552961, 1.9566780797072818, 1.840048006602696, 1.1684364335877555, 2.5627546778747012, 35.28029475893293, 71.04023756299699, 59.69801207951137, 69.95133672441754, 57.68513284410749, 69.48323658534459, 28.21952666555132, 18.12989115715027, 45.26736443383353, 30.794357095445903, 81.61676461356026, 39.424262932368684, 32.48524291174752, 54.411419595990864, 69.50385189056396, 11.905744365283422, 0.8405797662479537, 0.32827383066926685, 0.1910806316882372, 0.146677788613098, 0.14381346159747668, 0.15680488305432455, 0.19653738316680702], [0.06587933815483536, 0.059224361686834266, 0.06358961494905607, 0.041475483548960516, 0.025531983535204614, 0.08745202235877514, 0.017548851103388836, 0.058830675669014454, 0.19711812771856785, 0.05418017985565322, 0.08773796380098377, 0.11155728423701865, 27.96074969427926, 57.181041036333355, 40.00829723903111, 23.076709781374248, 32.73280722754342, 32.97859280450003, 33.26870788846697, 10.159189581871033, 18.586903708321707, 53.60123879568917, 54.00549193790981, 60.5066225869315, 44.805159841264995, 58.0356798853193, 37.13179513386318, 0.6264883428812027, 0.3843458747225148, 0.05475718567946127, 0.10128823348454066, 0.09057065072868552, 5.0902324829782755, 45.605550629752024, 59.25838565826416, 58.28957748413086, 58.80449458530971, 55.646152700696675, 49.32067251205444, 46.630903244018555, 46.15386772155762, 49.220448221479145, 53.40527180262974, 57.37220682416643, 55.23413494655064, 57.958339486803325, 54.82056079592024, 47.80264745439802, 49.13950865609305, 50.9309001650129, 55.024973324366975, 53.96888535363333, 55.93246712003435, 53.853013719831196, 53.49396208354405, 48.330522945949006, 54.22073323386056, 58.12923043114798, 53.75418949127197, 48.08722482408796, 47.445228644779746, 42.68732459204537, 46.43609660012381, 44.76307807649885, 45.9939340863909, 47.18417092732021, 46.23094408852713, 46.51802280970982, 44.94049685341971, 47.76173646109444, 47.12870345796858, 47.07368762152535, 46.81942176818848, 46.61977570397513, 48.65085921968733, 46.00555147443499, 42.112378529139924, 44.00286872046334, 44.107671873910085, 43.23866067613874, 42.82999195371355, 41.5573981148856, 44.541704995291575, 43.625849042619976, 48.023958001817974, 45.627538204193115, 45.63880818230765, 59.22579165867397, 46.44593524932861, 41.57293428693499, 45.74562978744507, 44.370654242379324, 47.011831283569336, 44.2968886920384, 46.169515064784456, 42.85433496747698, 46.95450169699532, 46.32625947679792, 43.850373131888254, 44.376779079437256, 39.67352260862078, 39.772381578172954, 41.97859443937029, 42.3572677884783, 42.26902914047241, 44.474922384534565, 46.19335780824934, 46.48050948551723, 43.92907190322876, 44.850514207567485, 42.59382268360683, 44.17164741243635, 46.74980776650565, 44.97271565028599, 46.692102977207725, 44.15796640941075, 43.94344425201416, 43.25615971429007, 46.33283594676426, 47.04487691606794, 49.34101683752877, 17.17241723196847, 34.218971320560996, 52.99281978607178, 46.71326719011579, 52.3153634752546, 52.73070594242641, 54.44183880942208, 52.158692019326345, 47.91020209448678, 41.07325805936541, 48.221231256212505, 31.989384719303676, 78.98298045567104, 83.2287049974714, 46.7699818611145, 55.09554270335606, 47.633041926792686, 54.771586418151855, 46.78391299928938, 51.37252071925572, 47.93246759687151, 47.32502828325544, 51.43416166305542, 56.53943395614624, 58.8662223815918, 65.9693796975272, 29.51621512004307, 2.7044390865734647, 0.28796990907617975, 0.5703875560845647, 0.16799248701759747, 1.6798106048788344, 47.07087360109602, 55.0263421194894, 45.894790240696494, 61.78652940477644, 49.46883937290737, 63.96551922389439, 15.676681995391846, 17.057771955217632, 24.317367962428502, 22.07975619179862, 54.454474108559744, 21.21654847690037, 44.66008145468575, 43.76938145501273, 45.603233405521934, 0.5827405846544674, 0.11074139337454524, 0.08204278190221105, 0.03284401260316372, 0.20461249271673815, 0.041571374117795906, 0.059805438720754216, 0.07985526642629079, 0.0937120168070708, 0.03547939172546778, 0.0589272922703198, 0.03561419288494757, 0.08428679220378399, 0.01592408543053482, 0.09250526941780533, 0.07264139423412935, 0.12461880514664309, 0.07552522234618664, 0.13719427106635912, 0.1233499175203698, 30.408829348427908, 68.6759740284511, 41.585486207689556, 21.99111454827445, 43.386556557246614, 31.024064540863037, 39.88199288504464, 15.648470572062902, 18.108405590057373, 62.85991491590227, 56.587981019701274, 64.92851175580705, 48.77067743028913, 65.56752368382045, 41.15140792301723, 1.079757769192968, 0.5114702518497194, 0.11934604522372995, 0.20272915091897759, 0.1115656437884484, 6.377567359379359, 52.307584966932026, 59.424225262233186, 60.595476150512695, 56.64764520100185, 60.22148241315569, 51.023439747946604, 49.542427744184224, 46.36700023923601, 51.902035985674175, 52.61825977052961, 57.77642869949341, 54.476829937526155, 58.59666006905692, 55.4532151222229, 48.51433753967285, 49.27451910291399, 54.40873759133475, 54.50562674658639, 55.88392700467791, 56.20083434241158, 55.688067708696636, 54.78505897521973, 52.26458256585257, 58.08919143676758, 59.03910745893206, 51.85077565056937, 50.647941725594656, 49.076227937425884, 44.09825011662075, 47.22734008516584, 47.617648192814414, 45.840966020311626, 47.35569415773664, 46.98433378764561, 47.0356080191476, 46.91171816417149, 45.55390814372471, 47.61532402038574, 47.83172219140189, 48.792074407849995, 46.72677101407732, 48.85268007005964, 46.85585117340088, 43.949725423540386, 45.06549494607108, 48.10358088357108, 44.65154211861746, 44.072100571223665, 42.591363021305625, 46.82919093540737, 46.25386619567871, 48.4622677394322, 48.81482975823538, 47.09884704862322, 52.13611037390572, 45.35012442725045, 46.24537897109985, 48.83836678096226, 50.53048937661307, 50.3099605015346, 48.933546679360525, 46.52590206691197, 46.98847838810512, 45.771556990487234, 47.75086253029959, 47.656617164611816, 45.671416078295024, 43.891780921391074, 46.27226849964687, 45.10891771316528, 47.583932059151785, 46.1086870602199, 47.907405444553916, 49.15669502530779, 47.155592986515586, 46.53373268672398, 44.93332631247384, 45.590785707746235, 42.27168682643345, 46.51915536608015, 45.9652692931039, 48.313388688223704, 44.69787965502058, 45.20194019590105, 43.48184415272304, 50.711559431893484, 47.64557647705078, 60.86221054622105, 27.390903609139578, 34.15812594549996, 57.288067613329204, 48.49718591145107, 57.27009957177298, 53.615041392190115, 56.82662384850638, 53.89092656544277, 49.41074548448835, 45.64848354884556, 47.439989703042166, 34.92777442932129, 67.59649494716099, 72.4550645010812, 52.389723096575054, 54.35860286440168, 51.79329667772566, 56.70054183687483, 50.84574999128069, 51.30776350838797, 51.08383001599993, 48.90977341788155, 53.38871424538748, 57.57255465643746, 58.97955444880894, 67.90227127075195, 33.30120461327689, 3.015238957745688, 0.3501769410712378, 0.6922535853726524, 0.09039723074861936, 2.1169239495481764, 53.69978509630476, 59.893312045506065, 51.42822095326015, 62.52034950256348, 57.30290896551949, 66.67546953473772, 18.64418986865452, 20.53793181691851, 32.167751925332205, 18.155701977866038, 59.445827211652485, 24.081077098846436, 38.56599712371826, 51.229373931884766, 49.581824030194966, 0.35460470776472774, 0.19220686411218985, 0.06329441828919308, 0.07449977951390402, 0.14938742321516785, 0.008229757858706372, 0.11526980038200106, 0.040560842092548094, 0.25405306475503103, 0.13368951555873665, 0.14194306624787195, 0.12824254855513573, 0.1247833634593657, 0.16454467416874, 0.1770329890506608, 0.1957435379070895, 0.37780167588165825, 0.10501749587378331, 0.2671788361455713, 0.2069903372653893, 44.32250322614397, 74.64073848724365, 52.303673131125315, 36.79350471496582, 46.66949006489345, 49.24880381992885, 40.31778737476894, 17.997441121510096, 28.612237112862722, 67.86689799172538, 64.53240885053361, 73.09726565224784, 54.77596378326416, 71.1688209261213, 44.223890917641775, 1.531552983181817, 2.022793446268354, 0.49717009919030325, 0.9825455227068493, 0.36821112622107777, 9.263145548956734, 58.86182417188372, 62.60755634307861, 64.18413734436035, 59.40209524972098, 61.91769749777657, 53.93867458615984, 52.31648908342634, 48.3617377281189, 54.664344446999685, 56.83555228369576, 61.87406281062535, 56.774957043784006, 59.322128432137625, 54.00086791174752, 48.68583992549351, 52.542378493717735, 57.42444685527256, 58.52194608960833, 57.685330867767334, 58.9502261025565, 57.36189917155674, 57.51804256439209, 55.28041689736502, 55.807656628744944, 61.86419636862618, 55.76014832087925, 53.284501688820974, 51.11472518103463, 44.938950879233225, 47.90740891865322, 51.869042464665, 48.91756582260132, 51.96305506569998, 46.55911793027605, 50.32677514212472, 48.22401053564889, 48.48400865282331, 50.610880034310476, 49.19320780890328, 53.188203130449565, 48.938820362091064, 51.104938643319265, 51.80279833929879, 49.29090295519148, 48.7136674608503, 51.50607551847185, 48.06801652908325, 50.69584608078003, 46.291164125714985, 50.42162152699062, 47.02383082253592, 53.130029337746755, 51.397628034864155, 51.84673874718802, 58.901130131312776, 48.34298801422119, 51.9667341368539, 52.531205790383474, 54.54249736240932, 55.234680380140034, 52.88005747113909, 54.27328940800258, 51.32405703408377, 52.58111817496163, 54.24285282407488, 53.174963338034495, 52.14774513244629, 49.79854529244559, 51.06718908037458, 50.41878318786621, 51.84979248046875, 50.211035524095806, 51.53536912373134, 53.071511609213694, 49.018620422908235, 49.06288392203194, 48.153170176914756, 47.483860628945486, 46.29610429491316, 49.939871651785715, 47.22487347466605, 49.28465305055891, 46.80876670564924, 45.970160824911936, 45.98170525687081, 50.96558557237898, 51.13580254146031, 55.158361366816926, 20.666813952582224, 36.888872214726035, 58.9158672605242, 49.75172138214111, 59.783516611371724, 56.35166236332485, 55.890493052346365, 56.6020268031529, 53.86320325306484, 48.79580559049334, 47.09535557883126, 35.215339524405344, 61.41412680489676, 76.1155561719622, 55.08566583905901, 57.420006956372944, 52.789998395102366, 60.480816977364675, 54.27280650820051, 55.822664737701416, 54.909216335841585, 51.63660437720162, 56.40736607142857, 60.253729002816335, 62.430703844342915, 68.55561038425991, 38.355960028512136, 4.475025083337512, 0.4491507187485695, 1.2215023232357842, 0.49330071253435953, 2.170826554298401, 61.12736075265067, 67.63181958879743, 57.49027756282261, 70.91437094552177, 59.048487527029856, 73.78097534179688, 25.34215603555952, 24.731006383895874, 31.74614565713065, 30.901738030569895, 74.2560236794608, 29.253194536481583, 61.637275150844026, 54.800299848829, 67.78744534083775, 2.624745420047215, 0.351501712841647, 0.268135950501476, 0.15564589095967157, 0.35110865107604433, 0.16261369921267033, 0.2563341094979218, 0.1852895524352789], [0.10624031775764056, 0.051678390707820654, 0.07163985619055373, 0.2146103126662118, 0.01073155548822667, 0.05150754237547517, 0.16416180399911745, 0.044344146403351, 0.17067360957818373, 0.1404272597283125, 0.045752839384866614, 0.5392439929502351, 13.758219225066048, 61.45843546731131, 45.290019035339355, 42.97608477728707, 46.37903799329485, 37.214996337890625, 23.286246606281825, 12.34369192804609, 3.8132143786975314, 44.27003737858364, 47.15599250793457, 58.02301331928798, 51.84871203558785, 49.12439285005842, 44.36755534580776, 1.7920214065483637, 0.24695488278354916, 0.2079490122518369, 0.246672123670578, 0.14876602084508964, 4.195561587810516, 47.59190164293562, 58.327063015529085, 63.053373609270366, 55.69980321611677, 56.06066485813686, 48.80204854692732, 51.83594472067696, 47.98599304471697, 50.74523735046387, 44.76479775565011, 51.14375475474766, 56.75438690185547, 59.01971503666469, 59.941574232918875, 53.09756735392979, 45.44905635288784, 48.93934147698538, 47.571328026907786, 51.651365825108115, 54.02842446735927, 56.20757409504482, 54.83732679912022, 59.23202419281006, 53.244122232709614, 52.68491036551339, 50.725702490125386, 54.69378049033028, 49.01621634619576, 46.72307109832764, 45.99180793762207, 48.28325435093471, 47.311121463775635, 42.8640832901001, 44.46613638741629, 43.403082847595215, 45.51332024165562, 44.07741246904646, 47.67578377042498, 47.3521158354623, 51.8611284664699, 46.460231167929514, 47.704559734889436, 46.519193581172395, 44.96199457986014, 42.55275188173567, 43.59996700286865, 42.80994987487793, 42.59482669830322, 40.092161996024, 42.195319175720215, 46.45895617348807, 47.28094891139439, 42.95518807002476, 48.261492592947825, 49.54547800336565, 41.640939780644004, 40.625880922589985, 44.42914417811802, 43.62576566423689, 45.68718501499721, 43.1971868787493, 42.934524127415244, 42.67384161267962, 43.126249245234895, 40.95142487117222, 43.007671288081575, 39.409831523895264, 44.30715465545654, 40.005017689296174, 42.31072875431606, 42.590411118098665, 44.60121979032244, 43.53866652079991, 44.54838221413748, 44.58922719955444, 43.25350202832903, 44.50005054473877, 42.27469539642334, 42.772658893040244, 45.69959102358137, 43.43136896405901, 45.97073057719639, 41.86692993981497, 44.8822466305324, 42.9563102040972, 46.311383383614675, 45.79470838819231, 48.28887891769409, 35.186466285160606, 21.65911224910191, 43.73901087897164, 51.36937665939331, 48.02274554116385, 52.66537550517491, 51.967088494982036, 51.05805567332676, 42.76636382511684, 43.9084392275129, 40.69741610118321, 52.13778141566685, 58.38172449384417, 42.117638315473286, 58.96032878330776, 52.09391743796212, 52.87457881655012, 47.502023220062256, 49.54372010912214, 52.446038246154785, 46.97639199665615, 49.53326307024275, 52.41252361025129, 59.00017670222691, 54.10415983200073, 59.38346018110003, 31.592416763305664, 2.127113482781819, 0.5254150692905698, 0.5822466111608914, 0.11127964127808809, 10.204094052314758, 57.57877329417637, 48.58075189590454, 53.543190070560996, 60.85683264051165, 44.53318650381905, 54.130781854902, 9.96888884476253, 19.999726091112407, 23.07720831462315, 30.665197031838552, 49.99144465582711, 28.845264060156687, 41.1248345375061, 47.5577894619533, 31.096214635031565, 0.32354468586189405, 0.1032582852723343, 0.10538266306476933, 0.03984340666128056, 0.11562345283372061, 0.04583492176607251, 0.10577598267367908, 0.014159259951806493, 0.06216303578444889, 0.06671305413224868, 0.06217469980141946, 0.14298278545694693, 0.06495585877980505, 0.11506161226757936, 0.04172458732500672, 0.02283578223016645, 0.2652398001934801, 0.07067691321883883, 0.14626504933195456, 0.4983012984905924, 15.79887648991176, 70.47038800375802, 48.883870533534456, 34.966521058763774, 58.71871907370431, 42.48749092647007, 25.411776985440934, 19.52572172028678, 4.147929515157427, 54.6572642326355, 55.56609903063093, 63.76574461800711, 55.41921411241804, 54.34118720463344, 50.75042765481131, 2.1481773810727254, 0.24393768182822637, 0.28872872835823465, 0.300055486283132, 0.13289534460221017, 5.313503290925707, 51.63426283427647, 58.07216835021973, 65.81695011683873, 56.737558364868164, 58.37108680180141, 49.37010894502912, 51.255551270076204, 47.16112722669329, 52.806000096457346, 45.65411506380354, 49.93413243974958, 56.29620879037039, 60.7347388948713, 56.977674211774556, 54.43687432152884, 45.16110215868269, 47.4670147214617, 46.40241520745413, 52.58180604662214, 54.722747530256, 56.858512605939595, 54.10800565992083, 63.51746463775635, 53.95147664206368, 53.979008878980366, 50.06292077473232, 54.64706080300467, 52.592468057359966, 47.98744174412319, 45.892803055899485, 46.969614028930664, 50.032595361982075, 43.85033144269671, 46.293495246342246, 44.67104223796299, 45.035009724753245, 45.35817044121878, 47.516986165727886, 48.75496407917568, 50.70377050127302, 47.76994923182896, 51.09878601346697, 46.804191316877095, 45.68791804994856, 45.35660362243652, 44.35062605994088, 43.890238421303884, 42.58602680478777, 43.2586784362793, 41.880986145564485, 46.92649698257446, 49.709653513772146, 47.93140799658639, 48.02884953362601, 47.52761343547276, 41.32292420523507, 46.819147314344136, 49.83951187133789, 49.58748681204659, 48.95391879762922, 48.40381949288504, 45.02546637398856, 45.492152554648264, 44.0550149508885, 44.225812094552175, 46.042807715279714, 45.27844681058611, 46.81473868233817, 46.01475088936942, 46.13999911717006, 48.57560328074864, 48.72755690983364, 47.96038198471069, 48.74993358339582, 45.99479218891689, 45.69407415390015, 42.536236013684956, 43.268461499895366, 42.17630890437535, 44.47525937216622, 44.340478215898784, 49.293140275137766, 44.97929212025234, 50.14027506964547, 44.1667663029262, 48.28281661442348, 47.5058308328901, 53.26561301095145, 52.02699933733259, 25.835637944085256, 44.31647913796561, 54.68629033224923, 50.24120112827846, 55.62489816120693, 54.00059693200247, 55.62456464767456, 46.32836478097098, 46.7310128893171, 40.57470049176897, 51.79462725775582, 51.88722242627825, 42.603310448782786, 61.110921314784456, 53.58675527572632, 54.230999197278706, 48.45008407320295, 51.65866838182722, 52.625086375645225, 47.49769796643938, 51.6328558240618, 53.79746634619576, 59.58711882999965, 56.154548917497905, 63.96632521493094, 35.238362380436485, 2.027383382831301, 0.8067083294902528, 0.3256517270846026, 0.25937362068465775, 11.864082966532026, 64.28811713627407, 51.38313061850411, 59.939593996320454, 63.71609279087612, 49.988543782915386, 56.017433166503906, 12.94811485494886, 28.99454436983381, 27.142852919442312, 25.70468177114214, 64.42173794337681, 31.624805791037424, 38.05806643622262, 56.16678816931588, 34.17353704997471, 0.22038764479969228, 0.07747843289481741, 0.1235486197152308, 0.039754905338798247, 0.09869187351848398, 0.05483409423114998, 0.1198014100747449, 0.04981694523511188, 0.1699876378157309, 0.1281404018934284, 0.20276261626609735, 0.3734353573194572, 0.1482193251805646, 0.2081347679985421, 0.2893026332770075, 0.12668172802243913, 0.42634222550051554, 0.25952911376953125, 0.4700831983770643, 0.720498012644904, 24.184304748262676, 82.69634096963065, 58.07489204406738, 60.18633147648403, 58.68820258549282, 54.613004207611084, 28.956963300704956, 20.59677611078535, 9.229665654046194, 57.26243918282645, 56.584579876491, 72.59165913718087, 57.08947420120239, 61.08571325029646, 53.16791091646467, 3.8434069071497237, 0.49647929625851767, 0.5732103160449437, 0.8784060850739479, 0.35714652708598543, 6.6118011219160895, 59.46214853014265, 60.64516966683524, 72.1354751586914, 59.374754088265554, 61.12877818516323, 51.86923006602696, 56.81184850420271, 51.96620259966169, 57.710670948028564, 46.34724303654262, 54.37455940246582, 57.519616331372944, 63.610494068690706, 58.97000067574637, 56.456583636147634, 46.4042078426906, 50.6317697933742, 48.131422315325054, 54.98797416687012, 56.609395367758616, 60.123686517987935, 56.86520372118269, 65.72626222882951, 54.85582290376936, 58.51487282344273, 52.343455042157856, 57.86894743783133, 54.411600249154226, 48.37363304410662, 46.644684995923726, 50.082466057368684, 52.26792812347412, 45.275278432028635, 47.28990166527884, 49.04929324558803, 47.28057370867048, 46.63776459012713, 52.84214462552752, 51.694086824144634, 54.609394618443076, 49.86216647284371, 52.70985439845494, 49.491758005959646, 50.645443848201204, 48.81883886882237, 49.69243240356445, 46.95565857206072, 47.40103810174124, 45.029805524008616, 44.99397366387503, 50.772015707833425, 54.06507274082729, 50.04597064426967, 56.42858239582607, 52.25862795966012, 45.63559464045933, 50.73293209075928, 54.3661208152771, 52.89868559156145, 54.60429464067732, 51.18457889556885, 47.99570662634713, 49.151657581329346, 49.60858154296875, 46.295989649636404, 50.82860878535679, 46.580865791865754, 51.727591037750244, 48.13738734381539, 51.94426713671003, 51.223808424813406, 54.17227649688721, 51.7725111416408, 52.45044687816075, 48.91921601976667, 47.73988785062517, 44.548142501286094, 47.35185180391584, 42.96078136989048, 48.11626482009888, 43.597962447575156, 51.46665491376604, 44.070815154484336, 51.06351695741926, 47.91127559116909, 49.923432213919504, 48.62899671282087, 54.28083862577166, 36.134617464882986, 27.263605662754603, 49.13227210726057, 54.90151425770351, 54.5311405318124, 56.9216821534293, 58.83416339329311, 57.20329959051949, 49.04971013750349, 46.52006558009556, 42.19472163064139, 48.922210693359375, 61.1774503162929, 58.810789653233115, 61.472443035670686, 56.73306288037981, 56.12357037408011, 53.384771142687114, 53.82512365068708, 57.3630108833313, 49.4352239881243, 55.30213001796177, 57.72573116847447, 64.31181744166783, 60.85192721230643, 65.71714619227818, 38.89711700166975, 4.7906396218708585, 0.7810628541878292, 1.0349715266908919, 0.34364207887223785, 12.427348239081246, 68.6546083177839, 57.618298121861045, 63.624744824000764, 71.63860252925328, 50.85164901188442, 65.11480685642788, 17.08366094316755, 29.402879578726633, 28.874932868140085, 43.89024189540318, 74.13306140899658, 39.23828397478376, 57.60269594192505, 58.455271175929475, 51.38331821986607, 0.5530130969626563, 0.21601739073438303, 0.2529472698058401, 0.12654057916785988, 0.17516688204237393, 0.16006225826484816, 0.2470948781285967, 0.07778052347046988], [0.02511666921366538, 0.01720237755216658, 0.02936761307397059, 0.13143452656056198, 0.1833014991134405, 0.02195552723216159, 0.04746543123785939, 0.07104701335941042, 0.0518270170183054, 0.014235927623563578, 0.020706356137192676, 0.25187423452734947, 5.107188258852277, 58.168449538094656, 49.02314370019095, 37.94980307987758, 24.854472398757935, 37.18884679249355, 30.399914809635707, 17.635450397218975, 7.2872185707092285, 37.060530935014995, 43.9661613873073, 54.941108567374094, 56.45301226207188, 48.50469691412789, 54.19325658253261, 7.828690818377903, 0.25121553987264633, 0.16959822656852858, 0.4949404331190245, 0.1250579258693116, 1.5889961293765476, 39.631277561187744, 54.72515855516706, 62.27703748430525, 56.78004312515259, 59.06416266305106, 46.26922171456473, 53.353146416800364, 53.73776742390224, 56.64249311174665, 51.77629096167428, 49.24154642650059, 53.85069302150181, 56.90292549133301, 54.84060287475586, 56.540771484375, 46.71558788844517, 48.78705780846732, 38.664449623652864, 46.16374111175537, 56.14403976712908, 54.54483890533447, 56.42492764336722, 54.669600759233745, 51.38876560756138, 52.00748184749058, 53.87920495441982, 54.42224836349487, 52.46561826978411, 48.774801186152864, 47.3969212940761, 46.01939923422677, 42.943796498434885, 44.19538245882307, 44.3143356187003, 40.645071847098215, 42.13613442012242, 46.308878558022634, 46.564728600638254, 45.98082283564976, 45.88654967716762, 46.991455691201345, 46.26369789668492, 46.90984909875052, 45.95059469767979, 44.77938549859183, 44.44533000673567, 42.30606998716082, 41.06230422428676, 39.28615358897618, 44.134728159223286, 46.35552181516375, 47.4285877091544, 43.48213597706386, 49.86703021185738, 45.264550413404194, 38.23542962755476, 42.822449684143066, 44.78739677156721, 43.410809244428364, 45.55926867893764, 42.38453599384853, 39.567538261413574, 39.194868155888145, 42.306813444410054, 40.390465532030376, 40.762868131910054, 43.69617176055908, 39.62665006092617, 42.682620661599294, 43.597774846213206, 41.621905190604075, 43.19673524584089, 43.622315883636475, 43.55515807015555, 43.47151565551758, 44.23539366040911, 43.32122264589582, 43.03349774224417, 41.24263777051653, 43.340792247227256, 41.77664852142334, 44.75926698957171, 46.47510378701346, 44.42321389062064, 43.02559069224766, 43.67450727735247, 47.14609479904175, 42.98484298161098, 59.06262016296387, 49.469753061022075, 35.00616747992379, 47.13973024913243, 47.648932456970215, 50.766339029584614, 48.54268271582467, 50.15850019454956, 51.29887328829084, 52.574117864881245, 44.07487637656075, 48.8589369228908, 13.346579279218401, 34.33838306154524, 57.52197871889387, 52.355920110430034, 50.67913218906948, 50.71651349748884, 51.20252261843, 49.727079595838276, 46.139467579977854, 51.82535566602434, 55.50699070521763, 57.20762137004307, 55.219835553850444, 49.183230195726665, 19.6063677242824, 0.3717492249395166, 0.11259135124938828, 0.1059565544128418, 0.02980188566393086, 12.465476478849139, 50.97413533074515, 48.7862274987357, 53.94720002583095, 55.91879653930664, 45.69161449159895, 45.694529260907856, 1.9238146202904838, 29.698087692260742, 22.56809295926775, 46.97317498070853, 33.721567153930664, 25.540970052991593, 55.40787812641689, 46.93872928619385, 15.129309858594622, 0.6132727063127926, 0.16243159398436546, 0.01724803278089634, 0.04057639750785061, 0.1335349588521889, 0.18170527262347086, 0.11373941893024103, 0.1361552303923028, 0.013979648339695163, 0.03854659392631479, 0.028248417058161328, 0.011124847955735666, 0.07100522238761187, 0.10681329308343784, 0.014638848502987196, 0.06253780424594879, 0.03207654199962105, 0.012262065861640232, 0.16735224851540156, 0.08617987097906214, 5.346244505473545, 66.70597212655204, 54.16055488586426, 31.56535700389317, 32.41053935459682, 44.54624564307076, 25.214649643216813, 25.397793735776627, 7.574061053139823, 40.54385396412441, 50.0453314099993, 64.8063554763794, 63.35090936933245, 54.85844932283674, 58.22041164125715, 9.11718213558197, 0.20729409025183745, 0.24966666155627795, 0.21056593182895864, 0.20692709780165128, 1.6092950744288308, 45.85879857199532, 57.548882143838064, 65.52267306191581, 58.705642563956125, 61.079168047223774, 47.29371622630528, 55.586794240134104, 55.21168531690325, 57.13165324074881, 51.336768763405935, 50.38052988052368, 51.14484909602574, 56.65044185093471, 54.99635369437081, 55.743747098105295, 46.23086765834263, 48.6863124029977, 42.227458068302695, 48.83200570515224, 56.18074362618582, 55.5014773096357, 55.25417007718767, 52.17911972318377, 51.29443686349051, 52.99287189756121, 54.836656297956196, 53.943590436662944, 54.51924521582467, 49.77627631596157, 49.90291765757969, 47.469495228358674, 47.26578794206892, 45.033217089516775, 44.524716649736675, 42.88680042539324, 45.7626632962908, 44.8283668245588, 45.638564995356965, 45.279985836574006, 48.696915354047505, 49.99532869883946, 50.06074251447405, 48.334132535117014, 46.04787642615182, 44.50874968937465, 43.95320299693516, 44.346259117126465, 42.12352343967983, 38.7402023587908, 43.57446363994053, 47.5058343069894, 46.9345395224435, 46.669371945517405, 49.47014910834176, 44.98293645041329, 40.14916501726423, 49.30867297308785, 47.8031234060015, 49.58660439082554, 50.53318875176566, 46.989096777779714, 44.2120372908456, 44.017254965645925, 43.879579884665354, 44.56706592014858, 47.30833523614066, 47.1955520766122, 42.770748138427734, 45.06374052592686, 47.786315713609966, 46.5662259374346, 47.980663776397705, 45.99240895680019, 48.099224363054546, 44.74998419625418, 44.2274831363133, 43.96001917975289, 43.301767689841135, 42.34239864349365, 42.81977115358625, 43.26604005268642, 47.22254582813808, 48.11488560267857, 47.92860787255423, 46.19320147378104, 46.66406004769461, 48.71079438073294, 43.73855924606323, 65.71006597791398, 64.27315071650914, 40.33454295567104, 50.967478956495015, 50.12735142026629, 54.068550314222065, 52.710677759987966, 53.216579573495046, 53.48226131711687, 53.17917742047991, 44.073052474430625, 48.02428456715175, 17.977558851242065, 38.30625261579241, 58.7113470349993, 54.3080929347447, 52.563507965632844, 51.38502747671944, 52.27255909783499, 50.2913566998073, 46.81416198185512, 52.56106914792742, 55.176986013139995, 58.1156883920942, 54.44286714281355, 52.150024141584126, 20.900049345833914, 1.1553149776799339, 0.09544857790959732, 0.6471656390598842, 0.11716142030698912, 15.138825416564941, 58.143488134656636, 51.01516096932547, 58.50892516544887, 60.66978018624442, 49.0490847996303, 42.26289735521589, 5.140396305492946, 39.86323274884905, 24.351582629340037, 47.80430112566267, 41.93259389059884, 26.898324966430664, 57.62878295353481, 55.4447591645377, 15.546208722250801, 0.6310432127543858, 0.12917284720710345, 0.01022947604568409, 0.018549264475171055, 0.1196659609143223, 0.06114062600369964, 0.07593942726297037, 0.0899130485153624, 0.18447167346520082, 0.13445419738335268, 0.12392668585692133, 0.13770838347928865, 0.2547449804842472, 0.21491481204118046, 0.15368727248694214, 0.12154517721916948, 0.1802102564168828, 0.1472891215234995, 0.24059652111360005, 0.4628155454993248, 8.730881401470729, 82.9320377622332, 60.80120536259243, 53.840430532182964, 34.16234697614397, 53.69145768029349, 36.695007051740376, 25.912966183253697, 13.390722053391592, 48.530742236546104, 54.092997550964355, 67.80312742505754, 66.60006768362862, 60.462765557425364, 66.11110210418701, 11.511001569884163, 0.3040209806391171, 0.4556206858583859, 0.6878681321229253, 0.42424758789794786, 2.5255212358066013, 54.56889009475708, 60.02682168143136, 69.95132282802037, 61.53856904166085, 62.84219006129673, 50.14564255305699, 58.67131846291678, 57.881120681762695, 59.2729560307094, 57.00386197226388, 52.658462047576904, 53.423111302512034, 59.841228348868235, 57.92107629776001, 59.985875947134836, 47.423696177346365, 52.16525111879621, 43.179562773023335, 50.57442283630371, 59.526732036045615, 57.61212464741298, 56.09856728145054, 52.362343720027376, 53.91612073353359, 55.68004253932408, 56.394980907440186, 56.77767378943307, 55.096362590789795, 53.624741077423096, 51.88770532608032, 49.85491255351475, 47.14247826167515, 48.063027722494944, 47.68455934524536, 46.160201004573274, 47.31135770252773, 47.7129670551845, 47.761722564697266, 49.43695756367275, 48.43609734943935, 52.12184919629778, 52.58283090591431, 52.04032250813076, 50.91530493327549, 49.96480178833008, 50.19246646336147, 49.36032935551235, 46.34663506916591, 41.86569316046578, 49.44430180958339, 52.336635385240825, 52.60517283848354, 50.51267419542585, 56.621037074497764, 49.7787880897522, 44.914118017469136, 53.99198463984898, 54.85420397349766, 54.85001768384661, 57.60489157267979, 51.25271987915039, 47.133160727364675, 44.47363349369594, 50.77216509410313, 47.80333532605852, 49.40922730309622, 52.463033539908274, 48.541848931993755, 50.74812780107771, 51.62125580651419, 52.37851912634713, 53.00341231482369, 49.05955573490688, 50.1537059375218, 47.108275754111155, 47.63742276600429, 44.95371232713972, 45.566765785217285, 44.96187993458339, 45.612762859889436, 45.1132047516959, 46.835079533713206, 50.16472578048706, 50.20290960584368, 46.11686161586216, 49.564922537122456, 52.267990657261436, 47.945804664066856, 57.36058248792376, 54.531230858394075, 45.70692137309483, 51.795825822012766, 52.30211673464094, 56.0957532610212, 55.47041538783482, 55.04761750357491, 54.430509771619526, 54.919068881443565, 46.49100821358817, 51.39855561937605, 24.14532014301845, 39.84404182434082, 61.301788330078125, 57.87291485922677, 55.57834870474679, 54.50941004071917, 55.56890957696097, 52.774896485464915, 50.57245997020176, 58.75067383902413, 57.439600876399446, 61.88671548025948, 58.6301851272583, 54.56314046042306, 25.542146035603114, 2.4096467792987823, 0.17112250120512076, 0.9753567427396774, 0.14413468007530483, 16.22545072010585, 60.38060310908726, 58.2446608543396, 64.37981946127755, 66.34713935852051, 54.77948304585048, 53.68735824312483, 5.329243566308703, 39.91204731804984, 27.65167818750654, 69.03110340663365, 46.31847749437605, 35.659534386226106, 68.68067795889718, 63.136988231113975, 29.800500665392192, 0.9657179628099714, 0.36864590431962696, 0.44267247351152555, 0.13413793221116066, 0.30875601513045176, 0.22914105866636547, 0.20951897943658487, 0.23849175976855413], [0.07383847249937908, 0.08601163500653845, 0.04425555008596607, 0.0822605916431972, 0.0517613009017493, 0.00955935740577323, 0.02743389514008803, 0.059359614072101455, 0.23291583039930888, 0.025776958425662348, 0.023214219869779687, 0.08145097722964627, 0.36065471598080223, 46.1229065486363, 51.140155587877544, 43.584594113486155, 31.396811076572963, 40.84812947681972, 37.411237784794395, 26.393204825265066, 2.7007165891783576, 42.21271399089268, 50.210021087101524, 45.905219486781526, 59.507645334516255, 48.20594869341169, 60.78974083491734, 20.718812533787318, 0.06930274409907204, 0.21243221525635037, 0.41029161534139086, 0.503049795116697, 0.13543531830821717, 26.881084748676844, 57.007634844098774, 62.20647157941546, 60.27557413918631, 57.79200308663504, 52.85276147297451, 57.50272526059832, 57.973080090114046, 58.240564891270225, 54.267776012420654, 51.19311475753784, 50.133764607565745, 56.9067747933524, 54.007691042763845, 58.347740854535786, 45.404205730983186, 46.58921752657209, 49.11620092391968, 51.502639634268625, 53.74393047605242, 55.920867102486746, 52.21646976470947, 53.31884663445609, 54.25354610170637, 53.62578330721174, 53.15091214861189, 53.69926050731114, 52.93248857770647, 50.76290314538138, 46.600358963012695, 46.23971618924822, 48.31040096282959, 44.61567551749093, 42.95657076154436, 42.32438891274588, 41.79516894476754, 43.94972889763968, 43.25669819968087, 45.839437416621614, 49.36810786383492, 48.14844192777361, 47.51837927954537, 47.87092740195138, 48.106711047036306, 47.997617380959646, 46.35807875224522, 46.426480293273926, 42.57102564402989, 39.19965546471732, 39.645865304129465, 46.51264837809971, 45.32759141921997, 40.59566668101719, 44.38629116330828, 40.41415541512625, 35.32537119729178, 41.83158792768206, 41.111327239445274, 41.26691130229405, 42.03196702684675, 42.93846375601632, 42.04836824962071, 41.105462959834504, 39.32261426108224, 43.41155617577689, 43.22599411010742, 41.86837863922119, 42.486431326184956, 43.252914905548096, 43.09947088786534, 43.03914662769863, 41.50894832611084, 41.90673269544329, 43.98066227776663, 43.135983671460835, 43.63815777642386, 41.47875492913382, 43.541081019810264, 41.199902875082834, 44.34690529959542, 42.349937438964844, 41.72092744282314, 44.29225771767752, 45.01565204347883, 44.324316705976216, 45.25941916874477, 47.25829083578927, 47.283509322575156, 47.4895407812936, 66.2134907586234, 64.23495646885463, 49.391693523951936, 49.99443238122122, 49.385725021362305, 50.62788922446114, 50.981465680258616, 53.41052116666521, 47.94147941044399, 50.592672279902864, 34.88352482659476, 35.183673109327046, 54.01648746218, 55.78551966803414, 52.316398756844656, 51.12187835148403, 49.76983533586775, 49.424555029187886, 51.14942795889718, 51.324838706425254, 51.78294733592442, 56.37853799547468, 57.07962512969971, 57.458962031773154, 45.77293273380825, 8.42063217503684, 1.0144004076719284, 0.570829906633922, 0.38061200508049553, 0.5157158183200019, 31.15652847290039, 64.13972445896694, 46.57046086447579, 61.30081558227539, 41.554076875959126, 53.9682218006679, 27.75806553023202, 4.279969607080732, 45.52220351355416, 11.670927388327462, 42.03721291678292, 30.806262833731516, 29.60089976446969, 41.939479555402485, 49.97003378186907, 4.219453402927943, 0.3740029925746577, 0.05745719865496669, 0.013031530509968954, 0.01780136112522866, 0.0372891565784812, 0.0033427872902913286, 0.03477658211652722, 0.09621226228773594, 0.020959264798355953, 0.04317190930513399, 0.037522039974906614, 0.007785408175550401, 0.035849189917956076, 0.07939480577728578, 0.06309174666447298, 0.07643846941313573, 0.07607820803033453, 0.0393382950153734, 0.02967684862336942, 0.09754609928599425, 0.11255221334951264, 47.99629027502877, 61.37478610447475, 40.842136655535015, 30.544617993491038, 56.91601242337908, 30.998356206076487, 34.884285654340474, 4.582029947212764, 40.57689264842442, 56.16182368142264, 52.73746306555611, 64.92120225088937, 51.84566177640642, 66.50320284707206, 22.407626049859182, 0.10062927420118026, 0.5029311329126358, 0.656819401042802, 0.5094685735447066, 0.0746025029303772, 31.52177095413208, 60.03112956455776, 63.02599770682198, 62.96253980909075, 58.961197308131624, 54.22775786263602, 57.94920955385481, 59.239257267543245, 57.3158986227853, 55.25006716591971, 53.23930018288748, 50.22950036185128, 56.52435636520386, 55.19384234292166, 57.798412799835205, 44.61275379998343, 45.543645654405864, 48.45048359462193, 52.11067649296352, 56.826613426208496, 55.081628935677664, 53.22257934297834, 53.36997495378767, 54.61648178100586, 54.824639388493125, 52.39296095711844, 53.77912310191563, 53.04066855566842, 52.92856284550258, 49.70860086168562, 48.39042336600167, 47.04404660633632, 46.983385358537944, 45.255632400512695, 41.56804622922625, 42.6429568699428, 45.12299823760986, 43.15832560403006, 44.9907740184239, 47.8118850844247, 49.905818530491416, 49.88138171604702, 48.100346497126985, 48.32253251756941, 46.44281898226057, 44.117378507341655, 44.667891229902, 43.2590571131025, 40.829317229134695, 41.40374912534441, 48.235388210841585, 49.03942332948957, 43.50265053340367, 45.253659112112864, 42.421677589416504, 39.923265184674946, 45.390253748212544, 48.851036821092876, 47.806184087480815, 47.773263522556846, 47.57034485680716, 45.55085441044399, 42.820980140141074, 41.94993659428188, 45.0704733303615, 46.82568556921822, 46.85111945016043, 47.06688533510481, 48.544294697897776, 48.62736736025129, 48.89957693644932, 48.13448994500296, 48.00913054602486, 46.88699647358486, 44.55472591945103, 45.11210346221924, 41.93699904850551, 42.61177682876587, 41.64784976414272, 45.37152140481131, 43.70124741962978, 43.69442776271275, 46.64032847540719, 46.99859149115426, 46.56708403996059, 47.20295190811157, 49.85268218176705, 50.848626545497346, 47.67593663079398, 64.90321336473737, 67.93622711726597, 53.94189507620675, 53.931208746773855, 52.24632964815412, 52.07966668265206, 53.47560494286673, 55.667084148951936, 51.34744814464024, 50.924917766026084, 38.297115734645296, 37.17153882980347, 55.81751612254551, 56.031899315970286, 55.4458361353193, 52.47400821958269, 50.96173974445888, 50.39000722340175, 51.78059884480068, 52.18314620426723, 53.30302211216518, 57.32817608969552, 57.807956150599885, 55.67483139038086, 44.58390140533447, 10.868714434759957, 1.8362056527818953, 1.2247867584228516, 0.2667367841516222, 0.5944541075399944, 34.1981440952846, 64.75311143057687, 49.69406870433262, 64.14723546164376, 48.53278153283255, 55.30087586811611, 29.84462172644479, 6.713861908231463, 47.86995465414864, 13.661396077701024, 43.60648441314697, 39.35247761862618, 27.83925175666809, 44.31432172230312, 61.26375389099121, 6.1206086448260715, 0.2617960992668356, 0.08396182821265288, 0.01935832418634423, 0.0670774138665625, 0.014381559898278542, 0.0738484062520521, 0.01529925306593733, 0.053289246412792375, 0.11011553302939449, 0.15199363550969533, 0.0839067990226405, 0.21656179295054503, 0.11727709695696831, 0.11015612299421004, 0.12544957628207548, 0.1680298200143235, 0.2370340765586921, 0.14873243336166653, 0.09490676091185637, 0.2660271722291197, 0.5356909121785844, 67.82721682957241, 65.75838375091553, 58.19386952263968, 43.152044432503835, 56.778108051845, 50.43152270998274, 34.867074966430664, 7.937265975134713, 50.590872696467805, 59.1189353125436, 56.78285714558193, 68.59589603969029, 60.042830330984934, 73.54512568882534, 24.608752829687937, 0.3177340648003987, 1.5855441774640764, 1.1460094941513879, 1.2334447566952025, 0.5357596884880746, 37.7485728263855, 66.82662064688546, 67.77048478807721, 67.05889197758266, 63.72078282492501, 58.329216957092285, 61.46916348593575, 62.284479004996165, 61.73404966081892, 57.0690986088344, 56.17618213381086, 54.06712245941162, 59.04555538722447, 56.17614391871861, 59.20110470908028, 46.859252316611155, 47.05995103291103, 49.58968244280134, 53.70264775412423, 56.44705070768084, 58.97055653163365, 53.53193398884365, 55.38425772530692, 55.68151903152466, 56.79511376789638, 55.081080027988975, 55.63910027912685, 53.966331890651155, 55.12964446204049, 51.32597473689488, 49.47579104559762, 48.80124602999006, 48.95028141566685, 47.30166149139404, 44.2088862827846, 45.369329248155864, 47.82573284421648, 43.164332321711946, 48.45962047576904, 52.026231561388286, 53.0097907611302, 52.46326977866036, 51.997059549604145, 53.577576705387656, 50.286274092538015, 49.25163868495396, 50.91093104226248, 49.43176031112671, 43.61862986428397, 45.82656935283116, 52.9873480796814, 55.81743969236101, 45.91351216179984, 51.90291493279593, 46.11837979725429, 43.29705681119646, 52.00469561985561, 53.91707958493914, 52.018786566598074, 52.38490799495152, 52.12858894893101, 51.08158227375576, 48.85520921434675, 47.254285199301584, 50.641389574323384, 50.82977608272007, 49.64268330165318, 52.93320771626064, 55.40429285594395, 51.88336270196097, 54.736890588487896, 50.724389280591694, 49.44144262586321, 50.7459773336138, 47.69379002707345, 45.883850302015034, 43.6033160345895, 44.96220302581787, 44.70311164855957, 47.66231121335711, 45.89832339968, 44.97283376966204, 49.30969435828072, 48.78720719473702, 49.19245045525687, 48.661180768694194, 51.91256945473807, 52.247326714651926, 50.548787457602366, 61.39910479954311, 65.350510597229, 56.14246252604893, 55.74442802156721, 53.821239607674734, 56.28703022003174, 56.21518932070051, 58.16206414358956, 53.277136598314556, 52.176364762442454, 40.38466031210763, 36.264392444065635, 57.99623843601772, 59.04397119794573, 57.423241342817036, 55.41138349260603, 53.94649478367397, 53.83585514341082, 56.54408924920218, 54.72538089752197, 57.571092060634065, 61.653902190072195, 61.58365590231759, 58.497676031930105, 48.67521612984793, 15.924546820776802, 2.08010761652674, 1.7130620777606964, 0.8744458290083068, 0.6299972374524389, 38.19571719850813, 69.8797424861363, 54.654929637908936, 70.02168028695243, 53.13617501940046, 63.06906958988735, 35.65587963376726, 6.890276670455933, 58.4185916355678, 15.258935451507568, 62.20845876421247, 42.437960692814414, 43.308729784829275, 49.43735013689314, 71.98964636666435, 10.76705186707633, 0.7023512178233692, 0.21760319492646626, 0.09944358853889362, 0.1560656598636082, 0.10598093417606183, 0.13719072911356175, 0.06980114842631988, 0.20212601471160138], [0.03990677843934723, 0.08983135968446732, 0.06107117115919079, 0.12013615854084492, 0.06002757751515933, 0.00969226036353835, 0.032891666117523394, 0.07273572417242186, 0.013085609750955232, 0.05458657483437231, 0.044965100940316916, 0.17304162893976482, 0.15551531368068286, 21.295306307928904, 58.25687231336321, 39.377949714660645, 35.346941879817415, 31.681120940617152, 30.6521726335798, 30.371600900377544, 3.4136417167527333, 22.63819854600089, 73.25553866795131, 47.61929144178118, 54.5024653162275, 56.795117241995676, 50.19454050064087, 44.18244143894741, 0.06130272801965475, 0.30493412592581337, 0.7173227944544384, 0.13881918601691723, 0.5144602028386933, 14.190416284969874, 58.194303785051616, 55.51692662920271, 64.9682901927403, 58.60037040710449, 54.659532819475444, 57.503673689705984, 62.9662640435355, 58.29922158377511, 61.019295419965474, 54.585333006722585, 54.79487330572945, 57.334161962781636, 57.132257734026226, 56.95207704816546, 47.465791838509695, 38.86221967424665, 45.42196880068098, 51.05796882084438, 58.00126198359898, 54.365662234170095, 53.00084842954363, 54.004491397312705, 51.94222436632429, 51.533395835331504, 52.71057006290981, 50.87774644579206, 52.68379865373884, 53.02088703427996, 50.891896452222554, 45.05543048041207, 44.96085854939052, 46.62792246682303, 42.65873622894287, 41.70908076422555, 41.367778301239014, 40.203329699380056, 42.486000537872314, 44.417408670697895, 44.10080705370222, 47.41880464553833, 47.48662601198469, 49.460630076272146, 47.54809325081961, 49.9421124458313, 45.93280036108834, 45.80479717254639, 40.870520046779085, 40.13562297821045, 40.62358454295567, 46.78376013892037, 42.67073229381016, 32.355377605983186, 36.80129017148699, 37.854671818869456, 35.36827284949166, 39.182597637176514, 41.80432667051043, 41.31677852358137, 42.576410497937886, 44.67642709187099, 41.660280091421946, 40.711760657174246, 39.71203647341047, 40.197267396109446, 43.51928104673113, 45.42673873901367, 42.60556166512625, 44.607285567692344, 45.401110308510916, 43.27133805411202, 42.67196559906006, 41.81991842814854, 41.22474615914481, 40.49583148956299, 41.557085445949006, 41.53016465050833, 40.453044482639854, 38.76051194327218, 41.19710622514997, 42.7610102381025, 42.99755123683384, 45.462087699345176, 43.30860471725464, 45.50082738058907, 43.20727913720267, 45.35173640932356, 46.23924718584333, 48.48688868113926, 46.879242283957346, 53.70316539491926, 51.95557532991682, 52.188576221466064, 49.68881934029715, 50.32857125146048, 48.91215664999825, 52.22553368977138, 53.75380039215088, 52.05927719388689, 46.18521104540144, 48.20926298413958, 52.06077800478254, 55.836950234004426, 52.83955989565168, 51.53952762058803, 47.91242551803589, 52.32260349818638, 50.4591417993818, 54.1240907396589, 54.64938497543335, 56.78740126746041, 56.173534870147705, 64.32848617008754, 36.875486510140554, 3.5519008806773593, 0.43416871981961386, 1.5352197864225932, 0.227679792791605, 3.3439382570130483, 44.14637334006173, 45.64569732121059, 51.03638424192156, 55.90638705662319, 39.41266291482108, 62.1042149407523, 14.810142619269234, 13.640291793005806, 39.79826709202358, 17.697883435658046, 54.97003391810826, 23.983218669891357, 36.70684330804007, 45.705649852752686, 49.49623611995152, 2.287715013538088, 0.25228976937276976, 0.16423367442829268, 0.10873278722699199, 0.03168009773695043, 0.11039775609970093, 0.09425518408949886, 0.022908724744671156, 0.05176776734047702, 0.045135586256427426, 0.05658869418714728, 0.032954339004520855, 0.042374491558543274, 0.046494593511202505, 0.03186578902282885, 0.040820490302784104, 0.04210791889844196, 0.06427885046494858, 0.11691409429269177, 0.04551230550610593, 0.1569039627377476, 0.18581456212060793, 19.656323535101755, 68.11708177839006, 41.853565079825266, 29.722548825400217, 44.719175883701865, 31.414938926696777, 30.046519007001603, 7.185338003294809, 21.316439253943308, 79.93686389923096, 48.822309494018555, 62.92071165357317, 61.140944480895996, 57.81604732785906, 49.49870620455061, 0.17330308205315045, 0.37855913809367586, 1.4213396800415856, 0.2487097643315792, 0.5962517367941993, 16.706462349210465, 63.53420979636056, 55.807305744716096, 65.10785865783691, 58.330759457179475, 58.17131567001343, 56.89391367776053, 63.10258075169155, 58.986169133867534, 62.39172445024763, 53.22495215279715, 54.968421936035156, 55.30309929166521, 58.36702210562569, 55.156259536743164, 48.09639992032732, 39.69174425942557, 47.27689463751656, 51.597121238708496, 60.11231231689453, 54.76755993706839, 56.52957098824637, 54.31989097595215, 55.134077412741526, 53.32345676422119, 54.928125858306885, 53.421318667275564, 56.080811159951345, 54.61447375161307, 52.88015474591936, 47.49012095587594, 48.63008757999965, 47.76158707482474, 43.460613931928364, 43.199524947575156, 40.97471175874983, 42.08366162436349, 42.50491006033761, 44.67130626950945, 43.86688552583967, 48.58899245943342, 48.97390181677682, 52.71625368935721, 47.44466584069388, 50.133764607565745, 47.4196766444615, 45.8563562801906, 42.79081801005772, 42.265791279929026, 42.472135407584055, 48.94596658434187, 46.78370107923235, 34.19698027202061, 40.14421442576817, 41.50386919294085, 39.89802932739258, 45.410903794424875, 47.23960018157959, 48.24075222015381, 49.44882508686611, 47.57873828070504, 45.988931383405415, 44.0095876285008, 43.534737314496724, 42.92313950402396, 47.164372035435264, 46.21136406489781, 44.96605927603585, 48.23748656681606, 48.323387145996094, 48.002005168369834, 47.20179155894688, 46.469329833984375, 43.92071322032383, 41.77507128034319, 42.32161658150809, 42.13087463378906, 41.882229873112266, 42.31282016209194, 40.71116311209542, 44.72298697062901, 45.795997279030935, 48.44889940534319, 46.1249041557312, 48.230218751089915, 47.36775623049055, 47.832423959459575, 48.79724734170096, 52.26821994781494, 47.93021290642874, 50.586818422589985, 53.87601225716727, 53.54991592679705, 53.033369473048616, 52.76605837685721, 50.75261981146676, 54.93785681043352, 54.06715372630528, 52.926151820591514, 45.59679242542812, 48.64175360543387, 52.725220339638845, 55.75732735225132, 53.69854136875698, 52.060566084725515, 48.95453371320452, 54.74612821851458, 49.921048981802805, 54.938030515398296, 54.66960423333304, 56.93130540847778, 55.72495916911534, 62.86216613224575, 35.44902828761509, 3.8035959005355835, 0.4889047827039446, 2.2172852499144415, 0.5042282747370856, 4.269543835094996, 50.73820229939052, 48.81695243290493, 57.510371753147666, 56.24252005985805, 42.892206123897004, 59.93635613577706, 19.764477457318986, 12.925188405173165, 43.89715882710048, 14.930532319205147, 62.01149123055594, 30.802191189357213, 35.928752762930735, 52.54477909633091, 55.31711033412388, 1.7823022880724497, 0.14901089056261949, 0.097741917707026, 0.05566808840792094, 0.06088294554501772, 0.08152818772941828, 0.025270511762105992, 0.07900312822312117, 0.08926983124443463, 0.13668839606855596, 0.14583848150713102, 0.09084066695400647, 0.1147921931530748, 0.20471841203314917, 0.12989362781601294, 0.13070084021559783, 0.12687405198812485, 0.21261341124773026, 0.2911401332489082, 0.11809782577412468, 0.2724611227001463, 0.22831615007349423, 33.60657794134957, 80.20697511945451, 48.84372384207589, 53.33446618488857, 42.85666956220354, 46.3149790763855, 33.75085381099156, 8.340957181794302, 28.257161583219254, 80.08932127271379, 56.91559205736433, 66.28360503060478, 66.34834834507534, 64.89898885999406, 53.367800167628694, 0.19186402750866755, 1.9854777114731925, 1.52595696917602, 0.4940603460584368, 0.5462862093533788, 19.112215314592632, 68.7695176260812, 59.162938254220144, 70.0943306514195, 62.75032792772566, 61.46832970210484, 59.77781908852713, 67.82431943075997, 60.85734680720738, 68.60925047738212, 54.72517939976284, 57.92689541407994, 59.147221429007395, 60.16447244371687, 56.52394642148699, 51.230270249503, 39.5776617867606, 47.28972796031407, 52.17481531415667, 60.94523457118443, 56.15361785888672, 57.52888175419399, 55.96917445319039, 57.096165316445486, 55.70952374594552, 54.569991384233745, 54.32465744018555, 58.49770382472447, 57.520516123090474, 55.50714356558663, 47.809630393981934, 50.43670606613159, 50.38400397981916, 45.07259947913033, 45.71021481922695, 43.780477728162495, 44.397856439862935, 44.19531645093645, 46.29103210994175, 45.963566984449116, 50.680028506687705, 50.060961382729666, 53.7755343573434, 51.21449089050293, 55.86567061288016, 50.12364455631801, 50.3070387840271, 46.77367830276489, 48.002873693193706, 46.53384385790144, 54.36748613630022, 49.04352971485683, 34.71484688350132, 42.378671714237754, 45.75801842553275, 40.800051416669575, 48.82380335671561, 54.56968913759504, 54.3929443359375, 53.81679623467581, 52.79612670625959, 50.43249198368618, 48.71060330527169, 48.1303905078343, 48.35450117928641, 49.81383827754429, 51.80508777073452, 49.56111492429461, 51.88442577634539, 52.63207973752703, 54.14796822411673, 50.12282119478498, 48.189450195857454, 46.378329277038574, 44.70635993140084, 44.786371912275044, 44.03830105917794, 42.025300230298726, 41.349598339625764, 44.87235586983817, 44.95767627443586, 47.01711886269705, 50.22657169614519, 46.657278605869834, 50.82532228742327, 48.245414461408345, 48.00201906476702, 51.3001378604344, 53.508685316358296, 50.00393751689366, 50.9904670715332, 54.920552321842735, 55.79787356512887, 55.49629742758614, 53.37743384497506, 51.7826555115836, 57.05364581516811, 57.50723811558315, 55.47641863141741, 47.65633576256888, 49.33165066582816, 55.95340551648821, 59.474655287606375, 58.14808784212385, 55.562982763562886, 52.070651394980295, 57.47781944274902, 54.29448141370501, 58.842973709106445, 60.19636467524937, 60.593391690935405, 59.79945577893938, 66.58011940547398, 44.30692189080374, 6.553282959120614, 0.7444264143705368, 4.135056674480438, 0.8067999045763696, 4.866289002554757, 56.62903445107596, 53.71363285609654, 61.69717557089669, 63.469793047223774, 47.93959992272513, 69.39581435067313, 23.268247297831945, 17.682932649339946, 53.08190264020647, 24.39613274165562, 81.68598951612199, 31.413848059517996, 54.507888385227744, 50.521765913282124, 72.63491167340959, 3.6994745390755788, 0.39556800254753655, 0.18166546975927694, 0.2286354957946709, 0.10165540235383169, 0.21633186457412584, 0.20236375981143542, 0.11507208884826728, 0.11352232843637466], [0.1507734531270606, 0.09496104371334825, 0.07183503678866796, 0.08284805369164262, 0.16450825040893896, 0.029693913779088428, 0.09587464361850705, 0.04976031809513058, 0.04646623753277319, 0.05497066636702844, 0.1106170586177281, 0.052450020731027634, 0.24495925701090268, 4.221046711717333, 48.152235644204275, 49.75452845437186, 36.184422152382986, 32.411758763449534, 41.19643919808524, 35.857457297188894, 8.929825697626386, 8.236842768532888, 70.47277123587472, 68.76768330165318, 40.549714769635884, 52.745783533368794, 51.03681155613491, 53.80182981491089, 5.822847502572196, 1.11154034946646, 0.9983072940792356, 0.3322544427854674, 0.6982145969356809, 1.3269151811088835, 47.68357270104544, 53.64492212023054, 63.063483238220215, 59.043304170881, 63.68775108882359, 57.836579254695344, 61.387369292122976, 59.25795486995152, 57.17349181856428, 57.246135234832764, 57.92739568437849, 59.08374963487898, 59.42478806631905, 53.73002018247332, 47.8193405015128, 49.08745622634888, 49.34966734477452, 50.88885314123971, 55.6834089415414, 51.477831091199604, 55.16146373748779, 53.15162781306675, 53.1276078905378, 55.048100403376985, 52.74342809404646, 52.43331609453474, 51.700107438223704, 52.22707618985857, 47.12152944292341, 46.21685661588396, 45.089976923806326, 46.081773212977815, 43.43810871669224, 42.70288160869053, 40.51067631585257, 42.44949470247541, 41.23601961135864, 40.87376485552107, 42.59549372536795, 42.9887478692191, 46.07454708644322, 49.42934581211635, 48.938125542231965, 48.671874046325684, 47.10914427893502, 47.72350747244698, 42.99037374768938, 38.89572041375296, 44.23953826086861, 46.433682101113455, 42.65203816550118, 22.830512523651123, 28.61277907235282, 37.895065171378, 32.04445961543492, 35.22952774592808, 37.59422206878662, 43.02776895250593, 42.53026056289673, 45.39794192995344, 43.322143282209126, 43.564878599984304, 38.37025594711304, 40.01436301640102, 44.183184896196636, 45.0161384173802, 44.49367209843227, 45.22750261851719, 43.645366532461985, 45.0245874268668, 43.43647241592407, 40.891520977020264, 38.06987837382725, 40.588586466653005, 41.924565247126985, 40.786766460963655, 39.51047270638602, 40.58214201245989, 42.599707807813374, 44.74318538393293, 44.066271032605854, 45.23208842958723, 45.25520856039864, 46.37751286370413, 45.14790752955845, 48.74401371819632, 44.85249791826521, 46.61512041091919, 46.51771708897182, 47.77102620261056, 45.714112758636475, 50.288125787462505, 49.44839777265276, 53.80501208986555, 50.25628219332014, 53.058289187295095, 49.61122880663191, 51.6527658871242, 42.39613948549543, 48.99359648568289, 52.43735647201538, 53.62079797472273, 50.99241951533726, 52.20189939226423, 51.730867113385884, 54.99503353663853, 54.0286294392177, 59.1884103502546, 52.76059014456612, 58.08913932527815, 53.799140862056184, 59.4809364591326, 7.380302718707493, 1.3636133947542735, 0.10958068458629505, 1.2525702161448342, 0.05992809749607529, 17.915771995271953, 57.439996923719136, 49.473928928375244, 52.889229093279155, 54.760608264378135, 48.00447872706822, 59.37487915584019, 7.644002488681248, 25.410453353609356, 36.28541074480329, 21.394323348999023, 45.70824500492641, 15.009147712162562, 39.73886694226946, 48.12266411100115, 28.283752339226858, 0.1092889823817781, 0.09302504759814058, 0.10734936288957085, 0.0275643876021994, 0.03819136727335198, 0.036293141809957366, 0.016473500324147086, 0.05240925773978233, 0.06297686390046563, 0.06824044324457645, 0.08986137807369232, 0.04437314359737294, 0.01551796356216073, 0.03062639052846602, 0.0301717109978199, 0.05818666451211486, 0.04937587711693985, 0.06706222825284515, 0.16803455618875368, 0.02074260008521378, 0.07734478863754443, 0.17985154209392412, 3.4394447207450867, 56.93005125863211, 55.42237901687622, 32.89871631349836, 34.01554543631417, 49.02202156611851, 25.403513840266637, 15.112321513039724, 7.464404582977295, 72.34892381940568, 67.4677517754691, 44.40899092810494, 59.10188443320138, 55.86058800561087, 58.16340862001692, 6.049345314502716, 0.45422127523592537, 1.6077517058168138, 0.054513191272105486, 1.0812662882464272, 1.5419688756976808, 52.378362791878835, 55.941934040614534, 65.50479534694126, 58.94205502101353, 64.37772805350167, 56.542901107243125, 62.61877073560442, 59.295829500470845, 58.625807762145996, 56.80414990016392, 57.949911321912495, 57.29957035609654, 61.26211411612374, 53.27849497113909, 48.30726385116577, 50.76000574656895, 49.26494795935494, 52.378911699567524, 56.11132764816284, 54.308009556361604, 56.449656282152446, 55.14989846093314, 55.95974574770246, 58.16919299534389, 54.61113861628941, 53.63035869598389, 54.52549512045724, 55.20532076699393, 51.98285048348563, 49.67037187303816, 47.22615194320679, 47.79865918840681, 43.705666473933626, 43.411153180258616, 41.43107986450195, 43.290112086704795, 41.141385146549766, 43.974846635546, 42.85576629638672, 46.930624212537495, 48.69767965589251, 49.435418537684846, 50.22236803599766, 47.883250032152446, 49.366541045052664, 49.060066427503315, 46.14349058696202, 39.82041794913155, 46.872422627040315, 48.943993295942036, 46.49026128223964, 25.164009434836252, 32.51412657329014, 41.332193102155415, 36.0573604447501, 38.70619440078735, 46.104104723249165, 50.792380877903526, 48.27697317940848, 48.28698900767735, 48.51287841796875, 44.98068175997053, 41.56433589117867, 43.66529049192156, 46.68218789781843, 47.62751463481358, 49.36969205311367, 49.19660200391497, 49.70958750588553, 47.709103856767925, 47.08321360179356, 42.440201486860005, 40.19290392739432, 42.947201115744456, 42.358452456338064, 41.898985454014365, 39.364435468401226, 42.551344871520996, 43.12078101294381, 46.10773515701294, 43.806484835488455, 45.69110379900251, 47.90287174497332, 48.907820974077495, 47.123547894614084, 51.56384284155709, 49.913802010672434, 49.73671327318464, 51.58427401951381, 51.99769530977522, 49.066059248788015, 52.935629163469585, 50.99172122137887, 54.30460841315133, 53.19507837295532, 54.150212492261616, 52.656825746808735, 52.732199805123464, 41.204259395599365, 49.42303684779576, 53.39741339002337, 55.06760399682181, 52.27967405319214, 54.04688583101545, 51.81980752944946, 55.565046378544395, 55.06973361968994, 60.26967511858259, 54.45094094957624, 60.071067810058594, 55.05655288696289, 55.909986223493306, 6.26689167533602, 1.950692858014788, 0.47008683532476425, 1.4945199532168252, 0.11893393019480364, 20.815781593322754, 63.03666319165911, 52.15993922097342, 57.91121332986014, 57.942758151463096, 51.65727179391043, 60.77439226422991, 10.451679212706429, 26.47945281437465, 42.327008383614675, 20.02053768294198, 53.566567284720286, 19.315512657165527, 38.51721382141113, 55.32553155081612, 24.84256144932338, 0.14322439820638724, 0.16300145483442716, 0.07270184491894074, 0.026016165768461566, 0.08626495927040066, 0.032725733771388016, 0.1260068163807903, 0.011630258157051035, 0.034291073347308805, 0.14798326284757682, 0.20783803106418677, 0.2799536149416651, 0.1540085452475718, 0.1728044402386461, 0.09310206132275717, 0.24538274428674153, 0.22804793875132287, 0.18705105648509093, 0.36188614847404615, 0.3546498439141682, 0.41832647419401575, 0.46364873221942354, 9.12009516784123, 76.1485948562622, 62.762605394635884, 54.32141957964216, 40.84003829956055, 60.27857576097761, 42.665211950029644, 14.490221500396729, 12.679038047790527, 77.0510060446603, 70.21904386792863, 52.22989368438721, 62.72875377110073, 64.0313811983381, 64.23129476819719, 6.959451198577881, 1.74989067869527, 3.302452734538487, 0.636258487190519, 1.4535320954663413, 2.845302087920053, 56.083684240068706, 63.810407638549805, 66.46081188746861, 63.970514978681294, 69.90874426705497, 61.213865825108115, 65.15297331128801, 62.314189502171104, 60.958908626011436, 59.14131546020508, 61.18838678087507, 60.44102464403425, 62.67609337397984, 55.40896551949637, 49.3365387235369, 51.42974260875157, 49.94263703482491, 52.78872340066092, 59.687020029340474, 53.64531469345093, 57.4855249949864, 55.37298774719238, 56.069791316986084, 58.86263711111886, 56.411006927490234, 54.06404788153512, 55.62649972098214, 56.697099004473, 52.10071625028338, 51.44495916366577, 48.55880948475429, 49.956943375723704, 45.38026918683733, 44.925332409994944, 42.4602609361921, 45.1547897202628, 44.277451106480186, 45.39039618628365, 44.70682198660714, 48.14288684300014, 50.98813942500523, 52.85569361277989, 53.5223593711853, 51.92701823370797, 51.84694024494716, 54.23958717073713, 50.49071093967983, 44.38940743037632, 51.78666114807129, 54.83910206386021, 52.36781195231846, 23.836368492671422, 34.36616195951189, 44.98814412525722, 38.03850725718907, 42.75799124581473, 48.71285104751587, 56.33336080823626, 53.576916626521516, 54.36259460449219, 50.57332502092634, 52.2457321030753, 47.19850506101336, 48.07887656348092, 50.3867380959647, 51.24197449002947, 52.1956911768232, 52.98301935195923, 54.36137866973877, 53.43014982768467, 50.438509123665945, 46.275082520076204, 43.309091091156006, 45.12113264628819, 45.17660706383841, 44.40889365332467, 41.770495891571045, 43.58188084193638, 45.390149525233674, 47.85175384793963, 46.59688138961792, 49.04067053113665, 49.02839306422642, 51.527746949877056, 47.52608830588204, 54.234574045453755, 50.77986717224121, 53.21226821626936, 51.400209290640696, 53.74388183866228, 50.23219626290457, 55.550305775233674, 52.5016759463719, 58.26530395235334, 53.82235131944929, 58.72257532392229, 55.64964069638933, 54.925089495522634, 42.53937659944807, 51.54751110076904, 56.0293493270874, 57.64613607951573, 55.20721067701067, 57.823811939784456, 53.47974606922695, 58.48029858725411, 58.988434246608186, 62.507029805864605, 57.71144219807216, 65.49350452423096, 59.00816018240792, 64.99255330221993, 13.738256181989398, 2.83333403297833, 0.5430839040449688, 4.444915933268411, 0.9404391135488237, 21.579280921391078, 69.54573563167027, 57.16598081588745, 62.07040500640869, 63.428110803876606, 55.63444151197161, 68.47202355521065, 13.587706089019775, 33.968283789498464, 46.317626340048655, 33.06664037704468, 65.81146103995187, 22.92307816232954, 57.509881905147004, 57.443081923893516, 47.32734203338623, 0.3531229229910033, 0.280702066208635, 0.23287851097328321, 0.17007150474403585, 0.2503930740058422, 0.21650113191987785, 0.1726703888603619, 0.10642007525478091, 0.1263702940195799], [0.26194627263716286, 0.08278701268136501, 0.02202920426082398, 0.033535938510405164, 0.24734892163957867, 0.14183663124484674, 0.09342494221138102, 0.03664146776178053, 0.03417664859443903, 0.0272859609353223, 0.0877822246402502, 0.043701102158852985, 0.07551128523690359, 0.0582076312441911, 31.521430492401123, 48.773731163569856, 42.81531041009085, 34.28547600337437, 40.54234273093087, 47.18502902984619, 23.813726050513132, 2.8100749381950925, 48.53277111053467, 71.3860285622733, 57.73717137745449, 37.67865310396467, 39.664635862622944, 55.671037673950195, 26.725328717912944, 0.4307473562657833, 0.7878115092005048, 0.1898798689778362, 0.8593185693025589, 0.2905750764267785, 15.195762429918561, 59.193037850516184, 52.42094830104283, 68.09378446851457, 56.93371990748814, 62.59855147770473, 60.17313684735979, 62.781983920506065, 60.453642572675435, 61.615159034729004, 58.49942697797503, 59.84788472311837, 57.07822854178292, 54.061748027801514, 50.944351877485005, 57.08945335660662, 53.44384820120675, 55.32999924251011, 49.0852084841047, 54.13760151181902, 51.728431769779746, 54.194038254874094, 46.369581495012554, 44.89953374862671, 52.739061151232036, 51.206340653555735, 53.75271994726998, 53.4541072164263, 50.46519020625523, 44.8627986226763, 43.27910961423601, 48.18172379902431, 41.96056386402675, 39.92916420527867, 42.634146554129465, 41.17266593660627, 39.39826624734061, 40.86493369511196, 40.28721877506801, 42.33778156552996, 44.494342599596294, 48.32481152670724, 51.33933959688459, 48.070882661002024, 48.302969864436555, 46.08765138898577, 43.127836908612935, 36.96851246697562, 45.34748411178589, 45.58224637167794, 44.7935528755188, 15.960840736116682, 15.82241177558899, 38.604424136025564, 33.84661040987287, 38.50258091517857, 35.49304512568882, 42.90115540368216, 43.11014679500035, 44.67796264375959, 43.182213510785786, 47.16774538585118, 40.95626776559012, 36.11937311717442, 42.53131321498326, 48.35399048668997, 46.262933594839915, 46.6115768296378, 45.59139020102364, 46.540906701769146, 44.77234697341919, 42.53293561935425, 40.12462050574166, 42.51840346200125, 38.681705474853516, 38.51706443514143, 38.63965150288173, 41.41456052235195, 41.48540782928467, 40.87286158970424, 45.665346826825825, 45.54083858217512, 49.42553472518921, 47.26964766638619, 47.12282875605992, 46.33645943232945, 49.03866597584316, 49.436867237091064, 50.06291382653372, 51.9289984703064, 48.84832007544381, 49.475773675101145, 48.3448987688337, 50.679583821977886, 50.27519518988473, 50.70313821520124, 49.783287048339844, 45.308678422655376, 46.75364317212786, 51.02732031685965, 53.81183174678257, 51.21601949419294, 50.1733033316476, 51.01451131275722, 54.289968558720176, 55.17080559049334, 55.696541036878315, 55.96021127700806, 61.918566022600444, 55.55745894568307, 52.613538469587056, 16.61399051121303, 1.2558609481368745, 0.08512865060142108, 0.449791635785784, 0.21417287471038954, 0.22088533666517052, 39.12116861343384, 53.50855330058506, 47.82842179707119, 52.375173568725586, 47.74351481028965, 61.64286845070975, 35.50437763759068, 4.118577284472329, 42.42933103016445, 17.624882187162125, 33.95850419998169, 33.415005683898926, 29.5193452835083, 43.509425027029856, 44.30606031417847, 7.26507031917572, 0.45989599930388586, 0.20411724357732705, 0.06669564292367015, 0.031999582557805946, 0.037858162474419386, 0.17786093748041562, 0.16240352977599415, 0.07975682456578527, 0.11689633024590355, 0.0850296455568501, 0.023759220893095647, 0.10043601385716881, 0.028216547964672958, 0.04114252980798483, 0.017962438553305607, 0.040400056434529166, 0.04469016533611076, 0.0232268643698522, 0.09349358281386749, 0.04002341182370271, 0.02778068251375641, 0.028717847940112864, 0.13537053178463662, 35.16101850782122, 54.51016044616699, 40.260197230747764, 28.030619042260305, 52.778453963143484, 33.777496678488596, 31.444093567984446, 4.649296760559082, 48.965504918779644, 76.9364094052996, 55.08299078260149, 42.24517250061035, 44.08580241884504, 61.16004507882254, 29.544661045074463, 0.2700724351618971, 0.3139488436281681, 0.47337061911821365, 1.4710706514971597, 0.3763709712241377, 18.073063577924454, 60.6068434034075, 55.01072951725551, 68.17973368508476, 58.38719967433384, 64.04372119903564, 59.94876561846052, 63.806871005467, 60.43525069100516, 59.0174012865339, 58.64557538713728, 57.57596622194563, 56.718805176871165, 53.524384771074565, 51.4866691998073, 56.32654462541853, 54.32850326810564, 58.22677271706717, 51.92772694996425, 56.36862291608538, 53.09132439749581, 54.59333038330078, 49.082283292497905, 46.38834163120815, 54.67173038210188, 53.68326228005545, 55.655498027801514, 56.992369651794434, 51.44674832480294, 48.38534075873238, 46.59555775778634, 48.92130742754255, 43.72211633409773, 42.18242679323469, 41.897672244480674, 42.290109974997385, 41.36727108274187, 42.06690604346139, 41.12050233568464, 42.97786351612636, 44.775730746132986, 49.60928331102644, 53.11802632468087, 49.13653482709612, 50.18117216655186, 49.90711784362793, 45.997727802821565, 41.53761659349714, 49.67849779129028, 50.147535937173025, 50.27475050517491, 19.370240143367223, 22.368587596075876, 46.80842276981899, 35.8227093560355, 40.81933961595808, 40.13409090042114, 47.4630959374564, 48.395318371909006, 50.50208166667393, 47.99931274141584, 49.840022563934326, 41.605424063546316, 40.28236198425293, 45.943285192762104, 49.91499015263149, 48.83612598691668, 50.20951386860439, 49.34034286226545, 50.26574216570173, 48.100954464503694, 43.97247382572719, 41.657149927956716, 42.57034124646868, 39.670715536390034, 38.53812789916992, 38.38646609442574, 41.46669980457851, 42.97064781188965, 44.07324702399117, 45.907988343920024, 49.13717058726719, 49.8859293120248, 50.24556459699358, 49.94940110615322, 49.84024838038853, 53.57026720046997, 50.55216775621687, 51.52306038992745, 52.52957991191319, 51.50310516357422, 52.87392915998186, 52.5680764062064, 51.45294959204537, 51.88866070338658, 51.72098330089024, 50.70407622201102, 45.55703135899135, 46.99265078135899, 51.609433446611675, 54.26645932878767, 52.73566000802176, 51.07257046018328, 52.035938194819856, 56.86702414921352, 56.4366249356951, 56.281666210719514, 55.64104577473232, 61.28733607700893, 53.93353639330183, 52.27260078702654, 15.700950316020421, 1.85543891787529, 0.547508006649358, 0.8894026407173702, 0.9934069684573582, 0.23430430303726876, 45.278391224997385, 57.26548249380929, 54.78824472427368, 55.43144989013672, 52.88909707750593, 65.16310378483364, 34.860953603472026, 7.381688015801566, 45.86358935492379, 18.225145748683385, 33.55683578763689, 43.80246182850429, 25.613502298082622, 47.00476149150303, 54.830006871904644, 6.568740095411028, 0.3726541463817869, 0.1295865092958723, 0.06956795629646097, 0.12586972516562256, 0.034447319606052976, 0.03314377919637731, 0.05556602317041584, 0.0907388392037579, 0.09496210901332752, 0.4146957147334303, 0.12216751596757344, 0.1835802277284009, 0.10106096496539456, 0.31268421720181194, 0.20380135838474545, 0.16024515059377464, 0.235393188893795, 0.1702132099973304, 0.302069215370076, 0.13040503965956823, 0.11340874845960311, 0.18901785809014524, 0.5182646672640527, 56.61798334121704, 60.72009209224156, 57.15459271839687, 47.94075332369123, 55.145496777125764, 58.7071989604405, 31.4331362588065, 6.926102885178157, 59.35201958247593, 74.6094924381801, 64.07024247305733, 51.13693857192993, 53.027598994118826, 69.14333765847343, 33.01980257034302, 1.370557250721114, 2.503339111804962, 0.2914246294115271, 3.3541696965694427, 0.3818745416189943, 19.37227075440543, 67.4883392878941, 62.181319100516184, 73.23869623456682, 64.02971363067627, 67.4533690043858, 63.15214920043945, 65.58003044128418, 61.41197286333357, 62.92632579803467, 60.75744560786656, 62.41600840432303, 58.48557921818325, 54.48673459461757, 50.4792811529977, 57.06714269093105, 56.14485618046352, 58.806794439043315, 52.59304823194231, 57.17025048392159, 53.14377982275826, 56.163897718702046, 48.24048818860735, 50.612877641405376, 56.391868114471436, 52.5926730292184, 57.387239251817974, 60.415517807006836, 53.06800971712385, 50.29410123825073, 46.869389738355366, 52.01466975893293, 43.428190163203645, 42.803644384656636, 43.348664556230815, 43.23716681344168, 40.56371191569737, 44.78464528492519, 43.2663631439209, 43.875129563467844, 46.1080721446446, 53.768898827689036, 55.00631741115025, 51.35574776785714, 53.387310709272114, 52.07951034818377, 50.86617769513811, 43.78797830854143, 54.115909235818044, 52.95143978936331, 55.780412742069785, 16.699184111186437, 19.561661277498516, 53.01036051341465, 38.7234537260873, 44.54640197753906, 42.134918485369, 53.16924844469343, 54.75967720576695, 54.076259340558735, 49.83060080664498, 55.43324599947248, 45.34230422973633, 41.64512607029506, 50.451568262917654, 55.37011466707502, 52.29605095727103, 53.876790455409456, 53.870985235486714, 54.44349595478603, 52.639802660260884, 49.06997108459473, 47.106260776519775, 46.041094984327046, 41.783152035304475, 42.117447240012034, 38.688024861471995, 42.80456502096993, 44.093514919281006, 46.20375926154, 47.05153676441738, 51.247817925044465, 51.635391916547505, 52.41471924100603, 50.46502692358834, 51.75788518360683, 55.006074224199565, 51.22512510844639, 54.02442577907017, 56.593529156276155, 52.14403826849801, 54.67993967873709, 52.666240555899485, 54.97514084407261, 54.50719703946795, 53.45867913109915, 52.98984595707485, 48.349592276981895, 47.52516072137015, 55.479253496442524, 56.421304157802034, 54.09835808617728, 50.621350969587056, 54.16641916547503, 57.723389625549316, 59.55966649736677, 59.15262017931257, 62.50729383741106, 64.42777592795235, 58.798074449811665, 55.84551388876778, 27.906553745269775, 3.0992081548486436, 0.7937132439443043, 1.3742413158927644, 4.004906926836286, 0.46259787146534237, 48.184548241751536, 62.04558604104178, 59.279869488307405, 59.81220572335379, 58.33822182246617, 70.67873668670654, 45.98252861840384, 6.828478523663112, 54.880471638270784, 20.81208167757307, 52.69407851355416, 48.92025130135672, 41.52619028091431, 55.787822995867046, 61.235836029052734, 15.650674888065883, 1.038796944277627, 0.50063898733684, 0.21605950061764034, 0.37996891673122135, 0.21814041824213096, 0.31275443200554165, 0.4907630458474159, 0.17131971062294074, 0.2649758229298251], [0.18366228975355625, 0.15658465772867203, 0.07725623303226062, 0.1056074888578483, 0.18531252763101033, 0.09015732790742602, 0.11691929187093462, 0.23137542019997323, 0.05616119337667312, 0.06842588007982288, 0.08191151251750332, 0.03569183086178132, 0.13639898731240205, 0.09697438603533165, 12.888685175350734, 52.28135551725115, 43.804487228393555, 34.67957435335432, 29.00958721978324, 35.74732834952218, 38.45625032697405, 2.682727051632745, 10.513426116534642, 60.36291299547468, 61.98757553100586, 54.87318992614746, 51.39640167781285, 52.129707608904155, 48.176015853881836, 2.1517103229250227, 0.10628729952233178, 1.23762246966362, 0.4211655189948422, 1.1998773579086577, 0.22812545459185327, 42.79789822442191, 51.41952180862427, 58.21299096516201, 67.26494080679757, 61.34839684622628, 57.635783263615195, 56.02475309371948, 60.56855188097273, 61.480537687029155, 59.588174956185476, 58.933251653398784, 57.82971443448748, 58.940095629010884, 56.502966335841585, 53.960707323891775, 55.883701188223704, 55.62320627485003, 55.14601789202009, 53.71219457898821, 54.58479452133179, 51.110194955553325, 49.48900651931763, 35.906737395695274, 39.251773902348106, 49.89354453768049, 54.95485210418701, 51.691026142665315, 48.62969848087856, 47.1485926764352, 44.93780790056501, 46.48665516717093, 44.543178013392854, 41.8875070299421, 41.40481219972883, 41.09649978365217, 37.70675161906651, 40.42571374348232, 41.06892238344465, 41.28210006441389, 40.088479450770784, 45.05162981578282, 46.86261524472918, 48.680819852011545, 49.31722273145403, 45.26165648869106, 42.15471042905535, 36.48486573355538, 45.23791102000645, 43.06521626881191, 48.63524661745344, 17.772500140326365, 11.004852226802281, 38.60000508172171, 34.35543046678816, 39.29946286337716, 27.494775703975133, 29.3827680179051, 43.84046152659825, 42.86217253548758, 45.0459566116333, 46.11820956638881, 44.40376935686384, 37.860011509486604, 40.60615151269095, 45.670745577131, 48.68079900741577, 45.58647435052054, 44.88237517220633, 49.01809235981533, 42.437154701777864, 42.3877842766898, 38.729314531598774, 39.21024104527065, 38.8671806880406, 38.82761764526367, 38.90102536337716, 40.55499540056501, 42.26960236685616, 42.34002235957554, 46.27838291440691, 49.39761338915144, 49.522507258823936, 47.026947089603965, 47.74804850987026, 47.792044503348215, 49.675437109810964, 46.650181021009175, 46.70835133961269, 38.174917766026084, 41.483517919267925, 47.31308432987758, 49.13582263674055, 50.136165210178916, 48.71160731996809, 44.974657671792166, 45.471467767442974, 42.457752636500764, 44.05204112189156, 51.574508326394216, 53.31866250719343, 52.066628387996126, 53.71385172435215, 55.556910037994385, 51.91498047964913, 56.91645015989031, 58.250865595681326, 62.52897916521345, 54.79689523151943, 49.36918830871582, 18.249191726957047, 1.45550560099738, 0.24088525133473532, 0.4075385273567268, 0.20169233583978244, 0.651361482484, 10.111787234033857, 49.61399071557181, 50.61251980917794, 50.98918860299246, 50.995699065072195, 54.87951626096453, 42.96027067729405, 2.619468480348587, 14.645131587982178, 47.03830739430019, 14.920236825942993, 40.0873121534075, 23.902499709810527, 26.11700698307582, 45.427589893341064, 41.13909918921334, 0.9707321737493787, 0.04397278418764472, 0.06998974044940301, 0.07111596608800547, 0.05326058848627976, 0.06004297347473247, 0.040938514683927806, 0.15623381441192968, 0.08344469631889037, 0.146954101643392, 0.14487330615520477, 0.17825659124978951, 0.02060772937589458, 0.04521600283416254, 0.1376640751425709, 0.05513853593064206, 0.05212317380521979, 0.1361259583915983, 0.0487458539594497, 0.0319284178050501, 0.0442524254322052, 0.032109953063939295, 0.07308680497642074, 0.20201147800045355, 14.786405835832868, 64.95277486528668, 45.62956360408238, 32.4878762790135, 42.63271869931902, 35.505892344883506, 34.32670313971383, 7.421531592096601, 8.930810604776655, 66.72831058502197, 63.308803285871235, 56.27934203829084, 56.24067531313215, 56.152971676417756, 53.56462178911482, 2.603584246976035, 1.0094947623355048, 1.4575831123760767, 0.6035609702978815, 2.485489841018404, 0.5510786207658904, 49.03047057560512, 53.74269717080252, 59.147332600184846, 65.09385803767613, 61.92866175515311, 57.56850038255964, 54.27829211098807, 60.33293151855469, 62.09573813847133, 58.88822732652937, 60.64193875449044, 57.17958191462925, 59.085632596697124, 56.52347394398281, 57.64651823043823, 56.17503915514265, 56.41122579574585, 55.074204785483225, 55.406165395464214, 55.032616342817036, 52.39294358662197, 50.30884878976004, 40.91699307305472, 42.11618614196777, 54.325067383902415, 55.72713048117501, 56.008084365299766, 50.80057280404227, 49.10277353014265, 46.186520780835835, 46.85688645499093, 43.21981021336147, 42.11392797742571, 41.90385266712734, 40.66567325592041, 39.15259531566075, 40.95124421800886, 42.392026151929585, 41.92675392968314, 42.23645945957729, 45.58769375937325, 49.0558488709586, 49.666098730904714, 50.223854950496126, 47.184987340654644, 44.33506209509713, 39.080914224897114, 46.878314699445454, 47.283561434064595, 51.72113616125924, 25.123807157788956, 15.787165301186697, 42.632868085588726, 37.48041752406529, 40.82740647452218, 35.666611126491, 41.81999485833304, 48.1221638407026, 50.10797984259469, 49.50025912693569, 49.24137272153582, 46.841878346034456, 40.69394200188773, 43.81583711079189, 49.79605436325073, 51.98996543884277, 48.958157198769705, 48.18575722830636, 52.04158360617501, 46.55509144919259, 44.71095616476876, 42.792280605861116, 40.66742767606463, 38.64333752223423, 39.3757506098066, 39.443387848990305, 42.13369560241699, 41.617069244384766, 43.389200346810476, 46.69163049970354, 52.14317669187273, 50.4301678112575, 48.50210176195417, 52.29391438620431, 51.94855070114136, 52.86039406912667, 49.36360543114798, 50.373637267521445, 43.271060126168386, 43.34891469138009, 49.6837923186166, 50.47880172729492, 51.92055293491909, 50.96859761646816, 45.91270964486258, 46.21753406524658, 44.149114404405864, 45.41243587221418, 52.33685425349644, 54.25588069643293, 53.30053118297032, 54.47207736968994, 55.51241030011858, 52.92266035079956, 59.03095722198486, 58.91974435533796, 60.62387343815395, 54.818045548030305, 51.93267059326172, 18.80624791554042, 1.6624496621744973, 1.012064401592527, 0.9127009276832853, 0.5745793825813702, 1.0213329728160585, 13.947148561477661, 57.1122955594744, 53.59670162200928, 58.36021981920515, 54.65250471660069, 64.35639708382743, 40.68462446757725, 5.266120050634656, 20.26636494909014, 50.684496198381694, 14.507208977426801, 44.28498642785208, 30.55797937938145, 23.042585441044398, 53.73768057141985, 41.384207316807334, 0.7150497021419662, 0.16220015926020487, 0.05352949191417013, 0.08971674154911723, 0.0827398273561682, 0.01680424712997462, 0.024022536585107446, 0.0388908350973257, 0.010454708111605473, 0.10941163437174899, 0.2605990549283368, 0.21129150289509976, 0.1326597843851362, 0.19681484970663274, 0.3006814212671348, 0.1415550256414073, 0.17350191995501518, 0.31489694703902515, 0.1667000406554767, 0.11533929593861103, 0.21888270841113158, 0.23572401542748722, 0.32730740681290627, 0.33937387647373335, 28.134089878627233, 75.05619212559291, 57.73287391662598, 50.758689062935964, 42.33629812513079, 50.28224066325596, 44.97328887666975, 7.032914936542511, 16.319591862814768, 72.95676612854004, 66.18945693969727, 63.969667298453196, 62.65628405979702, 62.40673950740269, 56.801752771650044, 2.558573382241385, 2.450764698641641, 3.2566593289375305, 0.684460637824876, 2.590798041650227, 1.1474193270717348, 50.60632201603481, 58.842424801417756, 69.22567381177629, 68.9569730758667, 64.40924508231026, 59.777916363307405, 55.333525453295024, 62.31667695726667, 66.04166180746896, 61.064743586948936, 64.74127864837646, 57.387524127960205, 58.689786774771555, 55.468174593789236, 58.96086379459926, 58.80563408987862, 58.419015475681846, 56.66146864209856, 58.07137972967965, 54.02191053118025, 54.02997391564505, 49.833967208862305, 39.01803650174822, 44.08186279024397, 53.48673595700945, 58.52348858969552, 57.722819873264854, 50.67970888955252, 50.5773515020098, 45.992332526615684, 49.33424234390259, 45.78254209245954, 42.999434198652, 43.28163528442383, 42.05202647617885, 38.447714465005056, 42.44344629560198, 45.26142372403826, 44.284430571964805, 43.02477775301252, 46.53852694375174, 51.18612139565604, 52.39557695388794, 54.43258728299822, 48.72839764186314, 49.311969893319265, 41.64002261843, 53.27480200358799, 48.65125526700701, 60.57690361567906, 19.710347516196116, 14.252428088869367, 49.92508935928345, 39.851017815726145, 45.04622411727905, 33.485279764447895, 39.69703878675188, 54.09176424571446, 52.726335525512695, 51.68514101845877, 53.51626232692173, 51.185200759342735, 44.07981307165963, 46.138703278132844, 52.90031494413103, 57.41171775545393, 52.522520542144775, 53.02090440477644, 57.19315869467599, 49.475697244916645, 48.62398706163679, 45.95316205705915, 43.3798828125, 41.209626879010884, 43.10302141734532, 40.61475338254656, 43.188727446964805, 42.62983867100307, 45.22670010157994, 48.77036823545183, 55.88227333341326, 51.24408326830183, 51.494586672101704, 51.74448905672346, 52.65352535247803, 54.65827519553048, 51.31248133523123, 52.19741780417306, 43.85204069955008, 45.56419495173863, 51.76335688999721, 52.236306871686665, 53.57066672188895, 53.87717260633196, 48.26603671482631, 48.18276602881295, 47.14901304244995, 47.01475647517613, 54.63753482273647, 57.97275005068098, 53.97896718978882, 56.835305622645784, 61.623281478881836, 54.561785561697825, 61.072393553597585, 64.38042395455497, 65.0713597706386, 60.30054596492222, 59.192787715366904, 26.355368409837993, 3.893101726259504, 1.6118776329926081, 2.268804405416761, 4.11105021408626, 2.568065272910254, 12.4291330575943, 60.19977624075753, 56.62666858945574, 61.20238740103585, 59.27425534384591, 65.50130040305001, 50.416924544743125, 7.548341427530561, 20.05373443875994, 60.81384413582938, 20.72381349972316, 62.02415779658726, 33.201122760772705, 41.056995800563264, 58.502254894801546, 61.72161933353969, 2.401184741939817, 0.48416589413370403, 0.22273369319736958, 0.2555914936321122, 0.1784937120974064, 0.12389657247279372, 0.0864404487822737, 0.3867297853742327, 0.17091026902198792, 0.2316031094108309], [0.29305096928562435, 0.19907880893775395, 0.049255457507180314, 0.09511887095868587, 0.07509049853043896, 0.18796640022524766, 0.06746476915265832, 0.17816549113818578, 0.11327222721385104, 0.06814399627702576, 0.03031585897718157, 0.03126436272369964, 0.18602779853556836, 0.2555757244782788, 4.858079705919538, 51.4530816078186, 51.836920942579, 40.099686895098, 24.055420875549316, 30.43278326307024, 51.08585888998849, 32.09486879621233, 2.1089343896933963, 25.061051028115408, 64.5363415309361, 59.98784923553467, 54.43197236742292, 57.98662560326712, 42.85979972566877, 21.373068809509277, 0.5332042170422417, 1.0914101153612137, 0.7031001576355526, 4.969362923077174, 7.353579946926661, 4.1286612919398715, 50.85016557148525, 54.84144708088466, 59.344647543770925, 59.580775124686106, 56.837751388549805, 56.51805087498256, 58.20710236685616, 60.778401374816895, 62.11385209219796, 60.067364420209614, 58.33417797088623, 56.03827428817749, 58.39936597006661, 56.174427713666645, 55.9903108733041, 55.483179228646414, 56.400459562029155, 55.01235886982509, 55.468699182782856, 52.83702032906668, 52.728562423161094, 48.215974943978445, 42.88500084195818, 40.85410492760794, 51.59661054611206, 53.667375223977224, 50.046759264809744, 42.252926690237864, 42.93367644718715, 44.499532903943745, 42.649196352277485, 41.20613540921892, 42.63579327719552, 41.13320016860962, 39.584432806287495, 38.939389841897146, 41.42903709411621, 39.40736838749477, 41.78085218157087, 45.92596333367484, 49.87526730128697, 48.44525160108294, 44.05065843037197, 44.01887389591762, 36.45478350775582, 37.16102620533535, 42.2046332359314, 45.98967831475394, 43.712371485573904, 27.82663209097726, 9.26218843460083, 33.167267663138254, 35.535484722682405, 39.403348854609895, 8.762044072151184, 12.594418542725698, 51.33313832964216, 37.69771548679897, 47.93986395427159, 42.9836756842477, 48.57438039779663, 37.573902062007356, 36.979959624154226, 42.941111019679475, 49.19684171676636, 44.29184429986136, 46.06396845408848, 47.68832179478237, 44.22703845160348, 37.96381412233625, 36.89544868469238, 38.208929198128835, 37.9145062310355, 37.22709662573678, 39.105653285980225, 41.66662379673549, 42.43393073763166, 43.70075409752982, 46.568039417266846, 49.27363668169294, 49.982610021318706, 50.244914940425325, 48.14833075659615, 44.49570097242083, 43.50308132171631, 43.10002326965332, 43.31699119295393, 44.366051060812815, 44.73058829988752, 44.04092400414603, 45.41637897491455, 45.217271396092, 45.14757054192679, 43.02137313570295, 44.212690421513145, 39.89868245806013, 47.09553970609392, 52.4272711617606, 53.972755500248496, 53.280360562460764, 53.24109976632254, 56.12784351621355, 57.89777551378523, 56.60581704548427, 56.68614864349365, 44.67110824584961, 35.718781675611226, 13.863458377974373, 0.5710489377379417, 0.28789250180125237, 0.7021107450127602, 0.5358387785298484, 1.5192871327911104, 23.878379038402013, 44.70803097316197, 49.55270412990025, 48.520799364362446, 50.197031429835725, 48.55513736179897, 43.20643145697457, 16.317870446613856, 3.223930707999638, 47.85283429282052, 37.85037088394165, 19.23414751461574, 40.88806077412197, 19.06065968104771, 41.1614202771868, 52.791686807359966, 17.81720311301095, 0.4462574454290526, 0.19966772305113928, 0.06390621938875743, 0.14757242346448557, 0.10764305998704263, 0.07026231475174427, 0.10143977749560561, 0.11436995438167027, 0.12245837678866726, 0.08381530536072594, 0.2352436397756849, 0.12362137223993029, 0.02567522058130375, 0.016163708376032964, 0.0724161681053894, 0.08622012846171856, 0.10021344080035176, 0.07197754949863468, 0.05836103444120713, 0.08124224628720965, 0.0256804656569979, 0.06430011575243302, 0.14725978166929313, 0.34006858776722637, 3.8526923060417175, 57.4636937550136, 53.41712890352522, 41.782346044267925, 29.164921147482737, 40.42075967788696, 44.56878559929984, 41.56398153305054, 3.2337124688284735, 24.32072741644723, 69.13461072104317, 62.01569489070347, 56.88106298446655, 61.997226578848704, 46.662468910217285, 26.697761740003312, 0.5887528391821044, 0.3597315012344292, 0.5513827130198479, 6.497156713690076, 9.22310221195221, 4.3253335271562845, 55.67961522511074, 56.180865219661165, 59.717050143650596, 59.66587666102818, 58.65595599583217, 53.34423882620675, 55.55782720020839, 60.68426718030657, 61.932733399527415, 59.79192393166678, 56.97439466203962, 57.136364119393484, 57.406002862112864, 54.81795522144863, 54.95753410884312, 55.322849546160015, 54.098253863198416, 56.32853181021554, 56.709432056971956, 52.91791820526123, 52.13805586951119, 51.43707990646362, 45.66913706915719, 42.05108152117048, 53.44299009868077, 54.31925521578108, 50.48810536520821, 43.555043424878804, 46.25360216413225, 45.253478458949495, 42.683975560324534, 41.50837509972708, 43.50489132744925, 39.867300919124055, 38.40926660810198, 40.305690561022075, 42.37754610606602, 40.48035785130092, 41.9654414994376, 45.50430495398385, 52.8189480645316, 49.17626462663923, 47.344399860927034, 47.4109844480242, 41.68044376373291, 39.64982230322701, 46.10771778651646, 50.99142939703805, 46.79347024645124, 46.77045086451939, 18.524272646222794, 38.3539137840271, 38.54539918899536, 44.14252751214163, 15.174144847052437, 17.46378125463213, 56.313026905059814, 43.22451066970825, 53.03295258113316, 45.71242782047817, 52.482801164899556, 39.04550273077828, 42.63628312519619, 45.00908946990967, 54.09576988220215, 47.07795034136091, 48.32894570486886, 50.2762200491769, 47.63976778302874, 41.55874259131295, 39.13105590002877, 40.042301722935264, 39.936032499585835, 39.81822231837681, 39.98667097091675, 42.08767073495047, 42.339734009334016, 45.110342093876426, 47.89607640675136, 51.75434855052403, 50.39382873262678, 52.600760732378276, 50.63599082401821, 46.50695432935442, 46.20500298908779, 45.316311018807546, 43.81809180123465, 45.7023355620248, 47.334241594587056, 47.44225828988211, 46.88163593837193, 47.7988919530596, 46.78241566249302, 47.195562498910085, 43.801280634743826, 42.41919013432094, 47.020200388772146, 53.94594587598528, 54.86819069726126, 54.7496474811009, 54.90385580062866, 56.92624364580427, 58.66112545558384, 54.727201325552805, 53.9123443875994, 45.022857325417654, 37.651617663247244, 13.763839449201312, 0.7501053724970136, 0.6546231731772423, 1.201077659215246, 0.5746192261576653, 3.823900273868016, 32.378650597163606, 47.754142080034526, 53.99599722453526, 52.34112739562988, 56.33238806043352, 51.90572547912598, 50.347637108394075, 17.415359258651733, 7.503634112221854, 55.42803485052926, 41.61394255501883, 19.05505074773516, 46.21740552357265, 23.33385740007673, 36.43245547158377, 59.50763838631766, 17.631939819880895, 0.42520831206015175, 0.14607196540704795, 0.09843492587762219, 0.06393385612006698, 0.0502795059499996, 0.023855162352057438, 0.03562556513186012, 0.08835299472723689, 0.04643195115828088, 0.04384801516841565, 0.341649167239666, 0.2900210390133517, 0.12024453415402345, 0.23023520995463642, 0.1754442671579974, 0.2465873882174492, 0.20173212513327599, 0.2715248800814152, 0.18720274977385998, 0.17568407500428812, 0.13082512068961347, 0.30722130462527275, 0.5394736092005457, 0.7032275050878525, 10.237150975636073, 75.4528647831508, 60.96525927952358, 58.835170882088796, 33.36563525881086, 45.15109327861241, 60.14467007773263, 41.47088262013027, 4.088638365268707, 31.998031752450125, 74.93026297433036, 69.66385500771659, 63.66541263035366, 69.69410746438163, 57.86315611430577, 33.79288346426827, 0.9045723495738847, 2.0170472860336304, 1.2949208979095732, 8.443541254316058, 8.62369327885764, 6.768231562205723, 60.332320077078684, 63.02073792048863, 64.67142145974296, 58.7905148097447, 58.71494620186942, 55.57839386803763, 58.44220161437988, 63.87693664005825, 63.817737988063264, 63.92033508845738, 58.971411160060335, 57.962866238185335, 58.746338163103374, 58.99983624049595, 58.05711160387312, 57.57891573224749, 57.14172118050711, 58.137922627585276, 58.33221857888358, 53.646537576402935, 54.828943797520225, 45.85716227122715, 42.86052233832223, 42.93047332763672, 54.623961516789024, 55.265196868351524, 52.791273389543804, 43.595801557813374, 46.51969037737165, 46.62706783839634, 44.94333866664341, 43.72076838357108, 44.397495133536204, 41.643368176051546, 39.479025159563335, 43.216812065669465, 45.070330892290386, 40.672888960157124, 43.42236409868513, 47.73532288415091, 54.01669243403843, 50.49185391834804, 49.178488050188335, 49.91081428527832, 41.67122350420271, 41.94795635768345, 48.85157878058297, 55.02781513759068, 49.68487971169608, 39.5278570992606, 9.782169035502843, 38.560768604278564, 43.870644501277376, 46.76001467023577, 14.527084299496241, 16.97875530379159, 65.94044045039585, 43.19914974485125, 57.59961094175066, 47.04751375743321, 57.38919864382063, 41.203067779541016, 44.715910230364116, 48.96398326328823, 58.5009069442749, 51.37977811268398, 50.56988218852452, 53.73899725505284, 50.52977023805891, 45.61224174499512, 42.41385044370379, 42.13457802363804, 44.646553312029155, 42.324649470193044, 41.56123004640852, 43.37731892721993, 43.95333848680769, 47.033627782549175, 49.03479930332729, 51.86856303896223, 52.43010255268642, 53.7674674987793, 50.62944562094552, 50.340511730739046, 48.25839022227696, 43.608475072043284, 44.84813444955008, 45.25137662887573, 47.61728688648769, 47.33521086829049, 48.886417048318044, 48.318002292088096, 48.77069827488491, 45.6197110584804, 45.50756713322231, 43.749176093510215, 52.439882142203196, 57.923018319266184, 57.236994879586355, 55.93396445683071, 57.861971446446006, 59.93297931126186, 61.214477266584126, 56.81667055402483, 55.28737551825387, 50.41422169549124, 46.253438881465364, 17.859823363167898, 1.3486747677837099, 1.1495654519115175, 2.4743316854749406, 1.734460900936808, 2.686051981789725, 28.973060539790563, 52.75383302143642, 60.19775431496756, 55.01071909495762, 59.210213797433035, 54.74593366895403, 52.759176186152864, 23.643463918140956, 7.639854414122445, 58.42528969900948, 49.19068561281477, 29.141721112387522, 58.09376335144043, 27.495288133621216, 55.563059193747385, 62.88672801426479, 35.269868986947195, 0.9960642201559884, 0.3407563508621284, 0.5563073030539921, 0.34259290088500294, 0.25589175894856453, 0.16117144588913235, 0.22289082833698817, 0.3155629155891282, 0.2659618971603257, 0.19207140138106688], [0.055586348686899455, 0.3032007946499756, 0.03296146701489176, 0.1259159469710929, 0.17222320714167186, 0.219296682626009, 0.08260860546891179, 0.376537809414523, 0.16936407770429338, 0.035626945950623067, 0.11477680397885186, 0.08649644149201256, 0.1946486130888973, 0.08915477206132241, 0.11090481174843651, 38.21121515546526, 46.520916734422954, 47.12674754006522, 35.98144095284598, 21.25090037073408, 34.8519070489066, 46.777770791734966, 6.504303804465702, 9.467921120779854, 55.1230263028826, 59.13198402949742, 51.999262128557476, 61.11884226117815, 50.2456236566816, 66.8890780040196, 35.88349567140852, 7.467818754059928, 0.25809406648789135, 3.901866444519588, 20.36919481413705, 6.860638695103781, 9.993458543504987, 41.8201789855957, 58.99031720842634, 57.491111346653526, 57.50585889816284, 55.60533898217337, 57.60513823372977, 64.30518886021206, 60.51965740748814, 58.99453476497105, 58.05776126044137, 59.21898242405483, 56.30947290148054, 53.792845794132774, 55.4776554107666, 54.170893805367605, 55.12872035162789, 52.09337200437273, 55.18946497780936, 54.15126167024885, 55.52780403409685, 50.881442887442454, 53.78159318651472, 46.33394765853882, 52.43853071757725, 50.578164441244944, 50.93645872388567, 44.791902678353445, 42.97041852133614, 41.54390123912266, 41.4114407811846, 42.42651006153652, 40.94172518593924, 39.407653263636995, 38.0720670563834, 37.889812333243235, 39.99748931612287, 40.2931421143668, 39.658094133649556, 44.658730030059814, 47.21857145854405, 46.253449303763254, 42.088893617902485, 42.48964139393398, 35.921773297446116, 37.231373241969514, 40.67588363374983, 42.13770818710327, 43.05759062085833, 35.2666346005031, 13.617849111557007, 33.55174970626831, 24.728407757622854, 32.90389272144863, 10.017818059240069, 18.68665725844247, 53.66108363015311, 40.11602210998535, 49.99651684079851, 44.22721563066755, 49.45785427093506, 39.84711292811802, 37.315856388636995, 44.72079828807286, 50.88316604069301, 45.91550629479544, 47.24405745097569, 45.08066633769444, 40.225265162331716, 36.076683385031565, 37.87452629634312, 37.35663884026663, 38.563426290239605, 38.36512470245361, 39.74864305768694, 40.561693464006694, 40.2058345249721, 40.85766240528652, 47.412061418805806, 48.44483470916748, 48.99303715569632, 49.73489284515381, 40.978356088910786, 40.22725929532732, 45.22305229731968, 48.04487555367606, 49.32904856545584, 45.44643688201904, 45.957810401916504, 47.14393738337925, 47.782490730285645, 48.0786576952253, 48.285401344299316, 47.56031165804182, 46.955738476344514, 45.40330246516636, 43.21365410940987, 50.35051366261074, 54.75053685052054, 54.81679834638323, 57.07845435823713, 58.10222625732422, 55.28947387422834, 51.67664337158203, 40.216979435511995, 21.2546489238739, 8.912549001829964, 3.1463002221924916, 1.517320684024266, 0.5680995360016823, 0.5540045180491039, 3.4775091239384244, 40.593703814915244, 52.78766032627651, 49.309791633060996, 51.33404506955828, 46.86936889375959, 51.64711005347115, 49.81228188105992, 39.165887219565256, 16.41979009764535, 8.766216465405055, 41.13855028152466, 31.222730909075054, 24.527373790740967, 32.96974427359444, 22.413773468562535, 38.18822009222848, 47.265527384621755, 4.679713802678244, 0.30649635781134876, 0.1588207698826279, 0.04634406730266554, 0.09241982828825712, 0.06516081706753798, 0.014010594625558172, 0.1801521602485861, 0.07048899973077433, 0.06214899689491306, 0.021568538354975835, 0.0028624707982609315, 0.045848092130784474, 0.07784363401255437, 0.03783918724262288, 0.07482409889676742, 0.15452959228839191, 0.030265247050140585, 0.12195421169911112, 0.16489030633653912, 0.04234413729448404, 0.056279821653983424, 0.054714112276477475, 0.07030500138976745, 0.11935908666678838, 0.29154945271355764, 38.91528654098511, 53.7795330456325, 45.02095351900373, 29.087653705051967, 28.590100152151926, 36.23951094491141, 53.301326751708984, 10.650157111031668, 10.048793128558568, 56.793793610164094, 62.45230579376221, 55.10047592435564, 64.50947284698486, 54.73100546428135, 70.9551499230521, 44.07933017185756, 9.796134046145848, 0.13256735434489592, 3.238734496491296, 24.67543990271432, 10.028269018445696, 13.909002082688467, 46.215991565159385, 56.993536949157715, 56.41712829044887, 58.82086454119001, 52.63179833548409, 55.51689536230904, 63.41638919285366, 59.89815493992397, 59.57511929103306, 57.31287268229893, 58.171913215092246, 55.017368521009175, 53.169099058423726, 53.23838302067348, 51.26378835950579, 53.7480194909232, 53.03366477148873, 54.73455599376133, 54.570727893284385, 56.0286579813276, 51.69271455492292, 56.00124733788626, 45.843564646584646, 53.4542670249939, 52.03090075084141, 53.70300211225237, 45.845364230019705, 43.29729652404785, 41.174382141658235, 42.65012741088867, 40.91859463282994, 41.26811334065029, 39.52195807865688, 38.467138154166086, 37.54118994304112, 41.89991998672485, 43.85436487197876, 40.162818227495464, 46.52322006225586, 47.418738637651714, 50.39835548400879, 44.8900077683585, 44.99618666512625, 39.33833108629499, 43.07495069503784, 42.055757658822195, 48.147767952510286, 45.176353454589844, 55.85276780809675, 33.59045812061855, 37.04206262316023, 36.348371846335276, 36.78184216363089, 13.653169410569326, 20.48848843574524, 55.8357377733503, 43.78232247488839, 53.891770771571565, 47.39288091659546, 53.13695669174194, 43.50663185119629, 41.274901730673655, 47.21448939187186, 52.07646703720093, 47.933113779340474, 50.36152308327811, 48.46922288622175, 43.85939189365932, 38.693152632032124, 40.00962087086269, 39.05789136886597, 39.28168589728219, 38.48045090266636, 38.79068796975272, 41.256954533713206, 41.44285358701433, 43.3665075302124, 48.252633639744346, 49.814929144723074, 49.6103116444179, 51.5144168308803, 43.528855664389475, 39.294623443058555, 48.17036696842739, 48.60822854723249, 50.01084402629307, 50.75161232267107, 49.184345381600515, 49.81975466864449, 49.39007806777954, 50.01618371691023, 50.81265919549124, 48.092543670109336, 49.465695313044954, 47.292555877140586, 46.02728543962751, 49.26935659136091, 56.00080960137503, 56.417308943612234, 59.127259254455566, 58.01702397210257, 55.248271056583945, 50.29381288800921, 42.35556547982352, 23.921541248049053, 11.337157641138349, 4.546371792043958, 2.6231579738003865, 1.096243673137256, 0.920872334923063, 6.880975638117109, 48.29598345075335, 56.160055364881245, 54.39592511313302, 53.254746028355186, 53.56215170451573, 54.31980412346976, 58.035884857177734, 38.57258749008179, 17.176799808229717, 13.68368763583047, 40.42481395176479, 36.9645346232823, 25.850211790629796, 41.92866121019636, 22.392096826008387, 41.69061245237078, 50.84655250821795, 2.352714542831693, 0.4034658244677952, 0.024419381183439066, 0.1363995029990162, 0.03636147367901035, 0.1211371198296547, 0.10968118919325726, 0.02314190669650478, 0.07025126820164067, 0.08322710370911018, 0.04722145040120397, 0.11188018548169307, 0.33105270298463957, 0.19035868399909564, 0.3065199708299977, 0.1874035554272788, 0.4035743629293782, 0.09836832766554185, 0.395060838333198, 0.27419825377208845, 0.08502131314682108, 0.11555078173322336, 0.1883859791393791, 0.30927129462361336, 0.4526636302471161, 0.8564524916665894, 66.66446358816964, 60.06901809147426, 63.98220879690987, 46.51012618201119, 35.72745997565133, 44.41506017957415, 56.81922401700701, 11.279539704322815, 14.118682214191981, 62.29734012058803, 67.76429394313267, 63.92315605708531, 71.05542632511684, 60.33646815163748, 78.51335866110665, 46.97773994718279, 10.345833829471044, 0.48654440364667345, 4.8741165825298856, 28.43568512371608, 8.690531475203377, 18.061705010277883, 53.35971246446882, 62.32058184487479, 58.51244790213448, 63.00220707484654, 56.86929273605347, 58.664926120213096, 68.82580498286656, 62.971266746520996, 65.04681873321533, 59.39003317696707, 59.61558559962681, 56.46878119877407, 56.0894512448992, 57.260045528411865, 54.4125452041626, 56.565826688494, 54.283048152923584, 56.92843580245972, 56.233424867902485, 57.50700535093035, 53.34045900617327, 53.92099142074585, 44.40614216668265, 55.66203280857631, 51.55317735671997, 55.48019845145089, 45.87371982846941, 44.27707590375628, 41.66260078975132, 42.389931270054404, 42.67403268814087, 41.47132383074079, 40.8618243762425, 39.70949690682547, 40.78275040217808, 42.00755453109741, 45.76914249147688, 41.40899501528059, 45.99386807850429, 48.94358682632446, 52.253465448107036, 44.29663160869053, 44.42296722957066, 39.80938073566982, 44.73074810845511, 44.670941489083425, 50.42024230957031, 46.94948162351336, 56.05345262799944, 21.16630605288914, 34.3478673526219, 37.01691361836025, 40.46882731573922, 11.342886430876595, 19.716602631977626, 64.79321643284389, 46.7376241002764, 60.21935626438686, 50.95061567851475, 59.89303411756243, 45.76202406202044, 41.762512411390034, 50.480003765651155, 56.386379037584575, 52.14687660762242, 54.08337777001517, 52.3458764893668, 49.623541014535085, 44.5803474017552, 45.81083515712193, 43.22492061342512, 44.44528136934553, 41.826449734824045, 42.91058758326939, 42.64338765825544, 42.93649741581508, 44.459855215890066, 48.897909368787495, 47.83360515322004, 51.19589056287493, 52.149405751909526, 46.83679573876517, 37.87717356000628, 47.601632595062256, 53.19875397000994, 54.500189781188965, 49.94185536248343, 49.00902496065412, 49.88466126578194, 51.006288119724815, 50.871100493839805, 52.17938028063093, 47.41022709437779, 49.530671392168315, 47.21502440316336, 49.000760078430176, 53.48445347377232, 60.41326659066336, 59.53901645115444, 60.461299487522666, 61.94593497685024, 56.71780463627407, 53.18742145810808, 49.24634068352835, 31.01714413506644, 12.991594076156616, 4.011814304760524, 3.0464641622134616, 1.0452280449015754, 1.9982422036784036, 6.269161130700793, 49.275738511766704, 62.255984442574636, 59.90816729409354, 59.18296991075788, 54.406257084437776, 59.09202493940081, 59.21567508152553, 45.685941287449424, 22.664134434291295, 12.982070701462881, 49.94435323987688, 40.5360928262983, 39.245121002197266, 50.597560337611604, 32.73166077477591, 51.0072990826198, 63.38397584642683, 14.4436468567167, 0.9697161082710538, 0.24761485308408737, 0.28295499246035305, 0.2640470713376999, 0.27628580746906145, 0.16051268338092736, 0.33810550453407423, 0.2400076612830162, 0.15561467834881373, 0.24335311033896037], [0.14268492215446063, 0.1704692891133683, 0.12145280146173068, 0.05307884966688497, 0.09201182518154383, 0.23168798057096346, 0.07418116661054747, 0.16277671046555042, 0.1041522076619523, 0.06982197945139237, 0.07880321823592697, 0.15597768101309026, 0.05012965827648129, 0.07123346121183463, 0.32445055725319044, 13.17500046321324, 52.260830538613455, 51.42711271558489, 44.75502511433193, 30.827357564653667, 26.334193774632045, 35.55177477427891, 22.56229989869254, 4.582245341369084, 52.55474281311035, 68.29068946838379, 57.94580493654524, 58.82714571271624, 58.276608671460835, 46.2793938773019, 44.819462708064485, 59.94202586582729, 11.30402341910771, 0.14173495955765247, 11.523342439106532, 18.77201066698347, 11.760998623711721, 23.24705876622881, 33.704881055014475, 50.16900587081909, 52.88787766865322, 57.69245624542236, 62.498198645455496, 58.728793961661204, 58.36337430136544, 56.86401905332293, 54.61911514827183, 53.572560106004985, 50.916020597730366, 49.391290528433665, 49.14156532287598, 49.09031541006905, 50.27385071345738, 51.43799706867763, 55.71824720927647, 51.61747946058001, 54.25350093841553, 54.10070310320173, 53.301462241581504, 54.82794325692313, 51.10569947106497, 52.52562986101423, 51.24305493491036, 45.74254478727068, 41.45781653267996, 42.37262678146362, 41.16643687656948, 40.14078548976353, 39.361030851091655, 39.30130761010306, 40.996841771262034, 38.41189302716936, 38.45596892493111, 38.55175331660679, 40.95725788388933, 46.47567353929792, 45.98571784155709, 44.85406126294817, 42.39674745287214, 38.675702231270925, 38.26622404370989, 37.469508852277485, 36.65648276465279, 43.83965900966099, 44.973389625549316, 43.63338436399187, 17.5381669316973, 21.3884243283953, 28.248646565846034, 36.32389334269932, 21.43078749520438, 31.01725878034319, 50.80893496104649, 45.59079960414341, 48.5431204523359, 45.60432079860142, 48.43658372334072, 39.132348264966694, 38.74539961133684, 44.12390981401716, 50.53367859976632, 46.390248911721365, 47.800635950905935, 43.270820413317, 38.47800861086164, 35.719893387385774, 36.12660619190761, 38.19700608934675, 36.639550004686626, 36.5129051889692, 38.48889296395438, 39.37427411760603, 41.38028505870274, 42.13044384547642, 45.25769601549421, 49.52757249559675, 49.76156003134591, 46.50616223471505, 51.91474771499634, 50.905737263815745, 45.0179831641061, 45.91193839481899, 48.41216427939278, 45.019445759909495, 47.11634956087385, 43.48917102813721, 42.981817041124614, 42.97649472100394, 43.87680755342756, 49.05659580230713, 49.4609705380031, 49.37467738560268, 48.709137235369, 41.759681020464214, 48.91805567060198, 53.89654070990426, 50.35741669791085, 48.96344477789742, 45.60488707678658, 32.7260605267116, 14.729519196919032, 19.216648476464407, 23.222752230507986, 9.580816320010594, 1.5669277821268355, 0.06848567937101636, 1.9072835530553545, 24.83417844772339, 50.26928922108242, 46.49698713847569, 52.97147144590105, 47.7036668913705, 52.69150768007551, 44.79822901317051, 51.03238902773176, 23.55298968723842, 2.1192546359130313, 18.624102626528057, 66.12729835510254, 32.30712931496756, 27.343730551855906, 27.463243041719707, 22.547185829707555, 44.77372966493879, 30.692173412867955, 0.26921555399894714, 0.17948035629732267, 0.06753338939909424, 0.07202774751931429, 0.03356644883751869, 0.0717822942616684, 0.0298761648924223, 0.21651699606861385, 0.05969267298600503, 0.05281606662486281, 0.028297512459435632, 0.06909318534391266, 0.05093058404911842, 0.06357995939574071, 0.03694003674068621, 0.013981958751433661, 0.07663654735577957, 0.05720863092158522, 0.06311931554228067, 0.03858455117525799, 0.14311830247087137, 0.024435940830569183, 0.05167773252885256, 0.11591938909675394, 0.027147507561104636, 0.30100687380347935, 12.568161300250463, 59.78965881892613, 53.88364485331944, 39.47048929759434, 36.1269188608442, 30.43352324622018, 30.22988544191633, 25.455578429358347, 4.97828744990485, 54.157466411590576, 72.62234238215855, 61.65634100777762, 62.52510207039969, 61.121253286089214, 52.01225873402187, 50.50945370537894, 65.23563602992466, 13.298476900373187, 0.06390224995889834, 12.269953301974706, 21.799443278993877, 18.057600361960276, 30.253224440983363, 39.660321031297954, 51.61931031090872, 52.91630274908883, 57.69894586290632, 60.62318556649344, 59.70597471509661, 57.23369101115635, 57.79599135262625, 54.39101621082851, 54.413125378744944, 50.47037008830479, 49.38494334902082, 48.242781094142366, 50.589611598423545, 51.77539116995675, 52.32649448939732, 55.202565806252615, 53.88431535448347, 54.35931158065796, 55.941027300698416, 53.73825032370431, 57.45761408124651, 51.90984923498971, 53.80583892549787, 52.87104913166591, 45.99346160888672, 41.592611585344585, 43.89918075289045, 42.43594571522304, 41.47098684310913, 40.12696204866682, 41.6927490234375, 39.779051848820274, 38.613470690590994, 39.320050375802175, 39.49624974387032, 41.73414986474173, 46.288040910448345, 48.49891948699951, 47.109133856637136, 45.67716918672834, 41.729609216962544, 41.325717381068635, 40.970105103084016, 42.89938013894217, 48.56036588123867, 49.30037682397025, 49.96540975570679, 51.81067412240164, 40.24847214562552, 31.006496020725795, 34.26314449310303, 39.644517353602815, 50.981215545109336, 48.028832163129536, 50.20037351335798, 51.37567172731672, 50.112541334969656, 49.03281906672886, 42.074726240975515, 40.260499477386475, 49.09184053965977, 49.93825619561331, 50.01349128995623, 50.17359515598842, 46.497800077710835, 43.08246169771467, 38.27907473700387, 37.56624862125942, 39.89084836414882, 37.584432056971956, 39.56036424636841, 40.46329307556152, 40.11866937364851, 41.28707497460501, 42.2416775567191, 45.85753399985177, 50.135977608816965, 51.4689929825919, 49.067157064165386, 52.056852272578645, 52.5327969278608, 48.70206049510411, 49.94879313877651, 50.37241438456944, 48.30010373251778, 50.13755832399641, 45.77183839253017, 45.75112233843122, 48.093492099217, 47.93999597004482, 50.52740437643868, 51.9658135005406, 52.015142236437114, 50.477776868002756, 45.085467542920796, 51.547417300088064, 55.21990850993565, 51.860840116228374, 49.94724369049072, 49.76411696842739, 39.12126241411482, 17.955906527382986, 24.061853170394897, 31.161183765956334, 9.667454276766096, 1.6717540600470133, 0.47539460765463964, 2.0583543266568864, 27.665479046957834, 55.43101215362549, 50.24529709134783, 58.949385370527, 50.8780973298209, 60.10708032335554, 47.377681732177734, 59.65249443054199, 20.30245562962123, 6.794921330043247, 22.476128339767456, 60.68535109928676, 40.70924540928432, 28.33163411276681, 41.08111994607108, 21.90313298361642, 52.80790737697056, 36.33899525233677, 0.4833514892629215, 0.323165873331683, 0.07949581250016179, 0.09359787364623376, 0.04735318797507456, 0.1446399986743927, 0.008020015050923186, 0.02279900054314307, 0.050121471751481295, 0.10090569579707724, 0.03197860564770443, 0.1834979892841407, 0.10775433973010097, 0.12689619937113353, 0.19342669365661486, 0.1272175128438643, 0.2404136966381754, 0.15272683330944606, 0.18509645493967192, 0.28721763087170465, 0.2570610376341002, 0.2003006333751338, 0.5445613190531731, 0.17065241214420113, 0.38846979343465393, 0.47167916702372686, 26.22881739480155, 70.40708991459438, 66.24616813659668, 59.10796410696847, 43.74941233226231, 40.363899094717844, 41.070690699986045, 27.375188520976476, 8.248856203896658, 61.58844321114676, 74.54053156716483, 69.01828398023332, 69.16009671347481, 65.94233730861119, 55.844548089163645, 53.344502857753206, 73.2710748400007, 14.409961989947728, 0.20329168359083788, 18.67744221006121, 23.675785200936453, 24.276269367762975, 36.7648468698774, 44.046249798366, 54.94238008771624, 58.06909029824393, 61.58082103729248, 64.69681017739433, 63.496745109558105, 61.697884287152974, 59.96580260140555, 56.88863999502999, 55.872691767556326, 52.234538555145264, 51.1850756917681, 49.37591069085257, 53.183221272059846, 51.73526184899466, 53.24709258760725, 58.01425511496407, 54.56720168249947, 56.535063539232524, 56.26431655883789, 55.51325798034668, 56.05327892303467, 53.091303552900044, 56.37771463394165, 55.06697865894863, 46.855625356946675, 41.341500214168, 44.23065498897007, 42.43271827697754, 42.007589272090364, 40.85375056947981, 43.710947104862754, 41.96557698931013, 41.40724754333496, 40.23317221232823, 40.03442593983242, 41.80129378182547, 47.82203640256609, 49.0875951903207, 50.1733797618321, 45.735815456935335, 42.72935424532209, 42.03460039411272, 42.03163698741368, 41.55936098098755, 50.15038122449602, 51.60162019729614, 54.263464655194966, 38.20791823523385, 25.93852686882019, 34.919374057224815, 38.365089961460654, 36.30863162449428, 46.82015480313982, 53.876894678388325, 52.5186573437282, 55.68529537745884, 51.51407636914934, 52.55528824669974, 43.655358042035786, 43.80919115883963, 51.00418628965105, 56.51827321733747, 52.97053343909127, 55.16743918827602, 51.11554159436907, 47.7156594821385, 41.79737152372088, 40.721081665584016, 42.4876264163426, 41.37788793018886, 41.45322029931204, 42.66995062146868, 41.973393712724956, 42.59800202505929, 43.855740615299766, 46.554542541503906, 51.282624925885884, 52.846556731632774, 51.43256705147879, 51.871602875845774, 53.5954578944615, 52.02651643753052, 52.54591860089983, 53.669365882873535, 50.44688170296805, 52.16822842189244, 45.08833367483956, 46.8436153956822, 50.222645963941304, 48.63835941042219, 53.34812634331839, 53.597340856279644, 54.25817360196795, 53.04344783510481, 45.731003829411094, 53.30994946616036, 56.740660735539024, 52.99383422306606, 53.08895853587559, 52.10133811405727, 45.97997168132237, 23.075212444577897, 32.14962754930769, 41.19828394481114, 12.713837231908526, 3.4290393590927124, 0.7240358399493354, 3.6762202211788724, 30.515088149479457, 60.8108286176409, 53.40616117204939, 64.09434577396938, 55.25874546595982, 61.8451999936785, 51.3688451222011, 63.203551973615376, 29.65257351739066, 6.62545085804803, 25.761323486055645, 78.8309052331107, 41.47063595908028, 41.62978792190552, 38.7553494317191, 34.855697291237966, 53.687097685677664, 48.24302428109305, 1.5867306909390857, 0.5308101826480457, 0.173361938180668, 0.2476012823837144, 0.19129332527518272, 0.32395544382078306, 0.11771711334586143, 0.2720974550715515, 0.07915629393288068, 0.26912433175104006, 0.14820219895669393], [0.05538598068856767, 0.05457127386970179, 0.09408735523798636, 0.06434494656111513, 0.05850109085440636, 0.1584937431450401, 0.07545147916035992, 0.11577088492257254, 0.23254594738994325, 0.029693153819867542, 0.04483451348330293, 0.07110719263021435, 0.056431277455495935, 0.1604035206671272, 0.1753140427172184, 1.4685617004122054, 47.648925508771626, 43.28299018314907, 51.33964531762259, 34.85899421146938, 24.10892721584865, 37.72870792661394, 63.936677251543315, 7.003644347190857, 12.469727039337158, 52.60340799604143, 60.041030747549875, 56.3485495703561, 55.91706991195679, 62.160773277282715, 50.96223306655884, 51.753813539232524, 41.005864007132395, 0.6328845939465931, 0.9031636565923691, 12.636627112116132, 16.693026270185197, 24.649919169289724, 40.79843596049717, 44.406131744384766, 48.71138497761318, 62.47158704485212, 57.97509854180472, 54.332776410239084, 56.05304268428257, 56.6139360155378, 55.893244538988384, 49.2990288734436, 49.53782108851841, 48.68156678336007, 47.2913955279759, 48.983198506491526, 48.40763405391148, 50.015040738242014, 51.982301575796946, 52.53069857188633, 53.61140053612845, 52.90481390271868, 50.42194809232439, 53.31037678037371, 52.37339135578701, 53.484696660723, 51.69191551208496, 44.7421362059457, 40.67521660668509, 42.500973905835835, 39.760058947971885, 40.650258677346365, 40.66027103151594, 38.84391117095947, 39.178147315979004, 37.4186897277832, 39.669221673692974, 39.689510413578574, 39.52999019622803, 43.70816087722778, 45.3021297454834, 45.32482256208147, 39.18019356046404, 38.056753226688926, 36.78880773271833, 38.982308864593506, 34.67792763028826, 46.47122669219971, 42.31264993122646, 48.84899752480643, 22.199680362428936, 21.90238778931754, 44.10293320247105, 36.77595703942435, 36.99157701219831, 38.38474988937378, 49.13482209614345, 45.33461952209473, 48.460624490465435, 44.668791021619526, 46.970704896109446, 38.04798460006714, 40.91527339390346, 41.55303117207119, 46.850726876940044, 45.812144892556326, 44.97508846010481, 42.943803446633474, 38.70214360100882, 35.58464322771345, 35.604852063315256, 36.14593955448696, 35.9509904725211, 38.10510574068342, 38.90572234562465, 41.41835076468331, 41.600150380815776, 42.0192414011274, 40.98312602724348, 48.32754216875349, 50.19306748253958, 49.357115813664024, 47.95982265472412, 46.067463397979736, 48.1298485483442, 46.507781164986746, 44.87032699584961, 44.09801735196795, 46.00098998206002, 45.13705096926008, 47.83705840791975, 43.45195300238473, 46.70390101841518, 49.01056398664202, 49.33920683179583, 48.15686661856515, 51.41117007391793, 49.20729180744716, 45.548620564596995, 46.62859296798706, 43.02051503317696, 42.20079435620989, 34.69125427518572, 16.619389261518204, 6.0710818852697095, 14.784264053617205, 9.723267418997628, 2.2922278685229163, 0.36875805258750916, 0.5468778918896402, 3.013527963842664, 33.4541448865618, 51.453484603336875, 51.826505592891145, 49.176045758383616, 55.1551582472665, 50.48937341145107, 50.32983234950474, 47.06329311643328, 5.730450791972024, 5.670850881508418, 39.25789873940604, 61.63294642312186, 19.673754828316824, 32.880727427346365, 17.657028027943202, 21.72127778189523, 48.53217356545584, 24.148151533944265, 0.056690813707453866, 0.0981258192498769, 0.08119227896843638, 0.0848284259970699, 0.052616967487015893, 0.015317475123863136, 0.05516375368461013, 0.059449017846158574, 0.044856949243694544, 0.14875316939183644, 0.0730647322322641, 0.06612122910363333, 0.05117427311571581, 0.014913446536021573, 0.0014852277028174804, 0.042952718745384894, 0.020212521743295447, 0.032532727878008566, 0.044856165535748005, 0.1096972840438996, 0.030922798373337303, 0.02695876795665494, 0.05049882882407733, 0.08678833368633475, 0.08609044006360428, 0.053912375654493055, 1.6900444328784943, 50.791199684143066, 50.618314606802805, 54.334628105163574, 44.61987917763846, 30.63431576320103, 32.02023819514683, 61.625748089381624, 12.343363625662667, 10.415226357323782, 50.26324428830828, 63.71801744188581, 57.93564319610596, 63.343273299080984, 59.76283877236502, 53.86632646833147, 56.384906019483296, 43.34954350335257, 0.5257756156580788, 1.0927739164658954, 11.598101581845965, 16.646254471370153, 35.11147090366909, 41.77540826797485, 45.97653579711914, 49.413816588265554, 62.288835525512695, 58.3328925541469, 54.69660840715681, 57.439583505902974, 56.232205459049766, 55.436178139277864, 50.08665929521833, 49.78396449770246, 49.89319365365164, 47.72270842960903, 48.19491147994995, 50.27719627107893, 50.61451046807425, 52.90550177437918, 54.423047406332834, 57.075720242091585, 52.23434747968401, 53.72148779460362, 53.68656267438616, 52.49245916094099, 53.011381898607524, 52.84322507040841, 46.57554694584438, 41.61028432846069, 44.11536005565098, 37.88321501868111, 41.35240193775722, 41.174020835331504, 41.00419296537127, 39.79449422018868, 37.90033885410854, 38.4252370425633, 38.84080532618931, 40.78141287394932, 45.41029582704817, 45.32436398097447, 46.89744656426566, 44.53443023136684, 40.05020877293178, 41.66206577845982, 40.25012581689017, 38.81190429415022, 49.625667163303916, 48.00991569246565, 50.59596920013428, 42.257422174726216, 33.13478136062622, 41.03947939191546, 39.52021408081055, 45.92041172300066, 47.47530392238072, 50.080690792628694, 49.39184985842024, 50.94810043062483, 51.09320313589913, 49.64295080729893, 40.373709951128276, 41.924488816942485, 45.33964654377529, 49.150601455143516, 48.28414372035435, 48.785838399614605, 47.50592810767037, 39.81613438470023, 39.00433118002755, 38.772601808820454, 36.85189042772566, 37.77831111635481, 39.5625181879316, 39.44875533240182, 41.81014231273106, 40.03669800077166, 41.90459612437657, 43.76929112843105, 48.48600973401751, 51.57648856299264, 50.9395888873509, 49.50935779299055, 48.24689095360892, 51.63207415172032, 49.060073375701904, 49.26051153455462, 47.849943842206685, 48.94403151103428, 48.96150623049055, 50.1150426864624, 47.94810799189976, 48.74155752999442, 51.31731728145054, 51.42881849833897, 49.47870234080723, 52.903566701071604, 49.69513177871704, 47.606527600969585, 47.27875328063965, 47.199960708618164, 47.75642108917236, 41.440376554216655, 19.483308179037913, 6.693653506892068, 22.432102816445486, 11.569315195083618, 1.651129201054573, 0.614279218018055, 0.2932176717690059, 3.5239634769303456, 36.517574378422324, 54.27641609736851, 56.48676661082676, 55.511837073734824, 59.12755107879639, 55.534536838531494, 54.025492327553884, 50.67673853465489, 8.147111126354762, 13.148119619914464, 36.2575033051627, 73.96336555480957, 23.764777728489467, 42.69405392238072, 26.30774024554661, 18.531905242374965, 56.45913709912981, 26.400653294154576, 0.09191372937389783, 0.04856427798845938, 0.050242098314421516, 0.12289816247565405, 0.01898737926967442, 0.08933376281389169, 0.018358584260568023, 0.035212791923965724, 0.04774077396307673, 0.043352732102253606, 0.0731150456038969, 0.11636741219886712, 0.10118690106485571, 0.20522363563733442, 0.13626728366528237, 0.16526138356753758, 0.14103734413427965, 0.23547518306544848, 0.16445547395518847, 0.24090927147439548, 0.14738102230642522, 0.09315016945557934, 0.22486301751009055, 0.17769749196512358, 0.3510696217417717, 0.38303942339760916, 6.686803017343793, 71.34779262542725, 56.38510404314314, 62.92979294913155, 49.393784931727815, 38.93176071984427, 44.12497983660017, 73.8452878679548, 9.627701027052742, 16.990740946360997, 59.52477264404297, 69.23017624446324, 63.744378907339915, 66.08797849927629, 65.73740019117082, 65.0288576398577, 60.49010671888079, 47.19036177226475, 0.7371404681886945, 2.3935132793017795, 16.90655309813363, 24.04588794708252, 47.31491865430559, 51.57503638948713, 50.91605186462402, 50.877173219408306, 61.86160469055176, 61.49317646026611, 57.56739909308297, 58.96442822047642, 61.94209262302944, 59.33180727277483, 51.880100522722515, 51.44087014879499, 53.2090095111302, 48.99034820284162, 48.92015750067574, 54.04619101115635, 51.67656694139753, 55.673028332846506, 55.92706836972918, 58.48692716870989, 53.48315068653652, 54.42959608350481, 55.56477539879935, 53.38632753917149, 55.78566905430385, 57.599409443991526, 48.32846975326538, 42.2758001599993, 44.30633129392351, 39.277440547943115, 42.24273368290493, 42.114000933510916, 43.35707187652588, 40.61596931729998, 38.245612212589805, 41.18403318950108, 42.58811126436506, 41.44012294496809, 46.31410012926374, 46.0632632119315, 49.91828012466431, 44.42332853589739, 41.29780994142805, 41.679630824497764, 43.90869631086077, 39.27261502402169, 52.73510415213448, 50.099944250924246, 54.1028778893607, 41.64734601974487, 36.74628128324236, 47.79542132786342, 39.32663031986782, 52.45767647879464, 50.85188177653721, 54.539610385894775, 52.08827550070626, 52.73146677017212, 51.936724867139546, 53.09551763534546, 42.107997689928325, 48.035012585776194, 45.700546400887625, 52.53861951828003, 52.424464089529856, 52.118430682591026, 49.69278676169259, 44.55794988359724, 41.26674107142857, 41.72298410960606, 39.897348403930664, 39.8649628502982, 41.35147435324532, 42.757070609501426, 43.43015302930559, 41.41579382760184, 43.39461646761213, 42.50308963230678, 49.1643762588501, 51.38169581549508, 54.54687820162092, 50.28103862489973, 49.69584049497332, 52.833560126168386, 53.76085628782, 50.9276762008667, 51.9039432661874, 51.78134230204991, 50.48248774664742, 50.64879635402134, 48.83948196683611, 51.76687267848423, 53.41478041240147, 53.68435314723423, 53.80203826086861, 57.827894006456646, 52.61402136938912, 47.20598479679653, 50.01338011877877, 47.23939520972115, 51.08413226263863, 48.452033042907715, 22.547144140516007, 8.754305515970502, 28.467839649745397, 18.6092369556427, 3.7863552485193526, 1.0521274975367954, 1.4375962934323718, 4.261621151651655, 40.103393759046284, 59.69826916285923, 62.566235406058176, 60.54426097869873, 62.62660830361502, 59.11088235037667, 58.55266407557896, 56.124327727726524, 10.501680186816625, 10.977464165006365, 49.75349317278181, 71.1670560836792, 27.712667737688335, 50.77310310091291, 26.689050436019897, 30.940418652125768, 60.30080999646868, 41.9532265663147, 0.3561488091945648, 0.1915404884410756, 0.2414766624569893, 0.26811046472617556, 0.16604300162621907, 0.13108132194195474, 0.07618745895368711, 0.14509098018918717, 0.1465997706566538, 0.13288394521389688, 0.17911620012351445], [0.07119912733989102, 0.029835802236838, 0.07903102958308798, 0.03753999740417514, 0.09389908212636199, 0.15188747192067759, 0.08989208178328616, 0.041676848993769715, 0.03740334723676954, 0.03675677800284965, 0.07625400288296597, 0.052975817516978295, 0.03266327462292143, 0.0972564055451325, 0.1252791147146906, 0.09671377430536918, 20.771424293518066, 51.72417599814278, 55.61995104381016, 42.202298641204834, 29.49914687020438, 29.938922677721294, 64.75821140834263, 37.36771426882063, 4.263391639505114, 11.741101588521685, 57.59501123428345, 59.57348646436419, 56.71476479939052, 57.10697323935372, 54.14566142218453, 49.98283583777291, 50.10229969024658, 3.706233833517347, 0.17962515567030224, 0.6519171755228723, 9.596631288528442, 16.575170925685338, 49.369938714163645, 43.635187421526226, 53.5006080354963, 60.07499354226248, 64.00921644483293, 57.226857457842144, 55.924056325639995, 49.395216260637554, 49.423300879342214, 47.56061737877982, 47.777064187186106, 46.603034019470215, 46.74919979912894, 46.87313829149519, 48.35414334705898, 50.09397922243391, 47.539307253701345, 49.24036523274013, 51.9655807358878, 50.5033358165196, 51.76596246446882, 52.389400005340576, 53.58963877814156, 52.73804324013846, 46.78809928894043, 41.67284590857369, 40.72588634490967, 42.80864361354283, 40.80697182246617, 40.399390493120464, 41.537936210632324, 40.342974594661165, 37.83672114780971, 38.59889684404646, 38.23845904214041, 39.42599303381783, 40.24992431913103, 42.38833665847778, 42.702412605285645, 39.75363881247384, 39.639278411865234, 37.873956544058665, 37.344385692051475, 36.19456304822649, 38.140680517469136, 38.29904385975429, 41.336761542728965, 44.176924569266184, 47.839104652404785, 47.1041658946446, 43.70029204232352, 43.476358549935476, 45.095601490565706, 47.59182521275112, 45.171878814697266, 44.780368668692454, 46.517189025878906, 46.47255727222988, 42.45163822174072, 38.157401357378276, 37.71956409726824, 41.35304464612688, 45.963428020477295, 45.965710503714426, 45.06497730527605, 41.91885730198452, 36.76249143055507, 35.46356391906738, 35.643779345921104, 35.80046122414725, 35.6560811315264, 38.278251375470845, 37.07011944907052, 40.0069249698094, 39.1372641154698, 39.02787862505232, 39.85070514678955, 42.26029872894287, 44.50997952052525, 46.63538135801043, 47.40763194220406, 49.12666491099766, 45.09073427745274, 42.43310390199934, 42.52016135624477, 43.08928482873099, 41.9340877532959, 43.39422389439174, 42.51470354625157, 43.803722926548545, 45.485180037362234, 45.30116047177996, 48.248801708221436, 46.91885049002511, 51.68648896898542, 50.99767582757132, 48.18363455363682, 49.94627094268799, 48.93826103210449, 41.352617331913535, 26.822679928370885, 11.287925311497279, 3.407514056989125, 8.007061498505728, 5.6017666799681525, 0.902162464601653, 0.13068048416503839, 0.5657546275428363, 7.640833241598947, 42.681814670562744, 46.36659376961844, 51.545635087149485, 50.79955489294869, 47.024619443076, 41.72981071472168, 51.042759214128765, 23.287184613091604, 2.2769038336617604, 13.585882186889648, 59.738283838544575, 22.746918746403285, 22.05114872114999, 28.182779380253383, 19.307841845921107, 35.06120763506208, 48.23854964120047, 11.628454787390572, 0.565075332564967, 0.057990052205111296, 0.06558490145419325, 0.12131784084652152, 0.09783788970006363, 0.04753314224737031, 0.01153714194827314, 0.017396228221644248, 0.043069688004574606, 0.09935922628002507, 0.12120759247669152, 0.03247172079448189, 0.07502630911767483, 0.08654496353119612, 0.04719956425417747, 0.02092328547899212, 0.07696889380791358, 0.039404659132872305, 0.03362686559557915, 0.01990310468577913, 0.024793047025533657, 0.038788301670657735, 0.02993649004825524, 0.04411544278264046, 0.1440886075475386, 0.11216895641492945, 0.1909149062952825, 21.585468292236328, 59.47163282121931, 53.312218053000315, 45.24249335697719, 34.54041583197457, 30.571844509669713, 63.004187311444966, 47.93429497310093, 8.162803632872444, 9.60358556679317, 59.01430238996233, 62.755177770342144, 61.186392647879465, 59.331911495753694, 59.25586346217564, 53.77171284811837, 52.232704230717246, 4.018364284719739, 0.15641411473708494, 2.0230650774070194, 7.42649781703949, 20.691106591905864, 54.18316779817854, 48.18369013922555, 53.610521589006694, 60.57345730917794, 64.2397437776838, 58.33187116895403, 55.127928256988525, 49.79772193091256, 50.050900391169954, 49.29651362555367, 49.79013797215053, 47.06123992374965, 48.27315514428275, 46.05457101549421, 47.46834182739258, 50.05238035746983, 50.404577595846995, 49.944217750004356, 54.794122900281636, 53.02641780035836, 55.03967571258545, 53.36959627696446, 54.33679246902466, 51.503143378666465, 47.91153614861624, 42.40232685634068, 42.1781119619097, 41.56730624607631, 40.97260992867606, 41.2153000831604, 43.143056937626426, 40.162012236458914, 39.42611115319388, 39.605322565351216, 39.201687812805176, 38.90404435566494, 41.1558130809239, 43.24451800755092, 42.85280288968767, 41.23844453266689, 40.44879565920149, 41.05152062007359, 40.70997149603707, 38.01172889981951, 40.00713341576712, 44.037210191999165, 46.873117446899414, 48.292019503457205, 43.95677784511021, 45.18459749221802, 47.81761734826224, 43.58261387688773, 50.15581471579415, 50.66244261605399, 49.63510281699044, 47.53120912824358, 49.72740616117205, 50.07774823052542, 47.07889529636928, 39.84526818139212, 39.62864071982247, 44.22958844048636, 47.61457708903721, 47.56643302100045, 48.31359018598284, 45.91529784883772, 39.873328481401714, 39.18056876318795, 38.23927198137556, 38.23875086648123, 36.89885677610125, 38.829292161124094, 37.385744844164165, 38.52920641217913, 38.26271520342146, 40.158958503178184, 41.432778699057444, 42.16364928654262, 48.301006998334614, 48.992432662418906, 50.0628547668457, 51.19065509523664, 48.514212472098215, 46.050131116594585, 45.51878499984741, 45.922739369528635, 45.91159793308803, 45.054363931928364, 43.776909828186035, 47.188805375780376, 48.7752354485648, 49.025002343314036, 50.24880593163626, 49.64594895499093, 53.21695130211966, 52.27018976211548, 48.73755536760603, 51.02837296894619, 49.51258870533535, 45.65101964133126, 30.264907836914062, 13.935400026185171, 3.5104655155113766, 8.03377992766244, 5.167244579110827, 1.5441242286137171, 0.4730920397809574, 0.5858342157942908, 8.320348824773516, 47.843693937574116, 49.16036714826311, 56.17886413846697, 56.75155551092965, 49.796898569379536, 45.6294698034014, 55.04383768354143, 22.7405298777989, 5.841145583561488, 16.130566120147705, 61.11079624720982, 31.21033184868949, 23.245910576411656, 37.65692956107003, 16.51737928390503, 36.729914801461355, 56.7308464050293, 9.673356771469116, 0.7767777698380607, 0.08324882361505713, 0.1420422409261976, 0.09274511797619717, 0.01114407170098275, 0.07197531033307314, 0.03232819028198719, 0.050796498744083304, 0.007746590883471072, 0.07250707144183771, 0.06117886145200048, 0.12443309011203901, 0.17017525274838718, 0.13455296494066715, 0.20260982375059808, 0.15629936089473112, 0.08820695363517318, 0.11165498649435383, 0.11672789071287427, 0.2030867931566068, 0.16569601238838264, 0.14359022357634135, 0.1014680452644825, 0.15146676663841518, 0.32952040806412697, 0.23055246578795568, 0.2545707326914583, 45.91829947062901, 67.03993034362793, 63.980992862156455, 55.75401306152344, 42.98004872458321, 38.89994491849627, 72.4888813836234, 47.213398524693076, 7.638961570603507, 14.682992322104317, 67.9997683933803, 68.14877251216343, 65.48791817256382, 66.89713791438511, 65.78274413517543, 61.112498555864605, 59.11205659593855, 5.01927878175463, 0.4433466116232531, 3.257951042481831, 12.886852587972369, 30.657943112509592, 63.750166756766184, 57.29594339643206, 57.521725109645296, 65.13217735290527, 68.64847305842808, 61.47651468004499, 59.64389256068638, 52.955327306474956, 51.432157107761924, 52.86679336002895, 50.27437877655029, 50.915520327431814, 49.46853712626866, 50.56366702488491, 52.31200402123587, 53.8236471584865, 51.12555047443935, 52.25639063971383, 57.1753191947937, 54.57269770758492, 56.63299145017351, 56.117890221732004, 56.44474737984793, 55.210427692958284, 51.54145227159773, 44.004056862422395, 43.45961686543056, 44.546197005680625, 43.99749428885323, 42.34718247822353, 45.50067799431937, 41.77184384209769, 40.871353830610005, 40.89243466513497, 39.74148293903896, 41.96922479357038, 43.41883093970162, 44.252430643354145, 43.957375390189036, 43.1790520804269, 44.530778953007285, 42.73645530428205, 42.437526430402485, 40.053794043404714, 44.22199058532715, 44.06532955169678, 47.475918837956016, 50.651721545628135, 53.3485050201416, 54.85132394518171, 49.2931090082441, 49.43346956798008, 54.684275354657856, 54.76533303941999, 51.2633957862854, 50.72324630192348, 52.18924672263009, 52.00636318751744, 48.58592135565621, 44.32215234211513, 43.091501304081504, 46.6679128238133, 51.51819665091378, 51.31390571594238, 50.98971666608538, 47.61732857567923, 42.338198457445415, 42.377455779484336, 41.12818009512765, 39.52614089420864, 37.85113171168736, 41.15145308630807, 38.51457003184727, 41.26747063228062, 40.18219327926636, 39.329249790736604, 41.741202286311555, 44.01580626623971, 48.91185440335955, 50.00355189187186, 50.22346237727574, 52.07309716088431, 51.40829699380057, 48.247266156332834, 47.20826728003365, 47.484461648123606, 47.59067528588431, 47.71541976928711, 47.37158816201346, 49.83835847037179, 52.24010753631592, 51.271803106580464, 53.33950710296631, 52.700165135519846, 54.98195007869175, 53.712034770420615, 50.807732922690256, 53.598886830466135, 54.01501096997942, 50.80406427383423, 33.82017946243286, 16.13598918914795, 6.315251571791513, 10.961690885680062, 6.690517263753073, 1.8638588317802973, 0.8027759747845786, 1.9641363195010593, 8.813693506377083, 55.81940255846296, 53.33253805977957, 61.75594343457903, 57.65468583788191, 57.11740248543875, 50.51310498373849, 59.557526452200754, 27.738018240247452, 5.423601405961173, 20.216280596596853, 71.6455854688372, 29.04355522564479, 35.33420583180019, 38.317724091666086, 29.481109346662247, 49.54631873539516, 59.68962560381208, 22.580280099596294, 1.4148747069495065, 0.214878591841885, 0.27379612677863663, 0.23482330090233258, 0.22484036801116808, 0.1857642691050257, 0.10353524291089602, 0.14020991139113903, 0.09915118065795728, 0.19413885687078747, 0.15015271572130068], [0.052156781644693444, 0.07026415358164481, 0.06516281196049281, 0.028541913987802606, 0.01165101199876517, 0.04258546166654144, 0.0918793547898531, 0.08224860871476786, 0.05842205509543419, 0.009276142826170793, 0.01711104843499405, 0.03539258674053209, 0.14442455023527145, 0.02317723462225071, 0.10876166567738567, 0.23660013984356607, 3.4915305886949812, 48.90997838973999, 43.55208696637835, 49.68162795475551, 36.05753067561558, 21.907425233295985, 46.289531299046104, 71.69278458186558, 20.924814462661743, 4.936108410358429, 29.873585292271205, 58.856529644557405, 57.723268032073975, 56.58207157679966, 53.615180356161936, 52.21682064873831, 46.901243754795615, 12.04463016986847, 0.29984448903373306, 0.7968229427933693, 0.2969162847314562, 2.4068260278020586, 9.1629090990339, 32.89803539003645, 52.75081055504935, 62.46379116603306, 59.05341379983084, 59.10731097630092, 51.976513726370676, 51.64741924830845, 46.853606905256, 45.39738607406616, 48.687642983027864, 45.77989135469709, 46.699582712990896, 46.36613171441214, 43.78563676561628, 45.58513682229178, 46.20374536514282, 46.59225041525704, 46.79959160940987, 46.617336886269705, 47.325545924050466, 48.412133012499126, 48.37860795429775, 42.453646251133506, 42.45668608801705, 41.04104968479702, 39.00110374178205, 41.011721338544575, 42.56895160675049, 42.31106921604702, 39.57345117841448, 40.405702931540354, 36.85413816996983, 38.21076004845755, 39.475752558027, 38.64275387355259, 39.88795443943569, 38.218069553375244, 40.31208290372576, 39.172213554382324, 37.367540563855854, 37.30716071810041, 38.14860493796212, 38.59049994604928, 38.81416940689087, 41.401153973170686, 41.09333487919399, 43.612300055367605, 44.39993395124163, 44.7814873286656, 50.083949497767854, 48.47139767238072, 46.87138387135097, 47.61281572069441, 45.6829639843532, 44.85554122924805, 43.98893410818917, 42.0565219606672, 37.426374435424805, 37.25494500568935, 38.56032044546944, 38.140809059143066, 41.55072784423828, 43.036572320120676, 43.00466966629028, 40.18006713049752, 37.114042486463276, 37.0329326902117, 35.195366927555625, 35.054262910570415, 36.311615875789094, 38.4721234866551, 40.77387407847813, 40.37123639242989, 38.9267441204616, 38.15134252820696, 39.705942903246196, 40.06976100376674, 38.103573662894114, 40.833691120147705, 40.73492595127651, 40.92517805099487, 39.64370094026838, 40.090598651341026, 40.145489420209614, 40.95035137448992, 41.68388659613473, 41.663622174944194, 41.91209323065621, 41.779431274959016, 43.43408570970808, 44.24524620601109, 45.713452679770334, 47.952426297324045, 49.846307209559846, 52.29965707233974, 52.38973004477364, 48.850376742226736, 49.015962736947195, 42.753846645355225, 33.668121610369, 11.3296822479793, 2.8168222904205322, 0.26665731413023813, 0.7898723557591438, 0.07240585437310593, 0.2734881804457733, 0.8524794791425977, 11.321922847202845, 45.13479975291661, 49.11171933582851, 51.14596080780029, 47.362770898001536, 51.972987515585764, 53.20925269808088, 45.123050349099294, 6.855915222849164, 7.498505473136902, 45.27935355050223, 37.45865229197911, 17.16828305380685, 30.55203172138759, 21.17021267754691, 25.18880581855774, 35.184572901044575, 44.807518754686626, 2.558989188500813, 0.19487307247306618, 0.13125539331563882, 0.10063413251191378, 0.04272094475371497, 0.09080928470939398, 0.03048898040183953, 0.049154477925705056, 0.030887127787406956, 0.052181514246123176, 0.010026784913082207, 0.07676187955907413, 0.0014249876819251636, 0.027028699472014393, 0.014563163010669606, 0.029536327413682426, 0.032838726815368445, 0.05618125765717455, 0.012167164257594516, 0.06080544327518769, 0.02952900602083121, 0.04838375374674797, 0.06073393246957234, 0.013784087761970503, 0.04650464940017887, 0.09136429242789745, 0.07731854968837329, 0.07902627983795744, 3.216197580099106, 54.66895457676479, 48.83369411740984, 45.70591041019985, 41.471153599875315, 25.603401354381017, 47.041517462049214, 64.13465922219413, 29.47406734739031, 8.39350380216326, 28.203570127487183, 66.33840547289167, 58.43806743621826, 61.48289312635149, 56.36568035398211, 56.07832717895508, 52.79897894178118, 12.632938487189156, 0.09458577313593455, 1.9678420977933067, 0.400184266269207, 2.0228431693145206, 11.0668831382479, 39.34417104721069, 53.43941872460501, 66.19986534118652, 57.78482559749058, 58.85429927280971, 52.79843003409249, 50.790049757276265, 48.05219548089163, 47.23784576143537, 47.815532888684956, 48.58617149080549, 48.106110027858186, 46.60950974055699, 46.30163506099156, 46.1139121055603, 47.022576672690256, 48.104591846466064, 49.02385936464582, 48.413178716387065, 49.768383162362234, 50.310002190726145, 47.596390179225374, 45.6177134513855, 43.0137231690543, 41.08868306023734, 40.85782221385411, 40.67845794132778, 43.23778172901699, 43.160062653677805, 40.47250291279384, 39.96859175818307, 39.25351095199585, 39.41445207595825, 40.10628768375942, 39.51314081464495, 40.69653367996216, 39.92412328720093, 42.219346046447754, 41.64003651482718, 38.8677191734314, 38.878992625645225, 41.42909615380423, 40.036663259778706, 42.54551880700247, 42.489936692374094, 44.151782512664795, 47.05909293038504, 50.87181615829468, 50.46040984562465, 51.54056985037667, 50.66808107921055, 50.130943638937815, 51.15528876440865, 48.84180613926479, 46.44781821114676, 46.927622590746196, 45.673705509730745, 41.238284724099294, 40.68417630876814, 40.857103075299946, 43.140235968998496, 45.549537726810996, 46.7805118560791, 47.59254435130528, 43.84935522079468, 39.42704221180507, 39.25054407119751, 38.345951148441856, 37.587784562792095, 37.70870753696987, 38.54537834439959, 41.735817432403564, 39.2991224016462, 39.80052873066494, 39.54279225213187, 40.443845067705425, 40.18084880283901, 40.624730995723176, 42.69680888312203, 44.40215390069144, 43.57392168045044, 42.297895431518555, 44.114213602883474, 43.94793973650251, 44.40076426097325, 43.86307791301182, 46.769547598702566, 45.309602533067974, 45.57738263266427, 46.04265832901001, 47.017233507973806, 47.88938529150826, 51.30593613215855, 51.823177405766074, 52.81382376807076, 51.660054547446116, 52.418922901153564, 50.5279289654323, 45.83118295669556, 34.02858720506941, 13.087236029761177, 2.8442943819931576, 0.14526749428893837, 0.420377034161772, 0.47010534576007296, 0.525968645300184, 1.3320130961281913, 12.57475687776293, 49.365995611463276, 51.8465233530317, 55.12777887071882, 48.619762556893484, 57.27970545632498, 55.55980396270752, 47.70181172234671, 8.077534471239362, 11.868791239602224, 38.744913237435476, 40.99668543679373, 17.041678190231323, 33.39666938781738, 24.836733647755214, 19.637605088097708, 40.67965650558472, 50.50415570395333, 3.3711031079292297, 0.2811838260718754, 0.11575871200433799, 0.04760330955364874, 0.03796768820445452, 0.0480842789235924, 0.05413120998335736, 0.11193285336984055, 0.04337383793400867, 0.04420913150534034, 0.026145184113244926, 0.07383120538932936, 0.22973382685865673, 0.17630330606230668, 0.07607337686100177, 0.13409138470888138, 0.10010469877826315, 0.16973058160926613, 0.1783545852771827, 0.2544737293251923, 0.17005961681050913, 0.13259655849209853, 0.11969166382082871, 0.14346925435321672, 0.31326574885419434, 0.20344123270894798, 0.25558991943086895, 0.39374920300074984, 11.609054548399788, 73.9455086844308, 58.0409848349435, 62.539213861737935, 48.386296136038645, 34.569566999162944, 55.64788280214582, 80.32453169141496, 27.081156390053884, 9.40882408618927, 35.79410014833723, 69.621262550354, 66.65896756308419, 67.49317523411342, 62.37786974225725, 61.9609500340053, 58.483063970293315, 14.753587756838117, 0.8701683985335487, 2.2881477560315813, 0.6607884509222848, 3.3024299357618605, 14.739314419882637, 45.01786504473005, 56.706861223493306, 68.0133034842355, 60.45344107491629, 62.7054078238351, 56.62157555988857, 53.76134613582066, 50.229222433907644, 49.25686025619507, 52.19525344031197, 50.29779767990112, 50.529547895704, 49.5597357068743, 48.149584906441824, 48.21333810261318, 48.824598925454275, 50.50611857005528, 50.762830189296174, 50.90412528174264, 51.007490158081055, 51.621523312159944, 50.94778776168823, 46.145085198538645, 46.69831814084734, 43.95445019858224, 41.42117520741054, 42.78103494644165, 44.997791699000764, 45.309081418173655, 39.938551221575054, 41.41773584910801, 40.38358334132603, 39.81103440693447, 41.645803519657676, 40.83663020815168, 42.12046275820051, 41.400570324489046, 43.30338314601353, 42.87824371882847, 40.971981116703574, 41.45188624518258, 43.6338255746024, 43.20466661453247, 45.23016030447823, 47.106858321598594, 46.7716737474714, 51.81222357068743, 52.479542459760395, 52.243112632206504, 56.65699052810669, 52.86049829210554, 53.51895127977644, 53.62683595929827, 51.16653094972883, 49.404460838862825, 49.228584562029155, 46.73816953386579, 44.79927471705845, 42.79115152359009, 44.13311617715018, 44.39439276286534, 48.40585878917149, 50.656970909663606, 50.953433173043386, 45.89908422742571, 42.97918367385864, 43.3552896635873, 41.611510685511995, 39.260153429848806, 38.41232034138271, 41.23506770815168, 45.37643378121512, 40.69593266078404, 41.499366760253906, 40.65650858197893, 42.98289748600551, 40.95645536695208, 40.020119598933626, 43.892972537449424, 46.946024894714355, 45.4995002746582, 43.42027269090925, 45.6294698034014, 46.18184116908482, 45.836533069610596, 46.93097162246704, 48.570326123918804, 47.223834718976704, 49.99299757821219, 49.231120654514854, 49.197480951036724, 50.90264184134347, 54.75075224467686, 55.5420686858041, 54.12357657296317, 55.42420291900635, 52.705289431980674, 52.92454331261771, 47.47302838734218, 37.635678495679585, 15.82042806489127, 4.593873151711055, 0.9421440277780805, 2.062760570219585, 1.4171043187379837, 1.4518700646502631, 2.2060780227184296, 13.695586425917488, 57.91480554853167, 57.870013986315044, 60.429622650146484, 54.61143738882882, 57.88131870542254, 58.664342471531455, 55.595594133649556, 10.255235399518694, 12.28853017943246, 52.48854732513428, 46.81451633998326, 20.97560405731201, 47.75052901676723, 30.28109019143241, 39.44228655951363, 43.73408113207136, 65.8557071685791, 7.766318576676505, 0.6830028189080102, 0.2263555231371096, 0.27681221493652886, 0.0962094192260078, 0.12690010773284094, 0.11227556105170931, 0.23617988239441598, 0.08220281438635928, 0.1496047851230417, 0.08104172561849866, 0.15966254685606274], [0.1075194241212947, 0.08367645673985992, 0.05622225474300129, 0.08662319861884628, 0.03067359620971339, 0.06598204121525798, 0.02458049593094204, 0.017443014907517602, 0.042339879487242014, 0.08816580727164235, 0.04343807823689921, 0.052362058843885145, 0.05377960331471903, 0.07135183164583785, 0.017394106103373424, 0.01051342683578176, 0.30988270895821707, 28.997014454432897, 48.65968343189785, 43.31684875488281, 37.44806323732649, 25.38706398010254, 24.748045103890554, 74.1563309260777, 31.338289873940603, 4.936056733131409, 27.70118931361607, 60.80407496861049, 61.20744568961007, 58.41955048697335, 53.658165386744905, 50.472767216818674, 53.96445935113089, 11.428922499929156, 0.25487517778362545, 0.8666453904339245, 0.4034297806876046, 0.17715946797813686, 6.122436021055494, 30.72653225490025, 52.67043031964983, 65.11461925506592, 60.411022322518484, 58.09488548551287, 49.71376684733799, 46.66781554903303, 46.49292591639927, 47.560134478977744, 45.00275271279471, 45.97501414162772, 44.773225920540945, 44.91432646342686, 45.97483696256365, 43.430642877306255, 42.17460659572056, 43.578941753932405, 44.63466841833932, 45.26117706298828, 41.73070355824062, 44.00329603467669, 41.490215982709614, 41.49962036950247, 39.9699501310076, 38.80540425436837, 40.69666916983468, 42.31654439653669, 43.413150787353516, 43.03900418962751, 42.14784213474819, 40.6649888583592, 37.7856171471732, 36.951805523463655, 38.696762221200125, 38.82180895124163, 38.89103732790266, 38.01197903496878, 37.9361047063555, 37.4020140511649, 37.07977049691336, 35.788128171648296, 38.095617975507466, 39.51968601771763, 43.1574501310076, 39.999118668692454, 42.686883381434846, 42.201100076947895, 47.22691624505179, 48.212476525987896, 49.447602203914094, 46.73082876205444, 48.746247564043315, 49.69437789916992, 47.226165839603965, 46.95105539049421, 42.74334791728428, 39.570640632084434, 39.56202139173235, 38.39505059378487, 36.66363246100289, 38.38376324517386, 40.582822935921804, 40.67324331828526, 38.73614808491298, 39.43882983071463, 36.34933417184012, 37.9802257674081, 35.654312814985005, 36.482374804360525, 36.36144488198416, 40.45844323294503, 39.73274210521153, 40.264289719717844, 40.32018450328282, 39.43329906463623, 36.18454374585833, 39.26453079496111, 39.5077976499285, 37.64270312445504, 37.87281356539045, 37.92615488597325, 37.600767271859304, 36.47796617235456, 37.34856503350394, 38.415804862976074, 39.681280272347585, 40.027279717581614, 40.13728707177298, 41.087953499385286, 42.59870031901768, 43.96942356654576, 45.72555296761649, 48.14282430921282, 52.2308976990836, 51.959480217524934, 49.0170362336295, 50.442118712833945, 51.7110195841108, 48.2577475139073, 36.58082383019583, 18.927408865519933, 3.917088644845145, 0.2321293811712946, 0.232791468501091, 0.5399134627410344, 0.22096553950437478, 1.9712334700993128, 20.147220713751658, 48.47176592690604, 45.979891777038574, 45.18673753738403, 46.0644200869969, 41.58847393308367, 56.21472726549421, 23.555115836007253, 6.202747642993927, 23.770386661802018, 64.20666340419224, 35.15794392994472, 21.629181146621704, 31.351977825164795, 37.11023487363543, 34.80572237287249, 40.20084571838379, 38.02012927191598, 0.2394622548350266, 0.045227039206240854, 0.008234554253119444, 0.04528887749516538, 0.05547034973278642, 0.05240408730294023, 0.04374802964074271, 0.03399095391588552, 0.09218614761318479, 0.03853922503601227, 0.030956966004201343, 0.07470822547163282, 0.03643987840041518, 0.022152716293931007, 0.044594522432557175, 0.031159746194524423, 0.014498729325298752, 0.02784554537252656, 0.05753859571580376, 0.05020282810021724, 0.03428855258971453, 0.06691805991743292, 0.03271697049162217, 0.07163733882563454, 0.036459806973912885, 0.08133317676505872, 0.010412616039892393, 0.025135585073647753, 0.3103076618696962, 31.623958110809326, 56.25547497613089, 40.98091302599226, 40.727908270699636, 30.07315492630005, 28.62310583250863, 74.09249087742397, 28.93411762373788, 7.600840279034205, 30.302261352539062, 65.62552724565778, 62.08699035644531, 62.15104579925537, 55.92968436649868, 55.70915896551949, 55.92232275009155, 12.87598386832646, 0.14988297090998717, 0.8276442289352417, 0.7025181374379567, 0.010644203434432191, 5.910439099584307, 33.86031225749424, 52.43029710224697, 65.82376629965646, 61.29966218130929, 60.25607749394008, 50.95742491313389, 48.217833587101524, 48.280881541115896, 47.004959515162874, 45.98789957591465, 46.21665511812483, 46.24221406664167, 46.14006859915597, 46.63484982081822, 43.30582543781826, 43.51867307935442, 45.63268334524972, 47.44521822248186, 48.40772785459246, 44.02715267453875, 43.37740230560303, 42.667838369097026, 42.202058928353445, 41.22435358592442, 39.61862489155361, 41.75535576684134, 41.68949726649693, 45.612099306924, 44.83538450513567, 42.29180186135428, 41.1571957724435, 38.89133610044207, 38.700844287872314, 38.80158274514334, 38.933532510484966, 40.41423184531075, 39.39861365727016, 40.24857636860439, 38.97757019315447, 39.85825783865792, 38.804817131587434, 39.04423468453543, 41.94901248386928, 43.97936643872942, 43.20330129350935, 44.51454448699951, 44.92677763530186, 48.46525199072701, 49.38236556734358, 50.006953035082134, 50.22025578362601, 51.382380213056294, 52.49533224105835, 49.959517683301655, 46.51821041107178, 42.684833662850515, 41.34948716844831, 41.94920355933053, 40.27776575088501, 39.657920428684776, 40.91622182301113, 44.68343782424927, 43.58758183888027, 43.91955287115914, 42.71576009477888, 40.89649588721139, 40.964591707502095, 38.325499125889365, 39.45324386869158, 38.83496536527361, 40.77444035666329, 41.51983962740217, 40.310759271894185, 38.906889642987935, 39.156538418361116, 38.43697254998343, 39.03254781450544, 40.03483588354928, 39.02026687349592, 39.83428307941982, 40.950031757354736, 40.206338269369944, 38.53290285382952, 39.57882908412388, 41.29052822930472, 43.81729275839669, 43.21565171650478, 43.68941463742937, 42.198595251355854, 46.65451669692993, 47.040461335863384, 48.068266664232524, 50.38637678963797, 53.2612738609314, 54.12348277228219, 50.910924094063894, 52.6552346093314, 52.52275330679757, 50.37724338259016, 39.45329598018101, 21.66429213115147, 5.450122679982867, 0.504279300570488, 0.3212650253304413, 0.42584545644266264, 0.7432676394070897, 2.04960697889328, 21.94368961879185, 53.78444194793701, 51.35971518925258, 49.40977273668562, 48.015126841408865, 45.49393129348755, 58.34030628204346, 25.67838110242571, 8.855035287993294, 28.82168882233756, 57.35175132751465, 43.60035957608904, 19.12291727747236, 34.95461184637887, 39.9888596534729, 35.58523382459368, 47.844729219164165, 44.071930340358186, 0.24917988053389958, 0.05181756841817072, 0.023110899342490093, 0.02168638801335224, 0.037456435816628594, 0.06520156309540782, 0.04136347098808203, 0.06230954506567546, 0.054891250628445826, 0.0217144471327109, 0.024061759301860417, 0.019656637018280368, 0.24117862273539814, 0.11406983834292207, 0.13215772275413784, 0.1103062963645373, 0.11486932901399476, 0.20980260707437992, 0.10829785985073873, 0.08440050110220909, 0.1692199975784336, 0.20559119805693626, 0.169565494039229, 0.17026959625738008, 0.09883355841572795, 0.12436820859355585, 0.10301075569753136, 0.09574280426438365, 0.8098815392170633, 56.773591722760884, 64.25361933026994, 56.9132296698434, 53.174876485552105, 37.544514656066895, 33.194751262664795, 87.41815607888358, 36.00933449608939, 8.641979200499398, 34.29933418546404, 70.39966229030064, 70.66695949009487, 66.085435458592, 62.023553303309846, 60.32057067326137, 63.71734346662249, 15.409489018576485, 0.5454352721571922, 2.5673971601894925, 1.0087214495454515, 0.5778280996850559, 7.361335005078997, 37.83891330446516, 54.991416999271934, 69.48964977264404, 64.89429882594517, 62.82256834847586, 52.96059056690761, 51.38886635644095, 49.724651200430735, 50.65058551515852, 49.57184294291905, 48.63898127419608, 48.700688225882395, 48.09098379952567, 49.26862703050886, 46.480373995644705, 46.5635404586792, 47.22936201095581, 48.89466456004551, 50.10165350777762, 44.33499608721052, 46.655135086604524, 44.935667855399, 44.091145583561485, 44.168812547411235, 42.12807103565761, 43.63301610946655, 43.722474166325156, 47.95229775565011, 46.422801222120015, 43.42982298987252, 43.7674046925136, 40.55194166728428, 38.90542704718453, 40.213567870003835, 40.84009041104998, 41.890112604413716, 41.688687801361084, 40.18336405072893, 39.774441719055176, 41.633300236293245, 40.71348033632551, 43.45799446105957, 43.93800381251744, 48.107576097760884, 44.08809185028076, 48.333222321101594, 46.20218549455915, 51.66625581468855, 53.883248805999756, 52.274532386234824, 51.49897793361119, 54.993254797799246, 55.86129672186715, 50.766088894435335, 50.44798994064331, 45.77820989063808, 43.15705408368792, 44.99560996464321, 43.218476159232004, 42.10665668760027, 43.22849546160017, 47.97947563443865, 46.21934754507882, 45.52914128984724, 46.48587696892874, 44.0151218686785, 45.2224999155317, 41.14500863211495, 41.41322994232178, 40.6629113469805, 42.88526834760393, 43.161744117736816, 42.169249534606934, 41.83803585597447, 42.14392335074288, 38.54918595722744, 41.86508171898978, 42.870246342250276, 41.5361123085022, 42.81160354614258, 41.621397972106934, 42.751994950430735, 41.53144311904907, 41.351613317217144, 43.41027423313686, 44.2066559110369, 45.44021824428013, 46.758750098092214, 46.15789072854178, 49.57696376528059, 51.161997250148225, 50.572341850825715, 53.201185839516775, 56.06495189666748, 57.400291442871094, 53.46164601189749, 54.87352691377912, 55.022263526916504, 53.22811010905674, 42.3697259085519, 23.28812609400068, 6.765116597924914, 1.0294763701302665, 0.7261955897722925, 1.5801020009177071, 1.63174426981381, 2.85014454807554, 25.329612800053187, 61.33369445800781, 55.27249247687203, 55.16779702050345, 53.076031412397114, 50.84742450714111, 64.44532707759312, 31.677573885236466, 10.58353430884225, 32.86421850749424, 70.74796158926827, 44.0427895954677, 27.809318917138235, 46.00220591681344, 45.08646808351789, 47.236285890851704, 50.101504121507915, 59.559867995125906, 1.034314053399222, 0.46482319491250174, 0.07437712752393313, 0.2685577821518694, 0.11811417846807412, 0.14234028064778873, 0.13755582166569574, 0.11878462534930025, 0.1513766979000398, 0.15939250348934106, 0.10964498935001236, 0.11025577943239893], [0.042777751705476215, 0.04996622972456472, 0.03217751140307103, 0.017209631091515933, 0.010447088163346052, 0.042244151766811094, 0.03501061562980924, 0.02301135316624173, 0.011789150702367936, 0.018591722107625434, 0.07309107974703823, 0.043617591461432834, 0.03370854764112404, 0.07648450122880084, 0.06984115485101938, 0.04743740434891411, 0.2904980762728623, 9.541718806539263, 49.75079379762922, 40.32531574794224, 30.804668222154888, 31.479779515947612, 21.710843324661255, 51.03548445020403, 74.76585469927106, 13.778038093021937, 14.622169528688703, 56.26821102414812, 57.47483171735491, 60.32315540313721, 58.237129007067, 52.68561560767037, 52.33271312713623, 18.749894550868444, 0.47825558270726887, 1.6028761331524168, 0.7731319197586605, 0.12283196459923472, 2.6721883714199066, 29.441198893955775, 52.450627531324116, 65.13447025844029, 59.554017611912315, 59.63851465497698, 48.83517755780901, 47.34418099267142, 46.87502472741263, 47.676999705178396, 44.485664299556184, 43.58527503694807, 42.971141133989605, 43.95705229895455, 44.346266065325054, 41.76870673043387, 40.753126757485525, 42.99847534724644, 41.34282732009888, 44.061330863407676, 40.93170935767037, 41.018450668879915, 40.89530427115304, 41.671470165252686, 38.67813410077776, 40.4300320489066, 41.39323650087629, 44.22403335571289, 44.11807680130005, 44.62525013514927, 43.48908070155552, 40.36120319366455, 39.5200959614345, 38.91019698551723, 39.105816568647114, 38.67513942718506, 40.83540732519967, 38.59659351621355, 38.36136225291661, 36.53336068562099, 37.49056536810738, 37.74283014025007, 39.590811252593994, 42.5427325793675, 44.4323160307748, 45.279652323041645, 43.35368462971279, 45.38819708142962, 46.867906297956196, 46.91933338982718, 49.7355876650129, 48.83041456767491, 47.33961950029646, 50.048947947365896, 48.86961283002581, 47.99353878838675, 43.04015064239502, 39.19318669182913, 37.784644399370464, 37.545782702309744, 38.307972294943674, 37.477429798671174, 38.762113503047395, 38.69583811078753, 39.5145617212568, 37.28802537918091, 36.996652671269004, 35.17506776537214, 34.53623996462141, 36.02512427738735, 38.50082996913365, 41.43623195375715, 40.626085894448416, 41.48499093736921, 40.4882162639073, 38.9958370072501, 38.87390307017735, 38.33391686848232, 38.24877364294869, 37.68342651639666, 36.277246611458914, 35.04348278045654, 37.09868696757725, 36.1117057800293, 38.26132903780256, 37.318361214229036, 38.24598741531372, 39.21707112448556, 39.01661212103707, 39.4825895854405, 40.773116724831716, 43.482948916299, 45.389558928353445, 48.40515007291521, 51.32443223680769, 51.50655147007534, 52.45395919254848, 52.314022472926546, 52.73909936632429, 53.00006675720215, 51.96511173248291, 38.567140102386475, 18.12354745183672, 1.477026017648833, 0.17704862249749048, 0.33252384832927157, 0.14340085802333696, 2.8120306389672414, 24.104621069771902, 47.72342756816319, 47.241173948560444, 53.2774840082441, 55.10693427494594, 53.25113991328648, 51.76446165357317, 23.04676478249686, 15.175654343196324, 40.848740918295725, 45.30913700376238, 25.753348691122874, 29.24682651247297, 32.73794194630214, 47.64835575648716, 37.4161571093968, 50.49258695329939, 24.769356966018677, 0.17191996984183788, 0.17097700972642216, 0.03574636811390519, 0.06842349842190742, 0.05925162522388356, 0.03811766479962638, 0.017411741228508096, 0.050292102952620814, 0.038084691390395164, 0.039512658159115484, 0.019652874541601965, 0.07218228386981146, 0.061372739262878895, 0.029696641489863396, 0.05122560089720147, 0.02762469070564423, 0.012211375054903328, 0.0884948085461344, 0.012452226996953999, 0.04329358759735312, 0.036793435857232125, 0.012932198072251464, 0.09701855187969548, 0.029945521349353448, 0.028014607461435453, 0.021191062538751533, 0.01966092875227332, 0.09352886663483721, 0.2613672651350498, 7.87932060446058, 60.93351296016148, 41.002646991184776, 31.92940786906651, 40.00156096049717, 23.21795449938093, 54.426795959472656, 67.58654512677873, 14.204762578010559, 16.82553710256304, 58.919883319309776, 63.18729318891253, 62.35721274784633, 63.06881945473807, 58.90525041307722, 56.96801274163382, 21.673628773008073, 0.353979939860957, 1.4061350673437119, 0.628116175532341, 0.09606586157211236, 2.9178664684295654, 31.195591245378765, 55.62212930406843, 65.53853579929897, 60.02757903507778, 59.76107392992292, 50.839965615953716, 48.87824249267578, 46.412990365709575, 49.65202862875802, 44.4158661706107, 46.998469897678916, 43.822333676474436, 45.41414165496826, 45.23394707271031, 41.859575271606445, 43.32920612607683, 43.9049824987139, 43.0053471156529, 44.7644225529262, 43.84868124553135, 41.18265397208077, 41.556098801749094, 42.80306421007429, 41.10090146745954, 41.48087412970406, 41.70841026306152, 44.27764565604073, 46.20266144616263, 45.66269261496407, 44.454762186322895, 41.28924281256539, 41.26977048601423, 39.20615897859846, 39.32508781978062, 39.460073947906494, 40.27970429829189, 39.91566038131714, 40.352684702192036, 36.894371713910786, 38.09851884841919, 39.16030781609671, 40.5773720741272, 44.260601724897114, 46.39520297731672, 44.95559876305716, 46.10670682362148, 47.26160512651716, 50.953096185411724, 50.00446557998657, 54.07340710503714, 51.02765383039202, 50.76369524002075, 52.39981882912772, 50.47239201409476, 48.74103988919939, 43.61809485299246, 41.267175333840505, 40.409243038722444, 39.97055809838431, 40.66592339106968, 40.325565883091514, 42.04511301858084, 41.78601121902466, 42.026276452200754, 40.26592602048601, 40.23529141289847, 38.215001923697336, 38.08326060431344, 38.104209423065186, 39.478226116725374, 41.649979387010845, 39.59231553758894, 42.11313240868704, 40.97179351534162, 38.13293327604021, 38.67135960715157, 38.27152899333409, 39.56526967457363, 39.66758189882551, 39.815696648189, 36.896650723048616, 39.74287257875715, 40.04223224094936, 40.52978386197771, 38.47885629108974, 40.70420101710728, 41.76949535097395, 42.885150228227886, 42.97020660127912, 44.98619862965175, 45.42954233714512, 47.667970521109446, 51.210249015263145, 53.60574817657471, 54.2549809047154, 54.72286217553275, 54.986136368342805, 52.930511815207346, 53.413894517081125, 53.72211313247681, 41.53726918356759, 20.392083917345317, 2.524281850882939, 0.03758999525702425, 0.3768165787415845, 0.18813087711376802, 3.0815334575516835, 26.713728700365337, 52.24390125274658, 51.41064201082502, 56.91342074530465, 57.352776186806814, 54.365283557346885, 54.810732569013325, 25.374935899462017, 19.51824024745396, 36.455335889543804, 46.84512315477644, 33.24060589926583, 24.250236204692296, 44.22089624404907, 48.243305683135986, 38.9295095035008, 58.53817013331822, 25.740055050168717, 0.25720054443393436, 0.13876471322562012, 0.06054604612290859, 0.11465934956712381, 0.03742163375552211, 0.03338012990674802, 0.0232981037614601, 0.030495803071452037, 0.031059580855071545, 0.013081998248318476, 0.040975087721432955, 0.08469216259462492, 0.15687925049236842, 0.17646211039807114, 0.1511714139154979, 0.15147295487778528, 0.07073416800371238, 0.20827944523521832, 0.09129160775669984, 0.10404940960662705, 0.10622099308030945, 0.13266069362206118, 0.31439656817487305, 0.14088930136391095, 0.1255791357585362, 0.2616654134222439, 0.13332504725881986, 0.38296413315193994, 0.5091428224529538, 22.223186118262156, 72.04485675266811, 52.39459030968802, 47.69545759473528, 47.56362247467041, 30.98820836203439, 61.060345377240864, 83.85022136143276, 18.121131215776714, 20.807568822588237, 65.65808650425502, 65.88600131443569, 67.86247198922294, 68.39830316816057, 63.61269664764404, 63.689015660967144, 25.067434685570852, 0.7630410183753286, 4.830682958875384, 2.4708191539560045, 1.0047607592173984, 4.628916391304561, 37.34326703207833, 58.0469012260437, 67.9054674421038, 63.07735879080636, 64.52473109109062, 52.467150347573416, 51.51560844693865, 51.0635586466108, 53.03824363436018, 48.69635949816023, 50.75271361214774, 46.42970773151943, 48.76556703022548, 48.65096344266619, 44.559044224875315, 45.90667860848563, 46.909998485020225, 43.52746255057198, 47.595799582345144, 43.74599381855556, 43.7632531438555, 45.07745279584612, 45.65624816077096, 42.63478578839983, 43.432640484401155, 44.54757969720023, 47.04641941615513, 47.191119125911165, 48.53686012540545, 45.86245679855347, 43.83218969617571, 43.57821914127895, 41.797781467437744, 42.443098885672434, 41.701413427080425, 46.14971964699881, 41.499689851488384, 42.03957877840315, 37.609264918736045, 41.29019818987165, 42.51093067441668, 42.555218492235454, 46.96267972673689, 48.432532923562185, 48.208060945783345, 48.73133325576782, 50.42961195537022, 53.720789500645225, 51.15611560004098, 56.49176583971296, 51.90991871697562, 53.20735583986555, 54.78302315303257, 54.937241894858225, 52.44616331372942, 48.42649493898664, 43.85205112184797, 42.19053186689104, 42.001349789755686, 43.405962875911165, 41.76786947250366, 45.30913005556379, 44.972976207733154, 46.52617999485561, 42.30904381615775, 44.01546580450875, 39.536486761910574, 39.07047455651419, 40.76479973111834, 41.593195234026226, 44.33532265254429, 41.69708122525896, 44.58497837611607, 42.65151357650757, 40.566883768354145, 41.29261268888201, 41.107606479099815, 41.862979888916016, 40.9412179674421, 40.63658114842006, 38.654958384377615, 41.476924078805105, 41.75066920689174, 44.03433016368321, 40.82291099003383, 43.19274697984968, 43.46670055389404, 43.90662922177996, 44.49814326422555, 46.68680844988142, 48.711871351514546, 51.45525639397757, 54.48606756755284, 55.718750953674316, 56.315917355673655, 58.76280539376395, 57.51016330718994, 56.0502564566476, 58.00182826178414, 56.60589000156948, 44.89573655809675, 21.80068700654166, 2.7310176832335333, 0.3757415621408394, 0.9967898726463318, 0.6927555384380477, 4.309711371149335, 31.80677911213466, 57.1680965423584, 55.757751192365376, 61.927682059151785, 63.20665781838553, 61.83292252676827, 58.66633660452706, 30.541713646480016, 20.349885770252772, 47.290808405194966, 54.457329818180625, 31.765166350773402, 39.527085849217, 47.758943285260884, 53.50672245025635, 48.170363494328086, 62.115728105817524, 43.16278287342617, 0.36443260897483143, 0.21175448090902396, 0.11986787936517171, 0.1962572703404086, 0.13870399791215146, 0.12085035736007349, 0.12145755120686122, 0.09960613838796105, 0.17099431236939772, 0.22201595242534364, 0.12408136469977242, 0.20836544276348182], [0.0625032057453479, 0.0644500855622547, 0.026813507179862688, 0.009191473530206298, 0.022656192670443227, 0.07380538713186979, 0.08638095483183861, 0.06983468841229167, 0.02908784630043166, 0.04084501934370824, 0.028609981228198324, 0.03732156001829675, 0.026068740358043994, 0.09312581683376006, 0.023675728855388503, 0.09085908239441258, 0.02378993308437722, 0.5393954962491989, 40.512420313698904, 43.27676807131086, 27.04119382585798, 39.03193637302944, 27.66352312905448, 34.983731746673584, 70.98235212053571, 26.702448299952916, 9.729063953672137, 48.22749853134155, 59.621026039123535, 58.96620001111712, 56.809117862156455, 56.54595831462315, 55.51892076219831, 33.95639542170933, 1.7018178296940667, 0.48068978637456894, 0.5043570335422243, 0.053103310854307244, 1.3675857016018458, 30.014189038957866, 59.376178468976704, 62.50704370226179, 63.07408618927002, 57.85027068001883, 50.437393937792095, 44.30678987503052, 43.91885110310146, 46.06397540228707, 46.73949316569737, 44.79198605673653, 43.3805706841605, 41.2871653011867, 41.66143696648734, 41.62739079339163, 40.896666118076865, 43.18600375311715, 41.464017799922395, 40.98811830793108, 39.58381789071219, 40.69067982264927, 38.228498799460276, 39.399523871285574, 38.16956417901175, 39.74697549002511, 41.539951188223704, 45.013425145830425, 48.48973396846226, 45.28614888872419, 43.42571313040597, 39.54354265757969, 40.32100439071655, 37.39450652258736, 37.14759186335972, 38.769506386348176, 39.595542975834434, 38.490640435900005, 38.05426924569266, 37.6101473399571, 36.892586026872905, 37.090613160814556, 40.57286269324166, 44.4012575830732, 44.25826365607125, 44.21212066922869, 44.58571835926601, 44.47791010992867, 45.79929072516305, 49.659803662981304, 51.48902811322893, 47.725765636989046, 46.965806416102815, 49.67183794294085, 50.51576961789812, 50.24056189400809, 46.94594151633126, 40.415145533425466, 38.19351461955479, 38.11240482330322, 37.26041671207973, 36.50197914668492, 37.30410351072039, 38.52539879935128, 37.617154598236084, 35.56895419529506, 36.59665182658604, 35.37431083406721, 36.56014946528843, 36.935136795043945, 37.881519658224924, 40.1752416065761, 40.939824853624614, 42.34272868292672, 42.65807267597744, 42.37952981676374, 43.47737993512835, 44.073636123112266, 44.10024772371565, 44.66816568374634, 43.762735503060476, 39.226176738739014, 36.235755443573, 34.65504721232823, 37.199123178209575, 36.760518142155235, 37.00632456370762, 36.43375825881958, 37.334762437003, 39.98500687735421, 41.686071804591585, 42.96547835213797, 45.870242255074636, 48.24136366162981, 53.26891687938145, 53.10812514168875, 54.44948877607073, 52.66026857921055, 52.200204031808035, 50.75656638826643, 53.11063691547939, 54.014809472220286, 41.4014527457101, 12.977197408676147, 0.6951436560068811, 0.12941402569413185, 0.27435198266591343, 4.431604487555368, 26.255988325391495, 45.483217171260286, 48.25099386487688, 45.88652883257185, 50.89228902544294, 55.30934919629778, 45.93841797964913, 11.709867698805672, 21.267120940344675, 66.85508046831403, 35.41175120217459, 17.20134605680193, 31.373576300484793, 27.540920427867345, 39.908281394413535, 38.16711841310774, 54.65934521811349, 5.340248644351959, 0.41516895219683647, 0.04630925167085869, 0.06277221773884126, 0.037179973508630476, 0.07500161722834621, 0.009580211331402617, 0.07874779549560376, 0.03951775734978063, 0.041797869107020755, 0.030087572655507495, 0.08519401387976748, 0.05274518685681479, 0.02062879449554852, 0.04636756157768624, 0.07718403012092624, 0.04239215721775379, 0.06004838139883109, 0.03590324201754161, 0.036128552963158915, 0.1185138491647584, 0.010828812456955867, 0.03524767540927444, 0.0644629370155079, 0.08960785024932452, 0.021461585968998925, 0.12039500607975892, 0.04226529152531709, 0.06129799863057477, 0.05151857535487839, 1.0938432876552855, 40.915575640542166, 52.866272245134624, 28.275129624775477, 43.38238068989345, 33.362831660679404, 36.67055981499808, 70.38772528512138, 29.692167827061244, 12.185325111661639, 49.157497542245046, 66.77684375217983, 63.2465752192906, 61.11283901759556, 59.2715733391898, 59.14421285901751, 36.19875281197684, 2.104814976453781, 0.5312408081122807, 0.562173102583204, 0.10823764665318386, 1.4152476297957557, 31.0466114452907, 60.02615465436663, 63.023822920663015, 63.9601274217878, 57.0688727923802, 52.17077146257673, 46.64017561503819, 46.66811779567173, 46.67228324072701, 47.89475277491978, 44.95850658416748, 45.58384098325457, 43.315702302115305, 43.09756360735212, 42.94019733156477, 42.27839878627232, 43.68335233415876, 41.26848159517561, 40.68733426502773, 41.12473031452724, 41.71916260038103, 39.45644351414272, 40.74026911599295, 37.32525382723127, 40.73702778135027, 41.994213989802766, 45.07822404588972, 46.912426880427766, 47.4342748097011, 43.246689319610596, 41.68439381463187, 40.304217542920796, 39.72518246514456, 38.833957876477925, 41.39552593231201, 40.88590683255877, 39.82085568564278, 38.94533749989101, 38.30325446810041, 39.77965981619698, 39.35901934759957, 41.86243792942592, 45.86088650567191, 45.795559542519705, 45.56358698436192, 47.02006837299892, 47.50377416610718, 48.11727230889456, 49.069609778267996, 51.346631731305806, 50.96624217714582, 48.846027169908794, 51.83596209117344, 51.53506340299334, 52.02611691611153, 46.94908905029297, 42.825055258614675, 42.502808230263845, 40.903277329036165, 39.600938252040315, 41.2393582207816, 40.52646262305123, 43.714858940669465, 42.1420647076198, 38.73134340558733, 40.48669808251517, 38.47509036745344, 38.83632721219744, 39.571252073560444, 39.51407534735543, 40.279829365866526, 43.35871512549264, 43.7323579788208, 41.94188710621425, 42.225380556924, 42.49740947995867, 44.36869832447597, 45.72976010186331, 43.22468784877232, 44.038676261901855, 41.57962540217808, 39.417387689862935, 38.799689361027305, 39.348440715244834, 38.44570296151297, 40.70209223883492, 39.98318297522408, 41.601494857243125, 42.106958934238975, 44.23852382387434, 45.605449880872456, 48.88981124332973, 51.37186411448887, 54.683775084359304, 55.241840498788015, 55.829077925000874, 54.509357929229736, 53.65355178288051, 51.185648918151855, 55.25736624853951, 53.28621094567435, 45.77672645023891, 15.851119995117188, 1.2636996018035072, 0.08620043059012719, 0.7946363772664751, 5.620080394404275, 29.63450472695487, 48.92678608213152, 52.92457805361067, 50.349638189588276, 53.87448712757656, 55.67886829376221, 50.59196703774588, 14.988454239709036, 25.68023453439985, 57.1917655808585, 43.96573059899466, 18.706152166639054, 29.90749250139509, 38.51336104529244, 35.355741773332866, 43.58537925992693, 57.807306494031636, 6.421546416623252, 0.6170725024172238, 0.055935532985521216, 0.17334429627018316, 0.10348497703671455, 0.11464466606932026, 0.05285755225590297, 0.04405270204214113, 0.09476189368537494, 0.07041801818247352, 0.07883355553661074, 0.07560675511402742, 0.05099221199218716, 0.1211303887622697, 0.205203754561288, 0.12187996639737061, 0.12645886998091424, 0.14081705095512526, 0.13293750876826899, 0.1745182704180479, 0.2994980833360127, 0.11089977701859814, 0.12381294981709548, 0.19443502383572714, 0.1798308603465557, 0.12067046415592943, 0.15506293438374996, 0.126261796270098, 0.20796545994068893, 0.13339283290718282, 2.9280974737235477, 65.0306224822998, 59.88471017565046, 41.97561713627407, 50.789507797786165, 39.782168115888325, 44.72907359259469, 81.57714598519462, 32.521505560193745, 13.721365111214773, 58.334421157836914, 72.18502971104213, 67.86320849827358, 66.11212348937988, 65.44741712297711, 64.92555182320731, 40.58685636520386, 3.1697805736746107, 2.648720396416528, 3.058338633605412, 0.2851916610130242, 3.193652195589883, 36.2329865864345, 65.2524437223162, 65.37091050829206, 67.27542563847133, 61.82981668199812, 55.48606620516096, 48.59424182346889, 48.43855701174055, 50.058755329677034, 49.60745593479702, 47.6623980658395, 47.57507310594831, 46.235922472817556, 45.288962909153526, 44.97899334771292, 44.16162116186959, 47.140355587005615, 45.55449179240635, 43.99283899579729, 43.90577111925398, 44.33328683035714, 41.11422116415841, 42.992100375039236, 40.16939122336251, 43.97623974936349, 43.75471033368792, 48.27543067932129, 51.84358426502773, 49.92624276024954, 46.968512739454, 43.22547994341169, 42.18319109507969, 41.12525142942156, 39.597405093056814, 43.86144856044224, 43.43400927952358, 42.00530331475394, 40.888244901384624, 41.484136308942524, 41.5790764944894, 41.39597061702183, 45.48676422664097, 48.952421460832866, 48.807336126055034, 49.207455090114046, 50.52695969172886, 50.75228977203369, 51.07822281973702, 53.86665998186384, 55.066461018153596, 52.234128611428396, 50.64797299248831, 56.17249958855765, 56.717683042798726, 56.9203793661935, 52.136395250047954, 46.20325551714216, 46.677793162209646, 43.986804485321045, 43.180351393563406, 42.06602709633963, 43.34947402136666, 46.40795986992972, 44.60183123179844, 40.807433877672466, 42.206603050231934, 40.18547282900129, 42.387120723724365, 41.909654412950786, 40.76831899370466, 41.548167433057515, 44.38386276790074, 45.01641981942313, 45.491030420575825, 43.919653620038716, 46.213420731680735, 47.57144267218453, 48.53502580097744, 47.597196170261924, 47.413628237588064, 42.18813821247646, 42.07913139888218, 39.27182987758091, 41.27748646054949, 40.80420296532767, 42.81144721167428, 40.91445698056902, 44.698348658425466, 45.30574280875069, 46.29529135567801, 47.58691283634731, 51.175056389399934, 51.84016922542027, 57.04853194100516, 56.10072817121233, 59.70766312735421, 55.258279936654226, 56.98957995006016, 55.981125354766846, 58.47990948813302, 55.99725907189505, 47.05827651705061, 15.361410958426339, 1.605714580842427, 0.2642231918871403, 1.2781670540571213, 7.230851309640067, 33.39217390332903, 52.67212568010603, 57.484336853027344, 52.577202865055625, 60.93226228441511, 63.88587897164481, 56.255666051592144, 17.962364877973283, 28.24782494136265, 74.29532963888985, 43.40367691857474, 20.968608958380564, 44.909751074654714, 37.80996363503592, 47.736399854932515, 48.739011015210835, 72.52005100250244, 15.150774581091744, 0.7192808293870517, 0.1680258980819157, 0.25392343742506845, 0.19439169258943625, 0.22326675030801976, 0.16207104761685642, 0.15324593974011286, 0.3046352176793984, 0.13224210536905698, 0.10513598844408989, 0.21038894275469439, 0.15175198204815388], [0.024840464748974358, 0.028276808659679124, 0.03155833123517888, 0.03992532958675708, 0.0688659507515175, 0.03452831293855395, 0.12073020237897124, 0.05402217958388584, 0.018962539798979248, 0.05344296173591699, 0.05958126432129315, 0.03189012807394777, 0.03968517229493175, 0.0482268527017108, 0.05737791183803763, 0.14549944469971315, 0.07303164686475482, 0.3952105502997126, 11.796208620071411, 50.17681564603533, 35.34455169950213, 31.248654638017925, 36.19480276107788, 20.285889387130737, 54.950026580265586, 43.971907547542024, 7.619527459144592, 36.30267701830183, 61.75623525891985, 58.030354091099326, 57.53637538637434, 55.790240968976704, 54.80424642562866, 39.52012375422886, 2.122889195169721, 0.17362062287117752, 0.23250328110797064, 0.2321739202099187, 2.7032565900257657, 31.418138572147914, 66.1819042478289, 60.34020628247942, 64.1601869038173, 58.43517698560442, 50.84209871292114, 45.56305544716971, 45.135348660605295, 46.18306057793753, 50.425887720925466, 48.0177914755685, 42.779040813446045, 42.296985217503135, 41.638650349208284, 41.437941210610525, 40.112120696476524, 40.725952352796284, 41.679658617292134, 39.18218074526106, 39.818517616816926, 39.249519211905344, 39.328506333487375, 40.44249364307949, 39.21773815155029, 38.34349496023995, 40.87231963021414, 44.24916499001639, 47.217727252415244, 45.01885863712856, 43.214762347085134, 40.60678727286202, 38.04903377805437, 36.72269214902605, 38.74918637956892, 38.27605921881539, 40.19589860098702, 38.00382532392229, 37.72759968893868, 35.985898222242085, 38.31628581455776, 38.869355474199565, 41.79291078022548, 47.9313975742885, 45.16481597082955, 46.376098905290874, 45.5578408241272, 46.188851901463096, 45.41040005002703, 48.75589166368757, 49.255331652505056, 49.162409918648855, 48.94661276681082, 49.445152963910786, 49.89397185189383, 51.70547144753592, 48.45364849908011, 44.81981011799404, 37.651944228581016, 38.03576966694423, 36.36966460091727, 36.766702038901194, 35.99528176443917, 34.82017115184239, 36.28726591382708, 35.9352319581168, 34.873300552368164, 37.19346387045724, 37.23183529717581, 36.015876225062776, 37.04021092823574, 38.567723751068115, 41.25135081154959, 42.318628856113975, 44.42917891911098, 43.267370632716585, 47.05542080742972, 47.44484996795654, 46.95634296962193, 47.44172327859061, 44.218599864414756, 40.6151042665754, 37.65925373349871, 38.11107076917376, 39.72787141799927, 38.69664062772478, 37.629202774592805, 37.389097349984304, 37.223528725760325, 37.82289770671299, 39.305591174534385, 42.410240854535786, 44.03861720221383, 48.22919389179775, 50.3034222466605, 54.30615438733782, 51.78777633394514, 52.920829500470845, 51.44856527873448, 50.01941115515572, 52.41263130732945, 54.742421354566304, 49.738860266549246, 34.52405629839216, 7.554019842829023, 0.7469799859183175, 1.7152706278221947, 6.019893637725285, 34.63664490836007, 48.636869021824424, 52.724414348602295, 50.74634211403983, 54.73974977220808, 52.59581708908081, 32.23283917563302, 10.993110639708382, 46.03832265308925, 52.001593249184744, 19.161198377609253, 25.910391875675746, 31.10194342476981, 19.663464546203613, 32.77994728088379, 48.808649335588726, 27.307222979409353, 0.07786501465099198, 0.03540387077789221, 0.04225566311340247, 0.017254029334123646, 0.05736603068986109, 0.06997952849737235, 0.01658629659297211, 0.049583461335194964, 0.015512324936155761, 0.049370455622140846, 0.049794991234583516, 0.10595580802432128, 0.04923567142603653, 0.035964618902653456, 0.039000069057302814, 0.04896325657942465, 0.028220369813165495, 0.003276534494943917, 0.05030828262014048, 0.07975444969322, 0.03339525445231369, 0.05281894700601697, 0.05367406058524336, 0.016393828438594937, 0.04399933526292443, 0.03515213767864874, 0.03234644626666393, 0.09841518050857953, 0.12597161398402282, 0.0888388529419899, 0.5834866474781717, 12.481571980885096, 61.30813898359026, 36.504296370915, 36.27332782745361, 41.294839586530415, 24.87751088823591, 59.646741322108674, 44.77311127526419, 10.086553113801138, 39.25050933020455, 69.03410502842495, 63.85453564780099, 64.71291610172817, 59.352735246930806, 59.94959940229143, 42.69769825254168, 2.3779093623161316, 0.27439630457333153, 0.20806159478213104, 0.11713856724756104, 3.8186895591872076, 32.81415673664638, 66.62480327061245, 61.419859068734304, 64.56228610447475, 60.25730732509068, 53.78164529800415, 46.52115644727434, 47.01875516346523, 49.45245204653059, 50.782907009124756, 49.32958705084664, 45.354213442121235, 44.00093017305647, 42.66487496239798, 41.34373753411429, 40.2531031199864, 42.032707009996685, 42.35689953395298, 40.934481688908164, 40.56810665130615, 40.29720333644322, 40.008415358407156, 40.570330074855256, 40.762301853724885, 38.46903501238142, 41.49255405153547, 45.935405935559956, 47.411939825330464, 46.41484553473336, 43.57022523880005, 42.81651244844709, 39.054948806762695, 39.29846232278006, 38.11259242466518, 39.760805879320415, 41.25499166761126, 39.14700548989432, 40.352458885737825, 37.897365025111604, 40.17772558757237, 41.135802268981934, 44.440799781254356, 48.260224546704976, 45.986238956451416, 46.863365650177, 45.638221059526714, 48.15781157357352, 49.664820262363975, 51.20096622194563, 52.15471764973232, 49.8674054145813, 50.54940932137625, 49.90324422291347, 51.69207532065255, 54.1373096874782, 51.12832280567714, 45.12810516357422, 42.069751330784385, 40.684551511492046, 39.060288497379844, 40.95554167883736, 40.37171581813267, 38.93736791610718, 40.64571802956717, 39.859810761043, 38.85955156598772, 40.31721067428589, 38.81085859026228, 37.24466167177473, 38.19387245178223, 39.8852515901838, 42.05420126233782, 43.615103653499055, 45.46104199545724, 44.67166757583618, 46.163973876408164, 48.19099269594465, 47.48809208188738, 47.518410546439036, 47.797575269426616, 43.91588422230312, 39.786806038447786, 41.082353251320974, 43.607043743133545, 41.86234065464565, 39.755146571568076, 39.30195379257202, 40.24251059123448, 40.390799045562744, 41.82906573159354, 45.650946685246055, 46.09560707637242, 49.576609407152446, 54.053945200783865, 55.16897126606533, 54.92399862834385, 55.93792840412685, 52.07601887839181, 51.44558450153896, 54.172530106135774, 57.759127685001914, 53.08505712236677, 37.713960375104634, 9.602251512663704, 1.3919117791312081, 2.833774592195238, 7.867256794657026, 38.33997222355434, 51.41608245032174, 55.772293772016255, 53.45064353942871, 58.7042807170323, 55.00142240524292, 35.40532411847796, 12.82074134690421, 50.618304184504915, 50.886202403477256, 25.795675379889353, 20.64362781388419, 35.33928149087088, 22.313424110412598, 27.659444536481583, 58.17384828839983, 24.655220644814626, 0.3068678421633584, 0.0898179111203977, 0.03291661245748401, 0.042020974813827446, 0.036463752655046325, 0.04397197673097253, 0.04655714426189661, 0.0371276991707938, 0.031328633560666015, 0.09613621208284583, 0.06282025123281137, 0.10955876111984253, 0.03425978270492383, 0.1757614958499159, 0.14768553525209427, 0.08147026798022644, 0.12272742949426174, 0.21023870153086527, 0.12977899610996246, 0.28238841571978157, 0.20826674305966922, 0.12425296620598861, 0.07523059565573931, 0.18689109863979475, 0.09128194541803428, 0.1402610729315451, 0.10826586692460946, 0.2307788793529783, 0.22169372971568788, 0.2887255528143474, 0.6337868283901895, 29.1103013583592, 70.70806503295898, 48.90665020261492, 47.793441091264995, 50.037163802555625, 29.35897043773106, 66.28948320661272, 51.66040195737566, 11.965402466910225, 44.17655284064156, 74.4341824395316, 69.38731670379639, 68.45484066009521, 62.972920417785645, 65.21276950836182, 47.46992949077061, 3.736220521586282, 1.2466627274240767, 1.0462035068443842, 0.7324774669749397, 5.918333121708461, 37.773808683667866, 69.63074684143066, 63.38103675842285, 67.99418204171317, 65.09847858973912, 56.08262463978359, 50.47280543191092, 49.63455043520246, 50.44419622421265, 56.944906507219585, 53.132989270346506, 47.90768337249756, 46.40912021909441, 45.107760838099885, 45.509644644601, 43.069208008902415, 43.40302031380789, 46.224308558872764, 42.06727082388741, 44.047893047332764, 42.63262837273734, 42.479330267224995, 42.505253996167866, 43.85897500174386, 40.17430359976632, 44.805090359279085, 49.679578236171174, 50.909253052302766, 47.779867785317556, 45.901668957301546, 44.93194709505354, 40.492604051317485, 40.185260908944265, 42.77993713106428, 42.386957441057476, 43.08444193431309, 41.6106595311846, 43.76053639820644, 38.16110127312796, 41.81058699744088, 43.494031293051584, 45.4820568220956, 53.81704289572579, 49.177518776484895, 49.63855259759085, 50.52253368922642, 51.133770193372456, 52.618176392146516, 54.73139803750174, 55.83942379270281, 51.47350583757673, 51.86606863566807, 53.10748243331909, 57.44188683373587, 59.08777959006173, 52.98225505011422, 49.27716636657715, 44.85130630220686, 43.49620607921055, 40.81215517861502, 43.411299092429026, 41.258507456098286, 41.25013140269688, 43.028053828648154, 41.811716079711914, 39.32704026358468, 41.77503306525094, 41.59551593235561, 39.78384263174874, 40.74069990430559, 41.825695855276926, 44.89303023474557, 45.36179740088326, 46.94784532274519, 45.524291447230745, 48.107815810612266, 51.545378003801616, 50.928332805633545, 50.25020946775164, 48.97360304423741, 45.17873321260725, 42.84739024298531, 43.941887855529785, 45.19051388331822, 43.65666082927159, 43.08641174861363, 41.88936914716448, 43.44320522035871, 42.1642815726144, 44.39474712099348, 47.57033790860857, 48.65183196749006, 51.749783584049766, 57.805906432015554, 56.7355294908796, 57.31403303146362, 58.270758288247244, 55.39931099755423, 55.48822709492275, 56.56415912083217, 61.539715494428364, 54.821752411978586, 38.74846376691546, 12.103722861834935, 1.9940767586231232, 3.8789517198290144, 11.388419713292803, 41.018613951546804, 55.944216523851665, 61.31309999738421, 59.19598388671875, 61.575165203639436, 61.59213965279715, 40.490717615400044, 14.567139795848302, 53.86008698599679, 59.85480512891497, 25.584226063319615, 33.91922950744629, 45.022110394069124, 26.96778437069484, 44.92142404828753, 60.78878893171038, 46.6310248374939, 1.0084004210574287, 0.20528683438897133, 0.13758858133639607, 0.12281996810010501, 0.2216329194073166, 0.14497235869722708, 0.12465586672936167, 0.1483960971236229, 0.1679209287145308, 0.09359753437872444, 0.193724624812603, 0.1764006351253816, 0.1652829066983291], [0.028915135389459983, 0.04490264857720051, 0.007382502563164702, 0.039348126987793615, 0.014761700660788586, 0.02042481329824243, 0.04096961194383247, 0.08657472407711403, 0.027568406225847344, 0.044606535895062346, 0.030600117652543952, 0.013911278303047376, 0.04544199910014868, 0.029183092260999337, 0.06725282195423331, 0.046418210824153254, 0.1679814268967935, 0.22105688388858521, 2.122290998697281, 44.77649852207729, 37.85206971849714, 25.74146727153233, 40.67639085224697, 21.183827672685894, 35.5403276171003, 70.81283691951207, 18.833931275776454, 29.026830911636353, 63.59447152273995, 57.76108707700457, 51.406535625457764, 55.55445384979248, 54.87184544972011, 38.22065428325108, 3.0522674279553548, 0.19660207469548496, 0.36858413049152916, 0.07921095671398298, 2.6069089600018094, 33.63187633241926, 71.08713095528739, 62.10707759857178, 63.78987571171352, 58.55064214978899, 53.011451380593435, 44.38238280160086, 47.2012391771589, 51.31323521477835, 50.95567396708897, 52.91546549115862, 48.081593309129985, 43.51813806806292, 41.61754172188895, 40.62840659277779, 40.5855153628758, 39.79062754767281, 40.268489905766074, 39.298868792397634, 39.986643178122385, 41.161187512534006, 42.43978112084525, 38.9451881136213, 38.586991105760845, 38.54969317572457, 42.499636377607075, 47.402573653629844, 48.033820969717844, 47.781583990369526, 45.78961188452584, 42.09990998676845, 38.2300934110369, 40.328209672655376, 38.77757671901158, 39.245576109204976, 39.82675470624651, 39.18298326219831, 38.955415861947195, 38.734845297677175, 37.856009347098215, 37.9427923474993, 41.616329261234824, 46.11382177897862, 46.73410483769008, 44.69882113592965, 44.3043406350272, 46.517856052943635, 48.559695380074636, 52.25367736816406, 51.74841826302664, 51.04064348765782, 49.53296777180263, 50.61901290076119, 51.00356789997646, 48.44555732182094, 49.19532353537423, 46.46964250292097, 39.58770540782383, 37.21167857306344, 37.5458973475865, 37.55074719020298, 37.41667127609253, 37.44174385070801, 35.68695892606463, 36.765409673963276, 37.205039569309776, 36.42562886646816, 36.637635775974815, 36.868531363351, 37.26352950504848, 38.54301595687866, 42.44698987688337, 44.63172238213675, 47.650937012263704, 48.50213997704642, 47.0977839742388, 47.03200190407889, 50.079929964882986, 45.01543664932251, 47.749750818525044, 44.793618883405415, 40.96595008032662, 38.76771722521101, 38.09593064444405, 37.25688007899693, 35.85932983670916, 36.342702116285054, 34.31899411337716, 36.76366915021624, 39.92973395756313, 42.186880588531494, 42.49114220482962, 47.05762338638306, 49.73299598693848, 52.253052030290874, 50.4637519291469, 51.094624042510986, 45.98568657466343, 49.881103788103374, 51.488454886845176, 54.27498129435948, 54.10197114944458, 46.11650378363473, 14.831148760659353, 0.7483853133661407, 2.5756718133177077, 7.239975162914821, 33.41743407930647, 52.2869279725211, 49.61623150961739, 51.945229462214876, 49.76357500893729, 45.694525786808555, 14.565414037023272, 18.495521000453405, 29.3391889163426, 43.828111103602815, 22.398633343832834, 26.26239456449236, 26.42825848715646, 25.648555959974015, 33.81918934413365, 46.812035833086284, 7.129685972418104, 0.6018650670136724, 0.1503608495529209, 0.1176648661494255, 0.07108830221529518, 0.1128630909536566, 0.027025425540549413, 0.0372703272317137, 0.04266048728355339, 0.10318119012351547, 0.026894159548516785, 0.008906337848332311, 0.04332280870793121, 0.036603045716349564, 0.02046699612401426, 0.00892525286014591, 0.07598573727799313, 0.05230156405429755, 0.024421204746301686, 0.019416949611955454, 0.0650143213570118, 0.005658819207123348, 0.05795053432562521, 0.038408871673579724, 0.05750168341078928, 0.06426004825958184, 0.04232049374175923, 0.015387915540486574, 0.06636278757027217, 0.005422539318845208, 0.14475794163133415, 0.07715357068393912, 1.9262823164463043, 51.35675525665283, 42.79784263883318, 28.24653605052403, 45.440468379429404, 28.111331054142543, 39.09128441129412, 70.33527333395821, 20.494785240718297, 32.82687194006783, 67.61450467790876, 63.827764238630024, 55.10285220827375, 61.587102208818706, 59.68199648175921, 44.496315887996126, 3.115477578980582, 0.24198811501264572, 0.8198416733316013, 0.1851366242127759, 3.4196078308991025, 35.873681340898784, 69.31381865910122, 62.670903069632395, 65.44555500575474, 59.96628897530692, 53.74677576337542, 44.69856057848249, 47.7591586794172, 53.26431369781494, 54.245069299425396, 53.619776589529856, 49.111938204084126, 44.37567431586129, 42.17182731628418, 42.18353850500924, 41.778486319950645, 40.90196759360177, 40.718670640672954, 39.858487129211426, 41.10285043716431, 43.31683138438633, 41.2840907233102, 38.77631909506661, 38.156386920383994, 40.05286645889282, 43.07708379200527, 48.37522765568325, 48.90757431302752, 49.698341846466064, 47.25689772197178, 41.95678056989397, 40.18266575677054, 41.21682521275112, 39.326189109257285, 38.49085235595703, 39.747687680380686, 40.1031470979963, 40.025549616132466, 38.20338453565325, 39.46325969696045, 40.35665907178606, 41.70449842725481, 46.04943977083479, 47.54311834062849, 46.75209719794137, 45.842852456229075, 48.16391209193638, 49.25106198447091, 52.38503653662545, 51.96950299399239, 49.99265364238194, 51.01471628461565, 51.35881192343575, 51.20243229184832, 51.80146428516933, 51.80483068738665, 50.119965485164094, 42.25484439304897, 41.62459761755807, 40.64465842928205, 39.84845045634678, 38.91147197995867, 39.94152505057198, 38.74951989310128, 40.04597731998989, 41.619143281664165, 39.59493153435843, 38.77959517070225, 39.778127738407676, 39.36995581218174, 40.17023195539202, 44.05102321079799, 46.638164111546104, 47.270860127040315, 46.82734271458217, 47.799659729003906, 48.73792362213135, 47.800292015075684, 45.56266287394932, 47.99151686259678, 47.39293997628348, 42.24080555779593, 40.70433303288051, 40.06068665640694, 39.05810676302229, 37.91008717673165, 39.43363952636719, 36.82119676045009, 40.13651234763009, 42.165452344076975, 45.41915478025164, 44.16629382542202, 48.591525077819824, 53.01303904397147, 55.104165417807444, 52.51986633028303, 53.14194549833025, 49.104955264500205, 52.05108526774815, 53.37466498783657, 55.49070760181972, 56.82406691142491, 48.93915734972273, 17.10570584024702, 0.8785981919084276, 3.0727930579866682, 10.568777203559875, 36.045982769557405, 54.77178791591099, 52.93266575677054, 54.832949434007915, 53.401835918426514, 49.0354037966047, 15.464984280722481, 21.658165557043894, 28.05901632990156, 51.05777079718453, 21.327917678015574, 22.22313574382237, 34.8792655808585, 22.1949052129473, 37.303919383457725, 51.7164044380188, 7.8476550579071045, 0.6894579668130193, 0.14159649770174706, 0.13788689247199468, 0.07107235664235693, 0.05356687240834747, 0.0024367869773413986, 0.042460523013557704, 0.015741223635684167, 0.07053001038730145, 0.038464827063892565, 0.04571636473493917, 0.03986446499558432, 0.05790547960038696, 0.10920386016368866, 0.18031974482749188, 0.22400625848344394, 0.13196172112865107, 0.10349808633327484, 0.1288839541375637, 0.21271619573235512, 0.16907840089074203, 0.13392351514526776, 0.1556485779583454, 0.1411176555390869, 0.13084078127784388, 0.20905578429145472, 0.13267183516706738, 0.24938330533249037, 0.13026934622653893, 0.25498195205415997, 0.4394335815949099, 7.695291485105242, 71.30451924460274, 51.71606050218855, 40.18566737856184, 54.1861902645656, 32.83022097178868, 45.70321103504726, 80.77049486977714, 23.553601128714426, 36.83506883893694, 73.66215419769287, 66.10337570735386, 60.92941352299282, 65.17093440464565, 64.4923872266497, 48.25345005307879, 4.977720737457275, 0.6659071019717625, 2.1989489538328986, 0.299918530774968, 5.216912039688655, 39.91298532485962, 71.67872837611607, 65.11668287004743, 69.97675323486328, 62.320032937186106, 57.513262203761506, 47.79035261699131, 51.934449332101, 57.108084951128276, 56.84624208722796, 57.13262946265084, 53.26160390036446, 48.55937576293945, 45.77995388848441, 44.8542697089059, 43.9501770564488, 42.69405044828142, 42.871170452662874, 42.835963930402485, 44.64550065994263, 46.595992020198274, 44.45798962456839, 41.019437313079834, 40.59679923738752, 41.06718533379691, 45.07959631511143, 52.801924977983745, 52.716097354888916, 51.482323101588655, 50.05367619650704, 45.75424902779715, 42.55000386919294, 44.84245082310268, 42.72635262353079, 41.90082672664097, 42.13434178488595, 43.04663678577968, 42.21073375429426, 41.162076881953645, 42.946085929870605, 43.17452185494559, 45.252081871032715, 50.03524957384382, 51.87515687942505, 49.62724787848336, 49.542240142822266, 52.764700004032676, 53.245973927634104, 57.06883805138724, 56.846068382263184, 53.66237252099173, 54.78721639088222, 55.74024173191616, 54.83120196206229, 54.530692373003276, 54.14676965985979, 54.200392382485525, 44.201802594321116, 45.105481828962056, 43.476768493652344, 43.55814926964896, 41.33286360331944, 41.87297487258911, 39.788393701825825, 41.59010328565325, 44.546447140829905, 42.19247041429792, 40.491704259599956, 43.455340249197825, 41.285730498177664, 42.422400202069966, 46.95932027271816, 48.142390046800884, 49.45938982282366, 50.50840105329241, 50.75930745261056, 51.01168687002999, 50.856814997536794, 47.598245348249165, 49.38479743685041, 48.67551142828805, 45.3137332371303, 41.75691563742501, 40.8572872025626, 41.35173143659319, 39.672087805611746, 43.33854797908238, 40.08742332458496, 42.805169514247346, 43.28592927115304, 48.455677373068674, 45.10050344467163, 51.73583160127912, 54.25450842721121, 57.759284019470215, 55.2156423160008, 56.00179277147566, 50.28408540998186, 56.04593815122332, 57.27497373308454, 58.97484357016427, 59.55337837764195, 53.408130986349924, 17.88730001449585, 2.129539272614888, 5.7961907386779785, 12.23653507232666, 41.842611244746614, 61.650719915117534, 57.245878151484895, 60.884667124067036, 59.04636137826102, 54.732697350638254, 20.14485832623073, 24.856541224888392, 35.79109157834734, 54.5241436958313, 27.05138509614127, 38.92684486934117, 37.36244753428868, 37.6385098866054, 45.48613541466849, 65.23624747140067, 16.10577494757516, 1.2059882985694068, 0.3568230830132961, 0.3502299482268946, 0.1951851307281426, 0.3009587792413575, 0.17152472319347517, 0.11545149848929473, 0.15145464800298214, 0.26935560362679617, 0.17233380834971154, 0.14828677156141826, 0.18280289801103727, 0.20170457661151886], [0.04989697504788637, 0.026912949879520705, 0.0967136114569647, 0.06167549480284963, 0.03657656249457172, 0.01481837360188365, 0.04817520261609128, 0.04986365219312055, 0.021191439125686884, 0.06334458238312177, 0.12118111604026385, 0.05867676357073443, 0.06170579817678247, 0.020688924572563598, 0.05241282004863024, 0.04828038911468216, 0.12939559668302536, 0.04750457592308521, 0.4753905364445278, 25.625781502042496, 47.50611570903233, 30.678283963884624, 33.35674156461443, 31.842069012778147, 16.466042518615723, 54.97350801740374, 31.47813974108015, 22.629454238074167, 52.49982425144741, 64.04590293339321, 59.3141519001552, 52.0127729007176, 56.972320624760215, 38.189015660967144, 3.419308189834867, 0.1193066087684461, 0.2351074442267418, 0.13079993346972124, 5.874122168336596, 37.62817791530064, 67.51447146279472, 61.4554477419172, 63.006209237234934, 59.90668037959507, 55.63920102800642, 45.000921862465994, 49.455151421683176, 55.73690659659249, 56.96531684058053, 54.32313231059483, 54.483871936798096, 48.14473853792463, 40.799724851335796, 39.8513582774571, 39.96009758540562, 40.61827959333147, 40.64317498888288, 42.91992596217564, 42.947548525674, 47.73499631881714, 48.150015694754465, 47.82238728659493, 44.2314818246024, 43.47176579066685, 45.63295432499477, 47.13288279942104, 48.39612436294556, 50.87015206473214, 46.527041571480886, 42.368888650621685, 39.38307053702218, 37.1210914339338, 39.56017664500645, 38.31061608450753, 37.59748772212437, 38.6530511038644, 38.211843967437744, 37.34577185767037, 38.990469523838584, 39.174040930611746, 43.326360838753835, 45.85273626872471, 46.167604310171946, 45.99545921598162, 45.62041630063738, 46.3837627683367, 49.490205083574565, 52.02695417404175, 52.21262741088867, 50.85721104485648, 49.480189255305696, 50.589972904750276, 49.778871468135286, 50.168658460889546, 50.47184310640608, 48.265640667506624, 41.271340778895784, 36.33943993704659, 37.60458878108433, 37.04421656472342, 38.67866563796997, 35.199320452553884, 35.23976591655186, 36.10380220413208, 38.62618241991316, 36.94735172816685, 37.507213251931326, 38.23397397994995, 38.42797463280814, 39.3660682950701, 41.53829056876046, 45.592422008514404, 48.073609828948975, 46.281394958496094, 48.82168763024466, 50.04982689448765, 47.82677159990583, 46.22761937550136, 48.70961318697248, 44.759367738451274, 39.54094403130667, 36.65962682451521, 37.139021260397776, 40.935093130384175, 41.92841454914638, 39.5128698348999, 40.1124472618103, 39.09152412414551, 40.4254149709429, 41.32088838304792, 42.96046870095389, 42.04992812020438, 43.72553137370518, 44.437610558101106, 45.55402626310076, 44.52363967895508, 47.390733923230854, 46.418281418936594, 52.420482771737234, 53.653517041887554, 56.03722163609096, 46.64834669658116, 23.067195960453578, 1.3670855398688997, 0.08583772648125887, 13.548711930002485, 42.206783703395296, 51.44631406239101, 52.21779339654105, 50.24646438871111, 57.537247385297505, 42.680744647979736, 36.7652324948992, 50.46645825249808, 51.33768245152065, 39.705814361572266, 19.391734395708355, 31.88448429107666, 25.034265722547257, 29.35003158024379, 41.4503367968968, 21.017463479723247, 0.5222384397472654, 0.1352861084576164, 0.02431410308262067, 0.11290064786693879, 0.038462547186229906, 0.06191656472427504, 0.02803236641921103, 0.019251856952905655, 0.04230508760416082, 0.041521328767495494, 0.0726587443745562, 0.02539832061821861, 0.018296842662883655, 0.07193678990006447, 0.02763671604251223, 0.012493923822018718, 0.05933722920183625, 0.05691953089886478, 0.0538214349986187, 0.06561902498028108, 0.078888544014522, 0.036651615252984424, 0.03692978407655444, 0.05437863438523241, 0.13026804343930312, 0.03046696533315948, 0.04039905220270157, 0.02077668798821313, 0.05798967222550085, 0.10245017042117459, 0.17984839369143757, 0.03422096710918205, 0.44467724593622343, 28.911204201834543, 54.71882874625069, 30.874313490731375, 40.092769963400706, 38.26217671803066, 19.878638097218104, 59.21942016056606, 30.638845988682338, 26.831141097205027, 55.20320156642369, 71.69078350067139, 60.22020394461495, 57.69766739436558, 61.620759282793315, 41.55559158325195, 3.8653849278177534, 0.04580640633191381, 0.14327146139528069, 0.5075916371175221, 6.674385283674512, 42.53300510134016, 66.81687927246094, 62.543785776410786, 64.12490395137242, 62.05399336133684, 56.75063140051705, 45.26380695615496, 50.88498299462454, 58.092867033822195, 57.40390450613839, 56.32513066700527, 54.94083063943045, 48.59855318069458, 43.58121381487165, 40.5925851549421, 40.92314222880772, 42.20730134419033, 42.47873272214617, 43.109795910971506, 44.376424721309114, 47.27749913079398, 49.11684363228934, 48.49409048897879, 44.48916271754673, 42.84903001785278, 46.53387859889439, 48.190283979688374, 48.97448546545846, 51.524658475603374, 47.070029394967214, 43.93768419538225, 39.938655444553916, 38.856185163770405, 39.855971881321494, 40.43999229158674, 39.04065983636038, 40.65120710645403, 38.597667012895855, 38.49645607812064, 39.03670631136213, 39.07260070528303, 44.98457275118147, 46.63689259120396, 47.41487543923514, 46.54442596435547, 45.66311298097883, 48.27272435597011, 50.32239430291312, 52.44205345426287, 53.206904206957134, 52.774802684783936, 50.94144058227539, 52.51978990009853, 52.37580238069807, 51.61266783305577, 53.52730648858206, 49.07430676051548, 43.2002614566258, 40.18346132550921, 42.26072951725551, 41.825556891305105, 41.61206306729998, 38.88803570611136, 40.4278016771589, 39.76159102576119, 42.49273681640625, 38.722685950142996, 40.97101879119873, 39.611753123147146, 39.16111380713326, 40.546046120779856, 42.16875968660627, 46.09596143450056, 48.065497807094026, 48.216933795383994, 49.3283155305045, 50.53290734972273, 49.742494174412315, 45.92423323222569, 50.435191358838765, 45.35719769341605, 41.80599076407296, 38.9768580027989, 38.76261029924665, 44.08526393345424, 43.46752738952637, 42.524399757385254, 43.81093168258667, 42.87538800920759, 42.77013322285244, 43.08111374718802, 45.36552163532802, 44.06614943913051, 46.10671724591936, 47.21517726353237, 48.11957911082676, 46.95454338618687, 48.34311655589512, 51.033438205718994, 54.527732440403526, 56.04899535860334, 57.823520115443635, 49.19683129446847, 25.49659538269043, 1.8557674373899187, 0.044595455418207815, 16.68497678211757, 47.11995915004185, 55.65000547681536, 54.10214485440935, 54.51997477667672, 59.395369393484934, 49.90115281513759, 38.33287811279297, 50.60854196548462, 48.88997105189732, 44.856826645987375, 15.466829027448382, 34.2722292627607, 31.281238215310232, 25.30141874722072, 50.94184010369437, 24.378635440553936, 1.025611326098442, 0.1262619998306036, 0.022366546427032778, 0.031304721986608844, 0.05781876961035388, 0.03558036112891776, 0.04992950740935547, 0.03769312918718372, 0.06590686632054192, 0.030060597495841127, 0.02727925531300051, 0.03221938719174691, 0.03919716651684471, 0.029766394889780452, 0.1015547416838152, 0.17400094174912997, 0.15341706627181598, 0.14915533709738935, 0.2233967033347913, 0.08381349367222615, 0.18625270575284958, 0.21846821850964002, 0.19047224361981663, 0.153462840244174, 0.23048805924398558, 0.13380971125194005, 0.1355036467845951, 0.09634756895580462, 0.09116393460759095, 0.15135889314115047, 0.26713513849037035, 0.1507049346608775, 0.6004785756979669, 52.04068381445748, 63.62603024074009, 46.91033547265189, 47.624818733760286, 45.915714740753174, 23.847838231495448, 63.288493701389854, 39.14645310810634, 30.70449604306902, 61.4326993397304, 75.84751551491874, 68.26161125728062, 61.875973565237864, 65.87557206835065, 45.85244444438389, 5.354217563356672, 0.39158899177398, 1.398993730545044, 1.019066340156964, 8.89912508215223, 46.5038172176906, 68.02414962223598, 65.31783321925572, 68.10216399601528, 65.78602368491036, 60.56763471875872, 49.69707032612392, 55.47674172265189, 61.15213802882603, 61.258139746529714, 59.599979945591514, 60.277790614536826, 52.56211485181536, 46.70254264559065, 43.09318971633911, 42.87854943956648, 45.55549233300345, 45.67717613492693, 45.96118722643171, 46.12516818727766, 50.50093868800572, 51.712395327431814, 51.5999630519322, 47.78236566271101, 46.785573618752615, 50.68773405892508, 50.454014028821675, 51.54936279569353, 55.14610474450247, 49.11670814241682, 46.9005628313337, 42.14235653196062, 41.30318437303816, 43.681219237191335, 43.84886189869472, 42.40236159733364, 43.211024216243196, 41.73515387943813, 41.76094559260777, 41.600622858319966, 41.694020543779644, 46.2348906653268, 49.44143220356533, 51.10403537750244, 50.539146832057405, 50.17125013896397, 53.136015210832866, 54.53742170333862, 56.548699378967285, 55.32860265459333, 54.10450724193028, 53.114343779427664, 55.41825873511178, 53.74585860116141, 56.033011027744834, 58.093019894191194, 52.38570008959089, 47.616682393210276, 43.32980367115566, 43.3574401310512, 44.28321116311209, 44.66378831863403, 39.081786223820274, 42.415049007960725, 41.336153575352256, 42.888502734048025, 41.57403905051095, 43.15679700034005, 42.61053657531738, 42.07513271059309, 41.58692795889718, 44.66326025554112, 48.96043620790754, 50.30656978062221, 49.43533863340105, 52.74096148354666, 53.120485986982075, 52.5356422151838, 47.69385950905936, 51.41795151574271, 49.24639974321638, 44.192401681627544, 40.58023820604597, 41.44428144182478, 46.644539083753315, 45.83139487675258, 44.18073913029262, 45.040259088788716, 44.992236614227295, 44.167937074388774, 45.5514554296221, 49.49929332733154, 45.89756257193429, 47.535826206207275, 49.913906233651296, 50.00214835575649, 48.504418986184255, 50.848796776362825, 52.51472813742501, 56.120238712855745, 60.37612846919468, 62.01404121943882, 51.56245667593819, 28.307704516819545, 2.031374905790601, 0.6063932297485215, 17.71091651916504, 50.48743486404419, 62.250307764325825, 61.53788117000035, 58.29111998421805, 65.94611712864467, 53.61162635258266, 42.435751165662495, 57.433357919965474, 60.100903374808176, 50.27999986921038, 25.813926560538157, 46.26508058820452, 33.69475058146885, 45.92540747778756, 54.41982691628592, 49.197216919490266, 2.5018170220511298, 0.1945383104362658, 0.1333253729556288, 0.26598483164395603, 0.17490726097353868, 0.18603406819914067, 0.17722730790930136, 0.12233533124838557, 0.1561367974749633, 0.12010179752750055, 0.17253712458269937, 0.11048127018979617, 0.14096092752047948, 0.23853494173714093], [0.09176231428448643, 0.03205160583768572, 0.03572675845186625, 0.038654338501925976, 0.032829244288482835, 0.05248812386499984, 0.033871501218527555, 0.01976410000185881, 0.12107544099645955, 0.03623487261523094, 0.1460270056767123, 0.018075438382636224, 0.022467439495293156, 0.022616260884595767, 0.0391017882419484, 0.05124387723792877, 0.11416182055005006, 0.08677182492933103, 0.11267645989677735, 5.88686386176518, 43.82489061355591, 34.819757734026226, 30.06699882234846, 31.579750197274343, 19.90019314629691, 44.97343826293945, 77.72726031712124, 28.109658275331768, 37.84766803468977, 56.52507202965872, 61.242645263671875, 59.34617614746094, 59.528267587934224, 36.85120255606515, 4.284274884632655, 0.2651935783880097, 0.5423945124660219, 1.546617003423827, 10.760414600372314, 54.728247029440745, 65.8781429018293, 63.30985941205706, 64.50842366899762, 62.09999738420759, 55.74271876471383, 44.40869562966483, 49.369928291865754, 57.304156167166575, 53.38123450960432, 58.45286015101841, 53.822990553719656, 51.94727223260062, 47.7509320122855, 45.85600192206246, 42.11310461589268, 43.33956241607666, 42.09670686721802, 43.82350097383772, 46.4129695211138, 52.15104900087629, 51.975620882851736, 51.830219405038015, 49.73534100396292, 52.17450264522007, 48.842400210244314, 51.03295530591692, 53.0603597504752, 51.58834913798741, 47.63580730983189, 41.91765873772757, 37.86429507391793, 38.573125975472585, 38.72917556762695, 38.52591296604702, 38.505999428885325, 38.35906934738159, 38.93745824268886, 40.051539352961946, 38.74035174506051, 40.42029414858137, 45.267475605010986, 44.333714144570486, 46.44775915145874, 46.6858218056815, 46.31741441999163, 47.12974568775722, 49.4668938773019, 50.58352845055716, 50.914714336395264, 52.47645051138741, 50.80758006232125, 51.960664885384695, 50.652194023132324, 50.95954063960484, 49.66535527365548, 49.297142437526155, 43.43728188105992, 37.35276869365147, 38.380518436431885, 36.96525723593575, 37.69795172555106, 36.9365542275565, 37.70468800408499, 37.98649304253714, 38.46581104823521, 38.170905181339805, 36.82078334263393, 39.05864872251238, 38.238042150224956, 38.2162630217416, 39.91740437916347, 42.21490267344883, 45.247037478855674, 47.60078491483416, 47.46656656265259, 50.198368958064485, 51.09068441390991, 48.322463035583496, 48.56686592102051, 47.11028725760323, 43.192364828927175, 42.58065584727696, 46.379666805267334, 44.22498525891985, 44.421035630362375, 43.31964193071638, 40.12145560128348, 39.73082092830113, 39.51843534197126, 39.46224873406546, 41.15135581152779, 41.08913121904646, 42.432544572012766, 42.331090450286865, 44.30485480172293, 43.83240161623274, 45.21383203778948, 47.12896401541573, 49.95546340942383, 51.64499780109951, 55.1616860798427, 48.60102326529366, 28.725553546633037, 5.579710057803562, 1.0639760217496326, 18.11546148572649, 47.5800792830331, 50.06563057218279, 50.816914967128206, 49.5686537197658, 50.28618376595633, 48.85672739573887, 54.538825239454, 61.120947565351216, 57.0024619102478, 36.3376646723066, 15.945688452039446, 25.761054243360245, 21.579822880881174, 33.636896405901226, 39.05280876159668, 2.5736023357936313, 0.31561820262244766, 0.03940889997673886, 0.11026863088565213, 0.0599159924313426, 0.0938487687547292, 0.042031207121908665, 0.11062051236097302, 0.01972408509547157, 0.05029594006815127, 0.028819699439087083, 0.08230784482189588, 0.014635416812130382, 0.108236269227096, 0.044513464639229436, 0.005374525332756872, 0.026217736470113908, 0.016086957583736097, 0.07538515236228704, 0.08803254299397979, 0.07452308040644441, 0.10128397228462355, 0.0998443245355572, 0.10494674502738885, 0.08128253769661699, 0.03831315413117409, 0.05224366466115628, 0.07942517700472049, 0.05243845510163477, 0.054456072194235663, 0.16064518769936903, 0.16517318758581365, 0.1563398287232433, 0.15401922538876534, 6.848450251988002, 54.13719851630074, 38.71111025129046, 34.56730883462088, 36.17896086829049, 22.856167009898595, 48.02031714575631, 73.58202757154191, 31.73181847163609, 44.295426096235005, 61.25585378919329, 66.23787893567766, 62.199592862810405, 64.70038155147007, 41.111956051417756, 5.87410740341459, 0.28302591294050217, 0.69064562022686, 1.9259581395557948, 12.306174261229378, 56.199114663260325, 65.66720948900495, 64.97147246769497, 64.68439374651227, 64.14284420013428, 56.97673273086548, 47.11667612620762, 50.187470708574565, 58.274267128535676, 56.86177478517805, 58.789396149771555, 56.72456175940377, 53.00917584555489, 49.43159702845982, 45.78409848894392, 43.61225141797747, 43.93231323787144, 42.55490582329886, 44.84957620075771, 47.76322684969221, 51.32970591953823, 52.278367791857036, 55.12104606628418, 49.6213002204895, 51.05062804903303, 49.744519574301584, 52.21704993929182, 51.57938596180507, 51.283781800951274, 48.40694965635027, 42.73186601911272, 39.368371622903005, 39.61967754364014, 39.33197348458426, 39.000117097582134, 38.52257088252476, 39.28031710215977, 39.07461568287441, 40.155401025499614, 40.52274881090437, 41.77620383671352, 46.40387085505894, 47.37711197989327, 48.9777615410941, 45.65965972627912, 47.257175649915425, 48.202495438711985, 49.33536795207432, 50.72357634135655, 51.40970400401524, 52.875235421316965, 53.275361333574565, 52.86643900190081, 51.93254552568708, 53.04599434988839, 51.50383472442627, 53.22298581259591, 44.827182156699045, 41.541702134268625, 41.394869327545166, 40.34714698791504, 39.995877334049766, 39.85661806379046, 41.04191473552159, 41.89524037497384, 43.35394171306065, 40.34833860397339, 39.399277210235596, 40.23439162118094, 41.20222009931292, 40.52937044416155, 41.69485780170986, 44.952499866485596, 44.06520101002285, 46.20750434058053, 49.00030149732317, 50.20240238734654, 51.306557995932444, 49.59756517410278, 49.58769873210362, 47.82837315968105, 42.54686328342983, 44.01317637307303, 49.550984450748985, 47.729726110185894, 45.73612812587193, 47.79313884462629, 43.8456518309457, 42.75149468013218, 41.36249419621059, 41.1432055745806, 42.63343436377389, 44.84469509124756, 45.37528732844761, 45.73059388569423, 46.10857241494315, 47.29120445251465, 48.54753255844116, 50.846809591565815, 52.1728698185512, 54.21141569955008, 59.44800894601004, 52.45704071862357, 32.74181209291731, 6.341034599712916, 1.5453172560249056, 20.1949166229793, 51.5152645111084, 54.72725691114153, 55.250074114118306, 56.554504598890034, 56.0085255759103, 52.58017321995327, 56.12915325164795, 59.895688329424175, 55.443359102521626, 40.91975498199463, 13.597833956990923, 34.760503496442524, 21.9341983795166, 36.88140637534005, 48.47614329201834, 6.006876187665122, 0.48748365896088736, 0.07249529885926417, 0.1434940615934985, 0.07083628073866878, 0.05279032979160547, 0.06469101977667638, 0.05060081263738019, 0.06520335442785706, 0.055335613034133396, 0.05720249017966645, 0.07325593661516905, 0.04277237431545343, 0.06907506845891476, 0.09388899231063468, 0.1224842154021774, 0.21423631773463317, 0.1061353755316564, 0.12195011334759848, 0.12396027334034443, 0.18130044506064483, 0.19868295160787447, 0.19805100480360643, 0.22762574069201946, 0.12068936814154897, 0.23150618746876717, 0.19449853471347264, 0.17290869035891124, 0.2944773313190256, 0.17416818706052645, 0.2643819419401032, 0.35513814485498835, 0.34560318078313557, 0.3960672957556588, 21.79056521824428, 69.02969987051827, 48.012767927987234, 43.9116701398577, 46.26261050360543, 29.168228490012034, 52.71852922439575, 86.90805407932827, 35.97447885785784, 48.29280464989798, 66.93316432407924, 71.96937152317592, 67.8058580671038, 69.68957723890031, 44.46797071184431, 7.538851056780134, 0.7318689567702157, 1.0069994905165263, 3.2807456936155046, 15.777571575982229, 59.9290257862636, 66.83754321507045, 66.99597603934151, 69.30195113590786, 67.74622862679618, 60.775365012032644, 48.86474561691284, 55.65461213248116, 63.598223549979075, 59.05954211098807, 62.96775790623256, 58.74799878256661, 56.145943573543, 51.69253737585885, 49.162503719329834, 47.05938475472586, 47.72415018081665, 45.436917849949424, 47.473448753356934, 49.27261529650007, 54.45322690691267, 54.44764402934483, 57.60286617279053, 53.54365907396589, 55.638801506587434, 53.74192244665963, 54.827984946114675, 55.95867225102016, 55.937091146196636, 52.150475774492534, 45.33974034445626, 41.40139716012137, 43.20973879950387, 41.942821638924734, 41.97449847630092, 42.589236872536794, 43.66427605492728, 42.39302321842739, 43.09049034118652, 43.74725144250052, 43.89981998716082, 47.94794818333217, 49.21382311412266, 54.2393022945949, 50.85216665267944, 50.13013417380196, 51.73286124638149, 53.622726099831716, 55.323426246643066, 54.2553665297372, 56.85059860774449, 57.76831667763846, 56.13087640489851, 56.4228640283857, 56.2427111353193, 54.767365387507844, 55.635303088596885, 48.83544506345476, 43.16922385351998, 44.46300622395107, 43.101930550166536, 42.87413733346121, 42.54814175197056, 43.42044986997332, 43.94314200537545, 46.61680882317679, 43.10362243652344, 40.25526748384748, 42.25156831741333, 44.33918585096087, 41.33198813029698, 42.569653374808176, 45.73920617784773, 47.55457592010498, 49.3807292665754, 51.59489434106009, 54.776120117732454, 55.592780113220215, 52.4706244468689, 52.729027952466694, 49.63176768166678, 45.45255477087838, 46.20277609143938, 52.027371065957205, 49.47392545427595, 49.18068020684378, 48.82384852000645, 46.10673461641584, 44.29675667626517, 44.87250178200858, 42.71289396286011, 44.72566202708653, 45.656446184430806, 46.175448826381135, 47.494501795087544, 47.2869417326791, 48.65561873572213, 50.82609701156616, 52.40903214045933, 54.924856730869834, 56.28259726933071, 61.64325754983084, 54.83467606135777, 34.16526174545288, 7.055094454969678, 2.03947759100369, 21.84710792132786, 55.942125116075786, 58.63568115234375, 61.081961223057334, 57.20930978230068, 60.09773499625069, 56.89852033342634, 63.87524127960205, 67.61226040976388, 66.70993954794747, 42.95185988289969, 24.499367339270457, 38.11921058382307, 31.93988922664097, 47.64971760341099, 60.68852642604283, 18.527911765234812, 1.3578336877482278, 0.3416227043739387, 0.2910945899784565, 0.13534200617245265, 0.11276527334536825, 0.22077396192720958, 0.17426300554403237, 0.11828636351440634, 0.10122434941253491, 0.10808105434158019, 0.12115611881017685, 0.11666968597897462, 0.16701178678444453, 0.30044887374554363], [0.07581698561885528, 0.09455041467611279, 0.06692301322306905, 0.07441733072378806, 0.011343087718289877, 0.04312966371487294, 0.06212861370295286, 0.01397313185900982, 0.04506630104567323, 0.05753239390573331, 0.022022049109052335, 0.05782176194978612, 0.04140195410166468, 0.0419596997089684, 0.035674480721354485, 0.1394097828971488, 0.053394758608192205, 0.027278990684343234, 0.04636825368340526, 0.7688625774213246, 35.25612197603498, 50.8429741859436, 69.80161694117955, 38.05945955004011, 26.286379746028356, 27.3129882471902, 74.94059494563511, 52.93525048664638, 28.47596209389823, 51.61345297949654, 62.29706219264439, 57.53906781332833, 60.10308510916573, 49.977902616773335, 12.674223814691816, 0.6220500724656242, 1.326950030667441, 4.32993757724762, 31.509708881378174, 61.893955503191265, 66.49620601109096, 64.73242664337158, 61.133836473737446, 58.9884272984096, 52.86494166510445, 43.88708046504429, 47.046593121119905, 57.67919213431222, 57.65078442437308, 54.69856432506016, 58.9967998777117, 52.17233828135899, 53.26763146264212, 52.016104561941965, 54.57589735303606, 50.43505239486694, 48.31049823760986, 47.16090835843767, 48.582905837467735, 52.3082936831883, 53.73761108943394, 54.53179366247994, 53.136512007032124, 52.87557240894863, 52.97706127166748, 52.056654248918804, 52.896802629743306, 50.496332032339915, 47.01189729145595, 40.027974537440706, 39.07076290675572, 39.146341936928884, 37.994549478803364, 39.41599110194615, 37.56820453916277, 36.341201305389404, 37.19982147216797, 38.93872281483242, 38.974325384412495, 42.17182036808559, 45.32060847963606, 46.5002840587071, 45.88180753162929, 47.92347662789481, 50.142561026981895, 48.24701254708426, 48.81715740476336, 48.40318373271397, 50.88602522441319, 51.9659628868103, 50.73551682063511, 52.33403328486851, 49.91554600851876, 52.31474161148071, 50.01289027077811, 50.89249747140067, 43.93248694283621, 38.011999879564556, 38.19418512071882, 36.63546446391514, 36.36932413918631, 35.31326048714774, 37.17121226446969, 39.53027159827096, 38.57652017048427, 36.46214165006365, 38.19294139317104, 37.36424016952515, 38.01964637211391, 38.467892033713206, 39.058155400412424, 39.552471092769075, 40.04345164980207, 40.585702964237754, 47.38874326433454, 47.28260605675833, 49.80965198789324, 47.382851191929404, 47.12390225274222, 49.369104930332725, 44.48282248633248, 49.44311366762434, 45.85680096490042, 49.23265620640346, 46.7505373273577, 42.22291742052351, 47.95503534589495, 41.56596524374825, 39.39220741816929, 40.98277514321463, 38.96617514746529, 41.483312947409495, 40.69994871956961, 42.10145248685564, 44.17003195626395, 44.130500180380686, 46.01502881731306, 48.243114607674734, 50.52882180895124, 49.78412083217076, 53.731149264744346, 45.18397910254342, 31.925867761884415, 10.74128360407693, 1.782000475696155, 21.120932579040527, 49.932041031973704, 51.096329825265066, 50.84065348761422, 41.84465054103306, 49.57691512789045, 49.647043296269004, 48.58324629919869, 54.14275360107422, 54.093518665858674, 15.793931109564644, 21.54201599529811, 33.40714727129255, 31.443575927189418, 42.490527289254324, 28.11217178617205, 0.9306501873901912, 0.15894148126244545, 0.049997869812484295, 0.0629846602678299, 0.05411978345364332, 0.09273883474192449, 0.06526243447193078, 0.05071698461792298, 0.06037835297839982, 0.06781080165611846, 0.022571523374478732, 0.03616479351850493, 0.05430691662643637, 0.04585979685985616, 0.03834314877167344, 0.08176201768219471, 0.05378672793241484, 0.042140176453228505, 0.0306854400384639, 0.04182556690648198, 0.043033969921192954, 0.044529491636369906, 0.01681977879655148, 0.04265576128714851, 0.025820142090586678, 0.043290615613971434, 0.08837933545666081, 0.040641927027276585, 0.04360404111711042, 0.0622610298118421, 0.02100753238690751, 0.09795992422316756, 0.014476927995149578, 0.012411879608407617, 0.965754006590162, 49.02875089645386, 55.524316038404194, 60.29964964730399, 44.49504436765398, 29.680453164236887, 29.47163895198277, 79.43972029004777, 53.99098062515259, 31.913833481924875, 55.48536096300398, 66.7163666316441, 60.902760233197895, 65.23603207724435, 55.69058643068586, 15.120909486498151, 1.0037273232425963, 1.5346748956612177, 4.904660429273333, 33.73525857925415, 63.82199028560093, 68.10583959306989, 66.24650165012905, 62.80061204092843, 61.98796463012695, 56.6965639931815, 45.56278446742466, 50.368339266095845, 57.984881605420796, 58.99321460723877, 57.43900333132063, 60.01195253644671, 55.08057975769043, 54.591197286333355, 53.677804470062256, 53.76937477929251, 50.28139645712716, 50.73577042988369, 48.9564653124128, 49.732256003788535, 52.478409903390066, 54.41039473669869, 55.19838299070086, 55.05372497013637, 52.780649593898225, 53.33057171957833, 54.52116639273507, 54.46021679469517, 52.804085867745535, 48.49499028069632, 41.710098675319124, 39.777332169669016, 39.28746679850987, 38.61529459272112, 40.06716237749372, 40.38959353310721, 38.97514874594552, 38.4559828213283, 40.71666261128017, 40.04955216816494, 42.19242525100708, 46.18281739098685, 47.290196963718955, 47.185411180768696, 49.74424512045724, 50.125541414533345, 49.97415753773281, 49.89778641292027, 49.58175802230835, 51.974745409829275, 52.83067314965384, 53.37255620956421, 52.610543795994346, 52.23324271610805, 54.51100812639509, 53.21935885293143, 54.164821079799104, 47.87288679395403, 40.848661014011924, 40.75128895895821, 40.96131215776716, 38.79303993497576, 40.50090020043509, 40.03409937449864, 43.35247911725725, 42.15243489401681, 40.56248903274536, 39.33691365378243, 39.52364649091448, 39.482645171029226, 39.547061920166016, 38.89122840336391, 40.29809965406145, 41.77377544130598, 41.4767746925354, 47.52051932471139, 48.31855467387608, 50.86003201348441, 49.471246923719136, 47.70959023066929, 50.13894101551601, 47.301480838230674, 49.70266710008894, 48.815121582576204, 51.392135483878, 50.331062180655344, 44.787160532815115, 50.76298999786377, 43.77195576259068, 42.735162939344136, 42.92630788258144, 42.402323382241384, 44.168385233197895, 43.52037538800921, 45.391195229121614, 47.030900614602224, 45.81847470147269, 49.687082290649414, 51.28421606336321, 53.3203752381461, 51.4500869342259, 56.54711866378784, 49.829742704119, 36.98954813820975, 12.75714795930045, 2.3280445294720784, 23.15197614261082, 54.68287181854248, 54.82219014848982, 55.50458662850516, 44.40559673309326, 54.68003347941807, 51.073980944497244, 55.1061178616115, 56.599515029362266, 58.566226959228516, 17.325854301452637, 21.233927658626012, 36.05778775896345, 27.44567452158247, 50.696040630340576, 35.623827593667166, 1.1313635600464684, 0.203661729448608, 0.09034883763108935, 0.04749269477490868, 0.05049045570194721, 0.0953162500102605, 0.04241979394906333, 0.044656516784535985, 0.015226101901914393, 0.05502638087740966, 0.08891396676855427, 0.07219581385808331, 0.018233742298824445, 0.0632968203031591, 0.05127448934529509, 0.18543589886810097, 0.25060249705399784, 0.10342137794941664, 0.09615106521440403, 0.08518509792962245, 0.1226607295019286, 0.12169777974486351, 0.1518297828733921, 0.10936936842543737, 0.16749137533562525, 0.15659593498068197, 0.09819720113383872, 0.16753519512712955, 0.1519366249974285, 0.18402958075915063, 0.17944823444953986, 0.13739259328160966, 0.14247045080576623, 0.12415259730603014, 4.29081574508122, 71.55254908970424, 62.812514305114746, 75.28502409798759, 56.26524066925049, 39.5087182862418, 36.15909596851894, 84.58845356532505, 62.82103974478585, 36.630381856645855, 61.24449348449707, 73.79596955435616, 65.8954439163208, 69.41647829328264, 58.40208966391427, 17.320311376026698, 1.2597781036581313, 2.515996341194425, 6.329734657491956, 40.35645062582833, 67.72965717315674, 70.84138011932373, 69.29470416477749, 65.95803328922817, 65.01302964346749, 58.40172140938895, 50.33917072841099, 54.36946289879935, 62.18855912344796, 65.90333012172154, 60.55013220650809, 64.36652755737305, 57.2868412562779, 56.699148723057334, 57.67930677958897, 58.047495297023225, 53.93188967023577, 55.54292678833008, 53.33725241252354, 53.073186125074116, 57.59360422406878, 58.305197034563335, 56.15261384419033, 58.55093397412981, 56.17243358067104, 59.926149232046946, 57.45958389554705, 58.728529930114746, 55.525934968675884, 50.4410834312439, 42.67382424218314, 42.58102062770298, 41.07053089141846, 40.45643172945295, 43.286537238529746, 41.741890157972065, 40.17486640385219, 41.17118944440569, 43.659763199942454, 42.1022515296936, 45.900220257895334, 48.983181135995046, 51.823608194078716, 50.340904303959434, 54.31182411738804, 54.355295521872385, 54.713798250470845, 53.80102729797363, 52.85294212613787, 55.57394354684012, 55.164097104753765, 55.54760640008109, 56.97424527576992, 54.10271460669381, 57.38413340704781, 55.98841748918806, 58.804049900599885, 49.960914271218435, 44.45176403863089, 44.25267035620553, 43.01136078153338, 40.53640896933419, 42.34124524252755, 42.79049839292254, 45.68552786963326, 43.00170973369053, 41.43985891342163, 39.94086844580514, 40.58969470432827, 42.392394406454905, 40.637814453669954, 40.200988156454905, 42.12073373794556, 42.00213493619646, 43.27875873020717, 50.08871248790196, 50.592081683022634, 52.766503061567036, 51.69731773648943, 50.454312801361084, 53.30720840181623, 50.30301925114223, 53.769180229731965, 51.17220415387835, 54.170449120657786, 54.30222865513393, 46.360441139766145, 53.30640935897827, 45.43373557499477, 44.16203110558646, 43.94636249542236, 42.80452333177839, 46.303622245788574, 44.3618335042681, 46.66739865711757, 48.709887640816824, 47.555687631879536, 50.578953061785015, 53.329849106924875, 54.63039207458496, 54.54855271748134, 60.58805547441755, 55.515543937683105, 40.51284762791225, 13.650156497955322, 2.8513908811977933, 26.36682251521519, 60.76080158778599, 59.55988189152309, 60.91465554918562, 50.27653619221279, 59.97600950513567, 57.68053661073957, 58.362728118896484, 62.31637123652867, 63.45682770865304, 19.963614565985544, 33.810208797454834, 44.42868559701102, 46.277229513440815, 55.6385235786438, 55.28652088982718, 2.7511377121720995, 0.38471638198409763, 0.17350197423781666, 0.13720237277448177, 0.13348162599972316, 0.19743152947298118, 0.17535130786044256, 0.08752003192369427, 0.15764463799340384, 0.16847594321838447, 0.12667990954858915, 0.2827631027570793, 0.12780923609222683, 0.1517452374100685, 0.10047388968190976], [0.04192082304507494, 0.04080435134736555, 0.04263216523187501, 0.04822331414158855, 0.02238891094124743, 0.06225136068782636, 0.07030516423817192, 0.05279676569625735, 0.0553224596327969, 0.0703282140727554, 0.12740394712558814, 0.023881611647084355, 0.0336193101081465, 0.023181894461491277, 0.02184910579983677, 0.03818460567189114, 0.03981989881555949, 0.09375209108527217, 0.03507306120757546, 0.16991557739675045, 19.64710327557155, 48.70572566986084, 31.103499821254186, 37.9304176058088, 34.8961740221296, 22.11155809674944, 65.50947148459298, 65.82140391213554, 50.19832032067435, 45.89764247621809, 59.348573275974815, 64.11019461495536, 58.956097330365864, 53.999089172908235, 30.632071495056152, 7.098109015396663, 0.3530048578977585, 5.618773698806763, 42.04747193200247, 67.0835302897862, 65.05148792266846, 60.90553951263428, 61.047414779663086, 56.30645390919277, 51.634634562901084, 41.696525369371685, 46.99000004359654, 56.18440185274397, 61.19619655609131, 56.2776049886431, 53.815486499241416, 58.523968015398296, 52.29894835608346, 53.937288420540945, 52.26860557283674, 53.90065404347011, 51.15782833099365, 51.57172209875924, 50.02889197213309, 50.950928347451345, 52.468557357788086, 53.577163287571494, 54.250857148851665, 54.51356158937727, 53.70756360462734, 54.837684631347656, 52.07379198074341, 50.5375383240836, 45.12294265202114, 40.50345366341727, 39.36504690987723, 38.16582257407052, 38.8901583807809, 38.814499446323936, 39.18233013153076, 36.66336842945644, 38.76768248421805, 38.666825907570974, 40.75678150994437, 43.36809866768973, 46.349192006247385, 45.55382476534162, 47.10093150820051, 46.90262644631522, 49.25480358941214, 47.55345378603254, 49.716907433101106, 48.911447933741975, 43.91710015705654, 51.97155966077532, 50.647656849452424, 54.32932662963867, 51.416148458208355, 52.36698511668614, 50.020811217171804, 49.55941956383841, 48.1806572505406, 39.36964661734444, 37.19753898893084, 38.16946690423148, 37.50664349964687, 36.79125697272164, 36.5846974509103, 38.38018144880022, 37.6734037399292, 35.75647565296718, 37.0308586529323, 37.734530517033164, 36.60983255931309, 38.24418088368007, 39.47234099251883, 37.19306434903826, 38.6341415813991, 38.53791945321219, 42.77049800327846, 49.702955450330464, 51.981040477752686, 50.87383460998535, 49.372391428266255, 49.72018003463745, 49.68877765110561, 49.17111601148333, 48.0307811328343, 52.048611709049766, 47.73931809834072, 50.62050328935896, 43.584955419812886, 42.34260014125279, 38.985001291547505, 41.493610177721294, 40.7894206728254, 44.87443685531616, 41.51254054478237, 41.95789228166853, 40.479253087724956, 44.157709326062886, 45.327355180467876, 50.416445119040354, 47.837603841509136, 49.26692124775478, 48.93378986631121, 49.064850262233186, 36.7549387386867, 21.10166696139744, 6.563789069652557, 22.76872045653207, 49.52953883579799, 50.0058274269104, 48.357172761644634, 48.39950813565935, 56.74364498683384, 55.4502204486302, 56.85068198612758, 50.34469107219151, 33.22290883745466, 10.618885006223406, 34.60533632550921, 29.43422290257045, 31.612820148468018, 47.496405601501465, 16.14386670930045, 0.17926142018820557, 0.09187537178929363, 0.07373039544160877, 0.03939545141266925, 0.13364188240042754, 0.054618679718779664, 0.015358657110482454, 0.06710578341569219, 0.07268949558160134, 0.0627770624788744, 0.014004874575350965, 0.020712825968595486, 0.0510699042518224, 0.06578247728092329, 0.02891813451424241, 0.06999596261552402, 0.029541168761040484, 0.027848826089341725, 0.03285224323293992, 0.01904753309541515, 0.028288664362792457, 0.03925424488261342, 0.10152208379336766, 0.05906974391213485, 0.02258656988851726, 0.018706450504916053, 0.06985869498125144, 0.03590062965771981, 0.005443072212593896, 0.046096870210021734, 0.02177474514714309, 0.07884167081543378, 0.14241759292781353, 0.028963976340102296, 0.2708813031869275, 22.79455038479396, 59.38839340209961, 33.43023613521031, 41.82629687445504, 43.48893478938511, 24.56815450532096, 73.20882592882428, 68.27543817247663, 52.05090461458479, 50.66707011631557, 65.29181221553257, 69.22222055707658, 63.45446532113211, 59.42228671482631, 34.162235804966514, 8.83721489565713, 0.5478588363953999, 6.6526495814323425, 45.65024144308907, 68.52774810791016, 67.37794630868095, 61.562679290771484, 62.11940370287214, 57.26148380552019, 53.31173167909895, 45.19422769546509, 48.242822783333914, 58.62097181592669, 63.28168446677071, 58.438011850629536, 56.40536151613508, 59.64053658076695, 54.69274173464094, 56.12837157930647, 54.3623548916408, 56.03022827420916, 55.07273871558053, 52.6423248563494, 53.002404826028005, 51.85709503718785, 55.074562617710654, 55.18630007335118, 55.55460671016148, 54.553159373147146, 53.96871859686715, 53.85530315126692, 53.35489388874599, 51.405910287584575, 45.59775822503226, 40.955972467150005, 42.06417192731585, 40.26787846429007, 40.48911952972412, 40.570218903677805, 40.03303630011422, 38.17384426934378, 39.87662192753383, 39.505119119371685, 40.86190775462559, 43.80028356824602, 48.307868344443186, 46.83379064287458, 49.00259092875889, 47.432614190237864, 51.14558907917568, 49.089280128479004, 51.88027075358799, 50.75352655138288, 48.87820775168282, 53.98473072052002, 52.611745834350586, 54.33464894975935, 54.31893559864589, 53.74641445704869, 51.440157958439414, 50.56233297075544, 50.53790657860892, 43.10540812356131, 41.60741124834333, 40.62124994822911, 39.98523964200701, 39.88781200136457, 40.247061661311555, 41.548525265284944, 40.816643714904785, 39.97402177538191, 40.78285115105765, 39.44329752240862, 38.88589913504464, 41.342243671417236, 40.76026255743844, 38.824223450251985, 38.87511205673218, 38.44814872741699, 43.00228296007429, 50.266780921391074, 52.196115016937256, 50.540699754442485, 49.45154183251517, 51.916853019169395, 51.46970517294747, 50.871315887996126, 51.04831082480294, 53.89602654320853, 50.56956604548863, 53.969917161124094, 47.69795547212873, 45.20443112509591, 42.576924664633616, 42.933471475328716, 42.73432568141392, 45.03976229258946, 43.67435441698347, 43.88257803235735, 43.910468101501465, 47.390914576394216, 47.83521366119385, 52.77585186277117, 51.37446968896048, 51.93889965329851, 54.02728148869106, 54.70866700581142, 43.07202202933175, 24.807810034070695, 7.401944620268686, 24.332970142364502, 53.99713672910418, 55.502620288303916, 51.34004136494228, 50.71079513004848, 58.70990875789097, 58.685256549290244, 61.467794690813335, 54.45706926073347, 41.99494355065482, 10.064027053969246, 36.71316964285714, 31.35307911464146, 31.637923989977153, 56.58844654900687, 16.782376629965647, 0.5003024882503918, 0.12189192218439919, 0.10504388410065855, 0.0355133218690753, 0.15991588469062532, 0.033038881075169356, 0.07140591767217432, 0.019578619061836174, 0.09222699542130743, 0.05339916230046323, 0.05141463736072183, 0.01357458922679403, 0.02834622618476195, 0.020302417455241084, 0.029760617164096663, 0.16838853433728218, 0.10602754274649279, 0.07902503811887332, 0.13640418489064488, 0.12879740021058492, 0.08135243358888797, 0.15154962933489255, 0.12246546069426195, 0.23748484094228062, 0.16686206124722958, 0.2564058170786926, 0.1312262298805373, 0.11029429308005742, 0.11095156959657158, 0.14216778347534792, 0.1299083927380187, 0.24598818751318113, 0.23623185817684444, 0.1666151966367449, 0.35928562230297495, 45.548012597220286, 70.11490426744733, 44.23384073802403, 51.87616089412144, 51.81514181409563, 30.034335340772355, 76.69969122750419, 75.13925089154924, 56.279276030404226, 57.152657645089285, 69.42086955479213, 75.41331563677106, 66.92938450404576, 64.40279020581926, 34.71587521689278, 10.668112124715533, 1.1318018393857139, 8.001576764242989, 49.39309706006731, 74.00677095140729, 71.07092080797467, 65.24992152622768, 66.57494299752372, 61.097740582057405, 56.72971732275826, 48.85662317276001, 51.59923349108015, 63.69258008684431, 67.44290501730782, 61.086713790893555, 58.90575763157436, 64.23931298937116, 58.379160608564106, 60.54593549455915, 57.266406604221885, 59.58231067657471, 58.00903006962368, 57.70404584067208, 54.909577642168315, 53.385681356702534, 56.470657212393625, 57.75154372623989, 57.34552574157715, 59.75224276951381, 57.81456388745989, 58.51465048108782, 57.6723690032959, 54.94774409702846, 48.40255839484078, 44.07524115698678, 44.127769538334434, 43.03096512385777, 42.348009313855854, 42.5687883240836, 41.8892753464835, 39.915691648210796, 43.16915437153408, 42.753829274858745, 44.07903139931815, 46.99853590556553, 51.2645491872515, 50.51717662811279, 52.55688285827637, 50.47048820768084, 55.09603949955532, 53.03854240689959, 53.4372752053397, 56.11390542984009, 50.51099273136684, 55.04726661954607, 57.62196677071707, 57.135231563023154, 57.7182549067906, 57.78872006280081, 54.783016204833984, 53.565073422023225, 54.65904644557408, 45.16391617911202, 43.55641222000122, 44.71802943093436, 41.75756529399327, 42.981681551252095, 42.11042261123657, 43.43804618290493, 40.94868033272879, 41.093303612300325, 43.59019783564976, 41.67493731634957, 39.39745330810547, 41.462027141026084, 42.689704350062776, 40.353935377938406, 40.84029885700771, 40.99114077431815, 45.926682472229004, 52.79239899771554, 55.42795842034476, 52.487164633614675, 53.67408718381609, 54.33015693937029, 53.59590605327061, 53.640843527657644, 51.55831207547869, 56.75164236341204, 52.45746455873762, 58.71797561645508, 48.2691946710859, 47.057553904397146, 42.72185713904244, 45.5263237953186, 44.67148344857352, 49.16891690662929, 43.37822219303676, 46.74706670216152, 46.62705741609846, 49.52897603171212, 50.73817103249686, 55.29063769749233, 53.99631684167044, 55.556309018816265, 57.418207372937886, 60.88601507459368, 45.92172493253435, 26.977900947843278, 8.353507365499224, 29.104754958833965, 57.5862078666687, 60.61387498038155, 59.0777394430978, 56.66453627177647, 64.55900655473981, 64.26653603145054, 65.50401714869908, 60.449320793151855, 42.3898617880685, 16.14452678816659, 51.83218921933855, 43.43664959498814, 44.1566219329834, 61.92554896218436, 32.3854216166905, 0.7621109368545669, 0.17487093220864022, 0.26170086009161814, 0.1447058572833027, 0.2734786809555122, 0.10590934873159442, 0.1208129565098456, 0.16623840614088944, 0.25864397840840475, 0.17715652313615593, 0.19163204995649202, 0.1336687659578664, 0.08150680030563048, 0.1424066685140133, 0.09889191242733172], [0.019701096329039762, 0.01576156950821834, 0.04845162081931319, 0.01557916572450527, 0.06830236635037831, 0.04553395416587591, 0.061054357061428685, 0.02326969858924193, 0.08315642071621758, 0.01987437890576465, 0.09851480980536767, 0.024367071222513914, 0.040511831508151123, 0.029787453224084208, 0.006618951771607888, 0.018808537794809257, 0.10261944455227681, 0.09171047420906168, 0.05915365155254092, 0.3786607283566679, 5.632670530251094, 54.03589378084455, 40.300649642944336, 29.854338782174246, 44.2527745791844, 20.083719389779226, 45.90802655901228, 67.59075573512486, 68.37718759264264, 64.53983647482735, 56.07009008952549, 63.96668652125767, 58.10356378555298, 60.3990158353533, 37.10054908479963, 13.198025924818856, 1.2666039488145282, 4.899419316223689, 47.53577062061855, 67.18938609531948, 64.4689370564052, 62.81027698516846, 55.102581228528706, 53.722703729357036, 47.289536884852815, 44.80972828183855, 46.747337681906565, 55.14027520588466, 58.67086683000837, 60.01079913548061, 55.30659770965576, 56.45800454275948, 57.2424943787711, 57.31337642669678, 56.97805636269705, 56.843865803309846, 57.02305637087141, 56.428335734776084, 56.31241546358381, 52.22351523808071, 51.9633468900408, 52.41637291227068, 52.627924714769634, 51.69267633983067, 52.48575414930071, 52.1655707359314, 52.993736948285786, 45.856040137154714, 40.589399405888145, 39.03808205468314, 40.10976873125349, 39.937574999673025, 40.57508611679077, 40.07803978238787, 38.83662598473685, 37.85426882335118, 38.8335131917681, 40.553084645952495, 40.67512975420271, 45.76411199569702, 46.03269113813128, 46.17068236214774, 47.263227530888145, 49.25535944529942, 50.38998637880598, 49.55392006465367, 49.24078559875488, 54.3097049168178, 48.0738182749067, 46.94939824513027, 53.66375521251133, 51.18173360824585, 52.04807322365897, 50.809480394635884, 50.01845925194876, 49.17995759419033, 49.40514176232474, 39.70767995289394, 38.104157311575754, 38.117991174970356, 37.0698241506304, 36.86567217963082, 35.75420011792864, 37.30530554907662, 37.355895383017405, 36.82255860737392, 38.15124872752598, 37.30176196779524, 37.40941040856497, 38.00788654599871, 37.89027786254883, 38.62252071925572, 38.06007446561541, 39.25294814790998, 38.731211389814106, 46.99308851787022, 49.364595549447195, 52.79868016924177, 50.97328070231846, 49.79012407575335, 50.05788333075387, 51.19156183515276, 49.460595335279194, 44.46722378049578, 49.28432648522513, 45.309748445238384, 46.57104103905814, 44.166662079947336, 44.19196741921561, 45.91432162693569, 46.32788535526821, 47.045144421713694, 43.890974930354524, 41.39518894468035, 42.625315393720356, 43.12904242106846, 45.52233900342669, 45.55052089691162, 46.641707692827495, 50.776233264378135, 48.70235231944493, 49.61041586739676, 45.772894518715994, 30.393762179783412, 11.489527293613978, 19.963605880737305, 45.28489473887852, 50.86683429990496, 47.372640814099995, 52.65096146719796, 52.55828292029244, 54.68487637383597, 48.56588969911848, 36.92932462692261, 9.97929116657802, 20.63260623386928, 37.567606994083945, 28.135046992983135, 38.841930934361045, 47.951474394117085, 2.9102082507950917, 0.19972709486527102, 0.025685388428558196, 0.02050329096216176, 0.0436209196756993, 0.09962732225124325, 0.05546643119305372, 0.013930990593507886, 0.03879653230043394, 0.04430959879287651, 0.06090524220573051, 0.10227874533406325, 0.038780671544373035, 0.03758275189570018, 0.05250430353251951, 0.03403837333566376, 0.0336960693821311, 0.043482261044638496, 0.027415941103494594, 0.012198849298459078, 0.055807473071451695, 0.05764001634504114, 0.11792661781821932, 0.032952001451381614, 0.08359196555933782, 0.051232762834323306, 0.04487985997859921, 0.027207515501816357, 0.058984642050095966, 0.025998939460675632, 0.04849081300199032, 0.0711990866277899, 0.1572103620107685, 0.008980049651914408, 0.21146760987383978, 0.42656234226056505, 4.588484823703766, 66.4920231955392, 46.40768541608538, 35.20915910175869, 52.24270268848964, 24.729443039212907, 52.71474593026297, 72.22549601963588, 72.13569055284772, 69.10735293797084, 59.75760677882603, 68.95556953975132, 62.26688616616385, 64.67595168522426, 41.00869539805821, 15.251089198248726, 1.2689809926918574, 4.991869441100529, 49.734118121010916, 70.2591905593872, 66.0719906943185, 64.08941950116838, 58.18215833391462, 53.99142530986241, 49.613052708762034, 46.329674516405376, 47.529822962624685, 57.89485379627773, 60.38898263658796, 61.57053770337786, 56.20269298553467, 59.325449671064106, 60.07170009613037, 58.26488011223929, 58.28453656605312, 58.31599453517369, 60.698344230651855, 55.95413160324097, 55.90900305339268, 53.30727440970284, 54.53365230560303, 53.62004409517561, 53.530412333352224, 54.13099724905831, 54.3801075390407, 56.187855107443674, 52.82464558737618, 49.74368231637137, 42.39724424907139, 40.02341651916504, 41.57734291894095, 41.907952104296, 41.26550081798008, 42.095803601401194, 40.13244417735508, 38.25656604766846, 39.71416957037789, 41.58975240162441, 40.70258208683559, 46.60959311894008, 48.05396727153233, 47.81959411076137, 48.78461899076189, 50.11985083988735, 50.60198286601475, 50.63747773851667, 52.38469607489449, 53.560793331691194, 48.077004023960654, 50.59054613113403, 53.62808663504464, 53.63442686625889, 54.084336621420725, 54.44793585368565, 53.41103533336094, 52.90018292835781, 49.93069308144705, 42.21473591668265, 40.98559263774327, 39.92572832107544, 40.9997113772801, 39.56188242776053, 39.86182573863438, 43.131807804107666, 41.66459492274693, 40.3696938923427, 39.49710784639631, 39.0340382031032, 39.07041202272688, 39.098673820495605, 40.84490898677281, 39.62982538768223, 39.244391441345215, 39.070220947265625, 41.11527034214565, 48.211875506809776, 50.99188450404576, 53.69817658833095, 50.88965218407767, 51.85327352796282, 52.2616400037493, 52.48940890175955, 52.53337362834385, 47.023320129939485, 50.88004629952567, 48.712083271571565, 48.687337262289866, 47.586127689906526, 46.33002887453352, 48.95284877504621, 48.746230193546836, 50.85083607264927, 44.95456348146711, 45.3420923096793, 45.01122604097639, 44.71165793282645, 49.360787936619346, 48.05235528945923, 50.461921078818186, 54.59481034960066, 52.4551751273019, 53.041516235896516, 52.43167631966727, 33.36836242675781, 13.1854053906032, 23.23365569114685, 49.74815695626395, 55.23482281821114, 51.73373324530465, 57.29072182519095, 55.39415543419974, 59.37206513541085, 52.25150258200509, 45.360404287065776, 14.411085861069814, 18.75339296885899, 41.99456139973232, 28.40654958997454, 44.04235185895647, 50.66648646763393, 2.100288442202977, 0.2799085330750261, 0.0510653886012733, 0.16487482216741356, 0.08262524314756904, 0.008167548071859139, 0.027179866896143982, 0.05263610556721687, 0.06247471405991486, 0.06668062015835728, 0.07171084452420473, 0.12800423348588602, 0.008608965635565775, 0.02800599006669862, 0.07062046589063746, 0.0012361302880370723, 0.16818907218320028, 0.09205405041575432, 0.21056842883782728, 0.09649968293628522, 0.1550606952181884, 0.127895002918584, 0.21559754040624413, 0.10937802653227534, 0.15182435459324292, 0.09487058821001224, 0.20506147933857782, 0.08786926032709223, 0.11817566731146403, 0.10533299430140428, 0.25305602539862904, 0.1584831444280488, 0.43243400433233803, 0.20957571853484425, 0.5290682475481714, 0.7498497005019868, 16.22128701210022, 82.90899753570557, 53.4107608795166, 47.18784305027553, 58.817418234688894, 30.043242931365967, 54.18374449866158, 77.28124155317033, 75.46333571842739, 75.96723297664097, 65.27002961294991, 75.54890973227364, 66.5408273424421, 69.23705496106828, 44.29439776284354, 17.654835871287755, 1.7245449530226844, 5.991270533629826, 53.91205603735787, 72.24079595293317, 68.56187071119035, 68.01611055646623, 60.88059547969273, 57.6162553514753, 52.207457951136995, 50.50570862633841, 52.33070509774344, 61.523025921412874, 64.80479907989502, 64.52247292654855, 57.91251611709595, 61.17436531611851, 61.845095770699636, 60.76856272561209, 61.218486377171104, 61.282666887555806, 62.64912741524832, 60.81166934967041, 60.319028173174175, 55.41567053113665, 58.26735367093767, 54.82899938310896, 58.54043524605887, 57.018001556396484, 55.751772267477854, 57.96676417759487, 57.095348903111045, 51.353044918605256, 43.94193649291992, 42.61608471189226, 44.08092825753348, 44.301495347704204, 45.653038093021934, 46.49491310119629, 43.31754010064261, 41.91668946402413, 43.30855260576521, 44.90174674987793, 43.67036962509155, 50.883200781685964, 50.79592098508562, 51.47616352353777, 51.61006920678275, 53.177697454180034, 55.975747449057444, 52.775771958487375, 55.86846031461443, 56.74063989094326, 55.3339319229126, 52.03253705160958, 57.45918437412807, 56.074637685503276, 57.31849030085972, 56.476674352373394, 55.315088408333914, 55.73730264391218, 52.947805881500244, 44.201139041355674, 43.21459559031895, 43.54845653261457, 43.603020736149375, 42.404751777648926, 40.42032541547503, 44.0611571584429, 43.20990208217076, 41.836969307490754, 41.69440269470215, 41.054605620247976, 40.9682742527553, 41.182313510349815, 42.56531769888741, 40.334084374564036, 40.085745334625244, 41.90867819104876, 42.387412548065186, 49.91209970201765, 51.72518348693848, 57.0352018220084, 53.925942012241904, 54.89674431937081, 53.67803028651646, 55.59519461223057, 53.80026994432722, 48.885149002075195, 53.104018756321494, 50.58609580993652, 49.86266326904297, 50.37604481833321, 49.349406787327354, 49.90966783251081, 49.86513682774135, 51.97265747615269, 47.125166824885774, 46.65697635923113, 46.74966880253383, 47.67602695737566, 50.86277655192784, 51.70886216844831, 52.77783209936959, 58.90846048082624, 55.77103614807129, 58.3471155166626, 57.086781774248394, 35.66512768609183, 14.159931932176862, 26.559235504695348, 53.835587637765066, 60.09124537876674, 56.02115045275007, 61.3908086504255, 60.125743184770855, 63.42943096160889, 56.65005970001221, 48.87204817363194, 14.462265423366002, 32.30183826174055, 50.899897302900044, 42.87459591456822, 48.16584021704537, 66.8716310773577, 8.116107395717076, 0.8250277436205319, 0.289227261607136, 0.3009014294615814, 0.16118971205183438, 0.18308803199657372, 0.11507455871573516, 0.1271559561469725, 0.17168185833309377, 0.11906361180756773, 0.24689389605607304, 0.2358288083757673, 0.09676825388201646, 0.11844963261059352, 0.13277523033320904, 0.12885997471000465], [0.06445754944745984, 0.05356958654842206, 0.029667552693613937, 0.01965975827936615, 0.04038895899429917, 0.0798209189836468, 0.08362773792552096, 0.047283047810196877, 0.05718193735395159, 0.08163183395351682, 0.0578051039150783, 0.030549651610531976, 0.03825759229117206, 0.023546888626047542, 0.11567202237035547, 0.0253931535740516, 0.057546453151319704, 0.0632178456123386, 0.0724557199116264, 0.032807951859597645, 0.21368274172501905, 32.8115268434797, 54.42155006953648, 34.820598466055735, 41.0793377331325, 30.670922347477504, 35.14578458241054, 62.59743281773159, 58.52145971570696, 65.25680024283272, 62.08755316053118, 59.78781059810093, 60.85291385650635, 58.940276282174246, 53.13812746320452, 20.69759099824088, 1.036346184355872, 4.173184479985919, 51.290789059230256, 67.78449930463518, 63.38467066628592, 63.27772399357387, 57.027520588466096, 53.613241808755056, 49.19927706037249, 45.598647594451904, 45.583736760275706, 54.88797916684832, 59.34946264539446, 57.119525160108296, 57.45804834365845, 58.63069234575544, 56.48770809173584, 58.16390541621617, 58.48466205596924, 59.10703999655587, 56.44806514467512, 56.19925710133144, 55.78280987058367, 52.347766399383545, 48.28355312347412, 46.24601125717163, 51.614623750959126, 51.601064341408865, 53.1351432119097, 51.95440455845424, 47.30902658190046, 42.17740671975272, 38.77998774392264, 40.626992634364534, 39.80967256001064, 40.176506178719656, 38.231688022613525, 37.4207672391619, 37.80541951315743, 38.8661002431597, 38.462865012032644, 39.881919928959434, 41.10217646190098, 45.51062781470162, 47.278749806540354, 45.21010432924543, 47.52078683035714, 47.715930461883545, 48.172249930245535, 49.187666620527, 52.70378514698574, 51.69798476355416, 51.82726294653756, 42.69479043143136, 53.21655872889927, 52.493553502219065, 53.56720304489136, 51.536442620413645, 51.69723783220564, 49.60150480270386, 47.92183337892805, 43.131172043936594, 39.40377616882324, 38.41388021196638, 36.84453575951712, 37.35649987629482, 37.62082324709211, 36.83920301709856, 36.530696051461355, 38.4378445489066, 38.695431641169954, 38.96842636380877, 38.115336963108604, 38.206716196877615, 38.67085238865444, 38.81350237982613, 38.77853209631783, 39.808689389910015, 38.43886593409947, 42.44956418446132, 49.75696727207729, 50.74201338631766, 50.88745655332293, 49.66169009889875, 51.18479428972517, 50.83710643223354, 47.889586789267405, 50.596274920872276, 51.746319907052175, 49.374534947531565, 48.23800073351179, 47.98168863568987, 51.064097132001606, 49.69698347364153, 50.814608165196006, 52.239735807691304, 47.62806701660156, 41.39543213163103, 43.66394254139492, 42.44489846910749, 45.69782965523856, 46.69741140093122, 46.75708253043038, 48.43055616106306, 51.770989486149375, 51.491182054792134, 52.319681780678884, 37.68943670817784, 16.727643932615006, 19.507463591439382, 42.32937771933419, 48.298331941877095, 46.635492529187886, 54.08723749433245, 57.36198254993984, 54.84928117479597, 50.72736310958862, 21.463748012270244, 8.322124089513506, 24.61697428567069, 36.57292372839791, 30.22373628616333, 44.97472367967878, 21.65542275565011, 0.13185715888227734, 0.04525025188922882, 0.028413921927234957, 0.02949123197634305, 0.04841576024357762, 0.07282058854720422, 0.05079723495457854, 0.12538336483495577, 0.002725307488747473, 0.06471091442342315, 0.05849855313343661, 0.07202324883214065, 0.029887096091572727, 0.036795159336179495, 0.05229151155799627, 0.017247876717842052, 0.06776632368564606, 0.04676566146580236, 0.06623958596693617, 0.029739901489977325, 0.04000467068648764, 0.06269557042313473, 0.03493126095937831, 0.015738453516470532, 0.0531926908796387, 0.038809946937752623, 0.04635064909234643, 0.005383958241769246, 0.03918092578117337, 0.030208708119711707, 0.12007059848734311, 0.028229572444355915, 0.06434916026358094, 0.039855796710721085, 0.06382438806550843, 0.045265505356448035, 0.7762691399880818, 34.566429887499126, 65.38383415767125, 34.73552472250802, 44.684566906520296, 38.526930877140586, 37.70992694582258, 68.43342631203788, 63.22270815713065, 71.37304237910679, 64.29780987330845, 64.89214488438198, 64.58584744589669, 63.93111869267055, 57.09881258010864, 23.87573524883815, 1.2910353349787849, 4.451392957142421, 52.68787029811314, 70.13224002293178, 65.43514660426548, 64.88922664097377, 59.342438016619, 54.79719747815813, 49.89874873842512, 46.96255465916225, 46.82289586748396, 56.55186775752476, 61.68384197780064, 58.19393900462559, 57.18519605909075, 59.122534479413716, 57.887575558253694, 61.32652391706194, 61.59746197291783, 59.95057215009417, 57.4653126852853, 58.28336579459054, 56.53105442864554, 52.56042643955776, 49.289881569998606, 47.744247845241, 53.44784688949585, 53.0207793372018, 54.79121160507202, 53.742103099823, 51.78433697564261, 43.027018547058105, 41.0690405028207, 40.435774735042024, 40.313948495047434, 42.429233755384175, 41.65179634094238, 39.943647725241526, 39.658264364515034, 40.03862265178135, 40.55713544573103, 40.50167145047869, 42.87490163530622, 47.54232277188982, 47.435119015829905, 47.26038571766445, 49.215028626578196, 50.08304623195103, 51.06915889467512, 51.48530387878418, 52.908215045928955, 55.60180582318987, 51.62988894326346, 46.61758702141898, 55.38194744927542, 55.23737628119332, 54.427421297345845, 53.37484564099993, 54.199405738285606, 53.83252348218645, 50.25028589793614, 46.229054178510395, 41.87170682634626, 40.4794476372855, 39.398109912872314, 41.30893053327288, 40.72190850121634, 41.588376658303396, 40.55920948301043, 41.51434012821743, 40.70753615243094, 40.16291897637503, 40.47613334655762, 39.87971387590681, 40.09020607812064, 40.22894423348563, 39.679220131465364, 40.764480113983154, 39.65728119441441, 42.75107431411743, 50.78813900266375, 52.7274819782802, 51.80556719643729, 53.13188450677054, 51.692363670894075, 52.13270575659615, 50.55603095463344, 50.502540247780935, 51.733893053872244, 53.3774790082659, 53.2878611428397, 51.084118366241455, 54.65885884421212, 53.63597978864397, 53.68344293321882, 55.41658074515206, 50.38909700938633, 44.034319741385325, 46.95824677603585, 46.39855548313686, 48.576433590480256, 50.53588465281895, 50.28564180646624, 51.3025176184518, 54.695600918361116, 54.98667137963431, 56.46148211615426, 40.55691310337612, 18.35949090548924, 21.91387837273734, 48.49095685141427, 53.85402120862688, 52.24323075158255, 57.810933453696116, 59.394667625427246, 60.222531591142925, 55.22892379760742, 27.715106555393763, 13.378839765276227, 26.77425445829119, 41.65551015308925, 31.514329433441162, 51.16751411982945, 20.494331870760234, 0.458071554345744, 0.09146153328141995, 0.12192118061440331, 0.05445440639076488, 0.07644722251487629, 0.04852698231115937, 0.04944344902677195, 0.0908586277759501, 0.01978863582813314, 0.12615462844925268, 0.046200645355773826, 0.10317888310445206, 0.045559663857732496, 0.05585578476477947, 0.04359041952661105, 0.035077237590615234, 0.207436596176454, 0.24950153327413968, 0.08881482601697956, 0.13890089520386287, 0.18997909793896334, 0.1804858637707574, 0.14921466819941998, 0.09810718667826482, 0.1853881435734885, 0.14953314539577278, 0.15303197050733225, 0.08259125532848494, 0.12855799948530539, 0.11416175269654819, 0.20725780219904014, 0.09779772042695965, 0.1791319828480482, 0.12189123007868018, 0.2286972424813679, 0.08594401220657996, 0.9969265567404884, 58.31494535718645, 74.56457928248814, 51.077156271253315, 55.30807420185634, 44.18957029070173, 42.643637793404714, 76.61178261893136, 65.39743873051235, 74.82282297951835, 70.18432371956962, 70.03436769757951, 69.36475590297154, 68.95941884177071, 60.62700707571847, 26.9844548361642, 1.3662563157933099, 5.781694190842765, 57.743539401463096, 73.45739078521729, 69.62400708879743, 69.09365109034947, 63.98374434879848, 59.73468467167446, 53.38752957752773, 51.334479331970215, 50.77569477898734, 61.62881919315883, 63.50350570678711, 61.300586291721885, 61.87918363298689, 61.664185523986816, 59.91888836451939, 63.940783636910574, 64.99130262647355, 62.803189822605674, 59.993247985839844, 62.3045106615339, 60.27214172908238, 57.57574387959072, 52.483666215624126, 51.74630948475429, 56.81131001881191, 57.007461139133994, 59.05016204289028, 57.39230448859078, 53.565914154052734, 46.2302805355617, 45.07965537479946, 44.59013393947056, 42.72802366529192, 45.03306770324707, 44.73947851998465, 42.75838729313442, 43.29520859037127, 43.13999278204781, 41.77977521078927, 43.19624539784023, 46.00857394082205, 50.49462277548653, 52.03765092577253, 48.694462639944895, 54.42939111164638, 54.630009923662456, 56.25364065170288, 54.81048590796334, 57.26073687417166, 57.22127458027431, 56.158339159829275, 50.906904561179026, 58.761603355407715, 57.93133878707886, 57.31105572836739, 56.631396838596885, 57.052568844386506, 56.23755209786551, 52.640507902417866, 50.247350284031455, 45.43283578327724, 44.058999742780415, 41.71390976224627, 44.52258355276925, 42.686900751931326, 43.1139474596296, 42.24638148716518, 43.77607951845442, 43.59803540366036, 42.8745333807809, 42.836332184927805, 41.42788716724941, 40.82689578192574, 42.633347511291504, 41.55564022064209, 42.75403772081648, 42.7728499685015, 46.262349946158274, 52.7068076133728, 56.77279615402222, 53.50558294568743, 55.30136571611677, 56.31250579016549, 55.73865059443882, 52.734322479793, 51.76889113017491, 55.54099866322109, 55.84820978982108, 56.22030666896275, 53.573682240077424, 57.14515706471035, 53.86694138390677, 56.59056574957711, 56.55605752127511, 52.930827958243235, 45.97555957521711, 50.16913788659232, 48.27337053843907, 50.66859524590628, 51.83923816680908, 53.422485964638845, 53.884318828582764, 59.64682470049177, 58.46344920567104, 61.18941511426653, 43.936245918273926, 20.19077375956944, 24.662592683519634, 50.82722609383719, 58.50103201184954, 54.727430616106304, 64.61038153512138, 64.05375439780099, 64.7624637058803, 60.68757452283587, 29.90645374570574, 12.173167501177106, 36.62935699735369, 49.243950503213064, 41.43883752822876, 56.75861835479736, 41.18656928198678, 0.5165089443325996, 0.17996261827647686, 0.22873016500047275, 0.1606104059943131, 0.1776322576084307, 0.1290799421923501, 0.16609477384814195, 0.18416266861770833, 0.09159397653170995, 0.21590556816330977, 0.20583880905594143, 0.23659074891890797, 0.10950637143105268, 0.16439839558941977, 0.1332932918199471, 0.13176163472235203], [0.041518577307994874, 0.049949697218835354, 0.04808800068816968, 0.011940236702295286, 0.06268424567367349, 0.03797756088897586, 0.021474640982757722, 0.04151459430743541, 0.025323440886235664, 0.005836109381302127, 0.06158111058175564, 0.07479209918528795, 0.04377893691084214, 0.0462148640570896, 0.002145248681439885, 0.02936299903584378, 0.06675864490015165, 0.09465037645506007, 0.1473993563226291, 0.03349134518897959, 0.4494877335216318, 6.196466905730111, 52.158615589141846, 45.688585077013286, 41.57748188291277, 39.586336612701416, 18.10244229861668, 52.579544407980784, 62.72732244219099, 67.41321536472866, 67.86597388131278, 62.21708147866385, 57.70608166285923, 59.79345253535679, 58.8387769971575, 30.47718572616577, 3.1071277984551022, 2.0375132049833025, 38.928807735443115, 74.00750051225934, 60.66654232570103, 64.39603655678886, 58.74264866965157, 55.56585236958095, 49.50665841783796, 51.65104273387364, 47.21305111476353, 54.35922472817557, 57.70528262002127, 61.57737473079136, 57.27317067555019, 57.94780254364014, 59.958097049168174, 56.07042360305786, 55.75248793193272, 54.63427611759731, 56.288492815835134, 54.71192223685128, 53.47973564692906, 47.729632309504915, 41.384801387786865, 44.34540101460048, 48.41271318708147, 46.98561225618635, 48.13643544060843, 46.25746536254883, 41.953584398542134, 40.486097063337056, 40.50739329201834, 38.734424931662424, 41.230610438755576, 38.77029153278896, 39.01763698032924, 38.58798817225865, 37.48829330716814, 38.871745654514854, 40.20584842136928, 39.801126275743755, 43.18958902359009, 48.25300189426967, 46.436273779187886, 48.30838598523821, 47.47450835364205, 49.4917163167681, 48.94800935472761, 48.46031876972744, 51.46939945220947, 52.21305125100272, 56.558121136256624, 45.18237059456961, 48.887893540518625, 54.361812932150706, 52.032714230673655, 54.70865658351353, 48.5043078150068, 48.581860133579795, 49.5123941557748, 43.82089539936611, 39.359203474862234, 38.790660176958355, 38.21509919847761, 37.679094314575195, 37.206616810389924, 38.47720609392439, 38.72807080405099, 38.90542704718453, 38.68702779497419, 37.24113546098982, 39.01773772920881, 39.07680089133126, 39.52629375457764, 38.11627844401768, 41.63837242126465, 39.83138220650809, 38.82781914302281, 39.016935212271555, 40.14438465663365, 42.98801136016846, 44.83626345225743, 46.38802548817226, 47.53528772081648, 50.692274706704275, 50.55563838141305, 50.72828722000122, 50.485433782849995, 48.17222213745117, 52.96150425502232, 52.283728327069966, 51.19364629473005, 51.855938162122456, 53.805154527936665, 52.43659217017037, 50.33357048034668, 43.471849169049946, 43.03805923461914, 43.170905317579, 45.082653522491455, 46.07516895021711, 45.269059794289724, 48.28353575297764, 49.31911611557007, 55.637516089848106, 56.40409346989223, 45.929986340659006, 17.97502623285566, 13.286391377449036, 47.335054533822195, 47.07281909670149, 50.14331143242972, 52.765634536743164, 55.483241762433735, 50.19610037122454, 49.7808621270316, 10.593442440032959, 12.60922862802233, 27.985858746937343, 31.810249737330846, 29.402160440172466, 53.886153153010774, 6.33035044159208, 0.23351356546793664, 0.1160168538668326, 0.10357644355722836, 0.10588961693325213, 0.050350864085235765, 0.05917638247566564, 0.049692749577973566, 0.13377461742077554, 0.011942677732024874, 0.06118709886712687, 0.045713684521615505, 0.05854391998478344, 0.077207853485431, 0.02893943033580269, 0.03628960664251021, 0.01685372251085937, 0.04095096240884491, 0.05408172103177224, 0.03058211611849921, 0.047618298392210684, 0.022136779202680503, 0.10368043583418642, 0.042981196860117574, 0.07826214762670652, 0.02900926855259708, 0.012861908629669674, 0.0254156436172447, 0.039793910924345255, 0.019886550127661655, 0.15976249506430967, 0.07832224547330822, 0.020115365706650273, 0.05250090067940099, 0.13424181592251572, 0.013654126253511225, 0.08684499814574208, 0.42131930217146873, 5.5883670789854865, 64.50153800419399, 47.504475934164866, 43.83307211739676, 41.06827620097569, 21.59841799736023, 63.465950693402974, 67.20495700836182, 73.19729886736188, 72.2398509979248, 67.2903642654419, 63.20077964237758, 64.4524837221418, 63.361178806849885, 34.545616558619905, 3.581695841891425, 2.915523622717176, 39.68838480540684, 74.70797620500836, 62.670757157461985, 68.3277997970581, 59.486731256757466, 58.40979521615164, 52.24937295913696, 53.7837575503758, 47.71528427941458, 57.8441493170602, 60.7143737248012, 63.14662538255964, 56.95532880510603, 60.54578263419015, 61.622260093688965, 58.01575592585972, 58.529936517987935, 55.567276750292095, 57.50439977645874, 56.010408537728445, 53.800669465746196, 49.26086589268276, 43.31327043260847, 44.38448115757534, 50.28471769605364, 50.320719787052695, 49.466219902038574, 49.39616468974522, 43.96875653948103, 41.530449526650564, 42.717128889901296, 40.77479818889073, 43.29492718832833, 41.77067654473441, 41.4214357648577, 39.49067381450108, 39.43223599025181, 39.55875226429531, 41.58727189472744, 41.04780680792672, 44.452229567936485, 49.228063447134836, 48.28208357947213, 48.34367935998099, 49.61849314825875, 51.24677569525582, 53.62629052570888, 52.17254325321743, 54.56656244822911, 55.50038991655622, 56.520632130759104, 46.60370799473354, 54.2546717098781, 57.091756684439524, 55.047902379717144, 57.378456728799, 51.6028812953404, 52.31452621732439, 52.454699175698416, 48.86603798185076, 42.92153099605015, 42.17021533421108, 40.90740803309849, 40.69063465935843, 40.822268281664165, 41.21565096718924, 41.79291078022548, 41.95234761919294, 41.05347653797695, 38.64336878912789, 40.953460693359375, 40.86619131905692, 40.920633929116384, 39.758499077388215, 41.664521966661724, 40.503589153289795, 40.54640742710659, 40.49193007605416, 43.21523829868862, 44.56017678124564, 48.176321574619834, 49.14851004736764, 51.839766229902, 52.42943205152239, 53.602350507463726, 53.676029205322266, 52.452701568603516, 51.49015372140067, 56.95876121520996, 54.89182499476841, 54.572940894535606, 54.212131364004954, 55.703124455043245, 56.16818128313337, 53.00790432521275, 46.029540130070274, 43.54171677998134, 45.861372879573274, 47.71807050704956, 48.65001848765782, 49.653640610831125, 51.581633704049246, 53.469306400844026, 58.57068770272391, 58.178326402391704, 47.81276055744716, 19.45483272416251, 16.543144941329956, 53.02043540137154, 51.17269400187901, 53.95595475605556, 59.01965945107596, 59.773337500435964, 56.56958566393171, 50.10367195946829, 17.43790963717869, 14.933424506868635, 32.849592549460276, 37.35288333892822, 32.12939786911011, 61.33563300541469, 6.137136237961905, 0.3467480593494007, 0.08078275594328131, 0.04724827967584133, 0.024745133971529346, 0.010190442470567567, 0.04312680708244443, 0.038182888978293965, 0.06487492990813085, 0.04369621331404362, 0.013320134353957005, 0.04522447434387036, 0.033432058191725185, 0.00823095632118306, 0.08627466232116733, 0.047441624836730104, 0.021095394190134745, 0.12968049996665545, 0.19870716173733982, 0.09924016374030284, 0.1263087780347892, 0.0970045333462102, 0.19398234598338604, 0.1053913618837084, 0.15203292268727506, 0.12475706344204289, 0.1402133447783334, 0.12102860850947243, 0.22062864686761582, 0.0952777024358511, 0.33861668567572323, 0.17781839333474636, 0.2494652723627431, 0.11967548754598413, 0.32037467882037163, 0.16128200638507093, 0.37336864375642365, 0.839201743049281, 18.577297823769705, 81.96036693028041, 60.71007973807198, 59.2853307723999, 53.42802367891584, 26.828559841428483, 62.61232280731201, 75.1615824018206, 76.66917473929269, 76.11149842398507, 71.68967178889683, 67.82119968959263, 69.34541906629289, 68.67281954629081, 38.37774610519409, 4.715671164648874, 3.4512158376829962, 42.370149748665945, 77.384338923863, 67.62844971248082, 72.58269596099854, 64.59972994668144, 62.10955115727016, 57.180089133126394, 56.3366368838719, 52.805218424115864, 60.25555637904576, 64.49609061649868, 68.39454419272286, 60.71647208077567, 62.681853430611746, 66.80832603999546, 61.855566705976216, 61.25269930703299, 58.24943774087088, 61.43749359675816, 61.216464451381135, 58.36120646340506, 51.63129595347813, 46.14978565488543, 47.22361585072109, 53.20159925733294, 53.049336433410645, 54.15267562866211, 52.13955668040684, 45.896499497549875, 45.436525276729036, 46.26881871904646, 43.52702481406075, 46.24108151027134, 42.73544086728777, 45.08828156335013, 44.12439271381923, 43.55570002964565, 43.145818846566335, 44.08585105623518, 43.66980334690639, 47.32612609863281, 53.22055046898978, 51.027594770704, 51.77402932303292, 54.1503757749285, 55.707626887730186, 55.60972329548427, 55.69101027079991, 59.09593677520752, 58.96923637390137, 60.36592851366316, 50.09927722385952, 55.93425628117153, 59.45966107504708, 59.8560905456543, 59.83664948599679, 54.78218936920166, 55.349801608494346, 56.255943979535786, 50.9408187185015, 44.78069175992693, 43.81965167181832, 43.07677807126726, 42.21550716672625, 42.29269470487322, 43.454680170331685, 44.31406116485596, 43.096031529562815, 42.95934656688145, 39.64467716217041, 42.34683506829398, 42.913175787244526, 43.77799722126552, 41.72123663766043, 43.767640931265696, 42.025300230298726, 42.11166981288365, 42.60808733531407, 44.69602796009609, 45.91148328781128, 49.376299789973665, 51.74965156827654, 53.05055931636265, 55.76484530312674, 53.27370766230992, 56.84333079201834, 56.41590540749686, 51.26568521772112, 57.47493941443307, 57.09347288949149, 57.44022274017334, 55.315018926348, 57.768400056021555, 57.86441721235003, 55.967406136649, 45.78973695210048, 46.92745583398001, 47.34511552538191, 50.29637329918997, 51.683397020612446, 52.23306206294468, 54.13843876974923, 57.98136234283447, 63.83049488067627, 63.9049448285784, 49.86263200214931, 23.20819401741028, 19.38959435054234, 57.115210328783306, 55.63425391060965, 59.85575703212193, 61.93727057320731, 64.90251854487828, 59.05207279750279, 58.63743904658726, 15.217109033039637, 17.69419915335519, 42.365775857652935, 44.00886501584734, 41.53700862612043, 69.31379086630685, 13.182306494031634, 0.8710017481020519, 0.3297596052289009, 0.2732708321085998, 0.2155544398618596, 0.20345766682709965, 0.18035209737718105, 0.12691777678472654, 0.18691548518836498, 0.1813181276832308, 0.08878457692584821, 0.10961241966911725, 0.22456571060631955, 0.14749705179461411, 0.1332598536142281, 0.1436006865863289, 0.0967724472284317], [0.008262129916277314, 0.023554162521447455, 0.01441336453094014, 0.021459077085767473, 0.05008514977193304, 0.06076882952558143, 0.014873976153986794, 0.010674510201040124, 0.09651865477540664, 0.12334599558796201, 0.02290134398000581, 0.10366335032241684, 0.03442154545336962, 0.04823312236528311, 0.06773108736212764, 0.07074613736144134, 0.03451771761423775, 0.22627579527241842, 0.12805706422243798, 0.21452286307300839, 0.04754400220034378, 0.8556720135467393, 38.89541121891567, 59.0978753226144, 40.63880109786987, 79.52384907858712, 21.135447365897043, 24.46388636316572, 87.61332402910504, 60.052092279706685, 71.90421826498849, 63.81083147866385, 57.14386122567313, 49.329156262534006, 66.06493827274868, 30.72129331316267, 5.121472452368055, 0.5161226136343819, 28.15339892251151, 70.36378874097551, 62.01504870823452, 64.39734976632255, 63.28472777775356, 57.9475975717817, 50.814403193337576, 48.778139795575825, 46.236099651881624, 53.274124554225374, 58.26511982509068, 59.35923876081194, 57.00125987189156, 59.47968578338623, 56.09716721943447, 55.444679260253906, 51.09479774747576, 48.546076910836355, 47.339112281799316, 43.33600146429879, 46.26577888216291, 41.47066375187465, 39.8861791746957, 41.639518874032156, 44.75624452318464, 45.25494452885219, 43.19090223312378, 42.28488145555769, 41.01310750416347, 41.30574131011963, 39.82468066896711, 41.76781388691494, 39.82670259475708, 38.88104234422956, 37.992996556418284, 37.401155948638916, 37.72039788109915, 37.94767345700945, 40.1352026121957, 42.94217756816319, 46.83955764770508, 51.21825681413923, 49.08188377107893, 47.63451841899327, 49.02429015295846, 48.716036796569824, 48.84929977144514, 49.588855607169016, 53.40773146493094, 51.446960244859966, 55.198792934417725, 50.99641472952706, 47.21806424004691, 54.49641343525478, 49.9126729284014, 51.146888392312185, 47.099965708596365, 48.70286648614066, 46.14594677516392, 43.004954542432515, 37.61750200816563, 37.97357634135655, 37.76406383514404, 37.88559825079781, 38.52127851758684, 36.02026401247297, 36.59830549785069, 38.00685821260725, 38.569815158843994, 38.48468235560826, 37.812204429081504, 37.21838011060442, 39.30757141113281, 39.893909045628135, 39.953354358673096, 42.455817563193186, 42.036292280469624, 40.33047825949532, 40.65319081715175, 42.60466882160732, 42.12251942498343, 43.29182481765747, 45.405911513737266, 48.97560065133231, 50.31532103674752, 54.35467365809849, 55.030101094927105, 50.01069811412266, 52.518129280635286, 51.11004556928362, 52.39628219604492, 51.072782380240305, 53.49279478618077, 54.01913472584316, 48.76496601104736, 45.31346573148455, 43.07373823438372, 44.60760171072823, 43.93384184156145, 47.87497125353132, 48.05630881445748, 49.43011358806065, 51.13839421953474, 56.990733351026265, 57.21665055411202, 51.7756586756025, 17.781524113246373, 13.778275200298854, 44.95825644901821, 48.94060604912894, 53.46864284787859, 50.17148290361677, 54.22853258677891, 45.95640686580113, 31.93382692337036, 6.1186405675751825, 34.52364635467529, 28.49263255936759, 29.57432290485927, 37.593780858176096, 41.260644027165, 0.8444289597017425, 0.0789469319528767, 0.02348429716325232, 0.08257054643971579, 0.018752580708158866, 0.06900587145771299, 0.07812034737850938, 0.0065272698162256605, 0.0389345632866025, 0.04132314904459885, 0.016028898734865443, 0.08788047651095049, 0.07304821668991021, 0.004884044174104929, 0.030024543537625244, 0.05727792291768959, 0.07753832718091351, 0.0418944857083261, 0.007197856221215001, 0.06387120019644499, 0.020389073162472675, 0.02339937850566847, 0.04335979565179773, 0.050202040999595604, 0.035280906661812744, 0.048606513400695155, 0.08024916278996638, 0.033761218921946626, 0.0934369047837598, 0.09101163063730512, 0.019229546721492494, 0.010184406901576688, 0.08123913859682423, 0.011740048515743442, 0.1720612815448216, 0.013394563708321323, 0.09995536679135901, 0.0701549637264439, 0.9324812548501151, 44.56740985597883, 69.22738306862968, 40.68176875795637, 80.48938465118408, 24.672344480242046, 36.388028689793174, 88.86704308646065, 67.60339450836182, 77.75413594927106, 68.68049035753522, 63.53147915431431, 54.29458563668387, 70.50303064073834, 35.11335039138794, 6.464326041085379, 0.5372534426195281, 30.79011869430542, 74.3522423335484, 64.32434504372733, 66.86900465829032, 66.07562460218156, 59.268807956150596, 51.15204048156738, 50.05888387135097, 47.76826081957136, 54.32178088596889, 62.07706832885742, 62.520981788635254, 57.64056709834507, 62.149336542402, 58.93088231767927, 56.45238692419869, 54.144945757729666, 51.84978553227016, 49.61373015812465, 45.51328897476196, 47.649832248687744, 42.0960259437561, 41.98091861179897, 42.942955766405376, 45.583632537296836, 47.88086680003575, 45.79712636130196, 44.30037668773106, 42.05623361042568, 42.1977093560355, 43.17158624104091, 43.03043358666556, 42.647421087537495, 40.80253887176514, 39.311517987932476, 40.15104103088379, 40.11170727866036, 39.33419343403408, 41.83356121608189, 43.28377880368914, 46.97038527897426, 53.18921756744385, 49.99842412131173, 49.447233949388774, 50.60361916678292, 50.2782107080732, 52.69046197618757, 52.49105562482561, 53.239637170519146, 54.95338256018502, 55.818874495370046, 50.96446343830654, 49.6499719619751, 57.132257734026226, 52.96292168753487, 54.384398051670615, 49.100147111075266, 52.487393924168174, 48.558458600725444, 46.39455679484776, 43.06309012004307, 43.585862159729004, 40.41716398511614, 41.16532516479492, 42.90214204788208, 39.438937527792795, 38.92147043773106, 41.471983909606934, 40.21734421593802, 40.51346254348755, 40.831915855407715, 39.6642815044948, 40.43781055722918, 40.3466362953186, 41.04316888536726, 42.570389883858816, 42.926603181021555, 41.960720198495046, 41.21725947516305, 44.43411908830915, 43.14306388582502, 45.43258564812796, 47.61962842941284, 48.949555328914094, 52.12026153291975, 56.282020568847656, 57.84702239717756, 52.487473828451975, 55.055594035557334, 52.70391716275896, 52.87741368157523, 54.20639215196882, 54.859019075121196, 56.61588151114327, 51.71560192108154, 47.542857783181326, 44.98031003134591, 47.220120906829834, 45.54604973111834, 50.87031534739903, 51.87411117553711, 52.21800184249878, 55.440708364759175, 59.02551678248814, 61.022449902125764, 53.43928323473249, 19.159106969833374, 15.686402525220599, 49.243599619184224, 52.62721599851336, 57.85500587735857, 56.1701545715332, 59.9991261618478, 50.94216666902815, 37.382555621010916, 11.821033665112086, 27.351144279752457, 35.5405638558524, 29.254090854099818, 42.49896935054234, 43.54710163388933, 0.6339787180934633, 0.12699078715273313, 0.049242813007107804, 0.052564961170511584, 0.031012595697705234, 0.0267878449854574, 0.09463860387248652, 0.06727614320282425, 0.12554443547768251, 0.05643791352797832, 0.051578384824097157, 0.04268552861841662, 0.008220186274099563, 0.02046127268113196, 0.05351765487076981, 0.03338507981970906, 0.01402529508673719, 0.10977664549968072, 0.10293431872768061, 0.12091090982513768, 0.0942172064845051, 0.10761273625705924, 0.13074274653834955, 0.18056928286595003, 0.06211843567767313, 0.1022367508017591, 0.23392847606113978, 0.13856827733772142, 0.15290687579129422, 0.14940315165690013, 0.132982590634908, 0.11068820301443338, 0.15780302163745674, 0.13406942731567792, 0.21608341219169752, 0.2933397266481604, 0.21958782843181066, 0.12587960463549408, 1.320786001426833, 62.70984772273472, 80.47471005575997, 55.66691739218575, 95.41457380567277, 30.039067064012798, 30.526041984558105, 99.81399250030518, 71.29604939052037, 82.52504702976772, 73.35673223223004, 67.02310180664062, 58.890992709568565, 76.75094808850969, 37.71251514979771, 8.662340027945381, 0.5687580949493817, 32.74809326444353, 75.02304227011544, 67.20346314566476, 70.7282634462629, 72.012193271092, 63.545896666390554, 55.64158426012312, 54.285045760018484, 51.76304769515991, 57.25623096738543, 65.41533729008266, 67.39751243591309, 59.447807448250906, 62.80236298697335, 62.39608097076416, 61.98042583465576, 56.94399976730347, 54.56167786461966, 52.433434213910786, 46.80153015681675, 50.799044200352256, 43.97760854448591, 43.78107179914202, 46.218513761247905, 49.5316024507795, 51.200337409973145, 48.136980874197825, 46.888090814862935, 47.37838002613613, 46.122892652239116, 44.534492765154155, 45.68998861312866, 44.71309968403408, 45.180626596723286, 41.04986000061035, 41.80915566853115, 42.23205082757132, 44.09994200297764, 45.208648681640625, 47.950289726257324, 50.19311611992972, 58.064431531088694, 52.611916065216064, 52.16812767301287, 53.84133379799979, 53.98979595729283, 54.70617260251726, 56.93419585909162, 57.987469809395925, 61.424660273960654, 56.35459450313023, 54.03910732269287, 52.3181323323931, 60.72758225032261, 54.765058585575645, 56.891971656254356, 53.00558362688337, 56.04566717147827, 51.974978174482075, 49.09249367032732, 43.488792351314, 46.30095761162894, 44.0756128856114, 43.02956853594099, 46.00829601287842, 41.11506189618792, 39.988425391060964, 42.994792801993235, 41.460116386413574, 42.73219953264509, 42.14201259613037, 38.7775593485151, 42.66963447843279, 43.17224631990705, 43.47202982221331, 44.22081633976528, 44.94244582312447, 45.16023710795811, 44.162441049303325, 47.891455854688374, 45.57007660184588, 48.56266573497227, 50.924841335841585, 52.02286515917097, 55.18448659351894, 59.30642550332205, 57.574138845716206, 55.70845719746181, 57.82387099947248, 56.233320644923616, 53.60272571018764, 57.56398057937622, 57.33090673174177, 58.09166499546596, 54.275620528629844, 50.12402670724051, 46.87875938415527, 49.207319600241526, 49.365762846810476, 53.41957466942923, 55.37923070362636, 55.37086854662214, 58.776034763881135, 62.812965938023154, 63.709624017987935, 56.38844960076468, 22.932272366115026, 17.09208389690944, 56.88223375592913, 56.850855691092356, 64.45193481445312, 60.33449486323765, 65.62639577048165, 53.62410879135132, 40.680879388536724, 9.080888220242091, 49.611037731170654, 42.20695740836007, 39.8924777167184, 47.51588487625122, 58.709193093436106, 2.2908595076629092, 0.26449816141809734, 0.1351270598492452, 0.13122945970722608, 0.1563649345189333, 0.07888903255973544, 0.15836087241768837, 0.20499027387372085, 0.30712492551122395, 0.10772550199180841, 0.08792323778782572, 0.11095192243478127, 0.12404821147876126, 0.1822168066033295, 0.1294095745044095, 0.15470584854483604, 0.1596554900918688], [0.028257584066263268, 0.014358878168942673, 0.04633266791435225, 0.00457620174191626, 0.026954538987151215, 0.020253573111923676, 0.005629250347348196, 0.04947085505617516, 0.0754857858909028, 0.03776670952460595, 0.07625234047217028, 0.08978095131793193, 0.09063306916505098, 0.009687174743573581, 0.04260029783472419, 0.08530823846480676, 0.04620807870690312, 0.04802868315683944, 0.3012075844619955, 0.00835553026159427, 0.15460309120161192, 0.19034195132553577, 16.681245599474224, 58.634235927036826, 36.0643572807312, 48.11111967904227, 37.78508560998099, 7.05717978307179, 47.507981300354004, 69.56335626329694, 62.02754851749965, 68.21837261744908, 60.23990903581892, 60.36902046203613, 61.57243456159319, 42.22156946999686, 9.511512381689888, 0.17127929707723005, 17.711102383477346, 70.499758039202, 58.250994137355256, 68.64144148145402, 59.324282373700825, 60.129474367414204, 49.006485394069124, 48.17211444037301, 44.404749052865164, 54.11906371797834, 59.419208662850515, 59.89163058144705, 58.43920694078718, 57.31278582981655, 59.94572230747768, 54.21890933173043, 49.29667690822056, 42.822258608681814, 41.88410241263253, 45.749159472329275, 47.82658052444458, 46.316493783678325, 44.28744609015328, 42.05912753513881, 42.42591251645769, 44.066236291612896, 43.13099486487252, 41.01271145684378, 41.61171565737043, 41.30657161985125, 45.775708539145334, 44.1439379964556, 41.47111538478306, 39.850159713200156, 40.062670367104666, 38.620203495025635, 37.57383605412075, 37.21907493046352, 39.58876153400966, 41.31455510003226, 53.75583968843733, 51.601717472076416, 49.04872349330357, 48.72384657178606, 45.843185969761436, 48.105689661843435, 50.02120379039219, 50.03684418542044, 51.659436157771516, 51.99069847379412, 53.392344679151265, 52.96903610229492, 46.95466497966221, 54.28253051212856, 49.97132614680699, 51.31740760803223, 47.59524720055716, 45.93474585669381, 46.95072535106114, 43.77191754749843, 39.18809018816267, 39.30585173198155, 38.87960754122053, 38.20691769463675, 39.28240156173706, 37.98670843669346, 37.1887321472168, 39.14762735366821, 39.04924780981881, 38.42564351218087, 39.29277522223336, 39.33043098449707, 39.90140962600708, 44.981637137276785, 50.53469998495919, 49.70628016335623, 48.098863056727815, 47.98847702571324, 45.91892828260149, 44.58586427143642, 40.65131132943289, 40.889936787741526, 43.330647877284456, 45.71679128919329, 49.47029849461147, 52.90260784966605, 52.43532759802682, 53.447395256587434, 53.78648819242205, 54.24707385471889, 50.49670376096453, 53.08677332741873, 52.980399881090435, 55.30368988854544, 52.49343190874372, 44.55673394884382, 42.828192370278494, 48.955499512808665, 53.08311857495989, 55.735054901668, 54.053688117435996, 54.78336361476353, 55.91803223746163, 59.994922501700266, 60.79912090301514, 50.35187898363386, 12.366452489580427, 15.864863531930105, 40.926466941833496, 52.121998582567485, 52.28220319747925, 55.73009736197335, 44.84955188206264, 55.938727446964805, 10.82298833983285, 15.410190786634173, 36.47053854806082, 35.02539314542498, 35.693570137023926, 46.69549022402082, 19.13984830038888, 0.04810843816293137, 0.07997968939266034, 0.11294679503355708, 0.09582951425441674, 0.03166545834392309, 0.038047762122005224, 0.05808710306882858, 0.11137970483728818, 0.06994339650762932, 0.030561916130994047, 0.09546543950481073, 0.019574859977832863, 0.008791773147614939, 0.028780768492392132, 0.08486822886126381, 0.04352746844025595, 0.05535118202013629, 0.013475842873698898, 0.022082296233358126, 0.0027345226304272986, 0.025920164937685643, 0.034013471100479364, 0.10446528371955667, 0.005249477690085769, 0.010870246349700859, 0.02011792717634567, 0.07701740906174694, 0.03587491318051304, 0.03986511638920222, 0.015963187707321982, 0.016669500253296325, 0.0558084230204778, 0.07499352909092392, 0.07377177250704595, 0.03683849397514548, 0.11103146709501743, 0.04414085731176393, 0.12223458236881665, 0.16968644969165325, 17.26930638722011, 69.45501300266811, 40.50377328055245, 58.13302067347935, 41.44033139092581, 12.573172688484192, 67.58305018288749, 69.75161075592041, 72.07283020019531, 73.76679406847272, 64.59935474395752, 63.242093631199424, 67.32035269056047, 45.336127281188965, 11.936252168246678, 0.2393687255680561, 19.2385196685791, 73.00022711072648, 60.769424302237375, 69.59873649052211, 63.19178867340088, 62.99206270490374, 52.96176481246948, 50.55640615735735, 47.20488698141915, 56.63980415889195, 60.54455975123814, 62.86941310337612, 60.27407332829067, 59.424774169921875, 61.7545051574707, 56.102222033909385, 50.94623136520386, 43.74489252907889, 43.33948598589216, 47.24622181483677, 47.886748450142996, 47.419614110674175, 45.50632687977382, 43.81220667702811, 44.70755502155849, 44.39272519520351, 44.39955527441842, 44.1552357673645, 41.25366803577968, 42.37693813868931, 45.58164187840053, 44.848148345947266, 41.85508326121739, 40.506093978881836, 42.08409241267613, 39.65563447134835, 39.65709359305245, 39.445524420057026, 41.06216526031494, 43.24922888619559, 53.141639777592246, 55.052269322531565, 52.07808596747262, 50.650991984776084, 48.73164592470442, 50.9737879208156, 53.07649694170271, 52.209747382572715, 56.06414590563093, 55.6775655065264, 56.9092309815543, 55.22983748572213, 51.399007252284456, 56.64827748707363, 54.208084038325715, 54.987508637564524, 51.912121295928955, 50.1842154775347, 51.94869661331177, 49.04687874657767, 43.077122007097515, 42.42169148581368, 40.75087554114205, 42.22923680714199, 43.12133339473179, 39.967896938323975, 39.974758284432546, 41.500051157815115, 40.346045698438374, 41.0920147214617, 41.2488876751491, 41.03124925068447, 40.96839237213135, 45.00908599581037, 50.09804391860962, 49.71891893659319, 48.97625378199986, 48.64036743981497, 48.71845129558018, 46.581174986703054, 42.32339184624808, 43.72532640184675, 45.43756750651768, 47.70108910969326, 52.74928542545864, 55.5477523122515, 53.663800375802175, 55.11720718656267, 54.40046228681292, 54.64521953037807, 51.45220266069685, 54.05051279067993, 55.60196910585676, 56.36608682359968, 54.35245370864868, 47.65011017663138, 46.19231557846069, 50.93519762584141, 56.7753461429051, 58.954895292009624, 57.67840698787144, 58.83041136605399, 58.744837352207725, 62.52297592163086, 63.560397556849885, 51.41131598608834, 15.227402789252144, 18.341640983309063, 46.657865728650776, 55.87384516852242, 58.61214760371617, 59.562320709228516, 53.90391274860927, 55.35863276890346, 21.279417514801025, 17.112317051206315, 32.71734053747994, 42.371633189065115, 34.85347734178816, 52.91363116673061, 18.83768504006522, 0.3496709167957306, 0.05486151722392865, 0.0942351808771491, 0.028992803900369575, 0.03571916903768267, 0.05208637685115848, 0.06336166789489132, 0.12688740555729183, 0.03736172250605055, 0.055316661551062546, 0.03084968961775303, 0.06387852837464639, 0.045785449777862856, 0.033766365610063076, 0.03253531988177981, 0.04505558358505368, 0.023926554414044534, 0.11995330692401954, 0.19756091253033706, 0.07759796362370253, 0.12474057504108974, 0.1352984442242554, 0.21303436080259935, 0.11826068774930068, 0.07161793950945139, 0.17452245019376278, 0.19149955920875072, 0.11381325711097036, 0.18567705021372863, 0.24260664039424487, 0.24148502200841904, 0.1967274815376316, 0.4019030768956457, 0.2670086052800928, 0.18360218512160437, 0.42179400527051514, 0.11784922411399228, 0.3937284126877785, 0.2878608820693833, 33.92232492991856, 77.08818585532052, 54.90972702843802, 60.07508386884417, 50.891500404902864, 9.981359992708478, 58.2863187789917, 80.66504205976213, 71.36282852717808, 78.76332010541643, 68.842223576137, 70.5570320401873, 70.32689380645752, 51.759233134133474, 13.49191301209586, 0.34656265644090517, 22.334716864994594, 75.4462639944894, 63.60276072365897, 73.73886231013707, 65.46573952266148, 68.2259600503104, 56.79552371161324, 54.55079698562622, 52.213693959372385, 61.45710836138044, 66.83898149217877, 67.0351082938058, 62.9521244594029, 61.37512656620571, 67.88853468213762, 60.0279472896031, 55.165643078940256, 46.286394187382285, 46.40580940246582, 51.657952717372346, 51.93826389312744, 51.91221162251064, 50.302824701581685, 48.34852920259748, 48.12036425726754, 47.36612687792097, 48.614763328007285, 47.23340586253575, 46.60526091711861, 46.0175336429051, 50.24192721503121, 47.962879862104145, 45.2017491204398, 43.70314427784511, 46.797458512442454, 44.173881258283345, 42.855224336896626, 42.306083883558, 43.470226764678955, 45.7217766216823, 58.09133495603289, 57.742518016270225, 56.44927760532924, 53.06494556154524, 52.24648250852312, 53.653649057660786, 58.15690858023507, 56.41844844818115, 57.754326479775564, 58.73747226170131, 59.230606760297505, 56.09396757398333, 54.4755653653826, 59.6002231325422, 56.354281834193635, 57.2138226372855, 55.71106277193342, 52.85830960954939, 54.27379315240042, 51.07791362489973, 45.02736323220389, 45.88301999228341, 44.322840213775635, 44.95328848702567, 44.38369948523385, 42.47888905661446, 41.73264557974679, 44.00304242542812, 41.93905224118914, 42.46339804785592, 42.59661933353969, 41.98014736175537, 42.589820521218435, 47.8275636945452, 54.45193454197475, 51.5958115032741, 52.30027198791504, 51.21648849759783, 52.19581971849714, 49.25999736785889, 44.388962745666504, 46.21892370496477, 46.91091564723423, 51.34841047014509, 55.73356451307024, 58.10113191604614, 54.94364813395909, 58.20541395459856, 56.853186811719624, 57.68492439814976, 55.039578437805176, 54.21332992826189, 56.84058625357491, 59.40308884211949, 58.26193755013602, 49.45680856704712, 47.48977354594639, 53.32661124638149, 58.0594288281032, 61.18774059840611, 58.91059357779366, 62.129492487226216, 61.673676763262065, 68.59126159123012, 67.35931818825858, 54.77541487557547, 17.715709039143153, 21.322505031313213, 51.32870537894112, 61.204048020499094, 62.13486344473702, 66.26462950025285, 56.61110462461199, 66.364440373012, 17.242547137396677, 22.19159960746765, 56.687934330531526, 46.30562680108206, 45.68643113545009, 57.47298002243042, 33.4698999268668, 0.5045234646115984, 0.28010348975658417, 0.29346720980746405, 0.1781333014369011, 0.10745967232755252, 0.18554299883544445, 0.1410307487738984, 0.18787302023598126, 0.13111793569156102, 0.18692617890025887, 0.11954560237271444, 0.13469528087547847, 0.1400650848767587, 0.14587927503245218, 0.17621832633657114, 0.17672606052032538, 0.19336781038769654], [0.0769928732354726, 0.08008370881101914, 0.010912750631437769, 0.03937264585069247, 0.030345707732651914, 0.050517563175942214, 0.03872769492279206, 0.0938908379258854, 0.04558375185089452, 0.028870881335543733, 0.015216487060700144, 0.022236230384026254, 0.06120306479611567, 0.035855829383113554, 0.025124652178159783, 0.04425992663683636, 0.0960295395925641, 0.13327213509806565, 0.04461566558373826, 0.10512686893343925, 0.13044921228928225, 0.07948618408824716, 1.971699433667319, 59.59475490025112, 43.52810525894165, 20.338926724025182, 36.24694204330444, 25.224858283996582, 10.398025223187037, 79.13506957462856, 58.66157014029366, 60.677068846566335, 65.17390823364258, 64.1576577595302, 58.29713017599923, 40.87645728247506, 11.81759170123509, 0.11321776120790414, 11.571635024888174, 59.016921860831125, 60.506893566676546, 68.60592229025704, 61.08947917393276, 61.581203188214985, 48.91182313646589, 46.777812480926514, 45.3252602985927, 51.77713516780308, 56.7839549609593, 60.44211551121303, 60.929934637887136, 59.27309499468122, 58.90482657296317, 57.84100873129708, 50.66952977861677, 49.5423652103969, 47.23570919036865, 50.90090479169573, 51.76209579195295, 52.58653776986258, 53.051601546151296, 48.75727435520717, 43.58588995252337, 41.6749129976545, 43.79895298821585, 40.496901512145996, 45.47404554912022, 45.12936973571777, 48.08321918760027, 43.68445014953613, 43.879538195473806, 40.195849963596885, 38.712565898895264, 37.61090121950422, 38.278240953172954, 36.951968806130544, 38.13923181806292, 42.531962871551514, 53.96769026347569, 49.61646427427019, 48.96803058896746, 51.086546761649, 49.21807541166033, 47.73336696624756, 47.01499966212681, 51.99038927895682, 51.0338898386274, 52.65671804973057, 53.883950574057444, 54.34625938960484, 45.707261834825786, 53.16267892292568, 50.0198905808585, 49.03797810418265, 47.27999700818743, 47.312097685677664, 46.0787160055978, 43.812411648886545, 40.20764453070504, 38.14872305733817, 37.716121264866416, 36.602359771728516, 37.11460529054914, 38.13854047230312, 36.35743577139718, 38.81067098890032, 40.393970898219514, 40.37843472617013, 39.50190210342407, 41.22257137298584, 45.37915052686419, 50.33479683739798, 51.19463293892996, 49.986646924700054, 49.6074663570949, 49.86251040867397, 50.27069970539638, 47.27558837618147, 43.63923822130476, 43.90665006637573, 41.48183992930821, 41.205520493643625, 46.41171884536743, 50.740519523620605, 52.78984553473336, 53.795437472207205, 52.80442632947649, 54.70822926930019, 56.67405530384609, 49.89119257245745, 56.62334735052926, 54.9637006350926, 52.06284509386335, 43.705454553876606, 43.87478215353829, 48.631004742213655, 56.7752697127206, 55.50077901567732, 59.58545821053641, 55.66133451461792, 59.15651117052351, 60.51573167528425, 67.25091239384243, 40.807357447487966, 11.859418988227844, 24.223235504967825, 46.53465679713658, 49.75747101647513, 53.355050223214285, 42.83647462299892, 55.89572504588536, 41.02411692483084, 4.155678927898407, 34.23939902441842, 36.597968510219026, 27.70952888897487, 36.982978616442, 44.28285333088466, 2.346264877489635, 0.060179209735776694, 0.06479721050709486, 0.08102932878370796, 0.04129402292892337, 0.06361774701092925, 0.04808645023565207, 0.08983381598123483, 0.03581399769921388, 0.09626398022685732, 0.03393868975607412, 0.06877694731312138, 0.06492231879383326, 0.054506175220012665, 0.05803153105080128, 0.11103399803063699, 0.01438809758318322, 0.0599523890497429, 0.06326474595282759, 0.018465913233480284, 0.0720205143360155, 0.03426966896014554, 0.01740086600849671, 0.04131128825247288, 0.0807762895045536, 0.08009153231978416, 0.04227208366085376, 0.0416317739124809, 0.07619511961404767, 0.02343887772544154, 0.05537512752094439, 0.04602363592545901, 0.08310280287904398, 0.044106608256697655, 0.06322986246751887, 0.05275619948016746, 0.16007696890405246, 0.0006976976957438247, 0.4141021322991167, 0.23196639705981525, 3.0282257923058102, 68.00106075831822, 52.497472286224365, 25.394760847091675, 46.87413535799299, 22.624512331826345, 25.34211434636797, 85.79737758636475, 65.4900929587228, 68.08754498617989, 68.97324575696672, 69.7879637309483, 63.43275914873396, 46.889841760907856, 15.339093344552175, 0.4855811010513987, 13.794347252164568, 62.75847121647426, 63.677071707589285, 73.25260652814592, 64.98926680428642, 63.90289510999407, 50.407440253666465, 50.72702612195696, 46.828423159463064, 53.03083338056292, 59.341319356645855, 61.953320911952424, 61.42105415889195, 60.97030367170061, 61.4179413659232, 59.77026639665876, 53.303247928619385, 50.39997441428048, 48.20383991513933, 52.782372747148784, 53.309921673366, 56.79408890860421, 53.49763420649937, 48.895380224500386, 44.332307134355815, 41.87771701812744, 44.10288803918021, 41.95177091870989, 45.3786050932748, 46.065385886601035, 49.14560570035662, 45.27694599969046, 45.35749299185616, 43.62626593453543, 40.8736606325422, 38.55339656557356, 39.78086532865252, 40.44817726952689, 40.12121588843209, 43.44184684753418, 56.86134052276611, 51.629593644823345, 52.240437575748985, 52.560044288635254, 51.970302036830354, 50.39561789376395, 50.728429658072336, 53.828701972961426, 54.39694997242519, 55.05337756020682, 56.1060574395316, 59.420452390398296, 49.4381422315325, 56.104650429316926, 54.67066730771746, 54.17551783152989, 50.354189259665354, 50.77758468900408, 50.066655431474956, 48.14056267057146, 43.391660009111675, 41.20867150170462, 41.639689104897634, 40.27643864495413, 40.463998317718506, 41.40276942934309, 39.793135847364155, 40.844367027282715, 40.738667556217735, 41.18219886507307, 40.02911056791033, 42.76769093104771, 46.718638147626606, 51.66343832015991, 53.02339880807059, 50.441020897456575, 51.57576247623989, 51.06375319617135, 51.35459089279175, 50.270195960998535, 46.121141706194194, 45.87777410234724, 42.09796449116298, 44.0568527494158, 48.61289426258632, 51.99915443147932, 52.73571559361049, 54.84175974982125, 54.499821526663645, 56.66548122678484, 57.77279131753104, 50.38626561846052, 57.621153831481934, 56.33143615722656, 53.59423501150948, 45.37625312805176, 46.2611791746957, 52.00125278745379, 59.33940165383475, 61.00375229971749, 63.58038057599749, 59.883167675563264, 62.402070317949565, 62.297152519226074, 66.27149432046073, 41.14354256221226, 14.875773566109793, 28.409174271992274, 53.0408387865339, 55.15463365827288, 58.5899133682251, 48.738462107522146, 61.19174970899309, 44.48325327464512, 12.371689694268362, 23.45305722100394, 42.04027707236153, 28.389592511313303, 39.81681183406285, 49.09300783702305, 0.5015938218150819, 0.06959537589656455, 0.035003457085362503, 0.060146728264434, 0.029415649960615804, 0.07210541263754879, 0.056041696574538946, 0.06373041096542563, 0.046762167010456324, 0.12067517318895885, 0.10971376565950257, 0.09966270785246577, 0.073291702196002, 0.053642145690641234, 0.012479022344840425, 0.07126511487045459, 0.005030303669627756, 0.0213569253350475, 0.10248069771166358, 0.3494578296584742, 0.20283158256539277, 0.1030052595638803, 0.0771883659596954, 0.1203799018902438, 0.09618237960551466, 0.15080431289970875, 0.1636941440935646, 0.15160373571727956, 0.1172916583184685, 0.1283315316374813, 0.10086787425513778, 0.09364129310207707, 0.21651399694383144, 0.1049291981118066, 0.1435650499271495, 0.342802703912769, 0.26289266613977297, 0.18435609181012425, 0.6191385058420045, 0.4203155588890825, 6.1176921384675165, 84.60437188829694, 60.09763077327183, 33.363262448992046, 51.84861476080758, 34.663937432425364, 15.479603290557861, 91.77821322849819, 68.30415507725307, 72.03354508536202, 72.90945584433419, 75.46122346605573, 68.35187530517578, 52.53645862851824, 16.65111994743347, 1.114554022039686, 16.831314529691422, 66.68937982831682, 65.20099925994873, 78.58484172821045, 69.19936793191093, 70.65925393785749, 55.130964619772776, 54.92709405081612, 49.835374219076975, 58.0138521194458, 63.801354135785786, 65.38630076817104, 64.05245508466447, 64.35502134050641, 64.61515494755336, 63.83166912623814, 55.034235273088726, 53.45028918130057, 51.15995100566319, 56.72806017739432, 55.48110866546631, 60.98121929168701, 58.41988400050572, 53.85087020056588, 47.36020353862217, 46.19066538129534, 47.41815498897007, 45.8075521332877, 50.923434325626914, 49.40341860907418, 52.17001410893032, 48.023857252938406, 48.90372848510742, 46.067400864192415, 42.051307337624685, 41.831921441214426, 44.25583873476301, 43.15089797973633, 43.18735865184239, 46.26860332489014, 61.54275185721261, 54.157181535448345, 57.0522665977478, 55.92692593165806, 56.3928165435791, 53.93059383119856, 54.582991463797434, 59.3111572265625, 58.42932660239083, 57.774281706128804, 60.86806092943464, 58.873260906764436, 49.86547034127371, 60.75160217285156, 57.10685511997768, 56.508462360927034, 54.55994776317051, 54.154308455330984, 52.60852534430367, 50.08162879943848, 46.048922130039756, 44.74873352050781, 45.12795925140381, 41.974602699279785, 42.82506915501186, 44.08575030735561, 42.324993406023296, 42.83321244376046, 43.986623832157676, 44.34471314293997, 42.050716740744456, 43.982284682137625, 48.93485641479492, 52.8830451965332, 54.75451816831316, 50.79531649180821, 53.070722988673616, 51.973758765629356, 55.384653772626606, 52.85556507110596, 48.17438302721296, 49.90894174575806, 44.74441868918282, 46.67935650689261, 51.952142919812886, 56.07841750553676, 57.10944332395281, 57.76896980830601, 59.441658292497905, 59.492380142211914, 58.79534380776541, 54.94969654083252, 58.89029788970947, 59.205079078674316, 55.14719908578055, 47.575562953948975, 48.772657666887554, 54.17108835492815, 62.88713100978306, 64.7208023071289, 66.21959127698625, 60.08768790108817, 65.09592860085624, 66.07178919655937, 71.21554756164551, 46.80457694189889, 19.37173400606428, 30.57780258996146, 56.369950022016255, 58.259672437395366, 62.93394102369036, 53.74591418675014, 66.22159930637905, 49.2532194001334, 6.628643121038165, 46.09591974530901, 54.722236837659565, 38.897669383457725, 46.1142178262983, 63.553213119506836, 6.453891149588993, 0.176716004631349, 0.1673273327095168, 0.21449739086840833, 0.11667549423873425, 0.18748350042317594, 0.12691226708037512, 0.19597962738147803, 0.15878886516605104, 0.13054047524929047, 0.12326690554618835, 0.14526145532727242, 0.13746785638587816, 0.11882364111287252, 0.09231283010116645, 0.15142275685710566, 0.17405772155949048, 0.12306296506098338], [0.14283728040754795, 0.018562804641468183, 0.01388979418801942, 0.04083553342414754, 0.05174446984061173, 0.03552110805841429, 0.051304222749812264, 0.043835139966436794, 0.027867718200598444, 0.052886848005333116, 0.018512462432097112, 0.04772326097424541, 0.018433435154812675, 0.05092302516901067, 0.033118178070123704, 0.10919112406138863, 0.06738155361797128, 0.09236680756189994, 0.06611917992787701, 0.18016144260764122, 0.05363659866686378, 0.2830469203846795, 0.09931345909301724, 26.627386910574778, 54.615585463387625, 40.341525895254954, 27.28200970377241, 46.704203265053884, 10.542146495410375, 31.734733240944998, 76.39126764025006, 58.05508272988455, 68.93621185847691, 59.494582721165244, 65.53593022482735, 44.912780489240376, 19.99740191868373, 0.31494249030947685, 12.04410992349897, 55.78476578848702, 66.21980667114258, 64.12141595567975, 63.20071710859026, 59.13329029083252, 52.45670025689261, 50.40030445371355, 44.74726745060512, 50.94793019975935, 54.765069007873535, 61.37724576677595, 63.32010105678013, 60.92962196895054, 60.16761997767857, 61.051590647016255, 54.221153599875315, 51.995558738708496, 50.078755719321116, 51.93310138157436, 56.22002526691982, 57.350486755371094, 55.23847757066999, 56.28251389094761, 49.167159012385774, 44.808425494602744, 42.510131631578716, 42.947089944567, 46.46209328515189, 49.67762579236712, 48.87812784739903, 48.25953320094517, 44.85583305358887, 42.70019612993513, 40.091064180646626, 38.608787604740684, 37.72574799401419, 38.622895921979634, 39.37864106042044, 47.36243043627058, 56.92691762106759, 49.46616431644985, 48.066331590924946, 57.11071831839425, 50.369652475629536, 51.408585344042095, 49.83583280018398, 50.804533277239116, 52.37967600141253, 54.948293004717144, 52.48494815826416, 57.58040959494454, 48.88229676655361, 49.217668942042756, 52.14732476643154, 49.393176964351106, 49.454189096178325, 48.10267761775425, 46.92112602506365, 45.64032288960048, 42.50558056150164, 38.55548449925014, 38.28078746795654, 38.255398750305176, 39.34175654820034, 38.763801915305, 39.08700084686279, 39.02800716672625, 38.23378637858799, 39.650374685014995, 41.96476752417428, 43.90479489735195, 51.45926897866385, 53.47873510633196, 51.2093631199428, 52.47651651927403, 48.72599009105137, 50.49303163800921, 47.55556951250349, 48.28919506072998, 46.18483236857823, 45.42258024215698, 41.18119485037667, 40.026046412331716, 40.47225972584316, 44.457770756312776, 45.67508125305176, 47.02629395893642, 49.35566711425781, 54.395727089473176, 55.76762110846383, 50.47172498703003, 54.327141421181814, 57.61674519947597, 53.00960315976824, 46.00642694745745, 45.817647865840364, 53.034981455121724, 56.641044412340435, 59.401699202401296, 59.5873133795602, 63.69880567278181, 63.016645431518555, 65.51282746451241, 59.257642201014924, 16.166882617133005, 4.775755277701786, 27.28233105795724, 49.263356821877615, 49.917189257485525, 53.74718918119158, 50.26039205278669, 54.53500720432827, 10.957719121660505, 12.039620518684387, 40.36353431429182, 28.07574585505894, 22.997420413153513, 47.82554176875523, 23.951284749167307, 0.009488530224189162, 0.08691823921565499, 0.027532347178618823, 0.09333180649472134, 0.07150776577847344, 0.06850813888013363, 0.12270477999533926, 0.018485701010961617, 0.06952221625085388, 0.035557145053254705, 0.035614918917417526, 0.008259107890938009, 0.04274030335779701, 0.009236503658550126, 0.028138933736564856, 0.07636369485408068, 0.05196932956044163, 0.04160374023818544, 0.038715101312845945, 0.00828663181580071, 0.044760827972952805, 0.010040979865672333, 0.06876507295029503, 0.04857177919309054, 0.0555956140825791, 0.044940239417233636, 0.0204574610106647, 0.01128438426115151, 0.022774568193459084, 0.11228595620819501, 0.06778939387628011, 0.0749232532190425, 0.0484842447830098, 0.04301116096654108, 0.03749838963683162, 0.029294137909476246, 0.018083406080092703, 0.09715838437633854, 0.05271350944946919, 0.1501519014792783, 0.13350517116487026, 28.622966868536814, 66.99947793143136, 36.454429149627686, 33.195393971034456, 38.775533948625835, 16.54462317058018, 56.80553606578282, 73.56207929338727, 65.1955657686506, 73.27641800471714, 66.30567250932965, 70.19828959873745, 54.38970994949341, 21.56643717629569, 0.8310971036553383, 14.252347316060748, 64.76697308676583, 66.20553507123674, 69.178863797869, 65.81344822474888, 61.69888482775007, 53.96609912599836, 53.142334597451345, 47.75476394380842, 52.375267369406565, 58.10418912342617, 63.57910210745675, 63.593172209603445, 61.45507948739188, 63.19518634251186, 62.75675501142229, 54.59775291170393, 53.78657157080514, 50.495765754154746, 52.451826095581055, 57.18650232042585, 57.98213011877877, 58.209944180079866, 58.14725753239223, 51.25980704171317, 44.93134954997471, 45.00198841094971, 45.90251316343035, 48.79386009488787, 51.21119049617222, 51.16771214348929, 50.90971858160836, 47.24419641494751, 45.78488710948399, 42.27360452924456, 41.23572431291853, 40.0847031048366, 39.691167558942524, 40.28216396059309, 46.27519021715437, 58.53633580889021, 51.59906326021467, 52.16781152997698, 59.471250670296804, 52.91093873977661, 53.58817618233817, 52.30123083932059, 55.79908602578299, 54.56980030877249, 58.24670362472534, 56.61911589758736, 60.59894330160958, 52.910049370356965, 55.022169726235525, 56.226091044289724, 52.54921899523054, 53.4222914150783, 50.52965906688145, 51.435117040361675, 49.76173373631069, 46.872492109026226, 40.45045280456543, 43.180684907095774, 41.90836552211216, 42.74846873964582, 42.23495864868164, 41.86287914003645, 42.51397745949881, 41.694871698107036, 40.78198610033308, 42.73997456686837, 43.94799532209124, 52.4500994682312, 53.06523738588606, 52.18053715569632, 52.43039437702724, 50.264491489955354, 52.289592606680735, 50.9174484525408, 50.996883732931956, 47.96467249734061, 47.86202328545706, 42.69267817905971, 41.68618297576904, 43.93940387453352, 46.046597957611084, 47.81450802939278, 48.10916028703962, 52.08504111426217, 56.16334186281477, 55.85658236912319, 52.48995433534895, 56.00526687077114, 57.97671399797712, 53.8425566809518, 47.24102108819144, 47.118618147713796, 53.78906944819859, 58.05953652518136, 63.42192690713065, 61.92683437892369, 65.07561901637486, 64.05099596296037, 66.26346220288957, 58.09268638065883, 17.10655004637582, 6.052844601018088, 32.151982988630024, 55.409639494759695, 56.27332142421177, 58.745018005371094, 55.20414652143206, 57.516170024871826, 21.732676301683696, 15.54362051827567, 27.143214225769043, 35.06608874457223, 22.72847475324358, 52.651037897382466, 24.0716483933585, 0.07647700341684477, 0.01585031849598246, 0.09901962628854172, 0.0657937206061823, 0.05580564781225153, 0.020573989222092286, 0.07911535791520562, 0.0394216326863638, 0.12615228071808815, 0.028474355648670877, 0.06066654037152018, 0.00889096818199115, 0.027271609919677888, 0.06124942230858973, 0.038227146424885304, 0.04043551328192864, 0.09173012458320175, 0.03014262898692063, 0.1612539557474, 0.10215863106506211, 0.10072199601147856, 0.10698089123304401, 0.16401913522609643, 0.1190302414553506, 0.16458482987114362, 0.11295594168560845, 0.0927026348986796, 0.1274079911942993, 0.10457455499895982, 0.202273908204266, 0.11511343877230372, 0.18319635332695075, 0.1238794598196234, 0.1459155630852495, 0.14489393361977168, 0.17364481942994253, 0.10280195690159287, 0.2191518425409283, 0.10988405080778257, 0.47745735411133083, 0.20182758143969945, 50.85156910760062, 71.19126360757011, 58.5564022064209, 38.264382771083284, 63.41763986860003, 12.215868524142675, 46.475117683410645, 86.11309678213937, 66.73341056278774, 81.03623567308698, 69.9546023777553, 75.43356963566372, 57.874842984335764, 25.425727231161936, 1.180996822459357, 16.906643424715313, 66.33588327680314, 71.0563712801252, 72.94696916852678, 68.83573395865304, 65.17383875165666, 58.668365478515625, 56.25827857426235, 52.34603977203369, 56.46692255565098, 60.11755820683071, 69.57616179330009, 67.18427222115653, 64.71300642830985, 66.37807968684605, 68.10770171029228, 58.84533609662737, 57.73044204711914, 54.945781230926514, 57.60405431474958, 61.09446103232247, 61.38987759181431, 60.71385955810547, 60.89670835222517, 53.682914870125906, 50.20264557429722, 49.493008681706016, 49.25010660716465, 51.8538293838501, 54.26506274087088, 54.658580916268484, 54.110774517059326, 49.43734666279384, 48.85260363987514, 45.86976282937186, 43.70496817997524, 42.56448738915579, 45.05486420222691, 43.31466702052525, 51.58153990336827, 63.45061601911272, 55.19481856482369, 52.22576992852347, 63.3725460597447, 55.89588138035366, 57.36925036566598, 57.3827611378261, 59.30071408408028, 60.90240587506975, 62.378891127450125, 58.70064680916922, 62.35583005632673, 51.85087987354824, 58.7991236277989, 59.2123121534075, 56.19480330603463, 57.03124829701015, 55.25625453676496, 54.47805629457746, 54.19371516363961, 49.7782496043614, 43.89721441268921, 45.6419974054609, 42.78838266645159, 44.533377579280305, 44.59615455354963, 43.44661678586687, 43.38941921506609, 41.52468599591936, 42.97157539640154, 43.97327634266445, 45.55533947263445, 55.93536799294608, 55.3842716217041, 53.647336619240896, 55.916673864637104, 52.05380201339722, 55.24013124193464, 52.73237698418753, 51.88610029220581, 49.71406214577811, 51.624688216618125, 44.612854548863, 43.386643409729004, 46.06402403967721, 48.41494008472988, 51.23453644343785, 52.0444393157959, 54.21588339124407, 58.93443284715925, 60.0697546005249, 54.96009104592459, 59.200062479291645, 60.50856113433838, 57.96078872680664, 48.20444440841675, 49.49369307926723, 57.05717202595302, 60.75463853563581, 64.02227905818394, 64.39238180433, 67.83408164978027, 67.49075726100376, 67.7780374799456, 64.53462532588414, 21.17536129270281, 7.8942540202822, 35.49486207962036, 61.28078392573765, 59.620372908455984, 65.3360652923584, 57.34212112426758, 64.86472729274205, 17.34189942904881, 17.516066449029104, 59.39932986668178, 39.78102513722011, 35.58303124564034, 57.860838890075684, 40.81207874843052, 0.21590524246650084, 0.19229256308504514, 0.19439751441989625, 0.2159675998347146, 0.09823578263499907, 0.14942419981317862, 0.10632748236613614, 0.09118997678160667, 0.19585935026407242, 0.10707589970635516, 0.13453163179968083, 0.10836783716721193, 0.16286380722054414, 0.09530466063214199, 0.14249981780137333, 0.1810830288699695, 0.11162977213306086, 0.12964140277888092], [0.15636929071375302, 0.04720881947183183, 0.059310338859047206, 0.01757631141559354, 0.019879104902169535, 0.013793975713529756, 0.07008976329650198, 0.03250061620825103, 0.014229988745812858, 0.024307182025430456, 0.04526060972628849, 0.03804098016449383, 0.030725303970809494, 0.10554003569164447, 0.0268593608800854, 0.040946036244609525, 0.1347574211124863, 0.019659403744818907, 0.014355583881427134, 0.08130577073565551, 0.022118565626442432, 0.21461272825087818, 0.3875080921820232, 4.294628569058009, 67.27718353271484, 39.02906329291207, 47.98765019008091, 56.44660602297102, 40.11571291514805, 6.917198768683842, 69.8682084764753, 72.99903202056885, 65.56776687077114, 68.6180191040039, 59.340075629098074, 50.714877196720664, 26.629386254719325, 1.4630175807646342, 7.125272129263196, 54.54030520575387, 65.29313237326485, 67.32623781476701, 65.2560567855835, 56.72106681551252, 50.918032101222444, 47.741249697549, 49.447817598070415, 47.64739343098232, 53.942767075129915, 60.28113269805908, 62.384491375514436, 61.53172506604876, 61.488993644714355, 60.73328672136579, 58.10427597590855, 54.58012185777937, 50.6444467817034, 53.47389221191406, 57.30100168500628, 57.75554241452898, 57.74463026864188, 55.99095358167376, 55.9065329687936, 49.827362946101594, 45.17555093765259, 47.2232962335859, 50.99801628930228, 50.39134475163051, 48.732201780591694, 47.57390580858503, 42.35395349775042, 40.6709052494594, 38.97292879649571, 40.03890405382429, 39.4878945350647, 39.42457560130528, 40.19775724411011, 47.55105318341936, 55.28022582190377, 48.42157908848354, 47.87722246987479, 55.04275376456124, 52.35274478367397, 55.899612562997, 50.416410378047395, 52.3833064351763, 52.01370048522949, 54.06920344488961, 52.25022758756365, 55.06150695255825, 56.31893982206072, 49.335152557918, 52.06355728421892, 49.60086209433419, 47.245304652622764, 47.18748869214739, 46.069707666124614, 46.320447308676584, 44.40386315754482, 40.58070026125227, 37.83743681226458, 40.522609846932546, 37.91941860743931, 38.37566859381539, 39.75100197110857, 40.18442365101406, 41.006951400211875, 41.83966868264334, 43.69853414808001, 53.08639465059553, 54.7072217805045, 56.405563013894216, 52.171167509896414, 50.846354484558105, 50.30997092383248, 50.942524501255576, 49.58656964983259, 46.579048837934224, 43.15934004102434, 44.74109050205776, 40.531038011823384, 40.346827370779856, 43.40349279131208, 44.398936884743826, 43.03360196522304, 45.22052662713187, 47.770991461617605, 52.17550318581717, 55.81448323386056, 54.17709159851074, 53.513955524989534, 61.61916119711739, 53.06293058395386, 48.67320810045515, 45.66249459130423, 50.96385894502912, 55.6337571144104, 62.279128892081125, 61.637601716177805, 60.921951157706125, 62.841856547764365, 55.40708603177752, 17.08631862912859, 0.7813916993992669, 5.95648090328489, 31.185384341648646, 42.93315533229283, 55.12121977124895, 53.637491021837505, 64.25314685276577, 34.500692980630056, 5.657474730695997, 33.43443284715925, 38.74139744894845, 28.26163101196289, 33.482378891536165, 52.89997100830078, 7.688503095081874, 0.14776396032954964, 0.1436938223029886, 0.01775580258773906, 0.02366763902162867, 0.10347513827894415, 0.03652525167646153, 0.0792627085798553, 0.04722915177366563, 0.1304837225803307, 0.047706172069800754, 0.018900123058951328, 0.04536398792905467, 0.038442136852868965, 0.03612463103075113, 0.04377154087913888, 0.03284168183537466, 0.017902791932491318, 0.05693397351673671, 0.027564382513186762, 0.017516028668199266, 0.015994980465620756, 0.020845479564741254, 0.017264354940769926, 0.02614696866034397, 0.03394021645986608, 0.04677405833665814, 0.052761135822428126, 0.04050066960709436, 0.059932161920836995, 0.030953848135790656, 0.035086818505078554, 0.0840876286051103, 0.011234936021667506, 0.07511685961591345, 0.07680293771305255, 0.121433164658291, 0.0289106095608856, 0.12182410939463548, 0.04938520018809608, 0.28742238559893196, 0.3369358187275273, 6.3527392745018005, 77.39985425131661, 46.01720707757132, 42.0519118309021, 52.54482773372105, 24.99154646056039, 20.34522874014718, 77.99795518602643, 75.05721351078579, 73.69608225141252, 73.78938961029053, 66.17944458552769, 55.07821389607021, 31.251374857766287, 1.7712085119315555, 9.408411536897932, 58.77663230895996, 71.29604244232178, 70.76464421408517, 66.60213824680874, 58.7151893888201, 53.22711999075753, 50.638620717184885, 51.329712867736816, 51.345902170453755, 56.952942098890034, 61.886701583862305, 65.53252560751778, 62.84545571463448, 62.64275591714041, 64.0032479422433, 59.08495167323521, 56.669000489371165, 51.74134152276175, 56.8763382094247, 59.732614108494346, 60.84150491441999, 60.15740612574986, 58.726556641714915, 56.19833646501814, 50.41262708391462, 47.410567556108745, 49.90479367119925, 52.688391413007466, 54.28558771950858, 51.44238485608782, 48.08099576405117, 45.41271032605852, 44.92830276489258, 42.00085299355643, 42.15431090763637, 41.64537273134504, 41.93911477497646, 42.65177065985543, 48.70447499411446, 57.87370000566755, 52.83919511522566, 51.893211773463655, 57.228584085192, 55.45678997039795, 56.491401059286936, 53.42473718098232, 53.86446782520839, 54.60442665645054, 57.371539797101704, 55.816626753125874, 58.42002296447754, 60.662234442574636, 53.54267937796456, 56.511363233838765, 52.83799655096871, 52.91242912837437, 50.32691758019583, 51.09291478565761, 49.67613887786865, 48.391079970768516, 43.57941770553589, 42.004813466753276, 43.78552212033953, 42.67226437159947, 41.417850494384766, 43.11286006655012, 43.877179282052175, 42.18714462007795, 41.475826263427734, 45.51290682383946, 53.35840620313372, 55.94724941253662, 58.00103964124407, 53.14854976109096, 52.02401508603777, 51.44440678187779, 52.50553914478847, 50.32820299693516, 48.98872579847063, 44.29337985174996, 46.91272565296718, 41.08055714198521, 42.417362758091514, 45.13609906605312, 46.21339641298567, 45.83661992209298, 47.22807659421648, 50.27642502103533, 55.046867098127095, 58.14314072472708, 56.612720080784385, 54.814581871032715, 62.01199150085449, 54.629005908966064, 51.187483242579866, 47.082275594983784, 52.755139282771516, 57.665240151541575, 63.039755140032085, 65.43828024183, 62.81789915902274, 62.01741804395403, 56.88232408251081, 16.78906774520874, 1.7847878975527627, 7.63218447140285, 35.733880111149375, 49.59468167168753, 60.39332526070731, 57.97917366027832, 66.61851515088762, 42.3545823097229, 15.55438675199236, 25.239036083221436, 37.102199281964985, 34.75770337241036, 32.64026417051043, 61.38497216360909, 6.3591320514678955, 0.33099592317427906, 0.1534076617764575, 0.04047162152294602, 0.019287049171647856, 0.043541731246347935, 0.07744416009102549, 0.08122909627854824, 0.059267665791724405, 0.04653232345091445, 0.06610792981726782, 0.02938853230859552, 0.03907878251214113, 0.08676607095237289, 0.029210464363651614, 0.05766510857003076, 0.09368187628154244, 0.055636838477637084, 0.019446248754060695, 0.18118415772914886, 0.10162678174674511, 0.15785042409385952, 0.09188370419932262, 0.07737661871526923, 0.13296224815504892, 0.14004519023001194, 0.09452157693782023, 0.21148731453078135, 0.17901625191526754, 0.14731686003506184, 0.09212239924818277, 0.08922128884920053, 0.2031698865549905, 0.10101130977272987, 0.09029109430100236, 0.18337860783295973, 0.17456947267055511, 0.0748152711561748, 0.24464533956987516, 0.07842584419995546, 0.49975786890302387, 0.5740072961364473, 11.101026586123876, 90.67271314348493, 56.14768409729004, 66.52785505567277, 79.69460800715855, 51.0710904938834, 10.050190585000173, 84.25086838858468, 81.14040306636265, 78.32206085750035, 77.4739637374878, 71.10501561846051, 61.612011500767295, 34.49333136422293, 2.1586059757641385, 10.83596931185041, 61.964778491428916, 73.80267456599644, 76.1206978389195, 71.96474402291435, 62.34082194737026, 56.306870801108225, 53.30883775438581, 55.86162676130022, 54.448919023786274, 60.04113497052874, 67.45487676348004, 70.13613796234131, 65.83521693093437, 65.2969330378941, 65.17031601497105, 62.34280218396868, 59.81128856113979, 54.512845924922395, 61.03796522957938, 64.29861586434501, 62.35906791687012, 62.811861174447195, 61.66967460087368, 60.78307056427002, 53.82513754708426, 51.14425502504621, 53.830553667885916, 58.410962513514924, 56.554598399571006, 55.190114634377615, 51.50451217378889, 47.8247184072222, 47.921211515154155, 45.189756529671804, 46.557776927948, 45.000664779118125, 45.30755281448364, 45.91498517990112, 53.71859386989048, 61.09207780020577, 55.35026018960135, 52.73214769363403, 62.0357334954398, 59.23203114100865, 61.010436466761995, 57.19256462369646, 57.983335631234304, 58.24884019579206, 60.284127371651785, 59.36148302895682, 58.77970341273716, 59.474571909223286, 56.21194103785923, 59.488127844674246, 55.92714479991368, 54.55077961512974, 53.759129660470144, 53.73388338088989, 53.42665488379342, 52.169454778943745, 47.48339857373919, 43.67235680988857, 45.756698267800466, 43.347052574157715, 44.6864846093314, 44.230432646615164, 44.99386249269758, 43.67564330782209, 43.46859393801008, 46.3946783883231, 53.98960835593087, 57.301463740212576, 59.62393038613455, 55.465009689331055, 53.96684953144619, 52.42621156147548, 54.9195830481393, 54.32633195604597, 50.31432744434902, 47.217445850372314, 49.501634870256694, 44.251315457480295, 45.01196602412632, 48.99961709976196, 49.985757555280415, 48.19540132795061, 49.53597634179251, 54.54685040882656, 57.913242203848704, 61.10564068385533, 59.73135648454939, 59.12145056043352, 65.74303518022809, 55.814663887023926, 53.802100794655935, 50.674695764269146, 55.96560307911464, 60.25971835000174, 65.31616565159389, 67.41723837171281, 64.38644804273332, 64.60496888841901, 64.22030966622489, 19.74337751524789, 2.6989337248461585, 8.646875074931554, 38.658970969063894, 52.357549462999614, 65.70709214891706, 64.2318228312901, 72.00809383392334, 44.17288071768624, 9.512485129492623, 47.08252573013306, 57.69666337966919, 43.10875368118286, 44.677497114454, 69.87105028969901, 14.95434205872672, 0.6814918028456824, 0.2922111600637436, 0.16631878539919853, 0.12703369770731243, 0.2165966560798032, 0.12315509654581547, 0.16136781392352922, 0.21337008635912622, 0.31255803682974403, 0.07459537152733121, 0.10667881422809192, 0.2007155032562358, 0.18598477941538605, 0.125216472361769, 0.10245572762297732, 0.19658786617219448, 0.09353264607489109, 0.18382680735417775], [0.013825004271763777, 0.02499907909493361, 0.044407711563897986, 0.04051281199125307, 0.004993528767954558, 0.031643558626196215, 0.0425720741706235, 0.05217330397239753, 0.052540191249655824, 0.030002494542194263, 0.05925488219197307, 0.02020769057396267, 0.06722363816308123, 0.051535844071102996, 0.07795740397913115, 0.05003052091758166, 0.2661312595009804, 0.010601601613286351, 0.04167010435568435, 0.040408304027680836, 0.3436055736882346, 0.05585731486124652, 0.14592920163912432, 0.35546215889709337, 52.1983071735927, 49.81383827754429, 61.83222075871059, 67.15328325544084, 61.72019495282854, 16.235007967267716, 17.109245947429113, 81.65994766780308, 57.49337298529488, 67.91988495418003, 60.23445469992501, 60.70236723763602, 35.196732248578755, 4.839772939682007, 0.697786414197513, 42.50827298845564, 76.36713654654366, 66.07198374611991, 65.31019020080566, 58.261624881199424, 57.43780129296439, 55.70451062066214, 51.074950218200684, 48.84905311039516, 50.90040452139718, 56.63872023991176, 62.81067998068673, 62.81342451913016, 64.96761621747697, 61.337898118155344, 60.709996359688894, 52.70647757393973, 51.52384901046753, 48.86902570724487, 56.356599058423726, 58.929291180201936, 60.54330907549177, 58.50417954581124, 56.91022457395281, 51.884165218898225, 47.25645651136126, 47.10305070877075, 52.535836764744346, 53.28737129483904, 52.54455327987671, 50.71185820443289, 44.10176937920706, 42.08030564444405, 39.809394632067, 39.023143427712576, 39.49783740724836, 39.339911801474436, 39.754958970206125, 48.12276833398001, 54.781456334250315, 53.813179697309224, 46.427432196480886, 53.150634220668245, 54.246271337781636, 54.19580657141549, 54.82818644387381, 52.80227933611189, 52.09377152579171, 51.34682628086635, 53.77853945323399, 53.32331085205078, 55.49434150968279, 54.21190554755074, 48.989337239946636, 49.42839738300869, 47.85871941702706, 48.242874894823345, 47.02354942049299, 47.65821525028774, 45.58929531914847, 41.93063449859619, 40.873327119009836, 40.734373569488525, 39.475457259586875, 37.82809148515974, 39.524181502205984, 40.834625652858186, 41.80253056117466, 43.963437693459646, 48.92805412837437, 50.39903988157, 53.62740223748343, 54.09730543409075, 52.54270853315081, 50.28363377707345, 47.98900508880615, 46.34717355455671, 44.44843932560512, 43.90948840550014, 42.0406105858939, 40.547751903533936, 44.31117418834141, 45.45541742869786, 47.79671369280134, 48.2774213382176, 45.666468960898264, 46.046445097242085, 49.135527338300435, 53.47463566916329, 56.14871937888009, 53.20592451095581, 52.10118872778756, 58.37281690325056, 57.21838412966047, 49.895820072719026, 48.44901057652065, 48.956218651362825, 58.98933056422642, 61.96030385153634, 63.25505896977016, 62.78243555341448, 60.812308583940776, 13.455489686557225, 0.2850602152092116, 0.8938394997801099, 11.298319816589355, 38.97600337437221, 48.13086993353707, 53.732007367270334, 57.9377623966762, 53.24946887152535, 9.889318074498858, 14.237664035388402, 39.71705307279314, 38.719058990478516, 25.744868414742605, 38.7947735105242, 43.66123969214303, 1.055290122117315, 0.05442001823601978, 0.05491282804203885, 0.032041000335344245, 0.09627489106995718, 0.07435572652944497, 0.06821993113096271, 0.025877315451257994, 0.11135921986507517, 0.027167096867093017, 0.0660878587514162, 0.019456443742715886, 0.026063598758940185, 0.029258409648069313, 0.03061454669971551, 0.06121494594429221, 0.046669530017035346, 0.051147545621331246, 0.11217569426766463, 0.04628836636298469, 0.026881774588088905, 0.09378052170255355, 0.08012773894837924, 0.07618635294160672, 0.055215305382651944, 0.07806662776108299, 0.023925840255937407, 0.01068069165506001, 0.025876633523564254, 0.03584433839257274, 0.029664282154824053, 0.0509447993577591, 0.03271387976461223, 0.05214794033340045, 0.06720621338380234, 0.14094063932342188, 0.055081433816147704, 0.10253699576216084, 0.06056275165506771, 0.2359279559126922, 0.04564718808978796, 0.12689125963619777, 0.7837837796126093, 61.31539290291922, 59.052705083574565, 60.26172637939453, 79.46408067430768, 35.516286849975586, 16.506922245025635, 38.747821058545796, 83.15167726789201, 65.1039537702288, 73.8203021458217, 65.34154742104667, 63.658242089407786, 42.19633708681379, 5.329839374337878, 0.9740792512893677, 44.05811384746006, 77.1200989314488, 68.59801524026054, 69.50936876024518, 61.67738710130964, 61.59992858341762, 57.9877963747297, 55.12744535718645, 50.4037264415196, 53.57970632825579, 59.95678383963448, 64.55498354775565, 64.22221347263881, 64.60573319026402, 61.67410060337612, 62.07480321611677, 54.88638802937099, 52.798298018319265, 50.33896228245327, 57.75675140108381, 60.299323081970215, 60.63164847237723, 60.07099832807268, 59.207385880606516, 55.34973907470703, 49.36650630405971, 50.34392329624721, 54.797114099775044, 55.70942299706595, 55.241239479609895, 51.220052923474995, 44.8279846736363, 42.001134395599365, 42.041816098349436, 42.35514858790806, 42.7019053867885, 41.80481651851109, 41.62837396349226, 49.98070968900408, 56.365207876477925, 56.746674401419504, 50.727449962071006, 54.042609214782715, 56.05987971169608, 57.58859804698399, 58.991289956229075, 57.21109199523926, 57.81723199571882, 56.3815187726702, 59.01207201821463, 56.93737465994698, 61.74880068642752, 58.93380750928606, 53.21234464645386, 54.361656597682405, 52.44070897783552, 51.79756981985909, 52.07147823061262, 50.66436031886509, 50.40410164424351, 44.911151136670796, 44.347450733184814, 43.22857189178467, 43.33485501153128, 41.002080712999614, 42.59393038068499, 41.512134075164795, 43.188685757773264, 44.712686266217915, 48.697505950927734, 52.19535766329084, 53.98318474633353, 53.42830508095877, 55.30316877365112, 53.03631550925118, 51.143174580165315, 48.20443398611886, 48.193101474217, 44.96376984460013, 44.22146947043282, 42.683381489345, 46.638911042894634, 46.7332432610648, 50.175054277692524, 50.792690072740825, 48.402099813733784, 47.00699881144932, 52.47982038770403, 55.5608948298863, 57.25553962162563, 54.87737968989781, 55.190781661442344, 59.12489686693464, 58.743072509765625, 52.21454511369978, 48.72172737121582, 50.19599267414638, 60.35565907614571, 62.22201469966343, 64.18487385341099, 64.50219113486153, 61.527160099574495, 13.891988549913679, 0.4440494381955692, 1.9126215066228593, 12.562101602554321, 44.037199769701274, 52.40031215122768, 58.75839328765869, 61.687997000558035, 60.32171712602888, 19.194638320377894, 17.643666642052786, 27.12780659539359, 44.51890100751604, 28.328759295599802, 42.963261876787456, 49.030394145420615, 0.5327858594911439, 0.1330549224678959, 0.04081417992711067, 0.025395742185147743, 0.06534762454352208, 0.07681460173002311, 0.04520619800314307, 0.030775084692452635, 0.028113441175914237, 0.03311255301481911, 0.06315105062510286, 0.04614878153162343, 0.00926446439033108, 0.05195016433883991, 0.1600518902497632, 0.07597588494952236, 0.061672251405460496, 0.015103470267994063, 0.0747796752090965, 0.10216551819550139, 0.12220817378589086, 0.26794034242630005, 0.28273417002388407, 0.12926603720656463, 0.14744822441467217, 0.13242858036288194, 0.10075569206050464, 0.12785080314746924, 0.08191597727792603, 0.10179752151348762, 0.09606221783906221, 0.19017832939113888, 0.15199387978230203, 0.16437570537839616, 0.1758719884923526, 0.35625455209187096, 0.0884862250781485, 0.22541088025484765, 0.12560006177851132, 0.31346336539302555, 0.163638707782541, 0.2062357791832515, 1.4423210684742247, 83.8301271711077, 63.729732104710166, 81.9207205091204, 82.92993940625871, 84.90633365086147, 17.377303974969045, 25.754813023975917, 93.59905815124512, 67.64455563681466, 77.82026890345982, 71.10360513414655, 70.13203852517265, 45.90883255004883, 6.937378508704049, 1.2597103587218692, 47.864941528865266, 82.17067500523159, 73.17229230063302, 72.01361070360456, 66.79138633183071, 64.55981949397496, 60.723844119480674, 58.84310572487967, 54.44842570168631, 57.65365055629185, 63.08270195552281, 68.24057906014579, 68.31566824231828, 69.06523990631104, 65.82165404728481, 66.35385131835938, 57.209143025534495, 57.0129154750279, 53.70580571038382, 60.679973193577354, 64.94894640786308, 64.11641325269426, 64.33915165492466, 62.413722446986604, 57.7414618900844, 52.92944179262434, 53.70250184195382, 59.78664330073765, 58.55581855773926, 57.90314647129604, 53.61728566033499, 49.34702008111136, 46.33093908854893, 45.07857492991856, 44.9658716746739, 45.62021827697754, 45.00546945844378, 44.35873808179583, 53.28005484172276, 59.57243728637695, 57.462658473423545, 51.59112841742379, 57.71875517708914, 58.77192143031529, 60.693313734872, 62.78592354910714, 60.13972296033587, 59.84466770717076, 58.94352109091622, 61.37807955060686, 58.34742818559919, 62.09168039049421, 60.671795163835796, 54.241233893803184, 57.05765145165579, 54.95972626549857, 53.372542313167024, 55.48816456113543, 54.21153034482683, 51.0285883631025, 45.52980831691197, 47.28068835394723, 45.29684911455427, 44.348993233272004, 42.109929289136616, 44.13436337879726, 43.199420724596294, 43.99387080328805, 45.30646889550345, 51.861552306583945, 54.36879587173462, 55.306496960776194, 55.19872692653111, 55.3734324319022, 53.809670857020784, 53.40177685873849, 50.52919353757586, 51.42854751859392, 49.001135281154085, 46.356324332101, 45.91824735913958, 50.069149834769114, 48.85397243499756, 53.68650361469814, 54.334978989192415, 50.216951915196006, 49.86012370245797, 56.1527875491551, 58.179511070251465, 61.09862300327846, 56.44647053309849, 57.878032207489014, 61.38117844717843, 61.47707053593227, 53.847583702632356, 51.62926360539028, 53.4185220173427, 63.62558555603027, 64.19513634272984, 67.98833860669816, 65.3917134148734, 67.52103751046317, 17.3928279876709, 0.8651171667235238, 2.595653312546866, 14.278225013187953, 48.06878777912685, 57.90265314919608, 62.80700438363211, 66.23710073743547, 64.96546922411237, 16.014279331479752, 18.221763713019236, 60.250873293195454, 50.171632289886475, 41.47387381962368, 50.00626516342163, 69.2757842200143, 2.540779479912349, 0.6346201236758913, 0.19766030433986867, 0.1529105534510953, 0.13699132124228136, 0.22317269178373472, 0.175965585612825, 0.16801136386181625, 0.19997001040194715, 0.14060775004327297, 0.16090593513633522, 0.14675864284592016, 0.08432837961507694, 0.1275907206748213, 0.2694256012993199, 0.16474005154200963, 0.1379014809748956, 0.12929891901356833, 0.23110034210341318], [0.043762499400015385, 0.022007138302017535, 0.022097256234181777, 0.039607693773827383, 0.015928694379648993, 0.030321514566562006, 0.019706465237374817, 0.06490149455411093, 0.045917465551091094, 0.06444445372159992, 0.050843436403998306, 0.04113363082121525, 0.04546482162550092, 0.05117715010419488, 0.08843373360910586, 0.09835770859250001, 0.049339884226875644, 0.022429728215294223, 0.05453091460679259, 0.01497936960575836, 0.10502998770347663, 0.0898302129602858, 0.2728607255433287, 0.26646045755062786, 14.69774682181222, 64.34942804064069, 37.545226846422466, 47.21331514630999, 37.87818104880196, 56.21543598175049, 5.177633873053959, 51.15921449661255, 71.12884099142892, 63.76974678039551, 69.4368017741612, 60.593468121119905, 43.31897490365164, 10.37215621130807, 0.9865386741501945, 28.25805790083749, 72.3938786642892, 68.0715641294207, 69.51977716173444, 61.70997415270124, 66.39416476658413, 61.31901291438511, 60.87958799089704, 50.88581330435616, 51.69543824877058, 56.13272115162441, 62.476666178022114, 61.95890726361956, 63.89369569505964, 65.06479372297014, 61.18601049695696, 59.13405459267752, 50.65754413604736, 49.74505458559309, 55.128074169158936, 58.75751086643764, 59.50944491795131, 59.832181794302805, 58.44269493647984, 53.63476732798985, 51.145026275089805, 51.626487800053184, 53.4722489629473, 54.50785711833409, 52.3813922064645, 50.97187369210379, 42.509016445704866, 40.40142284120832, 40.99025140489851, 40.30711841583252, 39.95785331726074, 39.25411197117397, 40.38994789123535, 45.62515844617571, 50.51277494430542, 57.699609415871755, 51.85241542543684, 45.81558772495815, 56.9776394707816, 51.79196957179478, 52.58462701525007, 54.024662017822266, 55.493393080575125, 51.668757166181294, 54.52457101004464, 55.2858121735709, 55.39684438705444, 52.09224987030029, 50.22805513654436, 48.59649998801095, 49.261324473789756, 48.59877552304949, 48.872687407902305, 48.98592567443848, 47.91719545636858, 44.64279086249215, 39.47555453436715, 38.41244888305664, 40.2814621925354, 39.04186882291521, 39.96235922404698, 41.08747754778181, 42.01206043788365, 45.14830010277884, 52.604808058057515, 53.0190874508449, 53.55861159733364, 53.09411062513079, 52.01962382452828, 47.953565801892964, 45.359098025730674, 42.7463321685791, 44.127773012433735, 44.77068982805525, 46.55999340329851, 50.05389853886196, 51.48861469541277, 50.81734575544085, 50.66687209265572, 51.47857454844883, 47.899491446358816, 51.28663751057216, 52.90646062578474, 54.401101521083284, 59.98714746747698, 56.72217852728707, 50.03877231052944, 58.68870980398995, 58.46858392442976, 53.568863664354595, 47.81430305753435, 51.12461246762957, 53.80616896493094, 61.77714238848005, 59.59006486620222, 65.80166407993862, 31.73126608984811, 0.08455279150179454, 0.2155310304037162, 1.5194519353764397, 16.53046100480216, 39.236407961164204, 55.386133738926475, 47.28859192984444, 60.38797514779227, 22.31633540562221, 6.544686300413949, 35.20402090890067, 44.05083908353533, 29.81793369565691, 32.91939762660435, 57.282974583762034, 20.18684455326625, 0.324856131204537, 0.06589575191693646, 0.028860197801675116, 0.049097080648477585, 0.03737637546977826, 0.009501591175129371, 0.12557475242231572, 0.0159187504489507, 0.05202937651691692, 0.04920743079856038, 0.05090905074030161, 0.033999422032918246, 0.06404497301472084, 0.04396724055654236, 0.01818830080862556, 0.04887084350255983, 0.053590085091335435, 0.09752351085522346, 0.06727532896080188, 0.010460822560292269, 0.014357551632981216, 0.03342563925044877, 0.043845711542027335, 0.03116592425586922, 0.031655005511960814, 0.05736020885940109, 0.07346869805561644, 0.053131900927317996, 0.09262081036078078, 0.027586219466424415, 0.01755059154571167, 0.012643082782493105, 0.0136954303764339, 0.03160000007067408, 0.03762263957677143, 0.03413472870098693, 0.010267875190558178, 0.08101435351584639, 0.04111396348369973, 0.07193713595292398, 0.08172395865299872, 0.187500640217747, 0.13707023486495018, 17.033388989312307, 75.83587033408028, 39.92447417122977, 50.404765197208945, 41.76142154421125, 29.088815791266306, 14.281723431178502, 66.40775544302804, 75.13276127406529, 70.13863931383405, 73.64503383636475, 66.47937052590507, 48.838773250579834, 12.848024317196437, 1.3578161001205444, 30.13426433290754, 73.81117221287319, 69.60240513937813, 73.29039778028215, 65.13449805123466, 68.36747401101249, 64.3654783793858, 63.03573213304792, 54.01105397088187, 53.92504569462368, 59.83783067975725, 63.76241643088204, 64.74691363743374, 66.12505408695766, 67.29464435577393, 62.0759288242885, 59.91954844338553, 51.89842987060547, 51.539048194885254, 57.68506336212158, 60.42237567901611, 61.43422794342041, 61.47377708980015, 60.122956957135884, 56.241140842437744, 53.01187522070748, 53.29284300122942, 55.170239312308176, 58.50449916294643, 55.42895201274327, 52.08956439154488, 45.15283727645874, 43.08488661902291, 43.45864759172712, 42.59823131561279, 42.686164242880686, 40.92548377173287, 41.94496168409075, 48.49091168812343, 52.743758133479524, 62.36498778206961, 56.15630333764212, 48.83070639201573, 59.07322311401367, 52.99796492712838, 56.51286404473441, 55.56354556764875, 60.155182702200754, 56.914053031376426, 58.58112389700753, 58.98079817635672, 58.6666909626552, 56.880437646593364, 54.68895844050816, 53.18632364273071, 51.16353975023542, 51.10430288314819, 53.04232570103237, 53.75595433371407, 52.192109380449565, 47.68758528573172, 41.67504848752703, 42.090512548174175, 42.07401752471924, 41.77647829055786, 42.6115266936166, 43.744222027914866, 43.03299399784633, 47.64790759767805, 52.02476896558489, 52.914294719696045, 54.4360613822937, 53.72187689372471, 52.01919303621565, 49.047837597983225, 45.06069721494402, 44.73170348576137, 46.318543502262656, 46.688024384634836, 48.73087120056152, 51.5753664289202, 53.611098289489746, 53.70542355946132, 53.45766816820417, 52.96877554484776, 50.84189721516201, 53.9177257674081, 56.4462377684457, 56.85184233529227, 60.905032294137136, 57.359345708574565, 55.70398255756923, 59.4186041695731, 58.411761556352886, 54.93863500867571, 48.41777842385428, 52.828533104487825, 55.86060537610735, 64.52755900791713, 62.910740988595144, 67.43888201032365, 34.464162826538086, 0.07677478529512882, 0.7349018454551697, 2.6276936275618414, 19.942353078297206, 44.47988339832851, 60.30602809361049, 50.888905252729145, 66.79782731192452, 29.79704393659319, 15.411915676934377, 25.60463465963091, 40.20447267804827, 38.50797619138445, 32.43249566214425, 66.22881153651646, 18.627885920660837, 0.3677959442138672, 0.08407596458813973, 0.03462022729218006, 0.018061796436086297, 0.05613753625324794, 0.008659315478455807, 0.06822399555572442, 0.07585107521819216, 0.04559707149331059, 0.020912355976179242, 0.15043092864964688, 0.01725443815147238, 0.04469411440991929, 0.06969528339271035, 0.04048013713743005, 0.05094932857900858, 0.0742813590914011, 0.028137585148215294, 0.02454305436861302, 0.10109596380165645, 0.08376505305724484, 0.08957191503473691, 0.10215860392366137, 0.14412051226411546, 0.1601047616984163, 0.12302698913429465, 0.19031019588666304, 0.10082088570509638, 0.2072997899459941, 0.12375725566276483, 0.14236017529453548, 0.13725067089710916, 0.09274973879967417, 0.158602132328919, 0.14226626604795456, 0.18443016069275991, 0.1297632540975298, 0.1721267330327204, 0.11675238582704749, 0.17438003926404885, 0.19739781985325472, 0.448223595640489, 0.2890348019344466, 29.685688631875173, 85.83718381609235, 50.18315240315029, 59.703139850071494, 60.62363025120327, 72.16078049795968, 6.773605125291007, 65.58123247964042, 79.14866025107247, 75.67180946895054, 80.62919630323137, 74.00904301234654, 53.77076094491141, 15.316789627075195, 1.7335820623806544, 33.35435485839844, 76.7979734965733, 74.7479908806937, 78.0047435760498, 69.07525226048061, 72.0987330845424, 69.02474580492292, 66.39690930502755, 57.17252949305943, 57.19630970273699, 63.195533752441406, 69.07837200164795, 67.76480810982841, 69.17685576847622, 70.4731672831944, 65.7185149874006, 65.27771432059151, 54.77655438014439, 54.68688440322876, 58.841799463544575, 64.71844686780656, 63.4809171131679, 63.80896936144148, 63.02205807822091, 60.96905994415283, 56.464205810001914, 58.08753081730434, 60.47072124481201, 61.348111970084055, 57.47754846300398, 55.60185446058001, 47.3846994127546, 45.90401744842529, 47.92911509105137, 44.7420563016619, 45.90149525233677, 43.762089320591514, 46.596259525844026, 52.18659251076834, 55.61911031178066, 63.404542514256065, 56.41759034565517, 50.943219321114675, 61.06145708901541, 55.794211864471436, 58.82722214290074, 58.17152411597115, 63.631116322108674, 57.16844742638724, 61.30025972638811, 62.187065260750906, 61.48952170780727, 59.183331217084614, 55.838801928928916, 57.04686784744263, 54.41038431440081, 54.26314851215908, 56.37337895802089, 57.015607901981895, 53.725910323006765, 50.78680842263358, 43.971660886492046, 43.612505027226035, 45.45560155596052, 44.23230518613543, 44.524563789367676, 45.068718910217285, 44.89046287536621, 48.63956144877842, 55.21143865585327, 55.371917724609375, 56.34939725058419, 56.97595453262329, 55.019254956926616, 50.703096526009695, 47.411185945783345, 48.65588971546718, 49.687655517033164, 50.20559508459908, 50.94134330749512, 55.247395583561485, 56.88582597460066, 55.339031900678364, 55.99702630724226, 55.811842918395996, 53.41850812094552, 57.533995628356934, 59.768070765904014, 60.532212802342, 65.24651690891811, 60.028065408979145, 57.934868471963064, 60.899035998753135, 59.65008340563093, 58.034366675785606, 49.707242488861084, 54.33988094329834, 58.759817668369834, 67.03747762952531, 65.54261439187187, 67.87678527832031, 36.77449444362095, 0.22473461154316152, 0.6310714398111615, 3.1669602564402988, 22.094314404896327, 48.54257501874651, 65.7758515221732, 55.19931057521275, 71.45973505292619, 29.55668142863682, 9.572480218751089, 47.01774072647095, 64.72761154174805, 44.00836474554879, 45.16915512084961, 69.70362649645124, 35.287920406886506, 0.4269498943218163, 0.18108225534004824, 0.08776891178318433, 0.1420228076832635, 0.11696387162165982, 0.062067274137267044, 0.2745080185788018, 0.14047190733253956, 0.148330170661211, 0.2663866329405989, 0.19291738527161734, 0.05958067399582692, 0.17290696687996387, 0.12797091741647038, 0.14266624887074741, 0.15279394042279038, 0.1418637726455927, 0.17462181486189365, 0.13832764167870792], [0.025303413925160254, 0.04221145316426243, 0.055478017178497145, 0.023645357627953802, 0.02111333974504045, 0.04276240663602948, 0.046427415151681216, 0.053883195256016085, 0.05217500709529434, 0.06459248970661845, 0.03391576884314418, 0.06010927991675479, 0.02214168161819024, 0.049213313697172065, 0.058405641333333085, 0.07109439545976264, 0.06505541343774114, 0.07571922907871859, 0.05519606212952307, 0.011826076578082783, 0.04605498085064547, 0.043782757062997134, 0.06361104987029519, 0.05099105169730527, 0.488648350749697, 49.01005329404558, 50.803296497889924, 39.73885651997158, 40.22310774666922, 51.81461027690342, 24.913943767547607, 10.248035328728811, 69.77284445081438, 61.91507107870919, 59.35591752188546, 61.934206417628694, 58.39123657771519, 19.936499220984324, 0.7248266860842705, 6.20570410149438, 55.82020507540022, 75.47889968327114, 68.77763312203544, 69.74888706207275, 66.74165112631661, 67.45118032182965, 63.692788532802034, 55.22346598761422, 50.156068325042725, 56.26652608598982, 62.15935584477016, 65.79618195125035, 66.14311245509556, 64.88260500771659, 65.12053912026542, 59.78965881892613, 53.843383516584126, 49.98714372089931, 54.28823845727103, 60.32956164223807, 63.63079670497349, 60.74076298304966, 58.56981222970145, 54.40043101991926, 55.97212396349226, 55.88375677381243, 57.062765325818745, 57.68693937574114, 54.866992133004324, 51.70512751170567, 45.86758804321289, 42.99510894502912, 43.325315134865896, 41.059524944850374, 41.64150605882917, 42.266440936497276, 40.936010292598176, 41.08519853864397, 50.53543996810913, 53.37761797223772, 58.920612880161826, 48.421728474753245, 47.45181901114327, 54.702160017830984, 54.60909932000296, 55.058244773319785, 53.35292754854475, 54.527742862701416, 53.96215602329799, 55.76466812406267, 54.1149434362139, 51.58456931795393, 51.508934702192036, 50.27376038687569, 49.539589405059814, 50.058380126953125, 49.96314811706543, 47.88608489717756, 50.563319614955354, 48.57036781311035, 39.26214061464582, 40.27188410077776, 39.35503108160836, 38.5476781981332, 40.79983949661255, 40.97626468113491, 41.94428423472813, 47.10711193084717, 50.48740012305123, 51.459130014692036, 49.186721665518625, 51.23251451764788, 49.6328307560512, 47.03548642567226, 41.38334574018206, 43.44035645893642, 47.95452465329851, 52.094952719552175, 54.427327496664866, 55.056049142565044, 52.8856577192034, 53.957285336085725, 52.3331995010376, 51.977420466286794, 49.81794466291155, 50.28223718915667, 52.40680524281093, 59.02975518362862, 55.6160044670105, 57.0305951663426, 49.89440611430577, 59.88926819392613, 57.070661953517366, 57.16498374938965, 48.4047019141061, 53.206956318446565, 53.80239609309605, 64.49202592032296, 58.313472339085166, 68.39444691794259, 16.25824100630624, 0.3249696636838572, 0.48855726420879364, 3.550718818392072, 13.03680600438799, 35.91057627541678, 57.100410665784565, 55.68478121076311, 50.88189104625157, 9.858144981520516, 13.037327987807137, 40.100836821964805, 36.08273179190499, 26.8256641796657, 43.926452432359966, 50.624394280569895, 3.072385068450655, 0.20999028986053808, 0.03710640674190862, 0.06816594688487904, 0.04875751119107008, 0.046807326908622465, 0.06980300082692079, 0.12753476867718355, 0.0189978321016367, 0.05219545474808131, 0.027959785224603753, 0.0380300014678921, 0.08482472119586808, 0.03888130507298878, 0.015600839829338449, 0.02259861727777336, 0.026358074475345866, 0.058541382263813696, 0.05802558029868773, 0.05507758652259197, 0.037361413772617064, 0.0749812408217362, 0.02231742049168263, 0.014006299498890127, 0.016939884583864893, 0.0770880174157875, 0.05270284627165113, 0.049769189940499406, 0.03623863848458443, 0.052815215063414404, 0.05908668014620032, 0.04808714912672128, 0.0075839061755687, 0.07051634469202586, 0.12165940180420876, 0.022088791509824138, 0.03159002560589995, 0.07600783037820033, 0.06291640643030405, 0.043057392950036695, 0.02774796525149473, 0.014705916600567954, 0.05056669589664255, 0.09404067881405354, 0.8576832456248147, 53.64035715375628, 59.5750150680542, 36.333481856754844, 48.32372760772705, 33.595332281930105, 24.69769671985081, 28.662931169782365, 74.94286700657436, 70.05544853210449, 70.37970706394741, 67.72158336639404, 65.21559047698975, 24.329132999692643, 0.7420696179781641, 7.520994186401367, 57.10627147129604, 77.5377482005528, 71.10279914311, 72.38618006025041, 68.57003484453473, 69.02317551204136, 64.7244153703962, 57.67125381742205, 51.83437442779541, 58.28052050726754, 62.962074279785156, 65.12752900804792, 68.43552466801235, 64.4265113558088, 66.83026845114571, 61.50318186623709, 54.65009021759033, 50.54751246316092, 57.431308201381135, 62.56182329995291, 62.8710389818464, 61.06256880078997, 62.830162729535786, 56.8484377179827, 56.96376044409615, 57.87436703273228, 57.929441928863525, 57.483635084969656, 58.512072699410574, 54.16988631657192, 47.44459635870797, 43.74320411682129, 44.16347633089338, 44.58840731212071, 44.087740966251914, 44.61080483027867, 41.84633200509207, 45.26267439978463, 53.292255878448486, 56.676400320870535, 62.91167899540493, 51.29725783211844, 51.21483482633318, 57.929011140550884, 57.32341309956142, 57.470899036952424, 57.43319116319929, 58.173115253448486, 57.54791981833321, 60.270251819065635, 56.486099583762034, 56.99613904953003, 54.47695847920009, 54.39537967954363, 54.28067881720406, 53.45865828650338, 53.825887952532085, 53.45290865216936, 53.07684435163225, 50.35196236201695, 42.55699028287615, 42.56955262592861, 42.64275884628296, 42.19430821282523, 42.977342401232036, 43.897554874420166, 43.654704911368235, 48.096941879817415, 52.74807643890381, 52.528471674237935, 52.13658285140991, 52.38197932924543, 51.28972945894514, 48.7720080103193, 42.9300251688276, 45.91356427328927, 49.49725750514439, 53.41722617830549, 55.957345145089285, 56.50890357153756, 55.35409906932286, 56.20891509737287, 54.90303243909563, 56.21662064961025, 52.683183738163535, 53.62917750222342, 54.8570944241115, 61.23757307870047, 58.190899167742046, 58.03289713178362, 55.29229484285627, 62.55616051810128, 58.59510367257254, 58.22647047042847, 49.74617671966553, 53.575544357299805, 55.66333906991141, 65.91317571912492, 58.396746499197825, 71.18082741328648, 18.630140611103602, 0.2293883982513632, 0.7195366642304829, 4.49142804316112, 17.260485649108887, 41.712398529052734, 62.61766597202846, 57.96697609765189, 57.89902966363089, 19.319573879241943, 18.58742482321603, 24.611273288726807, 38.92707068579537, 28.309450251715525, 45.76745407921927, 54.00904941558838, 2.205159123454775, 0.15565077641180583, 0.07934314890631608, 0.06202584957437856, 0.024413830766986524, 0.08033013915909187, 0.052292882198733945, 0.07218404127550976, 0.05262563577187913, 0.07920010015368462, 0.01801394614657121, 0.011654857595983361, 0.0939538941851684, 0.05149595978270684, 0.045856234551008256, 0.023691618449187705, 0.029013953836900846, 0.03512464004701801, 0.03525540731581194, 0.017142488355083123, 0.23515296035579272, 0.17527096931423458, 0.07732813060283661, 0.1026141791205321, 0.1310151376362358, 0.12871167409632886, 0.0853679088343467, 0.1840288479413305, 0.11441049006368433, 0.1319389087813241, 0.1694723176104682, 0.17903576658240386, 0.14471972653908388, 0.13004162987428053, 0.20638501617525304, 0.14171851186880044, 0.19076937410448278, 0.17911193892359734, 0.14275973742561682, 0.14617742331964628, 0.1848008715148483, 0.08533820257123027, 0.1585923885660512, 0.14554363090012754, 1.8508174972874778, 74.5662954875401, 62.16717256818499, 54.38468640191214, 57.112886156354634, 76.53030804225376, 26.780443566186086, 18.306193011147634, 79.5316241128104, 72.1972654887608, 68.59323487962995, 75.39827973502022, 71.23727457863944, 27.434069292885916, 1.1976449234145028, 8.469648241996765, 64.28866604396275, 81.68387031555176, 74.62783568246024, 76.65765462602887, 72.3298649106707, 72.15959930419922, 69.84372997283936, 60.30905055999756, 56.09500980377197, 61.660058294023784, 66.7651777267456, 70.26583303724016, 71.42527198791504, 69.36326204027448, 71.50744138445172, 66.65333257402692, 58.206230367933, 54.641158308301655, 61.09749044690813, 65.75558362688336, 69.10103007725307, 64.65141759599958, 65.41638646806989, 59.72080911908831, 62.06454767499651, 62.60181018284389, 63.10520717075893, 63.768405778067454, 61.20556272779192, 56.74357897894723, 49.11392191478184, 48.13516392026629, 47.01618780408587, 46.98831857953753, 44.98025097165789, 47.305479526519775, 44.1061988558088, 47.14206484385899, 56.13818938391549, 59.336136000497, 59.61954607282366, 56.00410999570574, 52.704347951071604, 60.614819935389924, 59.77540806361607, 62.72549506596157, 59.42772715432303, 59.19221796308245, 58.46239307948521, 63.60415036337716, 58.44584247044155, 58.38021673474993, 56.58474315915789, 57.03617109571184, 55.671920095171245, 57.04061794281006, 56.83496863501412, 56.23611034665789, 55.388958181653706, 53.20440980366298, 45.53761461802891, 44.158831460135325, 44.541534764426096, 43.90585797173636, 44.85715668542044, 45.48437057222639, 45.294031620025635, 49.197783197675435, 53.88345725195748, 54.63706234523228, 51.98205838884626, 55.4027989932469, 53.31194707325527, 49.65685067858015, 44.79725973946707, 47.35282802581787, 53.237285205296104, 56.087853159223286, 58.52450997488839, 59.26044232504708, 58.08342095783779, 57.22648572921753, 57.52905545915876, 59.20964404514858, 54.33877617972237, 56.28516462871006, 57.87308161599295, 65.82079941885812, 60.77127947126116, 61.60960742405483, 57.14156484603882, 66.5711979184832, 59.0424564906529, 60.978863852364675, 52.295165061950684, 56.89528594698225, 58.418647221156526, 68.55726405552456, 60.20050580160958, 73.34009824480329, 22.64919059617179, 0.2974580813731466, 1.2774415101323808, 5.463433691433497, 18.00952751295907, 46.23412983758109, 65.95775536128453, 64.5247449874878, 60.92464705875942, 15.35618417603629, 15.92111267362322, 55.52573347091675, 52.98591327667236, 39.94811541693551, 54.34166663033621, 67.90937232971191, 8.024206178528921, 0.7401252080287252, 0.25230418145656586, 0.17937093574021543, 0.18508150002786092, 0.15265032170074327, 0.13578631090266363, 0.2074752455311162, 0.19473299570381641, 0.10538991660411869, 0.09603402470903737, 0.1414394982691322, 0.15450694278946944, 0.190726992807218, 0.13678146393171378, 0.06516117669109787, 0.17414236201771668, 0.1560047681310347, 0.13459654045956476, 0.10837125019835574], [0.06670587523175137, 0.0357788936900241, 0.0608157841488719, 0.00924705742259643, 0.05617922205211861, 0.062029004762215276, 0.028767693122582774, 0.021754948887974024, 0.05335947817989758, 0.004278678555108074, 0.03524936496147087, 0.03897416937564101, 0.01529833025831197, 0.009910112512963158, 0.0707076033577323, 0.03893711118559752, 0.03508607211655804, 0.03311921622870224, 0.0446587695207979, 0.04694434009226305, 0.07378433897559132, 0.07362909016332456, 0.07885840348899364, 0.17525657080113888, 0.2911420331469604, 10.709664957863943, 63.08052716936384, 40.967850412641255, 42.352727140699116, 40.67893041883196, 54.5266763142177, 6.3704363363129755, 30.641941411154612, 68.27716827392578, 38.232949120657786, 70.53092070988247, 54.23267718723842, 33.30213567188808, 3.636609192405428, 0.5036785528063774, 11.707716362816946, 77.4238394328526, 71.96525818961007, 74.32991082327706, 67.03246103014264, 69.17085252489362, 62.059294836861746, 59.9048182623727, 51.72945315497262, 56.248224530901226, 58.40305546351841, 67.30110618046352, 66.55731541769845, 70.21329075949532, 66.9410296848842, 60.88784939902169, 54.16705839974539, 50.971310888017925, 51.551645278930664, 57.97268404279436, 62.194388662065776, 62.69014263153076, 61.393747738429475, 61.07819529942104, 58.19440105983189, 60.75137288229806, 56.99202571596418, 60.85846546718052, 56.64220476150513, 52.84017481122698, 44.25520644869123, 42.267993858882356, 41.0704996245248, 40.877638476235525, 42.2614278112139, 40.68316534587315, 42.3769520350865, 40.85094697134835, 46.637111459459575, 50.61522265842983, 57.10114370073591, 60.44088568006243, 55.26718405314854, 52.21946791240147, 52.803133964538574, 52.048920903887065, 53.418240615299766, 53.19999074935913, 55.23179687772478, 53.55208723885672, 55.345368657793315, 52.993459020342144, 52.623088768550325, 50.71049288340977, 51.780817713056294, 52.028649534497944, 52.00869083404541, 50.56473009926932, 53.20787695475987, 48.18405144555228, 37.88134247916085, 40.02369792120797, 38.98240613937378, 39.30093935557774, 40.249521323612754, 42.31847946984427, 43.68149021693638, 49.49667733056204, 51.75872244153704, 50.662647587912424, 50.51174661091396, 51.46752691268921, 46.6686041695731, 43.94567462376186, 41.130365303584504, 48.63037593024117, 51.60574395315987, 54.891501903533936, 54.701166425432476, 56.39725644247872, 55.03475638798305, 54.67580202647618, 52.40625980922154, 51.45234162466866, 49.92752817698887, 53.25724737984793, 52.0331380707877, 56.934376512254985, 58.63406222207205, 57.03184584208897, 50.88702229091099, 57.059197425842285, 59.8240385055542, 58.685319083077566, 53.39065626689366, 54.647244930267334, 53.85935742514474, 63.724131856645855, 58.229409558432444, 63.97955458504813, 11.981619562421526, 0.18980328951563152, 0.6871666354792458, 5.12856091771807, 15.67550253868103, 45.79541015625, 50.63899939400809, 50.186226981026785, 27.790755067552837, 6.83102764402117, 34.6792755808149, 39.94533961159842, 41.12288556780134, 29.310270513807023, 47.225147928510395, 24.053275619234356, 0.10872129284377609, 0.04236099888969745, 0.07348623140049831, 0.0838358106889895, 0.0370047520180898, 0.019055963893021857, 0.031680993403175046, 0.07331104722938367, 0.07342379939343248, 0.013149224953459842, 0.08922202845237084, 0.026751375424542596, 0.06756131790046181, 0.04640728980302811, 0.06252210294561726, 0.04001148317807487, 0.06144077596919877, 0.06754393383328404, 0.09095654037914105, 0.045858986010508876, 0.03899538377299905, 0.030896871550274745, 0.03391528708328094, 0.05372075397255165, 0.09992812361036028, 0.0580256956496409, 0.045760846098086665, 0.024396541694711362, 0.036726803718400855, 0.01691543187813035, 0.02267907796028469, 0.07917564575161253, 0.042475328647664616, 0.058302110460187705, 0.05788338650017977, 0.0037182188077297595, 0.03178351325914264, 0.057858185709587166, 0.004563657749843384, 0.04253539256751537, 0.06439130407358919, 0.021083896414243748, 0.12175251037946769, 0.12736289575695992, 0.3321406931749412, 12.883731978280203, 76.90214783804757, 44.43612016950335, 45.191695077078684, 43.189182553972515, 27.372412715639385, 15.673907927104406, 49.047889709472656, 71.81570516313825, 48.0611378124782, 73.63124166216168, 61.81490584782192, 39.45616906029837, 4.377771147659846, 0.5511571679796491, 14.299862572125026, 77.47390815189907, 72.84352438790458, 75.35982840401786, 69.44827325003487, 74.12693309783936, 63.992269788469585, 62.33823721749442, 53.73797934395926, 58.49017892565046, 61.28343118940081, 68.68326268877301, 66.85690089634487, 71.75886195046562, 68.55327578953334, 62.7316928591047, 54.8278147152492, 52.20370592389788, 53.80568259102957, 60.875564983912874, 62.789481026785715, 63.804612840924946, 64.61022867475236, 60.01626736777169, 60.858673913138254, 62.09838540213448, 60.76812498910086, 62.13577365875244, 58.79555920192173, 54.74289730616978, 46.75763838631766, 45.36307239532471, 44.7551189150129, 44.029285771506174, 42.65269824436733, 43.319756575993125, 42.25300312042236, 43.410861355917795, 47.6932168006897, 53.93611070087978, 60.336746079581125, 64.4145257132394, 57.05066851207188, 55.59857491084507, 56.4549230166844, 55.097408294677734, 56.4977308682033, 57.558290004730225, 58.04707840510777, 58.04681089946202, 58.013619354793, 56.156331130436485, 55.94862168175833, 54.33739696230207, 53.656348432813374, 55.487372466496055, 55.86786624363491, 55.97167927878243, 56.25533601215908, 51.09092065266201, 42.201673303331646, 42.59997878755842, 42.167689664023264, 42.16134595870972, 42.71775770187378, 43.71062053952898, 45.67744711467198, 51.303952421460835, 52.37430156980242, 53.13978460856846, 52.6742969921657, 54.22815390995571, 47.5496426991054, 44.72744076592581, 42.802821023123606, 49.880402020045686, 54.10003955023629, 55.59658425194876, 57.02738857269287, 59.58193547385079, 57.18433795656477, 59.212555340358186, 55.39294644764492, 53.79949174608503, 52.31462001800537, 58.32959910801479, 56.114127772195, 61.08409432002476, 59.74138968331473, 59.64025865282331, 53.53233698436192, 60.800267355782644, 61.02225535256522, 60.92467485155378, 53.64741652352469, 56.70779228210449, 54.61468914576939, 65.99874973297119, 61.53170422145298, 66.48435933249337, 13.979667867933001, 0.22013086000723497, 0.8898669758013317, 5.941287798540933, 20.03429511615208, 51.266855989183696, 57.88199962888445, 55.77876601900373, 36.15033081599644, 14.61144151006426, 25.011524268559047, 33.65206779752459, 51.8586688041687, 27.91262299673898, 56.21921927588326, 25.488627535956248, 0.15128616775785172, 0.06656818012041704, 0.011555143482317882, 0.09874846333903925, 0.039802742057612965, 0.054841039037065845, 0.0341401128763599, 0.03951590834185481, 0.035610501654446125, 0.03691959587324943, 0.04073709495631712, 0.01503773549172495, 0.048642709851264954, 0.025908424585525478, 0.04558832517692021, 0.04419859724917582, 0.05119539251817124, 0.035323284566402435, 0.051674092188477516, 0.03816860242347632, 0.17636645053114208, 0.0721807096685682, 0.13584683622632707, 0.12788709120026656, 0.18703950781907352, 0.09915247665984289, 0.0829947597480246, 0.1556778092469488, 0.11624321314905371, 0.12422703259757586, 0.16415242664515972, 0.13684021149362835, 0.08300992500569139, 0.1519824939646891, 0.0877789133893592, 0.10396148503891059, 0.11389179075402872, 0.11962542523230825, 0.13063126323478563, 0.18734070951385157, 0.16530120000243187, 0.28380924090743065, 0.28038147198302404, 0.38790736932839665, 0.4976402425340244, 24.50065623010908, 88.63880171094621, 53.25768511635916, 58.298457281930105, 63.289730480739046, 69.79802472250802, 7.628987431526184, 42.23538596289498, 76.50249440329415, 47.18167652402605, 81.21850081852504, 68.88717842102051, 43.1430013520377, 5.521885412079947, 0.5540380648204258, 15.967457158224923, 81.70295701708112, 75.69092396327427, 78.01501996176583, 72.4767289842878, 76.55858721051897, 67.36881637573242, 65.7712379183088, 55.31344515936715, 63.2153708594186, 64.92779609135219, 71.2210922241211, 69.84408433096749, 75.55362061091832, 72.21847139086042, 65.43813432965959, 59.646699632917134, 56.67063679013933, 55.89260877881731, 64.44322177342006, 65.67433834075928, 68.76506383078438, 67.06105286734444, 63.40842655726841, 62.173446791512625, 66.17879840305874, 63.99038682665144, 67.83004474639893, 60.85957023075649, 56.93784018925258, 49.11862237112862, 49.10102258409773, 45.498951366969514, 45.56179782322475, 45.690537520817344, 45.3815997668675, 45.44063513619559, 46.94171701158796, 51.28265271868025, 58.49677276611328, 61.97326224190848, 65.2735037122454, 60.647073473249165, 58.07431186948504, 58.982611656188965, 57.17667061941964, 58.47386455535889, 60.44653456551688, 59.504136494227815, 60.17040620531355, 60.07473645891462, 59.83719144548689, 57.430741923195974, 57.09931632450649, 56.68724298477173, 58.08704096930367, 58.911093848092214, 58.50606945582798, 59.8701536996024, 52.277808461870464, 43.45223093032837, 45.534897872379844, 43.16758755275181, 43.73428610392979, 43.4639629636492, 45.02249254499163, 46.87987109592983, 52.304298468998496, 54.306279454912456, 55.37105614798409, 54.7146007674081, 55.41981165749686, 50.22421278272356, 46.884866850716726, 44.55420133045742, 52.036254337855745, 56.08970138004848, 58.6209579195295, 59.45768778664725, 62.41659205300467, 60.268862179347444, 61.28250013078962, 57.482981954302105, 57.09665169034685, 54.88286529268537, 61.65743882315499, 57.95776973451887, 64.76050431387765, 65.26745877947126, 60.49338626861572, 55.62119477135794, 63.78380993434361, 64.6989015851702, 63.76403536115374, 55.05990539278303, 59.70694746289934, 58.34589263371059, 69.54287297385079, 63.9544437953404, 68.74531010219029, 15.731022119522095, 0.20781829926584447, 3.038006467478616, 6.798332027026585, 21.52872235434396, 55.292416436331614, 61.05842072623116, 57.4818320274353, 36.64460481916155, 9.327703867639814, 43.247022833142964, 59.90980012076241, 56.42205456324986, 42.12551062447684, 59.905061449323384, 44.927673952920095, 0.3916599936783314, 0.10098937273557697, 0.22772495608244622, 0.14692888728209905, 0.15976742122854504, 0.11911368769194398, 0.057398871784763675, 0.17056640104523726, 0.13626318531376974, 0.12365979089268617, 0.16365704179874488, 0.08515892683395318, 0.10079846012273005, 0.10983060260436364, 0.14032769149967603, 0.10431472358426877, 0.15678952102150234, 0.15039841325155326, 0.13675289760742868, 0.08121239074638911], [0.037484388066721816, 0.056919191631355455, 0.018104846090344445, 0.0657301147335342, 0.03964640758931637, 0.005708091027502502, 0.03387603383245213, 0.013757903943769634, 0.12488454660134655, 0.013250993331894279, 0.0533731235191226, 0.08292526419141463, 0.04871770154152598, 0.07280937236334596, 0.0722922133281827, 0.04551933512889913, 0.033253494916217666, 0.004642529812242303, 0.03351135518667953, 0.04178262921050191, 0.028225087327882648, 0.01919986929611436, 0.03242576701034393, 0.1050312090665102, 0.1777958252600261, 0.6078018684472356, 49.9009895324707, 51.11917550223214, 38.34024320329939, 43.75529745646885, 63.29376738412039, 32.901120390210835, 8.41098894391741, 63.92483752114432, 59.8316467830113, 64.98095675877163, 64.07184055873326, 49.87844957624163, 7.651245985712324, 0.28748491938625065, 0.047248344136668105, 31.4345988546099, 81.81459372384208, 67.32345158713204, 74.85696642739433, 64.34669045039585, 67.05113778795514, 58.634235927036826, 55.392067500523154, 56.35375724520002, 61.48513044629778, 64.93778760092599, 68.63212394714355, 68.54156807490757, 64.91491413116455, 63.03957448686872, 58.59850828988211, 49.40775081089565, 54.02928951808384, 58.04108905792236, 60.873167855399, 60.90084947858538, 58.80513381958008, 59.04462432861328, 59.71934304918562, 57.82152598244803, 57.939499446323936, 57.76258441380092, 58.57342529296875, 52.304649353027344, 44.24342230388096, 42.26811892645699, 42.86541039603097, 42.27636643818447, 41.56503765923636, 41.97078466415405, 43.16563858304705, 43.62973655973162, 42.83500507899693, 46.270778111049104, 49.63080883026123, 52.61655051367623, 57.631298201424734, 56.13591037477766, 51.868087087358745, 50.84183815547398, 53.13428858348301, 52.97975022452218, 54.081703254154746, 53.418695722307476, 55.9418054989406, 53.783733231680735, 55.57447508403233, 49.696257386888774, 49.312209606170654, 54.03214175360543, 51.66148240225655, 52.53938382012503, 52.834015233176096, 50.36700521196638, 40.214964457920615, 40.5346371786935, 40.084838594709126, 38.98206915174212, 41.49303000313895, 41.040181159973145, 47.43974651609148, 48.13275984355381, 50.55563490731375, 51.39211463928223, 49.93987512588501, 49.924081870487754, 45.54010207312447, 42.300184862954275, 43.452894483293804, 47.53584010260445, 53.0390704699925, 58.86661842891148, 54.907527923583984, 51.57278517314366, 52.87277923311506, 54.94503429957798, 51.71078681945801, 51.802409240177695, 51.47372817993164, 54.41009249005999, 54.95574494770595, 57.951214109148296, 57.208027839660645, 57.83682244164603, 52.869822774614605, 53.57238640104021, 59.14509528023856, 56.50561012540545, 52.36264249256679, 57.69606930868966, 57.19751174109322, 65.79070677076066, 55.49942411695208, 66.8779330934797, 9.252141339438301, 0.127312032771962, 0.795975805393287, 3.180176381553922, 22.121624299458094, 48.85954141616821, 44.69782059533255, 45.372223172869, 13.165241718292236, 18.850733757019043, 48.61966528211321, 31.05343805040632, 27.766884531293595, 34.63483837672642, 54.2581319127764, 10.54823659147535, 0.40547930928213255, 0.09473842994443007, 0.0803642151877284, 0.02112004706369979, 0.044708638451993465, 0.056099049746990204, 0.024170840591458336, 0.033992385624774864, 0.020394294489441172, 0.025561372583199824, 0.03054958375703011, 0.013734999994215156, 0.1024014176800847, 0.05388841997565968, 0.05214381484048707, 0.07245363002376896, 0.04026889222274933, 0.015564076802028077, 0.029151306288050752, 0.023128585357751166, 0.051896597391792705, 0.018560633329408507, 0.024272707357470478, 0.01010179950390011, 0.0197060207969376, 0.02562696995612766, 0.049247525432812314, 0.028471383665289198, 0.034407523527209244, 0.05344690741705043, 0.03403837333566376, 0.0958700974338821, 0.02716020804031619, 0.03681640087493828, 0.07092977607888834, 0.03672920233969178, 0.037224756819861274, 0.07575631101748773, 0.04309229000604578, 0.05077954215396728, 0.07167391864848988, 0.08146739099174738, 0.044266182729708295, 0.047889566514641047, 0.07770374723310981, 1.1805387841803687, 57.7246333530971, 60.45945126669747, 40.461458751133506, 52.34172146660941, 40.30085114070347, 25.248110430581228, 22.197790452412196, 72.73097051892961, 54.6987658228193, 70.89797319684709, 69.34406416756767, 52.45712409700666, 8.384006483214241, 0.13121571258774825, 0.024123273590313535, 33.71420553752354, 80.72189222063336, 70.61931569235665, 78.64892496381486, 67.25253132411412, 69.00934164864677, 59.80873857225691, 56.47335311344692, 58.526934896196636, 63.58878789629255, 68.34067480904716, 71.4986241204398, 69.14432430267334, 68.07754652840751, 65.65227086203438, 58.66903945377895, 50.91397435324532, 56.13205412455967, 60.67289297921317, 62.62810911451067, 64.34609985351562, 61.08494200025286, 61.53001580919538, 61.418872424534385, 61.720445087977815, 59.14815943581717, 60.988827569144114, 61.32181303841727, 54.97806256158011, 46.05255603790283, 43.68940421513149, 44.82891225814819, 46.07679830278669, 45.878361225128174, 44.98558023997715, 44.24232448850359, 44.821950163160054, 45.417153699057444, 49.563821247645784, 54.49966866629464, 57.91503136498587, 61.783618109566824, 58.399088042122976, 54.67931434086391, 54.47761508396694, 57.19129657745361, 57.264315196446006, 60.14652524675642, 59.036842346191406, 61.59427274976458, 59.46396895817348, 55.51420293535505, 54.383894307272776, 53.12060758045742, 59.21671731131417, 56.113655294690815, 55.84282841001238, 55.95780720029558, 54.15984616960798, 44.41213846206665, 43.63122000013079, 41.84889589037214, 42.57904039110456, 44.79179498127529, 44.346422399793354, 48.55537360055106, 50.32796675818307, 52.76800734656197, 53.12020805903843, 51.33732114519392, 51.14585658482143, 48.10506432397025, 45.24231617791312, 45.4475485937936, 49.05400759833199, 53.869390623910085, 59.75345870426723, 57.50675174168178, 56.6247022492545, 56.16221625464303, 58.817188944135395, 54.16287211009434, 54.85416228430611, 51.448082378932405, 57.72557135990688, 57.76874399185181, 61.164790698460166, 58.66172994886126, 60.14341245378767, 55.756146158490864, 57.704042366572786, 61.1493170601981, 59.82153715406145, 54.902896949223106, 59.8334880556379, 59.55790165492466, 65.76519298553467, 57.18051644733974, 69.07192407335553, 9.856123055730547, 0.08247129712253809, 1.8575735347611564, 3.3493797821657996, 23.141739709036692, 54.0182592528207, 50.908447061266216, 50.65007134846279, 21.051139661243983, 21.46794993536813, 32.11907284600394, 31.84046745300293, 33.97713926860264, 37.010941641671316, 63.96009268079485, 11.209656459944588, 0.4335672935204846, 0.10279051001582827, 0.02906576677092484, 0.03928761184215546, 0.09889193956873246, 0.10439055665795292, 0.008223974195841168, 0.025724008945482116, 0.03690797256837998, 0.07380901050886937, 0.06545125041157007, 0.03090371796861291, 0.03323327796533704, 0.05089034692251256, 0.06948944979480334, 0.06840093713253736, 0.013136446442721146, 0.02452444893840168, 0.0505053732943322, 0.090169080133949, 0.10202584176191262, 0.09752467115010534, 0.07986642832734756, 0.10667886851089341, 0.12232484109699726, 0.14048044330307416, 0.09136803115585021, 0.12270886477615152, 0.18187232794506208, 0.11026375900421824, 0.16218544862100057, 0.2089928433831249, 0.08207209461501666, 0.15938115838382924, 0.19213808780269964, 0.09990632228021111, 0.09784561821392604, 0.13985587895980903, 0.1126507298488702, 0.12554985018713133, 0.1097074281424284, 0.18655107117124967, 0.06945565875087466, 0.2279541109289442, 0.151794485481722, 2.2065583169460297, 79.31434004647392, 67.68545273372105, 52.74623169217791, 65.51976871490479, 91.49391378675188, 36.12072801589966, 12.149944015911647, 74.92379420144218, 67.07885415213448, 76.29657064165387, 76.73416818891252, 57.59061649867466, 9.7167751959392, 0.3783770464360714, 0.1295266625072275, 34.72387259347098, 81.08770098005022, 71.44153772081647, 82.43405342102051, 67.08266176496232, 74.60020269666398, 62.88282312665667, 61.872492517743794, 61.347347668239046, 66.75035721915108, 70.60392543247768, 74.28249631609235, 73.64312308175224, 70.5223605292184, 68.56635924748012, 64.97804546356201, 54.43693338121687, 60.11060306004116, 63.64563110896519, 66.44112764086042, 63.992596353803364, 62.52593585423061, 63.102309771946494, 67.95699528285435, 63.38656752450125, 61.36589935847691, 62.56863948277065, 63.952831813267295, 58.27382591792515, 50.51308066504342, 45.7761150087629, 47.32219689232962, 48.487166609082905, 48.13353456769671, 47.467275278908865, 48.5714030947004, 47.16240569523403, 49.447612626211985, 50.35575607844761, 54.474189622061594, 58.48918533325195, 61.394220215933665, 61.09236962454659, 57.892095361437114, 56.60421201160976, 60.362906047276084, 57.89638934816633, 60.20486927032471, 59.18757656642369, 61.8923157283238, 60.84388814653669, 60.00479589189802, 54.55239854540144, 53.186136041368755, 59.545478275844026, 57.98053898130144, 58.36868967328753, 57.93449674333845, 55.03115374701363, 46.64973633629935, 44.798590319497244, 42.84524672372, 44.09311192376273, 46.97754192352295, 46.04724761417934, 51.94541706357683, 51.786219937460764, 55.58857297897339, 55.87028421674456, 51.20180695397513, 53.03849376950945, 49.79198619297573, 47.53117438725063, 47.50616782052176, 51.46802370888846, 55.32514592579433, 61.86921296800886, 58.78825664520264, 55.75104965482439, 57.64926276888166, 59.444847515651155, 56.32041284016201, 57.94348771231515, 56.37046766281128, 61.47008759634835, 62.080577169145855, 63.48659379141671, 62.34603309631348, 64.10606043679374, 59.69049412863595, 60.63604668208531, 64.68868078504289, 61.07988371167864, 56.671821457999094, 61.56292942592076, 61.26616491590227, 70.9373208454677, 58.54449994223458, 72.9109080178397, 11.318874325071063, 0.18046273929732187, 3.4413420132228305, 6.235050686768123, 26.860698734010967, 58.68838323865618, 52.509690693446565, 53.479759965624126, 18.00599956512451, 23.32079999787467, 69.24446174076625, 43.350380761282786, 42.280917508261545, 44.779614789145334, 74.19333703177315, 19.33475395611354, 0.6561156245214599, 0.24369264926229203, 0.33536045040403095, 0.18652946661625588, 0.2546657547354698, 0.20918424454118523, 0.13575473188289575, 0.16902924781399115, 0.07286402157374791, 0.11711959540843964, 0.17260743438133172, 0.07303360104560852, 0.14730346575379372, 0.1135302944374936, 0.20445873668151243, 0.1493960406099047, 0.14014102651604585, 0.12014111184648105, 0.13879850426954882, 0.28271280974149704], [0.016774488280394247, 0.1055303258555276, 0.03127375704103282, 0.024245336951155747, 0.01906066614070109, 0.017537582333066633, 0.041106977965682745, 0.07007280670638595, 0.020541292315881168, 0.04088619284863983, 0.010230772895738482, 0.034646445885300636, 0.05682001356035471, 0.03349331972588386, 0.05281585967168212, 0.036362301491733105, 0.01753896484816713, 0.040793515143117735, 0.08722633482622248, 0.023409473410408412, 0.04490352049469948, 0.0584133630618453, 0.054937234946659634, 0.0814762662297913, 0.23318984998123987, 0.3383385134594781, 13.363812548773629, 71.2591336114066, 40.37400524956839, 45.9621182850429, 48.190850257873535, 61.81634412493025, 15.835140875407628, 25.69947930744716, 86.2784708568028, 62.02977194104876, 58.212327412196565, 49.82147434779576, 11.876421230179922, 0.27611145111066954, 0.10242899334324257, 2.2126825026103427, 77.55281884329659, 72.32952444893974, 72.11497102464948, 67.42184502737862, 62.50598062787737, 58.045591490609304, 62.616338866097585, 58.75521101270403, 63.14643778119768, 68.17671121869768, 71.57229587009975, 70.97616127559117, 68.98805931636265, 65.7358090536935, 60.72501836504255, 51.94075829642159, 53.33328151702881, 59.956915855407715, 62.13094466073172, 60.31991754259382, 54.582459926605225, 54.75439657483782, 59.90915393829346, 59.940434728349956, 61.175998142787385, 59.652445793151855, 56.488885811397004, 47.315047195979524, 43.45832450049264, 43.81777565819876, 41.89960036958967, 43.132551261356895, 43.42387533187866, 42.19951936176845, 42.04444599151611, 42.99818352290562, 43.08742618560791, 43.901807171957834, 47.37229687826974, 49.947966303144185, 50.31040866034371, 51.38247748783657, 52.573225021362305, 49.48406287602016, 49.04343591417585, 53.26536634990147, 55.13272251401629, 55.25808538709368, 54.332098960876465, 55.007394381931846, 55.672941480364116, 52.12266213553292, 49.727531228746685, 58.25861978530884, 54.09844493865967, 53.22855479376656, 53.12799004146031, 50.79534428460257, 39.50618914195469, 39.11567606244768, 39.39630338123867, 40.063493728637695, 40.37341465268816, 43.525520529065815, 47.792214734213694, 49.930352619716096, 50.874522481645855, 49.3309280531747, 50.01498515265328, 45.56315619604928, 46.800769329071045, 41.892502784729004, 44.496315887996126, 47.43715483801705, 51.40273496082851, 53.76536566870553, 55.92304188864571, 48.78937503269741, 40.89432804925101, 38.415412289755686, 50.850717953273225, 52.75764063426426, 52.60511377879551, 56.073640619005474, 58.798296792166575, 58.267860889434814, 60.456067493983674, 56.25634697505406, 51.76021630423409, 49.466185161045615, 60.060582978384836, 59.1313864844186, 57.014298166547505, 61.701024872916086, 62.01676491328648, 60.81492110661098, 63.570729528154644, 43.34625700541905, 6.028220185211726, 0.08216732700488397, 1.085162164909499, 3.431680543082101, 30.622948510306223, 39.18924706322806, 51.35642869131905, 30.657814570835658, 7.21391681262425, 37.203573499407085, 34.345216614859446, 42.6647082056318, 29.903869015829905, 38.63351624352591, 48.624556813921245, 2.034610595021929, 0.2761066199413368, 0.019014486743669425, 0.09626738647265093, 0.02909844501742295, 0.06837665914957013, 0.08330347961080925, 0.01570386689023248, 0.024687723123601506, 0.014992348284327557, 0.07631367325250592, 0.024577719026378224, 0.04821362126884716, 0.006418906925578735, 0.04772692506334611, 0.03381208190694451, 0.06031479460320302, 0.07999515320573534, 0.03336728523884501, 0.03824034393099802, 0.0751556446775794, 0.03982711842815791, 0.019705528859049082, 0.048229593983186145, 0.005765695681995047, 0.02312032419389912, 0.04692192808059709, 0.02448781144006976, 0.0738955983625991, 0.019991924919720207, 0.01974582196479397, 0.03112217571054186, 0.024408122591142143, 0.007551270337509257, 0.0011303798632330395, 0.05823215349976506, 0.037664515365447314, 0.037682479580066035, 0.09279665271086351, 0.11788072170955793, 0.019978937759463276, 0.042389120773545334, 0.06505609875810997, 0.04278353960918529, 0.09725107904523611, 0.1364741147096668, 0.4691220128110477, 18.224609000342234, 84.14009325844901, 41.162146363939556, 54.461481366838726, 46.01147828783308, 36.242672375270296, 22.731172391346522, 42.05979108810425, 82.38607610974992, 68.51793725149972, 62.85279301234654, 55.1697598866054, 14.6713992527553, 0.6321486277239663, 0.16688823912824902, 2.819302580186299, 82.11359555380685, 73.27594552721295, 73.89166709354946, 73.05779293605259, 64.69373212541852, 58.64599922725132, 61.320180211748394, 60.718674659729004, 65.99287850516183, 70.77726214272636, 72.17084843771798, 72.49991512298584, 71.04974269866943, 66.0590739931379, 64.26153332846505, 53.91345609937395, 55.65700578689575, 62.738912037440706, 64.43650286538261, 66.29155376979283, 56.47223792757307, 57.596390451703755, 62.1911438533238, 61.95336954934256, 64.49800137111119, 61.866781098502024, 61.09309918539864, 49.744127001081196, 46.54435648236956, 47.027051312582834, 45.68605593272618, 44.18878167016165, 45.9874826839992, 44.30906541006905, 44.929303305489675, 44.53738668986729, 45.486038139888215, 48.42257268088204, 51.1272736276899, 52.14671332495553, 53.32686832972935, 57.448366028921946, 56.01679393223354, 52.33622544152396, 53.80209732055664, 54.86418158667428, 59.48961475917271, 58.84247343880789, 57.52214894975935, 55.907668999263215, 58.76854460580008, 55.02416385923113, 54.72093057632446, 59.9063538142613, 58.15490402494158, 57.21539987836565, 57.866755281175884, 55.283345563071116, 42.33501965659005, 42.25339569364275, 43.22178002766201, 44.50134290967669, 43.370624337877544, 45.8481365612575, 48.65965911320278, 51.71816233226231, 53.441385064806255, 51.97202866418021, 52.38649913242885, 48.99976301193237, 47.40799672263009, 44.48138420922415, 46.30655091149466, 49.31103883470808, 54.105327129364014, 59.05807604108538, 58.54531288146973, 54.97909089497158, 46.82153402056013, 47.090189593178884, 58.047943455832346, 55.59518766403198, 55.25604261670794, 59.37684549604143, 61.084261076790945, 61.27686514173235, 63.36603559766497, 58.252974373953684, 55.3932660647801, 54.99934489386422, 62.10896750858852, 61.79934883117676, 60.15548842293875, 62.85076413835798, 62.15965461730957, 63.16216155460903, 65.08763939993722, 45.99126945223127, 6.5517930047852655, 0.3261009986911501, 3.1298051987375533, 3.5183072090148926, 33.300492422921316, 42.35934182575771, 57.07039097377232, 34.68561233792986, 15.520667144230433, 31.678956576756068, 26.539115258625575, 46.23985515322004, 29.713158335004533, 42.7621636390686, 55.55649662017822, 1.6933748998812266, 0.20339186250099114, 0.10750435385853052, 0.037858966538416486, 0.04871777278770294, 0.04710144469780581, 0.05828355931277786, 0.04953862374116268, 0.06483642983117274, 0.06327040493488312, 0.04743442897285734, 0.06549016439488956, 0.0841781519619482, 0.04913506843149662, 0.03840417621125068, 0.018979555760909404, 0.025797440005200248, 0.08431869692036084, 0.046422848611005714, 0.021278451063803265, 0.07064489315130881, 0.2316137488399233, 0.15074058489075728, 0.17262374636318, 0.09763589661036219, 0.12732331002397196, 0.117452756102596, 0.18183906615844794, 0.18104680867067405, 0.11353439957435642, 0.11735060944088868, 0.11129701855991568, 0.12590943303491386, 0.1725341933114188, 0.12914016896060534, 0.33505877373473986, 0.12140773316579205, 0.16064749471843243, 0.284102449459689, 0.21445563382336072, 0.11203736811876297, 0.10138422583362885, 0.11673345470002719, 0.18295487628451415, 0.22586533586893762, 0.33378396928310394, 0.5382825902530125, 30.52492332458496, 96.36118943350655, 52.06320292609078, 65.4290599822998, 69.29753902980259, 78.4778881072998, 17.776227848870413, 34.547753129686626, 95.14189175197056, 73.67917728424072, 67.97153786250523, 60.422264507838655, 15.752997534615652, 0.4665360344307763, 0.20853067961122307, 3.1423056593963077, 85.32322556631905, 75.1972405569894, 77.16819436209542, 75.8413941519601, 66.48205253056118, 62.6992586680821, 67.73850222996303, 64.67036533355713, 70.34042194911412, 73.32311684744698, 76.85074506487165, 73.200286592756, 74.8527558190482, 68.89208384922573, 68.11341312953404, 57.47771521977016, 59.69724082946777, 67.05889197758266, 68.48761531284877, 67.35417652130127, 59.50139890398298, 60.048659869602744, 63.48736504146031, 64.26988506317139, 67.97258704049247, 65.82067435128349, 64.00809778485979, 50.34587574005127, 49.680676051548545, 48.86325175421578, 48.37669025148664, 46.55637339183262, 50.103939465114046, 46.588282993861604, 47.15133721487862, 46.96729333060128, 47.75376340321132, 50.07939147949219, 54.583126953669954, 55.02545275006975, 56.72036157335554, 57.35976954868862, 56.9597304889134, 53.970858642033164, 54.28871440887451, 58.894577980041504, 62.10934965951102, 58.05488470622471, 58.51542867933001, 58.44858700888497, 61.32807336534773, 57.39725508008684, 56.84088502611433, 63.140274729047505, 60.477120535714285, 60.42878886631557, 58.62548814501081, 56.75017976760864, 42.15460968017578, 44.49012156895229, 45.09459400177002, 47.071881089891704, 45.10100024087088, 45.75556918552944, 49.48586940765381, 52.989140714917866, 55.6628110068185, 52.5081273487636, 53.85110296521868, 49.839807169778005, 50.32150840759277, 45.12593732561384, 49.04302944455828, 51.671182087489534, 55.78469283240182, 59.609610148838584, 60.22856957571847, 54.43595021111624, 49.76359585353306, 47.968511377062114, 57.55587897981916, 56.98945835658482, 56.95438732419695, 62.80949878692627, 66.0206435067313, 65.63395541054862, 68.52005645206997, 60.46893555777413, 57.853935854775564, 58.29546955653599, 66.16792447226388, 64.5182136808123, 62.859727314540315, 66.53248255593437, 66.4773416519165, 63.96617235456194, 69.69849872589111, 47.129318373543875, 9.035453081130981, 0.27633287065795487, 3.741777343409402, 7.516756653785706, 36.95149285452706, 47.37302991322109, 59.84858649117606, 37.123231479099815, 11.51019036769867, 47.78299447468349, 50.34610850470406, 58.36668859209333, 39.73510101863316, 49.99657242638724, 69.86332389286586, 5.779464253357478, 0.6390525315489087, 0.35370499747140066, 0.24846280472619192, 0.11534480564296246, 0.2181718344134944, 0.12283655149596077, 0.21368560514279775, 0.15611528791487217, 0.1569886031959738, 0.18823759710150106, 0.18501743275140012, 0.18268091098538466, 0.13745862830962452, 0.1990144838179861, 0.1383655175034489, 0.13118891045451164, 0.24763192502515657, 0.09419601583587271, 0.12088024004229478, 0.16718849087400095], [0.027657737057389956, 0.016100121163097874, 0.036735421113137684, 0.05773193748401744, 0.04803114623895713, 0.053486031746225696, 0.04157991687368069, 0.08963505271822214, 0.04987847479060292, 0.04351019293868116, 0.041038992149489265, 0.0323506769325052, 0.03595465800857969, 0.029065488571567193, 0.01839796473671283, 0.015100508462637663, 0.03863835221688662, 0.04145839125184076, 0.033992331341973374, 0.02648551861888596, 0.06672384283904519, 0.037052870328937254, 0.05051788208740098, 0.052867838846785684, 0.03594587776543839, 0.030297406217349426, 1.3762667157820292, 53.36426700864519, 52.98075771331787, 43.79412399019514, 57.92240687779018, 53.94925669261387, 38.689720221928184, 9.014602405684334, 59.10175241742815, 72.44055666242326, 49.960271562848774, 50.90166909354073, 16.055042675563268, 0.19716249033808708, 0.02452212495596281, 0.14778970394815716, 45.40638746534075, 84.51262787410191, 67.84970120021275, 72.83195563725063, 63.20320456368582, 65.75816140856061, 62.60076795305525, 65.73120934622628, 66.50488431113106, 70.16240910121373, 70.1192329951695, 69.15255096980503, 69.87978417532784, 66.78526496887207, 62.887672969273154, 53.58832209450858, 53.12540878568377, 60.77372523716518, 63.21343231201172, 53.09910985401699, 50.61162349155971, 62.93079348972866, 62.92848668779646, 61.67594882420131, 60.68237032209124, 57.39015054702759, 47.60780259541103, 44.05474744524275, 44.61049216134207, 43.26675571714129, 46.533524240766255, 44.59185709272112, 42.46735504695347, 41.74184846878052, 42.26478726523263, 41.3238274710519, 43.00859887259347, 42.40329613004412, 42.423907961164204, 43.496987751552034, 47.97929150717599, 45.54682445526123, 48.170561517987935, 48.245636803763254, 53.28658267429897, 55.547623770577566, 57.487501757485525, 57.365140506199424, 53.73094081878662, 55.48007685797555, 56.194963114602224, 53.978724002838135, 50.885980061122346, 56.576294149671284, 52.23416335242135, 55.59235627310616, 56.77309145246233, 51.53581728254046, 43.13571269171578, 40.998943601335796, 41.66434131349836, 40.012806619916645, 39.89672654015677, 44.1504727772304, 47.39370427812849, 47.1045480455671, 49.381205218178884, 47.2252208845956, 46.016046728406636, 42.45341001238142, 42.2954739843096, 43.74882868358067, 44.94692741121565, 44.05445214680263, 47.801073687417166, 48.892427240099224, 56.49814428601946, 51.0924631527492, 32.202447754996165, 13.219938806125096, 43.291810921260286, 53.9567676952907, 52.8455353464399, 54.325796944754465, 58.00280448368618, 59.88181277683803, 61.76799161093575, 56.29408264160156, 54.14713096618652, 45.15133646556309, 59.21560559953962, 60.12896020071847, 61.06993389129639, 59.25278541019985, 62.79959065573556, 59.55235699244908, 57.297784669058665, 20.78291313988822, 0.014809640856193644, 0.03673435242048331, 1.7050029273544038, 2.3235892142568315, 33.48820495605469, 51.48016916002546, 54.19155427387783, 19.870230776923044, 26.71564292907715, 42.00004005432129, 32.617015498025076, 55.8352027620588, 72.75490011487688, 48.80261829921177, 30.55246945789882, 0.0746798219957522, 0.1393455799136843, 0.02793176851368376, 0.06260229899947133, 0.063331710573818, 0.03403572026374085, 0.028983090671577623, 0.023598650669945136, 0.05683950447876539, 0.04218747712937849, 0.04261330874370677, 0.09494883686836277, 0.044340193936867375, 0.049750486122710366, 0.010094121031995331, 0.028538063301571777, 0.026408309815451503, 0.04170337971299887, 0.0278101071848401, 0.055348671440567286, 0.049660105258226395, 0.009863469167612493, 0.019515247283769504, 0.037715015334210227, 0.04927939961531332, 0.04448097638253655, 0.026728508794414144, 0.04974461000944887, 0.07522419028516326, 0.05251226614096335, 0.03134780217494283, 0.01732379800107862, 0.04733453504741192, 0.052651321715010066, 0.07792488858103752, 0.034990252793899605, 0.05545003778700318, 0.02028098762301462, 0.037166484232459746, 0.029389848666531698, 0.046670069452375174, 0.03598297666758299, 0.010400887562095054, 0.057289322306002886, 0.014982897987855332, 0.050152362058205266, 0.10100022251052515, 1.562281174319131, 62.711230414254324, 59.9720698765346, 45.949330125536235, 69.96610859462193, 36.30880185535976, 28.480857099805558, 22.06199312210083, 67.20836162567139, 74.90261609213692, 54.91365276064192, 56.78777299608503, 18.545749528067454, 0.6033247858285904, 0.22084607662899153, 0.057736917931054316, 48.85145718710763, 87.12713772909981, 72.62915161677769, 73.47519901820591, 65.45326055799211, 66.99789374215263, 64.86842373439244, 66.60129751477922, 67.49239703587124, 73.46604824066162, 71.43688937595913, 70.17690999167306, 73.02998624529157, 67.4772847039359, 64.08429867880685, 55.450689452035085, 56.538475104740684, 64.59716606140137, 65.2511374609811, 59.156928062438965, 57.05648762839181, 68.3127361025129, 66.36778940473283, 64.35793263571603, 62.000686781747, 61.112053871154785, 51.71149900981358, 49.272611822400776, 47.808028834206716, 46.29087577547346, 47.896024295261924, 47.529986245291575, 45.21302604675293, 43.67288487298148, 44.98753268378121, 44.28923525129046, 45.44764239447457, 45.594635009765625, 44.48854085377285, 49.3034861428397, 50.97890526907784, 50.237633228302, 51.443590368543354, 52.07603277478899, 55.799784319741384, 59.38514859335763, 61.03066267286028, 60.43041474478585, 57.15467609677996, 58.9141024180821, 59.389359201703755, 56.56002494267055, 54.17634119306292, 58.94218703678676, 57.20797572817121, 57.18554694311959, 59.498529297964915, 53.47546945299421, 45.60609258924212, 43.22144651412964, 43.575745582580566, 42.672389439174104, 41.99751785823277, 43.92464937482561, 49.01896783283779, 50.265016078948975, 54.22751814978463, 49.407069887433735, 47.369962283543174, 44.591662543160574, 45.488362312316895, 45.40282998766218, 46.81030225753784, 46.785882813589915, 51.61496421269008, 52.84088005338396, 59.54843820844378, 55.05333934511457, 39.05347578866141, 18.923910447529384, 48.64593294688633, 59.50618621281215, 55.67487307957241, 58.25087949207851, 61.87668228149414, 62.97128759111677, 64.93104090009416, 57.89960983821324, 56.260849407741, 50.472690786634175, 62.81689861842564, 62.57139791761126, 62.55570193699428, 61.224121366228374, 66.22727598462785, 63.26067311423165, 59.79152093614851, 20.793099199022564, 0.1096344313451222, 0.20981070878250258, 3.7189694472721646, 3.266541187252317, 33.91519260406494, 53.263646670750205, 54.89971120016915, 23.074750389371598, 29.831152643476212, 29.980194977351598, 32.9716272354126, 64.80133887699672, 65.10552406311035, 58.65077263968331, 32.069685050419395, 0.07913390906261546, 0.15190341749361583, 0.04336407381509032, 0.04096374600859625, 0.02466513299649315, 0.04386098197262202, 0.0381530504008489, 0.09991800665323224, 0.033997288040284596, 0.04969412700406142, 0.04362267029604741, 0.10276239831000566, 0.0531403283322496, 0.027207652905157635, 0.027284893939005475, 0.03579477819481066, 0.03028525026249034, 0.020139065238514116, 0.010528821099017347, 0.01978383180020111, 0.013261028864820088, 0.07060422176229102, 0.15960888830678804, 0.1372846383601427, 0.14177411102822848, 0.141800655318158, 0.12873549067548343, 0.11578600268278803, 0.197965482249856, 0.136710665587868, 0.11764379085174628, 0.0976568701277886, 0.10070447623729706, 0.1543891355395317, 0.1252324315054076, 0.1389761311667306, 0.12795942303325447, 0.17772607186010905, 0.09381937461772136, 0.11359433457255363, 0.13396624928074224, 0.1453956424125603, 0.19778501907629625, 0.32100856623479296, 0.1262683237769774, 0.16603271503533634, 0.18388540563838823, 3.2869326301983426, 84.41951506478446, 67.48864500863212, 58.3637147630964, 81.2551108769008, 81.59850474766323, 44.92894894736153, 12.411898050989423, 70.92096478598458, 83.86627170017788, 59.914295605250764, 64.48159667423793, 18.930288893835886, 1.4822309783526828, 0.214556287708027, 0.25092759675213266, 51.01307998384748, 91.02570247650146, 75.47757952553886, 75.62442970275879, 68.58695370810372, 71.23901857648576, 66.31112684522355, 70.18416391100202, 71.11115782601493, 76.680771282741, 72.5813410622733, 71.96049172537667, 76.57171930585588, 72.17639310019356, 67.58371026175362, 59.30335439954485, 58.19123615537371, 69.85623673030308, 69.06667818341936, 63.03179250444685, 59.69940866742815, 69.49823079790387, 71.15512602669853, 67.49720518929618, 65.15011065346854, 63.8237829208374, 51.94251619066511, 51.39462988717215, 50.69228860310146, 47.8322502544948, 52.050987992967876, 51.94100495747158, 47.83700977052961, 46.134579522269114, 47.60325499943325, 46.02281774793352, 47.28721966062273, 49.21922533852713, 48.550912857055664, 50.796987533569336, 53.06736700875418, 51.19249289376395, 53.18324211665562, 54.6818573815482, 59.09249741690499, 59.86394201006208, 64.26468086242676, 62.678295952933176, 56.95122936793736, 60.03188691820417, 59.47745541163853, 57.31725352151053, 54.27360555103847, 60.360335213797434, 59.292543002537315, 58.48021520887102, 60.25545910426548, 53.14129931586129, 46.90688221795218, 46.70145525251116, 46.78576816831316, 42.8684606552124, 44.02628762381417, 45.56214870725359, 49.9237448828561, 53.6711619922093, 54.88793747765677, 51.84554713112967, 49.78602811268398, 46.34982429231916, 46.801662172589985, 48.17622429983956, 47.60553053447178, 49.142162867954795, 54.86990342821394, 55.095341205596924, 62.61164883204869, 61.966862951006206, 45.56303807667324, 26.28812721797398, 52.69749007906233, 59.938537870134624, 58.8418550491333, 61.938486507960725, 66.20720958709717, 65.28037548065186, 67.78804288591657, 61.03583213261196, 58.823602131434846, 55.693702697753906, 65.87929630279541, 66.3167896270752, 67.9207534790039, 63.622215679713655, 66.41573892320905, 65.91628156389508, 61.69061647142683, 24.87982984951564, 0.4734431952238083, 0.7368484267166683, 5.803253148283277, 5.147339292934962, 38.10708597728184, 59.193107332502095, 63.00014345986502, 25.647282702582224, 34.910876410348074, 53.689696311950684, 50.9925445829119, 67.03305162702287, 70.72933346884591, 62.53476006644112, 48.65696668624878, 0.1555915403046778, 0.21589583797114237, 0.08420273528567382, 0.1191964689642191, 0.16241980104574136, 0.1792471030993121, 0.1011024641671351, 0.1735993982957942, 0.15433109365403652, 0.19362337381712028, 0.09968140149222952, 0.22788017775331224, 0.11517336698515074, 0.13956725730427674, 0.18229133688977786, 0.12526224633412703, 0.12668426574340888, 0.11686544333185468, 0.10588573571294546, 0.09710860026202031, 0.12289044074714184], [0.02762571020450975, 0.03422534026737724, 0.0543630755772548, 0.017956284240686467, 0.00982189447885113, 0.013369177168767368, 0.03729570444141116, 0.03567620759297695, 0.05839382125330823, 0.046971396676131656, 0.037287952178823094, 0.017529850426529135, 0.08787193375506572, 0.04116988833993673, 0.04606524708547762, 0.020081103080883622, 0.007579225980277572, 0.052728430434529266, 0.05519121399681483, 0.03244524435805423, 0.035359542085123916, 0.10575219323592526, 0.0014199622819432989, 0.10699702679578747, 0.034239477544490776, 0.12335299806935446, 0.3007063642144203, 22.976445538657053, 70.24824019840786, 37.92817333766392, 52.94325481142317, 59.91558102199009, 64.24745627811977, 14.287118707384382, 29.090644904545375, 84.44129766736711, 70.75397872924805, 63.98229912349156, 29.093413761683873, 1.1501989322049277, 0.24180656618305615, 0.11098760659141199, 33.29153619493757, 87.39510890415737, 67.22316128867013, 77.20808397020612, 69.95001656668526, 71.87547356741769, 68.07766464778355, 67.2640722819737, 70.08416543688092, 71.42689786638532, 70.39739717755998, 68.07222420828683, 65.14739390781948, 65.9764460154942, 66.29404817308698, 55.66447857448033, 56.211565835135325, 60.272808756147114, 63.41472857339041, 45.01281023025513, 45.542249066489084, 67.19818251473563, 63.561022894723074, 60.71893869127546, 55.36445188522339, 49.451145785195486, 46.47637183325631, 43.925663811819895, 46.40944331032889, 43.62112079347883, 49.42753233228411, 49.641067845480784, 42.4104597227914, 44.270068645477295, 42.518448625292095, 43.429235867091585, 41.986077649252756, 41.86651652199881, 41.49089690617153, 42.65684979302542, 45.15779481615339, 45.47102655683245, 47.94594710213797, 46.06136635371617, 51.869869300297324, 53.22633831841605, 57.8522926058088, 47.90678358078003, 53.46126733507429, 55.74718645640782, 55.98475578853062, 55.803393908909385, 49.417787483760286, 55.60541541235787, 53.36270366396223, 58.98428617204939, 54.531540053231375, 50.75538519450596, 41.64864533288138, 41.27258103234427, 39.641404560634065, 40.577490193503245, 43.922370365687776, 46.570043972560335, 48.48645441872733, 50.5252365384783, 48.85874932152884, 48.934738295418875, 43.953883920397075, 42.630450112479075, 42.25110626220703, 43.762811933244976, 46.24525042942592, 47.002294881003245, 44.97304916381836, 47.198744773864746, 52.27807249341692, 57.272701672145296, 50.83238860539028, 22.580426011766704, 27.493997505732946, 56.22847427640642, 53.295504161289756, 53.042013032095774, 59.048994745527, 58.11557722091675, 62.87888349805559, 57.345376355307444, 54.01672717503139, 40.03161539350237, 46.05161803109305, 61.01539748055594, 58.38890198298863, 63.89670426504952, 61.73441096714565, 56.2575490134103, 37.38443858282906, 3.346874088048935, 0.13311767338642053, 2.054770576102393, 1.7098571125950133, 2.456228805439813, 30.377420016697474, 60.25208922794887, 43.83025114876883, 18.52045634814671, 46.13685853140694, 38.527771609170095, 29.40068394797189, 26.803292717252457, 39.51843186787197, 51.176671845572336, 5.9331180197852, 0.0993138729993786, 0.103581742915724, 0.04273213718884757, 0.09127955697476864, 0.03450882541281836, 0.014580343517341783, 0.03671971981280616, 0.040796823001333644, 0.05832140799611807, 0.059961440706891675, 0.043694981772984774, 0.07477740890213422, 0.0560099920257926, 0.052138973493129015, 0.10088394874972956, 0.06479041837155819, 0.06626480711357934, 0.016308560335476483, 0.01155468971202416, 0.019883662961157303, 0.0034072695333244546, 0.02020036748477391, 0.039978703151323965, 0.05647379106708935, 0.045789615982877355, 0.053451270397220335, 0.04696120847282665, 0.049463730438479354, 0.042157183933470926, 0.04257242361615811, 0.064309065629329, 0.02778681816666254, 0.023254881080772196, 0.02784095677946295, 0.03621230114783559, 0.08068799852792706, 0.07481795815484864, 0.07984011473932437, 0.09442448536200182, 0.012376495703522648, 0.016896631369101148, 0.06916246376931667, 0.03455106082505413, 0.05547653797215649, 0.06855856760271958, 0.034651175274380615, 0.1493062704269375, 0.22945459612778255, 29.165879998888286, 80.85545744214738, 39.51170948573521, 61.11540290287563, 56.053584643772666, 30.502046380724224, 20.518452542168752, 48.99037252153669, 85.73089722224644, 71.47645936693463, 68.56020314352853, 32.670756340026855, 1.276693275996617, 1.2620324684040887, 0.0735485412712608, 36.338970933641704, 90.04904978615897, 69.42061247144426, 79.60047381264823, 70.69239684513637, 74.7227897644043, 71.75174699510846, 72.18218094961983, 72.33896705082485, 75.235823903765, 70.7905193056379, 70.34859997885567, 68.46048259735107, 70.35572188241142, 67.04267488207135, 57.85125037602016, 56.7910977091108, 63.593241691589355, 68.4443210874285, 51.521677698407856, 51.58136967250279, 68.18990584782192, 65.82894270760673, 63.22345161437988, 58.77957139696394, 54.277750151497976, 48.09956135068621, 47.673087869371685, 49.286622864859446, 47.29917403629848, 53.6737745148795, 52.61700562068394, 44.967327322278706, 45.67865262712751, 44.57411139351981, 44.86323635918753, 44.82632405417306, 46.15561171940395, 45.16449982779366, 46.36070169721331, 48.052251066480366, 50.04643269947597, 50.29253789356777, 49.10189805712019, 53.142643792288645, 57.914795126233784, 60.926905223301475, 53.81420455660139, 56.41660370145525, 57.88953842435564, 58.73606872558594, 57.30340576171875, 53.5053710256304, 60.006539889744346, 55.68816498347691, 61.57746505737305, 58.703113419669016, 53.03006213051932, 45.243000575474326, 43.95371716363089, 42.331451756613596, 43.467329365866526, 44.57255499703543, 46.80279125486101, 51.61695487158639, 51.654502936771934, 51.30921220779419, 49.70457785470145, 47.49863249914986, 44.262575013296946, 43.91731207711356, 45.02859306335449, 48.631150654384065, 49.311976841517854, 49.2432313646589, 51.21362583977835, 56.722279276166645, 59.76237324305943, 56.892718587602886, 30.589590208871023, 34.20603724888393, 62.43080806732178, 55.847344739096506, 57.990075383867534, 63.41257463182722, 62.20142718723842, 66.01200689588273, 61.577249663216726, 56.06899574824742, 44.7475905418396, 49.99427604675293, 65.8830761228289, 62.8130840573992, 66.69890580858502, 62.81029782976423, 57.00345550264631, 39.762435231889995, 3.1409264419760023, 0.1360736840537616, 1.9136543997696467, 3.665352370057787, 3.29079561148371, 33.91907664707729, 63.870426177978516, 47.0077075277056, 23.955705540520803, 38.43236936841692, 28.525071961539133, 37.06147589002337, 30.761085646493093, 43.53803423472813, 56.36406489780971, 7.00108219896044, 0.11884264009339468, 0.17941996668066296, 0.05398969811254314, 0.028981621643262248, 0.04348634921812585, 0.0433232158289424, 0.02523552649654448, 0.017870988996167268, 0.057842165497796874, 0.012551295654182988, 0.06745643674262933, 0.05361769128856914, 0.06434346056942429, 0.02900598444310682, 0.09868442320397922, 0.07413864960627896, 0.03994458641058632, 0.008339178415813615, 0.028515423980674574, 0.051722166394548755, 0.04693154970716153, 0.11292194029582397, 0.16241461703819887, 0.1930083768176181, 0.10481312791151659, 0.07934434991329908, 0.09198110111589942, 0.14378228969871998, 0.09380637388676405, 0.2003898878714868, 0.11114300468138286, 0.15043877251446247, 0.11232549444373165, 0.2547716333397797, 0.2071654535830021, 0.19367460321102822, 0.19011143940900052, 0.18471595964261464, 0.1988109504537923, 0.07424568172012057, 0.15085179678031377, 0.21072306696857723, 0.2700557974832398, 0.1858504159109933, 0.12729344091245107, 0.14600901092801774, 0.2894683043871607, 0.2504052604947771, 44.8398938860212, 92.81999833243233, 50.67209366389683, 69.33999947139195, 85.95092582702637, 80.50442055293492, 17.578452587127686, 39.46816512516567, 96.21200466156006, 78.511246408735, 76.75852162497384, 34.73470483507429, 6.6973191159112115, 3.2855102036680495, 0.46118706145456856, 39.74058314732143, 92.57924325125558, 74.62810666220528, 84.77153164999825, 73.69096142905099, 77.43965353284563, 74.54634720938546, 74.04261670793805, 78.1899061203003, 80.20655822753906, 73.79726191929409, 74.7030360358102, 70.35361657823834, 72.96654224395752, 70.88163103376115, 60.835668427603586, 61.32003429957798, 68.29228060586112, 71.88110855647496, 58.750875336783274, 57.72147192273821, 71.31587954929897, 67.59791237967355, 67.14416027069092, 61.79121943882534, 57.77954496656145, 51.458306653159006, 51.15609128134591, 51.24701540810721, 50.73026398250035, 55.407992771693635, 57.16937153679984, 46.452497822897776, 49.22218874522618, 45.908724852970664, 49.34453957421439, 46.51568126678467, 47.78733709880284, 47.34108904429844, 49.52139902114868, 50.103512150900706, 53.48610367093767, 50.96037094933646, 50.70714732578823, 55.26101752689907, 59.64807537623814, 62.66956206730434, 53.54239102772304, 55.0706090927124, 59.37545585632324, 59.92847687857491, 58.4942227772304, 52.548975808279856, 61.90195982796805, 57.5837516784668, 64.43284116472516, 59.53078978402274, 53.72138704572405, 45.84475973674229, 46.903866699763704, 43.22669587816511, 44.25423717498779, 48.04472964150565, 50.40989644186837, 53.74840859004429, 54.563397543770925, 53.22359030587332, 51.66602305003575, 48.64721836362566, 46.93210417883736, 44.3676769392831, 46.318206514631, 51.884380613054546, 51.843184743608745, 51.39579023633684, 54.38508244923183, 59.57640470777239, 64.5467916216169, 61.07725729261126, 38.034723963056294, 39.03450720650809, 64.42448248182023, 57.60650702885219, 62.18869113922119, 66.18962369646344, 68.63183212280273, 69.5420947756086, 63.05556924002511, 58.91438034602574, 51.27293218885149, 51.76111262185233, 69.79890714372907, 63.19479029519217, 68.56151635306222, 66.79852213178361, 60.1568363734654, 43.57758685520717, 5.1189954195703775, 0.24782191483037813, 4.502430081367493, 9.75276165349143, 4.584105721541813, 39.415740966796875, 68.26738521030971, 52.48240859167916, 26.359594651630946, 52.47685350690569, 57.02540486199515, 43.43597214562552, 39.242300033569336, 51.659700189317974, 71.88923100062779, 16.53825514657157, 0.4038589947990009, 0.2809981788907732, 0.3028823174536228, 0.15224302427044936, 0.11485915098871503, 0.1377679452832256, 0.1422874363405364, 0.1010791700599449, 0.1733922144132001, 0.15604643018117972, 0.15028808345752104, 0.1786606859947954, 0.1662453543394804, 0.19707821628877095, 0.13893574476242065, 0.17110979902957166, 0.17814854133341992, 0.1261737902781793, 0.10152576145316873, 0.11237161446894918, 0.1432712578347751], [0.018675073349316205, 0.02590707260450082, 0.027368945768103004, 0.1110929830798081, 0.03786118874060256, 0.019627173331433108, 0.032209256663918495, 0.017188720338578736, 0.1065256078062313, 0.03219904810456293, 0.04589734020243798, 0.03559031184496624, 0.08092888524489743, 0.026481535618326495, 0.04780204567526068, 0.008307870810053177, 0.08777167342071023, 0.027778682531788945, 0.10263891172196184, 0.04049214720726013, 0.05601532191836408, 0.0418906689488462, 0.04846696928143501, 0.06214960079107966, 0.038369964475610426, 0.09679245044078146, 0.07630399734313999, 4.826275629656656, 81.64459214891706, 52.55772706440517, 52.29146862030029, 52.86111320768084, 54.07308748790196, 47.03620209012713, 8.683102113859993, 59.22253295353481, 78.59966223580497, 63.57438428061349, 28.678055661065237, 0.4915906957217625, 1.1389906193528856, 0.015474435540714433, 16.0104786668505, 78.08587074279785, 78.75537831442696, 80.69285569872174, 78.3225541796003, 76.25109468187604, 71.13597679138184, 72.30168996538434, 69.35286753518241, 63.810400690351216, 63.27919006347656, 70.54684598105294, 66.8862361907959, 67.8472067969186, 65.14900588989258, 57.06603445325579, 58.37208039419991, 60.508978026253835, 65.62961973462785, 45.241107191358296, 52.32049124581473, 68.49202741895402, 61.90234892708914, 57.77363204956055, 51.1157465662275, 48.36454480034964, 48.80938931873867, 49.48607785361153, 48.507034982953755, 47.04796191624233, 45.04467466899327, 41.9198682648795, 42.598491873059956, 43.20203672136579, 41.81603785923549, 42.502387864249094, 42.87323406764439, 42.870777879442485, 44.32432018007551, 43.42454235894339, 44.427577359335764, 44.79491472244263, 48.18489217758179, 49.66292340414864, 53.69049188068935, 55.37084075382778, 60.037375995091026, 36.09828880855015, 53.46381384985787, 57.46309968403408, 56.46572746549334, 57.77962139674595, 51.62189851488386, 56.59915024893624, 55.2922739982605, 57.7904223714556, 53.814767360687256, 50.84491968154907, 43.52196305138724, 41.23266363143921, 41.34609644753592, 42.488352503095356, 44.57176290239607, 47.587343624659944, 48.17821148463658, 49.07524824142456, 46.76243611744472, 45.280896050589426, 42.646517821720664, 42.387787750789094, 41.22011865888323, 44.21352767944336, 44.216421604156494, 45.37612806047712, 47.451909337724956, 47.937828132084434, 49.229185581207275, 53.33148888179234, 53.99850899832589, 49.7538822719029, 33.901063442230225, 49.51681668417794, 56.593522208077566, 52.47839253289359, 56.348820550101145, 58.61440576825823, 57.4819848878043, 59.78210612705776, 54.864351817539756, 36.66025216238839, 33.58352729252407, 50.48159490312849, 56.400407450539724, 58.46582548958914, 47.92436947141375, 35.39557926995413, 7.377641558647156, 0.029221683940184966, 0.10597869501050029, 0.46024883751358303, 2.425697986568723, 1.369289095912661, 35.29107141494751, 60.62529781886509, 30.021693093436106, 8.446433441979543, 26.927054030554636, 31.20789303098406, 34.15572534288679, 26.62215839113508, 50.80756269182478, 23.582344089235576, 1.0428770567689623, 0.12421262051377978, 0.02571637712285987, 0.04847743907677276, 0.016590462797986608, 0.04860191632594381, 0.03763183033359902, 0.017016051836045723, 0.06105358353150742, 0.05480003855856402, 0.04418768979875105, 0.11004827663834606, 0.07012652632381235, 0.030120094838951315, 0.06203823283846889, 0.03346129965835384, 0.007341290042469544, 0.03321086595367108, 0.054443054499902895, 0.0754697656791125, 0.02702084373283599, 0.025232953152486255, 0.0745072230430586, 0.04008811013773084, 0.053630827726530175, 0.03522642708516546, 0.030343241257859126, 0.027740136653717076, 0.029547458780663352, 0.09586221964231559, 0.03499943676537701, 0.06144871482891696, 0.053761031811258624, 0.04780808463692665, 0.05102268839254975, 0.06143798040492194, 0.0426730876788497, 0.0219886567044471, 0.04177208477631211, 0.0697070559752839, 0.059219326956995895, 0.008613415977119334, 0.06396213745964424, 0.04819757730833121, 0.05092392422791038, 0.05339229552607451, 0.0476365170574614, 0.06814696826040745, 0.0381157004407474, 7.233809070927756, 86.52661882128034, 57.73263767787388, 51.83550351006644, 63.095340728759766, 42.85535287857056, 27.07369749886649, 23.895923239844187, 75.51045840127128, 81.11463914598737, 67.70337908608573, 33.38967602593558, 0.37116500628846033, 3.476460163082395, 0.13032134915036814, 16.390011855534144, 80.30843966347831, 80.05831841060093, 81.07782758985246, 78.82108742850167, 77.29868153163365, 74.13216509137834, 76.7530881336757, 73.38509477887834, 69.31947449275425, 69.1453526360648, 72.71020930153983, 69.0629608971732, 69.63591630118233, 65.55077157701764, 59.222949845450266, 60.598581995282856, 63.116616112845286, 68.1501829964774, 50.30705615452358, 57.67810821533203, 71.21663842882428, 65.12995392935616, 59.72419984000069, 53.09032733099801, 52.06993573052542, 51.06839459283011, 50.93240097590855, 51.596853733062744, 49.16811786379133, 48.045716285705566, 46.49717126573835, 44.578766686575754, 46.047754832676475, 44.75943374633789, 45.29154416493007, 45.68620184489659, 44.528565951756065, 46.32677711759295, 47.70279836654663, 48.6455716405596, 48.21005507877895, 51.607282979147776, 52.37835236958095, 56.866006238119944, 59.70000621250698, 63.425234249659944, 39.706929547446116, 56.86725343976702, 61.502250807625906, 57.62057713099888, 61.93585314069475, 54.52499485015869, 59.46949277605329, 58.28594357626778, 60.382930755615234, 57.878591537475586, 53.578796114240376, 46.24999604906355, 44.00187860216413, 43.38335691179548, 44.99959823063442, 45.260218211582725, 50.26802464893886, 50.92696401051113, 50.6612023626055, 49.443881443568635, 48.87594263894217, 43.811980860573904, 45.14493370056152, 44.70366750444685, 47.55359969820295, 47.10128934042794, 48.0491486958095, 49.39384051731655, 51.16852855682373, 51.96752970559256, 55.49171509061541, 56.29757063729422, 53.63686220986502, 40.72369071415493, 54.91662311553955, 60.21131025041853, 57.44483286993844, 62.291065897260395, 63.94533470698765, 62.28449290139334, 63.89839962550572, 56.86269194739205, 43.89393833705357, 37.09129408427647, 53.84351553235735, 60.29744012015206, 61.00031294141497, 49.0407052721296, 37.2569009235927, 7.628294348716736, 0.1938765895153795, 0.4802920020052365, 1.013427659869194, 1.215966128877231, 2.2825742151056017, 38.32306725638253, 67.03087684086391, 33.36323813029698, 11.249374968664986, 20.705994844436646, 26.42900194440569, 37.15557534354073, 29.80915812083653, 58.977268491472515, 28.66378058706011, 1.101428549204554, 0.13307161442935467, 0.05447001608886889, 0.11461501408900533, 0.05199554476088711, 0.058781047617750506, 0.03694152951772724, 0.07967917301825114, 0.09599363151937723, 0.07208298705518246, 0.03795151532228504, 0.06855284076716218, 0.06646477816892521, 0.019898019065814357, 0.022482357087678144, 0.048763523011335304, 0.05790102841066463, 0.06519291855927024, 0.05505809560418129, 0.037753250782511065, 0.08893239577966076, 0.005466852320491203, 0.19803929328918457, 0.12625323315816267, 0.170158180807318, 0.20311738151524747, 0.11066205227481467, 0.15866045919912203, 0.13266219996980258, 0.1494960431009531, 0.24385872749345644, 0.13684236923498766, 0.1019446211201804, 0.09994119898016963, 0.19982301257550716, 0.1435413961963994, 0.1882199009082147, 0.10605931854141609, 0.16219281751130307, 0.10059207691145794, 0.21425911651125976, 0.08439589384943247, 0.12637417523988656, 0.09074036590754986, 0.13032472825476102, 0.24034983292222023, 0.21373352328581469, 0.4524311641497271, 0.17810886060552938, 11.657172560691833, 106.0345618384225, 65.97978115081787, 64.63752119881767, 68.95984268188477, 83.69879926953996, 55.1752906526838, 14.111832158906118, 69.57328523908342, 89.80854484013149, 72.45588438851493, 37.63800266810826, 1.9040856446538652, 4.848072562898908, 0.28293805622628754, 18.411329678126744, 82.0058706828526, 83.03895664215088, 82.0888043812343, 82.58243915012905, 80.8019632611956, 78.21232795715332, 81.07868221827916, 75.50941617148263, 68.96837506975446, 68.89146545955113, 76.48235852377755, 74.39641203199113, 72.49467618124825, 70.38774612971714, 61.652804374694824, 65.09685271126884, 66.08242688860211, 73.43083477020264, 55.901203700474326, 64.28515025547573, 74.37692928314209, 68.39824758257184, 62.66861016409737, 56.153100218091694, 54.55844695227486, 54.85848753792899, 55.44719450814383, 55.04031842095511, 54.23246874128069, 50.674035685403005, 46.89191232408796, 48.954961027417866, 48.73684665134975, 46.298768929072786, 49.07856600625174, 47.89347430637905, 48.39359869275774, 51.0946865762983, 49.74795893260411, 49.90826082229614, 50.06856618608747, 55.67816652570452, 55.27694974626814, 58.71530055999756, 60.4053178514753, 65.60406426021031, 43.45061200005667, 56.89943402154105, 61.5445305960519, 60.68697697775704, 63.365417207990376, 52.85858406339373, 62.18672479901995, 59.12872532435826, 61.367386272975374, 59.58289432525635, 55.78948014123099, 47.030216217041016, 45.98942123140608, 45.33420263017927, 46.47496829714094, 48.13151611600603, 52.16837780816214, 51.893291677747456, 54.86653355189732, 51.747897148132324, 50.32934944970267, 46.32817370550973, 46.98905508858817, 46.489851338522776, 49.30488967895508, 47.831096853528706, 50.34249891553606, 52.73586845397949, 53.65716137204851, 54.91028983252389, 60.68478829520089, 60.54675538199288, 59.462648800441194, 48.175491264888215, 59.63856329236712, 62.689072608947754, 60.61586911337716, 64.23146847316197, 69.7533061163766, 66.64980288914272, 67.04794161660331, 59.63706248147147, 46.55458075659615, 41.78416299819946, 55.11764144897461, 62.87479100908552, 62.86955206734793, 50.590952600751606, 40.119371141706196, 8.670879364013672, 0.5792161109192031, 0.29124555044940537, 1.0784595417124885, 6.080058089324406, 2.5175903013774326, 42.65533855983189, 72.1727522441319, 37.85157639639718, 12.942792534828186, 38.574171679360525, 49.06175831386021, 46.258028166634695, 39.06663915089199, 65.32831110273088, 48.49157871518816, 1.7564736625977924, 0.2533525180603777, 0.07316233949469668, 0.13531267988894666, 0.07397674436547927, 0.1304147427103349, 0.11805420954312597, 0.2317808855857168, 0.20218579364674433, 0.15913231245109014, 0.12832793540188245, 0.1484260612300464, 0.1824937438858407, 0.08815343757825238, 0.122035201638937, 0.20052502490580082, 0.1178064356957163, 0.14863031384135994, 0.13809573198003428, 0.12216960585543088, 0.17364648862608842, 0.18030888826719352], [0.05143639458609479, 0.01843803731857666, 0.04113116773909756, 0.0585339523053595, 0.04617822316608258, 0.06921212574733154, 0.046299830212124755, 0.09656110392617327, 0.08091935182788543, 0.049762194244457145, 0.08540437330624887, 0.047989969341350455, 0.06374585442245007, 0.060568424207823615, 0.029522210492619445, 0.006720907595341227, 0.02914672956934997, 0.04582696933565395, 0.019279354584536383, 0.017077438899182847, 0.07195312223796334, 0.014273040096408554, 0.06223608686455658, 0.008295496027650577, 0.06256190580981118, 0.02656881557777524, 0.055093871363039525, 0.06361060882253305, 20.518982342311315, 71.30645779200962, 40.459871087755474, 65.15298025948661, 51.50483873912266, 53.892740045275005, 24.746341058186122, 16.532194580350602, 69.11289065224784, 70.61216599600655, 33.05502298900059, 0.6499175599643162, 1.3690385265009744, 0.060318879384015284, 1.8294685057231357, 43.61828245435442, 76.36972822461809, 76.25087233952114, 81.87191636221749, 77.29736832209996, 74.58370767320905, 63.201543944222585, 59.41187136513846, 36.00097581318447, 52.28206075940813, 73.617171560015, 69.49816131591797, 65.26432514190674, 62.10698727199009, 61.26822853088379, 60.35219887324742, 62.81038120814732, 64.60477433885846, 54.51974548612322, 64.7686823436192, 67.7701860155378, 63.97097355978829, 56.63978678839547, 50.97863776343209, 50.94017253603254, 51.23751374653408, 51.23907709121704, 51.823316369737896, 51.10951403209141, 46.51969037737165, 44.55869681494576, 44.70788853509085, 43.94230127334595, 42.833657128470286, 42.54063769749233, 43.262534686497276, 43.850414821079795, 41.65696580069405, 44.162329878125874, 46.616933890751426, 47.53765705653599, 47.85655157906668, 49.21473332813808, 54.51087263652256, 56.67253712245396, 58.061283997126985, 44.0029034614563, 56.50596100943429, 57.19671269825527, 57.70196485519409, 58.07696955544608, 53.89266014099121, 57.07906927381243, 57.492688587733674, 59.13412407466343, 52.79576192583357, 47.72027656010219, 43.01640864780971, 41.51930809020996, 41.40046262741089, 41.10491752624512, 46.96191195079258, 47.4143716948373, 48.34339100973946, 49.207892826625276, 45.76441771643502, 43.88007320676531, 42.321880613054546, 42.983814648219514, 41.104632650102886, 45.607378005981445, 44.851705823625835, 46.41828489303589, 46.37078005926949, 49.13851158959525, 49.80212014062064, 53.13963869639805, 53.7036726134164, 58.957486970084055, 55.398956639426096, 49.090944222041536, 54.335673809051514, 57.094758306230815, 56.50102431433541, 56.310848644801546, 58.54985005514962, 57.8868077823094, 53.050357818603516, 40.79909256526402, 25.012563024248394, 30.779644284929546, 45.82133041109358, 40.22286455971854, 30.07532623835972, 12.444307054792132, 0.5466993014727319, 0.21389717236161232, 0.33101275084274157, 1.829240083694458, 1.3928665050438471, 1.2240008520228522, 38.513597284044536, 57.05161346708025, 20.305542366845266, 18.454486676624843, 32.23176220485142, 41.355900355747764, 63.143790517534526, 35.66895266941616, 42.744497844151084, 3.996111810207367, 0.19088544430477278, 0.10975317497338567, 0.0904955029753702, 0.0468521441466042, 0.023786282565976893, 0.07031379520360913, 0.06722612838659968, 0.037970663580511294, 0.10937942431441375, 0.09236504337085144, 0.033265298032867055, 0.05327626603788563, 0.04193032253533602, 0.032336390377687554, 0.03389509388112596, 0.02317158581822046, 0.022018006736678735, 0.05861888453364372, 0.03900045582226344, 0.08704844330038343, 0.036627123531486304, 0.10656659810670785, 0.0471547164821199, 0.02181098739882665, 0.04054437065497041, 0.02619484269858471, 0.04338590567931533, 0.08047357467668396, 0.04500695298026715, 0.083273088027324, 0.027611274371988008, 0.0762612157102142, 0.08703168348542281, 0.03355129375787718, 0.012621861599784876, 0.042257607116230896, 0.011919315771332808, 0.04414390054132257, 0.06605197781963007, 0.05340141842940024, 0.020014552366254584, 0.03645135921293071, 0.06521302355187279, 0.00790478368954999, 0.11227773914911918, 0.07897573576441833, 0.1344945566462619, 0.04580988043120929, 0.03879708191379905, 0.0675645816539015, 28.885657412665232, 78.44894886016846, 45.322637353624614, 73.19895253862653, 57.581632477896555, 27.1668415750776, 27.0122788974217, 35.45058468409947, 76.30881336757115, 73.63775907244, 38.266939708164756, 0.864888636129243, 3.135163779769625, 0.4416571137096201, 2.3631702789238522, 46.890157903943745, 78.24888937813895, 79.61488437652588, 83.17909485953194, 78.63915579659599, 79.63211590903146, 69.26028973715646, 64.86982032230922, 41.226212229047505, 56.51879433223179, 77.08202975136894, 69.6530019215175, 69.19014072418213, 64.63107327052525, 62.02653408050537, 61.403086117335725, 64.60149478912354, 67.01922471182687, 59.78869996752058, 66.29370076315743, 69.09108025687081, 64.0996403012957, 57.91683094842093, 51.20635454995291, 53.140979698726106, 53.323793751852854, 54.4645802634103, 53.24181890487671, 52.8935022354126, 48.59138263974871, 43.99975592749459, 46.610374791281565, 46.686631270817344, 44.19077580315726, 45.38854449135916, 45.99568503243582, 46.58262021200997, 45.60155194146292, 46.17387853349958, 49.21998964037214, 49.609040124075754, 49.74986273901803, 52.13206304822649, 57.598148345947266, 57.49450901576451, 60.01974146706717, 44.91157150268555, 57.13164629255022, 63.03193146841866, 61.28101321629116, 61.496615818568635, 59.28901331765311, 61.62489346095494, 58.75007629394531, 63.219421659197124, 56.04575054986136, 50.72758545194353, 45.66203601019723, 43.974488803318565, 44.51282828194754, 45.57142455237252, 48.72196708406721, 48.22782162257603, 51.228859765189036, 51.311713559286936, 47.846375942230225, 47.78768450873238, 45.07884243556431, 44.28031723839896, 43.20462492534092, 47.56588063921247, 47.78391858509609, 50.8110020501273, 49.42367260796683, 52.839184692927766, 52.56175007138933, 55.57897751671927, 56.406101499285015, 61.29638263157436, 57.67047561917986, 53.564722537994385, 58.53999750954764, 61.453877449035645, 62.34345531463623, 62.411193302699495, 64.776533808027, 63.41756343841553, 55.67760024751936, 45.42305966785976, 27.878147772380284, 33.10482767650059, 46.67562532424927, 42.53056975773403, 30.91373062133789, 11.935261181422643, 0.7544431654470307, 0.19193748570978642, 1.2451556197234561, 3.527393932853426, 1.5163408794573374, 1.79848008283547, 44.15788997922625, 60.49516500745501, 24.77021680559431, 18.197092396872385, 22.77445272036961, 44.02937262398856, 65.16067886352539, 38.47723388671875, 50.27504580361502, 6.345239128385272, 0.23647881778223173, 0.04323953889044268, 0.10646945224808795, 0.005286792875267565, 0.06310605696801629, 0.03890014120510646, 0.07249409785228116, 0.07463752212268965, 0.01705406167145286, 0.013581884326413274, 0.030892294831573963, 0.04476504506809371, 0.036098958658320565, 0.04137989832088351, 0.03522708187145846, 0.034462267732513804, 0.025876901544896618, 0.024438739787521105, 0.054226985201239586, 0.0563468541284757, 0.032560958327459436, 0.019739850856629864, 0.1830473198954548, 0.13573981768318585, 0.09253419536565032, 0.13924177762653145, 0.27663666435650414, 0.13265156054071017, 0.09789456094482116, 0.15978225400405272, 0.1395893096923828, 0.1806646984602724, 0.15553788175540312, 0.08040305453219584, 0.13350852312786238, 0.13788078565682682, 0.10415990903441395, 0.1074413043845977, 0.1647714405719723, 0.13487927243113518, 0.1045121094211936, 0.13163696069802555, 0.2579825424722263, 0.08726739976555109, 0.14066432629312786, 0.1769583909107106, 0.37694251484104563, 0.12611915463847773, 0.18378848369632447, 0.19906408472784928, 51.06572995867048, 90.61955942426408, 53.32033702305385, 75.62263706752232, 70.96776090349469, 72.48461518968854, 31.28955520902361, 25.81667631013053, 81.23450946807861, 81.09068175724575, 40.27795682634626, 2.8200325753007616, 4.789753726550511, 0.3755184869681086, 3.0002128268991197, 51.04151201248169, 80.31463745662144, 83.17638506208147, 85.52712045397077, 83.35010392325265, 83.57252270834786, 72.53259250095913, 64.33901269095284, 42.549114499773296, 61.77860845838274, 79.26072079794747, 77.34044020516532, 72.71145302908761, 67.22720514025006, 65.90057863507951, 65.62696552276611, 67.4656673158918, 71.2170831135341, 64.19656072344098, 69.86585303715297, 71.6149925504412, 66.69115161895752, 62.0154447555542, 56.0457192829677, 56.80440003531319, 58.39289024897984, 58.29802649361746, 58.024239676339285, 55.85197571345738, 50.93875510351998, 48.441801820482524, 51.44058179855347, 51.4809056690761, 47.75582006999424, 48.43709094183785, 48.37943478993007, 49.84088066646031, 47.32955503463745, 50.52820341927664, 51.40276275362287, 52.48570203781128, 52.56040212086269, 55.79980863843645, 60.18157196044922, 59.81403309958321, 61.32375158582415, 48.25534691129412, 59.8604679107666, 64.17669582366943, 61.669764927455354, 61.14473124912807, 56.82879516056606, 64.62541048867362, 61.76473985399519, 65.18640109470913, 57.09782246180943, 53.05871650150844, 47.00538682937622, 46.84713118416922, 45.140622343335835, 46.25582558768136, 51.277479784829275, 51.54603113446917, 53.41545786176409, 52.2614871433803, 48.5795498575483, 47.96987322398594, 45.300000122615266, 46.51012965611049, 44.426892961774556, 49.96185922622681, 50.34094599315098, 51.91953502382551, 52.19425637381417, 54.91122783933367, 55.5499826839992, 59.62921796526228, 60.790116037641255, 61.663615771702354, 61.8490423474993, 58.70111928667341, 60.1127986907959, 64.69091115679059, 65.8779205594744, 68.67994839804513, 71.40598378862653, 69.26144313812256, 59.94004562922886, 49.85334573473249, 29.779565743037633, 37.4979374068124, 47.18145070757185, 45.76988247462681, 34.62730652945382, 14.278656670025416, 0.9905214032956532, 0.685740029173238, 1.2481484477009093, 6.691497828279223, 6.668258709566934, 2.5939153943743025, 47.07700886045183, 66.80935437338692, 29.499084336417063, 24.468154294150217, 50.438279833112446, 52.91232143129621, 73.43833882468087, 46.0726432800293, 70.80103193010602, 13.019246169498988, 0.43143460367407116, 0.1665215588041714, 0.1394493550594364, 0.24250317737460136, 0.09674802675311055, 0.14717436768114567, 0.17979956631149563, 0.13890953974000045, 0.24245779695255415, 0.2280481830239296, 0.10963931679725647, 0.14571079478732177, 0.08943050833685057, 0.21030134388378688, 0.09376480004617146, 0.10712828260979482, 0.06834811318133559, 0.1550511143037251, 0.17590981003429207, 0.1329423670790025, 0.11399958282709122, 0.16262391795005116], [0.0384430732311947, 0.0199901454616338, 0.027021902247465084, 0.020878654838140522, 0.011865963410985256, 0.031799390978579006, 0.046327914776546616, 0.04999099625274539, 0.009018241843607808, 0.059163300320506096, 0.022418015004534806, 0.006664491225300091, 0.026072655505101596, 0.07358164699482066, 0.02477090642787516, 0.031831383904708285, 0.08891075051256589, 0.04236662394500204, 0.019667575002780983, 0.046887994544314485, 0.04640953236126474, 0.059125261647360663, 0.043586575625730414, 0.04648130101018718, 0.08577112148382834, 0.06911923430327858, 0.05817360271300588, 0.07222798320331744, 2.2129992970398495, 60.80695847102574, 49.67678158623831, 30.42360121863229, 67.25205189841134, 49.77819054467337, 60.67673533303397, 15.158292531967163, 34.08965492248535, 81.9523834500994, 32.83251387732369, 0.6792504659720829, 3.909074766295297, 0.185543636658362, 0.10233266851199524, 11.57743069103786, 45.118221351078574, 60.65627983638218, 63.533959661211284, 65.36351067679269, 56.321972710745676, 47.700279644557405, 30.137338910784038, 23.877838815961564, 63.451526233128135, 73.03202901567731, 65.86849185398647, 65.20605754852295, 66.35837459564209, 64.60875565665108, 61.173288345336914, 65.38795443943569, 67.19498634338379, 65.22148254939488, 70.49743039267403, 66.33365290505546, 63.55430398668562, 57.62859187807356, 52.225912366594585, 50.672663416181294, 51.89038038253784, 52.24689245223999, 55.1501590183803, 52.877146175929475, 50.38294437953404, 46.552927085331504, 43.896988596235005, 43.017235483442036, 43.61803231920515, 41.86740936551775, 43.43089648655483, 42.860334736960276, 43.77200787408011, 45.29089798246111, 47.86225605010986, 46.04513536180769, 47.200030190604075, 50.62181649889265, 57.55668497085571, 57.52611289705549, 59.098743847438264, 44.2843576158796, 61.3320894241333, 59.77049568721226, 59.1854156766619, 57.40859106608799, 57.828286579677034, 57.62920331954956, 58.71427917480469, 57.76413038798741, 51.145627294267925, 45.809289182935444, 41.951277596609934, 42.23350300107683, 42.35159111022949, 43.197475228990825, 43.6168407031468, 45.20170743124825, 45.72244712284633, 44.34645366668701, 45.058428628104075, 43.19795118059431, 45.29961797169277, 41.17437866755894, 42.429299763270784, 45.43673372268677, 44.92344944817679, 43.30441495350429, 47.07369456972395, 49.91060583932059, 47.88746411459786, 50.43250240598406, 51.602318491254536, 54.85431514467512, 53.53925739015852, 56.667774132319856, 55.11189528873989, 57.309172766549246, 58.09050464630127, 57.77362857546125, 53.03903572899954, 54.469576018197195, 51.674562386104036, 37.66253675733294, 22.780520234789165, 16.35321593284607, 27.817793982369558, 19.5121397290911, 11.969629577228002, 1.4062603520495551, 0.12586748600006104, 0.4161608618284975, 1.7912364772387912, 1.2276182579142707, 0.46043090202978676, 2.287147649696895, 48.593505314418245, 49.15859883172171, 20.97087754522051, 16.635307584490093, 40.43068170547485, 67.15342916761125, 52.63278497968401, 45.85139874049595, 24.53987012590681, 1.469799456851823, 0.08735874414976154, 0.03377592616847583, 0.07427687397492783, 0.008378274755419364, 0.07953463827392884, 0.042795302013733556, 0.054213119338133504, 0.040344511557902606, 0.019532587246171067, 0.03503637621179223, 0.03839901934510895, 0.0255302074697933, 0.09447932456220899, 0.04055292358888047, 0.14340920400406632, 0.046805830738906345, 0.06454897525587253, 0.010855674810175384, 0.06913807043539626, 0.10480156567479883, 0.03008821726377521, 0.028825972495334487, 0.06129959997321878, 0.07633751018771104, 0.056387898711753745, 0.009468107168296618, 0.05507413277934704, 0.017147233011201024, 0.07369823288172483, 0.016386016804192747, 0.006477433115443481, 0.01638550790292876, 0.04945654135995677, 0.020961697346397808, 0.005883410481536495, 0.023519516523395265, 0.03700710314192942, 0.06483660625027758, 0.049711612851492, 0.05793158962790455, 0.044555720407515764, 0.027677923474194746, 0.015678245407928313, 0.051205668931028674, 0.09999877267650195, 0.12431445504937853, 0.018244683676000153, 0.0912041717341968, 0.0398712537384459, 0.09139158989169768, 4.0367149114608765, 75.64533683231899, 52.82985673631941, 33.24184267861502, 68.91827855791364, 43.33291646412441, 36.62342323575701, 23.52721013341631, 47.26460674830845, 83.69337272644043, 37.82731328691755, 0.7393724684204374, 4.1405965600694925, 1.7147233486175537, 0.062450524286500046, 13.14269915648869, 49.25530733380999, 62.88615826198033, 67.87076119014195, 70.17615958622524, 63.69239248548235, 55.027141162327354, 34.27115229197911, 28.312363283974783, 65.10375922066825, 74.35175595964704, 71.36841487884521, 69.18549237932477, 67.5347740990775, 65.55213342394147, 64.24743543352399, 67.78344317844936, 69.54695851462228, 65.36852727617536, 70.56607164655412, 69.39748886653355, 65.72979886191231, 59.31201185498919, 55.791415214538574, 54.72229937144688, 56.97897352491106, 56.304411138807026, 56.373722893851145, 55.21976259776524, 51.373615060533794, 50.57054226739066, 46.51998220171247, 45.29599796022688, 45.94229507446289, 44.91201271329607, 45.15681859425136, 45.96078423091343, 46.287731715611045, 46.80523354666573, 50.27128682817732, 51.76284967150007, 50.453551973615376, 54.44426025663103, 60.91355078560965, 60.42521054404122, 62.50282614571707, 48.33974320547921, 63.56406620570591, 63.45110934121268, 63.91399833134243, 61.42789813450405, 62.93093940189907, 61.120148522513254, 62.228045736040386, 61.729561124529155, 53.76666498184204, 50.4386967250279, 46.50553342274257, 43.58487204142979, 44.45177098682949, 45.50877264567784, 48.34218897138323, 47.66983263833182, 47.24797623498099, 46.208053248269216, 44.47429357256208, 45.430918080466135, 46.309403147016255, 44.20278229032244, 44.17997830254691, 48.53346593039376, 48.52871683665684, 48.42049864360264, 50.51419585091727, 51.79097250529698, 52.057828494480674, 54.36374453135899, 54.78267574310303, 59.372447286333355, 56.056885038103374, 59.32426847730364, 59.166273389543804, 61.09260586329869, 61.52285916464669, 64.64521285465786, 60.372640473502024, 61.003620283944265, 56.19035298483712, 40.9213878086635, 24.565488134111675, 17.71984495435442, 29.633941922869, 20.617603336061748, 12.045620288167681, 1.2695296832493372, 0.12474824248680047, 1.2483673159565245, 2.6299383299691335, 4.088303114686694, 1.2190170394522803, 2.5658670365810394, 52.25998633248465, 52.11582163402012, 29.36548784800938, 14.329659921782357, 37.88237081255232, 70.07532038007463, 54.3546667098999, 53.10473094667707, 32.64310598373413, 2.1152146926948, 0.11026654099779469, 0.13874985330871173, 0.05508076545915433, 0.0344060409281935, 0.032934885405536206, 0.05612429464235902, 0.07679051373686109, 0.04095922018002186, 0.05195767232882125, 0.044154967447476726, 0.042643618902989795, 0.039381928209747584, 0.04339052311011723, 0.02975061216524669, 0.026718836277723312, 0.0198763856730823, 0.06261513688202415, 0.016358103569863097, 0.02495343574056668, 0.06910824882132666, 0.018793511636821286, 0.047838476220411916, 0.21011632095490182, 0.3207872823945114, 0.17574747731643064, 0.23226286258016313, 0.21039624379149505, 0.20359292599771703, 0.20354747772216797, 0.07301727549305984, 0.10195701795497111, 0.14451404900423118, 0.19402008610112326, 0.09818791198943343, 0.10729877810393061, 0.20827134352709564, 0.13106709984796389, 0.2171602336955922, 0.2258957206670727, 0.1491981390863657, 0.12074548298759119, 0.14563796083842004, 0.17000416692878517, 0.15988676196762494, 0.1745783207671983, 0.24396178339208874, 0.22671514669699327, 0.15650924534669944, 0.11620452308229037, 0.28212110006383484, 8.958888275282723, 97.00138255528041, 63.453541210719514, 47.289554255349294, 81.37304959978376, 73.47100925445557, 74.28897203717912, 21.01871762956892, 44.47987297603062, 93.60917472839355, 41.24429838997977, 1.2321959265640803, 7.439498765128, 0.8003654927015305, 0.10362094188375132, 13.868721638407026, 48.73137494495937, 61.965035574776785, 68.86032363346645, 69.8493093763079, 65.26515892573765, 58.57104900905064, 35.30563831329346, 35.34883526393345, 70.49011393955776, 81.82461997440883, 76.16641698564801, 73.67064489637102, 73.93925530569894, 69.02023642403739, 67.59969111851284, 70.6942172731672, 73.8455935886928, 68.7098673411778, 73.16196727752686, 72.05429935455322, 69.89258275713239, 63.75512082236153, 57.4673867225647, 55.85984107426235, 59.38375200544085, 59.22450624193464, 62.05049841744559, 59.75201347896031, 55.37878949301583, 53.13719640459333, 48.21341800689697, 47.8705278805324, 49.50264235905239, 47.27966349465506, 48.216798305511475, 47.60684026990618, 49.88043328693935, 48.45776878084455, 53.650157587868826, 55.91284193311419, 52.56933403015137, 58.414881297520225, 63.5145047051566, 61.23245225633894, 64.62738377707345, 50.68806062425886, 63.92857565198626, 65.05357238224575, 65.83071449824742, 62.68689087459019, 62.08733081817627, 63.862185614449636, 64.44224207741874, 63.708130155290874, 55.17470700400216, 52.01128946031843, 47.49037109102522, 45.55634696143014, 46.59080866404942, 47.685386180877686, 48.2917137827192, 48.676814215523855, 47.92713138035366, 47.98030941826956, 46.417593547276084, 47.0144681249346, 49.18995257786342, 44.24111897604806, 45.582715375082834, 49.0501582963126, 50.52044922964913, 48.22596297945295, 53.47702237537929, 53.01706552505493, 53.68296698161534, 56.89864540100098, 56.71535192217146, 62.795456477573936, 58.120805740356445, 62.99941389901297, 61.22255107334682, 63.7732903616769, 65.92605073111397, 69.47958878108433, 66.33088057381767, 68.84052126748222, 58.30575289045061, 45.75126477650234, 28.15103132384164, 19.58458685874939, 30.554348945617676, 22.852546998432704, 13.07383816582816, 2.333098041159766, 0.24782756024173327, 1.8243001316274916, 3.4485223250729695, 7.584654450416565, 3.227110811642238, 3.745396052088056, 57.91546215329851, 59.82176644461495, 30.042419569832937, 24.76833384377616, 54.735921314784456, 73.35140991210938, 66.60371548788888, 62.012686320713584, 44.93793991633824, 2.9381582481520514, 0.5005932812179837, 0.2129959828619446, 0.1532621295856578, 0.10821731095867497, 0.2626453808375767, 0.12475170301539557, 0.09569928302828755, 0.15822502970695496, 0.18660003425819532, 0.1452617131705795, 0.1214059554040432, 0.09145798454327242, 0.15591012606663363, 0.19655822776257992, 0.22018816907491, 0.22023901848920754, 0.1313664966395923, 0.17234630696475506, 0.17122918048075267, 0.1477666880403246, 0.11606066008763653, 0.13889765180647373], [0.08027029915579728, 0.07391927244939975, 0.05971218765314136, 0.035150767037911076, 0.07682653037565094, 0.04067241699833955, 0.07919615786522627, 0.06574151412184749, 0.06993534908230815, 0.05315917803506766, 0.01060168388565736, 0.024344326728688817, 0.03333956029798303, 0.06901466527155467, 0.06672484707087278, 0.11432734238249914, 0.07100666766720158, 0.026886727893725038, 0.06191815249621868, 0.05589182854497007, 0.038885973393917084, 0.024671014198767285, 0.05526541519377913, 0.045021938426154, 0.013557371400695826, 0.016786271040993075, 0.023361234659595147, 0.16633238324097224, 0.4026880333466189, 48.09690713882446, 80.00956290108817, 63.53375816345215, 89.46718679155622, 51.12702349254063, 52.35872023446219, 29.273924486977712, 19.220932040895732, 75.45075253077916, 50.254906449999126, 1.9937278287751334, 4.078824903283801, 2.9409244997160773, 0.082211391068995, 0.6955569109746388, 9.318736348833356, 27.441496917179652, 32.221791539873394, 35.521053314208984, 27.981059278760636, 18.656109503337316, 12.657738345009939, 49.619236605507986, 73.4908116204398, 67.51012189047677, 63.77943951742989, 66.92878695896694, 68.40753037588937, 68.49746091025216, 63.902325357709614, 65.80621515001569, 68.13983712877545, 65.93682738712856, 73.2166496004377, 66.96896839141846, 64.55873557499477, 56.34603084836687, 51.50779172352382, 51.487426553453716, 48.88050760541643, 50.72816562652588, 52.005067348480225, 52.960524559020996, 52.11731202261788, 49.01336063657488, 46.92853627886091, 44.21881178447178, 45.34087290082659, 42.47774607794625, 44.95597396578108, 43.06143992287772, 44.01555265699114, 46.13068158285958, 45.82255676814488, 46.672408308301655, 47.45817313875471, 48.74348912920271, 54.5440468106951, 56.001883098057334, 57.91665376935686, 38.269632135118755, 59.37228747776577, 57.29364006859915, 55.10600321633475, 57.23380218233381, 58.40445899963379, 55.88234976359776, 58.50927952357701, 53.69128050122942, 49.21936777659825, 44.06420741762434, 41.24881819316319, 40.72019577026367, 40.960002422332764, 42.45259707314627, 44.41720717293875, 44.05461195537022, 44.47185475485665, 47.16007457460676, 45.95971073423113, 45.48473882675171, 45.525093964168, 45.570229462214876, 44.126227038247244, 45.31417097364153, 45.87378931045532, 47.2240640095302, 45.77430847712925, 49.37529924937657, 50.434110913957866, 51.607512269701274, 53.37406744275774, 57.361583028520855, 57.56777082170759, 56.06953075953892, 56.474377972739084, 58.502769061497276, 59.29904651641846, 56.92537859507969, 55.14960316249302, 51.281012943812776, 42.03445795604161, 31.48281240463257, 17.681813989366802, 11.621894819395882, 11.93355279309409, 5.2277156199727735, 0.9297182602541787, 0.05138799807588969, 0.3560359552502632, 0.4832304928983961, 2.7720648178032468, 4.33305948972702, 0.6185763531497547, 3.494531124830246, 47.52968052455357, 50.86538560049874, 20.551067386354717, 40.360324246542795, 43.386129243033274, 48.104977471487864, 34.43090179988316, 52.597613198416575, 16.78074380329677, 0.3330757687134402, 0.11915718178663935, 0.08887569739350251, 0.09074038626360041, 0.10664984078279563, 0.008338527870364487, 0.048927965973104746, 0.03395849958594356, 0.04697854504255312, 0.01518416843776192, 0.04610696681109922, 0.07623300900948898, 0.06975262638713632, 0.04393598384090832, 0.052575458107250075, 0.033483762560146194, 0.05724643210747412, 0.0277864856845034, 0.025713274521487098, 0.031726468820124865, 0.07986754112477813, 0.008818507427349687, 0.057822209782898426, 0.10897953648652349, 0.07695536381964173, 0.02471746500980641, 0.009490455567304577, 0.05520040136096733, 0.03040543577766844, 0.1097113907869373, 0.08542944517518793, 0.06444790067949466, 0.03917949067960892, 0.04149206694481628, 0.032581721499030075, 0.054640925489366055, 0.046586168597319295, 0.036511049938521216, 0.041949979694826264, 0.035045790885175974, 0.04297873377799988, 0.033825628858591826, 0.08836480123656136, 0.0618756694187011, 0.02698517993225583, 0.03485306319115417, 0.055410648829170635, 0.02503683787238385, 0.03464257823569434, 0.05805613473057747, 0.11455120465585164, 0.46193936680044445, 53.93227529525757, 85.47140979766846, 59.601105553763254, 90.15075056893485, 56.13014336994716, 39.576115812574116, 26.97625596182687, 33.0089807510376, 77.41521671840123, 54.93210717609951, 2.33820127589362, 4.375674094472613, 4.740831894533975, 0.6439354323915073, 0.9377571088927132, 9.964460236685616, 30.460683754512242, 35.56117916107178, 39.965590136391775, 34.38494641440255, 22.99351031439645, 16.982430900846207, 51.99729926245553, 75.03772381373814, 72.43934072766984, 70.29519612448556, 71.68558624812535, 71.3651144845145, 70.63455309186662, 66.08900683266776, 66.95958832332066, 68.5731337411063, 68.1589446749006, 73.68192877088273, 66.6144574029105, 67.42394338335309, 59.94893932342529, 55.752390657152446, 56.50397035053798, 54.71180411747524, 56.34085444041661, 54.38622195380074, 55.01902914047241, 53.94474731172834, 48.636563301086426, 47.925019127982004, 47.048823492867605, 46.17635556629726, 43.03965732029506, 46.77552652359009, 46.46651928765433, 46.100460393088206, 47.86009863444737, 49.23363937650408, 49.913551875523154, 49.67346729551043, 51.54080956322806, 59.439969880240305, 59.91185678754534, 59.9073543548584, 42.566408566066194, 63.96124608176095, 61.80588708605085, 60.002655846732004, 61.844845635550364, 62.265579904828755, 60.67335850851876, 63.02782508305141, 60.096074376787456, 53.48519345692226, 49.84340981074742, 44.94753190449306, 45.463758741106304, 44.65836872373308, 47.211751801627024, 47.39789056777954, 46.6862074307033, 47.21142871039254, 49.39425046103341, 46.874729428972515, 47.04031889779227, 47.11670739310128, 47.681241580418174, 46.16472775595528, 48.097087791987825, 48.22636597497122, 51.88961260659354, 49.84831871305193, 53.8472432409014, 52.48045267377581, 57.09894806998116, 55.691559178488596, 58.936871664864675, 58.854257583618164, 59.220351219177246, 59.712255886622835, 63.022759846278596, 62.139650753566194, 63.71136801583426, 61.631299700055806, 59.03678676060268, 46.26959344318935, 34.79105819974627, 17.789253984178814, 12.343079618045262, 12.172708920070104, 6.276343830994197, 0.6660110535366195, 0.35238071424620493, 0.902766903596265, 2.488455419029508, 5.576304137706757, 3.8797676989010403, 0.24264892669660704, 4.805179161684854, 53.06252064023699, 65.99660968780518, 19.82064495767866, 34.53824799401419, 51.106696537562776, 48.51528596878052, 41.210064615522114, 60.702415875026155, 18.226121970585414, 0.5104502237268856, 0.314798043774707, 0.10092772104378257, 0.01336371072102338, 0.1542342124240739, 0.029252726917288134, 0.05629021681046911, 0.06697618322713034, 0.0632443627608674, 0.13125166137303623, 0.11829302672828947, 0.07614580368889229, 0.02259107705737863, 0.05162242513948253, 0.06486741174012423, 0.060962965179766924, 0.0465731135835605, 0.06241232955030032, 0.011972904770768114, 0.09865532762237958, 0.10609913497631039, 0.09602481020348412, 0.0588646906294993, 0.26567693959389416, 0.2026533992694957, 0.177955226706607, 0.1648646170007331, 0.12254919191556317, 0.15447757579386234, 0.2681952273207051, 0.19137252388255938, 0.15565976021545275, 0.21065866042460712, 0.1688297449478081, 0.08303220131035362, 0.11716887062149388, 0.20352698596460478, 0.13962314144841262, 0.23883718837584766, 0.21930577499525888, 0.15605162775942258, 0.10381095883037363, 0.11357885040342808, 0.14618920268757002, 0.20367566655789102, 0.11029719720993723, 0.18760623383734906, 0.13325118193668978, 0.07720507149185453, 0.07103385656539883, 0.29182301089167595, 0.9805391217981065, 72.21155793326241, 96.05687917981828, 73.12491948263985, 100.62065751211983, 68.59563895634243, 71.33757182529995, 38.088482175554546, 26.793040650231497, 87.21171815054757, 60.42887224469866, 3.9697746634483337, 11.227484669004168, 7.094970600945609, 0.4822585593376841, 1.2954911930220467, 11.34210215296064, 33.23655162538801, 34.54541853496006, 41.749453272138325, 32.818985734667095, 25.036899089813232, 22.335771254130773, 65.21137292044503, 85.47969899858747, 80.58153860909599, 77.37794658115932, 77.23489012037004, 74.9216194152832, 75.37309946332658, 68.14045551845005, 71.28619684491838, 73.63231863294328, 70.09846482958112, 75.74774633135114, 68.25073732648576, 68.91868850163051, 60.49441460200718, 58.31976740700858, 58.35391780308315, 55.83884709221976, 60.70649446759905, 58.609333583286826, 57.40705898829869, 55.41442680358887, 54.35468060629708, 51.90379040581839, 49.9056031363351, 50.33492885317121, 46.98763418197632, 48.45298147201538, 49.55494144984654, 47.86090462548392, 52.80217163903372, 52.9558310508728, 54.289933817727224, 52.82996095929827, 53.31661973680769, 61.75526251111712, 62.296534129551475, 63.9167081287929, 44.85929673058646, 66.0751312800816, 64.3480453491211, 61.552639143807546, 64.46872166224888, 63.226265634809224, 62.532661710466655, 63.67543888092041, 62.258159228733604, 54.318299838474815, 51.69936050687517, 45.81624780382429, 48.46156597137451, 46.11786215645926, 49.64819322313581, 49.32720381872994, 49.203914982931956, 49.98806435721261, 52.737817423684255, 47.26758405140468, 48.62860066550118, 48.42923252923148, 50.3614536012922, 48.08856235231672, 49.63946975980486, 50.94672121320452, 54.85425608498709, 52.91929742268154, 55.48821667262486, 55.23891183308193, 57.789185592106406, 57.54350076402937, 62.668957574026926, 60.07050500597273, 62.963734899248394, 62.046628270830425, 65.09817286900112, 64.69255787985665, 68.19747243608747, 67.10117871420724, 66.76893670218331, 49.795731272016255, 38.51737362997872, 19.27115535736084, 14.17916020325252, 13.77076940877097, 8.288976839610509, 1.6577788442373276, 0.3560686063553606, 0.8784875092761857, 2.1961195170879364, 8.486859798431396, 12.790202277047293, 2.6933258771896362, 5.7974735498428345, 60.59484386444092, 64.14900030408586, 25.386749574116298, 57.31870222091675, 54.38784435817173, 59.76442296164376, 48.220734460013254, 71.0704483304705, 26.94428382601057, 0.7285967352134841, 0.4104355461895466, 0.26945572825414793, 0.21455532418830053, 0.3034637133990015, 0.1899978526468788, 0.17589722999504634, 0.22298023211104528, 0.17499503626355103, 0.21134657279721328, 0.2611767867846148, 0.24448661665831292, 0.12565828008311136, 0.10984726063907146, 0.27814721901501926, 0.15387107405279363, 0.19793527387082577, 0.23642334075910704, 0.07767198500888688, 0.2236945666372776, 0.19001218330647263, 0.21845251720930847, 0.1387276787843023], [0.013180725941700595, 0.054759791253932884, 0.05285677194063153, 0.060362699175519605, 0.11363263108900615, 0.09766189807227679, 0.038687244057655334, 0.02730495313049427, 0.03908858055781041, 0.04737342867468085, 0.038577429950237274, 0.03399939828419259, 0.04619032144546509, 0.009045513014176061, 0.05519751419446298, 0.07475036928164107, 0.053445811582995315, 0.04841550240027053, 0.03954219139580216, 0.07289007053311382, 0.06990609743765422, 0.052289883073951514, 0.1256755827260869, 0.07431161496788263, 0.029333272416676794, 0.04402804747223854, 0.18140037969819137, 0.26839867926069666, 0.20177515782415867, 20.361136640821183, 85.15701075962612, 62.984676769801546, 71.92056737627301, 49.68898262296404, 44.17243255887713, 37.915221895490376, 15.39106239591326, 45.480979851314, 60.89513805934361, 0.7090228455407279, 1.81930068561009, 3.6133587828704288, 0.45873771288565224, 0.17554061913064548, 1.3130399542195457, 5.989432300840106, 10.034490261759077, 9.691200613975525, 7.340721436909266, 5.470355400017329, 21.562320368630544, 61.293985503060476, 64.78187697274345, 69.75118691580636, 63.22869750431606, 69.96546936035156, 71.65029634748186, 73.49532100132534, 67.04564871106828, 67.5728988647461, 72.17159884316581, 66.9534878049578, 72.21813787732805, 70.71649319784981, 64.07081917354039, 58.67380591801235, 54.923213481903076, 49.28229761123657, 44.13462393624442, 43.4596585546221, 52.10913051877703, 58.083090918404714, 55.600318908691406, 52.56651306152344, 51.441644872937886, 48.39700331006731, 44.30613327026367, 46.48739167622158, 43.23413739885603, 44.02851799556187, 43.68646165302822, 44.87954378128052, 44.55056047439575, 46.01761702128819, 45.02258634567261, 48.36291197368077, 57.02460581915719, 57.773288113730295, 55.7311361176627, 31.595904758998326, 53.93899072919573, 58.54732091086251, 53.30042348589216, 56.60361099243164, 55.590094634464805, 56.40999596459525, 54.18513066428048, 50.5822743007115, 46.40102556773594, 43.33467435836792, 40.5620756149292, 43.28630794797625, 42.741214820316856, 43.7121456691197, 44.48869024004255, 43.04431956154959, 47.316593170166016, 50.05522217069353, 49.93596676417759, 51.84750304903303, 49.155531202043804, 47.99356310708182, 46.32276453290667, 47.469109603336875, 43.98040172031948, 45.3289532661438, 46.10533455439976, 48.27306481770107, 51.701649938310894, 52.793719155447825, 52.31800726481846, 52.164841175079346, 51.93802418027605, 55.200411864689414, 58.775555338178364, 57.760096958705354, 57.68046712875366, 59.57163824353899, 54.87184544972011, 50.99866941996983, 37.58195502417428, 20.81081189428057, 9.07124846322196, 5.05252982037408, 2.766185773270471, 0.09074131585657597, 0.3489146488053458, 0.16119444822626455, 0.8983005689723151, 2.36013891015734, 5.127998113632202, 1.9851444150720323, 0.5491617321968079, 3.1417150625160764, 49.52189929144723, 13.750478063310895, 29.67689916065761, 46.59457458768572, 20.768858671188354, 30.77267176764352, 49.33626774379185, 38.71000896181379, 0.37224420266492025, 0.04054815348769937, 0.07792391827596085, 0.019510718062520027, 0.0720081175012248, 0.015835987836388603, 0.06704793830535241, 0.08011906048549072, 0.16458024297441753, 0.07084516276206289, 0.03181737894192338, 0.06300399851586137, 0.060169689889465056, 0.13538431961621555, 0.03281489327283842, 0.008630317436265094, 0.0707472094467708, 0.07328333585922207, 0.04591251563813005, 0.06925465632230043, 0.040221228530364375, 0.0708363214507699, 0.026498705946973393, 0.05020864314532705, 0.022793970902317336, 0.023860015573778322, 0.01687550009228289, 0.06574640635933195, 0.08099740371108055, 0.11997563072613307, 0.060863274814827104, 0.011853902451028782, 0.052813902098153315, 0.008238139462524226, 0.03166156016024096, 0.06152787272419248, 0.03648702979886106, 0.02285176681886826, 0.05144064900066171, 0.07558264676481485, 0.06230497852499996, 0.04480797937139869, 0.09217113841857229, 0.08588101023009845, 0.06516274410699095, 0.003468321993880506, 0.06795856622712952, 0.012552334660930293, 0.24047074786254338, 0.04622833297720977, 0.22203412359314306, 0.11866404967648642, 0.479183058653559, 21.299810477665492, 94.80031136104039, 64.35566752297538, 79.23169122423444, 59.424412863595144, 40.740804127284456, 25.565962723323278, 23.190404891967773, 58.75542640686035, 61.75435924530029, 1.6266628567661559, 2.414811896426337, 5.972420070852552, 1.5990038152251924, 1.0230883700507027, 2.570459795849664, 6.559412573065076, 11.495577437537056, 11.956769330160958, 9.08077096939087, 7.776297926902771, 26.573917048318044, 65.90791593279157, 69.39741243634904, 74.67723737444196, 72.28160272325788, 75.86040442330497, 75.28965159824916, 75.88414641789028, 68.72588988712856, 70.48798779078892, 71.19819096156529, 69.9450694492885, 73.73954323359898, 73.78200367518834, 68.49999005453927, 62.87453392573765, 58.58255522591727, 55.97773115975516, 51.237854208265034, 51.457354749952046, 56.1411771093096, 59.34445299421038, 56.966491086142405, 56.03274004799979, 52.089276041303364, 50.28033338274275, 46.84668302536011, 48.60423680714199, 45.395409311567036, 47.14796039036342, 45.92395877838135, 48.42846475328718, 48.523773193359375, 50.150495869772776, 48.850529602595735, 52.098673479897634, 60.66042096274239, 62.5104135785784, 60.40576253618513, 34.19751875741141, 61.16745185852051, 63.7650636945452, 57.76174020767212, 61.131974356515066, 60.589695249285015, 59.47098663875035, 58.47755404881069, 55.927683285304475, 49.11031927381243, 47.95120688847133, 43.94392367771694, 46.41334819793701, 43.87048121861049, 48.444053036826, 48.66518293108259, 46.784006799970356, 49.34577635356358, 53.36908558436802, 53.34514556612287, 53.21582221984863, 50.79538944789341, 51.81964077268328, 49.563727446964805, 51.27868529728481, 47.78807360785348, 48.74237046922956, 50.38523381096976, 53.64005143301827, 55.96176767349243, 58.60169056483677, 56.32932390485491, 57.49429014750889, 55.61765813827515, 59.53768239702497, 61.319805009024485, 61.87650162833077, 60.890600885663716, 64.07333442143032, 62.059364318847656, 58.17038461140224, 42.894453866141184, 23.425207104001725, 10.190350515501839, 5.429331064224243, 3.5278790039675574, 0.04693978712228792, 0.8067183175257274, 1.1953754680497306, 2.799315652676991, 5.033545170511518, 3.1560620069503784, 1.9857814780303409, 0.15661226053323063, 3.875935333115714, 52.906439781188965, 21.16138846533639, 28.519836493900844, 51.01645333426339, 28.218908275876725, 34.53035831451416, 58.22727646146502, 40.80008963176182, 0.36511125255908283, 0.05900816007384232, 0.09971546395016567, 0.024099512990298014, 0.07416797588978495, 0.03713576355949044, 0.07835143604981047, 0.06263735890388489, 0.04369721415319613, 0.03824341769463249, 0.0632768849443112, 0.08462553045579366, 0.05674564272963575, 0.07953902161014931, 0.06944965371595961, 0.02332047845370003, 0.05397793910066996, 0.014615213431950127, 0.05587691773793527, 0.053310779721609185, 0.027907122425468903, 0.07399798929691315, 0.01962269839298512, 0.03745603887364268, 0.1364969949104956, 0.11200626407350812, 0.1727629274662052, 0.10773019066878728, 0.2311084573822362, 0.29705242599759785, 0.12882984775517667, 0.15519942848810128, 0.08577712651874338, 0.16067645459302834, 0.1486536825874022, 0.12523813119956426, 0.13421014190784522, 0.17125303777200834, 0.12691651470959187, 0.14551971932607038, 0.14118864387273788, 0.11617868446878024, 0.1320499035396746, 0.17141374200582504, 0.21800952883703367, 0.06531818290906292, 0.175906240940094, 0.13305756875446864, 0.3830845595470497, 0.11858426752899374, 0.4074844074036394, 0.36539338741983685, 0.6976095608302525, 31.149823461260112, 106.82683713095528, 74.27959891727993, 84.28890282767159, 66.11260291508266, 61.1735315322876, 51.847645487104145, 21.949600798743113, 56.544763224465505, 72.28243650708879, 1.4699700134141105, 6.319028786250523, 13.202174867902484, 1.435017860361508, 0.9909685850143433, 2.083487263747624, 6.359670536858695, 12.599288361413137, 10.688620601381574, 9.162104845046997, 9.15964778832027, 35.226161343710764, 74.38170964377267, 76.74022006988525, 82.62399632590157, 80.53028174809047, 85.571672303336, 79.16297354016984, 80.49557549612862, 74.23297650473458, 75.47375801631382, 75.9817338671003, 71.6229829788208, 74.00637490408761, 74.10472665514264, 71.14009707314628, 64.65070193154472, 58.428089823041645, 57.67238984789167, 55.51558910097395, 55.43895047051566, 59.78643485477993, 62.365453311375205, 61.9348178591047, 59.913190841674805, 56.321903228759766, 54.145442553928916, 47.91591003962925, 51.3312657901219, 47.914728845868794, 48.8505608694894, 47.72202055794852, 49.73335729326521, 50.0776926449367, 52.27643619264875, 50.65496288027082, 54.60863726479666, 62.85416875566755, 65.72178064073834, 60.62612465449742, 37.11915636062622, 60.81384413582938, 65.92302826472691, 60.07343714577811, 61.13467720576695, 60.98054531642369, 61.248863901410786, 59.86636693137032, 57.42491933277675, 50.288726806640625, 50.293090275355745, 46.87232535226004, 48.62408433641706, 46.221782888684956, 50.31701292310442, 51.111713136945454, 46.98102644511631, 51.31544821602957, 54.06661524091448, 54.30936445508684, 55.61949941090175, 52.327769483838765, 53.49610560280936, 50.94295181546892, 53.05787576947893, 49.07505716596331, 52.017657484327046, 52.59219012941633, 55.48135532651629, 59.08741133553641, 59.60747010367257, 58.49359743935721, 58.78979219709124, 58.24467822483608, 62.258082798549104, 63.23495088304792, 64.00964028494698, 63.41884190695626, 68.96171869550432, 66.2330846786499, 62.33918217250279, 44.81633601869856, 26.319826636995586, 11.305154238428388, 6.3507255996976575, 4.474614705358233, 0.8124344050884247, 0.8655033888561385, 0.8067707004291671, 2.531415479523795, 5.961306427206312, 10.911169665200369, 6.902860726628985, 1.9987539819308688, 4.812392260347094, 58.22818667548043, 22.904901674815587, 41.98362493515015, 60.81965977805001, 30.821479388645717, 45.37200777871268, 63.46783365522112, 57.94151789801461, 1.1779864068542207, 0.1398607101291418, 0.2747490613588265, 0.17550837514655931, 0.16651079723877565, 0.16212211416235991, 0.188377388886043, 0.2622832602688244, 0.23044601721423014, 0.251449960150889, 0.12066703076873507, 0.19866441403116497, 0.21215987844126566, 0.17164573312870093, 0.20743457414209843, 0.1054817834602935, 0.1352918760052749, 0.19221013465097972, 0.11541241487222058, 0.14803816990128585, 0.1437522577387946, 0.23488591611385345, 0.15584829795573438, 0.22071669357163565], [0.05733747793627637, 0.13503792748919555, 0.041469061215009005, 0.01979030163160392, 0.029836066865495274, 0.07415048325700418, 0.029421458220375434, 0.14575145260563918, 0.025407368882692287, 0.04559291546632137, 0.06621395091393165, 0.0757859969245536, 0.01966627051920763, 0.04036291342760835, 0.09393710722880703, 0.047365486422287564, 0.03410347198535289, 0.043907461621399434, 0.06786579691937991, 0.07501598181469099, 0.013879178507652665, 0.03371572314894625, 0.0747207919401782, 0.03493030083232692, 0.07332577143928834, 0.018292533965515237, 0.04586236511490174, 0.07872336823493242, 0.17505538516810962, 0.2106660564563104, 60.17271300724575, 73.39935943058559, 42.43610552379063, 36.621575014931814, 56.69183226994106, 55.883016790662495, 26.135775804519653, 22.35056049483163, 67.23923247201103, 1.5981475583144595, 2.3189586741583685, 2.992942188467298, 0.9701763178621019, 1.0585590324231555, 1.441896902663367, 0.3204290973288672, 0.5022290391581399, 3.0117633385317664, 3.638721010514668, 12.164757575307574, 30.98999752317156, 55.292152404785156, 65.21313081468854, 67.66592134748186, 63.673889432634624, 65.93707752227783, 74.31144945962089, 72.25763143811906, 69.7275699887957, 69.91228784833635, 74.42610168457031, 65.1897223336356, 76.0677386692592, 72.8106941495623, 67.78119196210588, 59.481179646083284, 54.94157757077898, 45.59378732953753, 41.38125433240618, 43.44492837360927, 53.7139698437282, 56.94685547692435, 56.91487986700875, 57.91256128038679, 58.07417637961251, 56.458994661058696, 51.502313068934846, 47.49082967213222, 48.22139801297869, 46.50869485310146, 44.902264390672954, 42.84303024836949, 47.94229582377842, 47.24327577863421, 45.329481329236714, 51.3117413520813, 58.468889645167756, 54.39396572113037, 59.412177085876465, 28.445567199162074, 51.34747246333531, 58.95360292707171, 51.67748410361153, 53.21771560396467, 51.69531318119594, 50.56384072984968, 50.365063190460205, 49.58678156988961, 43.639526571546284, 43.25258834021432, 40.8985595021929, 42.57054969242641, 40.58373314993722, 42.68746703011649, 42.68642480032784, 47.832284995487754, 54.20427295139858, 56.992192472730366, 58.92815167563302, 54.394080366407124, 51.85223477227347, 50.05877270017351, 47.42143106460571, 45.95233522142683, 44.21235343388149, 46.53641121728079, 45.63014725276402, 47.297443934849326, 51.34108359473092, 51.87891238076346, 55.409837518419536, 55.9939204624721, 53.94384057181222, 57.14090824127197, 58.290439060756135, 61.73309080941336, 60.207989011492046, 61.66217054639544, 58.525031089782715, 50.67236811774117, 30.047161715371267, 12.233588167599269, 2.175007849931717, 0.8147372986589159, 0.3221891628844397, 0.27415588604552404, 0.5554463235395295, 0.8468849850552422, 2.9799004197120667, 4.150618468012128, 2.6563323651041304, 1.8552289519991194, 0.20980901244495595, 10.385876297950745, 44.192891529628206, 19.45999697276524, 51.618087427956716, 34.603415148598806, 36.90892471585955, 38.96716526576451, 59.31570829663958, 7.986614687102182, 0.049891048044498475, 0.1107114903362734, 0.07068403105118445, 0.05002033271427665, 0.11540382461888449, 0.06837182119488716, 0.04280121544642108, 0.11517731605895928, 0.06901193077542953, 0.020333516411483288, 0.061051771843007634, 0.01844185238171901, 0.04175142677766936, 0.08293365088424512, 0.02335825589086328, 0.09146213717758656, 0.06430696895612137, 0.12095656166119234, 0.07657678877668721, 0.0832016925726618, 0.11704254097172193, 0.3297300211020878, 0.08694460030112948, 0.06345118701990161, 0.09951580502092838, 0.11804319013442312, 0.07899172204945769, 0.06943602873278515, 0.05290093778499535, 0.06617064002369132, 0.043758947269192765, 0.09192003974957125, 0.038399182193513424, 0.025012361417923654, 0.05982000008225441, 0.056092145653175454, 0.027189517360446707, 0.058580106257327964, 0.004223926292200173, 0.007920495167906796, 0.03928707579949072, 0.054130416097385545, 0.06183233138706003, 0.10439485856997115, 0.05671602128339665, 0.0024971821070981343, 0.05871007964015007, 0.06809344541813646, 0.033348941044615846, 0.02515720489567944, 0.052882471454462836, 0.09620175856564726, 0.0773135217438851, 0.08904953806528024, 59.95950058528355, 80.89461748940604, 41.731290681021555, 40.25211647578648, 59.443819182259695, 43.92650801794869, 25.011149065835134, 34.1481066431318, 70.50665760040283, 1.3936000828232085, 0.3721815603119986, 5.528195679187775, 2.9633867229734148, 3.506367381129946, 2.1614716734204973, 0.8204231507011822, 1.1959371864795685, 4.498713663646153, 5.076752543449402, 12.458963411194937, 34.13480084283011, 61.564138412475586, 71.70500646318708, 73.15158666883195, 74.3454817363194, 74.76122719900948, 79.04169273376465, 77.534975869315, 73.39298098427909, 71.3336044039045, 74.67686217171806, 68.56226675851005, 77.53346811022077, 73.52496896471295, 68.76718303135463, 59.94664641789028, 59.54051031385149, 51.3169663974217, 48.781586102076936, 49.26486458097185, 56.09943928037371, 57.1066049848284, 60.67950071607317, 60.581162861415315, 59.20503044128418, 58.54743903023856, 52.188920157296316, 49.228654044015066, 49.735976764133994, 47.93356541224888, 47.92655120577131, 46.4408734866551, 50.28875459943499, 49.57886757169451, 49.46156113488333, 55.15339340482439, 61.59689222063337, 59.406389236450195, 61.71724891662598, 31.938364097050258, 56.92326634270804, 63.11247498648507, 56.12061391557966, 58.37608255658831, 56.46267025811331, 56.009755407060894, 55.59793220247541, 53.50680930273873, 47.89580890110561, 47.31100681849888, 44.9514159475054, 46.29993275233677, 45.1855320249285, 48.441058363233296, 45.55389077322823, 48.58803013392857, 56.649611541203086, 60.2027987071446, 61.130404063633506, 56.721386432647705, 56.068728242601665, 52.581298828125, 51.38005256652832, 49.68161405835833, 50.822428362710134, 52.24507897240775, 52.2535696710859, 53.72245012010847, 56.070736271994456, 59.24642086029053, 59.695406505039756, 62.01247092655727, 57.96195602416992, 60.207808358328684, 61.50525937761579, 65.40810421534947, 64.18198340279716, 64.62618868691581, 64.71446555001395, 55.551087447575156, 32.725456033434185, 14.44377018724169, 2.515415732349668, 1.5247650274208613, 1.2630335518292017, 1.1738743760756083, 1.5311690952096666, 2.4593353016035895, 4.827929300921304, 7.017719226224082, 3.924879312515259, 0.9246113342898232, 0.10814598335751466, 11.798103741237096, 51.0041480745588, 18.618571860449656, 51.395081520080566, 42.81078018460955, 35.95003856931414, 42.42629814147949, 65.49175357818604, 5.892682109560285, 0.3069016874900886, 0.06814925492342029, 0.042592382723731656, 0.11974729012165751, 0.07010075556380407, 0.02905172448871391, 0.036576172336936, 0.06531595731420176, 0.006001400935929269, 0.007923613884486258, 0.012474868862357522, 0.010491427882308406, 0.0668560214606779, 0.04043215114091124, 0.045257108485592265, 0.01825194908971233, 0.025411650438659956, 0.049608173580574136, 0.04231349126036678, 0.042080855529223166, 0.08061755980764117, 0.14374197114791187, 0.10200199804135732, 0.01862699575056987, 0.18005603897784436, 0.19662914824272903, 0.12276385325406279, 0.16550618543156556, 0.09257646809731211, 0.15915407985448837, 0.12159694944109235, 0.259138359022992, 0.11772065529865877, 0.10221209283918142, 0.21077315642365388, 0.13394631392189435, 0.1096666549731578, 0.11772991051631314, 0.1662400753370353, 0.06749543893550124, 0.14972690785569803, 0.1718428475516183, 0.13696603902748652, 0.19881724725876534, 0.12130481297416346, 0.08135837755565133, 0.22769292922956602, 0.18012358035360063, 0.17075332387217454, 0.1768893024751118, 0.22618405733789715, 0.14385037390249117, 0.22761757113039494, 0.7061248496174812, 84.24473312922886, 89.29076508113316, 55.29189879553658, 50.810783181871685, 73.43911702292306, 76.12673582349504, 34.914117744990754, 30.303324426923478, 81.72175884246826, 2.4689594251768927, 6.756189899785178, 10.444827420370919, 2.537112785237176, 1.6849901612315858, 3.282413044146129, 0.9961578037057603, 0.9106452922735895, 4.8923985958099365, 6.496937411172049, 14.847588198525564, 41.47911276136126, 67.51836940220424, 79.2025921685355, 81.00820663997105, 82.51810577937535, 80.452559198652, 83.00129740578788, 81.07128933497837, 77.10522283826555, 75.12557683672223, 77.69789028167725, 71.84843117850167, 78.80486338479179, 76.36853313446045, 70.29518222808838, 61.25640269688198, 61.5416818346296, 57.078603744506836, 54.96099778584072, 55.671635219029014, 59.47876862117222, 59.003372873578755, 64.0888705934797, 62.89892210279192, 63.35127762385777, 62.006564957754954, 55.90214170728411, 54.2506764956883, 52.1155298096793, 50.2354028565543, 49.632208892277305, 48.29564298902239, 53.427311488560264, 52.00478594643729, 51.22103956767491, 57.18006828853062, 65.59281512669155, 62.5470792225429, 64.38217490059989, 35.3946065221514, 58.59695884159633, 67.35813699449811, 59.15073721749442, 59.25344548906599, 58.41525650024414, 56.17274624960763, 57.78548220225743, 56.6951778275626, 50.073850291115896, 49.567715712956016, 46.65261289051601, 50.16319022859846, 46.36332811628069, 49.16073540278843, 46.816708496638704, 51.651977266584126, 58.13935048239571, 60.858965737479075, 62.327981676374165, 57.542795521872385, 57.905877113342285, 54.17291573115757, 52.33026736123221, 50.64663893835885, 52.78328990936279, 54.53628914696829, 55.341019085475374, 55.319653374808176, 58.738424164908274, 60.432478359767366, 61.716227531433105, 63.31616142817906, 58.70285633632115, 63.56674821036202, 66.12852123805455, 68.85976082938058, 66.84869507380894, 67.30099500928605, 67.03528199877057, 58.2202969959804, 34.85871280942644, 15.76363696370806, 2.680126905441284, 2.6111200026103427, 1.0161254065377372, 0.7186349183320999, 0.9864846084799085, 2.1446505188941956, 7.428539718900408, 12.62121774469103, 10.273187807628087, 3.2603006192616055, 0.3802568327103342, 12.55219955103738, 58.7073518208095, 29.36371258326939, 64.71636935642788, 45.34036915642874, 50.994670731680735, 49.554562773023335, 79.2790779386248, 14.26225631577628, 0.553974065397467, 0.15045659084405216, 0.18535735165434225, 0.19343848659523896, 0.3559580594301224, 0.13649053525711807, 0.14508442554090703, 0.18174253776669502, 0.12456202533628259, 0.06709649427128689, 0.19214465602168015, 0.11537622181432587, 0.1698571148195437, 0.11543507794184343, 0.13983612002006598, 0.24358321513448442, 0.20637410533215317, 0.2696150482765266, 0.10144205058791808, 0.07269632164388895, 0.20560341168727192, 0.3526731628392424, 0.15358363304819378, 0.22658488154411316], [0.08911599378500666, 0.019422983484608785, 0.047376129244055064, 0.07388913192387138, 0.12081204727292061, 0.05568665312603116, 0.11349768404449735, 0.09467331772404057, 0.07154847787959234, 0.03757941011073334, 0.15950199189995015, 0.024434609205595086, 0.04290741974753993, 0.060667985651109896, 0.12129357643425465, 0.07355403740491186, 0.04072515952533909, 0.11420014420790331, 0.03287376636373145, 0.06688018409269196, 0.03204613006008523, 0.05491002229973674, 0.059452573369656286, 0.06756977923214436, 0.11215857482914414, 0.04512653799195375, 0.05330256944788354, 0.17651262054485933, 0.09989251409258161, 0.20272510685026646, 3.3589198759623935, 69.05905600956508, 85.28662245614188, 44.33263717378889, 49.31030232565743, 64.71722398485456, 42.34394461768014, 17.23738636289324, 47.65416445050921, 3.621706609215055, 0.5357678851911, 6.028695702552795, 4.426400286810739, 2.3470044263771603, 1.6660467662981577, 0.8542281453098569, 0.8902328961661884, 1.4015619584492274, 3.9734294159071784, 14.95742358480181, 33.29536812646048, 48.72288424628121, 61.09753908429827, 64.18088558741978, 67.4929598399571, 62.785784585135325, 68.44700309208461, 68.08392497471401, 66.05919211251395, 70.00403186253139, 70.95278058733258, 60.61846079145159, 75.00399725777763, 68.35758672441754, 64.1991662979126, 57.15025009427752, 50.875800950186594, 44.54555082321167, 46.02047620500837, 47.795122555324006, 54.5837071282523, 57.971245765686035, 62.74080889565604, 61.89578982761928, 63.749242646353586, 62.575066566467285, 60.96127796173096, 52.57272475106375, 48.319374561309814, 43.119596345084055, 46.407817431858604, 43.52927255630493, 44.83990430831909, 44.53137649808611, 51.11706324986049, 53.91902160644531, 62.83421352931431, 53.86562122617449, 56.52597182137625, 22.115796497889928, 51.47058064596993, 57.40025322777884, 53.670564447130474, 54.77073178972517, 50.76960120882307, 49.12755428041731, 45.469445841653005, 44.88044357299805, 40.96367107118879, 40.53255271911621, 41.34755209514073, 43.7404283114842, 44.30129732404436, 44.87221690586635, 49.03488615580967, 54.78046274185181, 55.878024509974885, 56.52649988446917, 61.21548475537981, 56.71974318368094, 53.579060145786826, 51.199712072099956, 49.6853209223066, 47.884542397090364, 44.40068435668945, 44.72842046192714, 44.16287183761597, 46.33571597508022, 42.014836243220735, 41.55458409445626, 46.14585992268154, 50.9977696282523, 50.578960009983604, 54.960146631513325, 59.28504589625767, 60.48903669629778, 63.18857165745327, 62.59090845925467, 54.192322049822124, 42.31104142325265, 22.037716116224015, 4.327992515904563, 0.25649815212403027, 0.43944175115653444, 0.7385973642979349, 1.0344846099615097, 3.1097021060330525, 4.320048119340624, 4.7712715182985574, 6.355611486094339, 2.1762266073908125, 1.8127304038831165, 0.05681189828153167, 17.847327028002056, 25.684090784617833, 36.067807061331614, 44.77760328565325, 35.40960073471069, 41.87932552610125, 58.14790718896048, 29.74986914225987, 0.2532689225460802, 0.06451279576867819, 0.0647336317758475, 0.12726317825061934, 0.0490721207378166, 0.016669832735455463, 0.02138109814508685, 0.041972371350441656, 0.025645361647808125, 0.019220028571518402, 0.048197244826172075, 0.05169062130153179, 0.04570589493960142, 0.014093447992179011, 0.05789391736366919, 0.0593644113146833, 0.0614422687462398, 0.070161844071533, 0.03332674955683095, 0.1140429140733821, 0.062177054317934174, 0.153508722782135, 0.17539598260607037, 0.08950826166463749, 0.028246581620935882, 0.04380832426249981, 0.042801286692598035, 0.08993923318173204, 0.1253325289913586, 0.1037099181807467, 0.040681790959622176, 0.06301846488245896, 0.08940226770937443, 0.10931849186973912, 0.07954592909663916, 0.10489559027233294, 0.05373081325420311, 0.08214889799377748, 0.07288755316819463, 0.10914770460554532, 0.028947409907621995, 0.06289879844657012, 0.08018000650086574, 0.022861444424571734, 0.03600620970662151, 0.05097536736034921, 0.07557843984769923, 0.01734848310505705, 0.047872090845235755, 0.02229260646605066, 0.030535334521638494, 0.03474597340183599, 0.06075466849974223, 0.06027934793382883, 0.12125964968332223, 2.9555715194770267, 74.16099316733224, 89.28459508078438, 38.1991982460022, 60.24072197505406, 64.38911615099225, 29.633323533194407, 24.78305881364005, 56.52002763748169, 4.559136067117963, 0.2689350204808371, 3.095313472407205, 4.669710568019322, 6.948049204690116, 4.098067939281464, 1.692583565201078, 0.985165210706847, 2.2518219224044254, 4.421773220811572, 14.003229209354945, 35.32938378197806, 56.87109579358782, 66.21485955374581, 72.35605267116001, 77.34625584738595, 73.77931472233364, 77.69502762385777, 74.82902077266148, 73.81241594042096, 75.04863248552594, 74.2646255493164, 64.32015527997697, 77.64715453556606, 73.90826633998326, 70.95228031703404, 61.797097614833284, 57.33277232306344, 50.90261057444981, 52.432565689086914, 53.34655952453613, 55.80585009711129, 61.13954094478062, 64.25553008488247, 64.70539815085274, 66.31466347830636, 63.380918639046804, 63.052650996616904, 54.42397499084473, 49.176403590611045, 44.47924416405814, 49.25358765465872, 45.653117997305735, 46.89893695286342, 46.94373198917934, 55.45947197505406, 56.435777255467, 67.14024148668561, 59.56780283791678, 59.72039917537144, 24.687694787979126, 56.171974999564036, 63.13709940229143, 55.42466150011335, 56.885447297777446, 54.013676915849956, 53.607460907527376, 50.19449533735003, 48.54125486101423, 43.67229080200195, 44.4687419618879, 44.18276105608259, 46.18227195739746, 47.58224017279488, 48.66349104472569, 53.260714530944824, 59.32961859021868, 60.6077675138201, 60.79058851514544, 64.94520132882255, 62.405843189784456, 58.205476488385884, 56.622454507010325, 54.180798462459016, 53.62421996252877, 50.58432401929583, 52.47541522979736, 52.53723335266113, 55.37448855808803, 52.07308326448713, 49.386829784938264, 56.10851015363421, 58.74310030255999, 57.285823345184326, 61.09998485020229, 64.25822598593575, 63.59736197335379, 64.5430326461792, 68.49220807211739, 58.90200560433524, 46.80864858627319, 24.573911087853567, 6.213611585753305, 0.3856659781719957, 1.05546968962465, 2.9432006861482347, 2.277253197772162, 6.545974322727748, 6.349445828369685, 5.613004088401794, 4.917541086673737, 2.1399600505828857, 0.7585031390190125, 0.04617416213399597, 17.949444702693395, 30.364037786211284, 35.90119620731899, 53.09813710621425, 42.095914772578645, 40.05712570462908, 68.46619401659284, 27.14911150932312, 0.25467091160161154, 0.07103895914873906, 0.03984273151893701, 0.0728497112702046, 0.024905069764437418, 0.05148685045008149, 0.03886813470827682, 0.013227704313716717, 0.02385310978362603, 0.017413870132129108, 0.004110527823546103, 0.0334205061330327, 0.04311681565429483, 0.05836252721824816, 0.042188271015350304, 0.08978796737002474, 0.06009938009083271, 0.013788729789666831, 0.051327907014638186, 0.06052292843482324, 0.05134963370593531, 0.10087819477277142, 0.15511625366551535, 0.09316551791770117, 0.04417471620919449, 0.1470048696334873, 0.21110657496111734, 0.15876662278813974, 0.15398322232067585, 0.19758196068661554, 0.19316486056361878, 0.13281998650303908, 0.17803457459168776, 0.1870963012001344, 0.15733027271926403, 0.23513032442757062, 0.14520212422524179, 0.15247417400990212, 0.2023204014237438, 0.14399677461811475, 0.17703810520470142, 0.2438930342239993, 0.25688290862100466, 0.14751696001206124, 0.16974238811859063, 0.14822387136518955, 0.16765290738216468, 0.22954687689031872, 0.20305705975208962, 0.1902301423251629, 0.2160124374287469, 0.08981094935110637, 0.2406227939895221, 0.14677661045321397, 0.4619292159165655, 7.435911757605417, 97.2383508682251, 98.86142226627895, 58.944236755371094, 64.01858261653355, 83.54295117514474, 57.84499699728829, 23.842906747545513, 60.20065171377999, 6.157738949571337, 1.5517151355743408, 15.643441813332693, 12.514962417738777, 5.732935641493116, 3.653964706829616, 2.365455367735454, 1.5461586394480296, 2.868111938238144, 7.28155665738242, 18.984957320349558, 36.08799852643694, 60.988132749285015, 71.98938233511788, 77.18263271876744, 85.79277093069894, 80.92873314448765, 84.1236538205828, 79.70580155508858, 77.81534957885742, 78.54493127550397, 75.50193296160016, 65.0587557383946, 78.03501687731061, 74.0188330241612, 71.92304788316999, 64.99153191702706, 58.52439880371094, 55.79406247820173, 59.594254629952566, 57.476304735456196, 58.492332867213655, 62.89043140411377, 66.76500402178083, 67.9437381199428, 68.691892351423, 65.69534274509975, 65.94007219587053, 55.67581108638218, 52.08721590042114, 45.791477475847515, 50.41675778797695, 48.93489462988717, 48.870939935956685, 49.4795743397304, 59.242592402866904, 60.3478354045323, 69.54622895377022, 61.51698098863874, 61.351148332868306, 26.648670979908534, 57.7028021131243, 64.43917792184013, 59.98066479819161, 61.20989840371268, 57.14255496433803, 55.428410053253174, 53.124283177512034, 52.35189362934658, 45.565101691654746, 47.36636659077236, 46.80552537100655, 50.36966984612601, 50.33250045776367, 50.65833623068673, 56.90182072775704, 60.78887231009347, 61.009929248264854, 64.16807310921806, 66.2144912992205, 62.19303376334054, 59.80878026144845, 57.11914995738438, 57.30684859412057, 56.9157657623291, 52.455960273742676, 53.02444798605782, 53.797136306762695, 59.045673506600515, 57.68998963492257, 53.313753604888916, 57.95979860850743, 60.94527626037598, 61.31374617985317, 64.61571080344063, 66.61670167105538, 66.0621589933123, 67.32318755558559, 70.91221005575997, 60.94531100136893, 48.89412954875401, 28.99772490773882, 7.4268660715648105, 0.8201305121183395, 0.556341501218932, 2.1716021469661166, 1.6046421698161533, 5.784602880477905, 9.559443661144801, 12.058575204440526, 14.85266385759626, 5.063015954835074, 3.3642921362604414, 0.14512642685856136, 23.04944678715297, 38.22684165409633, 44.96014288493565, 56.31974581309727, 49.103523935590474, 54.31544760295323, 69.89109584263393, 44.92588479178292, 0.31609008301581654, 0.1328674161008426, 0.16467500717512198, 0.2302449265761035, 0.08485840367419378, 0.09212215497557606, 0.11382487363048963, 0.08879472780972719, 0.16417935091469968, 0.12887993721025331, 0.1352156086691788, 0.1379878313413688, 0.22334554179438523, 0.12082880708788123, 0.12721406588596956, 0.14807827132088797, 0.15126612383340085, 0.08100176669125046, 0.0847814849444798, 0.2823127183531012, 0.12197084937776838, 0.2557843604258129, 0.2942933669047696, 0.1685262226632663, 0.1271564718335867], [0.10418061113783292, 0.14866034580128534, 0.18048298678227834, 0.03612091265884893, 0.148305281996727, 0.06506402404712779, 0.08390063113932099, 0.1951794988874878, 0.2025431373289653, 0.10737761708774737, 0.1288741696625948, 0.07749389670789242, 0.23703776778919355, 0.03786478836887649, 0.10067339254809277, 0.16028746403753757, 0.08302694266395909, 0.14504728253398622, 0.06368682187582765, 0.0852428005476083, 0.05607315685067858, 0.1097789185919932, 0.044356655196419785, 0.15965330520910875, 0.0789542126336268, 0.18806344430361474, 0.1293967773339578, 0.3426017218402454, 0.06882313519184079, 0.41133395369563786, 0.19581090286374092, 18.612269844327653, 89.19330269949776, 63.589802333286826, 44.25491115025112, 64.14827769143241, 71.63159874507359, 21.965970754623413, 34.18419211251395, 11.44742294720241, 0.4536193875329835, 2.652694331748145, 4.193728566169739, 17.15020557812282, 1.4249763020447321, 1.2825617896659034, 1.2328684904745646, 0.7079001686402729, 2.468130201101303, 11.663131509508405, 25.911237818854197, 40.34796340124947, 53.620495728084016, 53.44651978356497, 52.14092200142996, 53.08720064163208, 52.79106841768537, 71.25592354365757, 66.62201704297746, 72.554507119315, 62.860581942967, 53.6089825630188, 73.01451955522809, 72.75452491215297, 64.48217337472099, 56.60108184814453, 47.41815498897007, 43.698204108646934, 46.40399939673287, 47.39689350128174, 53.218139444078716, 58.26844801221575, 64.56330748966762, 66.3828044618879, 68.91313689095634, 67.68511227199009, 67.9883941922869, 62.18757247924805, 56.35663379941668, 44.19292974472046, 45.22652292251587, 43.523797375815256, 44.57798848833357, 46.76009457451956, 53.60596357073103, 55.267104148864746, 60.33013139452253, 54.65694114140102, 58.1296785899571, 16.760826792035783, 50.1965902192252, 61.835986682346885, 52.507033007485525, 56.11771304266793, 48.27464900697981, 45.82870592389788, 41.97693034580776, 42.35658686501639, 41.139929498944966, 42.63476146970476, 41.6379520552499, 41.95961543491909, 44.46592446735927, 47.30568102427891, 55.2018084526062, 60.1569892338344, 58.35037422180176, 60.49620028904506, 57.33682312284197, 60.69275093078613, 51.43344599860055, 51.57272611345564, 47.45966700145176, 43.8416531426566, 40.91622529711042, 40.58034937722342, 40.400866985321045, 41.47557612827846, 33.48826401574271, 29.82994713102068, 37.09440687724522, 49.690358366285054, 51.02389832905361, 58.29633808135986, 55.77557332175118, 64.01732499258858, 60.93126174381801, 59.788713863917756, 54.3152391569955, 37.770831380571636, 10.464188575744629, 5.181533115250724, 0.3174910678395203, 0.5354977196880749, 3.685305859361376, 4.944562196731567, 4.718342747007098, 4.35307160445622, 3.852643234389169, 5.287825354507991, 1.7163996015276228, 0.5187637976237706, 0.199829119390675, 14.341811452593122, 31.866033349718364, 42.663996015276226, 42.47559213638306, 33.50062486103603, 54.39290264674595, 56.61287294115339, 2.2720954631056105, 0.03794271133041807, 0.09803678867008005, 0.17492643637316568, 0.12668835052422114, 0.1383243439985173, 0.1435036967907633, 0.07661873581154005, 0.16010629518755845, 0.06259685714862176, 0.07768707562770162, 0.018825290824419687, 0.049905134431485615, 0.0441187811749322, 0.11714626183467251, 0.08539804935987506, 0.06923124007880688, 0.02607069962791034, 0.10870795284530946, 0.04697020584717393, 0.22190309848104203, 0.2046364178614957, 0.27159737476280754, 0.13595017710966723, 0.23819605420742715, 0.21327962407044002, 0.15192781761288643, 0.13347475922533444, 0.13099071037556442, 0.10457711307598011, 0.12916823316897663, 0.08495678446654763, 0.1325152021433626, 0.1356031878718308, 0.1307903661259583, 0.062239873089960644, 0.07098123617470264, 0.08049547778708593, 0.12216473397399698, 0.06330362600939614, 0.07928644373480763, 0.07418510889900581, 0.09376265587551252, 0.07828184549829789, 0.03022674358050738, 0.060628325279269896, 0.110303738287517, 0.027115146529727747, 0.03850637037040932, 0.07617659560803856, 0.060299934686294625, 0.20875550540430204, 0.09946358496589319, 0.23669100925326347, 0.08977410489959375, 0.3374538395021643, 0.18747778715831892, 18.810142380850657, 100.70122882298061, 63.855487551007954, 44.15908506938389, 72.10685552869523, 61.389092445373535, 19.925614867891582, 45.942607743399485, 11.499580468450274, 0.48378309181758333, 2.3523810292993272, 4.231725658689227, 11.695702058928353, 5.368783593177795, 4.239508943898337, 3.2943526548998694, 1.4845194326979774, 2.5577089829104285, 13.39264930997576, 28.17881543295724, 44.74641629627773, 61.19263213021414, 61.46081869942801, 62.755177770342144, 64.58030973161969, 69.06713676452637, 77.65087182181222, 73.53152806418282, 77.31924819946289, 69.04098374502999, 62.19697339194161, 74.66125651768276, 74.80148506164551, 67.48106452396938, 61.72788660866873, 54.699915749686106, 51.4433193887983, 52.485834053584504, 51.42158889770508, 56.529713426317485, 60.903024264744346, 66.69550119127545, 68.14483288356236, 70.8804498400007, 68.40179116385323, 68.30248750959123, 62.5563759122576, 58.33836078643799, 47.30863400868007, 49.21965612683977, 45.64561741692679, 46.89647729056222, 48.17349713189261, 54.301433086395264, 58.78018283843994, 63.05003847394671, 58.90620231628418, 58.65409387860979, 18.891389404024395, 51.76373209272112, 65.02086721147809, 56.0582468850272, 59.019054957798545, 52.12639331817627, 49.97012758255005, 46.708757809230256, 46.517703192574636, 45.07535443987165, 46.29802199772426, 43.83460072108677, 47.73485735484532, 46.95159387588501, 51.790572983878, 57.88858652114868, 63.21126447405134, 63.2797737121582, 65.60377938406808, 63.64955684116909, 64.67585441044399, 56.39386224746704, 59.54888984135219, 53.56046676635742, 53.22910370145525, 49.38125385556902, 50.5290823663984, 49.281116417476106, 51.25156300408499, 43.361963408333914, 39.78678171975272, 47.13448783329555, 58.87312194279262, 57.255869661058696, 62.5958069392613, 60.46522521972656, 67.62926959991455, 64.38925511496407, 65.10675389426095, 57.40329653876168, 40.34844977515084, 11.795825600624084, 6.483607292175293, 0.5646455756255558, 2.9668599537440707, 4.441317200660706, 7.704057506152561, 7.101540556975773, 7.53396213054657, 4.044692746230534, 4.786323922021048, 1.8233599535056522, 0.4605504327586719, 0.12391000746616296, 17.03318575450352, 39.063171999795095, 39.14205837249756, 48.78540413720267, 27.915100029536656, 60.94027355739048, 57.686883790152415, 1.6816708764859607, 0.3094996895108904, 0.13640848680266313, 0.07612533907272986, 0.23221189102956227, 0.11583881984863963, 0.1108378946248974, 0.07855089820389237, 0.18861763099474566, 0.04609455301293305, 0.027950704729716693, 0.012083103946809257, 0.030464753308998685, 0.08909792439746005, 0.03747855945091162, 0.09688342841608183, 0.0854522507371647, 0.08115264573799712, 0.10654436929949693, 0.08746219359870468, 0.18233829151306832, 0.23879878329379217, 0.22306625678070954, 0.13727101337696823, 0.2765131438417094, 0.18269270392400877, 0.17342352201896055, 0.1875601341681821, 0.2572766217802252, 0.15370133173252853, 0.158664679686938, 0.11680793070367404, 0.15472543106547423, 0.22313758438186987, 0.24252299059714588, 0.15757706947624683, 0.2897610515356064, 0.22583957867962973, 0.23601738682815007, 0.13530114479362965, 0.149565172248653, 0.19053914717265538, 0.20555708131619863, 0.23996350222400256, 0.21994804910251073, 0.17062509432435036, 0.15774658109460557, 0.1578985322266817, 0.2615739740431309, 0.17527228567217076, 0.11171057208308152, 0.17132360541394778, 0.21156959368714265, 0.2366319495652403, 0.1559754011354276, 0.32788850420287674, 0.44291796748127255, 33.02405834197998, 112.95259135110038, 75.9393845966884, 65.49711758749825, 79.97441891261509, 96.51988628932408, 30.92557382583618, 46.73882613863264, 13.499186038970947, 0.618243002465793, 6.147761336394718, 13.862929446356636, 30.300882135118755, 6.364275889737265, 3.9110002858298163, 3.5951846837997437, 2.3356608407838, 3.933366971356528, 14.59195181301662, 28.562983070101055, 45.70182834352766, 63.15443515777588, 61.600255148751394, 59.670907156808035, 68.60466466631208, 77.63584981645856, 83.16543470110211, 78.2327834538051, 77.7197493144444, 69.76186629704067, 63.72602871486119, 73.47879818507603, 74.7081082207816, 65.84458310263497, 63.852270535060335, 58.72349943433489, 57.40628773825509, 57.019794191632954, 56.42532021658761, 58.56830447060721, 61.34706279209682, 66.59674644470215, 70.06990078517369, 71.66032259804862, 69.68336554936, 69.37281581333706, 65.83086041041783, 59.77654756818499, 48.69493859154837, 49.849506855010986, 47.86147437776838, 49.76607983452933, 51.816500186920166, 56.22510092599051, 60.86397538866316, 65.15638487679618, 62.283964838300435, 61.62528950827462, 23.132012231009348, 54.795460428510395, 68.32183824266706, 59.913079670497346, 62.588038853236604, 54.47490528651646, 52.01383250100272, 48.74904073987688, 49.992789132254465, 47.06271641595023, 50.259297711508616, 46.97615228380476, 49.80646971293858, 49.76083394459316, 56.15189470563616, 61.52340807233538, 67.46263790130615, 66.3924138205392, 67.14111695970807, 62.493981088910786, 66.70071928841728, 58.17872244971139, 62.46006693158831, 57.38861152103969, 54.69803973606655, 53.77154956545149, 54.98893301827567, 54.35135589327131, 57.64503826413836, 52.37195307867867, 51.58213744844709, 56.01861088616507, 62.666949544634136, 58.492263385227744, 65.61217975616455, 61.1767554964338, 69.02327278682164, 67.4784242085048, 68.18942642211914, 59.28746386936733, 44.04231364386422, 14.573318481445312, 7.982418843678065, 0.6167235182864326, 3.226531288453511, 5.61236572265625, 10.43334378514971, 11.116357786314827, 15.48703612600054, 14.35739973613194, 8.423136132104055, 3.8429991347449164, 0.5905081821339471, 0.20441332911806448, 24.44547884804862, 40.89452954701015, 52.58652039936611, 54.90837907791138, 44.78685481207711, 63.74045317513602, 73.39400931767055, 5.024578085967472, 0.6967276824372155, 0.26947198595319477, 0.22248247239206517, 0.3380863427051476, 0.1579858868249825, 0.29849765130451744, 0.153465350823743, 0.2852042546229703, 0.11380864307284355, 0.11639524570533208, 0.09160249214619398, 0.1134973583476884, 0.3981820451361792, 0.20623117871582508, 0.22931278230888502, 0.11352673891399588, 0.24698712676763535, 0.2578754967876843, 0.1353479094271149, 0.2892999191369329, 0.3480423241853714, 0.35252206666128977, 0.2150412095444543, 0.27033847517200876, 0.2935656245265688], [0.29076533764600754, 0.177335724234581, 0.2038300061332328, 0.16792653341378483, 0.18313400952943734, 0.15863675118557044, 0.24678907596639224, 0.27071400359272957, 0.25080299058130806, 0.04684968784983669, 0.202411664383752, 0.13785888254642487, 0.04360567299383027, 0.1300537349390132, 0.1060693065768906, 0.1137452068339501, 0.06892777207706656, 0.09066130979252712, 0.09398136806807347, 0.042146164524768076, 0.16416791081428528, 0.12605261749454907, 0.06665615218558482, 0.24883640610745975, 0.2690566953803812, 0.22564456771527017, 0.394140609140907, 0.24945007317832538, 0.15145744356725896, 0.2518199788672583, 0.2565467080899647, 0.19288754330149718, 62.07242693219866, 90.17057377951485, 60.78804547446114, 46.95156260899135, 81.43672289167131, 53.214536803109304, 30.560994897569927, 12.710205929619924, 0.12028627762837069, 0.8722906389406749, 3.4791104665824344, 7.484830549785069, 10.882100139345441, 6.237361831324441, 1.6819814826760973, 1.8038728620324815, 0.36521672404238154, 4.169561428683145, 16.319901057652064, 25.129240649087087, 33.36634397506714, 34.86918374470302, 31.866526671818324, 40.06732218606131, 48.32585028239659, 58.958772386823384, 66.06944070543561, 66.35678345816476, 51.20687566484724, 46.14619691031319, 67.4815925870623, 61.583739280700684, 55.112826347351074, 44.62084150314331, 44.72801399230957, 43.37099954060146, 46.54331077848162, 47.208406244005474, 55.82932111195156, 63.65109934125628, 67.59791932787213, 71.06018584115165, 67.97877788543701, 65.03414521898542, 65.46348135811942, 68.8206285749163, 61.62007141113281, 56.39716264179775, 45.592585291181294, 43.02791486467634, 44.5745803969247, 45.952098982674734, 56.26445552280971, 55.236222880227224, 61.64487648010254, 55.81835685457502, 59.720204625810894, 18.436046157564434, 47.25216947283064, 62.41212436131069, 55.22224310466221, 59.22506904602051, 53.80321250643049, 47.290342875889365, 42.72282641274588, 43.35257986613682, 39.45916025979178, 43.04320090157645, 41.59505040305001, 46.84908710207258, 46.294773714882986, 55.90204790660313, 58.30782345363072, 58.38018199375698, 56.2724598475865, 57.68598052433559, 58.58855846949986, 59.994088717869346, 52.85088545935494, 48.986248765672954, 44.78769901820591, 38.774932929447715, 38.077677726745605, 32.993302140917095, 34.80092116764614, 28.296976498195104, 25.575712782996042, 19.249838284083776, 25.159724133355276, 30.874497617994034, 40.47887788500105, 45.27256863457816, 52.57448959350586, 58.01711082458496, 59.48814868927002, 60.58780533926827, 42.59228713171822, 30.5610157421657, 7.0125749536923, 1.7543808434690749, 1.7233935062374388, 4.673033543995448, 3.022000857761928, 4.510287191186633, 9.23929672581809, 6.57426347902843, 2.5568812787532806, 3.243443420955113, 1.0416207356112344, 0.2933627968387944, 0.0922214382195047, 12.548457077571324, 37.301348549979075, 72.56463064466203, 36.65123340061733, 50.6080972807748, 58.84619072505406, 18.11566993168422, 0.24356212626610482, 0.3154124436633927, 0.028364080137440136, 0.2317608009491648, 0.026256412966176867, 0.15529755822249822, 0.13282523836408341, 0.06487278573747192, 0.04500015405938029, 0.0555418469677014, 0.06413227333022015, 0.058044789625065665, 0.061764253968639035, 0.06135419490081923, 0.1108427665063313, 0.14828944498939173, 0.09299802154834781, 0.1055809852800199, 0.17610103477324757, 0.1426251432193177, 0.13116852726255143, 0.16989575060350554, 0.2650371082127094, 0.19186708091625146, 0.34309995653373854, 0.20986047254077025, 0.2461322269269398, 0.164840271164264, 0.1508934045476573, 0.19862875023058482, 0.3394107887787478, 0.1618508222912039, 0.21090092456766538, 0.21493520880384104, 0.1448699270508119, 0.05000358647001641, 0.19343896156975202, 0.14482707077903406, 0.11030418612062931, 0.12359488223280225, 0.11638506768005234, 0.18220932914742402, 0.11238700364317213, 0.11125203168817929, 0.09553908769573484, 0.055996417932744534, 0.0992031835817865, 0.11467340881271021, 0.10755101671176297, 0.13682524301111698, 0.23582186017717632, 0.21820643969944545, 0.2335910541670663, 0.17715151554771832, 0.1624662671238184, 0.19500432828707354, 0.19102443541799272, 0.28331771013992174, 63.87293447766985, 100.69588565826416, 54.74373803819929, 56.55009249278477, 91.13037014007568, 41.5238869530814, 34.6162554195949, 16.481295551572526, 0.2189438986991133, 0.6413387060165405, 3.3622715132577077, 4.674510036196027, 8.244042839322772, 6.950584428650992, 4.3840484108243665, 2.5333931105477467, 0.7010732378278459, 4.713363494191851, 17.409984827041626, 29.85556513922555, 40.21041686194283, 42.13359137943813, 37.10242509841919, 47.02717638015747, 53.804629938943044, 71.22068922860282, 72.72063159942627, 74.54581914629254, 56.75184038707188, 54.350612436022075, 74.2245761326381, 69.9270110811506, 65.0390020098005, 55.7711056300572, 53.90658780506679, 51.142431122916086, 52.94032267161778, 51.87153339385986, 58.724180357796804, 65.80333164760044, 72.08771324157715, 72.60365172794887, 71.4555800301688, 66.89955588749477, 72.21586581638881, 69.72703497750419, 64.4264418738229, 55.12919282913208, 47.91858857018607, 45.42527266911098, 47.19971752166748, 48.12957409449986, 58.23576021194458, 58.095962456294465, 63.824616704668315, 56.792893818446565, 59.93218721662249, 19.245843069893972, 49.78426327024187, 65.97309698377336, 57.91213396617344, 62.272396087646484, 54.54874726704189, 50.6780343736921, 45.254937580653596, 45.58580732345581, 43.78089462007795, 46.431000096457346, 44.088696343558176, 50.16447911943708, 51.873499734061106, 60.30773735046387, 63.8023407799857, 64.41443538665771, 62.65554755074637, 63.59959234510149, 64.31489549364362, 66.981766973223, 60.43838432856968, 57.40671157836914, 51.9937869480678, 49.237999371119905, 47.35529811041695, 45.52319015775408, 44.91189111982073, 41.05924701690674, 35.129647391183035, 29.856857504163468, 34.66957242148263, 41.652011735098704, 49.47084740230015, 56.034935678754536, 58.7492425101144, 63.64177485874721, 63.19186510358538, 66.7504961831229, 47.000047138759065, 33.38093866620745, 8.541314567838397, 2.0654058797018866, 3.7578906502042497, 7.491378358432224, 5.503295072487422, 8.310913171086993, 7.602696316582816, 4.937918416091374, 1.404784836939403, 1.170924431511334, 0.9070165955594608, 0.17353704092758043, 0.3836250534015042, 23.927329097475322, 37.74037742614746, 75.8472375869751, 41.66536964688982, 46.09649991989136, 66.56887722015381, 15.56611704826355, 0.15578226292771952, 0.33764700485127314, 0.007851815549656749, 0.11803394848746912, 0.08861109587763037, 0.15260777755507401, 0.08406606476221766, 0.11598315781780652, 0.011004582712692874, 0.06402168569288083, 0.03026324537183557, 0.03692649996706417, 0.09226364988301482, 0.11065551119723491, 0.07962866287146296, 0.1382155069815261, 0.20534881177757466, 0.08028646864529167, 0.3368201692189489, 0.12000731831150395, 0.2147058503968375, 0.18316351223204816, 0.2193371911666223, 0.19599351020795958, 0.2683352769485542, 0.23665757104754448, 0.239507933812482, 0.25052370556763237, 0.24327928572893143, 0.2890944315918854, 0.3895296651337828, 0.1996106853974717, 0.3382779067116124, 0.43074407215629307, 0.40302111261657303, 0.24255173334053584, 0.21290041798991816, 0.21292181898440632, 0.2230653611144849, 0.25522112207753317, 0.21934901124664716, 0.27308597202811924, 0.18939486571720668, 0.15335457319659845, 0.21253998018801212, 0.16555835120379925, 0.24058156620178903, 0.1428897175937891, 0.14440848252602986, 0.23854121140071324, 0.25160322764090126, 0.25892866456082886, 0.30353542097977226, 0.2014114630541631, 0.27942986733147074, 0.3291359772639615, 0.20502056367695332, 0.4591301775404385, 88.10131686074394, 102.79377610342843, 75.8463134765625, 64.3562650680542, 99.61234188079834, 74.8529086794172, 44.403078011104036, 19.34716691289629, 0.35411928381238666, 1.9442720711231232, 7.313068475042071, 17.20800937925066, 20.789465291159495, 14.363504597118922, 6.928336296762739, 4.2986220461981635, 1.3824946901627948, 5.958437689713069, 19.332667759486608, 28.780942848750524, 38.10166638238089, 39.780959129333496, 33.95167759486607, 43.721623011997764, 57.238315037318635, 73.49562672206334, 75.0954008102417, 73.71330683571952, 59.10742909567696, 53.966255460466655, 73.76755142211914, 69.21498053414481, 68.36090101514543, 61.088805198669434, 59.3455924987793, 57.22843469892229, 57.62271022796631, 55.36824212755476, 62.75335039411272, 68.87679086412702, 72.29975836617606, 74.52619048527309, 70.49590873718262, 66.97240774972099, 73.01860509599958, 67.7128494807652, 65.05247456686837, 57.09443174089704, 48.686927318573, 45.60543598447527, 48.87628310067313, 51.213365282331196, 61.6246155330113, 58.70464202335903, 66.03319890158517, 59.65739985874721, 61.82178456442696, 23.744742597852433, 51.68178503853934, 69.10643577575684, 62.88617215837751, 65.50032070704869, 60.9281975882394, 53.21003089632307, 49.74980020523071, 49.565186568668906, 46.7157164301191, 50.34075491768973, 48.8739241872515, 54.357154164995464, 54.772580010550364, 64.34334141867501, 67.41035965510777, 67.46241555895124, 65.12616716112409, 65.47449425288609, 66.57077407836914, 67.25718661717006, 63.05914061410086, 61.62199606214251, 58.73999445778983, 55.4854964528765, 54.75202029091971, 51.42083849225725, 53.59335953848702, 51.467273303440635, 49.685564109257285, 43.131679262433735, 45.77038621902466, 51.05388675417219, 56.600182056427, 61.60650852748326, 62.018911906651084, 65.81754071371896, 65.94298349108014, 68.24622794560024, 47.45139864512852, 35.09410388129098, 10.352668251310076, 5.006153200353895, 5.627696054322379, 8.912862539291382, 12.551021831376211, 11.809268627847944, 20.78071924618312, 16.839506455830165, 7.798790114266532, 5.714988010270255, 2.9645014745848517, 0.31099789483206614, 0.48705341347626274, 20.502496004104614, 47.80030591147286, 82.88451903206962, 50.32922090802874, 60.86854730333601, 74.1499524797712, 30.342526163373673, 0.6846834687250001, 0.6225409518395151, 0.11237228621861764, 0.3539570596601282, 0.18161985863532337, 0.2931767153952803, 0.20453794885958942, 0.2881341959748949, 0.18910781826291764, 0.1158410861556019, 0.09638828105692353, 0.12010324959244047, 0.32684649154543877, 0.2320476041308471, 0.17000226703073296, 0.24006061415587152, 0.3163778632879257, 0.23394758360726492, 0.38210529780813624, 0.2076705821922847, 0.3255133330821991, 0.2583715058863163, 0.3472940357668059, 0.34800978164587704, 0.39700332124318394, 0.35207314789295197], [0.4095790721476078, 0.23623587510415486, 0.35854276216455866, 0.3141464330255985, 0.22225491888821125, 0.14722789052341664, 0.24664101962532314, 0.28608716438923565, 0.26108309466923985, 0.24078162546668733, 0.2717514564948422, 0.22634377091058663, 0.25372481665440966, 0.3164849632552692, 0.13536951398210867, 0.13332485726901463, 0.09545899342213358, 0.20881094171532563, 0.06642656307667494, 0.21465631734047616, 0.09198157609041248, 0.27235182427934235, 0.062156548989670615, 0.2509552538394928, 0.22835086392504828, 0.3241048843732902, 0.207474146304386, 0.4980961095009531, 0.39090253146631376, 0.35590735929352896, 0.3503252688263144, 0.1456756873854569, 5.282806149550846, 85.99454661778041, 73.61849866594586, 43.85872139249529, 69.33259963989258, 71.21250425066266, 43.55265324456351, 14.267507416861397, 0.06182995651449476, 0.4855349606701306, 0.8935840449162892, 4.100682199001312, 4.121556758880615, 4.612834785665784, 5.377517913069044, 2.019592498029981, 0.880986743739673, 1.0298091237034117, 2.8195855021476746, 9.146645103182111, 12.1914073910032, 5.964249423571995, 7.52920000893729, 12.089151620864868, 31.606156826019287, 43.2204772404262, 49.26299204145159, 41.38728189468384, 26.117583683558873, 35.99642474310738, 55.42539800916399, 55.83488661902291, 50.47377470561436, 43.20788015638079, 39.40192794799805, 38.93351861408779, 44.33305059160505, 50.83446611676897, 55.31315680912563, 61.43568706512451, 67.03048079354423, 71.14852523803711, 70.32344055175781, 64.86401162828717, 61.46077701023647, 67.8049270084926, 67.55904415675572, 60.98775059836251, 55.87243468420846, 45.5270950453622, 44.37342657361712, 44.761417457035606, 56.25320986339024, 53.16494403566633, 60.571053232465474, 54.92435993467058, 61.81277275085449, 30.101920468466624, 41.287627356392996, 61.906920841761995, 53.487639222826274, 58.954811913626536, 55.62318195615496, 53.85371896198818, 44.589195932660786, 43.48514802115304, 42.7515606880188, 43.5302209854126, 44.51818534306118, 46.428203446524485, 50.74908665248326, 59.01840877532959, 59.74882425580706, 61.81146648951939, 59.600924900599885, 59.85504136766706, 56.44499404089791, 54.18128483636038, 50.447906562260215, 44.02554416656494, 38.501146112169536, 32.85290684018816, 29.596772534506663, 27.504388536725724, 25.661406653267996, 24.022208486284526, 18.599917684282573, 14.782721553530012, 16.374282870973857, 21.368283237729752, 30.132061753954204, 35.48803200040545, 42.49630124228341, 52.19653190885271, 56.906079973493306, 50.9557260785784, 42.676468031747, 19.749283484050206, 4.291147521563938, 1.0165592346872603, 1.7263543073620116, 7.563240970884051, 2.9805431280817305, 5.755727469921112, 5.899612503392356, 2.4006282346589223, 0.5507097148469516, 2.0303778392927985, 0.7831750522766794, 1.240589133330754, 8.327620114598956, 23.3160491670881, 62.539582116263254, 41.196678910936626, 37.85748931339809, 60.59016077859061, 43.297702993665425, 1.0822243796927589, 0.18432798688965185, 0.23222994006105832, 0.08264289184340409, 0.4300098701247147, 0.17304332527731145, 0.1841749501015459, 0.046644441184720824, 0.2131783730749573, 0.17024681105145387, 0.1537909254963909, 0.2621995290475232, 0.0504571294545063, 0.0663769282400608, 0.10285296237894467, 0.17785143799015454, 0.055124907554792504, 0.16102243959903717, 0.07206600332366568, 0.13224419525691442, 0.13006797060370445, 0.24997721346361296, 0.21601207101983683, 0.48239828326872414, 0.3072488531470299, 0.3816733424152647, 0.30815925715225084, 0.4221911382462297, 0.23471603808658464, 0.3429029642471245, 0.28961584504161564, 0.25802542588540484, 0.15865615728710378, 0.3878931743758065, 0.3248049425227301, 0.35103767631309374, 0.2651381285062858, 0.34893394634127617, 0.21025679127446242, 0.2701400172497545, 0.24038997505392345, 0.12712916758443626, 0.1629812480615718, 0.15765397463526043, 0.22531174628862313, 0.11375083867460489, 0.1735745503434113, 0.04542636226064392, 0.20404895581305027, 0.025624832570818917, 0.19587779284587928, 0.1895880310663155, 0.3148391087140356, 0.23587766289710999, 0.5325559175440243, 0.27888527512550354, 0.5221328054155622, 0.33326440144862446, 0.5401873737573624, 6.202029372964587, 95.81705515725272, 79.1892238344465, 42.176548617226736, 82.10658482142857, 73.73490183694022, 50.29283319200788, 15.670532839638845, 0.1152071715997798, 0.7469996905752591, 1.592432664973395, 5.691099669252123, 4.040490388870239, 11.500398618834359, 7.332007527351379, 4.623440342290061, 1.4290475121566226, 1.283445187977382, 4.8051674365997314, 12.24720229421343, 17.03433220727103, 10.67218724318913, 11.213957394872393, 17.70873131070818, 40.72983292170933, 52.424488408224924, 59.68629741668701, 51.99006271362305, 34.24118818555559, 46.060584681374685, 61.484706606183735, 65.76291397639683, 58.82362992422921, 52.90780162811279, 49.49942534310477, 49.51123380661011, 52.99945184162685, 55.09430592400687, 59.44303403581892, 65.19052137647355, 70.69016647338867, 71.63173076084682, 72.32259709494454, 67.44759505135673, 65.43108885628837, 69.93489728655133, 68.41963413783482, 64.1029337474278, 57.565047127859934, 45.48775781903948, 47.01176527568272, 47.08219569069998, 57.07816253389631, 55.20305218015398, 61.32470348903111, 58.01464768818447, 61.77916431427002, 30.661813259124756, 44.99592958177839, 63.41014276232038, 57.66689382280622, 62.62690012795584, 59.40941865103585, 55.69967120034354, 48.09095253263201, 48.02930811473301, 44.57223885399954, 46.24884612219674, 49.11547483716692, 50.87669379370553, 55.05968999862671, 62.05780097416469, 63.5222658429827, 64.6133553641183, 66.27266161782401, 66.79181712014335, 64.5849163872855, 62.221785409109934, 59.66272217886788, 55.31623138700213, 51.125998633248464, 44.63488381249564, 43.42598411015102, 39.34224987030029, 39.36309099197388, 37.300302846091135, 30.64791338784354, 25.721011774880544, 28.65304388318743, 33.80096421922956, 39.33664614813668, 45.718847955976216, 52.039367130824495, 59.77144759041922, 62.28005300249372, 56.05875062942505, 47.00264923913138, 21.889158419200353, 5.936489633151463, 0.3147097799394812, 3.6535274045807973, 7.118089863232203, 3.2706866562366486, 5.508380285331181, 2.7451340343270982, 5.42718711069652, 0.27109368464776445, 3.27038180402347, 0.5226008860128266, 1.9794258305004664, 16.355369874409266, 31.03599112374442, 59.14127377101353, 52.57191528592791, 32.882193497249055, 65.26563835144043, 46.31781741550991, 0.7466805077024868, 0.2131322326936892, 0.21690608161900723, 0.1012118033000401, 0.1796939048383917, 0.15521424769290856, 0.1610255337187222, 0.06455833903912987, 0.14450240534331116, 0.20752211873020443, 0.2748094509754862, 0.11883069787706647, 0.15959090712879384, 0.10272585241390125, 0.12890562654605933, 0.19152068878923142, 0.1989658735692501, 0.24226417019963264, 0.1935437409473317, 0.3359453747315066, 0.26342053924288067, 0.3421230289552893, 0.22223685628601483, 0.559447563120297, 0.4468419354941164, 0.46039366402796333, 0.44714933899896486, 0.5562521517276764, 0.25408180749842096, 0.6416997952120644, 0.3735868063356195, 0.32226173899003435, 0.2621468747300761, 0.49973561295441216, 0.5416754281946591, 0.2752961234322616, 0.3533579675214631, 0.3037697598338127, 0.31525513210466927, 0.3828574674470084, 0.3290521374770573, 0.2053923737257719, 0.18989980433668407, 0.27462453661220415, 0.33544217316167696, 0.11190938962889568, 0.3042734499488558, 0.19620397820004395, 0.23851409714136804, 0.0983280430414847, 0.27314435318112373, 0.2557830304971763, 0.34644687122532297, 0.24214504659175873, 0.6780056527682713, 0.3206693258668695, 0.6037145906261036, 0.35586952418088913, 0.8153057481561388, 12.88802249091012, 114.75632980891636, 86.50365502493722, 61.621815408979145, 83.14576435089111, 90.00379616873605, 62.60793849400112, 23.79881521633693, 0.1843865444617612, 1.1272089715514864, 3.7347878898893083, 11.613899179867335, 11.365695629801069, 17.91925130571638, 9.14863749912807, 5.081690107073102, 1.7756360343524387, 1.2150804506880897, 4.462357214518955, 12.166375637054443, 15.449614865439278, 10.32206838471549, 10.97648446900504, 16.875562395368302, 39.224092279161724, 53.723054613385884, 59.71498652866909, 51.33745663506644, 36.043814931597026, 46.96982247488839, 64.64961106436593, 67.96947424752372, 64.2353594643729, 60.850030354091096, 60.018476894923616, 57.99127394812447, 59.1851099559239, 59.414337975638254, 62.10731383732387, 67.36958067757743, 70.09856905255998, 70.92811448233468, 71.28802422114781, 65.2879420689174, 66.87243012019566, 70.5067548751831, 67.03530979156494, 65.71034390585763, 60.52911390577044, 48.025219099862234, 48.558305740356445, 49.515072686331614, 59.11160496303013, 56.98891639709473, 64.56444004603794, 60.68469796861921, 63.16704613821847, 35.40187086377825, 47.11281292779105, 65.58513041904995, 59.79291752406529, 65.00070353916713, 64.72934859139579, 60.41378075735909, 52.80753217424665, 50.038966860089985, 49.58123343331473, 48.982983112335205, 51.91493879045759, 54.3233824457441, 59.33186980656215, 65.77333627428327, 67.20533915928432, 68.59555557795933, 69.6186500276838, 70.73073700496128, 68.3289601462228, 66.61665303366524, 63.86179651532854, 62.824979373386924, 58.37486662183489, 53.9878956249782, 54.81794132505144, 54.164807183401926, 54.038012981414795, 52.88782555716378, 45.50568069730486, 39.075331347329275, 42.97455964769636, 49.91258260181972, 55.456390448978965, 57.74260834285191, 60.679452078683035, 64.95521368299211, 66.53058569771903, 60.0621463230678, 50.49734646933419, 24.637629543031963, 8.122059396335057, 0.7322059444018773, 3.6280490117413655, 19.79159106527056, 17.09591930253165, 17.68589084489005, 10.287574052810669, 10.989825878824506, 7.443955165999276, 5.239088952541351, 2.7125708673681532, 2.1207628292696814, 14.05918392113277, 37.352688789367676, 80.10667787279401, 53.23114994594029, 47.19559029170445, 66.5256872177124, 62.88630417415074, 1.2204594420535224, 0.28933048035417286, 0.3840284288993904, 0.14944435230323247, 0.36667117742555483, 0.27962284269077436, 0.22366069416914666, 0.2085216822368758, 0.3071102148720196, 0.30995379228677067, 0.3744042239018849, 0.4246259933071477, 0.20536437737090246, 0.23964953050017357, 0.2671183651047093, 0.3030784954982144, 0.28521633254630224, 0.24799238996846334, 0.29880329061831745, 0.413074830280883, 0.3019883339958531, 0.5436462738684246, 0.21462424977549485, 0.7473388495189803, 0.4674640532050814, 0.448166978678533, 0.5873700390969003], [0.27253622295601027, 0.22205811659140245, 0.2383519544133118, 0.35243502418909756, 0.247193129999297, 0.23789405184132711, 0.2236102247344596, 0.5374898985028267, 0.20661062906895364, 0.2762554633830275, 0.27092500084212845, 0.31801557540893555, 0.17874407794858727, 0.1589245857404811, 0.19692102686635085, 0.16233989676194532, 0.05804990577910628, 0.2015051415988377, 0.04328142146446875, 0.051350017078220844, 0.16781898561332906, 0.07699939395700182, 0.22208362950810365, 0.1880474037357739, 0.2602629358214991, 0.23235213064721652, 0.28313298576644486, 0.27347656392625397, 0.22618541440793447, 0.5462539110864911, 0.26343269859041485, 0.28895158639975954, 0.15264781112117426, 28.09716194016593, 84.95260865347726, 61.65691770826067, 41.91676589420864, 73.78870173863002, 45.281785420009065, 15.726563113076345, 0.1427143027207681, 0.10754121866609369, 2.025718637875148, 1.12033003781523, 3.8834254911967685, 5.812522045203617, 5.418983025210244, 2.767805789198194, 2.015371467385973, 0.17810113887701715, 0.48578026465007235, 0.46407040102141245, 0.1329843955380576, 0.49234576949051445, 0.6691725381783077, 1.1599318385124207, 5.266987706933703, 18.442956141063146, 25.559414046151296, 18.406724759510585, 23.811495678765432, 32.916906697409495, 43.39654459272112, 39.550758361816406, 29.787132331303187, 28.375729118074688, 31.135232244219097, 39.13690628324236, 44.987442357199534, 52.49695464542934, 59.64546285356794, 66.2983352116176, 70.54053701673234, 73.94496672494071, 70.84554209027971, 67.28166512080601, 66.2058824811663, 63.76963560921805, 67.02294199807304, 62.81532832554409, 58.202405384608674, 52.84397894995553, 44.479963302612305, 45.423275062016074, 52.336781297411235, 54.259903703417095, 60.16553551810128, 57.82381541388375, 59.76712581089565, 39.36787830080305, 38.464779240744456, 59.63090637751988, 54.67834506716047, 61.58494131905692, 56.92466293062483, 57.820869377681184, 45.28101069586617, 43.44678701673235, 42.88139125279018, 46.367285115378245, 47.869193826402935, 50.52947146551949, 56.91413640975952, 61.920462880815776, 60.19787243434361, 58.91668019975935, 55.6108523777553, 56.07091692515782, 52.60329335076468, 52.36460883276803, 46.34874732153756, 42.051831926618306, 31.752412932259695, 27.325621809278214, 23.05518252508981, 22.345745393208094, 23.358665943145752, 26.480241434914724, 26.275755950382777, 23.971512692315237, 20.37701848575047, 20.116765022277832, 15.756897211074829, 21.117439372198923, 25.803365298679896, 40.28194509233747, 46.65233496257237, 49.108092376164024, 26.59824616568429, 11.175354940550667, 2.382740531648908, 0.13753672769027098, 1.933860412665776, 7.384820784841265, 3.3155136108398438, 6.017900373254504, 1.848612747022084, 2.1971448106425147, 1.274141441498484, 0.4140818305313587, 2.222568052155631, 7.071892159325736, 25.12194504056658, 58.1608065196446, 43.965873037065776, 40.119086265563965, 51.084545680454795, 61.39239978790283, 19.271073716027395, 0.18447602966002055, 0.6817049171243394, 0.07238746607410056, 0.42988127416798044, 0.10394397205007927, 0.40953879430890083, 0.09713591129652091, 0.3339531144925526, 0.05892930751932519, 0.215511773579887, 0.139204865321517, 0.2573082957948957, 0.120365245533841, 0.18880133756569453, 0.1493250929883548, 0.08286243863403797, 0.09838457179388829, 0.041425526408212524, 0.12779980445546762, 0.08437152087156262, 0.18023865989276341, 0.15120848906891687, 0.33533556173954693, 0.26457361451217104, 0.32210475312811987, 0.16532061967466558, 0.5108482795102256, 0.29543086301003185, 0.3680059643728392, 0.17859399957316263, 0.30918533780745094, 0.23475262469479016, 0.38741285300680567, 0.3472610589648996, 0.4994330406188965, 0.2943312020174095, 0.42393141772065845, 0.27332563059670584, 0.3190425517303603, 0.24891109924231256, 0.18614632503262588, 0.239364355802536, 0.13267399290842669, 0.08134472543107611, 0.2671614656490939, 0.08685471476720912, 0.11111573435898338, 0.13183806490685257, 0.07117992479886327, 0.1964995480541672, 0.1448196747473308, 0.21434514118092401, 0.22019884921610355, 0.3935655371419021, 0.30929222064358847, 0.23513814115098544, 0.47065191928829464, 0.23705359122582845, 0.3941864238253662, 0.26936504883425577, 31.098528385162354, 98.86748109545026, 58.796726499285015, 48.987294469560894, 88.56344154902867, 48.649441787174766, 30.157287188938685, 0.14422459953597613, 0.27900570152061327, 1.46760784302439, 0.6367867674146379, 3.256741621664592, 3.8800534435680936, 6.915685364178248, 5.223110701356616, 3.0102188842637196, 1.7477955796888895, 0.35489883912461145, 0.8825196900538036, 1.3344902374914713, 3.0470386913844516, 1.1461070946284702, 3.200558053595679, 8.526493191719055, 24.656891686575754, 31.963460990360804, 24.98157058443342, 28.153657742909022, 37.327338286808555, 51.03324365615845, 52.37141111918858, 43.94169330596924, 42.79341663633074, 42.82462794440133, 50.12491955075945, 53.629834106990266, 61.00265448434012, 64.54156657627651, 71.4918635232108, 72.71054976327079, 77.35137666974748, 75.2113870893206, 71.2099473135812, 68.62753813607353, 68.22421605246407, 69.61956024169922, 64.5245087487357, 61.73857293810163, 55.422879287174766, 45.80276829855782, 48.638199601854595, 55.07678951535906, 57.6420852797372, 62.63828822544643, 59.67285960061209, 62.16005066462925, 41.23604045595442, 40.88640362875802, 60.02668271745954, 55.680528913225444, 63.7019601549421, 59.24261324746268, 60.92384801592146, 47.30862358638218, 45.18948902402605, 43.654635429382324, 48.877669266292024, 50.5878780228751, 51.410360608782085, 58.282532010759624, 66.0530776977539, 67.33604172297886, 66.10933726174491, 63.83949974605015, 63.142407826014924, 60.89267839704241, 63.2301218850272, 58.150755950382774, 53.572490624019075, 44.11979300635201, 38.58547292436872, 35.48100389753069, 38.06332969665527, 36.238402707236155, 41.378565379551475, 40.71534940174648, 35.324398449489046, 31.803322383335658, 30.806321893419536, 26.591480357306345, 31.534559113638743, 36.686196735927034, 49.53896754128592, 55.87435586111886, 56.0729284286499, 31.41904878616333, 11.748464941978455, 3.9751252106257846, 0.3720234887940543, 1.5875957416636604, 5.038183093070984, 2.760459154844284, 0.6021642195326942, 4.492857200758798, 0.2981475000934941, 1.8600051871367862, 0.3756754185472216, 3.0408810675144196, 13.444990958486285, 37.31522410256522, 52.41026891980852, 55.57908868789673, 37.747523648398264, 49.119140011923655, 66.19177068982805, 19.151180812290736, 0.5289798208645412, 0.6667523394737924, 0.09408799984625407, 0.3484998196363449, 0.15707367791661195, 0.39926582840936525, 0.03282856236078909, 0.33926308527588844, 0.15315006274197782, 0.1995849824909653, 0.1013451422165547, 0.29424345386879786, 0.11376180380050625, 0.17720395273395947, 0.13698494301310607, 0.08560603391379118, 0.05288279375859669, 0.11360543540545873, 0.1369637455791235, 0.12639468056815012, 0.2905428595840931, 0.34744236352188246, 0.5626352120723043, 0.18118380489093916, 0.49062782738889965, 0.3280383518763951, 0.4762720348579543, 0.33821537292429377, 0.5291474461555481, 0.41170370099799974, 0.39927559931363377, 0.44273658150008743, 0.32484201767614906, 0.42713244738323347, 0.6721130375351224, 0.25469048055154936, 0.3451238093631608, 0.32792712641613825, 0.37360773235559464, 0.4419670956475394, 0.22267295074250015, 0.39832478176270214, 0.22694097672189983, 0.20497024351997034, 0.32989186527473585, 0.2993441644523825, 0.2508361302316189, 0.285097887473447, 0.07796407397836447, 0.19548230192490987, 0.17972576884286745, 0.2659655883908272, 0.20502308782722267, 0.3492717482149601, 0.256292637437582, 0.38348454236984253, 0.6770164029938834, 0.33924549764820505, 0.4617420488170215, 0.37036048088754925, 49.687367166791645, 107.80026585715157, 78.35170882088798, 58.95861952645438, 89.92931147984096, 62.232589857918875, 27.615472861698695, 0.14093062414654664, 0.24548870431525366, 6.79670831986836, 3.724375580038343, 11.019750033106122, 14.519645384379796, 15.010348013469152, 5.281088207449232, 2.9692920403821126, 0.8515062970774514, 0.5880194242511476, 0.9949320980480739, 1.8321615840707506, 5.2374860899788995, 0.7312793369804109, 2.8600974082946777, 9.293218220983233, 23.951670374189103, 31.50320884159633, 28.972876412527903, 30.20341280528477, 39.517664091927664, 53.83126238414219, 62.82121344975063, 55.64556557791573, 55.17207363673619, 53.644602503095356, 60.23229381016323, 61.7509754725865, 67.55654280526298, 69.38910933903286, 74.28850650787354, 73.57232093811035, 77.0679874420166, 72.45901107788086, 71.35311494554792, 67.31504426683698, 68.74063396453857, 67.51964092254639, 66.09392615727016, 61.494232586451936, 57.54476186207363, 47.54289599827358, 50.21199437550136, 57.0249080657959, 60.77229390825544, 63.9911858694894, 62.28768907274519, 63.99244349343436, 44.38633285249983, 44.513241699763704, 60.14751883915493, 57.878376143319265, 65.89208098820278, 63.255739893232075, 64.35159587860107, 50.307556424822124, 50.29250315257481, 48.849654129573274, 54.18025650296892, 54.00276129586356, 60.09331594194685, 62.18134689331055, 70.67665917532784, 70.57003906794957, 69.46027973720005, 65.92232649666923, 65.36660262516567, 65.78944219861711, 68.7556003843035, 63.700730323791504, 64.11682319641113, 55.13088124138968, 52.51857049124581, 50.382103647504536, 51.48988968985421, 50.989935534340994, 55.750938483646934, 52.931932721819194, 47.69218846729824, 44.29216044289725, 47.21331514630999, 42.644888469151084, 49.59359080450875, 53.84527342660086, 59.09948035648891, 62.1182086127145, 61.473499161856516, 35.56153004510062, 12.363657576697213, 5.450777547700064, 0.5134141732539449, 5.8085190142904, 24.217616149357386, 11.57887417929513, 11.891621283122472, 6.928408818585532, 4.717481170381818, 2.046548685857228, 1.3793961192880357, 3.0167666929108754, 12.547363604818072, 41.303274699619834, 79.14422730037144, 56.89173889160156, 52.7248729297093, 60.28431497301374, 71.53385148729596, 29.685594831194194, 0.8749690066490854, 0.6617499079023088, 0.28276416127170834, 0.4013090059161186, 0.17409348035497324, 0.5300053315503257, 0.22392285295895167, 0.3730603717267513, 0.2208302803337574, 0.3575437143445015, 0.2137871411229883, 0.38325690744178637, 0.1964196709117719, 0.35493689136845724, 0.2767639575260026, 0.1256471521088055, 0.18698464147746563, 0.365454048450504, 0.3486937720860754, 0.2148256389690297, 0.44813734026891844, 0.39842854333775385, 0.6150251179933548, 0.32804766137685093, 0.5311782200421605, 0.3433661051094532, 0.5261211256895746], [0.2033894604870251, 0.22615242403532776, 0.14046607193137917, 0.18039622929479393, 0.26594311531100956, 0.36128963476845194, 0.27489291078277994, 0.2771797909268311, 0.287150075925248, 0.17489364956106457, 0.21117193145411356, 0.22656297843371118, 0.15960762623165334, 0.12607671905841145, 0.06203084359211581, 0.07953778667641537, 0.10388618800789118, 0.10301213312361922, 0.08499771369887249, 0.06415765732526779, 0.1642917027430875, 0.1751789463950055, 0.11408062704971858, 0.12464786001614162, 0.10722382034042052, 0.12828414275177888, 0.24619592779449054, 0.18444561772048473, 0.2185362484306097, 0.05358704864712698, 0.25884479763252394, 0.3280339278280735, 0.19532999795462402, 1.4592004141637256, 54.353082520621165, 82.00036770956856, 53.23007297515869, 48.366813387189595, 92.4366453715733, 30.26237521852766, 7.63204116480691, 0.44773220057998386, 0.2789586383317198, 1.172654532960483, 1.085722797683307, 2.785726930413927, 5.420690545013972, 5.13414249249867, 2.2512133036340987, 3.611032656260899, 0.5883360015494483, 0.8768633135727474, 1.327345209462302, 3.4308843229498183, 1.3499114385672977, 0.6751276871987751, 0.5357024744153023, 3.0730950874941687, 11.65559879371098, 12.902066537312098, 11.539295503071376, 11.02961300100599, 37.43726921081543, 35.17299025399344, 33.09529822213309, 30.810289314814977, 31.401150226593018, 39.07934045791626, 51.097580501011436, 56.95212915965489, 60.328839029584614, 64.60011904580253, 67.12820720672607, 72.74225439344133, 68.04343087332589, 65.21720940726144, 64.97951848166329, 65.37276567731584, 65.01992225646973, 63.80024937220982, 59.89661243983677, 52.71761553628104, 50.66628496987479, 44.34547397068569, 50.94886473246983, 52.65105526787894, 56.21668665749686, 54.66838482448033, 63.440714836120605, 36.77974728175572, 35.59450966971261, 61.67617811475481, 55.81769330160958, 61.55860764639718, 56.94903026308332, 59.38243184770857, 46.786688804626465, 42.18842656271798, 47.361527170453755, 48.94929129736764, 49.5483615057809, 50.422583852495464, 59.16587734222412, 62.55443041665213, 62.13366140638079, 62.71567726135254, 59.98979473114014, 54.901997157505576, 50.733540058135986, 44.508364064352854, 40.30533620289394, 33.50292818886893, 25.66160293987819, 20.267539194652013, 20.684116704123362, 21.142272233963013, 27.401018449238368, 46.950534275599885, 58.01381737845284, 47.67667661394392, 45.93105288914272, 42.95045634678432, 38.51551151275635, 30.90745987210955, 24.823080437523977, 25.425397191728862, 37.76418195452009, 42.90038067953927, 21.916386672428676, 3.8221380370003835, 1.408979160445077, 0.24449101356523378, 3.874135749680655, 2.1220538914203644, 1.7797455681221825, 1.1569093721253532, 1.3876135583434785, 1.9762420356273651, 0.13142812118998595, 3.127066739967891, 6.399613559246063, 26.06678192956107, 46.4298814364842, 55.460465567452566, 28.576066528047832, 43.51546995980399, 57.05789811270577, 55.423112051827566, 0.8877363758427756, 0.21349993082029478, 0.08906951413622924, 0.18837381979184492, 0.2056705052299159, 0.2392995964203562, 0.0885712658720357, 0.12347995197134358, 0.057960678424154005, 0.15984140868697846, 0.07270529866218567, 0.06441379750945739, 0.05469204631767102, 0.1375968594636236, 0.09693017269351653, 0.052422244900039265, 0.08843381503330809, 0.1408250576683453, 0.06403011309781245, 0.15417086439473288, 0.13775407602744444, 0.05441008448334677, 0.12325351126492023, 0.36553050577640533, 0.23544920874493463, 0.2761201092175075, 0.37358116092426435, 0.20495499005275114, 0.2916282170585224, 0.3863173175070967, 0.3408606009823935, 0.27913633308240343, 0.316873628113951, 0.37209234652774675, 0.32259755954146385, 0.37111569036330494, 0.48505130090883797, 0.380996327315058, 0.3826035867844309, 0.2812691857772214, 0.19561874174645968, 0.19398484299225466, 0.12798087831054414, 0.11313827761581965, 0.17553745715745858, 0.10637301206588745, 0.07838799551661525, 0.09827205711709601, 0.2062185036816767, 0.16494344919919968, 0.10782353673130274, 0.0790457334369421, 0.11931773674275194, 0.08556948123233658, 0.22390994722289698, 0.1232656299003533, 0.2513942117137568, 0.05234326342386859, 0.30035292889390675, 0.18604442264352525, 0.2146470621228218, 1.8147321364709308, 64.15184211730957, 94.0038115637643, 45.28853212084089, 66.26148891448975, 95.6286061150687, 36.514256613595144, 14.42674275806972, 1.2827204040118625, 0.9739054377589906, 1.418044279728617, 0.382509351841041, 4.193005084991455, 6.87631904227393, 4.872175429548536, 4.618571826389857, 4.515306396143777, 2.882091496671949, 1.299864975469453, 1.8156241114650453, 10.513260228293282, 3.787306717463902, 1.6407329589128494, 1.408772125840187, 4.613514406340463, 13.847561768123082, 15.350512708936419, 14.645807300295148, 14.721593039376394, 39.5829632622855, 43.29684141704014, 38.629837172372, 35.57835510798863, 42.80003479548863, 51.34442220415388, 61.72248091016497, 62.51679202488491, 66.36741420200893, 67.95000539507184, 71.35376807621547, 75.92723914555141, 70.22285148075649, 70.22321278708321, 69.36929307665143, 69.12163148607526, 67.44639301300049, 67.92260864802769, 63.482028824942454, 55.15775339944022, 52.554325921194895, 47.451704365866526, 53.88584048407418, 53.78672095707485, 59.5168308530535, 58.65790843963623, 66.19393852778843, 39.643127713884624, 38.97865758623396, 63.075857979910715, 58.53452927725655, 65.53138610294887, 62.823033877781455, 60.00468472072056, 49.78230387823922, 45.90505620411464, 50.0705429485866, 52.377977166857036, 51.869365555899485, 54.88895886284964, 62.65225410461426, 67.35156399863106, 65.92921216147286, 67.81243106297084, 67.03577532087053, 64.3702587400164, 59.415512221200125, 56.21613080160958, 52.029577119009836, 47.44075400488717, 40.59674365179879, 36.206579957689556, 34.07080793380737, 35.59677478245327, 41.88849367414202, 60.16716834477016, 64.6066711970738, 54.587570326668875, 53.856904711042134, 52.31318868909563, 44.32349681854248, 36.308520453316824, 31.908604962485178, 37.631672859191895, 47.78445359638759, 46.4449451310294, 23.941786561693462, 4.225413654531751, 2.051949824605669, 0.9063217757003648, 3.1101884799344197, 1.122187812413488, 2.7836326999323706, 3.629898101091385, 0.40279673465660637, 1.857188995395388, 0.4612446555069515, 3.392536997795105, 9.738154803003583, 40.73920604160854, 40.608548641204834, 71.85604640415737, 32.698934759412495, 43.42350360325405, 60.252332414899556, 58.61000755855015, 0.27765544397490366, 0.19271321408450603, 0.21714941784739494, 0.15614864469638892, 0.09348392726055213, 0.23388627118297986, 0.12398030369409493, 0.1535096184483596, 0.07150814575808388, 0.1668604870459863, 0.14268686276461395, 0.14712217476751122, 0.09239652739571673, 0.19545153714716434, 0.12888332988534654, 0.11565915734640189, 0.047374035963522534, 0.15060304584247725, 0.038428240455687046, 0.10678140193756137, 0.16847287624010018, 0.19726409417177948, 0.13175073744995253, 0.549932276563985, 0.2651507763990334, 0.254699708627803, 0.34131331954683575, 0.2655520077262606, 0.3195401621716363, 0.4176231862178871, 0.39720278339726584, 0.2955101430416107, 0.46177087298461367, 0.5040820368698665, 0.3193697141749518, 0.3399965816310474, 0.5080887047307832, 0.36193999701312607, 0.4421109179300921, 0.3639331529183047, 0.28038293761866434, 0.2228717343615634, 0.17675491182931832, 0.27559763725314823, 0.19433641912681715, 0.21142997832170554, 0.18712059275380202, 0.322766867599317, 0.2351888141461781, 0.1708110264901604, 0.29912803747824257, 0.13696799320834024, 0.20976745896041393, 0.19598181226423808, 0.22146795397358282, 0.2290787962930543, 0.3382986698831831, 0.09178853966295719, 0.26975295373371666, 0.29921225724475725, 0.17287556427930081, 2.861063425030027, 86.08713136400495, 96.83919075557164, 73.86711910792759, 65.00182914733887, 107.79338019234794, 46.700652735573904, 14.047044549669538, 0.9464851319789886, 1.5415713084595544, 4.417330282075064, 4.013432800769806, 13.362223148345947, 16.048157010759624, 18.390422548566544, 7.0388782279832025, 5.381290784903935, 1.9464396919522966, 1.5670918247529437, 6.60469354901995, 10.763829639979772, 1.9264158521379744, 1.223133412855012, 0.7737725110990661, 5.955136426857539, 14.518122860363551, 14.395171012197222, 14.196507249559675, 15.942719834191458, 43.26444544110979, 55.09276689801897, 53.57236555644444, 50.59360333851406, 58.054690156664165, 65.85375472477504, 70.62108053479875, 68.58716215406145, 68.95704950605119, 70.4463472366333, 70.45540768759591, 74.96005684988839, 68.13040147508893, 68.13161046164376, 67.58545425959996, 68.79465620858329, 69.48234721592495, 68.07648345402309, 64.54830632890973, 56.1570919581822, 55.64444691794259, 49.18778473990304, 57.14711993081229, 58.2363577570234, 61.84094074794224, 60.62651375361851, 68.64399147033691, 43.83494118281773, 47.61368077141898, 65.64273793356759, 60.29109641483852, 68.3213449205671, 66.24948242732457, 65.53738239833287, 52.68763753346035, 48.542234557015554, 55.70043202808925, 57.66515677315848, 57.22661427089146, 59.498682158333914, 67.02212905883789, 72.69383239746094, 70.69405051640102, 73.58101313454765, 70.39117159162248, 69.26112352098737, 65.57278347015381, 61.93909100123814, 60.14576094491141, 58.03301177706037, 53.2282977104187, 49.68696764537266, 50.703020095825195, 52.232440199170796, 56.520253453935894, 70.6890617098127, 74.79882390158517, 66.96534837995256, 64.92346041543144, 64.49512481689453, 55.806155817849294, 48.97594458716256, 44.70254189627511, 54.286213057381765, 57.74347339357649, 53.18652514048985, 26.04111180986677, 5.231515850339617, 3.1763876591409956, 1.1853679993322916, 10.10741855416979, 7.82618338721139, 8.557814802442278, 7.83680978843144, 4.304286130837031, 2.810497258390699, 1.019065905894552, 3.424618133476802, 9.469221302441188, 44.03792585645403, 60.930490493774414, 72.89419760022844, 39.74876465116228, 59.515712193080354, 62.106723240443635, 77.47553403036935, 1.5130251773766108, 0.34476714421595844, 0.23376969886677607, 0.42624894050615175, 0.17065020012004034, 0.2883032597601414, 0.28240160644054413, 0.2924531256513936, 0.13206583554191248, 0.17720602905111654, 0.24034587027771132, 0.1944062810923372, 0.2566375774996621, 0.23213586796607288, 0.2273769083299807, 0.15483368454234941, 0.24163085275462695, 0.23716060976896966, 0.18721059363867554, 0.2893220122371401, 0.3114689067006111, 0.3181733755128724, 0.2543252115803105, 0.49883831824575153, 0.3184374342007296, 0.28042715096047943, 0.40940485149621964, 0.23914307196225437], [0.2028133435440915, 0.08735484257340431, 0.17039108116711887, 0.17864559537598065, 0.11420922300645284, 0.22308252805045672, 0.19804407017571585, 0.20630186849406787, 0.24901195668748446, 0.2656148129275867, 0.20935984940401145, 0.09991105845464127, 0.15368305199912616, 0.11462388932704926, 0.16759467550686427, 0.041921301412263086, 0.019441704265773296, 0.05930691904255322, 0.054121771561247964, 0.12851052917540073, 0.10512710642069578, 0.04538479181272643, 0.049404280592820475, 0.25991799575941904, 0.11673752591013908, 0.2398142788027014, 0.08918583539447614, 0.15701928654951708, 0.16744964543197835, 0.11677700307752405, 0.29607224145105904, 0.07535557502082416, 0.5185134996260915, 0.357575171227966, 20.685317005429948, 88.83453246525356, 70.63240609850202, 37.0051920073373, 48.29116487503052, 83.83538695744106, 34.85435976300921, 9.932236228670392, 0.5929992741772107, 0.3534804295216288, 0.3602002060839108, 2.443814763001033, 2.4135868421622684, 3.6271125248500278, 4.296966637883868, 3.5586810197149004, 1.070132668529238, 1.0051200027976717, 0.4884580352476665, 2.2813061688627516, 3.688753034387316, 1.1613228895834513, 0.2583729715219566, 0.2067165348146643, 3.158936606986182, 5.947533794811793, 3.76478282894407, 4.7427526371819635, 23.275353567940847, 28.264054196221487, 31.93496642793928, 41.94606644766671, 52.82191147123064, 58.15892355782645, 62.30087675367083, 60.362391880580354, 64.91740158626011, 66.60060964311872, 72.92087868281773, 67.84974983760289, 66.39453302110944, 63.62553691864014, 65.81613717760358, 59.69938782283238, 62.07703358786446, 60.56029742104666, 58.672645568847656, 55.01960931505476, 50.00364916665213, 44.23642199380057, 49.96526384353638, 51.288739340645925, 60.379630361284526, 58.44030475616455, 60.01878956386021, 38.283344405038015, 20.478099141802105, 59.352895055498394, 58.422962052481516, 63.39478029523577, 58.333219119480674, 57.09940317698887, 43.337241717747276, 44.51522888456072, 49.98371131079537, 54.14245482853481, 54.630916663578574, 55.50166143689837, 57.488745485033306, 64.21741921561105, 61.91730145045689, 59.19982624053955, 55.44334173202515, 50.216385637010845, 46.1309768812997, 41.57549122401646, 35.230670724596294, 28.151151180267334, 25.10395094326564, 21.2287859916687, 22.083390099661692, 22.4850845677512, 43.32072932379586, 60.0599923815046, 56.819717339106965, 46.35522651672363, 43.084469727107454, 49.26766470500401, 49.357084546770366, 45.71026693071638, 41.18487392153059, 24.411463941846574, 30.234290599822998, 27.201594727379934, 3.3567961156368256, 0.2052612536187683, 1.7786046522004264, 1.2645875598703111, 2.1636738181114197, 0.9727585507290704, 1.8343107487474168, 0.6105149771486009, 1.8762355276516505, 0.6914018339344433, 2.299674166100366, 6.898439501013074, 25.37009300504412, 49.594778946467805, 57.10773059300014, 26.597843170166016, 40.86826883043562, 51.77721854618618, 63.716620853969026, 10.298184820583888, 0.3131269748721804, 0.2450579974268164, 0.0433986214255648, 0.14114396912711008, 0.05329844395497015, 0.09630818678332226, 0.06328610623521463, 0.06254744622856379, 0.04632629307785204, 0.03951975563541055, 0.0664501760953239, 0.024496423745793954, 0.15163378124790533, 0.21727220554436955, 0.08730967249721289, 0.05868367784257446, 0.0776374882885388, 0.037527169699647596, 0.11514116371316568, 0.026662582332002263, 0.11428791949791567, 0.08117085083254746, 0.18758978614849703, 0.13218139005558832, 0.2734795766217368, 0.17189444335443632, 0.1758351983236415, 0.19200007377990655, 0.2844502122274467, 0.12337551186127321, 0.16053759918681212, 0.19065147185964243, 0.2533866890839168, 0.20394917045320782, 0.3260033982140677, 0.25676489781056133, 0.2884445850338255, 0.20815361770136015, 0.18372464712177003, 0.1988953330687114, 0.12167708442679473, 0.1967925801873207, 0.011587207654624112, 0.12056998669036798, 0.11440084129571915, 0.10302462495331254, 0.05965746380388737, 0.13516695770834172, 0.047609759029001, 0.23525180933730944, 0.04017720178567937, 0.2607090590255601, 0.0632405426087124, 0.367941042142255, 0.14981393675718988, 0.23690911754965782, 0.18017733389777796, 0.20724629424512386, 0.231734392366239, 0.21861874471817697, 0.4359098949602672, 0.5898364867482866, 25.363698925290787, 97.73810700007847, 73.74154431479317, 32.29668617248535, 71.17070388793945, 84.1401002066476, 42.224303586142405, 17.72401908465794, 1.4341348963124412, 0.6852441014988082, 0.31753015145659447, 1.412145150559289, 0.6998299988252776, 5.726392609732492, 3.3564337236540656, 9.158542156219482, 2.852975070476532, 3.0631832650729587, 3.5582252613135745, 6.886296655450549, 8.180115938186646, 6.063091456890106, 2.2867422657353536, 0.7547213648046766, 3.537963879959924, 7.360484719276428, 5.048191104616437, 6.2528458918843945, 27.13457587787083, 40.41791786466326, 50.21199784960066, 49.9753908429827, 57.799149308885845, 63.76131861550467, 69.92291164398193, 68.08939320700509, 69.26988519941057, 70.71079567500523, 76.90938091278076, 71.8169697352818, 72.54220185961042, 68.8775829587664, 70.1928630556379, 63.5602377482823, 67.93707479749406, 63.7329352242606, 61.97069835662842, 59.34650271279471, 54.150202069963726, 49.38967159816197, 52.540432998112266, 57.02940355028425, 64.75008201599121, 59.934362002781455, 65.54715851375035, 42.0200890813555, 26.656267098018102, 63.27226965767996, 60.1094913482666, 66.46131215776715, 61.340830257960725, 60.888294083731516, 47.40028074809483, 46.049686431884766, 51.853697368076865, 55.825982502528596, 57.405599866594585, 57.43001931054251, 61.24397931780134, 68.01804910387311, 65.97246469770158, 68.1871474129813, 63.99092878614153, 58.62612043108259, 54.71054996762957, 51.44923577989851, 46.98079368046352, 42.36345168522426, 37.46938378470284, 33.74180725642613, 34.49805266516549, 37.85307720729283, 52.79996906008039, 61.10074915204729, 53.093954290662495, 46.13089350291661, 47.23455926350185, 55.21846328462873, 57.128776686532156, 57.19008411679949, 46.9088694027492, 37.17829247883388, 38.10314287458147, 28.921701192855835, 2.894464067050389, 0.5562531288181032, 1.7278109320572443, 2.864108907324927, 3.237718105316162, 1.791886785200664, 1.365327537059784, 0.39115977766258375, 1.539690843650273, 0.671651905136449, 2.809643715620041, 10.40072112424033, 43.71877077647618, 45.398879936763215, 75.5444142477853, 32.97234637396676, 41.336035455976216, 52.2525691304888, 69.77290003640312, 8.752773438181196, 0.4046826548874378, 0.3037633816046374, 0.03228077086220894, 0.1033041678102953, 0.04885162399815662, 0.2122853667076145, 0.06248673770044531, 0.13534545313034738, 0.08039446427885975, 0.1050419502758554, 0.07765346100287777, 0.14294410896088394, 0.11952014373881475, 0.13177273555525712, 0.2044616136699915, 0.06114948767104319, 0.13208499737083912, 0.05142894087891493, 0.08064059607152428, 0.04863064889130848, 0.14405176309602602, 0.10264835014407124, 0.22465406943644795, 0.23655231669545174, 0.15994544167603764, 0.14677278351570877, 0.2738537479724203, 0.2885215851877417, 0.46449358974184307, 0.3065428781722273, 0.2965011570070471, 0.3445345424115658, 0.34892270980136736, 0.2948759027889797, 0.46280843445232933, 0.34026905415313585, 0.2885948126869542, 0.32172005091394695, 0.33469836307423456, 0.17862526646682195, 0.3715849108994007, 0.2324823279465948, 0.20532724793468202, 0.1956896757973092, 0.2035672909447125, 0.14295411056705884, 0.14288063879523957, 0.14953864152942384, 0.15970714017748833, 0.26064587384462357, 0.09014091414532491, 0.23042237705418042, 0.20771723826016697, 0.3163561230259282, 0.13706393805997713, 0.2284038167979036, 0.25409301689692904, 0.28292950668505257, 0.36959712899156977, 0.26645752627934727, 0.7324922861797469, 0.8130352071353367, 37.25256177357265, 115.42342635563442, 83.80344608851841, 54.52674579620361, 64.34259101322719, 103.47280965532575, 51.93725987843105, 18.869478259767803, 1.5280863749129432, 1.895449468067714, 1.090031006506511, 4.357923184122358, 7.347230161939349, 12.150274055344717, 13.841799974441528, 9.707481111798968, 1.9719350210257938, 1.9825314581394196, 2.9297196609633307, 5.529057255813053, 8.268183486802236, 5.757189631462097, 1.5356375468628747, 0.8326437835182462, 6.149996485028948, 9.203820960862295, 6.080160575253623, 8.364146794591631, 29.587798936026438, 46.6015818459647, 64.33762999943325, 65.57730674743652, 74.88738564082554, 76.71941021510533, 81.00569834027971, 76.71565818786621, 76.31847831181118, 75.41765826089042, 78.97682435171944, 71.9175865990775, 73.45917647225517, 67.67292513166154, 69.64534500667027, 62.99475860595703, 68.70176574162075, 64.37867995670864, 63.00329099382673, 60.54210008893694, 54.316792079380576, 50.63375697817121, 56.801870891026084, 57.3695456641061, 69.96504552023751, 62.66791534423828, 67.57141889844621, 46.121416160038535, 29.077693462371826, 71.05626010894775, 62.831086839948384, 70.14660889761788, 63.198945317949565, 63.39594064440046, 52.11952154976981, 50.76890638896397, 55.558608872549875, 60.12096977233887, 63.23161574772426, 62.97496318817139, 67.1861412865775, 72.22537790025983, 71.92345782688686, 70.3238365990775, 68.66132722582135, 64.35288824353898, 62.85707310267857, 58.83264173780169, 56.497487681252615, 54.65492268971035, 53.22842277799334, 48.750920227595735, 48.48677403586251, 49.36389030729021, 60.215055329459055, 68.14442988804409, 58.88792855398995, 50.41373184749058, 55.667476722172324, 64.80756446293422, 75.09875679016113, 70.4652463368007, 59.79930291857038, 46.59622825895037, 47.51572854178292, 33.00801495143345, 5.52412360055106, 0.5353645096932138, 3.4038946969168524, 4.864563677992139, 7.371986593518939, 8.494437677519661, 4.793492725917271, 1.461095318198204, 2.6856748248849596, 1.1370552203484943, 2.680602422782353, 10.96914369719369, 44.85486377988543, 64.48785005296979, 76.20475714547294, 38.86339044570923, 56.561379841395784, 56.97791392462594, 81.2214468547276, 15.709614719663348, 0.8109320199915341, 0.24008379291210855, 0.25417243263551165, 0.1942630559206009, 0.1396993545017072, 0.25921758477176937, 0.13545467012694903, 0.2853749468922615, 0.29366838186979294, 0.1464777836310012, 0.15161422586866788, 0.2398446500301361, 0.2914537792759282, 0.3884271542940821, 0.3688075856438705, 0.21792237779923848, 0.20558215997048787, 0.13768432262752736, 0.12874406735811914, 0.11152928109679904, 0.2576936494026865, 0.1709590828312295, 0.3217153825930187, 0.3152089917234012, 0.3677326776087284, 0.25848053289311274, 0.2991724950926644, 0.3513772695192269], [0.14580288556005272, 0.10876354521938733, 0.03464667658720698, 0.06473693624138832, 0.13013084365853242, 0.1106166107846158, 0.18057817167469434, 0.21393591671117715, 0.3072492874094418, 0.22508925465600832, 0.35754374148590223, 0.10424909567726509, 0.1154645127909524, 0.07332767133734056, 0.16629889075245174, 0.08595353883824178, 0.16774754944656575, 0.05297197022342256, 0.21824784390628338, 0.03223165849755917, 0.2195712314652545, 0.12290969757097107, 0.3279903658798763, 0.16714798233338765, 0.26979000174573486, 0.1334228648671082, 0.20934949495962688, 0.2556872213525431, 0.25898164457508493, 0.11470121517777443, 0.08320758225662367, 0.3090123385190964, 0.12962773708360537, 0.18077163557921136, 0.05827293345438583, 59.399586950029644, 78.71576663425991, 68.88662256513322, 37.7816983631679, 60.668974195207866, 69.80591092790876, 31.65674318586077, 14.802536078861781, 0.16875351832381316, 0.3899555408528873, 0.4756059306008475, 2.9201103023120334, 0.3583171899829592, 2.4293494820594788, 8.25338990347726, 5.627380779811314, 3.1837911818708693, 4.819590159824916, 8.706549678530012, 8.9610013961792, 4.494181266852787, 3.6082540282181332, 0.6126751069511686, 0.3208158622894968, 1.425485800419535, 1.6105478129216602, 2.354619000639234, 8.028998698507037, 13.0731155531747, 18.836342300687516, 35.3602511542184, 50.93229675292969, 64.52473109109062, 66.40121023995536, 67.49824741908482, 63.53965718405587, 64.45051738194057, 64.56382165636334, 62.74530438014439, 61.296375683375764, 61.04186316898891, 61.80533817836216, 60.266180174691335, 60.453093664986746, 61.77766350337437, 58.66774014064244, 57.26580558504377, 53.781416007450645, 48.59717396327427, 47.630179268973215, 47.844805649348665, 53.31293371745518, 55.983053479875835, 55.71043048586164, 34.71103927067348, 0.6450055635401181, 46.78690072468349, 62.22994259425572, 56.80805131367275, 60.82603127615792, 51.73294809886387, 44.329135281699045, 50.090320995875764, 52.35022953578404, 56.65680987494332, 57.15278271266392, 52.541735785348074, 60.99372604915074, 58.38863100324358, 62.673911639622276, 58.64085061209542, 59.48286805834089, 53.66026374271938, 44.555417265210835, 36.125063691820415, 25.779223782675608, 22.30261618750436, 15.99870320728847, 18.225366353988647, 20.38641766139439, 29.385422229766846, 36.09736817223685, 25.43329381942749, 14.41678946358817, 9.258227961403982, 7.100946920258658, 9.45867133140564, 16.24522008214678, 29.037741320473806, 42.99848576954433, 38.599303313664024, 13.609062245913915, 1.1320489346981049, 0.2380614328597273, 0.16931510104664735, 0.48107372862952097, 0.18762390288923467, 2.323892763682774, 0.44590376583593233, 1.250847497156688, 1.0970784340585982, 0.17565136961638927, 2.0146575399807523, 11.407271913119725, 25.501778738839285, 47.88353490829468, 56.881174155644004, 26.196782725197927, 35.80984476634434, 45.604188782828196, 61.96507031576974, 24.750581196376256, 0.30640152575714247, 0.38166517285364016, 0.07057039000626121, 0.3840417010443551, 0.053691085028861246, 0.23974441683718137, 0.03048650035634637, 0.10767838452011347, 0.020054312822009836, 0.08149688012365784, 0.08524167417947735, 0.05778109734611852, 0.084702571321811, 0.08040118856089455, 0.0919315137767366, 0.03176203762580242, 0.1091339574860675, 0.03167424876508968, 0.05938813289893525, 0.15494036381798132, 0.2960885262915066, 0.09668105534676995, 0.16694265763674462, 0.1101560890674591, 0.08847344826374735, 0.0850189518449562, 0.29242052882909775, 0.1757896686238902, 0.26690685216869625, 0.11678814462253026, 0.15242977067828178, 0.05240034178963729, 0.10943897933300052, 0.26219695061445236, 0.17016959376633167, 0.18232283448534353, 0.25973655549543245, 0.24161630496382713, 0.2993527954178197, 0.29036581622702734, 0.23278403175728662, 0.14950805317078317, 0.12207623943686485, 0.06630103409822498, 0.15680482877152307, 0.16944380556898458, 0.04882645034896476, 0.2686864323914051, 0.0064573794370517135, 0.14276754057833127, 0.10050647971885544, 0.3079846022384507, 0.18877878306167467, 0.39457766711711884, 0.20461926449622425, 0.1920393066746848, 0.18768049270978995, 0.2841931017381804, 0.07795637260590281, 0.17891930283180305, 0.28500126408679144, 0.2643098272383213, 0.31536155353699413, 0.3603602317827088, 68.48403004237584, 88.0656795501709, 64.80376379830497, 32.773957933698384, 83.42312949044364, 71.73280620574951, 43.773248127528596, 20.531046152114868, 0.4908488669565746, 0.17122954688966274, 0.729328087397984, 2.245299300977162, 0.8448798326509339, 2.944467212472643, 4.914255457265036, 5.786202268941062, 6.871226012706757, 7.42415714263916, 11.40301787853241, 14.382758055414472, 8.941315412521362, 7.616005590983799, 1.9632538982800074, 1.303044427718435, 2.654879323073796, 1.9675081499985285, 4.042870146887643, 11.283656511987958, 20.650553430829728, 34.667307308741975, 50.76282671519688, 61.24181842803955, 71.45476709093366, 71.246828351702, 70.17551340375627, 66.84092698778424, 69.76731368473598, 66.58381584712437, 66.27742113385881, 65.23194653647286, 65.69967842102051, 66.29912730625698, 66.24204090663365, 62.79503958565848, 67.04443277631486, 62.9695713860648, 60.9135160446167, 57.71944652284895, 53.0672037260873, 50.75576039722988, 52.406652382441926, 58.73192065102713, 62.622279575892854, 61.756992612566265, 40.52341931206839, 1.6201998378549303, 53.60611643110003, 65.13672147478376, 61.77242456163679, 63.54317992074149, 57.14954832621983, 48.08449765614101, 53.573915004730225, 55.843346050807405, 60.405442919049946, 60.23125852857317, 56.00741733823504, 64.35853018079484, 63.85055433000837, 65.39015007019043, 63.493924140930176, 63.532528332301546, 62.7440676007952, 54.376477105276926, 46.62821429116385, 41.41645390646798, 36.98240886415754, 33.67015048435756, 35.48378317696707, 38.990573746817454, 40.98943846566336, 38.73473760059902, 27.05348171506609, 15.879664931978498, 10.995173386165074, 10.269068394388471, 11.467749033655439, 23.74576050894601, 35.02174186706543, 45.7808050428118, 42.42261559622628, 13.916097930499486, 1.1686122012989861, 0.19205831922590733, 0.30219444579311777, 0.5362129498805318, 1.637615171926362, 2.340420356818608, 0.9343889696257455, 1.1656364181212016, 1.1306444214923042, 0.21958482930702822, 2.650542561497007, 16.37211503301348, 45.37678119114467, 38.80351434435163, 74.44349302564348, 34.65457820892334, 34.23825257165091, 43.588565008980886, 68.85040160587856, 21.90947321483067, 0.36751663205879076, 0.42397951228278025, 0.052162450804774246, 0.3336380842540945, 0.010969045289259936, 0.20764118805527687, 0.015003496614683951, 0.08612360006996564, 0.02942464394228799, 0.05105555323617799, 0.05754234801445689, 0.01622492410907788, 0.1144669306065355, 0.08430431876331568, 0.050274335513157506, 0.05856690875121525, 0.0706458498856851, 0.037998317275196314, 0.0879896663661514, 0.03254402209339397, 0.1302106122353247, 0.1769940818526915, 0.2976964914372989, 0.04546879105536001, 0.21329145772116526, 0.08450852387717792, 0.33829058174576077, 0.34894499289137976, 0.3331760833305972, 0.20642054426882947, 0.23264835189495767, 0.16640744278473513, 0.19192869189594472, 0.26182353922298973, 0.1342235090477126, 0.29049813055566376, 0.37272997945547104, 0.3785229314650808, 0.3795455108795847, 0.43960829079151154, 0.384220969996282, 0.3023614196905068, 0.2806330456265381, 0.2637861610523292, 0.21900726029915468, 0.4499936763729368, 0.1548301154481513, 0.32282994421465055, 0.13866707203643663, 0.12682084127196244, 0.11606349636401449, 0.4087305776774883, 0.1828202006540128, 0.3633305866803442, 0.21387651775564465, 0.31298366827624186, 0.3403209756527628, 0.38453271612524986, 0.2005289468382086, 0.19426195669387067, 0.3578263648918697, 0.3141900221151965, 0.43051440162318094, 0.6738269627094269, 88.18884331839425, 96.98898696899414, 85.79862826211112, 53.13801629202706, 78.91457544054303, 86.87968458448137, 50.82251868929182, 23.813392536980764, 0.27465737770710674, 0.47233403474092484, 3.183955115931375, 3.948191387312753, 2.859048447438649, 9.313687614032201, 23.416492325919016, 20.709668704441615, 10.551166125706263, 10.286226102284022, 26.067195347377233, 24.627719674791607, 10.49160703590938, 7.199393774781909, 2.2322907532964433, 1.085583290883473, 2.606331390993936, 2.080068967172078, 4.5498263495309015, 12.344939129693167, 24.302385909216746, 42.16509451184954, 63.60326099395752, 69.68665899549211, 81.08037063053676, 80.01348863329206, 79.13443728855678, 70.74519620622907, 70.7447932107108, 67.38659681592668, 65.4974649974278, 64.25540501730782, 64.2126944405692, 65.94462326594761, 65.59483705248151, 66.79801491328648, 68.86141450064522, 64.6308022907802, 64.49296392713273, 59.65081296648298, 55.73899800436837, 52.78756652559553, 55.187352725437705, 61.54578127179827, 64.95784010205949, 66.02238750457764, 43.80098533630371, 1.6815813098634993, 55.00975676945278, 68.78392818995884, 65.5439762387957, 65.87111827305385, 61.274836267743794, 52.31762858799526, 58.340639795575825, 58.01372357777187, 65.38443170275006, 65.96846948351178, 58.25679240907942, 69.4790746143886, 69.2354985645839, 69.9858067376273, 69.80076231275285, 71.17294120788574, 72.34997994559151, 62.31095164162772, 56.78071015221732, 54.25488362993513, 51.02678530556815, 48.737937518528526, 48.979554176330566, 54.23902784075056, 53.92315925870623, 45.85903481074742, 30.30664219175066, 16.228916134153092, 10.897344487054006, 9.506968259811401, 10.789298261914935, 21.81525216783796, 38.11270012174334, 51.62876680919102, 51.24179383686611, 21.489027295793804, 2.8092583077294484, 0.38937254356486456, 0.24262783782822744, 1.1688478972230638, 1.6648334371192115, 6.452905373913901, 3.732108925070081, 2.2732992385114943, 2.3921909502574374, 0.2321578525006771, 2.3401511141232083, 16.702520983559744, 44.41200644629342, 61.07410281045096, 73.41692447662354, 37.759495394570486, 52.79249627249581, 52.36387232371739, 78.19392217908586, 34.46419061933245, 0.6515708512493542, 0.34280601516366005, 0.1824974486870425, 0.38987935494099346, 0.09652227815240622, 0.3289332852831909, 0.2878909818828106, 0.22041295415588788, 0.1461181872125183, 0.15957553152527126, 0.18675615159528597, 0.17074041813611984, 0.14115216583013535, 0.11961634643375874, 0.18984761142304965, 0.13060462394995348, 0.13360670714506082, 0.161932802892157, 0.13161287270486355, 0.21088326908648014, 0.44456064647861887, 0.30324199529630796, 0.3627776892057487, 0.17032533112381185, 0.2240746955254248, 0.21662010625004768, 0.47528837621212006, 0.3869401312300137, 0.47438771596976687], [0.13051403952496393, 0.10027558782270976, 0.052772545388766696, 0.0222086954329695, 0.019512962317094207, 0.06153110255088125, 0.2607937401958874, 0.06963306851685047, 0.2732926537947995, 0.3554214467959744, 0.1980556866952351, 0.2418686385665621, 0.1155336962214538, 0.09484878687986306, 0.14109337755611964, 0.11212910605328423, 0.09676219456429992, 0.06629752607217856, 0.03325350509424295, 0.13691502676478454, 0.07573495073510067, 0.1729298470807927, 0.15812182453061852, 0.09682065035615649, 0.20547595566936902, 0.17777488566935062, 0.11129592611853566, 0.07960203715733119, 0.22195274010300636, 0.18395828029939107, 0.03127538213240249, 0.1074676654700722, 0.06057024946702378, 0.0317768568306097, 0.10542916985494749, 3.7477384635380337, 83.39339120047433, 64.50662408556256, 71.74358286176408, 35.57931743349348, 45.66695186070034, 70.34979506901333, 35.24894796098982, 23.345367091042654, 0.5268382557800838, 1.406014342393194, 0.6826777734926769, 2.3841021614415303, 0.372344435857875, 4.825813140187945, 2.046809026173183, 5.289525926113129, 5.4285763161523, 6.6301539199692865, 9.551092794963292, 8.209890706198555, 5.320590453488486, 2.387043420757566, 2.0139553376606534, 0.8803642828549657, 0.19359782018831798, 0.1987167697932039, 0.9231781597648347, 1.3972342078174864, 5.617008422102247, 14.06187982218606, 23.80732502256121, 30.510929652622767, 40.415454728262766, 54.75076266697475, 54.1947990826198, 57.36838184084211, 57.87532588413784, 62.826362064906526, 65.64314092908586, 63.30134092058454, 57.35908167702811, 59.054344858442036, 56.50827128546578, 53.542484828404014, 52.57931859152657, 54.06247411455427, 50.98237936837332, 51.226792676108225, 47.03156416756766, 50.4450022152492, 54.29555491038731, 56.77837903159005, 50.79848139626639, 32.060982431684224, 0.04451180562110884, 39.60401630401611, 67.19486127580915, 56.11924512045724, 60.79912090301514, 51.9515175819397, 49.23268052509853, 52.35572903496878, 55.63647386005947, 59.23864582606724, 60.559741565159385, 60.915253094264436, 59.58451325552804, 62.44153608594622, 55.267642634255544, 54.75364964348929, 49.7078469821385, 43.958188329424175, 44.759669985089985, 34.34541811261858, 29.392179352896555, 21.516179118837627, 20.826339381081716, 21.452453715460642, 21.024774721690587, 12.398410728999547, 4.070794088499887, 3.0919231857572282, 2.137526661157608, 0.6934045436126846, 0.8486682293670518, 0.3074762709438801, 0.6825725734233856, 0.9165895304509571, 1.4736382280077254, 2.806971698999405, 0.06720350602907793, 0.3695946591241019, 0.04321000226108091, 0.16011139777089867, 0.7196660744292396, 1.8098868536097663, 0.9995572098663875, 0.6701415404677391, 0.2621456262256418, 0.07641699377979551, 0.8998467060072082, 18.065893036978586, 25.574225868497575, 40.81074469430106, 68.46547140393938, 28.848838908331736, 48.43776839120047, 39.41187082018171, 62.719283376421245, 29.069362572261266, 0.04002686556694763, 0.1696857711566346, 0.07921001355030707, 0.14270755808268273, 0.048849656246602535, 0.1478973738849163, 0.045601515897682736, 0.11273121767278228, 0.09941382120762553, 0.051404211670160294, 0.05300712512273874, 0.04322710134355085, 0.06899504882416554, 0.025962393564571227, 0.055214179014520984, 0.09287563418703419, 0.040668454353830645, 0.04848272825724312, 0.08509388925241572, 0.0029107292689981735, 0.13978563701467855, 0.09179517573543958, 0.26323304644652773, 0.01981501218064555, 0.13858538999089173, 0.009132258627297623, 0.09342911520174571, 0.10890366270073823, 0.2295982012791293, 0.11970123116459165, 0.12129858402269227, 0.032821071334183216, 0.20632136959050382, 0.10672692236091409, 0.06845028019909348, 0.13977806456387043, 0.25338677050811903, 0.13064920370067867, 0.25871669022100313, 0.263153115021331, 0.18493637495807239, 0.2061378394386598, 0.06881563059453454, 0.11969869344362191, 0.14341239311865397, 0.0765026452551995, 0.039394525212368796, 0.09245264902710915, 0.11255160945334605, 0.07438896796000855, 0.06592119698013578, 0.10306818690150976, 0.15619002176182611, 0.05283543201429503, 0.1190162364925657, 0.05936854359294687, 0.09244128356554679, 0.10008845464991671, 0.16733723932078906, 0.1340751948633364, 0.05196964168655021, 0.08869150227734021, 0.07097670356077806, 0.06407644346888576, 0.046126607007214, 4.945214893136706, 96.29229804447719, 74.57933030809674, 70.03671618870327, 36.89154379708426, 76.82357066018241, 71.15485504695347, 51.66462298801967, 35.71719748633248, 1.2224281706980296, 0.5416849276849202, 0.8336461154477937, 1.0886183508804865, 0.5895710981317929, 2.220662942954472, 2.012574600321906, 4.330123441559928, 7.291499529566083, 6.215907096862793, 7.329949992043631, 10.517459545816694, 8.458621450832911, 6.825965447085244, 2.349275835922786, 2.8432784250804355, 1.9362299655164992, 0.5057669750281742, 2.0416931978293826, 2.3343843264239172, 8.106738618441991, 17.732263122286113, 28.59427080835615, 38.078070299965994, 51.40553161076137, 65.49674933297294, 63.2425730569022, 65.537431035723, 63.1290533883231, 69.42612934112549, 69.70203535897392, 69.27776445661272, 65.22544302259172, 66.453127179827, 65.38122858319963, 61.78945459638323, 57.932777064187185, 59.228015082223074, 56.44088070733206, 56.94113710948399, 53.27057402474539, 55.909409523010254, 60.029385566711426, 61.77920600346157, 56.786491053445, 39.56939690453665, 0.08732008800974914, 44.80299200330462, 75.2189119883946, 60.61333302089146, 66.66344915117536, 55.75595160893032, 51.90357501166207, 54.19622693743025, 58.83418423788888, 60.7850785936628, 62.96931430271694, 60.67664500645229, 63.05076108660017, 63.77992589133126, 63.22526509421212, 64.81538118634904, 61.70752143859863, 55.207314899989534, 55.70772763660976, 49.205766677856445, 43.80827052252633, 37.81108576910836, 34.70721776144845, 34.69429063796997, 25.92273187637329, 10.903664742197309, 4.496451590742383, 5.16830678497042, 2.956518211535045, 1.823608785867691, 1.3513007525886809, 1.4166835184608186, 0.8030669848833765, 0.5189437451107162, 2.0730973184108734, 2.163339218923024, 0.0760509173518845, 0.13381026765065535, 0.015500721987336874, 0.7128830584032195, 2.0136717643056596, 1.1460827759334018, 1.4898535864693778, 0.8566802623016494, 0.5508530757256916, 0.17522792305265153, 1.716571786573955, 24.98917191369193, 46.96485103879656, 30.306857585906982, 83.25827653067452, 37.32481261662075, 39.266292163303916, 41.7741436958313, 68.76534175872803, 27.175594568252563, 0.09813403630895273, 0.07799036721033709, 0.08417702559381723, 0.19800248954977306, 0.02800264149638159, 0.0883922411927155, 0.01853543084247836, 0.02758073520713619, 0.0815088494813868, 0.036595551297068596, 0.07747271284461021, 0.01680861519915717, 0.07264259524111237, 0.0816778793398823, 0.04250734871519463, 0.06538621961538281, 0.05239714249702437, 0.019898163254505823, 0.07354485004075936, 0.04861900183771338, 0.16273758613637515, 0.053698477667889426, 0.16342700485672268, 0.05234387071271028, 0.1091614177982722, 0.13693242440266268, 0.17142538566674503, 0.035206719035548825, 0.22527439972119673, 0.10028909745493106, 0.31237298675945824, 0.21089753189257213, 0.31705645258937565, 0.20309203144695076, 0.18512168287166528, 0.17297882373843873, 0.29877327222909245, 0.17846361228397914, 0.44620321691036224, 0.4336353912949562, 0.2580758274665901, 0.33407438227108543, 0.21250481850334577, 0.3047929092177323, 0.27068517942513737, 0.26094942327056614, 0.16233592054673604, 0.16685964566256317, 0.12614719170544827, 0.23974229980792316, 0.11084125337323972, 0.2120370636028903, 0.22081570540155682, 0.14686377506170953, 0.3298695007605212, 0.3280989857656615, 0.2521108261176518, 0.1714359029595341, 0.3464171513915062, 0.3204597942531109, 0.2155351016138281, 0.23629626472081455, 0.1562019639781543, 0.2114234236734254, 0.18675912357866764, 8.21494378362383, 118.8375140598842, 82.24534034729004, 96.91302926199776, 52.22311224256243, 65.41019562312535, 84.26456328800747, 56.24473653520857, 35.128316811152864, 1.3186906852892466, 2.1826843065874915, 2.3108301503317694, 4.979565918445587, 2.79460585968835, 13.740850465638296, 12.511547378131322, 18.728952680315288, 18.35545400210789, 22.089332546506608, 31.139352525983536, 27.963516814368113, 10.863815954753331, 7.6800132649285455, 2.7478132162775313, 1.4994181075266428, 1.980771609715053, 0.7825800042067255, 1.8214735175882066, 1.5941662405218398, 6.572844743728638, 15.69055928502764, 27.15164065361023, 37.762403215680806, 51.64173214776175, 68.36684172494071, 64.62620953151158, 66.66659668513707, 62.038088934762136, 69.01603276388985, 70.95737334660122, 69.63281045641217, 63.79621941702706, 66.45793533325195, 63.888880593436106, 63.186278751918245, 59.77873625074114, 62.263933181762695, 59.04015663691929, 57.53623294830322, 55.72673790795462, 58.624459811619346, 61.512805121285574, 64.8986483982631, 60.952537127903526, 42.90812792096819, 0.17720171356839792, 48.370784282684326, 77.9854484285627, 62.8691977092198, 69.21855885641915, 58.809316635131836, 55.721811635153635, 58.375874110630576, 62.57940224238804, 64.91720008850098, 67.46119267599923, 69.47602435520717, 69.29586451394218, 69.4338765825544, 69.1867777960641, 70.38643292018345, 69.14557497841972, 64.32000936780656, 66.5518958227975, 64.77392823355538, 56.79662847518921, 54.01736988340105, 50.72711992263794, 48.585153579711914, 34.464822905404226, 15.091285841805593, 6.265334410326822, 6.029239399092538, 3.925366120679038, 2.589042752981186, 1.8462015049798148, 2.242525884083339, 1.2761904001235962, 1.5103629316602434, 2.0511308056967597, 3.4336729390280585, 0.35591704877359526, 0.6382326441151756, 0.14947709840323242, 1.133471469794001, 4.362981038434165, 7.244676487786429, 5.499682443482535, 2.8762765058449338, 1.4424528671162469, 0.20436417604131357, 1.3279516569205692, 25.148044211523874, 40.420957701546804, 50.22091933659145, 84.7831837790353, 41.67556265422276, 57.499490874154226, 50.92205858230591, 77.09664181300572, 42.7073631967817, 0.16752900688775949, 0.18565184942313603, 0.18976685218513012, 0.26552310213446617, 0.08410554871495281, 0.26889314129948616, 0.17142629490367003, 0.20039433906120913, 0.25768965961677687, 0.11626213070537363, 0.1855692717113665, 0.2364399784377643, 0.2131470383277961, 0.14224638497190817, 0.1561986527272633, 0.1794236171990633, 0.23179467341729573, 0.16312014417988913, 0.12936906596379621, 0.09421112681073801, 0.2502339711146695, 0.2785678564437798, 0.45498120731541086, 0.14690393076411315, 0.2636052636163575, 0.27184444293379784, 0.30508370218532427, 0.2169490193149873, 0.43245384469628334, 0.17835028336516448], [0.1113184466958046, 0.06354738971484558, 0.05012341236163463, 0.01808924487392817, 0.12998248876205512, 0.12386728690138885, 0.11847978670682226, 0.10821586567908525, 0.16737443661051138, 0.20222694001027516, 0.11351871184472527, 0.17283022456935473, 0.11700603578771863, 0.20684952767831938, 0.16978464727955206, 0.11412534250744752, 0.1814154160342046, 0.15926211620015757, 0.10877533815801144, 0.12226555070706777, 0.11407156182186944, 0.058795446130846224, 0.05365585549069302, 0.010046794062613376, 0.1355551475925105, 0.11175393047077314, 0.07832392824015447, 0.20952623976128443, 0.13028564463768685, 0.17697683349251747, 0.023291538935154676, 0.13867870212665626, 0.08171102577554328, 0.11688676290214062, 0.11300792425338711, 0.12951075764639036, 9.674214005470276, 85.994859286717, 61.41498838152204, 59.9135035106114, 26.90376193182809, 52.22801767076765, 70.94886875152588, 32.55042396272932, 34.77041162763323, 4.765598314149039, 2.0094974168709347, 0.36877219325729776, 0.6942815365535873, 1.094178972499711, 0.8699181005358696, 4.280896323067801, 6.358133247920445, 3.547561730657305, 3.3625474870204926, 5.737894049712589, 10.952347295624868, 3.0220712082726613, 3.4672672620841434, 3.079633776630674, 0.7640343393598283, 0.5048573581235749, 0.144355801067182, 0.13666239460664137, 0.26644789108208244, 0.11529424121337277, 0.061091187942240915, 1.2273790878908974, 2.2607653396470204, 2.8907241991588046, 5.740339381354196, 5.302615029471261, 6.8266090239797315, 10.399660655430385, 25.669609001704625, 39.583633763449534, 45.77856077466692, 46.51641082763672, 42.741319043295725, 46.44157872881208, 51.74393320083618, 54.80923523221697, 55.03388786315918, 54.004293373652864, 54.509055682591026, 56.210589613233296, 56.06656387874058, 59.01503889901297, 46.51228359767369, 27.881378684725078, 0.19918267907840864, 40.69864245823452, 65.48409666333879, 64.16379301888603, 57.17164012363979, 54.144455909729004, 53.96592889513288, 58.691773959568565, 61.98014095851353, 62.397345542907715, 60.448222977774485, 67.39916610717773, 65.71554115840367, 65.90123176574707, 65.25666822705949, 54.57866621017456, 44.960868971688406, 38.828090122767854, 26.213277748652867, 16.292455673217773, 12.84784540108272, 10.087576236043658, 7.794533474104745, 7.28295715366091, 3.3342850378581455, 0.5663197115063667, 0.8043364424790654, 0.8365445999162537, 0.8213631116918155, 0.5774385663015502, 0.41893232454146656, 0.6198281145521572, 0.5976141808288438, 0.9996723979711533, 0.11556450171130044, 0.08254169513072286, 0.10034509695002011, 0.20805086035813602, 0.20375011542013713, 0.8937611696975571, 2.67761469738824, 1.3455720714160373, 1.7776234362806593, 0.14619623231036322, 0.16428503952920437, 0.08400213997811079, 26.26347153527396, 27.88144642966134, 35.17252472468785, 83.55884865352085, 27.277408259255544, 49.225548199244905, 49.82264164515904, 41.43297324861799, 31.320585863930837, 0.6421455655779157, 0.2638236976095608, 0.07492995035967656, 0.07013800713632788, 0.05913311908287661, 0.06029217903103147, 0.04667562326150281, 0.030914357397705317, 0.027409501806167618, 0.04536561980577452, 0.06328854217593159, 0.035479245840438774, 0.08072157922599997, 0.07776470681918518, 0.05765594156192882, 0.1274222947124924, 0.08035396252359663, 0.02970319953081863, 0.04590398984562073, 0.04165854551164167, 0.04182986203315003, 0.06922887199159179, 0.04357358507279839, 0.06992723380348512, 0.07395459019712039, 0.10742402209767274, 0.02876919268497399, 0.038854078855365515, 0.09228721540421247, 0.15665142557450704, 0.07399070861616305, 0.04757529284272875, 0.07538002942289625, 0.024931590305641294, 0.0029478349564929624, 0.03529230605012604, 0.10608213088874306, 0.07627563457936049, 0.04500493094591158, 0.18768417036959104, 0.19073383244020597, 0.129389544150659, 0.21927517306591782, 0.21101905751441205, 0.14757505618035793, 0.12782591448298522, 0.10416983600173678, 0.14502759144774505, 0.16759377984063967, 0.06471484992653131, 0.021042154636234045, 0.1292291520429509, 0.12739243917167187, 0.08152081205376557, 0.05127776666943516, 0.1589832247367927, 0.09252358986330883, 0.0910803187372429, 0.2761254832148552, 0.019603689234437685, 0.16355777212551662, 0.06994588673114777, 0.17230099439620972, 0.040489178616553545, 0.10295323628400053, 0.06555488985031843, 0.07906610305820193, 14.494335702487401, 100.01366983141217, 70.07164478302002, 55.74526180539812, 27.987356083733694, 81.01994909558977, 60.592592648097444, 40.90227678843907, 58.915012632097515, 2.848871942077364, 1.3738796838692255, 0.21392028326434748, 0.9326811241252082, 0.7833997830748558, 0.3493782510714871, 2.1345795392990112, 2.8156964651175906, 5.228953267846789, 7.258413510663169, 8.257412910461426, 8.224545325551714, 4.857309324400766, 4.12985725062234, 5.0454834784780225, 4.3122752564294, 1.6551397229943956, 0.17356378877801554, 0.11346973518707923, 0.29556540293352945, 1.062196848647935, 0.17239607072302274, 2.7078532576560974, 5.514164660658155, 6.8340462020465305, 11.425251245498657, 10.273809671401978, 11.917117697851998, 14.270953723362513, 31.22049011502947, 46.00280346189226, 55.39767817088536, 58.78988252367292, 54.68596376691546, 57.39254420144217, 61.93150356837681, 61.80531733376639, 60.95518439156668, 60.1937313079834, 59.834710938589915, 61.03058624267578, 59.695802552359446, 67.49253599984306, 58.3368113381522, 34.84467397417341, 0.16308173909783363, 48.413453170231406, 75.9903426851545, 68.70127936771938, 64.0626619883946, 57.95361123766218, 58.30125045776367, 61.575853075299946, 63.99093573434012, 62.486734117780415, 63.483084951128276, 68.25849846431187, 66.8928439276559, 66.61994647979736, 63.56605339050293, 58.27938447679792, 52.73591709136963, 53.91356727055141, 38.36231415612357, 23.066014766693115, 15.901418004717145, 11.924019864627294, 8.754339388438634, 7.232874538217272, 2.370489771877016, 0.9448492654732296, 1.5498561667544501, 1.4503304958343506, 0.8298612471137727, 0.6537917777895927, 0.6850629597902298, 0.9316177240439824, 0.9462784230709076, 0.641202021922384, 0.13532547705939837, 0.17440574217055524, 0.24137623927422933, 0.7700041447366986, 1.3538930820567268, 0.4052298255264759, 0.5127165849719728, 0.3457479530147144, 0.1688462740608624, 0.22122060081788472, 0.20452679374388286, 0.34088901802897453, 36.85967935834612, 50.82572875704084, 23.806920289993286, 85.30607046399797, 46.953143324170796, 44.25458458491734, 51.25218834195818, 47.60342870439802, 41.27901159014021, 0.9360485034329551, 0.24120994391185896, 0.048189970930772166, 0.11816589640719549, 0.009428223728069236, 0.042910971878362555, 0.011925729623596584, 0.011131250781805387, 0.016916235942127447, 0.02800466353073716, 0.09335316677710839, 0.023607296902420263, 0.01564417446830443, 0.04373076092451811, 0.013493816418174123, 0.07670976806964193, 0.09962141221123082, 0.06206465499209506, 0.016057626211217473, 0.014121836201021714, 0.08671914347048316, 0.05410515423864126, 0.04599814336480839, 0.10648290759750775, 0.0723753949361188, 0.050256764848849604, 0.027106883669538156, 0.0018744201224762946, 0.11348225415817328, 0.17840918020478316, 0.12819971942475863, 0.21867819795651094, 0.17605127101497992, 0.11673648096621037, 0.12234156019985676, 0.21474667106355938, 0.24700870418122836, 0.1655828734593732, 0.16636545503778116, 0.3902859059827668, 0.24850785945143017, 0.2141190804541111, 0.2376514891428607, 0.292114753808294, 0.2621179962796824, 0.1940476889056819, 0.17308379310582364, 0.27332652626293047, 0.24154554733208247, 0.39962588623166084, 0.23115581912653788, 0.18354786160801137, 0.13215143951986516, 0.14272947476378509, 0.15564259327948093, 0.2306799760886601, 0.1622937156685761, 0.1559236967670066, 0.3299891400550093, 0.278454595378467, 0.18139842551733765, 0.23680231613772257, 0.2589924468525818, 0.12116560472973756, 0.25273944810032845, 0.31383311269538744, 0.23743870056101254, 23.342450584684098, 122.98935454232353, 80.31793785095215, 84.33452469961983, 38.15097427368164, 72.28952366965157, 83.74731159210205, 52.063678877694265, 54.4604252406529, 8.453631775719778, 2.261290145771844, 0.5583708094699043, 2.544372567108699, 2.5338755760874068, 3.6359593187059676, 11.666464907782418, 15.834583282470703, 16.67529967853001, 17.324603625706263, 22.68438843318394, 33.21747187205723, 13.107250315802437, 8.692340612411499, 10.87628970827375, 5.801454867635455, 2.629854734454836, 0.36822073427694185, 0.1741731132247618, 0.3667061355497156, 0.6504209786653519, 0.1242584894810404, 1.5973285394055503, 3.6033494685377394, 5.075067171028682, 9.710061499050685, 7.940075652939933, 9.215502619743347, 12.099926539829799, 29.101166214261735, 44.67138964789254, 59.53825909750802, 59.96528148651123, 59.08307565961565, 61.30836132594517, 65.46751131330217, 64.9287827355521, 65.36825629643032, 62.71904018947056, 62.92244870322091, 63.32501343318394, 63.678169522966655, 70.97837775094169, 62.85633659362793, 37.71705232347761, 0.5245870394366128, 53.966734886169434, 78.6935601915632, 72.5982529776437, 68.4313279560634, 61.87457697732108, 63.03876154763358, 65.40218435014997, 67.73411791665214, 65.52331229618618, 65.20346587044853, 73.55340099334717, 72.70311519077846, 72.45853165217808, 75.35834148951939, 69.6658491407122, 65.55801854814801, 63.65241949898856, 48.774238382067, 30.782652854919434, 21.65052601269313, 15.988234009061541, 14.487777471542358, 12.406256982258387, 4.694393609251295, 1.7479499599763324, 2.3077429788453236, 1.9266733697482517, 1.7009127182619912, 0.9830987730196544, 0.7045332778777395, 1.2523358230079924, 1.1916160583496094, 2.4496577637536183, 0.6139170431665012, 0.41585261694022585, 0.42882951774767464, 0.904436968266964, 0.9197943870510373, 4.759849982602256, 7.64008457320077, 3.4832133778503964, 4.516963107245309, 0.6479344463774136, 0.25734482812029974, 0.31889753522617476, 37.59548316683088, 39.94622203281948, 41.05892392567226, 98.23331901005336, 44.84695325578962, 56.907295908246724, 65.07122080666679, 57.06501306806292, 63.8207118170602, 2.1171593197754452, 0.5191192414079393, 0.1477514888559069, 0.21968289118792328, 0.20157637420509542, 0.08756723081959145, 0.12049480501030173, 0.1353175789117813, 0.15352441051176616, 0.1805134258632149, 0.17908064488853725, 0.14462973922491074, 0.14498527800398214, 0.17481434238808496, 0.12734324538281985, 0.15373034588992596, 0.15772828779050282, 0.11890098053429808, 0.11013817574296679, 0.13640313994671616, 0.16773344948887825, 0.14745275702859673, 0.184515561110207, 0.18982526047953538, 0.1644254419952631, 0.15396704604583128, 0.0599168473854661, 0.27287185351763454, 0.19306612014770508, 0.3256182617374829, 0.2196056739028011], [0.04970159428194165, 0.012140954146161675, 0.10174093169293233, 0.09922681017113583, 0.0661324452874916, 0.03104964710239853, 0.09438816338245358, 0.028288569367889847, 0.05388182461527841, 0.02924350223370961, 0.04416828030454261, 0.11404762310641152, 0.14409741493208067, 0.23999533908707754, 0.3000311404466629, 0.16779877884047373, 0.19418336876801082, 0.2945529472615038, 0.22140664154929773, 0.18358704021998815, 0.1353303896529334, 0.08440225850790739, 0.07872891186603478, 0.0417814282035189, 0.09342513898653643, 0.09772700350731611, 0.0677699199212449, 0.053734528233430216, 0.22674197597163065, 0.09751313605478831, 0.13728269774998936, 0.06315601071608917, 0.09472366502242428, 0.03403133014217019, 0.06153718222464834, 0.11126773298851081, 0.12381763170872416, 26.05877239363534, 88.9743788582938, 62.39113385336739, 61.70179612295968, 39.18490096500942, 58.23223747525896, 92.43736103602818, 33.346437386104036, 34.639198371342246, 16.21769479342869, 0.43578110901372774, 0.47685633493321283, 0.5978914573788643, 0.5861342911209378, 0.6105182341166905, 2.1002363307135443, 1.8062623909541538, 4.419422558375767, 2.192249587603978, 3.572805621794292, 7.493020738874163, 3.189332587378366, 3.6432253973824635, 3.124310693570546, 1.5483219176530838, 0.7566810282213348, 0.11027907353958913, 0.18630175026399748, 0.1768038206334625, 0.5324510974543435, 0.49383512671504703, 0.48542031539337976, 0.6479972515787397, 0.3813271267073495, 0.5669884213379451, 0.2145250208143677, 0.3283981382846832, 0.9390423085008348, 4.971393534115382, 14.691088710512433, 23.291462966373988, 26.47253588267735, 28.433901173727854, 36.17887054170881, 47.9062694140843, 58.80699593680245, 59.13800116947719, 62.639406885419575, 58.949246406555176, 59.6958372933524, 54.884418215070454, 45.3752247946603, 23.93724070276533, 0.30123874279005186, 46.602853366306846, 52.44703878675188, 61.03444249289376, 62.35414859226772, 60.85624204363142, 62.00164563315255, 64.40556948525565, 67.45197241646903, 72.40535708836147, 75.91519096919468, 81.15948281969342, 78.07628222874233, 78.96017646789551, 75.63177394866943, 65.87831660679409, 42.99872548239571, 20.708251271929058, 8.188148924282618, 2.458498912198203, 0.1492627084787403, 0.13694775929408415, 0.3969999285680907, 0.61160323875291, 1.7867191710642405, 1.636313253215381, 0.729799533528941, 0.04438349464908242, 0.19082472899130412, 0.018030680516468625, 0.0073697223560884595, 0.2813950404524803, 0.07867671895240035, 0.31245582231453484, 0.2991034473691668, 0.1221303322485515, 0.2216535061597824, 0.0645701726898551, 1.016005767243249, 2.0645927233355383, 0.6311257226126534, 0.47262602193014963, 0.11000232624688319, 0.05031802299033318, 0.5488826643143381, 29.39243643624442, 22.89134747641427, 33.42333309991019, 87.8000568662371, 40.09087310518537, 39.719585691179546, 38.530807971954346, 45.86255407333374, 51.0159843308585, 2.0793671991143907, 0.3114604114421776, 0.11151481473020144, 0.12404723438833441, 0.0942267941843186, 0.16948955239994185, 0.04039027874491044, 0.1360707799238818, 0.10418299958109856, 0.011505724928740944, 0.039465255702712705, 0.09564074581222874, 0.10754670801439456, 0.11679904189492975, 0.05539021474708404, 0.06499580413635288, 0.07854405178555421, 0.0599534950618233, 0.048707326741090844, 0.06723548538450684, 0.11113007180392742, 0.030884668097964356, 0.049636176720793755, 0.05041934183931776, 0.13158275932073593, 0.07999425075416054, 0.05930630157568625, 0.029196588322520256, 0.025712297431060245, 0.1518966592848301, 0.1658190850700651, 0.07151066312300307, 0.022396995685994625, 0.03585836371140821, 0.09267812621380601, 0.053099046261715035, 0.010148370754905045, 0.06685751423771892, 0.07116940072072403, 0.017049164344955767, 0.12356411745505673, 0.06453845796308347, 0.09522242218788181, 0.10489498637616634, 0.14373751995818956, 0.30136712161558016, 0.21914564073085785, 0.1732202193566731, 0.19781207905283996, 0.19614846046481813, 0.13992006837257318, 0.1280714084527322, 0.12119841868323938, 0.04282299981319478, 0.06696881433682782, 0.02356373325788549, 0.10965191719255277, 0.05374358328325408, 0.1447383455399956, 0.09440161194652319, 0.19511832217020647, 0.10556897521018982, 0.12589422027979577, 0.09915241559169122, 0.06716930786413805, 0.01349201490769961, 0.11169491149485111, 0.104800771788827, 0.0988343862284507, 34.624878134046284, 101.63348252432687, 66.19482789720807, 47.90868738719395, 36.6575527872358, 93.07902022770473, 74.86595739637102, 32.58234746115548, 64.15313448224748, 10.462572251047407, 1.2482911029032298, 0.3082660042813846, 0.3472601904400757, 0.7656527810863086, 0.4707171129328864, 1.7504097308431352, 1.8223887256213596, 2.040388456412724, 4.037551300866263, 8.804292593683515, 4.591839935098376, 5.088971819196429, 4.42988133430481, 6.268153641905103, 1.7712813594511576, 1.6067244580813815, 0.1034533233780946, 0.1703592985868454, 0.12163626376007285, 0.1501309076058013, 0.19174977578222752, 0.20421348698437214, 0.5882586485573224, 0.06856316128479582, 0.30427909536021097, 0.14577209364090646, 0.35099202447703903, 1.5058509452002389, 6.184695788792201, 17.746006659099034, 28.57790780067444, 37.93516322544643, 43.26836422511509, 49.75108562197004, 58.48275824955532, 67.44037587302071, 66.33324990953717, 70.17105266026088, 66.58580998011998, 69.15307903289795, 61.5700443812779, 55.173960072653635, 29.399186611175537, 0.2835528632359845, 54.95947960444859, 60.27895096370152, 68.22125611986432, 66.81719888959611, 63.83999306815011, 62.83381748199463, 66.74443735395158, 67.09066608973912, 70.35317884172711, 71.53205885205949, 76.98706177302769, 74.50671468462262, 75.40451226915631, 72.21269743783134, 65.20429965427944, 47.784908703395296, 29.691952432904923, 12.211466840335301, 2.6384031900337765, 0.14503782375582627, 0.09703389355646712, 0.5450435674616269, 0.8977540497268949, 2.071452332394464, 1.8353501558303833, 0.8057919815182686, 0.1289828166897808, 0.03011272594864879, 0.06905949608023677, 0.05254975180806858, 0.1611641991351332, 0.0831885968468019, 0.6248212637645858, 0.7062181074704442, 0.4386605130774634, 1.1448203751019068, 1.1723834446498325, 1.1202145240136554, 1.5717550430979048, 0.7165316226226943, 0.14742906258574554, 0.28042299832616535, 0.02700851984055979, 0.6973516632403646, 45.37106629780361, 48.64571755273001, 20.060255323137554, 83.47055094582694, 63.66218866620745, 37.80889013835362, 40.85318429129464, 52.802397455487935, 61.66417162758963, 4.058685115405491, 0.30663904015507015, 0.0955693842843175, 0.1484243513217994, 0.06417302614344017, 0.058272031002811024, 0.031097975759101764, 0.08371212054044008, 0.007068809886862124, 0.07439070500965629, 0.03484839826290097, 0.08257242598171745, 0.13700779607253416, 0.04890784740980182, 0.0548428676889411, 0.04282744421756693, 0.038896544969507625, 0.09208330884575844, 0.01566683584158974, 0.046189887183053155, 0.057842450482504706, 0.025938025675714016, 0.017529422949467386, 0.07323682906904391, 0.07707061977790934, 0.04206047233726297, 0.025773925374128988, 0.018660271107884388, 0.04717900803578751, 0.09856576099991798, 0.05339730650718723, 0.07142026190246854, 0.2793590011341231, 0.11352991445788316, 0.1547672152519226, 0.1534349253135068, 0.16009158454835415, 0.12065979758543627, 0.16476684010454587, 0.20638726891151496, 0.2435964872794492, 0.12454971671104431, 0.15848332084715366, 0.12657252459653787, 0.2452533883707864, 0.31921506247350145, 0.2715318554214069, 0.23811066736068043, 0.17484835056321962, 0.37582475053412573, 0.3622019115303244, 0.1911693433565753, 0.16897470716919216, 0.1310133191623858, 0.19507440738379955, 0.13688145285206182, 0.15809777724955762, 0.20317302138677665, 0.20997883618942328, 0.13965761102735996, 0.23468881526163646, 0.1798617336899042, 0.33898551017045975, 0.16452648943024023, 0.17943824641406536, 0.11655377862708909, 0.12287563511303493, 0.11945233094905104, 0.18097465325679096, 49.61421653202602, 117.75727762494768, 80.38844817025321, 84.41111469268799, 48.669671467372346, 84.00807748522077, 105.57914910997663, 46.29121623720442, 50.79772751671927, 24.535730736596243, 0.8532719537615776, 0.6612919239061219, 1.1773684514420373, 2.4471609720161984, 1.9047318271228244, 9.365496856825692, 6.580395698547363, 12.81474505152021, 15.453827210835048, 18.823522874287196, 23.39626611982073, 13.618336353983198, 21.445800815309795, 10.052898645401001, 2.7722042160374776, 2.2832258258547102, 0.3574805020221642, 0.397380532430751, 0.15524598956108093, 0.9642417963062013, 1.988654992410115, 3.4075175310884203, 2.320092316184725, 0.584166376718453, 0.9051179460116795, 0.35002022662333077, 0.517238450901849, 1.691309547850064, 7.588900668280465, 20.064938408987864, 35.3042973109654, 48.07349518367222, 54.72757305417742, 59.033076422555105, 64.96249539511544, 68.14600018092564, 67.62965175083706, 75.01483644757951, 69.05087797982353, 72.86671747480119, 64.54029505593437, 59.897925649370464, 32.14899526323591, 0.6651863349335534, 62.08418328421456, 63.84654521942139, 70.95225252423967, 71.11887032645089, 67.45934445517403, 66.15713391985211, 70.05633095332554, 69.44311073848179, 74.33523314339774, 75.46958214896065, 82.56029524121965, 79.54110840388707, 82.26173114776611, 80.22031566074916, 75.75575760432652, 59.065885816301616, 37.15447405406407, 15.433837243488856, 3.3912118460450853, 0.2337659533534731, 0.23424130784613745, 0.8633303397468158, 1.8061532825231552, 3.0873575678893497, 2.38286538209234, 1.1629733038800103, 0.3703617565333843, 0.30868628887193544, 0.15375861365880283, 0.18540362774261407, 0.3189765709851469, 0.5749133846589497, 0.9355052411556244, 1.9110496938228607, 0.29641886427998543, 0.6762591036302703, 1.8447684390204293, 5.571078223841531, 6.042664621557508, 2.1847626864910126, 1.2254390205655779, 0.3301754929125309, 0.19254345819354057, 0.8721221451248441, 42.54515402657645, 34.39615733282906, 39.47348049708775, 102.65916865212577, 57.68065473011562, 44.09521722793579, 51.692895208086284, 58.90550054822649, 79.52297360556466, 6.0381113801683695, 0.4852779858878681, 0.20449035641338142, 0.16728055450533116, 0.15969671787960188, 0.20391505371247018, 0.15949580366058008, 0.16510798037052155, 0.1020511579034584, 0.15133184673530714, 0.15302841498383454, 0.2126295603811741, 0.20030432460563524, 0.15411591662892274, 0.17193230560847692, 0.1293400518063988, 0.14665295423141547, 0.12347414371158395, 0.12536089175513812, 0.13131404588265078, 0.1294068603643349, 0.08162512324218239, 0.09148986890379872, 0.11940460279583931, 0.2523075198488576, 0.183466016714062, 0.07387818036867039, 0.1655126450849431, 0.12195851361112935, 0.1596001216343471, 0.31045664101839066, 0.1634210201778582], [0.09258068858512811, 0.12924578972160816, 0.08783953370792524, 0.13886311437402452, 0.07048582418688706, 0.04559532765831266, 0.007642859842495194, 0.011747301206924021, 0.03217569971457124, 0.061071340792945454, 0.037559922584997754, 0.11068823015583412, 0.07323840327028718, 0.06619461945125035, 0.1430645624973944, 0.12870841712823936, 0.12556054389902524, 0.11737849723015513, 0.05370243013437305, 0.045248803216964006, 0.11570341140031815, 0.12551752477884293, 0.050872861075081995, 0.01229571526138378, 0.11428189410695008, 0.046136364340782166, 0.06299067887344531, 0.11571772848921162, 0.10038428913269724, 0.07330302016011306, 0.10558300731437546, 0.0913676308201892, 0.047217117955109904, 0.06259879097342491, 0.10036371595093183, 0.09638053897236075, 0.04539820645004511, 0.10356735118797847, 35.037952014378135, 77.10166536058698, 66.49885327475411, 57.04536703654698, 23.896942887987407, 52.1220645904541, 95.88533510480607, 40.759258542742046, 39.821748529161724, 32.55011476789202, 0.16584587363260134, 0.2342247244502817, 0.13459815537290915, 0.37027482262679506, 0.4253164162593228, 1.5477075449057986, 1.2156101422650474, 2.5661788369928087, 3.291111320257187, 1.6176737334047044, 2.496807153735842, 2.261343777179718, 6.851422343935285, 0.5700412318110466, 2.6348756764616286, 0.5472684566463742, 0.5542253404855728, 0.3375234029122761, 0.4902185893484524, 0.2636057793029717, 0.43979062672172275, 0.6050422936677933, 1.30266292818955, 2.5003793963364194, 0.8404214233160019, 0.671194246837071, 1.0416070563452584, 0.4446641637810639, 0.5630107947758266, 2.2646443886416296, 8.87725215298789, 20.797205584389822, 34.25211075374058, 54.69757768086025, 66.95576681409563, 61.15547316414969, 63.05713258470808, 57.13910518373762, 63.3174329485212, 46.93621751240322, 41.706961563655305, 4.655109362942832, 0.38022789997713907, 35.4481771332877, 57.7212495803833, 63.44164589473179, 63.63404846191406, 70.01115376608712, 73.18233244759696, 79.16181319100517, 80.084714617048, 78.99072769709996, 75.5491807120187, 74.04850878034318, 72.28179032461983, 64.29350199018205, 60.23225212097168, 48.67144325801304, 30.864259447370255, 11.582445553370885, 2.5441686809062958, 0.039244877706680975, 0.48164901775973185, 0.2932615594140121, 1.1754038482904434, 1.1241938876254218, 0.47876904372658047, 0.08365094382315874, 0.13934222795069218, 0.059015210052686076, 0.08550751741443362, 0.03842579433694482, 0.06663804208593709, 0.025409596173891, 0.1209962966718844, 0.061911068590623994, 0.8011411396520478, 0.6660337980304445, 0.6200645161526543, 1.350003610764231, 2.1050657629966736, 0.2220820010240589, 0.2385889802660261, 0.2122199423611164, 0.362331430294684, 1.700546309351921, 33.0281925201416, 22.04735153062003, 38.53290632792881, 96.70066452026367, 54.19508048466274, 42.81157922744751, 53.15001930509295, 52.23550435474941, 68.5126566205706, 11.48959938117436, 0.4014110304415226, 0.17947101965546608, 0.15223554681454385, 0.0538915683781462, 0.1452501102217606, 0.028516312861549, 0.06941701618156262, 0.04736178840643593, 0.0755402518968497, 0.04165199425603662, 0.10044661935951028, 0.0502493348903954, 0.023396036720701625, 0.04176895672987614, 0.034199593256094625, 0.14271085576287337, 0.017334415377782922, 0.045375526417046785, 0.035179964399763515, 0.09804357402026653, 0.028177206504291723, 0.07658375054597855, 0.09178932676357882, 0.046712820551225116, 0.03131311885746462, 0.2044798391205924, 0.16472452666078294, 0.059763586680803976, 0.09067507048270532, 0.2213917409202882, 0.04662822759045022, 0.11817918212286063, 0.08551728153335196, 0.12059294831539903, 0.04946272959932685, 0.14606268304799283, 0.06147563909845693, 0.038363138413322825, 0.03237475135496684, 0.02639370604551264, 0.06880617181637458, 0.03482555538149817, 0.05189659060644252, 0.08691481261381082, 0.08990793236132179, 0.13518518315894262, 0.14565360785595008, 0.07301973178982735, 0.08284685268465962, 0.14360032017741883, 0.05861062676246677, 0.04747662367299199, 0.1384394642497812, 0.005870221881195903, 0.06776808787669454, 0.08692067515637193, 0.05393011595255562, 0.07893713390720741, 0.03811343074111002, 0.08923810973231282, 0.08126348443329334, 0.023517236645732607, 0.1605125069618225, 0.045911555511078665, 0.05087971427877035, 0.05049382123563971, 0.09270813103233065, 0.0498581526667944, 0.07021564511316163, 0.16547048091888428, 47.45944118499756, 91.99695641653878, 68.61539268493652, 49.373548303331646, 30.99356542314802, 91.85011318751744, 86.11071355002267, 28.698226281574794, 73.28235871451241, 29.38236849648612, 0.35022262004869326, 0.4586581342986652, 0.07187325188091823, 0.6035836062261036, 0.378401229424136, 0.32489529624581337, 0.4510485811957291, 3.673842634473528, 4.047115496226719, 5.597059275422778, 2.9924453922680447, 3.7294238805770874, 6.844820252486637, 2.7761588266917636, 1.1898799857922961, 0.935394178543772, 0.9702542679650443, 0.7153693192771503, 0.3940161115356854, 0.3461568924997534, 0.4224229800914015, 0.2718427873083523, 2.6381667341504778, 1.7915714021239961, 0.9579422771930695, 0.5489585516708237, 1.1511944787842887, 0.36914359618510517, 0.3185005379574639, 2.0438647270202637, 10.042465056691851, 27.7894800731114, 46.91246509552002, 64.13842514583042, 71.85059901646206, 67.1047361918858, 69.22704955509731, 64.1516614641462, 70.9396971293858, 59.1308445249285, 54.108321802956716, 6.957349802766528, 0.26524066871830393, 43.879246371132986, 67.99341773986816, 73.01400538853237, 73.11327430180141, 75.67196232931954, 75.75951657976422, 80.50776958465576, 80.2903048651559, 80.04383836473737, 75.75841876438686, 74.84862858908517, 76.22160652705601, 72.96873092651367, 72.21229444231305, 54.10601152692522, 33.666342871529714, 16.285759346825735, 3.2751441427639554, 0.027009836198495965, 0.2249382941850594, 0.5373931665505681, 0.9409344983952386, 0.81338462552854, 0.2377732726080077, 0.08105378997113023, 0.1235713642090559, 0.06281064317694732, 0.12143859293844018, 0.0561539228739483, 0.10143136366137437, 0.07937436830252409, 0.15746771677264146, 0.09172715938517026, 1.910372244460242, 0.1408236056034054, 1.9081203767231532, 1.6127947952066148, 1.0972504019737244, 0.5272635072469711, 0.10680165620786802, 0.3417796088116509, 0.2900887025254113, 2.038744338921138, 55.59939479827881, 40.51779474530901, 15.095136880874634, 85.58067716870988, 75.78431470053536, 44.90772567476545, 46.043905530657085, 52.31110075541905, 77.58881746019635, 15.29324391910008, 0.4026376860482352, 0.22157170197793416, 0.11821701723550047, 0.10418981885803597, 0.17018551219786915, 0.039023193530738354, 0.07188840356788465, 0.01813334965014032, 0.08185965208602802, 0.0345811979579074, 0.10951639339327812, 0.03818123335284846, 0.05047892399930528, 0.04994394324187722, 0.033261725545993874, 0.10420969993408237, 0.01341346514943455, 0.03326547445197191, 0.022329428865175163, 0.02502970307666276, 0.0602035555722458, 0.06908084957727365, 0.05496947553807071, 0.02680069474237306, 0.010931088888485516, 0.11656876068030085, 0.09084346930363349, 0.03568497426541788, 0.06067348178476095, 0.18141499534249306, 0.09959342942706176, 0.09352751635015011, 0.18503226552690777, 0.19858847239187785, 0.18272079527378082, 0.21788467839360237, 0.20346846910459654, 0.10297157030020442, 0.12207960497055735, 0.20017585078520433, 0.1340561823121139, 0.09295101264225585, 0.0910816283098289, 0.10500416944601706, 0.1479915545455047, 0.14592202273862703, 0.17826135456562042, 0.1661910851086889, 0.1750042371984039, 0.1476903935628278, 0.16883526822285994, 0.15035795899374144, 0.18987984183643544, 0.1467747784086636, 0.12929699197411537, 0.12891694451017038, 0.10917725480560746, 0.1542198953351804, 0.09647526924631425, 0.1917473737682615, 0.1189165325569255, 0.1541388239711523, 0.22324258089065552, 0.0938849143151726, 0.09274397803736584, 0.16243913929377282, 0.13236410596540996, 0.1304290055164269, 0.11426826912377562, 0.29802118401442257, 63.884600503104075, 108.2203678403582, 83.14726516178676, 79.13755008152553, 34.06442253930228, 75.7928192956107, 112.64514051164899, 50.76451512745449, 59.5964572089059, 47.38200351170131, 0.25468410232237404, 0.9683903051274163, 0.31039223447442055, 1.4714110046625137, 0.9682125832353319, 3.5084887530122484, 8.850971460342407, 14.872773681368146, 12.252361331667219, 8.317050167492457, 15.809130293982369, 15.74330653463091, 16.881411041532242, 7.568730916295733, 8.259831752095904, 1.5611488350800105, 1.611177059156554, 1.3076965723718916, 3.9043087363243103, 1.0048996146236147, 1.7645851416247231, 1.9999132454395294, 4.060836885656629, 5.590723821095057, 2.510600847857339, 2.442266400371279, 1.7955285097871507, 0.5157748237252235, 0.7661710189921516, 2.412354188305991, 12.21340799331665, 34.9517491885594, 59.899933678763254, 73.14887687138149, 78.80052076067243, 71.24573053632463, 72.86415358952114, 65.63430282047817, 74.75066593715123, 66.50138241904122, 64.56521129608154, 9.179546560559954, 0.2485947119338172, 51.10141938073294, 71.89349719456264, 75.9525305884225, 76.38998917170933, 77.02598558153424, 79.35822486877441, 81.59831714630127, 79.68646471840995, 80.31269890921456, 78.13878127506801, 77.25269140516008, 83.34772763933454, 81.96413285391671, 80.64484364645821, 57.48642478670393, 33.71083913530622, 16.688280650547572, 3.0121231249400546, 0.17512372721518787, 0.8639589345880917, 0.8949350895626205, 1.9026901423931122, 1.1434589624404907, 0.7078090278165681, 0.22601386718451977, 0.19458945840597153, 0.14127610703664167, 0.18253672229392187, 0.11679393931158952, 0.23289943699325832, 0.1762073612106698, 0.3296384188745703, 0.2844507821968624, 2.6692427694797516, 1.6294279141085488, 2.577767997980118, 4.871539669377463, 9.808334214346749, 2.1022943002837042, 0.479800851217338, 0.5565422390188489, 0.6839302948543003, 2.8741190901824405, 49.58532592228481, 31.7209723336356, 44.33491965702602, 110.04640306745256, 72.34554699489048, 46.04058081763131, 59.70348031180245, 59.584270068577354, 89.02735887254987, 21.148954663957866, 0.4433463673506464, 0.25423795197691235, 0.12153476849198341, 0.15077413166207926, 0.23258456960320473, 0.1681944868926491, 0.18609516349221977, 0.07814011310360261, 0.20873593645436422, 0.12002075330487319, 0.18297994136810303, 0.08064866385289601, 0.13312990058745655, 0.09728799813560077, 0.08507603699607508, 0.2608081522796835, 0.11844661991511073, 0.07491493437971387, 0.09202604049018451, 0.1565357217831271, 0.08427869049566132, 0.12992769027394907, 0.11654376345021383, 0.14035784559590475, 0.09840934510741915, 0.2778644599020481, 0.16157039733869688, 0.15434994335685456, 0.13846359295504435, 0.1748042322163071, 0.18033202631132944, 0.17590451746114663], [0.026286570455080698, 0.02057356683404318, 0.05783980419593198, 0.05869757423975638, 0.0719808539641755, 0.051565584260970354, 0.04137099254876375, 0.049789542598383765, 0.052071259090943, 0.06619197316467762, 0.07917167632175343, 0.17341341184718267, 0.10489020948963505, 0.07362667457865817, 0.1433141412479537, 0.12100452051631042, 0.03167061860273991, 0.08556623104959726, 0.017813846169571792, 0.041276995092630386, 0.10261507478675672, 0.06706166506877967, 0.05031463031523994, 0.11184570233204535, 0.1341487616300583, 0.12605960640524114, 0.08308991071368967, 0.048493669634418826, 0.037007842745099745, 0.03934243068631206, 0.12482019434017794, 0.1358692550233432, 0.06267273093440703, 0.10984887555241585, 0.0211403980252466, 0.03500557750729578, 0.12935625522264413, 0.16708196087607316, 0.7395157207335744, 40.49794026783535, 82.89340577806745, 62.46019894736153, 53.398611954280305, 27.86278877939497, 35.57590586798531, 76.96501513889858, 34.73213747569493, 31.898675986698695, 41.19727298191616, 1.7523520780461175, 0.23720642445342882, 0.24121686496904918, 0.3807626669960362, 0.2691621668636799, 0.1571658636842455, 1.459505049245698, 3.9006730914115906, 1.6412825179951531, 1.2744889599936349, 2.16476794225829, 6.951316160815103, 2.63510713832719, 0.6233605678592409, 1.6128653628485543, 0.7828821965626308, 1.3969523715121406, 0.3522980415395328, 0.2215860462082284, 0.16831358335912228, 0.3692595713904926, 0.5827727200729507, 0.2582879103720188, 0.45024145022034645, 0.4509866716606276, 0.4646966617022242, 0.5974566521389144, 0.7948894436870302, 1.5050300806760788, 1.8364937858922141, 4.502691941601889, 15.919888053621564, 36.489114556993755, 61.581578390938894, 66.91866343361991, 58.74377427782331, 55.26914691925049, 45.64256368364607, 23.17796414239066, 4.401963038103921, 0.4508973764521735, 0.6008708232215473, 12.31518086365291, 42.230150495256694, 60.467052595955984, 65.63751288822719, 71.72068854740688, 74.89212431226457, 79.15116160256522, 80.58797264099121, 85.63253157479423, 81.09995760236467, 71.91211141858781, 53.87040853500366, 33.64123903002058, 10.212058424949646, 2.3152416050434113, 0.8645556111420903, 4.018854566982814, 1.070039084979466, 0.34245982659714563, 0.21520574071577617, 0.32356148638895577, 0.15674234926700592, 0.04472511328224625, 0.13524090445467404, 0.08689767281923975, 0.0028680258796417286, 0.08405723702162504, 0.0773139763623476, 0.1707156923200403, 0.0943517056959016, 0.10452190746686288, 0.2253211507839816, 0.4175183389868055, 2.7039368620940616, 0.15189480009887898, 2.557787367275783, 1.3221305864197868, 0.8240458763071469, 0.6341503060289791, 0.2880660710590226, 0.20993384931768688, 4.7395981550216675, 37.701988628932405, 20.065226759229386, 48.158822536468506, 103.56023188999721, 48.36246381487165, 23.35343394960676, 37.77748080662319, 54.58453743798392, 66.89849281311035, 18.158201592309133, 0.13814489862748555, 0.17306024794067654, 0.13962844759225845, 0.12365509543035712, 0.3336697854101658, 0.13915088107543333, 0.08208087485815797, 0.04818503798118659, 0.010304177662224641, 0.0664250228021826, 0.09025251279984202, 0.0649741045864565, 0.06120546681008168, 0.04749922228178807, 0.1268152772848095, 0.06402739895773785, 0.13167402228074415, 0.06049662163215024, 0.07878413104585238, 0.023693396210936562, 0.10318847080426556, 0.06841644844306366, 0.10716039767222744, 0.051140176731028726, 0.045264592726847956, 0.04967824928462505, 0.042409622709133794, 0.014760058606043458, 0.06665193848311901, 0.08433320399905954, 0.07731210360569613, 0.15225116669067315, 0.1186157651245594, 0.020248825063130686, 0.0508371158502996, 0.05877143956188645, 0.11230547087533133, 0.02454896440862545, 0.022507859826354042, 0.07175182125398091, 0.06185792572796345, 0.04493339978424566, 0.04459963519392269, 0.02791752775997988, 0.1408233613307987, 0.10896755355809416, 0.11618085578083992, 0.09103511473430054, 0.21694956214300223, 0.04642904702840107, 0.04021598006199513, 0.033620310947299004, 0.01521425976950143, 0.03795132872515491, 0.06473038837845836, 0.0829077579879335, 0.06496486293950252, 0.02913106558844447, 0.14969999715685844, 0.0850115693839533, 0.061807748063334396, 0.04888881450252874, 0.06425394822976419, 0.14431852235325746, 0.0714333847697292, 0.08170947193035058, 0.10613731614180974, 0.01996583864092827, 0.022123052439253246, 0.13681819981762341, 0.1586615719965526, 1.0202533964599882, 57.430286816188264, 94.03250067574638, 63.973231724330354, 39.395341055733816, 29.346533162253245, 70.66075474875313, 80.00146130153111, 28.485062497002737, 71.88824435642788, 48.7826179095677, 1.6021308302879333, 0.5985787862113544, 0.12410017369048935, 0.3505139558443001, 0.19615162243800505, 0.29559360284890446, 0.5302374448095049, 0.5911945338760103, 2.263581531388419, 1.9054937405245644, 2.550888240337372, 3.323722690343857, 2.1827270814350674, 2.710232581411089, 3.998931041785649, 1.5033276634556907, 1.2970953583717346, 0.6448866842048508, 0.18338898941874504, 0.5455562142389161, 0.789032872234072, 0.37364969296114786, 0.39095122313925196, 0.32244630051510675, 0.48714922262089594, 1.4054135403462817, 1.1012287884950638, 2.2419029346534183, 2.4717408759253363, 1.9016872133527483, 4.736550501414707, 16.742454017911637, 40.472968442099436, 64.47817121233258, 75.41169670649937, 68.21519034249442, 69.52505084446499, 57.60471439361572, 31.805660452161515, 5.577751100063324, 0.43173978158405846, 1.1000763646193912, 20.299542597361974, 58.59015655517578, 70.69470364706856, 73.60626288822719, 78.60610321589878, 77.87871020180839, 82.10099846976144, 80.53568049839565, 84.7891731262207, 82.74063573564801, 79.84341062818254, 67.48139803750175, 50.92344127382551, 22.180503334317887, 5.036132940224238, 5.040455154010227, 5.6121703045708795, 1.0273972302675247, 0.39672911167144775, 0.5903400140149253, 0.35896236822009087, 0.1322003618947097, 0.08864105319870369, 0.07552147004753351, 0.04693401278927922, 0.07078444744859423, 0.03576299222186208, 0.050205057087753496, 0.05276358872652054, 0.06626309041998216, 0.09296541794070176, 0.16137014808399336, 0.18648333980568818, 2.3666011691093445, 1.9759258925914764, 0.897011786699295, 0.9895307421684265, 0.2976931801864079, 0.7291004796113286, 0.27220743202737396, 0.3748197316059044, 6.84380624975477, 62.89808137076241, 35.26883717945644, 21.48177511351449, 91.25039332253593, 77.15738296508789, 30.187515326908656, 35.679256847926546, 52.84985017776489, 74.7731294631958, 23.115400825228008, 0.1185502457831587, 0.16209444350429944, 0.11831779325647013, 0.19902227340000017, 0.23366577444331987, 0.14095085806080274, 0.11758838168212346, 0.028612149147582904, 0.030706179461308887, 0.028298996754788926, 0.038990627242518325, 0.03383289936131664, 0.165845534365092, 0.0646938696237547, 0.025597121200657318, 0.021399642507146512, 0.09517041247870241, 0.0911895628752453, 0.005378076615410724, 0.044450269280267615, 0.039473303128033876, 0.05026597596172776, 0.06521585304290056, 0.036133696258600266, 0.07396867658410754, 0.07876061302210603, 0.06289134134671517, 0.008621878156970655, 0.0718336118651288, 0.07652907419417586, 0.037046380141483884, 0.12535941254879746, 0.08718157865639244, 0.17332787572273187, 0.13006060171340192, 0.10252830372857195, 0.2683871170239789, 0.08730940786855561, 0.20395948418549129, 0.13911064394882747, 0.18215322787208216, 0.09928193435605083, 0.13954082157995018, 0.177797494456172, 0.17819346035165445, 0.18824785655098303, 0.10210331010499171, 0.10621724756700651, 0.23351866805127688, 0.14730904331164701, 0.1294209738927228, 0.20720312584723743, 0.1351925249078444, 0.13924318897937024, 0.1083956163908754, 0.1447926690535886, 0.2561782907162394, 0.15377472208014556, 0.31139063090085983, 0.1837149847831045, 0.10349354693400008, 0.15092328722987855, 0.17419220720018658, 0.29839720098035677, 0.16199688373931817, 0.2157991195895842, 0.12695084858153546, 0.15359701375876153, 0.163008253755314, 0.29801852415714947, 0.12800139720950807, 0.9819933580500739, 73.88160610198975, 109.08831596374512, 81.95243208748954, 70.98605551038469, 36.66194404874529, 58.26222937447684, 95.52375085013253, 43.29231813975743, 49.47367531912667, 63.10167748587472, 2.5491081987108504, 0.7370745145848819, 0.5741269897137369, 0.6764425794993127, 1.7655591922146934, 0.6470856262104852, 3.2013907517705644, 11.166129469871521, 11.616198165076119, 7.767914925302778, 10.120786019733973, 19.78789288657052, 15.202483075005667, 7.437425596373422, 6.692622133663722, 4.079146691731044, 2.1210149185998097, 0.39672267915947096, 0.194094304261463, 2.2112956855978285, 1.683800390788487, 0.9441952662808555, 0.5713392964431218, 0.46129606131996426, 0.7589715995958873, 3.1353051321847096, 1.7507761397532053, 3.8846006052834645, 2.0251076306615556, 2.1525219593729292, 5.326457338673728, 18.111164024897985, 44.2383987562997, 67.23794705527169, 75.12379809788295, 73.01640251704625, 75.44025380270821, 67.83592987060547, 41.37630026681082, 9.13632355417524, 0.5107099126492227, 1.4295280235154288, 27.85562344959804, 68.40572384425572, 73.15206609453473, 76.7119061606271, 79.94613974434989, 80.04778494153703, 82.36402947562081, 82.7109043938773, 88.37563174111503, 86.12702792031425, 84.52801813398088, 66.6804027557373, 47.440469128744944, 15.668479646955218, 2.269973874092102, 4.278265561376299, 6.934304799352374, 2.1619977823325565, 0.984724651489939, 0.6695735795157296, 0.45906558100666317, 0.2536904013582638, 0.2262247558683157, 0.2828257993928024, 0.08950333550040211, 0.17690987565687724, 0.08413463072585207, 0.1267134834613119, 0.20240003429353237, 0.19638225649084362, 0.2733568974903652, 0.261397582079683, 0.6077389003975051, 3.7653399876185825, 5.903438355241503, 12.706429583685738, 5.427239656448364, 1.95005145243236, 1.474247606737273, 0.6036364233919552, 0.32765883366976467, 8.359282187053136, 60.55113969530378, 30.345392295292445, 58.42147513798305, 121.59724126543317, 66.77259145464215, 32.11367756979806, 52.34823887688773, 64.73833261217389, 88.77568817138672, 33.56302663258144, 0.1814779226801225, 0.2547849869089467, 0.1306004034621375, 0.2511469264115606, 0.2904818999980177, 0.22366857874606336, 0.24011136857526644, 0.10310040374419518, 0.18464141578546592, 0.12310267293027469, 0.17657710851303168, 0.14721963953758987, 0.16507599422974245, 0.17408980269517216, 0.14521880261600018, 0.05776458180376461, 0.15943789748208864, 0.101703951534416, 0.1780681756458112, 0.07521910805787359, 0.19008106818156584, 0.17428516649774142, 0.2325242342693465, 0.0949216615408659, 0.11383709404617548, 0.14784645661711693, 0.20980313633169445, 0.10555961142693247, 0.14122619400066988, 0.17253491255853856, 0.1344550930495773, 0.16875734526131833, 0.21997376557971748], [0.06373645671244178, 0.052755687186228375, 0.07475756175283875, 0.052210643754473755, 0.04623753051938755, 0.12048958029065814, 0.062155951878854206, 0.06920915376394987, 0.07157713241342988, 0.024649809979434525, 0.11364024425191538, 0.012230791334461952, 0.11665334685572556, 0.11932967895908014, 0.06111940142831632, 0.02667089268964316, 0.025480358894648295, 0.03045512828975916, 0.01927703060209751, 0.023548951372504234, 0.039080940253500424, 0.10940659285656043, 0.09025818535259791, 0.12940403765865735, 0.08119488454290799, 0.012057533354631491, 0.023152210250762955, 0.14386786653527192, 0.027611530518957546, 0.05475733834984047, 0.11884806837354388, 0.10706651556704726, 0.09482701269111463, 0.02798422096696283, 0.08890568185597658, 0.023036757517339926, 0.1894224685217653, 0.13226691260933876, 0.11009347385593823, 1.4494597996984209, 59.332967621939524, 93.76791327340263, 59.73255157470703, 57.046377999441965, 46.30205542700631, 53.58409411566598, 84.76321465628487, 35.828372137887136, 22.4603785106114, 38.07509994506836, 6.652865844113486, 0.46205515201602665, 0.08291560185274907, 0.04967389987515552, 0.20272441474454744, 0.36899532271283014, 0.7086815152849469, 2.078423546893256, 1.6047744027205875, 1.118473891701017, 2.13101771899632, 1.7387188438858305, 0.7844353903617177, 1.970277441399438, 1.189621165394783, 0.6673843541315624, 0.7019736809389931, 0.04286173737740942, 0.5621653401425907, 0.11735329643956252, 0.12058370666844503, 0.013730662459108447, 0.038958858232945204, 0.06772508232721261, 0.036979469803294966, 0.0466660389543644, 0.1816570966371468, 0.2809221015444824, 0.8917684480547905, 1.1779919436999728, 0.5298874293054853, 2.3109834449631825, 5.9262657931872775, 14.447074924196516, 9.167903116771154, 3.4528775428022658, 1.7890445377145494, 0.24233704486063548, 0.3420257270336151, 0.38152829876967836, 0.17582963433648857, 3.55145445891789, 22.102273566382273, 56.262391907828196, 82.2462853022984, 84.93518951960972, 92.32991409301758, 93.64267199380058, 84.63971042633057, 68.85689122336251, 44.17748737335205, 25.73132116453988, 12.012064831597463, 3.8520830358777727, 0.6237679060016359, 0.16108935672257627, 0.6513961691941533, 3.191279820033482, 0.3763013263898236, 0.2843729135181223, 0.05912037619522639, 0.02730344339007778, 0.051540386863052845, 0.1022926756579961, 0.056450303577418835, 0.07879182563296386, 0.08329648391476699, 0.03762367434267487, 0.04338383614750845, 0.06850452228848423, 0.009677353797347417, 0.027647331722878983, 0.06796603689768485, 0.14347812959126063, 0.8657911419868469, 0.1914857170943703, 1.6510812150580543, 0.6608449593186378, 0.39858734767351833, 0.06290647946298122, 0.24736759492329188, 10.204094920839582, 31.496309280395508, 20.00758797781808, 52.738074507032124, 94.70110498155866, 44.67260558264596, 20.71859019143241, 29.399735518864222, 54.27276829310826, 68.36550767081124, 18.28355230603899, 0.033942475981478176, 0.08915884327143431, 0.027420819770278673, 0.11112251292381968, 0.03135876730084419, 0.22261800297669002, 0.11322958807327918, 0.03367480748732175, 0.043397464523358006, 0.08792523946613073, 0.01672744544755135, 0.03768210977848087, 0.04859189436371837, 0.03449039300903678, 0.04471880290657282, 0.11233270727097988, 0.13146849402359553, 0.037597113089369874, 0.03723730293235608, 0.034835913218557835, 0.14452244926776203, 0.173836369865707, 0.11826451468680586, 0.08668151870369911, 0.11489158496260643, 0.06655186813856874, 0.020229814208245704, 0.037827031287763796, 0.03133790913437094, 0.04198360449767538, 0.026975509111902544, 0.04770644009113312, 0.06326674084578242, 0.02176818371351276, 0.03758566959628037, 0.07638774892049176, 0.025398885498621633, 0.025147659604304602, 0.028111824566232305, 0.011321911488526633, 0.11559089672352586, 0.052122135646641254, 0.043085287524653335, 0.12559280145381177, 0.004430605938458549, 0.04433754086494446, 0.14673711971512862, 0.07027758178966385, 0.055335328049425564, 0.013854691875167191, 0.03519988279523594, 0.029219546554876224, 0.03928079256521804, 0.03175615133451564, 0.039134843075381856, 0.07488032230841261, 0.0892573462000915, 0.09190735114472252, 0.08475980575063399, 0.032810065496180735, 0.018763452535495162, 0.09586627049637692, 0.023888921165572743, 0.08104966447821685, 0.01609551051764616, 0.09255119945321764, 0.13286046790225164, 0.033023915985333066, 0.03152716951444745, 0.010644213612457471, 0.1744661182165146, 0.08359429293445178, 0.0898628979921341, 2.980168793882642, 78.04090200151715, 104.0136365890503, 54.35999250411987, 44.37660884857178, 38.90149436678205, 70.48106738499233, 81.52133805411202, 21.83640422139849, 54.03465700149536, 58.3798554284232, 6.011865862778254, 0.3915559878306729, 0.045944250720952234, 0.08482575256909643, 0.1231316870876721, 0.24124156364372798, 0.3681685956461089, 0.4489543235727719, 0.5550903369273458, 1.7569538482597895, 0.8667736606938499, 2.2961816106523787, 0.3333520953144346, 2.0955667069980075, 1.5399454299892699, 1.257621556520462, 0.383588331086295, 0.13979601860046387, 0.16747564689389297, 0.1288976198328393, 0.039585827982851436, 0.07771902784172978, 0.036841275968721936, 0.11045463769031422, 0.037875183525362184, 0.027824337760518705, 0.06749385794890778, 0.2821349421782153, 0.702281898685864, 1.6274539743150984, 0.9129118706498827, 2.0422167011669705, 6.993056161063058, 16.805427278791154, 10.167416249002729, 3.672693141869136, 1.6422477747712816, 0.07118787722928183, 0.17883455380797386, 0.40453288863812176, 0.100039416924119, 4.883362897804805, 33.24342686789376, 70.07586233956474, 89.67653601510185, 88.0894215447562, 96.41699041639055, 95.9551089150565, 96.31681823730469, 81.6839120047433, 57.61942720413208, 35.799095903124126, 18.116859810692922, 6.1438290902546475, 1.1332088496003832, 0.25271355520401684, 0.9281252771615982, 6.048814645835331, 0.9064506430711065, 0.05457407282665372, 0.057681712321937084, 0.07842866012028285, 0.02625008562712797, 0.043359968678227494, 0.05812243438724961, 0.034134229977748225, 0.09588042473686592, 0.022632030038429157, 0.03505885268428496, 0.08387434469269854, 0.06277143063821963, 0.03602834012625473, 0.03281065921432205, 0.18028509882943972, 1.9119907404695238, 0.6211167339767728, 0.7350790788020406, 0.4042283078389508, 0.6899266988039017, 0.005838843453342893, 0.36336964315601755, 13.593334998403277, 57.47633252825056, 30.835507801600865, 25.63922279221671, 89.1830541065761, 66.72654574257987, 23.09168314933777, 22.701117958341325, 53.60878106525966, 77.30084936959403, 23.392336913517543, 0.0407420211205525, 0.053950261657259295, 0.04082433759633984, 0.14695980133754866, 0.07535723743161984, 0.27098058643085615, 0.09336177738649504, 0.027662062718133842, 0.018969026593757526, 0.07220193424395152, 0.03593270740072642, 0.03702349654797997, 0.08748591518295662, 0.030972212686070373, 0.024488881829061677, 0.04813887724386794, 0.09866780588137251, 0.013692676372426962, 0.03576213726773858, 0.012268823222257197, 0.11721516028046608, 0.05940326422985111, 0.12199728510209493, 0.010637304429630083, 0.03359282010101846, 0.02852912699537618, 0.042777361547840495, 0.057604298261659484, 0.05913914447384221, 0.05700758778090988, 0.02213892337333943, 0.05129245016723871, 0.08153932927442448, 0.028689688736838952, 0.23278229470763886, 0.15594650911433355, 0.1743090780717986, 0.1720085186617715, 0.07861618684338671, 0.2051680093365056, 0.22684241272509098, 0.18134142857577118, 0.13825304353875773, 0.19053785795611994, 0.13810349442064762, 0.20033685357442924, 0.18395287916064262, 0.15149584864931448, 0.2545396829290049, 0.09345078761024134, 0.15932250581681728, 0.0557142457525645, 0.17930686846375465, 0.08184564033789293, 0.13745520849313053, 0.13050888265882218, 0.12549923147474015, 0.16278638637491635, 0.19252952108425753, 0.12289798605654921, 0.09039085930479424, 0.18524738826922008, 0.1312557461538485, 0.19161678291857243, 0.21635368626032556, 0.1433757929397481, 0.2072906568646431, 0.1536684634962252, 0.2098635123776538, 0.11355626197265727, 0.25436421377318247, 0.21025422641209193, 0.2291061548250062, 3.175134594951357, 92.0880195072719, 119.84604508536202, 78.18299961090088, 75.53957135336739, 63.41563183920724, 73.56455980028424, 112.84902845110211, 48.77818495886666, 37.89673273903983, 65.94188567570278, 12.094230754034859, 0.6841873782021659, 0.08296758442052773, 0.10995901535664286, 0.3529719353786537, 1.343383388859885, 2.2115297530378615, 6.596399571214404, 9.14393356868199, 7.801203744752066, 11.677458695002965, 6.400212841374533, 4.7775240285055975, 5.737194887229374, 2.906720472233636, 1.9915810525417328, 1.9415603194917952, 0.3470124437340668, 2.0075805825846533, 0.2465765859399523, 0.6407659681779998, 0.20921846984752587, 0.14833859806614264, 0.23102564896856034, 0.09224441341523613, 0.1705885212868452, 0.29676353292805807, 0.5669310444167682, 0.8164286421877998, 1.8604657224246433, 1.244382958327021, 2.9979036365236555, 8.059430071285792, 20.488038539886475, 14.323720949036733, 7.394018462726048, 3.613665589264461, 0.1895761295620884, 0.4731255865522793, 0.2882244139909744, 0.2704891099461487, 5.863118393080575, 49.7680253301348, 78.19725731440953, 90.42116056169782, 89.83534404209682, 95.220260483878, 96.92874608721051, 97.32276453290666, 78.71444647652763, 51.998035771506174, 29.05382466316223, 13.679136565753392, 4.328750303813389, 0.5450293996504375, 0.20057472081056663, 2.0623204452650885, 14.231334226472036, 1.2753997168370654, 0.4640809861677033, 0.16468948711241993, 0.2105357777327299, 0.16596495652837412, 0.10361013960625444, 0.10244440965886627, 0.08349379511283976, 0.1972442673785346, 0.14193919859826565, 0.15902214550546237, 0.1786738360034568, 0.12728676412786755, 0.1963009544249092, 0.09296320591654096, 0.3713678611176354, 1.7479683075632368, 2.336839646100998, 5.190071148531778, 1.5643946209124155, 1.1398615326200212, 0.10514172206499747, 0.3537122170839991, 16.836492674691335, 54.37059892926897, 30.672437054770334, 64.652939251491, 114.9675828388759, 66.52205330984933, 31.51695932660784, 40.779067856924875, 67.38506126403809, 88.00708539145333, 34.846959931509836, 0.10457838193646499, 0.14706538138645037, 0.16612374729343823, 0.17479500414005347, 0.1860081074493272, 0.2609955093690327, 0.1261450746761901, 0.10098575614392757, 0.12786552735737391, 0.2125900832137891, 0.14928605008338178, 0.13591475758169377, 0.20982829641018594, 0.10669800998376948, 0.15659840484814985, 0.16535461427909987, 0.18886197145496095, 0.10079276721392359, 0.15922000631690025, 0.15942938865295478, 0.36703758633562494, 0.25957568841321127, 0.20712411722966603, 0.09358998228396688, 0.12641658367855207, 0.174653665295669, 0.15748956560024194, 0.12120909882443291, 0.1972330172679254, 0.09794550535402127, 0.12080689040677887, 0.13177306125206606, 0.18775104678102902, 0.20581750305635588], [0.038260974788240025, 0.07643557885395628, 0.018169496906921268, 0.02225784002803266, 0.06791962510240929, 0.11097518940057073, 0.038406632508018186, 0.09382134236927543, 0.06646171797599111, 0.04229109960475138, 0.06267506509487118, 0.09898970289421932, 0.04636715445667505, 0.0797069047444633, 0.08349283837846347, 0.0892030226864985, 0.030608782544732094, 0.06296660445098366, 0.03942044185740607, 0.03368174550788743, 0.07197803125849792, 0.09472053697598831, 0.06612682701753718, 0.026181356815089072, 0.05467370551611696, 0.025421689364260862, 0.0169351619801351, 0.10754386495266642, 0.05657670786604285, 0.05599073859463845, 0.16824666623558315, 0.16374652699700423, 0.03307604783081582, 0.12005955193723951, 0.09041972418448754, 0.08964299836329051, 0.12043893443686621, 0.20826362179858343, 0.1111407248037202, 0.04356035024725965, 3.2914541704314093, 53.89766979217529, 81.06912149701799, 61.87874589647566, 53.700347900390625, 34.867564814431326, 39.233260427202495, 112.11438151768276, 54.195083958762034, 24.109828744615825, 48.16216114589146, 18.236693654741558, 0.5086678479398999, 0.6626873718840736, 0.11830844304391316, 0.305342576865639, 0.4012903869152069, 0.3225022932248456, 0.29035908515964237, 1.5339183019740241, 0.39183464859213146, 1.064869299530983, 1.2294110017163413, 3.0222783514431546, 1.433461681008339, 0.6218234417693955, 0.4177133770925658, 0.341006051748991, 0.09674457979521581, 0.3771641786609377, 0.36615994200110435, 0.08557447525007383, 0.07431088215006248, 0.20366722558225903, 0.14651027188769408, 0.1558823197015694, 0.13930820620485715, 0.12222463504544326, 0.05376451948125448, 0.01676483272707888, 0.42398412632090704, 0.5184425520045417, 0.8046506313341004, 0.7228477522730827, 0.823841392993927, 0.5788111069372722, 0.9026956302779061, 0.1961906382015773, 0.20330515929630824, 0.2327138983777591, 0.16698554104992322, 0.07922741118818521, 2.353396551949637, 24.60588322366987, 50.3923522404262, 54.58997440338135, 53.53774963106428, 35.91283443995884, 18.32705671446664, 8.705271209989276, 2.315724504845483, 0.6050517931580544, 0.1390872344906841, 0.3787541761994362, 0.1990484512810196, 0.6287798370633806, 0.905210823885032, 1.66921058510031, 0.7848632474030767, 0.43425508375678745, 0.04117860412225127, 0.3280721700617245, 0.14783564076891967, 0.075214684009552, 0.04736952031297343, 0.22412299364805222, 0.05390336470944541, 0.0370586718033467, 0.047637908054249625, 0.05619218885632498, 0.003968283134911741, 0.04985443429489221, 0.04399018182552286, 0.006852282152976841, 1.0760087817907333, 0.023931394065065042, 0.36060192595635143, 0.07205497712961265, 0.41619050023811205, 0.18094485199877194, 20.15615783418928, 39.969345637730186, 24.69750564438956, 54.55423981802804, 84.1578598022461, 44.47380372456142, 23.378153903143748, 47.4502591405596, 68.50352668762207, 67.85872691018241, 21.308355024882726, 0.0305470290726849, 0.11771959678402968, 0.025478893259008015, 0.03276192682928272, 0.005209222327851291, 0.06138693421546902, 0.028650069077100073, 0.0218701777048409, 0.0031525610580242103, 0.036660660124783, 0.021343795682436655, 0.03597191654677902, 0.011309185564251882, 0.0746313270979694, 0.07616095537585871, 0.08690635128212826, 0.0941043593255537, 0.10229053148733717, 0.11861409592841353, 0.11674568190106324, 0.06741215554731232, 0.08192969047065292, 0.0600508376955986, 0.065903812912958, 0.07082054551158633, 0.11360611394047737, 0.015460847876966, 0.10465922938393694, 0.057399937084742954, 0.04257287484194551, 0.08327414654195309, 0.027302595221304467, 0.03443498044673886, 0.07458429783582687, 0.02768263589989926, 0.11455569655767509, 0.04244872328958341, 0.03449518346626844, 0.034218432780887396, 0.04431666573509574, 0.09947375620582274, 0.023698948323726654, 0.06315155952636685, 0.12498724966176919, 0.0023186474572867155, 0.12230782343872956, 0.08380053365336997, 0.07282743496554238, 0.10502727356340204, 0.05772287904151848, 0.07020929402538709, 0.017696113558486104, 0.049301200945462496, 0.014619481417217424, 0.03822304807337267, 0.07289230291332517, 0.042039139196276665, 0.03367562172934413, 0.060089697396116595, 0.058069807211203237, 0.04844712891748973, 0.048089042239423306, 0.02365896395141525, 0.021710029869739498, 0.11044980652098145, 0.11937997197466237, 0.10290819512946264, 0.10315083925213132, 0.06182331365666219, 0.09974433561520916, 0.02993333146774343, 0.13726444515798772, 0.14488982169755868, 0.09807560087314673, 0.12916722893714905, 6.084311255386897, 77.08143915448869, 91.99482331957135, 62.40418951851981, 62.07637350899832, 50.34940889903477, 75.65826048169816, 95.99449130467006, 27.583215849740164, 40.62775346211025, 69.15183530535016, 17.147009406770977, 0.5964219133768762, 0.27024038614971296, 0.04772327793762088, 0.21537518448063306, 0.18405152458165372, 0.18394669092127255, 0.24318211951426097, 0.1615852979677064, 1.4472193313496453, 1.3307689343179976, 2.714716992207936, 3.344983526638576, 1.5802293483700072, 0.41828771627375055, 0.19719704134123667, 0.1873475627175399, 0.11731684553836073, 0.20333055007670606, 0.33663495630025864, 0.07467314521116869, 0.09942872183663504, 0.10106123637940202, 0.136551114863583, 0.09174347815236875, 0.1775115190872124, 0.07714409833507878, 0.14687943564993994, 0.0533722210675478, 0.2996368573180267, 0.8334725190486226, 1.2415448363338197, 1.2048498796565192, 1.9660270980426242, 1.2093485125473566, 1.7846465451376778, 1.2006947483335222, 0.11575474935982909, 0.12046416236885957, 0.11965826632721083, 0.06593894067087344, 4.048803039959498, 29.83295570101057, 54.6180659702846, 58.82326166970389, 58.2724084854126, 41.40900543757847, 24.801784208842687, 11.936352917126246, 3.4448167639119283, 1.183320777756827, 0.7181667291692325, 0.3599107973277569, 0.3877142311206886, 0.6142705327698162, 2.5600275099277496, 3.353384332997458, 0.6506641656160355, 0.10744365890111242, 0.12075221405497619, 0.16443125025502273, 0.1611502891672509, 0.10526030284485646, 0.006349133593695504, 0.08265610970556736, 0.0194134364968964, 0.10574139774377857, 0.0278408566955477, 0.0901951901614666, 0.04316981941727655, 0.08459813799709082, 0.13912029271679266, 0.29989155222262653, 0.7716449509773935, 0.10554914163159472, 0.39544985603008953, 0.044019525072404316, 0.34656056655304773, 0.2460214900118964, 23.167984792164393, 57.57905469621931, 22.998195137296403, 32.12337030683245, 85.30226285117013, 66.51079027993339, 32.15074273518154, 39.036563873291016, 64.22827230181012, 77.18024253845215, 25.57883426121303, 0.026053352880158594, 0.12840399917747292, 0.05434304183082921, 0.05290318373590708, 0.05313611802245889, 0.04076221093003239, 0.0399495159674968, 0.03322437219321728, 0.029306734912097454, 0.03589468229828136, 0.018738077022135258, 0.052814526350370476, 0.04224826368902411, 0.048225872218608856, 0.07772939585681472, 0.05338473664596677, 0.13795581805918897, 0.09682389375354562, 0.0995920045035226, 0.03504067473113537, 0.03551772216867123, 0.09525615216365882, 0.10328789654054812, 0.08117058620389019, 0.0498621187039784, 0.08218914869108371, 0.02577486853780491, 0.10594542643853597, 0.06113337924970048, 0.10612439004970448, 0.01492941246501037, 0.0734765554911324, 0.03822459852589028, 0.06877221113869122, 0.030058259942701886, 0.16935104983193533, 0.16111557531569684, 0.12342917041054793, 0.11090080839182649, 0.19215197062918118, 0.24747013513531002, 0.10440510444875274, 0.21016567759215832, 0.1647037634892123, 0.18018557131290436, 0.21061398567897932, 0.13224192894995213, 0.18403951451182365, 0.1739152834883758, 0.20625871366688184, 0.18244000391236373, 0.1252927261271647, 0.10169271499450717, 0.10459081269800663, 0.04780800660539951, 0.19474633570228303, 0.1846021150371858, 0.10622266906180552, 0.18439027640436376, 0.24270665645599365, 0.0730373737003122, 0.16481675314051764, 0.1723091232457331, 0.09279279184660741, 0.20492491738072463, 0.23521101581198828, 0.22608818033976213, 0.16607391568166868, 0.1479314634842532, 0.14570778209183896, 0.12554613181522914, 0.28385315569383757, 0.18473442936582224, 0.24845544940658978, 0.22606242315045424, 6.132824880736215, 85.14175251552037, 107.06542437417167, 81.84526307242257, 69.84371607644218, 44.85367563792637, 55.912067208971294, 140.58398600987024, 72.45603030068534, 37.61778341020857, 78.45952401842389, 31.085392815726145, 0.3996085428765842, 0.7783356319580759, 0.3662188116993223, 0.3541777463895934, 0.6427306798951966, 0.49941930707011906, 1.5985567420721054, 5.462972939014435, 3.5927204617432187, 6.15607659305845, 8.933671525546483, 9.003659861428396, 2.6527926921844482, 3.6990824001176015, 0.41600800145949635, 0.5603311785629818, 0.34318366061363903, 1.2458089675222124, 1.0842375116688865, 0.3419855034777096, 0.17229464330843516, 0.4146190131349223, 0.5625864118337631, 0.24765108685408319, 0.27067958829658373, 0.233831879815885, 0.26062337362340515, 0.09823711256363563, 0.5535498453038079, 1.1611003300973346, 1.8418456358569009, 1.676352139030184, 2.6537261392389024, 2.0701504136834825, 3.2323586557592665, 2.8365241246564046, 0.4089378294135843, 0.22681437565812043, 0.21201634114342077, 0.11735964752733707, 5.073645395892007, 41.72017356327602, 58.125676427568706, 59.15414183480399, 55.99930184228079, 39.04430764062064, 20.60851856640407, 10.026804685592651, 3.222629440682275, 1.4731275354112898, 1.3474310402359282, 0.6964726075530052, 0.4245117280100073, 1.3033327779599597, 4.177320829459599, 12.257004465375628, 2.4450561021055495, 0.8909343928098679, 0.12855645242546285, 0.35109795736415045, 0.4260431815470968, 0.36561798251100946, 0.08069792549524989, 0.3152717426419258, 0.12575942251299108, 0.2002539365951504, 0.06849781836249999, 0.2831359713205269, 0.13649928835885866, 0.19154819659888744, 0.30099759144442423, 0.15572259255817958, 2.8935139008930753, 0.1849910513098751, 1.0311111509799957, 0.2557236451123442, 0.6698553072554725, 0.15436620105590138, 30.27008424486433, 61.125672340393066, 34.47520003999983, 69.29056303841728, 105.50459493909563, 63.43391949789864, 38.40352044786726, 64.93752356937954, 82.66398320879254, 89.21143054962158, 32.53135463169643, 0.254320678966386, 0.21064426191151142, 0.14042603836527892, 0.1278854084334203, 0.15149056964686938, 0.23030629328319005, 0.11344527399965695, 0.17275661709053175, 0.12823581748775073, 0.15333579134728226, 0.13659025276345865, 0.12979617661663465, 0.09803549945354462, 0.1333336103707552, 0.30533486870782717, 0.19692021262432846, 0.22488616912492684, 0.1867592999977725, 0.3025303477687495, 0.24406179945383752, 0.21592482498713902, 0.19624485314956733, 0.20404017556990894, 0.1916585671050208, 0.21798564440437726, 0.19026686464037212, 0.09554459061473608, 0.19164610920207842, 0.14317413233220577, 0.33138344809412956, 0.19238848079528126, 0.15375101406659397, 0.2112980575433799, 0.1660728028842381, 0.06348388562245028], [0.05622435141620891, 0.0057697914890013635, 0.016698546641107117, 0.03783912617447121, 0.025996552713747536, 0.06469213935945715, 0.15853493022067205, 0.03848890148635421, 0.07458792121282645, 0.07346036564558744, 0.027190050010436347, 0.05207303685269185, 0.07125257554330997, 0.03994205886764186, 0.04956470662727952, 0.03543958207592368, 0.03764937724918127, 0.0461805742899222, 0.03326815466529556, 0.08064658075038876, 0.0928885331377387, 0.02032916191300111, 0.04479911431138005, 0.030484824374850308, 0.02566344290971756, 0.05226245329582265, 0.07113850023597479, 0.025192044276211942, 0.02056995702774397, 0.07357598122741495, 0.07331945427826472, 0.05249966913834214, 0.04663171186777098, 0.042264565492847135, 0.06786631260599409, 0.10012329063777413, 0.028732982663703815, 0.01705720498492675, 0.18464327497141703, 0.15529820961611612, 0.05582900298759341, 1.626334771513939, 36.32981320789882, 83.96856307983398, 51.93338973181588, 38.27769551958357, 25.79785364014762, 26.358649696622575, 91.69314643314907, 61.24211720057896, 32.741172858646934, 45.6087190083095, 36.478007861546104, 5.021807491779327, 0.37524946140391485, 0.3114554445658411, 0.001563694658606047, 0.3292560779622623, 0.22825073929769651, 0.13570875435003213, 0.5344019127743584, 0.931753539613315, 0.2873374601559979, 1.1516622879675456, 0.79044601640531, 0.2101742271333933, 0.3135664755744593, 0.19560830587787287, 0.1756610455257552, 0.3899866448981421, 0.18520933602537426, 0.05677772725799254, 0.036320178037775416, 0.022298279018806558, 0.020100539716492807, 0.016699058935046196, 0.046271355490067174, 0.028859478554555347, 0.041343946142920425, 0.027493187226355076, 0.0518332934672279, 0.040968726455633125, 0.1595073930386986, 0.1949295944401196, 0.2723875695041248, 0.3489341363310814, 0.11135947770838227, 0.0362050204670855, 0.021047018035980206, 0.08467995574963944, 0.06477771619600908, 0.035624828921364884, 0.031285122502595186, 1.1684490271977015, 1.813141433256013, 2.2392895434583937, 1.190837642976216, 0.3827857327248369, 0.26072200547371593, 0.5117249467543193, 0.4437643177807331, 1.1255072057247162, 0.2590498509151595, 0.3258608244359493, 0.143934091553092, 0.32048576857362476, 0.5313513278961182, 2.999956177813666, 0.6912565731576511, 0.20430751836725644, 0.09149425224001918, 0.12006180467350142, 0.06691984446453196, 0.11788623141390936, 0.07543330120721034, 0.09628470268632684, 0.08311777814690556, 0.038058197990592034, 0.0969923332865749, 0.08998173661530018, 0.04839508867423449, 0.0837601065369589, 0.05036617862060666, 1.9278128743171692, 0.12637954923723424, 0.08849915117025375, 0.14655149967542716, 0.5150147016559328, 3.8652307646615163, 37.52831145695278, 49.768744468688965, 33.46515083312988, 67.16319833483014, 78.8994561604091, 38.2902717590332, 19.99870296886989, 38.126599993024556, 59.908000537327354, 47.89027466092791, 13.192562903676714, 0.022858548776379654, 0.04842883561338697, 0.02701461817403989, 0.041518658732197115, 0.06341709742056471, 0.03239694284275174, 0.062482978616441996, 0.060955447011760304, 0.08316495668675218, 0.07772879196064812, 0.019310233016897525, 0.04070436581969261, 0.05659918773121067, 0.02049135383484619, 0.045202812113400014, 0.0031164939531923403, 0.09858771160777126, 0.10520770959556103, 0.18210669394050324, 0.02651009346092386, 0.042771912911640744, 0.0927690974037562, 0.11324160492845944, 0.035753404522048574, 0.10072850994765759, 0.11886117767010417, 0.06675707069890839, 0.03129325135211859, 0.0689989368298224, 0.05734607497496264, 0.025476262239473205, 0.046912750894469876, 0.052460181792931895, 0.0076482312953365696, 0.03682634819831167, 0.09073330235800572, 0.06815981292831046, 0.011196171316052122, 0.05243311503103801, 0.05981181016457932, 0.014762056891673377, 0.04276575181367142, 0.02718195678400142, 0.07620792356984955, 0.03168692719191313, 0.03048391853060041, 0.038612842692860534, 0.025401891408754245, 0.05462292395532131, 0.04272406262212566, 0.024783410131931305, 0.03237453761643597, 0.09511697106063366, 0.017906503519043326, 0.0714004554652742, 0.045194588268974, 0.055723327943789105, 0.001779529544624633, 0.017715085397607515, 0.07114846113004855, 0.05135735543444753, 0.009443715530713754, 0.023675839117329036, 0.12382330426148005, 0.05147950530850461, 0.00834153886950974, 0.10099374928644725, 0.06945204215922526, 0.05576446073661957, 0.02278223733550736, 0.09117413977427141, 0.03248249932325312, 0.01536547638741987, 0.0548648590088955, 0.11058254154132945, 0.06740180110292775, 0.0778750026864665, 4.473280216966357, 60.765039988926475, 94.85596643175397, 49.157990864345, 26.81807848385402, 30.228874479021343, 62.66198853084019, 94.21175030299595, 40.22839185169765, 43.98186431612287, 71.4518210547311, 39.25650215148926, 6.041506443704877, 0.37191182907138554, 0.10008310100861958, 0.05115819522844894, 0.2057162384901728, 0.025780697153615098, 0.5578686392733029, 0.17908217837767942, 0.47117064573935097, 0.7820513440029961, 1.4960737441267287, 0.3700903153845242, 0.08999422165964331, 0.4279033717300211, 0.37448106120739666, 0.0684830534404942, 0.5804129924092973, 0.5504263043403625, 0.030272015436951603, 0.05788704380393028, 0.033330942903246195, 0.03370114482407059, 0.01497855706007353, 0.02299829475980784, 0.02533442636818758, 0.004571601274489824, 0.04932432881157313, 0.052797797069485695, 0.07761808218700544, 0.16093741916120052, 0.307296269174133, 0.29533556955201284, 0.27155150579554693, 0.23187693900295667, 0.06509683121527944, 0.02059165827397789, 0.0872072476361479, 0.08004603654678379, 0.0400175933859178, 0.05896434706768819, 0.8672816391502107, 2.322214339460645, 2.939378959792001, 2.165127294404166, 0.6016770313893045, 0.25697985770446913, 0.08406415129346506, 0.7800437488726207, 0.8623017892241478, 0.7206608610493797, 0.3510673690055098, 0.688725366124085, 0.07444438391498157, 0.22302302052932127, 2.58167809673718, 3.258172733443124, 0.33598624968102997, 0.06616454677922384, 0.1542942084904228, 0.01855671139700072, 0.04436077729665807, 0.0590614861409579, 0.13203654997050762, 0.061042828751461845, 0.005632477629530642, 0.03292888715597136, 0.02672431035898626, 0.023668648342468908, 0.010766391476084079, 0.19028308162731783, 1.7757913917303085, 0.3936334177851677, 0.09105012392891304, 0.20442091513957295, 0.6234200075268745, 6.021567719323294, 47.510830061776296, 64.24360697610038, 33.06983307429722, 56.00695180892944, 88.379793712071, 55.32127577917916, 26.85637174333845, 34.242185252053396, 66.6799372264317, 61.50443254198347, 16.80378576687404, 0.08163169824651309, 0.03408685805542128, 0.05502906109073332, 0.018290272747565593, 0.025322445136095797, 0.09943660641355173, 0.07492235755281788, 0.0263319763221911, 0.07279671089989798, 0.13507291275475705, 0.011339651786589196, 0.056320567681853256, 0.029339067105736052, 0.04263292858377099, 0.07184408844581672, 0.02085899937498782, 0.06599400378763676, 0.08831472535218511, 0.04040334393669452, 0.029212157308523144, 0.06143555124955518, 0.06940816129956927, 0.04627323842474392, 0.027277796462710415, 0.14764277397521905, 0.10279435730938401, 0.01962625391648284, 0.0247706350138677, 0.024780008975150328, 0.02242253065508391, 0.027058273420802186, 0.06321469720985208, 0.08442215315465416, 0.031970436086079905, 0.012671788206457027, 0.04001514048182538, 0.24395746790937015, 0.057481897329645495, 0.12238276084618908, 0.1944213445697512, 0.0825139634045107, 0.12353412620723248, 0.22128967568278313, 0.1071761871821114, 0.17522600958389895, 0.1277084057884557, 0.08742605482361146, 0.17195434442588262, 0.11425908175962311, 0.15557153709232807, 0.12470883317291737, 0.15052186591284616, 0.13206910608070238, 0.09769775864801236, 0.11130182258784771, 0.1761119591870478, 0.13358077353664807, 0.10453237047685043, 0.06838054036987679, 0.2991927968604224, 0.1642302546117987, 0.12962965055235795, 0.13951818565172808, 0.17458620534411498, 0.1255196960909026, 0.18176140104021343, 0.18866804614663124, 0.10280848440847226, 0.12588534504175186, 0.09458279436720268, 0.14494976348110608, 0.18379739964646952, 0.09907061140984297, 0.18254149918045315, 0.24565263837575912, 0.17408323447619165, 0.14529629131512983, 4.292685679027012, 64.8061887196132, 114.82522119794572, 71.46958759852818, 52.987448828560964, 35.7784423828125, 41.6202688898359, 115.48974691118512, 84.21192373548234, 48.79088626589094, 74.99485342843192, 62.62021596091134, 8.64571646281651, 0.2409606230046068, 0.35273976783667293, 0.16584630789501326, 0.48379720534597126, 0.32089693365352495, 1.1806394244943346, 2.963625350168773, 4.336918779781886, 2.6352639070578983, 2.1512623812471117, 2.6018424204417636, 0.9283117928675243, 0.6662801333836147, 0.5585102619869369, 0.16235502809286118, 1.7840871065855026, 2.323967239686421, 0.306914253958634, 0.22716778383723327, 0.0969547356611916, 0.10402183394346919, 0.12394257714705807, 0.2097308180694069, 0.16480614085282597, 0.18394055696470396, 0.07831737359187432, 0.1298266699803727, 0.183388405878629, 0.320696304419211, 0.6093337291053363, 0.3809161516172545, 0.7618038047637258, 0.40934193772929056, 0.12064007935779435, 0.17778099248451845, 0.19256720691919327, 0.23010175568716867, 0.07688822277954646, 0.07966633513569832, 1.6028245644909995, 3.78231052841459, 4.0551076616559705, 2.3029031242643083, 1.0385153251034873, 1.6180344969034195, 1.430282554456166, 1.9541337362357547, 1.8709034366267068, 1.7923443892172404, 1.9416258931159973, 1.015077531337738, 0.574122809938022, 0.5220983358366149, 6.322388674531664, 9.139903613499232, 0.3873707838356495, 0.18133923012231076, 0.31697540836674826, 0.33633764939648764, 0.218407272494265, 0.10671027111155645, 0.226228406386716, 0.17790990056736128, 0.09506669840110199, 0.254181579287563, 0.20701827933745726, 0.23756479950887815, 0.19106208054082735, 0.14373506366142205, 4.654552204268319, 0.8127422428556851, 0.1335445126252515, 0.27917218687278883, 0.8318296500614711, 4.927385815552302, 57.96021550042288, 69.3486499786377, 44.582383223942344, 87.67345373971122, 101.7400678907122, 57.068535804748535, 36.351116384778706, 53.56848151343209, 80.8199382509504, 74.30194432394845, 21.963870661599294, 0.1728563481675727, 0.13516969898981707, 0.26151521291051594, 0.13933305415724004, 0.16421979160181113, 0.16516104180897984, 0.11851022578775883, 0.14725695896361554, 0.20502790542585508, 0.2907361334988049, 0.1367898370538439, 0.13421861002487795, 0.15682527981698513, 0.11578357352742127, 0.1307405616555895, 0.15704479946621827, 0.13280851926122392, 0.17949816105621202, 0.18594944131161484, 0.2420120265867029, 0.15638140934918607, 0.1961558564965214, 0.16906818215336117, 0.08489437960088253, 0.28226158395409584, 0.23226886082972797, 0.10092140388275896, 0.18133051773267134, 0.09038248618266412, 0.18192925703312668, 0.22214362557445252, 0.16992838813790254, 0.20883895164089544, 0.07206772680261306, 0.1431002670100757, 0.17582622809069498], [0.11659393432949271, 0.09237322650317635, 0.03227618735815797, 0.12333929166197777, 0.18809859241758073, 0.05911693602268185, 0.10674128694725887, 0.08215513373059885, 0.036611730964588265, 0.04625463977988277, 0.05916412813322885, 0.030861197571669306, 0.0702110921431865, 0.13587076137108461, 0.03619133780843445, 0.07052289255495582, 0.008726503167833601, 0.1306191310286522, 0.041735454063330374, 0.1215578658240182, 0.05159361793526581, 0.06939015976552453, 0.03972072074455874, 0.15355543313281877, 0.04326185929988112, 0.05485086761681097, 0.08453842013009957, 0.1263765636831522, 0.07380398256438118, 0.07680428799773965, 0.09253226154084716, 0.025111537792586854, 0.035786483104207685, 0.18602056535226957, 0.040106440761259625, 0.08451764338782855, 0.09713215899786778, 0.12323388803218092, 0.07487692963331938, 0.0821393985035164, 0.05731881143791335, 0.0840129761823586, 1.239787376352719, 38.509609018053325, 89.14084380013603, 82.02426256452287, 68.05930055890764, 38.13095303944179, 27.618807997022355, 67.39428847176688, 76.59543350764683, 34.923456123897004, 27.23516842297145, 42.29919474465506, 22.940580674580165, 5.132792804922376, 1.3116483603205, 0.1538640172885997, 0.0976900097780994, 0.3785167975085122, 1.1751809631075179, 0.4306442460843495, 0.7968559467366764, 1.0296113171747752, 0.0614545163033264, 0.3217103885752814, 0.3200762862605708, 0.15363959861653192, 0.24393165643726075, 0.2908604953970228, 0.2837163901754788, 0.15374682072017873, 0.04372245565588985, 0.11084662058523723, 0.07555624496723924, 0.08842713146337441, 0.07933100312948227, 0.06318905537149735, 0.07029411090271813, 0.11598508485725947, 0.036617661360651255, 0.08380860822009188, 0.14619448169001512, 0.07795806894344942, 0.09794610925018787, 0.21330088935792446, 0.017401949968189, 0.05373537300952843, 0.08936369299356427, 0.040853826728250296, 0.09256439017398016, 0.23964198519076618, 0.20784309293542588, 0.596360302397183, 0.7651679271033832, 0.36168057950479643, 0.5345829459173339, 0.18725080362388066, 0.2833533467991011, 0.14810101581471308, 0.09481460228562355, 0.05166495232177632, 0.13034692992057118, 0.06160122914505856, 0.19411100979362214, 0.034941177748675854, 0.05579403468540736, 0.09257654273616416, 1.5176310730831963, 0.693658749972071, 0.08530289839421, 0.1279289432402168, 0.18670614356441156, 0.08280455281159707, 0.10690399285938058, 0.04452282502981169, 0.07328991086355277, 0.10388789113078799, 0.0777018473350576, 0.05138034080820424, 0.16124966740608215, 0.11391403313194003, 0.941071399620601, 0.6792541029197829, 0.12906635792127677, 0.2896288457725729, 0.45887211710214615, 14.576882907322474, 35.23933860233852, 41.170393875667024, 36.76618092400687, 68.817932673863, 59.46763065883091, 26.697105135236466, 22.380734784262522, 46.78392342158726, 56.079088006700786, 38.62428903579712, 2.7725001658712114, 0.2232916389725038, 0.21396122606737272, 0.05131614461008992, 0.04778967937454581, 0.04698574769177607, 0.11319128477147647, 0.04592529584520629, 0.03791898635349103, 0.04643459065950342, 0.04224205170092838, 0.016794740854363357, 0.03681218717247248, 0.009280203858257403, 0.09851435518690518, 0.05208325898274779, 0.052511197448308976, 0.09610130145613636, 0.021711814416838542, 0.07082234362938575, 0.04106780613905617, 0.12038410880735942, 0.08228874406112091, 0.05285662266292742, 0.07199125590601138, 0.034043533594480584, 0.07743846718221903, 0.018360950651445558, 0.138474096677133, 0.04591688879632524, 0.04466425208374858, 0.03966798839558448, 0.07027649613363401, 0.030428624711930752, 0.06607747716563088, 0.04137486019837005, 0.05371703899332455, 0.0697587128462536, 0.10253774893603154, 0.10801326190786702, 0.076966071102236, 0.03772704236741577, 0.12586511112749577, 0.05609913117119244, 0.06075164223355906, 0.0594660219337259, 0.058311257112239084, 0.07925664247678858, 0.0804589997444834, 0.022168817929923534, 0.07980979100934096, 0.07399893246058907, 0.05904216824897698, 0.02700180234387517, 0.03761264814862183, 0.09500706195831299, 0.042585760221949646, 0.11458296009472438, 0.04783208442053624, 0.04150317795574665, 0.009675474255345762, 0.05655920844791191, 0.041943828774882216, 0.011360162203865392, 0.0721305523599897, 0.05875442868896893, 0.04454904701560736, 0.16809919343463012, 0.0643290959830795, 0.043211461111371, 0.08481323359800236, 0.09480196796357632, 0.022895506882507886, 0.03659005516341754, 0.10228327794798783, 0.10639893888895001, 0.08845579278256212, 0.015445518074557185, 0.012588026451079972, 0.03648716550586479, 3.219436092036111, 60.154633794512065, 98.39731039319719, 71.84476252964565, 31.306029387882777, 29.590123108455114, 53.1227719443185, 82.34754140036446, 63.944473130362375, 39.46876267024449, 54.233097553253174, 54.081876959119526, 22.308989422661917, 3.8001934545380727, 0.6200862835560526, 0.30123271739908625, 0.12201165647378989, 0.22586240459765705, 0.08110368943640164, 0.1674363732870136, 0.9312937642846788, 0.981692197067397, 0.5080644403185163, 0.2546251783413546, 0.13165096566081047, 0.11856813196625028, 0.16214172382439884, 0.10494956773306642, 0.6717763213174683, 0.07582010009459086, 0.0581096372167979, 0.047852165664413145, 0.0919582684125219, 0.04786135981391583, 0.05679574914808784, 0.03455065031136785, 0.10493780872119324, 0.02928325081510203, 0.0740003709548286, 0.09858447499573231, 0.09284261667302676, 0.07177861660186734, 0.047079911388989, 0.10921880150479929, 0.0848506140921797, 0.04853634948709181, 0.07608852854796819, 0.0355638761206397, 0.10820881570024149, 0.28844686491148813, 0.15778343911681855, 0.40853054555399076, 0.19927310065499373, 1.3376451539141792, 0.9797769912651607, 0.9595852004630225, 0.34840637179357664, 0.377129003405571, 0.1861693545111588, 0.05607825264866863, 0.08155095936464411, 0.02805907016486994, 0.049435191255595, 0.0521519335119852, 0.037472914039556465, 0.315520846417972, 0.9329251796007156, 1.6484917082956858, 0.17476419865020684, 0.16514410557491438, 0.1938680535448449, 0.2232881241611072, 0.15447486165378774, 0.05126406704740865, 0.07601452751883439, 0.05787062325647899, 0.06430873314716987, 0.027899259900940315, 0.01921464439614543, 0.26919872633048464, 2.125655012471335, 0.5792226248553821, 0.194991137566311, 0.5882994692240442, 0.8859332097428185, 25.912544080189296, 56.02477741241455, 55.027478149959016, 38.89379923684256, 71.84344932011196, 76.22355202266148, 46.930099623543875, 30.2869371005467, 40.71761451448713, 68.27347878047398, 55.162742206028526, 5.001442321709224, 0.5573378620403153, 0.21742056044084684, 0.07420475927314588, 0.061180720637951574, 0.03602786175906658, 0.10431202301489455, 0.036336859821208885, 0.07522369495459966, 0.06108584787164416, 0.05416193404900176, 0.013496840139850974, 0.07091317232698202, 0.023112373459818106, 0.025619755432541882, 0.0626989020300763, 0.050078537448176315, 0.02840503990384085, 0.06488548112767083, 0.015241993192051138, 0.04407658986747265, 0.04069676622748375, 0.07609270832368306, 0.026653746109721915, 0.08433746519897665, 0.14278728594737394, 0.030573441048285792, 0.05946410167962313, 0.08612588673297848, 0.01269235460287226, 0.052298083169651885, 0.02376708511396178, 0.060088313184678555, 0.033634343051484654, 0.03583135123231581, 0.053108922338911464, 0.0581626511578049, 0.03297309031976121, 0.29185286643249647, 0.332061765981572, 0.23983086219855718, 0.1664860171398946, 0.3619768278939383, 0.1781393132571663, 0.2398710586130619, 0.29464226961135864, 0.30644017511180466, 0.15998304608677114, 0.16554142854043416, 0.12156397263918604, 0.17646004765161447, 0.21193949026720865, 0.17773487924465112, 0.15158035340053694, 0.1529892228011574, 0.2217638088124139, 0.14821613606597694, 0.246994427804436, 0.19523353741637298, 0.17854589144034044, 0.11179859843105078, 0.1958536777113165, 0.14377534150012902, 0.11402388795145921, 0.16044986460890087, 0.2610363300357546, 0.08843620347657374, 0.27579400528754505, 0.14657390490174294, 0.12884066360337393, 0.27622243229831966, 0.2635003892438752, 0.08000440163803951, 0.2113393396139145, 0.16606328982327664, 0.23495262967688696, 0.10285763748522316, 0.25269585901073044, 0.06682294966386897, 0.11162823185856853, 2.651278853416443, 57.80371427536011, 116.15739931379045, 103.09880896977016, 83.57232815878731, 55.02161039624895, 43.65047345842634, 91.10482856205532, 107.06543132237026, 53.61482947213309, 45.804081508091514, 67.93304484231132, 38.60999659129551, 5.063725105353764, 1.0974344206707818, 0.46594674033778055, 0.18124233532164777, 0.3395586551300117, 2.8530586659908295, 0.41628687935216085, 5.120199629238673, 6.306059105055673, 0.7282149642705917, 0.7781137238655771, 0.43801905321223394, 0.7206113008516175, 0.7916364925248283, 0.7166379626308168, 2.3921661972999573, 0.277322418987751, 0.10077934579125472, 0.2940340851034437, 0.20535563783986227, 0.14072512303079876, 0.20772554352879524, 0.16684770344623498, 0.28762201060141834, 0.22237147763371468, 0.173067250422069, 0.1658323707857302, 0.26431020721793175, 0.5163441960300718, 0.11336610253368105, 0.30079272815159386, 0.16011899736310753, 0.20201890117355756, 0.1731053569487163, 0.31102728896907395, 0.20228145351367338, 0.5794174458299364, 1.1465774008205958, 2.334039739200047, 1.1713482716253825, 2.3550849642072404, 1.2485333127634866, 1.8763267227581568, 0.9816089272499084, 0.5158510910613197, 0.24304320982524327, 0.12840223498642445, 0.4822878177676882, 0.13211303443780967, 0.3206155316105911, 0.194090300904853, 0.2815789505839348, 0.63837980479002, 4.821683304650443, 2.3391410197530473, 0.4174773826130799, 0.19783607205109938, 0.32871384705816, 0.27200739990387646, 0.2523055113852024, 0.19009056767182692, 0.16126995560313973, 0.33893782272934914, 0.1757617944053241, 0.2482630711581026, 0.18925383899893078, 0.4566059729882649, 3.9375228626387457, 0.7273385684405054, 0.4304160140454769, 0.6288878598383495, 0.4125989872430052, 23.05801044191633, 63.594124112810405, 58.164899008614675, 54.15755673817226, 95.24860913412911, 81.00312750680106, 47.414555822099956, 42.827501024518696, 64.92027814047677, 84.87132862636021, 67.5577448436192, 7.5313305003302435, 0.5678849560873849, 0.35661667266062325, 0.2796713172325066, 0.13258224140320504, 0.13310712895223073, 0.234104080923966, 0.11269921796130282, 0.13323207439056464, 0.17829476562993868, 0.10467619954475335, 0.13773206435143948, 0.23375528678297997, 0.13894981757870742, 0.17425346534167016, 0.17456589000565664, 0.12403666281274386, 0.20482324569353036, 0.13040604389139585, 0.25108023998992784, 0.22733236929135664, 0.23237666647349084, 0.24507107958197594, 0.14714471570083074, 0.25357458900128094, 0.2612863023366247, 0.24780343153647014, 0.1718219622437443, 0.2851257345506123, 0.18943028524518013, 0.113340521763478, 0.25885364572916714, 0.15613974231694425, 0.17737421074083873, 0.1701980379543134, 0.16095449110226973, 0.3274971523455211, 0.1511423997581005], [0.019347521908847348, 0.06773301440158061, 0.09858530959380524, 0.05133484842787896, 0.06333179878337042, 0.07896732871553727, 0.06347492896020412, 0.024742087349295616, 0.03407051893217223, 0.07047490655843701, 0.0848314929753542, 0.02290069089005036, 0.03321484216888036, 0.05363613387037601, 0.12293567189148494, 0.022748312280912484, 0.03505291211019669, 0.027488391680110778, 0.03189572938052671, 0.05457085996334042, 0.07669304896678243, 0.05959826162351029, 0.04927434452942439, 0.07533699673201356, 0.029434506448784044, 0.0815543316836868, 0.025308453744011264, 0.06986855409507241, 0.01639092091604003, 0.01795486101348485, 0.07549582820917879, 0.12245442771485873, 0.05919916768159185, 0.10805254908544676, 0.1358451127473797, 0.05910207610577345, 0.05434554223237293, 0.14265037115131105, 0.025641359987535646, 0.08618484464074884, 0.05812929437628814, 0.057567338459193707, 0.039916335605084896, 0.2698990287525313, 16.47061617033822, 69.39021410260881, 75.57686928340367, 64.15411417824882, 37.80512421471732, 23.33855438232422, 55.546053477696006, 84.8065436226981, 51.82966354915074, 28.786176579339163, 36.931662695748464, 48.57710756574358, 16.028236525399343, 2.6034077193055833, 0.5147051268390247, 0.2181475292891264, 0.32648559233972, 0.28029090112873484, 0.2981379734618323, 0.6242259442806244, 0.32225859058754786, 0.05610915652609297, 0.15497211925685406, 0.0806328064895102, 0.6041232315557343, 0.6427436534847532, 0.036540959762143235, 0.04066732459302459, 0.09405418166092464, 0.04720517913145678, 0.0740233665066106, 0.06647072213568858, 0.026777212341715182, 0.02967703522049955, 0.06878882846129791, 0.05573304117258106, 0.06414407305419445, 0.06350709152008806, 0.10105433567826237, 0.1407000036644084, 0.06181952064590795, 0.1278979749019657, 0.08112567397100584, 0.09174214143838201, 0.028826888517609665, 0.1111330980701106, 0.07668198884597846, 0.10323195132826056, 0.48199284502438133, 0.4881846127765519, 0.033921845124236176, 0.05016461300796696, 0.01840776447871966, 0.04452856543606945, 0.006063687906134874, 0.10144984016993217, 0.03820319074605193, 0.02840122314436095, 0.075626351205366, 0.11407332601291792, 0.004802076719767813, 0.05894460169864552, 0.19860329159668513, 0.14178572754774774, 0.14708898083439895, 1.1159274854830332, 0.10809953085013799, 0.06385021310831819, 0.1418078885014568, 0.0897718793047326, 0.03432940039783716, 0.09454310685396194, 0.07714158097015959, 0.04699562716164759, 0.09410714131913014, 0.15662232999290737, 0.3816447082374777, 1.3251684691224779, 0.23298628947564534, 0.09269054340464727, 0.3204959194575037, 4.571351434503283, 37.91189023426601, 32.695787225450786, 19.635369505201066, 43.89890282494681, 64.31657695770264, 45.47704717091152, 19.759342738560267, 25.252800464630127, 43.05698265348162, 34.70351089750017, 7.795902269227164, 1.185191037399428, 0.10853190693472113, 0.22258142993918487, 0.013535439452555562, 0.16151706448623113, 0.08043628239205905, 0.039430830228541575, 0.01617711453166391, 0.03805084606366498, 0.039418935509664674, 0.04889121312381966, 0.053614196833223104, 0.029168805706181695, 0.030147348197975328, 0.06393015810421535, 0.04831291129812598, 0.03391505977404969, 0.05959627351590565, 0.04281930858269334, 0.049188713410070965, 0.03545597887464932, 0.11563213808195931, 0.10217616440994398, 0.08385792414524726, 0.15950180191014493, 0.033624728210270405, 0.007295689096541277, 0.04036736461733069, 0.1288788922663246, 0.04229295200535229, 0.10014463056411062, 0.05374458072973149, 0.07744705743555512, 0.02362507112723376, 0.054959568926798444, 0.08913295716047287, 0.06273166170077664, 0.0504219847332154, 0.02519263799435326, 0.0411853691163872, 0.024327646641592895, 0.04541936995727675, 0.11509129138929503, 0.07005694934300014, 0.039771705865859985, 0.034162121159689765, 0.050949040201625655, 0.06435209832021169, 0.04306090097608311, 0.05647643396098699, 0.06213712253208671, 0.028986680121826272, 0.019725055400548235, 0.087832829781941, 0.00914078187530062, 0.06192857479410512, 0.06210368432636772, 0.0677010350461517, 0.05373940011486411, 0.08557672798633575, 0.029205103937004293, 0.07370549320642437, 0.054250197884227545, 0.07685985323041677, 0.03437504544854164, 0.037489490650062046, 0.05651685089937278, 0.05242343572899699, 0.01521858203757022, 0.11578543271337237, 0.13687755806105478, 0.09737028407731227, 0.06354821752756834, 0.0319578356907836, 0.060928264898913245, 0.03950595084045615, 0.14200957625039987, 0.04833280933754785, 0.16784732123570784, 0.032605348088379414, 0.030669860874435732, 0.07159321369337183, 1.0353631228208542, 34.063331672123496, 91.33110359736851, 81.48220579964774, 53.294885771615164, 37.55765717370169, 44.77010270527431, 82.21783937726701, 77.36902509416852, 38.01946224485125, 43.604796000889365, 58.76026930127825, 48.42301041739327, 21.09852463858468, 2.538434245756694, 0.7103317124502999, 0.2499420110668455, 0.34971941847886356, 0.1794218530080148, 0.29343976985130993, 0.3539983960134642, 0.10957605019211769, 0.02417114084320409, 0.14103547137762817, 0.05992351059934922, 0.6048451385327748, 0.5742121594292777, 0.09453742751585585, 0.04229382053017616, 0.01310267999568688, 0.07824311471943345, 0.036320439273757596, 0.11535418299692017, 0.028459977491625717, 0.07028689129011971, 0.14890588048313344, 0.051603375268833976, 0.1706994753330946, 0.07816911369029965, 0.07061019287045513, 0.1250460379357849, 0.0894453071856073, 0.11601394973695278, 0.19969174319079944, 0.10232839374137775, 0.05167157821623342, 0.07524769473820925, 0.08788513804652862, 0.23491577165467398, 0.7211073370916503, 0.16872841252812318, 0.11154267537806715, 0.12983011693826743, 0.07238184780414615, 0.046513209119439125, 0.01624392987495022, 0.07905424226607595, 0.0100362648954615, 0.03525421987952931, 0.040112893629286966, 0.020696164541212574, 0.04322932354573693, 0.029018035225038017, 0.07844951150140592, 0.05591720575466752, 0.1555955165198871, 4.0064789567674906, 0.4524741289871079, 0.1100446939734476, 0.12597746295588358, 0.10026251245290041, 0.15711574708776815, 0.11588770151138306, 0.04613713787070342, 0.0872405365641628, 0.20461728317396982, 0.0668938769293683, 0.5769715713603156, 2.1401554686682562, 0.28297779123697964, 0.29828811969075886, 0.3858701086470059, 8.569987177848816, 51.858533314296174, 48.61342232567923, 27.388570751462662, 47.03908559254238, 77.40308516366142, 65.49749973842076, 35.43582671029227, 31.28027241570609, 47.09697450910296, 58.328598567417686, 23.848484413964407, 2.606148566518511, 0.13970007374882698, 0.27340512775949066, 0.07978480734995433, 0.11872981329049383, 0.05605726895321693, 0.02526945833648954, 0.05014933579202209, 0.027970619732514024, 0.04432163600410734, 0.03426946200696485, 0.021889110528198735, 0.07912441635770456, 0.016810920521883026, 0.10515090264379978, 0.05165501178375312, 0.011509757123089262, 0.054262771138123105, 0.042995493592960496, 0.06842509976455144, 0.03722517072622265, 0.03674381119864328, 0.04033148029286947, 0.059029649277882915, 0.034629553756011386, 0.019568619151998843, 0.043051462553973706, 0.044004349636712244, 0.034191338877592764, 0.0872591555650745, 0.07033751000251089, 0.032821278287363906, 0.059509780657078536, 0.031759472763431926, 0.07596717255988292, 0.011598752079797643, 0.061130644753575325, 0.0330509589985013, 0.10423257334956101, 0.11987911590508052, 0.1663049975676196, 0.16658576178763593, 0.19851358926721982, 0.15363396677587712, 0.12765343088124478, 0.14600770814078196, 0.16316818445920944, 0.2608625707881791, 0.18777653255632945, 0.2226147460086005, 0.08056858993534531, 0.10147335819367852, 0.10735966305115394, 0.18113417683967523, 0.10782061903072254, 0.14792295465511934, 0.14407176630837576, 0.12991629088563578, 0.08051784230130059, 0.17874424079699175, 0.15909018899713243, 0.18973519174116, 0.21837360358663968, 0.12639896890946797, 0.19362975204629557, 0.10788316638874156, 0.12458261208874838, 0.26220645010471344, 0.12236769736877509, 0.28125124531132834, 0.23997842999441282, 0.16145934829754488, 0.2173021967921938, 0.20494589768350124, 0.2133283293140786, 0.15716941920774324, 0.2931600234338215, 0.1536002435854503, 0.18044469026582582, 0.13408818202359335, 0.16545492889625685, 0.15766640539680207, 0.47334396626268116, 29.718643937792095, 101.09635898045131, 101.82288346971784, 84.83956146240234, 57.98139360972813, 45.593589305877686, 82.58167484828404, 110.78384317670549, 70.90421962738037, 45.488292830330984, 59.670914105006624, 77.49480138506208, 31.056217329842703, 3.1152665274483815, 0.959815250975745, 0.37648059534175055, 0.722495511174202, 1.494561533842768, 0.999406520809446, 1.5623048416205814, 0.516545965203217, 0.1784125728798764, 0.7519382855721882, 0.23731705280286924, 1.2434409345899309, 1.4326966192041124, 0.2900104538670608, 0.11298444015639168, 0.11288080071764332, 0.19674892324422086, 0.13101308846047946, 0.11643039381929807, 0.1246938104076045, 0.16996126994490623, 0.23808078467845917, 0.1334027802305562, 0.4414130582341126, 0.08924029461507287, 0.1851574145257473, 0.3559457372341837, 0.16482281924358436, 0.2690151147544384, 0.2741528462086405, 0.1952363872634513, 0.1740414367190429, 0.17077737115323544, 0.15933100107525075, 0.40925739226596697, 1.2643227683646339, 0.672482811978885, 0.22055550079260552, 0.24915290198155812, 0.17126047451581272, 0.17735652811825275, 0.1140879959400211, 0.2815484436494963, 0.2153626044413873, 0.14637368278844015, 0.13746649931584085, 0.22488880184079918, 0.27709266703043667, 0.21026155459029333, 0.2518310525587627, 0.2329121120274067, 0.19730544409581594, 9.55259621143341, 0.2480451257101127, 0.3008328431418964, 0.23569299280643463, 0.14309603295155934, 0.22840088552662305, 0.18267447847340787, 0.22213730162807874, 0.28092565706798006, 0.2677711700754506, 0.2915994200323309, 0.6936037072113582, 3.4917082020214627, 0.33262427151203156, 0.3982613794505596, 0.8732610525829452, 5.464135459491184, 59.07862881251744, 54.67001417704991, 29.655905178615026, 62.90423747471401, 90.48542445046562, 65.24393912724086, 38.28413997377668, 49.09255620411464, 68.92405945914132, 76.81570529937744, 35.32791076387678, 3.49320792726108, 0.45802096277475357, 0.7153419607451984, 0.12769720996064798, 0.23466601648500987, 0.24410907977393695, 0.11076667558934007, 0.15012598144156591, 0.1169356174234833, 0.17425004552517617, 0.17640790902078152, 0.12088830103831631, 0.1527704766818455, 0.11643161518233162, 0.23127952963113785, 0.2007053116602557, 0.19522603281906672, 0.11113532366497175, 0.13158647769263812, 0.1771748707230602, 0.1648216928754534, 0.22004820087126323, 0.16230379869895323, 0.15181292806352886, 0.18576342772160256, 0.16768458139683518, 0.12325515331966536, 0.11955014855733939, 0.17970640345343522, 0.17762581152575357, 0.12309610471129417, 0.14400038442441396, 0.15430547217173235, 0.1778838855347463, 0.1775684617459774, 0.1919440267873662, 0.13211870699056558, 0.11345741977649075, 0.17521881711270126], [0.04160596244037151, 0.12640761344560555, 0.03280949213408998, 0.024743037298321724, 0.15697701381785528, 0.08920570289982216, 0.009162337236505533, 0.02435117993237717, 0.022921455757958547, 0.0036341521356787, 0.06477805546351842, 0.07027386341776166, 0.04126366866486413, 0.04163653722831181, 0.048574805459273715, 0.09087802030678306, 0.026038698220093335, 0.032024311766560586, 0.06820074894598552, 0.014297860907390714, 0.02948201068543962, 0.04554208640807441, 0.058579678780266216, 0.027458758359508853, 0.029090723288910728, 0.026430377470595495, 0.08918464117284332, 0.02199539286084473, 0.03305756453690784, 0.044252377934753895, 0.04972738539800048, 0.0478811051829585, 0.1392037525240864, 0.07810175551899842, 0.08561476665948119, 0.03899971961176821, 0.10033700881259781, 0.030702484838132347, 0.08446015111569848, 0.0477092085140092, 0.17066200662936482, 0.12688011809119157, 0.07862733517374311, 0.035931950834180625, 0.11001890964273896, 5.305897184780665, 39.29807669775826, 76.71469238826207, 62.255192347935264, 39.10523639406477, 23.56577089854649, 35.02823148454939, 86.27726187024797, 84.44572366986955, 53.58335760661534, 36.45090988704136, 38.175150530678884, 37.08102117265974, 17.464206831795828, 0.5192883866173881, 0.33136648471866337, 0.4617465542895453, 0.15433984675577708, 0.4388948247901031, 0.13459464056151255, 0.15188836758690222, 0.28506111087543623, 0.1830013966453927, 0.050244303553232124, 0.2706121690571308, 0.12394614624125616, 0.11429933245692935, 0.07241788479898657, 0.0037886579521000385, 0.04282130686832326, 0.04692137846723199, 0.016808023177353398, 0.06946469005197287, 0.019571811659261584, 0.042615948244929314, 0.047450761310756207, 0.06289606395044497, 0.08795585496617214, 0.09092054409640175, 0.052762906798826795, 0.07452145870774984, 0.0344745661797268, 0.026563933518316065, 0.07094186078757048, 0.03989262759153332, 0.06799774483910628, 0.609025565641267, 0.10909726909760918, 0.10098045000008174, 0.051063526022647104, 0.054250832314469984, 0.06634883010493857, 0.037888170685619116, 0.11023895176393644, 0.03491685226825731, 0.025546025817415545, 0.08859194761940412, 0.11280037396188293, 0.13856882016573632, 0.0839682471539293, 0.0673023753666452, 0.04787033683221255, 0.10489836548055921, 0.0787843753184591, 0.8008766738431794, 1.046439202768462, 0.6127982203449521, 0.08525562485946075, 0.18516722614211695, 0.23252019020063536, 0.05299254340518798, 0.08478618719215904, 0.09835538800273623, 0.2536378284650189, 1.613876760005951, 1.1282991873366492, 0.022704579002623047, 0.2627661329294954, 1.084092142326491, 17.59925549370902, 45.29529619216919, 50.635893549237935, 40.744097573416575, 72.38215010506767, 69.82898589542934, 35.28909812654768, 19.178318738937378, 28.420524154390606, 40.40596348898751, 25.88957507269723, 2.658143239361899, 0.40509205577628954, 0.06646156191293683, 0.12231840858502047, 0.18013407050498895, 0.014339102265824164, 0.039305440349770446, 0.04055930860340595, 0.08257003075310163, 0.03805298005629863, 0.0543610196161483, 0.012954303046821483, 0.018583969845037376, 0.015293164910482509, 0.07284148742577859, 0.01603367392505918, 0.04831713178594198, 0.008876219375192054, 0.05367526159222637, 0.015590841615838664, 0.06139800112162318, 0.030729955328362327, 0.023382050417629734, 0.078293638436922, 0.007771856983059219, 0.042277006432414055, 0.061451381471540244, 0.1331104537738221, 0.0444505780137011, 0.06968564819544554, 0.01728483143129519, 0.06944910410259451, 0.08288048766553402, 0.12881851622036525, 0.01496272174907582, 0.1024108628875443, 0.01962476622845445, 0.048838521486946514, 0.0069250062640224186, 0.07815149892121553, 0.004141939329981271, 0.09390313298042331, 0.06349759202982698, 0.0795818507405264, 0.026129711818482195, 0.07061697143529143, 0.07392686525625841, 0.010885660968987005, 0.019276984800983752, 0.018434315553999374, 0.01897248881869018, 0.027563435956835747, 0.047896806483290026, 0.0809481352833765, 0.03842837277001568, 0.03089606748627765, 0.07181831768580846, 0.02907234856060573, 0.07692898237811667, 0.013314721340845739, 0.049630212397979837, 0.10722957431737866, 0.04301102525953736, 0.030623591571514095, 0.05898715941501515, 0.01468607793296022, 0.05996811070612498, 0.10639818571507931, 0.05666988768747874, 0.047009279286222797, 0.05834195403648274, 0.02581488005151706, 0.05430406677935805, 0.050168989558837244, 0.03007033108068364, 0.08531714084425143, 0.022763433433803063, 0.04099770329360451, 0.02913908926503999, 0.07930012978613377, 0.06013963757348912, 0.12508364234651836, 0.05833607792322125, 0.10534294841012784, 0.014194173123022276, 0.24816810339689255, 15.580246210098267, 67.17961692810059, 83.05326298304966, 54.1307749067034, 43.48102426528931, 39.95814514160156, 70.92204175676618, 92.2228284563337, 55.2486115183149, 45.41827583312988, 60.52308981759207, 57.44055625370571, 45.57914400100708, 13.10244824205126, 0.6047177910804749, 0.5320920710052762, 0.028654384559818676, 0.1114916427593146, 0.12482472695410252, 0.4522121601871082, 0.025661707556407367, 0.2048467637172767, 0.10100128102515425, 0.20017103318657192, 0.24425773322582245, 0.13966253719159535, 0.10068445266889674, 0.007115796740565981, 0.03230844491294452, 0.07289390425596919, 0.13452214588012013, 0.06678947753139905, 0.06553205714694091, 0.02589231955685786, 0.015830450990636433, 0.005174120439083448, 0.09848242332892758, 0.05879142241818564, 0.08128259197941848, 0.015598912789885486, 0.046555525955877135, 0.016994861187413335, 0.025013145125870193, 0.07445369341543742, 0.06215426911200796, 0.08838646007435662, 0.7370384708046913, 0.21826682931610517, 0.06861659591751439, 0.03228389212329473, 0.052446733228862286, 0.14261773361691407, 0.04481852041291339, 0.09402993081935815, 0.054525985049882104, 0.06010387199265616, 0.031776269897818565, 0.03824460513091513, 0.07279461422669035, 0.025250654434785247, 0.0454147287777492, 0.05317746116114514, 0.10636408254504204, 0.08735652534025055, 0.8305131835596902, 7.296703730310712, 1.2411576913935798, 0.45882461965084076, 0.24709352105855942, 0.13827538091157163, 0.21636188296335085, 0.04972359238724623, 0.05516901233100465, 0.22475931021784032, 1.5228915108101708, 1.1999464056321552, 0.11694726108440331, 0.514065186892237, 2.2380062980311255, 34.78051430838448, 63.961690766470774, 61.23134749276297, 36.481294359479634, 65.55131353650773, 85.81346266610282, 53.83487892150879, 32.72255168642317, 31.327197074890137, 51.45315456390381, 54.57469531467983, 15.420640877314977, 0.9520038472754615, 0.09385110970054354, 0.20178662506597383, 0.12323569293533053, 0.054501422082207034, 0.019551414896601012, 0.046958806458860636, 0.07757420132734946, 0.03842014892558966, 0.006973299297637173, 0.008842748090890902, 0.023380574603964175, 0.004920002289249429, 0.04568510462663003, 0.030381076370498965, 0.019478117847549062, 0.0582566282578877, 0.07424783267612968, 0.04560385684349707, 0.08444545404719454, 0.04216665288965617, 0.02146304990830166, 0.020677213058141724, 0.027194915106520057, 0.08653580330844436, 0.05387321739856686, 0.06701884950910296, 0.06627636935029711, 0.1306438704154321, 0.06140266265720129, 0.12888442911207676, 0.07294007177863802, 0.15954878367483616, 0.019337377810318555, 0.06018148282808917, 0.0727738578404699, 0.02401515412410455, 0.04664439707994461, 0.04497708726142134, 0.021004236403054426, 0.13670079968869686, 0.22860555882964814, 0.15900056809186935, 0.11912374358092036, 0.2208840474486351, 0.286964510168348, 0.1298835040735347, 0.11101664110485997, 0.12627145860876354, 0.20984303419079098, 0.13791870219366892, 0.12050547158079487, 0.1544228315885578, 0.12196721243006842, 0.10868211423179933, 0.18660866522363254, 0.10936963305409465, 0.23047421712960514, 0.08476015858884368, 0.15144641058785574, 0.2833479999431542, 0.16962270811200142, 0.13480050808617047, 0.1522700706762927, 0.08592945763042995, 0.24109293733324322, 0.17113357489662512, 0.1472766636205571, 0.13872785520340714, 0.1526460333594254, 0.1549173750515495, 0.1304688219513212, 0.16989455638187273, 0.16450800613633224, 0.24252377769776753, 0.10290412391935076, 0.23764608800411224, 0.08140916590179716, 0.1782041269221476, 0.17220519882227692, 0.26263883975999697, 0.18789037716175827, 0.2065246043992894, 0.07374338260186569, 0.21028329485229083, 10.798237119402204, 67.18269498007638, 106.41865130833217, 85.12584808894566, 60.622754778180806, 45.86733095986502, 58.73132310594831, 107.43002414703369, 106.92808628082275, 78.22657871246338, 55.12763295854841, 59.531415121895925, 58.36534758976528, 23.250697885240825, 0.8803252535206931, 1.3457707464694977, 0.8332907802292279, 0.3061361371406487, 1.5963579629148756, 0.9216652980872563, 0.6110278953398977, 0.6427118980458805, 0.5817678911345345, 0.335086322256497, 0.7403678521513939, 0.3130880541035107, 0.190732923203281, 0.1610361731478146, 0.08945848433566944, 0.12938828207552433, 0.3051690618906702, 0.17401865151311668, 0.15054523465888842, 0.10245553084782191, 0.15856728277036122, 0.21196707950106689, 0.2255852230425392, 0.2750493266752788, 0.26042735842721804, 0.178422818758658, 0.20312192769987242, 0.07025174317615372, 0.08946996514818498, 0.277392498084477, 0.18663776080523217, 0.17379417855824741, 1.2073207242148263, 0.3413096283163343, 0.2268511793975319, 0.08250499995691435, 0.10445648990571499, 0.29662693025810377, 0.2091642820409366, 0.15004257591707365, 0.11067993845790625, 0.09954203718474933, 0.33471687350954327, 0.19335280119308404, 0.16129917332104274, 0.2128324694931507, 0.19063049155686582, 0.1400125798370157, 0.23395436895745142, 0.1503139492124319, 2.830617721591677, 9.432725020817347, 0.947591741170202, 0.760586675788675, 0.32489228355033056, 0.37418033448713167, 0.22819222243768827, 0.1742119254278285, 0.21137216713811668, 0.6278965473175049, 2.4190917696271623, 2.144961885043553, 0.178262575928654, 1.0608167627028056, 1.5997170912367957, 28.296472753797257, 65.101181438991, 64.66972609928676, 50.11622735432216, 89.81493023463658, 90.39065102168492, 53.436653341565815, 38.854778153555735, 48.7514066014971, 70.91240460532052, 74.71366677965436, 24.122198275157384, 0.7910316735506058, 0.2001212015748024, 0.363577383437327, 0.37750901015741484, 0.1220458953508309, 0.10453233655009951, 0.19004326021032675, 0.16924526622252806, 0.18843640786196503, 0.12459097164017813, 0.09802785236388445, 0.15157938988081046, 0.14677879533597402, 0.2171137947589159, 0.10560316658977952, 0.21222026805792535, 0.16476749149816378, 0.26428179017135073, 0.16619400280926908, 0.2180728225835732, 0.08298859865005527, 0.1595746630004474, 0.16219813722584928, 0.13304771642599786, 0.22926989889570645, 0.17459219002297946, 0.19867052084633283, 0.14144525224609034, 0.235383255141122, 0.16430306141929968, 0.16665968139256748, 0.16235004764582428, 0.27052936064345495, 0.15316326703344071, 0.17750999916877064, 0.19054248556494713, 0.14168488367327622, 0.20064836900149072, 0.12893906475177833, 0.2437165065535477], [0.05370651491518531, 0.03737704043409654, 0.04493450918900115, 0.004458032323912318, 0.055700169543602636, 0.11759507203740732, 0.016535362361797264, 0.05254705123869436, 0.058524452815098424, 0.02536399183528764, 0.09771189253245081, 0.06079591664352587, 0.038313788561416526, 0.005941175439927194, 0.055921070011598725, 0.05811602223132338, 0.020258244825527072, 0.052727789218936644, 0.045112214117710076, 0.04638031464336174, 0.10954994694995028, 0.08063564955123834, 0.06034855850573097, 0.03520930425396987, 0.06831605918705463, 0.11183886948440756, 0.08018170962376253, 0.11444928869605064, 0.15643445721694402, 0.028847142787916318, 0.0288877666794828, 0.024526922198544656, 0.03136766628761377, 0.16205335142357008, 0.024787335457014184, 0.024299746977963617, 0.08433983328619174, 0.05550869035401514, 0.07293523382395506, 0.0399041830429009, 0.05928868002125195, 0.07502746262720653, 0.045962924004665444, 0.047131435945630074, 0.08795146484460149, 0.2292776070535183, 0.4669977096574647, 23.78455056462969, 65.35517978668213, 70.87778867994035, 50.65347249167306, 26.112346478870936, 23.405264036996023, 53.344228403908865, 83.14891188485282, 79.87029320853097, 48.22977059228079, 38.16019800731114, 39.38887228284563, 41.2560338973999, 7.212663965565818, 0.1140597824539457, 0.1351260556174176, 0.5399288790566581, 0.32521504908800125, 0.157267942492451, 0.16642520683152334, 0.21326671833438532, 0.14429816630269798, 0.04486665229446121, 0.04920038760506681, 0.06767193946455206, 0.05788731521793774, 0.07451484299131803, 0.12175302606608186, 0.0781831932919366, 0.07752890911485467, 0.045283408502915075, 0.10073047091386148, 0.05919401760080031, 0.01754815730133227, 0.06935400063438074, 0.15217833274177142, 0.21430092783910887, 0.07691334893128701, 0.05696258055312293, 0.09190831466444901, 0.0487115133021559, 0.03282356834305184, 0.05448620254173875, 0.0501308558907892, 0.5064275424395288, 0.113755900545844, 0.04050046265391367, 0.023886919487267733, 0.08319802169821092, 0.06416901600147996, 0.016348230885341763, 0.06356966601950781, 0.09522421352033104, 0.01169005235923188, 0.06393500962959868, 0.04213437497881906, 0.009427593538670667, 0.024543620945353593, 0.20464017694549902, 0.07338785739349467, 0.1026848688987749, 0.0611663492662566, 0.13966213007058415, 1.920059553214482, 4.993582172053201, 6.9810305663517545, 0.36715337155120714, 0.1285022103360721, 0.16084426987384046, 0.15874097416443483, 0.7071035142455782, 1.181358128786087, 0.3587680086493492, 0.12830698224050657, 0.15432250340070042, 9.055043527058192, 34.7022636958531, 41.22883169991629, 43.667722361428396, 60.08654144832066, 82.57112748282296, 64.14247594560895, 32.35326187951224, 29.873845849718364, 39.39847469329834, 46.09102821350098, 12.772708450044904, 0.31655547661440714, 0.13081072217651776, 0.1738219577819109, 0.15669870589460644, 0.09233906905033759, 0.03455602770139064, 0.07252004503139428, 0.01829460688999721, 0.06255606362330061, 0.05646911256813577, 0.07966049973453794, 0.05027643218636513, 0.07254857742892844, 0.027488393376448324, 0.04867553737546716, 0.03584038931876421, 0.03534697222390345, 0.1307238018406289, 0.021238483654867326, 0.0025322328936973853, 0.03380762393187199, 0.03207554455314364, 0.005337966714120869, 0.025802883552387357, 0.0790505985330258, 0.04843381945309894, 0.09621659134115491, 0.017552666166531186, 0.014500142374475087, 0.057928237664912424, 0.19595829424049171, 0.054811404020126374, 0.012119140941649675, 0.06032246883426394, 0.06146862983171429, 0.08358069509267807, 0.042297474441251585, 0.00946214878266411, 0.036263863023902686, 0.0637448773320232, 0.028952390354658877, 0.031527698771761994, 0.12836142789040292, 0.028159649410684193, 0.029094295775783912, 0.035175978006528955, 0.05507261286090527, 0.012424094086912061, 0.011360636330209672, 0.09226913244596549, 0.06451162868844611, 0.030937040823378732, 0.04471644499738302, 0.023302599055958644, 0.053669704390423636, 0.06025130408150809, 0.0585000662665282, 0.05289716852296676, 0.005064643902837166, 0.046554908489010165, 0.09207963118595736, 0.011773585957208914, 0.055416687790836604, 0.029215943533927202, 0.02044472999737731, 0.07445931168539183, 0.025662727055272887, 0.0538519080063062, 0.044029329903423786, 0.08054522118930306, 0.083686756901443, 0.031147803978196213, 0.021133994351008108, 0.03520124325794833, 0.020451242237218788, 0.17884059276963982, 0.0549023582467011, 0.0051066418278164095, 0.08274948290948357, 0.0544152413494885, 0.10756652802228928, 0.09693402677242245, 0.0441415765588837, 0.10755396833909409, 0.023139686190656254, 0.05008157389238477, 0.08220237333859716, 0.39096066834671156, 3.7226511240005493, 50.791626998356406, 85.95184298924038, 65.73305756705147, 52.90809692655291, 36.83404745374407, 57.28518063681466, 84.81918934413365, 95.0739244733538, 62.49232741764614, 44.82335369927542, 47.20183324813843, 58.555429458618164, 37.30423205239432, 3.2108359592301503, 0.16325042290346964, 0.34712969458528925, 0.343566327222756, 0.40908045747450417, 0.163829077567373, 0.25407268798777033, 0.6011282865490232, 0.05333114595019391, 0.20592775142618588, 0.058627196587622166, 0.028564152973038808, 0.07147276015686137, 0.1045831927497472, 0.00531509965990803, 0.06615289633295365, 0.09772636568439858, 0.022106769295143228, 0.1088150663833533, 0.01941579270974866, 0.04521575516888073, 0.04437432764098048, 0.03094001280676041, 0.0400807480327785, 0.19555680506995746, 0.030552138441375325, 0.18910640691007885, 0.016228002961724997, 0.05435856331938079, 0.07382529534931694, 0.07030231439109359, 1.0336765561785017, 0.22576530623648847, 0.030469031472291266, 0.037964719613747935, 0.08361973121230092, 0.04888178148706045, 0.035695844396416626, 0.016017738530146222, 0.04513394759435739, 0.008537489604870123, 0.04199267990354981, 0.038111093187970776, 0.1020702315228326, 0.024765337351709604, 0.03225906113428729, 0.06704524452132837, 0.027674274652131965, 0.06624764017760754, 0.16471808057810577, 4.737215791429792, 7.707669700895037, 8.772341302462987, 1.3542551483426775, 0.677115469106606, 0.49657472542354036, 0.054356836447758336, 0.7832625561526844, 1.5909366309642792, 0.6715370970112937, 0.29939565168959753, 0.24531239377600805, 13.437179446220398, 58.0575840813773, 47.85534954071045, 36.49898794719151, 57.672553130558555, 87.15809890202114, 84.95547131129673, 50.17198664801461, 32.734631129673545, 38.62114150183541, 60.51287596566336, 42.550552776881624, 7.4107149839401245, 1.0028107038566043, 0.122693964147142, 0.13004215913159506, 0.06371730166886534, 0.09055966524673359, 0.07827392699463026, 0.020041310394714986, 0.03819062088483146, 0.08633740645434175, 0.06292013837290661, 0.01668680628894695, 0.06095647159963846, 0.03465883593474116, 0.03802679878260408, 0.006978598656132817, 0.019791439874097705, 0.03274086510230388, 0.04494488738211138, 0.03422346072537558, 0.034552906440304856, 0.0262312935997865, 0.05451649234497121, 0.027240012240196978, 0.0735171183145472, 0.02786674959185932, 0.0032659202988725156, 0.041028929475162706, 0.019549345364794135, 0.039946096151002815, 0.10667539441159793, 0.04523159556889108, 0.014828962140849658, 0.05783265922218561, 0.08965194824018649, 0.044791548645922115, 0.03930952173790761, 0.05682134348899126, 0.10846889817288943, 0.05247304003153529, 0.040029718806701045, 0.0635537136612194, 0.17639212629624776, 0.12412703010652747, 0.1519005676465375, 0.1569794294025217, 0.10212203088615622, 0.2124345222754138, 0.07578590192965098, 0.15814792098743574, 0.20480210254234926, 0.10074656576450382, 0.18253081903925963, 0.15971938094922475, 0.12590092420578003, 0.14380981107907637, 0.0890066275107009, 0.15635722636112145, 0.09775260463356972, 0.16926735932273523, 0.27380432348166195, 0.12468076896454607, 0.12811632747096674, 0.19363546531115258, 0.21751695312559605, 0.13635490967759065, 0.1593632586300373, 0.15396795528275625, 0.12560322375169822, 0.22310656176081725, 0.2319143669945853, 0.10593382348971707, 0.1583746195371662, 0.19028655572661332, 0.17367684628282273, 0.23737024994833128, 0.1919493872140135, 0.0852712175941893, 0.21249268629721232, 0.11842391613338675, 0.1548371043588434, 0.20879031425075872, 0.23328012228012085, 0.13998241217008658, 0.07402752592627491, 0.10466663898634058, 0.23006150498986244, 0.6057007983326912, 1.6452895658356803, 42.453371797289165, 101.36255141666958, 94.16355759756905, 74.26732839856828, 50.705035073416575, 48.106360163007466, 75.29629407610211, 109.09545176369804, 100.71346460069928, 64.3705575125558, 47.344893183027, 53.48871271950858, 60.97088732038225, 11.539563877241951, 0.4405920851443495, 0.43235445288675173, 0.9769630794014249, 1.2087075412273407, 0.9691411448376519, 0.3626610083239419, 2.105083784886769, 0.5261772541063172, 0.6572569747056279, 0.15889648082000868, 0.11497602186032704, 0.12345988090549197, 0.2307092888014657, 0.1907927157091243, 0.11359177649553333, 0.10855371505022049, 0.188947697569217, 0.2776524584208216, 0.11613833877657141, 0.0904987667288099, 0.12410710831837994, 0.26664374342986513, 0.19931823680443422, 0.3092701275433813, 0.15231427044740745, 0.30041858394231113, 0.1721825628940548, 0.1470612423228366, 0.14638751133212022, 0.23762795754841395, 2.136005005666188, 0.19085454382002354, 0.08851838763803244, 0.09886250471962349, 0.17256634230060236, 0.17675715099487985, 0.15111536692295754, 0.1314140890858003, 0.14075028310929025, 0.12081386574677058, 0.13869145858500684, 0.1327493374368974, 0.13451147930962698, 0.1650631292057889, 0.24423716004405702, 0.16970019681113108, 0.15926231976066316, 0.23558081739715167, 0.4586997149246079, 8.888701915740967, 11.6477256161826, 7.943321330206735, 0.767797874552863, 0.35511575319937294, 0.6926860021693366, 0.72545468381473, 2.049793928861618, 2.300211782966341, 1.065430800829615, 1.0144686954362052, 0.3739183928285326, 14.424625294549124, 53.33641168049404, 52.558449677058626, 50.22724567140852, 75.8294779913766, 99.28617259434291, 83.53534289768764, 56.09533289500645, 47.40496383394514, 57.719641072409495, 81.03110790252686, 54.52640186037336, 8.344109058380127, 0.7220607602170536, 0.25604475502456936, 0.19778353986995562, 0.22995899191924504, 0.29631871251123293, 0.2493101049746786, 0.10352336854806968, 0.1513119928006615, 0.11899885242538792, 0.239227400294372, 0.1147253303123372, 0.1962713702980961, 0.12543486564287118, 0.10305003608976092, 0.11700026824006013, 0.14404797687062196, 0.16935757733881474, 0.10386992352349417, 0.1734520612018449, 0.07973440576876913, 0.16022388530629023, 0.11295248794236354, 0.12280422608767237, 0.19578247224645956, 0.11258641151445252, 0.18735210890216486, 0.08164544536599092, 0.11828128807246685, 0.16395151242613792, 0.2390523382595607, 0.14272471144795418, 0.06284717550235135, 0.1334388375814472, 0.21148996081735405, 0.10955606733581849, 0.08478320163807698, 0.14045189054948942, 0.15906318330339023, 0.11054016702941485, 0.12365861024175372, 0.1978031631026949], [0.0406239967394088, 0.0008365625378376405, 0.06751707063189574, 0.023584876409066573, 0.07361313780503613, 0.030278973813567842, 0.0358040978732918, 0.0726315826177597, 0.04855496170265334, 0.022340621300307766, 0.0350447221925216, 0.02583720554996814, 0.044377554074994156, 0.05461234559438058, 0.0200407760483878, 0.025500160242830004, 0.022834840762828077, 0.15104509783642633, 0.06235392804124525, 0.04058179525392396, 0.003111641579640231, 0.016198719086657678, 0.09965431437428508, 0.0905591631308198, 0.12431019384946142, 0.04687204897137625, 0.022826357378757427, 0.021581832552328706, 0.07910217397979327, 0.029018951247313192, 0.017957670148462057, 0.019113227159583142, 0.0544170462526381, 0.024100929432149445, 0.06791982866291489, 0.033745110500603914, 0.03374555494104113, 0.025322821723031144, 0.05431748820202691, 0.05511599160464747, 0.03564683041934456, 0.06020933669060469, 0.09785891750029155, 0.06064719533813851, 0.13785367139748164, 0.3072183190711907, 0.07361049151846341, 0.5219284849507468, 7.3014371906008035, 58.12504414149693, 69.79917812347412, 60.475953238351, 41.121971879686626, 23.861013753073557, 28.20077521460397, 53.36013977868216, 98.1697221483503, 90.84611238752092, 56.298578126089915, 43.29271766117641, 62.89134161812918, 28.508929559162684, 2.1705075885568346, 0.4024801573583058, 0.09267372930688517, 0.5605852763567651, 0.3529322275093624, 0.07563667850834982, 0.05282607840906296, 0.14318513817020825, 0.13134744337626866, 0.012528699589893222, 0.04672786027991346, 0.04621252650395036, 0.04721299246219652, 0.127424791721361, 0.027623689866491725, 0.05427901865914464, 0.05490922502108982, 0.05196784356875079, 0.010264786159885781, 0.06113403064331838, 0.02924039793599929, 0.06213039146470172, 0.0459293568772929, 0.14144867206258432, 0.08103141188621521, 0.04588951330099787, 0.04542629101446696, 0.05526267730497888, 0.01651946089363524, 0.7280845226986068, 0.09115659285868917, 0.17742744859840187, 0.08045887082282986, 0.13119797568236077, 0.07545874627040965, 0.059444810929042954, 0.06721123454294034, 0.03739700971969536, 0.03114271835823144, 0.13637918766055787, 0.07501201917018209, 0.12251385381179196, 0.010158146748186221, 0.10038673185876437, 0.033336778304406574, 0.033804808011544604, 0.025455409162012593, 0.040782583943967304, 0.7793658109647887, 1.948054496731077, 6.871085745947702, 6.893476315907069, 5.675442772252219, 1.8913109472819736, 1.012972769992692, 0.6819286165492875, 0.20008370572967188, 0.10477869904467038, 4.252013964312417, 24.472627196993145, 54.76966176714216, 53.55366447993687, 68.78761073521206, 79.51688698359898, 62.90528665270124, 43.49658128193447, 31.498265198298864, 44.168906348092214, 57.63840273448399, 45.06457083565848, 12.176950795309883, 0.6972035254750932, 0.01912118128633925, 0.218306374336992, 0.10898581972079617, 0.029283640972737755, 0.05542199732735753, 0.041951716744474, 0.0513260919334633, 0.06479379747595106, 0.04439348268455692, 0.0495871559583715, 0.025254208261945417, 0.024924179006900107, 0.06705950054207019, 0.02693114140337067, 0.02422955592295953, 0.00469509040703997, 0.0322010192487921, 0.014131814906639712, 0.026964610143165504, 0.020086729832525765, 0.033597335751567564, 0.05851490582738604, 0.026480078464373946, 0.033241878396698406, 0.09230529836245946, 0.010736640260022665, 0.005657603781271193, 0.019734785592715656, 0.023107694960864525, 0.06017795444599219, 0.042189176859600205, 0.06127308282469, 0.024686900399891392, 0.02539266672517572, 0.017068639996328523, 0.07315993069538049, 0.040859363574002466, 0.06898117278303419, 0.08582258157964263, 0.11105019466153213, 0.05852610844054392, 0.04053790760891778, 0.10748904610850982, 0.005657910394282746, 0.032007029479635615, 0.04753669098551784, 0.015256893821060658, 0.0678973284416965, 0.06180446395384414, 0.03706489057679262, 0.060654835642448494, 0.05609823889764292, 0.025946062923009907, 0.027612880803644657, 0.09174752900643007, 0.007028627043057765, 0.10346358282757656, 0.011653744798552777, 0.039268097175019126, 0.03483378261859928, 0.0982215062582067, 0.07532080688646861, 0.050214200347129784, 0.040737763313310485, 0.028309157816693187, 0.1425725838967732, 0.046727164781519344, 0.04718788327383144, 0.06942087704581873, 0.02416970574163965, 0.013494472900804664, 0.029442106040992906, 0.049870471470057964, 0.12154979125729629, 0.010023686552553304, 0.025192877177947333, 0.03548582084476948, 0.10225282529635088, 0.11135018177862678, 0.08388022759131022, 0.0440846474708191, 0.038588469714990685, 0.07285330750580345, 0.04767845730696406, 0.05364712953035321, 0.046045176019626, 0.05296806186171515, 0.1605053280613252, 0.04030954325571656, 1.366843655705452, 25.46110224723816, 81.72139058794293, 76.24586268833706, 54.577561446598594, 41.36344262531826, 46.12602628980364, 58.7585391998291, 86.41403715951103, 88.00794001988002, 61.508698735918315, 42.56253147125244, 61.55673163277762, 61.99573271615164, 15.87226162637983, 1.3685026466846466, 0.30909541834677967, 0.40545898037297384, 0.2295923658779689, 0.2591882992003645, 0.05192936384784324, 0.07364894409797021, 0.03833303859989558, 0.07147463969886303, 0.10119477207107203, 0.042163263607238016, 0.03372235243607845, 0.07347388206315891, 0.022719907108694315, 0.025560683870155896, 0.056995387721274576, 0.06138170271047524, 0.021588560227038603, 0.01770538404317839, 0.09189313583608184, 0.054914615981812985, 0.05648373160511255, 0.03365507908165455, 0.18148432805069856, 0.10272636810051543, 0.04783870013696807, 0.0781814358862383, 0.07715150115213223, 0.03511740347104413, 1.090459297810282, 0.361594948385443, 0.1493862425642354, 0.09696762782654592, 0.15621670175875935, 0.02557048191582518, 0.06070627538221223, 0.14983602985739708, 0.057416981884411404, 0.008876557794532605, 0.08823979473007576, 0.07347040796386343, 0.09494584452893053, 0.04013678484729358, 0.0762508273390787, 0.03698112542874046, 0.05919036029704979, 0.054674092281077585, 0.03991049002589924, 2.7457889020442963, 2.176569240433829, 6.107208175318582, 7.5310821022306165, 6.336424469947815, 1.1013356170483997, 0.5441389445747647, 0.37788643847618786, 0.14595214969345502, 0.23805505463055202, 7.611569166183472, 38.6290659223284, 66.71940299442836, 46.627780028751914, 51.60431262425014, 88.21410696847099, 85.75705024174282, 66.28250026702881, 40.931747572762625, 47.46310288565499, 62.46090766361782, 64.0964719227382, 33.347337177821565, 3.120816183941705, 0.1679005455225706, 0.15652574731835298, 0.09549880985702787, 0.060213489324918816, 0.11688506656459399, 0.16114007042987005, 0.0718178427112954, 0.06584948261401483, 0.04189817015347736, 0.05011704770315971, 0.03125929745978542, 0.036393358039536645, 0.105073882133833, 0.04601782088034919, 0.032256659120321274, 0.01554945097970111, 0.08570046563233648, 0.07143496575632266, 0.009136124580566372, 0.029629992387656654, 0.033045113419315646, 0.016524049486698847, 0.014548679680696555, 0.03820856813607471, 0.05764167197048664, 0.010542860836721957, 0.09513898273663861, 0.039214201138487885, 0.03854461260406034, 0.04353684579421367, 0.05434066017291375, 0.053297270089387894, 0.026187339797616005, 0.050439894665032625, 0.042546615536723814, 0.04193449552570071, 0.02445689059926995, 0.03850638394110969, 0.14644777881247656, 0.06151209678500891, 0.10100498582635607, 0.06677070246743304, 0.25203605155859676, 0.1379382304315056, 0.17552045306989125, 0.4252552395420415, 0.2273613020245518, 0.1516811701336077, 0.12197283070002284, 0.18738428503274918, 0.10991668834217957, 0.12839810949351105, 0.14951297933501856, 0.11723449852849756, 0.23370122111269406, 0.13877448412988866, 0.19735868195337908, 0.15043590909668378, 0.17647068708070687, 0.19372037718338625, 0.16582848956542356, 0.17869010727320397, 0.229657098118748, 0.1219203392309802, 0.15360212991280214, 0.32289329224399155, 0.245461427207504, 0.1954090879963977, 0.20304613533828939, 0.16109800125871385, 0.20522953889199666, 0.08383508465651955, 0.100226767228118, 0.15962724946439266, 0.16415615858776228, 0.19166544745010988, 0.16516158463699476, 0.2356140384716647, 0.2571740001440048, 0.20661083262945923, 0.14385680641446794, 0.1785590685904026, 0.20358323651765073, 0.20820978683020386, 0.2354042354438986, 0.25505661804761204, 0.2211184948682785, 0.5166974685021809, 0.11662453625883375, 0.6826164882097925, 16.8166138785226, 85.70049885341099, 101.08440807887486, 82.8460260118757, 65.8567007609776, 47.20899336678641, 49.009462697165354, 71.7896841594151, 117.04033470153809, 108.30233573913574, 67.35451003483364, 56.468141964503694, 82.58220291137695, 41.10038382666451, 2.798655790942056, 0.6045876209224973, 0.39804975794894354, 1.620215688432966, 1.8461556902953555, 0.172741526471717, 0.32011083726372036, 0.3047472302402769, 0.2526093050837517, 0.4334193186036178, 0.2409179024398327, 0.2549279678080763, 0.3969576694071293, 0.2559885180422238, 0.1911576861249549, 0.1713990449373211, 0.22955659351178578, 0.12492073965924126, 0.17607348625149044, 0.16835791883724077, 0.1853656162108694, 0.20998996416372911, 0.0863823593993272, 0.3668526176895414, 0.12216016064797129, 0.14927011808114393, 0.21604054234921932, 0.15686338634363242, 0.10139408494744982, 1.7190803033964974, 0.4883516952395439, 0.2951016106775829, 0.25669818424752777, 0.30710646935871666, 0.20897179522684642, 0.11415793932974339, 0.18860699156565325, 0.23123561484473093, 0.0854913614956396, 0.2295333333313465, 0.22831541725567409, 0.14713817462325096, 0.17394333412604673, 0.21607469980205807, 0.1415093330932515, 0.11633917157139097, 0.08712674624153546, 0.194113588226693, 5.813613780907222, 4.925387339932578, 11.259069442749023, 12.749571817261831, 12.261391384260994, 4.039606664861951, 2.014871848481042, 1.1492315041167396, 0.46580234808581217, 0.27421160734125544, 7.40517292703901, 41.35182523727417, 76.90653909955705, 63.290202958243235, 76.59512778690883, 102.15547983986991, 82.84235041482108, 66.87571661812919, 51.63133416857038, 64.69997160775321, 86.08790261404855, 80.84739753178188, 36.19241605486189, 2.6168001549584523, 0.16311893638755592, 0.3053161954241139, 0.283566271087953, 0.21467177436820098, 0.27489703627569334, 0.23193968992148126, 0.18754911475947925, 0.22157947798924787, 0.12588891413594994, 0.08925522238548313, 0.18156495158161434, 0.13094196441982472, 0.19378729430692537, 0.19626267147915705, 0.16137477569282055, 0.16218596430761473, 0.15610941180161067, 0.14009153417178563, 0.09621948190033436, 0.14623934642544814, 0.156647313652294, 0.20822907079543385, 0.19567282098744596, 0.2650244603199618, 0.2753406896122864, 0.11326428156878267, 0.21903263750885213, 0.21165050220276627, 0.09897902275302581, 0.14271454699337482, 0.10032892067517553, 0.1858866496809891, 0.1273912585207394, 0.1289056943995612, 0.14349464513361454, 0.10214962012001447, 0.09113395693046705, 0.15867398918739387, 0.2678276513304029, 0.25180399258221897, 0.2213689692850624, 0.1575258265116385], [0.029691576225949184, 0.022296796419790814, 0.043041644152253866, 0.03321349527686834, 0.07419492051537548, 0.03789272704826934, 0.08917696015643221, 0.050844610269580565, 0.0326497887394258, 0.008802885854882854, 0.031993703051869354, 0.007997719238379171, 0.03013753318893058, 0.03456319642386266, 0.03992650005966425, 0.07454283256083727, 0.03071935661137104, 0.01531552433568452, 0.040690191223153045, 0.06350544946534292, 0.06710560699658734, 0.07673712660159383, 0.06431715376675129, 0.013611012986595077, 0.060336154885590076, 0.0436363834887743, 0.02675189620016941, 0.0774002792313695, 0.04476196451910904, 0.009995417087338865, 0.019746134090902548, 0.0008874433343797655, 0.06919263143624578, 0.02936802358765687, 0.029924418910273483, 0.033518021793237755, 0.07542815791176898, 0.06413499425564494, 0.05844252649694681, 0.04582438072455781, 0.059395461077136655, 0.03331104486382433, 0.05092211253941059, 0.04128626388098512, 0.05619587330147624, 0.2734844349324703, 0.03873851077098932, 0.09440799696104867, 0.10206690670124122, 2.785072931221553, 30.66428334372384, 71.41235528673444, 74.75577981131417, 65.89170578547886, 46.84285109383719, 27.94474278177534, 39.75048780441284, 78.55335944039481, 89.42377444675991, 76.95885903494698, 48.67640427180699, 61.04527473449707, 48.41819531576974, 16.936267069407872, 1.4055085352488925, 0.3640581933515412, 0.31699424449886593, 0.37350448646715706, 0.1066190285075988, 0.4496249333024025, 0.1059627290815115, 0.012057854810596576, 0.06507894503218786, 0.06380817107856274, 0.1162643020174333, 0.08891838403152567, 0.0701300139938082, 0.05017815995961428, 0.012862211425921746, 0.03943385988739984, 0.037593221691037924, 0.11899015360644885, 0.18572808961783135, 0.22348555071013315, 0.07228266634047031, 0.21967115253210068, 0.05640744391296591, 0.1002261226198503, 0.026308934969295348, 0.09090599630560194, 0.01917884319222399, 0.6513622424432209, 0.24739131650754384, 0.09704656859061547, 0.1572450894330229, 0.030348357411899736, 0.03202491566272719, 0.04665747584242906, 0.18009791815919535, 0.13105776320610726, 0.06243038536714656, 0.07000173016318254, 0.09434355649032763, 0.09365369672221796, 0.0804244080292327, 0.021898620196485093, 0.14244569784828595, 0.07490997428872756, 0.06855477459196534, 0.17428033532840864, 0.29710839156593594, 0.11998784435646874, 0.05028881545045546, 0.11820963477449757, 0.19953805500907557, 0.32560941364083973, 0.20989692344197206, 0.05463823849069221, 3.835828593799046, 27.860706056867325, 43.649274894169395, 41.80955171585083, 65.63137762887138, 82.44367667606899, 81.4147526877267, 52.64703573499407, 35.655709402901785, 37.71857050486973, 58.96105139596121, 61.12829181126186, 33.32589851106916, 4.219308793544769, 0.20817530368055615, 0.01020109886303544, 0.034440693711595874, 0.07917755922036511, 0.058475367591849396, 0.040253760891833475, 0.17262808898729937, 0.08066497583474432, 0.02634067683746772, 0.05011183316154139, 0.04754429736307689, 0.06723821988063199, 0.025203374114685824, 0.14221878216734954, 0.026208140288612673, 0.027719985860000764, 0.0612450186163187, 0.015943959721231034, 0.04016532403017793, 0.017332893763003603, 0.038409641810825894, 0.040633747287626774, 0.04340210909556065, 0.04837692089911018, 0.02813827895027186, 0.03798324361975704, 0.02612182215255286, 0.05026574186714632, 0.02505697848807488, 0.09088872758937733, 0.06391313366059746, 0.010551975258359951, 0.01313605034790401, 0.02269794123380312, 0.08764446846076421, 0.02396812316562448, 0.0370222751849464, 0.011104912596887775, 0.03908085882929819, 0.05900811257639101, 0.00495851381648598, 0.07998918888292142, 0.028677539567330053, 0.0517411212702947, 0.00797933348388012, 0.04249858543542879, 0.04451866221747228, 0.00919307317651276, 0.018641234807936207, 0.05419506012861218, 0.023896702265899097, 0.051091966817953756, 0.019882548467389176, 0.027832388578514968, 0.01591843832284212, 0.04599707806482911, 0.07829922278012548, 0.06596330007804291, 0.011178279195779135, 0.07194884068199567, 0.03643682499283126, 0.06043300897415195, 0.012896367182422961, 0.06943366743092026, 0.04930539768455284, 0.046841491146811416, 0.059763830953410695, 0.021146986600277678, 0.1234851631202868, 0.019568110250734856, 0.02551083529501089, 0.0699338223785162, 0.02332093476850007, 0.0869150161743164, 0.041547147024955065, 0.1073177092309509, 0.059208008992884836, 0.04101433079423649, 0.0330351457398917, 0.06576922549200909, 0.07317048870027065, 0.036791491854403696, 0.04470603966287204, 0.06378912460058928, 0.037102260892944675, 0.11724633217922278, 0.02526141600018101, 0.03772904743839588, 0.02878469381747501, 0.06279353730912719, 0.03488235894058432, 0.09127564182771103, 0.15727429358022554, 13.148976853915624, 57.55474294934954, 82.30936799730573, 73.73711831229073, 54.40452698298863, 43.0677558353969, 40.807440825871055, 68.22943414960588, 98.33048261914934, 85.22340774536133, 59.41961860656738, 60.78532872881208, 74.18232413700649, 48.3820264680045, 7.355042542730059, 0.775319082396371, 0.05253139743581414, 0.24379961352263177, 0.16692327867661202, 0.07359172323984758, 0.4462932177952358, 0.11900616703288895, 0.05775776931217738, 0.09299595880189113, 0.07565197947302035, 0.03816919953429273, 0.04321776809436934, 0.041447022397603304, 0.09872948471456766, 0.031042074651590416, 0.10630567425063678, 0.0753308559900948, 0.09184991315539394, 0.08660171620015587, 0.09374120059822287, 0.046502976811357906, 0.17202218435704708, 0.14505325364215033, 0.03573956580034324, 0.05673025016273771, 0.06085938002382006, 0.06749237195721694, 0.32316725754312103, 0.371475911034005, 0.2857291693133967, 0.05016686913690396, 0.13615581393241882, 0.026185266873134033, 0.04186369039650474, 0.16631421207317285, 0.12278065378112452, 0.08033900761178561, 0.05153586103447846, 0.08551393635571003, 0.09776582249573298, 0.05594072377841387, 0.09129791134702307, 0.08395926335028239, 0.07748904518250908, 0.07656649540045432, 0.23390445592147963, 0.5929991113288062, 0.20893191093845026, 0.04562025024954762, 0.21642433532646724, 0.2939838735120637, 0.2324109732040337, 0.0366650298903031, 0.18000650592148304, 6.402167890753065, 37.47764866692679, 56.30172218595232, 53.516039984566824, 67.16933359418596, 84.63803591047014, 96.32768521990094, 69.79677404676164, 44.571391173771445, 42.97642871311733, 61.62931251525879, 74.8980302810669, 55.17222997120449, 16.19379472732544, 0.6022794076374599, 0.11745466957134859, 0.02572670272950615, 0.06235678467367377, 0.0356764790069844, 0.024175868535946523, 0.1386694469090019, 0.06937396313462939, 0.06630672022168126, 0.09980588552675076, 0.05247069230037076, 0.048479243979922364, 0.025642725539260676, 0.07789753004908562, 0.09013645617025239, 0.03311010350340179, 0.048116166676793776, 0.040534732065030506, 0.011436277717751051, 0.028842165733554533, 0.055778777825513055, 0.0947387692119394, 0.10227052148963724, 0.06628265936991998, 0.04443797083305461, 0.046650992440325875, 0.025543771384816085, 0.05379535211250186, 0.027466383396780918, 0.05190998149503555, 0.10244373112384762, 0.01452383681732629, 0.018784454890659878, 0.026927557042134658, 0.0031941611918487717, 0.08353578285979373, 0.01751870888152293, 0.04038910487932818, 0.059058405591973236, 0.006184749155571418, 0.021549958369827697, 0.05867462618542569, 0.05302972373153482, 0.06333973085773842, 0.11822830805821077, 0.15572073337222847, 0.17040120490959712, 0.11574408278933593, 0.16715499838548048, 0.15360830458147184, 0.2507262075585978, 0.14699342953307287, 0.12929453567734786, 0.26030611779008594, 0.13317277042993478, 0.15340155496128968, 0.19306439666875772, 0.22607726949666226, 0.0659410644854818, 0.17200541097138608, 0.11125311055885893, 0.11317546133484159, 0.15442384939108575, 0.20431358447032316, 0.20569466107657977, 0.13683668311153138, 0.23094753601721354, 0.08396836929023266, 0.1807535458356142, 0.1538136021367141, 0.0914176320657134, 0.18456202718828404, 0.1485983548419816, 0.09804706847561256, 0.12187915215534822, 0.2576118995036398, 0.15783650055527687, 0.23594812197344645, 0.11936808404113565, 0.19534724631479808, 0.300726801689182, 0.2181756477802992, 0.10903052160782473, 0.19586689557347978, 0.17474652959832124, 0.14477816197488988, 0.10548191238194704, 0.16674399615398475, 0.14634567286287034, 0.491931645997933, 0.13414990156888962, 0.14297096537692205, 0.1742073113897017, 6.586533997740064, 52.0930940764291, 104.63937050955636, 101.58809689113072, 83.75352328164237, 67.22204957689557, 49.23668268748692, 57.830749716077534, 92.63255677904401, 105.79751709529332, 90.63310146331787, 61.608092716761995, 78.77515288761684, 67.32204805101667, 25.516267469951085, 1.694100986633982, 0.39601100449051174, 0.6291169332606452, 0.5775126623255866, 0.4328754592154707, 1.542676831994738, 0.3886509622846331, 0.1939056579555784, 0.27645573977913174, 0.39594439949308124, 0.1844936851412058, 0.19596748160464422, 0.13599768813167298, 0.12061828481299536, 0.13756665108459337, 0.18750712701252528, 0.17748699683163846, 0.24507121528897965, 0.2534759028681687, 0.3196026145347527, 0.20455796564263956, 0.48273521661758423, 0.3794660137167999, 0.21209712752274104, 0.1031999991142324, 0.15757203474640846, 0.22550793790391513, 1.1398592527423586, 1.1832610666751862, 0.5384812653064728, 0.401657230087689, 0.23171398203287805, 0.17363470925816468, 0.1324768377734082, 0.3251814480338778, 0.17679711670747825, 0.24880190938711166, 0.16988851742020675, 0.2690431246800082, 0.16236262768507004, 0.3201451168528625, 0.19710048580808298, 0.235104322965656, 0.2160088276224477, 0.17597504439098494, 0.5263629012874195, 0.876344478556088, 0.29956913952316555, 0.16254803059356554, 0.2056793804679598, 0.2715237944253853, 0.2430159870002951, 0.6062111652323178, 0.1539143645869834, 5.691495282309396, 41.45050007956368, 61.582301003592356, 60.7098365511213, 82.06032371520996, 95.13750743865967, 96.77007007598877, 73.35003416878837, 52.94436999729702, 55.328175340379985, 82.15402017320905, 90.78785869053432, 58.94725227355957, 13.574893610818044, 0.3790448063186237, 0.3177271437432085, 0.12644992688936846, 0.1601863351783582, 0.2072671524115971, 0.15454435721039772, 0.3405790632324559, 0.1841448095760175, 0.10256504639983177, 0.3247148059308529, 0.15326145105063915, 0.15457821610782826, 0.12467589708311216, 0.2537391201726028, 0.17875454095857485, 0.1328827374215637, 0.10037613314177309, 0.10401164913283927, 0.07185024275843586, 0.321542817567076, 0.19261507077940873, 0.19749387327049459, 0.14531904937965529, 0.18522821286959307, 0.09325002266892365, 0.15545097499021462, 0.15943592973053455, 0.1820512983415808, 0.19747245870530605, 0.20814026413219316, 0.1353030311209815, 0.1273744579936777, 0.1649303399026394, 0.11629099558506693, 0.17868851950126036, 0.2692014133291585, 0.20827924167471273, 0.24881235882639885, 0.11815588123032025, 0.2460731943803174, 0.12474125357610838, 0.1179676963282483, 0.18272327871194907, 0.1491822749376297], [0.054515939338931015, 0.017592603041391288, 0.041067802746381075, 0.03979811105611069, 0.03508246909560902, 0.047766934880720716, 0.055903275430734665, 0.016967880938734328, 0.030233688386423246, 0.005141523192703191, 0.042977027262427976, 0.01155236064057265, 0.06265601183154754, 0.00882841319045318, 0.06813161301293544, 0.10625423451087304, 0.04217631183564663, 0.0336062042042613, 0.03374319703185132, 0.06136494968086481, 0.09817465341516904, 0.005988603341393173, 0.03845543274655938, 0.05209830549678632, 0.09547943768224545, 0.09144846469696079, 0.04873479723132082, 0.06047141405620745, 0.04113843145647219, 0.02826725997562919, 0.0831308603020651, 0.009757543914020061, 0.07640887171562229, 0.048853133738573105, 0.02347213781571814, 0.03979353094473481, 0.08465350645461253, 0.015622223860451152, 0.049287447040634494, 0.03738350008747407, 0.05092328979766794, 0.088806072915239, 0.008924168052284845, 0.006037317914888263, 0.04501943463193519, 0.13325757373656544, 0.08248068804719619, 0.1074291586077639, 0.01211763289757073, 0.005807979439850897, 0.6448467863457543, 16.035384484699794, 53.44900376456124, 77.36295236860002, 75.01967239379883, 64.29667036873954, 51.64471639905657, 47.96461691175188, 56.11769219807216, 86.40320491790771, 86.63656711578369, 72.2668239048549, 51.70794153213501, 43.96107530593872, 41.412524700164795, 10.024647269930158, 0.9792664072343281, 0.5297314205339977, 0.36789425036736895, 0.20034613593348435, 0.12376860076827662, 0.029576785064169338, 0.3075207014169012, 0.24715312357459748, 0.15753839298018388, 0.020295202931655303, 0.032393655340586386, 0.11981343371527535, 0.03770650650507637, 0.028275405788528066, 0.1056450389857803, 0.15268973101462635, 0.176034864038229, 0.06129605123507125, 0.033957023772278, 0.24116407494459832, 0.19068104241575512, 0.03566253850502627, 0.15546882046120508, 0.09906578024051019, 0.03253144205414823, 0.5039092547127179, 0.10513537097722292, 0.14394773010696682, 0.16025101313633577, 0.12107488459774426, 0.09687605952577931, 0.2576976663299969, 0.25683399981686045, 0.10667243599891663, 0.027009637727003013, 0.17274348065257072, 0.059641328241143904, 0.0676711116518293, 0.06353892838316304, 0.006048668109412704, 0.042516726069152355, 0.30828199056642397, 0.6080105315361704, 0.21221052429505757, 0.27999945676752497, 0.06560388007866484, 0.1061798060046775, 0.13836126987423214, 0.45311643023576054, 0.1470300704240799, 4.4488590359687805, 21.164551632744924, 55.935340200151714, 50.70131778717041, 45.83318403788975, 53.1774125780378, 70.79015799931118, 58.36413165501186, 45.08016259329659, 40.604372773851665, 47.81240272521973, 60.46355765206473, 47.695613929203574, 10.78849400792803, 0.6157432251742908, 0.03421176956700427, 0.03024891810491681, 0.01177197358837085, 0.0643916501264487, 0.058666666969656944, 0.05932032010917153, 0.056770728169275184, 0.08154859127742903, 0.07859560009092093, 0.011413444166204758, 0.03599569919918265, 0.030883297457226684, 0.07701548202229397, 0.02756335453263351, 0.015920952295086215, 0.01407089688083423, 0.02758607527773295, 0.03959111037797161, 0.059321690749909194, 0.07000483785356794, 0.03501587427620377, 0.08268451318144798, 0.059675682469138076, 0.05274300875940493, 0.024196479037137966, 0.045225736419005055, 0.01159425508896155, 0.02616157751929547, 0.07738242018967867, 0.07905720746410744, 0.03936796735173889, 0.02182596775570086, 0.07039467657783202, 0.03147775520171438, 0.04107886625986014, 0.07104704728616135, 0.015260593533249838, 0.0193382090157164, 0.04901597196502345, 0.030387858328010355, 0.03527572265427027, 0.02368375931733421, 0.013637281621673276, 0.055896317054118426, 0.07749624443905694, 0.04065531113051942, 0.011916665243916214, 0.056693181794668944, 0.03808834530147059, 0.03796390537172556, 0.039143450292093415, 0.029086777607777288, 0.02852942215810929, 0.015202129259705544, 0.03894277695300324, 0.09447025254900966, 0.09046039557350533, 0.005614544797156538, 0.029997612482735088, 0.05132817164329546, 0.01643252868338355, 0.02705878401840372, 0.0769460339631353, 0.02017879855286862, 0.025435027666389942, 0.07121885913823332, 0.014267411648428865, 0.029802940785884857, 0.049746343666421514, 0.021063735442502157, 0.14452033223850386, 0.007401305616700223, 0.09726628501500402, 0.10013993510178157, 0.05402231189821448, 0.03235210185604436, 0.056597365864685605, 0.01451171309288059, 0.02933294671986784, 0.06597940171403543, 0.06675331840025527, 0.09242529728050743, 0.018411550704123716, 0.01815427906279053, 0.02526205382309854, 0.10484448301472835, 0.0634416061054383, 0.06647972629538604, 0.0053995789660673055, 0.0487299389205873, 0.2319872687969889, 0.03784754000870245, 0.062432862019964626, 0.04074283196989979, 0.06502855023635284, 3.328489588839667, 39.36257335117885, 78.34779003688267, 84.78678294590541, 73.5987935747419, 58.30052784511021, 49.276999609810964, 63.881084714617046, 73.60637405940464, 95.81611020224435, 75.5539332798549, 69.12247916630336, 61.436305454799104, 65.00976399012974, 36.270868165152415, 4.377335582460676, 0.588478548186166, 0.5633037590554782, 0.17893876321613789, 0.3026703702551978, 0.08068860920944385, 0.048437507290925295, 0.17698177322745323, 0.08010954742452928, 0.046350353929613314, 0.1600103367652212, 0.04105918874431934, 0.04198740768645491, 0.02703134066957448, 0.021489434742501805, 0.14372597129217216, 0.04521052027121186, 0.11676420590707234, 0.04019791745979871, 0.023357222821297388, 0.31674904908452717, 0.24869432087455476, 0.09533862809517554, 0.14322426249938353, 0.15738085071955407, 0.11622304708829947, 0.08466490584292582, 0.10410000117761747, 0.1208546728427921, 0.23771752417087555, 0.5985393768974713, 0.12986998765596322, 0.14801823454243795, 0.4262963836746556, 0.2407772285597665, 0.1263398685093437, 0.09356927339519773, 0.07256309807832752, 0.01345715856379164, 0.07915277912148408, 0.13051357812115125, 0.15164952326033795, 0.1279860351766859, 1.035078029547419, 1.0704792099339622, 0.5417772084474564, 0.23222258474145616, 0.015922748716548085, 0.08232951044504132, 0.3243428873164313, 0.23676106120858872, 5.0692910466875345, 27.978947026388987, 65.76497759137834, 62.56048924582345, 52.17639602933611, 62.781539235796245, 89.33910369873047, 75.6905973979405, 56.930242334093364, 44.83411298479353, 54.04207420349121, 69.30803775787354, 67.95643247876848, 27.88312963077, 4.215349188872746, 0.18116935209504195, 0.05535981298557349, 0.023468872365940894, 0.057094087425087175, 0.03180789980771286, 0.01227551866655371, 0.09118750012878861, 0.09366283658891916, 0.10506168885954789, 0.02770524638305817, 0.09041895065456629, 0.023276699374296834, 0.04640656037788306, 0.02744516560674778, 0.10976619606039353, 0.03245188043053661, 0.06084454046296222, 0.007738885270165545, 0.04827498458325863, 0.013615975622087717, 0.02910836859207068, 0.07286193168589047, 0.08675605577549764, 0.04571701952123216, 0.015152592810669115, 0.09370306693017483, 0.0189419292977878, 0.03781739609049899, 0.04555316009957876, 0.027994549966284206, 0.03861984517425299, 0.10059709807059594, 0.02121903684123286, 0.009103452271249677, 0.06650587024965457, 0.06270491385034152, 0.04043485849563565, 0.029773848596960306, 0.018236349569633603, 0.03056099671604378, 0.04260499329705324, 0.04635182635060378, 0.01232051571631538, 0.05562813965869801, 0.07799825178725378, 0.1503262985497713, 0.1891297892268215, 0.17093029937573842, 0.19039140295769486, 0.16342734412423202, 0.16588526937578404, 0.19378173031977244, 0.16616619644420488, 0.07516964285501412, 0.09840844265584435, 0.19165256885545595, 0.12791933518435272, 0.1269383363957916, 0.08925861506057636, 0.19924156234732696, 0.27437999259148327, 0.08938630178038563, 0.21180387825838157, 0.15572587666766985, 0.12631419274423802, 0.2372972938631262, 0.15102913869278772, 0.19137753147099698, 0.15217019032154763, 0.15336020503725323, 0.2969848167683397, 0.2462223092360156, 0.21282013372651168, 0.170360411384276, 0.2345798153962408, 0.12132261773305279, 0.12419470718928746, 0.18297772934394224, 0.127466562337109, 0.09621526819786855, 0.10116654501429626, 0.26629725630794254, 0.13564284145832062, 0.14264955690928868, 0.23074516973325185, 0.15632594589676174, 0.2936827668121883, 0.2009684339697872, 0.08443755589957748, 0.1349529070513589, 0.42727863096765106, 0.16784695482679776, 0.2743438673870904, 0.12103586883417197, 0.11400829521673066, 1.1324840656348636, 26.55712672642299, 77.79720088413784, 109.1443601335798, 96.00920758928571, 86.52636868613106, 71.90061214991978, 69.91877746582031, 74.21733610970634, 104.45801557813371, 104.61876215253557, 94.33447633470807, 67.2374815259661, 66.58200236729213, 60.95637253352574, 17.205469812665665, 1.212585830262729, 1.004503350172724, 0.7250996742929731, 0.3366854121642453, 0.29379933912839207, 0.09102053980209998, 1.4036733422960554, 0.5545967976961816, 0.3512039988168648, 0.3095299521727221, 0.25064923454608234, 0.19296326780957834, 0.15761134906538896, 0.16650409331279142, 0.18826730336461747, 0.3405022259269442, 0.5138966930764062, 0.5516674805964742, 0.2128300131963832, 0.546058004455907, 0.5319944705281938, 0.3090289761977536, 0.5244988298841885, 0.3634742461144924, 0.23431461676955223, 1.1290858536958694, 0.4643269958240645, 0.21947478449770383, 0.6589782823409353, 2.1720576882362366, 0.4162582994571754, 0.32392086567623274, 0.5954376576202256, 0.3300244781587805, 0.20777639294309275, 0.2985105977526733, 0.24945976265839168, 0.14776993143771375, 0.23573774897626468, 0.40194522749100414, 0.2687010073236057, 0.7897320347172874, 2.3366878713880266, 1.8994462021759577, 0.4731294406311852, 0.24476318753191403, 0.6124224747930254, 0.4953860949192728, 0.6606664231845311, 0.17382047857557023, 6.98215400321143, 30.158523968287877, 74.27786881583077, 68.92674841199602, 62.600851331438335, 67.99026325770787, 89.90301254817417, 77.34678391047886, 66.64985847473145, 57.38955647604806, 70.70691163199288, 90.00597790309361, 70.30674403054374, 22.44176254953657, 2.1734486307416643, 0.12032620262886796, 0.10459289580051388, 0.12304104837988104, 0.13100369753582136, 0.1718543962176357, 0.19250218969370636, 0.13992283679544926, 0.24815949957285607, 0.20025114103087358, 0.13449476020676748, 0.16388809654329503, 0.10076798711504255, 0.11310169100761414, 0.1785385361207383, 0.16830331033893994, 0.1335780458258731, 0.14302651025354862, 0.11968394209231649, 0.23420244136026927, 0.14173737514231885, 0.16923795161502703, 0.18314455396362714, 0.20618359984031745, 0.13306795034025395, 0.0832727826865656, 0.13803171898637498, 0.12125179224780627, 0.15219217485615186, 0.2581705780965941, 0.18456839184675897, 0.0957288739404508, 0.1417419213269438, 0.12759737031800406, 0.09575200519923653, 0.15417785330542497, 0.16095527820289135, 0.1767513563058206, 0.10534365408654724, 0.1653407450233187, 0.1255712511816195, 0.23382072470017842, 0.10788360065115349, 0.1876821754766362, 0.134512062849743, 0.22835368663072586], [0.007510081565539751, 0.05710373619305236, 0.08344459453863756, 0.03160026469933135, 0.03609997985352363, 0.047294996811875274, 0.03157182729669979, 0.09310105709092957, 0.11051327668662582, 0.03114122897386551, 0.09628881460853986, 0.058665676308529716, 0.11685949936509132, 0.0357061479506748, 0.03394045055444751, 0.015616393548303416, 0.05329993673201118, 0.023533323014687215, 0.05397204941670809, 0.02987705377329673, 0.03307183412835002, 0.04470213130116463, 0.06402788750295128, 0.1425691640802792, 0.020798808229821067, 0.041197036526032856, 0.04816045465746096, 0.030559269844421318, 0.07519728637167386, 0.06830177602491208, 0.02540312464615064, 0.05159413701455508, 0.06730408527489219, 0.01496327475511602, 0.044773777813783715, 0.043827418237924576, 0.016267363081819246, 0.03277668157326324, 0.05201576171176774, 0.05661563202738762, 0.0682500580857907, 0.04179535174210157, 0.041233443322458437, 0.026295262488669584, 0.04959680811901178, 0.009192677081695624, 0.04120059544220567, 0.06687523078705583, 0.06974825662161623, 0.02880690566131047, 0.08180847018957138, 0.14351458049246243, 2.5772134448800768, 20.134614944458008, 40.46042346954346, 77.73216574532645, 80.0297543661935, 67.02124663761684, 59.8304933820452, 61.24705736977713, 71.4705672945295, 68.18697370801652, 89.13533387865338, 67.73754337855748, 48.23607955660139, 48.732424122946604, 30.673639093126567, 9.278450693402972, 1.5463380983897617, 0.6447591739041465, 0.2507556288370064, 0.12984226271510124, 0.8156169514570917, 0.2597307472356728, 0.20237574273986475, 0.17346689397735254, 0.10473352896847896, 0.028687273152172565, 0.029609619373721734, 0.026997481772143925, 0.17489603800433023, 0.238644755844559, 0.04566734397251691, 0.4228850895805018, 0.282838338719947, 0.39044916150825365, 0.23524947517684527, 0.4588792824319431, 0.05590438822816525, 0.18151255510747433, 0.07518444848912102, 0.06292007051940475, 0.08114428618656737, 0.20429858884641103, 0.39532527700066566, 0.3752556767846857, 0.12534706321145805, 0.9131886043718883, 1.403582364320755, 0.5865879867758069, 0.37894194040979656, 0.4594363325408527, 0.2778862273054463, 0.1960718131491116, 0.22970104004655564, 0.45648459664412905, 2.0393640313829695, 2.0025333677019392, 0.26521849419389454, 0.3297830825405461, 0.12047054059803486, 0.040206392362181625, 0.23972104809113912, 0.11320860777050257, 7.5025215319224765, 33.48844119480678, 58.73094095502581, 71.1106436593192, 63.16521181379046, 60.30411039079939, 57.40557902199881, 45.80010713849749, 43.89841297694615, 38.073088441576274, 45.78386572429112, 67.81368868691581, 64.18822288513184, 19.740412371499197, 0.9147309958934784, 0.015261563838326504, 0.22124341316521168, 0.04776024452543684, 0.07542580339525427, 0.0861121735402516, 0.07869358733296394, 0.016945984613682543, 0.0577103193583233, 0.013457385024854114, 0.04217891062476805, 0.023259420480046953, 0.05058026998969061, 0.02487313112110964, 0.040620017131524425, 0.026263177960312793, 0.03238269021468503, 0.021847546865631427, 0.03194913687184453, 0.06466025499893086, 0.04518170967432005, 0.07582243425505501, 0.044159476312675645, 0.06262728944420815, 0.044456030042575936, 0.05285458705787148, 0.01743313543764608, 0.00993413180445454, 0.04973686792488609, 0.011889874985042428, 0.02648846515720444, 0.03963135089725256, 0.03312147914298943, 0.018063066992908716, 0.054218025146318335, 0.02844352980277368, 0.036787362968815226, 0.07501421083829232, 0.12459441859807287, 0.08742529486439057, 0.04465806045170341, 0.06471831724047661, 0.09911043463008744, 0.06643096676894597, 0.05424622506169336, 0.09771059653056519, 0.06177703756839037, 0.0673646309546062, 0.011789411090181341, 0.059545681944915226, 0.006783837053392614, 0.021554592764005065, 0.08427295687475375, 0.04282713209145835, 0.030052041169255972, 0.007568655252855803, 0.07416958401777915, 0.011111842983934497, 0.021290218557364175, 0.054273227362760475, 0.007635949811499033, 0.02219050899813218, 0.07930883539042302, 0.045457001509410996, 0.03954591655305453, 0.021026902865352373, 0.016698651814035008, 0.016872424632310867, 0.06538995834333555, 0.04250158456021121, 0.052685143293014595, 0.13173671891646727, 0.04600531208728041, 0.05043021197031651, 0.019210067677444646, 0.09437534585595131, 0.051126799413136075, 0.028924482209341865, 0.049496727596436224, 0.024255815228181224, 0.049984214295233996, 0.061753831670752594, 0.06426927633583546, 0.04170014649363501, 0.024930760796580995, 0.07759606372565031, 0.10268015986574547, 0.03267147132594671, 0.04589446321395891, 0.0036670890736526674, 0.04188059948916946, 0.015333775231348616, 0.03876795240544847, 0.03325067560321518, 0.05783358881516116, 0.08025563601404428, 0.10547927966607468, 0.019462582788297107, 0.0635842341663582, 1.094519542796271, 11.65146722112383, 44.87190423692976, 69.92761557442802, 79.77740274156842, 79.50653416769845, 67.25613743918282, 65.33492578778947, 74.16235501425606, 86.63710907527378, 88.76231983729771, 75.27034950256348, 59.16726003374372, 67.12728309631348, 58.61108452933175, 33.00038930347988, 7.468969549451556, 0.8361422015087945, 0.544701694377831, 0.18272154166230134, 0.2514449932745525, 0.9206675801958356, 0.18195994038666996, 0.1706021326993193, 0.18072516950113432, 0.031131023807185035, 0.08836757644478764, 0.05670413334986993, 0.18967123303030217, 0.2636542538447039, 0.6444930253284318, 0.5621435727391924, 0.36221010823334965, 0.10928007321698324, 1.0495137806449617, 0.2543010828750474, 0.5083550161549023, 0.12288296329123632, 0.07148165575095586, 0.07465028536639043, 0.023613325686060956, 0.10934735674943243, 0.16107706166803837, 1.2310907287257058, 0.5919907540082932, 0.23073860151427134, 1.5580205172300339, 1.8624010128634316, 0.6743510631578309, 0.38981147429772783, 0.2339391697730337, 0.08708207828125783, 0.1202377759452377, 0.2622411368148667, 0.9907199697835105, 3.1573930212429593, 3.0119446430887495, 0.5908939157213483, 0.44094799033233095, 0.07032341683017355, 0.07504468384597983, 0.31777871240462574, 0.31528216493981226, 8.33514848777226, 42.590025493076865, 71.51966326577323, 72.43688801356724, 71.07172679901123, 59.83911609649658, 72.61745085035051, 57.97182594026838, 55.650662081582205, 45.630230631147114, 50.232251848493306, 71.30854225158691, 79.55505343845913, 37.473083700452534, 6.235187913690295, 0.22324051814419882, 0.1831302097333329, 0.07737224894974913, 0.08920098708144256, 0.042917292432061264, 0.08817936440131494, 0.020248311072854058, 0.057589465486151833, 0.029105257509010177, 0.0029068601350965245, 0.009826735826209188, 0.09149431330817086, 0.04869287055251854, 0.011972872540354729, 0.04448401961209519, 0.02031024944569383, 0.020703801452847462, 0.07235067590538945, 0.05462166866553681, 0.08171223356787648, 0.08622115983494691, 0.02823297699381198, 0.04429443014253463, 0.02358782973273524, 0.0606231548424278, 0.010549968491042299, 0.019822381070948074, 0.05231487351868834, 0.05755380168557167, 0.08043456569846187, 0.02451492061040231, 0.03838263611708369, 0.05403892922082117, 0.034574680629053285, 0.06959894499076263, 0.027145163222615207, 0.006709030688008559, 0.06826461266194071, 0.011139772333470839, 0.08053849690726825, 0.030315957364759276, 0.09062192762004477, 0.048996060354901214, 0.08466202885444675, 0.00226752705306613, 0.038250094479216, 0.0045056981367192096, 0.16024439063455376, 0.14439827735934938, 0.12135149618344647, 0.08309312696967806, 0.19603617648993218, 0.1142529206616538, 0.1368983212326254, 0.1926051370267357, 0.25517283752560616, 0.08311196988714592, 0.1448050591030291, 0.18496329922761234, 0.15766009502112865, 0.12202948837407998, 0.1404854373208114, 0.07156915962696075, 0.17672897822090558, 0.07997739594429731, 0.10729199275374413, 0.13842608353921346, 0.1722938154957124, 0.09926720336079597, 0.15458988691014902, 0.21855650948626654, 0.11028437289808478, 0.22995999615107263, 0.10558436438441277, 0.1494418824357646, 0.16761412232049874, 0.13258210569620132, 0.11765842006674834, 0.21029294362025602, 0.2296619564294815, 0.19370568011488232, 0.13923815424953187, 0.17133598189268792, 0.10437330151242868, 0.20927522251648562, 0.2368437067738601, 0.07655388143445764, 0.14746456353792123, 0.11151090636849403, 0.12761802492397173, 0.15067910961806774, 0.12992117633777006, 0.1467777503920453, 0.13358514330216817, 0.18237398245504924, 0.21933037867503508, 0.1116970217387591, 0.18531134698007787, 0.45187571538346155, 4.2771521125520975, 31.54689564023699, 73.17835112980434, 105.38355037144252, 104.71388299124581, 87.88219846997941, 80.63451862335205, 82.51846708570207, 90.1284190586635, 85.91769259316581, 105.45103822435651, 86.83559826442173, 71.26713098798479, 76.18589973449707, 50.49279539925711, 22.877049820763723, 2.9992333480290005, 0.9452263138123921, 0.5154538495200021, 0.5441896447113582, 1.77111297420093, 1.3357903105872018, 0.8855815657547542, 0.3783928155899048, 0.1744759026914835, 0.20841528794595174, 0.1473535280674696, 0.3640377287353788, 0.9184638070208686, 1.5817907388721193, 1.3373539809669768, 1.0695738813706805, 0.4830911489469664, 1.8952646894114358, 0.8937639381204332, 1.156015008687973, 1.0454341024160385, 0.705161492739405, 0.1455675017620836, 0.2339901141822338, 0.18399137923760073, 1.9613492233412606, 2.9197917708328793, 1.5998527982405253, 1.590328989284379, 2.9696070977619717, 2.031458935567311, 0.6944582813552448, 0.42805042383926256, 0.3842310665973595, 0.2975403741002083, 0.37245883686201914, 0.5281381117446082, 1.4322589912584849, 3.7198661991528104, 4.294848740100861, 1.665758416056633, 1.0442400979144233, 0.23121724011642592, 0.264273322054318, 0.4449506141245365, 0.4606704520327704, 9.911409871918814, 45.343673024858745, 76.27274526868547, 93.75612912859235, 82.01522295815604, 77.54869161333356, 72.03077970232282, 61.66624219076974, 62.63379968915667, 56.850209508623394, 63.12336976187569, 93.44111864907401, 91.68836607251848, 32.6468962260655, 3.0889211297035217, 0.1194590755871364, 0.44679500801222666, 0.17699351188327583, 0.12491529780839171, 0.2459016064448016, 0.35691674798727036, 0.2270870924528156, 0.10188582606081452, 0.11005846823432616, 0.2289824986032077, 0.10419499608022825, 0.2591910133404391, 0.145609068817326, 0.191638781023877, 0.2511030116251537, 0.2248602355165141, 0.13348214168633732, 0.1435562696840082, 0.15859689403857502, 0.25840206710355623, 0.24034470319747925, 0.20026298825229916, 0.17381589167884418, 0.07622882923377411, 0.14406719298235007, 0.13073400700730936, 0.09619167553527014, 0.06980205766324486, 0.1035686879019652, 0.254819890750306, 0.1282234817211117, 0.0654755826773388, 0.20887171131159576, 0.23020261313234056, 0.1886699731860842, 0.13111857351447853, 0.18402713803308351, 0.194510191945093, 0.24128840970141546, 0.19548246477331432, 0.15387160331010818, 0.2887626551091671, 0.26270791462489534, 0.18588382697531156, 0.23588447538869722, 0.15999663035784448, 0.1534370830548661], [0.032773607809628756, 0.028458052148510302, 0.02702023135498166, 0.07935612249587264, 0.09537663962692022, 0.02591229053879423, 0.05414982559159398, 0.12788086224879536, 0.031101185229739974, 0.013457792145865304, 0.09421350846865348, 0.06034815138471978, 0.04987463767507246, 0.0597728622545089, 0.05563255013631923, 0.08347001924578633, 0.10270810193781342, 0.015987012768164277, 0.06144937979323523, 0.06594431466822114, 0.024669000646099448, 0.01463885189566229, 0.08041402644344739, 0.018379656165572147, 0.04084456811792084, 0.03077717118763498, 0.0697620783799461, 0.02060582778150482, 0.009540441545790859, 0.026425780395844152, 0.056431766000709364, 0.05637056553470237, 0.0607151234788554, 0.031747703573533466, 0.04702491612572755, 0.005747454116187457, 0.018333741397197758, 0.07935108098068408, 0.02726357097604445, 0.0076240610298035395, 0.020177239618663276, 0.01943150079543037, 0.006102378396982593, 0.12978342015828404, 0.012778135848098567, 0.08792178572288581, 0.005202050212704177, 0.046799058959420235, 0.08578252765749182, 0.11009793183101074, 0.11405465272920472, 0.03334490715392998, 0.12027813520814691, 0.04490132543391415, 2.2182627746037076, 21.857068164008005, 46.68621785300118, 75.07371548243931, 85.92242431640625, 67.9676399230957, 64.94361019134521, 61.44790199824742, 62.11154529026577, 76.6724751336234, 63.24590124402727, 60.91384260995047, 53.48909487043108, 38.97060809816633, 29.12658793585641, 11.745358228683472, 3.6403256101267676, 0.9792579391172954, 0.2929045685700008, 0.27218607174498693, 0.31819839988436016, 0.07384594316993441, 0.3825014808348247, 0.1889849898538419, 0.14853632317057677, 0.3924293709652764, 0.4998750111886433, 0.47725026522363934, 1.168279013463429, 1.9898077419825961, 1.4325149889503206, 0.7642257405178887, 0.34090712134327206, 0.1567293078239475, 0.11450148160968508, 0.22215210726218565, 0.1733674614557198, 0.17325855658522674, 0.11900964113218443, 0.19357852265238762, 0.15832423152668135, 0.08315025283289806, 0.05266644286790064, 0.032939058395900896, 0.5050646641424724, 1.3038569326911653, 1.8011262608425957, 1.0411480409758431, 2.0812725254467557, 1.3524704383952277, 2.1812833760465895, 0.9723985471895763, 0.366471172443458, 0.0628109553030559, 0.05941243802330323, 0.0880621542621936, 0.2817813168678965, 2.4167341589927673, 16.15883834021432, 40.15548092978341, 54.35091815676008, 51.31586858204433, 79.04160240718296, 87.19567476000104, 56.45076104572841, 64.31121989658901, 43.03951488222395, 52.49204921722412, 50.0424930708749, 67.76990113939557, 80.78006948743547, 34.43698842184884, 6.829842107636588, 0.22646875706102165, 0.09846733949546303, 0.0741570039785334, 0.05919437722436019, 0.03815165261871048, 0.05491412404392447, 0.028065241440864544, 0.02122506053586091, 0.09229779376515321, 0.0054987337124267855, 0.019174242724797556, 0.03757398522325924, 0.009127278180260743, 0.027034433092921972, 0.02966874012989657, 0.030046568784330572, 0.013064631992684943, 0.06149374919810465, 0.06997317062424761, 0.016045480434383665, 0.047654637335134406, 0.05737356242856809, 0.06642631201871804, 0.018332026399938122, 0.02351513657984989, 0.02768987586854824, 0.028338487492874265, 0.05118551644097481, 0.038336139504930804, 0.06664946183030095, 0.027136991964653134, 0.03879278000178082, 0.03825312753074935, 0.005168282069332365, 0.04711197895397033, 0.019658365586240376, 0.07581472609724317, 0.03261966856994799, 0.03526106969054256, 0.0006223156358048852, 0.012510512306887125, 0.01610753415817661, 0.02258856308513454, 0.0632497231875147, 0.06552782308842454, 0.03649926717792239, 0.05527314031496644, 0.04545339848846197, 0.019590552796476653, 0.04430821458143847, 0.055126088205724955, 0.03148019114243133, 0.023598294439060346, 0.03763829337965165, 0.013817243527487984, 0.019887457668249096, 0.09679626380758626, 0.01821915040324841, 0.057527169186089716, 0.054851159386868985, 0.04389284258442266, 0.009547967347316444, 0.02725237005922411, 0.06321711279451847, 0.036777069592582326, 0.05250666144170931, 0.09169726991759879, 0.07052637343960148, 0.033960284133042605, 0.03642854347292866, 0.05408966667684061, 0.06947304281805243, 0.08390135038644075, 0.039276870632810254, 0.07217073520379406, 0.050280669637556584, 0.0534865304694644, 0.03492554769452129, 0.05623914008694036, 0.08317568432539701, 0.04615633362638099, 0.03244589575167213, 0.08933940822524683, 0.026532228969569718, 0.0371223794562476, 0.05904744725142207, 0.0769011556570019, 0.04700642265379429, 0.06587909388222865, 0.06233477299766881, 0.0310423324948975, 0.03338125966755407, 0.08761601748743228, 0.01787425614228206, 0.04847568167107446, 0.0055837583911073, 0.04218613363004156, 0.0628328923402088, 0.18930536694824696, 0.042194598354399204, 0.05844678769686392, 0.17558150765086922, 0.6047281048127583, 9.188662597111293, 45.15435198375157, 74.09355395180839, 85.58991827283586, 80.47010340009416, 71.41076414925712, 70.65008926391602, 64.73523371560233, 86.93144866398403, 88.74565805707658, 71.55876772744315, 76.81347492762974, 68.04005404881069, 64.67893941061837, 42.74508844103132, 16.258934089115687, 2.420229320015226, 0.8743873664311, 0.751184731721878, 1.3424306171280997, 1.3502538544791085, 0.0561078876656081, 0.08326356139566217, 0.2201286886951753, 0.09182892606726714, 0.05515429490645017, 0.5536786041089466, 0.7631385645696095, 2.554319130522864, 6.518021719796317, 1.6012226790189743, 0.1542282413159098, 0.24954091544662202, 0.17157390341162682, 0.14869714954069682, 0.31832642587167875, 0.21080959375415528, 0.09334565539445196, 0.12360127403267793, 0.14340677484869957, 0.15479892997869424, 0.12372767153595175, 0.06474423727818898, 0.07938230716224227, 0.8603026622108051, 1.2248794734477997, 1.5205894857645035, 1.6164531303303582, 2.364106114421572, 1.8128815272024699, 2.4373277510915483, 1.1469339302607944, 0.32826609537005424, 0.16483548070703233, 0.09676193672099284, 0.09753719690654959, 0.3168826662003994, 2.796756327152252, 14.931524174554006, 46.18182727268764, 74.8761990410941, 66.90077877044678, 87.8280997957502, 96.20450060708183, 66.93932737622941, 78.31791973114014, 51.53485843113491, 52.55904027393886, 53.492357049669536, 72.15693119594029, 87.46443802969796, 55.648390020642964, 18.33445828301566, 0.671657876244613, 0.1761572039020913, 0.02863441527421985, 0.06095914502761193, 0.010510067239270678, 0.06521381743784462, 0.09749599626021725, 0.047025330032088926, 0.008612442279367574, 0.03835077550528305, 0.06694484169461898, 0.02015216096437403, 0.1388435454240867, 0.03220572828182152, 0.10293299558439425, 0.04445798422342964, 0.13026751418198856, 0.07783997670880385, 0.11256755502628428, 0.16332933652613843, 0.03143058005454285, 0.018366197423477258, 0.04778553691825696, 0.03808019948857171, 0.03401269417788301, 0.05328560607241733, 0.024884248917390193, 0.031168126102004732, 0.015379432156415922, 0.03109494949291859, 0.04745823876666171, 0.06889126010771308, 0.021342799932296787, 0.034487522805907896, 0.03330959279888442, 0.03234526561573148, 0.10528864525258541, 0.014246083596455199, 0.02691005083865353, 0.03029279557189771, 0.09422481964741435, 0.02485385224489229, 0.05100548752982702, 0.07377967744001321, 0.1640425989670413, 0.15530829264649323, 0.004618838762066194, 0.03490886591108782, 0.030212453633014644, 0.10526029605950628, 0.2567296139895916, 0.09670061072600739, 0.16790358535945415, 0.16343178174325398, 0.13097844246242726, 0.14127557777932712, 0.24819380630339893, 0.12087595170097691, 0.12881133731986794, 0.20578197496277945, 0.2033687380275556, 0.12491030379065446, 0.13317457533308438, 0.19932765487049306, 0.23179391345807485, 0.14863082952797413, 0.14879139805478708, 0.14040739222296647, 0.20928358206791536, 0.1286504023841449, 0.11884246367428984, 0.129483127700431, 0.17756141855248384, 0.10984923517597572, 0.14657484128006867, 0.2753438651561737, 0.0887227284588984, 0.08413299545645714, 0.17833874826984747, 0.19027488492429256, 0.16555113159120083, 0.10970281410430159, 0.13549311592110566, 0.09835964920265333, 0.1186515646321433, 0.1716401827122484, 0.15551179886928626, 0.11972426064312458, 0.09252944562051978, 0.16413524613848754, 0.13451179143573555, 0.09767805399107081, 0.13501001255852835, 0.096627715708954, 0.21379071021718637, 0.12025757559708186, 0.08821300616753952, 0.10793388688138553, 0.2010048305881875, 0.21555587835609913, 0.09359838933284793, 0.2434503851192338, 0.1645106795643057, 3.5200112547193254, 31.463190691811697, 74.15423951830182, 106.10992200034005, 106.3452227456229, 86.98168413979667, 86.8263988494873, 80.02323000771659, 81.1727955681937, 93.86160973140171, 78.73110825674874, 84.65519101279122, 84.14700671604702, 77.48328821999687, 58.737951687404085, 26.60440226963588, 8.191166179520742, 1.8794553663049425, 2.6608122161456516, 2.1168017046792165, 1.0847559124231339, 0.1682180320577962, 0.3782556158091341, 0.38438873099429266, 0.20425037214798586, 0.8611484968236515, 2.32191469839641, 1.0074966124125888, 2.667714600052152, 7.685725552695138, 3.83974346944264, 1.7242676764726639, 1.4040396426405226, 0.9612657959972108, 0.7009376936725208, 0.8468968729887689, 0.8076033443212509, 0.6993011757731438, 0.2524938184235777, 0.5863146728702954, 0.3243107518979481, 0.3831389509141445, 0.16664874340806687, 0.15613336408776896, 1.4832151255437305, 2.3692469128540585, 2.0396300171102797, 1.7532818338700702, 2.4756685623100827, 2.5205363375799994, 3.54003552879606, 2.4727286057812825, 0.55650516386543, 0.35328685705150875, 0.17142743484250136, 0.25636942046029226, 0.6702108596052442, 4.001614349228995, 22.300462245941162, 52.098871503557476, 75.15616975511823, 68.66819204602922, 101.74511923108781, 102.51075513022286, 69.99294948577881, 83.60863249642509, 62.530688422066824, 68.86801528930664, 67.8399737221854, 90.477128301348, 106.94340705871582, 51.62174218041556, 12.860851560320173, 0.34355359790580614, 0.25996256193944384, 0.19036017677613667, 0.250142151755946, 0.12018820217677526, 0.10032065611864839, 0.3190949617752007, 0.08703421442104237, 0.16325894530330384, 0.12691175139376096, 0.20506412562515053, 0.12321885169616767, 0.2404452892286437, 0.1807191033980676, 0.1739219467022589, 0.1452261172235012, 0.22824460534112795, 0.17819597093122347, 0.26433395594358444, 0.20003646612167358, 0.16004323214292526, 0.17065832896956376, 0.12491247510271412, 0.12650096629347118, 0.11545350695294992, 0.14113077840634755, 0.12703675111489637, 0.10229911495532308, 0.15798020070152624, 0.11233008134045772, 0.11383247322269849, 0.14961560097123894, 0.1649875132633107, 0.21490738886807645, 0.12433493323624134, 0.09476960862853698, 0.17379516921937466, 0.1425292526504823, 0.1722437803234373, 0.11247666526053633, 0.0910486922200237, 0.06358997457261596, 0.18350348541779177, 0.20740878981138977, 0.24922471812793187, 0.3541235721537045, 0.12000408848481518, 0.16389823385647365, 0.12597531878522464], [0.03072412671255214, 0.02077380591072142, 0.029739589363868748, 0.018881797524435178, 0.08952142524399928, 0.028335965038942437, 0.027427162376365492, 0.08293322340718337, 0.06540436364178147, 0.06449606309511832, 0.011846375801334423, 0.047043494414538145, 0.04756505374929734, 0.027934838884643147, 0.005462035145943186, 0.04708489862137607, 0.08881809655576944, 0.031200190274310962, 0.012859059630760124, 0.0056286914041265845, 0.04244901166696634, 0.038744264747947454, 0.021417387894221714, 0.01719073558758412, 0.0552657816026892, 0.028555294698370353, 0.042473730697695694, 0.01351903671664851, 0.01665862164060984, 0.11566260430429663, 0.02821455816073077, 0.043323002090411525, 0.05672309501096606, 0.0681954360167895, 0.06036942345755441, 0.05073483348158853, 0.006690605917745935, 0.035052494811160226, 0.009182112291455269, 0.12214397080242634, 0.017008148599416018, 0.07490004053605454, 0.05178370952074017, 0.052402655594050884, 0.03213724034971424, 0.037578483910432885, 0.07188024757696049, 0.016979639950607504, 0.03179100089307342, 0.04859312590477722, 0.022207465588248203, 0.0855152052161949, 0.013740903248877397, 0.042261179603104077, 0.09275653772056103, 0.07872273719736508, 0.7452617181198937, 11.662744147436959, 51.393511227199006, 84.75338295527867, 84.10000215257917, 66.33552197047642, 64.15356527056012, 58.36147049495152, 54.49618067060198, 55.26434918812343, 49.73438215255737, 55.193321228027344, 51.29310628346035, 25.08126507486616, 15.697771515165057, 11.944952181407384, 6.59464384828295, 1.1103332085268838, 0.41999292905841557, 0.594733826816082, 0.8287822678685188, 1.5318978961024965, 1.5405757618801934, 1.037735064114843, 0.2737902913774763, 0.40766188502311707, 1.3478980894599641, 1.1018200367689133, 1.1874721092837197, 1.9151456568922316, 2.5097601158278326, 2.0011951880795613, 1.859492106097085, 0.9424659247909273, 0.8186460946287427, 0.6979083333696637, 1.1074477519307817, 2.7546962755067006, 4.404014493737902, 5.191862915243421, 5.151475642408643, 5.094107406479972, 2.8349974751472473, 2.1455726751259396, 1.5535433803285872, 1.5314019684280669, 1.1513155294316155, 1.118487570966993, 1.1661970508950097, 2.6435848091329848, 2.5000450142792294, 6.634682408400944, 14.57757077898298, 24.437535320009502, 43.81081703730992, 61.53996562957764, 64.37637315477643, 54.354173387799946, 46.01519904817854, 58.674188068934846, 53.969128540584016, 51.53963879176548, 58.333066259111675, 48.61078201021467, 49.94002798625401, 66.39980670383999, 76.75566591535295, 47.839636189596995, 11.93042436667851, 0.4188684879669121, 0.14506651221641473, 0.09714293413396392, 0.0528382106151964, 0.02338305295311979, 0.10375905090144702, 0.0336644903623632, 0.07137611641415528, 0.06378054791795355, 0.0289724105303841, 0.021058519204546298, 0.032604282788400135, 0.03498720277899078, 0.044896127855671306, 0.041929847560822964, 0.04884878772177866, 0.03702694011319961, 0.09182585908898286, 0.03218034089409879, 0.043690774855869155, 0.026660266831251125, 0.027975674818402956, 0.03534060078007834, 0.05468655018401997, 0.03655728870736701, 0.044446727327470265, 0.03453565468745572, 0.07509416940488986, 0.04987861728295684, 0.07563936550702367, 0.06700696157557623, 0.10521300216870648, 0.04481176220412765, 0.03311188126515065, 0.03595217117773635, 0.03713471183021154, 0.022612250742635558, 0.054701779902513535, 0.024294060854507343, 0.006348873629966485, 0.019779782642477324, 0.009058093901590576, 0.07694514508226089, 0.03676851326599717, 0.03411472209596208, 0.020622146548703313, 0.04701581357845238, 0.09835792572370597, 0.031702431717089245, 0.008692121798438686, 0.01320803867253874, 0.03891074670744794, 0.03882083063945174, 0.10215078720024653, 0.05388356845027634, 0.02083239740958171, 0.014427820719512445, 0.014579257861311947, 0.012402613364559199, 0.06527656835636922, 0.010327557434460946, 0.017647067351000648, 0.03215275505291564, 0.022738999387781535, 0.03760047523038728, 0.04967330276433911, 0.015123062966657537, 0.07438138193850007, 0.04716878929840667, 0.04562354453706315, 0.021052736389849867, 0.015702248584213, 0.02620443039839821, 0.04371250154716628, 0.02637104636856488, 0.04689559752919844, 0.049946891476533244, 0.06476564505802733, 0.00905280132844512, 0.049163414231900654, 0.06264493814004318, 0.07369953566896063, 0.10414885569896017, 0.03551373916811176, 0.04804575849058373, 0.07220679255468504, 0.03361095394939184, 0.052834617772272656, 0.03608485870063305, 0.02194794629966574, 0.06042606756091118, 0.06798278314194509, 0.0851011292210647, 0.08129889039056641, 0.08222517211522375, 0.055373868838484795, 0.05446351572339024, 0.03023540847269552, 0.0410646780926202, 0.02583694431398596, 0.0354059844144753, 0.03667526898373451, 0.060020256122308116, 0.044093845012996874, 0.1207340835992779, 0.14803897057260784, 0.4510630747037274, 5.442408442497253, 32.316359996795654, 77.05070727212089, 86.95740713391984, 84.10802732195172, 67.31107684544155, 63.714341844831196, 67.3193313053676, 65.31383105686733, 74.24173818315778, 69.47481536865234, 69.03457750592912, 66.77514839172363, 51.601443018232075, 42.51189994812012, 28.0483786378588, 12.49374088219234, 5.098152995109558, 1.1101990214415958, 0.39414736734969275, 0.7307456827589444, 2.3427315013749257, 0.9847684034279415, 1.230040356516838, 0.3074540149952684, 0.6243416209306035, 1.3536987496273858, 2.7780967227050235, 2.745575027806418, 3.6641208018575395, 3.70073607138225, 2.8350569690976823, 2.4563831857272556, 0.7719199476497514, 1.0020079697881425, 1.0809158384799957, 2.362561877284731, 3.503687330654689, 5.943301473345075, 6.1417984792164395, 9.272884317806788, 7.466714859008789, 4.330829552241734, 3.910590776375362, 3.0646063429968695, 2.4882389392171587, 1.521327514733587, 1.2949092813900538, 1.5794133692979813, 2.971954720360892, 3.7264092309134345, 9.286640013967242, 16.285861832754954, 24.38880239214216, 43.857696533203125, 65.71937656402588, 83.40771838596889, 71.1180226462228, 52.290638310568674, 58.65502493722098, 74.02258505140031, 73.21593393598283, 65.36356626238141, 61.22961739131382, 56.63679558890206, 73.91989762442452, 88.54161725725446, 67.28207506452287, 28.918904542922974, 3.9038527607917786, 0.5467589582715715, 0.046021142309265475, 0.06358581515295164, 0.024594504286402037, 0.05161262030846306, 0.11889372020959854, 0.03531498608312436, 0.04020880116149783, 0.06859711517712899, 0.04621286916413477, 0.022031236473204832, 0.0647342356720141, 0.07774304798138992, 0.1547112903956856, 0.05404315649398735, 0.039348035385566096, 0.04376447054424456, 0.019418517027848532, 0.041940866969525814, 0.018745006561013203, 0.024612629653087685, 0.00401136968451153, 0.08348255857293095, 0.1465701458177396, 0.11319214651095015, 0.029577327892184258, 0.040466915882591686, 0.0870782309877021, 0.0632142358060394, 0.018668718868866563, 0.12716441069330486, 0.12154884130827018, 0.09886338681514774, 0.08537607161062104, 0.04940800914274795, 0.02230402790675206, 0.0557521487187062, 0.04071234539151192, 0.07683297645832811, 0.06310841148453099, 0.018214227631688118, 0.016215543362445066, 0.029920649648244892, 0.04759761325216719, 0.08548945481223719, 0.13112263115389006, 0.19345469001148427, 0.09196691294865948, 0.03948410879820585, 0.03623476744230304, 0.12748083871390137, 0.1519123605851616, 0.2641683391162327, 0.13645743631890841, 0.10728697837995631, 0.11840490358216421, 0.13762169384530612, 0.13588568914149488, 0.21134712919592857, 0.14399772456714086, 0.08037037628569774, 0.11682578974536487, 0.19478760420211724, 0.14203006800796303, 0.12102445587515831, 0.1875875876950366, 0.15193349016564234, 0.13953008715595516, 0.08846354843782527, 0.1912927824471678, 0.16732449643313885, 0.12115231901407242, 0.13941785746387073, 0.10650624241679907, 0.16236644105187484, 0.1288847140967846, 0.13265948582972797, 0.14805564896336623, 0.10052858638976302, 0.18197418962206158, 0.13286057646785462, 0.1160674047257219, 0.14417414367198944, 0.18728528677352838, 0.1404540618615491, 0.18051099670784815, 0.09086779478405203, 0.2138063029519149, 0.26885967595236643, 0.22346553392708302, 0.08899697874273572, 0.10062461266560213, 0.18124221318534442, 0.17441195755132607, 0.1229251545986959, 0.13835033188973153, 0.13400013531957353, 0.10834196462695088, 0.1383025494537183, 0.14611866218703135, 0.12427128665149212, 0.1866935228130647, 0.11467043682932854, 0.13933627041322844, 0.20179805159568787, 0.17476655995207174, 1.388405544417245, 19.25087182862418, 71.95603098188127, 108.11501925332206, 103.79305907658168, 82.8006820678711, 80.87248052869523, 77.0420150756836, 74.11907468523297, 77.44750499725342, 71.68300151824951, 81.43559033530099, 89.58231149400983, 72.34811782836914, 63.9934092930385, 45.67368813923427, 26.4716534614563, 10.730506079537527, 2.1230335874216895, 0.9987363453422273, 1.49363959474223, 3.259299644402095, 1.8430151045322418, 1.0730467864445277, 0.13759413175284863, 0.23647993057966232, 1.0425218301159995, 1.4766107542174203, 1.3277757806437356, 2.479888290166855, 3.255540668964386, 4.703861832618713, 4.361321287495749, 3.1016013750008176, 3.5704556107521057, 2.910141808646066, 3.4772242477961948, 5.4772506185940335, 9.622698324067251, 9.402716619627816, 9.804023725645882, 7.214847436973026, 4.696757299559457, 3.834132364818028, 3.4284861087799072, 2.350262914385114, 1.6390098056622913, 1.537886157631874, 1.779114150575229, 3.4355669745377133, 4.504255286284855, 10.445470128740583, 20.604686634881155, 34.99399423599243, 62.515916551862446, 82.90525940486363, 88.91024698529924, 74.00580515180314, 57.72583886555263, 66.86904634748186, 65.80048288617814, 70.10081332070487, 79.13151904514858, 65.08664580753872, 66.00471128736223, 89.01005785805839, 104.40675176892961, 68.6708323614938, 19.134524243218557, 1.8888460738318307, 0.3888037683708327, 0.1672285380108016, 0.13228013047150203, 0.23848942560809, 0.2022667835865702, 0.14778430280940874, 0.19360008649528027, 0.2096788151455777, 0.09627160696046692, 0.10021696918244873, 0.20557076058217458, 0.3326835483312607, 0.14684993294732912, 0.2922210395336151, 0.08102585468441248, 0.1685179445360388, 0.21627448765294893, 0.18376348646623747, 0.19047826901078224, 0.12552116172654287, 0.1213535860713039, 0.15130135337156908, 0.12213261212621417, 0.13585241378418036, 0.16616983339190483, 0.11991332764072077, 0.1784567047974893, 0.15416140561657293, 0.19030189061803476, 0.11792387653674398, 0.2886935259614672, 0.2629068339509623, 0.2565868230802672, 0.2507282703050545, 0.23398389880146298, 0.14964465584073747, 0.17067004048398562, 0.07583492608474833, 0.19412014287497315, 0.16832400565700872, 0.15801695015813622, 0.12407746990876538, 0.08114660677633115, 0.12108556473893778, 0.1676153979663338, 0.2091601158359221, 0.3134880912091051, 0.14760484386767658, 0.12330938183835574, 0.0793321430683136], [0.04985236476308533, 0.03660455206409097, 0.1511399977441345, 0.22721747974199907, 0.2754253979240145, 0.14873734595520155, 0.2216281560914857, 0.07093462081892149, 0.12642913657639707, 0.05541290156543255, 0.05467264021613768, 0.06185295885162694, 0.1261686198413372, 0.1361735372671059, 0.06629101892134973, 0.039522242466253896, 0.1281762828252145, 0.09003680651741368, 0.18139151803084783, 0.18556639472288744, 0.2634341370846544, 0.20507405937782355, 0.13983929556395325, 0.19025701231190137, 0.22691774368286133, 0.21362090004341944, 0.29340991431048935, 0.3863431561206068, 0.35224530579788343, 0.26013870963028496, 0.28439837215202196, 0.17871275677212647, 0.13409597160560743, 0.1441722980567387, 0.11809717438050679, 0.0043688677334492755, 0.12230110594204494, 0.11311967218560831, 0.08486721784408603, 0.07027587866676704, 0.06613655042435442, 0.09512675553560257, 0.06072302841182266, 0.08827384361731154, 0.05756193732044526, 0.012408179896218436, 0.08640712592750788, 0.08777168020606041, 0.09864160085895232, 0.10363397654145956, 0.08298288538519825, 0.10117461958101817, 0.0416699279365795, 0.11644974563802991, 0.2060346749744245, 0.04349285636895469, 0.03146379095103059, 0.2135026856724705, 1.068369454571179, 17.701972450528825, 51.77357421602522, 78.94883005959647, 74.95383126395089, 70.94933428083147, 63.07359981536865, 62.041834013802664, 50.544892992292134, 46.70171928405762, 42.10377665928432, 40.742853845868794, 37.156898975372314, 21.589597259249004, 9.518086246081761, 8.777227623122078, 8.816106268337794, 8.695676616259984, 3.2042039036750793, 1.780204257794789, 0.33157509352479664, 2.0225648071084703, 4.155550820486886, 6.423916620867593, 13.285951903888158, 22.261347361973353, 27.256994451795304, 32.274253913334434, 32.41784191131592, 27.535471303122385, 18.259754725864955, 22.640093667166575, 17.24939111300877, 10.50145263331277, 10.511672564915248, 19.95054153033665, 29.533311162676128, 36.95725638525826, 26.71551091330392, 27.21561619213649, 26.74018222945077, 19.100768157414027, 11.254076293536595, 9.06459035192217, 10.10427188873291, 15.003948722566877, 22.449714762823923, 29.75936038153512, 38.43565934044974, 43.10866682870047, 53.25220993586949, 68.89703096662248, 60.67082241603306, 58.64453315734863, 56.603263582502095, 42.26252562659127, 52.77311427252633, 60.814038685389924, 57.87186915533883, 55.326855182647705, 61.263997077941895, 60.444345882960725, 79.68423434666225, 61.654555320739746, 23.29420403071812, 1.8863505848816462, 0.09617822697120053, 0.3493427772607122, 0.05346949245514614, 0.0809374822835837, 0.180059336658035, 0.14129142835736275, 0.060262275992759635, 0.2410115131310054, 0.17138281437967504, 0.10601011118186371, 0.20854298823646136, 0.13135687501302787, 0.1316104299787964, 0.07454091909208468, 0.08736620124961648, 0.1064581342839769, 0.15754885599017143, 0.21374072932771274, 0.2550099076969283, 0.2927356947745596, 0.20930984137313707, 0.07256435336811201, 0.21918737063450472, 0.2659837459879262, 0.2601568400859833, 0.2984840806041445, 0.29222532787493294, 0.33402769906180246, 0.27178218056048664, 0.3124213255941868, 0.18896544804530485, 0.09371582338852541, 0.04915295461458819, 0.0065811802716260505, 0.11422854768378393, 0.07755058830870049, 0.01062790332694671, 0.037078505381941795, 0.017974730215168426, 0.10488100176943199, 0.07642425410449505, 0.06713561860046216, 0.12424425381634917, 0.09954430349171162, 0.22135075740516186, 0.22006090304681233, 0.12445352758680071, 0.2034162219081606, 0.1528204982834203, 0.165578354416149, 0.06489633768796921, 0.054643001806523116, 0.1448477796678032, 0.1406206829207284, 0.178424420101302, 0.2504600047000817, 0.24149004316755704, 0.17954913260681288, 0.21724260784685612, 0.14499219906117233, 0.013490925010825907, 0.12668326151158127, 0.09176962889198746, 0.07633285543748311, 0.15065998850124224, 0.07363291031547956, 0.13267153661165917, 0.07253358180501632, 0.11524605165634837, 0.11205451469868422, 0.2134042845240661, 0.17781034590942518, 0.22142220714262553, 0.2017133432839598, 0.2561619515929903, 0.3632051662674972, 0.5616568731410163, 0.43988526878612383, 0.45073469089610235, 0.3664193052266325, 0.41609314403363634, 0.5253905334642955, 0.3992568446057183, 0.21508838129895075, 0.27782999032310074, 0.13612952748579638, 0.06982857481177364, 0.23543452524713107, 0.15477957815996238, 0.12610196056110518, 0.09094725802008595, 0.17569630220532417, 0.13888082413801126, 0.11403596587479115, 0.11865442804992199, 0.12425721383520535, 0.054728476862822256, 0.047494981437921524, 0.0728778297613774, 0.130216189793178, 0.16122286527284554, 0.173550598057253, 0.11889351664909295, 0.258849058832441, 0.05292920216119715, 0.09698352590203285, 0.15527689004583017, 0.11326876668525593, 0.04426299022244556, 0.7619713214891297, 7.252795457839966, 43.287179946899414, 80.47147219521659, 88.58563409532819, 81.7969661440168, 71.34124047415597, 58.1847882270813, 52.642863341740195, 56.094975062779014, 67.1767612184797, 71.38597992488316, 62.83466516222273, 54.85557624271938, 43.27117477144514, 34.516274315970286, 33.12081895555769, 24.207985946110316, 20.75485805102757, 14.334378617150442, 12.999305708067757, 13.616445575441633, 15.313827957425799, 20.929085867745535, 24.46452907153538, 32.14164754322597, 42.29929549353463, 47.87869896207537, 52.65025969914028, 56.33603586469378, 50.91554812022618, 36.12577240807669, 32.9073737689427, 25.488012620380946, 26.01391656058175, 23.236789328711374, 36.8878994669233, 45.09543473379952, 57.716674191611155, 46.271174158368794, 47.66330827985491, 46.55675206865583, 39.21477474485125, 27.363953283854894, 24.56913767542158, 25.99924717630659, 29.888364110674175, 37.4950851712908, 46.24131427492414, 53.51838847569057, 57.56529031481062, 69.55500452859062, 81.0348321369716, 86.94326754978725, 85.13502665928432, 66.21615191868374, 52.14226300375802, 60.431929452078684, 70.26998111179897, 52.901843547821045, 51.14598512649536, 65.84514590672084, 61.45579515184675, 80.63600553785051, 78.81236743927002, 39.90568971633911, 6.7660850031035285, 0.6868186284388814, 0.339137393449034, 0.1906525982277734, 0.13921528761940344, 0.40103840615068165, 0.22037962451577187, 0.18245259752230986, 0.26017953029700686, 0.20079510898462363, 0.18102975030030521, 0.16316646098026208, 0.08172983476626021, 0.23937325818198069, 0.09053738894207136, 0.3050001338124275, 0.13145508617162704, 0.2588395322007792, 0.21539748114134583, 0.16013600145067486, 0.20553937155221189, 0.24107366693871363, 0.1781522597053221, 0.25804388203791206, 0.27382497808762957, 0.36893707726682934, 0.36543472377317293, 0.4806815896715437, 0.47531188066516605, 0.4119878171810082, 0.4860978733216013, 0.40054247847625185, 0.175646375598652, 0.1850359703281096, 0.12977263145148754, 0.1045770655785288, 0.03333452556814466, 0.026867175907162682, 0.032625615929386446, 0.09272227170211927, 0.027376499559198107, 0.08721623143979482, 0.07988135609775782, 0.227357380092144, 0.17113429414374487, 0.26168199681809967, 0.2504569377217974, 0.099100412667862, 0.3055230943220002, 0.20929693563708238, 0.16254752847765172, 0.07561704170491014, 0.09501899060394083, 0.23936750420502254, 0.16281792468258313, 0.2651476008551461, 0.25654339683907373, 0.25223421092544285, 0.2595217584499291, 0.38927863431828363, 0.17035438599331038, 0.2437387625021594, 0.16493779021714414, 0.15446560643613338, 0.16931979650897638, 0.22852408034460886, 0.14842830039560795, 0.19172975899917738, 0.11967297696641513, 0.24673625880054065, 0.22621786195252622, 0.39956620229142054, 0.4925499813897269, 0.41188752970525194, 0.3865799105593136, 0.3984879015811852, 0.4926113752382142, 0.5779221717800412, 0.5333120226860046, 0.632485072527613, 0.40239574760198593, 0.3556196061628205, 0.4967332312038967, 0.4144761679427964, 0.2631569691002369, 0.2572014672415597, 0.17320207533027443, 0.2589350427900042, 0.2990815442587648, 0.2880786103861672, 0.23715436724679811, 0.1321929930044072, 0.2728447121168886, 0.2470501491001674, 0.2680986853582518, 0.13701283080237253, 0.13032616674900055, 0.10960201772728137, 0.13428551357771668, 0.20637942504669937, 0.14366317966154643, 0.1847003126250846, 0.20886010836277688, 0.19434522651135921, 0.2923309893480369, 0.14581632055342197, 0.32754673968468395, 0.36472614322389874, 0.20628702214785985, 0.131439439154097, 0.35683681656207356, 1.9396002760955264, 27.01031082017081, 80.23591436658586, 112.56186635153634, 101.78020763397217, 89.79628126961845, 77.80955478123256, 76.26385852268764, 71.5351369040353, 70.82466970171247, 62.771693638392854, 59.46929822649275, 69.78147411346436, 67.30168288094657, 70.86935356685093, 64.12605735233852, 52.17888348443167, 40.92754391261509, 26.061848708561488, 25.61902437891279, 28.12607513155256, 27.358062948499406, 35.211643082754954, 43.634294578007285, 49.013013226645334, 59.42820658002581, 61.99951253618513, 71.77106993538993, 75.1007022857666, 65.48035158429826, 51.903244972229004, 53.66499546595982, 44.220684323992046, 37.62762205941336, 43.32466547829764, 58.80391093662807, 68.03229291098458, 77.63739231654576, 59.94818891797747, 61.58369064331055, 64.61267444065639, 54.52264983313424, 40.58983366830008, 37.98092406136649, 36.384908948625835, 40.92171089989798, 47.75436094829014, 62.73283931187221, 68.54354136330741, 71.52884183611188, 78.9319042478289, 93.78361620221818, 73.81627913883754, 73.10640253339494, 66.08875669751848, 52.31600618362427, 65.00066184997559, 75.78856699807304, 69.75805868421281, 65.03197738102504, 73.97667135511125, 72.9721633366176, 97.96701540265764, 81.68585750034877, 29.693244797842844, 2.73363042303494, 0.572018699986594, 0.3518716501338141, 0.3232902895127024, 0.3694598206451961, 0.4277053752115795, 0.34657549432345797, 0.2680700240390641, 0.3922100141644478, 0.3251199184783867, 0.2812832993056093, 0.26564757259828703, 0.29816193931869095, 0.4302314525204045, 0.2455254809132644, 0.4629655288798468, 0.2769339984016759, 0.22880396246910095, 0.26498233686600414, 0.41990105541689055, 0.3954325940992151, 0.24817176748599323, 0.20730664314968245, 0.3289446032473019, 0.41074387250202044, 0.5495134847504752, 0.6282357605440276, 0.59711119639022, 0.5069642907806805, 0.4884687289595604, 0.6216585306184632, 0.38686706657920567, 0.32841925429446356, 0.17449549878282206, 0.20400147193244525, 0.23146770096250943, 0.11974898645920412, 0.13837235713643686, 0.1458927643086229, 0.22409218815820559, 0.2354242115148476, 0.19474938910986694, 0.21559755397694452, 0.21910973265767097, 0.2983538561633655, 0.250860476068088, 0.38965139431612833, 0.2099968037967171, 0.29256174553717884, 0.18367572474692548, 0.21909617552799837, 0.1418941438730274, 0.10736066049763135], [0.062013547734490464, 0.13479740039578506, 0.10302070980625493, 0.15258582016187056, 0.17793245507138117, 0.19700341458831513, 0.06585086004010268, 0.13569926843047142, 0.1061574143490621, 0.08520236664584704, 0.08829421323857137, 0.10060646185385329, 0.1639734019658395, 0.05226011235000832, 0.11646582691797189, 0.2371600940823555, 0.09582125648323979, 0.22367913675095352, 0.1856777151780469, 0.15974664448627404, 0.2383563784616334, 0.2351342870720795, 0.1936060304620436, 0.4803561642765999, 0.2923125603369304, 0.389678779989481, 0.5191196756703513, 0.3171352983585426, 0.34683987870812416, 0.35475268268159454, 0.18736968295914785, 0.29352499384965214, 0.23158212910805429, 0.3754051716199943, 0.11459072253533772, 0.21323474576430662, 0.22482094833893435, 0.2031247911176511, 0.26776085634316715, 0.30789582271661076, 0.24953212163278035, 0.16308594601494925, 0.18821107995297226, 0.1409413449998413, 0.1345321067741939, 0.09047435982418911, 0.14597964393241064, 0.011687054930787002, 0.08952044136822224, 0.07716672069260053, 0.08360972960612603, 0.09787212857710463, 0.10145031514444522, 0.08136995336306946, 0.0641035780842815, 0.3015209590750081, 0.09168866609356233, 0.04145202659336584, 0.0816527803295425, 0.18175601347216538, 1.1895253019673484, 19.146669694355555, 69.05524144853864, 90.9085419518607, 81.99941580636161, 75.83887890407017, 67.21601854051862, 65.62734072549003, 58.54632731846401, 47.17791754858834, 29.951210566929408, 27.572055305753434, 38.9787791797093, 31.887169769832067, 21.63293317386082, 23.89830126081194, 13.595677409853254, 14.573634624481201, 10.337136421884809, 18.182958023888723, 21.23294448852539, 24.77777991976057, 29.609591960906982, 34.72834028516497, 44.62609086717878, 47.16049146652222, 35.84973784855434, 24.413371222359793, 26.876846347536357, 20.708353757858276, 16.80871377672468, 11.693551591464452, 23.445146696908132, 28.423659529004777, 36.84387220655169, 26.4640052318573, 23.060920000076294, 30.277900968279155, 35.671797956739155, 29.521207400730678, 32.998627935137065, 30.887664454323904, 27.062239919389995, 36.76552779333932, 43.62820448194231, 41.4894551549639, 42.96524906158447, 55.698357990809846, 57.92632218769619, 52.00067956107003, 37.13550199781145, 47.67816005434309, 54.093741008213584, 61.81773376464844, 64.70819132668632, 59.53959315163748, 64.55141912187848, 77.22931071690151, 82.25394221714565, 68.81778676169259, 23.114820650645665, 1.2466806407485689, 0.1047295323972191, 0.06253775674849749, 0.2773630768060684, 0.067444854149861, 0.336542404123715, 0.20751198141702584, 0.09666386805474758, 0.14522128605416842, 0.1925791355648211, 0.09776228732828583, 0.1098070777952671, 0.16862108185887337, 0.2600660521004881, 0.046805125062486956, 0.13286612688430718, 0.16563341074756213, 0.16919239477387496, 0.2335131854883262, 0.2435603892164571, 0.35823793709278107, 0.35367864317127634, 0.41457843674080713, 0.37783025577664375, 0.3011270287845816, 0.2850084294165884, 0.3148843262876783, 0.3340438481952463, 0.3253739619893687, 0.29457514892731396, 0.47413888360772816, 0.2646302043327263, 0.339159296559436, 0.2676100587206227, 0.3508480122046811, 0.1842036521328347, 0.15424804096775396, 0.1424498911947012, 0.018984805925616195, 0.03858161651130233, 0.048391994554549456, 0.09729143152279512, 0.05256556845935328, 0.10176403581031732, 0.15510182801101888, 0.024215669703802893, 0.21978773841900484, 0.2578870861658028, 0.20713053617094243, 0.29022587516478127, 0.2575196187411036, 0.1509192567318678, 0.22667162546089717, 0.1368291920849255, 0.1432072584118162, 0.12436404238854136, 0.12198136667055742, 0.11751980893313885, 0.13099817426076957, 0.10458026826381683, 0.12558630108833313, 0.0992980156359928, 0.09542570449411869, 0.07702068638588701, 0.04089171951636672, 0.08927015694124357, 0.08862953845943723, 0.15746213921478816, 0.10083480245832886, 0.09052670201552765, 0.1278671965535198, 0.1650837023875543, 0.1937633827328682, 0.12899466391120637, 0.1676789495561804, 0.23087173008493014, 0.19181009754538536, 0.2718407245618956, 0.46204907234225956, 0.422280949141298, 0.6084888715829168, 0.49878924659320284, 0.4593754272375788, 0.38732513199959484, 0.33204320126346176, 0.14565744836415562, 0.3346679375639984, 0.2531640753149986, 0.3989882261625358, 0.14706185300435337, 0.2738833049578326, 0.3305856537606035, 0.2036036332803113, 0.21320862216608866, 0.34730671080095427, 0.2828179826693875, 0.16818524524569511, 0.23136727777974947, 0.14030287068869385, 0.09721566630261284, 0.19914146486137593, 0.12564674498779432, 0.10869848728179932, 0.08775591105222702, 0.17491575623197214, 0.09260869172534772, 0.070775524713099, 0.12111843297524111, 0.2562489669237818, 0.058614440129271576, 0.13225245981344155, 0.3326665849557945, 0.014316213583307607, 0.060679941438138485, 1.3068368413618632, 9.363002453531537, 50.18202679497855, 90.3732249396188, 94.28447709764752, 83.98718425205776, 81.04335062844413, 64.54476274762834, 51.01464680262974, 40.71416473388672, 40.63072381700788, 49.91201979773385, 56.560935156685964, 78.44334166390556, 67.62414877755302, 55.38978154318673, 55.522085666656494, 38.27911295209612, 43.556544235774446, 34.96333530970982, 45.46027421951294, 48.36933210917881, 57.56152091707502, 64.24612917218889, 62.94624628339495, 73.17500904628209, 77.36920574733189, 73.44356387002128, 57.301616600581575, 57.21694237845284, 57.05408355167934, 48.7584798676627, 39.15272385733468, 54.081831795828684, 56.170988355364116, 62.459601402282715, 48.29464244842529, 30.934078420911515, 41.65304701668875, 56.70060437066214, 50.96952172688076, 58.29942308153425, 56.1212739944458, 58.43832451956612, 59.69942256382534, 74.55572727748326, 70.49998732975551, 61.71012006487165, 70.49128818511963, 76.15714114052909, 71.76377432686942, 41.36883790152413, 45.67598451886858, 56.7757282938276, 53.08629042761666, 58.044323444366455, 58.18844297954014, 65.56615488869804, 74.57686369759696, 82.20746571677071, 80.47414030347551, 40.96496343612671, 6.512262097426823, 0.7892672653709139, 0.6683898344635963, 0.23675598576664925, 0.019330056417467337, 0.335620465023177, 0.2796990286026682, 0.10983879252203874, 0.14307559547679766, 0.12582484685948916, 0.15388397978884832, 0.06228354360376086, 0.22014512281332696, 0.28835751542023247, 0.1677761022001505, 0.16561681378100598, 0.24968044938785688, 0.21025954612663814, 0.283965493951525, 0.3983986335141318, 0.3653666802815029, 0.28686775107468876, 0.32791124869670185, 0.2758138727928911, 0.15868830627628736, 0.341378567474229, 0.2327005990913936, 0.19473285999681267, 0.4360739918691771, 0.5340318126337869, 0.5462875121406147, 0.3596294495676245, 0.4292056975620133, 0.29741025822503225, 0.42570318121995243, 0.37182391807436943, 0.23020768857428006, 0.11923057213425636, 0.06678622734865972, 0.06712923358593668, 0.034352806463305435, 0.08331250412655727, 0.0469007408246398, 0.056692119887364764, 0.12515961112720625, 0.13673630064087255, 0.2253740629447358, 0.2505953588656017, 0.21945102220135076, 0.24269072445375578, 0.21220399678817817, 0.17628522988940987, 0.22660717820482595, 0.1656664011201688, 0.14334798657468387, 0.29263440306697575, 0.31123473069497515, 0.2089774270675012, 0.2442814005272729, 0.1933500599116087, 0.323725339025259, 0.11243542390210287, 0.1693027109972068, 0.24761048331856728, 0.14603502596063273, 0.16836380852120264, 0.22903965839317866, 0.2486818086888109, 0.26235062522547586, 0.268169171575989, 0.40999618119427134, 0.2509707515793187, 0.2857211354587759, 0.3731115875499589, 0.19841930004102842, 0.3555131304476942, 0.38915085260357174, 0.3559778726526669, 0.6912585816213063, 0.5965574032494, 0.5185745134949684, 0.6013393923640251, 0.4083712255316121, 0.6151952402932304, 0.41405083505170687, 0.21323678136936255, 0.588421279830592, 0.4439399769263608, 0.6898755644048963, 0.41489778246198383, 0.4330350506518568, 0.5182276463934353, 0.3803941681981087, 0.4133233369461128, 0.4640331087367875, 0.26097849171076504, 0.24102725514343806, 0.3894818148442677, 0.1750708964786359, 0.20622466477964604, 0.4405462976012911, 0.23053406391824993, 0.26384733776961056, 0.15918084127562387, 0.18148014827498368, 0.2493542640336922, 0.1886058651975223, 0.22270804457366467, 0.33925469858305796, 0.20831709035805293, 0.48182451405695503, 0.39595965296030045, 0.1665312075721366, 0.24014068128807203, 0.4723421771611486, 2.970190095049994, 34.50729724339077, 95.5530583517892, 115.75129100254604, 104.70301600864956, 96.86848436083112, 82.0759780066354, 77.60734830583844, 75.8850427355085, 75.21201242719377, 62.72882325308663, 63.939532961164204, 91.7197858265468, 75.92778805324009, 69.15423243386405, 68.93653842381069, 63.11879784720284, 74.22207478114537, 66.74270030430385, 77.7976108278547, 65.09506007603237, 71.40940925053188, 81.1910901750837, 71.80287878853935, 75.84436798095703, 82.32362570081438, 65.35971001216343, 56.54765714917864, 67.92977918897355, 59.19210679190499, 52.33645473207746, 52.672097887311665, 69.64460849761963, 71.89011342184884, 76.1563698904855, 63.88115419660296, 56.1846068246024, 64.73374680110386, 77.20414434160504, 62.20019735608782, 71.12809753417969, 75.67930657523019, 72.03315598624093, 84.36185196467808, 86.84683350154332, 81.59210545676095, 70.18906933920724, 81.09057753426688, 75.62348474775041, 68.19173322405133, 51.14213235037667, 58.99950967516218, 71.54784515925816, 74.58057403564453, 75.08359582083565, 68.22893387930733, 72.63926124572754, 91.15467493874687, 100.19438552856445, 82.24940504346574, 31.387688091823033, 2.613370133297784, 0.32191207632422447, 0.7541526438934463, 0.2257482750075204, 0.11929191169994217, 0.38359652778932024, 0.3701373242906162, 0.4064756158207144, 0.29995416743414743, 0.21450803029750073, 0.2639023805303233, 0.1757200373602765, 0.3564205488988331, 0.4920970999768802, 0.3822754201080118, 0.3162655793130398, 0.2554624362715653, 0.395127823310239, 0.3858034222253731, 0.5069164676325661, 0.4021264777651855, 0.3406711540051869, 0.3916199058294296, 0.37133618710296495, 0.41673207974859644, 0.3969147045697485, 0.42372199467250277, 0.49154574956212727, 0.6559263946754592, 0.5914836983595575, 0.592242246227605, 0.46073857694864273, 0.5690865058984075, 0.3379836939275265, 0.3815913482436112, 0.3743608519434929, 0.3514795926000391, 0.14580574897783144, 0.13870957547000476, 0.1344805381127766, 0.22906859112637384, 0.2402320663843836, 0.18548365416271345, 0.24656059965491295, 0.3703983160001891, 0.2633587382733822, 0.2222674853567566, 0.24251343682408333, 0.25197273067065645, 0.2709414213895798, 0.35860106189336094, 0.3093129295323576, 0.26582784578204155, 0.21036884454744204, 0.2545864204210894], [0.1055575893925769, 0.06229007111064025, 0.18432722693043097, 0.038869339107934914, 0.02262878494470247, 0.14323514620108263, 0.1857901212892362, 0.028864509891718626, 0.08376389276236296, 0.13536584989300796, 0.05697718262672424, 0.06120565001453672, 0.13537534938326903, 0.05555456949930106, 0.05962936566876514, 0.17284750007092953, 0.06220858584025076, 0.11669403181544372, 0.19076457007655076, 0.17312579442347797, 0.05048070176105414, 0.2154643711234842, 0.2737310416996479, 0.08522208487348897, 0.14246407257659094, 0.3336812119398798, 0.22772642171808652, 0.19172070734202862, 0.3392434077603476, 0.18717362705085958, 0.13366377194012913, 0.2285015529819897, 0.22923792632562773, 0.08328364603221416, 0.14225120257054055, 0.24208533551011766, 0.20873681854988846, 0.1568819239203419, 0.1953101847320795, 0.204671104571649, 0.026852953813171813, 0.060421175323426723, 0.14589022658765316, 0.056697229256055186, 0.1442667365606342, 0.19072110312325613, 0.12057848194880144, 0.06028785676296268, 0.060460611778710566, 0.054071973876229355, 0.040334187647593875, 0.11154099939657108, 0.032857301711503945, 0.10385930445045233, 0.0692518607580236, 0.10185536662382738, 0.01994791513841067, 0.15297254441039904, 0.16020849613206728, 0.015927186335570047, 0.10413740881319557, 0.21112733813268797, 2.014832547732762, 21.45976322037833, 67.41555690765381, 95.76670851026262, 96.95741435459682, 81.24914237431118, 70.47243772234235, 63.66756657191685, 59.624291692461284, 52.9537535394941, 44.184824671064106, 32.8881515775408, 31.402022225516184, 18.209493194307598, 23.480546031679424, 30.25232117516654, 32.20332670211792, 28.30857651574271, 30.99605287824358, 36.140328884124756, 49.663663387298584, 53.45673016139439, 35.219831534794395, 48.540890080588206, 35.692514010838096, 49.0160356930324, 35.46882023130144, 27.618274722780498, 29.551536287580216, 34.74037109102522, 21.7920868737357, 24.011619431631907, 30.409301825932094, 56.13324921471732, 89.39232689993722, 38.550238609313965, 35.544916902269634, 29.58356053488595, 37.382333278656006, 26.655827624457224, 35.8010379246303, 43.52304697036743, 26.530914647238596, 44.02669409343174, 39.07276051385062, 35.59939425332205, 40.52215473992484, 54.756758962358745, 72.34223965236119, 69.12871864863804, 81.38427094050816, 85.29024246760777, 75.90169061933244, 83.35953262874058, 67.0336491721017, 63.61032036372593, 27.611017329352244, 3.061944531542914, 0.47302776894399096, 0.14713365558002675, 0.29237189143896103, 0.15189197739320143, 0.0814857589347022, 0.12047001134072031, 0.23570232944829123, 0.029477243976933614, 0.11288660219205277, 0.2169068551489285, 0.0163774061948061, 0.10422826465219259, 0.1137990350169795, 0.04997399216517806, 0.057222568030868254, 0.18683712796441146, 0.0914645256208522, 0.04630743319700871, 0.13587947376072407, 0.2348343745938369, 0.2310625341321741, 0.2270940270807062, 0.2573135069438389, 0.3500851217125143, 0.12923434962119373, 0.3970127935920443, 0.3295492593731199, 0.13982976893229143, 0.12684396574539797, 0.24230672791600227, 0.21913338638842106, 0.226457235536405, 0.1926420493317502, 0.1391505825200251, 0.175935350092394, 0.22963649779558182, 0.2705093302897045, 0.20745457735444817, 0.014358386231054152, 0.20124280638992786, 0.09525590110570192, 0.09479237347841263, 0.17202892899513245, 0.04312865948304534, 0.05020521315080779, 0.05094242448519383, 0.05968976207077503, 0.03744829339640481, 0.21041571774653026, 0.23707723138587816, 0.14926910027861595, 0.11334048783672707, 0.2351765733744417, 0.19077431383941854, 0.037579827409769805, 0.3463915027678013, 0.08001766021230391, 0.012920634987364923, 0.15381798547293457, 0.09191115094082696, 0.07025413840476956, 0.0820759419085724, 0.13353794440627098, 0.039766579533794096, 0.1335564005587782, 0.15894043631851673, 0.004248162714897522, 0.057202890515327454, 0.05792196121598993, 0.020392783052687134, 0.06968477288527147, 0.08550092883940254, 0.024867831762613993, 0.09794912873102085, 0.08990201553595917, 0.14023245232445852, 0.13523592400763715, 0.11176842397877149, 0.19932863196091993, 0.1087880606896111, 0.22772845732314245, 0.2519190178385803, 0.07995942833700351, 0.19678854968930992, 0.30912646810923305, 0.1795939023473433, 0.13203003603432859, 0.21913543556417736, 0.24434968829154968, 0.20835928166551249, 0.1860151913549219, 0.20073963196149894, 0.16607126939509595, 0.20025773639125483, 0.14064781075077398, 0.09327628875949553, 0.07611206014241491, 0.1326602322182485, 0.08779663672404629, 0.05342482788754361, 0.10336294929896082, 0.21472702068941935, 0.06327032351068088, 0.04766404183049287, 0.055935899394431284, 0.0574052839406899, 0.034161469766071866, 0.11417020724288054, 0.08791931585541793, 0.08745275517659527, 0.16580182313919067, 0.034701739703970294, 0.06663148065230676, 0.006663724480729018, 0.2283549622765609, 0.04811421249594007, 0.13139623004410947, 1.0421758315392902, 13.147290178707667, 47.762382643563406, 88.45001915522984, 100.63257367270333, 95.23327445983887, 81.85941655295235, 76.79845292227608, 68.99466010502407, 55.535763195582796, 47.44284888676235, 44.181409631456646, 36.506686551230295, 43.05577366692679, 49.80627863747733, 55.17440128326416, 61.04421860831124, 70.84711933135986, 69.25066648210797, 60.24796199798584, 65.85714544568742, 70.62987695421491, 65.35053144182477, 43.19361203057425, 55.82354021072388, 36.756616728646414, 47.12111949920654, 47.19005257742745, 36.225934164864675, 39.84785638536726, 44.545846121651785, 43.31157159805298, 49.861099924360005, 48.64608580725533, 78.01604829515729, 113.18220846993583, 56.56479140690395, 57.189754077366416, 43.12036412102835, 56.93791661943708, 50.2955881527492, 56.043012959616526, 67.18470995766776, 48.24736343111311, 65.8085914339338, 53.55958781923567, 49.265656675611226, 45.105325494493755, 52.39761972427368, 60.08472796848842, 58.82596451895577, 68.35695443834577, 82.86242376055036, 79.4377886908395, 83.510621207101, 78.47659574236188, 82.09932395390102, 45.69302845001221, 8.19388553074428, 0.8707429277045386, 0.5776251905730793, 0.2653741772685732, 0.05493318069992321, 0.1100748616403767, 0.2318477619971548, 0.18592236776437077, 0.005978454577936125, 0.24101219166602406, 0.12333311699330807, 0.0615032147616148, 0.04699417170403259, 0.12835673242807388, 0.06720688513347081, 0.01830941591677921, 0.14794226576175007, 0.10350822364645344, 0.05074015998148492, 0.058108884042927196, 0.19241757637688092, 0.04650185044322695, 0.15994869864412717, 0.228828525436776, 0.21834159030445985, 0.06197755823710135, 0.22175045524324688, 0.16230991908482142, 0.119737302086183, 0.1048923468749438, 0.17155927419662476, 0.13669092021882534, 0.20326679492635386, 0.22811462517295564, 0.2541037920330252, 0.15665964941893304, 0.288394102028438, 0.2178634266768183, 0.19877903216651507, 0.02931482983486993, 0.17567191565675394, 0.06554544464285884, 0.06584024096706084, 0.08002909352736813, 0.06293512721146856, 0.046071150340139866, 0.047242488379457166, 0.11065201674188886, 0.04882104581754122, 0.15275750309228897, 0.08605495946747915, 0.08637096679636411, 0.07993450574576855, 0.14595771368060792, 0.15906832659883158, 0.04588960151055029, 0.253059770911932, 0.15847072723720754, 0.13852316832968167, 0.23857378108160837, 0.2063514965453318, 0.1352922288434846, 0.29608103526490076, 0.23166890016623906, 0.12826126255095005, 0.251805811056069, 0.19590485282242298, 0.10745982160525662, 0.12144061497279576, 0.12887076341680118, 0.10710385534912348, 0.16405154205858707, 0.2786012132252966, 0.1008087263575622, 0.1866350873772587, 0.2087429796478578, 0.25666507173861774, 0.23369033741099493, 0.29833580713186947, 0.3170567240033831, 0.21339726847197327, 0.2864595444074699, 0.4716040939092636, 0.20231020982776368, 0.3392931579479149, 0.47512894762413843, 0.3700007487620626, 0.3852002317351954, 0.3889568458710398, 0.45816535502672195, 0.2664640944983278, 0.25559738331607407, 0.33562068215438295, 0.25813350294317516, 0.3363612624151366, 0.3075511540685381, 0.21071812723364147, 0.13496000452765397, 0.286039694079331, 0.09318039140530995, 0.20821642290268624, 0.2447123516883169, 0.34144742520792143, 0.20048759691417217, 0.14235674190734113, 0.13278055004775524, 0.19033868078674587, 0.14363811457795755, 0.19283634104898997, 0.17346675827034883, 0.19104671850800514, 0.23683987983635493, 0.17817900755575725, 0.10985053117786135, 0.3523967005312443, 0.27831761272890226, 0.19698642407144817, 0.26719626092485016, 0.5107901969126293, 4.283203993524824, 30.478610106876918, 85.21190152849469, 118.83708327157157, 128.8759100777762, 106.0030517578125, 91.0906264441354, 86.12665271759033, 81.32264736720494, 82.97938278743199, 78.58133288792202, 69.39725957598004, 73.06304577418736, 69.83664281027657, 69.32763167790004, 69.36689594813755, 89.47987420218331, 76.1665073122297, 75.16753700801304, 89.27187987736293, 91.92873900277274, 98.6338757106236, 70.25698103223527, 89.24410792759487, 70.70611258915493, 93.37128925323486, 82.18681567055839, 72.15973826817104, 71.27771309443882, 82.38160146985734, 64.89015769958496, 71.68033340999058, 70.10338415418352, 102.76323877062116, 130.10311480930872, 78.62647533416748, 80.99433108738491, 67.52925722939628, 86.44055148533413, 72.21090480259487, 75.47347314017159, 79.20436395917619, 56.64321225030081, 78.62864317212785, 70.83184024265834, 63.44290351867676, 63.378528458731516, 74.82321902683803, 84.96807534354073, 79.01910414014543, 87.11813286372593, 97.06470843723842, 93.09932286398751, 106.37580176762172, 89.96528230394635, 80.06245258876255, 34.01189068385533, 3.3693080842494965, 0.6644359294857297, 0.7016882619687489, 0.24765222679291451, 0.16951898724905082, 0.288322421589068, 0.36889215824859484, 0.30962177153144566, 0.18133829374398502, 0.45040386436241014, 0.33064742758870125, 0.15050604247621127, 0.13512167228119715, 0.218377946210759, 0.18812097050249577, 0.216880894399115, 0.24079432764223643, 0.20179016701877117, 0.23968220874667168, 0.26741089512194904, 0.22806140088609286, 0.28423215821385384, 0.2488394459443433, 0.30835597802485737, 0.34290841966867447, 0.16606271985386098, 0.4702525607177189, 0.36843705124088694, 0.2308639676443168, 0.1675863838089364, 0.2701473725693566, 0.41753456954445156, 0.2931899061160428, 0.2720943609518664, 0.37830134906939095, 0.2770483451230185, 0.24658307273473057, 0.31083838481988224, 0.2838703633419105, 0.10347573538976056, 0.20511702421520436, 0.10941892183784928, 0.3411361404827663, 0.24897319876721927, 0.13601428509822913, 0.13796698674559593, 0.21823634952306747, 0.2103086042084864, 0.30059828715665, 0.23870226847273962, 0.31667584872671534, 0.2545520051249436, 0.12159776368311473, 0.3100194473351751, 0.2683756633528641, 0.13645218445786408, 0.3726908958383969], [0.12861931190959044, 0.13014974764415196, 0.05876842008105346, 0.09356473399592297, 0.11057927100253956, 0.0659527081464018, 0.0401365711087627, 0.033294088273708305, 0.05206404626369476, 0.08429842907935381, 0.04409267454008971, 0.032045095294181786, 0.05539411632344127, 0.024686291414712156, 0.1131333378808839, 0.0052463241985866, 0.07623741270176002, 0.10899070517293044, 0.06259260273405484, 0.062391315320772786, 0.0772847111469933, 0.11901519154863698, 0.13882835981036934, 0.18146498980266706, 0.03990838656734143, 0.1534175141049283, 0.08784304851932184, 0.14169511598135742, 0.22518731653690338, 0.2789346996162619, 0.20891802811196872, 0.09875753535223858, 0.3194099377308573, 0.13689153588243894, 0.14955496708197252, 0.14783990196883678, 0.14367556971098694, 0.18254086135753564, 0.0825697389830436, 0.14443794451653957, 0.11090179905295372, 0.10896988093320813, 0.07396396076572792, 0.15387524025780813, 0.0851675510140402, 0.1921420233058078, 0.08788039508674826, 0.087823296364929, 0.05197420822722571, 0.03728554677218199, 0.039521438402256796, 0.01533870818093419, 0.0326313631209944, 0.031536512941654236, 0.04608390001314027, 0.020239437531147684, 0.08473606381033148, 0.04437831403421504, 0.05699282964425428, 0.0954811747318932, 0.0561684808427734, 0.16465961800089904, 0.04952874766396625, 0.02732292582680072, 0.37342097237706184, 8.859425680977957, 34.150430815560476, 71.07594435555595, 94.46299021584647, 90.62915488651821, 77.06320708138603, 62.652149881635395, 56.88007286616734, 53.44633565630232, 47.87201132093157, 52.13063866751534, 52.092201232910156, 52.45413637161255, 46.70964023045131, 38.35897554670061, 50.25858899525234, 40.018128940037315, 50.09123815808977, 57.542965752737864, 60.756834166390554, 60.86423247201102, 66.41573892320905, 61.15987137385777, 48.59458575929914, 46.67624371392386, 48.397760663713726, 39.18328898293631, 42.72109631129673, 37.43940578188215, 39.41992725644793, 41.732301643916536, 36.825330938611714, 35.209464822496685, 39.650426796504426, 42.838037967681885, 38.69745009286063, 40.35911178588867, 45.41162988117763, 42.593815735408235, 41.54270962306431, 45.59612192426409, 51.85168586458479, 60.27607440948486, 63.960926464625764, 70.98984227861676, 74.9392956324986, 93.21379443577358, 90.80350603376115, 72.71243272508893, 59.22810540880476, 30.87977477482387, 6.856763771602085, 1.3483041248151233, 0.24595941762839044, 0.06424055394849607, 0.11069650149771146, 0.12759575540465967, 0.05611932776602251, 0.15318896993994713, 0.16710079700819083, 0.05543861464996423, 0.08706227184406348, 0.09392579605004617, 0.02630136930383742, 0.08991232926824264, 0.18217306823602744, 0.02709536044858396, 0.08206910227558442, 0.13494636597377913, 0.01026318990625441, 0.023300127492153218, 0.31640188342758585, 0.04597737001521247, 0.04840964664305959, 0.06174806412309408, 0.10328734014183283, 0.057241092036877356, 0.0872750807819622, 0.1750262217330081, 0.2941770117197718, 0.1282153393008879, 0.16036800614425115, 0.1692133615059512, 0.07529781133468662, 0.10568419045635633, 0.023149458791262338, 0.126012882483857, 0.07408503855445556, 0.16042220752154077, 0.21279690068747315, 0.14443198697907583, 0.1442533287086657, 0.22323477773794106, 0.13443781754800252, 0.09132885932922363, 0.1317251566797495, 0.09594315529933997, 0.026037775412467972, 0.06867652413036142, 0.03679319158462541, 0.06903276858585221, 0.02776486925514681, 0.06102857951607023, 0.04360456019639969, 0.09871388519448893, 0.115804594542299, 0.10169136470982007, 0.15388252772390842, 0.2709907373147351, 0.12350579058485371, 0.1690758088869708, 0.05696325230279139, 0.03831171902960964, 0.08567516306149107, 0.06125743580715997, 0.1398533276681389, 0.14268952262188705, 0.055862084962427616, 0.05799775357757296, 0.03713274747133255, 0.020483942536105002, 0.0673737640359572, 0.024706856114789844, 0.051890066492238214, 0.022246642503887415, 0.047665368366454325, 0.035398581597421847, 0.09447304132793631, 0.06042283094887223, 0.12480291883860316, 0.08021066271300827, 0.07198442984372377, 0.06884871596204382, 0.18596856242844037, 0.1421224030533007, 0.09743747261485883, 0.12350064728941236, 0.06023195226277624, 0.12804428062268666, 0.14158496260643005, 0.2762521521321365, 0.28708203243357794, 0.13185148632952146, 0.2788535196866308, 0.1231337905462299, 0.13628678476171835, 0.14548258988984994, 0.05141699526991163, 0.07583795913628169, 0.08528375013598374, 0.11671773982899529, 0.040070498761321814, 0.09829905602548804, 0.012812448515822845, 0.07857277417289359, 0.07398251869848796, 0.09731489526373999, 0.09656885958143643, 0.07310883700847626, 0.053231272380799055, 0.06780022329517774, 0.024256356359858598, 0.014195088297128677, 0.005494654444711549, 0.020965264744258354, 0.03163918886067612, 0.09355775865593127, 0.08233769357736621, 0.031033063706542765, 0.06093015122626509, 0.057207321348999224, 0.09069626791668789, 0.17232102474996022, 0.33537638240626877, 0.9108131889786039, 4.73639850957053, 28.68158882004874, 62.15240069798061, 87.31526715414864, 95.8036937713623, 87.08658109392438, 82.05971922193254, 76.4531830378941, 73.14429800851005, 67.75578934805733, 54.592989921569824, 52.05921466009957, 52.92722879137312, 45.482411180223735, 48.08132232938494, 40.60774959836687, 46.49114717755999, 49.57960408074515, 53.17148576463972, 60.43388189588274, 59.42890139988491, 64.77902821132115, 65.29865619114467, 65.23043877737862, 56.98736694880894, 54.97440433502197, 56.98610585076468, 47.30470827647618, 42.963268824986045, 47.81438643591744, 49.83387688228062, 55.301282337733674, 54.28469835008894, 47.8018935748509, 50.48372800009591, 49.376591614314485, 47.17514869144985, 46.72630548477173, 45.32235247748238, 45.99982615879604, 36.18926852090018, 41.527253355298726, 52.43983697891235, 54.5478891645159, 59.41401835850307, 72.48370497567313, 77.06272765568325, 94.44379929133824, 103.42507553100586, 92.61191368103027, 79.03645379202706, 53.96494919913155, 17.580983468464442, 5.080673933029175, 0.7732660525611469, 0.16559713626546518, 0.06557318993977138, 0.038466604825641425, 0.10177419347954647, 0.15145911276340485, 0.09026300295123033, 0.046700752805918455, 0.03714560231726084, 0.1178724571530308, 0.03869814472272992, 0.0955437288752624, 0.12482377700507641, 0.014898581530100532, 0.025189733864473443, 0.07154365349560976, 0.08997970779559442, 0.05802380932228906, 0.08741230091878346, 0.08204274119010993, 0.09820339615855898, 0.06873733443873269, 0.049094892373042445, 0.0843141507357359, 0.024338399725300924, 0.09538866326745067, 0.08241432732237236, 0.09405604763222591, 0.12607211859098502, 0.12467249083731856, 0.23097836864846094, 0.20400736161640712, 0.0961446123463767, 0.14821036851831845, 0.15528995863028935, 0.21696522273123264, 0.2521559622670923, 0.16098524230931485, 0.13238413631916046, 0.1583455918090684, 0.049217374729258676, 0.058827608690730164, 0.07218733217035021, 0.04555102610694511, 0.02476587169803679, 0.011771721682245178, 0.0252924454065838, 0.05894779081323317, 0.043130277789064815, 0.10498606613171951, 0.07584625761955976, 0.09419325419834682, 0.06487294858587639, 0.11036475894174405, 0.1439506070954459, 0.11881867423653603, 0.06047660484910011, 0.153504719425525, 0.20254639429705484, 0.23894700248326572, 0.17205653179969105, 0.3112540010895048, 0.2773776245968682, 0.3107901002679552, 0.11582234501838684, 0.1348033036504473, 0.13571585182632717, 0.1077561853453517, 0.15907148857201847, 0.17162750767810003, 0.12755135207303933, 0.10469300007181508, 0.28018553821103914, 0.17880897303777082, 0.23085264968020575, 0.15103740324931486, 0.20094400670911583, 0.15127552832875932, 0.20270004176667758, 0.21762207177068504, 0.26730550506285256, 0.36921731222953114, 0.29346997823034016, 0.2677630547966276, 0.36911509771432194, 0.323023788098778, 0.41611767985991066, 0.5522443982107299, 0.3901085640702929, 0.3648955869887556, 0.5650282693760735, 0.27709225990942543, 0.5154630775962556, 0.28218382384095875, 0.2923798981521811, 0.17625491294477666, 0.12181494917188372, 0.17917619618986333, 0.17799251899123192, 0.15560862581644738, 0.20227823725768498, 0.2044848602797304, 0.2108132035604545, 0.27874389556901796, 0.2016940186066287, 0.19783692700522287, 0.18323557265102863, 0.19741755165159702, 0.24946684656398638, 0.1605846080929041, 0.2085273547896317, 0.11523777352912085, 0.14024795006428445, 0.3080173890505518, 0.2449594470007079, 0.15130207261868886, 0.1861368255423648, 0.2853907160460949, 0.16538516192563943, 0.2669227841709341, 0.28375547379255295, 0.32131396127598627, 0.8988369373338563, 12.956725410052709, 44.32199600764683, 89.81030968257359, 122.74124826703752, 121.59918676103864, 115.5906903403146, 102.93262890407017, 95.46353776114327, 89.44587666647774, 79.05038493020194, 79.6644389288766, 81.27665724073137, 82.70610318865094, 81.24748870304653, 71.77576691763741, 80.30488218579973, 68.02886744907924, 74.72936970846993, 86.82519681113106, 87.86180550711495, 86.24209008898053, 93.37793867928642, 90.7452940259661, 77.66530323028564, 76.40262794494629, 79.47052165440151, 68.96620723179409, 70.26302596500942, 71.83251980372837, 66.64684990474156, 73.01814651489258, 67.19026156834194, 62.23517458779471, 67.64279079437256, 67.46427767617362, 58.77732712881905, 58.02986771719796, 64.95007201603481, 61.6620454788208, 56.38070930753435, 63.36489609309605, 68.9356004170009, 76.01993506295341, 77.69643115997314, 89.41249057224819, 97.27904646737235, 116.25523689814976, 122.99342618669782, 101.83957999093192, 77.61641570499965, 42.31644017355782, 9.972512330327715, 1.5518324949911662, 0.4001275950244495, 0.18846972393138067, 0.1706529821136168, 0.15271776808159693, 0.2728591784834862, 0.3802620438592774, 0.2182389008147376, 0.10468217743826763, 0.17337208906454699, 0.173551507294178, 0.1474822461605072, 0.186209713774068, 0.3115641458758286, 0.06702499703637191, 0.0929465207404324, 0.24348135345748492, 0.13330555973308428, 0.1624534020998648, 0.4112791552075318, 0.13991335087588855, 0.2362525670656136, 0.21165502124599048, 0.3516159781387874, 0.17233336051659925, 0.2172771452793053, 0.28506111087543623, 0.36396013147064615, 0.19518363795110158, 0.39438618453485624, 0.22356656779135975, 0.37174583226442337, 0.4295759605509894, 0.3641321265271732, 0.3187492617538997, 0.26634065540773527, 0.31598425869430813, 0.3536385553223746, 0.2574484811297485, 0.23216613062790462, 0.23169994992869242, 0.14978522115520068, 0.11447279314909663, 0.20135583675333432, 0.12722276470490865, 0.11438402719795704, 0.11104422355336802, 0.1832521017640829, 0.12669698148965836, 0.12409874876695019, 0.1587917557252305, 0.18912980279752187, 0.18400522135198116, 0.2278547462608133, 0.2561231665313244, 0.294888686388731, 0.2968663716954844, 0.2364774335707937, 0.24068885615893773], [0.07210268492677382, 0.11718850742493357, 0.1283932783241783, 0.09142004086502961, 0.06209800498826163, 0.02315195240745587, 0.06528999656438828, 0.0842681053493704, 0.039194011329008, 0.028916485674147095, 0.02573549484701029, 0.04975174819784505, 0.03907859930768609, 0.01876895036548376, 0.01417799006282751, 0.035171811801514456, 0.008577188992473696, 0.07330770883709192, 0.0496736589952239, 0.07750758275921855, 0.04695773437353117, 0.06219483193542276, 0.06812800320663623, 0.03972786571830511, 0.114144572189876, 0.17043062618800572, 0.11295288149267435, 0.10614199124808822, 0.05544034491426178, 0.08949747295784098, 0.07758699171245098, 0.06629120891115495, 0.0800933168668832, 0.047354188814227066, 0.1407546257334096, 0.08717297483235598, 0.14293895209474222, 0.058150376459317546, 0.10495011734643153, 0.12108263346765723, 0.07243379644517388, 0.03204884080748473, 0.022618145515610064, 0.06113844790628978, 0.0349513998787318, 0.03647225469882999, 0.04383124517542975, 0.014867402845993638, 0.05974827893078327, 0.07465198170393705, 0.03973300562107137, 0.013263195087867123, 0.04186874208971858, 0.019353216513991356, 0.08308968679713351, 0.0850062428840569, 0.06891305465251207, 0.013093165238387883, 0.06008449981787375, 0.06646851011152778, 0.052682164524282725, 0.04078704531171492, 0.0902883190927761, 0.0727216988535864, 0.1272331734320947, 0.14656896516680717, 0.050541233870067766, 0.8670219502278737, 9.328568049839564, 22.22179126739502, 46.31089700971331, 72.571273122515, 94.43588529314313, 87.28603608267647, 83.24301828656877, 79.36741733551025, 67.01715414864677, 61.89470590863909, 65.08087880270821, 66.8294346673148, 72.46716826302665, 63.14900861467634, 66.63096632276262, 78.56952789851597, 95.10528864179338, 97.10172149113247, 111.7998296192714, 103.5271167755127, 97.0980042048863, 97.18396036965507, 89.6316020148141, 91.0011544908796, 84.25797639574323, 80.52929510389055, 86.52206775120327, 90.04865373883928, 87.05765574319022, 82.16954939705985, 82.33301966530937, 86.69769736698696, 92.71008477892194, 90.02806622641427, 80.24839333125523, 77.33820288521903, 83.23106738499233, 84.42305864606584, 88.10337352752686, 85.0511896950858, 92.91392408098493, 90.11700316837856, 71.27307169778007, 42.36819035666329, 17.425449780055455, 4.911544357027326, 0.6656846510512489, 0.3144972627716405, 0.21228006056376866, 0.03186197565602405, 0.11590262928179332, 0.10707338234143597, 0.17813847187374318, 0.2206049252833639, 0.21107894501515798, 0.07387132716498204, 0.05204432803605284, 0.03894847325448479, 0.08709023427218199, 0.03720339314479913, 0.0737616555499179, 0.013116677324952824, 0.016513164088662182, 0.04283116598214422, 0.040402991098484824, 0.007627487631647715, 0.0540225018880197, 0.06284265645912715, 0.00747022611488189, 0.013304367744629937, 0.044245324563235044, 0.08364740865571157, 0.05068088655493089, 0.14380937681666442, 0.022317537538973347, 0.0891190879046917, 0.08969713188707829, 0.14361626575035707, 0.09057712395276342, 0.12176494114100933, 0.08276433604104177, 0.1774482796234744, 0.05780835409781762, 0.050762076662587266, 0.062072682061365674, 0.03890753723680973, 0.07912146473037344, 0.11356297268399171, 0.1774329175906522, 0.06101694264050041, 0.15025360030787333, 0.05407664219715765, 0.07586205391479389, 0.06588006418730531, 0.10354904431317534, 0.06551044580659696, 0.035165820337299786, 0.012154303474484809, 0.11703997610935143, 0.16622193131063664, 0.04159244602280004, 0.04580046236515045, 0.09779381206525223, 0.11552354533757482, 0.12707500691924775, 0.07047059786106859, 0.026016433789793934, 0.08738126472703048, 0.08099000767937728, 0.06414840210761343, 0.09252003433981112, 0.05455269218821611, 0.007474835063996059, 0.02619875275662967, 0.10040461125650577, 0.03382438374683261, 0.08417657776070492, 0.016992450691759586, 0.0371134940401784, 0.04805005361725177, 0.0757798697533352, 0.08065170368977956, 0.03820347912343485, 0.05125307817278164, 0.0769198832235166, 0.03563012149451034, 0.17265878591154302, 0.09757498452173811, 0.047342456943754635, 0.05935559714479106, 0.05399782017671636, 0.044166041138981066, 0.0618717542716435, 0.1465614741402013, 0.22166265281183378, 0.1155839485249349, 0.16564752427595003, 0.11399061259414468, 0.1766768938728741, 0.042457289794193845, 0.1480307602988822, 0.056443229849849424, 0.04155769824449505, 0.06759098345147711, 0.1545148002249854, 0.03927613102963992, 0.09312317733253751, 0.17920017561742238, 0.009650675496751708, 0.046533052876059494, 0.05845698607819421, 0.014994115868051137, 0.04394204994397504, 0.03897373511322907, 0.056731515630547485, 0.016688879213428924, 0.03259885111557586, 0.03485307676185455, 0.0843699738117201, 0.03874359978362918, 0.04220093247879829, 0.0705392181075045, 0.07471345019127641, 0.04588237850527678, 0.002617894335084462, 0.08319583681545087, 0.09717093048883335, 0.031611850684774775, 0.06053311324545315, 0.043215681599187, 0.05207644309848547, 0.06678546738943883, 0.16935364183570656, 0.4973432070442608, 0.7494573986956051, 6.190815848963601, 26.781100170952932, 48.70055621010916, 75.11785738808769, 89.45043468475342, 97.76021616799491, 88.65693650926862, 87.94771998269218, 85.89823068891252, 85.46897097996303, 82.41655785696847, 80.65899017878941, 82.33448573521206, 86.18651144845145, 78.35882377624512, 82.44878360203334, 94.36998857770647, 107.4816701071603, 105.26855768476213, 118.49588503156389, 114.91628428867885, 112.60636956351144, 108.30666446685791, 101.60327870505196, 102.67161287580217, 98.73846694401333, 93.49227128710065, 96.0821567262922, 98.28802912575858, 96.3481754575457, 95.97737094334194, 97.72742067064557, 99.33338560376848, 98.31553704398019, 97.38224111284528, 90.49424171447754, 84.92278698512486, 91.70864786420549, 89.49623720986503, 93.68903732299805, 100.18164948054722, 100.8245871407645, 98.10296385628837, 88.47164194924491, 63.53471006665911, 38.10444218771798, 15.122497149876185, 3.5386207018579756, 0.8873672527926308, 0.7366364523768425, 0.34724957815238405, 0.16398580558598042, 0.11341089941561222, 0.07570274067776543, 0.17066569785986627, 0.0654879320146782, 0.031573069015783925, 0.03114151395857334, 0.05165422807580658, 0.071192104502448, 0.030705918225326707, 0.016916507356134907, 0.04426920221054128, 0.03778946080378123, 0.0289452487735876, 0.03027737925627402, 0.05181620456278324, 0.06574227408106838, 0.021820873654048358, 0.05395343380847147, 0.045886429359338114, 0.08104705211839505, 0.0878593333597694, 0.06002596260181495, 0.13952647734965595, 0.07467456334935767, 0.09004146805299179, 0.05066018445151193, 0.11639353579708508, 0.10897816584578582, 0.033384635379271846, 0.06384075433015823, 0.18725449485438211, 0.03784939240930336, 0.08302555166717086, 0.0988380571029016, 0.11094147978084427, 0.15686456699456486, 0.1421773372484105, 0.18599081837705203, 0.15508008774902138, 0.11911721607404095, 0.05442047963983246, 0.07787873462906905, 0.008370634451109384, 0.015594208845868707, 0.049880123630698235, 0.041036674952400584, 0.08571849430778197, 0.05831115533198629, 0.03276995729122843, 0.09131171274930239, 0.1598035464329379, 0.08708128439528601, 0.14388325570949487, 0.18247493489512376, 0.11458765555705343, 0.021302240501557077, 0.08719890844076872, 0.1882052445518119, 0.2906879303710801, 0.26345851006252424, 0.17101257853209972, 0.1170723150883402, 0.07838058591421161, 0.16255690583160945, 0.14981108691011155, 0.16185422853699752, 0.15910162909754685, 0.19948404362159117, 0.11648657651884214, 0.13404752420527594, 0.11003742007804768, 0.199993582708495, 0.18595548027328082, 0.3027522287198475, 0.15571183099278382, 0.2834691862974848, 0.20110544376075268, 0.14652313691164764, 0.18766219940568718, 0.24330512434244156, 0.18342944367655686, 0.2721344759421689, 0.341478556394577, 0.25352006192718235, 0.27888853209359304, 0.20121979048209532, 0.20768633777541773, 0.2525432700557368, 0.21294883824884892, 0.293113611638546, 0.21617964202804224, 0.1253586390188762, 0.14924636935549124, 0.23216906189918518, 0.20654961520007678, 0.2555009499192238, 0.3191447933869702, 0.1436368389321225, 0.22374830661075457, 0.15181600861251354, 0.1994931631322418, 0.12852042221597262, 0.10525110869535378, 0.07562367099204234, 0.08615411378975425, 0.11787639265613896, 0.20534123932676657, 0.2746683699744088, 0.08533139007964305, 0.14310725592076778, 0.16394351928361825, 0.21960314975253173, 0.16561389608042582, 0.17194773549480097, 0.13179005176893302, 0.1357270340834345, 0.13492493783789022, 0.1735551849539791, 0.29998733422585894, 0.22237645808075154, 0.23919018943394932, 0.2578617089561054, 0.40213136321731974, 0.22200907208025455, 1.5274308558021272, 12.171062197004046, 32.2185571534293, 66.7728693825858, 98.05934306553432, 128.72140993390764, 132.18376677376884, 128.26045254298617, 123.88861819675991, 113.19614655630929, 111.25003950936454, 107.95400169917515, 109.62070083618164, 117.97121265956334, 106.5926342010498, 111.33175727299282, 122.31091853550502, 135.91479655674524, 135.32271276201521, 147.4140235355922, 137.05821990966797, 136.28670583452498, 138.08505249023438, 133.60472897120883, 137.9187126159668, 129.22191647120883, 120.91941670009068, 124.46316473824638, 128.49596868242537, 127.47562571934291, 128.1482947213309, 126.12011555262974, 127.15171459742955, 130.62389619009835, 129.70794296264648, 121.99513680594308, 113.9839402607509, 118.56258773803711, 117.6122270311628, 119.4240392957415, 122.21483884538922, 129.67460550580705, 118.47763906206403, 92.19072083064488, 53.52042777197701, 24.707015991210938, 7.312397973878043, 0.8758006191679409, 0.4898585315261568, 0.6663416900805065, 0.41607753772820744, 0.2296471915074757, 0.3342169831906046, 0.2769331841596535, 0.28751054086855476, 0.36125508376530235, 0.12804795828248772, 0.11468366826219217, 0.10380362386682204, 0.31761529403073446, 0.20028889471931116, 0.11572116187640599, 0.14293177319424494, 0.10460907886070864, 0.09739062655717134, 0.2045298742928675, 0.12431528286210128, 0.22309213610632078, 0.11618426202663354, 0.0864064609631896, 0.13752003572881222, 0.21532805343823774, 0.2889484651386738, 0.25630132268582073, 0.3299665855509894, 0.1577501773302044, 0.27835550212434357, 0.1572861136602504, 0.3131789506546089, 0.1110927320218512, 0.27788145041891504, 0.19765847229531833, 0.2946655840745994, 0.20527698206050055, 0.19205327092536859, 0.29921586705105646, 0.2614255648638521, 0.1753733873899494, 0.19248082941131933, 0.2399817141039031, 0.23407940939068794, 0.17081355064042977, 0.125327304271715, 0.13238197857780115, 0.11683846477951322, 0.16451591785464967, 0.1393732912838459, 0.08694888185709715, 0.12473801017871924, 0.1676992784653391, 0.2958759276994637, 0.22254816815257072, 0.19288978246705873, 0.19579722359776497, 0.4252220184675285, 0.24172717758587428, 0.20629356322543962, 0.12651217569197926, 0.1530794408172369], [0.0673743204346725, 0.0714517594980342, 0.21004837245813437, 0.03335787395813635, 0.05676898094160216, 0.054185041559061835, 0.038770666545523066, 0.05257340893149376, 0.03361682327730315, 0.05275245396686452, 0.014005866932815738, 0.022023083874955773, 0.045474623063845296, 0.10114947307322707, 0.08325645034866673, 0.0251889281041388, 0.044964690426630635, 0.04872573200347168, 0.07904855614261967, 0.114131218620709, 0.07211561101887907, 0.09209882694163493, 0.03239005231963737, 0.047111629508435726, 0.010569484854516174, 0.08484496868082456, 0.11920315931950297, 0.11760108385767255, 0.10046527228717293, 0.012567302295272904, 0.11947012213724, 0.07263063945408378, 0.056080753050212345, 0.11485754964607102, 0.08646410251302378, 0.07561472111514636, 0.03490797703021339, 0.21094260018851074, 0.10214982368052006, 0.0582378056964704, 0.05589454947039485, 0.04051924789590495, 0.0070579656250109625, 0.16831766813993454, 0.035947872658393214, 0.01918409505326833, 0.14997768082789012, 0.016164054428892474, 0.009762397135740944, 0.04238380105899913, 0.02106360312817352, 0.06632344610989094, 0.017577161280704395, 0.017239225396354283, 0.020116816075252633, 0.08490942950759615, 0.044393472506531646, 0.007772892597131431, 0.04623424980257239, 0.029925233152295862, 0.07305768903877054, 0.05541847233793565, 0.06810363022876637, 0.05425849297483053, 0.016532495551343476, 0.036035610628979545, 0.06601799678589616, 0.043673132945384295, 0.07469700250242438, 0.137796050203698, 0.06903367103742701, 0.48919237298624857, 5.512504475457328, 18.753597940717423, 39.516833782196045, 52.75714731216431, 58.457654408046174, 69.12939262390137, 72.1895946775164, 87.68181937081474, 79.14007227761405, 60.85084329332624, 54.86198248182024, 56.99430819920131, 51.735359123774934, 34.72007540294102, 27.006954840251378, 7.8739843879427225, 5.522286670548575, 14.564638444355555, 20.13333647591727, 28.564245905194962, 32.4519019808088, 29.089759009225027, 38.41102450234549, 42.19987024579729, 36.273157596588135, 28.152202095304215, 14.470109071050372, 15.837234020233154, 34.58378996167864, 41.82977097375052, 48.91661739349365, 45.60539429528372, 39.38045106615339, 38.63230030877249, 33.84476566314697, 22.332304103033884, 16.12889334133693, 6.303621590137482, 1.1630038108144487, 0.07680906488427094, 0.12128544758473124, 0.16620743780263833, 0.010741865827835031, 0.0502096270211041, 0.02837979161579694, 0.07138748187571764, 0.21050993911921978, 0.05467115083177175, 0.08622604528708117, 0.17057527628328117, 0.0819162961893848, 0.026445798875231828, 0.06473901934389557, 0.041149067492889504, 0.030575293448886702, 0.038110194129071066, 0.07499026533748422, 0.062740916918431, 0.08221059039767299, 0.06474210667823042, 0.012151591030747762, 0.028872818553021977, 0.02319413692956524, 0.007552930203798626, 0.01084790049519922, 0.05748790914991072, 0.02139020069236202, 0.027652212086000612, 0.0408326903624194, 0.020504916053531424, 0.0420791320502758, 0.049855360495192666, 0.056469272023865154, 0.10617870677794729, 0.061401414152766974, 0.09964631444641522, 0.056019416877201626, 0.02766856986896268, 0.0349676643631288, 0.015146182351080435, 0.07464229222387075, 0.03265306267089077, 0.033564599829592874, 0.16102052613028459, 0.043631599816892824, 0.06256432139447757, 0.08580032563103096, 0.18545911833643913, 0.0826900771686009, 0.06669634181473937, 0.11874894797801971, 0.09172344101326806, 0.10671453909682375, 0.10021233478827135, 0.11734746103840214, 0.06392027863434382, 0.04668082423242075, 0.024579434023637856, 0.03058531541111214, 0.044696740340441465, 0.05111683512638722, 0.08133399779243128, 0.03078806506735938, 0.08225453232548066, 0.04000198708048888, 0.025583944050595164, 0.10003151199115173, 0.06511122972837516, 0.06439416749136788, 0.029691108036786318, 0.07225264116589512, 0.043159665140722475, 0.03530880802177957, 0.047496535283114226, 0.034867675442780764, 0.027071577796180333, 0.04851005286244409, 0.07522180184189763, 0.04622200224548578, 0.03983011416026524, 0.0389940538443625, 0.02433310036680528, 0.056641799730381796, 0.07467550651303359, 0.06115536378430469, 0.044288635453475375, 0.08067237186644759, 0.06684029980429582, 0.10933133653764214, 0.0028134035985983375, 0.10683529118874244, 0.11317234685910599, 0.14736363823924745, 0.030446059669234922, 0.06700377246098858, 0.21459990393902573, 0.0644818681425282, 0.05512903644038098, 0.06446622112499815, 0.10306634128625904, 0.03053928698812212, 0.08921590128115245, 0.04518222536093422, 0.08522410690784454, 0.02757596849863018, 0.09983390902302094, 0.008179208696154612, 0.046881412754633596, 0.0771052318492106, 0.05367958725297025, 0.09200235283268349, 0.031002845149487257, 0.025717903826651827, 0.014768469047599604, 0.04263998534796493, 0.09739070119602339, 0.03955547711146729, 0.05932948711727347, 0.012332452843630952, 0.04232081265321799, 0.039795573335140944, 0.020255513722077012, 0.07184556086680718, 0.060605858984802446, 0.031224902519690137, 0.07839098785604749, 0.06354836680527244, 0.07958771328308753, 0.02207275603099593, 0.03530484876994576, 0.16450081366513455, 0.10216125699558429, 0.15518279080944403, 0.5739335258092199, 0.38015540529574665, 8.584051200321742, 22.850848163877213, 46.615742274693076, 67.37761279514858, 81.58098139081682, 84.13151918138776, 97.28435489109584, 98.2283024106707, 110.69400296892438, 105.3974050794329, 88.95226969037736, 78.75847721099854, 79.59132303510393, 77.42666734967912, 58.35127748761858, 45.99091509410313, 15.385641063962664, 11.374317475727626, 24.827332735061646, 32.73897722789219, 44.50454255512783, 46.554782254355295, 44.34822198322841, 54.132949692862375, 55.63828386579241, 49.59317391259329, 42.47068670817784, 27.537939650671824, 30.693340710231237, 55.63862780162266, 63.200960295540945, 70.8967433656965, 66.11641747610909, 61.67225238255092, 60.9510988507952, 56.74246031897408, 44.06816094262259, 37.10384947913033, 18.857796600886754, 6.586401547704424, 0.8824388086795807, 0.93902830353805, 0.530356866972787, 0.13491481409541198, 0.06225876350487981, 0.04028568596446088, 0.023445747892505357, 0.1746129531945501, 0.09570008369960956, 0.06690405495464802, 0.05685202344985945, 0.045400934160820076, 0.05379198318613427, 0.02878983032756618, 0.05880331713706255, 0.009760954400657542, 0.0029741366701533218, 0.07250513083168439, 0.08742030763200351, 0.055706551165453026, 0.023397546461118118, 0.005095193669798651, 0.033457968051412275, 0.07343415383781705, 0.008511765494144388, 0.02496095560491085, 0.009100959503224917, 0.06300249216811997, 0.04774537103782807, 0.06271095959735767, 0.03303883697039314, 0.03834202579621758, 0.0006458649887853035, 0.06603960812624012, 0.04465546505525708, 0.01601927032295082, 0.05247378981273089, 0.046640624425240924, 0.016822285983445387, 0.038917779722916226, 0.0654813570103475, 0.049778743713561974, 0.08434986203376736, 0.07429235814405338, 0.20323212178690092, 0.12800713761576585, 0.07702327838965825, 0.13417869859508105, 0.21945507984076226, 0.14993057692689554, 0.18170111998915672, 0.10255919742797102, 0.07197383791208267, 0.03226803136723382, 0.03823871544695326, 0.05484482186979481, 0.06952127987252814, 0.054835315594183545, 0.0266043046555881, 0.03936513446803604, 0.047230756508984735, 0.05891292768397501, 0.09658242349645921, 0.13010450292910847, 0.08907210614000048, 0.16632786419774803, 0.12961054300623281, 0.24720762350729533, 0.15301113948225975, 0.12712914044303553, 0.1430062356271914, 0.13789023086428642, 0.13947607576847076, 0.2445771060883999, 0.09561441865350519, 0.18415432263697895, 0.15811122581362724, 0.1654976358903306, 0.1849911870168788, 0.1100244532738413, 0.12385233198957783, 0.09508324108485665, 0.20533608246062482, 0.13859794288873672, 0.27833373472094536, 0.1895212767911809, 0.13070713702057088, 0.14626488648355007, 0.15324710682034492, 0.15817793937666075, 0.2269128310893263, 0.19219988877219812, 0.26486511315618244, 0.25701014750770157, 0.19867563700037344, 0.17986717554075377, 0.3177726055894579, 0.29223385027476717, 0.21016592186476502, 0.2490331269800663, 0.19240958323436125, 0.19901528448930808, 0.25887446318353924, 0.19353238227111952, 0.20842731158648217, 0.19390207529067993, 0.25242601920451435, 0.12772051085318836, 0.30042089096137453, 0.21619158424437046, 0.12009787559509277, 0.16761827495481285, 0.13418020494282246, 0.11781673585729939, 0.12454536051622458, 0.10900693573057652, 0.13684638616229805, 0.07002368077103581, 0.0760297334886023, 0.09133776849401848, 0.24353376350232533, 0.1111202941143087, 0.14237337958599838, 0.1943847851029464, 0.12817432864436082, 0.10516550471740109, 0.2110854046685355, 0.1419005221022027, 0.18170396983623505, 0.13026827414120945, 0.11136811545916966, 0.13495369415198052, 0.16384752014917986, 0.30316363807235447, 0.2705862218780177, 0.16516386451465742, 2.6700366011687686, 10.412434918539864, 31.496809550694056, 56.08573743275234, 75.25655732836042, 88.00766904013497, 107.21067646571568, 113.34782573154995, 128.44594165257044, 117.63535063607353, 95.37393379211426, 88.27573054177421, 80.56558554513114, 75.78685774121965, 55.11300005231585, 43.22437865393502, 13.010221328054156, 8.201059545789446, 21.311342750276836, 31.586934634617396, 43.66015229906355, 48.49350336619786, 47.41826616014753, 56.3745254107884, 54.83689601080758, 48.95285224914551, 40.573547090802876, 25.42839707647051, 26.30011807169233, 50.52389553615025, 58.83135632106236, 65.58215659005302, 64.41155188424247, 57.92789942877633, 57.62486069543021, 48.34533997944423, 35.94148881094796, 24.82762803350176, 9.458091156823293, 2.332310723406928, 0.25892877312643187, 0.5187551123755318, 0.30075261316129137, 0.16795026856873715, 0.21152957369174274, 0.10499524671052184, 0.11563079458262239, 0.26080218117151943, 0.18032593306686195, 0.20185401716402598, 0.24336904234119824, 0.1974802618580205, 0.14401894914252417, 0.2905998293842588, 0.1644263376614877, 0.1414970244680132, 0.11636282530214105, 0.19444559541131767, 0.17810092174581119, 0.18499077989586762, 0.1657644630010639, 0.1262244497026716, 0.1285441845123257, 0.19274047762155533, 0.11500104623181479, 0.1515037060848304, 0.07480225685451712, 0.2214284496647971, 0.17094708633209976, 0.20428357965179852, 0.1330497656017542, 0.13417602516710758, 0.13331135442214354, 0.12902184602405342, 0.153284114120262, 0.22208778214241776, 0.29629580516900333, 0.09195024812860148, 0.17460894983794006, 0.1727425849863461, 0.20952003795121396, 0.15872759345386708, 0.13901277205773763, 0.1349802655833108, 0.2990738632423537, 0.21800472480910166, 0.24703174723046167, 0.18775176602814878, 0.33039756385343416, 0.2711544271026339, 0.3432924976306302, 0.3484886645206383, 0.14858584265623773, 0.22585067951253482, 0.12077156587370805, 0.1995308082550764, 0.19066432331289562, 0.23515201040676662, 0.12226008171481745, 0.14885877658213886, 0.1341820912701743, 0.1794639764619725, 0.20262851060501166, 0.14931608204330715, 0.17636482204709733], [0.02630240237340331, 0.005468095735912877, 0.046460785503898344, 0.028862810161496912, 0.008150225921001817, 0.048001358551638465, 0.03103734865518553, 0.017157324523265873, 0.10035716130265168, 0.043102515528776815, 0.012454777440455343, 0.05950316494064672, 0.04245380212419799, 0.014620595910985554, 0.11195696850440331, 0.0350338317054723, 0.031296362435179095, 0.02579291587296341, 0.052154651044734886, 0.02860047834526215, 0.04768435038360102, 0.04389336505638702, 0.03244764976469534, 0.041574943211994, 0.035054326855710576, 0.022676368909222738, 0.022461290271686654, 0.005734525055491498, 0.03173747465812734, 0.021836050786077976, 0.03198045465563025, 0.0705011183662074, 0.011198521591722965, 0.011998119980229862, 0.051864553575537035, 0.06055518598960979, 0.04057185471590076, 0.06698675480272089, 0.011964947251336915, 0.024780612871316925, 0.021694949428950037, 0.05887751494135175, 0.01354139783818807, 0.01830599779662277, 0.02822890069468745, 0.0588996283976095, 0.02032413736118802, 0.09692237632615225, 0.06244707054325512, 0.013170322303527167, 0.019944379970963513, 0.03965671792892473, 0.031568370160779784, 0.011901360038401825, 0.056800753343850374, 0.01597109094395169, 0.030122045627129928, 0.09092010983398982, 0.034320070541330745, 0.012166156633091825, 0.06852232026202337, 0.04326870232554419, 0.02400398374136005, 0.042469489853829145, 0.013890997739508748, 0.07655748445540667, 0.07118356853191342, 0.006661640530052994, 0.037185768197689734, 0.12038556087229933, 0.023375317653907195, 0.04104255445833717, 0.21876906736620835, 0.40949200253401485, 0.1384911686182022, 0.05658791387187583, 0.5419202436293874, 0.9135380770478929, 2.480327763727733, 2.5751795768737793, 1.1967640221118927, 0.7376620173454285, 0.12863060273230076, 0.03896296676248312, 0.15245290872241768, 0.20448372034089907, 0.8988509422966412, 0.3132834721888815, 0.1450609075171607, 0.4795182006699698, 0.4868697204760143, 0.227921866944858, 0.1232264648590769, 0.025219178891607692, 0.16520283956612858, 0.16975522600114346, 0.0294267474008458, 0.3048424965568951, 0.19612547169838632, 0.34683214340891155, 0.4528804900390761, 0.3642367837684495, 0.044364380317607095, 0.1328542118093797, 0.09352220342095409, 0.11958138830959797, 0.0566977754767452, 0.1432759397264038, 0.2788379948054041, 0.11768808561776366, 0.10514028357075793, 0.10506231311176505, 0.14652441255748272, 0.1779715929712568, 0.07244244098131146, 0.09121103172323533, 0.01208749576471746, 0.055736786685884, 0.07112563521202121, 0.01992732668960733, 0.03535863963354911, 0.024550029708604728, 0.03690936356516821, 0.04000698449090123, 0.03436554256560547, 0.029389126026736836, 0.03319091363144772, 0.02548636562590088, 0.03593484817871025, 0.031131156121513674, 0.05547287388305579, 0.022620481372411762, 0.024664137246353284, 0.06768779682793788, 0.041136497631669044, 0.042707954200782945, 0.07905623715903078, 0.031025396260832037, 0.00838896507463817, 0.03642172080331615, 0.009070229500399103, 0.043346313160977194, 0.06593393308243581, 0.059988412473882945, 0.029154264700732062, 0.026529538578220775, 0.05449394801897662, 0.008431105491971331, 0.04003629720370684, 0.05614915955811739, 0.03405474977833884, 0.05363216444051691, 0.01380141924268433, 0.04057318125186222, 0.05266836651467851, 0.004480669948471976, 0.004726048143181417, 0.02038773475214839, 0.018869729779128517, 0.04197825085637825, 0.005921745589668197, 0.06409396324306726, 0.005658580023529274, 0.021756117664543644, 0.0667153475806117, 0.05636654521471687, 0.014357134333944746, 0.04320114737908755, 0.04202897474169731, 0.018885103686313544, 0.029395293910056353, 0.021402712878105894, 0.024674043857625554, 0.033287126504416974, 0.02615653770044446, 0.0332058855066342, 0.030857720079698732, 0.018673407545845424, 0.05283928270052586, 0.04414272328306522, 0.017043744546494315, 0.027242834945874553, 0.05883290126387562, 0.04837828136182257, 0.0692266056846295, 0.09444201192153351, 0.04593471051859004, 0.0325308076239058, 0.05645431371937905, 0.03718255194170134, 0.0037131314914274427, 0.006423242764347898, 0.049459180861179314, 0.023146563143070256, 0.013480287278071046, 0.03416531366695251, 0.021444478404841254, 0.02972939098253846, 0.04149041471204587, 0.020384131731199365, 0.04648598290181585, 0.011315402641360248, 0.04948945709371141, 0.020211336003350358, 0.04717660941449659, 0.023057910846546292, 0.044298620096274784, 0.04563854355365038, 0.010249413949038302, 0.03952664955120001, 0.04810684021296246, 0.0556482276879251, 0.05205524905717798, 0.02978461355503116, 0.028420629245894294, 0.03804790800703423, 0.011015563105632151, 0.08855407858001334, 0.02473560903620507, 0.02343972589421485, 0.04552573371412499, 0.06528840879244463, 0.04622115068403738, 0.044827765452542474, 0.05257615360564419, 0.03348108913217272, 0.011697447542766375, 0.016719571048659936, 0.020615820905991962, 0.06286512953894478, 0.06350207714630024, 0.043253353863422356, 0.006690189042793853, 0.022538738258715187, 0.04694932053929993, 0.04450467761073794, 0.02943076772083129, 0.04895066975482872, 0.03317565337887832, 0.02568980908420469, 0.0180980658291706, 0.06162181589752436, 0.09794656386865036, 0.030329008985842978, 0.022372305493003557, 0.10628095521990742, 0.038250929077288935, 0.1781635640987328, 0.21111977925258024, 0.9816145726612636, 1.0642125861985343, 0.9025153570941516, 3.3609098834650855, 6.432223626545497, 10.904752135276794, 10.34069129398891, 5.784146470682962, 3.5718997504029955, 1.5729532816580363, 1.3262574906860078, 0.7838869712182454, 0.25718868364180836, 0.7560610100626945, 0.47251343939985546, 0.1973687649837562, 0.30137447693518227, 0.39728605321475435, 0.15789292752742767, 0.09746318230671541, 0.01784692644806845, 0.1099985535921795, 0.09715450994138207, 0.08356430168662753, 0.1741873896015542, 0.23029679379292897, 0.19830446477447236, 0.3563111147710255, 0.29001064385686603, 0.06847390678844281, 0.2501971130924565, 0.11098034626671247, 0.24451753071376256, 0.3934716007539204, 0.40230124124458855, 0.31954624184540337, 0.07107300803597484, 0.1937751349593912, 0.09496853473995413, 0.06286895647644997, 0.11948213220707007, 0.06381720237966094, 0.05844916256942919, 0.049766102606164556, 0.009357554305877005, 0.03847823491586106, 0.021876751012834053, 0.032958606989788156, 0.04343229711854032, 0.03375574653702123, 0.033513431503836594, 0.05529202055186033, 0.06759118022663252, 0.029913708235004118, 0.02719596853213651, 0.009100756790888096, 0.023765432881191373, 0.06467957967626196, 0.04495221895298787, 0.036769470000373464, 0.051204617201749764, 0.053055440208741596, 0.03486235572823456, 0.10217793538634266, 0.03535751326541815, 0.007036179137815322, 0.05445039285612958, 0.01965758018195629, 0.02632176606649799, 0.04866068424390895, 0.012091872315587742, 0.046728362395827255, 0.04049183168847646, 0.05538259479882462, 0.02412498858757317, 0.04797270062512585, 0.04507695065279092, 0.02300119719335011, 0.013311289649988924, 0.04072574645813022, 0.018675965622865727, 0.03659542916076524, 0.04372648276122553, 0.060558436172349114, 0.005729837650765798, 0.0673103074410132, 0.037088924287153144, 0.015825735172256827, 0.03954491910657712, 0.015892146787207042, 0.04219797067344189, 0.062183283269405365, 0.048263228964060545, 0.11225450611008064, 0.046025335655680726, 0.07642419303634337, 0.07534230966120958, 0.1134606088910784, 0.06187959135110889, 0.03249920146273715, 0.07684594326253448, 0.050060369673052, 0.011491024467561926, 0.10663867209638868, 0.13535060999648912, 0.12640933692455292, 0.15003524773887225, 0.10078981558659247, 0.08499729300716094, 0.13837129862180778, 0.08563665619918279, 0.15754463550235542, 0.1398844588547945, 0.09601933442588363, 0.19037068049822534, 0.1014589528952326, 0.09255235296274934, 0.11929967414055552, 0.06689925092671599, 0.09420607172484909, 0.14353991699005875, 0.08691208490303584, 0.12591807757105145, 0.14193999926958764, 0.07788717560470104, 0.09914401532816035, 0.13958933683378355, 0.11789588018187455, 0.1404232292303017, 0.18520223854907922, 0.06582864480359213, 0.09596872928419284, 0.13057666830718517, 0.14419156845126832, 0.1186975964478084, 0.1250348828200783, 0.11678870102124554, 0.1793263288480895, 0.14778907969594002, 0.12234354152211122, 0.09330528934619256, 0.10445515997707844, 0.1029055081307888, 0.0884783947840333, 0.20277392065950803, 0.10069349754069533, 0.12621005118957587, 0.1254540274717978, 0.23843009450605937, 0.18227577129645006, 0.21905983319239958, 0.16323101680193627, 0.14191137866250106, 0.06781333259173802, 0.07265561632812023, 0.1250907126814127, 0.11737864650785923, 0.15880280227533408, 0.13853067292698792, 0.10820044936346156, 0.17900597889508518, 0.0967973969610674, 0.12412730152053492, 0.1619374305009842, 0.16720640419849328, 0.10938815706010376, 0.13034170520092758, 0.09333994891494513, 0.13721010807369435, 0.235039156462465, 0.11211450397968292, 0.09051037646297898, 0.3045981153845787, 0.16298518356467995, 0.16613653089318955, 0.37021299451589584, 0.8668180097426686, 0.3092899407659258, 0.20915523038378783, 0.7348884376032012, 1.9961041126932417, 4.106076172419956, 3.543714599949973, 1.8113948298352105, 1.1031930659498488, 0.5691645102841514, 0.3403735485460077, 0.41757093902145115, 0.4336690737732819, 1.0839176774024963, 0.4506556822785309, 0.3518967559295041, 0.5165285404239381, 0.5659118848187583, 0.36943623476794785, 0.2860919412757669, 0.07553679136825459, 0.29575389996171, 0.32117735860603197, 0.18471279766942772, 0.4008721650711128, 0.3388359067695481, 0.41135135133351597, 0.43781834255371777, 0.37966962850519587, 0.12906679218368872, 0.1430892611720732, 0.1796606294810772, 0.19391627024327004, 0.23216756912214415, 0.32993312020386967, 0.3068589669253145, 0.32209126385194914, 0.22904932073184422, 0.12471834623387881, 0.20697185397148132, 0.2510886809655598, 0.14437144808471203, 0.16620255235050405, 0.1643943108086075, 0.1251793700669493, 0.12109813120748315, 0.16349259205162525, 0.07379185035824776, 0.1859503234071391, 0.0968050779774785, 0.18564403269972118, 0.07697001339069434, 0.185365494074566, 0.16117417359990732, 0.0975152530840465, 0.08278280576424939, 0.09070908544319016, 0.11784211306699685, 0.09282234883201973, 0.10305734391191176, 0.20221579846526894, 0.13592627910631044, 0.14217595303697245, 0.1885217132845095, 0.098095549802695, 0.10506329020219189, 0.22223226938928875, 0.12077516210930687, 0.19484297265963896, 0.10522080532142095, 0.09489566007895128, 0.13965595540191444, 0.09497650074107306, 0.16290924192539283, 0.15064366294869355, 0.15383070121918405, 0.15031749116522924, 0.10380918785397496, 0.21065726264246873, 0.11864401932273592, 0.13721141086093017, 0.1143674845142024, 0.12874625224087918, 0.1326493892286505, 0.09138738297458206, 0.12379803561738559, 0.1094618323924286, 0.06780264566519431, 0.11104085801967553, 0.09053254420203821, 0.18766200941588196, 0.19022991162325653, 0.13299506210855075, 0.18679356601621422, 0.11269903475684778, 0.2056523747742176, 0.13373892647879465, 0.14886750254247869, 0.1422766340630395, 0.10953921931130545, 0.1623841236744608, 0.15857368814093725, 0.10849969687738589], [0.044300957649414024, 0.03994074250970568, 0.027944491045283418, 0.05079819508162992, 0.018309904461992637, 0.035012210187103064, 0.02329720470256039, 0.06770253460854292, 0.019996985094621778, 0.015921293258933083, 0.0711436163900154, 0.040018176926033835, 0.07822159158864192, 0.05255495956433671, 0.013212467809872968, 0.02588259954271572, 0.04597682718719755, 0.04009823388020907, 0.034277397474007945, 0.012606898206286132, 0.028864435252866576, 0.03198731803734388, 0.03885459793465478, 0.04594185549233641, 0.03181251723851476, 0.013708920500773405, 0.050765479515705786, 0.009399878775833972, 0.0464657795216356, 0.05850075837224722, 0.02125762852041849, 0.008534029076275016, 0.01512404514609703, 0.08180361187883786, 0.03284408384934068, 0.01580143513690148, 0.03620219097605773, 0.054879355909568925, 0.03346283993284617, 0.02600591310432979, 0.018222558345379572, 0.05414456355252436, 0.046984845240201266, 0.04251796778823648, 0.02164916697490428, 0.09584794326552323, 0.01971117257406669, 0.053095192182809114, 0.05051557846101267, 0.016126373682969382, 0.016221653570287993, 0.062380723389131684, 0.01230725205303835, 0.03573315703709211, 0.023091593324871998, 0.03072346853358405, 0.08633543191743748, 0.005530967094403292, 0.006294613729031491, 0.0289221548342279, 0.03973338560068181, 0.03761807642877102, 0.017152452641831975, 0.06919170184327023, 0.016126351630581275, 0.004261395420014326, 0.046507560315408876, 0.043493144746337614, 0.0911520534594144, 0.07890852008547102, 0.09078168869018555, 0.04664050907428775, 0.049119719969374795, 0.1794636779065643, 0.08596716382141624, 0.06583133858761617, 0.006972723391040095, 0.016373231508103863, 0.10566649426306997, 0.028280291240662336, 0.009681678609922528, 0.014110752331492091, 0.0383999489380845, 0.049259121596281014, 0.11726428621581622, 0.11544550023972988, 0.2504853004855769, 0.05404260688062225, 0.06388694220887763, 0.11516375892928668, 0.11138739263904945, 0.10608074667730502, 0.05509858378874404, 0.03560963312962225, 0.08278816619089671, 0.027360289357602596, 0.06569323635527066, 0.18972272026751721, 0.08315047674945422, 0.09262234384992293, 0.2747900177325521, 0.1432149801403284, 0.0661776764318347, 0.03648227666105543, 0.10823716489332062, 0.1180345591689859, 0.02662739689861025, 0.15564726160040923, 0.14021201484969684, 0.03550693006919963, 0.0075844786894906846, 0.05759137895490442, 0.10638160231922354, 0.05520895768755248, 0.006801683796636228, 0.003176603886199051, 0.02713758229011936, 0.017509670795074532, 0.05231587096516575, 0.04017100676095911, 0.023847177691225494, 0.028528665591563498, 0.05316302872129849, 0.0388186423640166, 0.03388699895835348, 0.06333280980054821, 0.035548164642282894, 0.05808911153248378, 0.04947379311280591, 0.036437544239951034, 0.04619334092629807, 0.0071606402717796815, 0.0415041075487222, 0.032213368586131504, 0.08100781243826662, 0.01982933435855167, 0.03146889353437083, 0.006973802261719746, 0.04365050719518747, 0.05310302247692432, 0.025210583549258963, 0.06717221199401788, 0.04587842943146825, 0.05077101636145796, 0.06556426041892596, 0.021006429767502204, 0.03706265141123107, 0.02332165401561984, 0.03521131950297526, 0.038267149456909726, 0.02817374258302152, 0.08648460105593715, 0.054861130458968024, 0.03931652082662497, 0.08081778192094394, 0.008637006943380194, 0.06020135711878538, 0.07464308610984258, 0.04882507970822709, 0.019648791457127248, 0.06323830344315086, 0.04240986019639032, 0.049251287909490724, 0.062422941837991984, 0.013473240691902382, 0.024813194426574876, 0.04410162102431059, 0.07293861292834793, 0.04487709155572312, 0.04577662882262042, 0.03644814634961741, 0.020957537926733494, 0.019887549270476614, 0.03679768687912396, 0.031234914303890297, 0.026204579676102315, 0.0502103801949748, 0.04833737248554826, 0.015185913969097393, 0.012631397561303206, 0.041257371859891076, 0.014867328207141586, 0.006783900666050613, 0.05625045465837632, 0.05538527161947318, 0.045201003817575316, 0.0541258190226342, 0.05879598217351096, 0.04336108486833317, 0.01469376403838396, 0.05357917085556047, 0.026965763652697206, 0.02435361417675657, 0.07216751894780568, 0.02636848998788212, 0.03832505902807627, 0.02823362499475479, 0.0384891593296613, 0.022490874398499727, 0.05587251404566424, 0.010949602716469338, 0.0344031775104148, 0.049429963143276315, 0.004918864470840032, 0.03652563165607197, 0.04866500311930265, 0.0478870796837977, 0.03178929777017661, 0.03919062204658985, 0.027622188607762967, 0.03884078635435019, 0.024940202611365488, 0.040184543534581146, 0.06887884291687182, 0.05292108688237412, 0.0688937639019319, 0.027576852290491973, 0.010336481866293719, 0.010256934661551245, 0.04804757017908352, 0.03268165274390152, 0.044112274024103365, 0.04502335317166788, 0.0669316238324557, 0.011802818942149835, 0.041349113187087436, 0.013311805336603096, 0.06160772951053722, 0.014651321672967501, 0.04990064252966216, 0.028084172567884837, 0.03612270738397326, 0.04865697265735694, 0.02397848100268415, 0.02769003532427762, 0.045024194555091004, 0.03466982820204326, 0.05416433606296778, 0.031737501799528084, 0.07100611805383648, 0.05846539991242545, 0.026007538195699453, 0.0762387765571475, 0.034298218321055174, 0.0879712373550449, 0.08546096312680415, 0.07685906612979514, 0.022739469273281947, 0.009487916149997284, 0.08330997319093772, 0.09002322903169052, 0.0117292004371328, 0.010831943896066929, 0.020018040036250438, 0.04623604113502162, 0.03430466779640742, 0.033637169149837325, 0.030464383507413522, 0.07909236236342362, 0.05715959998113768, 0.015612188327525343, 0.013526129103930933, 0.1690812235964196, 0.09984539662088666, 0.09135740529745817, 0.22908229753375053, 0.11068755840616566, 0.09057262526558978, 0.10399379687649862, 0.030245596676000526, 0.0654155391135386, 0.035760759841650724, 0.02790775346303625, 0.06304927715765578, 0.14872558015797818, 0.08964928838291339, 0.13104130194655486, 0.04501690708899072, 0.09083017001726798, 0.04066120081448129, 0.030938991611557345, 0.10754317963229758, 0.032760009967855046, 0.009294953513225275, 0.07885136029550008, 0.05095460758145366, 0.043349977250077894, 0.12284203405891146, 0.12039401541863169, 0.06542108952999115, 0.05473135045862623, 0.019235465243192654, 0.02548987534828484, 0.009429445091102804, 0.04796491443578686, 0.010573122650384903, 0.1455301009118557, 0.06146279443055391, 0.022415339880223786, 0.020248512937022106, 0.02925146823482854, 0.048062419917966635, 0.051397592561053376, 0.025056674843654037, 0.07312933555138962, 0.042209135967173746, 0.05883974768221378, 0.011930311431310006, 0.02165065466293267, 0.04287423259977784, 0.03339890497071402, 0.10323189704545907, 0.015082827536389232, 0.011293468996882439, 0.05085544986650348, 0.0231182495730796, 0.022966127110911266, 0.0483571314252913, 0.04422456817701459, 0.10061529637979609, 0.09788718526916844, 0.06039868188755853, 0.05772572210324662, 0.006605219070999218, 0.031453992905361314, 0.04218798942331757, 0.03697033332926886, 0.05052307966564383, 0.04897427938080259, 0.05133095024419682, 0.06362384704074689, 0.012784906779415905, 0.032166471638317616, 0.02041919672462557, 0.038213304310504875, 0.02335081066537116, 0.05698480936033385, 0.02421306073665619, 0.03563693059342248, 0.04034471172573311, 0.023337558876456957, 0.0653609170445374, 0.06500463866229568, 0.04180035933053919, 0.027335531311109662, 0.015770463405975273, 0.05879574468625443, 0.01599715177768043, 0.016047202216993486, 0.024119609501212835, 0.028623154985585382, 0.03319393311228071, 0.1652201557798045, 0.13813073081629618, 0.08522379478173596, 0.09956482917602573, 0.1399999726563692, 0.06646989432296582, 0.07102411958788123, 0.16979635879397392, 0.08951451097215925, 0.13879998347588948, 0.15513362416199275, 0.17487488128244877, 0.16387281593467506, 0.13299439714423247, 0.20599040734980786, 0.09237401360379797, 0.14271514410419123, 0.16323122036244186, 0.14230708671467646, 0.202468389911311, 0.07390424289873668, 0.09082631593836205, 0.09232847033334629, 0.14070746754961355, 0.09960963284330708, 0.13193657462085995, 0.0941154465877584, 0.10808608228606836, 0.09851495229772159, 0.110991718513625, 0.11509648896753788, 0.06658952683210373, 0.1504898119185652, 0.14359791816345283, 0.08934812740023647, 0.11807843324329172, 0.11409550053732735, 0.1184696222522429, 0.11768505935158048, 0.1721733891006027, 0.15056610639606202, 0.17072194841291222, 0.0862684537257467, 0.20668435868407997, 0.12773026818675653, 0.10888626506286007, 0.12400895144258227, 0.1791162679770163, 0.12877793982625008, 0.11048895120620728, 0.07668380053447825, 0.17054356155650957, 0.1775190643966198, 0.11821794004312583, 0.0893505158435021, 0.13497685933751719, 0.16922253529940331, 0.10939848436308758, 0.14261362169470104, 0.2066761619810547, 0.13202600553631783, 0.28009893000125885, 0.12209669048232691, 0.23273903131484985, 0.17491566123706953, 0.1516079833464963, 0.15640295962137835, 0.09642615009631429, 0.20562638688300336, 0.18254050851932593, 0.22739297603922232, 0.11419274817620005, 0.11634679830500058, 0.30951719571437153, 0.16006372390048845, 0.253139675195728, 0.14879092308027403, 0.08044711181095668, 0.13073000365069934, 0.10838870211903538, 0.1372055211769683, 0.10029080057782785, 0.11866664168025766, 0.12574919020490988, 0.3929198160767555, 0.21407201726521763, 0.27775157881634577, 0.15190405531653337, 0.12948585541120597, 0.26429082825779915, 0.33730100627456394, 0.17728936672210693, 0.15603094601205417, 0.18092544589723858, 0.1560200894517558, 0.12603356423122541, 0.15998356177338532, 0.17358301846044405, 0.17794802066470894, 0.2895935890930039, 0.4615089041846139, 0.24517864095313208, 0.2743068736578737, 0.12353624323649065, 0.21733510574059828, 0.284561926232917, 0.1136720607589398, 0.2798724078706333, 0.2708307387573378, 0.12325214062418256, 0.3183123937674931, 0.11362047174147197, 0.1753803084471396, 0.19057630375027657, 0.10574031887309891, 0.08549453703952686, 0.13117048144340515, 0.08538635141615357, 0.13889900887651102, 0.07617781697107212, 0.45184534415602684, 0.12443611637822219, 0.09982445024486099, 0.1344349134181227, 0.299951643283878, 0.10793506074696779, 0.19047228433191776, 0.21235868920172962, 0.1905791535973549, 0.07741771079599857, 0.11353595341954913, 0.08496315591037273, 0.11173319444060326, 0.13186559985790933, 0.13888478678252014, 0.23076254022972925, 0.052954993277255974, 0.0612571168957012, 0.11741587093898229, 0.15284225211611815, 0.1299426316150597, 0.08705459761300258, 0.13911771428372177, 0.18916003831795283, 0.1652132347226143, 0.14109324184911592, 0.14895683846303395, 0.1176588950412614, 0.09023050112383706, 0.2716289402118751, 0.13270715970013822, 0.1369194643838065, 0.10099059409861054, 0.09757607696311814, 0.22069806100002357, 0.10109278825776917, 0.17861884752554552, 0.14502080609755857, 0.089737837202847, 0.07149899232068233, 0.11808337297822748, 0.19603555223771504, 0.1819505358913115, 0.17059874002422604, 0.07695782690175942, 0.24417989168848309, 0.14768131476427826, 0.1791146666343723, 0.13923449016043118, 0.13592754118144512, 0.09156953570033823, 0.1076393076883895, 0.14755100889929704, 0.08926277448024068, 0.15226241680128233, 0.1488464679569006], [0.06339252766753946, 0.021799333559881364, 0.006846125719935766, 0.05076563557876008, 0.037545113558215756, 0.03417966128992183, 0.059934631788304875, 0.047316754037248235, 0.02761587992842708, 0.01894075712854309, 0.019093988995466913, 0.04100502807913082, 0.043150705085801225, 0.03232150331937841, 0.04701014781104667, 0.0590480307915381, 0.010379536609564508, 0.030662122182548046, 0.01960790463324104, 0.028959219809621572, 0.10046253779104777, 0.009834193774232907, 0.03981407359242439, 0.05308309390342661, 0.059868915671748776, 0.02291971361929817, 0.038215736858546734, 0.0541656795623047, 0.05490689764597586, 0.006530353757885418, 0.020189365039446523, 0.025124168721958995, 0.06664936683539834, 0.024167066240417104, 0.03645549488386937, 0.04523538179429514, 0.01905520393380097, 0.10288611559995584, 0.058029502231095514, 0.10588785952755383, 0.01605100031676037, 0.020826446657468165, 0.011265241940106665, 0.02824566390232316, 0.054011431589190445, 0.03205401124432683, 0.10820114825453077, 0.02665071136185101, 0.046153612700956206, 0.08136512219373669, 0.015463512823251742, 0.009403887221456637, 0.08676092087158135, 0.01718884247488209, 0.032529325024890046, 0.026207149627485445, 0.030852980512593473, 0.048004666409854374, 0.020052550327298895, 0.05082050192036799, 0.019335167482495308, 0.05475061746048076, 0.05847133709383862, 0.06451706375394549, 0.020024491207940236, 0.04964125555540834, 0.018905239212991934, 0.027338598289393952, 0.07341459167322942, 0.02104317074242447, 0.11701522315187113, 0.05478499543720058, 0.01797157502733171, 0.11620740007076945, 0.06398675471012082, 0.05306949945432799, 0.07983561605215073, 0.018263105901756456, 0.05826836012836013, 0.05171080432566149, 0.03507722741258996, 0.09524760940777403, 0.07445048394479922, 0.0261277508522783, 0.11371163970657758, 0.10428125823714904, 0.19252232861305985, 0.025548414260681187, 0.04972272725509746, 0.09792071846979004, 0.1491094681301287, 0.10988483112305403, 0.07080479671380349, 0.053033828868397644, 0.11604387313127518, 0.03896335692011884, 0.042991693796856065, 0.07289055907832724, 0.08091853758586304, 0.062432203840996535, 0.15595915700708116, 0.18017909808882646, 0.06625992166144506, 0.07969947478600911, 0.06978211551904678, 0.09050735698214599, 0.06091436850173133, 0.028760157991200686, 0.042478616149829965, 0.009702783593508815, 0.018946078539426838, 0.05806897261313029, 0.054474334964262586, 0.03243194167901363, 0.05987730236457927, 0.04682615286271487, 0.0038577167017917547, 0.10381697065063886, 0.019718448165804148, 0.05043384552534137, 0.056161179805972745, 0.06928299873002938, 0.03894040547311306, 0.021528274086969237, 0.013688488115024353, 0.02520292967424861, 0.04276982302378331, 0.05222321700836931, 0.023032818621556674, 0.031499244405754974, 0.032831418993217606, 0.05350029455231769, 0.03585683022226606, 0.04754449074555721, 0.029630389330642562, 0.04562199069187045, 0.053556049774800024, 0.06889236611979348, 0.046121843691383085, 0.02760426001623273, 0.03929468556972487, 0.048547263722866774, 0.047381404853825054, 0.050358891154506376, 0.03778268902429512, 0.03502883768773504, 0.06573001973863159, 0.07622098536895854, 0.00683607958490029, 0.03423102978350861, 0.010210490635862308, 0.09997881017625332, 0.06374290279511895, 0.030864189911101545, 0.032600411746118746, 0.015488711917506797, 0.0007983160103322007, 0.037435614969581366, 0.013601320962022458, 0.05494234092267496, 0.007213179238273629, 0.018981910277424113, 0.02596121121730123, 0.007234676075833184, 0.04331157895337258, 0.03774980043194123, 0.03874274143683059, 0.009861878002993762, 0.056151656566986015, 0.040026424519185505, 0.0602673650053995, 0.04064062424004078, 0.06619628864739623, 0.060880692808755806, 0.0364317868703178, 0.03789621811094029, 0.02933514517332826, 0.015461702831089497, 0.04950314314503755, 0.028510558884590864, 0.00207193403288589, 0.0684300802115883, 0.05878679480935846, 0.0449344345501491, 0.038857295111353905, 0.011957053344563713, 0.08661757356354169, 0.015764066517086964, 0.050164314452558756, 0.009394765166299683, 0.03217170653598649, 0.023731163470074534, 0.03164685969906194, 0.025163784989022782, 0.010553420537949672, 0.029359307805342332, 0.06525687048477785, 0.015054298531530159, 0.03264324426917093, 0.05794729092823608, 0.05152460753119417, 0.029898621008864472, 0.015388741656871778, 0.04601228064192193, 0.056586831608521085, 0.042573611052440744, 0.013023139576294591, 0.02068109597478594, 0.025068516976066997, 0.034966697450727224, 0.04338445022170033, 0.06402581118579422, 0.04046906344592571, 0.04581752412819436, 0.028154100690569197, 0.051587229528065236, 0.041482662449457815, 0.10865605170173304, 0.021227655932307243, 0.012381468517040568, 0.057578914266611846, 0.039344015065580606, 0.00976933685264417, 0.015437955801774348, 0.0067780936785441425, 0.00986083475540259, 0.10563043012682881, 0.023429649649187922, 0.04087861021980643, 0.028299872064962983, 0.04308768614594426, 0.010163860013043242, 0.05460963145430599, 0.08671783389789717, 0.07077629824302026, 0.027291080482038002, 0.026898134067388516, 0.1517779835100685, 0.07044789407934461, 0.0411786923318037, 0.051504183627132855, 0.022441792567925792, 0.01980024216962712, 0.11521744461996214, 0.07060757372528315, 0.012728120183705218, 0.005888593640910196, 0.014044752078396934, 0.03519408132082649, 0.04773660436538713, 0.051159460696258714, 0.055874990698482306, 0.0306928191067917, 0.03159105019377811, 0.05953059132610049, 0.05378512998244592, 0.03415429765092475, 0.10134595645857708, 0.126094822372709, 0.039278163242020776, 0.054153496466044865, 0.05023825102086578, 0.1589507907629013, 0.03071372816339135, 0.10170467078153576, 0.08019474428147078, 0.0950130737785782, 0.05817536011870418, 0.022441134388957704, 0.060816639102995396, 0.06191418306635959, 0.034079149897609434, 0.029378564629171575, 0.055241588436599286, 0.061636424756475856, 0.06121909857860633, 0.16976967879704066, 0.07658621362809624, 0.005505874445329287, 0.024907395443213836, 0.043779951320695024, 0.04471210576593876, 0.08939702941903047, 0.02164728573656508, 0.10188971406647138, 0.07586951779999904, 0.021984470143382038, 0.0692422187754086, 0.025663755035826137, 0.060066403288926394, 0.08556318442736353, 0.02653849184779184, 0.04135160680328097, 0.047073109075427055, 0.03172245528548956, 0.05462317501327821, 0.06083837936499289, 0.007155161949672869, 0.027931605665279285, 0.09911712498537131, 0.012169264323477234, 0.05653611450855221, 0.061419395330761156, 0.034135030649070225, 0.04409898491576314, 0.07816439108656985, 0.060554174972432, 0.029124480406088487, 0.0411872757997896, 0.01498784450814128, 0.016619909521458403, 0.04017959022894502, 0.11452626170856611, 0.05678089940920472, 0.05479134652497513, 0.03066356067678758, 0.028909266061548675, 0.05879887951804059, 0.037584733217954636, 0.011487820934105133, 0.07028386502393655, 0.03415451817480581, 0.005984429078775325, 0.08960044743227107, 0.04252762334155185, 0.03696854878216982, 0.055025067912148576, 0.017109579406678677, 0.04062588645943573, 0.01743555611132511, 0.05003816122189164, 0.033113971153008084, 0.039013466731246026, 0.06912877450564078, 0.04308942998094218, 0.03958242852240801, 0.03577425929584673, 0.03257165543202843, 0.027376942303297774, 0.0033384111635054326, 0.02589770542856838, 0.05774679061557565, 0.028123568311067562, 0.04293817434726017, 0.05426550902692335, 0.012674795812927186, 0.0034308378110706273, 0.02645281153464956, 0.028930558490433862, 0.05817823710718325, 0.01229380433713751, 0.0204517630128456, 0.12688387717519486, 0.08571404311805964, 0.14426029047795705, 0.09650746573294912, 0.062090086484594006, 0.19689377690000193, 0.1460470496011632, 0.116769797035626, 0.12320137263408729, 0.06685184847031321, 0.12927645950445107, 0.14046653333519185, 0.19260515059743608, 0.0952590291521379, 0.1376752709703786, 0.1374096923640796, 0.13255748844572476, 0.09685579168477229, 0.10873749626002141, 0.25503278789775713, 0.17770404661340372, 0.11692967345671994, 0.14823475506688866, 0.21411959614072526, 0.11203150557620184, 0.094269670812147, 0.09816472644784621, 0.09786635424409594, 0.1660607656730073, 0.15344964952341147, 0.07978961137788636, 0.11032865409340177, 0.09084640736026423, 0.1302282812872103, 0.1918585313750165, 0.1319894189281123, 0.11804257945290633, 0.1730064536843981, 0.10647009685635567, 0.1990546259496893, 0.11525204990591321, 0.20934338814445905, 0.054202028683253696, 0.19084104097315244, 0.14209285963858875, 0.18621561702873024, 0.1550467581089054, 0.11510682984122209, 0.08354115685714142, 0.1613655069044658, 0.17399795619504793, 0.08064540009945631, 0.2631859289748328, 0.12634953084800923, 0.18102582836789743, 0.12685396735157284, 0.12139640163098063, 0.18849854809897287, 0.14506625437310763, 0.14402709156274796, 0.12158796563744545, 0.2781164678079741, 0.159707601581301, 0.15357521921396255, 0.15607825347355433, 0.1555266316447939, 0.12693490300859722, 0.10322205828768866, 0.1264651803565877, 0.12139823367553097, 0.18097345903515816, 0.10338727477937937, 0.29139588666813715, 0.27807081597191946, 0.18780584526913507, 0.17704676331153937, 0.26387116791946547, 0.07986501018915858, 0.2317094494189535, 0.15121492158089364, 0.10803441862974848, 0.34458676246660097, 0.16953690057354315, 0.13630615015115055, 0.17920343258551188, 0.17777019020702156, 0.3210572036249297, 0.12791982372956617, 0.17849278928978102, 0.21093395565237316, 0.20463096243994577, 0.2110336867294141, 0.1771538361374821, 0.1566737765180213, 0.20394629346472876, 0.12795413046010903, 0.13834822843117373, 0.2379605754145554, 0.2047538994146245, 0.20328301191329956, 0.3112646405185972, 0.23246607024754795, 0.10772145792309727, 0.10155964749200003, 0.2559093194348471, 0.2334935622555869, 0.20575761555560998, 0.16859186414097035, 0.24020519639764512, 0.08822820535195725, 0.17958790409777844, 0.11870484320180756, 0.2567472830414772, 0.07951112025018249, 0.17351840835596832, 0.14516508978392395, 0.16093991617006914, 0.2029645618583475, 0.09966305390532527, 0.15669175769601548, 0.2016030813434294, 0.1715705514486347, 0.1189564439867224, 0.20212167208748205, 0.09535929627184357, 0.1549110918172768, 0.14077678668711865, 0.16058196180633136, 0.16485984011420182, 0.2503881885537079, 0.08663408910589558, 0.24660437873431615, 0.1441635585256985, 0.05395660595968366, 0.10059842799923249, 0.1854329811675208, 0.19318571873009205, 0.15051442916904176, 0.2142453965331827, 0.12037313011075769, 0.15303275760795387, 0.11980867039944444, 0.0906489265284368, 0.11679468570011002, 0.15687694347330502, 0.11058955759342227, 0.10016821644135884, 0.18511728596474442, 0.16058477094130857, 0.11337752906339509, 0.10923669447324105, 0.2806655067418303, 0.11713262328079768, 0.14468917889254435, 0.15906980580517224, 0.06615962740033865, 0.11257585350956235, 0.20270221307873726, 0.12613064902169363, 0.12328921577760152, 0.1490283967661006, 0.10891774908772536, 0.11821519876165049, 0.11408579748656068, 0.08816288278571197, 0.1305763561810766, 0.0796890389174223, 0.07924987069730248, 0.20918432596538747, 0.09368597463305507, 0.09482874295541219, 0.17372739714171204, 0.16622087279600756, 0.19725243694015912, 0.14881197123655251, 0.12366247789136], [0.0567642413744969, 0.07543915696442127, 0.05680902807840279, 0.032464161914374144, 0.04069199951897774, 0.04771173605695367, 0.04412677092477679, 0.021260186597438793, 0.02049065155110189, 0.02750318543985486, 0.03104872429477317, 0.12878163105675153, 0.029000861503716027, 0.00805433704850397, 0.00639503139869443, 0.049510087950953414, 0.0549635587127081, 0.05702294981373208, 0.019368648096652966, 0.03540715488738247, 0.07831594866833516, 0.03995499513777239, 0.07034201547503471, 0.030876451038888524, 0.03409536009920495, 0.12770962715148926, 0.0377462041963424, 0.02443474660893636, 0.0795246163117034, 0.03339711703093989, 0.04454624127330525, 0.007390934208940182, 0.05669287306123546, 0.028694842210305587, 0.018789738982117603, 0.029015741776674986, 0.03231340839660593, 0.029474387344505106, 0.0418659702741674, 0.032498176874858994, 0.019531477841415575, 0.07713869719633035, 0.018086476451052085, 0.012510642924878215, 0.026849274457033192, 0.028099078285906996, 0.01861882788528289, 0.05397473302270685, 0.023931002211091772, 0.043324481296752176, 0.04392719002706664, 0.014777439280546137, 0.04842935469267624, 0.041880497708916664, 0.04988399128030453, 0.10755238056715045, 0.03543179927925978, 0.0218044106981584, 0.02160586117367659, 0.05888670230550425, 0.018606336055589572, 0.014442465201552426, 0.0031463776956245837, 0.04777564048500998, 0.061480700969696045, 0.041362185164221694, 0.026315472654200027, 0.062064356436686854, 0.017696437558957508, 0.03195613935323698, 0.018366987916773984, 0.037302004639059305, 0.03587345093754785, 0.0647245461919478, 0.054190537692712884, 0.03342948654400451, 0.054008456213133674, 0.04261205006124718, 0.02914813413683857, 0.07574314743812595, 0.03956275779221739, 0.06627691896366221, 0.05918987175183637, 0.07149665816021816, 0.04394667076745203, 0.0932931707107595, 0.1363066251256636, 0.029075418931565115, 0.04323000886610576, 0.12953129011605466, 0.023901606377746378, 0.011736212248381759, 0.010827224685012229, 0.0875641977680581, 0.11980206146836281, 0.06910413011376347, 0.037042675340282064, 0.033509526534804275, 0.024650581813018237, 0.028601146702255522, 0.07349742722830602, 0.07501767136688743, 0.021183232244636332, 0.049229883522327454, 0.06647247275603668, 0.025113308768985525, 0.09340985159256629, 0.05590942635067871, 0.045867688222123046, 0.07152379277561392, 0.049510892014950514, 0.04542426898011139, 0.04573452911738839, 0.013041195393140827, 0.029543146690619842, 0.03471658605017832, 0.04805942079318421, 0.04432892347020762, 0.02618770281385098, 0.05847312842628785, 0.004188487680429327, 0.03403256846857922, 0.023292151313009005, 0.025165315085489835, 0.053735216946474144, 0.05403681558423808, 0.01414230081718415, 0.04570989829621144, 0.011996144595156823, 0.013619188485401017, 0.02948944064389382, 0.015005406690761447, 0.009609136431078826, 0.02795801085552999, 0.05077639714415584, 0.028486935687916617, 0.06716904323548079, 0.013169683632440865, 0.0037702263964872274, 0.037261540203222206, 0.019462928841156617, 0.021157777003411735, 0.04974338186106511, 0.021280713978090456, 0.015994018642231822, 0.02031331472764058, 0.0832074194082192, 0.03947143715673259, 0.07197488964136158, 0.025960486881168823, 0.0366963578521141, 0.06534343798245702, 0.04065836114542825, 0.05188458053661244, 0.004010952809559447, 0.05191980328943048, 0.04373052004458649, 0.05312066778008427, 0.060803970854197226, 0.022425526387191246, 0.06395219692162105, 0.005494578957690724, 0.03355550406766789, 0.06967625048543725, 0.007501491312203663, 0.08277895847069365, 0.024237861191587787, 0.010020879113913646, 0.04169533568035279, 0.03109596051009638, 0.028347556113398502, 0.03490639604361994, 0.07515721209347248, 0.06247301772236824, 0.009874726911740643, 0.041696285629378896, 0.043498929257371595, 0.03523576033434697, 0.1367194458310093, 0.019676071957552006, 0.026957918091544082, 0.05955391936004162, 0.07253637736929314, 0.004165386955719441, 0.01875711332208344, 0.013120687466913035, 0.023977985672120537, 0.04941603281934347, 0.03125100236918245, 0.06340281425842217, 0.03265438920685223, 0.007678991832238222, 0.008251413303826536, 0.026244370665933405, 0.0497437380919499, 0.043821202857153754, 0.05245612754619547, 0.05282882647588849, 0.031299863675875325, 0.03788673558405467, 0.060054155731839795, 0.057756656514746804, 0.05331069829740694, 0.026522018713876605, 0.08711174383227314, 0.004880368634725788, 0.061361794493028095, 0.04785797731684787, 0.06328144469963652, 0.021284327177064757, 0.014744767819398215, 0.020474191987887025, 0.043901890848896334, 0.029575526381709745, 0.013084354461170733, 0.04384285490959883, 0.09957240841218404, 0.01575555599161557, 0.018670215038582683, 0.034562653595847745, 0.03339257084631494, 0.01471696823968419, 0.01733325677923858, 0.018013342250404612, 0.04232881597376295, 0.03354580780225141, 0.051275934624884806, 0.025162261677905917, 0.03335467466552343, 0.009196350500652832, 0.05682003052373018, 0.01833782108899738, 0.04412137657137854, 0.08006546978971787, 0.04212871599676354, 0.04308476844536407, 0.023814136428492408, 0.017269908749897565, 0.04099783900060824, 0.05369438949440207, 0.014804601037342633, 0.09022111698452916, 0.007756767212413251, 0.10511498778526272, 0.030771993965442692, 0.07973204446690423, 0.07209309722696032, 0.020801466390756623, 0.031156417980257953, 0.0544285440285291, 0.016578332288190722, 0.012690101018441575, 0.08806380988763911, 0.04753833643293806, 0.1152789198926517, 0.05227743195635932, 0.07126330996730498, 0.12472343524651867, 0.05431660271382757, 0.032299427182546685, 0.03351836106074708, 0.0332389674814684, 0.15463486021118505, 0.06430152031992163, 0.0185914116778544, 0.10037042666226625, 0.020883657337565507, 0.029524059500545263, 0.03570409877491849, 0.07362484253410782, 0.08971724366503102, 0.1252675796193736, 0.037330289371311665, 0.0314212671614119, 0.06607707682996988, 0.11455091967114381, 0.07333882645304714, 0.03582686950851764, 0.07275438388543469, 0.028097454890874878, 0.019311444201905812, 0.007755033555440605, 0.03188878118193575, 0.054715286142059734, 0.02661504247225821, 0.02924389239134533, 0.0420423317035394, 0.03805473406932183, 0.03433954788904105, 0.010763511094929916, 0.026618538623941795, 0.06982436789465801, 0.0080256680957973, 0.04679215147293039, 0.03757100984720247, 0.021078184845724275, 0.0006317711273108476, 0.07171440004770245, 0.03001122728788427, 0.021194467088207603, 0.060768782028130124, 0.06054046177970512, 0.08923434386295931, 0.04013399267569184, 0.06574255228042603, 0.03706854788054313, 0.03978392967422094, 0.018228692301948155, 0.040612946796630106, 0.03247429244220257, 0.010797962014164244, 0.011206551205499895, 0.056635906653744836, 0.028361362604690448, 0.06195746681519917, 0.042794233321079185, 0.030387573343302523, 0.03878223556759102, 0.028097381948360374, 0.07399933279625007, 0.030708072574010918, 0.048526235922638855, 0.07085456047207117, 0.029054421665413038, 0.056621050129511526, 0.02374765356736524, 0.05584289259942515, 0.024542564127062048, 0.022543242034901465, 0.1006146856982793, 0.023754888447001576, 0.022960564820095897, 0.06330870823668582, 0.04029062230672155, 0.022225884421329414, 0.024072698982698575, 0.005635504319798201, 0.022337491557534252, 0.033801832635487826, 0.03776975953951478, 0.005664764022055481, 0.16519348935357162, 0.02184716349334589, 0.04129368026873895, 0.06565628333815507, 0.022233943721013408, 0.03116009903273412, 0.02598856296390295, 0.13240453308182104, 0.04683921466182385, 0.0032272503761175486, 0.006116749768677566, 0.15539769642055035, 0.13320029181029114, 0.2452716545334884, 0.061577344712402136, 0.21464041247963905, 0.14276513856436523, 0.15284757183066436, 0.08550321550241538, 0.09216454984354121, 0.10687256311731679, 0.15009095546390328, 0.22696159061576637, 0.08795238765222685, 0.12567851399736746, 0.14534016538943562, 0.09538341819175652, 0.1266741691423314, 0.10882622149905988, 0.1723707342254264, 0.18100939424974577, 0.1609340129154069, 0.13584530273718493, 0.17033420636185578, 0.1403405022408281, 0.11967797098415238, 0.18289990137730325, 0.10745989624410868, 0.06328891537019185, 0.1178835037031344, 0.0985006419941783, 0.17423559272927897, 0.10714027910892453, 0.13040062918194703, 0.16313093288668565, 0.19125460806701863, 0.08037781302950212, 0.23327683817063058, 0.08755159737276179, 0.2009531126490661, 0.13008439115115575, 0.17301809734531812, 0.12957084870764188, 0.051650312928748984, 0.11046769270407301, 0.10820458164172513, 0.14073365900133336, 0.17649287517581666, 0.08048402411597115, 0.12634043847875936, 0.14323974666850908, 0.33213162794709206, 0.17341790374900612, 0.10477641916700772, 0.0937440504453012, 0.11552966572344303, 0.11575491220823356, 0.14718010808740342, 0.2401488779910973, 0.12270957045257092, 0.13299147944365228, 0.1971962135285139, 0.12142612146479742, 0.0793509656297309, 0.20725073186414583, 0.10584984121045896, 0.1770280221743243, 0.14882582692163332, 0.14050929461206707, 0.09991903802646057, 0.214624765462109, 0.14241479736353668, 0.09319343284836837, 0.11028269013123852, 0.15582312430654252, 0.11761086833264146, 0.16576153172978333, 0.22194100144718373, 0.2124063087893384, 0.2604413905314037, 0.21867283752986363, 0.1386705461357321, 0.18151695201439516, 0.18921034490423544, 0.1425568690257413, 0.1338116925741945, 0.2635153984384877, 0.21763185624565395, 0.11942590879542486, 0.10645050755036728, 0.21145941317081451, 0.16269878750400885, 0.09105833420263869, 0.09080960362085275, 0.11100657164518322, 0.25905655484114376, 0.19062028639018536, 0.08778827717261654, 0.14931648916431836, 0.18681914678641728, 0.18414080621940748, 0.18646151811948844, 0.20764048237885746, 0.09054442535021476, 0.16166611148842744, 0.14169443744633878, 0.09218631724693946, 0.21412282596741403, 0.122218840356384, 0.12337026000022888, 0.15701345114835671, 0.1234291839812483, 0.10622279798345906, 0.1128715251439384, 0.08601776896310703, 0.1521096649978842, 0.10106583684682846, 0.11711020448378154, 0.11053359202508416, 0.15156026876398496, 0.15690424772245543, 0.09320690176848855, 0.13161142063992365, 0.07581608995263066, 0.1044266140088439, 0.18060436312641415, 0.2192603810025113, 0.20813422517052718, 0.1325976848602295, 0.09122477884271316, 0.12600613784577164, 0.11011674082172768, 0.09635118554745402, 0.11517775032137122, 0.1146858667156526, 0.1942242437175342, 0.1721795637692724, 0.1698097666459424, 0.10884393804839679, 0.336485352899347, 0.12569489383271762, 0.08807767914342028, 0.1005243251898459, 0.15207461187882082, 0.164398585579225, 0.11173803239528622, 0.12660204086984905, 0.18057943374982902, 0.1887313670345715, 0.1567350346595049, 0.11264158998216901, 0.1118315209501556, 0.1438455834452595, 0.10114274200584207, 0.16939617241067545, 0.16700505571705954, 0.1300884216491665, 0.12194511932986123, 0.13730749141957077, 0.11268817819654942, 0.08329709459628377, 0.12673934921622276, 0.10066525012786899, 0.13577284876789364, 0.15345216010298046, 0.09956959249185664, 0.29154407871620996, 0.11161702924541064, 0.09577694136117186, 0.19996930472552776, 0.061320973826306205, 0.10700402249182973, 0.1685309452669961, 0.18856416243527616, 0.23968587283577236, 0.11525196848171097, 0.07067375124565192], [0.03859171311237982, 0.042054945669536076, 0.05592390628797667, 0.005429350538179278, 0.07129431223230702, 0.02159985274608646, 0.02943202979596598, 0.055649659396814447, 0.024528674515230314, 0.03839784887220178, 0.03745075308584741, 0.027213717311886803, 0.027644178231379817, 0.047823653622929535, 0.04818867492888655, 0.09449665434658527, 0.0202302179365818, 0.020594703199874078, 0.053821194118687084, 0.04019422622929726, 0.0069024903516817305, 0.04108287640182035, 0.038859184831380844, 0.020081498327531984, 0.030946489423513412, 0.029343643824436834, 0.044546197168529034, 0.023711675944338952, 0.005671773288798119, 0.017715039596493756, 0.06721464078873396, 0.01864674111961254, 0.012340419692918658, 0.01619543836984251, 0.026926892077816383, 0.020377073270667876, 0.02998012663530452, 0.016817176614754965, 0.01876984433537083, 0.03743283297600491, 0.04481192505253213, 0.04373104590922594, 0.03414119513971465, 0.0400581087118813, 0.043673845407153876, 0.08098887452589613, 0.03633269022351929, 0.05596777357693229, 0.06999970812882696, 0.028356158241097416, 0.044502272204096825, 0.0037919641139784028, 0.030712350737303495, 0.014666251139715314, 0.03641061657773597, 0.05646609647997788, 0.0161205162294209, 0.032769923364477496, 0.03104156575032643, 0.07249853547130312, 0.026467327095035995, 0.04713303389559899, 0.045807257893362215, 0.014454020652920008, 0.05229367947738085, 0.034749220191900215, 0.05267120957640665, 0.01379971781612507, 0.013607994353930866, 0.004343427335178214, 0.08112281733857733, 0.013426900990972561, 0.03266464865633419, 0.023978964458884935, 0.011864665712762092, 0.022438391411144818, 0.09088293968566827, 0.008147030021063983, 0.09461652434297971, 0.07527139596641064, 0.0111498570601855, 0.05708680674433708, 0.02854961875293936, 0.03801788961780923, 0.022208865066724162, 0.04367918887042573, 0.0736162658514721, 0.004360548894120646, 0.030692968384495804, 0.07286252879670688, 0.029492772250835384, 0.04220240150711366, 0.03404700090842588, 0.0368454591371119, 0.008460830414800771, 0.009256606954815132, 0.028010632942563722, 0.09605438754494701, 0.046249109719480784, 0.053502940838890414, 0.09179495181888342, 0.023762737400829792, 0.044647892604448965, 0.07306220129664455, 0.0932828773345266, 0.01587779916423772, 0.01752893440425396, 0.023305808526596854, 0.01471587919097926, 0.007193512748926878, 0.03616123799500721, 0.023380243818142583, 0.060850070523364205, 0.055118793954274485, 0.06661551472331796, 0.041230145642267804, 0.01049389605343874, 0.015933316899463534, 0.0454522314082299, 0.03227969877687948, 0.03186138533055782, 0.02861863254968609, 0.014872561408472913, 0.06742128862866334, 0.029812453846846308, 0.029063205301229442, 0.034125079933021746, 0.008179886383004487, 0.005379568544282977, 0.02291282479252134, 0.105652523227036, 0.04090331907251051, 0.03607836172782949, 0.042546381442142386, 0.0513330706661301, 0.050545400075082264, 0.13372773065098695, 0.0572823876781123, 0.015512689648728286, 0.03807572115744863, 0.042631194926798344, 0.13320837994771345, 0.11892156728676387, 0.06555956495659691, 0.051254418279443464, 0.02353653757433806, 0.013205656166454511, 0.027223014937979833, 0.019759043219632337, 0.022224469675815532, 0.10896015752639089, 0.06290110546563353, 0.00014837282729526384, 0.022146120933549743, 0.05452766442405326, 0.021406091982498765, 0.04261470991852028, 0.04195444106257387, 0.010581818924817656, 0.03300674565668617, 0.03145459001617772, 0.03669774206355214, 0.006826647948141077, 0.07589405362627336, 0.06245135888457298, 0.006266256478349013, 0.0029478408936743756, 0.05544485038678561, 0.014010823631126965, 0.03327229372890932, 0.04467027408203908, 0.05885662963347776, 0.0370304583172713, 0.04111401776650122, 0.07531838451645204, 0.018727634368198257, 0.011342315884706165, 0.023245005003575767, 0.03814415819942951, 0.08659671539706842, 0.07115200308284589, 0.03672518541238137, 0.03854355748210635, 0.10081018520785229, 0.007029116436439965, 0.05894222682608025, 0.06531841361096927, 0.06994188337453774, 0.06693876202085189, 0.010166471524696265, 0.03209555794351867, 0.05644333502277732, 0.01881653263366648, 0.02085653968554522, 0.04930751132113593, 0.06779732595064811, 0.053791284295065064, 0.06453808476882321, 0.07403773787830557, 0.03498749794172389, 0.030590971000492573, 0.0450628540877785, 0.03803269525191613, 0.03123815091592925, 0.09468932436513049, 0.034482287908239026, 0.04152695721547518, 0.051341314866606674, 0.007638673281430134, 0.06185614796621459, 0.035730208802436075, 0.0204853504962687, 0.01569083223252424, 0.021946875910673822, 0.033964955846646, 0.014221813247006918, 0.02067508585085826, 0.022001084073313644, 0.059181030440543375, 0.06944676315678017, 0.08044054359197617, 0.046914226708135436, 0.021806778785373484, 0.054437371769121716, 0.08181330814425435, 0.009164499218708702, 0.05418042412825993, 0.00810521699687732, 0.02237128429780049, 0.015399744102199162, 0.008776168538523572, 0.05347320404169815, 0.0051888921464394245, 0.028247879319159046, 0.06550437970353024, 0.04195830871218017, 0.04482838631208454, 0.05384286652718272, 0.0564804949930736, 0.025349147185417156, 0.03522823538099017, 0.04112127469852567, 0.02518036329586591, 0.014180832276386874, 0.043622005331729136, 0.015681039275867597, 0.08426030898200614, 0.09185691563678638, 0.01857846522969859, 0.052449854489948065, 0.013776686641254594, 0.031129758339375257, 0.018973681343985454, 0.056094917468726635, 0.055470251345208714, 0.030946597989116396, 0.0428651639792536, 0.08445557100432259, 0.05436621040904096, 0.004118161342505897, 0.027366988194574202, 0.022627858744402016, 0.03204436247636165, 0.07694302126765251, 0.04692309855350426, 0.02668634632469288, 0.03937300208157726, 0.02710479887069336, 0.030089079003248895, 0.023276891060439602, 0.02272539136798254, 0.05545585622478809, 0.03793400572612882, 0.032134726377470155, 0.06771326903253794, 0.023739324550011327, 0.04688381476859961, 0.08094219131661312, 0.028399881341361573, 0.02083108274798308, 0.07620653257306133, 0.02811673715976732, 0.04875369443159018, 0.010747609626767891, 0.0565529387843396, 0.009162683289365044, 0.07785016830478396, 0.00412217530122559, 0.018360248367701257, 0.07457922917923757, 0.03564272867515683, 0.04911551305225917, 0.02958741770791156, 0.04767196372683559, 0.053028556651302745, 0.046716766232358556, 0.020510181485276138, 0.023604850783678036, 0.030509119321193014, 0.018483792631221668, 0.04359035167310919, 0.042430202676249404, 0.007043275765941611, 0.04284655176369207, 0.02046265180355736, 0.0374693856574595, 0.018308515161541954, 0.023921087118131772, 0.028571810240724256, 0.034915963387382884, 0.054931022958563905, 0.06714155578187533, 0.034063401099826605, 0.037645814940333366, 0.027569612321842994, 0.08181741328111716, 0.030996585663940226, 0.06929460846419845, 0.038996896906090636, 0.04844262344496591, 0.05989294259675911, 0.023449506976508667, 0.024607386273731078, 0.019964093109592795, 0.018372987862676382, 0.04635690857789346, 0.0778952773128237, 0.060342288842158656, 0.051490358476127894, 0.06013228225388697, 0.06634148157068662, 0.03315351617389491, 0.039103939197957516, 0.02839645304317985, 0.032871500056769164, 0.05046422014545117, 0.026242508087307215, 0.020910729188472033, 0.021815380913072398, 0.0161495592245566, 0.08930472151509353, 0.011047022533603013, 0.016468502913734744, 0.03518825949036649, 0.04652835402105536, 0.04453221256179469, 0.07849483764065163, 0.026276558670880537, 0.03652003713484321, 0.053146974582757266, 0.042885767695094855, 0.03871756100228854, 0.1456226666590997, 0.0873346629419497, 0.09772986013974462, 0.15173105602817877, 0.12946081746901783, 0.11836199302758489, 0.09608752040990762, 0.2145805521202939, 0.08870387875608035, 0.10841583673443113, 0.26558324747851914, 0.1123445952045066, 0.11206885214362826, 0.19543757289648056, 0.13990868255496025, 0.33582777104207445, 0.12439859339169093, 0.16344106410230907, 0.14895487071147986, 0.17327509926898138, 0.1433949140565736, 0.09759504880223956, 0.1417500637471676, 0.0986431682748454, 0.1161816157400608, 0.2637280241719314, 0.11169371048786811, 0.08707879417176757, 0.14549044732536587, 0.0722731329234583, 0.19520141556859016, 0.12275086609380585, 0.10738567129841872, 0.12526382053537027, 0.13409211752670153, 0.12326313289148466, 0.09755573448325906, 0.1329962970422847, 0.15540826799614088, 0.22209493390151433, 0.18104017259819166, 0.11841858284814016, 0.13017945390726837, 0.23093950216259274, 0.21198431429054054, 0.1434814001300505, 0.08711417977299009, 0.20252370408603124, 0.12656854838132858, 0.1099451325301613, 0.11631317010947637, 0.08506627287715673, 0.1596221061689513, 0.11066015916211264, 0.08638847299984523, 0.12822828574904374, 0.11988542628075395, 0.07464191224426031, 0.11675252153405122, 0.15044509646083626, 0.08555981210832085, 0.143722836460386, 0.16048668191901275, 0.09734189417213202, 0.22545375009732588, 0.1306811355586563, 0.14924807926373823, 0.12151081620582513, 0.18097260408103466, 0.10794517770409584, 0.3052014415817601, 0.18644942662545613, 0.1034155221922057, 0.14882313992295945, 0.14083391933568887, 0.11112873508994069, 0.14437473219420227, 0.16894124182207243, 0.21337744167872838, 0.14447149128786155, 0.06782030793172972, 0.1908638940325805, 0.25049661844968796, 0.0662540319774832, 0.08740668943417923, 0.16962855708386215, 0.14743421945188726, 0.14606311731040478, 0.08061860475156989, 0.18764244046594414, 0.17391033018273966, 0.12390459275671414, 0.13223713849272045, 0.14364061158682617, 0.22146100577499184, 0.11810828878411225, 0.07317255823207752, 0.13501591581319058, 0.20563862765473978, 0.11911747391734805, 0.1333835098360266, 0.2020287535020283, 0.12266117733504091, 0.12340775584535939, 0.18038732691534928, 0.07307721727660724, 0.14010146792445863, 0.10458775250507252, 0.11016080488583871, 0.09479788996811424, 0.16062438381569727, 0.08236428536474705, 0.08179995457508735, 0.09778150344001395, 0.12403536002550807, 0.16946641435580595, 0.07252719679049083, 0.12734506385666983, 0.1087242987539087, 0.16347295524818556, 0.09166329566921506, 0.11984395422041416, 0.08147904143801757, 0.12429038062691689, 0.13913459623498575, 0.14292212442627975, 0.1069728166663221, 0.09350958266960722, 0.05390414163204176, 0.07700395371232714, 0.22541451720254763, 0.08011321829898016, 0.10877180977591447, 0.11443483590015344, 0.13845042937568255, 0.16140866173165186, 0.22883750924042293, 0.13868296332657337, 0.09216853284410068, 0.13916967649544987, 0.14038847466664656, 0.23594920762947627, 0.15116924260343823, 0.0995719198669706, 0.2179910455431257, 0.05322613926338298, 0.1253257164997714, 0.12376520809318338, 0.08274997824004718, 0.08331192737179142, 0.26665061020425385, 0.13273776162947926, 0.1576858250690358, 0.12356008695704596, 0.13750447013548442, 0.07292470296046563, 0.17065252070980413, 0.12239137824092593, 0.09493010251649789, 0.19581382056432112, 0.13469153536217554, 0.11580455383019787, 0.0761410810851625, 0.14426384600145475, 0.1643903481640986, 0.07385017722845078, 0.12399927553321634, 0.08342637587338686, 0.13088418037763663, 0.13269067129918508, 0.158461865569864, 0.09293869723166738, 0.12751153563814505, 0.1977154285247837, 0.2135768359793084, 0.12105262864913259], [0.01906860669675682, 0.03606367823002594, 0.037175468036106656, 0.046559868579996486, 0.0721395429489868, 0.0673202954764877, 0.05657580880714314, 0.08428130285548312, 0.05577963277963655, 0.05275368211524827, 0.027648890657084327, 0.020906057474868636, 0.07182095718703099, 0.05910548235156706, 0.053271750387336524, 0.10194749810865947, 0.04196199655000653, 0.016638855915516615, 0.017261496612003872, 0.025495240863944803, 0.029204204878104583, 0.034363751233156235, 0.02801428346096405, 0.10278372466564178, 0.05036335252225399, 0.0057219831838405556, 0.028469286992081573, 0.03198769462427922, 0.03927913693977254, 0.036274678872099946, 0.026878275043730224, 0.016486419630902152, 0.09738219915223972, 0.020883752332468117, 0.027173911055017794, 0.028725230401115756, 0.015935042074748447, 0.06300317748848881, 0.04412279470956751, 0.016198423923924565, 0.014091630366497805, 0.012239919326800321, 0.03564373629965952, 0.018738730112090707, 0.029657734291894094, 0.043007235641458204, 0.03638930379280022, 0.06033656879195145, 0.06280993750052792, 0.0197402087838522, 0.06158286798745394, 0.037656718998083046, 0.03296677655141268, 0.05342276853376201, 0.025824918977117965, 0.023535521468147635, 0.08303123100527696, 0.03361960527087961, 0.03782474123207586, 0.045678906209234676, 0.028471926493304114, 0.0053073830204084516, 0.019514081899874976, 0.01992142173860754, 0.03219964521537934, 0.03581436750079904, 0.036162584887019227, 0.027402616372065883, 0.027793009798707705, 0.07165786450994865, 0.012617345949235772, 0.06547907713268485, 0.023716267930077653, 0.02197180189458387, 0.052792843763849566, 0.01438068289176694, 0.058788959336067946, 0.03921003154079829, 0.03615335341809051, 0.05110695904919079, 0.044731213312063894, 0.011500150763562747, 0.03720417006739548, 0.0350213296977537, 0.0857770654505917, 0.05912000300096614, 0.11060230048107249, 0.017450819756569605, 0.01896786969155073, 0.03149939707613417, 0.026130061264016798, 0.05332581605762243, 0.015964156316061105, 0.03535800859598177, 0.06896365979420287, 0.07312897592782974, 0.012216609104403427, 0.03210580042962517, 0.06777617601411683, 0.06327896804681846, 0.06679716533316032, 0.12652537998344215, 0.08424675185233355, 0.038741442042269876, 0.06748913534517799, 0.026099851188649024, 0.061617208644747734, 0.06935609730758838, 0.051433619377868514, 0.046030818218631406, 0.04379755251907876, 0.04059914878702589, 0.06524129132074968, 0.11193868198565074, 0.02433473733253777, 0.07388873837356057, 0.032975763747734685, 0.012930230320697384, 0.02965093537100724, 0.023987159465572665, 0.047665656743837256, 0.017410501205761517, 0.02558273625826197, 0.0429732987125005, 0.042292266684983454, 0.07786261942237616, 0.039045629291129966, 0.06345304620585271, 0.05056066032765167, 0.04702071938663721, 0.04113886571888413, 0.033300544534410746, 0.07221267545329672, 0.013098495130959367, 0.043008250051311085, 0.027255248744040728, 0.04339908282937748, 0.06775871052273683, 0.006008007322504584, 0.05013308148565037, 0.01913638725610716, 0.055492327482040436, 0.06757091917097569, 0.03031182169382061, 0.0062290723352426925, 0.04924340333257403, 0.024456274828740528, 0.07451493798622064, 0.030995316803455353, 0.04883286589756608, 0.02315895488884832, 0.06944385224155017, 0.04854742317859616, 0.013833827771512526, 0.020528661386509026, 0.03885501523369125, 0.022650581185839007, 0.10150864201464824, 0.051762369594403675, 0.07757172467453138, 0.011294705626953925, 0.02338638116738626, 0.055010947598410506, 0.01957399145300899, 0.05986742289470775, 0.023592988295214515, 0.039835874922573566, 0.01564892760611006, 0.04714812451441373, 0.032398839348128865, 0.014896988669144256, 0.040540567466190884, 0.031782200293881555, 0.024295660500813807, 0.017751230958050916, 0.12090605151440416, 0.012396597303450108, 0.033777025395206044, 0.04933260693880064, 0.04739436487268124, 0.030364065497581447, 0.084268709245537, 0.08404483340148415, 0.030933444587779895, 0.0138325224397704, 0.07349656548883234, 0.025731695050905858, 0.019673069440094487, 0.0404955772017794, 0.01763932017742523, 0.035445763529943566, 0.005717043872989182, 0.08627043504800115, 0.07530229645115988, 0.050142234923051934, 0.04669432707929185, 0.02886549716017076, 0.031574246274041276, 0.03400743553148849, 0.02419133574169661, 0.04383472606007542, 0.06056380338434662, 0.06749955085771424, 0.019943440199962685, 0.029594579645033394, 0.038919686406318627, 0.020456370265622224, 0.02572181388469679, 0.08097932753818375, 0.033474354672112634, 0.01534367844994579, 0.017508067756092975, 0.06869923469743558, 0.015515785464750869, 0.05087043870506542, 0.013203645158292992, 0.004433143235343907, 0.03353786894253322, 0.04913611676810043, 0.010904498797442232, 0.019076386100745628, 0.0325343699327537, 0.027115792834333012, 0.03296471719763108, 0.06973485555499792, 0.05315762758255005, 0.05402327881061605, 0.014816315944439598, 0.011673479989570166, 0.018482857949233482, 0.04863971072648253, 0.05247727748272674, 0.03598722429679973, 0.025846886548346708, 0.039365938532033136, 0.041025034684155665, 0.035493132059595416, 0.06515374673264367, 0.015930575617988194, 0.04120864965287702, 0.03341046720743179, 0.05585969991183706, 0.020300329263721193, 0.01445302999179278, 0.01923416245595685, 0.025033000756853392, 0.07410030559237514, 0.03054112581802266, 0.025282694858365824, 0.04509706921609385, 0.007354397642692285, 0.04176081091697727, 0.03924051811918616, 0.07517934590578079, 0.0850149824150971, 0.04054966662079096, 0.024008962492059385, 0.020815562955769043, 0.05654957664332219, 0.04373560905722635, 0.030585834490401403, 0.0443801426860903, 0.11736564577690192, 0.010223963796826345, 0.03726770130119153, 0.013837576677490557, 0.023083710444292853, 0.03719763916784099, 0.04205091177885022, 0.04458788975274988, 0.05481240825195398, 0.05516955855169466, 0.013331970549188554, 0.006556351827124932, 0.0870795880577394, 0.03952222550287843, 0.05462807064343776, 0.10555452241429261, 0.07141540359173502, 0.06784198712557554, 0.08401721702622515, 0.03551927601386394, 0.014354415104857512, 0.07132648836289134, 0.013577611252133335, 0.022804405074566603, 0.10210333724639245, 0.01947908306361309, 0.02314202713647059, 0.04537972654881222, 0.025589591158287864, 0.050551089591213634, 0.05933517324072974, 0.02662045548536948, 0.03686550984691296, 0.05788670453642096, 0.024401986938236014, 0.018888350476377776, 0.02289641951210797, 0.053411779659135, 0.006867395248264074, 0.06266324501484632, 0.0429316298770053, 0.031618697103112936, 0.04361481286053147, 0.014898559477712427, 0.03060914556096707, 0.03918979762654219, 0.059426144430679936, 0.006106768094468862, 0.031256121915898154, 0.026018788306308643, 0.01057204038703016, 0.062341253007096906, 0.03727296334026115, 0.042083040411983214, 0.04264821597774114, 0.05098917554797871, 0.04060622929994549, 0.027219087916559408, 0.0324100691026875, 0.04192065341132028, 0.038435293827205896, 0.07781521696597338, 0.010310690750234892, 0.03518993886453765, 0.03433737996965647, 0.029937389107154946, 0.03620854884918247, 0.021911295230633447, 0.04366397611530764, 0.01724807688567255, 0.02412759925105742, 0.11595554144254752, 0.009805662224867513, 0.06108994622315679, 0.023763499056388224, 0.024449638756258146, 0.05065094619723303, 0.02847446421427386, 0.030442846805921624, 0.06915148507271494, 0.03767680702731013, 0.03432739193418196, 0.057539138543818674, 0.024405705310138207, 0.05840785335749388, 0.037685041049761434, 0.05032075748645833, 0.014521107410213776, 0.028582646444972073, 0.019127713882231286, 0.12197863895978246, 0.15223378262349538, 0.08227176032960415, 0.12631005368062428, 0.18857235913830145, 0.14553518992449554, 0.25574546679854393, 0.12391471649919238, 0.09095781602497612, 0.14372331143489905, 0.11620516090520791, 0.08195546123066119, 0.14188396584774765, 0.07754881054695163, 0.12043385899492673, 0.1267843632293599, 0.16594327054917812, 0.0898199670815042, 0.18364401002015385, 0.09507033534880195, 0.08508131599852017, 0.1459815302597625, 0.10171740009848561, 0.15261327368872507, 0.12217276782861777, 0.09240460874778883, 0.13378810669694627, 0.12603821898145334, 0.07715740440679447, 0.10324809367635421, 0.1112353057999696, 0.12405441328883171, 0.13800334265189512, 0.11060584921922002, 0.11757027836782591, 0.059879012272826264, 0.15209730208984443, 0.1384534149297646, 0.13285088698778832, 0.11636454878108841, 0.07786410541406699, 0.11040703845875603, 0.13771359462823185, 0.08206982152270419, 0.08561487522508417, 0.19870169274508953, 0.15542204225701944, 0.11520254399095263, 0.12049994830574308, 0.09608961708311524, 0.1795563115073102, 0.1606916266360453, 0.09582473058253527, 0.1024508693122438, 0.10665836318262986, 0.11694154781954628, 0.13384755993528025, 0.12979340819375856, 0.1395142637193203, 0.1634237886007343, 0.11257062200456858, 0.14182829883481773, 0.0753867265635303, 0.11992304426218782, 0.08981934961463724, 0.13511072072599614, 0.17493315386985028, 0.09341868611850909, 0.10072772963238613, 0.1419424827077559, 0.23250488245061465, 0.13473500231547014, 0.1527424260441746, 0.1751620780144419, 0.1014583082869649, 0.17316557014627115, 0.1017216748691031, 0.16924848247851643, 0.1983661028955664, 0.18215550774974482, 0.12281880101987294, 0.132161766822849, 0.15039245571408952, 0.11926889579210963, 0.23029003558414324, 0.09420761878469161, 0.25613831143294064, 0.12719223062906945, 0.10986500432980911, 0.07686623824494225, 0.14655593729444913, 0.1423009391874075, 0.09485777746886015, 0.12989096795873983, 0.16200014070740767, 0.14820525236427784, 0.0919259430042335, 0.1089004600154502, 0.1820686281259571, 0.15445565911276, 0.11013761255890131, 0.1981983690389565, 0.1269480123051575, 0.18371255562773772, 0.20924170288656438, 0.19683122954198293, 0.21430209491934094, 0.1429921899523054, 0.14821442615772995, 0.16042251964764936, 0.2074961851217917, 0.10818438843957015, 0.20128441415727139, 0.24789329671433993, 0.1178767726357494, 0.26136856792228563, 0.18253125330167158, 0.09034952295145818, 0.1317034571298531, 0.15838031923132284, 0.1449437788022416, 0.08542911947837897, 0.07735931607229368, 0.22245016055447714, 0.1417180776063885, 0.15398444368370942, 0.14266740238027914, 0.13529191671737603, 0.08352926213826452, 0.16790068122957433, 0.1761692411133221, 0.16773635361875805, 0.16150715787495884, 0.0912407651277525, 0.12504887421216282, 0.10352829471230507, 0.10779969301074743, 0.1443088057317904, 0.12988392476524624, 0.09660204672919852, 0.08530829274760825, 0.12697524870080606, 0.1755040596638407, 0.14274836517870426, 0.0968360531010798, 0.11525636538863182, 0.12255900353193283, 0.1778515601264579, 0.08833364969385521, 0.16428543307951518, 0.11472431250980922, 0.08819315901824407, 0.11135248201233999, 0.06369840446859598, 0.1391180535512311, 0.0619424915473376, 0.06878646715943303, 0.2419956060392516, 0.09728613216429949, 0.14115984684654645, 0.11494725197553635, 0.15763163726244653, 0.13869491911360196, 0.11442102092717375, 0.18905570677348546, 0.1475113553128072, 0.0896739259894405, 0.11423321600471224, 0.21795460821262427, 0.18978476550962242, 0.14446851930447988, 0.10035577709121363, 0.10632392005728823, 0.10287042787032467, 0.07166397811046668, 0.1899250458393778], [0.02355253234106515, 0.015211947661425387, 0.01075110917112657, 0.015633828505607586, 0.02030392041030739, 0.03922333761251398, 0.03203667467460036, 0.015090934333524533, 0.03779154051361339, 0.012878230789543262, 0.043529476903911145, 0.08460269775241613, 0.02861299392368112, 0.023510941537097096, 0.04241190937214664, 0.03957316991207855, 0.05766997366611447, 0.026161962587918555, 0.06091353390365839, 0.02895118934767587, 0.04115749829049621, 0.036612365394830704, 0.009151734278670378, 0.048118734931839366, 0.02944973616727761, 0.022807611152529716, 0.014721570403448172, 0.04048395389690995, 0.016957419625084316, 0.07487220024423939, 0.07250405874635492, 0.031562626361846924, 0.04277960749875222, 0.021735011832788587, 0.03097930337701525, 0.055056762282869647, 0.04390242689156106, 0.02761775947042874, 0.015714988079188124, 0.05102845933288336, 0.010245433492985154, 0.0186977923980781, 0.016679754613765647, 0.030170208042753593, 0.023814896387713294, 0.07041127354438816, 0.01634316562142755, 0.07324719029877867, 0.01360421661021454, 0.04711873037740588, 0.03466130580220904, 0.025114794760676365, 0.08025475391852004, 0.029243193500276123, 0.049191349518618414, 0.047498255369386504, 0.04765826410480908, 0.0468108247566436, 0.04150190230991159, 0.05968678330204316, 0.02499151003680059, 0.02011073300881045, 0.059684544136481624, 0.05213009486241, 0.05139937710815242, 0.00475981755880639, 0.08455749374947377, 0.042688941649560413, 0.040255029752318344, 0.030270427665007964, 0.04908507057864751, 0.03829328323315297, 0.02845983160659671, 0.04785634204745293, 0.0505221907847694, 0.015720655542931387, 0.03338861159448113, 0.029792535451373885, 0.03531201070706759, 0.07536567162190165, 0.061519784586770196, 0.019897542394963757, 0.01630703023900943, 0.05039524366813047, 0.04759173035355551, 0.019260576127895286, 0.09769018619720425, 0.03333106843222465, 0.04783241690269538, 0.022086978124986802, 0.060868682738925727, 0.044279522728174925, 0.047763216508818526, 0.07607470678963832, 0.05911491398832627, 0.016613543166645935, 0.007661333806546671, 0.0760097031348518, 0.059428532873945575, 0.08427871763706207, 0.05233978253922292, 0.02325783101176577, 0.035057580431124995, 0.007082372529631746, 0.029096999737833227, 0.08792340063623019, 0.011634591451313878, 0.022719159023836255, 0.01976581839179354, 0.0742852742384587, 0.11369752617818968, 0.011019461289314287, 0.05991041487348931, 0.026316141011193395, 0.027107828529551625, 0.019247414244871055, 0.011851462269467967, 0.02878750634512731, 0.07890235898750168, 0.005857646930962801, 0.03563861675294382, 0.03247286073331322, 0.024546565787334527, 0.018409504921042492, 0.028441212605684996, 0.03926720490146961, 0.061661415201212676, 0.0123985837147172, 0.024248938275767223, 0.0631237735173532, 0.02495121014570551, 0.06150626816919871, 0.023593705845996737, 0.03211028215342334, 0.039849737393004556, 0.04097896215638944, 0.03935896319204143, 0.02742232272534498, 0.04872723835121308, 0.026871052038456713, 0.02450308865601463, 0.020711623265274932, 0.0197003736892449, 0.01909023160780115, 0.06211962311395577, 0.0239391463276531, 0.028601072063403468, 0.05549850893606033, 0.025309271378708736, 0.03121558962655919, 0.02746512641065887, 0.021711025619879365, 0.0391771904458957, 0.03585161228797265, 0.05102967730324183, 0.035619984181331735, 0.05807987667087998, 0.09677206724882126, 0.04419267363846302, 0.011359534558973141, 0.04532775755173393, 0.0712490878733141, 0.013871928360978407, 0.031368480529636145, 0.012247828500611442, 0.048340883904269764, 0.010295140423945017, 0.052720722276717424, 0.0025139917519741823, 0.0639324922646795, 0.004689072225508946, 0.020750303154012988, 0.08479643985629082, 0.018906864304361597, 0.042629189855818234, 0.016633485310844014, 0.029891184265060083, 0.037687042728066444, 0.04224979717816625, 0.023464965700571026, 0.0365461505550359, 0.025001521821000745, 0.027054953688223447, 0.003556977895121755, 0.033880122005939484, 0.024686601844483187, 0.04361260083637067, 0.0440704389475286, 0.01784241758286953, 0.02553560521586665, 0.012265675667939442, 0.025985614729246924, 0.01864935178309679, 0.023394214854176556, 0.01421059960765498, 0.012283751840836235, 0.039085879988436184, 0.019011925273974026, 0.06106390404914107, 0.0553070975999747, 0.04956207051873207, 0.01649085894626166, 0.021033209848350713, 0.04332697152027062, 0.03560904280415603, 0.07236069786761488, 0.03022830081837518, 0.04809098284957664, 0.007623477489687502, 0.024251643934154084, 0.03210052142718008, 0.017566532029637268, 0.012503678611080562, 0.044461285296295366, 0.014773249326805984, 0.05806348326482943, 0.053461899648287466, 0.06179029614265476, 0.08084524901849882, 0.02187729044817388, 0.05963000349168267, 0.012059191524583315, 0.023808911708848815, 0.049649330122130256, 0.042752628946410756, 0.046144537295081785, 0.017488924586879354, 0.033054351673594544, 0.08286528169576611, 0.018005584898803915, 0.096839371137321, 0.007585951958649925, 0.05303121990125094, 0.014919432911223598, 0.04470301339668887, 0.05768439932061093, 0.03702712671032973, 0.017941600742882917, 0.015027447204504694, 0.029296597598918846, 0.10878099035471678, 0.008199742013987685, 0.03450882541281836, 0.02695946006237396, 0.015096824017486401, 0.029861318546214273, 0.01490716839076153, 0.02209808743957962, 0.004383705173885184, 0.07462278434208461, 0.040644919366708825, 0.013052677901993905, 0.07534264214336872, 0.05643603737865176, 0.040034695861062834, 0.03899991299424853, 0.08633398663784776, 0.07440487282084567, 0.0686887309753469, 0.020041714123051082, 0.03508727651621614, 0.035073030673499615, 0.1083102702562298, 0.05007895135453769, 0.027459837230188505, 0.05579282010772398, 0.007833371271512337, 0.023308790688003813, 0.01926626225135156, 0.03230532365185874, 0.03439181883420263, 0.01549751590937376, 0.04928746400400996, 0.0424008831780936, 0.007232440302946738, 0.020184248885405914, 0.04108056938275695, 0.020838348161695257, 0.03147022685568247, 0.018645487526165586, 0.16017414868942328, 0.023528481667329158, 0.021470744495413134, 0.04193547600880265, 0.02672930437672351, 0.032724369916000536, 0.027406872482970357, 0.07389083504676819, 0.038482092387442074, 0.08099879470786878, 0.009596680224473988, 0.043091139889189174, 0.01855564779335899, 0.011988932616077363, 0.046871143127126355, 0.0135580490875457, 0.022883678320795298, 0.051639483509851355, 0.06063975180898394, 0.021459769191486493, 0.032700309064239264, 0.13117977737316064, 0.0309266151328172, 0.022048771514424255, 0.07478154796574797, 0.06989040970802307, 0.06719578430056572, 0.03267428046092391, 0.010394167520904114, 0.012185346451587975, 0.07045154459774494, 0.03046363711889301, 0.07003284099378757, 0.027584305997671824, 0.018711829591276388, 0.04537791146763733, 0.02625364963231342, 0.04904282159571137, 0.018386249829615866, 0.014402038085141351, 0.08048729465476104, 0.043574429848896604, 0.04515404919428485, 0.09827796037175826, 0.08981596372489419, 0.00471416233007663, 0.06657665502279997, 0.035840090763356, 0.024115643464028835, 0.05645269202068448, 0.03840795565130455, 0.03910002065822482, 0.03228075050615838, 0.02420876221731305, 0.02328075362103326, 0.050408129048134596, 0.06212028807827404, 0.013103913233083273, 0.021653416300458566, 0.07730090099253825, 0.05260513722896576, 0.029748437460511923, 0.03140397130378655, 0.026571008942223022, 0.12886209173926286, 0.0448857360918607, 0.020476310713482753, 0.02090994717686304, 0.02712883597372898, 0.019667983820129718, 0.04021644485848291, 0.03486972461853709, 0.1254565787634679, 0.0818952073210052, 0.14299357416374342, 0.0718440477337156, 0.07215433501239334, 0.18435689248144627, 0.07473892918122665, 0.10644022095948458, 0.1310396734625101, 0.11149965625788484, 0.19776648149958678, 0.11255410646221467, 0.11410983119692121, 0.10016413166054658, 0.07978606263973884, 0.13545868705425942, 0.12539335287043027, 0.10839013382792473, 0.15331992719854626, 0.05321033957547375, 0.18929679026561125, 0.1223220048206193, 0.18677945248782635, 0.14422326960733958, 0.20130306029958384, 0.0641576030424663, 0.06345111238104956, 0.18326508892433985, 0.13771838508546352, 0.15989148457135471, 0.14320393359022482, 0.14256319297211512, 0.13426139844315393, 0.12908850530428545, 0.1298532278410026, 0.16894349455833435, 0.0876218257471919, 0.13290066431675637, 0.09326370872024979, 0.15260424917297705, 0.18408941397709505, 0.148304264194199, 0.1509727252913373, 0.15759951541466372, 0.13960342322077068, 0.14958589470812253, 0.19665217772126198, 0.1348542616303478, 0.10222307153578315, 0.24886704874890192, 0.10904993449470826, 0.1818652983222689, 0.14307015362594808, 0.09175909802849803, 0.15260172502270766, 0.1979502152119364, 0.15201685497803347, 0.11290324665606022, 0.16405862596418175, 0.14599325534488472, 0.0986747405092631, 0.18124029971659184, 0.11959759172584329, 0.16565926293177263, 0.15957550438387053, 0.07445832102426461, 0.12619671119110926, 0.08554533217102289, 0.11881530870284353, 0.1384977504078831, 0.18608362839690276, 0.15739762410521507, 0.11988747545651027, 0.1751336202557598, 0.1795041457350765, 0.115159185603261, 0.1727634702942201, 0.1558376992387431, 0.17788552758949144, 0.13350157492927142, 0.1611175566379513, 0.10161706512527806, 0.1063557162082621, 0.11871918743210179, 0.12108154781162739, 0.11296898312866688, 0.14742978183286531, 0.11549223773181438, 0.21573638224175998, 0.20804799694035733, 0.12923800013959408, 0.1636651570775679, 0.1654800618333476, 0.14306118339300156, 0.11983634105750493, 0.08362317817019564, 0.1768445327345814, 0.1472801241491522, 0.15112718700298242, 0.1786393935659102, 0.14182878738003118, 0.114383443657841, 0.11145984660834074, 0.11837778932281903, 0.3282310558216912, 0.22567356830196722, 0.1536615967218365, 0.12320707232824393, 0.06880158491964851, 0.13354911309267792, 0.18993964791297913, 0.10410776361823082, 0.12175815579082284, 0.19151053790535244, 0.19398771998073372, 0.11582989032779421, 0.06125662835048778, 0.08231072859572512, 0.13817661335425718, 0.14719431661069393, 0.12692429072090558, 0.1229339348418372, 0.06985266280493566, 0.11628248675593308, 0.14287443698516913, 0.13869907174791607, 0.09775516949594021, 0.1253348902932235, 0.17080950657171862, 0.1493992975779942, 0.10518746889595475, 0.1179110115127904, 0.06655963736453227, 0.14481842624289648, 0.14620403546307767, 0.10086522118321486, 0.15031901108367102, 0.0958055891096592, 0.11929033749869891, 0.09127542469650507, 0.08025480141597134, 0.13125525760863507, 0.14805547254426138, 0.08498256201190607, 0.21180743378187927, 0.06681111601314374, 0.1407046719853367, 0.19160903404865945, 0.13177607394754887, 0.06978430718715702, 0.16009937413036823, 0.1006959741935134, 0.13705226725765637, 0.13926364002483232, 0.13172538738165582, 0.19731388507144793, 0.20534431987575122, 0.14242144700671944, 0.1004154406754034, 0.16820686337138924, 0.09145284124783107, 0.09673005236046654, 0.11797267677528517, 0.18083340940730913, 0.18184810424489634, 0.120949708457504, 0.08719506793256317, 0.10544380585529975, 0.19642566916133675, 0.1576997350369181, 0.10277852708739893, 0.13690578511783055, 0.18693016868616852, 0.1440130594585623, 0.10105240185345922, 0.11772858058767659], [0.06004977918096951, 0.011937005179268973, 0.03225380927324295, 0.021018253240202154, 0.01638805919459888, 0.018965203048927442, 0.02563976034122918, 0.05464215363774981, 0.09074042019035135, 0.03604619238259537, 0.0340985458211175, 0.014906347363388963, 0.047604910896292756, 0.04069502239248582, 0.04610141300197158, 0.028110348752566745, 0.046926701574453285, 0.007401767868681678, 0.03451020283890622, 0.043440392041312795, 0.035430421853171926, 0.0398050321133009, 0.011694640104126717, 0.05022553527461631, 0.05617282685956784, 0.06741782131471805, 0.04354907299524971, 0.03275866307584303, 0.0626462884247303, 0.02642510355716305, 0.04779762162693909, 0.0727614067228777, 0.01673902804031968, 0.042718729336879084, 0.0642227695456573, 0.03375518335295575, 0.014130619836838117, 0.032766181243849654, 0.13277056201228074, 0.03294803202152252, 0.017400911809610467, 0.08562546037137508, 0.06532120238989592, 0.018101750274321864, 0.04260914932404246, 0.028499617507415156, 0.061971193578626425, 0.06567372168813433, 0.020709487576303736, 0.01282883937736707, 0.09180010868502514, 0.005104730903570141, 0.036202150263956616, 0.07333331674869571, 0.028006855198847394, 0.024480961629056504, 0.045960006304085255, 0.024884259095415473, 0.0034692613407969475, 0.06784001258867127, 0.10216452074902398, 0.023256674109558974, 0.01630926431555833, 0.03512013457449419, 0.054372324009558985, 0.04901773276339684, 0.003583737407877509, 0.00575739295787311, 0.05532690742984414, 0.01916311475049172, 0.06738432882619755, 0.0283238107804209, 0.008400227059610188, 0.04925700117434774, 0.04073708477829184, 0.13068408040063723, 0.012915629943433617, 0.040470169458006106, 0.02948315062427095, 0.08701670143221106, 0.0049887446719887, 0.018082018475979567, 0.030315767374954054, 0.028375937536891018, 0.04943718954122492, 0.04805818585945027, 0.048416869648333104, 0.0416307662879782, 0.04939191089943051, 0.019807156441467147, 0.01467775400461895, 0.03776622097939253, 0.0446327646662082, 0.02157557137044413, 0.016833904199302197, 0.04412543081811496, 0.07193043202693973, 0.026957913002531444, 0.06605858675071172, 0.01935804937966168, 0.06821644346096686, 0.03677474221746836, 0.013651323055715432, 0.03470690335546221, 0.05386354148920093, 0.07682110209550176, 0.05050977020125304, 0.04000156299610223, 0.07299900933035783, 0.06078674963542393, 0.03308305370488337, 0.0505435782085572, 0.017563622810744813, 0.016746161139703224, 0.02702976986100631, 0.08417211978563241, 0.0394703786421035, 0.07052980682679585, 0.04014362448028155, 0.08452681039593049, 0.017215242576120154, 0.0522951111862702, 0.02223899880690234, 0.025070270989090204, 0.022609465356384004, 0.0452307338294174, 0.01462859583885542, 0.01773680530355445, 0.07949978871537106, 0.035957996400871446, 0.03064293660489576, 0.01738311892508396, 0.05852443245904786, 0.06594361577715192, 0.051696592409695895, 0.03838193044066429, 0.02059828756111009, 0.045117231884172986, 0.015127044270879455, 0.029086835283253874, 0.03089984692633152, 0.08483910613826343, 0.01696144164140735, 0.06228918901511601, 0.01000265875232539, 0.04073552754042404, 0.0018882189802492835, 0.027132406764264618, 0.0864982803219131, 0.03242411817024861, 0.021546066971495748, 0.04712438257411122, 0.03409328378204789, 0.04669235932773777, 0.0387514198997191, 0.028494036556886773, 0.04108529877183693, 0.047424420581332276, 0.07527990479554449, 0.028364897772137607, 0.0609055475464889, 0.025388802468244518, 0.028439473859699707, 0.03454057406634092, 0.004773611327566738, 0.07046077945934874, 0.04905005477901016, 0.05584133196888225, 0.06758126004465989, 0.041054781659373214, 0.05159275619579213, 0.036400838888117244, 0.03875063958444765, 0.031724260188639164, 0.0025778228134315994, 0.046634680458477566, 0.020497263874858618, 0.03747376899367996, 0.030147093747343336, 0.018987637112981508, 0.03148305456021002, 0.012682288535870612, 0.023343616497835944, 0.04441291932016611, 0.0641903830692172, 0.02562891735163118, 0.04924269426347954, 0.025131642785189406, 0.011924772889220288, 0.02051027648017875, 0.0813942381313869, 0.03184110052617533, 0.031302503177097867, 0.09277911258063146, 0.005103251273145101, 0.07052517243261848, 0.055590443645737, 0.009376439631783536, 0.006386740124850933, 0.01830107332872493, 0.05830544206712927, 0.06820324595485415, 0.038882309304816384, 0.06003850192895957, 0.06028955988585949, 0.007579163215788347, 0.019076813577807376, 0.0754137933254242, 0.03758093002917511, 0.04667490740705814, 0.06234522922230618, 0.03515766773905073, 0.032687888480722904, 0.03752742415027959, 0.03247381407501442, 0.03741128948916282, 0.03336536159206714, 0.028989723351384913, 0.033910018258861134, 0.015868303066651736, 0.04504957515746355, 0.05055181562368359, 0.009928081816594516, 0.0823066777416638, 0.02685741857359452, 0.017111251995499645, 0.13785087583320482, 0.010081769150149609, 0.02002525795251131, 0.0677966270595789, 0.026602781344471232, 0.04286346085635679, 0.02105851411553366, 0.03369905832888825, 0.01812064747459122, 0.033978543510394435, 0.060234836036605496, 0.04085860361478158, 0.009256714672249342, 0.06198633848024266, 0.034810318877654414, 0.010079940498274351, 0.023939902894198895, 0.010911881258445126, 0.03390183512653623, 0.06280572379806212, 0.035457790563149114, 0.03779383396197643, 0.0407432289128857, 0.04852307734212705, 0.025731851113960147, 0.06531975711030619, 0.013228925676750285, 0.0029721858819747077, 0.07941624069852488, 0.0571542191984398, 0.028528842010668347, 0.054361433522509675, 0.016073045919516256, 0.03965803089418581, 0.029008664656430483, 0.015308075717517307, 0.06762680331511156, 0.025494769282106842, 0.058173331298998425, 0.039004004560410976, 0.09031076503119298, 0.0640929861526404, 0.025303522490763238, 0.014038475629474436, 0.02097454710331346, 0.007035377618324543, 0.127014250893678, 0.019245580503983156, 0.025461800961888263, 0.027652899102706994, 0.03694771097174712, 0.08474803995341063, 0.028853426022189002, 0.05188844818621874, 0.013190730940550566, 0.02938636778188603, 0.05515930588756289, 0.009884094935841858, 0.04468420101329684, 0.08165508734860591, 0.09763046154486281, 0.06268892077995197, 0.04499751455815775, 0.003141360777330452, 0.005815054439673466, 0.049155750178865025, 0.0021724153152068277, 0.015248758186187063, 0.03456144241083946, 0.015071299226422395, 0.011964883638678916, 0.0495459417413388, 0.020336445986426303, 0.0316336723709745, 0.02143227155985577, 0.0102442562347278, 0.017050894609253322, 0.02387905865907669, 0.09277615416795015, 0.10139689408242702, 0.05163536140961306, 0.03086068867040532, 0.0901749562472105, 0.04629665466823748, 0.06544525216200522, 0.02464163363245981, 0.01990229553276939, 0.018253334997487918, 0.027960338230643953, 0.017518920923716257, 0.0430396696153496, 0.030241640816841806, 0.0505231916239219, 0.009738142901499356, 0.03134842642715999, 0.021463775940771614, 0.07502186471330267, 0.009066199002388333, 0.05871441547891923, 0.04726809289838586, 0.042375404188143354, 0.04211803246289492, 0.01283659418446145, 0.04142431861587933, 0.04728813682283674, 0.02801145057726119, 0.041479500476270914, 0.06327589428318398, 0.009192923898808658, 0.005215174776302385, 0.04472198184313519, 0.053691705888403315, 0.09633000168417181, 0.011149716264169132, 0.019995124212333133, 0.06569573336413928, 0.06642169119524104, 0.008934449554154915, 0.13668902032077312, 0.047350897919386625, 0.010023181892133184, 0.03300332244751709, 0.010332210488351328, 0.045478582315679104, 0.04502493755093642, 0.026417846625138606, 0.2509267825101103, 0.08857938115085874, 0.07932806507285152, 0.08118235878646374, 0.12447860624108996, 0.10551594769848244, 0.10901754123291799, 0.12094445659645967, 0.1435773449816874, 0.13136632022048744, 0.12770775439483778, 0.10005511143910033, 0.1506778746843338, 0.09524431851293359, 0.1606773231178522, 0.17012049497238227, 0.10998614997203861, 0.16756962399397576, 0.1587544091578041, 0.16818753869405814, 0.13043200464120933, 0.13939705358019897, 0.09561392332294158, 0.14630304729299887, 0.18929708882101945, 0.17518054773764952, 0.19319774237062248, 0.15565608255565166, 0.14370656519063882, 0.10587364421891314, 0.09873300631131444, 0.17630623733358725, 0.10971071225191865, 0.09343591412263257, 0.1373585443943739, 0.14084507445139544, 0.08077381963708571, 0.1318240463733673, 0.16598662893686975, 0.16731184854039124, 0.0587564507233245, 0.16730673238635063, 0.1035826996501003, 0.11048515141010284, 0.13380884272711618, 0.12459593851651464, 0.19169693147497519, 0.16060712188482285, 0.06652390571045023, 0.15770437621644565, 0.19887550627546652, 0.11927927737789494, 0.08227210638246366, 0.1448396643889802, 0.1863648404500314, 0.10041981722627367, 0.1666018973503794, 0.14070992384638104, 0.07543565572372504, 0.11839673402053968, 0.19433299931032316, 0.10167379065283708, 0.0710765907008733, 0.30949553687657627, 0.1401165992553745, 0.1094623887911439, 0.15101672150194645, 0.11004947764532906, 0.12345336696931294, 0.10015270513083253, 0.1633346833820854, 0.18033182275082382, 0.09050581670765366, 0.13317761516996793, 0.11782696816538062, 0.27325834706425667, 0.09047699932541166, 0.07782098451363188, 0.16813219737793716, 0.15061809574919088, 0.15132180441703114, 0.11850581531013761, 0.1712449767759868, 0.14619971998035908, 0.1028170000229563, 0.15358813852071762, 0.12026896141469479, 0.13118930400482245, 0.1452635723565306, 0.11694818389202867, 0.12002046832016536, 0.15510295437914984, 0.14254232123494148, 0.2529774239020688, 0.10736912861466408, 0.1325087696313858, 0.18620543900345052, 0.11649224907159805, 0.18991253365363392, 0.2020189690270594, 0.09066350824598755, 0.28400322049856186, 0.13200948999396392, 0.10141785402915307, 0.18214938736387662, 0.12719263775008066, 0.19636077407215322, 0.08650896046310663, 0.13037827823843273, 0.16002115261341843, 0.13926710055342742, 0.18770724056022509, 0.1074131451813238, 0.11256603510784251, 0.17623618537826197, 0.18880740366876125, 0.14393812205110276, 0.19106801093689033, 0.11527931344296251, 0.10607395454176835, 0.09257927723228931, 0.16928949313504355, 0.11245565781635897, 0.12352865721498217, 0.07423594474260296, 0.1102305922125067, 0.20647971252245562, 0.1455699580588511, 0.25712924397417475, 0.1427005556012903, 0.1595881794180189, 0.08104450761207513, 0.1297200856996434, 0.21841378643044404, 0.1262584307364055, 0.10036199925733463, 0.14061871516917432, 0.12297015504113265, 0.06410923028098685, 0.1818997814719166, 0.08019420145345585, 0.1684549900570086, 0.14708819373377732, 0.09456736448087863, 0.11362264305353165, 0.14233534091285296, 0.14736690877803735, 0.07024885261697428, 0.13354068568774632, 0.12640812913221972, 0.09758606499859265, 0.15585535471992834, 0.1262857892683574, 0.11356266055788312, 0.1545244897050517, 0.12902195458965643, 0.1461368469255311, 0.21136682028216974, 0.1155588970120464, 0.11189522181770631, 0.20334824626999243, 0.1947935481688806, 0.14991984250290052, 0.09513509473098175, 0.12954222810055527, 0.12151970501456942, 0.19918497252677167, 0.1904452514967748, 0.3183404579758644, 0.17903749006135122, 0.09307477064430714, 0.1958162361489875, 0.2293069740491254, 0.08794659296316759, 0.08673603220709733, 0.12426047080329486], [0.04472623286502702, 0.02126032060810498, 0.03673745332551854, 0.053973403094070296, 0.028867749896432673, 0.04554789127515895, 0.018324660902310694, 0.03563231994797077, 0.009013239344182824, 0.04354900514174785, 0.05910804721393755, 0.017930459197876707, 0.06030279131872313, 0.043080999183335474, 0.06554736489696161, 0.03341962743018355, 0.07138636907828705, 0.026020282779687216, 0.07682020642927714, 0.05566152358161552, 0.038027148228138685, 0.07997742987104825, 0.02187757712921926, 0.022793847069676434, 0.05027286309216704, 0.039974696402038844, 0.015508250333368778, 0.003976233020823981, 0.024431467588458742, 0.04358945939955967, 0.017235227128756896, 0.017139114339702895, 0.026465177835364426, 0.05950565516416516, 0.023225709163982953, 0.037870885006019046, 0.04374041987050857, 0.08391495501356465, 0.019745340204930732, 0.005419244183160896, 0.045530307040150673, 0.04104934320119875, 0.11275720556399652, 0.038229955559862513, 0.026556983623387556, 0.07362792986844267, 0.07698960948203291, 0.04974200104230216, 0.033526625617274215, 0.04334222159481474, 0.009883601301615792, 0.030205681853528534, 0.05500366352498531, 0.039696049211280685, 0.09967673317130123, 0.02690038171463779, 0.020050010909991603, 0.06012029254010745, 0.1156705974468163, 0.05997680273971387, 0.1027324070621814, 0.04770400754309126, 0.02354175381229392, 0.03248464010123696, 0.03147465768935425, 0.06788495874830655, 0.011835414916276932, 0.009967554743135614, 0.13709877404783452, 0.07407996989786625, 0.027520408354965702, 0.06058251738016095, 0.03076976158523134, 0.028729121799447706, 0.04441233578005007, 0.07395256137741463, 0.07348771739218916, 0.017455613606476357, 0.06885724514722824, 0.05653967681740012, 0.06015289614775351, 0.08494279307446309, 0.0590898014072861, 0.031984050891229084, 0.022078019766403095, 0.026047683720077788, 0.03755009739792772, 0.028391652407922914, 0.04046462243422866, 0.04635129030793905, 0.026773078367114067, 0.04622989021507757, 0.06746778863349132, 0.016462465648406317, 0.010056511532249195, 0.014180423459038138, 0.06105243002197572, 0.02268932553540383, 0.03495600373883333, 0.025341257519487823, 0.01659224395241056, 0.02816841099411249, 0.07550412669245686, 0.025818145501294305, 0.03258845256641507, 0.02912784254710589, 0.029368620698473284, 0.0567135887353548, 0.04195330451641764, 0.0292946128839893, 0.022583245066925883, 0.03840991661750844, 0.10551852613155331, 0.052864527595894675, 0.012392664344848266, 0.08387212588318757, 0.034149310418537686, 0.02171644372200327, 0.02095612487755716, 0.03754902191992317, 0.02911864161225302, 0.034594249578991106, 0.016151659290439317, 0.07994431057678801, 0.034622778583850176, 0.07674024107732944, 0.08072170136230332, 0.0489547986404172, 0.015732529905757735, 0.04782591314454164, 0.0324182997324637, 0.019633821278278316, 0.03444817456017647, 0.036524552785392315, 0.07504850399813481, 0.009694257800999497, 0.03593545546755195, 0.029735820101840154, 0.02521005768461951, 0.03886448758255158, 0.03084281605801412, 0.03547519498637744, 0.08698757192386047, 0.02478955765920026, 0.05050510188032474, 0.05899416868175779, 0.010697448077345533, 0.02537178820265191, 0.026948382978194525, 0.02602855921057718, 0.022039265238812993, 0.020738389775423065, 0.022045127781374112, 0.0940327603103859, 0.03560757377584066, 0.04040447369750057, 0.032222406672579904, 0.021223087695294192, 0.01272548153065145, 0.033282678707369735, 0.017771670129150152, 0.08525597091232028, 0.032592516991176775, 0.053452973520117145, 0.011970035415808005, 0.046211980283260345, 0.007421402127615043, 0.023473584791645408, 0.06090176132108484, 0.020356420361037766, 0.013545653949092542, 0.025493983877822757, 0.015322134963103702, 0.05279860452615789, 0.032953704574278424, 0.05722114310732909, 0.01151499371709568, 0.01999790620590959, 0.02865064243919083, 0.024072183296084404, 0.029397743421473672, 0.05513069885117667, 0.01792712419826005, 0.059808973888201375, 0.05484926627416696, 0.03290643443220428, 0.026118044408836534, 0.03623390570282936, 0.02981283043378166, 0.0692464392632246, 0.025536465259002786, 0.007943338897478367, 0.07051456693027701, 0.039626943812306435, 0.08877249221716609, 0.04555426271898406, 0.05402533137904746, 0.011844052667064326, 0.03001634344192488, 0.02164872083812952, 0.08495073871953146, 0.061146617467914305, 0.02219060399303479, 0.015597426798194647, 0.023308929787682633, 0.017341840247224485, 0.02718372776040009, 0.01827798447837787, 0.03563673381826707, 0.00896418041416577, 0.03015216240393264, 0.052391656541398594, 0.02908643494759287, 0.16129282223326818, 0.029460575764200518, 0.027763997337647846, 0.06962718561823879, 0.025278579543477724, 0.0175777363391327, 0.03303819575480052, 0.03876220182116542, 0.03512117951842291, 0.05226802406832576, 0.04016394999676517, 0.03448115814743297, 0.06369936798832246, 0.02876820880919695, 0.027668863335358243, 0.03957672204290118, 0.027403143933042884, 0.04752222801159535, 0.048587504242147715, 0.038469732872077396, 0.03798444801941514, 0.03358780911990574, 0.05471952698592629, 0.11173174916101353, 0.07532112579792738, 0.032325167408479114, 0.009871024655045142, 0.04635833689410772, 0.024471518117934465, 0.018033849275005714, 0.008988700973402177, 0.09046936580645186, 0.026944420333685618, 0.012877184149276997, 0.10347179310130221, 0.07927277803953205, 0.02511797539357628, 0.022444884991273284, 0.007937471265904605, 0.011118309422662216, 0.026127779690016593, 0.044305262954107354, 0.05812322148787124, 0.01917057015400912, 0.06339897375021662, 0.04621832458568471, 0.040966222661414316, 0.058636567156229696, 0.05023926203804357, 0.05002786784565874, 0.04718282140259232, 0.017584209563210607, 0.050464349067104716, 0.06744102721235581, 0.0023796937686191605, 0.07568182822849069, 0.06440963808979307, 0.022818829032725522, 0.029452239961496422, 0.008573713196840669, 0.03891563215958221, 0.041152623016387224, 0.015939535672909448, 0.017242036227669035, 0.00517032785241359, 0.031857551607702456, 0.037567705381661654, 0.02311123182464923, 0.01630316598207823, 0.05283136758953333, 0.09029467696590082, 0.022910485543044548, 0.04651222185098699, 0.052895733421402316, 0.037832825976823053, 0.1144127156585455, 0.0442115606607071, 0.03067240198808057, 0.04685457669464605, 0.05047942950789418, 0.05336391579891954, 0.04978566477075219, 0.019702470362452523, 0.06619487050920725, 0.01131198282486626, 0.06957485021225043, 0.032369207723864486, 0.02255795437044331, 0.03471342068431633, 0.02329818348932479, 0.02566767018288374, 0.042049300258180926, 0.05430923382352505, 0.03922009760779994, 0.021989401396630064, 0.039028340218854804, 0.039696049211280685, 0.06321407974298511, 0.03299148540411677, 0.030297039808439355, 0.04813891117061887, 0.010736045693712575, 0.04191710128049765, 0.03181572670915297, 0.03413267952523061, 0.024160723634330288, 0.006737856976022678, 0.05516211502254009, 0.0058344694469789305, 0.029860819822975566, 0.03102554553853614, 0.054313335567712784, 0.036596280722213645, 0.016119093002219285, 0.045191022567451, 0.031973913578050475, 0.06647664574640137, 0.017274758578943353, 0.012430148315615952, 0.022498896378757696, 0.031484415022922416, 0.039802965974169116, 0.030297779411609684, 0.04219447621809585, 0.07295962715787546, 0.04794524370559624, 0.061239854964826784, 0.007769153021009905, 0.0066621859025742325, 0.031221886431532245, 0.017179117371727313, 0.021759325438844304, 0.0690494876887117, 0.026851535674982836, 0.03972690559125372, 0.017351015737014155, 0.013079341783720468, 0.05079758779278823, 0.10037288295903377, 0.115037185006908, 0.10560402154390301, 0.14212488649146898, 0.17107482733471052, 0.12070962919720582, 0.11185163272810833, 0.11925711642418589, 0.13428703349615845, 0.11130108977002756, 0.1220952927001885, 0.12168975946094308, 0.1044748578486698, 0.13672069433544362, 0.11664561155651297, 0.15045023975627764, 0.10522713605314493, 0.12083325827760355, 0.145408765279821, 0.30908950152141706, 0.16258562143359864, 0.1830726292516504, 0.12025217445833342, 0.09686611898775611, 0.08124702317374093, 0.17847469954618386, 0.11400030207421098, 0.08101461814450366, 0.1250971451933895, 0.12109947470682007, 0.07131589643125023, 0.14678822697273322, 0.08868646076215164, 0.13432959121252808, 0.14283542122159684, 0.08869178726204804, 0.10946418012359313, 0.1394677704998425, 0.22623764803367002, 0.13502336612769536, 0.13846946906830582, 0.12575475419206278, 0.09377514091985566, 0.19859806687704154, 0.1320113627506154, 0.11546897755137511, 0.11599077098071575, 0.23740520807249205, 0.19744333598230565, 0.07699796903346266, 0.12835700384208135, 0.06293543255222694, 0.17639706603118352, 0.15005830435880593, 0.14616534539631434, 0.14338583525802406, 0.14842824611280644, 0.12085680344275065, 0.14482819714716502, 0.2073509921985013, 0.19897170897041047, 0.18938744254410267, 0.15101047897977488, 0.1269208709044116, 0.10063766767936093, 0.12300678236143929, 0.19303621032408305, 0.11250031220593623, 0.06864499939339501, 0.23188054880925588, 0.12474358773657254, 0.15229483720447334, 0.1985013484954834, 0.2115682094757046, 0.13766525579350336, 0.16082213606153214, 0.11673017059053693, 0.11977908627263137, 0.16041110668863567, 0.16192014142870903, 0.10571807649518762, 0.2283918745815754, 0.2818046041897365, 0.2190206545804228, 0.12784627053354466, 0.11837697508079664, 0.134015470210995, 0.23007890262774058, 0.13486137267734322, 0.10479924508503505, 0.10626633957560573, 0.15682179214698927, 0.08772422346685614, 0.17155497228460653, 0.10689550438629729, 0.11627130449882575, 0.12764797545969486, 0.1265431847423315, 0.2238206248730421, 0.19184048234352044, 0.16414744619812283, 0.13193455258650438, 0.07419557869434357, 0.1273198359246765, 0.2117668573877641, 0.07560625299811363, 0.12073360862476484, 0.13142219079392298, 0.12680295508887085, 0.08616097377879278, 0.15624973284346716, 0.16923902370035648, 0.1370861397257873, 0.21484826132655144, 0.10988559108227491, 0.09366298586662326, 0.1997969296893903, 0.1470480787434748, 0.13201194629073143, 0.08988581211971385, 0.19212820833282812, 0.12263406307569572, 0.08581870714468615, 0.15751460354243005, 0.18848009194646562, 0.1415292141692979, 0.1669902772243534, 0.12810403241642884, 0.1512263345399073, 0.06771389328475509, 0.13036269907440456, 0.14950584114662238, 0.1198228517813342, 0.11558518345866885, 0.12474016792007855, 0.1880881701196943, 0.08130633391972099, 0.06929465596164976, 0.1673902736178466, 0.07632412947714329, 0.0951566585738744, 0.09539122134447098, 0.1461332914020334, 0.2860534276281084, 0.17765755339392594, 0.15114922582038812, 0.13318383055073874, 0.11404230339186532, 0.09657629632524081, 0.135929318943194, 0.18585471782301152, 0.05099449526252491, 0.09796454504664455, 0.08173914426671607, 0.16095081344246864, 0.1665105258247682, 0.11086589097976685, 0.07962298353335687, 0.10394264212144272, 0.13988558522292546, 0.08279939594545535, 0.09393195036266531, 0.16464530091200555, 0.1776785608381033, 0.2829977944493294, 0.1226553555045809, 0.10345145062144313, 0.11381677192236696, 0.07951705743159566, 0.22206161783209868, 0.14205939429146902, 0.09404944548649447, 0.11140211006360394, 0.04768827910135899, 0.15224003871636732, 0.10186791952167239, 0.133444360856499], [0.09058810943471533, 0.03173030593565532, 0.015071009152701922, 0.053870265771235736, 0.0573745598750455, 0.031828035334391255, 0.07006437251610415, 0.058163017566714964, 0.03194475353562406, 0.005919937717927886, 0.07201031595468521, 0.04798785909744246, 0.020153609636638845, 0.035001156851649284, 0.02326522025811885, 0.0185108610894531, 0.013501617874551033, 0.0012485115377265693, 0.028077758715621064, 0.022129340762538568, 0.04422723821231297, 0.013963620494385915, 0.022302190773189068, 0.06898730673960277, 0.021570041310042143, 0.012586116375002478, 0.03852853810946856, 0.0379460599007351, 0.0703134084386485, 0.04492491131116237, 0.019744649795549254, 0.011410758863868458, 0.017667591338977218, 0.002071652652895344, 0.024185720864417296, 0.04973299348992961, 0.034769932473344464, 0.04261988035536238, 0.017834892629512718, 0.0017411234023581657, 0.09719981572457723, 0.011971680863228227, 0.04106962800558124, 0.016058599908969233, 0.02226651000923344, 0.06958483146237475, 0.014673911800075854, 0.029874421057424376, 0.0408293791115284, 0.0835105956399015, 0.004246644492793296, 0.05240401605676327, 0.03139634796285203, 0.04283855862117239, 0.013168235808344824, 0.032159078999289444, 0.01831043541564473, 0.03739634814805218, 0.030140739266893694, 0.03531905390056116, 0.08416032684700829, 0.09529594824250255, 0.06693952876542296, 0.02070902956516615, 0.012142597897244351, 0.1746924232159342, 0.04303100133048637, 0.06136385723948479, 0.0230298432454999, 0.013751102478376456, 0.024665875992338573, 0.00689149129902944, 0.04925662798008748, 0.0370552587722029, 0.021434361447713206, 0.04821040840553386, 0.010426667651959827, 0.04188646881708077, 0.06673459083374057, 0.025002512482127974, 0.028525693608181815, 0.022989326223198856, 0.039363695973796506, 0.01699350242103849, 0.07204842926668269, 0.07305473741143942, 0.02849869809246489, 0.03282666924808707, 0.035972829176379104, 0.007801063674768167, 0.04307353190545525, 0.022711893610124077, 0.05279967661148735, 0.039524410385638475, 0.0052296258758620495, 0.03257894629080381, 0.029959804511495998, 0.051823227400226254, 0.03333386738917657, 0.04982236672991088, 0.057103776905153475, 0.015611525059544613, 0.07488145546189376, 0.01539026157531355, 0.04119648012731757, 0.06762531053807054, 0.08014503480600459, 0.02774239787166672, 0.05663544864260724, 0.014291257065321718, 0.06665535151426281, 0.04670034568490727, 0.053641993020262034, 0.023126882234854356, 0.05652524437755346, 0.03618582810408302, 0.026353448562856232, 0.0165578863317413, 0.009458366798103919, 0.03671138061742697, 0.07645395358226129, 0.022170081701395766, 0.054870263540319035, 0.05240909828405295, 0.027064122392662933, 0.01264652974038784, 0.026289152280826653, 0.07106401744697775, 0.02603556678098227, 0.05229100604940738, 0.05048464744218758, 0.035728081595152617, 0.03933790825041277, 0.025326105832521404, 0.033961597098303695, 0.061261391666318686, 0.03138218015166266, 0.04365125697638307, 0.03146879853946822, 0.017910464467214685, 0.03499062598815986, 0.01672727072478405, 0.03441943181678653, 0.04862128850072622, 0.003645698257189776, 0.0483923745341599, 0.009775320683339877, 0.03554241745067494, 0.06813538566763912, 0.01593234489804932, 0.056111585681459734, 0.09774703386106662, 0.03148734290152788, 0.016702482144215276, 0.027261428501723067, 0.015677992653633867, 0.030609298231346265, 0.011190680271413709, 0.1286572962999344, 0.04642955592966505, 0.05802385003439017, 0.029409573679523807, 0.021635219687595963, 0.012919434828550687, 0.024203790251963904, 0.04682127758860588, 0.021823704841413667, 0.040664281363465955, 0.03194589347445539, 0.02290390714603875, 0.031871790665068796, 0.007690903514490596, 0.015344728482887149, 0.018360836996829936, 0.020756961278883473, 0.07959560464535441, 0.053808271419256926, 0.01769129087084106, 0.022727169129731398, 0.04104184199656759, 0.02363116097902613, 0.048250224840428145, 0.029222091061196158, 0.016510723058932593, 0.06327450328639575, 0.06370408380670206, 0.05664653590481196, 0.0914995176717639, 0.027204999833234718, 0.04719140487057822, 0.09404371865093708, 0.09454620775899716, 0.03311353689059615, 0.026987118846071616, 0.0882113641127944, 0.037995623491172276, 0.051287313657147546, 0.0813365965815527, 0.03348392540855067, 0.01627833329673324, 0.03700941016099282, 0.0388647284624832, 0.0404576233455113, 0.05839684073414121, 0.023689776226612072, 0.0048044252991011095, 0.030722121641572033, 0.022937608284077475, 0.057419716380536556, 0.034154396038502455, 0.03780162354399051, 0.10511809547564813, 0.09050733662609543, 0.02719445200636983, 0.025666871207899282, 0.01685206010006368, 0.013514545662993831, 0.008423440590766924, 0.030258003688816513, 0.03221848813284721, 0.033729826499308856, 0.029992197773286274, 0.07053011895290442, 0.053776577048535855, 0.027165892467434918, 0.05575231156711068, 0.03638733604124614, 0.010243749877970134, 0.02360005523743374, 0.020163972562711154, 0.040437043378395696, 0.027827213052660227, 0.031151206831314733, 0.02438927797733673, 0.007948229438625276, 0.047915717254259756, 0.12116208991834096, 0.04177654953673482, 0.1023897740191647, 0.04811211582273245, 0.004697006420298878, 0.02842036122456193, 0.01657403546518513, 0.0313758799540145, 0.054027336450027566, 0.021017293113150766, 0.041808515321463346, 0.02627772405477507, 0.012996713181824555, 0.030363716052046845, 0.012912620640625911, 0.001803677121642977, 0.02260996916863535, 0.029204812166946273, 0.02147413377783128, 0.03541382149394069, 0.02111558908862727, 0.019009938862706934, 0.023925182076969316, 0.05061865132302046, 0.012832393204527242, 0.06742092221975327, 0.0287798287213913, 0.05329233035445213, 0.0476252194494009, 0.062221783346363475, 0.03334080880241735, 0.02896085168634142, 0.03613273613154888, 0.06060987591211285, 0.03927322689976011, 0.031012364995798895, 0.02651118759864143, 0.07681728194334678, 0.04324980851794992, 0.006116518642686839, 0.027438246245895113, 0.039852651700909646, 0.021740440112937773, 0.07782426183777195, 0.07810731272080115, 0.046149592380970716, 0.05963333509862423, 0.035255410708487034, 0.05824180905308042, 0.03247377675558839, 0.030765429139137268, 0.028743476207767214, 0.03325080791754382, 0.017705823394602964, 0.05572386398645384, 0.07628166675567627, 0.046295752216662676, 0.04740904837048479, 0.02165569448178368, 0.04350651867155518, 0.04259136152852859, 0.012810466345399618, 0.04036780566509281, 0.04404871564890657, 0.03273526379572494, 0.03033889863373978, 0.019435242916058217, 0.029252811734165465, 0.06057117227464914, 0.010917373999421085, 0.04294505129967417, 0.027836607369993414, 0.02695282907890422, 0.0582885601158653, 0.031046125505651747, 0.04727443041546004, 0.03221110567184431, 0.01913096067229552, 0.015554702840745449, 0.031054814146565538, 0.02509310538880527, 0.06340100935527257, 0.02566477283835411, 0.06020463444292545, 0.02443013765982219, 0.048349803247089894, 0.057738566771149635, 0.062019925963665755, 0.048885035062474866, 0.02173011620262904, 0.019576313739110316, 0.059026731577302725, 0.03748108360118099, 0.024073201098612378, 0.02048943697341851, 0.0026220766553056558, 0.024516213219612837, 0.024787376169115305, 0.06169097897197519, 0.074149275464671, 0.035674087171043666, 0.025777652227718915, 0.02486768757392253, 0.01573829066806606, 0.014216278097592294, 0.03024223114230803, 0.036654193686055284, 0.03521083774311202, 0.03049796081281134, 0.03361751877569726, 0.01301763580912458, 0.03023876722103783, 0.04698451954339232, 0.025989514609266604, 0.03922013831990106, 0.04350413362096463, 0.18039734209222452, 0.07456848796989236, 0.18703801504203252, 0.15605670320136206, 0.08843650881733213, 0.18753299276743615, 0.16468787219907555, 0.14697354845702648, 0.1270249310348715, 0.0915023268067411, 0.19858669463012898, 0.154777963246618, 0.12995997497013637, 0.12342613057366439, 0.12347282735364777, 0.1817335539630481, 0.13684965670108795, 0.06929213181138039, 0.14700975508562156, 0.14017621534211294, 0.14302167908421584, 0.16298157375838074, 0.11538813688925334, 0.19464348336415632, 0.11417323350906372, 0.11877895279654435, 0.08440013469329902, 0.21079199255577155, 0.10777710457997662, 0.1376895880592721, 0.1259750745126179, 0.09598939746086087, 0.14456255068736418, 0.08405079772429806, 0.10914180813623325, 0.21849720552563667, 0.1202929001301527, 0.07024001130568129, 0.06027661343770368, 0.14317303310547555, 0.1539465542882681, 0.2202103300286191, 0.23823543637990952, 0.18591138906776905, 0.11139719747006893, 0.16810699658734457, 0.20165421574243478, 0.09685393249882118, 0.11592825076409749, 0.17961511335202626, 0.11453725397586823, 0.09501550971929516, 0.07834046413855893, 0.08356116006949119, 0.15655082597264222, 0.1423101672636611, 0.12795195914804935, 0.07632636864270483, 0.13412255660763808, 0.1514292707932847, 0.21061859971710614, 0.1940817785050188, 0.17840888164937496, 0.12861522712877818, 0.050925413612276316, 0.23304268930639538, 0.12878784643752234, 0.1229199298790523, 0.12179379245000226, 0.20891280339232512, 0.11252134679151432, 0.10910237168094941, 0.16294250371200697, 0.20451059032763752, 0.1344584992953709, 0.16161686341677392, 0.07997689382838351, 0.1296462339482137, 0.10103191688124623, 0.17362778820097446, 0.11566290285970483, 0.08041614347270556, 0.10107633378356695, 0.1389869334442275, 0.17860674246081285, 0.16982084033744677, 0.10178604748632226, 0.15219849880252564, 0.15749834584338324, 0.1360890053744827, 0.16716631634959153, 0.13127390375094755, 0.12423902909670557, 0.2041476826582636, 0.15917758430753434, 0.12380757581974779, 0.10709505474993161, 0.16469308334801877, 0.1520357182515519, 0.13263788127473422, 0.19037423602172307, 0.12093649059534073, 0.10801635602755205, 0.1382175697279828, 0.2731509214001042, 0.26344762636082514, 0.1168924490255969, 0.1623015459626913, 0.18910137218024048, 0.16873500788850443, 0.08128776241626058, 0.19651025533676147, 0.11589346905904156, 0.11548154401992049, 0.12027414542223726, 0.16054722081337655, 0.10572473292372056, 0.11829586300466742, 0.08661044216049568, 0.12874174676835537, 0.21171929208295687, 0.10934396407433919, 0.1454358116856643, 0.23762670904397964, 0.1072243292416845, 0.08974689564534596, 0.09612632582762412, 0.20030114906174795, 0.15769187760140213, 0.17025609341050896, 0.16554520119513783, 0.10472688611064639, 0.10676992791039602, 0.12826589015977724, 0.09261374681123666, 0.151224285364151, 0.15146296684231075, 0.1704757080546447, 0.057530460080930164, 0.14890195855072566, 0.13632258426930222, 0.08811484929174185, 0.08317143669618027, 0.1263209916651249, 0.11466279652501855, 0.12856379417436464, 0.10638570745608636, 0.11801778578332492, 0.13294922028269085, 0.16555463283189706, 0.07716311088630132, 0.1787013980959143, 0.07889427763542958, 0.10915862901934556, 0.11938905077321188, 0.0889842426404357, 0.15461124719253608, 0.11739916540682316, 0.21607535119567597, 0.20555515427674564, 0.21057849829750402, 0.18815341804708752, 0.13217194484812872, 0.058552815578877926, 0.07910470491541283, 0.1849647241511515, 0.13065635545977525, 0.10134318125035081, 0.22595085842268808, 0.16301673544304712, 0.11189321335405111, 0.08494383123304163, 0.11011751435164895, 0.08007807697036437, 0.12379328587225505, 0.11085335165262222], [0.025268798461183906, 0.010215197972554182, 0.11093660789941039, 0.030712008077119077, 0.0346262832172215, 0.03655327517273171, 0.056762792702232084, 0.04828320503500955, 0.04662351516474571, 0.018032831472477744, 0.02414446763162102, 0.06439224723726511, 0.025399195928392664, 0.03608110640197992, 0.03725054454324501, 0.05462109869612115, 0.004687416175979057, 0.06620028521865606, 0.046367531043610404, 0.03229902345421059, 0.04587351683793323, 0.016759504530844942, 0.030649206268468072, 0.03747324312904051, 0.029877678025513887, 0.0437828758066254, 0.010236078191415539, 0.03153197014970439, 0.0137028857799513, 0.03494614123233727, 0.020194686450330273, 0.0635201193924461, 0.04537227623430746, 0.029477372898587158, 0.007435814211411136, 0.06917017192712852, 0.02722466377807515, 0.05405511228101594, 0.0236811028527362, 0.023319423331746032, 0.04176515693377171, 0.039669657591730356, 0.05157782842538186, 0.03320063703826495, 0.05446816708094307, 0.054599470392401726, 0.03734464377963117, 0.040530538718615255, 0.05459773673542908, 0.042275883456958194, 0.030265196160014187, 0.014330076053738594, 0.027208175377121994, 0.019993249759344116, 0.013598369334691336, 0.09641441144049168, 0.038614623847284486, 0.012015006172337701, 0.015929866548893706, 0.014155661171701337, 0.02754450143714036, 0.033912060649267266, 0.04726496485194989, 0.02791250660084188, 0.012274986864732844, 0.013538721017539501, 0.04220218437590769, 0.019301909088556255, 0.026720529222594838, 0.013957396631927362, 0.07457359733858279, 0.03029947235648121, 0.026178327156230807, 0.047652577981352806, 0.017684049205854535, 0.0130843332569514, 0.05893540076379265, 0.032287827626402886, 0.03298417418929083, 0.019544782216793725, 0.041110889720065255, 0.04157976759597659, 0.0078866311814636, 0.0741882776575429, 0.03751044041876282, 0.025872686146093265, 0.048024221789091825, 0.0515744459283139, 0.07656956916408879, 0.04595256277493068, 0.029350727730031525, 0.027799761222143258, 0.012979983052771007, 0.0538515076706452, 0.032566250900604894, 0.004233055556791702, 0.011498316174506076, 0.02808635575430734, 0.008050531315218126, 0.030316771606781652, 0.027983235394848243, 0.043154128294970305, 0.008493898818934602, 0.027799125095563273, 0.017099906889987842, 0.04303097418908562, 0.05943957942404917, 0.018684114828439694, 0.021525897518066422, 0.009949370852804609, 0.0334643802073385, 0.021000536690865244, 0.07245829834469728, 0.04878673908699836, 0.04167222138494253, 0.010273959105169135, 0.03574133338406682, 0.043847323062696626, 0.03549501499427216, 0.036913448345980475, 0.08696163831544773, 0.03292503646974053, 0.04617763962596655, 0.008712752655680691, 0.04720996958868844, 0.034185547581208606, 0.027248622849583626, 0.05087380423875792, 0.017105854249426296, 0.05038763050522123, 0.026343099207484295, 0.025937107957101295, 0.03610686698396291, 0.024328620339344655, 0.036196291114070585, 0.0076947041587638, 0.029572445832725083, 0.04683352175301739, 0.010938724103782858, 0.03906088615102427, 0.058010367543569634, 0.004797543257674468, 0.025465641470093812, 0.04427533955978496, 0.07436368574521371, 0.016317260850753103, 0.029240540428353206, 0.02583357708395592, 0.06732113007456064, 0.025130133044772913, 0.0453191910471235, 0.012278934242203832, 0.023381622940567986, 0.03819006787879126, 0.0038339637352951934, 0.05384678506691541, 0.03672312266592469, 0.0065453230885655755, 0.024874608631112745, 0.0636976920068264, 0.021575837695438947, 0.08072825601058346, 0.052219301861311705, 0.012575011301253523, 0.02477336611731776, 0.02266357682778367, 0.02519740131018417, 0.014387614126982433, 0.09946033478315387, 0.008646146810081388, 0.04208793943481786, 0.01850865754698004, 0.030903317632951906, 0.01743163587525487, 0.04104227286630443, 0.029961473707641875, 0.052060008980333805, 0.05526917088510735, 0.06278622270162616, 0.03110123611986637, 0.013457483412431819, 0.05476416101945298, 0.030451270818178142, 0.05502702209300228, 0.030108624204461063, 0.015607944090983697, 0.04173352363120232, 0.03884327318519354, 0.027478332398459315, 0.009461339629654373, 0.023958170753238455, 0.014174278476275504, 0.005571453582628497, 0.08399002812802792, 0.039399746539337296, 0.025179225053372126, 0.01037464097940496, 0.05228899419307709, 0.029646938799747398, 0.012708905768314642, 0.03777149658916252, 0.006251743886553283, 0.03531602763437799, 0.044606831057795455, 0.035456745619220395, 0.021779367666957632, 0.026602971334276453, 0.03567394467868975, 0.04671363479324749, 0.036535870749503374, 0.049159115712557516, 0.1117332690794553, 0.040156428436083455, 0.07282259701085941, 0.030998075048306158, 0.019381477497518063, 0.022894348283963542, 0.017869623444442238, 0.01994339100617383, 0.03191429749131203, 0.016197470582223365, 0.01592937291466764, 0.02632880925999156, 0.1079087471589446, 0.004787831725220063, 0.041540826471256356, 0.017181797585050975, 0.027240339633343474, 0.005297851723818374, 0.011440236121416092, 0.04572107037529349, 0.010890039216194834, 0.06516034887837512, 0.02813543419220618, 0.027867406074489866, 0.04883127812562244, 0.022873503688190664, 0.03039969197873558, 0.06692006838108812, 0.0987438764423132, 0.026813960101987635, 0.0452888673171401, 0.024443450516888073, 0.030157906202865497, 0.06217650470456906, 0.017982696216287355, 0.03481944856633033, 0.01308641635945865, 0.07959834592682974, 0.09128216933459044, 0.03899162468899574, 0.05733440417264189, 0.03712316994954433, 0.010272831040700632, 0.13167179668588297, 0.07815520372241735, 0.05913788239870753, 0.0462364516487079, 0.0024102435355806457, 0.014932250437725867, 0.01781390723772347, 0.06553339386092764, 0.0116095297604001, 0.007317875495313534, 0.08321107671196971, 0.034139285063637156, 0.03955330579940762, 0.0332367079598563, 0.030630624586982385, 0.10071107159767832, 0.07147797809115478, 0.02838045997279031, 0.017155775767085806, 0.06335436685809068, 0.037453161885163615, 0.040736677657280645, 0.03997458105108567, 0.006403021572623402, 0.014114809122734835, 0.046276800733591826, 0.03531255014240742, 0.03270016657188535, 0.04064172346677099, 0.022161206463351846, 0.02553069431866918, 0.017425730924255083, 0.007393662767883922, 0.01707724212402744, 0.08241943669106279, 0.027359305481825556, 0.023980324921597327, 0.07614756109459059, 0.022027263650670648, 0.014899234620055981, 0.01084974526228117, 0.041980303424809656, 0.09449252885367189, 0.045140505635312626, 0.015626790401126658, 0.02159422599444432, 0.023023118963465095, 0.04538391650255237, 0.02115195686928928, 0.03810187189706734, 0.04685539093666843, 0.03846026730856725, 0.026525151849325215, 0.029301659470157962, 0.026261254313534925, 0.02377830638683268, 0.025533915663670217, 0.029015813022851944, 0.016606605146080256, 0.05147757487637656, 0.033337266849620004, 0.04373424520183887, 0.024823148535298448, 0.03049573182527508, 0.059341972161616595, 0.05705509201756545, 0.06347284585769687, 0.01718795359400766, 0.028657034239066497, 0.04607724019193223, 0.05263268914339798, 0.01806690919745181, 0.06730756615953785, 0.044518923453454456, 0.03376864209505064, 0.04397854834262814, 0.03286147809454373, 0.03866072690912655, 0.05432640754484704, 0.08099232826914106, 0.014164186116041881, 0.037578015721270015, 0.07775083077805382, 0.010788978210517337, 0.012434775924443133, 0.01703049106124256, 0.01380326909877892, 0.015570110674681408, 0.030090961937925646, 0.016406691766210964, 0.022653186760310615, 0.07808526711804525, 0.0227087944014264, 0.017561609258076975, 0.05643491440319589, 0.004467276091288243, 0.04304015476788793, 0.03770640811749867, 0.16870071472866194, 0.1020049157419375, 0.17028764528887613, 0.20667964965105057, 0.08515905575560671, 0.10877316006060157, 0.1938591240239995, 0.10838279886437313, 0.14026116792644772, 0.11300008717392172, 0.09949504184935774, 0.13016485183366708, 0.062494852979268344, 0.13383124795343193, 0.154717125796846, 0.08155265570219074, 0.12969118010784897, 0.14312902332416602, 0.14268399934683526, 0.14942282917244093, 0.09927786993128912, 0.21107416812862667, 0.12815161129193647, 0.08621519551213298, 0.20845760138971464, 0.11196192859538964, 0.10596678672092301, 0.1032489486304777, 0.21051270754209586, 0.06803163766328778, 0.09764423580574137, 0.18708970583975315, 0.09996013010718993, 0.17630863934755325, 0.10310151654162578, 0.18854747047381742, 0.18031636572309903, 0.11685948579439095, 0.1379697144563709, 0.11116874829999038, 0.15588407032191753, 0.0920983383964215, 0.11973636570785727, 0.16415314589227947, 0.15578085157488072, 0.12095523173255579, 0.1077797305104988, 0.17387626772480352, 0.09313120440180812, 0.1679249456418412, 0.0893629737464445, 0.18049990944564342, 0.11508420748370034, 0.1201920426849808, 0.08345761562564544, 0.0918409972052489, 0.14344477280974388, 0.1610220189073256, 0.12815345690718719, 0.16647269071212836, 0.062420512682625225, 0.0983972196866359, 0.1659387515059539, 0.19793840870261192, 0.09158869752926485, 0.14919980828251156, 0.12377587466367654, 0.10965128615498543, 0.18082602694630623, 0.10323827527463436, 0.20225454281483377, 0.10233059219483819, 0.27946392978940693, 0.2350605438862528, 0.11552172686372485, 0.08638248832098075, 0.13603094991828713, 0.09858490247279406, 0.2559612680758749, 0.14338172333581106, 0.1172229770038809, 0.1509802434593439, 0.043978670478931496, 0.13459014865968907, 0.1144726574420929, 0.10833328616406236, 0.1837976574897766, 0.10144004890961306, 0.15900348579244955, 0.16341827889638288, 0.09319665588970695, 0.13644613192549773, 0.14822461775371007, 0.172427663313491, 0.13753778620490006, 0.08235028040196214, 0.11431705579161644, 0.14155193152172224, 0.11605238196040903, 0.11920618558568613, 0.10326151509902307, 0.11586851254105568, 0.08618899048971278, 0.08852541047547545, 0.15066479252917425, 0.15316203209970677, 0.15063476056924888, 0.11166890324758631, 0.13855123253805296, 0.07284114815826927, 0.1401226653584412, 0.10790872680289404, 0.21247982127325876, 0.09053576045802661, 0.13183947625969136, 0.15551922204239027, 0.09305519490901913, 0.13844667029167923, 0.11757639875369412, 0.08728869219443627, 0.21928697957524232, 0.08079331394817148, 0.10650566566203322, 0.14020863574530396, 0.13009671334709438, 0.13605083099433354, 0.0991069944575429, 0.12582996301352978, 0.1581939256617001, 0.12289721252662794, 0.14717592831168855, 0.09064675521637712, 0.07581098058394023, 0.07652263489684888, 0.09815432450601033, 0.1002864104562572, 0.10143295821866818, 0.19366765501243727, 0.10648125875741243, 0.10494981879102332, 0.10873575242502348, 0.13295876048505306, 0.1453776340931654, 0.11300650611519814, 0.2037111675100667, 0.29437403114778654, 0.10866358344044004, 0.09901594862874065, 0.09300613004182066, 0.2032429240643978, 0.17713886765497072, 0.1340643518737384, 0.08226190800113337, 0.10935051193726913, 0.06421458641333239, 0.11551001534930297, 0.16351606936327048, 0.15489800966211728, 0.08630607170718056, 0.18726299011281558, 0.16639778044606957, 0.10294694626437766, 0.126451256818005, 0.11297056411526032, 0.06544407829642296, 0.10942527971097402, 0.0506265121512115, 0.08221436983772687, 0.22149581462144852, 0.15045262819954328, 0.09870801586657763, 0.12132987805775233, 0.13955934558595928, 0.08249380412910666, 0.0943600313205804, 0.08897348107503993], [0.05240081676415034, 0.027559298589559536, 0.016505240495981913, 0.03468064405024052, 0.0339444742671081, 0.06108309980481863, 0.05070284055545926, 0.061013739955212386, 0.04387234404150929, 0.053620069553809505, 0.03171645025057452, 0.0421330009454063, 0.048484519589692354, 0.04614127354164209, 0.020075344014912844, 0.07239287399819919, 0.021688303178442375, 0.019179136658619558, 0.05672451654183013, 0.08751803024538926, 0.05588199996522494, 0.031386644912085364, 0.0018553677073214203, 0.04793245671316981, 0.036924131879849095, 0.02031023587499346, 0.005663226716153855, 0.01849172979460231, 0.03201813370521579, 0.07537895733756678, 0.053845251577773263, 0.03655782475003174, 0.008802901121920772, 0.034982768552643914, 0.08163487379040037, 0.01823232924964811, 0.03452634518699987, 0.019605451729148626, 0.009786987244816763, 0.07398554496467113, 0.09482019341417722, 0.0187599682581744, 0.026170832736949836, 0.03770030130233083, 0.0241692273744515, 0.04134870267340115, 0.09241988257105861, 0.06409998863403286, 0.1191274348114218, 0.026230720237695744, 0.016797568649053574, 0.025353752741856233, 0.061938135352517874, 0.022114940553105304, 0.018651599430346062, 0.02144281769038311, 0.03475739314619984, 0.021337663422205617, 0.03196866171700614, 0.0264217906099345, 0.022795087092423012, 0.028238345902147036, 0.03477035316505602, 0.016301439110455767, 0.01988887750277562, 0.0682528197233166, 0.02059817560283201, 0.03552178320075784, 0.06060562149754592, 0.04352564996640597, 0.02927865374035069, 0.01362614262117339, 0.016403387300670147, 0.02210002126438277, 0.02379717644570129, 0.02384852458323751, 0.033633467741310596, 0.058239461321915896, 0.04309738241136074, 0.054246961272188594, 0.025739072422896112, 0.02089613220388336, 0.02599906498965408, 0.04064607287624052, 0.0206192899162748, 0.03220480886687126, 0.030461289387728487, 0.1368938564722027, 0.00306395223014988, 0.034179386483239274, 0.0339667132523443, 0.06892686284014157, 0.05115372029000095, 0.06800957848983151, 0.01351708677663867, 0.03580474587423461, 0.009804653752196048, 0.035589548493070264, 0.030845601444265673, 0.03199710251231279, 0.012980527577123471, 0.0511513352394104, 0.05847504189504044, 0.09279471888606038, 0.028453702739040767, 0.03096663173554199, 0.022235577294070805, 0.02197181885795934, 0.0676382841276271, 0.03433519847957151, 0.021649377320760062, 0.026962340443528125, 0.08385938978088753, 0.07929749028491122, 0.03971724325258817, 0.06343127201710429, 0.02845471036354346, 0.04041411568011556, 0.06690979536090579, 0.026127101154997945, 0.03721470432356, 0.023186730719836693, 0.08483126905879804, 0.013920589499840779, 0.035803918061511855, 0.05696969838546855, 0.02157925581559539, 0.07245652058294841, 0.009494434327020176, 0.02254943366694663, 0.01808434076208089, 0.08620921761861869, 0.03217602201870509, 0.051551050040870905, 0.01579686181087579, 0.020420419783996682, 0.002676676247834361, 0.028735557704099586, 0.031116801713194166, 0.053070425654628446, 0.028141941343035017, 0.030489743753735508, 0.04529106577060052, 0.02793968701735139, 0.01918242246444736, 0.07654057536274195, 0.019296150022585477, 0.047802836168557405, 0.02928387506731919, 0.035650457189019234, 0.021565400130514587, 0.0663066455828292, 0.10720412246882915, 0.002996375655389524, 0.029714754982186214, 0.018057009371529733, 0.08274739302162613, 0.0585285783080118, 0.04841321912993278, 0.03523147199302912, 0.024753619051937546, 0.054794922404523404, 0.025898979378065894, 0.0191405839951975, 0.04289900930598378, 0.01607593478235815, 0.03600611810439399, 0.058032012810664516, 0.009368573714579855, 0.09667007665016822, 0.02663468266837299, 0.03377602116337844, 0.03364115893574698, 0.03531011759436556, 0.01198198611382395, 0.01411613481052752, 0.03968619688280991, 0.07138396027897086, 0.005632310964366687, 0.03712090364258204, 0.0037201865592838396, 0.07778133771249227, 0.0663465027298246, 0.05972786859742232, 0.03364948795310088, 0.029106980987957547, 0.008432849326969256, 0.0201562932426376, 0.07597152875470263, 0.03207137495545404, 0.009077812977401274, 0.02319275102178965, 0.008254090124475104, 0.032084402827812095, 0.009563301390569125, 0.09696678644312279, 0.042293823922851255, 0.02784153862324144, 0.02900484450427549, 0.040642714127898216, 0.02713414720658745, 0.036376353951969316, 0.01362958618639303, 0.023775994278756634, 0.01080801705497184, 0.010813765094748564, 0.05412005486765078, 0.058185504217232974, 0.06205157283693552, 0.01639076485298574, 0.014492929547226854, 0.034105609370661635, 0.02712229489614921, 0.06220457569829055, 0.049622036051005125, 0.1255397807274546, 0.027024799591994712, 0.025426878460815976, 0.03705399330439312, 0.04088438455281513, 0.022521118400618434, 0.01406979765410402, 0.047137485085321326, 0.027068198691787462, 0.05935117309646947, 0.056846439106655974, 0.0420367609310363, 0.05473258539236017, 0.03855760994234255, 0.01599097710901073, 0.049906410077320676, 0.052982857317796776, 0.034561170996831994, 0.02577834602977548, 0.031138345200036253, 0.07513933269573109, 0.06166567640112979, 0.04449084567438279, 0.07736363155501229, 0.05521907464468053, 0.022558653261512518, 0.012877196871808596, 0.04326540125267846, 0.031243484201175824, 0.029961660304772, 0.04794597991609147, 0.052162040291087966, 0.05422468836020146, 0.058695531849350245, 0.007685589737125805, 0.026934001428474273, 0.06560354081115552, 0.030892359292400733, 0.07373187464794942, 0.03260588752371924, 0.014460146127800857, 0.032587672251143625, 0.013966354990511068, 0.007556944586602705, 0.04009069874882698, 0.0248266362052943, 0.04264229915237852, 0.07754809808518205, 0.01601666983749185, 0.018804459799347178, 0.011305741150863469, 0.01983282881389771, 0.014701492552246367, 0.04328705669779863, 0.09430901227252823, 0.029431171449167386, 0.036898591821747165, 0.02243484097665974, 0.012902287400460668, 0.054833877099944014, 0.01648601420622851, 0.09063051787338086, 0.02577711109604154, 0.06229332807872977, 0.07932023477873631, 0.03097185306251049, 0.05067437601142696, 0.0419746614061296, 0.013678768100882215, 0.06420141604862042, 0.06355309619435243, 0.00925184872799686, 0.03696299158036709, 0.03893656496490751, 0.09251029736229352, 0.019333023311836377, 0.0420330968419356, 0.03643493866547942, 0.043635827090059004, 0.06781880836933851, 0.03678266750648618, 0.017184659306492125, 0.025578671833500266, 0.033284829663378854, 0.06299555754022938, 0.023898308697555746, 0.01711579648378704, 0.018254171291898404, 0.012973228236660361, 0.016453946641247188, 0.047905261029622385, 0.030292975383677652, 0.08910784457943269, 0.07025945811931576, 0.006307795968106282, 0.021920735349080393, 0.05221039269651685, 0.04813093159879957, 0.09421690114374671, 0.05899050459265709, 0.04881326302087732, 0.0718504259628909, 0.03950789484328457, 0.07351158146879502, 0.06196075092468943, 0.035431602504104376, 0.03208929506529655, 0.0770823923604829, 0.09532002945031438, 0.0326265421296869, 0.05766308653567519, 0.020505730295553803, 0.033951062842139175, 0.042399034170167785, 0.028836289620293037, 0.02916799146415932, 0.06437138907079186, 0.08454647434077092, 0.04914701064782483, 0.06572142269994531, 0.003905142058751413, 0.07831546012312174, 0.028730797780943767, 0.03103774899084653, 0.05906208325177431, 0.005256852093485317, 0.022552744917837635, 0.031273875784661086, 0.020537436540637697, 0.017744438822514245, 0.01635235977093024, 0.05156208641294922, 0.040425993435617, 0.021242880561788167, 0.0659276634188635, 0.009982211947707193, 0.011921572748438587, 0.1931568674210991, 0.23098129991974148, 0.0977487505546638, 0.1624082795211247, 0.08818752717758928, 0.18591024912893772, 0.1534936185926199, 0.2015266783003296, 0.146513325295278, 0.09992729579763752, 0.11329199972429446, 0.11252716862197433, 0.1692459447575467, 0.16084608834769043, 0.1294147449412516, 0.10575977925743375, 0.07765774255884544, 0.16943824158183166, 0.1856732097055231, 0.20392988648797783, 0.22098282857664994, 0.07601516534175191, 0.12144582612173897, 0.13208898715674877, 0.15904294938913413, 0.09839713147708348, 0.10802177752235106, 0.06561390882624046, 0.0883153835311532, 0.213221989305956, 0.15809898504189082, 0.1168892327696085, 0.11218236426689795, 0.10094403302563087, 0.13494086984012807, 0.08779543571706329, 0.0898550134152174, 0.21965296779360088, 0.12699840031564236, 0.22073711747569696, 0.1175768601575068, 0.07816018416945424, 0.0845615446035351, 0.21152243550334657, 0.1861056536436081, 0.1756427250802517, 0.15770611326609338, 0.07023477980068751, 0.30397120331014904, 0.11799673762704645, 0.14577507919498853, 0.129322776304824, 0.1981421456273113, 0.12386009443019118, 0.11665140624557223, 0.11744207596140248, 0.10358558342392955, 0.20671614126435348, 0.15921157891196863, 0.11312493083200284, 0.15106918582958834, 0.15223625249096326, 0.1264627104891198, 0.12786374959562505, 0.08976326190999576, 0.11767573628042426, 0.1014215520450047, 0.08229772786476783, 0.15699647420219012, 0.14714702271989413, 0.12998768634029798, 0.12115083980773177, 0.19403875938483647, 0.12001149808721882, 0.10407365366284337, 0.16223494096526078, 0.11895762463765484, 0.17299452503877027, 0.11190845325056996, 0.12524015323391982, 0.06342993530311755, 0.1236084122210741, 0.15465514840824263, 0.08158044849655458, 0.11003719616149153, 0.11171266875628914, 0.19262689085943357, 0.19944976403244905, 0.16128476123724664, 0.10618404684854404, 0.10219738219997712, 0.1534528929208006, 0.1367654912173748, 0.13193517683872155, 0.14649824824716362, 0.13415663263627461, 0.09422329294362239, 0.06766299637300627, 0.16893495858779975, 0.07967606532786574, 0.11749927646347455, 0.1388839589697974, 0.23261708500129835, 0.14376694123659814, 0.15026316765163625, 0.07248555509639637, 0.11391505093446799, 0.11905199528804847, 0.1748016673539366, 0.11809213965066842, 0.09562353816415582, 0.12411795130797795, 0.12749487081808702, 0.14989036694169044, 0.15112661703356675, 0.14714310078748635, 0.08819659240543842, 0.15147436623062405, 0.2399101693715368, 0.1398584031100784, 0.11092449604932751, 0.20776880692158425, 0.1816472035965749, 0.14374734514525958, 0.09846372290381364, 0.1588897361819233, 0.15530627061213764, 0.2600789985486439, 0.07832305292998042, 0.15796080817069325, 0.17848980373569898, 0.2547843355153288, 0.12128430764589991, 0.14895865693688393, 0.038932198592062504, 0.17308250388928823, 0.12273525978837695, 0.14764711659933838, 0.14230319192366941, 0.1427563311798232, 0.10185006047998156, 0.0941812644845673, 0.15568042839212076, 0.1602145079523325, 0.12175025764320578, 0.18635264039039612, 0.13256883355123655, 0.15309516925896915, 0.17285401400710854, 0.10380245678658996, 0.12880400914166654, 0.1357974253062691, 0.20219245686062745, 0.06484876559781176, 0.09339835720935039, 0.1655229723879269, 0.2021731593246971, 0.11948423566562788, 0.19113039544650487, 0.1210198418370315, 0.12139150260814599, 0.10868596831070525, 0.10330875470702137, 0.14770230863775524, 0.08128080743231944, 0.09749390637235981, 0.14237703010439873, 0.12197702404643808, 0.18322990009827272, 0.17435591055878571, 0.15515638222651823, 0.1779683224324669, 0.1451863550714084, 0.12090534583798476, 0.0842054019282971, 0.10388468166014977], [0.04918173128472907, 0.06973696579890591, 0.007681115646846592, 0.0341228984429368, 0.05556909354137523, 0.07609220620776926, 0.023781822894566824, 0.055341509503445456, 0.013026894419454038, 0.024521836578579884, 0.03136407344469002, 0.012902603767413114, 0.012695903341019792, 0.03415456906493221, 0.011785119356188391, 0.019528785753729086, 0.02799129978354488, 0.012066215210195099, 0.033340371147330315, 0.01390560150944761, 0.04356095753610134, 0.06242554062711341, 0.024363390170037746, 0.028658163999872546, 0.0535703736490437, 0.03520994886223759, 0.0635254933897938, 0.014358476136944123, 0.02606056401106928, 0.03508469808314528, 0.05174827981474144, 0.021720062009990215, 0.042384720473949394, 0.05196880708847727, 0.05452840741989868, 0.0428274611809424, 0.009617839490861764, 0.02672061912848481, 0.044563143580619774, 0.020069418707862496, 0.0022605143936483985, 0.034118382792387686, 0.014648824664098876, 0.028956807617630278, 0.0573875131085515, 0.01887458808986204, 0.033872318853225024, 0.012819252525722342, 0.014575013624770301, 0.07021489872464112, 0.03763779126373785, 0.08225557726940938, 0.05065660517928856, 0.10450371594301291, 0.07587951262082372, 0.02485516351381583, 0.014756793156266212, 0.04773678417716708, 0.05192661578101771, 0.022589621599763632, 0.01119326803434108, 0.015295885835907288, 0.026198308316192458, 0.03946926923734801, 0.04900266928598285, 0.021994648168661764, 0.03623304735603077, 0.014124891304943179, 0.05639415819730077, 0.022207625043977584, 0.032317313365638256, 0.023287091138107435, 0.030121696181595325, 0.04586130320759756, 0.04275402333587408, 0.016661722545645068, 0.04329777755109327, 0.03090528877718108, 0.04151130680527006, 0.05127366492524743, 0.00822749239991286, 0.06559371562408549, 0.02271074688594256, 0.045131053642502854, 0.008281950772340809, 0.07788539784295218, 0.0223762986715883, 0.04452885042077728, 0.00328260865561398, 0.017199313966557384, 0.014672815966020738, 0.012760106324484306, 0.07381357704954487, 0.020370376130033816, 0.04898757188181792, 0.026623339259198735, 0.014278929780370422, 0.03231516580230423, 0.005156350879198206, 0.010996320700672055, 0.02955042737136994, 0.10014028115464108, 0.033441879986120124, 0.00935434568340757, 0.040659266989678144, 0.021901118901691267, 0.04800981649064592, 0.08438457588532142, 0.021871475403064063, 0.03444562326850636, 0.05705698513026748, 0.016550970363563726, 0.05469314554440124, 0.03001826030335256, 0.0571170694061688, 0.04159902102713074, 0.029701645685625926, 0.041756335978529284, 0.08643513585307769, 0.021884735673666, 0.04798313310103757, 0.022625258258943046, 0.08126644284597465, 0.035580920920308144, 0.04000199047316398, 0.04754577996209264, 0.048364761551576, 0.05713332031986543, 0.054187752306461334, 0.03297646603147898, 0.04795535048469901, 0.02668625132979027, 0.03506251677338566, 0.029874797644359723, 0.030711536495281116, 0.06096460723451205, 0.07676910595702273, 0.011447437074301499, 0.05313698993995786, 0.027716800138088207, 0.04430795334545629, 0.014586375693657568, 0.056924840435385704, 0.034796999235238345, 0.033387587006602965, 0.025304971163028052, 0.02606451478121536, 0.057629478696201525, 0.058166613802313805, 0.035165891583476744, 0.02712449334960963, 0.02559581502074642, 0.04084100241639784, 0.023107074101322463, 0.021245362303618873, 0.03022168849461845, 0.02875701298138925, 0.04179200656445963, 0.035529986689133305, 0.03519612031855753, 0.015230919500546796, 0.15222555877906935, 0.04345715185627341, 0.052623518742620945, 0.051540159553821595, 0.019247975732598985, 0.03515773559255259, 0.04273190309426614, 0.03788774320855737, 0.017652042709024887, 0.05705267643289907, 0.01929783109309418, 0.04524843341537884, 0.016757624988843287, 0.020160498463415673, 0.05672463867813349, 0.04904951873634543, 0.05903600036565747, 0.027783288088228022, 0.055362143753362555, 0.07884481243257012, 0.04056683016408767, 0.0370747870100396, 0.019955709809437394, 0.03737398702651262, 0.017139587617878402, 0.02224165866417544, 0.027087716751598885, 0.07385355633284364, 0.03284078956182514, 0.042142815954451046, 0.05292897145929081, 0.016026293160393834, 0.03839878185785242, 0.024250493817297474, 0.05062340785350118, 0.025368307318006243, 0.08603207926665034, 0.023118156274514537, 0.01243193116637745, 0.057464031502604485, 0.01988784104053463, 0.018098108237609267, 0.03829708642193249, 0.007252955809235573, 0.019786549332950796, 0.1364165206572839, 0.014191587904601224, 0.03730850161186286, 0.10094704572111368, 0.03845420799085072, 0.0018107410952714936, 0.01720276431712721, 0.026746807187529545, 0.03628028357135398, 0.010551915038377047, 0.006909434309428824, 0.08866811317524739, 0.030185926306460584, 0.0395689765656633, 0.05032049285780106, 0.014024976175278425, 0.03992131944479687, 0.06448454157050167, 0.014476975492600883, 0.03260856095169272, 0.036583164640303166, 0.03557390147554023, 0.05986562477690833, 0.05355473680953894, 0.05092524737119675, 0.009755661827512085, 0.0538158133359892, 0.023900612323944057, 0.05531895499942558, 0.02720252826942929, 0.021523402205535343, 0.028876825302307094, 0.08356977067887783, 0.03181602865723627, 0.049150437249669006, 0.029355487653187344, 0.019834202847310474, 0.013191197433375886, 0.012816922606102057, 0.017452969016241174, 0.03430279843243105, 0.11821270175278187, 0.050515042418347936, 0.02292523350167487, 0.040095872578344176, 0.031265472128455124, 0.005125748101688389, 0.039381575371537886, 0.040049325076064894, 0.08064039251101868, 0.06679471582174301, 0.08681863706026759, 0.03714013671768563, 0.014301072074366468, 0.01402591509811048, 0.07559004958186831, 0.039529987943491766, 0.038977752040539465, 0.04142221515732152, 0.022194086574018, 0.05317016351701958, 0.048272151699555774, 0.05688691711319344, 0.017321859087262834, 0.009620196551882794, 0.032755060054894, 0.07330527289637498, 0.028578090082321848, 0.021413550778691257, 0.06035771194313254, 0.06368033508104937, 0.023686573541324054, 0.03841509044702564, 0.008502659554194127, 0.041895612076457055, 0.015042373278577412, 0.021711337745987942, 0.045726610613720756, 0.06544649388108935, 0.035323749362890206, 0.08474600434835468, 0.0382575719351215, 0.06413901796830551, 0.03951081932921495, 0.03917484610740628, 0.04048015410080552, 0.015074432361871004, 0.006600227173683899, 0.040717746530260356, 0.05768731702119112, 0.021975925691159706, 0.022265590594283173, 0.03549899120948144, 0.037524384313396046, 0.012646438986329096, 0.03278732778770583, 0.012337919291374939, 0.01934327258329306, 0.013512786560957986, 0.049759103517447195, 0.03390222867684705, 0.029116053001156876, 0.05879639607987233, 0.03441289413188185, 0.03848064032250217, 0.02251891485814537, 0.013345306306811315, 0.0291695554873773, 0.07887380623391696, 0.03664743208459445, 0.06134525180927344, 0.03193042966138039, 0.02037284430116415, 0.04374196693035109, 0.03161090073574867, 0.020800455373578837, 0.027790485648438334, 0.0981778832418578, 0.07406445180198976, 0.04232204419427684, 0.0298760156147182, 0.018446620786562562, 0.027095725161156485, 0.02383154085172074, 0.011687894617872579, 0.03218082604663713, 0.03136566800198384, 0.06464143243751355, 0.024079918595296994, 0.04376414484743561, 0.08140167487519127, 0.08413699881306716, 0.015342418071148651, 0.05338077060878277, 0.07965138700923749, 0.015214799204841256, 0.043792768847197294, 0.0216978298101042, 0.020549595888171877, 0.012407819424489779, 0.07276536936738662, 0.04441269540360995, 0.03432956663891673, 0.02146630178737853, 0.06114931803728853, 0.02023822973881449, 0.09229529675628458, 0.15598015088055814, 0.08922934305987187, 0.10248482320457697, 0.15443645657173224, 0.17693194161568368, 0.11371456419250794, 0.11653753449874264, 0.09063815817769084, 0.1315243374556303, 0.13318039716354438, 0.10374852003795759, 0.12456735862152916, 0.09128328213202101, 0.11645549961498805, 0.15747337575469697, 0.0724188686747636, 0.12963221541472844, 0.12781063387436525, 0.13386393977063044, 0.18530290600444588, 0.2236355205199548, 0.1119428685467158, 0.10477942507714033, 0.1874277384153434, 0.1216569183660405, 0.1855586322822741, 0.09994752971189362, 0.09489200956055097, 0.08492981269955635, 0.21160759164818696, 0.07945320728634085, 0.13056573032268456, 0.223025558250291, 0.1430335534470422, 0.05446491011285356, 0.08974154200404882, 0.10015868302434683, 0.08527454241578068, 0.13256675723407949, 0.04400993737259081, 0.1797620840370655, 0.1464654342936618, 0.14439603819378785, 0.111962451067354, 0.11038293689489365, 0.17688263926122869, 0.10765750599758965, 0.11890625953674316, 0.14875026526195662, 0.062174638733267784, 0.19018588827124663, 0.10556365549564362, 0.16954794712364674, 0.12091746447341782, 0.10671633721462317, 0.1487348625170333, 0.11454000882804394, 0.14093899726867676, 0.08700712730309793, 0.06821218904639993, 0.09703246184757777, 0.15030307908143314, 0.10652359934257609, 0.23417198870863232, 0.07894344428288085, 0.11947654107851641, 0.09109103280518736, 0.12659950314887933, 0.11295670843017952, 0.10213728435337543, 0.26985001138278414, 0.14143440925649234, 0.13286128214427403, 0.13997391691165312, 0.08608483536435024, 0.1517419668712786, 0.11825603299907275, 0.19462061673402786, 0.22501753350453718, 0.13803143400166715, 0.230131095541375, 0.17833363211580686, 0.13100931580577577, 0.06779716310224362, 0.2255156324910266, 0.1800689311431987, 0.12314886759434428, 0.08650090625243527, 0.09209293725767306, 0.15493266923086985, 0.08899461744087082, 0.17367401000644478, 0.11077797319740057, 0.14962155850870268, 0.1722523027232715, 0.12903214618563652, 0.1407278643122741, 0.0972332132181951, 0.1472991502710751, 0.12323136388191155, 0.19668697299701826, 0.13862604780920915, 0.06487712157624108, 0.16679897106119565, 0.09677198582461902, 0.17698812431522778, 0.17262500843831471, 0.1667101779686553, 0.14858904534152576, 0.16846581947590622, 0.12147534239505019, 0.23242280685475894, 0.1236713667001043, 0.08807134162634611, 0.08489136690539972, 0.10080592400793519, 0.07902644268636193, 0.22326740170163767, 0.10299400945327111, 0.10885636202458825, 0.16069322797868932, 0.1663849697049175, 0.07544294997517552, 0.1007894966751337, 0.15618768760136195, 0.1350227961582797, 0.13275955617427826, 0.145213157204645, 0.13439808253731045, 0.08634126731859786, 0.14364850973444326, 0.09962101866092, 0.09008309617638588, 0.07826455642602273, 0.21550008920686586, 0.09107791672327689, 0.16248095062162193, 0.3039161334080355, 0.11903143567698342, 0.18224214310092585, 0.12303703145257064, 0.12799835737262452, 0.11373905930668116, 0.07824680594993488, 0.05626493798834937, 0.10684669736240592, 0.1580151452549866, 0.16847902376736912, 0.08346358673380953, 0.11119219847023487, 0.09086929434644324, 0.1282586298350777, 0.11995334763612066, 0.0958389255351254, 0.1514825765043497, 0.13543767961008207, 0.1269719238792147, 0.11369690871132271, 0.14681110717356205, 0.09543711745313235, 0.20955256692000798, 0.18564671969839505, 0.09812499822250434, 0.1726455951907805, 0.11241476251078503, 0.16041417366691998, 0.16535561851092748, 0.11433430415179048, 0.08934276697358914, 0.17310664616525173, 0.13535227919263498, 0.12227149467383112, 0.09925528150051832, 0.19084318514381135, 0.13906708200063023], [0.024298859793426733, 0.09988125719662223, 0.010561457785245563, 0.02194336279561477, 0.04442687678549971, 0.0321376644341009, 0.007650856377689966, 0.023643662986744727, 0.07545777596533298, 0.030655323261661187, 0.03773305758035608, 0.02705133200756141, 0.009291616817271071, 0.04195913991757801, 0.040842027004276, 0.06545987459165709, 0.033860933035612106, 0.021152355508612733, 0.07214242672281605, 0.02325689802611513, 0.026031782251915762, 0.03093947676409568, 0.013999226619489491, 0.04675223325778331, 0.020849360785047923, 0.027775598590129187, 0.027269160408260565, 0.024841891368851066, 0.016673233892236437, 0.026197456754744053, 0.02980040306491511, 0.08393944334238768, 0.00955373065413109, 0.024421014756496464, 0.06781449967197009, 0.016006897236885767, 0.023919840310035006, 0.06922700602029051, 0.029770561094794954, 0.03471093724614807, 0.016322475392371416, 0.029656906479171345, 0.07647086946027619, 0.05489861273339816, 0.03167108339922769, 0.012086403323337436, 0.04355040631656136, 0.07055253096457038, 0.011628144520467945, 0.016307249066552947, 0.04764023882203868, 0.055363039419587166, 0.04824203492275306, 0.07532500023288385, 0.11400118416973523, 0.028334657162693993, 0.05110130345981036, 0.023298787385491387, 0.08863640523382596, 0.0641705019931708, 0.04221662020842944, 0.02841329088966761, 0.0665449538667287, 0.029188381441469704, 0.03278929214658482, 0.02832572255283594, 0.040144638890134435, 0.012106673708850784, 0.04180383003715958, 0.044765584503433535, 0.06548124844474451, 0.05293385012607489, 0.02878432401588985, 0.03912246320396662, 0.016952717377405082, 0.003933835608352507, 0.021628492012886063, 0.047753404892448864, 0.003934893698897213, 0.02348511479794979, 0.028383684710466435, 0.0533005779476038, 0.04197365038895181, 0.0643493773947869, 0.08406658044883183, 0.030703224441302673, 0.03129045578784176, 0.03428567899391055, 0.016409986053726504, 0.02915878374395626, 0.040656800514885356, 0.042939962287034304, 0.02917257836088538, 0.040688223471598964, 0.058294124103018215, 0.011592568081271435, 0.02639120734030647, 0.01895459245757333, 0.06182659098080226, 0.032677018349724155, 0.026560359335105335, 0.07899803242513112, 0.07426226511597633, 0.06243805281285729, 0.06010503228753805, 0.021717651514336467, 0.019679179647937417, 0.032587244774081876, 0.012671976499924702, 0.017405473261273334, 0.04080453794449568, 0.042615106861506186, 0.03555326383294804, 0.06212368753871747, 0.004988980462907681, 0.06298214290291071, 0.07335998317492859, 0.01670099445618689, 0.013095922635069914, 0.0340828343427607, 0.0301193993405572, 0.028072796928297197, 0.047125525905617645, 0.02845288340800575, 0.024250051073197807, 0.0701296611555985, 0.05277449278427022, 0.04280315266389932, 0.05679720799837794, 0.06245217991194554, 0.020126017010105506, 0.08092376230550663, 0.019624338751392703, 0.034688532019832304, 0.027963897146816765, 0.026844724879733155, 0.06090408191084862, 0.061419619247317314, 0.08901656126337391, 0.009161251580475696, 0.015903530908482413, 0.042799525894224644, 0.0420965534368796, 0.028323349376608218, 0.017716707096302083, 0.015170110888513071, 0.04469479973028813, 0.036527358527694426, 0.02724946932201939, 0.0556476237917585, 0.032307864765503576, 0.021778967331296632, 0.04490355442145041, 0.02941147018490093, 0.024211951331900697, 0.013076044103529836, 0.05810281793986048, 0.05994867067784071, 0.032462221304220815, 0.03766223888045975, 0.037581513569291146, 0.08344538842460938, 0.05398270580917597, 0.05213224581841912, 0.07899043961827244, 0.05070117814466357, 0.04050138206886394, 0.024528196148042167, 0.020049161044880748, 0.053773812018334866, 0.09004797520382063, 0.07507939091218369, 0.021144265674852898, 0.004198829826366688, 0.045046983153692315, 0.024643050074311237, 0.004438102902245841, 0.0484708403237164, 0.01570689315641565, 0.015440819219553044, 0.012224593765235372, 0.021845535009301136, 0.012114183395169675, 0.052806760517082045, 0.05103856950466122, 0.0719105713069439, 0.06800672864275319, 0.005114289341560964, 0.04411419088553105, 0.030459101112293344, 0.06396338596407856, 0.019509308406018784, 0.035226698499172926, 0.019563474160219942, 0.05333258105175836, 0.012383892583394689, 0.04281885057155575, 0.06300733012280293, 0.039261756265269857, 0.01975809157426868, 0.09122346248477697, 0.10309476511819021, 0.04947294155135751, 0.01831771948906992, 0.03775714557351811, 0.019336916406505873, 0.04091892198526433, 0.021371296706742475, 0.0504932716222746, 0.06352026188480002, 0.04505576000415853, 0.07829069359494106, 0.03150734272120254, 0.037474576450352154, 0.025195355527102947, 0.044859738022621186, 0.02847947858806167, 0.07477116637996264, 0.0755890996328422, 0.006894674476435674, 0.06993018543081624, 0.01457267437529351, 0.08633406806205, 0.01695951460195439, 0.007707193443950797, 0.07475134637206793, 0.021536598015310507, 0.02543947207076209, 0.026401872214462076, 0.022884107494194592, 0.025904690946585367, 0.02558079225543354, 0.052746238586093695, 0.049187963628875356, 0.0615671734724726, 0.06145849930388587, 0.06443697626569442, 0.022514429741672108, 0.014694164374044963, 0.008335226797498763, 0.033877319656312466, 0.04697302855285151, 0.05481704603880644, 0.01370462791861168, 0.02996906651450055, 0.0739109061126198, 0.016457861788304787, 0.0343127627191799, 0.03294202698660748, 0.03468265251389571, 0.015446888715294855, 0.06089821258293731, 0.013784950349612959, 0.031243480808500732, 0.06854809780738183, 0.06836114105369363, 0.016304261816133345, 0.04087436937593988, 0.06715976766177587, 0.04563422467825668, 0.08242000666047845, 0.048599253075995615, 0.0853758409087147, 0.005751139833591878, 0.024089772620105317, 0.02552186488173902, 0.040433331791843684, 0.08824655293886151, 0.02485716179944575, 0.02576891948202891, 0.07994002902082034, 0.04057184453787548, 0.024269867688417435, 0.05403781642339059, 0.010311242059937544, 0.02471917661439095, 0.03069922447736774, 0.06942152165408645, 0.049680478272161314, 0.03481033584102988, 0.038102353656930585, 0.05024795067895736, 0.015535011754504271, 0.04639764103506293, 0.004296356512765799, 0.06804152391850948, 0.022346181894785593, 0.015149585204198956, 0.039375105540135076, 0.07630591081189257, 0.02990577955331121, 0.09411571121641568, 0.008086347786177481, 0.07139917303408895, 0.008500835143162735, 0.04480023389416082, 0.062168165509189875, 0.0358811557026846, 0.015928977668019276, 0.013576026024696018, 0.0371912100485393, 0.026301338769761578, 0.02032518569779183, 0.02690085329647575, 0.005750389628311885, 0.025034274706350904, 0.04922216518649033, 0.02723131511759545, 0.03111215714099152, 0.020629700339798416, 0.05978969670832157, 0.023058390910071985, 0.014796412816005093, 0.018509431076901298, 0.05985915155283042, 0.06640672271272965, 0.008478835341520607, 0.02107375061937741, 0.01896066195331514, 0.0797530926231827, 0.06724861503711768, 0.022541562660730312, 0.010195236320474317, 0.051959304205541096, 0.00472409905134035, 0.039477808600557704, 0.01214461908343115, 0.007875319154533957, 0.021833275577851703, 0.05099976747961981, 0.02524396068682628, 0.01574228554298835, 0.039027800783514977, 0.04391219101047941, 0.05978357632245336, 0.015341364645532199, 0.06112959302429642, 0.043035242174352915, 0.037623250258288214, 0.04627795085044844, 0.04702290766207235, 0.0708629268088511, 0.031669353134930134, 0.050383586436510086, 0.034833182115107775, 0.01873437052459589, 0.03236328750582678, 0.09311358963272401, 0.03889196485813175, 0.03776513532336269, 0.05359606298484972, 0.02681278284373028, 0.10833368649972336, 0.18487681315413543, 0.05771310813724995, 0.17308354883321694, 0.09924944609935794, 0.10838222210960728, 0.05658811064703124, 0.2060903962701559, 0.12663395915712627, 0.1190794895270041, 0.1162289096308606, 0.12869495499346936, 0.10677221457340888, 0.07935902662575245, 0.11113832957510437, 0.1516864084239517, 0.12125032661216599, 0.1463088962648596, 0.145923841212477, 0.18262989872268268, 0.09968551341444254, 0.12189644122762339, 0.10236290403242622, 0.21652839545692715, 0.10114567327712264, 0.181758510481034, 0.08488252559410674, 0.07348391759608473, 0.14307602973920958, 0.11436751165560313, 0.1160204636731318, 0.19266355889184134, 0.13868885301053524, 0.15076437432851109, 0.09901294271860804, 0.16872405633330345, 0.1619994214602879, 0.16776965611747333, 0.20224531473858015, 0.1522189091358866, 0.09555581358394452, 0.13575482687779836, 0.19415398820170335, 0.09616521945489304, 0.15372569113969803, 0.10584474541246891, 0.21417226402887277, 0.15257256158760615, 0.10917254577257804, 0.0772613152595503, 0.19804792425462178, 0.11442163160869054, 0.09765271749347448, 0.16370557062327862, 0.17416156455874443, 0.12345290556550026, 0.14940072250153336, 0.11149409905608211, 0.13230272568762302, 0.12461299688688346, 0.18524870462715626, 0.14781385979482106, 0.1846774595656565, 0.12539477779396943, 0.08454443195036479, 0.11241684561329228, 0.2210234592535666, 0.12137312787984099, 0.13414098561874457, 0.13085120357573032, 0.15000096814973013, 0.11037588691604988, 0.16902794502675533, 0.2252697314002684, 0.12072310490267617, 0.15386660929237092, 0.08352968961532627, 0.15965204313397408, 0.13431509770452976, 0.1780046240559646, 0.12517246258045944, 0.18260049101497444, 0.140815476753882, 0.11525299985493932, 0.16983139834233693, 0.12456275815410273, 0.16071571462920733, 0.11939992090421063, 0.15069417309548172, 0.12039501965045929, 0.11416623102767126, 0.1278135244335447, 0.11514995752700738, 0.10306461780731167, 0.18414219043084554, 0.1652929897287062, 0.09196131503475563, 0.13451519768152917, 0.12323658860155515, 0.0928670507190483, 0.09641634526529483, 0.128521127892392, 0.1012127125369651, 0.20280526897736958, 0.09576601694737162, 0.07160635013133287, 0.11685902439057827, 0.18843651642756803, 0.15540486175034726, 0.21247604861855507, 0.12824664690664836, 0.09733069155897413, 0.09648583403655461, 0.09734045567789248, 0.07107588502445392, 0.20196634185101303, 0.1298515722155571, 0.15989402229232447, 0.052082047797739506, 0.16502761468291283, 0.16374314789261135, 0.16032533986227854, 0.10717556292989425, 0.09945603287113564, 0.10353571788540908, 0.08598445967904159, 0.16370037304503576, 0.13578728799309048, 0.14480484197182314, 0.14257578658206121, 0.11104786050106798, 0.21329390044723237, 0.18205908792359488, 0.08880654110440186, 0.11606028010802609, 0.10799196269363165, 0.15379406032817705, 0.13634494878351688, 0.21914314372198923, 0.10460966918617487, 0.13977871595748834, 0.0682584447786212, 0.12900230421551637, 0.12195123971572944, 0.1254044265619346, 0.12968910379069193, 0.1360516995191574, 0.14863644779792853, 0.10293541116906063, 0.19344555693013327, 0.20903825094657286, 0.08230510354042053, 0.09306512866169214, 0.10454686398484878, 0.07538350352219172, 0.1099045289946454, 0.11818231695464679, 0.17676232143172196, 0.14526365378073283, 0.08968867734074593, 0.12634913729769842, 0.13267156375305994, 0.11001891642808914, 0.11749853007495403, 0.13135462227676595, 0.1787231383579118, 0.09126711264252663, 0.08670665842614003, 0.1045189897662827, 0.138551015406847, 0.13423938676714897, 0.1699605371270861, 0.08754333960158484, 0.05800386717809098, 0.1407097338565758, 0.09545839631131717], [0.004512202318957341, 0.01501058052027864, 0.031774247863462994, 0.03237344178238085, 0.02803423747952495, 0.026969712726505737, 0.0036993546860425598, 0.02683044341392815, 0.10840604547411203, 0.04092075402981468, 0.006419732193795166, 0.05120199466390269, 0.013808738091029227, 0.0694874141897474, 0.045609648139881234, 0.022729566054684774, 0.07427401734249932, 0.022966966797996844, 0.030544145298855643, 0.02267510344141296, 0.03541961279032486, 0.05150492323030319, 0.01653776946477592, 0.05004185923774328, 0.00802390814559268, 0.043157307231532674, 0.0438132979241865, 0.0192549222348524, 0.019244408334738443, 0.018218711051823835, 0.043696294738245864, 0.031131922866084745, 0.017737846854808073, 0.03928228873493416, 0.015577226810689484, 0.054308266911123476, 0.03638833688039865, 0.03579307507191386, 0.05485912199531283, 0.07937777454831771, 0.05390712379344872, 0.04448460654488631, 0.07009207031556539, 0.06522989193243639, 0.08077527170202561, 0.0438480898072677, 0.0799781559035182, 0.039368011456515105, 0.013235151235546385, 0.058785756650779925, 0.042910422264997444, 0.01090008407897715, 0.03363689434315477, 0.026816837090466703, 0.07284228131175041, 0.04544950030477984, 0.09374329048608031, 0.021368397665875297, 0.08898344196911369, 0.05913004531924214, 0.014903677328090583, 0.009952400511662875, 0.03571722503485424, 0.022212183102965355, 0.04793018701353243, 0.025169058902455226, 0.05728691350668669, 0.03911949122058494, 0.02956922957673669, 0.051899213144289594, 0.052793104999831746, 0.04344012062730534, 0.015806429154638733, 0.01632155937009624, 0.03775735252669879, 0.047989911665873866, 0.06629066608314003, 0.1076945336535573, 0.03032902255654335, 0.06309315801731177, 0.0439549726434052, 0.09136558164443288, 0.02625620092398354, 0.06960763702435152, 0.038778035435825586, 0.022870321358953203, 0.03728802342500005, 0.03315506662641253, 0.04777621045442564, 0.038580140697636774, 0.04533119433160339, 0.012441232185145574, 0.00499160257667037, 0.03974326167787824, 0.004295545239334128, 0.02369342335233731, 0.04221637254314763, 0.024741619160132747, 0.02026832276689155, 0.020421737838270407, 0.06288074262972389, 0.014765972038730979, 0.015333383377375347, 0.06272837759128638, 0.03597884438931942, 0.07018388967428889, 0.019735672777252536, 0.04654014017432928, 0.06572807912847825, 0.05310596053355506, 0.046571464743465185, 0.01799953236643757, 0.04969361471012235, 0.025576904249776686, 0.022518952177571397, 0.04657121029283319, 0.08094884774514607, 0.044811511146170754, 0.01757533771784178, 0.06235390089984451, 0.050180253240146806, 0.0567036956947829, 0.027086673504007713, 0.027927296967910867, 0.023739421241251484, 0.05957219909344401, 0.03729958566171782, 0.019058377781350697, 0.06456638646445104, 0.014066108968108892, 0.01631252806899803, 0.0335070532746613, 0.0359653517204736, 0.045574160758405924, 0.04328631030927811, 0.012505040770130498, 0.04510624300954597, 0.08239356415080172, 0.010476319451949425, 0.04284634481051138, 0.03456247039139271, 0.058567499076681476, 0.01793772291525134, 0.12246261084718363, 0.03224842170519488, 0.018593001146135584, 0.06372593263430254, 0.025797446790550436, 0.03128462377935648, 0.05920758830117328, 0.020177059806883335, 0.03852807670565588, 0.018671368548114384, 0.018280703707465103, 0.02135345971743975, 0.01904638297855854, 0.03616745676845312, 0.056935391654925685, 0.025959579340581383, 0.015259339939802885, 0.03716099827683397, 0.05824567670268672, 0.04659232969528862, 0.02741252807235079, 0.020511728545118655, 0.07845873279230935, 0.008306804661905127, 0.03467138543991106, 0.06298844649323396, 0.026746104903785244, 0.09093970592532839, 0.011738508241251111, 0.025087570239390646, 0.01122350779561592, 0.0443603633902967, 0.019011618236878088, 0.05746808235666581, 0.06734492629766464, 0.013759781789433743, 0.06315700816256659, 0.01680958380789629, 0.021072347748226354, 0.027981332104120935, 0.0720100716820785, 0.10814704187214375, 0.013087134758409644, 0.022133781774235622, 0.01374090664155249, 0.018855031014287045, 0.03870859416201711, 0.05423823870452387, 0.006127056715610836, 0.01599428496722664, 0.01780510154951896, 0.008830712575997626, 0.006136827195794987, 0.02419334420535181, 0.033494843037000725, 0.05887748779995101, 0.06067607378853219, 0.029098031111061573, 0.012809456176390606, 0.04318266408517957, 0.028115624362336736, 0.016562868475115726, 0.010690101239431118, 0.0364586941764823, 0.039385171607136726, 0.038468006000454934, 0.03486456775239535, 0.06362784361200673, 0.06255264380680663, 0.040447760839015245, 0.02884667120607836, 0.04833434282668999, 0.07904983857380492, 0.04115772220705237, 0.012087283722524132, 0.051605991021330865, 0.14640480040439538, 0.09406438682760511, 0.010011930085186447, 0.016086360472919684, 0.037744884445731125, 0.041908409246908765, 0.026739451867927398, 0.02112913434393704, 0.04488335782662034, 0.04511722849149789, 0.02836401228393827, 0.034443726763129234, 0.025519452689747726, 0.0344023768390928, 0.01968958498244839, 0.025789107595171248, 0.09648602402635983, 0.0735178714884179, 0.02939909031348569, 0.02465422384973083, 0.020616538456774185, 0.022437616184886013, 0.0295807205672775, 0.012121789772728724, 0.038503720691161494, 0.0212446464491742, 0.028301388590729663, 0.06241292666111674, 0.04769353096240333, 0.01890682359226048, 0.056891375088265965, 0.007096797760043825, 0.07339735688375575, 0.08698267968637602, 0.033675577624567916, 0.023897363837542276, 0.08172091881611518, 0.015041212983695524, 0.06807515889938388, 0.08440738823264837, 0.026922408657680665, 0.039702430833131075, 0.0682752588763833, 0.052315626692559035, 0.022620876619060124, 0.020803778498832668, 0.03305840252765587, 0.05892334998186145, 0.09921410799558673, 0.05232342305992331, 0.028771648981741497, 0.024643625132739544, 0.012422748891237591, 0.020288475256945406, 0.020317940640130212, 0.013098372146487236, 0.03644742710249765, 0.017609978626881326, 0.031729464552232196, 0.03461615608206817, 0.030184073905859674, 0.04871355229988694, 0.016708751807787588, 0.06670058265860591, 0.04423667663442237, 0.02221263263241521, 0.0397684828245214, 0.021410012218569006, 0.06116155880902495, 0.027083574295310036, 0.017770804997001375, 0.0321067876980773, 0.03177297221762793, 0.03131219944251435, 0.03672972820433123, 0.07123386154749564, 0.02672274803210582, 0.0252833598226841, 0.048344059448157034, 0.04730104595156653, 0.010664062458090484, 0.020836015697568655, 0.048842657157885175, 0.03862403512799314, 0.027494829281100204, 0.02242400137973683, 0.013008721555317087, 0.009082362554701311, 0.08150664424257618, 0.04157798304887755, 0.05915088312966483, 0.03253589663654566, 0.05099060386419296, 0.006683488933569086, 0.029727833744670664, 0.09063394447522503, 0.0429397146217525, 0.02929803609315838, 0.036912121810019016, 0.01196921693294176, 0.08043718484363385, 0.04295851004176906, 0.047731932651783736, 0.057556373333292346, 0.03704606123002512, 0.0554998252939965, 0.05258760727675898, 0.019364281723807966, 0.031917191443166563, 0.011955842159555426, 0.013973856195142227, 0.04757048881479672, 0.026766613624723892, 0.02809958888350853, 0.01981436417970274, 0.0659240468272141, 0.03602772605206285, 0.05529874483389514, 0.06089678087404796, 0.07071750996900455, 0.012314109497570565, 0.03978326470990266, 0.03467441170609423, 0.08901730765189443, 0.060592125436025004, 0.026032206336302415, 0.023857099569535682, 0.00959223582010184, 0.01286368299874344, 0.05775887532425778, 0.0487537860338177, 0.0403895493197654, 0.0390549489696111, 0.13936185118343147, 0.18727107825023787, 0.06955340172031096, 0.1735059775944267, 0.09073966701648065, 0.10515971681369202, 0.09492426032998733, 0.10715371410229377, 0.1852092138890709, 0.10352478668625865, 0.0835674704451646, 0.12282076877142702, 0.07241276185959578, 0.17897825395422323, 0.08752517521913562, 0.11327061908585684, 0.21027927792498044, 0.06165085719632251, 0.09393298852124385, 0.11876608777259078, 0.1749988089182547, 0.10174752026796341, 0.16097575638975414, 0.20145235157438687, 0.07497222309133836, 0.1228269027279956, 0.16269235499203205, 0.14095005738948072, 0.07827661399330411, 0.08161134898130383, 0.1983524372002908, 0.12338042445480824, 0.18273660513971532, 0.15053475807820046, 0.15214672658060277, 0.14813255412237986, 0.09464590490928718, 0.07536360887544495, 0.10969499059553657, 0.1789148109299796, 0.13347220793366432, 0.14534722215362958, 0.1470046525022813, 0.22978528695447104, 0.18259658265326703, 0.10241903244916882, 0.151322890073061, 0.11701871082186699, 0.13741278648376465, 0.12354708622608866, 0.14085435681045055, 0.12119261042347976, 0.15303948867533887, 0.14160238738570893, 0.17977412124829634, 0.1177043297461101, 0.12784787187618868, 0.12706096124436173, 0.14890953100153378, 0.14733959095818655, 0.11324876347290617, 0.09804366901516914, 0.16197012231818267, 0.07343118863978557, 0.09851912528808628, 0.09377669476504837, 0.12161579914391041, 0.13355983394597257, 0.13195363299122878, 0.11784964480570384, 0.1290605225201164, 0.11982937928821359, 0.08808833892856326, 0.12716453282960824, 0.1234121663229806, 0.1374673678406647, 0.14519592241517135, 0.23856726714542933, 0.08059683734817163, 0.17249201557465962, 0.1212617667125804, 0.22137139844042913, 0.16518172355634825, 0.12336469601307597, 0.24692399586950028, 0.10373861342668533, 0.08113060692059142, 0.0936173340305686, 0.17376429587602615, 0.11111627718699829, 0.1847430874726602, 0.1647503109914916, 0.16526556334325246, 0.1388370722000088, 0.1805132765855108, 0.07446077732103211, 0.08709068889064447, 0.11611703277698585, 0.11507199385336467, 0.12985416421932833, 0.09189433005771466, 0.1709294579923153, 0.09907240952764239, 0.08898290592644896, 0.07621956044541937, 0.13822829058127745, 0.08887902221509389, 0.1617610113961356, 0.13062435574829578, 0.09438749163278512, 0.10275919562471764, 0.2213517887783902, 0.09103016821401459, 0.1029156454439674, 0.18185227044991084, 0.11169864343745367, 0.17409476957150868, 0.1758174749889544, 0.14968246381197656, 0.11827457057578222, 0.08282470530165092, 0.11043934351099388, 0.11099854457591261, 0.13802882842719555, 0.11656790572617735, 0.10681486049933092, 0.10631788109562226, 0.13872298332197325, 0.15535512513348035, 0.13531649325575146, 0.08253874350339174, 0.18158253920929773, 0.17262105936450617, 0.17219242879322597, 0.10159689906452384, 0.19100312941840716, 0.08016699898455824, 0.16668950979198727, 0.16737544084233896, 0.1008076746282833, 0.0626728937828115, 0.1513674155409847, 0.12456186248787812, 0.1841935555317572, 0.12736680411866733, 0.08367564249783754, 0.16086776075618608, 0.14813796883182867, 0.09868996004973139, 0.18495663601372922, 0.11330862383225135, 0.11616856072630201, 0.07549221161752939, 0.1411075046552079, 0.0864501857597913, 0.11824472860566207, 0.1394512549574886, 0.14782641269266605, 0.13404748349317483, 0.12351481510060174, 0.13872420468500682, 0.19913580587932042, 0.2072934117168188, 0.07669091836682387, 0.13179200594978674, 0.09544604697397777, 0.13269133626350335, 0.16803075639264925, 0.1704670363771064, 0.17762106178062304, 0.19080093955355032, 0.07545654781694923, 0.11837953994316713, 0.15014816953667573, 0.0723972369783691, 0.13811399814273628], [0.040351195127836297, 0.03712795701410089, 0.029276099056005478, 0.015890938994873847, 0.03814519975068314, 0.04692942589255316, 0.04157405433111957, 0.02644011953712574, 0.058262863994709084, 0.02271279097268624, 0.03357207389282329, 0.07854142585503203, 0.030440003744193485, 0.004340570278665317, 0.018273886126865233, 0.02774289998758052, 0.07513888486261878, 0.033956056859876425, 0.048339146854622025, 0.01908709168700235, 0.02172018075361848, 0.008473505448949124, 0.01669415651953646, 0.049409837794623206, 0.037885001927082024, 0.017451722208144407, 0.010692281033178526, 0.03326538624241948, 0.028668498088206564, 0.0244124872676496, 0.0877429646040712, 0.025873023717265044, 0.03729534481785127, 0.06462665394480739, 0.02843868506274053, 0.02098026206450803, 0.06047171261161566, 0.010944110823662152, 0.023079535757590617, 0.01640921422014279, 0.030477163714489768, 0.01305778557434678, 0.012223131522270185, 0.05650917327563677, 0.09887870813586883, 0.029966579683657204, 0.03251694515347481, 0.026328692212700844, 0.07227632882339613, 0.015751360948862772, 0.028907006539936577, 0.05961187303598438, 0.0506502099867378, 0.01804258710970836, 0.02609334573415773, 0.12412929641348974, 0.044066927528807094, 0.04416510136798024, 0.015255278907716274, 0.01758586009964347, 0.013815952614615006, 0.037246724391090016, 0.04781913797238043, 0.05375191908595817, 0.049246351567230055, 0.07276790708835636, 0.03700116256784115, 0.02542977750168315, 0.011628474458120763, 0.03000610095581838, 0.04165573637666447, 0.0676043505913445, 0.040927888825535774, 0.03950053613100733, 0.05041336055312838, 0.02504820333394621, 0.04972937011293002, 0.04339928299720798, 0.01124445247530405, 0.030439026653766632, 0.05253313109278679, 0.0300202993010836, 0.02984228903161628, 0.06717740278691053, 0.028605567357902015, 0.02485348583598222, 0.019128334741773348, 0.036495090794882605, 0.016984885026301657, 0.07755036439214434, 0.019911962960447584, 0.023483661036672335, 0.02546910708770156, 0.07712510613990681, 0.010556977757784938, 0.039257505243378024, 0.009681073865587158, 0.08741964266768523, 0.017023727763444185, 0.09466824906745128, 0.06734276855630533, 0.04552380667467203, 0.02222555872452046, 0.08706114547593252, 0.024175892284672176, 0.03653463242309434, 0.016795052980471934, 0.01703420264779457, 0.03978194835196648, 0.027781172755307386, 0.052998175245842764, 0.0149201097499047, 0.07756176378045763, 0.052645180973091295, 0.03107767059866871, 0.018148613295384815, 0.05411588866263628, 0.01738240646331438, 0.015293020721791046, 0.02193047571927309, 0.015884640493563244, 0.058641282974609306, 0.06969095433929137, 0.027385218734187738, 0.047549304951514514, 0.024562141558687602, 0.05533894124839987, 0.049898569605180194, 0.017322605475783348, 0.01693451397919229, 0.06857273541390896, 0.024345724510827234, 0.028981183988175223, 0.021659387408622673, 0.06893330892281872, 0.052834967217807255, 0.038003949115851095, 0.02748125179537705, 0.05948839323329074, 0.06258078943938017, 0.026884173209379827, 0.042613858357071877, 0.03027164563536644, 0.04129640458683882, 0.011392332397268286, 0.027591853003416742, 0.02664639418279486, 0.04244106262922287, 0.024252490406589847, 0.019130484001444917, 0.04633666787828718, 0.03567591582291892, 0.06843274006886141, 0.02093625228319849, 0.014955011894926429, 0.03414478798263839, 0.024420616117173007, 0.042651642579585314, 0.041448128409683704, 0.02597911436376827, 0.055458634825689454, 0.05111444668312158, 0.03591643613097923, 0.0315208184266729, 0.02895609854853579, 0.016109654580109885, 0.0877901092171669, 0.02657313275683139, 0.0338957758088197, 0.017815138778782318, 0.009987967621002878, 0.029624313049550568, 0.05477757226409657, 0.1266677773424557, 0.03286790382117033, 0.03423593559169343, 0.0092858161910304, 0.01206283356129591, 0.014121887939316886, 0.03266096081850784, 0.061688169836997986, 0.05108449954007353, 0.054833554795810154, 0.027803291300577775, 0.024793286209127734, 0.051004473119974136, 0.006485334655735642, 0.053477092047355006, 0.08365633817655699, 0.02855175274557301, 0.03659224683152778, 0.04885068761983088, 0.04730693902820349, 0.00919517154605793, 0.028594279927866798, 0.05179577726604683, 0.06377727737916367, 0.03170050807031138, 0.09096996180180993, 0.014329445016171252, 0.03837940289771982, 0.04188978685332196, 0.03426956378721765, 0.028376134312046424, 0.08025180229118892, 0.026696782193279693, 0.09401927103421517, 0.04311167914420366, 0.07438214189772095, 0.03973231012267726, 0.02031066844106785, 0.02113394346088171, 0.019601409356775026, 0.06818419947688069, 0.048146921276514015, 0.058986847288906574, 0.013141772942617536, 0.06507106045527117, 0.023597500553088527, 0.027208580801795636, 0.031064971815794706, 0.025956810917705297, 0.04236432710396392, 0.05764282548001834, 0.031411173953009505, 0.06349375152162143, 0.030000916948275905, 0.00875041474189077, 0.023508295250524367, 0.015218375084389533, 0.027739868632384708, 0.10870528620268617, 0.016193278932145665, 0.005210090004506388, 0.045700310596397946, 0.0322237637426172, 0.00816465581634215, 0.03273330622219613, 0.005801442603114992, 0.006604617295254554, 0.023263958182984164, 0.04935585015586444, 0.03416753926181367, 0.029103676522416726, 0.0642436480681811, 0.03622512885236314, 0.027389047368030463, 0.020292405671040927, 0.05706081885312285, 0.08345174629773412, 0.021818444498681595, 0.07413525014583554, 0.06464449263044766, 0.03929051597203527, 0.012975833811131971, 0.04698337960456099, 0.0021024990668852945, 0.032420501578599215, 0.09231726093483822, 0.06702629982360772, 0.05115306889638305, 0.03315616585314274, 0.0382544099619346, 0.07381183999989714, 0.02628093522175082, 0.042525838794452805, 0.03177521816853966, 0.10212271620652505, 0.014836997691808003, 0.035674741957336664, 0.03457355426092233, 0.01079585261842502, 0.011140350784574236, 0.04957709328404494, 0.012434109263787312, 0.027876966632902622, 0.07424859263535057, 0.04866455528619034, 0.0663411830152784, 0.05791817499058587, 0.05348205213834133, 0.03077178361958691, 0.015994585218972394, 0.04311122452574117, 0.034547610474484305, 0.03637265254344259, 0.05252588773146272, 0.04211691627278924, 0.09461909599070038, 0.0208645073830017, 0.03199552491839443, 0.011781354335003665, 0.04369630830894623, 0.059570597750799995, 0.04640115923913462, 0.047666328493505716, 0.032046852699880085, 0.048150181637278626, 0.0599281924909779, 0.060046834338988574, 0.06678629520216159, 0.020071201558623995, 0.03468455919729812, 0.03816738445311785, 0.00913285743445158, 0.03235679053302322, 0.03538751469126769, 0.012685761786997318, 0.03382279936756406, 0.03228656215859311, 0.053084118491304774, 0.027207466308027506, 0.05141372133844665, 0.016416552576369474, 0.025658138462209275, 0.011126356847983385, 0.04182133624064071, 0.06692006159573793, 0.026642762324107543, 0.040025732413466485, 0.06746198037373168, 0.03574282616110785, 0.025959129811131527, 0.019188873636137162, 0.053295868914574385, 0.02495145102563713, 0.024067884776741266, 0.03956572977559907, 0.03129301047218697, 0.04149896086060575, 0.06063772298927818, 0.02295314334332943, 0.013859227881766856, 0.04332958048741732, 0.030459481091903787, 0.01313390363273876, 0.042289691644587686, 0.06299149311546769, 0.02733944306549217, 0.06112126061426742, 0.042764859540121894, 0.039545675673122914, 0.04101954872852989, 0.024293453565665653, 0.00991193437948823, 0.023749075098229305, 0.020993461266958287, 0.07353364064225129, 0.057740568449454646, 0.060804479755461216, 0.012291920554291989, 0.012640771522585834, 0.11166182612734181, 0.2009743507951498, 0.15200498061520712, 0.1294124922049897, 0.21656871400773525, 0.19659728423825332, 0.14881216122635774, 0.1344854235649109, 0.13927563652396202, 0.12901602419359343, 0.14840079258595193, 0.15146994218230247, 0.22605468785124166, 0.06545807647385768, 0.12386025727859565, 0.121970035135746, 0.19237915772412503, 0.09934904825474535, 0.11307513314698424, 0.11736217167760644, 0.13319794407912663, 0.18557286794696534, 0.2139175555535725, 0.1438009494117328, 0.1304708711270775, 0.16967157620404447, 0.0861387246155313, 0.1341015084513596, 0.12980692461133003, 0.07553542751286711, 0.1723620489771877, 0.08348115400544234, 0.14926558546721935, 0.1441120577177831, 0.13863276530589375, 0.15239236982805388, 0.13235139021916048, 0.11656604654022626, 0.18000770014311585, 0.15921403520873614, 0.1304477195122412, 0.11204831288861376, 0.12099137050764901, 0.10986211377062968, 0.20383931563368865, 0.1625928274754967, 0.13639110273548535, 0.18764159908252104, 0.14367491831736906, 0.1072647427873952, 0.09015419307563986, 0.14881236478686333, 0.22361213820321219, 0.0960730676140104, 0.10448610795927898, 0.2841223441064358, 0.16684690277491296, 0.10056005684392792, 0.15115132927894592, 0.12178940911378179, 0.08827496320009232, 0.0985231286446963, 0.16606714390218258, 0.08134451508522034, 0.13388133740850858, 0.15193730353244714, 0.16259993852249213, 0.1166977501873459, 0.1560034653437989, 0.10914059355854988, 0.13644345849752426, 0.12676497069852694, 0.16165323289377348, 0.29675028792449404, 0.1783272810280323, 0.15805217969630445, 0.1631589699536562, 0.15818898592676434, 0.13190574198961258, 0.10950829168515545, 0.12615765471543583, 0.14993654803505965, 0.15679959048117909, 0.13753752836159297, 0.11866827016430241, 0.09411272566233363, 0.14343289844691753, 0.16583252006343432, 0.1528335940092802, 0.19698733330837317, 0.06980933155864477, 0.22076628091079847, 0.10145638124751193, 0.17582092194684915, 0.09399160716150488, 0.16513087414205074, 0.06233688324157681, 0.2218321237180914, 0.09255807979830674, 0.15923992810504778, 0.17041093510176453, 0.1585481752242361, 0.13817011298877852, 0.19690289641065256, 0.08570591426853623, 0.10803152128521885, 0.12057044809418065, 0.10827594316963639, 0.18052086260701927, 0.12914105105612958, 0.13165856525301933, 0.06012969703546592, 0.2285905767764364, 0.12739424407482147, 0.09214571371142354, 0.044272262403475385, 0.16519256654594625, 0.12889612705579825, 0.08536617857004915, 0.062331278542322774, 0.14311851960207733, 0.15540613739618234, 0.1650932833020176, 0.14004680514335632, 0.17347920260259084, 0.10195006297102996, 0.10367857664823532, 0.09991717884050948, 0.14876181392797402, 0.10921831974493605, 0.17956203834286757, 0.1348050678414958, 0.10000953424189772, 0.15764547937682696, 0.21884089708328247, 0.163447537326387, 0.1461187300405332, 0.09323343248771769, 0.18500261354659284, 0.1715617033519915, 0.19216224364936352, 0.20787537763161318, 0.16774570383131504, 0.13945095640208038, 0.1619809517370803, 0.12117252578692776, 0.11797255463898182, 0.12345518544316292, 0.14603841863572598, 0.16024114723716462, 0.15656613372266293, 0.12338555417954922, 0.09228406700172595, 0.11486752411084515, 0.20463924056717328, 0.09053457980709416, 0.05934925962771688, 0.11366105492093734, 0.09268856886774302, 0.07529300730675459, 0.23037406536085264, 0.27955322499786106, 0.12771569325455598, 0.1312717052974871, 0.11255756699080978, 0.08914425476853337, 0.24035672683800968, 0.09573566607598748, 0.126693330971258, 0.17040524897830828, 0.10019066237977572, 0.17580645558025154, 0.11556066120309488, 0.19116593711078167, 0.13644792325794697, 0.09953274125499384], [0.055361621281398196, 0.06560185125895909, 0.07249514958156006, 0.02138743396582348, 0.06359268871269055, 0.04139558605051466, 0.058193666993507316, 0.03660780903218048, 0.024898715283987776, 0.05042150975870235, 0.03710416418367198, 0.012302684664194073, 0.07374769129923411, 0.04510081812207188, 0.029082923528871367, 0.08012955063687903, 0.041394907515496016, 0.007117860335191446, 0.02028781877431486, 0.030261216552129815, 0.044573419993477206, 0.014914225154955472, 0.030623432115784714, 0.0605020634829998, 0.051091122041855536, 0.023937190450461845, 0.05732727276959589, 0.012581375111559672, 0.03022450102227075, 0.03478463293452348, 0.0124409930015515, 0.017429871684206382, 0.047648947819003036, 0.03455546112465007, 0.028146770816030245, 0.013166260423271783, 0.021994566744459525, 0.061999590269156864, 0.03294999638040151, 0.05696369335055351, 0.02622398577763566, 0.054288419761828015, 0.07532449811697006, 0.003647254222804414, 0.019133087879578983, 0.026036358970616545, 0.02848084583612425, 0.034029579521822076, 0.05610248652685966, 0.0658667649009398, 0.03424795583954879, 0.0478423506553684, 0.06141944282821246, 0.024246466711961796, 0.03765160284404244, 0.04514221215088453, 0.0747766625136137, 0.012696053466892667, 0.05792021059564181, 0.03158905190814819, 0.012168020059886788, 0.04579851836232202, 0.06850188957261187, 0.028943973127752542, 0.01475989745397653, 0.04646531133247273, 0.04207031109503337, 0.051128444860556295, 0.06123157683759928, 0.028157118475064635, 0.07913036710981812, 0.053144148484404595, 0.018662337247016172, 0.040757128702742715, 0.07625192656580891, 0.006018732840727482, 0.031511464821440835, 0.040008429770490954, 0.10414771576012884, 0.03908304371205824, 0.02359004514957113, 0.04552900425291487, 0.031694910156407526, 0.0702656124319349, 0.0431406763382256, 0.03981899975665978, 0.013134800147132149, 0.027586587571672032, 0.014317267008924058, 0.09817687222468001, 0.02621334295586816, 0.06749574427625962, 0.02242564513081951, 0.048021897806652954, 0.029621188395789692, 0.024698837527206967, 0.028838515215154206, 0.06865268040980611, 0.04656958180878844, 0.03495288247774754, 0.014116548716888895, 0.036077309998550584, 0.03339107806927391, 0.07227930080677782, 0.021195130356188332, 0.03148130393986191, 0.09463434267256941, 0.018344628491571972, 0.060373603233269284, 0.06737869020019259, 0.041207302760865004, 0.016234791704586575, 0.00941943924408406, 0.039880020410886834, 0.05084023032603519, 0.02492585838107126, 0.03401694180709975, 0.06109535414725542, 0.03396911187363522, 0.046991091155047925, 0.03289428526269538, 0.015842535699318563, 0.07501284019755465, 0.0208715115607317, 0.04341290119503226, 0.040323412511497736, 0.02630625305963414, 0.010500634754342692, 0.027036383881100585, 0.03965194782774363, 0.055970341831977875, 0.060166025800364356, 0.036968033095555644, 0.06066595683140414, 0.026865662774071097, 0.01031208089885435, 0.014719818086762513, 0.029645649583211968, 0.08105453635965075, 0.1079696931743196, 0.026285194725330387, 0.07355008154575314, 0.025856472551822662, 0.05040785424145205, 0.060847600655896325, 0.03072464239916631, 0.047028152737766504, 0.06223217850284917, 0.004954887894980077, 0.035475337478731356, 0.02221456476088081, 0.007111838760985327, 0.027401793648355773, 0.042777358155165396, 0.04811384269435491, 0.03452507632651499, 0.023255144013091922, 0.027180411420496445, 0.05478101582931621, 0.056233050235147984, 0.06327153808836426, 0.10143001337668725, 0.03189449105411768, 0.02330782886461488, 0.04647766066981213, 0.05635146477392741, 0.013893000265982534, 0.04430907292823706, 0.01907013848956142, 0.027867314472262348, 0.008347431946146702, 0.028431423041703444, 0.013570447618673955, 0.053591482873473845, 0.028065658739901016, 0.045218737330287695, 0.09679231473377772, 0.07460588203477007, 0.047794174669044356, 0.008724353059993258, 0.022335489879229238, 0.04743633565625974, 0.012624985405376979, 0.03706995244803173, 0.01972098758311144, 0.023657023341261914, 0.002716842552347641, 0.023572443951187388, 0.06133286175983293, 0.02016512946491795, 0.014585951609270913, 0.028901761464242424, 0.027026005687990358, 0.08282910220857177, 0.020386336970009973, 0.016825831328917826, 0.06190260047359126, 0.04550856338547809, 0.036542340580906184, 0.11371689835297209, 0.05336602604282754, 0.0712979423946568, 0.022935392867241586, 0.008961384001720165, 0.07554612122476101, 0.02670745724546058, 0.03421755407803825, 0.020880712495584573, 0.029950332162635665, 0.06865094336015837, 0.04908292640798858, 0.03794480461095061, 0.05520452685388071, 0.08949002264333622, 0.031090169213712215, 0.01557075697928667, 0.07325366352285657, 0.08228334292237248, 0.024206100663702403, 0.028304827066936662, 0.006480911879667214, 0.060006746490086825, 0.062482042238116264, 0.014300369790622165, 0.0393453246381666, 0.07342905125447682, 0.04652982644204583, 0.04431352751063449, 0.06465188187680074, 0.01876038725354842, 0.029508826389376606, 0.037777532158153396, 0.05513551984248417, 0.032381400998149595, 0.07070467208645173, 0.008680719865619071, 0.007577922344872994, 0.02631313679739833, 0.05190710111388138, 0.027010346796097498, 0.05684831864865763, 0.023037531047261188, 0.05720664281398058, 0.04476293143151062, 0.03310144539656384, 0.04482302249276212, 0.02640747182470347, 0.04121046134137681, 0.02280987237047936, 0.010469965819668556, 0.06474782672843762, 0.06740748722638402, 0.04983306722715497, 0.03877437134672489, 0.05292605375871062, 0.048070633584367375, 0.008537202075655972, 0.03465845934780581, 0.055963736293571334, 0.04021937952243856, 0.05885012248264892, 0.04108268980469022, 0.03413280505420906, 0.027169081582022563, 0.03390264258320842, 0.05612482389967356, 0.00686123499846352, 0.08491121405469519, 0.05972998562668051, 0.06654733552464417, 0.012072550182762955, 0.013502260786481202, 0.016867512038775852, 0.04402103481282081, 0.11518731766513415, 0.043497453443706036, 0.006798698666638562, 0.057152977479355674, 0.05502286945868816, 0.02179857699333557, 0.058893569079892974, 0.051965064967849424, 0.01653885342446821, 0.03471311195088284, 0.06348888642553772, 0.058722788601049354, 0.026450555405712554, 0.028891552904886857, 0.02511178545786866, 0.018144898316157714, 0.03657982624801142, 0.026789758454209993, 0.022178571870816604, 0.05914293748459645, 0.031475169983293326, 0.014904723968356848, 0.05904672121895211, 0.017051364494753734, 0.0486829978679972, 0.033562207993652136, 0.041487374875162325, 0.018977718627346412, 0.03850716764905623, 0.008129729074425995, 0.04753167321905494, 0.04977494052478245, 0.01307860218055014, 0.07375062257051468, 0.02708375919610262, 0.025494377428133572, 0.014381118850516421, 0.02879145202626075, 0.06382111752671854, 0.049612400853740315, 0.04441890399903059, 0.023569151360009397, 0.10443476999976806, 0.031143807406936373, 0.018357770018545643, 0.035128371989620585, 0.029460280601467406, 0.05535001493990421, 0.0294468286447227, 0.01599485324030476, 0.0580715306901506, 0.011426176027660924, 0.05191314007554736, 0.0344580506373729, 0.07940117722111088, 0.02674363842899246, 0.04757194427241172, 0.042146765028259585, 0.030080403933035474, 0.022029974398070147, 0.016007367122386183, 0.017065764704187, 0.021175731040005173, 0.030039474700710604, 0.07080613342779023, 0.04725079025541033, 0.019041254950155104, 0.06416746215628726, 0.04040960681491664, 0.023108775527881723, 0.044265008864126036, 0.05064375711871045, 0.01606254219742758, 0.013309520369927798, 0.04987001345892038, 0.04447443869763187, 0.03353995204504047, 0.021349240925961306, 0.22370021204863275, 0.15934101625212602, 0.18175510423524038, 0.10936046604599271, 0.09329874826861279, 0.14053026134414331, 0.06998737914753811, 0.13008825880076202, 0.10380329817001309, 0.10392149218491145, 0.17750207387975284, 0.07236139675868408, 0.12469414967511382, 0.2087599973061255, 0.08122147633028881, 0.16939409609351838, 0.09888134763709136, 0.12154485152236053, 0.10856383879269872, 0.07036771159619093, 0.22973958083561488, 0.08370459558708326, 0.07758170592465571, 0.19755986758640834, 0.18651320891720907, 0.15489818608122213, 0.15519041754305363, 0.0955992533958384, 0.13554070836731366, 0.1299822444894484, 0.13978233933448792, 0.06959009010876928, 0.12219477950462274, 0.14535522886684962, 0.09540619661233254, 0.0578901447089655, 0.11472538459513869, 0.17249125561543874, 0.08850122748741082, 0.10570688066737992, 0.172690622774618, 0.2089627299989973, 0.09754638427070209, 0.11919737820114408, 0.109602804827903, 0.23145499878696033, 0.17421477527490684, 0.1383975443563291, 0.1272512496049915, 0.16896824751581463, 0.08852440624364785, 0.14697681899581636, 0.17014828776674612, 0.09478887902306658, 0.11200993494795901, 0.1423497258552483, 0.11248816642910242, 0.14060157537460327, 0.1647610996982881, 0.10803633888385125, 0.059098961630037854, 0.1923250649124384, 0.11019318457692862, 0.10313185384230954, 0.13536986682031835, 0.13878163588898523, 0.14936457015573978, 0.12738171831837722, 0.16782372178775923, 0.12662591173180512, 0.1317395551928452, 0.15159765604351247, 0.14565478850688252, 0.12274665917669024, 0.12599529485617364, 0.1253084817102977, 0.10691560259354965, 0.17436131169753416, 0.2578786723315716, 0.12604310443358763, 0.09907344090087072, 0.207357275432774, 0.12045531427221638, 0.14202116562851838, 0.11502741410263947, 0.10756386816501617, 0.09940057620406151, 0.10037232656031847, 0.10138016140886716, 0.12604584571506294, 0.09280446943427835, 0.19841402103858335, 0.16561808942684106, 0.20601486175187997, 0.18038734048604965, 0.15392382336514338, 0.07902220184249537, 0.12815353833138943, 0.19118019991687366, 0.13162747477846487, 0.10776244143822364, 0.13440940050142153, 0.1301365297819887, 0.14307258278131485, 0.11098953363086496, 0.16611935038651737, 0.1974030038607972, 0.09765922464430332, 0.22259523134146417, 0.23135500986661228, 0.1481930251632418, 0.07353682975683894, 0.10676297292645488, 0.13742649289114134, 0.17407852544316224, 0.08502004428633622, 0.0874573624293719, 0.1091531328856945, 0.18302350331630024, 0.15475221962801047, 0.11759375567947115, 0.0791663226804563, 0.16377236561051436, 0.11708865421158926, 0.13129457192761557, 0.11759914324751922, 0.12333509831556252, 0.08760189038834401, 0.09296385731015887, 0.12284345898245062, 0.12837467289396695, 0.16363357805780002, 0.1248228270560503, 0.10498526546039752, 0.14926213850932463, 0.11181384511291981, 0.12742542954427855, 0.1244362113731248, 0.1928485275379249, 0.16538725181349687, 0.23260579417858804, 0.21668352213289055, 0.1109304196600403, 0.1079039363456624, 0.10042736253568105, 0.14097282902470656, 0.17032482900789805, 0.18612706820879663, 0.10521810475204672, 0.08845027629286051, 0.13838663351322922, 0.08694316180688993, 0.13976479241890566, 0.060641760272639136, 0.13345365678625448, 0.17922374792397022, 0.07888552453368902, 0.08721168525516987, 0.09129638464323112, 0.14425772561558656, 0.14278758450278214, 0.16051302264843667, 0.15921384521893092, 0.08331046852150134, 0.1319327341126544, 0.18222854525915214, 0.11530496206666742, 0.09221989115966217, 0.08451052555548293, 0.17573970130511693, 0.12488996131079537, 0.08982990083417722, 0.18352202299450124, 0.10179601516574621, 0.0962171002424189, 0.12052369703139577], [0.033121645384069, 0.05614589580467769, 0.011069297990096467, 0.03233833438051598, 0.03186741072152342, 0.03114024509808847, 0.027701494084405046, 0.06542947622282164, 0.02868705941364169, 0.1101461010319846, 0.03839137904079897, 0.010988017128381346, 0.015532307792454958, 0.027415659511461854, 0.04138861071052296, 0.05455726890691689, 0.05376785108819604, 0.00809084138433848, 0.044797797953443866, 0.03353901905938983, 0.05166148500783103, 0.04788153605269534, 0.031493707560002804, 0.07104723049061638, 0.02176697931385466, 0.03076438419520855, 0.02421737621937479, 0.04409853368997574, 0.04385370468454702, 0.03166571957990527, 0.04795584920793772, 0.04750389399539147, 0.04772348828347666, 0.03867489132764084, 0.041016546211072376, 0.016080496234021018, 0.027330148832074234, 0.05283239896276167, 0.04568309955564993, 0.023149148361491304, 0.030353385356387923, 0.0312176421949906, 0.04307964889864836, 0.060293312184512615, 0.01409131399954536, 0.040391432254442146, 0.026770274321149503, 0.03287493683663862, 0.01695374196528324, 0.021768248174339533, 0.022929018030741384, 0.02539955555195255, 0.014131802184108113, 0.005922239647978651, 0.06860540687505688, 0.0660857485075082, 0.044921640772372484, 0.03057647409981915, 0.11307024090949978, 0.023149747168645263, 0.021571486589631865, 0.07080814189144544, 0.07711285179747002, 0.11232751647808722, 0.0342984049181853, 0.031703944850180826, 0.03646104530032192, 0.0465429425239563, 0.0319536694857691, 0.006305489797211651, 0.015523135695340378, 0.07560765078025204, 0.014179184284460331, 0.059490754535155635, 0.019308199108179127, 0.028599698029990708, 0.018959318453978215, 0.016619381960481405, 0.05544408364221454, 0.02989408160958971, 0.022090394548805695, 0.07002638134041003, 0.0660149637343628, 0.020831242203712463, 0.02794550884781139, 0.03207938845402428, 0.05640257203153201, 0.024879326145829897, 0.07595920655876398, 0.040140618570148945, 0.04920513056484716, 0.055348389848534546, 0.00858043069352529, 0.03304910999057548, 0.03251086547970772, 0.03256778438974704, 0.0831846274169428, 0.017255958069914153, 0.002197340875032491, 0.026897397856893282, 0.02741917941187109, 0.09940121402697903, 0.016582471351804476, 0.062058873873736174, 0.017440085332574587, 0.015324323238538844, 0.018412364946146096, 0.02020226907916367, 0.021633560669475367, 0.013534943273823177, 0.03383138622822506, 0.031077602745166848, 0.05112660942333085, 0.04160799465275236, 0.028730170136051517, 0.02439418208918401, 0.011558794000718211, 0.022580122109502554, 0.01034463955355542, 0.02066002067710672, 0.02422549489087292, 0.024726711745773042, 0.015931668059368218, 0.03903164807707071, 0.007915448563705598, 0.03412035732929196, 0.04063696015094008, 0.023547249945944974, 0.005176885893368828, 0.008632935733268303, 0.018805603130853603, 0.04089622498889055, 0.04618869974677052, 0.04757295189691441, 0.031662153878382275, 0.08609176320689065, 0.032181192455547195, 0.03713290014171174, 0.03982448571228555, 0.06363460182079247, 0.020848344678857496, 0.04569593743820276, 0.01242449611891061, 0.08845241367816925, 0.019837793993896673, 0.017390708339267542, 0.023446757213345597, 0.014987177847485458, 0.04759870569354721, 0.027733478528846587, 0.07211200799793005, 0.03307424632034131, 0.06344541268689291, 0.025389816878097396, 0.05033346644735762, 0.02736963448114693, 0.060002946693982394, 0.030263815341251235, 0.0841842180650149, 0.06263469904661179, 0.07060366536357573, 0.020647165831178427, 0.032283932835395844, 0.029733373983097926, 0.04680104706702488, 0.012288378601494645, 0.07641432713717222, 0.036738980029310496, 0.014308585153360451, 0.025282896722533872, 0.038231020859841786, 0.0064748987871488285, 0.04571333846875599, 0.04824365662144763, 0.06186047701963356, 0.029269931172685962, 0.04470261645370296, 0.040934555432094, 0.030683438360158886, 0.06351644851799522, 0.011289383367901402, 0.0739521271150027, 0.014166548266075552, 0.058368600106665065, 0.0188691360609872, 0.0736985042957323, 0.04368928547150322, 0.017645554217909063, 0.059563805615263324, 0.07935006996350628, 0.015850447417636002, 0.04339924567778196, 0.028095790783741643, 0.0820755415729114, 0.12201867252588272, 0.017303379186029946, 0.02863460187134998, 0.018524416522788148, 0.041539662783699374, 0.02921026080314602, 0.010595314986338573, 0.007569564489780792, 0.005192378544182117, 0.023140173039532135, 0.03508839609899691, 0.044364136045000384, 0.048987850081175566, 0.017822970769235065, 0.040646191619868786, 0.02415082380840821, 0.05006285311122026, 0.05306006781756878, 0.046588166882949214, 0.06325770275933401, 0.03593484817871025, 0.02811768201978079, 0.041555788168417554, 0.03147231674353991, 0.005853422626387328, 0.010132870470572795, 0.07137323264032602, 0.021584438126800314, 0.04738420041810189, 0.023059669948582138, 0.026998776077691997, 0.03843317340527262, 0.03806673056845154, 0.11006860554750476, 0.05572348739951849, 0.03237245112125363, 0.04292001335748604, 0.026617659921092645, 0.028347528971997753, 0.0010028787863640381, 0.14878497911351068, 0.018256839630859237, 0.047239699600530524, 0.032616723727967055, 0.034031167293765714, 0.03517580837277429, 0.047866479360631535, 0.0603632012914334, 0.04290927554081593, 0.045029863715171814, 0.06130415294319391, 0.029094149890754904, 0.048843254268701584, 0.022657590452581644, 0.04250738603462066, 0.05135573373575296, 0.022145606943273118, 0.044940962057028494, 0.023588343723011867, 0.0470912598871759, 0.06607755858983312, 0.02572345593944192, 0.06973081148628678, 0.07002396575574364, 0.062363291824502606, 0.0179227306840143, 0.02195649584090071, 0.05221692020339625, 0.025649997738323042, 0.05207322344982198, 0.07695158437958785, 0.006691049934098763, 0.03260633874950664, 0.027895952042724406, 0.044349900380309136, 0.025129374781889573, 0.032885593229106495, 0.07622996917260544, 0.05984183533915451, 0.0780011016343321, 0.022300241681348, 0.02685599365005536, 0.04115884857518332, 0.050739179498382976, 0.03918538375624588, 0.06701074101563011, 0.016310156589107852, 0.03982420072757772, 0.013052011241338082, 0.05097379315910595, 0.05623983219265938, 0.025410496929128255, 0.04254360623391611, 0.05252424906939268, 0.036044044819261344, 0.07726635677473885, 0.04185725109917777, 0.038923299605292935, 0.03246379550546408, 0.04339282673650554, 0.04395943061847772, 0.04475499935714262, 0.010556826783743287, 0.015754117497376034, 0.032253948372921774, 0.016862736848582114, 0.06164992081799677, 0.03309947085965957, 0.0163127926976553, 0.02840234442347927, 0.052836409104721885, 0.04175132839009166, 0.022469520901462862, 0.057085951790213585, 0.06813252903521061, 0.02474394823158426, 0.06017087732574769, 0.07509479365710701, 0.047658019832202365, 0.05697177470262561, 0.05293857612247978, 0.01502956762643797, 0.02776938320935837, 0.05406322416716388, 0.0185312951715397, 0.028737847759787525, 0.04149449270750795, 0.022324507789952413, 0.04585079948550888, 0.012509009351820817, 0.00999729917384684, 0.0199955415113696, 0.06140161092792239, 0.031161157547363212, 0.017565403965168765, 0.03141465483765517, 0.042913078729595454, 0.023093572950788906, 0.04666018319715347, 0.013712463301739522, 0.017413279806662883, 0.05395670434726136, 0.04613689020542162, 0.04628424087007131, 0.05540227909971561, 0.04753193445503712, 0.00175372655420298, 0.011585980354409133, 0.04458805938650455, 0.04136945566694651, 0.006236179141394261, 0.02900721598416567, 0.034244922788015435, 0.030257114807942083, 0.02101376642739134, 0.05642558793936457, 0.006093890347983688, 0.02085687216770436, 0.12616050456251415, 0.1139985378831625, 0.08721064709659133, 0.108927669269698, 0.0887444687208959, 0.17883611443851674, 0.11181292909064464, 0.15485131288213388, 0.14107028022408485, 0.2402514996273177, 0.1287549374891179, 0.09504799797598805, 0.2056373655796051, 0.16568731356944355, 0.1243683850126607, 0.1291404403746128, 0.0965013996298824, 0.1294561627187899, 0.20030228900057928, 0.09531852988792316, 0.1253534685820341, 0.1169024370610714, 0.14540856171931538, 0.18991382287016936, 0.08752855432352849, 0.05463288824207016, 0.06290848792663642, 0.12446096433060509, 0.17834758279579027, 0.12233514125858035, 0.10034151428512164, 0.15723212941416673, 0.09057588901902948, 0.1831263420837266, 0.10774787329137325, 0.23160386937005178, 0.08558922660137926, 0.08754608088306018, 0.09105272950338465, 0.07722699495830707, 0.12126165814697742, 0.2021637141172375, 0.13222751686615603, 0.15285099164715835, 0.13618390528219088, 0.12357741674142224, 0.19714418346328394, 0.11692877779049532, 0.10190004815480538, 0.10489329003861972, 0.11564801580139569, 0.2762187139264175, 0.20961577924234526, 0.0562016171004091, 0.14367537972118172, 0.18727295100688934, 0.14423499469246182, 0.12157128724668707, 0.37228106068713324, 0.15199497900903225, 0.09976864752492734, 0.17796047856765135, 0.2140585415597473, 0.20989050450069563, 0.1317319284592356, 0.1466082659150873, 0.1431937962770462, 0.10547859434570585, 0.11966587949012007, 0.10161234930689846, 0.10856953848685537, 0.1319375652819872, 0.07973324547388724, 0.20831561115171227, 0.12668980258916104, 0.0831353250624878, 0.11017107790602104, 0.1299988550267049, 0.1266145666262933, 0.12091388180851936, 0.08926119349364724, 0.1620360759219953, 0.14133378251322679, 0.08142082991876773, 0.06888362658875329, 0.12641196964042528, 0.22845410981348582, 0.11107321735471487, 0.16630596108734608, 0.1535340864211321, 0.09804231873048203, 0.21239604933985642, 0.08569952925401074, 0.1995833675776209, 0.1399392302014998, 0.1579138399767024, 0.20617727589394363, 0.21920877162899288, 0.1400921991361039, 0.12583554057138308, 0.30455897748470306, 0.24783125147223473, 0.1055279713390129, 0.18090286425181798, 0.09679809585213661, 0.07784278584378106, 0.09613227657973766, 0.10132482687809638, 0.10667072609066963, 0.16396208400172846, 0.12241702686463084, 0.13657886694584573, 0.278281107544899, 0.12158746352153164, 0.17662246179367813, 0.10163028298744134, 0.09330483472773007, 0.13791289393390926, 0.1252124418637582, 0.10605111505304064, 0.10381609534046479, 0.19798153638839722, 0.09775322888578687, 0.1768781609301056, 0.1168962081096002, 0.12708446569740772, 0.09883988914745194, 0.17187730355986527, 0.1019278545198696, 0.12417026635791574, 0.09151437080332211, 0.15220119937189988, 0.14954583400062152, 0.07659457996487617, 0.19453787617385387, 0.21617350807147367, 0.09788015564637524, 0.14280173874327115, 0.18164744786918163, 0.118840577346938, 0.11531277879008225, 0.14026869966515473, 0.1189399284443685, 0.16968423766749247, 0.11568027335618224, 0.06915113223450524, 0.10676402465573379, 0.11214752827904054, 0.1606253066233226, 0.09096549704138722, 0.22903982124158315, 0.08144596964120865, 0.11043491267732211, 0.0858362540602684, 0.11298655040029969, 0.09893165422337395, 0.2094661079879318, 0.071184681329344, 0.16428311248975142, 0.1460107886897666, 0.1168109162577561, 0.08845997934362718, 0.15656510234943458, 0.11419869214296341, 0.15128019664968761, 0.10924562399408647, 0.16135884369058268, 0.10548696746783597, 0.1412049422838858, 0.08385708954717432, 0.12400976568460464, 0.0996813132826771, 0.13735117550407136, 0.1592789574393204, 0.11100059375166893, 0.07936297569956098], [0.03563010113845978, 0.018808366464717046, 0.0890809745926942, 0.04820881045556494, 0.034719178053949556, 0.013398683264053293, 0.12370845542422362, 0.027966994659176896, 0.026652178693828837, 0.014901869032265884, 0.04082252251516495, 0.029144191848380224, 0.014723468605162842, 0.0020270234963390976, 0.018217345500098805, 0.07930990747575249, 0.030008190843675817, 0.036129971101347885, 0.019058125027056252, 0.05399419340704169, 0.11894484103790351, 0.05965225265494414, 0.04600791766175202, 0.021038337876754146, 0.06916717280234609, 0.0514409068439688, 0.03919206054082938, 0.02833821438252926, 0.030696442483791282, 0.07408417002963168, 0.04064928234687873, 0.014018988103738852, 0.05451068747788668, 0.05763027936752353, 0.04688843559207661, 0.05462537346673863, 0.015320372468392764, 0.01684039947576821, 0.017337903047778776, 0.013550732783707125, 0.047286481197391234, 0.05312726653314062, 0.022307250948090638, 0.07615585957786866, 0.025315530864255767, 0.026400126683126603, 0.044549827330878804, 0.012606430865292038, 0.03341078272621546, 0.04525996172534568, 0.06268054087247167, 0.03154017703075494, 0.038421207440218756, 0.0254921297808843, 0.006467155006248504, 0.030733395500906875, 0.05917438758271081, 0.027718359072293555, 0.04576111072674394, 0.032959631577666314, 0.05029266613668629, 0.04941264692960041, 0.03125939584736313, 0.03715828074408429, 0.038136137915509086, 0.05215230331357036, 0.0632505849269884, 0.09159942516790968, 0.06446831779820578, 0.025081672073741044, 0.04308241053617426, 0.05580557317339948, 0.08077671019626514, 0.030490758163588386, 0.03256618643977812, 0.007953890965187123, 0.048848550234522135, 0.012072387334358479, 0.030752360554678098, 0.04455340999577727, 0.03889239572786859, 0.0580683687169637, 0.0372223344498447, 0.017625963215583136, 0.028275653453809873, 0.014676530945247837, 0.04718867715980325, 0.038527927427951775, 0.026897884705769162, 0.03541041524814708, 0.042659798570509465, 0.021309005495693003, 0.011495483290803219, 0.026829323831147382, 0.01063443931551384, 0.038082075637898276, 0.04053889487736991, 0.04528058918991259, 0.011514849528404219, 0.014363633003085852, 0.015202166579131569, 0.014582711604556866, 0.12072822105671678, 0.04715195145191891, 0.002320984374299379, 0.053970461644764454, 0.04882019425609282, 0.015201104671827384, 0.022229236384321536, 0.06596952902951411, 0.025019704863162975, 0.0021161187490049216, 0.056295970787427256, 0.002763775335292199, 0.028091302274593284, 0.0382245374577386, 0.03688270053161042, 0.08429166408521788, 0.054483722496245585, 0.06075898398246084, 0.034582853583352904, 0.04911682941019535, 0.024135188665241003, 0.028778943233191967, 0.04307898732700518, 0.02817257889546454, 0.03284629926617656, 0.05825222456561668, 0.04443547043151089, 0.014087040925265422, 0.021709012067211524, 0.02970840728708676, 0.04734260282878365, 0.03354177391156554, 0.0585884725941079, 0.021228107158094645, 0.029879683096493994, 0.04071356675454548, 0.0710484789950507, 0.04874731620241489, 0.03488594839083297, 0.012492604071407445, 0.011042801197618246, 0.041239037843687196, 0.018264683495674814, 0.02570809899563236, 0.05547032259138567, 0.060849581978150775, 0.01174953019446028, 0.06875826045870781, 0.019256530362846594, 0.0420155261776277, 0.02327338812340583, 0.04072872183418699, 0.01868442865088582, 0.04370679506765945, 0.019830908559794937, 0.02620695624500513, 0.011233097191766968, 0.11926194759351866, 0.022092348729659404, 0.012717073633601623, 0.07483389015708651, 0.05907650212092059, 0.024382523161226084, 0.03334979260606425, 0.037529415650559325, 0.03352675114625266, 0.05489271626408611, 0.018702825431578925, 0.027173296980825917, 0.008686104040992047, 0.03896230519083994, 0.042608918622136116, 0.03318476610417877, 0.024542777865592922, 0.0133577769322853, 0.012595207896083593, 0.04891056494255151, 0.026700907686193074, 0.022189250315672586, 0.019493077848372713, 0.04196188119905336, 0.05388534960470029, 0.018031118171555654, 0.01954666684780802, 0.03764168605474489, 0.060423780897898335, 0.03948533016123942, 0.00952577925220664, 0.019427809564928924, 0.06252985860088042, 0.03517924854531884, 0.014569188401635205, 0.041635889227369, 0.08077212329953909, 0.11707557205642972, 0.013398468677353646, 0.04528669261240533, 0.030614590804491724, 0.02095948701857456, 0.05673559023333447, 0.06515439134091139, 0.07213888477001872, 0.06095992534288338, 0.02705177305532353, 0.028393204556778073, 0.006796632527506777, 0.04861770583582776, 0.042861018130289655, 0.020334887052220956, 0.012714863305778375, 0.005748903212536658, 0.038103232359779735, 0.017693172109180262, 0.006524656608235091, 0.014292758324050477, 0.019563837176454917, 0.04067580967343279, 0.06843839226556675, 0.06023018128637757, 0.03187948525218027, 0.023933290570442165, 0.059571608767977784, 0.06716149114072323, 0.017006669393075362, 0.02166951963278864, 0.03783685986750892, 0.01303589518647641, 0.03498762686337743, 0.03756056380059038, 0.013127787487714418, 0.03481148935056158, 0.03720249408589942, 0.07636339629867248, 0.008548347861506045, 0.016085169643961957, 0.028480811909373318, 0.0219007491001061, 0.04279869129615171, 0.03596689199496593, 0.025141506988023008, 0.045857564479644806, 0.08025990399931159, 0.014182617671654692, 0.08267399588865892, 0.038714242966047356, 0.028829504270106554, 0.07045578544161149, 0.02944155303495271, 0.04120368616921561, 0.00789665144735149, 0.059451508069677014, 0.05149815484349217, 0.03701578499749303, 0.07314359835748162, 0.023155434988439083, 0.036390026432595084, 0.019339991866477897, 0.019333432129185115, 0.010967886690715594, 0.018383344003398503, 0.07148810183363301, 0.03298813683379974, 0.06807952866490398, 0.03725760470011404, 0.05792250404400485, 0.02637441359859492, 0.05150735917102013, 0.0457431058000241, 0.017792692840365425, 0.005532436122718666, 0.04911565215193799, 0.05372918816283345, 0.040239111320780854, 0.03986892636333193, 0.06231306666242225, 0.037444259505718946, 0.06033151370606252, 0.03527968190610409, 0.04004422249272466, 0.01661018611464117, 0.0639444887638092, 0.011469788017815776, 0.02918930764177016, 0.04644875507801771, 0.04756761182631765, 0.02633640376318778, 0.04228331341541239, 0.045761310894574435, 0.034591253846883774, 0.09473712715719428, 0.05071686587429472, 0.11045965206410203, 0.05028978914820722, 0.04918888982917581, 0.049151282025767226, 0.07148181181401014, 0.0030927657956323984, 0.031041993227388178, 0.03645730996504426, 0.01696213035445128, 0.028877361344971826, 0.02380557501289461, 0.055639315130455155, 0.05275333945506385, 0.09112056943454913, 0.03091366868466139, 0.02374627783761493, 0.01679947872513107, 0.026647917493911724, 0.012341009170216109, 0.024079709945778762, 0.07283966895192862, 0.020827881759032607, 0.027003444398620298, 0.033536016541932306, 0.03285835004810776, 0.04803863048021283, 0.03422531312597649, 0.023363429720380476, 0.023155957460403442, 0.02177958649450115, 0.027120072693963135, 0.028313023769961934, 0.05999604599284274, 0.016519633920064995, 0.045245525892823935, 0.054826280900410244, 0.018828749656677246, 0.0290764808388693, 0.009211733737694365, 0.021244424228955592, 0.006071955431252718, 0.05893229985875743, 0.04378384950437716, 0.027244862069242766, 0.012660250566633684, 0.08580568605767828, 0.005118941547282572, 0.04129232998405184, 0.010874767089262605, 0.010229060442985168, 0.035316587425768375, 0.00962400482967496, 0.02813817547368152, 0.04939192447013088, 0.023922584984185438, 0.02060885913670063, 0.05709421634674072, 0.03874676175681608, 0.06614840443113021, 0.12051013990172318, 0.12719197278576239, 0.18712591246834823, 0.09809867784913097, 0.10592870055032627, 0.1700677728014333, 0.22244184171514852, 0.11123628967574664, 0.1120831828032221, 0.07464934898806469, 0.11189920481826578, 0.14228806059275353, 0.1883345597556659, 0.16857958265713283, 0.09573439043015242, 0.1920640460614647, 0.08603241853415966, 0.13814147881099156, 0.10088956701968398, 0.19724609942308494, 0.2340564749070576, 0.2608383878001145, 0.12490083144179412, 0.0640508219865816, 0.0619029804532017, 0.11027926352939435, 0.11748054889695984, 0.15353485995105334, 0.1179848632642201, 0.14035829342901707, 0.14593980035611562, 0.1215449193758624, 0.23730416063751492, 0.09491510689258575, 0.10872763714620046, 0.08763763561312642, 0.1611225777970893, 0.19299129130584852, 0.17433178185352258, 0.08904229131128107, 0.09274346913610186, 0.07848132800843034, 0.05858952432338681, 0.13581349301551068, 0.14389006820108208, 0.17981753391878946, 0.06345384009182453, 0.10130726639181376, 0.12476401164063386, 0.1449739464691707, 0.09197059739381075, 0.14052601371492657, 0.09502311609685421, 0.16441767955464975, 0.07666885240801743, 0.10772286249058587, 0.18785263704402105, 0.1240856937531914, 0.15154760730053696, 0.10334315643246685, 0.09155371226370335, 0.13971390229250702, 0.06014915741980076, 0.10358685906976461, 0.12059007132691996, 0.11640051113707678, 0.08279958593526057, 0.1522402422768729, 0.2346732360976083, 0.17213731817901134, 0.11530445995075361, 0.09961950552782842, 0.2133763288812978, 0.1913538370281458, 0.12022024260035583, 0.06053046017353024, 0.11401361493127686, 0.08937865469072546, 0.09534367639571428, 0.19466127455234528, 0.1265462517206158, 0.19822267416332448, 0.0555088158829936, 0.13206343352794647, 0.13727498959217752, 0.10940246736364705, 0.25130016676017214, 0.12096311630947248, 0.22303250644888195, 0.1656502384160246, 0.2783116416207382, 0.12867197979773792, 0.1685272811778954, 0.15831661836377212, 0.14733241205768927, 0.11226400560034172, 0.10602997868720974, 0.1386051760720355, 0.13667099843067781, 0.12653744433607372, 0.11023047686155353, 0.10125635590936456, 0.18185488959508284, 0.13231316155620984, 0.14875668420323304, 0.12807930660034927, 0.12286678701639175, 0.08359766525349446, 0.07933955267071724, 0.08976271229663066, 0.13004357048443385, 0.09472158870526723, 0.11448956653475761, 0.12802475238484995, 0.10188701349709715, 0.1720216686704329, 0.1669833425964628, 0.21834415516683034, 0.1845110013548817, 0.17010543149496826, 0.1465803916965212, 0.1172445679881743, 0.12963582522102765, 0.10556560967649732, 0.10636370935078178, 0.07889311055519752, 0.08818807000560419, 0.07272467083696808, 0.10915280040353537, 0.15495208890310355, 0.17329754520739826, 0.14582149099026406, 0.11266409698873758, 0.09326041782540934, 0.14299065646316322, 0.08127750296677862, 0.201124157756567, 0.1423286505575691, 0.09641435037234, 0.11983418331614562, 0.08507501919354711, 0.1075371949534331, 0.191243778648121, 0.185764024832419, 0.08771266801548855, 0.09554283999438797, 0.10704658699354955, 0.23442874635968888, 0.0942615419626236, 0.16362943899418625, 0.11200179252773523, 0.13944248828504766, 0.10598067633275475, 0.08627926278859377, 0.10550872808588402, 0.231786205300263, 0.10213636154575007, 0.1360132401543004, 0.138223690113851, 0.22039996699563094, 0.13095685147813388, 0.07826760983360664, 0.15501641402287142, 0.10836347418704204, 0.11803312067474638, 0.08488419479025261, 0.17179450871688978, 0.13168702301170143, 0.1505892580108983, 0.11857353310499873, 0.08096883060144526, 0.051946415432861874, 0.14070199855736323, 0.11770476400852203, 0.09679369215986558, 0.11629627458751202], [0.06288526167294808, 0.037382672274751325, 0.01821543712035886, 0.021652557953659977, 0.040714214755488295, 0.018232760119384954, 0.000577140947695755, 0.04740826466253825, 0.05899869451033218, 0.021787740789087753, 0.03313536875482116, 0.031385803528662236, 0.025219477447015897, 0.036044295877218246, 0.01124208523625774, 0.01607418755468513, 0.040704036730208566, 0.03389739750751427, 0.002207922628648313, 0.07048980040209633, 0.016552057715931108, 0.08016407449862786, 0.02722405140022082, 0.01472635068265455, 0.03206745980839644, 0.039691523382706304, 0.0614243961338486, 0.020190676308370063, 0.010427892407668489, 0.014522774910022105, 0.028021720204768435, 0.03014085122517177, 0.03515308762767485, 0.053610420785844326, 0.022524933463760784, 0.03471453348174691, 0.020907202502712607, 0.056161050884319205, 0.02588757829341505, 0.06617533548602036, 0.053625552116760185, 0.041635129268148115, 0.02406802218008254, 0.021682133598785316, 0.09231922190104212, 0.007004046687922839, 0.038569141644984484, 0.03625589023743357, 0.05206403269299439, 0.0212966816034168, 0.009297652386261948, 0.02973669201933912, 0.06441596882151705, 0.03372506657615304, 0.08881327895713703, 0.027970175292076807, 0.02211216534487903, 0.013913817720354667, 0.029844463736351048, 0.007934087072499096, 0.022730685637465546, 0.03787362289481929, 0.03909906392384853, 0.1339827919644969, 0.06569775539849486, 0.061168975196778774, 0.043455418199300766, 0.042650899583739896, 0.015184166741424372, 0.064901060291699, 0.006436368176114878, 0.06433432748807327, 0.07354169485292264, 0.08632211227502141, 0.0371214770046728, 0.036039369712982855, 0.027893287096438662, 0.03134162750627313, 0.029097037057259252, 0.07345210787441049, 0.031264108273067644, 0.035960276278534105, 0.05450887578938689, 0.08772070865545954, 0.007256128808616528, 0.032458438471491845, 0.05667001660913229, 0.013207814755982586, 0.03920719526442034, 0.03437760352556195, 0.03843050676264933, 0.035085437686315606, 0.016995543115107075, 0.02407218499242195, 0.003601143527443388, 0.03236733157453792, 0.007754776560302291, 0.07075457155172314, 0.03629732497834733, 0.04311734151893428, 0.0026128996812206295, 0.0443801426860903, 0.04111263355506318, 0.013468671606720557, 0.126035694831184, 0.04173927082281027, 0.01725114556029439, 0.07985395685370479, 0.05747176001646689, 0.0577944102031844, 0.054574866712625535, 0.05480785188930375, 0.04668890558449285, 0.013726077258719929, 0.0713383559403675, 0.02709955209866166, 0.026807673475039855, 0.004036291427577713, 0.007722121214361063, 0.019393686038841094, 0.02360600259687219, 0.062190672515758445, 0.01196093117219529, 0.011801283756670142, 0.02030858364222305, 0.0426509436885161, 0.027829070542273775, 0.02036663400940597, 0.048085751344582865, 0.020904868342248455, 0.026987056081582392, 0.03122681598844273, 0.005248087541466313, 0.04473835489313517, 0.033972127961793115, 0.052533738381628475, 0.05592479177617601, 0.029735148352171694, 0.0773348548848714, 0.05519497647349324, 0.007434821005777589, 0.09059177352381603, 0.058230613225272725, 0.024399305028574805, 0.04037577166621174, 0.021241716874231185, 0.03802788783130901, 0.03032907683934484, 0.04701184414859329, 0.02654598796341036, 0.042584430293313096, 0.028116399588595544, 0.01259507642992373, 0.03394772444984742, 0.0413533472456038, 0.017391610790842345, 0.07773280888795853, 0.052400728554597924, 0.029543010983616114, 0.04725217446684837, 0.03420445495950324, 0.023930891949151243, 0.017629026801192334, 0.076037618065519, 0.04688918198059712, 0.01531349721231631, 0.056661127800388, 0.007974647351407578, 0.025691546133852432, 0.05892267144684281, 0.035207482387444804, 0.045188786794564555, 0.018599817030397908, 0.05484628750543509, 0.058909602862383635, 0.03164993007002132, 0.01042462865422879, 0.03412276952128325, 0.031603732013276646, 0.03031421352976135, 0.021396502586347715, 0.06711352550025497, 0.015266311887119497, 0.0670147104454892, 0.007696052747113364, 0.05836870867226805, 0.020969480143061707, 0.017596258648804257, 0.021883112278633883, 0.041634752681212764, 0.06088655535131693, 0.03108854072966746, 0.05122013529762626, 0.04680282822144883, 0.01995055633597076, 0.043340121528932025, 0.07773902426872935, 0.028075046271884015, 0.05031225883534976, 0.0627666808930891, 0.0398643225032304, 0.02978085447102785, 0.05291940411552787, 0.01814931388279157, 0.031004894325243573, 0.03751611975686891, 0.009039199245827538, 0.03289332852831908, 0.03293442400172353, 0.04299408902547189, 0.04569061093830636, 0.008172847430354782, 0.009989635120811207, 0.016891457539583956, 0.03341092182589429, 0.027983776526525617, 0.04958608387304204, 0.021221197975267257, 0.0324250749046249, 0.027910172440377728, 0.04096280963027051, 0.01986650450687323, 0.0030151927037098047, 0.044688567386141846, 0.025660036663923944, 0.024807632135759507, 0.02482606453954109, 0.021317421026261787, 0.03317698670018997, 0.018444554647430778, 0.047628551056342464, 0.025062264275870154, 0.05766083379941327, 0.047922716342977116, 0.021275920128183703, 0.009918310912325978, 0.02327064853826804, 0.05046970270840185, 0.0034297453696906033, 0.04169818213475602, 0.03678244698260512, 0.021268820955551097, 0.01987605488726071, 0.07327507808804512, 0.03474438223721726, 0.07111009676009417, 0.01786483129087303, 0.025224976973342042, 0.06691675034484693, 0.020862096887347952, 0.03024627860369427, 0.0842847226719771, 0.01615472457238606, 0.01968916429073683, 0.048616426797317605, 0.041929308125483136, 0.03308378652270351, 0.04392139194533229, 0.02306852991958814, 0.03745354525744915, 0.027430317564202205, 0.14427719957062177, 0.047038853235010586, 0.045768791743155034, 0.012144471502064593, 0.03470229949536068, 0.06147962888436658, 0.019521474538903152, 0.022071650018915534, 0.029618894947426658, 0.033857408046190224, 0.029340393641697507, 0.028773715120873282, 0.03342108967314873, 0.01349189192322748, 0.06145248069827046, 0.06274259968527726, 0.013485115902897502, 0.06324780293341194, 0.02906274050474167, 0.06771209516695567, 0.022209236564646875, 0.02673250706201153, 0.0437944244726428, 0.04721587284335068, 0.060801372065075805, 0.02063237376777189, 0.0732772019026535, 0.029971739942474023, 0.019303866662085056, 0.013860149841223444, 0.029855523857155015, 0.05138815074626889, 0.04131076917318361, 0.02137341203966311, 0.02068369137123227, 0.010551343372623836, 0.032927309562052996, 0.027902267507410476, 0.04552421718835831, 0.037842484922813516, 0.058901575793113024, 0.02891426007928593, 0.026868539762550166, 0.035506807932896275, 0.027660809124686887, 0.01919078201587711, 0.04899158541645322, 0.01410026302827256, 0.028664742396878343, 0.06707564967551402, 0.009669074821951134, 0.05279395316860505, 0.07088648554469858, 0.010466260170297963, 0.025942514184862375, 0.024254392000979612, 0.007996104325034788, 0.08021870335297925, 0.04593644756823778, 0.055931390529232364, 0.03326016830812607, 0.07093960126595837, 0.01853903386342738, 0.0017458659380541316, 0.014965446067175694, 0.03769860835745931, 0.07335276356233017, 0.02067105026383485, 0.02692437980190984, 0.018350881191768816, 0.017791442639593567, 0.0332638188265264, 0.020114948407613804, 0.07715209826294865, 0.02597275479430599, 0.0513411045207509, 0.03482231537678412, 0.030855484306812286, 0.03640142921358347, 0.04322087239207966, 0.03185123783935394, 0.03148213514525976, 0.012928328726307621, 0.028023959370329976, 0.02960236244169729, 0.0148505039313542, 0.017999367821695547, 0.0032243755080604126, 0.022597234762672867, 0.016695415201996053, 0.007290302376661981, 0.11199780952717577, 0.10522706141429287, 0.11133497580885887, 0.07258465513586998, 0.13760093067373547, 0.13247306511870452, 0.0894467660358974, 0.1690381094813347, 0.10472800569342715, 0.15976866973297937, 0.13847549445927143, 0.08643907135618584, 0.16742665666554654, 0.13846773201865809, 0.13079113965587957, 0.07860442104616336, 0.12618219054171018, 0.15858013422361442, 0.11215761809476785, 0.13100848799305304, 0.14551244543067046, 0.16177253292075225, 0.0801223920924323, 0.14652555249631405, 0.1463548330856221, 0.11584267392754555, 0.17728913602020058, 0.1654827216906207, 0.13415063438670977, 0.09351794222103697, 0.11182244893695627, 0.10332786225314651, 0.1333020177802869, 0.17751591599413327, 0.07295854150184564, 0.13454361472811016, 0.08159332030585834, 0.12119749587561403, 0.11160579949085202, 0.15918717879269803, 0.1802892650344542, 0.10420720292521374, 0.1926212047359773, 0.14330104552209377, 0.12091670451419693, 0.11322774924337864, 0.16869232803583145, 0.12967564165592194, 0.13960920433912957, 0.07963457969682557, 0.1286477968096733, 0.19119788253945963, 0.10600595854754959, 0.08478141709097795, 0.18686714635363647, 0.14867631851562432, 0.15900900906750134, 0.10905978003782885, 0.1293247983391796, 0.0667896471651537, 0.10278940400374786, 0.12209431560976164, 0.16156859243554728, 0.24838224904877798, 0.1580811260002, 0.1481919666486127, 0.15771753979580744, 0.17401424103549548, 0.09998716972768307, 0.17658048761742456, 0.06495925824024848, 0.09531040782374994, 0.11920212794627462, 0.2605397238263062, 0.08657698359872613, 0.16813898272812366, 0.13325131764369352, 0.0966764073818922, 0.1702678320663316, 0.07947796024382114, 0.151042356554951, 0.13399200647005013, 0.11579566502145358, 0.18462732939847878, 0.08106755744665861, 0.18963084662599222, 0.13789324355976923, 0.11597589749310698, 0.0820705204137734, 0.08000569763992514, 0.20012870617210865, 0.1843072237180812, 0.09694545330213648, 0.13736284630639212, 0.13908473748181546, 0.09984230250120163, 0.12427761059786592, 0.1270256367112909, 0.15590194293430873, 0.1555337698331901, 0.12721945345401764, 0.15295126555221422, 0.14050090791923658, 0.057550219020673206, 0.17596288504345076, 0.09330784063786268, 0.1433436439505645, 0.11902051126318318, 0.19447718800178596, 0.14684449109647954, 0.1349264984684331, 0.20625925649489674, 0.08275745569595269, 0.14554160886577197, 0.17196454959256308, 0.15848355154906, 0.14278245477804116, 0.1015534388965794, 0.06123961747757026, 0.1449666725737708, 0.08472923774804388, 0.1490882435547454, 0.0663439446528043, 0.1407860011926719, 0.06774657831660338, 0.1007978290851627, 0.1019915146753192, 0.07634127605706453, 0.09536925038056714, 0.0923160667132054, 0.08517061799232449, 0.12315985986164638, 0.11169172916561365, 0.09214085540069, 0.1576970073261431, 0.1711490862071514, 0.11745533453566687, 0.22165056131780148, 0.13866454788616725, 0.13284051897270338, 0.12898087607962744, 0.14166117565972464, 0.2231933463897024, 0.07646470836230687, 0.08528543290282999, 0.12256243691912719, 0.2110676813338484, 0.121309562719294, 0.1204849798232317, 0.10209419059434108, 0.11856959760189056, 0.1788630929908582, 0.09230090145553861, 0.09347205968307597, 0.12166801919894558, 0.10301303557519402, 0.15490991116634437, 0.13660108218235628, 0.14369193597563676, 0.15940743125975132, 0.13954730837472848, 0.1313893904111215, 0.1195654020245586, 0.08885304789458003, 0.12299269597445216, 0.14185063620763166, 0.09369681762265307, 0.14011978836996214, 0.09498544383261885, 0.13383336498269013, 0.20718811665262493, 0.07891630288213491, 0.05893801312361445, 0.11786713743848459, 0.12091636524668761, 0.09570923035166093], [0.010654075270784753, 0.05443316824468119, 0.05580718130139368, 0.006351513555273414, 0.04028784031314509, 0.045987934805452824, 0.033191911077925136, 0.021813701538901244, 0.0499369712945606, 0.04234396426805428, 0.003292101572567065, 0.05683026961716158, 0.0611816638016275, 0.051385935329432995, 0.06834249491138117, 0.06078963340925319, 0.05180208764172026, 0.018627735353740196, 0.04739558623571481, 0.020627498493662903, 0.03635757888800331, 0.055526393332651684, 0.027239438878106217, 0.08993951816643987, 0.01876451613913689, 0.024272670038044453, 0.034534647062953026, 0.01865257482443537, 0.016379226364993622, 0.02524792672401028, 0.05990442340927465, 0.006287518373158361, 0.013214300702592092, 0.059602305692221434, 0.00924245101798858, 0.03531746952129262, 0.08923940573419843, 0.012205793256206172, 0.02496382750437728, 0.04447376694796341, 0.03312418310503874, 0.0764857768746359, 0.02616621021713529, 0.02443465161403375, 0.016497623940397586, 0.011443973153031297, 0.0386257111094892, 0.017897748720965216, 0.034821131333176575, 0.04189311506758843, 0.0335780416083123, 0.06411620562097856, 0.01995500922203064, 0.02177859074436128, 0.006030660638186548, 0.030658563266375234, 0.05848459566810301, 0.001375389952694864, 0.027905987575650215, 0.032671878446957896, 0.026318972198558704, 0.017550398163231354, 0.012109960362847363, 0.024529627856931517, 0.02573603088967502, 0.03820953504847629, 0.014037119407605912, 0.053946014028042555, 0.02928289119154215, 0.027114042213984897, 0.04436244310012885, 0.025174192019871304, 0.05526332530592169, 0.004213339873656098, 0.04723162164113351, 0.050520223033215315, 0.03193514208708491, 0.022917776401819925, 0.008772767381742597, 0.025599852304107377, 0.03674581626962338, 0.08166325691023044, 0.05252006929367781, 0.009452144631982913, 0.06621899921447039, 0.025273683913318173, 0.0310634688607284, 0.006301136570982635, 0.04589530799005713, 0.0049396776843683, 0.01764513861521014, 0.07197303045541048, 0.0183378363560353, 0.05446948343887925, 0.04811779855351363, 0.022439678931342702, 0.04430392963279571, 0.030150160725627626, 0.05157683437157955, 0.02458552726810532, 0.07592046899454934, 0.04414914222434163, 0.03743361668395145, 0.02495475040216531, 0.037042906042188406, 0.03011264791712165, 0.013603766232595911, 0.04732718651315995, 0.014641944319009781, 0.030544572775917392, 0.09702869597822428, 0.0453173352538475, 0.01975525020887809, 0.05637716089508363, 0.09457157818334443, 0.06965398096612521, 0.01835192783203508, 0.05912138721240418, 0.04447841830551624, 0.02890349512121507, 0.02037340239621699, 0.030407081225088665, 0.03864435385912657, 0.024206265208444426, 0.050661782401480844, 0.07319202540176255, 0.03900283408750381, 0.044376614303993325, 0.0592752518132329, 0.03839359785030995, 0.05334210089807, 0.07655544206500053, 0.027635377632187944, 0.09031851390110594, 0.038529973211033006, 0.05953301369611706, 0.03663791563095791, 0.04047957734603967, 0.03613722803337233, 0.005136275148418332, 0.06410722860268184, 0.020122251140752008, 0.030444661887096505, 0.08550462685525417, 0.01933827517288072, 0.048735916814101596, 0.02808872044884733, 0.010666780839008945, 0.02761380870028266, 0.02629174428459789, 0.05151264156614031, 0.03528260299935937, 0.01825985741535468, 0.0840373288041779, 0.05002126909260239, 0.08116935127015625, 0.0833753432546343, 0.020762764449630464, 0.04032433192644801, 0.023152517287858894, 0.029982945948307003, 0.013445430085994303, 0.049432955482708554, 0.013373047362879982, 0.04330695812989559, 0.010255766733150398, 0.007449424775716449, 0.027498646040580103, 0.0408038254827261, 0.06213375021304403, 0.042909584274249415, 0.013756939575874379, 0.04496625784252371, 0.019082788078646575, 0.02094390955088394, 0.03853761351534298, 0.056479378802967925, 0.03234249719285539, 0.038156510929444006, 0.032815212184297185, 0.11390948694731508, 0.014632047885762793, 0.03576344005497439, 0.04723443416878581, 0.02366059073912246, 0.02546552272646555, 0.04196174209937453, 0.0524784547409841, 0.029425712634942362, 0.0299412296153605, 0.03120867196204407, 0.06867395248264074, 0.038528100454381535, 0.014009684540464409, 0.030445591480072056, 0.055184720416686366, 0.02401366813241371, 0.08286653020020042, 0.06752659047820739, 0.018808373250067234, 0.08382182608225516, 0.05196709718023028, 0.01766002906619438, 0.030266325920820236, 0.028067205799743533, 0.01498145779727825, 0.03177689415003572, 0.0660227465310267, 0.018152754055336118, 0.02395102408315454, 0.006625064523957137, 0.017827971572322503, 0.05168216675519943, 0.02575127248253141, 0.012185661122202873, 0.030290861747094562, 0.022537447345842208, 0.04597671522891947, 0.02287738151582224, 0.037654361088893244, 0.028707330647323812, 0.007879949307867458, 0.04032581452546375, 0.04019564436748624, 0.03391877475327679, 0.011777403564857585, 0.02541889379998403, 0.055338120221027305, 0.04800172835322363, 0.03328469056370003, 0.017874349440847124, 0.04909215109156711, 0.04799061394961817, 0.06443302719188587, 0.01604571283262755, 0.06688093048121248, 0.012727176171860524, 0.004582690657116473, 0.031764500707920106, 0.011758454626293054, 0.07036248687654734, 0.04709482898137399, 0.043252010364085436, 0.056662749499082565, 0.03174745251557656, 0.017230769153684378, 0.021650600380131176, 0.031019744064126695, 0.07591364293226174, 0.010784482916018792, 0.0472104920606528, 0.03578387413706098, 0.013976684838001217, 0.07804717416209833, 0.013153705829089242, 0.03698129166982003, 0.012693721002766063, 0.07494610627847058, 0.048413392156362534, 0.028634846143956696, 0.05716772883066109, 0.041193331724831035, 0.012204441275181515, 0.013030476236183728, 0.03760738271687712, 0.010693218259673034, 0.0593799226252096, 0.022602179586621265, 0.01694658681351159, 0.02143111465764897, 0.03349950796525393, 0.013730707412053431, 0.039225671772978137, 0.042752289678901434, 0.008932205299580736, 0.03523133967870048, 0.08941424385245357, 0.07924685121646949, 0.048715201139982255, 0.01422792939203126, 0.031218378405485834, 0.0589856802086745, 0.029878013900348117, 0.045780510042927096, 0.028956064621784856, 0.038512887699263434, 0.06202905225966658, 0.014096462383999355, 0.11034108485494341, 0.07850334646978549, 0.012412230750279767, 0.02515528803425176, 0.04085041708978159, 0.09902552954320397, 0.05019956434677754, 0.02933808322995901, 0.027320952986234, 0.007848821513886963, 0.04629997270447867, 0.03752725112384983, 0.024544562412691966, 0.036220121263925514, 0.044184117311877866, 0.020622987932126437, 0.0308710397221148, 0.018708236748352647, 0.036475559164370806, 0.0447216731097017, 0.052765603975525925, 0.030351288683180298, 0.02158070957687284, 0.024886806994410496, 0.012714661441610327, 0.038792383058794906, 0.06285922628428255, 0.009868722724994379, 0.046425633997257264, 0.03517606282340629, 0.03692795881735427, 0.020019929756277373, 0.03631268361849444, 0.056046049376683574, 0.016920790608440126, 0.03276985551097563, 0.05314199752839548, 0.038916992622294595, 0.12078193388879299, 0.04240493403215494, 0.026133325017456497, 0.012713251785109085, 0.010421312314325144, 0.051295038778334856, 0.07000111269631556, 0.0684176833767976, 0.037245394462453466, 0.0202423671060907, 0.02912796807608434, 0.11284780355968646, 0.03345530480146408, 0.031848907071564875, 0.08703327804271664, 0.030736628720270734, 0.025891532456236224, 0.032132144551724195, 0.06240542884916067, 0.06103254894592932, 0.04236748229180064, 0.02497440586531801, 0.06388312884207283, 0.03170197709862675, 0.03104509073974831, 0.02819313681019204, 0.2789262043578284, 0.11507295737309114, 0.1458273128207241, 0.07826661238712923, 0.22289947287312575, 0.11788172594138555, 0.17391699339662278, 0.11609027135585036, 0.16097766985850676, 0.09855037861104522, 0.1101384200155735, 0.15140238723584584, 0.1717130709439516, 0.12463342079094478, 0.1322194422994341, 0.24238169246486255, 0.13144721516541072, 0.09613025454538209, 0.15231508468942984, 0.1015472642279097, 0.15322732073920114, 0.1498742720910481, 0.16176358982920647, 0.10525324608066253, 0.15659077811454022, 0.12807390546160086, 0.14001206415040152, 0.09635377755122525, 0.11518999109310762, 0.08822856497551713, 0.16157022091959203, 0.11718230561486312, 0.12438110075891018, 0.14869453039552483, 0.10779722314327955, 0.06706986177180495, 0.1998376010784081, 0.07468085336898055, 0.08883128049118177, 0.15825556378279412, 0.13145670108497143, 0.15991289913654327, 0.14662360080650874, 0.09133478293993644, 0.1521692539432219, 0.09966299962252378, 0.11993122739451272, 0.08715338552636759, 0.153943785865392, 0.14120085750307354, 0.14190343980278286, 0.17781120086354868, 0.14307247421571187, 0.10769895770187889, 0.04393191263079643, 0.13111972702401026, 0.12999417313507625, 0.11889237671026162, 0.08705575790788446, 0.1794682919446911, 0.1812527033367327, 0.11546095726745469, 0.12001315371266433, 0.0854901062058551, 0.14453614210443838, 0.21178349506642136, 0.10941673695508923, 0.21422573258834227, 0.18677065867398465, 0.1185960876090186, 0.1201947975371565, 0.13122203653412207, 0.14556261630994932, 0.1056164794468454, 0.12696477212011814, 0.14506132820887224, 0.0706932862688388, 0.1466097179800272, 0.17317181266844273, 0.1844456855739866, 0.0740249203518033, 0.23983653475131306, 0.1658431730632271, 0.09477253989981753, 0.23984530142375401, 0.09476791907634054, 0.20230968057044915, 0.13047171251050063, 0.08139609731733799, 0.10566575465989964, 0.21180930653853075, 0.1347718739083835, 0.11267288401722908, 0.13709591063005583, 0.10924893524497747, 0.09465629328042269, 0.12057221228522913, 0.0630826542952231, 0.08798854678337063, 0.1267707518168858, 0.21105218359402247, 0.15020988908197197, 0.10785782989114523, 0.12452159821987152, 0.0868686790178929, 0.19153858854302339, 0.11323156261018344, 0.15275591532034533, 0.17470048421195575, 0.12959667375045164, 0.18362373539379664, 0.16950772356774124, 0.11869223602116108, 0.16034448812050478, 0.19744484233004705, 0.21475000945585115, 0.11306610863123621, 0.16059555964810507, 0.14680624886282853, 0.10814127432448523, 0.10104684465165649, 0.06445676913218838, 0.10246336114193712, 0.08652812907738344, 0.12367348372936249, 0.1688310205936432, 0.21416668647101947, 0.07544291604842458, 0.1740513840424163, 0.08652545564940997, 0.11362229021532194, 0.1960227279258626, 0.18465706280299596, 0.081097480840981, 0.09683259935783488, 0.14478995491351399, 0.12448668080781188, 0.11801440667893205, 0.18213485314377717, 0.08912573076252427, 0.14180460439196654, 0.1400030396346535, 0.1451197772153786, 0.14128875492938928, 0.13665251513676985, 0.15680856071412563, 0.16449272552771227, 0.13412807988268988, 0.21451826260558196, 0.08813085593283176, 0.17055098472961358, 0.14689388844583715, 0.09601479502660887, 0.17254878181431973, 0.09159494683678661, 0.1889817735978535, 0.1488659419119358, 0.14676897014890397, 0.2565161468727248, 0.10668552493942635, 0.06882150670779602, 0.10840092253472124, 0.08986853661813907, 0.15312448197177478, 0.15140329647277082, 0.13025160932115146, 0.10386385063507728, 0.08981960067259413, 0.1017518900334835, 0.1331034241510289, 0.13278867889727863, 0.12812741473317146, 0.21601979274834904, 0.062213532360536714, 0.11693820942725454, 0.13798906627510274], [0.020895501166316013, 0.032456236625356336, 0.022671230702794025, 0.020252490848568932, 0.02495597685421152, 0.08291019392865044, 0.018272149077217494, 0.05253356196252363, 0.009846817070086087, 0.04356205676283155, 0.05467608038868223, 0.08093655269060816, 0.06646190796579633, 0.10186034028551408, 0.009096593978548688, 0.019512628138597523, 0.031451445006366284, 0.0365165766062481, 0.04084118562085288, 0.06933839432895184, 0.006504674176020282, 0.025401774361463528, 0.017171587329357862, 0.025591825234836767, 0.056070147547870874, 0.02830971421540848, 0.01837467571853527, 0.04422891080113394, 0.04720260748373611, 0.03183530244444098, 0.03837860222639782, 0.0165952871819692, 0.037106827433620176, 0.030760404587324177, 0.02371888028989945, 0.02499490780090647, 0.034494854376784394, 0.020986587707219378, 0.04193273472732731, 0.0031311666368440327, 0.029679342239562954, 0.02360698307997414, 0.03448955162561365, 0.04601262669478144, 0.042467803694307804, 0.03497355065441557, 0.01658659175570522, 0.03879756706633738, 0.0743891443791134, 0.028042118663766553, 0.019069714405174767, 0.0018252201844006777, 0.02354179791707013, 0.021529039135202765, 0.036585352915738306, 0.10349297696458441, 0.02589132889573063, 0.060686156818909306, 0.0569381465071014, 0.022543803522629396, 0.02629726247063705, 0.034080483218921084, 0.02994871385661619, 0.03392852530149477, 0.04475728941283055, 0.021347729489207268, 0.0005154261203382962, 0.026708468262638365, 0.023612715004544173, 0.029259006758885722, 0.024318052156429206, 0.06410864674087081, 0.04890979480530534, 0.029158217167215686, 0.012357253298562552, 0.06707331551504986, 0.016356873725141798, 0.06911863719246217, 0.08204881407852684, 0.017599954968318343, 0.043349604055817635, 0.022916929929384162, 0.04628828154610736, 0.017372830637863705, 0.028351094673520753, 0.022725750991542424, 0.04356893032257046, 0.033271007905048985, 0.06126394295798881, 0.01909374981187284, 0.0513637947317745, 0.025459936686924527, 0.02379854199742632, 0.042299004537718635, 0.04989661542432649, 0.061327467406434674, 0.02802829860177423, 0.05229716036202652, 0.015917356059487377, 0.06802772251623017, 0.0017090577457565814, 0.0652582546962159, 0.08494774638009922, 0.04716017868902002, 0.06149825467062848, 0.023184310046157668, 0.025800330564379692, 0.04529883160388895, 0.02591029734217695, 0.05756397971085139, 0.0062283034702496866, 0.020521492664037005, 0.021261319750919938, 0.012528110960764545, 0.03690723296520965, 0.08508593682199717, 0.014056088702221001, 0.048798036695058854, 0.014690965081432035, 0.06978350651583501, 0.032863836003733535, 0.07698095137519495, 0.0007722570319726531, 0.05629828119916575, 0.044852569300149164, 0.027298520618517483, 0.021410695842600296, 0.021953550998919776, 0.03070303105882236, 0.04907135399324553, 0.06906083279422351, 0.05090237056304302, 0.08160597498395614, 0.044173172542027066, 0.015507308866030403, 0.04866570879572204, 0.022637577062206607, 0.046561286718185456, 0.058465508478028436, 0.04157325705247266, 0.012017644825391471, 0.06803246547601052, 0.02648830909415015, 0.020355433092585633, 0.041401845536061695, 0.03205790264265878, 0.0422482670816992, 0.029295705325369324, 0.06530650532139198, 0.05720821701522384, 0.03250282483973673, 0.04842017411387392, 0.021983935797054852, 0.017031744654689516, 0.01554284883396966, 0.038284523346062214, 0.008981684073140579, 0.0152203496212938, 0.019466233306697438, 0.05737313495150634, 0.037214242919747315, 0.007654580686773572, 0.027066622794206654, 0.03406798121120248, 0.02673722796940378, 0.009623610431195369, 0.022502954018169215, 0.034723859945578237, 0.03450039800788675, 0.044300173941467486, 0.036030128066028864, 0.03715464040370924, 0.07142333566610302, 0.030307007487863302, 0.007152115327439138, 0.05171312152275017, 0.021981474411274706, 0.08238519781402179, 0.04207208885678223, 0.06256383963461433, 0.02907581248187593, 0.018100442398073416, 0.06864109781703778, 0.02642559040603893, 0.009649966427657222, 0.00958475751602756, 0.05802532924073083, 0.04162553817565952, 0.040173751435109546, 0.10273689896400486, 0.04356780056176441, 0.03398111855079021, 0.009578137558751872, 0.019616927452651516, 0.05599259778058954, 0.03403372537078602, 0.03520413042445268, 0.016286353580653667, 0.060598897215511115, 0.012958347115532627, 0.0033477352948726286, 0.018409318323912363, 0.0361981910121228, 0.029345821921846697, 0.045537455406572135, 0.05861962413681405, 0.038685507008007596, 0.0366050847140806, 0.04001295220639024, 0.04184578046468752, 0.08510948198714427, 0.07878443638661078, 0.0919046098632472, 0.03957765842122691, 0.033160444016435316, 0.008390396783527519, 0.037094776651688983, 0.018663702798741202, 0.036765880550124815, 0.09792459290474653, 0.02424004946702293, 0.04534833073349936, 0.04212794925219246, 0.04410828763086881, 0.04475954893444266, 0.038922234305313656, 0.03850692676912461, 0.03406492780361857, 0.0072226897547287595, 0.006759260939101556, 0.04044003911050303, 0.035357085788356404, 0.03364410038505282, 0.03196364055786814, 0.0532005754565554, 0.014945928007364273, 0.01553113731954779, 0.04560634367434042, 0.022423731662066917, 0.04275264251711113, 0.028613112667309384, 0.0232601244601288, 0.05804938330714192, 0.04792627186647483, 0.06510415939348084, 0.057729881522910934, 0.03048288037202188, 0.01024860394785979, 0.08570425864309072, 0.023322870289640765, 0.01934559826206948, 0.02551769867672452, 0.09680604828255517, 0.008067394606769085, 0.036968525033444166, 0.05427128675260714, 0.021092970123780624, 0.11642252281308174, 0.06068175991198846, 0.02698114773790751, 0.04532171180471778, 0.02731923459629927, 0.04427248632003154, 0.0820847289370639, 0.0626133591202753, 0.02186539233662188, 0.047699831160051484, 0.029975078334765773, 0.052979990507342985, 0.02030304170745824, 0.025063719733485153, 0.006242122684073235, 0.04040009714663029, 0.029315362484859567, 0.024118106546146528, 0.02151349898693817, 0.05609401501715183, 0.08207849320024252, 0.11203842663339206, 0.014388713353712643, 0.020387475212503756, 0.04911117382081492, 0.05213331451107349, 0.02962769554661853, 0.044809821593974314, 0.022621595866179893, 0.06465271647487368, 0.025105985679796765, 0.0373375021985599, 0.015295760306928839, 0.01014461082273296, 0.07023401984146663, 0.06767870445868798, 0.016215081958632385, 0.017228686051177125, 0.011237061532613422, 0.08649493514427117, 0.05418162174256785, 0.01120678530008133, 0.05121289872165237, 0.020881384245253036, 0.05710040458611079, 0.020069243985095193, 0.022800383058243563, 0.03930450397144471, 0.004878291045315564, 0.04199746357543128, 0.006378517976762461, 0.03962777501770428, 0.058914970074381144, 0.0015467339336672531, 0.013101791114812451, 0.03951275993936828, 0.015678108004587035, 0.02384882653132081, 0.039341317888881476, 0.02252603947584118, 0.013938274666933077, 0.008509087825327047, 0.03254036818231855, 0.07299900254500763, 0.007438307827604669, 0.01692632575785475, 0.031106389593333006, 0.04411299327122314, 0.025072299808795964, 0.04310136201924511, 0.03888938642506089, 0.014179963751563003, 0.01924987223797611, 0.022668564060170735, 0.03226652162681733, 0.011305350145058972, 0.037224651646933386, 0.030583493544587066, 0.024696369356076633, 0.008288931201345153, 0.03760356595739722, 0.0381560122062053, 0.052423160922314437, 0.0649405171030334, 0.022601407753037553, 0.016363304540781037, 0.022144841895039593, 0.0389823525079659, 0.03531838893624289, 0.009789588578444506, 0.034946042844759564, 0.017829255699845295, 0.020245391675936322, 0.05665415246039629, 0.03944215497800282, 0.12480439804494381, 0.12438019152198519, 0.09052530423338924, 0.13506429536002024, 0.12432326243392058, 0.1808740807963269, 0.0916914955845901, 0.14261398810361112, 0.07307637589318411, 0.13089290633797646, 0.11845090825642858, 0.19773672095366887, 0.19723107665777206, 0.24169316941073962, 0.19022771316979611, 0.12850493804684707, 0.08492061855005366, 0.13388900485421928, 0.09322658606937953, 0.17043644801846572, 0.13613510504364967, 0.13918761696134294, 0.14567897149494716, 0.0740957051249487, 0.09630328776048762, 0.0648799714233194, 0.15555247025830404, 0.1210681399596589, 0.10878672397562436, 0.19803387857973576, 0.11812594426529748, 0.11344731639006309, 0.09801225284380571, 0.14288085592644556, 0.17989496833511762, 0.15621575180973324, 0.16619469491498812, 0.12784658265965326, 0.28527235239744186, 0.17385340109467506, 0.09235584243599858, 0.137802089165364, 0.10905598702707461, 0.14473130234650203, 0.11723808119339602, 0.11827128646629197, 0.0989189791892256, 0.12901651273880685, 0.1615808332072837, 0.2447803137557847, 0.21598240546882153, 0.09102331501032625, 0.09392875446272747, 0.0642570084226983, 0.09435203817806073, 0.1548429669014045, 0.09679591775472675, 0.14537232794931956, 0.22549301013350487, 0.09421633117433105, 0.07564245962670871, 0.0850963116224323, 0.0745403559080192, 0.1027588156451072, 0.0597941004005926, 0.10785626247525215, 0.1261698683457715, 0.19101207250995295, 0.14057782664895058, 0.1958731652370521, 0.09920224041811057, 0.20120153789009365, 0.11843532909240041, 0.12430709972977638, 0.07955352868884802, 0.08604497143200465, 0.13542891293764114, 0.17972100552703651, 0.08188492073012249, 0.11957028747669288, 0.10159174898373229, 0.19755684132022516, 0.1209495048969984, 0.1875784003308841, 0.10242951581520693, 0.08758747151919774, 0.10085470389042582, 0.2653624250420502, 0.1571438791496413, 0.12470257708004542, 0.18968147890908377, 0.11417237855494022, 0.16728533139186247, 0.13269160767751081, 0.08085524383932352, 0.13868502607303007, 0.09807616405721221, 0.08107057692749159, 0.09490617058639016, 0.13215080169694765, 0.10258243725235973, 0.28416653030685013, 0.22092527523636818, 0.20382886619440146, 0.09751998925847666, 0.10263388377747365, 0.1302534413657018, 0.12665812857449055, 0.1191526898848159, 0.10999637549476964, 0.14303127356937953, 0.09605023491063289, 0.22154169715940952, 0.08345684888107435, 0.08579656654702765, 0.14759052677878312, 0.18403096497058868, 0.13857025865997585, 0.13002096169761249, 0.10525141403611217, 0.18159697843449457, 0.16787382481353624, 0.0611066585406661, 0.11343954716409956, 0.1051609856741769, 0.13347323930689267, 0.14127405786088534, 0.1233582499303988, 0.09718353088412966, 0.23450327664613724, 0.22405864138688358, 0.20934379526547023, 0.09745801865522351, 0.12280673666724137, 0.1659475453197956, 0.12672382433499607, 0.13271215371787548, 0.08861261579607214, 0.08837479605738606, 0.10068464944405214, 0.08652541493730885, 0.12393467899944101, 0.0744911078363657, 0.11895849316247872, 0.13988106617970125, 0.09144917037338018, 0.1833188153271164, 0.19251729388322147, 0.1059784439525434, 0.1165270172059536, 0.09227599243500403, 0.12445819590772901, 0.13646384168948444, 0.11749915432717119, 0.1845143533178738, 0.10531544060047184, 0.09080138656177691, 0.1740623763097184, 0.08242988613034997, 0.17082626638667925, 0.2183995914778539, 0.10557265286999089, 0.16223194184047834, 0.16012515846107686, 0.14845978442047322, 0.08914315554180316, 0.09920909362179892, 0.07826036986495767, 0.09790931229612657, 0.13422341405281, 0.1405784101890666, 0.07911073709172861, 0.13021965032177313, 0.07394478536610093, 0.12800985175584043, 0.17534502462616988]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.06072205810674599, 0.03951185070244329, 0.008758646219835749, 0.043344216487769566, 0.09510864543595485, 0.026996828682188476, 0.06224536922361169, 0.011752893183646458, 0.07042240151869399, 0.03280072206897395, 0.02371031208895147, 0.016859359440526793, 0.03302363778597542, 0.05264942181695785, 0.07381745826985155, 0.0121362849770646, 0.010404378624766, 0.03715051491079586, 0.026659976757530655, 0.11220015545508691, 0.025271585543773005, 0.0017264869779215328, 0.04454850418759244, 0.032909572656665526, 0.0728868135650243, 0.00432259206926184, 0.06552810807313238, 0.05710289480962923, 0.07161219231784344, 0.038531974889338017, 0.04875147222940411, 0.030238685796835592, 0.043728097674569914, 0.01975089231772082, 0.04597404519362109, 0.0642342164314219, 0.009914894488507082, 0.051035750191658735, 0.05017913705004113, 0.035000346002302, 0.05854880543691771, 0.03940613155386277, 0.01947728494581367, 0.025284703322021023, 0.0580751947792513, 0.050283777327941995, 0.04484066101057189, 0.03160789143294096, 0.007617907565353172, 0.055242446783397875, 0.05016826691904238, 0.060692602901586463, 0.0381178547894316, 0.036366511801523824, 0.027181558144677962, 0.029823351119245802, 0.04325781523116997, 0.01201118856468903, 0.05544736775170479, 0.011248344721804773, 0.040178206017506976, 0.033170058857649565, 0.024851640220731497, 0.012755510097901736, 0.02633321125592504, 0.02550544772696282, 0.011513366081219698, 0.025003292797399417, 0.025482095944296037, 0.06788725898201976, 0.01769029681703874, 0.024079857527145317, 0.0782298832865698, 0.012286259027730142, 0.071521648604955, 0.03815661949504699, 0.03986360325611063, 0.015743506906021918, 0.028832876589149237, 0.020642741782856838, 0.06935777328908443, 0.012351820777569498, 0.0385647175966629, 0.044067806231656244, 0.052771232423505614, 0.05451470779787217, 0.023056233168712685, 0.05869350302964449, 0.03407773854477065, 0.03770682880921023, 0.05432062303381307, 0.02099255033369575, 0.042548939519162686, 0.030155514366924763, 0.053909349388309886, 0.03027299592005355, 0.017183485440909863, 0.059487497567066124, 0.007684682196538363, 0.033461035029696565, 0.024017328828839318, 0.042480600864759514, 0.03750029632023402, 0.05175101770354169, 0.012968510721943207, 0.004928825364913791, 0.012847651760759098, 0.023541830147483518, 0.01019404803602291, 0.036929217499813864, 0.0380207632136132, 0.054225505994898934, 0.04629081587440201, 0.011095181556551583, 0.04574710237128394, 0.0367743249184319, 0.07916670944541693, 0.020980413038549677, 0.019693288087312664, 0.006939769065606275, 0.0144793266164405, 0.07800854516348668, 0.03566560209063547, 0.034717495287103314, 0.017032348550856113, 0.023566957995561615, 0.04063678712451032, 0.012824311004286366, 0.04268149133505566, 0.054041212491158924, 0.02665410064426916, 0.04172927600198558, 0.031236125488898585, 0.00917627604212612, 0.025088374303387742, 0.02526835402074669, 0.04967161321214267, 0.02019059658050537, 0.04888967624200242, 0.01157508053750332, 0.04382910439744592, 0.01119329093489796, 0.05436129442283085, 0.04332254068659885, 0.01438055227377585, 0.06699122634849378, 0.007080530731140503, 0.0326716239963259, 0.029565484063433747, 0.02862023049965501, 0.02007558659118201, 0.041582240856119564, 0.016350178280845284, 0.009508550399914384, 0.02037932600692979, 0.038064284449709315, 0.06910920555570296, 0.024341185111552477, 0.0054260185071533275, 0.006306697589544845, 0.015168816582964999, 0.06377848517149687, 0.025873938043202673, 0.018851601019767777, 0.046218806345547946, 0.019071249590654458, 0.03806296130642295, 0.01592334752370204, 0.0017628970610011102, 0.03327247693336435, 0.027501957291471105, 0.04283070797100663, 0.022455480315589478, 0.07566873928798096, 0.06292644196322986, 0.00972931770541306, 0.0522427520315562, 0.04327444612447705, 0.011293868484374667, 0.005818477224758161, 0.05043668180171933, 0.04193044467163937, 0.0900675712951592, 0.05158174017976437, 0.03905448756579842, 0.024436108767986298, 0.0048886255577339655, 0.022774435879130448, 0.061944384660039625, 0.027324727337275232, 0.03660229254247887, 0.04413151388455715, 0.006776091152070356, 0.03299724955910018, 0.013182821766739445, 0.036147317849099636, 0.02769737028782921, 0.011619353251132582, 0.02483569464779326, 0.04393351736611553, 0.022559343670893992, 0.062126747731651576, 0.029571967465536933, 0.060045660473406315, 0.01461968497772302, 0.014872364633317505, 0.10122595754052911, 0.05799076466688088, 0.055685445333697965, 0.045677335400666506, 0.03861001320183277, 0.05045829653473837, 0.020635564578697085, 0.03417285219100969, 0.014249111558975918, 0.061865776378129206, 0.014504379825666547, 0.0446419520303607, 0.031597482705754895, 0.02985162228079779, 0.024475580846358622, 0.009935591502913406, 0.0895993278494903, 0.055435344111174345, 0.03170189567442451, 0.04420414427295327, 0.06403829623013735, 0.013249616753975195, 0.03922284906730056, 0.03554111127076404, 0.018943472964955226, 0.05209755910826581, 0.11088144300239426, 0.0371575716749898, 0.10753632642860923, 0.013397754519246519, 0.042927260111485205, 0.04985733163942184, 0.05259778190936361, 0.014023382466153374, 0.036547979206911156, 0.03609666181728244, 0.03388651380581515, 0.024999910300331454, 0.03092499343412263, 0.03876290749758482, 0.02556900949483471, 0.02339922413895173, 0.04740867856889963, 0.026787392063332454, 0.013949017572615827, 0.0600976769679359, 0.0387898249817746, 0.0683548306780202, 0.01783014797339482, 0.007391427843166249, 0.012858216550999453, 0.044981338283313174, 0.030574553845716373, 0.052184937455292256, 0.0809469749884946, 0.05171770163412605, 0.009815105735989553, 0.02148083770381553, 0.036911093829465766, 0.02049028853486691, 0.01778974799838449, 0.020238748818103756, 0.02502484306959169, 0.0431672850889819, 0.04125829806019153, 0.04148772092802184, 0.03408650860988668, 0.10587663655834538, 0.012625338243586677, 0.02558881932470415, 0.02989665325731039, 0.010616553980591041, 0.02699253016284534, 0.12173241217221532, 0.04362213425338268, 0.005462270088693393, 0.05575655919632741, 0.057562527645911486, 0.04730812307181103, 0.04791987328124898, 0.043685407643871646, 0.03463545022532344, 0.03268266376107931, 0.02029439547498311, 0.038101359603128264, 0.039111382727112086, 0.02972469212753432, 0.06137257641447442, 0.03580792820347207, 0.03959512391260692, 0.051811685519559045, 0.04367054094161306, 0.049501518053667884, 0.0390533408416169, 0.024886747622596364, 0.06099223718047142, 0.04580155141385538, 0.024865270292918597, 0.021058334303753715, 0.08152993834976639, 0.032510784055505476, 0.07037070393562317, 0.03941746987402439, 0.04791801070262279, 0.037877096994114776, 0.022857899079099298, 0.05888269216354404, 0.018478226947731206, 0.06356715543993882, 0.04615486120539052, 0.06640191868479763, 0.06073472635554416, 0.028408239196453775, 0.0022156973677088638, 0.01882214072559561, 0.05098341817834547, 0.03139544890395232, 0.006355151351142142, 0.005246291544088828, 0.01024186609512461, 0.029778584771390473, 0.06361850697015013, 0.052771887209798606, 0.02583389769175223, 0.003973059173274253, 0.02484945533797145, 0.014839969675189682, 0.02624415692740253, 0.07067247559981686, 0.03667439706623554, 0.028516265364097695, 0.07167614424335104, 0.08931386816714491, 0.03410794013845069, 0.029381841953311647, 0.01848293767709817, 0.05172970491860594, 0.018058437687743987, 0.010773064019823713, 0.0731334135468517, 0.020095723814197948, 0.0365992119934942, 0.05874828116169997, 0.04687461044107165, 0.016235789151063988, 0.021773667972800986, 0.128189799242786, 0.14971911827368395, 0.14342380607766764, 0.11201956335987363, 0.20568248815834522, 0.14238752025578702, 0.1475698043193136, 0.13108865012015614, 0.17785004020801612, 0.11633051346455302, 0.19602454639971256, 0.20928086792784079, 0.11658956456397261, 0.14343568044049398, 0.1195442181612764, 0.12135954360876765, 0.08099302037486009, 0.13622167254132883, 0.06388984633875744, 0.21943570088062966, 0.09794524751071419, 0.11298289988189936, 0.10908814280160836, 0.1926790973437684, 0.12266186944075994, 0.10735449261431183, 0.16659418919256755, 0.1596984549292496, 0.13350420764514379, 0.13669311867228576, 0.14545954684061663, 0.09447156212159566, 0.16081737274570124, 0.13327604345977306, 0.1777820238577468, 0.13469739790473664, 0.05960677045264414, 0.08225229994526931, 0.17393105264220918, 0.10555445456079074, 0.17567889099674566, 0.14723045538578713, 0.07921882772019931, 0.1471978449927909, 0.18038024300975458, 0.1020952830357211, 0.11408662529928343, 0.09572050081832068, 0.143359562382102, 0.15868971762912615, 0.15758460121495382, 0.16343259598527635, 0.16140715538391046, 0.19869866647890636, 0.11553322124694075, 0.14782376640609332, 0.18917921371757984, 0.11097187814967972, 0.2044405248016119, 0.07075666143958058, 0.11118336394429207, 0.11602939319397722, 0.15418286089386257, 0.07647118158638477, 0.07103067423616137, 0.17539824891303266, 0.08540316551391568, 0.07281942825232234, 0.12635252997279167, 0.13675436324306897, 0.07487388979643583, 0.11487420089542866, 0.13540449924767017, 0.11266829712050301, 0.14078894603465283, 0.09944005337144647, 0.1870079966528075, 0.1530460026115179, 0.08886118352945362, 0.06875632663390466, 0.09992691581802708, 0.13504298936043466, 0.15566421140517506, 0.07381074077316693, 0.2641357694353376, 0.15924310364893504, 0.06357952513332878, 0.1344801988452673, 0.056874930792089017, 0.12578127134059156, 0.12298656201788358, 0.16366367787122726, 0.11480493604072503, 0.08165005940411772, 0.1071836171405656, 0.08272102515080146, 0.09279803013695137, 0.15584771441561834, 0.0727200907255922, 0.13677967259926455, 0.08309061639010906, 0.1406962988632066, 0.14220146595367364, 0.16401404621345655, 0.10347894486039877, 0.06533636086221252, 0.15682462842336722, 0.15668102327202046, 0.13260649224477156, 0.08237356093845197, 0.11700390518776008, 0.22001218423247337, 0.09284237240042005, 0.07035411375441722, 0.11626265996268817, 0.08868573472968169, 0.19928969762154988, 0.09622783466641392, 0.09203595388680696, 0.15350990343306745, 0.24295586879764283, 0.10356026728238378, 0.11093224491924047, 0.0832378449184554, 0.08286346322191612, 0.10933135010834251, 0.08577702473849058, 0.06765420934451477, 0.10397427542401211, 0.10334090369620494, 0.15925626722829683, 0.2013179880699941, 0.1821706797927618, 0.09637585708073207, 0.1267184910497495, 0.15523163176008634, 0.2310666867664882, 0.1891495617372649, 0.1506718492933682, 0.17698777147701808, 0.15202578449887888, 0.1359527012599366, 0.17138907047254698, 0.08529696799814701, 0.08703226024018866, 0.148986422589847, 0.11317953254495348, 0.08070507046899625, 0.05682317553354161, 0.1269123756459781, 0.1336934646325452, 0.10216260728027139, 0.12570963161332266, 0.09493498796863215, 0.1359320602246693, 0.09376209269144706, 0.12568911271435873, 0.0776633879702006, 0.15179698249059065, 0.059870578082544465, 0.1141383975212063, 0.21344544445829733, 0.16684082310114587, 0.08644167014530726, 0.10869376467806952, 0.08692123155508723, 0.08748710261923925, 0.09000667277723551, 0.13263779985053198, 0.12673098966479301, 0.06227466158036675, 0.122691453567573, 0.10246813802846841, 0.13601458365363733, 0.10184648460043327, 0.07999137376568147], [0.004802362976728806, 0.030866283191634074, 0.04081690763788564, 0.0450811779259571, 0.006824870186392218, 0.013012607864636396, 0.053447572381368706, 0.008844640355424156, 0.011748091700220746, 0.03304749846990619, 0.008628184291800218, 0.03410192831818547, 0.016634530254772732, 0.019787979345502596, 0.02425156590262694, 0.024929653088163053, 0.059212066632296355, 0.027461872835244452, 0.04543901354606662, 0.026747772403593575, 0.0398246146339391, 0.012525807334376233, 0.03208304915044989, 0.020457116654142737, 0.026853920725573386, 0.013665702060929366, 0.0034553827551592675, 0.03710150093372379, 0.0059072605633576, 0.020800903206691146, 0.02807143476924726, 0.02342049451544881, 0.0589754886126944, 0.035003233168806346, 0.023873384409983243, 0.06833891224648271, 0.018028722942939827, 0.07213207906378166, 0.015515419055840798, 0.005660046507338328, 0.030741527743105377, 0.057198866802666865, 0.05539037759548851, 0.06664758228829928, 0.048704276726182015, 0.048704001919499466, 0.024168190912210515, 0.047187527042946646, 0.01573709475009569, 0.017240691031994562, 0.018381389822544794, 0.058870987434472354, 0.02577708225830325, 0.0738764161776219, 0.037180889530905654, 0.012050699658824928, 0.06502807526183979, 0.024460125514971356, 0.05864295895610537, 0.03939659474417567, 0.05602041093100395, 0.022215087232845168, 0.054117320371525626, 0.040707907772489955, 0.01990684850274452, 0.07234817211117063, 0.05430740856432489, 0.04389247278283749, 0.02410451040071036, 0.025632835891363875, 0.04524077954036849, 0.024081219686195254, 0.04011049161532095, 0.057361796631344726, 0.022945855877229145, 0.03030020517430135, 0.06038672610052994, 0.014619790150650909, 0.05381925350853375, 0.01245751787376191, 0.060071424448064396, 0.013254863526006895, 0.02342761743680707, 0.048734193335154226, 0.04445144993120006, 0.026810947406504835, 0.007024034633234675, 0.0781598516872951, 0.01684726116114429, 0.021431197778188756, 0.04926865501329303, 0.010022526257671416, 0.0039280125056393445, 0.03835989162325859, 0.02934996777081064, 0.05994118643658502, 0.03895598463714123, 0.06467179687959806, 0.015521597117185593, 0.04314122595159071, 0.09250813283558403, 0.09128127366836582, 0.010849090475988175, 0.016780693483139788, 0.02076203332814787, 0.04473582735019071, 0.0539853995932, 0.018221867935998098, 0.022404254314356616, 0.01421757325130914, 0.007962379438270415, 0.05781405379197427, 0.04681601215686117, 0.013725090838436569, 0.001539147806137667, 0.028121897418584143, 0.02727212051727942, 0.005395162975349064, 0.030862588568457534, 0.05094227181481464, 0.02276203904433974, 0.03758801732744489, 0.0012515050433908723, 0.004378226003609598, 0.030419013263391595, 0.017933025756584745, 0.06267062747584921, 0.06414864638022014, 0.049534671274679046, 0.040221194603613446, 0.031528411233531575, 0.03635215400052922, 0.014280298724770546, 0.03200299898162484, 0.037002628203481436, 0.028022073042978133, 0.0901692294116531, 0.023532610552917634, 0.006835423950438521, 0.04086019477940031, 0.01788676154267575, 0.0202209796823029, 0.0665926073810884, 0.04610812710598111, 0.013672172740500952, 0.020251379747475897, 0.02046782902574965, 0.05636396678164601, 0.023847980058885047, 0.08093340428812162, 0.03354247619530984, 0.055823150623057566, 0.04903600910412414, 0.05607799480536154, 0.03203975861626012, 0.05363974028400012, 0.0281861784335758, 0.005321620381437242, 0.03231575952044555, 0.0450963397909488, 0.017166871510978256, 0.10998009065432207, 0.028644881676882505, 0.019787243135007362, 0.017672183324715922, 0.055480195275907, 0.07387654509927545, 0.03801777765953115, 0.05579455376469663, 0.024377532536163926, 0.08643586188554764, 0.014269364132945026, 0.09172046902988638, 0.048343000933527946, 0.021679707836093645, 0.030704683291592767, 0.04373218924073236, 0.00863085687160492, 0.028935708571225405, 0.020232338358515074, 0.03685380172516618, 0.06656028197279998, 0.04312289193538683, 0.035896314175001214, 0.021203942829743028, 0.032842170380588086, 0.05178969419960465, 0.011499243222975304, 0.05045113120494144, 0.031883966975978444, 0.03125224408826657, 0.030935849994421005, 0.05713032798043319, 0.030160002876073122, 0.012100911250204911, 0.02529620279424957, 0.06053867723260607, 0.01498445013671049, 0.01642697487425591, 0.04557098860719374, 0.07693161509398903, 0.015882615066532577, 0.024412790912070444, 0.003581104692005153, 0.004335913408015455, 0.0655375872073429, 0.039787247710462124, 0.017318756485890065, 0.02280553144269756, 0.015847227768972516, 0.011919068106051003, 0.05833751641746078, 0.04084296677527683, 0.036067844435040436, 0.051178320577102046, 0.0030966283562260544, 0.01821441083614315, 0.05616367681484137, 0.007835417054593563, 0.0346985743381083, 0.042206988403839726, 0.03898362476112587, 0.06042782496660948, 0.026678887528500388, 0.051453958465052504, 0.04492867039516568, 0.042631812393665314, 0.019262275858117, 0.030291784554719925, 0.06171062934611525, 0.03412487976519125, 0.00513041515036353, 0.050165600276419094, 0.03612072266904371, 0.04896836934079017, 0.033084953602935584, 0.09028163552284241, 0.05100424920341798, 0.04978183444057192, 0.043652067825730355, 0.017845106277880923, 0.008033307551938509, 0.007385010598227382, 0.07999197766184807, 0.05125458452052303, 0.03573253957022514, 0.06378075147845916, 0.04791128642058798, 0.002331257182439523, 0.06767269942377295, 0.029446384204285483, 0.029115350717412572, 0.037056089977600744, 0.03909659405638065, 0.042057320542101345, 0.03178187120439751, 0.02529272360594145, 0.028238032079700912, 0.0417764579345073, 0.02671667853636401, 0.0709906949528626, 0.03531388007104397, 0.04761311438466821, 0.0413903477601707, 0.026130619359069636, 0.05306837987154722, 0.018085190627191747, 0.026714517402329614, 0.06586989973272596, 0.048770610309605084, 0.022554714365729263, 0.07100275252014399, 0.024973318512950624, 0.005684347814946834, 0.05285657855815121, 0.020095566054806113, 0.024108379746654203, 0.018957902012126784, 0.04779337060504726, 0.06834381126931735, 0.06522084706063781, 0.007429664987804634, 0.06409255867557866, 0.010654749564959534, 0.019337074165897708, 0.04272161989605852, 0.027225661224552562, 0.04557948725830231, 0.03993434053180473, 0.0600905998476914, 0.03042913361319474, 0.021244179956348877, 0.05076358301032867, 0.05579107627272606, 0.052255613662834675, 0.034416266450924535, 0.02631257361333285, 0.004984695938349302, 0.02913239212440593, 0.018731235692809736, 0.035867469651358466, 0.029258718381502798, 0.0315490319127483, 0.07381496126098291, 0.07621428822832448, 0.0057674484227650934, 0.05582008703744837, 0.00993866441837911, 0.02883034904620477, 0.06078583361314876, 0.07156628263848168, 0.015027218198935901, 0.06130620890430041, 0.05648301575066788, 0.047859425989112685, 0.0230278347818447, 0.05531232910496848, 0.04251862596720457, 0.004207850525355232, 0.03564990757565413, 0.020839321859447018, 0.10087700733648879, 0.03788676272545542, 0.05397131320621286, 0.027110344198133265, 0.014632002084649034, 0.028903393340962272, 0.039834358396806886, 0.03542053899062531, 0.05748659957732473, 0.018466026888095906, 0.034045199397951365, 0.051232477849615474, 0.03641043337328093, 0.03323199553415179, 0.07086526775466544, 0.01995241891459695, 0.08511961251497269, 0.0023377749353780276, 0.05832062768084662, 0.02791246758507831, 0.020744335438523973, 0.01861226136263992, 0.048162972022380145, 0.042040879638599496, 0.03263437920915229, 0.04516090579064829, 0.020421332413596765, 0.11203654030604021, 0.04466902897027986, 0.015028336085379124, 0.014663961084027375, 0.09647672131125416, 0.10912890240017857, 0.07056135191981282, 0.10535628162324429, 0.170988029135125, 0.1951962722731488, 0.16499412219439233, 0.07581070238458258, 0.09239897012178387, 0.1372721940279007, 0.1485019214451313, 0.09054534815784011, 0.09982431453785726, 0.19838731390024933, 0.10221828786390168, 0.07866655449782099, 0.10662818194500037, 0.1175827905535698, 0.12033796842609133, 0.16191940861088888, 0.12129877401249749, 0.12009722420147487, 0.1108223900997213, 0.09906732730035271, 0.17639344265418394, 0.1120983005634376, 0.10261047431933028, 0.08176586497575045, 0.15855692832597665, 0.17462633390511784, 0.14616159988301142, 0.13616604624050005, 0.07999817268656832, 0.13873770753187792, 0.07995226979255676, 0.13532834047717707, 0.09040130195873124, 0.13022068169500145, 0.09347098081239633, 0.08263843386833157, 0.09227257940386023, 0.2002862620034388, 0.1865136567503214, 0.20746955940765993, 0.10149906110018492, 0.08084323376949344, 0.11313432175666094, 0.10963805472212178, 0.14572028070688248, 0.12478891387581825, 0.0866400059312582, 0.0987134984295283, 0.08634661417454481, 0.12060208139675004, 0.25913276789443834, 0.0794289835861751, 0.134561365204198, 0.10112421121448278, 0.14251200429030828, 0.1192207605178867, 0.23582495429686137, 0.11405402847698756, 0.17136023273425444, 0.08341716136783361, 0.09640511551073619, 0.1627007552555629, 0.11123327019491366, 0.1023412791213819, 0.18370636738836765, 0.17799250542053155, 0.15728969632514886, 0.07330568001738616, 0.09595208482018538, 0.24576326672519955, 0.0800854390753167, 0.07434321434370109, 0.1769288339252983, 0.06753075668322188, 0.09739318463419165, 0.12834146539015429, 0.11503943774316992, 0.08828874424632106, 0.11038132198154926, 0.28283293758119854, 0.10524689499288797, 0.09630693827888795, 0.147090256480234, 0.13749573060444423, 0.08031458035111427, 0.1595386192202568, 0.10697985307446548, 0.11799292426024165, 0.18752350684787544, 0.15023228073758738, 0.1018845843417304, 0.145727758162788, 0.11973628428365503, 0.19087287783622742, 0.10483979433774948, 0.1097071702991213, 0.18399116210639477, 0.22176504374614783, 0.12935058266988822, 0.15367994430874074, 0.10946800027574811, 0.07416891226811068, 0.0999210872022169, 0.07296434297625508, 0.08848252027694668, 0.13250859321228095, 0.08490661358726875, 0.13131424944315637, 0.14175946824252605, 0.2561776121812207, 0.14949782086270197, 0.14390743869755948, 0.1250165080917733, 0.13011590231742176, 0.0863110250128167, 0.13688979883279118, 0.12019037348883492, 0.24442316006336892, 0.08652562528316464, 0.08817684703639575, 0.16918965349239962, 0.14640847806419643, 0.1107113410585693, 0.12673495230930193, 0.29465516177671297, 0.12027410471013614, 0.1131157163264496, 0.1139844786375761, 0.09486398606428079, 0.18538715291236127, 0.15956722625664302, 0.11317417211830616, 0.15857345743903092, 0.08359451685100794, 0.07462820583688361, 0.11223096773028374, 0.08915378140019518, 0.12858790930892738, 0.12699597116027558, 0.09921700534011636, 0.1149488804595811, 0.2369856291583606, 0.07470686840159552, 0.20775314633335384, 0.08704110155148165, 0.20221886544355325, 0.1863181979528495, 0.15620024049920694, 0.12327510224921362, 0.17461543663271836, 0.12546313341174806, 0.1334224170339959, 0.1835740123476301, 0.08575262461921998, 0.15059315280190536, 0.1412961102489914, 0.09136199897953443, 0.23093051835894585, 0.12460285957370486, 0.12214901910296508, 0.1488957703113556, 0.1268328106296914, 0.26765964605978554, 0.19393925900970185, 0.18298465040113243, 0.17329420681510652, 0.17891785076686315, 0.08840968632804495, 0.16893968119152955, 0.1380143892019987, 0.15688740648329258, 0.154499031071152], [0.04065367925379958, 0.032806347124278545, 0.018629384193835512, 0.024278863366427164, 0.038368071362908394, 0.0387900285422802, 0.055785885479833396, 0.013337051080140685, 0.03834720980376005, 0.053431446996650526, 0.06492112457220044, 0.026670872333592603, 0.03758568316698074, 0.012406511548241335, 0.019598859761442457, 0.02658363987159516, 0.01053085076689188, 0.01709936066929783, 0.022897903807461262, 0.037848601916006634, 0.0279643822993551, 0.05929307692817279, 0.014862037330333675, 0.002919272661009537, 0.05620056537113019, 0.04283902341766017, 0.10402402561157942, 0.040160299478364844, 0.039037843101790974, 0.015199715371376701, 0.04026555722313268, 0.04071696621498891, 0.04706262570938893, 0.01949743743586753, 0.04609111962573869, 0.012366941082291305, 0.061744875008506436, 0.02753565164415964, 0.043750974482723644, 0.02172246911296887, 0.008527027443051338, 0.024635833854387914, 0.07772457825818233, 0.03683720136593495, 0.013480066754189985, 0.036508298479020596, 0.06512872914650611, 0.016446034922929745, 0.07369339492704187, 0.04334033187478781, 0.06610383146575519, 0.005515806501664753, 0.06323026280317988, 0.02968301311401384, 0.013695243779303772, 0.049145538226834366, 0.0193489281726735, 0.029637853215847696, 0.05960687901824713, 0.022428201511502266, 0.041610681651426215, 0.04241339875651257, 0.04662882809394172, 0.027733066318822757, 0.057934283411928585, 0.049560883082449436, 0.015138206171936222, 0.03765717022387045, 0.029248899979782955, 0.038862964271434715, 0.027222397471112863, 0.036360374452280145, 0.01730984732109521, 0.05104875431529113, 0.033139358540730815, 0.021488325337746313, 0.048906432664287944, 0.082352058163711, 0.08058710037065403, 0.0258806012570858, 0.05224851279386452, 0.016545542083414536, 0.06094238521265132, 0.03089918874736343, 0.030508851299860647, 0.07202176284044981, 0.032615583789135726, 0.004037164617329836, 0.010277608775400689, 0.010576194717681833, 0.04335433683757271, 0.019614091176273565, 0.039722562967134376, 0.08299676142632961, 0.05383130429046495, 0.02255875164909022, 0.0059201344930832935, 0.12565962358244828, 0.08404184106205191, 0.040589523767786365, 0.020338734345776693, 0.04924172395840287, 0.03807499173230358, 0.05020521315080779, 0.01796818065590092, 0.02052151471642511, 0.041163265838154724, 0.003010664542671293, 0.03750270511955023, 0.045921787819159884, 0.03454129670613578, 0.036276080046913455, 0.028739438924406255, 0.014301485980727842, 0.026168885341446315, 0.014553308985861284, 0.040533792294029675, 0.03050790474350963, 0.051873886824718544, 0.02486918374363865, 0.07755857466586999, 0.03204411141840475, 0.03053780099643128, 0.012076854639287506, 0.02086617997182267, 0.044866153571222506, 0.04239309698875461, 0.025933303071984222, 0.036304547983620844, 0.035619553311594894, 0.022198843104498725, 0.0737337474046009, 0.025951328354754617, 0.021175875228696635, 0.03394124783309443, 0.014642799273133278, 0.035390496852674654, 0.013149202901071735, 0.04157951653801969, 0.020086702691125016, 0.023913212719240358, 0.0360446215740272, 0.05792308758412089, 0.05774019525519439, 0.04577717843598553, 0.023314843220370154, 0.05583765770175627, 0.016939055074804595, 0.01411615516657808, 0.037748680849160464, 0.06866692964519773, 0.06760709865817002, 0.021544180644143904, 0.04893745528534055, 0.09545275089996201, 0.07190014222370726, 0.03206432158393519, 0.028700636899364845, 0.034494460826473575, 0.03644849579515202, 0.03096102364361286, 0.019349778037784354, 0.05647702767912831, 0.024703044444322586, 0.028915311808564832, 0.012345107521728745, 0.013313069956244102, 0.029123859546546425, 0.013584038675097483, 0.009035686978937259, 0.014365439602573003, 0.02806782835562314, 0.03471056065921273, 0.02556516389761652, 0.023184717167168856, 0.01972574072091707, 0.026591731401692544, 0.009396981431304343, 0.05165398719587496, 0.029659274566386427, 0.044366663587944846, 0.04698384440104876, 0.006446472410711327, 0.030709409287997654, 0.03304429578461817, 0.0626480933278799, 0.00791932808767472, 0.05560916442690151, 0.013916327451754893, 0.02067496201821736, 0.01611323045965816, 0.0383847361829664, 0.024877305807811872, 0.014290966991601246, 0.036893187290323634, 0.03496340655588678, 0.024854468015421714, 0.08382247747587306, 0.033629386353173425, 0.04337575140276125, 0.006739593601586031, 0.03173605312726327, 0.10164543467440776, 0.0037017647576119217, 0.04122046973290188, 0.03364154230803251, 0.057494769138949256, 0.028813151576157128, 0.018893687154299448, 0.09158932178148202, 0.014388255342575056, 0.033765500477914295, 0.032248486166021655, 0.032795643234359365, 0.06077177436756236, 0.01870156335644424, 0.00517988544223564, 0.015271821591470922, 0.06002339095409427, 0.03041519989658679, 0.02152650480690811, 0.020303576053785424, 0.018142487820503966, 0.04005547260333385, 0.06577355454542808, 0.046205188147723675, 0.0022148292669693804, 0.018757606956309507, 0.07964323101831333, 0.06842325414930071, 0.04013578061546598, 0.07016039200659309, 0.06066824349441698, 0.04218241525813937, 0.08515172757740531, 0.021077039817880307, 0.027424166644258157, 0.035135136983756504, 0.028588013656969582, 0.0019117770799701767, 0.04469659445541246, 0.06924272089132241, 0.03357003150241716, 0.056708862738949914, 0.07214994489082269, 0.02879904822579452, 0.018122528712930422, 0.03676569056031959, 0.014033241579974336, 0.046544876348759444, 0.07751832396856376, 0.06064984162471124, 0.014730820532089897, 0.014274102003712739, 0.03993714627410684, 0.04940511179821832, 0.08541303819843701, 0.01424622948148421, 0.023738096401627575, 0.005789194197859615, 0.04226598023836102, 0.02528545310321663, 0.0451582900381514, 0.022757701509233032, 0.04765715470005359, 0.04112589212932757, 0.03852888076965298, 0.05966905996735607, 0.07463721678193126, 0.03742035810968705, 0.0301605660601386, 0.03524490698639836, 0.04343774236206498, 0.04756398166396788, 0.02493121032603085, 0.027334847687078372, 0.02103523866805647, 0.0346926982248468, 0.03695007905896221, 0.041463992558419704, 0.04188271651842764, 0.006187460751139692, 0.026273734268865416, 0.02369460230693221, 0.029096548512045826, 0.025788714044860432, 0.035872260108590126, 0.02258248850038009, 0.009482470058303858, 0.012768009561114013, 0.02038187729859991, 0.042721816671213934, 0.04246574094785111, 0.04314475094101258, 0.0675353164385472, 0.023294354855482067, 0.05149441611553941, 0.029741750497903143, 0.06978820876351424, 0.027867109215419208, 0.027745809206472974, 0.017221071191930344, 0.07775670010596514, 0.05734483325587852, 0.06043843046895095, 0.03471349871584347, 0.024419518586780344, 0.050545159195150645, 0.05480093422478863, 0.01812988063985748, 0.04146117324541722, 0.017686783701979687, 0.049016972804175954, 0.041915781529886384, 0.060308633505233696, 0.030050582318965877, 0.007831991300918162, 0.03680043833862458, 0.006702048562666667, 0.03696670995226928, 0.014533483888953924, 0.09150319533156497, 0.03952996080209102, 0.03925394632720521, 0.019096095846699815, 0.03023922523217542, 0.022525746009445617, 0.05452464155054518, 0.018350557191297412, 0.011811270943975874, 0.045359604592834196, 0.06906795062656913, 0.02648158141944025, 0.05862982251814433, 0.02507723106204399, 0.02723641600459814, 0.024721442921353236, 0.013510759437589772, 0.020626256774578775, 0.023030141800908104, 0.02473562939225563, 0.012950320894430791, 0.008576452781978463, 0.025583048384370546, 0.019142156500103216, 0.042564298159309795, 0.021063837222754955, 0.03702611569315195, 0.041583346868199964, 0.0652946513146162, 0.03420486547318952, 0.00735172930373145, 0.06257728141333375, 0.11766071351511137, 0.11978296749293804, 0.11096061446837016, 0.20841291307338647, 0.11679335577147347, 0.10869656024234635, 0.14328994468918868, 0.08450086321681738, 0.17347112803586892, 0.181013696161764, 0.13994175435176917, 0.11988070367702416, 0.055126386761133156, 0.0672683332647596, 0.12821014172264508, 0.08888722570346934, 0.10150316623704773, 0.20029175813708985, 0.15506847122950213, 0.1206301591758217, 0.17584437211709364, 0.11600632300334317, 0.1491137429007462, 0.14858456701040268, 0.14780822795416626, 0.2024449533117669, 0.09117685391434602, 0.11310469691774674, 0.11076643810208354, 0.14808133829917225, 0.10418527945876122, 0.13311329005020006, 0.17193427336003098, 0.12369322909840516, 0.15254599015627587, 0.131326680204698, 0.07924704120627471, 0.10891188654516425, 0.05255234720451491, 0.0833286057625498, 0.10335496972714152, 0.13836580248815672, 0.12139694445899554, 0.08871375144060169, 0.11529163563890116, 0.09071453407938991, 0.09319958037563733, 0.2512400214161192, 0.1339832805097103, 0.1788237786718777, 0.08198087236710958, 0.08616788805063282, 0.14425133381571087, 0.09150780258434159, 0.13418728884841713, 0.06637008182172265, 0.1357423418334552, 0.20343687651412828, 0.10626832089786019, 0.15689271262713841, 0.17941491838012422, 0.10040270457310335, 0.16455349512398243, 0.1576673417751278, 0.24357526270406588, 0.08805359115025826, 0.10936763137578964, 0.1146484115826232, 0.07216195496065275, 0.06545802219105618, 0.0744627925700375, 0.0694493619459016, 0.16714034202907765, 0.17623805813491344, 0.16638591965394361, 0.1218347352530275, 0.121779665350914, 0.15468302262680872, 0.10470688968364682, 0.11934122762509755, 0.12010717152484826, 0.1174536110567195, 0.13842129308198178, 0.09132806544325181, 0.17402178634490284, 0.08466700930148363, 0.12281851603516511, 0.19534895622304507, 0.06286014230655772, 0.13765572916184152, 0.08475177868136338, 0.07503525220922061, 0.08657074786190476, 0.1654175958995308, 0.1307246025119509, 0.11019064007060868, 0.2129663580230304, 0.17894283442624978, 0.12769699282944202, 0.18450352389897617, 0.08844623222414937, 0.15290781216961996, 0.13800387190920965, 0.17579204349645547, 0.07625251689127513, 0.10898791639400379, 0.06895773618349008, 0.15316418984106608, 0.10400193929672241, 0.1540013663470745, 0.0948173367817487, 0.1525667668985469, 0.11544649090085711, 0.0684916911912816, 0.11457935028842517, 0.1278958578727075, 0.15063387847372464, 0.10363212414085865, 0.08312349819711276, 0.10978280659765005, 0.107280708716384, 0.1215177101216146, 0.09574293997138739, 0.07500434493912117, 0.12525460602981703, 0.12042952994150774, 0.10877303113894803, 0.08450857137462922, 0.11402681922273976, 0.08495808725378343, 0.12092627185795989, 0.16983146619583878, 0.10824635225747313, 0.23336561769247055, 0.13232913427054882, 0.14842512485172066, 0.16044550841408117, 0.14186753172959599, 0.10006364062428474, 0.1401414064956563, 0.10577062224703175, 0.19882340835673468, 0.14798339855458054, 0.15116078805710587, 0.17059291819376604, 0.12006582160081182, 0.16533197835087776, 0.054127644281834364, 0.08762068580836058, 0.1611385369407279, 0.1313222697270768, 0.12934543937444687, 0.09862660523504019, 0.27308977182422367, 0.19586484639772347, 0.08515161901180233, 0.16912950814834662, 0.16279792147023336, 0.11335801439625875, 0.11230431058044944, 0.13580317928322724, 0.10206911872540202, 0.11456501962883131, 0.15279347901897772, 0.11554422708494322, 0.11182677120502506, 0.11984539271465369, 0.143875656117286, 0.09360917125429426, 0.15864352296505654, 0.12253083075795855, 0.08653963703129973, 0.09315871899681431, 0.09109783172607422, 0.07840817514806986], [0.05221205510731254, 0.05668011321020978, 0.011138322813037251, 0.045140485279262066, 0.023262648610398173, 0.034615158635590754, 0.057652677808489115, 0.02953645633533597, 0.02091929399674492, 0.09639519532876355, 0.0349364381815706, 0.029605049440371137, 0.05116510271493878, 0.07928428599344832, 0.040067285898008516, 0.039502317285431285, 0.0301669917867652, 0.10026626475155354, 0.051422491403562684, 0.03215100782524262, 0.028610513878187964, 0.06772916032267468, 0.015986364767221466, 0.0414316162600049, 0.02987629042140075, 0.02929206159231918, 0.024982519447803497, 0.04528631602546998, 0.008720174132447158, 0.04739954209487353, 0.00886076404380479, 0.05651562275098903, 0.02110271219031087, 0.026451720789607083, 0.03030470386147499, 0.009707598647634898, 0.030078873836568425, 0.05737234106553452, 0.07580176607838698, 0.03209211437829903, 0.02942015543313963, 0.07161638566425868, 0.03194339307291167, 0.030905281991830895, 0.05010504102600472, 0.03800656486834798, 0.016817914521587745, 0.027743308804929256, 0.0497044305583196, 0.03437033641551222, 0.007422153605148196, 0.052881345086331875, 0.02600792156798499, 0.08211657937083926, 0.04706124828330108, 0.03319176519289613, 0.018124784841867428, 0.03899252714057054, 0.07435754500329494, 0.00926188426092267, 0.08998340581144605, 0.03550576298896756, 0.02091492253488728, 0.03153281492580261, 0.015280160786850112, 0.03969009167381695, 0.03156003775075078, 0.00882437251441713, 0.0069503168924711645, 0.03327617494921599, 0.012123406382410653, 0.022371603209259253, 0.013599845148356897, 0.034535189890967946, 0.02801737418797399, 0.05253952628533755, 0.009997964138165116, 0.09039759037217923, 0.018831063461090838, 0.01612687240620809, 0.06504497756915432, 0.017107723613402674, 0.04100267016994102, 0.03263791437659945, 0.042607642976301055, 0.008684428907664759, 0.03266611089929938, 0.05461461190134287, 0.009303821117750235, 0.06447384107325758, 0.04340403274233852, 0.0480036011098751, 0.03201071053211178, 0.045299856191767116, 0.057918887452355454, 0.04407768230885267, 0.004220114621732916, 0.012787632793853325, 0.07909635893468346, 0.011163767028067793, 0.033557675379727564, 0.011422164189363164, 0.029455510500286306, 0.031100140285811255, 0.043932910077273846, 0.01801063319934266, 0.03028694660003696, 0.0262762516337846, 0.05132163395839078, 0.027946160241429294, 0.03157642097877605, 0.031198636429118257, 0.037603274187339206, 0.0494770093687943, 0.014886430664254087, 0.06438578079853739, 0.07161459433180944, 0.05002152015055929, 0.015810970250251036, 0.022303368031446422, 0.04799089214897581, 0.03487650318337338, 0.08481634128838778, 0.07501461795930352, 0.009762901796161063, 0.05508906054975731, 0.0622116799599358, 0.038864049927464554, 0.0721448083807315, 0.08573909463094813, 0.0465102099946567, 0.03230089281818696, 0.046828975568392446, 0.026139947519238507, 0.04609900759533048, 0.043772657069244554, 0.01504631556703576, 0.011793930133405541, 0.024115855506222163, 0.010022219220575477, 0.04495761330638613, 0.04135198678289141, 0.0021181670765924665, 0.08073358251047985, 0.030305368825793266, 0.014319507870823145, 0.053804210387170315, 0.043059021434081454, 0.09034099376627377, 0.01189341354516468, 0.03969785411443029, 0.03959755306797368, 0.01587637254436101, 0.03563153284734913, 0.013941118576829987, 0.06922689745468752, 0.026189617978941118, 0.04235775549230831, 0.037656603647129874, 0.035831754960651906, 0.0203097388480923, 0.005317752731830946, 0.059373605464185984, 0.04019964433142117, 0.04022526581372533, 0.04689846773232732, 0.07795219283018794, 0.014580849025930678, 0.014474300368289863, 0.03274123151121395, 0.03567582082801631, 0.02544074093124696, 0.030658427559371506, 0.059074025468102524, 0.039923480578831265, 0.01646971918775567, 0.019949467287265828, 0.016403017499084984, 0.016761261936543242, 0.046246663600738556, 0.03660118992307356, 0.06383647955954075, 0.046662473252841404, 0.035645184971924336, 0.025761601481852785, 0.04720592891265239, 0.07515772778008666, 0.01736064923794142, 0.07452194725296327, 0.08080316627664225, 0.06124151059027229, 0.024538786383345723, 0.018664250715768764, 0.01794925801056836, 0.015749520422624688, 0.010173210225600218, 0.026798260497993658, 0.06012175817574773, 0.02296176243440381, 0.022955821860315542, 0.04878925984459264, 0.04142106504046491, 0.026283165905624628, 0.0274898369597005, 0.0033932138924553457, 0.05903566109814814, 0.023224151926115155, 0.06649502726005656, 0.01748246662983937, 0.010757655337718981, 0.031325712467410734, 0.0789802683783429, 0.04705730260216764, 0.03071522094043238, 0.06609833533210413, 0.02587481844238937, 0.025725506811535785, 0.05323650388579283, 0.02398373286372849, 0.04912194556423596, 0.06516581108527524, 0.04956414344321404, 0.009974784533759313, 0.041657032378550084, 0.04353328009269067, 0.08383698455457177, 0.02701402106322348, 0.041901508545769114, 0.08831254725477525, 0.01252431031649134, 0.0314723710263414, 0.05707957356103829, 0.012221660797617264, 0.006664676126092672, 0.05365110235288739, 0.016112275421619415, 0.03651382175407239, 0.058774126560560296, 0.06641785068703548, 0.01841260412974017, 0.045326814388058016, 0.04201123783630984, 0.046088958491704295, 0.010834753879212906, 0.01674913821209754, 0.02255567958179329, 0.009624216023699513, 0.04932706330769828, 0.04089244894151177, 0.01268142510005938, 0.010062201048380561, 0.04172697916094746, 0.011306948095027889, 0.005070096355796392, 0.03585872672764318, 0.020621181332639286, 0.03543818090111017, 0.03029861400968262, 0.05735254819904055, 0.009648576279037764, 0.0976685748568603, 0.01711734354362956, 0.04613697841497404, 0.027837189213771905, 0.03279443204935108, 0.08458840101957321, 0.009094555828986424, 0.03478915537042277, 0.0457651446174298, 0.04339032633496182, 0.05300005818051951, 0.013271734451076813, 0.0358903939569635, 0.011035987009693469, 0.015932499264766063, 0.03091969746830208, 0.016272799843656163, 0.04443551114361201, 0.029436348671359674, 0.010023682311709439, 0.031521754804998636, 0.03306212429223316, 0.06425071161772523, 0.08321945661945002, 0.025142280517944267, 0.051020031927951744, 0.01215359355722155, 0.05667345678167684, 0.012277625517786613, 0.024539090027766566, 0.02476726608750011, 0.01941910565697721, 0.010397646709212234, 0.05033798549058182, 0.026403398918254033, 0.009056614695249923, 0.05411846709570714, 0.08144782882715974, 0.044221993136618815, 0.04352856766698616, 0.04447415710559913, 0.009571825486740895, 0.05422920401075056, 0.04306910785713366, 0.03537885997710483, 0.03162496676668525, 0.049004236701875925, 0.02830071175204856, 0.04978070128709078, 0.05995254511279719, 0.03063395619392395, 0.021942877643076435, 0.02753655918474708, 0.007122828059696725, 0.04422201009999428, 0.10872141498007945, 0.04807750714410629, 0.04759317224047013, 0.028994825934725146, 0.13555065569068703, 0.023684183401720862, 0.03688952659389802, 0.06444444015089955, 0.03450982625197087, 0.06214262545108795, 0.017243903895307864, 0.03346256173348852, 0.03608074338574495, 0.027006241659234678, 0.039611530889357836, 0.005013336901486452, 0.0410173367043691, 0.00812843900972179, 0.06108411082199641, 0.04828486744580524, 0.07179200409778527, 0.06096449188355889, 0.040570297478032966, 0.010226476920901664, 0.024633282562717795, 0.002885424789773034, 0.019741900032386184, 0.07484877043004547, 0.01385482249315828, 0.048615978964205296, 0.02940362971276045, 0.04873128241992422, 0.054986567835190465, 0.013041903614066541, 0.03670715334426079, 0.02262952963688544, 0.03702237017984901, 0.0877801211816924, 0.09146369780812945, 0.19044955340879305, 0.09086185760263886, 0.15754832673285687, 0.0783362640067935, 0.2491320302443845, 0.07339488701628787, 0.10582807380706072, 0.20006960577198438, 0.1033301760575601, 0.09572368993290833, 0.13413998138691696, 0.1293437158954995, 0.09766130774681057, 0.11499449158353464, 0.10793809379850115, 0.1613387047712292, 0.11981553717383317, 0.11648846284619399, 0.12650537677109241, 0.19129587656685285, 0.15187738889030047, 0.18355843318360193, 0.14467277191579342, 0.10986475327185222, 0.12926766569060938, 0.15977464084114346, 0.1916847585567406, 0.08557593410036393, 0.10274322291037866, 0.17008191347122192, 0.06808576440172535, 0.09924465564212628, 0.10489141728196825, 0.1390025397496564, 0.13169550469943456, 0.22627221260751995, 0.12787067065281527, 0.12033917621842452, 0.10163748902933938, 0.1490731936480318, 0.0804370152098792, 0.14203493988939694, 0.16861148737370968, 0.13296965775745256, 0.10854917565094573, 0.20569761948926107, 0.08127077189939362, 0.14768595594380582, 0.07433492264577321, 0.13627799094787665, 0.20334044311727795, 0.284452844943319, 0.12620664494378225, 0.21520282301519597, 0.08500335911022765, 0.07124621088483504, 0.13459698829267705, 0.08481894686285939, 0.21710523164698056, 0.12071615670408521, 0.1255869117698499, 0.0960349610873631, 0.07852762445275273, 0.17309197623814854, 0.12700468354991504, 0.1400851152305092, 0.07747679762542248, 0.19839082871164593, 0.1371835230716637, 0.12260944582521915, 0.172801780381373, 0.11452163409973894, 0.08116511721163988, 0.16392895792211803, 0.07625325649444546, 0.12441406399011612, 0.11457550978021962, 0.10068570117333106, 0.13958142511546612, 0.09119096065738372, 0.13471782180879796, 0.08263181815189974, 0.18941927940717765, 0.1480836317475353, 0.15932949472750935, 0.21165036649576255, 0.11602739830102239, 0.1295963751950434, 0.16331720432000502, 0.10788548019315515, 0.1667981975312744, 0.10401875339448452, 0.12482041147138391, 0.095869948156178, 0.10221564836267914, 0.08500985269035612, 0.15979031500007423, 0.12780752618397984, 0.0686827055843813, 0.0688550059816667, 0.2289164907165936, 0.1137696069532207, 0.13517819424825056, 0.14611289463937283, 0.1252162145184619, 0.12231880213533129, 0.11598614337188856, 0.1513126034821783, 0.12362458849591867, 0.11591847985982895, 0.08328146114945412, 0.1739464689578329, 0.07832172300134387, 0.13155419299645082, 0.08574848555560623, 0.1272071719701801, 0.1375351534890277, 0.1022171750664711, 0.20527658851018973, 0.17696794468377317, 0.1447330801082509, 0.23903928324580193, 0.0898245404075299, 0.1131391597113439, 0.14291597689901078, 0.11236285458185843, 0.1768654723252569, 0.28204000155840603, 0.12267500587872096, 0.10246862657368183, 0.10960823989340238, 0.15307796161089623, 0.10045170158679996, 0.13975099101662636, 0.08896746246942452, 0.05775230710527726, 0.10540556362164871, 0.19074810881699833, 0.16016753975834164, 0.11117705356861864, 0.10322913540793316, 0.2518487216106483, 0.08432260528206825, 0.1297255546918937, 0.11397335066327027, 0.17649880557187966, 0.15947504048900946, 0.09228078289223568, 0.09104867186397314, 0.1381344220467976, 0.11432593102966036, 0.1442316020173686, 0.11438978117491518, 0.18774008165512765, 0.1192868769701038, 0.08957054439399924, 0.12343953842563288, 0.08722565629120384, 0.13763584808579513, 0.0990482536809785, 0.14142144923763617, 0.21848793673728192, 0.08988022099116019, 0.1605247613042593, 0.18654550718409674, 0.060724371911159584, 0.10835940976228033, 0.10224869980343751, 0.13114472425409726, 0.14183048371757778, 0.06765363258974892, 0.1726344536457743, 0.14485281439764158, 0.08860067357974392], [0.08961349566067968, 0.03442082281357475, 0.031767398052449734, 0.0409641192028565, 0.030845628585666418, 0.04263477759169681, 0.008625004507069076, 0.0246899351477623, 0.029693021505538906, 0.03317380097827741, 0.017741438001394272, 0.04537537035399249, 0.036526330547141175, 0.003607580280264041, 0.08717148205531494, 0.02848829615062901, 0.1027106735855341, 0.0030618905439041555, 0.047181087745619674, 0.040524720280830345, 0.012404179932283503, 0.07153210482959237, 0.05822480496551309, 0.03507006886814322, 0.010838164365850389, 0.0491819144891841, 0.03973591314362628, 0.025210564889545952, 0.003519859485095367, 0.05378596118784376, 0.00792218980911587, 0.027568879504022852, 0.0831463241151401, 0.030876864945249896, 0.03043282145102109, 0.014364594826474786, 0.07091981518481459, 0.04828779532441071, 0.03381684183010033, 0.049269879769001684, 0.028655365042920624, 0.017608387462262596, 0.01553585144158985, 0.009161494156744863, 0.1017111304349133, 0.047748203921530924, 0.019247237825766206, 0.035072450526058674, 0.02582782819601042, 0.08212613314390182, 0.0257018785258489, 0.03212343894743493, 0.10340986999550036, 0.05916599410453013, 0.039309023014668903, 0.030718138641012565, 0.03391305809574468, 0.10533133189060859, 0.016692054757316197, 0.00791994301003537, 0.02822822724868144, 0.04045780315729124, 0.02839898906781205, 0.03382687057767596, 0.06318282642002616, 0.04746749737699117, 0.038240286255521436, 0.041315434101436815, 0.05359434289857745, 0.012699419848753937, 0.007445943891070783, 0.011331824036980314, 0.029466570621090274, 0.05633920703881553, 0.0241273329260626, 0.05972523588154997, 0.03979608902175512, 0.021244578595672334, 0.021796536299266984, 0.00219502198160626, 0.051683554359312565, 0.0020603749768010205, 0.04060785439131515, 0.04144460002758673, 0.0496428331493267, 0.020833028447149054, 0.038166085058557134, 0.0048780955424133155, 0.05114768132833498, 0.06895650124975614, 0.02235894344214882, 0.020066562075433985, 0.03826618593718324, 0.020611130532675555, 0.020726021778370653, 0.03301653352433017, 0.014959887169035417, 0.02797879947216383, 0.030338230276746408, 0.047914346613522084, 0.012104831486275154, 0.06469347607344389, 0.020741819769942334, 0.04172757627176387, 0.02223061889942203, 0.03471752582117915, 0.05177247298083135, 0.017582284220095192, 0.08875075195516859, 0.08045489460762058, 0.010740395103182112, 0.03815630736893841, 0.00857134341328804, 0.014853206197065967, 0.030595591823969568, 0.005231477852378572, 0.015228812649313892, 0.030768628431750194, 0.02221420852999602, 0.033778185690087933, 0.01670348976871797, 0.024388054917965616, 0.030620500844504153, 0.032527920457401445, 0.0736306304378169, 0.04235274790387068, 0.045974655875137875, 0.031758950291467566, 0.027803125059498206, 0.012456944511671151, 0.0563517226172345, 0.05808893511337893, 0.04271568271464535, 0.05563477573118039, 0.0158204765258623, 0.03777318274868386, 0.038838418267135105, 0.008770009985060563, 0.02597099738860769, 0.010653121080914778, 0.04148259798863104, 0.07761294567691428, 0.03665245324373245, 0.03310270407902343, 0.061022194501544745, 0.05945086346140929, 0.017200837277674248, 0.023300882362361466, 0.019378106874812926, 0.030261572783014605, 0.050849387156111855, 0.062146038482231755, 0.03800616792536207, 0.025823331205174327, 0.03824549740446465, 0.04888180862846119, 0.004975930114077138, 0.024138106365821192, 0.026995390187948942, 0.03505968049700771, 0.015475258264424545, 0.03384005790576339, 0.07921530612345253, 0.01932811241463891, 0.004199851021569754, 0.027163984087694968, 0.029043483680912426, 0.015383252308570912, 0.04209313701306071, 0.013932152584727322, 0.05505592429212161, 0.07154741257961307, 0.0553330040669867, 0.028679005202970335, 0.026202274353376458, 0.037418441248259375, 0.055089535524270365, 0.044012264747704775, 0.013458461351027446, 0.037573829160204957, 0.003381471419873248, 0.02909370545031769, 0.03708266480160611, 0.0721049512337361, 0.063649902785463, 0.01775711724933769, 0.03504823021856802, 0.038927319925278425, 0.0073984718848285926, 0.023076344946665422, 0.007655345735007099, 0.02065395118136491, 0.11430400077785764, 0.017996312717774084, 0.03285233144249235, 0.057381942336048396, 0.017163509369960854, 0.06696821044066123, 0.01891089989138501, 0.011602002262536968, 0.011806260811031928, 0.0075017830822616816, 0.015381452494433947, 0.030645538786692277, 0.02335514311146523, 0.011253526184840925, 0.011572507193445094, 0.07224276848137379, 0.014766911809731807, 0.039730976801365614, 0.031982276522155316, 0.03170793802876558, 0.05723378421472652, 0.025106194329314997, 0.023855696698384624, 0.05483116974521961, 0.010126232701752867, 0.024029288008542996, 0.04790947812476328, 0.010989600659481116, 0.05677802920607584, 0.034027801760073216, 0.049405047337391546, 0.020885107706167867, 0.03159782197326422, 0.03050421690568328, 0.04434151029480355, 0.02742683667955654, 0.03838855633512139, 0.05024315682905061, 0.030363671947270632, 0.009566175834541875, 0.016197611378239732, 0.04040068068674632, 0.028161191381514072, 0.028611199198556796, 0.029301598402006284, 0.07111738422619444, 0.07621569958116327, 0.03184941936550396, 0.0300013715667384, 0.04157224603529487, 0.028465005436113903, 0.009495646360197237, 0.055820738431066275, 0.0427293619806213, 0.03567785643307226, 0.022211626704250063, 0.06760813003139836, 0.027057666131960492, 0.03298157200749431, 0.036253763030150106, 0.02827906987762877, 0.03635623538866639, 0.029933772515505552, 0.09711900898920638, 0.02167301408813468, 0.01792927345793162, 0.02912803253691111, 0.027452790644019842, 0.07844129444233008, 0.04868738798956786, 0.0906097614871604, 0.023750221822410822, 0.06723102740943432, 0.027578592732814804, 0.05022132496482559, 0.017750727145799568, 0.014000431019147592, 0.022218352682622414, 0.018022543185257485, 0.027294432445030128, 0.009232887915069503, 0.03756102520440306, 0.017308583549622978, 0.02952401539576905, 0.04482461026470576, 0.0186377742793411, 0.010872313337001418, 0.03208605166790741, 0.04803982809452074, 0.06029048269348485, 0.005651329028686243, 0.03697162254580429, 0.12999084831348487, 0.07242009003779717, 0.009699130530602165, 0.034976146050861905, 0.045027448130505424, 0.06919182397957359, 0.04347449860402516, 0.03850716764905623, 0.0107686026520761, 0.024207405147275755, 0.03674830988581691, 0.05457846634089947, 0.02560959945965026, 0.010085491762895669, 0.030246193786816936, 0.08222839515656233, 0.0455179441321109, 0.036964121341173134, 0.0036051248316653073, 0.04355112217100603, 0.030657389400792972, 0.021739059294174825, 0.03927297584180321, 0.026350975302713256, 0.051782725644963126, 0.06679851561784744, 0.014577556434752685, 0.02423918942388679, 0.04450016535286393, 0.009511399398823934, 0.025849035808018277, 0.022286279127001762, 0.05018744571134448, 0.030636419276041642, 0.008534046039650483, 0.036674682050943375, 0.11537136350359235, 0.006657900529847081, 0.03976520210770624, 0.03688208645741854, 0.035224096317376406, 0.04034247934552176, 0.04990385878565056, 0.024263045018804923, 0.03565242833324841, 0.06531685976577656, 0.04475320463201829, 0.04301467238526259, 0.007737016754357943, 0.016853671620732973, 0.026740593503096273, 0.032641995764736614, 0.06969461164304189, 0.053794205388320346, 0.07805521480206933, 0.015984924576644386, 0.0198388830426016, 0.02715153805911541, 0.015927381414387907, 0.017571274989417622, 0.03558594547212124, 0.019057928251900842, 0.009629315214364656, 0.05998037861926215, 0.04079280946669834, 0.01578033439415906, 0.0033690828547280815, 0.06683956698647567, 0.23355810450656073, 0.13160654875848973, 0.18030449136027268, 0.13783366818513187, 0.1346748298300164, 0.11857616582087108, 0.16404772869178227, 0.22577912120946816, 0.15337205225867884, 0.11906144049550806, 0.12713485370789254, 0.1437245870807341, 0.06709272161658321, 0.14525301435164042, 0.1187554754848991, 0.12938514724373817, 0.3259071819484234, 0.12401959087167468, 0.08044758678546973, 0.14978306341384137, 0.045460590959659646, 0.17633739566164358, 0.2120636078928198, 0.09628480446657964, 0.05995206335293395, 0.09014902263879776, 0.10621734934725932, 0.17359901831618377, 0.16471729347748415, 0.1111971992733223, 0.18736791876809938, 0.19436985733253614, 0.30100831229771885, 0.2173011518482651, 0.1734237391501665, 0.10474471122558628, 0.16849788704088756, 0.19292342423328332, 0.11011205214474883, 0.11417011224797793, 0.12069524425481047, 0.14252009242773056, 0.10202149235244308, 0.10591135040989944, 0.15124339291027614, 0.10254353005439043, 0.11292318201490811, 0.15582326001354627, 0.14407921662288053, 0.13157339553747857, 0.15857771863894804, 0.10857651382684708, 0.1843048624162163, 0.10358705584492002, 0.13618507236242294, 0.10751439617680651, 0.08434573654085398, 0.17224483883806638, 0.10355068636792046, 0.12283758286918912, 0.08242035271333796, 0.15916041737156256, 0.14591510168143682, 0.14758078301591532, 0.11861419092331614, 0.10033956010426794, 0.13277303187974862, 0.12601311318576336, 0.14663850143551826, 0.13130886187510832, 0.08285371945904833, 0.10277089356843915, 0.13112905009516648, 0.1109824293692197, 0.0776150491354721, 0.15450534144682543, 0.07205626634614808, 0.07626461517065763, 0.09118662481861455, 0.11882640953574862, 0.12519469138767036, 0.069472153937178, 0.08221393557531492, 0.1033422200541411, 0.12492019683122635, 0.13019609158592566, 0.10830709471234254, 0.10992709706936564, 0.16386997965829714, 0.162011322964515, 0.13560991893921578, 0.056771345636142154, 0.14920871066195623, 0.07562423417610781, 0.1002725072737251, 0.0809132857248187, 0.06587914816503014, 0.3024277261325291, 0.10387930766280208, 0.10214361508509942, 0.1222679391503334, 0.16461142844387464, 0.14937853440642357, 0.10249686041580779, 0.08964090169008289, 0.16310741486293928, 0.15261020671044076, 0.09559877163597516, 0.23132979550531932, 0.17832866523947033, 0.09597246801214558, 0.10031664597668818, 0.09188616049609014, 0.12635528482496738, 0.1263007577508688, 0.07445266204220907, 0.05962142002369676, 0.10307909095925943, 0.1342702872518982, 0.10429113770702056, 0.06803850443767649, 0.12545375605779036, 0.1280096617660352, 0.24280414836747305, 0.11645396612584591, 0.11487646720239095, 0.13526409678161144, 0.07239469925739936, 0.11749319678970746, 0.07001758752656834, 0.23128669496093476, 0.15972601702170713, 0.09384000886763845, 0.14411930447178228, 0.08506668678351811, 0.08971878393952336, 0.10465268830635718, 0.13699965365231037, 0.08490909702543702, 0.06744502378361565, 0.1569886031959738, 0.11087411482419286, 0.10727490724197455, 0.08051012057278838, 0.15777058766356536, 0.15005381245698246, 0.14371507401977265, 0.15920935331710748, 0.0925500662997365, 0.09693340930555548, 0.15855112006621702, 0.13308769570929663, 0.11291391322655336, 0.11976962749447141, 0.1433027418596404, 0.1313883318964924, 0.12212981656193733, 0.16898165536778315, 0.1570846973253148, 0.1489940493234566, 0.1564134226313659, 0.14148399659565516, 0.23427319899201393, 0.102106777418937, 0.1069609626595463, 0.0929733771564705, 0.11354281340858766, 0.13483025506138802, 0.14355058356055192, 0.12295518655862127, 0.13557384801762445, 0.15376748889684677, 0.07894279288926295, 0.13039723650685378, 0.13452057167887688, 0.15192754619887897], [0.05188968311995268, 0.00983766617719084, 0.03979446053771036, 0.014876574943108218, 0.030177546398980275, 0.017714104914505566, 0.10069513959544045, 0.037767747683184485, 0.006972342563260878, 0.04239081711109195, 0.017153799533843994, 0.02392208626094673, 0.028861297028405324, 0.04263808544991272, 0.05791871781860079, 0.012725805531122854, 0.05970305457179036, 0.033622875809669495, 0.03583608740674598, 0.030592915003321, 0.05083534148122583, 0.004565327794158033, 0.032650060153433254, 0.025547847683940614, 0.07863066678068467, 0.023816049897245, 0.03326265513896942, 0.04086616249488933, 0.03734751398276005, 0.022100274018677216, 0.03290525717394693, 0.03775441447006805, 0.02778815318431173, 0.08168454255376544, 0.0841481810701745, 0.0800272072000163, 0.04119850555434823, 0.013127395633741148, 0.03247035354641931, 0.08225634401398045, 0.02849048442606415, 0.03872399351426533, 0.09329550487122365, 0.023302402280803238, 0.01855865879250424, 0.02712145690540118, 0.039627317006566694, 0.04430687786745174, 0.011950741272552736, 0.050043609858091385, 0.0320110531922962, 0.058896995681737146, 0.037137358116784265, 0.025696986288364445, 0.0898441161428179, 0.029940011645002023, 0.05761761111872537, 0.03084315193284835, 0.04603104552786265, 0.0432669890246221, 0.05246630896415029, 0.05553229319463883, 0.03195495870230453, 0.019232846098020673, 0.004574612697719463, 0.07822604956371443, 0.037794573565146754, 0.03339921370414751, 0.027854790412155644, 0.009573280944355896, 0.024933128883796077, 0.05428427052018898, 0.012605155219456978, 0.016595299056332027, 0.04239012500537293, 0.04873067852375763, 0.015384300645174724, 0.014084691497763353, 0.02342349024755614, 0.028278072431151356, 0.027214975994346396, 0.10574530610548598, 0.0506991052201816, 0.033470276676650555, 0.031547980183469396, 0.036335136342261515, 0.06815087662211486, 0.04013221152126789, 0.02005412113586707, 0.04082437491576586, 0.05160224550802793, 0.06120725814253092, 0.02073289024909692, 0.02664198031249855, 0.0236991756329579, 0.06754221713968686, 0.01982167878720377, 0.05420779623091221, 0.00581815788921501, 0.06651208563042538, 0.01368565353498395, 0.0416915630256491, 0.026358032066907202, 0.03209138495315399, 0.07860716232763869, 0.007948744277070676, 0.012655394800406481, 0.04566164767103536, 0.04820243561906474, 0.019304675815094794, 0.006917105147814644, 0.049433477954672914, 0.007697155366518668, 0.037136835644819906, 0.010389217607943075, 0.03850985125505498, 0.0406501508717026, 0.0032676620134485085, 0.061695348737495284, 0.031207423457609754, 0.03275592179436769, 0.018588656825678687, 0.05373346632612603, 0.0206444177643529, 0.042958204701010666, 0.09555675674762044, 0.012916057420495366, 0.04322880446644766, 0.09784650709480047, 0.05446096443172012, 0.027933975448831916, 0.033752815265740664, 0.03744040881948812, 0.07233710520501647, 0.04391046413885696, 0.07391313170748097, 0.03951125019895179, 0.04110563446634582, 0.042714837938547134, 0.0422477174683341, 0.011648422539500254, 0.02583286292584879, 0.01060542176544134, 0.03444345874179687, 0.024187965118991475, 0.002911394869443029, 0.00998330523725599, 0.015322194334917834, 0.037765016579734426, 0.053998057663972886, 0.046304111768092425, 0.04654492384621075, 0.03153398200603468, 0.026379774025242244, 0.04275168917540993, 0.0048469143138001, 0.05350807395630649, 0.020400411482634287, 0.01354866664457534, 0.038801736664026976, 0.015279499215206929, 0.06136118381151131, 0.038002978810774427, 0.02839644456149212, 0.03230796315308128, 0.05123892393229263, 0.0446276960096189, 0.03317878142531429, 0.029347148457808152, 0.006454985480689044, 0.05303707905113697, 0.0298413730093411, 0.03588810729395066, 0.08015991507896356, 0.07838627203766789, 0.005858392895398927, 0.07643137193684067, 0.016063875518739223, 0.06419944829706635, 0.028193029940926602, 0.03153593618688839, 0.03121993564335363, 0.09066969648535762, 0.036189051145421605, 0.03031841366152678, 0.05252352642959782, 0.025893512082153132, 0.044586590358189175, 0.04695376833634717, 0.07147886697202921, 0.03348254458978772, 0.015159364590155227, 0.05413053484101381, 0.016862219465630393, 0.02606520858327193, 0.05152309779077768, 0.01716530409508518, 0.0353019649961165, 0.030195351157869612, 0.024924265520114983, 0.024759944694648896, 0.019656363907935362, 0.040596468573702235, 0.01219493754407657, 0.005970579330875937, 0.0432662358507514, 0.03626010733257447, 0.05905278053666864, 0.029065020382404327, 0.015519790517698442, 0.02808013528452388, 0.0675470075969185, 0.04404516691075904, 0.07753114149506603, 0.027118978556245565, 0.05281000391447118, 0.05488538469320961, 0.03143233746024115, 0.05630079856408494, 0.06374710292688437, 0.03315197929207768, 0.012752617842384746, 0.06700570628579174, 0.020645109870071923, 0.047396729567221234, 0.04001451622960823, 0.010718111165000923, 0.0830515870558364, 0.011271636284488653, 0.04725130254934941, 0.0465930455497333, 0.022703118455995406, 0.02209437924570271, 0.016222447456259812, 0.038881372926490645, 0.10651698362614427, 0.019270900038204024, 0.07873006537556648, 0.024795771343633533, 0.009835708603662039, 0.02378525458542364, 0.00945685536134988, 0.036131246747182946, 0.03774908457749656, 0.03333076309146626, 0.024648785391556363, 0.0333674379092242, 0.019146163249388337, 0.03955832356587052, 0.025711710498269116, 0.0435079130610185, 0.0663457020585026, 0.02812706446275115, 0.0627562857366034, 0.03931989314566765, 0.02083485709902431, 0.02145239181949624, 0.011030051524617841, 0.03645818527521832, 0.01803779156346406, 0.03299496968143752, 0.03252233272152288, 0.08321373656924282, 0.05886953536953245, 0.00666451539811013, 0.08255777641066483, 0.0314444085982229, 0.05388709004702313, 0.02146665462558823, 0.07375444950801985, 0.05459800136408635, 0.04657154277499233, 0.02235925387191985, 0.02891331013025982, 0.01857261625783784, 0.08100613645677056, 0.0582157668790647, 0.032598355785012245, 0.07391545229724475, 0.03798097392011966, 0.051047872219766886, 0.04542869981378317, 0.0275376550188022, 0.06197384665054934, 0.045143382623791695, 0.03440289931105716, 0.03930078559954252, 0.05278033157810569, 0.038659013608204465, 0.06282347427414996, 0.07295757119676896, 0.020443417032116225, 0.027196280658245087, 0.038308767402278524, 0.04755690793639847, 0.019391541868182163, 0.033594981235052855, 0.044046798787478886, 0.022477675196049467, 0.033371315736855776, 0.04599443856360657, 0.09525839132922036, 0.02933249549408044, 0.02068503317423165, 0.038756067864596844, 0.036095321710620604, 0.035275671764143875, 0.022414530727214048, 0.036746219997959476, 0.040795723774603436, 0.014218549493567219, 0.04370040666045887, 0.0792298267728516, 0.028724056535533497, 0.038747016207448075, 0.03885349192257438, 0.01123144495899656, 0.03015257291761892, 0.011410590926451343, 0.027632490465683595, 0.0337523436839027, 0.06533945498189755, 0.00806546163013471, 0.00945391136753772, 0.052843241952359676, 0.019083671870508363, 0.008939095822695111, 0.019919508269854953, 0.12367182810391698, 0.004453316505532712, 0.013144033312398409, 0.04618729857195701, 0.05220727143543107, 0.025561065546103885, 0.022905316802539995, 0.020118010296885456, 0.09220237138548068, 0.06863587309739419, 0.045808553895247836, 0.017336981936490962, 0.04868008356009211, 0.03714673547074199, 0.00716568178696824, 0.01754239314634885, 0.017233576592324034, 0.024652707323964154, 0.05803748858826501, 0.04038640770262905, 0.03976182300331337, 0.05060342838987708, 0.06509045298610415, 0.02445178123057953, 0.22010958114905016, 0.09679540885346276, 0.1374596461121525, 0.1591226772538253, 0.09478901473007031, 0.08986115415713616, 0.23614614563328878, 0.10389337369373866, 0.08441728805857045, 0.14544775390199252, 0.07291698123195342, 0.1295628419944218, 0.12224894016981125, 0.12249887175858021, 0.17286234641713755, 0.0909776563889214, 0.12984269697751316, 0.06741576535361153, 0.12523452139326505, 0.20565479035888398, 0.08127679729035922, 0.139016897550651, 0.09940651338547468, 0.14198866380112513, 0.19101865429963383, 0.09375697653740644, 0.11687264937375273, 0.1227664588285344, 0.1327834270362343, 0.11937409586140088, 0.13999824917742185, 0.14458958352250711, 0.13417926856449672, 0.15014622892652238, 0.14926084929278918, 0.11474223940500192, 0.1443951560982636, 0.14941991147186073, 0.2190950491598674, 0.1584225105387824, 0.08416196890175343, 0.06831230010305132, 0.22632352342563017, 0.17405943146773747, 0.10682472639850207, 0.10689796746841498, 0.1372270035956587, 0.18042779474386147, 0.07732860557734966, 0.1609853780163186, 0.13783715585512774, 0.17673249303230218, 0.14615807150091442, 0.148011978449566, 0.1481259451912982, 0.09919372480362654, 0.11674576332526547, 0.1874769457748958, 0.1699570223156895, 0.19343888014554977, 0.13981846453888075, 0.1867144081209387, 0.0580393002767648, 0.11698715894349984, 0.0958906299035464, 0.17951616937560694, 0.12971716799906322, 0.21627322557781423, 0.11290082428604364, 0.10241887638611452, 0.08286896614091736, 0.1538001535726445, 0.10081070089446646, 0.09449349915874855, 0.12150812920715127, 0.14749455478574547, 0.15102695381002768, 0.1582400253308671, 0.08109036300863538, 0.134653455976929, 0.09037127678415605, 0.2285963036119938, 0.18725377560726233, 0.10297747355486665, 0.08351458542581115, 0.11092213474746261, 0.16418703193111078, 0.14226642889635904, 0.1483970877847501, 0.15444755740463734, 0.09798777130033288, 0.12261681471552167, 0.11317257756101233, 0.09393385704606771, 0.08881537563034467, 0.15544959077877657, 0.0878511027299932, 0.2255226621138198, 0.07768489074494157, 0.1591922135225364, 0.08426169319344418, 0.09619357543332235, 0.17596709196056637, 0.08729664462485484, 0.17156923509069852, 0.12538434192538261, 0.10485336503812245, 0.15886647600148404, 0.17040770527507576, 0.09247852156737021, 0.09049561154097319, 0.10234974723841463, 0.22342506609857082, 0.21662666089832783, 0.11023746577224561, 0.11064083448478154, 0.12918499298393726, 0.12459753985915865, 0.09902287647128105, 0.14062955815877232, 0.15897125537906373, 0.09600514625864369, 0.10230539818959576, 0.11937256237225873, 0.19900547287293843, 0.19979179996464932, 0.1361224842923028, 0.10517908898847443, 0.20051415477480206, 0.12697851923959597, 0.08435942259218011, 0.10988813558859484, 0.21472554148307868, 0.17239342443645, 0.0674574002623558, 0.11350607752267804, 0.1707294394395181, 0.21340380954955304, 0.08376477485788719, 0.12639014795422554, 0.11461616759853703, 0.14242838163461002, 0.13129533188683645, 0.1335004892732416, 0.08765429364783422, 0.12493124338132994, 0.17031288679156983, 0.0806661429149764, 0.16898651367851666, 0.19813791156879493, 0.13732856671725, 0.16441105705286774, 0.2105251383036375, 0.09332310089043208, 0.11477776749857835, 0.09794093881334577, 0.1257521350468908, 0.07540870431278433, 0.10306238542710032, 0.06335747454847608, 0.1607654241046735, 0.17163779426898274, 0.15511926636099815, 0.06631554117692368, 0.12487335077353887, 0.14884439163974353, 0.08487567239041839, 0.13022947550884315, 0.0777956208746348, 0.12877507640847138, 0.15800327089216026, 0.2075565747384514, 0.1281072079603161, 0.1714934427291155, 0.14222087205520698, 0.08760043832340411], [0.06072116922587156, 0.08274611059044089, 0.05557240479226623, 0.00738344487867185, 0.02968696897317256, 0.014896250762311476, 0.015209732244589498, 0.024642032271783267, 0.031902524908738475, 0.014431035279163291, 0.009020118841103144, 0.05976471983428512, 0.03094512556812593, 0.09814783771123205, 0.03449292055198124, 0.040930399405104775, 0.01753129400978131, 0.011854504650857831, 0.012067478133498557, 0.00666361506695726, 0.05461990786716342, 0.033207625948957036, 0.037162355346871276, 0.03156186979530113, 0.05181588565132447, 0.028445197302582007, 0.03740097575687936, 0.08501376105206353, 0.0310998654791287, 0.03133343080324786, 0.034188896151525636, 0.02260707352044327, 0.022544473575960313, 0.022216987130897384, 0.03869842292208757, 0.05270655446552804, 0.08108557255140372, 0.05533612872074757, 0.05232199813638415, 0.05480625054665974, 0.03612808138132095, 0.011359487061521836, 0.09469404696886029, 0.01044020612191941, 0.049817627162805626, 0.0460885004805667, 0.022927414991759827, 0.05587926886177488, 0.019720427791721055, 0.03617373661005071, 0.07079277985862323, 0.007857554259576967, 0.017750211459185396, 0.013324551616928406, 0.0962356785312295, 0.08141411920743329, 0.011897616221436431, 0.052629225222127776, 0.010033208943371261, 0.03475805811051812, 0.031123699021658728, 0.06178355828991958, 0.06176535998071943, 0.10020584799349308, 0.016883515287190676, 0.027392485844237462, 0.08035825086491448, 0.010399335413239896, 0.06628614025456564, 0.03345274333176868, 0.02501601363266153, 0.034773840835051875, 0.05067861685529351, 0.03126208284603698, 0.03829087443383677, 0.128348440730146, 0.029708078197602714, 0.021875863828297173, 0.016637746510761123, 0.03717000922188163, 0.035951631742396524, 0.03629275843767183, 0.011616124272612589, 0.010635346856101282, 0.12187095545232296, 0.02049909083039633, 0.031694686239851375, 0.008648564091085323, 0.041088681268904886, 0.03652166901156306, 0.028208953461476734, 0.03156739646302802, 0.040808948422116895, 0.01556405474963997, 0.03203490369820169, 0.014767792208918502, 0.028743754407124858, 0.05569736719397562, 0.052610199100204875, 0.0060584826943730664, 0.06375582210187401, 0.02281036600470543, 0.05675981054082513, 0.007649759695466075, 0.02424738273423697, 0.020491265625293766, 0.01872732224208968, 0.0483149095837559, 0.03626506742356079, 0.005747037665319762, 0.050198210669415336, 0.025505564774253538, 0.04510370868125132, 0.02800566776256476, 0.053355043953550715, 0.059441160410642624, 0.07152012868651322, 0.0377571998563196, 0.012339660581866545, 0.016045597481674383, 0.041429024256233654, 0.012956202096704925, 0.06155117361673287, 0.011584548645519784, 0.021482540826712335, 0.035464752332440445, 0.03193099284544587, 0.04136216141549604, 0.07958611194044352, 0.00648727229729827, 0.06309463722365242, 0.040845127909311225, 0.09176999530089752, 0.04314102578376021, 0.04910015780478716, 0.02304788040263312, 0.03112526304487671, 0.008512722228520682, 0.038193983025848866, 0.014351029215114457, 0.016771841993821517, 0.02464661238315914, 0.016503930923395922, 0.06997502302484852, 0.06690875041697707, 0.05370161249967558, 0.022918812864060913, 0.02976551279425621, 0.01233561396864908, 0.020488281767549257, 0.030859782826155424, 0.05787067075393029, 0.031223582769078866, 0.047391477706176896, 0.02969196977626, 0.01857278249891741, 0.02278205073837723, 0.01512875417912645, 0.04173720468367849, 0.06823644667331662, 0.012211825432521957, 0.04394485568627715, 0.045398800168186426, 0.05369554300393377, 0.021684432136160985, 0.009609836170316806, 0.02468836773186922, 0.02519463119097054, 0.030036601104906628, 0.03696709332455482, 0.04375534424824374, 0.03528271156496235, 0.08961492058421884, 0.023470675572752953, 0.035948598690863164, 0.029497097911579267, 0.02951765412996922, 0.09663244509803397, 0.03372886976493256, 0.02799594435574753, 0.07904267324400799, 0.025692370553900088, 0.057893442389156134, 0.035543292760849, 0.021127826467688595, 0.029500694147178104, 0.028535579863403524, 0.0810642461957676, 0.04020142887852021, 0.013795035076327622, 0.028478274188403572, 0.03408375036503587, 0.043510379535811286, 0.0791807279789022, 0.026636731844129305, 0.05185328989422747, 0.04759059380739927, 0.05259007714422686, 0.03969156409480742, 0.034099899498479705, 0.04282778348507626, 0.0275596429460815, 0.04374801946271743, 0.03611602381403957, 0.019524448218622377, 0.06245118246546813, 0.016569940506347587, 0.016833271465397308, 0.04820896651861923, 0.030678478269172565, 0.06309317837336234, 0.024369369759889584, 0.0071096895013137585, 0.05682710425129958, 0.025569131631138067, 0.07165381365588733, 0.02001924952492118, 0.0406276099383831, 0.013389580716778125, 0.058095822243818214, 0.05864006161157574, 0.04048204382083245, 0.032954003129686625, 0.02479339307839317, 0.042297043571514745, 0.038522037743989906, 0.01877587311901152, 0.00845218078965055, 0.026653345774060914, 0.007083727055162723, 0.0357145346435053, 0.02248876415459173, 0.04038489796221256, 0.04015855225069182, 0.004037992854136974, 0.021568906460223452, 0.05816760446344103, 0.07954380528203078, 0.08931763403649841, 0.006484684110286513, 0.042217814430062256, 0.01650983587439571, 0.021182205960420624, 0.00774106930475682, 0.04113076061808637, 0.02749619652916278, 0.0517002564987966, 0.0029406225533291164, 0.06449288755123105, 0.028572356461414268, 0.038422849494963884, 0.02688838860818318, 0.06012101857257741, 0.014394845613943679, 0.05556250157366906, 0.038220730876283984, 0.03095272516033479, 0.10153104045561381, 0.018622724372627478, 0.03429777727329305, 0.032743816729635, 0.028525388267423426, 0.011849173061948801, 0.00942922371905297, 0.02168774338705199, 0.05938662655119385, 0.013936227187514305, 0.08949562055724007, 0.10735012284879174, 0.060209988084222586, 0.021001993844817792, 0.0037165131403266317, 0.041231455214853795, 0.035029780851410966, 0.024513253110593984, 0.05842401606163808, 0.010333842365071177, 0.015032420866191387, 0.05969056274209704, 0.023362155770882964, 0.06353276049984352, 0.015559874973925096, 0.05337925408301609, 0.03494078080568995, 0.06578751201076166, 0.0345823039699878, 0.02552095055580139, 0.04753918120903628, 0.02198169832783086, 0.027142925753391216, 0.020173906315384165, 0.07381158215659005, 0.02987654147935765, 0.02375097499628152, 0.008066176636410611, 0.010427991643414965, 0.030996144616178105, 0.034942660347691605, 0.061906597044851096, 0.051616114763809104, 0.019832460708650093, 0.042017381970903704, 0.06103183648415974, 0.010209854509282325, 0.011353680498099752, 0.03883886270757232, 0.09096310181277138, 0.03289884841069579, 0.0647558673684086, 0.09378559714449303, 0.06469910112874848, 0.029469688489500965, 0.03849878774157592, 0.03585529673312392, 0.057566184949662, 0.015473807895822185, 0.030661212945623056, 0.03156651097482868, 0.03347659383767417, 0.028809205895023685, 0.07514719691659723, 0.028831465236310447, 0.02226169071426349, 0.025296365642654042, 0.020841126762596623, 0.015499463304877281, 0.05116943855370794, 0.024171895713412335, 0.06370227211820227, 0.08222138588981968, 0.037659785976367335, 0.005495919912521328, 0.03010588970833591, 0.03864533434222851, 0.03829192277044058, 0.02042278617487422, 0.04118364903011492, 0.020072992891073227, 0.017582369036972523, 0.03864248788782528, 0.03401662968099117, 0.0407041724372123, 0.05075617680060012, 0.06156646101070302, 0.01124311491314854, 0.024283518116655092, 0.058911529901836596, 0.02328812929668597, 0.07733267678746156, 0.03254158615267702, 0.04348283440672925, 0.024667202528300028, 0.12235821144921438, 0.2395421862602234, 0.14568623181964668, 0.10655232851526567, 0.25457407108375, 0.12095356253640992, 0.16716152589235986, 0.08886408087398324, 0.13554278468447073, 0.13524199011070387, 0.08131403529218265, 0.15009524380522116, 0.12870058683412416, 0.14510645078761236, 0.12005031029028551, 0.12859352757888182, 0.1376823955880744, 0.11832879909447261, 0.08723545433687312, 0.07956076865749699, 0.11903067571776253, 0.11979351192712784, 0.11072304578764097, 0.07247003700051989, 0.10842190283749785, 0.08834086930645363, 0.1972370341952358, 0.21403688272195204, 0.13371327785508974, 0.13228679368538515, 0.09060078446886369, 0.08060957345047168, 0.12695091643503734, 0.09306782923106637, 0.19623094318168505, 0.15853161896978105, 0.17713061666914395, 0.14290195836552552, 0.10458460410258599, 0.1495438933904682, 0.11919984806861196, 0.18553782839860233, 0.2701221853494644, 0.08936709245400769, 0.15705619885453156, 0.1489906566483634, 0.1605164288942303, 0.08215512015989848, 0.18268613570502826, 0.11570641052510057, 0.07438254901873213, 0.07256077748856374, 0.11530109441706113, 0.14667504733162268, 0.18251336711858, 0.18775361164339952, 0.11862732736127717, 0.10068336022751671, 0.10603272675403527, 0.10767539896603141, 0.17370676967714513, 0.1542237629847867, 0.20479203308267252, 0.13688283706349985, 0.07557189877011947, 0.09279307683131524, 0.13698555369462284, 0.09038302222532885, 0.16642120347491332, 0.17113855534366199, 0.07767713508967843, 0.1444473625825984, 0.12642549962869712, 0.1860025841742754, 0.07023228957716908, 0.19164353076900753, 0.11489204636641911, 0.07789665473891155, 0.1376958577228444, 0.15258933497326715, 0.06253975164145231, 0.1858934350311756, 0.0888395586184093, 0.13814309372433595, 0.12291840996061053, 0.05742407936070647, 0.09179579998765673, 0.16472277604043484, 0.10229196319622652, 0.1382285077124834, 0.10112512045140777, 0.11742095995162215, 0.18644417476441177, 0.08329252805560827, 0.08895400712000472, 0.09103357445980821, 0.2760610223880836, 0.13215498147266252, 0.10468854888209275, 0.1253969491060291, 0.10975282213517598, 0.09193772237215724, 0.13934110158256122, 0.08155699832631008, 0.12829400865095003, 0.13346140565616743, 0.11699702484267098, 0.10495785943099431, 0.09453797712922096, 0.07459454371460847, 0.13326169922947884, 0.11261465892727886, 0.17846361228397914, 0.12562694533595017, 0.1828067520899432, 0.1917015319424016, 0.19079796757016862, 0.12125534777130399, 0.067173854048763, 0.09324084209012133, 0.16691976386521543, 0.10705951987100498, 0.1932025599692549, 0.13497633008020266, 0.14733280560800008, 0.1089629666613681, 0.12623876679156507, 0.11806837735431534, 0.21046643145382404, 0.17561441659927368, 0.1466012770043952, 0.10546019247600011, 0.1418473520981414, 0.13507659041455813, 0.16127978079020977, 0.11684351308005196, 0.15172941397343362, 0.13285790303988115, 0.13755557739308902, 0.0893973551158394, 0.09967901304896389, 0.12464655722890582, 0.11924772549952779, 0.09486283934009926, 0.19723674921052797, 0.16772606702787535, 0.09322583289550883, 0.19673723887119973, 0.10458353880260672, 0.19029913576585905, 0.19479020977658884, 0.12229134860847678, 0.08023321043167796, 0.17549993417092732, 0.14120221457311086, 0.09482522814401559, 0.08767521288245916, 0.11530830045895916, 0.12957482492285116, 0.1336794460990599, 0.17592864616640977, 0.13922644273511, 0.12509155406483582, 0.09016512427479029, 0.14838266213025364, 0.13380025247378008, 0.10723255308611052, 0.09281310039971556, 0.09096823153751236, 0.18666780633585794, 0.19886543681578978, 0.26392482646874016, 0.1442921951945339, 0.2277144795017583, 0.0839746185977544, 0.14223338424095086], [0.017310975385563712, 0.02668508594589574, 0.04018139513209462, 0.04825693555176258, 0.044560056246284924, 0.05203303721334253, 0.02600775023789278, 0.03149102056132896, 0.03136353740202529, 0.02169471194169351, 0.054981142947716374, 0.018728899836008037, 0.02188839467375406, 0.059579242286937575, 0.027506722303639566, 0.04106934302087341, 0.02904253712456141, 0.04411395339827452, 0.04711345476763589, 0.046792232897132635, 0.06010999237852437, 0.04801476979628205, 0.02860303981495755, 0.08485506528190204, 0.03769311561648335, 0.024012343292789798, 0.06781109342617647, 0.038212954864970276, 0.08569902713809695, 0.011941751531724418, 0.02718367687027369, 0.024462335842794607, 0.054778332223317454, 0.0446387391670474, 0.01673919937041189, 0.022480608163667575, 0.015584037605939167, 0.050699108612856696, 0.06517686442072902, 0.03860486990639141, 0.0354635207913816, 0.012515491057586457, 0.031218497149114097, 0.06701644749513694, 0.028189379422526275, 0.014219453641479569, 0.036397191762392006, 0.022735130041837692, 0.027976200683042407, 0.04835960129275918, 0.03804504798193063, 0.03359654865094593, 0.10236880728708846, 0.0377888263735388, 0.02954872085579804, 0.020094661906893765, 0.03722085863617914, 0.015925157515864288, 0.015273358473288161, 0.051740052577640326, 0.040947573126426766, 0.045751692660685093, 0.012328013528271444, 0.049151370235319645, 0.043371418956667185, 0.010861438965158803, 0.06683128885924816, 0.05363147233479789, 0.012837996207443731, 0.016977716303829635, 0.05554637618895088, 0.0267804913621928, 0.031462973316333125, 0.030179483616458516, 0.04383823408612183, 0.025447758679677333, 0.026199283710281764, 0.05246368981897831, 0.03135305403598717, 0.003411960118683055, 0.043466413859277964, 0.04275248306138175, 0.04291391332766839, 0.03721820556425622, 0.040033274330198765, 0.015984926272981932, 0.023414767679891417, 0.015495210586647903, 0.01883922114835254, 0.07733262250466005, 0.03487049814845834, 0.025386093417182565, 0.03203677984752825, 0.14364685410899775, 0.039344330584364276, 0.019947913442073122, 0.09651583206972905, 0.040786027509186945, 0.017353085268821036, 0.03314829145425132, 0.042943124260221205, 0.01960722609822239, 0.0017102623574568757, 0.03819699232865657, 0.11039071290620736, 0.01826202533473926, 0.0597080010920763, 0.10479714162647724, 0.011671396887062915, 0.004931609478912183, 0.027008190751075745, 0.007531834550068847, 0.0633336172572204, 0.021895537951162884, 0.038378534372895956, 0.002296575349256662, 0.05399183889052697, 0.024062307218887975, 0.0501421026087233, 0.020406876225024462, 0.022656294450696026, 0.031021816988608668, 0.016714500695733086, 0.026057213744414703, 0.03840921772643924, 0.0830230750143528, 0.027977832559762255, 0.013938163556823773, 0.02488480361976794, 0.02762499774274017, 0.025103685446083546, 0.04837680554815701, 0.02985444837915046, 0.07501212773578507, 0.018929381488955448, 0.02581732108124665, 0.035398147335009914, 0.0325501831913633, 0.015561839332804084, 0.013692685702283467, 0.02423989340396864, 0.028021967870050242, 0.0030577983416151255, 0.024601091165095568, 0.012940324377268553, 0.03593824424647859, 0.01890682359226048, 0.01545724315967943, 0.023231452962915813, 0.02006822787890477, 0.034326095932296345, 0.04468501864799431, 0.04998161211343748, 0.03681316087022424, 0.041692954022437334, 0.04954750915723188, 0.037133877232138596, 0.03878367066915546, 0.03178551833012274, 0.000907956508204474, 0.03639530882771526, 0.04773294027628643, 0.032334263170404096, 0.05977499285446746, 0.04459402710199356, 0.04206559527665377, 0.029157711658626795, 0.04038644841473017, 0.00737154676711985, 0.02712994028947183, 0.01858911314047873, 0.0787468726879784, 0.06801051486815725, 0.02472128176928631, 0.03159245476126671, 0.07521870772221259, 0.01892332047490137, 0.02439245012854891, 0.027573651301541498, 0.0415613385848701, 0.006934021873998323, 0.00834289678771581, 0.019416727391736846, 0.047914502676576376, 0.02692684966937772, 0.05994940349566085, 0.020443718980199525, 0.07107351015188865, 0.016061283514967988, 0.012760583843503679, 0.046596363585974486, 0.09179077882851873, 0.032017577306500504, 0.02806658494020147, 0.042816139824156246, 0.013344821154272981, 0.03324776468798518, 0.02716322921748672, 0.05274021998047829, 0.03459444296147142, 0.055240109230258634, 0.04610151817489948, 0.03466456616297364, 0.04118776434500303, 0.051092468933867555, 0.030850625996078764, 0.024576823360153606, 0.04005194082856178, 0.04688443223546658, 0.01568974827283195, 0.048437303730419705, 0.034372375413243256, 0.03527484395142112, 0.044688390967036994, 0.03733834358198302, 0.05133650744599955, 0.06310736654060227, 0.02263697825505265, 0.07550384170774903, 0.01890154798249049, 0.06732839039926018, 0.010543412994593382, 0.029074523265340498, 0.009367914687442993, 0.02217082808991628, 0.02514980547130108, 0.066336365416646, 0.015214502345770597, 0.09528390424592154, 0.03293981835512178, 0.0033141094318125397, 0.02897162003708737, 0.02278821014000901, 0.0282056557812861, 0.034189581471894465, 0.04135311654369746, 0.07277079086218562, 0.019100440167156712, 0.02757170899505062, 0.06265413907489606, 0.02159928108033325, 0.010793564259074628, 0.05831477192363568, 0.03905933230583157, 0.014467928924464753, 0.010488999575110418, 0.06343857305390493, 0.012683124830281096, 0.15277215944869177, 0.011197854082898369, 0.04799950275836246, 0.056252076357070885, 0.0027237551278501216, 0.041502848866262605, 0.013435927203058131, 0.03241126671699541, 0.006377895844967237, 0.026479394840342656, 0.10225505767656223, 0.12062853069177695, 0.05051439441740513, 0.035378954972007444, 0.032871340601039786, 0.03640202971707497, 0.12332688804183688, 0.02790140576793679, 0.054514578876218626, 0.02818850241601467, 0.043216054793447256, 0.028230037240843688, 0.02023032819852233, 0.05089670818831239, 0.11630706329430852, 0.045248915175242085, 0.018745769912909185, 0.017988580811236585, 0.04829036697213139, 0.03499036475217768, 0.05259671321670924, 0.0068115399418664825, 0.10853988650654044, 0.02643443680634456, 0.03745285315173013, 0.02802822905193482, 0.04377120839697974, 0.027530735657949532, 0.05035081998045955, 0.033638834953308105, 0.02771014710223036, 0.01613289610083614, 0.026883260579779744, 0.016354846601773585, 0.018523817715634192, 0.01991628692485392, 0.07225715342376914, 0.014129510432082628, 0.04523847930665527, 0.045170286537281105, 0.033627405030918975, 0.038628313291285715, 0.02243383674483214, 0.007745536609685847, 0.02963040629401803, 0.026359577430412173, 0.06922498398593493, 0.03591914348570364, 0.03065573038267238, 0.08212238763059888, 0.0697869738297803, 0.050440566414701085, 0.03305078597207155, 0.047480124913688214, 0.033849913626909256, 0.0035876792722514695, 0.013129276872080351, 0.07130583375692368, 0.05200376181996294, 0.01804423764614122, 0.03958929190412164, 0.041731006266283135, 0.019136258334453617, 0.03130341241402285, 0.03438760173906173, 0.02295275148935616, 0.05455830706549542, 0.009680506440677812, 0.053022415909383974, 0.033378257150096555, 0.07398445252329111, 0.03344770520925522, 0.03964913869276643, 0.04860778904653021, 0.06507157614188534, 0.07579386114541974, 0.03350803375776325, 0.02224671883907701, 0.04729005368426442, 0.026539061817207506, 0.05801896458225591, 0.06233610292630536, 0.01549949892796576, 0.03374026236789567, 0.012153241567180624, 0.01355202030390501, 0.05335199393864189, 0.019822292861395648, 0.04477813740127853, 0.04936285263725689, 0.09479753034455435, 0.07634497407291617, 0.060423774112548144, 0.046411852951028516, 0.04976116965657898, 0.16325718111225537, 0.14491899870336056, 0.12363620501543794, 0.10820492769458465, 0.12916410767606326, 0.14181789010763168, 0.10271587794912712, 0.104316114581057, 0.09578792005777359, 0.1606414286153657, 0.1644949782639742, 0.1231577428323882, 0.11678576974996499, 0.11192584410309792, 0.12383215235812323, 0.12998684495687485, 0.08640526674155678, 0.12218555142836911, 0.10333286984158413, 0.15140708269817488, 0.21310194289045675, 0.1152364978832858, 0.15731343148010118, 0.1502284538000822, 0.18911947549453803, 0.1972642027373825, 0.08115563807742936, 0.13711298257112503, 0.12349633180669375, 0.13459283565836294, 0.07099864059793097, 0.15231310336717538, 0.09467392162020717, 0.11383336888892309, 0.15064367651939392, 0.17717373078422888, 0.13986320713801043, 0.12652281512107166, 0.14242530108562537, 0.17307855481547968, 0.13139534794858523, 0.13081543120954717, 0.141203748062253, 0.11048004204141242, 0.1687586209071534, 0.07356625782059771, 0.11092020092265946, 0.08908008571181979, 0.1392749308475426, 0.11425952959273543, 0.09159399010241032, 0.19755301438272, 0.12741894274950027, 0.05462325983015554, 0.14147326217166015, 0.12801768204995564, 0.07172784182642188, 0.10163663407521588, 0.1896562645477908, 0.22741691475468023, 0.1231314835271665, 0.07201397325843573, 0.14107630561505044, 0.13913374128086226, 0.07813230995088816, 0.15639970265328884, 0.12576254377407686, 0.11206967317100082, 0.052894006549779854, 0.2047428392938205, 0.05147652993244784, 0.20388188692075865, 0.10573692619800568, 0.11068638454058341, 0.10664596634783916, 0.07417411663170372, 0.15813265394951614, 0.08014562513147082, 0.11221549713185855, 0.1068734112860901, 0.10449558030813932, 0.24485801958612033, 0.189606460077422, 0.10160251733447824, 0.21862614074988024, 0.09359738510102034, 0.12825660780072212, 0.13546155047203812, 0.14874190571052687, 0.09099835849234036, 0.09779020904430322, 0.12573780438729695, 0.19827174581587315, 0.12768270288194927, 0.138451718592218, 0.19049919503075735, 0.1730583751840251, 0.12290969757097107, 0.12498549904142107, 0.19936842125441345, 0.1110054317063519, 0.1877724884876183, 0.10021413290607077, 0.2874905919390065, 0.08418043862496104, 0.17044159131390707, 0.18872713297605515, 0.12411683851054736, 0.15565822672631058, 0.0894897851560797, 0.11688090035957949, 0.138250397252185, 0.11705831012555531, 0.12856816393988474, 0.08361732241298471, 0.10314089192875794, 0.0869734041126711, 0.13020423400614942, 0.07988343920026507, 0.09312264807522297, 0.0979575968480536, 0.07337683798479182, 0.08404392416455916, 0.16932960812534603, 0.23188217729330063, 0.0743439132347703, 0.05990934278815985, 0.11850219193313803, 0.08684706767754895, 0.10696213652512856, 0.1235005794359105, 0.12777427796806606, 0.16733589582145214, 0.09201208981020109, 0.12832075650138514, 0.08995781825589282, 0.062227727313126834, 0.06415636810873236, 0.22119704208203725, 0.09531637214656387, 0.11350612502012934, 0.1289681467626776, 0.10966831059860331, 0.15762475691735744, 0.13084175836827072, 0.10813113022595644, 0.13189366406628064, 0.16078738149787697, 0.08727558289787599, 0.11688296310603619, 0.19364606402814388, 0.2194874052490507, 0.09389798289963178, 0.13930163798587664, 0.08413924476397888, 0.17150401430470602, 0.15034438829336846, 0.11614333279430866, 0.069517636139478, 0.11909250382866178, 0.1014414399064013, 0.09846304436879498, 0.18384609131940774, 0.10937517668519701, 0.20316679243530544, 0.15837528450148447, 0.14255418202706746, 0.1531267347080367, 0.10613293959093945, 0.14977150117712362, 0.14984065746622427, 0.11317320859857968, 0.13086002453097276, 0.10094855206885509, 0.1510073034358876], [0.0625033143109509, 0.05778115162892001, 0.02430259682504194, 0.033786229722734006, 0.0180877758456128, 0.028977703103529553, 0.010291696858725377, 0.013006183834347342, 0.02148918538088245, 0.03430571952568633, 0.032443921214767864, 0.03930861250098262, 0.04575960098632744, 0.03695561929738947, 0.021924530056172183, 0.033296910979385884, 0.03461732994765043, 0.03774812784312027, 0.011890514504297503, 0.01469181664288044, 0.016451481862791946, 0.03221052213172827, 0.07463415658899716, 0.0968520665275199, 0.017589340984289135, 0.04667496168985963, 0.016419566968189817, 0.024758840378906046, 0.03873525041022471, 0.026441027077713182, 0.028306101016434174, 0.04087879342426147, 0.026723289163783193, 0.041296876168676784, 0.050098890106060674, 0.032361574204904694, 0.02522530436648854, 0.0841387901455164, 0.04660179525879877, 0.027867116000769392, 0.028972240896629434, 0.02815501162383173, 0.008337454088697476, 0.02386147272773087, 0.054334027493106465, 0.009407307037950625, 0.0234027270759855, 0.03668938929747258, 0.05857508509818997, 0.04601699985297663, 0.02079258776003761, 0.013284377254811781, 0.008683021795669836, 0.038301700460059304, 0.0049899617941784, 0.025149781722575426, 0.04791097090180431, 0.0075342560719166484, 0.059100196563771794, 0.024012070182444792, 0.04043320965554033, 0.04963783573891435, 0.08554124739021063, 0.05202606187335082, 0.008899670393605317, 0.018366572314075062, 0.03457602412839021, 0.08090828492173127, 0.030736923883003846, 0.04200737697205373, 0.02224869846499392, 0.04652034391516021, 0.05942765756377152, 0.014794445064451014, 0.02597638326031821, 0.05621997147266354, 0.006697524854514215, 0.032619006998304806, 0.03142205086935844, 0.04366683614041124, 0.026497041839840155, 0.03166137356311083, 0.03888483006241066, 0.0404109842410045, 0.050583564277206144, 0.0327110842003354, 0.10690519386636359, 0.026034364077661718, 0.05792487891657012, 0.006029452421768967, 0.020717937033623457, 0.04600078286603093, 0.06929874074246202, 0.019048810437587754, 0.08573167145784412, 0.025369284408433095, 0.025589038152247667, 0.03622727641569717, 0.01597032250304307, 0.03004759337220873, 0.017433961554031287, 0.06199136642473085, 0.01542969124524721, 0.08514045032539538, 0.03998029770861779, 0.09031105001590081, 0.07132905322526183, 0.06152297370135784, 0.010841353480438036, 0.05484106957114168, 0.011312155003127242, 0.018503560052652444, 0.015054636102701937, 0.00972228977895741, 0.031881968690348525, 0.03205977539931025, 0.020142629243699566, 0.02801139290178461, 0.023132300336978266, 0.011698746937327087, 0.03128449485770293, 0.01369714452552476, 0.07201568316668272, 0.04779702790879777, 0.012626486664105738, 0.007592096093243786, 0.054818291150565655, 0.035395083749400716, 0.011242744263394602, 0.03742890086557184, 0.030142500065267086, 0.0031300230932954165, 0.060154986035610945, 0.029521287684994083, 0.024888028357444063, 0.03135859088173934, 0.022799171873235276, 0.040990504037056646, 0.07209111590470586, 0.07458361930080823, 0.04570521301190768, 0.06846597471407481, 0.028757162259093354, 0.021362899835886698, 0.024030419465686594, 0.016482451897380606, 0.03851229398112212, 0.03810897615871259, 0.04061474830710462, 0.014140498458540865, 0.02534981214973543, 0.028884150087833405, 0.060972322177674086, 0.012212065464284803, 0.029075805696525743, 0.04676751047372818, 0.01745713861393077, 0.023355007404461503, 0.04013314111424344, 0.015186602682141321, 0.0566597198402243, 0.035395229634429724, 0.11939932379339423, 0.03154191068772759, 0.012980640383570321, 0.03178303489195449, 0.025898651984919394, 0.05054649251646229, 0.0416560213613723, 0.0449333285380687, 0.05186521175450512, 0.010166608928037542, 0.021157346133674895, 0.004689072225508946, 0.04438411211594939, 0.04223809584176966, 0.0301679960185928, 0.02554828194635255, 0.0636847862707717, 0.050618848098175864, 0.034518216337476454, 0.05515104811638594, 0.030616524629294872, 0.0231068060799901, 0.029707504835511957, 0.0334014257283083, 0.03681555949151516, 0.014702824177220464, 0.08568876768861498, 0.044014751578548124, 0.042902045750192234, 0.027925327520019243, 0.03099458059296012, 0.031413250270166566, 0.032503713720611165, 0.022833541368267367, 0.09216427842953376, 0.02492772095969745, 0.054958242390836985, 0.021942738543397615, 0.029729048322354044, 0.041138872504234314, 0.06072209881884711, 0.022206322256741778, 0.007948851994504886, 0.004367066647059151, 0.043806627924953184, 0.020968357167605842, 0.05000173067674041, 0.03699090651103428, 0.05427434016019106, 0.11554384710533278, 0.03234855651057192, 0.02994813710185034, 0.029429254587739706, 0.028433178751064197, 0.05333305602627141, 0.05307857486020241, 0.08835156980369772, 0.015129956882447004, 0.031316494569182396, 0.03172840264492801, 0.0356967129212405, 0.0506398657203785, 0.06996317580342293, 0.049417216862951, 0.04018120174961431, 0.0406071758562965, 0.05807430589837687, 0.046062970600490055, 0.027903410838916898, 0.015619779438046473, 0.0228680143398898, 0.006678739188438547, 0.03413644200190902, 0.01840943537120308, 0.03907403276701059, 0.01721675570921174, 0.02882972140131252, 0.019106825181682194, 0.04161456626440797, 0.05375337454357317, 0.10528236201831273, 0.01181784934098167, 0.05408270151487418, 0.051090860805873356, 0.027684824175334403, 0.017284001922234893, 0.0499966654128262, 0.07900249040020363, 0.01621646956274552, 0.01942155516839453, 0.03170391770878008, 0.012932695099152625, 0.048393283771084886, 0.08343731385788747, 0.025506012607365847, 0.023134695565594093, 0.03223347357873406, 0.0371149494977934, 0.021285121063036577, 0.017067674780264497, 0.01832731397423361, 0.06590367720595428, 0.04068823025694915, 0.03663254163361021, 0.05453338447426047, 0.0016161571838892996, 0.034403055374111445, 0.02893277390726975, 0.04528988851234317, 0.03834103852776544, 0.045730179707918844, 0.035743450413325, 0.03466502756678632, 0.025985316173838716, 0.04267155758238264, 0.029942963272333145, 0.05750409221010549, 0.06550549928631101, 0.0850188432793532, 0.021283741940611174, 0.055849508315856965, 0.043611959620778046, 0.013967509348211544, 0.007452331450102585, 0.0671133626518505, 0.013278620733347322, 0.021696035084979873, 0.012761063907029373, 0.033813337196729014, 0.03209202277607151, 0.01945501203382654, 0.05458241202203291, 0.03515709776963506, 0.009112548881343432, 0.019457280037126372, 0.045909737037228684, 0.03341143751250846, 0.04905230072992189, 0.026300387124397924, 0.022371277512450303, 0.030541862028517892, 0.05714119132608175, 0.03712169752855386, 0.02463319604950292, 0.05738088382141931, 0.03567676059901714, 0.0439560752628105, 0.028823414418314184, 0.04034175670572689, 0.02037065432939146, 0.048819946590811014, 0.06578171053635222, 0.060017134861222336, 0.037465280520596674, 0.04092644015327096, 0.030387033907962695, 0.020940464289326752, 0.04394058430833476, 0.03390497674367257, 0.026946517006893243, 0.06937905893261943, 0.04876209130244596, 0.04920776328071952, 0.04020887580034988, 0.014041754649952054, 0.039372259085731845, 0.05233395053073764, 0.04499336192384362, 0.0320113042502531, 0.05269749602302909, 0.02495650780786361, 0.020573826373687813, 0.036807037091680934, 0.03401127264701894, 0.020572428591549397, 0.07307609769382648, 0.08253277918057782, 0.008257051081662732, 0.038310606232179065, 0.022894891111978462, 0.016234771348536015, 0.04158634938565748, 0.04788034861641271, 0.026456855603360703, 0.02992292952590755, 0.022896836811144437, 0.06546226303492274, 0.03594984719529748, 0.06793808125491653, 0.0624846342418875, 0.11182726653558867, 0.12117966397532395, 0.13375341998679297, 0.10403646994382143, 0.16915203551096575, 0.1440127066203526, 0.06718652229756117, 0.0895197560478534, 0.08870398053633315, 0.09771640479032483, 0.1228264548948833, 0.0856032654909151, 0.2032509172069175, 0.1012097473389336, 0.08648529994700636, 0.0876121362671256, 0.13164293180618966, 0.09337899181991816, 0.17306688401315892, 0.1611629370599985, 0.11358449581478323, 0.11947359623653547, 0.22230622970632144, 0.12587325354771955, 0.09868960721152169, 0.13925053072827204, 0.12760948895343713, 0.09912629877882344, 0.08767709920981101, 0.05220477442656245, 0.08445097732224635, 0.09707704159830298, 0.18427436905247824, 0.11906062625348568, 0.1341291791094201, 0.15382487938872405, 0.1414508840867451, 0.09194840251335076, 0.17500562140984194, 0.22005745608891758, 0.14779568862702164, 0.10426913281636578, 0.2656294692839895, 0.12127042481941835, 0.15413673408329487, 0.10287623613008431, 0.22715076617896557, 0.22718554788402148, 0.11672920707081046, 0.11910847654300076, 0.14395087850945337, 0.12951127333300455, 0.10223130895090954, 0.1505556298153741, 0.1888317766466311, 0.11609758596335139, 0.12629934639803, 0.09956894788358893, 0.16133084733571323, 0.1094310065465314, 0.21149367918925627, 0.08804103146706309, 0.15553805817450794, 0.13798670497323784, 0.0875173042129193, 0.07378712775451796, 0.20989454856940679, 0.15238512307405472, 0.1869975065014192, 0.13704569903867586, 0.1158302431660039, 0.09858684308294739, 0.20628752426377364, 0.11033754290214606, 0.13070366292127542, 0.1273818268839802, 0.09758227877318859, 0.08119852149060794, 0.11538877471217088, 0.1924405787140131, 0.09591259408210005, 0.06759012171200343, 0.1188848042594535, 0.14816037405814442, 0.08227862031864268, 0.13464053667017392, 0.20363534800708294, 0.12570746030126298, 0.16097766985850676, 0.09088390320539474, 0.08669763391039201, 0.12310348717229706, 0.13899180532566138, 0.12024169787764549, 0.19285145880920546, 0.10611879213580064, 0.1621998878461974, 0.0815642179389085, 0.18458391672798566, 0.16200774029961654, 0.1106739809204425, 0.1473162222121443, 0.11744997410901956, 0.16720951188887867, 0.21634835297507898, 0.2028265478355544, 0.3236314297786781, 0.10282712376543454, 0.09438375969018255, 0.14715322452996457, 0.11386185378900596, 0.1640499271452427, 0.17675359547138214, 0.1782956477254629, 0.09301672875881195, 0.20510489200907095, 0.10280720197728702, 0.15477488269763334, 0.07560444809496403, 0.10573733331901686, 0.0757077754076038, 0.11232670902141503, 0.14706738985010556, 0.19926824234426022, 0.10889729804226331, 0.0796015757535185, 0.14159385141517433, 0.19557889817016466, 0.09198021223502499, 0.13011833147278853, 0.10701863135078124, 0.12171814936612334, 0.10948394584868636, 0.11333980251635824, 0.14176685070352896, 0.1145173864705222, 0.15379786012428148, 0.1702686191669532, 0.15320019290915557, 0.12467905905629907, 0.14032823432769093, 0.1496449408254453, 0.2030110415071249, 0.2583520183605807, 0.15509325132838317, 0.14875220587210997, 0.13575865381530353, 0.15040975835706505, 0.20437632181814738, 0.07361258140632085, 0.10479292113866125, 0.08808605226555041, 0.12414858037871973, 0.12078205602509634, 0.08755905447261673, 0.15234997496008873, 0.1738759691693953, 0.09713357713605676, 0.1532666350581816, 0.08852364628442697, 0.15819218861205236, 0.17375847404556616, 0.1289594072316374, 0.16080137288996152, 0.17351070019815648, 0.13390828881944927, 0.08561820004667554, 0.1266194927905287, 0.12900542547660215, 0.1577621738293341, 0.07405160713408675, 0.14910093215959414, 0.12978538790983812, 0.07314182059573275, 0.17324107752314635, 0.16875319262700422], [0.018867863807827234, 0.037008612882345915, 0.057580115273594856, 0.03427669858293874, 0.022328051439087306, 0.08903591986745596, 0.07356319084231343, 0.02555657534061798, 0.03254317731729575, 0.01863248340253319, 0.037153354579848905, 0.03640570737687605, 0.03774385307250278, 0.04808151050071631, 0.014387602252619607, 0.0061236937264246595, 0.02845711068117193, 0.013994985775622939, 0.04897853718804462, 0.05047406229589667, 0.02589949336834252, 0.06366077291646174, 0.025639566958748868, 0.003064360623414229, 0.0229981912832175, 0.019285639515146613, 0.013242683822422155, 0.011214468012829977, 0.03319926979020238, 0.014851772791839071, 0.04081440384366682, 0.045646787754126956, 0.05046351446903177, 0.02426868534114744, 0.059790395599390776, 0.08626343935195889, 0.027302130424816693, 0.06555188394018582, 0.0674897324559944, 0.06035887902336461, 0.008369779496985887, 0.0368878302563514, 0.03644172062299081, 0.013877548327270364, 0.06574420790587153, 0.03051442207236375, 0.04600035538896918, 0.03986392895291958, 0.03438644822953003, 0.10748170435960804, 0.04037662662033524, 0.02735588905800666, 0.02142270251975528, 0.05153536231123975, 0.03666333016008139, 0.06116094812750816, 0.042187751936061044, 0.04218941095418163, 0.03266752225213817, 0.03881632855960301, 0.10388186573982239, 0.028143639376919185, 0.008006577513047626, 0.04136837001091667, 0.05106859467923641, 0.02301382303370961, 0.054068604949861765, 0.018807694715048586, 0.02914047347647803, 0.04088352959869163, 0.07272262166121177, 0.0378623252867588, 0.008356479362451603, 0.028732283772634606, 0.03207417730508106, 0.034942341436232836, 0.08105678909591266, 0.02336019480467907, 0.032397981001330275, 0.02991429516779525, 0.05132372045357313, 0.03292847324960998, 0.06081680873675006, 0.019222895381972194, 0.00783068681734481, 0.024384484127429978, 0.01079982628912798, 0.03546429771397795, 0.06210101768374443, 0.01972562028095126, 0.06957120647920029, 0.021786853604550873, 0.013230260694399476, 0.04053231987303921, 0.024425762805289457, 0.029474899638444185, 0.027264424233830402, 0.038208323863468, 0.033195816046957455, 0.012671415860365545, 0.04892825435048767, 0.042107983359268734, 0.07117691888873066, 0.030569230738495077, 0.023555064973022257, 0.03647000874791827, 0.048398878292313645, 0.046456483591880114, 0.008828220656141639, 0.011778048173125302, 0.06650194153189659, 0.016350424249789546, 0.0377200975614999, 0.07949561572500638, 0.012719923480679947, 0.007628638596673096, 0.050156568975320885, 0.037936305959842036, 0.05069257432062711, 0.036628511135599444, 0.029904259634869437, 0.04456647518756134, 0.05271317357463496, 0.028841215784528425, 0.03333619815696563, 0.08019721414893866, 0.024757154219384705, 0.05654308306319373, 0.03514620728258576, 0.028708986272769313, 0.028600352816283703, 0.0429672733215349, 0.05289044424093195, 0.04304953890719584, 0.017126603850296566, 0.050354419608733485, 0.053287265090537925, 0.022603896280218447, 0.059746806509792805, 0.03271433777574982, 0.015034855110570788, 0.04367362488327282, 0.02712014563647764, 0.0269774140989674, 0.057232712129397054, 0.010533723514527082, 0.0949291389967714, 0.03663717942046268, 0.03616243900199022, 0.02643396013549396, 0.028791197575628757, 0.040309773957622905, 0.03030758084995406, 0.0860554344419922, 0.054468201007694006, 0.021307784132659435, 0.08397690526076726, 0.054258411550628285, 0.02969888404810003, 0.013112315192951687, 0.023907150008848736, 0.04788983453597341, 0.03389723465910979, 0.040694381176893196, 0.046071747450956275, 0.025677169673144817, 0.08198710810393095, 0.037156268887753995, 0.018111253157258034, 0.03402297737609063, 0.052739653403737714, 0.04368032541658197, 0.03688042065394776, 0.011748934779981417, 0.05245923184390579, 0.025847931492275426, 0.029950108246079514, 0.027505231222936084, 0.07562578123595033, 0.030368092602917125, 0.02893707242661289, 0.04770350203450237, 0.022235254989936948, 0.017409288324415684, 0.0035269137047829902, 0.033525539961244376, 0.03223461012489029, 0.031614293410841904, 0.05601397163367697, 0.028729742658989768, 0.032699861231126955, 0.03688008817178862, 0.025204841446663653, 0.02284133603929409, 0.0606655768517937, 0.016707771324685643, 0.035928246032978804, 0.04106467469994511, 0.019894080170031105, 0.02574366271229727, 0.013073490267353398, 0.03501914481499365, 0.07057680216218744, 0.07750333513000182, 0.031195389639054025, 0.019221845349030833, 0.06208976757313524, 0.10319498474044458, 0.04984721128961869, 0.06915590912103653, 0.02731796064680176, 0.013310477104304093, 0.03397647397858756, 0.04110470487337027, 0.04530334725443806, 0.03777656863842692, 0.03928507412118571, 0.03710714973775404, 0.03678277607208916, 0.10714690839605671, 0.034173646076981506, 0.043203277979046106, 0.027956333177696382, 0.04228863312995859, 0.031099427824041674, 0.022818265848660042, 0.04867820401809045, 0.041090604915682755, 0.015693134162575006, 0.0279139009903052, 0.059733446155275614, 0.05890979963753905, 0.027003480021708777, 0.06898706246699605, 0.01815167348831892, 0.0512788998229163, 0.06389754771121911, 0.022073497330503802, 0.05525210572938834, 0.07328777347824403, 0.02961657096498779, 0.026089493351589357, 0.006326583754603884, 0.041574553054358275, 0.03452593128063849, 0.0100295117756884, 0.05279833650482552, 0.01725366971056376, 0.0127796379549961, 0.04182170943490096, 0.020300702457981448, 0.07744038065097161, 0.03580849817288773, 0.020743731542357376, 0.01233327217466597, 0.011263914555976433, 0.043258558227015395, 0.05299722529681666, 0.06064146850258112, 0.059660150802561214, 0.03930129110813141, 0.015313086698630025, 0.08177911676466465, 0.02952241405312504, 0.06628454569727182, 0.054391926886247735, 0.057197638654283116, 0.03296563661258135, 0.049134705415261645, 0.03082492308957236, 0.08553407527506351, 0.023754060634278824, 0.026843391558421508, 0.024064507368685942, 0.022171873033844998, 0.039772995082395415, 0.012476486320208226, 0.04707928713677185, 0.05524300318211317, 0.02519481778810067, 0.007260417998103159, 0.0574034790375403, 0.0199971241943006, 0.015464228677696415, 0.03179895332349198, 0.040748613088258674, 0.03917673582743321, 0.03704499253737075, 0.06568114486123834, 0.07478524598159961, 0.016522534657269716, 0.07320142311177083, 0.04775673649939043, 0.05251064444226878, 0.05084438296034932, 0.024710966340665306, 0.03873768635094166, 0.03288135238523994, 0.026218884890632968, 0.04914504289627075, 0.03006991038897208, 0.0758744982470359, 0.03645890112966299, 0.04729857947677374, 0.01705316939790334, 0.013874246406235864, 0.060688097429062636, 0.029391684103757143, 0.038981718077723465, 0.02986295720828431, 0.03552916905443583, 0.02092095640754061, 0.012463099672459066, 0.03036347177944013, 0.0369743841833302, 0.05408733251637646, 0.022664272326177785, 0.053213013003447225, 0.06917287928185292, 0.024170496234936372, 0.06818799248763494, 0.03218698375193136, 0.08318581485322543, 0.009092594862782528, 0.04061644125197615, 0.051105581623102934, 0.020071623946673105, 0.028856055345386267, 0.038143883392746956, 0.023745845271540538, 0.050844596698880196, 0.053117285283016305, 0.04228636343032122, 0.04921457916498184, 0.04216347734576889, 0.03246084387813296, 0.03352905137996588, 0.020109411561861634, 0.02043232468089887, 0.04233618486406548, 0.04112477933189698, 0.04600712716845529, 0.044889688558344326, 0.04343773218403969, 0.04439777781122497, 0.044305039037551196, 0.04119474647034492, 0.08552889805287123, 0.03627693500103695, 0.04492247197777033, 0.019627631342570697, 0.03735168358044965, 0.20700987907392637, 0.07422957329877786, 0.2215323198054518, 0.15659289514379843, 0.13749038374849729, 0.18831868203622953, 0.12538287628974232, 0.1362269651144743, 0.11279847406383071, 0.053801363932767084, 0.1393276530184916, 0.09568706261260168, 0.16772370572601045, 0.1375754584691354, 0.09339589412723269, 0.10074222992573466, 0.13287428287523134, 0.07856230437755585, 0.1619364126984562, 0.13924484460481576, 0.12905885332397052, 0.1717943051563842, 0.12367983481713704, 0.10196070918547255, 0.07548104293112244, 0.10617403845701899, 0.11771977320313454, 0.11112779871161495, 0.14844071758644922, 0.1038320544841034, 0.13315466711563723, 0.24414618206875666, 0.15416911377438478, 0.10870105892951999, 0.12477475963532925, 0.22181939440114157, 0.0640958020729678, 0.1530580533934491, 0.16321014506476267, 0.12985520916325705, 0.1442968635154622, 0.09066376608929463, 0.10692502744495869, 0.23078175634145737, 0.198093996782388, 0.11904233294938292, 0.0864851303132517, 0.1257826012692281, 0.09072997075106416, 0.162386240703719, 0.1474207030343158, 0.08364000583865813, 0.14021346691463674, 0.18489729134099825, 0.11309607952300992, 0.12464262172579765, 0.12547455994146212, 0.12098697360072817, 0.1640135305268424, 0.18407417408057622, 0.2698333465627262, 0.08693613218409674, 0.16534392056720598, 0.11826436540910176, 0.12035475538245269, 0.08801410719752312, 0.12300272472202778, 0.14667856214301928, 0.11874041200748511, 0.0859033272468618, 0.1278305420918124, 0.18605749122798443, 0.09775223143930946, 0.11212172359228134, 0.1079124655308468, 0.12404709868133068, 0.17249303337718758, 0.09162732652787652, 0.12686494604817458, 0.09509743603744678, 0.11611247302166053, 0.15783054301781313, 0.13618284676756176, 0.09369673619845084, 0.12029845054660525, 0.1051588279328176, 0.1343908357833113, 0.10312059016099998, 0.16803797600524767, 0.09029936564287969, 0.1912131631480796, 0.1474563396934952, 0.12801888984228882, 0.14306248618023737, 0.1410248183778354, 0.09248061824057784, 0.09040832479617425, 0.09460963721254043, 0.06436607614159584, 0.11012826913169452, 0.09439651614853314, 0.17173065857163497, 0.1656112362231527, 0.10898996556976012, 0.07636500442666666, 0.11537163491759982, 0.1368455719202757, 0.11335466243326664, 0.11753784439393453, 0.1628326896045889, 0.11240275244095496, 0.17218134153102124, 0.11826356473777976, 0.09070308719362531, 0.07147861591407231, 0.11416652958307948, 0.13120558884527, 0.1734777098255498, 0.1039712220164282, 0.12250579281577043, 0.14233235535877092, 0.09695800619998149, 0.0850615706294775, 0.12467577494680882, 0.1330642726804529, 0.1569791715592146, 0.10772466739373547, 0.0986496414989233, 0.09268525761685201, 0.06354825823966946, 0.13575783957328114, 0.17803618950503214, 0.18050136151058332, 0.09035152462976319, 0.07360367902687617, 0.17006644287279674, 0.12386297141867024, 0.0755377413172807, 0.17015113761382444, 0.15542007450546536, 0.0686116154704775, 0.0937597042481814, 0.22575283476284572, 0.09930280609322445, 0.1605101456599576, 0.09376703242638282, 0.15767058517251695, 0.09862057984407459, 0.10945657374603407, 0.09850348505590643, 0.08717982803604432, 0.22047586792281695, 0.17299863696098328, 0.10584141380552735, 0.1403571127780846, 0.07925973659647362, 0.16047011209385736, 0.12149211578071117, 0.10178884983594928, 0.0513407007924148, 0.12182448937424592, 0.11367024228508983, 0.08161034474947623, 0.07416994364133903, 0.12748668768576213, 0.14871054382196494, 0.1562311952667577, 0.07993177124964339, 0.06477925647050142, 0.14024835718529566, 0.08032749965786934, 0.15743845834263734, 0.10966712316232068, 0.10715670644172601, 0.11664475660238947, 0.1361316173736538], [0.02531425521842071, 0.036323055026254485, 0.0417244991154543, 0.029498129284807613, 0.027814673725515604, 0.02877056671838675, 0.04523435042106679, 0.020926442363166382, 0.0188061306918306, 0.048553458747587035, 0.05101493612996169, 0.03660815169236489, 0.012656840079996203, 0.016425310767122676, 0.00786757028462099, 0.028745118262512342, 0.029062811750918627, 0.02855856523716024, 0.0425347751006484, 0.037696057065789185, 0.02671184397435614, 0.04998732198561941, 0.006523905130701938, 0.015031788132286497, 0.047510825230606964, 0.032827843113669326, 0.05161095789766737, 0.0847251054697803, 0.04207128479278513, 0.022074547363445163, 0.05654811440035701, 0.00525871424802712, 0.02517036847504122, 0.05731810576149395, 0.07631958329251834, 0.039794338401407, 0.054199314543179104, 0.03267949839521732, 0.08122877058173929, 0.018593024894861237, 0.03006380357380424, 0.02479344396851957, 0.035268129847411595, 0.027718013019434044, 0.04369613867519157, 0.019847110279702714, 0.040674082801810334, 0.011774008345258023, 0.049715219265116115, 0.007622686996390777, 0.05179642187431455, 0.06300939965460982, 0.04117280604051692, 0.04472810562167849, 0.02838135394267738, 0.05938465201428958, 0.022096318159518496, 0.013978647500542658, 0.03191474871709943, 0.032655115239322186, 0.07321647980383464, 0.00809443592359977, 0.07866395570869956, 0.027599181181618145, 0.04336789057457021, 0.019942654795678597, 0.05501981605110424, 0.01798316270911268, 0.01898609514215163, 0.013104662166110106, 0.02823159278237394, 0.04050692569996629, 0.038420695146279674, 0.0579784560416426, 0.042067016807517836, 0.030031166039407253, 0.007149553009574967, 0.04714876912268145, 0.031691972099776776, 0.0652484634358968, 0.05824757660073893, 0.03781359629439456, 0.02837316402500229, 0.0774681530892849, 0.032813641375729015, 0.10657923921410527, 0.03372263402811118, 0.025217932083510926, 0.0683688356408051, 0.020309002637597065, 0.010003887748877918, 0.01689353216040347, 0.04720731990944062, 0.030243659458522285, 0.039663557561912706, 0.023338775150477886, 0.016566352752436484, 0.04590670737837042, 0.027675945544615388, 0.032794031713690074, 0.007550095623758222, 0.020575420930981636, 0.013863969993378435, 0.01457984309776553, 0.050263109151273966, 0.0445102687392916, 0.01209430062278573, 0.020039301931059787, 0.031961269077977965, 0.012082943642911102, 0.0471630997822753, 0.018237894933138574, 0.07739840647471802, 0.014480814304468887, 0.03482389636337757, 0.016964242294696823, 0.04187029593491128, 0.01392029264077012, 0.023493437029953514, 0.054386067736361704, 0.014590752244527851, 0.0457352755059089, 0.031804815866053104, 0.06969072363738503, 0.06180896942636796, 0.01664627399960799, 0.04350960261321493, 0.06280284680958305, 0.030251764559320042, 0.0025023097114171833, 0.013054100281026746, 0.014408255162249719, 0.05543565284460783, 0.062533882313541, 0.07557796487318617, 0.04895981301420501, 0.03652645268344453, 0.04240531061909028, 0.01863873440639249, 0.041378446255943606, 0.02025023302329438, 0.05190281955791371, 0.02541299393799688, 0.019633750032101358, 0.05387150749031987, 0.043955220308687, 0.010413888293052358, 0.04669856792315841, 0.018993408053315113, 0.02970453624480537, 0.011473563217025782, 0.031107699165918996, 0.01433060531105314, 0.0494205315065171, 0.026100273576698134, 0.03056587538282786, 0.04817222045468433, 0.03466525487601757, 0.0454971097143633, 0.03671792508768184, 0.04370208603463002, 0.027692422071205716, 0.08371784737599747, 0.014201357960700989, 0.027655104341517602, 0.043834939798606296, 0.03712897142395377, 0.047617036317076, 0.050907581711986234, 0.01615436325248863, 0.01596498752145895, 0.033083647423024685, 0.041545596572437456, 0.010545730191682066, 0.029240621852555444, 0.049844300374388695, 0.034596590524805446, 0.06682335678488016, 0.034523047506809235, 0.022302536826048578, 0.051230102977050204, 0.038514329586178064, 0.03928423273776259, 0.022775267084528292, 0.01789442220303629, 0.03664795794923391, 0.042321976340774975, 0.06214140408805438, 0.043433735612779856, 0.030639143594141518, 0.08965003477143389, 0.05371195676603487, 0.03315143985673785, 0.008891351554276688, 0.05483435885980725, 0.0037838034581259956, 0.04247851436957717, 0.04945942174111094, 0.02274365583434701, 0.09451931741620813, 0.03842966537922621, 0.029584041996193782, 0.03897257821102228, 0.07125064171850681, 0.017622616341603652, 0.02711688866838813, 0.052131621566201956, 0.015265536660860692, 0.0447171031763511, 0.024786996189504862, 0.04300602784912501, 0.02165880217216909, 0.009110199453841363, 0.043138304858335426, 0.022702105742480074, 0.032807822937944105, 0.008511252352036536, 0.014377297002023883, 0.08491341250815562, 0.018686498182692697, 0.03307381205792938, 0.026935093869854296, 0.01721223327331245, 0.02385868225246668, 0.024405751111251966, 0.011026516357170684, 0.030972674089883055, 0.041586362956357856, 0.03089007262938789, 0.01953837345354259, 0.027968619750546556, 0.04722558607214263, 0.026647630812866346, 0.03075397546802248, 0.029254223087004254, 0.017179342984621013, 0.024792563569332873, 0.06127674012844052, 0.0284299658877509, 0.01862541985298906, 0.060531030142945905, 0.0200645722714918, 0.012254833526510214, 0.0021502166179873583, 0.03601061339889254, 0.03189686253400786, 0.013372553728653916, 0.046021403545247655, 0.016083262960559556, 0.03335519713748779, 0.03353812000049012, 0.03131334277402077, 0.05893137026578188, 0.01584730580049966, 0.053965542265879254, 0.05485323231135096, 0.03327531320974231, 0.06605113643620696, 0.02709034607479615, 0.05606511960338269, 0.003534561430569738, 0.11151665356010199, 0.012876820284873247, 0.04278964642435312, 0.005415110632644168, 0.011764811651249017, 0.006366889582880373, 0.041164561840040345, 0.015547942935622163, 0.04339619566287313, 0.020944915479049087, 0.06479961252106087, 0.04791933723858424, 0.041742700817329545, 0.003311542236977922, 0.017477031564339995, 0.022848430122914057, 0.01564388269824641, 0.017004772887698243, 0.044221921890441857, 0.016203479009813497, 0.02840795590808349, 0.0470501440577209, 0.026562959820564305, 0.05958604120782443, 0.022445295504959564, 0.040917883826685805, 0.03837375070101448, 0.03394153621047735, 0.04918785845594747, 0.03078748831259353, 0.05442463905949678, 0.019354071468114853, 0.05598020773114903, 0.06761787379426615, 0.0620288419138108, 0.030074107128062418, 0.030595191488308564, 0.07934943892593894, 0.03617709535839302, 0.04476134365956698, 0.03782118910125323, 0.016672139754518867, 0.051785171763705354, 0.013876437226177325, 0.020635751175827215, 0.02914604764165623, 0.03451416887609022, 0.07565137557685375, 0.06208796266998563, 0.0049612033596661475, 0.01653015799820423, 0.022095403833580867, 0.011438446485304406, 0.04417725053748914, 0.03184532101399132, 0.00842965766787529, 0.021786534693092108, 0.04145178910610931, 0.06301017318453107, 0.010485009789200765, 0.017333300884014795, 0.04079797311819025, 0.03586058591359428, 0.06223900456513677, 0.09505217096635274, 0.0068589046547588494, 0.04954572121745773, 0.009565539707961892, 0.051831458030002456, 0.011082230019383132, 0.019135798626978482, 0.011673813319898077, 0.02351054289777364, 0.04849627860156553, 0.05100634587662561, 0.021864505152084997, 0.02969201048836112, 0.0367404863770519, 0.027021573157981038, 0.04820628630529557, 0.023790095932781696, 0.00853385859435158, 0.0649105462112597, 0.006855291031700159, 0.040743191593459675, 0.008616367604450455, 0.049591654645545144, 0.06372142716177873, 0.0024507075473333573, 0.051154822909406254, 0.016385204258507917, 0.13327338360249996, 0.15709484820919378, 0.1252258090036256, 0.1053570280117648, 0.14592096422399792, 0.14034878036805562, 0.10849647383604731, 0.15876476360218866, 0.10430866426655225, 0.13223399009023393, 0.14096417091786861, 0.15239782524960382, 0.12414408847689629, 0.10523798582809311, 0.1709517410823277, 0.12480769572513443, 0.15454624353774957, 0.23417017023478234, 0.1395212933421135, 0.08869881009949104, 0.15179819028292382, 0.145276830930795, 0.08241569796311003, 0.14766554561044487, 0.0878232488674777, 0.12174803204834461, 0.11977364442178182, 0.25957978676472393, 0.12682967579790524, 0.1073083725890943, 0.13010252160685404, 0.12466384630118098, 0.11106419283896685, 0.19217373803257942, 0.17645835131406784, 0.13254758183445248, 0.13853618263133935, 0.155935245433024, 0.11732136458158493, 0.09389498377484934, 0.1541928896414382, 0.09958313605082886, 0.15944070661706583, 0.177748884207436, 0.10017091022538287, 0.055530003138950894, 0.14043485932052135, 0.11805026046931744, 0.13287905976176262, 0.07733745367399283, 0.09303325108651604, 0.16740700629140648, 0.11574393351163183, 0.15461611907396997, 0.10698973932968718, 0.14728553885860102, 0.09881029823528868, 0.08424469589122704, 0.08746341496173825, 0.08285030642790453, 0.1468817698104041, 0.17284703866711684, 0.162033809615033, 0.12197032012045383, 0.264161472341844, 0.1316986395312207, 0.10564772598445415, 0.14390134545309202, 0.0875166528193014, 0.07108958464648042, 0.12033108808100224, 0.23848038752164158, 0.15628699798669132, 0.14570381944733007, 0.0686857725626656, 0.11380552181175776, 0.14835699993584836, 0.1148967689701489, 0.12102429302675383, 0.15658049152365752, 0.0981734116960849, 0.11850193408983094, 0.16847818238394602, 0.13801003300717898, 0.0840121212282351, 0.2471463925072125, 0.13865873962640762, 0.18549308579947266, 0.1299920425351177, 0.132119195535779, 0.08790127360927207, 0.17310929245182446, 0.12735589327556746, 0.09625422289328915, 0.0866784652961152, 0.10364469739475421, 0.1316641970936741, 0.11269490926393441, 0.1392376385629177, 0.11159775885088102, 0.08548398581998688, 0.04874645785561629, 0.13129533188683645, 0.15536991719688686, 0.09280442193682704, 0.256974103727511, 0.10939288644918374, 0.1030452184911285, 0.1708319660808359, 0.12000617837267262, 0.16139811729746206, 0.27468492622886387, 0.12203806505671569, 0.16204425905432018, 0.08991223427334002, 0.18472791542964323, 0.11533286342663424, 0.0718081532312291, 0.14555330680949347, 0.19368414341339044, 0.08875594953341143, 0.08485600844557796, 0.1789410023816994, 0.16386916541627475, 0.15758187350417885, 0.18226237701518194, 0.11183512397110462, 0.17219394871166774, 0.12646854589028017, 0.14545110586498464, 0.11128894399319376, 0.07905809634498187, 0.09630575084260531, 0.1256145281451089, 0.1853427631514413, 0.092354621072965, 0.16505257120089872, 0.08955994567700795, 0.07411450054496527, 0.08757598392133202, 0.10251896030136518, 0.13580035657754966, 0.2143341489136219, 0.2056500134723527, 0.1164561781500067, 0.1546240850750889, 0.17659738313938889, 0.09444971329399518, 0.11060175086770739, 0.15725737091686043, 0.12581983927105153, 0.14669477912996495, 0.06297781384949173, 0.15344447908656939, 0.09670103820306913, 0.11550963536969253, 0.1512565700603383, 0.16652831701295717, 0.13147943200809614, 0.09901940915733576, 0.106014888068395, 0.07465703678982598, 0.19239415334803717, 0.09339408922408308, 0.1315078761960779, 0.10713112567152296, 0.07844265151236739, 0.1106075659128172, 0.1560822975422655, 0.08863100409507751, 0.052998911456338, 0.13784790384982312, 0.16700812269534382, 0.07987929335130112, 0.12100213207304478, 0.06362189285989318], [0.019751251941280704, 0.01844424082498465, 0.039862212259322405, 0.04235147225803562, 0.07874164118298463, 0.056884230114519596, 0.10390659155590193, 0.021756272031260387, 0.037466929360691986, 0.03767060521723969, 0.061196924054196904, 0.03599561098963022, 0.026093349126832824, 0.036125916854611466, 0.04490293695458344, 0.012936426193586417, 0.014780872667740499, 0.04555516856323395, 0.024144661014101336, 0.017802180456263677, 0.046671830250748565, 0.034391140299183984, 0.08391267513590199, 0.07006781947399889, 0.01475737160736961, 0.02454261671352599, 0.02487577571134482, 0.028582775366625617, 0.015620795544236898, 0.059392631586108885, 0.04715355618723801, 0.02956431019785149, 0.0068883734306187504, 0.0340757538298411, 0.025353544092338, 0.002935860721793558, 0.07937575251396213, 0.0505902139203889, 0.022037991289315478, 0.1117380391806364, 0.020131419845191494, 0.03653959929943085, 0.022338042867236903, 0.025240327131801417, 0.03217237828565495, 0.043039530515670776, 0.021704942553437183, 0.11473231922302927, 0.02618714132612305, 0.047545304987579584, 0.024686472922829644, 0.04703291605359741, 0.02646792590218995, 0.0263754280084478, 0.06223333879773106, 0.056576840180371485, 0.02337485285741942, 0.011412182091070073, 0.04030526848509908, 0.05257909505495003, 0.04495472274720669, 0.04130822805953877, 0.014172719542070158, 0.03093164986265557, 0.04384385235607624, 0.03988428161080394, 0.11787822470068932, 0.019875600268798213, 0.05285454634577036, 0.026167333192591156, 0.08069052946354661, 0.04678778849276049, 0.09237438679805823, 0.012827969156205654, 0.045544400212488005, 0.054926666763744185, 0.08304797046418701, 0.04543416541335838, 0.036204111230160506, 0.09072572990719761, 0.03225568542256951, 0.039561397329505, 0.013844714865886738, 0.04147119860031775, 0.017839197934206043, 0.04136720632335969, 0.04387598777455943, 0.008835800740468715, 0.023264102371675626, 0.0637667193742735, 0.05252716337729778, 0.043099730142525265, 0.010185300871463758, 0.012517397740988858, 0.06585596940879311, 0.06336654656167541, 0.010440744709090462, 0.004561114939861, 0.07739431490855557, 0.02523774021704282, 0.027652086557022164, 0.05165880818718246, 0.04123971298603075, 0.02268642310186156, 0.08045758160629443, 0.02692364528775215, 0.032485132039125474, 0.038611031004360745, 0.027368737118584768, 0.006830870132294616, 0.020119477628863285, 0.02348248377841498, 0.03678594822330134, 0.029645876892443215, 0.01877476880326867, 0.02501346403732896, 0.027655628509819508, 0.032861199895186086, 0.012388753438634532, 0.014130363689868577, 0.05568719595404608, 0.004730443777849099, 0.02192924078553915, 0.015141815978235431, 0.03993087661053453, 0.04772836355758565, 0.023882073050897037, 0.04081711459106632, 0.014799535773428423, 0.02623521553219429, 0.004141460538708738, 0.03327601210081151, 0.05012043359290276, 0.031472255675388236, 0.040552146666284115, 0.04003249740760241, 0.012517245070609664, 0.02333775395527482, 0.02713444915467075, 0.038370093397263966, 0.008257749124563165, 0.04721913320411529, 0.052913449970739226, 0.009477128291369548, 0.023616277313392078, 0.016122071770951152, 0.03594655290778194, 0.031208956946751902, 0.025789742025413682, 0.03466772474348545, 0.05478651535564235, 0.05871535864259515, 0.018703502270260026, 0.0050905584274525085, 0.05291179773796882, 0.040236461641533036, 0.03199710251231279, 0.05111232965386339, 0.04955697472074202, 0.023463469530854906, 0.03566604992374778, 0.028863956885678426, 0.03455386996003134, 0.03092334120135222, 0.032886434612529616, 0.04445063568917768, 0.10780104329543454, 0.016262014529534748, 0.029612984907414232, 0.05776939940239702, 0.026331704908183644, 0.009418261985826706, 0.043960784295839925, 0.013302953847284828, 0.01944148543822978, 0.08321764493095023, 0.054904811150793514, 0.02061115258506366, 0.01093342644162476, 0.04376860960785832, 0.05690881683092032, 0.019487865003091947, 0.0871499182124223, 0.045186204968818595, 0.015914940474820987, 0.010022461796844644, 0.04325598318661962, 0.02688876349878098, 0.06616563243525368, 0.025726473723937358, 0.029196462793541805, 0.028251716434689503, 0.03463229164481163, 0.012092383761358048, 0.01768396608531475, 0.016145947721919844, 0.03551811911165714, 0.02357454232073256, 0.07658651218350444, 0.023343277230326618, 0.032661887018808296, 0.013150587960678552, 0.04332430827032242, 0.014725137801308717, 0.011391609757473426, 0.035555014453296147, 0.03500884465341057, 0.061901562315012724, 0.040144377654152255, 0.0134519957604685, 0.019387803140229413, 0.026794243570683256, 0.019556659972295165, 0.03647374747587102, 0.05726498325488397, 0.09159312836293663, 0.04311907517590693, 0.02018532097073538, 0.01509920397906431, 0.015439243321972234, 0.04933909373357892, 0.033317976099039824, 0.04360980187941875, 0.03162624919787049, 0.017278619443199465, 0.021019874938896725, 0.023429356182792356, 0.027564499560477476, 0.013281259386401092, 0.03521996743178793, 0.02946830427806292, 0.009887331547880811, 0.029411531253052608, 0.01581177261791059, 0.04399093499939356, 0.0367972661874124, 0.0417213846397187, 0.03777890279889107, 0.0306259494807039, 0.021031467709690332, 0.015182485670915671, 0.05532279211495604, 0.05933581106364727, 0.005427500682084688, 0.019847771851345897, 0.03228171741855996, 0.048993834760040045, 0.011136969135675048, 0.08205832713948828, 0.06779525641884122, 0.04085462400689721, 0.017783709036718522, 0.008253957810146468, 0.019937871123797128, 0.04495131989408817, 0.05427819763177207, 0.04581184818276337, 0.02050095340902252, 0.020743329510358826, 0.024966891089986478, 0.0395191245978432, 0.029103171013827835, 0.030057035186993222, 0.06410009719963584, 0.0515569736515837, 0.06122826558670827, 0.03499749954789877, 0.015472067453499352, 0.020874946644263606, 0.048832031299493144, 0.0373729929727103, 0.08737612143158913, 0.033959235796438794, 0.03083506040275097, 0.023258529902834977, 0.054985706095716784, 0.06244400356497083, 0.005815930173931909, 0.024801240335883837, 0.027150876487472227, 0.07915135419794492, 0.061874156285609515, 0.059827565747712336, 0.05146925603704793, 0.022958025402788605, 0.013307399099825748, 0.028835665368075882, 0.03663369853581701, 0.029844864072012048, 0.05631639129881348, 0.0014157829303128111, 0.007787940807507506, 0.0029951566248200834, 0.031782967038452625, 0.0347212645491319, 0.01443162390829197, 0.036071196398032565, 0.03319244712058987, 0.01803419193519013, 0.025552627963146994, 0.04685880396781223, 0.04786169229607497, 0.03525169912193503, 0.03462382692045399, 0.02259957231581211, 0.02486124149124537, 0.034534697953079424, 0.011548180864857776, 0.008556845664445843, 0.05623435302238379, 0.017038791240858178, 0.027184945730758563, 0.025826359167695045, 0.03487550912957106, 0.03999066911637783, 0.012274533094439124, 0.04837428139788764, 0.013353370695507951, 0.03960338168378387, 0.041128806437232664, 0.06668024017874684, 0.048664076919002194, 0.026065653023709143, 0.016428328551618115, 0.022728592356933013, 0.05960519625140088, 0.02151854898381446, 0.08482394088059664, 0.047955282631197145, 0.015294175927660294, 0.08553651800113064, 0.037525951729289124, 0.02778424651894186, 0.014139725776788379, 0.03025833617097565, 0.0015148691870438466, 0.018328783002548983, 0.06675301305949688, 0.04656466582257833, 0.02419667411595583, 0.017970085642965775, 0.011167984971377467, 0.0466055441647768, 0.0303606253250369, 0.03398165798613003, 0.044114031429801664, 0.014219207672535308, 0.062034541607967446, 0.022751038295349905, 0.012183989381550677, 0.003043161069009719, 0.06593272529010262, 0.1434834628765072, 0.1056523739493319, 0.0819405402456011, 0.12923946577523435, 0.16082890784101828, 0.07614910136908293, 0.18582372234335967, 0.10182693600654602, 0.07843575081122772, 0.127751424908638, 0.12695339987320559, 0.13744019929851803, 0.23024875351360866, 0.13041631691157818, 0.1254450436681509, 0.12891731091908046, 0.07030488603881427, 0.09890112014753477, 0.09125993374202933, 0.08204339936907802, 0.1628623687263046, 0.09426307545176574, 0.19156313793999807, 0.13039077685347625, 0.09646410734525748, 0.08309191239199468, 0.14754172654024192, 0.14586996553199633, 0.08918966233198132, 0.1684238181582519, 0.1121431313721197, 0.142503006915961, 0.09770580607333354, 0.11474141159227916, 0.15203170132424149, 0.11475005612841674, 0.16019041995917047, 0.16101592566285813, 0.1750908318374838, 0.17053171433508396, 0.12884447697017873, 0.07639101945928164, 0.05427896776901824, 0.1261681177254234, 0.12152958448444094, 0.09165342977004391, 0.09365415812603065, 0.27695989129798754, 0.0806737153657845, 0.20604831352829933, 0.10287002753466368, 0.07929558360150882, 0.10255306347140244, 0.13104607883308614, 0.09558755545211689, 0.12102855422667094, 0.08306699658610991, 0.05557617744696992, 0.26339152508548325, 0.20485705030815943, 0.13223739633602755, 0.148398756980896, 0.18580314916159424, 0.13466364757290908, 0.13766825491828577, 0.09634159106229033, 0.19405127157058033, 0.12109096587768622, 0.1300878652504512, 0.13730033966047422, 0.22578232389475617, 0.1097736938723496, 0.11421858678971018, 0.17624198006732122, 0.08461483674389975, 0.12365179775016648, 0.1593595945409366, 0.1767906163419996, 0.1092327521847827, 0.1893957478127309, 0.10274936365229742, 0.12155705158199583, 0.11202514770307712, 0.129974115639925, 0.12399299229894366, 0.10761600001049892, 0.0876029964004244, 0.11776009175394263, 0.1342052293143102, 0.21170251869729587, 0.07263317717505352, 0.15973741641002043, 0.1149572671524116, 0.09366093669086695, 0.139628176178251, 0.23575756219880922, 0.09030668025038072, 0.11512667020516736, 0.15230371244251728, 0.14303277991712093, 0.10963064511971814, 0.1281369820769344, 0.12384850505207266, 0.054534086758004766, 0.17753156301166328, 0.12160437261419636, 0.2325338694666113, 0.0899309211277536, 0.08660328361604895, 0.12298768838601452, 0.08970769667731864, 0.09784730776612248, 0.16889978333243302, 0.13724619256598608, 0.1279411975826536, 0.08681384660303593, 0.08283956521855933, 0.125217164467488, 0.10968971837844167, 0.10647696363074438, 0.2507623870457922, 0.14162047712930612, 0.0845621484997017, 0.11924248720918383, 0.10472673004759209, 0.19202598024691853, 0.11776059386985642, 0.1659967933914491, 0.133767465661679, 0.10251385771802493, 0.1468285998063428, 0.13893438769238337, 0.16016569414309093, 0.13959519937634468, 0.16228694388908999, 0.1088828384610159, 0.09870586491056851, 0.09115522900330168, 0.08592169518981661, 0.18208335233586176, 0.14584897165851934, 0.12130327948502131, 0.10367807453232152, 0.15096650991056645, 0.16643162577279977, 0.12772904682372296, 0.15536493674985, 0.0900314257347158, 0.12559795831995352, 0.19017108263713972, 0.10601382276841573, 0.20726601247276577, 0.11013367705579315, 0.1381521453814847, 0.13016724027693272, 0.11675055378249713, 0.10307729962681021, 0.0935015623856868, 0.12776750618857996, 0.10099653128002371, 0.11942841937499386, 0.11117170671267168, 0.11695435856069837, 0.09782435971179179, 0.1448195661817278, 0.11007442737796477, 0.22643449104257993, 0.14284254583929265, 0.11306830708469663, 0.22748552821576595, 0.07693887541868857, 0.09311927575618029, 0.09244730217116219, 0.0636275043444974, 0.1332929932645389, 0.15827657122697147], [0.023853291291743517, 0.059488155746034214, 0.022394354488434534, 0.025066907151735256, 0.039567660207727125, 0.026399125843974094, 0.030040546786040068, 0.023610012738832405, 0.06901408851678882, 0.033698098201836856, 0.01932439404273672, 0.06590954653386559, 0.03252911128635917, 0.006707352586090565, 0.0322126696950623, 0.018719797288732867, 0.054510046262294054, 0.027037595066108873, 0.024410334615302936, 0.07523492470915828, 0.02603694251073258, 0.012571373505384793, 0.011239264226917709, 0.026702919542523365, 0.01864427125214466, 0.01616873123150851, 0.05409453177292432, 0.03691820826913629, 0.011065057146229913, 0.0017871395269009683, 0.04091244876118643, 0.06521503880087819, 0.0511292964220047, 0.06831600490425314, 0.09630162534969193, 0.005542608634901366, 0.038779548568917174, 0.03898831683077982, 0.03583008576450603, 0.06638186797499657, 0.01697668832327638, 0.01320132880937308, 0.03206586864377771, 0.02439688265855823, 0.06215674576482602, 0.05815180816820689, 0.03631444441686783, 0.05570667330175638, 0.07751310603427035, 0.049232373745845895, 0.040174480860254595, 0.02927822626328894, 0.026400642369740775, 0.031373359196420224, 0.037302696744778326, 0.06499006373009511, 0.014974316216206976, 0.027613133557939103, 0.07030304720891373, 0.017473930659304773, 0.01587458121191178, 0.009811829260018255, 0.07820983936211892, 0.05601391735087548, 0.05987290545765843, 0.008262013717155372, 0.027776132936456373, 0.0300090016930231, 0.013269039818884006, 0.02991586597636342, 0.05358595620574696, 0.021930731866242628, 0.04437842259981802, 0.009594588640279003, 0.04323821574715631, 0.024607708577864935, 0.038231282095823965, 0.030619021638163497, 0.004400409009706761, 0.019279390207624862, 0.05025900062173605, 0.020902439186881696, 0.014212938008962997, 0.03064347604023559, 0.058081267667668204, 0.04275576377819691, 0.05034331877582839, 0.004005226822170828, 0.04984734360394733, 0.047992344213915725, 0.019421419461390803, 0.05222041465874229, 0.04177467338740826, 0.017328440876943723, 0.05130317441320845, 0.06153075649802174, 0.031126806712044135, 0.0340514046006969, 0.020865857667688812, 0.030958587702895914, 0.026539535095383014, 0.08415858979736056, 0.0652649789782507, 0.02293713330956442, 0.05294125294312835, 0.01927460653574339, 0.02844145518195416, 0.03610251757449337, 0.05256285771195378, 0.047708716576120684, 0.009724213425735278, 0.048957617953419685, 0.0333393262034016, 0.0291359713966293, 0.05128628567659429, 0.019552302081137896, 0.03991506335192493, 0.016916514141485095, 0.020840699285534874, 0.04132472324584212, 0.024559595356030122, 0.029161131475120783, 0.026844453465725695, 0.1226703239870923, 0.025432549317234328, 0.011280225689655967, 0.038115032083754025, 0.06685061353657927, 0.053877264859953096, 0.06101617589592934, 0.0248490278609097, 0.09636442376566784, 0.024496023410132954, 0.04574855782889894, 0.007911268787990724, 0.0027958219080963837, 0.022308614803478122, 0.04265628715178796, 0.05661746746461306, 0.01618836633861065, 0.012728147325105965, 0.03632682768095817, 0.03080194110849074, 0.03558374023331063, 0.047408739637051306, 0.05577816714399627, 0.017752934080947722, 0.009957858477719128, 0.018029783153906465, 0.10939522739499807, 0.011958946457265742, 0.07304115314036608, 0.032119567905153544, 0.02306595996820501, 0.012591666791455021, 0.07794215729726212, 0.029396030120551586, 0.010297371107818825, 0.008730862755328417, 0.012839880838458027, 0.02667748465734933, 0.0283923869220806, 0.021374294135187353, 0.008031529790189649, 0.04144110557224069, 0.02172772097401321, 0.03317122254520655, 0.044396590374942334, 0.06201830426497119, 0.03828676590429885, 0.022219594401706542, 0.04218424391001463, 0.033395369803266864, 0.03258691907727292, 0.043900187725999525, 0.02716324618086219, 0.02439906245230564, 0.04038165456482342, 0.02258449187502265, 0.06125874537974596, 0.04377869603091052, 0.0335053976492158, 0.04198985719787223, 0.04551247853253569, 0.014934645666341697, 0.030889573906149183, 0.02611428702117077, 0.07868741266429424, 0.08472859313977615, 0.04146512231922575, 0.04358213800670845, 0.03023743050705109, 0.02661148694876049, 0.01589459290594927, 0.003701274091976562, 0.04802539226199899, 0.07424869441560336, 0.03150396022413458, 0.022449312432269965, 0.023467605201793567, 0.009948532862056578, 0.05838976361389671, 0.04635665751993656, 0.004350089276808181, 0.005219144206161478, 0.04935621317209942, 0.04502409277483821, 0.028778627714408294, 0.06000860567603793, 0.024654020289225236, 0.07016514853707381, 0.02436309161462954, 0.014722479640373161, 0.04665743852300303, 0.01774298845391188, 0.04226877580263785, 0.020795378235301802, 0.013525338610634208, 0.01746397146156856, 0.01622723282447883, 0.06733881269714662, 0.033388828725687096, 0.03735042829066515, 0.11013464057551962, 0.02674681566921728, 0.01800660270133189, 0.04723205590354545, 0.04325155235294785, 0.05302605964243412, 0.046092137428266663, 0.038355484538312466, 0.09264663540359054, 0.005134485936391034, 0.02608369187717991, 0.041069074999541044, 0.028587491185005223, 0.02622234881190317, 0.05435413248570902, 0.04465684587402003, 0.03635200472282512, 0.021176338328846862, 0.06402636758450951, 0.01770960453099438, 0.02282778569497168, 0.04244412621483207, 0.02928679616057447, 0.055644112373037, 0.008667485040080334, 0.020664202149159143, 0.04427486119259681, 0.056840342469513416, 0.005798595724627376, 0.018807869437815886, 0.007654048036783934, 0.003046398741259639, 0.032048800095383606, 0.034732572335217676, 0.03579283758465733, 0.029499404930642674, 0.006423139287757554, 0.0957682900396841, 0.04976052165563617, 0.013171603038374866, 0.025655519317037294, 0.07040306327066251, 0.06760873392756496, 0.032774578114705424, 0.03784434071608952, 0.05950646262083735, 0.05645357072353363, 0.0019439958310353436, 0.11070221476256847, 0.008737358031794429, 0.004596211739616203, 0.0025291421666874415, 0.0695212527311274, 0.07775207928248815, 0.04018375982663461, 0.07935050422591822, 0.07130358780601195, 0.0678534543673907, 0.013259820224318122, 0.026772920607722232, 0.04119582534102457, 0.051770973418440135, 0.06031679628150804, 0.04757730809173413, 0.02296535867000265, 0.07084930182567664, 0.08129183362637248, 0.03452764797423567, 0.07929106455828462, 0.028155327142615403, 0.0059668859799525565, 0.018658286392954842, 0.051441551452236514, 0.025462360753278648, 0.031517544495207925, 0.0455858213827014, 0.06319468721215214, 0.05948240176907607, 0.018122350597488027, 0.01006433249650789, 0.041403772575514655, 0.043796151344265254, 0.06411484176559107, 0.012013630442587393, 0.07455162637467895, 0.017152293186102594, 0.03419006323175771, 0.01699339215909796, 0.01267649045413626, 0.013457043212838471, 0.03140401201588767, 0.008010831927614552, 0.008818948475111808, 0.05092837881030781, 0.0539092408227069, 0.021707180022661175, 0.040552821808627675, 0.01847455946595541, 0.0022000738868622905, 0.07156637763338429, 0.030920969721462046, 0.08545368244605404, 0.01799701669785593, 0.026503961200692823, 0.09724980339940105, 0.052778397753302536, 0.06089543058936085, 0.03190741714622293, 0.08105930646083184, 0.013753992189387125, 0.01356419746298343, 0.016666387473898273, 0.014450712794704097, 0.0555250294772642, 0.05975095235875674, 0.050424776904817135, 0.025487895722367933, 0.03574287026588406, 0.06731961015611887, 0.010254866826081914, 0.023079537453928163, 0.05695981213024684, 0.0772976575951491, 0.04005678556859493, 0.025783586016456996, 0.0215602483533855, 0.038025760624025545, 0.0357443053674485, 0.03711085453895586, 0.20349210926464625, 0.13458621315658092, 0.1146738159337214, 0.1245174862976585, 0.1332146767526865, 0.14314837514289788, 0.13770291448703834, 0.13619599677622318, 0.1748684894825731, 0.13034319797796862, 0.07480501849204302, 0.1225802552487169, 0.16585666233939783, 0.0956633071015988, 0.1077786719958697, 0.1229783653148583, 0.1917058474251202, 0.08472723606973886, 0.06856163458100387, 0.21751821520073072, 0.17075730008738382, 0.10992848806615386, 0.10265088786504098, 0.1104001309722662, 0.09972596767225436, 0.10704056160258395, 0.20683428778180055, 0.1383175586483308, 0.060371228360704014, 0.10464717181665556, 0.10782400492046561, 0.15453746329460824, 0.1246003218527351, 0.12666579602020128, 0.19511169966842445, 0.08796440450740711, 0.11713623308709689, 0.12262304366699286, 0.07741827398006405, 0.13334765604564122, 0.08708395782325949, 0.17623417691460677, 0.11735625485224382, 0.1561467447983367, 0.11770876736513206, 0.09085195099136659, 0.11984328925609589, 0.1782267221382686, 0.19035135582089424, 0.0998877507767507, 0.1545354276895523, 0.17970161299620355, 0.15018918019320282, 0.15951702823596342, 0.1369604750403336, 0.2271329207079751, 0.12897343933582306, 0.20862001553177834, 0.1008243394483413, 0.12648145162633487, 0.11756303161382675, 0.11167822631874255, 0.1972617192992142, 0.16961315433893884, 0.13055091111787728, 0.13083400949835777, 0.05878418923488685, 0.08125360496342182, 0.1046760706230998, 0.1559177256588425, 0.11175665139619793, 0.10414836036839656, 0.12296214832791261, 0.0980101018877966, 0.11044272261538676, 0.14066629404468195, 0.11817675296749387, 0.05410779034718871, 0.05127987691334315, 0.1597014269126313, 0.11080839870763676, 0.1775396511490856, 0.10992778238973447, 0.0955603394125189, 0.18889900589627878, 0.17174455496881688, 0.11217720740075622, 0.15718507979597363, 0.17675649960126194, 0.13579582396362508, 0.08820888745997633, 0.11706164851784706, 0.17708085291087627, 0.13214301211493357, 0.13806382726345742, 0.22513611428439617, 0.16475701491747582, 0.11907535046339035, 0.13007996710283415, 0.2356656885572842, 0.17067054259989942, 0.17093897105327674, 0.15331797301769257, 0.1602527637566839, 0.17521752789616585, 0.1504785753786564, 0.09352560288139752, 0.1587280819990805, 0.13880385112549576, 0.0800399568730167, 0.17100462610168116, 0.08010258565523795, 0.14292985972549233, 0.1568196751177311, 0.12432086041995458, 0.1057995685509273, 0.11574724476252284, 0.10777108597436122, 0.045289749412664344, 0.1303042500678982, 0.12583985605410167, 0.12025019313607897, 0.14247361277895315, 0.20391197316348553, 0.1820725771997656, 0.1174217334815434, 0.1230829411319324, 0.13053427343922003, 0.23823766197477067, 0.11577769741415977, 0.04357846034690738, 0.16437988515411103, 0.1804103563938822, 0.15087774395942688, 0.10888216671134744, 0.09563033029969249, 0.1420343563492809, 0.10003873838910035, 0.09867655219776289, 0.18500787897833756, 0.161785004394395, 0.09957269339689187, 0.10183838289231062, 0.12648386721100124, 0.10370146363441433, 0.14160217025450297, 0.16679871321788856, 0.13588340926383222, 0.11984118579753808, 0.1561009165431772, 0.07903159276715346, 0.1707890826676573, 0.1889698856643268, 0.1507812834211758, 0.09831933743719544, 0.23141412383743695, 0.14957940791334423, 0.05492871254682541, 0.06663540937006474, 0.11934098335249083, 0.12206611569438662, 0.10941893540854965, 0.0998073715184416, 0.060770227307719846, 0.13256421951310976, 0.16370931613658155, 0.10859425073223454, 0.1339500051523958, 0.19476344835545334, 0.1917671598494053, 0.11978076903947762, 0.13702653720974922, 0.12033373436757497, 0.10373019280710391, 0.19603480584919453, 0.12956170205559048], [0.011366516684315034, 0.020014808513224125, 0.035150047790791304, 0.015328089107892342, 0.020490653247439435, 0.01363805854426963, 0.0342112538803901, 0.02324027900717088, 0.04097995960286685, 0.024631379271990488, 0.00621490367588454, 0.02255097054876387, 0.04192986113152333, 0.0034029449327915373, 0.01612004464758294, 0.048312110626803975, 0.0037594555012349573, 0.043764497685645304, 0.030979506937520843, 0.01636039192921349, 0.024553123828289763, 0.031558680680713484, 0.07383419094341141, 0.008856655514266874, 0.05081295661096062, 0.023117742368153164, 0.030857404560915062, 0.010411592300183006, 0.06777154840528965, 0.02158131347303944, 0.02889584463887981, 0.01273625242590372, 0.03971912618726492, 0.021558574068226984, 0.03884209592693618, 0.04399647184514573, 0.04480929572933486, 0.06380087004176208, 0.01658303792854505, 0.011081991683957832, 0.03710565356803792, 0.005822292287900511, 0.01778457247252975, 0.02441882648106132, 0.11149921521012272, 0.031124431839478866, 0.05201961239799857, 0.04219230829871126, 0.053323149414999146, 0.03387070393988064, 0.004098432512754309, 0.0029760166362393647, 0.018590999467830573, 0.0574252667969891, 0.030793259252927134, 0.02477135256464992, 0.014949083195200987, 0.026166932856930152, 0.04783610813319683, 0.04936298155891044, 0.0005802918946886036, 0.02587154451092439, 0.0360700225324503, 0.0225340377073735, 0.02952630545145699, 0.024105210988117114, 0.01927982277369925, 0.012310282560065389, 0.06703527005655424, 0.0427159100238766, 0.02310483663209847, 0.04147088308153408, 0.025468360699181045, 0.009505217944804047, 0.05383776733651757, 0.033131036308727095, 0.037250072961407046, 0.03269809364740338, 0.0299449445945876, 0.016612128421132053, 0.06029992790094443, 0.04466509685984679, 0.02212332046058561, 0.05223254347220063, 0.014633182735581483, 0.019374673487618566, 0.08733912770237241, 0.020836295593263846, 0.025603731828076497, 0.017286972209279026, 0.04685062422816243, 0.023558226946209158, 0.018965966400823424, 0.04611725340198193, 0.06666177724088941, 0.023485650840614523, 0.03912527573161891, 0.03243871345849974, 0.03601490513288549, 0.038242189546248744, 0.05999626312404871, 0.0192550969576197, 0.027443998526515703, 0.013728889786372227, 0.019128884355138456, 0.04453683338527169, 0.019821768693093742, 0.058319718443921635, 0.04491190040217979, 0.01437890004100544, 0.05751629226974078, 0.03337700864566224, 0.016195406139429127, 0.03155506748173918, 0.037880968036396165, 0.008514629760091858, 0.05553566212100642, 0.05174736039979117, 0.006434983116508062, 0.02943957849804844, 0.07559199019202165, 0.013850716508126684, 0.028292168996163776, 0.017281842484538044, 0.05198519370917763, 0.02825683428506766, 0.01733383353400443, 0.026453206781297922, 0.03419255345527615, 0.013107028556987643, 0.08250310005886213, 0.024712301358314495, 0.0014703478539429072, 0.044293931419295926, 0.04199896313782249, 0.036125482592199526, 0.011853751476987131, 0.04169378862051027, 0.027626420969941785, 0.02993859350681305, 0.10921945968376738, 0.04820447800947087, 0.020723473879375627, 0.024641996648694788, 0.05986317526549101, 0.02072239331235843, 0.023995211979906474, 0.05661678553691932, 0.062278576727424345, 0.031303639723254104, 0.06572253549737589, 0.04216173351077097, 0.03779956419020891, 0.04191736251647983, 0.015333385073712893, 0.023843299863593917, 0.021982047773365463, 0.0128506008435839, 0.026113007982660617, 0.06000277706022773, 0.00910247433265405, 0.011536431182841105, 0.04479013390040823, 0.04288597804095064, 0.05831688216754368, 0.026086049786369716, 0.057994075917771885, 0.02453311383058982, 0.02394365519285202, 0.05820773980979409, 0.02001016054834638, 0.04915916321000882, 0.02681224001571536, 0.022533644157062684, 0.03743060398846865, 0.024709073227963278, 0.011664143347713565, 0.021180482481473258, 0.03848942056564348, 0.030343298933335712, 0.019631341232785156, 0.023128661692940762, 0.04525165306404233, 0.048074114469013045, 0.04804426910621779, 0.042168912411268265, 0.03692031851304429, 0.008712780645250209, 0.012598659942990966, 0.03201206081679889, 0.010976752598903008, 0.04028942469241364, 0.004552748178996677, 0.048112237959035804, 0.037164353632501194, 0.02016883935513241, 0.01033373804031206, 0.10420547266091619, 0.061253893854362626, 0.014169918888780688, 0.0505756050614374, 0.023554589998509203, 0.07884132476257426, 0.05428471835330129, 0.044465926475822926, 0.031490939137126715, 0.03745874962104218, 0.021161809197760055, 0.07715073440756116, 0.07814868300088815, 0.028191572786974053, 0.04937092720397881, 0.0324149375914463, 0.03604153423969235, 0.014845223232571567, 0.00931096778783415, 0.06447036018861191, 0.02679912563014243, 0.034620284967656643, 0.013510686495075268, 0.02577558608858713, 0.02115185508903648, 0.02248491855737354, 0.04283512184130294, 0.034669546610010524, 0.03049956215545535, 0.030386392692370073, 0.019731854321435094, 0.04903544931273375, 0.084908696689776, 0.006832660192490688, 0.03511697260130729, 0.025047212672818984, 0.030403023585677147, 0.04023869062906929, 0.07262648681976966, 0.058526624127158096, 0.012133177286679191, 0.044829882481800656, 0.022859675144510608, 0.05049647770023771, 0.04224852831768138, 0.02684760356454977, 0.007573771406896412, 0.05488265358975955, 0.006217220872973225, 0.03514214625049915, 0.05496048494907362, 0.025647560101268545, 0.01804210534984512, 0.05304350477776357, 0.042798891463982205, 0.03209802781098655, 0.058987444399722984, 0.0882488124604736, 0.04978981401239123, 0.026389412615182142, 0.016614912111046057, 0.0202752489130944, 0.030036224517971277, 0.010141891593645726, 0.05033033500824656, 0.0037056794805851367, 0.031677325921399255, 0.031209713513297693, 0.02086181190264012, 0.030317416215049367, 0.033396326537643156, 0.01739198568144015, 0.00333058214164339, 0.0420768759213388, 0.08585169751729284, 0.04037067586822169, 0.04738997135843549, 0.021363323920273354, 0.0624053134982075, 0.01864656470050769, 0.050989016092249324, 0.016979653521307876, 0.020470960464860712, 0.0620120210306985, 0.036887144935982566, 0.029119360859372785, 0.018608368267970424, 0.01782283845490643, 0.018011788405211906, 0.08025398717394897, 0.022033136371257048, 0.11901795997151307, 0.01247109705582261, 0.10104755032807589, 0.019107727633256997, 0.02305739346359457, 0.021796878959451402, 0.03057616197371057, 0.024001030417691385, 0.01269721206543701, 0.03934177250734397, 0.03911522662799273, 0.013804566797002085, 0.06563641583280903, 0.06305028138948338, 0.036820587436003346, 0.06327470684690134, 0.025235818266602497, 0.02511516456226153, 0.05291732440569571, 0.0403229307516345, 0.014423970033281615, 0.02898783023868288, 0.015415774492014731, 0.020248246612027287, 0.03910467201577766, 0.05073531184877668, 0.016021363603483354, 0.005153031146619469, 0.058250630008322854, 0.008370521644662534, 0.047614149150571654, 0.03841640001961163, 0.028701943079275743, 0.07164089434913226, 0.05778394040784665, 0.06809872442058154, 0.03154667739623359, 0.02244985526028488, 0.057034864888659546, 0.03842381640736546, 0.031600020426724634, 0.03766903440867152, 0.0475426349522812, 0.01794203500529485, 0.013562316224644226, 0.03533318778499961, 0.06479681017143385, 0.052969195015196285, 0.09817950494055237, 0.03862237271719745, 0.03712249141452568, 0.05601281812414527, 0.046405101527592967, 0.05630259668188436, 0.024181108522628034, 0.03441320625799043, 0.014021578411172544, 0.018445560575595925, 0.09177094524992363, 0.0326489303926272, 0.026267490050356303, 0.025186037544959357, 0.02489612328021654, 0.021693454955571463, 0.10015915799885988, 0.1146713053541524, 0.1033895139449409, 0.14379809956465447, 0.20153570281607763, 0.10339183453470469, 0.16974679859621183, 0.09940067119896412, 0.10745427797415427, 0.04903943231329322, 0.09531102529061691, 0.1196088825485536, 0.18244512006640434, 0.1391770046736513, 0.0861554980011923, 0.12239581585994788, 0.08549220287906271, 0.11054548674396106, 0.12160077637859754, 0.1451478549944503, 0.11336078281913485, 0.2885732352733612, 0.1496930896703686, 0.08946855379534618, 0.11185730528086424, 0.1539650240114757, 0.2940865494310856, 0.09324067245636668, 0.26043522943343433, 0.09124514167862278, 0.09028255833046776, 0.11152782903185912, 0.100184704842312, 0.12421864590474538, 0.1692145150154829, 0.15401569700666837, 0.11949997767806053, 0.14055996760725975, 0.13426922873726913, 0.06045208937887635, 0.09594794575657163, 0.11104184868080275, 0.09352665461067643, 0.09997781951512609, 0.1764484854148967, 0.09892914364380495, 0.19407511529113564, 0.18103635923138686, 0.18544731182711466, 0.07900651411286422, 0.06720311247876712, 0.16221177577972412, 0.22511442830520018, 0.21522772525038036, 0.11665331971432481, 0.11107642682535307, 0.09176485879080636, 0.1993407370256526, 0.124187704707895, 0.10791806344475065, 0.10933119404528822, 0.20813047965722425, 0.10099049231835774, 0.17198249005845614, 0.10598415721740041, 0.10925185294555766, 0.07027384306171111, 0.11841533945075103, 0.1499942642237459, 0.15092042381209986, 0.1505403220653534, 0.17137803749314376, 0.17391556847308362, 0.1477263830602169, 0.1740129246775593, 0.15344624327761786, 0.10621261317282915, 0.11165411118417978, 0.14889890514314175, 0.09978778899780341, 0.1646134504782302, 0.22802858693259104, 0.11597109346517495, 0.12185254001191684, 0.07272207883319684, 0.09173109488827841, 0.14323076286486217, 0.11325326216007982, 0.11969995551875659, 0.10960037567253623, 0.09440728449927908, 0.08548249982829605, 0.1426075827330351, 0.1274864434131554, 0.17841979249247483, 0.21754535660147667, 0.11714755105120794, 0.17731388897768088, 0.1506295901324068, 0.16283502376505307, 0.13045781611331872, 0.13155097674046243, 0.13485439733735152, 0.10000538160758358, 0.14220204949378967, 0.13654777647129127, 0.07588132430932351, 0.0841145393039499, 0.11723179795912334, 0.12569663088236535, 0.17338736967316695, 0.07447713001498155, 0.18188379518687725, 0.0847344013995358, 0.1169675492814609, 0.1018678652388709, 0.16173483351511614, 0.15975955022232874, 0.13863165250846318, 0.14642746347401822, 0.11477361486426421, 0.07537399724658046, 0.07474756693201405, 0.10931106191128492, 0.19344510909702095, 0.10658236726054124, 0.1406482450131859, 0.12601483666471072, 0.13135131102587494, 0.14505268367273466, 0.16173100657761097, 0.12118578436119215, 0.1430309885846717, 0.13754991841103348, 0.08622805375073637, 0.08708804260407176, 0.2418139215026583, 0.15284616047782557, 0.08100296769823347, 0.06559465878776141, 0.2516062674777848, 0.14400444206382546, 0.08756070331271205, 0.12127626022057873, 0.19125485233962536, 0.14029706242893422, 0.18167304221008504, 0.23087767405169352, 0.08736696120883737, 0.16027609179062502, 0.1369692688541753, 0.15733621668602737, 0.17486991440611227, 0.14125136764986174, 0.10273934169007198, 0.09484485816210508, 0.09660218922155243, 0.1378924021763461, 0.15156987681984901, 0.15012120455503464, 0.2090687985931124, 0.09413800109177828, 0.08787045454872505, 0.14505052593137535, 0.0985543073288032, 0.1642747800797224, 0.1827976054378918, 0.11438923834690026, 0.09962255893541233, 0.17595395552260534, 0.11590022726782731, 0.09928789189351456, 0.08497952896037272, 0.1279555553836482, 0.1002541325454201, 0.10553380674017326], [0.048091851374400515, 0.009379116452432104, 0.021021130228681222, 0.03618610969611576, 0.010050817775273961, 0.02027775440365076, 0.00684325212413179, 0.04536788272006171, 0.06299646677715437, 0.09665248223713466, 0.03756127965503505, 0.06475360106144633, 0.015635998121329715, 0.010683097909869892, 0.0452099503017962, 0.007212281875711466, 0.04038998018950224, 0.06934692351413624, 0.038374829571694136, 0.07826038343565804, 0.07270886097103357, 0.029969175080103532, 0.06702246610075235, 0.016495038721976534, 0.07628315953271729, 0.012400436963486885, 0.042072065108056576, 0.03723083310095327, 0.04330335171627147, 0.056274827636246166, 0.03187354128541691, 0.0457313569661762, 0.06787189694919757, 0.07278514866318021, 0.025978021922388246, 0.011246421923195677, 0.009893606300465763, 0.057611653581261635, 0.04397623114553945, 0.017983193243188516, 0.03164907172322273, 0.05087965660329376, 0.03326197660395077, 0.05708396368260894, 0.010388753659624075, 0.0340197814761528, 0.029078926957611526, 0.040262890580509386, 0.021466512133234313, 0.01672027842141688, 0.029628882982901165, 0.039923575573733876, 0.03784878172778657, 0.027157161418082457, 0.014403714066637414, 0.003900000883731991, 0.06467926076480321, 0.03370955526562674, 0.04938254372349807, 0.04267752529787166, 0.039968565838145356, 0.012690228243757571, 0.04656549024262598, 0.03653970107968364, 0.062400645177279196, 0.0261525258621467, 0.015219620196148753, 0.02378555653350694, 0.036396245206041, 0.02929638386038797, 0.03454849596268364, 0.05040471940966589, 0.016905313224664757, 0.03506242856383324, 0.005070192622952163, 0.046967746157731326, 0.04942993260920048, 0.043628196963774304, 0.046272780413606336, 0.038544765274439535, 0.050530624975051196, 0.011451784787433488, 0.03516967102353062, 0.031146738678216934, 0.013115746883808501, 0.04634269326925278, 0.016762730964858617, 0.01097384253184178, 0.038921837362327745, 0.10685384233615228, 0.02261764509603381, 0.04593416769057512, 0.020945327689072916, 0.027975781687668393, 0.0331705915076392, 0.010709492073926543, 0.04035021125205925, 0.04792015487328172, 0.026230469179738845, 0.054566042364708016, 0.03029294145692672, 0.034119956993630955, 0.024496203221912895, 0.03670676318662507, 0.03272198486540999, 0.03397995825590832, 0.025909832545689175, 0.0691535681752222, 0.07075603040201323, 0.05775772860007627, 0.02642976848541626, 0.04255104637039559, 0.021962351598111645, 0.0236590385902673, 0.038996279439223666, 0.03617523617244192, 0.020951242818097984, 0.02920250854055796, 0.061281089537910054, 0.021906201128980944, 0.045252206070082526, 0.017981452800865685, 0.013579559495805629, 0.032044233554708104, 0.012967822857068052, 0.040036361664533615, 0.04863399746162551, 0.01487733659866665, 0.015508504784000772, 0.01779533064525042, 0.04018215509131551, 0.030407566377626996, 0.0489445086568594, 0.034976407286844084, 0.030106836264686923, 0.04929319762491754, 0.005293403926771134, 0.029407799310450043, 0.05052385998091527, 0.019454079048175896, 0.02917326707392931, 0.03782528066741569, 0.015345761552453041, 0.022599931939371994, 0.04106719545753939, 0.03615668841770717, 0.015670382883399725, 0.05212819157168269, 0.03291868877464107, 0.038985260030520816, 0.021108260910425867, 0.02084007503331772, 0.014229457792160767, 0.03614986914076975, 0.02985205315053463, 0.022295183202783977, 0.024516274287764515, 0.03538478358781763, 0.03175654149215136, 0.013566181329744203, 0.07659171654709748, 0.012168025997068201, 0.01764399528370372, 0.0705253149249724, 0.12435447504477841, 0.011510370349112366, 0.034222978965512345, 0.051402735856494734, 0.04563186676906688, 0.016445663425007036, 0.03396147496200033, 0.029641429095395973, 0.02130619975339089, 0.053582597457404645, 0.07600103824266366, 0.00732670069139983, 0.01354850803701473, 0.011431559354865124, 0.047553274381373606, 0.022263093585414544, 0.021437467441761067, 0.006794141031735177, 0.050893363010670455, 0.045515328379614015, 0.016722875514200757, 0.02244366193190217, 0.01747175765090755, 0.024471998181460158, 0.03889273499537792, 0.0445996318012476, 0.00809568866887795, 0.035855004963065894, 0.0493506491849465, 0.016691142127716115, 0.045294743430401595, 0.028399538681177155, 0.049571264668234756, 0.01897025474214128, 0.008015498552205307, 0.01712309243157506, 0.036078867236418385, 0.01677258838234203, 0.04745163322825517, 0.02527358552574047, 0.07612535942878042, 0.05423433712816664, 0.018368745322472284, 0.03139207997758474, 0.02503308218105563, 0.05237052696091788, 0.05159174517861434, 0.045653193124703, 0.02315974877482014, 0.027585501915642192, 0.03496747098064848, 0.012270684952714613, 0.038404854746269326, 0.0400971651875547, 0.02309923871819462, 0.06700797937810421, 0.02957798946382744, 0.007336034788750112, 0.02522916523074465, 0.056446961792452, 0.038011748875890455, 0.03877528736900006, 0.072298883327416, 0.02788839316261666, 0.039017992559820414, 0.01376126184394317, 0.016963674021618705, 0.007513458973595074, 0.02535152545065752, 0.026028995169326663, 0.006717025950950171, 0.07290873024612665, 0.01726374595559069, 0.03837472439876624, 0.012765305599064698, 0.06146208875413452, 0.041314894666096995, 0.007833370423343564, 0.027643730398267508, 0.049993418622761965, 0.015434714100722755, 0.027615854483363882, 0.05699895681547267, 0.047517132213605304, 0.0560044687507408, 0.06494514471186058, 0.03468218432473285, 0.014123263669067194, 0.06519308819302491, 0.00472308845824695, 0.052172157248216014, 0.02781502826006285, 0.04782523800219808, 0.017647116544789503, 0.017412048265604035, 0.010725458851084113, 0.012830177787691355, 0.027060612670278976, 0.00963224224480135, 0.044248863123357296, 0.07578500626342637, 0.06291741744748183, 0.020001800996916633, 0.045957054676754136, 0.04094859432162983, 0.029399222627814327, 0.009151534959008651, 0.07032578491738864, 0.027064090162249546, 0.01646366835172687, 0.06892332088734422, 0.03642568684050015, 0.041609368686165125, 0.03474204468407801, 0.026076937061069266, 0.032710917959255834, 0.017117100967360393, 0.02971553529745766, 0.058335392602852414, 0.0723224352779133, 0.05849752854555845, 0.04854145207043205, 0.03944420415375914, 0.04201526154897042, 0.03768283241827573, 0.025240769875901084, 0.05846960682954107, 0.025281157976548587, 0.026483678092647876, 0.04363215621560812, 0.019696558626102548, 0.0279451526169266, 0.04574368594746504, 0.009829476259515753, 0.0417340868152678, 0.018926419683599045, 0.015262452719200934, 0.0336796013372285, 0.06294341212404625, 0.027217037044465542, 0.035564446090055366, 0.050301378526325734, 0.0341545215674809, 0.03373398931164827, 0.028150601146210517, 0.07381145323493651, 0.03917124308645725, 0.11875597760081291, 0.022226837763030614, 0.057522548362612724, 0.018344660721985356, 0.037543932907283306, 0.02086186109642897, 0.125778231503708, 0.02059365825594536, 0.025133384923849787, 0.03967707397948418, 0.04291425259517772, 0.032011758868715594, 0.039993932869817526, 0.13080069342894213, 0.024921208719855974, 0.009008507410596524, 0.03408300058384027, 0.020820860617927144, 0.043230012258780856, 0.06369469966739416, 0.05084621500489967, 0.020330988868538822, 0.013440297816747, 0.034259477364165444, 0.037701882288924286, 0.009002994313570005, 0.0033008915696492685, 0.021615089249930212, 0.06715942839426653, 0.10456450589533363, 0.03344784430893404, 0.0964569691568613, 0.02643053692632488, 0.030003960177834545, 0.02237915530401681, 0.03397445194423199, 0.010252609848976135, 0.025129676729972874, 0.05096943357161113, 0.0651197996256607, 0.057295062712260654, 0.12227598657565457, 0.1613263011510883, 0.11107527331582137, 0.12144362766827856, 0.22845644397394999, 0.08831019952361073, 0.10082546581647225, 0.1658879563744579, 0.1266445443034172, 0.1411199082753488, 0.1398590680743967, 0.16855829022824764, 0.08055142978472368, 0.0735589364277465, 0.10771054029464722, 0.1555949194090707, 0.06901792902499437, 0.1335641901407923, 0.20362181801881107, 0.09790686278470925, 0.1322376270379339, 0.07692126064960446, 0.20761648938059807, 0.1382360937339919, 0.16713264744196618, 0.10440935207796948, 0.1281819146658693, 0.11882563600582735, 0.13029534768845352, 0.14743812781359467, 0.07722799919013466, 0.12499449641576835, 0.12746223328369005, 0.16852425491171225, 0.1446566634944507, 0.1121214453929237, 0.08277977271271603, 0.09893149816031967, 0.15349243794168743, 0.15634898894599505, 0.17922017882977212, 0.177642856325422, 0.17528059094079904, 0.17785400285252503, 0.07023950240441731, 0.0917186980534877, 0.0900500515209777, 0.10433792269655637, 0.06435682092394147, 0.08082346125905003, 0.13344418443739414, 0.1300070924418313, 0.11090711876749992, 0.11759782688958303, 0.10831327616636242, 0.09711338393390179, 0.15441064509962285, 0.13776623537497862, 0.16062739651118005, 0.19733110629022121, 0.1463550366461277, 0.1385419230375971, 0.07117026246019773, 0.09519942663609982, 0.13880520819553308, 0.10764546200100865, 0.16457313192742212, 0.09790646923439843, 0.12058306884552751, 0.12046104110777378, 0.2129021007567644, 0.15096119019602025, 0.19029738514551095, 0.138904138601252, 0.08636512460985354, 0.14230403330709251, 0.1584498690707343, 0.07719707834933486, 0.12553281895816326, 0.11239978724292346, 0.1600243824401072, 0.18604842600013527, 0.08428531299744334, 0.1252712979912758, 0.0908155000901648, 0.07424451463988849, 0.09021830784955195, 0.1428392617298024, 0.14764191902109555, 0.14216341370982782, 0.10338466241955757, 0.13142487779259682, 0.12194913625717163, 0.071386803340699, 0.12792127579450607, 0.08000219639922891, 0.11746784672141075, 0.2208862051899944, 0.18412118298666819, 0.15435017405876092, 0.08568124952060835, 0.10760031228086778, 0.17774435159351143, 0.08849299007228442, 0.11081285668270928, 0.2347345213804926, 0.10448199603706598, 0.18178011503602776, 0.17630372675401823, 0.15314919421715395, 0.13245277692164692, 0.1295934167823621, 0.1356051420526845, 0.11356351551200662, 0.1841018040265356, 0.14295630902051926, 0.18457757921091147, 0.14897627170596803, 0.15529202137674603, 0.15820489078760147, 0.16927148481564863, 0.12472654293690409, 0.1065988013786929, 0.18983606275703224, 0.10325505544564553, 0.21610902010330132, 0.25311959055917604, 0.09578179967190538, 0.1560086900634425, 0.10977788721876484, 0.08231161069124937, 0.15223956374185427, 0.14546555866088184, 0.15013461240700313, 0.17681196305368627, 0.2781563385256699, 0.08349515896822725, 0.09582969745887177, 0.20475843202854904, 0.09938987570681743, 0.13769767619669437, 0.3415705928845065, 0.1172330193221569, 0.12753247522882052, 0.10491925078843321, 0.11390547002000467, 0.11158398459000246, 0.14530606221939835, 0.19654962393854344, 0.10710111406764813, 0.15746116212436131, 0.09186010475137404, 0.1409798857889005, 0.08280571310647897, 0.11065645436091082, 0.1632034954215799, 0.12285424768924713, 0.1115539933421782, 0.1654952745884657, 0.10633896996400186, 0.1266476112817015, 0.11207765952817031, 0.0866820208196129, 0.24615942261048726, 0.23002459268484796, 0.08722695907843964, 0.1610357795975038, 0.08900877168135983, 0.09208559550877128, 0.1536252950983388, 0.11056912011866059, 0.09830803304378476, 0.10097717267594167, 0.14457857768450463, 0.21341318690351077, 0.09582203679851123], [0.021548513090237975, 0.035179740483207364, 0.024591618816235235, 0.016710349757756506, 0.004996067761177463, 0.054310811417443414, 0.06926665960678033, 0.048238367440977266, 0.023440501120473658, 0.06663164350071124, 0.08309720496514014, 0.033534757859472714, 0.03799874135958297, 0.03404506369094763, 0.01009129747814898, 0.025641200531806265, 0.04961708613804408, 0.037729641156537194, 0.02602215384000114, 0.04317999744255628, 0.061638650351337025, 0.05065650000636067, 0.005587157851550728, 0.020096856967679093, 0.020685319855277027, 0.03796570348952498, 0.07268996377076421, 0.01935195443885667, 0.013612105427975101, 0.02877453954092094, 0.0034547557463935974, 0.010597925649822822, 0.024152501486241817, 0.01288091015469815, 0.01214738326546337, 0.06193806749901601, 0.03827069480238216, 0.05870070228619235, 0.04636370071343013, 0.060155420298022885, 0.03237011017543929, 0.030227167664894035, 0.05811081108238016, 0.01895315565967134, 0.08833897619375161, 0.054589930190039535, 0.01822905701452068, 0.11220396203654152, 0.024684169296441332, 0.0278700489683875, 0.008729936555027962, 0.014928179227613976, 0.013089346782570439, 0.019785762232329165, 0.025015016186184118, 0.02025330509059131, 0.03844371105411223, 0.06608513782599143, 0.026172049010970762, 0.07509149597691638, 0.02090337556520743, 0.11637982938970838, 0.02615904319100082, 0.007836953088242029, 0.02685230750856655, 0.017325965920463204, 0.025662643934733102, 0.015397647428991539, 0.03926862982500877, 0.04323914873280695, 0.038288061906184466, 0.010148806713654526, 0.019794410161141838, 0.018209616986236403, 0.03601170923294766, 0.04959510499611497, 0.05633791442960501, 0.059543849900364876, 0.06331606355628797, 0.02169189602136612, 0.02632205274754337, 0.05168229228417788, 0.019603699412462965, 0.03024677393425788, 0.010639720862465245, 0.003561721915113074, 0.049145646792437346, 0.034486097882368734, 0.03382831585726567, 0.03580944472923875, 0.04617932917816298, 0.03277120240298765, 0.06291330552526883, 0.030109390949032137, 0.005802819181034076, 0.04409533439736281, 0.1134819488174149, 0.10311344518725361, 0.02863107348925301, 0.0526323770172894, 0.07982260175049305, 0.05763880176735776, 0.03311339100556714, 0.043747066121016226, 0.05994575297726052, 0.030085275814469372, 0.03001041304586189, 0.026208988457385982, 0.052453671249427965, 0.00504897440883464, 0.055832073358552795, 0.008889311708376875, 0.03176572885630386, 0.02290406999444323, 0.016562661521935036, 0.017608095692204576, 0.024627263957102383, 0.018848722334951162, 0.032512097020766566, 0.02461817498052759, 0.05981886014342308, 0.026289554312825203, 0.06947117006140095, 0.02828488153006349, 0.07622194210333483, 0.03309727919154933, 0.01640800473147205, 0.010676678968593478, 0.036277576216629574, 0.04749473037996462, 0.06985198426991701, 0.025637770537286997, 0.030265467574021647, 0.02606836037843355, 0.013072844810916908, 0.046785121850137196, 0.03137535408937505, 0.03086675816614713, 0.03911742168877806, 0.011091738839500716, 0.01807989805404629, 0.029768477992287705, 0.02059564975622509, 0.006470236827486328, 0.02137511007354728, 0.04060265342039721, 0.015497015489797508, 0.03853301644059164, 0.014356639003381133, 0.04882089653983712, 0.06100761278399399, 0.04004783908437405, 0.006197946237599743, 0.0431696463908468, 0.023302763600700667, 0.033437971624412706, 0.08101506597761597, 0.05041782192087599, 0.042304432817867825, 0.06522023637912103, 0.02065003603430731, 0.020038202704329575, 0.06285431369074754, 0.05120596070108669, 0.08267096962247576, 0.042501554026135376, 0.02766540111042559, 0.03488044886450682, 0.021114496647247245, 0.05546606478414365, 0.030302512193364755, 0.052764050130333216, 0.04253825259261897, 0.04883410422397511, 0.04656702033909304, 0.04188020254618355, 0.028098813657249724, 0.04819400482145803, 0.021501907912482108, 0.020867374193455492, 0.0359259899040418, 0.019647361444575445, 0.05224159173667431, 0.031076673152191297, 0.054590863175690174, 0.07645920544330563, 0.026590240320989063, 0.009336987909461771, 0.041613711310284476, 0.07286725140043668, 0.009402409711453532, 0.06399457143353564, 0.010310007974372377, 0.011242104744139527, 0.00963764762439366, 0.015699661669454405, 0.049248539842665195, 0.028640654403716326, 0.014972974413207598, 0.017914783342608383, 0.0031970008609018153, 0.012435526553807514, 0.03572335559874773, 0.04308499236192022, 0.034895217179187706, 0.08338296320289373, 0.053886825418365855, 0.0107953734030681, 0.012644937727600336, 0.0539561309851706, 0.007410139294474253, 0.032456138237778626, 0.019307635924113647, 0.019750790537468026, 0.008307692694610782, 0.11576910716082368, 0.019922210535566722, 0.032643458007701805, 0.018551408645829985, 0.04656995839572378, 0.00773016524700714, 0.033563626131841114, 0.009741957116472934, 0.054718529539448876, 0.025108291002522622, 0.0486195921631796, 0.03772255385826741, 0.04755822090165956, 0.028647677241159335, 0.033721090360943756, 0.04494154898981963, 0.018508141860365868, 0.01608113744961364, 0.04297235894149967, 0.03633764013648033, 0.01391816373714911, 0.008723046031913586, 0.07405076575066362, 0.056450995683137856, 0.016584869973095398, 0.0512361758654671, 0.03177214779758027, 0.03420917417055794, 0.018378599347280603, 0.06072416835065399, 0.04517697349988988, 0.03963013971224427, 0.02457181068270334, 0.11115344733531986, 0.0168225811461785, 0.0741024361923337, 0.0033279653289355338, 0.010424161313234695, 0.007233551404039774, 0.04741872427985072, 0.047999601145940166, 0.04147879819252661, 0.05042455638093608, 0.04234746550875051, 0.02010550320015422, 0.03888558323628136, 0.06623833067715168, 0.01971877216627555, 0.03713540393593056, 0.0827748669045312, 0.04940090827377779, 0.01863371324725449, 0.034546263582472286, 0.06164816341229847, 0.02132266610195594, 0.03470373120425003, 0.033830080048314164, 0.0281036702716457, 0.02114019276840346, 0.013590326998382807, 0.039583995938301086, 0.08366387670061418, 0.05002165585756302, 0.04072352425594415, 0.0813956901963268, 0.017455525396923934, 0.013008093062256063, 0.028385084188942398, 0.015274722328675645, 0.047643390617200305, 0.05261464011190193, 0.03387750964611769, 0.027467959294361726, 0.04917355154507926, 0.03668300767562219, 0.024382402721260275, 0.02251294714265636, 0.019924051061804806, 0.02791567535937897, 0.03145140090159007, 0.028557866346091032, 0.015786356392449567, 0.04372104091037597, 0.0575516778709633, 0.06574393649186407, 0.0327585748662906, 0.005385986213306231, 0.019275274892736758, 0.043511950344379456, 0.018594280184645737, 0.0451224430331162, 0.03499620693868824, 0.019532295476113046, 0.012671752583368548, 0.01883492771802204, 0.008252592258421438, 0.03907521002526794, 0.02590385125949979, 0.046265051899743934, 0.03623068605416587, 0.006742631742132029, 0.04356200587270515, 0.0055543540760741705, 0.03405336217422571, 0.019911871358220066, 0.026697097712063363, 0.06125105079263449, 0.03029078371556742, 0.02854957804083824, 0.01221354042978159, 0.018626636127009988, 0.03909106399597866, 0.033563554885664156, 0.054299829328166585, 0.022175167321360538, 0.04513074151639428, 0.06216287972139461, 0.009942201282163816, 0.05669358891568013, 0.05281378335452505, 0.01649585466033646, 0.02818012929388455, 0.030697283867214407, 0.013287293259054422, 0.016458933873634254, 0.020364829106256366, 0.04247233970090747, 0.04077456026737179, 0.010350073770886021, 0.011601123559687818, 0.018506426863106232, 0.03155520318874291, 0.02981835710150855, 0.03581068305564778, 0.022904575503032123, 0.04675484561760511, 0.004533367098442146, 0.115721053310803, 0.13328889491302626, 0.06657073819743735, 0.1682813936578376, 0.07591963439647641, 0.15137112034218653, 0.11191840057394334, 0.17417695373296738, 0.13001737903271401, 0.1379542981407472, 0.1601133519517524, 0.07443208207509347, 0.1102883287572435, 0.13554840295442513, 0.07788115699908563, 0.1533115812178169, 0.144662241052304, 0.13637080096772738, 0.13081365344779833, 0.1666731842394386, 0.09189816378057003, 0.12982704995998315, 0.11839332777474608, 0.11404136701353959, 0.07828029843845538, 0.18511820877236979, 0.1608455048075744, 0.09309171366372279, 0.08877075516751834, 0.15727798481072697, 0.09362011602414505, 0.07903605752757617, 0.07462410748537097, 0.09306167491844722, 0.10789530538022518, 0.10465272901845829, 0.18192994913884572, 0.10318207221903972, 0.13408051457788261, 0.19027758549366677, 0.10378642300409929, 0.10256531102848904, 0.15136789051549776, 0.12013419078929083, 0.1910919225109475, 0.1455867857273136, 0.12147949502936431, 0.26686182458485874, 0.1292175083820309, 0.1123184919623392, 0.17744317704013415, 0.18278961229537213, 0.12574600109032222, 0.13332017537738594, 0.10959641981337752, 0.1828319121684347, 0.14106866531074047, 0.19400080213589327, 0.09098621271550655, 0.22115014174154826, 0.07485821563750505, 0.18452599697879382, 0.11559669141258512, 0.11986338746334825, 0.15678185357579164, 0.06723813167107956, 0.10567390386547361, 0.11220068471240145, 0.12404916142778737, 0.14761993448649133, 0.14468311278947762, 0.11931011000914232, 0.16130884923040867, 0.07422944437712431, 0.18837585539690085, 0.12060820178261825, 0.18784461676010064, 0.14451703455831322, 0.2108327317982912, 0.09878613560327462, 0.08063225687614509, 0.25435200014284676, 0.10501536527382475, 0.10534722996609551, 0.12041232229343482, 0.13912303399826798, 0.1559890532600028, 0.2206011526286602, 0.16756963756467613, 0.14129206618028028, 0.12797610142401286, 0.1846850998699665, 0.21092969445245607, 0.10278108516441924, 0.09702750854194164, 0.11646634260458605, 0.24363171681761742, 0.216330778918096, 0.12138588433819157, 0.12591463061315672, 0.2826482946319239, 0.19041416102222034, 0.09420037881604262, 0.19907153504235403, 0.12097876332700253, 0.06321169808506966, 0.1966534669377974, 0.10300951397844724, 0.2250413772250925, 0.11065463588706084, 0.16113298652427538, 0.11071693218712296, 0.17329147910433157, 0.11314452013799123, 0.11572475811200482, 0.13001741974481515, 0.08319829989756856, 0.058029339382691045, 0.09864755839641605, 0.09173545108309814, 0.17419665838990891, 0.1564225150006158, 0.15143454979572976, 0.19962110769535812, 0.10350775545729057, 0.07433332808847938, 0.14831201306411199, 0.11211815449808325, 0.14611821435391903, 0.08709514008036681, 0.2046411811773266, 0.13104719163051673, 0.08781212089317185, 0.1470346301794052, 0.1432884247707469, 0.11061805606420551, 0.10813279263675213, 0.15932806980397018, 0.10606736596673727, 0.051958330507789335, 0.13068019918033055, 0.08666207867541484, 0.07639588455536536, 0.0692417641569461, 0.1253709883562156, 0.11211417828287397, 0.17652836255729198, 0.1553530352456229, 0.08388898747840098, 0.09491889990334, 0.1319325441228492, 0.07517127812440906, 0.1518356996987547, 0.09233882477773087, 0.1382501529795783, 0.1247799029307706, 0.12859747665269033, 0.12996168487838336, 0.15845911071768828, 0.12084981453205858, 0.13939534367195197, 0.11564615661544458, 0.1377275317375149, 0.13675513677299023, 0.17614842365894998, 0.09211253334901162, 0.07881738604711634, 0.08031547601733889, 0.09928230755031109, 0.12376698585493223, 0.09698998555541039, 0.09663649595209531, 0.10355385512645755, 0.12732743551688536, 0.19262495024928025, 0.14658985047468118], [0.023692044229911904, 0.023471917291837077, 0.010283949685149958, 0.04623252971630011, 0.03447605895676783, 0.022106312980343188, 0.0281804804357567, 0.05772496892937592, 0.046341492262269766, 0.13866796770266124, 0.027215868267895918, 0.06861280290676014, 0.03138401219621301, 0.07107313695762839, 0.06375405112547533, 0.018345566566235254, 0.04503611641536866, 0.005218726907125009, 0.011631403184895004, 0.015292131840916616, 0.014290420770911234, 0.10614992332245622, 0.038781139733535905, 0.01690825297763305, 0.0470055134168693, 0.03825125477409788, 0.04432080479870949, 0.04066992338214602, 0.025741350604221225, 0.08148928053144898, 0.04003528618652906, 0.025885060928495865, 0.046459201124629805, 0.011762334150262177, 0.04951956708516393, 0.028248864891273633, 0.026252217923424075, 0.03994320559182337, 0.044180823024362326, 0.050066866645855565, 0.031187040265649557, 0.041988333886755366, 0.051863484882882664, 0.024730150221980045, 0.007618994069551783, 0.02245051513559052, 0.01821772039069661, 0.023764501591878276, 0.0555779925281448, 0.00905113382863679, 0.06494643392839602, 0.011960375621648771, 0.042182116702731164, 0.03669737565464207, 0.015446656317050968, 0.07830593349145991, 0.00833945831150881, 0.011383960971475711, 0.04033318002309118, 0.011923694018540638, 0.06375895693366017, 0.020759524444916418, 0.05351498144279633, 0.051751221264047284, 0.044809828379324505, 0.03621530705796821, 0.028909503548805202, 0.057937743940523694, 0.047501678578555584, 0.02525228800784264, 0.013822265534794756, 0.07139955979904958, 0.007877800896364664, 0.08064602435167346, 0.061126023930098326, 0.024858328879677823, 0.042821673277233324, 0.0505727450363338, 0.05001904010506613, 0.04245660447382501, 0.014227523119188845, 0.024003345918442522, 0.0695298836965646, 0.054595762198524814, 0.074176382938666, 0.025021221388929656, 0.03068056476435491, 0.06293398727263723, 0.07365203821765524, 0.03243221987837127, 0.010073027922771871, 0.08762044153575387, 0.030303044843354394, 0.04330636780442936, 0.03228014660999179, 0.042724622413516045, 0.01849756689210023, 0.011859559736746763, 0.03765908029994794, 0.036722498413707526, 0.06310909001954965, 0.014930126623117497, 0.027548406406172683, 0.033132776751049926, 0.006971794222148934, 0.06387235370597669, 0.038563794789037535, 0.024188387507040585, 0.0596452501735517, 0.003624505064051066, 0.07994049042463303, 0.06337968978498663, 0.03926686563396028, 0.030347153012241636, 0.053877356462180614, 0.015884569247386286, 0.045844933550272665, 0.0306565717660955, 0.005565705542851771, 0.039256419587348185, 0.05751215999147721, 0.031729851317192824, 0.026486225991642902, 0.052845542186072895, 0.01609632306333099, 0.06337741669267416, 0.062217495005045614, 0.020263810509017537, 0.04182012166295733, 0.047687128984502385, 0.015468072578577059, 0.014844660048506089, 0.06008976524961846, 0.0178534013684839, 0.03520509394417916, 0.05522964282759598, 0.024717507418245077, 0.08094814885407686, 0.057786627406520505, 0.03239397764472025, 0.008835913546915566, 0.06286019658935921, 0.039995412076158185, 0.05775909924081393, 0.013993248725975198, 0.004750698048155755, 0.000802753735375258, 0.060530148047421656, 0.041987173591873476, 0.03611557598092726, 0.036427668162754605, 0.00846163447879787, 0.03901876269706658, 0.021654425621298806, 0.04872664124039667, 0.03120247693732381, 0.020937668725049922, 0.06644442211836576, 0.033160142068352015, 0.012663281921829497, 0.008911150357952076, 0.03381102339231542, 0.03852462974776115, 0.0068334019160829484, 0.04813017163957868, 0.040414644937430105, 0.028061546817688004, 0.02209831983782351, 0.020448689249211123, 0.03413758872609053, 0.03604675895933594, 0.015588979037212474, 0.014827070724485176, 0.020774065450366055, 0.07719680014997721, 0.04004740482196212, 0.040033460927328894, 0.04087122097345335, 0.06666765335415091, 0.0308295235569988, 0.02040491865149566, 0.021704257233068347, 0.016212873327146684, 0.029226644031171287, 0.07467485511941568, 0.03127790628267186, 0.05344914658261197, 0.04334039294293948, 0.09150834541235651, 0.028322910025183643, 0.005593132776474314, 0.012636878427916338, 0.04206633487982409, 0.027159091850210513, 0.06271245237439871, 0.003375416130958391, 0.007220183416003627, 0.052106084900775125, 0.07314505042242152, 0.04198250527094517, 0.08274565597197839, 0.03414761068831597, 0.013687388888294143, 0.07989331867013659, 0.014191972125055534, 0.07833930384367704, 0.05830006806978157, 0.024985119933262467, 0.08975667333496468, 0.01532220620928066, 0.012326311253543411, 0.01119993209639298, 0.04681655498487609, 0.06457650342157908, 0.05098689567031605, 0.039902337427650175, 0.02646836864628962, 0.04144258477858134, 0.04456100619531103, 0.046477911727769036, 0.013055526900903454, 0.06281586111124073, 0.029152843169867992, 0.05366109378103699, 0.008839067886583507, 0.015579769620671868, 0.05205621596957956, 0.01925159402058593, 0.029462509589003663, 0.030339977504419427, 0.01041955575679562, 0.041284771103944094, 0.04036094228337918, 0.033261800184845924, 0.03341751040092536, 0.05432920650179897, 0.03135380381718278, 0.009615469707309135, 0.008039184513368776, 0.03069976730538266, 0.03221279861671584, 0.022682711515309553, 0.0317861934724663, 0.0638918276610119, 0.041782174592039416, 0.034724843821355274, 0.0809115826019219, 0.07848418464085885, 0.01197296753525734, 0.053733887017837594, 0.046911790767418485, 0.05796476320496627, 0.055169955494680574, 0.05682940787768789, 0.030934506495084082, 0.05138534161129168, 0.031365321949124336, 0.05384453911600368, 0.06938635318406991, 0.02397059981844255, 0.0378529343621007, 0.024950691066416245, 0.01480007860144334, 0.12059273118419306, 0.04134004795923829, 0.033670933052365265, 0.03067219503489988, 0.10607661439904145, 0.034771391323634555, 0.07234001612024647, 0.03380210404949529, 0.02408803387412003, 0.03703404437484486, 0.03115952227796827, 0.07736680709889956, 0.02121778833679855, 0.03182788605668715, 0.038849366429661, 0.007267020143834608, 0.017129748860108, 0.03262491025296705, 0.06187754896070276, 0.02552769858656185, 0.03098786648895059, 0.05413046698751194, 0.06494036103997912, 0.06624903795974595, 0.046185754904789586, 0.028142540150188973, 0.057914253058178086, 0.013058594727356519, 0.02662327140569687, 0.06525435990520886, 0.11690349557570048, 0.0728952477553061, 0.016486438290615166, 0.039753331137554984, 0.05468798528558441, 0.009725776600784488, 0.021891268269558038, 0.0015554630746399717, 0.05939989869615861, 0.06817916474704232, 0.026091169333085418, 0.014541183565078037, 0.041976300068199635, 0.015640154148318937, 0.019257951893710663, 0.011303757284102696, 0.07024526316672564, 0.04113843484914728, 0.03480406278478248, 0.031108272528009753, 0.0181957104110292, 0.02103873821241515, 0.07589525463325636, 0.017473408187340413, 0.05267269217542239, 0.027972197326432382, 0.015520172193646431, 0.03589449570115123, 0.022469604022002647, 0.030652680367763554, 0.06193740253469773, 0.008344191941432655, 0.03569963740717087, 0.05647439496325595, 0.04678410744028432, 0.0191894571762532, 0.050958410770233185, 0.053727600390889814, 0.045251510571688414, 0.028340604522132447, 0.02605171761076365, 0.0701661052714501, 0.03944969010938491, 0.03739968314766884, 0.050778409000486135, 0.0560729465048228, 0.02382349851541221, 0.028845561801322868, 0.03906230089653816, 0.0279864211167608, 0.021012448373117616, 0.036136725917458534, 0.029390798615557805, 0.05396010720037988, 0.013777148893236049, 0.027414188786808933, 0.031465348188898394, 0.006931454891205898, 0.06540451970483575, 0.12370186006384236, 0.14325601793825626, 0.1788086337702615, 0.12864926244531358, 0.08356681226619653, 0.10086175386926957, 0.09206934459507465, 0.14863807628197329, 0.16699791752866336, 0.2157188624675785, 0.10629474983683654, 0.2402742441211428, 0.2617241202720574, 0.1408232527651957, 0.13643709383904934, 0.1150666605681181, 0.08359753633184092, 0.16972100069480284, 0.14332388501082147, 0.12832910248211452, 0.12920994950192316, 0.2057961699153696, 0.14665382275623934, 0.07492341606744699, 0.1188795795398099, 0.1762964664293187, 0.12020391704780714, 0.12346536346844264, 0.09799828180777174, 0.1649051798241479, 0.16871507252965653, 0.12026467307337693, 0.12008434560682092, 0.12704745839749063, 0.1328896584787539, 0.1029599809220859, 0.11745688159550939, 0.24478718053017343, 0.1123740639803665, 0.14248349224882467, 0.08766073973051139, 0.12695975096098014, 0.12313513404556684, 0.1861271767743996, 0.06621764214443308, 0.11005534697324038, 0.11357262145195689, 0.1742726271705968, 0.18838663053299698, 0.14232240803539753, 0.11371130043906824, 0.08445409858333212, 0.07155280014766113, 0.1317910152886595, 0.16280518179493292, 0.13057088718882628, 0.0994697053517614, 0.12650042346545629, 0.14304085448384285, 0.15640058474881308, 0.16395847419542925, 0.11563463509082794, 0.15326477587223053, 0.11188818540956293, 0.11905727429049355, 0.12479861692658492, 0.09142873968396868, 0.23290576093963214, 0.10484576544591359, 0.13855712222201483, 0.21531384491494723, 0.18980453802006586, 0.09537076351365872, 0.15314976418656961, 0.21098574144499643, 0.15631650068930217, 0.11608842574059963, 0.20259603591901915, 0.1683802290686539, 0.10734479634889535, 0.17161635256239346, 0.10351651534438133, 0.14061343616672925, 0.14797233843377658, 0.13136542455426284, 0.21102595143020153, 0.062449323279517036, 0.25141801472221104, 0.15155646896788053, 0.09667054483933107, 0.17162267650876725, 0.1440309320709535, 0.10706933827272483, 0.14495523247335637, 0.09898185224405356, 0.17192366107233933, 0.0974956773487585, 0.0781087444296905, 0.12337790030453887, 0.10891849547624588, 0.21062474724437508, 0.14485392719507217, 0.08711664285510778, 0.11686822532543115, 0.10824105968432766, 0.23028341308236122, 0.18522632654224122, 0.14243655119623455, 0.2057715119527919, 0.14494804000215872, 0.2599795253149101, 0.151993296242186, 0.16735659113952092, 0.08925864220197711, 0.1326253012354885, 0.12776165721671923, 0.19798849815768854, 0.2611759454011917, 0.2079777414245265, 0.09556421384747539, 0.11009473593107291, 0.24398965761065483, 0.1234406376523631, 0.1337379901004689, 0.1048480181821755, 0.1691848494644676, 0.14862188643642835, 0.0946485579812101, 0.16983530670404434, 0.11765380602862154, 0.048282889516225884, 0.0965019017457962, 0.0795955096504518, 0.20899472971047672, 0.15684294886887074, 0.06728277248995644, 0.0721606725294675, 0.11900535279086658, 0.21098143953297818, 0.16506663044648512, 0.17588778478758677, 0.1361599937081337, 0.14253504733954156, 0.14601040871015616, 0.1519772285329444, 0.1544983253947326, 0.07215690666011401, 0.1547459363937378, 0.08813021810991423, 0.11239167196410042, 0.18337392594133103, 0.11361175935183253, 0.09430387576243707, 0.1492761027600084, 0.17053497130317347, 0.15401583271367209, 0.08533706263239894, 0.09602063042776925, 0.1891403200903109, 0.13852307333477906, 0.06711754921291556, 0.19115451058106764, 0.1377742285174983, 0.10726907862616436, 0.07588538873408522, 0.10810742899775505, 0.1373118069022894, 0.15769550097840174, 0.1600729248353413, 0.1333558527486665, 0.15588879292564733, 0.11616686438875538, 0.0712906074311052, 0.08193433165018048, 0.1301300022751093, 0.2457019543009145], [0.03821607951873115, 0.03624898614361882, 0.029689214924084287, 0.03161410342103668, 0.014802193934363978, 0.03742196623768125, 0.08557147612529141, 0.010173691985463458, 0.04053662517773254, 0.013156648974732628, 0.05769746111971991, 0.030787915789655278, 0.005376794608309865, 0.03872560842760971, 0.03163532121106982, 0.0190147259272635, 0.05312923089201961, 0.03765983347381864, 0.03522594193262713, 0.05482786867235388, 0.046281662437000444, 0.03833445334540946, 0.04388777053515826, 0.02701558847911656, 0.006022288788309587, 0.049521483946591616, 0.023776939138770103, 0.04486233002639242, 0.03891551002327885, 0.025249811355024576, 0.019629417586007288, 0.02359125972725451, 0.03286092848117862, 0.049486681885485134, 0.0464264685953302, 0.018390226044825146, 0.0661062877625227, 0.013379552817371274, 0.031044317209827046, 0.01945571431757084, 0.03889805810259921, 0.060062908833580356, 0.0064426798240414685, 0.031303246172943285, 0.006195634129523698, 0.043628780503890345, 0.029698042664676905, 0.027391327245693122, 0.023409697326964567, 0.020339914996709143, 0.030844434364033595, 0.11264781214829002, 0.02789410133846104, 0.02178151353395411, 0.07329917286655732, 0.03968769305252603, 0.03379387681239417, 0.06521710154733487, 0.07607242012662546, 0.027736647287383676, 0.04670556701187577, 0.03007768640028579, 0.02231049264914223, 0.03791773784905672, 0.005586558620312384, 0.10026043613574334, 0.038054326948310645, 0.01744411243791027, 0.033556406519242694, 0.05829926739845957, 0.02434382800545011, 0.025166314228304794, 0.04679246699171407, 0.03363143213625465, 0.026637517248413393, 0.04296133953279682, 0.07419800784971033, 0.06710318462657076, 0.03887996157365186, 0.025699310270803313, 0.047338938739682944, 0.02727063452558858, 0.041647254688931365, 0.020469562682722296, 0.06734787792499576, 0.1009611931762525, 0.04177362844347954, 0.03073914608518992, 0.023294923128560185, 0.027236132716227855, 0.044867354578205516, 0.11544307108436312, 0.02928490304787244, 0.03583047252946666, 0.007123427715019456, 0.029915882939738885, 0.022157562730301703, 0.0483585868829063, 0.12847581532384666, 0.049318279671881876, 0.062353948397295814, 0.0686302005446383, 0.03130219444366438, 0.018843224504962564, 0.048846945499203036, 0.014585598771061217, 0.0437599311449698, 0.0638177791344268, 0.02949556102976203, 0.02814836537332407, 0.03103211036484156, 0.06154085988444941, 0.006454720003862998, 0.062205077814204354, 0.03655419798035707, 0.03171315257038389, 0.04396514388333474, 0.010617894087252873, 0.058386337012052536, 0.03271569484578712, 0.01752563163505069, 0.027490520583731786, 0.01707782905681857, 0.04046454101002642, 0.05458487171147551, 0.01190648297779262, 0.022208069484414797, 0.01613526079537613, 0.030264826358429024, 0.03345621403838907, 0.029057285083191733, 0.049758862637515576, 0.06458814708249909, 0.02463784401438066, 0.03548259101808071, 0.03671805061666029, 0.020888637784602385, 0.009309553890489042, 0.05332183984241315, 0.015596748263175999, 0.01408234631110515, 0.04918108667646136, 0.0559900600596198, 0.034177781747920175, 0.025244413608951227, 0.06555341064397778, 0.0482738955345537, 0.07464051446212189, 0.017614855597327863, 0.03388496674597263, 0.06876808564577784, 0.048557441748146496, 0.03977969561570457, 0.06174606244478907, 0.024049435409584215, 0.01753107348590025, 0.05274364318964737, 0.07908856935266938, 0.0756432670833809, 0.03745067844699536, 0.018285463630620922, 0.05722921767405101, 0.041952619196048806, 0.03233152188892875, 0.05125624353864363, 0.06295321016971554, 0.019157873067472662, 0.016564413838620697, 0.0077971103601157665, 0.04975505605606096, 0.03487199431817446, 0.054228328700576506, 0.038226942864379714, 0.0914496114211423, 0.019654667570388744, 0.050619285753262896, 0.013676529783489448, 0.030689619814178774, 0.02527828438074461, 0.016728039165692668, 0.08354506521884884, 0.04419518421803202, 0.09161179486129965, 0.024057939149705426, 0.044607743687395535, 0.02526356525985258, 0.12247361668518611, 0.03894754366150924, 0.008837963570840657, 0.047597932163625956, 0.026941438172278658, 0.08968502003699541, 0.0574361097865871, 0.023578160608719503, 0.04462066977950079, 0.0408079882950655, 0.05237428604492119, 0.05291740582989795, 0.017760915349104574, 0.02666922179715974, 0.02212795485476298, 0.031316660810261965, 0.048417229271892986, 0.008329985114479703, 0.00668471453744652, 0.06004231529576438, 0.019759506319782565, 0.019120735149564486, 0.018800356358821903, 0.03817027501229729, 0.04935890017077327, 0.01616243103386036, 0.05036611755245498, 0.04274392673479659, 0.08685609897864716, 0.03405154709305082, 0.018272925999813845, 0.009775910160637327, 0.049285207875072956, 0.041671220545790026, 0.013758459494316151, 0.06033213117292949, 0.06654577489410128, 0.020635444138731276, 0.058523889631032944, 0.03425978270492383, 0.012907477345184555, 0.004328983445053122, 0.021904475953696028, 0.02510201624993767, 0.03052474937534758, 0.09072332789323159, 0.062123626470565796, 0.10964374763092824, 0.05130681814625859, 0.058973486934389384, 0.044132277236453125, 0.03289461095950433, 0.04306618676387838, 0.0387371638789773, 0.019187151853527342, 0.02655257993111653, 0.08426085859537125, 0.019253526149051528, 0.026763266750744412, 0.029902257956564426, 0.04693606196503554, 0.02728419504793627, 0.04455842776224017, 0.007917644472659698, 0.010730296805767077, 0.10837149447096245, 0.06849561312368938, 0.03684868896380067, 0.036928939300456216, 0.03323032973068101, 0.02217324197824512, 0.050618417228439024, 0.09056556171604566, 0.06383795198053122, 0.021408809515248452, 0.010578701056406965, 0.05207481461444071, 0.026720023714005947, 0.017615311912127903, 0.03599450497754982, 0.067491137023483, 0.071664425943579, 0.026928311912342906, 0.04509567482663052, 0.06990157160907984, 0.019563438537131463, 0.054754386722509346, 0.0556520410547299, 0.024854503638510193, 0.04113312191995127, 0.05069649286035981, 0.05261602771601506, 0.025269314147798077, 0.029436355456709862, 0.006847118501484926, 0.0002760415897812761, 0.043078135765556774, 0.04745251193110432, 0.024932323123461435, 0.036502439329134564, 0.005893769166764936, 0.05618348325203572, 0.04243131886635508, 0.0647286174020597, 0.06538621961538281, 0.005083734061502452, 0.03288470434823206, 0.05232291076598423, 0.05940538125910929, 0.03538654438619103, 0.05960920639336109, 0.02045376638748816, 0.04300822290991034, 0.05094733368605375, 0.0704523656251175, 0.02336303617006966, 0.0349623446485826, 0.013435285987465509, 0.01783092150331608, 0.06345118023455143, 0.022616060716765266, 0.02764715869644923, 0.06766511340226446, 0.01174016047402152, 0.044391877949237823, 0.03584525441484792, 0.01598985752622996, 0.056724709924310446, 0.0442622132998492, 0.06244746409356594, 0.04689421671043549, 0.03825396552149739, 0.09954865968653134, 0.0029109039917654756, 0.030630726367235184, 0.0310413791531963, 0.0843817260382431, 0.05268960466076221, 0.011238384675899786, 0.09562794864177704, 0.06466910988092422, 0.04096052635993276, 0.03728487162983843, 0.059390182074691565, 0.021789257314854434, 0.018989189261836664, 0.049369051054652245, 0.06531846789377076, 0.07744221948087215, 0.013857334769064826, 0.0065700378784510705, 0.04831662967002817, 0.07403770395155464, 0.029298928366707902, 0.0237338657357863, 0.023075160903057883, 0.03533968815047826, 0.033572776176567586, 0.03110896124105368, 0.04950805234589747, 0.029876694149736847, 0.07961978763341904, 0.03681164434445756, 0.10875309578010015, 0.031045694635914903, 0.03988573706841894, 0.12169630053852286, 0.0853135921061039, 0.052895339871091504, 0.1270206698349544, 0.16623778188867228, 0.17518603030060018, 0.26341703800218447, 0.0739668852516583, 0.1276539194264582, 0.11730248773736612, 0.23532408688749584, 0.1070035407319665, 0.11005204250769955, 0.14076192677021027, 0.13955674001148768, 0.17275440506637096, 0.15953733000372136, 0.11934243541743074, 0.14338628309113638, 0.10363689424203974, 0.17762125177042826, 0.09775215001510722, 0.12116214420114245, 0.10539153830281325, 0.07850285792457205, 0.10320609914405005, 0.20744583782340797, 0.1502801174564021, 0.12025164520101887, 0.14100288812603268, 0.07070615129279238, 0.17556424571999482, 0.2140244519604104, 0.13680115501795495, 0.08215404128921883, 0.05384236441126891, 0.19684193682457718, 0.08050952346197196, 0.12251232032264982, 0.07518421778721468, 0.15511942920940264, 0.1264659674572093, 0.11197174021175929, 0.22873629895704134, 0.08670533528285367, 0.1706668377986976, 0.1697921518768583, 0.10220057131456477, 0.14303664756672724, 0.09332495329103299, 0.16050485308681214, 0.17185503404055322, 0.12911487317511014, 0.10747365014893667, 0.3032692995454584, 0.1746460385620594, 0.08644501532294921, 0.16051503111209187, 0.11546330499861922, 0.1975795586726495, 0.06376235639410359, 0.13870213872620038, 0.12150996125170163, 0.11931822528796536, 0.11102377250790596, 0.15110935510269233, 0.17121351989252226, 0.13497282883950643, 0.10676325112581253, 0.16591294003384455, 0.1275102871337107, 0.07708839061004774, 0.15111471552933964, 0.08936313659484897, 0.23435872154576437, 0.256169035498585, 0.14214384475989, 0.2146227162863527, 0.10565348674676248, 0.08681676430361611, 0.08606287797114678, 0.10284805657075984, 0.23318637588194438, 0.0989661712997726, 0.13827268034219742, 0.18154527406607354, 0.12585521808692388, 0.10926239059439727, 0.07785745577088424, 0.11737403246973242, 0.11038549497191395, 0.15920935331710748, 0.14059113950601645, 0.15200920110302313, 0.16134468945009367, 0.12663218139537744, 0.14936911634036473, 0.138602027669549, 0.2957081938428538, 0.20252502044396742, 0.19356871103601797, 0.22562018116669996, 0.15654493628868035, 0.17065576410719327, 0.10641551549945559, 0.09754398904208626, 0.1451761091926268, 0.1488873700478247, 0.08837046021861689, 0.08817741700581141, 0.11447900852986745, 0.12628494788493427, 0.08083519312952246, 0.180856764582651, 0.1711711793073586, 0.1788814134363617, 0.17969984880515508, 0.08179971708783082, 0.14256669421281132, 0.07806588137256247, 0.15241728563393864, 0.07083197882665054, 0.1416349842080048, 0.1662849672138691, 0.1288963034749031, 0.07536816863077027, 0.05470392407317247, 0.08452477479087454, 0.15081682508545263, 0.1359559582280261, 0.10393072704651526, 0.12123814012323107, 0.1486928883407797, 0.11639357650918619, 0.0719662926026753, 0.077691710021879, 0.053842225311590095, 0.18949627956109388, 0.17351815051266126, 0.15890538319945335, 0.12256360399935927, 0.13129157280283316, 0.15626612624951772, 0.06848135710294757, 0.11542834687445845, 0.17235721780785493, 0.16634158417582512, 0.1310026254504919, 0.0574318418013198, 0.15778637038809912, 0.22749550268054008, 0.12519074231386185, 0.19737424754670688, 0.14314939294542584, 0.11074874190879719, 0.15652458023812088, 0.15233339156423295, 0.2060398454112666, 0.15061604657343455, 0.07632165960967541, 0.0619697008015854, 0.12285875316177096, 0.12019737597022738, 0.17446653890822614, 0.12761056103876658, 0.1245474096919809, 0.11113488940255982, 0.1433708124927112, 0.09478333539196424, 0.1756091918796301, 0.14837517110364778, 0.2690984931375299, 0.11526977324060031, 0.21158912192497933, 0.13709349504538945, 0.19279573751347406], [0.024444537869255458, 0.03217785745593054, 0.02855996980464884, 0.03534064827752965, 0.06662545526134116, 0.007959094480611384, 0.022266084228509238, 0.030587289948016405, 0.05635929506804262, 0.02384120488672384, 0.02060384306657527, 0.03459354390257171, 0.09346714708954096, 0.01852490846067667, 0.031530134712478945, 0.01996075132462595, 0.013563719095795282, 0.04157448180818132, 0.06898014140980584, 0.08646046556532383, 0.03814938970442329, 0.028937381160046374, 0.028066942867423807, 0.024415757806439484, 0.022938512431989824, 0.03893888894734638, 0.04648065979459456, 0.03545666080234306, 0.066655758635274, 0.06947111577859946, 0.05874017945357731, 0.06548641888158661, 0.017007035801985433, 0.04912483273074031, 0.020700895626630102, 0.012020144378766418, 0.0349471793909158, 0.06638557956154857, 0.051039977464824915, 0.03583655559590884, 0.016975633201322386, 0.037719575089535544, 0.020821176136710813, 0.05125374313709991, 0.03714891017547675, 0.02519704507929938, 0.025662153693182126, 0.025522324589214156, 0.018176090570964983, 0.05696435831487179, 0.029585853684693575, 0.04251018159889749, 0.038554532786032984, 0.027937293485073105, 0.04102807791371431, 0.0336963170474129, 0.020078070029350262, 0.04557529391188707, 0.02448749422494854, 0.014432770632473486, 0.08528033710483994, 0.015263665600546768, 0.016798708587884903, 0.004270407637315137, 0.015480304868625743, 0.03788664398182716, 0.023452640111957277, 0.05389584314876369, 0.05855124816298485, 0.1336745335055249, 0.033957871941051314, 0.03501705153446112, 0.01938975223207048, 0.0019146790894280586, 0.02286526288038918, 0.058254015898065906, 0.024391544284299016, 0.021293653640896082, 0.057650940758841376, 0.030986092119876827, 0.036738925746509006, 0.022149415221065283, 0.03220752300694585, 0.050657073368451426, 0.012525028715442334, 0.02049906368899558, 0.022423802908243876, 0.005470607587735036, 0.008706358311298703, 0.053469326214066575, 0.10528529328959328, 0.021206081911389316, 0.02962138856362019, 0.03616067820361682, 0.014830756865973984, 0.08596394078007766, 0.015775730534057533, 0.018220972269773483, 0.03393344807305506, 0.03139575085203562, 0.05066863899784429, 0.01890526805073023, 0.014954650575028998, 0.02764036656091256, 0.004467779479455203, 0.0371959767570453, 0.017467990085216503, 0.05984321955059256, 0.030543402303010225, 0.07095535006374121, 0.01225203032871442, 0.005936873103824577, 0.013941689394414425, 0.02559009157786412, 0.02443498748886798, 0.049832758493721485, 0.04991846425192697, 0.030350728891789913, 0.03074276606951441, 0.03987983042108161, 0.030004916912210838, 0.03385731644396271, 0.03270821399720652, 0.05089476079280887, 0.016702253138646483, 0.025656793266534805, 0.04098526235403759, 0.008949021941849163, 0.022131052367123108, 0.008434376030761217, 0.03761575244633215, 0.019172970471637588, 0.041054164192506244, 0.011637826367015285, 0.03022794798016548, 0.04916001816413232, 0.029927278935377086, 0.062068699060806205, 0.03197867689388139, 0.029140300450048277, 0.03886300159086074, 0.05537649816168206, 0.038724210645471296, 0.018874267482065728, 0.018239491186769943, 0.050839246450258155, 0.07621375897100993, 0.02421101156089987, 0.0267266733571887, 0.03881777723186782, 0.01842164051985102, 0.02285056241921016, 0.056468617237572155, 0.03619871687676225, 0.035171112910445244, 0.031025732135666267, 0.022244316825110997, 0.018162901546540003, 0.03331734845414758, 0.03567557994808469, 0.04054203649450626, 0.05330378741824201, 0.03229087424863662, 0.031172475511474267, 0.027157137669356804, 0.05340651422739029, 0.05909596250525542, 0.03490501522485699, 0.04017403981249247, 0.028741281146981885, 0.06386835034936666, 0.006393413940843726, 0.004454533203638026, 0.03772991596321974, 0.04787518835759588, 0.02907640959269234, 0.0612845297104546, 0.028848187731845037, 0.06505820900201797, 0.02521771834498005, 0.04001266382900732, 0.008965280489064753, 0.03171863513333457, 0.06374909103448902, 0.015643263535041894, 0.034392975736409426, 0.02454977186529764, 0.007100488990545273, 0.034622625913470984, 0.07245568598487548, 0.02535225317946502, 0.014340176047491176, 0.018769935937598348, 0.0754480796999165, 0.05109132220968604, 0.06175691221973725, 0.06231697502412966, 0.027401746150904467, 0.011964729271962174, 0.048051156236657074, 0.0377285317517817, 0.05779769431267466, 0.01054548507090658, 0.016382444317319562, 0.05458491581625172, 0.002509256637754983, 0.08869834869567837, 0.016259972139128616, 0.03879357388775263, 0.04394937472950135, 0.008680416221198226, 0.0455033861632858, 0.03969499748200178, 0.04035263701475092, 0.032257408901516876, 0.016202610484989624, 0.022717220110020468, 0.03251168989975538, 0.0686395846839462, 0.04253751977479883, 0.007002749413784061, 0.03021808886634452, 0.01868371618911624, 0.051663072779774666, 0.06295445188879967, 0.030199313802378516, 0.09462677022176129, 0.026525202739451612, 0.00241690780967474, 0.03524499519595078, 0.035694534823830636, 0.027205773363155977, 0.023631973524710963, 0.059825041597442966, 0.06810084144983973, 0.04629839171788522, 0.12120190635323524, 0.0628477522571172, 0.05753387989742415, 0.032694565265306404, 0.0390867756546608, 0.047744675539433956, 0.04007746731596334, 0.02377660496027342, 0.06688010266848973, 0.04197136711861406, 0.022760491984497224, 0.03399771891002144, 0.024327061405139308, 0.032922983901309114, 0.02587685744012041, 0.034848388084875684, 0.08754776364990643, 0.05107315443456173, 0.04881417225780232, 0.031018539664468596, 0.0482847894142781, 0.028567287804824964, 0.03351648151874542, 0.024510851096627966, 0.024870145567027584, 0.08098776851381574, 0.024412124251414622, 0.025491726052548205, 0.09078289648251874, 0.06461102728332792, 0.06745367510510342, 0.06422460159020764, 0.08340064582547971, 0.058316644680287154, 0.04958377346130354, 0.029989456491810933, 0.022563945834657977, 0.0212079478826906, 0.04067723120429686, 0.04053250986284443, 0.012434164394757577, 0.029163540274436985, 0.023276563667293106, 0.008857756437334632, 0.09016502927988768, 0.027344750905675546, 0.03141544533095189, 0.04368622188589402, 0.05846078587429864, 0.02438626528185393, 0.03460972696276648, 0.019760734468166317, 0.024718959483184984, 0.02518188999965787, 0.04075213807768055, 0.020489754188539724, 0.04729931568726897, 0.026714671769046357, 0.017486634531191418, 0.027540377640564526, 0.02674389287962445, 0.011802208260633051, 0.09008410040821348, 0.03170112892985344, 0.011795935204385646, 0.03338348865509033, 0.050959832301097255, 0.027789198128240447, 0.008891997010713177, 0.07787832750805787, 0.02610754068674786, 0.014939697359555533, 0.03509903892076441, 0.016963979362377098, 0.04489448580092617, 0.030151154779429947, 0.03827652681086745, 0.0071512434099401745, 0.05692772420921496, 0.018193756230175495, 0.04471944412216544, 0.03009915185560073, 0.03270835988223553, 0.006137166463304311, 0.024044163192489316, 0.0586189456017954, 0.06099248145307813, 0.056035352272114584, 0.02641145482526294, 0.06420443552945342, 0.031024900930268422, 0.03999276239691036, 0.01564007781312934, 0.01609326117405934, 0.020247693605987088, 0.0340989495494536, 0.05304153702620949, 0.08390104504568235, 0.03310665315283196, 0.06077457671718938, 0.0655666081500905, 0.08775811629103762, 0.02626638064560081, 0.04725566552951932, 0.004383984221411603, 0.04132652814899172, 0.03412232168817094, 0.019759752288726822, 0.03496939802010145, 0.04277680854180029, 0.04366973687761596, 0.021848108353359357, 0.016620499846924628, 0.03827166510745883, 0.04020078766292759, 0.01705851625385029, 0.08907851829592671, 0.07508838150118079, 0.11443650509629931, 0.13139025893594536, 0.17128294759563037, 0.09524541095431362, 0.1033238453258361, 0.05771455341683967, 0.14688117269958767, 0.1097023052030376, 0.0776477273819702, 0.12329817243984767, 0.18244630071733678, 0.1439694296568632, 0.07239062804728746, 0.12903462962380477, 0.15904368220695428, 0.16610721818038396, 0.1839585110012974, 0.12559575986649307, 0.16827204344528063, 0.08941132615187339, 0.09240082252238478, 0.09712031177644219, 0.11421101433890206, 0.09639018774032593, 0.0945381128362247, 0.1775075700134039, 0.20830372321818555, 0.1390069095151765, 0.218242008505123, 0.16856636479496956, 0.13324094962860855, 0.08236577135643788, 0.10545843507030181, 0.08732895646244287, 0.12646660528012685, 0.18012951074966363, 0.15365812262254103, 0.07302017962293965, 0.1387034279427358, 0.14013371190854482, 0.1593273098447493, 0.0958167781521167, 0.09217774056430374, 0.14939756052834646, 0.12472841569355556, 0.07271892364536013, 0.10711851170552628, 0.1749571468681097, 0.2308865221483367, 0.15051087364554405, 0.12025719561747142, 0.16158080606588296, 0.09526597056537867, 0.11017930175044707, 0.15248585838292325, 0.29942385160497254, 0.12509721304689134, 0.142909435821431, 0.17473200894892216, 0.09298096996332918, 0.1388260663620063, 0.08313107064792088, 0.09329920967242547, 0.20864095512245381, 0.12053691489355904, 0.16535130302820886, 0.12788548985762255, 0.20533792807587556, 0.12702869011887483, 0.13924379966088704, 0.07538944748895508, 0.1021216373358454, 0.0663761275687388, 0.15833888788308415, 0.12874878996184894, 0.12179269322327205, 0.10710962968213217, 0.11796285158821515, 0.17467467273984635, 0.12370849613632474, 0.17179651718054498, 0.17628786260528223, 0.1789276081004313, 0.15499752360795224, 0.14152884776038782, 0.11252687006656613, 0.12360862935228006, 0.21689977124333382, 0.18614428942756994, 0.20940657332539558, 0.15165620004492147, 0.11126915112669979, 0.2041653517101492, 0.23557655619723455, 0.15346446872821876, 0.0967157624129738, 0.0965360931253859, 0.23597021507365362, 0.08780568838119507, 0.1882350593805313, 0.17567867386553968, 0.1822851893625089, 0.1701780211712633, 0.09384908088083778, 0.08345652318426541, 0.17875463595347746, 0.1648348971669163, 0.17049907680068696, 0.16568907776049205, 0.11600260463144098, 0.2265614585152694, 0.17309534177184105, 0.11708846422178404, 0.1291791032999754, 0.10014129895716906, 0.10686665307730436, 0.08513288465993744, 0.12240998367113726, 0.16430170434926236, 0.11279778874346189, 0.12801244375961168, 0.09879995057625429, 0.1684206019022635, 0.11153453974319355, 0.21577546585883411, 0.07848898866879088, 0.12131347108100142, 0.1189141169722591, 0.14216619570340427, 0.10698059946298599, 0.07894605664270264, 0.09727466492248432, 0.16986658716840403, 0.09800595603883266, 0.09428455108510596, 0.2008894117815154, 0.1502137431608779, 0.12943393391157898, 0.10306933362569128, 0.10217936030988183, 0.13389859933938297, 0.10013135841914586, 0.1604403786893402, 0.1893031820654869, 0.1414050151194845, 0.10287961523447718, 0.13052516749926976, 0.12213495985737868, 0.09329750654952866, 0.09599940585238592, 0.22537000530532428, 0.07946793828159571, 0.15572947290326866, 0.10188611783087254, 0.13303878690515245, 0.2884176607642855, 0.09640766001705613, 0.1296155098825693, 0.11449565977922507, 0.20381229636924608, 0.14644908159971237, 0.11453432270458766, 0.13204984925687313, 0.16001748852431774, 0.12082390806504659, 0.15236072295478412, 0.1034469994317208, 0.16154206171631813, 0.13351555275065558, 0.14681150072387286, 0.09180071936654192, 0.10256540602339165, 0.1158082043485982, 0.11227390542626381], [0.042188878304192, 0.0036951592192053795, 0.011149437216642712, 0.024988488859630058, 0.05149908443646772, 0.07088861614465714, 0.007938349968753755, 0.018795837315597703, 0.07730232591607741, 0.01850065083375999, 0.09751648123243026, 0.022088793206161687, 0.0556095715479127, 0.010783127542319042, 0.06250131263264588, 0.029465942976198027, 0.06672135940087692, 0.09064359324319021, 0.02736096958895879, 0.02822490412342761, 0.01543964705030833, 0.01767167103077684, 0.01985815682980631, 0.02576925196418805, 0.021709140988865068, 0.03615441871806979, 0.03120627673342824, 0.06885275324540478, 0.056740835309028625, 0.0371540568635932, 0.04998390216912542, 0.024334111383983066, 0.026753986088026847, 0.04856327375663178, 0.06714694334992341, 0.05105581107948508, 0.07326637926910605, 0.02448072753447507, 0.02717076943788145, 0.03707457666418382, 0.061842950460101874, 0.09647446857499224, 0.037896404708070416, 0.012254710542038083, 0.05419699734609042, 0.0495732527758394, 0.010070401992249702, 0.023972384365541593, 0.045223979013306756, 0.015332713324044431, 0.06914928661925451, 0.02574400367614414, 0.0473342941674803, 0.008063476915205163, 0.08691586434308972, 0.07695924503994839, 0.036114032313759835, 0.008504316875977176, 0.07637323505644288, 0.0211648490346436, 0.052742740738072565, 0.05137558427772351, 0.007501705050734537, 0.012847980002074369, 0.04372474231890269, 0.03772197710350156, 0.051166198548993895, 0.023145526680829268, 0.08299340946333748, 0.004091468198956656, 0.04302075205902968, 0.016663354422364916, 0.030936654058418105, 0.02377905786436583, 0.043740969483873675, 0.06540129666349717, 0.009447901243610042, 0.01300776397277202, 0.07967901016984667, 0.021048500634995953, 0.1039777427379574, 0.07179179375192948, 0.010263407885629152, 0.04765350418165326, 0.05048373141991241, 0.029556479903736284, 0.023166539214019264, 0.04351907835475036, 0.004668644928772534, 0.06348826895867075, 0.1112997734120914, 0.10263638757169247, 0.10386264962809426, 0.03861342962565167, 0.05510388653991478, 0.010816461423278918, 0.06002099572547844, 0.027563717548868487, 0.019450781367985264, 0.06002640364957707, 0.07050039911908762, 0.053040471726230214, 0.015674447308161428, 0.01965097464354975, 0.01412723055441997, 0.029139730480632613, 0.03409999110070722, 0.041755284249250374, 0.06600260082632303, 0.03036604342716081, 0.05721124328140702, 0.023870422604626844, 0.06968026062739746, 0.044100416624652486, 0.05154973368293472, 0.04050892059292112, 0.03530178179166146, 0.045678777287581136, 0.04895744492698993, 0.020729690956483995, 0.06458887311496905, 0.048203551809170415, 0.00742448098026216, 0.051543172249304395, 0.04284782062417694, 0.032773553526827266, 0.04453552381268569, 0.06895567343703338, 0.007926872548913317, 0.025726838436509882, 0.02366670603597803, 0.06953820932124342, 0.028582429313766103, 0.05136658690337624, 0.03354016239089625, 0.06335727777332067, 0.02241428815094488, 0.01564076991884836, 0.08390357598130192, 0.02883468149229884, 0.02719659448069121, 0.08881541634244577, 0.07064696268311568, 0.03928348634924207, 0.026017300618280257, 0.019954328990674446, 0.021886968053877354, 0.0539954894089273, 0.0797246755766017, 0.014468880569828408, 0.05264021409675479, 0.012392594795008855, 0.010191344073973596, 0.016879062401130795, 0.03801462247169443, 0.019636472653863684, 0.08551827219447919, 0.01663064055277833, 0.057190866874797006, 0.025409362079309564, 0.054630374269826074, 0.03940113753612552, 0.012222678600145238, 0.017111050131331598, 0.012851752656778055, 0.030527002111609493, 0.043607281121824465, 0.013053469243459404, 0.0070567383247959825, 0.03387577598914504, 0.035772115125187805, 0.03532260263870869, 0.03890444990247488, 0.05203782767057419, 0.04951243907479303, 0.049540818801948, 0.01579096194888864, 0.012747778191364236, 0.032780712071274004, 0.025284048535728028, 0.056024054664054086, 0.054276501294225454, 0.020394092625273124, 0.057203738684100766, 0.026112027499558668, 0.030558567560677017, 0.06440568223063435, 0.019250299715037857, 0.030548905222011462, 0.004453794872720859, 0.04581590582217489, 0.023008337078083838, 0.007277699436859361, 0.030103759108377353, 0.07468489743769169, 0.018267251750720397, 0.03201426944828459, 0.022702943733228103, 0.04626332502812147, 0.019077132489266138, 0.021507846790232828, 0.016024333890527487, 0.05765957172427859, 0.0479717710321503, 0.06389364613486187, 0.0456840664680515, 0.027223069220781326, 0.027980590804613063, 0.020150532480329275, 0.043965099778558524, 0.03854209863181625, 0.034252535950924666, 0.03577837461073484, 0.04349068505689502, 0.05842376500368118, 0.05958629905113152, 0.011280434339174202, 0.027305300879691328, 0.017061595106497407, 0.055069946218281984, 0.030897268493260657, 0.029171794652938843, 0.04041697570521917, 0.055611943027802875, 0.027497504405411224, 0.015952219188745533, 0.035289201752415726, 0.02853740851527878, 0.04377362058897104, 0.010453171229788234, 0.12453672955078737, 0.07221420215708868, 0.04806600597554019, 0.04738405792574797, 0.036313453755740605, 0.01810136520569878, 0.026911533437669277, 0.026296170029257025, 0.01737252699344286, 0.06286917360765593, 0.06990962581975119, 0.02497308950738183, 0.004275793933110046, 0.018697967120845402, 0.04357608547434211, 0.02960746841771262, 0.10985022583710295, 0.02915781343887959, 0.06611015541212899, 0.01014891273475119, 0.07548237964510918, 0.045293885083603005, 0.022211830264755657, 0.03592657344415784, 0.0827704971390111, 0.12182189737047468, 0.003524534379331661, 0.02340564308022814, 0.009331496016654586, 0.0716379087950502, 0.03540224568652255, 0.039274760388902256, 0.029646932014397213, 0.05532462755218148, 0.020535852161369154, 0.06188022917402642, 0.022037953969889452, 0.06984746522669281, 0.034328430092760494, 0.016249349673411677, 0.055909897932516675, 0.007927746162749827, 0.06606835086963006, 0.021611428553504602, 0.07042909187397786, 0.024053818745804683, 0.07180892676115036, 0.04856719908171466, 0.032902261441839595, 0.05850424604224307, 0.024692467779719403, 0.017230947269126773, 0.005401729922076421, 0.012393504880102617, 0.06814762643937554, 0.03027516044676304, 0.04881847756249564, 0.01968058930443866, 0.02546624536626041, 0.018542859104595015, 0.06016006826290062, 0.029697706789842675, 0.0477494727820158, 0.058556364317025454, 0.027129673964477012, 0.09247029772294418, 0.0394641055858561, 0.014788811527458685, 0.02487713617405721, 0.06376565407429423, 0.022845205385237932, 0.02529860650455313, 0.016633454776768173, 0.05418447498232126, 0.027889078482985497, 0.04443907005978482, 0.05419904991452183, 0.027358691407633678, 0.008765418847490634, 0.03239774690674884, 0.016650518236149634, 0.010482727367031788, 0.03814591560512781, 0.04762511427647301, 0.08635857674692358, 0.017042898074058548, 0.01807249354065529, 0.0704753611768995, 0.007376221025229565, 0.02634352838088359, 0.06520604821188108, 0.035755056754818985, 0.010019364284484513, 0.050536548585764, 0.053232548026634116, 0.007335833772750837, 0.011835002706253102, 0.017692349385470152, 0.030656483556543077, 0.08555959497711488, 0.026803626013653617, 0.015504170641569155, 0.03187134961730667, 0.032871595051671774, 0.010928772539565606, 0.043028175232133696, 0.024857836941789304, 0.05037798512993114, 0.00835860996241016, 0.01458702199826283, 0.012877763448549169, 0.04226961040071078, 0.0748129098543099, 0.05585305366132941, 0.041629962223981104, 0.020715263605649983, 0.013483107439242303, 0.017505299333216887, 0.05240780906751752, 0.0604844419285655, 0.016063532858554806, 0.006526456422372056, 0.16803884453007153, 0.12652373792869703, 0.1409693006426096, 0.11814252766115324, 0.10343470437718288, 0.11978587162281785, 0.12272947867001806, 0.23944521003535815, 0.16046302818826266, 0.09395063721707889, 0.21057145510401043, 0.10331619145082575, 0.15528311899730138, 0.11984293641788618, 0.14060304101024354, 0.10585231786327702, 0.15048954050455773, 0.18760167408202374, 0.20045759209564754, 0.1275312945778881, 0.07705563772469759, 0.06731158987219844, 0.10189297103456088, 0.10066053430948939, 0.10270105195896966, 0.15712125679211958, 0.07597085021968399, 0.2062565694962229, 0.12392355102513518, 0.16606909808303627, 0.12442021151738507, 0.09659805015793868, 0.1101185864369784, 0.19295964443257876, 0.1860204025038651, 0.25566436829311506, 0.16314180301768438, 0.10601104077483926, 0.1080962603113481, 0.12330350572509424, 0.162600006375994, 0.16020318998822144, 0.06165169857974563, 0.11872262081929616, 0.19378943847758429, 0.14607151757393563, 0.13740674752209867, 0.12793941982090473, 0.10640788876584598, 0.10119687552962985, 0.12672735271709307, 0.10893193046961512, 0.11459216102957726, 0.08304584664957863, 0.2502635009586811, 0.22210846388978617, 0.2418991726424013, 0.15365223293857916, 0.1658655647188425, 0.12305923311838082, 0.11689998076430388, 0.15510808410389082, 0.15932718770844595, 0.1673177925071546, 0.1339076374258314, 0.06073221577597516, 0.16465423043285096, 0.13967979912246975, 0.19039878541869776, 0.06306240002491645, 0.20130211035055773, 0.10810911176460129, 0.1658947960074459, 0.13673507927783898, 0.16035454400948115, 0.21307573786803655, 0.16241639479994774, 0.14749349627111638, 0.18303635476955346, 0.21062068960496358, 0.1841031475258725, 0.1299002638884953, 0.10557929572782346, 0.13543064998728888, 0.15329919116837637, 0.08576413257313625, 0.1178475549178464, 0.12349361766661916, 0.1526900702821357, 0.20720045241926396, 0.15455562089170727, 0.2199454435280391, 0.21173297134893282, 0.15700871497392654, 0.21355456645999635, 0.08670606131532363, 0.14125572384468146, 0.11517969093152455, 0.1456359252333641, 0.16672815914664949, 0.13921591187162058, 0.1483859055276428, 0.1187891715339252, 0.1121933293927993, 0.15383545096431459, 0.14919773196535452, 0.0663334002186145, 0.19498485433203833, 0.18489700635629042, 0.0645641947963408, 0.18243633982326302, 0.15921372308262757, 0.2752948206450258, 0.21427373215556145, 0.14870412488068852, 0.08873351038034473, 0.11893095821142197, 0.14283794537186623, 0.1496403674994196, 0.19666143293891633, 0.1709795067352908, 0.11880021808402878, 0.12578299481953892, 0.12493920938244887, 0.11209605461252586, 0.13420448292578968, 0.12237569051129477, 0.2045031264424324, 0.09257597955209868, 0.14302617098603929, 0.16895007634801523, 0.11804149379687649, 0.08574152378631489, 0.15024536289274693, 0.09315237469438996, 0.12429625674017838, 0.10155517594622714, 0.0843791136784213, 0.17758474658642495, 0.1238910084856408, 0.15034285480422632, 0.160529334630285, 0.19920816485370907, 0.08585141931793519, 0.1318592351994344, 0.12361977089728628, 0.09757396671921015, 0.181547255388328, 0.16986788995563984, 0.11024167947471142, 0.11428859803293433, 0.12101016592766557, 0.09548238930957657, 0.1489196140319109, 0.13852934299835137, 0.06547938247344323, 0.198675257020763, 0.10708176224891629, 0.20204541832208633, 0.09182191680052451, 0.1282633931509086, 0.10376852325030736, 0.08319177917603936, 0.09517372372959342, 0.09387890249490738, 0.17358958667942456, 0.13869433557348593, 0.131259111687541, 0.11700219527951308, 0.08087114191481046, 0.10584583106849875, 0.12656757129090174, 0.11545702176434652, 0.16825867630541325, 0.14383904236767972, 0.10911520277815205], [0.02160999345194016, 0.016059069794469645, 0.034593143566910706, 0.002849634187961263, 0.04257532774603792, 0.061224608282957754, 0.024062811031139324, 0.026360193200941597, 0.048349080607295036, 0.04410893902448671, 0.027991871449298093, 0.017607971859563674, 0.08389415112989289, 0.049368640540965965, 0.01949701165514333, 0.009347897904392864, 0.022154008903141533, 0.0283314663517688, 0.029911560671670095, 0.04589263116940856, 0.0165942320600152, 0.03947550158149429, 0.032075782040400166, 0.04675494400518281, 0.01733365372222449, 0.021256597147190144, 0.03507130380187716, 0.03612979807491813, 0.03308384759085519, 0.04230877204931208, 0.07537004138742175, 0.022955160288672363, 0.03275729582778045, 0.04600382609558957, 0.024213981847944002, 0.06810338595615965, 0.07333001228315489, 0.06485360355249473, 0.07059914632035152, 0.024628412377621447, 0.036928935907781124, 0.06955682153680495, 0.02254049905708858, 0.07833589759788342, 0.03572560494233455, 0.04228309628420642, 0.08690195437520742, 0.04142110575256603, 0.0287616066634655, 0.008103985455818474, 0.022430983505078723, 0.030765887150274854, 0.044294487818011215, 0.0038512930955870873, 0.03511814307421446, 0.02785427981455411, 0.05832786086414542, 0.02242031693458557, 0.02950619367350425, 0.014414350103054727, 0.008412954680222486, 0.045463081183178086, 0.01587807057824518, 0.027858512176732932, 0.029967051265495162, 0.021273614805457846, 0.02920576211597238, 0.07819956634193659, 0.03329215784158025, 0.04894413206992405, 0.03806539046178971, 0.07424840264554534, 0.03528299994234528, 0.011173984917279865, 0.02473611115211887, 0.016258330084383488, 0.04900742242378848, 0.0029663150697680457, 0.04300716778795634, 0.018055998354351947, 0.03913476504385471, 0.06866071426442691, 0.047712255136242936, 0.04626444800357733, 0.0029625161218323876, 0.04166501873571958, 0.04490913876465388, 0.05533814736242805, 0.043492211760686975, 0.00920709001366049, 0.07484901470265218, 0.050327946564980915, 0.029066669222499644, 0.04883003979921341, 0.016800971502172093, 0.0577151912397572, 0.051174863441182036, 0.06629859815750803, 0.02986357806782637, 0.021319100400432944, 0.035474180576524565, 0.021251552239326493, 0.06354163573788744, 0.021252563256504278, 0.019717260729521513, 0.007958469380225455, 0.05343468360868948, 0.06429835156138454, 0.0209467169895236, 0.007622989792642849, 0.07146744722766535, 0.0447324652091733, 0.012359259217711431, 0.01514224854430982, 0.005994260627111154, 0.0613995413961155, 0.019896814666156257, 0.09096789227000304, 0.03284861646326525, 0.022702341533399055, 0.10197482271386044, 0.04194351664877363, 0.04523195858512606, 0.016997115620012795, 0.02879720600321889, 0.017849903520462767, 0.017324166106326238, 0.029775677248835564, 0.005698573301612798, 0.019215860670166354, 0.08895198508564915, 0.041830625385046005, 0.0356323029845953, 0.021185233922941343, 0.03326650582520025, 0.043422733167452474, 0.03770625205444438, 0.08191606548747846, 0.032650382457567115, 0.031344477353351455, 0.03912371170840093, 0.023200153838843107, 0.04218107515147754, 0.035184642898717096, 0.047785058551068814, 0.03303668601438403, 0.030168264039925168, 0.0357092658190855, 0.011630867990399045, 0.016530492176700915, 0.032717747414218526, 0.050797601363488605, 0.011435440575171794, 0.009361100499518216, 0.04268863630880203, 0.014096064592844673, 0.06656250078231096, 0.005528395870767001, 0.08569233678281307, 0.010658118491327124, 0.059885974042117596, 0.024805347169084207, 0.0836326912311571, 0.017321418039500713, 0.08613847355757441, 0.03249253485617893, 0.0429919753888888, 0.03678885574585625, 0.01928194998098271, 0.033340802017067156, 0.06276565630521093, 0.044528504367917776, 0.05846757800983531, 0.03245245039995227, 0.039375030901283026, 0.02051600331573614, 0.019564512318798473, 0.04581536299415997, 0.03663665694849832, 0.037443038142685375, 0.04804123266200934, 0.028039843875116537, 0.04704689048230648, 0.041796108308647356, 0.02743413602001965, 0.05906586269182818, 0.02072587250066655, 0.02756447241907673, 0.06632003986409732, 0.11758995588336672, 0.007049422445041793, 0.02418427388849003, 0.030139463621058633, 0.015658666279965212, 0.08213354274630547, 0.005353937308037919, 0.0761855115581836, 0.004152426936863256, 0.0055570877240305495, 0.037897412332573106, 0.06689813134393521, 0.016730602331725613, 0.046170301269739866, 0.04195461408900363, 0.024852959971342767, 0.014674469895128692, 0.09503614396921226, 0.012874326668679714, 0.007445641094818711, 0.05401835943173085, 0.01574684360197612, 0.012227046669327786, 0.02431396907195449, 0.054123003102306805, 0.06567245961299964, 0.026821339170315435, 0.007450020190195313, 0.08654275150703532, 0.03817189331831677, 0.018763462713520442, 0.03216629861188786, 0.01656713815672057, 0.04093818898711886, 0.02368144890559571, 0.014364007893683655, 0.012357024292993759, 0.030216935356812816, 0.017524573120421598, 0.040465779336435456, 0.023947784078440497, 0.05061257164925337, 0.041628041969878335, 0.0029352572497113472, 0.024782041187531183, 0.04077189023207341, 0.0499054465575942, 0.04410607221403292, 0.03112342082230108, 0.047252941211419444, 0.047112823730068545, 0.024716947626854693, 0.02201447496190667, 0.012898450284930212, 0.012787998354594623, 0.05786644348076411, 0.03086821362376213, 0.010663865682935076, 0.04314134469521897, 0.025562592249895846, 0.027982729886259352, 0.00470476334781519, 0.035795053001493216, 0.07360328547656536, 0.0788430143147707, 0.05703445098229817, 0.03641753424225109, 0.11961602073694978, 0.01926185855908053, 0.0848289823957852, 0.01821230398491025, 0.009327730147301086, 0.0706080012023449, 0.04001068589942796, 0.034497436202530346, 0.014842317406354206, 0.04814720965389695, 0.08488517866602965, 0.10944583932203905, 0.03170327649318746, 0.052627705303686004, 0.02320491036932383, 0.03551696560212544, 0.043085250205227306, 0.04274193523451686, 0.0481006451882422, 0.08270760372813259, 0.04875895307798471, 0.008636671068545963, 0.02643785153382591, 0.03278224216774106, 0.06969700687165771, 0.030769859972809042, 0.018530626814546328, 0.08437397716833012, 0.01706086059233972, 0.09032573351370436, 0.03151262850899782, 0.03257020336708852, 0.028847607584404092, 0.030000967838402306, 0.05944531983030694, 0.05502746992611459, 0.03478731654052224, 0.025857157872191498, 0.07390093164784567, 0.06851520921502795, 0.04177511782784547, 0.04778111965528556, 0.022179581191656843, 0.03761327240083899, 0.0023525016897890183, 0.02917870892477887, 0.032417695836297104, 0.019693703690011586, 0.007893460636426295, 0.020735746881525432, 0.007270393311046064, 0.025956093366923075, 0.0532595130082752, 0.02236877880724413, 0.007382933432901544, 0.008467854100412555, 0.05438976575221334, 0.06875946146569081, 0.010905419060561274, 0.04959819572312491, 0.011965691095351108, 0.12652411790830748, 0.028161215130239725, 0.022440028376877308, 0.029158234130591154, 0.07193916477262974, 0.04841161100193858, 0.03225464726399098, 0.04521037099350776, 0.019708914748792137, 0.03799387965617435, 0.04547970189845987, 0.010864683210716715, 0.02352477008077715, 0.01451330934651196, 0.017836633071835552, 0.026298424461856484, 0.043897046108863184, 0.05817055609077215, 0.015304350560264928, 0.056969026635800085, 0.016373679341216172, 0.06941343351666417, 0.06904593895056418, 0.025884345074051192, 0.008977013207705957, 0.03070298016869596, 0.03161678024168525, 0.018607665984226123, 0.019825135923123786, 0.08232009916433267, 0.04192699771374464, 0.07180126610078982, 0.030667309582765614, 0.028823329601436853, 0.04208249079861811, 0.08161378492202077, 0.16444403385477407, 0.13550843724182673, 0.17394679465464183, 0.10979286248662642, 0.13619917232011045, 0.08847661702228443, 0.18903121165931225, 0.15638713618474348, 0.10640347828822476, 0.19053236182246888, 0.18576927669346333, 0.16660291515290737, 0.1830245889723301, 0.1328094420688493, 0.14056584372052125, 0.11054516783250229, 0.08727575253163065, 0.1335898387644972, 0.08337214056934629, 0.1749688990946327, 0.15998810795801027, 0.1303396424544709, 0.07897719461470842, 0.14888287814600126, 0.07488312465803963, 0.13360928557813168, 0.09180423417793852, 0.15921801142394543, 0.0894684452297432, 0.1811357917530196, 0.1265428319041218, 0.1129170616290399, 0.09845424376960311, 0.09724662107016359, 0.1812819346253361, 0.1351881687130247, 0.1443389733987195, 0.16417677248162882, 0.09149972801761967, 0.13196576519736222, 0.13562167116573878, 0.11027551123074122, 0.21812606044113636, 0.1365418460752283, 0.08996087844882693, 0.15612402744591236, 0.1010331314589296, 0.09632559799190078, 0.09101228203092303, 0.0970303855304207, 0.1528019064239093, 0.10945516917854548, 0.12196402331548077, 0.15442260088665144, 0.16452582446592195, 0.09193404471235615, 0.08116973124976669, 0.10756797330187899, 0.07893670643014566, 0.11429617048374244, 0.17589892633259296, 0.13879762217402458, 0.19686896965972014, 0.12452976778149605, 0.09661654023719685, 0.13249025919607707, 0.15039481701595442, 0.12593747010188444, 0.17301763594150543, 0.07883474975824356, 0.1763299046350377, 0.16436396672257356, 0.14341320736067636, 0.08269346305834395, 0.2532409397619111, 0.14207489203129495, 0.19422230310738087, 0.1492816667471613, 0.11005457344331912, 0.20185954043907778, 0.14763305735375198, 0.1445404440164566, 0.07177548855543137, 0.14851034885006292, 0.16755061144275324, 0.09090869687497616, 0.1394535076937505, 0.08937900752893516, 0.08081727301967995, 0.21429746731051377, 0.15996743978134223, 0.15453466773033142, 0.1546252928674221, 0.07707795474146094, 0.13963015750050545, 0.10871451427893979, 0.15751439998192446, 0.21623214706778526, 0.1520655466509717, 0.15650290782962525, 0.14359277486801147, 0.12361863095845495, 0.11512445818100657, 0.10869172907301358, 0.07494471528168235, 0.14835626711802824, 0.16717152749853476, 0.08995325171521731, 0.16975532099604607, 0.12471295866583075, 0.08842714503407478, 0.12826451951903955, 0.1854292627956186, 0.13663107343018055, 0.1122106998892767, 0.10856014756219727, 0.22212329666529382, 0.13561507580535753, 0.18898332065769605, 0.15922001988760062, 0.1415919650878225, 0.07533620963139193, 0.1580123904028109, 0.07572669296392373, 0.07663065088646752, 0.0880481018019574, 0.14973123690911702, 0.14505439358098166, 0.12152934021183423, 0.114416773297957, 0.1279327566070216, 0.08947356138378382, 0.12665609296943459, 0.08061831298151187, 0.1357659955642053, 0.18884130327829293, 0.11827208713761397, 0.10956186881022793, 0.20066678444189684, 0.12636106594332627, 0.19798961095511913, 0.10779319264526878, 0.06461919005960226, 0.15973878705075809, 0.16245617052274092, 0.22393563655870302, 0.06848745713276522, 0.08419177694512264, 0.09817620726036173, 0.11187311514679875, 0.12234603853097983, 0.10634414040084396, 0.1085583290883473, 0.10149290000221559, 0.12512009324772017, 0.1417075331721987, 0.1857584472745657, 0.17574329754071577, 0.07050934221063342, 0.10477808157780341, 0.08742300141602755, 0.10294052732310124, 0.15837734724794114, 0.1728042366781405, 0.12631705616201672, 0.09981493718389954, 0.16212699961449417, 0.0679331279492804, 0.09753546664225203, 0.1412381769290992, 0.12432665510901383, 0.13699700736573764, 0.10105552989989519, 0.20158757003290312, 0.1338098876710449], [0.02736510186722236, 0.04400391537430031, 0.013029354957065411, 0.021636313825313534, 0.01689998502843082, 0.011323187134361692, 0.032653639425656626, 0.03874565574473568, 0.011462788929098418, 0.03865437242867691, 0.028018546357218708, 0.034710329957306385, 0.022463634610176086, 0.054545197768935134, 0.04212755570188165, 0.026849637473268167, 0.07730345228420836, 0.03570177139980452, 0.037041911988386085, 0.0361314197736127, 0.030491541871534925, 0.02508718517076756, 0.047637266838657, 0.02938964171335101, 0.0457928593802665, 0.05966300743498972, 0.0040638827818578905, 0.0551855550147593, 0.08688744729650871, 0.021115967371900166, 0.04679497417860797, 0.04523501538538507, 0.03929582890123129, 0.04321669940171497, 0.07319825435323374, 0.05388214013406208, 0.006450505029144031, 0.012107696600391396, 0.018641972714768987, 0.03890515218621918, 0.03293432900682092, 0.03969572351447173, 0.02644582262395748, 0.0797222735626357, 0.010589024118546928, 0.03459898914609637, 0.05377937600548778, 0.0645844287105969, 0.0044616009940260225, 0.049716623832604716, 0.022916456651208655, 0.030919127498886416, 0.019693637532847266, 0.026479661165337478, 0.013220013967449111, 0.09040300508162805, 0.05129676225728222, 0.03162088877122317, 0.005174588628246316, 0.07232607901096344, 0.04883669962042144, 0.07605298009834119, 0.023760773041950803, 0.040985917140330584, 0.025615762253957133, 0.03785708360373974, 0.046556218061596155, 0.10125489705907446, 0.0466233149969152, 0.040419191122055054, 0.028212368188958083, 0.037473952198135, 0.07366007207227604, 0.062415552591638904, 0.01946892200170883, 0.04650764513228621, 0.03196673467755318, 0.042991690404180966, 0.023187750218702213, 0.07539236518953528, 0.05429471995947616, 0.09477414802781173, 0.044892646971025636, 0.07015739966716085, 0.011367017103891288, 0.03682796311165605, 0.06024782319686242, 0.04483999604625361, 0.019605875813535283, 0.05005491425150207, 0.020100164825895002, 0.08038958561207567, 0.04495616802679641, 0.04847482332427587, 0.037264060960816484, 0.10512856527098588, 0.10064332666141645, 0.04725452559068799, 0.019480017745601277, 0.07092787618083612, 0.043464415573648045, 0.04906152541350041, 0.021137017224516188, 0.06453811869557415, 0.006916262916222746, 0.017418041426156248, 0.06990364114088671, 0.04096136435068079, 0.008122883504256606, 0.03237961984372564, 0.06925697691206421, 0.07322374691388436, 0.09297273933355298, 0.0356483164110354, 0.04345126895766173, 0.021780622956742133, 0.03363247029483318, 0.06163035186805895, 0.05750678599412952, 0.04241743264719844, 0.015814866737595627, 0.024500579772783176, 0.05869156241949115, 0.016069827967190316, 0.030982207506895065, 0.07097462724362101, 0.008518812928481825, 0.027637852588668466, 0.03138238710484334, 0.033676995762756894, 0.016889138646157723, 0.03389247812862907, 0.07140188717416354, 0.07603411003947258, 0.03747283261535423, 0.02627806332228439, 0.024571559624746442, 0.0472680725423353, 0.033025283233395646, 0.014149062418644982, 0.03550894531820502, 0.09254355236355748, 0.051404364340539486, 0.0607255186353411, 0.058568808649267466, 0.010023433798258858, 0.041951886378228664, 0.03437550685235432, 0.0640071446874312, 0.04968310081000839, 0.04050419120384114, 0.011742771985674543, 0.04202693235129118, 0.04923228553629347, 0.046839598034109385, 0.035325157323053906, 0.019482594482334595, 0.04441716016403266, 0.05227825637640698, 0.01922288181127182, 0.01643085609456258, 0.022689848007368188, 0.03477097063192299, 0.03878050530329347, 0.04346734345225351, 0.03333949583715626, 0.03647779154458216, 0.020987729342388253, 0.019061482079061012, 0.02562596063528742, 0.014202435135043092, 0.06627388591212885, 0.04543999402916857, 0.02804407454095781, 0.017280219089505926, 0.04358933726325631, 0.04191186299015369, 0.022240642557985017, 0.015036268159747124, 0.04513230214693716, 0.06475174187549523, 0.05472871435007878, 0.018012997893882648, 0.028296187619811723, 0.028875027184507678, 0.03521750095699515, 0.0829935994531427, 0.0339711305153157, 0.009858967935932534, 0.007303861202672124, 0.026190383027174642, 0.012018854314062213, 0.05465384818879621, 0.006707851733413658, 0.028395391135875667, 0.05070238593699677, 0.04662704693951777, 0.023472977502803718, 0.011328657822949546, 0.03590104356408119, 0.03249207005969115, 0.00871930900029838, 0.03015014376225216, 0.05343399828832064, 0.027005776862746904, 0.03798594758180635, 0.018372148175590804, 0.021375167749023864, 0.04801678843796253, 0.061789821168141704, 0.03515611728653312, 0.033492576730038436, 0.08749854950500385, 0.041642050325338326, 0.0754936093996678, 0.0046649168029294485, 0.01914845160873873, 0.007654288916715554, 0.05550990493169852, 0.04315547179430723, 0.04177497533549156, 0.013809714333287306, 0.08597738255879708, 0.021698238627452935, 0.03274843076776181, 0.00811591325327754, 0.022520977604602064, 0.049087442058537684, 0.0621832154159035, 0.02002347001273717, 0.04996773946498122, 0.07855958345213107, 0.009565310702393097, 0.006037266600677478, 0.011488798872700759, 0.021730011029701148, 0.042746077690805705, 0.035005387517490556, 0.03590611222067049, 0.025178824717711126, 0.02972022058176143, 0.06685916986316442, 0.018139894120395184, 0.05286443938634225, 0.13294783607125282, 0.05391500158501523, 0.03319643012114933, 0.059451189158218246, 0.052076938429049084, 0.05997706058302096, 0.011245421932211943, 0.04644356428512505, 0.1768481425408806, 0.04609160477827702, 0.004547788936179131, 0.028853995991604667, 0.04874943323167307, 0.04071734280192426, 0.0141955038998276, 0.006461527406437588, 0.07324821488665682, 0.05228287380720888, 0.04513537251789655, 0.019681142310478857, 0.04842429621411221, 0.041130719905985255, 0.043254042576466284, 0.06142295763960906, 0.051292735151946545, 0.07549498004040547, 0.030531395625855242, 0.020349467073434165, 0.07310037567679371, 0.030680242460221052, 0.03965465518246804, 0.11125536329512085, 0.0469063590945942, 0.07479657751641103, 0.04272311606577464, 0.06466705391981772, 0.018317790735246878, 0.028431989618444016, 0.10121841223112174, 0.08934711638305869, 0.11392019422990934, 0.06559504555272204, 0.0669788159430027, 0.08916826133749314, 0.0683315908536315, 0.02249802276492119, 0.05841741391590663, 0.00929346667336566, 0.0683167784341744, 0.032597141207328865, 0.06287738388138157, 0.036793493532708714, 0.023853518600974764, 0.018423265611220683, 0.025055143050849438, 0.0411693014071456, 0.04378386986042772, 0.04281366317133818, 0.027351163061601774, 0.03721128111439092, 0.047339556206549914, 0.03510723223111459, 0.03695805184543133, 0.0775389378624303, 0.03784583688580564, 0.018155575064676147, 0.05369491196636643, 0.05646753836689251, 0.05673268271077957, 0.03112985333427787, 0.06163602442081485, 0.026686076607022966, 0.013503093688216592, 0.08104586468211242, 0.03690352477133274, 0.016909881461677805, 0.04311500057311995, 0.047328445195619545, 0.034125660080462694, 0.03696390760264226, 0.06226073804178408, 0.048475542571395636, 0.03255228325724602, 0.026229822875133584, 0.07466692983039788, 0.0419549296077873, 0.03872842434793711, 0.011194732821812587, 0.04036878614819475, 0.05725099864814963, 0.014235893696812647, 0.03697184306968536, 0.017543967347592115, 0.04725440684705973, 0.03220954843397651, 0.009334594377183487, 0.04270171167861138, 0.05215653397941163, 0.07250017074069806, 0.022964400239288807, 0.03968074485393507, 0.056182821680392535, 0.03874966588669589, 0.04263067924018417, 0.03636920219287276, 0.03959439109478678, 0.03740590870646494, 0.028266099680747305, 0.12519695769463265, 0.08905962788100753, 0.11309817619621754, 0.16793223310794148, 0.19990789730634007, 0.09524781975362982, 0.16615927538701467, 0.11596109185900007, 0.07868794870695897, 0.1304688083806208, 0.09962822470281806, 0.18180015896047863, 0.08808100396501166, 0.09738466223435742, 0.09178378313247647, 0.0804131647039737, 0.16507307652916225, 0.06712934215153966, 0.134515482666237, 0.1313234639487096, 0.10518910416534968, 0.10034827927925757, 0.09929914200412375, 0.12341946735978127, 0.1163391580006906, 0.14696115840758595, 0.06467380534325327, 0.18242263341588633, 0.15438053171549523, 0.09139332015599523, 0.14244408293494157, 0.10030904638447932, 0.06770251425249235, 0.1186588928103447, 0.20126591729266302, 0.15697176195681095, 0.15463967780981744, 0.12380689728472914, 0.13798355657075131, 0.10137505204017673, 0.07589984831533261, 0.11502104944416455, 0.12192975729703903, 0.16106787430388586, 0.11457439698278904, 0.08965665727321591, 0.21237747105104582, 0.1188933402299881, 0.1144320403358766, 0.19310140396867478, 0.20311720509614262, 0.08527034906936543, 0.13827331816511496, 0.09233299616192069, 0.11316107639244624, 0.18554871210030147, 0.12926951130586012, 0.11179862557245152, 0.1796921542180436, 0.11323186795094184, 0.15441162219004972, 0.17740076860146864, 0.13165304197796754, 0.2330394594797066, 0.15587579219469003, 0.12385139561125211, 0.09194164430456502, 0.23075388212289127, 0.2305673664169652, 0.1733752374670335, 0.2355314471891948, 0.22254047356545925, 0.25967822862522943, 0.18108791432210378, 0.10559249323393617, 0.21466213917093618, 0.26824261620640755, 0.20457350409456662, 0.0967587883185063, 0.11589185414569718, 0.11953386371689183, 0.1680637603359563, 0.09491617897791521, 0.16489512393517153, 0.16673529733504566, 0.08048232099307434, 0.16459895697023186, 0.09665621417973723, 0.1316544126187052, 0.15342485585383006, 0.09815025329589844, 0.17099925210433348, 0.15062117629817554, 0.2726260338510786, 0.198243613754, 0.22160794931863034, 0.19468336765255245, 0.21322158218494483, 0.18535579102379934, 0.1680645610072783, 0.18464255572429725, 0.1067286254838109, 0.13739994860121182, 0.1479323591504778, 0.10232694846178804, 0.14820712512092932, 0.1842445813651596, 0.20266924984753132, 0.25244786803211483, 0.1491872011018651, 0.22702484365020478, 0.2381800679223878, 0.14421389225338185, 0.11392349191009998, 0.18436747762773717, 0.10902068963540451, 0.22890538988368853, 0.14065219408699445, 0.1306426761937993, 0.14548577900443757, 0.13259437360933848, 0.11510920471378736, 0.16191389890653746, 0.17969093285501003, 0.15879954530724458, 0.15189724282494613, 0.17242547843073094, 0.1141222348170621, 0.14252185661877903, 0.10962158667721919, 0.07742577179202012, 0.20849148742854595, 0.1604944850717272, 0.1711501854338816, 0.1353354922362736, 0.12091587670147419, 0.13800095420862946, 0.15233139667127812, 0.14716980792582035, 0.13038762845098972, 0.1258897962314742, 0.14668103201048716, 0.08314551665846791, 0.20862471099410737, 0.2297334468790463, 0.10678238581333842, 0.12203465881092207, 0.11599457077682018, 0.13700763322412968, 0.15134488817836556, 0.12875537175152982, 0.07958267855324916, 0.12967252039483615, 0.14281354525259563, 0.11520779585199696, 0.12867614600275243, 0.1469734398914235, 0.17850672639906406, 0.10929610021412373, 0.11577525468809263, 0.07866525171058518, 0.09172910678067378, 0.11903370198394571, 0.06315828380840165, 0.1490654447781188, 0.1079884207408343, 0.11675134088311877, 0.0845644623041153, 0.09592774576906647, 0.11782751099339553, 0.1470753422805241, 0.23077073693275452, 0.16962486585336073, 0.10583192110061646, 0.11335755977779627, 0.08845549422715392], [0.005284590180963278, 0.03527376168806638, 0.06567402024354253, 0.024836654774844646, 0.08103401067533664, 0.047823317748095305, 0.031074128645871366, 0.011709829110519161, 0.07472192509365932, 0.024665024430890168, 0.031130538654646704, 0.036653464260910235, 0.02153014175460807, 0.08968908446175711, 0.02142104859064732, 0.044859232514032295, 0.028532733409000293, 0.02065959320004497, 0.03939726649384413, 0.03366724182186382, 0.08121833471315247, 0.013396685826592147, 0.06038020537900073, 0.06306223717651196, 0.11686553832675729, 0.03008392213710717, 0.0325426514526563, 0.03966264153963753, 0.056664208349372656, 0.021342253711606776, 0.04200861529846277, 0.04820849832945636, 0.07079571791525398, 0.0566679538626756, 0.031477616102035554, 0.03719184108610664, 0.03965991043618747, 0.04433424997010401, 0.05692775813596589, 0.039454646807696135, 0.017314905799659233, 0.023486549899514233, 0.026147313016865934, 0.012494566733948886, 0.07510493097028562, 0.022204235761559436, 0.010385946220984417, 0.04624947952106595, 0.07098262717149087, 0.021324457434405173, 0.018768098804035356, 0.05446319002658129, 0.06096816275800977, 0.03901756169008357, 0.024955525628424118, 0.053743783451084576, 0.0467154871938484, 0.012352210935205221, 0.07923743993576084, 0.019247103815100024, 0.10474330665809767, 0.03739572050315993, 0.027896533886502897, 0.015561053928519999, 0.01570570911280811, 0.03354414878413081, 0.032106268618788035, 0.008696043730846472, 0.07240214278655392, 0.049758713359811475, 0.044591302783893685, 0.026774199646232382, 0.015295438002794981, 0.03179233082170997, 0.07195189408957958, 0.08683505082236868, 0.07397851534187794, 0.033090571872889996, 0.021853185491636395, 0.04343752183818391, 0.06053174939006567, 0.04391344290758882, 0.035302124451845884, 0.04665539273992181, 0.03421905364042946, 0.03364455500351531, 0.04168269796563046, 0.04974450483652098, 0.025896266934328845, 0.030852749810687134, 0.05041226471907326, 0.060183572715946605, 0.08170621496226106, 0.04182609277112143, 0.008943623347607042, 0.06653385981917381, 0.05286815436556935, 0.015469836769625545, 0.01998630495342825, 0.04634610290772148, 0.10035355828170266, 0.11543898630355086, 0.021135169912927916, 0.02327296743169427, 0.0524503396424864, 0.041595730132290294, 0.015479607673894082, 0.10680766802813325, 0.026259956615311757, 0.07312067065920148, 0.0288026716027941, 0.05801943955676896, 0.0292286965996027, 0.07804116234183311, 0.014168382006963449, 0.03444125350298626, 0.03657687801335539, 0.01771650692847158, 0.06653029072497572, 0.10259482730180025, 0.03128317171441657, 0.0063384309760294855, 0.0038203387521207333, 0.07748489254819495, 0.0247412425731974, 0.03868335605199848, 0.0683798346934574, 0.02592949309785451, 0.0841764895511525, 0.03259527184335249, 0.028066006489098072, 0.026469930973170058, 0.054043909667858055, 0.011195565723547978, 0.02251978338296924, 0.04343082469754985, 0.01975370484537312, 0.03819370821916631, 0.030858351117266074, 0.0254073366522789, 0.03855892290760364, 0.03389782498457602, 0.06013359182647296, 0.032448358833789825, 0.06595279635595423, 0.020926969924143383, 0.07757786541645016, 0.06060083104031427, 0.039369870642466206, 0.06531033225889717, 0.00524149345333821, 0.03875776420214346, 0.05972271851663079, 0.021154889836907387, 0.06654557811894588, 0.04501559751640473, 0.037777851069612164, 0.0410165360330471, 0.02027523534239403, 0.03622945790578212, 0.049686897213437727, 0.03854771690177066, 0.013255345285870135, 0.0249747112060764, 0.05080497364646622, 0.04876522274155702, 0.045897095929831266, 0.015251548661451255, 0.016678607889584134, 0.041208724291729074, 0.030049228641603674, 0.02911332529038191, 0.011235465278982051, 0.02731079701334238, 0.05735778648938451, 0.07447233955774989, 0.05336180555501154, 0.020257525578407303, 0.03539041542847242, 0.02217499938394342, 0.010944227022784097, 0.04888969659805298, 0.051660467205303054, 0.05690488811316235, 0.05832972005009651, 0.018054120508687835, 0.0334760272609336, 0.021805129945278168, 0.02130720398521849, 0.02221002196893096, 0.01475018252884703, 0.06548833235033921, 0.011416548463915075, 0.0277312376669475, 0.03094138005482299, 0.09226423342313085, 0.05282539308869413, 0.02776291168161801, 0.014662705794242876, 0.039298736423786194, 0.06966630316206388, 0.030018884555569718, 0.0405129985883832, 0.02547127670342369, 0.022529703564941883, 0.029486061539500952, 0.020375371844108616, 0.018324145215696523, 0.026759392315787927, 0.058871068858674595, 0.040948309336922, 0.012497626078714217, 0.01613208355515131, 0.05951548035123518, 0.06090960518590041, 0.04779648508078285, 0.03208334770585809, 0.05046553311071225, 0.014985880149262292, 0.029163709908191646, 0.022646761033684015, 0.036110103596001863, 0.03842381640736546, 0.027177410599376475, 0.0566373281846089, 0.03427415407661881, 0.04570237673552973, 0.03004064517361777, 0.10832566621580295, 0.11066357897860662, 0.029055100200431686, 0.021120768007157103, 0.0634704234876803, 0.0097005690248417, 0.02386595445152904, 0.04951654760433095, 0.038192822730966976, 0.04221436407949243, 0.01064506687024342, 0.05167576477729848, 0.032084307832909484, 0.07387138823313372, 0.025932490526299392, 0.041363813648266454, 0.024612739915028214, 0.06743210447686059, 0.10933648661843368, 0.02179431070440582, 0.06209619329976184, 0.053311733063310385, 0.183639721678836, 0.03310953014131103, 0.10964483328695808, 0.061270707952124734, 0.010090020135976374, 0.013427354761266282, 0.07310843667281525, 0.009875905018166771, 0.05298293534932392, 0.06011511531791516, 0.04207491834780999, 0.07611649776143686, 0.061135618415262015, 0.045748774960104904, 0.024770567160365835, 0.006556638932254697, 0.09114636055060796, 0.08401716952877385, 0.11244247388094664, 0.037380256690084934, 0.01164432758066271, 0.026282056500869136, 0.019987697646554028, 0.06331289479775087, 0.007353400196214872, 0.07368419399218899, 0.1402608286589384, 0.08199284172483853, 0.01144153721231435, 0.01587301040334361, 0.01375594552207206, 0.034869795864714045, 0.019441376872626797, 0.04649853240698576, 0.03502288354294641, 0.024263474192204218, 0.09091426764747926, 0.0694259592731084, 0.045227683814508576, 0.1002950007095933, 0.01972690949748669, 0.04202328522556594, 0.048771417766277275, 0.010021568675126349, 0.11259131732263736, 0.043781186254428964, 0.04538978922313877, 0.048553421428161006, 0.03897844414625849, 0.08304125975285258, 0.006509273371193558, 0.025843970544104065, 0.027469197620770762, 0.052871187417102714, 0.05717688226806266, 0.040404806179659705, 0.0033250775263046046, 0.04633375357038208, 0.02212403292235519, 0.060433714650571346, 0.07932984961995057, 0.0436194133279579, 0.053541593586227725, 0.04353235049971512, 0.01942782652830439, 0.03291416633874178, 0.011368140927515924, 0.05381550799523081, 0.07739409099199943, 0.06603997453515019, 0.05501690513587423, 0.014714401680976152, 0.042152060994080136, 0.06967594514467887, 0.019848642072507312, 0.04210731839495046, 0.02574921821776245, 0.08089154546282121, 0.010431278297411544, 0.009639625553973019, 0.04320977495184966, 0.04170388522158776, 0.04791082162410021, 0.01994100765192083, 0.013122074222857398, 0.028200429365304962, 0.08480147458612919, 0.027242634778044054, 0.022161516893122877, 0.01891822467691132, 0.041442089448017735, 0.04233306360297969, 0.032156144335333786, 0.022117625855441605, 0.03182763499873025, 0.04202781444681542, 0.0350702758213239, 0.012565869738214781, 0.014825430366077592, 0.007848765534747924, 0.074949213968856, 0.021297904662787914, 0.14646038599312305, 0.12316549170230116, 0.08464606292545795, 0.12845092665936264, 0.2043741097939866, 0.10061369503715209, 0.10385291265057665, 0.1238694175013474, 0.231594125607184, 0.15334343165159225, 0.09531259270650999, 0.13888756877609662, 0.09720428727035012, 0.21892184631100722, 0.11035701685718127, 0.18367786891758442, 0.09070563169994525, 0.0719725147687963, 0.11735504705991064, 0.20011046715080738, 0.24694646894931793, 0.09246876423380204, 0.1390408362661089, 0.15803049371710845, 0.15619650855660439, 0.06987886782735586, 0.1569425170975072, 0.10840780287981033, 0.0861902864915984, 0.12360643089881965, 0.07484826152878148, 0.08143004442432097, 0.06327795702964067, 0.15755709340529783, 0.15927335274006638, 0.1329145607139383, 0.05807855352759361, 0.1292196118405887, 0.18532585405877658, 0.12812380492687225, 0.13251541927456856, 0.19293905768011296, 0.13805796472089632, 0.12187919286744935, 0.23687869203942163, 0.10607991886458226, 0.09472097802375044, 0.0981052867802126, 0.1729763267295701, 0.15337009807782515, 0.18333054041223867, 0.13909825389938696, 0.26364820131233757, 0.23487049979822977, 0.11116106728357927, 0.09467229313616242, 0.1339209231414965, 0.1500575036874839, 0.38102775705712183, 0.1451458872428962, 0.16652625426650047, 0.1360366903245449, 0.22349226820681775, 0.1119119409205658, 0.09000658456768308, 0.1657985933125019, 0.07961703278124332, 0.1509105579129287, 0.13823622944099562, 0.15230447240173817, 0.2075768086527075, 0.1747080838041646, 0.10488917811640672, 0.17311834410897323, 0.1798100836042847, 0.1560611136789833, 0.19564612741981233, 0.15536466533584253, 0.08395988760249955, 0.14234754097248825, 0.13785797330949986, 0.11612366884946823, 0.17534600171659673, 0.14739932918122836, 0.1880642314042364, 0.1924552893532174, 0.1164502070418426, 0.269664147070476, 0.14899668203932898, 0.08615184069744178, 0.19722263568214007, 0.12473453607942377, 0.2248479811740773, 0.19545824107314858, 0.16960980237594672, 0.31545502852116314, 0.14409824274480343, 0.17612038659197943, 0.1119800658364381, 0.18057745242757456, 0.18503453183387006, 0.2732789202460221, 0.15216134222490446, 0.11370968552572386, 0.16792546132845537, 0.13168273467038358, 0.08217266707548074, 0.15361351573041507, 0.16758600382932595, 0.21073861899120466, 0.1181455132152353, 0.20769215960587772, 0.2531972149653094, 0.1247880860630955, 0.2086105024708169, 0.1238681147141116, 0.15994327036397799, 0.1403932244117771, 0.1571995054504701, 0.14875201588230474, 0.08915557273264442, 0.1804301831871271, 0.1553349726434265, 0.1917166497026171, 0.0575949548344527, 0.08972521645150014, 0.145035448883261, 0.1766951736062765, 0.13585512792425497, 0.0949884293867009, 0.11352371943316289, 0.09658367200089352, 0.09311711122947079, 0.12250387934701783, 0.1195446252822876, 0.10027889228825058, 0.1563233538929905, 0.12163838078933102, 0.09326060781521456, 0.08937963178115231, 0.12334668769368104, 0.11398431578917162, 0.1364212025489126, 0.11735370356057372, 0.18397831065314157, 0.10112712891506297, 0.15291807161910193, 0.15291991723435266, 0.11171829381159373, 0.21498369691627367, 0.0744701207482389, 0.16032854254756654, 0.21611452980765275, 0.11094550349350486, 0.12002295175833361, 0.06956068240106106, 0.13798434367137297, 0.08104750673685755, 0.07174448629042932, 0.11749080834644181, 0.16731966526380607, 0.13709227368235588, 0.10267334058880806, 0.11763844399579934, 0.12527049731995377, 0.1060081095035587, 0.12189247858311449, 0.08471162297895976, 0.09428159267242466, 0.09150070510804653, 0.15230194825146878, 0.11934565167341914, 0.09350766241550446, 0.075944034515747, 0.1952160990663937, 0.1701719822095973], [0.05111136952681201, 0.03905182770852532, 0.08967029582709074, 0.0752011743773307, 0.02320158894040755, 0.04939344099589756, 0.07716893271676131, 0.05076801384400044, 0.025867575081065297, 0.02125786940035011, 0.05260653840377927, 0.06200894048171384, 0.025162322746057595, 0.0708195548504591, 0.03774356808779495, 0.022889091333906566, 0.016501043756891574, 0.032322398985603025, 0.007822083841477121, 0.02681991594311382, 0.01789351466244885, 0.05636641290038824, 0.058690598899764676, 0.025108774458723407, 0.03606912686622568, 0.042821866659713645, 0.010494041090298976, 0.03505056777170726, 0.03633230006588357, 0.01461951364763081, 0.004071907730706568, 0.004820498097355345, 0.04509294372318046, 0.021252961895827736, 0.030700079431491237, 0.05323337583935686, 0.04618118836411408, 0.07421550048249108, 0.02005264362586396, 0.05309061885678342, 0.03559524140187672, 0.038957046544445414, 0.031185228577149764, 0.07356412043528897, 0.04325076864500131, 0.017875457149265066, 0.04331673242683921, 0.09068375573094402, 0.012016264006628521, 0.03372446607266154, 0.03943501000425645, 0.0900173189916781, 0.02535384095140866, 0.02815381740219891, 0.026815946513254727, 0.0201136201753148, 0.10842419628586088, 0.08472819958946534, 0.05930527698780809, 0.04143035079219511, 0.07114749082497188, 0.024978120844545107, 0.041382500502680025, 0.009772760061813253, 0.06423249973782472, 0.06320715868579489, 0.01957245117851666, 0.027847687846847942, 0.036079294713480134, 0.08307035533445221, 0.0457903962981488, 0.05280611590881433, 0.014974784405369843, 0.025956851629806415, 0.01251192026705082, 0.015226100205576845, 0.07306541755263295, 0.10502236775521721, 0.05277734263134854, 0.028375247127509544, 0.02300973316388471, 0.05905303837997573, 0.05349045579454728, 0.031006475311837027, 0.06600796803832054, 0.028592447883316448, 0.026888441194647124, 0.06720089366925613, 0.09474911687097379, 0.05707964141454015, 0.043587712171886644, 0.1293199671698468, 0.08851253866617169, 0.05938368170921292, 0.02682879627017038, 0.05075883326519813, 0.05432844654257808, 0.06183143572083541, 0.03224714266668473, 0.07859689609280654, 0.06005855942411082, 0.05874953645148447, 0.034346411270754676, 0.040697655108358176, 0.01887484423683158, 0.04252238165853279, 0.11082472426018544, 0.03720463825655835, 0.04382332667176213, 0.013988077440964324, 0.02246262868201094, 0.052080571984073946, 0.07479521366102354, 0.05215626935075436, 0.030790677427181175, 0.03602466246645365, 0.011156273456955594, 0.03994361949818475, 0.02067023771815002, 0.015616971999406815, 0.03407712107790368, 0.04644839206178274, 0.04796674648033721, 0.0987664105902825, 0.018916611459904482, 0.054954052437096834, 0.034729970153421164, 0.029715386019753556, 0.03694198074351464, 0.10283875385565416, 0.028653695846774747, 0.013442017054850501, 0.010725492777835046, 0.08962044385927063, 0.02981264722932662, 0.02490499003657273, 0.03282462346500584, 0.05682527899209942, 0.05103567894548178, 0.030234383884817362, 0.032302025971668105, 0.05019901812608753, 0.02182301952104483, 0.022265217400022914, 0.020840846866901432, 0.03126783003764493, 0.03199496173432895, 0.07861335056700877, 0.022143981851903454, 0.012242197508125432, 0.04018430604732462, 0.037301499130470414, 0.038477698873196325, 0.0063580054390643325, 0.03967563887791974, 0.02699607890099287, 0.043041006329336336, 0.05633277791951384, 0.04460973518767527, 0.057423190479832034, 0.012447333063131996, 0.03793584455602935, 0.05125263712501951, 0.028391531967957104, 0.007947897804634911, 0.0052783396011883655, 0.02699638593808881, 0.014967720855825713, 0.05170178998793874, 0.08338670871619668, 0.014055925005647753, 0.03446858150086232, 0.023516128937314664, 0.05708572108830724, 0.056212175105299265, 0.01766263972967863, 0.01125112162636859, 0.05479583842679858, 0.05604200530797243, 0.0049162644094654494, 0.02911291816937072, 0.0581586342304945, 0.08814099324601037, 0.015812698818211044, 0.03851177829450794, 0.03717549857018249, 0.03889416331159217, 0.028469144499727657, 0.019250460867104784, 0.020569839980453253, 0.027834568372262374, 0.027662632687549506, 0.010575971649294453, 0.07902277181191103, 0.027122528990730643, 0.0376535807736218, 0.09556939785501786, 0.020987222137461816, 0.024537300391654884, 0.030472373257258108, 0.002645486537533413, 0.03494859752910478, 0.010053872879195427, 0.02139592243890677, 0.02849768368261201, 0.010134943395054765, 0.03852534220953073, 0.018015513562464287, 0.03781237493136099, 0.023600654044587697, 0.010882924776524305, 0.014089828007854521, 0.03558233227314694, 0.07105072494596243, 0.009850177514765943, 0.05783822999468871, 0.04074520344978996, 0.04766783484124711, 0.016901635564863682, 0.05081503292811768, 0.016718466732917086, 0.04421859367617539, 0.037733023653605154, 0.03520285138594253, 0.09016056451946497, 0.010568461114806789, 0.029583539880279983, 0.058368484755711894, 0.02950366952323488, 0.03429562631728394, 0.049680949853999276, 0.12441759237221309, 0.06337551679462194, 0.10729966019945485, 0.0670725419851286, 0.009194300476727741, 0.03668842917042119, 0.0480844282012965, 0.02993234759196639, 0.01374686078634113, 0.019333452485235672, 0.0266768977245582, 0.02244308008812368, 0.00449565115351496, 0.041896942005093606, 0.046325438123728545, 0.0554973656045539, 0.04285239055752754, 0.0410773293780429, 0.04932909891275423, 0.046657387632876635, 0.09455446553017412, 0.159397850345288, 0.060282496336315355, 0.06772508232721261, 0.013208085321821272, 0.0702530120366386, 0.02457436197437346, 0.038631437945046594, 0.031550246490431685, 0.07949343762759652, 0.061447771665241034, 0.030284744753901447, 0.06083896969045911, 0.05345753327544246, 0.03529640440163868, 0.09113781100937299, 0.10572030209004879, 0.13944088694240364, 0.032693143734442334, 0.020345821644046476, 0.06416902278683015, 0.17845924251845904, 0.011539892559604985, 0.025466482853516936, 0.1321812950606857, 0.08418079824852091, 0.0931173080046262, 0.05664384890613811, 0.03300619265064597, 0.038327349083764214, 0.032324794214218855, 0.028582001836704354, 0.060649522713252475, 0.01491144485771656, 0.06610415716256414, 0.02942031149619392, 0.032126471998968294, 0.05597143766603299, 0.03135039417871407, 0.04912146719704781, 0.05252809636294842, 0.03931127575093082, 0.03345798501478774, 0.022358499001711607, 0.030844325798430612, 0.01543308052766536, 0.023412662524996058, 0.056574841894741566, 0.05394740502483078, 0.0683764216623136, 0.05923436329300914, 0.061278992864702425, 0.08148945016520363, 0.009969888903599764, 0.07580182036118847, 0.08379801628845078, 0.0683224984843816, 0.08170521073043346, 0.05281782403056111, 0.018832334017913257, 0.02466918045787939, 0.03477123186790517, 0.045038898408945115, 0.027981910555224334, 0.030291597957589796, 0.038441142799066644, 0.01653479748139424, 0.014491287492481726, 0.022647407338289276, 0.03522029991394707, 0.0012476972957041913, 0.053555900497095923, 0.012275705263683838, 0.03405510261654854, 0.05769880461905684, 0.017706367918955426, 0.04123082078461136, 0.037302713708153794, 0.06164517107286623, 0.052343273601893864, 0.02720565122685262, 0.029713805033160106, 0.05881215166300535, 0.038344767077692916, 0.019421131084007875, 0.041703932719039064, 0.05079313999574099, 0.022502920091418282, 0.03376510692760348, 0.029650138092360327, 0.03254720102995634, 0.018924599513411522, 0.02028115725676928, 0.028901215243552412, 0.04458000517583319, 0.05602775946525591, 0.08332110116524355, 0.021552200928064327, 0.03601339878514409, 0.013367420611237841, 0.056807620118239095, 0.07910016551613808, 0.14942839315959386, 0.15585483903331415, 0.18160698004066944, 0.16158997985933507, 0.12529586095895084, 0.18718801199325494, 0.13437198608049325, 0.15351035126617976, 0.08698679839393922, 0.11076472819383655, 0.1384875045291015, 0.11798012708978993, 0.1306793170848063, 0.13440710705305847, 0.12657382738377365, 0.1042897602809327, 0.18462582305073738, 0.09570526092180184, 0.07607220978076969, 0.1327091681637934, 0.1679251492023468, 0.08620467821934394, 0.1864879402731146, 0.18799127531903131, 0.0990207458713225, 0.17846848416541303, 0.17787019269806997, 0.07705282858972039, 0.10487322575811829, 0.06120185021843229, 0.12107837226774011, 0.08192929013499192, 0.06509406279240336, 0.1586690901645592, 0.163979386644704, 0.12536015893731797, 0.16648493148386478, 0.0902855031724487, 0.1276894203786339, 0.08832112393741097, 0.11564569521163191, 0.10862544298704181, 0.14516409912279674, 0.14317215100995132, 0.15014787098126753, 0.17754000398729528, 0.35033381836754934, 0.1596349576222045, 0.1321632731705904, 0.1339403021016291, 0.2038056602967637, 0.08323112742177077, 0.15099658258259296, 0.11435227175908429, 0.14585297501512937, 0.2573725937732628, 0.23323172916259083, 0.12515454925596714, 0.19765057414770126, 0.16455280301826342, 0.08401059452444315, 0.16907234835837567, 0.11354389227926731, 0.12996519968977996, 0.09775143755333764, 0.09921841669295516, 0.12962488723652704, 0.1372007578611374, 0.30065509410841124, 0.11063947741474424, 0.09754265232809953, 0.16235909930297307, 0.11819455772638321, 0.198127434988107, 0.1835572932447706, 0.3158934164260115, 0.24153832771948405, 0.12897048092314176, 0.10078474014465298, 0.1503641065210104, 0.11083559439118419, 0.3045151169810976, 0.06383807411683456, 0.1834860606385129, 0.15481889247894287, 0.04860557023701923, 0.15162952004798821, 0.16324944581304277, 0.156874541459339, 0.24699127940194948, 0.2133847020034279, 0.17719868730221475, 0.15824618642883642, 0.1764559085880007, 0.16530419912721428, 0.39627324470451897, 0.17100010705845697, 0.12160655749695641, 0.2225878488804613, 0.21887679158576898, 0.16240574180015496, 0.19113728936229432, 0.23867192438670568, 0.1843365500015872, 0.189258358042155, 0.24888705196125166, 0.31888583728245323, 0.11032935298447098, 0.16356894081192358, 0.15691011026501656, 0.09471565830920424, 0.1345290805080107, 0.13584690407982894, 0.12012865394353867, 0.17336729860731534, 0.21296221895941667, 0.20401051001889364, 0.11118191866470234, 0.1471264088260276, 0.08061954112989561, 0.0752633824678404, 0.15263162127562932, 0.17768544118319238, 0.11765649302729539, 0.21454545828912938, 0.1489033970449652, 0.2599444586251463, 0.1484497013900961, 0.20335956423410348, 0.17091438094420092, 0.21451230506811822, 0.1291159859725407, 0.15507011328424725, 0.08349044314984765, 0.09235975758305617, 0.18433512507804803, 0.12013082525559834, 0.13082452357879706, 0.16035489684769086, 0.08042505942285061, 0.1676284936921937, 0.06765426362731627, 0.08345928482179131, 0.11583644497607436, 0.11001157467918736, 0.13720860172595295, 0.13557785137423448, 0.13378425261804036, 0.162497181179268, 0.12390107794531754, 0.10339794134987251, 0.09544867968985013, 0.16542003862559795, 0.19009913078376225, 0.12679945384817465, 0.1636950397597892, 0.12252682740134851, 0.22369591013661452, 0.12696659059396811, 0.15581975877285004, 0.12249492268477168, 0.10312400319214378, 0.1467465649225882, 0.11376083349542958, 0.0782092490366527, 0.0939414973503777, 0.09503410157880612, 0.11957091172891003, 0.2046828975102731, 0.09950906038284302, 0.1508703072156225, 0.17510122699396952, 0.1429214458912611, 0.12720361644668238, 0.1549178771674633], [0.05252435763499566, 0.0470159051806799, 0.016278533464563743, 0.022150504269770215, 0.06230499209570033, 0.04844340715291245, 0.04214070910321815, 0.022043897936652814, 0.022172717809943215, 0.026036969652133327, 0.013053986626411123, 0.024252471746876836, 0.011188479273446968, 0.04372754127585462, 0.00884739011858723, 0.11469320846455437, 0.011194849869103303, 0.04914154504824962, 0.016326049575582147, 0.06123481344963823, 0.05337984440848231, 0.02432462207174727, 0.011000313879256802, 0.015691353008151054, 0.0060805906375337926, 0.022685591896463717, 0.026322563345144902, 0.01577993405849806, 0.03352686988988093, 0.022935153683647513, 0.08046541190040962, 0.03472761902958155, 0.10157344889427934, 0.04601622971573046, 0.04966566924537931, 0.023453596846333573, 0.07731922143804175, 0.03916261212102004, 0.01180795969308487, 0.04537474610177534, 0.027399006565766673, 0.02250974445736834, 0.026303277683577368, 0.010875468524838132, 0.025399223069793413, 0.033356048698936186, 0.04824073552819235, 0.013963372829104108, 0.016802016446100812, 0.06116049350904567, 0.03095510003290006, 0.030042453469442468, 0.05174320437280195, 0.05549698562494346, 0.04272421529250486, 0.014554638914497835, 0.025957614981702397, 0.07548274605401925, 0.04441413389784949, 0.03896937891840935, 0.038613239635846446, 0.023953745008579323, 0.04579929867759347, 0.04803603508376649, 0.06824078251208578, 0.07988297779645238, 0.005666468417205448, 0.11216254425900322, 0.10202679849628891, 0.05305531807243824, 0.04463312089709299, 0.03972064610570669, 0.03268020407163671, 0.05403400984193597, 0.03900354994194848, 0.2012566349336079, 0.13381644231932505, 0.08108455474887576, 0.017865180736407638, 0.03932226801823292, 0.017883618229201863, 0.05548787289964301, 0.056612571834453514, 0.019909080882955874, 0.022969153377094438, 0.10516464976327759, 0.01896472298540175, 0.01424731853018914, 0.018959598349673406, 0.026973936606996825, 0.05053562577813864, 0.007006242172792554, 0.1850672915045704, 0.08991429023444653, 0.07438022164361817, 0.024154204609138624, 0.1051037512453539, 0.062665416326906, 0.01082968182994851, 0.09665107088429586, 0.21185183711349964, 0.08074388945741312, 0.059490924168910296, 0.017622394121385047, 0.057700100620942454, 0.04959981402914439, 0.08601751111979995, 0.06316144578158855, 0.012087539869493671, 0.02982051484286785, 0.012590468328978335, 0.0591566710333739, 0.10467030307544128, 0.057125910717461786, 0.025488050089084675, 0.09604036222611155, 0.03749302242483411, 0.010209812100843658, 0.05285102135634848, 0.03840262236605797, 0.04413419070520571, 0.008316593377717903, 0.030721968971192837, 0.09008593923811402, 0.04906365601345897, 0.04660706747589367, 0.02188872037056301, 0.011759700586221047, 0.01639703451655805, 0.051822979734944444, 0.014741938328370452, 0.036941040972513814, 0.023495033283584883, 0.03435158849294696, 0.04238558899877327, 0.01473914276409362, 0.04762495821341872, 0.04817312290625913, 0.03638767530875547, 0.04927952514429178, 0.07760413150702204, 0.046565887185611894, 0.06117833898003612, 0.059352394459503036, 0.026287369430065155, 0.02911580533587507, 0.033968222992760796, 0.05096917912097914, 0.009763367440817612, 0.013038728070179266, 0.05102544663740056, 0.021738163627950207, 0.035424698410289626, 0.039898201756711514, 0.03775895047666771, 0.04282330176127808, 0.08466773533395358, 0.046399632535342655, 0.024622439573119794, 0.03995248795087848, 0.010499618648152267, 0.011992527155338653, 0.025565548966239606, 0.018958378682977388, 0.010514288575255444, 0.03668419850457992, 0.044898747000843287, 0.019776598616902317, 0.033486737936202965, 0.0068738990064178196, 0.030415400064417293, 0.03316422684916428, 0.05718091276607343, 0.02195443818345666, 0.057369111238845756, 0.014515070144885352, 0.028390200342983007, 0.03642043158678072, 0.008191334965106632, 0.013757807252529477, 0.019240403281790868, 0.03654186899906822, 0.08440791748996292, 0.04012767890734332, 0.04989287330369864, 0.007586466797095324, 0.025673782087064216, 0.01909450807475618, 0.036900047279362164, 0.07157601961599928, 0.020522819199998463, 0.04932285299790757, 0.010449798062576779, 0.012599656541299607, 0.011429399068999504, 0.08580253765519176, 0.03186858119443059, 0.0497571934413697, 0.015139844834006258, 0.03518154538635697, 0.06560521000730139, 0.055979790432112556, 0.0891287231019565, 0.029148568399250507, 0.027525743336549828, 0.035048990177788904, 0.023166252532973886, 0.03987645470936384, 0.03752426556976778, 0.06173192856035062, 0.0206478816856231, 0.004035357593758298, 0.020769549799816947, 0.04777936903493745, 0.00932607876269945, 0.024666276327999573, 0.03383190870018942, 0.030812726422612156, 0.012238414675396467, 0.017049698691282953, 0.05034591756494982, 0.033591954968869686, 0.02704318958733763, 0.02925907800506268, 0.05070084226982934, 0.04047327036304133, 0.02995649665328009, 0.04166109680331179, 0.05880814830639532, 0.014139216027355619, 0.053246067836880684, 0.04239933951092618, 0.045099433910633833, 0.029024277747209584, 0.052045454404183795, 0.01174978634142982, 0.09463149961084127, 0.05446407551478062, 0.02262361959687301, 0.0876258969573038, 0.04494205449840852, 0.051494327905986986, 0.010684764561509448, 0.13230375706085137, 0.07522592733481101, 0.08637596759945154, 0.06517620624176093, 0.05943421899740185, 0.03721360848950488, 0.09618173499724694, 0.12745903059840202, 0.3183093267892088, 0.18337431949164185, 0.06851934149329152, 0.05779219139367342, 0.045334946630256515, 0.03465801490736859, 0.08108602038451604, 0.06367411970027856, 0.05540106112935713, 0.09660629435841527, 0.04406905134341546, 0.04472449242270418, 0.008873021778916674, 0.016306244834725345, 0.08138884377798863, 0.08306409245623009, 0.10284369359058992, 0.1603324237678732, 0.08863003379000084, 0.18261178183768476, 0.0769133557166372, 0.13365301037473337, 0.09978310710617475, 0.034809609808559926, 0.144222048244306, 0.24234841710754804, 0.084429060641144, 0.024641772732138634, 0.026034486213965074, 0.05775810857968671, 0.03884863361184086, 0.013594108982942998, 0.06090345087328127, 0.08289474368627582, 0.09387073971863304, 0.019187798158132603, 0.0446304067570184, 0.06351198375757251, 0.027679853906322802, 0.03649564040824771, 0.050045238342136145, 0.020124717615544796, 0.019302797969430685, 0.05045936522739274, 0.026040616777858565, 0.032915805000811815, 0.012069802964106202, 0.04046941628413541, 0.07604377237813813, 0.013640200170422239, 0.05328218964859843, 0.01334998310942735, 0.04706189967691898, 0.026251424037452255, 0.04779938242531248, 0.011981354228087833, 0.01491987904799836, 0.062288883674357615, 0.052365410806877274, 0.02143768118029194, 0.04955451503129942, 0.017881653870322874, 0.03180402537275638, 0.025234661364395703, 0.014239783398807049, 0.021413813711010983, 0.035655997427446504, 0.07089523864643914, 0.03718997511480536, 0.01853013487665781, 0.007760835029850048, 0.03743681597656437, 0.09438866549836737, 0.003827715275942215, 0.021777693381799117, 0.042423709096120935, 0.014847777916916778, 0.0324707606674305, 0.045849296530442576, 0.028428157591926198, 0.00836743600666523, 0.05558789913941707, 0.03419586470616715, 0.005136999908635127, 0.033014691301754544, 0.03611247168321695, 0.05185071824650679, 0.0381796082614788, 0.02078142755531839, 0.028397596374686276, 0.030183727853000164, 0.006548710250561791, 0.07721101545861789, 0.018144681184951748, 0.004986421113634216, 0.030798952161733593, 0.01969452471738415, 0.0943572221856032, 0.031250473111867905, 0.017138892119484286, 0.034436374836202176, 0.14458235033920833, 0.13121735464249337, 0.08239105357123272, 0.1578579151204654, 0.13102349718766554, 0.14063044025429658, 0.24135859736374446, 0.14948969201317855, 0.10765299373971564, 0.17069712760193007, 0.10164805381957974, 0.09619387398873057, 0.10433248763105699, 0.17903903712119373, 0.07894645697836365, 0.21590632812253066, 0.07750272444848504, 0.08991859893181495, 0.0802258076146245, 0.23455362394452095, 0.12414114363491535, 0.11405835753040654, 0.0910015001094767, 0.07303608448377677, 0.15761185118130275, 0.10882232670805284, 0.14927045734865324, 0.0781768693455628, 0.11480999791196414, 0.17283751203545503, 0.13559980876743793, 0.12431288084813527, 0.19931944459676743, 0.2005977774305003, 0.08505221363157034, 0.14315510621028288, 0.19678860397211143, 0.15617411690098898, 0.13774904129760607, 0.13519165638302053, 0.07775997743010521, 0.08854814818395035, 0.06475635591362204, 0.1353059895336628, 0.1399656930672271, 0.1515400212790285, 0.10366602375039033, 0.12328887651009218, 0.1585262721138341, 0.15665356974516595, 0.09337165685636656, 0.14013307408562728, 0.10796386455850941, 0.12950832849102362, 0.14452239498496056, 0.2219987040651696, 0.06734833932880845, 0.19982075983924524, 0.20319615943091257, 0.09226301884544746, 0.126932202439223, 0.11713678948581219, 0.08898037499082939, 0.16642351049397672, 0.12402465274291379, 0.09997245908847877, 0.15170589594968728, 0.2347693166562489, 0.16338794838104928, 0.17478584391730173, 0.14258310118956224, 0.20237709980990204, 0.15179345410849365, 0.23578084952064923, 0.1658226813056639, 0.34527007437178064, 0.24747474917343684, 0.1395224061395441, 0.19543008186987468, 0.20618559473327228, 0.07453293273491518, 0.21260909576501164, 0.1594531645200082, 0.21019758230873517, 0.18931882908301695, 0.2036926977868591, 0.14740270828562124, 0.11893580295145512, 0.09059376163142067, 0.23338081687688828, 0.30937763463173595, 0.1485592440835067, 0.4823566483599799, 0.17881000441099915, 0.28176321355359896, 0.21244632878473826, 0.33515219443610733, 0.24234334166560853, 0.1453474121434348, 0.18982103999171937, 0.48096993991306847, 0.19847404424633297, 0.15480636672249862, 0.11662581190466881, 0.14942445765648568, 0.1467766783067158, 0.16939334970499786, 0.18260264875633375, 0.1230660727513688, 0.16955089196562767, 0.19835597915308817, 0.16321207210421562, 0.22664436192384788, 0.2609165550342628, 0.10009678705994572, 0.15169972128101758, 0.1413301048534257, 0.08192790592355387, 0.13308568724564143, 0.13334734391953262, 0.15750764177313872, 0.0696693022868463, 0.1889365017414093, 0.1924792416393757, 0.1237943172454834, 0.2147062032350472, 0.134527926998479, 0.10488959880811827, 0.08739801097129073, 0.14848479522126062, 0.06920335907489061, 0.09643422466303621, 0.18825403121965273, 0.12451684847474098, 0.07843349807496582, 0.1293708844376462, 0.10920558364263602, 0.1118468287001763, 0.1029976260449205, 0.1661267192768199, 0.11497512619410243, 0.11935363124523844, 0.1324710702257497, 0.11992878466844559, 0.10539685123200927, 0.09266315094594445, 0.15993214238967213, 0.19149187819233962, 0.15472697812531674, 0.11789493023284844, 0.1663982147084815, 0.08774044045380183, 0.09772140559341226, 0.09025762895388262, 0.12480191460677556, 0.09911730818982635, 0.18256284589213984, 0.20359485303717, 0.11389951248254095, 0.10852265171706676, 0.11332423013768025, 0.19671791419386864, 0.09548165649175644, 0.08113088511994906, 0.11993829772940703, 0.11810919802103724, 0.08904691213475806, 0.1520116166876895, 0.14230036921799183, 0.09702569685344185, 0.16490125789174012, 0.1242972474013056, 0.15006711174334797, 0.10750466598463909, 0.11718831743512835, 0.0679473839700222], [0.02190191957301327, 0.07721729869289057, 0.025877958363188163, 0.04638295753725937, 0.010460399324074388, 0.0282980060936617, 0.05400511782084193, 0.0652436933347157, 0.05894654230879886, 0.011218965003666068, 0.0125307436766369, 0.033123104234359095, 0.030401703835065876, 0.033040791151246855, 0.03229465368869049, 0.049198270575808625, 0.07072290432240282, 0.016685590014926026, 0.015460929301168238, 0.04810074018314481, 0.007306766180720712, 0.024436470087883726, 0.03200257828991328, 0.018373579884480153, 0.08151101400809628, 0.028961764315941503, 0.03615568079320448, 0.06536200270056725, 0.06447162904909678, 0.01946507640449064, 0.017938019774322, 0.033583069552800486, 0.014633357458348786, 0.012060246646537312, 0.039317765938384194, 0.03890700797949519, 0.020295649068430066, 0.013430517582621957, 0.009457149675914218, 0.08797623137278215, 0.039501418226531575, 0.018608113817338432, 0.02658177898930652, 0.02013567934877106, 0.020398248652262346, 0.03690129917647157, 0.019101245927491357, 0.06270882899739913, 0.03105584891246898, 0.06039723660796881, 0.009552927438302763, 0.010801615925239665, 0.05442823529509561, 0.05266788475481527, 0.00986328172231359, 0.03240496991202235, 0.01398174331656524, 0.051323211552309136, 0.08259039358901125, 0.023617865085335712, 0.1531523290489401, 0.04421947237902454, 0.0847506116011313, 0.06823126945112433, 0.052629014876271994, 0.032339738948004584, 0.06875055230089597, 0.03383765589179737, 0.12364020837204796, 0.06493215076625347, 0.039297521846102815, 0.04269912646019033, 0.30768487975001335, 0.18152027683598654, 0.09560046118817159, 0.3714895631585802, 0.2658488532262189, 0.07747102329241377, 1.1470360904932022, 0.874581264598029, 0.3971244533147131, 2.1406227350234985, 2.2107802161148618, 3.5983035564422607, 1.8675179268632616, 2.521831742354802, 1.2488961390086581, 0.7253982297011784, 0.6306277864745685, 1.0555216925484794, 0.8328719884157181, 0.02576693137442427, 0.17605349660984107, 0.027839469091434563, 0.12703536690345832, 0.15631067885884217, 0.40266116335988045, 0.3371309925402914, 0.08724342033799205, 0.13852151270423615, 0.16325612259762629, 0.14281016614820274, 0.05319897411391139, 0.05791942349502018, 0.0620308978749173, 0.04890816971393568, 0.076758927931743, 0.1554104257375002, 0.009578132469739233, 0.057335937661784034, 0.023325465686087097, 0.02981116802298597, 0.13009964461837495, 0.05033984806920801, 0.04744867142289877, 0.06321931803332907, 0.029028776434383223, 0.07715198969734566, 0.02867379066135202, 0.002529750091655712, 0.008367575954512825, 0.045852007277842076, 0.019754666668762053, 0.05018140335700341, 0.026470480586535165, 0.07215044700673648, 0.07391637510487012, 0.0530437931551465, 0.03134065380852137, 0.02443749297942434, 0.05323059045310531, 0.0367600146148886, 0.02169142783220325, 0.030992283751921992, 0.07274598362190382, 0.012524782746498073, 0.03335571621677705, 0.05434178654104471, 0.028620437452835695, 0.026258217869326472, 0.04704675477530275, 0.022855992395696894, 0.051124984331961186, 0.029711260526840175, 0.007918058379021074, 0.03716065561664956, 0.04886530326413257, 0.0080259191537542, 0.03517114344452109, 0.0069034182483197325, 0.07620647150490965, 0.03432210614638669, 0.026185287229184593, 0.03451562772638031, 0.041115113600556336, 0.0596715026934232, 0.026083479834986583, 0.05990825713213001, 0.03369528567418456, 0.08631036683384861, 0.013704774651809462, 0.004798463944877897, 0.04765308688261679, 0.004323916908885751, 0.028064708790874908, 0.039445852993854454, 0.03369408127452646, 0.0073476385857377735, 0.02916659028934581, 0.05449041624420455, 0.006754825016417141, 0.046634151201163015, 0.04056588700041175, 0.036565560049244335, 0.03376249456778169, 0.027706783264875412, 0.027223401702940464, 0.044012244391654215, 0.0597126694130046, 0.02210289825286184, 0.10661205316760711, 0.053018901097987375, 0.03244292037561536, 0.09463263276432242, 0.05846136262906449, 0.014401435885312302, 0.024505034355180602, 0.03617151101518955, 0.02309618191793561, 0.0687877835173692, 0.029767422870333706, 0.01859544726487781, 0.012247053274352635, 0.049254222573446374, 0.059429733880928585, 0.0410862181867872, 0.023272799494277154, 0.02602827931488199, 0.03178552172279783, 0.04298436901132975, 0.045000713850770674, 0.006629854557104409, 0.07092341142041342, 0.059984130917915275, 0.004563958001589137, 0.017500598781875203, 0.020711653799350773, 0.035769628294344456, 0.03321392275393009, 0.029293310096753494, 0.017938140214287808, 0.02601787567670856, 0.0643805560788938, 0.02641006382847471, 0.02973653595628483, 0.09246324095875025, 0.04225735605827399, 0.07287423352577857, 0.03855697211942502, 0.024740541985790645, 0.05066673231444188, 0.016218466152037894, 0.08440227207860776, 0.028839366776602607, 0.01779836369678378, 0.014633160683193376, 0.045029636405940564, 0.03794003450976951, 0.05225363912593041, 0.08238528602357421, 0.021380674060700194, 0.08935487203832183, 0.018744850497958914, 0.012710703886114061, 0.021561403559254746, 0.04775826320318239, 0.03974212173904691, 0.02116752415895462, 0.012998600357345172, 0.05770542033548866, 0.0682236970003162, 0.05127419757523707, 0.021070939788062657, 0.05539310869893857, 0.19685651175677776, 0.05635224848187395, 0.12580265876437935, 0.08426589332520962, 0.08496591076254845, 0.20506488558437141, 0.186344267268266, 0.40598560497164726, 0.32647894269653727, 0.06477001482354743, 0.9145593536751611, 0.4362086946410792, 0.5078415551355907, 1.5561048771653856, 2.600257796900613, 3.2178156418459753, 1.9447291323116846, 2.0164393186569214, 1.1429328535284315, 0.9997444855315345, 1.1266349852085114, 1.2220096502985274, 1.090285484279905, 0.0063677771915016425, 0.2018417221094881, 0.009466081741265953, 0.038832209671714475, 0.136065148083227, 0.29667201212474276, 0.3105250102068697, 0.04608902295253106, 0.11582043154963426, 0.28165263948696, 0.15160731838217803, 0.046896398200520446, 0.029537884651550224, 0.053324696474841664, 0.10567093188209192, 0.09921376194272723, 0.16075912729970046, 0.038241293880024126, 0.013150223248106028, 0.057324042942907126, 0.021119366832343594, 0.05219577026686498, 0.030888963224632398, 0.03693399438634515, 0.05278736459357398, 0.028670720290392637, 0.02740459599798279, 0.07817207210298095, 0.049377095087298324, 0.03334406577050686, 0.07221948794488396, 0.0031606542844591396, 0.05749079292373998, 0.038732234322066815, 0.013196311891078949, 0.06366905104368925, 0.011484181441898857, 0.021170518194724406, 0.018899447916607772, 0.04061023604923061, 0.01000267401936331, 0.015421279107353516, 0.0243656225502491, 0.019778074430567876, 0.028339294949546456, 0.0129278876785455, 0.01214285658872021, 0.04112851466717465, 0.05305976926216057, 0.060551345481404235, 0.06859066909445183, 0.0428796201678259, 0.04142810823395848, 0.0322184915255223, 0.040508801849292855, 0.03274231716724379, 0.03083048029137509, 0.02464861236512661, 0.046975305037839074, 0.01587788907012769, 0.00827876165775316, 0.06215612151260887, 0.023883007732885222, 0.023381356615573168, 0.05063437297940254, 0.02178991210114743, 0.07125520147383213, 0.050951605063996146, 0.035943065237786086, 0.028897859887885194, 0.048795963770576885, 0.05549705008577023, 0.032945545190679174, 0.02147107188855963, 0.06530950444617442, 0.006653033313341439, 0.05179324633042727, 0.031421589465545754, 0.06522579358092376, 0.0035359573043284138, 0.047571815350758176, 0.05869091102587325, 0.03666939965582319, 0.027522834117657373, 0.04144152287127716, 0.2001338087554489, 0.16062120827180998, 0.13845992886594363, 0.11503497298274722, 0.15475399738975934, 0.1070771346400891, 0.12773439367966993, 0.13114357074456556, 0.21008820246372903, 0.131078675655382, 0.08986696920224599, 0.1291268425328391, 0.09423632760133062, 0.25102245594773975, 0.1208195790116276, 0.1698918151003974, 0.1318921170064381, 0.1446950142937047, 0.14445289942835057, 0.10242658454392638, 0.07646445051899978, 0.08067670091986656, 0.08149168254541499, 0.13830548072499887, 0.2775570292557989, 0.10511321680886404, 0.12386673050267355, 0.16554387126650127, 0.0747029600398881, 0.09113362444830791, 0.10045114518808466, 0.126536399392145, 0.18120450020900794, 0.0920897074309843, 0.16170926631561347, 0.12122193670698575, 0.08989763898508889, 0.07534490166498081, 0.08133456776184694, 0.23788425379565784, 0.18064139756773198, 0.13479167356022767, 0.11060935045991625, 0.14899191872349807, 0.17392654716968536, 0.1159134858420917, 0.22406333684921265, 0.13951730355620384, 0.09375344815530948, 0.1313372789216893, 0.21386663828577313, 0.20679927537483828, 0.18833943163709982, 0.16578853742352553, 0.08527377567120961, 0.24504697801811354, 0.13974603771099023, 0.24716989696025848, 0.1931555646338633, 0.18657055869698524, 0.2186275656734194, 0.11922633807574, 0.182370481214353, 0.2587265154080731, 0.13708308631820337, 0.14333590865135193, 0.21797694558543818, 0.17969218135944434, 0.21225244418850966, 0.22680370908762726, 0.16804732621780463, 0.19015137798019818, 0.5607679922665868, 0.3200608699449471, 0.18366174692554132, 0.4002123033361775, 0.29494006506034304, 0.18054864183068275, 2.474891232592719, 2.029354282787868, 1.6301333733967371, 3.9297000595501492, 4.865449573312487, 6.359755652291434, 4.147806618894849, 4.871260872909001, 2.694107983793531, 2.4338482235159193, 2.9143178931304385, 2.9777762251240865, 2.189822712114879, 0.15208382638437407, 0.25745673211557524, 0.11307519421513591, 0.1383074349058526, 0.41125513506787165, 0.4452911029968943, 0.5641252206904548, 0.256728609757764, 0.3621581324509212, 0.3770633754985673, 0.2793452133025442, 0.21445267541067942, 0.2220696381160191, 0.1656322300966297, 0.15389060229063034, 0.1817047026540552, 0.3810633665749005, 0.13673654491347925, 0.19461776688694954, 0.13409924214439733, 0.15737444534897804, 0.25938407012394493, 0.1649603582918644, 0.12799884591783794, 0.1435485343847956, 0.0658245939495308, 0.1264048178813287, 0.17280616371759347, 0.08266712911427021, 0.16015960089862347, 0.10211251103984458, 0.06214640489114182, 0.22728484469865048, 0.11299136799893209, 0.11199861698384796, 0.18436327071062156, 0.1800092879150595, 0.13339075659002575, 0.06362136360257864, 0.15635562501847744, 0.08456609757351023, 0.08895901470844235, 0.0751110649268542, 0.1094348741961377, 0.12606778953756603, 0.13861079434198992, 0.22930474845426424, 0.12478002506707396, 0.1493716404906341, 0.15415964142552444, 0.13207487362836087, 0.14233132398554257, 0.08507264432098184, 0.09135553932615689, 0.13095240028841154, 0.08449025092912571, 0.15347687234835966, 0.09137703531554767, 0.06876021463956151, 0.1068605598328369, 0.12734464316495828, 0.2477460274738925, 0.09129214379936457, 0.13865655474364758, 0.1302952662642513, 0.10526608396321535, 0.1290824663426195, 0.10140797455928155, 0.13699825587017195, 0.10972815060189792, 0.10280798229255847, 0.15222447312303952, 0.09157762383776051, 0.09399939674351897, 0.13399339068148816, 0.2057939986033099, 0.12073286223624434, 0.11280383449047804, 0.14225694297679833, 0.10782978603882448, 0.16910844642136777, 0.16185538204652922, 0.18593601988894598, 0.11815512127109937, 0.0677487767700638], [0.04087896305801613, 0.07758581106151853, 0.12452047185174056, 0.04173735396138259, 0.05047529722963061, 0.02737008231425924, 0.03675216735739793, 0.03851149330980011, 0.07338913982467991, 0.006709760537237993, 0.023792173946276307, 0.02988874153899295, 0.036668188470814905, 0.036219710750239234, 0.027761792098837237, 0.11964078726513044, 0.03642247058451176, 0.03585422464779445, 0.030311037985874072, 0.04873654106631875, 0.01131153414358518, 0.04693137328805668, 0.016590023446562033, 0.033035060923014364, 0.037564862319933515, 0.010813106915780475, 0.015341693735016244, 0.0034500318704106447, 0.010080235661007464, 0.002593445446109399, 0.02619657974823245, 0.03996530208470566, 0.011979897074135286, 0.03081843290211899, 0.05405791463064296, 0.020323116165984954, 0.04247823277754443, 0.03586970542424491, 0.038583716577185054, 0.04600862333817141, 0.019242308268855726, 0.015157227204846484, 0.03189173620194197, 0.030651805057589496, 0.023364661261439323, 0.03179192030802369, 0.009598373169345515, 0.06366946495005063, 0.019638209703511426, 0.027667397699717964, 0.042022209747561386, 0.04042851080053619, 0.09755732904055289, 0.06358907212104116, 0.024812802572601607, 0.09162479559225695, 0.0366325009215091, 0.02998665753485901, 0.07470946719071694, 0.025328082065763216, 0.10401120129972696, 0.059311892704239914, 0.18797279202512332, 0.12014430096106869, 0.07328679638781718, 0.07405250280031137, 0.0640622213748949, 0.2706500313111714, 0.39709614483373507, 0.1442110152649028, 0.0812159123431359, 0.32720038826976505, 3.3035531554903304, 14.915525947298322, 26.95898621422904, 39.430429458618164, 52.04731934411185, 54.9258051599775, 84.66445990971157, 76.71862506866455, 85.62142835344586, 95.30775914873395, 99.30446720123291, 93.56931291307721, 105.7830023084368, 96.99706077575684, 85.4879048211234, 94.61016001020158, 93.11717973436627, 90.54740238189697, 95.84548023768834, 68.15781211853027, 46.30359097889492, 52.96576697485787, 41.83851875577654, 31.159835815429688, 22.37008319582258, 6.012249316487994, 0.28421372920274734, 0.0555846727054034, 0.05147105076217225, 0.6660557282822472, 0.11770774956260409, 0.058788117952644825, 0.0389327041006514, 0.13037415274551936, 0.21958282084337302, 0.1582249075706516, 0.12810465666864598, 0.06382916495203972, 0.04561741058049457, 0.012962140126286872, 0.10623582585581712, 0.029346232435532978, 0.011467137490399182, 0.006996069660609854, 0.04313538037240505, 0.0035598813888749904, 0.05359726399183273, 0.03876436634787491, 0.025051619757765105, 0.022091731262792434, 0.05336538821991001, 0.05060464296756046, 0.018426454725808332, 0.045926144013979604, 0.034088961513979096, 0.01007068358428244, 0.07572753434734684, 0.0438494943747563, 0.02944517641195229, 0.014493988061855947, 0.037599898475621424, 0.04230748622545174, 0.08232837050620999, 0.02991178798090134, 0.044608194913182936, 0.010410622843275113, 0.050146672542073896, 0.06933736974107367, 0.04604644827278597, 0.027161398869273917, 0.06219542904623917, 0.05860018410852977, 0.01717885274307004, 0.06427525422934975, 0.04101112471627338, 0.03125343491722431, 0.029402849397489002, 0.032692848571709225, 0.027431920603183762, 0.039883426656680446, 0.04547113539384944, 0.09130965678819589, 0.04008614917152694, 0.018974960382495607, 0.05713289284280368, 0.045978079084306955, 0.05828591382929257, 0.020507777774972574, 0.031033338513225317, 0.03885251483214753, 0.029074051683502536, 0.04046765209308692, 0.047455846930720975, 0.037377023470721076, 0.02587542573123106, 0.02510415024257132, 0.03654388085539852, 0.04482739904363241, 0.04879144812002778, 0.03344965260475874, 0.013168322321559702, 0.020682247787980095, 0.07023054574217115, 0.0687186543696693, 0.09848364469196115, 0.01826339597547693, 0.06411937437951565, 0.01648155114214335, 0.048544200137257576, 0.07147421222180128, 0.03842528882835593, 0.05111361887039883, 0.008754760758685214, 0.008386185625568032, 0.003993404197639653, 0.04567857711975064, 0.033294410577842166, 0.021990590529250245, 0.022937447132010545, 0.084908805255379, 0.04043063800781965, 0.0231391348809536, 0.049708589977983914, 0.02944693381765059, 0.015267573962254184, 0.09720824991485902, 0.04891275321798665, 0.013191406931062894, 0.02446519417156066, 0.0734612884532128, 0.016244666085445454, 0.015286835875096065, 0.01678446613784347, 0.06972967154745545, 0.035872592590749264, 0.008424335408822765, 0.03269848719771419, 0.05327454934428845, 0.0355995670626206, 0.024078905881781663, 0.06748359171407563, 0.022467517526820302, 0.027726616843470504, 0.03410312253981829, 0.023743938588138138, 0.013990607528415109, 0.01795836564685617, 0.014150484797677823, 0.01609068613366357, 0.015342131390103271, 0.03824919542031629, 0.06112442258745432, 0.006405404502792018, 0.03376412644450154, 0.009170338860712945, 0.012425033857912889, 0.06463044017021145, 0.041654959454068115, 0.06241378840059042, 0.10473121516406536, 0.00948649801180831, 0.04975978205246585, 0.08319842203387193, 0.025887591864115427, 0.05506450097475733, 0.11004297049450022, 0.021992213924282362, 0.1640283361609493, 0.13087529156889233, 0.06062560435384512, 0.03437674178608826, 0.31425518861838747, 0.3876142422003405, 0.11444305974457945, 0.08542163523712329, 0.338145700948579, 3.4258590383189063, 15.941608122416906, 32.46608672823225, 43.28691591535296, 58.52448913029262, 64.68838201250348, 97.32126372201103, 90.06776128496442, 102.4129592350551, 113.5270962033953, 119.4985795702253, 113.60859162466866, 126.43500791277204, 119.38922882080078, 106.86695602961949, 114.70492703574044, 110.47785145895821, 108.53516292572021, 111.3123995917184, 84.20519093104771, 60.36384405408587, 66.53012711661202, 52.14663342067173, 41.11005571910313, 29.56136451448713, 8.669639110565186, 1.1739314815827777, 0.07113691924938134, 0.0472375520371965, 0.5028756016067096, 0.12938532366284303, 0.04597257955798081, 0.03009003573762519, 0.23809913226536342, 0.23805217764207295, 0.26608311065605705, 0.08997501233326537, 0.08363386509673935, 0.008078548026138117, 0.017837455795545663, 0.05070119171536394, 0.018905797308044772, 0.021149129074599062, 0.04530680439035807, 0.03737574103953583, 0.009392889865141894, 0.05696698424539395, 0.05037120317241975, 0.03817218169569969, 0.04518987923594458, 0.06446960022939102, 0.07369064007486616, 0.02222360284732921, 0.014700327168351837, 0.05063880720574941, 0.04335627066237586, 0.04606254312342831, 0.021609033324888775, 0.017129731896732534, 0.01655859370449824, 0.029559621520872627, 0.005315563608227032, 0.09807312422032867, 0.009253902144597044, 0.04500005567180259, 0.03906241624749132, 0.030095433483698537, 0.02124713497635509, 0.1042766102722713, 0.014984509508524622, 0.023562289674633315, 0.002149731677491218, 0.0469682618443455, 0.03606697251754148, 0.09720819563205753, 0.049689753845866234, 0.0262479872575828, 0.02636919736063906, 0.04167790411572371, 0.006799057866114059, 0.07165637173290763, 0.04576979936765773, 0.05180599939610277, 0.04372370755299926, 0.018587362520130615, 0.03029413567855954, 0.051138175052723715, 0.02799163735471666, 0.034241333337766786, 0.06161753434155669, 0.05118826111512525, 0.014527260026495372, 0.02701878946806703, 0.03880578073273812, 0.01711545721627772, 0.04826965808336224, 0.03962112198184643, 0.06425951900226728, 0.007704309670121542, 0.05424458979229842, 0.023713619947167378, 0.017456251429393888, 0.05809059752417462, 0.05034900489928467, 0.10998950872038092, 0.2321459102843489, 0.15579284807401045, 0.08245480193623475, 0.12602873306189263, 0.13067947993321077, 0.11351769404219729, 0.13230807254356997, 0.08629055361130408, 0.05989312580121415, 0.15164075658789702, 0.1165011650217431, 0.13643807092947619, 0.1039727758616209, 0.10085933828460318, 0.17849908609475407, 0.23557791326727184, 0.12860886247030326, 0.11658431270292827, 0.14558606648019382, 0.11982218681701592, 0.20547077166182653, 0.16235699584441526, 0.061724125407636166, 0.08444675683443036, 0.15244541769581182, 0.12485308971788202, 0.10142342480165617, 0.03938226069190672, 0.10445997079036065, 0.12960972876421042, 0.10018859963331904, 0.07807633759719984, 0.1957125695688384, 0.13723430463245936, 0.1695973173316036, 0.11019150181008236, 0.1034394676930138, 0.15536835656634398, 0.1762699628514903, 0.1493673250079155, 0.08360464737883636, 0.07507158097411905, 0.15762311486261232, 0.11441006937197276, 0.12339905702642032, 0.1147573571652174, 0.16117512354893343, 0.056309975750212155, 0.10334156187517302, 0.13387947822255747, 0.14773060354803288, 0.13501388020813465, 0.1270892968667405, 0.12429974441017423, 0.3254140769796712, 0.16526895601834568, 0.10221997741609812, 0.2578883075288364, 0.14298009845827306, 0.27939094656280106, 0.22391172498464584, 0.2322549915739468, 0.21778407879173756, 0.26743749369468006, 0.10687046644410916, 0.21936988298382076, 0.5061689934560231, 0.4484148068087441, 0.21172796376049519, 0.25174859698329655, 1.1436590488467897, 6.133831066744668, 23.520050014768326, 44.036171436309814, 58.87664467947823, 74.66901765550885, 83.91985620771135, 120.98550796508789, 112.99947779519218, 124.62565531049455, 135.10041209629603, 144.6076739174979, 134.95199857439314, 149.16180120195662, 138.02133750915527, 126.56168746948242, 133.86460549490792, 133.79606846400668, 128.55932235717773, 129.63172122410364, 101.05453082493374, 74.55433068956647, 80.63729790278843, 64.89207540239606, 50.07233558382307, 36.78589991160801, 11.056803907666888, 1.8468826455729348, 0.26030093378254343, 0.12834993350718701, 0.8185184757624353, 0.2709442712366581, 0.1316794641315937, 0.16143511102667876, 0.28333521634340286, 0.3037337160536221, 0.4611903727054596, 0.2566158915204661, 0.2443776982171195, 0.16987314181668417, 0.08416401807750974, 0.2343768791428634, 0.1546065110181059, 0.1503194724874837, 0.14307087287306786, 0.15591347802962574, 0.04990767554513045, 0.11753515739526067, 0.1861202014344079, 0.11091498977371625, 0.11681349469082696, 0.11063812713005713, 0.15971054642328195, 0.14610116955425057, 0.144005880558065, 0.12420534661837987, 0.10205887284662042, 0.2030911629221269, 0.0988318824342319, 0.07239672807710511, 0.14350531170410769, 0.17593939416110516, 0.13912467605301312, 0.23114697102989468, 0.08560044278523751, 0.19582199012594564, 0.11443095467984676, 0.18251176577593597, 0.11515135530914579, 0.23359705241663115, 0.1478168453489031, 0.12531829332666738, 0.14945172119353498, 0.1386272827429431, 0.1738593450614384, 0.1854139007627964, 0.1346435086535556, 0.17966646488223756, 0.09965483006089926, 0.13157425049160207, 0.1726751657468932, 0.1304720789194107, 0.1908723350082125, 0.10484613185482365, 0.12240555962281567, 0.10154717601835728, 0.1300883266542639, 0.10575805577848639, 0.06766728471432414, 0.14474975849900926, 0.18572247134787695, 0.12631341921431677, 0.1298130178557975, 0.13400245590933732, 0.07668482512235641, 0.22212525084614754, 0.18949268332549504, 0.17130805339132035, 0.10940351909292595, 0.17292097184274877, 0.15838544895606382, 0.08907007732029472, 0.10428951600832598, 0.2110483566565173, 0.15093535158251012], [0.028739072515496185, 0.03643230255693197, 0.01580576249398291, 0.02768926179435636, 0.04399701467316065, 0.052838241149272235, 0.043067625258117914, 0.05247806119067328, 0.046197907466973574, 0.03419274005240627, 0.044999444990285804, 0.05371000597785626, 0.055516944732517004, 0.024570477361391698, 0.010306999519733446, 0.018595165672845075, 0.027864444269133464, 0.021870114940351675, 0.005649257800541818, 0.05483592288302524, 0.02410395909100771, 0.0526983950819288, 0.0690518014931253, 0.08492508331047637, 0.03291483469573515, 0.009341159203488911, 0.03698394474174295, 0.0688671992559518, 0.011718922327937824, 0.031931637453713586, 0.018545132196907486, 0.041661846584507396, 0.06780329027346202, 0.06563704008502619, 0.032355362216808965, 0.04264443993036236, 0.030642770363816192, 0.05835007610065596, 0.03253304000411715, 0.07569355331361294, 0.02269098624986197, 0.01257410884967872, 0.006316222948953509, 0.010583816362278802, 0.024426622848425592, 0.027903814567252994, 0.010509523563086987, 0.0703971396599497, 0.01375578691451145, 0.016657425722639476, 0.044875337542699914, 0.020714607123019438, 0.0034188209558903638, 0.03599307666133557, 0.07831684433455978, 0.018997748981096914, 0.040889107156544924, 0.03335564497060009, 0.04170485891933952, 0.028907681682280133, 0.04656149706404124, 0.01843117393686303, 0.2843708779130663, 0.5205723920038768, 0.40364037081599236, 0.08097782119044236, 1.3286307347672326, 7.850054791995457, 12.308491485459463, 27.92615113939558, 55.87697533198765, 72.75141211918422, 78.65731838771275, 109.10593659537179, 114.87468542371477, 102.34178188868931, 98.58166694641113, 102.51167229243687, 98.22034672328404, 92.07696492331368, 96.10641288757324, 92.95925412859235, 92.55730084010533, 98.11833327157157, 90.29821218763078, 91.04802703857422, 95.73384353092739, 97.21915299551827, 96.82359899793352, 95.18712452479771, 104.96216991969517, 108.44928319113595, 115.53947516850063, 107.10637010846818, 123.7787949698312, 124.53271620614188, 113.73588262285504, 105.13560390472412, 84.03587027958461, 76.12661075592041, 46.106689453125, 14.6672876562391, 2.5985231356961385, 0.2418877189712865, 0.3027683235704899, 0.1841647449348654, 0.25274305790662766, 0.716222590633801, 0.06429276721818106, 0.1736002125378166, 0.044028563158852715, 0.0441280228218862, 0.10648189658032996, 0.05138831359467336, 0.028857195284217596, 0.020661048657659973, 0.1089454943846379, 0.06069119154874768, 0.013594236208258994, 0.010412593987504286, 0.05001014790364674, 0.03639457600989512, 0.023299080851886953, 0.03460297893200602, 0.03700261124010597, 0.033736279367336204, 0.05107962087328945, 0.03960791090503335, 0.029714856762439013, 0.013448455504008701, 0.026674239563622644, 0.03499898214691451, 0.03826988395303488, 0.05147076577746442, 0.018338665865095596, 0.04056868935003877, 0.033845235127955675, 0.060179793275892735, 0.03454290822680507, 0.008349829719268849, 0.038162102057997666, 0.025471733018223728, 0.06458168064377137, 0.04267038371680038, 0.029059531034103463, 0.07838510495743581, 0.0630358625203371, 0.04009097355550953, 0.05839581614626305, 0.034485575410404375, 0.00475025360771854, 0.015275458539170879, 0.029453624172934463, 0.04808029253035784, 0.03172467409500054, 0.01807355205528438, 0.12588786919202122, 0.055144235624798706, 0.021947640958907347, 0.05479196059916701, 0.0737406209643398, 0.010503960424102843, 0.021409264133710946, 0.048944861495069096, 0.050420776940882206, 0.04001323379842298, 0.030910432072622434, 0.06726810934820346, 0.01079160244470196, 0.012163153267465532, 0.03733121217893703, 0.09635318722575903, 0.0621603216443743, 0.04455558130783694, 0.05819008432860885, 0.026446893012949398, 0.039666214026510715, 0.058231882085757594, 0.03315713615821941, 0.06671457405069045, 0.05130532876189266, 0.053588080020355325, 0.020847063944009796, 0.033974166959524155, 0.028892228047230413, 0.0486564400073673, 0.06078919914684125, 0.0413682071625122, 0.03797904009531651, 0.02975335344672203, 0.014112885475956967, 0.008783174412591117, 0.04184481355228594, 0.016250811916376864, 0.013927341771445103, 0.012332697964406438, 0.02709947745980961, 0.037517344512577565, 0.05401573350120868, 0.023099873148437058, 0.07220426840441567, 0.024987586408055255, 0.0422508285513946, 0.04445829295686313, 0.01839034478845341, 0.011414626513474753, 0.02941432681732944, 0.036121407989412546, 0.0483493995187538, 0.02688654638560755, 0.025356965605169535, 0.062264341062733104, 0.032233609285737784, 0.09654724824109248, 0.04165089163663132, 0.03357747503157173, 0.027836074720003774, 0.020522937943626727, 0.018118832393416336, 0.029465210158377886, 0.041804657849882326, 0.007655426311040563, 0.014377010320978505, 0.0689800667709538, 0.06168385435427938, 0.035281395207026174, 0.031557744302387745, 0.02493076249291854, 0.03682655515149236, 0.031870420024331124, 0.026454816605629664, 0.10813482145645789, 0.05330356689436095, 0.05533322459086776, 0.07030104553060872, 0.038607621365892034, 0.17083622728075298, 0.04562565478097115, 0.19401965183871134, 0.3334018183606011, 0.22056728016052926, 0.20221689769199916, 1.7395515420607157, 9.06708128111703, 15.15053313119071, 33.18918922969273, 66.25923769814628, 83.8486580167498, 94.21139594486782, 129.9964599609375, 130.8675695146833, 120.14106559753418, 117.08066204616001, 125.11100087847028, 115.64557416098458, 115.83118833814348, 121.34641129629952, 108.44290474482945, 110.63084384373256, 112.10272938864571, 109.50545801435197, 105.70891366686139, 117.17008536202567, 111.14642102377755, 113.24727140154157, 112.160614831107, 127.31173161097935, 129.93680272783553, 133.29011453901018, 131.13165664672852, 153.67147391183036, 148.3537951878139, 136.0339859553746, 130.31970405578613, 105.25541864122663, 95.29325131007603, 64.1246885572161, 21.000405652182444, 4.317561967032296, 0.7817216845495361, 0.7035777920058796, 0.05875961269651141, 0.3087955872927393, 0.5507806081857, 0.06734265999070235, 0.0733029048091599, 0.19401571633560316, 0.03325077738346798, 0.07128692298595395, 0.054026515422655005, 0.011264314043468662, 0.062252819538116455, 0.073746741350208, 0.03400631255603262, 0.05020236669640456, 0.03957086628569024, 0.0301620215177536, 0.040903400496712754, 0.03316913265734911, 0.049565181601792574, 0.04052544292062521, 0.04090831648292286, 0.035849770065397024, 0.05888178971196924, 0.043462861728455336, 0.018947223567270806, 0.024070922917287265, 0.02893201055537377, 0.04349317867308855, 0.09004067416701998, 0.028221384223018373, 0.017502047454140017, 0.023543994674193006, 0.012700164540936905, 0.03151853854901024, 0.040908194346619506, 0.04364475661090442, 0.04146583817367043, 0.05674592432166849, 0.02890774275043181, 0.012418887178812708, 0.015898977938507284, 0.025503683535914336, 0.03527191607281566, 0.021433494619226882, 0.046616176808519025, 0.02485459524073771, 0.0325858775260193, 0.02635551809466311, 0.028838338796049356, 0.030683740308242183, 0.06149826145597866, 0.031050057616084814, 0.07178409237946783, 0.06339224268283163, 0.03569349666525211, 0.04158326205132263, 0.01941563664669437, 0.02764622401446104, 0.03952675133145281, 0.04192859905638865, 0.08909324250583138, 0.022060781584254334, 0.02544479857065848, 0.02139752038887569, 0.04286570341459342, 0.04679404119295733, 0.06892681534269027, 0.06451623594122273, 0.07990986813924142, 0.03202245258060949, 0.02772211645995932, 0.09995125486914601, 0.14159007876047067, 0.07952985460204737, 0.1318323923540967, 0.17253151988344534, 0.2052794247865677, 0.1199600515621049, 0.22507047280669212, 0.1135072988857116, 0.14136556509350026, 0.15586572273501328, 0.11654863533164773, 0.1416664682328701, 0.16789704428187438, 0.17093282352600778, 0.12104779747979981, 0.13650606013834476, 0.08687454156045403, 0.09778772560613495, 0.12204128131270409, 0.09363007013286863, 0.15066486038267612, 0.1471447292715311, 0.16666105203330517, 0.2355034915464265, 0.075277339933174, 0.11300467407064778, 0.11629228480160236, 0.11582622623869351, 0.14015512647373335, 0.16271334886550903, 0.11004001208181892, 0.0993993276996272, 0.16987615451216698, 0.14826359280518123, 0.16130754644317286, 0.07060908007302455, 0.2625754103064537, 0.13825619194124425, 0.1724253562944276, 0.06264895506735359, 0.07328534432287727, 0.07943010316895587, 0.1314573117664882, 0.11494411714375019, 0.06719602178782225, 0.21278446992593153, 0.1817161834665707, 0.19502791416432175, 0.14421729849917547, 0.09379095757114035, 0.13957221060991287, 0.1306500993669033, 0.1610954771084445, 0.11559475080243178, 0.1266031265258789, 0.14125963220638887, 0.17307216301560402, 0.13106305577925273, 0.10297534974025828, 0.37005212743367466, 0.13150604415152753, 0.46109906903335024, 0.7091302169220788, 0.40024422162345474, 0.5234974750450679, 3.9347049338476996, 13.522134201867239, 20.757758923939296, 42.35577392578125, 80.99945885794503, 101.60264641898019, 109.12448133741105, 145.98401478358676, 146.99670083182198, 133.82655715942383, 127.58052962166923, 131.34381294250488, 124.20125934055874, 118.31781659807477, 122.17503956386021, 119.44607898167202, 118.38123975481305, 125.63800784519741, 113.51504802703857, 114.93885203770229, 124.91510336739677, 125.02551024300712, 121.27231570652553, 123.91970443725586, 136.53475652422225, 139.3814195905413, 150.23471423557825, 143.6878158024379, 165.69813864571708, 162.63701248168945, 153.1220381600516, 147.49253817967005, 121.85175377982003, 110.43923337118966, 73.40093667166573, 25.79071089199611, 4.813941274370466, 1.351947695016861, 0.8983920354928289, 0.17184720374643803, 0.3779897657888276, 1.1953291105372565, 0.41549076778548105, 0.3384714791817324, 0.3210775325340884, 0.12449122699243681, 0.44982852094939774, 0.22792048273341997, 0.09858987613448075, 0.16755393626434462, 0.17491374776831695, 0.12913659986640724, 0.11898412821548325, 0.11591968765216214, 0.09856350147830588, 0.1611957238720996, 0.09784994048199483, 0.16238691923873766, 0.15975370125046798, 0.1591737437993288, 0.14481598351682934, 0.13347284575658186, 0.12365734816661902, 0.09075779747217894, 0.08703029248863459, 0.08994419327271835, 0.2232117754008089, 0.1751057053250926, 0.07914506417832204, 0.08460564259439707, 0.09682584793439933, 0.07027277097638164, 0.09380854519882373, 0.09048748269144978, 0.11075485550931521, 0.1082879328834159, 0.14517047735197203, 0.17206628913325922, 0.10545212469462838, 0.14909433679921286, 0.23018114428435052, 0.1695146853370326, 0.21515537984669209, 0.0734050175441163, 0.13288505801132747, 0.1209224449204547, 0.08085938290293727, 0.1204661572618144, 0.1153886118637664, 0.19168524710195406, 0.14061463038836206, 0.14669061292495045, 0.17598417747233594, 0.13415494986942836, 0.10880534976188626, 0.172757607751659, 0.10464210994541645, 0.1005967180909855, 0.19038886523672513, 0.1327957763735737, 0.11401586766753878, 0.1298037762088435, 0.11901540867984295, 0.12875219620764256, 0.14387968661529676, 0.23714009087000573, 0.12606044778866426, 0.18831473296242102, 0.15089216961392335, 0.07169903801488024], [0.06551291567406484, 0.11373166327497788, 0.021564005741051266, 0.04222747337605272, 0.006960516121970224, 0.07497252164674656, 0.010818876159776534, 0.012894925295508333, 0.04186597366684249, 0.08718702729259219, 0.09066920115479402, 0.04475479918931212, 0.025982325530744026, 0.02617235265539161, 0.0022567606106999195, 0.06491956394165754, 0.047454143807824166, 0.03181783356038587, 0.0036499480068284485, 0.02705471111195428, 0.05982628331652709, 0.027431501607809747, 0.019636096066928337, 0.02616920425290508, 0.03338523927543845, 0.05437436639996512, 0.07507502114666359, 0.007470199821649918, 0.07098269502499274, 0.024702204757237008, 0.03804595382618053, 0.03647041926160455, 0.0331394671063338, 0.06433352003140108, 0.01611202266732497, 0.039095796777733734, 0.05381464286308203, 0.030434979192380394, 0.08012539121721472, 0.01655880405035402, 0.03110485610419086, 0.018857999604993632, 0.07729807828686067, 0.06119387064661298, 0.045751360178525956, 0.09744891950062343, 0.04480900056660175, 0.09918187079685074, 0.010071775177493691, 0.028596033940890005, 0.06484852811055523, 0.02914629191426294, 0.05431921507364937, 0.09837905530418668, 0.048027997836470604, 0.1345713125275714, 0.05940267390438488, 0.06651809745069061, 0.08066066035202571, 0.23649116711957113, 0.3063067751271384, 0.2477104722389153, 4.635179323809488, 15.229541097368513, 26.063743829727173, 57.26191111973354, 75.87569046020508, 87.02683353424072, 92.01196452549526, 107.70508248465401, 94.7566419328962, 90.17026111057827, 92.64566802978516, 52.53665665217808, 53.12956728254046, 72.30345480782645, 74.8565286908831, 62.9502067565918, 84.63504123687744, 51.038447856903076, 67.5157082421439, 78.54124873025077, 61.783986364092144, 81.15700926099504, 75.7051191329956, 84.97092410496303, 71.63164043426514, 102.17462907518659, 78.59518759591239, 77.89548315320695, 80.77438586098808, 68.49395206996373, 85.27854170118059, 86.60236808231899, 60.25969750540597, 79.21848964691162, 81.66942501068115, 95.43113136291504, 104.09222071511405, 94.59590230669293, 109.34128597804478, 97.82049179077148, 88.27076952798026, 79.68270574297223, 65.74883692605155, 45.969584124428884, 31.244777543204172, 12.632974965231758, 1.457101623926844, 0.4659258414592062, 0.41653964721730774, 0.018322671098368506, 0.1683340479752847, 0.11047856283507176, 0.02889555286882179, 0.02132238111724811, 0.04515504324808717, 0.024693253184003488, 0.0362589877497937, 0.030782395907278572, 0.011768926966137119, 0.03467218950390816, 0.005009433628791677, 0.073978481415127, 0.05995804803179843, 0.03669036638789943, 0.01906113263352641, 0.061049376614391804, 0.03807697305455804, 0.005639720566770328, 0.021185710593791943, 0.014226158415632588, 0.06504089278834206, 0.015197181043082049, 0.05544708276699696, 0.05753122004015105, 0.021284769921164428, 0.007080349223023015, 0.03888931857155902, 0.036097048582243066, 0.055907825008034706, 0.0511140327767602, 0.030786640143820217, 0.07443594972469977, 0.01358675875235349, 0.04236711588289056, 0.06797767377325467, 0.060478755805109224, 0.055129324817763906, 0.058028172302458964, 0.034235715067812374, 0.047326854031000815, 0.03397451640505876, 0.055148313620260785, 0.03719897588182773, 0.008639751617530627, 0.030807722226849625, 0.04419841065204569, 0.0541869652058397, 0.024103865792442645, 0.04720677029607551, 0.06665332269455705, 0.07605911405490977, 0.04721805772611073, 0.021666842812140073, 0.06476341946316616, 0.01621257816441357, 0.04463208613118955, 0.021029683162591288, 0.005368627591191658, 0.07517862665866103, 0.020694235805422068, 0.027218697758923684, 0.013175117001602692, 0.08707468224955456, 0.04470880808574813, 0.06623374378042561, 0.09120383246668748, 0.049720830749720335, 0.09215935905064855, 0.03855960483529738, 0.06758768577128649, 0.023834556939878633, 0.05588941296030368, 0.039785547980240414, 0.01692498056218028, 0.03381428714575512, 0.03662680122735245, 0.030123317880289893, 0.03433483546333654, 0.05432681805853333, 0.06274038766111646, 0.04019992592345391, 0.039092356605189185, 0.016433249626840864, 0.05641596970547523, 0.04600625525095633, 0.0746754047327808, 0.03785571635567716, 0.010825146671517618, 0.03699358333168285, 0.06523808185011148, 0.010519049346580036, 0.04472376639023423, 0.024710737335096513, 0.05815927205341203, 0.027956190685342466, 0.08239547083420412, 0.015339644559259926, 0.033563853441072364, 0.013852003180155796, 0.07346546822892767, 0.03445475634985736, 0.025517283074025596, 0.01546019478701055, 0.034379856261823855, 0.03276777919381857, 0.04320176484595452, 0.02505515662154981, 0.07090357105646815, 0.01982048456557095, 0.11666189639696053, 0.03813706750848463, 0.041662386019847224, 0.040368324744382074, 0.0012625611353931682, 0.025187138468027115, 0.06042021180370024, 0.03492313889520509, 0.027093391000692333, 0.059663387414600165, 0.21795411966741085, 0.01699306137327637, 0.0371903042042894, 0.05791348631360701, 0.26407120004296303, 0.251837105091129, 0.13110635988414288, 5.384183841092246, 19.047352143696376, 30.653089795793804, 65.41323198590959, 93.00222873687744, 101.33853844233921, 108.7059635434832, 128.00767707824707, 112.60392379760742, 116.18124553135463, 111.36602578844342, 73.86010837554932, 91.77739334106445, 102.13279397147042, 118.77138110569545, 93.58996295928955, 122.49412863595145, 84.55030795506069, 92.76979064941406, 125.42540686471122, 102.46248599461147, 123.2001211983817, 116.38031836918422, 134.84570503234863, 97.53401061466762, 143.96516009739466, 117.66610336303711, 109.73255293709892, 122.84377588544572, 105.9657677241734, 116.54645674569267, 110.7114429473877, 88.91053186144147, 103.37272085462297, 108.57987458365304, 120.98443794250488, 125.33426039559501, 107.25581891196114, 126.06500244140625, 118.42581939697266, 109.86602088383266, 103.18433434622628, 86.28436987740653, 59.629746028355186, 42.99091918127877, 18.241791895457677, 2.852180153131485, 0.2700259419424193, 0.45160557702183723, 0.04825995842527066, 0.14814189076423645, 0.04708941087925008, 0.019609675609639714, 0.05221210599743894, 0.0391435554650213, 0.00531241690207805, 0.020575884031131864, 0.021574714719983082, 0.01973042430888329, 0.03547183284536004, 0.05862097442150116, 0.06232108694634267, 0.053046961913683584, 0.036929946924958906, 0.006957570007736129, 0.02963723914165582, 0.02124579656603081, 0.011027937888034751, 0.039600474161228964, 0.006010333849449775, 0.04397677058087928, 0.036825561097690036, 0.05728436900036676, 0.03185037949255534, 0.052409990557602475, 0.022016310399132114, 0.010110885935968586, 0.015489580442330666, 0.0409680377425892, 0.03441946574353746, 0.054115071027938805, 0.07396998615669352, 0.00955990277829447, 0.019620513510225073, 0.008920212193126125, 0.011602196493186057, 0.0334524820957865, 0.06200490319835288, 0.030799834257257835, 0.034718988064144335, 0.07307666087789194, 0.05967724309968097, 0.03751148875536663, 0.03145465447700449, 0.07328993800495352, 0.01492607407271862, 0.05038090283051133, 0.03474150864141328, 0.11626869892435414, 0.04262525435271008, 0.05987167730927467, 0.028851166500576904, 0.05209541833028197, 0.08625494409352541, 0.0414175536217434, 0.023922888628606285, 0.01860150827893189, 0.07021091572408165, 0.01587971772200295, 0.04060388156878097, 0.02797283684568746, 0.04870146759120481, 0.15961547009646893, 0.04511795452396784, 0.1080498213746718, 0.14756795870406286, 0.0734400028096778, 0.15195430762001447, 0.1412518969071763, 0.16525898155357155, 0.08269849778818232, 0.07770853769034147, 0.12088911528033869, 0.24315961929304258, 0.1327975812767233, 0.1295077856630087, 0.15109266314123357, 0.06243154566202845, 0.1576235626957246, 0.11717045839343752, 0.08737401797303132, 0.13060792163014412, 0.11479451374283858, 0.1731894002961261, 0.2214732872588294, 0.2101572501872267, 0.09956166041748864, 0.10338012302028281, 0.14129977433809213, 0.11719588988593646, 0.165322017456804, 0.1682479011693171, 0.1524943129292556, 0.1309136152267456, 0.12545622592525824, 0.22346391901373863, 0.14643936497824533, 0.14438619943601744, 0.08141388172017676, 0.16703480269227708, 0.09451090358197689, 0.14918802891458782, 0.12651099504104682, 0.14380369069320814, 0.1432389867092882, 0.13395176934344427, 0.12719843243913992, 0.1300537892218147, 0.08791183161416224, 0.2474012774016176, 0.11791768829737391, 0.350432993045875, 0.13589868987245218, 0.07380836590060166, 0.1313354197357382, 0.15272297923054012, 0.2464894349021571, 0.12580898271075316, 0.14844310602971486, 0.42518749460577965, 0.19251905807426997, 0.19680993711309774, 0.17887396312185697, 0.3949930119727339, 0.30819663086107796, 0.46571891541991917, 8.556840317589895, 25.728618315288, 40.00274215425764, 79.63092081887382, 109.67748846326555, 119.48179272242955, 126.94151769365583, 141.3048199244908, 123.91856493268693, 119.79630987984794, 120.1192204611642, 71.63475322723389, 76.25309576307023, 98.6251140322004, 101.78860105787004, 86.54604598454067, 111.72942352294922, 74.85604926518032, 93.37770244053432, 103.85320963178361, 85.20369570595878, 107.37135355813163, 101.893477167402, 111.31473418644497, 95.00777067456926, 132.3128226143973, 107.47510405949184, 104.19481781550816, 103.93628229413713, 94.55743707929338, 112.32752445765904, 111.91790035792759, 79.6293157849993, 102.67300251552037, 109.63575063432965, 123.60589599609375, 128.64682797023227, 120.15599032810756, 143.45306396484375, 136.87061854771204, 126.30106054033551, 114.7764448438372, 97.54566969190324, 69.5550114767892, 51.2607033593314, 25.08322446686881, 3.6552961553846086, 0.5912627130746841, 0.6618654217038835, 0.11859726825995104, 0.34903933640037266, 0.18888759293726512, 0.17587999520557268, 0.14508325846067496, 0.13659642743212835, 0.10558222021375384, 0.21826129247035297, 0.11855617617922169, 0.0900673202372023, 0.20081877628607409, 0.1830407923885754, 0.1688652051878827, 0.1566407047212124, 0.10015234550727264, 0.07381450664252043, 0.10973966534116439, 0.11202151075537715, 0.1468678598425218, 0.17120654455253057, 0.09127269020037991, 0.1093338131904602, 0.1317260523459741, 0.14753992163709231, 0.10573260392993689, 0.10396994637059313, 0.13294908457568713, 0.1525411589869431, 0.10757166453238044, 0.12866440734692983, 0.10274747732494559, 0.13095413733805927, 0.12448345098112311, 0.06000890423144613, 0.26187288228954586, 0.15437837397413595, 0.1520415400820119, 0.10748932430786745, 0.17733672846640858, 0.14694095163473062, 0.11820544142808233, 0.11940799547093255, 0.17723010347357818, 0.14001286482172354, 0.129584025857704, 0.11212978458830289, 0.12847292476466723, 0.10571142006665468, 0.07032634810145412, 0.2334664479962417, 0.13689026023660386, 0.12480183318257332, 0.13325532100030354, 0.06465665876333203, 0.22649260078157696, 0.1106066159637911, 0.11211658708219017, 0.1744254468274968, 0.12479829122977597, 0.10632702774767365, 0.08941537022058453, 0.18306056489901884, 0.11434174089559487, 0.23321273018206867, 0.17563409411481448], [0.06440087820270232, 0.056328425117369206, 0.03638091370729463, 0.09165099382932697, 0.021383094734379222, 0.04073555807449988, 0.02482762517008398, 0.044481339398771524, 0.03156819713435002, 0.11725306324660778, 0.02620879846758076, 0.018859063208635365, 0.03945909799741847, 0.03135406505316496, 0.034037246967532804, 0.009736079306873893, 0.035690097204808674, 0.01483993065942611, 0.06254961754062346, 0.04635830296735678, 0.03886024334600993, 0.016960015021530644, 0.003959306964783796, 0.0658219340922577, 0.06025211832353047, 0.02461235993541777, 0.018694437042410885, 0.01684211108035275, 0.010749761430945779, 0.043830712525440116, 0.013685969053767622, 0.022919510058792572, 0.027940068693299378, 0.04675370228609868, 0.036004581222576756, 0.04131612620715584, 0.04929059883579612, 0.024658508798373596, 0.02859766921028495, 0.053412882278540304, 0.14380637769188198, 0.035775443339454274, 0.05259292699130518, 0.042811291691448004, 0.04656335964266743, 0.084445725461202, 0.06237364626888718, 0.016852755598457794, 0.017053495094712292, 0.036383312328585556, 0.02841186596612845, 0.048003692712102614, 0.03196771176798003, 0.007631567323447338, 0.08536056708544493, 0.06688715943268367, 0.04516081418842077, 0.24011280706950597, 0.09704365767538548, 5.683343742574964, 31.597839832305908, 53.84066677093506, 74.69348226274762, 89.39273684365409, 89.91928522927421, 87.51725128718785, 83.12029920305524, 72.75452491215297, 71.2710428237915, 53.71646772112165, 70.25126266479492, 42.51738902500698, 54.72546427590506, 57.43680075236729, 40.78209727151053, 40.958254950387136, 26.362660544259207, 48.22964205060686, 31.784572669437953, 50.28145204271589, 53.86482218333653, 24.813521453312465, 20.880927903311594, 27.05253676005772, 23.269270420074463, 26.97563409805298, 35.57904992784773, 11.87483182975224, 24.01375773974827, 39.6815755707877, 38.248863969530376, 32.39976269858224, 38.98067256382534, 61.236489159720286, 56.799713475363596, 55.59568098613194, 43.5195346559797, 51.461787700653076, 62.89129992893764, 73.84227929796491, 74.98138087136405, 90.66301345825195, 95.98886326381138, 99.29574721200126, 93.47390719822475, 106.73519733973912, 95.31121935163225, 102.55843366895402, 76.19537707737514, 41.341666970934185, 6.9304550630705695, 0.06191406093005623, 0.5493997622813497, 0.3538158972348486, 0.11185177522046225, 0.06871447459395442, 0.03128110557528479, 0.01030587824061513, 0.10415965119110686, 0.019926581997424364, 0.07008912547358445, 0.07863298058509827, 0.03994161781987973, 0.07131274124341351, 0.04120065651035734, 0.012185136105732193, 0.03299952604408775, 0.06868432728307587, 0.04199076643479722, 0.011772487578647477, 0.011495743678616626, 0.05104807238759739, 0.02796408374394689, 0.0387883695241596, 0.045873435413731, 0.06289820133575372, 0.03783025772177747, 0.030951232383293763, 0.011757444457284041, 0.06403208763471671, 0.028626167681068182, 0.05347179947420955, 0.042262129552130184, 0.04322464165410825, 0.01848464928168271, 0.031629356888255904, 0.053343705633389096, 0.01628335445587124, 0.0654306500884039, 0.033910635725728104, 0.0782491604664496, 0.01593733043409884, 0.044414201751351357, 0.013918838879492666, 0.016554380002032434, 0.01031439724777426, 0.030397720834506408, 0.01619971653313509, 0.041338860522955656, 0.02575474658182689, 0.0280951597461743, 0.033374287720237455, 0.018826534239841358, 0.0589436585349696, 0.05293046084365674, 0.035551475893173895, 0.055920001318944354, 0.07116805043603693, 0.030238146361495768, 0.05109081670109715, 0.053385181086403985, 0.04023748962208629, 0.06471938932580606, 0.07296576111444406, 0.07665906114769833, 0.04752047399857214, 0.01703939344068723, 0.06869979109615088, 0.010339478446569825, 0.076423270228718, 0.04909025797886508, 0.02921919371666653, 0.0191205027513206, 0.07628940205488886, 0.01362379319367132, 0.07493578576083694, 0.05421521940401622, 0.03879504970141819, 0.04671842185780406, 0.01990856689267925, 0.05928322459970202, 0.08139917786632266, 0.039569848483162265, 0.007998793868214955, 0.022677564827193106, 0.06805091484316758, 0.0631968110267605, 0.03803770962570395, 0.03408965701237321, 0.004305048546354685, 0.03308335904564176, 0.05333326976480229, 0.02840255985834769, 0.027036309242248535, 0.05089664372748562, 0.11644993562783514, 0.04067388941933002, 0.03223515295290521, 0.036287289445421526, 0.016026031924411654, 0.023918919198747193, 0.029848755470343998, 0.07478061837277242, 0.0357126279601029, 0.014331541689378875, 0.024153548126508082, 0.070328817968922, 0.024231250564168607, 0.028746773887957846, 0.03841404889577201, 0.004822358979643988, 0.054180101824126074, 0.05555872552629028, 0.061402051975684505, 0.03176192906019943, 0.017168594989925623, 0.055027459748089314, 0.04126059490122965, 0.021605311560311487, 0.0601008389411228, 0.07978399989328214, 0.025515349249222448, 0.026836151589772532, 0.1704614588192531, 0.10354650659220559, 7.811871835163661, 37.879358768463135, 66.01422337123326, 92.17979826245988, 108.77680737631661, 105.18998745509556, 107.12514414106096, 95.80222075326103, 99.47089740208217, 95.83079869406563, 76.63613605499268, 100.14326068333217, 70.5310388292585, 92.4349639075143, 65.44053840637207, 49.23035287857056, 61.783096994672505, 41.565016814640586, 50.390333788735525, 49.05171469279698, 46.11895649773734, 59.59569985525948, 35.716645104544504, 30.712924207959855, 40.24896546772548, 35.745542662484304, 33.53104060036795, 47.94889661243984, 29.558998652866908, 44.74304641996111, 58.83396189553397, 56.57261160441807, 50.297325202396934, 56.42137711388724, 93.47510923658098, 73.99194349561418, 83.08151435852051, 79.15792219979423, 94.2754305430821, 95.16417462485177, 109.86073330470494, 111.28070885794503, 112.49667835235596, 126.54451152256557, 121.11363274710519, 120.48587690080915, 123.27749633789062, 111.37725407736642, 123.13129234313965, 95.15655245099748, 55.0833694594247, 11.00467678478786, 0.07675926041390214, 0.5321092243705476, 0.2199096983032567, 0.11745555166687284, 0.04086408278505717, 0.07902216791574444, 0.01827399978148086, 0.03602617220687015, 0.008901204730916237, 0.05640219544459667, 0.09119300304778985, 0.04368494624005897, 0.05623749463952013, 0.06593363452702761, 0.004478032143586981, 0.032195149920880795, 0.037547332367726734, 0.025592875267778124, 0.01934059745898204, 0.03125567747546094, 0.0942736402420061, 0.07564669368522507, 0.02768438821658492, 0.020209807603220855, 0.037479390656309466, 0.04700958801965628, 0.015838276195738996, 0.032303131983748505, 0.023441342503896782, 0.024128545807408433, 0.018374275382874266, 0.03809568705037236, 0.04862485080957413, 0.0760815396372761, 0.0035111167734222753, 0.04533222231215664, 0.06585147750696965, 0.04275470865624292, 0.04819052393681236, 0.1235758832522801, 0.04602642470438566, 0.035192313737102916, 0.046242229374391694, 0.062254183393503935, 0.04441537900960871, 0.01994247837657375, 0.012545409362896212, 0.01116017418514405, 0.022789090539195707, 0.025948012014850974, 0.036314373170690875, 0.008497448405250907, 0.021732044938419546, 0.0070738976272488275, 0.014998265109690172, 0.04378673327820642, 0.0638324897736311, 0.04698258571858917, 0.009649183567879456, 0.07306223522339549, 0.06389394469027009, 0.03778678398313267, 0.02084672128382538, 0.04505643853917718, 0.033945787232369184, 0.12567981678460324, 0.17808824671166285, 0.17179699215505803, 0.15624089831752436, 0.09980047081730195, 0.0638200386560389, 0.08235564761395965, 0.1105937170130866, 0.10933322286499397, 0.22696412833673613, 0.12815287336707115, 0.09545005711593799, 0.1520222018339804, 0.16897145020110266, 0.08465891437871115, 0.17652427777647972, 0.1485909316688776, 0.07932930000658546, 0.14705167497907365, 0.20694578465606484, 0.09107729247105972, 0.07469278201460838, 0.10413294405277286, 0.27074092786226955, 0.16781952844134398, 0.10004513018897601, 0.13738829136959144, 0.1198993091072355, 0.1408815796353987, 0.1839088693793331, 0.30740782033119884, 0.1636545176484755, 0.10059366468340158, 0.15731651202908584, 0.14701865746506623, 0.13248303958347865, 0.20275436528027058, 0.1500134260526725, 0.08105733192392758, 0.15972586774400302, 0.22219362003462656, 0.12846004617001328, 0.09962530021688767, 0.243226984249694, 0.13614152398492607, 0.12157153151929379, 0.1714513599872589, 0.1305630433240107, 0.15520241404218332, 0.14054510769035133, 0.07717514809753213, 0.1301274374127388, 0.1474208387413195, 0.14478943922689982, 0.19054914877883025, 0.28878146409988403, 0.13454569104526723, 0.3834879350449358, 0.141591218699302, 9.795583401407514, 50.054100036621094, 79.88242476327079, 107.31690052577427, 120.94209562029157, 119.67684255327497, 114.47371877942766, 106.53950827462333, 93.5599467413766, 89.05356747763497, 68.74068260192871, 90.41098839896065, 58.11912775039673, 72.92003100258964, 79.01373318263462, 55.56452873774937, 57.549757616860525, 34.397018909454346, 68.35184751238141, 47.16286080224173, 69.86685357775006, 73.68652153015137, 37.52103669302804, 28.82976610319955, 42.26395000730242, 33.56726155962263, 34.20930290222168, 55.85472025190081, 15.874031679970876, 33.434950487954275, 56.3711451121739, 51.73626238959176, 44.27939312798636, 53.48259483064924, 83.64603464944022, 78.3428568158831, 80.27657522474016, 64.46301719120571, 68.40260410308838, 90.31326198577881, 99.58034542628697, 99.5797895703997, 112.97016334533691, 120.34385572160993, 126.69783047267369, 122.4977694920131, 137.09876959664481, 126.17578451974052, 135.28462273733956, 108.22486332484654, 65.05785247257778, 13.636485917227608, 0.2668742282049996, 0.8696237249033791, 0.4740241840481758, 0.2601317342902933, 0.14923307006912573, 0.14443649245159967, 0.08990218516971384, 0.19529976243419306, 0.14038961460547789, 0.24108737334609032, 0.2037101768489395, 0.20610905598316873, 0.22084150330296584, 0.18778440356254578, 0.06298599698181663, 0.1882467166121517, 0.16325139999389648, 0.10682031592088086, 0.08376005903950759, 0.09199123164372784, 0.18356535424079212, 0.09412442360605512, 0.09940608590841293, 0.1313823607883283, 0.13319729268550873, 0.14750512636133603, 0.16522269350077423, 0.11388051350201879, 0.14746091301952088, 0.09856111982039042, 0.10763605750565018, 0.15935772178428514, 0.13402868807315826, 0.1449050615940775, 0.06319335728351559, 0.1823783250791686, 0.2279258295893669, 0.16240499541163445, 0.132851348391601, 0.27474716146077427, 0.16893996617623738, 0.1400979802544628, 0.07954890786537103, 0.08507180293755871, 0.08572034670838288, 0.10528622288256884, 0.08364048081317119, 0.12575183649148258, 0.10550102671342236, 0.10914998448320798, 0.10677499656698533, 0.0806119211816362, 0.10547636875084468, 0.0973115229446973, 0.14045630102711065, 0.2005358814660992, 0.14370535739830562, 0.18249626803611005, 0.22882184865219252, 0.15232655193124497, 0.12285055645874568, 0.17901348349239143, 0.10952163846897227, 0.15925617223339422, 0.14511044057352201], [0.1022272105993969, 0.07994733684297119, 0.06553194179598774, 0.03307131504906075, 0.034984078125229905, 0.0997027549892664, 0.05313904590106436, 0.06571505804147039, 0.06564936228096485, 0.044440929245735915, 0.012635571399836667, 0.026436789626521722, 0.028114421659016182, 0.044331094782267294, 0.05021673467542444, 0.07719265430101327, 0.04775532853922673, 0.018053660801212703, 0.06521258250411067, 0.021599279383995702, 0.034313244479043145, 0.01690507573740823, 0.048254533537796566, 0.02851281501352787, 0.062163748246218474, 0.027455550585208193, 0.01585018278897873, 0.038775304332375526, 0.04427926488486784, 0.019509710438017334, 0.015146604739129543, 0.06699400155672006, 0.028291291989652172, 0.0369738277846149, 0.04538079524146659, 0.0278775298169681, 0.03005959326401353, 0.06065286110554423, 0.005028334221736128, 0.019544330991006324, 0.04421796942395823, 0.02900653744914702, 0.0348599265728678, 0.051359930474843295, 0.02384602927070643, 0.04982686202440943, 0.030821727189634527, 0.10244003310799599, 0.0262091309497399, 0.062367851579827924, 0.017331819981336594, 0.07344619783439807, 0.026462266920134425, 0.06451361679605075, 0.08443061448633671, 0.29059032989399775, 0.6384794137307576, 8.868843964168004, 37.197149889809744, 72.12691497802734, 80.18091937473842, 78.50198446001325, 85.20145838601249, 68.09798812866211, 67.20625632149833, 61.32209096636091, 66.66801411764962, 34.219134603227886, 42.12563221795218, 45.200623512268066, 33.72609390531267, 52.05603238514492, 45.36406946182251, 48.067109789167134, 68.44981711251395, 63.302730560302734, 102.1835436139788, 84.20229353223527, 89.8013812473842, 96.48933506011963, 69.77749974387032, 115.95022487640381, 115.63415132250104, 101.05370398930141, 107.00383554186139, 130.7863311767578, 76.0122503553118, 105.82407311030796, 98.24665260314941, 72.74596473148891, 97.61738204956055, 92.58685152871269, 69.9942626953125, 50.52465983799526, 54.515666893550325, 46.994575432368684, 68.1172902243478, 50.67708247048514, 46.444153036390034, 26.07154839379447, 35.46631193161011, 48.905736514500205, 43.37943465369088, 52.9286253792899, 43.63037926810128, 74.5125789642334, 73.16535799843925, 91.21823705945695, 87.36383506229946, 105.56785133906773, 83.31799629756382, 49.99543292181832, 26.85092088154384, 9.578835214887347, 2.057099308286394, 0.14935049733945302, 0.2587432073695319, 0.13527774890618666, 0.0378136777185968, 0.1354062905801194, 0.07667588881616082, 0.1214364216263805, 0.008334182701738817, 0.01815666750605617, 0.0753087696752378, 0.01949437045758324, 0.015809960929410796, 0.0325186550617218, 0.03979568190074392, 0.0202778103827898, 0.03781288043994989, 0.035311084506767135, 0.04357466733615313, 0.030916586385241578, 0.03316763988030808, 0.04392083554661699, 0.06000635293977601, 0.0517074353992939, 0.06263194419443607, 0.03540560782753995, 0.07599776770387377, 0.07103920342134577, 0.037513982371560166, 0.02418340027465352, 0.07371839215712887, 0.020908118524987782, 0.021284552789958458, 0.023199721272768717, 0.04369924297290189, 0.04048749924238239, 0.05954518661435161, 0.03275458508038095, 0.03872616482632501, 0.04511355083169682, 0.035200822566236765, 0.026378296515239135, 0.07667568525565521, 0.0458439123550696, 0.05783263208078487, 0.02316776566606547, 0.06359722132661513, 0.04089510879878487, 0.0572223441143121, 0.021775355828659873, 0.03035298502072692, 0.0359346751522805, 0.01651736082775252, 0.06712031763579164, 0.014149409319673265, 0.03319545642339757, 0.02657446438180549, 0.041595323011279106, 0.15163626468607358, 0.044075344755713425, 0.03332870373768466, 0.04826111193480236, 0.093174644213702, 0.04886578502399581, 0.02523703793329852, 0.034861677193215916, 0.03779915028384753, 0.09079825172999076, 0.028929866384714842, 0.06191520765423775, 0.07428038200097424, 0.056058887259236405, 0.029895686344908814, 0.011909464291030807, 0.0339424149133265, 0.10303930845111609, 0.08928669283964805, 0.02064991389800395, 0.035502614586481025, 0.04329824913293123, 0.0029580994949875666, 0.06224399858287402, 0.048649281462920566, 0.022577991509543996, 0.0966011985604252, 0.04774993757850357, 0.029030974887843643, 0.016635286821318523, 0.020553407558639134, 0.029979139366852384, 0.04032842688528555, 0.05533662744398628, 0.08015403218035187, 0.016269105220479623, 0.005973000852723739, 0.05514450364613107, 0.02600664083313729, 0.04593954508059791, 0.052174291240849664, 0.008148632211876767, 0.040203756253634176, 0.045335679448076656, 0.0250494399640177, 0.05274827419114964, 0.012829439880858575, 0.0492698220935251, 0.022483461403420994, 0.06682206756834473, 0.0796039370553834, 0.04692224020670567, 0.04452823295391031, 0.04279976338148117, 0.011047105654142797, 0.025372261480827416, 0.045616365636565855, 0.037511040922254324, 0.03880844398268631, 0.25715985947421616, 0.9094982966780663, 10.565116371427264, 46.606000900268555, 89.36746624537876, 96.38541085379464, 90.73680332728794, 94.19462994166783, 83.02973638262067, 91.03463091169084, 90.8089325768607, 103.08372443062919, 58.41290800912039, 52.86323240825108, 47.44915437698364, 41.693037373679026, 38.267231532505576, 31.278222697121755, 40.13570983069283, 36.24387788772583, 30.86424902507237, 41.129628794533865, 58.80878857203892, 49.26355137143816, 67.58360603877476, 47.87803888320923, 53.140507221221924, 50.04244095938546, 55.34387479509626, 42.9683757509504, 53.856442655835835, 47.30864095687866, 26.61132093838283, 34.36206947054182, 41.38485697337559, 44.86609206880842, 39.56087841306414, 41.08065789086478, 35.824898038591655, 34.790078503744944, 39.04217801775251, 41.24550042833601, 33.78632436479841, 48.635677405766074, 36.97610337393624, 44.99217408043997, 74.38565622057233, 82.30622741154262, 91.32358564649309, 77.77687045506069, 105.62957913534981, 101.57212298257011, 105.71766144888741, 108.36272253308977, 116.86736624581474, 104.58170740944999, 67.07685307094029, 35.392674922943115, 13.52326762676239, 2.833156853914261, 0.11883790391896452, 0.28271253832748955, 0.0531670388632587, 0.06729941016861371, 0.13727351038583688, 0.043548486062458584, 0.09861644756581102, 0.04909478720011456, 0.028125188313424587, 0.06327157880046538, 0.04994441482371517, 0.041044925938227346, 0.05119775042736104, 0.02585067616642586, 0.06394091288426093, 0.035006167832762, 0.03480458864942193, 0.05798886476882866, 0.018494903642152036, 0.028607144951820374, 0.06859723731343235, 0.03833822260743805, 0.02561410832484918, 0.04016394999676517, 0.08943651337176561, 0.019491457846015692, 0.05256642680615187, 0.05762068488235984, 0.006914121290070138, 0.04113711849121111, 0.07592076076460735, 0.0621975732168981, 0.08046656540994133, 0.04196571831458381, 0.00725653677779649, 0.011544457403942943, 0.018368828443012068, 0.05959294869431427, 0.03648820027176823, 0.044398259571088214, 0.018799728713929653, 0.06979605941368, 0.020483720315886394, 0.023312763510537998, 0.038372373274926624, 0.03251197149178811, 0.13518773445061275, 0.030851966102740595, 0.03441435298217194, 0.04446299181186727, 0.027034697721579244, 0.061907180584967136, 0.029479398325617825, 0.06473840866237879, 0.037304494862577746, 0.007718800633613552, 0.06287823883550507, 0.07402158874486174, 0.0320064357614943, 0.054156027401664426, 0.03166864745851074, 0.2836148270538875, 0.1422007331358535, 0.16618298340056623, 0.18403164350560733, 0.09900138048189026, 0.1808306681258338, 0.13463323563337326, 0.09964601589100701, 0.1801663144890751, 0.1790622023067304, 0.11331504277352776, 0.06478323947106089, 0.14618397796792643, 0.19292019440659455, 0.17195571506662027, 0.13978740120572702, 0.09961091527449233, 0.12917573776628288, 0.1520359625241586, 0.1515615036977189, 0.21876449404018267, 0.06450721821082489, 0.21875225326844625, 0.1299539902912719, 0.16221792330699308, 0.13146020232566766, 0.10552169489009039, 0.10262217226305179, 0.11088980255382401, 0.11186118650117091, 0.13194901895310196, 0.18334109841712884, 0.06314245358641658, 0.1740344613790512, 0.1354417779615947, 0.14127579491053308, 0.11897560581564903, 0.15375665947794914, 0.10190296585538558, 0.12806486737515244, 0.08715973661414214, 0.15328088429357323, 0.07646965488259282, 0.13939556080315793, 0.11512285683836256, 0.11107121567640986, 0.1669087308858122, 0.2079121678003243, 0.1378577154661928, 0.18975032307207584, 0.09506336000881024, 0.2006811151014907, 0.12576254377407686, 0.16086681080715998, 0.1722066644579172, 0.43516209508691517, 1.5339442491531372, 16.378582068852015, 60.41796357291085, 103.6689920425415, 106.4031846182687, 100.0313252040318, 104.6520231791905, 86.64082636151994, 82.9158901487078, 78.7648834500994, 86.44996629442487, 48.95667723246983, 61.24544538770403, 64.20302254813058, 47.83633579526629, 73.00028964451381, 64.19861739022392, 71.63080665043422, 105.37822110312325, 88.32611887795585, 151.09694399152482, 118.38178171430314, 121.42903927394322, 128.8730752127511, 102.54890074048723, 165.54936381748743, 159.38078090122767, 145.21027728489466, 152.9853948865618, 172.78581537519182, 106.29269436427525, 141.62081010001046, 133.70485251290458, 101.44296291896275, 130.8694177355085, 128.808443069458, 94.80985818590436, 67.8387508392334, 76.70693819863456, 62.8442884172712, 89.3602887562343, 66.2370034626552, 62.4784449168614, 35.15781886237008, 49.81564480917794, 68.99275629861015, 62.01497227805001, 74.80097089494977, 62.06009387969971, 97.35073103223527, 94.36247062683105, 115.13646575382778, 111.45831176212856, 128.72292464120048, 115.6558644430978, 80.22045462472099, 42.93760912758963, 17.54986596107483, 3.964329881327493, 0.18883033815239156, 0.44188664853572845, 0.24003656687481062, 0.15401244003857884, 0.16165615059435368, 0.1681095478790147, 0.21497121187193052, 0.1375193843351943, 0.11629658671362059, 0.16731068146015915, 0.18361796784613812, 0.11534833402505942, 0.08890629932284355, 0.1587440547134195, 0.09702711499163083, 0.13090719628546918, 0.130839003516095, 0.19278876217348234, 0.1259555055626801, 0.11233311439199106, 0.16139229546700204, 0.14645174145698547, 0.17955070680805615, 0.09239662239061934, 0.18533502785222872, 0.24550246500543185, 0.13328561080353601, 0.12918611935206822, 0.09303262004894869, 0.17214018159679004, 0.0886470243068678, 0.11971785527254854, 0.15380551399929182, 0.18796821869909763, 0.15753901723240102, 0.16181309574416705, 0.18471984086292131, 0.12484874709376267, 0.242589215614966, 0.3105093224772385, 0.10991659334727696, 0.16383031250110694, 0.12864266708493233, 0.1326060036995581, 0.07628835032560996, 0.21897479918386253, 0.17675104417971202, 0.11261494391198669, 0.12296991076852594, 0.13471402201269353, 0.0749639178227101, 0.1626569354640586, 0.13611242840332644, 0.10526077781936952, 0.15760457728590282, 0.15033638158014842, 0.2567205216203417, 0.17639384977519512, 0.06588640170437948, 0.12460942779268537, 0.14294125911380562], [0.07402101199009589, 0.010977531217836907, 0.04186904403780188, 0.1014607645837324, 0.03900609105559332, 0.031349115140203915, 0.039465388017041345, 0.025456131801807454, 0.029057519177773168, 0.06352151717458453, 0.025216461358858005, 0.03207096444176776, 0.08289004143859659, 0.027187403723863617, 0.005676422525929021, 0.011381153532836055, 0.025102126511878202, 0.02438172248990408, 0.04962094700230019, 0.026127642286675315, 0.06440760248473712, 0.07801704720727035, 0.13266781823975698, 0.038991858783577166, 0.07061001645135027, 0.056981633816446574, 0.02014725006717656, 0.017452714565609182, 0.072026682219335, 0.07080583487238203, 0.01649074868432113, 0.04827878437936306, 0.07482371213180677, 0.06167719792574644, 0.04542420791195972, 0.04299249786085316, 0.044937711874289174, 0.007375115013149167, 0.049372179101088216, 0.02584719019276755, 0.009070188788297986, 0.027418129378929734, 0.01570058786975486, 0.03276557734768305, 0.05210680754056998, 0.04032033535518816, 0.042369514504181485, 0.10970988443919591, 0.07270533937428679, 0.02495717616485698, 0.02660543780906924, 0.03306318959221244, 0.007294671294013304, 0.29052584192582537, 3.871692589351109, 25.887580939701625, 55.388450963156565, 74.1499524797712, 76.48953601292202, 69.91189874921525, 83.92868041992188, 69.86870874677385, 50.512100969042095, 64.55449022565568, 33.15961422239031, 35.33914252689907, 26.731368439538137, 58.09333951132638, 77.44476045880998, 53.26079443522862, 73.05805001940045, 75.59684535435268, 93.54078360966274, 55.067301750183105, 50.58629730769566, 64.39161055428642, 57.3776090485709, 45.54878384726388, 50.96442869731358, 32.766505990709575, 38.99770607267107, 35.41951234000069, 41.84979568208967, 35.172934668404714, 49.24395745141165, 43.301173618861604, 46.69545895712716, 78.25928388323102, 79.58092158181327, 70.49586704799107, 81.37052740369523, 77.37237412588937, 76.16584028516496, 108.31688526698521, 98.92729118892125, 115.51346806117466, 116.11821842193604, 145.87933322361536, 102.77952534811837, 87.75765201023647, 82.88255964006696, 51.963607447487966, 60.63900661468506, 42.09417077473232, 41.033354554857524, 29.91304063796997, 38.58657768794468, 51.19274302891323, 58.33832604544503, 70.70032473972866, 77.22974150521415, 94.30596787588937, 91.10896274021694, 83.06388677869523, 69.23659637996128, 37.400923183986116, 8.399820583207266, 0.6045025597725595, 0.06687771422522408, 0.28017164181385723, 0.06518635712563992, 0.08920653071254492, 0.032714846677013805, 0.16674764667238506, 0.019390746285872798, 0.07359055615961552, 0.038103778580469747, 0.04253588789807899, 0.024251908562811356, 0.07557058919753347, 0.024127460151378597, 0.013397978435802673, 0.055242317861744335, 0.05873042890535934, 0.04392859798723033, 0.0428020568298442, 0.0218339812542711, 0.024752747134438584, 0.03176344219329102, 0.017758861084335616, 0.040111997963062355, 0.05267178972384759, 0.013777634893943156, 0.029545450317008153, 0.018028378586417863, 0.06938502325543336, 0.04729547517906342, 0.030782762316188643, 0.023779980671991195, 0.04932828467073185, 0.014178384461307099, 0.05405275776450123, 0.08399742415973119, 0.06648187046604496, 0.04712680833680289, 0.04898988568623151, 0.018352835372622524, 0.030713310864354883, 0.049180611701948304, 0.02234997320920229, 0.04690491720767958, 0.0531271783235882, 0.02573011236797486, 0.05015369198684182, 0.056220687327108214, 0.06383368399526392, 0.07858027198484965, 0.020204721983256083, 0.07382042346788303, 0.10199203714728355, 0.047836206520774534, 0.02501228847540915, 0.05086598412266799, 0.019613645039498806, 0.043022445003901205, 0.06780523766896554, 0.05287338587056313, 0.025794941299994077, 0.011062035969059383, 0.014060324457074915, 0.044525752908417156, 0.058745580592325757, 0.019276623481086323, 0.027367534415264214, 0.0534016389532813, 0.01675489218905568, 0.024340431937681775, 0.044273609295487404, 0.027901972344677364, 0.07721723083938871, 0.04111458434324179, 0.019145220085712414, 0.07933388011796133, 0.04114404294107642, 0.024915570093851005, 0.0104472391373877, 0.05943324190697499, 0.050299173287515125, 0.04344350651704839, 0.02243938885762223, 0.04451866221747228, 0.05047789601875203, 0.03496133363140481, 0.05500425385045154, 0.07137377546834094, 0.08498463832906314, 0.08424407163900988, 0.050943693345678706, 0.032550556385623555, 0.06572676277054207, 0.05317929659837058, 0.07156816896583353, 0.04092542913609317, 0.01364140965909298, 0.044666677846440246, 0.037978768681309054, 0.0488036380016378, 0.019212357733132582, 0.023151972763506428, 0.011770514738080757, 0.04568454144256456, 0.005475240709659244, 0.03146969420569284, 0.05198217762101974, 0.06699386584971632, 0.021991345399458493, 0.03252766600676945, 0.02664450615910547, 0.06876576505601406, 0.3039441704750061, 4.113649274621691, 30.443549496786936, 66.88010787963867, 93.16923563820976, 93.19032342093331, 86.06416061946324, 102.15130397251674, 99.07175813402448, 88.02507427760533, 88.47140571049282, 61.11925915309361, 54.43460920878819, 33.012486117226736, 36.473620074135916, 57.05009181158883, 43.76004655020577, 44.970728465488975, 65.34914875030518, 76.97447858537946, 59.12355586460659, 60.18007809775216, 70.83781569344657, 67.34799262455532, 55.53092724936349, 55.385758536202566, 41.54797288349697, 44.76481860024588, 41.91237810679844, 44.02226461683001, 38.6075473512922, 49.72996309825352, 52.05214139393398, 47.30440255573818, 72.3906477519444, 72.43727016448975, 68.06284414018903, 74.42889486040387, 75.96038205283028, 77.17979090554374, 83.83328860146659, 78.33973707471574, 86.65465327671596, 95.32903453281948, 104.08291707720075, 76.20769623347691, 49.91598721912929, 48.724972179957796, 36.663208620888845, 30.714706420898438, 35.4072904586792, 37.48501375743321, 52.59972892488752, 65.14447566441127, 88.26393250056675, 96.58702673230852, 101.19837243216378, 94.99110889434814, 106.675797189985, 108.23800236838204, 103.22078459603446, 88.33233751569475, 51.69894361495972, 12.583961503846304, 1.1703018077782221, 0.05397966257961733, 0.31033067777752876, 0.0852513840155942, 0.1005753849499992, 0.05648910899513534, 0.1370701670114483, 0.016378868437771286, 0.05000719288364053, 0.031675225855516534, 0.004876553571583437, 0.02725707909225353, 0.03378049610182643, 0.011241532230217541, 0.016168291880083934, 0.010942880978940852, 0.06209258349346263, 0.014491177230541195, 0.04517618979194334, 0.01983282372488507, 0.020882537754784738, 0.014817968177210008, 0.02333348766634507, 0.005917066242545843, 0.044981596126620255, 0.03243236576340028, 0.043552567450595756, 0.017853319944281663, 0.02636722452007234, 0.06338486700717892, 0.019043231183396916, 0.03429458137335522, 0.034992251079529524, 0.018560601098995124, 0.0693682295137218, 0.044273551620010815, 0.07959036635501043, 0.03988674469292164, 0.03157645829820207, 0.022351532143407633, 0.025255258294886777, 0.01568306131022317, 0.0788312688735979, 0.04990750591137579, 0.0421849597644593, 0.07084586843848228, 0.06192050701273339, 0.04060831240245274, 0.0722357320732304, 0.023324391904420087, 0.06937309460980551, 0.037293434741773775, 0.02837126243061253, 0.04341088933870196, 0.08038533119750874, 0.02929454842316253, 0.012806914214576994, 0.020871755833338414, 0.09261409286409616, 0.10198034598891224, 0.10758215468376875, 0.16810322393264088, 0.2898833235459668, 0.19205046179039137, 0.1369062600923436, 0.13919665504779133, 0.09226748360587017, 0.15329760339643272, 0.2380981280335358, 0.10761103313416243, 0.1758108931992735, 0.10792238571281944, 0.1329406164586544, 0.1294802235705512, 0.13202015656445706, 0.10870189352759294, 0.14684226550161839, 0.17415757477283478, 0.06810343345361096, 0.18912016760025704, 0.19771734199353627, 0.14783327946705477, 0.11775254644453526, 0.18120209819504193, 0.12156237129654203, 0.14941841869481973, 0.1352102075304304, 0.2301190990422453, 0.184135730777468, 0.1414563666496958, 0.11196441881890808, 0.17031618447176047, 0.13746071819748196, 0.13926551278148377, 0.11851223425141402, 0.18381498727415288, 0.10724252755088465, 0.12882283170308384, 0.19582469069531985, 0.12459729558655194, 0.13624023725943907, 0.07932546628373009, 0.13479372273598397, 0.15380985662341118, 0.08974804236952748, 0.2074371525751693, 0.19469893324588025, 0.17601073533296585, 0.13399355352989265, 0.1141835879534483, 0.10948622572634902, 0.11064181836055857, 0.48277902283838814, 7.549404501914978, 41.79245219911848, 84.40516008649553, 106.2848151070731, 99.34163311549595, 89.69900648934501, 104.63889108385358, 90.33598259517125, 69.02173028673444, 81.9518484388079, 47.578967571258545, 50.68768194743565, 36.38243191582816, 79.45204639434814, 99.93022891453334, 75.28134850093296, 105.03265939440045, 112.59953253609794, 135.86025319780623, 82.18463393620083, 78.90726593562535, 96.64574595860073, 87.66889572143555, 66.53539385114397, 78.51326138632638, 50.35002728870937, 58.37467902047293, 54.008385862622944, 64.69264125823975, 54.579218591962544, 72.80719225747245, 66.24591105324882, 71.5016118458339, 117.7916990007673, 118.38403293064663, 102.448395047869, 122.83525739397321, 115.13663251059396, 110.78587205069405, 151.83185495649064, 143.0485954284668, 162.18332290649414, 159.54079791477747, 200.75350979396273, 137.43800844464982, 122.89737428937639, 116.34883608136857, 72.28929437909807, 80.71012197222028, 56.91500146048409, 54.76086187362671, 45.03287315368652, 49.210199628557476, 69.71126951490129, 79.22552817208427, 93.88647038596017, 99.09899507250104, 115.84096445356096, 117.13951328822544, 115.81532560076032, 101.2626919065203, 65.50649070739746, 16.377185480935232, 1.4273042742695128, 0.16506156857524598, 0.5264004107032503, 0.22629278578928538, 0.19234129547008447, 0.17908706382981368, 0.2274370672447341, 0.1618448511830398, 0.12954918986984662, 0.1378982647189072, 0.14850299353046076, 0.13141195848584175, 0.13706775142678193, 0.0990463469975761, 0.14932950346597604, 0.168244440640722, 0.12813466148717062, 0.10968416117663894, 0.10207097791135311, 0.10660866727786404, 0.06875809082495314, 0.06529566911714417, 0.14373510437352316, 0.1038794976526073, 0.1680707492466484, 0.09076802978026015, 0.18121638814253466, 0.19528250050331863, 0.11478106517876897, 0.10003533214330673, 0.12437066489032336, 0.10314069515360252, 0.11561560896890503, 0.07448830548673868, 0.14264294797820704, 0.14442773934985909, 0.15221943839320115, 0.11520619450935296, 0.10627379667546068, 0.08991378133318254, 0.08747730457356998, 0.10288460246686425, 0.15676351955958776, 0.0916713091677853, 0.15550358859556063, 0.14497147660170281, 0.12530290415244444, 0.1094568112332906, 0.13706140033900738, 0.12662193551659584, 0.11603308442447867, 0.1807685007474252, 0.14714418644351618, 0.13438874589545385, 0.1830163515572037, 0.06948951764830522, 0.1272828286247594, 0.1533688088612897, 0.22611293329724244], [0.038560218909489255, 0.017978884545820098, 0.015221818649609174, 0.04083470221874969, 0.04126055758180363, 0.04563455716041582, 0.04717432614415884, 0.09093617075788123, 0.033182479441165924, 0.00985020974517933, 0.0674699531602008, 0.06907308035131011, 0.06216547851051603, 0.05594292901722448, 0.046171030694884915, 0.04019453835540584, 0.016759267043588415, 0.03279462543183139, 0.016651666656668698, 0.02324430611250656, 0.04447193829608815, 0.03719757131433912, 0.035977059842220376, 0.029469311902565614, 0.05470319804070251, 0.06869208293833903, 0.0363117031353925, 0.02560583359029676, 0.09672859351017646, 0.004999962128100118, 0.05745324958115816, 0.010680003790184855, 0.04784491891041398, 0.02633501955174974, 0.06898112528558288, 0.08396601477371794, 0.024768063366147022, 0.09886382107755967, 0.05558395006560853, 0.03659413655155471, 0.03537791342075382, 0.022027628363243172, 0.061612533538469245, 0.03915635263547301, 0.013690771385362106, 0.03482344853026526, 0.06703877129725047, 0.10694382965032544, 0.045414939123604975, 0.00745309649833611, 0.08510656428656407, 0.42621428093739916, 3.969638305050986, 15.171942268099103, 50.635789326259065, 67.13379355839321, 74.0196042742048, 68.9590436390468, 65.68601826259068, 50.274201597486226, 53.03185476575579, 28.288659504481725, 23.395807538713726, 38.28686714172363, 51.114930152893066, 62.72698892865862, 80.29033265795026, 85.80956472669328, 71.83448614392961, 52.51133394241333, 36.85328701564244, 16.250043869018555, 6.920487003667014, 5.569127517087119, 2.712771496602467, 1.1061982704060418, 0.6791394576430321, 0.3909029928701264, 0.8134424367121288, 0.30248564588172094, 0.9720415834869657, 0.8967877072947366, 1.6094521688563483, 1.00356154356684, 1.6534297061817986, 1.0290514443601881, 0.785753105367933, 1.886379246200834, 1.8737817278930118, 0.5032050439289638, 0.6911767231566566, 0.6662391498684883, 0.9422522676842553, 1.163468363029616, 3.6975012506757463, 6.237934189183371, 5.871785836560385, 10.670587420463562, 24.108472108840942, 44.814460005079, 49.69394711085728, 85.61259719303676, 120.84885079520089, 111.30431883675712, 106.32575389317104, 70.91977664402553, 55.67382042748587, 37.17590924671718, 50.61445140838623, 36.88979285103934, 43.86779573985508, 52.890865394047324, 75.19339125497001, 77.50875336783272, 69.11168166569301, 86.24231243133545, 78.79860305786133, 53.76227024623326, 26.98278032030378, 11.537582772118704, 2.568168410233089, 0.4639099953430039, 0.15486759772258146, 0.022622042002954652, 0.07870757872504847, 0.026889469175200378, 0.01991227508655616, 0.06178978045604058, 0.0487969103269279, 0.019465821096673608, 0.040127091974552186, 0.04150732719738569, 0.04262737138196826, 0.05636985307293279, 0.01638139598071575, 0.040015310115580044, 0.040138596535793374, 0.056085920094379356, 0.022268650787217275, 0.0731356255710125, 0.025730566986437355, 0.04424194206616708, 0.013154923799447715, 0.035895907053990025, 0.046956892990108044, 0.015620866790413857, 0.0558913128583559, 0.03195361181029251, 0.01820618359904204, 0.04115340333165867, 0.0246546665938305, 0.014936238527297974, 0.07021087501198053, 0.025692463852465153, 0.006934766990265676, 0.03721954906359315, 0.020285725493782332, 0.019883260929158757, 0.013798368379606732, 0.04320668761751481, 0.05185000239206212, 0.05536128879923906, 0.021420213992574384, 0.03703767792986972, 0.028123753211860145, 0.02796479790205402, 0.03993037788729582, 0.04112583106117589, 0.01578642933496407, 0.06106317801667111, 0.0616994063769068, 0.04898132935964635, 0.020960798287498097, 0.017692941407273923, 0.028702238242008855, 0.017072775667267184, 0.011830283495198404, 0.03454103207747851, 0.04186206530513508, 0.021311147970014384, 0.032726239279976914, 0.03828212472477129, 0.038198586885950396, 0.04186992613332612, 0.038231024252516885, 0.014945047608177577, 0.029489878298980848, 0.008828113786876202, 0.007222720288804599, 0.02751045424624213, 0.07933317444154195, 0.05684010837493198, 0.01014348869544587, 0.047472179268619845, 0.022330419526302388, 0.03413445050162928, 0.04979932028800249, 0.05319635157606431, 0.011974832658389849, 0.034506155377519984, 0.026170276338234544, 0.03737457735197885, 0.052937673670904975, 0.046140706964901516, 0.025821443181484938, 0.030256833215909343, 0.05618926097771951, 0.03452391263895801, 0.013379477330350449, 0.023064758961222002, 0.06135106006903308, 0.07796039631856339, 0.03337908157014421, 0.0190033044865621, 0.05495501256414822, 0.02043618554515498, 0.05466985822256122, 0.027073705003463795, 0.06097824578838689, 0.037758444968078814, 0.0504538148109402, 0.02784456149674952, 0.04989497676225645, 0.019977166783064604, 0.050199856116835556, 0.07016782875039748, 0.024464513940204467, 0.48250722885131836, 4.484013012477329, 19.71069492612566, 68.9781025477818, 83.51887566702706, 87.63125732966832, 79.72451305389404, 85.27128778185163, 82.1785056250436, 85.27854170118059, 48.89557129996163, 26.93456503323146, 37.58983080727713, 28.823512724467687, 24.97511397089277, 40.45721687589373, 74.90426281520298, 83.74758257184709, 56.64035306658064, 43.480628217969624, 21.813233716147288, 11.082386306353978, 7.033180705138615, 3.2910374956471578, 0.8569235578179359, 0.3167112139718873, 0.38852923310228754, 0.6170107828719276, 0.4428151829966477, 0.5567684897354671, 1.2088407512222017, 1.648070256624903, 1.1843094847032, 1.5675702733652932, 1.319041677883693, 0.8539909294673375, 1.4590298576014382, 1.1348516643047333, 0.4623411680970873, 0.15622500702738762, 0.16247925428407534, 0.4615277403167316, 1.2670641584055764, 4.078152230807713, 7.48180547782353, 7.149567808423724, 12.301916752542768, 26.20972374507359, 47.19372122628348, 55.70529924120222, 72.87011514391217, 97.14297989436558, 80.05124514443534, 69.7536118371146, 35.56133549554007, 22.39273953437805, 28.86026348386492, 53.36847761699131, 60.346153940473286, 75.10271726335797, 90.84711292811802, 91.0325881413051, 92.38729231698173, 78.08862917763847, 103.65233026232038, 97.96639701298305, 71.35584558759416, 36.22471475601196, 20.219148465565272, 4.684234908648899, 0.35325553587504793, 0.2986655208681311, 0.12265162356197834, 0.05103256446974618, 0.03267998015508056, 0.017143250010641556, 0.07908578735909291, 0.019261232610525827, 0.028856109628187757, 0.04891476168164185, 0.066619809849986, 0.05483994659568582, 0.0664688493790371, 0.015456020100308316, 0.024858595204672644, 0.06543295710746731, 0.019869004908416952, 0.04346998973882624, 0.055622290686837265, 0.07045811960207564, 0.010249129812499242, 0.07949685065874032, 0.03976227083642568, 0.012040275664600943, 0.040184190696371455, 0.017514432414567897, 0.038233192171901464, 0.02652553013259811, 0.009619939556744481, 0.012372060629007007, 0.06357482288564954, 0.0815733103081584, 0.03446371301210352, 0.03367812891623803, 0.050518262067011425, 0.05050659805004086, 0.006028476603595274, 0.041186057829431126, 0.029628886375576258, 0.037548641940312724, 0.06510626285203866, 0.07015870923974685, 0.05500446419630732, 0.016029589144246917, 0.01750318400029625, 0.005645838832216603, 0.06944164021738938, 0.03310604925666537, 0.06594860300953899, 0.023263671501938785, 0.02908769023737737, 0.04552934691309929, 0.022718780740563358, 0.040929856577089856, 0.03084263624623418, 0.08796984635825668, 0.19399986575756753, 0.2036869302392006, 0.14515632311148302, 0.16013857988374575, 0.08147388457187585, 0.09713080871318068, 0.17291660207722867, 0.1288215967693499, 0.18111202945666655, 0.12999892288020679, 0.115981610757964, 0.12132245488464832, 0.12798199110797473, 0.19040998124650546, 0.15320205209510668, 0.09702754246869258, 0.18968731431024416, 0.106965535985572, 0.10460424769137587, 0.13036738096603326, 0.07909570754106555, 0.13255903550556727, 0.17682123184204102, 0.11597771596695695, 0.10189198715878384, 0.19196306647998945, 0.12790045834013394, 0.1535221306341035, 0.1399616218571152, 0.20420435390302114, 0.14076930923121317, 0.10363826488277741, 0.09545319873307433, 0.1182354733880077, 0.17762064108891146, 0.11779882253280707, 0.20745379025382654, 0.24853177102548735, 0.08567483736468212, 0.1253649086824485, 0.11586841754615307, 0.15642555483749934, 0.15400604823870317, 0.18792705876486643, 0.1642561610788107, 0.1918903953794922, 0.1349476823317153, 0.2070903397564377, 0.12939917934792383, 0.201185103771942, 0.8067072981170246, 7.0384292006492615, 31.428498336247035, 90.53658403669084, 95.72697176252092, 96.64616285051618, 86.74621663774762, 85.89750112806047, 68.46441527775356, 67.67751094273159, 37.9883690561567, 33.55897583280291, 50.910083362034385, 71.04588644845145, 88.07211358206612, 120.28401783534459, 120.64229474748883, 97.47437422616142, 80.6038840157645, 57.73218951906477, 26.19172269957406, 10.876813428742544, 9.188924023083278, 5.245068311691284, 1.6970977229731423, 0.8388270831533841, 0.8673951444881303, 0.9920312251363481, 0.8720262816974095, 1.0744353405066898, 1.1920173168182373, 2.130038240126201, 1.5287970453500748, 1.8524798538003648, 1.398171020405633, 1.0892686588423592, 2.0908649478639876, 2.1603085015501295, 0.9088936948350498, 0.8769012029681886, 0.9305013439485005, 1.6880163188491548, 2.395747559411185, 6.55710403408323, 11.86882163797106, 9.332244515419006, 17.28692180769784, 37.922173568180625, 69.07639176504952, 73.01690278734479, 123.85585049220494, 171.07628059387207, 156.27622849600655, 144.31181962149483, 98.26370348249162, 77.42396450042725, 51.2759998185294, 64.09899411882672, 46.377950600215364, 57.807768549237935, 74.76515293121338, 95.2400211606707, 97.63642011369977, 90.00730500902448, 111.71803542545864, 112.20206778390067, 82.13598264966691, 46.08549049922398, 26.149316106523784, 5.88130921125412, 0.5681314542889595, 0.3839966734605176, 0.16044757116053784, 0.23872666859201022, 0.10105341965598719, 0.14724131194608553, 0.19465807186705725, 0.12267796429140226, 0.08001495285757951, 0.21009717269667558, 0.22885352266686304, 0.18062178790569305, 0.14220887555607728, 0.15146906008677824, 0.14747736070837292, 0.1696357224136591, 0.17223105100648745, 0.10193890106997319, 0.13658713150237287, 0.1326223292521068, 0.12989552771406515, 0.12131963217897074, 0.12981383209781988, 0.13791123830846377, 0.11853202033255782, 0.18610760782446178, 0.13662508875131607, 0.09593001886137895, 0.14141481316515378, 0.08670351002365351, 0.2271655039595706, 0.18081219840262616, 0.07596939815474407, 0.1379002867532628, 0.1151615469051259, 0.08623969741165638, 0.11008468004209654, 0.10999577838395323, 0.1637946894126279, 0.16007751173206738, 0.1604898167507989, 0.0776729281725628, 0.0928946128115058, 0.15609966803874287, 0.0911677683304463, 0.14340091230613844, 0.1647802750979151, 0.06518280838749238, 0.14554069962884697, 0.08728297892957926, 0.1272569764405489, 0.12656618707946368, 0.22934524342417717, 0.10902402802769627, 0.148828798905015], [0.03256768939484443, 0.08424720647079603, 0.04281132561819894, 0.059373062636171064, 0.03157605117719088, 0.05426549884889807, 0.018102340599788085, 0.012267452581519527, 0.012865167294096733, 0.01746010550829981, 0.015949014807119966, 0.06185819035662072, 0.06700555022273745, 0.021067367301189473, 0.03859079369742956, 0.08589893033994095, 0.023668599148680056, 0.04272426278995616, 0.025221538497135043, 0.04050923950437989, 0.02852979874504464, 0.043175064492970705, 0.009601184000660266, 0.04292585215132151, 0.029476477232362543, 0.04320384794846177, 0.05895195023289748, 0.13009192288986274, 0.03679823309981397, 0.0659603416653616, 0.013353391051558512, 0.02722295217349061, 0.062391817436686585, 0.05013268793533955, 0.08736904431134462, 0.016364229044743946, 0.018716557284018824, 0.04904975283092686, 0.02451511229654508, 0.026878269954717586, 0.038679427334240506, 0.05507511326244899, 0.02418537650789533, 0.024187583443043486, 0.03622260470209377, 0.04298549198678561, 0.07739059653665338, 0.08647335773067814, 0.027455401307504092, 0.15470799271549496, 4.211991037641253, 30.78372982570103, 51.03055470330374, 56.46568577630179, 68.0604887008667, 68.90813418797084, 64.67833491734096, 73.64888313838414, 51.80446590696062, 23.549520799091884, 45.02450752258301, 60.16809940338135, 80.2849269594465, 65.67157990591866, 82.69654246738979, 78.06717314038957, 48.1124016216823, 20.817431790488108, 3.8533350144113814, 1.0751463366406304, 0.5091588901621955, 0.2955067775079182, 0.22062199722443307, 0.3740908221474716, 0.22139034313814981, 0.04775230227304356, 0.15735989755817822, 0.1318098921328783, 0.24592250532337598, 0.2401664656187807, 0.20891468971967697, 0.4067357932882649, 0.5142427459359169, 0.44356127296175274, 0.7902791510735239, 0.684673969234739, 0.4268508553504944, 0.8580179533788136, 0.6412977767842156, 0.3274882771074772, 0.027765831078535745, 0.18050598911941051, 0.07224831211247615, 0.016281585175810114, 0.15572131691234453, 0.3128608262964657, 0.2549052775970527, 0.16455327799277647, 0.6233881978052003, 0.973709368280002, 0.21284886289920124, 0.4858114229781287, 4.3686807325908115, 20.704441922051565, 50.780513354710166, 93.2196934563773, 99.58650153023856, 96.4685946873256, 75.5432538986206, 58.349179131644114, 31.634456838880265, 24.66252841268267, 52.622435637882774, 53.43988772800991, 53.80314302444458, 64.8411590031215, 69.89709213801792, 78.09481307438442, 86.20254789079938, 84.2860540662493, 68.42399065835136, 23.630458627428325, 1.0122159591742923, 0.5743931382894516, 0.05579622296084251, 0.004568719196998115, 0.03318888141906687, 0.04752806680543082, 0.09214836678334645, 0.043394726634557755, 0.025144616374745965, 0.03100675011851958, 0.042650821552212746, 0.09404137770512275, 0.0022146346122359057, 0.03997762767331941, 0.028419911695112075, 0.007486224274284073, 0.023695207899436355, 0.03329348098486662, 0.011115575774705835, 0.028313831226634126, 0.01990165770985186, 0.03393430302717856, 0.06914737993585211, 0.04598178727818387, 0.021542482610259737, 0.039173940263156376, 0.01918536052107811, 0.03899451864085027, 0.029384539130010774, 0.03546788377155151, 0.05286659034235137, 0.020810794550925493, 0.011286542002510811, 0.01377002936455288, 0.029395765491894314, 0.028310891473665833, 0.021073351980053952, 0.04283867057945047, 0.03841966716572642, 0.029001675745738403, 0.017621337303093502, 0.054206998952265294, 0.04494410706683993, 0.07049968665731804, 0.007677908720714706, 0.04163022685263838, 0.018678727260391628, 0.026765578858820454, 0.0028378702991176397, 0.013133231034901525, 0.031203016372663633, 0.06998232406164918, 0.05046719212883285, 0.06036802567541599, 0.025151444133371115, 0.06442908490342752, 0.06748338815357004, 0.048838280607014894, 0.020735293959400485, 0.049506668134459426, 0.07592631796641008, 0.029195146435605626, 0.03375507478735276, 0.02604846573168678, 0.036890513862350156, 0.023038793122395873, 0.03960159035133464, 0.02869990068886961, 0.022531269284497415, 0.11473739466496877, 0.024020407681486437, 0.02242919217262949, 0.0298070866348488, 0.03189316791083131, 0.037164764146187475, 0.0409364621154964, 0.04334263889385121, 0.018271485809236765, 0.00918093672953546, 0.03560857800766826, 0.027612605996962105, 0.05070803813370211, 0.007424681148092661, 0.07383727827774626, 0.025968388421460986, 0.06974181732428925, 0.06770164572766849, 0.00569704532556768, 0.009916880051605403, 0.042572620391313515, 0.05223518975877336, 0.014158451646965529, 0.03507254212828619, 0.06009038271648543, 0.07201479428580829, 0.06797106484217302, 0.05352405006332057, 0.029403941838869026, 0.05732845342052834, 0.06518925447016954, 0.10475826835525887, 0.13144812440233572, 0.06619957954223667, 0.04154908424243331, 6.105944037437439, 42.50885663713728, 72.51361697060722, 74.85614653996059, 80.84115804944719, 88.30849129813058, 97.70808383396694, 113.05186721256801, 83.66969326564244, 31.47936609813145, 36.06554889678955, 30.23763268334525, 46.93894815444946, 48.963319710322786, 68.15897941589355, 78.60645062582833, 56.03164223262242, 25.375943388257706, 3.453751278775079, 1.0557541315044676, 0.5876714714935848, 0.5916866617543357, 0.47218301998717443, 0.6152544085468564, 0.3005528524518013, 0.039480899327567646, 0.042192111523555856, 0.1444983341331993, 0.28086111481700626, 0.3704999605459826, 0.21746442094445229, 0.715504592018468, 0.48440989532641, 0.3017603190881865, 0.6116802117654255, 0.9010576467428888, 0.9493089233125959, 0.7970361656376294, 0.4078207165002823, 0.35257352675710407, 0.18939318295036042, 0.037808045877942016, 0.022191394486331513, 0.07868595381400414, 0.29181931966117447, 0.380580656762634, 0.13600935893399374, 0.33639839185135706, 0.9393776676484517, 1.2226949163845606, 0.3791163239095892, 0.4199571838336331, 5.362994875226702, 24.328217574528285, 55.8286714553833, 96.291061265128, 89.77715982709611, 64.93100615910122, 41.14055136271885, 30.70836271558489, 29.224693025861466, 32.024202142442974, 86.81061254228864, 88.334456716265, 86.50534343719482, 84.88642011369977, 81.84907763344901, 90.29288291931152, 101.6276946749006, 101.80212920052665, 85.4214175088065, 34.77460833958217, 2.4254582737173354, 0.6557284252984183, 0.025485173100605607, 0.04333508340641856, 0.06658337251948458, 0.0492282075408314, 0.05678942520171404, 0.010128229291045239, 0.05441280880144664, 0.06215240314070668, 0.04003379340948803, 0.05293345318308898, 0.003220799416469942, 0.021457996518750275, 0.053393951151520014, 0.014900193050769823, 0.04874919235174145, 0.026665932598656843, 0.04435862634064896, 0.057532292125480514, 0.021428420873624936, 0.02183871403602617, 0.06799484749457665, 0.01358115066042436, 0.01848212173873825, 0.09211768342980317, 0.03660150883453233, 0.020912795327603817, 0.03389322112447449, 0.038088504757199965, 0.013340123147437615, 0.021378322936860577, 0.020282792526164224, 0.02167668835526066, 0.049967267883143256, 0.03666622071926083, 0.06691755101616893, 0.040598093665071895, 0.06830656648214374, 0.04933615906962326, 0.042622723417090516, 0.03462411190516182, 0.050439552004848204, 0.06563705365572657, 0.04669779778591224, 0.07800267583557538, 0.04901245376095176, 0.02440014132298529, 0.032655033815119944, 0.030310966739697114, 0.09673637630684034, 0.02429341963891472, 0.06722390279173851, 0.030657172269587005, 0.0926110598125628, 0.12480236243988786, 0.15901734147753033, 0.09348373727074691, 0.18693300496254647, 0.13536958183561051, 0.10655121571783509, 0.11816481075116567, 0.09599987404154879, 0.1379156352153846, 0.1327925601175853, 0.2543052083679608, 0.08493239113262721, 0.0898836272369538, 0.08681048106934343, 0.15799143724143505, 0.0680028067103454, 0.10410555159407002, 0.12383319730205194, 0.11772167310118675, 0.1189612615853548, 0.1175094409180539, 0.09648546084229435, 0.13888558745384216, 0.10075329004653863, 0.07877298271549599, 0.08140641783497163, 0.1303990821221045, 0.15122391895524093, 0.20676222736282007, 0.08464316558092833, 0.20648001107786382, 0.1569555178284645, 0.11752141027578286, 0.15683426362063202, 0.15001767368188926, 0.09267748160553829, 0.12946092603462084, 0.1251521608127015, 0.09896753515516009, 0.18997732017721447, 0.20450318072523388, 0.24838129909975187, 0.1117770481588585, 0.13323216938546725, 0.1067502096827541, 0.16466138219194754, 0.16318649133401258, 0.11443767217653138, 0.2327032589486667, 10.144985726901464, 57.228188037872314, 92.23540469578334, 91.68165411267961, 89.25825445992606, 92.73047079358781, 90.71664660317558, 94.88498905726841, 66.14924771445138, 30.783205236707413, 61.46739169529506, 82.78888402666364, 113.41325691768101, 98.68677929469517, 125.28666523524693, 120.11196654183524, 69.74482931409563, 33.655128479003906, 6.524355871336801, 2.314067359481539, 0.8339622042008809, 0.8880549073219299, 0.3177001109080655, 0.899753882416657, 0.3638436948614461, 0.13952501171401568, 0.26366312908274786, 0.24831504694053105, 0.5499675603849548, 0.5764835689749036, 0.508557273873261, 1.1331349164247513, 0.9000070574028152, 0.6839052162000111, 1.1217243458543504, 1.1031480112246104, 1.092069000005722, 1.5095037434782301, 1.1657386869192123, 0.6930499683533395, 0.3480807292674269, 0.31223052154694286, 0.1415525014911379, 0.10270308077867542, 0.3126879355737141, 0.4947175479360989, 0.29474939672010286, 0.4815788300974028, 1.231450840830803, 1.6336557843855448, 0.4630552040679114, 1.0498877891472407, 6.251386770180293, 33.146291051592144, 76.47392341068813, 138.40592030116488, 146.12870407104492, 138.31325912475586, 110.05601937430245, 84.53120040893555, 44.36443560464041, 33.64955602373396, 71.18612888881138, 70.84449986049107, 75.83769771030971, 86.68911634172711, 86.26153809683663, 99.7549467086792, 115.38096591404506, 113.11813218252999, 98.13942800249372, 39.581729957035606, 2.694155535527638, 0.7682031499488013, 0.09777109471282788, 0.22774908478770936, 0.17501057471547807, 0.11077428196689912, 0.10916642538670983, 0.12954357159989222, 0.12924338770764215, 0.21226441354623862, 0.4309419058263302, 0.17742240029786313, 0.11816687349762235, 0.18056470953992435, 0.12112850243491785, 0.09299682054136481, 0.06233034894934722, 0.1123175352279629, 0.09636386736695256, 0.11631037454519953, 0.0540696397157652, 0.13031920497970922, 0.14680928869971208, 0.12579273858240672, 0.1172681131533214, 0.1967125130551202, 0.13184235324817045, 0.1144860110112599, 0.14489800482988358, 0.186756735135402, 0.1355376142476286, 0.10369144845753908, 0.07935687566974334, 0.06011687272361346, 0.11757778296513216, 0.08344310176159654, 0.14725528976746968, 0.12831212553594792, 0.11977425510329859, 0.100328282852258, 0.11035873355077845, 0.1568923190768276, 0.21721629425883293, 0.1319035706775529, 0.14451432041823864, 0.22708194915737423, 0.07679526348199163, 0.17132478606488022, 0.15665137129170553, 0.09428815410605498, 0.21279422725949967, 0.13614008549068654, 0.11487597865717751, 0.14490213032279695], [0.040490583184042146, 0.01863564028670745, 0.036520739418587515, 0.0696955548067178, 0.05690170578392489, 0.025887776764908006, 0.0505029611023409, 0.042745239700057676, 0.028760188525276523, 0.04760513481284891, 0.08264614202614341, 0.029879309902233735, 0.03658482026574867, 0.04605239223954933, 0.03495378153664725, 0.042861560958304575, 0.01294806391732501, 0.09242772643587419, 0.024841058467115675, 0.013286225414568824, 0.07844925365809884, 0.03264126294691648, 0.008518252288922668, 0.044406527520290444, 0.03280801971309951, 0.029351942307714905, 0.0295918655049588, 0.02872275374829769, 0.0817253225083862, 0.04290474292689136, 0.05138566730810063, 0.008966554438562264, 0.06270802154072694, 0.053833037947437594, 0.051032869810504575, 0.02285113069228828, 0.05817973666957446, 0.07503498079521315, 0.04483316319861582, 0.02597622380458883, 0.05157636957509177, 0.048968728964350054, 0.0861099615160908, 0.05633549205958843, 0.01600365892850927, 0.020366159034892917, 0.1587871281164033, 0.10708434746733733, 1.659031257033348, 14.643851382391793, 48.81679262433733, 61.8879383632115, 60.24202128819057, 65.74409130641392, 68.66127164023263, 45.24835416248867, 37.59939500263759, 27.797055346625193, 32.59604583467756, 58.90029634748186, 57.56017296654837, 71.32962308611188, 52.15989753178188, 43.91011374337332, 22.776478120258876, 4.156507500580378, 0.3251528681388923, 0.256664936031614, 0.09142394922673702, 0.027895650094641105, 0.08715688676706382, 0.029991610840495144, 0.23218795231410436, 0.20386336291474955, 0.2491023646933692, 0.16495148305382046, 0.46372033123459133, 0.12116545545203344, 0.23409661703876086, 0.1134500712422388, 0.4022424529705729, 0.23322646373084613, 0.4572356534855706, 0.24046374538115092, 0.6773717382124492, 0.486230160508837, 0.3470233002943652, 0.4937751442193985, 0.577723388160978, 0.11291479532207761, 0.0940606277436018, 0.24471341020294599, 0.4438210704496929, 0.08657689538917371, 0.04354213158200894, 0.2546937646610396, 0.21932690457573958, 0.310556168534926, 0.28614891107593265, 0.5555314932550702, 0.2663742836032595, 0.09639071699764047, 0.07041162638259785, 0.28354358087692944, 0.055244095623493195, 3.2614388210432868, 14.704331977026802, 40.096386500767295, 63.66955375671387, 81.71462304251534, 87.70119094848633, 69.74847017015729, 22.219489676611765, 16.649902275630406, 24.454329116003855, 43.79185887745449, 61.21725654602051, 58.664481435503276, 67.49334893907819, 70.33534281594413, 69.08387497493199, 79.27291488647461, 49.74696881430489, 7.3885745491300305, 0.34177646040916443, 0.03163020166435412, 0.036184810301555057, 0.07142552054886307, 0.13771119261426584, 0.01608169554466648, 0.06779639635767255, 0.01667270972393453, 0.04168422127674733, 0.023221863566764762, 0.05914468131959438, 0.03196530636133892, 0.034136584494262934, 0.030012214556336403, 0.044184035887675624, 0.04311584195654307, 0.03639806367989097, 0.07816412645791258, 0.03002347145229578, 0.011031868302130272, 0.022125186431886892, 0.04251095173614366, 0.02598275979315596, 0.045884858550769944, 0.011879425545755242, 0.020647988554888537, 0.020378001167305877, 0.017900920872177397, 0.014968272165528365, 0.02348986454308033, 0.009855095197313597, 0.011591824237257242, 0.016006047371774912, 0.03198727732524276, 0.017506671670292104, 0.03034929039755038, 0.03343442288626518, 0.009110906826598304, 0.005661075336060354, 0.08782837180686848, 0.05309923964419535, 0.029505124980849878, 0.046114288203950436, 0.04544749862647482, 0.011776563029603233, 0.011746984839971577, 0.03070532450718539, 0.033196755817958286, 0.03409987235707896, 0.04040536597105009, 0.04769162427900093, 0.07170266139187984, 0.034079061688057015, 0.029317669503922974, 0.03299476272825684, 0.04562996008566447, 0.05315477095012154, 0.0027085854172972696, 0.07429412912045207, 0.02042597020044923, 0.05515294122908797, 0.01392437402890729, 0.09707448352128267, 0.030657633673399687, 0.05933064741215535, 0.01829204542030181, 0.03466491221583315, 0.055389322473534515, 0.031496292778423855, 0.059994085026638846, 0.032097759789654186, 0.05399349790864757, 0.055037111908729584, 0.016319303241159235, 0.038517698512545655, 0.02235074165011091, 0.008953365414137287, 0.029858726542443037, 0.038384939743472, 0.03170238761231303, 0.039570506662130356, 0.053793696487056356, 0.1049475728401116, 0.0377944989262947, 0.10636817411120449, 0.03272030209856374, 0.013227401517464646, 0.03273768616574151, 0.033263503307742734, 0.05591251029233847, 0.16988177278212138, 0.04821704787069133, 0.05590379111734884, 0.05915758027029889, 0.0307484454076205, 0.06606234583471503, 0.04378088769902076, 0.05358240068224924, 0.043843652188245735, 0.1775375884026289, 2.348188659974507, 23.666389499391826, 68.20242650168282, 75.92784363882882, 68.83178043365479, 83.77345071520124, 100.5599649974278, 87.73718956538609, 58.906876291547505, 36.060657364981516, 29.58842079980033, 27.67975238391331, 43.42180476869856, 61.1964327948434, 57.571102482931956, 52.49203879492623, 27.97921974318368, 5.095226066453116, 0.21147018830691064, 0.36047881256256786, 0.08700012482170548, 0.02415684241402362, 0.11772525576608521, 0.060011163753058226, 0.10679920669645071, 0.051851267859871895, 0.2320078962615558, 0.09490836903985057, 0.5519634304302079, 0.3534227269036429, 0.6529921378408159, 0.6809544031109128, 1.1251449223075594, 0.6849174275994301, 1.5203514013971602, 0.8380785233208111, 1.3628366078649248, 1.5619018461023058, 1.2723569486822401, 1.1446208315236228, 1.148231832044465, 0.6779101150376456, 0.6314050076263291, 0.4051065764256886, 0.6189251744321415, 0.30055667938930647, 0.1340973558170455, 0.17258261357034954, 0.1585184418197189, 0.13065640974257672, 0.1797405066234725, 0.718373275228909, 0.2562428058258125, 0.0403798598396991, 0.13100797230643885, 0.4373835915965693, 0.20269529202154704, 2.799114154917853, 15.922306026731219, 49.55925280707223, 70.33270250047956, 72.80723394666398, 52.06183065686907, 41.26789794649397, 17.022704396929058, 20.943640606743948, 35.76825284957886, 78.1965833391462, 102.89883286612374, 90.66115828922817, 86.04254477364677, 84.62356281280518, 78.79196752820695, 91.68956116267613, 65.08508941105434, 13.429866467203412, 0.19481646908181055, 0.10088817602289574, 0.01815387872712953, 0.0837259626548205, 0.13871359239731515, 0.031308090912976434, 0.02610383418920849, 0.06037139120910849, 0.043900153799248595, 0.02420189035391169, 0.016034204878711274, 0.05816607775964907, 0.05217849815796528, 0.03927903515951974, 0.04425828458209123, 0.062058256406869204, 0.009756007032202823, 0.026921504509768317, 0.05381226459784167, 0.010200044589250215, 0.02419596504686134, 0.018125405701409494, 0.05031918328521507, 0.05637057910540274, 0.04445151099935174, 0.022174088450680886, 0.025304626806506088, 0.05474306197304811, 0.0661072377115488, 0.08060319522129637, 0.03775085216122014, 0.05656028053324137, 0.029005258410636867, 0.05033291344131742, 0.011360908592385905, 0.0128500860051385, 0.06036449729331902, 0.0325568599759468, 0.050417893167052946, 0.03809798389141049, 0.0382245374577386, 0.020606175530701876, 0.04377519139753921, 0.015031637158244848, 0.02155594644136727, 0.02963654025058661, 0.021547931246459484, 0.014925921402339424, 0.027434977403442775, 0.029691762823079313, 0.03592409000598958, 0.06290790438652039, 0.14195362425276212, 0.1032214340354715, 0.13090148302061216, 0.1050544013934476, 0.17665003745683602, 0.1170637384057045, 0.11322523187845945, 0.1169876339180129, 0.10644004454037972, 0.11617206196699824, 0.24412330186792783, 0.1950802563556603, 0.11942988501063415, 0.15533664183957235, 0.10369307015623365, 0.0730918464916093, 0.08800503518432379, 0.17650404386222363, 0.07649490317063672, 0.0897805577676211, 0.13098411501518317, 0.09688604077590363, 0.07870244900030748, 0.0948751208239368, 0.08287484225417886, 0.13172835936503752, 0.12567058870834963, 0.07963243552616664, 0.20387369021773338, 0.13684479839035443, 0.1930865847638675, 0.13730654147054466, 0.15238194753016743, 0.15467207107160771, 0.12762734799512795, 0.13390689103731088, 0.15440934231238707, 0.20142154608454022, 0.21727198841316359, 0.1515852931354727, 0.16042166469352587, 0.16715301706322602, 0.23062819029603684, 0.11432579532265663, 0.08700514598084347, 0.14591176328914507, 0.31743548225079266, 0.30751369893550873, 3.421005938734327, 32.76754127229963, 87.85264083317348, 87.5029935836792, 81.05261952536446, 88.54862798963273, 95.22756304059709, 61.19406345912388, 53.92700508662632, 34.34852743148804, 48.61745922906058, 85.48315920148576, 90.63533183506557, 106.04844433920724, 78.34212725503104, 68.91269915444511, 33.70864003045218, 6.039472792829786, 0.7631800909127507, 0.49690042223249165, 0.2062959245273045, 0.07565242052078247, 0.2544573630605425, 0.22424251080623694, 0.5315130363617624, 0.7725364917090961, 1.0151901138680322, 0.28656930423208643, 0.5380810924938747, 0.4631579614111355, 0.6553084935460771, 0.4687748742955071, 0.7251724132469722, 0.411230843514204, 0.7899969890713692, 0.35214585970555035, 0.7386866052235875, 0.6549995701227869, 0.6006612916077886, 0.7098976128867694, 0.6562221273779869, 0.4014540495617049, 0.44410377527986256, 0.47138142585754395, 0.6253917217254639, 0.6275593425546373, 0.5071818019662584, 0.8125190319759505, 0.5735330815826143, 0.5564372017979622, 0.7040273621678352, 0.9636872432061604, 0.5528811354722295, 0.26901215634175707, 0.25790703509535107, 0.562176088137286, 0.5564303078821727, 4.538978474480765, 21.794450998306274, 61.28174277714321, 95.14165551321847, 122.0086441040039, 128.01151248386927, 109.22600841522217, 36.387191431862966, 24.60478367124285, 34.660345213753835, 58.8048072542463, 77.2562836238316, 78.44032614571708, 83.83725602286202, 88.95607035500663, 86.74812739236015, 106.75269985198975, 77.0680569240025, 14.415854930877686, 0.3231583280222756, 0.14982184847550734, 0.13953315413423947, 0.18205216686640466, 0.2538737958031041, 0.10651486659688608, 0.23443349610481942, 0.11069779749959707, 0.152115079707333, 0.14872183464467525, 0.08418807892927102, 0.1661032691065754, 0.07313093010868345, 0.148549975295152, 0.115275255803551, 0.17689048312604427, 0.112634166809065, 0.1407308770077569, 0.1717723613338811, 0.10899638451103653, 0.13214668977473462, 0.10009675991854497, 0.09343928644167525, 0.1360464205167123, 0.1849726630108697, 0.10541669838130474, 0.18748493891741547, 0.11153963554118361, 0.16535852264080728, 0.1592977935714381, 0.2729145197996071, 0.10593304317444563, 0.08422224995281015, 0.14322249830833503, 0.0880820896210415, 0.16680629923939705, 0.15824200665312155, 0.09798992904169218, 0.17962470783718995, 0.1918587756476232, 0.11356595823807375, 0.09896794227617127, 0.15119447053543159, 0.1538527671779905, 0.06780581442373139, 0.10664662452680723, 0.19485179361488136, 0.08345254018370594, 0.11791477059679371, 0.11970775867147104, 0.08795907122216054, 0.16350418142974377], [0.07165816306535687, 0.030863141574497734, 0.01417599177719759, 0.10081652272492647, 0.07765832609896149, 0.06626690378678696, 0.023634250009698526, 0.04347233746999076, 0.03743218836773719, 0.06198126303830317, 0.05584706558978983, 0.03870313874046717, 0.011990331246384552, 0.02908090827986598, 0.01582198796261634, 0.025936112206961428, 0.06786278422389712, 0.008581462914922407, 0.028723405141915594, 0.022470314787434678, 0.008393091415720326, 0.01955049717798829, 0.06714471096971206, 0.04555088700726628, 0.034813915113253255, 0.02864762974370803, 0.04732600246955242, 0.06640798478786435, 0.020829547562503388, 0.05026931096134441, 0.036121217999607325, 0.05626681074500084, 0.0315653506799468, 0.09284600934812001, 0.02727109592940126, 0.03815934720582195, 0.016357090856347765, 0.07994049042463303, 0.01987772069073149, 0.08240702628557171, 0.02823969109782151, 0.0547447209911687, 0.06252635736018419, 0.045063183177262545, 0.007260412909090519, 0.07847175387931721, 0.5811737115894045, 19.65658756664821, 41.61098609651838, 64.1609581538609, 50.665510245731895, 59.96619864872524, 68.96462999071393, 48.66651003701346, 24.812345470700944, 28.569517850875854, 49.28843634469168, 60.01161207471575, 62.72220161982945, 55.886195591517854, 46.447342259543284, 25.968020234789165, 15.302396433694021, 2.207350411585399, 0.08659408946654626, 0.12654474537287438, 0.0515973396998431, 0.017390401302171603, 0.05195671220176986, 0.11200013690228973, 0.09328930306115321, 0.12759499544543879, 0.07914083011980567, 0.05932322423905134, 0.0813809320596712, 0.06183963920921087, 0.10350770795983927, 0.021621316505063857, 0.1328196743769305, 0.09987942515207188, 0.16093043025050843, 0.1548342952238662, 0.23867656556623323, 0.19513307352151188, 0.44011909195355003, 0.36435544597251074, 0.8652930430003575, 0.2967657313815185, 0.3818225658365658, 0.11480686308017798, 0.032437807614249844, 0.058709340036979744, 0.08910656893359763, 0.06382067647895642, 0.024724319909832308, 0.0934305265545845, 0.17860613177929605, 0.12261943386069366, 0.0733322175219655, 0.34026327303477694, 0.25950191808598383, 0.12352825009397098, 0.012016124058780926, 0.14294552031372273, 0.04996136123580592, 0.1170283460191318, 0.12692989542015962, 0.551912784576416, 6.79656457901001, 25.058900560651505, 62.24827889033726, 61.078765051705496, 90.82972853524345, 75.26028851100376, 61.47853660583496, 26.39565406526838, 21.702029534748622, 23.394892113549368, 47.851906708308626, 62.84769998277937, 66.66249029976981, 64.48227064950126, 70.10058403015137, 65.63502543313163, 21.283351932253154, 0.16697290672787599, 0.14440114077712807, 0.04932335850649646, 0.06768922175147704, 0.08886378910392523, 0.04786306293681264, 0.048336388609771214, 0.04501739563420415, 0.028721576490040337, 0.028501018682228665, 0.07032899438802685, 0.12578971231622355, 0.018399718749736036, 0.010003450093790889, 0.05126501699643476, 0.05295614678678768, 0.012762744129369301, 0.035237772190677266, 0.008010849739158792, 0.07565754346017327, 0.04151693864592484, 0.030448125808366706, 0.03902421472594142, 0.03740499946953995, 0.011616230293709253, 0.024087358731776476, 0.02397300522508366, 0.015278919067765986, 0.04007687699049711, 0.03799402214852827, 0.0033663337276915884, 0.02835156625535871, 0.06497151258268527, 0.04630870884284377, 0.04090257268399, 0.08864418803048985, 0.02470766526779958, 0.025829115716208304, 0.02846608091411846, 0.01396641945133784, 0.030328659540308372, 0.04118815789531384, 0.009334006596223583, 0.019824462477117777, 0.015378443191626241, 0.014683143269004566, 0.04885872147445168, 0.017808392444359403, 0.03415779210627079, 0.009292185938517963, 0.022933180843080794, 0.019604873278045228, 0.03546473536906498, 0.04787524264039738, 0.05585251083331449, 0.06557232141494751, 0.05257011125130313, 0.04419841743739588, 0.02233025328522282, 0.027769781848681823, 0.03721854483176555, 0.03819967254198023, 0.01844803722841399, 0.03676905609401209, 0.035685890287693055, 0.027303392499951378, 0.03660676408825176, 0.07648404661033835, 0.010612498885685844, 0.03663197844954474, 0.03822405569787536, 0.02752724798795368, 0.04370376540880118, 0.03029165224039129, 0.022994735843635032, 0.033603998965450695, 0.030710328702947924, 0.03975442357893501, 0.042479399857776504, 0.03437620235074844, 0.056284065890525065, 0.05699960142374039, 0.050848969857075384, 0.021549882034638097, 0.034335446144853315, 0.031042220536619425, 0.008882282085583677, 0.04291961980717523, 0.0929578115631427, 0.05494958767667413, 0.08072284808648483, 0.024821462375777106, 0.05804419929959944, 0.04448546828436, 0.06538545965616192, 0.06167257710226944, 0.06875683553516865, 0.9747962185314724, 28.386293854032242, 58.01443576812744, 83.39077867780412, 65.7070643561227, 84.05719430106026, 106.28467614310128, 87.25114917755127, 43.49848508834839, 23.597605807440623, 37.56017936979021, 27.012397016797745, 42.65270519256592, 52.44408580235073, 48.43251207896641, 31.687836374555314, 18.406358242034912, 2.476442200796945, 0.13591557182371616, 0.17114340008369514, 0.018559758019234453, 0.04224642825179866, 0.23349220518554958, 0.74913447030953, 0.6932919610823903, 0.5321532477225576, 0.41294512152671814, 0.6794560349413327, 0.4985572418996266, 0.22725068724581174, 0.08214260797415461, 0.4075598062149116, 0.9629403118576322, 0.980182375226702, 0.8473062195948192, 0.9150607096297401, 0.9974621108600071, 1.3618581060852324, 2.3591457520212447, 2.162676534482411, 3.950578962053571, 1.7629703368459428, 1.8020807696240289, 1.9701323977538516, 1.5165275037288666, 0.6048129488314901, 0.5896276065281459, 1.038477544273649, 0.6318006206836019, 1.1190584089074815, 0.6118785068392754, 0.44626993047339575, 0.7808383405208588, 1.1224216627223151, 0.9087403459208352, 0.5417883907045636, 0.03188464890367218, 0.37584562227129936, 0.16792255719857557, 0.11725896650127002, 0.0958884721621871, 0.3611975982785225, 6.842912537711007, 27.16931860787528, 66.77010399954659, 63.3432594026838, 59.10061291285923, 33.483487129211426, 36.45176451546805, 27.947806937353953, 27.785245146070206, 41.08735942840576, 83.11362198420933, 91.25620201655796, 90.58854961395264, 81.42755821772984, 86.42615481785366, 81.443573815482, 33.131216934749055, 0.5869399564606803, 0.1733865418604442, 0.04670161454539214, 0.04510721331462264, 0.10455094876566104, 0.06989319848694972, 0.057801161626619954, 0.08108624430107218, 0.025435161677056124, 0.042230251976954084, 0.01936642759080444, 0.006970089826998966, 0.009880634407246751, 0.06396077360425677, 0.0928847129855837, 0.023234843941671506, 0.013229487164478217, 0.037734221267913065, 0.05597637400829366, 0.08425950152533394, 0.011397814112050193, 0.030095379200897047, 0.031380734872072935, 0.03795723197981715, 0.1114232667854854, 0.013019559455902448, 0.014791171132986034, 0.026691048572372113, 0.04453179526275822, 0.0411592590888696, 0.03466592323301094, 0.015785326715558767, 0.014897701130913836, 0.05395054664196713, 0.04334706972752299, 0.03930127414475594, 0.02763975757573332, 0.02817993930407933, 0.03915360117597239, 0.01811887989086764, 0.02845902245358697, 0.03103597801444786, 0.07759370242378541, 0.02973438160760062, 0.06413333184484925, 0.042967765259423425, 0.09100947968129601, 0.01961355852628393, 0.07346206876848425, 0.03918309370055795, 0.050611876150859256, 0.22047677715974195, 0.12143357177930218, 0.11344776422317539, 0.158233728525894, 0.13659779807286604, 0.15668004618159362, 0.13098487497440406, 0.12443484073238713, 0.07227843906730413, 0.09630101466817514, 0.216247346252203, 0.13855438094053948, 0.07685992108391863, 0.07768710955445256, 0.08370395776416574, 0.11507770711822168, 0.16917739914996283, 0.07631063341562237, 0.08753799953098808, 0.11499082749443394, 0.07601314330739634, 0.13523337271596703, 0.10211645332830292, 0.13479023506598814, 0.15196377996887478, 0.06309644212680203, 0.12138004893703119, 0.1862341138933386, 0.0978568343977843, 0.1372502909174987, 0.11485136140670095, 0.11705927364528179, 0.08379051847649471, 0.19140195873166832, 0.10034129715391568, 0.10044664650091104, 0.09585747668253523, 0.16308817160981043, 0.15848592642162526, 0.23515317748699868, 0.18241217040589877, 0.16626214129584177, 0.20017631218901702, 0.16029770991631917, 0.19535594513373716, 0.19932564640683786, 1.690767371228763, 37.42056226730347, 73.95309611729213, 98.37285968235561, 77.67188317435128, 87.89307240077427, 96.57468673161098, 67.69136565072196, 33.76237045015608, 38.51269749232701, 76.5673280443464, 99.35719013214111, 98.32395131247384, 89.11651815686906, 67.75178718566895, 40.57508264269148, 26.92761857169015, 4.230293895517077, 0.47661037955965313, 0.31690584495663643, 0.1701637447944709, 0.18417034963411943, 0.2764510443168027, 0.47599720103400095, 0.45784687783036915, 0.31764357537031174, 0.2519918110753809, 0.3534942444946085, 0.30617427080869675, 0.18165582099131175, 0.17232738940843514, 0.2152218355664185, 0.5294037695441927, 0.383843541677509, 0.32442716136574745, 0.5365148708224297, 0.38496697853718487, 0.40100700355001856, 0.5162682543907846, 0.43888404965400696, 2.0818605167525153, 0.6108662411570549, 0.5346306604998452, 0.566879367189748, 0.5798759183713368, 0.2515591228646891, 0.2053572798946074, 0.3689569719135761, 0.30690779430525644, 0.46397214915071217, 0.3429269572453839, 0.28701868440423695, 0.357196358697755, 0.7455395374979291, 0.6379440767424447, 0.3535226343997887, 0.21162166446447372, 0.4400044466767992, 0.24687413711633, 0.21164508749331745, 0.18857271197651113, 1.3938709540026528, 11.20964777469635, 38.005492891584126, 92.28299290793282, 90.68098844800676, 130.82660293579102, 105.4648859841483, 86.36242594037736, 38.065980434417725, 27.3367371899741, 32.20870113372803, 66.51405593327114, 81.47906521388462, 88.53707313537598, 83.79522636958531, 91.6862051827567, 99.62926769256592, 38.78930875233242, 0.9014373549393245, 0.33978504155363354, 0.16439948124544962, 0.10677543761474745, 0.1757075251745326, 0.22220917205725396, 0.1210600518222366, 0.1273365414568356, 0.14726077233042034, 0.10542955661990813, 0.27100433515650885, 0.1754234225622245, 0.10851566280637469, 0.12594079492347582, 0.14857638387807778, 0.1393162672008787, 0.12338966610176222, 0.19045909361115523, 0.1882095600345305, 0.2204921527632645, 0.09871220242764268, 0.09160262785319771, 0.12649085612169333, 0.09063547117901699, 0.19317000385906014, 0.17516897193023137, 0.19284550127174171, 0.09675704448350839, 0.11404029492821012, 0.1427745023476226, 0.11229488572904042, 0.08664065732487611, 0.1368880753538438, 0.1274836885609797, 0.13530434747891767, 0.2666729475770678, 0.09820063452103309, 0.1083267383011324, 0.07562937068619899, 0.08584277478179761, 0.11889201030135155, 0.0803814364065017, 0.10558201665324823, 0.19426355803651468, 0.12179842005882945, 0.1076885082625917, 0.14589629269071988, 0.15512744949332305, 0.15003098653895514, 0.1485684993011611, 0.1335889430982726], [0.010409978235007396, 0.02936736201601369, 0.05678890272974968, 0.040524367442620654, 0.022462280932813883, 0.029154067925576652, 0.054619371824498684, 0.0293625885221575, 0.033163602596947124, 0.01106731581967324, 0.07240759820810386, 0.014615946249770266, 0.03849043497549636, 0.07087101494627339, 0.07678712106176785, 0.023318451330331818, 0.018311602495876805, 0.049734801785754304, 0.0490241313486227, 0.026160049119165966, 0.022414656256192496, 0.0677146939560771, 0.04125874589330383, 0.025578464880319576, 0.011276003505502428, 0.013738963486892837, 0.04408403339662722, 0.016304579031254565, 0.04144394524129374, 0.04141275977183666, 0.05371848427291427, 0.022876188990526965, 0.13443519840283052, 0.05626142656962786, 0.10594427292900425, 0.037612027289079766, 0.01247109196680997, 0.06063990108668804, 0.035728807627622566, 0.02048011220592473, 0.011258964643015392, 0.015274993742683103, 0.0645201171615294, 0.028265458465154682, 0.012406274060984808, 3.7004394701548984, 21.540949446814402, 58.745309829711914, 60.82537119729178, 58.93805285862514, 51.66089875357491, 40.861980710710796, 18.888908897127422, 29.019733326775686, 49.09069061279297, 68.36389568873814, 65.07529245104108, 51.42980514253889, 45.37187228884016, 25.168464967182704, 6.950896663325174, 0.6218979177730424, 0.14653475343116693, 0.11536513455212116, 0.017953291901254227, 0.013196729190115417, 0.08154952765575477, 0.11459630009319101, 0.053445190723453245, 0.16005001749311173, 0.17701842768916062, 0.06649777532688209, 0.11206505234752383, 0.1682015707982438, 0.416529686323234, 0.11327804225896086, 0.7673810912030083, 0.822642340191773, 1.2195713754211153, 1.3819956140858787, 1.8526505189282554, 1.4561472237110138, 2.947626905781882, 3.241547865527017, 5.946351732526507, 6.889865858214242, 6.7524009602410455, 3.131339882101331, 3.69223929303033, 2.6390767310346877, 1.837863883801869, 0.6486131442444665, 1.5315193278448922, 0.9051797741225788, 0.0879906163151775, 0.24080743693879672, 0.2603273423654692, 0.3584051009799753, 0.1332708458815302, 0.3914464994200638, 0.03574956740651812, 0.167399311704295, 0.0938949091359973, 0.2226951252669096, 0.16773085748510702, 0.09103188490761177, 0.1538946327886411, 0.036576053593307734, 0.11807740187006337, 0.18641241932553904, 2.6040942881788527, 20.669438634599956, 38.97671903882708, 62.171028818402974, 52.38475513458252, 97.3391136441912, 84.146242414202, 42.72946194240025, 23.487509863717214, 22.874477250235422, 37.68853344236101, 46.98317343848092, 61.16646521432059, 64.66766248430524, 66.01270171574184, 41.1602668762207, 12.311780588967459, 0.2637999488839081, 0.3438574730285576, 0.019860158508111323, 0.07246003539434501, 0.09088547740663801, 0.014403848077303596, 0.039280049569372616, 0.005790867634849357, 0.021083336622853364, 0.0396003554176007, 0.08330858897949968, 0.014489077164658477, 0.06936674352203097, 0.03179244277998805, 0.04332498341266598, 0.06530045957437583, 0.04060298590255635, 0.03909221072016018, 0.056116820579128604, 0.020688795650910054, 0.028595206128167253, 0.043396188877522945, 0.0216943913338972, 0.050420512312224934, 0.013051085041037627, 0.015474907122552395, 0.007880464146312858, 0.03539697007675256, 0.047652442274349074, 0.01487887856949653, 0.1021216373358454, 0.038464212989700694, 0.04096039065292903, 0.017715314403176308, 0.030449448951653073, 0.016391655430197716, 0.02001823002605566, 0.11342826312673943, 0.059172915161720345, 0.045157241701547585, 0.04188136623374053, 0.030595754672374045, 0.025248050556651185, 0.04511478915810585, 0.046300654632172415, 0.053845064980643134, 0.025287539598398974, 0.035036108190459866, 0.03483597767938461, 0.007111135629072253, 0.032930675095745494, 0.02671014254779688, 0.04059181043079921, 0.04973283403420022, 0.036266013979911804, 0.03454756636970809, 0.04267082137188741, 0.03868575128061431, 0.047875045865241966, 0.05615431981693421, 0.011588959971309772, 0.03652153330455933, 0.013747395132668316, 0.01999227436525481, 0.026392072472455244, 0.036508987192064524, 0.023036852512242537, 0.01581095837588821, 0.08105609020484345, 0.019916364956381064, 0.05554082916517343, 0.04455971019342542, 0.0657320689143879, 0.056304198024528365, 0.01813753112219274, 0.006989757164514491, 0.03221363660746387, 0.05242611933499575, 0.03085039190149733, 0.09323514918131487, 0.08855751196720771, 0.011814031733333, 0.013166499606865858, 0.04221718678517001, 0.06059123655515058, 0.037143315654248, 0.06264230542417083, 0.05823550546275718, 0.07158115612609045, 0.012309720224168683, 0.05796402360179594, 0.07021633721888065, 0.02773930035930659, 0.10989050367580992, 6.436415995870318, 32.405661719185964, 76.8370223726545, 77.18621104104179, 81.59377997262138, 87.52191352844238, 75.22956357683454, 39.96163313729422, 36.83991520745413, 28.443109273910522, 36.02449199131557, 59.96421841212681, 58.057604925973074, 50.97022696903774, 30.42548418045044, 9.73336228302547, 0.7259660820875848, 0.33372154406138826, 0.2858765742608479, 0.03475291481507676, 0.11975167345787797, 0.42954083957842415, 0.4054206295737198, 0.4344960722540106, 1.1115350297519138, 0.7129948266914913, 1.382694125175476, 1.9232033959456851, 2.9642708812441145, 2.5297702763761793, 1.8677858667714256, 2.752637871674129, 3.1171913955892836, 4.376027584075928, 4.637192564351218, 4.957466738564627, 4.696214471544538, 5.350250141961234, 9.485023243086678, 13.043644768851143, 12.270476153918676, 11.342178583145142, 7.261941892760141, 7.510782940047128, 6.429996728897095, 5.810865334102085, 7.574411068643842, 5.384172984531947, 3.2316558020455495, 2.3412715111460005, 1.6790279554469245, 2.659272755895342, 2.431005758898599, 1.5317035636731555, 2.434998150382723, 1.1840496872152602, 1.530485240476472, 0.7350844527993883, 0.8395035554255758, 0.44353204167314936, 0.17607107066682406, 0.16684619709849358, 0.09837908244558743, 0.20567088520952634, 0.182151802948543, 2.555950220142092, 22.90598385674613, 48.308809825352256, 65.87228557041713, 49.395362172807964, 48.24180487224034, 50.568989345005576, 32.44595084871565, 29.56672157560076, 45.11085278647286, 63.65822124481201, 74.27809810638428, 77.13399532863072, 77.76672608511788, 82.39528942108154, 58.91251128060477, 18.23677703312465, 0.9137837610074452, 0.26057305346642223, 0.015700881336150423, 0.05175678864387529, 0.08247137176139013, 0.06546608997242791, 0.04508690815418959, 0.03763850711818252, 0.038083419137235196, 0.017836692443649684, 0.036714807219271145, 0.05376309116504022, 0.062053527017789226, 0.035642022998737435, 0.0652494133849229, 0.03505065258858459, 0.02447546210273036, 0.026796749061239616, 0.009481190171624933, 0.04767576691561511, 0.030862904087241207, 0.026817882034395422, 0.041284028108098676, 0.030225769882755618, 0.04450600414669939, 0.02051206611629043, 0.01968717448679464, 0.07516865897923708, 0.02645765457834516, 0.02524995554371604, 0.04906192574916141, 0.03702472469636372, 0.04223597541983638, 0.0507247097391103, 0.03505582981077688, 0.0326771438787026, 0.02030578298893358, 0.014242672261648943, 0.013363568228669465, 0.030633447292659963, 0.018621771030926278, 0.004543006960635206, 0.046959423925727606, 0.02939154839675341, 0.03245373622381261, 0.12667339561241014, 0.0368942593756531, 0.025282944219985178, 0.011813879062953805, 0.08549433347902127, 0.08672445639967918, 0.13188833078103407, 0.13920619525015354, 0.11180968569325549, 0.08406158643109457, 0.1112860602193645, 0.1464616616389581, 0.1139587757310697, 0.16335446946322918, 0.16943353254880222, 0.05777982848563364, 0.16333575546741486, 0.1455324079309191, 0.11472200549074582, 0.09683641950998988, 0.11089365663272993, 0.10416115075349808, 0.07843575081122772, 0.19597345271280833, 0.1043084878474474, 0.15449061723692076, 0.16035189772290842, 0.12003604748419353, 0.10279673218194928, 0.09282846921788794, 0.10629813572657959, 0.12552824563213758, 0.14173711729901178, 0.213302219286561, 0.2013091535440513, 0.1957276737583535, 0.15969190028096947, 0.14215445704758167, 0.23668674805334636, 0.16875632745879038, 0.10317880846560001, 0.17664067367357866, 0.18621109798550606, 0.08989786968699523, 0.05832425105784621, 0.10986001031207186, 0.18841044711215155, 0.10757967803095068, 0.20778297473277363, 8.734680329050336, 45.76641532352993, 95.66878754752022, 86.5036689213344, 85.60808086395264, 72.39344092777797, 55.412238121032715, 22.90207028388977, 41.389637334006174, 70.03928007398332, 101.96573148454938, 91.98795849936349, 78.66098008837018, 68.46083000728062, 39.55262047903878, 14.730801139559064, 1.6941304079123904, 0.6508683775152478, 0.8207670322486332, 0.10349726530590228, 0.17491093863333973, 0.26132183043020113, 0.2437494019312518, 0.14833768882921763, 0.5747404939361981, 0.491711257823876, 0.9160144584519523, 1.4246279150247574, 1.9583819082805087, 2.987267030136926, 1.142549182687487, 2.500306874513626, 2.517697347061975, 3.9772722039903914, 4.25399854353496, 6.041118213108607, 5.169754615851811, 9.066056421824864, 9.542745402881078, 16.60073334830148, 12.250665971211024, 15.186368465423584, 8.323863744735718, 9.560005596705846, 7.834518619946071, 5.017531309809003, 3.276413926056453, 4.133978835174015, 3.011479765176773, 1.4427355719464166, 0.7948818440948213, 1.0703344919851847, 1.1352992802858353, 0.6137783506086895, 1.3982482105493546, 0.7075897795813424, 0.6037453689745494, 0.31107223512870924, 0.5071973811302866, 0.57255669683218, 0.3252875166279929, 0.34941250351922853, 0.1568182094820908, 0.3741660581103393, 0.48812826722860336, 4.3398591705730984, 32.946909018925254, 60.682127135140554, 92.46535532815116, 76.01081207820347, 131.02686391557967, 120.44217273167202, 60.947041102818076, 31.6554890360151, 31.510330745152064, 46.621394634246826, 65.22065571376255, 80.64045238494873, 83.10844557625907, 94.37128789084298, 68.94055448259626, 21.09636722292219, 1.2705059051513672, 0.34772251706038204, 0.21342633691217217, 0.16383644645767553, 0.15741517102079733, 0.10878039324390036, 0.12195676299078123, 0.09294894989579916, 0.11446475929447583, 0.09775331030998911, 0.15726882458797523, 0.11035796680620738, 0.1747441818671567, 0.12176775027598653, 0.17005910112389497, 0.14871850982308388, 0.12245229711490017, 0.14169390818902425, 0.1287005189806223, 0.1029635975137353, 0.11513174564710685, 0.06617458231214966, 0.09516936753477369, 0.1212883245732103, 0.14117752946913242, 0.18788281828165054, 0.08403609387044396, 0.12539401783474854, 0.1307360968951668, 0.1593832347009863, 0.15587299663041318, 0.16765695145087584, 0.11852619850209781, 0.15819807829601423, 0.158762483724526, 0.09466277328985077, 0.10220468323677778, 0.18011549221617834, 0.11649090557226113, 0.13335365429520607, 0.09148848469236068, 0.07451263096715723, 0.07566117362252303, 0.12874231673777103, 0.1790728010237217, 0.19275176844426564, 0.06840811603303466, 0.06595031291778598, 0.12381358764001302], [0.02426457341893443, 0.07398127697940383, 0.05764083058706351, 0.033359495656830926, 0.013912079822538155, 0.04944778147286602, 0.03793820585789425, 0.03251245664432645, 0.04951221855091197, 0.03441197132425649, 0.026274777516456585, 0.02110394203503217, 0.019804812102977718, 0.020902096526697278, 0.02012275156032826, 0.025283497226025377, 0.03027725711997066, 0.06732281962675707, 0.0297353451273271, 0.062429713617478094, 0.07381645403802395, 0.0491928592590349, 0.009893256854931158, 0.00988000167334186, 0.018265964230522513, 0.007654068392834493, 0.017354535637423396, 0.015433474077976175, 0.02518740818569703, 0.05366415397397109, 0.037372026060308726, 0.05699971677469356, 0.03775801070566688, 0.07802809375737395, 0.019210294986675893, 0.013603742483870258, 0.006554838694033346, 0.017489883017593195, 0.03726854946996484, 0.03935296154980149, 0.01732395915314555, 0.07199627706514937, 0.020006471014182483, 0.6431205932583127, 13.169518334524971, 57.27761057444981, 74.27698639460972, 67.34832613808769, 53.422030857631135, 39.73711599622454, 43.32703481401716, 35.8791252544948, 50.622608593532014, 62.19809900011335, 57.31850419725691, 46.644907338278635, 38.56109864371163, 17.549007858548844, 3.523654933486666, 0.06452179992837564, 0.5396327663745198, 0.1891286221465894, 0.09828524105250835, 0.020405877082209502, 0.23939209431409836, 0.07811234066528933, 0.060000049349452765, 0.21123648727578775, 0.05020097569961633, 1.977745234966278, 1.280613037092345, 1.38018256851605, 1.7848218785864967, 3.332129576376506, 2.419349504368646, 1.919623988015311, 2.291931050164359, 2.338401687996728, 2.6458151808806827, 4.198308731828417, 5.7847570436341424, 2.666448725121362, 3.3080080364431654, 7.833344374384199, 16.348115955080303, 21.201745339802333, 12.640884620802742, 7.414030143192836, 7.34880827154432, 9.17085349559784, 7.479755759239197, 4.142822589193072, 5.899104850632804, 4.755987218448094, 2.522490518433707, 3.405594617128372, 2.837082151855741, 2.181862247841699, 2.5694514385291507, 2.27750745841435, 2.0349758097103665, 1.572081065603665, 0.5617965427892548, 0.46041049169642584, 0.1349564625748566, 0.05720374546945095, 0.13337227329611778, 0.19479821648980888, 0.06980317724602562, 0.08918888201670987, 0.08299527543463878, 0.23030276490109308, 1.495395643370492, 15.118194477898733, 36.838991097041536, 65.09625516619, 62.48574052538191, 53.82586015973772, 64.53274931226457, 40.996737548283164, 22.799082347324916, 30.22993755340576, 50.804995332445415, 53.24876710346767, 65.58088506971086, 60.38778059823172, 71.90710176740373, 38.09836598805019, 5.900528362819126, 0.34810119388358934, 0.11938203472111907, 0.0463717990288777, 0.049935444590768645, 0.007994904166220554, 0.03518498895157661, 0.058156998961099556, 0.08900142314710788, 0.05823055215712104, 0.05868721301002162, 0.0208769839456571, 0.009290347108617425, 0.007222354728063303, 0.03564912386770759, 0.03052423368873341, 0.02945098467171192, 0.024728854220094423, 0.07381604691701275, 0.036638855401958735, 0.014981663054121392, 0.02370273963814335, 0.02445764886215329, 0.05808288258101259, 0.041576819361320565, 0.03962305919932468, 0.04181546012737921, 0.01795597550725298, 0.0894040386857731, 0.01857944232012544, 0.03391973488032818, 0.019617762050724456, 0.06565290423376219, 0.06913623839084591, 0.018854408458407437, 0.07274022964494568, 0.02820580675532775, 0.021517015494672314, 0.07170380133071116, 0.057927715192948065, 0.008987485547550023, 0.051616922220481296, 0.039395811036229134, 0.022029267025313208, 0.02156635856122843, 0.03431747514488442, 0.04846404818817973, 0.10863344291491167, 0.008543275812241648, 0.027258403931877444, 0.02416322403587401, 0.026018450735136867, 0.02314539436650063, 0.05501696281135082, 0.06795625920806612, 0.02418346643181784, 0.042440248387200494, 0.032931333274713585, 0.023589726238112365, 0.03959904584501471, 0.018204583952735578, 0.051822216383048465, 0.04662289769787874, 0.03501291586352246, 0.041668489442339966, 0.07083180919289589, 0.02590170199982822, 0.029371436618800675, 0.02409061400352844, 0.01750876155814954, 0.005193929844868502, 0.018909802360992347, 0.02182707716045635, 0.03769627758967025, 0.021720346994698048, 0.0189583718976272, 0.034163712324308496, 0.04596360593235918, 0.005801161859251026, 0.02613095862657896, 0.026707696429054652, 0.05257582112348505, 0.05618008718426738, 0.040445084018366675, 0.02801993565766939, 0.05418555046032582, 0.07278101638491664, 0.032057872108582935, 0.0936754166281649, 0.041067453300846476, 0.06823124909507376, 0.9398168155125209, 22.602545601981028, 77.30590070996965, 99.7710039956229, 92.85000760214669, 81.87744018009731, 71.03776400429862, 57.78874438149588, 34.39266586303711, 21.405800036021642, 29.832511016300746, 46.83303328922817, 48.10075296674456, 45.77062593187605, 21.48354169300624, 4.441591220242636, 0.07278048034225192, 0.8150126210280827, 0.3477327493684632, 0.13519401768488543, 0.22688811884394713, 0.6675588733383587, 0.5924309332455907, 0.663850163774831, 1.4739463371889931, 2.1142840683460236, 5.845685797078269, 4.9135510836328775, 4.256306213991983, 5.6076183659689764, 7.129599988460541, 4.175739245755332, 4.8481133835656305, 5.312877084527697, 6.39913500206811, 7.944336635725839, 9.886171409061976, 5.807667425700596, 6.5056673884391785, 8.997328315462385, 12.430453215326581, 15.313023703438894, 18.991860355649674, 18.08620956965855, 12.092572740146093, 10.94607480934688, 9.45273062161037, 12.674163017954145, 7.643636839730399, 8.482860241617475, 9.544769065720693, 9.48950743675232, 7.802428364753723, 4.768774509429932, 4.694900393486023, 4.636757867676871, 4.17798525094986, 2.807062025581087, 2.4183624259063174, 1.6161144056490488, 0.9083495640328952, 0.6499915474227497, 0.11464082556111471, 0.6240028962492943, 0.40796912567956106, 0.06319054136318819, 0.17545037397316524, 0.05693771903003965, 0.4509016919348921, 1.1146953744547707, 16.774945531572612, 42.33904613767351, 68.18404851640973, 55.90659202848162, 34.42479085922241, 44.159130232674734, 23.727893216269358, 31.738429682595388, 51.26298931666783, 85.07853780473981, 78.84920678819928, 78.68075466156006, 75.6079694202968, 89.06383691515241, 58.17117323194231, 13.57938301563263, 0.3633696702974183, 0.19448727103216307, 0.037904238394860706, 0.0680713862446802, 0.03744647492255483, 0.018251998283501183, 0.04073734940694911, 0.034277753704892736, 0.025673320683251535, 0.04580803481595857, 0.02603890517327402, 0.0461801264568099, 0.056909593753516674, 0.0771152198846851, 0.028672806785574982, 0.023186510195955634, 0.02833822456055454, 0.0531527319523905, 0.039947500718491416, 0.011246995285286434, 0.049932842408972125, 0.03732259478420019, 0.03573315703709211, 0.010917909193917044, 0.0530448448844254, 0.01664534949564508, 0.011491869243660142, 0.07076774870178529, 0.01109086098482034, 0.060746933200529644, 0.032869240535157065, 0.09225753628249679, 0.039634540011840205, 0.06603452589895044, 0.0270966208273811, 0.014564072247594595, 0.04393647238612175, 0.029129586382103816, 0.058174450881779194, 0.034593163922961266, 0.07772117879773889, 0.03371151962450572, 0.04403327897723232, 0.02401418381902788, 0.025304645466219102, 0.026942620519548655, 0.024490238899098973, 0.10446869675070047, 0.12026893427329403, 0.1559496982289212, 0.15176788690899098, 0.16990230525178568, 0.10679899635059492, 0.19632967002689838, 0.07778276263603143, 0.20059002856058733, 0.08850499335676432, 0.13018157093652657, 0.11483306810259819, 0.12721368590635912, 0.10865719842591456, 0.09835204282509429, 0.11909892276993819, 0.14895526426179068, 0.1932444255799055, 0.09216782716768128, 0.14415219984948635, 0.12870229674237116, 0.09623338508286647, 0.09100274182856083, 0.124675381396498, 0.1396997616227184, 0.0813395142821329, 0.13437840502176965, 0.09563336335122585, 0.26948102403964314, 0.13328258453735284, 0.09442325721361808, 0.09905873704701662, 0.14130607114306518, 0.13940924006913388, 0.11988277999418122, 0.15679759558822426, 0.1255990575466837, 0.0877178180962801, 0.15860187448561192, 0.20974596297102316, 0.18252818632338727, 0.18806119156735285, 0.11975094064005784, 1.1665174279894148, 31.550387110028947, 95.95761026654924, 109.47601154872349, 91.0527240208217, 76.37241022927421, 59.8022906439645, 57.49730913979666, 51.68075670514788, 73.12092426845005, 92.75895840781075, 83.36946160452706, 69.36249773842948, 61.83572959899902, 30.7536232812064, 7.739198889051165, 0.5673156380653381, 1.3756686278751917, 0.5055104345083237, 0.5312378225581986, 0.2752384479556765, 0.45822598891598837, 0.4890386440924236, 0.2713761994881289, 0.8264419191649982, 1.4633242785930634, 5.570527144840785, 5.104633058820452, 5.819688677787781, 6.724932559898921, 11.168494462966919, 7.482013923781259, 6.664404630661011, 8.381935051509313, 9.463535938944135, 11.239089897700719, 16.63766997201102, 15.992241382598877, 14.648551838738577, 15.73035682950701, 23.47711362157549, 35.069611481257844, 53.408627782549175, 34.48048414502825, 26.945145402635845, 26.891062361853464, 30.76236411503383, 23.91455136026655, 15.290410791124616, 20.85116355759757, 16.290847165243967, 12.552328092711312, 14.681305646896362, 7.787408096449716, 6.007003426551819, 8.477669068745204, 6.984599334853036, 6.141695993287223, 3.9816838758332387, 2.336937572274889, 1.663713582924434, 0.7529778555035591, 0.2646293086665017, 0.24765076115727425, 0.2064592886183943, 0.2989020310342312, 0.3623371571302414, 0.180550216031926, 0.50288325548172, 3.0032272594315663, 23.826566321509226, 57.43936811174665, 95.50246851784843, 85.53891154697963, 78.42809731619698, 90.25762775966099, 54.87428426742554, 35.3764647756304, 39.38985545294625, 66.93133694784981, 73.44913632529122, 84.1432477406093, 82.64775221688407, 106.71825068337577, 71.21627017429897, 18.996150868279592, 0.6878251944269452, 0.27245064611945835, 0.140122583934239, 0.1568385519619499, 0.13274636545351573, 0.10395621282181569, 0.33760276436805725, 0.11201368724661213, 0.1282584669866732, 0.10537789296358824, 0.09963116954479899, 0.05566713845889483, 0.1316257377288171, 0.19796335164989742, 0.14495197550526687, 0.1200443934649229, 0.12432836501726083, 0.11549055496496813, 0.11800699707652841, 0.077493408162679, 0.13315895545695508, 0.10139865827347551, 0.181316024224673, 0.12391232805592672, 0.13377422387046473, 0.14786732835429056, 0.10022005651678358, 0.23592822732669966, 0.07978461736014911, 0.16054758722228663, 0.10705671073602778, 0.24891506188682147, 0.24476006627082825, 0.16976696465696606, 0.2261317151465586, 0.1499527921634061, 0.045266686007380486, 0.13772664964199066, 0.2087194344827107, 0.11134030909410544, 0.1731485796294042, 0.1982029287942818, 0.08104322518088988, 0.12202182092836925, 0.12291736501668181, 0.1470635493419, 0.1859692952462605], [0.01966088973650975, 0.03058044352967824, 0.07638462087405579, 0.05798852550131934, 0.09886958183986799, 0.025237602813701545, 0.031853677172745974, 0.050735623974885256, 0.020723590926666344, 0.05179541085713676, 0.04895501237894807, 0.04737071114193116, 0.014371317412172045, 0.009065940310912473, 0.03435268432700208, 0.03475939143182976, 0.06270295966948781, 0.05734555928834847, 0.04048636269622615, 0.035083317264382324, 0.08196521856422935, 0.028442517089258348, 0.0288302336952516, 0.03623220257993255, 0.04192181709887726, 0.0655503368803433, 0.051607076677360704, 0.06352703366428614, 0.006312032995213355, 0.041271712697510204, 0.011479687843737858, 0.01680712920746633, 0.046306601991610866, 0.044184507469513586, 0.03998406357797129, 0.07818091341427394, 0.062391030336064954, 0.09056798408606223, 0.06050003466329404, 0.06537444024745907, 0.0691619005852512, 0.07442440105868237, 5.215453352246966, 45.151579652513774, 64.29726096561977, 65.11139529091972, 40.45500040054321, 39.6280848639352, 31.28547661645072, 34.5230244909014, 47.120931897844585, 57.003243582589285, 66.6701889038086, 60.60780920301165, 43.84911550794329, 23.346635137285503, 3.321283004113606, 0.10698790728513684, 0.27560037853462355, 0.03114631798650537, 0.1745607467102153, 0.1737232580780983, 0.06578299296753747, 0.062139225990644524, 0.15004016033240727, 0.3236950220806258, 1.1645594473396028, 0.6727324043001447, 4.920015513896942, 1.901448803288596, 2.332117476633617, 2.788367028747286, 3.985476723739079, 4.8048169868333, 1.9125752576759882, 4.6984318154198785, 4.864710024424961, 4.8063937936510355, 6.05859466961452, 6.289402970245906, 4.679209189755576, 5.555705768721444, 3.747181304863521, 11.998836330005101, 12.00914398261479, 11.362198080335345, 9.269411955560956, 7.720505629267011, 9.19790804386139, 5.891493533338819, 7.737749321120126, 22.29165540422712, 6.294593274593353, 4.416463494300842, 4.84214357818876, 4.954168081283569, 9.93393245765141, 7.973651954105922, 5.568924282278333, 5.145024240016937, 3.112024975674493, 4.715942578656333, 2.764147562640054, 1.4823205449751444, 0.2047576042158263, 0.2075243443250656, 0.3086148798465729, 0.4384406405900206, 0.11609417971755777, 0.03211669430934957, 0.07923587930521794, 0.12099823728203773, 0.0676260297851903, 0.22048148619277136, 1.4948263253484453, 14.611137526375906, 48.53863539014544, 60.862300872802734, 57.37964487075806, 72.6203065599714, 54.35792541503906, 32.630213601248606, 20.945811918803624, 35.43284593309675, 46.39678716659546, 50.95465605599539, 42.80686834880284, 53.03416504178728, 58.21696186065674, 20.975541523524694, 0.8037211469241551, 0.28290483515177456, 0.04254875970738275, 0.039358566249055524, 0.013631624335955297, 0.06129444989242724, 0.017080209018396478, 0.06432345735707454, 0.055706320463546684, 0.06381644242044006, 0.0369063067649092, 0.03341324920100825, 0.0377017737233213, 0.03948255834568824, 0.007381777378863522, 0.016058067258979594, 0.03726929246581026, 0.011449122385654067, 0.012880793107407433, 0.08037223547164883, 0.045169126242399216, 0.05222668771498969, 0.028094001147629957, 0.029596014746597836, 0.07280479903732028, 0.029047690598028045, 0.07193279332880463, 0.03556918226448553, 0.01797763434504824, 0.0040233046914051685, 0.06383998758558716, 0.025732254842296243, 0.041486764193645546, 0.025265393911727836, 0.03554005614881005, 0.03478797471949032, 0.04857776726463011, 0.027548857631960084, 0.0730448579415679, 0.037267860756920915, 0.03184343807931457, 0.017267810380352393, 0.02015362151100167, 0.0795721137630088, 0.060230513768536706, 0.08130754849740437, 0.024067267309874296, 0.006250679858827165, 0.027638359793594906, 0.06434329772101981, 0.07204303491328444, 0.0080544345879129, 0.004563241298975689, 0.10217898711562157, 0.05665240862539836, 0.03909170860424638, 0.051986883261374066, 0.040710472634860446, 0.037462345856641016, 0.018769705235692005, 0.011754251101852527, 0.026658154891005585, 0.07467258202710322, 0.048778542383973084, 0.06622723662959677, 0.01138391177768686, 0.0659825840432729, 0.027509514475241303, 0.022374570103628293, 0.05064555862918496, 0.09520291430609566, 0.03308362028162394, 0.04741299405161824, 0.026340703978868465, 0.042933902969317775, 0.037232112139463425, 0.027286583491201912, 0.01547308186335223, 0.03634834402639951, 0.024592448325295533, 0.032302456841404946, 0.045440404542854855, 0.06201145784663303, 0.03168220119550824, 0.14002027442412718, 0.03982297597186906, 0.11283900296049458, 0.096848504218672, 9.089540464537484, 63.36881487710135, 83.47647081102643, 83.926589012146, 61.368991306849885, 66.65394401550293, 59.48690496172224, 36.54706253324236, 33.525753021240234, 32.24975109100342, 47.631652287074495, 55.00705739430019, 51.26304142815726, 28.878853389195033, 4.6087605357170105, 0.12630976869591645, 0.479463917868478, 0.08963268463100706, 0.12265322490462235, 0.2608775799827916, 0.4750962150948388, 0.7255773629461015, 1.0290696833814894, 1.748988498534475, 4.000760155064719, 2.5934689726148332, 6.671113984925406, 4.063388177326747, 1.3335886001586914, 1.5483820629971368, 0.6268538289836475, 0.8159148011888776, 1.3355979323387146, 2.5447186742510115, 4.470079268727984, 6.124496161937714, 8.083969371659414, 11.740159239087786, 11.234723823411123, 14.710830279758998, 11.746240649904523, 15.578019312449864, 16.507954052516393, 10.773498926843915, 9.221033385821752, 8.28899507863181, 4.682858731065478, 7.474973661558969, 7.236992648669651, 18.301638466971262, 17.381538902010234, 10.945452077048165, 10.123837147440229, 3.3125350049563815, 1.8480881580284663, 1.4038045981100626, 3.596271642616817, 2.5489455674375807, 1.3766202053853442, 1.1239231250115802, 0.9067070207425526, 1.5311635583639145, 1.192934370466641, 0.6907359468085426, 0.25140096992254257, 0.5209858641028404, 0.5376724515642438, 0.3849498794547149, 0.3745776303112507, 0.14405223807053907, 0.12578308981444153, 0.24181438290647098, 1.6838876775332858, 17.905554669243948, 51.798799651009695, 53.553789547511506, 40.19071871893746, 44.026534284864155, 19.842420612062725, 22.207229580198014, 29.384654453822545, 60.45080770765032, 79.13992636544364, 74.71504252297538, 58.22532401766096, 67.88864585331508, 80.13992500305176, 38.645123209272114, 2.9166974340166365, 0.2797560526856354, 0.01223201269749552, 0.009282661003193684, 0.07608240816209998, 0.059679685825748105, 0.03742080594279936, 0.07851868136120693, 0.028425948960440497, 0.06216694414615631, 0.03704115881451538, 0.009225922753103077, 0.038689208416534324, 0.06388859104897295, 0.04158264797713075, 0.048746854798602204, 0.04941945602851255, 0.03378049949450152, 0.01709774066694081, 0.05292329890653491, 0.05217273400298186, 0.06845808335180793, 0.05006029164152486, 0.04791546958897795, 0.018422738050243685, 0.03471107973850199, 0.03326321153768471, 0.021018941953246082, 0.03646604610340936, 0.019199158530682325, 0.09048455142016922, 0.012548039534262248, 0.021768502624971525, 0.05148718632491572, 0.009264467783006174, 0.03764763002150825, 0.03877214914453881, 0.01612376301948513, 0.061295386270752976, 0.06493072584271431, 0.029870692507496903, 0.009070059018475669, 0.0210391147993505, 0.01043106964789331, 0.01813674402157111, 0.05584993579291871, 0.11836026954863753, 0.07449839530246598, 0.19277630427053996, 0.0936131135427526, 0.138638559994953, 0.13350442477634974, 0.08097393997013569, 0.2547299712896347, 0.1831301554505314, 0.0878271097317338, 0.2075477402125086, 0.12869526711957796, 0.08750124328902789, 0.09867678968501942, 0.15720506943762302, 0.1672684901526996, 0.17321024489189896, 0.13735967076250485, 0.11760617287031241, 0.08652786444872618, 0.21754904783197812, 0.148075652175716, 0.11757193399327141, 0.16106334168996128, 0.2042994573712349, 0.16352617953504833, 0.15352753177285194, 0.16324555102203572, 0.08142985443451575, 0.08276935720017978, 0.10710924970252172, 0.13234749542815344, 0.1459534524806908, 0.08931067905255727, 0.1248794033059052, 0.20932552910276822, 0.11649448823715959, 0.16430724119501455, 0.2859717048704624, 0.14784980858010904, 0.17923738647784504, 0.11695134586521558, 12.57477685383388, 78.74852739061627, 99.84660039629254, 91.34832123347691, 56.1560115133013, 56.37288563592093, 42.002541405814036, 49.997659819466726, 77.14177731105259, 88.25703988756452, 102.17164829799107, 89.42567130497524, 68.55131639753068, 39.94247695377895, 6.56247455733163, 0.4253988175519875, 0.7591188145535332, 0.12732210223163876, 0.9570914485624858, 0.4279345300580774, 0.20531139735664639, 0.3046564965375832, 0.4312074030084269, 1.5383459329605103, 4.195340113980429, 5.1672563041959485, 11.565971374511719, 7.044220524174826, 7.530072007860456, 12.605454887662615, 14.178616506712777, 12.862241200038365, 11.059635298592703, 13.20340383052826, 17.41140399660383, 15.776822907584053, 19.19998322214399, 16.796981743403844, 18.515524864196777, 14.923186336244855, 17.565963200160436, 30.727220126560756, 28.020141158785137, 31.758218152182444, 28.270726203918457, 23.73916666848319, 23.32797748701913, 23.886164494923182, 21.95792474065508, 44.53594146456037, 23.611422300338745, 16.18723562785557, 22.0844566481454, 18.928537947790964, 27.336721556527273, 21.784553289413452, 22.273195777620586, 17.514487470899308, 13.257979324885778, 16.67544732775007, 11.745359097208295, 10.096919826098851, 7.282063007354736, 3.2140351704188754, 1.3157133821930205, 0.6571317442825862, 0.44424301066568916, 0.1595573060746704, 0.28610885036843164, 0.3559025009827954, 0.21218817335154327, 0.4354373360318797, 3.4431869770799364, 24.92607705933707, 73.28278950282505, 87.76528113228935, 83.2069501876831, 110.34929588862828, 77.24752194540841, 48.77850457600185, 27.65441230365208, 45.45340245110648, 64.80695302145821, 74.37225314549038, 63.26246574946812, 77.30531706128801, 95.61981664385114, 51.02323477608817, 4.740078883511679, 0.38819113267319544, 0.10210580032851015, 0.09080298790442091, 0.17347021879894392, 0.1004390265526516, 0.08597821715687003, 0.14779256736593588, 0.12633365312857286, 0.12585097045770713, 0.1481867419289691, 0.1082894392311573, 0.08418158534914255, 0.14254981226154737, 0.12647961958178452, 0.203176454773971, 0.14702374647770608, 0.12663285993039608, 0.061536076212567944, 0.19605915168566362, 0.18654811275856836, 0.16988600684063776, 0.21656540275684424, 0.12578299481953892, 0.149444080889225, 0.10332243397299733, 0.15848478648279393, 0.10093745802130018, 0.14799254520663194, 0.07195041488323893, 0.14930002790476593, 0.07905497508389608, 0.16389174706169538, 0.11665904654988221, 0.09533042460680008, 0.11795941820102078, 0.12385577894747257, 0.09482037661863224, 0.17315137519368104, 0.12437432897942406, 0.06217326809253011, 0.09479725214519671, 0.1260395081979888, 0.13646745149578365, 0.15027116079415592, 0.1322047859430313], [0.037473182060888836, 0.05612690360950572, 0.02432978741957673, 0.03210554597899318, 0.05827738464410816, 0.06457284611782857, 0.01419716970329838, 0.06707910341875893, 0.03829406015574932, 0.023714827739500573, 0.034053151828369925, 0.014233639264213187, 0.04211463978780167, 0.047382229273872714, 0.025146560377574394, 0.035169918688812425, 0.006019948266579637, 0.0673075933009386, 0.02682072339978601, 0.05696869415364095, 0.010001735096531255, 0.03866335962499891, 0.012241795476126884, 0.024289468868768642, 0.04601777677557298, 0.006893582883224423, 0.015442140666501862, 0.003059113003213757, 0.011284849057639284, 0.03276707351739917, 0.04375259278874312, 0.03259128884279302, 0.08296966752303497, 0.054098331569028754, 0.06518556323966809, 0.03792285739577242, 0.026697864456634437, 0.026989588713539497, 0.07138541912926094, 0.11234032043388911, 3.7175785047667365, 37.834949357169016, 64.97993537357875, 66.99271733420235, 63.50039291381836, 61.92069911956787, 75.77396188463483, 69.25030517578125, 50.070685386657715, 62.17082732064383, 43.80895839418684, 46.029223987034385, 36.85601765768868, 21.488172667367117, 3.7465147120612006, 0.2528991752437183, 0.2792134960847241, 0.012204336102253624, 0.00862826656417123, 0.07515491864510945, 0.032878142914601734, 0.12048582120665483, 0.16879095988614218, 0.6925529007400785, 1.2755012256758553, 0.932642149073737, 4.423908923353467, 4.820907277720315, 5.310717931815556, 9.518295560564313, 6.5938825862748285, 4.2552600758416315, 7.031673814569201, 6.165969959327152, 4.230245692389352, 5.701233182634626, 6.892532229423523, 5.36446224791663, 8.099113839013235, 7.3022414445877075, 4.352544844150543, 11.703319021633693, 5.948408833571842, 8.404445477894374, 8.435513479369027, 9.95294794014522, 11.588275960513524, 7.624942711421421, 5.294864313943045, 4.281671481473105, 9.651235444205147, 3.5113336060728346, 5.20898414509637, 7.2973507813044955, 9.39264520577022, 4.103390693664551, 3.22868674993515, 3.805489718914032, 3.6475159100123813, 5.472524975027357, 3.7109403695378984, 3.1206103435584476, 2.0245202907494138, 1.9568168265478951, 1.54825992669378, 0.6295079865625927, 2.973490055118288, 2.9040252225739613, 0.201259511922087, 0.2116380985826254, 1.7091324371950967, 0.0491919059173337, 0.08718896111739532, 0.03268155774899891, 0.015073024401707309, 0.20454914468739713, 5.549460206712995, 30.581408705030167, 59.314033780779155, 48.43900864464896, 63.028512954711914, 78.90216595785958, 63.064949308122905, 31.110937867845806, 22.71339542525155, 34.0775476864406, 62.719429288591655, 62.2533232825143, 46.40622282028198, 51.09713929040091, 30.658293996538433, 10.102620823042733, 0.389798744980778, 0.06253520545682736, 0.0039894072022954264, 0.05559450128514852, 0.01672965068636196, 0.004683055316231081, 0.03072568055774484, 0.059457981293754916, 0.04670642535867436, 0.014999293090243424, 0.06188651919364929, 0.03136958654171654, 0.04390382128102439, 0.08072938916406461, 0.03548397522951875, 0.042408296173172336, 0.06413033272006682, 0.03454499811466251, 0.03211943559082491, 0.027116915809788873, 0.007608900861149388, 0.021945354295894504, 0.028759917111269066, 0.05771201569586992, 0.015511430966268693, 0.08461889438331127, 0.057233743502625396, 0.07604310741381985, 0.06645852207605328, 0.0059325639823717725, 0.02251306758262217, 0.08458428231201001, 0.019066060494099344, 0.024854973524010608, 0.0467198569593685, 0.008955635113774665, 0.01897863295328404, 0.03625685714983514, 0.02188824030703732, 0.031843000424227545, 0.0588615761537637, 0.03469563628147755, 0.04579531228435891, 0.08678107336163521, 0.035172442839081795, 0.040017169301531146, 0.039462819761995754, 0.012569342989341488, 0.04304954229987093, 0.05974371239010777, 0.039674536258514435, 0.029511744089956795, 0.01954918590906475, 0.040947654550629, 0.025283057874600803, 0.02042035193049482, 0.02370061582353498, 0.026817870160032595, 0.023910042264365723, 0.02366270437570555, 0.013752174563705921, 0.02741939145406442, 0.013580195622385612, 0.03440228523686528, 0.00563603569753468, 0.029111252365899936, 0.04266021926222103, 0.039772974726344855, 0.04561252173568521, 0.043173137453517745, 0.043417739149715216, 0.010799328414058047, 0.028391652407922914, 0.02396546839736402, 0.04886236520750182, 0.04289202718064189, 0.0415608364689563, 0.03891163219564727, 0.011248378648555704, 0.05526071633877499, 0.09400679277522223, 0.06525476024086986, 0.18714892837618077, 0.1524177741791521, 7.079736241272517, 52.134852749960764, 85.92849009377616, 85.0796286719186, 79.2904451915196, 98.38522747584751, 90.2238803591047, 43.169546944754465, 33.211034366062705, 39.209105014801025, 39.17455857140677, 41.88415799822126, 44.42828260149275, 28.258662394114904, 5.771991465772901, 0.14726413786411285, 0.40451690235308235, 0.04757530302075403, 0.11274531084511961, 0.14720676094293594, 0.6555992322308677, 0.7769850215741566, 1.3072308259350913, 2.2330650431769232, 1.5766992292233875, 1.0594055184296198, 1.1421710486922945, 1.7261156801666533, 1.7230126581021716, 1.9890857807227542, 4.2939819523266385, 7.989037871360779, 11.546158586229597, 7.160130373069218, 4.427403432982309, 0.6716571162853922, 1.1571377941540308, 1.8554235015596663, 3.188265387501035, 4.083024220807212, 10.267260125705175, 20.91469614846366, 14.798094442912511, 20.49728659221104, 9.184017726353236, 3.6543095111846924, 1.7200762842382704, 3.008968208517347, 2.202713791813169, 1.5141892177718026, 1.8027403056621552, 3.9781898004668097, 4.640389169965472, 3.7980047719819203, 0.44598106454525677, 1.4594458809920718, 0.4584009423851967, 5.2734169619424005, 7.393769196101597, 10.473762324878148, 7.044759443828037, 7.4657047646386285, 5.913270924772535, 6.500658171517508, 7.146738588809967, 5.438857044492449, 3.20855456164905, 1.8168174645730426, 0.6525252514651844, 0.8448351579053062, 5.741759853703635, 0.5764312403542655, 0.5594674849084446, 0.05887500436178275, 0.19810758105346135, 0.12365295125969819, 5.738007392202105, 36.2774133682251, 60.793742997305735, 41.11324494225638, 43.47577837535313, 39.10537188393729, 20.660654374531337, 22.421030861990793, 35.154105050223215, 63.71499497549874, 89.82639476231166, 96.83552210671562, 67.07754094260079, 69.62357630048479, 49.801647663116455, 17.768847124917166, 0.21517207180815084, 0.10837400505053145, 0.008493363624438643, 0.049770838780594726, 0.019666362121435146, 0.03128337188224707, 0.04066960447068725, 0.012462951242923737, 0.04921597016177007, 0.00562503918938871, 0.023062292486429214, 0.04955926477642996, 0.012667980776833636, 0.10727866632597786, 0.0041474689662988696, 0.029198949624385153, 0.03144204729635801, 0.005341425122294042, 0.045132115549807034, 0.020090186968445778, 0.024064434426171438, 0.04838858152340565, 0.00464800262125209, 0.01594651610191379, 0.024068933113345077, 0.06894648607288088, 0.03658732405996748, 0.07138392635221992, 0.07350895553827286, 0.019298584266964878, 0.014745707590399044, 0.03465573163703084, 0.040734642052224705, 0.013093007478996046, 0.04054130367668612, 0.04708093597686716, 0.04631132120266557, 0.009032939760280507, 0.024284074515370385, 0.04687440688056605, 0.01652090108421232, 0.05325847824237176, 0.06208942152027573, 0.03861499364886965, 0.13658985921314784, 0.15122982220990316, 0.12256608743752752, 0.06957252962248665, 0.18178950596068585, 0.2115415430494717, 0.15640192824815, 0.16575508564710617, 0.08868601292903934, 0.10602351224848203, 0.09460290614515543, 0.14401563789163316, 0.1095145952754787, 0.10054396199328558, 0.08030396127807242, 0.09552822435008627, 0.08063881830977541, 0.13900779161070073, 0.1288087995988982, 0.08646430607352938, 0.24191545748284884, 0.11113210062363318, 0.13356344375227178, 0.13121617399156094, 0.09928453993052244, 0.10999954425330673, 0.13059608797941888, 0.08469134835260254, 0.06756595907998936, 0.07911063531147582, 0.09889115246811084, 0.1502973793872765, 0.18004761157291277, 0.16194380873015948, 0.08922467473894358, 0.245257812419108, 0.20852237434259482, 0.21840382553637028, 0.31080812215805054, 0.2589132753866059, 9.013489825384957, 64.53850936889648, 102.25683321271623, 95.76046207972935, 90.56515502929688, 87.38613877977643, 102.95868464878627, 84.04728616986955, 70.44382504054478, 90.45249693734306, 64.69865839821952, 65.46576731545585, 58.64323384421212, 38.13353429521833, 7.46718646798815, 0.7094234526157379, 0.6200553423592022, 0.10668557922222785, 0.30575759602444513, 0.25658644310065676, 0.6811291394489152, 0.26980131970984594, 1.4306006516729082, 2.301790543964931, 6.90154230594635, 6.632664825235095, 11.39674539225442, 15.731531075068883, 14.459924748965673, 24.64577283178057, 21.093577521187918, 18.150113889149257, 19.8901686327798, 16.05825448036194, 12.109458599771772, 15.98677315030779, 15.69394132069179, 18.761228799819946, 22.10198869024004, 21.343870741980417, 15.610347543443952, 28.547318356377737, 21.431822776794434, 24.306572198867798, 29.368055207388743, 24.824320690972463, 24.83157808440072, 23.410687105996267, 17.54508212634495, 17.42155531474522, 27.590372494288854, 18.989207880837576, 17.541783469063894, 22.79008616719927, 28.493893657411846, 17.96843934059143, 17.686424119131907, 17.45406767300197, 11.34640656198774, 13.943675330707006, 9.394322327205114, 11.946820378303528, 9.61138926233564, 6.991975281919752, 7.058024857725416, 5.673298818724496, 10.542874319212777, 7.22934181349618, 2.298645181315286, 0.7841055137770516, 3.1937006158488135, 0.3799949996173382, 0.2087442417229925, 0.14741159709436552, 0.350931987698589, 0.6104336072291646, 9.640269449778966, 49.21324641363961, 93.65396281651088, 69.575772694179, 96.10078484671456, 104.242586680821, 91.21949468340192, 51.74712242398943, 31.12225648335048, 47.23780754634312, 85.42273071834019, 90.61662033626011, 69.47526700156075, 83.12603841509137, 68.97294003622872, 24.591177361352102, 0.6746193287628037, 0.21069082298449107, 0.11504411963479859, 0.19363824730472906, 0.18719633083258355, 0.1422135303063052, 0.10614766380084412, 0.11648969777992793, 0.15244064080928052, 0.09340579395315476, 0.1539951373956033, 0.14519209547766618, 0.07345377707055636, 0.28655052238277023, 0.1200384223567588, 0.09001598906304155, 0.09663245866873435, 0.11774364406509058, 0.0975772033312491, 0.11381980497390032, 0.10781569286648716, 0.09832028738622155, 0.07983660671327795, 0.139466114874397, 0.1065020626410842, 0.19900688422577723, 0.18186075213764394, 0.13426086918583938, 0.17052659818104335, 0.11319223472050258, 0.08355247482125248, 0.13873211640332425, 0.1627818401902914, 0.12221554267619338, 0.07839241277958665, 0.195639165650521, 0.0942118867699589, 0.12679942670677388, 0.1515026611409017, 0.10897713447255747, 0.17536105162331037, 0.12958787993660995, 0.20644164670790943, 0.1298212009881224], [0.04989165533334017, 0.016570188171629394, 0.015544813192848648, 0.023886602272146513, 0.026914622468341674, 0.02178184092710061, 0.028962341070707356, 0.012235552953955318, 0.03421057534537145, 0.01176990829740784, 0.0076247455020036015, 0.016177192563191056, 0.0758193808474711, 0.05809626329158034, 0.008316148089111915, 0.07159676921686955, 0.02373530762270093, 0.032268411346844265, 0.04350358061492443, 0.04409599596900599, 0.07222946919500828, 0.012685908520195101, 0.08454776355730635, 0.060524482280015945, 0.03728727703647954, 0.05436956915738327, 0.053222610881286006, 0.0030811789620202035, 0.03508644870349339, 0.039873231668025255, 0.014623832523024507, 0.07878390712929623, 0.022869958342718225, 0.012365029309876263, 0.035452908503689935, 0.02335757396316954, 0.10450037755072117, 0.11028825411839144, 4.455511501857212, 34.13129200254168, 77.52620724269322, 79.38906792231968, 63.19128840310233, 68.4256512778146, 46.48017944608416, 26.49860552379063, 30.58249957220895, 76.40099511827741, 92.75746454511369, 39.64876617704119, 44.38557202475411, 27.2124981880188, 7.38948563167027, 0.3200246090335505, 0.27701083570718765, 0.02095035054454846, 0.11025780825210468, 0.09087859706154891, 0.07985933085105248, 0.06730688083916903, 0.21201711467334203, 0.5042023275579725, 1.7034105956554413, 2.6978198417595456, 8.369837369237628, 5.397693744727543, 4.896806359291077, 4.600669792720249, 21.86286817278181, 31.70683969770159, 53.74729340417044, 64.32617936815534, 73.51813888549805, 75.2411948612758, 61.4564482825143, 39.24926560265677, 16.17048352105277, 3.6793972849845886, 3.9489231194768633, 6.224089469228472, 9.76295552934919, 11.342440009117126, 8.932149870055062, 12.30314224106925, 10.744895798819405, 1.8615116434437888, 4.1978888000760755, 4.516025100435529, 2.8170609176158905, 2.9797671011516025, 1.9156750227723802, 12.739574228014265, 18.79458883830479, 8.366312895502363, 7.359036888395037, 5.134220225470407, 20.030567407608032, 51.47998850686209, 74.37935420445034, 86.35823617662702, 87.9659173148019, 81.63556643894741, 74.62830121176583, 82.67088276999337, 93.07138415745327, 94.09554862976074, 70.63951410566057, 29.546405042920792, 0.36166676453181673, 5.487097953047071, 18.72965097427368, 1.8174114269869668, 0.21747520965124878, 0.23080224809902056, 0.05955644351031099, 0.1505617502012423, 0.2220446951687336, 0.24273615915860447, 10.396864005497523, 41.16101380756923, 36.30449397223336, 44.679713589804514, 72.89555944715227, 97.2045270374843, 50.154199259621755, 20.818376745496476, 17.80061776297433, 24.088423081806727, 42.41717168263027, 50.615931374686106, 54.20139292308262, 44.26143898282732, 13.298656685011727, 0.9900734616177422, 0.09413931066436426, 0.06117863753544433, 0.03935052560908454, 0.07094229504998241, 0.09852880798280239, 0.03900325817189046, 0.03260055423847266, 0.026471559457214813, 0.03380968328565359, 0.06536215197827135, 0.034571779891848564, 0.04154876533097454, 0.03095068276992866, 0.022848570918930427, 0.0488181959704629, 0.009681491164623626, 0.09510631806084088, 0.07123536789523703, 0.09875041073454277, 0.018872445615540658, 0.05061875988862344, 0.012418122130579181, 0.04928469218845878, 0.04484776866489223, 0.05334264711876001, 0.05095275178817766, 0.02266747161879071, 0.09259613882750273, 0.023074707980932932, 0.00862844128693853, 0.09111510722764901, 0.02900943818635174, 0.01664240804633924, 0.04490058922341891, 0.01263918205430465, 0.08317060888345752, 0.04200113444988217, 0.027476530887984803, 0.04077443813106843, 0.04100156755053571, 0.038593202496745756, 0.06922181522739784, 0.035178617507751496, 0.0650777779519558, 0.025690494404573525, 0.02724934888205358, 0.017314559746799723, 0.0693494544497558, 0.03309410364766206, 0.006671649769746831, 0.016356529368619834, 0.04262703211445894, 0.05684027461601155, 0.04058734227770141, 0.05189359487433519, 0.015613531826862266, 0.0065740378423860026, 0.03425941629601376, 0.010646973553645824, 0.015058744632239853, 0.024146635551005602, 0.05596264045951622, 0.030246298959744827, 0.019814282755500505, 0.03331529927839126, 0.06272574487541403, 0.017517384041899016, 0.06538786845547812, 0.023587023972400596, 0.03735430611829672, 0.1097024069832904, 0.06061109048979623, 0.019627717855785574, 0.025886356930381486, 0.024930097528600266, 0.038083307178957124, 0.0946159204468131, 0.11602519984756197, 0.03624994627067021, 0.04940619066889797, 9.329840438706533, 46.842486313411165, 97.98822130475725, 102.78643185751778, 80.996401650565, 96.70396491459438, 87.90170901162284, 48.99963794435774, 45.96282352719988, 75.49608952658517, 62.74454007829939, 39.45705148151943, 48.63016748428345, 35.97620895930699, 11.09913580758231, 0.2086612433195114, 0.3771669470838138, 0.00821318379270711, 0.09129226593566792, 0.2771889647202832, 0.6925723882658141, 0.9456831578697477, 0.9235391403947557, 0.5168146107878003, 1.0740969415221895, 2.918056241103581, 0.6896543619888169, 1.2601222566195895, 6.192338372979846, 11.864146368844168, 27.903477430343628, 42.804436479296, 68.53064550672258, 79.75004073551723, 85.16204125540597, 88.13167354038784, 75.75256838117326, 51.48332016808646, 23.972280468259537, 7.469180600983756, 0.20852872543036938, 1.3233211168221064, 1.4037728969539915, 8.69420794078282, 15.204143694468907, 5.006602227687836, 1.093633538910321, 1.13254833647183, 1.5378954942737306, 3.5273793850626265, 3.620686092547008, 3.1615128687449863, 1.1844697275332041, 2.1908163045133864, 2.7062223851680756, 0.5659167702708925, 2.6343332827091217, 10.13873929636819, 30.195554392678396, 66.42040811266217, 91.51388985770089, 104.06480312347412, 105.81040600367955, 97.34187902723039, 89.04481274741036, 95.935973576137, 107.71453203473772, 106.594329561506, 86.15397998264858, 41.09031241280692, 4.084929330008371, 3.1768038996628354, 9.039406606129237, 0.6231066871966634, 0.6676579394510814, 0.2979456494961466, 0.2797508143952915, 0.005983502030306096, 0.7178034686616489, 0.07421971418495689, 11.384358491216387, 50.971783365522114, 41.75955595288958, 47.21262380055019, 64.29234164101737, 65.66099779946464, 30.38172789982387, 21.610488755362375, 36.79999433244978, 44.385902064187185, 72.75257246834892, 76.72218254634312, 69.05380317143032, 66.4102428981236, 29.055156980242046, 0.8637344209211213, 0.2604996631188052, 0.01815791940316558, 0.05309336353093386, 0.03300844877958298, 0.017199453066236207, 0.06061348571841206, 0.03381983416953257, 0.03558167748685394, 0.044883252653692446, 0.06613205852253096, 0.014285908513037222, 0.050449750386178493, 0.03234637502048697, 0.020955568478841866, 0.02403550169297627, 0.03878651712355869, 0.053904986408139975, 0.07447029716734375, 0.036085316711770635, 0.032713645670030794, 0.07476164653365101, 0.04122384205194456, 0.0463961482580219, 0.01131783179672701, 0.04740329100085156, 0.03374080180323549, 0.051909852573382, 0.08542926875608307, 0.01210741840103375, 0.029753838599260365, 0.06213159925703492, 0.05852021875658205, 0.03480404582140701, 0.10219840678785529, 0.008509075102795447, 0.016693949566355774, 0.04069452027657202, 0.0741711107215711, 0.03727090059380446, 0.06236288470349141, 0.08184536892388548, 0.029712590455476726, 0.08813508999134813, 0.10010826108711106, 0.15787865115063532, 0.1536968398307051, 0.09320999588817358, 0.17588010377117566, 0.08890384981142622, 0.10705711785703897, 0.09535445153181042, 0.1313811665666955, 0.15534616847123417, 0.0927336100222809, 0.1769990622997284, 0.11898741232497351, 0.07367765291460923, 0.16056810612125055, 0.10782344173640013, 0.14544147066771984, 0.14086830749043397, 0.09034999114062105, 0.1322568567203624, 0.1430161150970629, 0.18038421922496387, 0.21506351977586746, 0.1737156720565898, 0.204313760889428, 0.13228513805993966, 0.21973018507872308, 0.24649608454533986, 0.19235375337302685, 0.13299275508948735, 0.09532891147370849, 0.07939479220658541, 0.09924651482807738, 0.2104002742895058, 0.3662644906767777, 0.34890126809477806, 0.11356415333492414, 12.256685716765267, 60.9311922618321, 114.19138567788261, 112.62019647870744, 83.24088518960136, 99.59920283726284, 67.52729783739362, 38.62887484686715, 36.41236822945731, 94.66626671382359, 138.71675491333008, 59.38841424669538, 70.46651785714286, 47.78357812336513, 14.225251947130475, 0.6946710699370929, 0.5236992442182132, 0.1127987794045891, 0.1788609488201993, 0.25361361833555357, 0.3533177711069584, 0.5487467401794025, 1.3201856336423328, 4.426212251186371, 8.18002734865461, 13.942368200847081, 18.157407760620117, 15.703203269413539, 17.795661960329326, 13.514730027743749, 31.612639495304652, 39.4273270879473, 64.65244592939104, 74.80582073756626, 81.5559331348964, 83.5124624797276, 71.57627023969377, 46.015428338732036, 21.393456561224802, 11.216462220464434, 13.623903598104205, 24.661302055631364, 21.655641623905726, 31.788314274379186, 27.177100590297155, 29.45533847808838, 33.52833775111607, 17.983023609433854, 12.539657184055873, 8.715245349066597, 5.621262890951974, 6.202081484454019, 9.463137286049978, 30.160952363695415, 41.019729137420654, 25.215330566678727, 20.51916994367327, 10.044373205729894, 22.2307961327689, 58.54446520124163, 84.96351732526506, 99.54374926430839, 101.80603408813477, 91.35146181924003, 83.50903006962368, 90.82826941353935, 103.51452663966587, 101.29793316977364, 75.52402823311942, 32.24412652424404, 3.2031354010105133, 13.15336377280099, 29.764331817626953, 3.021706427846636, 0.3984054188643183, 0.492879966539996, 0.36763863265514374, 0.18857515470257827, 0.6648991789136613, 0.7903900508369718, 16.28450867107936, 68.37343556540353, 53.50094502312796, 66.30304609026227, 95.11164624350411, 124.92405264718192, 73.84838676452637, 31.94507258278983, 25.088783025741577, 34.89561121804373, 64.44049807957241, 74.7622138432094, 82.20442240578788, 85.23501123700822, 40.72812713895525, 1.7263715692928858, 0.2812730941389288, 0.13782042318156787, 0.14541711126055035, 0.18735181034675666, 0.1382088301969426, 0.11408976013106958, 0.09909800386854581, 0.14373731639768395, 0.1102362172678113, 0.19029833509453706, 0.14404230431786605, 0.11764035746455193, 0.08374238998762198, 0.08976689885769572, 0.19702549411782197, 0.1381477349038635, 0.15485253424516746, 0.13252946494945458, 0.14088015471185955, 0.10981619730591774, 0.1169541957122939, 0.11975376334573541, 0.1050785436694111, 0.10744257324508258, 0.1667358401630606, 0.12836815895778791, 0.10669784713536501, 0.2337397076189518, 0.08786946388759784, 0.11294068143303905, 0.1428966929337808, 0.12454472269330706, 0.14025355476353848, 0.15621374334607804, 0.09530514239200524, 0.17491899962936128, 0.15940200297960214, 0.11933482225452151, 0.11330612003803253, 0.19058303481766156, 0.07436270186943666, 0.09736723745507853], [0.06801316794008017, 0.056450100016913245, 0.03032686820785914, 0.045780900200562816, 0.01842901449916618, 0.08853248081036977, 0.07314659069691386, 0.07948210609278508, 0.03156582565445985, 0.0722314640879631, 0.024344058707356453, 0.08139457739889622, 0.04382329274501119, 0.1123885710590652, 0.061224180805896006, 0.05106530039172087, 0.021676055621355772, 0.01762182924098202, 0.008816802608115333, 0.034084673172661235, 0.11089734786323138, 0.031196465117058585, 0.024248554903481687, 0.03129169750692589, 0.02683484710619918, 0.00581614306429401, 0.010327147768943437, 0.059682060698313374, 0.02452539719109024, 0.00948351585040135, 0.032430733886680434, 0.024480116852958287, 0.03865970910659858, 0.11409545982522623, 0.09036124803658042, 0.22256836135472569, 1.9859758104596819, 28.966873168945312, 81.66278948102678, 91.22114835466657, 71.33186735425676, 64.80784933907645, 56.58051865441458, 34.92216028485979, 18.966033901487076, 41.21273619788033, 51.81336654935564, 26.781213079180034, 31.254074232918875, 32.981288705553325, 16.001970597675868, 1.24368032174451, 0.31608256484780994, 0.04758084325918129, 0.11847392416426114, 0.2466463121984686, 0.15753035912556307, 0.010379110828840306, 0.07817060646734067, 0.6210740676948002, 0.7161252615707261, 4.806485423019954, 6.42377461705889, 13.620128989219666, 20.686927250453405, 44.2630683353969, 75.37457942962646, 93.52524743761334, 110.45304638998849, 114.37166363852364, 112.63883154732841, 107.88806329454694, 110.28390639168876, 105.66444519587925, 116.65790585109166, 112.67314870016915, 111.84413133348737, 70.26032311575753, 23.932403019496373, 1.3201000839471817, 4.000435761043003, 20.33870611871992, 15.135696990149361, 18.209258692605154, 3.8641281723976135, 2.2372126834733144, 13.479911736079625, 39.71528475625174, 52.839431353977744, 35.163210664476665, 8.169523409434728, 0.9200228090797151, 0.35141779163054054, 2.6672284432819913, 11.841388412884303, 68.35540499005998, 105.39840562002999, 116.43042877742222, 108.07852731432233, 111.9375776563372, 109.30512060437883, 118.02061435154506, 105.41726303100586, 107.00084781646729, 110.91898563929966, 108.23479230063302, 116.05985355377197, 127.21416500636509, 96.99637290409633, 17.40221152986799, 1.0524813128369195, 4.7952649508203775, 3.3411131628922055, 0.34678806577410015, 0.023202515140708004, 0.3008864474083696, 0.08093775369759117, 0.07662116496690682, 0.21332452951797418, 2.5814431607723236, 32.4377623966762, 35.528838770730154, 39.38809061050415, 68.52015372685024, 78.58600902557373, 70.08650003160749, 66.28629398345947, 71.18899849482945, 30.143276146480016, 39.21272850036621, 39.46008784430367, 46.28307294845581, 43.05096551350185, 22.931693928582327, 3.0224841918264116, 0.12015521180416856, 0.020011500655008212, 0.03785648310024824, 0.014457491359540393, 0.04488702530839613, 0.06474930593477828, 0.06274406532091753, 0.023246708126472573, 0.011524671322799154, 0.032887275995952744, 0.0475762733258307, 0.006970122481496739, 0.020032313020367707, 0.09669169477586236, 0.009444494997816426, 0.036862615895058425, 0.07547513289111, 0.03574099750923259, 0.06597875032041754, 0.03214954897495253, 0.07805554728422846, 0.03014578078208225, 0.013394924180049981, 0.02317069693734603, 0.04289765902129667, 0.0324481213465333, 0.02930747451526778, 0.03384021736149277, 0.05122752793665443, 0.0699642886008535, 0.020391687218632017, 0.02843835766959403, 0.008898086014336773, 0.04352754647178309, 0.0234091782476753, 0.10547815329794373, 0.045142408926039934, 0.14063044025429658, 0.18183712554829462, 0.10123986072306122, 0.0671250063127705, 0.014397249324247241, 0.018423593004367182, 0.062356065426553996, 0.08162038706775222, 0.027739709176655327, 0.06894348694809846, 0.03873367960165654, 0.0807833598394479, 0.009670147755449372, 0.01564886823429593, 0.03300240303256682, 0.03653601324185729, 0.012717735205244805, 0.02260892592104418, 0.04435982395495687, 0.06489168293774128, 0.06303248341594424, 0.05329527858910816, 0.034218805975147655, 0.061765074996011596, 0.03284590232319065, 0.031203111367566243, 0.06384994847966091, 0.0648712929604309, 0.0610260825072016, 0.03188760731635349, 0.027775318694433997, 0.061116748356393406, 0.03378719324246049, 0.07452223902302128, 0.015619770956358739, 0.07758162450045347, 0.08574300977800574, 0.013379278858857495, 0.13736740606171743, 0.11217519215175084, 5.130674472876957, 45.27248525619507, 101.32657364436558, 110.96538570949009, 89.94847461155483, 84.40417344229562, 93.04916381835938, 70.98771612984794, 29.996749060494558, 22.686683075768606, 26.22910053389413, 27.371851648603165, 38.20016057150704, 41.173902715955464, 20.502509900501796, 1.378286361694336, 0.5969030218464988, 0.09590951353311539, 0.09299269504845142, 0.1431208944746426, 0.6593055533511298, 0.7853527697069305, 0.8214947474854333, 0.5700606650539807, 1.065783639039312, 6.018734157085419, 10.819264105388097, 20.397208213806152, 31.18070125579834, 59.88958781106131, 88.54441043308803, 106.74057524544853, 119.5998009272984, 121.61872509547642, 114.68977301461356, 110.81558949606759, 111.46431500571114, 109.49031094142369, 115.80966976710728, 117.87809290204729, 118.58072253635952, 86.19713524409703, 34.80385330745152, 4.740386341299329, 1.4279151729175021, 0.7003298348614148, 1.7636092454195023, 1.2231425323656626, 1.0933075164045607, 2.670414843729564, 22.04718824795314, 55.434746810368125, 71.52276911054338, 52.252881799425396, 13.539758307593209, 1.6841377041169574, 1.0729966291359492, 3.569666338818414, 20.693797281810216, 82.06934247698102, 113.70142650604248, 118.08692795889718, 109.77948107038225, 110.39518874032157, 110.32494940076555, 117.74263082231793, 102.57941722869873, 105.64255142211914, 113.28689697810582, 108.85319587162563, 119.38440677097866, 132.14015987941195, 114.33022458212716, 27.909055096762522, 2.2779239160673956, 2.1604891547134946, 0.7890602307660239, 0.3000660171466214, 0.05715940320598228, 0.2612074022846562, 0.1544995874698673, 0.020245563006028533, 0.2411263755389622, 2.312478393316269, 37.86952011925833, 39.804770605904714, 42.633896418980186, 70.39460400172642, 62.38289328983852, 40.68532623563494, 49.34690890993391, 39.052958147866384, 37.25325311933245, 66.93884795052665, 63.41954367501395, 67.17486436026437, 61.06280503954206, 44.356104714529856, 6.237287138189588, 0.16685169323214463, 0.060326370410621166, 0.04170734575018287, 0.043737380033625026, 0.03765225763033543, 0.01081366925167718, 0.007915025327487715, 0.06866404587136847, 0.0852004871038454, 0.07218405484621014, 0.05658277736178466, 0.03952868854893105, 0.07551057956048421, 0.08522296696901321, 0.02323097798840276, 0.05021682967032705, 0.09597845269101006, 0.025561689798321043, 0.08085196651518345, 0.05685547040775418, 0.06322526200009243, 0.028265336328851323, 0.0320599009282887, 0.04146508499979973, 0.017498639512008855, 0.02859585073643497, 0.017727234567116414, 0.04249087388494185, 0.05074272484385541, 0.05880507454276085, 0.030851582730455056, 0.03434570898701038, 0.017373210617474148, 0.052666768564709594, 0.024672047268333178, 0.0686744749546051, 0.06981429164963109, 0.08484155564968075, 0.1565856755312, 0.13720503263175488, 0.07337313318359, 0.14249987208417483, 0.09041882173291274, 0.15108804910310678, 0.19072393939963408, 0.12822825860764298, 0.09524850507399865, 0.09220418985933065, 0.13914674201181956, 0.082990444265306, 0.10656726307102612, 0.1552036896880184, 0.12876352774245398, 0.181730093434453, 0.20037516366158212, 0.16983534741614545, 0.13805842612470898, 0.10402114183775016, 0.09274376090615988, 0.09432099520095757, 0.16537035629153252, 0.19526002742350101, 0.153220766090921, 0.10578462720981666, 0.14267307493303502, 0.207883411486234, 0.13318236491509847, 0.18287205430013792, 0.15378115459212235, 0.08526265448225395, 0.1670042143336364, 0.12751384265720844, 0.14051473646291665, 0.18620894024414675, 0.15623963624238968, 0.20370728628976004, 0.4602543200765337, 6.621199429035187, 58.54069927760533, 121.77280834742955, 122.38982227870396, 90.071930204119, 88.04575211661202, 78.02902058192662, 50.148873465401785, 29.724761826651438, 62.43160711015974, 81.04202352251325, 42.741874899183, 52.93042148862566, 54.68925721304757, 28.26999490601676, 1.9137321327413832, 0.7031231192605836, 0.10434853498424802, 0.41678476120744434, 0.4275967281843935, 0.6205320539219039, 0.3184491592858519, 0.5258661593709673, 2.4102176172392706, 7.241844662598201, 15.475465638296944, 13.870265007019043, 20.89016205923898, 26.899494000843593, 53.70870310919625, 86.64733682359967, 104.85482025146484, 123.8471235547747, 131.68567820957728, 126.21162332807268, 121.47967774527413, 123.32238170078823, 117.4362291608538, 126.16573742457798, 124.01485306876046, 125.96297509329659, 82.08479527064732, 32.79734557015555, 5.113926708698273, 18.093279361724854, 38.11314828055245, 33.35888508387974, 38.62136731828962, 13.788239785603114, 4.600619418280465, 22.30114143235343, 61.856754847935264, 79.15890189579555, 60.44707652500698, 15.154922655650548, 3.590751950229917, 7.738920092582703, 5.452267067773001, 16.80251772063119, 82.39103017534528, 122.1064886365618, 130.5921151297433, 119.39463451930455, 124.01379694257463, 120.19560895647321, 126.90202413286481, 105.89428465706962, 110.87263420649937, 121.48402731759208, 121.25682122366769, 132.23418290274483, 144.2459784916469, 112.35050909859794, 21.299192087990896, 4.9804426942552835, 14.59750689779009, 7.250780480248587, 0.3503051570483616, 0.15718136142407144, 0.6211381214005607, 0.3192990922502109, 0.16863875091075897, 0.42577136041862623, 4.3671117424964905, 52.32800919669015, 54.51688977650234, 55.449584688459126, 80.91689341408866, 96.85859707423619, 96.69929572514125, 80.26727853502545, 97.62593528202602, 44.34931632450649, 56.16920614242554, 66.09675407409668, 70.70211737496513, 77.91515350341797, 60.41254397800991, 8.764497654778616, 0.4884945675730705, 0.11018414649048022, 0.12308211331920964, 0.10877079875873667, 0.21087227681917803, 0.13892134624932492, 0.17770666575857572, 0.12054842284747533, 0.1337635980120727, 0.12751460261642933, 0.10754876397550106, 0.10566164273768663, 0.11581682174333505, 0.17587517760694027, 0.07309503560619694, 0.1051411045981305, 0.18786645201700075, 0.12916585829641136, 0.09897134852196489, 0.15648218537015574, 0.13074873121721403, 0.17181163494076046, 0.11471261456608772, 0.20015050071690763, 0.09532170543181044, 0.19548083628926957, 0.11449116787740163, 0.12078542155878884, 0.14583873935043812, 0.16834337104644093, 0.0885401414707303, 0.08287794315921408, 0.1172156488256795, 0.09590560517140798, 0.12537518170263084, 0.3072372094861099, 0.10595714473830802, 0.2393161526748112, 0.2066407831651824, 0.16972353841577256, 0.17415764262633665], [0.07804220050041165, 0.13696077359574182, 0.059607808611222675, 0.10006854643246957, 0.04401461587154439, 0.11517407266157013, 0.11546866542526654, 0.04559510374175651, 0.023328900769619004, 0.04764018453923719, 0.024149968854284713, 0.017259016566510712, 0.08915564058614628, 0.08603149572653429, 0.061355755531362126, 0.10853173051561628, 0.03671451544921313, 0.044852420022445064, 0.060819122541163645, 0.02290194109082222, 0.06797681203378098, 0.10426404380372592, 0.09736419761819498, 0.01886166030141924, 0.1713520088898284, 0.09099261130073241, 0.0316029008078788, 0.03420946254794087, 0.02595170833436506, 0.017422429851389358, 0.08100029427026, 0.05544094881042838, 0.004474150923280311, 0.09373579267412424, 0.30277109199336594, 7.693882737840925, 76.26681845528739, 89.49070644378662, 84.2399319240025, 64.31894629342216, 68.25373894827706, 68.49632835388184, 41.430068901606965, 31.78290162767683, 55.885108198438374, 72.78054591587612, 55.76968819754464, 37.41194302695138, 28.38693482535226, 6.226601243019104, 0.2568766118160316, 0.33551743626594543, 0.0850876806569951, 0.012743221828714013, 0.11172666693372385, 0.08877414784261159, 0.16875490253525122, 0.5782037909541811, 2.250020819050925, 4.483539666448321, 30.64365761620658, 57.39740794045584, 88.70933982304165, 101.33405685424805, 117.52048301696777, 108.61244079044887, 99.21081938062395, 92.61655507768903, 89.58411107744489, 83.83333723885673, 86.53220517294747, 85.18809700012207, 90.1605475289481, 90.51439843858991, 90.94273403712681, 93.6250444139753, 91.20757157461983, 106.24357754843575, 109.61034802028111, 63.774089404514854, 9.604677302496773, 1.2789072543382645, 10.103029898234777, 1.0676516188042504, 2.4950353630951474, 36.037384373801096, 75.64196000780377, 84.32537392207554, 90.54324041094098, 94.08685643332345, 74.35197135380336, 34.32939556666783, 7.9767274005072455, 33.862073625837056, 92.23089531489781, 108.46693161555699, 95.21402100154332, 95.21584142957414, 96.22724900926862, 90.00954232897077, 94.1993408203125, 97.06454168047223, 96.85254519326347, 95.61257662091936, 102.3823732648577, 93.67294529506138, 90.71966212136405, 88.10674340384347, 101.24160412379673, 111.06478663853237, 62.454112325395855, 20.64325087411063, 19.445473500660487, 7.3007058926991055, 1.9307880061013358, 0.4354400230305535, 0.017205210435869436, 0.15438817201980523, 0.055814285563038926, 0.07157872697072369, 0.13800262340477534, 16.455027886799403, 32.86259262902396, 42.03904029301235, 58.42503956386021, 60.084505626133506, 143.78347860063826, 173.54200172424316, 59.21668951851981, 25.115517956869944, 39.931213923863, 45.02985416139875, 50.40968452181135, 51.095291069575715, 37.359504972185405, 11.073480452810015, 0.6112703766141618, 0.2775932087429932, 0.026556040459711636, 0.07487287199390785, 0.04351848802928414, 0.07327786008162157, 0.007512028961043272, 0.034614279932741604, 0.03016465762630105, 0.017091079149395227, 0.018655409404475774, 0.05337012778701527, 0.10076756642333098, 0.0743443610678826, 0.023940569554854716, 0.0321514726217304, 0.13123258096831186, 0.1906165001647813, 0.09583145486457006, 0.04722027314294662, 0.03944114735350013, 0.04003257883180465, 0.027799080990787064, 0.004893673434188324, 0.019570159426491176, 0.04459243254469974, 0.019924790664975132, 0.0249098245985806, 0.05906889574336154, 0.054714482078062635, 0.10922385659068823, 0.05385238637349435, 0.08105585950293712, 0.05091359353225146, 0.0901969950646162, 0.12535113442156995, 0.18016467243433, 0.22209242332194531, 0.34088790523154394, 0.19394859565155848, 0.11472476034292153, 0.07635538280010223, 0.12796079367399216, 0.08444639721087047, 0.14264822698065213, 0.13154891399400576, 0.1142102408089808, 0.03421877544107182, 0.08331561181694269, 0.020563514337741902, 0.019089754936950545, 0.037501198771808825, 0.08714952466211148, 0.16586519830993243, 0.08848619793674775, 0.14000503452760832, 0.16609157116285392, 0.03090090544096061, 0.02303891016968659, 0.02201752328047795, 0.058494224080017636, 0.15760905561702593, 0.17767310541655335, 0.05587402378608074, 0.17131349524216993, 0.12891492247581482, 0.057381290942430496, 0.05010173316778881, 0.025182354796145643, 0.02233777484590454, 0.022653302111263787, 0.023839520423540046, 0.03063529630058578, 0.07979764523250715, 0.3210287865783487, 18.732466731752666, 96.72995117732457, 106.24097197396415, 99.92873505183628, 80.43396581922258, 102.64163139888218, 111.63903440747941, 56.06267636162894, 23.33221241406032, 26.846751962389263, 52.644305092947825, 55.52797079086304, 47.13016605377197, 36.041532448359895, 8.305748053959437, 0.28698445909789627, 0.45132705196738243, 0.0649798314220139, 0.06733242089727096, 0.6642395343099321, 0.5723965082849775, 0.7713572521294866, 1.4413932668311256, 1.3361499884298869, 8.284246853419713, 36.94505187443325, 69.69749123709542, 99.07649680546352, 115.0452914919172, 127.81655992780412, 114.89128467014858, 101.76576927730015, 98.05342320033482, 92.40633038112095, 88.29700592585972, 93.89947741372245, 92.7587708064488, 96.09327384403774, 97.68432099478585, 97.45261941637311, 99.19032219478062, 94.5335283279419, 107.39457443782261, 114.76170771462577, 77.98241206577846, 16.662138053349086, 3.0228646056992665, 2.039407023361751, 0.782583695437227, 5.406307339668274, 52.39071321487427, 90.5798087801252, 93.58104147229875, 99.76710605621338, 107.34879970550537, 96.55195222582135, 46.15676164627075, 13.925174014908926, 43.07138974325997, 105.98294367109025, 115.92627443586076, 102.04446152278355, 100.79054791586739, 103.9529927117484, 97.14109693254743, 99.7507152557373, 105.20575291769845, 101.00050163269043, 101.34329795837402, 109.6872228894915, 99.92397553580147, 96.58884021214077, 93.72094345092773, 102.19042233058384, 122.72141810825893, 81.43326268877301, 33.83989497593471, 28.61866419655936, 13.858281101499285, 5.144749351910182, 0.1853005854146821, 0.12185116937117917, 0.17391560918518476, 0.019679713994264603, 0.129334528531347, 0.45630557196480886, 18.562284503664287, 40.25259242738996, 43.861632687704905, 51.76210274015154, 46.264861719948904, 101.75979382651192, 162.86249542236328, 42.929132325308665, 38.01078047071184, 67.83403301239014, 72.7132317679269, 71.81230749402727, 68.37590912410191, 61.02078928266253, 20.514033487864904, 0.5642127788492611, 0.24962258392146655, 0.047471039329788516, 0.06231529225728341, 0.02465533495082387, 0.04628766407924039, 0.01455380262008735, 0.021559289922671657, 0.045705301221460104, 0.03789720537939242, 0.0419720490463078, 0.0218470837654812, 0.08723217701273304, 0.043449263886681626, 0.039111945911177566, 0.03636654233559966, 0.14551891865474836, 0.1890618543007544, 0.19320040222789558, 0.05696873486574207, 0.05642839028899159, 0.017208555613511374, 0.03298985692007201, 0.04114642799166696, 0.03994184173643589, 0.026567568769678473, 0.05595514264756015, 0.03597427784864392, 0.021949020081332753, 0.021650943040315593, 0.13222553554390157, 0.04944170519177403, 0.06155976387006896, 0.007837400921354336, 0.03789778891950846, 0.15578952325241907, 0.17170878260263375, 0.17832102493516036, 0.3868947779493672, 0.18017115922910826, 0.17024989160043852, 0.2582475511091096, 0.19531874784401485, 0.1598958543368748, 0.26915947986500605, 0.20731455486799988, 0.20533586532941886, 0.10148351586290769, 0.206335130280682, 0.08177925247166838, 0.09054129730377879, 0.12671014506902012, 0.1846025628702981, 0.2539796472660133, 0.15541692610297883, 0.20475309874330247, 0.26545573717781473, 0.10675501371068613, 0.12471508926578931, 0.1674770853881325, 0.19023584201931953, 0.1849285446639572, 0.21253841955746922, 0.1946117686373847, 0.3421768774943692, 0.18287459202110767, 0.16149270507906163, 0.09457294203873191, 0.20549948726381573, 0.07082657090255193, 0.15080291511757032, 0.11227742702301059, 0.16922311883951935, 0.13114035448857717, 0.46159488814217703, 28.674154247556412, 117.17417090279716, 125.09124020167759, 106.45826993669782, 86.10613468715123, 90.65391826629639, 88.95486831665039, 56.5353935786656, 44.017261913844514, 88.06387996673584, 113.45382050105503, 91.16600050245012, 64.4723903111049, 47.51039579936436, 12.144064102854047, 0.40056340449622696, 0.4865514061280659, 0.23163676474775585, 0.1094701715878078, 0.45095146926386015, 0.38913801472101894, 0.4104366861283779, 1.9392072686127253, 12.146660992077418, 11.57359962803977, 37.1036445072719, 67.6899482182094, 104.02881145477295, 118.01523644583565, 137.57351221357072, 124.488039289202, 115.35408333369664, 108.95478548322404, 101.32545498439244, 95.4148656300136, 96.83571665627616, 93.84913771493095, 99.30358478001186, 100.80069923400879, 99.64723573412213, 102.79593004499162, 96.10973412649972, 114.60717282976422, 117.38329778398786, 76.47700146266392, 13.092140589441572, 8.911045585359846, 24.755622114453995, 4.810336896351405, 4.090249913079398, 61.60161004747663, 100.96064676557268, 99.63049057551792, 101.8052419934954, 108.83760411398751, 114.14229665483747, 52.56027705328805, 10.780824065208435, 41.86856276648385, 109.54638985225132, 123.28990582057408, 102.97874409811837, 102.88681248256138, 105.76590279170445, 99.24584524972099, 104.6995210647583, 108.90759331839425, 101.944351877485, 102.94953387124198, 113.13113921029228, 102.7360018321446, 96.03061498914445, 97.50716972351074, 109.41214370727539, 132.98715918404716, 78.68731376102993, 25.671985285622732, 26.617006301879883, 11.604783143315997, 5.195012620517185, 0.47448678208248957, 0.2633111865392753, 0.36024588506136623, 0.186666462836521, 0.4097877080951418, 0.6120763676507133, 27.750921045030864, 53.345110825129915, 62.44983918326241, 77.1558335168021, 83.78963306971959, 174.80428096226282, 189.6388656071254, 73.70881135123116, 41.67583015986851, 56.70987326758248, 72.80177961077008, 73.14554868425641, 83.66116782597133, 79.36869580405099, 27.29845608983721, 0.988612060035978, 0.5346326689635004, 0.13303311435239656, 0.2628548853099346, 0.14055650707866463, 0.17356773785182408, 0.09785792005381413, 0.21305847593716212, 0.11254419306559221, 0.11520490529281752, 0.15470910551292555, 0.1626049325402294, 0.2060380812202181, 0.1736226449055331, 0.16742696879165514, 0.17216057835945062, 0.23096691497734614, 0.2972609262381281, 0.2887647178556238, 0.1385311343308006, 0.09888463174658162, 0.06619147104876381, 0.2020507516073329, 0.09998018760234118, 0.14386961715562002, 0.12378035299479961, 0.12056470768792288, 0.10965656515743051, 0.12507331504353456, 0.10558979266456195, 0.2724196234984057, 0.1258693587567125, 0.15105520800820418, 0.06894151241119419, 0.15870214839066776, 0.21110795917255537, 0.20140235711421284, 0.2417771720460483, 0.3270445966294834, 0.2732360368328435], [0.15643356155071939, 0.12364628804581505, 0.06356268389416592, 0.11239317152649164, 0.22155258086110863, 0.12742994858750276, 0.14394122974148818, 0.06356014617319618, 0.14615184254944324, 0.03910568303295544, 0.13837140718741076, 0.05823222813861711, 0.09815203105764729, 0.10709642539066927, 0.16713593155145645, 0.07890525633203131, 0.10201843894485917, 0.10799760131963662, 0.015811830293387175, 0.08349062635430268, 0.07716952982757773, 0.1366945028837238, 0.0234276259184948, 0.19775471570236342, 0.11469242136393275, 0.06838788211877857, 0.08134301552282912, 0.09207673384142773, 0.025436018327517167, 0.04783580618511353, 0.050950831534074884, 0.058466661987560134, 0.030239703599363565, 0.5768295132688114, 20.838179111480713, 93.97223200116838, 85.63346263340541, 74.12452207292829, 63.92242649623326, 62.392509596688406, 38.14147956030709, 27.966396842684063, 51.54704557146345, 75.61211749485561, 70.62406826019287, 40.041471413203645, 33.705402169908794, 14.78661949293954, 0.377270654376064, 0.5497806646994182, 0.18196631861584528, 0.032907893282494376, 0.13662461377680302, 0.009559694976945008, 0.09804712954376425, 0.21963129538510526, 0.45867154215063366, 4.950042588370187, 15.31766162599836, 56.37769378934588, 91.6311754499163, 97.54392569405692, 94.63479832240513, 89.56927667345319, 84.44696739741734, 87.05077007838658, 89.82251071929932, 90.08805002485002, 90.11891392299107, 93.12626102992466, 95.3300906590053, 101.5298501423427, 97.05930273873466, 101.72619233812604, 98.8609150477818, 100.53002520969936, 103.84943675994873, 97.64561258043561, 97.04055649893624, 104.81648009163993, 76.91737828935895, 22.449073791503906, 1.1279183392013823, 9.564147591590881, 46.54296336855207, 78.722152028765, 81.40369115556989, 82.56405421665737, 85.88206223079136, 89.19182968139648, 93.73962715693882, 75.36779103960309, 75.66175542558942, 88.87713881901333, 105.68834699903215, 105.23547036307198, 109.55337974003383, 107.22328049795968, 107.18465546199253, 96.27617127554757, 81.48526300702775, 102.509122303554, 105.30054024287632, 102.24381228855678, 101.67009258270264, 95.1845258985247, 86.57253946576799, 98.88526848384312, 95.46744264875139, 86.96842697688511, 96.46059731074742, 106.7259770802089, 101.60862186976841, 92.92549283163888, 76.93047564370292, 37.909225600106375, 0.8294765448995999, 0.2212023346551827, 0.013918469077907503, 0.07228850852698088, 0.08910302698080029, 0.4431160997067179, 2.1058919472353796, 18.234591824667795, 43.29068183898926, 53.281242983681814, 43.44815581185477, 29.947107655661448, 39.94827175140381, 38.505707604544504, 20.053628478731426, 39.43837819780622, 54.66119691303798, 46.978479930332725, 47.51949446541922, 44.205950668879915, 19.48409332547869, 1.6501279004982539, 0.18210564899657453, 0.05576127501470702, 0.08630664846194641, 0.09225896799138614, 0.034677400652851374, 0.20417607256344386, 0.019542325920026218, 0.06286905825670276, 0.10370526343051877, 0.08237756429506199, 0.07483894524297544, 0.1783751313175474, 0.13093220708625658, 0.20645618092800888, 0.15939529905361788, 0.19516378401645593, 0.08914467546024493, 0.06568546034395695, 0.08215082503323044, 0.04642640074182834, 0.03313953495983567, 0.060210510556186946, 0.08858033109988485, 0.047150031197816133, 0.07274697428303105, 0.06242330824690206, 0.014542404928111603, 0.03670480900577136, 0.07537509647331067, 0.10598138879452433, 0.061527791299990246, 0.13283023238182068, 0.17792803102305957, 0.26565107383898323, 0.31105562459145275, 0.12244879587420396, 0.3343552957688059, 0.12330816047532217, 0.15310312168938772, 0.08322376531681844, 0.10401234802390848, 0.16416022979787417, 0.18046700049723896, 0.10150725780321018, 0.12013853341341019, 0.17792159851108277, 0.05515288694628647, 0.045669213336493285, 0.11843270994722843, 0.055057827582848926, 0.09161741313125406, 0.06994196479873997, 0.17615902237594128, 0.1500321129070861, 0.07323968570147242, 0.10895640522773777, 0.05303726225559201, 0.036611262775425396, 0.1369363870471716, 0.17808622467730725, 0.02178516235601689, 0.24005076182740076, 0.16373942952070916, 0.059942523150571754, 0.045038077381572554, 0.048265641156051836, 0.06870222025151763, 0.021753691901851977, 0.10487780586949416, 0.023281035213065997, 0.022163930781451718, 0.05984989633517606, 34.879793643951416, 115.26406942095075, 100.09060723440987, 90.28787326812744, 89.23383154187883, 101.08385222298759, 63.271818024771555, 33.17547695977347, 28.883418355669292, 46.46435144969395, 63.363478660583496, 43.53935786655971, 40.12804249354771, 17.454064198902675, 0.6115218688334737, 0.6700025764959199, 0.16023527112390312, 0.0737141106011612, 0.406065970659256, 0.37996313561286243, 0.3151162495570523, 0.2908700763114861, 0.6360705601317542, 1.5371093707425254, 20.042440141950333, 65.1513682774135, 100.19462871551514, 102.09535012926374, 101.61962781633649, 95.77742263248989, 91.65256895337785, 93.22341074262346, 97.54008334023612, 98.34583118983677, 98.21863746643066, 99.06988906860352, 101.82256385258266, 105.80019909994942, 104.66796234675816, 106.76679079873222, 105.13579150608608, 105.89117186410087, 108.2401076725551, 102.86257716587612, 100.83982454027448, 105.50348322732108, 86.88110201699394, 32.09686292920794, 4.932005499090467, 15.815976006644112, 61.0780702318464, 93.10288728986467, 88.13892051151821, 90.08923816680908, 93.27279159000942, 92.39487974984306, 104.42939594813755, 97.74875164031982, 84.32699285234723, 97.05828830174038, 107.80373995644706, 108.52305221557617, 112.4999509538923, 112.30432442256382, 111.36772114889962, 98.63359778267997, 83.24419253213065, 104.22504247937883, 106.51165294647217, 104.39011778150285, 107.12393515450614, 99.0177914755685, 88.80648258754185, 102.53671360015869, 103.03299563271659, 92.31250885554722, 98.43232236589704, 113.20249720982143, 111.63946519579206, 106.57858494349888, 91.41966533660889, 52.55213723863874, 3.7753601585115706, 0.15495640438582214, 0.06764253175684384, 0.08631551691464015, 0.1292291520429509, 0.7676557078957558, 1.2238663392407554, 22.578902619225637, 50.76453249795096, 58.921669006347656, 47.49428640093122, 39.9515825680324, 37.91487795966012, 29.9019513130188, 33.03127057211739, 64.31885596684047, 78.49942752293178, 67.60743141174316, 61.70099013192313, 65.92106887272426, 36.319668837956016, 3.2000894844532013, 0.21760003295327934, 0.06505501310208014, 0.0349235867283174, 0.2762478366494179, 0.0726163223651903, 0.11557227772261415, 0.059820420773965974, 0.03795352039326515, 0.04605532351082989, 0.08367148986352341, 0.12953217221157892, 0.15360800602606364, 0.04947231051379016, 0.29815518110990524, 0.19880112526672228, 0.22812450464282716, 0.13121720536478929, 0.07227350611771856, 0.10890836494841746, 0.058928798618061204, 0.05860198222632919, 0.06022131283368383, 0.1554408919598375, 0.03678423152970416, 0.04448958020657301, 0.06256083372448172, 0.047518194120909484, 0.07130403563912426, 0.1476801476840462, 0.07822243297206503, 0.041303050837346485, 0.199673789154206, 0.1759383627878768, 0.3148025492472308, 0.20717455952295236, 0.11940325929650239, 0.1960906492812293, 0.1301124282181263, 0.1975075661071709, 0.15990377962589264, 0.17058949837727205, 0.20232884239937576, 0.31166272344333784, 0.24464941077998706, 0.25949024728366304, 0.26153426617383957, 0.1581247422311987, 0.08773939550987311, 0.1921469901821443, 0.10981252643146686, 0.2638033687004021, 0.25792988815477913, 0.24219020988259995, 0.2379870382802827, 0.14665003653083528, 0.24348786739366396, 0.11094735589410577, 0.1710420133812087, 0.2152994599725519, 0.34230110368558336, 0.13396691424506052, 0.22058987537665026, 0.22337602158742292, 0.14511410466262273, 0.1223614684173039, 0.14750801692051546, 0.13501503371766635, 0.22043421944337233, 0.24695949682167598, 0.18191707054419176, 0.0666819161602429, 0.8500412042651857, 50.49189560753958, 136.81891005379813, 110.56057671138218, 100.18813909803117, 87.50372314453125, 85.2435644694737, 50.18348591668265, 38.91799981253487, 80.13545036315918, 126.05769293648856, 102.41114575522286, 59.6484158379691, 51.814356667654856, 23.138317721230642, 1.2480371679578508, 0.8886998955692563, 0.29795153918010847, 0.1524706320571048, 0.44383371834244045, 0.19369121374828474, 0.23798133858612605, 1.0043461471796036, 5.61840501001903, 18.77748758452279, 23.438981907708303, 66.46955272129604, 105.51066766466413, 113.05375712258476, 110.75208296094621, 103.06713213239397, 96.92556381225586, 97.1461969103132, 100.75889887128557, 100.49004527500698, 102.25426237923759, 107.78798839024135, 108.80182089124406, 114.13552910940987, 110.26500729152134, 112.82912186213902, 110.58663245609829, 112.55725969587053, 116.73177909851074, 106.80199037279401, 108.39601135253906, 108.72199303763253, 88.04713480813163, 33.24634511130196, 5.223720405782972, 13.004042642457144, 77.51645892007011, 101.68503815787179, 92.75849982670375, 92.9863590512957, 98.79687350136894, 98.93538584027971, 103.96819537026542, 116.5387442452567, 95.78258514404297, 105.84388242449079, 112.7731054850987, 111.89901515415737, 117.65923854282924, 119.30831010001046, 118.60059438432965, 105.29192447662354, 89.32442910330636, 111.13234397343227, 113.74205262320382, 109.3971425465175, 112.68167413984025, 105.42416259220668, 97.44659532819475, 112.06449345179966, 104.24542849404472, 94.42523370470319, 105.4789491380964, 122.30800029209682, 115.99561050959996, 102.60400690351213, 86.37682260785783, 46.07630498068673, 2.7625729271343777, 0.3193310648202896, 0.28470791982752935, 0.16355769070131437, 0.16835200201187814, 0.9643471049410957, 3.3772785365581512, 31.853766305106028, 66.23240375518799, 75.54544258117676, 61.954738344464985, 43.64995581763131, 52.12306860515049, 56.03809710911342, 32.53043052128383, 58.16322449275425, 77.73370824541364, 70.03695937565395, 72.27748938969204, 82.95640509469169, 46.25524541309902, 3.82735743692943, 0.25463516637682915, 0.11788266231971127, 0.17930006954286778, 0.4017978496849537, 0.1839886922389269, 0.2277385267828192, 0.11794837165091719, 0.1105359804683498, 0.13111376948654652, 0.2079060474144561, 0.3138024429125445, 0.29455574282578056, 0.2060148481811796, 0.40584949084690636, 0.36946647028837887, 0.3773925192654133, 0.2506839483976364, 0.20665288822991507, 0.12696047020809992, 0.08162686029183013, 0.22212206173155988, 0.15348205635590212, 0.23649046144315175, 0.08232452999800444, 0.17704616620072297, 0.23364875678505215, 0.07241903152316809, 0.16759372555783816, 0.2116015933986221, 0.1985727303794452, 0.12483239439981324, 0.17787338181265763, 0.2421545460820198, 0.35004424676299095, 0.27238040417432785, 0.2222771341247218, 0.3434473936046873, 0.19355881799544605], [0.13283842908484594, 0.07194105788533177, 0.16618100207831177, 0.15497620403766632, 0.1896577573248318, 0.17238319212836878, 0.35940420308283394, 0.10484084606702838, 0.03820178957123842, 0.04371744128210204, 0.10305961021887404, 0.041352366762501855, 0.13711793587676116, 0.08141295212720122, 0.08091839509350912, 0.15780227524893625, 0.13106928473072393, 0.036509492700653415, 0.056750015887830935, 0.039609390111374, 0.22207502568406717, 0.04435724212921091, 0.15971833600529603, 0.08387420220034462, 0.0806344553296055, 0.013987977357049073, 0.05862355285457202, 0.016266318137890527, 0.08869602810591459, 0.07567022527967181, 0.061937334681195874, 0.06331482183720384, 0.11478608633790698, 43.9175135748727, 96.40779100145612, 83.22107587541852, 65.75902993338448, 78.5543669291905, 49.05301400593349, 21.991913591112407, 46.13865116664341, 64.06713662828717, 66.21818774087089, 56.84072869164603, 35.37542254584176, 32.40130867276873, 7.538764204297747, 0.16692891051726683, 0.09405245139662709, 0.09094609093985387, 0.06025903259537049, 0.3696101840053286, 0.12920135924858706, 0.1971224567719868, 0.812849831368242, 3.0069206612450734, 3.617337929350989, 22.423488787242345, 69.43512031010219, 91.46017333439418, 89.01738125937325, 89.5881827218192, 93.96435274396623, 91.97429139273507, 96.96056883675712, 93.00066539219448, 90.54656164986747, 84.17258303506034, 83.65958363669259, 86.34038625444684, 89.34589903695243, 90.55248151506696, 97.01051248822893, 91.03038556235177, 96.90496240343366, 89.15952750614711, 92.92763287680489, 92.96374961308071, 99.84561375209263, 91.91651712145124, 103.06176117488316, 62.38393551962716, 34.317045143672395, 59.61712809971401, 59.154704638889854, 84.11284242357526, 93.43510150909424, 90.4237869807652, 95.44028908865792, 87.923109463283, 112.124178477696, 88.50921085902623, 69.88459232875279, 105.0722015925816, 103.35529477255685, 97.43586730957031, 96.7427567073277, 97.17046001979283, 91.98737485068185, 92.2284495489938, 76.87470245361328, 83.86793231964111, 94.57819134848458, 95.82965224129813, 101.56761360168457, 97.52915382385254, 92.45063209533691, 73.35678781781877, 93.0284651347569, 102.47968973432268, 95.82219682421002, 89.7272231238229, 90.53874492645264, 92.04822717394147, 98.19058758871896, 109.96599156515938, 83.25785269056047, 4.129847262586866, 0.22269750013947487, 0.07932308462581464, 0.2160731391715152, 0.508661225438118, 0.14606007747352123, 0.15562098872448715, 4.486857865537916, 26.53824325970241, 53.8890575000218, 59.03948960985456, 42.801191670554026, 48.70551374980381, 48.27461426598685, 25.040345396314347, 32.107674326215474, 45.54775551387242, 50.511895997183665, 48.97625725609915, 50.93983554840088, 30.601363931383403, 2.8957477467400685, 0.27876308453934534, 0.07577848554189716, 0.017858278338930438, 0.051464655569621494, 0.1201502720692328, 0.057429555138306956, 0.054931694708232365, 0.08276743016072682, 0.07477887453777449, 0.040395265977297506, 0.10657199924545628, 0.029521626952503408, 0.1921192652412823, 0.1720281554652112, 0.08588805342359201, 0.05007123301870056, 0.07373839536947863, 0.08271618719611849, 0.10224089665072304, 0.09304233667041574, 0.06754625442304782, 0.042612284155828614, 0.0039819055735798815, 0.007151181493619723, 0.028314194242869104, 0.12153254289712224, 0.04823036412043231, 0.05308003371049251, 0.07060430318649326, 0.16487612495464937, 0.1436534087572779, 0.386846411973238, 0.3694929060127054, 0.17273087347192423, 0.19521067078624452, 0.19961783715656825, 0.08762403098600251, 0.09543133633477346, 0.12658085700656685, 0.10081338789314032, 0.20357491767832211, 0.17679666887436593, 0.20804042448954924, 0.2494662223117692, 0.07367687938468796, 0.05884282144584826, 0.04545993617336665, 0.03736118985606091, 0.05802679487637111, 0.13728922525686876, 0.012594492889807692, 0.08563546197754995, 0.08373569284698792, 0.06604013059820447, 0.0034181405124919756, 0.03634998268846955, 0.026628494429002916, 0.1237961764314345, 0.04777520961527314, 0.19489783900124685, 0.06547152503792729, 0.13026196376553603, 0.04086516165573682, 0.05411746286387954, 0.09410582496119396, 0.08958184200205974, 0.038381357078573534, 0.053224911114999225, 0.01602138395953391, 0.6805162866200719, 61.868101256234304, 112.1723711831229, 96.90475395747593, 91.46202850341797, 104.60388605935233, 81.8902040209089, 33.91121823447091, 28.47383073398045, 26.279052870614187, 57.871414048331125, 62.6698955808367, 43.120992933000835, 42.145187922886436, 9.859730039324079, 0.16785459513110773, 0.10886576651994671, 0.07739839290401765, 0.14797452331653663, 0.7753422068698066, 0.16633828649563448, 0.15237054814185413, 0.3032009574983801, 2.242553459746497, 3.0459645433085303, 28.420711755752563, 79.96054336002895, 99.95011465890067, 98.52922889164516, 98.30559417179653, 100.92869894845145, 98.81776673453194, 103.71954713548932, 97.59837177821568, 93.24053110395158, 87.26507336752755, 90.6791124343872, 92.09130600520542, 97.48647103990827, 95.45966066632951, 100.8259698322841, 97.19199248722622, 100.00841699327741, 93.68590368543352, 97.0395837511335, 96.42789213997978, 105.27141339438302, 97.54294599805559, 105.61154161180768, 73.31133270263672, 46.37870100566319, 71.74310343606132, 70.7065989630563, 92.06977353777204, 99.93861539023263, 96.10290404728481, 101.30414485931396, 94.40639019012451, 116.2808757509504, 94.79648985181535, 75.00249644688198, 105.87650421687535, 107.35472651890346, 99.60927772521973, 99.5928452355521, 101.98307418823242, 97.64904499053955, 98.1728766305106, 83.26710074288505, 87.91202013833183, 101.79172079903739, 99.27230398995536, 105.7126031603132, 102.12199647086007, 99.51759624481201, 76.5826140812465, 94.72757066999162, 107.9929255076817, 101.42541871752057, 94.8357263292585, 93.84192548479352, 95.86054393223354, 101.74862807137626, 114.25157792227608, 100.32718644823346, 9.061584387506757, 0.1627143123852355, 0.18310409970581532, 0.1390545426734856, 0.48808554666382925, 0.11597125631357942, 0.15333089232444763, 4.942763481821332, 30.67429222379412, 61.0895972933088, 61.28041567121233, 46.34205968039376, 40.211302757263184, 32.335533550807405, 32.70840515409197, 58.84156322479248, 71.42123508453369, 75.00149590628487, 65.00359398978097, 69.20979717799595, 54.17336041586739, 7.135335726397378, 0.25806488948208944, 0.08686162903904915, 0.08563031189675842, 0.07233166335416691, 0.07160737471921103, 0.07953694529299225, 0.03137813947562661, 0.05719776079058647, 0.06851145691637482, 0.008109521453401871, 0.017893088881724646, 0.07433596080435173, 0.17790264024266175, 0.2546228441808905, 0.11676725931465626, 0.07673950825950929, 0.05129556464297431, 0.053334501305861134, 0.07718881379280772, 0.07902676838317088, 0.06925329246691295, 0.017768430124436106, 0.024492583237588406, 0.052952472519661696, 0.029446886320199286, 0.11902644165924617, 0.016243441329736794, 0.07239026163837739, 0.013370340008155575, 0.058119116351008415, 0.19307116844824382, 0.3687144363565104, 0.3557795232960156, 0.1787237354687282, 0.2034211887844971, 0.20813502584184917, 0.040169578444744856, 0.2214509498860155, 0.18476489558815956, 0.2481509500316211, 0.3257633053830692, 0.2697335204907826, 0.24939999729394913, 0.4439274104578154, 0.19559495230870588, 0.13634401240519115, 0.16374784335494041, 0.11397681119186537, 0.19879755617252418, 0.2658149264752865, 0.22906715263213429, 0.17546337470412254, 0.4151621939880507, 0.22424477711319923, 0.09125095672373261, 0.12828977459243365, 0.13996095689279692, 0.3973279595375061, 0.11002540322286741, 0.3342091936085905, 0.23657231990780148, 0.26157926661627634, 0.15337559421147617, 0.18223279288836888, 0.25247487372585703, 0.3924482613801956, 0.12578835524618626, 0.1806455637727465, 0.15910865872034005, 2.1986612549849918, 82.83008684430803, 131.69482203892298, 109.99000453948975, 93.8298008782523, 107.20486082349504, 64.5547820499965, 30.308730125427246, 70.21729987008231, 101.83188833509172, 100.84200627463204, 80.28399590083531, 58.225532463618684, 54.8856862613133, 16.708484275000437, 0.43066438500370297, 0.3131075144878456, 0.22561216088277952, 0.09287399891763926, 0.5243414640426636, 0.22650409516479286, 0.3056232732321535, 3.6734526668276106, 8.507405621664864, 10.017254386629377, 29.788379532950266, 82.67115374973842, 110.043762751988, 102.92165769849504, 103.12366962432861, 106.9949904850551, 104.95743124825614, 109.08772536686489, 103.38492883954729, 101.0364099230085, 95.26872416904995, 98.19825839996338, 96.22919450487409, 100.52750301361084, 101.64724690573556, 103.30991608755929, 101.03752858298165, 104.67022051130022, 98.38539423261369, 101.8561931337629, 104.9253236225673, 109.63782119750977, 104.92826271057129, 107.20563207353864, 76.00290502820695, 51.08879797799246, 81.50185530526298, 81.78860746111188, 97.41744068690709, 107.95235497610909, 103.42635399954659, 108.08674008505685, 102.88793114253453, 123.2063467843192, 99.66544696262905, 79.89446599142892, 111.05173097337995, 114.88109166281563, 107.70537430899483, 104.94333335331508, 104.48606545584542, 100.2708296094622, 101.05050086975098, 87.5992956161499, 92.73117256164551, 106.21078205108643, 101.57998834337506, 109.26474462236676, 105.93693270002092, 102.89483070373535, 80.04531833103725, 102.40694209507534, 116.67074612208775, 104.16790049416679, 97.2033805847168, 99.20146710532052, 103.69265065874372, 114.8157091140747, 122.046080998012, 98.0814869744437, 6.741959120546069, 0.2533657359225409, 0.42481085338762825, 0.26027582798685345, 0.9821895360946655, 0.3708006329834461, 0.387447539716959, 8.736492071832929, 43.9993633542742, 73.81720324925014, 85.52760682787213, 64.40167154584611, 71.90273829868862, 65.09451811654228, 38.64324719565255, 45.40347269603184, 64.53581346784318, 76.39513778686523, 70.18059253692627, 85.86378152029855, 72.19054658072335, 10.465590374810354, 0.5090004386646407, 0.20593042485415936, 0.18897121559296334, 0.19083059153386525, 0.17788311200482504, 0.18306585747216428, 0.19432210203792366, 0.186899512474026, 0.18354058771261147, 0.10686340289456503, 0.24781328386494092, 0.1883833057114056, 0.32670095935463905, 0.35932353883981705, 0.38322694333536284, 0.18523601602230752, 0.21572600065597466, 0.20109669065901212, 0.1702338374618973, 0.18716129128422054, 0.1604263194437538, 0.09850442143423216, 0.13960993715694972, 0.13556491849677904, 0.09906711016914674, 0.1585729553231171, 0.08726253466946737, 0.2374838095690523, 0.21841758622654847, 0.19714749471417495, 0.1975802779197693, 0.39345979424459593, 0.4930877068213054, 0.20155994008694375, 0.31672706454992294, 0.21656431710081442, 0.1342901276158435], [0.13398964516818523, 0.020526824252946035, 0.06721096991428308, 0.16657592302986554, 0.07139965479395219, 0.2825661918946675, 0.22256403230130672, 0.06183231103100947, 0.03217819672343986, 0.09460622418139662, 0.04394714574196509, 0.1449107884296349, 0.06925855111330748, 0.2405005491205624, 0.1724196294588702, 0.10888175280498606, 0.08464309772742645, 0.09387192715491567, 0.09540494810789824, 0.055206287652254105, 0.07933614642492362, 0.06760880856641702, 0.04637098139418023, 0.12193777758095946, 0.03749524801969528, 0.004946991443700556, 0.0762798414964761, 0.035810370929539204, 0.05871710247759308, 0.021098452686731304, 0.04926684671746833, 0.5472229133759225, 43.22300638471331, 108.68856525421143, 77.80149487086705, 72.5532078061785, 65.62402643476213, 55.925025599343435, 26.412651096071514, 62.279566628592356, 67.18368162427629, 79.35101958683559, 63.91129548209054, 41.78676857267107, 22.23368832043239, 2.716671173061643, 0.7010435451354299, 0.11660636509103434, 0.1203864293971232, 0.2655695139297417, 0.20281050726771355, 0.2353507668844291, 0.08136679138988256, 2.4078031182289124, 4.736651684556689, 6.153532683849335, 57.79542507444109, 96.93239389147077, 95.65386976514543, 93.15477643694196, 96.25805732182094, 92.58044528961182, 88.44509983062744, 85.1057608468192, 79.77101734706334, 78.7592693056379, 83.42248330797467, 84.52092402321952, 89.94008813585553, 96.83006082262311, 103.53691373552594, 88.71963705335344, 93.2440607888358, 97.268401827131, 96.32454463413784, 93.18301391601562, 92.55706460135323, 86.76048823765346, 88.96419974735805, 91.20824554988316, 92.28443813323975, 86.88007368360246, 54.16883019038609, 50.45923907416207, 90.80374922071184, 90.3346346446446, 84.72328335898263, 79.15236364092145, 83.84653186798096, 76.1163969039917, 94.87433052062988, 83.39876215798515, 91.2360313960484, 104.27228328159877, 91.71872275216239, 83.85553673335484, 90.83456448146275, 104.00383268083844, 100.04975182669503, 92.9510691506522, 83.90809985569545, 74.32885469709123, 93.19400596618652, 96.9541903904506, 98.58855261121477, 98.29145458766392, 101.51500879015241, 89.91902814592633, 74.06574031284877, 89.10912527356828, 95.36616570608956, 103.16604668753487, 95.06443323407854, 90.24111189161027, 83.65417098999023, 81.87946210588727, 97.09050709860665, 91.36710916246686, 3.313199209315436, 0.13329152762889862, 0.32384405551212175, 0.17050089527453693, 0.048693949423198185, 0.11418471432157926, 0.16976363983537468, 0.4760540894099644, 9.145234618868146, 37.42930310113089, 71.54369708469936, 56.93082250867571, 45.14474957329886, 44.95412574495588, 20.74216890335083, 26.27573684283665, 32.4439879826137, 45.83209317071097, 48.741154534476145, 48.8884528705052, 42.785610335213796, 7.777368818010602, 0.332000127860478, 0.4531453086861542, 0.09537959125425134, 0.0868212833468403, 0.04216583864763379, 0.07174403845731701, 0.06426561903208494, 0.013741126317264778, 0.048376537526824644, 0.012125472521542438, 0.10027452252273049, 0.08998442361397402, 0.07710756600967475, 0.0448333260470203, 0.10906876384147576, 0.02386584927860115, 0.06496896807636533, 0.05611749572147216, 0.08122215486530747, 0.03725297369861177, 0.030272310599684715, 0.08748006621109587, 0.05635242150830371, 0.03929590693275843, 0.043263928831687996, 0.10980701672711543, 0.04602300488789167, 0.11064650025218725, 0.13084905940507138, 0.15198148973286152, 0.2266319447330066, 0.13119703930403503, 0.21367937619132654, 0.20965392648109368, 0.24365239856498583, 0.02871945946078215, 0.00526613021169656, 0.03612561151385307, 0.0667925173682826, 0.12673298455774784, 0.10901094587253672, 0.18715422094932624, 0.12946780637970992, 0.07219826336950064, 0.03372914457161512, 0.03333353829969253, 0.06546495681894676, 0.13724947667547635, 0.0785896832655583, 0.11472766447280135, 0.12104156852832862, 0.0634317130648664, 0.052800473890134265, 0.013399767223745584, 0.045895911886223724, 0.04361256690961974, 0.15845844575337, 0.03015581631500806, 0.05628703448123165, 0.1160371827759913, 0.011270289392476636, 0.041320991303239546, 0.04261001106351614, 0.07498121368033545, 0.034450183023831675, 0.04422621023175972, 0.05034512707165309, 0.48212502364601406, 64.40055288587297, 121.54303142002651, 94.56181444440568, 92.6320217677525, 93.85057599203927, 94.04721696036202, 36.87568800789969, 33.0530184337071, 45.12296002251761, 78.4547506059919, 71.72337750026158, 50.193772724696565, 28.47539928981236, 2.5252057441643307, 1.319195189646312, 0.14053034276834556, 0.10790110006928444, 0.4101083566035543, 0.35808608095560757, 0.11104981468192168, 0.10068638649369989, 0.8501516697662217, 0.8688207737037114, 10.048927749906268, 70.88080419812883, 108.39250251225063, 102.65934930528913, 101.21962697165353, 103.18980952671596, 99.0384623663766, 93.42306722913469, 91.14837987082345, 84.7282304763794, 84.7518196105957, 89.41897324153355, 92.98722062792096, 97.22790077754429, 104.30414772033691, 105.66923945290702, 95.09308065686906, 95.76497840881348, 101.42037432534354, 100.01801940373012, 97.23054804120744, 98.4790837424142, 90.99850027901786, 93.0154025214059, 92.85186971936906, 96.62502643040249, 93.7670864377703, 60.13979244232178, 56.95094796589443, 100.071291242327, 95.4825688770839, 91.63180773598808, 88.51590892246791, 91.09471893310547, 84.34892831529889, 101.78592600141252, 91.32748358590263, 96.96414021083287, 107.53062711443219, 95.04882758004325, 86.07746641976493, 93.3920157296317, 104.58817618233817, 103.72070748465401, 95.75179767608643, 88.80240399496896, 78.81962830679757, 94.66589845929826, 100.87710857391357, 100.72550582885742, 99.60488646371024, 105.63029479980469, 96.14444732666016, 79.17472294398716, 93.0112613950457, 97.72636454445976, 105.15719890594482, 98.10835565839494, 95.90947314671108, 88.78575611114502, 86.11302730015346, 97.48543575831822, 105.52572441101074, 7.974566510745457, 0.1722068273063217, 0.39156326172607286, 0.32204718621713774, 0.08175460807979107, 0.21091826792274201, 0.11719705696616854, 0.52731768148286, 9.508086051259722, 42.704101017543245, 66.08704049246651, 51.89880159923008, 44.90648194721767, 23.950539554868424, 18.17378987584795, 45.04294804164341, 55.07175554547991, 76.07409627096993, 69.59977872031075, 64.05940328325543, 66.92623002188546, 16.91862906728472, 0.3034747599491051, 0.5751978265387672, 0.027294522350920097, 0.09674750428114619, 0.033657019691807885, 0.04462636268830725, 0.09642061325056211, 0.059248490392097404, 0.091447854015444, 0.06111792900732585, 0.07147005280213696, 0.10684082124914442, 0.05763025222612279, 0.04827983271596687, 0.06957229892058031, 0.06010628079197236, 0.04053511543731604, 0.07203967616494213, 0.09549093206546136, 0.05321028868534735, 0.031606310446347506, 0.0303241778165102, 0.04519377402695162, 0.05296225020928042, 0.007763500824304563, 0.054200006648898125, 0.1346638375627143, 0.0025330072717874175, 0.09780299264405455, 0.190782917663455, 0.2872779390641621, 0.11854952653603894, 0.1913824033524309, 0.16302430789385522, 0.23843025735446385, 0.05719620694539376, 0.17872047850063869, 0.1349682690841811, 0.21315993049315043, 0.17561148532799312, 0.31070881177272114, 0.31240542073334965, 0.239950637200049, 0.15946103552622454, 0.09125415940902062, 0.25436361666236607, 0.12855767378849642, 0.2713702826627663, 0.18085768739027636, 0.2461683792727334, 0.17643887735903263, 0.19227247844849313, 0.25539298142705646, 0.12164992945534842, 0.19362283098910535, 0.20989951544574328, 0.31117675666298183, 0.15898150125784533, 0.19183411768504552, 0.25982419507844107, 0.11591187092874732, 0.18219080514141492, 0.26143226878983633, 0.1616018135100603, 0.14171494277460234, 0.12145417210246835, 0.13705479140792573, 2.1591318675449918, 87.47337341308594, 138.32555743626185, 102.65991905757359, 100.1031973702567, 88.1611339024135, 73.49056148529053, 43.32517269679478, 96.39316504342216, 102.18904658726284, 106.5725678035191, 86.26116289411272, 65.1232350213187, 39.18443543570382, 4.594518465655191, 1.9878012325082506, 0.26501745783856934, 0.3576512485742569, 0.6300132508788789, 0.2949679935617106, 0.3944617733359337, 1.1837601427521025, 6.36384596994945, 10.475357804979597, 7.312179974147251, 69.85865470341274, 114.92581721714565, 110.93307658604213, 106.22299003601074, 109.36811297280448, 102.98631068638393, 101.41091087886265, 97.10108920506069, 90.07337542942592, 87.07901450565883, 93.02224649701799, 94.0058821269444, 99.55262211390904, 108.73727907453264, 114.66652434212821, 99.60834666660854, 105.94572217123849, 104.33745043618339, 106.1038840157645, 102.4535436630249, 106.38560567583356, 93.73408944266183, 101.4888001850673, 98.956529208592, 104.99483340127128, 95.60520458221436, 67.52993120465959, 72.36416816711426, 105.86660303388322, 104.98908724103654, 97.22248118264335, 95.82722731998989, 100.32119015284947, 92.4885345186506, 108.83103111812046, 96.40865952627999, 102.7941026687622, 114.59161581311906, 101.49893760681152, 91.41728905269078, 100.81906332288469, 112.98658888680595, 107.64616176060268, 101.41457952771867, 95.29052761622837, 82.3173097882952, 102.94560813903809, 107.5203229359218, 104.24032851627895, 105.72121892656598, 112.98818002428327, 101.25273513793945, 85.32404545375279, 97.75995908464704, 104.78849969591413, 113.52299676622663, 104.00691073281425, 101.41195310865129, 93.17097268785749, 89.2397027696882, 110.13443674360002, 104.02917276109967, 5.661361379282815, 0.2792143374681473, 0.529389004622187, 0.44847812769668444, 0.17966820193188532, 0.2592465989291668, 0.32824394798704554, 1.4971767706530434, 18.61755916050502, 53.002988474709646, 91.56657109941754, 79.61649635859898, 73.62196581704276, 64.10577556065151, 32.65581423895699, 37.74478605815342, 41.52883407047817, 69.83760166168213, 68.96344184875488, 76.22314207894462, 80.50339221954346, 22.60322478839329, 0.5521453320980072, 0.7017545412693704, 0.24610950957451547, 0.1786495308790888, 0.16618371621838637, 0.14671250246465206, 0.18965160979756288, 0.17054612641888006, 0.17335025380764688, 0.08107276181025164, 0.2045478554708617, 0.2807503236191613, 0.1527808311262301, 0.1892452487455947, 0.22192838069583687, 0.25553468668035095, 0.139803373920066, 0.16588176813508781, 0.26772109419107437, 0.16002314750637325, 0.0955658694729209, 0.11320715570556265, 0.13827787792044027, 0.0910136933837618, 0.17483290710619517, 0.12672961902405533, 0.20369838391031536, 0.17961917099143776, 0.20121464718665394, 0.18885424972644874, 0.294748636760882, 0.2451682457966464, 0.421381021716765, 0.22857000359467097, 0.28261257654854227, 0.10601564802761589], [0.08976165378200156, 0.10682098088519913, 0.07726861629635096, 0.14806772688669817, 0.23529569698231562, 0.13934378858123506, 0.11636629940143653, 0.12091188691556454, 0.06797055594090905, 0.11646726541221142, 0.015560860546039683, 0.041631197157715044, 0.08105561523033039, 0.08114775350051266, 0.03805701394698449, 0.08633333524422986, 0.04886098099606378, 0.06140707992017269, 0.06221959846360343, 0.022080523560621908, 0.05433996128184455, 0.057402352669409344, 0.12614093561257633, 0.08872452657669783, 0.12850208819976874, 0.038636452318834405, 0.043523081711360385, 0.070887082655515, 0.06201530514018876, 0.02064566796512476, 0.745109889124121, 43.38457979474749, 93.74009963444301, 76.15472316741943, 63.05490916115897, 59.76647962842669, 46.01449033192226, 22.092857020241873, 57.15755612509591, 51.24296113422939, 76.33202729906354, 66.4256123134068, 34.77623421805245, 14.31588511807578, 0.07598854641297034, 0.2777631681944643, 0.12972035711365087, 0.05778653919696808, 0.1925141183393342, 0.12442094433520522, 0.26513682571905, 3.6850908994674683, 1.7532828109604972, 4.303442793233054, 54.44190829140799, 105.09966782161167, 102.43465151105607, 88.13871206556047, 93.81145763397217, 94.20444079807827, 87.67765045166016, 84.52054187229702, 82.08617796216691, 81.60550158364433, 81.08314296177456, 89.94783537728446, 86.48789651053292, 91.84518691471645, 92.56611810411725, 90.55364186423165, 90.24767793927873, 91.36997876848493, 82.09762164524624, 91.30091367449079, 88.7071372440883, 88.06119796207973, 84.31630652291435, 88.79879093170166, 84.70145906720842, 89.38152939932687, 82.81141008649553, 96.24508503505162, 76.20887047903878, 47.41201625551496, 94.35752350943429, 89.06043924604143, 86.17557498386928, 77.7916909626552, 82.18236187526158, 87.48679038456508, 86.66536045074463, 71.25902938842773, 87.87652179173061, 99.92568479265485, 91.57756314958844, 78.18240206582206, 83.27467427934918, 93.39259937831334, 101.21321378435407, 97.27833775111607, 90.35468019757951, 73.37090655735561, 74.70177146366665, 91.36072376796177, 95.89071301051548, 93.43989576612199, 94.67188780648368, 92.24184567587716, 79.23330320630754, 76.72756740025112, 85.14184284210205, 79.73555374145508, 77.91796057564872, 75.88614749908447, 74.27200453622001, 86.58343424115861, 81.99735913957868, 93.11254528590611, 92.8552326474871, 4.113304904529026, 0.42006493519459454, 0.20476481025772436, 0.11819303780794144, 0.04249857525740351, 0.26841602261577335, 0.12445246907217161, 0.17150041806910718, 3.284950439419065, 26.213946512767247, 51.23062113353184, 46.39986521857125, 45.22363594600132, 68.71330669948033, 28.623157943998063, 18.96207516533988, 20.71775640760149, 39.39540706362043, 45.684596811022075, 44.11135441916329, 50.01379006249564, 27.23988972391401, 2.922085327761514, 0.3711575152618544, 0.013758523955142923, 0.05081963000286903, 0.1169991690133299, 0.05321615122790847, 0.04385528227846537, 0.04273274787036436, 0.08876175100782088, 0.11578427920384066, 0.12551262575600827, 0.058755398994045596, 0.05692899306969983, 0.03930991189554334, 0.06055750657937356, 0.04793508942904217, 0.057307561327304156, 0.04849679089550461, 0.057971942105463574, 0.14747502654790878, 0.08023094412471567, 0.03098761543099369, 0.04076299803065402, 0.02407931978814304, 0.027487838674070578, 0.10655578225851059, 0.0822106853925756, 0.15367701303746018, 0.12334165296384267, 0.11701339110732079, 0.2040212851549898, 0.16530820248382433, 0.17018582432397775, 0.06989221461117268, 0.038789763913622925, 0.10850238387605973, 0.08574269765189715, 0.05120564857497811, 0.03453543755624976, 0.15800495365900652, 0.1404954253562859, 0.02417932906454163, 0.057169018047196526, 0.04383259206744177, 0.03487660496362618, 0.014992295697863613, 0.04616192136225956, 0.038014388377113004, 0.003750273650179484, 0.11330334482980625, 0.05895367371184485, 0.039764615174915106, 0.048293997134481154, 0.055948282658521614, 0.0393014437785106, 0.08605926816484757, 0.0677007364907435, 0.08190677634307317, 0.010907117942614215, 0.11130126618913241, 0.008819297072477639, 0.04217641022322433, 0.023893669214365736, 0.04591159283050469, 0.11420812377972261, 0.3435974855508123, 61.239831243242534, 107.56785556248256, 95.92209107535226, 89.82804843357631, 83.82914052690778, 75.38575213296073, 32.639190673828125, 24.820992503847393, 47.540446758270264, 83.00431987217495, 74.5515444619315, 42.94753462927682, 17.664464337485178, 0.04953114967793226, 0.4146881694240229, 0.26822605995195253, 0.03966975937198315, 0.13103321380913258, 0.13172305322119168, 0.223583422601223, 1.9973760672977992, 0.18711519161505358, 7.542748127664838, 64.86285127912248, 117.67688696725028, 109.76784283774239, 93.79718603406633, 100.16458470480782, 98.9381581715175, 95.04976558685303, 89.47990199497768, 86.36951310294015, 86.98918124607631, 87.19533429827008, 91.74902384621757, 92.64813464028495, 94.1798094340733, 95.75498689923967, 94.42872170039585, 93.2175395148141, 94.39546067374093, 90.89538901192802, 93.90174947466168, 94.22584819793701, 91.08447728838239, 89.27188682556152, 92.77320221492222, 86.09184224264962, 92.78921086447579, 86.41703183310372, 100.99190671103341, 82.55197824750627, 54.9565509387425, 97.12727001735142, 95.57705048152378, 92.34299755096436, 83.49345220838273, 87.9720595223563, 94.87092590332031, 93.72499425070626, 75.39803654806954, 92.78724452427456, 101.63985402243478, 95.9643222263881, 79.93650954110282, 86.7197926385062, 96.95069544655937, 103.85442556653703, 101.07790456499372, 96.64047922406877, 78.98391151428223, 78.47314943586076, 95.51507949829102, 98.94299411773682, 93.53490543365479, 95.9539555140904, 95.40030915396554, 83.33660357339042, 81.06844752175468, 88.79389245169503, 83.4220038822719, 81.12977232251848, 77.69380474090576, 79.15331554412842, 89.28225353785923, 87.58018807002476, 94.36214406149728, 103.71992928641183, 8.250468185969762, 0.3262600472995213, 0.3802672550082207, 0.09161936731210776, 0.19556193479469844, 0.07928649801760912, 0.16693557373114995, 0.06608498854828732, 2.2774879166058133, 30.38182864870344, 49.778871468135286, 32.6495817048209, 36.26064389092581, 36.68708610534668, 15.277528830936976, 28.599490642547607, 44.52397666658674, 70.01929705483573, 69.40895339420864, 56.28337894167219, 69.89592484065464, 46.030262742723735, 7.017257171017783, 0.39036887724484715, 0.0951589180954865, 0.03644324393410768, 0.09920976537146739, 0.060043733433953354, 0.05803647757108722, 0.042362522200814316, 0.007940033583768775, 0.1014439504859703, 0.087622884261821, 0.042347998158740144, 0.054334254802337716, 0.04099238357905831, 0.061785146061863215, 0.0457814124945019, 0.04976418574473687, 0.020369417699319974, 0.036160651062216075, 0.14185724513871328, 0.09072205224739653, 0.012133687036111951, 0.03445209309990917, 0.05219351074525288, 0.03710999958483236, 0.07868351108793702, 0.018960755251880203, 0.12963532310511383, 0.039896244183182716, 0.11219596210867167, 0.23046097212604114, 0.14216587000659534, 0.13596175291708537, 0.0876979370202337, 0.11858361613537584, 0.13631308477904114, 0.11157033246542726, 0.17626467027834483, 0.15645194984972477, 0.26295026019215584, 0.3267655016056129, 0.1901998660926308, 0.1983727253973484, 0.12319970343794141, 0.22899482079914638, 0.14579478385193007, 0.11390484576778752, 0.09459330487464156, 0.1899237566228424, 0.18538142607680388, 0.22597949260047503, 0.11417445487209729, 0.16263161253716263, 0.1822228862770966, 0.177864262302007, 0.17598135476665838, 0.18359400198927947, 0.25425442680716515, 0.09527067959840808, 0.27809806593826836, 0.15153399588806288, 0.17021854328257696, 0.21593446018440382, 0.14516962239784853, 0.13749206651534351, 2.0600229799747467, 87.96300601959229, 123.32782908848354, 99.76204081944057, 90.64426721845354, 82.74055930546352, 61.44610936301095, 34.474116121019634, 91.71683979034424, 86.08355304173061, 100.61217376164028, 84.95183045523507, 56.30643653869629, 25.64704646383013, 0.6248450396316392, 0.7670697793364525, 0.3698408044874668, 0.34538363399250166, 0.26677206797259195, 0.2488753811589309, 0.502188327057021, 6.796096009867532, 4.882517388888767, 6.811407233987536, 63.21761512756348, 124.2191162109375, 115.8948060444423, 97.02142810821533, 104.61569799695695, 104.27841854095459, 100.88204874311174, 95.27829183850969, 91.19105570656913, 92.02982834407261, 90.3108023234776, 98.54930918557304, 97.95193781171525, 101.58285794939313, 102.26503903525216, 99.49634865352085, 100.28514289855957, 100.75378499712262, 93.20096111297607, 98.23204054151262, 98.72317395891461, 96.18824877057756, 95.11519677298409, 98.68700163705009, 91.48993246895927, 99.66411985669816, 90.0822343826294, 107.17583124978202, 85.37213393620083, 61.46331310272217, 102.60432652064732, 103.51333849770683, 105.39600154331752, 91.26691613878522, 98.42285891941616, 104.14788273402623, 100.70309094020298, 81.49134962899345, 97.99113259996686, 107.92470114571708, 103.79687363760812, 86.03054523468018, 91.18743569510323, 101.9946985244751, 104.99358967372349, 105.75983701433454, 103.44874804360526, 81.8527740750994, 83.59791142599923, 99.25988061087472, 103.99992084503174, 94.41561044965471, 98.08037526266915, 99.56023733956474, 88.74292046683175, 86.68794209616524, 95.15044498443604, 88.62607261112758, 86.98823629106793, 83.2826647077288, 84.99521500723702, 97.26658139910016, 92.54553059169224, 103.44944286346436, 105.21457712990897, 6.249721373830523, 0.3958413435944489, 0.5795907708151, 0.26971558002488955, 0.2785082810691425, 0.4548663449074541, 0.45899105072021484, 0.25438731110521723, 7.311565058571952, 43.01342787061419, 72.9602610724313, 67.39259311131069, 70.0941777910505, 105.11608641488212, 45.59125818525042, 34.27230569294521, 29.691212449754985, 61.16019793919155, 70.10706669943673, 66.19445964268276, 86.0395153590611, 53.79954038347517, 7.858448215893336, 0.453950078359672, 0.1541107733334814, 0.13090556780142443, 0.32323578958000454, 0.13692580190088066, 0.14761572756937572, 0.1619207113981247, 0.3345860519579479, 0.1894536947033235, 0.2409768807036536, 0.17382319271564484, 0.1555075512400695, 0.12493873440793582, 0.1181685562644686, 0.10269831746284451, 0.11162129044532776, 0.1858662393476282, 0.14297286527497427, 0.2611175642481872, 0.1540300819490637, 0.10494663646178586, 0.18176311094846043, 0.07972067900534187, 0.18802506636295999, 0.2176836013261761, 0.14822682977787086, 0.2085726402167763, 0.1716999752180917, 0.2345702616231782, 0.29006500808256014, 0.19665676461798803, 0.24692787708980696, 0.2565661956157003, 0.1990787817963532], [0.09618977563721792, 0.1063934698966997, 0.08720678623233523, 0.10410518518515996, 0.21705356799066067, 0.21045758335718087, 0.10252197978219815, 0.1635247953236103, 0.06877421281699624, 0.04011998092755675, 0.034397932434720654, 0.13924766731049332, 0.09779726580849715, 0.07860170012073857, 0.08107723335602454, 0.0932118957862258, 0.06911649302180324, 0.0971361148570265, 0.03144240691991789, 0.05606533334191356, 0.037223752588033676, 0.01142643387096801, 0.0823230372209634, 0.07556147647223302, 0.04531990011621799, 0.028742763745997633, 0.03568366469283189, 0.04307692458054849, 0.062069689721933434, 0.5297952571085521, 41.984875610896516, 90.69343961988176, 83.77231815883091, 64.15626811981201, 44.63461978094918, 31.622043882097515, 29.29410900388445, 66.60199233463833, 57.21245731626238, 92.33755016326904, 69.8906581061227, 37.82263020106724, 10.469335453850881, 0.10500594720776592, 0.05344052240252495, 0.06327220305268254, 0.18755633437207767, 0.03533591888844967, 0.20836652841951164, 0.717659239258085, 0.6945138669439724, 10.506864411490303, 51.086254937308176, 102.20083768027169, 109.61244637625558, 90.94906384604317, 88.10119874136788, 91.95177922930036, 88.76083987099784, 83.66195297241211, 82.87810584477016, 77.88429655347551, 75.16807201930455, 76.5450382232666, 78.50893265860421, 78.86330468314034, 85.03254073006767, 91.62908404214042, 92.91797488076347, 92.81161185673305, 94.88394682747978, 94.72578498295375, 91.92105429513114, 82.4971569606236, 85.77348273141044, 83.63762732914516, 82.60144247327531, 79.6768136705671, 82.17383643559047, 84.1841378893171, 90.05579648699079, 85.60419682094029, 90.03266593388149, 63.269587653023855, 77.12228066580636, 94.83183533804757, 74.37542152404785, 69.59995937347412, 70.77831132071358, 82.13156359536308, 74.42094612121582, 76.09799807412284, 94.91843073708671, 87.46343748910087, 77.17157813480922, 74.05375467027936, 81.54251616341728, 95.38615567343575, 93.41973904200962, 101.03892517089844, 94.63834885188511, 82.84068284715924, 69.63593714577812, 80.34307643345424, 95.56508568355015, 92.98339911869594, 85.93797438485282, 94.22010203770229, 91.22068977355957, 71.48851449148995, 72.09676674434117, 72.95008196149553, 75.07038729531425, 75.52814156668526, 73.9402072089059, 69.15489946092877, 86.89984825679234, 85.40082999638149, 90.42348820822579, 85.27428245544434, 9.718948245048523, 0.5500844855393682, 0.08559228000896317, 0.11726503260433674, 0.13670284886445316, 0.05284996962706957, 0.0314842725305685, 0.22248479298182897, 0.5101563909224102, 15.033134630748204, 60.82313387734549, 71.24686309269497, 42.851441042763845, 62.854557854788645, 40.40442793709891, 27.783909354891094, 17.87663800375802, 38.044079712459016, 57.36880915505545, 55.03926576886858, 62.35888726370675, 49.64796393258231, 9.405934504100255, 0.48230279982089996, 0.11131214310548135, 0.2521704286336899, 0.008177885552868247, 0.016879498359880278, 0.07205536389457327, 0.031313763465732336, 0.05251922791025468, 0.02727530793552952, 0.05421761463263205, 0.023186237085610628, 0.04207835512767945, 0.0362880561899926, 0.03755445359274745, 0.03118671117616551, 0.03637379587494901, 0.11572519237441675, 0.12193362494664532, 0.08575829717197589, 0.10122496687940188, 0.018334416539541314, 0.0425983334758452, 0.018838771618902683, 0.04411786175998194, 0.08171354314046246, 0.09067513155085699, 0.08222281081335885, 0.1084711237677506, 0.058958240252520354, 0.0868882140410798, 0.07763511341597353, 0.17498360973383698, 0.2065171269433839, 0.06266297360083886, 0.04110628925263882, 0.028669390361756086, 0.030868593603372574, 0.1383868913565363, 0.1594346947968006, 0.08133304784340517, 0.15851905250123569, 0.04940279460112963, 0.09108434923525367, 0.021406639899526323, 0.03942850624610271, 0.010285403446427413, 0.007164237355547292, 0.13438128201024874, 0.01669238554313779, 0.05899231628115688, 0.059462188210870535, 0.08935381352369275, 0.05619218207097479, 0.05453310288222773, 0.007964895955020828, 0.04387599455990961, 0.07465613433825118, 0.04453367141208478, 0.012166769859114928, 0.05143811806504216, 0.019722419292000786, 0.036769195193690915, 0.18713516768600258, 54.490156582423616, 107.39843068804059, 101.2549238204956, 86.37721865517753, 62.19704287392752, 62.25703362056187, 37.898421151297434, 25.856635400227137, 50.77346440723964, 92.87039361681256, 79.60324614388603, 48.182755606515066, 12.745313440050397, 0.15592867721404347, 0.0444745744046356, 0.032762924275760136, 0.32698298564979006, 0.38198842693652424, 0.14626570072557243, 0.7500807823879378, 1.6865936751876558, 15.957364899771553, 61.37987913404192, 114.7745201928275, 114.17918464115688, 92.72585024152482, 92.81492614746094, 101.62888976505825, 93.01042761121477, 90.16864912850517, 87.77795464651925, 81.52164377485002, 81.43012210300991, 81.05206366947719, 84.79158415113176, 84.81951590946743, 91.71228177206856, 97.0976151057652, 98.33008657182965, 97.4866725376674, 98.45774582454136, 97.49339839390346, 93.61194705963135, 88.67835780552456, 89.6214576448713, 86.84871646336147, 87.15175519670758, 83.4948696408953, 85.42637852260044, 87.3677191053118, 92.56842490604946, 91.02975327627999, 94.47936017172677, 68.8997894014631, 80.0051577431815, 101.537930897304, 82.3436643055507, 79.5424633026123, 78.11240591321672, 88.15188585008893, 78.77013628823417, 83.30806732177734, 98.03734506879533, 91.32216126578194, 80.79179109845842, 77.03682477133614, 86.2996072769165, 99.11473969050816, 94.74261351994106, 103.87752137865338, 98.9485387802124, 89.09179646628243, 74.51153673444475, 83.57454463413784, 98.06446388789585, 96.56056104387555, 88.82905728476388, 95.68824250357491, 97.35097421918596, 74.60286385672433, 74.8905679157802, 77.64379855564663, 77.79249695369175, 80.91911683763776, 78.82754925319126, 74.35766192844936, 91.9167811529977, 91.56215204511369, 92.79524884905133, 95.56225081852504, 16.39475573812212, 0.24786322404231342, 0.10908748462264027, 0.02797783086342471, 0.2575253184352602, 0.11691600776144437, 0.0016858328703425027, 0.2235440132873399, 0.4248729257711342, 18.90224596432277, 62.84611579350063, 67.3364725112915, 45.51876415525164, 32.89971685409546, 23.82280387197222, 24.004919631140574, 25.896359988621303, 67.44383607591901, 90.46605287279401, 71.98093332563127, 75.25356265476772, 71.78696046556745, 19.562161547797068, 0.4858672799808638, 0.08373933658003807, 0.1456226666590997, 0.08223517372139863, 0.010333902585054082, 0.08032602723687887, 0.0313033377751708, 0.02769169773507331, 0.025343930947461298, 0.05145115272275039, 0.03924898962889399, 0.03017424193343946, 0.1069635750193681, 0.11000755775187697, 0.027463435162124888, 0.01453775865957141, 0.05702080564307315, 0.025216471536883285, 0.05379350310457604, 0.12278853835804121, 0.00992676121781447, 0.040738289177949936, 0.05040090943553618, 0.08172147521483046, 0.03529440950868385, 0.07742127989019666, 0.03918238802413855, 0.10639056576681988, 0.15240090579858848, 0.0642163370336805, 0.08411133661866188, 0.02631974233580487, 0.18392782764775412, 0.15137475728988647, 0.1705168272767748, 0.14103163086942264, 0.13531414552458695, 0.26553157025149887, 0.2352048275726182, 0.23022785463503428, 0.26786619211946217, 0.19663327373564243, 0.21209602829601082, 0.09024564602545329, 0.18730577853109154, 0.23759240231343678, 0.10508057927446705, 0.2420610710978508, 0.13473190819578512, 0.36063449563724653, 0.18766678630241326, 0.11907928596649851, 0.15465950460306235, 0.1966227021600519, 0.12078679219952651, 0.14249824360013008, 0.12318253650196961, 0.1742252925676959, 0.13456827269068786, 0.15936624418411935, 0.09381042474082538, 0.12240429754768099, 1.5118383382047926, 80.40936919621059, 123.58927590506417, 109.7697674887521, 92.0403687613351, 67.63017286573137, 46.38388088771275, 46.76969698497227, 101.61276299612862, 90.98887702396938, 114.31401443481445, 91.59444727216447, 63.424018314906526, 19.12439203262329, 0.2629089509802205, 0.16941177871610436, 0.17845818400382996, 0.4267555618924754, 0.4861982965043613, 0.35403376125863617, 2.0263722028051103, 4.117993201528277, 12.952633789607457, 58.61078575679234, 117.70148359026227, 121.80742427280971, 98.183945110866, 93.638808795384, 104.28013474600655, 97.61795180184501, 95.86703354971749, 91.6529997416905, 84.6635844366891, 86.33477905818394, 86.97411755153111, 91.11295100620815, 89.37657533373151, 95.80118547167096, 101.45301696232387, 101.42181955065045, 103.84157834734235, 104.89780180794853, 104.44050611768449, 99.67021342686245, 96.44350474221366, 96.42027691432408, 96.00421183449882, 93.54282638004848, 88.9322588784354, 89.81472178867885, 92.36939375741142, 98.62387030465263, 96.15004757472447, 100.05251026153564, 75.98647948673793, 86.617417880467, 110.60608046395438, 89.84676688058036, 86.56179755074638, 87.08530957358224, 95.03682109287807, 85.4856675011771, 90.29976163591657, 103.79231561933244, 98.11205904824394, 86.31537273951939, 80.22003078460693, 91.18801934378487, 104.4219891684396, 101.59804671151298, 104.64813913617814, 103.67600277491978, 94.14288670676095, 76.40230137961251, 90.6053295135498, 103.58471734183175, 101.41907501220703, 91.7004142488752, 102.11010115487235, 99.5124545778547, 77.61137131282261, 78.15837519509452, 84.18818174089704, 83.60063511984688, 83.5335224696568, 81.00487150464738, 76.54302324567522, 97.97948047092983, 96.03609016963414, 99.49164472307477, 96.7748087474278, 12.682334968021937, 0.6155910161989075, 0.13242138789168426, 0.3050337891493525, 0.41918476670980453, 0.29093556851148605, 0.09584552768085684, 0.5417113634092467, 1.253787127988679, 29.294661385672434, 92.30635275159563, 93.25223187037876, 65.83377170562744, 94.94438225882394, 63.735478264944895, 43.28913239070347, 23.86075493267604, 51.20084115437099, 81.57845919472831, 73.2865206854684, 90.25396605900356, 84.79913684300014, 23.921339750289917, 0.5523380903261048, 0.19195370269673212, 0.3060285214866911, 0.10796414275786706, 0.12883332185447216, 0.185439101553389, 0.19654244503804616, 0.14915654488972255, 0.19880826345511846, 0.12767263342227253, 0.18449681997299194, 0.17068646103143692, 0.12539219936089857, 0.19964495141591343, 0.0875182541619454, 0.17449646230254853, 0.2467599803847926, 0.15031019012842858, 0.1236859280616045, 0.22971420362591743, 0.14746103515582426, 0.12253382988274097, 0.11914452032319137, 0.15262544660695962, 0.16267453666244233, 0.16414649624909672, 0.18826490135065146, 0.23432305774518422, 0.1551208948450429, 0.08961933784719024, 0.16563974826463632, 0.2657731558595385, 0.26058222725987434], [0.13053713685699872, 0.052387317309954336, 0.07562355564108916, 0.0539222958364657, 0.09566819933908326, 0.0515482409058937, 0.04097327942560826, 0.09297632878380162, 0.019725706794166138, 0.028469751788569347, 0.11842736309128148, 0.044800339067088704, 0.08203647152653762, 0.05115939623543194, 0.06661747568952185, 0.10822780789541346, 0.0463937360660306, 0.02155052325023072, 0.08889654877462558, 0.026177365332841873, 0.045988497989518304, 0.027328259112047296, 0.009369283631843115, 0.10867007023521832, 0.085382110572287, 0.012471961339802613, 0.05633409767012511, 0.02768533138026084, 0.4323906052325453, 32.13304567337036, 90.68293394361223, 83.80509281158447, 70.79085281917027, 75.08926555088588, 58.3533411026001, 30.113944326128276, 63.12132699148995, 66.4610481262207, 79.1431850705828, 58.31646006447928, 32.20836067199707, 11.11775003160749, 0.3062369945858206, 0.09365084687513964, 0.0223990906628647, 0.027023272888202752, 0.145968923079116, 0.0910523020263229, 0.5810143372842244, 6.006369837692805, 69.0585001536778, 114.16262708391461, 110.14581094469342, 93.09514004843575, 89.12976837158203, 92.08450371878487, 84.23704147338867, 77.1995654787336, 76.76507377624512, 77.16733973366874, 73.92786720820835, 77.0911249433245, 77.96042101723808, 80.5308723449707, 79.64769377027238, 84.8568902696882, 87.93958364214215, 90.38383483886719, 89.60212775639125, 88.3547454561506, 90.57875960213798, 87.21991007668632, 79.5988826751709, 81.60058920724052, 76.49925654275077, 77.46513952527727, 75.50619220733643, 82.01819678715297, 85.42183440072196, 82.99963678632463, 82.44233567374093, 87.58298124585832, 89.00838334219796, 81.64616244179862, 55.989657742636545, 82.18783705575126, 78.58538368770054, 78.60022503989083, 82.15484700884137, 88.21112619127545, 70.6198159626552, 82.47807025909424, 91.36291245051792, 85.57664026532854, 74.05969538007463, 71.67014040265764, 70.5531757899693, 86.04358005523682, 93.37007331848145, 85.75532708849225, 99.08779457637242, 90.56439767565045, 78.97752611977714, 69.84879520961216, 84.00746604374477, 95.11591938563755, 90.33427333831787, 84.9027761731829, 94.20273848942348, 75.2770962033953, 72.17210606166294, 71.80879865373883, 72.66060611179897, 77.33681324550084, 81.05969973972866, 87.26256506783622, 82.5419728415353, 87.09682968684605, 84.76041453225272, 80.55233533041817, 83.47684601375035, 27.285007851464407, 0.6848454486046518, 0.39322732814720696, 0.02965038236496704, 0.08977304638496467, 0.08072987770927803, 0.05468832455309374, 0.05896433349698782, 0.24001648223825864, 10.104423012052264, 56.466126986912315, 72.88139901842389, 45.21083736419678, 53.018489905766074, 65.32034151894706, 47.78290414810181, 23.457863637379237, 17.64492426599775, 47.829328536987305, 53.63979434967041, 67.75890908922467, 65.38034616197858, 9.276391421045576, 0.3440025438155447, 0.024888849384816628, 0.05035379535651632, 0.06349198733057294, 0.10053824872842856, 0.09966024477034807, 0.06450248203639473, 0.0335569561326078, 0.0694389192919646, 0.04275939054787159, 0.09645540852631841, 0.028398619266226888, 0.03589547957692828, 0.04040930486683335, 0.04419255828750985, 0.05097684317401477, 0.05473876345370497, 0.0515298661775887, 0.08307154955608503, 0.03128118699948702, 0.0625506964113031, 0.029259909210460525, 0.04161044755684478, 0.06736434596989836, 0.07655366430325167, 0.03642363427206874, 0.09321475920400449, 0.03845545310260994, 0.05818867976112025, 0.08838852282081332, 0.09568684548139572, 0.05391258600034884, 0.1091139814151185, 0.05650814529508352, 0.05443786709968533, 0.06456988091979708, 0.09070930935974632, 0.032021485668207915, 0.08692613057792187, 0.1099194296236549, 0.03315349581784435, 0.05811938097966569, 0.09034783339926175, 0.07568119040557317, 0.08198177481868438, 0.03762707719579339, 0.0909033025215779, 0.045070962581251345, 0.04149487947246858, 0.04770169713135276, 0.05779744325471776, 0.02000125477622662, 0.05315525610265987, 0.1028688061716301, 0.043404813057609966, 0.07615390539701496, 0.1258097698113748, 0.007052555156406015, 0.09476289791720253, 0.03791037913677948, 0.26145672319190844, 42.83863203866141, 111.11836419786725, 94.1568386895316, 92.94612898145402, 87.7145106451852, 83.76584938594273, 38.653019836970735, 20.973642928259714, 59.44757815769741, 88.23756408691406, 70.52331243242536, 40.241086210523335, 12.989587783813477, 0.4352265016308853, 0.06937229393848351, 0.0732006902939507, 0.036202632023819854, 0.10704960647438254, 0.036128251015075614, 0.33025865416441647, 10.370704906327383, 80.7697444643293, 122.91866356985909, 117.84254591805595, 96.82342529296875, 93.62839344569615, 98.44068104880196, 87.49109131949288, 78.25234958103725, 80.09858322143555, 78.78818075997489, 79.15699808938163, 81.519503729684, 82.66273253304618, 85.87848390851701, 85.05831854684013, 87.36901147024972, 92.98948574066162, 93.91151864188058, 93.98260566166469, 92.03039809635708, 94.57078456878662, 90.0163585117885, 83.78092697688511, 85.42576013292584, 79.72540937151227, 81.69846848079136, 79.49921771458217, 87.5667085647583, 86.90716470990861, 86.60944829668317, 86.0727208001273, 91.11448655809674, 94.15519196646554, 86.57285213470459, 60.25714751652309, 85.99736758640834, 85.31672900063651, 84.76317991529191, 88.23619529179165, 93.24308804103306, 74.0254407610212, 86.50121620723179, 94.36422157287598, 88.59903022221157, 76.37459891183036, 72.88843059539795, 72.31003475189209, 89.31081758226667, 96.82862949371338, 89.44004712785993, 100.68499783107212, 97.1917006628854, 85.7188698904855, 73.30138288225446, 88.3971781049456, 99.55107961382184, 91.98451219286237, 88.14085905892509, 96.05242538452148, 79.1867641721453, 74.81761877877372, 75.9646690913609, 75.94573525020054, 81.67983341217041, 85.20823982783726, 89.58343710218156, 88.46429075513566, 91.27862385341099, 89.18540954589844, 82.55432673863002, 94.14210156032017, 42.217786175864084, 3.1139103259359087, 0.425610927598817, 0.11936850473284721, 0.09982244178120579, 0.09227292545671974, 0.01334299165422895, 0.09195087238081864, 0.11632912925311498, 10.28701298577445, 62.187690598624094, 72.94959558759416, 50.6937894139971, 37.250977584293906, 26.68669673374721, 19.01058053970337, 20.18605419567653, 37.74708243778774, 77.4241521017892, 73.8662714276995, 75.85390785762242, 83.98543330601284, 21.097751651491436, 0.1505394671112299, 0.053075962500380616, 0.007379155689185219, 0.08465663450104849, 0.02535777645451682, 0.037011103105864356, 0.07451645790466241, 0.02592537778296641, 0.034442213630037646, 0.061819995620421, 0.07849326343940836, 0.03989522638065474, 0.029559224577886716, 0.046099811659327576, 0.05941108773861613, 0.06029717983411891, 0.07459646396871124, 0.02456122214373733, 0.05231678020209074, 0.048359072035444636, 0.0316543609036931, 0.011748957680538297, 0.03340565300147448, 0.02023268271503704, 0.06386625367615904, 0.09728428654904876, 0.08904300377305065, 0.021584132786041925, 0.040549581803913624, 0.033254655211099556, 0.1771992165595293, 0.022658236757186905, 0.1532612339194332, 0.09091909203146185, 0.2095484957098961, 0.08920222880052668, 0.23020625008004053, 0.1311694500701768, 0.21888508328369685, 0.170512213238648, 0.13253972439893655, 0.10882567188569478, 0.1832955280052764, 0.14242931801293576, 0.12402974175555365, 0.13380584360233375, 0.13972424316619123, 0.11919465049036912, 0.20293965962316307, 0.14482046184795244, 0.23133910500577518, 0.14172547363809176, 0.19992693699896336, 0.1491209625133446, 0.1636211880083595, 0.2718786410987377, 0.20662527185465607, 0.13090183585882187, 0.19762411128197396, 0.13628792470054968, 0.5467115151030677, 67.65026010785783, 129.1026575905936, 110.55369104657854, 99.90718173980713, 98.13041618892125, 81.82503686632428, 45.98804896218436, 94.13886369977678, 107.3691440309797, 98.71364103044782, 81.18023014068604, 53.93043402263096, 18.460066080093384, 0.6531880987542016, 0.19381069019436836, 0.2881665213831833, 0.12257637402841023, 0.2567423161651407, 0.5933389216661453, 1.6243728825024195, 8.972242712974548, 78.4779645374843, 128.4603661128453, 122.7159012385777, 100.91375337328229, 94.6592629296439, 100.45676340375627, 94.39077758789062, 83.07310703822544, 84.61037513187954, 83.8004583631243, 84.19481032235282, 85.03370107923234, 87.73543861934117, 88.73487445286342, 89.5381417955671, 91.54834597451347, 97.97436659676688, 100.2158693586077, 98.45167309897286, 97.82079751150948, 98.6170471736363, 95.38084030151367, 88.46527739933559, 90.75564684186662, 87.86703055245536, 86.96358408246721, 84.80304173060826, 93.82616002219063, 93.8238045828683, 90.16294465746198, 89.72189385550362, 97.36537088666643, 97.81701074327741, 89.53988579341343, 65.90295491899762, 90.7716554914202, 93.87172630855015, 93.14449310302734, 95.69541999271938, 98.98938723972866, 83.89505113874162, 91.57800783429826, 97.80908979688371, 92.64575140816825, 80.39386081695557, 77.25646427699498, 76.51880877358573, 94.59834112439836, 100.47494683946881, 94.5244470323835, 103.96173354557583, 99.81424958365304, 89.25632286071777, 77.8687812260219, 93.50948197501046, 102.10089479173932, 93.7185810634068, 90.65232712881905, 103.24252550942558, 82.71548325674874, 77.70217732020787, 79.45096247536796, 81.63423933301652, 85.21431950160435, 90.95137064797538, 93.63530690329415, 90.85241440364292, 95.9016981124878, 91.44700649806431, 85.62423542567662, 97.55311816079276, 36.43605463845389, 2.417923386607851, 0.5256094017199108, 0.2686211573226111, 0.2682230472564697, 0.14773691392370633, 0.22767318386052335, 0.15394135671002523, 0.4097123092838696, 16.181989737919398, 77.37721702030727, 91.38229792458671, 65.8029842376709, 82.16636712210519, 101.37085451398576, 74.39415386744908, 34.97951766422817, 25.04946490696498, 63.7001188823155, 74.47780323028564, 84.83426693507603, 98.9164103099278, 25.316235780715942, 0.35500667190977503, 0.11143778064953429, 0.11046732629516295, 0.175642372242042, 0.239745203937803, 0.13128499101315225, 0.1387153294469629, 0.07863013073801994, 0.12635011438812527, 0.13263135376785481, 0.12107055554432528, 0.12384237109550408, 0.1320092457213572, 0.08990374580025673, 0.10026372703058378, 0.10012825072876044, 0.1558275619255645, 0.11432981224996702, 0.1947833972850016, 0.12800724618136883, 0.1087045194581151, 0.08638283437384026, 0.08342026905821902, 0.16703772039285728, 0.14539132692984172, 0.15198216826788016, 0.18469355441629887, 0.1255500673183373, 0.17922834839139665, 0.15230813649083885, 0.29581078833767344, 0.19187267204480513], [0.07539775954293353, 0.07754196412861347, 0.0794217571882265, 0.2057604654026883, 0.08219041755156857, 0.028071841890258447, 0.03303903713822365, 0.08882470548685108, 0.061296112303222926, 0.13835500021065983, 0.10540544148534536, 0.040208132804504464, 0.09134635196200439, 0.09211072844586202, 0.05878004338592291, 0.05754394257175071, 0.12840653689844267, 0.10609696366425071, 0.09354533467973981, 0.05018355770568762, 0.1419369594327041, 0.048189333107854636, 0.08539904680635248, 0.18171976613146917, 0.11755248717963696, 0.059086374805441925, 0.3396623081394604, 0.5874072770987238, 23.588048560278757, 86.18871402740479, 82.77974714551652, 89.53500815800258, 89.48409870692662, 75.77224567958287, 24.392816713878087, 52.047986371176584, 70.02889946528843, 72.40127154758999, 57.55261680058071, 28.878023079463414, 8.387344224112374, 0.6488410777279309, 0.165603460211839, 0.04467279823230846, 0.027330689963751605, 0.08595984242856503, 0.1599115284958056, 0.1799128409475088, 6.598342461245401, 98.9140270778111, 103.30352374485561, 85.55617782047817, 87.00688525608608, 93.60864666530064, 84.0907541002546, 72.31358528137207, 69.88621820722307, 74.7779793058123, 71.48453317369733, 74.35247162410191, 75.33981759207589, 73.05441611153739, 70.21550723484584, 75.70208971840995, 78.17285524095807, 82.5416601725987, 89.30872617449079, 91.50769206455776, 89.36768858773368, 92.12930570329938, 87.80803339821952, 84.0902121407645, 78.91051769256592, 76.79478427342006, 72.37139429364885, 74.147034236363, 75.07243701389858, 78.77016408102853, 78.80748285566057, 81.34764698573521, 81.51886449541364, 83.35148661477226, 85.8467584337507, 92.1671108518328, 56.95337288720267, 65.94157995496477, 91.7661442075457, 68.74177346910749, 77.14557102748326, 66.48424816131592, 64.56983184814453, 84.29937376294816, 94.80177743094308, 85.53576401301792, 84.32164273943219, 69.61175046648297, 71.69340297154018, 78.37292167118618, 96.40428910936627, 87.42752225058419, 88.57702527727399, 100.49199771881104, 89.72889069148472, 75.12572274889264, 67.97614451817104, 82.69056701660156, 94.34463460104806, 96.16636194501604, 91.33262525285993, 70.15227167946952, 70.01559366498674, 80.06892136165074, 85.7947998046875, 84.41993195669991, 88.595778465271, 85.49888297489711, 89.75544670649937, 88.23613970620292, 82.92245619637626, 84.38722678593227, 80.79377133505685, 92.43213599068778, 68.34228679112026, 5.4474263446671625, 0.37874589807220865, 0.07898999178516013, 0.09216471947729588, 0.14882581335093292, 0.029188825881906917, 0.11730537829654557, 0.2564069570175239, 6.157802351883479, 43.47100496292114, 57.391314370291575, 53.04965257644653, 64.63501984732491, 81.56660556793213, 105.57167979649135, 58.32659748622349, 16.838222776140483, 31.49901212964739, 47.88061319078718, 57.86877025876726, 64.57303496769497, 22.05554345675877, 0.47587902737515314, 0.019133191356169324, 0.04399997308584196, 0.07197416360889163, 0.05227660075096147, 0.04381495015695691, 0.04352826571890286, 0.07141614319490534, 0.052027211990207434, 0.03409087159005659, 0.05099980479904583, 0.003449304777729724, 0.023971775380362357, 0.06841399214629616, 0.03148358381752457, 0.006533414374903909, 0.07419109357787029, 0.09095908488546099, 0.04975274225164737, 0.03413851831906608, 0.08495153939085347, 0.020292159702096666, 0.10271002219191619, 0.12802897287266596, 0.040733050887605975, 0.09501871240458318, 0.09525067638605833, 0.022939978067630103, 0.03169173800519534, 0.06569767397429262, 0.046101945651961226, 0.0818065974329199, 0.05304925875472171, 0.049259314978761334, 0.1028278430125543, 0.056068237471793375, 0.04432363768241235, 0.05429785139858723, 0.07689240934061152, 0.05703165541802134, 0.057678143227738995, 0.04326176091230341, 0.01735122438653239, 0.05674086245042937, 0.05562343401834369, 0.045806776133498976, 0.020427522349304388, 0.03476741171575018, 0.038153362526957474, 0.052202857565134764, 0.043148214862282784, 0.09435467767928328, 0.08430332810218845, 0.06874439120292664, 0.14961288683116436, 0.1054216856136918, 0.09177285193332604, 0.24953727849892207, 0.534966236778668, 31.330136162894114, 102.20772334507534, 95.88703046526227, 112.08046041216168, 110.42211300986153, 103.11406026567731, 46.46833276748657, 33.3237932068961, 56.938878944941926, 81.90574019295829, 66.30998734065464, 36.48380265917097, 8.959776776177542, 0.7673002641115869, 0.11330316841070141, 0.0579205227217504, 0.08426749466785363, 0.37796661417399136, 1.0172706650836127, 0.4383693129888603, 10.974028280803136, 108.62771987915039, 107.1759980065482, 89.36012894766671, 90.39490331922258, 99.615829876491, 90.7169245311192, 73.91010761260986, 73.9125394821167, 78.80032621111188, 78.40074920654297, 77.40580190931047, 77.71871403285435, 76.79915469033378, 74.75113146645683, 80.4012814930507, 83.20041888100761, 85.70051969800676, 95.10305132184709, 94.18222045898438, 95.34342425210136, 96.64075020381382, 91.67323289598737, 87.85292570931571, 83.85639830998012, 79.53179086957658, 78.57702500479562, 79.6595960344587, 79.830153465271, 83.43138395036969, 82.58033384595598, 86.07081699371338, 85.2451833997454, 87.19015789031982, 89.87154415675572, 97.09699671609062, 62.85409232548305, 67.22266101837158, 97.25232369559151, 75.51547500065395, 83.65291336604527, 70.35062190464565, 69.9373777934483, 88.63107531411308, 96.54401043483189, 89.06091172354562, 87.59704439980644, 71.94126605987549, 74.47612871442522, 81.02362469264439, 99.40554959433419, 89.43809468405587, 90.98754296983991, 103.4174325125558, 94.59982803889683, 76.67991665431431, 70.74948324475969, 86.10712133135114, 96.8829505102975, 98.53909533364433, 93.85514095851353, 72.57731805528913, 74.45466572897774, 82.48536586761475, 89.61535712650844, 88.8354913166591, 92.07943153381348, 87.33561842782157, 91.67800630841936, 93.03287029266357, 87.34003053392682, 88.26799719674247, 84.29904024941581, 95.18285138266427, 83.59904398236955, 12.980202504566737, 0.3375042682247502, 0.09013933994408165, 0.10246560709284884, 0.22231856547296047, 0.05999519782406943, 0.09786064776458911, 0.2044094886098589, 5.5212622455188205, 50.508105754852295, 65.40915339333671, 58.664266041346956, 64.30983025687081, 79.44634192330497, 74.339950970241, 27.531858239855083, 26.69063115119934, 60.111235346112935, 70.83295890263149, 68.46042701176235, 82.4471160343715, 38.869501386369976, 0.1999729416732277, 0.07089778315275908, 0.047644364314952066, 0.017652756867132018, 0.038662864294435294, 0.057283425836690834, 0.06951143432940755, 0.07563722812171493, 0.024458821031398008, 0.10182450685117926, 0.034125137608498335, 0.01975527565394129, 0.041061163281223605, 0.06135232214416776, 0.050012726336717606, 0.016824652374322926, 0.05625502119905182, 0.0776910518429109, 0.10753052495419979, 0.054244942630508115, 0.11220530553587846, 0.023974808431895714, 0.05650335483785186, 0.06595791250999485, 0.03740576621411102, 0.03408179957685726, 0.10911354036735636, 0.005219275248236954, 0.04868408013135195, 0.020933494038347687, 0.06719917697565896, 0.13607907162180968, 0.15312910958060197, 0.17953455767461232, 0.25595393989767345, 0.1645842327603272, 0.17188814654946327, 0.14566270022519998, 0.15278385739241326, 0.09926966644291367, 0.16664821415075234, 0.1361461923058544, 0.10070489014365844, 0.12799914447324617, 0.18518751433917455, 0.145785284361669, 0.08336908037641219, 0.17591816958572182, 0.1387823008533035, 0.13673830910452775, 0.19319771522922174, 0.22652867170316832, 0.13536700340253965, 0.16748038306832314, 0.2542984230177743, 0.2313194546316351, 0.2284721859863826, 0.390951114573649, 2.874242637838636, 54.42379086358206, 121.12344360351562, 107.00924124036516, 119.47359384809221, 114.26668330601284, 102.1389639718192, 34.756626401628765, 88.04709311894008, 112.40560831342424, 90.73478140149797, 82.91331931522915, 49.22929675238473, 14.862373965127126, 1.0982635361807687, 0.4484735407999584, 0.22480197649981293, 0.1587539477539914, 0.1846371545855488, 0.5134008739675794, 1.4858229798930032, 9.481393677847725, 112.55485561915806, 115.90893868037632, 93.91128935132707, 93.40596076420375, 103.65063490186418, 95.60359954833984, 78.62659345354352, 77.64443778991699, 81.07422842298234, 82.49387046269008, 81.9856653213501, 83.32272107260567, 81.87086023603166, 78.9799371446882, 85.38915007455009, 90.17496504102434, 91.01300116947719, 97.10989952087402, 96.75579152788434, 98.83139215196881, 101.41485050746373, 96.63130760192871, 94.54796668461391, 90.25503608158657, 86.1950855255127, 84.51099504743303, 85.0629529953003, 86.48677785055978, 89.5169984272548, 89.2473110471453, 90.56525925227574, 90.46783855983189, 91.4677677154541, 95.80479853493827, 99.26586300986153, 69.66640499659947, 78.78260135650635, 102.23881653376988, 83.2192554473877, 89.22123445783342, 79.07092380523682, 76.37734345027378, 95.99641595567975, 102.24274921417236, 95.25851726531982, 91.4938304083688, 75.64529514312744, 79.09681974138532, 86.59371757507324, 105.83958148956299, 93.6859245300293, 94.55893094199044, 105.20129912240165, 98.91847392490932, 81.3283587864467, 76.7690828868321, 92.38934898376465, 105.779465675354, 102.26591450827462, 99.25898429325649, 75.4618627003261, 79.43880312783378, 87.03850650787354, 95.67155293055943, 92.01394476209367, 96.31715175083706, 90.9955472946167, 96.54590034484863, 97.29823739188058, 92.21648475102016, 88.67136791774205, 85.54945196424211, 101.01628793988908, 78.58370222364152, 9.155548351151602, 0.637748007263456, 0.35049487543957575, 0.2216616892921073, 0.31050367706588333, 0.08118826204112597, 0.2768640550119536, 0.4911608302167484, 12.42952823638916, 64.43678079332624, 73.95354775020054, 78.7180734361921, 90.3562296458653, 115.4010670525687, 145.03180585588728, 74.61206327165876, 22.092693737574987, 48.18181759970528, 68.8663546698434, 75.59879779815674, 96.93745912824357, 43.290032182421, 0.4123885871044227, 0.11491329808320318, 0.10490546295685427, 0.17514848017266818, 0.11071913064058338, 0.10370613874069282, 0.15380313912672655, 0.15292678400874138, 0.12023598461278848, 0.2202453695769821, 0.12552733639521257, 0.09091713106525795, 0.14521475854728902, 0.1017050032636949, 0.12007730241332736, 0.12064529050673757, 0.09079774961407695, 0.12907782516309194, 0.19317077738898142, 0.10361663318638291, 0.24909153527447156, 0.12440529731767518, 0.1799981463700533, 0.1947695551706212, 0.06861897757542984, 0.0820710225296872, 0.23613803035446576, 0.11988713618900095, 0.18407825886138848, 0.11013871178563152, 0.09937153490526335], [0.02051884977013937, 0.06904190845255341, 0.09959271017994199, 0.17283612782401697, 0.07458681520074606, 0.048562344163656235, 0.052049454368118725, 0.052468677051365376, 0.07920120616576501, 0.15244213358632155, 0.06407619919627905, 0.10115596665335552, 0.0841043477079698, 0.07749736402183771, 0.10371527182204382, 0.06608291901648045, 0.08252388358648334, 0.06900300125458411, 0.03531345598665731, 0.045443003331976276, 0.04462096833490899, 0.027228543302044272, 0.06075994071683713, 0.11827949674001761, 0.3331744819879532, 0.34783344396523064, 11.977407217025757, 57.20894152777535, 102.28739833831787, 87.93390001569475, 75.37851905822754, 59.29465525490897, 51.140895571027485, 19.868452038083756, 53.73528691700527, 61.270889690944124, 49.128384590148926, 64.90175424303327, 27.714997121265956, 5.569617365087781, 0.7328719943761826, 0.29040373276386944, 0.15015542986137526, 0.08816839927541358, 0.11135254986584187, 0.2151469795831612, 0.7030219904014042, 0.6327832479562078, 70.15330696105957, 97.711106300354, 79.44935049329484, 85.13095501491001, 77.33109487806047, 75.35462420327323, 68.13971900939941, 76.93166378566197, 77.52330984388078, 78.02808257511684, 75.44378348759243, 73.82841069357735, 70.23407976967948, 70.31977190290178, 70.8028870991298, 69.97321660178048, 76.01083987099784, 84.0245794568743, 87.58479472569057, 89.82207993098667, 88.41097027914864, 86.09395449502128, 79.70227881840297, 75.68942315237862, 74.26648071834019, 70.212463923863, 68.6779681614467, 72.70187146323067, 76.53755501338414, 82.75711686270577, 80.2514088494437, 83.47529656546456, 80.81979233877999, 82.64213807242257, 83.33540848323277, 87.35335717882428, 72.99136120932442, 37.10606248038155, 57.36091252735683, 84.7240824018206, 76.20944717952183, 58.013264996664866, 74.29510034833635, 87.5907632282802, 87.86659976414272, 94.29489244733537, 89.84955310821533, 77.26081384931291, 65.38645362854004, 72.08747005462646, 80.56627341679165, 92.38527733939034, 81.26793725149972, 90.07520280565534, 91.80165645054409, 76.68809468405587, 67.30544880458287, 72.60989815848214, 80.65779508863176, 81.10045092446464, 81.95023645673479, 68.5649140221732, 70.05134214673723, 77.68835040501186, 85.78010436466762, 87.23694705963135, 86.98293481554303, 91.30934878758022, 87.47764655521938, 86.59164006369454, 86.23985971723283, 85.15134797777448, 87.58373165130615, 78.31652314322335, 86.82177134922573, 92.28088065556118, 9.200692534446716, 0.4311023386461394, 0.0816079970183117, 0.028794491863144294, 0.06121753116271325, 0.05956049436437232, 0.028648155608347485, 0.15893817001155444, 5.956419238022395, 52.029962744031636, 84.6720473425729, 83.82450607844761, 98.62941496712821, 100.64281531742641, 133.4980741228376, 69.44864845275879, 13.104870557785034, 39.04812567574637, 59.14545658656529, 59.173152106148855, 63.300423758370535, 31.440181732177734, 1.0235330547605241, 0.2549715026148728, 0.033392899935798984, 0.006763966155371496, 0.09252418697412525, 0.08199818858078547, 0.0460127963285361, 0.058980340138077736, 0.10418797324278525, 0.07155775345329728, 0.032488500965493064, 0.056590499090296884, 0.02553104715687888, 0.08430196424680096, 0.11004606461418526, 0.03838467850748982, 0.05595404002815485, 0.05784525961748191, 0.019826189348740236, 0.06922478721077953, 0.037659243148352416, 0.03830957146627562, 0.0061872635518998974, 0.09503623217876468, 0.05080197452168379, 0.08065078766750437, 0.07066475387130465, 0.06952434685081244, 0.13483534407402786, 0.19029365320290836, 0.07653736589210373, 0.022231316094153693, 0.03794883171628628, 0.02090318387906466, 0.1008115354925394, 0.03806764319805162, 0.15275409684649535, 0.02359098831324705, 0.07607825552778584, 0.10814231248306376, 0.05753560337637152, 0.08102071138897113, 0.016167387732171586, 0.015889193463538374, 0.06995999347418547, 0.07217591921133654, 0.03718518805024879, 0.0491158014296421, 0.03553279582411051, 0.05522028922236391, 0.03324382579220193, 0.053125739829348664, 0.020973807500143136, 0.19285633069063934, 0.36128898337483406, 0.20196327487272875, 14.644513198307582, 68.13111019134521, 117.18373162405831, 103.74526241847447, 98.85518278394426, 87.0691202708653, 86.59869248526437, 49.10576125553676, 31.759378501347133, 33.10611309323992, 64.53463922228131, 73.88362107958112, 35.22004345485142, 6.603841960430145, 0.6317584429468427, 0.28038168911423, 0.07697056300405945, 0.13165985446955475, 0.9015153050422668, 3.0252775847911835, 1.1330001865114485, 1.0885962034974779, 79.48562008993966, 102.62546294076103, 85.8749611718314, 91.05323123931885, 81.40426090785435, 78.03719861166817, 71.54131385258266, 84.60423292432512, 83.51410225459507, 83.11643600463867, 78.24057933262416, 78.80841391427177, 74.37313556671143, 75.3666306904384, 74.4938188280378, 72.72077056339809, 79.51159940447126, 88.07172448294503, 88.67461967468262, 92.7723753792899, 91.12466566903251, 91.0216030393328, 83.9460231236049, 80.48555619376046, 78.32162312098912, 75.62766756330217, 71.69718973977226, 76.52225508008684, 80.63166986192975, 86.59703186580113, 86.77566310337612, 87.4871516908918, 86.30850097111293, 84.6316227231707, 88.78633281162807, 91.00296102251325, 77.2903436933245, 42.08941125869751, 55.524281297411235, 87.8847484588623, 81.24894782475063, 64.90400545937675, 78.58138847351074, 90.26688276018415, 90.10139751434326, 97.4032177243914, 94.08423001425606, 81.20057446616036, 68.00928047725132, 76.05860873631069, 82.21890939985002, 95.48984364100865, 83.58193751743862, 92.96308953421456, 95.51290471213204, 82.4828714643206, 70.60130596160889, 75.40971646990094, 82.92704200744629, 84.42500414167131, 82.13356467655727, 72.39697756086076, 73.1537892477853, 83.92376804351807, 88.21098027910504, 89.39286885942731, 88.78604793548584, 94.74586527688163, 89.33587278638566, 89.36092104230607, 89.97637162889752, 89.7637220110212, 93.23628575461251, 83.74632494790214, 85.95449720110211, 103.5831401007516, 19.438744170325144, 0.2036660856434277, 0.014412765723786183, 0.03203876795513289, 0.0429930814009692, 0.06116805238915341, 0.028235119468133365, 0.08619839498507124, 5.172509142330714, 56.721164090292795, 89.50145530700684, 86.59634399414062, 99.02810955047607, 107.69132505144391, 106.04721450805664, 56.7402195249285, 27.11515392575945, 54.63856315612793, 77.1386992590768, 66.75629792894635, 76.29438195909772, 51.29448897497994, 2.4132198904241835, 0.298450588115624, 0.07784267049282789, 0.07107291982642241, 0.1344964022615126, 0.03215078730136156, 0.06268613878637552, 0.053231252024748495, 0.026933031123397604, 0.040853925115828, 0.03131568032716002, 0.03101248713210225, 0.09505362981664282, 0.024433438732687916, 0.02394019636059446, 0.018812688732785837, 0.14928197887326988, 0.09397176001220942, 0.007502348810833479, 0.08866239312504019, 0.02183723482968552, 0.07602513980652605, 0.07448407142822232, 0.12204456542219434, 0.02968696897317256, 0.09912111477128097, 0.0869296318186181, 0.021941386562372957, 0.06308865933013813, 0.05805172425295625, 0.16036962105759553, 0.172102156494345, 0.10106393694877625, 0.20053973554500512, 0.16189689481897013, 0.16025801561772823, 0.17959061823785305, 0.16305186998631271, 0.09016166374619518, 0.157872490052666, 0.1078663319349289, 0.12558814670358384, 0.10018009758953537, 0.1449981973107372, 0.2039231825619936, 0.11904252293918814, 0.2134256719478539, 0.14931201083319529, 0.20129261086029665, 0.12520786853773253, 0.1851000376045704, 0.16057550215295383, 0.20677106188876287, 0.24840816908649035, 0.4546183267874377, 0.41964386350342203, 26.240294081824167, 97.40069552830288, 135.74983242579867, 114.25168214525495, 106.15836484091622, 79.97169521876744, 64.05608204432896, 33.20744909558977, 73.86076150621686, 91.34304060254777, 72.02706936427525, 92.32423046657017, 47.790835516793386, 10.910039714404515, 1.2604709693363734, 0.5733918377331325, 0.2997822809432234, 0.2623065747320652, 0.4261983489351613, 1.145755342074803, 2.4806106856891086, 2.686705763850893, 81.80287211281913, 111.35752119336809, 87.00766345432827, 95.82976341247559, 86.90728282928467, 83.85646084376744, 74.34049987792969, 87.58191122327531, 88.69621467590332, 88.24928569793701, 82.80160617828369, 81.66652066367013, 77.75427491324288, 79.77747222355434, 78.15244143349784, 77.18187536512102, 83.59511130196708, 94.00178963797433, 96.59894984109062, 98.37500667572021, 97.55261094229562, 95.14562293461391, 87.81828893933977, 85.09811088017055, 83.45691858019147, 82.84374005453927, 76.59696211133684, 80.41192613329206, 83.94828128814697, 92.67018127441406, 90.50385107312883, 91.83097784859794, 89.59608282361711, 90.04134423392159, 92.66766602652413, 96.00824178968156, 78.97584465571812, 50.940603324345176, 68.80637781960624, 93.91445078168596, 87.11668763841901, 74.22619506290981, 85.07445226396833, 92.76906108856201, 96.10691315787179, 99.53321579524449, 98.69030897957938, 85.49953610556466, 70.86696338653564, 80.00818020956856, 87.08914497920445, 101.17890357971191, 88.29547732216972, 94.98373685564313, 100.33767127990723, 86.31080777304513, 73.86262362343925, 79.41663837432861, 87.35735934121269, 89.60956232888358, 89.82415744236538, 76.97841821398053, 77.92237962995256, 86.05271693638393, 93.45937851497105, 94.64287907736642, 93.72436196463448, 99.20749814169747, 92.42279761178153, 95.44376318795341, 92.00208418709892, 94.68152495792934, 94.62945515768868, 86.69909395490373, 96.08966772896903, 104.321914264134, 14.75041937828064, 0.7329674235412053, 0.3253613683794226, 0.08462546260229178, 0.1622647015111787, 0.13173707175467694, 0.17209922522306442, 0.21162660419940948, 11.847421186310903, 71.44408770969936, 96.39278984069824, 93.18939931052071, 100.19193281446184, 115.06986727033342, 172.9764461517334, 90.95307990482875, 19.737700836999075, 49.64680358341762, 79.58463886805943, 75.62216459001813, 90.96837983812604, 59.75797503335135, 2.425659554345267, 0.3522424288094044, 0.07392088736274413, 0.15313812052564962, 0.1681198887526989, 0.140332821224417, 0.17044149631900446, 0.11229004098900727, 0.12400524664138045, 0.14917620883456298, 0.13102330719786032, 0.09405161001320396, 0.11521688822124686, 0.16020332569522516, 0.20165656347359928, 0.303862881979772, 0.2884908068392958, 0.19751308938222273, 0.07996474126619951, 0.1610536386391946, 0.10997456737927028, 0.15854662816439355, 0.17426597752741405, 0.30939432659319466, 0.10811371223202773, 0.15323980578354426, 0.14999453563775333, 0.12884666185293878, 0.19824273165847572, 0.2209680772253445], [0.07042922079563141, 0.015354007449267166, 0.11042259048138346, 0.07376558426767588, 0.1357285947139774, 0.09767435597521917, 0.11911755534155027, 0.1157224103808403, 0.04858524472053562, 0.033710912335664034, 0.16283091184284004, 0.04413471317717007, 0.057110406192285676, 0.055213676898607185, 0.03566267081935491, 0.07913205666201455, 0.04187898796850017, 0.019165693183562586, 0.09837091966931309, 0.059368842148355076, 0.010676539020745881, 0.03473258590591805, 0.03676198236644268, 0.2104752388383661, 9.192085453442164, 51.552468640463694, 96.94513688768659, 101.37496784755162, 84.41732638222831, 85.03387478419712, 77.99156979152134, 51.6258659362793, 29.64835943494524, 62.79975046430315, 90.89680644444057, 59.706092834472656, 48.07398850577218, 34.66084895815168, 3.2085200377873013, 0.2426842376589775, 0.08619698363223247, 0.1870760672858783, 0.022718911358554448, 0.28046867730362074, 0.034288715438119004, 29.17672266278948, 3.3597354207720076, 9.390765718051366, 108.17651775905064, 85.03067166464669, 94.60240582057408, 68.51069722856793, 75.03188732692173, 73.06892395019531, 82.74721567971366, 76.23770550319126, 83.16287776402065, 81.64954621451241, 83.26120172228131, 79.12719031742641, 79.34364059993199, 67.85869216918945, 66.68013872419084, 63.19664546421596, 65.8177352632795, 67.85808072771344, 77.87037931169782, 81.12654835837228, 83.0429379599435, 80.99524824959892, 81.86810180119106, 74.90447126116071, 75.52950341360909, 67.59576538630894, 70.67824336460659, 73.95225538526262, 78.06578350067139, 81.57931382315499, 84.13994039808, 82.07670061928886, 83.69667312077114, 76.28238242013114, 79.39141641344342, 79.61423819405692, 85.99882670811245, 47.691771575382774, 23.686045953205653, 32.125142097473145, 46.488204615456716, 57.59278086253575, 78.01882757459367, 85.02224349975586, 88.3171695981707, 87.5353513445173, 89.62144374847412, 78.38376780918666, 66.35034247807094, 69.34826782771519, 73.98034000396729, 83.9263527733939, 86.82399477277482, 85.63349737439836, 94.78175272260393, 84.96105766296387, 71.92397894178117, 63.773853165762766, 71.7449586050851, 72.89452416556222, 70.03246389116559, 66.73145117078508, 68.1564085824149, 80.81738131386894, 86.61122703552246, 83.74133614131382, 85.47425161089215, 81.57294927324567, 89.96422617776054, 85.12239483424595, 86.6728297642299, 85.4659971509661, 81.02528531210763, 84.85999611445835, 80.44956452505929, 77.35620566776821, 91.6808967590332, 5.568766210760389, 0.3651908311460699, 0.060767248538987975, 0.11679039735879217, 0.17524287796446256, 0.13837367349437305, 0.07070884507681642, 0.0673442409772958, 3.655655724661691, 44.56791360037667, 88.93724073682512, 105.92835862295968, 100.31196294512067, 70.28656646183559, 68.26293836321149, 40.294285093035015, 28.333313839776174, 33.15655354091099, 64.40135192871094, 58.96640845707485, 67.66060597555978, 54.499915327344624, 3.6579025983810425, 0.20427627861499786, 0.02404091470608754, 0.06242261614118304, 0.027042897817279612, 0.06829872940267835, 0.050894357064472776, 0.03136856873918857, 0.04941251800794687, 0.01109021298387753, 0.022419999719464352, 0.03996669986684408, 0.0801583815898214, 0.04756006651691028, 0.02412149922123977, 0.13052097415285452, 0.029603926464915276, 0.03154198871925473, 0.09039778714733464, 0.09961417224258184, 0.05506662818204079, 0.06639344378241471, 0.03754933743870684, 0.05422859672190888, 0.14867876124169144, 0.08324336140815701, 0.04462821508890816, 0.16429254412651062, 0.06271911558828183, 0.0872328080503004, 0.06528775061347655, 0.08138743921050004, 0.01899251408342804, 0.09606344598744597, 0.11958764440246991, 0.11860128518726144, 0.10673592652061156, 0.03316845412233046, 0.011188977148516901, 0.11051961420369999, 0.07500841614923306, 0.08040491371814694, 0.028939182670520883, 0.05491783902315157, 0.061972055318100114, 0.02855406315731151, 0.04524191947919982, 0.14091337578637259, 0.13807224109768867, 0.01364334942107754, 0.01685738829629762, 0.10103701267923627, 0.14443247552428926, 8.901677676609584, 62.4698360988072, 112.98141942705426, 117.83185958862305, 98.88198198590959, 92.8880420412336, 96.46669088091168, 81.20737675258091, 34.319720200129915, 24.585726499557495, 47.04942103794643, 66.69509819575718, 56.99052143096924, 41.61296285901751, 3.7346932206835066, 0.5492163406951087, 0.03393937846911805, 0.2617444763226168, 0.07572707294353417, 1.022953748703003, 0.7071676222341401, 29.48110239846366, 2.6338988031659807, 12.14687899180821, 114.08354268755231, 91.2211969920567, 99.05770887647355, 73.25646277836391, 79.39584241594586, 78.67644677843366, 88.42203181130546, 79.80202020917619, 85.75950990404401, 89.46748556409563, 90.00708961486816, 83.84013952527727, 85.64167540413993, 72.65384551456997, 73.07304423195976, 66.99444048745292, 68.28869533538818, 69.25049277714321, 80.0601944242205, 84.58859252929688, 86.8220909663609, 85.25891304016113, 84.69451781681606, 80.57892608642578, 79.27433231898716, 71.53269113813127, 74.09444332122803, 77.11090646471295, 83.59053243909563, 85.96380778721401, 86.97967611040387, 85.6862689426967, 88.47214916774205, 80.9691299710955, 81.79012216840471, 84.00101811545235, 91.72597667149135, 55.244678837912424, 30.74483380998884, 35.36952005113874, 49.191849436078755, 63.86891841888428, 82.59013775416783, 87.42583383832658, 92.9409247807094, 91.35114915030343, 92.21103736332485, 79.64962536948067, 69.19574097224644, 71.8298030580793, 77.22273077283586, 86.57465866633824, 88.84412097930908, 89.14995288848877, 95.96168191092355, 89.01649188995361, 76.08954211643764, 66.20292254856655, 73.027804510934, 74.34358487810407, 74.18246310097831, 67.99787153516496, 70.66812678745815, 82.45779541560582, 90.52827399117606, 86.90767887660435, 88.38003689902169, 84.49538939339774, 91.56260367802211, 89.31044932774135, 89.19531767708915, 88.3058579308646, 84.8851624897548, 84.13688319069999, 87.3656415939331, 78.05922440120152, 102.72297395978654, 12.32996576172965, 0.41231022988046917, 0.14682163803705148, 0.1910986400076321, 0.06954061133520943, 0.20064359211495944, 0.0671961439241256, 0.12706271186470985, 3.4642478355339597, 48.448843819754465, 93.27208982195172, 106.84960637773786, 103.04616246904645, 77.67635086604527, 52.351692131587434, 30.36597285951887, 41.00170203617641, 50.18924944741385, 82.11222675868443, 70.46967233930314, 74.61295264107841, 80.33380058833531, 9.380636981555394, 0.28785149114472525, 0.03350343668301191, 0.045155111101589034, 0.029071486821132045, 0.04436833278409072, 0.05252600647509098, 0.0429049227386713, 0.04984638008422085, 0.04031460851963077, 0.02318627949404929, 0.06618010558720146, 0.03246872166969946, 0.018650201648207645, 0.06247754355094262, 0.0783484165689775, 0.01394295655856175, 0.057356314068394046, 0.09370882769248315, 0.026875194494745562, 0.0320921313416745, 0.07803828535335404, 0.04812304362920778, 0.042869452320571454, 0.08288548846862145, 0.028134728515786783, 0.09789645405752317, 0.07893165134425674, 0.009795909132143217, 0.13126975111663342, 0.2698253398495061, 0.1687559067670788, 0.10838298206882817, 0.14624211484832422, 0.1735057197511196, 0.14416845754853316, 0.20250577719083854, 0.06951941390122686, 0.08015555888414383, 0.1889231481722423, 0.1546283598457064, 0.16847248268978937, 0.14101700165442058, 0.12680034951439925, 0.19844099959092482, 0.1075275529708181, 0.1144789813884667, 0.19267142989805766, 0.1720649999167238, 0.0727174783657704, 0.2558716743120125, 0.1731926165521145, 0.1194223261305264, 16.90608583177839, 90.90995243617466, 137.4851450238909, 129.02478218078613, 111.72280883789062, 111.47869777679443, 99.78732531411308, 67.66147450038365, 40.40319115774972, 87.0519790649414, 140.15699141366142, 95.36255959102085, 68.36135959625244, 59.12372956957136, 5.922883323260716, 0.6209819497806686, 0.1461591435862439, 0.4182627461850643, 0.26129363051482607, 0.6487814752118928, 0.1584521760897977, 37.92635638373238, 11.062647342681885, 10.556506684848241, 120.3082253592355, 92.560788835798, 106.84222044263566, 76.25868211473737, 84.98502894810268, 83.07303060804094, 94.23408876146588, 83.80090304783413, 90.68999331338065, 93.0195505959647, 93.50403458731515, 89.21799659729004, 89.21757970537458, 75.43984385899135, 76.10200718470982, 70.60748291015625, 72.97073895590646, 74.12203461783272, 86.22734601157052, 89.78002943311418, 89.7309126172747, 90.5448384966169, 89.1779819216047, 83.90186732155937, 84.7427452632359, 77.20766707829067, 78.67468888419015, 81.42992755344936, 88.15866034371513, 90.483888898577, 92.62768609183175, 91.07864774976457, 91.27228014809745, 85.66664028167725, 88.06642995561872, 89.93521050044468, 96.36587946755546, 59.71445151737758, 35.376225062779014, 43.63767487662179, 61.124213218688965, 69.37044647761753, 87.39852741786412, 91.56359727042062, 97.18714959280831, 94.96023109980992, 95.65856674739292, 83.46447822025844, 73.5506842476981, 76.37414033072335, 82.29628453935895, 90.78403718130929, 94.8138256072998, 89.62026950291225, 99.18371445792062, 93.60558945792062, 79.75164576939174, 72.75296156747001, 78.72475760323661, 80.58977222442627, 77.69635472978864, 72.1144151687622, 76.89440059661865, 89.8033753803798, 95.45281669071743, 91.52430520738874, 91.80931336539132, 87.74916131155831, 99.59483936854771, 93.20934758867536, 94.19758292606899, 93.3608044215611, 88.3076227733067, 89.95373439788818, 89.59315763201032, 86.64104175567627, 105.61666938236782, 9.85888843876975, 0.8036571475011962, 0.7000204228929111, 0.22581536855016435, 0.2984892917530877, 0.2560202734810965, 0.24098760155694826, 0.22257427818008832, 7.940285835947309, 64.28606741768974, 101.77790778023856, 113.65060043334961, 103.94925458090646, 80.4961244038173, 93.86134569985526, 53.63161631992885, 37.89729554312569, 44.867485182625906, 84.94098431723458, 75.51531519208635, 90.93892642429897, 90.45681176866803, 10.258118033409119, 0.3744695803948811, 0.05567501285778625, 0.14674258870737894, 0.08541875824864421, 0.13116008628691944, 0.1317234874836036, 0.15808797920388834, 0.12433573390756335, 0.17448519862123898, 0.1330767170126949, 0.19441434208835873, 0.17521622510893003, 0.09262686289314713, 0.12656240085405962, 0.2358493815575327, 0.12133922827030931, 0.22304657926516874, 0.14332786122603075, 0.1535942181944847, 0.14631679441247666, 0.16107419825025968, 0.17569802568427154, 0.09872537957770483, 0.3933972604572773, 0.21660600629236015, 0.19775259867310524, 0.15522188799721853, 0.21061170580131666], [0.06275426370224782, 0.08932968481842961, 0.11560891861362116, 0.06833252044660704, 0.06794505659490824, 0.06441168726554938, 0.1514661152447973, 0.12931295111775398, 0.16692521928676538, 0.0369109241957111, 0.11815339779215199, 0.03709636103095753, 0.09145684460444109, 0.07913406512566976, 0.08975198465798583, 0.08260509065751519, 0.0933281152642199, 0.04671388924387949, 0.03885121204491172, 0.06035290112985032, 0.04707023208694799, 0.05794805767280715, 0.1664754319936037, 43.36593777792794, 103.30865151541573, 103.97139154161725, 88.60969570704869, 87.55000509534563, 81.93214334760393, 92.14407757350376, 43.68292154584612, 34.81879193442208, 82.71626840318952, 114.82918861934117, 65.73187637329102, 57.414424078805105, 36.48994139262608, 3.6428979635238647, 0.3848044015467167, 0.11706500048083918, 0.2304895520210266, 0.1537952816912106, 0.3140141729797636, 0.1842529002044882, 21.166144507271902, 68.25439207894462, 0.9886494066034044, 43.07088599886213, 109.01950795309884, 87.33969702039445, 84.25064604622978, 89.5055547441755, 88.52271815708706, 84.22754328591483, 84.72515937260219, 83.60918140411377, 83.088198525565, 86.81412833077567, 86.35558196476528, 86.03084400721959, 80.6770554951259, 76.83297852107457, 67.82956532069615, 67.58528750283378, 64.80213791983468, 68.13377135140556, 65.68048749651227, 73.77797372000558, 76.97015680585588, 76.16633360726493, 75.1830175944737, 72.08900560651506, 68.85433428628104, 65.9057480948312, 67.69434642791748, 72.976776940482, 79.80620302472795, 87.40608705793107, 84.14226804460797, 85.8030959538051, 87.42826570783342, 84.00581932067871, 81.59425939832414, 81.71576254708427, 81.49034214019775, 84.57175009591239, 84.66770471845354, 50.05135897227696, 27.187762601034983, 60.53904288155692, 81.30412346976144, 80.78951903751918, 82.57830497196743, 88.30455861772809, 87.15078244890485, 78.89548179081508, 65.20429965427944, 63.849220275878906, 66.9913763318743, 78.27558435712541, 88.23903710501534, 86.87296567644391, 85.84962803976876, 82.90745503561837, 75.92421667916435, 65.99246161324638, 64.6914461680821, 65.97063037327358, 65.99216978890556, 67.72263254438127, 64.69574710300991, 72.06288037981305, 83.24458857945034, 81.43728569575718, 82.13459995814732, 80.29575225285122, 81.87540435791016, 78.06156594412667, 78.21924141475132, 77.4762635912214, 78.86937740870884, 69.92691380637032, 81.4142176764352, 84.11298138754708, 84.7269936970302, 69.48985127040318, 0.722334508384977, 0.3547821582428047, 0.08110174204089812, 0.04441203043929168, 0.051546656526625156, 0.1383116418229682, 0.042180233768054416, 0.1223318435783897, 1.8407000516142165, 39.36771501813616, 73.03054904937744, 88.56514385768345, 42.7251992225647, 68.1052212033953, 66.11681352342877, 22.93984763962882, 22.526586157935007, 36.17108508518764, 57.63154138837542, 65.430908203125, 69.20052133287702, 72.88434505462646, 6.285165003367832, 0.3952402158507279, 0.11043076682835817, 0.15218068047293595, 0.14696472750178405, 0.049544058806662045, 0.06037843440260206, 0.005913154912247721, 0.10093869295503412, 0.056717853327947, 0.057621309134577, 0.13972352391907147, 0.02968150676627244, 0.045602092652448585, 0.08313815455351557, 0.09613293475870575, 0.06362849500562463, 0.07542637336466994, 0.0303849745541811, 0.049524961438562186, 0.014542985075552548, 0.053493665265185494, 0.06421607240502324, 0.01462285203992256, 0.07363829109817743, 0.03807210795847433, 0.06940165414874043, 0.04391245224646159, 0.0339190224185586, 0.056046561670622656, 0.07796665919678551, 0.07172097505203315, 0.04465838275583727, 0.05013704752283437, 0.07707884362233536, 0.03525893569790891, 0.12897243510399545, 0.03695663709991744, 0.07801355275192431, 0.027041328705048988, 0.04432579881644674, 0.0920170566865376, 0.025846966276211397, 0.0656770532950759, 0.06534332941685404, 0.09017848462930747, 0.08274486208600657, 0.06783901514219386, 0.038954274728894234, 0.060013219714164734, 0.08683634003890411, 49.19454186303275, 124.52122388567243, 118.95666176932198, 99.79066739763532, 107.74725805010114, 106.25423608507428, 109.8480042048863, 77.31676769256592, 44.81529378890991, 36.92029891695295, 87.66137082236153, 68.54582732064384, 67.0486364364624, 45.712104729243684, 4.6587532588413785, 0.5113603834594999, 0.11958108975418977, 0.43876090911882265, 0.12117342145315238, 0.5798862321036202, 0.3987345354897635, 19.657475199018204, 51.35734585353306, 0.6625161096453667, 51.38391923904419, 110.8547009059361, 93.41132477351597, 88.73740359715053, 95.39544541495187, 95.24340493338448, 87.63186182294572, 87.64425046103341, 90.45266369410923, 87.45232037135533, 90.2203367778233, 90.52114513942173, 92.05022825513566, 87.20183781215123, 79.8069395337786, 71.2447647367205, 71.3505858012608, 67.55978761400495, 70.21008763994489, 69.4149010522025, 74.57081876482282, 78.92804104941231, 79.15820012773786, 78.34610162462506, 76.06037357875279, 71.77120195116315, 69.7234080178397, 72.05109623500279, 75.5344157900129, 81.66084398542131, 89.19123213631767, 89.09885583605084, 89.26971898760114, 91.76218373434884, 88.0990239552089, 84.50861876351493, 84.72710486820766, 83.71620450701032, 89.0007403237479, 92.29403359549386, 58.11982951845442, 31.732662677764893, 64.71839823041643, 86.32066031864711, 81.93200438363212, 85.70650209699357, 90.5105560847691, 91.98820863451276, 83.20585932050432, 67.00058964320591, 67.640150478908, 68.05907821655273, 81.95333535330636, 91.99137701307023, 88.39273820604596, 86.90491349356515, 88.14589650290353, 79.86213602338518, 70.30304064069475, 67.76391874040876, 69.10959025791713, 69.55881908961705, 70.95597675868443, 68.07796342032296, 77.68456363677979, 85.32755429404122, 85.65129171098981, 84.18595136914934, 87.26382963997978, 83.64736870356968, 82.3935523714338, 80.41195392608643, 81.7324868610927, 82.78851577213833, 76.07008716038295, 80.75247819083077, 89.08651583535331, 86.23951925550188, 82.65713228498186, 3.0768069454601834, 0.33110763717974934, 0.05742597247340849, 0.23210321686097554, 0.24404679025922502, 0.1965537087193557, 0.014922723806064044, 0.20768302652452672, 1.8935956018311637, 41.62670986992972, 77.51946749005998, 94.24421228681291, 51.90357501166207, 52.46880749293736, 37.53763941356114, 25.662273441042217, 34.66416324887957, 58.731649671282085, 75.24341828482491, 77.76662186213902, 74.88723278045654, 96.6821962084089, 11.585713812283107, 0.33148710110357826, 0.08263897669634648, 0.10403169984264032, 0.005201073970446097, 0.06080951448529959, 0.08901917362319571, 0.05608329077118209, 0.018409257255760685, 0.03144319402053952, 0.025452377806816782, 0.05266326732401337, 0.021289070136845112, 0.09256897028535604, 0.06469342857599258, 0.00974083414101707, 0.0587542929819652, 0.030557067998285805, 0.03347787626885942, 0.038588618992694786, 0.03179464123344847, 0.06130263302475214, 0.05458566899012242, 0.03807517832943371, 0.02990757767111063, 0.042057062698794265, 0.06105047584112201, 0.05535662387098585, 0.08905147867543356, 0.13155232023979935, 0.15192363783717155, 0.12405958372567381, 0.11913056964320795, 0.09134896432182618, 0.2154827051396881, 0.12595542413847788, 0.2077866523925747, 0.1683478629482644, 0.12145566487950937, 0.13383742262210163, 0.1635540130415133, 0.18189188332429954, 0.20331487591777528, 0.13566555881074496, 0.1565605290234089, 0.19507781362959317, 0.2995491363108158, 0.3012824947280543, 0.14134105640862668, 0.1308607437780925, 0.25681350805929726, 69.05010672977993, 146.2266180855887, 132.25991903032576, 112.10596030099052, 113.36566175733293, 108.77545942578996, 110.97122914450509, 62.11948708125523, 47.533981459481375, 117.07653481619698, 172.99452536446708, 94.97414834158761, 74.5377105985369, 61.85522624424526, 6.841548519475119, 0.5858147282685552, 0.24762049849544251, 0.47032719956977026, 0.24278672358819417, 0.6467352307268551, 0.1856750960328749, 33.45006281988961, 88.33283083779472, 1.2278948830706733, 55.16031033652169, 114.82495021820068, 98.24065630776542, 91.97084508623395, 99.67557743617466, 100.5565047945295, 91.90530967712402, 91.24305602482387, 92.88090624128068, 92.5367967060634, 93.75894314902169, 94.87053680419922, 96.40723514556885, 91.48536055428642, 85.94678470066616, 74.39854512895856, 73.91592325483049, 70.28059101104736, 75.35738263811383, 73.87012767791748, 80.90818732125419, 84.84036745343889, 83.59531279972622, 83.7927736554827, 81.72481604984829, 76.31027943747384, 74.70867102486747, 75.23668548039028, 80.06302234104702, 85.59761687687465, 94.69089112962995, 94.35746097564697, 93.64333207266671, 94.69687352861676, 92.17198153904506, 88.04828820909772, 89.38090406145368, 88.29359436035156, 91.84646538325718, 91.08126027243478, 57.80916166305542, 39.4059613772801, 72.26776885986328, 90.16097136906215, 85.06587818690709, 91.1656322479248, 93.78077438899449, 96.05191816602434, 88.38046768733433, 71.34527042933873, 69.80684893471854, 72.69380460466657, 86.99457999638149, 96.16358961377824, 93.18705776759556, 90.99235807146344, 92.21780490875244, 83.9824525288173, 73.75739315577916, 70.16536208561489, 73.21654537745884, 72.84401076180595, 74.93120098114014, 72.11511693681989, 80.3805411202567, 89.31254768371582, 90.05280181339809, 87.70888260432652, 90.01662949153355, 89.90461758204869, 86.65819685799735, 84.03908729553223, 86.75440161568778, 88.04967784881592, 79.68942465100969, 89.08431325639997, 93.99117279052734, 92.16678428649902, 84.4637472970145, 2.128262975386211, 0.9810581739459718, 0.39937933374728474, 0.29310308077505653, 0.2308826952108315, 0.2057210560888052, 0.14749401195773057, 0.39650761069996016, 5.013546083654676, 54.8276618548802, 82.33818912506104, 97.60085228511265, 59.542004176548545, 89.29423918042863, 86.95278658185686, 33.679103238242014, 32.30712236676897, 50.08138561248779, 77.3066302708217, 85.86358002253941, 86.85178756713867, 113.87886265345982, 15.624085869107928, 0.5334745996764728, 0.1502469778060913, 0.19827374070882797, 0.20451992696949414, 0.21544119236724718, 0.11931894453508513, 0.08706412424466439, 0.20344396041972296, 0.20387560368648597, 0.15462571355913365, 0.15078335973833287, 0.0862981735595635, 0.1463091948202678, 0.1020818276863013, 0.1436144472765071, 0.16527066592659267, 0.23527789222342627, 0.038432091141917875, 0.1731133908033371, 0.13168728085500853, 0.13752323841410025, 0.15045429739568913, 0.06606715664799724, 0.14428371350680078, 0.22626369020768575, 0.18292436935007572, 0.1422220527061394], [0.020090015638353567, 0.07862540813429014, 0.06724379743848528, 0.10135107939796788, 0.07121597536440406, 0.04307173718033092, 0.031072171072342565, 0.0644737257223044, 0.03103027832029121, 0.06589569084878479, 0.018323068041354418, 0.04378095555252262, 0.07687122547732932, 0.06056955736130476, 0.06582164910754987, 0.10883693556700434, 0.01984997878649405, 0.03773639936532293, 0.013619479407290263, 0.09862758911081723, 0.032124361755060296, 0.16155715233513288, 45.30875832693917, 115.20941489083427, 92.54371016366142, 89.74225902557373, 77.23764855521065, 64.95686040605817, 37.02534873144967, 66.2080294745309, 46.67537866319929, 65.78898361751011, 89.24396201542446, 75.1499719619751, 71.28001989637102, 41.44359357016427, 3.9043330550193787, 0.4849370898944991, 0.11338797171733209, 0.15753331753824437, 0.03839635270248566, 0.12446697615087032, 0.18952549727899687, 3.371815298284803, 27.96981188229152, 5.264947976384844, 3.260822819811957, 92.84888199397496, 87.90917832510812, 101.7037079674857, 92.94556617736816, 92.42329093388149, 87.4036065510341, 92.89627565656389, 88.9464887891497, 89.64131559644426, 87.27941444941929, 89.55549144744873, 84.70537785121373, 87.70397022792271, 84.37187126704625, 82.67206396375383, 72.5077874319894, 66.62891660417829, 63.68019839695522, 66.11289473942348, 63.489241055079866, 65.8583196912493, 72.3525299344744, 75.58645779745919, 73.12769181387765, 72.84930528913225, 64.5651626586914, 64.31921032496861, 68.25948510851178, 75.30964156559536, 81.40913159506661, 84.05467905317033, 79.99438803536552, 83.43706062861851, 82.89105033874512, 84.43728160858154, 83.18953800201416, 80.89568751198905, 79.4971193586077, 81.89189938136509, 77.02597863333565, 94.69755445207868, 40.431925433022634, 54.29482882363455, 85.02987957000732, 73.58981650216239, 85.12513242449079, 83.95842565808977, 86.31342724391392, 73.66579505375454, 64.75491101401192, 62.53437096732003, 67.42274829319545, 72.18739209856305, 83.0875940322876, 80.42382839747837, 74.75980976649693, 80.70304870605469, 77.02896635872978, 71.97708402361188, 65.08718081883022, 66.25298431941441, 63.858419690813335, 65.55059092385429, 62.35733781542097, 68.97306510380336, 75.50863797324044, 81.76720700945172, 74.99165030888149, 79.79834461212158, 73.87886851174491, 73.43134198869977, 71.83675125667027, 72.29029491969517, 69.28271157400948, 75.35578455243791, 64.44083159310478, 77.6523448399135, 81.10291753496442, 89.6326025554112, 51.27766738619123, 0.49625418548073086, 0.17451083367424353, 0.2544649897941521, 0.1608807072043419, 0.04357943743733423, 0.0905527374041932, 0.05285355568464313, 0.1692126151174307, 4.368565653051649, 39.48665080751692, 69.65569087437221, 78.40662043435233, 55.19939742769514, 69.84234033312116, 49.017890862056184, 29.15606219427926, 27.222751992089407, 35.36281851359776, 47.27905900137765, 67.96253299713135, 73.82394300188336, 66.9864500590733, 5.788164266518184, 0.032594389747828245, 0.07234961739076035, 0.03491471488294857, 0.09414984152785369, 0.010799794058714594, 0.10345211558576141, 0.015951449051499367, 0.0898661617455738, 0.05539591444124069, 0.08646149015320198, 0.1353788370532649, 0.14889062701591424, 0.04600695074935045, 0.0626385056280664, 0.03784298364605222, 0.07277000376156398, 0.028408826129244905, 0.037414770373808484, 0.12205276212521962, 0.0973259350284934, 0.0381569146577801, 0.11399187466927937, 0.053568775699074776, 0.0735402631440333, 0.08510297483631543, 0.11774320980267865, 0.0834766078208174, 0.10133587342819997, 0.04835953004658222, 0.08999540909592595, 0.025766702368855476, 0.015412794026945318, 0.0970444515613573, 0.05637323557000075, 0.05051099156428661, 0.024893470208293626, 0.0357622797600925, 0.05665204900183848, 0.02357672041814242, 0.015839889412745833, 0.012732443299942782, 0.09189750560160194, 0.04519712259726865, 0.06250999788088457, 0.04674238771466272, 0.07688951199608189, 0.020362727344036102, 0.04821394696565611, 56.766087668282644, 136.86961800711495, 101.37899085453579, 100.78388459341866, 93.61232226235526, 91.02742562975202, 50.05280419758388, 78.8059334073748, 52.56591551644461, 29.621337890625, 78.54347215379987, 85.5266340800694, 81.8294837134225, 54.00883749553135, 4.21786139692579, 0.7321399907980646, 0.24465589757476533, 0.4683903349297387, 0.2952691274029868, 0.809946841427258, 1.1645738865647997, 1.8787696659564972, 14.319145560264587, 1.9318204649857111, 7.233770421573094, 98.15843827383858, 90.09349046434674, 106.59002862657819, 97.76869991847447, 97.32116644723075, 93.61519881657192, 98.33885519845145, 95.70013087136405, 93.6647116797311, 93.20788846697126, 94.07471098218645, 88.8133613041469, 91.55682277679443, 88.63779422215053, 86.8057974406651, 77.63899735042027, 69.42899199894497, 66.82682909284318, 68.50352668762207, 66.8577207837786, 69.51792199271065, 77.25712435586112, 80.68141896384103, 74.61901147024972, 76.27109854561942, 69.93059635162354, 68.1886065346854, 73.18097060067313, 79.30422346932548, 84.87262793949672, 85.83935165405273, 83.85608564104352, 86.95940126691545, 85.21686949048723, 86.71754837036133, 86.56195735931396, 84.96437195369175, 82.780928339277, 84.52532918112618, 77.49217496599469, 93.32412488119942, 45.8857957976205, 58.048037256513325, 88.22710009983608, 77.81896264212472, 87.30335794176374, 85.56317465645927, 89.77661786760602, 77.94107723236084, 68.19879954201835, 66.51103346688407, 70.77515683855329, 74.76996803283691, 83.99916294642857, 82.31484317779541, 78.39125101906913, 86.20316628047398, 79.28247560773576, 75.94752788543701, 69.75866317749023, 70.90277440207345, 66.14783028193882, 65.96289702824184, 64.40516648973737, 70.29937199183873, 78.2366327558245, 85.28599017007011, 79.29193905421666, 82.66043267931256, 76.48633289337158, 77.85264056069511, 74.95942456381661, 73.87719399588448, 72.61048180716378, 77.6553395135062, 69.62850257328579, 79.3872822352818, 85.63741615840367, 90.17448561532157, 64.45597171783447, 1.54344428224223, 0.6230005100369453, 0.3437818299446787, 0.4473346604832581, 0.03614805745226996, 0.15900708202804836, 0.00949107388234032, 0.2285645753145218, 4.288878500461578, 45.680549485342844, 73.811769757952, 83.60018348693848, 62.20610332489014, 51.25031580243792, 29.194781030927384, 29.562149660927908, 46.00122274671282, 49.49995340619768, 58.096646853855674, 79.8538190296718, 79.37057876586914, 91.05452360425676, 9.19035187789372, 0.08828734646418265, 0.08604531069951397, 0.08545925321855716, 0.09480365073042256, 0.035885572965656004, 0.05458016946379628, 0.0759806821921042, 0.13917414125587257, 0.03243587378944669, 0.05109811434522271, 0.08394828465368066, 0.07380795877959047, 0.056125410832464695, 0.057794573051588874, 0.0461268580651709, 0.013925003370137086, 0.02905537500711424, 0.02076912741176784, 0.05941999011806079, 0.07173127521361623, 0.07617229369602033, 0.12186286731490067, 0.10506150565509285, 0.054094307856368165, 0.01588541571982205, 0.08602944655077797, 0.2664217267717634, 0.22436535278601305, 0.1991838461586407, 0.15061734936067037, 0.16967620381287166, 0.11115761354033436, 0.2201807051897049, 0.10033172302480255, 0.1536769587546587, 0.21472425226654324, 0.1363641241831439, 0.06618429214826652, 0.1298589411058596, 0.16460899928850786, 0.1525222821427243, 0.16410244575568608, 0.16617978071527822, 0.1802886679236378, 0.12910958060196467, 0.20553417397396906, 0.11911188278879438, 0.30128032341599464, 73.7951774597168, 154.81224305289132, 109.58781501225063, 114.333879334586, 107.03184373038155, 88.43112005506242, 51.21685675212315, 84.78773484911237, 58.77484662192208, 95.97826726096017, 134.07938820975167, 89.47200189317975, 93.64096968514579, 70.62303992680141, 7.503975442477635, 1.0211856492928095, 0.48615622733320507, 0.4131884713258062, 0.4914051028234618, 1.2705971002578735, 0.7232110670634678, 7.27372647183282, 43.35672446659633, 7.447355440684727, 6.498096023287092, 98.91209547860282, 89.49705014910016, 110.54309504372733, 101.50874151502336, 102.66340705326625, 95.32052298954555, 103.35854652949742, 100.42104271480015, 98.06989737919399, 97.31736578260148, 99.3067045211792, 92.05121489933559, 96.26965386526925, 92.65732710702079, 91.94051619938442, 82.27558585575649, 75.2501927784511, 71.48921625954765, 74.0066806248256, 71.09801878247941, 71.31036962781633, 81.37173639025006, 85.21371500832694, 80.0684836251395, 81.33437592642647, 76.15296527317592, 72.01115104130336, 75.78954669407436, 83.80588490622384, 90.09979248046875, 93.41101210457938, 87.74296351841518, 92.20198386056083, 90.19435051509312, 91.34836292266846, 92.88683305467877, 89.14374814714704, 87.72452299935478, 89.823212487357, 83.70268331255231, 96.51062434060233, 49.52252115522112, 65.79976722172329, 91.30235889979771, 80.92698219844273, 92.14495999472481, 90.46931157793317, 93.9659230368478, 81.68110493251255, 70.26147651672363, 70.01809501647949, 73.67951079777309, 79.39079107557023, 91.41505868094308, 86.18248844146729, 82.71058477674211, 88.07046685900006, 83.58074242728097, 79.24569879259381, 73.39243902478898, 73.79404490334647, 69.54652772630963, 69.88564150674003, 68.63484764099121, 75.00683907100132, 83.11566475459507, 91.73655877794538, 83.10851505824498, 87.80583081926618, 82.56537437438965, 81.6931461606707, 79.2683082308088, 79.42138399396623, 78.30491270337785, 82.09140995570591, 72.50692585536412, 87.9363179888044, 91.28666986737932, 98.3528836114066, 63.63760593959263, 1.612728244491986, 2.311134785413742, 0.5923047800149236, 0.5335748057280267, 0.08968827700508492, 0.19587047823837825, 0.2741505391895771, 0.3664147454713072, 9.192243524960109, 60.548485483442036, 82.80847794669015, 91.74520233699253, 74.36891801016671, 94.11767169407436, 65.17493656703404, 40.86738988331386, 36.712266377040315, 45.90281541006905, 63.869397844587056, 90.05380235399518, 88.89484977722168, 109.41885566711426, 11.329849004745483, 0.2544716665787356, 0.20909922410334858, 0.19327216409146786, 0.15920112947268145, 0.06789173052779265, 0.09922101548207657, 0.1963459820087467, 0.2520737781056336, 0.0841570088107671, 0.1352419765400035, 0.1696009271379028, 0.20384391610111507, 0.11932912256036486, 0.16946140676736832, 0.08314024444137301, 0.09508845901915006, 0.0855281041668994, 0.1087596368576799, 0.11559977196156979, 0.14673429700945104, 0.14179936610162258, 0.19950021989643574, 0.19291912232126507, 0.18462989426084928, 0.17917036078870296, 0.3041930842612471], [0.10587538805391107, 0.0816711075603962, 0.05148948995130403, 0.1106843285794769, 0.18341944207038197, 0.023850460104378204, 0.10246112876172576, 0.046700396575033665, 0.12101658486894198, 0.043085450373057804, 0.04948607798931854, 0.07775591979069368, 0.11068886119340147, 0.04900789400562644, 0.00852704101375171, 0.03174785624391266, 0.06747170378054891, 0.028663500677794218, 0.04297192807176283, 0.07101723924279213, 0.05627940096227186, 37.25571278163365, 119.18218639918736, 91.60915660858154, 104.25917203085763, 80.22542953491211, 82.54093755994523, 51.38123376028878, 82.22095217023576, 166.37271145411898, 138.90641294206893, 104.26397323608398, 97.56188678741455, 93.43229443686349, 42.61560181209019, 5.651670813560486, 0.164991272347314, 0.09627025667577982, 0.07524171684469495, 0.13049634333167756, 0.1945461950131825, 0.018080237321555614, 0.6926031123314584, 5.222473204135895, 1.7375166969639915, 5.599707407610757, 80.73630973270961, 93.59718213762555, 93.97155107770647, 94.68443625313895, 93.29169763837541, 96.09221076965332, 93.68456268310547, 90.64715766906738, 92.00113228389195, 92.57995196751186, 88.02256597791398, 85.36959089551652, 87.67850508008684, 85.64774118150983, 84.12804508209229, 82.09143080030168, 81.15947587149483, 69.67225537981305, 65.85620743887765, 63.62054811205183, 63.26542568206787, 66.33750220707485, 71.99303708757672, 70.49121870313371, 67.70819418770927, 63.863609995160786, 61.16125406537737, 63.561273029872346, 70.01301588330949, 75.63866656167167, 80.61898939950126, 83.36042894635881, 83.10768127441406, 81.15602261679513, 78.9777067729405, 83.2267733982631, 81.1956342969622, 83.39534364427838, 77.53696305411202, 85.96487780979702, 80.45796489715576, 84.21120807102749, 70.15092372894287, 55.44240025111607, 87.76662213461739, 73.64515195574079, 84.11445440564836, 85.21445846557617, 87.70153835841587, 76.68724700382778, 67.48728316170829, 59.670358249119346, 62.12025833129883, 66.52058723994664, 75.61844730377197, 78.89824717385429, 79.64721434456962, 85.68091882978166, 82.49935953957694, 76.71819428035191, 72.35571220942906, 66.6043130329677, 67.06491606576103, 62.17027146475655, 64.32686029161725, 62.117055211748394, 70.93827969687325, 77.0345596585955, 74.78298895699638, 75.1530430657523, 73.6274687903268, 68.60164219992501, 71.98033578055245, 65.50278731754848, 73.26725333077567, 65.29108960287911, 69.41654777526855, 65.5761741910662, 81.42102691105434, 76.46943487439836, 94.52259186335972, 35.565087522779194, 0.7902435958385468, 0.16584476083517075, 0.2767900675535202, 0.2595759598272187, 0.014570779566253935, 0.08360410455082144, 0.06108704887862716, 0.2634227105549404, 10.458298240389142, 34.390303475516184, 73.34107794080461, 83.97685922895158, 74.1980757032122, 74.55141939435686, 48.97504826954433, 26.019853796277726, 23.292225531169347, 40.35672855377197, 73.26712826320103, 72.37859262738908, 70.59797777448381, 44.41016864776611, 2.244890008653913, 0.004260823754261115, 0.16301119859729493, 0.02023651813422995, 0.08804385417274066, 0.018348333292773793, 0.032482458611152, 0.03458271787634917, 0.07378859339015824, 0.05901762563735247, 0.036150401790759394, 0.05993491677301271, 0.06479453029377119, 0.036509815004787276, 0.03189645880567176, 0.016992783173918724, 0.02323235711082816, 0.011391061840445867, 0.034917642761554034, 0.043070485283221514, 0.07643186726740428, 0.05925267695316246, 0.08954134703214679, 0.033961223904043436, 0.037131970548736196, 0.02316169617032366, 0.049348158961428065, 0.011426964824620103, 0.04655008749770267, 0.05725023190357855, 0.1424655924950327, 0.03907308281798448, 0.11076748304601226, 0.051460021175444126, 0.06287623037184988, 0.10181574017873832, 0.13905262920473302, 0.06590671025748764, 0.054070623591542244, 0.02469961784247841, 0.03897295819063272, 0.0341579379912998, 0.10642631777695247, 0.05956329671399934, 0.022209085590605224, 0.021463638537430337, 0.031121293615017618, 49.313300473349436, 136.52350044250488, 101.68469769614083, 117.98631804330009, 102.57087094443185, 96.27171053205217, 68.6001900264195, 71.81925569261823, 145.3699607849121, 92.80368396214077, 73.3849071775164, 111.91868550436837, 99.30315399169922, 53.56182861328125, 6.125352093151637, 0.2434066060398306, 0.1838855142039912, 0.46968715105737957, 0.2834509201347828, 0.9927377700805664, 0.3497347262288843, 0.6972577539937836, 2.6482435762882233, 0.743630628500666, 10.986640129770551, 93.06916768210274, 95.41214888436454, 94.62657860347203, 93.55873080662319, 94.95334543500627, 98.74941035679409, 97.44670649937221, 93.70769323621477, 94.80816977364677, 96.70781421661377, 94.09536102839878, 89.31226975577218, 89.78050885881696, 88.89731638772147, 88.15908418382917, 86.96938582829067, 85.2754567010062, 75.90198244367326, 68.84136199951172, 66.90924862452916, 65.84147725786481, 67.59011650085449, 73.77836976732526, 74.62915584019252, 72.71186297280448, 67.6220851625715, 65.04779148101807, 67.885011945452, 73.89933790479387, 79.59691633496965, 85.204592023577, 86.14949144635881, 85.42692743028913, 85.30506297520229, 82.20058700016567, 86.01855959211076, 83.05652863638741, 86.78340339660645, 82.0640618460519, 89.74123069218227, 85.45866680145264, 86.98736081804547, 73.84286989484514, 61.38787651062012, 88.36955901554653, 75.99087074824742, 85.16489001682827, 86.43867547171456, 90.66940580095563, 79.99031639099121, 71.40233598436627, 63.22331959860665, 65.29697472708565, 69.0871684210641, 78.56277424948556, 83.43050152914864, 82.80155059269497, 86.95799078260148, 86.85251712799072, 80.26552758898053, 78.57072298867362, 69.1684067589896, 70.9332492010934, 65.89055238451276, 67.28566033499581, 64.42439215523856, 72.87265123639787, 77.79649911608014, 78.88334328787667, 79.67786284855434, 77.5680284500122, 72.66900648389543, 75.46979059491838, 69.14231627328056, 78.21224457877022, 68.02234309060233, 71.09699044908795, 70.11227090018136, 83.4061689376831, 79.97352259499687, 98.27536255972726, 48.07473891122, 0.7936182490416935, 0.5443760518516813, 0.4324398940162999, 0.46845889410802294, 0.1480815147182771, 0.09644791749971253, 0.022574427504358546, 0.30369835080845015, 10.479246190616063, 39.96361684799194, 74.74963065556118, 91.76962525503976, 70.08525630405971, 41.345491954258506, 21.95766592025757, 26.986410754067556, 35.51241322926113, 57.78132717950003, 81.43352672031948, 82.81382805960519, 79.14765276227678, 65.88239519936698, 3.0540010035037994, 0.1177391657339675, 0.11692739357905728, 0.03903435203912003, 0.082532385630267, 0.0464388213253447, 0.011383280740119517, 0.141757391925369, 0.07000897013183151, 0.04381790517696312, 0.10780855467809097, 0.05269761137398226, 0.04275489864604814, 0.04197715502232313, 0.07103304910872664, 0.05794731806963682, 0.020130244283271686, 0.08058273060513393, 0.04615505798054593, 0.05700834774013076, 0.021108211716637015, 0.07787934531058584, 0.06089195649006537, 0.029968231916427612, 0.09352853415267808, 0.04141422540747693, 0.13059021186615738, 0.1282964785184179, 0.12011737669152872, 0.18166215850838593, 0.25081474280783106, 0.12482545977192265, 0.1664465671139104, 0.08958621176757983, 0.2240051728274141, 0.18644463616822446, 0.1604923409010683, 0.09684657717921905, 0.12265687542302267, 0.08979097328015737, 0.09648664827857699, 0.08038129391414778, 0.1697946624564273, 0.12553203185754164, 0.06979090254753828, 0.20838248756315025, 0.11381607981664793, 64.52359853472028, 155.1306095123291, 112.86382116590227, 133.11659022739954, 107.0909867967878, 106.93774427686418, 69.16461999075753, 95.25935104915074, 166.20310592651367, 163.410402570452, 147.44227491106307, 116.16864149911063, 118.47534615652901, 69.7652222769601, 10.254247886793953, 0.3281279999230589, 0.4844937079719135, 0.3816929113652025, 0.762122987636498, 1.6338694414922168, 0.3118108612086092, 2.562742518527167, 16.26873278617859, 5.934445994240897, 8.238760471343994, 89.98293072836739, 96.26055867331368, 94.39796897343227, 96.64095864977155, 97.03078733171735, 101.24548816680908, 100.88572434016636, 98.28176185062954, 98.90802383422852, 104.54622295924595, 97.57415730612618, 94.59127480643136, 92.9784242085048, 91.3607098715646, 92.20171288081578, 90.8943259375436, 89.04841191428048, 80.26974514552525, 73.95807797568185, 70.92783655439104, 70.44069835117885, 73.6632033756801, 78.62183393750871, 79.46923623766217, 76.89909757886613, 72.28187370300293, 69.6827471596854, 71.36350945064, 77.10654994419643, 83.82463114602226, 90.05480984279087, 91.47549411228725, 89.68344252450126, 87.15714699881417, 85.260240146092, 90.09267057691301, 87.7589304787772, 89.88794190543038, 84.16314738137382, 93.94332749502999, 89.80739838736397, 90.8220716203962, 75.4913786479405, 66.08252416338239, 93.40359837668282, 79.38988086155483, 89.44712039402553, 89.81349890572685, 94.82418537139893, 84.70273058755058, 75.1719560623169, 65.29905918666294, 68.21188299996513, 73.80978952135358, 82.23882988521031, 85.73997156960624, 85.04410253252301, 90.28562205178397, 91.63023744310651, 82.65178217206682, 80.15193149021694, 71.87161036900112, 75.40016964503697, 70.27635260990688, 70.74669006892613, 67.87399905068534, 76.40535163879395, 83.56893743787492, 84.01116248539516, 84.20717116764614, 80.71554851531982, 76.63528142656598, 79.26033169882638, 72.55810628618512, 81.10549531664167, 73.58848244803292, 76.13352421351841, 72.9267429624285, 89.30888598305839, 85.03559793744768, 105.12964235033307, 46.445716381073, 1.7321309745311737, 2.141318206276212, 0.42471398572836605, 0.4864501144204821, 0.21515991246061666, 0.17868067563644477, 0.19293666923684732, 0.4555573378290449, 17.626787730625697, 51.46251378740583, 88.56352492741176, 97.60573686872209, 93.06622164590019, 102.74723012106759, 64.98756449563163, 35.590917451041086, 32.620361055646626, 55.311134883335654, 89.32025323595319, 93.94857338496617, 92.07047530582973, 84.33718585968018, 4.3230123945644925, 0.14617095009556838, 0.21302924464855874, 0.09921007071222578, 0.15704064683190413, 0.15537178995353834, 0.12765816705567495, 0.23400341346859932, 0.14336819334753922, 0.169580340385437, 0.16757068250860485, 0.14359646609851293, 0.09092902578413486, 0.16038779222539493, 0.14689927601388522, 0.14261546730995178, 0.09700899810663291, 0.14482724719813891, 0.12167871291083948, 0.11911803031606333, 0.20248600468039513, 0.15434015888188565, 0.12759029998310975, 0.12255263887345791, 0.19557105430534907, 0.1210991625807115], [0.005952445058418172, 0.046999698371759484, 0.050512362205024273, 0.05993073699729783, 0.060985865736646314, 0.06860590220562049, 0.10625969671777316, 0.05513567590553846, 0.0865691668753113, 0.09089189634791442, 0.014066890979717885, 0.057755102669554095, 0.02528190945408174, 0.030749113764613867, 0.04403216278712664, 0.06312604660966567, 0.09784947907818214, 0.16777395802949155, 0.23058286415679113, 0.5891601230416978, 11.243824226515633, 110.20428698403495, 84.51714420318604, 95.24942902156285, 63.47797107696533, 44.8567293712071, 45.09528882162911, 25.60502549580165, 30.498589651925222, 75.8195629119873, 89.03270203726632, 98.33554785592216, 92.61749308449882, 33.83834900174822, 4.146449548857553, 0.07859016502542154, 0.12917220938418592, 0.09086252256695714, 0.09113758709281683, 0.3924816724445139, 0.6043963826128415, 0.42423906549811363, 4.919194323675973, 1.0867420115641184, 14.56547222818647, 107.44587993621826, 97.50480038779122, 101.85376821245465, 96.57014955793107, 100.12981591905866, 93.29783984592983, 94.44550159999302, 87.01005363464355, 88.0329257420131, 84.33560861860002, 85.54895864214215, 86.90989535195487, 92.93617916107178, 89.40818268912179, 87.91054712023053, 85.65632220676967, 83.65528964996338, 77.66319792611259, 72.9481920514788, 62.246764183044434, 62.925019536699565, 60.451815196446006, 64.01619243621826, 68.21760831560407, 71.11424282618931, 70.74526568821499, 64.87631688799176, 62.608244214739116, 66.7826177052089, 70.85820170811245, 74.83462102072579, 76.49542808532715, 79.05169813973563, 79.57967785426548, 83.32322829110282, 81.26576941353935, 80.22538089752197, 82.60077544621059, 81.99366269792829, 82.42482621329171, 81.08314296177456, 74.65286309378487, 79.44075557163784, 81.83040087563651, 68.12525285993303, 78.41750131334577, 73.29112039293561, 77.33126163482666, 83.30150822230748, 83.71526650020054, 81.50074359348842, 67.4007294518607, 63.61044543130057, 62.439277921404155, 65.41616412571499, 69.60613632202148, 79.14614500318254, 83.65407371520996, 83.93532289777482, 83.79578917367118, 80.96482903616769, 79.91521331242153, 75.05819320678711, 67.30945096697126, 62.71376650674002, 59.33201571873256, 64.05126694270542, 62.95935753413609, 71.413619858878, 73.60762473515102, 70.87192440032959, 75.44523566109794, 72.04412024361747, 68.07082762037004, 72.15037904466901, 67.1513238634382, 70.09651933397565, 63.444786480494905, 64.01706096104213, 67.99751022883824, 80.65712806156704, 79.63160869053432, 90.15719849722726, 23.60374801499503, 1.6152891985007694, 0.7834265987787927, 0.8110038904207093, 0.19787029735744, 0.02960970758327416, 0.1127812053476061, 0.03655275609344244, 0.025551376066037586, 17.013854128973826, 24.64468022755214, 62.481460435049875, 88.26699665614537, 84.77505438668388, 73.17308439527238, 76.15884344918388, 24.26518177986145, 19.740304674421036, 50.97943680627005, 56.88654511315482, 62.789696420942036, 66.66901465824672, 30.382377556392125, 0.8497273953897613, 0.059540219738015106, 0.03903154290414282, 0.08525692764669657, 0.15185989625751972, 0.03127744148618408, 0.023670056302632605, 0.08242837978260857, 0.03056077958483781, 0.08273009716400079, 0.051892763668937344, 0.05925783381930419, 0.08803417147802454, 0.06647615720118795, 0.09381890642855849, 0.04818452907992261, 0.07636716895337615, 0.09130858470286642, 0.0869946897562061, 0.07283398282847234, 0.06048631468521697, 0.14742660628897802, 0.06725430116057396, 0.0655439111537167, 0.07320111098566226, 0.05642557776133929, 0.05284853791818023, 0.09011970992599215, 0.11244155107332127, 0.09262244563017573, 0.03238823384578739, 0.06002944348646062, 0.05221575990851436, 0.0600154453090259, 0.10506116638758353, 0.06914733922375099, 0.0631245741886752, 0.07807160820811987, 0.055988434968250136, 0.11928485493574824, 0.06001309757786138, 0.08811631492738213, 0.10586194627519165, 0.19322214248989308, 0.6815055906772614, 17.028648580823624, 131.6156403677804, 97.081634249006, 108.6552208491734, 77.12964575631278, 68.207672391619, 81.88154656546456, 51.80429915019444, 44.29311234610421, 90.42276559557233, 77.94199439457485, 106.35404000963483, 102.73229149409703, 43.339027404785156, 5.00077051775796, 0.14548930738653454, 0.1015973672536867, 0.33690962727580753, 0.05695221253803798, 1.862726275409971, 1.473066738673619, 1.5301947189228875, 5.704990855285099, 0.29611737760049955, 22.296102251325333, 120.82367052350725, 95.80242225102016, 103.03408649989537, 98.87599263872418, 102.57157966068813, 95.23369135175432, 95.66639736720494, 87.5065996987479, 90.87835202898297, 86.249114717756, 86.0489718573434, 89.26746777125767, 96.24254894256592, 92.82319450378418, 90.47232014792306, 88.1499195098877, 88.14486122131348, 81.1822590146746, 76.78594616481236, 66.95328630719865, 66.82816314697266, 63.492284366062705, 67.9708638872419, 71.78730787549699, 75.17224093845913, 73.41486780984062, 68.48572540283203, 66.04692159380231, 69.36181681496757, 73.78984819139752, 77.54638481140137, 81.2822435923985, 81.57951532091413, 81.76041861942836, 86.10594013759068, 83.97075871058873, 83.73301914760044, 82.96310315813336, 84.68614523751395, 83.96146202087402, 84.00465897151402, 76.59426621028355, 81.13389260428292, 85.09190613882882, 71.84294210161481, 80.54365008217948, 75.49197619301933, 81.16141441890171, 85.16445228031704, 85.57525757380894, 84.73515088217599, 70.18060643332345, 66.13895743233817, 66.29949556078229, 67.64350645882743, 72.75993755885533, 82.59646756308419, 85.40845217023576, 85.39914158412388, 85.42928981781006, 84.21031870160783, 83.14456926073346, 79.12131214141846, 72.46349961417062, 65.44117069244385, 63.00520869663784, 67.65901483808244, 64.6261122567313, 73.84326594216483, 76.45851925441197, 74.11384963989258, 76.8844438280378, 75.5613956451416, 71.6252133505685, 75.74472386496407, 69.30886459350586, 71.46773937770298, 67.90474482945034, 67.13516235351562, 69.90153203691754, 83.41559069497245, 81.70356845855713, 91.68638583592006, 35.863272939409526, 0.7479373716882297, 1.147511282137462, 2.2936958926064626, 0.4368555556450571, 0.08182194589504174, 0.17038117455584662, 0.021890922216698527, 0.23162555534924778, 19.33851293155125, 30.136011804853165, 65.49881294795445, 94.66723251342773, 87.66672093527657, 52.82784523282732, 27.487417561667307, 23.168023007256643, 35.7263308933803, 68.73768098013741, 66.24649470193046, 72.18754495893205, 80.14597688402448, 47.75133153370449, 1.0901701876095362, 0.07208067325076886, 0.09491123245762927, 0.03918123112193175, 0.05544842965900898, 0.0187468911920275, 0.05971203837543726, 0.08981178394917931, 0.07314602072749819, 0.0586736151682479, 0.05709792114794254, 0.07586258995745863, 0.0634385934099555, 0.053925043903291225, 0.08127571163432938, 0.04292601839240108, 0.03991419482710106, 0.007853086106479168, 0.04957748004900558, 0.022076781439994062, 0.06331269802259547, 0.09401858571384634, 0.06390477410916771, 0.0858265645802021, 0.004997687763534486, 0.18033381764377865, 0.1594268780733858, 0.1559371589017766, 0.21574262476393155, 0.23105694300362042, 0.09511809064341442, 0.2207538230078561, 0.2323821218950408, 0.17300232819148473, 0.16022442813430512, 0.1438811793923378, 0.11713404820433684, 0.13288371451199055, 0.1591875452016081, 0.1407784151711634, 0.13499338845057146, 0.2035604105996234, 0.22429470371987137, 0.448068699666432, 0.8034572239433015, 28.05062985420227, 151.54786818368095, 108.40500926971436, 126.79609189714704, 86.92691843850272, 69.95832661220005, 65.13503306252616, 36.893322535923545, 38.085866178785054, 88.79686628069196, 125.41784722464425, 117.81252970014299, 115.68035684313092, 53.32003477641514, 9.008086732455663, 0.34843332320451736, 0.387215290750776, 0.35158674685018404, 0.45843714901379173, 3.06024808543069, 3.5847558719771246, 2.7255870146410803, 16.107157639094762, 3.66880909885679, 18.320728642599924, 126.05738721575055, 103.30833189828056, 106.94180202484131, 101.85610280718122, 104.36385359082902, 98.42092732020787, 98.31151403699602, 89.0949787412371, 93.61299623761857, 89.55981322697231, 91.21091365814209, 90.80479145050049, 100.06533663613456, 97.07098266056606, 95.92620440891811, 92.89854076930455, 92.09664916992188, 85.12324946267265, 80.61602251870292, 70.93568801879883, 69.53607763562883, 68.65689427512032, 70.93522943769182, 75.92891366141183, 81.35444232395717, 79.8113099506923, 73.66250160762242, 69.00658321380615, 74.12679413386753, 77.86470263344901, 82.94068132128034, 85.0188319342477, 87.96094240461076, 88.25840868268693, 92.13603850773403, 89.86297007969448, 88.27800955091203, 87.98116166251046, 88.97134249550956, 89.46651281629289, 90.20468248639787, 80.07970496586391, 86.87365354810441, 89.72422845023019, 76.46883732931954, 85.80665343148368, 79.94826589311872, 86.89545699528286, 90.36873640332902, 88.71933133261544, 89.76370116642543, 73.73647212982178, 69.57832268306187, 68.48257786887032, 72.4612900870187, 77.63816356658936, 87.7823042188372, 89.07233456202916, 88.68189443860734, 90.91413525172642, 88.9046745300293, 88.77988488333565, 83.1526847566877, 76.17725617544991, 68.26905277797154, 66.01245852879116, 72.04991504124233, 69.78555270603725, 78.94814913613456, 80.62427003043038, 78.61573341914585, 83.88871438162667, 79.94569505964006, 75.77331570216587, 79.72934900011334, 75.3077586037772, 76.91935157775879, 70.76007229941231, 73.26152106693813, 74.68934113638741, 90.46873487745012, 87.26091834477016, 96.16253348759243, 31.73576157433646, 3.380444960934775, 3.191974857023784, 1.5879088448626655, 0.5591092184185982, 0.12277295919401304, 0.22804745020610945, 0.13932305255106517, 0.5199374460748264, 32.982264927455354, 38.849341188158306, 76.90820666721889, 101.82612133026123, 109.40151296343122, 106.99951376233781, 99.94005366734096, 32.799047878810335, 28.707832166126796, 69.77787494659424, 75.12245709555489, 85.76385252816337, 91.70443725585938, 60.38687038421631, 1.0535810823951448, 0.17331632705671446, 0.20508397955979618, 0.24177695491484233, 0.20755147215511116, 0.11068256438842841, 0.23856821709445544, 0.11499579437077045, 0.11176906180168901, 0.12447377507175718, 0.21259453440351145, 0.13105608043926104, 0.1172326664839472, 0.1975832363324506, 0.2131121073450361, 0.1286386094455208, 0.10266324398773057, 0.10516059212386608, 0.14648117630609445, 0.1485000215470791, 0.1841097835983549, 0.2601977693183081, 0.1252509555114167, 0.14872350384082111, 0.11244047220264163], [0.045836126165730615, 0.07276574256164686, 0.014848917855748107, 0.05288244770573718, 0.11044141982815095, 0.04086863236235721, 0.035191224688397985, 0.03146946689646159, 0.027206541804064597, 0.037124299710350375, 0.032361312968922515, 0.01792405213096312, 0.04835797280871442, 0.02351499578383352, 0.1252784633210727, 0.016902515964050378, 0.019527627155184746, 0.050705181501273594, 0.05023908901161381, 0.9238362844501222, 77.61287212371826, 93.81443841116769, 95.56373078482491, 68.4484691619873, 55.40880223682949, 36.063648564474924, 23.179624761853898, 39.34551204953875, 46.950645446777344, 56.75483158656529, 94.03153487614223, 100.9045192173549, 42.21230057307652, 1.9760194761412484, 0.5585261668477739, 0.1050595718302897, 0.08639853567417179, 0.12085740055356707, 0.6550092324614525, 0.3467548175581864, 0.9954274828944887, 1.061990139739854, 3.8516891598701477, 9.311498062951223, 107.53296170915876, 88.8818427494594, 95.90406744820731, 91.6091079711914, 97.80693585532052, 90.50477518354143, 93.9861283983503, 92.99407849993024, 95.47587081364223, 88.74289962223598, 90.19034140450614, 88.97851998465401, 88.83293437957764, 83.48498235430036, 89.45249135153634, 85.95719310215541, 84.19172532217843, 81.54523290906633, 79.59014878954206, 70.36967386518205, 64.78977012634277, 60.64453043256487, 63.7336300441197, 60.75507627214704, 65.7284995487758, 67.00349399021694, 67.41435486929757, 59.978698457990376, 62.957286970955984, 62.51836231776646, 67.63059670584542, 67.49071557181222, 70.17039258139474, 66.94123118264335, 70.85258756365094, 69.88451589856828, 72.44717134748186, 74.5261765888759, 79.27716023581368, 75.25468131474086, 75.7866701398577, 75.37836619785854, 73.36748109545026, 74.55850655691964, 78.41235964638847, 63.207915442330496, 79.083388873509, 71.60680062430245, 75.6097412109375, 80.87221649714878, 83.21365519932338, 79.54397106170654, 70.30379799434117, 62.316628319876536, 59.97192396436419, 59.15350260053362, 65.85643672943115, 69.98279816763741, 77.02369962419782, 80.66103989737374, 82.82520920889718, 79.75192369733537, 76.73748942783901, 72.88997309548515, 69.65919276646206, 63.76006099155971, 60.81866618565151, 58.574766295296804, 61.913952418736045, 63.269733565194265, 72.23568902696881, 70.15421022687639, 70.7800622667585, 68.7387718473162, 72.08476720537458, 66.41011783054897, 71.49887425558907, 64.3211419241769, 67.89311354500907, 63.91381072998047, 65.86867945534843, 72.18708637782505, 82.93698487962995, 77.7853889465332, 93.40870530264718, 13.703483922140938, 1.1875337745462144, 6.955242327281407, 0.06382793680365596, 0.08508765351559434, 0.13892925796764238, 0.02466340103585805, 0.16320190764963627, 1.4179054243224007, 17.329988479614258, 16.444157430103846, 52.03414555958339, 74.54347760336739, 67.19927338191441, 79.47362055097307, 62.220979418073384, 25.528748171670095, 16.3517324924469, 37.67720093045916, 63.9482182094029, 65.78355707441057, 72.04719134739467, 13.48843457017626, 0.47798563433544977, 0.07815611974469253, 0.15614241574491772, 0.22780396470001765, 0.11217722097145659, 0.11342464653509003, 0.07764508109539747, 0.0384043153109295, 0.10566303373447486, 0.016175136602084552, 0.14940347735370907, 0.06458569078573159, 0.05027304629662207, 0.06445975468627044, 0.02682735268691821, 0.04829122871160507, 0.09991344011255673, 0.059929746336170604, 0.08292168831186635, 0.05228421052119561, 0.05983040202409029, 0.10185167539332594, 0.07419058467660632, 0.091100152315838, 0.00955025146582297, 0.10683864993708474, 0.055349628174943585, 0.0845086799402322, 0.06010136819843735, 0.03752654544743044, 0.02717980752432985, 0.077363984393222, 0.014869623351842165, 0.03110720044268029, 0.04582139177780066, 0.012669947680218943, 0.06492640357464552, 0.07171317868466888, 0.05176075468105929, 0.0369236263712602, 0.10674939544073173, 0.036828397374067984, 0.05319221251245056, 1.7628774046897888, 95.8445074898856, 109.88760893685478, 106.34467383793422, 82.18759386880058, 66.52121952601841, 51.8858779498509, 29.180467741830007, 14.54422550542014, 35.96976450511387, 56.71718277250017, 100.78935977390834, 110.73935386112758, 50.94185747419085, 3.167044937610626, 1.187657213636807, 0.1187359472470624, 0.4085405064480645, 0.18013933593673365, 1.2401088391031538, 0.42453903225915773, 1.3322392382792063, 3.1304227198873247, 1.8067500676427568, 14.34062157358442, 115.61357770647321, 91.180543082101, 102.08289200919015, 94.18437440054757, 101.90516403743199, 93.7164340700422, 97.95899023328508, 95.83557905469621, 100.16117313929966, 92.23157623835972, 93.25455951690674, 92.15302685328892, 92.11282457624162, 84.5093274797712, 93.25792939322335, 90.63957023620605, 88.73078891209194, 83.90432003566197, 83.6135448728289, 73.16861670357841, 67.40445368630546, 64.10143988473075, 66.33630016871861, 63.77280398777553, 68.00475719996861, 71.34365149906704, 70.03472205570766, 62.72969872610909, 64.37181513650077, 64.90007277897426, 70.71087905338833, 71.07208115713937, 71.60188129970005, 71.1687444959368, 72.32796110425676, 73.19626358577183, 74.38746970040458, 77.84484468187604, 80.84579944610596, 76.38421521868024, 76.78161743709019, 77.29929992130825, 75.88516085488456, 78.86133139474052, 82.79794447762626, 66.45095239366803, 84.5561305454799, 74.21165943145752, 76.82919175284249, 84.580504826137, 86.00017465863908, 82.74012156895229, 73.26989364624023, 65.61673082624162, 63.32365158626011, 63.09290885925293, 68.46687494005475, 72.0132007598877, 79.00470052446637, 83.01023973737443, 84.69479574475969, 81.81256484985352, 79.89199243273053, 75.53339440482003, 73.06635311671666, 66.74008778163365, 64.10806846618652, 61.364183153424946, 65.1596713747297, 66.38053934914726, 74.80970478057861, 72.8564202444894, 75.8133442742484, 71.73418194907052, 75.66710553850446, 69.89454909733364, 74.82194055829729, 67.54616914476667, 70.43091528756278, 67.73315906524658, 68.23608357565743, 72.52125998905727, 86.33378546578544, 79.28327465057373, 99.55754143851144, 23.34324962752206, 0.8820758195860046, 2.833047636917659, 0.08092790815447058, 0.7597918127264295, 0.19641341481889996, 0.08783926907926798, 0.2823212407529354, 0.9608185057129178, 19.979004825864518, 20.515115669795446, 56.45935596738543, 78.26849024636405, 77.5149928501674, 65.70840535845075, 41.05749954496111, 31.600362028394425, 35.64775371551514, 46.30073526927403, 75.41023063659668, 72.84487233843122, 87.43114921024868, 23.05204541342599, 0.5180770116192954, 0.14351025143904345, 0.08378171787730285, 0.08499450422823429, 0.11394911339240414, 0.04755396648709263, 0.013331081668314124, 0.04728568731141942, 0.05947588783289705, 0.047042015208197493, 0.027014345063694885, 0.0602808203548193, 0.08581684795873505, 0.037012015735464435, 0.016251716064289212, 0.03579580617536392, 0.02254891119498227, 0.01678180119155773, 0.002633787745643141, 0.02192972763441503, 0.028372446474220072, 0.06647335485156093, 0.04128757006089602, 0.04609211367954101, 0.10119258718831198, 0.1600790180798088, 0.17160325683653355, 0.15657351618366583, 0.11714818887412548, 0.12540758853512152, 0.2198504621961287, 0.12042559443839959, 0.15913670935801097, 0.09083927595721823, 0.08308443493608918, 0.19751774413245066, 0.16372041696948664, 0.15394331089087895, 0.14218653818326338, 0.09368276516241686, 0.13948447603200162, 0.14597124366887979, 0.17920255048998765, 3.7649726016180853, 120.47817829677037, 118.4969550541469, 126.89101818629673, 92.80971499851772, 78.53068052019391, 54.88303204945156, 31.669934340885707, 54.91307258605957, 66.6962307521275, 85.51703861781529, 117.85774857657296, 119.2965954371861, 66.93160792759487, 4.555060080119541, 1.7151033282279968, 0.4494781254657677, 0.6158565133810043, 0.2794407510331699, 2.7310719660350253, 1.1540742899690355, 4.302027097770146, 7.050863002027784, 8.6448974439076, 12.263275214603969, 125.34229251316616, 95.68839536394391, 109.65421894618443, 99.56483704703194, 107.10038076128278, 98.71569074903215, 102.80196108136857, 100.03199917929513, 105.91355895996094, 96.0504173551287, 96.13207953316825, 94.74054990495954, 96.00018882751465, 89.09042767116001, 96.59655966077531, 94.35361862182617, 92.39542170933315, 89.9013727733067, 88.72553607395717, 77.60263742719377, 70.06478691101074, 66.69081810542515, 70.0958662033081, 68.68429797036308, 74.16627379826137, 76.18950584956578, 76.20576463426862, 65.11010987418038, 68.19816725594657, 68.70428793770927, 74.59293488093785, 76.74077592577252, 78.26623903002057, 74.62980897086007, 77.88328211648124, 79.29130676814488, 79.44998277936662, 83.53170898982457, 88.20691558292934, 81.2593492780413, 83.19634028843471, 82.72847638811383, 80.08652114868164, 82.37311771937779, 86.38670989445278, 70.16314561026437, 87.83554131644112, 79.65769917624337, 80.46139730725969, 87.15748746054513, 89.4448413848877, 87.06875201633999, 77.6798597063337, 68.18604959760393, 64.61303574698312, 65.92193044934953, 72.33462442670549, 76.25431169782365, 84.76291588374546, 87.66912501198905, 89.54716750553676, 84.83400290352958, 81.70839050837925, 78.9398112978254, 77.69567380632672, 71.72275911058698, 68.07802595411027, 64.01251683916364, 68.66990130288261, 69.9215567452567, 80.05886037009103, 76.91010352543422, 79.9804916381836, 76.95270987919399, 80.77321161542619, 72.43938936505998, 79.74603162493024, 71.4342212677002, 77.18373053414481, 72.17480891091483, 74.79743426186698, 78.23120621272496, 92.24498626164028, 84.59993198939732, 105.37820025852749, 17.814635753631592, 2.483573875256947, 13.679344143186297, 0.09025289277945246, 1.2431306540966034, 0.23938370762126787, 0.192547257989645, 0.4259202852845192, 3.667578399181366, 35.58709246771676, 32.38006802967617, 69.53832190377372, 84.34406457628522, 87.92122650146484, 113.93138408660889, 81.20687648228237, 35.15305239813668, 26.95324526514326, 53.38975647517613, 87.99518312726701, 85.09347643171037, 100.13021891457694, 28.808725220816477, 0.824312187731266, 0.3470913166446345, 0.2267171415899481, 0.24156183217253002, 0.1553949958511761, 0.1891523708722421, 0.21827095480901854, 0.11029860177742583, 0.15049154896821293, 0.13713289078857216, 0.28924859474812237, 0.16071705812854425, 0.19621300271579198, 0.19946250692009926, 0.12236416898667812, 0.12016529483454567, 0.18110262496130808, 0.0808246283392821, 0.17287279585642473, 0.14524422053779873, 0.16295641367988928, 0.13485618866980076, 0.2178551892616919, 0.09616582335105964], [0.04428888651143227, 0.08224528389317648, 0.08432164176234178, 0.06324632372707129, 0.06781099843127386, 0.04031723445015294, 0.08817749164466347, 0.06323031030063118, 0.04589633936328547, 0.02080318986970399, 0.04718556946941784, 0.03287686048341649, 0.04107931748564754, 0.06364881034408297, 0.11359195291463818, 0.047478876409253905, 0.06531238143465348, 0.09393068828753062, 0.4626323953270912, 32.122064045497346, 112.94951329912458, 90.95277418409074, 82.00653770991734, 60.35346344539097, 30.09166840144566, 28.541725056512014, 70.87714944566999, 116.38585608346122, 76.05393954685756, 90.02366106850761, 98.73449952261788, 54.88100317546299, 6.65024767603193, 1.0319528600999286, 0.2431917004287243, 0.14855228231421538, 0.26712990020002636, 0.060859217175415585, 0.1258788446762732, 0.464424053473132, 0.5797415141548429, 1.4701014863593238, 2.8212482929229736, 94.31895405905587, 94.82884761265346, 92.8506190436227, 90.5707483291626, 91.91661439623151, 88.5896987915039, 92.50727381025041, 91.16828645978654, 85.20495332990373, 84.93745463235038, 90.48425715310233, 90.55499676295689, 85.16323634556362, 85.52338927132743, 83.66360664367676, 81.5593238558088, 89.20662934439522, 84.63297762189592, 81.3926226752145, 73.29057148524693, 65.93560450417655, 58.056010314396445, 59.38945647648403, 60.54428877149309, 60.80874415806362, 63.30597536904471, 66.17324679238456, 62.164184842790874, 61.95062501089913, 60.93800149645124, 61.56322125026158, 60.929024423871724, 59.622936793736045, 60.76530402047293, 59.61566202981131, 59.25975445338658, 58.49154077257429, 57.69248056411743, 58.71954590933663, 59.07063838413784, 58.68044144766671, 60.9846100125994, 61.509872981480186, 66.46608557019914, 78.04793357849121, 79.05654798235211, 61.1882895060948, 77.6768719809396, 70.07240213666643, 70.3581120627267, 78.04944133758545, 79.52431460789272, 80.55943638937813, 68.26518263135637, 61.53321892874581, 63.58958693913051, 62.43710313524519, 62.158244132995605, 62.82816859654018, 63.99114418029785, 68.04509149278913, 74.56862313406808, 75.7906723022461, 73.06620720454625, 71.02632726941789, 67.40733024052211, 68.5181109564645, 59.483778272356304, 61.164526666913716, 61.10925374712263, 61.21376160212925, 60.56796128409249, 68.9482808794294, 70.08594417572021, 69.47150107792446, 66.95407840183803, 70.71224090031215, 65.24043028695243, 70.00664438520158, 63.24985476902553, 64.41556794302804, 59.19899245670864, 64.78568458557129, 72.32910755702427, 81.67688737596784, 79.58638981410435, 84.70698983328683, 6.712304208959852, 0.1745602445943015, 0.464828297495842, 0.27394904143043924, 0.09720591575439487, 0.05986296491963523, 0.035019080354166884, 0.13385439956826822, 1.0363542182104928, 1.911909316267286, 19.31155218396868, 60.5183094569615, 86.84012154170445, 64.00269903455461, 60.03053201947893, 42.84498616627285, 19.96136682374137, 26.14351783479963, 47.023184640066965, 62.30098097664969, 69.27837589808873, 62.58311952863421, 5.167284965515137, 0.23819735699466296, 0.09018984330551964, 0.03442347588549767, 0.019180437749517814, 0.14961591309734754, 0.06755075989557163, 0.10768748367471354, 0.14103085733950138, 0.07764892838895321, 0.0865948765671679, 0.057558714279106686, 0.11082846977348838, 0.04232193223599877, 0.09471267954047237, 0.03339934601847615, 0.1859410953308855, 0.022832767838346105, 0.028330414622489895, 0.045761463564953635, 0.06485398353210517, 0.041223770805767605, 0.006909366455926959, 0.04902355120118175, 0.07148804755083152, 0.02055999104465757, 0.017776653968862126, 0.05059107905253768, 0.027751513989642262, 0.10187813825905323, 0.0325827630502837, 0.05098936214510884, 0.041057984344661236, 0.058686873742512295, 0.07489731282527957, 0.026986363975863372, 0.04411091695406607, 0.07295360855226006, 0.024434945080429316, 0.09741918609610625, 0.05570874622623835, 0.036756940851254125, 0.3571513311139175, 39.77747113364083, 129.60069056919642, 98.05125536237443, 96.24598135266984, 73.52841527121407, 59.799122265407014, 40.075489793504985, 27.287569999694824, 69.39473737989152, 71.67387158530099, 100.54275430951799, 106.34023393903459, 67.23207582746232, 7.919719168118068, 1.0313875590051924, 0.08986159520489828, 0.062140121656869135, 0.08294309609170471, 0.6971906604511398, 0.123877953471882, 1.1467746645212173, 1.683144980243274, 0.8926354529602187, 5.107927807739802, 104.515748160226, 94.62179129464286, 99.05799375261579, 92.50956671578544, 95.40438774653843, 91.1561757496425, 96.94902093069894, 93.99759292602539, 87.23725278036935, 87.96716104234967, 94.64438683646065, 93.92911842891148, 88.01968942369733, 89.11671965462821, 86.64344583238874, 86.2073699406215, 89.64226749965123, 88.95559787750244, 85.48351355961391, 76.50785146440778, 69.22135898045131, 62.75203023638044, 63.1946165902274, 64.69700472695487, 64.65883827209473, 65.75471510205949, 69.7120338167463, 64.4458065032959, 65.44165706634521, 64.38071577889579, 64.02890763963971, 64.49137278965541, 61.85776233673096, 61.82485566820417, 62.11256667545864, 62.94813619341169, 62.51205335344587, 60.89443629128592, 60.43879427228655, 62.46284621102469, 60.62292848314558, 63.11214147295271, 64.07198647090367, 68.84711510794503, 80.46337059565953, 82.8231178011213, 62.821936062404085, 81.97131729125977, 72.81303569248745, 75.73359979901994, 80.00188514164516, 79.95934132167271, 83.91035107203892, 73.1693810054234, 65.33802468436105, 67.26250198909214, 65.127000944955, 64.04058061327252, 66.69679355621338, 67.19150529588971, 68.923844064985, 75.0046295438494, 79.88609341212681, 77.05837113516671, 75.50075871603829, 71.02472918374198, 71.70058046068463, 63.373407636369976, 63.70817879268101, 62.77495929173061, 63.99400683811733, 62.14918368203299, 71.67710944584438, 71.85414259774345, 72.9145975112915, 69.99454062325614, 73.50662572043282, 67.64211681910923, 74.16265378679547, 67.18618992396763, 66.93399810791016, 61.952355112348286, 68.02915927342006, 75.17313030787876, 84.04654271262032, 78.72374316624233, 93.1919492994036, 12.227747338158743, 1.0247663600104195, 0.6386426421148437, 0.847858764231205, 0.26705621129700113, 0.11005324351468257, 0.04367572155648044, 0.38237815030983513, 1.3306557003940855, 1.4623636901378632, 21.30379526955741, 64.45032283238002, 89.45148386274064, 71.77554457528251, 48.03032602582659, 39.52328518458775, 26.05234009878976, 36.09144483293806, 56.485498564583914, 71.37664154597691, 76.8900579724993, 80.89109475272042, 8.908632823399135, 0.24257648629801615, 0.12382516344743115, 0.05247966592599239, 0.07412677524345261, 0.14957583881914616, 0.08145351495061602, 0.057927063799330165, 0.089149662692632, 0.16541436607284205, 0.08743615142468895, 0.07020791659929923, 0.06451907221760068, 0.08396602834441833, 0.07312559003808669, 0.040629316453955004, 0.04128248444093125, 0.05287881415071232, 0.03530269442126155, 0.054588020113962035, 0.03313384883637939, 0.06496806562479053, 0.030448010457413535, 0.06135291925498417, 0.11789379029401711, 0.13764240273407527, 0.240406368459974, 0.1869891740913902, 0.19669928162225656, 0.1540519172059638, 0.12154699569301945, 0.173975618822234, 0.15117536298930645, 0.22810805695397512, 0.15678566694259644, 0.11623155591743332, 0.11638270637818746, 0.27858823963574, 0.17881128005683422, 0.1237199633781399, 0.16600957699120045, 0.3800237152193274, 0.38503374638301985, 52.66017477852957, 142.04677636282784, 115.81862599509103, 110.45194162641252, 87.17734541211809, 54.38918536049979, 44.63654095785958, 104.53056171962193, 166.09724317278182, 116.51170880453927, 111.8131354195731, 113.4049607685634, 79.76707771846226, 11.56392686707633, 2.536159796374185, 0.3571851764406477, 0.29371520078607966, 0.43768049137932913, 0.953623754637582, 0.21878698069070066, 1.908977393593107, 4.5879988840648105, 5.660568416118622, 4.15095762695585, 108.45625918252128, 99.99166488647461, 105.4475849696568, 100.02684361594063, 98.21833174569267, 96.08891037532261, 100.26803643362862, 99.37290000915527, 92.74360983712333, 93.37749399457658, 97.7353902544294, 99.1625919342041, 94.72980798993791, 93.5929228918893, 88.5300624029977, 90.10462842668805, 95.18449810573033, 93.17644092014858, 89.785553250994, 80.34511920383999, 73.38617174965995, 65.24812194279262, 65.49967452457973, 66.51457009996686, 66.43406132289341, 70.08717400687081, 73.89494664328438, 70.04964678628104, 68.43955462319511, 67.64185278756278, 68.27808543613979, 67.66754027775356, 66.32503713880266, 67.48539325169155, 67.41060284205845, 67.08523954663957, 65.99923610687256, 65.04463005065918, 66.85537924085344, 67.61776338304792, 64.46101611001151, 68.17917088099888, 68.2361877986363, 74.12423719678605, 84.96883964538574, 85.77130099705288, 66.89859008789062, 84.85594531467983, 75.8277200971331, 79.24076557159424, 84.60237775530133, 83.03957503182548, 88.24950109209333, 76.43167836325509, 68.44404315948486, 70.41064739227295, 67.91443756648472, 69.4428744997297, 71.77687168121338, 70.7344056538173, 73.91313007899693, 79.67958600180489, 83.64052472795758, 81.94865226745605, 78.8279869897025, 73.54541751316616, 74.94244316646031, 66.98176002502441, 68.55203206198556, 66.28738485063825, 66.88049697875977, 66.1921945299421, 76.8014475958688, 78.62408515385219, 76.00762285505022, 75.7071202141898, 77.6926165989467, 73.3849002293178, 78.45347213745117, 69.66640499659947, 72.305483681815, 65.43626526423863, 74.08208247593471, 78.3836635862078, 89.31484753744942, 84.5282335281372, 96.55696187700543, 9.089416265487671, 3.50744782601084, 4.121320954390934, 0.8907819124204772, 1.1581769841057914, 0.13784666891608918, 0.21147678366729192, 0.8132853965674127, 2.8848269156047275, 7.861547112464905, 34.41414621898106, 80.41352421896798, 99.55668681008476, 76.76718602861676, 85.48863438197544, 57.27418163844517, 28.719308853149414, 39.46133852005005, 64.81282424926758, 85.25636305127824, 88.34914520808628, 94.23411655426025, 11.273418341364179, 0.47838314729077475, 0.19592450319656304, 0.1519578088607107, 0.1299003588833979, 0.2201586120894977, 0.12020112148353032, 0.1301876370395933, 0.1786438583263329, 0.39300514864070074, 0.1692165234791381, 0.09971082955598831, 0.20540088255490574, 0.11745815724134445, 0.20186074823141098, 0.25061579634036335, 0.16021669283509254, 0.13457235747150012, 0.09943293553910085, 0.12336601237101213, 0.0847669778657811, 0.2003717709864889, 0.1558520977518388, 0.1436767910740205], [0.1231624111533165, 0.04188422965151923, 0.11417891963252, 0.055942284408956766, 0.07179604138114623, 0.06797331079308476, 0.014675100932696035, 0.04676661480750356, 0.09148993675730058, 0.06449636165052652, 0.037147624351616414, 0.07877944236887352, 0.05337585462257266, 0.07904848828911781, 0.07917712495795318, 0.058932075942201276, 0.12416923498468739, 0.07290932057159287, 0.6567276631082807, 66.8102923801967, 97.07534612928117, 80.26025390625, 53.31368064880371, 59.086515017918174, 27.104856695447648, 46.693159103393555, 110.75269440242222, 57.913877964019775, 86.70078931535993, 107.12125314985002, 64.57304191589355, 13.60573058468955, 0.29659004509449005, 0.23214705022318022, 0.2158802995192153, 0.09977198591721909, 0.08824599654014621, 0.03196316897603018, 0.17577664075153215, 1.449157987322126, 0.5203134630407605, 0.20590397555913242, 63.875269072396414, 105.99638843536377, 90.4228767667498, 89.45133795057023, 78.92827033996582, 81.4997569492885, 79.76609107426235, 87.35316262926374, 76.7643928527832, 83.7395018168858, 84.0265805380685, 81.09759521484375, 78.71159771510533, 87.11902918134416, 86.58621352059501, 86.33659253801618, 81.77911622183663, 81.32654530661446, 82.8134320122855, 83.4249985558646, 74.83876909528459, 64.61502987997872, 60.83787100655692, 62.134773118155344, 62.85539163861956, 63.46919550214495, 60.51683643886021, 58.844849722726, 56.18580191476004, 58.01972334725516, 62.81418187277657, 61.17732524871826, 58.45390238080706, 56.662628991263254, 59.20742756979806, 60.07658467973982, 63.603323527744834, 65.4655658176967, 67.76029178074428, 65.54635252271379, 62.49022906167166, 62.36011014665876, 62.10973181043352, 61.23925454275948, 68.98439761570522, 76.78242342812675, 81.03852857862199, 55.27006755556379, 78.74383735656738, 68.43883895874023, 68.58355603899274, 78.92487267085484, 79.00059413909912, 77.93159294128418, 70.45629010881696, 63.42308725629534, 58.289195333208355, 59.69838728223528, 58.00569493430001, 57.68682473046439, 58.33484499795096, 58.7281825201852, 60.15428638458252, 66.52536065237862, 73.84933866773332, 72.73425701686314, 69.59437997000558, 66.88194220406669, 59.148020471845356, 58.41721589224679, 58.62888581412179, 59.63620090484619, 57.49375166211809, 63.52085535866873, 67.19831453050885, 67.63733645847866, 65.78063188280377, 67.20654119764055, 69.9009622846331, 64.38006264822823, 67.19238771711076, 63.411275318690706, 58.68919617789132, 59.32148919786726, 64.73510864802769, 76.61626420702252, 78.82712541307721, 85.97244439806256, 60.10122299194336, 0.9928734770842961, 1.473520108631679, 0.27115312431539806, 0.11018622959298746, 0.16445563680359296, 0.08019188764904227, 0.04227302682452968, 0.20960583191897186, 0.29359306448272293, 0.15334515513053962, 16.11662629672459, 39.80327326910836, 61.03685351780483, 94.57406411852155, 67.74924414498466, 47.63685301371983, 29.021458217075892, 32.68393359865461, 47.29578678948538, 65.1568990434919, 64.60146004813058, 40.196527412959504, 1.2974815262215478, 0.032573270345372815, 0.06555044544594628, 0.017088977387174964, 0.07295009374086346, 0.03027322662195989, 0.021122633978458386, 0.10862994167421545, 0.024387870017173033, 0.14696917869150639, 0.05569904317547168, 0.08769769274762698, 0.017842824703880718, 0.06523821755711522, 0.020661026605271866, 0.0745078744366765, 0.10243803142969098, 0.08143798328403916, 0.09580244070717267, 0.06123079652232783, 0.032068029777812104, 0.01827558924976204, 0.027357417458136166, 0.06889584021908896, 0.00898525825635131, 0.027199249248951674, 0.041140799543687274, 0.03162519746859159, 0.032206732513649125, 0.03515523179833378, 0.0036769091717100567, 0.029306212440133095, 0.06157378240355423, 0.09963228912757975, 0.040572556999645064, 0.08845438142972332, 0.031138715001621416, 0.032682205749941726, 0.042616755701601505, 0.06738428132874624, 0.09798281120934657, 1.0550791791507175, 80.87614917755127, 111.05409336090088, 91.41457230704171, 72.07994515555245, 75.23254435403007, 39.70918423788888, 38.19056510925293, 97.15238775525773, 72.20153168269566, 85.01219640459333, 109.65421894618443, 77.47247682298932, 16.180737325123378, 0.29983838221856524, 0.10010399988719396, 0.2919547552508967, 0.06753241909401757, 0.0232363282370248, 0.1598140908671277, 0.7742974257894925, 1.3067834270851952, 0.3493599577673844, 0.3953424303659371, 73.67591163090297, 105.56416184561593, 95.37532343183244, 93.53592681884766, 82.53021648951939, 84.84021459306989, 82.83391530173165, 89.69289207458496, 80.54781900133405, 86.61777223859514, 88.93985325949532, 83.6502799987793, 84.04950264522007, 90.6002503803798, 90.96550328390938, 88.90863500322614, 84.80947576250348, 83.50676495688302, 87.61374092102051, 85.68430260249546, 78.22662734985352, 67.67639923095703, 63.751049177987234, 63.532597814287456, 65.73609392983573, 66.44394166128976, 62.69609028952462, 62.78238691602434, 60.034728731427876, 61.503244400024414, 65.85964679718018, 63.80571065630232, 61.698794501168386, 61.2543043409075, 61.682876178196494, 62.92847279139927, 65.91650390625, 70.72551890781948, 71.7764756338937, 70.19099399021694, 67.10879393986293, 65.3730366570609, 66.48466505323137, 65.50135598863874, 73.11934702736991, 78.19114984784807, 83.6076944896153, 56.329320430755615, 82.35129342760358, 72.75225285121373, 72.34822899954659, 81.56013679504395, 81.69286823272705, 81.36239106314522, 75.15531512669155, 66.27030617850167, 61.56175518035889, 61.62110669272286, 59.64806147984096, 60.9850685937064, 62.04601682935442, 62.177254404340474, 61.32516207013811, 69.85708441053117, 76.83732114519391, 74.94870349339077, 72.3898834500994, 68.46024635859898, 63.962858063834055, 62.45725291115897, 60.76115594591413, 61.84398405892508, 60.52935709272112, 67.3018079485212, 69.61453669411796, 72.10752950395856, 71.08073166438511, 70.04508876800537, 73.4012701851981, 68.23688956669399, 70.09522696903774, 66.32504408700126, 63.36258234296526, 62.24564552307129, 69.01874256134033, 77.61358778817313, 84.76246425083706, 86.0871661049979, 70.0762028012957, 5.286533858094897, 1.5764941487993513, 0.08580577426723071, 0.33970532725964275, 0.14125854655035905, 0.20982769929936954, 0.04199820996395179, 0.02808377392856138, 0.2598375215062073, 0.3572072152580534, 16.612449748175486, 43.37991755349295, 63.59259550912039, 89.04720292772565, 44.124684538160054, 51.084083625248496, 39.610036918095176, 38.37899678094046, 54.077516964503694, 74.57664135524205, 75.6932863507952, 58.257862431662424, 1.497286204780851, 0.01704879284703306, 0.09289714374712535, 0.04114843984799726, 0.02704559499397874, 0.05309693941048213, 0.03625977145774024, 0.0467671983476196, 0.0371023491024971, 0.012948381980615003, 0.046754272255514345, 0.0725573373160192, 0.010756316927394696, 0.053681056281285625, 0.02228676258320255, 0.0599905430738415, 0.03466171292322023, 0.09432768555624144, 0.061087897047400475, 0.03751960064151457, 0.07383632832872015, 0.030340028394545828, 0.06527339959783213, 0.2517386632306235, 0.12590433045157365, 0.21918761490711144, 0.10891751838581902, 0.11066399967031819, 0.10867996327579021, 0.12901868405086653, 0.19587126533899987, 0.14859185447650297, 0.15439296247703688, 0.11234078862305198, 0.13042931764253549, 0.15272667046104157, 0.1543176043778658, 0.11721834939505373, 0.1310598530939647, 0.25313142420990126, 0.2974644867437226, 2.380958535841533, 100.81308787209647, 125.25524548121861, 108.00872571127755, 79.7891035079956, 83.67770453861782, 37.61863456453596, 65.49401869092668, 143.17267635890414, 78.8166753223964, 100.76716027941022, 116.82053538731166, 93.96473489488874, 21.105722972324916, 0.5474730485251972, 0.3362463457243783, 0.5792974265558379, 0.1929484893168722, 0.5199091104524476, 1.1781709683792931, 1.875416943005153, 4.313265808991023, 5.750481579984937, 0.6600093841552734, 78.17825399126325, 109.93357821873256, 99.491776738848, 96.14123725891113, 87.843323298863, 91.3212788445609, 88.58099269866943, 95.94724355425153, 84.49959305354527, 91.22557435716901, 94.63058076586042, 89.08646719796317, 85.68658855983189, 95.66368062155587, 95.9322007043021, 93.54017216818673, 86.61347825186593, 88.53848361968994, 91.9207763671875, 89.70034054347447, 82.70922987801688, 72.6202301297869, 67.04972730364118, 67.35915837969098, 69.39673151288713, 71.31225953783307, 66.43313026428223, 65.29736382620675, 62.21004295349121, 64.69169630323137, 69.94513198307583, 67.61982699802944, 64.05741609845842, 63.02603939601353, 66.31006377083915, 67.45026315961564, 70.76713166918073, 72.92342172350202, 74.56457233428955, 72.74248368399483, 68.943514415196, 69.00139985765729, 69.12534877232143, 65.52320112500871, 76.71961171286446, 84.34018053327287, 88.83368478502545, 63.226675578526084, 87.27390452793666, 74.04784870147705, 75.43409075055803, 84.98667567116874, 83.26275811876569, 85.77328818184989, 77.4155502319336, 68.77864755902971, 65.4511969430106, 63.72462517874581, 63.90563270023891, 64.75085326603481, 65.49302509852818, 66.03035708836147, 65.98924459729875, 71.87298611232212, 81.46979631696428, 79.58693177359444, 76.62882655007499, 74.55465725490025, 67.48139803750175, 65.7145128250122, 64.73692907605852, 65.52502850123814, 64.48617553710938, 70.74441105978829, 75.13003758021763, 75.86869362422398, 73.73782702854702, 75.76303931644985, 79.37765203203473, 72.11130237579346, 76.03408159528459, 70.20944840567452, 66.72057723999023, 66.16777856009347, 74.3494838987078, 84.78430243900844, 87.61342130388532, 88.23092855725969, 74.40512507302421, 3.9590722663061957, 5.6448776466505866, 1.1207487753459384, 0.6262689317975725, 0.5326705085379737, 0.33006467457328525, 0.1946827434003353, 0.2765114339334624, 0.8308231926390103, 0.5369153693318367, 25.169878925595963, 57.67743076596941, 74.26545238494873, 111.64153575897217, 88.545973777771, 62.21662984575544, 39.94345317568098, 46.20335626602173, 64.86189242771694, 86.91104875292096, 86.46418230874198, 71.59405067988804, 1.9740077555179596, 0.15000125313443796, 0.17990693769284657, 0.13433818146586418, 0.18631207756698132, 0.12884086716387952, 0.09316020498850516, 0.18046694621443748, 0.09174218215048313, 0.3075327793402331, 0.07789058185049466, 0.23061554240328924, 0.09448617098054715, 0.14427668388400758, 0.09660968024815832, 0.13679337900664124, 0.15203201345035008, 0.16469308334801877, 0.10647135214614016, 0.08870584650763444, 0.12487873834158693, 0.08548401974673782, 0.21252423817557947], [0.05225680109911731, 0.08078877454889671, 0.09558952320367098, 0.03954024739297373, 0.01866942284894841, 0.0795735183304974, 0.03771666756698063, 0.04116770006450159, 0.05640873312950134, 0.03731679670246584, 0.03131596191919275, 0.07987163947629076, 0.05577489660520639, 0.11097232598279204, 0.1018229258645858, 0.12717480584979057, 0.013583534862846136, 0.4883278108068875, 6.85935240983963, 90.38485622406006, 91.82521779196603, 79.17635577065604, 53.69700581686837, 36.69726174218314, 43.47745983941214, 106.23765768323625, 96.31975732530866, 108.35875511169434, 135.31130381992884, 78.64618737357003, 21.28718560082572, 0.24687036446162633, 0.013213135318697562, 0.22611823944108828, 0.04575329400332911, 0.03189204493537545, 0.20149497714425835, 0.2598475366830826, 0.4484081028827599, 0.30765475279518534, 1.2257801336901528, 30.754477909633092, 105.71308258601597, 92.79372719355992, 98.28996072496686, 85.64314842224121, 78.45839841025216, 67.34741592407227, 72.69838346753801, 73.77851567949567, 77.45671136038644, 72.27565506526402, 75.93778651101249, 76.95573929377964, 85.43723160879952, 84.99124758584159, 84.00902938842773, 82.85672623770577, 84.22767530168805, 79.95306015014648, 87.00300816127232, 80.04377583095005, 70.25867639269147, 59.28515011923653, 61.03779847281319, 56.38323150362287, 62.62107058933803, 60.089848790849956, 62.607229777744834, 59.384085518973215, 60.479934556143625, 61.73320892878941, 59.635936873299734, 55.89136157717024, 59.46694278717041, 59.13850143977574, 61.51699488503592, 64.63085787636894, 72.20497104099819, 76.9404741014753, 75.75552831377301, 77.309020451137, 77.54262583596366, 70.68349620274135, 71.00172369820731, 61.6868713923863, 66.80282306671143, 76.65399292537144, 74.71477849142892, 45.32922077178955, 74.2484154020037, 69.85759162902832, 67.52253137316022, 75.42207036699567, 80.25846127101353, 76.73029109409877, 76.57374123164585, 67.41803741455078, 63.9979464667184, 59.11696202414376, 56.85331187929426, 57.01581982203892, 57.88668966293335, 59.79968506949288, 58.830453055245535, 57.810711111341206, 63.774381228855674, 65.28180680956159, 66.6781723839896, 60.20759296417236, 61.20944677080427, 57.7028820174081, 59.01066848209926, 55.423410824366975, 56.706093447549, 58.910134996686665, 62.59578609466553, 66.96226337977818, 67.43540791102818, 66.51502173287528, 69.14967441558838, 65.04800687517438, 62.07522010803223, 61.52629852294922, 58.672430174691335, 55.81614037922451, 64.74630914415631, 69.88257735116142, 80.01288414001465, 79.10280214037213, 74.40339497157505, 49.06174441746303, 0.2881481466548783, 0.856545260974339, 0.3967353541936193, 0.07868355858538832, 0.1345879909183298, 0.042773280159703324, 0.3040425037699086, 0.039849265811166594, 0.061579509239111624, 0.13392308088285582, 16.470531054905482, 24.93296272414071, 57.03870023999895, 77.3734302520752, 38.266818114689414, 21.402456215449742, 26.742153780800955, 39.085638999938965, 50.38811731338501, 65.56803785051618, 66.20430524008614, 20.196566820144653, 0.5214070986424173, 0.1590599399060011, 0.1254711944077696, 0.1416207892554147, 0.121940016746521, 0.02848822151177696, 0.05425967023308788, 0.07232367699699742, 0.14452539410974297, 0.07076918719602482, 0.07403128501027822, 0.04904641443863511, 0.042296816262283495, 0.08508614038250276, 0.08525242895952292, 0.10313735676131078, 0.132413883294378, 0.12425767523901803, 0.0331196369204138, 0.102476273663342, 0.04397364253444331, 0.06943119756345238, 0.0732253889686295, 0.04957444699747222, 0.07188749433095966, 0.031740124337375164, 0.03826567703591926, 0.046574854025883336, 0.06909858648266111, 0.07831418447728668, 0.03249689783634884, 0.0738508625488196, 0.04545728310144373, 0.05963975403990064, 0.025018636170508604, 0.07967414507376296, 0.035543509892054966, 0.0878752585766571, 0.038280747298683436, 0.5147734146033014, 8.830238904271807, 109.7057328905378, 103.0766372680664, 93.30643476758684, 62.515888759068076, 55.7628789629255, 32.63497659138271, 64.10707487378801, 111.617995262146, 108.9967178617205, 131.47517558506556, 93.68201269422258, 26.268416915621074, 0.20775374344417027, 0.1574739728655134, 0.23654591132487568, 0.0633728772933994, 0.02392426605469414, 0.10059157479554415, 0.1863479313573667, 0.4010554780917508, 0.5587735335741724, 0.7533070264118058, 37.88089084625244, 109.82362297603062, 96.93304007393974, 102.52907752990723, 90.56538431985038, 79.95608956473214, 71.17235061100551, 76.70859186989921, 76.57645102909633, 80.5022040775844, 76.60939938681466, 80.17918232509068, 79.68321296146938, 91.34523623330253, 87.24124799455915, 89.63985647474016, 87.08353083474296, 88.04489053998674, 85.29169464111328, 89.11138343811035, 82.65901524680001, 73.09386103493827, 61.79344981057303, 63.37342848096575, 61.41582216535296, 66.48012787955147, 64.20036833626884, 64.84703023093087, 61.84693704332624, 65.81403187343052, 64.39105469839913, 63.18352031707764, 58.105738571711946, 61.15434755597796, 62.20711081368582, 65.2434527533395, 68.13517488752092, 76.47907897404262, 81.02694593157086, 81.19537026541573, 80.39604949951172, 80.54617227826799, 74.27208791460309, 74.55336488996232, 64.33878340039934, 70.98801490238735, 78.9976897920881, 76.6620945249285, 47.70146778651646, 77.71587221963065, 72.60464532034737, 68.20553234645298, 78.62939357757568, 81.13057831355503, 79.94855076926095, 80.01993656158447, 71.30107988630022, 67.08230740683419, 62.65249729156494, 59.42186287471226, 59.59986877441406, 61.22750513894217, 60.89600658416748, 62.1230445589338, 61.16209479740688, 65.91456535884312, 69.34467560904366, 68.37749331338065, 64.796051297869, 63.27100508553641, 61.78111675807408, 61.05281352996826, 58.3677864074707, 60.47823224748884, 59.832265172685894, 64.97040244511196, 70.38546017238072, 69.90754917689732, 71.34351253509521, 71.90219633919853, 68.37813949584961, 66.79212284088135, 62.62676811218262, 63.67782211303711, 57.73364864076887, 65.21773747035435, 71.01697499411446, 80.41303089686802, 81.79694529942104, 80.18877778734479, 63.876144545418875, 1.5648315974644251, 0.6337585470506123, 0.03373122428144727, 0.20305076294711658, 0.031436198324497254, 0.13512936686830862, 0.44682909761156353, 0.05346858661089625, 0.08110571147075721, 0.21771028132310935, 18.057815756116593, 26.23252773284912, 53.665078844342915, 63.75592681339809, 31.391356740679058, 28.040803364345006, 35.485627923692974, 45.80501256670271, 60.87197276524135, 74.10741560799735, 83.0947437286377, 32.12159504209246, 0.4972630856292588, 0.07634120820356266, 0.08467775051082883, 0.06981355204646077, 0.15904916476990494, 0.023518568270706704, 0.06744326637791735, 0.08302279002964497, 0.12100758749459471, 0.05864192758287702, 0.1042923658554043, 0.06741109024733305, 0.014261708561597126, 0.08394508196839265, 0.06676863293562617, 0.08039020307894264, 0.03760736236082656, 0.07857606506773404, 0.09990178966628653, 0.04782019309433443, 0.019621653449056402, 0.032717014596398385, 0.1329858068908964, 0.18045750100697788, 0.2193608856094735, 0.22261431174618856, 0.201421247529132, 0.18997512172375405, 0.18057806310909136, 0.11193509932075228, 0.09147804882377386, 0.08437643346509763, 0.16982185813997472, 0.16378130870206015, 0.0693131596116083, 0.11520217758204256, 0.2074422687292099, 0.1816179451665708, 0.15819369495979377, 0.8103422373533249, 13.950406398091998, 128.6731060573033, 116.55999878474644, 108.71755313873291, 77.70187159946987, 52.7181852885655, 61.71335792541504, 143.91135324750627, 104.99008778163365, 125.47162628173828, 145.84514808654785, 105.0429218837193, 33.5928760937282, 0.36161576583981514, 0.30762107031685965, 0.4889307841658592, 0.2452578938433102, 0.21834905418966497, 0.5009606672184808, 0.9557366584028516, 1.4737714380025864, 4.564324200153351, 3.346860408782959, 39.04113926206316, 113.1438822065081, 100.84844725472587, 104.6521829877581, 95.94422108786446, 85.06680229731968, 74.43311241694859, 81.21096897125244, 80.92429324558803, 85.22494329724992, 81.29466002328056, 83.9873788016183, 85.55398218972343, 93.08421748025077, 91.41199452536446, 93.16337830679757, 93.15194852011544, 94.4872602735247, 88.20619991847447, 92.27374485560826, 87.14173589433942, 77.98380170549665, 63.55993202754429, 67.54634979793003, 64.0837150301252, 68.930146081107, 66.11135918753487, 66.04281520843506, 65.1786608014788, 68.46242114475795, 69.3466488974435, 65.63026591709682, 60.540550640651155, 65.32631696973527, 65.35838290623256, 68.26473794664655, 71.38796710968018, 80.06163964952741, 84.10080814361572, 83.30404431479317, 83.64258139474052, 83.36265236990792, 76.93914699554443, 80.01490606580461, 68.31706483023507, 73.77343654632568, 82.51450661250523, 80.09710325513566, 52.902263913835796, 81.48404707227434, 75.84363842010498, 71.92782824380058, 81.08396284920829, 85.90184375217983, 82.23056152888707, 84.9065351486206, 74.82727677481515, 70.44835526602608, 65.39112281799316, 62.378891127450125, 64.22993292127336, 63.049531255449565, 65.59604603903634, 64.81130954197475, 65.16948223114014, 70.43240220206124, 72.68484837668282, 74.15312780652727, 69.08315931047711, 68.69279561723981, 64.51710196903774, 64.10530308314732, 62.048455647059846, 63.32252597808838, 64.73970835549491, 70.4406566619873, 75.59612968989781, 76.16782746996198, 75.9611394064767, 76.82675988333565, 73.97616413661412, 70.47362586430141, 68.17819813319615, 67.57864502498082, 63.65043231419155, 69.63508946555001, 77.92912633078438, 86.77550329480852, 86.56045654841832, 84.55410861968994, 60.78094441550118, 1.0767827459744044, 2.6153842423643385, 1.1062750262873513, 0.6003154558794839, 0.26631321545158115, 0.1609737750674997, 0.8791174069046974, 0.21856421764407838, 0.2085264591234071, 0.22294433760855878, 27.493928023747035, 38.59458201272147, 68.85297243935722, 99.96990312848772, 49.84648091452462, 29.65820155824934, 41.220858642033164, 55.20830501828875, 73.1593964440482, 86.44196891784668, 96.6250125340053, 39.98139728818621, 0.741348416677543, 0.18959729985467025, 0.14107842264430864, 0.2352248579263687, 0.22046247364154883, 0.12734676019421645, 0.14414537378719874, 0.136149489986045, 0.1900903776820217, 0.1044295249240739, 0.13181021782968724, 0.15580937718706472, 0.14264332795781748, 0.1439851988106966, 0.16760839548494133, 0.1628881666277136, 0.18100739935679094, 0.1754014923104218, 0.1514085211924144, 0.19852665785167897, 0.10287969665867941, 0.12331912560122353], [0.037460028659552336, 0.09127870880599533, 0.1416014510073832, 0.10513610379504305, 0.0425557587961001, 0.05748853340212788, 0.1701152566820383, 0.08154211126800094, 0.1335850347365652, 0.1323008257895708, 0.07996754361582653, 0.09449821497712817, 0.037719167968524356, 0.084510491628732, 0.029142641395862614, 0.1403009436492409, 0.10618190267788512, 0.17114152732704366, 26.831578833716257, 89.75946276528495, 81.48522826603481, 66.05071531023297, 57.366995675223215, 46.72252219063895, 43.34000710078648, 90.61489718300956, 69.4802280153547, 87.66575513567243, 85.90366418021065, 42.36884348733084, 0.26599351689219475, 0.04737474503261702, 0.14906149570431027, 0.09641779054488454, 0.07953026850840875, 0.033303743827023675, 0.18135224442396844, 0.04829746444842645, 0.5801051003592355, 1.6023082264832087, 9.590594172477722, 93.71802520751953, 84.21464048113141, 98.39699077606201, 90.30683490208217, 88.4109285899571, 70.51456465039934, 68.07344709123883, 64.63905675070626, 70.83363287789481, 70.25332627977643, 75.36908340454102, 73.99122783115932, 78.65307998657227, 77.21906907217843, 78.99820395878383, 81.15301404680524, 83.00067206791469, 81.50291837964738, 81.35959788731166, 82.46664047241211, 78.55821623120988, 63.37328951699393, 60.62818826947893, 60.30310985020229, 62.91846738542829, 60.93101160866873, 63.03934519631522, 59.149521282741, 57.24607270104544, 59.08846746172224, 56.95415455954415, 60.089230401175364, 68.44658620016915, 72.52795110430036, 75.0894045148577, 74.25022193363735, 75.01405824933732, 75.45739500863212, 78.26341111319405, 77.47621495383126, 76.02793938773019, 73.25302342006138, 74.15638651166643, 71.86642701285226, 62.13343906402588, 66.60625158037458, 73.6340000970023, 72.61595698765346, 38.55301788875035, 73.09400694710868, 69.99053846086774, 62.66999980381557, 73.47480991908482, 77.98058468954903, 74.93372317722866, 75.74287564413888, 74.39046437399728, 68.27632059369768, 64.56013911111015, 61.75364358084542, 56.693069049290244, 55.2463880947658, 58.482369150434224, 59.77246897561209, 57.759009565625874, 58.47450378962925, 58.160285404750276, 60.019908223833355, 56.656333923339844, 55.82922731127058, 55.74039111818586, 55.37373815264021, 56.647888387952534, 55.32098395483834, 59.42908900124686, 55.57887329374041, 60.813448088509695, 67.29199709211076, 68.0186744417463, 66.32959515707833, 66.6847175870623, 63.86631979261126, 63.902909006391255, 55.68051849092756, 56.52435983930315, 56.84991768428257, 68.90688351222447, 71.4223884854998, 81.12239333561489, 79.77029473440987, 94.8192868913923, 23.377379179000854, 1.1812662822859628, 0.17286493842090878, 0.3619657813438347, 0.1725023700190442, 0.05103845415370805, 0.07655188654150281, 0.24406939904604638, 0.0749894714515124, 0.020827630701075708, 0.04316725116223097, 24.690078020095825, 25.570301873343332, 46.21314627783639, 64.26558412824357, 29.72139195033482, 20.14800238609314, 31.475589752197266, 54.43393175942557, 51.39939635140555, 71.57531833648682, 38.89562661307198, 1.3254233811582838, 0.047141953238419125, 0.07655698912484304, 0.07150278533143656, 0.017460424419758574, 0.07260203241769757, 0.05488547629543713, 0.02415944798849523, 0.07954567803868226, 0.05204875208437443, 0.09999266586133412, 0.08470946523760046, 0.0350049125429775, 0.0718518780278308, 0.056390853731759956, 0.054498894539262564, 0.07364690849291426, 0.08317321445792913, 0.009084020724653133, 0.04422076838091016, 0.10862334631383419, 0.08032196281211716, 0.04125335493258067, 0.08568701706826687, 0.04084972159138747, 0.06301982195249625, 0.0765814163855144, 0.09109186061791011, 0.05518218269571662, 0.06468190705137593, 0.015789735496842434, 0.10982575107898031, 0.1167003150497164, 0.07274947807724987, 0.033910486448023996, 0.06716816113995654, 0.08180707919278316, 0.11700420374316828, 0.12411312013864517, 0.06635414981948477, 34.867880957467214, 106.34793949127197, 92.311612537929, 82.29590238843645, 65.56832272665841, 48.16953665869576, 41.107314654758994, 92.82021372658866, 78.33483164651054, 95.09089197431291, 101.05821337018693, 48.67368752615792, 0.4517257320029395, 0.05253501742013863, 0.13794231521231787, 0.35740518463509424, 0.031813378977988443, 0.10804657119193248, 0.07487906023327794, 0.06982321438512631, 0.5197441993015153, 0.8950024545192719, 15.703991889953613, 103.33501992906842, 90.0490219933646, 100.35649394989014, 93.08381448473249, 93.75448240552629, 75.48305470602853, 71.84312275477818, 69.12574481964111, 73.64595099857875, 74.18704196384975, 78.35949080330985, 80.00055803571428, 82.28755065373012, 80.8484606061663, 84.75916385650635, 84.8727946962629, 85.3219609941755, 86.37232712336949, 85.04853548322404, 85.0823176247733, 82.57143320356096, 65.89656257629395, 63.073078700474326, 63.43098040989467, 65.30575725010463, 65.616452898298, 66.9600191116333, 63.579150744846885, 59.876490456717356, 60.75427028111049, 60.081135749816895, 64.17566054207938, 73.33383096967424, 78.02286447797502, 79.38658741542271, 78.17515509469169, 80.3686944416591, 78.07549708230155, 81.49612998962402, 81.51894787379673, 79.39174992697579, 76.72290515899658, 77.59618255070278, 74.04536124638149, 66.4136961528233, 69.32319872719901, 77.74071202959333, 75.75272818974086, 41.215074266706196, 76.44372653961182, 74.04959964752197, 65.99992397853306, 76.06917694636753, 80.96409947531563, 76.43301936558315, 79.61441884722028, 77.09326498849052, 74.14867401123047, 69.27889701298305, 63.64830616542271, 60.52789797101702, 58.38721357073103, 60.20046411241804, 61.25695855276925, 62.027215003967285, 61.0153557913644, 61.563777106148855, 62.037797110421316, 60.94972310747419, 58.327862058367046, 60.185838154384065, 58.81536156790597, 59.83576706477574, 57.30711609976632, 62.87811919621059, 58.39523179190499, 64.46636622292655, 71.5421267918178, 71.85390635899135, 68.43797043391636, 69.44260351998466, 65.85796533312116, 66.89729077475411, 59.85777200971331, 58.88414873395647, 59.24803284236363, 71.01416792188371, 72.75283649989537, 83.80994960239956, 80.01916531154087, 96.01862934657505, 33.20269305365426, 0.6797908512609345, 0.15273888409137726, 0.36250209542257444, 0.08479867902185236, 0.04466778725119574, 0.06618744733610324, 0.328880603824343, 0.08898927737027407, 0.0776463703119329, 0.019451761851087213, 26.934309686933243, 24.68579271861485, 38.250166756766184, 46.41942092350551, 32.590449060712544, 33.65580940246582, 43.1474620955331, 62.66763046809605, 61.213018144880024, 81.5853796005249, 54.32668284007481, 1.893472922699792, 0.0923937318314399, 0.08662925793656281, 0.04876014729961753, 0.057871634273656776, 0.08903948217630386, 0.02817575613568936, 0.021058855079380528, 0.10194849555513688, 0.04156705863507731, 0.07540158648043871, 0.04300222126767039, 0.055223943133439334, 0.05437510600313544, 0.07858460782361881, 0.028096559224650264, 0.042694651521742344, 0.011199377394015235, 0.02615062426775694, 0.021940021010647928, 0.05400264456069895, 0.015646912357104675, 0.12999478381659302, 0.21604332434279577, 0.18430651804166182, 0.16068079721714768, 0.16860105150512286, 0.15621576538043364, 0.17768047430685588, 0.09165374868150268, 0.21564632707408496, 0.2714282566947596, 0.2648067862859794, 0.18606172528650078, 0.15412807597645692, 0.20409660254205975, 0.2922339859817709, 0.25937397352286745, 0.32328013862882343, 0.25323138598884853, 45.94194071633475, 121.53807040623256, 106.40579714093889, 92.28202016013009, 80.72617925916398, 60.48534720284598, 68.52492019108364, 115.3953069959368, 86.45030675615583, 108.18422331128801, 105.7481918334961, 61.64228480202811, 0.7758344433137349, 0.2326187134853431, 0.46519590062754496, 0.4891877589481217, 0.34194829261728693, 0.2428775115736893, 0.3428289496472904, 0.3933348080941609, 2.6588002783911566, 4.584661143166678, 14.535227588244847, 108.874422618321, 91.85886096954346, 104.0883436203003, 96.20546640668596, 97.43353966304234, 77.44148785727364, 77.3539127622332, 72.29730565207345, 79.88810838971818, 78.12276567731584, 82.7212085723877, 83.57728222438267, 86.54360021863664, 85.47833020346505, 90.6840317589896, 88.77142892565045, 92.77533531188965, 91.11957263946533, 89.56562192099435, 88.93330805642265, 88.70321846008301, 68.71589142935616, 66.92693178994315, 67.18133313315255, 68.29039069584438, 66.50705909729004, 70.69774695805141, 65.78612095969063, 63.39623246874128, 63.866368430001394, 62.49280684334891, 67.01085213252476, 74.65419714791435, 80.01246724809918, 83.64738954816545, 79.10087054116386, 85.51683712005615, 82.60946069444928, 85.13731956481934, 81.88270691462925, 83.28308854784284, 80.31399127415249, 81.62674222673688, 79.38127899169922, 69.1735623223441, 72.33750792912075, 82.15632697514125, 78.92196832384381, 45.70058809007917, 80.10102898733956, 76.12073952811105, 68.94808632986886, 80.90583188193185, 84.47878319876534, 80.58709021977016, 83.90619604928153, 79.79960223606655, 75.16454233442033, 71.06148515428815, 66.88725757598877, 64.54594394138881, 60.41744940621512, 63.790556635175435, 63.912914412362234, 64.76330443790981, 62.29346997397286, 65.52554266793388, 66.85940224783761, 66.2343978881836, 62.1152069909232, 62.60134465353829, 62.52564402988979, 64.0250791822161, 61.11109501974923, 67.36362607138497, 60.83536965506417, 68.29333673204694, 75.52454934801374, 78.29311466217041, 74.59970937456403, 74.44739096505302, 72.19019222259521, 71.82714884621757, 63.790375982012065, 63.58366012573242, 63.43871375492641, 77.15882124219621, 77.15185219900948, 88.27313886369977, 85.11727401188442, 105.56355735233852, 29.70970160620553, 2.0281253201620917, 0.7687271418316024, 0.9477830337626594, 0.4916362389922142, 0.16160439194313117, 0.23625308275222778, 0.6830934711865017, 0.21775931226355688, 0.11178470881921904, 0.12446603977254458, 40.363572529384065, 39.247761317661826, 62.49206338609968, 86.24010290418352, 40.584667682647705, 29.097943987165177, 46.18098654065813, 72.45903192247663, 74.47790050506592, 94.2021062033517, 71.75617994580949, 3.6856107115745544, 0.1913501186562436, 0.16580422515315668, 0.23521913109081133, 0.2628279338989939, 0.17084713812385285, 0.141034263585295, 0.10279046930372715, 0.16640305944851466, 0.12541795655020646, 0.16348922651793274, 0.1049694623798132, 0.09043389878102712, 0.16825541933732374, 0.2307332003755229, 0.12748899470482553, 0.17363397644034453, 0.1745120007544756, 0.10810486413538456, 0.17461452739579336, 0.16928221923964365, 0.1269482701484646], [0.05694280804267951, 0.11577526825879302, 0.0438056677979018, 0.07391647688512291, 0.09843899708773408, 0.058120968751609325, 0.06006677648318665, 0.10181582838829074, 0.05190207656206829, 0.12477120411183153, 0.06671318305390221, 0.07313201576471329, 0.06017429714224168, 0.044580626035375256, 0.08551549698625292, 0.01872028922662139, 0.04108667619792478, 0.7225737869739532, 49.539273262023926, 81.77867153712681, 85.47493253435407, 50.557309423174175, 61.741060393197195, 58.08787822723389, 33.559986795697895, 65.36013385227749, 100.90294197627476, 97.72334902627128, 67.31676742008754, 4.386218420096806, 0.36216475495270317, 0.14774040159370216, 0.1580406988837889, 0.11217209803206579, 0.0814033712127379, 0.2452142776123115, 0.06941488558160407, 0.2679109482892922, 0.5083951311452048, 3.326584045376096, 86.0013975415911, 84.39278534480503, 102.22189767020089, 91.57683358873639, 96.22905554090227, 81.92360401153564, 69.89625140598842, 66.5843230656215, 66.04102952139718, 64.01733888898576, 67.70879173278809, 66.67338507516044, 70.54044669015067, 70.3661858694894, 75.33853912353516, 73.18708501543317, 76.72207832336426, 77.22157737186977, 78.79142556871686, 79.50217764718192, 76.74829387664795, 64.74940804072789, 59.423898696899414, 59.92719146183559, 58.43745599474226, 61.37559904370989, 59.17616067613874, 60.04687418256487, 60.01955386570522, 57.90843405042376, 58.09944002968924, 63.54665402003697, 76.81211308070591, 79.01292719159807, 79.96678979056222, 76.35893072400773, 77.95245838165283, 73.06982721601213, 74.54734774998256, 77.33493723188127, 74.01681109837124, 75.82550362178257, 70.40606158120292, 71.27612890516008, 70.02688448769706, 57.77571650913784, 63.94080448150635, 70.89058031354631, 75.38174997057233, 38.54535402570452, 70.80124037606376, 73.30006967272077, 61.397187096732004, 65.62833431788853, 74.4259557723999, 72.49780981881278, 75.6485538482666, 75.44847352164132, 74.59309468950543, 75.45943083081926, 69.80874579293388, 66.78663376399449, 60.02083233424595, 55.100229263305664, 56.355028765542166, 58.67129067012242, 58.86867509569441, 58.76920468466622, 56.17499051775251, 55.83320862906319, 55.642730712890625, 59.42632361820766, 55.382798603602815, 52.787476199013845, 54.107984815325054, 53.09346791676113, 56.09060117176601, 55.996421813964844, 60.502460615975515, 67.49083369118827, 64.18888296399797, 66.32983139583042, 62.40651021684919, 59.59132249014718, 55.17097929545811, 55.08558593477522, 56.72157403400966, 62.485525131225586, 66.75497082301548, 73.33749961853027, 71.66472775595528, 75.589841570173, 78.2703662599836, 3.1423119562012807, 0.5141252779534885, 0.06712246859180075, 0.0837934429624251, 0.0631051477310913, 0.02533016516827047, 0.15782716391342028, 0.08873026019760541, 0.2553503694278853, 0.15535319809402737, 0.7102631532720157, 24.638736043657573, 25.212189980915614, 66.88459641592843, 41.10345145634243, 20.717414208820887, 15.792280912399292, 42.85936198915754, 57.76046173913138, 53.93184103284563, 54.177418163844514, 10.373857651438032, 0.48212513221161707, 0.06757362652570009, 0.16703986456351622, 0.06635632791689464, 0.07167946227959224, 0.047717004881373475, 0.027707399035404836, 0.03365943866914936, 0.07240911134119545, 0.09953485828425203, 0.06550108202333961, 0.11828260443040303, 0.050650148918586116, 0.06652320003403084, 0.11020442111683743, 0.1711227454777275, 0.008656357913943273, 0.04621638058285628, 0.0561628591801439, 0.00847454191119011, 0.04388856442113008, 0.0709979213508112, 0.05740894124444042, 0.050809930344777446, 0.07208946027926036, 0.08903094620576926, 0.0845999496855906, 0.08234128981296505, 0.06292300179068532, 0.07368060454194035, 0.044453913013317754, 0.01986006012053362, 0.041470537028674564, 0.04845708302621331, 0.07893023999141795, 0.07775083077805382, 0.04355270994294967, 0.044816749436514716, 0.5422208075012479, 63.56494862692696, 95.23282977512905, 96.54988166264125, 62.03935350690569, 64.08122062683105, 62.37278366088867, 36.376925468444824, 71.89119039263043, 102.34957081930978, 101.8236060823713, 79.30263233184814, 5.746898480824061, 0.40176408578242573, 0.15454960907144205, 0.17801925327096665, 0.08789130592984812, 0.23961253677095684, 0.19646422352109635, 0.0481638982226806, 0.3750647913132395, 0.4026402916227068, 5.300772019795009, 97.04426683698381, 87.97625623430524, 104.36738327571324, 94.48382786342076, 100.35991941179547, 86.01997702462333, 72.83460290091378, 70.83227103097099, 69.74668448311942, 68.17197949545724, 72.0585447038923, 69.36328288487026, 72.96548611777169, 74.52967848096574, 78.51019723074776, 75.4336599622454, 79.47683061872209, 79.79651723589215, 81.92472961970738, 81.13864517211914, 79.66313961574009, 68.38156495775495, 63.104970932006836, 62.44059113093785, 61.62136377607073, 64.37652601514543, 62.275543621608186, 63.539740562438965, 62.43542167118618, 60.52702944619315, 60.74898270198277, 66.81599685123989, 81.38735594068254, 81.5914523260934, 82.74991158076695, 79.38879694257463, 80.40818800245012, 79.48172909872872, 78.56321198599679, 79.09285231998989, 78.83270481654576, 79.31622995649064, 74.51067515781948, 72.327634538923, 71.99622631072998, 58.767022950308665, 66.11336721692766, 75.30436788286481, 78.84974179949079, 40.88946083613804, 73.35379314422607, 75.37606634412492, 64.61234092712402, 68.96586677006313, 76.59648268563407, 75.09888185773576, 77.98880440848214, 79.61643382481166, 78.56710992540631, 79.2220401763916, 73.30085481916154, 70.50495529174805, 62.85871287754604, 58.798227310180664, 59.708955492292134, 61.27610083988735, 61.279964038303916, 62.60860552106585, 59.486376898629324, 57.91077559334891, 59.38997759137835, 60.04440757206508, 57.52358027866909, 55.62362316676548, 57.19060523169381, 56.197975158691406, 58.84612124306815, 57.51046207972935, 61.57272638593401, 69.48655087607247, 68.97819287436349, 69.6345544542585, 65.20200674874442, 60.688276290893555, 57.58306728090559, 57.520265987941194, 59.47557244982038, 62.88704068320138, 71.3566654750279, 73.88205078669957, 78.57962363106864, 77.85178593226841, 86.36120305742536, 6.407805919647217, 0.6393949474607195, 0.17537190818360873, 0.08268718660942145, 0.0611817112990788, 0.2332217682685171, 0.11769495239215237, 0.30607905877488, 0.22155150877577917, 0.19811256150049822, 0.33725861140659874, 28.95025655201503, 25.919839688709803, 43.264921392713276, 23.42011407443455, 25.24713941982814, 27.246379341397965, 52.501186098371235, 68.60225364140102, 63.32428387233189, 71.5110752923148, 20.20608411516462, 0.666665432708604, 0.09646828712097236, 0.12887252760784967, 0.10803120237376009, 0.08881542312779597, 0.025690168707764575, 0.025151001389271448, 0.08589124253817967, 0.03192176816186734, 0.04114965781835573, 0.010727608958924455, 0.0629149747214147, 0.04420645807736686, 0.019278774437095438, 0.05647062570122736, 0.05396192906690495, 0.026279498423848833, 0.028314816798748713, 0.10028055469904627, 0.09668817317911557, 0.04583025344514421, 0.19951372274330684, 0.2047801994319473, 0.0705555843721543, 0.11396644317678042, 0.23562752774783544, 0.12480720717992101, 0.1295301637479237, 0.1614070739597082, 0.2121952436864376, 0.13066323580486433, 0.14614118954965047, 0.12567370996943542, 0.1535193079284259, 0.15760829565780504, 0.18465415867311613, 0.12503100159977162, 0.2305319740303925, 1.0245440176555087, 83.07204396384103, 108.51316492898124, 114.27552141462053, 77.16102382114956, 81.31857572283063, 72.7104663848877, 53.698065417153494, 76.16571521759033, 124.4739761352539, 117.57820865086147, 95.23320497785295, 8.686292205538068, 0.6992991673094886, 0.7208986740027155, 0.3643506962273802, 0.8165787884167263, 0.5976938136986324, 0.6852913818189076, 0.2084755418556077, 0.980897496853556, 2.0755936758858815, 4.5297708085605075, 100.53242233821324, 91.01072910853794, 107.69316632407052, 99.03985895429338, 103.05247143336705, 91.54282910483224, 77.3277666909354, 75.32818630763462, 74.03420938764299, 70.70648084368024, 75.44761889321464, 72.81363323756626, 75.0891752243042, 78.93741416931152, 83.12955420357841, 80.43897547040666, 84.41731943402971, 84.4273178918021, 85.77054364340646, 88.53063215528215, 83.65606784820557, 69.77415071214948, 66.03219141278947, 67.54757962908063, 64.21559183938163, 69.71490342276437, 65.25769656045097, 65.58041259220668, 65.65325055803571, 64.78131416865757, 63.66002777644566, 69.80587618691581, 83.84669167654855, 84.06387846810478, 85.62798745291573, 85.18640858786446, 84.34748308999198, 84.44256918770927, 81.52602113996232, 84.23415797097343, 81.71185071127755, 83.9432646887643, 76.77150085994175, 77.66212790352958, 76.62734658377511, 62.78097643171038, 70.01852580479213, 78.92078713008335, 83.26420334407261, 46.21676281520298, 76.1552929197039, 79.45067759922573, 66.83032403673444, 72.36188220977783, 82.14969144548688, 79.16272340502057, 82.92496449606759, 82.05602278028215, 81.58977781023297, 81.81362792423793, 75.14218303135463, 72.79721464429582, 65.55704580034528, 61.96381269182478, 62.30265549251011, 65.35615948268345, 66.11554895128522, 64.65277249472481, 62.96576377323696, 62.056334904261995, 61.555175236293245, 63.47280856541225, 61.059581075395855, 59.74913692474365, 60.685087067740305, 59.541448320661274, 63.06613745008196, 59.634130341666086, 68.48450251988002, 72.74679156712124, 73.16234942844936, 72.84387179783413, 68.50117819649833, 67.95759977613176, 61.64698873247419, 61.36911637442452, 63.01666627611433, 69.31654930114746, 74.78789438520158, 79.15326690673828, 82.79390757424491, 81.22547680991036, 92.49433626447404, 5.019256634371621, 1.105856940150261, 0.5378098956176213, 0.3585341583405222, 0.29831707956535475, 0.28673451393842697, 0.45112281292676926, 0.41059310202087673, 0.5610422832625253, 0.25677627005747383, 1.5294888253722871, 39.48056765965053, 43.05424158913748, 86.10796206338065, 54.42894990103585, 28.48973342350551, 26.015983649662562, 59.34453637259347, 80.49008641924176, 74.71084581102643, 88.84037590026855, 28.513676915849956, 0.6521480402776173, 0.1687564088829926, 0.2770950554737023, 0.19672001765242644, 0.1642836146056652, 0.12437033919351441, 0.07727282999881677, 0.12012688975249018, 0.14534568866448744, 0.12534726677196367, 0.1316422125590699, 0.1032787634591971, 0.1214267321463142, 0.15118042486054556, 0.14568802315209592, 0.15486482929970535, 0.10934542970997946, 0.1548519642757518, 0.14669733042163507, 0.1737623552658728, 0.13128613095198358], [0.047534078625696044, 0.12381490399794919, 0.16643919822360786, 0.05958243140152522, 0.12507779337465763, 0.035811996020908864, 0.037305241251098256, 0.10763894806482963, 0.08931756618299655, 0.03722637173320566, 0.06806797999888659, 0.04599781766799944, 0.11237096307533127, 0.021159946619133865, 0.07150827467973743, 0.08959607766675097, 0.1688734833151102, 4.7075135452406744, 71.86749008723667, 85.63604736328125, 75.93286023821149, 69.97742026192802, 66.20142868586949, 47.089074407305034, 63.59415190560477, 50.648466314588276, 87.88199002402169, 82.90188258034843, 14.455907821655273, 0.16534218351755822, 0.07017777607377086, 0.03425245791939752, 0.13066314080996172, 0.021695105492004325, 0.14134929382375308, 0.15496164267616613, 0.08982719347945281, 0.15138596668839455, 0.3816150426864624, 63.86048330579485, 107.45028509412492, 96.0003764288766, 97.63282094682965, 92.38324846540178, 89.96988201141357, 74.08741869245256, 68.67595318385533, 64.82508087158203, 64.217301096235, 63.2636330468314, 63.147903851100374, 63.23210906982422, 65.72047437940324, 63.217031478881836, 65.79359027317592, 66.96461881910051, 67.6120936529977, 63.805349349975586, 64.90067727225167, 63.696769850594656, 61.60784952981131, 59.2474422454834, 60.84766796657017, 60.49664497375488, 60.40180206298828, 58.86021913800921, 59.88697528839111, 59.945124762398855, 57.59905855996268, 57.48247473580496, 60.409959248134065, 73.27334690093994, 79.1805316380092, 71.99714347294399, 75.08936977386475, 76.63530227116176, 76.75637463160923, 75.26130989619664, 77.92406804221017, 71.32919229779924, 65.42619037628174, 62.449602944510325, 65.87860148293632, 63.81894697461809, 64.5281148638044, 58.410587310791016, 66.22361428397042, 71.45716421944755, 74.79738562447685, 33.529904569898335, 68.18193626403809, 76.30681923457554, 63.083264759608674, 59.869681222098215, 65.60027749197823, 69.44240897042411, 72.07207284654889, 74.03050599779401, 72.97972297668457, 71.89538710457938, 74.54976572309221, 70.93520164489746, 72.90286895206997, 62.41044289725167, 56.36807748249599, 57.81113147735596, 58.51314967019217, 58.09963805334908, 58.30573204585484, 56.11451687131609, 55.519195216042654, 55.70382274900164, 55.008165631975444, 52.383917876652305, 55.65501512799944, 54.97667292186192, 54.92837946755545, 53.720810345241, 59.058235849652974, 59.510730334690635, 67.87177562713623, 61.90683051518032, 66.13249560764858, 56.85399975095476, 53.681139605385916, 53.83142219270979, 55.91341168539864, 57.68554973602295, 67.7177757535662, 65.71622903006417, 75.26904324122837, 68.25838729313442, 87.66319125039237, 40.38610553741455, 0.1505711954087019, 0.20999345183372498, 0.07159482182136603, 0.09090267826936074, 0.027594100650666014, 0.3022312495325293, 0.10913068694727761, 0.15998262539505959, 0.1815927036638771, 0.17739869228431157, 5.594179247106824, 19.343388829912456, 56.73308719907488, 72.78991903577531, 36.27120862688337, 23.981191532952444, 18.756295578820364, 45.813850675310405, 56.76526778084891, 60.97811344691685, 44.58086156845093, 4.0313708782196045, 0.09056678307907921, 0.09417608047702483, 0.1473020679716553, 0.05889567253845079, 0.14013941160270146, 0.04146495607814618, 0.05061066835852606, 0.07271304753209863, 0.09231344756803342, 0.030023067723959684, 0.02894446167296597, 0.023197940118344765, 0.05231222723211561, 0.02835010570873107, 0.05786807196480887, 0.06520946802837507, 0.024472145762826716, 0.03138394773538623, 0.09978986531496048, 0.06556943764111825, 0.05584656347387603, 0.09578161646745034, 0.15525715824748787, 0.05725338709141527, 0.07274267237101283, 0.038980388149086914, 0.07146193752331392, 0.05840404677603926, 0.046261048543133905, 0.04984691612688558, 0.08167549089661666, 0.07367333064654044, 0.037327466665634086, 0.0392835236686681, 0.05626889384750809, 0.05796632383550916, 0.2164769625025136, 6.37639137676784, 86.67393452780587, 96.24996267046247, 90.15031978062221, 76.92333984375, 78.28511033739362, 47.91405834470476, 59.94760526929583, 64.60558032989502, 96.24024214063371, 97.43614523751395, 17.64378649847848, 0.10180101596883365, 0.09719828902078526, 0.052226877704794915, 0.13903604580887727, 0.10440893817160811, 0.10247053325708423, 0.16466073079832963, 0.1267170389848096, 0.1503453246716942, 0.7598730740802628, 75.03601455688477, 109.14556912013462, 99.80806568690709, 99.03964356013707, 93.60299777984619, 93.28699370792934, 77.85934557233537, 72.63795498439244, 69.01640101841518, 69.70595414297921, 68.09370803833008, 65.93162318638393, 67.06197002955845, 70.4168312890189, 67.50235380445207, 68.96865994589669, 69.028991154262, 71.2738151550293, 66.57866028376988, 66.04873507363456, 65.84157453264508, 64.71998241969517, 61.260377066476, 63.617338044302805, 62.80544103894915, 63.799415588378906, 60.64510713304792, 63.43217550005232, 61.98913887568882, 58.87181568145752, 59.120081765311106, 62.839619227818076, 77.56369972229004, 82.39642197745187, 74.53589017050606, 79.21424429757255, 80.07836396353585, 79.79384217943463, 78.84053543635777, 79.17541776384626, 74.25008296966553, 69.2297454561506, 65.03833498273576, 66.94451073237828, 68.01153169359479, 67.84099510737828, 62.95232595716204, 70.50664370400565, 74.13977336883545, 75.98971734728131, 36.98308283942086, 73.09581347874233, 79.53745365142822, 65.96937274932861, 63.53680147443499, 67.64159570421491, 71.09629562922886, 75.40965393611363, 76.58512238093785, 76.73845522744315, 76.32871995653424, 76.84158733912876, 73.74535192762102, 75.22356728145054, 66.215026310512, 60.1130279813494, 60.19830322265625, 62.24786894662039, 59.85570839473179, 59.83239024026053, 58.94711330958775, 57.572738783700125, 57.259958675929475, 56.494812624795095, 54.901371819632395, 58.208693504333496, 57.04233067376273, 57.6353212084089, 56.73501532418387, 61.47122015271868, 64.78974928174699, 69.45145552498954, 65.2563555581229, 67.65071174076625, 59.885606493268696, 56.31333957399641, 56.14820868628365, 59.16790621621268, 60.68475355420794, 70.26927934374127, 69.66018635886056, 76.9804470879691, 71.76299612862724, 88.38695730481828, 51.18455457687378, 0.08745797311088868, 0.22507161274552345, 0.02729383872688881, 0.12226188661796705, 0.04944174251120005, 0.49072548214878353, 0.09896613737302166, 0.21911013977868216, 0.17829059942492417, 0.18439779457237038, 4.722511666161673, 23.973282745906285, 39.163319860185894, 47.33956044060843, 26.226107597351074, 29.480650765555247, 27.703464848654612, 53.53117316109793, 66.73839936937604, 70.7261859348842, 63.584639821733745, 6.708585185664041, 0.18856679515114852, 0.1478602308779955, 0.16396717301436833, 0.052208021216626675, 0.07703061335320983, 0.04965098574757576, 0.02231097949801811, 0.12903891796512262, 0.05627556045406631, 0.045441225570227416, 0.05229302808376295, 0.06780430807599, 0.04542344116738864, 0.039434294149811776, 0.04250868542918137, 0.014376840687223842, 0.07793421165219375, 0.027114956539922526, 0.0942763543820807, 0.0339096314939005, 0.1118566267458456, 0.2085397991218737, 0.2704983651638031, 0.12415616640022822, 0.15849044546484947, 0.08228440143700157, 0.1675641278603247, 0.11201142093964986, 0.16779473477176257, 0.16676790772804193, 0.17201763817242213, 0.26242759823799133, 0.19916635352585996, 0.17780550116939203, 0.15757183118590287, 0.27382557519844597, 0.3201703583555562, 13.340448362486702, 107.79982117244175, 110.39956610543388, 103.55595179966518, 97.51956530979702, 87.02597195761544, 63.97671972002302, 91.12203924996513, 75.8657475880214, 104.88746288844517, 103.58480072021484, 26.008043595722743, 0.3880677478654044, 0.5491016954183578, 0.17540808767080307, 0.3719522426170962, 0.28514861475144115, 0.5112876445055008, 0.3544410994010312, 0.3373040732528482, 0.5867488809994289, 0.9059218743017742, 78.6378286906651, 111.85559586116246, 101.96407781328473, 105.84667560032436, 98.92774977002824, 97.6489268711635, 82.880537714277, 77.0221015385219, 71.97354739052909, 74.79322365352085, 72.36210455213273, 68.94132573263985, 71.3761899130685, 77.11298397609166, 70.70984377179826, 73.37350518362862, 74.1704010282244, 76.5478105545044, 71.96720368521554, 69.87994398389543, 68.35068716321672, 69.53598036084855, 63.9041805267334, 67.22677435193742, 66.21631172725132, 67.41995511736188, 65.23844310215541, 66.66003063746861, 65.87511348724365, 62.327370234898154, 61.92547948019845, 67.50234685625348, 80.90995216369629, 85.22464452471051, 76.91318157741001, 80.99296924046108, 84.48631504603794, 83.01066357748849, 81.56775202069963, 84.7667234965733, 79.45325538090297, 73.14388806479317, 69.65077154976981, 73.29598413194928, 72.57145377567836, 71.20588261740548, 65.71165711539132, 73.68961347852434, 77.48568534851074, 79.33820016043526, 41.800869941711426, 79.43291105542863, 83.56228801182338, 69.28349672045026, 65.14900588989258, 74.00290080479213, 74.14882687159947, 79.4563056400844, 78.86199147360665, 80.85344246455601, 78.68698024749756, 80.79800278799874, 76.89166995457241, 79.32494994572231, 70.07817608969552, 62.07336493900844, 62.49887956891741, 64.94506931304932, 62.88419886997768, 63.50152547018868, 61.50245230538504, 61.63041033063616, 61.02094909123012, 61.163505281720845, 58.345552171979634, 62.974935395377024, 61.424222537449424, 61.16139302934919, 60.331368173871724, 65.41421863010952, 68.48826149531773, 75.58502646854946, 67.7020936693464, 74.03056853158134, 62.38378265925816, 58.47578920636858, 60.10007653917585, 62.528895786830354, 64.8756012235369, 75.74236147744315, 72.4709689276559, 82.24718161991665, 74.86033630371094, 96.42620372772217, 48.689498152051655, 0.17003748299820082, 0.5867718426244599, 0.2195991463959217, 0.5093751528433391, 0.16427742636629514, 0.8426271506718227, 0.20758286118507385, 0.3140752139900412, 0.5441145173140934, 0.38969609620315687, 8.801793847765241, 34.375510760716026, 75.54848589215959, 97.33320767538888, 48.69178063528878, 34.11644370215279, 30.81632035119193, 65.97590405600411, 81.71069036211286, 86.49223913465227, 78.19275488172258, 7.6423905066081455, 0.42231721005269457, 0.24055836030415126, 0.23954500896590097, 0.13242077721016748, 0.21277822740375996, 0.17045049369335175, 0.19271049994443143, 0.23188673704862595, 0.16024605983069964, 0.1566407047212124, 0.1930652516228812, 0.24777710437774658, 0.1410721122686352, 0.08272217866033316, 0.15888820269278117, 0.11955553612538747, 0.12971549880291733, 0.12720249007855142, 0.12270718200930528, 0.08311411405780486], [0.006903196452185512, 0.024749683548829386, 0.12642487537647995, 0.028852269119982208, 0.062499439875994406, 0.09066975076815911, 0.08101671481771128, 0.059216891016278944, 0.12028000796479837, 0.07202822249382734, 0.027909587203924145, 0.03849640947633556, 0.051767906440155845, 0.015856706903183033, 0.009784582686344427, 0.06686060835740396, 0.14128750642495497, 43.063486167362754, 83.49828120640346, 72.13036128452846, 67.28833539145333, 71.81173079354423, 24.80160355567932, 33.24723448072161, 54.65014927727835, 85.84461838858468, 96.24338967459542, 43.710273129599436, 0.904777321432318, 0.08957331281687532, 0.028247791109606624, 0.19635689285184654, 0.09382178341703755, 0.08748558270079748, 0.11508175118693284, 0.09072906829948936, 0.23787535141621316, 0.5343028466616357, 38.72672632762364, 111.06985187530518, 90.73509407043457, 94.24535873958042, 90.2978161403111, 88.15769454411098, 78.72591795240129, 70.22535978044782, 65.36007826668876, 65.42974785396031, 64.13733427865165, 60.06134728022984, 61.36654554094587, 62.5493860244751, 57.87660435267857, 61.21227468763079, 59.46036284310477, 58.569040979657856, 59.19630350385393, 57.33121592657906, 56.496143204825266, 60.40557493482317, 60.82466942923409, 61.778156825474326, 59.00709015982491, 58.16902276447841, 55.96412658691406, 57.15094838823591, 58.47997202192034, 56.6081030028207, 56.305661814553396, 58.20372554234096, 64.88792732783726, 77.63870552607945, 76.20723070417131, 75.56650951930455, 78.14846706390381, 72.95966352735246, 67.51738970620292, 65.62149034227643, 60.36806855882917, 57.60879298618862, 54.81652389253889, 57.97685991014753, 56.91651269367763, 59.339234897068565, 58.852089745657786, 57.27741949898856, 65.89311626979283, 72.2151015145438, 71.15994112832206, 35.33612700871059, 69.53190871647426, 70.89332485198975, 61.79315103803362, 55.515919140407014, 62.55356189182827, 62.31218842097691, 63.133319582257954, 70.25969777788434, 71.26338590894426, 70.17142786298479, 73.14160905565534, 69.41900743756975, 70.70273576463971, 69.69099467141288, 58.49902398245675, 56.1338780266898, 55.73353672027588, 54.87250552858625, 54.47153888429914, 55.75395400183541, 52.36665160315377, 54.47857740947178, 54.17966938018799, 54.216477462223594, 51.35407672609602, 54.528736455099924, 53.35952833720616, 55.52820702961513, 53.091876779283794, 62.89749077388218, 60.00516414642334, 65.11293084280831, 57.49679149900164, 56.92611510413033, 53.7407933643886, 55.93522555487496, 53.17844091142927, 57.26684086663382, 59.43373039790562, 70.45925004141671, 65.04103088378906, 74.81979356493268, 69.15335696084159, 88.89470386505127, 12.558291384152003, 0.5422613024711609, 0.1405025635446821, 0.19704838788935117, 0.1043074836156198, 0.10192291478493384, 0.05801112071744033, 0.10824481198298079, 0.0619135248873915, 0.10970818810164928, 0.09703398855136973, 14.044647421155657, 23.78786138125828, 49.84255518232073, 56.207827704293386, 25.515438897269114, 25.148171016148158, 33.23526620864868, 52.002381869724815, 50.56947571890694, 57.18765572139195, 35.19448103223528, 1.5282493318830217, 0.0629762192921979, 0.05479359247588685, 0.010210912175742643, 0.08707423441644226, 0.048775034357926676, 0.11362045138542141, 0.0717625692486763, 0.07049157137849502, 0.08355693958167519, 0.061420440274689875, 0.07563850376754999, 0.029273965063371828, 0.07063173635729722, 0.0894175890300955, 0.018112688258822476, 0.16155903866248472, 0.06411638204008341, 0.08679032857928957, 0.1289070921816996, 0.06385412825537579, 0.0422159891708621, 0.02624144109099039, 0.04391201459137457, 0.043327215792877335, 0.06646265435431685, 0.058096086872475486, 0.04537128557318023, 0.023650984379595945, 0.03835682803764939, 0.06102007747228656, 0.028099634684622288, 0.03697050974837371, 0.011296274739184549, 0.0465948029554316, 0.03667539112003786, 0.0923256544130189, 52.91891527175903, 99.86889716557094, 81.48419993264335, 83.17934499468122, 80.38332039969308, 39.7819561958313, 47.71247720718384, 61.404663358415874, 92.21328857966832, 106.59651129586356, 50.885420731135774, 1.1441265323332377, 0.06610324792563915, 0.16310839195336613, 0.28711753338575363, 0.12584231235086918, 0.021585004703540887, 0.13943359947630338, 0.11071076430380344, 0.16694150412721293, 0.5526983652796064, 48.1250855582101, 114.60175323486328, 95.7476704461234, 99.0622807911464, 93.6392604282924, 92.86465440477643, 80.4022125516619, 73.20449720110211, 66.74044908796037, 68.9509767804827, 65.43074144635881, 65.75701495579311, 65.51912253243583, 65.138840675354, 61.36209174564907, 64.11748327527727, 61.69898905072893, 61.26697785513741, 62.1680063520159, 62.20042664664132, 59.12487602233887, 61.342775753566194, 63.707136562892366, 64.65107018607003, 61.18118149893624, 62.2397187096732, 59.397717884608674, 60.14910997663225, 59.79883738926479, 59.626556805201936, 59.79993520464216, 59.92714977264404, 67.48432322910854, 81.33872549874442, 77.23545292445591, 78.09003271375383, 79.45731312888009, 75.05651174272809, 70.92193058558873, 68.16527448381696, 64.10132871355329, 58.16680976322719, 57.01482970373971, 59.342271259852815, 61.19741249084473, 62.84765134538923, 61.72167491912842, 60.38701629638672, 68.94933700561523, 77.60671601976667, 71.395630972726, 38.19695397785732, 73.71341800689697, 74.33640044076103, 65.17062868390764, 58.308747564043315, 64.76782076699394, 65.59312779562813, 65.96598897661481, 72.78223432813371, 74.08637646266392, 74.67018495287213, 74.31383963993618, 69.69569860185895, 75.10323143005371, 73.67820453643799, 60.78274399893624, 57.6320173399789, 57.872091497693745, 57.73843247549874, 57.49169846943447, 58.5447222845895, 55.93735517774309, 56.36167819159371, 57.32287808826992, 58.119072164808, 54.85464171000889, 56.83109501429966, 56.438268184661865, 57.90146848133632, 56.2811416217259, 64.75484848022461, 62.82388850620815, 66.95047228676933, 61.07556888035366, 58.5790741784232, 55.14773062297276, 58.42555373055594, 56.78043917247227, 60.107059478759766, 61.36288384028843, 73.29100227355957, 67.05997589656285, 78.65710994175502, 71.82981695447648, 94.4048685346331, 19.324430670057023, 0.40644014200993944, 0.24521017926079886, 0.1414272574973958, 0.2842951534049851, 0.028946259790765386, 0.1263420126800026, 0.06895243003964424, 0.3242422198610646, 0.05347396060824394, 0.09638562119965043, 14.009542516299657, 30.618998459407262, 38.14758355276925, 39.943206514631, 32.091905389513286, 29.785336221967423, 43.05218839645386, 62.59538309914725, 61.74488885062081, 71.79882104056222, 48.46598849977766, 2.1105891466140747, 0.06109997497073241, 0.11783604696393013, 0.03965725736426456, 0.039424916795854054, 0.023540681726964455, 0.015226777044257947, 0.05436194581644876, 0.02105233775052641, 0.009505915139535708, 0.08329178166708776, 0.040764046367257833, 0.021768297368128384, 0.04708831165251987, 0.06803139339068107, 0.03341892175376415, 0.1036375727770584, 0.05919578857719898, 0.07499664356665951, 0.058198437094688416, 0.11867177140499864, 0.15864853055349418, 0.14601916181189672, 0.09150046083543982, 0.11257683059998921, 0.14795475080609322, 0.10588878233517919, 0.1709331085107156, 0.2185632541243519, 0.14081293903291225, 0.1365624192569937, 0.16494848392903805, 0.12123694590159825, 0.11476077698171139, 0.1432241132216794, 0.10676415357738733, 0.5352241886513573, 69.2335878099714, 112.08062022072929, 97.79274068559918, 97.36490535736084, 95.91356563568115, 41.85397154944283, 49.17453105109078, 76.02830764225551, 103.71346746172223, 117.52702822004045, 66.03243459974016, 2.250553224767957, 0.18076711653598718, 0.4113764842706067, 0.4024501389690808, 0.3165952116250992, 0.46062463734831127, 0.37504226395062035, 0.21906246590827191, 0.34689380867140635, 1.165051358086722, 48.16278648376465, 118.21163422720772, 101.39270659855434, 102.29753576006208, 97.54657295772007, 95.36688137054443, 84.36386694226945, 77.05151326315743, 70.80882780892509, 71.21415097372872, 69.49622971670968, 67.95143672398159, 70.3592724118914, 69.65189715794155, 65.63330227988106, 66.77484961918422, 64.10841587611607, 65.38768345969063, 66.12151050567627, 66.24780791146415, 61.20017787388393, 66.3960963657924, 67.41467448643276, 69.44400705610002, 65.45490033285958, 64.74182755606515, 62.98513535090855, 63.7490758895874, 63.61478110722133, 62.244047437395366, 62.39405904497419, 64.36586053030831, 71.61226190839494, 85.3563198362078, 81.75904982430595, 82.18054144723075, 85.17870998382568, 81.12300477709088, 76.49535165514264, 74.49349226270402, 69.47493348802838, 63.31112398420061, 60.444901738848, 63.60799271719796, 64.72213636125836, 66.0128823689052, 66.1220316205706, 61.99205017089844, 74.53524398803711, 81.33271530696324, 75.00657503945487, 42.58832318442208, 75.61693954467773, 76.6205165045602, 68.87177426474435, 60.86423247201102, 69.78428118569511, 70.19080638885498, 67.88588047027588, 75.13187885284424, 76.64252839769635, 76.28637068612235, 78.56316334860665, 73.6848817552839, 79.21678733825684, 77.65843146187919, 65.40725653512138, 60.53363023485456, 60.327852385384695, 62.84072399139404, 59.123340470450266, 61.81910950796944, 59.65922723497663, 60.33632223946707, 62.40054171425955, 60.74523762294224, 56.886201177324565, 60.398459979466026, 59.18446377345494, 62.36284078870501, 59.52338300432478, 70.52572345733643, 66.694014276777, 72.59641170501709, 63.5020535332816, 63.325395584106445, 60.792534010750906, 64.94587530408586, 59.020625250680105, 63.70317608969552, 64.57013756888253, 78.85424423217773, 71.11429146357945, 83.48564938136509, 77.12090492248535, 100.66973263876778, 16.779628617422922, 0.4779581129550934, 0.43463973168815884, 0.4666634904486792, 0.5121271823133741, 0.12303401875708785, 0.4690311976841518, 0.17994608916342258, 0.2886506425482886, 0.1767349493290697, 0.2063077717487301, 23.668929065976823, 40.39578437805176, 66.81455162593296, 74.44180461338588, 34.94395330974034, 34.87979016985212, 49.609109606061665, 75.98662539890834, 75.80251203264508, 89.27974523816789, 59.50103064945766, 2.452966409070151, 0.16710807090359076, 0.2000916174479893, 0.11425917675452572, 0.13477490017456667, 0.08731264448059456, 0.0955838370802147, 0.08637228315430028, 0.16481520608067513, 0.1047211524897388, 0.14771817278649124, 0.13078461214900017, 0.08529719870005335, 0.15001816222710268, 0.21510172129741736, 0.1495453861675092, 0.21107454810823711, 0.12374512345663138, 0.21896521826939924, 0.14631640086216585], [0.04386340434263859, 0.03501897857391408, 0.055042129675192494, 0.11375693870442254, 0.04492628873725023, 0.08934355407421078, 0.041554180040423355, 0.06089610233902931, 0.022939048474654555, 0.11257986365152256, 0.05469604628160596, 0.08841048021401678, 0.01997660020632403, 0.10079229223941054, 0.10442396772227117, 0.362423303936209, 7.241440798555102, 68.16098049708775, 71.04597677503313, 58.50465897151402, 41.00260877609253, 32.777508463178364, 24.971387999398367, 38.16562802450997, 79.2462546484811, 88.31572437286377, 69.23843765258789, 11.299718141555786, 0.32772068892206463, 0.17320948493267807, 0.06160728167742491, 0.12609836432550633, 0.07941785561186926, 0.26141959375568796, 0.05901459937116929, 0.34761140016572817, 0.30878722774130957, 15.160310983657837, 109.63472924913678, 91.24009609222412, 97.47012887682233, 88.54418809073312, 86.04108565194267, 76.02351338522774, 72.12691497802734, 66.31474685668945, 67.8550443649292, 62.11721502031599, 64.53229073115757, 61.804490498134065, 59.47490542275565, 62.29763194492885, 60.62256022862026, 57.96580185209002, 58.312812260219026, 59.41262871878487, 59.54268510001046, 60.50117519923619, 60.025918415614534, 59.08037975856236, 59.79469626290457, 58.86818872179304, 58.56792231968471, 55.90540736062186, 56.73757573536464, 57.539998871939524, 57.976571559906006, 56.225576877593994, 54.96353735242571, 56.27088260650635, 68.16024398803711, 74.38845634460449, 73.0630874633789, 74.67701503208706, 68.67646040235246, 63.281455176217214, 59.59452560969761, 61.309806551252095, 58.37073939187186, 58.358955247061594, 55.61403465270996, 56.47330100195748, 52.777401311056956, 57.9260824748448, 55.3630587714059, 63.40224960872105, 65.92637034824916, 74.45076778956822, 65.16361795152936, 42.15529407773699, 78.46522848946708, 65.22909777505058, 59.99199731009347, 60.61688355037144, 68.08710030147007, 68.30018070765904, 69.50020408630371, 69.19870090484619, 70.41271100725446, 68.0607179914202, 70.34224932534354, 68.08399445669991, 71.02029623304094, 66.73657894134521, 56.6311605998448, 57.56813212803432, 54.10022715159825, 52.04469639914376, 54.924196652003694, 55.6342191696167, 53.234029974256245, 52.46491650172642, 50.9572685786656, 52.0887827192034, 52.022267614092144, 51.76004259926932, 53.19337606430054, 51.38861969539097, 54.32870823996407, 57.32134601048061, 60.15423774719238, 58.47436482565743, 57.393826144082205, 54.32994154521397, 51.03795453480312, 52.33053486687796, 53.97940492630005, 55.89991133553641, 58.4133665902274, 66.83454854147774, 70.68973568507603, 74.25341115679059, 70.21890490395683, 80.5353261402675, 64.24510778699602, 0.265180089111839, 0.1863661568079676, 0.043314693429108174, 0.09137550182640553, 0.1967249980994633, 0.1319861483893224, 0.09777498950383492, 0.3150880496416773, 0.10792234500071832, 0.12252547033131123, 0.3125615380704403, 21.5545939717974, 34.71019853864397, 63.88040379115513, 35.994489669799805, 23.15785084451948, 31.57070016860962, 45.412269115448, 52.155666078839985, 55.78415434701102, 54.36408846718924, 19.771236317498342, 0.27426583585994585, 0.04109579910125051, 0.07255402606512819, 0.10975736831980092, 0.037310367583164146, 0.07023043039121799, 0.13012489969176905, 0.05591702255021248, 0.0632598672860435, 0.014279869551371251, 0.1146624708282096, 0.035694161629570384, 0.053003898688725064, 0.05383899887757642, 0.027097613184845874, 0.1067519195910011, 0.11603212090475218, 0.08343572608594384, 0.09745423242981945, 0.06956903516714062, 0.029909219725855758, 0.07996037828602962, 0.052102641335555484, 0.027257730485871434, 0.10578347370028496, 0.020616346770631414, 0.07304289019001381, 0.03962925761672003, 0.025808766450999037, 0.02793124264904431, 0.04751808216263141, 0.0598456079938582, 0.04709434722151075, 0.04892022728121706, 0.41303145832249094, 9.743591768401009, 83.90097100394112, 81.96333381107875, 70.86649785723004, 56.09573589052473, 54.42761237280709, 34.52821479524885, 25.404820101601736, 71.51556382860456, 102.06698063441685, 77.83838980538505, 13.431805883135114, 0.5314245553953307, 0.08742730332804577, 0.7093838261706489, 0.09949194772967271, 0.2632629562701498, 0.29313133497323307, 0.20512440667620727, 0.2025682566953557, 0.6437487538371767, 20.688633033207484, 115.29443304879325, 95.41105801718575, 101.90649809156145, 89.43580872671944, 88.75057043348039, 79.5169495173863, 76.91523129599435, 68.38455963134766, 72.34934071132115, 67.8680305480957, 67.07905564989362, 64.07707950047084, 65.16272858210972, 66.48327541351318, 64.21901035308838, 59.34740597861153, 62.898512159075054, 62.71612889426095, 63.63047708783831, 63.066596031188965, 62.7577486038208, 62.19500010354178, 61.53082874843052, 62.04412691933768, 60.616390228271484, 60.025758607046946, 60.42406409127371, 60.743757656642366, 59.61430018288748, 58.982021059308735, 58.202276842934744, 59.39113099234444, 72.24097660609654, 77.80240508488247, 74.44211033412388, 77.48928451538086, 71.6323630469186, 66.09415544782365, 62.17917210715157, 64.07861505235944, 62.562254088265554, 61.973498480660574, 59.14611666543143, 58.902116775512695, 55.94236135482788, 60.111964906964985, 57.55321087156023, 64.70178508758545, 70.13294179098946, 77.7389610835484, 68.14323479788644, 44.64848838533674, 80.71389484405518, 68.88157122475761, 62.4878944669451, 63.65749168395996, 74.14998722076416, 71.70235919952393, 73.31767640795026, 71.84582560403007, 73.8737268447876, 70.4759326662336, 73.71073600224086, 70.70509120396206, 74.61837223597935, 69.57122162410191, 59.02095181601388, 60.8387325831822, 56.902220249176025, 54.80811309814453, 58.472078868321006, 57.39212383542742, 57.891952923366, 56.29733787264143, 56.03244474955967, 54.30058193206787, 53.97579533713204, 54.728545801980154, 55.79019233158657, 54.19185652051653, 57.36550528662545, 59.35722378322056, 62.66741507393973, 61.07206004006522, 61.052618980407715, 56.87076922825405, 56.97636447634016, 53.93857731137957, 57.23313862936837, 57.93712663650513, 63.017381940569194, 70.02090903690883, 73.29237801688058, 74.90783418927873, 75.30090767996651, 79.64531053815568, 74.2308850969587, 1.4487936411585127, 0.3568940577762467, 0.0657032990295972, 0.0212163057377828, 0.2543292556490217, 0.1491472353892667, 0.17857185219015392, 0.39458803513220375, 0.2641204074025154, 0.25412325241736, 0.20359547728938715, 25.759397097996303, 35.9848073550633, 42.554259640829905, 23.167606115341187, 31.4312150818961, 41.87303045817784, 55.01192113331386, 65.88419478280204, 65.93300587790353, 68.69820826394218, 28.05777781350272, 0.7782234294073922, 0.050887602248362133, 0.045577377014394314, 0.04336448772145169, 0.06066372445119279, 0.0372370959791754, 0.0727592489815184, 0.03717433148995042, 0.02570743572765163, 0.016262268980166743, 0.06621710610176836, 0.04607750142791441, 0.14785493830485003, 0.019839710855324353, 0.07050210224198443, 0.06356130646807806, 0.10547735941197191, 0.05243736944560494, 0.114113753129329, 0.16796525062194892, 0.19856157526373863, 0.12372540522898946, 0.14737157709896564, 0.09399326278695039, 0.12561750012849057, 0.09876575919666461, 0.21125716902315617, 0.09864347361560379, 0.16311889567545482, 0.11918691519115653, 0.12992855879877294, 0.15534417357827934, 0.18985203547137125, 0.254089922777244, 0.5511635733502251, 14.811164004462105, 100.28307928357805, 94.3993308203561, 86.54759543282645, 65.4219102859497, 53.70560073852539, 36.823461873190745, 54.277381896972656, 105.77419199262346, 110.0984798158918, 90.41742937905448, 17.590132508959087, 0.7157737261482647, 0.3146260758595807, 0.5074428479586328, 0.3584363678736346, 0.3142880568546908, 0.44927090087107246, 0.46456052043608254, 0.6822076844317573, 1.0682367874043328, 18.298213005065918, 120.21423012869698, 99.1044007710048, 106.83288206372941, 93.6645588193621, 93.78397750854492, 81.6081349509103, 81.28029114859444, 72.12981237683977, 76.3965482711792, 71.77105603899274, 71.14075715201241, 68.56146076747349, 66.93816702706474, 71.25941153935024, 67.89863041469029, 63.75172315325056, 66.09207098824638, 67.26837321690151, 67.52637372698102, 66.21949400220598, 65.53843157632011, 65.07834271022251, 64.48855182102749, 65.25823157174247, 62.601949146815706, 62.47404670715332, 63.860469409397666, 64.07842745099748, 63.14736189161028, 61.91231264386858, 61.36925533839634, 60.91522530147007, 75.51908806392125, 81.20311055864606, 78.81195749555314, 82.78980118887765, 76.2980158669608, 70.00276034218925, 66.3077083315168, 68.82989747183663, 65.2840997150966, 64.07267434256417, 62.229254722595215, 61.956218310764854, 59.05577618735177, 63.974656105041504, 60.71439456939697, 68.22675214494977, 73.56866618565151, 80.20339679718018, 72.83756283351353, 50.74732181004116, 83.78786822727749, 71.70477022443498, 65.50539289202008, 66.4713523047311, 77.06624344417027, 75.75087996891567, 75.25336115700858, 75.76656900133405, 79.05606160845075, 73.78620038713727, 76.92539651053292, 72.27761445726667, 76.79731341770717, 73.7062474659511, 61.50244535718645, 63.593616894313264, 59.16877474103655, 57.512199129377095, 61.950423513139995, 61.2916578565325, 59.52952521187918, 58.553039278302876, 59.65159811292376, 58.8287924357823, 56.38747337886265, 58.72792543683733, 60.414649282182964, 57.498907225472585, 61.45612171718052, 64.96058464050293, 67.44885267530168, 65.59944370814732, 65.55217511313302, 60.40866688319615, 59.72014209202358, 57.496068886348176, 61.20600046430315, 63.639204025268555, 66.36193207332066, 74.68909794943673, 76.81919329507011, 82.2452917098999, 80.33429391043526, 87.54901150294712, 73.99297182900565, 1.0119127354451587, 0.6269920329962457, 0.23046121639864786, 0.13329549027340754, 0.43476914188691546, 0.3572956962244851, 0.4149122488285814, 0.5181745035307748, 0.5306914118783814, 0.2481298611632415, 0.6050395252449172, 36.9560786655971, 50.92360455649239, 87.41208335331508, 47.04786811556135, 34.04338339396885, 45.73366151537214, 66.11890493120465, 77.86698164258684, 80.03292969294957, 86.32710824693952, 34.0525689125061, 1.0210663356951304, 0.16470746829041413, 0.1274671187358243, 0.2163077358688627, 0.2010404672473669, 0.19304668690477098, 0.18972365664584295, 0.12532366732401506, 0.11272623044039522, 0.10985323853258576, 0.185315499614392, 0.10299746998186622, 0.23368998457278523, 0.15304208067911013, 0.15865793504885264, 0.20798112052891934, 0.15242924142096723, 0.08564388259713139, 0.16524769073086126], [0.04797227993341429, 0.08385898265987635, 0.07265126691865069, 0.0774573033143367, 0.06635019396032606, 0.11381356245172874, 0.06751393580010959, 0.05609825246834329, 0.03272646658920816, 0.04496556234412959, 0.0859765208193234, 0.2042703346482345, 0.07079882560563938, 0.13487844461841242, 0.10895107872784138, 0.36068432724901606, 19.051925795418875, 78.48956108093262, 73.80457837241036, 63.009801455906455, 45.81527158192226, 25.69227228845869, 25.71505716868809, 94.30054133278983, 94.94111660548619, 93.1787338256836, 43.69368430546352, 0.2990935136164938, 0.10176273980843169, 0.11322160850145987, 0.2861606090196541, 0.2715943620673248, 0.05770420575780528, 0.031104045254843574, 0.23010737395712308, 0.16055506467819214, 2.446302218096597, 86.50438458578927, 96.87137481144497, 90.59306594303676, 85.03979464939663, 80.3476344517299, 77.05819743020194, 70.65768364497593, 67.11626325334821, 68.69066252027238, 69.6225757598877, 69.36647905622209, 64.76675769260952, 62.53327315194266, 60.323634828839985, 59.79269518171038, 58.12857730048043, 59.50292750767299, 57.55114378247942, 57.26853970118931, 56.86306715011597, 60.107247080121724, 59.80383314405169, 59.28761672973633, 57.75594193594796, 57.25635950905936, 56.45067419324602, 53.29336411612374, 54.5473541532244, 56.04382242475237, 57.36199297223772, 53.41251182556152, 56.693791661943706, 67.6881069455828, 71.37106214250836, 75.5982975278582, 73.40202753884452, 71.39765289851597, 66.18983909061977, 57.804930210113525, 59.489413261413574, 63.92793641771589, 68.31509849003383, 69.57895496913365, 67.64855085100446, 64.23028033120292, 58.22772114617484, 55.63964223861694, 55.964824880872456, 63.29143973759243, 66.31353092193604, 72.87058762141636, 57.108116218021934, 48.44419200079781, 76.37250750405448, 63.45867592947823, 60.97201987675258, 66.05815683092389, 69.10252393995012, 66.8226671218872, 70.7906721660069, 70.53130980900356, 70.40535286494664, 67.54748235430036, 68.70154339926583, 68.20963178362165, 66.45969322749546, 58.09221737725394, 52.936897209712434, 56.86205618722098, 57.178682122911724, 54.186982359204976, 52.729354517800466, 53.16504825864519, 57.13466875893729, 55.1389376776559, 53.5034533228193, 47.580732413700645, 52.287713118961875, 51.341080120631624, 53.70724746159145, 51.711266245160786, 54.08988128389631, 53.72520160675049, 57.974674701690674, 55.49620015280587, 55.92195796966553, 49.490521226610454, 55.01324823924473, 49.96336351122175, 55.79455232620239, 53.6114387512207, 61.91288934435163, 65.72165557316372, 71.01243087223598, 65.0026490347726, 78.4638249533517, 67.74898706163678, 91.5257156917027, 21.14326408931187, 0.5831627420016697, 0.11655390076339245, 0.16624306089111737, 0.03345206818942513, 0.10913405926632029, 0.14716323970683984, 0.3637485099690301, 0.037596705968358686, 0.15747733839920589, 0.14734040520020894, 5.680063758577619, 22.340101718902588, 33.27769190924508, 75.87379360198975, 22.264995166233607, 19.503581285476685, 31.906732422964915, 46.91256584439959, 53.54937049320766, 52.9599825995309, 56.43813616888863, 18.90307453700474, 0.44157476669975687, 0.13262827321887016, 0.06282358283975295, 0.12108518475932734, 0.11006302120430128, 0.08392976064767156, 0.06382809965206043, 0.05365675115691764, 0.06279297412506171, 0.06246920435556343, 0.021000334826697196, 0.1111035750114492, 0.01625266601331532, 0.05359467538073659, 0.09048187120684556, 0.023648217653057406, 0.0810230319787349, 0.09707454458943435, 0.040059743981276236, 0.08486339090658085, 0.08513955465917077, 0.03152842819690704, 0.04130679974332452, 0.03091084597898381, 0.07784194446035794, 0.053168473964823146, 0.03671805061666029, 0.06505743547209672, 0.038531523663550615, 0.12588227806346758, 0.03711121076984065, 0.03809304076379963, 0.22332800844950335, 0.29187305963465143, 27.283138786043438, 95.69186251504081, 84.92289120810372, 77.32819747924805, 51.368497712271555, 33.55028363636562, 32.11306960242135, 66.3920316696167, 101.71145520891461, 103.70280197688511, 52.1369754246303, 0.1271724309772253, 0.09115988375352961, 0.2857044163559164, 0.6761156341859272, 0.7635325491428375, 0.2800405759896551, 0.3033913815660136, 0.19661028496921062, 0.1091341067637716, 4.197294294834137, 99.41035774775914, 99.78741564069475, 97.0327536719186, 88.23628561837333, 84.86522810799735, 78.4686678477696, 74.99574974605015, 69.3589472089495, 71.49820028032575, 71.37992109571184, 73.24811799185616, 66.88383906228202, 66.73844800676618, 62.99012415749686, 62.06426279885428, 60.33750343322754, 65.52731445857457, 60.92366736275809, 60.44897338322231, 59.699763025556294, 62.78572899954659, 60.73478058406285, 62.142381395612446, 60.183343751089915, 61.13470499856131, 58.52787985120501, 56.834364141736714, 57.25449044363839, 57.955681800842285, 60.45557417188372, 58.07091072627476, 60.27977779933384, 70.57773767198834, 77.67238344464982, 77.5413682120187, 76.35133634294782, 75.53014264787946, 69.29842145102364, 61.17917346954346, 62.4971147264753, 68.29008497510637, 72.90191010066441, 74.10902759007045, 71.61894607543945, 71.27849129268101, 63.46399824959891, 59.34466144016811, 56.89213841302054, 66.14692701612199, 69.60940892355782, 77.48230157579694, 58.96308721814837, 54.298448835100444, 79.4625381742205, 65.78150040762765, 65.8064444405692, 71.19892052241734, 72.65337998526437, 71.51244408743722, 72.18609973362514, 72.6239126750401, 73.60378238133022, 69.34555803026471, 72.72547449384416, 70.20698179517473, 68.76154804229736, 62.0239007132394, 55.827980109623496, 58.703113419669016, 58.559556688581196, 55.79338502883911, 55.23326294762747, 56.805244241442, 59.10099506378174, 58.03736482347761, 56.6975610596793, 51.75219808306013, 52.68131119864327, 53.3670323916844, 55.554228033338276, 56.405510902404785, 55.570921080453054, 54.46409041540963, 60.37407180241176, 57.71176528930664, 58.60955592564174, 54.719242164066856, 59.34593990870884, 53.65335028512137, 57.76362664358956, 57.10344008037022, 63.72704315185547, 68.16067477634975, 75.47746835436139, 68.82825769696916, 79.4574590410505, 70.67659664154053, 93.19835553850446, 27.404028756277903, 0.5174902688179697, 0.08507923289601292, 0.38878487795591354, 0.056905763423336406, 0.17668578268161841, 0.2174191219466073, 0.6911146779145513, 0.9616970185722623, 0.1700640544295311, 0.16369559615850449, 4.485124724251883, 28.559609719685145, 27.48760690007891, 41.46192986624581, 26.974402529852732, 32.731688567570274, 40.45158536093575, 54.818413802555625, 64.36092036111015, 66.16964067731584, 69.42141846248082, 24.648328031812394, 0.38982849195599556, 0.07334546931087971, 0.07642449159175158, 0.060554575308093, 0.11236565693148545, 0.013629221473820508, 0.03577551119295614, 0.03444613216977034, 0.052178236921983104, 0.04625651253653424, 0.09272417838552169, 0.03547418736187475, 0.07238161031688962, 0.06081640161573887, 0.07310665212571621, 0.02311465673015586, 0.044664001025791676, 0.10783458328140633, 0.11753784439393453, 0.21187124321503298, 0.17438370335314954, 0.1520159457411085, 0.12594098491328104, 0.10438011400401592, 0.16093940048345498, 0.1274350376001426, 0.19286657656942094, 0.11376014138971056, 0.1706290298274585, 0.21875827865941183, 0.12867397469069275, 0.18486491164990834, 0.45019891964537756, 0.3065774291753769, 39.306741101401194, 113.56061431339809, 100.88218075888497, 91.85385131835938, 69.37940965379987, 38.418129035404746, 37.84190797805786, 134.28391538347518, 115.62199892316545, 109.53294508797782, 65.49381719316754, 0.9313912561961583, 0.36591409519314766, 0.22778729987995966, 1.3787379946027483, 1.5073986564363753, 0.658042175429208, 0.2581891970975058, 0.6180606665355819, 0.6549632549285889, 3.6276429763862064, 95.28722722189767, 106.00710950578961, 98.45445932660783, 92.9881169455392, 89.44877406529018, 82.59385504041398, 79.6373062133789, 72.82525757380894, 76.70162282671247, 74.2797656740461, 77.42581966945103, 68.17453643253872, 69.98354857308524, 67.18334116254533, 65.56354931422642, 63.01155240195138, 68.13197871616909, 64.68447712489537, 64.42033440726144, 63.29956218174526, 65.97723811013358, 64.71461841038295, 65.02110345023019, 62.02456079210554, 63.91937623705183, 62.54073551722935, 59.63225432804653, 62.2997441973005, 61.850744656154085, 65.22519288744245, 59.53718212672642, 63.25865813664028, 75.12830053056989, 78.97341278621128, 81.62175342014858, 81.77946363176618, 79.19466427394322, 74.14283057621547, 64.07791328430176, 66.91727379390171, 71.73036738804409, 75.47174998692104, 78.72452136448452, 75.59414250510079, 72.95054054260254, 65.82556588309151, 61.272202900477815, 61.05546079363142, 69.37720012664795, 73.270067351205, 79.77587413787842, 64.49395751953125, 57.61053350993565, 83.47285079956055, 70.50025136130196, 67.73629965100969, 72.86895479474748, 73.68456213814872, 73.54739080156598, 76.749482018607, 76.43378366742814, 77.57466397966657, 73.41132422855922, 76.13174547467912, 75.1870128086635, 72.21577548980713, 66.2069594519479, 59.60291903359549, 63.22048473358154, 62.63700975690569, 60.20497349330357, 57.0538785798209, 60.30023329598563, 63.82814638955252, 61.02701486860003, 60.06627355303083, 53.16820274080549, 57.554062025887625, 56.09784814289638, 60.287302698407856, 58.81683458600725, 58.43566335950579, 58.272234780447825, 66.04780401502336, 61.9173709324428, 62.44978359767369, 59.10268347603934, 62.72127056121826, 56.92720249720982, 61.35235731942313, 58.85641152518136, 69.00715296609062, 73.07308592115129, 80.61340999603271, 71.88485363551548, 85.25828075408936, 74.33558055332729, 100.82093933650425, 24.97173193522862, 0.685058020055294, 0.30671183339187075, 0.3348428096090044, 0.17041677050292492, 0.2930593288370541, 0.30055016545312746, 1.8453601215566908, 0.6472888067364693, 0.314724436295884, 0.23394750218306268, 9.519718204225812, 38.14113562447684, 49.55316618510655, 101.95205048152378, 31.56100743157523, 30.57011788231986, 47.503006390162874, 70.40036405835832, 77.3854923248291, 79.48119408743722, 84.52421746935163, 30.75158051082066, 1.3575020198311125, 0.21886901557445526, 0.1195038046155657, 0.15221021031694754, 0.27810175716876984, 0.13301691093615123, 0.1334144374621766, 0.1297448386571237, 0.1715556372489248, 0.1325802057981491, 0.15973524509796075, 0.21377199622137205, 0.20202298595436982, 0.12139489528323923, 0.1331806414361511, 0.13925202350531304, 0.15134875582797186, 0.18007688357361726], [0.050464155684624395, 0.09954472418342318, 0.06491724335189376, 0.033292218909731934, 0.030047047151518718, 0.07503475009330682, 0.0965123986825347, 0.05687250163672226, 0.1373483392276934, 0.028596743009984493, 0.05930825575653996, 0.09115883880960089, 0.09251822265131132, 0.03204610970403467, 0.21178220584988594, 1.603328634585653, 51.43206330708095, 73.49886458260673, 58.5753846849714, 54.26514611925398, 42.98815032414028, 36.479640688214985, 55.23000076838902, 80.12850216456822, 87.18496758597237, 70.4619389942714, 12.765622156006948, 0.011425137020913618, 0.11305156084043638, 0.22395367201949867, 0.4608315091047968, 0.49086819163390566, 0.3811877556145191, 0.13513455087585108, 0.3966920093766281, 0.12531631200441293, 49.477472509656636, 103.99553653172084, 85.3225793838501, 88.55808448791504, 74.30589090074811, 77.04003483908517, 68.16616385323661, 73.45616790226528, 70.64025061471122, 70.72909028189522, 68.81138052259172, 73.51430347987584, 71.61042063576835, 71.96598080226353, 62.71660137176514, 64.90601348876953, 63.19211523873465, 64.01990277426583, 59.283899443490164, 59.438024384634836, 57.54793718882969, 60.7650260925293, 60.31631142752511, 59.39007486615862, 57.063501834869385, 56.11992604391915, 54.66421243122646, 55.68154682431902, 54.683914048331125, 56.01737410681588, 55.50765773228237, 55.8174466405596, 58.10866723741804, 70.2256863457816, 75.64212676456997, 68.08166681017194, 68.74108559744698, 71.15664073399135, 65.10566997528076, 58.94624478476388, 58.96166978563581, 65.16529941558838, 68.1740083694458, 70.44028840746198, 69.64964594159807, 72.66332980564663, 69.95970930371965, 63.45717511858259, 54.59738118307931, 65.09392057146344, 67.84400367736816, 72.66317694527763, 56.224840368543354, 61.69327763148716, 72.49293913160051, 60.33855955941336, 62.09373010907854, 68.19679846082414, 68.35141672406877, 68.51110717228481, 68.10167067391532, 68.44559955596924, 66.54773385184151, 62.672230175563264, 62.83226803370884, 58.92480264391218, 59.66595309121268, 53.17024203709194, 53.37327534811837, 53.88020549501692, 53.783330236162456, 54.228202547345845, 52.67087500435965, 54.700891971588135, 55.845979418073384, 57.89581264768328, 57.551480770111084, 52.21573672975813, 49.99858045578003, 51.53147118432181, 51.5918162890843, 52.19053561346871, 50.62383495058332, 52.977596282958984, 53.08146142959595, 52.85903222220284, 52.43509830747332, 53.72712973185948, 50.24099963051932, 52.064186096191406, 53.50697258540562, 53.31600134713309, 57.92725672040667, 67.149781363351, 68.92972224099296, 68.03368255070278, 69.04749420710972, 73.30826159885952, 77.07863208225795, 69.03931617736816, 0.34509471378156115, 0.16795136779546738, 0.05924456845968962, 0.11046531783150774, 0.022940185020810792, 0.2010034599474498, 0.30077875033020973, 0.7465868155871118, 0.21877769833164556, 0.05072951037436724, 0.03093216215659465, 16.39609500340053, 23.639753580093384, 53.58994102478027, 45.17432805470058, 17.51034460748945, 25.01980652127947, 44.80237708772932, 44.37100165230887, 62.7253908429827, 51.15101909637451, 46.69126571927752, 14.099068318094526, 0.1341970054698842, 0.08445781695523433, 0.041259295506668944, 0.04361576959490776, 0.039002613563622744, 0.06044714964394059, 0.07961385045200586, 0.04959922370367816, 0.014324471354484558, 0.05583331507763692, 0.07381715292909316, 0.02856146258168987, 0.06298208183475903, 0.15173581934400968, 0.06599242280104331, 0.1208346424890416, 0.03722533018195203, 0.05283482811812844, 0.05764308332332543, 0.03843879846057721, 0.027059506658198576, 0.03730534303135105, 0.014417318693761314, 0.04095794114151171, 0.008123910636641085, 0.06777631172112056, 0.02140157463561211, 0.06871814546840531, 0.05313021816047175, 0.06692726085228579, 0.015761859581938813, 0.254707823906626, 1.4393740551812308, 67.41411168234688, 87.45094462803432, 71.732882635934, 65.60184778485979, 53.88332176208496, 42.33477994373867, 54.08464929035732, 76.0617423738752, 94.77689593178886, 79.4927350452968, 14.203548380306788, 0.14037339761853218, 0.2647177624915327, 1.0651444047689438, 0.43005478914294926, 0.7979621759482792, 0.8141439876386097, 1.0413605038608824, 0.37421529261129244, 0.4329160356095859, 61.51284681047712, 109.31992026737758, 92.14914975847516, 94.57254941122872, 79.38365527561733, 79.5822834287371, 71.95428003583635, 75.45788833073208, 74.96345451899937, 75.79959378923688, 75.37710162571499, 80.68838800702775, 76.47331196921212, 75.18249647957938, 67.94320310865129, 66.91822569710868, 65.74172891889299, 66.80193369729179, 61.790489877973286, 61.87386131286621, 60.930490493774414, 61.979501724243164, 62.03401034218924, 60.62102467673165, 57.65713855198452, 58.585640226091655, 58.252425466264995, 58.17457784925188, 57.1534149987357, 59.009237153189524, 57.73330123083932, 58.33590112413679, 61.284028734479634, 75.08309555053711, 78.65253107888358, 72.99013832637242, 71.47248499734062, 74.27358872549874, 67.91177640642438, 62.112142835344585, 62.60369314466204, 68.13500118255615, 70.69196605682373, 72.28185980660575, 71.40535150255475, 76.10789925711495, 73.8518191746303, 69.14902823311942, 57.8931063243321, 68.48476655142647, 74.12598119463239, 73.98197977883476, 59.13355432237898, 64.89761311667306, 75.13486657823834, 65.48836980547223, 65.34480612618583, 69.94809886387416, 69.66672461373466, 70.28949165344238, 71.24685614449638, 71.95407853807721, 67.66556004115513, 63.98745468684605, 64.0087092263358, 63.912761551993235, 62.046030725751606, 56.81399897166661, 55.1341746875218, 55.2098822593689, 56.218364647456575, 56.8796386037554, 57.008920260838096, 55.86013984680176, 59.409877232142854, 62.35017422267369, 59.97216715131487, 55.138458251953125, 53.03305680411202, 54.07632187434605, 55.223247119358604, 55.181762899671284, 52.56589467184884, 56.359402656555176, 56.12768718174526, 55.63307966504778, 54.20213638033186, 55.424678870609824, 55.237619468144004, 54.78793205533709, 57.37845325469971, 56.55690172740391, 59.54932757786342, 70.28001431056431, 71.84424141475132, 73.21562821524483, 70.49619361332485, 77.7367446081979, 75.21347154889787, 75.31081581115723, 1.3327743581363132, 0.18736014275678567, 0.0417106434303735, 0.28510022163391113, 0.30571235130940166, 0.6357928493193218, 1.308234406369073, 1.5843338881220137, 0.9491421665464128, 0.11598933248647622, 0.07097793170916182, 17.679409912654332, 31.63308456965855, 40.33138152531215, 32.998867647988455, 22.99689061301095, 31.10775211879185, 55.70811326163155, 55.06044387817383, 71.40801266261509, 64.48360470363072, 57.03642470496041, 16.9060389314379, 0.5375956414001328, 0.022032540956778184, 0.029302738340837613, 0.006789324705355934, 0.13462881158505166, 0.021669953895200576, 0.08263763319700956, 0.027173463221905485, 0.08656633059893336, 0.026436145018254007, 0.08927325106092862, 0.025166051295985068, 0.007865167422486203, 0.056023898600999794, 0.07077479189527885, 0.06146394115473543, 0.08208390112434115, 0.17371352788593086, 0.17709321581891604, 0.18523702025413513, 0.0899345309340528, 0.16197935039443628, 0.160691979474255, 0.15335257830364363, 0.2030632072793586, 0.30396650784782, 0.1796688533255032, 0.08502653108111449, 0.20697235608739512, 0.24270855635404587, 0.0897201206535101, 0.3712264544197491, 2.9882994890213013, 84.91448388780866, 100.1375492640904, 86.23180675506592, 80.62827219281877, 63.81504208700997, 50.344774450574604, 76.95969976697648, 97.9741998400007, 100.29189654758999, 96.1182804107666, 19.600923810686382, 0.15869590586849622, 0.3964109873133046, 1.4957143919808524, 2.0199409936155592, 1.7745038036789214, 0.7794762764658246, 1.7699146270751953, 1.4332384701286043, 0.5987366948808942, 57.88515758514404, 112.69162396022251, 94.69622734614781, 96.9697265625, 81.69193717411586, 84.33819334847587, 74.75566169193813, 80.76272678375244, 75.82127911703927, 78.45652239663261, 77.52218423570905, 83.83528968266079, 79.1373346873692, 80.26718126024518, 70.24899060385567, 71.41302926199776, 70.24088205610002, 69.60608073643276, 64.69988822937012, 66.02013628823417, 64.5621679850987, 65.51910863603864, 66.13080024719238, 64.1875558580671, 62.22031933920724, 62.663322584969656, 61.048554284232004, 61.69820390428816, 60.68496200016567, 60.875155040196006, 61.466912269592285, 61.946428298950195, 65.29896191188267, 78.37286608559745, 84.27417264665876, 75.42004149300712, 73.94517517089844, 77.8497292654855, 72.17314829145158, 66.26979896000454, 66.59189660208565, 72.13396045139858, 75.07293728419712, 77.51134504590715, 74.16788578033447, 79.07509967258999, 77.11388724190849, 69.98925304412842, 59.45643016270229, 71.41294588361467, 77.48815890720913, 76.94734586988176, 61.72915118081229, 67.05991336277553, 78.08043725149972, 66.02285998208183, 68.39674677167619, 73.12689277103969, 72.70936162131173, 73.09916945866176, 72.93990979875836, 75.49961226327079, 71.4179972239903, 69.49104636056083, 68.32101140703473, 67.66398280007499, 66.402711050851, 59.23234380994524, 58.428680419921875, 58.08645037242344, 57.964221136910574, 60.78475897652762, 59.714562688555034, 60.07647350856236, 62.636405263628276, 64.41876411437988, 62.79372637612479, 58.53511987413679, 56.5389267376491, 57.88790559768677, 57.980344431740896, 58.64759036472866, 53.940185819353374, 59.08037975856236, 60.97101933615548, 59.71616077423096, 57.95054013388497, 60.5034750529698, 57.530712604522705, 57.98270681926182, 61.01168714250837, 57.917675154549734, 63.60809694017683, 74.02442632402692, 75.85016277858189, 75.61921160561698, 74.79803875514439, 79.950350352696, 80.9724373136248, 76.62667955671037, 1.2273004863943373, 0.20849124315593923, 0.23896928557327815, 0.24189572568450654, 0.23757478754435266, 0.8270620458892414, 1.446038571851594, 2.8641877259526933, 0.6823424686278615, 0.23180414576615604, 0.23633754679134913, 27.83145935194833, 38.871283599308555, 72.68550845554897, 60.56307670048305, 24.998895917619976, 38.186298915318076, 67.54796178000313, 67.4035643168858, 87.13178607395717, 75.75909273965019, 67.83095496041435, 22.44836160114833, 1.153010021362986, 0.12197528699679033, 0.14105000559772762, 0.12507889260138783, 0.23132238590291568, 0.09157305051173482, 0.1659600439348391, 0.15949631934719427, 0.13906364861343587, 0.1544002770845379, 0.21164271262075218, 0.13761245219835214, 0.16685895355684416, 0.2021401689520904, 0.1639590034527438, 0.21593448732580456, 0.12201808898576669], [0.03686010870816452, 0.03969402039157493, 0.12240433825978211, 0.06642111444047519, 0.033726779877075126, 0.05683843239343592, 0.04979017363595111, 0.1724006576197488, 0.04948247157569442, 0.12022295674043042, 0.06579112181706087, 0.025353455882785574, 0.008132679853588343, 0.06415643596223422, 0.2540538789970534, 12.717998334339686, 76.82009656088692, 69.9115652356829, 66.09584386008126, 43.24531010219029, 33.38472890853882, 31.70220524924142, 60.262622697012766, 93.80045863560268, 86.44774981907436, 41.71422243118286, 1.1443831814186913, 0.12697851923959597, 0.16355344307209763, 0.8764891422220639, 1.0385589684758867, 0.2986427220915045, 0.39154393704874174, 0.9748750371592385, 0.8537731468677521, 12.784658483096532, 98.12988812582833, 90.94215733664376, 89.93080534253801, 77.17477430616105, 74.8376156943185, 68.88931151798793, 74.00009373256138, 73.38303811209542, 83.38232966831752, 80.4921291896275, 84.71857942853654, 79.2971363067627, 78.01326901572091, 72.54047870635986, 74.55431679316929, 69.17987128666469, 69.27260889325822, 67.7747162410191, 67.5004222052438, 61.64765575953892, 56.590742928641184, 56.40139409473964, 56.38713986533028, 58.6226532799857, 58.436441557747976, 52.11391435350691, 53.47937086650303, 52.41579621178763, 53.76983683449881, 54.85416228430611, 54.06020900181362, 56.4191814831325, 56.45482921600342, 66.28321593148368, 72.4250065939767, 72.27054119110107, 73.62097222464425, 71.73616218566895, 67.29092012132917, 58.435795375279014, 53.94607094355992, 57.34582798821585, 61.61338724408831, 63.82859802246094, 66.74599375043596, 69.86097540174211, 69.58356162479946, 69.1476524897984, 55.329221044267925, 60.747488839285715, 67.19603552137102, 67.18395260402134, 69.69756071908134, 69.32513727460588, 69.25386960165841, 63.9891083581107, 61.538867814200266, 68.51775659833635, 67.59697437286377, 65.37465558733258, 65.72235039302281, 63.94370188031878, 60.58589458465576, 59.32147530147007, 58.86205346243722, 57.096457140786306, 53.8113557951791, 51.164297103881836, 51.07905660356794, 51.44412885393415, 51.79089954921177, 51.384353501456125, 52.079948084695, 51.06288467134748, 55.45242302758353, 56.95462008884975, 55.99935047967093, 55.907008920397075, 49.46499701908657, 49.60196338381086, 50.673288754054475, 51.318039894104004, 51.59843792234148, 54.68036699295044, 49.83439104897635, 51.785215922764365, 50.06649214880807, 51.638932023729595, 49.313599245888845, 53.70327309199742, 53.175956930433, 54.33686542510986, 55.92307662963867, 66.61376953125, 61.22303744724819, 69.72493662152971, 65.20919118608747, 76.48759746551514, 69.49988446916852, 91.64313329969133, 14.203932268278939, 0.9481971029724393, 0.05022623755836061, 0.09322816705597298, 0.2440925778022834, 0.3059123291500977, 0.34863875646676334, 1.8748712922845567, 0.3274466964815344, 0.24896956181951932, 0.27843448360051426, 3.4194864545549666, 24.253067595618113, 25.587585517338344, 77.90435600280762, 30.879802567618235, 28.5764764717647, 17.18207696505955, 37.97701917375837, 49.85745212009975, 57.36594302313668, 53.0581328528268, 41.75774942125593, 20.10838896887643, 1.2229026023830687, 0.1653971719954695, 0.079920622919287, 0.06530370297176497, 0.01865222877157586, 0.07027362593050514, 0.044950899202376604, 0.08280363000397171, 0.026079172833955715, 0.07221378825072731, 0.13521254169089453, 0.12358922325074673, 0.08416297991893121, 0.03923581926418202, 0.046789610359285555, 0.060755591307367594, 0.039159117665674, 0.06823149336768047, 0.11834603388394628, 0.01918333679038499, 0.028743466029741933, 0.03308120130428246, 0.09550564270466566, 0.10574741634939398, 0.06676844973117113, 0.06736680226666586, 0.04288503148459962, 0.03824225739975061, 0.09257578277694327, 0.16141392716339656, 0.33711497911385124, 18.353628362928117, 93.41418048313686, 82.34677709851945, 79.93090234483991, 54.04919958114624, 41.88305670874459, 33.76406928471157, 49.22462061473301, 98.77632767813546, 98.48956857408795, 47.74862173625401, 1.2777381113597324, 0.45366962626576424, 0.4685448237827846, 1.2511326989957263, 0.5960106125899723, 0.35054462562714306, 0.6409551980240005, 1.83430249776159, 0.30580924611006466, 18.40888043812343, 105.90340069362095, 92.46623774937221, 93.37474250793457, 78.24818761008126, 78.10723645346505, 73.38664422716413, 80.19896384647915, 79.94219316755022, 86.44349752153668, 84.77119813646588, 86.692124911717, 82.86663436889648, 81.67474038260323, 75.74872602735246, 79.68752779279436, 73.54348591395787, 74.72271333421979, 71.50106988634381, 70.26936272212437, 63.494674546378, 60.04624189649309, 59.74036829812186, 59.868583406720845, 61.54000037057059, 60.754895618983674, 55.35011427743094, 56.27535029820034, 55.7572682925633, 55.46035092217581, 55.69534247262137, 57.00990343093872, 58.795406341552734, 58.25936671665737, 68.63079684121269, 74.99219226837158, 74.39796842847551, 75.19146660396031, 73.679274559021, 70.85747909545898, 63.19751398903983, 57.54000582013811, 60.02834333692278, 64.51016766684396, 65.67945916312081, 70.26462405068534, 72.82761301313127, 73.65504619053432, 72.3430734361921, 60.4449781690325, 62.88006469181606, 70.672545841762, 69.7865879876273, 71.64194461277553, 72.1030409676688, 72.34310817718506, 65.33625984191895, 64.11964416503906, 72.80382238115583, 68.16112640925816, 68.88038308279855, 69.2686414718628, 66.0615406036377, 62.22928946358817, 62.07695715767996, 60.72483771187918, 59.303451674325125, 56.84279925482613, 52.72926071711949, 54.49568040030343, 54.91685240609305, 53.22992358888899, 52.84531647818429, 54.46415989739554, 54.34260811124529, 58.35947636195591, 60.17507539476667, 59.48246506282261, 59.10088389260428, 52.8280918938773, 52.440111432756694, 54.362497329711914, 53.76922191892351, 53.44714512143816, 56.30168744495937, 52.330934388296946, 55.17476258959089, 53.69603654316494, 54.95941012246268, 52.574545179094585, 55.60557174682617, 54.13965123040335, 58.24654034205845, 58.577399662562776, 69.66029753003801, 65.26900127955845, 73.3369368144444, 66.0249444416591, 79.26032475062779, 71.02618830544608, 94.62457752227783, 18.900053807667323, 0.8864564416663987, 0.19207502475806645, 0.9675528300659997, 0.6654078630464417, 1.0337702482938766, 0.8004235210163253, 1.8483085462025233, 1.676840032849993, 0.8105032944253513, 0.40434441875134197, 2.2712471314838956, 33.13363143375942, 27.977880477905273, 50.62493276596069, 29.525973864964076, 40.85199267523629, 25.254454135894775, 47.294570854731965, 62.06879997253418, 67.80633749280656, 64.2146190915789, 53.6002174104963, 24.374108689171926, 1.4505852993045534, 0.09516985607998711, 0.03046184578644378, 0.07668958843818732, 0.014219886207553958, 0.03960354792486344, 0.04541987546586564, 0.11185012638036694, 0.02288374787063471, 0.06788664830050298, 0.08573393776480641, 0.09483814745077065, 0.0691448218588318, 0.03877326872731958, 0.010865481337532401, 0.07574505412152835, 0.1397626075361456, 0.12311855064971106, 0.21547526839588368, 0.09807851857372693, 0.1827586032450199, 0.17740688898733684, 0.13308753286089214, 0.29202828130551745, 0.1940926622067179, 0.16823483258485794, 0.11165877950510808, 0.10415891158793654, 0.17622876220515796, 0.3336392513343266, 0.4416220470198563, 26.035026924950735, 110.00875772748674, 95.44834899902344, 95.42676094600132, 67.54854542868478, 49.72082969120571, 44.44057049070086, 78.49543230874198, 116.24369594029018, 104.89262539999825, 61.485408374241416, 2.3830130313123976, 0.29459219372698237, 0.6048508925097329, 3.339733728340694, 2.342563441821507, 1.5871347721133913, 1.470841252378055, 7.602978587150574, 1.1972251002277647, 15.964155026844569, 109.91022532326835, 95.02657944815499, 98.16570608956474, 82.8759935923985, 82.56401252746582, 75.99802044459751, 82.97990390232631, 80.89186600276402, 91.1083651951381, 85.94365801130022, 91.6014996937343, 84.90988418034145, 84.81819575173515, 79.28281606946672, 83.97833919525146, 76.56250599452427, 78.09368051801408, 75.04583930969238, 75.81340680803571, 66.9834623336792, 63.09246417454311, 62.13771220615932, 62.46793229239327, 64.30678694588798, 64.07020773206438, 58.71345928737095, 59.84187453133719, 58.785915102277485, 59.46865899222237, 60.301192147391184, 60.232022830418174, 61.2054237638201, 62.339849199567524, 71.52576378413609, 80.59195395878383, 76.99496882302421, 78.07851954868862, 78.67821162087577, 74.87548337663922, 65.6774719783238, 61.153701373508994, 64.35370813097272, 70.89810521262032, 68.61762305668422, 75.52739810943604, 77.3673575265067, 78.00262437547956, 76.276184626988, 63.35372338976179, 67.03665774209159, 74.95092691693986, 73.82436684199742, 67.00001294272286, 71.87822505405971, 74.47444725036621, 70.06088202340263, 68.53360543932233, 75.04068374633789, 69.76232487814767, 69.61737850734166, 73.67400782448905, 72.22028487069267, 67.62503119877407, 65.66078240530831, 63.87176718030657, 62.71242550441197, 59.92672593252999, 56.35004343305315, 57.021173409053254, 58.85135323660714, 56.2677663394383, 55.8744774545942, 58.43790762765067, 57.56900760105678, 62.69536072867257, 64.22736208779472, 62.38286549704415, 62.24982139042446, 55.75975227355957, 55.05052185058594, 56.63658019474575, 57.27878482001168, 56.71350717544556, 59.99447781699044, 55.94100645610264, 57.996808188302175, 56.29164382389614, 57.89589255196707, 55.33510964257376, 59.69586508614676, 57.542434215545654, 59.7135135105678, 60.90889549255371, 73.12937327793666, 69.57641887664795, 77.87080315181187, 70.04057243892125, 84.04752935682023, 75.25698811667306, 99.76848874773297, 17.894269057682582, 1.5999050182955605, 0.30508771911263466, 1.085642242005893, 0.5337693010057721, 0.8324602533664022, 1.0720138932977403, 5.999990088599069, 1.4904144363743919, 0.5741915319647107, 0.5686444810458592, 5.242996445723942, 41.5882967540196, 40.54188067572457, 101.93670885903495, 44.17382219859532, 40.85061693191528, 29.624155385153635, 60.915656089782715, 71.78333350590297, 80.76745850699288, 76.56343705313546, 63.84302943093436, 30.2870135307312, 2.2753876064504897, 0.2219085946146931, 0.16785755354378903, 0.16979182618004934, 0.11399091114955288, 0.19712184609047004, 0.114876942176904, 0.16757303023976938, 0.07313741011811153, 0.07809149606951646, 0.13953964092901774, 0.14273182249494962, 0.2589461979057108, 0.1026593627674239, 0.14729699252971581, 0.19361599135611737], [0.047589436905192475, 0.028684480980570828, 0.06509290249752146, 0.02812899150220411, 0.03174080287239381, 0.06661824243409292, 0.06740914963717971, 0.0438584306809519, 0.07650328307811703, 0.073934600555471, 0.010146130741174732, 0.0347692098335496, 0.060419194001172266, 0.09098350536078215, 0.44148074888757294, 39.58478716441563, 72.96761921473912, 68.05675057002476, 57.09337214061192, 33.177773339407786, 35.9191711970738, 52.94016981124878, 88.27383368355888, 76.4467351096017, 69.28524766649518, 15.558366332735334, 0.07807213746543441, 0.24837581653680119, 0.6522741392254829, 0.7837501242756844, 0.29672629492623465, 0.3914414239781243, 1.4504093144621168, 0.45645099559000557, 0.37388593171324047, 51.39750991548811, 97.91381999424526, 88.990206854684, 79.98712716783795, 71.9267999104091, 77.2543728692191, 76.87381308419364, 79.52235521589006, 82.58768504006522, 82.64179066249302, 82.26747730800084, 80.45069708142961, 79.99110153743199, 80.40057972499302, 81.84103856767926, 80.40194852011544, 78.21560750688825, 76.80240644727434, 72.73192937033517, 68.46075357709611, 62.453049251011436, 56.23659324645996, 56.504821504865376, 56.150793416159495, 56.80312156677246, 54.85407543182373, 50.4175568308149, 54.99581868307931, 54.68188170024327, 53.02150542395455, 53.63951642172677, 54.35258225032261, 54.22373832975115, 53.09523623330252, 60.7480377469744, 64.88829558236259, 70.24878910609654, 70.23190498352051, 72.77105467660087, 68.5533869607108, 63.70653206961495, 56.7451423236302, 55.139667238507954, 53.52079950060163, 58.465526717049734, 63.78886127471924, 68.35502978733608, 68.83469867706299, 67.47260161808559, 56.36071586608887, 59.598937715802876, 66.17124571119035, 62.673612867082866, 77.92122622898647, 72.70305960518974, 72.32507065364292, 61.05606528690883, 63.61405154636928, 69.01908302307129, 71.51436873844692, 66.45683056967599, 63.56910364968436, 54.37871095112392, 53.852430071149556, 53.88248103005545, 53.6281213760376, 50.91763605390276, 50.86236660821097, 49.66261420931135, 53.679656164986746, 52.72459152766636, 55.84724399021694, 52.80825826099941, 49.512689454214915, 51.37134299959455, 54.92609698431832, 56.63383565630232, 57.523524693080354, 56.61499214172363, 53.62184367861067, 49.734878948756624, 51.90694836207798, 51.95106594903128, 53.92514991760254, 50.39767803464617, 51.36665991374424, 49.07017953055245, 49.517945766448975, 50.65465368543352, 50.623577867235454, 52.81434835706438, 51.765271118709016, 54.49006972994123, 62.14995493207659, 67.78397124154228, 66.56093542916435, 68.19067709786552, 64.68417140415737, 72.69331128256661, 69.63442243848527, 82.07846546173096, 41.791093826293945, 0.046619331996355734, 0.28704636863299776, 1.7900331360953194, 0.3751379373882498, 0.713982068002224, 1.281394926565034, 1.6151955063853944, 1.0087972283363342, 0.31110841461590355, 0.24237523281148501, 0.38530488897647175, 19.40483522415161, 40.014501980372835, 63.15734645298549, 60.45676926204136, 8.584811159542628, 16.937495163508824, 38.5708122253418, 48.416169915880474, 54.15004573549543, 61.67560141427176, 63.76926735469273, 59.289972169058665, 22.553880419049943, 1.8323695957660675, 0.11699105373450688, 0.0020379231012027177, 0.04723632728148784, 0.07481921344463315, 0.07759761078549282, 0.007055668783972838, 0.14467703311571053, 0.0740923395912562, 0.18924773218376295, 0.11120973181511674, 0.06173163000494242, 0.11398044813956533, 0.026234682882204652, 0.07468436818037714, 0.04875098707686577, 0.07157677957522017, 0.06177964314286198, 0.025192734685593417, 0.03881109705460923, 0.021158996670107757, 0.08229886780359916, 0.06253215883459363, 0.017878641174840074, 0.05035998020321131, 0.06145152396389416, 0.12325640182409968, 0.02899819825376783, 0.17759275329964502, 0.3381650527673108, 51.10313905988421, 87.60495839800153, 74.32422719682965, 74.06046663011823, 41.4644763810294, 46.737485136304585, 52.69540561948504, 68.47180121285575, 84.270906993321, 77.72478675842285, 16.894313846315654, 0.25612346508673256, 0.3579735527081149, 1.4551379978656769, 0.8407654134290559, 0.7685452944466046, 0.8426323075379644, 0.6674918883613178, 0.15415456598358496, 1.4011685167040144, 60.39375604901995, 100.46968010493687, 94.61619104657854, 83.07895742143903, 74.7858168738229, 78.54370839255196, 81.6267978123256, 85.92020784105573, 84.38649722508022, 85.20008264269147, 85.52309049878801, 86.13664422716413, 83.54370158059257, 85.16254847390312, 84.78337832859584, 84.29139723096574, 83.54200622013637, 80.81516483851841, 78.19917501722063, 72.08337756565639, 63.629386220659526, 59.50583185468401, 60.97859287261963, 60.411272457667756, 57.89037915638515, 58.308386257716585, 53.56106778553554, 57.12779351643154, 55.943778787340435, 53.85744319643293, 56.42521251950945, 56.89505665642874, 55.80714593614851, 56.46804468972342, 61.57683971949986, 66.99911662510463, 71.93939699445451, 72.74344253540039, 75.96906730106899, 70.87261922018868, 67.56579085758754, 61.01181221008301, 57.19625759124756, 57.259635584695, 62.33283151899065, 69.37428188323975, 72.90042318616594, 73.03166770935059, 72.65752111162458, 60.10673986162458, 64.15758827754429, 69.18305356161935, 64.94723715100969, 80.96863664899553, 75.79951735905239, 76.59286267416817, 65.29379940032959, 64.64189856392997, 72.50262492043632, 73.86509023393903, 68.4579256602696, 64.16709341321672, 57.16776997702462, 56.20603854315621, 55.85468898500715, 55.570097718920024, 55.063494137355256, 53.32265772138323, 52.82247427531651, 55.762653146471294, 55.978766441345215, 58.95674351283482, 54.52952854973929, 51.298463344573975, 53.38576473508562, 58.01395634242466, 59.803478785923545, 61.13877664293562, 60.51204218183245, 54.18159403119768, 52.48072017942156, 53.298352922712056, 52.849937030247276, 54.71940197263445, 52.92764220918928, 54.802919319697786, 53.129661083221436, 52.76634325299944, 54.04724018914359, 52.86808225086757, 55.58480358123779, 53.81226600919451, 57.25812087740217, 65.73090362548828, 69.99235194069999, 70.69058336530412, 71.85997908455985, 68.75595474243164, 76.46492549351284, 72.7351324898856, 83.0486285345895, 49.1848977633885, 0.05946810503623315, 0.587251811155251, 1.0284848404782159, 0.9359319039753505, 1.7316843356404985, 1.6673326172998972, 1.9152175273214067, 5.036990174225398, 1.6555319705179758, 0.2927016594580242, 0.3014084851103169, 16.144509417670115, 53.6889146396092, 52.723128931862966, 43.91393872669765, 16.57019427844456, 25.587170362472534, 46.907059397016255, 58.26959793908255, 63.90775190080915, 70.33092376164028, 72.6678113937378, 70.46129976000104, 28.189119611467632, 2.0347803916249956, 0.037886318285018206, 0.04035650805703231, 0.04785073734819889, 0.01769136211701802, 0.0682087963713067, 0.010367031209170818, 0.11099138603146587, 0.07785844643201147, 0.0886103291330593, 0.09818425468568291, 0.04103587428107858, 0.08620626599128757, 0.01692054633583341, 0.06652123906782695, 0.11011402668165308, 0.1267437461231436, 0.21884548398000853, 0.0846206382183092, 0.12649275601974555, 0.09469815889107329, 0.13976422244949, 0.14188125170767307, 0.16504546015390328, 0.16494435843612465, 0.09811545123479196, 0.15822144704205648, 0.14781339839100838, 0.22742470433669432, 0.7059487562094415, 66.44945853097099, 103.40495354788644, 89.68485300881522, 82.74708366394043, 54.496844223567415, 54.66305903026036, 73.77454825810024, 115.59550544193813, 90.36331680842808, 89.18910598754883, 25.722710609436035, 0.3798583155231816, 0.8625050783157349, 1.943104556628636, 2.929591770683016, 2.3183064120156422, 1.5203783256667, 6.985423564910889, 3.326405780655997, 1.1440793062959398, 59.4312082018171, 105.83459963117326, 97.5818281173706, 87.02865396227155, 78.77216516222272, 83.06082262311662, 84.72202573503766, 87.46181855882917, 87.92424896785191, 90.38099997384208, 90.51108414786202, 92.57781192234584, 87.80312102181571, 89.84953226361955, 89.79560729435512, 87.92216450827462, 86.94877052307129, 86.77227238246373, 80.93181814466203, 76.58931909288678, 68.76426478794643, 61.593772479466026, 63.37763214111328, 63.46234457833426, 62.209702491760254, 61.434471130371094, 56.60182530539376, 62.6503016608102, 59.45866748264858, 58.37624931335449, 60.45623425074986, 59.745829582214355, 60.643925939287456, 60.83781542096819, 68.2829144341605, 71.94933986663818, 77.33344336918422, 76.06646020071847, 79.2625481741769, 74.90080956050328, 69.49049745287213, 64.26195022038051, 60.912543296813965, 60.96148640768868, 64.54178197043282, 71.52247728620256, 76.11345781598772, 76.66871615818569, 75.8866547175816, 62.21130057743618, 64.63627747126988, 74.86050306047711, 66.5906320299421, 68.56096049717495, 69.55364268166679, 77.40085479191372, 69.95792361668178, 68.28171239580426, 75.23142569405692, 75.83853149414062, 71.67084911891392, 69.58534731183732, 59.77650587899344, 60.53795896257673, 60.264019284929546, 60.04803453172956, 57.010865756443565, 55.57226208278111, 56.43612813949585, 57.347512926374165, 57.818718910217285, 60.30381161825997, 57.96075745991298, 55.30526712962559, 58.26151718412127, 61.08407347542899, 63.43062605176653, 64.01667881011963, 62.21492058890206, 59.288040569850374, 54.821630818503245, 56.10053014755249, 56.504758971078054, 57.667658124651226, 56.45483616420201, 59.01537241254534, 55.376520906175884, 55.69948707308088, 57.326890672956196, 56.77819837842669, 59.039302008492605, 57.98948131288801, 60.52525070735386, 67.39832537514823, 75.07033865792411, 74.5692971093314, 76.53008569989885, 71.64161109924316, 79.73328168051583, 75.8995783669608, 87.48979895455497, 48.694160393306184, 0.12234037954892431, 1.0116648801735468, 3.0496978972639357, 2.692004633801324, 1.9084250118051256, 5.713333036218371, 3.188279066767011, 7.981648462159293, 1.270860914673124, 0.46409716244254795, 0.45496223547628944, 28.86081760270255, 58.447732380458284, 83.03093147277832, 78.67228480747768, 15.578642913273402, 28.531231539590017, 55.14412450790405, 66.76352405548096, 75.98753561292375, 80.98777198791504, 82.63389056069511, 77.40842832837785, 34.57305152075631, 2.655219784804753, 0.17469650799674646, 0.07775060686149768, 0.1596714085234063, 0.15432877306427273, 0.1664382347038814, 0.17052961087652616, 0.27536156134946005, 0.13161980733275414, 0.14094753323921136, 0.15995777744267667, 0.11801318531589848, 0.17016286269894668, 0.13451910604323658, 0.16364246686654432], [0.08983857251171555, 0.017631567914837172, 0.05029936327732035, 0.023901818419939706, 0.0368920507441674, 0.021700077457353473, 0.11992809256272656, 0.10077035520225763, 0.09491646396262304, 0.006737753499432334, 0.0016831160797404923, 0.06006628793797322, 0.02372456980603082, 0.2281657052891595, 7.371181471007211, 67.39659527369908, 68.28156648363385, 58.72878701346261, 50.00644929068429, 61.8440465927124, 30.38742889676775, 48.4265262058803, 75.40362289973667, 64.03690501621791, 44.87536791392735, 2.296004431588309, 0.03187574991690261, 0.9258850259440286, 0.8037803151777813, 0.5220687517098018, 0.11760747565754823, 0.7662594999585832, 0.46066551229783465, 0.5512628565941537, 8.816919207572937, 79.72818865094865, 92.9702809197562, 87.07286534990583, 74.43377944401333, 77.5579605102539, 77.81217425210136, 84.72702148982457, 84.18750776563371, 80.68571295057023, 82.25713144029889, 78.03161226000104, 78.66488497597831, 79.50115626198905, 77.1359338760376, 79.22985689980644, 76.6033683504377, 77.91631385258266, 76.28352192470005, 75.45508820669991, 68.65025874546596, 62.77288178035191, 53.811807428087505, 54.909296240125386, 56.683869634355815, 57.11054808752877, 54.11829594203404, 50.667810099465505, 50.862439564296174, 52.623311110905235, 52.84395463126046, 53.68508618218558, 54.17974928447178, 52.24629143306187, 52.194503034864155, 55.103772844587056, 60.91027818407331, 66.11293642861503, 73.24752739497593, 67.73601477486747, 70.70219380514962, 65.68610858917236, 62.72881630488804, 54.355010645730154, 54.029925278254915, 62.720937047685894, 66.41475922720772, 65.39968994685582, 65.22178827013288, 63.850512640816824, 56.462760584695, 61.594133785792756, 68.34628200531006, 56.39453969682966, 74.01881217956543, 66.03572804587228, 63.22785677228655, 61.65050452096121, 60.31965351104736, 68.55208764757428, 66.6776373726981, 60.46234171731131, 58.55544335501534, 54.97805213928223, 51.74477045876639, 51.42433343614851, 51.53780794143677, 53.56437512806484, 52.30379472460066, 53.40236398151943, 59.3282150541033, 60.70472962515694, 63.662237303597585, 57.88532086781093, 51.801679679325645, 50.81322199957711, 56.68258769171578, 62.58244555337088, 59.91017532348633, 59.19367013658796, 58.58887113843645, 50.52334662846157, 51.93673528943743, 52.47582517351423, 52.5398701940264, 52.22653770446777, 50.75836597170149, 51.37728370938982, 48.783764362335205, 48.5994599206107, 51.92467669078282, 53.206810406276155, 52.510239601135254, 58.21703481674194, 71.44648483821324, 69.41241359710693, 70.0785721370152, 67.94123676845005, 73.2713736125401, 67.766343661717, 75.44340133666992, 74.2544116973877, 66.16717406681606, 3.0307010880538394, 1.17593495122024, 0.2833553824041571, 1.1710480877331324, 1.7701939663716724, 0.30160042909639223, 0.6891736877816064, 4.502374930041177, 2.395574071577617, 0.217969807397042, 0.23886956806693757, 2.75729273046766, 37.4831724848066, 33.162449087415425, 78.15850721086774, 44.987341608319966, 20.992470809391566, 24.17722453389849, 31.59719364983695, 34.18617582321167, 51.14362621307373, 56.54986320223127, 63.404938561575754, 57.518122468675884, 27.597020183290752, 0.5557879794921193, 0.08594781200268439, 0.022695423868883933, 0.06860424658017499, 0.07571412649537836, 0.07819511515221425, 0.13058246299624443, 0.022623166674748063, 0.1291827131062746, 0.0881052819479789, 0.0800009003973433, 0.16363854493413652, 0.11583621427416801, 0.06148093845695257, 0.08565996387707335, 0.02697609774103122, 0.07708356622606516, 0.030443365885210887, 0.028291643131524324, 0.024381695348503332, 0.12377240056438105, 0.05301630909421614, 0.05067588575184345, 0.07337071081357342, 0.05409402287166033, 0.13740408766482556, 0.120093845097082, 0.268152615321534, 8.863492114203316, 81.58656079428536, 79.78258609771729, 73.4305498940604, 60.52689743041992, 66.48699964795793, 37.10296705790928, 42.735597201756065, 76.8852845600673, 74.42814445495605, 54.16639832087925, 2.3382655467305864, 0.0626155168616346, 2.6368161780493597, 4.0259808131626675, 0.9218822121620178, 1.3755533312048231, 0.368951000805412, 0.4559672815459115, 0.08663465907531125, 13.648755567414419, 89.75475188664028, 96.03111525944301, 88.5432848249163, 76.98346955435616, 82.09076377323696, 85.62764004298619, 88.7378899710519, 86.74095685141427, 86.95748356410435, 86.75963360922677, 83.02674865722656, 84.60030024392265, 83.44095856802804, 83.32679271697998, 84.9443611417498, 80.27799960545131, 80.83206980569022, 79.72609724317277, 80.35588891165597, 71.63767841884068, 64.87596947806222, 56.05656542096819, 58.22378499167306, 58.89384841918945, 59.27101053510393, 55.6946302822658, 54.24265827451433, 51.88832024165562, 55.018396854400635, 53.261075837271555, 55.600926876068115, 56.062509604862754, 53.19944531576974, 54.69412095206124, 57.66807501656668, 64.49595165252686, 68.97737993512834, 74.63684054783413, 71.73060362679618, 73.16421154567173, 69.43637098584855, 64.35743236541748, 56.897168908800396, 55.134966782161165, 65.53992543901715, 71.96918392181396, 70.61910724639893, 69.31402015686035, 69.12470953805106, 60.224032402038574, 66.01571723393032, 69.3508803503854, 63.0588071005685, 81.22883973802838, 74.64292022160122, 70.77717181614467, 64.11513478415353, 65.58201067788261, 72.54537023816789, 70.75827271597726, 66.05708680834088, 62.026478494916645, 55.99217993872506, 54.17654963902065, 54.624392305101665, 57.04174355098179, 55.93594469342913, 55.99681091308594, 56.77779885700771, 61.14382798331124, 64.78038311004639, 64.78699779510498, 61.497380120413645, 53.23841428756714, 54.30394833428519, 59.34174319675991, 64.09136499677385, 62.748938288007466, 61.254478045872276, 60.19924817766462, 53.46969549996512, 53.343481472560335, 53.772977420261924, 55.23513201304844, 52.89708750588553, 53.66324799401419, 53.62303182056972, 52.34926373617989, 51.211596965789795, 54.62672689982823, 55.0972762789045, 55.83626583644322, 61.62271172659737, 73.75961657932827, 72.76765700748989, 73.19458906991142, 70.1223805291312, 75.87453705923897, 72.30120359148297, 80.24118110111782, 75.80192838396344, 71.33267334529332, 6.144842224461692, 1.540872254541942, 0.8353549923215593, 0.5872370462332452, 0.7895761345114026, 1.6198119329554694, 1.6377341598272324, 3.215532724346433, 5.036102541855403, 1.685691277895655, 0.41732121099318775, 1.5065963566303253, 37.93755687986101, 42.10387740816389, 52.37323154721941, 37.74561289378575, 32.1545364516122, 36.23309775761196, 42.14044925144741, 42.079405852726524, 61.145307949611116, 64.24154336111886, 71.63840797969273, 68.32717445918492, 32.63706452505929, 0.7703073684658323, 0.04051338874601892, 0.03914242570421525, 0.03135084201182638, 0.020890446080427085, 0.09505634395671742, 0.09536047013742582, 0.07631129837994065, 0.0425843251203852, 0.057073154619761875, 0.09613147590841566, 0.14479437896183558, 0.07138726474451167, 0.10850623795496565, 0.12490492979330675, 0.20731361848967417, 0.19593580758997373, 0.09740672140781369, 0.14543353180800164, 0.1166089978069067, 0.37314407580665176, 0.1476245756660189, 0.20352987652378424, 0.13463223140154565, 0.14836696082992212, 0.23507677444389888, 0.20646530043865952, 0.36701068920748575, 12.556117466517858, 98.6781426838466, 94.10374750409807, 86.31745025089809, 74.23998028891427, 86.93986988067627, 48.355519090379985, 66.92044217245919, 97.76462827410016, 81.01186139242989, 68.54447937011719, 3.879040743623461, 0.16093915621084826, 3.1271095148154666, 4.490627697535923, 2.439702080828803, 1.517092044864382, 1.6295112924916404, 3.6913820590291704, 1.028163486293384, 12.11742992060525, 92.2235997063773, 99.95440864562988, 92.81605175563267, 80.26967566353935, 84.14254597255162, 85.52027647835868, 92.6360308783395, 91.99007075173515, 91.69497380937848, 90.2976632799421, 87.89026532854352, 87.3565672465733, 85.08793871743339, 86.51216656821114, 88.03140408652169, 85.578432900565, 83.91684068952287, 81.56340939658028, 83.19324139186314, 75.73153618403843, 70.04376861027309, 58.609993662152974, 62.32862785884312, 62.61999361855643, 61.88304683140346, 61.27317564828055, 58.939185414995464, 56.089781284332275, 58.70597607748849, 58.34293270111084, 61.0522437776838, 59.92965112413679, 56.77715614863804, 58.80410548618862, 60.40704100472586, 67.35554531642369, 72.22345324925014, 80.40549210139683, 75.85250432150704, 77.85035460335868, 72.82711274283272, 68.65409415108817, 60.29227066040039, 58.79329408918108, 68.72366646357945, 74.34341812133789, 75.2451205934797, 71.27751854487828, 72.8072269984654, 62.62577451978411, 68.59884207589286, 74.0995432989938, 63.75612136295864, 71.84778499603271, 67.72909436907086, 67.70033577510289, 70.52730764661516, 67.98958233424595, 76.55245889936174, 72.39191232408795, 68.65846456800188, 65.28042411804199, 60.99993079049246, 60.49489402770996, 57.841262340545654, 59.7097475869315, 59.26832158224923, 57.82327345439366, 60.021547998700825, 65.89761870247978, 68.23162978036063, 68.66658006395612, 63.36909280504499, 56.28635624476841, 57.01794249670846, 64.1630356652396, 69.89244379316057, 65.18305206298828, 64.35923194885254, 63.45863424028669, 56.454363686697825, 58.340028354099815, 57.2012985093253, 58.293114117213655, 57.416286196027485, 56.32511677060808, 56.38922085080828, 53.59132024220058, 53.655747413635254, 59.05242715563093, 59.75580719539097, 57.978722027369905, 64.37808935982841, 77.49232782636369, 76.4536555153983, 76.11373574393136, 71.62814549037388, 80.5320326941354, 74.85838385990688, 83.41959285736084, 79.04852976117814, 73.711090360369, 6.3933393359184265, 2.6913753875664304, 2.7283995151519775, 4.607707015105656, 4.570661391530718, 1.5457539068801063, 3.189882580723081, 10.404901334217616, 5.372410552842276, 1.7201640052454812, 0.45814201342208044, 4.2782342944826395, 53.150866985321045, 50.62074647630964, 98.7644601549421, 59.30705778939383, 31.913864748818533, 36.469322613307405, 50.11291306359427, 53.50872700554984, 73.2225764138358, 74.82658195495605, 81.17097514016288, 77.1695978982108, 36.87781415666853, 0.9414014390536717, 0.21928942230130943, 0.08311852453542606, 0.18332239799201488, 0.10395159878368888, 0.2317096936915602, 0.21555913532418863, 0.1739271307098014, 0.22379621118307114, 0.16873333869235857, 0.22505820489355496, 0.24367381313017436, 0.17061715546463216, 0.1361081807741097], [0.0032737739176289843, 0.01931211255889918, 0.00946631922852248, 0.0678647994729025, 0.031181880006832734, 0.10193296388856002, 0.09813572586114917, 0.0375318346279008, 0.027419635726671134, 0.018695627871368612, 0.06410690969122307, 0.019826962878661494, 0.12432434808995042, 0.2493199301617486, 25.267122438975743, 72.99590533120292, 65.96422413417271, 46.157588481903076, 60.20017228807722, 37.55391556876046, 33.25527354649135, 89.27636841365269, 85.04082993098667, 64.40241500309536, 20.33453893661499, 0.06553962281239883, 0.28562141795243534, 1.5347083338669367, 2.5179296774523596, 0.5017083585262299, 0.2225391436368227, 0.9093118895377431, 0.2698154332382338, 0.10004892998508044, 35.92367710386004, 90.05651909964425, 91.21730600084577, 81.83063016619, 74.8891087940761, 80.9313109261649, 84.72337368556431, 82.85853971753801, 79.7373880658831, 81.29595238821847, 82.13803931644985, 81.28452954973493, 80.61133248465401, 80.89077513558524, 77.41949680873326, 79.32681901114327, 76.85243347712925, 77.1997322354998, 76.66925811767578, 76.8241126196725, 64.68453965868268, 57.11049945013863, 56.44551168169294, 56.033452238355366, 56.89036314828055, 54.74497134344918, 49.26546560014997, 51.77620758329119, 52.377463000161306, 53.62398372377668, 51.60178000586373, 53.04066160746983, 52.61796794618879, 52.53182765415737, 55.061503478458945, 57.484215259552, 61.26321887969971, 65.02236107417515, 65.56183310917446, 70.53896672385079, 67.20370633261544, 66.68268871307373, 67.77654361724854, 57.798840114048545, 56.51038701193673, 65.70329843248639, 66.4243824822562, 62.27046448843819, 67.29371329716274, 63.39495400020054, 57.82038300377982, 59.479560715811594, 72.82800211225236, 44.02692338398525, 51.663886478969026, 51.35827691214425, 56.70631231580462, 65.69633633749825, 63.30113247462681, 66.03712463378906, 64.63898726872036, 61.77052075522286, 53.77709422792707, 50.16330834797451, 49.94659750802176, 50.08795860835484, 51.579653467450825, 53.96286473955427, 54.46012994221279, 56.17986815316336, 61.5354562486921, 63.18940544128418, 63.928186552865164, 62.39413547515869, 56.56548622676304, 53.86006614140102, 60.14073739733015, 62.48535142626081, 62.56838934762137, 62.611211095537456, 58.49681445530483, 50.44738892146519, 51.44110638754708, 50.26303584235055, 52.47513730185372, 48.90176909310477, 51.06887401853289, 49.3806528363909, 48.90662588391985, 51.62652948924473, 51.053879805973594, 53.76864174434117, 52.30646630695888, 65.94614492143903, 72.54810088021415, 72.67091029030937, 74.41369915008545, 70.61470208849225, 69.49653543744768, 70.7879137311663, 74.18397780827114, 65.43214498247418, 68.5153455734253, 45.131996154785156, 2.345289306981223, 0.8897236149225916, 1.096338233777455, 2.647109934261867, 1.1429171115159988, 1.0452865617615836, 3.391527554818562, 0.8094594904354641, 0.9014752443347658, 0.40143491487417904, 0.8197223597339222, 12.060742173876081, 27.93155857494899, 57.15304674421038, 70.54821477617536, 27.97625286238534, 13.511455689157758, 14.142528431756155, 23.71410972731454, 32.56386872700283, 51.04102911267962, 60.02416052137102, 55.68556635720389, 67.41079044342041, 11.228565982409886, 0.06667462190879242, 0.09380697778293065, 0.07803331169166736, 0.015913420556379215, 0.05394710986209767, 0.08821971009352378, 0.08613886032253504, 0.038632618595979044, 0.03647165419533849, 0.11194164718368224, 0.22911546432546206, 0.13450611888297967, 0.1550778757248606, 0.033219388353505304, 0.030641559178807905, 0.05488192416461451, 0.0602454279682466, 0.13589094100253923, 0.07355727401695081, 0.08778641798666545, 0.05072441118370209, 0.020892578376723186, 0.051977580546268394, 0.055621540905641656, 0.05489022604056767, 0.14219358137675694, 0.21011870939816746, 32.29707874570574, 86.15985121045793, 73.86376312800816, 59.26969732557024, 64.88571085248674, 59.218412671770366, 43.32632262366158, 63.90930134909493, 93.10322080339704, 71.31574058532715, 22.919496365955897, 0.23317028103130205, 1.0863056864057268, 2.9269783794879913, 3.3872717831815993, 2.471771708556584, 0.8352868131228856, 0.7520077675580978, 0.3901420837002141, 0.8299009821244648, 44.762251240866526, 95.0059016091483, 95.12335395812988, 83.76619679587228, 79.83050087520054, 85.78446783338273, 86.1019240788051, 87.5814665385655, 86.28681564331055, 86.96314634595598, 85.81551238468715, 85.19133486066545, 82.706068447658, 83.45827347891671, 79.73617213112968, 81.80986894880022, 80.94896629878453, 81.698287827628, 80.31019755772182, 78.33157294137138, 68.60954230172294, 58.515220233372276, 58.130005155290874, 58.332176889692036, 57.88301059177944, 58.168327944619314, 53.17612716129848, 54.91397932597569, 55.0801420211792, 57.11903183800833, 54.66212102345058, 55.61023746218, 55.70416668483189, 55.97053630011422, 57.116804940359934, 60.392991747174946, 62.86222171783447, 67.35758808680943, 68.93088953835624, 74.02057702200753, 69.92002814156669, 72.21458039964948, 70.03419399261475, 61.7477445602417, 56.834468364715576, 70.29858684539795, 70.30638967241559, 67.29515852246965, 69.39377158028739, 65.49492195674351, 61.044600759233745, 64.6018977846418, 71.57638835906982, 55.279263496398926, 59.94656303950718, 60.903788566589355, 64.19569219861711, 64.56635774884904, 66.67926325116838, 68.75688580104283, 69.2610192980085, 64.54950836726597, 58.68983541216169, 52.66978413718087, 51.26527527400425, 54.75420202527727, 55.569326468876426, 56.86438383374895, 56.882737500326975, 58.312708037240164, 63.483487946646555, 64.6772232055664, 66.59877531869071, 65.36676243373326, 61.04022339412144, 59.164584977286204, 62.66670635768345, 64.77743012564522, 64.59856959751674, 64.98739079066685, 60.231126512799946, 54.84942708696638, 53.24363933290754, 51.98193679537092, 53.11759901046753, 52.86996521268572, 55.46304682322911, 53.24556745801653, 53.4019192968096, 54.23059272766113, 54.11493648801531, 55.0828344481332, 54.45372717721121, 69.03887844085693, 75.73253672463554, 74.01431669507707, 76.20172773088727, 73.87161459241594, 74.58326993669782, 71.445129939488, 74.40678569248745, 65.34808567592076, 70.05038329533168, 56.77948032106672, 6.317852803639003, 0.26859008041875704, 1.0933546338762556, 0.7536042247499738, 1.7224143530641283, 1.1235037360872542, 3.9493612902505055, 2.7079611718654633, 2.5452719245638167, 0.6080147655946868, 0.613126739859581, 8.475953732218061, 36.099244185856406, 49.58869579860142, 46.6855126108442, 26.497580664498464, 20.87119174003601, 22.345460517065867, 32.97161681311471, 42.62267507825579, 60.65980952126639, 67.9285979952131, 64.21659237997872, 78.21522535596574, 14.533900482313973, 0.08878475334495306, 0.067631403782538, 0.03766011167317629, 0.03713120719684022, 0.08822410700044461, 0.0812496423189129, 0.07356768952948706, 0.04649310073416148, 0.04810828549255218, 0.14388427351202282, 0.13314473336296423, 0.0837895210300173, 0.06293417726244245, 0.1428173721901008, 0.13667732237705163, 0.11747748191867556, 0.15390589646995068, 0.22871073175753864, 0.1837113749768053, 0.3265227217759405, 0.09399607192192759, 0.14476528338023595, 0.16174194456211158, 0.12338959824826036, 0.17309483965592726, 0.33637847006320953, 0.312182861247233, 41.82146440233503, 104.0960213797433, 86.35159369877407, 67.22319602966309, 84.37030097416469, 62.95682838984898, 50.30909892490932, 118.3350898197719, 101.38193689073834, 83.36003289903913, 32.00103684834072, 0.3214388931436198, 0.7296213230916432, 5.187692259039197, 6.814546516963413, 4.012763602393014, 1.846647275345666, 2.449900299310684, 1.520605662039348, 0.5687228111284119, 43.870053904397146, 98.88921506064278, 100.21576513562883, 88.70267650059291, 83.46738951546806, 89.13465990339006, 87.09639889853341, 93.07454558781215, 90.06528077806745, 88.48503112792969, 91.23550333295549, 86.37642656053815, 85.24837262289864, 88.11064829145158, 84.57567582811627, 86.18546227046421, 85.18013436453683, 83.75954042162213, 83.34115464346749, 83.45137391771588, 71.7183678490775, 62.168534415108816, 61.47807107652937, 60.69809409550258, 61.72347450256348, 61.43828569139753, 56.350064277648926, 59.467005320957725, 58.43082741328648, 60.867630141122, 59.082151549203054, 60.553800855364116, 59.8309519631522, 59.58687564304897, 62.708548409598215, 63.54894692557198, 67.08894293648856, 72.12550449371338, 71.50250121525356, 77.23875331878662, 73.3221857888358, 72.99710736955915, 74.51583072117397, 64.98385415758405, 63.37142045157296, 73.72252014705113, 72.51306806291852, 68.61339855194092, 72.12130083356584, 69.65082018715995, 65.26651382446289, 66.84046145847866, 79.8283886228289, 53.68540232522147, 55.33313635417393, 56.69673422404698, 62.96126134055001, 72.42795263017926, 69.03884369986397, 71.47408308301652, 69.8178687776838, 68.3721570968628, 59.687561988830566, 55.3039539200919, 55.010979652404785, 57.33376938956124, 57.898150716509136, 59.81291443961007, 60.64459991455078, 61.271577562604634, 68.97370433807373, 69.41626289912632, 68.96346269335065, 69.41138526371547, 64.3654088973999, 62.36206259046282, 66.3241686139788, 67.71175166538784, 69.42197431836809, 69.08932931082589, 62.45400810241699, 57.37060179029192, 56.15260689599173, 54.27301842825753, 56.1748480796814, 54.140957491738455, 57.461390427180696, 55.15726702553885, 56.5066488810948, 56.91344853809902, 55.528269563402446, 59.70207677568708, 58.3822386605399, 74.55134991237095, 79.60196767534528, 78.89965765816825, 80.2467257635934, 78.58869797842843, 78.72616808755058, 76.16893918173653, 79.96330179486955, 65.74329921177456, 70.23419094085693, 56.26709236417498, 4.413264283112117, 2.0304725084986006, 5.155675394194467, 8.787490112440926, 4.271937923771994, 1.9025142661162784, 8.907310060092382, 6.985971169812339, 2.4489800972597937, 0.6135184445551464, 1.0118733261312758, 18.979803494044713, 46.379625116075786, 75.27306624821254, 88.99744687761579, 38.230888979775564, 19.682151726314, 24.601714304515294, 39.19381897790091, 52.89373847416469, 70.38766275133405, 77.33919647761753, 72.47230298178536, 85.46632371629987, 17.476169892719813, 0.2546958816902978, 0.20970388022916658, 0.1477482725999185, 0.09595461575580494, 0.12916861314858707, 0.212918969137328, 0.18360651417502336, 0.18566761857696942, 0.1735751610249281, 0.25775303478751865, 0.2178530315203326, 0.20526151146207536, 0.22767995564000948], [0.08116126991808414, 0.010240001820160874, 0.060359218290873935, 0.028766593895852566, 0.040112388120698075, 0.17481948568352632, 0.09193791914731264, 0.08678403177431651, 0.1286742053925991, 0.05529721134475299, 0.03876097706545677, 0.021135275085855807, 0.06514436937868595, 0.7237767481378147, 61.42660576956612, 69.45144162859235, 63.88610826219831, 43.165826184409006, 68.99627208709717, 40.36812012536185, 37.79192958559309, 85.9400657926287, 82.09663500104631, 51.72390154429844, 4.979606739112309, 0.18140896995152744, 2.784719007355826, 2.116711812359946, 4.285172939300537, 0.3226680729006018, 0.886327899992466, 0.022325043832617145, 0.19030244701675006, 6.798778014523642, 62.50910036904471, 91.17013468061174, 85.18203817095075, 80.79153401511056, 85.80773040226528, 86.90670612880162, 79.62703677586147, 81.48361628396171, 84.41568660736084, 82.25617953709194, 78.47026593344552, 75.53723675864083, 69.69903373718262, 68.2290381022862, 69.01017543247768, 73.5170202255249, 78.33886160169328, 78.36337484632219, 74.97674642290387, 73.86705657414028, 63.35450158800398, 55.48870652062552, 55.17597852434431, 52.39625440325056, 54.97752060209002, 54.52625247410366, 50.96245193481445, 52.18466785975865, 56.34611422674996, 53.16846677235195, 52.755611760275706, 53.460937295641216, 52.996412004743306, 57.48799160548619, 55.10483939307076, 57.63595002038138, 58.013049602508545, 64.42663642338344, 68.17464760371617, 67.94651045118059, 63.93908132825579, 68.3849904196603, 68.89697538103376, 61.230159350803916, 55.269873006003245, 60.83591856275286, 66.09970011029924, 65.53845242091587, 68.82292148045131, 59.664758001055034, 60.611123493739534, 62.05853053501674, 72.51388795035226, 32.33749641690935, 27.85689323289054, 33.57830919538225, 46.105921677180696, 61.97412381853376, 60.53815351213728, 64.802047593253, 64.00797271728516, 58.51014804840088, 52.97760670525687, 52.2078401020595, 50.05199473244803, 49.994956970214844, 50.03989444460188, 53.666767256600515, 51.268561771937776, 52.95220409120832, 58.60492842538016, 60.57087952750069, 67.86484827314104, 65.07451425279889, 63.13199247632708, 62.099552699497764, 63.86180346352713, 65.14624745505196, 63.3480258669172, 62.53004223959786, 59.05860410417829, 51.01509843553816, 50.17283432824271, 51.11727516991751, 52.88770048958914, 49.84701245171683, 50.555089473724365, 50.76723187310355, 51.683025291987825, 49.73455933162144, 50.972408703395296, 52.4524062701634, 53.23824405670166, 62.5181747164045, 70.9287120274135, 65.2609691619873, 66.91737801688058, 67.31644085475376, 66.06735624585832, 65.38926764896938, 64.08559104374477, 70.11438315255302, 67.0999002456665, 74.23199680873326, 70.64020197732108, 19.23988846370152, 0.33577682663287434, 0.8780440187879971, 3.0154163539409637, 1.4544034429958888, 0.8988410085439682, 5.049269812447684, 1.2845912064824785, 1.1210744721548898, 0.08651001897773572, 0.2249534119452749, 28.20766087940761, 34.27736745561872, 68.16620554242814, 67.0409517288208, 38.61652094977242, 27.982179675783428, 16.993907587868826, 23.16138400350298, 39.56439420155117, 47.48797396251133, 56.488587038857595, 64.30378532409668, 44.73070294516427, 0.7268181049398014, 0.14112495657588753, 0.08384077756532601, 0.02055263233238033, 0.04851375087829573, 0.113410709425807, 0.013274585994492685, 0.06684406567364931, 0.028658445591905286, 0.03633857651480606, 0.16644032459173883, 0.1592891083231994, 0.1434745333556618, 0.08560208483998265, 0.02216699606339846, 0.03946945244180305, 0.019845016999170184, 0.05452969663643411, 0.17491453486893857, 0.10670163336076907, 0.10784611837672335, 0.04903812613338232, 0.03305475540193064, 0.07855850458145142, 0.062138174261365614, 0.0796173991901534, 1.0457356976611274, 74.63085120064872, 80.79438972473145, 72.24030263083321, 52.95563302721296, 79.07112530299595, 43.477042947496685, 25.636780500411987, 84.72654206412179, 91.0093811580113, 58.29514299120222, 4.7825923051152905, 0.4298783428966999, 4.396056200776782, 5.674688024180276, 4.718645862170628, 1.5231113561562128, 1.2019545435905457, 0.133666241807597, 0.031681943352201154, 10.970839057649885, 69.96956184932164, 94.4954035622733, 89.83498968396867, 83.53779561179024, 88.85345241001674, 88.90899630955288, 84.81065000806535, 86.92220061165946, 88.2820325578962, 84.22050476074219, 81.15068640027727, 78.04284054892403, 72.08591365814209, 70.03256811414445, 69.7464621407645, 78.20850644792829, 81.61550004141671, 79.44529274531773, 79.72972420283726, 75.85308797018868, 64.3458844593593, 58.20310715266636, 56.78536197117397, 55.63554974964687, 57.0243695804051, 56.19852406638009, 53.96980251584734, 53.30475916181292, 57.92789248057774, 54.00701706750052, 55.639478955950054, 57.866883822849815, 57.20424107142857, 59.90811170850481, 57.72859035219465, 60.80728503635952, 62.504681314740864, 68.97923510415214, 71.68614210401262, 71.03993879045758, 65.52281897408622, 70.87622533525739, 71.28523799351284, 63.39311967577253, 58.13283307211739, 64.38927595955985, 70.14945765904018, 68.82474885668073, 69.71274948120117, 64.4550337110247, 62.74866730826241, 66.27181393759591, 70.97304848262242, 45.51366417748587, 40.27350997924805, 44.95230879102434, 53.78065170560564, 63.19353267124721, 63.01526273999895, 65.92700958251953, 69.047744342259, 61.87799549102783, 57.25821120398385, 53.90647663388933, 52.75157138279506, 51.80442769186837, 53.32216092518398, 56.617410114833284, 54.67907115391323, 55.57614959989275, 61.19772515978132, 62.76042366027832, 70.67971638270787, 67.48254449026925, 66.08987535749162, 66.34440871647426, 65.78162547520229, 66.43179621015275, 66.05468273162842, 65.07060936519078, 61.20815440586635, 52.67203187942505, 52.29478638512747, 52.19919654301235, 53.76717914853777, 52.7372441973005, 54.28520209448678, 54.91401406696865, 56.095412799290244, 51.46615464346749, 53.97908183506557, 55.87414394106184, 54.93140888214111, 65.92171505519322, 72.53289127349854, 69.6933570589338, 70.85485962459019, 70.43393775394985, 70.23190498352051, 67.37363147735596, 65.89312321799142, 71.6822372164045, 69.30212484087262, 76.15195083618164, 80.7777487891061, 32.371695450374055, 0.9669737411396844, 1.4815209593091692, 0.4087254208113466, 1.6780810462577003, 2.3884109130927493, 3.6828362090247015, 2.0798755032675604, 2.3191549607685635, 0.1323462197823184, 0.12408209751759257, 25.530754464013235, 43.393289361681255, 51.23955651691982, 47.665250301361084, 34.59581381934029, 29.80374894823347, 22.98577175821577, 29.389632838112966, 49.29200771876744, 55.57501356942313, 64.96329443795341, 73.44152109963554, 56.06761653082711, 1.3156772298472268, 0.14333959988185338, 0.022564022169847573, 0.010756985284388065, 0.007722952419758907, 0.06882976447897297, 0.046202236520392556, 0.04148121038451791, 0.0527683249009507, 0.022937153665614978, 0.1564906399164881, 0.12973603127258165, 0.07827802534614291, 0.25784417561122347, 0.1195968860494239, 0.09206955494093043, 0.07075778780771153, 0.14944649647389138, 0.3173205384186336, 0.13659904657730035, 0.1462239165391241, 0.2021211428301675, 0.12042281244482313, 0.14847803701247486, 0.1662234647997788, 0.23188603137220654, 1.5175254387514931, 88.32132462092808, 93.91593074798584, 86.653089932033, 66.0184965133667, 86.45482308523995, 51.47132757731846, 55.35117735181536, 108.76712158748082, 92.92843886784145, 76.86509309496198, 7.493673001016889, 0.30055222819958416, 7.668434960501535, 7.71505389894758, 9.951831017221723, 3.6042373180389404, 5.686813064983912, 1.752588425363813, 0.12910521083644458, 11.05247517994472, 69.5803724016462, 101.1109640938895, 95.03509099142892, 86.28229931422642, 91.8575963973999, 94.12664876665387, 90.66022028241838, 88.71691335950578, 89.11938776288713, 89.68820204053605, 85.03025477273124, 81.2469675881522, 75.40607561383928, 74.52960205078125, 74.63440867832729, 82.10028975350517, 85.76688194274902, 82.80666446685791, 82.59034620012555, 78.48522540501186, 69.57197202954973, 61.48022501809256, 58.87189905984061, 58.330613545009065, 62.593416758946006, 61.784271240234375, 56.933115414210725, 56.2214982850211, 62.3318726675851, 58.153340680258616, 60.835974148341585, 62.077318464006694, 60.56015150887625, 62.78782040732247, 61.942071778433665, 63.69476876940046, 64.11052118028913, 72.27189608982631, 74.58448587145124, 72.03743607657296, 67.3911200932094, 71.47347164154053, 74.48161779131208, 68.35965033939907, 61.95589174543108, 68.43489238194057, 75.05821405138288, 69.68431050436837, 73.94805172511509, 67.47371332986015, 65.95220375061035, 69.23686041150773, 78.41300582885742, 42.23286376680647, 40.278266021183555, 43.263392789023264, 52.715023858206614, 70.31319890703473, 66.27523245130266, 68.66080611092704, 70.43224934169224, 63.82615920475551, 58.557555607386995, 58.04015105111258, 55.573742049080984, 56.09469713483538, 55.151774474552695, 62.294553892953054, 57.67366484233311, 59.06494780949184, 65.73444025857108, 68.255948475429, 75.2663334437779, 72.06680611201695, 69.94297804151262, 68.2621601649693, 69.20020171574184, 72.32502201625279, 68.23884201049805, 69.38141073499406, 66.40367685045514, 56.203419072287424, 55.73752498626709, 55.57176181248256, 59.76122679029192, 55.59560803004673, 57.01505899429321, 57.54803793770926, 59.04919624328613, 56.08447980880737, 56.02691398348127, 59.536973680768696, 57.56817381722586, 68.61191858564104, 75.79271507263184, 73.5590568270002, 73.03963034493583, 72.04772635868618, 72.85158429827008, 70.30293641771588, 67.6828054700579, 73.76475129808698, 71.75542954036167, 78.1176518031529, 78.57683740343366, 25.349835532052175, 0.6761835962533951, 3.2076276285307745, 7.923246247427804, 6.323047884872981, 5.364153053079333, 16.38016278403146, 5.497197159699031, 3.2006045196737563, 0.2282929713172572, 0.6018485650420189, 42.595900194985525, 54.018307890210835, 86.43400628226144, 84.52144513811383, 53.56779364177159, 40.40213850566319, 26.680457251412527, 35.29747417994908, 58.215106691632954, 66.18191119602749, 72.39589364188058, 83.50485420227051, 64.01115499223981, 1.5171032271214893, 0.22534020404730523, 0.22138528126691068, 0.12340414603906018, 0.12015719312642302, 0.12013078454349722, 0.18473651925367968, 0.12970656928207192, 0.07558635835136686, 0.09290754568896123, 0.24227565101214818, 0.1658406082008566, 0.15026708958404406], [0.03387967756550227, 0.08273177314549685, 0.05235214883993779, 0.04534672599818025, 0.07862496708652802, 0.08735942947013037, 0.10798269390527691, 0.05712039422776018, 0.09047540476811783, 0.03699851628126843, 0.14783941342362336, 0.10421260406396218, 0.33664448293192045, 5.767167244638715, 73.49799605778286, 71.13080038343156, 63.97976303100586, 35.79208517074585, 37.93792166028704, 83.00709915161133, 80.68733882904053, 80.95750563485282, 73.26698929922921, 28.136514799935476, 0.09318866274718728, 0.32131075859069824, 2.9526458936078206, 2.1434678052152907, 1.8149030187300272, 1.7538818759577615, 0.6076136156916618, 0.31595513597130775, 0.27985845719064983, 24.596593482153757, 81.51038769313267, 88.8037519454956, 81.49849932534354, 83.41361740657261, 85.12998921530587, 79.78822803497314, 80.66227667672294, 86.6536249433245, 80.5887508392334, 74.24667835235596, 65.9681568145752, 62.145209312438965, 61.34069129398891, 59.78155721936907, 61.11153275626046, 69.95604760306222, 73.70121002197266, 75.10206413269043, 73.70049435751778, 70.77832521711076, 57.602219990321565, 54.16853836604527, 55.620847361428396, 55.195381368909565, 53.752202306474956, 50.689332144601, 50.325427191598074, 53.13323940549578, 54.240705830710276, 55.32705668040684, 55.18147802352905, 53.18644871030535, 56.63653155735561, 57.07775259017944, 58.06316001074654, 58.87510912758963, 64.53325653076172, 67.0906035559518, 68.04799583980015, 67.9389647075108, 66.83698041098458, 65.89001737322126, 68.62946278708321, 65.29076998574394, 56.54644468852452, 53.94830478940691, 63.066707202366416, 65.94188567570278, 71.68359906332833, 58.0847932270595, 63.1164493560791, 58.250813484191895, 68.05052498408726, 30.961054801940918, 13.236593638147626, 24.041748557771953, 38.30466495241438, 58.24018274034773, 58.99229744502476, 66.0449344090053, 62.0527982711792, 58.82351875305176, 57.888794967106406, 58.5195072719029, 53.72730343682425, 52.92069748469761, 48.14869553702218, 50.99101945332119, 51.715344837733674, 54.45887231826782, 52.106820242745535, 58.226050104413716, 63.15314279283796, 63.77727862766811, 66.77425207410539, 64.55979864937919, 62.15486036028181, 64.06825528826032, 63.978651319231304, 60.60245909009661, 56.014334269932334, 49.696010725838796, 46.57351112365723, 48.9613881111145, 49.175170285361155, 49.21365635735648, 51.76540660858154, 52.113396712711875, 56.04219307218279, 49.430700710841585, 49.77503258841378, 51.87867266791207, 50.94900369644165, 59.639299801417756, 65.99526173727853, 63.20357281821114, 71.2767333984375, 70.56570339202881, 70.40240682874406, 63.984279360089985, 69.0113913672311, 70.58032240186418, 69.78706741333008, 68.78075981140137, 69.27890396118164, 83.45202010018485, 42.53869915008545, 0.39949091204575127, 0.6173457620399339, 1.9735211644853865, 2.2140693196228574, 3.4346730453627448, 2.847361360277448, 1.6620079087359565, 0.06306481560958282, 0.32142230974776403, 5.194370780672346, 32.09029688153948, 49.70330286026001, 92.73438262939453, 65.72086347852434, 38.44380610329764, 17.822827679770334, 19.838578258241924, 24.091052974973405, 30.996928351266043, 60.42141682761056, 56.67531640189034, 65.23625441959926, 7.429399558476039, 0.06704208254814148, 0.2830238773354462, 0.06299061101994344, 0.01015624515379646, 0.13346201633768423, 0.09076351073703595, 0.031353987021637816, 0.05997167301497289, 0.019597297434562018, 0.09777102685932602, 0.12498374842107296, 0.11378610213952405, 0.0538056726301355, 0.03417479958651321, 0.039051613969994445, 0.010678402447540845, 0.07459682359227113, 0.06034971880061286, 0.05382648669183254, 0.09363880287855864, 0.10186438435422522, 0.06013872833656413, 0.15136267936655454, 0.13516861333378724, 0.5675519311002323, 7.108588635921478, 90.12739767347063, 76.30814634050641, 75.55883870806012, 40.16567393711635, 56.905100277491975, 71.40681757245744, 62.93949958256313, 91.84517301831926, 78.36434064592633, 31.958336693899973, 0.04858998428764088, 0.3088267999035971, 3.489902973175049, 3.7803889172417775, 4.2837641920362195, 1.1268220437424523, 1.0984939123903001, 0.21606463034238133, 0.4265441032392638, 31.652796609061106, 85.6842817578997, 90.48998246874127, 84.13921083722795, 86.87164551871163, 87.66936125074113, 85.1078383581979, 85.4463893345424, 86.30788258143834, 81.02187374659947, 76.34402683803013, 68.11046014513288, 65.73261983054024, 64.333829334804, 62.60074710845947, 63.0730231148856, 71.7462648664202, 76.01481424059186, 78.22318799155099, 76.6087532043457, 72.77465384347099, 58.7914389201573, 57.955664430345806, 59.423488753182546, 57.76126773016793, 56.062151772635325, 53.13648074013846, 52.971113613673616, 55.58898639678955, 57.03158528464181, 58.15958016259329, 56.481093406677246, 58.039949553353445, 60.75948143005371, 57.612475531441824, 60.5415928704398, 62.19176919119698, 67.03097411564418, 69.59695080348423, 71.81499644688198, 69.47648988451276, 65.87934494018555, 67.7939419065203, 73.17272308894566, 67.08403750828334, 58.79617064339774, 58.36893286023821, 65.42409202030727, 69.58886310032436, 71.74947493416923, 63.91879258837019, 66.13467039380754, 63.53683621542794, 69.9621342250279, 41.16114582334246, 21.38702426637922, 32.368516649518696, 46.42297492708479, 61.36799076625279, 61.56449971880232, 67.79510225568498, 65.99579674857003, 63.43742833818708, 62.11288629259382, 62.16517843518938, 59.44610513959612, 55.906897749219624, 52.619256837027415, 53.682494504111155, 52.97302089418684, 55.33845520019531, 53.47955846786499, 59.77594307490757, 65.88450050354004, 67.39667865208217, 66.54792840140206, 65.79013007027763, 63.477262360709055, 65.40977873120988, 67.0852187020438, 62.7926424571446, 59.434258460998535, 52.320178576878135, 50.1211953163147, 51.484466620853965, 52.840084484645296, 50.240680013384136, 53.37548834936959, 57.5704528263637, 59.04238700866699, 52.993358271462576, 54.18398421151297, 54.234410762786865, 53.51311131886074, 61.50525937761579, 67.02774320329938, 68.99822453090123, 74.63390840802873, 72.9789378302438, 72.12754031590053, 66.70842484065464, 70.20169421604702, 71.87902409689767, 72.37336758204869, 73.94899668012346, 71.36879702976772, 82.60181072780064, 58.77832072121756, 1.463166858468737, 0.7619579136371613, 0.4655909708568028, 1.671930804848671, 3.663752547332219, 2.9028249212673733, 2.6323777990681783, 0.6018903627991676, 0.234007294688906, 4.057729738099234, 41.18381779534476, 50.92257274900164, 76.62961169651577, 54.93951742989676, 35.161511829921174, 26.204040118626185, 29.141729797635758, 35.00616747992379, 38.449566159929546, 67.37980842590332, 62.218047278267996, 78.60804871150425, 10.413843665804182, 0.18748237405504498, 0.2838923750179154, 0.11099080927670002, 0.03379140694492629, 0.13525803067854472, 0.045831973531416485, 0.02893284515344671, 0.017480259694691216, 0.028077969061476842, 0.1671718124832426, 0.10269749643547194, 0.03566333917634828, 0.17529052469347203, 0.17847541879330361, 0.15850310692829744, 0.17448826559952327, 0.17365244616355213, 0.16025247877197607, 0.17137286705630167, 0.11111340698386941, 0.2633318140038422, 0.17978877760469913, 0.27666282866682324, 0.2401286576475416, 0.7439788526722363, 8.76083595412118, 106.74040848868233, 86.99425343104771, 87.22842856815883, 54.932447637830464, 54.13586793627058, 87.32375090462821, 112.54474599020821, 99.54898820604596, 92.66768687111991, 41.586754253932405, 0.20403530368847506, 0.5950657118644033, 7.9858086960656305, 7.413402199745178, 6.397656338555472, 4.3942118883132935, 4.463729049478259, 1.0502362847328186, 1.014376414673669, 30.71487317766462, 91.11042186192104, 94.94189480372837, 90.06722627367292, 91.98358113425118, 94.70607294355119, 87.36097935267857, 87.44318349020821, 88.82294287000383, 87.20095539093018, 79.83125128064836, 73.40671757289341, 66.25596509660993, 68.39085469927106, 64.94794586726597, 67.30438573019845, 74.5727573122297, 80.89841120583671, 80.94011429377964, 80.62034429822648, 74.99545792170933, 63.90368720463344, 59.88648196629116, 63.25746304648263, 59.887697901044575, 61.1586971282959, 56.35225643430437, 56.911044461386545, 58.643428393772666, 61.27167483738491, 62.47332409449986, 61.793574878147666, 61.183946881975444, 66.69725908551897, 62.87676429748535, 66.32409218379429, 66.11815452575684, 71.89780507768903, 76.19031184060233, 74.29832431248256, 70.94343526022774, 69.20182064601353, 69.93541840144566, 77.35690743582589, 71.85127993992397, 62.637322425842285, 60.56423010144915, 70.18562998090471, 70.35970320020402, 75.88362530299595, 64.55708190373012, 70.34987149919782, 64.55922194889614, 76.29952362605503, 38.70184135437012, 19.418820210865565, 32.034871101379395, 47.90776327678135, 69.42394760676792, 65.09469182150704, 71.75853538513184, 68.42581108638218, 65.3334527696882, 66.2383097239903, 63.713987486703054, 61.60957963126046, 57.6894268308367, 55.157444204602925, 57.6518440246582, 56.412174224853516, 60.23168236868722, 58.38263470785958, 64.94834886278424, 68.81772422790527, 72.03030027662004, 72.40792097364152, 71.32179941449846, 66.58444813319615, 69.40531948634556, 70.27096775599888, 65.83160386766706, 62.72336196899414, 55.52380534580776, 52.71932826723371, 55.117019585200715, 53.96884019034249, 54.60320029939924, 56.690077849796836, 58.983348165239605, 63.51482432229178, 55.07166869299752, 56.41150024959019, 57.2399582862854, 56.44343417031424, 65.52497291564941, 71.66556848798479, 70.75331170218331, 78.54458386557442, 76.48573534829276, 75.29395948137555, 67.94346019199916, 72.81977544512067, 75.33383519308907, 77.05954538072858, 75.43422971452985, 76.64550222669328, 88.815584727696, 52.97021729605538, 0.814168957727296, 4.079082855156489, 7.490541969026838, 6.5589757050786694, 7.729110973221915, 7.628963981355939, 3.4909124161515916, 0.2994181790522167, 0.39471983377422604, 10.05062484741211, 52.64645903451102, 67.33098343440464, 109.73192759922573, 82.89031382969448, 52.56680488586426, 30.088843958718435, 30.278991835457937, 39.04802145276751, 46.940775530678884, 76.569169316973, 70.58087130955288, 87.26817921229771, 11.930310589926583, 0.33644700210009304, 0.4953815351639475, 0.2297865083175046, 0.12771455331572465, 0.2509657847029822, 0.15408071423215525, 0.13305610311882837, 0.2045589970158679, 0.12610692743744167, 0.31591111261929783, 0.18316638922052725, 0.17275539572749818], [0.04895096491756184, 0.040156302907105, 0.054930181575140784, 0.034526168767895014, 0.04012283755998526, 0.040401457609342675, 0.15241408294865064, 0.09742532683802502, 0.08208079343395573, 0.045260195819927115, 0.1512578592768737, 0.08355375046708755, 0.5578975177236966, 17.7548326083592, 78.71966457366943, 68.38546984536308, 56.3425498008728, 48.14856352124895, 24.13826424734933, 42.68410757609776, 71.43838323865617, 78.02863843100411, 58.03123651232038, 6.78037006514413, 0.09658754643585, 0.18897432328334876, 0.4206995282854353, 4.0084070818764825, 4.291403302124568, 0.35287808041487423, 0.37908823255981716, 0.5727272533944675, 1.216814460498946, 54.34220858982631, 84.62295831952775, 89.19038445608956, 80.28450311933244, 88.01327623639787, 82.98287078312465, 85.1680861881801, 78.48152201516288, 75.89352648598808, 67.06809139251709, 63.33344854627337, 60.27877031053816, 61.645738056727815, 60.86142539978027, 61.242638315473286, 60.64754595075335, 66.07256044660295, 72.42925194331578, 74.11797686985561, 71.07241467067173, 67.02378273010254, 54.17380510057722, 57.53265462602888, 54.73671688352312, 53.69353519167219, 52.17095558983939, 50.28415836606707, 49.585457938058035, 53.236079692840576, 52.58334854670933, 53.01575231552124, 53.23272371292114, 55.201228278023855, 57.92099986757551, 60.3967159816197, 61.03673539842878, 63.0529636655535, 63.91275460379464, 69.74653162275041, 71.43879318237305, 67.1972792489188, 60.71188626970564, 63.40686321258545, 67.91310351235526, 60.71119144984654, 51.28397635051182, 53.29942641939436, 64.63422080448696, 67.26280076163155, 68.58194405691964, 61.61473519461495, 60.72410815102713, 58.46590191977364, 59.61100673675537, 32.543878759656636, 15.162294694355555, 20.019075087138585, 38.67895746231079, 53.62879535130092, 53.01097195489066, 58.8301751273019, 60.175985608782085, 62.655450275966096, 62.37461103711809, 66.17748519352504, 62.748035022190635, 63.95946734292166, 58.03190006528582, 51.65612186704363, 48.13358320508684, 50.999249594552175, 46.991111755371094, 54.96706356321062, 57.08372804096767, 62.9208436693464, 62.10471521105085, 62.03114768436977, 55.34414577484131, 59.425218854631694, 62.847415106637136, 61.27047279902867, 51.79822989872524, 49.29661784853254, 48.03073944364275, 48.29556655883789, 48.80610629490444, 47.85903903416225, 50.211945738111226, 52.32606022698538, 54.17442001615252, 52.653900555201936, 52.354103156498496, 49.43966736112322, 49.88779142924717, 53.40649815968105, 59.116308893476216, 64.1159199305943, 65.65921906062535, 69.09240041460309, 67.98041071210588, 70.74437631879533, 71.56344386509487, 69.82869407108852, 69.2055309840611, 69.69041102273124, 69.61901133401054, 63.56936073303223, 79.75995581490653, 39.831465584891184, 0.2158623319119215, 0.6043282576969692, 1.7554251360041755, 1.121480073247637, 0.9045487908380372, 1.8067109840256828, 0.2477915978857449, 0.035577484140438695, 0.10365547253085033, 19.075976984841482, 34.28418016433716, 63.024191175188335, 72.98289135524205, 49.055511883326936, 36.45015600749424, 17.886044127600535, 18.42237557683672, 24.98641869000026, 42.71553775242397, 50.659757137298584, 64.55221816471645, 24.18086886405945, 0.09089944844267198, 0.23426690218704088, 0.1135048900863954, 0.018390733249751583, 0.02609438050006117, 0.05859156671379294, 0.05296243002106037, 0.09312650215412889, 0.03392112248444131, 0.009281309870337802, 0.11318585649132729, 0.09844863907034908, 0.05059692802439843, 0.05837123282253742, 0.047872935621333976, 0.04310171485745481, 0.03142679722181388, 0.022811824854995524, 0.12837608424680574, 0.10489820941750493, 0.04528149842683758, 0.07073072783116784, 0.11668727360665798, 0.25320275181106155, 0.7033835681421416, 21.25959951536996, 93.07874229976109, 76.21188599722726, 68.77076135362897, 50.71144478661673, 32.50631332397461, 47.97811031341553, 75.5985963003976, 88.51811150142125, 64.10033512115479, 7.8973285981587, 0.2692580302911145, 1.3573793406997408, 2.8024369137627736, 1.9541964871542794, 4.731786208493369, 2.3823258110455106, 2.259386339357921, 0.7590998698558126, 2.2429095549242835, 60.24880273001534, 85.4533861705235, 92.80169677734375, 82.00277178628104, 89.52940790993827, 85.43713433401925, 86.80613095419747, 82.16015543256486, 78.18256187438965, 69.72802856990269, 66.30563776833671, 61.87356948852539, 64.71195030212402, 62.2519405909947, 62.730157307216096, 62.27212510790144, 68.89669050489152, 72.62995065961564, 76.81191158294678, 73.78237192971366, 70.3347452708653, 59.57256235395159, 59.75086007799421, 57.179026058741975, 56.496011189052034, 54.43312924248831, 53.744663511003765, 52.41821071079799, 56.3253356388637, 54.84719671521868, 56.88604136875698, 56.307086195264546, 58.665551458086284, 61.517377035958425, 64.60275936126709, 64.77733285086495, 68.50101838793073, 69.47303662981305, 72.77520275115967, 71.9987485068185, 67.33494390760148, 65.48184544699532, 67.27477250780377, 69.3753935950143, 63.62658609662737, 53.285001959119526, 55.91829626900809, 65.83570330483573, 70.36289242335728, 70.93236677987235, 64.01789474487305, 64.9687557220459, 61.05527319226946, 60.41534410204206, 37.81698131561279, 19.24068750653948, 27.73496103286743, 45.02073117664882, 57.47255965641567, 55.90496962411063, 59.2476715360369, 60.06774657113211, 65.30198437826974, 64.58993993486676, 68.75223745618547, 65.21978024074009, 66.71128749847412, 61.97875131879534, 56.01490749631609, 49.674665859767366, 52.65997328077044, 48.80719716208321, 56.90374190466744, 61.09002808162144, 64.81237261635917, 65.66593102046421, 65.53768117087228, 60.504690987723215, 63.63980157034737, 65.37686511448452, 64.47152178628104, 54.04510014397757, 51.48348345075335, 51.09677103587559, 49.93569925853184, 50.078522954668315, 51.486696992601665, 52.650221484048025, 54.742859091077534, 56.77322346823556, 56.02213362285069, 55.04628692354475, 52.34177705219814, 51.50637429101126, 56.301218441554475, 60.65203448704311, 65.99150276184082, 66.76867267063686, 71.17754786355155, 70.9597635269165, 73.73556191580636, 73.3484638759068, 72.35203661237443, 72.69196333203996, 71.64754486083984, 73.88845702580043, 69.56567696162632, 80.07973970685686, 54.607869488852366, 0.593033852321761, 0.9871350250073841, 2.7896678618022372, 1.5180857458284922, 2.6978267899581363, 4.347687184810638, 0.9185850747994014, 0.3942605198494026, 0.07657445461622306, 19.697408233370098, 44.491094316755024, 60.44409574781145, 62.10500703539167, 42.94084003993443, 31.742827892303467, 19.82820633479527, 26.33074573108128, 28.814096178327286, 47.94229582377842, 58.583076340811594, 73.33811106000627, 30.817022119249614, 0.3017050591962678, 0.2605291929628168, 0.09506449994764157, 0.09703225828707218, 0.13705422143851007, 0.04021341859229973, 0.059510825601007254, 0.05418061072539006, 0.008074519224464893, 0.07603503284709794, 0.12609185038932733, 0.09595031384378672, 0.16050008977098124, 0.13163097601916107, 0.0965373959126217, 0.16397443333906786, 0.25726098833339556, 0.15146638665880474, 0.26740712246724535, 0.3406115514891488, 0.13943250024957315, 0.26112443102257593, 0.26142165650214466, 0.28804707207850044, 0.868515378662518, 25.66265732901437, 111.32572623661586, 84.27013574327741, 81.67717225211007, 65.77970082419259, 36.54363359723772, 51.00420366014753, 95.78853975023542, 89.27634756905692, 82.53655324663434, 11.466477513313293, 0.35432943967836245, 1.1461472639015742, 3.4703928657940457, 9.041390316826956, 11.179013167108808, 6.1253759775842935, 2.228932167802538, 0.847630993596145, 2.436854839324951, 64.65686498369489, 92.4109022957938, 96.22168350219727, 87.65052468436105, 95.78321048191616, 89.1021284375872, 90.83073602403913, 87.3087705884661, 81.53766632080078, 73.40877423967633, 69.2701005935669, 65.41479533059257, 67.05375031062535, 66.08364282335553, 65.97090830121721, 66.16991860525948, 74.27401951381138, 75.1222208568028, 80.42743451254708, 77.4857895714896, 74.27505479540143, 61.91766275678362, 63.84928975786482, 60.90361486162458, 59.19706085750035, 58.842758314950125, 57.05543845040457, 55.20468848092215, 59.45965412684849, 58.91349792480469, 60.20412581307547, 59.92794186728341, 61.857845715114046, 65.3315211704799, 68.43305805751255, 68.90609836578369, 70.17338725498745, 72.81564126695905, 75.84012263161796, 76.76258632114956, 70.75714015960693, 67.84631047930036, 69.41499137878418, 72.41803060259137, 68.532931464059, 57.7018015725272, 58.09603541237967, 72.4904099873134, 72.03899942125592, 74.44527871268136, 68.60622801099504, 68.74916635240827, 64.56733049665178, 66.70583316258022, 38.53116233008248, 15.862921510423933, 25.80454649244036, 47.56973341533116, 62.38161482129778, 58.885378565107075, 62.56805583408901, 62.44119562421526, 67.70929200308663, 66.69011633736747, 73.12671906607491, 71.00225870949882, 69.52398082188198, 65.18881211962018, 57.981834820338655, 53.80004065377371, 54.763533455984934, 51.50802796227591, 59.7773813520159, 63.8818142754691, 69.75074917929513, 67.89680303846086, 67.33181027003697, 60.78582205091204, 64.42004258292062, 68.97908224378313, 67.45156942095075, 58.2740204674857, 55.90266629627773, 54.69114712306431, 52.6697598184858, 55.186049938201904, 53.51729760851179, 58.02923543112618, 57.87388413293021, 61.01707894461495, 59.83751106262207, 58.35867037091936, 55.299138818468364, 54.98113366535732, 58.82636056627546, 67.36378587995256, 70.44299820491246, 71.69043609074184, 75.3511084147862, 75.25418799264091, 76.8498626436506, 78.09778690338135, 76.41663551330566, 76.91191700526646, 74.94488198416573, 76.45029953547886, 70.22831971304757, 89.29341929299491, 50.847744124276296, 0.6202341499073165, 5.133636142526354, 10.552081550870623, 2.803789641175951, 4.667352523122515, 8.149475250925336, 0.3342238499649933, 0.23082803242972919, 0.20036745550377028, 30.727105481284006, 54.078239577157156, 77.7988406590053, 83.44108363560268, 64.65580190931047, 47.9040390423366, 27.14320206642151, 29.9813449042184, 37.33930655888149, 61.49722031184605, 67.0231157030378, 84.16712869916643, 35.77617727007185, 0.44896493586046354, 0.3325292766094208, 0.2231751209391015, 0.16978945130748407, 0.2594622102166925, 0.12312236401651587, 0.15682731542204106, 0.28353313143764225, 0.11253645776637963, 0.18033552755202564, 0.17588467709720135, 0.22242377911295208], [0.03398783265479973, 0.028881765037242855, 0.09964038405035223, 0.05777123823229756, 0.00915156040407185, 0.0842853265681437, 0.048595473635941744, 0.11290706002286502, 0.05039686875950013, 0.01181407498994044, 0.2063817727778639, 0.1050307069505964, 0.5024285284536225, 25.338421378816875, 76.88606275830949, 60.91340487343924, 55.28821277618408, 31.955873557499476, 33.59761823926653, 26.62018162863595, 79.50413703918457, 75.83587728227887, 31.149309294564382, 0.8355382510593959, 0.03396300505846739, 0.02829389926046133, 1.6340309871094567, 1.421843858701842, 2.347897921289716, 0.3150316226695265, 0.8552023587482316, 0.1018073670566082, 14.78954815864563, 85.96093123299735, 88.86036586761475, 86.73921285356793, 78.81789820534843, 82.65916115897042, 76.82707255227226, 71.52004541669572, 66.0855188369751, 63.24174622126988, 60.089153970990864, 62.387388774326865, 60.06104155949184, 61.805699484688894, 58.34633037022182, 60.020352908543174, 58.85177707672119, 60.56083938053676, 66.52823025839669, 71.19864954267229, 67.12807519095284, 61.65959971291678, 56.93607187271118, 55.18028988157, 54.68748194830758, 52.73258195604597, 49.233489990234375, 48.82873657771519, 51.86580807822091, 53.043169907161165, 54.886690276009695, 58.95718819754464, 59.044395038059776, 62.187148639133994, 64.63128171648297, 64.68824999673026, 63.37221254621233, 68.37240723201207, 65.5695664542062, 70.26467268807548, 63.690099579947336, 65.54572023664201, 65.76434530530656, 64.6723942075457, 60.92698165348598, 55.51770830154419, 49.50909376144409, 54.573104177202495, 60.82919270651681, 65.23942279815674, 68.00245039803642, 61.15839140755789, 59.021500723702566, 54.839313983917236, 51.38109827041626, 35.70036200114659, 25.185005153928483, 26.99434907095773, 39.161753041403635, 50.68994011197771, 48.76419128690447, 52.726248673030305, 57.857416902269634, 65.35521452767509, 62.41788441794259, 64.23679079328264, 63.15944480895996, 65.47580051422119, 60.35633305140904, 60.33141681126186, 48.252161162240164, 47.57232856750488, 46.60006366457258, 48.53337560381208, 49.93022060394287, 57.79331977026803, 61.57650620596749, 62.60500635419573, 61.54201534816197, 61.12663813999721, 62.43490055629185, 61.11682728358677, 54.794150693076, 50.01806320462908, 47.79427834919521, 46.249728543417795, 47.90104784284319, 48.15205151694161, 47.99913208825247, 53.41941138676235, 55.05158839906965, 55.73882777350289, 51.542814118521555, 50.84917197908674, 48.67361109597342, 49.61174644742693, 52.32889856610979, 54.64215884889875, 57.814841815403526, 62.30983992985317, 64.89278411865234, 67.74092020307268, 65.79452133178711, 68.15211459568569, 66.20270020621163, 64.10604654039655, 60.74832262311663, 77.60706342969621, 66.6503517968314, 77.01347882407052, 19.755196401051112, 0.7545063506279672, 0.5629284477659634, 2.6298660252775465, 2.12048186148916, 2.785923651286534, 2.5241176996912276, 0.11389502058071749, 0.08630252975438323, 3.2089254217488423, 28.811209201812744, 38.692989349365234, 54.01143612180437, 74.25987992967877, 109.68459647042411, 69.52662113734654, 24.43756311280387, 21.98882337978908, 34.483867917742046, 52.16950341633388, 60.73329366956438, 41.23183332170759, 0.14760993288031646, 0.1256181922342096, 0.09856385431651558, 0.12793253947581562, 0.04202103588197913, 0.09782869555056095, 0.08591929317585059, 0.05510999335508261, 0.09538458527198859, 0.02991787783269371, 0.07477321555571896, 0.1039389373202409, 0.07171321939677, 0.05415118605430637, 0.04659412781308804, 0.030669430004698888, 0.05387010631550636, 0.07294172740408353, 0.04024052606629474, 0.10100700786071164, 0.07967306620308331, 0.11763701907226018, 0.04339711847049849, 0.2617318012884685, 0.48277723150593893, 30.929975509643555, 90.43296555110386, 69.68263598850795, 65.40474823543003, 36.50903851645333, 34.85713904244559, 34.41051925931658, 86.2049867085048, 82.40562834058488, 36.68455001286098, 0.7358631938695908, 0.07421480837677207, 1.3157373751912798, 4.788024927888598, 3.363752565213612, 5.459746369293757, 1.442310971873147, 2.655191992010389, 0.12085764482617378, 18.156785896846227, 90.28023719787598, 90.16090883527482, 88.54173537663051, 81.0661963054112, 84.95638152531215, 77.29092039380754, 75.02477931976318, 69.54451969691685, 65.57937731061662, 62.981779370989116, 66.0030437197004, 62.79403904506138, 63.54642472948347, 63.02929810115269, 62.62968635559082, 60.50701863425118, 62.4537718636649, 67.89016056060791, 71.75038514818463, 69.58857127598354, 64.77663803100586, 57.756077425820486, 58.77213682447161, 55.74536950247628, 55.34959316253662, 51.03895507540022, 51.307353564671104, 54.15269994735718, 54.69345392499651, 56.85052565165928, 61.948804582868306, 62.77953815460205, 66.19637039729527, 68.05960627964565, 68.59424236842564, 66.27257129124233, 71.78627954210553, 68.0405056817191, 71.0611377443586, 64.93810026986259, 69.36659022739956, 68.48917865753174, 68.6430743081229, 62.047211919512065, 57.58309159960066, 52.68258966718401, 56.04047686713082, 63.74472631726946, 66.65941224779401, 69.9670604978289, 62.84085600716727, 62.67679514203753, 58.33992413112095, 52.95724848338536, 40.49983017785208, 28.237802164895193, 33.05138560703823, 44.822738783700125, 55.09907586233956, 51.76836306708199, 53.175453186035156, 59.93690504346575, 66.83862713405064, 65.71208790370396, 66.95558616093227, 64.60867922646659, 67.5162432534354, 63.50910595485142, 62.96759114946638, 50.33013807024275, 49.82746022088187, 49.54814958572388, 50.86260632106236, 52.38744756153652, 59.62247821262905, 62.62079266139439, 65.32506629398891, 66.18073000226701, 66.08107893807548, 66.33236054011753, 64.60094588143485, 58.88236999511719, 52.394319329942974, 50.10553060259138, 49.07227441242763, 49.3381472315107, 50.37631927217756, 50.03578805923462, 55.23899173736572, 57.5008944102696, 58.72844655173165, 55.2870454788208, 54.46955169950213, 51.4713762147086, 52.87898397445679, 55.820441314152305, 57.54966729027884, 59.99691663469587, 64.32137121473039, 67.52207279205322, 70.87432847704206, 68.4879071371896, 70.42540536608014, 67.14554296221051, 67.03584480285645, 62.90609264373779, 78.44838605608258, 69.52305671146938, 78.19786875588554, 30.052671636853898, 0.4850200340151787, 0.3844694766615118, 2.9792659623282294, 2.2738305585724965, 2.685577550104686, 1.4380823416369302, 0.8304077120763915, 0.14372370498520987, 2.504120349884033, 34.38691970280239, 44.259906905038015, 49.496809346335276, 66.40504564557756, 84.15735953194755, 48.47011225564139, 27.586559670312063, 26.466365882328578, 39.960830620356965, 57.63596044267927, 67.35421821049282, 49.92231355394636, 0.08296792368803706, 0.10344457027635404, 0.0376273214684001, 0.0330734999318208, 0.06723642854818276, 0.028721267756606852, 0.036289684674037356, 0.037264607181506496, 0.051503287960908244, 0.0293060088796275, 0.12437514322144644, 0.062037086114287376, 0.10848187854779617, 0.2069168926349708, 0.13209383189678192, 0.16268676386347838, 0.12661007472446986, 0.17973178066313267, 0.13883274314658983, 0.2996687213225024, 0.13220332030739101, 0.25307551292436464, 0.3542023907814707, 0.5974924245050975, 0.835544113601957, 38.06429897035871, 103.43075915745327, 77.80114051273891, 78.64162240709577, 50.530426842825754, 45.92434440340315, 36.4767849785941, 102.62311444963727, 89.12926810128349, 50.54938847678048, 1.3760709719998496, 0.2299294892166342, 0.8731473843966211, 6.547687487942832, 5.477162463324411, 10.849664211273193, 5.9913356729916165, 5.708081935133253, 0.7037727758288383, 19.16207558768136, 98.44976929255894, 97.23856626238141, 93.92405319213867, 85.16742610931396, 88.96907043457031, 82.8463247844151, 79.27486038208008, 72.85986655099052, 70.50113378252301, 66.98728384290422, 69.1856938770839, 65.79561914716447, 68.54562582288469, 64.10153715951103, 66.73862171173096, 64.15946429116386, 67.60199792044503, 71.26461574009487, 78.64479773385185, 71.85585880279541, 67.78641700744629, 61.94183553968157, 61.891210964747835, 59.438990184238975, 57.95607437406267, 54.79142352512905, 55.34662280763899, 57.867929526737754, 56.8013254574367, 60.70536885942732, 64.46516418457031, 64.16286890847343, 70.49988310677665, 71.25385298047746, 71.8448042188372, 70.02402182987758, 78.7423643384661, 71.55898312159947, 74.7331634249006, 68.01577009473527, 73.53501605987549, 72.34563037327358, 73.79730360848563, 67.44127913883754, 61.32726042611258, 56.22784546443394, 58.9537627356393, 67.64569514138358, 70.11005442483085, 73.27516038077218, 66.45600373404366, 68.83985424041748, 61.8613406590053, 56.481624943869456, 42.65315335137503, 28.013985054833547, 31.912384782518657, 48.706465653010774, 60.176868030003135, 54.085889543805806, 55.52990239007132, 60.166577747889924, 71.19611345018659, 67.60682691846574, 69.2451982498169, 66.38144261496407, 69.18682643345424, 67.1140467779977, 65.85290704454694, 52.535718645368306, 54.3026351247515, 52.85014547620501, 55.04222570146833, 54.99015590122768, 62.12480245317732, 67.94839341299874, 70.80168506077358, 67.0329613004412, 68.18757125309536, 68.40269442967006, 67.95172854832241, 61.36359255654471, 55.447455065590994, 55.32702888761248, 51.324703216552734, 52.98162971224104, 53.14706632069179, 53.489713260105674, 60.44524914877755, 61.62082181658064, 62.31132684435163, 58.48909500667027, 57.995856285095215, 55.466569559914724, 55.86810943058559, 58.428207942417686, 62.112983567374094, 62.95638370513916, 68.01295607430595, 72.58596161433628, 74.16292476654053, 71.66311577388218, 74.4645391191755, 70.34926005772182, 71.15004689352853, 68.26145839691162, 85.38965034484863, 73.22875336238316, 84.99299853188651, 27.70878890582493, 1.868257258619581, 4.647356041840144, 9.114613039152962, 4.023049541882106, 7.883370535714286, 4.639172366687229, 0.5152796560100147, 0.12692487426102161, 6.027937480381556, 46.79825408118111, 56.12100996289934, 72.04081290108817, 86.98031534467424, 121.9404683794294, 83.06227479662213, 36.19021347590855, 33.917794704437256, 53.03464099339077, 66.96200629643032, 76.26614448002407, 56.70635747909546, 0.18496586408998283, 0.21253166134868348, 0.1275447974247592, 0.27285605722240036, 0.09638142785323517, 0.2019350342452526, 0.11841200105845928, 0.07807859711881195, 0.12584358799670423, 0.1424577757716179, 0.2123576035456998, 0.2186866117907422], [0.0421224565112165, 0.00960951641068927, 0.05437564204580017, 0.07716712781361171, 0.01773353815743966, 0.12345530757946627, 0.07679304467248065, 0.06069729157856532, 0.09825187070029122, 0.026584773025076305, 0.08770023046859673, 0.06255064212850162, 0.35093453899025917, 31.28216232572283, 75.98330415998186, 60.25577872140067, 55.010687828063965, 37.165921211242676, 30.895220620291575, 33.21633931568691, 78.25913797106061, 59.29642704554966, 15.226848670414515, 0.11058556102216244, 0.30834292301109856, 1.3777952109064375, 2.2729427090712955, 0.9183025871004377, 3.884122048105512, 1.0913367250135966, 0.443150487861463, 0.8538257469023977, 53.72038303102766, 95.17571558271135, 85.54257324763707, 82.75918742588588, 78.34174510410854, 74.03926072801862, 67.62972123282296, 68.54783535003662, 66.77598912375313, 69.11831719534737, 70.8995087487357, 68.19766698564801, 62.19493062155587, 60.791505677359446, 59.52926812853132, 58.606394495282856, 56.1190436226981, 56.97014236450195, 59.14569977351597, 61.33824552808489, 58.83149528503418, 58.555172375270296, 54.86851378849575, 53.8781418800354, 53.84105934415545, 49.381514413016184, 48.4521198953901, 51.476611682346885, 50.132930823734824, 57.60463448933193, 64.34846224103654, 65.68049444471086, 64.55328123910087, 67.07157244001115, 65.96357100350517, 68.02563653673444, 68.31502205984933, 69.45931393759591, 66.9709277834211, 66.23933805738176, 63.213341985430034, 65.31032916477749, 58.440805026463096, 53.926004546029226, 49.449148178100586, 46.97561032431466, 48.447509765625, 54.39076260157994, 59.52666255405971, 63.20567812238421, 64.79785088130406, 54.38951539993286, 55.2533779825483, 52.85496405192784, 47.03655644825527, 42.47185747964041, 38.88495765413557, 35.71983085359846, 41.67137636457171, 53.76161364146641, 50.34174503598894, 55.36871460505894, 61.626401220049175, 62.52213518960135, 63.29557391575405, 62.262467111860005, 62.666358947753906, 61.58656024932861, 63.88660853249686, 58.71798256465367, 50.285019942692344, 46.87771020616804, 45.45483030591692, 48.24609191077096, 47.962046078273225, 45.25134883608137, 52.362308979034424, 57.28640004566738, 62.43479633331299, 61.01437609536307, 59.87023707798549, 61.62979194096157, 58.892410142081125, 55.50171702248709, 48.6226669039045, 45.04501860482352, 47.18646035875593, 46.71224580492292, 46.93790939876011, 50.303887775966096, 54.107300417763845, 55.2845093863351, 55.64118473870413, 52.90886470249721, 48.92813055855887, 49.629836082458496, 49.51471138000488, 50.68440587180001, 51.38943263462612, 54.39460148130144, 55.664158957345144, 58.96845122746059, 56.96744646344866, 56.503018447331016, 57.47813905988421, 54.86468185697283, 58.50301224844796, 59.533061844961985, 68.3261113848005, 72.32779434749058, 57.40513433728899, 1.0524019513811385, 1.3899983103786195, 0.7043934996638979, 3.426828746284757, 2.863457513707025, 4.539447912148066, 1.0146250299045017, 0.24551552001919064, 0.1120090867791857, 14.23370703629085, 27.896725518362864, 40.601336411067415, 97.6774422781808, 110.47710800170898, 95.19211333138603, 34.65251806804112, 21.807279109954834, 31.599955558776855, 49.30826302937099, 59.46829768589565, 49.40620831080845, 0.4749107307621411, 0.10273077857813664, 0.060948322394064496, 0.0763698627374002, 0.1749688448118312, 0.0758214368085776, 0.05828709448022502, 0.008194354445939618, 0.08334831041949135, 0.010030571138486266, 0.07778457432453122, 0.11414005314665181, 0.04807462337027703, 0.029493518639355898, 0.0683203950258238, 0.07924942964954035, 0.06736470559345824, 0.028619938729596988, 0.06964481395802327, 0.05137859697320631, 0.09978658799082041, 0.09303961574499096, 0.07513969231929098, 0.1803751675678151, 0.2858854223574911, 39.91577502659389, 85.92527307782854, 68.60666574750627, 63.320497104099815, 48.00579193660191, 38.0533173424857, 35.6405588558742, 84.80116571698869, 68.00019918169293, 16.85787922995431, 0.17703768451298985, 0.7979029534118516, 4.359196875776563, 3.1356664385114397, 2.008844720465796, 4.035496371132987, 0.9699737344469342, 0.08319100564611809, 2.227177096264703, 66.60391003744942, 96.22139862605503, 89.75630133492606, 85.87717764718192, 82.9529309953962, 75.77191911424909, 70.67977196829659, 72.37454877580915, 70.95587948390416, 73.01026725769043, 76.00726154872349, 72.024338722229, 66.10801710401262, 63.75480120522635, 62.73714024680001, 60.27683176313128, 61.65438161577497, 59.400462423052105, 63.2545656476702, 63.36829376220703, 62.97036348070417, 61.09457220349993, 58.46820177350725, 55.996223790305, 56.84547083718436, 50.96449817929949, 50.83000884737287, 53.415461335863384, 53.68087557383946, 61.26698480333601, 69.6210332598005, 67.87373501913888, 68.02673435211182, 69.1880910055978, 69.75711372920445, 72.94216101510185, 70.79978820255825, 71.73990031651088, 67.43084294455392, 69.33758844648088, 66.9418009349278, 67.22662149156842, 60.401864596775596, 54.46279110227312, 49.87595864704677, 48.75391837528774, 50.71847983769008, 56.452209745134624, 63.655129296439036, 66.03961208888462, 66.71483107975551, 56.32755558831351, 58.498447281973704, 54.714090074811665, 49.01189456667219, 45.451439585004536, 41.07550927570888, 40.10180262156895, 46.116830348968506, 55.92913893290928, 53.21545396532331, 58.99732099260603, 62.78522178104946, 64.05731882367814, 65.49959114619664, 65.98276192801339, 64.83459295545305, 66.56406211853027, 67.92012119293213, 60.52779374803816, 52.97471278054373, 48.95026057107108, 48.653985909053254, 50.981688022613525, 50.55459267752511, 47.810804639543804, 53.55522435052054, 60.2552923474993, 62.76826122828892, 63.050663811819895, 64.27359540121896, 64.24735205514091, 64.48010281154087, 58.66550976889474, 51.01367058072771, 47.30974572045462, 51.07805258887154, 48.781978675297324, 50.4573734828404, 52.39127949305943, 58.16738646371024, 57.634171281542095, 59.001656668526785, 56.18395021983555, 53.29275267464774, 52.096880844661165, 52.728479044778005, 52.02207653863089, 53.96689816883632, 55.818016392844065, 58.087482179914204, 60.62172644478934, 59.686623982020784, 57.38305296216692, 59.140307971409385, 55.89096552985055, 63.706400053841726, 59.945562498910085, 71.77544035230363, 73.56093978881836, 66.0817459651402, 1.9636260611670358, 0.8821268997022084, 0.5588919243642262, 2.1289545382772173, 3.1574227682181766, 2.958828921828951, 1.621944595660482, 0.1700316204556397, 0.05406379074390445, 14.640285219464984, 34.732745443071636, 46.6682185445513, 97.69062995910645, 106.32507296970913, 81.49786703927177, 32.523562226976665, 30.416694709232875, 39.88440390995571, 55.460302284785676, 65.61332620893205, 57.493049894060405, 0.6007395674075399, 0.0740929977702243, 0.05706397404095956, 0.04427430818655661, 0.11315056588500738, 0.0796761331813676, 0.02813846554740199, 0.016015619804550494, 0.08917232576225485, 0.047925817248012335, 0.060030454503638406, 0.13081901387444564, 0.2240922831531082, 0.13603591679462365, 0.12721904633300646, 0.2549952513405255, 0.2342129722237587, 0.24303987143295153, 0.1691029638584171, 0.11234481912106276, 0.1753629379506622, 0.14323026074894837, 0.25272587739995545, 0.35506046616605347, 0.511539950966835, 49.16486610685076, 99.28613785334996, 78.30715697152274, 74.42675481523786, 58.20794309888567, 44.86008882522583, 51.11327995572771, 92.58616365705217, 77.90973390851701, 25.083710840770177, 0.230986266796078, 0.9680889270135334, 6.08452274118151, 8.343132836478096, 5.096303905759539, 13.457104274204799, 5.660424675260272, 1.3021007754973002, 1.813702174595424, 70.05187020983014, 103.10775130135673, 94.10925742558071, 89.15267658233643, 85.60669122423444, 80.52561950683594, 74.6267170224871, 74.96895054408482, 74.3703145980835, 75.15386990138462, 79.63294969286237, 74.76609093802315, 66.49460792541504, 66.38798086983817, 63.91896629333496, 62.88460881369454, 64.50016920907157, 62.39674799782889, 66.63098021915981, 68.39465536390031, 65.50332232883999, 65.21529865264893, 62.18698188236782, 58.566081047058105, 57.7926527432033, 54.3297678402492, 55.248218945094514, 56.27175807952881, 57.38587393079485, 63.28418581826346, 70.64150823865617, 71.66695812770298, 71.6468847819737, 73.87217739650181, 72.05274990626744, 75.57158865247453, 72.77960096086774, 76.0048713684082, 70.41861697605678, 75.44492994035993, 71.3838746207101, 71.2994818006243, 65.5197617667062, 60.136033466884065, 55.005799770355225, 51.43590913500105, 53.64216715948922, 60.94219126020159, 66.74597290584019, 71.08861092158726, 70.06999805995396, 59.51660851069859, 62.98874841417585, 58.917020661490305, 50.72749512536185, 46.59848294939314, 42.729802404131206, 41.42876958847046, 49.47356762204851, 60.69758687700544, 59.57895469665527, 60.523951394217356, 65.52839142935616, 68.55849388667515, 70.73300211770194, 68.96390042986188, 68.58983721051897, 69.77460929325649, 72.45400142669678, 65.59567778451103, 54.63249390465872, 51.711109910692485, 51.59129517418997, 53.665662493024556, 53.001668316977366, 49.16356679371425, 56.724082333701, 62.517611912318635, 67.72739206041608, 67.2768361227853, 65.55519757952008, 66.08921527862549, 66.9591644832066, 61.75672858101981, 54.00435243334089, 49.929261752537315, 54.7282782963344, 51.15417010443551, 52.815328053065706, 55.456998416355674, 60.41964503696987, 61.09453051430838, 62.08407211303711, 59.43778119768415, 54.610895429338726, 55.89111491612026, 55.2951922416687, 56.09900154386248, 58.781155586242676, 60.95888083321707, 64.27131639208112, 64.97664887564522, 62.54017966134207, 61.14612783704485, 62.92335891723633, 60.29278482709612, 66.90284933362688, 65.31355312892369, 75.2325860432216, 80.55203655787876, 69.08269378117153, 1.2718928307294846, 4.213516167231968, 6.787927968161447, 9.647301026753016, 9.204014641898018, 11.888116785458156, 1.7072440470967973, 0.28952030731098993, 0.2569579817354679, 22.678767340523855, 44.8635698727199, 56.167420455387656, 104.88932500566754, 112.03691605159214, 106.11201340811593, 47.43241616657802, 33.51522650037493, 47.219863823481965, 64.26044940948486, 75.93572984422956, 66.74550737653459, 0.7165389508008957, 0.2442851188991751, 0.12543516419827938, 0.14680666955454008, 0.15985972913248198, 0.12154281591730458, 0.10375939016895634, 0.15127810676183018, 0.18099283799529076, 0.12201256571071488, 0.1661161748426301, 0.21493074404341833], [0.15560638665088586, 0.061585704263831885, 0.030890876693384986, 0.06857460817056042, 0.056849675718694925, 0.03722729114815593, 0.03416275219725711, 0.060469690577260087, 0.012287979962171187, 0.023016571100535135, 0.046715551654675176, 0.07243827477629695, 0.02369084152659135, 37.51483889988491, 75.14139093671525, 56.37313229697091, 39.22139637810843, 25.76413229533604, 39.933579785483225, 67.6617454801287, 63.506020954677034, 43.31216219493321, 2.124779539448874, 0.03452058103201645, 0.26618670938270433, 2.2382959510598863, 4.923990752015795, 1.8447884150913783, 2.5655322202614377, 1.0260823922497886, 0.2781485218022551, 20.44064835139683, 94.4292219706944, 87.62599754333496, 92.44098799569267, 80.11503655569894, 83.92252431597028, 76.49006407601493, 75.79618917192731, 76.31048093523297, 81.23439829690116, 80.91077899932861, 81.3936926977975, 76.1891028540475, 75.32695647648403, 64.80625820159912, 60.59385027204241, 57.42220606122698, 58.77757031576974, 56.16117402485439, 54.801831926618306, 55.41120283944266, 56.654749734061106, 55.85413312911987, 55.604331493377686, 53.001004764011924, 53.00790432521275, 48.474121366228374, 48.73904575620379, 48.91831275394985, 57.55507646288191, 69.47981807163784, 68.28349808284214, 67.77531378609794, 68.61004952022007, 69.32300417763847, 72.38024629865373, 69.6161139351981, 66.62483801160539, 68.12802519117082, 65.71355397360665, 64.5638563973563, 61.34132358006069, 54.64492770603725, 48.92055702209473, 47.68151256016323, 48.87973982947213, 50.76747506005423, 50.714811188834055, 57.5041948046003, 60.052022797720774, 63.73476954868862, 58.07334606988089, 52.55768190111433, 52.97755806786673, 48.754342215401785, 48.9094364302499, 47.863260064806255, 47.82001795087542, 45.42004762377058, 45.85660988943917, 50.563482897622244, 52.36926759992327, 54.65896306719099, 60.35040623801095, 59.63235855102539, 55.52075508662632, 57.026200430733816, 57.50823518208095, 54.37617138453892, 57.302415643419536, 55.33461284637451, 48.92804023197719, 46.469850948878694, 47.58889307294573, 47.559262480054585, 46.659929343632285, 46.28330223900931, 47.05538259233747, 48.634461471012656, 57.444944041115896, 60.62962654658726, 60.95201601300921, 60.494657788957866, 63.59541647774832, 58.91134398324149, 54.17324924468994, 44.99878181729998, 45.79257876532418, 45.07814414160592, 48.03640569959368, 48.67338875361851, 56.27503415516445, 54.7301230430603, 55.72816923686436, 52.69209132875715, 51.73448365075247, 47.26200812203543, 48.85430942262922, 45.91927569253104, 50.535752637045725, 47.72788136345999, 50.62555810383388, 49.52295194353376, 50.13804817199707, 50.05741432734898, 54.169865471976145, 55.53273030689785, 59.85590294429234, 64.0942484991891, 71.24954509735107, 65.4103832244873, 75.55310644422258, 10.56817010470799, 0.5264102358903203, 1.1696455287081855, 1.7626065335103442, 1.3569746081318175, 0.8156547865697316, 2.7870512136391232, 0.11136418674141169, 0.20366337150335312, 2.5965591839381625, 28.44840553828648, 29.103766577584402, 97.46487603868756, 98.6624675478254, 71.57699980054582, 33.057566029684885, 17.12941656793867, 28.717031581061228, 53.70755665642874, 56.02940491267613, 59.60407938276018, 2.2311334439686368, 0.04467150901577302, 0.12031888802136693, 0.00787556342714067, 0.12439540427710329, 0.09181574213185481, 0.13710361878786767, 0.09457780713481562, 0.13965686463883945, 0.05768769700080156, 0.12425046919711999, 0.03335658474160092, 0.1384363565593958, 0.12288296329123632, 0.04727858644244926, 0.04041457369125315, 0.08710611199161836, 0.0748063348499792, 0.03698929838304009, 0.004366929243717874, 0.05118012887292674, 0.039561448219631395, 0.03731554480535643, 0.031123434393001453, 0.05649561614596418, 51.35022047587803, 85.24339076450893, 66.0099571772984, 45.918372426714214, 37.27412550789969, 28.94300263268607, 54.922567299434114, 76.19689873286656, 48.16313736779349, 2.4543814531394412, 0.16469781952244894, 1.1157595344952174, 5.071040689945221, 1.963805845805577, 4.210483278547015, 5.824341799531664, 1.2577630175011498, 0.18136519087212427, 25.668893337249756, 92.45399502345494, 89.37116268702916, 98.26275157928467, 81.640958241054, 86.33768340519497, 79.4574590410505, 78.96688842773438, 79.62213829585484, 86.3668519428798, 82.92071219852993, 85.31351893288749, 81.67296164376395, 79.53411851610456, 67.73511845724923, 63.83990968976702, 60.40956320081438, 61.50416156223842, 59.49458966936384, 58.152284554072786, 58.79541328975132, 60.014446939740864, 58.75136171068464, 59.74266120365688, 56.827273505074636, 54.85139342716762, 52.27416065761021, 52.18287869862148, 50.37277569089617, 61.042328698294504, 73.12858813149589, 71.81183501652309, 70.30466651916504, 72.99624579293388, 71.51898929050991, 73.84772668566022, 71.22371864318848, 70.29864937918526, 69.70968532562256, 69.5059780393328, 66.44738101959229, 64.33282879420689, 56.62193686621529, 51.24043198994228, 51.62159974234444, 51.35007108960833, 52.145427908216206, 53.17016908100673, 61.17824935913086, 63.93696212768555, 66.15972559792655, 60.2487610408238, 55.868411677224294, 55.53317846570696, 50.287816592625205, 50.57911287035261, 48.7369612966265, 50.10429729734148, 49.71711935315813, 50.1966666494097, 51.65584046500069, 55.9797739301409, 58.16428756713867, 62.68433393750872, 61.036686761038645, 57.683586869921, 58.480944769723074, 60.02006803240095, 59.860530444553916, 59.02389785221645, 56.23523834773472, 51.19831895828247, 49.26623337609427, 50.98919207709176, 48.65731757027762, 49.052749974387034, 48.15123510360718, 50.856960909707205, 51.18021890095302, 61.14894185747419, 64.31777899605888, 63.69037055969238, 62.05444499424526, 64.26165839603969, 60.77000100272042, 56.59381750651768, 47.609734194619314, 48.42544576099941, 47.815393924713135, 50.540998526981895, 51.811921324048726, 59.10850606645857, 57.63605771745954, 57.75887754985264, 55.02762753622872, 55.45776966639927, 50.58138493129185, 51.70618711199079, 49.57651560647147, 53.5132155418396, 50.89114952087402, 53.941370487213135, 51.883953298841206, 53.289466176714214, 53.524384771074565, 56.8048551423209, 58.25563553401402, 63.69349030085972, 68.22753034319196, 73.78167016165597, 66.98651954105922, 78.04034614562988, 12.687599965504237, 0.3317643233707973, 0.373196078730481, 2.7269701404230933, 3.5977687622819627, 1.8198649010487964, 2.977507850953511, 2.6670249913419997, 0.2392181179353169, 1.901767986161368, 33.9603385244097, 32.89312301363264, 96.02416706085205, 100.8837788445609, 72.82985033307756, 32.66424240384783, 20.937161411557877, 34.63065903527396, 59.444555691310335, 59.56776809692383, 68.40538338252476, 2.7082755778517043, 0.05304678549457874, 0.1463537338588919, 0.03411166529570307, 0.049408806421394856, 0.11460942296045167, 0.08929253502615861, 0.09025078932089464, 0.07938689405896834, 0.03218260720106108, 0.047401574307254384, 0.08027665024357182, 0.21544968762568065, 0.1596661838037627, 0.15669110630239758, 0.15360497975988047, 0.11697574598448617, 0.10849689452775887, 0.15150780443634304, 0.15370327234268188, 0.09299291217965738, 0.14143781550228596, 0.19517485770796025, 0.13747427532715456, 0.33261854467647417, 60.01790714263916, 95.59608159746442, 75.1153004510062, 55.99134962899344, 40.36294371741158, 51.97589533669608, 91.87141636439732, 80.92355673653739, 66.45049381256104, 3.5907856055668423, 0.1380770586963211, 1.3665471630437034, 9.401716947555542, 12.45134471143995, 9.161148599215917, 10.6879666021892, 6.140680253505707, 0.4995608223336083, 30.30593694959368, 100.09877136775425, 94.1770509992327, 103.3290514264788, 86.33637019566127, 89.76060226985386, 83.44250106811523, 80.20297295706612, 84.05147593361991, 87.62639359065464, 86.07348510197231, 89.4364549091884, 81.99229390280587, 82.41296563829694, 72.35708100455147, 66.1879700251988, 63.0295968736921, 65.84807804652623, 61.93531118120466, 61.51996176583426, 62.34940297263009, 62.577234404427664, 60.475800377982004, 62.40059035164969, 59.638903754098074, 57.577248164585654, 55.240416118076865, 54.857629435403005, 54.38958140781948, 63.22299303327288, 75.87327248709542, 74.87344755445207, 73.40545994894845, 74.77458163670131, 74.81512437547956, 77.74640260423932, 74.78555284227643, 73.08943503243583, 71.82309109824044, 72.3016413279942, 69.67962047031948, 67.91623020172119, 60.43798133305141, 54.17462846211025, 54.23420579092843, 54.18370975766863, 56.50955670220511, 56.30698544638497, 63.97733810969761, 67.93116882869175, 70.46772684369768, 62.92803505488804, 58.7617631639753, 60.26092038835798, 52.91597965785435, 54.07817356927054, 52.39895030430385, 51.15823827471052, 50.856874057224815, 52.50054339000157, 55.77322483062744, 59.381042207990376, 62.76407841273716, 66.98449761526925, 65.49611704690116, 61.72965145111084, 62.15914739881243, 63.060113361903596, 61.16075379507882, 64.66468170710972, 58.80820492335728, 53.80705486025129, 50.39568737574986, 53.26859378814697, 52.776303495679585, 52.33718081883022, 51.37349694115775, 52.723452023097444, 55.53775038037981, 63.59937000274658, 66.70347077505929, 66.11288084302629, 66.8319012778146, 69.49313776833671, 63.642719813755576, 59.54191384996687, 49.50566829953875, 51.769808292388916, 49.82248878479004, 54.683809825352256, 55.83279173714774, 62.98916530609131, 61.20729282924107, 60.716430391584126, 56.980554240090505, 60.55941499982561, 52.571192673274446, 54.93598427091326, 51.80988550186157, 55.37875822612217, 52.864851338522776, 57.17887667247227, 55.57367951529366, 56.44199936730521, 56.83285985674177, 60.445117133004324, 61.89531735011509, 66.42521626608712, 72.17662239074707, 77.72393907819475, 72.5897970199585, 83.55606937408447, 14.371132850646973, 1.0251296205180032, 4.128825877393995, 8.520977190562657, 5.750184544495173, 4.784281151635306, 7.828913160732814, 1.6230464279651642, 0.24869784925665173, 3.8179144007819037, 45.85492842538016, 43.51586600712368, 104.68478393554688, 99.01767335619245, 82.02786867959159, 46.25484241758074, 27.176214694976807, 42.42629814147949, 68.96018314361572, 69.50231633867536, 77.31330054146903, 3.1828473125185286, 0.3087931717080729, 0.32816276805741446, 0.14669600049299852, 0.21861338429152966, 0.2560510518295424, 0.2674362723316465, 0.2300930975803307, 0.22536032939595835, 0.22643453175468103, 0.15817390887865, 0.23234032413789205], [0.03298364493197628, 0.026954181059928875, 0.0647935735593949, 0.016997709338154112, 0.06373174089406218, 0.05339772041354861, 0.037067916842975786, 0.040859156620821784, 0.050507130700030496, 0.1386956383607217, 0.04812566955972995, 0.013748148306539016, 0.20808520780078002, 44.23656790597098, 71.37641920362199, 56.65941544941494, 49.946465492248535, 40.608103956495015, 61.89334406171526, 67.6274630682809, 48.770274434770855, 20.19600054195949, 0.0941587235512478, 0.050930760468223264, 0.6789761749761445, 2.7718921984945024, 1.3155848405190875, 1.1642389616795947, 4.2041625891413, 1.9279880992003848, 5.534124229635511, 65.63931247166225, 74.11735848018101, 87.98596286773682, 85.03345789228166, 87.82322216033936, 86.50842148917062, 84.99266501835415, 82.64985057285854, 82.63779544830322, 80.55897086007255, 81.48859119415283, 84.8647278376988, 82.44815826416016, 76.86044475010463, 77.95063795362199, 63.96705477578299, 59.98395129612514, 56.184040546417236, 56.16437367030552, 54.232110909053254, 52.94848680496216, 53.79297086170742, 55.52110249655587, 53.417854990277974, 53.54809202466692, 49.16943107332502, 48.70625720705305, 47.24513094765799, 53.2924017906189, 67.15848050798688, 70.30936350141252, 67.30098111288888, 69.65627452305385, 68.27094268798828, 71.53350407736642, 68.11630358014787, 67.3947401046753, 64.63985579354423, 63.36115101405552, 63.29959692273821, 56.836285318647114, 50.37089967727661, 48.76238822937012, 47.744758537837434, 48.667972632816856, 48.410580090114046, 50.92286457334246, 50.92018256868635, 56.55065877096993, 62.88574831826346, 61.313767024448936, 55.56938900266375, 52.664586884634836, 50.54273557662964, 49.55733510426113, 48.608426570892334, 47.455185413360596, 47.50969403130667, 47.54246173586164, 49.4298426083156, 45.77974891662598, 50.80571794509888, 52.6562351499285, 54.58130305153983, 58.227446692330496, 56.95615564073835, 55.05962746483939, 55.35735777446202, 51.94854722704206, 53.072609424591064, 50.18822111402239, 47.535027163369314, 44.383286067417686, 47.236303261348176, 50.57276569093977, 50.782288619450156, 44.34476178033011, 45.37428331375122, 46.060817446027485, 50.56898587090628, 58.30971336364746, 60.109817913600374, 59.990385328020366, 59.66203430720738, 63.04187434060233, 58.439054080418174, 49.43647118977138, 45.523117201668875, 43.77050011498587, 46.45457533427647, 48.21023225784302, 53.23779937199184, 57.440577098301475, 58.54077570778983, 54.4365234375, 51.965313230242046, 50.76855550493513, 46.8943372453962, 49.148919991084504, 48.49764449255807, 50.41168907710484, 48.65904419762747, 51.22386053630284, 52.50258616038731, 58.76375034877232, 61.63153593880789, 67.16206577845982, 67.05100577218192, 67.24834156036377, 70.17628465379987, 70.47195829663957, 72.47886208125523, 25.691686902727398, 0.22247716624821934, 0.4117921548230307, 0.9797510440860475, 1.1628390082291193, 1.3536190624747957, 1.8440267188208443, 1.2155840865203311, 0.336864708257573, 0.10636473393865994, 20.692881856645855, 26.36079842703683, 41.46833610534668, 81.99844305855888, 49.52980286734444, 33.79368598120553, 39.64656359808785, 40.81024789810181, 49.50343097959246, 50.91839688164847, 58.06823219571795, 5.60806348494121, 0.19988412143928663, 0.2189847600779363, 0.03535759808229549, 0.16007410548627377, 0.12220308477325098, 0.2129102838890893, 0.09005846535520894, 0.07241285685449839, 0.05276668963155576, 0.04732102541519063, 0.0935087955689856, 0.06280495026814086, 0.018521151073010902, 0.04286856343969703, 0.04105040171582784, 0.07016267866960593, 0.03853699265580092, 0.09065410375062909, 0.012793009335707341, 0.05435702983023865, 0.0747844928077289, 0.09055003683481898, 0.06604331292744194, 0.16693717507379396, 54.25269147327968, 79.20593425205776, 64.51095976148332, 55.05798421587263, 52.524243695395334, 51.96790490831648, 69.45622893742153, 61.58947154453823, 22.947356905255997, 0.09115434690777745, 0.49521825249706, 4.545087243829455, 2.5818630925246646, 3.878439290182931, 0.5873557084373066, 2.142108563865934, 1.2958934285811015, 8.654239296913147, 77.35072353907994, 81.24149240766252, 90.58532564980644, 87.31306457519531, 88.159987449646, 88.40286867959159, 88.19890430995396, 85.05540030343192, 86.50310611724854, 81.34604890005929, 86.1361300604684, 86.60848944527763, 85.05487224033901, 79.21215288979667, 82.45679487500871, 67.22861562456403, 62.4848233631679, 59.39898245675223, 60.43067877633231, 57.43285417556763, 55.05917583193098, 55.45658499853951, 57.35207789284842, 55.37344632829939, 55.80824722562517, 53.53910800388881, 50.834184714726035, 50.179581029074534, 55.95707416534424, 69.34538432529995, 72.37741838182721, 69.40930080413818, 71.9173503603254, 68.67329202379499, 72.18754495893205, 71.23063904898507, 71.50213296072823, 67.3790510722569, 66.42238140106201, 67.09417493002755, 58.905458859034944, 53.88940143585205, 50.09003611973354, 50.75064304896763, 52.87906040464129, 49.547128200531006, 51.80529274259295, 54.2632805279323, 60.75058078765869, 67.11431775774274, 65.11643968309674, 56.550749097551616, 53.767415387289866, 51.11470086233956, 50.012330940791536, 48.678099632263184, 48.27527781895229, 48.89081525802612, 49.13868876865932, 50.65333005360195, 47.69958829879761, 53.92304808752877, 55.73488467080252, 58.35548114776611, 61.22207164764404, 61.32575266701834, 57.13716663633074, 57.70180852072579, 56.10241658346993, 55.28692735944475, 52.47732251031058, 50.000574588775635, 47.95437526702881, 49.63600260870797, 53.07590981892177, 54.52781581878662, 47.70291996002197, 47.418971402304514, 48.24672072274344, 51.21074233736311, 60.74233327593122, 61.22337096078055, 62.59090151105608, 62.62866497039795, 65.29254872458321, 60.80869552067348, 52.01157086236136, 47.98457213810512, 47.58946629932949, 47.4034560748509, 50.7396023614066, 57.54392113004412, 59.0979517527989, 61.49678952353341, 56.74579892839704, 54.678553513118196, 53.56661939620972, 51.03766965866089, 52.31450537272862, 50.48077154159546, 51.587147099631174, 51.87046684537615, 53.6189740725926, 54.538279805864605, 62.092736516680034, 65.2858784539359, 71.72131388528007, 69.55611624036516, 71.10764898572648, 73.19411659240723, 75.13573510306222, 71.32305009024483, 33.84015553338187, 0.38764336492334095, 0.4848367209945406, 0.8781426506383079, 1.1132611142737525, 3.7597284487315585, 2.2391297348908017, 2.7697135039738248, 1.1453800307852882, 0.22708737743752344, 20.277714831488474, 39.07766246795654, 41.0572772026062, 85.29876790727887, 54.18086794444493, 33.741411209106445, 42.49640893936157, 49.477409975869314, 57.49060412815639, 56.261481693812776, 67.13826819828579, 8.033327426229205, 0.2968521224600928, 0.2632044665515423, 0.0540819381629782, 0.06369257585278579, 0.04920839431828686, 0.12947426603308745, 0.029305367664034878, 0.10151812114885875, 0.08660200797021389, 0.06986205372959375, 0.08988799021712371, 0.263378632920129, 0.12586752671216214, 0.13948993145355157, 0.1925546268799475, 0.1686718769903694, 0.1399602105042764, 0.12041784556848661, 0.18162789248994418, 0.18762631847390107, 0.25711776316165924, 0.10937120046998773, 0.14343186707368918, 0.30573042748229845, 64.65726103101457, 91.1408827645438, 73.45078304835728, 66.65809209006173, 55.2265614100865, 84.24629647391183, 86.9624376296997, 67.61264256068638, 33.611702237810405, 0.22907084386263574, 0.3092497986342226, 5.841915096555438, 10.065351554325648, 8.955798932484218, 3.125050893851689, 14.890415157590594, 2.0949339866638184, 7.39245685509273, 81.22085625784737, 85.86039079938615, 96.30802876608712, 92.55133928571428, 95.01644202641079, 93.66590676988874, 89.70634378705705, 89.57914311545235, 89.58221421922956, 86.92937115260533, 88.70756108420235, 89.65899181365967, 90.4379335130964, 82.22985281263078, 85.55549689701625, 69.42254407065255, 65.65024893624442, 63.548606463841026, 62.24876526423863, 60.18552548544747, 57.765502657209126, 59.278146335056846, 60.50214099884033, 58.7722202028547, 58.64315741402762, 56.66788182939802, 53.71067292349679, 54.71568121228899, 58.196103368486675, 73.05752890450614, 74.51871422358921, 75.26139327457973, 75.24800409589494, 71.49826976231166, 74.80639743804932, 73.5767469406128, 73.91326904296875, 70.25866944449288, 69.10225296020508, 71.79309572492326, 62.044314520699636, 58.24156195776803, 55.891444955553325, 52.73399591445923, 54.3533604485648, 53.231712750026155, 55.21199451174055, 57.546516282217844, 63.20401750292097, 71.57968875340053, 70.52594579969133, 60.443164689200266, 57.77914891924177, 54.625455379486084, 50.496460574013845, 49.52095781053816, 48.905378682272776, 49.933628695351736, 50.43848827907017, 51.982582977839876, 49.43640865598406, 57.390216554914204, 60.5552738734654, 62.65731239318848, 64.10979856763566, 62.18994876316616, 60.272989409310476, 61.483942304338726, 58.259071418217246, 58.59455476488386, 55.72194365092686, 51.906924043382915, 50.286180291857036, 53.78672095707485, 55.370632307870046, 56.46170098440987, 50.96937581471035, 49.202636514391216, 51.851296765463694, 55.41506603785923, 63.642024993896484, 65.07372910635812, 66.61283152444022, 64.4392682484218, 67.31667709350586, 65.51772594451904, 53.58499043328421, 50.253113814762656, 50.04009594236101, 50.635292530059814, 54.371467454092844, 59.2544321332659, 61.550450461251394, 65.60550253731864, 58.217326641082764, 58.50403363364083, 56.612205914088655, 52.90786763599941, 55.72454922539847, 53.80620718002319, 56.07960912159511, 54.438903195517405, 56.95630850110735, 57.639153139931814, 64.67650059291294, 67.50305557250977, 73.77347128731864, 74.40511117662702, 75.64751856667655, 77.68773201533726, 80.43368094308036, 77.25097520010812, 34.364852224077495, 0.4279063844255039, 1.5100432059594562, 4.457046185220991, 4.2942055974687845, 5.2342356358255655, 6.470572471618652, 2.8343386990683417, 0.9087401830724308, 0.39595829589026316, 28.678385700498307, 45.21559688023159, 55.67481401988438, 89.34756660461426, 65.61907931736538, 47.94216728210449, 53.50516605377197, 57.00581094196865, 65.71768120356968, 65.00062016078404, 77.7770163672311, 9.23411510671888, 0.5700563224298614, 0.3819920638842242, 0.1333744717495782, 0.2576547014926161, 0.2829780897923878, 0.31697263994387215, 0.14450066829366343, 0.2206614336797169, 0.17519053577312402, 0.07661026769450732, 0.13693531496184214], [0.06217255563076053, 0.04955064398901803, 0.05109558001692806, 0.010880465935250478, 0.04372451500967145, 0.04966901442302125, 0.0030105154770093834, 0.10532318268503461, 0.05091351210804922, 0.070042862956013, 0.020023629468466555, 0.06710516594882522, 0.15737307470824036, 40.776399748665945, 70.08229637145996, 55.97025489807129, 47.29216677801949, 27.095068420682633, 49.03549412318638, 70.39447893415178, 43.68251160212925, 6.063221301351275, 0.09907984627144677, 0.23826404341629573, 1.856907593352454, 3.441311831985201, 1.075235360435077, 3.368951120546886, 2.428217794213976, 2.5449197377477373, 64.93188163212368, 80.21849523271833, 68.56805460793632, 78.15568624223981, 81.28365407671247, 86.91057627541679, 85.82721315111432, 85.77515724727085, 83.41238062722343, 83.78950105394635, 82.31897040775844, 86.39052445547921, 80.55210603986467, 82.880384853908, 81.22810322897774, 77.414931842259, 73.14538887568882, 60.501147406441824, 58.19071504047939, 55.313809939793174, 54.68878126144409, 54.41419192722866, 52.88259703772408, 53.97856419427054, 53.65057795388358, 52.601994037628174, 48.05495391573225, 48.63754647118704, 46.99384587151663, 54.46723794937134, 68.31361852373395, 67.01057420458112, 64.05053738185337, 65.91983209337506, 68.42553315843854, 67.566972051348, 63.043194498334614, 64.35482679094586, 58.966429301670615, 54.6779385975429, 48.86472477231707, 48.70146989822388, 47.61100918906075, 55.8610292162214, 58.69788837432861, 58.29810292380196, 59.112612451825825, 58.515838623046875, 57.63097163609096, 56.099557399749756, 61.25448499407087, 56.96109580993652, 54.18851791109358, 50.063233443668906, 49.9278130531311, 51.481972217559814, 51.527104241507395, 51.42623724256243, 49.15917900630406, 47.33262266431536, 48.80666215079171, 48.8719231060573, 44.67912994112287, 49.929873194013325, 50.14261661257063, 55.34923880440848, 59.772093772888184, 62.3314140864781, 56.14265360151018, 52.75752598898751, 50.75783790860857, 49.056557587214876, 45.67050239018032, 48.22535501207624, 53.324797766549246, 56.33162028448922, 60.0207211630685, 55.70773458480835, 43.81131730760847, 45.48095900671822, 45.1021397454398, 51.46105119160244, 55.40603685379028, 60.54434435708182, 56.766688687460764, 59.22936303274972, 59.55537945883614, 51.24392345973423, 46.19708204269409, 45.21828235898699, 46.71589708328247, 43.44464002336775, 51.7795079776219, 56.35834305627005, 55.206741673605784, 56.23230620792934, 53.46321977887835, 50.24214955738613, 46.52347019740513, 47.84405524390084, 51.416871070861816, 53.061162267412456, 56.0296550478254, 60.13836111341204, 61.770722252982004, 64.96764401027134, 65.44380405970982, 68.30660779135567, 66.50188963753837, 70.98989786420549, 69.03366729191372, 73.33311530521938, 66.68480791364397, 71.28486973898751, 19.951670612607682, 0.14972694856779917, 0.843426410640989, 3.1567481415612355, 0.3944084947662694, 0.6547845016632761, 4.1601031933512, 0.1614802878882204, 0.047843222572867355, 2.541927452598299, 50.17521061216082, 24.95437707219805, 44.69590984072004, 45.207182611737935, 37.643745354243684, 23.92801523208618, 18.45176124572754, 47.87143462044852, 49.17238058362688, 65.38830184936523, 10.073966452053615, 0.14353400016469614, 0.1903811570789133, 0.04751800073842917, 0.059101295790502, 0.040128306552235565, 0.07022540923207998, 0.07848064268806151, 0.044996337299900394, 0.07404391254697527, 0.08298677339085511, 0.04682418850383588, 0.018625080585479736, 0.025925253950325505, 0.026403259818575213, 0.046723480336368084, 0.05500078992918134, 0.07136384171566793, 0.0446335687302053, 0.02819674152747861, 0.06377346401235887, 0.020668697443657687, 0.06272227077611855, 0.10892241740865366, 0.10435584959174905, 48.615381717681885, 79.49652181352887, 63.82363700866699, 55.66782065800258, 30.698395524706157, 50.51628725869315, 76.09559399741036, 53.3713333266122, 6.945836637701307, 0.16057664209178515, 1.0461367389985492, 2.8186561805861334, 3.565685889550618, 2.0320714626993452, 2.0611453311783925, 0.5416496981467519, 6.486862088952746, 72.79745088304792, 84.96695668356759, 76.94786698477608, 82.28524385179792, 82.41386890411377, 88.64125442504883, 88.68817561013358, 85.88197885240827, 84.82397665296281, 86.15661334991455, 86.95440551212856, 86.78918429783413, 82.25117683410645, 85.37528147016252, 83.39501707894462, 80.7607673917498, 78.09379863739014, 62.99962929316929, 60.21351282937186, 58.06072466714041, 57.60304682595389, 55.28230333328247, 56.11706338609968, 57.09020376205444, 57.48288120542254, 54.57718276977539, 52.08988053458077, 50.97813401903425, 50.16053949083601, 57.37751872198922, 71.11720275878906, 71.22302382332938, 68.46866757529122, 68.78679779597691, 67.93972206115723, 70.28560066223145, 64.52883747645787, 67.2099666595459, 60.39396449497768, 55.50652865001133, 51.4839837210519, 50.87469271251133, 50.241228921072825, 58.728981563023154, 62.842627797807964, 62.67641299111502, 63.17989335741316, 63.668428148542134, 60.902065413338796, 61.57529721941267, 62.8077825818743, 61.2971955708095, 56.812032631465364, 52.28480529785156, 51.47960983003889, 54.61419929776873, 51.68874018532889, 51.87061970574515, 50.44620425360543, 48.49459423337664, 50.33323001861572, 49.19555630002703, 47.58827468327114, 53.31780787876674, 53.59262997763497, 57.975696086883545, 62.36908721923828, 63.93090329851423, 59.18023926871163, 53.702432359967915, 53.26522043773106, 51.11438124520438, 47.98963042667934, 51.360548973083496, 57.31403650556292, 60.39242894308907, 63.705969265529085, 59.90314374651228, 47.582132475716726, 47.34534134183611, 48.65947846003941, 53.356592723301475, 58.74848515646798, 62.32178388323103, 59.783106667654856, 61.343581744602744, 62.16508116040911, 55.832816055842805, 49.297013895852224, 47.42538806370327, 49.281244959150044, 45.680420943668906, 53.146725858960835, 59.465018136160715, 59.12676593235561, 59.591287749154226, 56.39086062567574, 52.72769737243652, 49.77684954234532, 52.11261504037039, 52.78719827107021, 56.53118297031948, 59.81499889918736, 63.183999742780415, 64.81536034175328, 67.4017299924578, 69.4457093647548, 70.6259651184082, 70.27453218187604, 74.39394542149135, 71.92781434740338, 73.04580034528459, 68.93550314222063, 77.05675915309361, 32.34398603439331, 0.2019405575203044, 0.7236598229834011, 1.1362337044307163, 2.509025126695633, 2.320191328014646, 3.704204959528787, 0.5501929968595505, 0.14304214370037827, 1.6446378465209688, 55.98940065928868, 36.29481513159615, 48.55972664696829, 52.64425992965698, 32.25740453175136, 30.490724291120255, 25.695810658591135, 52.7995799609593, 54.5186059815543, 75.16253430502755, 14.874156372887747, 0.2888021729886532, 0.13732939452997275, 0.08032283812229123, 0.03797744893069778, 0.09240679363054888, 0.05420390143990517, 0.02893230571810688, 0.038889813902122636, 0.032857328852904696, 0.09596448844032628, 0.004201826406642795, 0.13273550889321736, 0.10522985019321952, 0.11507264524698257, 0.12246419861912727, 0.23942194985491888, 0.0955214322145496, 0.16192745603621006, 0.20218940345304354, 0.1336973729942526, 0.1732602800641741, 0.1266366597265005, 0.15846441686153412, 0.3135497293301991, 58.268725940159385, 92.55564022064209, 70.76956353868756, 65.35622896466936, 36.54805612564087, 66.77758026123047, 83.04826028006417, 68.15454646519252, 10.855160236358643, 0.20935120486787387, 0.8025505925927843, 6.583724319934845, 9.47122151511056, 5.202019444533756, 14.509945699146815, 10.293222069740295, 5.674308478832245, 75.05917985098702, 88.98307800292969, 78.36156136648995, 82.97935499463762, 83.4073987688337, 91.51113837105888, 91.82983139583042, 89.38418361118862, 89.05369254520961, 90.55787331717355, 89.2408561706543, 90.78059087480817, 87.69480555398124, 89.53976072583879, 87.23678725106376, 83.84506579807827, 81.08191313062395, 67.31317520141602, 63.270942551749094, 61.181118965148926, 61.064305850437705, 58.903068678719656, 58.30887957981655, 60.58308751242501, 59.288693700517925, 57.57855442592076, 54.81919200079781, 55.02128035681588, 51.1925311088562, 61.56074769156319, 73.5861895424979, 73.09925283704484, 71.19583552224296, 71.39533914838518, 71.96921171460832, 73.02448327200753, 69.43684346335274, 71.68235533578056, 64.42252308981759, 58.30479403904506, 54.11045142582485, 54.19339902060372, 53.09065737043108, 63.869112968444824, 64.67324188777378, 63.950330461774556, 65.84488882337297, 66.69865567343575, 63.05365153721401, 63.26555074964251, 68.08057594299316, 65.00339249202183, 60.659635816301616, 55.37122637884957, 53.18797383989607, 54.20514495032174, 53.33270134244646, 52.85111822400774, 51.3671532358442, 49.41796118872506, 51.248144490378245, 51.78829744883946, 50.856662137167795, 58.01388338633946, 57.639795848301475, 61.567730631147114, 65.25686277662004, 67.38806983402797, 63.476894106183735, 57.18613753999983, 57.781528677259175, 53.66710424423218, 49.744519574301584, 53.242569310324534, 59.70004790169852, 62.06215749468122, 65.80468654632568, 60.00578253609793, 49.73080383028303, 50.37085798808506, 51.21140936442784, 55.85384130477905, 62.35330786023821, 66.04681042262486, 61.67701884678432, 65.86266926356724, 65.01922048841203, 57.41579634802682, 53.650772503444124, 51.78267635617937, 53.69124228613717, 50.10157707759312, 56.3914338520595, 62.50113773345947, 60.893143926348, 62.56670093536377, 60.87425177437918, 56.72889048712594, 51.687545095171245, 54.326849596840994, 56.13335691179548, 60.62872328077044, 61.606223651341026, 65.62071214403424, 68.52063315255302, 70.96863637651715, 73.1616268157959, 74.83959593091691, 74.28417083195278, 77.58052825927734, 74.46120398385185, 77.68374374934605, 69.45433902740479, 79.95007242475236, 28.175605365208217, 0.3321622705885342, 3.7401288832936967, 9.226019586835589, 7.42255471433912, 4.704772915158953, 11.304744294711522, 0.24755196645855904, 0.2559570340173585, 3.9093896065439497, 66.77013179234096, 43.69156163079398, 61.18516281672886, 60.05581651415144, 53.64328581946236, 31.12171104976109, 30.70396450587681, 62.88974353245327, 62.65144116537911, 84.86243493216378, 17.422484636306763, 0.5121258795261383, 0.31891322295580593, 0.19528657171343053, 0.17122547567955085, 0.16794280468353204, 0.14463117771915027, 0.1767372563481331, 0.14552250131964684, 0.20472400316170283, 0.12458656116255692, 0.1301976657871689], [0.025826932529785802, 0.06409483176789113, 0.062099545262753963, 0.06415295507758856, 0.08656494638749532, 0.06599828534360443, 0.13318970666400023, 0.0373825331750725, 0.0768810303083488, 0.01145802646143628, 0.07596456020006112, 0.013484365273533123, 0.13752648181148938, 33.981693812779014, 65.40012073516846, 50.078224182128906, 41.78356197902134, 30.218622412000382, 57.247438022068565, 66.52065672193254, 28.615448917661393, 0.7175791721258844, 0.05415053126801338, 0.6987379917076656, 5.406157953398568, 0.667880716068404, 2.683700450829097, 0.06592495606413909, 4.382168923105512, 78.77786963326591, 73.77704266139439, 77.60502065931047, 87.49872044154576, 92.67486436026437, 85.92623887743268, 87.66907637459892, 85.85560349055699, 86.1538062776838, 82.30981268201555, 83.8813840321132, 82.30417769295829, 79.79960223606655, 79.8535966873169, 79.85462502070835, 83.92377499171666, 77.72179903302873, 75.3442713873727, 65.3955557686942, 54.19370821544102, 56.23389387130737, 54.071659633091514, 54.348329952784944, 52.47972311292376, 55.245648111615864, 51.506145000457764, 51.43729182652065, 48.87980931145804, 48.08585950306484, 49.80673027038574, 54.83586072921753, 66.70363058362688, 67.23004695347377, 66.87940611158098, 67.49355043683732, 64.60499668121338, 63.65841579437256, 57.90162134170532, 54.86626604625157, 52.17315469469343, 50.07116828645979, 48.852666173662456, 48.46774639402117, 52.999462263924734, 64.03020000457764, 64.1021694455828, 64.3940007346017, 60.69852488381522, 63.19624246869768, 59.76987034933907, 60.4196172441755, 56.852637904030935, 56.1350314276559, 53.11681386402675, 49.856580121176584, 48.8452593939645, 51.03154134750366, 52.62490224838257, 53.842824186597554, 56.06528888429914, 58.475747517177034, 57.03729322978428, 49.74586057662964, 44.191408089229036, 45.086888449532644, 50.8725665637425, 52.162767137799946, 60.32875565120152, 62.226002965654644, 61.104584557669504, 56.05890348979405, 53.0875688961574, 47.78792769568307, 46.471035616738455, 54.403540338788716, 57.954104559762136, 59.06195313589913, 61.04220363071987, 56.956294604710166, 51.630861691066194, 42.321571418217246, 46.68064887183053, 44.438013553619385, 49.28622334344046, 53.96949332101004, 58.28004455566406, 55.51828500202724, 58.60278838021414, 55.16073417663574, 45.331221852983745, 44.622012274605886, 46.6101142338344, 44.224953992026194, 49.75376762662615, 55.569524492536274, 57.252850668770925, 55.23902300425938, 53.39158385140555, 50.16157824652535, 49.50777360371181, 51.672429289136616, 56.09267520904541, 60.872730118887766, 64.15441295078823, 63.74138423374721, 66.1900475365775, 63.53188214983259, 69.22283894675118, 67.1258795601981, 67.40129225594657, 63.46348408290318, 69.7167169025966, 66.94278757912772, 72.77487618582589, 67.64684159415108, 80.23485824040004, 23.743896654673986, 0.7954426939998354, 0.6152224902595792, 2.695145219564438, 1.2039715839283807, 2.997238346508571, 2.0173864449773515, 0.3940012923308781, 0.19759464929146425, 25.805283001491002, 54.29951190948486, 30.129939079284668, 68.16326645442417, 26.001415014266968, 28.975480249949864, 23.66128257342747, 48.623347827366416, 44.70789895738874, 66.11567401885986, 19.408714056015015, 0.13532083587987082, 0.1836591549217701, 0.055619196567152224, 0.09149351263684885, 0.08131513451891285, 0.07695227648530688, 0.026258562225848436, 0.07496488812778677, 0.04835097371999707, 0.0036032927871149567, 0.013567329750263264, 0.12070728146604129, 0.059292506958757124, 0.11728203669190407, 0.07255064696073532, 0.12765044532716274, 0.0326510406365352, 0.07241890938686472, 0.03361019059749586, 0.054957865803901634, 0.037920533413333554, 0.009089547392380024, 0.04118522662403328, 0.1128487806501133, 42.31290354047503, 74.42225238255092, 56.820832524980815, 50.206807545253206, 26.141106809888566, 51.74302298682076, 78.0242680140904, 32.06104843957083, 0.6800894066691399, 0.24951488684330667, 1.4313523599079676, 5.449289330414363, 2.5175492635795047, 1.4082068247454507, 0.3347362253282751, 9.81127417087555, 88.67331341334751, 80.06093788146973, 82.34249005998883, 88.50596605028424, 92.89521258217948, 85.5411627633231, 88.24993882860456, 87.32764189583915, 86.9970257622855, 84.39637756347656, 85.43714823041643, 82.61525549207414, 80.98900181906563, 82.40581594194684, 82.67588547297886, 83.63935048239571, 82.42010838644845, 77.31387724195207, 68.32270676749093, 56.64294127055577, 58.98698902130127, 57.51588862282889, 57.29432794025966, 55.71789632524763, 57.455352442605154, 54.06748723983765, 54.915744168417795, 51.373135634831016, 51.52757671901158, 51.671619824000764, 58.50749383653913, 70.25188105446952, 70.25177683149064, 69.01046030861991, 70.05410058157784, 67.21284321376255, 66.62965311322893, 60.42956706455776, 57.26322085516793, 55.02498722076416, 53.587457043784006, 50.66875505447388, 51.08372231892177, 56.804900305611746, 67.30411475045341, 68.63322871071952, 68.04282638004848, 64.57705102648053, 66.57906327928815, 63.1261351449149, 62.53227261134556, 62.51023292541504, 58.07546179635184, 55.457120009831016, 48.69739130565098, 48.86410985674177, 51.02149772644043, 54.11439452852522, 55.01598235539028, 57.525713375636506, 62.43050929478237, 61.342692375183105, 52.25580351693289, 44.953364917210166, 50.050431387765066, 53.303161076136995, 54.761664390563965, 62.11083657400948, 65.56029755728585, 63.87162821633475, 59.001510756356375, 55.784435749053955, 49.69132416588919, 50.729781082698274, 57.133042880467, 61.56874506814139, 62.15900148664202, 62.86844730377197, 59.89735589708601, 56.11651447841099, 46.53044618879046, 48.91147225243704, 46.054814202444895, 50.96478305544172, 56.40185614994594, 60.6324405670166, 58.041123798915315, 60.19248758043562, 58.37927872794015, 50.00543832778931, 46.25501612254551, 48.21033648082188, 47.43507732663836, 51.07099321910313, 57.642154761723106, 59.770815304347444, 58.556228501456125, 57.02947303227016, 53.23286962509155, 54.865244661058696, 54.73712682723999, 59.96567753383091, 64.55362864903041, 66.53387914385114, 67.18356350490025, 68.28685406276158, 67.16704068865094, 71.04608794621059, 69.22107410430908, 68.88113348824638, 64.92866461617606, 71.91310501098633, 69.75047125135148, 76.00778266361782, 69.4327370779855, 84.6954905646188, 35.357669898441856, 0.3806136335645403, 0.5556002695645604, 1.4449868968554904, 1.6955551143203462, 2.241786769458226, 3.8673269493239264, 1.001095475895064, 0.1763155332633427, 23.565774372645787, 66.51509121486119, 33.88500615528652, 75.52038737705776, 24.47479156085423, 24.71402324948992, 25.456829105104717, 56.74670566831316, 49.91923202787127, 74.45137923104423, 24.199809653418406, 0.32166202259915216, 0.20568879853401864, 0.07424409394817692, 0.14103519996362074, 0.058775843254157474, 0.07799928316048213, 0.017846261483750174, 0.12375675354685102, 0.03481758259502905, 0.004357866560375052, 0.06473472421722752, 0.24672366519059452, 0.16730158909090928, 0.2599053478666714, 0.13808305694588593, 0.249774874321052, 0.21330230071076325, 0.19565025291272573, 0.12015572749078274, 0.19692674013120787, 0.07478953432291746, 0.1264648682304791, 0.20983909868768283, 0.34074853413871353, 50.14595174789429, 82.54040949685233, 64.08932917458671, 56.17721046720232, 41.73972579411098, 77.15753582545689, 83.03398173195976, 45.04147849764143, 0.7698037869163922, 0.3353928029537201, 4.08286224092756, 15.873128414154053, 7.11247615303312, 8.738236938204084, 3.557896307536534, 6.615706443786621, 91.50898442949567, 87.3364313670567, 89.09517329079765, 92.2910736628941, 97.51458345140729, 90.62086568559918, 92.4613948549543, 89.92763001578194, 88.67248657771519, 86.33976786477226, 89.38666411808559, 88.54402828216553, 85.54046099526542, 85.06960936955043, 86.3978270121983, 85.8572919028146, 84.92396817888532, 80.91495486668178, 71.53770773751395, 59.16118035997663, 61.83939824785505, 59.831417492457796, 61.60703659057617, 58.73969568525042, 61.08631774357387, 56.94198131561279, 57.73174136025565, 55.03798730032784, 53.407891273498535, 54.199423108782085, 60.172726903642925, 72.18559946332658, 73.84562138148716, 71.06258991786412, 73.43733828408378, 68.73081615992955, 68.42344869886125, 63.79264109475272, 59.41317762647356, 57.55308927808489, 56.411281381334575, 53.068193844386506, 53.065911361149375, 59.38296685900007, 70.36693627493722, 70.90775626046317, 70.20206941877092, 68.49937861306327, 69.4713829585484, 66.25432532174247, 66.18680272783551, 68.45826612200055, 63.260541098458425, 60.48017079489571, 50.891396181924, 49.3346140725272, 51.5567626271929, 55.430039405822754, 56.48737110410418, 60.235747064862935, 63.335977690560476, 60.197809900556294, 51.449489389147075, 46.696640150887625, 55.141564096723286, 55.24260827473232, 59.09352575029646, 67.93326023646763, 69.28480298178536, 68.9777203968593, 62.93386459350586, 58.49850981576102, 51.065535409109934, 51.33503866195679, 60.350677217756, 64.15832478659493, 66.77787903376988, 66.96512603759766, 63.27483354296003, 56.91529328482491, 49.46529231752668, 52.03548308781215, 49.56853560038975, 54.728382519313264, 59.104823521205354, 64.7201144354684, 61.11924525669643, 64.3262071609497, 60.30974537985665, 51.753573826381135, 50.29296520778111, 52.520873819078716, 49.75438254220145, 56.38109840665545, 61.65790435246059, 63.42128767286028, 60.59765788487026, 60.38308361598423, 56.158568450382774, 57.07115527561733, 57.141999108450754, 62.92204570770264, 67.10019901820591, 70.19437081473214, 70.88642529078892, 72.88280950273786, 70.1230753489903, 74.62097086225236, 72.4033282143729, 72.58906745910645, 67.05091544560024, 74.31795297350202, 71.34901550837925, 80.67797265733991, 73.88961042676652, 89.64975070953369, 31.70203501837594, 1.3962382269757134, 4.196932119982583, 10.180087157658168, 5.15995809010097, 10.39897973196847, 8.455612880843026, 0.6170153969100544, 0.3363929364298071, 33.763937268938335, 71.37090928213937, 43.77198008128575, 82.54859447479248, 38.26566818782261, 39.60955054419381, 33.51790850503104, 65.60926151275635, 57.2759291103908, 83.15800707680839, 28.988176345825195, 0.43407334493739264, 0.31528506906969206, 0.13913625186043127, 0.18784258115504468, 0.15279411684189523, 0.36016698500939776, 0.12281888244407517, 0.2172573727688619, 0.21064893023243972, 0.12324954862041132, 0.10320357499378068], [0.0827673894486257, 0.04478765385491507, 0.01934038711312626, 0.20215413320277417, 0.02266789231050227, 0.038811446500143836, 0.12145833830748286, 0.07509206594633204, 0.06436596757599286, 0.13408522361091205, 0.08342216895627123, 0.03795927097754819, 0.12781998408692224, 29.23763404573713, 70.74868420192173, 53.383708068302695, 48.84587778363909, 48.12160103661673, 69.72850799560547, 52.18688086100987, 14.997316667011805, 0.11230607477149793, 0.20445220917463303, 4.53570066179548, 1.886647186108998, 2.0267984313624243, 0.90642675863845, 5.976730125291007, 95.80908557346889, 69.85707746233258, 77.9029872076852, 85.65779522487095, 87.24541691371373, 82.69087273733956, 86.21556881495884, 82.89496912275041, 84.7974762235369, 81.3985355922154, 82.74324131011963, 81.89169093540737, 78.49152742113385, 75.94232368469238, 75.91588578905377, 76.9713727406093, 78.2959564753941, 78.67942755562919, 77.14642565590995, 70.28090367998395, 59.06409318106515, 55.18469851357596, 54.21827704565865, 53.51828077861241, 52.62201527186802, 54.86746808460781, 52.22335195541382, 49.28978776931763, 48.62108618872506, 49.793938636779785, 49.12143986565726, 53.59167807442801, 65.4067771094186, 64.20776121956962, 69.94577121734619, 64.8410895211356, 64.81492260524205, 59.23092637743269, 60.440566062927246, 55.07256848471505, 53.59334911618914, 53.49916281018938, 49.135106972285676, 47.32587248938424, 55.63899605614798, 60.1020359311785, 64.86824308122907, 62.77714797428676, 64.28756822858537, 61.94230106898716, 64.83496815817696, 61.346430506025044, 54.75600855691092, 52.407416684286936, 47.03661898204258, 48.05297367913382, 51.18403346197945, 52.22109726497105, 55.72108902250017, 54.593566622052876, 57.89738641466413, 59.677639961242676, 62.27040195465088, 60.876544679914204, 52.686821120125906, 40.81713356290545, 49.41242694854736, 49.5576616695949, 51.69189814158848, 59.783113615853445, 60.74715532575335, 56.57031175068447, 57.237279755728586, 54.47582939692906, 55.90046719142369, 58.34720584324428, 59.01471928187779, 57.84936741420201, 57.989992005484446, 57.93021665300642, 57.7751259122576, 50.17029823575701, 44.030015332358225, 45.55531167984009, 45.444258621760774, 48.14805282865252, 54.644441332135884, 55.01161888667515, 57.043418066842214, 54.93154089791434, 47.436946392059326, 42.996766090393066, 43.42570270810808, 44.018821784428184, 46.025152342660085, 54.476409571511404, 56.03009973253523, 56.94707087108067, 52.96730252674648, 52.56860099520002, 52.97365665435791, 56.48945556368147, 62.309930256434846, 65.62508256094796, 63.6521554674421, 63.557361194065635, 64.00952911376953, 69.7685296194894, 63.25170298985073, 65.76122556413922, 63.355536869594026, 68.63417366572789, 66.27048683166504, 72.49767085484096, 64.9027408872332, 70.96530818939209, 66.71597753252301, 70.65657888139997, 12.146722657339913, 1.2221734757934297, 1.0435114055871964, 2.804698118141719, 1.00918567606381, 1.8728715138775962, 0.2882548395012106, 0.16731083073786326, 6.241465611117227, 69.71739782605852, 35.09999247959682, 48.72036899839129, 43.548362731933594, 42.67365401131766, 24.721652371542795, 37.20926059995379, 48.33881562096732, 58.681038992745535, 23.515457255499705, 0.2059901495065008, 0.0917265894157546, 0.06835058983415365, 0.056386249871658425, 0.0704696886241436, 0.0554986751771399, 0.047286057113004584, 0.05489528451913169, 0.059246956902955256, 0.05449292003842337, 0.03421947433214102, 0.08660700198795114, 0.04968081075432045, 0.07888436423880713, 0.1246736172054495, 0.018322452270824994, 0.05154560479734625, 0.040611789894423315, 0.09027648544205086, 0.05734830056982381, 0.11218942781644207, 0.05476343159430793, 0.04403530779693808, 0.10682789515703917, 38.71549456460135, 80.12669563293457, 57.297322613852366, 62.638503619602744, 48.154653617313926, 69.28837435586112, 61.89421953473772, 15.48540677343096, 0.03448748548648187, 0.3941554826285158, 8.293027639389038, 4.792731029646737, 1.192853489092418, 0.21913535413997515, 11.062939167022705, 101.40692956107003, 75.65873990740094, 86.30989755902971, 87.69670936039516, 90.03705024719238, 85.90431731087821, 88.18113776615688, 84.29626791817802, 87.44191891806466, 82.96659810202462, 84.06025845663888, 84.7435165132795, 81.17729800088065, 78.33048207419259, 78.50014318738664, 80.12426376342773, 82.0293139048985, 81.79959256308419, 79.22623688834054, 72.37339537484306, 61.50193813868931, 57.49176795142037, 57.395962715148926, 55.62882041931152, 55.26777465002877, 57.597033160073416, 54.08283233642578, 50.956639766693115, 50.748596804482595, 51.31741108213152, 53.08808306285313, 56.62529632023403, 66.40818623134068, 66.75086443764823, 72.12896469661167, 68.97774818965367, 68.0504207611084, 63.83705398014614, 62.903931753976, 59.220976557050435, 55.5809577533177, 55.627396038600374, 50.42848287309919, 48.94935730525425, 57.58732305254255, 63.54573685782296, 66.33532047271729, 66.45264080592564, 66.30813217163086, 63.71458503178188, 67.74825055258614, 63.3415709904262, 57.575267927987234, 53.05224078042166, 48.09510408129011, 49.290875162397114, 51.49396480832781, 54.54456097739083, 58.910433769226074, 59.110097203935894, 61.756485394069124, 62.15285927908761, 64.73704024723598, 62.428105218069895, 53.19762488773891, 42.93544476372855, 51.64101300920759, 54.302471842084614, 54.84577233450753, 62.30544866834368, 62.44606631142752, 60.87127794538225, 59.3096216746739, 57.87300171170916, 59.090503283909385, 59.893895694187705, 61.73862852369036, 60.85012762887137, 58.86554840632847, 59.53377750941685, 59.732905932835166, 54.78067118780953, 46.36741713115147, 47.72702326093401, 47.82036188670567, 52.42411320550101, 55.56160354614258, 57.700484888894216, 60.050591468811035, 56.321458544049946, 50.79102597917829, 46.36759778431484, 47.78374835423061, 46.53196784428188, 47.909267561776296, 56.82342420305525, 59.49341542380196, 58.392535890851704, 56.06173488071987, 54.89299576623099, 56.95804902485439, 60.24619715554373, 66.41531508309501, 68.94602271488735, 65.77319731031145, 67.30032798222133, 65.55908162253243, 71.41899081638881, 65.20757920401437, 66.28505025591168, 64.0180892944336, 70.9354031426566, 69.29700401851109, 73.02674838474819, 67.30053642817906, 73.85723876953125, 68.84316853114537, 75.85189982822963, 18.837210825511388, 0.5812826571719987, 0.7625579557248524, 2.291357389518193, 3.286553953375135, 2.806435384920665, 1.4671100697347095, 0.18472684334431375, 5.441777893475123, 76.40312126704625, 42.79077632086617, 54.49852916172573, 43.26500824519566, 32.65115894590105, 34.34018611907959, 44.48261056627546, 55.692542348589214, 66.13882541656494, 29.425443853650773, 0.23117935072098458, 0.20628455228039197, 0.09759082831442356, 0.11423284959580217, 0.11472223619265215, 0.05718452935772283, 0.08627498801797628, 0.005884684006949621, 0.040338659193366766, 0.048383499296115975, 0.04715277247929147, 0.15905399593923772, 0.1422218762870346, 0.10068100571100201, 0.2667829788156918, 0.13168766083461897, 0.10106823207544428, 0.2929006330668926, 0.12979982713503496, 0.13552318859313214, 0.18684764525720052, 0.1629584085728441, 0.21500830059604986, 0.3423027050282274, 47.85519320624215, 86.32387038639614, 67.04197311401367, 60.984874044145855, 68.86544445582798, 87.74202551160539, 71.12158707209996, 23.90373648915972, 0.18472364065902575, 0.6780297000493322, 13.493247934750148, 7.945309383528573, 9.643023541995458, 6.155363968440464, 8.375309075628008, 106.3778097970145, 82.308700970241, 90.1380284173148, 91.18502467019218, 94.66921275002616, 87.83181013379777, 91.31375394548688, 87.40686525617326, 92.72946330479213, 86.30285208565849, 89.25303636278424, 88.47720050811768, 84.32661764962333, 80.67854240962437, 83.13933726719448, 81.94134971073696, 84.7667304447719, 84.4838136945452, 83.44482871464321, 74.84566865648542, 64.6988251549857, 59.39040837969099, 60.599770137241904, 59.402400970458984, 59.388740812029155, 59.73914541516985, 56.45783083779471, 54.8474885395595, 54.73254449026925, 54.80993700027466, 55.623376505715505, 59.006381443568635, 70.73617744445801, 70.4993758882795, 73.69463702610561, 71.06471606663295, 69.7419319152832, 67.21036965506417, 67.18439728873116, 60.96193109239851, 57.77347918919155, 60.283647945949006, 52.85487025124686, 52.27244445255825, 61.039069993155344, 65.30448572976249, 70.87955352238247, 68.57026413508824, 68.75105626242501, 66.81573976789201, 72.30162743159703, 66.5614287512643, 61.48363658360073, 58.580470766339985, 50.37440504346575, 48.55341420854841, 51.941175188337056, 54.35862718309675, 58.5735364641462, 61.07515198843819, 64.16430023738316, 66.52531896318708, 67.31212602342877, 64.63789640154157, 54.18123619897025, 46.354354517800466, 57.13779892240252, 55.54478543145316, 59.0962563923427, 64.37298243386405, 64.65541281018938, 61.59243842533657, 65.31010682242257, 59.739610944475444, 62.11742346627371, 62.402438572474885, 64.48583507537842, 62.8832608631679, 62.65269878932408, 63.02619225638253, 63.325472014290945, 56.28287519727434, 48.099703788757324, 51.359089851379395, 50.884677273886545, 54.262630871364046, 60.93794591086251, 59.60387093680245, 64.34529386247907, 59.52785069601876, 53.13332973207746, 49.63617631367275, 51.08147457667759, 48.77657297679356, 50.616153717041016, 60.52503531319754, 62.668151582990376, 61.19227082388741, 60.740165437970845, 59.67563888004848, 59.32986177716936, 62.26716409410749, 68.79977703094482, 72.94056292942592, 68.5807420185634, 70.80984919411796, 69.38769885471889, 73.74016162327358, 67.61930588313511, 70.02482782091413, 67.39713028499058, 73.18242277417863, 72.31420367104667, 77.41740540095738, 70.75061580113002, 78.80533586229596, 72.16567897796631, 80.83502279009137, 17.922697612217494, 3.3190550208091736, 4.758596701281411, 7.342019881520953, 4.966899352414267, 8.026985457965306, 1.1144213548728397, 0.2716055986072336, 9.036855748721532, 85.47151402064732, 48.75360223225185, 63.12296676635742, 57.9983993257795, 56.266692842756, 36.533364159720286, 49.41288552965437, 63.60399750300816, 76.75085776192802, 35.43677166530064, 0.35856281965970993, 0.31293074254478725, 0.20111514681151935, 0.2407189288309642, 0.2084283565304109, 0.1452372180564063, 0.1918597798794508, 0.13519040787858622, 0.17118818339492592, 0.10550680104643106, 0.08129236288368702], [0.08799558319151402, 0.038501237252993245, 0.11222392453679017, 0.08790215570479631, 0.09701058587857656, 0.11511471441813878, 0.043964299107236524, 0.12440441522215094, 0.03924300155735441, 0.14010039583912917, 0.07140068616718054, 0.05090291339105793, 0.028670428520334617, 31.920541967664445, 58.0091620853969, 49.54927519389561, 28.435389825275966, 45.52858195986067, 60.530850955418174, 40.334674971444265, 5.873986678464072, 0.059723125637641976, 0.32134533673524857, 1.3876800004925047, 1.4680896571704318, 2.0797495671680997, 2.7516646896089827, 80.121915272304, 68.09950283595494, 75.31835460662842, 91.64742728642055, 80.9440678187779, 86.29800919124058, 82.24984277997697, 82.35652542114258, 77.58423164912632, 80.51673970903668, 78.99882929665702, 81.2207589830671, 79.1490979875837, 78.58494595118931, 71.61017744881767, 69.93516826629639, 76.06896850040981, 78.41931479317802, 74.80777318137032, 76.30456107003349, 68.64973763057164, 58.362658636910574, 55.410282203129356, 51.45311287471226, 54.175865241459434, 52.49416841779436, 52.21550049100603, 52.4623943056379, 46.99038566861834, 47.59701899119786, 49.28768246514456, 49.75191593170166, 55.125413009098594, 65.71076079777309, 64.42061928340367, 67.16398348127092, 63.40717588152204, 64.92824077606201, 61.43885544368199, 61.4308511189052, 59.68410873413086, 60.400544439043315, 52.79246153150286, 49.384526457105366, 45.73566607066563, 53.603490012032644, 55.95068529673985, 58.81647327968052, 60.24195180620466, 61.61711147853306, 61.50300816127232, 56.24385411398751, 51.92824459075928, 50.16227306638445, 47.777456760406494, 47.42041662761143, 53.734209946223665, 51.96569538116455, 58.303619793483186, 60.04657541002546, 58.00948517663138, 57.28864083971296, 59.44559792109898, 58.188634055001394, 59.5919964654105, 59.64067554473877, 46.55429935455322, 44.82319736480713, 54.38185848508562, 50.76897587094988, 54.791565963200156, 61.12851415361677, 60.930156980242046, 57.608970165252686, 58.66646862030029, 58.110876764569966, 59.39519568852016, 60.85463006155831, 57.68601179122925, 56.34559311185564, 57.9939420563834, 58.935190200805664, 54.183105264391216, 47.48419761657715, 43.96249621255057, 45.142526149749756, 45.58621031897408, 51.696994645254954, 54.671994413648335, 55.837592942374094, 56.5659830229623, 50.04279184341431, 43.332516942705425, 43.81192874908447, 45.13103035518101, 46.534681115831646, 50.88833202634539, 54.83804941177368, 55.324239185878206, 53.58590064729963, 52.595219544001985, 58.06316001074654, 60.93959263392857, 63.1009201322283, 63.245560782296316, 63.27859251839774, 64.43247291019985, 66.61378342764718, 63.315626416887554, 65.56105491093227, 66.73669011252267, 69.45723642621721, 66.62842328207833, 67.43583175114223, 64.49541664123535, 65.32196739741734, 63.10747923169817, 74.35299968719482, 60.53434589930943, 47.4820054599217, 2.177472940513066, 1.14157925759043, 1.1232192942074366, 0.7570757184709821, 1.0828704535961151, 1.620075095977102, 0.06038743856229952, 0.2146919947117567, 50.65325014931815, 56.950986180986675, 40.789649963378906, 48.70099394662039, 34.50033514840262, 21.10802456310817, 32.13329928261893, 50.717906611306326, 63.137280055454795, 21.955432074410574, 0.13160291181078979, 0.21792916314942495, 0.08155595338238136, 0.0676019892894796, 0.02066441928036511, 0.04484717155407582, 0.11417581194213458, 0.10245981240378958, 0.06574491358229093, 0.12221364277814116, 0.07062620629689523, 0.032027490703122954, 0.015725632597293173, 0.022951423257057155, 0.008067838199037527, 0.11232996598950454, 0.08756642336291925, 0.039367017402712784, 0.07411302133862462, 0.0522130796951907, 0.03208908811211586, 0.07716965196388108, 0.03451929520815611, 0.019199604667457085, 42.93906477519444, 66.05065972464425, 54.648867334638325, 30.95740004948207, 32.95825890132359, 64.53368037087577, 48.09996782030378, 5.99439548594611, 0.3602140481982912, 2.8306452972548346, 2.831773945263454, 0.9116718343326023, 0.5982074375663484, 4.843813751425062, 90.21824537004743, 74.9365233012608, 85.02020072937012, 89.88448170253209, 85.43797506604875, 86.04739461626325, 86.1077744620187, 82.02228232792446, 81.28257015773228, 83.17735086168561, 79.77112851824079, 83.60648550306047, 81.14448860713414, 79.18121256147111, 73.86015701293945, 70.9685252053397, 78.3151057107108, 81.09077208382743, 77.67398847852434, 77.09094429016113, 71.93994590214321, 59.07480730329241, 58.099905558994834, 55.75864403588431, 56.69523688725063, 55.63216597693307, 56.55770077024187, 54.10059193202427, 50.832881927490234, 50.32288415091378, 52.72468185424805, 51.28947932379586, 57.77983679090227, 66.91277136121477, 67.91382612500871, 69.75363962990897, 66.04525402614048, 67.52888897487095, 65.88678646087646, 64.92602430071149, 62.0225110735212, 61.8416633605957, 57.78445039476667, 53.9308648109436, 49.362667424338206, 54.709254128592356, 57.87368263517107, 61.9981506892613, 63.01164272853306, 62.77416024889265, 63.820628438677105, 58.01716641017369, 54.29424170085362, 53.878958293369834, 49.73726218087332, 48.43469728742327, 55.027974946158274, 53.54962410245623, 61.23654474530901, 61.88228252955845, 62.48426055908203, 62.38937595912388, 61.96819005693708, 60.180675642830984, 60.366929054260254, 60.5274532863072, 47.85019745145525, 47.36086361748831, 56.655510561806814, 54.444444383893696, 58.05768830435616, 61.13155746459961, 64.35622337886265, 61.3361610685076, 61.33627918788365, 61.67581680842808, 62.48238454546247, 63.18626485552107, 60.799308504377095, 59.472355433872764, 59.19114099230085, 59.525411878313335, 57.11553342001778, 50.22328519821167, 45.31545639038086, 47.58214289801461, 49.68608522415161, 53.2150787625994, 56.66461270196097, 57.6522331237793, 59.428658212934224, 52.039582524980815, 46.22394377844674, 47.794479846954346, 46.95717327935355, 48.5212162562779, 52.827556882585796, 57.626309394836426, 57.262136936187744, 56.71683883666992, 55.64397096633911, 62.15925856998989, 65.49950776781354, 65.75493049621582, 65.0511474609375, 66.757493019104, 65.75181770324707, 68.22639778682164, 64.51802607945034, 68.24903501783098, 70.94242777143205, 72.06047630310059, 70.0396066393171, 68.98020090375627, 66.26467813764299, 66.21681894574846, 64.88147939954484, 76.32159805297852, 67.6312289919172, 56.410850593021934, 5.304017697061811, 1.250419748680932, 0.33016995606677874, 1.8155108775411333, 2.1742828488349915, 2.238317664180483, 0.03599862029243793, 0.08282682233090911, 51.63659742900303, 66.33895438058036, 49.169733319963726, 51.967234407152446, 28.06081243923732, 24.655847719737462, 39.16028349740164, 54.719130992889404, 70.71678502219063, 25.663289615086146, 0.10725647823086806, 0.17671719885298184, 0.06576590067041771, 0.15827777901930468, 0.04078001229624663, 0.06677640216158968, 0.04934408775131617, 0.07862043447260346, 0.05446964628728373, 0.04211620381101966, 0.02989683985444052, 0.11602503699915749, 0.10662501318646328, 0.07565896838371243, 0.10894512119037764, 0.1655872432248933, 0.17945476195641927, 0.1275477558374405, 0.20662303268909454, 0.09455212458435978, 0.24484037767563546, 0.09420304545866591, 0.21422470121511392, 0.14378022695226328, 50.574648652757915, 74.83801868983677, 64.66676616668701, 35.805561201913015, 63.304120200020925, 76.20482662745884, 60.05350971221924, 9.138566953795296, 0.3909570313990116, 2.320562405245645, 5.237260273524693, 5.120356832231794, 5.956044903823307, 3.9283290931156705, 90.80493041447231, 81.32877567836216, 84.70136874062675, 95.33289773123605, 88.95898859841483, 89.61996378217424, 87.82151985168457, 86.6078154700143, 84.79910210200718, 87.80687999725342, 82.43205233982631, 88.71850449698312, 83.7011616570609, 85.45612376076835, 78.54921831403459, 74.5835131236485, 82.9210318156651, 82.5046888078962, 81.47810636247907, 80.8337790625436, 75.06163951328823, 63.30300154004778, 61.599115644182476, 57.84247480119978, 58.8592255456107, 59.497653824942454, 59.789742197309224, 57.43911797659737, 52.75781086512974, 53.43670197895595, 54.17844649723598, 55.30643790108817, 60.25177655901228, 72.7724860055106, 70.181565284729, 73.49776676722935, 68.06153787885393, 71.66101741790771, 69.61239664895194, 67.85394654955182, 64.23064163752964, 64.25038146972656, 59.116753578186035, 56.08873210634504, 51.463278089250835, 60.84994002750942, 62.92393561771938, 64.73141915457589, 67.53936685834611, 67.86100591932023, 67.27087456839425, 59.89683478219168, 57.59578595842634, 57.00256960732596, 52.42438071114676, 50.4547574860709, 55.56290980747768, 54.20286594118391, 62.601469721112935, 64.01569216591972, 63.902283668518066, 62.75616441454206, 63.990942682538716, 62.621682030814036, 63.692705154418945, 63.78943797520229, 49.242821420942036, 50.89318881716047, 61.99808815547398, 57.213652406420024, 65.0182546888079, 66.51580687931606, 67.00115939549038, 64.31024714878627, 65.09978485107422, 65.43461159297398, 64.42762306758335, 67.4136322566441, 64.36522129603794, 61.11541679927281, 63.04238850729806, 64.71629292624337, 59.863677978515625, 54.2289251599993, 48.871985639844624, 50.172514711107524, 53.13843665804182, 56.452254908425466, 61.61611788613455, 62.045857020786826, 64.71853719438825, 55.54200267791748, 48.190815516880576, 50.37769501549857, 48.03205265317644, 51.1185953276498, 56.01511941637312, 61.2395533152989, 62.23758561270577, 59.902532305036274, 58.046407903943745, 65.77364199502128, 68.20544896806989, 69.41007900238037, 67.39512920379639, 70.10251562935966, 69.43490491594586, 70.64132063729423, 67.76698289598737, 70.69850431169782, 73.99410438537598, 75.77925641196114, 72.70744391850063, 74.383606501988, 70.02594648088727, 71.04048074994768, 67.63091632298061, 81.12633991241455, 68.09862041473389, 59.26878711155483, 4.570253619125911, 3.636255702802113, 5.40720192023686, 4.09499249288014, 4.48056366613933, 5.235310435295105, 0.21503389493695327, 0.6641443222761154, 61.26087038857596, 71.25930036817277, 58.309991291591096, 61.50350843157087, 47.32262420654297, 28.503801788602555, 46.480905532836914, 62.98405838012695, 80.86717210497174, 33.801429748535156, 0.3147268518805504, 0.3193662943584578, 0.24425436769212994, 0.22879386586802347, 0.20121399579303606, 0.20472945858325275, 0.20538132717566832, 0.14801262984318392, 0.20139614173344203, 0.1479884332844189, 0.08313920628279448], [0.10421980332051005, 0.04181779768051846, 0.10388639156839677, 0.017176011377679448, 0.028982401958533695, 0.02654708719014057, 0.04385972668283752, 0.023044223098882606, 0.042902286630123854, 0.024890527062650238, 0.059838245888905864, 0.05380989990330168, 0.3101133294403553, 45.04422651018415, 59.28670651572091, 43.68085445676531, 44.082554136003765, 65.94745118277413, 64.2831005368914, 24.69828384263175, 0.6702981463500431, 0.0748900728566306, 0.8504690613065446, 4.9428029997008185, 1.0060856938362122, 0.26907262738261906, 59.46920095171247, 73.60280963352749, 84.15338516235352, 94.73261506216866, 78.30753217424665, 89.2450042452131, 84.87367016928536, 82.60622978210449, 80.00486591884068, 74.04404108864921, 72.31421756744385, 75.29894133976528, 73.96570014953613, 74.8696677344186, 75.10410690307617, 68.28792408534459, 68.31083924429757, 75.2090733391898, 74.246490750994, 76.19529369899205, 75.13150365012032, 70.45745045798165, 56.54587146214077, 55.03748008183071, 52.08375917162214, 53.65404510498047, 53.33518532344273, 53.14261252539498, 48.82521731512887, 48.251983983176096, 49.004918575286865, 50.12881401606968, 49.2516873223441, 57.227423736027305, 63.324804987226216, 63.22083214351109, 66.87790530068534, 61.03553336007254, 63.865263666425435, 60.71619415283203, 64.64817278725761, 61.92861311776297, 58.19975812094552, 51.47576747621809, 48.3632698059082, 46.481332847050254, 47.842814990452354, 55.14232839856829, 56.325245312282014, 61.44709600721087, 58.56415639604841, 62.357608795166016, 57.81043318339756, 45.51535258974348, 46.86444609505789, 47.83967440468924, 59.16919163295201, 56.14057609013149, 57.670180320739746, 59.364825112479075, 57.05969769614083, 61.10883685520717, 58.01940720421927, 57.3484822000776, 59.56541960580008, 61.07488100869315, 59.082109860011506, 53.42993095942906, 46.27903257097517, 45.070622716631206, 50.16642461504255, 54.44237034661429, 57.70607124056135, 57.922556264059885, 61.50901140485491, 58.74107142857143, 57.972197668892996, 59.28162043435233, 58.137929575783865, 57.02553687776838, 57.406259945460725, 59.87009116581508, 56.77754872185843, 54.92718437739781, 50.22469220842634, 45.942736285073416, 45.747144494737896, 46.25962277821132, 46.40845319202968, 52.707683086395264, 54.34454665865217, 54.522406646183555, 48.77525976725987, 44.19626835414341, 42.83389336722237, 44.530858857291086, 44.21192264556885, 49.040712220328196, 53.59683016368321, 54.28124509538923, 54.519811494009836, 57.010678155081614, 60.09859657287598, 60.40785394396101, 62.09677342006138, 63.94919095720564, 62.75972189222063, 63.24175316946847, 63.81027562277657, 65.83322974613735, 65.02479989188058, 63.02435098375593, 63.309762137276785, 63.6292542048863, 58.96476868220738, 58.995875767299104, 60.41223130907331, 63.12807369232178, 67.7676499230521, 71.15124893188477, 70.58053084782192, 32.33143411363874, 0.04392161925456353, 0.9248747144426618, 3.0145252474716733, 1.8092653155326843, 2.177764981985092, 0.3214046135544777, 0.18708000278898648, 19.89791587420872, 71.27468367985317, 38.93267093385969, 52.56041949135916, 42.85619361060006, 28.904929978506907, 38.83940873827253, 45.1912191254752, 58.60602624075753, 15.22888101850237, 0.0715630595971431, 0.1760618697319712, 0.04613826423883438, 0.17218208791954176, 0.06593438770089831, 0.026223994259323393, 0.012190502469560929, 0.0021900472597086, 0.022145338921940753, 0.1447056672934975, 0.03818248185728278, 0.077270801179111, 0.052879736958337684, 0.03705060062929988, 0.013114979291068656, 0.11023697722703218, 0.010710066284186073, 0.051628738907831054, 0.06490137920315776, 0.02104413935116359, 0.024476829350792935, 0.06900695711374283, 0.054415950418582985, 0.5570070626480239, 55.14330462047032, 64.95603357042584, 55.6512040410723, 39.98366240092686, 59.89274229322161, 73.18000480106899, 30.011124883379253, 0.28578926037464825, 0.03429320055459227, 4.608221181801387, 5.515232077666691, 0.9260663305010114, 0.6810237765312195, 69.14376844678605, 78.84268242972237, 89.85911382947648, 94.58138751983643, 85.71180357251848, 90.25343799591064, 87.19038718087333, 85.63089179992676, 82.60954407283238, 75.45728383745465, 75.74582168034145, 78.02767957959855, 79.00176838466099, 77.62872096470424, 75.7709046772548, 71.03274045671735, 71.55685002463204, 74.66555050441197, 77.26856803894043, 78.92845794132778, 76.08971582140241, 73.42885453360421, 59.584332602364675, 56.833318437848774, 54.79802778788975, 55.92276396070208, 55.76796851839338, 55.382878507886616, 51.28464685167585, 49.842041015625, 50.25977713721139, 52.401635783059255, 51.474106856754844, 59.05349717821394, 66.91823264530727, 67.50791931152344, 68.83245440891811, 63.78690883091518, 66.45596204485211, 64.51610837663922, 65.77731759207589, 64.48642567225865, 58.97135557447161, 53.83151599339077, 51.22647305897304, 50.13386883054461, 51.87158203125, 57.31232030051095, 60.59904752458845, 62.90911511012486, 62.42149748120989, 64.80509090423584, 59.748650550842285, 49.12485490526472, 49.607768603733604, 49.80756058011736, 62.30175917489188, 58.277633530753, 59.713457924979075, 62.84234292166573, 60.95150184631348, 64.24017456599644, 59.815999439784456, 59.44201265062605, 60.566578592572895, 62.90556458064488, 60.83637714385986, 55.54713044847761, 48.77242142813546, 47.60721547263009, 53.27010154724121, 56.54975203105381, 59.97901112692696, 59.12541798182896, 63.596062660217285, 60.714755875723704, 61.1019720349993, 61.987186431884766, 60.87282739366804, 60.14241191319057, 60.62933472224644, 61.02365888868059, 58.78508826664516, 57.93175220489502, 52.022107805524556, 49.448425565447124, 47.60809094565255, 50.088778495788574, 49.89150524139404, 55.95382588250296, 56.73922940662929, 56.9943186214992, 52.22356040137154, 47.3717097554888, 44.749240739004954, 46.68741989135742, 46.704984937395366, 51.451744079589844, 54.167027132851736, 57.000353131975444, 57.42438084738595, 61.10248620169503, 63.305989265441895, 64.39215251377651, 65.7390330178397, 65.4932335444859, 65.87905311584473, 66.07472133636475, 67.20460959843227, 68.73865372794015, 65.5492638179234, 65.68776226043701, 63.82415117536272, 64.20546831403459, 63.02979142325265, 60.92786407470703, 61.778010913303916, 66.08335099901471, 66.94604628426688, 72.72988659994942, 74.33697714124406, 41.34707614353725, 0.20247665446783814, 0.4683074450918606, 0.09367985424718686, 3.456527735505785, 3.804080537387303, 0.5754095294645855, 0.1929886450192758, 20.285547188350133, 79.83423900604248, 47.22822598048619, 54.731272969927105, 33.82451513835362, 27.606895310538157, 45.03684057508196, 48.67204427719116, 67.44027165004185, 19.642270803451538, 0.2957872567432267, 0.1569469411458288, 0.04773719808352845, 0.016029665479436517, 0.03816238025735531, 0.06398414235029902, 0.016888195482481803, 0.023478419353653277, 0.038347108023507256, 0.09092958896820034, 0.0211366355485682, 0.12319982557424478, 0.14456567194844994, 0.1474821511656046, 0.1852243316492864, 0.14385258592665195, 0.1627981657428401, 0.08763637353799172, 0.09065717751426355, 0.19993501156568527, 0.1261638565255063, 0.15990668375577244, 0.2836858018168381, 0.7001749117459569, 62.99657208578927, 75.17900153568813, 58.459947313581196, 57.61345870154244, 89.5064788545881, 80.26288727351597, 40.78190619604928, 0.7944456817848342, 0.14043504931032658, 5.34701097863061, 11.294397558484759, 9.042335271835327, 0.6451875194907188, 69.61074992588588, 82.68474442618233, 91.24870491027832, 100.36096858978271, 87.56444345201764, 93.71130629948208, 89.15781824929374, 88.13423742566789, 86.9350061416626, 79.11317580086845, 78.7861657823835, 80.54394885471889, 80.23057815006801, 79.8196130480085, 78.63985756465367, 73.72404875074113, 76.03244876861572, 79.01157924107143, 81.33275699615479, 82.14330605098179, 80.61475794655937, 75.52623081207275, 62.41878768375942, 61.13740784781319, 57.18088470186506, 57.92635692868914, 59.61753804343087, 58.87965324946812, 53.71862513678414, 53.41646882465908, 55.18024819237845, 54.73348249707903, 54.133161612919395, 64.71566758837018, 69.2450384412493, 71.65006010872978, 71.29211671011788, 64.67526381356376, 69.7784377506801, 65.28045191083635, 66.22952720097133, 67.9041472843715, 63.15104443686349, 57.83883741923741, 54.91088390350342, 52.79767268044608, 54.1250878061567, 61.283549308776855, 62.5617607661656, 67.31437723977226, 64.18653447287423, 66.32006222861153, 61.33584145137242, 51.8455992426191, 53.661931310381206, 51.937134810856406, 64.12597397395542, 58.020303521837505, 59.57464681352888, 65.80035781860352, 63.84610053471157, 67.70891680036272, 61.67768587384905, 61.870116233825684, 63.59490925925118, 67.3599991117205, 63.42492158072335, 55.97849893569946, 49.735070024217876, 53.031027930123464, 57.075275557381765, 60.48380470275879, 63.96806921277727, 62.43251732417515, 66.34520775931222, 64.61798981257847, 63.78838184901646, 64.3339682987758, 64.53992680140904, 63.86243574959891, 63.12352957044329, 65.59687287466866, 62.702538217817036, 60.49590151650565, 53.961520263126914, 51.63976233346121, 51.41920566558838, 51.663525172642295, 52.540245396750315, 58.472704206194194, 60.64024339403425, 61.032990319388254, 56.19329554694039, 49.73310368401663, 47.66224520547049, 49.1141095161438, 48.770059040614534, 54.03478206907, 59.30878789084298, 60.13873631613595, 62.066652979169575, 63.691718510219026, 66.54639284951347, 66.44611644744873, 66.82387610844204, 68.0522689819336, 68.55147620609829, 70.16053308759416, 70.7703834261213, 73.22531400408063, 70.6895272391183, 68.33322634015764, 69.14862523760114, 69.57659258161272, 64.82941654750279, 64.87075138092041, 65.27808952331543, 70.35971014840263, 71.40637288774762, 79.14397716522217, 74.97660745893205, 43.971462862832205, 0.3256533012858459, 3.4431939252785275, 5.6189391527857095, 7.555619665554591, 6.728437057563236, 0.6631664176072393, 0.2823591301483767, 26.84058369909014, 88.26450225285122, 52.99378905977522, 66.52762576511928, 56.07768447058541, 40.10320963178362, 50.20593554633004, 58.70851911817278, 73.3022027696882, 27.289214985711233, 0.42062763071485926, 0.2738209883017199, 0.0958739582981382, 0.3755696213671139, 0.2147703112236091, 0.11404748739940779, 0.08856895206762211, 0.0864990334957838, 0.17909496197743074, 0.13903206959366798, 0.11654700684760298], [0.11151054674493414, 0.034070793738854785, 0.06524784596902983, 0.10028573192123856, 0.08835817194942917, 0.08969999530485698, 0.021590190407420908, 0.08249983630542244, 0.03370893101340958, 0.019105914248419658, 0.0906653402905379, 0.1577498244919947, 1.5717136796031679, 54.40566996165684, 53.89993837901524, 35.92464290346418, 20.023450715201243, 51.38504832131522, 46.56473902293614, 13.330866796629769, 0.11302644147404603, 0.5821903741785458, 2.0670365350587026, 1.4165909120014735, 1.8132860426391875, 24.5024471282959, 85.6877350125994, 79.75046457563127, 88.30528123038155, 81.88433974129813, 92.36691325051444, 81.35588754926408, 88.23072705950055, 83.61985383714948, 81.8395516531808, 74.9790323802403, 69.89690453665597, 69.68238585335868, 74.55977807726178, 72.8239026750837, 72.08703231811523, 69.75767653329032, 67.60322080339704, 69.97657258169991, 76.16561794281006, 75.73645550864083, 72.70038454873222, 66.11538914271763, 55.90729379653931, 52.84629964828491, 52.25873565673828, 49.740572997501914, 52.70856203351702, 50.23480183737618, 49.380399227142334, 48.46685355050223, 47.59631027494158, 47.76496042524065, 49.78536803381783, 59.692113058907644, 64.14688805171421, 62.71875531332833, 64.37008503505162, 64.4029847553798, 63.83504595075335, 64.88908767700195, 61.17322581154959, 57.62903308868408, 53.55958434513637, 48.85633134841919, 45.73846966879708, 47.73218924658639, 52.21279764175415, 58.4597875050136, 59.17082445962088, 58.75543335505894, 56.551117352076936, 58.94912133898054, 60.16555636269705, 51.19954878943307, 46.35758890424456, 53.15832935060774, 58.82529749189104, 56.333117621285574, 60.413294383457725, 57.83274037497384, 57.42336641039167, 58.29364218030657, 56.43694107873099, 56.95199366978237, 56.22635507583618, 54.92645481654576, 57.78826148169381, 57.086972849709646, 54.86698865890503, 47.67002023969378, 47.890754086630686, 54.58192491531372, 54.10775899887085, 55.040443488529746, 57.03415959221976, 56.28701284953526, 56.94809225627354, 56.77186162131173, 54.31813308170864, 53.604639938899446, 56.41090617861067, 59.067907742091585, 58.1324474470956, 56.72899471010481, 52.73429121289934, 50.07951307296753, 47.966110774448936, 47.18172516141619, 47.18388952527727, 48.74416657856533, 50.98450551714216, 50.39507246017456, 46.9632112639291, 40.93303646360125, 43.1968811580113, 46.219535146440776, 43.782072339739116, 45.95944322858538, 51.98241622107369, 55.426172733306885, 55.806506701878135, 60.97026893070766, 61.707618713378906, 63.23097651345389, 62.99202101571219, 63.3400354385376, 63.322574615478516, 64.30432728358677, 62.06597900390625, 62.622501918247764, 56.77754177365984, 57.115081787109375, 56.26471260615757, 53.215120451790945, 52.19173417772566, 55.39454800742013, 57.04143435614449, 64.76178278241838, 65.07317325047084, 68.86479827335903, 65.14155742100307, 65.29072829655239, 10.392352887562343, 0.6839596075671059, 0.6739104496581214, 1.6189875943320138, 1.0245394579001834, 0.5877279256071363, 0.11968486489994185, 3.108545230967658, 65.87225082942417, 52.04916409083775, 47.410970551627024, 61.12774290357317, 27.978118453707012, 29.36933020183018, 44.07007169723511, 59.14497716086251, 19.05572819709778, 0.12249265637780939, 0.14817895234695502, 0.02529515785032085, 0.03469666086935571, 0.06879249255039863, 0.035223370284906456, 0.0517164192029408, 0.10866743073399578, 0.0912287211311715, 0.15300215567861283, 0.05563976974891765, 0.1292506887444428, 0.08408390344785792, 0.0711490853822657, 0.10191026689218623, 0.051530286869300265, 0.03491440614951508, 0.03944923888359751, 0.090570304675826, 0.03667600519422974, 0.02057181791003261, 0.12858039114092076, 0.09523679355957679, 2.608012420790536, 65.16508402143205, 59.865150996616904, 54.37821415492466, 26.453600304467336, 50.57810538155692, 56.94373573575701, 13.77722428526197, 0.4457069906805243, 1.9768321982451846, 2.311855661017554, 0.5794520782572883, 0.7395438935075487, 29.994838305882045, 92.71307250431606, 83.97172451019287, 90.97945526668003, 82.8889936719622, 92.11251190730503, 81.4334363937378, 90.06189700535366, 84.2668353489467, 84.1302685056414, 77.49714292798723, 73.9505044392177, 71.7026927130563, 77.28456974029541, 74.39008917127336, 75.18349007197789, 70.95605318886894, 71.93904263632638, 72.43947969164167, 77.79716614314488, 75.11926092420305, 73.80474512917655, 69.72465869358608, 57.776004859379356, 55.2471593448094, 56.04460757119315, 53.11595923560006, 55.4803478377206, 54.278615202222554, 50.682199818747385, 49.36854560034615, 50.280677318573, 49.91156816482544, 52.27700594493321, 63.15431703839983, 68.71921961648124, 64.75138827732631, 67.06740352085659, 64.4707088470459, 65.25368050166539, 67.11886882781982, 62.97388621738979, 59.76033047267369, 56.43655545370919, 52.388600962502615, 51.24691465922764, 50.37750046593802, 55.332660402570454, 61.09713608877999, 63.95523588997977, 61.038159779139924, 59.13736193520682, 61.74015712738037, 63.84664944240025, 53.22642169679914, 48.0570661681039, 55.40742301940918, 61.28811427525112, 59.06669180733817, 63.338722229003906, 61.612845284598215, 60.94599887302944, 59.3472809110369, 57.80808816637312, 60.558747972760884, 58.838658877781455, 56.47854341779436, 60.41482298714774, 58.45829364231655, 56.26934358051845, 50.03008706229073, 52.62995706285749, 57.558797223227366, 56.99807064873831, 56.6371499470302, 59.492011887686594, 61.21749973297119, 59.172707421439036, 58.49889891488211, 56.33157164709908, 53.57952567509243, 59.44699450901577, 62.06149741581508, 61.47122015271868, 60.35768100193569, 54.70767341341291, 53.22163438796997, 48.91131591796875, 49.706196784973145, 49.355969360896516, 51.18421411514282, 54.058746406010215, 54.04956783567156, 49.95695727212088, 42.944550377982004, 45.7059451511928, 47.17325530733381, 48.78877401351929, 48.264535903930664, 53.841889653887065, 57.86767591748919, 59.64462212153843, 63.936156136649, 63.879410198756624, 65.06685733795166, 64.53809942517961, 64.97409193856376, 66.37115928104946, 65.76438004629952, 63.948252950395855, 64.1722628729684, 57.80308198928833, 60.78932394300188, 57.78291484287807, 55.02113791874477, 56.51359013148716, 57.422803606305806, 61.44440010615757, 69.00870936257499, 68.84588527679443, 72.84064088548932, 67.16247572217668, 68.02737358638218, 19.415556294577463, 0.8989468600068773, 0.5876475870609283, 1.7554785502808434, 3.551408861364637, 0.9132966271468571, 0.02720591924818499, 3.0691287517547607, 69.60022340502057, 60.44278253827776, 53.04220758165632, 50.79592793328421, 21.99779176712036, 36.961227280753, 48.8433312688555, 66.63638591766357, 24.466262647083827, 0.1588700586663825, 0.10124567576817103, 0.08482256345450878, 0.0721023388739143, 0.15309898262577398, 0.04176147588129554, 0.025899763086012433, 0.043294401839375496, 0.0754105770694358, 0.013181166141293943, 0.05209973381300058, 0.23619196031774792, 0.14034403062292508, 0.08620066129203353, 0.18456647837800638, 0.1688696699483054, 0.1471049264073372, 0.06842602935752698, 0.18022036658866064, 0.21069494847740444, 0.09290076712412493, 0.16667836824698107, 0.2641947476991585, 2.873488975422723, 74.99498544420514, 69.15731048583984, 49.48924275806972, 29.332834788731166, 68.83090496063232, 65.49937575204032, 21.36566550391061, 0.8288779141647475, 2.1795304758208136, 7.507992369788034, 8.90378211225782, 3.112180007355554, 31.640668528420584, 94.7770140511649, 88.86042145320347, 95.11418233598981, 86.43668828691754, 95.44926616123745, 83.87444972991943, 93.46737589154924, 90.31463078090123, 88.44359901973179, 82.34899357386998, 75.5380288532802, 74.94804341452462, 81.13310745784214, 78.80296652657645, 77.4818707874843, 76.27652508871896, 73.9012347630092, 75.86214842115129, 79.67302690233502, 79.80691868918282, 76.60842663901192, 73.9255256652832, 62.463888440813335, 58.0027871131897, 58.720296314784456, 55.31162125723702, 58.04921497617449, 57.465642724718364, 54.1469920022147, 53.09344359806606, 51.26582070759365, 51.47047642299107, 54.40832764761788, 64.73715836661202, 70.40602684020996, 68.80015223366874, 69.06501061575753, 66.64728764125279, 68.66453034537179, 72.17505209786552, 66.46340356554303, 64.90426254272461, 59.24473244803292, 56.8569701058524, 53.72186647142683, 53.28086083275931, 57.99438674109322, 63.74923569815499, 66.4516680581229, 65.39483315604073, 62.3343323298863, 66.51682826450893, 65.91425268990653, 56.24270418712071, 50.55450235094343, 58.472773688180105, 62.96891130719866, 60.641216141836985, 66.48727757590157, 64.16457121712821, 63.59019143240792, 64.24447550092424, 61.752191407339915, 63.2482636315482, 59.59410176958357, 61.03319181714739, 65.44202532087053, 62.33299132755825, 58.431647300720215, 51.33611215863909, 56.94505589348929, 62.88845116751534, 59.83364091600691, 60.780784606933594, 62.764398029872346, 63.84887286594936, 60.903316089085166, 62.68270805903843, 60.285669871738975, 58.561939920697895, 61.71343435559954, 64.8435561316354, 64.46554633549282, 62.59668936048235, 57.92880269459316, 56.253334930964876, 54.365273135049, 53.1371408190046, 52.440111432756694, 54.658890111105784, 57.64293990816389, 59.48895468030657, 53.33984061649868, 45.94829831804548, 48.15449728284563, 51.65112958635603, 50.65161732264927, 51.88415132250105, 55.93708419799805, 62.46294348580496, 61.31865855625698, 66.75027384076799, 65.50042493002755, 67.94286959511894, 66.11045592171806, 68.29453182220459, 69.66434832981655, 70.29383427756173, 68.051803452628, 69.79279272896903, 62.449971199035645, 64.46289212363106, 61.937979289463584, 59.653036390032085, 58.333948680332725, 62.09838540213448, 63.33793708256313, 72.69813333238874, 70.71510355813163, 76.20187364305768, 71.09367615836007, 70.00082179478237, 19.063986131123134, 1.3941863370793206, 4.143497867243631, 7.749450956072126, 6.530622712203434, 0.9827218332460949, 0.154731972143054, 5.1337633814130506, 79.04445116860526, 64.99328981127057, 63.71612753186907, 79.39201395852226, 38.011322430201936, 39.610516343797954, 55.675213541303364, 74.508271081107, 30.20937088557652, 0.3024105184844562, 0.38820467623216764, 0.12845927264009202, 0.31702160303081783, 0.21680069155991077, 0.14321203529834747, 0.13455350776868208, 0.14205334175910267, 0.16617950930127076, 0.20781239601118223, 0.14606919698417187], [0.037774146268410344, 0.02350902806834451, 0.05505753242011581, 0.035544073076120446, 0.07674874990646328, 0.07277037017047405, 0.14718232011156424, 0.04305099436481084, 0.23698842472263745, 0.054864238149353435, 0.17079698081527436, 0.25979091972112656, 5.307832258088248, 63.11657442365374, 47.82034799030849, 28.877632243292673, 30.511183261871338, 56.92354079655239, 38.368657861437114, 3.2975054000105177, 0.11422888695129327, 1.5200599027531487, 4.944963889462607, 1.1876546080623354, 0.5620029802833284, 64.24701159340995, 86.02896799360002, 81.89360169001988, 88.79631737300328, 86.64419623783657, 82.27682263510567, 87.63514137268066, 81.32401616232735, 84.1610768181937, 81.26126003265381, 76.25168527875627, 70.960451398577, 67.51024000985282, 69.65980420793805, 70.72778402056012, 68.35281331198556, 68.75682326725551, 67.70759664263043, 68.1640099116734, 71.87551525660923, 72.27268818446568, 73.38039084843227, 63.74157183510916, 55.53802483422415, 54.67433248247419, 52.47186122621809, 53.01072876793997, 49.53309978757586, 49.78981835501534, 45.879441670009065, 48.16242865153721, 48.23573562077114, 50.44129882540022, 55.537694794791086, 65.44932092939104, 64.29222352164132, 64.12231922149658, 63.73133019038609, 64.77208001273019, 63.199931962149485, 58.482327461242676, 57.16254145758492, 52.695978845868794, 49.39262110846383, 47.4881546156747, 47.058530126299175, 49.97126708711897, 57.54555395671299, 59.755605697631836, 59.3961614881243, 58.5319584437779, 55.21804986681257, 57.61295148304531, 53.58567483084542, 50.41408620561872, 48.86538485118321, 59.077239172799246, 59.00116334642683, 60.06031894683838, 57.8727376801627, 56.64169406890869, 59.45659691946847, 62.03102956499372, 59.06631660461426, 59.39341694968087, 57.36340693065098, 57.987417697906494, 55.58211462838309, 57.2570230620248, 54.82058164051601, 52.05357967104231, 49.59684256144932, 52.23715107781546, 57.87122644696917, 51.966084480285645, 51.024829387664795, 52.8308607510158, 56.326944146837505, 54.727416719709126, 50.45601511001587, 49.91877344676426, 56.78207547324044, 60.76893792833601, 57.909417220524375, 55.07020262309483, 53.79795619419643, 53.58780792781285, 48.37244142804827, 45.957511629377095, 45.31828083310808, 46.16866043635777, 48.47838756016323, 44.681565284729004, 42.92194441386631, 44.204974446977886, 45.62364721298218, 45.48125777925764, 43.91435561861311, 45.82972036089216, 48.29751900264195, 55.08441168921334, 57.714513301849365, 60.51767022269112, 62.21093232291085, 64.32861123766217, 62.51367228371756, 61.49623366764614, 60.217952728271484, 56.94385732923235, 55.331135272979736, 51.37595312935965, 50.07551438467843, 49.89099107469831, 50.22236456189837, 53.15479966572353, 55.9668607030596, 59.40449932643345, 60.123505864824565, 66.60500090462821, 66.17170429229736, 68.44653756277901, 63.39449541909354, 66.12645067487443, 56.80747808728899, 5.109528064727783, 0.5572204483406884, 1.759996833545821, 2.1633394360542297, 0.41882017627358437, 0.034281682422650714, 0.3794894367456436, 36.94446127755301, 70.94745826721191, 39.03947516850063, 58.72292273385184, 35.82973745891026, 38.28570679255894, 52.9190924508231, 50.85682541983468, 23.532402174813406, 0.24003887389387402, 0.29464731791189736, 0.08475557847746781, 0.06673603611333029, 0.069138606478061, 0.052426601094858985, 0.0044238036248965985, 0.07136236929467746, 0.0418121013790369, 0.07101184488939387, 0.09423201211861201, 0.08928515935050589, 0.05785429770393031, 0.07393130966063056, 0.05370405183306762, 0.14225380814501218, 0.02112210981015648, 0.06051184795796871, 0.01790372152546687, 0.018178251704999378, 0.08176935943109648, 0.18477322799818857, 0.4565491388951029, 8.668283343315125, 73.13304192679269, 57.01635830742972, 39.766003131866455, 26.999945844922745, 59.96128627232143, 46.55574457986014, 2.7446470090321133, 0.19621733176921094, 3.827218907220023, 5.3458571434021, 0.951813206076622, 1.1044475414923258, 69.93237509046281, 90.56062480381557, 86.3916083744594, 89.41859109061105, 88.37086527688163, 85.05253069741386, 90.52316706521171, 82.44633783612932, 85.4007396697998, 82.90102100372314, 79.86390781402588, 72.81224359784807, 70.65974725995744, 71.58952740260533, 73.01597867693219, 70.48315184456962, 71.37490449632917, 69.06992299216134, 70.97356959751674, 74.96563625335693, 75.41137708936418, 75.97306251525879, 66.8341316495623, 58.75130612509591, 56.7910282271249, 54.638729912894114, 54.33210938317435, 51.7195589201791, 52.17551360811506, 49.24911996296474, 48.894581181662424, 50.49490417752947, 52.416400705065044, 58.53600924355643, 68.06854166303361, 68.02955532073975, 67.37520177023751, 65.98762566702706, 66.18183476584298, 64.97665582384381, 60.596497535705566, 59.441957065037315, 54.23848935535976, 52.56190987995693, 50.96865667615618, 49.451145785195486, 53.18989849090576, 62.047031266348704, 62.916487148829866, 62.26311329432896, 61.64775998251778, 57.67276157651629, 60.05471175057547, 58.06332676751273, 53.00474984305245, 49.44477081298828, 60.1897360937936, 61.14502307346889, 61.25001035417829, 59.512370109558105, 59.32101672036307, 61.275093351091655, 61.545538084847585, 58.857627459934776, 60.90952777862549, 60.57330444880894, 60.235135623386924, 58.033501625061035, 59.645129340035574, 57.72083616256714, 53.53886481693813, 52.006019251687185, 55.686817032950266, 58.352660179138184, 53.59890072686331, 54.65661110196795, 56.09448868887765, 59.270899363926475, 57.42284876959664, 52.315891538347515, 50.766252177102224, 58.62778105054583, 63.606755937848774, 61.72075080871582, 58.95003155299595, 56.35199587685721, 56.25799022402082, 51.535636629377095, 49.55371509279524, 48.077358382088796, 50.35643352781023, 48.92906509126936, 47.329728739602224, 44.89911338261196, 45.779609952654155, 48.013129234313965, 47.04848650523594, 45.66951922007969, 48.342338357652935, 52.20520326069423, 58.04466390609741, 60.63783236912319, 63.32134478432791, 63.030632155282156, 64.82977090563092, 64.94082396371024, 63.52844279153006, 63.27479880196707, 59.68887519836426, 56.14971644537789, 54.04647936139788, 52.30626828329903, 52.70041874476841, 51.99975545065743, 54.63817058290754, 58.96271896362305, 60.96753134046282, 63.034189632960725, 69.7291819708688, 69.80307606288365, 70.79646001543317, 66.83437483651298, 66.88939762115479, 65.11729431152344, 13.008771760123116, 1.2706653880221503, 2.2063648530415128, 2.6812596789428165, 1.2622735926083155, 0.10248523711093835, 0.2009808783020292, 37.93660845075335, 77.92845930371965, 46.891092436654226, 57.750081130436485, 28.45591480391366, 44.5056403705052, 58.04873555047171, 56.558030809674946, 29.454497746058873, 0.2716166451573372, 0.27697601329003063, 0.08591940852680377, 0.11806088632770947, 0.07206138250018869, 0.029775887594691346, 0.050681124042187414, 0.062025204966110845, 0.007692586281336844, 0.11645674811942236, 0.032148419214146476, 0.16110497659870557, 0.09713533454175506, 0.19350577012768813, 0.16099805305046694, 0.36927876036081997, 0.14397295803896018, 0.1520492618105241, 0.08039165514388255, 0.41655517209853443, 0.1877632468406643, 0.3772284494979041, 0.6495633646845818, 10.24038188798087, 84.70175783974784, 62.34653336661202, 38.42519882747105, 41.9752071925572, 76.2602732522147, 57.38526596341814, 4.792600316660745, 0.35344921691077097, 5.833878202097757, 13.389652030808584, 6.784997131143298, 0.9347222660269056, 74.78603226797921, 93.05188751220703, 90.3683056150164, 94.11703940800258, 94.01640864780971, 86.40819372449602, 95.25273636409214, 83.21760177612305, 89.03831618172782, 85.34457043239048, 81.38883590698242, 75.84156090872628, 74.37500463213239, 75.23033482687813, 77.79756913866315, 71.91589818681989, 75.48233904157365, 73.06213556017194, 73.23039313725063, 75.59927027566093, 77.26985345567975, 80.92805916922433, 72.26650428771973, 61.89683205740792, 61.787168639046804, 56.48971612112862, 57.331698826381135, 54.498654229300364, 56.07854604721069, 51.25185135432652, 52.401396070207866, 53.810931955065044, 55.53421722139631, 59.544533320835654, 70.74626622881208, 71.51329176766532, 69.44606372288295, 68.3084351675851, 71.74339526040214, 67.87331812722343, 64.37562274932861, 64.68218421936035, 59.36253220694405, 55.9072208404541, 54.273855686187744, 51.81729228155953, 55.359338011060444, 65.04264286586216, 66.97803579057965, 64.2624921798706, 64.85488169533866, 61.23985208783831, 63.39423138754708, 61.08125250680106, 57.40583610534668, 51.06116846629551, 62.3360207421439, 63.09683459145682, 64.13116427830288, 63.42078045436314, 61.44924994877407, 61.84375476837158, 64.85866151537213, 62.95334039415632, 66.14518301827567, 63.46889672960554, 62.051714352199006, 59.785128593444824, 63.14898082188198, 58.333976473127095, 55.9042192186628, 55.01963710784912, 60.17644418988909, 62.7685877936227, 56.333788122449604, 58.74268341064453, 59.999251229422434, 61.03290694100516, 61.050166266305105, 54.98464250564575, 54.955533027648926, 62.81924016135079, 66.46801022120884, 64.59078761509487, 62.532223973955425, 59.56926890781948, 60.45252391270229, 54.701173373631065, 52.78884152003697, 52.66528170449393, 53.62583541870117, 53.31459433691842, 51.26698800495693, 48.37437302725655, 51.02208137512207, 52.05076912471226, 50.91128192629133, 49.70860086168562, 51.227821009499685, 53.57260526929583, 59.917408398219514, 62.555257252284456, 67.87642397199357, 66.46690545763288, 67.64209597451347, 67.44870676313127, 67.9253740310669, 66.66519314902169, 63.001338550022666, 59.99347032819475, 56.81097650527954, 56.45355422156197, 57.164733614240376, 55.376513957977295, 58.383850642613, 61.34242139543806, 65.7279645374843, 65.98873737880162, 74.50943143027169, 73.12473882947648, 77.25526918683732, 69.33779689243862, 68.55909143175397, 63.551496914454866, 13.600198081561498, 1.7306482940912247, 7.593317985534668, 9.952914936201912, 2.7949298194476535, 0.1475885318858283, 0.47287165160690037, 45.41454117638724, 84.81037902832031, 50.9219126701355, 77.00841358729771, 51.5032753944397, 45.5038081577846, 65.1954893384661, 65.01268223353794, 37.792499337877544, 0.4279909027474267, 0.33897185804588453, 0.1612053183572633, 0.12333042999463421, 0.17132534246359551, 0.19304576409714563, 0.08691052427249295, 0.1731725726276636, 0.17562186691377843, 0.20670949162117072, 0.20126430237931864], [0.08657447301915713, 0.09390071739575692, 0.07505007819937808, 0.01483216482613768, 0.06853536849043199, 0.03607405981581126, 0.030265335259693008, 0.029449698847851584, 0.1305802102599825, 0.03703712831650462, 0.1961120774171182, 0.23413627062525066, 11.581667355128697, 60.58336544036865, 37.287542479378835, 45.669307300022666, 61.378329685756135, 51.3480943271092, 24.265591723578318, 0.1691425631621054, 0.2335528933576175, 2.9929782322474887, 1.1020433562142509, 1.5347954034805298, 7.491878628730774, 91.36149501800537, 77.59390354156494, 89.17718982696533, 74.74173055376325, 82.25697857992989, 80.85442910875592, 82.12857586996896, 81.92866924830845, 82.31521838051933, 79.77347700936454, 84.41593674251011, 74.69619900839669, 68.14143521445138, 67.20593670436314, 67.77537631988525, 66.95748996734619, 68.0992249080113, 66.04312092917306, 72.07879175458635, 72.16509532928467, 71.7162139075143, 68.72787707192558, 59.58213002341134, 51.61886215209961, 54.30388927459717, 51.29025752203805, 52.99174281529018, 48.39126409803118, 47.29634264537266, 47.232933385031565, 48.26885073525565, 47.31342479160854, 51.68011399677822, 61.06548704419817, 64.96963814326695, 61.66646453312465, 65.48020567212785, 63.901623589651926, 61.020059721810476, 57.554270471845356, 54.42248807634626, 51.24361079079764, 49.800952843257356, 47.029392855507986, 47.68530627659389, 50.4351600919451, 58.10593659537179, 59.470729555402485, 62.209994316101074, 59.23630428314209, 56.92925221579415, 53.05405078615461, 57.361447538648335, 52.80259200504848, 50.99540376663208, 54.1691324370248, 59.965885979788645, 59.6670925957816, 58.968513761247905, 57.3707720211574, 59.23381682804653, 57.27017947605678, 55.28065313611712, 56.66050631659371, 56.506009646824424, 54.93665477207729, 55.72758558818272, 53.84246635437012, 54.84373303822109, 57.18560600280762, 54.45015927723476, 47.172504901885986, 48.572410583496094, 56.431476320539204, 52.21912397657122, 49.52625928606306, 47.75373213631766, 48.66792399542672, 50.25433669771467, 48.74089397702898, 45.36229419708252, 52.163958753858296, 58.37182331085205, 58.95110852377755, 57.00245148794991, 53.41450943265642, 52.3687047958374, 52.047093527657644, 45.05203628540039, 43.32611765180315, 42.90913888386318, 44.299403939928325, 42.176642417907715, 42.52969428471157, 42.91144221169608, 43.33980907712664, 42.755733081272666, 45.23013251168387, 43.84639876229422, 48.12891748973301, 55.8448155948094, 59.60258552006313, 59.45818110874721, 60.753783907209126, 62.01226942879813, 59.58888367244175, 56.69795363289969, 50.763184547424316, 48.058209146772114, 46.47415883200509, 46.02402326038906, 49.9865392276219, 50.925810609545024, 53.4479650088719, 55.937271799360005, 58.4987530027117, 59.299755232674734, 64.05076667240688, 64.80222129821777, 68.45884977068219, 63.72491700308663, 66.49824183327812, 65.65104103088379, 71.86366162981305, 53.20591408865792, 8.023544362613134, 1.0483142392975944, 3.8820358514785767, 0.87398312240839, 0.11144944466650486, 0.1521538376275982, 16.566869565418788, 73.15468556540353, 46.56542689459664, 49.93228421892439, 41.22979055132185, 44.42967224121094, 38.523168427603586, 51.72774389811924, 25.876786913190568, 0.09147811667727572, 0.09227888977953366, 0.0576034365221858, 0.14553286933473178, 0.07705624840621438, 0.026092073480997766, 0.0703255542154823, 0.10557778938008205, 0.014218221252251948, 0.07737458311021328, 0.0405328287743032, 0.08080397373331444, 0.08866225063268628, 0.07046870474836656, 0.0507462464406022, 0.018794697376766374, 0.03390768409839698, 0.06814029826117413, 0.02465055976063013, 0.1400683554155486, 0.05429598203461085, 0.34000542972769054, 0.2788398947034563, 20.668161903108867, 70.28608703613281, 45.27817930494036, 41.247178418295725, 39.436245100838796, 59.77786772591727, 26.63835116795131, 0.11176768437560115, 0.2736538244145257, 5.2157008818217685, 1.8654556146689822, 0.8941178077033588, 8.575013331004552, 97.0910004207066, 80.46762984139579, 91.05812277112688, 77.08772032601493, 84.53350721086774, 80.4194996697562, 85.304354258946, 83.52631023951939, 83.86603546142578, 83.30444036211286, 82.61707592010498, 77.70492185865129, 70.83882318224225, 69.7604558127267, 71.55134010314941, 68.4477048601423, 70.41280133383614, 69.22439534323556, 74.3701478413173, 72.91453497750419, 73.3552244731358, 70.51204940250942, 61.37986523764474, 55.03449930463518, 56.60615750721523, 53.06625877107893, 56.13378422600882, 50.376037870134624, 50.94426849910191, 49.653536387852256, 51.04163360595703, 49.925742489951, 54.33611849376133, 65.10204996381486, 66.23418944222587, 65.26652772086007, 65.76242760249546, 65.36233643123082, 62.259361267089844, 59.653696468898225, 54.574535506112234, 53.21671853746687, 53.66679852349417, 50.101392950330464, 48.20137677873884, 53.698666436331614, 61.81107044219971, 61.15520913260323, 65.3289155960083, 61.82780170440674, 58.25075789860317, 56.795690468379426, 62.37188039507185, 57.976269313267295, 53.53792681012835, 56.53625168119158, 61.92443725040981, 59.69821357727051, 62.37010860443115, 59.55740833282471, 60.289477484566824, 58.974086216517854, 57.86463608060564, 59.39554309844971, 59.58466611589704, 58.054888180324006, 58.84772627694266, 55.70375326701573, 55.366147245679585, 60.45558112008231, 55.359619413103374, 50.5347694669451, 51.826317991529194, 59.1206237248012, 53.8610006741115, 51.98989595685686, 51.24752957480294, 50.34174156188965, 51.37066902433123, 49.433024883270264, 46.79515518460955, 53.31139816556658, 60.05662250518799, 62.61427525111607, 58.51802035740444, 57.76868840626308, 54.67947762353079, 53.33891998018537, 49.71794966288975, 45.59789024080549, 45.21420724051339, 45.53026689801897, 45.13070726394653, 45.95863028935024, 45.524652753557476, 47.171191692352295, 45.37923043114798, 46.7383189201355, 46.42028597423008, 49.92199741091047, 59.02942167009626, 63.39769159044538, 62.27924006325858, 63.216531208583284, 64.41399765014648, 62.14872510092599, 58.5486341203962, 53.360838072640554, 50.256396838596885, 49.540388447897776, 48.69084957667759, 51.21806921277727, 54.667148045131135, 56.73223951884678, 57.450801372528076, 60.37737219674246, 62.785784585135325, 67.2085770198277, 67.81439740317208, 70.16824558803013, 69.64863845280239, 65.41794981275285, 67.98504516056606, 73.19713905879429, 65.0753480366298, 14.522653085844857, 0.4685965010098049, 0.7183652956570897, 2.5835274032184055, 0.30946679413318634, 0.22595874299960478, 15.139289208820887, 77.78889083862305, 55.23866517203194, 55.7681839125497, 33.918180329459055, 44.58132014955793, 50.323843002319336, 56.645255020686555, 34.14980200358799, 0.04275650677404233, 0.0827214051304119, 0.045386766349630694, 0.10367369119610105, 0.029375236414905106, 0.0370775486475655, 0.06054496725222894, 0.07656341485146965, 0.02410596755466291, 0.04925163735502532, 0.02368657014864896, 0.13527237490883895, 0.2125291914812156, 0.21291886057172502, 0.12429886231464998, 0.09750671032816172, 0.12230718561581203, 0.2957740660224642, 0.0754250366506832, 0.26546985070620266, 0.13246497698128223, 0.4228698903960841, 0.4135515147021839, 24.1308696269989, 82.81732995169503, 49.09693704332624, 57.647352014269146, 79.63005229404995, 70.64830357687813, 36.019169671194895, 0.2604157419076988, 0.3626834542623588, 7.099294551781245, 7.787103244236537, 3.3368222159998755, 9.191720673016139, 101.38107531411308, 84.1604723249163, 95.5846448625837, 81.63912391662598, 88.86034502301897, 84.23155239650181, 87.869601385934, 85.97679397038051, 83.90588338034493, 84.81112943376813, 89.47400992257255, 81.30656228746686, 72.17566353934151, 73.80342497144426, 72.78971753801618, 71.73463358197893, 73.98721177237374, 71.32293891906738, 78.59339496067592, 76.19062450953892, 76.74882888793945, 74.10904843466622, 65.38143008095878, 58.10484920229231, 59.622783933367046, 55.96437324796404, 59.30833625793457, 54.133634090423584, 52.9196309362139, 53.94726603371756, 53.91194486618042, 52.239708014896934, 55.95474304471697, 67.8781818662371, 70.89034407479423, 67.65859794616699, 67.84791551317487, 67.67541258675712, 65.78289699554443, 63.555193356105256, 59.145060539245605, 57.63821165902274, 55.480872426714214, 52.19478791100638, 53.81103270394461, 57.15817104067121, 64.60387802124023, 65.26692376817975, 68.0620173045567, 65.3150053024292, 63.90941252027239, 59.36959157671247, 64.7606224332537, 61.501882553100586, 56.53586605616978, 59.662958417619976, 63.92021002088274, 61.44473361968994, 65.35035078866142, 61.97469357081822, 61.39868790762765, 61.64806570325579, 61.137393951416016, 62.03897830418178, 62.93474701472691, 60.14919335501534, 62.36836460658482, 55.08749321528843, 58.599626949855256, 62.405509676252095, 58.40070002419608, 52.2619491985866, 53.59626735959734, 62.51148360116141, 56.208796977996826, 56.37604011808123, 54.81400864464896, 55.21092448915754, 55.48430831091744, 52.907520226069856, 48.257907322474885, 56.43273741858346, 64.34793417794364, 64.30160358973912, 60.71261583055769, 59.69908210209438, 58.97686549595424, 55.80420337404524, 50.37354694093977, 48.2788040297372, 47.14555631365095, 49.90401547295706, 48.04411472593035, 49.449763093675884, 50.116929122379844, 49.56038188934326, 47.64904015404837, 51.45691006524222, 48.604552950177876, 53.92418759209769, 63.1136075428554, 66.14794145311627, 64.63665962219238, 66.0826005935669, 66.04958970206124, 65.82023661477226, 62.73564638410296, 56.948457036699565, 53.88256440843855, 53.64577327455793, 51.29989814758301, 55.781889234270366, 57.12417697906494, 60.19281414576939, 62.02748598371233, 64.29745551518032, 64.39435509272984, 69.92333548409599, 70.04440089634487, 74.4798390524728, 73.01749338422502, 68.75661482129777, 70.74337577819824, 75.57501411437988, 67.28978756495884, 13.64274537563324, 3.931793204375676, 11.2017502784729, 4.877750490392957, 0.8408579656055996, 0.3007089155060904, 21.845660958971294, 85.0174422945295, 60.317742756434846, 63.057368823460166, 58.163655281066895, 55.1871269089835, 49.77161060060774, 67.54640538351876, 39.21397917611258, 0.1574441987488951, 0.1965466790965625, 0.22339020296931267, 0.2528269519763333, 0.1674434029098068, 0.16132252849638462, 0.1774650937212365, 0.1769292274756091, 0.07095009141734668, 0.17339895905128547, 0.11751201935112476], [0.03526123593162213, 0.06236355645315988, 0.0359050062085901, 0.030026429864977087, 0.03772620437666774, 0.07250912740294423, 0.06610351933964662, 0.05682693122486983, 0.09486670020435538, 0.03914444434589573, 0.07833747179912669, 0.09119802420692784, 30.135723454611643, 62.94824736458914, 35.25331142970494, 41.913368225097656, 61.13969380514962, 49.97651992525373, 16.078355618885585, 0.2873082288673946, 0.7187256791761943, 3.2054181013788496, 1.4171856343746185, 0.6711253619619778, 30.171253068106516, 90.54071126665387, 79.45109449114118, 82.69524315425328, 77.22181361062187, 80.76638848440987, 73.50527776990617, 81.62474114554269, 79.80226339612688, 81.38006033216203, 82.52947998046875, 81.263413974217, 74.65368298121861, 73.42536653791154, 65.642730985369, 66.89468520028251, 64.5388011932373, 68.0438130242484, 68.11842278071812, 70.76747213091168, 68.5390875680106, 70.66206101008824, 60.42513411385672, 53.78233316966465, 51.165127413613455, 53.95317200251988, 52.83594683238438, 50.14381170272827, 44.95696060998099, 49.10720648084368, 45.58803769520351, 47.18769366400582, 47.52390309742519, 53.749850341251914, 62.28299903869629, 63.51285103389195, 63.130172048296245, 64.83653150285993, 61.98767280578613, 57.56654446465628, 51.79246636799404, 49.679484435490195, 46.926455293382915, 46.25860834121704, 46.2136013848441, 48.934755665915354, 54.75888858522688, 57.408000469207764, 59.98634842463902, 58.13738761629377, 56.79216773169381, 55.67701659883772, 55.791227613176616, 54.826379912240164, 52.4723128591265, 51.81276900427682, 56.58551788330078, 61.10006128038679, 58.91916070665632, 59.42182118552071, 56.542397362845286, 57.50540031705584, 56.051792008536204, 57.37613950456892, 56.10095746176583, 57.003406865256174, 54.35714374269758, 59.733239446367534, 60.40075288500105, 58.00761611121041, 55.64638546534947, 54.80087307521275, 49.912214347294395, 47.414510658809114, 53.79771300724575, 53.45367990221296, 50.26623896190098, 45.97845002583095, 44.25954212461199, 43.501705578395296, 44.87030962535313, 41.76770966393607, 52.407482692173545, 57.699025767190115, 60.02447319030762, 56.57250738143921, 54.609422411237446, 53.046369552612305, 50.76341036387852, 52.460202148982454, 45.726341588156565, 42.53750058582851, 42.30365548815046, 42.83592224121094, 41.93691914422171, 41.80960035324097, 44.10321113041469, 44.15094525473458, 44.96537487847464, 44.38682617459978, 47.79436520167759, 57.29551260811942, 60.444568225315635, 60.839378765651155, 58.371218817574636, 58.86098343985421, 54.354041372026714, 48.56892258780343, 47.63800641468593, 45.6430014201573, 46.90405430112566, 46.931412833077566, 50.23946755273001, 52.242789540972026, 52.62996053695679, 58.68896688733782, 59.53154713766915, 58.79644162314278, 62.874110085623606, 65.72549792698452, 67.47982079642159, 66.88620144980294, 64.037752696446, 68.03994287763322, 69.52812889644078, 70.29416084289551, 49.75994457517351, 1.2835160813161304, 0.7050711661577225, 1.3521625463451659, 0.4909881023424012, 0.1193125391645091, 3.4922844682421004, 59.12015124729702, 59.59547751290457, 46.26112011500767, 43.15892314910889, 22.681979145322526, 25.796795776912145, 50.486041750226704, 27.954098531178065, 0.045794481078961065, 0.052394859226686616, 0.11515127388494355, 0.022413648631689802, 0.06922797632536717, 0.04843668965622783, 0.05539638263040355, 0.056033201316105466, 0.0771194403725011, 0.09722460260880844, 0.018953705273036445, 0.09160295355000667, 0.017455028370022774, 0.051285254303365946, 0.019139637438846484, 0.06679514329880476, 0.03760354560134666, 0.04379907583019563, 0.02347864835922207, 0.019870263590876545, 0.07488652411848307, 0.05233493779918977, 0.06539670976677112, 40.12970311301095, 70.07875279017857, 42.298718793051584, 33.41901479448591, 52.838156359536306, 59.19476100376674, 17.17357758113316, 0.4092225969902107, 0.7368621059826442, 4.971280625888279, 1.0078595472233636, 0.6367377500448907, 35.123275893075125, 95.19239125932965, 82.68887165614537, 84.38054956708635, 80.86895084381104, 79.91809681483677, 76.79452719007219, 83.27260371616909, 80.94733347211564, 85.69277245657784, 84.74057742527553, 83.70417022705078, 80.25401442391532, 76.39292131151471, 69.15401009150914, 70.63078022003174, 68.39081301007951, 71.23020826067243, 69.62031759534563, 72.89528151920864, 70.30331856863839, 70.96097946166992, 62.76045840127127, 55.221843583243235, 54.58159140178135, 55.28436347416469, 54.45102432795933, 52.33578075681414, 48.42671380724226, 48.933258329119, 48.02942623410906, 49.228678362710134, 51.84793036324637, 57.1159850529262, 64.35850238800049, 66.7403518131801, 66.0062676838466, 66.43135152544293, 64.20191778455461, 58.746692521231516, 53.796337263924734, 51.35461868558611, 50.690148557935444, 49.23606777191162, 48.057146072387695, 52.207006318228586, 58.65746375492641, 60.7958413532802, 61.57147571018764, 58.88767147064209, 59.16755185808454, 55.73971366882324, 61.17157908848354, 59.08862727028983, 55.227089473179404, 53.59862279891968, 60.228319440569194, 63.07488523210798, 60.93251936776297, 60.87714917319161, 57.44740717751639, 62.40839317866734, 59.71570914132254, 58.354119300842285, 59.75129781450544, 56.67080702100481, 57.586510113307405, 62.72548811776297, 63.1571866444179, 59.62053966522217, 58.508952958243235, 57.48837375640869, 53.9898168018886, 48.63585805892944, 56.61692026683262, 57.10954754693167, 54.68937185832432, 49.58074358531407, 46.627199854169575, 45.143297399793354, 47.03169618334089, 45.135803767613, 53.04771402903965, 60.169391768319265, 62.700599670410156, 57.847915240696494, 58.47941616603306, 57.41744654519217, 55.280180658612935, 55.12996060507638, 48.725076402936665, 45.721745354788645, 44.69252954210554, 44.89459705352783, 44.919725213732036, 44.501450606754844, 46.81680229731968, 46.33346128463745, 46.03588383538382, 46.38129963193621, 51.04467691693987, 59.07530757359096, 62.370872906276155, 61.94769981929234, 61.13338484082903, 61.605417660304475, 57.382775034223286, 50.59774793897356, 49.935487338474815, 48.7326534135001, 49.03875977652413, 49.94056299754551, 53.26260791506086, 55.062052386147634, 56.9926996912275, 60.993691308157786, 61.736773354666575, 62.466049330575125, 65.95606694902692, 68.50299862452916, 71.99646949768066, 66.48016956874302, 66.12373392922538, 71.04034873417446, 72.8873188836234, 70.65199307032994, 61.21344198499407, 3.6294045618602206, 1.1994179082768304, 2.6456219341073717, 0.8333442487886974, 0.15054993012121745, 2.156798141343253, 62.80220317840576, 69.36003112792969, 54.949863297598704, 41.25416830607823, 24.95352939196995, 36.738516671316965, 54.83936262130737, 35.99429512023926, 0.14261301101318427, 0.05597583796562893, 0.10351519220109497, 0.1016801010285105, 0.03707401008744325, 0.03574176764647875, 0.08489842366959367, 0.02123314019159547, 0.06057231899883066, 0.10021368507295847, 0.03590325898091708, 0.1920926666685513, 0.12129737623035908, 0.21521198323794774, 0.09714477296386446, 0.12636980547436646, 0.14314810372889042, 0.18508848893855298, 0.11323386284389667, 0.1475999312741416, 0.09119459081973348, 0.17485396883317403, 0.14403512541736874, 47.4570232118879, 82.1619758605957, 46.979011467524934, 55.788611616407124, 81.27665029253278, 69.3257417678833, 23.179440634591238, 0.6873639534626688, 2.8302529411656514, 9.312641910144261, 7.260388970375061, 1.5343688492264067, 36.9563114302499, 98.79153033665249, 87.62791524614606, 87.53491360800606, 85.23551150730678, 86.11971146719796, 79.67838396344865, 87.50539766039167, 83.11536598205566, 89.6926280430385, 88.21181406293596, 85.23091179983956, 80.63977146148682, 79.58374949863979, 72.32783603668213, 73.26095131465367, 70.01254340580532, 73.94817679268974, 74.26668916429792, 76.4280583517892, 73.44628756386894, 77.23511941092355, 65.48795986175537, 57.7054945400783, 55.811832496098106, 58.86080278669085, 57.53374201910836, 54.65142774581909, 51.64379228864397, 55.02368095942906, 50.942548819950645, 51.67148780822754, 54.50898272650582, 60.62627056666783, 67.94301550728935, 69.31096294948033, 68.47986807141984, 72.0392426082066, 68.42574855259487, 63.634916986737935, 56.41120842524937, 55.89030545098441, 53.714282512664795, 50.56355932780674, 51.909616470336914, 54.80771010262625, 60.52254785810198, 61.98958356039864, 65.53903606959751, 64.76140757969448, 61.02199132101876, 59.91624804905483, 62.377647399902344, 61.21601281847273, 58.78417110443115, 56.688344274248394, 61.67127268654959, 64.11628123692104, 65.60282053266252, 63.6411703654698, 58.883509499686106, 63.41157409123012, 61.49055698939732, 61.19600895472935, 62.46711240495954, 61.984226499285015, 59.26828684125628, 65.09671374729702, 66.09778935568673, 62.23835686274937, 60.34442383902413, 59.480957303728374, 55.37038564682007, 52.37878663199288, 60.8674008505685, 60.49504688807896, 57.910129410879954, 52.21942622320992, 48.82456418446132, 49.31826148714338, 50.6749597958156, 46.41770124435425, 56.728650774274556, 64.01048101697648, 63.58358369554792, 60.71349825177874, 60.321842193603516, 59.31801509857178, 58.05878611973354, 58.42046070098877, 50.31373337336949, 48.952351978846956, 47.94201442173549, 48.310112612588064, 47.813017640795024, 47.751515660967144, 48.486770561763215, 49.398895331791465, 49.00193779809134, 47.90723868778774, 54.03613349369594, 62.9706483568464, 66.62878458840507, 66.01704433986119, 64.6768410546439, 64.87954780033657, 61.28061716897147, 53.584608282361714, 52.48664699281965, 51.74027497427804, 54.268786975315635, 51.90595129558018, 57.181770597185405, 58.70330796922956, 59.86388642447335, 64.16420296260289, 66.08688763209751, 64.76479135240827, 70.13772215162004, 71.53076648712158, 74.44928087506975, 68.97322491237095, 68.11504595620292, 71.17035647800991, 78.36604295458112, 72.08200182233537, 67.18564796447754, 2.8465299648897986, 4.358614095619746, 7.728615045547485, 0.8092644523297037, 0.22467390980039323, 4.0500220145498, 71.46942778996059, 74.55497687203544, 60.84101159232003, 60.49346269880022, 33.44182573046003, 36.19408014842442, 66.18762261526925, 42.15968186514718, 0.3295409269630909, 0.15975518045680864, 0.20316452612834318, 0.16715977527201176, 0.12520136817225389, 0.09833828892026629, 0.13415617123246193, 0.08936220700187342, 0.24859400625739778, 0.12202867413205759, 0.12714298255741596], [0.05503150720947555, 0.08112827276012727, 0.02673873262080763, 0.08941857290587255, 0.05232785050091999, 0.056937264411577156, 0.036869333391743045, 0.11610480557594981, 0.029287376308015416, 0.11254825749035392, 0.03147636081225105, 0.5409297453505653, 41.36515883037022, 53.45589985166277, 37.39051130839756, 36.3467355455671, 42.90567520686558, 45.86501373563494, 6.631924407822745, 0.12890644078808172, 0.38914281874895096, 4.780984231403895, 0.886597522667476, 0.019825110478060584, 54.21082162857056, 87.49157074519566, 81.76596328190395, 79.66008240836007, 73.31368814195905, 71.5892425264631, 75.18765899113247, 71.93660381862095, 78.51346288408551, 79.82986858912876, 80.25406306130546, 79.08675180162702, 79.18144185202462, 73.79926994868687, 69.99982820238385, 66.76396179199219, 69.541476385934, 66.72051470620292, 67.80316911424909, 64.76169245583671, 66.75967475346157, 59.595137051173616, 55.52625111171177, 52.70447301864624, 52.00641182490757, 51.67959288188389, 51.80139480318342, 47.26628473826817, 46.153092997414724, 44.02537740979876, 46.250148909432546, 48.2651994568961, 48.61899478094918, 57.73074081965855, 62.23582771846226, 61.668945040021626, 62.2015175138201, 61.453988620213096, 55.02952439444405, 51.35780096054077, 50.44919197899954, 48.189933095659526, 48.08216653551374, 44.72926466805594, 47.231509004320415, 51.67296082632882, 59.01874228886196, 56.21760729381016, 58.535800797598704, 54.596411909375874, 52.3982172693525, 53.62825339181082, 57.22059713091169, 53.97430147443499, 54.22345345360892, 50.43492037909371, 56.65177937916347, 56.85701526914324, 59.8745310647147, 57.64449977874756, 58.15050234113421, 57.510552406311035, 55.81564358302525, 52.696552072252544, 56.64108957563128, 50.90089436939785, 48.64168759754726, 54.462012904030935, 48.47030333110264, 49.05795070103237, 55.99962145941598, 56.90621893746512, 52.81224652699062, 46.7679112979344, 51.215352467128206, 53.261134896959575, 51.60350315911429, 49.94735138756888, 47.00986494336809, 44.740843841007774, 42.595368657793315, 42.45404577255249, 45.3551618712289, 53.01676675251552, 54.9157406943185, 61.76536519186837, 55.51620749064854, 54.08140100751604, 53.65530620302473, 54.012269905635286, 52.984867572784424, 48.2098605292184, 41.8838974407741, 41.38357503073556, 41.01433733531407, 41.81094830376761, 40.74419484819685, 41.7251866885594, 43.50434589385986, 43.94956908907209, 48.64612749644688, 58.24223593303135, 57.69741031101772, 59.095922878810335, 59.71000467027937, 52.98187289919172, 46.738565581185476, 46.429891858782085, 45.748113768441335, 46.76076854978289, 48.07378700801304, 47.46696260997227, 50.17482846123831, 52.93294021061489, 57.49679844720023, 57.68006413323538, 59.72948047092983, 59.16869831085205, 62.777245249067036, 65.3515041896275, 69.1112369809832, 64.43529387882778, 65.11382716042655, 66.63629559108189, 67.18284784044538, 70.89615971701485, 74.43975489480155, 22.02203403200422, 1.1090511573212487, 1.2278877177408762, 0.4857662596872875, 0.05420476657205394, 0.06717704994870083, 37.39560086386544, 64.99089963095528, 51.998223372868125, 39.17197036743164, 36.92619098935808, 30.907122884477886, 44.23058898108346, 36.359030382973806, 0.11741983358349119, 0.056700988340058496, 0.08405294868030719, 0.13575718817966326, 0.05547213427988546, 0.05861807707697153, 0.060108553884284835, 0.05536040331103972, 0.140341045068843, 0.04344212230561035, 0.03140517570344465, 0.014807238842227628, 0.05952163466385432, 0.02419116610794195, 0.06520454864948988, 0.060777969392282624, 0.08412898531449692, 0.044323858206293414, 0.0648832894595606, 0.017299562426550046, 0.05214719394487994, 0.048279055793370516, 0.8601717863764081, 53.22808926446097, 61.01077692849295, 51.184318338121685, 35.3821553502764, 47.052825655256, 54.54369592666626, 6.287871760981424, 0.18694729491003922, 1.0925294267279761, 3.9845699838229587, 0.8418515037213052, 0.07381468984697546, 62.119653838021414, 90.42837279183524, 83.79435784476144, 83.33731228964669, 75.9931150163923, 74.24768584115165, 76.51757894243512, 72.15222031729562, 81.44168390546525, 80.09387929098946, 82.27398082188198, 80.99193395887102, 81.7919842856271, 76.00521183013916, 72.94177191598075, 69.27872330801827, 71.5155360358102, 69.1681010382516, 70.94369929177421, 68.19010039738247, 68.27491010938371, 62.477729252406526, 59.0677409853254, 56.08229807444981, 53.257566996983115, 54.21464661189488, 53.89310482570103, 49.53717838014875, 48.85504593167986, 48.7071396282741, 49.430787563323975, 51.13994019372122, 50.96075310025896, 61.001640047345845, 63.64399133409773, 64.26236016409737, 64.14142676762172, 63.975976262773784, 56.49612930842808, 54.03090844835554, 54.12484809330532, 50.84826176507132, 51.12941367285592, 47.67801761627197, 50.89458540507725, 54.5861667905535, 61.49788039071219, 59.43118735722133, 61.024603843688965, 59.62288815634591, 55.256737436567036, 54.85760859080723, 58.22311101640974, 56.54732016154698, 56.65601430620466, 52.92351497922625, 56.98996557508196, 59.27417196546282, 64.13079602377755, 58.16998161588396, 60.37958172389439, 61.4832683290754, 55.405248233250205, 55.04134675434658, 56.39382750647408, 52.139636584690635, 49.903786182403564, 58.91422053745815, 46.728876318250386, 47.94706923621041, 54.08532673971993, 59.95774269104004, 55.89887605394636, 47.67924049922398, 52.917688914707725, 57.399374280657085, 55.88111645834786, 52.55122355052403, 50.0409505707877, 46.14424794060843, 45.36195026125227, 45.224924836839946, 48.21778842381069, 55.56440019607544, 55.38104765755789, 63.25753252846854, 58.562523569379536, 58.388353075299946, 57.19011190959385, 56.32393905094692, 55.97660902568272, 51.59823295048305, 43.03151055744716, 43.371131556374685, 43.25614581789289, 44.33974865504673, 43.87642192840576, 44.395077160426546, 44.3747467313494, 46.12390014103481, 50.205265045166016, 60.58001640864781, 60.304673194885254, 60.29511942182268, 63.55529063088553, 56.00417947769165, 48.94407320022583, 48.87874971117292, 48.425775800432476, 49.04036133629935, 50.412561076028005, 50.62089933667864, 52.736247130802695, 55.14372498648507, 59.828666005815776, 61.077153069632395, 62.18224321092878, 63.458662033081055, 65.65775993892125, 67.3308653150286, 71.23543330601284, 66.50873361315045, 67.9382073538644, 71.2346967969622, 70.63358034406389, 71.75745146615165, 78.01963356563023, 32.32676492418562, 0.5770295453923089, 0.9779220393725804, 0.9404459531818117, 0.29742355751139776, 0.07336044457874127, 39.23923587799072, 70.92354256766183, 61.463368688310894, 40.96593270983015, 29.08371581350054, 33.24892289297921, 50.86955451965332, 46.21001264027187, 0.2617693921285016, 0.03358378879992025, 0.07193373649248055, 0.05911903269588947, 0.05581506248563528, 0.06355160341731139, 0.06541353743523359, 0.0200005881155708, 0.08363269801650729, 0.023249839565583637, 0.029889386147260666, 0.17782021180859633, 0.10296293254941702, 0.09502965717443398, 0.158753242077572, 0.1786544163312231, 0.10878631685461317, 0.10761459544301033, 0.15562980967972959, 0.13681857979723386, 0.13290276777531418, 0.1229876069618123, 1.1257700430495399, 63.202426365443635, 68.80370276314872, 52.05521249771118, 50.02291999544416, 58.2704074042184, 64.11342552730015, 8.25559595652989, 0.2992095431046826, 2.146134827818189, 8.796254396438599, 4.518122587885175, 0.20338553855461733, 63.96565123966762, 94.34181363242013, 89.34535012926374, 85.65605817522321, 80.01528821672711, 79.27558994293213, 81.58412892477853, 75.89042064121791, 85.03433336530412, 83.0789852142334, 83.64725753239223, 84.24433013371059, 85.00586659567696, 78.25411442347935, 76.6218922478812, 72.06079592023576, 76.06441743033272, 72.96456200735909, 75.22911194392613, 68.7444554737636, 72.69451332092285, 65.307772227696, 62.41907950810024, 58.27403088978359, 56.22093548093523, 57.08383226394653, 58.741606439862935, 52.638301849365234, 53.08650234767369, 50.22010292325701, 51.34545053754534, 54.37277371542794, 54.37525422232491, 63.44077736990792, 67.70289271218437, 66.41425200871059, 67.43985475812639, 67.36453628540039, 58.63373565673828, 57.02912562234061, 57.0893143926348, 56.38225875582014, 55.39481898716518, 50.50976984841483, 53.73877838679722, 57.78755971363613, 66.03533894675118, 62.085149083818706, 64.03142288752964, 61.51468808310372, 58.399782861982075, 58.05526685714722, 61.90287699018206, 59.400524956839426, 61.56065041678292, 54.803252833230154, 58.6118140901838, 61.766761779785156, 64.93941347939628, 59.717821393694194, 62.64878000531878, 63.244678361075266, 57.776675360543386, 55.48839037758963, 58.489143644060405, 52.117933886391775, 50.256108488355366, 59.14969498770577, 49.64485461371285, 50.43312774385725, 58.30034024374825, 62.46566023145403, 59.105990818568635, 50.67540448052542, 55.61245741162981, 60.722072328839985, 59.47335597446987, 56.3618414742606, 53.3077712059021, 50.03113971437727, 47.78412703105381, 49.370546681540354, 52.207537855420796, 60.07437515258789, 59.91250991821289, 63.644088608878, 60.886508396693635, 59.157657623291016, 58.44360515049526, 58.74028628213065, 58.521515301295686, 53.771632943834575, 47.220489161355154, 46.475402559552876, 46.97567980630057, 47.47349739074707, 46.53263487134661, 47.93949569974627, 46.54115683691842, 49.840845925467356, 53.38882194246565, 63.431960105895996, 62.326779638017925, 63.32527051653181, 66.2878851209368, 60.170044898986816, 52.768559728349956, 51.80411849703108, 51.311633655003135, 51.86470678874424, 55.28494712284633, 53.54645224979946, 56.038277762276785, 58.6281076158796, 63.36420822143555, 63.90434728349958, 65.67366436549595, 65.83494595118931, 67.79524816785539, 69.8856623513358, 75.49918842315674, 69.19528239113944, 69.24901281084333, 75.27005073002407, 73.18286745888847, 75.52242319924491, 82.08241898672921, 32.78014530454363, 1.6433060722691673, 7.920420067650931, 1.5359741002321243, 0.3174592581178461, 0.24756591713854245, 49.23227752958025, 77.6490444455828, 66.2148665019444, 54.41957330703735, 47.56809711456299, 41.6887503351484, 58.117460182734895, 54.548295634133474, 0.39656531331794603, 0.08746085009936776, 0.18856737869126455, 0.221004880964756, 0.18928680223013672, 0.17817583201186998, 0.18471589178911277, 0.17134063664291585, 0.21062279306352139, 0.12473327400428907, 0.16279904783836432], [0.027644749897133027, 0.05505806167743035, 0.049353166549865685, 0.15781664662063122, 0.060887797070401053, 0.1929661040859563, 0.052652627894920964, 0.1657209824770689, 0.12312482031328337, 0.2855450420507363, 0.2563837511198861, 3.480142056941986, 50.90856518064226, 53.35958044869559, 10.374449116843087, 39.23415674482073, 53.927144050598145, 42.58878871372768, 2.710882020848138, 0.09518846829554864, 0.44062267350299017, 2.048036034618105, 0.15539454801806382, 4.195022233894893, 85.33211926051548, 77.11328969682965, 90.45483153206962, 74.09879289354596, 80.93711962018693, 67.75790854862758, 72.65078135899135, 66.49962452479771, 70.74964305332729, 72.31699684688023, 81.44813183375767, 74.16761480058942, 81.72218268258231, 76.00983238220215, 71.37568964276994, 66.53410148620605, 68.6435467856271, 65.33924061911446, 66.71483107975551, 64.00595079149518, 62.12926319667271, 54.22341523851667, 56.07828548976353, 53.632602964128765, 53.326364585331504, 53.041696889059885, 50.90831504549299, 45.24703400475638, 48.5959232875279, 45.19424506596157, 48.13178014755249, 47.46022980553763, 50.91879292896816, 57.33563845498221, 59.46622017451695, 59.58885587964739, 58.95977292742048, 55.38508456093924, 52.27656820842198, 50.90530300140381, 46.90203584943499, 45.14840085165841, 46.23169101987566, 45.352549348558696, 50.87262214933123, 54.2298457963126, 57.373443603515625, 55.0514702796936, 54.17374604088919, 52.46207121440342, 50.49040174484253, 55.46288354056222, 60.653264318193706, 54.74620812279837, 50.78428970064436, 51.82770415714809, 56.68148292813982, 58.93972042628697, 62.97158636365618, 51.50669738224575, 52.24085446766445, 58.644408089774, 55.8835448537554, 59.864414487566265, 59.2207681110927, 60.047985894339426, 60.14176573072161, 57.8293149130685, 50.968635831560405, 41.903137002672466, 43.359934534345356, 55.74392427716936, 52.04811838694981, 47.58188581466675, 49.04338380268642, 55.29658188138689, 53.11614336286272, 53.26492166519165, 51.624681268419536, 48.965504918779644, 43.410253388541086, 43.00469398498535, 43.024503299168174, 54.813192231314524, 49.968161242348806, 51.88242816925049, 60.39652143205915, 58.00001130785261, 55.11997604370117, 55.865083490099224, 55.454590865543906, 53.971873079027446, 49.85265438897269, 43.03612763541085, 41.5594756262643, 42.26500613348824, 40.32482589994158, 41.0903263092041, 43.835323333740234, 44.77539028440203, 46.2593309538705, 56.743082182747976, 56.71484817777361, 58.609437806265696, 54.73535851069859, 49.715236391339985, 45.39971719469343, 46.5164281981332, 44.12090124402727, 46.35743951797485, 47.444585936410085, 49.97087103979928, 50.94933026177542, 56.3300221988133, 55.33278547014509, 59.864553451538086, 58.71254212515694, 63.57103524889265, 62.703128814697266, 66.37175682612828, 65.50908933367047, 65.3379135131836, 65.17770195007324, 69.86924375806535, 65.67531108856201, 70.53212274823869, 69.37768650054932, 64.03077670506069, 0.9336562603712082, 0.2717486066477639, 2.1976092542920793, 0.12371206523052283, 0.235373104257243, 12.193484033857073, 70.92083277021135, 50.51628378459385, 44.888305459703716, 35.286384854997905, 35.58625520978655, 46.265216078077046, 31.494697298322404, 0.16504014043935708, 0.01406557038093784, 0.057964254303702285, 0.018755539120840173, 0.00806768807316465, 0.0904454542323947, 0.08887923934629985, 0.05873241022761379, 0.15741867226149353, 0.07009339345885174, 0.1051179054858429, 0.028442060774458305, 0.15716525300272874, 0.048917808303875585, 0.12294768196131502, 0.023981249425560236, 0.20001244598201343, 0.07785565086773463, 0.25257592116083416, 0.07966030295938253, 0.4035020853791918, 0.2850087008305958, 5.585694628102439, 61.37502234322684, 60.4785657610212, 19.11688276699611, 36.865335191999165, 59.139126777648926, 47.11563737051827, 2.2125643832342963, 0.2713527221764837, 1.863781533070973, 2.2733561268874576, 0.11551002892000334, 5.678966377462659, 89.58950287955147, 81.55125699724469, 92.46385451725551, 76.53633907863072, 83.07892268044608, 71.68295982905796, 74.98815536499023, 68.39116042000907, 73.82080241612026, 76.65554932185582, 82.98885318211147, 77.77254867553711, 83.22266006469727, 77.30175958360944, 73.87307371412004, 67.83219868796212, 71.10131222861153, 67.22578770773751, 69.01148169381278, 65.07798835209438, 64.658782686506, 57.663131373269216, 55.90249259131295, 56.40230083465576, 54.76779270172119, 54.91949619565691, 52.927096775599885, 48.93085077830723, 50.72787380218506, 48.169592244284495, 50.54830803189959, 48.251758166721885, 53.74315922600882, 59.71986416407994, 63.46863964625767, 61.910943848746165, 62.925464221409385, 58.156085218702046, 53.582645416259766, 52.91587543487549, 51.13605267660958, 48.53804131916591, 48.85943719318935, 49.017223834991455, 55.148824964250835, 55.60236515317644, 58.621381759643555, 58.7665296282087, 56.46914945329939, 55.04608195168631, 51.668979508536204, 57.32940592084612, 62.419211523873464, 57.56194128308977, 53.061488832746235, 53.615916865212576, 57.39597313744681, 63.72000462668282, 64.5537120274135, 49.62900577272688, 54.38854265213013, 59.836038044520784, 59.923849378313335, 62.31935201372419, 59.79078442709786, 63.358795574733186, 63.53280626024519, 59.96663638523647, 53.20889139175415, 42.58711419786726, 43.9922206061227, 55.89971678597586, 54.94035816192627, 48.128677776881624, 49.13857759748186, 57.535736152103965, 56.60513264792306, 56.47592742102486, 52.92059326171875, 51.217068672180176, 46.47234535217285, 46.378912925720215, 45.64144849777222, 56.330657958984375, 52.277930055345806, 52.56140266145979, 60.613680430821006, 59.70243113381522, 57.87971714564732, 58.1764816556658, 57.9989447593689, 57.06793825966971, 53.34026098251343, 45.66662529536656, 43.8165979385376, 43.65301302501133, 42.99279866899763, 44.21477835518973, 46.177258832114084, 48.609586920057026, 49.66629328046526, 59.357758794512065, 60.49982724870954, 61.566445214407786, 57.14515706471035, 51.24985374723162, 48.039521966661724, 49.43302835736956, 46.27556889397757, 49.12259326662336, 50.01014920643398, 53.08021075384957, 54.13448177065168, 58.46122578212193, 56.73201717649187, 63.01381056649344, 60.50495501926967, 65.37822001320976, 66.48794460296631, 70.66823101043701, 67.50767612457275, 65.46475287846157, 68.723402432033, 74.42990234919957, 66.63656657082694, 73.52848475319999, 69.29109804970878, 73.46172646113804, 2.3116200736590793, 0.9453559411423547, 3.707189645086016, 1.3130892430033003, 0.19867953179138048, 11.03675401210785, 77.04441220419747, 58.73738888331822, 52.11328206743513, 29.646195071084158, 45.27796391078404, 51.610642433166504, 40.15947961807251, 0.19497519199337277, 0.0568460726977459, 0.08587216891880546, 0.07089428191206285, 0.07767299602606467, 0.010823019464234156, 0.04014866938814521, 0.013683819794096053, 0.15123586117156915, 0.05928329245320388, 0.10257976382438626, 0.10699398695890393, 0.20838068266000065, 0.15229067099945887, 0.18900508806109428, 0.18687332102230617, 0.285296481102705, 0.13544531991439207, 0.27770885825157166, 0.22202155712459767, 0.4862798292722021, 0.4890202965055193, 5.951344881738935, 70.42641980307442, 67.74913992200578, 16.36867220061166, 51.65884556089129, 71.92766843523297, 54.141687052590505, 3.4756791421345303, 0.4388778342732361, 2.7011471603597914, 9.220144884926931, 2.1751442083290646, 5.929323434829712, 94.39108330862862, 85.44213008880615, 97.86952522822789, 81.80369200025285, 88.47291346958706, 73.92915957314628, 79.85172067369733, 72.44711576189313, 77.78451347351074, 80.35656983511788, 88.77184581756592, 80.81599862234933, 86.89112826756069, 81.76352446419853, 78.62164633614677, 72.47757666451591, 74.73649161202567, 69.48341029030937, 72.98621259416852, 68.81951686314174, 66.20381191798619, 59.37166213989258, 59.352047375270296, 58.345302036830354, 57.144278117588584, 57.45850345066616, 56.151592458997456, 51.414828300476074, 54.16985157557896, 51.27314758300781, 53.39021505628313, 51.88066332680838, 56.879624707358225, 61.88910566057478, 65.63185010637555, 62.94914368220738, 66.05563463483537, 60.11550848824637, 55.52588285718645, 55.50380495616368, 52.60697937011719, 50.04347971507481, 50.84370027269636, 51.577284131731304, 57.60292870657784, 59.75287505558559, 62.838813236781526, 61.397520610264365, 59.06580938611712, 59.76433958326067, 55.529047761644634, 62.44595514025007, 65.63066891261509, 60.8348137991769, 57.08942903791155, 55.258158343178884, 59.08868980407715, 64.73638016836983, 68.89772578648159, 50.423612185886924, 55.13722842080252, 62.682624680655344, 61.63605226789202, 66.76305157797677, 63.837311063494, 67.07808985028947, 64.87594168526786, 64.25399453299386, 54.86886119842529, 43.27445084708077, 43.95223024913243, 60.32063320704869, 57.198613030569895, 52.613896301814485, 53.43817499705723, 63.30702454703194, 59.87660162789481, 59.85572229112898, 55.889464718954905, 53.72394050870623, 48.21422747203282, 48.95462056568691, 49.23886442184448, 60.25005340576172, 56.29288755144392, 56.54715687888009, 61.24079704284668, 61.95384202684675, 61.48981353214809, 60.615480014256065, 61.202109473092214, 61.20703574589321, 55.15120472226824, 49.013346740177695, 46.99735818590437, 49.11336953299386, 46.38649688448225, 47.211505140577046, 48.654225621904644, 51.395345551627024, 52.34237807137625, 63.68096964699881, 64.13165065220424, 65.09793663024902, 61.262503215244834, 54.875197955540244, 51.019871847970144, 53.026553290230886, 47.60554095676967, 51.782551288604736, 52.37942239216396, 55.75747326442173, 56.642948218754356, 62.17847033909389, 60.513084411621094, 65.91833128247941, 64.19039072309221, 70.12993322099958, 67.9160703931536, 74.21032537732805, 71.20722361973354, 66.9538769040789, 71.12313652038574, 78.63104030064174, 71.46493925367082, 76.79735510689872, 72.60686874389648, 73.4704395021711, 1.554706877895764, 3.6970066257885525, 11.468950203486852, 0.959635792034013, 0.3171516646231924, 16.755884885787964, 86.04330212729317, 61.563846588134766, 61.88068444388253, 50.43312774385725, 50.41836977005005, 60.06396675109863, 50.00097411019461, 0.5210773849061557, 0.2025941088795662, 0.14132321093763622, 0.10378435347229242, 0.13697556565914834, 0.11887713681374278, 0.1262347362935543, 0.12314387357660703, 0.2316464270864214, 0.20231543454740727, 0.16424788295158319], [0.07658733999622719, 0.057697766460478306, 0.08675369447363274, 0.10800903463470084, 0.07148301960634333, 0.12653928995132446, 0.06901653124285595, 0.12833359438393796, 0.06906653927373034, 0.1567983284060444, 0.25659580688391415, 11.088524171284266, 60.12147004263741, 30.86861596788679, 30.41622917992728, 46.877835273742676, 46.48090900693621, 43.04282917295183, 0.040923305321484804, 0.33945606063519207, 0.8728314584919384, 3.897745294230325, 0.6842729278973171, 21.948537724358694, 89.63599327632359, 78.07912404196603, 85.91191864013672, 77.17760222298759, 74.21560600825718, 68.53132643018449, 72.39417048863002, 65.00938878740583, 64.9033453805106, 61.510498319353374, 69.14869471958706, 75.04867417471749, 76.02024773189, 74.63453374590192, 69.19245447431291, 64.61899730137416, 66.1420076915196, 63.983918053763254, 61.05431434086391, 56.723804405757356, 55.12697982788086, 54.13825464248657, 54.91357633045742, 52.47749274117606, 52.1817843573434, 52.18155854088919, 47.34007460730416, 46.50158337184361, 48.166177204677034, 45.76915986197335, 47.22674601418631, 46.457083633967805, 52.30110924584525, 56.46409116472517, 58.361998558044434, 59.545401845659526, 55.758185454777305, 52.597099031720845, 49.74439103262765, 48.09486436843872, 47.81143345151629, 47.17990473338536, 45.47051239013672, 47.089494773319785, 54.79154511860439, 55.180390630449565, 56.37396955490112, 54.02242817197527, 52.883910247257774, 48.55124984468733, 51.064180510384695, 54.01540354319981, 56.01288209642683, 52.02019705091204, 49.77523756027222, 51.89389269692557, 56.72297409602574, 60.022173336574006, 50.00138405391148, 45.51253162111555, 52.82723379135132, 57.60151127406529, 56.44229119164603, 54.13937677655901, 54.5722564969744, 51.055186067308696, 51.17432335444859, 52.17586101804461, 55.81980902808053, 53.6480244909014, 49.25873626981463, 47.00354208265032, 51.82205874579293, 46.90568365369524, 46.05075298036848, 54.04768834795271, 53.1052451133728, 52.28268609728132, 55.31524474280221, 54.01288482121059, 48.572994232177734, 42.353932653154644, 41.8995760508946, 47.640049185071675, 52.871101243155344, 45.95316553115845, 50.64100742340088, 56.67659139633179, 58.924351011003765, 55.11138112204415, 55.03146641595023, 54.768848827907014, 52.74889980043684, 47.19805690220424, 40.456237179892405, 39.6166342326573, 39.17652491160801, 40.626607009342735, 41.74755988802229, 43.12384169442313, 44.54316064289638, 51.20695556913103, 53.65263114656721, 55.227860723223, 49.90855264663696, 44.82143599646432, 44.23291662761143, 45.887230600629536, 46.143987383161274, 46.85047674179077, 49.01013667242867, 55.57219607489449, 54.94453402927944, 56.098383154187886, 57.76722233636038, 58.78673498971121, 60.59588609422956, 64.01653984614781, 63.401130948747905, 67.70083604540143, 61.52829960414341, 67.19311032976422, 67.30329486301967, 70.02033928462437, 62.345088141305105, 72.31887980869838, 67.71009799412319, 80.3511710848127, 19.959324053355626, 0.371068247194801, 1.07337215755667, 0.12774607805269106, 0.022121520646448647, 1.5759132142577852, 60.273246492658345, 56.97266108649117, 47.02365711757115, 39.4709061895098, 29.005631957735332, 39.57126596995762, 36.33042812347412, 0.31030478488121715, 0.07099675427057914, 0.11880970400358949, 0.02738806009957833, 0.08949412778019905, 0.039824350005281825, 0.03572111304051109, 0.022416118499157683, 0.12414045152919632, 0.0434667463414371, 0.1822399582181658, 0.03614919739110129, 0.0699965257995895, 0.06682926682489258, 0.08649326594812529, 0.08071579810764108, 0.2317179718187877, 0.01647101010062865, 0.12540532222815923, 0.04036416532471776, 0.14030266712818826, 0.3261485775666577, 15.799520935331072, 68.87485231672014, 40.82603767939976, 30.976622240883962, 34.555187702178955, 56.17068958282471, 45.51758990968977, 0.019448396317394714, 0.5884791995797838, 1.9438638644559043, 5.705209289278303, 0.5911722779273987, 26.708804164613994, 97.16012110028947, 78.72359030587333, 88.0494694028582, 77.14031818934849, 77.84107181004116, 71.68975516727993, 76.25321388244629, 68.64110101972307, 66.96110303061349, 63.87567206791469, 70.69134766714913, 76.50701768057687, 79.6664400100708, 74.83166803632463, 70.04748589651925, 68.17082609449113, 67.26662227085659, 65.13747188023159, 61.689240728105815, 57.40618004117693, 57.716879163469585, 56.66434519631522, 57.08198751722063, 54.69336707251412, 55.690895625523154, 53.50133759634835, 49.08758129392351, 49.6317537852696, 50.59648336683001, 48.49565035956246, 49.989898681640625, 48.70437771933419, 54.13183798108782, 58.773436137608115, 62.08443341936384, 60.15654454912458, 57.76262262889317, 55.76239258902413, 53.07725082124983, 51.98158591134207, 51.39617586135864, 49.24711193357195, 47.55647625241961, 50.40082556860787, 57.61108936582293, 57.34501157488142, 59.5157538822719, 55.57882118225098, 55.64988735743931, 51.49036564145769, 53.02234615598406, 56.63218198503767, 57.67535672869001, 55.386133738926475, 51.66980634416853, 52.70168331691197, 57.65781947544643, 60.41976315634591, 48.91003050122942, 46.875483308519634, 55.06143399647304, 60.42334147862026, 57.919537271772114, 56.599087715148926, 55.89981058665684, 53.278706891196116, 53.37687798908779, 54.18026692526681, 57.08704233169556, 56.21140602656773, 50.908815315791536, 46.943700722285676, 52.76870216642107, 47.87056956972395, 47.95901666368757, 57.78288010188511, 55.569764205387656, 55.56369147981916, 59.124118668692454, 56.149893624441965, 52.84525047029768, 44.260577406202046, 45.28816039221627, 49.1618401663644, 55.42866366250174, 51.12993131365095, 53.37542234148298, 56.56607334954398, 60.317930357796804, 59.217829023088726, 56.49600076675415, 57.480049814496724, 57.855096203940256, 49.7834016936166, 43.36190782274519, 41.84896189825875, 41.98209980555943, 44.215223039899556, 45.682109355926514, 46.06163385936192, 47.25412539073399, 53.17482437406267, 55.0043614932469, 56.834673336574006, 51.81130640847342, 47.20367104666573, 47.40413352421352, 48.602270466940745, 48.623587540217805, 48.72674397059849, 53.7437150818961, 59.205384799412315, 58.24285084860665, 59.620845385960166, 59.80807849339077, 61.60472978864397, 63.42037051064627, 67.38913985661098, 65.17043413434709, 69.9138650894165, 63.80320235661098, 68.1388018471854, 70.53559684753418, 73.4123317173549, 65.96590559823173, 74.17003972189767, 70.94351169041225, 81.9487703868321, 26.933055537087576, 0.5723282748035022, 0.824870052082198, 1.6853760033845901, 0.050069763990385194, 1.2180953174829483, 64.50451183319092, 63.080548013959614, 56.66539784840175, 35.428183691842214, 34.77482025963919, 49.65693405696324, 45.536819049290244, 0.8893365785479546, 0.0792091925229345, 0.07770870053874594, 0.05396590188943914, 0.06348761077970266, 0.015508808428421617, 0.001461149357575258, 0.030465516660894667, 0.05667742621153593, 0.09219719416328839, 0.08890242488788706, 0.1510724699390786, 0.21733340940305165, 0.1831871388213975, 0.17990715482405253, 0.18083423722003186, 0.27388010227254456, 0.1187355536967516, 0.21165895674909863, 0.20830524313662732, 0.20325962959655694, 0.5722362111721719, 15.79195955821446, 81.0525153023856, 42.676832812173025, 39.34232977458409, 62.739315032958984, 64.07006876809257, 51.520072664533345, 0.12951212828712805, 0.6449520406978471, 3.405783304146358, 10.401077219418116, 1.1547941884824207, 27.77534396307809, 101.28660065787179, 82.48989609309605, 90.66826629638672, 82.7879251752581, 82.3687264578683, 74.0261286326817, 79.63319287981305, 69.95255960736955, 71.83684853145054, 67.30920083182198, 75.68262781415666, 78.72082492283413, 83.51118401118687, 79.86631883893693, 74.63960593087333, 68.60590144566127, 73.0287355695452, 69.51687281472343, 65.65116609845842, 62.18564782823835, 59.75265966142927, 60.15896252223423, 60.184670857020784, 55.554620606558665, 57.65335873195103, 56.674385343279155, 53.59042045048305, 53.16268239702497, 53.822698729378835, 51.12228829520089, 51.84443889345442, 52.485903535570415, 57.96372781481062, 62.07968085152762, 64.30338232857841, 64.34506457192558, 61.05143778664725, 56.69370133536202, 55.545289175851, 53.4587972504752, 52.51738234928676, 52.602980681828086, 50.015752928597585, 52.24358510971069, 60.82412052154541, 58.84972735813686, 62.76991489955357, 59.76525674547468, 58.961739267621724, 54.219076088496614, 57.46453448704311, 60.659198079790386, 61.642326491219656, 58.230205127171104, 56.24036264419556, 56.28222206660679, 59.11589894975935, 65.55783094678605, 51.278799942561555, 48.57800040926252, 56.97651733670916, 61.99612181527274, 61.724829401288716, 59.76932838984898, 56.78025157111031, 52.87537785938808, 54.25956324168614, 56.87132855824062, 59.27330344063895, 57.002111026218955, 50.41462121691023, 49.41805151530674, 56.580289363861084, 51.38835913794381, 50.89522116524832, 59.66485527583531, 57.5074257169451, 58.82650647844587, 61.83277661459786, 58.84928962162563, 55.71748290743147, 46.64819383621216, 46.994697025844026, 53.21249055862427, 58.28658281053816, 54.42720937728882, 57.10278000150408, 58.76158945901053, 63.09687628064837, 60.568600518362864, 61.068043981279644, 59.56300163269043, 59.35792555127825, 54.00682599203927, 45.67218385423933, 45.41025761195591, 45.30909878867013, 47.11093691417149, 48.071073736463276, 47.93487862178257, 49.745891843523296, 56.81718124662127, 59.47346714564732, 60.19639246804373, 55.206863267081125, 49.78012561798096, 50.70949929101126, 51.77822950908116, 51.53433036804199, 51.18928630011422, 55.122824805123464, 62.28702899387905, 60.64369664873396, 63.237063135419575, 62.4746789932251, 65.30830029078892, 65.56614099230084, 71.19573129926408, 68.36117199489048, 71.89128766741071, 65.23534420558384, 71.35993807656425, 72.6269976752145, 77.36471026284354, 68.99197115216936, 77.56559658050537, 74.6541415623256, 86.94808959960938, 25.724067245210918, 0.803869230406625, 5.307701545102256, 1.8631190657615662, 0.19736887354935917, 2.663896130664008, 73.01009355272565, 68.44812870025635, 62.879828453063965, 55.71614537920271, 38.289406708308626, 51.27128546578543, 54.7037615776062, 1.0361357842172896, 0.1405868918767997, 0.21011424463774475, 0.1282130322818245, 0.15353958255478314, 0.13112796443913663, 0.13447333207087858, 0.08940809632518462, 0.19685595535806247, 0.22447101425911697, 0.3239141617502485], [0.05671209256563868, 0.05410627382142203, 0.06874559899525982, 0.049640482025487084, 0.047774134137268574, 0.10320865043572017, 0.15320686969373906, 0.024079623432563882, 0.03357263707688876, 0.06578844160373722, 0.09408433575715337, 25.846385070255824, 67.17678901127407, 24.23750536782401, 44.97182975496565, 45.243188176836284, 58.838909012930735, 26.11465675490243, 0.41526826258216587, 0.9327433322157178, 1.6323418148926325, 12.29069367476872, 0.780556287084307, 51.96402781350272, 93.59295068468366, 84.58786296844482, 88.00971181052071, 74.3996776853289, 73.28578417641776, 70.35659040723527, 69.91989612579346, 66.02747358594621, 63.87879875728062, 60.122547013419016, 58.32492297036307, 59.09488064902169, 64.37301022665841, 64.5391902923584, 62.80899156842913, 57.91183519363403, 56.09444005148751, 56.39916719709124, 52.656884806496755, 52.47163540976388, 54.05373675482613, 53.223274162837434, 51.728167738233296, 54.02449526105608, 55.030118465423584, 49.424339635031565, 45.37624965395246, 46.361549377441406, 46.589596203395296, 46.80993400301252, 46.609318665095735, 48.04115826742989, 53.4808577810015, 56.10960449491228, 57.93327733448574, 55.3529873575483, 53.25429092134748, 50.159396512167795, 51.454033511025564, 50.53847285679409, 49.84944779532296, 46.15304783412388, 45.40878806795393, 50.32795980998448, 53.7833753994533, 54.86477565765381, 52.007999488285606, 52.358004570007324, 47.83983768735613, 47.67278214863369, 52.354711123875205, 55.463251795087544, 55.37617349624634, 51.081380775996614, 51.56652137211391, 51.88767058508736, 56.07842445373535, 51.842239788600374, 53.76105431147984, 52.89267539978027, 60.115883690970286, 60.97606372833252, 54.04737220491682, 55.92763464791434, 55.54018572398594, 58.608715193612234, 56.41881670270647, 55.755972453526084, 54.357376507350374, 53.86768136705671, 55.45279475620815, 51.298901081085205, 44.92118780953543, 41.81594753265381, 45.62582894733974, 49.907687595912385, 55.299225670950754, 55.4805006980896, 54.6643340247018, 55.893758705684114, 54.42587184906006, 47.14420141492571, 39.69220284053257, 43.896318095070974, 49.41994489942278, 51.904360158102854, 46.02181025913784, 46.96674789701189, 50.637074742998394, 62.28263078417097, 57.60855674743652, 55.221697671072825, 53.6012179510934, 50.32713644845145, 46.49670573643276, 40.22367055075509, 39.61390706471035, 38.753598485674175, 43.4347562108721, 42.805496079581125, 44.623304639543804, 45.34034831183297, 51.08828728539603, 47.44398839133126, 47.12409332820347, 46.15497943333217, 46.44274255207607, 45.63810294015067, 45.23124074935913, 48.965345110212056, 54.451739992414204, 58.58118643079485, 61.68626689910889, 58.86358206612723, 59.8863707951137, 62.21075861794608, 63.99814796447754, 63.96624183654785, 68.0472662789481, 64.08835642678397, 63.30201489584786, 68.4716066632952, 68.16462135314941, 68.70352363586426, 65.48003196716309, 67.23037351880754, 70.01787267412458, 73.62809412819999, 55.86437824794224, 0.14367779530584812, 0.9467884642737252, 3.277957511799676, 0.04121428827888199, 0.053818167852503915, 34.043359075273784, 71.06303460257394, 44.95301750728062, 43.124404498508994, 34.84424665996006, 34.73650441850935, 46.686349868774414, 1.907868287393025, 0.16112431484673703, 0.07955857020403657, 0.09495791566691228, 0.10994336155376264, 0.03746604387249265, 0.0901380100154451, 0.09765779972076416, 0.054085256199219396, 0.04747291547911508, 0.040901307216180224, 0.04716683851022806, 0.05631143460050225, 0.0557353278355939, 0.09973563001091991, 0.06547031724559409, 0.13814663567713328, 0.05909911769309214, 0.05496423724772675, 0.04759620529200349, 0.09834634991628782, 0.0669714334819998, 36.31302636010306, 70.45911107744489, 39.01753623144967, 39.8239997455052, 39.60015310559954, 72.3911966596331, 27.138287952968053, 0.4458452489759241, 1.1439354568719864, 3.409464546612331, 17.06607505253383, 3.045439737183707, 58.94995512281145, 95.19781085423061, 84.89095033918107, 89.17864200047084, 76.22829764229911, 76.6361221585955, 73.09431266784668, 72.57567828042167, 69.43635014125279, 67.01887730189732, 61.543967791966026, 59.9129615511213, 60.840622493198936, 67.92947346823556, 66.52183096749442, 63.54130390712193, 60.39918259211949, 58.834816523960654, 57.59599787848336, 55.27924265180315, 53.80961874553135, 55.56901032584054, 55.6144654410226, 54.9357966695513, 57.1176769392831, 57.28658764702933, 52.673355511256624, 49.03735624040876, 48.64177792412894, 48.57658645084926, 48.12067345210484, 49.036171572549, 49.86186075210571, 57.840584891183035, 58.63315200805664, 61.3997996194022, 57.616540227617534, 55.66883162089756, 53.25360999788557, 53.858207498277935, 53.012368542807444, 53.02174513680594, 47.59619215556553, 47.48451028551374, 53.08023507254464, 56.62656436647688, 57.93513250350952, 53.797212736947195, 57.48735237121582, 50.33930969238281, 49.96164730616978, 54.365200178963796, 58.68424211229597, 57.31530802590506, 55.28116382871355, 53.273130961826865, 53.155164446149556, 55.10893188204084, 53.182953766414094, 55.95107092176165, 55.73916823523385, 63.09356893811907, 62.626775060381206, 56.47833149773734, 56.58065414428711, 58.61564254760742, 60.13697842189244, 57.667526108878, 57.77103689738682, 58.35798944745745, 55.371907302311485, 59.59763145446777, 53.30304643086025, 44.26495129721505, 45.27159241267613, 47.31382431302752, 50.96069056647164, 57.65531464985439, 57.33082682745797, 58.06392778669085, 57.972420011247905, 58.20303072248186, 50.76523079190935, 42.4591874395098, 45.561036995479036, 52.694391182490754, 53.99967976978847, 51.45475264957973, 50.17692681721279, 51.18866791043963, 62.482933453151155, 58.96003001076834, 57.73444768360683, 57.32224580219814, 53.750673702784944, 49.60733086722237, 41.82580702645438, 43.66604437146868, 41.04541662761143, 45.020449774605886, 45.218879904065815, 46.364651748112266, 47.49962261744908, 51.99820600237165, 49.94847699574062, 49.268706934792654, 47.257081849234446, 49.05856214250837, 47.331778458186555, 49.39082152502877, 52.26720551082066, 58.09907872336251, 60.683989252362935, 64.5455687386649, 62.43563706534249, 61.98447663443429, 65.8243499483381, 67.21153695242745, 65.9414757319859, 69.43507862091064, 64.59248297555106, 66.40046678270612, 68.59736210959298, 71.90289115905762, 69.38828250340053, 68.03769860948834, 65.91324520111084, 73.1834580557687, 73.81449345179966, 66.0348595210484, 0.36859829830271856, 1.8609851002693176, 4.227470321314676, 0.21189558905150208, 0.21299431366579874, 34.76272691999163, 76.33727318899972, 55.54277392796108, 44.54236160005842, 29.01691062109811, 43.01562350136893, 53.58267320905413, 3.342458073581968, 0.2837068092610155, 0.15104680774467333, 0.14106133713253907, 0.10597244570297853, 0.03232509955497725, 0.17551889243934835, 0.0787863837821143, 0.08167703795645918, 0.015216705888243658, 0.009108891577592917, 0.17071361600288323, 0.1791374518402985, 0.12500957346388272, 0.1792389063962868, 0.11915407409625393, 0.1901658307760954, 0.2327286090169634, 0.12955916433462075, 0.15654473272817476, 0.224599528791649, 0.2547659607870238, 38.986835615975515, 85.46416977473667, 34.6288594518389, 56.19116939817156, 63.22514002663748, 77.17072350638253, 33.73746115820748, 0.5904107445052692, 2.094235258443015, 4.923668963568551, 26.234077181134904, 4.974997477872031, 57.075258186885286, 98.24852166857038, 91.09589317866734, 93.66469083513532, 79.84289646148682, 79.91314274924142, 76.53724234444755, 76.7328132901873, 72.56674289703369, 72.09816333225795, 65.33696855817522, 64.34524522508893, 63.24672113146101, 70.13331004551479, 70.37937355041504, 67.39337130955288, 60.955212184361045, 62.0614835194179, 60.92425101143973, 57.73005294799805, 57.23044620241438, 58.33679049355643, 58.912664140973774, 57.088515349796836, 58.14602770124163, 59.3823276247297, 54.939232553754536, 51.877168382917134, 51.4686837877546, 51.63384594236101, 49.795988355364116, 50.02128022057669, 53.390645844595774, 61.73057556152344, 60.47138827187674, 64.37197494506836, 60.602577209472656, 60.26294231414795, 56.145571844918386, 56.10120759691511, 54.38322033200945, 57.82611526761736, 50.88955838339669, 51.12879180908203, 56.9342167036874, 61.52714620317732, 61.213351658412385, 56.76024770736694, 59.629746028355186, 55.00976024355207, 54.23034259251186, 57.104027203151155, 62.74966090066092, 61.146878242492676, 58.391611780439106, 56.890762669699534, 55.48821667262486, 57.79078367778233, 53.40105077198574, 56.113974911826, 57.02511303765433, 65.40998717716762, 64.61818436213902, 57.226336342947825, 58.71629415239607, 60.154119627816335, 62.61208656855992, 59.6986791065761, 60.60449491228376, 59.08556311471121, 59.38999148777553, 62.71922084263393, 54.03347928183419, 47.42189311981201, 47.47403935023716, 47.04878875187465, 53.97966200964791, 61.918996810913086, 59.76944650922503, 59.279285839625764, 61.53369140625, 59.33118888310024, 52.855672768184114, 44.602967262268066, 49.19994756153652, 55.95849507195609, 58.327424321855815, 53.185423851013184, 53.266175815037315, 55.10108041763306, 63.5334107535226, 59.626806940351216, 61.25537436349051, 58.6623900277274, 55.91137933731079, 51.3534722328186, 44.59123175484793, 45.42971951620919, 44.56728131430489, 48.142056533268516, 47.41542782102312, 50.71282400403704, 50.65675204140799, 55.463929244450156, 53.415301527295796, 52.375180516924175, 51.59799671173096, 53.11872461863926, 50.32019519805908, 50.689676080431255, 54.81273365020752, 60.845312527247835, 64.16008268083844, 68.72890540531704, 65.35536738804409, 65.24589157104492, 68.05013588496617, 70.07332624707902, 67.77693271636963, 73.15770803179059, 67.23445905957902, 67.91557012285504, 71.75475556509835, 75.30700125013078, 73.16510786328996, 71.52110154288155, 70.39973872048515, 77.90241745540074, 77.71586527143205, 66.04874202183315, 0.36860945341842516, 4.641617264066424, 9.218870759010315, 0.17561544797250203, 0.23342858574220113, 42.93767166137695, 84.74822044372559, 59.893527439662385, 63.31311811719622, 47.858372007097515, 46.88424498694283, 65.73378712790353, 3.604693510702678, 0.32740120749388424, 0.2247954761343343, 0.2941425692822252, 0.3258761593273708, 0.11392681673169136, 0.20291573447840555, 0.17557827782418045, 0.16890738292464189, 0.09784997440874577, 0.09582454059273005], [0.13121124782732554, 0.034309217373707464, 0.07561469397374562, 0.1422694687332426, 0.04299927303301437, 0.025162728170731237, 0.07914600734199796, 0.050520301064742465, 0.12270840337233883, 0.05875785529081311, 0.7655001921313149, 48.04201289585659, 52.45928498676845, 21.245098624910625, 46.61779546737671, 38.01279892240252, 66.34748676845005, 11.552283423287527, 0.21829177226339067, 0.8161123363035065, 2.781135691063745, 0.14621111936867237, 5.534721340451922, 89.60706097739083, 77.4963160923549, 84.90517330169678, 77.01079681941441, 75.92296600341797, 69.34000641959054, 70.11589785984584, 68.79270376477922, 66.01186793191093, 61.00407886505127, 59.78756741115025, 56.22504186630249, 55.03153242383684, 53.392028536115376, 54.995912483760286, 55.467160156794954, 54.36664193017142, 55.13516133172171, 55.32714353288923, 54.60345043454851, 55.331176962171284, 52.66604253223964, 52.73662233352661, 52.232054574149, 56.88685083389282, 51.15131786891392, 44.61843047823225, 45.21163988113403, 47.449310711451936, 47.854369844709126, 48.78788464409964, 47.420934268406455, 48.49567467825753, 53.348737784794395, 55.00987488882882, 56.213990756443565, 54.70397697176252, 54.21698815482003, 54.18572473526001, 53.02858911241804, 51.13893617902483, 46.095999649592805, 47.85695110048567, 46.79606192452567, 51.83474268232073, 53.00788000651768, 52.893363271440776, 51.2130560874939, 48.98852777481079, 47.08192818505423, 49.94244943346296, 50.94258008684431, 53.16001428876604, 53.3918583052499, 50.582451479775564, 54.07858003888811, 51.90421077183315, 52.18898269108364, 57.38212537765503, 59.29869910648891, 56.681343964168, 55.79624768665859, 55.505896363939556, 52.430175508771626, 51.98307977403913, 51.116952078683035, 52.04703794206892, 50.207022939409526, 48.8972875050136, 52.88338565826416, 51.40949903215681, 56.478348868233816, 53.97104971749442, 47.164451939719065, 47.592231682368684, 43.3404552595956, 42.14096341814314, 49.68070037024361, 51.90938023158482, 52.98902606964111, 54.37691484178816, 56.15038694654192, 48.499746322631836, 42.810530049460276, 40.829188687460764, 43.74205766405378, 47.6562419618879, 51.466168539864675, 51.135191099984304, 46.83471475328718, 46.90897362572806, 60.09608827318464, 56.54324851717268, 53.02816527230399, 54.088126863752095, 49.421654156276155, 39.74915722438267, 39.671351296561106, 38.52912998199463, 40.63904775891985, 41.122725759233745, 43.62488324301583, 42.002993038722444, 44.59766231264387, 44.59846830368042, 45.00455577032906, 44.514811992645264, 46.782408714294434, 43.12716293334961, 49.9767735345023, 56.61507552010672, 60.56253474099295, 62.06329699925014, 62.35558686937605, 62.01836994716099, 64.99138600485665, 63.031987054007395, 66.48605469294957, 64.43782302311489, 67.31223719460624, 65.73220988682338, 68.32654912131173, 66.40971483503068, 71.57636056627545, 61.63178607395717, 65.23654624394008, 61.64734309060233, 74.64328152792794, 64.79973384312221, 81.50227914537702, 8.878645266805377, 5.2437494567462375, 4.513872895921979, 0.04333813002865229, 0.14167351142636367, 12.114139080047607, 71.78317369733537, 52.17712211608887, 39.42319985798427, 37.38660989488874, 31.636485712868826, 43.615857533046174, 3.1532013033117567, 0.4014073392110211, 0.12027761952153274, 0.2638121082314423, 0.06956043134310416, 0.20812136014657362, 0.008957046466613454, 0.0734754969765033, 0.052667348712150536, 0.12925181511257375, 0.039113180844911506, 0.102050452227039, 0.0759298259924565, 0.07023150926189763, 0.122474376644407, 0.12368921217109476, 0.042711825243064334, 0.14406184612640313, 0.08489336858370475, 0.11043193390859024, 0.07495952091578927, 1.1520368392978395, 58.07526724679129, 60.934763635907856, 25.18465600694929, 37.45267684119088, 43.05063199996948, 76.08963939121791, 10.80751383304596, 0.3085048214665481, 0.6986590645142964, 4.5928352645465305, 0.4139812987829958, 7.137889623641968, 94.69572707584926, 78.47253799438477, 89.05653435843331, 77.94935253688267, 78.60242761884416, 72.45607198987688, 73.81344427381242, 70.50492055075509, 67.91890525817871, 64.09547138214111, 60.95357240949358, 58.51410157339913, 59.42733110700335, 56.51606021608625, 58.34259223937988, 57.077797753470286, 57.113153662000386, 58.27933236530849, 56.98313202176775, 55.806541442871094, 56.320489270346506, 54.160301276615684, 54.10947520392281, 52.87132011141096, 58.3805433000837, 53.03255653381348, 47.7647693497794, 47.52425398145403, 48.931764466421946, 49.97431039810181, 51.50663832255772, 49.35185602733067, 51.54121603284563, 55.75483294895717, 58.40158939361572, 58.749805314200266, 56.11354759761265, 57.01588582992554, 58.44325079236712, 55.80381080082485, 56.295687675476074, 49.65852519444057, 49.95993110111782, 49.0793650490897, 52.09292037146432, 55.05451011657715, 56.19545643670218, 53.18160234178816, 52.24901165281023, 49.07872234072004, 53.556798117501394, 54.770255838121685, 57.801886899130686, 54.91816561562674, 53.426943234034944, 53.948495864868164, 52.28998170580183, 53.386084352220806, 59.342438016619, 62.65331717899868, 58.125349862234934, 56.504811082567485, 56.9764061655317, 55.61358649390084, 55.44362660816738, 52.88941669464111, 52.62934562138149, 51.4447090285165, 51.34490162985665, 55.97182519095284, 53.4393527167184, 59.00588812146868, 54.77340684618269, 49.08587203707014, 48.80795798982893, 47.426124572753906, 42.805117402757915, 49.92571817125593, 53.13545935494559, 53.13495213644845, 56.3370954649789, 57.833733967372346, 51.6760527747018, 44.98498616899763, 43.18478087016514, 44.531122888837544, 50.50013269696917, 53.78159318651472, 54.11224406106131, 50.558956146240234, 47.72730118887765, 57.53748362404959, 58.84339754922049, 54.13783080237252, 55.94030816214425, 51.261273111615864, 42.8155049596514, 43.41958481924874, 39.85684388024466, 41.61300802230835, 42.73388794490269, 47.40777438027518, 44.86545283453805, 47.210893699101035, 47.15639550345284, 47.63931267602103, 45.17665917532784, 48.39394262858799, 48.012483051845, 53.75305346080235, 59.74603107997349, 63.821469170706614, 62.98246724264962, 65.53476292746407, 65.0503762108939, 68.28880650656563, 65.2229972566877, 70.40207331521171, 65.36563682556152, 67.97490079062325, 65.38608537401471, 71.59421048845563, 68.16880416870117, 72.63085392543248, 63.434822763715474, 68.95588220868791, 62.96916144234793, 78.54516751425606, 66.06287465776715, 85.69606590270996, 12.95308107989175, 3.9535358548164368, 4.2566640462194165, 0.088835290633142, 0.11552429172609534, 11.403119495936803, 78.28703498840332, 58.435427120753694, 46.29769195829119, 30.372677871159144, 41.98007787976946, 53.59894936425345, 5.015745622771127, 0.4163012642945562, 0.20730956085026264, 0.28556010552815025, 0.15375425746398313, 0.18692550036524022, 0.016035551770723293, 0.11646628832178456, 0.06540634496403591, 0.07074663269200496, 0.0335260318991329, 0.2895580881408283, 0.16115016703094753, 0.2220701945147344, 0.21881600841879845, 0.17306213426802838, 0.13137239989425453, 0.2762857531862599, 0.20314821414649487, 0.20485880092850753, 0.32444162773234503, 1.234175946031298, 64.47765704563686, 70.55908870697021, 29.255393641335623, 59.60428088051932, 53.39955690928868, 83.5924709865025, 16.420814956937516, 0.7310429353799138, 2.1091530408178056, 8.780283961977277, 2.4403141736984253, 8.367151890482221, 96.0979082924979, 84.11601775033134, 92.60914134979248, 83.31461252485002, 82.35245377676827, 75.69978986467633, 77.73285361698696, 74.90072618212018, 70.90649863651821, 66.3256207874843, 65.30268614632743, 62.120091574532644, 60.990953717912944, 57.62957157407488, 60.40510940551758, 60.323898860386436, 59.95048182351248, 59.34924725123814, 60.196274348667686, 59.51173782348633, 61.28986522129604, 56.11329051426479, 56.76152270180838, 55.25457307270595, 61.480106898716514, 56.70058700016567, 52.02343838555472, 50.78569323675973, 52.7007348878043, 52.35900511060442, 54.65015969957624, 52.29342106410435, 53.59278283800398, 58.61555222102574, 62.105951990400044, 61.57166331154959, 58.941485268729075, 58.79132080078125, 60.0752923148019, 58.82078116280692, 56.621638093675884, 51.65274156842913, 54.30835001809256, 52.14355884279524, 54.74428694588797, 59.84222194126674, 59.60861655644008, 56.66023186274937, 55.53463063921247, 52.438190255846294, 55.27832201548985, 57.82118552071707, 60.099041257585796, 59.176118986947195, 55.649317605154856, 58.799387659345356, 55.0757611819676, 55.32196365083967, 61.224406242370605, 64.91242667606899, 61.72981125967843, 60.172942297799246, 60.16695295061384, 59.48203427450997, 59.09854234967913, 57.21043886457171, 58.81614671434675, 57.23518834795271, 55.9046847479684, 58.3384233202253, 55.270362854003906, 60.95792198181152, 57.345143590654644, 48.74171386446272, 48.96335792541504, 50.91402646473476, 47.34380578994751, 54.68059975760323, 56.65254020690918, 57.74419948032924, 57.086114747183665, 62.36791297367641, 53.364603996276855, 46.58817182268415, 45.825273513793945, 47.352119309561594, 53.11281170163836, 57.403894083840505, 55.77446160997663, 53.31706094741821, 52.94166367394583, 60.15869154248919, 60.39394365038191, 57.79270485469273, 59.19419819968087, 55.679757663181846, 44.27276454653059, 47.97499752044678, 43.64400121143886, 46.028334617614746, 45.60050276347569, 50.01518317631313, 46.32623168400356, 50.16686929975237, 50.80453675133841, 50.05715376990182, 49.53986038480486, 51.77894517353603, 49.955296652657644, 55.48709453855242, 61.742741857256206, 67.42497866494315, 67.58430780683244, 68.73466546194894, 68.59037222181047, 72.17650427137102, 68.08521733965192, 72.64165142604283, 66.85412161690849, 72.02145521981376, 67.58284868512834, 75.4554078238351, 71.58911051068986, 77.64306899479458, 65.14462157658168, 73.90198516845703, 65.32776914324079, 82.54207706451416, 68.88074438912528, 89.19953523363385, 11.462335518428258, 10.409788523401533, 13.425201620374407, 0.13193574680813722, 0.2986634038388729, 17.32813331059047, 88.03316892896379, 62.90684999738421, 55.41584423610142, 50.207141058785574, 43.99426685060774, 63.954631396702354, 6.314053876059396, 0.47591213988406317, 0.40230759233236313, 0.401677206158638, 0.2738276922277042, 0.31872749435050146, 0.157995766294854, 0.18455710102404865, 0.18102282924311502, 0.30458071774670054, 0.150947863768254], [0.04063592538503664, 0.02964547655678221, 0.06687808741948434, 0.07927012496760913, 0.056520009479884586, 0.016826971267749156, 0.13688328489661217, 0.050903059276086945, 0.20612888277641364, 0.1391354240477085, 4.174482924597604, 58.386713300432476, 46.91948972429548, 43.82929229736328, 49.3221663747515, 39.39293697902134, 74.71778011322021, 4.323194350515093, 0.03399051965347358, 0.625574817614896, 0.7755037524870464, 1.4413197679179055, 21.957077060426982, 96.72539315904889, 75.36827046530587, 84.28385843549455, 75.28307860238212, 74.69920757838658, 69.76356165749687, 73.10577719552177, 64.86487320491246, 67.34619304112026, 57.81166301454817, 58.306843757629395, 56.51822110584804, 58.998974663870676, 56.131953375680105, 56.09988743918282, 52.05019589832851, 53.414714404514854, 49.9301233291626, 54.42818559919085, 51.228171893528526, 53.321632862091064, 52.8805056299482, 53.99676500047956, 51.94739382607596, 52.53727504185268, 48.1263883454459, 44.94275154386248, 44.35654592514038, 45.70762661525181, 46.3331173488072, 49.00994907106672, 45.4774432182312, 49.13709763118199, 50.92863505227225, 55.10144172395979, 55.62684713091169, 56.359239373888286, 59.06286334991455, 56.2494752066476, 55.19192811420986, 55.11571332386562, 48.119853564671104, 48.6286631992885, 48.08981997626168, 51.284493991306846, 49.00307035446167, 49.33456890923636, 49.35235629762922, 48.49428851263863, 46.79799004963466, 50.3615265573774, 52.637558392116, 54.28696346282959, 52.39994042260306, 51.69988162176949, 46.116555895124165, 50.52205078942435, 54.00566911697388, 53.885083130427766, 55.516144956861226, 55.413797991616384, 57.564661502838135, 49.590655190604075, 50.45456641060965, 53.28014169420515, 52.82590668542044, 53.979005404881065, 50.25526080812727, 48.41980382374355, 50.69566542761666, 54.815763064793174, 53.89365373338972, 52.420166628701345, 52.71680954524449, 46.48544270651681, 42.80060107367379, 44.45702035086495, 40.3221195765904, 42.348797934395925, 48.42914915084839, 55.607013498033794, 52.71889400482178, 52.77046353476388, 43.40619216646467, 40.769385542188374, 39.45039510726929, 42.829043524605886, 44.784742559705464, 49.094536440713064, 50.48315477371216, 46.58595534733364, 43.0147237096514, 56.3959640775408, 54.899749415261404, 52.292694977351594, 51.93409844807216, 43.39070463180542, 40.43012237548828, 39.46125166756766, 39.67709050859724, 39.273049286433626, 43.964559827532085, 44.096481800079346, 43.155827726636616, 44.705807549612864, 43.617789132254465, 45.05808469227382, 46.13158484867641, 45.86590657915388, 56.70689249038696, 59.615898268563406, 62.19742502485003, 62.27395943232945, 64.00776427132743, 60.560325213841026, 63.57446765899658, 66.75900077819824, 65.72648457118443, 60.68207849775042, 63.26879555838448, 66.80632495880127, 68.51471328735352, 64.64132881164551, 66.4488192967006, 62.240566389901296, 66.18561458587646, 59.717154366629465, 69.36012145451137, 66.00169576917375, 79.27031626020158, 37.50424984523228, 0.11737654304930142, 2.53164780991418, 1.376555934548378, 0.11233210337481328, 1.5689710953405924, 58.98870522635323, 62.29586015428816, 46.24836322239467, 51.67548997061593, 38.33452830995832, 48.083438055855886, 4.688283537115369, 0.21633913846952574, 0.03873839542003615, 0.22816668237958634, 0.10987933498940297, 0.11078035485531602, 0.12057466858199664, 0.08348183932581119, 0.06482965805168663, 0.1771528726177556, 0.06608253903687, 0.044577867790524445, 0.03393658629751631, 0.04553681079830442, 0.028827529733202288, 0.09399481663214308, 0.024664042251450673, 0.10783561465463468, 0.13656449557415076, 0.35866476276091164, 0.33379857135670526, 7.203316467148917, 65.41724109649658, 58.18404476983206, 44.61302477972848, 36.30906241280692, 49.369851861681255, 80.04702063969204, 4.296239682606288, 0.029185328033885787, 1.2742165688957487, 1.4221001820904868, 0.8034663434539522, 26.045655931745255, 99.81945378439767, 77.19326346261161, 89.13557011740548, 74.65562847682408, 78.83501161847795, 70.8368707384382, 74.18627766200474, 67.61264950888497, 69.73260048457554, 61.52688911982945, 61.51878752027239, 57.12304442269461, 61.34035778045654, 56.40324926376343, 58.59753554207938, 54.76552064078194, 55.786346503666465, 53.23066009793963, 56.17162411553519, 54.28929110935756, 55.66136578151158, 53.374807425907676, 57.098103863852366, 55.84049381528582, 55.281361852373394, 49.61197921207973, 46.93552616664341, 47.91950920649937, 50.042677198137554, 49.47378996440342, 51.36045517240252, 48.42627607073103, 51.6838139125279, 54.542997632707866, 56.92226232801165, 57.06685086659023, 59.06300926208496, 62.06927245003836, 59.138390268598286, 57.140953404562815, 56.43622541427612, 49.74553748539516, 51.113898345402305, 50.972641468048096, 52.85210139410836, 52.46589272362845, 53.75935547692435, 51.44342361177717, 51.0838508605957, 49.721889291490825, 53.36245352881295, 55.827570165906636, 59.739096777779714, 55.36594227382115, 55.83468859536307, 47.948945249829976, 53.17207983561924, 56.68925796236311, 57.57207523073469, 57.317944867270334, 59.48912838527134, 62.41445895603725, 52.302696909223286, 52.67071866989136, 57.219895362854004, 55.10165364401681, 57.79017571040562, 55.23060526166643, 51.39711386816842, 53.744861534663606, 57.213805266789024, 56.196335383823936, 55.64233119147164, 53.38268320901053, 48.77957459858486, 44.41629695892334, 49.539717946733745, 42.6413448878697, 46.514031069619314, 51.679262842450825, 56.72994313921247, 54.64335741315569, 55.087409836905344, 46.95037794113159, 44.29907390049526, 42.41481276920864, 44.58507565089634, 49.072910172598704, 52.426621505192344, 53.76614734104702, 51.85903011049543, 46.486540521894185, 56.75484548296247, 57.94388028553554, 54.23804814474923, 55.15097543171474, 46.43161848613194, 42.82266160420009, 41.36142417362758, 42.551730496542795, 42.28614602770124, 46.146766662597656, 46.768689496176584, 44.91854749407087, 45.88732787540981, 46.63840729849679, 47.38595356260027, 49.08989156995501, 48.635413374219624, 60.92401477268764, 62.63568959917341, 63.58227743421282, 63.682491302490234, 65.05078615461076, 64.36914008004325, 66.58455235617501, 67.98199490138462, 67.34084292820522, 61.64689145769392, 65.26667363303048, 69.64790194375175, 68.29000159672329, 66.41084739140102, 68.77318627493722, 64.68273312704903, 69.7633810043335, 63.51607499803816, 71.71031488691057, 67.67636448996407, 81.58084242684501, 43.85270077841622, 0.02318107513045626, 2.047801967178072, 1.446779532091958, 0.20266095814960344, 1.0460888615676334, 60.19633688245501, 70.99287169320243, 51.56997462681362, 48.1015659059797, 49.831094128744944, 57.14330536978585, 8.230928114482335, 0.4520810129387038, 0.07482893685145037, 0.19197518511542253, 0.08998994688902583, 0.06217700682048287, 0.04727965174242854, 0.08611114895237343, 0.01704176322423986, 0.09031060218278851, 0.11391663870641164, 0.10687577937330518, 0.15413549914956093, 0.22174616690192903, 0.1484042259731463, 0.2747208885848522, 0.1929315123707056, 0.18985143836055482, 0.20245274289378098, 0.3759143171565873, 0.45322963701827185, 7.33095748083932, 78.14217199598039, 61.62037713187081, 53.591605118342805, 67.71793556213379, 54.3714987209865, 90.66286059788295, 6.459210864135197, 0.16561282399509633, 1.5295851230621338, 8.449102418763296, 2.8689980506896973, 26.29481312206813, 104.68724359784807, 79.79673263004848, 91.84720189230782, 81.87029048374721, 82.36783014025006, 74.7075662612915, 80.11089542933873, 70.45109285627092, 74.35671002524239, 62.049602099827354, 65.89108044760567, 62.029049328395296, 65.90579673222133, 59.98715441567557, 62.938526834760395, 56.92374576841082, 59.33071640559605, 56.052066462380544, 58.747762543814524, 57.28501040594918, 59.807425362723215, 56.851307324000764, 59.980095045907156, 57.63426855632237, 57.058544295174734, 54.019610677446636, 50.425988469805034, 49.11574234281267, 51.91245133536202, 52.451593330928254, 53.549742221832275, 49.465156827654155, 55.71218490600586, 56.03335843767439, 60.10780988420759, 60.060444014413015, 61.01997634342739, 60.39405482155936, 61.46470274244036, 60.245050702776226, 60.32683794839041, 53.290247849055696, 54.69281816482544, 55.4959500176566, 55.594468525477815, 54.05531399590628, 56.30639137540545, 55.88525758470808, 53.33047444479806, 53.348508494240896, 56.59789262499128, 59.84864207676479, 62.8562045778547, 60.048659869602744, 59.97836494445801, 49.603877612522666, 51.53038726534162, 56.97788265773228, 58.684728486197336, 58.62930270603725, 60.375607354300364, 63.03291811261858, 55.623984473092214, 56.00939757483346, 56.39274706159319, 57.08852924619402, 59.865991728646414, 54.654568331582205, 51.405618463243755, 56.587525912693565, 60.536333084106445, 56.91886118480137, 57.368322781154085, 54.5701789855957, 52.003045422690256, 49.725540569850374, 51.86813225064959, 47.041989939553396, 49.97442156927926, 54.23803424835205, 59.00492927006313, 58.17303882326399, 57.83712816238403, 49.2529171534947, 45.471467767442974, 44.887832982199534, 46.84331662314278, 51.07572841644287, 56.50501952852522, 55.980770996638704, 53.255732672555105, 51.972883292606895, 58.78246184757778, 58.57908112662179, 56.11239072254726, 58.54658440181187, 48.177283900124685, 46.62754378999983, 44.737442697797505, 45.118092809404644, 45.33410882949829, 49.84422622408186, 49.16247592653547, 48.03089230401175, 49.16240644454956, 49.44902311052595, 51.000458581107004, 51.662812982286724, 50.725247383117676, 63.13149915422712, 65.7271168572562, 67.23228427342006, 66.42181164877755, 69.05804852076939, 66.95778179168701, 68.29014056069511, 70.9391621180943, 71.05282769884381, 64.10633141653878, 67.92364392961774, 72.37916237967355, 70.7882889338902, 69.71107496534074, 72.64201273236955, 66.7192987714495, 73.97688674926758, 65.67177445547921, 75.5006822858538, 70.14041110447475, 85.62306812831334, 44.177337987082346, 0.26979773704494747, 11.5625467811312, 4.836493389947074, 0.2668227409677846, 2.894009394305093, 71.02488899230957, 74.88432843344552, 62.25361510685512, 69.99993242536272, 50.489849363054546, 66.33564703805106, 10.768354654312134, 0.6130439585873059, 0.2705648344542299, 0.22667565595890793, 0.1997242450181927, 0.271604811506612, 0.15715103090873786, 0.18355706254286425, 0.10189645870455674, 0.2843840957752296, 0.16324868585382188], [0.07024606383804764, 0.07390127770070519, 0.08139929321727582, 0.07606092574340956, 0.06318505201488733, 0.04846474029389875, 0.041242976739470444, 0.0303278419056109, 0.14156831135707243, 0.14930780391607965, 9.682943548474993, 64.35131795065743, 26.83667360033308, 28.95984854016985, 34.425221647535054, 45.41269642966134, 60.3291516985212, 0.5989474207162857, 0.033227510417678525, 0.9002676148499761, 3.027312538453511, 0.18993569883917058, 52.82891525541033, 86.51918424878801, 79.37372629983085, 84.69041837964738, 76.25102519989014, 73.75042411259243, 68.66515568324498, 67.13505813053676, 64.3094620023455, 63.77715356009347, 61.664817810058594, 57.88302796227591, 56.06236021859305, 54.54276834215437, 54.48235375540597, 54.03099530083792, 53.80944504056658, 51.39979934692383, 52.8420021874564, 52.443946838378906, 51.663295882088796, 51.38887677873884, 52.600423744746614, 52.79825285502842, 54.31295319965908, 54.25482109614781, 46.06034844262259, 45.761457783835276, 43.60121073041643, 48.36393335887364, 49.755125999450684, 49.83228921890259, 45.941631521497456, 49.185175691332134, 51.44854096003941, 56.534928049360005, 54.270923546382356, 59.37082140786307, 57.8819648878915, 54.838299546922954, 56.45398848397391, 54.282363755362375, 49.980431761060444, 46.499033382960725, 52.28871365955898, 48.82015902655465, 50.604953220912385, 50.19062866483416, 49.15562847682408, 47.55234554835728, 48.407870292663574, 50.47249971117292, 52.853213105882915, 54.12921503611973, 53.16032695770264, 53.13087701797485, 46.25198670795986, 54.62063332966396, 54.34553330285208, 57.013714517865864, 56.35862793241228, 56.92892912455967, 53.23553773335048, 52.864292008536204, 60.6987680707659, 58.91423443385533, 53.64365407398769, 54.80048745019095, 56.751784801483154, 57.18467147009713, 52.141814844948904, 54.77712065832955, 54.261310713631765, 55.08122246606009, 54.243971484048025, 45.96395608357021, 44.773430892399375, 47.58897645132882, 41.92638220105852, 45.0292774609157, 51.31957197189331, 55.92655072893415, 52.09129449299404, 46.18787220546177, 44.222706249782014, 40.96555750710623, 41.04983220781599, 41.7410945892334, 43.484890937805176, 48.33688749585833, 46.09911939076015, 51.92151526042393, 47.867640904017854, 42.785401889256065, 56.4357842036656, 52.21570546286446, 52.62329721450806, 45.71705879483904, 41.16427598680769, 40.247662680489675, 39.28975970404488, 40.67238868985857, 41.803895882197786, 43.86160489491054, 43.618063586098806, 43.36953694479806, 43.24408721923828, 46.36606918062483, 46.79693392344883, 50.09753670011248, 60.206891196114675, 59.666620118277415, 60.27579648154122, 60.981907163347515, 62.976067951747346, 62.41215215410505, 61.38852964128767, 63.125377791268484, 63.25220326014927, 64.50364330836705, 65.78637109483991, 65.01920659201485, 65.76399789537702, 65.27376774379185, 62.919933455330984, 64.00412341526577, 63.34907504490444, 64.42490632193429, 63.75044468470982, 71.50883102416992, 69.63001033238002, 65.92022119249616, 1.4001745986086982, 0.9793368663106645, 0.6424706109932491, 0.15718586689659528, 0.1255946470690625, 27.1318712915693, 74.14820153372628, 45.122751576559885, 36.948334898267476, 23.67131577219282, 49.44015373502459, 9.64150275502886, 0.3252912349998951, 0.10838253423571587, 0.12310462711112839, 0.05301810381934047, 0.04406632702531559, 0.029257832893303463, 0.08574203268757888, 0.036880016925611665, 0.08073614058750016, 0.03883077796282513, 0.12051681668630668, 0.05120248660179121, 0.07283405068197421, 0.02217043623594301, 0.029011439864656756, 0.08392093969242913, 0.0370411520291652, 0.06094907556793519, 0.25384296317185673, 0.34793962112494875, 13.1196928024292, 73.68425641741071, 33.40617799758911, 33.74160575866699, 33.7404454095023, 57.02647141047886, 60.91085488455636, 0.5100283377936908, 0.045289528888783286, 2.9119885095528195, 1.6501924970320292, 0.7327367759176663, 58.41470759255545, 88.13102040972028, 81.89786093575614, 86.98845863342285, 78.0561671938215, 76.76633140019008, 71.82831614358085, 70.35971014840263, 68.25810936519078, 66.5976983479091, 62.57772077832903, 60.24052742549351, 59.32240636008126, 57.38251100267683, 55.12716048104422, 57.42727129799979, 57.79224974768502, 55.60050303595406, 56.11470447267805, 54.231450830187114, 55.67144414356777, 55.066864013671875, 55.70857879093715, 55.417265142713276, 55.651766845158164, 56.34020478384835, 48.70330769675118, 48.60687712260655, 47.47769062859671, 50.27462543760027, 52.32017510277884, 51.03170115607125, 48.670595577784944, 53.49393776484898, 53.695897579193115, 58.01857689448765, 55.023566314152305, 62.867599623543875, 60.08517960139683, 57.387016909463064, 60.171476227896555, 57.946729046957834, 51.00166409356253, 49.89408649717058, 53.39449862071446, 53.8550043787275, 55.54847492490496, 52.02596752984183, 52.01354762486049, 50.95897783551897, 51.55132218769619, 53.688258034842356, 55.77918291091919, 58.10858038493565, 55.90625156675066, 52.72732564381191, 48.363735335213796, 56.77517243794033, 55.20115532193865, 59.11367552621024, 60.436105319431846, 58.716412271772114, 55.061666761125835, 55.684003012520925, 64.78074441637311, 60.205939292907715, 55.381110191345215, 55.51318155016218, 57.49233422960554, 59.88519654955183, 54.542052677699495, 55.58771487644741, 55.59687260219029, 55.037504400525776, 54.57409429550171, 47.14524711881365, 47.69628095626831, 48.32701757975987, 47.86454548154558, 51.730464117867605, 53.443170751844136, 55.55848380497524, 53.02675131389073, 49.19899913242885, 45.547856262751985, 43.518103327069966, 43.64958756310599, 43.644466740744456, 46.82408400944301, 51.21041924612862, 49.421362331935335, 51.71282958984375, 50.35604790278843, 45.99352066857474, 56.601700237819124, 53.96356998171125, 54.92673969268799, 48.91469621658325, 43.74604940414429, 42.995195797511506, 42.34378828321184, 41.22704601287842, 43.6943096433367, 45.667677947453086, 45.23663255146572, 47.43402814865112, 45.03044475827898, 48.73422370638166, 46.395282881600515, 53.35144758224487, 61.001348223005024, 63.519569941929404, 62.8582056590489, 64.85535417284284, 64.68230233873639, 65.2500535420009, 63.230295589991975, 64.0724242074149, 63.73038523537772, 66.04669925144741, 66.2997248513358, 66.82737800053188, 69.39194420405796, 67.19109535217285, 65.0532180241176, 66.58300985608781, 62.790731702532085, 66.15010929107666, 65.06902517591203, 73.81240204402378, 69.71926689147949, 73.97573334830147, 2.9878029099532535, 0.528092297060149, 0.8108000585011074, 0.0763708126864263, 0.2051614411175251, 24.981667859213694, 81.0904107775007, 50.60643318721226, 39.09086404527937, 27.20242851121085, 61.84590176173619, 16.826556750706263, 0.37909944195832523, 0.04262537309633834, 0.08105489598321063, 0.024513817990997007, 0.08743153738656215, 0.008563461380877664, 0.11514357929783207, 0.016078436880239418, 0.07165414613804647, 0.022237214259803295, 0.20414963683911733, 0.11523790923612458, 0.1410536425454276, 0.09423787466117314, 0.16986493154295854, 0.16530923385705265, 0.19878653676382133, 0.12183320176388536, 0.4114694164267608, 0.5420588276215962, 14.852498837879725, 84.84152085440499, 36.22819232940674, 38.22427429471697, 50.62924064908709, 61.31507328578404, 71.98063455309186, 1.1693842113018036, 0.10369933303445578, 2.969107913119452, 9.557965431894575, 0.7907042396920068, 61.032406670706614, 90.29030513763428, 86.77875505174909, 91.07297107151577, 84.23326165335519, 80.32142584664481, 74.42920058114188, 74.83406516483852, 72.31345326559884, 69.6675306047712, 66.91924708230155, 62.5220170702253, 62.088442529950825, 60.86810956682478, 59.20987333570208, 61.067196301051546, 60.146177836826865, 57.78932108197893, 58.08951800210135, 57.61381305967058, 59.577370507376536, 57.22614874158587, 58.44441114153181, 58.70390551430838, 57.32969079698835, 58.70321069444929, 52.48735570907593, 50.431005069187705, 49.344796657562256, 53.702515738351, 55.852778230394634, 52.947368144989014, 51.57280254364014, 54.40696580069405, 57.068664346422466, 61.88784108843122, 58.14415168762207, 61.47358948843819, 57.877535411289756, 61.216249057224815, 62.44095243726458, 61.53143324170794, 53.89885793413435, 53.68638896942139, 57.32575116838728, 56.244458607264924, 57.40320273808071, 55.63958665302822, 55.15058980669294, 53.653732436043875, 53.46385901314871, 55.72028650556292, 58.92349638257708, 60.25347191946847, 60.730132239205496, 59.24063995906285, 48.84257391520909, 58.16204677309309, 56.627436365400044, 61.486943926130024, 63.37082290649414, 60.35656929016113, 58.79038279397147, 59.04169218880789, 66.44359425136021, 62.99428612845284, 57.14814131600516, 58.64557538713728, 59.80565357208252, 64.54779216221401, 57.00857979910714, 58.81343691689627, 58.1357547896249, 57.272486277988975, 58.63201945168631, 48.13351372310093, 50.17510291508266, 52.63831574576241, 51.71393435341971, 51.387987409319194, 55.75177921567644, 60.23940181732178, 57.869270529065815, 50.08546073096139, 49.528930868421284, 47.822811126708984, 46.43719094140189, 47.94641957964216, 49.308933530535015, 53.75589527402605, 50.79591056278774, 55.17396354675293, 53.33114842006138, 49.0707597051348, 58.824804169791086, 57.04679141725813, 58.502880232674734, 53.331999574388774, 47.131788458142964, 45.248086656842915, 46.25852148873465, 46.47250516074044, 48.16718121937343, 48.55808687210083, 49.06886632101876, 48.071653911045615, 47.591582025800435, 51.93205220358712, 53.12384196690151, 55.09841578347342, 66.5131526674543, 65.2370673588344, 65.71237277984619, 67.3242436817714, 68.74419839041573, 67.73685550689697, 65.72316333225795, 66.50452995300293, 67.34290654318673, 69.46413598741803, 71.14605862753731, 71.43126133510044, 71.94158567701066, 70.35971014840263, 67.98764378683907, 70.67557525634766, 67.10921777997697, 69.84364659445626, 68.52097361428397, 78.04553644997733, 75.10749762398856, 75.18966007232666, 2.448079437017441, 3.7994035312107632, 1.726223160113607, 0.22428342646786145, 0.3669997240815844, 35.59783090863909, 87.12824249267578, 56.19081851414272, 55.39237322126116, 32.26530463354928, 71.69098499843052, 18.803315775735037, 0.5326834278447288, 0.2703246330576283, 0.14433294800775393, 0.16713084253881658, 0.11372037923761777, 0.10140908735671214, 0.19321428505437716, 0.1886903970901455, 0.14121184977037565, 0.15188638626464776], [0.02795200073160231, 0.10407175376479115, 0.14702009595930576, 0.06224293328289475, 0.023055961754705225, 0.017026022908144763, 0.05866649733590228, 0.022123615623318722, 0.22834478425128119, 0.30515098571777344, 18.482732840946742, 65.31886850084577, 28.400280577795847, 31.381281852722168, 26.169646535600933, 69.02901894705636, 33.04278721128191, 0.21727999512638363, 0.266713198274374, 1.2605120071343012, 1.6113429473979133, 5.202629583222525, 76.24894768851144, 78.42465100969586, 81.742554800851, 82.65620817456926, 79.29337733132499, 71.27707386016846, 71.68699673243931, 67.83411639077323, 64.68686730521065, 62.37005301884243, 61.02212333679199, 60.057956559317454, 58.55534608023507, 55.095761571611675, 53.87316696984427, 54.34984466007778, 52.744317463466096, 54.37702601296561, 53.042065143585205, 52.27303157533918, 51.55934388296944, 51.33697026116507, 50.707640647888184, 51.32763188225882, 53.743256500789094, 49.61519275392805, 44.47248704092843, 45.173567226954866, 44.80366597856794, 48.83950628553118, 50.66769892828805, 47.753360407693044, 46.54482895987374, 47.261883054460796, 52.736281871795654, 53.44878142220633, 58.401179449898855, 53.66135113579886, 52.220878396715435, 57.69128199986049, 56.57233715057373, 54.289565563201904, 48.54537861687796, 47.6284179006304, 48.180035386766704, 48.88570833206177, 48.83101906095232, 48.66820887156895, 47.48687614713396, 50.63619926997593, 47.380561760493684, 50.756826945713584, 53.42135688236782, 54.838428088596885, 52.30451038905552, 48.86015633174351, 49.02854939869472, 53.332513741084504, 53.93466547557286, 56.58667475836617, 56.18936286653791, 55.712685176304404, 51.21960823876517, 58.36820329938616, 58.812867164611816, 52.22142730440412, 50.256539276668, 51.609193733760286, 48.306829588753835, 53.45468044281006, 56.09502370016915, 51.98570271900722, 55.47724199295044, 48.74211685998099, 56.44190904072353, 48.678537368774414, 45.86466979980469, 42.356962067740305, 45.7881875038147, 53.78319822038923, 50.691899503980366, 51.47820629392351, 49.30744661603655, 45.311113766261506, 44.34164898736136, 43.33276012965611, 42.52922180720738, 42.383844648088726, 40.63405895233154, 44.539759499686106, 47.83772890908377, 46.4630069732666, 48.3634990964617, 48.08273976189749, 44.930915287562776, 53.64397716522217, 52.895291396549766, 49.8299754687718, 41.96760933739798, 39.38211863381522, 40.20753335952759, 39.754142556871685, 39.82674775804792, 43.12472064154488, 44.15278652736119, 45.33726678575788, 42.986774580819265, 44.10956525802612, 45.271470819200786, 50.87513392312186, 58.34735870361328, 59.345780100141255, 56.90185546875, 61.3609105518886, 58.49293736049107, 63.57357134137835, 60.33567605699812, 65.56120082310268, 66.0267231804984, 65.2332250050136, 64.19767243521554, 65.41879749298096, 62.088407788957866, 65.0652800968715, 61.52765342167446, 65.00263513837541, 61.20322118486677, 64.86112117767334, 60.1351649420602, 76.27382918766567, 63.432661873953684, 85.27469934735979, 10.774231961795262, 0.3001363676573549, 0.27167459204792976, 0.1277708038687706, 0.17971648648381233, 5.916494454656329, 76.19562026432583, 47.1957813671657, 43.808399064200266, 33.53239549909319, 55.99261767523629, 15.761993714741298, 0.3446169708456312, 0.03118020063266158, 0.12857090522136005, 0.04515047331473657, 0.10483614381934915, 0.04644067033327051, 0.08582982154829161, 0.02410968253389001, 0.04477572860196233, 0.037549133878201246, 0.020911947158830504, 0.08544315158256463, 0.12080048503620283, 0.053793957723038535, 0.035060043513242684, 0.059386327995785644, 0.007711361345302845, 0.020228933809059005, 0.2131787666252681, 0.30635391974023407, 23.847746167864116, 73.22181211199079, 38.601304394858225, 29.41716160093035, 27.32713304247175, 80.65582874843052, 32.810633999960764, 0.12255262530275754, 0.05096584072868739, 1.871256709098816, 0.35512780398130417, 7.24339280809675, 82.19983659471784, 80.79508454459054, 85.45488698141915, 82.4801755632673, 82.58260590689522, 74.06214809417725, 75.24145889282227, 68.10204587663922, 68.20373971121651, 63.96920871734619, 63.71815640585763, 62.4068089893886, 59.90716675349644, 57.37089361463274, 55.58593961170742, 55.25369412558419, 55.94042975561959, 56.501569747924805, 55.26169845036098, 54.89115101950509, 53.59505837304251, 53.56579603467669, 53.38379839488438, 53.25927972793579, 55.5176978792463, 52.486341272081646, 47.31774309703282, 48.343752316066194, 47.10092108590262, 51.51067175183977, 51.82145425251552, 47.80210549490792, 48.86068786893572, 48.575335775102886, 55.51724624633789, 57.16839184079851, 59.64535863058907, 57.0837037222726, 55.196784905024934, 58.96326787131173, 59.36759049551827, 57.57072728020804, 51.53498002461025, 50.945071016039165, 52.7397837638855, 51.88282421657017, 52.38009636742728, 52.1133793422154, 49.11598205566406, 52.68482003893171, 51.165881293160574, 53.86249106270926, 57.550358636038645, 57.216244084494456, 57.25477531978062, 51.9729597227914, 52.06966822487967, 54.63030522210257, 54.962133816310335, 57.645740032196045, 58.50422123500279, 57.66516719545637, 55.03276572908674, 61.582224573407856, 59.420306478227886, 55.892851965767996, 53.226147242954795, 52.24715300968715, 51.388518946511404, 54.71616063799177, 57.87931415012905, 53.44416781834194, 56.3108104297093, 51.276955195835654, 57.92950793675014, 49.22870962960379, 46.09909159796578, 46.709529059273855, 50.60818413325718, 55.65652288709368, 53.13932255336216, 53.465043681008474, 49.62968669618879, 47.145604951041086, 46.55178410666329, 46.445716381073, 46.2015323638916, 44.53564616612026, 43.14958129610334, 45.71920926230294, 51.81730270385742, 48.07942547116961, 51.069151946476524, 51.346193994794575, 47.880762577056885, 54.76453399658203, 54.64171069008963, 50.8820230620248, 43.27195296968733, 42.29789195741926, 42.426395416259766, 43.01977505002703, 42.217073985508506, 45.55404710769653, 45.57604857853481, 45.88653925486973, 44.77588013240269, 46.164189270564485, 46.630097252982004, 52.825559275490896, 59.83440521785191, 61.35836751120431, 59.85176876613072, 63.182832445417134, 62.637023653302876, 64.37245437077114, 62.14047758919852, 66.80938911437988, 67.24290806906563, 65.72169031415666, 65.5638758795602, 67.13302230834961, 65.48999568394252, 66.18194593702043, 63.23572908129011, 68.55823680332729, 63.539587702069966, 65.60131277356828, 60.77879742213658, 79.8382967540196, 66.43140711103166, 88.44839327675956, 14.552041360310145, 0.46957505707229885, 0.34279958265168325, 0.07468517563704934, 0.2175706795283726, 5.4675426823752264, 81.46876798357282, 56.67107105255127, 45.614117758614675, 33.31261008126395, 66.40641444069999, 24.660181658608572, 0.3110239234353815, 0.018809533544949124, 0.1331221924296447, 0.035530804323830774, 0.07735144506607737, 0.07101926806249789, 0.04441682428919843, 0.08933324712727751, 0.07236963417381048, 0.06939482130110264, 0.07930908644837992, 0.1618867710764919, 0.18945188980017388, 0.1201222078608615, 0.1473991120500224, 0.10691203349935156, 0.12000159147594656, 0.1992974736328636, 0.39109135419130325, 0.4677616315228598, 26.220060927527292, 83.60199001857212, 38.69758210863386, 42.970602648598806, 40.028488704136436, 84.12607179369245, 41.92150109154837, 0.3978057567562376, 0.397901213062661, 4.293889020170484, 5.205197811126709, 7.734059827668326, 81.57710429600307, 84.10155160086495, 88.71347400120327, 88.08597523825509, 84.5702006476266, 78.29720715114048, 80.09225341251918, 72.42627116612026, 71.05953965868268, 68.88516344342912, 66.81313419342041, 67.06736877986363, 63.20895072392055, 60.99456678118025, 58.78618608202253, 59.78077902112688, 59.82506683894566, 59.05063452039446, 58.15000901903425, 59.49403381347656, 57.23948580878121, 57.84173481804984, 55.60643332345145, 56.637855189187185, 58.19717686516898, 54.74282087598528, 51.232639585222515, 51.99907452719552, 50.760756152016775, 55.92750610624041, 55.37640278679984, 52.48068196432931, 50.518799032483784, 50.04178088051932, 59.91199575151716, 58.9718975339617, 63.25817176273891, 57.81240994589669, 53.96915633337838, 60.54070350102016, 61.681333678109304, 61.124359130859375, 55.21519068309239, 54.29044451032366, 53.26497377668108, 57.09131894792829, 55.77169622693743, 56.053619384765625, 53.50717060906546, 57.021114349365234, 52.95607076372419, 57.43213503701346, 60.01838656834194, 59.632087571280344, 59.74413422175816, 56.6450639452253, 54.18111113139561, 56.464362144470215, 56.560396671295166, 61.990153312683105, 59.9057423727853, 59.229772976466585, 58.912407057625906, 65.34353460584367, 62.98889432634626, 56.31332220349993, 56.35593897955758, 54.923057147434776, 53.096740518297466, 57.221413544246126, 58.889484950474326, 56.71378510338919, 57.75351701463972, 52.357483455113, 58.61353724343436, 53.26258359636579, 49.247226578848704, 51.61374480383736, 53.9639938218253, 58.29590034484863, 56.194921425410676, 58.544076102120535, 53.235040937151226, 49.17946079799107, 50.29124205453055, 48.85060255868094, 49.536243847438264, 46.97755234582083, 45.83458409990583, 49.79996272495815, 54.63638489586966, 52.04245213099888, 52.177059582301546, 56.08857577187674, 51.80998625074114, 56.418132305145264, 58.87918077196394, 54.60578850337437, 45.74609184265137, 43.80080468314034, 45.38225984573364, 46.72172662190029, 46.00926528658186, 49.61298670087542, 49.84222166878836, 49.33155686514718, 48.267655645098, 48.91067320959908, 48.26365695680891, 56.08939218521118, 63.19383839198521, 63.4168894631522, 61.777239663260325, 66.23337650299072, 64.78789411272321, 66.4497434071132, 65.75784873962402, 70.84657737186977, 69.45646517617362, 67.36837863922119, 69.09258801596505, 70.47136075156075, 67.57525430406842, 69.13693836757115, 66.97594438280377, 72.9786182131086, 67.80391951969692, 70.60556520734514, 64.21008886609758, 83.85190977369035, 70.31415775844029, 92.21328857966832, 14.022188237735204, 0.870091859783445, 3.4256219310419898, 0.2627243623137474, 0.385717221136604, 7.411230019160679, 92.18321677616665, 58.5456394468035, 62.576685496738975, 42.51159075328282, 74.60733154841832, 35.60218742915562, 0.5328513788325446, 0.14924917849046843, 0.2735149418669087, 0.1637576956834112, 0.10584666566657168, 0.23840857137526783, 0.1715227011591196, 0.16101146090243543, 0.13088375968592508, 0.18162132427096367], [0.03242630305300866, 0.053030314057001045, 0.08014966920018196, 0.01973733858072332, 0.036918985191732645, 0.03710906320650663, 0.04153695882165006, 0.05401995059634958, 0.15283492393791676, 0.05249732140717762, 21.27589304106576, 61.49742875780378, 24.66924384662083, 47.66467012677874, 37.25484773090908, 68.92403861454555, 18.88552859851292, 0.28551849776080673, 0.20579899262104714, 3.539152021918978, 1.0886377841234207, 25.363808359418595, 95.04121930258614, 76.19943482535226, 85.87669127328056, 77.41511249542236, 79.02694170815604, 69.87625449044364, 67.58837945120675, 65.96254267011369, 64.66985116686139, 62.46074785505022, 61.87526484898159, 63.78563731057303, 59.64148153577532, 55.54943725040981, 52.33605521065848, 51.84158665793282, 52.239829608372276, 49.76283502578735, 48.84381764275687, 50.08055182865688, 52.47513035365513, 50.877207960401265, 52.552790369306294, 51.78682095663888, 55.139573437826975, 45.36924934387207, 44.08495821271624, 44.45919861112322, 47.51906367710659, 48.90429823739188, 49.60680627822876, 45.40429605756487, 48.28483854021345, 46.45420013155256, 54.40963043485369, 53.074162346976145, 58.14457205363682, 50.708807945251465, 52.529989855630056, 60.74194417681013, 55.679253918784006, 54.11911930356707, 48.633902141026084, 48.319152218954905, 47.4852363722665, 49.01904426302229, 48.98184708186558, 49.56953614098685, 50.863332407815115, 52.660529136657715, 50.93037210191999, 52.59570591790335, 52.5184280531747, 57.69626733234951, 51.22023010253906, 44.78335639408657, 49.259566579546245, 53.26712424414498, 55.078860078539165, 56.64851719992501, 55.87046834400722, 54.95245150157383, 54.49337707247053, 57.538841996874126, 56.75978912625994, 56.28147513525826, 56.68824005126953, 59.122103691101074, 56.9442776952471, 53.488170760018484, 54.59357009615217, 52.19259922845023, 54.56412015642439, 56.63124050412859, 49.896900517599924, 47.70627246584211, 41.93926763534546, 42.43846443721226, 52.278023856026785, 52.56274018968855, 51.90172331673758, 44.36620739528111, 46.125953333718435, 44.1951253754752, 46.44060945510864, 45.068065779549734, 45.24440063749041, 42.52102640696934, 41.59168747493199, 41.65253284999302, 45.23478780473982, 47.30988815852574, 48.98079790387835, 51.672283376966206, 46.94809545789446, 51.01199606486729, 53.14500617980957, 47.800858293260845, 42.47490079062325, 40.176221302577424, 40.149484634399414, 39.05400732585362, 38.07488455091204, 40.124283518110005, 41.425945145743235, 43.92301654815674, 44.728892939431326, 47.06472444534302, 44.91392694200788, 45.89784744807652, 54.61793395451137, 59.788533210754395, 57.0434319632394, 60.73868547167097, 61.026980127607075, 61.558357511247905, 61.760682106018066, 62.936379841395784, 64.58297089168003, 66.47613266536167, 61.69896125793457, 63.504728589739116, 61.98541464124407, 64.14786079951695, 62.19906479971749, 61.90441254207066, 59.64084924970354, 64.9878841127668, 59.990281105041504, 71.10999052865165, 64.87289142608643, 82.93745040893555, 33.87895427431379, 0.37708351441792076, 0.5653972838606153, 0.05549715865137322, 0.021429384393351417, 1.5452719841684615, 65.90246159689767, 53.970577239990234, 48.52159145900181, 29.971527099609375, 34.17763301304409, 27.638426235743932, 0.4169615331505026, 0.03273704495014889, 0.2339083914245878, 0.03446998606835093, 0.07992930816752569, 0.024583545945850865, 0.19996207154222898, 0.10767278660620962, 0.11561129348618643, 0.060991680781756125, 0.0391516368170934, 0.020364030131271908, 0.052463133420263014, 0.036652161473674436, 0.045052821947527785, 0.10414167001311268, 0.058476636452334266, 0.05704654247633048, 0.26691570026533945, 0.17283329154763902, 28.826432704925537, 65.26725728171212, 34.127758843558176, 44.123861176627024, 39.15426288332258, 81.6870664869036, 19.9628780569349, 0.2867167091795376, 0.060551644036812444, 1.2366832686322076, 0.7343301932726587, 31.13736186708723, 97.81450939178467, 77.11413042885917, 88.67393180302211, 80.18004390171596, 81.85993071964809, 73.11309364863804, 71.18213367462158, 67.82907894679478, 67.11652728489467, 65.22479684012276, 65.93547943660191, 65.20496668134416, 63.78086389814104, 57.32905156271798, 56.76398236410958, 55.32888405663626, 56.31666428702218, 53.69446972438267, 52.2568735395159, 52.94786146708897, 54.29768453325544, 52.72844082968575, 54.06702171053205, 54.08369043895176, 55.63170392172677, 48.09005274091448, 46.75535937717983, 47.803293636866975, 49.749852316720144, 50.41956486020769, 52.443714073726106, 48.87853084291731, 49.822638171059744, 50.03039973122733, 57.81629398890904, 55.57924849646432, 61.411757469177246, 53.27119241441999, 55.19941479819161, 62.481898171561106, 58.11787012645176, 56.70231015341622, 52.0998511995588, 50.1995918410165, 48.825345856802805, 50.92244420732771, 51.62976734978812, 52.30070277622768, 52.993288789476665, 55.64142445155552, 54.834227902548655, 55.448674474443706, 56.15663685117449, 59.35587583269392, 54.30115515845162, 48.82127768652779, 51.22832475389753, 54.88634634017944, 55.02530683789934, 57.62962368556431, 57.212735244206016, 56.80777338572911, 56.746358258383616, 57.12449312210083, 57.47254923411778, 57.52274996893746, 58.15574475697109, 60.861057145254954, 58.662278856549946, 55.726168155670166, 56.70994274956839, 56.544558252607075, 54.882100990840364, 59.08906500680106, 50.96193429401943, 47.336624826703755, 42.68021311078753, 47.33154221943447, 55.7835568019322, 56.77586030960083, 54.77496671676636, 47.281390122004915, 47.199925967625205, 46.52714579445975, 51.21949706758772, 49.84610571180071, 47.24450560978481, 45.619304588862825, 42.92260101863316, 44.591294288635254, 45.72090114865984, 49.21207216807774, 52.08270999363491, 52.250574997493196, 51.07800047738211, 51.5481607573373, 54.580024582999094, 50.88982241494315, 45.15661014829363, 44.21665784290859, 42.365998200007844, 41.82510525839669, 40.211664063589915, 43.57785088675362, 43.97433941704886, 46.507402488163535, 46.55051606042044, 48.087982177734375, 48.21876464571272, 48.859638690948486, 58.179726464407786, 62.207472120012554, 61.0043637411935, 62.647029059273855, 63.218212672642295, 64.8611489704677, 65.5989156450544, 65.43347903660366, 63.58788463047573, 67.22944940839494, 64.65371050153459, 66.34272725241524, 64.57866300855363, 65.07805783408028, 64.26062311444963, 63.892146246773855, 61.6005539212908, 66.53370543888637, 62.1321883882795, 72.28280476161412, 67.77382687159947, 85.14171082632882, 37.99562644958496, 0.21554751880466938, 0.520884843809264, 0.043900598239685805, 0.09832419574792896, 1.5776295278753554, 70.29127039228166, 63.1539557320731, 49.755237170628135, 28.081789050783428, 42.05632741110665, 44.84180811473301, 0.4517013861664704, 0.04639178527785199, 0.14991190364318235, 0.028990082974944795, 0.04825987360839333, 0.028513520689947263, 0.15659247445208685, 0.033668656567377706, 0.04064382353265371, 0.048196437369499884, 0.1337129928703819, 0.1557195255798953, 0.12130146101117134, 0.15920891905469553, 0.12128915238593306, 0.19693858735263348, 0.15403405816427299, 0.09152384993753263, 0.35160886709179195, 0.23765224910208158, 31.367753710065568, 78.91555513654436, 33.02425636563982, 61.15589005606515, 52.67135443006243, 84.90686866215297, 25.844192913600377, 0.44317393803170746, 0.32655094883271624, 11.675658243043081, 2.35037191425051, 32.05337068012783, 101.74861417497907, 81.31225981031145, 90.92067350660051, 83.63999666486467, 87.13134138924735, 76.05293205806187, 73.38992377689907, 71.54240471976144, 70.74307700565883, 66.75724288395473, 69.62068584987095, 69.49322114671979, 67.9611016682216, 60.98570782797677, 58.081881931849885, 58.93872683388846, 59.588466780526296, 56.12932348251343, 54.34791306086949, 56.50477981567383, 57.141922678266255, 56.42903750283377, 56.068762983594624, 56.87173850195748, 59.24308572496687, 50.910667010716026, 49.49624306815011, 50.08909463882446, 51.79403666087559, 53.55760758263724, 55.40596737180437, 51.30486610957554, 52.02375452859061, 52.66010182244437, 60.71474892752511, 57.698862484523225, 64.0662681034633, 54.78412444250924, 54.28161334991455, 65.42208399091447, 61.43342890058245, 59.69449629102434, 55.528019428253174, 54.661290713718955, 52.8642954826355, 55.08229596274239, 53.871937138693674, 54.74597883224487, 56.7813389641898, 58.86577769688198, 55.65780135563442, 57.604974951062886, 57.987400327410015, 64.203932762146, 58.139857700892854, 50.095785754067556, 54.320960998535156, 57.214597361428396, 57.99253157206944, 59.95695059640067, 59.179780687604634, 59.22806371961321, 58.796101161411826, 59.37681075504848, 59.36604799543108, 59.82842281886509, 61.73638425554548, 64.5130511692592, 61.459887640816824, 57.509812423161094, 60.77671991075788, 57.6400077683585, 58.68745218004499, 61.38196359361921, 52.756931918007986, 48.791636671338765, 44.9338196345738, 50.28554105758667, 56.549675600869314, 59.11389786856515, 56.441679750170024, 50.20898233141218, 50.675133500780376, 49.528552191598074, 51.733629022325786, 50.74173545837402, 50.28898041588919, 48.63318647657122, 46.19550827571324, 46.68436615807669, 49.75431306021554, 51.10889564241682, 54.86013773509434, 56.45669480732509, 53.29398250579834, 54.74775062288557, 58.44784355163574, 52.962025369916645, 48.14799724306379, 46.3690047945295, 45.57788985116141, 46.042491572243826, 43.70460687364851, 46.721987179347444, 45.5785117149353, 49.37453147343227, 49.6706463268825, 52.017886774880544, 50.099086148398264, 50.298426491873606, 62.04846259525844, 64.37050192696708, 62.349812916346956, 68.96505383082798, 65.8195001057216, 68.86748027801514, 68.1705481665475, 68.78103773934501, 68.1228279386248, 71.28053406306675, 66.17415005820138, 68.95821680341447, 67.9880815233503, 68.67311831883022, 68.4358720779419, 67.02064909253801, 64.3538818359375, 72.2115787778582, 66.42170742579869, 77.95112432752336, 71.20638983590263, 89.90733432769775, 38.28421292986189, 0.5734667479991913, 3.1135488024779727, 0.22743633442691394, 0.13552439638546535, 2.6539402306079865, 80.71328340257917, 66.66039889199394, 66.45447513035366, 41.80285712650844, 47.57410383224487, 53.71979243414742, 0.5016719347664288, 0.1304311225456851, 0.35669831399406704, 0.08570284050490175, 0.1300268785229751, 0.0661738562796797, 0.2646214919430869, 0.15282291386808666, 0.16261139219360693, 0.16280656600637095], [0.03274237484272037, 0.023523913430316106, 0.0527791203930974, 0.01672069911312844, 0.08690547597195421, 0.06580830910908324, 0.061076450161635876, 0.06923580661948238, 0.04441243416762777, 0.10694150227521147, 36.94028888429914, 53.99924203327724, 27.92576551437378, 37.500848702022004, 38.56534399305071, 74.8482950755528, 13.862376196043831, 0.23101547094328062, 0.16941694915294647, 2.8241767414978574, 0.4353243192391736, 59.71629279000418, 89.92655999319894, 74.08478532518659, 82.67253644125802, 76.02791854313442, 78.70494828905377, 70.70741885049003, 68.37319932665143, 63.8336215700422, 62.288911955697195, 63.37481117248535, 65.03890473502022, 62.70692253112793, 62.289933340890066, 56.724652085985454, 56.058017594473704, 51.77438715526036, 51.96151256561279, 52.46555921009609, 53.50274460656302, 51.21861812046596, 50.86825868061611, 49.31700733729771, 51.352179867880686, 50.71137877873012, 51.743498938424246, 42.715756620679585, 45.14052159445626, 42.77632754189627, 46.90757008961269, 49.271218708583284, 50.86172389984131, 46.93937199456351, 49.21672746113369, 47.557563645499094, 53.375140939440044, 53.04004669189453, 60.62308829171317, 53.82682248524257, 45.59452036448887, 61.919288635253906, 54.39024496078491, 56.097799505506245, 48.98945188522339, 46.14344194957188, 46.31532996041434, 49.03105422428676, 49.79027346202305, 51.19912494931902, 51.309139251708984, 56.894580704825266, 53.01043694359915, 52.61152696609497, 55.89940064293997, 56.336668150765554, 53.55649239676339, 45.506267820085796, 44.94535364423479, 52.16143308367048, 54.43423400606428, 58.896704128810335, 54.48126636232649, 52.52056809834072, 55.69452953338623, 52.833514962877544, 56.05704484667097, 54.61901092529297, 51.49703938620431, 51.089965275355745, 53.950451782771516, 54.55176625932966, 50.18700517926897, 56.377443654196604, 52.784783772059846, 51.85933583123343, 55.02345514297485, 45.1766174861363, 39.06966509137835, 48.73233379636492, 52.91616031101772, 52.457683426993235, 49.630169595990864, 45.868286337171284, 43.92816168921334, 47.851632254464285, 48.85607426507132, 51.76062624795096, 46.587563855307444, 45.87363645008632, 41.89889512743269, 41.69063677106585, 43.452578340257915, 45.24490785598755, 47.80352292742048, 49.24279015404837, 50.4612193107605, 50.096393721444265, 53.610438210623606, 52.26536423819405, 44.96743849345616, 40.9366842678615, 40.88878686087472, 39.70049898965018, 38.55318464551653, 38.36287348611014, 41.30352136066982, 43.69148172651018, 43.832141058785574, 44.23767614364624, 44.19685547692435, 45.530440602983745, 48.67941631589617, 55.93441956383841, 55.712994371141704, 55.54154062271118, 58.336394446236746, 60.636963844299316, 61.39626298631941, 62.349771227155415, 63.95563888549805, 61.4793495450701, 61.020434924534385, 59.773636272975374, 59.31954370226179, 59.48075580596924, 59.91138431004116, 61.274426324026926, 61.58797768184117, 60.50792190006801, 61.07288687569754, 68.32570144108364, 70.82501016344342, 77.05213165283203, 55.64437396185738, 0.06978651242596762, 0.08084382409495966, 0.07784782057361943, 0.11652452019708497, 0.05576803322349276, 53.0735821723938, 60.195572580610005, 47.740172726767405, 36.68647118977138, 25.24334396634783, 53.897388390132356, 1.0378801077604294, 0.17774912848004273, 0.043779001371668916, 0.07804640063217708, 0.07668042821543557, 0.038935177360794375, 0.03489723242819309, 0.06210757911737476, 0.05995716593627419, 0.1012861571673836, 0.047555971558072736, 0.06846057357532637, 0.009999506957163768, 0.01663032333765711, 0.02208182295518262, 0.08204653420086418, 0.06218326969870499, 0.07876874187162944, 0.035151961259543896, 0.37850919791630333, 45.30548225130354, 60.93423557281494, 34.5618371282305, 31.648023196629115, 46.71134948730469, 82.2856398991176, 15.620446750095912, 0.28440032633287565, 0.29597195397530285, 1.0122006514242716, 0.9161360519272941, 65.63339955466134, 93.0947995867048, 77.8991448538644, 85.1668563570295, 78.94907324654716, 81.48694447108677, 71.79080976758684, 72.4631244114467, 65.84754303523472, 65.61419473375592, 65.92278507777623, 66.60596670423234, 65.75383962903703, 64.9744462966919, 58.00559071132115, 57.95434774671282, 54.74313007082258, 53.82439408983503, 54.31773356028965, 55.59514250074114, 53.136880261557444, 53.9531581061227, 51.51413195473807, 53.62307003566197, 52.18400430679321, 53.755495752607075, 45.80211864198957, 47.13620056424822, 48.42178406034197, 49.138674872262136, 51.800026008060996, 52.69052798407418, 49.13043430873326, 51.56018114089966, 51.04148074558803, 56.71929155077253, 54.74154935564314, 62.49328626905169, 56.417663301740376, 48.164190019880024, 62.15893200465611, 57.57617466790335, 58.37112849099295, 52.25235373633248, 48.114420073372976, 49.20144837243216, 52.9586763381958, 53.403861318315776, 53.47938476290022, 54.7747026852199, 58.37791688101632, 54.63309144973755, 56.91812467575073, 58.72778647286551, 59.298504556928364, 56.645727498190745, 47.84070273808071, 46.70282404763358, 53.04171425955636, 56.231364727020264, 60.987069674900596, 55.49398020335606, 55.26323052815029, 56.42220394951956, 53.260276794433594, 57.79172168459211, 54.6399701663426, 53.069712025778635, 54.47134780883789, 56.508900097438264, 56.04962764467512, 50.75868558883667, 58.67201328277588, 54.93459810529436, 54.823242800576345, 56.36273084368025, 47.40862553460257, 42.35455104282924, 49.71815463474819, 53.35412958690098, 54.00677040645054, 52.14324964795794, 50.11332995550973, 47.26963724408831, 50.80734729766846, 51.82917022705078, 53.41584348678589, 49.66447632653372, 48.044403076171875, 43.872273853846956, 45.14282144818987, 44.91977037702288, 48.117095129830496, 48.4414370400565, 50.95529876436506, 53.361251490456716, 53.852291107177734, 55.867237431662424, 56.117865903036936, 48.12589502334595, 42.95257207325527, 42.87215709686279, 42.6314298084804, 42.345240456717356, 41.06719923019409, 42.94530425752912, 45.49449062347412, 47.1313020842416, 44.821102482931956, 46.996566091264995, 46.955300739833284, 50.858882086617605, 56.81495782307216, 58.10064206804548, 58.75876154218401, 63.591303144182476, 62.13867105756487, 63.00534071241106, 64.53168623788017, 65.09694998604911, 63.12740666525704, 63.40323625292097, 62.70989636012486, 62.87453392573765, 62.375048773629324, 61.89986147199358, 63.39769159044538, 64.35846069880894, 62.11219147273472, 64.28181512015206, 70.31592954908098, 73.01816735948834, 77.93078000204903, 61.27796295710972, 0.4272815350975309, 0.07464983074792794, 0.03470523415931633, 0.06950226053595543, 0.5865092224308422, 54.85627106257847, 68.09970433371407, 51.92363098689488, 34.06036826542446, 35.386379855019705, 67.26744215829032, 4.0172421506472995, 0.18179729554269994, 0.08090042748621531, 0.11558236075299126, 0.08039025057639394, 0.09694291558116674, 0.035170627757906914, 0.1402969674340316, 0.03181729751772114, 0.01848391137484993, 0.08963606373539992, 0.0927636284115059, 0.18314791949731962, 0.19562275867377008, 0.1539288173828806, 0.19463489311082022, 0.16177432425320148, 0.13514818942972592, 0.20703525628362382, 0.3192609857235636, 50.32196351460048, 71.21902166094098, 35.70886312212263, 47.3850086075919, 52.94894538606916, 87.29234504699707, 19.032533373151505, 0.3698973943080221, 0.5596214309334755, 7.556576779910496, 0.8749731321419988, 68.9286105292184, 98.6102101462228, 80.5354095186506, 88.75104985918317, 83.87041977473667, 85.81005804879325, 74.58704280853271, 75.95569896697998, 68.45499352046421, 69.31877272469657, 69.94151891980852, 70.01333550044468, 67.63270201001848, 68.39877564566476, 60.47347967965262, 61.96329852512905, 57.23755768367222, 56.93781934465681, 59.66160351889474, 59.42571217673165, 56.2284152167184, 56.88752828325544, 53.584299087524414, 58.168852533612935, 56.035755566188264, 54.99378980909075, 48.91320235388619, 49.58538498197283, 49.6743358203343, 51.60216563088553, 55.249643325805664, 55.86228684016636, 50.94068322862898, 53.75181320735386, 51.98159633363996, 60.266402517046245, 58.70293971470424, 65.39638260432652, 60.72781848907471, 52.39074100766863, 62.70021751948765, 60.488397462027415, 60.15157658713204, 54.55965593882969, 49.90982069287981, 49.994633878980366, 56.786470208849224, 56.83244643892561, 56.65035152435303, 55.93976967675345, 58.507973262241904, 58.55787522452218, 59.51999923161098, 61.22230093819754, 62.11893122536795, 58.28969560350691, 51.488128321511404, 48.846312046051025, 54.884682246616904, 57.44525671005249, 62.61840942927769, 58.07297781535557, 57.62144912992205, 58.845801625932964, 55.885820388793945, 59.94841820853097, 58.7416272844587, 54.991288457598, 58.52453081948416, 58.84510680607387, 58.18006692613874, 52.827855655125205, 61.486360277448384, 56.520976066589355, 57.26817839486258, 58.91103826250349, 48.233098779405864, 44.3957268169948, 53.490692956107004, 56.82830531256539, 58.04112727301461, 54.829329422542024, 51.562366349356516, 49.267018522535054, 52.91093526567732, 54.37751933506557, 55.85605430603027, 50.93489537920271, 51.066796507154194, 47.12546559742519, 48.68209484645298, 47.15256009783064, 49.95508125850132, 52.77281897408621, 54.42409658432007, 55.23343317849295, 56.340965611594065, 58.621673583984375, 59.35024084363665, 50.40015159334455, 46.07343537466866, 44.81082262311663, 45.547540119716096, 44.02120501654488, 44.55043193272182, 46.50311892373221, 47.43396214076451, 49.15243577957153, 48.04772431509835, 50.05805703571865, 50.42125327246529, 53.362133911677766, 61.14704499925886, 60.88164465767996, 61.07204614366804, 64.58572932652065, 66.2190910066877, 65.49240670885358, 66.90110533578056, 69.01235021863664, 65.85289314814976, 66.756422996521, 64.42421845027378, 65.58022499084473, 63.12746919904436, 65.63647760663713, 66.9717824118478, 66.23492595127651, 65.77200222015381, 68.61129324776786, 74.52615574428013, 78.03906767708915, 82.74278272901262, 64.34262575422014, 0.5283946522644588, 0.23834318774087088, 0.1962953225842544, 0.35959313437342644, 1.292382851243019, 65.81060641152519, 74.45706285749162, 63.219553674970356, 53.150189535958425, 36.43468931743077, 79.67889813014439, 4.221107074192592, 0.18804281683904783, 0.11598348351461546, 0.16863060849053518, 0.134462068389569, 0.12093568992401872, 0.11660770859037127, 0.19816731927650316, 0.14300738913672312, 0.18898557339395794], [0.09992263426205941, 0.06675418013972895, 0.06469711302114384, 0.0379886854706066, 0.1401569585182837, 0.046077023060726266, 0.015113305633089371, 0.22982936458928244, 0.03610023091148053, 1.2292020129305976, 52.86399323599679, 45.04173558098929, 35.068499769483296, 51.56565632138933, 45.44583238874163, 75.72549819946289, 9.795278549194336, 0.334958974804197, 0.4615674210446221, 0.3538689858147076, 4.393316004957471, 80.3700076511928, 81.12643023899624, 78.3970319202968, 77.45235483986991, 70.40403965541294, 68.47244044712612, 64.5379535130092, 62.310708454677034, 63.1880783353533, 62.97228813171387, 63.5553879056658, 65.64154284340995, 62.71487127031599, 62.905168533325195, 58.402145249503, 52.33380052021572, 52.3038398878915, 51.868215629032676, 49.895965984889436, 50.39568042755127, 50.98025669370379, 51.49033784866333, 50.88577856336321, 51.28587668282645, 54.418604033333914, 49.359332289014546, 43.346830231802805, 43.62093666621617, 44.713867459978374, 46.01490027563912, 49.60008042199271, 49.24920334134783, 49.39525447572981, 49.00783681869507, 51.469538416181294, 50.82647221429007, 54.093622888837544, 54.93431322915213, 60.30211625780378, 41.49466282980782, 57.61211422511509, 61.287023408072336, 52.569837774549214, 52.38516855239868, 45.316943304879324, 47.98074715478079, 48.75299079077584, 52.69244221278599, 49.6096202986581, 58.6055120740618, 58.51713793618338, 56.896911825452534, 55.30997453417097, 54.999591554914204, 56.73201717649187, 55.29191269193377, 46.10952431815011, 47.98031289236886, 53.79529503413609, 52.863777841840474, 56.89843348094395, 51.68414395196097, 55.452336175101145, 56.49952697753906, 53.20324945449829, 49.87556259972708, 50.94840962546212, 52.29665197644915, 52.05148826326643, 51.918037687029155, 51.982384954180034, 51.72675377982003, 52.56919854027884, 55.098856994083945, 52.54806212016514, 51.69194677897862, 44.753427028656006, 41.860732146671836, 46.86443567276001, 53.777337414877756, 53.017934049878804, 49.44177613939558, 45.275629316057476, 46.50226082120623, 48.402221407209126, 48.403121198926655, 48.32036120550973, 48.40152658735003, 46.647412163870676, 44.73318345206124, 41.812136445726665, 41.47720548084804, 44.846310547419954, 47.04679809297834, 49.799716063908164, 51.12963254111153, 51.04928009850638, 50.660399845668245, 51.09093802315848, 45.5603734425136, 40.860684871673584, 39.97346939359392, 40.561359950474326, 41.45440149307251, 40.345649651118684, 38.19261482783726, 39.99159376961844, 44.44892222540719, 46.266397271837505, 44.54660694939749, 44.38279274531773, 45.02576862062727, 49.49528421674456, 53.36886671611241, 56.621624197278706, 63.057264600481304, 59.159276553562705, 61.72966534750802, 62.13094466073172, 62.9797157560076, 60.674178395952495, 60.60508550916399, 59.1221592766898, 61.255020005362375, 59.871112551007954, 63.31050559452602, 62.28278364453997, 62.82748072487967, 62.78529126303536, 61.888612338474815, 62.36343138558524, 72.61088480268205, 68.46662480490548, 75.18072468893868, 2.938114821910858, 0.16433229270790303, 0.13777124296341622, 0.07512822507747582, 0.2817868808550494, 37.23150525774275, 71.15932968684605, 44.71476377759661, 43.56638288497925, 27.41140079498291, 51.50994219098772, 6.617563349860055, 0.31296830624341965, 0.11493414267897606, 0.19536838946597918, 0.05455473797129733, 0.07518513380948987, 0.08965373957263571, 0.07338018994778395, 0.0523198641437505, 0.07220534048974514, 0.042474616185895035, 0.08951063653720276, 0.05575930726315294, 0.12388258108070918, 0.03797133872285485, 0.11222431808710098, 0.020941532981981124, 0.19129019044339657, 0.08534901841942753, 1.9933213591575623, 63.21034731183733, 51.57692629950387, 35.202263014657156, 43.62556069237845, 56.984584195273264, 79.2535572052002, 11.057485699653625, 0.5580381101795605, 0.6525187918118068, 0.5711922443338803, 5.204516019139971, 84.27233137403215, 83.5103988647461, 79.61198002951485, 80.25553607940674, 76.76578249250139, 69.578524180821, 67.10281154087612, 67.10959993089948, 64.98654311043876, 67.31374495370048, 64.40556253705705, 67.83627033233643, 65.68872111184257, 65.80541610717773, 61.191666330610005, 54.340690408434185, 54.63476249149868, 54.5960054397583, 52.240465368543354, 54.09080539430891, 53.4075334412711, 54.50479643685477, 53.02506290163313, 53.020699432918, 56.33270072937012, 52.72981309890747, 44.86821821757725, 47.543834005083355, 48.83415617261614, 47.73421812057495, 50.94377170290266, 51.912652833121165, 50.763226236615864, 51.46378878184727, 52.78358520780291, 53.89759336199079, 55.64455461502075, 56.85727235249111, 62.562469482421875, 44.99411262784685, 57.74981015069144, 62.56576987675258, 54.45379318509783, 55.673490388052805, 47.64169590813773, 52.90696784428188, 52.179383754730225, 55.96210813522339, 53.17039837156023, 61.69233962467739, 61.88507570539202, 58.22481679916382, 58.707622800554546, 57.393516949244905, 60.82933861868722, 56.96851301193237, 48.66007947921753, 50.74879482814244, 52.001079082489014, 52.51175083432879, 57.72146497453962, 55.16696671077183, 57.150865009852815, 57.68738406045096, 55.094872202192036, 52.72377164023263, 53.46805919919695, 56.970521041325156, 54.708291803087505, 52.47937222889492, 53.24004364013672, 51.64020701817104, 53.51130826132638, 56.23054483958653, 56.96717200960432, 52.31130920137678, 45.132499899183, 43.25948790141514, 47.48844296591622, 56.90313393729073, 56.20511443274361, 51.150070667266846, 46.757037367139546, 48.387025696890696, 50.73781667436872, 50.76387936728341, 51.8831125668117, 51.19331278119768, 49.52489743913923, 46.15090431485857, 43.34298440388271, 44.00327171598162, 48.626484939030235, 49.684108461652485, 51.08196789877755, 53.87316002164568, 52.8204801423209, 53.93605511529105, 54.99366821561541, 48.54019526072911, 42.54745388031006, 42.28583683286394, 42.71273762839181, 43.86827516555786, 42.687484400612966, 42.03322465079171, 42.851364612579346, 47.60814305714199, 47.870249952588765, 47.78787211009434, 46.27445718220302, 47.30225556237357, 52.353373595646445, 55.97648743220738, 60.30996077401297, 64.13542352403913, 60.77164772578648, 64.40520817892892, 62.47723593030657, 65.06674616677421, 62.752064977373394, 62.249543462480815, 61.744868006025044, 62.74074636186872, 60.99484470912388, 66.23916435241699, 65.01258495875767, 67.25825663975307, 64.82969447544643, 64.65204293387276, 62.81633581433977, 75.64467675345284, 68.91934858049665, 79.46419184548515, 4.939643740653992, 0.2406567478818553, 0.09999548178166151, 0.02177726081572473, 0.6626382459487233, 40.31042228426252, 77.84374686649868, 52.763911383492605, 42.45194394247872, 36.708434445517405, 64.12819044930595, 12.250993405069623, 0.3234721640391009, 0.1190583056637219, 0.15353042233203137, 0.10099316574633121, 0.10091456424977098, 0.06283950127129044, 0.08086938450911216, 0.009321029613991933, 0.0191207792543407, 0.11152545415929385, 0.20656068889158113, 0.23739850414650782, 0.14353410873029912, 0.1345578096807003, 0.16456910142941134, 0.10762832220643759, 0.3888066996421133, 0.20616608006613596, 1.9119457943098885, 72.03717204502651, 57.007902349744526, 47.495429379599436, 69.06801223754883, 61.65306840624128, 88.26024300711495, 13.846568175724574, 0.5364534226911408, 0.7313919737935066, 1.4289394893816538, 5.492020317486354, 88.23574365888322, 87.29079559871128, 86.15775980268205, 84.08919770377022, 79.7536676951817, 75.98210906982422, 69.40095601763043, 70.5242782320295, 68.63622338431222, 69.65787260872978, 67.36133316584996, 72.32149927956718, 69.14278875078473, 67.71532303946358, 63.40214538574219, 58.1119259425572, 58.34888730730329, 57.9113245010376, 55.17461667742048, 57.68793296813965, 56.66230937412807, 57.08705275399344, 55.67290326527187, 54.9040572983878, 59.62003244672503, 54.13437754767281, 48.98144061224801, 50.580651896340505, 50.334508487156455, 49.84685959134783, 54.42672300338745, 54.46984004974365, 54.31051090785435, 53.581175872257774, 57.18965332848685, 56.29062243870327, 57.65014866420201, 60.91107027871268, 65.31943825313023, 49.954706055777415, 62.71542712620327, 64.4035336630685, 57.13284485680716, 57.077366965157644, 51.11291170120239, 54.36083671024868, 56.14849703652518, 57.75219685690743, 56.301972321101594, 64.59574168069022, 63.62465449741909, 61.31628227233887, 58.0432881627764, 61.09416920798165, 62.82290186200823, 62.0496437890189, 54.76176166534424, 51.55144725527082, 55.372216497148784, 52.92192036764962, 62.063137190682546, 57.67988348007202, 61.77366828918457, 61.42162391117641, 58.43050084795271, 53.43317229407174, 56.01225675855364, 58.04226677758353, 55.58055823189871, 56.8255295072283, 54.41513340813773, 53.233779839106965, 56.84226771763393, 58.14383554458618, 59.223394530160085, 54.71319375719343, 47.70511211667742, 45.70301301138741, 51.22592415128435, 59.27889674050467, 58.145544801439556, 52.82495478221348, 49.13486378533499, 51.277830668858115, 52.963567870003835, 52.08859511784145, 54.555250780923025, 53.681532178606304, 53.07658379418509, 49.254456179482595, 45.22338581085205, 46.142048835754395, 49.67956781387329, 52.10871710096087, 54.54185465403965, 55.42033972058977, 57.5178028515407, 56.247925758361816, 57.2700856753758, 50.81857558659145, 46.1532632282802, 45.03052118846348, 45.500420910971506, 47.20770795004708, 47.22039883477347, 44.996506282261436, 44.64045974186489, 49.20969588415963, 51.08411489214216, 50.78443561281477, 49.78706339427403, 49.92810140337263, 55.76994528089251, 57.46921409879412, 61.30228860037667, 67.90959467206682, 61.6743437903268, 66.49617821829659, 66.38423579079765, 67.79554694039481, 66.41969244820731, 65.2738789149693, 65.13642270224435, 65.84136608668736, 65.13144779205322, 69.03100613185337, 67.37166513715471, 69.23621422903878, 67.09980297088623, 67.83629812513078, 66.75089917864118, 79.3978157043457, 73.35183375222343, 82.87364510127476, 5.11608499288559, 0.23772881499358586, 0.43593975050108774, 0.13579404620187624, 2.0604787383760725, 46.497876507895334, 85.53763307843889, 57.39381224768502, 61.67421872275216, 38.853430203029085, 72.40229293278286, 14.90396067074367, 0.53611209243536, 0.2834600125040327, 0.21847250685095787, 0.11563091671892575, 0.25831073629004614, 0.11677635168390614, 0.2409088100705828, 0.09473984808261905, 0.19722917675971985], [0.0556154917659504, 0.007073792030236551, 0.05000050252835665, 0.029633266319121634, 0.07545823058379547, 0.14122267918927328, 0.027298920954178487, 0.16178030893206596, 0.0775402949324676, 3.2427985412733893, 61.940682138715474, 33.3996536391122, 35.59843192781721, 42.176781381879536, 47.06968893323626, 72.22027792249406, 6.359926751681736, 0.255962218024901, 0.5878537531409944, 0.7402918562293053, 10.534795301301138, 88.44860867091587, 77.97902134486607, 77.38869544437954, 70.29023511069161, 63.10479722704206, 60.00902039664132, 59.38202885219029, 61.99043124062674, 64.66149943215507, 63.21027088165283, 65.80084419250488, 65.10235568455288, 65.47646059308732, 63.40290968758719, 59.17540332249233, 53.531294754573274, 51.20711537769863, 51.13536480494908, 51.86315734045846, 53.002550738198416, 50.260729040418354, 50.3144976752145, 49.200079577309744, 50.84514202390398, 52.78618383407593, 44.792632239205496, 42.72166953768049, 44.7029309953962, 45.795389311654226, 46.622593198503765, 50.29802697045462, 46.29005936213902, 50.74331617355347, 50.62191724777222, 48.611737387520925, 49.64802994046892, 53.112398283822195, 53.60098171234131, 60.53941808428083, 51.943617480141775, 43.49281535829817, 61.81897749219622, 56.02422155652727, 52.209465980529785, 45.715134143829346, 44.43914263589041, 52.007641656058176, 49.89685188020979, 56.32423087528774, 55.18968037196568, 63.165322984967915, 55.47410488128662, 58.64994580405099, 57.93705368041992, 56.61504772731236, 52.216952664511545, 45.50621918269566, 47.55958904538836, 46.2322017124721, 54.46404872621809, 54.86930588313511, 54.47475242614746, 56.939427852630615, 56.53310762132917, 53.57363707678658, 51.197130816323416, 52.96819189616612, 53.25936310631888, 54.79859059197562, 52.818955012730186, 54.97442865371704, 53.29106078829084, 52.41101585115705, 52.389125551496235, 53.5540257862636, 51.86296626499721, 44.82077244349888, 38.88050733293806, 47.6095153263637, 51.65911306653704, 54.0177172933306, 49.455742018563406, 46.76511117390224, 49.867436681474956, 51.364690099443706, 49.30874940327236, 52.83550214767456, 51.82313919067383, 46.54231023788452, 42.540686334882466, 42.81224972861153, 45.154417991638184, 44.457864556993755, 46.45626722063337, 49.67523561205183, 49.769755431583945, 49.78088991982596, 51.20618084498814, 51.29250526428223, 48.9319555418832, 41.70205266135079, 40.777952671051025, 41.06016417912075, 40.15574148723057, 40.30506869724819, 38.28348684310913, 36.81824377604893, 44.41995171138218, 43.85406262534005, 44.06072637013027, 44.41769354684012, 44.46813746861049, 46.15292624064854, 54.78812313079834, 57.79779788425991, 59.91997923169817, 59.736783027648926, 60.83991377694266, 59.04496479034424, 61.74784183502197, 57.979375158037456, 60.69689900534493, 58.65806130000523, 62.12285695757185, 64.81815351758684, 66.33985764639718, 65.9192762374878, 70.7128106525966, 65.37701102665493, 66.49523326328823, 58.18400655473982, 75.3135186604091, 64.9254823412214, 83.74364989144462, 14.170141441481453, 0.3381142169237137, 0.14195179220821175, 0.1382074731269053, 0.21876134563769611, 29.175298282078334, 73.99519525255475, 46.98275654656546, 42.507953371320454, 18.882341112409318, 50.858444350106375, 21.31911083630153, 0.3871674676026617, 0.02542865282988974, 0.12003296693520886, 0.042970123168613227, 0.007401386192733688, 0.024244624489386166, 0.05095794258107032, 0.060929235203989913, 0.10713282879441977, 0.04603522530357752, 0.018572578938411813, 0.01104564086667129, 0.08168533643973724, 0.03511986994583692, 0.10029135019119297, 0.055419164443654675, 0.1595462052417653, 0.1809811264808689, 5.098088724272592, 72.40712193080357, 38.484039647238596, 36.565030574798584, 44.53368330001831, 54.81471388680594, 78.43688678741455, 6.378964815820966, 0.22288886058543408, 0.4533736492906298, 0.829081800367151, 12.311955162457057, 90.25658552987235, 79.31668853759766, 80.15104212079729, 71.86066695622036, 64.69865145002092, 61.77747590201241, 61.744610922677175, 64.2010840007237, 67.2012049811227, 64.72932079860142, 68.28888988494873, 67.70324012211391, 68.31677995409284, 66.74415247780937, 62.17152908870152, 56.175292764391216, 52.29734679630825, 53.52466269901821, 52.84240518297468, 54.32725606645857, 52.71963398797171, 53.63158852713448, 51.496542590005056, 53.584007263183594, 54.762967177799766, 48.79333897999355, 44.630020073481965, 45.66188662392752, 49.36731924329485, 49.222737652914866, 51.99995347431728, 48.352767603737966, 53.67845412663051, 51.68956354686192, 49.38047218322754, 52.3810031073434, 55.1128819329398, 57.273379121507915, 60.47002642495291, 57.37695591790335, 47.86319405691964, 61.971476554870605, 57.6691380909511, 55.62006916318621, 48.41385963984898, 48.03866386413574, 52.49743407113211, 53.483772550310405, 60.94753442491804, 58.21304655075073, 65.10035460335868, 55.48415197644915, 60.519045966012136, 59.35691806248256, 60.57593781607491, 56.27808788844517, 49.05713428769793, 49.38721888405936, 45.991571698869976, 54.102061476026265, 58.63978058951241, 56.678328445979524, 57.69564546857561, 57.94607244219099, 55.703065395355225, 54.89507327760969, 56.37255212238857, 55.79855448859078, 57.052673067365376, 58.01343870162964, 56.87141193662371, 56.060866355895996, 53.357700960976736, 54.4228424344744, 55.01309537887573, 53.63815804890224, 46.15975979396275, 41.71013341631208, 49.33194596426827, 52.74304941722325, 56.539722306387766, 50.108476638793945, 49.490583760397776, 53.15246507099697, 53.8540073122297, 52.56184039797102, 53.794461250305176, 53.883547578539165, 49.768452644348145, 45.24876758030483, 44.199117115565706, 44.822523389543804, 47.755007130759104, 47.58965737479073, 51.04213735035488, 52.133556910923545, 53.00246735981533, 54.83241094861712, 51.95725679397583, 50.421041352408274, 45.186497824532644, 43.924392291477744, 43.43455818721226, 43.701928343091694, 42.28945337023054, 39.895326478140696, 39.60747650691441, 45.391417571476524, 46.84213195528303, 46.24383994511196, 46.57217012132917, 46.54630197797503, 47.92681871141706, 57.34577240262713, 59.57354899815151, 63.16223103659493, 62.37531280517578, 62.42881393432617, 60.87342493874686, 61.64978190830776, 60.042420387268066, 62.3959697995867, 60.86323193141392, 66.57051004682268, 65.36586611611503, 69.59306676047188, 68.05777890341622, 73.29845074244908, 65.02008206503731, 68.680816922869, 59.30211762019566, 77.86850329807827, 65.23351682935441, 87.77086748395647, 16.53875889096941, 0.3299065487725394, 0.09041464195719787, 0.5770112520882061, 0.14301059182201112, 32.93752547672817, 81.36942264011928, 55.41507298605782, 42.74682549067906, 23.297012839998516, 64.53734901973179, 32.25196756635393, 0.2046906328094857, 0.04956298654100724, 0.07946479666445937, 0.04795269062742591, 0.06713557788836104, 0.019771563887063946, 0.11261296937508242, 0.07731970998325519, 0.09240317703889948, 0.19129998848906585, 0.16303204319306783, 0.13301514674510273, 0.14907299008752617, 0.1322256712509053, 0.23000893209661755, 0.20354572710181984, 0.2337638091828142, 0.25121572986245155, 5.631636551448277, 82.05127716064453, 43.774748938424246, 49.37470170429775, 57.487571239471436, 61.032740184238975, 86.98531109946114, 8.737238134656634, 0.33116406415190014, 1.0618341309683663, 1.1480810344219208, 13.269230195454188, 94.65350982121059, 84.05180249895368, 84.5346119744437, 77.52754824502128, 70.53585393088204, 65.46283517565045, 66.39081573486328, 68.11710262298584, 71.91713496616909, 69.1724019731794, 72.20677757263184, 70.65226405007499, 72.89644186837333, 70.44861929757255, 65.11209011077881, 59.04817485809326, 55.349930150168284, 55.98156656537737, 55.024347986493794, 56.71237114497593, 55.7957752091544, 56.02992255347115, 54.45551981244768, 57.440663950783865, 57.76731961114066, 51.700083119528635, 48.12071514129639, 49.93012680326189, 51.6144882610866, 51.99858120509556, 55.58620016915457, 49.62633071626936, 56.396394865853445, 53.89077370507376, 53.13187755857195, 55.52025481632778, 57.94188962663923, 60.2712801524571, 64.28974996294293, 59.19070325578962, 52.211661611284526, 65.69849027906145, 60.707682609558105, 57.23715121405465, 50.90174204962594, 50.3981922013419, 55.36779049464634, 57.05468804495675, 62.003563335963655, 63.55941786084856, 66.61036491394043, 56.89639071055821, 64.27754197801862, 61.855316570826936, 61.946365765162874, 58.146444593157085, 54.02504069464547, 51.05949395043509, 48.83746698924473, 56.143897329057964, 58.84227194104876, 59.51205744062151, 60.583247320992605, 61.64530726841518, 60.17449174608503, 57.56172241483416, 60.1307041985648, 58.4882264818464, 60.145406586783274, 57.099827017102925, 61.18622589111328, 56.60421895980835, 55.8448121207101, 57.74539109638759, 57.27951438086373, 54.58470072065081, 49.08164405822754, 44.0463991846357, 54.0174880027771, 56.665946756090435, 58.39355032784598, 53.97443349020821, 51.989788259778706, 55.791842528751914, 56.95822967801775, 53.91155924115862, 58.08036027635847, 57.008930683135986, 52.8274040222168, 48.364496162959504, 47.190399987357004, 50.117523193359375, 50.94962903431484, 50.405091762542725, 54.35254750932966, 55.48139006750924, 55.542384828839985, 58.90557697841099, 56.44237804412842, 52.66932208197457, 48.36764369692121, 46.50024931771414, 45.73312650408064, 47.24057640348162, 45.22943074362618, 43.78273589270455, 43.34462070465088, 49.47208765574864, 48.6826958656311, 47.18391384397234, 49.24099751881191, 49.126890727451865, 51.27061496462141, 61.09259196690151, 62.77984387534005, 65.04908384595598, 65.91708755493164, 66.50466196877616, 63.4577031816755, 68.07592064993722, 62.384887422834126, 66.48775700160435, 64.31394359043666, 68.58919102805001, 68.77219268253872, 72.30204432351249, 70.99231583731515, 77.25984110151018, 71.48908424377441, 72.9416537966047, 62.53759493146624, 83.1915807723999, 67.98888056618827, 91.28987993512834, 17.107503686632427, 0.344589748020683, 0.30450442326920374, 1.1588059046438761, 1.0648052458252226, 38.29285648890904, 90.12706415993827, 59.49201883588518, 59.292355401175364, 28.02715015411377, 70.80821636744908, 35.44146517344883, 0.3506427417908396, 0.2795642986893654, 0.2720961251429149, 0.12933262863329478, 0.15236539127571241, 0.09676902741193771, 0.14452073935951504, 0.21628098801842757, 0.1794051339051553], [0.037918474059551954, 0.14102951384016446, 0.015109083448935832, 0.061303447266774516, 0.04106464755854436, 0.1255120150744915, 0.08198284690401383, 0.3566250593534538, 0.19269228806453093, 7.5307581424713135, 63.10249737330845, 34.69652795791626, 41.80148833138602, 45.91541944231306, 53.6046781539917, 69.72270624978202, 4.249840046678271, 0.25210599494831903, 0.32349699842078344, 0.2966669095414025, 13.041851265089852, 89.42997918810163, 77.89818600245884, 77.47106633867536, 70.0611321585519, 64.75233323233468, 59.49171311514718, 59.58609744480678, 60.263136863708496, 60.18060616084507, 62.3074289049421, 62.71196692330496, 64.3343504496983, 63.881272315979004, 63.874428340366904, 63.391757828848704, 56.77789960588728, 50.741103172302246, 51.149480070386616, 51.246754850660054, 50.2887407030378, 49.62019198281424, 51.581307138715474, 51.354417187826975, 51.44196796417236, 52.75508369718279, 43.84773281642369, 43.380667958940776, 44.67324481691633, 46.68335172108242, 46.4622391973223, 48.16390514373779, 46.482955251421245, 51.736467361450195, 51.233515058244976, 48.42173889705113, 49.79902471814837, 50.54622704642159, 53.603319781167166, 56.02208498546055, 60.425085476466585, 48.62234033857073, 48.310689313071116, 58.45851598467146, 53.63195678165981, 48.75462361744472, 44.06665318352835, 52.47860792704991, 54.355827059064595, 57.93389572416033, 56.574122837611604, 52.61425413404192, 60.43758528573172, 56.20840440477644, 56.1161983353751, 57.737588269369944, 46.29069512231009, 45.604178360530305, 47.76353257043021, 51.976659638541086, 55.094844409397666, 54.724217074257986, 55.547856535230366, 55.12872382572719, 53.69377143042428, 51.09889718464443, 58.8451623916626, 55.90978472573416, 53.163901805877686, 53.72063316617693, 58.70814391544887, 53.80666923522949, 52.94312974384853, 55.09112712315151, 54.55556344985962, 52.27434131077358, 51.39987925120762, 46.315618310655864, 39.87705618994576, 45.355095863342285, 52.908899443490164, 52.23196772166661, 53.91221237182617, 47.26869228907994, 49.962484564099995, 49.26063312802996, 53.390114307403564, 47.62416212899344, 51.342077187129426, 49.318838187626426, 44.415418011801584, 40.846434116363525, 43.382339000701904, 43.19980634961809, 44.67122983932495, 46.80875628335135, 50.27641807283674, 49.90594359806606, 51.625469888959614, 48.615142004830496, 48.88586119243077, 44.003407205854145, 41.57020017078945, 42.4840897832598, 42.168770108904155, 39.61373683384487, 40.465259415762766, 35.85346555709839, 40.3339523587908, 43.536793981279644, 43.71250350134713, 46.70206669398716, 45.30181360244751, 45.01276854106358, 50.88908243179321, 55.64821284157889, 60.33659321921212, 58.78458104814802, 59.384238379342214, 57.298205035073416, 56.321885858263286, 58.33860397338867, 60.70748805999756, 62.68657125745501, 64.81552015032086, 64.84047807965959, 69.19327436174665, 67.30624089922223, 70.60136154719761, 67.40892137799943, 68.12340463910783, 56.94407272338867, 71.31691483088902, 63.80942794254848, 86.94085652487618, 26.506059203829082, 0.24709379247256688, 0.04914586392364331, 0.08826408628374338, 0.06663348233061177, 20.243206603186472, 72.35017449515206, 46.795898641858784, 50.09102623803275, 27.62297691617693, 34.36427552359444, 42.7391095161438, 0.2690465987793037, 0.06441953791571514, 0.17821771119322094, 0.09367347601801157, 0.1492028481193951, 0.02749451036964144, 0.07026296614536218, 0.03377009076731546, 0.07848940936050244, 0.04485022496165974, 0.139659904475723, 0.034836103208363056, 0.06047072195048843, 0.04277925805321761, 0.1061812648549676, 0.09506805547113929, 0.2174074918563877, 0.3235662632754871, 10.417118872914996, 72.2515309197562, 42.53311627251761, 42.0583667073931, 50.475477014269146, 61.47587544577462, 75.79547350747245, 4.839644398008074, 0.25323757422821863, 0.34772354843361036, 0.34454841166734695, 15.369436127798897, 91.0474294934954, 80.10674040658134, 81.19639859880719, 74.27433913094657, 66.76429530552456, 61.70484638214111, 62.85925483703613, 62.92869513375418, 62.912867137363975, 66.02206093924386, 65.03960650307792, 67.91274220602853, 66.96450069972447, 65.51662812914167, 64.89395836421421, 58.54043524605887, 54.19703640256609, 53.946713651929585, 53.88678543908255, 53.41184132439749, 52.25843688419887, 52.5679270199367, 53.76165533065796, 53.855240617479595, 54.59145784378052, 45.963539191654746, 44.66116189956665, 46.93174982070923, 48.252953256879536, 49.721100670950754, 50.39904335566929, 50.22553641455514, 54.971534729003906, 52.06679514476231, 50.51537357057844, 53.06315292630877, 52.9512209211077, 56.28854145322527, 57.50087703977312, 62.24586091722761, 52.99537672315325, 50.033752237047466, 60.346313749040874, 55.14033079147339, 51.88882746015276, 48.065445695604595, 53.30189650399344, 56.56155007226126, 60.33625275748116, 58.90928036825997, 54.67964785439627, 62.69094167436872, 57.39325639179775, 57.31491197858538, 59.193107332502095, 47.49645076479231, 49.97790609087263, 48.261468274252756, 52.126337732587544, 56.93509912490845, 57.45729446411133, 59.28178719111851, 59.14076655251639, 55.97779369354248, 54.8875344821385, 60.602737018040244, 58.200984477996826, 53.58313179016113, 57.15412718909127, 59.90891075134277, 55.4061723436628, 55.398567540305, 56.85070283072335, 56.348896980285645, 55.66129282542637, 52.25274978365217, 48.401568276541575, 41.81071553911482, 48.451070717402864, 53.825613498687744, 54.894406250544954, 56.160843985421316, 49.30358689171927, 52.98925188609532, 52.13895566122872, 54.6404322215489, 49.36562040873936, 55.10254996163504, 50.74931594303676, 47.98485006604876, 44.25053378513881, 43.59018393925258, 46.01578269686018, 47.554065227508545, 49.61082233701433, 52.54205192838396, 51.97266789845058, 53.177537645612446, 51.34254619053432, 51.31182820456368, 46.397752966199604, 42.59599052156721, 44.26125832966396, 44.932440417153494, 43.51026923315865, 43.33066177368164, 39.1100549697876, 42.27565424782889, 46.848805700029644, 46.45967878614153, 48.6086871283395, 48.232456071036204, 47.449619906289236, 51.61068412235805, 58.089524950299946, 64.26463222503662, 60.62194878714425, 62.13962990897042, 58.88019520895821, 59.980796813964844, 60.47536958966936, 65.84666756221226, 64.35505608149937, 66.06165177481515, 66.08936813899449, 70.14011928013393, 68.42879881177629, 72.88556793757847, 68.56496265956334, 70.87004838671002, 59.550821440560476, 73.59242902483258, 67.17227268218994, 87.83506189073834, 30.243632452828543, 0.21073827972369535, 0.08452909027359315, 0.1386371079300131, 0.3774229719170502, 23.212505374635967, 78.52573340279716, 56.6890321459089, 53.60856914520264, 25.38791513442993, 46.66599859510149, 48.70720216206142, 0.46391602073396954, 0.09059578366577625, 0.10966307230825935, 0.04258685605600476, 0.06282748441611018, 0.06943750115377562, 0.09207796877516167, 0.018045119741665464, 0.09487866277673415, 0.1377782861569098, 0.22672801172094686, 0.08795451146683522, 0.12910379948360579, 0.13175947698099272, 0.18082443917436258, 0.24457181351525442, 0.4310241442705904, 0.4080459901264736, 12.333255733762469, 82.93606076921735, 46.26245069503784, 55.159629413059776, 59.905617305210654, 69.44220747266496, 83.09445885249546, 6.447324667658124, 0.39241818870816914, 0.683084243110248, 0.46913943759032656, 17.12436522756304, 94.35170786721366, 85.72196183885846, 84.66703769138881, 77.64361790248326, 72.1952713557652, 67.2898917879377, 66.21013477870396, 66.58209269387382, 65.83022812434605, 70.73118863786969, 68.46731962476457, 70.73116084507534, 68.89569691249302, 67.99237551007951, 67.38125365121024, 63.37986946105957, 57.39609125682286, 56.45695883887154, 56.325443335941856, 55.75817503247942, 53.45729643957955, 56.00622572217669, 55.83787087031773, 56.15496233531407, 55.99278790610177, 48.969434125082834, 48.02271774836949, 50.03571857724871, 52.65550558907645, 51.45725747517177, 52.19359629494803, 51.53515372957502, 58.22562973839896, 54.22199085780552, 53.06113794871739, 54.14262853349958, 56.83855390548706, 59.28403145926339, 63.73032964978899, 65.98201847076416, 54.24508319582258, 53.51670353753226, 64.33682400839669, 59.29168142591204, 54.506988593510215, 49.52208341870989, 56.4480026108878, 60.38541126251221, 63.56616456168038, 60.48827239445278, 59.75903810773577, 59.82263496943882, 57.01327330725533, 61.89423343113491, 63.69985485076904, 52.91547243935721, 54.87287378311157, 51.771805899483816, 53.68597902570452, 58.38226645333426, 59.8303405216762, 60.39727183750698, 58.92203031267439, 58.60133620670864, 56.78830105917794, 65.12312385014125, 60.75130340031215, 57.37623677934919, 59.324296270098, 63.637195995875764, 57.85755934034075, 58.17683948789324, 59.37829072134835, 59.04931436266218, 57.04201453072684, 54.82401752471924, 50.23917572838919, 44.96802909033639, 54.013854094914024, 56.46212829862322, 57.01215117318289, 60.097213881356375, 51.372030871255056, 54.50455672400338, 54.035473414829795, 56.80463974816458, 53.40518147604806, 56.03272615160261, 53.26705476215908, 49.943634101322715, 46.31329066412789, 47.5349576813834, 48.80245501654488, 50.10793120520455, 51.22289473669869, 55.390903677259175, 54.46968371527535, 56.52818482262747, 54.84292704718453, 53.20307574953352, 50.00366653714861, 45.77376651763916, 47.76147937774658, 47.13038144792829, 45.61773082188198, 47.64352328436715, 42.195378235408235, 45.260760171072825, 48.26631811686924, 48.66454369681222, 50.78029448645455, 49.98659133911133, 50.063629490988596, 54.76973819732666, 60.91621889386858, 65.54776300702775, 63.339785303388325, 64.93918418884277, 63.16149452754429, 63.15473393031529, 62.27321597508022, 67.19491686139787, 67.69807761056083, 68.214738709586, 68.63315228053501, 71.56822422572544, 71.6468847819737, 76.17268426077706, 72.10131086621965, 73.64470032283238, 62.09186799185616, 78.29654012407575, 69.8218639918736, 91.12281744820731, 31.029689107622417, 0.2832996611084257, 0.1307266652584076, 0.24778931800808224, 1.259345252599035, 27.109934091567993, 86.62667288099016, 61.690560885838096, 70.60865020751953, 40.63380534308297, 50.596736976078574, 58.64567961011614, 0.5653767106788499, 0.09875573044908897, 0.29687361844948357, 0.2089367149663823, 0.24073917631592068, 0.13436355867556163, 0.30296602153352326, 0.12970038104270185, 0.12012323923408985], [0.07008349363292966, 0.14873091344322475, 0.03354722594044038, 0.10629553693745818, 0.03435878774949482, 0.21690551164959157, 0.06577867748481886, 0.13727873510548047, 0.08600717024611575, 9.963537863322667, 58.12049307141985, 35.17895180838448, 40.531381947653635, 41.22643804550171, 59.67349188668387, 64.79530784061977, 2.5776157890047346, 0.15295395255088806, 0.5518488937190601, 0.5255651069538934, 13.285002606255667, 90.90629073551723, 74.59580448695591, 77.32403550829206, 70.05945764269147, 65.37571171351841, 61.638852391924175, 57.768966334206716, 57.06659378324236, 61.273113114493235, 62.38285160064697, 63.45904418400356, 65.28318255288261, 64.96391977582658, 64.28467777797154, 58.63666779654366, 58.94935757773263, 54.46755756650652, 50.59797028132847, 49.16386209215437, 49.629697118486675, 50.60562024797712, 49.769491400037495, 50.12528780528477, 50.68375621523176, 51.55471290860857, 42.43340267453875, 43.426706722804475, 43.98105137688773, 45.93633699417114, 47.05342320033482, 47.287959643772666, 45.1049850327628, 50.2393980707441, 47.56860433306013, 49.509920597076416, 48.26818023409162, 51.17312479019165, 52.474414689200266, 52.13799680982317, 54.65054532459804, 58.634347098214285, 56.22955124718802, 58.28409188134329, 54.83001382010323, 49.554347378867014, 46.45933485031128, 47.112177167619976, 53.66183403560093, 57.385620321546284, 60.205647468566895, 49.75384405681065, 50.87285838808332, 61.66590172903878, 56.61153193882534, 53.80444581168038, 42.802365916115896, 46.78880105699812, 46.122927393232075, 44.51346404211861, 52.07447985240391, 56.310223306928364, 54.783325399671284, 55.65198571341378, 54.759364536830354, 55.57830354145595, 48.99570178985596, 46.12725959505354, 44.62464911597115, 47.186616693224224, 44.49703502655029, 52.96308497020176, 52.77900981903076, 52.415921279362266, 52.10756022589547, 52.18154811859131, 50.49606452669416, 44.43283019747053, 38.81827579225813, 41.723505224500386, 50.06875031335013, 54.214465958731516, 51.93000943320138, 51.54258482796805, 51.02241836275373, 52.895308767046245, 50.021634578704834, 48.16680949074881, 53.929030486515586, 51.22614996773856, 46.82359068734305, 42.66026483263288, 43.42243358067104, 43.08234010423933, 45.54203019823347, 47.19444383893694, 48.409715039389475, 47.50630678449358, 48.242367676326204, 47.07267318453108, 47.80740697043282, 45.54528890337263, 41.331359318324495, 40.50087240764073, 43.07827888216291, 40.88906478881836, 40.59724044799805, 37.02493183953421, 36.894944940294536, 42.57649735042027, 46.07966790880476, 45.237831115722656, 44.54699604851859, 45.438925879342214, 45.75449916294643, 48.87635605675833, 57.34508453096662, 55.4197039604187, 56.294103486197336, 55.361849784851074, 58.52417646135603, 59.78373895372663, 64.40561812264579, 62.95914213997977, 69.22761235918317, 69.05683953421456, 64.67770263126918, 65.00781154632568, 69.25011757441929, 66.31168964930943, 66.78522327968052, 59.377797399248394, 71.02239458901542, 66.74503489903041, 82.35333619798932, 40.57141399383545, 0.09750805382749864, 0.048291262638356, 0.24608893639275006, 0.2866377548447677, 16.84138420649937, 71.12364373888288, 50.723051752362935, 50.3544602394104, 31.66895464488438, 31.08322150366647, 44.0841417993818, 1.146201980965478, 0.18698020385844366, 0.13929656254393713, 0.0696992256811687, 0.06549868679472379, 0.07116519380360842, 0.06006572475390775, 0.04298250304002847, 0.10019950369106871, 0.04284517773027931, 0.1341165312166725, 0.04128639958798885, 0.049913012223052125, 0.03331718221306801, 0.26797934461917194, 0.06393904012760945, 0.1896956738616739, 0.2379115309034075, 14.86014359337943, 65.86388519832066, 44.54434878485543, 43.082756996154785, 41.00221620287214, 69.9688948222569, 68.34342629568917, 2.8780930255140578, 0.27657366916537285, 0.5456690139004162, 0.4975578955241612, 14.802543027060372, 91.50435692923409, 76.44953523363385, 80.92610672542027, 72.34220491136823, 68.16473252432687, 64.52537032536098, 60.37012522561209, 59.509695053100586, 65.4973121370588, 64.12113802773612, 66.1629148210798, 68.25895704541887, 66.64594663892473, 66.17371232169015, 62.809707232883994, 60.50486469268799, 55.62782335281372, 52.35587494713919, 53.050878933497835, 51.855806146349224, 53.56683479036604, 52.170173917497905, 52.894777229854036, 52.76455061776297, 53.21908787318638, 44.650110789707725, 46.243586335863384, 47.19427708217076, 46.71274954932076, 50.22499792916434, 49.43415396554129, 47.39688307898385, 52.62652117865426, 49.71575403213501, 51.956523759024485, 50.66875505447388, 53.16760866982596, 54.39150605882917, 54.478261266435894, 58.15885407584054, 61.24620968954903, 58.0399078641619, 60.00582422528948, 59.21601554325649, 52.893217359270366, 47.253976004464285, 50.5582925932748, 56.158280100141255, 59.37712342398507, 60.85073907034737, 51.53789479391915, 53.571695055280415, 61.967856543404714, 57.569824014391216, 56.90804283959525, 49.78284931182861, 51.21147884641375, 47.14362818854195, 46.59000614711216, 51.555772508893696, 59.01085608346121, 58.66842106410435, 58.31115164075579, 55.847462858472554, 56.386903626578196, 50.40667247772217, 46.8170941216605, 48.04216923032488, 47.67178160803658, 45.28984185627529, 54.58394684110369, 54.89748430252075, 54.205367292676655, 54.66998985835484, 55.80314377376011, 53.48678806849888, 45.54291261945452, 42.2210761478969, 44.42618077141898, 52.836843150002615, 55.914419174194336, 55.7976963860648, 53.976118428366526, 55.71191045216152, 55.55728524071829, 52.21796710150582, 52.493612561907085, 55.3116386277335, 52.236167907714844, 48.938889844076975, 46.115336486271445, 44.91510118756975, 46.73919786725725, 46.52729518072945, 50.1670812198094, 51.30108628954206, 49.06757395608084, 51.37039109638759, 50.66134132657732, 49.74645812170846, 47.068966320582796, 43.51101269040789, 43.96562985011509, 45.37876142774309, 43.690178939274375, 42.04917771475655, 39.22252198628017, 38.87487929207938, 44.66990620749337, 48.99613952636719, 47.231001785823274, 47.474049772535054, 46.98017529078892, 48.852860723223, 51.21333054133824, 59.06093175070626, 57.437790870666504, 58.324533871241975, 57.61761719839913, 62.07778399331229, 63.06942394801548, 66.18347454071045, 67.55179718562535, 70.83362592969621, 70.342207636152, 67.52630424499512, 66.60852364131382, 71.1932646887643, 67.75494166782924, 70.05250944410051, 61.952181407383506, 73.73997402191162, 69.43615559169224, 83.31550884246826, 45.53284815379551, 0.029915628489106894, 0.07345927320420742, 0.57731594145298, 0.2830969419862543, 19.015089920588903, 79.12242385319301, 58.93166051592146, 56.16515186854771, 34.64992986406599, 39.371491364070344, 53.948051180158345, 2.059772627694266, 0.24379801217998776, 0.12644335867038795, 0.07158000261655875, 0.08176695063178029, 0.0888272567785212, 0.02845207255865846, 0.058356997157846174, 0.07993781021130936, 0.20702499683414186, 0.3687010827873434, 0.08806093289916005, 0.2434231894356864, 0.13999913127294608, 0.34652205290538923, 0.10266585634755236, 0.3154286470796381, 0.2919045708009175, 16.167113644736155, 79.38485731397355, 45.23874480383736, 52.74521030698504, 53.9953545161656, 75.75087996891567, 74.17352076939174, 3.974086889198848, 0.2887585838990552, 0.6416757479310036, 0.6045424033488546, 16.69096439225333, 96.09305844988141, 79.74264785221645, 83.92583860669816, 75.74013110569545, 72.01282555716378, 67.75379521506173, 63.74335752214704, 62.846602167402, 69.71377086639404, 67.15670871734619, 70.34037331172398, 72.88610989706856, 70.25416701180595, 72.05662005288261, 65.65403570447648, 64.10328810555595, 58.07289443697248, 55.225692885262625, 54.05421270642962, 54.10672371728079, 56.71226692199707, 54.85958187920706, 53.4808577810015, 56.205708503723145, 55.43654291970389, 46.57754455293928, 49.871431895664756, 50.92221144267491, 50.165014130728586, 51.89203405380249, 51.84159708023071, 49.778683866773335, 54.55809954234532, 50.40559550694057, 53.061950887952534, 51.74242196764265, 58.603066308157786, 58.15351785932268, 58.32111535753523, 62.515048027038574, 65.5674055644444, 58.97816480909075, 64.697970526559, 61.444754464285715, 56.18146971293858, 51.1886887550354, 53.82798630850655, 57.014596939086914, 62.61890969957624, 62.644583293369834, 53.620308126722065, 62.084350040980745, 62.94172995431082, 57.757567814418245, 58.08152757372175, 50.60215309688023, 54.90608964647566, 51.223085812159944, 48.52635097503662, 54.93949311120169, 60.16764082227434, 60.873320715767996, 60.925355775015696, 59.0730424608503, 60.28547532217843, 53.56297854014805, 49.48297200884138, 51.12266002382551, 49.92845923560006, 45.348130294254844, 54.65674311774117, 56.67675467899868, 57.13689565658569, 56.59421007973807, 58.80366774967739, 52.97561604636056, 45.98874378204346, 47.29111760003226, 48.53018638065883, 57.36667953218733, 58.64036423819405, 58.51330253056118, 55.00576850346157, 56.09796626227242, 56.11062240600586, 57.73109517778669, 55.2745943069458, 57.1132926259722, 56.238309451511924, 50.361213888440815, 46.12978526524135, 47.54266323362078, 49.57131140572684, 50.763955797467915, 51.574025426592144, 54.453952993665425, 52.29301806858608, 54.0513778414045, 53.068270274571006, 52.513025828770225, 51.01562302453177, 46.78560141154698, 46.45587464741298, 49.684115409851074, 46.615742274693076, 45.527918406895225, 42.349159240722656, 42.687157835279194, 48.5952319417681, 51.30108281544277, 50.612749099731445, 49.1494584764753, 50.03796631949288, 52.157611574445454, 54.919218267713276, 62.93745681217739, 60.73832416534424, 62.70352486201695, 62.85885878971645, 64.20935235704694, 64.7357895714896, 68.96132264818463, 70.30005986349923, 72.33710493360246, 73.42499828338623, 69.35480608258928, 67.89057745252336, 74.1330405644008, 68.99565369742257, 73.47685963766915, 63.556402342660085, 77.83931391579765, 73.18727261679513, 86.91867092677525, 47.53982489449637, 0.18346132125173295, 0.1626185303820031, 0.8165277625833238, 0.5389590625252042, 21.795892749513897, 86.77431515284947, 63.32593754359654, 69.31499290466309, 46.80701575960432, 43.774842739105225, 64.83801146915981, 2.526177623442241, 0.2722864406449454, 0.28098447248339653, 0.14305460160332067, 0.14056627798293317, 0.18041441403329372, 0.11444620814706598, 0.1432010701724461, 0.18579709662922791], [0.08597216462450367, 0.013486854648882789, 0.14212916126208647, 0.04755665009309139, 0.06159979743616922, 0.1021937791790281, 0.07168669546289103, 0.08997559587338141, 0.28302957702960285, 15.591860124043055, 54.02856690543038, 19.75810248511178, 46.21601240975516, 39.229709897722515, 67.36934443882534, 60.86284283229283, 1.2431736460753848, 0.09378986512976033, 0.15549186351043837, 0.3032820017210075, 11.9056453534535, 91.97743892669678, 72.22842121124268, 79.2284186226981, 71.75783361707414, 67.66636603219169, 61.198920249938965, 57.689687388283865, 57.573023659842356, 59.21567508152553, 57.75434385027204, 61.23229244777134, 61.23388358524868, 63.02724838256836, 60.54246834346226, 59.42826911381313, 57.623717716761995, 53.99130719048636, 52.68253060749599, 51.451504366738455, 47.32988854816982, 49.477969305855886, 49.22045169557844, 51.627682890210835, 51.09972054617745, 48.819908891405376, 42.1810302053179, 43.9044440133231, 43.83554915019444, 44.989467757088796, 45.80638831002371, 48.07695191247122, 47.6701592036656, 52.94417197363717, 50.13703373500279, 46.42476756232125, 50.08434901918684, 51.9399071420942, 50.64103174209595, 51.53282955714634, 54.554212025233674, 56.09755631855556, 54.56479760578701, 55.484047753470286, 53.50580528804234, 53.07116767338344, 46.45718090874808, 46.971319811684744, 52.52740165165493, 58.86119883401053, 57.17845630645752, 56.89808259691511, 52.13284124646868, 51.4543114389692, 53.26839576448713, 53.0595919745309, 50.612172399248394, 50.53825051443917, 47.99989639009748, 50.91606228692191, 53.79480171203613, 52.222268036433626, 54.615053926195415, 53.68892853600638, 54.835040841783794, 56.17106825964791, 51.9850287437439, 45.353518622262136, 43.39267792020525, 43.56430884769985, 43.30551624298096, 51.46906246457781, 53.620895249503, 51.190224306924, 53.23648616245815, 52.00329555783953, 51.446387018476216, 46.61210489273071, 44.30826984133039, 40.30339070728847, 51.2205879347665, 50.972571986062185, 52.49834081104824, 53.32440519332886, 53.78704057421003, 49.66839163643973, 43.61461727959769, 52.87980038779122, 54.34735025678362, 49.35922459193638, 47.15491901125227, 42.71695171083723, 41.24391623905727, 44.25111048562186, 45.403587341308594, 45.59708077566964, 46.00640957696097, 45.8259266444615, 48.22558430262974, 46.99137231281826, 45.97327014378139, 43.78387539727347, 41.57863875797817, 38.16838993344988, 42.97016143798828, 43.96042912346976, 39.59996550423758, 39.36241354261126, 35.72584104537964, 38.210628032684326, 44.90412303379604, 43.14821250098092, 45.282539299556184, 43.89423710959298, 46.76949201311384, 44.318542752947124, 48.2776506287711, 51.57856607437134, 54.36902516228812, 58.44421659197126, 63.96093341282436, 61.85988848549979, 64.2779449735369, 63.712556157793315, 62.82194995880127, 64.02767086029053, 63.22063064575195, 64.56727491106305, 71.41517625536237, 65.40321268354143, 67.46939155033657, 59.97224358149937, 68.18346486772809, 66.74500710623605, 76.03738893781389, 55.23299196788243, 0.33152224921754425, 0.014350810387570943, 0.09002946476851191, 0.4355191944965294, 12.35419499874115, 66.22680350712368, 54.006937163216726, 48.70029565266201, 31.083652291979107, 24.56058270590646, 46.69078629357474, 2.2147739103862216, 0.34931734576821327, 0.021423472657001445, 0.07943718028920037, 0.03786647452839783, 0.03892773722431489, 0.0737610991512026, 0.1108419658350093, 0.1145858099418027, 0.02844925663833107, 0.029225432846163, 0.07903577932821852, 0.04722002547766481, 0.08926345980060951, 0.06713507577244725, 0.025632861336427074, 0.03292952497888889, 0.3936476398791586, 22.526584420885357, 64.06236321585519, 27.226740258080618, 50.72285720280239, 41.91014426095145, 75.05286393846784, 61.30195508684431, 1.4545940841947282, 0.1503201238811016, 0.17403569631278515, 0.4362027778157166, 12.98089211327689, 93.96543666294643, 75.80121271950858, 84.30159023829869, 73.2867499760219, 71.21945244925362, 64.84582124437604, 61.726747104099815, 60.79741164616176, 61.22963128771101, 60.91776834215437, 64.48997620173863, 63.525858061654226, 66.02463177272251, 63.98284108298165, 63.60563727787563, 60.63761002676827, 56.40376343045916, 54.51540981020246, 53.03821931566511, 50.770848410470144, 52.43051597050258, 52.35972772325788, 53.344134603227886, 54.202313559395925, 52.32369089126587, 45.01375865936279, 46.95693356650216, 46.45223379135132, 46.45813281195504, 49.372005803244456, 49.239243098667686, 48.98462288720267, 56.613175187792095, 51.405979769570486, 49.23529999596732, 50.74906928198678, 54.571158681597026, 53.55436972209385, 54.34089885439192, 55.515526567186626, 58.270494256700786, 57.44804988588606, 58.23410654067993, 57.430641174316406, 55.87822948183332, 50.76877784729004, 48.42554650987898, 53.97674376623971, 60.91701793670654, 59.209838594709126, 59.19150229862758, 55.85525873729161, 54.113011837005615, 55.30186946051461, 55.404237270355225, 55.26367521286011, 52.462998798915315, 49.637388774326865, 53.792849268232075, 53.00865820475987, 52.95257234573364, 56.976319313049316, 57.4753771509443, 57.46164403642927, 58.843126569475444, 54.24118873051235, 45.63800566537039, 46.97459936141968, 47.71359934125628, 42.99715518951416, 50.09774514607021, 54.78509371621268, 53.84446396146502, 55.849641118730815, 55.20966339111328, 54.14063440050398, 46.85377713612148, 44.89273493630545, 45.11241960525513, 54.632264614105225, 55.58307695388794, 54.20065988813128, 55.02004705156599, 53.27053233555385, 50.83453907285418, 50.24722521645682, 54.35254750932966, 56.80576535633632, 53.053529671260286, 47.80243900844029, 44.20977565220424, 43.85361794063023, 45.821980067661826, 47.98926912035261, 47.571543421064106, 48.82245888028826, 48.758313110896516, 49.39217642375401, 49.98240157536098, 47.04188224247524, 45.26606512069702, 43.394206523895264, 40.93221657616751, 45.49890620367867, 45.04919794627598, 42.428101199013845, 41.32547072001866, 38.770652839115684, 40.574498994009836, 48.44275024959019, 44.92002051217215, 48.175724029541016, 46.14192376817976, 49.07032891682216, 48.14432512010847, 50.26911899021694, 54.11652067729405, 55.75848075321743, 61.07628454480852, 66.6869340624128, 63.69997297014509, 66.86583627973283, 66.75647858210972, 64.77582509177071, 64.44771725790841, 64.7736155646188, 65.7448000226702, 71.76225961957658, 68.27456964765275, 68.65809631347656, 62.86410467965262, 71.17687388828823, 70.38867718832833, 79.38282149178642, 59.88925429752895, 0.4634875122989927, 0.033815840990947824, 0.41036421858838623, 0.35882557556033134, 14.545337217194692, 74.46271869114467, 60.7151380266462, 55.27256195885794, 29.679303237370082, 31.286737714494976, 58.5720773424421, 4.815228862421853, 0.45643074810504913, 0.11113712178277117, 0.078762431495956, 0.04967940279415675, 0.03669738922534244, 0.12197227430130754, 0.12337822600134782, 0.011834938245426332, 0.18570242742342608, 0.12065787054598331, 0.23150675743818283, 0.09761784079351596, 0.20815686109874929, 0.23280408925243787, 0.15716327168047428, 0.17538059343184742, 0.5176834070256778, 26.17784367288862, 78.00909314836774, 26.55844862120492, 59.42494092668806, 53.79482255663191, 81.56246444157192, 70.95751925877163, 2.271883760179792, 0.27160880129252163, 0.3718975526945931, 0.5616556789193834, 14.87144136428833, 96.79321452549526, 78.7075469153268, 87.98690087454659, 77.82991995130266, 74.51813752310616, 68.91911928994315, 64.61521748134068, 65.79777308872768, 64.92894254411969, 64.14394201551164, 68.51937552860805, 67.27699593135289, 70.25903769901821, 68.71835109165737, 64.51870005471366, 64.39096437181745, 58.64889662606375, 57.799441133226665, 56.704339027404785, 51.33302368436541, 55.91468667984009, 54.041716371263774, 57.69846296310425, 56.16410616465977, 54.15491642270769, 48.27189057213919, 49.8654008592878, 49.528013706207275, 50.98748976843697, 52.0093856539045, 51.625744342803955, 52.231186049325125, 58.20291607720511, 55.56144721167428, 51.32581145422799, 54.780125754220144, 56.53528240748814, 55.826538358415874, 57.17964097431728, 57.78389801297869, 63.61608736855643, 58.640280859810964, 58.609229360307964, 59.64309351784842, 58.36072703770229, 53.10751717431204, 50.89504051208496, 58.41009398869106, 66.22017492566789, 62.82138020651681, 60.702082361493794, 56.225698471069336, 58.860406739371165, 60.40840285164969, 57.04223687308175, 59.39154788425991, 55.89923388617379, 53.955451011657715, 53.079220635550364, 52.71148722512381, 55.22858680997576, 57.28942946025303, 59.99563816615513, 59.073174476623535, 62.185203143528526, 56.09434277670724, 45.152601037706646, 48.54679257529122, 49.24527760914394, 44.59598084858486, 53.70511089052473, 55.29753378459385, 53.49647733143398, 57.75723082678658, 56.48675618852888, 54.74363381522042, 47.38749953678676, 45.25091109957014, 49.24724742344448, 58.23814344406128, 58.45638983590262, 54.751735414777485, 58.79256452832903, 56.72901208060128, 57.63082572392055, 51.14348030090332, 57.65265348979405, 59.1315393447876, 55.966016496930806, 50.4601423399789, 46.15453822272164, 45.0510253225054, 47.309853417532786, 51.82137434823172, 50.684718540736604, 50.795372077396934, 50.68659108025687, 52.36460188456944, 51.48310477393014, 50.20211056300572, 47.36974688938686, 46.85604919706072, 43.67337472098214, 48.91093029294695, 48.753233977726524, 45.1721636908395, 45.738980361393516, 41.9823499407087, 43.22976350784302, 50.1350222315107, 47.89329712731497, 49.613233361925396, 47.192414964948384, 51.73775625228882, 49.87061200823103, 55.49289281027657, 58.56430925641741, 59.730640820094514, 63.32955755506243, 71.37052018301827, 66.35226712908063, 69.90087195805141, 68.89449487413678, 69.64896501813615, 66.64501558031354, 66.4371463230678, 68.43442685263497, 75.0825605392456, 69.8591410773141, 72.58134801047188, 65.91469737461635, 74.18866784232003, 74.11271013532365, 81.95341873168945, 63.06244100843157, 0.8215309541140283, 0.1791477927139827, 2.067755890744073, 0.8367084796939577, 16.77175109727042, 82.19620268685478, 66.31652559552873, 66.0206435067313, 45.2783773286002, 37.70786680494036, 69.67317254202706, 5.853231540748051, 0.5729427018335888, 0.2255016818110432, 0.14542013752673352, 0.10613540267305714, 0.16588973413620675, 0.24243646381156786, 0.24515022390655108, 0.12559331714042596], [0.04944133199751377, 0.07239571027457714, 0.05155339098668524, 0.16243172969136918, 0.07839186995157174, 0.12428709651742663, 0.09154398207153593, 0.10089169761964253, 0.24530465847679547, 23.526341608592443, 50.737629073006765, 27.712362016950333, 45.27443422589983, 46.06197084699358, 69.80325671604702, 57.070842606680735, 0.7115893906780651, 0.05532834253140858, 0.34633257878678186, 0.2802024744451046, 16.83959330831255, 93.05525738852364, 72.76737907954625, 78.46335247584751, 68.4044384275164, 69.10565062931606, 60.24664184025356, 60.19974149976458, 54.95477914810181, 53.81963804789952, 53.57069451468331, 61.00846317836216, 54.963318484170095, 59.38436344691685, 60.85220514025007, 58.743211473737446, 56.2920572417123, 56.37207269668579, 50.812172821589876, 48.308914048331125, 48.58235692977905, 48.98373351778303, 49.29393931797573, 50.00008126667568, 49.67632647923061, 49.899926458086284, 42.007867200034006, 42.802612577165874, 42.364876065935405, 43.81572593961443, 44.047132219587056, 47.820813519614084, 47.33466196060181, 53.34537485667637, 47.608577319553916, 49.97212866374424, 49.92825773784092, 49.39155803407942, 49.8459597996303, 49.95490060533796, 51.418542112622944, 54.6685585294451, 52.92426885877337, 56.39513724190848, 56.17854452133179, 49.930918897901265, 50.99745001111712, 48.037816183907644, 48.25239045279366, 56.80658176967076, 56.97885193143572, 55.3313923563276, 58.110001291547505, 55.431522846221924, 52.71574994495937, 48.903235163007466, 44.859560762132915, 46.58792168753487, 40.34103604725429, 45.527921880994526, 51.843184743608745, 55.20509147644043, 55.799416065216064, 54.37871095112392, 54.14336504255022, 55.47823211124965, 52.62092440468924, 45.37580844334194, 45.48827198573521, 44.9542612348284, 39.12035914829799, 42.57773412976946, 45.30111183438982, 53.17862156459263, 52.85475908006941, 53.622229303632466, 52.69570091792515, 48.2502886227199, 47.166560717991416, 42.070223808288574, 48.74790818350655, 54.52100658416748, 52.05547652925764, 49.777200426374165, 48.12863956178938, 44.85152864456177, 49.698609352111816, 55.06605454853603, 53.86689969471523, 52.72571018763951, 47.673654147556846, 42.55259207316807, 42.81121792112078, 44.73471900394985, 44.88056516647339, 48.211090360369, 46.77207326889038, 47.964481421879356, 48.941196646009175, 46.36711835861206, 46.46096420288086, 44.55319036756243, 43.27126509802682, 40.19929279599871, 43.625703130449565, 44.42196321487427, 41.56721939359392, 39.629460607256206, 37.27439648764474, 35.02891935620989, 43.19627666473389, 44.717803614480154, 44.05390671321324, 44.69030959265572, 45.90118605749947, 47.0700432913644, 46.996857915605815, 48.71338605880737, 53.73993526186262, 60.874717303684776, 61.49911717006138, 63.69718674251011, 66.42053318023682, 62.70977824074881, 64.2248398917062, 63.13102667672293, 65.6841561453683, 65.74578666687012, 67.61202417101178, 67.98036207471574, 65.78473131997245, 62.67983150482178, 69.07270921979631, 66.50260530199323, 76.1714196886335, 57.145445414951865, 1.1220767498016357, 0.17456172380064214, 0.37900365995509283, 0.47010952553578783, 13.104972175189427, 64.85896028791154, 57.090856892721995, 45.658829416547505, 42.953520502362935, 24.285659858158656, 47.64148746218, 6.183718698365348, 0.6578121791992868, 0.09264164138585329, 0.21311673495386327, 0.04785907993625317, 0.09921573647963149, 0.07320341121937547, 0.10056321203176465, 0.040595047042838166, 0.009480600694327481, 0.023661052142935138, 0.0432059921191207, 0.059868277848831246, 0.04188965793166842, 0.05839230812021664, 0.04433209222874471, 0.04728138879207628, 0.17373898651983055, 30.890662602015905, 61.2230999810355, 27.803685665130615, 40.11600821358817, 55.302963801792686, 74.14647143227714, 61.75634643009731, 0.603203898029668, 0.0283858848602644, 0.2771511838904449, 0.13800051994621754, 20.39351177215576, 95.53597967965263, 74.52632944924491, 81.18874168395996, 73.11206531524658, 71.56657750265938, 64.80217266082764, 63.13912827627999, 56.307812282017295, 57.006707259586875, 56.39379971367972, 65.19176510402134, 58.891423497881206, 61.37930243355887, 63.66072954450335, 62.62307167053223, 58.63897459847586, 58.08104814801897, 53.73512363433838, 50.53764254706246, 49.97255597795759, 51.156629766736714, 51.960963657924104, 52.01012563705444, 51.81816775458199, 52.36522722244263, 42.704830578395296, 45.611553873334614, 46.607605934143066, 47.315853187016074, 47.40195178985596, 50.14868933813912, 50.844725131988525, 56.00119175229754, 48.7208970614842, 51.338259152003694, 51.952354839869905, 53.05891105106899, 52.81070750100272, 52.68984011241368, 53.54229722704206, 56.44934013911656, 56.44903441837856, 57.16825287682669, 56.52746915817261, 53.26113142286028, 52.20417840140206, 49.84554638181414, 47.927565642765586, 58.01574550356184, 57.5247996875218, 59.81018379756382, 62.688780784606934, 57.332008021218435, 52.734044551849365, 51.50919525963919, 47.74877112252371, 48.90092141287667, 45.41596903119768, 47.88956594467163, 53.188151018960134, 58.856751986912315, 58.15477548326765, 56.93138183866228, 55.7121571132115, 56.82305942262922, 52.06192445755005, 44.960267952510286, 47.281692368643625, 44.82604265213013, 40.22345863069807, 41.773573943546836, 45.16836302621024, 55.44531849452427, 54.03496619633266, 55.01840032849993, 54.6808568409511, 49.274154322487966, 47.97538314546858, 42.90828078133719, 48.752129214150564, 56.33481992994036, 51.78406946999686, 52.51949460165841, 53.2115421295166, 50.53664895466396, 53.24107544762747, 56.29914093017578, 54.92510339191982, 54.53416299819946, 48.972477436065674, 43.88633353369576, 45.22672094617571, 45.95914445604597, 46.86877134868077, 49.373402391161235, 49.768153871808735, 50.32582671301705, 49.301714352199006, 49.29870925630842, 47.62791763033186, 47.12291560854231, 46.088763100760325, 42.54544932501656, 45.58079767227173, 45.66130297524588, 44.1125043460301, 41.429255962371826, 38.824317250932964, 38.327618326459614, 46.8526862689427, 46.492971079690115, 47.41246094022478, 46.7769752229963, 48.731659821101594, 49.35587556021554, 49.56061117989676, 48.15660606111799, 57.28429821559361, 61.799765723092214, 64.3354343686785, 64.15576784951347, 67.0124432700021, 65.69568320683071, 64.6331785746983, 66.26652635846818, 68.14814717429024, 66.83163029806954, 69.20928995949882, 68.54644571031842, 69.37290613991874, 65.84635489327567, 71.34217153276715, 69.86677019936698, 80.00021062578473, 61.85867255074637, 1.324820407799312, 0.18942284850137575, 0.40136527003986494, 0.34978005236813, 15.25102492741176, 74.42215510777065, 62.51488821847098, 54.72903912408011, 43.14171246119908, 29.99300398145403, 59.872877393450054, 11.147440552711487, 0.8056971494640622, 0.15175169706344604, 0.12201694904693536, 0.03093175164290837, 0.08302080870739051, 0.1100096476397344, 0.05349009956366249, 0.0496052796287196, 0.12812627479434013, 0.15404107421636581, 0.24955939874053001, 0.1891353532139744, 0.1661515807999032, 0.18655929501567567, 0.21409843941884382, 0.2297180305634226, 0.3878771338079657, 38.39655140468052, 73.3294049671718, 37.795775413513184, 59.983284269060405, 62.08139705657959, 82.694381577628, 67.99078437260219, 1.384965860417911, 0.2504614160529205, 0.4690994311656271, 0.24437205280576432, 21.318740844726562, 100.16008227212089, 78.48485715048653, 86.49830491202218, 77.38967514038086, 76.77921336037772, 66.35134301866803, 68.79389190673828, 60.406255858285085, 59.528531619480674, 60.14393356868199, 71.14035415649414, 61.13277339935303, 66.09601061684745, 67.4659730366298, 64.73598412105015, 62.839438574654714, 60.23312759399414, 56.5861189024789, 52.9826545715332, 54.423870767865864, 52.94617305483137, 54.51889780589512, 55.44015598297119, 54.41032525471279, 54.40157747268677, 46.752437659672324, 47.93295397077288, 49.83868850980486, 49.529872349330354, 48.384562560490195, 53.297296796526226, 52.74733645575387, 58.19092001233782, 50.73093448366438, 54.11541938781738, 54.800845282418386, 55.2468466758728, 57.667640754154746, 56.196481295994346, 58.13643223898751, 59.593740463256836, 57.53020886012486, 63.210889271327424, 60.76985509055001, 54.95481736319405, 54.90727431433541, 53.32350887571062, 52.71589238303048, 62.77405602591378, 59.713200841631206, 61.58980505807059, 63.94972596849714, 60.097873960222515, 54.690223012651714, 55.22815254756382, 49.60091767992292, 55.59926973070417, 49.39398990358625, 51.34021506990705, 51.335267952510286, 55.60574892589024, 60.90940271105085, 58.94389629364014, 57.480751582554404, 60.306201798575266, 55.57735858644758, 47.47199657985142, 50.42165279388428, 44.6697290284293, 41.238371576581685, 41.99371024540493, 45.65417759759085, 57.32426772798811, 57.23093605041504, 57.692199162074495, 52.644913060324534, 50.39500992638724, 48.078925200871055, 44.41684934071132, 53.600505760737825, 57.99260105405535, 57.7622925894601, 55.578039509909495, 57.79496996743338, 53.29830428532192, 53.191906520298545, 57.65604421070644, 57.3756149155753, 56.21773930958339, 51.20917551858084, 47.48980481284005, 48.850932598114014, 49.43412617274693, 50.146000385284424, 53.65499005998884, 53.802691391536165, 53.52712236131941, 52.98495442526681, 51.70002405984061, 52.24144506454468, 48.23437029974801, 47.457790987832205, 45.35158702305385, 49.32644299098423, 49.12888833454677, 47.29292413166591, 45.39334569658552, 43.228690011160715, 40.992752756391255, 48.74206127439226, 49.10201965059553, 48.97524976730347, 50.22170795713152, 50.39606605257307, 53.00272444316319, 52.25543873650687, 52.261122362954275, 59.635895184108186, 64.92635086604527, 66.50784424373082, 66.87249265398297, 70.06357097625732, 67.05032484872001, 65.26375538962228, 68.77155344826835, 70.17932796478271, 68.0985300881522, 72.79840278625488, 70.30132443564278, 72.37096350533622, 68.1041372844151, 75.31750692640031, 72.59372970036098, 83.11383737836564, 63.85078362056187, 1.7004250415733881, 0.23995573978338922, 1.6570581857647215, 0.8381145128182003, 17.213901451655797, 81.89888232094901, 69.46587998526437, 63.7905079977853, 65.81675556727818, 38.784882749829976, 68.22682162693569, 12.91983916078295, 0.974518182022231, 0.28832133593303816, 0.25399647493447575, 0.14419071349714482, 0.19789110124111176, 0.1567972834621157, 0.14736086981637136, 0.1525116427136319], [0.1422659946339471, 0.0371030547789165, 0.04375343077949115, 0.09145110419818334, 0.012036558989036297, 0.13550276468907083, 0.060732412551130564, 0.21503077367586748, 0.10536177775689534, 25.414438145501272, 43.336529527391704, 46.59492894581386, 53.80511283874512, 43.28983415876116, 74.97660051073346, 53.45946775163923, 0.1089333961052554, 0.045045110397040844, 0.013482068432494998, 3.8084869980812073, 51.60638666152954, 82.51562527247837, 75.93267263684953, 76.39095497131348, 69.45620114462716, 66.46305615561349, 60.36096749986921, 60.322731563023154, 55.22239943913051, 53.354011467524934, 50.90474019731794, 53.48010042735508, 53.05343587057931, 54.98872109821865, 58.07908180781773, 58.66081278664725, 56.593855721609934, 55.148981298719136, 51.99936635153634, 49.4137783731733, 47.52115855898176, 47.93711246762957, 47.554958071027485, 48.909297466278076, 49.353568758283345, 46.95772566114153, 40.749815940856934, 41.775074754442485, 40.95792143685477, 43.59356771196638, 46.97680194037301, 46.63061489377703, 49.01555626732962, 50.05593088694981, 47.373061180114746, 49.1406238419669, 50.137836251940044, 49.68894788197109, 48.89166293825422, 47.60568339484078, 47.14568485532488, 46.675649642944336, 50.9557260785784, 50.84921714237758, 51.920559883117676, 51.722532749176025, 47.510434014456614, 46.70130934034075, 44.67382846559797, 48.903645106724326, 54.75078698566982, 55.650130544389995, 55.39000735964094, 54.92745188304356, 56.82966715948922, 50.002051080976216, 46.117549487522666, 41.46056454522269, 40.95808819362095, 44.910195759364534, 38.70932109015328, 52.02289990016392, 54.960289069584434, 54.27846929005214, 49.52662754058838, 43.887056146349224, 43.37320906775338, 41.222960472106934, 44.41068281446184, 42.137729031699045, 39.71899162020002, 35.043305601392476, 34.4465526172093, 43.66661759785244, 55.860341344560894, 51.63197340284075, 53.53917053767613, 47.35404396057129, 39.09856264931815, 44.359936646052766, 42.52146066938128, 49.070724964141846, 48.21003076008388, 50.23282854897635, 50.23038625717163, 53.661312920706614, 52.99246890204293, 53.80452224186489, 54.063360009874614, 53.72503137588501, 47.563170841761995, 43.30473804473877, 43.02967970711844, 42.25442402703421, 44.64082799639021, 44.95224973133632, 45.81890548978533, 45.10196256637573, 46.19811037608555, 46.67932523999895, 46.05440773282732, 46.7219420160566, 45.37512057168143, 41.03328854697091, 42.46601404462542, 43.5127705846514, 40.6793646812439, 39.79990686689104, 37.62629842758179, 35.19607564381191, 42.03947455542428, 45.95094905580793, 44.360621043613975, 43.899809564862935, 45.69994190761021, 45.63134234292166, 47.85522447313581, 48.46004778998238, 52.03533717564174, 61.203811781747, 64.2151541028704, 63.85782214573452, 63.64094107491629, 63.83394118717739, 66.61683368682861, 66.19794763837541, 67.20417881011963, 67.63523115430559, 66.2702853339059, 66.68858773367745, 64.454637663705, 63.172799246651785, 67.60493006025041, 68.1928379876273, 72.85131331852504, 62.84109224591936, 1.5630210489034653, 0.05162985170526164, 0.7808113619685173, 0.5517820715904236, 11.547284194401332, 63.2598671231951, 58.677266120910645, 44.63884081159319, 38.58936391557966, 25.016276836395264, 44.22632278714861, 12.908055015972682, 0.7775098819817815, 0.06228652237249272, 0.12168708603296961, 0.09497751175825085, 0.03375082715813603, 0.0837234588606017, 0.15707492642104626, 0.04943971708416939, 0.09629034131233181, 0.05672264378517866, 0.023463723981486898, 0.12216101560209479, 0.06302100938877889, 0.03539548069238663, 0.07103494900677886, 0.13726061822048255, 0.0565573051571846, 33.490046228681294, 53.491756030491416, 45.549263272966655, 40.583267620631624, 51.0954578263419, 81.06222888401577, 59.83967890058245, 0.044812484843922515, 0.09120524381952626, 0.15599647643310682, 4.393025483403887, 57.803728171757285, 84.06857545035226, 79.86615208217076, 78.41297803606305, 72.42409637996128, 67.86060987200055, 62.05800942012242, 61.867072922842844, 59.55642168862479, 54.56824391228812, 55.726741382053916, 56.49812691552298, 56.205767563411165, 57.346251828329905, 60.348321778433665, 60.32883208138602, 58.43112618582589, 57.03239822387695, 54.52235800879342, 52.260959080287385, 50.32238735471453, 49.39405591147286, 49.74962650026594, 50.912452697753906, 52.22101388658796, 49.95790570122855, 43.11532667704991, 45.17159046445574, 43.51956244877407, 45.97374609538487, 49.27707256589617, 49.00639854158674, 52.166050161634175, 52.16655738013131, 47.97329521179199, 50.26578732899257, 51.54742772238595, 53.57423114776611, 53.02988495145525, 51.69674103600638, 50.7192302431379, 48.50288690839495, 52.540999276297434, 54.56596490315029, 53.77679198128836, 52.06883096694946, 51.399924414498464, 48.87678337097168, 46.43360219682966, 50.83296530587332, 54.42604207992554, 58.304828780038015, 57.46412454332624, 58.347310066223145, 58.362950461251394, 54.16558885574341, 47.75018160683768, 45.62697540010725, 44.36023194449288, 45.213237966809956, 42.18569939477103, 56.10249648775373, 57.875204290662495, 55.70194673538208, 48.9361800466265, 44.650472096034456, 44.499824728284565, 39.80694191796439, 46.50495324816023, 41.81802156993321, 40.719528743198936, 35.251431941986084, 35.385789258139475, 43.64610998971121, 59.11619077410017, 54.893791334969656, 57.37415926797049, 48.877259322575156, 40.05890096936907, 46.19928462164742, 44.46711955751692, 53.16319308962141, 54.016060147966655, 53.21146222523281, 53.719914027622764, 54.31765365600586, 55.671610900333945, 55.33268472126552, 55.55932453700474, 56.957632132938926, 47.71552051816668, 44.93410103661673, 46.04424251828875, 45.10140323638916, 48.76297535215105, 47.21424967902047, 49.74099683761597, 48.386348247528076, 50.358392919812886, 49.47320631572178, 49.31877565383911, 48.840916769845144, 47.71578802381243, 43.855559962136404, 44.07750974382673, 44.95075586863926, 43.74152960096087, 43.176714011601035, 41.84403909955706, 38.455593722207205, 43.81555223464966, 46.446623120989116, 45.64659363882882, 46.33453478131975, 48.07314429964338, 47.845243385859895, 49.98588262285505, 50.70777266366141, 53.44260447365897, 62.20453303200858, 65.11330604553223, 66.6894840512957, 67.18381364004952, 65.40309456416539, 68.7702888761248, 67.26296057019914, 70.3863912309919, 68.96780531747001, 68.18602180480957, 69.78041798727853, 66.84301144736153, 65.46621200016567, 69.38210555485317, 72.44657380240304, 75.69802502223423, 67.61772864205497, 1.982374472277505, 0.041968422276633124, 0.4395802808659417, 0.37962031258004053, 10.93253971849169, 69.72035081045968, 64.58597251347133, 54.52895532335554, 41.855562686920166, 31.63344587598528, 55.73927593231201, 19.5097564969744, 0.5464568744812692, 0.024500925825642686, 0.06346774327435664, 0.1317492446729115, 0.031394780546958954, 0.10630564032388584, 0.08282551275832312, 0.03665165596508554, 0.16639303070093903, 0.16892332849758013, 0.07084112547870193, 0.1864379458129406, 0.1867017602281911, 0.1888315730861255, 0.15452060848474503, 0.30830921339137213, 0.2958117111452988, 44.4576769556318, 59.34286880493164, 60.01835182734898, 71.15589727674211, 58.117685999189106, 88.44944245474679, 67.09149987357003, 0.33520384452172686, 0.29117978683539797, 0.37877778921808514, 5.150997953755515, 61.27264758518764, 88.8188920702253, 85.38063158307756, 84.21978214808873, 78.9441956111363, 71.67099503108433, 66.37200001307896, 64.38963031768799, 63.05818176269531, 60.55744171142578, 57.83473450796944, 59.750116620744976, 60.540251868111746, 61.360528400966096, 65.38129806518555, 65.15972696031842, 63.61123057774135, 60.78399467468262, 57.03947149004255, 56.53708893912179, 52.63700948442732, 52.85127108437674, 52.50958299636841, 54.23451845986502, 54.65245260511126, 52.71761553628104, 46.52376549584525, 47.52075556346348, 44.33949504579817, 49.25717987333025, 53.069256918770925, 50.48892525264195, 54.37412166595459, 54.34717655181885, 51.657257897513254, 51.34334870747158, 54.373155866350444, 54.9899856703622, 54.97593641281128, 54.88962241581508, 54.62985011509487, 51.56428752626692, 55.32429129736764, 56.61186892645699, 57.605350153786794, 55.862384114946636, 53.18676137924194, 50.570566586085725, 51.05350112915039, 55.49386555807931, 58.34129292624337, 59.474578857421875, 59.18160111563546, 62.39842251368931, 60.97598729814802, 55.76044361931937, 50.02312496730259, 48.3853303364345, 45.71964005061558, 47.98784473964146, 46.404826232365195, 53.20802634102957, 59.26716818128313, 59.14797878265381, 50.47705772944859, 46.375793184552876, 43.53571353639875, 40.849915163857595, 47.74390043531145, 42.85591568265642, 40.23385313579014, 35.976243700299946, 34.78532593590872, 44.171171460832866, 59.61217403411865, 56.39932700565883, 58.14314419882638, 49.51090029307774, 43.76160989488874, 45.2227326801845, 45.812058040073936, 57.490743092128206, 55.839805943625315, 54.96135909216744, 54.3102434022086, 57.31337295259748, 55.061239446912495, 57.5779846736363, 57.68795381273542, 59.062661852155415, 50.4867330959865, 46.66309772218977, 48.51249279294695, 48.15526853288923, 51.06993014471871, 51.70345994404384, 51.82959406716483, 50.42768383026123, 53.571333748953684, 54.36422048296247, 52.381732668195454, 50.63811697278704, 49.01515327181135, 47.827160699026926, 48.33770738329206, 47.75064713614327, 46.92201886858259, 46.38280391693115, 42.68702581950596, 42.24115644182478, 47.904643535614014, 49.76401621954781, 49.00685364859444, 48.04042870657784, 50.35667324066162, 50.02758223669869, 51.04575388772147, 53.76974998201643, 58.224573612213135, 66.13257203783307, 68.84715679713658, 70.54293414524624, 69.16473811013358, 69.02815737043107, 72.58664948599679, 68.25010504041398, 73.5337723323277, 72.19233921595982, 71.96391023908342, 71.76785986764091, 70.47143023354667, 69.22149794442313, 73.31664112636021, 74.15360028403146, 79.42152990613664, 72.02990422930036, 2.255445625100817, 0.09792207553982735, 1.9619185413633073, 0.9494320367063794, 15.812248298100062, 77.3817333493914, 72.79073197501046, 60.72595637185233, 57.04587772914341, 42.67161818913051, 63.29141194479806, 24.222465991973877, 0.8081423182572637, 0.26162559698734966, 0.30962082158241955, 0.2678892080272947, 0.1594341519687857, 0.1387857613818986, 0.26703531241842676, 0.2458982951939106], [0.00908825223866318, 0.028414393509072915, 0.03203877474048308, 0.07009182604295866, 0.05357456360278385, 0.07061134637998683, 0.1573388629726001, 0.04991547191249473, 0.11475300097039767, 24.487195832388743, 39.018255370003835, 24.23064923286438, 41.2584171295166, 48.943819590977256, 74.15863772800991, 53.36301633289882, 0.14039279014936515, 0.08939827792346478, 0.04477854112961462, 0.3032967123602118, 50.376340116773335, 82.20675700051444, 72.42788314819336, 76.32835865020752, 69.21159676143101, 66.2741346359253, 61.05193110874721, 58.950302532741, 57.98068836757115, 53.45732075827462, 51.43457508087158, 51.344630650111604, 50.822195598057334, 55.10459620612008, 54.565113748822895, 54.44982923780169, 54.48452854156494, 52.714481898716514, 50.715898581913535, 47.881662368774414, 47.39733471189226, 48.247943605695454, 48.29466676712036, 47.04141671316964, 48.86961283002581, 47.61969791139875, 40.09850917543684, 41.80814470563616, 42.430863107953755, 43.82346970694405, 44.195566586085725, 43.88871676581246, 47.088991028921946, 48.94630009787423, 46.1575711114066, 48.44764525549752, 48.76446226664952, 51.87913472311837, 48.722255434308735, 47.11493560246059, 46.076697553907124, 45.16141830171858, 44.979934828622, 48.10965708323887, 47.1628086907523, 47.01059797831944, 45.219967297145296, 43.22284310204642, 42.94905628476824, 42.82269287109375, 46.23576613834926, 52.69153547286987, 55.865420477730886, 54.93928813934326, 52.42719125747681, 54.60568080629621, 46.66280242374965, 41.691501821790425, 43.05706950596401, 45.89290380477905, 43.61717421667916, 41.836781706128804, 48.95491239002773, 50.62942130225045, 41.89187049865723, 37.085468019757954, 40.14029564176287, 41.00219883237566, 43.672419343675884, 40.31675556727818, 39.949373040880474, 39.442383834293906, 37.834261485508506, 34.324368544987266, 46.77265691757202, 54.265754086630686, 44.034826959882466, 48.674969468797954, 38.58003943307059, 43.19546372549874, 43.86606911250523, 48.49958651406424, 53.86548573630196, 52.864034925188335, 53.3871613230024, 53.137971128736226, 54.682489667619976, 56.20997469765799, 53.451640605926514, 52.15205648967198, 46.23756572178432, 42.69860846655709, 43.671158245631624, 42.78648928233555, 43.18937710353306, 45.029906272888184, 45.210997172764365, 47.03642095838274, 47.06972714832851, 47.1266085760934, 48.02599729810442, 47.609939166477744, 45.00205094473702, 44.57967690059117, 41.73391015189034, 45.210559436253135, 42.65450130190168, 41.16370970862252, 38.9040721484593, 36.91051932743618, 41.289496421813965, 47.14588982718331, 46.28128726141793, 45.387252126421245, 46.01451117651803, 45.86535767146519, 45.78814581462315, 45.34508350917271, 46.400976930345806, 51.95902511051723, 58.78798566545759, 61.25334548950195, 61.53344127110073, 65.85837527683803, 64.09329659598214, 65.70952401842389, 67.14703682490757, 67.53671264648438, 67.37486130850655, 67.2427899496896, 64.43516881125313, 63.38412870679583, 65.4560467856271, 69.60355159214565, 68.93341173444475, 68.50679234095982, 3.481089400393622, 0.22712295981390135, 0.23766481557062694, 0.3674256812248911, 3.1695653966494968, 51.776238850184846, 65.6420431137085, 44.29276841027396, 38.97621182032994, 19.521358251571655, 43.24032129560198, 21.412727390016826, 0.4684747989688601, 0.031033966158117567, 0.14948619077248232, 0.03633980805586491, 0.07006436573075396, 0.03392265936625855, 0.15249063526945456, 0.018640383246487806, 0.004929440711358828, 0.02324523400914456, 0.031406475098005364, 0.06629084928759507, 0.037148397881537676, 0.06658057695520775, 0.12365438975393772, 0.09527456760406494, 0.1458366358918803, 36.77865988867623, 48.71472358703613, 28.84311532974243, 40.80837188448225, 56.813783577510286, 79.50093391963414, 58.22692905153547, 0.15240921106721672, 0.1298405120947531, 0.15274201892316341, 0.3467906170657703, 53.29029996054513, 86.76404571533203, 77.71667126246861, 77.92483234405518, 72.61028725760323, 70.14058480943952, 65.17652075631278, 63.28453322819301, 62.00208336966378, 57.052131107875276, 54.42794588633946, 55.86165107999529, 54.19709893635341, 57.80417285646711, 55.563941614968435, 57.52771445683071, 58.03078835351126, 55.48839732578823, 53.00603525979178, 51.13898829051426, 48.90449626105172, 50.08963312421526, 50.014234747205464, 50.11375379562378, 51.079744475228445, 50.76667949131557, 43.5768711907523, 43.67643887656075, 45.75103548594883, 47.360832350594656, 46.91832937513079, 46.169223240443635, 50.49847207750593, 52.957401343754356, 46.3517142023359, 48.96648461478097, 51.528938565935405, 54.299539702279226, 52.29410546166556, 48.870783601488384, 48.34395728792463, 47.921468598502024, 46.512377398354666, 49.82940224238804, 48.465839113507954, 47.94942120143345, 47.701919419424875, 45.44153492791312, 45.03830317088536, 45.875557626996724, 50.0356490952628, 55.15576621464321, 55.229014124189106, 57.5938960484096, 55.5333000591823, 58.51788139343262, 50.307497365134104, 42.54904849188668, 42.22250747680664, 47.24666649954659, 43.991529260362896, 45.53387648718697, 52.14646666390555, 54.26841524669102, 41.51880087171282, 37.18706457955496, 38.19524472100394, 41.181226117270334, 43.64949723652431, 41.38424553189959, 41.465859072549, 39.77848557063511, 39.340589250837056, 35.62259428841727, 46.351540497371126, 57.88097129549299, 47.441712856292725, 51.62956237792969, 39.24989441462925, 42.40894154139927, 44.06458262034825, 47.94442197254726, 56.08793306350708, 53.38096700395857, 57.23046357291085, 54.42844615663801, 57.687894753047395, 57.14162390572684, 56.17118985312325, 53.697679792131694, 49.144626004355295, 43.211708613804404, 46.323910985674175, 44.432576588221956, 44.602039677756174, 47.38437284742083, 46.568741185324534, 47.91088996614729, 48.29020602362496, 48.50799036026001, 51.27545091084072, 48.70815059116909, 46.095374311719624, 46.82800626754761, 45.272155216761995, 47.008409295763286, 45.085012435913086, 44.29146909713745, 42.223334312438965, 38.81332172666277, 43.04870387486049, 49.98966939108712, 48.562558037894114, 46.85416276114327, 48.68744148526873, 47.98011834280831, 48.502796581813264, 47.85357775006975, 47.71952962875366, 53.36443376541138, 59.905936922345845, 63.317780358450754, 64.49403394971574, 67.92941093444824, 65.9951297215053, 67.40230669294084, 68.73265743255615, 71.55823966435024, 69.2590251650129, 69.00540896824428, 68.23950208936418, 67.87791783469063, 68.363847051348, 72.36441135406494, 71.49436487470354, 75.43560545785087, 4.316826326506479, 0.14486665651202202, 0.20548879355192184, 0.2708985379764012, 2.7813782266208102, 57.04633631025042, 72.13865743364606, 54.24164036342076, 44.3418504851205, 27.901964460100444, 56.41261543546404, 25.819969756262644, 0.38395077735185623, 0.04214727392952357, 0.023822292419416562, 0.05970493411379201, 0.08998628279992513, 0.00930231052916497, 0.08626099662589175, 0.06477505633873598, 0.09426584387464182, 0.16477829377566064, 0.1184028001236064, 0.1643808486738375, 0.14485322151865276, 0.27315662109426087, 0.23100757279566356, 0.13082052022218704, 0.23929139971733093, 47.716642652239116, 56.01341710771833, 33.72646563393729, 59.85919639042446, 64.63467938559396, 87.29044818878174, 64.28774888174874, 0.47261049704892294, 0.2851863684398787, 0.23572295691285813, 1.61691529410226, 60.44952229091099, 88.25199549538749, 81.55168083735875, 84.71306255885533, 79.42586558205741, 74.94891888754708, 71.01247256142753, 67.10872445787702, 66.55004760197231, 61.212038448878694, 57.743487289973665, 58.43143885476248, 58.845947538103374, 61.109024456569124, 59.875177247183665, 60.50819982801165, 60.36732510157994, 58.627391951424734, 55.249188218797954, 53.16144214357649, 52.19929381779262, 53.72500358309065, 54.848023550851, 51.075568607875276, 54.55626521791731, 52.6576178414481, 46.181639671325684, 46.65539564405169, 49.27145494733538, 50.94444915226528, 50.027036803109304, 49.77375411987305, 52.4810745375497, 55.47737053462437, 48.6633312361581, 49.87816817419869, 53.81915862219674, 56.599567140851704, 52.81593949454171, 52.227319376809255, 51.470542430877686, 49.483844007764546, 49.193982533046174, 51.92180013656616, 51.54616315024239, 50.7539712360927, 51.381410939352854, 48.51175628389631, 48.1456800188337, 48.00958565303257, 52.419273785182405, 57.0250609261649, 59.83353669302804, 60.730465752737864, 58.0189208303179, 60.84246376582554, 52.70322929109846, 45.80846929550171, 45.09773111343384, 45.32831055777413, 45.7586715562003, 46.409679549080984, 50.00007084437779, 55.772960799080984, 43.69711324146816, 37.60054840360369, 38.12405695234026, 45.72942311423165, 45.429587500435964, 41.64197506223406, 40.92572348458426, 36.76924160548619, 38.55076667240688, 34.90569652829851, 49.73097406114851, 59.363616125924246, 48.67203385489327, 49.609863485608784, 40.05730983189174, 43.67733519417899, 44.849715164729524, 51.93017271586827, 55.73003830228533, 56.40048040662493, 59.33883884974888, 56.02708421434675, 59.43193081447056, 61.42922524043492, 57.44980778012957, 57.199127197265625, 51.199496677943635, 46.59315368107387, 48.54721641540527, 47.51207031522478, 48.276518072400776, 49.486380100250244, 49.149725982121055, 50.81493820462908, 52.12335695539202, 49.78043828691755, 54.46321841648647, 50.89092370441982, 48.756030627659385, 50.665513719831196, 47.567784445626394, 50.165337221963064, 47.574190684727256, 46.49805021286011, 44.976474625723704, 42.52573381151472, 46.94123411178589, 52.77439621516636, 50.978248664310996, 50.59571211678641, 52.313310282570974, 50.41019868850708, 50.834031854357036, 50.233888149261475, 50.85651969909668, 56.621321950639995, 65.29370212554932, 66.55868421282086, 68.01285185132707, 71.66960539136613, 67.72295910971505, 70.36477538517543, 72.30329499925885, 72.44861657278878, 72.97679778507778, 71.40680367606026, 71.12849358149937, 70.51751068660191, 71.37178475516183, 76.49578939165387, 73.9787905556815, 78.26837907518659, 4.697645800454276, 0.29271978991372244, 0.6595534629055432, 0.8159464480621474, 6.331036141940525, 66.73169435773576, 77.1940347126552, 60.612068448747905, 57.54987921033587, 33.764503547123496, 64.53325653076172, 33.180910451071604, 0.5321568846702576, 0.13047578372061253, 0.17488900838153704, 0.09147158917039633, 0.18618966984961713, 0.1123346071690321, 0.12367482722869941, 0.15439100829618319], [0.06221350521913596, 0.13209050707519054, 0.014042167708144655, 0.025269346378211464, 0.1102059885327305, 0.009991258515843322, 0.08025024166064602, 0.10810560373855488, 0.15291830232100828, 32.83519588197981, 37.67083290645054, 37.567238739558626, 39.287275723048616, 50.01221282141549, 72.35755348205566, 49.91448988233294, 0.18354628740676812, 0.11499362305871078, 0.20074811364923204, 0.7741058617830276, 23.18409071649824, 87.83611801692417, 68.56655379704067, 74.15680340358189, 64.5577141898019, 66.61344991411481, 64.0064719063895, 65.42824009486607, 62.08560071672712, 58.70068849836077, 51.02698680332729, 51.52461331231253, 49.45157657350813, 49.9745466368539, 50.904990332467214, 50.46770198004586, 50.00638675689697, 50.47413601194109, 49.289235387529644, 50.86683429990496, 45.96433128629412, 49.672095026288716, 48.7204350062779, 46.300523349217, 49.36057254246303, 46.580987385341096, 41.914285387311665, 40.87469938823155, 42.03713648659842, 41.421039717538015, 44.65822628566197, 44.02801077706473, 47.213509695870535, 47.66030318396432, 45.6053352355957, 45.50535065787179, 46.24474321092878, 48.665280205862864, 50.06601619720459, 45.632502692086355, 47.36867339270455, 48.04836007526943, 46.99577399662563, 47.2775616645813, 45.240968227386475, 45.934829235076904, 46.76715047018868, 46.57918432780674, 44.71401684624808, 43.194963455200195, 46.78329113551548, 46.81106308528355, 49.496086733681814, 50.896329402923584, 53.05607966014317, 54.940834113529746, 50.50652156557356, 44.06510026114327, 43.47902665819441, 40.0498092515128, 42.46345363344465, 41.611441203526084, 44.375003814697266, 44.69273451396397, 34.99505731037685, 40.22138111931937, 42.28368983949934, 35.84948076520647, 40.30929667609078, 42.8243465423584, 41.82966675077166, 43.556047439575195, 36.46990973608834, 34.191557203020366, 39.28143228803362, 52.563956124441965, 45.10802139554705, 42.49879217147827, 44.61425461087908, 40.44230604171753, 43.90366928918021, 45.643856048583984, 51.46331977844238, 53.11575773784092, 53.5959130014692, 53.360167571476524, 52.63151345934187, 51.701128823416575, 54.30165195465088, 50.4498416355678, 42.64075081689017, 41.551433086395264, 42.70998266765049, 41.43370280947004, 41.69863414764404, 44.0556263923645, 46.44645983832223, 47.68488938467843, 45.915537561689106, 44.889094080243794, 45.62006194250924, 45.9728011403765, 47.05230801446097, 44.558828830718994, 46.000746795109336, 44.05503926958357, 41.384877817971365, 40.014220578329905, 39.6416130065918, 36.43155567986624, 36.81738567352295, 44.991395882197786, 46.0465076310294, 44.653831550053184, 45.18400689533779, 47.00958701542446, 46.2696316582816, 47.65781225476946, 45.80369240897042, 44.60020535332816, 49.602522713797434, 56.569603034428184, 58.750173568725586, 63.33853462764195, 64.074953351702, 69.85750825064522, 66.15967001233781, 66.80563013894218, 66.02689688546317, 67.35551752362932, 63.3757700238909, 64.8982731955392, 62.438548360552105, 72.66806152888707, 66.38756397792271, 72.76653139931815, 8.1546334198543, 0.2546597293445042, 0.30382974232946125, 0.51658646017313, 0.8174096409763608, 44.64763723100935, 67.52396965026855, 47.297006198338096, 39.30539662497384, 21.98184391430446, 40.01521069662911, 23.679226296288626, 0.3494772900428091, 0.062020339870027134, 0.1347279455512762, 0.040294564595179896, 0.03469277286369886, 0.014084409905730613, 0.07100842507289988, 0.022258099567677294, 0.030429720545985868, 0.04023238703874605, 0.03678765473887324, 0.0480425591979708, 0.10192151700279542, 0.05629188600661499, 0.022881099887724434, 0.04658011945762804, 0.17573085320847376, 46.46788808277675, 44.8711017199925, 40.80914660862514, 47.372484479631694, 56.33533409663609, 79.44595282418388, 56.75776025227138, 0.5954342920865331, 0.10656194335647992, 0.34189327699797495, 1.0489294805697031, 24.442282676696777, 92.50366074698312, 72.84091186523438, 79.00893197740827, 68.8771174294608, 70.00022424970354, 68.0037566593715, 68.83290604182652, 64.72638171059745, 62.31490516662598, 53.87634924479893, 56.130598476954866, 52.02915675299508, 53.813763345990864, 52.656756264822825, 52.94654825755528, 52.34004347664969, 52.89598969050816, 50.46725729533604, 52.26510715484619, 49.26988465445382, 52.241552761622835, 50.02678666796003, 50.61643164498465, 51.31657729830061, 49.84248570033482, 44.22616992677961, 44.58540221623012, 44.255025795527864, 44.769588538578574, 48.0962679045541, 47.920096329280305, 50.72857904434204, 51.64732544762747, 46.52632243292672, 46.97817073549543, 47.3940794808524, 50.49098539352417, 52.043664591653005, 48.692541463034495, 47.373471123831614, 50.75472164154053, 51.01503242765154, 50.439916133880615, 48.57182693481445, 48.52566310337612, 48.51063414982387, 49.048129422324045, 46.970187255314414, 46.27397428240095, 47.81036690303257, 46.79204933983939, 52.444092750549316, 55.455209255218506, 55.331736292157856, 56.012037890298025, 51.76108830315726, 46.97779900687081, 45.88948876517159, 39.446431159973145, 43.59256369726998, 48.447881494249614, 45.45958634785244, 44.6054026058742, 36.52739565713065, 41.69492728369576, 42.74505022593907, 38.88238334655762, 41.04732738222395, 41.87788030079433, 43.95715652193342, 43.740886892591206, 37.12668820789882, 34.83833026885986, 39.00708614076887, 53.42717947278704, 49.08222770690918, 46.395230770111084, 46.393128940037315, 41.33033445903233, 46.2809294291905, 47.707182679857524, 53.26379953111921, 53.940991810389924, 57.500751972198486, 55.09401062556675, 53.23812246322632, 52.602192061288015, 55.546602385384695, 52.522298199789866, 45.46387686048235, 43.1948835509164, 45.54378114427839, 43.64833688735962, 43.67382982798985, 47.49332407542637, 48.362258843013215, 48.72056702205113, 48.873656681605745, 46.04559394291469, 46.75804485593523, 47.81357002258301, 47.62770223617554, 47.97664771761213, 47.30585820334298, 46.15901286261422, 45.50853640692574, 43.10620716639927, 42.307980741773335, 38.404322964804514, 40.31411177771432, 46.829065867832725, 48.15062018803188, 47.47487660816738, 47.74926444462368, 48.34875501905169, 48.09844616481236, 49.355712277548655, 47.64104972566877, 47.32887411117554, 51.46761376517159, 58.2949275970459, 60.08192784445626, 65.29240976061139, 67.21408694131034, 71.03966086251395, 66.99487127576555, 69.53643894195557, 68.51657540457589, 71.82080514090401, 67.66348252977643, 69.216675894601, 65.88318034580776, 76.15447998046875, 67.49470383780343, 77.1591408593314, 12.54365587234497, 0.2626410653548581, 0.09702579184834446, 1.2650660084826606, 1.135861107281276, 49.34078059877668, 75.40503338405064, 54.792576926095144, 44.705088411058696, 26.856411695480347, 49.06869956425258, 32.20453221457345, 0.2721635443823678, 0.05115460577820029, 0.08062951559466974, 0.04262622126511165, 0.06696784403175116, 0.032361743838659356, 0.07301499561539718, 0.02283955318853259, 0.17428325302898884, 0.22856886365583964, 0.11172986961901188, 0.20388609383787426, 0.21945001796952315, 0.114674820165549, 0.18102903105318546, 0.18570696003735065, 0.5199903175234795, 55.86814764567784, 54.90552684238979, 48.175046580178396, 56.60354151044573, 62.02968161446707, 86.87439700535366, 62.8200044631958, 0.9256002583674022, 0.16310768627694675, 0.8904308655432293, 0.9491631197077888, 27.091085365840367, 98.07642868586949, 77.58374527522496, 85.70895481109619, 74.68039880480084, 72.39650508335659, 72.61817346300397, 73.57767799922398, 67.217422076634, 66.58226639883858, 58.50117097582136, 59.5927677154541, 55.6294527053833, 56.655656473977224, 57.50036287307739, 56.55092280251639, 55.3912684576852, 54.18821219035557, 55.61419446127755, 56.76367316927229, 51.07685055051531, 55.983789988926475, 52.80867167881557, 52.31835814884731, 55.776966435568674, 51.308145659310476, 46.69961050578526, 47.29495995385306, 46.973567553928916, 46.419900349208284, 50.82695163999285, 50.65452861785889, 54.12798867906843, 52.855012689317974, 48.98812825339181, 48.01857662200928, 49.19607741492135, 52.16396917615618, 52.923410756247385, 48.353597913469585, 50.09085948126656, 52.799121379852295, 53.279023034232004, 52.801358699798584, 50.36802659715925, 49.57089451381138, 51.58585473469326, 51.299029622759136, 50.2665307862418, 49.48924275806972, 50.73454407283238, 49.350129399980815, 53.22745697838919, 57.85248368127005, 58.34688622610909, 59.14453247615269, 54.48201329367501, 47.657909529549734, 45.77299179349627, 42.447438035692485, 45.304276738848, 47.37221697398594, 47.247972760881694, 46.80243689673287, 36.81080225535801, 42.226318563733784, 44.010171277182444, 41.04189041682652, 42.023799419403076, 43.11345066343035, 47.49934468950544, 47.67283078602382, 37.033426012311665, 34.13714933395386, 38.985258374895366, 54.49950885772705, 52.323214939662385, 43.82542215074812, 43.40590034212385, 40.97323874064854, 48.826544421059744, 48.9354122706822, 54.493192945207866, 57.032516343253, 59.72508226122175, 57.620990548815044, 55.16298886707851, 56.096083300454275, 58.00157117843628, 53.29366288866316, 47.57134887150356, 47.11522395270211, 47.752623898642405, 46.93125649860927, 47.29176378250122, 49.11241068158831, 50.77751868111746, 51.38758441380092, 51.83084126881191, 47.27127701895577, 48.99964836665562, 49.67169550486973, 50.92094687053135, 48.936075823647634, 51.14631516592843, 49.13360268729073, 48.42523731504168, 45.906206130981445, 46.49377359662737, 40.95970712389265, 43.50202866962978, 49.14407362256731, 50.80213267462594, 49.09357411520821, 52.03296436582293, 52.093406745365684, 51.77646814073835, 52.958704130990164, 50.60896233149937, 49.36635691779, 54.26327357973371, 61.942578996930806, 63.67463983808245, 69.10490022386823, 70.57297815595354, 73.47993074144635, 70.3776295525687, 72.35255772726876, 70.35979352678571, 73.70653234209333, 70.1595811843872, 70.98560387747628, 69.17791884286063, 80.49393572126115, 69.73859677995954, 82.21122469220842, 13.77865127154759, 0.4462053339396204, 0.7766575877155576, 2.669285761458533, 2.6386003451687947, 55.45984022957938, 83.05983597891671, 62.58632959638323, 58.429847717285156, 37.213881152016775, 63.449358395167756, 39.36879546301705, 0.30567090639046257, 0.1520454077316182, 0.2049105731504304, 0.12497225403785706, 0.19712268747389317, 0.10016241496694939, 0.11592990638954298, 0.16507353793297494], [0.18246585609657423, 0.061379531398415565, 0.03348099074459501, 0.06535080008740936, 0.057724826437022, 0.0520152799519045, 0.20508532305913313, 0.10519436281174421, 0.406303023653371, 38.786303656441824, 42.308852740696494, 28.9588497366224, 32.82035452978951, 55.76639127731323, 68.4132001059396, 56.87143625531878, 0.7254438272544316, 0.415182251483202, 0.4541450078998293, 0.45852530428341454, 15.199655158179146, 84.5298524584089, 66.79617364065987, 70.11801706041608, 63.824324880327495, 65.10126481737409, 64.77358777182442, 69.45183767591203, 64.07245200020927, 64.7006664276123, 54.00410924639021, 50.66849797112601, 51.236276967184885, 50.723204612731934, 46.51924221856253, 47.68620259421212, 49.29341125488281, 49.15020540782383, 46.37181881495884, 49.46857534136091, 46.98015097209385, 47.635494640895296, 45.567450182778494, 46.65694856643677, 47.86433008738926, 47.406391688755576, 41.657090868268696, 40.76970863342285, 42.89916474478585, 42.05974245071411, 42.69692700249808, 46.03181913920811, 48.337064674922395, 47.89802190235683, 45.50694874354771, 45.54618869509016, 43.70726455960955, 52.50437879562378, 52.10344689232962, 46.69453832081386, 46.10199247087751, 54.00122921807425, 54.84508098874773, 55.5520532471793, 52.288553850991384, 47.14583076749529, 50.355231489454, 48.62887511934553, 45.79424285888672, 45.64174379621233, 44.25263214111328, 45.098960944584434, 43.13593850816999, 50.84778233936855, 49.415428570338655, 51.439643791743684, 50.52000107084002, 46.5699189049857, 43.50940418243408, 40.34982899257115, 42.7000641141619, 40.327771936144146, 39.567993368421284, 41.28510168620518, 36.884526116507395, 42.2166953086853, 38.45215436390468, 39.58623586382185, 38.9205949647086, 42.12664665494646, 34.29284109388079, 34.12210300990513, 35.532510893685476, 37.55522877829415, 40.35014166150774, 40.94440024239676, 41.79385226113455, 37.40744754246303, 47.04524169649397, 40.76502207347325, 42.827181407383506, 49.49134806224278, 49.521075929914204, 52.44136210850307, 50.8329062461853, 51.15477807181222, 51.06717865807669, 49.839195728302, 49.452566691807334, 47.48339509963989, 42.9140408379691, 41.77448068346296, 40.62627002171108, 43.14195564814976, 41.61722557885306, 41.631219250815256, 43.280207429613384, 45.63549041748047, 43.97536775044033, 44.66225276674543, 45.98675659724644, 45.70556647436959, 46.643715722220286, 47.14546251296997, 43.56422199521746, 44.30915226255144, 41.97183384214129, 39.458111081804546, 38.66014174052647, 36.06060177939278, 37.719584941864014, 45.93667050770351, 44.75700535093035, 44.792347363063264, 45.11780445916312, 45.88592781339373, 45.01353631700788, 46.471035616738455, 45.803192138671875, 47.28368650163923, 48.80137457166399, 57.58707639149257, 61.65242917197091, 64.4645527430943, 64.21427168164934, 67.8162317276001, 64.90289374760219, 67.2920526776995, 64.18430410112653, 68.2105142048427, 66.74923161097935, 69.13607679094586, 64.66521671840123, 74.2544116973877, 68.13643945966447, 70.83259064810616, 32.36734587805611, 0.1363430760268654, 0.18984666147402354, 0.6108615728361266, 0.09357911215296813, 44.43321929659162, 65.70310388292584, 48.94892304284232, 35.41311999729702, 28.121445894241333, 32.65445934023176, 28.705504519598826, 0.18660292481737478, 0.04436383070424199, 0.20293630766017096, 0.08511771261692047, 0.13106925758932317, 0.04616121229316507, 0.055232197511941195, 0.033363549903567345, 0.16343953061316693, 0.046379391835736375, 0.12634224338190897, 0.05010782641225627, 0.04497367423027754, 0.0894951116559761, 0.11823795682617597, 0.04432059106017862, 0.2853822750704629, 48.02265868868147, 49.95886107853481, 33.68052067075457, 46.472220284598215, 61.770110811506, 75.37227262769426, 62.82593822479248, 1.1157961211034229, 0.5122992045113018, 0.3037233751799379, 0.7622956069452422, 16.47233063834054, 90.14679704393659, 71.58749852861676, 76.3417408806937, 67.79014124189104, 70.1619713647025, 66.89989634922573, 72.7899329321725, 68.80385562351772, 67.62663623264858, 57.25000538144793, 53.63159894943237, 55.08499533789498, 53.82440798623221, 49.01184245518276, 49.85111883708409, 52.754427092415945, 52.75074107306344, 49.33545133045742, 51.840457575661794, 48.62727008547102, 50.49840954371861, 48.295073236737935, 49.012446948460166, 49.93717575073242, 49.903195585523335, 44.13081284931728, 44.373322350638254, 45.5025748525347, 45.585459913526265, 44.42598622185843, 48.798727308000835, 51.689938749585835, 50.00592817578997, 46.24830763680594, 46.6117296900068, 46.013986587524414, 52.37090737479073, 52.98227936880929, 47.31156267438616, 47.30598327091762, 56.413331099918906, 59.56837259020124, 59.18335900987898, 54.13159826823643, 49.11858763013567, 52.92187173025948, 51.40809897014073, 49.69130332129342, 48.17300728389195, 46.97036790847778, 47.13131945473807, 45.43203674043928, 51.72611454554966, 51.56384631565639, 53.22248901639666, 53.05562802723476, 48.80848952702114, 45.115994453430176, 41.71930503845215, 41.93847554070609, 43.17786741256714, 38.50166722706386, 41.48923976080758, 37.8992931502206, 43.774832316807334, 40.000046253204346, 40.3136636189052, 40.4586968421936, 42.67580100468227, 37.89355393818447, 37.19732706887381, 33.7504369190761, 39.193523679460796, 40.3896039554051, 40.43867908205305, 42.50072029658726, 41.110274587358745, 47.934631960732595, 40.70076513290405, 45.7773448399135, 49.57844720567976, 51.29565627234322, 52.946596894945415, 52.532974106924875, 53.08527251652309, 50.022287709372385, 53.08567551204136, 51.86798981257847, 48.51334047317505, 43.59351907457624, 44.2898953301566, 42.71265772410801, 45.138829708099365, 44.45497063228062, 44.51433604104178, 44.237596239362446, 47.657548223223, 46.260550362723215, 46.27434253692627, 47.19411379950387, 46.14700984954834, 49.12506682532174, 49.017821380070274, 45.787576062338694, 46.764214856284006, 44.37682771682739, 42.53065313611712, 41.67594133104597, 39.32544217790876, 41.195417812892366, 47.44450603212629, 46.88066666466849, 46.542546476636616, 49.42844949449812, 48.0846574647086, 46.94367292949131, 48.8769188608442, 47.311552252088276, 48.16438456944057, 50.10695845740182, 60.54009900774275, 63.852666582380024, 67.18335505894252, 64.90610381535122, 69.79301507132394, 67.64093562534877, 69.27800069536481, 66.37255586896623, 69.48457758767265, 68.44748946598598, 71.62342071533203, 65.36108575548444, 77.24016380310059, 71.21895912715367, 72.94708033970424, 42.72352123260498, 0.13067102538687841, 0.13842848555317946, 0.9601339995861053, 0.22292607144585677, 50.00844342367989, 73.95129653385708, 58.01405361720494, 44.7999313218253, 32.90614741189139, 42.33558246067592, 35.187974044254844, 0.08836856032056467, 0.03626633628404566, 0.11589702458253928, 0.03393928347421544, 0.11175053779567991, 0.11309785728475877, 0.019011302718094418, 0.10620936299008982, 0.2863067111798695, 0.1155953479132482, 0.1632565161479371, 0.19843299287770474, 0.19272806043071405, 0.12104649469256401, 0.18997156620025635, 0.22954191001398222, 0.758225753903389, 60.312691416059224, 58.55728462764195, 36.51593460355486, 48.52377666745867, 67.05224255153111, 81.10056209564209, 70.53882081168038, 1.7398482518536704, 0.74098189920187, 0.581875099667481, 1.1946878135204315, 18.281657184873307, 94.8923819405692, 77.89228003365653, 81.67708192552838, 71.39646475655692, 76.85555321829659, 71.76812389918736, 75.15516226632255, 71.64315359933036, 72.71051502227783, 62.453889983040945, 56.2396365574428, 58.50703525543213, 57.38002354758126, 50.959245341164724, 52.1408942086356, 54.82307256971087, 56.815951415470664, 50.8183080809457, 55.03881066186087, 51.37111370904105, 53.269736766815186, 49.910293170383994, 51.68129171643938, 52.40093054090227, 53.27352006094796, 48.09530210494995, 47.86485120228359, 48.394432476588655, 47.29217372621809, 46.897272859300884, 52.226888588496614, 54.456996304648264, 52.72500147138323, 47.84571933746338, 47.63264240537371, 47.64413125174386, 55.10678836277553, 55.42312247412545, 50.460281303950715, 49.27244506563459, 56.67926297869001, 59.648158754621235, 59.79819120679583, 54.7966833114624, 53.072018827710835, 57.15808071408953, 53.25101484571184, 51.018551690237864, 51.66735363006592, 49.49811560767037, 49.654592514038086, 48.433724539620535, 55.77936008998326, 55.27218675613403, 58.57449531555176, 56.46712405341012, 50.82261596407209, 48.23951196670532, 41.068265778677805, 44.58384929384504, 42.88420179912022, 40.884173257010325, 40.926491260528564, 36.48069681440081, 44.10814087731497, 41.047230107443674, 39.29210819516863, 40.409604345049175, 44.40284872055054, 37.92053379331316, 40.254676886967246, 34.8332302910941, 38.136751311165945, 41.07913623537336, 41.551408767700195, 45.368714332580566, 42.21484013966152, 45.28585706438337, 41.50007200241089, 49.531432219914024, 52.34542833055769, 55.23202269417899, 56.27312340055193, 55.03947768892561, 55.81603615624564, 53.13553231103079, 54.97609969547817, 54.03584514345442, 51.84848969323294, 47.574756962912424, 47.55943618501936, 44.72864975248064, 47.64908879143851, 46.46082871300833, 45.160146781376426, 46.25953592572893, 51.10565083367484, 48.973304271698, 48.70046935762678, 49.83111844744001, 48.99095964431763, 52.22876460211617, 51.19671392440796, 47.69996002742222, 49.0012012890407, 46.80770363126482, 44.985708781651084, 45.358114855630056, 41.42210626602173, 44.66631746292114, 49.78217533656529, 49.756946427481516, 50.036590576171875, 53.049371174403596, 50.279096603393555, 50.42107261930193, 50.97445494788033, 51.148722716740195, 52.3119831766401, 54.58211251667568, 63.2620974949428, 66.01769747052873, 70.2018540246146, 69.27961267743791, 71.79067080361503, 69.26965590885708, 70.40020424979073, 69.8715922491891, 71.04782499585832, 72.36172934940883, 73.75101470947266, 67.95381995609829, 79.70468289511544, 75.34990637642997, 76.76911067962646, 42.425217696598594, 0.264490833239896, 0.40676274469920565, 2.237970254250935, 1.139630287885666, 55.32060875211443, 81.33655071258545, 64.65077836172921, 54.95519951411656, 45.66338743482317, 53.584497111184255, 45.00713702610561, 0.2031181821865695, 0.2811679754938398, 0.20520386312689098, 0.18193600167121204, 0.17026348944221223, 0.13713321648538113, 0.18241003980594023, 0.08698820974677801], [0.0829329587785261, 0.017302831269002387, 0.06317807667489563, 0.05887960482920919, 0.13094241225293704, 0.12264794590217726, 0.08379078310515199, 0.04979963580678616, 0.291411601539169, 38.49890879222325, 51.73333024978638, 36.54970284870693, 34.03643519537789, 56.07837234224592, 70.59127971104213, 57.25052997044155, 1.8143554138285773, 0.4953549365912165, 0.3224449705864702, 0.359498953712838, 11.766156792640686, 79.68735408782959, 67.77381992340088, 68.69110720498222, 63.43758119855608, 66.09737941196987, 69.86097540174211, 70.58358110700334, 66.9775424684797, 65.24644742693219, 55.42813907350813, 50.3752874646868, 49.55821405138288, 48.85214158466884, 48.718385287693565, 48.64715930393764, 47.351021494184224, 47.19380113056728, 46.82821123940604, 46.761383465358186, 47.02149275371006, 46.253355503082275, 45.418327944619314, 46.19276026317051, 47.28343984058925, 45.56738417489188, 43.19272266115461, 40.88417673110962, 40.674792766571045, 43.443396295819966, 43.88061169215611, 45.20195409229824, 46.19854463849749, 50.33330644880022, 45.75381823948452, 43.535029138837544, 45.87868431636265, 55.31807613372803, 47.92783662251064, 44.69179998125349, 53.81084510258266, 60.331472396850586, 59.01767226627895, 55.03398513793945, 56.7130902835301, 54.237224783216206, 48.640714849744526, 48.973915713174, 50.78670072555542, 47.35285929271153, 45.627461774008616, 44.02277530942644, 42.73201887948172, 43.27785893848964, 46.884366580418174, 48.27663619177682, 50.26705884933472, 46.819300174713135, 42.97127662386213, 38.3380823135376, 39.37278025490897, 38.56747709001814, 36.73559495380947, 39.91781084878104, 39.34387922286987, 43.38852637154715, 40.55348416737148, 41.63965436390468, 43.01970556804112, 37.21523257664272, 38.66432455607823, 37.57431547982352, 32.48594120570591, 37.91426999228341, 40.865840435028076, 37.2701997756958, 41.82290962764195, 30.500879083360942, 41.96470499038696, 41.8517689704895, 46.01374340057373, 49.595755168369834, 47.37400266102382, 48.32397426877703, 46.50316061292376, 49.005217347826274, 47.94079153878348, 46.27540213721139, 46.01717928477696, 44.45587737219674, 43.026573862348286, 43.941356318337576, 46.09804936817714, 46.343935694013325, 43.25346381323678, 42.79269749777657, 42.731980664389475, 39.45682566506522, 39.02523830958775, 44.048400265829905, 45.82187931878226, 44.542973041534424, 47.155773639678955, 45.51849317550659, 46.19795404161726, 43.9335743359157, 44.260275159563335, 41.02525642939976, 38.31969390596662, 37.348426069532124, 37.563038553510395, 43.844185761043, 44.320335388183594, 45.23883513041905, 44.00253520693098, 45.04026256288801, 47.587850843157085, 46.35597344807216, 47.37360661370413, 46.37551525660923, 46.39600202015468, 53.782916818346294, 62.80546883174351, 62.85424518585205, 63.82950823647635, 66.72423894064767, 65.83692618778774, 63.24635982513428, 67.87978690011161, 67.79329572405133, 70.66698033469063, 69.02070890154157, 70.82969324929374, 68.96987588065011, 72.6477449962071, 66.27687917436872, 64.75445938110352, 2.6111471440110887, 0.47371319787842886, 0.41142300463148523, 0.30516746054802624, 45.685413224356516, 64.79654461996896, 51.5195689201355, 35.22564370291573, 30.213199343000138, 38.38271059308733, 27.808664049421036, 0.27936266522322384, 0.15420852308826788, 0.06262357107230596, 0.08943643194756337, 0.12067784661693232, 0.02897612890228629, 0.030942241794296672, 0.12981338426470757, 0.13907070537762983, 0.03269575948693922, 0.11261957152081387, 0.0380883860135717, 0.05834027805498668, 0.05507472989016345, 0.06192875799856015, 0.08972028350191456, 0.7851262475763048, 52.192178862435476, 53.751413685934885, 40.88174486160278, 41.914945466177805, 62.045238631112234, 75.51514843532017, 63.22199249267578, 2.3225072494574954, 0.43873165068881853, 0.23892602218048914, 0.6124948337674141, 12.471956542560033, 85.95419148036412, 73.40312535422188, 74.18248394557408, 69.33954089028495, 71.60297216687883, 75.44743824005127, 73.62967136928013, 70.04648535592216, 68.68541663033622, 57.804794720241, 53.50932802472796, 53.69203438077654, 51.79399497168404, 52.089241300310405, 51.812501498631065, 50.842942919049946, 50.26563794272286, 49.45615543637957, 48.60012347357613, 49.62411424091884, 48.71632514681135, 48.09665700367519, 50.07536847250802, 48.926428249904085, 48.75238977159773, 46.016293389456614, 44.30230828693935, 43.84715959003994, 45.65186037336077, 45.84193181991577, 46.25123282841274, 48.72455876214163, 52.736608437129426, 48.724673407418386, 45.21669122150966, 45.79144968305315, 58.37014184679304, 49.51389149257115, 46.20751476287842, 56.141298702784944, 62.62461417061942, 58.83729008265904, 56.77478333881923, 58.90978758675711, 58.88184888022286, 51.07130241394043, 51.52565554210118, 52.866727352142334, 51.172898973737446, 49.45185450145176, 46.26580320085798, 44.58914729527065, 47.10272414343697, 49.72712475912911, 50.12002107075283, 53.466304779052734, 49.10567440305437, 45.06532818930489, 38.18811239515032, 40.6323219026838, 41.68827090944563, 37.87671497889927, 39.24279335566929, 40.230684757232666, 45.341150828770225, 40.031559807913645, 40.04479265213013, 41.5412574495588, 37.082723481314524, 38.58769634791783, 38.286012513296946, 32.15427936826433, 38.66538763046265, 41.58151183809553, 38.555581774030415, 41.157942703792024, 33.40373223168509, 46.9622072492327, 44.50804097311837, 47.542986324855256, 51.84617941720145, 48.93886552538191, 49.21603264127459, 47.89716727393014, 50.36335045950753, 50.434058802468435, 48.61151157106672, 47.580586501530235, 45.806544644492014, 46.5375646182469, 46.16817058835711, 47.083415099552695, 49.66841942923409, 46.223127365112305, 43.8543301309858, 43.379611832754954, 40.177628312792095, 40.261083126068115, 44.09984472819737, 48.574623584747314, 45.72534104755947, 49.46752963747297, 48.24307986668178, 47.23881503513881, 45.012174470084055, 45.84225491115025, 43.36345727103097, 40.72872468403408, 39.41496276855469, 41.40218578066145, 44.76378679275513, 47.62940454483032, 45.50536455426897, 47.020113536289756, 46.04813698359898, 48.88323824746268, 48.308914048331125, 49.979281834193635, 49.21453530447823, 47.879279136657715, 55.97017846788679, 65.6082192829677, 65.04325430733817, 68.9579666682652, 67.89425999777657, 68.54619557516915, 66.71098872593471, 70.01033387865338, 69.44698783329555, 72.38952214377267, 72.65215015411377, 73.30283505575997, 70.56633567810059, 75.09479631696428, 66.56098406655448, 69.15677547454834, 4.959650209971836, 0.6264021417924336, 0.8983942068048886, 0.425379004329443, 52.4517878804888, 71.29615361349923, 59.56004864828927, 41.34917797361101, 36.87926633017403, 49.34019347599575, 37.096512181418284, 0.33554471337369507, 0.0874566092555012, 0.04006825281041009, 0.0856021051960332, 0.0748333405437214, 0.07430914510041475, 0.03745076326387269, 0.05533758078568748, 0.35852596163749695, 0.16746787088257925, 0.2031970415264368, 0.19803667414401258, 0.13426153415015765, 0.17836740958903516, 0.29006408527493477, 0.235186262854508, 0.9828615571771349, 57.78515216282436, 67.69713960375104, 47.46610798154558, 45.23892893110003, 70.4958462033953, 81.86582974025181, 70.80265086037772, 3.293342343398503, 0.7163344674876758, 0.4767674739871706, 0.6702309442417962, 14.029682738440377, 91.49978501456124, 76.27089009966168, 81.32045868464878, 73.71652385166713, 75.38388306753976, 77.03345489501953, 79.40229729243687, 72.7870146887643, 73.6530659539359, 60.250407763889854, 55.60157305853707, 56.10023832321167, 54.83317525046212, 56.05506461007254, 54.43007550920759, 52.810585907527376, 53.33987535749163, 51.649215357644216, 52.70561252321516, 52.79611280986241, 50.47517476763044, 51.22037948880877, 51.018662861415315, 51.319926330021445, 52.353571619306294, 48.46500880377633, 48.078779288700645, 46.502677713121685, 49.514086042131694, 49.69605936322893, 49.96287366322109, 52.06517621449062, 55.463672161102295, 48.748682907649446, 47.384866169520784, 46.63191768101284, 60.99654006958008, 50.41141809735979, 47.27426127025059, 57.268275669642854, 65.12907150813511, 64.44543130057198, 57.62953335898263, 61.4871106828962, 59.44357599530901, 53.358513900211875, 51.58173445292881, 55.976383209228516, 51.83977665219988, 51.84224673679897, 49.631104128701345, 47.12670585087368, 48.77376937866211, 52.37063986914498, 52.47973700932094, 55.09002930777413, 50.77037593296596, 43.28339317866734, 41.00613151277815, 40.023840359279085, 41.95238583428519, 38.469212191445486, 41.4184376171657, 39.43536615371704, 44.14877394267491, 40.28135449545724, 41.365242208753315, 42.42696516854422, 37.23771694728306, 37.88544539042881, 36.566652979169575, 33.183912072862896, 39.22984538759504, 41.80836704799107, 38.18602793557303, 42.65183319364275, 33.6347667830331, 42.11537667683193, 48.4196891784668, 50.42967101505825, 53.58261414936611, 52.683055196489605, 52.90321234294346, 51.0524172101702, 52.97659226826259, 53.53563737869263, 51.330164500645225, 49.98784548895699, 47.954097339085166, 49.15442991256714, 48.79742799486433, 49.632434708731516, 51.872092723846436, 49.53085899353027, 46.53885350908552, 47.590164593287874, 42.76620054244995, 42.61204086031233, 46.00345311846052, 50.13889585222517, 47.24303606578282, 51.07835830960955, 50.14206770488194, 49.72245556967599, 47.70146778651646, 49.682399204799104, 47.32915898731777, 44.3984956741333, 41.8179520879473, 43.75796556472778, 47.562872069222585, 50.21878623962402, 49.06921373094831, 49.34064163480486, 49.083037172045024, 53.2425936290196, 50.99550451551165, 53.56188767296927, 51.002817494528635, 51.07301861899239, 58.21866069521223, 68.67427171979631, 66.08563695635114, 71.8093684060233, 72.45379298073905, 70.54161398751395, 67.3387028830392, 71.73144435882568, 70.89672946929932, 74.650771686009, 76.02136639186314, 75.89339447021484, 73.41786248343331, 79.13881465366909, 68.63532706669399, 70.56054088047573, 4.213315537997654, 0.5916662514209747, 2.274543400321688, 0.9559276252985001, 57.0228305544172, 79.31970405578613, 67.92937619345528, 51.872846603393555, 48.82063497815813, 61.38987759181431, 47.762545926230295, 0.5353960480008806, 0.1872029804757663, 0.1656051158372845, 0.14286491035350732, 0.16543635060744627, 0.18133340829185077, 0.17988344681050095, 0.1574706616146224], [0.04094189718099577, 0.05281615483441523, 0.06024615400071655, 0.04102899732866457, 0.10210743559790508, 0.05252716676997287, 0.01197786655809198, 0.1739721582936389, 0.39099188095756937, 46.782228061131065, 44.58976221084595, 36.91532400676182, 41.91869401931763, 52.00896181379046, 69.30096449170793, 61.766553333827424, 2.550999411514827, 0.35731127538851326, 0.5083792805671692, 0.9125972475324358, 10.140044689178467, 71.32435635157994, 67.68796103341239, 67.4387013571603, 65.43959345136369, 66.82442501613072, 69.61313315800258, 70.18754768371582, 68.49467468261719, 64.88137517656598, 53.5760064125061, 50.85001271111624, 48.66359874180385, 48.87007141113281, 48.74534429822649, 46.28467450823103, 46.873391900743755, 46.26644590922764, 45.48542322431292, 44.9265900339399, 46.64536591938564, 46.94054971422468, 46.733601093292236, 49.168635504586355, 48.206765106746126, 45.66817821775164, 45.6874976839338, 39.24744864872524, 41.15501056398664, 40.14759125028338, 43.45049735477993, 46.27284172603062, 44.129770619528635, 46.40625408717564, 43.36435011454991, 46.087345668247764, 52.219078813280376, 57.367603642599924, 47.04598862784249, 49.60581268583025, 57.35771288190569, 52.38840988704136, 53.126854010990684, 55.47993441990444, 55.57094192504883, 55.99541779926845, 54.79272978646414, 50.769493511744905, 50.24698550360543, 50.851405824933735, 48.14050361088344, 44.56780590329851, 44.05282279423305, 42.020710945129395, 44.13432168960571, 47.76329285757882, 49.23943417412894, 51.1560183252607, 43.0463136945452, 45.53813573292324, 44.601577622549875, 37.98826135907854, 43.12105894088745, 38.38045590264456, 45.69590500422886, 47.11620364870344, 46.25719090870449, 45.41132416043963, 39.83088541030884, 37.56869786126273, 40.13705430712019, 40.71644721712385, 41.914337498801096, 41.338852950504844, 42.88208607264927, 42.44947733197893, 42.497406005859375, 32.45280524662563, 34.27086394173758, 47.28077868052891, 46.41307026999337, 48.81913416726248, 44.19998911448887, 43.50306395121983, 42.774906635284424, 44.5705817086356, 44.13230323791504, 43.213647161211284, 41.374149799346924, 42.729329926627024, 44.43410866601126, 48.11439228057861, 47.86768954140799, 51.95201090403965, 51.394143513270784, 48.27735185623169, 41.692057677677695, 38.68542276109968, 35.702290126255576, 41.78374263218471, 47.87939378193447, 44.932853834969656, 46.22583368846348, 46.59502969469343, 43.482875960213796, 42.358351707458496, 41.56220279421125, 39.55911357062203, 37.77533728735787, 37.61223527363369, 36.74886948721749, 43.03597477504185, 43.81744909286499, 45.50024720600673, 44.948073863983154, 43.23605162756783, 43.90143196923392, 45.704774379730225, 45.951560497283936, 47.10027142933437, 47.62226179667881, 50.851232119968955, 59.97155570983887, 62.64796706608364, 65.05526079450334, 62.561184065682546, 64.37350354875836, 59.688625063214985, 66.81363446371896, 66.44609560285295, 69.68374770028251, 71.98141969953264, 70.44243540082658, 67.6668176651001, 69.59290000370571, 67.38010025024414, 78.87112140655518, 24.26239034107753, 0.5714619212916919, 0.48636527040175026, 0.3942809301827635, 48.029874392918174, 60.91647597721645, 50.220443384987966, 41.236426080976216, 33.112342153276714, 35.66657985959734, 25.32437906946455, 0.3323989436030388, 0.037431380911065, 0.09412970939385039, 0.01104214132231261, 0.10104871740830795, 0.054308154952845404, 0.028924261685460806, 0.08076303093028919, 0.050547459428863864, 0.027970665533627783, 0.05349056775282536, 0.027941240862544094, 0.03618887133364167, 0.06593516801616975, 0.042958374334765334, 0.35640342267496244, 0.7462543334279741, 55.223934991019114, 48.27737964902605, 38.13908590589251, 45.53285162789481, 58.794197354997905, 75.37258529663086, 69.8003454208374, 2.976069573845182, 0.48461334726640154, 0.4471856270517622, 1.2412535548210144, 11.336121491023473, 77.82684189932687, 74.14915343693325, 72.08187675476074, 70.1638960157122, 72.85386330740792, 74.34396702902657, 72.84439986092704, 72.76842130933488, 69.37714454105922, 57.07890599114554, 53.50584350313459, 52.36918074744088, 53.03354317801339, 51.78770685195923, 51.260560921260286, 49.26879031317574, 51.5862021446228, 49.42287009102957, 48.589871406555176, 49.14491435459682, 47.67482491901943, 49.82238803591047, 50.901175771440776, 49.421063559395925, 48.23393603733608, 47.647653988429475, 43.32537766865322, 42.46154982703072, 42.19647257668631, 45.76165580749512, 47.06512744086129, 46.031395299094065, 48.0719770022801, 46.128756931849885, 46.55619968686785, 53.60855524880545, 59.96814414433071, 47.116130692618235, 51.57609946387154, 59.407348087855745, 55.65357337679182, 55.5419088772365, 57.77777317592076, 57.83878183364868, 59.311393465314595, 57.11854199000767, 52.750706332070486, 52.773326192583355, 53.65925277982439, 50.7480548449925, 47.1931653703962, 46.380372047424316, 44.24250166756766, 47.006057330540244, 50.605401379721506, 52.06563479559762, 52.68052952630179, 44.26424952915737, 45.817265714917866, 46.97625650678362, 37.9567825453622, 41.31167507171631, 40.43707752227783, 46.86005483354841, 47.84920733315604, 46.61743763514927, 46.64798886435372, 40.69056865147182, 39.127752031598774, 41.259268283843994, 44.01313120978219, 44.096610341753276, 43.3163971219744, 42.47685323442732, 42.61898558480399, 41.25328935895647, 33.225663798195974, 40.91168812343052, 50.68115758895874, 48.57336596080235, 49.73664379119873, 46.64420904432024, 43.45764010293143, 44.18762132099697, 45.82111849103655, 46.7400837625776, 45.00042159216744, 43.4027111189706, 44.990013190678184, 46.39326442990984, 50.2113481930324, 50.099735804966514, 56.13859585353306, 54.67707354681832, 52.0767171723502, 44.05745724269322, 40.11107151848929, 37.45520598547799, 43.47443042482649, 49.353481905800955, 46.36558975492205, 49.20228215626308, 48.74348218100411, 45.176113741738455, 44.93752997262137, 44.4119473866054, 40.89168078558785, 40.505638871874126, 39.30218308312552, 40.15719018663679, 45.86264787401472, 46.971295492989675, 46.45196281160627, 47.160970892224995, 46.18702799933297, 44.91089057922363, 47.180460589272634, 47.91799102510725, 48.9111213684082, 48.40438577107021, 51.6874269757952, 62.46822411673409, 64.26205444335938, 66.539521081107, 66.2584456035069, 67.27030481610979, 62.41150597163609, 68.0344329561506, 67.55158873966762, 73.14442307608468, 73.31836427961076, 73.83179446629116, 69.46765177590507, 71.86012499673026, 69.3594057900565, 83.19766044616699, 29.932704039982386, 0.7720693882022585, 0.759244370673384, 0.508306975875582, 52.38263940811157, 70.98424203055245, 57.296429770333425, 48.33138452257429, 35.63584450313023, 46.49706356866019, 37.25307594026838, 0.41210851499012535, 0.019989907974377275, 0.07140538162950959, 0.03461208487195628, 0.08721308982265846, 0.049760155246726105, 0.04283512184130294, 0.06586575388376202, 0.10054540048752512, 0.07727250430200781, 0.16655794185187134, 0.10209693866116659, 0.0947045371202486, 0.1908930167555809, 0.1780358095254217, 0.3569363983614104, 1.1383225066321236, 68.28719452449253, 55.79855101449149, 47.715468406677246, 54.27725682939802, 67.04454394749233, 78.69530418940953, 77.16370582580566, 4.026388585567474, 0.6411045300109046, 0.8099882592047963, 1.1860992972339903, 12.397236483437673, 84.80097116742814, 78.63762024470738, 77.2609806060791, 74.62192971365792, 76.77895627702985, 77.58697618756975, 76.66333825247628, 76.87498038155692, 71.95764991215297, 59.371703829084126, 56.03724248068673, 54.74723298209054, 57.3593943459647, 54.67369672230312, 54.57327788216727, 52.949108668736045, 54.94250862939017, 52.401799065726145, 50.23124435969761, 52.79648453848702, 52.57028245925903, 53.75054863521031, 55.2277113369533, 52.45396614074707, 51.22538219179426, 51.94349241256714, 44.65679495675223, 45.59547921589443, 44.621008259909495, 50.66085842677525, 50.64376585824149, 50.39885228020804, 51.121819291796, 45.74270806993757, 49.23291676385062, 54.844511236463276, 63.44713497161865, 49.00987958908081, 53.00836638041905, 62.7764253616333, 56.52857392174857, 57.6111866406032, 61.39625603812081, 59.48488998413086, 62.94855308532715, 58.95058046068464, 56.22191865103585, 56.36079229627337, 54.55157518386841, 53.3800185748509, 47.82467671803066, 49.53317621776036, 47.32157155445644, 47.84222091947283, 53.73823642730713, 55.760718073163716, 54.27063867024013, 46.77854551587786, 44.16325398853847, 46.29144900185721, 41.59470994131905, 42.79102645601545, 40.3625476700919, 46.89221109662737, 49.05837801524571, 47.124183654785156, 48.27412789208548, 40.732084138052805, 38.69158581324986, 41.311567374638145, 42.54026249476841, 43.1045708656311, 43.47485426494053, 44.407785415649414, 42.04020759037563, 41.55261428015572, 33.27853611537388, 36.443975584847585, 52.922055857522146, 52.92300081253052, 52.504889488220215, 48.39999450956072, 45.710638659340994, 46.935279505593435, 48.25546850476946, 48.82420635223389, 47.39957203183855, 46.06784554890224, 47.84263433728899, 48.101468631199424, 52.69161537715367, 53.544475487300325, 57.13885504858834, 57.20580441611153, 54.40584019252232, 47.18915278570992, 39.176337310246055, 37.152028288160054, 45.526528767177034, 52.506657804761616, 48.07966865812029, 51.00115687506539, 51.27812596729824, 47.785732064928325, 47.18002980095999, 47.601358141217915, 43.97429077965872, 43.806356293814524, 43.677807671683176, 43.68873718806675, 48.11143582207816, 48.36745262145996, 51.35035943984985, 49.11426585061209, 48.544440610068186, 48.10307019097464, 50.904493536267964, 51.623823165893555, 52.256018911089214, 51.7718962260655, 53.70575359889439, 67.10208892822266, 66.82700974600655, 69.68050289154053, 68.86160210200718, 69.53870405469621, 62.11292798178536, 70.19866480146135, 68.48184135981968, 75.88767610277448, 76.20852306910923, 75.0225350516183, 70.28675406319755, 72.8632503237043, 70.6169741494315, 84.79628808157784, 28.858720983777726, 0.6952792544450078, 3.0655628059591566, 0.9835940493004662, 58.81372874123709, 78.2739862714495, 65.78054155622209, 59.50394194466727, 51.66008928843907, 56.97386312484741, 53.412838390895296, 0.6180999130010605, 0.09334827453962394, 0.12756942824593612, 0.077585573574262, 0.27677185567361967, 0.20323365527604306, 0.13483587333134242, 0.18351488480610506], [0.03372158908418246, 0.09177831414022616, 0.04498714993574789, 0.025508275521653037, 0.049415836044188054, 0.048253949997680526, 0.04633882901232157, 0.09495288093707391, 0.2715725132397243, 36.91816929408482, 42.66800512586321, 27.198120628084453, 33.26073830468314, 58.596618379865376, 65.27048124585832, 70.37659427097866, 6.772271505423954, 0.622491174510547, 0.7640143632888794, 1.8859323901789529, 8.056933062417166, 64.95401164463588, 70.17612484523228, 65.5268280846732, 69.94561835697719, 69.52333463941301, 69.00344957624162, 69.15945053100586, 67.42165047781808, 59.700937271118164, 51.753806591033936, 50.17332765034267, 48.13726922443935, 45.75334576198033, 46.147725514003206, 47.21770988191877, 46.101721491132466, 45.86655970982143, 47.61681093488421, 46.262839794158936, 46.80237783704485, 46.28315980093819, 47.785989148276194, 47.48108829770769, 45.58891316822597, 45.633110659463064, 45.88837705339704, 42.19866473334176, 38.551569189344136, 40.62937239238194, 43.14694792883736, 43.38754320144653, 42.45568207332066, 46.00249774115426, 48.0035719871521, 50.67225694656372, 57.293376037052695, 54.20435632978167, 46.466592243739534, 53.00566005706787, 58.22001211983817, 53.52403041294643, 54.04847696849278, 54.57123163768223, 54.83546815599714, 55.610692569187705, 54.12110301426479, 57.90997307641165, 56.34722941262381, 52.93772751944405, 49.37958628790719, 47.78481490271432, 45.30166074207851, 43.999314716884065, 46.42392683029175, 46.821186610630576, 51.79677772521973, 46.6840569632394, 44.664424078805105, 44.25165591921125, 38.348438603537424, 41.407268387930735, 41.538974966321675, 46.365725244794575, 50.10376228604998, 48.04860326222011, 48.2814165524074, 46.40448924473354, 44.15740360532488, 41.40085867473057, 47.48966932296753, 47.58434547696795, 49.336160046713694, 45.64493301936558, 41.73103707177298, 42.95343712397984, 47.42116355895996, 39.317312785557334, 28.680133172443934, 46.81685788290841, 49.30075550079346, 47.039193289620535, 41.60330833707537, 42.30556276866368, 41.56203951154436, 43.28617940630232, 42.9182688168117, 41.061602456229075, 41.46659210750035, 46.86319194521223, 46.54815019880022, 49.00379296711513, 51.30132252829415, 51.58079644611904, 50.79817567552839, 53.45185947418213, 49.33780329568045, 43.73214258466448, 39.46745293481009, 41.92617375510079, 48.42416034426008, 47.46425976072039, 46.072744028908865, 46.526457922799246, 43.81593438557216, 41.90846279689244, 40.27398245675223, 39.076290198734824, 36.60988119670323, 36.56209148679461, 38.3610600062779, 41.59761428833008, 43.0737486566816, 43.68081276757376, 42.52112020765032, 43.690574986594065, 45.95490605490548, 44.916789599827354, 45.89754172733852, 43.383746010916575, 46.14214611053467, 47.19853285380772, 55.56140899658203, 58.955763816833496, 62.480584962027415, 62.217602593558176, 64.24755355290004, 61.7926299231393, 60.921145166669575, 65.70411137172154, 64.63494341714042, 68.8479072025844, 68.77967589242118, 68.57063933781215, 71.45309952327183, 71.66651344299316, 76.18562875475202, 59.670240129743306, 0.186261526708092, 0.16323029755481652, 0.15125899921570504, 43.31617477961949, 61.249100140162874, 50.722415992191856, 31.46614020211356, 31.738488742283412, 34.1677839415414, 21.945730652127946, 0.6126447085823331, 0.13968042337468692, 0.10464215744286776, 0.05273676284455827, 0.05956808717123099, 0.0724416131685887, 0.10161191504448652, 0.008239544878181602, 0.024225703540391157, 0.16459571357284272, 0.031185082692120756, 0.012767159696003156, 0.041076579596847296, 0.0332754658801215, 0.020413485156106095, 0.10424314492515155, 0.36949141323566437, 47.544435024261475, 50.762180532727925, 32.20117276055472, 37.09333685466221, 64.17667497907365, 71.2902615410941, 77.80505234854562, 7.179934910365513, 0.5495474657842091, 0.5862159324543816, 1.8754371362073081, 8.178461398397173, 69.91113444737026, 75.37143189566476, 73.52115440368652, 76.60411180768693, 74.23009995051792, 75.87634359087262, 72.41729409354073, 70.40711075919015, 62.35598291669573, 56.0733904838562, 52.60305363791329, 49.657722677503315, 48.68456145695278, 49.70205218451363, 49.71084860392979, 50.479566029139924, 49.26770292009626, 50.93944297518049, 49.02896629061018, 47.73081350326538, 47.02700962339129, 49.618010248456685, 49.97130182811192, 47.4780866759164, 49.073125566755024, 47.03105694907052, 43.510693073272705, 41.759083475385395, 44.1825977734157, 46.23784712382725, 45.76432738985334, 46.27034732273647, 46.88005869729178, 50.54446915217808, 53.26237167630877, 58.31836387089321, 55.381693840026855, 46.40320035389492, 55.87680857522147, 59.625014305114746, 56.76047004972185, 56.11872400556292, 55.97684179033552, 55.55062886646816, 57.80629553113665, 56.4410856791905, 59.91123839787075, 58.06340667179653, 55.63196447917393, 52.24795552662441, 50.7000219481332, 49.484580516815186, 46.75352505275181, 49.192551204136436, 49.949175289699006, 55.34592798777989, 48.770628792899, 44.91947160448347, 45.18328080858503, 38.61394664219448, 41.2742486000061, 42.961031505039756, 46.8144086429051, 50.720897810799734, 50.74261787959507, 49.519418784550254, 47.94845887592861, 44.88572767802647, 43.62523065294538, 49.490795680454795, 47.682280336107524, 49.73685918535505, 47.66684143883841, 44.30424683434622, 44.89788702556065, 47.75307205745152, 39.09679780687605, 34.145928382873535, 50.863794463021414, 50.18318714414324, 51.379618304116384, 43.43233128956386, 44.033357415880474, 44.30855471747262, 45.18787704195295, 43.76435443333217, 42.745227405003135, 44.98069218226841, 49.08440944126674, 48.54266881942749, 51.56588213784354, 52.86554268428257, 53.66651364735195, 54.320693492889404, 54.12995849336897, 52.89108773640224, 45.28696182795933, 41.77177088601248, 43.18247059413365, 50.7477491242545, 49.183522020067485, 47.34301369530814, 48.86589901787894, 47.287428106580464, 44.80817188535418, 43.310282707214355, 40.806867599487305, 39.435206345149446, 38.72059801646641, 41.255915778023855, 44.00048548834664, 45.640743255615234, 46.26877008165632, 44.462443419865195, 45.32897411073957, 48.31949962888445, 48.52093138013567, 48.40864154270717, 47.64391933168684, 48.81472553525652, 49.978406361171174, 56.42161682673863, 60.52178355625698, 64.31886291503906, 65.60940047672817, 66.7758710043771, 63.39298071180071, 62.72599533626011, 67.72654438018799, 67.34433787209647, 71.43233830588204, 70.77482332502092, 71.14167431422642, 73.35137517111642, 75.89696584429059, 76.29874542781285, 66.7441941670009, 0.6094237842730114, 0.24425311918769563, 0.3146378823689052, 47.77377768925258, 70.16954490116665, 58.538732937404085, 41.244784763881135, 37.23904752731323, 43.85414947782244, 35.76972934177944, 0.9462270715406963, 0.13038902623312815, 0.06480869810496058, 0.019824798351952007, 0.061011643282004764, 0.024917398745726262, 0.04352509356769068, 0.056918984678174765, 0.17841986034597668, 0.21257948449679784, 0.09262906813195773, 0.12666836088257177, 0.09082577989569732, 0.2651652970484325, 0.10667125534798418, 0.13426770881882735, 0.6776882612279483, 61.433338574000764, 55.677468231746126, 35.199681758880615, 44.892078331538606, 75.10019506726945, 75.97292355128697, 86.60106182098389, 8.360501595905848, 0.6538280387009893, 1.3965987733432224, 1.749710025531905, 9.880268914358956, 77.59621729169572, 80.30062294006348, 76.95751108442033, 80.5319493157523, 78.73380415780204, 77.93685967581612, 77.37213788713727, 73.80369595118931, 65.3194660459246, 59.122576168605256, 55.003194195883616, 53.20620938709804, 50.728513036455425, 52.92523118427822, 51.70595782143729, 52.01411737714495, 51.70802838461739, 54.223408290318076, 50.97690418788365, 52.29421315874372, 50.22429963520595, 53.49985763004848, 52.16315623692104, 49.72880622318813, 49.52923311505999, 52.2818557875497, 46.269801889147075, 44.278361320495605, 46.45046547480992, 47.28477389471871, 48.29117182322911, 48.73399094172886, 48.187153816223145, 51.964455127716064, 54.51456560407366, 59.97332055228097, 57.04566580908639, 48.82257699966431, 57.90980979374477, 63.234693799700054, 58.65173149108887, 58.21058341435024, 59.95974377223423, 58.961120877947124, 59.27731255122593, 59.29881722586495, 58.82776410239083, 60.08960560389927, 58.934495380946565, 54.95928852898734, 51.809166363307405, 51.73046064376831, 47.556493622916086, 50.330746037619456, 52.86541414260864, 57.53432566779, 51.638938971928184, 42.98120559964861, 46.778833866119385, 41.51570544924055, 41.54991143090384, 44.973629338400706, 49.286466530391145, 53.37710380554199, 52.01980447769165, 50.271078382219585, 48.615749972207205, 44.719724791390554, 42.946221419743125, 49.56627743584769, 47.549392563956125, 51.29256084987095, 49.287744998931885, 44.63942098617554, 44.78983211517334, 46.67855746405465, 39.78184502465384, 31.25885111945016, 49.91122422899519, 54.721945013318745, 52.78537436894008, 47.57357924325125, 47.390855516706196, 47.46331827981131, 46.44307606560843, 46.721886430467876, 44.88253150667463, 47.43966661180769, 51.632174900599885, 52.06133386066982, 54.60009445462908, 54.5927745274135, 56.754067284720286, 55.85009969983782, 58.37008626120431, 54.31498902184622, 46.983086585998535, 41.641405309949604, 43.94082825524466, 52.9005685533796, 49.34854521070208, 49.462189946855815, 51.69513947623116, 50.06306668690273, 48.36459343773978, 47.06588479450771, 45.67484501429966, 41.75528975895473, 42.58245890481131, 44.3193348475865, 47.2698769569397, 48.99086236953735, 48.641760553632466, 47.11132601329258, 48.79394694737026, 51.412059443337576, 51.217169421059744, 51.15701886585781, 51.2004520552499, 50.0953688621521, 53.234759535108296, 61.60623059953962, 64.6382577078683, 65.78250094822475, 68.15401840209961, 69.47943592071533, 63.59789003644671, 63.399671827043804, 68.71951144082206, 69.20593397957938, 72.9444886616298, 72.96074744633266, 72.74353286198208, 75.99752017429897, 76.69800976344517, 79.62919766562325, 68.06487996237618, 0.8631482752306121, 0.43156032264232635, 0.5077782071062497, 56.111355440957205, 74.88544014522007, 67.52917385101318, 49.04374163491385, 52.67732293265206, 55.00131123406546, 49.69066408702305, 1.1382027587720325, 0.24458991682955197, 0.11130353928144489, 0.11304830387234688, 0.20357559621334076, 0.08043536636978388, 0.1803713406303099, 0.1164585394518716], [0.0641700541600585, 0.046888316848448346, 0.057065955363214016, 0.10273034431572471, 0.04969578602218202, 0.03293127899191209, 0.08463964398418154, 0.041850323256637366, 0.2297111637890339, 38.109851360321045, 42.31868444170271, 31.82229791368757, 35.50128221511841, 53.2457446370806, 66.63256440843854, 62.4355536869594, 3.4432349630764554, 0.3825895275388445, 0.38172911799379755, 2.4291647034032002, 5.872694747788565, 61.93459551674979, 70.80325535365513, 64.97196578979492, 69.1904603413173, 68.30563504355294, 72.42166451045445, 68.05294990539551, 65.84353392464774, 58.41936983380999, 53.13192619596209, 50.99010576520647, 48.968457903180806, 48.165499755314414, 47.21743195397513, 47.306080545697895, 46.83784144265311, 46.56810542515346, 46.51569168908255, 46.112953254154746, 45.5108015196664, 44.4913444519043, 44.50139502116612, 47.576445375170024, 45.96069737843105, 47.594232763562886, 45.64757333483015, 40.74143293925694, 39.33577067511422, 41.38393633706229, 41.25966780526297, 42.17189679827009, 46.99615962164742, 43.901720319475444, 49.95608179909842, 56.00332484926496, 57.86056791033064, 53.58867992673601, 49.69172716140747, 54.48806864874703, 55.3929568699428, 54.16135392870222, 58.20340592520577, 56.9840978213719, 52.761027881077354, 54.061449255262104, 53.21745504651751, 74.22868946620396, 54.21932622364589, 50.35086802073887, 50.26029825210571, 49.45538418633597, 50.73871646608625, 46.31232833862305, 50.471259457724436, 48.89376824242728, 52.74576268877302, 49.76053517205374, 42.22935840061733, 35.97918973650251, 44.131997517177034, 45.8476745060512, 43.96680409567696, 46.60090787070138, 47.0710438319615, 49.15543392726353, 47.586162430899485, 49.4160921233041, 49.6235340663365, 47.304819447653635, 49.12339230946132, 49.17808158057076, 47.92453275408064, 45.17542239597866, 42.208961963653564, 45.38341672079903, 49.66627243586949, 53.968100207192556, 25.737204551696777, 41.1086938721793, 50.26883411407471, 48.2423711504255, 44.83870226996285, 40.798779896327424, 42.25604295730591, 42.08630888802664, 43.81463507243565, 44.73064041137695, 44.0572383744376, 47.15067713601248, 52.43014076777867, 53.269674233027864, 50.50514929635184, 51.413098199026926, 48.726910727364675, 53.309970310756135, 52.31845194952828, 51.60746363231114, 41.955064364842, 42.18547705241612, 45.189131191798616, 44.97742305483137, 47.561610971178325, 47.724966594151084, 42.79612295968192, 44.32005051204136, 39.800233432224815, 37.581044810158865, 36.959094183785574, 37.095886843545095, 37.65423713411604, 43.709901400974815, 41.310087408338276, 42.29587003162929, 42.59559794834682, 45.39524255480085, 42.94258056368147, 45.80880280903408, 44.545529978615896, 47.76265709740775, 44.29728821345738, 47.053478785923545, 48.40178714479719, 55.889002663748606, 58.43381513868059, 62.79689475468227, 61.52661119188581, 69.40522221156529, 63.7274044581822, 63.923413140433176, 63.218900544302805, 68.19413035256522, 66.45445428575788, 72.99727412632534, 67.07178088596889, 73.42411586216518, 67.91495868137905, 81.01176411764962, 4.609953888825007, 0.24858518530215534, 0.293980209422963, 42.47421639306204, 65.76171193804059, 42.97016143798828, 36.02587815693447, 30.240043708256312, 27.678750106266566, 30.378139155251638, 1.106057569384575, 0.438723372561591, 0.1614184733480215, 0.12848482626889432, 0.12914136318223818, 0.14613990033311502, 0.043906026519834995, 0.0066151256822714844, 0.07788093986787967, 0.10386378956692559, 0.028960342785077434, 0.07855868100055627, 0.11669324471482209, 0.024138494827119366, 0.1252482413713421, 0.09796710312366486, 0.5050477279084069, 49.8412697655814, 47.30551079341343, 28.088594811303274, 38.69383008139474, 62.63157626560756, 72.37739058903286, 65.5507368360247, 2.8409942047936574, 0.40305639643754276, 0.522625096142292, 1.355615041085652, 6.7755111030169894, 68.68808473859514, 76.2252265385219, 74.04099082946777, 73.46139294760567, 73.7677251270839, 75.0259118761335, 73.36042172568185, 68.84239033290318, 61.97333172389439, 55.37560721806118, 53.57659353528704, 51.50984491620745, 51.91689470836094, 49.87967593329293, 50.749420166015625, 50.15471690041678, 48.7886072567531, 49.10445499420166, 49.33176531110491, 48.45524311065674, 46.545485564640586, 45.860577310834614, 48.94104378564017, 46.50431053979056, 50.55210174833025, 47.82051474707467, 43.78332996368408, 43.146701267787385, 45.277738094329834, 44.221695286887034, 45.432839257376536, 47.74384484972273, 47.449661595480784, 52.37037583759853, 56.05041626521519, 60.0511542728969, 55.28214005061558, 52.55383607319423, 58.15355607441494, 57.339185510362896, 58.708692823137554, 59.42150156838553, 59.420382908412385, 53.90351322719029, 56.02269990103585, 54.233302525111604, 69.70617648533413, 55.94398723329817, 54.03962843758719, 54.85158102852957, 52.11283390862601, 52.932568481990266, 48.180122239249094, 52.17236260005406, 51.89593199321202, 54.83201837539673, 49.35154683249337, 43.120617730276926, 37.64698668888637, 43.397802216666086, 46.46528945650373, 47.04603031703404, 47.37020547049386, 48.92938470840454, 50.78473785945347, 49.37346839904785, 51.46925354003906, 50.23355116162981, 51.17018222808838, 51.916126932416645, 49.82584476470947, 51.1381892476763, 47.8387051309858, 45.3093523979187, 49.53991249629429, 48.815559319087434, 51.97994613647461, 28.19842151233128, 45.619315011160715, 54.85327986308506, 50.12129259109497, 47.31404665538243, 41.636638845716206, 43.96664081301008, 44.9500367300851, 45.36920418058123, 46.04431200027466, 46.040879590170725, 50.74356630870274, 52.99551568712507, 52.89520106996809, 53.430924551827566, 52.31303235462734, 50.70587580544608, 55.08734382901873, 53.51149933678763, 54.07802765710013, 42.02505704334804, 45.59733438491821, 46.26149879183088, 44.50639425005232, 48.79141085488455, 49.42744895390102, 45.117933000837056, 46.19431318555559, 42.10959924970354, 40.57839693341936, 39.02830246516636, 41.86569663456508, 40.46436309814453, 46.37440354483468, 43.76048081261771, 45.72235679626465, 45.630348750523154, 47.513136863708496, 44.998684542519705, 47.59033482415335, 45.803928647722515, 48.791112082345144, 47.17570454733712, 50.63759238379342, 50.667278562273296, 59.935237475803916, 60.12916169847761, 64.33184215000698, 65.73881067548479, 71.77141039712089, 64.32531779153007, 65.6428074155535, 63.11515004294259, 71.2057158606393, 68.74924278259277, 75.56527273995536, 69.75242369515556, 78.95627852848598, 69.33489254542759, 89.08894770486015, 6.299985945224762, 0.44466997204082354, 0.467322755072798, 47.29275737489973, 72.9195168358939, 51.64257982798985, 43.539608001708984, 36.56185872214181, 41.67373875209263, 42.45585925238473, 2.394344457558223, 0.3709413611463138, 0.20312783095453465, 0.014923073251598647, 0.048067356260227304, 0.10246019238340003, 0.07828482426702976, 0.0692857535822051, 0.11577062707926546, 0.22209663023906095, 0.11578399421913282, 0.16642090491950512, 0.22500272787043027, 0.09753252858562128, 0.28086211904883385, 0.31354815512895584, 0.9879827052354813, 61.14557892935616, 55.626909664699006, 41.1217599596296, 48.845572062901084, 68.5093423298427, 75.54205880846295, 73.69203839983258, 4.667660415172577, 0.40515480669481413, 0.9769315953765596, 1.7930228156702859, 8.05945438998086, 78.56239209856305, 81.32404395512172, 75.99370561327252, 78.7697263445173, 77.56542287554059, 79.08099174499512, 78.48747662135533, 71.91562025887626, 65.0300040926252, 58.208999225071494, 57.309360367911204, 53.8880569594247, 53.304859910692485, 51.57706873757498, 53.82584278924124, 51.93454660688128, 50.42978566033499, 52.06531865256173, 50.77121319089617, 51.60532706124442, 49.1327098437718, 49.51349891935076, 52.341704096112935, 48.79151507786342, 51.26863472802298, 51.159030369349885, 46.75632865088326, 44.96767473220825, 47.845639433179585, 46.65059791292463, 48.57871259961809, 51.13193586894444, 49.10641091210501, 54.28230816977364, 61.128792081560405, 62.509697914123535, 58.11634847096035, 54.89767190388271, 60.118155751909526, 59.85666029793875, 58.765515191214426, 61.43345669337681, 61.67467730385916, 58.47642149244036, 60.66078921726772, 56.49782466888428, 68.87769412994385, 59.18101051875523, 56.190436363220215, 58.80475166865757, 53.9106525012425, 56.47848088400704, 51.45421763828823, 55.24440090996878, 55.408739703042166, 57.23283290863037, 46.796746322086875, 45.292763573782786, 39.40045492989676, 43.234992027282715, 48.516800676073345, 48.31762708936419, 50.15286520549229, 51.57159355708531, 53.184131486075266, 52.80344663347517, 52.601848125457764, 51.55458436693464, 51.07746546609061, 53.407651560647146, 51.91272578920637, 52.1405155318124, 49.91406256811959, 46.66122170857021, 52.3550237928118, 50.07091467721121, 50.14516312735421, 28.945153100149973, 41.58071974345616, 55.900484561920166, 50.261646202632356, 50.48752866472517, 42.8723064831325, 46.3112861088344, 46.492988450186594, 47.15661784580776, 48.86809464863369, 48.296025139944895, 53.90813725335257, 57.36684281485421, 58.63107449667794, 54.54454013279506, 55.03399556023734, 54.87243257250105, 58.382863998413086, 56.83454132080078, 55.5621211869376, 42.70249945776803, 45.864787919180735, 48.332374640873496, 45.21464497702462, 51.81978668485369, 53.811001437050955, 47.43429912839617, 50.095330647059846, 46.23474475315639, 42.8077438218253, 41.60312073571341, 43.40860666547503, 41.67268262590681, 49.08284609658377, 46.66969156265259, 47.322912556784495, 48.01743711744036, 50.763490268162315, 47.55989824022566, 51.75458131517683, 50.009468282972065, 53.216972146715435, 49.85098334721157, 54.486244746616904, 53.26752029146467, 62.39696339198521, 62.50496619088309, 67.61601938520158, 68.67923968178886, 72.3061854498727, 64.23227446419853, 67.13756643022809, 64.59695761544364, 71.1597535269601, 70.82681669507707, 76.38999611990792, 71.81693499428886, 79.9531991141183, 73.23213713509696, 91.85789516993931, 6.196274961744036, 0.46288785019091194, 1.2375443024294717, 54.544199671064106, 80.60875470297677, 59.37196091243199, 53.431678431374685, 50.98763220650809, 49.2911114011492, 58.43177236829485, 2.458418573651995, 0.5961028933525085, 0.3617727517017296, 0.24222641651119503, 0.27326567524245804, 0.19253499007650784, 0.1339781236435686, 0.20711613765784673], [0.12542920666081564, 0.0295486903217222, 0.1763866301625967, 0.04310841878343906, 0.09310886024364404, 0.05935445042060954, 0.048291554408414025, 0.08639008791318961, 0.5107961137379918, 46.09126445225307, 34.02444955280849, 36.80924933297293, 36.131820814950125, 54.58008711678641, 72.03612981523786, 41.492213589804514, 0.0982802470347711, 0.4596543865544455, 0.7366969234177044, 0.25198318010994364, 4.007971950939723, 66.44015489305768, 66.35592882973808, 70.66302680969238, 67.91994053976876, 70.03808498382568, 70.51899760110038, 68.13778741019112, 65.11096450260708, 58.65175928388323, 50.33971963609968, 52.3784635407584, 49.31364440917969, 50.909579617636545, 45.8960165977478, 46.51251288822719, 46.96721690041678, 45.53855957303728, 47.755274636404856, 45.7258482660566, 44.09573834283011, 46.14482464109148, 46.27017709187099, 47.4368908064706, 45.3915148462568, 46.58680302756173, 47.22187532697405, 43.472453662327354, 39.21021325247628, 40.75877564293997, 42.04295907701765, 44.7725693157741, 44.57428857258388, 43.603708607809885, 49.42206062589373, 57.86654683521816, 63.16091782706124, 54.61740241731916, 49.844479833330425, 52.47895533697945, 53.78124925068447, 54.07917063576834, 55.58513709477016, 55.860556738717214, 55.76989664350237, 51.427237783159526, 53.10650968551636, 49.343396595546174, 46.62153359821865, 53.68536411012922, 50.62768772670201, 50.09991993222918, 49.87391240256173, 51.44510507583618, 48.75710759844099, 54.59313930783953, 50.7432084764753, 39.01972491400582, 40.95462104252407, 49.34729453495571, 40.56034203938076, 41.25152104241507, 44.58188642774309, 51.608849797930034, 49.960073539188926, 50.26193455287388, 53.32253960200718, 53.04461513246809, 51.551176275525776, 53.5448819569179, 51.54329007012503, 52.48128298350743, 46.50825016839163, 50.42207663399832, 43.88770580291748, 42.974160126277376, 37.28576374053955, 57.61376442228045, 36.25710725784302, 29.505820614951, 55.87849003928048, 45.75233479908535, 46.88821588243757, 43.118627071380615, 43.36435011454991, 44.99705171585083, 48.71735348020281, 47.44857767650059, 48.42103712899344, 47.4998345375061, 52.13714565549578, 52.32591084071568, 53.47235318592617, 51.62269755772182, 49.2169463293893, 53.27053233555385, 48.49257925578526, 52.50713723046439, 48.04078653880528, 44.67651047025408, 46.22619846888951, 43.70965126582554, 41.31108447483608, 42.46002122334072, 43.091365814208984, 41.091830594199045, 39.22697925567627, 40.294354575020925, 36.70993525641305, 37.442511626652305, 38.9583341053554, 41.15873827253069, 43.42821795599801, 43.07589912414551, 42.03843927383423, 43.01066248757498, 41.674892153058735, 44.58552033560616, 43.537044116428916, 44.58309888839722, 42.687251635960166, 44.99508190155029, 46.104969773973735, 48.91254922321865, 50.853761264256065, 62.38382434844971, 62.0381167275565, 64.23104463304792, 69.58401325770787, 70.6256524494716, 65.69894191196987, 68.62903894696916, 67.49329335348946, 72.2217926297869, 64.18790326799665, 72.7988474709647, 65.15407112666539, 86.20265211377824, 19.00348469189235, 0.6791164417351995, 0.7067867198160717, 45.092856952122276, 66.43835530962262, 44.884841782706125, 37.734652110508506, 34.97448022024972, 27.909195797783987, 32.678402832576204, 2.071935449327741, 0.27848575370652334, 0.13704265920179232, 0.05897656748337405, 0.09604522732219525, 0.02643861827839698, 0.05808083340525627, 0.025113510633153573, 0.11007982173136302, 0.1078732597774693, 0.09707573202571698, 0.06314957141876221, 0.002577768106545721, 0.023040949167417626, 0.0034512059480351, 0.12692604134125368, 1.4505271081413542, 58.661486761910574, 40.73498848506382, 31.704491206577845, 40.54558406557356, 61.01839215414864, 80.25392409733364, 47.24176801953997, 0.15703387505241803, 0.4711024665406772, 0.7492945502911295, 0.3358621863382203, 5.089622778551919, 75.52372946058, 69.67434678758893, 77.28554943629673, 73.08417524610246, 74.10988916669572, 74.41354628971645, 71.39633274078369, 69.34854575565883, 62.6761211667742, 52.356211934770855, 55.39708409990583, 53.32085118974958, 52.22277178083147, 49.219795090811594, 49.9958359173366, 48.95597546441214, 50.145520959581646, 50.4951160975865, 48.373810223170686, 48.23678132465908, 50.22847897665841, 50.17016969408308, 49.504963057381765, 48.243336950029644, 48.25381830760411, 48.9960491997855, 44.9897700037275, 41.725818974631174, 42.360373633248464, 44.99751724515642, 46.46750593185425, 45.63109220777239, 47.38945198059082, 51.86461646216256, 58.0318340573992, 65.80811200823102, 55.37578092302595, 51.31159891401018, 55.312541893550325, 58.35949720655169, 56.996948514665874, 58.59317207336426, 57.82284614018032, 56.89921862738473, 54.14979212624686, 52.14044257572719, 51.86444623129708, 48.67277383804321, 55.42671469279698, 52.792294774736675, 53.66636773518154, 51.79596478598458, 53.349814755576, 50.27240201405117, 55.491558756147114, 51.150008133479524, 39.285594258989605, 40.9795754977635, 48.975426946367534, 43.5682623726981, 42.99978855678013, 48.65216548102242, 53.76598058428083, 51.87621995380947, 52.39433322634016, 54.535469259534565, 53.93531860624041, 52.53885923113142, 55.93879345485142, 53.38543469565255, 55.0351037979126, 49.325741222926546, 50.97273874282837, 46.33338138035366, 46.503202302115305, 38.99584742954799, 55.891153131212505, 37.834751333509175, 32.93744904654366, 58.89006165095738, 48.68766035352434, 49.264815943581716, 46.298178332192556, 45.783108370644705, 47.211939402988975, 50.67931284223284, 49.024693148476736, 50.493417263031006, 50.32263054166521, 53.99538925715855, 53.35958044869559, 51.82011325018746, 52.864677633558, 50.87719406400408, 52.65662424904959, 51.31427049636841, 54.088033063071116, 50.46380056653704, 46.166405745915, 47.34214517048427, 43.64659636361258, 44.36319882529122, 45.042899404253276, 46.77404655729021, 42.523267201014924, 42.507637228284565, 41.58190441131592, 39.088758741106304, 41.04302297319685, 43.17786741256714, 45.45988164629255, 44.9254401070731, 45.91707311357771, 45.4214893749782, 45.345020975385395, 45.13540077209473, 48.1901068006243, 46.42503159386771, 47.735496589115684, 44.78727170399257, 48.21768420083182, 48.53152390888759, 51.268586090632844, 51.90940455027989, 62.81719739096505, 64.33722005571637, 68.26276465824672, 71.0743601662772, 72.33896010262626, 66.61741038731166, 73.36262430463518, 70.21174131120954, 75.54536615099225, 66.1516170501709, 77.34387956346784, 67.49415493011475, 90.3434032712664, 23.0103405884334, 0.6594125990356717, 0.8225469653095517, 49.38740301132202, 73.10010746547154, 52.172119413103374, 46.91334056854248, 37.74159336090088, 36.79930298668997, 44.556591510772705, 2.850781176771436, 0.16760839548494133, 0.2203749833362443, 0.03836694499477744, 0.14356669198189462, 0.022535766275333505, 0.10194850912583725, 0.03971443072493587, 0.17825796189052717, 0.13376449367829732, 0.2075365986675024, 0.09727032229836498, 0.1722060130642993, 0.1345733752740281, 0.1595578489026853, 0.15967826172709465, 1.8653409693922316, 72.09934452601841, 47.962348324911936, 46.39746809005737, 48.74419437135969, 67.58237620762416, 84.26707853589738, 52.92527287346976, 0.306240685816322, 1.1503523354019438, 1.9276825955935886, 0.7063392124005726, 6.173747164862497, 82.37092903682164, 72.72781603676933, 82.52802085876465, 76.23346710205078, 76.85740143912179, 76.89569990975517, 74.50323363712856, 71.94139112745012, 66.50764274597168, 56.13463885443551, 58.05729225703648, 56.09988743918282, 55.40405314309256, 51.643177373068674, 53.07031304495675, 52.78256382261004, 51.33307926995413, 53.603156498500276, 51.194104875837056, 50.21226535524641, 52.355398995535715, 52.729319776807515, 53.224802766527446, 49.9530280658177, 51.19512626102993, 51.45244584764753, 47.03336375100272, 43.54669516427176, 45.155130181993755, 50.07782118661063, 48.83648729324341, 48.60474402563912, 49.45901462009975, 54.4703368459429, 61.38231100354876, 65.26306751796177, 56.30616555895124, 54.273966857365195, 57.96385635648455, 57.63699919836861, 58.471161706107004, 59.82507378714425, 59.96997846875872, 58.96289266858782, 56.66264636175973, 53.28539800643921, 58.44587026323591, 53.49928787776402, 56.89149917875017, 55.743899958474294, 55.361971378326416, 55.15521035875593, 55.5387613432748, 54.40894603729248, 58.24185725620815, 50.2018187386649, 41.553722517830984, 39.765763419015066, 48.329647472926546, 46.35405574526106, 47.15809781210763, 49.97606134414673, 56.52557577405657, 53.15793330328805, 53.335998262677876, 58.27597985948835, 57.11607537950788, 55.117679664066856, 57.05508756637573, 53.36200884410313, 55.42470318930489, 50.04309409005301, 53.08629390171596, 47.43925666809082, 47.35760491234915, 43.36280414036342, 54.42425291878836, 35.852510179792134, 32.16081762313843, 56.3572348185948, 51.002525670187815, 51.200326987675254, 46.40926613126482, 47.64645195007324, 50.24073907307216, 52.264287267412456, 50.20531020845686, 53.63439212526594, 51.09735468455723, 56.16271652494158, 55.69163908277239, 55.59412806374686, 55.68660511289324, 52.06944588252476, 54.90557895387922, 54.18391472952706, 56.94914490836007, 53.32982478822981, 46.940237045288086, 49.01108510153634, 44.64585154397147, 47.14624071121216, 47.157858099256245, 49.0498560496739, 45.84312343597412, 44.285108021327424, 46.83988421303885, 42.05709866115025, 44.69544778551374, 46.31161962236677, 47.27958011627197, 49.56689582552229, 47.83154501233782, 49.47655882154192, 47.701224599565776, 47.74658243996756, 50.02892671312605, 49.040368284497944, 50.21515927995954, 48.04660218102591, 50.766269547598704, 51.877897943769185, 53.28236164365496, 56.22582006454468, 68.2146692276001, 67.09072862352643, 72.19080366407121, 72.59252766200474, 73.17727415902274, 68.7618329184396, 74.6937254496983, 71.17513683864048, 78.86685521262032, 68.37611062186105, 78.47455297197614, 68.83101613180978, 93.80673285893032, 23.509876114981516, 0.8474689594336918, 1.1941007993050983, 55.83222198486328, 84.08941309792655, 59.78027875082833, 60.9391062600272, 53.2837130682809, 45.6140204838344, 60.20709964207241, 3.7890646117074147, 0.30605517434222357, 0.31948957060064587, 0.101921028457582, 0.2791669214410441, 0.07358056812414102, 0.19603120961359569, 0.18209876865148544], [0.07908105797001294, 0.08041892546628203, 0.06299757278923478, 0.09147604036011867, 0.12740121941481317, 0.07001964348767485, 0.026962893449568322, 0.19072410224803857, 1.6014280851398195, 51.82781185422625, 36.201990672520225, 32.13380650111607, 38.15701920645577, 54.27015924453735, 72.78592382158551, 40.145756925855366, 0.20183412251727922, 0.13484489784709044, 0.3310654865843909, 0.43413612299731796, 9.032712016786848, 77.13489859444755, 62.010845048086985, 73.7033361707415, 67.15004539489746, 69.79983125414167, 66.00735855102539, 71.33433396475655, 63.96713120596749, 56.1059775352478, 49.501575810568674, 53.96950374330793, 48.10403599057879, 49.70227105276925, 46.35589354378836, 47.34756823948452, 45.637759004320415, 47.67525223323277, 45.998558112553184, 44.69537830352783, 43.46754476002285, 46.50172233581543, 44.45691960198538, 44.9323605128697, 45.08674948556082, 47.886995111192974, 47.71526343481881, 42.95962102072579, 38.727452414376394, 40.847299167088096, 42.04035350254604, 43.34850822176252, 43.51182562964303, 46.61628076008388, 47.413902691432405, 53.90716450554984, 61.46785722460066, 44.89854710442679, 49.74054173060826, 49.96142496381487, 51.03294140951974, 49.131976808820454, 55.37284183502197, 55.62082999093192, 56.854541710444856, 53.018448216574534, 50.75855357306344, 43.32357113701956, 49.668766839163645, 50.5473005431039, 52.05949258804321, 50.78243453162057, 50.12029552459717, 47.77913127626692, 52.5694625718253, 45.278915813991, 36.40843554905483, 52.126104967934744, 52.05975661958967, 36.679321493421284, 40.171764033181326, 45.8347612789699, 51.72972413471767, 49.951436928340364, 49.929272174835205, 50.58976098469326, 51.78061621529715, 53.30824368340628, 53.50762571607317, 53.65708146776472, 51.64505338668823, 51.474572386060444, 49.88833686283657, 47.92375455583845, 51.038531235286165, 44.42309577124459, 35.65227699279785, 40.37372037342617, 57.93609135491507, 29.997103418622697, 33.95362309047154, 55.017625604357036, 45.62243127822876, 48.32863998413086, 46.68762138911656, 47.066694259643555, 48.53332349232265, 50.158812863486155, 47.98351253782, 53.68234511784145, 52.040628228868755, 51.634252411978586, 47.43003640856062, 51.50609288896833, 51.2933668409075, 52.11052710669381, 51.034980705806184, 49.46446895599365, 49.61405324935913, 48.667190960475374, 46.26607765470232, 47.15261915751866, 43.810549531664165, 45.2316437448774, 41.095516613551546, 40.511298179626465, 38.09594106674194, 37.41239813395909, 36.25625262941633, 37.5773275239127, 41.883737632206504, 42.82367604119437, 42.87548875808716, 41.92642389025007, 40.82388721193586, 42.42547477994646, 41.47035455703735, 43.089858055114746, 42.27229479381016, 45.02104731968471, 44.02670104163033, 46.636621611458914, 46.982391766139436, 46.980418477739605, 48.49444137300764, 53.033240931374685, 61.10920510973249, 64.39363942827497, 63.174807276044575, 68.36330509185791, 69.30703026907784, 72.4821833201817, 66.46874673025948, 69.75329221997941, 63.571167264665874, 72.56558949606759, 64.60977704184396, 82.2445204598563, 33.931229046412874, 0.47802797492061344, 0.8714682002152715, 51.05132981709072, 59.420785903930664, 45.8422931262425, 34.09809003557478, 41.43922662734985, 28.143655811037334, 35.51143700735909, 2.1083581234727586, 0.3855967404586928, 0.11975282696740967, 0.09425849534038987, 0.15312486195138522, 0.09612360490219933, 0.05187123375279563, 0.06540361046791077, 0.06707930697926454, 0.09856235475412436, 0.11816626281610557, 0.022761268907093575, 0.01805267183642302, 0.04864656053749578, 0.06632124087108032, 0.2072780089718955, 2.7251397243567874, 63.594047682625906, 41.048473834991455, 32.82958173751831, 41.20770222800118, 59.74134104592459, 76.64903885977608, 44.473737716674805, 0.2939591205545834, 0.20004056447318622, 0.04548868570210678, 0.34084377331393106, 11.624277182987758, 83.73460333687919, 66.38263075692313, 77.40629523141044, 71.02884946550641, 74.68541540418352, 71.00085517338344, 73.78845855167934, 66.89180864606584, 57.693151065281455, 52.27771118709019, 55.4359974861145, 51.149038859776084, 51.37290287017822, 48.79340846197945, 50.590813636779785, 48.32339756829398, 50.675390584128245, 48.45113672528948, 47.88901703698294, 47.17343943459647, 48.73579747336251, 47.91065372739519, 48.04875612258911, 47.365435532161165, 50.60668332236153, 48.79815060751778, 46.75844437735421, 42.2574325970241, 42.732196058545796, 44.946128368377686, 46.57665865761893, 47.3694828578404, 46.09128877094814, 50.60629422324044, 56.44962848935808, 62.84402438572475, 46.338866983141216, 50.21487440381731, 51.81745209012713, 53.21619742257254, 53.83786317280361, 58.011472361428396, 59.97796194893973, 59.72376210348946, 52.55132777350289, 50.26800380434309, 46.67546204158238, 50.58053377696446, 52.412398542676655, 54.2601295198713, 53.7132055418832, 51.68632568631853, 50.32104982648577, 52.77679681777954, 49.00909096854073, 39.12754358564104, 50.114608424050466, 52.16298600605556, 40.79065745217459, 42.46131706237793, 47.123829296657014, 53.2789500781468, 52.768069880349294, 51.7760443006243, 51.884696756090435, 54.002441678728374, 55.610067231314524, 53.940922328404014, 53.862796783447266, 54.78113671711513, 54.681923389434814, 52.51055227007185, 50.09534106935774, 53.204743317195344, 46.38983201980591, 41.46369818278721, 42.32194314684187, 55.590466363089426, 29.104801859174454, 39.818330015454976, 55.092332635607036, 50.014269488198416, 51.64323990685599, 47.47544636045183, 51.42697722571236, 52.011199133736746, 52.682016440800254, 50.94414690562657, 54.843955380576, 54.12492104939052, 53.197861126491, 48.58564690181187, 54.501954623631065, 51.268485341753276, 52.24987670353481, 52.625103746141704, 51.9090119770595, 51.41721848079136, 49.32652984346662, 48.11262396403721, 48.81557321548462, 45.486048562186106, 46.19856200899397, 42.85929250717163, 43.402756282261436, 39.543639932359966, 41.20987006596157, 38.71178075245449, 40.87914970942906, 42.49409171513149, 44.96518380301339, 45.913008417402, 45.15821518216814, 42.27946186065674, 44.91025134495327, 45.322501863752095, 46.7681371143886, 45.67607137135097, 47.91066762379238, 46.36805289132254, 47.02640513011387, 48.82240676879883, 51.374146597726, 49.28034169333321, 55.02612672533308, 62.45570346287319, 68.9705012185233, 66.49428136008126, 70.67210115705217, 71.37583555494035, 73.72233949388776, 68.90482684544155, 73.7749582018171, 65.53385966164726, 75.49098260062081, 68.01257392338344, 83.44215365818569, 39.35826546805245, 0.20989404645349297, 0.8127938115171024, 56.75357048852103, 67.34772859300885, 54.154075690678184, 44.59666177204677, 58.040324756077354, 37.97896466936384, 45.04039110456194, 3.45661632503782, 0.22860203044755117, 0.1445272397249937, 0.11431905068457127, 0.1386720117713724, 0.04892382690949099, 0.016945370539490665, 0.04204943596518465, 0.1472331288137606, 0.2147583554365805, 0.1688110852347953, 0.11075464516345944, 0.3829231224954128, 0.10049158587519612, 0.1998689765376704, 0.3716991219137396, 4.313773027488163, 78.46514511108398, 46.85436078480312, 41.70450190135411, 50.751254490443635, 67.01128986903599, 81.85263511112758, 49.85718808855329, 0.3887356977377619, 0.39132007477538927, 0.6702803958739553, 0.5694954725248473, 13.304574813161578, 89.51046017238072, 68.56834643227714, 81.81573322841099, 73.95975249154228, 74.27064268929618, 71.95368943895612, 77.0577666418893, 68.1055964061192, 62.59888499123709, 54.017192704336985, 59.557929447719026, 51.95739575794765, 54.62525388172695, 50.430216448647634, 52.37997824805123, 49.117868491581504, 54.26917607443673, 50.95831775665283, 50.55509294782366, 50.6333817754473, 52.342193944113596, 49.36094774518694, 50.36527511051723, 49.936373233795166, 53.45752225603376, 51.12898635864258, 47.19345024653843, 44.045200620378765, 46.09679869243077, 47.2945430619376, 48.6945355960301, 48.689248016902376, 48.22987481525966, 53.71108981541225, 57.987640040261404, 64.82444163731166, 47.54545988355364, 53.44157614026751, 54.751186507088796, 55.77648006166731, 54.10831485475813, 60.24892084939139, 61.97152519226074, 60.98556191580636, 54.74477331978934, 49.95838165283203, 50.49944829940796, 53.10869141987392, 54.40800108228411, 57.40404347011021, 56.88741711207798, 55.99078682490757, 52.36460883276803, 55.08015939167568, 46.688142504010884, 40.32786921092442, 50.91257429122925, 53.72328042984009, 43.16700390407017, 43.9955210004534, 51.16108703613281, 55.579008783612935, 56.92100122996739, 55.59243617738996, 55.228864737919395, 57.4806786264692, 57.65194129943848, 56.617187772478374, 56.725141933986116, 55.64135149547032, 57.2337327003479, 53.92600802012852, 52.3539502961295, 54.90668371745518, 47.9483060155596, 43.581634180886404, 49.24605580738613, 53.64002364022391, 27.14196355002267, 37.1015739440918, 56.43641301563808, 50.40127720151629, 53.47091143471854, 51.18748671667916, 51.49392311913626, 53.87011323656355, 56.18148708343506, 53.384250027792795, 58.99814782823835, 56.77249738148281, 56.551965032305034, 51.598764487675254, 56.89534500667027, 55.258894852229524, 55.96234089987618, 53.413300446101594, 54.87611511775425, 54.287866728646414, 51.36750759397234, 49.01879412787301, 49.008715765816824, 50.82563148226057, 48.49889864240374, 45.23707028797695, 46.47416230610439, 43.0413179397583, 44.412124565669465, 42.975216252463206, 44.56342158998762, 45.76822880336216, 47.70733206612723, 47.639517647879465, 45.76565449578421, 44.13046891348702, 47.709138597760884, 45.54753317151751, 47.53960255214146, 47.61523021970476, 51.874319621494834, 48.221446650368826, 50.09005001613072, 52.37791115897042, 52.26039975030081, 52.576681750161306, 58.00794267654419, 64.73720700400216, 70.46664987291608, 69.98432677132743, 73.68744564056396, 75.47860091073173, 76.25686168670654, 70.61763422829765, 75.91167518070766, 69.91590785980225, 77.7850901739938, 72.42131015232631, 89.53973988124302, 39.43028007234846, 0.5200394434588296, 1.5884340852499008, 62.13860852377755, 72.13509995596749, 61.88130978175572, 52.92082255227225, 67.95557090214321, 54.27966785430908, 58.75110462733677, 3.9617408088275363, 0.5309630972998483, 0.34102640779955046, 0.1577622281121356, 0.38753034813063486, 0.13626021333038807, 0.15393668838909694, 0.0979425333706396], [0.08728190684424979, 0.06283808991845165, 0.04797878708424313, 0.08269165136984416, 0.11970344318875245, 0.07310893878872905, 0.027904667825038944, 0.1328777569745268, 1.1450791954994202, 45.56346539088658, 34.53697994777134, 46.7563772882734, 63.70999922071184, 49.44522591999599, 71.96288885389055, 41.593827520098, 0.18263319640287332, 0.14269214176705905, 0.07616596296429634, 0.38163358026317185, 24.2169143812997, 85.30117198399135, 63.66421059199742, 75.34625162397111, 65.4194506236485, 72.40516948699951, 64.50538730621338, 72.69153254372733, 62.36662060873849, 52.163451535361155, 50.64143473761422, 51.36005565098354, 48.91090944835118, 50.20240586144583, 45.10861546652657, 46.79669073649815, 45.11286081586565, 46.74601752417428, 46.10049165998186, 45.339000361306326, 45.924865518297466, 46.046007360730854, 47.793166637420654, 44.9139894757952, 44.0803029196603, 46.67427042552403, 45.203976018088206, 45.035746233803884, 41.13419723510742, 40.762774331229075, 40.9741975920541, 43.74484041758946, 43.19562005996704, 45.547616549900596, 46.96462174824306, 56.45290456499372, 51.17500080381121, 43.85231515339443, 46.44649805341448, 48.28359481266567, 46.654433318546836, 49.25532470430647, 50.54614019393921, 52.03528159005301, 57.99904203414917, 48.80334786006382, 46.08767918178013, 39.12130062920706, 45.0726272719247, 49.67117786407471, 51.668715476989746, 48.09074408667428, 49.156990323747905, 52.611589499882285, 43.277164118630544, 37.73221329280308, 53.574797425951274, 43.10079451969692, 31.51267228807722, 42.33034004483904, 44.00475515638079, 46.59844126020159, 47.032950333186555, 47.11003712245396, 50.58574840000698, 49.156132221221924, 51.73789174216134, 52.859799998147146, 52.7460823059082, 50.413478238242014, 53.31267316000802, 53.6916834967477, 51.9992412839617, 49.69336346217564, 49.026253019060405, 46.51816872188023, 41.190776416233604, 29.69217824935913, 41.62523685182844, 52.67668717248099, 30.282097680228098, 41.67072670800345, 47.25249603816441, 46.368243966783794, 49.822005884987966, 47.35194560459682, 51.30615847451346, 47.740523610796245, 51.49962411608015, 49.75164147785732, 47.65230928148542, 46.07469299861363, 49.15504482814244, 50.354154518672395, 50.966860566820415, 52.26101119177682, 51.139040402003694, 49.71999938147408, 48.10128450393677, 49.99655505589077, 49.94009746823992, 53.32315451758248, 44.88533510480608, 43.29722704206194, 41.93755490439278, 41.86472736086164, 37.542259965624126, 35.318773882729666, 34.56427594593593, 39.38054486683437, 42.50057438441685, 43.03651326043265, 43.353354590279714, 42.94008616038731, 43.45214407784598, 44.95866639273507, 44.08658061708723, 45.339111532483784, 43.48843799318586, 43.779421601976665, 45.96343844277518, 44.52438313620431, 45.57278987339565, 47.71395369938442, 47.39896406446184, 49.88565138408116, 49.44875907897949, 59.34477955954415, 61.725051743643625, 68.40290982382638, 67.379287311009, 70.92675263541085, 66.31351702553886, 67.01785591670445, 60.7814724785941, 68.29554625919887, 68.10142748696464, 79.15372548784528, 47.18611989702497, 0.08611232960330588, 0.6775720960327557, 55.67323677880423, 59.895903723580496, 41.418587003435405, 41.05185413360596, 19.111605610166276, 31.993588379451207, 27.70679129873003, 2.0080037713050842, 0.3872335026306765, 0.21232700161635876, 0.14288089663854667, 0.12092705895858151, 0.04458930449826377, 0.011742425932815033, 0.07719958214355366, 0.0871915870479175, 0.01998546696268022, 0.0986551647739751, 0.04245142725163272, 0.07741537663553442, 0.053763840946235826, 0.07412177444036518, 0.058031938171812465, 2.182359044040952, 59.63550608498709, 38.88990477153233, 49.86384446280343, 73.10297012329102, 55.545487199510845, 78.68848105839321, 43.065101623535156, 0.16300055916820252, 0.21649436014039175, 0.14611338318458625, 0.6063698338610786, 27.126665353775024, 91.1365053994315, 66.99439879826137, 79.06382969447544, 69.17170020512172, 75.28579534803117, 69.18098994663784, 76.16298457554409, 65.9184980392456, 55.69744430269514, 54.359092712402344, 53.74766513279506, 51.606476988111226, 52.93656022208077, 48.85495213099888, 50.61167212894985, 50.37741013935634, 50.248312609536306, 49.04405082975115, 47.76754862921578, 48.20027548926217, 49.77166618619646, 50.91175092969622, 48.52700410570417, 46.50538751057216, 48.26824276787894, 46.32420628411429, 48.65906504222325, 43.7799322945731, 43.48218808855329, 42.34042535509382, 46.28968415941511, 45.18919025148664, 45.7513689994812, 47.964946951184956, 56.82748889923096, 52.02713482720511, 44.71110555103847, 45.61779335566929, 51.14850384848458, 48.19271584919521, 49.88696459361485, 52.26403365816389, 54.724818093436106, 57.70380960191999, 50.351649693080354, 48.57252522877285, 42.53659732001168, 47.94465821129935, 51.88298749923706, 52.883236271994456, 47.55430146626064, 49.518581526620046, 53.8334892817906, 47.22201429094587, 40.93659741537911, 49.73440299715315, 45.215371063777376, 37.4438977922712, 44.44696978160313, 47.58864641189575, 49.2141774722508, 50.02111346381051, 48.95298773901803, 51.83276244572231, 51.97592312949044, 53.998078210013254, 55.09609855924334, 56.23431076322283, 52.143642221178325, 55.20154789515904, 52.93529217583792, 52.9184011050633, 51.500346728733604, 50.933887890407014, 48.7569443157741, 45.99513265064785, 37.71934870311192, 43.41824034282139, 50.4521484375, 30.91906336375645, 47.537841183798655, 53.64096164703369, 50.648379462105886, 51.91709968021938, 49.0985872404916, 53.30351543426514, 50.224765164511545, 53.71230227606637, 51.948376996176584, 49.63926131384713, 50.55496788024902, 50.30316168921334, 52.988126277923584, 54.07270533697945, 53.072609424591064, 52.78091362544468, 50.4665972164699, 52.774330207279746, 52.23330177579607, 50.89396006720406, 54.14728035245623, 46.72191769736153, 44.911679199763704, 43.41780955450875, 42.755680969783235, 40.869554247174946, 37.60080548695156, 39.83169140134539, 43.56658090863909, 43.73378235953194, 44.75661277770996, 45.334661211286274, 44.973945481436594, 45.8256904057094, 45.449560097285676, 46.20316171646118, 47.79819713320051, 45.635118688855854, 45.94491801943098, 47.945231437683105, 47.75951303754534, 48.33987522125244, 48.72104297365461, 49.78114005497524, 52.73745959145682, 51.10510540008545, 61.62660271780831, 63.572299821036204, 70.65788514273507, 69.99068437303815, 72.6090921674456, 68.63657774244035, 70.38297966548375, 65.30260276794434, 70.97237450735909, 72.03371184212821, 83.53352941785539, 52.002548626491, 0.04659715068659612, 0.8520235578928674, 62.361388615199495, 66.84214292253766, 49.06110518319266, 47.69757679530552, 29.139666182654246, 42.98975535801479, 40.328723839351106, 2.787875009434564, 0.2554618391607489, 0.06129527770514999, 0.10932047319199358, 0.20678362835730824, 0.036621929345918555, 0.047424440937382836, 0.12699724680611066, 0.26403865750346867, 0.10870711146188633, 0.16313302277454308, 0.2485351637005806, 0.21606230975261756, 0.17842439295990126, 0.18468531700117247, 0.1721642017364502, 4.1147162573678155, 74.48212500980922, 47.27569954735892, 57.084082399095806, 78.88728986467633, 63.52822739737374, 84.38444750649589, 48.96909018925258, 0.3596084149820464, 0.30636274069547653, 0.31844647228717804, 0.7527793975813049, 28.294066940035137, 92.11294269561768, 68.60927827017647, 80.7522975376674, 72.64099829537528, 75.62158788953508, 71.68928268977574, 78.13341031755719, 67.60743141174316, 55.893157686506, 55.982685225350515, 55.54388563973563, 55.06774296079363, 56.420706612723215, 51.09262990951538, 52.38214956011091, 52.00705105917794, 52.162242548806326, 53.21970278876168, 51.08836024148123, 50.44897311074393, 51.19249289376395, 55.05271748134068, 52.34196465356009, 48.5235230582101, 50.06871209825788, 47.99958719526018, 52.1561906678336, 46.11517320360456, 45.96037081309727, 44.03780773707798, 48.39152465547834, 48.18244988577706, 48.12780925205776, 51.04413495744978, 57.30314173017229, 55.96063164302281, 44.968595368521555, 48.900549684252056, 51.90618058613369, 51.21299007960728, 52.88752678462437, 54.77312197004046, 55.595635822841096, 61.17850644247872, 52.4360328401838, 50.24249349321638, 47.5181291443961, 46.88991124289376, 54.22206728799002, 56.615388189043315, 53.84625312260219, 51.50523131234305, 52.18131535393851, 48.52670880726406, 45.239314556121826, 52.13882711955479, 52.08182062421526, 41.64207233701433, 45.31207261766706, 48.02285671234131, 51.807033266339985, 50.47814859662737, 52.821046420506065, 56.17729384558541, 53.80970559801374, 55.47054392950875, 55.852257115500315, 56.20925555910383, 52.69025700432913, 57.71391575677054, 57.31390796388899, 55.28456497192383, 53.76136698041643, 52.740252767290386, 51.34047562735421, 47.601142747061594, 39.55871752330235, 51.826745305742534, 53.035822187151226, 29.388017381940568, 46.92627464021955, 53.4672532081604, 53.43334947313581, 54.22042056492397, 52.54826014382498, 55.73739644459316, 53.86002445220947, 57.095536504473, 53.614836420331685, 49.436283588409424, 52.04941422598702, 52.157733167920796, 55.32093184334891, 56.03961181640625, 55.78588097436087, 54.529302733285085, 54.504337855747764, 55.26873697553362, 55.66935968399048, 52.54262515476772, 57.4773712839399, 51.004061222076416, 47.620934690747944, 45.9865585735866, 45.9281450680324, 43.59999132156372, 41.546538080487935, 42.14730017525809, 47.16553585869925, 48.162029130118235, 47.7925169808524, 48.61633014678955, 47.84367309297834, 48.559660639081685, 48.99809544427054, 48.171211174556184, 50.78069748197283, 48.108795506613596, 48.3355256489345, 51.24577862875802, 49.36875057220459, 50.38869401386806, 51.87680360249111, 52.0152325630188, 54.43307018280029, 53.16364819662911, 63.20014040810721, 66.55828816550118, 73.3122707094465, 72.4050235748291, 74.41064194270542, 72.35535090310233, 71.90576076507568, 67.4852751323155, 73.86978721618652, 74.78446892329625, 84.39485590798515, 52.80299152646746, 0.14778993465006351, 1.4492213896342685, 69.11862291608537, 73.62822614397321, 58.099471296582905, 61.010207176208496, 30.15342399052211, 56.55295515060425, 58.16279717854091, 3.512152624981744, 0.5739784719688552, 0.2837723286024162, 0.13306709538613046, 0.3480387958032744, 0.15255038706319674, 0.12609455095870153, 0.178006822509425], [0.07843782712838479, 0.06549266818910837, 0.05216732268620815, 0.11148451814161879, 0.10059943901641027, 0.07016394753009081, 0.05683024247576084, 0.07260938095194952, 0.28577007140432087, 40.48354360035488, 33.735123089381624, 37.41319022859846, 34.32077980041504, 54.24454123633248, 69.24001489366803, 42.15975482123238, 0.3143696439053331, 0.11515377089381218, 0.21320083258407457, 0.23341194806354387, 46.25920936039516, 80.7272423335484, 63.75611441476004, 72.97592231205532, 69.1558791569301, 69.7147991997855, 64.84643963405064, 67.79995904650006, 53.496095180511475, 51.91973304748535, 49.58578102929251, 50.102532454899375, 49.87640333175659, 51.229690074920654, 48.44131197248186, 51.08795724596296, 48.89430325371878, 47.14911726542881, 47.16583463123867, 49.535559449877056, 44.614011423928396, 45.36654302052089, 43.88176509312221, 45.37686456952776, 43.545833587646484, 45.15974031175886, 45.56015110015869, 44.42912680762154, 40.18731410162789, 39.20667314529419, 39.79687397820609, 43.81626442500523, 43.96771430969238, 43.606519154139924, 47.117363997868125, 57.91789402280535, 54.38752474103655, 44.99109710965838, 38.6209191594805, 47.58145502635411, 44.292500904628206, 45.52730001722063, 44.16576228822981, 51.52132681437901, 45.543440682547434, 47.87332105636597, 41.19242661339896, 41.12106166567121, 52.01238032749721, 46.00661454881941, 47.36147158486502, 48.30879592895508, 47.89383561270577, 39.32945128849575, 37.34552867071969, 46.589168889181956, 33.62527901785714, 28.805727073124476, 40.02148491995675, 45.66484308242798, 46.090170110974995, 47.78287982940674, 46.96724121911185, 45.61217226300921, 47.580148765019004, 50.5094050679888, 52.57192570822579, 53.55017648424421, 45.60588066918509, 47.247826848711284, 53.54258905138288, 51.80031783240182, 51.33514288493565, 47.747065339769634, 48.590076378413606, 46.88746895108904, 45.06007187707083, 39.196052823747905, 29.899668829781668, 36.46360771996634, 39.970974990299766, 33.37432050704956, 40.56848880222866, 43.52976587840489, 50.39867162704468, 47.113000529153005, 50.37953281402588, 48.04673419679914, 48.17149257659912, 49.97044372558594, 46.229874065944124, 45.138992990766255, 49.32959399904524, 49.503024509974885, 50.49544961111886, 50.94259050914219, 50.156787463596885, 48.16415180478777, 45.099537645067485, 50.31670025416783, 51.69907563073294, 51.57292413711548, 42.53464140210833, 41.35829748426165, 39.79734992980957, 39.11770493643624, 37.78395305361067, 34.81491831370762, 34.954518045697895, 39.5011864389692, 39.94854620524815, 41.876692158835276, 41.50242049353463, 43.305464131491526, 43.679975509643555, 43.24105085645403, 45.33945894241333, 44.40586076463972, 44.95139857700893, 47.767433983939036, 45.33409145900181, 46.41401522500174, 46.31572600773403, 49.3934132031032, 48.770566259111675, 50.716430119105745, 48.29720980780465, 49.31766741616385, 52.75231831414359, 56.476375579833984, 57.20227820532662, 62.05349309103829, 60.80160140991211, 61.77622522626604, 57.752759660993306, 65.44476985931396, 66.34963376181466, 77.40280723571777, 57.91364172526768, 0.16652256303599902, 0.3737923481634685, 54.285337584359304, 58.59228965214321, 43.537499223436626, 39.30019589832851, 30.884742736816406, 30.273252623421804, 22.996220111846924, 2.130615157740457, 0.2775936701468059, 0.08993281424045563, 0.05473428512258189, 0.21228795871138573, 0.05693335604986974, 0.12228026134627205, 0.1042765559894698, 0.04603301327941673, 0.021369632599609237, 0.0787912556635482, 0.12434912818883147, 0.18768380396068096, 0.002180793314307396, 0.016259376724649752, 0.11566993248249803, 1.9768017998763492, 52.195058890751426, 38.98041895457676, 37.65838520867484, 40.44477612631661, 58.81009483337402, 75.6199620110648, 46.77627345493862, 0.3233089627964156, 0.0985487297709499, 0.1203181009207453, 0.12454369132007871, 49.79070772443499, 84.46276760101318, 66.35189887455532, 76.77894238063267, 71.41104902539934, 72.39651897975376, 69.35124165671212, 72.45008959089006, 57.437790870666504, 54.61745800290789, 51.760261467524934, 50.821160316467285, 52.70203767504011, 56.00302607672555, 51.1605554989406, 52.19297095707485, 51.32712813786098, 50.06736414773123, 50.25681025641305, 50.50884573800223, 49.312115805489675, 49.437141690935405, 47.03671973092215, 47.40624230248587, 46.674517086574006, 47.31099987030029, 46.239789145333425, 46.0657194001334, 43.60880511147635, 42.88343749727522, 43.8353511265346, 45.402704920087544, 47.50784581048148, 45.22237832205636, 49.16937548773629, 59.22132396697998, 56.060435567583355, 45.658888476235525, 40.65361813136509, 50.63033151626587, 45.26529387065342, 47.42520046234131, 46.54319265910557, 53.42881577355521, 46.34871258054461, 50.05084480558123, 43.6953136580331, 44.377918584006174, 53.464091777801514, 50.25405529567173, 48.12819835117885, 48.83382265908377, 49.14770405633109, 42.74388640267508, 38.28014128548758, 45.76065526689802, 37.402003628867014, 34.152289458683555, 41.17583431516375, 44.22611781529018, 46.6078074319022, 50.56469883237566, 49.164400577545166, 49.048813819885254, 51.194549560546875, 51.434842586517334, 53.02414573941912, 56.377263001033235, 47.98810529708862, 47.9112616947719, 54.22586795261928, 53.84984186717442, 52.99363272530692, 51.70174373899187, 49.54028075081961, 49.05456345421927, 46.770541191101074, 42.95420837402344, 37.36875302450997, 38.491772992270334, 38.2158773967198, 35.817265442439485, 49.83759764262608, 45.47046375274658, 51.395748547145296, 51.08419132232666, 49.8190598487854, 51.64091920852661, 51.436155796051025, 49.86197887148176, 45.9063902582441, 45.80892440250942, 51.664272103990825, 52.35434634344918, 51.983121463230674, 52.831586837768555, 50.108792781829834, 50.08589151927403, 46.78763723373413, 52.149200780051096, 54.32316010338919, 52.73480190549578, 46.152280058179585, 43.48937947409493, 42.283745425088064, 42.59417356763567, 41.18406793049404, 37.600826331547324, 39.32189859662737, 41.90510334287371, 44.314669132232666, 44.057874134608674, 44.832601751599995, 47.80244595663888, 46.395077909742085, 44.94560030528477, 47.286503996167866, 48.48602710451399, 46.91500118800572, 50.298450810568674, 50.676040240696494, 48.22966636930193, 48.6112961769104, 51.128590311322895, 51.3995874268668, 51.564079080309185, 50.21822690963745, 52.20848628452846, 53.31394815444946, 57.70916666303362, 61.0535500390189, 63.65622016361782, 64.80048424857003, 64.16726016998291, 60.29163837432861, 69.20563520703996, 70.79356956481934, 79.05380344390869, 64.41673524039132, 0.25938531862837927, 0.3055775399718966, 61.44931943075997, 65.36451816558838, 50.79791859218052, 46.78184243610927, 34.44346761703491, 42.39165094920567, 38.626283168792725, 2.1392869438443864, 0.16089533641934395, 0.15105906208711012, 0.039895304412181885, 0.17482061205165728, 0.03612139441871217, 0.07242522654788834, 0.057818599976599216, 0.11836188446198191, 0.18772566957133158, 0.34245920234492844, 0.18957275045769556, 0.2793747974293572, 0.10486195529145853, 0.12667834891804627, 0.20295821077057294, 4.19120419876916, 67.49259158543178, 45.297443185533794, 46.70069095066616, 47.69579805646624, 66.31940909794399, 81.27677536010742, 51.08593879427229, 0.5902405136397907, 0.36320826038718224, 0.2870785854756832, 0.4597000926733017, 51.95353603363037, 85.94480446406773, 68.64627742767334, 78.18277726854596, 76.01855931963239, 76.00546891348702, 70.54133605957031, 73.5954931804112, 59.4760935647147, 58.48967865535191, 56.58491686412266, 54.1540652683803, 54.6222175189427, 57.83332402365548, 53.96453925541469, 54.472706181662424, 53.3103072983878, 51.41146537235805, 50.61391639709473, 53.87144381659371, 49.39984376089913, 51.77571773529053, 48.36400631495884, 48.773449761526926, 48.61378015790667, 49.92887265341622, 49.201847893851145, 49.247389861515586, 45.42490094048636, 43.95416532244001, 46.26689059393746, 47.802727358681814, 47.89556571415493, 48.96523741313389, 49.15256779534476, 62.99391787392752, 58.0220753124782, 48.04644932065691, 42.49837875366211, 52.69897699356079, 48.0401542527335, 47.130159105573384, 49.15721614020211, 55.46980047225952, 50.06411239079067, 51.90833452769688, 48.13586221422468, 46.44190182004656, 56.71914563860212, 53.11209603718349, 52.393558502197266, 48.16745567321777, 48.61620855331421, 47.7497820854187, 43.747574533735005, 50.528359753744944, 45.18067176001412, 36.26478154318673, 42.43124525887625, 47.793072836739675, 49.869965825762065, 52.938088825770784, 50.916086605616975, 51.09955726351057, 53.472214221954346, 54.29536036082676, 55.075215748378206, 58.14493683406285, 50.1208826473781, 49.91557032721383, 56.498509066445486, 55.8754814692906, 54.848582880837576, 55.76089872632708, 52.332483836582725, 48.7249687058585, 46.796840122767854, 45.0451089314052, 41.047855445316856, 46.9112491607666, 43.68357120241438, 36.59490435464041, 45.77898461478097, 46.664028780800955, 54.423596314021516, 53.86693443570818, 55.014161927359446, 52.108963762010845, 53.08314984185355, 53.81801216942923, 47.94634314945766, 49.643058504377095, 54.43263939448765, 55.000150884900776, 55.15434878213065, 54.01937096459525, 52.641928809029714, 53.24062728881836, 48.22934675216675, 54.08517040525164, 54.51569816044399, 55.62450211388724, 49.48036296027047, 45.97594520023891, 45.66627093723842, 43.422266823904856, 43.199552740369526, 39.563824449266704, 42.0029548236302, 45.2088223866054, 45.605310916900635, 46.47367245810372, 47.62784467424665, 48.03998054776873, 47.413610867091585, 46.59269857406616, 49.50047104699271, 50.78954601287842, 50.276077611105784, 54.110711983272004, 52.499108586992534, 50.595409870147705, 52.055504322052, 55.03547205243792, 53.23626382010323, 54.83300501959664, 54.21615089688982, 54.37576491492135, 58.29469830649239, 59.371092387608115, 62.959732736860005, 66.41874749319894, 68.78719384329659, 66.53433077675956, 64.79699625287736, 73.01633303506034, 73.15254552023751, 82.73800931658063, 66.60994107382638, 0.35530376168234007, 0.9104307666420937, 67.54232679094586, 71.30022525787354, 60.69121537889753, 56.163852555411204, 49.801612922123496, 53.63398218154907, 55.995949336460654, 3.119885342461722, 0.31178361124226023, 0.24078450245516642, 0.19831119584185736, 0.30277942440339495, 0.14248860840286526, 0.20105535430567606, 0.11411789219294276], [0.043458464821534495, 0.02741604627642248, 0.13133721106818744, 0.0957524191055979, 0.11562350711652211, 0.07093881416533675, 0.07745903357863426, 0.20923312620392867, 1.1633888930082321, 38.24394464492798, 39.96860565458025, 34.104749883924214, 33.04108837672642, 53.206588063921245, 66.99863025120327, 48.553778988974436, 0.5082298942974636, 0.05703778937458992, 0.13288250671965735, 0.5038658284715244, 61.201296533857075, 74.92114693777901, 65.06040246146065, 69.57886464255196, 66.47098405020577, 65.46678175245012, 66.03019033159528, 56.01084974833897, 50.11972229821341, 49.528903075626914, 51.1296568598066, 56.439477171216694, 57.626538685389924, 60.05774811335972, 59.84113107408796, 60.741770471845356, 55.93749066761562, 53.883231435503276, 52.53679214205061, 49.81101730891636, 50.877465043749126, 52.573225021362305, 53.31116540091378, 51.627158301217214, 47.79378502709525, 44.782512187957764, 44.15259892599923, 45.510589599609375, 41.86093364443098, 40.1252840587071, 40.26920557022095, 40.24845824922834, 42.633469104766846, 42.41109548296247, 48.30049630573818, 56.039993967328755, 53.39778164454869, 44.49978651319231, 42.07856512069702, 44.09579045431954, 43.05912617274693, 41.882323673793245, 44.08807100568499, 48.57158374786377, 41.31725794928414, 44.30671344484602, 41.220045702798025, 44.60707017353603, 46.90449898583548, 50.20364958899361, 53.77029194150652, 47.4076805795942, 34.80219268798828, 35.318780830928254, 40.95949172973633, 31.985740389142716, 32.69296625682286, 40.629806654793875, 44.23971543993269, 44.71430172239031, 46.32913603101458, 45.26305307660784, 46.84851387568882, 48.3299914087568, 49.37747403553554, 50.81756462369646, 54.10261385781424, 55.52012627465384, 44.32313551221575, 43.97494738442557, 52.733558177948, 53.433599608285085, 50.066836084638325, 46.24287067140852, 48.77395003182547, 46.82064117704119, 44.477972643715994, 42.553957394191194, 37.44508940832955, 25.214939730507986, 29.549337182726177, 32.77151911599295, 32.76883711133684, 37.38588033403669, 43.42455972943987, 48.891367639814106, 47.37859194619315, 42.5095271383013, 47.335586071014404, 46.26544189453125, 45.92085293361119, 41.93879515784127, 42.17952939442226, 48.65919010979788, 46.56964445114136, 47.5072135244097, 45.88424634933472, 44.4592924118042, 41.02213668823242, 47.520543643406455, 52.3430346761431, 50.42792354311262, 43.525346824101035, 40.24165596280779, 38.681406702314106, 39.15951224735805, 37.898174490247456, 35.055506638118196, 37.738692487989155, 40.28374120167324, 40.51102025168282, 42.96372740609305, 46.68682929447719, 49.69108097893851, 46.730401447841096, 46.46348292487008, 48.04435791288103, 46.28066539764404, 46.2652473449707, 47.845844405038015, 48.012528215135845, 49.333081994737896, 46.2588654245649, 47.07554279054914, 48.20183188574654, 50.59150150844029, 50.677422932216096, 49.98801919392177, 50.436650480542866, 49.5000194140843, 49.63427250725882, 52.47113166536604, 54.51903676986694, 55.29501158850533, 56.90433597564697, 64.59601266043526, 69.72801467350551, 72.07885428837368, 65.78887939453125, 0.7241035306027958, 0.173847904961024, 53.9704521724156, 61.55393845694405, 40.37054852076939, 41.74103900364467, 32.136641366141184, 26.00833715711321, 27.136088848114014, 1.7138145459549767, 0.16038435883820057, 0.09685018020016806, 0.05138034080820424, 0.14021380618214607, 0.0802003014832735, 0.34031603591782705, 0.058949358229126246, 0.05555042704301221, 0.03506297478452325, 0.07312668247946671, 0.015275896194257906, 0.0900112936007125, 0.050077102346611876, 0.08390563194240842, 0.15913054826004164, 2.405948166336332, 54.462666034698486, 47.222469397953574, 35.50372103282383, 37.053492409842356, 59.80783530644008, 71.5981570652553, 54.541614941188264, 0.46122256240674425, 0.130390003323555, 0.20798432321420737, 1.213154822587967, 66.79606941768101, 80.00950731549943, 69.51942975180489, 73.30460684640067, 70.88003294808524, 69.17696693965367, 68.63198498317173, 60.370333671569824, 52.13025999069214, 52.21028586796352, 52.88277421678816, 58.34351634979248, 61.68542616707938, 61.38647992270333, 62.63299369812012, 62.49697576250349, 58.689383779253276, 56.95298726218087, 55.266193934849326, 52.43063408987862, 52.514005524771555, 54.67681993756975, 55.86391619273594, 54.65682997022356, 49.87075097220284, 46.74394696099417, 47.54705102103097, 48.593668597085134, 44.15708746228899, 43.20315190723964, 42.50558750970023, 43.48211513246809, 45.75653845923287, 44.954789297921316, 49.85852561678205, 58.61393329075405, 55.2178761618478, 47.50541394097464, 44.41432367052351, 47.25087710789272, 44.59993437358311, 42.968250683375764, 45.68185922077724, 50.154077666146414, 44.76944957460676, 46.37594951902117, 42.94476924623762, 47.282727650233674, 49.5842558997018, 53.894591740199495, 53.53857299259731, 48.305276666368755, 37.54784631729126, 38.40076201302664, 38.94412851333618, 34.128332069941926, 37.92467144557408, 40.40922566822597, 43.759108543395996, 48.384065764290945, 48.54846361705235, 48.07695191247122, 48.31567464556013, 50.65799924305507, 50.631193092891145, 52.58430739811489, 56.42142922537667, 56.01230192184448, 46.183338505881174, 45.4849715914045, 56.09204987117222, 54.56342533656529, 51.45866101128714, 47.72354221343994, 50.87780897957938, 45.61373560769217, 46.36217124121529, 43.56890855516706, 39.3257965360369, 30.400467191423687, 33.771184240068706, 33.14767721721104, 35.10608952386038, 46.743495328085764, 45.69638442993164, 50.62956026622227, 50.610080991472515, 46.15661573410034, 49.630437101636616, 46.889984198978965, 46.10100582667759, 41.43035725184849, 43.198649474552695, 50.311555113111226, 46.58527789797102, 49.08164753232683, 48.259991782052175, 45.05735165732247, 44.30114098957607, 48.847041606903076, 55.051650932856965, 51.768554142543245, 47.74718345914568, 41.843445028577534, 41.9679810660226, 41.41268450873238, 42.05785254069737, 38.067026138305664, 41.691543510981965, 42.76660006386893, 43.71646050044468, 45.66838666370937, 50.272502762930735, 52.44252940586635, 50.92247894832066, 49.44908217021397, 48.92379835673741, 48.652811663491384, 48.94146762575422, 50.136491775512695, 52.211515699114116, 51.335670948028564, 50.73510340281895, 48.83930131367275, 50.50107765197754, 52.23785979407174, 52.482189723423545, 53.1405211176191, 52.93122400556292, 52.01491641998291, 54.05892358507429, 55.157854148319785, 57.068844999585835, 57.79135343006679, 60.805096353803364, 67.92788233075822, 76.1560502733503, 75.49440806252616, 71.5551199231829, 1.4086878789322717, 0.0850592568250639, 61.159704617091585, 67.50428540366036, 51.283635888780864, 48.510960715157644, 31.56708710534232, 38.04546935217721, 42.04786450522286, 1.228818559220859, 0.20634103353534425, 0.06930083741566964, 0.036249929307294745, 0.08561015940670456, 0.04092314586575542, 0.1339890073452677, 0.006260897748039237, 0.151596692523786, 0.12680127232202462, 0.16947547958365508, 0.1238307138638837, 0.17764115998787539, 0.1744102340723787, 0.24753986139382633, 0.4505273848772049, 4.672659644058772, 68.82671519688198, 54.17078958238874, 46.44410787309919, 44.87174790246146, 67.26282855442592, 74.80250644683838, 60.70748805999756, 0.7502458563872746, 0.3705883872296129, 0.40940297873956816, 1.8083226404019763, 69.80116530827114, 83.25952025822231, 70.77099486759731, 77.44660173143659, 73.48710823059082, 70.97231197357178, 70.24981049128941, 61.47288772038051, 54.76889746529715, 56.19374370574951, 54.95325749261038, 62.47144113268171, 64.2392851965768, 64.62639713287354, 64.61591230119977, 65.2211559840611, 60.9220414842878, 60.95687280382429, 57.892713751111714, 55.223952361515586, 53.87804807935442, 55.700835023607524, 58.55055182320731, 56.71741206305367, 51.65172365733555, 48.308372088841026, 49.26673017229353, 49.29141712188721, 46.220167432512554, 44.93555668422154, 46.4041348866054, 46.40583372116089, 46.59299039840698, 47.33894899913243, 51.77268484660557, 60.85032912663051, 56.40309292929513, 50.42717661176409, 45.07590682165963, 47.29512671061924, 47.91450302941458, 46.072445256369456, 48.150255407605854, 53.381880692073274, 46.11868551799229, 48.98526212147304, 46.996712003435405, 49.96348510469709, 51.54174757003784, 53.314660344805034, 55.07290547234671, 52.5670029095241, 44.19822427204677, 40.601576123918804, 43.76237767083304, 39.16249997275216, 40.58080448423113, 41.559319291796, 47.0617401940482, 48.70041724613735, 50.86989150728498, 50.09812034879412, 51.492123535701204, 52.61170761925833, 55.286395822252544, 55.56082534790039, 59.720128195626394, 59.76911299569266, 47.762469496045796, 47.28297431128365, 56.56272084372384, 56.200195108141216, 54.30336121150425, 51.620863233293804, 52.055420943668906, 50.97683817999703, 47.088706152779714, 46.261835779462544, 42.03620195388794, 34.101140294756206, 42.91507959365845, 42.39190108435494, 37.29331643240792, 42.18417773927961, 46.97425889968872, 52.677944796425955, 52.45765563419887, 48.634572642190115, 53.342428820473806, 49.143236364637104, 47.73251233782087, 44.6297664642334, 44.13977949959891, 53.182595934186665, 50.358622210366384, 49.8468074798584, 50.76476526260376, 47.67847272327968, 45.986555099487305, 52.98512813023159, 57.51186214174543, 54.991034848349436, 50.97500038146973, 45.606683186122346, 43.38873134340559, 44.27581480571202, 45.16813373565674, 40.586057322365896, 44.446948937007356, 45.10609674453735, 46.41437653132847, 46.744996138981406, 52.4055233001709, 54.18282733644758, 49.930533272879465, 52.32354497909546, 51.2440242086138, 50.159730025700156, 51.99500635692051, 51.5075033732823, 52.60630886895316, 53.41556208474295, 52.33532912390572, 52.14093589782715, 53.67782531465803, 54.94034079142979, 55.328244822365896, 53.9078106880188, 56.846909114292686, 54.14415366309029, 55.53287969316755, 56.67077922821045, 60.28257097516741, 60.32813031332833, 63.2895359311785, 70.49087824140275, 79.03354249681745, 77.84661647251674, 76.00259930746896, 1.3806328986372267, 0.2908176662666457, 67.79956994737897, 76.76976381029401, 59.150049345833914, 59.76789011274065, 51.7023343358721, 46.99255698067801, 60.9934481212071, 2.1593596381800513, 0.3630708163338048, 0.15756159887782165, 0.0823893097362348, 0.27719897989715847, 0.18279231286474637, 0.3246644586324692, 0.07362990440534693], [0.04170095734298229, 0.08602138555475644, 0.1191641842680318, 0.047519374771841934, 0.06665185705891677, 0.09479936917445489, 0.01722996508968728, 0.050350205906267674, 1.0553926080465317, 38.32193470001221, 39.84626177379063, 35.72273520060948, 41.90705231257847, 50.38428538186209, 63.38451780591692, 58.0854081426348, 1.0356405079364777, 0.03519043080242617, 0.0908498882449099, 3.975711464881897, 71.7332717350551, 69.40051133292062, 67.41197163718087, 63.75201497759138, 63.55613831111363, 59.83513477870396, 56.15785278592791, 50.50488526480538, 49.225318908691406, 50.899647167750764, 55.553745133536204, 59.068269048418315, 59.12117263248989, 60.16956547328404, 62.248515129089355, 63.59457574571882, 63.76092951638358, 60.685531752450125, 57.629060881478445, 57.44142825262887, 57.85736131668091, 59.49524280003139, 57.563907623291016, 58.71629415239607, 54.49376269749233, 47.66722011566162, 44.222268513270784, 43.65338475363595, 43.534532342638286, 39.755087511880056, 39.135735511779785, 39.78375577926636, 40.75273418426514, 42.329683440072195, 47.487744671957834, 49.29104539326259, 49.41382701056344, 45.290088517325266, 45.46143456867763, 42.51453678948538, 41.23641218457903, 40.401207447052, 42.120560032980784, 41.34264319283621, 41.49653189522879, 44.290941034044536, 42.598874023982454, 46.32920551300049, 48.923162596566335, 50.50996787207467, 41.71555301121303, 34.243762493133545, 37.82597575868879, 44.31807027544294, 34.665712697165354, 33.24812732424055, 37.3781087739127, 39.95434447697231, 44.09119769505092, 44.81217752184187, 42.775035176958355, 46.03914254052298, 47.33860158920288, 45.78723212650844, 46.95815992355347, 51.42820358276367, 51.806807449885774, 54.34228849411011, 46.176564012254985, 44.087278911045615, 53.30228907721383, 48.66380718776158, 49.37516723360334, 46.15327017647879, 47.65058960233416, 48.35282318932669, 45.848108768463135, 40.67898947851998, 41.97014542988369, 34.39199536187308, 28.57790780067444, 28.81921178953988, 25.633784089769634, 30.49912813731602, 42.97517803737095, 40.048589842660085, 44.559110232761924, 45.495762143816265, 43.17987544195992, 45.47092580795288, 46.4851439339774, 41.39800991330828, 40.46539837973458, 41.55919075012207, 43.17303146634783, 42.96572848728725, 44.44514240537371, 42.28937346594674, 43.06252384185791, 42.980104310171946, 50.82067046846662, 50.197854791368755, 44.21028634480068, 40.28598894391741, 38.44538334437779, 38.629996980939595, 37.830436502184185, 36.80806466511318, 38.33652591705322, 42.693425110408235, 43.455784933907644, 47.217574392046245, 51.75126355034964, 54.036331517355784, 53.57843828201294, 55.3475330216544, 52.191216536930625, 53.02036591938564, 52.142019816807334, 53.52524287360055, 54.071885449545725, 56.61545072283064, 56.33089419773647, 55.55676759992327, 51.83727182660784, 49.989752769470215, 48.32163619995117, 48.464168071746826, 50.131235463278635, 49.851382868630544, 51.311498165130615, 51.73275007520403, 51.696890422276084, 54.34708969933646, 54.75421592167446, 61.90881769997733, 69.56325204031808, 70.70878069741386, 73.46333149501255, 2.46115203840392, 0.1560853916619505, 53.81186996187483, 60.12329741886684, 40.862390654427664, 40.05544424057007, 35.25991221836635, 35.200411319732666, 36.978868756975444, 0.7704273334571293, 0.06874067283102445, 0.035428101263408146, 0.08782905034188714, 0.04277381620236805, 0.08450042895440545, 0.12712808192840644, 0.027320980127634745, 0.05271086994824665, 0.045174883612032445, 0.10018242496464934, 0.02468017442151904, 0.057428028434515, 0.06636126086648021, 0.09400239586830139, 0.08709853954081025, 1.8474074516977583, 50.740741865975515, 46.44829068865095, 36.77770103727068, 42.621771812438965, 59.17985711778913, 66.87799562726701, 66.44151673998151, 1.2973241060972214, 0.04116754060877221, 0.22909100992339, 5.292789842401232, 78.59238747188023, 72.47699301583427, 72.4894858769008, 65.33857359204973, 66.42582770756313, 62.7640506199428, 60.73478058406285, 53.510689871651785, 52.97693272999355, 54.69086224692208, 58.63265173775809, 59.13734803880964, 62.70147514343262, 64.03576551164899, 64.30995532444545, 66.44478239331926, 65.28994315011161, 63.19775717599051, 60.37977627345494, 60.67927142551967, 61.21599197387695, 60.72549779074532, 60.50390584128243, 61.562276295253206, 57.46879720687866, 50.7163919040135, 46.59921598434448, 47.74754129137312, 44.99909448623657, 41.84357009615217, 41.35562242780413, 41.6043575150626, 43.1797399520874, 43.874907221112935, 50.13497706821987, 51.41821207318987, 52.23867620740618, 47.71662875584194, 46.66639116832188, 43.81340176718575, 44.497146197727744, 44.41301393508911, 45.30760840007237, 43.54904018129621, 41.55881207329886, 44.49893535886492, 44.65218135288784, 49.7062280518668, 51.03523778915405, 51.93001985549927, 45.41473920004708, 38.385389123644146, 40.43918630055019, 43.97178247996739, 37.76239626748221, 37.39925561632429, 37.67445986611502, 42.340137004852295, 46.62212072099958, 44.13720171792166, 44.765655858176096, 48.013205664498464, 48.62347984313965, 48.25827905109951, 49.98662608010428, 55.04799965449742, 53.332815987723215, 56.183766092572895, 48.0917272567749, 43.49522985730852, 55.295956543513704, 52.747968741825645, 50.4505364554269, 46.93469933101109, 48.60105105808803, 49.25719724382673, 46.45511381966727, 43.073512417929514, 43.11335686274937, 37.829185826437815, 33.81071254185268, 34.404279776981895, 26.955048322677612, 31.060664176940918, 51.34339039666312, 41.61740623201643, 43.820728642599924, 47.41236366544451, 45.34119946616036, 46.776596546173096, 46.80140161514282, 42.82847377232143, 40.927992071424214, 41.594240937914165, 46.27891097749983, 44.924338817596436, 46.31149108069283, 42.8920567376273, 43.97786562783377, 44.36280972617013, 53.26318808964321, 53.11200571060181, 46.31275565283639, 41.54182720184326, 41.39129447937012, 41.659387247903005, 41.06570884159633, 39.77349328994751, 41.719593388693674, 45.12460674558367, 47.42681244441441, 50.117908818381174, 53.69489009039742, 56.13348197937012, 57.033565521240234, 58.73360211508614, 56.94487871442522, 55.00348949432373, 55.7789431980678, 58.1522011756897, 58.57719121660505, 57.46089015688215, 60.43078299931118, 58.310609681265696, 54.63411978312901, 53.50189692633492, 51.77245903015137, 51.03064155578613, 53.037562710898264, 52.76685047149658, 54.41850675855364, 55.392189093998496, 56.003231048583984, 57.91661555426461, 58.788284437997, 65.14282894134521, 76.26650578635079, 72.6897121156965, 78.89422416687012, 3.2961567980902533, 0.16615310071834496, 60.299830300467356, 65.8713823046003, 49.7829326902117, 48.599355697631836, 38.42042194093977, 46.50740596226284, 52.13768066678728, 0.5244340705020087, 0.09410245264215128, 0.02149316159609173, 0.13987670998488153, 0.07926855076636587, 0.06545702474457876, 0.19227268200899872, 0.022409943830487982, 0.11948100583893911, 0.13574789224990777, 0.1682311820664576, 0.15782326912241323, 0.12509451247751713, 0.17474844306707382, 0.21773302581693443, 0.1354312878102064, 3.4067410698958804, 67.21374647957938, 54.27305316925049, 47.19148390633719, 54.834578786577495, 64.42510781969342, 71.86268888201032, 70.59133529663086, 1.5385038959128516, 0.19651168026030064, 0.5480563715100288, 6.747066480772836, 80.90451867239815, 74.84190273284912, 74.47913033621651, 68.50889069693429, 69.4757672718593, 65.55670533861432, 61.98537295205252, 54.53802619661604, 54.4592718396868, 57.0472708429609, 61.01069355010986, 61.37238897596087, 65.76661736624581, 66.45885249546596, 66.62009239196777, 68.06030109950474, 66.23741340637207, 65.2761926651001, 63.08330644880022, 62.63243784223284, 63.33760356903076, 63.773568289620535, 62.31428677695138, 62.10630634852818, 60.32323183332171, 51.579712527138845, 48.66743414742606, 50.278572014399934, 48.21036774771554, 45.35742350987026, 43.82653733662197, 43.2734364100865, 43.68932431084769, 45.736142022269114, 52.98775107519967, 53.36210264478411, 54.16576256070818, 49.656075954437256, 49.217932973589214, 49.03207908357893, 47.653744084494456, 47.04718024390084, 46.16092014312744, 47.3409674508231, 44.81232343401228, 48.06479603903634, 48.678975105285645, 51.00631938661848, 55.04189566203526, 55.245502199445454, 51.82199968610491, 42.885792936597554, 41.26344762529646, 46.058663504464285, 41.1611909866333, 38.92180395126343, 40.06777729306902, 45.915037291390554, 47.49440104620797, 46.33938462393624, 46.45512771606445, 49.50869424002511, 50.91998454502651, 49.39304494857788, 53.577781677246094, 57.41432680402483, 56.49641765866961, 59.62184592655727, 48.27642774581909, 45.396951811654226, 57.19636181422642, 53.696119921548025, 52.669943945748464, 48.90162318093436, 52.09498398644583, 53.56854404721941, 48.34266144888741, 43.45646585736956, 47.32328428540911, 39.15898418426514, 36.15431908198765, 39.421598298209055, 35.499684129442485, 34.646323748997276, 45.97865499768938, 42.1767327444894, 49.96381861822945, 49.42667075565883, 49.36744083677019, 51.121607371738975, 50.20054374422346, 44.94786541802542, 44.1780640738351, 45.83797134671892, 48.422148840767996, 47.554707935878206, 47.57716451372419, 46.523216588156565, 47.36527572359358, 46.1136063848223, 55.15424108505249, 57.618746280670166, 49.31496109281267, 44.24948460715157, 44.0643880707877, 43.804504598890034, 44.08541331972395, 43.32478707177298, 45.06917749132429, 47.25407675334385, 49.14832592010498, 52.40397037778582, 55.57897751671927, 59.963134493146626, 58.35170827593122, 60.598811285836355, 58.63238075801304, 57.86100217274257, 57.96380424499512, 58.596118109566824, 59.880562101091655, 60.118336405072895, 61.66845171792166, 60.364184515816824, 56.41426910672869, 54.52983774457659, 54.54795864650181, 51.59126738139561, 54.81383146558489, 53.45748404094151, 56.102301938193186, 56.76559434618269, 57.89607320513044, 59.06134169442313, 62.54567568642752, 66.48469284602574, 80.10439886365617, 75.52832221984863, 80.42254992893764, 4.114744050162179, 0.3193825249161039, 65.18906920296806, 74.5701378413609, 58.27124466214861, 56.23775359562465, 54.276746136801584, 56.47049045562744, 63.89344555991036, 1.462277271917888, 0.16957350075244904, 0.09225858122642551, 0.19709564106804983, 0.16835088921444757, 0.13895877424095357, 0.18574452373598302, 0.1501191146671772], [0.12001554215592997, 0.04488496934728963, 0.05894603340753487, 0.2684662342071533, 0.06795046451900687, 0.1103070020409567, 0.06617834139615297, 0.07150077686778136, 0.7668837521757398, 31.413292203630718, 40.78621755327497, 49.4734251839774, 33.957093715667725, 46.007684571402415, 56.08575132914952, 67.49125753130231, 2.5959262464727675, 0.1006431095302105, 0.17206265218555927, 6.57607478754861, 80.7948066166469, 65.92641203744071, 70.31774997711182, 59.40598624093192, 59.14096805027553, 53.671568461826865, 51.936783926827566, 47.63929877962385, 53.945282323019846, 53.75471060616629, 58.86716038840157, 59.67934921809605, 62.25234358651297, 64.298157283238, 63.97695595877511, 62.940472330365864, 61.65952328273228, 58.950969559805735, 61.09680257524763, 56.24138750348772, 59.315819467817036, 57.53053889955793, 59.68847220284598, 59.19996520451137, 58.34718499864851, 47.935180868421284, 42.8826071875436, 44.116040979112896, 44.02491882869175, 38.89460175377982, 40.128184931618826, 40.52504866463797, 41.33987780979702, 39.206443854740684, 45.9929370198931, 48.66656562260219, 45.3769097328186, 41.798802852630615, 43.89146130425589, 40.7059519631522, 41.47579847063337, 42.28730290276663, 41.527190821511404, 36.95834377833775, 37.582587310246055, 39.44652148655483, 42.33437694822039, 45.19365446908133, 47.906623772212434, 41.306005341666086, 40.31499072483608, 40.62159040996006, 44.18342113494873, 46.270573139190674, 44.7957797731672, 43.44141953332083, 40.02776261738369, 44.642325333186555, 41.513464655194966, 39.36728422982352, 44.0796845299857, 45.56732511520386, 45.760179315294536, 47.56404978888375, 47.860911573682515, 49.331622873033794, 48.970611844744, 53.92981563295637, 49.02164288929531, 45.156040396009175, 52.14935711451939, 51.81199080603463, 49.25731883730207, 46.875837666647776, 48.438004629952566, 46.99944611958095, 46.70666987555367, 42.62734774180821, 41.52267449242728, 44.09177439553397, 30.461218765803746, 29.415497507367814, 32.07189457757132, 24.753035647528513, 27.96978756359645, 40.12301547186715, 39.61062751497541, 39.81860099520002, 47.365015166146414, 45.21428714479719, 46.49062258856637, 43.13075862612043, 39.67184461866106, 36.43287236349923, 38.73842709405081, 39.190271922520225, 40.88750491823469, 40.55241414478847, 42.65224313735962, 42.20870835440499, 48.01124974659511, 48.73954602650234, 43.93118762969971, 41.304768562316895, 38.203697204589844, 40.60887173243931, 37.27322571618216, 37.220450673784526, 39.797336033412385, 42.04831266403198, 43.097977025168284, 49.25428942271641, 51.87895406995501, 55.49489736557007, 56.1374910899571, 54.73032801491873, 56.086161272866384, 55.990265710013254, 56.57021100180489, 57.90554359980992, 58.79366929190499, 59.82146767207554, 60.774962016514365, 61.597288267953054, 60.138916969299316, 59.38138961791992, 56.63229315621512, 54.522410120282856, 54.03410809380667, 55.734443460192, 56.987182821546284, 59.191543987819124, 58.03272342681885, 59.383098874773296, 56.495028018951416, 59.45183045523507, 70.76096166883195, 67.02144813537598, 76.83318696703229, 3.7983586958476474, 0.09054705806608711, 61.13997868129185, 54.71271433149065, 41.37042556490217, 38.170443126133506, 52.786472184317454, 38.750478744506836, 44.801977566310335, 0.7227805501648358, 0.11842220622513976, 0.02721255023165473, 0.18168484871940954, 0.08911083013351474, 0.05316188878246716, 0.1409046905381339, 0.09188147181911127, 0.08129812364599534, 0.0664811512189252, 0.07713273287351642, 0.04860953288152814, 0.07039668504148722, 0.06196415717048304, 0.05349231498049838, 0.05719816791159766, 1.0088952630758286, 46.837386335645405, 42.80902576446533, 50.47087730680193, 43.62337548392159, 53.53014135360718, 59.85310282026018, 76.13132858276367, 3.1897195151873996, 0.12064131429152829, 0.15406073816120625, 8.383438467979431, 86.35556806836809, 68.00581332615444, 75.41765826089042, 63.32053879329136, 62.070203508649556, 56.8399088042123, 56.258771896362305, 50.518934522356304, 56.90617377417428, 55.98877879551479, 61.66095461164202, 62.14607088906424, 65.24327904837472, 65.88504246303013, 65.50058473859514, 63.38352421351841, 63.7571496963501, 61.75563076564244, 62.64009475708008, 59.83564894539969, 62.72802421024868, 59.06999914986746, 63.67264570508684, 59.335746901375906, 61.649253845214844, 49.498661041259766, 46.01141922814505, 46.562414850507466, 45.22168697629656, 42.779614039829795, 42.36312164579119, 43.14229263578142, 46.04536465236119, 42.40732261112758, 48.5998455456325, 50.2068144934518, 47.36653682163784, 45.401426451546804, 46.630378655024934, 42.58821896144322, 44.24348136356899, 43.1114113671439, 43.97500991821289, 40.8306234904698, 39.63426181248256, 42.26689951760428, 44.75861733300345, 48.81992278780256, 50.10269226346697, 44.755740778786794, 43.35856573922293, 42.12181418282645, 45.824689865112305, 48.26142658506121, 49.29051385607038, 46.65166098730904, 42.432534149714876, 45.82502337864467, 43.929520062037874, 41.926187651497976, 47.23050846372332, 48.12833036695208, 48.66736466544015, 48.448465142931255, 48.757764203207834, 53.44066940035139, 51.63314070020403, 55.271655218941824, 50.15663807732718, 47.87992879322597, 53.88618094580514, 52.36906610216413, 53.27904040472848, 47.791210719517295, 48.76958308901106, 46.66963597706386, 49.44813026700701, 43.98825665882656, 44.97028030667986, 43.26162447248186, 32.50946780613491, 32.24528687340872, 36.18457153865269, 25.64959297861372, 30.30824375152588, 48.200848715645925, 42.00678328105381, 42.07601860591343, 49.86040163040161, 48.30583947045462, 49.29451601845877, 45.576687812805176, 40.3657785824367, 38.80318430491856, 41.39538696834019, 41.44300992148263, 42.92719030380249, 42.06944561004639, 43.66661759785244, 44.90532854625157, 49.45343174253191, 51.77688503265381, 47.578512464250835, 43.57016270501273, 41.33476740973336, 41.16414744513375, 41.04424238204956, 38.945049149649485, 43.4509767804827, 44.54731913975307, 47.81599841799055, 52.03896066120693, 55.074378490448, 56.380924701690674, 60.05150168282645, 58.10163566044399, 61.01707894461495, 58.88487829480852, 58.9696741104126, 57.711098262241904, 63.393515723092214, 61.355358941214426, 64.93523761204311, 63.46765300205776, 63.44067314692906, 61.25957107543945, 60.67415060315813, 57.0215242930821, 57.2119014603751, 58.36218615940639, 61.170724460056846, 61.424076625279014, 64.61742006029401, 61.83621597290039, 61.81234891074044, 61.66062109810965, 76.2087801524571, 69.95702729906354, 82.34554726736886, 4.244975873402186, 0.17284368670412473, 67.02595751626151, 63.116831507001606, 47.56574167524065, 46.6987315586635, 57.32681424277169, 42.70961441312517, 58.76163114820208, 1.3242268796477998, 0.11961755422609192, 0.04433316092139908, 0.0633090678602457, 0.11486170228038516, 0.029591095367712632, 0.11930586237992559, 0.07933898270130157, 0.18268594571522304, 0.16892522839563234, 0.27046845534018105, 0.37567256870014326, 0.15562298361744198, 0.21293608179049833, 0.18833434262445994, 0.16575766408017703, 1.7746358194521494, 59.51740755353655, 53.36789049421038, 64.56525298527309, 45.46925129209246, 63.68504129137312, 64.99005889892578, 82.09861523764474, 3.218535431793758, 0.25680615273969515, 0.34314815966146334, 8.428417631558009, 89.38269669669015, 69.29196657453264, 77.7674834387643, 65.15699631827218, 66.00830350603376, 59.404270035879954, 56.59803853716169, 52.180328709738596, 59.14038440159389, 58.678885051182334, 63.797442299979075, 64.17251995631626, 67.25575528826032, 69.22470801217216, 67.55230440412248, 65.50788034711564, 66.51320825304303, 62.41892664773123, 64.26053973606655, 60.59378773825509, 64.37953458513532, 60.56438991001674, 65.0946501323155, 62.14764813014439, 62.510802677699495, 51.15704665865217, 47.63532093593052, 48.892705168042866, 48.52891833441598, 43.57189975466047, 45.53958790642874, 47.49137510572161, 46.52828877312796, 45.24147891998291, 49.96697310038975, 52.16007123674665, 50.10507549558367, 46.10609885624477, 48.1974128314427, 45.24413660594395, 45.06389686039516, 47.00531039919172, 48.341858931950156, 41.82302079881941, 42.077470779418945, 45.33711392538888, 47.95329829624721, 50.395360810416086, 53.63295384815761, 48.50774369921003, 44.425416469573975, 43.03501244953701, 49.402470179966514, 50.32001454489571, 50.149363313402446, 48.30544689723423, 43.831765856061665, 48.794447217668804, 47.599711418151855, 43.45836271558489, 49.951832975660054, 51.58642796107701, 51.2997522354126, 52.29980298451015, 50.986419745853965, 54.939659867967876, 54.03678315026419, 59.27344240461077, 53.18551070349557, 47.46678195680891, 57.355510302952354, 54.74012844903128, 55.47444534301758, 52.16947214944022, 51.89495229721069, 50.661799907684326, 52.055591174534385, 46.45618036815098, 45.49969482421875, 46.23161806379046, 33.795509883335654, 35.443372453962056, 39.98215116773333, 31.654095922197612, 35.831571783338276, 43.707716192517964, 42.036643164498464, 46.26443440573556, 51.300700664520264, 52.23363528932844, 53.837731157030376, 48.67594569069998, 42.39981855664934, 39.79748541968209, 43.25348465783255, 44.43687057495117, 45.08003057752337, 46.10516779763358, 47.06977578571865, 45.43018157141549, 51.67782456534249, 54.54773283004761, 51.17945112500872, 46.33970424107143, 42.20053032466343, 45.302775927952354, 44.51922409875052, 41.90194886071341, 45.370812688555034, 47.34848887579781, 49.519248553684776, 53.401217528751914, 56.43630879265921, 59.64292676108224, 62.16287858145577, 60.38423701695034, 61.49214812687465, 60.660108293805806, 62.122210775102886, 61.65561144692557, 64.36908449445451, 63.55968884059361, 66.6920131955828, 65.75099086761475, 65.8773021697998, 63.079339027404785, 63.23046929495675, 57.28574691499983, 60.40641566685268, 60.66215106419155, 62.77257605961391, 62.933558872767854, 65.88047054835728, 63.764813559395925, 63.05520098549979, 65.07782159532819, 79.43664918627057, 71.72347477504185, 87.04769202641079, 5.435389459133148, 0.28446915692516733, 76.00083446502686, 68.08865669795445, 60.522936957223074, 55.71271991729736, 78.40439006260463, 57.077717849186485, 68.35104846954346, 2.0595893689564297, 0.2781963178089687, 0.0910776588799698, 0.22091003533984932, 0.1925643706428153, 0.11071773964379515, 0.16054986709994928, 0.16302599066070148], [0.07683660662067787, 0.15102920654628957, 0.1577967248324837, 0.039612260314502885, 0.07697042051170554, 0.02975827961095742, 0.05106776347383857, 0.03235277021303773, 0.17746577225625515, 36.047827516283306, 43.955829416002544, 37.67241014753069, 26.343174321310862, 49.37664719990322, 51.929811409541536, 73.08808708190918, 6.277654869215829, 0.1260963694325515, 0.07702196203172207, 15.200442041669573, 85.9418306350708, 64.01054355076381, 73.08865683419364, 58.03576673780169, 55.82714285169329, 52.697952134268625, 50.77988454273769, 51.75220503125872, 54.75132199696132, 56.67710903712681, 58.09852286747524, 57.78411340713501, 62.020044463021414, 63.246109689985005, 62.81403596060616, 61.50875432150704, 65.63189874376569, 61.13070283617292, 60.188881465366904, 59.10018212454659, 61.12548473903111, 59.84013748168945, 58.7228740964617, 56.117042541503906, 59.63638850620815, 49.566576208387104, 44.31524930681501, 43.69263860157558, 45.33074937547956, 40.10210486820766, 39.576789787837434, 40.33531420571463, 42.403876304626465, 37.35081277574812, 43.36959947858538, 43.24004684175764, 41.198787689208984, 44.23497329439436, 41.43276480266026, 41.44918687002999, 40.88324914659773, 39.6167106628418, 38.54656648635864, 35.41000025612967, 36.15089014598301, 42.52930171149117, 41.07450526101248, 45.760040351322715, 50.887248107365195, 46.116305759974885, 45.515324796949116, 42.69292484010969, 48.66781282424927, 51.085737296513145, 47.85912241254534, 50.49931975773403, 49.955657958984375, 39.71018130438668, 40.289157322474885, 41.90970305034092, 47.209333828517366, 47.27607822418213, 47.18525832039969, 46.120808192661826, 47.49869850703648, 47.822647844042095, 47.59009163720267, 50.02572011947632, 49.264635290418354, 46.750311510903494, 48.973550932747976, 48.116740771702354, 48.88181734085083, 46.70946305138724, 47.5101317678179, 46.395849159785676, 46.06294706889561, 46.756151471819194, 41.06202629634312, 38.00176518304007, 37.88926689965384, 34.707405362810405, 36.94410344532558, 37.7499555179051, 31.709288937704905, 26.714791774749756, 37.83914606911795, 42.3555064201355, 43.11616046088082, 40.62210457665579, 46.00303622654506, 42.38087429319109, 35.98043346405029, 37.19309214183262, 35.63605989728655, 35.77018097468785, 38.506197452545166, 38.14304985318865, 42.87764269965035, 41.34428644180298, 45.077612604413716, 45.431963784354075, 42.61329501015799, 40.95776857648577, 38.1464718409947, 39.53859554018293, 37.599113600594656, 38.71034247534615, 39.56405373982021, 41.257451329912456, 44.87175832475935, 49.148919991084504, 52.561854294368196, 55.41941213607788, 55.414089815957205, 56.53959723881313, 55.85753427233015, 55.98739610399519, 57.773208209446494, 58.766480990818565, 57.4025878225054, 60.088862146650044, 61.76377405439104, 63.329974446977886, 61.88346372331892, 62.49777480534145, 61.495434624808176, 62.94716344560896, 64.39154802049909, 62.25565092904227, 64.44135965619768, 64.52856649671281, 66.82616901397705, 66.67247486114502, 64.93380628313336, 61.320284434727256, 67.90980311802456, 63.88715049198696, 78.64916120256696, 3.8109236444745744, 0.2164166271686554, 62.01931490216936, 60.08775738307408, 43.115958963121685, 35.035784176417756, 34.34464338847569, 40.44885124479021, 54.33039665222168, 1.0321939843041557, 0.11169723208461489, 0.020810382340901663, 0.03167854389175773, 0.04691221824448023, 0.034884252053286345, 0.054293206826384575, 0.05978965599622045, 0.07788085165832724, 0.13722868636250496, 0.06562176626175642, 0.040111268537917306, 0.0463633139484695, 0.02528184838593006, 0.04568071450505938, 0.05443722249141761, 0.09078121371567249, 48.536516189575195, 48.66190685544695, 43.84678438731602, 41.64754751750401, 54.03842639923096, 57.690792151859824, 79.63693795885358, 6.741412384169442, 0.14274786306279047, 0.08625370237444129, 17.43290867124285, 89.44973291669572, 67.2301025390625, 78.06275408608573, 60.85554027557373, 61.265247753688264, 55.89248718534197, 52.61549438749041, 55.949629170554026, 58.465749059404644, 58.93414797101702, 59.96598325456892, 62.07114846365792, 64.739791733878, 65.34085260118756, 65.36166940416608, 63.11008480616978, 68.62343869890485, 62.76587799617222, 63.585445812770296, 60.90444169725691, 62.35448905399868, 62.007044383457725, 61.24243681771414, 58.11127628598894, 62.12809589930943, 51.49999584470476, 47.436654567718506, 45.82565219061715, 46.248168672834126, 42.4969995362418, 42.84803295135498, 42.78904274531773, 43.875789642333984, 42.49151740755354, 44.412878445216585, 46.116177218300955, 44.4018759727478, 46.75935806546892, 43.682935442243306, 42.52649811335972, 41.67643812724522, 42.13016244343349, 40.66807038443429, 37.95160961151123, 38.72369343893868, 43.32107325962612, 41.30462612424578, 47.941010407039094, 51.87095321927752, 48.21911552974156, 45.62533562523978, 46.618427753448486, 52.819625513894216, 53.28269863128662, 50.907588958740234, 53.31163093021938, 51.08683163779122, 43.220765590667725, 42.963612760816304, 43.723759583064485, 49.90724638530186, 47.88354533059256, 48.11544145856585, 48.816796098436626, 49.71703944887434, 49.908639499119346, 50.9707168170384, 52.62596879686628, 49.454550402505056, 48.57605491365705, 51.308187348502024, 51.20051458903721, 50.27610192980085, 48.770284857068745, 49.84450762612479, 47.60169512884957, 49.27867759977068, 46.66420248576573, 42.121032510484966, 39.20649249213082, 38.36826181411743, 38.59281022208077, 40.86248098100935, 40.747877393450054, 32.79548692703247, 28.060173204966954, 43.395116737910676, 45.09380538122994, 43.00678539276123, 43.91360868726458, 49.27697876521519, 46.03119380133492, 38.00649343218122, 37.846233231680735, 37.11469561713082, 37.13011366980416, 40.44781943729946, 41.23394904817854, 42.123502595084055, 43.46743358884539, 47.2091566494533, 47.52135310854231, 45.15006841932024, 41.639741216387065, 41.738023485456196, 41.82182223456246, 39.92489801134382, 42.11871876035418, 42.47365011487688, 44.45153474807739, 47.789755071912495, 51.48409489222935, 54.629818848201204, 57.45169421604702, 59.1669682094029, 59.67638233729771, 58.89644009726388, 60.136172430855886, 60.835536411830354, 62.09444577353341, 61.64611325945173, 63.00431932721819, 64.00971671513149, 64.28820746285575, 66.14456462860107, 64.88762160709926, 65.08468641553605, 65.47880908421108, 67.66254452296666, 65.28959574018205, 70.01301588330949, 67.30952739715576, 68.47066170828683, 69.58515971047538, 70.57267938341413, 64.60080691746303, 73.17643342699323, 65.63645676204136, 84.74211992536272, 4.0188945191247125, 0.4359350007559572, 68.71277168818882, 68.47182205745152, 51.54039961951119, 43.564777851104736, 39.396831444331575, 41.89822462626866, 66.82388305664062, 1.5678006495748247, 0.09203505822058235, 0.031007784884423018, 0.034210517669894865, 0.026906288361975124, 0.02513737470975944, 0.07147442256765706, 0.03833088425121137, 0.2015578501990863, 0.2506202475300857, 0.12751935236155987, 0.15970286540687084, 0.12996073492935725, 0.12674202264419623, 0.1290313455143145, 0.10128292734069483, 0.5928290433117321, 60.13548455919538, 58.42026615142822, 47.330979415348594, 35.41968951906477, 65.4771067755563, 61.3914270401001, 88.06934125082833, 7.0753501909119745, 0.29110346521650043, 0.15413490203874453, 18.9572149004255, 91.84905011313302, 69.11894948141915, 80.4031366620745, 63.84163979121617, 63.14989798409598, 58.52558694566999, 54.04209157398769, 57.67372390202114, 60.57809175763811, 61.02415221078055, 61.92341586521694, 62.61650562286377, 64.91155815124512, 67.8878676550729, 69.21133272988456, 65.82441943032401, 68.66007655007499, 62.568625586373464, 64.61357075827462, 61.09475285666329, 65.5743329184396, 64.173798424857, 62.61424051012312, 58.57506506783621, 65.362808908735, 55.07928739275251, 49.65214327403477, 46.33650459562029, 50.33039515359061, 45.729933806828086, 45.94479295185634, 45.386824812207905, 46.37263870239258, 43.91799994877407, 48.63329069955008, 48.516731194087434, 47.23463569368635, 49.59973996026175, 48.543985503060476, 45.941329274858745, 45.77037579672677, 46.33613634109497, 44.58777502604893, 40.17780549185616, 40.19402606146676, 45.161887305123464, 45.18385403496878, 49.87357194083077, 55.36425733566284, 49.79880237579346, 48.72007022585188, 49.441772665296284, 54.557404722486226, 54.9617794581822, 54.022483757564, 56.38211631774902, 56.12702710287911, 44.98858880996704, 44.35859216962542, 46.57965680531093, 52.62008367265974, 49.623481954847065, 51.39632177352905, 52.217887197222026, 53.72098752430507, 53.418164185115266, 51.62747097015381, 54.891800676073345, 52.19768530981881, 51.53141212463379, 53.39656570979527, 53.704791273389546, 53.22234310422625, 54.2758845601763, 53.38740103585379, 50.068875380924766, 51.91437946047102, 51.62491750717163, 44.23511225836617, 41.524345534188406, 37.97324282782418, 39.89374923706055, 42.47685670852661, 43.99295016697475, 36.798490047454834, 32.8472649029323, 40.38048791885376, 42.700929164886475, 47.24371351514544, 46.66939279011318, 51.74106706891741, 48.734491212027415, 42.068799427577424, 41.436089515686035, 38.65885632378714, 38.76059532165527, 42.855891363961355, 43.069687434605186, 45.80079501015799, 46.520756925855366, 49.04319967542376, 50.71236889702933, 47.824141706739155, 45.881209986550466, 43.056892326899934, 43.73408808026995, 43.70515578133719, 44.196313517434255, 44.62664672306606, 46.50052029745919, 49.39921842302595, 53.74781799316406, 56.56607334954398, 59.89439596448626, 62.53954042707171, 60.505719321114675, 59.94096973964146, 60.82544762747628, 63.888157980782644, 63.14860561915806, 64.55779756818498, 65.92036015646798, 66.19712775094169, 66.52772303989956, 68.59377683912004, 66.97097642081124, 67.54042993273053, 68.6268641608102, 71.96912833622524, 67.5222395488194, 71.81260626656669, 69.1916971206665, 72.6129206248692, 70.51538453783307, 72.69495800563267, 66.01013783046177, 77.87820298331124, 67.78721605028424, 87.01709910801479, 5.350653571741922, 0.4876836910843849, 76.96370192936489, 74.55617196219308, 62.29410226004464, 50.07450689588274, 51.77090958186558, 57.61117969240461, 78.44619042532784, 2.8969647671495165, 0.28980287643415586, 0.12733717927975313, 0.11666227637657098, 0.13704538691256726, 0.2545598218483584, 0.12642488894718035, 0.15277085666145596], [0.016409487330487797, 0.09303249791264534, 0.10971177755189793, 0.17049482917147024, 0.09661065733858518, 0.13425417883055552, 0.08607781252690724, 0.09506452030369214, 0.22399951384535857, 36.94336346217564, 46.52460970197405, 28.65815428325108, 21.35682044710432, 45.00738716125488, 41.99317176001412, 77.71109185900006, 8.237807699612208, 0.300663345094238, 0.022718816363651837, 20.42222693988255, 83.78644384656633, 63.07799802507673, 71.04053633553642, 57.384102140154155, 58.085519313812256, 52.82016052518572, 54.7810811315264, 51.781880787440706, 54.85405458722796, 56.19109991618565, 58.9073418208531, 61.358763558524, 67.03166893550328, 67.03014033181327, 66.64295891353062, 63.12710789271763, 60.24843447549002, 57.16358021327427, 60.98002420152937, 59.221532412937705, 59.256391525268555, 56.21998357772827, 59.17804363795689, 56.44470221655709, 58.36006695883614, 46.4135114806039, 43.313319069998606, 42.5634104183742, 43.865266595567974, 42.45578629629952, 39.152088097163606, 39.38758339200701, 40.53746509552002, 38.69108206885201, 38.06679684775216, 39.39879083633423, 41.58492340360369, 42.678865160260884, 42.688839299338206, 37.887324878147666, 41.24683100836617, 35.61639302117484, 34.14924962180001, 32.84267214366368, 36.09576661246163, 42.600326197487966, 46.14365039552961, 45.826413018362864, 48.424584184374126, 45.18828698566982, 45.61868272508894, 47.85471378053938, 49.40298434666225, 47.549698284694124, 51.11631284441267, 46.14161804744175, 43.25551005772182, 43.53727340698242, 40.435837268829346, 42.25482702255249, 47.66707072939192, 46.14407076154436, 46.12999371119908, 46.50940009525844, 43.829406942640034, 48.738041741507395, 49.03727286202567, 47.490624700273784, 49.73732124056135, 46.99787582669939, 47.66186305454799, 46.455086026872905, 44.492841788700645, 41.58278335843767, 48.56076192855835, 46.71101597377232, 46.55251714161464, 46.54931402206421, 40.2029128074646, 41.48294121878487, 40.5063475881304, 41.47785513741629, 40.370819500514436, 43.590639046260286, 48.111408029283794, 36.774772371564595, 26.576413188661846, 33.66738510131836, 46.702487060001914, 43.64878504616873, 40.29445879799979, 40.642403738839285, 36.792094230651855, 33.44808258329119, 36.93288557870047, 35.559796469552175, 37.61749158586775, 37.50367661884853, 40.97230420793806, 39.74477638517107, 41.64413595199585, 43.04561540058681, 41.80717543193272, 38.26387555258614, 37.889888763427734, 39.167898723057334, 38.493075779506135, 38.46771138054984, 40.73903581074306, 43.533587387629915, 42.86166531699044, 51.657462869371685, 54.760834080832346, 54.03691169193813, 55.49912534441267, 55.6767213003976, 58.45830059051514, 57.29449817112514, 59.14054421016148, 59.09722914014544, 58.56175231933594, 59.93431336539132, 60.94441468375069, 63.174480710710796, 63.70458657400948, 63.54588276999337, 63.714723995753694, 64.31179659707206, 64.50561659676688, 65.23346819196428, 63.778980936322895, 66.84862559182304, 66.97836235591343, 65.32017476218087, 67.20802811213902, 65.43933636801583, 71.00236988067627, 66.31797776903424, 78.06060709272111, 2.674436982188906, 0.8302629941276142, 63.40015820094517, 54.870817116328645, 40.378056049346924, 36.389143875667024, 24.866708176476614, 40.12842117037092, 55.94239956992013, 0.7477900481649807, 0.14604149918471063, 0.02567966328933835, 0.08267191957150187, 0.05698284160877977, 0.03938635225806918, 0.1545592171273061, 0.10969257501087018, 0.042755678961319585, 0.028802223769681792, 0.04968804393761924, 0.14797992445528507, 0.09099143743515015, 0.0607563919786896, 0.024084858330232755, 0.014958353679893273, 0.20748736416654928, 44.37627533503941, 52.51447800227574, 25.03075861930847, 26.513872453144618, 56.86779539925711, 47.236612456185476, 83.92255210876465, 9.150488325527736, 0.30486673382776125, 0.01104773923621646, 23.229731695992605, 85.69616317749023, 67.0462532043457, 74.22256115504673, 59.23588044302804, 60.62649290902274, 55.90820401055472, 58.08883360454014, 54.82082135336739, 58.698326110839844, 58.87529672895159, 61.77546092442104, 64.2427453994751, 68.60608209882463, 70.80892508370536, 69.57435526166643, 64.46990980420793, 60.17308126177107, 58.17651292255947, 63.18767533983503, 60.830075127737864, 61.704068183898926, 57.60785150527954, 60.2277774810791, 57.83336918694632, 59.269655636378694, 49.13484294073922, 45.824227809906006, 44.713714599609375, 47.234270913260325, 44.76853936059134, 43.04805769239153, 42.494241101401194, 42.01674004963466, 42.153883593423025, 41.091469287872314, 41.27573551450457, 42.69839654650007, 44.727117674691335, 45.17858730043684, 40.12341499328613, 41.6646921975272, 40.05782747268677, 38.10667603356497, 35.277626650674, 38.31261369160244, 44.68635606765747, 49.29284150259835, 49.42341205051967, 50.653514180864605, 46.513138226100374, 47.263161523001536, 49.27634300504412, 52.36921896253313, 49.769929136548726, 52.73548282895769, 48.310612882886616, 45.36629635947091, 46.893989835466655, 41.94799109867641, 44.89418363571167, 50.65615102222988, 49.13228600365775, 47.877201625279014, 48.35445601599557, 47.14831822259085, 48.663445881434846, 51.3018992287772, 49.34058952331543, 52.85801431110927, 50.17835814612252, 49.99245909282139, 49.70846537181309, 46.96527140481131, 45.70453119277954, 51.36442606789725, 48.50195237568447, 46.22172730309622, 46.87445150102888, 44.45078434262957, 43.94491727011544, 44.75303445543562, 44.724373136247905, 45.444946493421284, 47.64731352669852, 50.774982588631765, 39.525459970746724, 29.0701425075531, 38.660308497292654, 46.78892265047346, 42.84378065381731, 43.744468688964844, 41.62217269624983, 41.64239195414952, 34.363445213862825, 37.03286668232509, 37.00956242425101, 38.76724822180611, 39.20996311732701, 42.855530057634624, 41.51984657560076, 44.65960897718157, 46.11372797829764, 44.291625431605745, 39.22383519581386, 40.307302543095176, 40.094750199999126, 39.83704151426043, 41.59356696265084, 44.03774867738996, 45.07623338699341, 47.36852053233555, 53.67821441377912, 56.87359367098127, 56.19491795131138, 57.46386398587908, 59.3829460144043, 59.3655685697283, 60.23378767286028, 61.55650234222412, 61.98146806444441, 59.72172628130232, 61.04004274095808, 64.53529930114746, 66.02525016239711, 66.00967924935478, 65.79871109553746, 65.94410909925188, 66.664797101702, 66.34704208374023, 66.6641092300415, 67.56414413452148, 68.82603427342006, 71.46674578530448, 67.50648798261369, 69.85737623487199, 68.51266356876918, 76.97103227887834, 70.80945314679826, 83.92061356135777, 2.7993938199111392, 0.9805613777467183, 73.23167160579136, 60.0984992980957, 48.929989201681956, 43.79819563456944, 28.749820130211965, 43.12464421136038, 64.36481135232108, 1.531160301395825, 0.21701346657105855, 0.03134665884343641, 0.06498281697609595, 0.007424448749848774, 0.07166936567851476, 0.07159375652138676, 0.09698948343949658, 0.09167215733655862, 0.14813807739743165, 0.1668869499117136, 0.3225086714540209, 0.20213921900306428, 0.19925714151135512, 0.15611573574798449, 0.13983517007103988, 0.3211281512464796, 58.734901428222656, 61.96186719621931, 37.962493964603965, 25.788817507880076, 67.970947265625, 50.54889862877982, 91.32386357443673, 10.436946426119123, 0.4970282039472035, 0.10917127691209316, 23.701662029538834, 89.13350650242397, 67.71419743129185, 77.0255547932216, 60.4505158833095, 64.10005719321114, 58.691072191510884, 61.39759704044887, 57.4024384362357, 61.463146345955984, 61.62600517272949, 63.53030490875244, 65.53998797280448, 72.81283419472831, 71.29637595585415, 69.96871416909354, 64.97052751268659, 62.44764355250767, 60.17550618307931, 64.54752118246896, 62.50960758754185, 63.857391357421875, 59.75680078778948, 63.16462121691023, 60.22560269492013, 63.01943860735212, 50.61092519760132, 47.29786777496338, 45.89610692432949, 48.342261927468435, 48.59165709359305, 45.07511125292097, 45.98849017279488, 44.028608322143555, 43.181841782161165, 43.84919193812779, 44.94935580662319, 45.426742213112966, 45.98811149597168, 50.28927918842861, 43.93181644167219, 45.34884595870972, 42.328106198992046, 40.575037479400635, 39.27413667951311, 41.22416251046317, 48.37405341012137, 50.37571825299944, 51.73206567764282, 52.96569054467337, 49.822228227342876, 51.13958930969238, 52.59601511274065, 55.54155451910836, 52.201840332576204, 53.68313373838152, 50.62752444403512, 48.27492346082415, 49.021080085209434, 45.89043024608067, 47.965700830732075, 53.96679047175816, 52.25601543698992, 51.38988774163382, 52.21363142558506, 49.08091449737549, 53.64798627580915, 52.88336133956909, 51.27156686782837, 52.838677474430625, 51.439549991062705, 53.391872201647075, 53.06807919910976, 49.37152637754168, 46.858171871730256, 54.632754462105886, 51.58132103511265, 49.80409690311977, 50.061861174447195, 47.67030511583601, 44.96430138179234, 45.784643922533306, 45.75774049758911, 46.69674784796578, 49.9987576348441, 53.50177533285958, 41.62043564660208, 34.88058226449149, 40.19746541976929, 43.722164971487864, 41.356914792742046, 45.028381143297466, 45.384834153311594, 43.883609839848106, 39.040722370147705, 42.72498035430908, 40.659100260053364, 41.04632684162685, 40.89984144483294, 45.308018343789236, 43.603399412972585, 47.343645981379915, 49.39099175589425, 46.294996057237896, 41.899450983319966, 41.781018938337056, 44.02447761808123, 43.79338748114449, 43.63731357029506, 47.25082499640328, 47.532095023563926, 47.68640756607056, 56.36436019624983, 59.849281311035156, 58.75339753287179, 58.840382031032014, 60.90249620165144, 61.59041649954659, 61.754428727286204, 65.63125256129673, 62.882100514003206, 61.63389137813023, 63.22254834856306, 65.15166704995292, 66.22898524148124, 70.02906622205461, 67.26269653865269, 68.39163984571184, 68.87566525595528, 70.11218057359967, 69.69816521235875, 70.51558603559221, 71.01351479121617, 74.43245233808244, 69.925628389631, 73.78922285352434, 69.74478762490409, 79.84077031271798, 72.79247597285679, 88.24239308493478, 3.89302225623812, 1.177316991346223, 79.00709070478166, 66.04263455527169, 59.781647545950754, 53.3727194922311, 35.940088748931885, 57.19366591317313, 78.22527939932687, 2.7582140181745802, 0.28500403250966755, 0.12733359661485466, 0.1426878941378423, 0.09173989548747029, 0.22566271174166883, 0.21824643255344459, 0.11256186211747782], [0.06987875926175288, 0.08322648624224321, 0.01237069338094443, 0.16931241404797348, 0.048121778161398, 0.19127575121819973, 0.09752475257430758, 0.16765009824718746, 0.11482320220342704, 25.77955208505903, 47.514849594661165, 56.78283977508545, 44.57252720424107, 44.84929479871477, 44.07209014892578, 73.71119458334786, 17.381122010094778, 0.05064309215439217, 0.1378485688141414, 26.51768527712141, 83.96316432952881, 62.35617051805769, 71.78791236877441, 57.632166726248606, 59.14705467224121, 55.808205536433626, 56.422172682625906, 55.30103915078299, 56.74379089900425, 58.293037687029155, 62.83448450905936, 59.24552454267229, 62.99038124084473, 63.505937576293945, 57.463784081595286, 52.84901639393398, 58.680156571524485, 59.02118805476597, 58.73725686754499, 59.01972893306187, 60.62461689540318, 56.299828801836284, 56.79487752914429, 53.380939211164204, 49.06775113514492, 45.37300484521048, 45.14931801387242, 43.84876114981515, 44.27573142732893, 43.928682804107666, 40.02477489198957, 37.34954125540597, 39.402671405247276, 38.15155097416469, 40.0407383782523, 40.92789132254464, 40.91841050556728, 39.25084284373692, 41.60709163120815, 38.41075699669974, 37.086044720241, 35.520539147513254, 33.63324165344238, 30.432203088487896, 37.960822922842844, 44.70242377689907, 47.457096167973106, 48.12768765858242, 47.7304904120309, 42.42839649745396, 48.641965525490896, 45.25396483285086, 47.78745174407959, 48.585504463740754, 45.46548536845616, 45.442604950496126, 45.17285851069859, 41.03939253943307, 40.602382114955354, 44.432847567967, 48.49457686288016, 45.484193393162315, 46.19954865319388, 46.465240819113596, 43.25880002975464, 44.29295948573521, 45.323974881853374, 44.813633169446675, 48.90809890202114, 48.63315173557827, 46.03625903810774, 44.449898447309224, 45.835435254233225, 42.619395528520855, 45.04005759102957, 45.337739263262065, 46.5352578163147, 47.15299088614327, 42.791947092328755, 37.56436218534197, 42.97759601048061, 42.85304955073765, 45.4799793107169, 43.60568537030901, 46.39888899666922, 49.80978747776577, 43.692263398851665, 28.78849032946995, 31.62938117980957, 55.21636840275356, 47.68820367540632, 38.222974981580464, 42.88840545926775, 33.11626788548061, 31.75306953702654, 34.073079994746614, 37.100476128714426, 36.09237241744995, 37.64613553455898, 39.48378814969744, 38.34609358651297, 40.55559989384243, 40.44618313653128, 37.82611819675991, 38.0766841343471, 37.03218228476388, 37.13014146259853, 41.13412775312151, 42.253552028111045, 42.414586952754426, 44.64250946044922, 50.92496640341622, 54.49243559156145, 56.216419151851106, 54.68224648066929, 57.58959858758109, 54.74574954169137, 55.07644557952881, 57.25902761731829, 59.157372747148784, 58.85924639020647, 59.90229606628418, 60.94508865901402, 63.25027860913958, 61.621384620666504, 61.93988309587751, 60.49538734980992, 64.83842141287667, 64.64824226924351, 64.33255086626325, 66.18138313293457, 66.61565249306815, 65.26964051382882, 68.36514636448452, 64.45815345219204, 67.10715416499546, 68.74321174621582, 69.29974160875592, 74.24862384796143, 1.269865802356175, 1.5075616134064538, 64.42416981288365, 52.261483669281006, 40.58546672548567, 38.74391964503697, 28.17266627720424, 28.741937398910522, 58.94393103463309, 1.9406876691750117, 0.14421493719731057, 0.09118929146123783, 0.06463248256061759, 0.02088650718464383, 0.05231592185529215, 0.021652603754773736, 0.09730614216199943, 0.07750560822231428, 0.040573530697396824, 0.03305019564660532, 0.06654789192335946, 0.05224930667983634, 0.23154149843113764, 0.029285052325576544, 0.20787594760102884, 0.23527645372918674, 32.22569990158081, 52.531129360198975, 54.827686173575266, 47.42045136860439, 55.06352193014962, 49.65717029571533, 80.22433171953473, 17.929581539971487, 0.0560158138562526, 0.10904400409864527, 31.20084755761283, 86.72593484606061, 65.6647845676967, 74.52501623971122, 60.22536645616804, 63.18077577863421, 59.101113183157786, 60.98825086866106, 57.180158615112305, 59.467769622802734, 61.790427344185964, 63.67434801374163, 62.53320366995675, 65.6436550957816, 64.02457196371896, 58.19952188219343, 51.11415890284947, 59.89368724822998, 59.156017848423545, 60.54584516797747, 60.126841000148225, 62.153491565159385, 58.5492525100708, 59.48159653799874, 55.86836651393345, 51.85577835355486, 47.122877393450054, 46.44601167951311, 45.05373164585659, 46.40082406997681, 44.280880042484824, 44.05466406685965, 41.253404004233225, 41.807189328329905, 41.16029119491577, 41.93903487069266, 42.968518189021516, 44.3005816595895, 43.592688764844624, 44.68160349982125, 40.96782956804548, 40.134024892534526, 37.838343552180696, 36.28447273799351, 33.012277671269004, 41.64750582831246, 47.443581921713694, 49.045555114746094, 48.983573709215435, 49.584728377205984, 44.964426449366975, 49.87981489726475, 49.22544397626604, 49.836857659476145, 51.813019139426096, 46.347698143550325, 45.87723561695644, 46.003345421382356, 41.750189781188965, 42.667473588671, 46.60411099025181, 49.33937358856201, 47.33741692134312, 47.71217496054513, 45.88032409123012, 45.61068882261004, 46.4848312650408, 46.47944293703352, 47.143614292144775, 50.43112318856375, 50.99964564187186, 48.033581256866455, 45.659916809626985, 47.71403012956892, 44.615373270852224, 46.47374194008963, 48.447367327553884, 50.15334463119507, 47.03004251207624, 44.14315285001482, 39.719304289136616, 44.48162392207554, 46.26614713668823, 46.98353474480765, 47.88287482942854, 49.51105662754604, 52.546908719199045, 47.72865261350359, 32.62238645553589, 35.75865043912615, 51.427185671670095, 46.55952092579433, 42.051890986306326, 44.57722418648856, 36.05186441966465, 33.71736001968384, 35.5506317956107, 37.761048316955566, 38.305133955819265, 42.77217251913888, 41.695660318647114, 42.95347881317139, 42.87510660716465, 43.50775398526873, 40.21621860776629, 41.651702540261404, 38.73093693596976, 40.27440629686628, 42.197087492261616, 45.055503436497276, 43.88910239083426, 47.415490354810444, 53.83174180984497, 56.841868196214946, 58.237924575805664, 57.032818589891704, 59.468422753470286, 57.35041379928589, 56.38373177392142, 59.3312166758946, 61.85767201014927, 61.979348863874165, 61.11281817299979, 63.52508681161063, 63.24825668334961, 63.268934522356304, 63.9806524004255, 62.73886340005057, 66.4746457508632, 67.5513733455113, 66.48763193402971, 68.9965569632394, 71.41075025285993, 69.88623210362026, 70.35869571140834, 68.28009346553257, 68.89850398472377, 72.09348024640764, 73.43084171840123, 75.64523955753872, 1.2403633168765476, 1.951853858573096, 71.1112481525966, 58.27217919485909, 47.604693276541575, 44.934132303510395, 29.155773844037736, 35.55376543317522, 69.433883530753, 3.792657264641353, 0.22334145701357297, 0.05986257136932441, 0.06420246777789933, 0.007186184570725475, 0.05613419107560601, 0.0481006451882422, 0.13005411491862365, 0.14529036091906683, 0.10837331973016262, 0.12838973637138093, 0.2380393940423216, 0.1218345859753234, 0.3302409036883286, 0.18559639954141208, 0.23565298638173512, 0.36144306510686874, 45.08197259902954, 60.042649677821565, 75.8811308997018, 57.574256965092246, 62.79705456324986, 54.88508524213518, 86.74611936296735, 20.192314522606985, 0.1587489673069545, 0.3021093303603785, 30.7152726990836, 89.92082772936139, 68.79605279650006, 76.8822273526873, 62.724188804626465, 65.72161388397217, 61.128972734723774, 62.43882628849575, 58.930791991097585, 59.74269594464983, 62.85175078255789, 67.15518011365617, 64.1092427117484, 65.2070094517299, 64.36426939283098, 59.12560558319092, 50.32136596952166, 61.8398220879691, 62.098406246730256, 61.5009445462908, 63.29003620147705, 64.20804609571184, 59.78441987718855, 63.04382678440639, 56.21998357772827, 53.1276148387364, 49.11485644749233, 47.673150403159006, 45.64234481539045, 48.956229073660715, 46.73170076097761, 46.38903297696795, 43.03748948233468, 43.4176983833313, 43.71749925613403, 44.88091605050223, 46.26441008704049, 46.02001414980207, 45.290449823652, 47.087205341884065, 43.38792535236904, 42.93311364310128, 41.00479745864868, 39.17408956800188, 35.06400081089565, 43.97816440037319, 50.28283126013619, 52.24536732264927, 51.389533383505686, 51.33798122406006, 46.7490747315543, 51.00878599711827, 50.29472310202462, 52.657114097050254, 53.78400421142578, 51.20835910524641, 48.58480269568307, 50.137530531202046, 45.570913859776084, 44.492174761635916, 49.721837180001394, 53.61814028876168, 48.755148206438335, 49.37418406350272, 50.767634868621826, 47.129102979387554, 48.817351954323904, 50.30031292779105, 48.1977915082659, 54.56947374343872, 52.756424699510845, 50.39651768548148, 48.20438534872872, 51.77501596723284, 47.71771962302071, 50.18269729614258, 49.27293143953596, 52.47629765101841, 49.923157760075156, 47.64205026626587, 42.96660396030971, 47.15799011502947, 47.829679421016145, 50.79843623297555, 49.452945368630544, 51.238437856946675, 53.82640906742641, 48.04646669115339, 37.217337880815776, 42.36650194440569, 50.78978225163051, 44.885234355926514, 43.95987674168178, 45.77231434413365, 38.365753514426096, 37.23831449236189, 40.562131200517925, 42.02613401412964, 40.45260674612862, 44.8873153414045, 44.133258615221294, 44.2566898890904, 45.04822172437395, 45.70262391226632, 42.80909177235195, 44.342989989689414, 41.11663566316877, 42.28856747491019, 44.08690023422241, 46.66148574011666, 45.49444546018328, 50.14802231107439, 55.652934142521445, 58.77249118259975, 59.706176212855745, 59.54829229627337, 61.47718170710972, 59.728042193821494, 58.17128440311977, 62.2670042855399, 63.57154941558838, 65.24698938642229, 63.53090245383126, 66.41509274074009, 66.54724747794015, 65.61427811213902, 66.36093848092216, 66.71761730739048, 68.74509470803397, 71.12406063079834, 68.89350128173828, 72.6887115750994, 73.40193721226284, 72.96821675981793, 73.89204229627336, 73.41689668382917, 73.15005806514195, 78.119110924857, 74.98461178370884, 82.5235948562622, 2.064224034547806, 1.7893719715731484, 81.12974452972412, 62.47022519792829, 57.88796465737479, 53.89590842383248, 43.4405961717878, 44.060344219207764, 83.26424503326416, 4.755433533872877, 0.505134146128382, 0.17561614007822104, 0.12098580652049609, 0.11836938905928816, 0.18873892591467925, 0.10772563091346196, 0.2606350987085274], [0.01912134243840618, 0.1411872325198991, 0.049480849876999855, 0.12545298252786907, 0.034882477684212584, 0.1375660811151777, 0.06738196752433266, 0.2320630204464708, 0.2737993023225239, 18.894496985844203, 50.591466767447336, 28.24739589009966, 30.47372899736677, 47.81054408209664, 46.5888214792524, 69.14521367209298, 30.995028018951416, 0.09330557433090039, 0.03950164553576282, 35.8021878514971, 81.06254155295235, 62.15167113712856, 68.9677983692714, 58.616629191807334, 60.9569422858102, 60.78099305289132, 65.05193955557687, 60.91717079707554, 61.21301119668143, 58.93737193516323, 62.699397632053916, 64.93229157584054, 106.86068875449044, 64.66568919590541, 54.95794752665928, 59.304660660879954, 62.4242559160505, 57.81034633091518, 57.62461403438023, 57.18087427956717, 53.664554255349294, 53.004093238285606, 54.402081217084614, 50.28928961072649, 51.96737684522356, 49.10481630052839, 44.50389984675816, 41.91115174974714, 44.45755188805716, 42.95776585170201, 41.84929541179112, 38.883838994162424, 38.7971636908395, 36.94305426733834, 41.10922193527222, 40.32625028065273, 42.764206409454346, 40.45901993342808, 39.44282504490444, 38.23816721779959, 39.614212785448345, 33.91797535760062, 31.998830795288086, 31.09054490498134, 39.01044906888689, 43.920483929770334, 47.02558871677944, 44.214111328125, 46.23249353681292, 43.04964188167027, 44.71540648596627, 48.57921634401594, 45.3613874571664, 43.469198431287495, 43.71338939666748, 39.463023458208355, 43.91742672239031, 42.68310008730207, 42.00250319072178, 41.07719768796648, 43.1531457219805, 43.5186904498509, 45.519618783678325, 42.47685670852661, 42.30811970574515, 41.70794473375593, 42.53046553475516, 42.55999190466744, 47.69518314089094, 47.27914932795933, 43.79471806117466, 41.37705067225865, 42.458054883139475, 41.238493170057026, 42.78923034667969, 42.861800806862966, 44.52473054613386, 43.41220235824585, 41.04302297319685, 37.21715027945382, 39.89341919762747, 44.04170567648751, 43.09703554425921, 43.721032415117534, 45.25924893787929, 42.79805455889021, 46.53835323878697, 47.26096936634609, 32.24942452566964, 26.42796666281564, 45.88270384924752, 44.62071990966797, 43.3376864024571, 39.45475857598441, 30.282521520342144, 31.88977187020438, 32.988330704825266, 37.94588082177298, 38.839429582868306, 39.51999521255493, 41.04562854766846, 38.30809736251831, 39.7618168422154, 36.32154485157558, 36.64245435169765, 38.10886819022042, 38.094648701804026, 40.85064819880894, 41.3822340284075, 41.70559624263218, 46.50861842291695, 53.69850662776402, 54.09703098024641, 55.78635345186506, 53.72761263166155, 55.30112600326538, 61.00518362862723, 63.06650570460728, 59.418472153799875, 57.16268042155674, 56.131216866629465, 56.53282969338553, 57.293779032570974, 61.58551801953997, 64.29972062792096, 63.38946492331368, 61.30085727146694, 62.075595310756135, 60.86806092943464, 61.60700879778181, 63.30241094316755, 65.49195507594517, 65.54687363760812, 64.13358919961112, 63.11597687857491, 69.16965048653739, 69.10272543770927, 73.87066963740757, 56.15264858518328, 0.9110716836793082, 3.5274538610662733, 64.92482921055385, 49.47449173246111, 32.657214300973074, 38.45630243846348, 26.17104833466666, 35.72949579783848, 54.92558281762259, 1.843248303447451, 0.3142189548483917, 0.028841456664460044, 0.029339345305093696, 0.03941202463049974, 0.07554133076752935, 0.07898936074759279, 0.05382501087816698, 0.05111231608316302, 0.08095130404191357, 0.0425774990580976, 0.026554710531075085, 0.04913394545604076, 0.13544595773730958, 0.061144507224006314, 0.18093577320022242, 0.3140454670148236, 26.754577159881592, 60.04255935123989, 27.929672139031545, 28.104261262076243, 55.04822199685233, 53.9250283241272, 76.7392612184797, 34.96864373343331, 0.10439778984125171, 0.2065467517822981, 38.61940792628697, 83.51928561074394, 66.01201384408134, 72.96511786324638, 60.55348818642752, 65.57011536189488, 63.87173938751221, 67.94752488817487, 63.11034883771624, 64.13299860273088, 62.30364213671003, 65.43109580448696, 66.67645617893764, 92.75883334023612, 63.468361718314036, 57.94755935668945, 63.16465595790318, 65.8658445903233, 59.099980626787456, 59.760080337524414, 57.186273029872346, 57.19619158336094, 56.43661451339722, 55.541422503335134, 53.243521213531494, 55.439704350062776, 51.70527342387608, 47.823780400412424, 44.63156952176775, 45.95109149387905, 44.846466881888254, 44.30171421595982, 40.83794341768537, 42.00687708173479, 40.40383734021868, 41.74954012462071, 42.335547719682964, 42.631829329899375, 41.44437524250576, 42.153463227408274, 39.94184466770717, 40.47752298627581, 36.48937164034162, 33.91233342034476, 33.68798998423985, 40.84521818161011, 45.67986856188093, 49.355250222342356, 45.76753398350307, 48.17019326346261, 43.877717767442974, 45.09835992540632, 50.00532715661185, 48.88046244212559, 47.56713826315743, 45.491318770817344, 43.37656157357352, 44.37802628108433, 45.59433971132551, 44.26208169119698, 44.4457607950483, 43.91928536551339, 44.82305840083531, 46.503278732299805, 45.124457359313965, 44.0506341116769, 43.79564217158726, 45.01798663820539, 45.38026571273804, 49.54016957964216, 48.485151631491526, 44.66741180419922, 43.452355997903005, 43.35532440458025, 44.755431583949495, 45.894852774483816, 45.2274991444179, 45.75195959636143, 45.95671258653913, 43.61795241492135, 39.029813698359895, 43.62954201017107, 45.24437631879534, 45.829379899161204, 45.63141877310616, 48.13261045728411, 46.28156866346087, 49.159005301339285, 47.291972228458945, 35.99156100409371, 26.552910906927927, 42.11369868687221, 46.448106561388286, 44.827335017068044, 42.31201764515468, 34.78541278839111, 35.19228540148054, 34.18872581209455, 38.46498768670218, 40.80726017270769, 41.848600591932026, 41.40023333685738, 40.417407172066824, 42.28245653424944, 39.479178019932334, 38.894018105098176, 40.39416544778006, 41.2471957887922, 44.37004974910191, 43.54352331161499, 43.77260889325823, 48.71734653200422, 56.08410460608346, 56.07666655949184, 57.82366950171334, 56.849886417388916, 57.16631085532052, 64.12954534803117, 65.81434454236711, 61.51791204724993, 59.30629348754883, 59.16840648651123, 57.30907201766968, 59.000697817121235, 62.28021975925991, 65.4774750300816, 65.65728051321847, 64.05267742701939, 64.38925511496407, 62.447073800223215, 65.02004732404436, 67.27910818372453, 68.15049566541398, 67.87358910696847, 68.99066489083427, 68.65143299102783, 72.88770798274449, 73.87999411991665, 76.54935305459159, 53.42253460202898, 1.1498986397470747, 3.969726026058197, 72.76227910178048, 54.31105286734444, 39.333700111934114, 44.31352267946516, 32.35950483594622, 42.71849768502371, 65.17892483302525, 2.7759779563971927, 0.2453097610601357, 0.09752051851579122, 0.05427561580602612, 0.0014277732802189089, 0.02316101424262992, 0.018864544075248495, 0.03989357075520924, 0.10546904735799346, 0.33099950583917753, 0.14119207725993224, 0.21362281351217202, 0.1613705823464053, 0.25032074217285427, 0.19865255323903902, 0.2542089378195149, 0.5613126116139548, 33.65569823128836, 69.73741558619908, 37.687532901763916, 39.99164588110787, 64.945923941476, 58.585209437779014, 81.98038469042096, 38.26246159417288, 0.20267762296966144, 0.31014475918241907, 40.3998247555324, 86.62460926600865, 67.05454240526471, 74.9413036618914, 63.75818497794015, 67.64629963466099, 66.35477542877197, 69.11585058484758, 63.52125140598842, 65.31524848937988, 62.475964409964426, 66.42718955448696, 68.62269524165562, 88.48186274937221, 64.02456501552037, 57.55029610225132, 63.19731249128069, 66.8906830378941, 60.47040162767683, 62.13904626028878, 59.51553848811558, 58.973162106105256, 57.38123253413609, 56.45759807314192, 54.46324620928083, 56.401727608272004, 53.35651281901768, 50.65741212027413, 45.707980973379954, 47.372786726270405, 47.53816427503313, 47.256685801914756, 43.39242083685738, 45.08850390570504, 41.670045784541536, 44.923084667750764, 45.2745349747794, 47.845622062683105, 44.16131544113159, 45.74480642591204, 42.978919642312185, 44.43791627883911, 41.623218400137766, 36.132995060511995, 35.79663624082293, 43.57009322302682, 47.75074788502285, 50.48414489201137, 49.20522124426705, 51.81646197182791, 46.741702692849294, 48.31968028204781, 52.92582525525774, 49.42638240541731, 48.029113565172466, 48.785324232918875, 44.98226247514997, 47.57552126475743, 47.85798985617501, 45.78908034733364, 46.97072574070522, 48.768398421151296, 48.24961117335728, 49.61363983154297, 46.37390327453613, 48.02888080051967, 46.76346097673689, 48.321809904915945, 48.82875394821167, 50.32850871767317, 50.453868116651265, 49.62146002905709, 45.70191519601004, 46.12593943732125, 47.520286560058594, 48.86361306054251, 47.874735014779226, 47.76523835318429, 48.73285491125924, 45.873063223702566, 40.2650922366551, 46.21047469547817, 49.1692156791687, 49.86754437855312, 49.07685327529907, 50.73907777241298, 48.43574299131121, 51.788894993918284, 48.1283929007394, 38.91875369208199, 36.8935900415693, 50.64804942267281, 47.94212906701224, 48.81940862110683, 45.11501475742885, 37.77641078404018, 37.448181356702534, 37.450015681130544, 41.9406989642552, 45.07186644417899, 44.870247091565815, 45.73181676864624, 42.30547244208199, 45.42593969617571, 40.89048569543021, 42.93614305768694, 43.7959200995309, 43.35385833467756, 45.828025000435964, 45.96033607210432, 44.27376161302839, 51.930534022195, 59.06728935241699, 57.94978972843715, 59.64063385554722, 58.18748760223389, 57.514763014657156, 61.05491188594273, 63.50540951320103, 64.42860276358468, 61.821590014866416, 63.07651111057827, 60.15594700404576, 60.67683955601284, 63.58595303126744, 67.42483275277274, 66.32546097891671, 66.13542774745396, 65.7730027607509, 64.0835691179548, 65.01870632171631, 69.16191019330705, 68.35584272657121, 70.30534744262695, 71.13509437016079, 70.90820789337158, 74.84801714760917, 80.48931516919816, 77.84215572902134, 67.72195162091936, 1.2669031556163515, 3.9830491968563626, 82.75476142338344, 60.785794258117676, 50.68795987537929, 54.67029210499355, 41.4574795450483, 49.18782295499529, 78.92442103794643, 4.2619516253471375, 0.49519757074969156, 0.17598695946591242, 0.13281639026744024, 0.16885015528116906, 0.11082899903080293, 0.23233239884887422, 0.15563529224268027], [0.07778254550482545, 0.10195903320397649, 0.0807393839848893, 0.1520400337342705, 0.08296241398368563, 0.18727799930742808, 0.0837168295734695, 0.3429772231195654, 0.3707270255046231, 24.97060111590794, 52.155749457223074, 44.50008528573172, 44.587271281651084, 46.14957026072911, 43.240008626665386, 65.02479989188058, 42.438940388815745, 0.0472173181229404, 0.057256616918104034, 38.28641550881522, 80.00265639168876, 62.03565011705671, 67.28073406219482, 58.414909090314595, 62.07048143659319, 59.941782678876606, 62.841675894601, 61.9973030090332, 62.80464199611119, 66.21790981292725, 60.88472270965576, 67.35140419006348, 104.52905396052769, 57.6168772152492, 63.57564190455845, 60.15989358084542, 57.68077284949166, 57.38520690373012, 56.385402815682546, 52.49855967930385, 54.50356660570417, 55.70889493397304, 53.06126649039132, 54.11162914548601, 55.50542736053467, 50.238870007651194, 42.59137691770281, 43.78191947937012, 44.48876667022705, 42.95390265328543, 43.45786591938564, 38.18340499060494, 40.23452016285488, 37.43484776360648, 39.72819103513445, 38.02459348951067, 39.811708382197786, 37.47007860456194, 38.227168219430105, 37.659208570207866, 36.176216329847065, 32.03142132077898, 32.5103953906468, 32.44277899605887, 40.65162052427019, 43.7089911869594, 45.084453105926514, 42.64481898716518, 44.90502977371216, 44.73737668991089, 43.768342699323384, 43.35028348650251, 43.29537534713745, 40.13305214473179, 40.48183781760079, 41.06987081255232, 45.63359008516584, 44.403550488608225, 41.18604816709246, 39.734534740448, 39.084381375994, 39.484729630606516, 41.24844299043928, 41.117983613695415, 40.76180853162493, 38.6850961957659, 38.66521392549787, 40.040443079812185, 48.80250712803432, 44.58048983982631, 40.510558196476524, 39.36321605954851, 38.25032309123448, 40.21152857371739, 42.224501609802246, 39.51925870350429, 41.51838050569807, 37.57834543500628, 37.32344729559762, 39.17019510269165, 40.417021547045024, 44.414441789899556, 43.242770535605295, 39.33636474609375, 40.23683391298567, 42.48586852209908, 43.83123084477016, 42.389031478336875, 47.25727639879499, 35.59100430352347, 25.24146100452968, 40.991849490574424, 42.06250088555472, 41.69211673736572, 34.32636615208217, 31.865533079419816, 31.766799177442277, 33.95878560202462, 37.47519595282418, 36.725780623299734, 37.475595474243164, 38.51396901266915, 36.93443155288696, 37.248215675354004, 37.27635587964739, 36.79845183236258, 37.93552105767386, 40.27519839150565, 41.997677666800364, 42.10123709269932, 46.83567360469273, 52.98222378322056, 55.01989071709769, 55.40949010848999, 51.51851279394967, 58.275382314409526, 67.27462659563336, 58.88949884687151, 60.01428713117327, 57.54080833707537, 56.259782859257285, 55.17324093409947, 55.26759052276611, 59.01607418060303, 59.21866280691964, 62.42984921591622, 63.68978691101074, 65.43530641283307, 65.8494051524571, 69.54467950548444, 66.71602616991315, 71.45353031158447, 68.88139057159424, 69.75434139796666, 64.9416924885341, 69.1989996773856, 66.07270635877336, 71.33258301871163, 25.930520806993755, 1.188625944512231, 5.342130737645285, 67.50923252105713, 42.57686907904488, 39.45391436985561, 34.767430850437705, 29.086847714015416, 40.69781562260219, 47.19162287030901, 1.7962972628218787, 0.28167519399097984, 0.03281101205253175, 0.09635630848684482, 0.1060841122109975, 0.14040326673005307, 0.05676071299239993, 0.12046189606189728, 0.019575119517477493, 0.12985347211360931, 0.043610198822404654, 0.09530504061175243, 0.014073080915425504, 0.17189533902066095, 0.06200024166277476, 0.35572925742183414, 0.4371049308351108, 29.630707536424907, 59.11940084184919, 45.194679328373496, 55.000963824135916, 56.730731759752544, 46.601397718702046, 71.20630645751953, 46.26365620749337, 0.04864024676914726, 0.10907871795019933, 42.161669049944194, 83.16634491511753, 65.90021732875279, 70.57565321241105, 59.613084248134065, 67.26334966932023, 63.18832847050258, 68.09913458142961, 65.98861231122697, 65.33449499947685, 66.20290170397077, 65.46385656084333, 65.93790435791016, 100.08598668234688, 59.4246768951416, 64.8908108302525, 60.87586375645229, 59.144108636038645, 57.73824487413679, 59.25824669429234, 54.418732575007844, 59.778903007507324, 56.210891859872, 56.481607573372976, 56.191919803619385, 59.31559017726353, 53.19094072069441, 46.05022144317627, 45.2049800327846, 47.4627902167184, 46.55334745134626, 45.108636311122346, 41.690369265420095, 42.886633668627056, 41.28943041392735, 41.903060572487966, 41.906805651528494, 41.37877035140991, 39.431958062308176, 41.3055328641619, 40.29541417530605, 38.70166070120675, 34.86258295604161, 36.68473761422293, 35.16682720184326, 42.36047090802874, 44.87643446241106, 47.70992374420166, 46.971364974975586, 45.40625197546822, 46.394629750932964, 47.53097288949149, 45.595791884831016, 44.92929288319179, 43.38005651746477, 44.59655407496861, 44.492140020642964, 47.37476348876953, 47.34364945547921, 42.27763795852661, 41.003282751355854, 41.56019129071917, 41.09646156855992, 41.936512674604145, 43.8166743687221, 43.01862512316023, 41.04732390812465, 39.64050824301583, 42.54317726407732, 50.52158178601946, 48.0005738394601, 43.12084354673113, 41.648898942129954, 39.52348320824759, 42.131965500967844, 44.4495336668832, 41.09960215432303, 42.448577540261404, 40.97676495143345, 40.61882850102016, 41.97791699000767, 42.73279012952532, 46.23660339627947, 43.94547312600272, 42.30198097229004, 43.90665006637573, 45.74825620651245, 46.59419591086251, 46.030269690922324, 48.94329500198364, 38.906132289341514, 28.010941743850708, 43.41845921107701, 44.679157733917236, 43.473065103803364, 37.24616943086897, 33.89618233272007, 35.51260083062308, 34.34562308447701, 39.985347339085166, 39.355722427368164, 39.30153342655727, 40.62331008911133, 39.68361486707415, 40.274277755192344, 39.022285325186594, 40.218077250889365, 40.89284460885184, 43.84646129608154, 43.54247760772705, 44.039464882441926, 49.776470865522114, 54.61219126837594, 56.82320186070034, 57.620014326913015, 54.64593172073364, 57.21152973175049, 66.99448217664445, 61.60384736742292, 63.268816402980256, 61.02406883239746, 58.896551268441335, 59.48559175218855, 59.07894148145403, 60.75863374982561, 60.67566531045096, 64.10361467088971, 66.64036028725761, 68.23950903756278, 66.81145272936139, 70.30793912070138, 68.4118104662214, 71.41863645826066, 70.73614270346505, 72.74617317744664, 69.32399777003697, 70.93948868342808, 69.92215429033551, 72.82347883496965, 24.51784954752241, 0.8154410751802581, 6.433661035129002, 75.98580551147461, 49.12814140319824, 47.83373369489397, 42.04671457835606, 34.96714639663696, 47.26244585854666, 56.82182264328003, 2.3526854472500935, 0.28167486829417093, 0.07047407874571425, 0.10084092284419707, 0.09447844246668474, 0.20270096457430295, 0.07426864334515162, 0.09995932943586792, 0.13296592581484998, 0.26946278501834187, 0.1794513285692249, 0.1747443447155612, 0.17034711209791048, 0.2417006604373455, 0.1500171037124736, 0.48098041649375645, 0.5022134057113102, 39.125796113695415, 69.07798985072544, 59.33120277949742, 57.64718525750296, 63.787186758858816, 54.66889551707676, 73.30712904248918, 49.40204981395176, 0.15880692776824745, 0.3569748034434659, 45.26298359462193, 85.82264123644147, 68.10086468287876, 74.91096782684326, 61.063722201756065, 67.70388630458287, 64.0576662336077, 70.18104416983468, 65.3786438533238, 69.06476048060826, 68.47876330784389, 67.43375423976353, 68.27443763187954, 105.3715716770717, 62.04379340580532, 65.82784489222935, 62.89537157331194, 60.46297400338309, 61.01747499193464, 61.02282510484968, 56.92249509266445, 61.318929536002024, 59.13512461526053, 59.05531760624477, 58.41166428157261, 60.50011212485177, 54.61063487189156, 48.623382568359375, 46.52942132949829, 50.49233681815011, 49.68302801677159, 49.87153959274292, 43.47598682131086, 44.671994141169954, 43.93199014663696, 43.899413517543245, 44.53018140792847, 42.96233776637486, 40.953158446720664, 42.063921792166575, 42.40107618059431, 41.584972040993826, 37.0393180847168, 38.39440093721662, 37.94099971226284, 45.29084587097168, 48.47411789212908, 50.11841951097761, 47.10223429543631, 48.24174581255232, 49.1759033203125, 49.678695814950125, 48.17614439555577, 49.53732081821987, 43.90743521281651, 48.54963091441563, 46.19328485216413, 49.05515405109951, 48.48012808391026, 44.68642207554409, 43.22244358062744, 43.44496658870152, 41.78838750294277, 44.3210197857448, 48.08368819100516, 45.406606333596365, 43.44483457292829, 41.7895131111145, 44.666654450552805, 53.986571993146626, 49.31296348571777, 44.395806721278596, 44.24804285594395, 41.9788167817252, 45.6640614100865, 48.41404029301235, 44.73216206686837, 45.51775319235665, 43.34933853149414, 42.91630942480904, 43.749641622815815, 45.24138164520264, 50.60798263549805, 47.749955790383474, 45.53469637462071, 48.25461735044207, 48.10513380595616, 48.73006173542568, 47.63102694920131, 50.44508906773159, 40.3033663885934, 32.52131448473249, 47.98514536448887, 47.466160093035015, 45.691843782152446, 40.28059366771153, 37.562256881168906, 38.64776699883597, 36.96638284410749, 43.41682291030884, 41.520590032849995, 41.006138460976736, 43.144272872379844, 42.537264347076416, 43.1501510483878, 42.015666552952354, 43.991932255881174, 42.91539921079363, 45.52690396990095, 46.234616211482454, 45.47441380364554, 52.203000681740896, 56.66931315830776, 58.40482725415911, 59.02445370810372, 55.87683984211513, 61.78531347002302, 69.6879027230399, 63.51174627031599, 62.30720656258719, 64.7168140411377, 62.6722023827689, 61.352246148245676, 60.15982409885952, 64.72666658673967, 63.4374908719744, 65.40444946289062, 69.84683581760952, 70.50427436828613, 68.33504676818848, 73.25327355521065, 70.22449820382255, 75.71085834503174, 73.20497662680489, 76.46975449153355, 71.09438487461635, 74.62914889199394, 72.66710267748151, 74.52692699432373, 36.72275120871407, 1.1103008559771945, 6.927258023193904, 86.59333542415074, 54.73671688352312, 61.22914491380964, 47.428660665239605, 42.13068355832781, 59.047945567539756, 67.43233680725098, 3.630885179553713, 0.3280485841844763, 0.13930929186088697, 0.2028325053730181, 0.1705128782029663, 0.32623135883893284, 0.13308314952467168, 0.22955529072454997], [0.038452352197574716, 0.1276355582688536, 0.07576047043715205, 0.15098763949104718, 0.03029015607067517, 0.2128553089818784, 0.08260886331221887, 0.349045171801533, 0.3011106082371303, 13.579598409788948, 51.20569099698748, 32.08804219109671, 23.28108409472874, 39.40600654057094, 47.45849622998919, 60.43953078133719, 54.104257106781006, 0.6189400479197502, 0.062340818744684966, 36.232510634831016, 78.77177606310163, 62.15431840079171, 64.68494265420097, 59.46114798954555, 62.82584095001221, 62.63972650255476, 62.887520108904155, 62.81037425994873, 62.30061967032296, 66.47513907296317, 57.11378594807216, 60.28418295724051, 40.92874247687203, 55.78078447069441, 62.3024331501552, 58.67061669485909, 57.85047912597656, 53.01058285576956, 55.61479548045567, 51.42286041804722, 56.948095730372835, 55.42613104411534, 57.620907170431956, 56.20325926371983, 59.833578382219585, 52.60531527655465, 46.89903770174299, 42.66901956285749, 44.02268498284476, 41.954501560756135, 41.4452611378261, 39.90196548189436, 38.81408255440848, 37.83483123779297, 39.886801038469585, 38.31427083696638, 37.68151923588344, 38.25905697686331, 38.462128502982004, 38.14922332763672, 36.174809319632395, 32.43786314555577, 32.21513516562325, 34.68170050212315, 42.89693089893886, 41.74825470788138, 41.88324083600725, 42.63047095707485, 45.55555139269148, 39.9874005317688, 41.72903599057879, 40.296067305973594, 39.025988715035574, 37.10203947339739, 40.09376008169991, 41.85042101996285, 45.140681403023855, 45.72902706691197, 43.41681943620954, 39.81946604592459, 40.95541661126273, 38.34178570338658, 39.13736833844866, 37.514946596963064, 41.38816084180559, 37.90202031816755, 40.18335362843105, 39.03427791595459, 42.5695595741272, 45.14222737721035, 39.402612345559255, 39.51552057266235, 39.525519030434744, 38.89400768280029, 40.595343589782715, 37.55596876144409, 37.09487240655081, 37.623011929648264, 38.409172807421, 37.6914621080671, 41.13822719029018, 42.82910605839321, 42.535634994506836, 39.69790036337716, 40.7805825642177, 40.126538208552766, 39.51539203098842, 41.75279188156128, 41.22422851834978, 44.331629684993196, 42.162620953151155, 39.98283209119524, 42.77745315006801, 41.469162940979004, 38.3785833631243, 32.00531346457345, 32.24543278557913, 33.15083169937134, 37.28613894326346, 37.72821460451399, 39.42164693559919, 37.939453738076345, 37.9816814150129, 36.334291321890696, 37.22398383276803, 36.367149353027344, 39.30018547603062, 40.84905358723232, 41.8490035874503, 41.26920073372977, 45.06764193943569, 53.41372081211635, 55.71031584058489, 53.65461138316563, 53.508021763392854, 53.341004439762656, 49.37002904074532, 54.26136629922049, 58.59694494519915, 62.5719815662929, 58.63128989083426, 60.000349044799805, 57.98463494437081, 56.23704835346767, 58.57687159946987, 58.913873127528596, 58.800860677446636, 60.9371121270316, 62.05980205535889, 61.97477000100272, 65.42509256090436, 65.70243685586112, 65.31819452558244, 64.2289810180664, 65.64248085021973, 67.14076260157994, 67.70050253186906, 71.63947800227574, 11.429316810199193, 0.9026643091014454, 9.605169756071907, 65.71077469417027, 44.237749099731445, 38.327660015651155, 34.77499049050467, 27.464907135282242, 34.55992637361799, 51.312182562691824, 1.033615108047213, 0.22168243889297756, 0.046381977054157426, 0.18868695013225079, 0.06736756222588675, 0.0694258099954043, 0.02178843628748187, 0.15565125138631888, 0.08591589371540717, 0.09111275949648448, 0.021026802781437124, 0.19465254859200545, 0.03414390588711415, 0.2506525729383741, 0.08191719185560942, 0.1762811993913991, 0.2858435703175408, 17.688816036496842, 61.282785006931846, 35.093106814793174, 33.09479447773525, 50.44131619589669, 49.84587642124721, 68.09278392791748, 60.558782713753835, 1.1287716648408344, 0.14947432998035634, 40.0524982043675, 81.12772955213273, 67.17715726579938, 69.18520750318254, 62.60002449580601, 65.49640887124198, 64.32474109104702, 65.61138071332658, 64.10826996394566, 65.63271168300084, 68.22522354125977, 59.45556163787842, 60.29017925262451, 48.90898479734148, 57.207489354269846, 65.2734967640468, 60.81865923745291, 59.46918705531529, 54.92302935464041, 57.82282876968384, 54.38593012945992, 59.502045086451936, 56.75958068030221, 59.95959786006382, 58.40033176967076, 60.63501140049526, 55.06888593946184, 50.77592754364014, 45.30503061839512, 46.54219559260777, 44.91172088895525, 44.829777308872764, 42.567200660705566, 42.03689677374703, 40.51050608498709, 41.27404015404837, 39.09300756454468, 40.38507372992379, 40.171625069209504, 40.884385177067344, 40.02897160393851, 39.59293392726353, 34.71367263793945, 36.1689624105181, 35.94279507228306, 44.52960818154471, 43.931674003601074, 43.587765966142925, 43.4963241985866, 48.117855957576204, 43.25038923536028, 41.59644004276821, 40.05296720777239, 40.00443056651524, 39.28852987289429, 42.114893777029856, 44.18332038606916, 47.19127198628017, 47.740996088300435, 44.9270590373448, 41.09056602205549, 43.10371971130371, 39.38834421975272, 41.06089721407209, 40.576076235089985, 43.7255140032087, 39.683680874960764, 42.402486664908274, 40.771282400403706, 43.76620265415737, 47.87448835372925, 42.10915456499372, 43.3417580468314, 41.067286082676475, 41.58674035753523, 42.59536170959473, 40.047853333609446, 40.53101716722761, 38.46137114933559, 39.50365652356829, 39.49069813319615, 42.938693046569824, 44.348770890917095, 44.598968573978965, 41.519481795174734, 42.69004133769444, 41.30039814540318, 40.99018887111119, 44.438614572797505, 43.48304966517857, 46.90674672807966, 46.057419776916504, 43.118446418217246, 43.66053097588675, 44.313192640032085, 41.63537427357265, 35.623091084616526, 35.90847791944231, 35.83063725062779, 39.464371408735005, 40.31233303887503, 42.11705814089094, 40.61574697494507, 40.16104991095406, 38.80589062826974, 38.4831085886274, 39.91775178909302, 40.730128220149446, 42.69600289208548, 44.49242837088448, 43.59411661965506, 47.26726443426949, 57.757894379752024, 58.12082658495222, 58.439498765128, 55.995376110076904, 56.959501198359895, 52.28115749359131, 53.49741881234305, 60.48723711286272, 64.51214790344238, 61.51992007664272, 60.95954786028181, 60.58733980996268, 58.44671099526541, 60.4530519757952, 61.33252716064453, 62.60611111777169, 64.06094578334263, 63.51885427747454, 66.25809819357735, 66.54162638528007, 68.76781531742641, 68.39576707567487, 66.8403433391026, 66.90734481811523, 72.50864900861467, 69.60002885546002, 72.83518654959542, 11.9516841173172, 0.8917410352400371, 11.648637567247663, 74.60678958892822, 53.3059264591762, 44.17632702418736, 44.67743110656738, 31.34839950289045, 38.81110872541155, 62.49229267665318, 1.386895614010947, 0.3085233047604561, 0.02965822283710752, 0.09989529608615808, 0.013557208552291351, 0.10104507367525782, 0.04925680439919233, 0.12094027682074479, 0.17277569749525615, 0.22190053361867154, 0.21231746141399654, 0.2768603637814522, 0.14877604959266527, 0.21082317802522862, 0.138277905061841, 0.584616978253637, 0.5964365154504776, 24.185459886278423, 73.65886075156075, 43.173034940447124, 29.83635684422084, 52.61026586805071, 62.98508671351841, 70.19762257167271, 66.05610711233956, 1.0267151125839777, 0.22317855432629585, 41.326241970062256, 83.78187193189348, 68.72965581076485, 72.29161507742745, 64.36390808650425, 68.58925356183732, 65.97563307625907, 68.202134677342, 65.85299737112862, 67.70754105704171, 69.59745802198137, 63.07800497327532, 59.03050558907645, 53.516616685049875, 59.538002014160156, 67.79310117449079, 63.744121823992046, 62.89296749659947, 57.8301591191973, 60.339712960379465, 54.56044108527047, 61.36273792811802, 59.743925775800435, 60.91780308314732, 60.79673072269985, 64.16238948277065, 56.5760509627206, 52.71212298529488, 47.16543163572039, 47.621806689671104, 46.18492616925921, 45.73601000649588, 45.33650595801217, 43.85155085154942, 43.875994614192415, 44.59734269550869, 41.35055719103132, 41.9527645111084, 43.38143573488508, 43.19328546524048, 42.36885390962873, 43.56359665734427, 37.30099766595023, 39.40484619140625, 39.187888690403526, 46.23525544575283, 46.690063680921284, 45.82002067565918, 46.01831531524658, 50.401214667728965, 44.636624336242676, 45.91522489275251, 43.459686347416465, 43.43708038330078, 41.59619338171822, 45.195356777736116, 47.95501797539847, 51.9730361529759, 50.016569341932026, 47.36727333068848, 43.74804701123919, 45.77321413585118, 42.064359528677805, 43.6067727633885, 44.29363693509783, 47.94694764273507, 41.30418143953596, 45.98742709841047, 44.93735974175589, 44.6855639730181, 49.95150293622698, 43.344016211373464, 46.44123131888253, 44.65119818278721, 42.98903969355992, 45.99600812367031, 41.995662689208984, 42.52572686331612, 41.6337171282087, 43.90494080952236, 41.00277553285871, 46.52773986543928, 46.98712001528059, 47.22110060283116, 44.687012672424316, 47.15902887071882, 43.63855034964425, 43.25506884711129, 44.97141286305019, 45.841942242213655, 49.418089730399, 46.3318840435573, 46.79805605752127, 46.48692962101528, 46.77613796506609, 44.33381141935076, 37.572161538260325, 39.91560826982771, 37.760478564671104, 41.55641841888428, 42.395069462912424, 43.612890652247835, 42.37166445595877, 42.973680700574604, 41.065159933907644, 41.04822022574288, 42.12493044989449, 42.67643676485334, 45.55588143212454, 47.475877148764475, 44.819754532405305, 49.695340224674766, 59.160416058131624, 60.74182605743408, 60.84005968911307, 56.67316246032715, 57.44178261075701, 55.91310249056135, 54.75468839917864, 61.11797373635428, 64.74056298392159, 62.77477863856724, 64.02524593898228, 64.40884903499058, 60.01912307739258, 64.58646583557129, 64.67149094172886, 65.06894874572754, 67.03173146929059, 65.90738092150006, 70.07172816140312, 70.21702194213867, 72.08509377070835, 69.98634869711739, 72.16812474387032, 70.14105033874512, 78.40899671827043, 72.62343324933732, 77.98346124376569, 16.394585507256643, 1.034081505877631, 12.703328950064522, 82.76383577074323, 57.414861815316335, 57.95040464401245, 49.11242110388619, 40.03129925046648, 48.038768087114605, 71.74520179203579, 2.1315314514296393, 0.400336068123579, 0.19724183822316782, 0.3884207217821053, 0.14901215263775416, 0.2201768918229001, 0.14928556153816835, 0.35643395675080164], [0.04449818403060947, 0.14156703571123735, 0.09074530564248562, 0.14764072479946272, 0.01575216501285987, 0.15373836617384637, 0.038895720549459965, 0.3647563244615282, 0.30982685195548193, 13.097488965306963, 48.79331118719918, 35.34652498790196, 30.98427220753261, 32.6392879486084, 43.93915721348354, 51.588998794555664, 65.67302513122559, 2.706066267830985, 0.24081962342773164, 30.187053271702357, 80.9052551814488, 60.36894403185163, 67.00393867492676, 61.4094089780535, 64.43705872126988, 60.089299883161274, 63.409447942461284, 63.289285796029226, 66.96034567696708, 61.830928393772666, 58.02024098805019, 56.0601680619376, 46.404708112989155, 63.488511494227815, 58.06108249936785, 57.213346685682026, 53.034408228737966, 54.1257826260158, 55.83035639354161, 56.25448833193098, 58.89653042384556, 55.8574925831386, 55.622688634055, 54.00128480366298, 54.589578356061665, 55.580697195870535, 48.73713500159127, 43.82551942552839, 43.630455698285786, 42.85274035590035, 41.7904372215271, 39.01945740836007, 39.17134155545916, 37.1805054800851, 37.87762171881539, 38.637772015162874, 38.91192708696638, 36.67534017562866, 38.5157025882176, 35.91239322934832, 35.06896529878889, 34.19225549697876, 34.259173597608296, 38.95562430790493, 41.636756965092246, 41.856368677956716, 41.25120142527989, 41.58020210266113, 37.95992660522461, 36.248144081660676, 36.45752804619925, 37.23605980191912, 36.04092100688389, 37.10883133752005, 39.15915788922991, 41.343727111816406, 44.52294485909598, 43.42505652563912, 45.53077411651611, 42.23312432425362, 41.34144810267857, 39.006474699292866, 37.95645598002842, 36.75796120507376, 38.82226405824934, 37.34949609211513, 40.12104218346732, 38.04010534286499, 41.731057916368755, 45.691843782152446, 39.80213723863874, 41.26166541235787, 39.83538089479719, 38.288927282605854, 36.490504196711946, 38.28566510336739, 37.27393443243844, 38.22152280807495, 37.01892164775303, 41.57864570617676, 43.51578957693917, 42.85025984900338, 39.95548745564052, 36.331407819475444, 37.652406283787315, 35.18945401055472, 36.87916210719517, 35.625901630946565, 38.36614261354719, 38.428454058510916, 41.54568692616054, 42.07299266542707, 41.904912267412456, 40.554602827344624, 39.825285162244526, 33.930200713021414, 32.80857733317784, 34.57958630153111, 37.18725912911551, 39.26333570480347, 39.4769024848938, 37.62140689577375, 38.70575666427612, 36.799358572278706, 39.64447219031197, 38.08363580703735, 37.95453480311802, 41.06885984965733, 39.6466052872794, 41.090493065970286, 45.40069341659546, 51.98414979662214, 55.41635492869786, 53.68479435784476, 53.94734593800136, 54.91992003577096, 55.922211578914094, 52.69500262396676, 50.68386738640921, 54.93453557150704, 59.568838119506836, 58.05257790429251, 59.83282102857317, 58.32399191175188, 57.04359177180699, 58.54860632760184, 60.29332678658621, 61.14257730756487, 62.570855958121165, 62.15746593475342, 61.57991082327706, 62.009121894836426, 62.47756249564034, 60.94161455971854, 64.09927204677037, 63.53788539341518, 65.92671775817871, 74.15209252493722, 7.173517380441938, 0.9655097339834485, 12.949517522539411, 65.46474593026298, 48.54253680365426, 40.110758849552695, 28.287207330976212, 35.663838795253206, 43.41812569754464, 53.0165513583592, 1.1328506916761398, 0.14943734982184, 0.04790814819612673, 0.012609575875103474, 0.04805469818945442, 0.07880824618041515, 0.009028689586557448, 0.08300525668476309, 0.025206627690100243, 0.1580912090305771, 0.07276148814707994, 0.03867580395724092, 0.050755189532147985, 0.1861626777265753, 0.062271804947938235, 0.24508437886834145, 0.3260328194924763, 16.5971428666796, 60.39540277208601, 37.183395930698936, 36.47035094669887, 39.411314964294434, 47.2099209512983, 58.629726546151296, 69.55707509177071, 3.6190658594880785, 0.39885349624923294, 31.71186671938215, 83.97209971291679, 65.00144699641636, 69.16017314365932, 63.94539724077497, 67.63724613189697, 63.291154861450195, 66.69950335366386, 66.0546132496425, 66.90402357918876, 64.26271452222551, 58.97205039433071, 58.01935856682913, 50.41059126172747, 63.810226985386436, 61.97288703918457, 57.39542770385742, 55.40521696635655, 57.56321280343192, 59.01904106140137, 57.42383541379656, 61.32942826407296, 58.09666769845145, 57.26342930112566, 55.81434774398804, 56.99630928039551, 58.38713714054653, 51.785466057913645, 44.85471439361572, 45.19868149076189, 45.03449208395821, 44.028146266937256, 42.39291204724993, 42.67071492331368, 38.669417585645405, 41.09974111829485, 40.76100254058838, 41.21744360242571, 38.02156407492501, 39.92795174462454, 38.350571700504844, 38.91819436209542, 36.727840764181956, 37.080170018332346, 41.63619416100638, 43.18708767209734, 44.929150445120676, 43.413981097085134, 44.48802668707711, 40.804039682660786, 38.27600015912737, 39.907013348170686, 38.95345994404384, 38.466123717171804, 40.179549489702495, 42.04229899815151, 44.450190271650044, 46.78494480678013, 47.03427049091884, 47.08474220548357, 43.037385259355815, 42.717969621930806, 41.665525981358115, 39.479341302599224, 39.60597917011806, 40.54560143607003, 39.23708888462612, 42.47937543051583, 40.26308420726231, 43.71603666033064, 48.14171607153756, 42.48813363483974, 43.75158364432198, 41.08305501937866, 41.72444323131016, 39.34806203842163, 40.36262757437569, 40.2534852709089, 40.38802324022566, 40.16124446051461, 42.04355662209647, 44.11174699238369, 46.700885500226704, 42.97338192803519, 40.14435338973999, 38.52420718329293, 38.04760592324393, 39.0942964553833, 36.524925572531565, 41.74589579445975, 40.557319572993684, 42.11228125435965, 43.162883622305735, 43.660114083971294, 44.136965479169575, 45.022909436907085, 36.39467464174543, 35.38116870607649, 37.5746420451573, 39.71888044902256, 41.93736035483224, 42.32850224631173, 40.00505937848772, 40.601944378444124, 40.248211588178364, 40.531458377838135, 38.92780719484602, 41.02490554537092, 43.81866502761841, 42.85232693808419, 42.51177488054548, 46.756641319819856, 55.546223708561485, 56.206719466618125, 56.11824457986014, 56.322709219796316, 58.867883001055034, 56.973720686776296, 55.53106621333531, 52.4512528691973, 59.40140042986189, 60.76426873888288, 62.17681666782924, 62.098336764744346, 61.454384667532786, 60.724122047424316, 60.142001969473704, 60.842880657741, 63.80317456381661, 64.92894949231828, 66.52393627166748, 64.39421612875802, 65.18442780630929, 66.61836923871721, 65.84501389094761, 65.46704578399658, 68.2055184500558, 69.2512709753854, 77.40504455566406, 8.334164449146815, 1.1499942860433032, 15.231106179101126, 76.46549524579729, 55.08890717370169, 49.79800680705479, 34.397178718021934, 35.00307205745152, 52.06947020121983, 62.24180316925049, 1.3104396994624818, 0.22877193561622075, 0.020765134233183095, 0.06014938133635691, 0.050470649264752865, 0.11319582417075123, 0.0771600506933672, 0.06034536260579314, 0.11743736692837306, 0.3563826052205903, 0.12005691922136716, 0.17513151679720196, 0.11166547664574214, 0.28498633631638115, 0.1335616252784218, 0.41071949952415054, 0.5686709710529873, 21.319070884159633, 70.24801090785435, 47.73412779399327, 41.673082147325786, 42.73075778143746, 59.52637767791748, 60.66977323804583, 76.26817335401262, 3.9650203585624695, 0.41763181718332426, 36.42650433949062, 89.48091643197196, 65.06260504041398, 72.1589253289359, 66.88359587533134, 70.22074617658342, 65.24368204389299, 67.70364311763218, 66.40146037510463, 71.44745063781738, 67.2959645135062, 60.54330907549177, 56.35878079278128, 56.22814423697335, 65.59865856170654, 64.6429477419172, 60.09070341927664, 56.393504415239605, 60.05256475721087, 60.60409886496407, 59.171144076756065, 62.97911821092878, 58.6367164339338, 59.97204903193882, 55.46089635576521, 58.90616757529122, 59.10321153913225, 53.867330483027864, 47.910757950374055, 48.42227043424334, 46.30895846230643, 46.387368883405415, 42.87940059389387, 44.49391875948225, 40.926484312329976, 42.38405656814575, 42.97379534585135, 43.44649519239153, 40.813899176461355, 44.18188558306013, 41.00189658573696, 40.979262828826904, 38.59888294764927, 39.475773402622764, 42.46059792382376, 46.24879053660801, 45.88461112976074, 45.745025294167654, 46.01631770815168, 43.252348627362935, 40.80460248674665, 40.73960556302752, 42.314855984279085, 41.17769990648542, 40.30254997525896, 44.42791434696743, 46.95685713631766, 49.35790096010481, 50.03224100385393, 49.39348268508911, 46.282930510384695, 45.88473619733538, 43.80622427804129, 43.44158629008702, 42.70583111899239, 43.6395891053336, 44.36791317803519, 47.207360540117534, 42.846612044743125, 48.345888887132915, 50.55176823479788, 45.35851090294974, 48.666576044900076, 45.20795038768223, 45.08308778490339, 42.88178730010986, 43.55759688786098, 42.675547395433696, 44.341277258736746, 41.1396724155971, 45.6466839654105, 48.938587597438264, 50.12445054735456, 46.59400136130196, 41.39186423165457, 42.38272251401629, 40.31457035882132, 40.929694380079, 39.09801721572876, 43.82154158183506, 41.914337498801096, 47.079600538526265, 45.91840021950858, 46.231993266514365, 46.727528367723735, 46.28829104559762, 39.78658717019217, 37.359230518341064, 40.07650423049927, 41.62058503287179, 43.68883098874773, 45.252338954380576, 42.48784181049892, 44.82017837251936, 43.59544719968523, 44.91407632827759, 42.776657581329346, 43.96606758662632, 45.60977513449532, 43.85758536202567, 44.44455528259277, 49.564714091164724, 58.894543239048545, 59.870188440595356, 58.37413011278425, 58.77941853659493, 59.9164217540196, 59.0505302974156, 59.04616682870047, 54.104264054979595, 60.96222291673933, 63.15362916673933, 63.139836992536274, 63.76227746691023, 64.52748257773263, 62.648272786821636, 62.67846965789795, 64.74617018018449, 68.0771713256836, 67.52492850167411, 69.98180457523891, 67.61079433986119, 68.31293760027204, 69.78952707563127, 68.56480285099575, 69.6945868900844, 71.50081975119454, 73.04844066074916, 82.58157757350376, 10.982728293963842, 1.2486323245934077, 16.957577194486344, 86.61679254259381, 61.25101784297398, 60.76464394160679, 40.41917201450893, 51.79891082218715, 62.10900919778006, 71.8741534096854, 2.130851830754961, 0.3155409039131233, 0.2548992522060871, 0.18328596066151345, 0.11255560602460589, 0.24389824537294252, 0.1418130589382989, 0.14956173886145863], [0.05612440999331219, 0.06640688556113414, 0.0513376405994807, 0.28953208667891367, 0.0020607295113482644, 0.19251683247940882, 0.029041224159300327, 0.22144938925547258, 0.25857810622879435, 10.167781897953578, 58.972390856061665, 35.032362188611714, 33.420279366629465, 30.839034012385778, 47.71272734233311, 53.12775032860892, 72.58106313432965, 7.890171085085187, 0.7705715085778917, 18.065913881574357, 75.51655891963414, 64.1261407307216, 66.89052322932652, 59.40169225420271, 61.131682532174246, 60.30791105542864, 62.40835148947579, 64.51808166503906, 64.70387649536133, 51.348723139081685, 56.63958181653704, 54.76722294943673, 48.66966451917376, 59.53274917602539, 56.23574209213257, 54.37608105795724, 54.39422975267683, 57.45707906995501, 58.62571743556431, 57.77717910494123, 55.505013942718506, 56.58708470208304, 54.0330867086138, 56.00659397670201, 59.302930559430806, 54.71003232683454, 49.8680168560573, 42.00274985177176, 42.02881949288504, 43.0103428704398, 43.316063608442036, 40.316383838653564, 38.28826720373971, 38.72688961029053, 38.86176109313965, 38.178864342825754, 38.56405162811279, 37.1699025290353, 36.478035654340474, 36.96763351985386, 36.03172506604876, 39.72234412602016, 41.17188079016549, 41.59045764378139, 40.06968804768154, 40.78668655667986, 38.16535357066563, 36.75779792240688, 36.49297080721174, 37.76476560320173, 37.37606600352696, 37.13445629392351, 36.83143145697457, 35.84387009484427, 39.26958908353533, 39.40005888257708, 42.882954597473145, 40.43001467841012, 42.6846912247794, 38.72728565761021, 40.55287619999477, 38.240647724696565, 37.83984783717564, 39.11453308377947, 38.09911986759731, 36.943120275224956, 37.72297913687569, 38.704401765550884, 40.9258450780596, 43.66840328489031, 39.20194837025234, 36.92447131020682, 38.52320664269583, 36.57589408329555, 37.01698310034615, 36.264632156917024, 36.68229532241821, 36.917266028267996, 38.38647651672363, 39.831507274082725, 41.4115206854684, 41.85242557525635, 41.83583327702114, 36.80993720463344, 35.405716691698345, 35.95680264064244, 33.39514773232596, 35.40723834718977, 33.91172545296805, 36.01266963141305, 38.1839017868042, 39.19683102199009, 41.66329560961042, 41.09097943987165, 40.25850534439087, 37.45542137963431, 35.67802701677595, 35.817918573107036, 37.63455636160714, 37.81498718261719, 37.941673687526155, 37.961319719042095, 37.56425796236311, 36.87380504608154, 35.80729130336216, 39.87129960741316, 38.182334968021934, 40.673608098711284, 40.60474797657558, 40.88535792487008, 42.98753888266427, 48.742561544690815, 52.38260119301932, 53.542418820517405, 53.70034442629133, 53.623341015407014, 55.599658829825266, 58.30294581821987, 56.82954209191458, 50.99540376663208, 51.525902203151155, 57.61817305428641, 60.17893859318325, 56.89807217461722, 59.7383394241333, 57.61619629178728, 57.33025360107422, 59.14553301674979, 58.53514071873256, 59.93335451398577, 60.97818987710135, 60.289324624197825, 60.992781094142366, 60.68429497310093, 60.712740898132324, 63.284276144845144, 65.80344976697648, 71.78611278533936, 7.827051912035261, 1.0646521683250154, 15.361080918993268, 66.18986688341413, 52.83841691698347, 44.107070854731965, 31.21089812687465, 34.0446514402117, 40.640371390751426, 52.184469836098806, 0.7874874408755983, 0.23035414357270512, 0.02168272222791399, 0.0574461521048631, 0.02962597885302135, 0.09116341213562659, 0.03021936451217958, 0.07279898399221045, 0.01736344989123089, 0.11203763274742023, 0.03460650731410299, 0.08775930372732026, 0.06953385991177388, 0.18060888216963836, 0.0248376318652715, 0.23779514857700892, 0.24281636199780873, 12.502208999225072, 70.50046675545829, 38.07142087391445, 30.9084986277989, 36.47057328905378, 52.382906913757324, 57.256255286080496, 78.86738327571324, 9.659770437649318, 1.0585281997919083, 19.016870396477835, 80.20589814867292, 67.34724916730607, 70.88509123665946, 63.13432707105364, 65.32663658687046, 61.32107652936663, 66.18322440556118, 64.39441067831856, 64.76439530508858, 55.133809907095774, 58.32729925428118, 56.069766998291016, 52.63736036845616, 61.89597742898123, 58.850693157741, 55.94531086512974, 55.92702668053763, 58.09513562066214, 60.95028591156006, 58.82296289716448, 58.52413477216448, 59.32144750867571, 56.82020023890904, 56.88525969641549, 63.254607336861746, 56.591420378003804, 51.91517850330898, 43.91513729095459, 42.890785217285156, 44.62838724681309, 44.50508451461792, 42.283429282052175, 40.703818866184776, 41.169358594076975, 40.57268551417759, 39.89455870219639, 40.72904430116926, 40.389746393476216, 38.79741382598877, 38.78553935459682, 38.80068990162441, 40.08886854989188, 44.17773403440203, 43.30321986334664, 44.645069871629985, 42.456415108272004, 40.095580509730745, 39.302308150700156, 38.742460523332866, 41.29384599413191, 39.66127640860421, 39.98605258124215, 39.834908417293, 38.67853709629604, 41.935981137411936, 42.67714548110962, 46.721747466496055, 43.329164436885286, 45.1973682812282, 41.836437770298545, 41.53173841748919, 39.753482478005544, 39.15253625597273, 39.73651845114571, 42.493924958365305, 38.363015924181255, 41.73035614831107, 41.70924752099173, 43.68014574050903, 44.545915603637695, 41.50845847811018, 41.923297200884136, 39.16832603727068, 38.892558983394075, 39.462717737470356, 38.78591455732073, 39.04851130076817, 39.516104221343994, 41.00343561172485, 42.739234583718435, 44.13140344619751, 44.87677839824131, 44.7220003264291, 39.80241516658238, 37.84712607519967, 37.80253253664289, 36.229526383536204, 37.53223371505737, 33.888997895377024, 36.61252498626709, 40.209958280835835, 40.06630080086844, 42.64609398160662, 42.7687748500279, 41.99843502044678, 40.98274735042027, 38.17226355416434, 38.08525473730904, 39.74000992093767, 39.0400379725865, 39.90805210386004, 39.86746767589024, 40.57708372388567, 39.74054493222918, 39.45873294557844, 42.01653855187552, 42.06545039585659, 42.572773115975515, 42.700491428375244, 43.70730972290039, 44.08567040307181, 52.50092554092407, 54.511011600494385, 56.03620719909668, 56.30835771560669, 56.27836581638881, 56.761328152247835, 59.729056630815776, 60.63929149082729, 54.901146003178184, 53.045709473746165, 58.366799763270784, 63.12615598951067, 61.03205231257847, 62.655485016959055, 61.30626991816929, 60.26495034354073, 61.617243494306294, 61.528799874441965, 63.73048945835659, 64.95727729797363, 64.43553706577846, 65.62404033115932, 63.459752900259836, 63.83881882258824, 67.54343155452183, 70.76073237827846, 75.55191830226353, 10.069334609167916, 1.1954998842307498, 18.019574608121598, 73.81801618848527, 58.07286664417812, 52.73738316127232, 39.36492531640189, 36.81175415856497, 45.36485808236258, 62.301515987941194, 0.9146215617656708, 0.23696910004530633, 0.06708166149577924, 0.0934488537854382, 0.08412694970944098, 0.11596588231623173, 0.03016955664913569, 0.09013753504093204, 0.08986599889716931, 0.17798728070088796, 0.13187534362077713, 0.3245281273765223, 0.2304237341242177, 0.36362080967852045, 0.1927123727010829, 0.29027559821094784, 0.3154561413185937, 16.52425800051008, 80.18543570382255, 46.11398506164551, 43.4591235433306, 41.830292088644846, 64.15210614885602, 63.22886426108224, 85.63225364685059, 9.98593885557992, 1.1279516688414981, 23.837655646460398, 82.18890013013566, 70.49534593309674, 73.58944824763707, 64.49712589808873, 68.48646191188267, 63.35173620496477, 68.69854177747453, 67.82700143541608, 69.46441391536167, 58.241172858646934, 58.41568728855678, 57.05773483003889, 56.06940221786499, 62.068848609924316, 62.39196763719831, 57.38682235990252, 59.79335526057652, 60.637332098824636, 63.14643778119768, 61.73335484095982, 61.48612403869629, 62.33375562940325, 59.20521109444754, 58.96808992113386, 63.63040065765381, 58.82438727787563, 53.44850696836199, 44.545908655439106, 46.730582101004465, 47.60337311880929, 47.85447754178728, 43.73985161100115, 42.14711952209473, 44.53874853679112, 43.34594781058175, 43.2540648324149, 42.91729606900896, 42.58049603870937, 41.10211740221296, 41.79862914766584, 41.1468950680324, 44.30795022419521, 46.60501773016793, 46.54850803102766, 44.99226440702166, 46.46053688866751, 43.12213243756975, 40.967471735818044, 41.379697935921804, 42.948684556143625, 40.819825989859446, 41.21734980174473, 41.47108064379011, 39.82915530885969, 44.71692814145769, 46.2531018938337, 49.06493016651699, 45.71712480272566, 47.49681207111904, 43.50031246457781, 45.06725631441389, 42.47009611129761, 43.3350738797869, 42.956539494650706, 47.37507963180542, 41.61176776885986, 45.01226132256644, 45.1490991456168, 47.30098751613072, 48.31747075489589, 45.82815701620919, 45.33128786087036, 43.64126014709473, 43.15866953986031, 43.6920028414045, 40.25244998931885, 42.38311161313738, 42.482863426208496, 44.497121879032676, 46.12384108134678, 46.18238312857491, 47.968865735190256, 47.571498257773264, 42.03650072642735, 40.12391526358468, 41.53256525312151, 39.07320172446114, 39.393944467817036, 38.79359926496233, 40.87508153915405, 42.82254695892334, 43.087037086486816, 44.65985216413225, 44.808925764901296, 43.94792236600603, 42.52633483069283, 40.38540029525757, 40.263244015829905, 42.3003203528268, 42.801129136766704, 43.27208151136126, 41.85967949458531, 42.06691646575928, 41.682093960898264, 42.127876486097065, 46.5465521131243, 43.575231415884836, 45.38456317356655, 45.32423543930054, 46.985237053462434, 46.89850616455078, 55.09846789496285, 57.145848410470144, 57.58829927444458, 59.39448002406529, 56.88337326049805, 59.58421448298863, 62.21119635445731, 64.03347260611397, 55.972506114414756, 54.77963938031878, 61.882852281842915, 65.7059804371425, 62.281373160226, 65.97680732182094, 64.9272541318621, 62.626448495047434, 63.95610441480364, 63.79453795296805, 68.49142292567662, 66.58505262647355, 66.30952875954765, 67.70934064047677, 68.67224979400635, 67.34794398716518, 71.10282693590436, 73.20216955457414, 81.71072510310582, 11.799856424331665, 1.4235560468264987, 21.36585831642151, 83.34177303314209, 66.9471024104527, 63.89066628047398, 47.080573286329, 49.59615468978882, 54.71522610528128, 74.5128013065883, 1.622433358005115, 0.387150124247585, 0.19900376296469144, 0.21875365105058464, 0.20097489362316473, 0.2080163364963872, 0.08706588843571288, 0.16459404437669686], [0.045622540305235555, 0.17023248039186, 0.03344414629308241, 0.06250760265226875, 0.05777050541447742, 0.11526776477694511, 0.07800758842911039, 0.49495221248694826, 0.40271593470658573, 10.557010429246084, 61.59442561013358, 44.45954949515206, 43.362487997327534, 30.259522983006068, 44.57417392730713, 44.99350813456944, 76.51407705034528, 19.91254183224269, 0.441911265786205, 6.084823250770569, 69.99144172668457, 65.30385344369071, 64.44946820395333, 60.53511714935303, 59.425983156476704, 60.663366998944966, 62.42976583753313, 64.61268138885498, 59.4320558820452, 47.532720361437114, 56.034206117902485, 51.89227376665388, 59.011981691632954, 58.816980498177664, 55.66720921652657, 54.57655395780291, 56.41503688267299, 59.10149533408028, 57.94439097813198, 59.846022605895996, 59.940907205854145, 58.68215765271868, 56.23302187238421, 57.411217485155376, 55.59555244445801, 52.56832306725638, 49.96915136064802, 42.01629536492484, 41.91845083236694, 42.53696557453701, 42.60733692986624, 41.204843044281006, 39.27543599264962, 38.777903284345356, 39.071832929338726, 38.124539852142334, 38.96130098615374, 38.52552386692592, 37.88103328432356, 38.01348679406302, 37.56509174619402, 38.374883447374614, 41.33695956638881, 44.32414647511074, 40.96582848685128, 36.66446624483381, 39.4083446093968, 37.60402250289917, 36.89983647210257, 37.86626836231777, 37.87047897066389, 38.022314480372835, 36.6344222341265, 36.112852232796804, 35.36761277062552, 41.20597560065133, 41.12674529211861, 38.70812599999564, 40.96259757450649, 38.60079370226179, 38.79618399483817, 38.45896707262312, 38.48490469796317, 36.55896132332938, 38.660805293491904, 37.85175704956055, 36.68194791248867, 38.677355902535574, 37.566088812691824, 41.410141468048096, 39.105806146349224, 36.65824065889631, 35.205605098179404, 36.34428630556379, 38.71131869724819, 36.32197911398751, 36.56211233139038, 37.3093181337629, 36.56195599692208, 40.513132504054475, 40.33888210569109, 38.969795158931184, 40.84047951017107, 38.374591623033794, 36.635040623801096, 36.158269132886616, 36.610951219286235, 34.51962334769112, 35.04315274102347, 34.48338501793997, 34.46800170625959, 36.69356182643345, 39.83682612010411, 39.89308915819441, 40.862897872924805, 43.1253251348223, 38.60918712615967, 38.56691428593227, 37.81307642800467, 35.99429859433855, 35.63882875442505, 37.73992231913975, 38.15889522007534, 38.55848612104143, 38.820391518729075, 39.64064025878906, 38.99196686063494, 41.429169109889436, 40.1860008920942, 40.858155727386475, 41.48009940556118, 45.54739073344639, 51.23546402794974, 52.75597654070173, 53.39599595751081, 55.67351123264858, 55.08263989857265, 54.1725891658238, 59.5315123966762, 58.95966870444161, 54.943311146327424, 50.93109818867275, 57.26208135059902, 60.86136286599295, 59.57903807503836, 59.81894547598702, 61.4014185496739, 59.672227314540315, 60.39723709651402, 60.319167137145996, 59.754695483616416, 60.16352054050991, 61.778629302978516, 57.422973837171284, 61.418135915483745, 61.82830892290388, 66.134781564985, 70.23735931941441, 9.160028202193123, 1.1460337042808533, 17.346315009253367, 66.09449590955461, 48.52135522024972, 38.14244883401053, 27.877098594393047, 36.86409493855068, 53.89567913327898, 49.592267172677175, 0.7772078524742807, 0.2195452842861414, 0.020221624290570617, 0.08297253772616386, 0.05182457429223827, 0.0386292768110122, 0.12038002402654716, 0.05666364516530718, 0.020028628575216447, 0.12010293746633188, 0.048132739894624264, 0.06398284634841339, 0.03442062603841935, 0.23937616231186049, 0.05857725641024964, 0.2788565323821136, 0.35494093543716837, 11.77251352582659, 69.89551489693778, 44.003045899527415, 31.42463861192976, 33.46057544435774, 52.754256861550466, 48.58893687384469, 82.73509107317243, 23.409208876746042, 0.5932902299932071, 5.785040616989136, 73.99481310163225, 67.62089007241386, 67.89434337615967, 64.5787741797311, 62.831781659807476, 62.559071813310894, 64.32368496486119, 65.23041793278286, 60.86813041142055, 50.82650695528303, 58.51501178741455, 55.84247405188424, 60.30468709128243, 60.90914562770298, 57.520550864083425, 56.571423462459016, 58.52808829716274, 60.98317173549107, 59.366874831063406, 60.35096904209682, 61.452668462480815, 60.3207791192191, 57.9944041115897, 58.171732561928884, 56.58727925164359, 55.68384320395333, 52.41332265308925, 44.01973894664219, 43.89997284752982, 44.92484951019287, 44.87835911342076, 43.07043089185442, 41.16599219185965, 40.479055064065115, 40.290581703186035, 42.846407072884695, 40.51147883278983, 40.25107772009713, 40.27240521567208, 39.849808829171316, 38.903537137167795, 40.043392590114046, 43.54364143099104, 45.62792035511562, 43.76324619565691, 39.21968364715576, 40.220470905303955, 40.157940592084614, 39.46964509146554, 38.08120741162981, 40.45916584559849, 39.491778578077046, 38.817501068115234, 39.09843063354492, 38.175150530678884, 43.52343259538923, 43.14431456157139, 41.17621994018555, 44.18317794799805, 41.66282313210623, 42.250362804957796, 40.228892121996196, 40.418814182281494, 38.50810473305838, 40.50984600612095, 43.033251081194194, 41.17101226534162, 42.007196698869976, 41.17504916872297, 43.70211941855294, 42.4249849319458, 39.97761051995413, 38.842747347695486, 40.72181817463466, 40.93912655966622, 38.800523144858225, 39.356125422886436, 39.45115940911429, 39.13186536516462, 42.45966339111328, 42.37134831292288, 42.217470032828196, 42.35315098081316, 39.64801924569266, 36.93072121483939, 36.819664682660786, 40.21492624282837, 37.427041462489534, 37.053568840026855, 36.100487913404194, 37.139757769448416, 38.33480623790196, 42.38513701302664, 43.0303258895874, 43.49515342712402, 45.46434586388724, 41.03088099615914, 41.13009779793875, 40.922940731048584, 38.74764040538243, 38.05365433011736, 38.38266542979649, 40.77126502990723, 39.185248374938965, 40.63598360334124, 42.7723114831107, 42.523645877838135, 44.42334590639387, 42.369402817317415, 43.61312689099993, 43.78256218773978, 49.11907400403704, 52.80184159960066, 54.896577562604634, 56.878054414476665, 57.62692083631243, 58.42998668125698, 57.95652253287179, 60.661873136247905, 62.386249269757954, 57.989182540348594, 53.263056073869976, 57.34991352898734, 64.49141447884696, 63.265488215855186, 63.786540576389854, 64.50781222752163, 62.44994340624128, 64.15831783839634, 64.70018005371094, 63.71874005453927, 63.83451788766043, 65.09219741821289, 63.01373413630894, 65.1010216304234, 67.38274751390729, 69.01858970097133, 74.23159381321499, 13.242708921432495, 1.3588122980935233, 19.9245274748121, 73.99268695286342, 56.839217458452495, 47.70630373273577, 36.55784266335623, 44.076088837214876, 60.15306350163051, 60.48288059234619, 0.7827629372477531, 0.12843933728124413, 0.046908242029270956, 0.11543262164507594, 0.02885597731385912, 0.04023661770458732, 0.05068001803010702, 0.09124532488307782, 0.14533386858446257, 0.24273455781596048, 0.2413987394954477, 0.12970038104270185, 0.16324304044246674, 0.39894843686904224, 0.18778040020593575, 0.7324064107877868, 0.6918699145317078, 16.09751180240086, 80.83686406271798, 54.81029135840279, 56.94496209280831, 40.10993201392037, 61.25382491520473, 54.44750159127371, 89.88329356057304, 24.66993519238063, 0.7524158113769123, 9.257822360311236, 81.94587298801967, 69.13570158822196, 72.34470626286098, 66.06734234946114, 65.99435847146171, 64.96271773747036, 66.8627165385655, 66.7043045588902, 67.0135897227696, 52.79486560821533, 56.81181723730904, 56.11149787902832, 63.25804669516427, 63.16000066484724, 60.15211854662214, 59.4900802884783, 60.455692291259766, 62.681408745901926, 63.19057273864746, 63.6031220299857, 64.96596949441093, 62.05327074868338, 58.782295090811594, 58.4016032900129, 60.884896414620535, 55.62994255338396, 53.54032393864223, 47.258871010371614, 44.766475745609824, 47.75702558244978, 47.203785691942485, 45.523992674691335, 45.03139666148594, 41.34558922903878, 43.52607291085379, 44.51455838339669, 41.90475940704346, 41.74475628989083, 44.93979855946132, 43.04542432512556, 41.45554099764143, 42.74053042275565, 47.15520388739449, 48.03781965800694, 45.94332340785435, 40.69764191763741, 43.62739501680647, 42.249025276729036, 42.26723303113665, 41.995784282684326, 43.064174039023264, 42.1326116834368, 41.220500809805735, 41.087550503867014, 40.804321084703716, 46.15635865075247, 46.529775687626426, 43.595235279628206, 46.80648422241211, 43.601537295750205, 45.05603149959019, 43.06079374040876, 42.75740759713309, 41.831379481724326, 44.2373947416033, 44.97872584206717, 45.65770728247506, 45.42960139683315, 42.252763407570974, 46.39346940176827, 48.0733596937997, 42.2768007005964, 41.391687052590505, 42.18942015511649, 44.86969818387713, 41.57427181516375, 43.84296982628958, 42.62637151990618, 41.20092078617641, 45.564389501299175, 46.83941868373326, 45.137061391557964, 47.24471058164324, 44.087886878422324, 39.45157977512905, 40.02253409794399, 41.26476778302874, 41.017252104622976, 39.340877601078574, 38.34036827087402, 39.58234487261091, 40.91414431163243, 45.30260917118618, 45.059456961495535, 46.71915578842163, 48.124435901641846, 43.90920352935791, 43.95335933140346, 44.80213737487793, 42.013019289289204, 39.16577952248709, 42.063459736960276, 43.189397948128835, 42.27710294723511, 43.531426497868125, 46.1491151537214, 44.49163280214582, 47.28253657477242, 44.43479306357247, 45.87415756498064, 46.52353620529175, 52.23861019951956, 54.99920245579311, 58.11830786296299, 60.012946128845215, 61.04810959952218, 60.020061084202354, 58.63139411381313, 63.442104475838796, 65.7596274784633, 59.05165590558733, 54.09792382376534, 59.573896408081055, 64.89782156263078, 64.91713060651506, 64.91954163142613, 65.37054920196533, 65.86523314884731, 65.06451579502651, 66.50822639465332, 65.9782247543335, 67.37201949528286, 69.1810107912336, 65.4967701775687, 68.45580645969936, 70.5293573651995, 72.84920801435197, 79.06343364715576, 15.139784267970494, 1.1667102405003138, 22.575779403959, 82.45282050541469, 62.10102571759905, 57.04226119177682, 40.793822356632774, 53.06352118083409, 69.69777611323765, 70.31173283713204, 1.5642636907952172, 0.3099881261587143, 0.1248186608510358, 0.19577352915491375, 0.14925525816423552, 0.2396210863121918, 0.18016826866992883, 0.11634754469352108], [0.06835090196026222, 0.10380053653248719, 0.05533262069470116, 0.06687316804059915, 0.019083210466695682, 0.15226943285337516, 0.010642343400312322, 0.22383255351866993, 0.21266778904412473, 4.787651896476746, 58.061891964503694, 43.42868348530361, 47.02860770906721, 27.76405140331813, 50.21494041170393, 42.91074044363839, 75.21993337358747, 27.11514002936227, 0.11301698948123626, 0.01399442004705114, 51.65167849404471, 71.16694491250175, 61.712023871285574, 64.40098367418561, 61.00238350459507, 61.94164793831961, 63.06814547947475, 58.1993134362357, 52.33988019398281, 51.85188736234392, 56.863734177180696, 55.73086861201695, 56.787422112056184, 54.00987277712141, 55.90897178649902, 57.20839956828526, 57.917154039655415, 56.82918773378645, 56.31093897138323, 56.77113553455898, 55.71304300853184, 53.31829077856881, 59.1120913369315, 54.02321679251534, 53.5614012990679, 52.539498465401785, 47.05800206320626, 42.51499189649309, 42.81396245956421, 40.731337206704275, 41.48738806588309, 41.467064585004536, 39.8299126625061, 38.38674749646868, 39.56266757420131, 38.37893772125244, 39.106306416647776, 39.710778849465505, 36.78748410088675, 38.889206477573936, 40.738316672188894, 38.008397238595144, 39.72442511149815, 40.9090964453561, 38.60942683901106, 37.408128465924946, 38.14607926777431, 38.59912266050066, 37.726223945617676, 38.1680668422154, 37.565189020974294, 35.77366897038051, 36.81944581440517, 36.303983279636924, 36.261651379721506, 36.835020201546804, 37.60013845988682, 39.928243568965364, 38.35866287776402, 39.83090625490461, 41.11441918781826, 38.262326104300364, 39.31965780258179, 37.314880166734966, 36.777301515851704, 37.23800182342529, 37.150134904044016, 37.399464062282014, 41.96603904451643, 41.58467674255371, 38.929818698338096, 38.58007764816284, 35.09715066637312, 37.26300491605486, 36.723449502672466, 36.02597543171474, 37.027346338544575, 37.02175303867885, 37.560130732400076, 38.547699042728965, 38.29120281764439, 38.51358686174665, 38.40339190619332, 34.90323339189802, 34.11571414130074, 34.32678999219622, 35.288024629865376, 35.474344049181255, 33.87125219617571, 35.71151385988508, 36.29140704018729, 35.52407578059605, 34.72756903512137, 39.11545024599348, 41.58848435538155, 40.786842891148154, 40.773526668548584, 38.45509345190865, 36.78280796323504, 38.252456188201904, 37.16516385759626, 38.03175360815865, 39.72825009482247, 37.99019643238613, 36.71579258782523, 38.44992399215698, 39.03082466125488, 40.700337818690706, 39.215483461107524, 39.840032713753835, 40.80012437275478, 43.41098642349243, 48.54045581817627, 50.092568738119944, 50.94669689450945, 52.91564614432198, 51.8623617717198, 56.15073783057076, 55.98852866036551, 55.61033126286098, 56.106443064553396, 56.07313687460763, 53.63046986716134, 56.34597178867885, 59.91017532348633, 61.05195195334298, 63.257977213178364, 67.46754332951137, 64.57714135306222, 59.960980551583425, 62.04518304552351, 61.62563691820417, 61.30784715924944, 59.96829005650112, 60.04217720031738, 63.28411633627755, 62.41614042009626, 70.36345522744315, 16.568519762584142, 1.4214021052633012, 19.021251235689434, 68.31662709372384, 47.92231280463082, 32.26618010657174, 27.12457742009844, 32.33720459256853, 49.91294738224575, 48.11419425691877, 0.49594640199627193, 0.15318940420235905, 0.05337238052327718, 0.057513625627117496, 0.04519560607150197, 0.026515229971015027, 0.059327193668910434, 0.026952902021418725, 0.016372915989320194, 0.11768391941274915, 0.007412631214330239, 0.12559426708945207, 0.043433599905776124, 0.139519529151065, 0.024012872550104345, 0.3108283153602055, 0.22811622651559965, 5.761025471346719, 68.96230234418596, 46.40704965591431, 46.49189410890852, 31.00570045198713, 57.78843171255929, 48.57789618628365, 81.53029428209577, 30.569120815822057, 0.07368880124496562, 0.07999209301280123, 53.060279846191406, 73.59397847311837, 64.57045023781913, 67.14428533826555, 63.29697745186942, 64.7096643447876, 66.71071079799107, 61.00078541891915, 56.67931161608015, 53.02750171933855, 60.212672097342356, 59.453970500401084, 59.68755504063198, 57.49662126813616, 59.980018615722656, 58.903068678719656, 58.78941699436733, 57.59469509124756, 58.269010816301616, 57.730900628226145, 57.37459005628313, 55.40797192709786, 59.77881962912423, 56.495472703661235, 55.560530049460276, 52.71737582342965, 48.625609466007774, 42.98916823523385, 43.65193952832903, 43.945077078683035, 43.69543872560774, 43.60587991986956, 42.741096700940815, 41.72725377764021, 42.017149993351524, 41.58032022203718, 42.07878398895264, 40.80652018955776, 38.385337012154714, 40.27377053669521, 42.49383463178362, 40.53652014051165, 42.69807692936489, 41.946038654872346, 41.39509514399937, 39.33170597893851, 38.98798554284232, 39.178515570504324, 39.28107792990548, 39.99305983952114, 38.96855837958199, 37.59694576263428, 38.70428017207554, 37.42794820240566, 38.260450090680806, 41.506936822618755, 39.795863015311106, 42.75654602050781, 40.40968424933297, 40.32830694743565, 41.77674232210432, 41.09964384351458, 40.9444454056876, 40.42316722869873, 40.80843441826956, 39.19197423117501, 40.269528661455425, 40.88025794710432, 42.85852473122733, 46.24099118368966, 41.23295545578003, 42.02153083256313, 40.700226647513254, 40.658697264535085, 39.736504554748535, 38.208585262298584, 39.58422436032976, 39.94104215076992, 39.573899337223594, 40.35202462332589, 40.739251204899375, 41.4112114906311, 41.83406148638044, 38.07003123419625, 36.64947203227452, 36.97084706170218, 37.66060168402535, 37.9822998046875, 36.24221379416329, 36.798483099256245, 39.25405985968453, 37.26839671816145, 37.71427999223982, 40.56141553606306, 42.69853203637259, 43.040428570338655, 42.01183809552874, 40.96238912854876, 38.67450366701399, 39.18053749629429, 39.27880239486694, 39.43642575400216, 41.69437837600708, 40.82830626623971, 40.31026247569493, 41.22399575369698, 41.82336820874895, 42.67564467021397, 42.16387857709612, 42.195267064230784, 43.86261933190482, 45.65236064365932, 51.55017573492867, 53.47796038218907, 53.107544967106406, 56.01497003010341, 54.02885525567191, 58.49073478153774, 58.11049461364746, 56.9257572719029, 58.24508122035435, 59.777291025434224, 54.16945552825928, 56.29284586225237, 61.62294796534947, 65.26892484937395, 67.2819847379412, 69.5354870387486, 65.05477442060197, 63.73437350136893, 66.75708307538713, 66.62713786533901, 64.08541733877999, 64.39250687190464, 62.21821403503418, 68.81454890114921, 66.4984711238316, 76.46912915366036, 19.468124628067017, 1.3063921566520418, 23.109216928482056, 75.25185339791435, 52.90172890254429, 41.2376628603254, 35.13400043760027, 33.415794304439, 53.97158472878592, 55.54446234021868, 0.5380058022482055, 0.11400678886898927, 0.12215984852186271, 0.01788879545139415, 0.05520656245893665, 0.059293857243444235, 0.004093336290679872, 0.03067872254177928, 0.09083928274256842, 0.24887445835130556, 0.1313038949987718, 0.3257229189787592, 0.13506307399698667, 0.20944043222282613, 0.10550307588917868, 0.5511498398014477, 0.41795037580387934, 9.122111882482256, 82.44201605660575, 55.979228496551514, 60.37136895315987, 35.88468033926827, 69.11438451494489, 54.345759119306294, 88.73655591692243, 32.9820773260934, 0.24174989493829863, 0.971752907548632, 61.22359330313546, 74.3752269744873, 68.18250601632255, 69.74694156646729, 68.05383927481515, 67.3051986694336, 69.26624434334892, 61.94985376085554, 60.82343264988491, 54.69239779881069, 58.68893214634487, 61.850807189941406, 61.79074001312256, 58.147584097726, 62.05785655975342, 61.09731674194336, 60.53382478441511, 58.262236322675435, 60.340671811785015, 59.251416615077424, 60.71886226109096, 56.690790040152415, 62.82062285287039, 58.09627512523106, 58.46755559103829, 54.93291316713606, 51.34891421454293, 44.759343419756206, 46.38121277945382, 45.54011249542236, 45.72476782117571, 44.12643895830427, 46.63374505724226, 43.632220540727886, 44.78521156311035, 42.20431014469692, 43.16815035683768, 44.65043388094221, 42.421952043260845, 43.01885788781302, 45.464773178100586, 42.30525357382638, 45.24334798540388, 44.34780856541225, 43.17278133119856, 40.785755498068674, 41.42646278653826, 42.08302239009312, 41.88828175408499, 41.54906375067574, 42.47514050347464, 38.45140743255615, 40.18498992919922, 40.36979464122227, 41.10575825827462, 44.43767656598772, 42.7464850289481, 45.1221227645874, 44.74450901576451, 43.883929456983296, 45.85342066628592, 42.837051323481965, 44.81705168315342, 43.407053743089946, 45.00899566922869, 42.444016047886436, 43.388408252171104, 44.726551396506174, 46.637847968510215, 48.91200378962925, 44.810200759342735, 46.76323863438198, 44.323955399649485, 44.630106925964355, 42.43889175142561, 40.0919257572719, 42.148696763174875, 42.35221297400338, 42.23567083903721, 43.746664319719585, 44.75606039592198, 44.560930660792756, 47.44786548614502, 40.22492470060076, 38.88598598752703, 41.16406406675066, 40.0909286907741, 40.271460260663716, 37.479747022901265, 39.309607233319966, 41.055950096675325, 39.181242738451274, 41.56276559829712, 44.06110157285418, 46.271379130227224, 47.160293442862375, 43.23342520850045, 42.00372954777309, 41.154076031276155, 43.319002696446006, 42.48100478308541, 42.46847023282732, 45.0992180279323, 43.86810840879168, 41.079754625047954, 43.29827274594988, 44.63297305788313, 44.5390751021249, 43.532044887542725, 44.70796843937465, 46.7257843698774, 48.13767569405692, 55.91032668522426, 55.63665451322283, 55.46369647979736, 58.358003343854634, 56.69644587380545, 60.452586446489605, 60.40411581311907, 61.169807297842844, 60.346272059849326, 60.110241753714426, 55.19263335636684, 58.78849288395473, 63.20424679347447, 67.05810683114188, 69.4705422265189, 68.53844138554165, 65.78883075714111, 68.6121826171875, 68.88940184456962, 69.31550707135881, 67.12845039367676, 68.01829923902238, 65.96795531681606, 71.83630657196045, 69.2976085117885, 80.46929740905762, 21.18797401019505, 1.3284760287829807, 25.15933677128383, 83.74264935084751, 60.14835262298584, 52.0141521181379, 40.68100445611136, 46.23648875100272, 63.543291091918945, 68.5496905190604, 1.1366376770394189, 0.2841378418462617, 0.2124150890324797, 0.1396053774016244, 0.1839355765176671, 0.14849977727447236, 0.10354604518839292, 0.11781692584710461], [0.029602321729596173, 0.039651282863425355, 0.09666644648781844, 0.11587278731167316, 0.06753523501434497, 0.03796969327543463, 0.021776702720671892, 0.07201284689030477, 0.03768568905070424, 2.799550371510642, 56.939580712999614, 48.97317920412336, 34.65644727434431, 29.11099444116865, 45.518204825265066, 39.945627961839946, 72.25049563816616, 36.67320013046265, 0.36383392395717756, 0.31308216441954884, 25.06055770601545, 80.07759271349225, 59.148319244384766, 63.348908288138254, 60.1342408316476, 64.22268595014299, 59.68289279937744, 57.794768469674246, 49.42702163968767, 59.31948811667306, 56.37059620448521, 54.84537628718785, 61.31708131517683, 56.94084528514317, 55.682519572121755, 55.325816426958355, 55.20946536745344, 55.9745488848005, 54.02612461362566, 56.06464965002877, 59.349407059805735, 59.80392347063337, 52.766648973737446, 52.33094481059483, 53.22127308164324, 49.62505572182791, 44.477201393672395, 40.59306458064488, 41.54775748934065, 42.51609666006905, 42.85502978733608, 44.63200378417969, 42.43912104197911, 40.65605000087193, 41.09645809446062, 37.05241196496146, 41.45903941563198, 42.114806924547466, 39.620386259896414, 37.530399390629356, 41.998476709638325, 39.24528775896345, 39.83315747124808, 38.50669077464512, 40.02727276938302, 38.826769965035574, 38.73560265132359, 37.52572325297764, 38.67313487189156, 37.05479867117745, 38.12063496453421, 36.339683123997276, 36.54102802276611, 37.03986004420689, 34.867967809949604, 37.5183755329677, 35.01773623057774, 38.66734702246529, 40.541731289454866, 41.48629372460501, 40.77726827348982, 39.033089773995535, 40.237803186689106, 36.910369941166465, 38.40487534659249, 37.48318985530308, 38.54424231392996, 36.54325144631522, 41.20839704786028, 44.621661390577046, 38.547778947012766, 37.31389004843575, 37.042444774082725, 36.510337829589844, 38.77152483803885, 40.443761689322336, 38.48145144326346, 38.593800340379985, 38.88221311569214, 36.202147006988525, 35.81404495239258, 36.49954727717808, 34.953316007341655, 35.515651089804514, 35.05756330490112, 34.85615587234497, 34.600840841020855, 33.9096166746957, 34.998534883771626, 35.64373765672956, 35.33210400172642, 37.220054626464844, 37.58195849827358, 35.737920488630024, 37.61716154643467, 39.16518545150757, 40.51575892312186, 36.270242827279226, 37.45068965639387, 37.660493986947195, 35.43173769542149, 42.33246619360787, 38.27068478720528, 38.581658363342285, 39.01271765572684, 40.91750029155186, 40.43852274758475, 39.28992646081107, 39.96762595857893, 40.427853788648335, 39.5553754397801, 40.706452233450754, 45.19947011130196, 48.694942065647666, 52.698910985674175, 50.56817293167114, 55.83350740160261, 55.56307309014456, 55.700991358075825, 56.3998133795602, 55.44692005429949, 57.05294752120972, 57.422501359667095, 55.39789703914097, 54.2218588420323, 55.557365145002095, 60.03196334838867, 66.70555523463658, 83.07550416673932, 59.17823818751744, 60.08154569353376, 61.27141775403704, 60.64649677276611, 60.16948904309954, 60.727610043116975, 62.953034673418315, 66.42074857439313, 72.60366562434605, 18.888853311538696, 1.1749667631728309, 25.713412182671682, 61.25322042192732, 50.40235417229788, 25.329607588904246, 27.11844389779227, 40.590584073747905, 45.26201432091849, 50.13393136433193, 0.39125365976776394, 0.18089891517800943, 0.05575240995468838, 0.04532858197178159, 0.10995114435042654, 0.06393047023032393, 0.06855026911944151, 0.029019344797624008, 0.05441221847598042, 0.07721892039158515, 0.09001370918537889, 0.04890895342188222, 0.024286364571058323, 0.06394114358616726, 0.029641961745385612, 0.1190128709588732, 0.07002536353788205, 3.5495821365288327, 63.56765842437744, 53.05528061730521, 36.15131746019636, 34.21610518864223, 52.48303740365164, 47.12905434199742, 76.73854555402482, 40.34693854195731, 0.3418863016579832, 0.21477014837520464, 25.072927236557007, 81.29516724177769, 61.18983200618199, 68.46709033421108, 61.561581475394114, 66.1882687977382, 61.35773522513253, 63.3168215070452, 53.395575591496055, 61.760869707380024, 62.36201395307268, 57.871549538203645, 63.04086685180664, 57.48659154347011, 58.27967630113874, 56.98469884055001, 58.168268884931294, 57.440518038613455, 56.709974016462056, 58.09212357657296, 59.37657451629639, 61.78773839133126, 55.11807223728725, 54.23956632614136, 55.01920631953648, 50.80710758481707, 45.763187885284424, 42.9490111214774, 43.32368925639561, 43.73464741025652, 44.33804634639195, 46.10854114804949, 44.16367782865252, 44.02665935243879, 43.036012990134104, 38.622861180986675, 43.91839599609375, 44.28218630381993, 41.02726445879255, 41.05055482046944, 42.448348249707905, 41.105025223323274, 42.32180070877075, 41.994238308497835, 40.671989168439595, 39.85836206163679, 41.818087577819824, 37.964654854365754, 40.70083114079067, 37.3155471937997, 39.85104213442121, 37.38127367837088, 39.60920313426426, 40.20878056117466, 38.10424416405814, 40.47620630264282, 38.88530158996582, 41.763575485774446, 42.49194124766758, 43.47944007601057, 42.281334400177, 40.59852239063808, 41.11358540398734, 41.468544551304404, 41.09528384889875, 39.375566482543945, 39.700471196855815, 40.130397932870046, 44.625663552965435, 46.635329246520996, 39.831079959869385, 40.40926735741751, 41.43039894104004, 41.03693635123116, 40.28986603873116, 41.9118708883013, 42.07521261487688, 41.392948150634766, 40.39032309395926, 40.520466327667236, 39.86800616128104, 39.7853364944458, 38.40777621950422, 39.08529506410871, 38.03644016810826, 36.471424443381174, 35.821118218558176, 37.11116940634591, 38.54093149730137, 38.59201117924282, 37.01218884331839, 39.56630843026297, 40.517471654074534, 38.30594342095511, 41.08532360621861, 41.8148775100708, 41.79838596071516, 39.90526587622506, 39.83455753326416, 39.35696962901524, 39.648488249097554, 45.23542356491089, 41.67136246817452, 40.821993827819824, 40.694358893803184, 42.25100898742676, 42.89490897314889, 42.18138803754534, 42.645920276641846, 41.73190907069615, 41.86672496795654, 43.22196762902396, 47.83944858823504, 51.031037603105815, 54.76413447516305, 54.63904605593, 57.45646415437971, 57.88039459500994, 56.690456526620046, 58.79696273803711, 56.25910540989467, 61.406824248177664, 59.78107779366629, 58.34790761130196, 54.62191179820469, 56.19197538920811, 61.150220326014924, 70.24149349757603, 80.07691873822893, 63.59356130872454, 65.51562064034599, 64.84097834995815, 65.08758381434849, 63.47108541216169, 64.19109943934849, 66.46381350925991, 67.98034123011998, 76.38210991450718, 19.699442318507604, 1.1026537120342255, 31.632514817374094, 69.27375534602574, 59.95817347935268, 35.06417451586042, 34.879852703639436, 47.05108165740967, 51.86516189575195, 56.998536178043906, 0.5215886746134076, 0.08744719797479254, 0.08482871776712791, 0.07472764514386654, 0.046993299786533625, 0.10581750223147017, 0.058430597851318974, 0.024455742178750888, 0.1430047835622515, 0.20190665791077272, 0.20488620017256054, 0.25263533368706703, 0.25398610691939083, 0.1850719191133976, 0.16986098246915, 0.2508165884230818, 0.24561056920460292, 5.064389092581613, 76.50796263558524, 61.56387438092913, 44.51415538787842, 37.76636368887765, 64.00718062264579, 51.11728211811611, 83.43963146209717, 44.42183467320034, 0.4953213898198945, 0.2753474478210722, 31.245812824794225, 83.89619064331055, 62.3826014654977, 71.5621862411499, 64.20743465423584, 68.56005723135812, 62.98029245649065, 64.0675048828125, 54.39881903784615, 58.405758312770296, 61.70805644989014, 60.71571472712925, 66.0474774496896, 61.53054387228829, 59.71406241825649, 59.34593990870884, 59.34134714944022, 60.21980094909668, 59.43831620897566, 60.230987548828125, 61.09602437700544, 63.87879180908203, 57.864528383527485, 54.61280965805054, 57.550282205854145, 53.258477210998535, 47.68321486881801, 43.630146503448486, 47.02395589011056, 45.79966940198626, 47.19272763388497, 50.07020943505423, 46.45989418029785, 45.452200412750244, 46.73012004579817, 39.86075571605137, 45.954311983925955, 46.26107495171683, 42.90155145100185, 42.484920092991416, 46.12812464577811, 43.963771206992014, 45.374731472560335, 44.90718718937465, 44.47846596581595, 42.73839732578823, 43.942349910736084, 41.60930115836007, 43.00538880484444, 39.0090594291687, 43.97557619639805, 39.27224676949637, 41.166812079293386, 42.01000724520002, 40.25881453922817, 42.634229932512554, 42.415434632982524, 45.55767754146031, 45.23635114942278, 48.567136900765554, 45.61502449853079, 44.78790399006435, 45.916041306086946, 44.864775385175435, 46.61731604167393, 43.53141607557024, 43.86246994563511, 41.70876462118966, 46.42660883494786, 49.68185377120972, 43.66044064930507, 43.58826276234218, 45.48086520603725, 43.496379784175325, 43.62316008976528, 47.74345227650234, 45.70420462744576, 42.17046546936035, 45.62145158222744, 42.8796055657523, 41.02141407557896, 44.39172812870571, 43.417156423841206, 41.72915758405413, 40.455396447862896, 36.85070923396519, 38.79463454655239, 39.41968754359654, 40.20920787538801, 39.6740402494158, 40.05445759637015, 40.829376288822715, 42.67621789659773, 40.98225055422102, 43.309834548405235, 42.85490124566214, 45.61319712230137, 41.759458678109304, 41.3721660886492, 43.692127908979145, 40.90997191837856, 48.07054219927107, 44.438691002982004, 43.59919227872576, 43.77061823436192, 45.88742167609078, 45.21642371586391, 43.37245518820626, 44.64057091304234, 44.777961117880686, 43.447725023542134, 44.96604190553938, 50.227652141026084, 53.36888756070818, 57.8366938999721, 57.07075922829764, 61.24682807922363, 62.21821403503418, 58.549634660993306, 60.6671051297869, 58.600655283246724, 64.32430335453579, 62.61049543108259, 57.81103767667498, 55.36334364754813, 58.11352055413382, 63.62923336029053, 75.0645021711077, 72.79925741468156, 63.601697649274556, 66.5809462411063, 66.3979445866176, 69.15683106013707, 68.56908294132778, 69.3210447856358, 72.14464678083147, 73.77785560062954, 80.42038903917584, 26.084859405245098, 1.196493693760463, 35.337381158556255, 77.63010365622384, 66.67883941105434, 40.62453644616263, 38.712256704057964, 57.64744928904942, 60.79658481052944, 67.81117343902588, 0.9040408123816762, 0.23686924683196203, 0.1738381204860551, 0.1752455649631364, 0.17871970497071743, 0.17820020498973982, 0.16288830233471735, 0.04983055325491088], [0.1013611149308937, 0.060783845505544117, 0.08670720803950514, 0.010910023768831576, 0.09188374491142375, 0.05447443674451538, 0.15207900878574165, 0.1026300432692681, 0.04351894264774663, 0.7419914507440158, 46.08290229524885, 42.8993627684457, 49.885237966264995, 29.96656608581543, 38.37590135846819, 35.388867310115266, 60.07609830583845, 53.79583004542759, 1.867521618093763, 0.3368897869118622, 6.625188997813633, 72.5693415233067, 62.27827426365444, 61.954564639500205, 61.186913762773784, 63.464158058166504, 61.29966218130929, 49.604374408721924, 60.81253787449428, 60.779943874904085, 48.96819387163435, 61.077410152980256, 55.704600947243826, 57.56159387316023, 55.91989435468401, 56.640314851488384, 55.601166588919504, 56.243242672511506, 60.055649757385254, 59.32623481750488, 53.45068870271955, 50.66422482899257, 51.066615853990825, 56.20367962973458, 52.50061634608677, 47.16009889330183, 42.523809160505024, 41.908924852098735, 41.73184653690883, 45.42427560261318, 45.895408630371094, 47.593510150909424, 44.539346081869944, 42.78434576307024, 39.22836194719587, 40.310279846191406, 44.08567040307181, 46.69710568019322, 44.60441943577358, 42.071321623665945, 38.67930139814104, 38.19049910136631, 39.4970383644104, 42.03978027616228, 42.37462786265782, 39.30815158571516, 37.9683130809239, 37.93585457120623, 37.5641085760934, 37.67600931440081, 38.54364129475185, 38.38376324517386, 36.24429477964129, 33.529432092394146, 34.695947783333914, 37.93838718959263, 35.3209729875837, 40.49539027895246, 40.72597667149135, 38.11326987402779, 41.954536301749094, 39.27374063219343, 38.88134111676897, 37.800114563533235, 38.535018580300466, 37.84340531485421, 39.5619797025408, 37.97615759713309, 43.89420236860003, 47.20653370448521, 38.33333321980068, 38.945511204855784, 38.335831097194124, 38.96007810320173, 38.64642947060721, 37.53348786490304, 38.050270557403564, 39.415192059108186, 39.76508944375174, 36.723227160317556, 37.6338198525565, 35.16667781557356, 34.814226967947825, 34.66146387372698, 34.02578708103725, 36.09004129682268, 35.24259383337838, 34.54328891209194, 34.30384704044887, 36.01661620821272, 34.93885680607387, 35.177523953574045, 35.80101360593523, 36.57417787824358, 36.62971135548183, 36.853026458195274, 42.30069555555071, 39.02745825903756, 37.65542527607509, 38.85330513545445, 42.83156224659511, 46.056071826389854, 39.3943544115339, 36.957645484379356, 38.19375433240618, 42.28839029584612, 43.134104183741975, 42.637627601623535, 42.48596927097866, 40.78439712524414, 38.85480942044939, 40.61615344456264, 43.22252695901053, 47.10487461090088, 49.613240310123985, 52.674102442605154, 52.59403140204293, 55.37341506140572, 58.94384765625, 55.697423458099365, 57.07807568141392, 55.3048780305045, 59.03154781886509, 57.606187411717, 61.736780302865164, 53.68006263460432, 56.23513412475586, 51.948074749537874, 84.0432562146868, 73.18161678314209, 61.887431144714355, 65.70286069597516, 62.48276669638497, 62.381190981183735, 58.70577457972935, 62.28468745095389, 64.3140617098127, 69.31999560764858, 11.36340011869158, 0.6074495730655534, 31.3757997240339, 62.35872745513916, 40.615510736192974, 24.783814430236816, 24.013716050556727, 36.76230730329241, 50.82632630211966, 42.58266387666975, 0.22053385552551064, 0.03540218122569578, 0.09808991796204022, 0.01035373192280531, 0.0516760090499052, 0.0803055761914168, 0.11504310183227062, 0.052219902364803214, 0.08948901841150862, 0.005072435181188796, 0.09037247779113905, 0.034709827841392586, 0.02030420709135277, 0.0586586534710867, 0.0033272615608958794, 0.08822293992021255, 0.06454563007823058, 1.0421801741634096, 53.65010895047869, 50.138437271118164, 50.54008483886719, 42.993052278246196, 47.396949086870464, 40.97920029503958, 65.81848566872733, 55.99212782723563, 2.88197837131364, 0.36977547513587133, 6.78216096333095, 71.42209666115897, 68.831453868321, 64.42462144579206, 65.94520691462925, 63.43396813528878, 64.23307350703648, 52.88647413253784, 64.89825929914201, 67.12543487548828, 53.026216302599224, 63.11679676600865, 58.81753635406494, 60.60868467603411, 58.66443974631173, 59.993241037641255, 57.24342891148159, 57.41751255307879, 62.2092855998448, 60.225859778267996, 54.70767341341291, 51.69458014624459, 52.44171299253191, 57.65647847311837, 55.419554574149, 49.409494808741975, 45.08344561713082, 42.88765852791922, 45.4543091910226, 47.14764077322823, 48.11892598015921, 50.38425758906773, 46.55242681503296, 46.1702480997358, 41.908480167388916, 43.49050508226667, 46.23492193222046, 49.255046776362825, 46.43940394265311, 43.77103165217808, 41.41365725653512, 40.64309161049979, 42.366050311497276, 44.16924680982317, 42.683513505118235, 41.571784360068186, 40.129901136670796, 38.45048679624285, 38.88699000222342, 39.74719088418143, 39.30850594384329, 40.6496958732605, 38.16197327205113, 37.66880750656128, 37.77157483782087, 38.79730265481131, 39.822248799460276, 41.117486817496165, 42.942337376730784, 42.256185395377024, 42.61962134497506, 40.67442798614502, 41.462534359523225, 42.42285530907767, 42.478958538600374, 39.76453011376517, 41.641457421439036, 40.145611013684956, 46.02720553534371, 49.14106852667672, 39.51057692936489, 41.23095090048653, 42.30243607929775, 41.83827556882586, 40.70557676042829, 41.594233989715576, 40.6284031186785, 39.892279693058555, 41.88444634846279, 39.05979517527989, 40.20153706414359, 38.93148626599993, 37.93622977393014, 36.95983764103481, 35.493465491703574, 37.79051562717983, 39.295971393585205, 36.508830070495605, 36.30098165784563, 38.18663590294974, 38.96620294025966, 36.593372276851106, 38.46756199428013, 37.929618562970845, 38.62709263392857, 41.245316301073345, 44.60305758884975, 42.059676442827495, 39.545199802943635, 41.06637934276036, 45.73451614379883, 48.85954489026751, 42.9261862891061, 39.567170006888254, 41.2534213747297, 43.35040160587856, 45.83838129043579, 45.09854752676827, 45.255212034497944, 43.52024337223598, 40.3672377041408, 43.97229664666312, 45.418842111315044, 49.59075593948364, 54.51231786182949, 56.6098678452628, 55.654299463544575, 57.30955491747175, 59.27888284410749, 59.90943186623709, 59.24300234658377, 59.11658682141985, 60.6674108505249, 61.79336643218994, 63.82012816837856, 55.464829036167686, 54.29144157682146, 55.39985990524292, 83.06287234170097, 72.39276695251465, 63.824727875845774, 69.52566228594098, 66.03442178453717, 66.047470501491, 61.71529647282192, 67.96431173597063, 67.94464138575962, 74.56271716526577, 11.298376270702907, 0.5367584377527237, 37.51606525693621, 71.47493076324463, 48.509084701538086, 33.615843364170615, 24.324064288820537, 35.11117907932827, 57.02622127532959, 48.8065961429051, 0.14422711011554512, 0.11956617555447988, 0.1173781036798443, 0.04077264001326902, 0.04689833541799869, 0.052466865362865586, 0.03431574148791177, 0.04798675987071224, 0.3489868720727307, 0.10305808351508208, 0.17926870765430586, 0.15375580452382565, 0.07526237145066261, 0.18042187791849884, 0.1632636407656329, 0.3092978117721421, 0.1790067252836057, 1.4909775661570686, 67.18164580208915, 55.747749260493684, 65.96155602591378, 41.521934509277344, 54.261859621320454, 48.07658018384661, 70.7447932107108, 62.76412010192871, 2.7993985967976704, 0.4339201860129833, 9.982502102851868, 73.99831499372209, 70.18280206407819, 68.71106243133545, 67.53222411019462, 66.23893506186349, 68.72200584411621, 56.60928767068045, 60.64003494807652, 62.87391553606306, 54.00335536684309, 64.87617792401994, 60.70648751940046, 62.36049229758126, 60.8558668409075, 60.5828651700701, 58.80689866202218, 60.741159030369346, 63.60114874158587, 61.98311478751046, 56.985588209969656, 56.3359385899135, 53.16388096128191, 59.05839565822056, 57.2530243737357, 52.02902126312256, 46.41473436355591, 45.61374602999006, 48.02089384623936, 49.30939211164202, 52.02384485517229, 54.89371837888445, 50.05922780718122, 50.00585521970476, 44.220854554857524, 45.28505107334682, 50.154181889125276, 52.82587889262608, 48.93880646569388, 45.039751870291575, 43.16453729357038, 43.613251958574565, 43.49018199103219, 45.4227226802281, 45.443463053022114, 43.36110183170864, 42.84374243872506, 41.13452727454049, 40.41814020701817, 41.704765932900564, 40.233436243874685, 42.98074354444231, 40.49835021155221, 40.15540449959891, 38.66295576095581, 42.216782161167686, 42.50813055038452, 46.98459087099348, 46.4916752406529, 43.461635317121235, 45.93957485471453, 44.4712050982884, 45.44307395390102, 46.71050180707659, 44.328381402151926, 44.38833045959473, 47.33621835708618, 43.99040017809187, 48.074766704014365, 52.06304311752319, 43.38789061137608, 44.0157402583531, 46.41236155373709, 45.21376950400216, 44.16794402258736, 44.0422545841762, 42.6767772265843, 43.593682357243125, 46.60100514548165, 42.85556479862758, 44.50861419950213, 42.620802538735525, 40.85800634111677, 40.953571864536826, 37.14223827634539, 42.39989151273455, 41.71950306211199, 39.34364298411778, 39.34873948778425, 41.59357043675014, 40.65454224177769, 37.99173545837402, 39.79566151755196, 40.22785684040615, 41.770565373556956, 43.88110154015677, 45.980381625039236, 45.199754987444194, 43.22175223486764, 44.86791249683925, 47.40948363712856, 50.90377787181309, 45.02185678482056, 41.92466599600655, 41.986855847494944, 46.00420699800764, 47.37641716003418, 47.170000076293945, 48.10355656487601, 46.419080461774556, 43.8815462248666, 48.397100584847585, 47.79016848972866, 51.984458991459434, 55.92463302612305, 59.39517484392439, 56.315222535814556, 61.52527713775635, 63.05700751713344, 62.64148439679827, 61.17015470777239, 62.119063241141184, 61.971844809395925, 63.892215728759766, 64.83569077083042, 56.27443661008562, 54.710737568991526, 59.685338565281455, 84.02095249720982, 70.07820388248989, 68.37244892120361, 72.5747263772147, 69.50093364715576, 68.62954616546631, 65.65976796831403, 72.13436344691685, 71.8735419682094, 79.72024685995919, 14.735600607735769, 0.6552502481000764, 42.938592297690256, 78.00872489384243, 54.621286460331504, 39.65847281047276, 35.424824237823486, 51.555178437914165, 67.2303248814174, 60.765512466430664, 0.6357086566942078, 0.28585597393768175, 0.33502899961812155, 0.13076759449073247, 0.14527715662760393, 0.136882877775601, 0.13775919218148502, 0.1814288374568735], [0.05478642036073974, 0.1105371814753328, 0.021693816275468895, 0.05750766130430358, 0.14828688012702124, 0.12152339624507086, 0.0670456855690905, 0.02503724499339504, 0.03783763000475509, 0.5645148626395634, 43.8423444884164, 55.73680237361363, 35.265220642089844, 17.589267458234513, 30.96553291593279, 33.54414142881121, 50.80398784364973, 64.37469863891602, 4.55891980443682, 0.3224235288798809, 1.8205726402146476, 42.727332319532124, 65.04053061349052, 57.151903765542166, 62.635974475315635, 59.97400842394148, 50.90472282682146, 60.06457124437605, 65.23767185211182, 43.170196601322715, 57.11962243488857, 58.810782705034526, 58.96251746586391, 55.80655881336757, 56.792372703552246, 53.58190195901053, 57.868092809404644, 58.20825229372297, 54.804969038282124, 50.60402563640049, 53.97306816918509, 54.342927728380474, 55.91441570009504, 53.71756553649902, 53.07835211072649, 44.33821310315813, 42.535332747868125, 42.19703538077218, 44.22668061937605, 47.89999866485596, 50.304589544023784, 47.48179701396397, 48.93505791255406, 44.15629884174892, 42.691726275852744, 39.16028349740164, 43.07998466491699, 49.622950417654856, 51.496070112500874, 43.20188733509609, 40.308897154671804, 42.292844091142925, 43.32375873838152, 44.9919239452907, 43.33288172313145, 40.20552880423409, 38.92024408067976, 39.330031463078086, 37.51377582550049, 36.71522283554077, 36.90447786876133, 35.820454665592735, 35.45253017970494, 34.479226521083284, 36.506359985896516, 37.87990767615182, 37.43611928394863, 37.17353643689837, 39.81460230691092, 41.18187229973929, 41.97129883084978, 41.15303727558681, 40.29344783510481, 39.19463539123535, 38.13460431780134, 41.453334944588796, 41.4637120791844, 39.64877312523978, 43.941981656210764, 50.004854679107666, 42.62315450395857, 40.544562680380686, 41.18510668618338, 40.35936539513724, 39.540124143872944, 37.82661499295916, 37.252665996551514, 39.861804894038606, 37.77770662307739, 37.54544571467808, 35.94926037107195, 33.97729212897164, 35.37375497817993, 34.511702401297434, 34.893874168395996, 34.16412918908255, 36.191109793526785, 34.00626959119524, 35.06827742712838, 34.21990932737078, 36.56805304118565, 36.728483472551616, 38.11832121440342, 36.52466154098511, 38.03073569706508, 38.9437255178179, 39.71436411993844, 38.11901256016323, 38.13976335525513, 42.82324177878243, 49.43423386982509, 44.65239674704415, 38.43116733006069, 38.33943026406424, 41.22840438570295, 44.887061732155935, 47.25162751334054, 46.23934098652431, 43.974815368652344, 42.512445381709504, 40.07403761999947, 40.455156735011506, 40.751351492745535, 46.503845010484966, 50.61880098070417, 53.12273720332554, 55.381933552878245, 54.38216420582363, 54.97167716707502, 55.3384621483939, 57.45543234688895, 55.814455441066194, 56.32312611171177, 57.92018345424107, 60.217619214739116, 61.15290233067104, 55.94716950825283, 53.42030075618199, 67.54382065364292, 66.31595584324428, 55.3702848979405, 63.91868836539132, 65.03926604134696, 64.22202587127686, 62.473998069763184, 64.30823217119489, 65.1072472163609, 64.49601418631417, 4.8779250638825555, 0.339579988270998, 41.1681808744158, 61.34363038199288, 36.82860006604876, 27.385504858834402, 46.01512261799404, 44.354913098471506, 50.369718483516145, 34.95324999945504, 0.013665646929959101, 0.09242532442190818, 0.07131628998156105, 0.037375354274575195, 0.02956048326034631, 0.0326696664227971, 0.058091628897402964, 0.005647054258068758, 0.10516547079065017, 0.010815789673610457, 0.007865632218973977, 0.03953255619853735, 0.05976125930569001, 0.2025324978998729, 0.09044573921710253, 0.06703123955854348, 0.05859113923673119, 1.0138315239122935, 52.1324382509504, 63.4751501083374, 37.05865839549473, 19.24234812600272, 36.001830441611155, 39.02545370374407, 56.545861039842876, 71.44627639225551, 5.623170605727604, 0.30680601405245916, 1.9508578777313232, 43.69935750961304, 64.88025651659284, 61.096128599984304, 64.62623037610734, 62.820094789777485, 54.17907878330776, 68.86913394927979, 76.05476638248989, 45.826430388859336, 59.99641636439732, 59.704626764569966, 62.81952503749302, 58.61901242392403, 59.35841192517962, 54.81409202303205, 59.42423221043178, 60.49588762010847, 57.17496483666556, 52.612569195883616, 54.99408858163016, 56.429503032139365, 59.115037373134065, 54.83786875861031, 55.226113251277376, 46.32611356462751, 44.03737347466605, 44.1719183921814, 46.690174852098735, 51.19899640764509, 52.265298230307444, 48.7594039780753, 51.48472023010254, 45.08320590427944, 43.35879850387573, 43.19327851704189, 46.67469426563808, 49.69549308504377, 52.020561831338064, 45.80892440250942, 42.39578512736729, 44.30139807292393, 45.87355654580252, 45.346441881997244, 44.51583685193743, 42.43140506744385, 39.6366936819894, 39.97892025538853, 40.65201309749058, 39.01561158043997, 40.27301318304879, 37.161950315747944, 36.67769908905029, 37.2637414251055, 38.33959354673113, 39.03659514018467, 41.86477599825178, 39.71655627659389, 43.597705364227295, 43.648093700408936, 42.669554574149, 42.22342116492135, 42.109182357788086, 43.7727096421378, 41.547618525368826, 44.160672732761924, 42.95947510855538, 41.019788197108674, 46.54735115596226, 51.15496219907488, 45.8065515926906, 43.335612365177695, 44.70091949190412, 42.63148191996983, 42.377487046378, 40.18320771626064, 38.08012696674892, 42.102362700871055, 40.0417354447501, 40.174300125667024, 39.187193870544434, 37.326747689928325, 38.474475451878135, 37.45447295052664, 35.951254504067556, 36.735386507851736, 37.980503695351736, 35.435781547001426, 37.03215796606881, 36.373503480638774, 36.95987933022635, 38.59341124125889, 40.67371579578945, 39.117958545684814, 39.90670415333339, 41.005624294281006, 40.725806440625874, 41.26053285598755, 38.9195944241115, 45.773085594177246, 52.45304203033447, 48.73754494530814, 43.22544172831944, 40.55449513026646, 43.20916557312012, 47.39305462156023, 48.56500727789742, 49.54077754701887, 49.643829754420686, 46.04475321088518, 44.36281667436872, 42.01932825360979, 43.34974847521101, 50.07571588243757, 52.98878983088902, 54.487651756831575, 58.25918953759329, 58.39972727639334, 55.666003704071045, 59.59146840231759, 59.41302476610456, 60.01208455221993, 59.2129305430821, 61.25513117653983, 61.17494896480015, 63.92178726196289, 56.92673001970564, 54.75581053325108, 67.9510476248605, 66.76127978733608, 59.18711798531668, 67.84016132354736, 67.49467604500907, 68.00074114118303, 68.2729159763881, 69.53921127319336, 67.04897689819336, 67.64623015267509, 3.835462510585785, 0.26252332595842226, 51.22584772109985, 68.75061157771519, 45.34102923529488, 30.709867000579834, 37.208572728293284, 48.36622279030936, 55.815553256443565, 43.993999344961985, 0.25172528252005577, 0.11401900249932494, 0.04902692352022443, 0.038554909372968335, 0.038648404713187895, 0.056724628500108204, 0.04836412712133356, 0.02229202801494726, 0.22378097128655228, 0.11323688232472964, 0.11288761320923056, 0.13420058813478264, 0.2308695859142712, 0.37167472179446903, 0.24332360763634953, 0.11483770928212575, 0.187511591772948, 1.1042903384992053, 64.53001172201974, 70.15348761422294, 48.6555666242327, 24.376241786139353, 42.62482207162039, 46.34481464113508, 60.82363414764404, 78.36651543208531, 6.529488853045872, 0.3671301385121686, 3.3357022532394955, 51.99014956610543, 65.75538907732282, 62.742059571402415, 64.79261193956647, 66.08296189989362, 58.76842648642403, 62.40359197344099, 65.30791119166783, 51.929220812661306, 61.84997340611049, 61.953904560634065, 63.44641235896519, 60.18216950552804, 60.62292153494698, 57.512619495391846, 61.612664631434846, 62.126602036612375, 56.96137373788016, 55.448851653507774, 58.743183680943076, 57.75471557889666, 60.136429514203755, 58.2621077810015, 58.34236989702497, 49.976134300231934, 47.03874165671212, 47.821508339473176, 48.81616728646414, 53.47792216709682, 53.93272345406668, 50.089438574654714, 53.845217841012136, 47.253041471753804, 46.45406116758074, 44.97478968756539, 47.83604049682617, 52.18909733636038, 55.96654803412301, 48.221085344042095, 44.333533491407124, 48.58137028557913, 47.738439151218955, 47.22092342376709, 44.77709606715611, 42.96559647151402, 41.197047165461946, 43.691311495644705, 44.29386622565133, 40.01622860772269, 41.31748029163906, 39.92151771272932, 38.80496651785714, 38.86072928564889, 41.33127246584211, 42.70623411451067, 45.60156583786011, 42.935323170253206, 47.372192655290874, 48.908720765795024, 45.27588987350464, 43.513420241219656, 45.78477941240583, 46.607251576014924, 43.59507199696132, 47.52613346917288, 44.93055050713675, 44.39262792042324, 49.19370460510254, 54.2627455166408, 47.92654773167202, 45.794812611171174, 46.65063612801688, 49.10724122183663, 46.96867602212088, 43.291484355926514, 40.92651557922363, 45.08328580856323, 41.67033066068377, 42.470283712659565, 42.56661353792463, 41.62785284859793, 42.87303951808384, 39.45982381275722, 39.45749964032854, 38.658363001687185, 41.386944907052175, 38.482048988342285, 39.70284400667463, 38.13735580444336, 40.18212727137974, 41.36221974236624, 43.8100631577628, 41.22088296072823, 42.29711375917707, 42.68271446228027, 44.089457171303884, 44.508655888693674, 41.129635742732454, 47.53333180291312, 54.82914876937866, 49.74660750797817, 45.03967891420637, 43.430712359292166, 45.964758600507466, 51.97609336035592, 51.557460921151296, 52.60083021436419, 52.05026190621512, 47.727728503090994, 45.992110184260774, 45.48967899594988, 43.59248726708548, 51.6574524470738, 56.78360407693045, 58.85866274152483, 60.465913091387065, 59.855590275355745, 59.04719516209194, 60.77145317622593, 61.70904309409005, 62.09835066114153, 60.20430646623884, 63.921842847551616, 63.327959469386506, 67.01547268458775, 58.1086220741272, 55.4274650982448, 70.665938104902, 70.24559293474469, 60.05203669411795, 71.2308544431414, 69.42023726872036, 71.9315663746425, 70.61568178449357, 74.49272796085903, 70.8078898021153, 72.74207374027797, 6.949757593018668, 0.2931069348539625, 55.950143337249756, 76.08584567478725, 52.48631695338658, 39.8969349861145, 59.418993268694194, 65.4684910093035, 66.53173909868512, 56.313224928719656, 0.7736415809818676, 0.23967925033399037, 0.16628352871962956, 0.08896709606051445, 0.15945620435689176, 0.19401149584778718, 0.17310398630797863, 0.21114749062274182], [0.012093509281320232, 0.09194992243179254, 0.08409411539988858, 0.04991997399234346, 0.06946155522018671, 0.04674544790759683, 0.03917001833074859, 0.029690395575016737, 0.13142384641936847, 0.3700712892626013, 41.286453110831125, 54.097798756190706, 48.68358176095145, 43.511936800820486, 30.4842346736363, 30.84153536387852, 46.33785949434553, 68.9190011705671, 16.112978492464336, 0.07334353548607656, 0.05081581324338913, 22.540560722351074, 58.99054649897984, 57.916184765951975, 62.941201891217915, 56.492797647203716, 58.73046152932303, 46.04675429207938, 36.62500742503575, 49.986553124019075, 60.27124541146414, 56.676838057381765, 56.45446443557739, 54.22218540736607, 54.66720710481916, 56.77676704951695, 59.92358534676688, 51.11258166176932, 54.73651191166469, 56.545079367501394, 55.51067672457014, 53.00627497264317, 54.92476293018886, 55.432165554591585, 45.02761336735317, 39.755688531058176, 41.02847344534737, 43.11062969480242, 47.06516913005284, 51.50873667853219, 52.50685235432216, 50.60652698789324, 51.33117546354021, 47.43049846376692, 43.767415114811485, 42.00809301648821, 42.38816295351301, 50.222312450408936, 49.60487815311977, 43.25074706758772, 43.05116353716169, 42.71837609154837, 45.231518677302766, 46.961449895586284, 43.85737691606794, 42.56028025490897, 39.74869516917637, 34.83278560638428, 35.76938888004848, 37.02829476765224, 36.72014216014317, 36.90078837530953, 36.373194285801475, 35.4553268296378, 37.54006086077009, 36.642259802137104, 36.23688799994332, 39.78685120173863, 35.18475008010864, 38.947331632886616, 44.33766072137015, 40.68453761509487, 39.72095101220267, 37.73177555629185, 40.49832936695644, 40.40629352842058, 41.21383053915841, 45.719935349055696, 47.267823764256065, 48.69506713322231, 47.079350403376985, 40.286482266017366, 41.384339332580566, 41.48313924244472, 41.758027349199565, 38.77014214651925, 39.32127673285348, 37.97825595310756, 38.11470120293753, 38.40181119101388, 33.1624629838126, 34.44182436806815, 34.886620249067036, 33.65012230191912, 34.72293111256191, 33.134131704057964, 31.672678879329137, 34.180735383714946, 35.80071135929653, 35.30206346511841, 37.2817268371582, 37.326980454581125, 33.78189141409737, 36.7816093989781, 38.214915071214946, 41.70605829783848, 42.17878941127232, 43.17053358895438, 40.83698456627982, 46.628690242767334, 48.95728519984654, 44.7819424356733, 39.50902400697981, 41.84673152651106, 43.97168867928641, 50.21887656620571, 48.1720414842878, 49.847745486668174, 49.17999233518328, 48.20491688592093, 41.57390356063843, 40.90373591014317, 38.02500343322754, 43.32693753923689, 47.68424320220947, 51.747306551252095, 54.13959564481463, 55.5811835697719, 54.82459422520229, 57.08432558604649, 55.49754810333252, 55.93646580832345, 54.52903870173863, 59.0800392968314, 58.01049613952637, 61.30371992928641, 57.22537054334368, 57.30514281136649, 63.359636306762695, 58.465526717049734, 57.01670571735927, 58.94322231837681, 62.54354953765869, 64.66359778812954, 61.27180685315813, 64.92737919943673, 62.660578046526226, 57.13113559995379, 1.009926962000983, 2.2465271779469083, 47.45820787974766, 61.39764567783901, 37.12482956477574, 56.55146476200649, 89.16613524300712, 28.454497371401104, 53.40244041170393, 25.029280390058243, 0.10198742310915675, 0.0619274823527251, 0.03015416068956256, 0.018928764022088478, 0.0603628009557724, 0.14281277172267437, 0.05378214442836387, 0.023175997992179224, 0.021680116653442383, 0.028286362432741692, 0.06883952181254115, 0.046568679357213635, 0.07058278005570173, 0.0737804781113352, 0.05751466378569603, 0.04535757916580353, 0.08831129196499075, 0.4175339995750359, 49.00738865988595, 59.760080337524414, 50.84552764892578, 41.772767952510286, 32.107125418526785, 33.21509211403983, 50.71449504579817, 78.60838222503662, 19.728656019483292, 0.027333395622138466, 0.05599664863465088, 25.809248685836792, 61.74176216125488, 58.27861670085362, 64.06200190952846, 59.93621717180525, 65.14888777051652, 54.544925757816856, 41.34712478092739, 51.640846252441406, 63.49409784589495, 59.716209411621094, 60.19562121800014, 56.401206493377686, 57.58365787778582, 60.01292528424944, 62.72696113586426, 51.954800605773926, 56.108895778656006, 58.327750887189595, 59.1709634235927, 54.73618187223162, 56.45742784227644, 56.91597073418753, 48.0825834274292, 41.130281925201416, 43.07415165219988, 45.510881423950195, 49.89439916610718, 53.888470377240864, 54.246705600193565, 53.68144185202462, 52.30036926269531, 48.47505242483956, 48.28328561782837, 43.99776874269758, 44.725797516959055, 51.95262929371425, 52.20687777655465, 47.15578753607613, 45.85680443899972, 46.4222731590271, 47.65000942775181, 48.747199467250276, 44.34503970827375, 42.20162466594151, 41.86973006384713, 37.18275669642857, 37.731813771384104, 38.066699572971885, 38.239859104156494, 39.77862106050764, 38.88041353225708, 37.290502411978586, 38.040126187460764, 39.09160055433001, 40.3636281149728, 40.7174824987139, 37.9371087210519, 41.75167669568743, 45.20698111397879, 41.91429928370884, 42.12782784870693, 40.98164258684431, 43.568651471819194, 43.80660990306309, 43.87219394956316, 47.57328394481114, 48.24112047467913, 50.78652354649135, 48.795690945216585, 43.28669704709734, 44.178776264190674, 44.623495715005056, 44.69292211532593, 42.02003002166748, 41.50178125926426, 40.74356256212507, 41.42433663776943, 41.80051905768258, 37.30275903429304, 39.067090783800396, 36.367416858673096, 37.129286834171836, 39.02641255514962, 35.459912640707834, 33.659596170697895, 36.922254834856304, 36.81807007108416, 37.248368535723, 38.869004590170725, 39.56605134691511, 35.37929964065552, 38.64618280955723, 39.770126887730186, 43.025319712502615, 46.555150508880615, 45.74290956769671, 43.435127939496724, 50.66874463217599, 51.144418307713096, 47.6145076070513, 41.13699735913958, 44.11927883965628, 46.90554468972342, 52.036400250026155, 52.21048389162336, 54.5970824105399, 52.386242049080984, 49.82793269838606, 45.17648894446236, 44.50775957107544, 40.85962527138846, 44.597064767565044, 49.41686337334769, 53.99097715105329, 57.18727357046944, 57.237526416778564, 57.800323554447715, 58.58312497820173, 58.426630701337544, 58.206411021096365, 58.06361859185355, 63.212424823216026, 60.821028573172434, 65.156982421875, 60.60225759233747, 58.7727552141462, 66.63273116520473, 62.40761498042515, 58.23360627038138, 63.184770992824006, 64.55254473005022, 67.87677138192313, 63.7477696282523, 68.83190550122941, 66.93408148629325, 56.374664374760215, 0.7504039279052189, 3.0854209746633257, 57.29188217435564, 67.98564965384347, 44.63889292308262, 67.47859791346959, 92.67032718658447, 33.18028163909912, 63.56388555254255, 31.051798275538854, 0.2662226988800934, 0.05296726458306823, 0.04599031646336828, 0.011763722602544087, 0.03134870123384254, 0.10978623319949422, 0.0489614754250007, 0.042040879638599496, 0.11783274928373949, 0.23524526825972966, 0.1647804243756192, 0.11376401582466704, 0.08987264854035207, 0.17439880754266465, 0.14213416885052407, 0.15434249304234982, 0.2105446801121746, 0.8385556148631232, 59.80994061061314, 72.58094501495361, 61.814683505467, 57.099535192762104, 45.87118026188442, 42.237946374075754, 60.454121998378206, 83.86703600202287, 21.11512041091919, 0.1829034976129021, 0.7711730705840247, 30.53904206412179, 67.10600771222795, 59.74261951446533, 68.4605381829398, 62.52382360185896, 62.49707303728376, 43.81785208838326, 47.35853944505964, 57.31293869018555, 64.47780990600586, 62.65920925140381, 61.06611238207136, 58.95000376020159, 57.27921213422503, 58.548905100141255, 65.37752519335065, 56.83241517203194, 58.57605866023472, 59.22395733424595, 60.099006516592844, 58.33487973894392, 59.14712415422712, 59.761476925441194, 50.77140426635742, 42.75354092461722, 46.69336060115269, 46.72051763534546, 50.8261456489563, 57.81869459152222, 56.574991362435476, 55.55093806130545, 54.49215071541922, 51.1831545148577, 49.57024138314383, 47.04869147709438, 47.99605751037598, 55.67290326527187, 53.88551391874041, 48.912142753601074, 48.79138306209019, 47.66460411889212, 49.50329896381923, 51.92764704568045, 47.69447789873396, 45.829713412693565, 43.65726184844971, 39.259646211351665, 39.218578883579795, 39.830273968832834, 40.04129770823887, 42.622518743787495, 40.40600170407976, 40.765894072396414, 41.92456177302769, 43.25748334612165, 43.41579457691738, 46.95907013756888, 41.7430157661438, 45.87036732264927, 50.345656871795654, 45.86569465909685, 45.067464760371614, 42.075848375047954, 46.54495750154768, 45.56150599888393, 46.76950938361031, 48.97287000928606, 49.57599449157715, 51.73134306498936, 49.98233209337507, 46.886555262974326, 47.91784858703613, 47.720457213265554, 47.329120772225515, 45.3105857031686, 43.269805976322715, 42.805193832942415, 42.12011882237026, 46.45514161246163, 40.86900533948626, 42.38293443407331, 39.62372486931937, 39.30002566746303, 42.227416379111155, 36.61312600544521, 35.7188720021929, 38.36860922404698, 39.94602748325893, 40.10251481192452, 41.99721213749477, 42.916114875248496, 37.49905606678554, 41.46337161745344, 43.62363256726946, 46.59498800550188, 48.10181951522827, 48.988614627293174, 47.162787846156526, 53.092383997780935, 55.953443731580464, 49.60374212265015, 45.113764081682476, 47.491944858006065, 49.75778021131243, 55.05649035317557, 54.55114092145647, 57.27470622743879, 53.47983986990792, 51.08798851285662, 46.247901167188374, 47.51608984810965, 42.37736545290266, 47.37852593830654, 53.71918446677071, 58.08269139698574, 59.84599481310163, 59.827651568821494, 59.14735344478062, 60.949382645743235, 62.2542473929269, 60.84210940769741, 59.25805214473179, 66.06666837419782, 64.43646812438965, 67.34163502284459, 62.73504883902413, 58.77761895315987, 70.25379180908203, 66.28595352172852, 59.63271985735212, 66.45544787815639, 65.49573489597866, 73.5024220602853, 68.41158117566789, 75.22491523197719, 71.05232742854527, 66.10061727251325, 1.3128559355224882, 2.5530319767338887, 65.11623123713902, 75.28830364772251, 55.57259212221418, 76.67819350106376, 104.47438553401402, 41.02110488074166, 77.12028653281075, 44.94062539509365, 0.5278117635420391, 0.18570556225521223, 0.16654430329799652, 0.12403880698340279, 0.15777258255652019, 0.2998739645949432, 0.12621735222637653, 0.11469881316380841], [0.09531401084469897, 0.009108814394234546, 0.039027570081608634, 0.09426715344722782, 0.09993813878723554, 0.011164364987052977, 0.09754147846251726, 0.06304469704627991, 0.08372253605297633, 0.2601201720535755, 26.100763831819805, 53.15570640563965, 38.88407175881522, 27.269278866904124, 56.733563150678364, 30.114361218043737, 42.72489697592599, 62.33681978498186, 35.32136903490339, 0.31844544091394966, 0.06662409819130387, 10.122027141707283, 39.59477172579084, 55.39037561416626, 56.057006631578716, 57.065370900290354, 36.94338778087071, 21.500156572886876, 49.03157186508179, 58.51856926509312, 57.777300698416575, 57.77385439191546, 58.26597792761666, 52.790064402988975, 58.05415167127337, 54.21081468037197, 49.75560542515346, 56.032997131347656, 56.82411902291434, 56.23777444022042, 53.97313417707171, 52.27909387860979, 50.27049125943865, 44.542312962668284, 38.87122801371983, 41.37145389829363, 40.30309888294765, 46.42908934184483, 51.50994219098772, 53.66421031951904, 50.35129533495222, 51.69274582181658, 51.68361588886806, 49.6562705039978, 43.79191446304321, 43.37330286843436, 42.29325750895909, 48.150759152003694, 49.38554089409964, 46.61507524762835, 42.39121668679373, 43.73588418960571, 43.79020868028913, 43.83355849129813, 46.34359870638166, 43.92359324863979, 41.608682768685476, 36.70563779558454, 36.420504570007324, 38.07999842507498, 36.54122952052525, 36.760948930467876, 35.965206486838206, 35.96653011866978, 35.829066957746235, 36.42831434522356, 36.74972064154488, 38.3552235194615, 36.656451497759136, 37.34729698726109, 40.168206555502756, 42.52960048403059, 44.823607308524, 41.009706360953196, 42.18815905707223, 40.6706794330052, 46.54606226512364, 48.154764788491384, 50.33815629141671, 45.635889938899446, 50.03709432056972, 47.38795116969517, 40.645749296460835, 40.44174323763166, 39.677514348711284, 41.504244395664756, 42.179247992379324, 40.830567904881065, 38.64519616535732, 34.65435586656843, 34.92181634902954, 35.75125060762678, 35.698996680123464, 37.07819325583321, 34.04413727351597, 34.120949608939036, 33.81465564455305, 33.129459040505544, 34.94971684047154, 35.25850520815168, 35.636424677712576, 35.660913603646414, 34.432579789842876, 38.72120598384312, 41.140513147626606, 42.579419067927766, 42.100066321236746, 41.58628872462681, 44.34179489953177, 48.780179091862266, 48.47261013303484, 45.526528767177034, 39.983950751168386, 42.18776648385184, 47.52408722468785, 49.57612998144967, 52.87235539300101, 50.11526850291661, 53.68673637935093, 51.95327547618321, 46.69448273522513, 44.62517023086548, 39.496475560324534, 41.38857078552246, 41.25452961240496, 46.00029168810163, 51.66833332606724, 55.75844948632376, 56.197450569697786, 55.21019492830549, 54.02459600993565, 53.66309513364519, 55.06035007749285, 56.36562476839338, 55.54210690089634, 60.566071374075754, 59.07523809160505, 61.02034459795271, 58.35038117000035, 55.08949082238333, 63.194213594709126, 59.24824823651995, 61.460902077811106, 60.99550478799002, 62.99186815534319, 60.84591702052525, 68.52034827641079, 33.22229044778006, 0.4608688013894217, 4.6795044881956915, 58.268753732953755, 52.955045904432026, 32.84629215512957, 30.698117596762522, 22.851315430232457, 31.5768632207598, 42.551198959350586, 22.120022739682877, 0.8578725297536168, 0.05717160326561757, 0.05059124868629234, 0.040658222045749426, 0.055895119439810514, 0.04874505328812769, 0.025041811534070542, 0.04058846525315728, 0.08067647021796022, 0.054804991864200146, 0.0108516638200464, 0.0935855039528438, 0.1094096734055451, 0.006497997391436781, 0.07644507834421736, 0.00983208607483123, 0.10848461304392133, 0.046031249088368247, 32.56412928444998, 62.82329790932791, 49.739899022238596, 32.737170696258545, 63.53139577593122, 33.071646554129465, 45.7217800957816, 69.05766636984688, 40.48500272205898, 0.3560231445091111, 0.009315411344037523, 10.110961266926356, 41.694458280290874, 58.341077532087056, 60.299031257629395, 60.53774356842041, 39.87102862766811, 26.83291983604431, 50.41667440959385, 60.803004946027485, 60.57242897578648, 59.19520568847656, 59.558770179748535, 55.12155328478132, 58.688584736415315, 57.59529958452497, 53.50570106506348, 56.95693383898054, 59.48687022072928, 59.43904576982771, 55.8051552772522, 54.76415531975882, 51.45290790285383, 46.038597106933594, 42.551730496542795, 42.998412813459126, 42.030348096575054, 48.596430506025044, 54.67450966153826, 55.24055160794939, 52.2995285306658, 53.97860240936279, 52.69622550691877, 51.27391535895211, 46.829899651663645, 44.14313895361764, 44.47990076882498, 49.34206254141671, 51.7945681980678, 49.61435897009713, 44.630895546504426, 45.45710236685616, 48.471164907727925, 45.38039772851126, 46.566726207733154, 45.29376411437988, 43.20559419904436, 37.92055811200823, 39.11377225603376, 39.547207832336426, 38.48470320020403, 37.440507071358816, 38.39450863429478, 39.11169474465506, 37.43938146318708, 37.160876819065635, 40.66162245614188, 40.01482507160732, 41.22881432941982, 40.577240058353965, 42.568621567317415, 45.29055404663086, 45.103772572108674, 41.969044140407014, 44.77588013240269, 41.7540043422154, 46.5901312146868, 50.25806788035801, 50.127316679273335, 47.467045988355366, 50.04897574016026, 50.65462589263916, 42.92284767968314, 43.97576379776001, 42.466931206839426, 43.75737149374825, 43.49695301055908, 42.302484716687886, 41.55253437587193, 39.07893051419939, 37.19214718682425, 38.84115621021816, 38.031131744384766, 40.45164442062378, 37.39779996871948, 34.542135511125835, 35.92550795418875, 34.968803542000906, 36.31073692866734, 36.462197235652376, 38.05591596875872, 39.009174074445454, 37.96048246111189, 40.79122373035976, 44.312171254839214, 44.73814793995449, 46.04501029423305, 44.40753528050014, 45.88933590480259, 49.863910470690044, 51.47861623764038, 47.04172938210623, 42.112604345594136, 44.418238980429514, 48.11800534384591, 51.7667476109096, 54.78183501107352, 53.285015855516704, 55.949584007263184, 54.680311407361714, 50.103668485369, 45.93038586207798, 42.30027518953596, 42.283290318080354, 43.30204561778477, 48.71279198782784, 53.46384164265224, 58.07213708332607, 57.453056062970845, 56.955162048339844, 56.630351134708945, 55.68508693150112, 57.05140502112252, 60.88582747323172, 59.29405076163155, 61.15803704942976, 61.61795915876116, 61.33288846697126, 60.7720159803118, 59.265514510018484, 66.9183577128819, 64.36688191550118, 64.13159506661552, 64.54160131726945, 64.72071892874581, 65.54591478620256, 71.6775541305542, 31.408060210091726, 0.4109440403325217, 6.728146536009652, 66.44553279876709, 61.18487794058663, 41.569494928632466, 36.93566485813686, 35.78730133601597, 39.82495512281145, 52.886331694466726, 35.123713629586355, 1.0335182675293513, 0.08751240519008466, 0.028474945974137102, 0.01634115376509726, 0.059299129460539134, 0.031484262352543216, 0.028668603261134455, 0.04587139641599996, 0.26691439747810364, 0.10117207507469825, 0.06871173331247908, 0.22176383595381463, 0.2657696274774415, 0.14882399487708295, 0.16429053566285542, 0.18157962150871754, 0.22462063123072895, 0.39725964463182856, 44.10970074789864, 70.21221378871373, 54.70304938725063, 35.8178699357169, 68.70440605708531, 44.75517450060163, 53.831085205078125, 73.623473576137, 41.34628752299717, 0.7707714321357864, 0.08809040846037013, 14.042987670217242, 46.201337814331055, 62.02423422677176, 62.56968866075788, 62.62537152426583, 38.685047558375764, 31.374086993081228, 56.751965454646516, 60.638249261038645, 64.1387586593628, 62.087316921779085, 62.89145278930664, 56.095551763262065, 60.01985263824463, 60.054440770830425, 55.45750910895211, 57.583477224622456, 61.16031605856759, 62.28764738355364, 58.890332630702424, 55.96042319706508, 53.23765345982143, 49.0336389541626, 46.08595255443028, 46.54836559295654, 43.60463966642107, 51.6435421534947, 55.614399433135986, 57.3822990826198, 53.59030927930559, 54.57831185204642, 56.150699615478516, 54.9167412349156, 48.247651781354634, 47.57327699661255, 47.66120992388044, 52.00827741622925, 55.23237705230713, 50.971164975847515, 47.02439710072109, 48.29173462731497, 51.290889808109824, 48.501684870038716, 49.3011862891061, 47.40357419422695, 46.379857880728586, 39.67293895993914, 39.252395766122, 41.182382992335725, 40.01561369214739, 40.263448987688335, 39.29779529571533, 41.130427837371826, 40.08911868504116, 41.11998816898891, 43.73113856996809, 43.385351044791086, 46.01814161028181, 45.58664458138602, 46.16902869088309, 48.36684465408325, 48.57957765034267, 43.527320112500874, 47.289307594299316, 43.55218424115862, 50.74416732788086, 52.64926610674177, 54.17293657575335, 49.16109323501587, 53.55058642796108, 52.702426774161204, 45.386821338108604, 45.743604387555806, 45.74519552503313, 46.70718056815011, 46.617927483149934, 46.18404374803816, 46.45295292990548, 44.401552881513325, 40.646562235695974, 42.75392654963902, 40.659666538238525, 43.57943855013166, 39.71288415363857, 36.714152812957764, 38.0798351424081, 38.15233959470476, 38.38163014820644, 39.746940749032156, 39.60075759887695, 40.953297410692485, 40.01158373696463, 44.6947078023638, 45.001359598977224, 49.38684368133545, 48.01019362040928, 47.04480395998274, 51.00078167234148, 56.03554712023054, 53.99826928547451, 50.03811917986189, 46.10805130004883, 46.572250025612966, 51.354340757642476, 55.80774000712803, 57.57375322069441, 55.19221299035208, 57.905960491725374, 55.63778012139456, 52.38534920556204, 49.49285234723772, 43.86316476549421, 45.42862170083182, 47.049407141549246, 52.48869671140398, 57.73893621989659, 63.458071436200825, 62.33802877153669, 59.57348646436419, 60.19094508034842, 58.977998052324565, 60.561228479657856, 64.26556328364781, 63.458154814583914, 64.6341165815081, 65.5604226248605, 61.24941975729806, 66.17932646615165, 66.02942602975028, 67.78996058872768, 67.3667527607509, 65.98499229976109, 69.54382487705776, 69.71022728511265, 68.70435047149658, 74.39010306767055, 42.01999528067452, 0.5574723748224122, 7.384869422231402, 76.46742684500558, 68.41179656982422, 47.77117211478097, 45.31482757840838, 33.24956560134888, 47.51007270812988, 62.11166340964181, 45.60478285380772, 1.2344684217657362, 0.2570117488503456, 0.0861881762476904, 0.1334672546280282, 0.1874277384153434, 0.1278135244335447, 0.1921471801719495, 0.10614750773778983], [0.10154621928398098, 0.05378728772380522, 0.09030206621225391, 0.07848469354212284, 0.12466884031891823, 0.032108494213649204, 0.16083399685365812, 0.09134523237922362, 0.10886859601097447, 0.2229466853397233, 36.12819038118635, 52.65534578050886, 43.656987394605366, 36.856646469661165, 45.14363786152431, 34.02217401776995, 38.83095278058733, 57.78852203914097, 46.62552881240845, 1.8324084622519357, 0.02818785102239677, 0.5320566243359021, 18.739715439932688, 50.901422432490754, 44.81223658152989, 62.934434345790315, 45.79396840504238, 52.03604589189802, 57.08943598611014, 56.51516042436872, 57.20678063801357, 58.670679228646414, 54.28655699321202, 58.2203734261649, 50.32928344181606, 47.77310718808855, 57.57264845711844, 57.039645195007324, 56.40377037865775, 54.84120389393398, 52.91866166251046, 45.20495918818882, 41.301263196127756, 41.97590896061489, 41.92008713313511, 39.02866377149309, 44.52842698778425, 50.72596999577114, 57.121675627572195, 53.0337689944676, 49.50403547286987, 54.96276610238211, 50.36924253191267, 47.844208104269846, 45.25427055358887, 45.68359974452427, 41.015855516706196, 46.707670416150776, 50.954881872449604, 48.178166321345735, 47.513341835566926, 45.13429948261806, 42.513859340122764, 43.89839560644967, 45.25966582979475, 43.64479330607823, 40.881126471928184, 39.05447980335781, 35.363714831215994, 39.283297879355295, 38.98448017665318, 37.64231055123465, 38.71437243052891, 37.877788475581575, 37.709131377083914, 36.0545950617109, 36.27799006870815, 37.97749512536185, 37.28820603234427, 36.90433195659092, 36.36302212306431, 40.652409144810264, 42.675992080143516, 44.91339193071638, 48.00061205455235, 44.2685296194894, 48.17763825825283, 51.44404894965035, 48.929912771497456, 46.0744081224714, 50.0212732723781, 49.06009422029768, 43.719302313668386, 45.77641725540161, 42.381204332624165, 43.495122160230366, 40.39459276199341, 39.217265674046104, 37.41150529044015, 34.426705087934224, 36.463381903512136, 34.624999727521626, 33.20775134222848, 36.8852904183524, 36.9790598324367, 34.4891277040754, 35.345246519361226, 33.6985581942967, 35.71238933290754, 35.70630965914045, 36.024940150124685, 35.285356521606445, 39.63502264022827, 43.33695684160505, 42.98149394989014, 44.50513662610735, 42.776740959712434, 42.444495473589214, 43.8790066582816, 45.96517201832363, 49.538672242845806, 41.343167781829834, 37.829835483006065, 42.76633950642177, 46.5834505217416, 51.82336848122733, 52.958165645599365, 50.364771366119385, 51.60354832240513, 54.72588116782052, 50.65299654006958, 48.702237674168174, 43.68870939527239, 42.27592870167324, 41.51200205939156, 43.297119344983784, 45.389406067984446, 48.770910194941926, 51.978921277182444, 51.47139358520508, 51.923328740256174, 50.607242652348106, 49.2159457887922, 51.73032862799508, 54.525227614811485, 57.38146529878889, 58.904576437813894, 62.546245438711985, 50.37852879932949, 56.36204644611904, 61.41430050986153, 59.87314142499651, 59.5392735345023, 61.42033154623849, 63.46365778786795, 62.56485966273716, 62.172307286943706, 12.805439676557269, 0.8860497006348201, 9.565452115876333, 60.69468947819301, 53.18059832709176, 33.54168176651001, 35.51075608389718, 28.736194712775095, 37.996581826891216, 46.76035165786743, 31.83055932181222, 2.399760578359876, 0.009872268070466816, 0.07653099444827863, 0.0390870776027441, 0.05848549811967781, 0.1465518253722361, 0.03443549952602812, 0.05153191874602011, 0.1235816507999386, 0.039728710494403324, 0.025830756074615886, 0.02944514248520136, 0.07498090833957706, 0.031071143091789315, 0.1046031281085951, 0.032175770960748196, 0.12881342720772537, 0.17573401518166065, 45.89471728461129, 61.73634951455252, 46.746007101876394, 39.1245037487575, 53.04274606704712, 37.41089037486485, 46.08375344957624, 59.29261943272182, 50.177180426461355, 2.565735020807811, 0.16367975915116922, 0.4585310039775712, 16.065550088882446, 55.944661208561485, 50.64793477739607, 64.35037299564907, 49.33119903291975, 59.66275691986084, 58.73442895071847, 60.40630449567522, 60.27117592947823, 60.720210211617605, 56.285216740199495, 60.748774256025044, 53.291251863752095, 47.985989570617676, 59.71118586403983, 58.05272034236363, 58.30088915143694, 54.658803258623394, 53.65916245324271, 47.531073638371055, 43.39359508241926, 42.34410442624773, 44.2809807913644, 41.07751383100237, 47.239655767168315, 55.22420597076416, 57.93497616904122, 54.48307984215872, 51.87712321962629, 58.88848440987723, 53.221432890210835, 48.41772978646414, 47.72637707846505, 47.578522886548726, 44.46464252471924, 48.20159217289516, 52.36559547696795, 50.10576684134347, 50.127976758139475, 47.7748372895377, 45.752518926348, 46.20190756661551, 46.93613760811942, 44.589519023895264, 42.07052952902657, 39.820421423230854, 37.84631661006382, 39.557171549115864, 42.276112828935894, 39.257870946611675, 40.16720601490566, 39.0991393498012, 38.71378183364868, 38.83019195284162, 38.9245936529977, 40.74693938664028, 40.37496062687465, 38.983997276851106, 40.708140645708355, 42.90776661464146, 43.68136167526245, 45.66964776175362, 46.41964326586042, 45.62186847414289, 50.21457215717861, 50.97189801079886, 49.95604010990688, 46.8799648966108, 50.12956094741821, 51.685127122061594, 45.54845380783081, 46.57394886016846, 44.319282736097065, 47.507800647190635, 42.19134133202689, 41.82011645180838, 38.92590686253139, 38.85131100245884, 39.30345460346767, 38.01282671519688, 36.864727224622456, 38.78837769372122, 39.59079040799822, 36.18647534506661, 36.446720123291016, 35.57406112125942, 35.99108852658953, 37.6575687953404, 36.977687563214985, 37.55414138521467, 41.0900171143668, 46.08480262756348, 45.2155065536499, 47.830735547201975, 46.00002070835659, 46.04223101479666, 48.210503237588064, 49.4689679145813, 52.598280225481304, 43.88515928813389, 41.222352504730225, 45.23461757387434, 49.41448361533028, 54.072330134255544, 54.782717432294575, 52.00434473582676, 51.87466355732509, 57.76631907054356, 55.77493061338152, 51.58953380584717, 46.34796217509678, 45.217076846531455, 43.730183192661826, 44.970652035304475, 45.354880469185964, 51.387765066964285, 54.27896956035069, 52.242515087127686, 53.14179263796125, 54.217940058027, 52.59287452697754, 55.62761490685599, 58.11325652258736, 60.89271313803536, 62.42461722237723, 63.82784761701311, 54.269790990012034, 59.83659390040806, 64.4448823928833, 64.67918954576764, 62.60613891056606, 62.556063243321006, 68.12324483054024, 65.08845233917236, 64.63585363115583, 12.182993122509547, 0.8904937793101583, 12.636508992740087, 69.63012150355748, 60.183267320905415, 40.73850427355085, 41.27812916891915, 28.575102465493337, 49.58315461022513, 59.31233842032296, 45.00070299421038, 3.6843018446649825, 0.11125896631606988, 0.11868009024432727, 0.04222146834113768, 0.08163051081023046, 0.10376070652689252, 0.09109086995678288, 0.04292869521304965, 0.209528153230037, 0.16221949750823633, 0.13878714559333666, 0.19320866678442272, 0.20031872311873095, 0.13955033464091166, 0.23672596737742424, 0.17978332218314919, 0.19834196061960288, 0.2653045324342591, 53.356078556605745, 71.34254673549107, 57.98896367209298, 44.03032105309622, 59.32141276768276, 46.42260667255947, 51.217659269060405, 68.93711512429374, 55.670297690800254, 2.2774770600455145, 0.2684743223445756, 1.2442783010857446, 21.99719422204154, 59.31666019984654, 53.667788641793386, 65.45288535526821, 52.109582151685444, 61.75011389596121, 61.57894502367292, 62.91658442361014, 62.0004574911935, 63.24079431806292, 59.13295677730015, 60.091571944100515, 56.221984658922466, 50.52496555873326, 60.607308932713096, 63.39466912405831, 61.08275331769671, 59.51123060498919, 56.00739649363926, 49.73846769332886, 45.68295356205532, 46.55312510899135, 48.33199596405029, 43.691398348127095, 49.07825333731515, 57.148113523210796, 60.908923285348074, 58.743843759809224, 53.180125849587576, 59.955929211207796, 54.43581472124372, 50.5051770891462, 50.11013725825718, 51.81946359361921, 45.6827346937997, 50.838447434561594, 55.02197865077427, 54.26695612498692, 54.52823271070208, 50.20368432998657, 47.004643372126985, 48.62764181409563, 48.67367015566145, 46.18042026247297, 46.10479954310826, 41.24614313670567, 38.30576276779175, 42.003347396850586, 42.955115113939556, 41.32138170514788, 43.24529273169381, 41.96879053115845, 40.675435474940706, 40.93102496010916, 43.047804083142964, 44.550536155700684, 45.224205698285786, 44.103099959237234, 44.44757080078125, 45.16784191131592, 47.37991905212402, 49.16120788029262, 50.92778737204415, 49.24071959086827, 53.62253849846976, 53.839471680777415, 53.92781802586147, 48.97027833121163, 54.01435783931187, 54.249974727630615, 48.132641724177766, 50.54317331314087, 47.5115978377206, 49.461144242967876, 44.962171758924214, 46.31449270248413, 43.87072440556118, 40.95958553041731, 43.89033222198486, 41.35678277696882, 39.70770079748971, 42.09385115759713, 42.29179491315569, 38.073963914598735, 39.59604672023228, 37.54755449295044, 39.41745022365025, 41.65889392580305, 39.45794085093907, 40.03565577098301, 45.543694291796, 47.81860399246216, 48.709133761269705, 49.94773701259068, 49.44585473196847, 49.16560609000069, 51.674743039267405, 52.30692836216518, 56.74009098325457, 45.7756564276559, 45.14464882441929, 46.85968657902309, 51.793105602264404, 57.27772174562727, 57.5124249458313, 54.968943050929475, 56.86771202087402, 59.70629433223179, 58.3374297278268, 54.07919495446341, 50.03118487766811, 47.171799659729004, 46.39421285901751, 49.4032553264073, 49.428206307547434, 55.620941162109375, 57.669680050441194, 56.45546497617449, 57.31069789613996, 56.79025002888271, 55.4442971093314, 58.712097440447124, 61.035554204668315, 63.4729961667742, 64.64829090663365, 63.84236935206822, 60.71088572910854, 62.65797247205462, 66.11373547145298, 67.1213493347168, 66.14113916669572, 68.12218870435441, 71.62227426256452, 69.22423553466797, 70.42765658242362, 17.619156871523174, 0.9568785514150346, 13.49944485936846, 78.60024588448661, 68.67790562765938, 49.220951965876985, 53.84942150115967, 38.922283376966206, 59.484500885009766, 68.33577632904053, 55.817766257694785, 4.929312203611646, 0.18567687379462378, 0.2577474708003657, 0.13246839679777622, 0.09790873554136072, 0.1587794470999922, 0.2220985029957124, 0.14616744885487215], [0.06820965811078038, 0.031114548976932253, 0.052941188482301574, 0.03147033542128546, 0.00449366304591032, 0.005859197383480412, 0.06867269040750605, 0.0738703500745552, 0.1164872550538608, 0.11368980444967747, 35.3291266986302, 51.66786432266235, 45.39586789267403, 25.666214806692942, 26.542636258261545, 35.88681691033499, 47.257467474256245, 59.538120133536204, 59.74676758902413, 7.5821713379451205, 0.14151590131223202, 0.7749431197132383, 1.1881239371640342, 33.10902786254883, 45.83050203323364, 50.15120806012835, 52.228458881378174, 54.24602815083095, 53.85729381016323, 60.558928625924246, 55.63595274516514, 57.68810319900513, 56.3476254599435, 54.712356499263215, 46.042988368443076, 57.952124323163716, 53.27291556767055, 54.087661334446494, 53.93707650048392, 52.06971338817051, 44.617808614458355, 43.291981152125764, 43.944615023476736, 42.97120019367763, 39.036570821489605, 42.85633952277047, 47.99464702606201, 50.04277794701712, 51.99664613178798, 48.86038909639631, 52.773506845746724, 52.46005971091134, 51.1609411239624, 49.67637511662075, 45.472437041146414, 47.639267512730186, 40.76493174689156, 47.131309032440186, 51.73609215872628, 48.76614373070853, 48.97915118081229, 47.28445080348423, 45.2648526600429, 45.743757247924805, 47.73354067121233, 46.614894594464985, 39.83043725149972, 40.14782748903547, 38.72607319695609, 40.590035166059224, 39.25361517497471, 40.92234666006905, 38.09534004756382, 36.989621094294954, 36.92776128223964, 37.8529451915196, 37.46878276552473, 37.0912697655814, 35.27858897617885, 36.80926670346941, 36.57030773162842, 40.937452043805806, 42.43135643005371, 43.252751622881206, 41.65091044562203, 43.2140987941197, 45.413544109889436, 49.41360119410923, 47.04960516520909, 42.8684641293117, 49.478139536721365, 49.59867341177804, 44.29053456442696, 44.81678417750767, 41.7437800679888, 42.7017560005188, 39.780312946864534, 39.89685508183071, 36.98778329576765, 34.250877448490684, 34.53758444104876, 34.52409103938511, 33.99178259713309, 33.660033907209126, 33.205642563956125, 35.124151366097585, 34.44947780881609, 35.53559241976057, 33.79303285053798, 36.76365525381905, 35.12491219384329, 38.1142704146249, 41.70246607916695, 44.21739435195923, 41.64462232589722, 43.77507202965872, 42.88677610669817, 46.8737393106733, 46.63618734904698, 47.83894484383719, 48.60198559079851, 43.123240675245015, 40.27024780000959, 44.77192660740444, 46.203453540802, 51.3518637248448, 51.54944964817592, 52.45533146177019, 49.206503186907085, 51.96792575291225, 54.056373596191406, 49.67206375939505, 46.36426264899117, 43.920911243983674, 40.664106437138145, 41.160996437072754, 40.201999119349885, 43.37769065584455, 43.88806710924421, 48.477380071367534, 46.81007644108364, 47.643641403743196, 48.56420823505947, 49.10039724622454, 52.10957520348685, 57.41030379704067, 59.735400336129324, 62.67226491655622, 45.32638243266514, 60.93137986319405, 57.82314838681902, 63.4886018208095, 58.89744758605957, 63.24868747166225, 59.98693207332066, 62.92425523485456, 50.297832420894075, 3.2107436784676144, 0.4909309968352318, 19.677182027271815, 57.49427277701241, 50.85276072365897, 34.23231881005423, 34.15339422225952, 40.921617099217, 22.562402384621755, 45.769694873264854, 49.581650325230186, 5.101805576256343, 0.2740079382700579, 0.14263291923063143, 0.08995485984321151, 0.04823084927297064, 0.05879388550030334, 0.04709519199760897, 0.05403952633163758, 0.05601902332689081, 0.05007972149178386, 0.023158557945862412, 0.007953075874995972, 0.05795191175171307, 0.05929632032556193, 0.16302869123007568, 0.023863662699503557, 0.078609320068998, 0.12637000903487206, 42.05113015856062, 59.60310663495745, 47.92840984889439, 31.194003582000732, 37.44129221779959, 43.58143615722656, 54.499640873500276, 62.037289891924175, 65.87628078460693, 8.948311379977635, 0.44146698819739477, 0.9111013220889228, 0.6620485175933156, 30.80537346431187, 50.586113180433, 55.36815527507237, 57.2343476159232, 56.76465286527361, 55.37919248853411, 60.96839986528669, 57.34296185629708, 60.97367354801723, 57.613437856946675, 58.38452461787632, 48.32901518685477, 59.67752184186663, 57.45625223432268, 55.98078489303589, 56.610190936497276, 54.02849742344448, 46.78303057806832, 44.41506017957415, 45.13463299615042, 45.587672914777485, 40.26093373979841, 45.666503701891216, 50.510044302259175, 53.04691846030099, 52.68478529793875, 50.57756689616612, 53.56456272942679, 52.94952208655221, 52.77873536518642, 51.64491094861712, 49.41280562537057, 49.8681766646249, 43.90432241984776, 47.372401101248606, 52.06018393380301, 52.76130928312029, 51.62647042955671, 49.64134577342442, 49.08150856835501, 46.47757387161255, 50.70912061418806, 48.1974093573434, 43.08963918685913, 42.453132084437776, 39.57577187674386, 42.30482625961304, 40.631640979221885, 42.021978991372244, 37.9724611554827, 37.58614478792463, 39.88405997412545, 40.44815642493111, 39.14889192581177, 39.71002844401768, 38.73646770204817, 40.523964745657786, 41.07984495162964, 42.55606964656285, 44.46695974894932, 44.950731549944194, 45.80785437992641, 46.27102477209908, 46.497782707214355, 50.269897188459126, 46.07943514415196, 41.50972999845232, 49.34081881386893, 49.302579402923584, 46.0438951083592, 45.29508079801287, 43.68303619112287, 44.2136492729187, 42.303099632263184, 43.001591614314485, 40.94119712284633, 37.3836430140904, 37.73107726233346, 38.070465496608186, 36.809568950108115, 37.740637983594624, 36.04242181777954, 36.53475727353777, 36.3501158441816, 36.48760332380022, 36.70089217594692, 37.43187393460955, 37.760318756103516, 42.03450311933245, 42.26828915732247, 46.09703493118286, 46.34816714695522, 47.44018772670201, 47.00372273581368, 49.355753966740195, 50.768010071345735, 51.70950835091727, 51.67838389532906, 46.37934718813215, 42.195909772600444, 47.28955078125, 47.46400267737252, 54.092688356127056, 53.138579096112935, 56.02776166370937, 51.712377956935335, 54.063936710357666, 55.686830929347444, 54.55091857910156, 50.56817987986973, 46.83666719709124, 43.53296204975673, 44.18020759310041, 44.05179793494088, 45.61107097353254, 46.75356674194336, 50.90444489887783, 49.00428628921509, 49.18275424412319, 51.28884008952549, 51.579250471932546, 55.27085965020316, 60.377281870160786, 61.92957196916853, 65.15132658822196, 48.99132095064436, 62.11308084215437, 61.047456468854634, 67.40352957589286, 60.5093879699707, 67.25126675197056, 61.59737164633614, 65.5789326259068, 50.0546350479126, 2.9375298704419817, 0.4474581538566521, 26.982231412615093, 66.25961290087018, 59.01537241254534, 38.319884981427876, 41.41854878834316, 36.41585969924927, 24.52782542364938, 57.52016871316092, 55.87474843433925, 8.733288952282496, 0.2209441385098866, 0.16695704257913999, 0.07873656574104514, 0.09569255874625274, 0.09090238649930273, 0.01627638590122972, 0.06467932861830507, 0.16678762595568383, 0.09923554291682583, 0.13194540914680275, 0.0865563697048596, 0.12437523821634905, 0.19272113937352384, 0.18482529877551965, 0.14416011156780378, 0.14835303729133947, 0.31318028058324543, 54.398728711264475, 67.74656214032854, 61.71668611254011, 33.71498373576573, 40.06035661697388, 51.29719182423183, 60.0366325378418, 69.15337085723877, 72.50483444758824, 9.70773298399789, 0.8776396119168827, 1.1607624739408493, 1.8216263779572077, 40.77899490083967, 51.36001396179199, 58.90896075112479, 58.69895839691162, 59.53871767861502, 57.63368838174002, 64.43716294424874, 59.365228107997346, 62.95891979762486, 59.35847445896694, 59.8014360155378, 51.34020117350987, 61.20846707480294, 59.77087088993618, 57.56565162113735, 59.05410861968994, 56.706093447549, 47.885202475956504, 45.4080376625061, 47.865344524383545, 46.60464252744402, 44.88275037493025, 48.25598961966378, 52.83949736186436, 53.70623649869646, 54.35037967136928, 52.96184819085257, 57.358598777226035, 55.32752568381173, 55.58592224121094, 53.20937776565552, 50.286798681531636, 51.50479357583182, 45.74720702852522, 50.545459270477295, 56.80649144308907, 55.12453753607613, 55.41896397726876, 51.623315947396414, 51.28401109150478, 51.52280330657959, 53.007813998631065, 49.73671327318464, 44.64462171282087, 45.52246059690203, 41.74157748903547, 44.27374076843262, 43.31210660934448, 42.96740647724697, 40.389374664851594, 41.78372178758894, 40.960638182503835, 44.003257819584434, 41.67605250222342, 43.66090270451137, 43.836730343954905, 46.064350605010986, 44.5946398462568, 46.17587614059448, 49.753170081547324, 49.5176226752145, 47.68487548828125, 48.834381989070344, 48.058250835963655, 54.22170598166329, 49.29672901970999, 42.69919906343733, 52.49025658198765, 50.82667718614851, 47.32122414452689, 48.355922085898264, 45.508487769535606, 47.69263662610735, 45.03341858727591, 48.154327051980154, 47.01283877236502, 40.74389607565743, 41.39549119131905, 41.38618060520717, 39.96051795142037, 39.69760159083775, 38.08271517072405, 40.63805416652134, 37.89131314413888, 38.96292339052473, 39.13352945872715, 40.72111293247768, 40.634093693324495, 44.27399785178048, 46.214827741895405, 49.08669887270246, 47.83372327259609, 50.777254649571006, 50.53137527193342, 52.720530305589946, 52.90299347468785, 53.457352025168284, 53.48381076540266, 48.40960386821202, 44.618256773267476, 50.14646244049072, 50.26256683894566, 57.3809928212847, 56.81488486698696, 55.96178504398891, 54.15180362973894, 56.22087642124721, 58.22253084182739, 55.259770325251985, 52.08580541610718, 49.7846280506679, 46.13011530467442, 47.15794842583792, 46.70005866459438, 48.27370752607073, 48.537322180611746, 54.334155627659385, 54.19032791682652, 53.11950976508004, 54.37305164337158, 52.482071604047505, 57.03790119716099, 63.76523045131138, 65.13102395193917, 67.06222711290631, 55.442414147513254, 64.7697662625994, 64.29744856698173, 70.24164635794503, 65.43618188585553, 71.54440580095563, 68.79912390027727, 67.29876463753837, 54.84862804412842, 6.177032360008784, 0.7949158794113568, 31.969940185546875, 74.94599369594029, 66.55647468566895, 46.324564116341726, 53.35086045946394, 56.539017064230784, 33.23563098907471, 63.7790504183088, 67.04981068202427, 9.855568068368093, 0.3940944144768374, 0.3071951131735529, 0.33560268740568844, 0.23441056162118912, 0.19683744492275373, 0.17548404288079056, 0.23630589991807938], [0.033673348637031655, 0.030275886479232992, 0.03572526567482522, 0.037706034923238416, 0.05177549246166434, 0.03378992434591055, 0.060117062713418684, 0.02581807934412999, 0.05162803662408676, 0.7247854311551366, 36.45950133459908, 48.52681303024292, 40.4643109866551, 32.68114389692034, 23.29113813808986, 36.38686139242989, 40.084828172411235, 55.34137691770281, 56.45472846712385, 26.615066017423356, 0.507558741739818, 0.39432633774621145, 0.10566213128290006, 5.373118834836142, 33.197916167122976, 50.98940747124808, 42.441288879939485, 56.2427111353193, 54.99412679672241, 53.824060576302664, 54.24090385437012, 55.975514684404644, 55.04827063424246, 48.55085727146694, 49.61344180788313, 57.282769611903596, 55.857186862400596, 56.24226645060948, 51.55971908569336, 48.115629059927805, 43.568026133946006, 42.4410526411874, 40.128956181662424, 40.109087807791575, 41.03664800098964, 44.472605160304475, 49.66408027921404, 52.535614422389436, 50.03069502966744, 50.22444554737636, 48.15805128642491, 53.91614852632795, 50.10719469615391, 48.21190677370344, 44.93593883514404, 48.10208354677473, 45.426509448460166, 44.99313293184553, 50.55585377556937, 49.48671013968331, 48.371253286089214, 48.41662154878889, 45.20964922223772, 46.37073837007795, 46.53444835117885, 46.91144371032715, 43.11745629991804, 41.40339824131557, 36.98683834075928, 37.75386735371181, 39.563053199223106, 40.67277431488037, 42.03535079956055, 41.27221972601754, 37.988091128213064, 37.969192028045654, 37.18839863368443, 36.90795544215611, 37.000873701913015, 35.0923946244376, 36.374361583164756, 38.22916235242571, 40.88592420305525, 42.813111305236816, 44.23003312519619, 45.61497586114066, 42.7693133354187, 45.47125584738595, 49.746423380715505, 44.05688749040876, 50.350329535348074, 44.84041152681623, 43.78014074053083, 43.482875960213796, 44.0155804497855, 42.32705702100481, 39.12903050013951, 36.096002851213726, 35.265557629721506, 34.042184829711914, 36.004394326891216, 36.590961251940044, 32.63218341554914, 36.19964912959507, 35.405709743499756, 34.21430560520717, 35.70506245749337, 35.82383149010794, 36.93463999884469, 35.88052879061018, 37.35440846851894, 39.39382634844099, 41.21426827566964, 45.704079559871126, 44.96368646621704, 44.351800305502756, 46.09963008335659, 46.071927615574424, 46.46195084708077, 49.69902971812657, 49.08794954844883, 43.62362561907087, 42.41546589987618, 45.77946056638445, 46.74622597013201, 51.44473682131086, 51.679888180324006, 51.207712922777446, 50.2306363923209, 49.81483881814139, 52.57731403623308, 52.7133389200483, 50.827736786433626, 46.22947454452515, 41.03250340053013, 41.405708517347065, 42.549861431121826, 41.25970254625593, 43.04965925216675, 42.73651088987078, 43.15948247909546, 46.68050295966012, 48.69152355194092, 51.44213819503784, 53.49045671735491, 54.87258890696934, 56.80877045222691, 58.87803431919643, 46.784329891204834, 60.24081230163574, 58.56130763462612, 62.219617571149556, 55.81976733888899, 62.386673109872, 56.62726960863386, 66.22199535369873, 33.95602369308472, 0.2980585848646504, 0.03245585664574589, 38.5457500730242, 57.45405660356794, 53.851999282836914, 37.759887967790874, 39.829613889966694, 30.147007329123362, 43.0418564251491, 51.2748464175633, 44.02294206619263, 7.198770173958369, 0.1986290623566934, 0.039216107821890285, 0.06946801487356424, 0.043037209925907, 0.016665593587926457, 0.03586143408236759, 0.02629270950066192, 0.04442842723801732, 0.03700491825916937, 0.06886200167770896, 0.07498014838035617, 0.0851548013410398, 0.01707817510967808, 0.057800191321543286, 0.030314220315111533, 0.06793281582317182, 0.8709227123430797, 44.5806496483939, 55.60980667386736, 46.16491535731724, 32.585397720336914, 32.82668086460659, 50.4746675491333, 48.42144359861101, 61.18543379647391, 59.12057508741106, 31.574823924473353, 0.4317808465233871, 1.2660132433686937, 0.41977267659136225, 3.5848435929843356, 33.59711102076939, 54.25028739656721, 49.226447990962434, 61.44437231336321, 57.6281749861581, 56.954168455941335, 57.950338636125835, 58.645082065037315, 56.816569805145264, 49.21138082231794, 51.536185537065776, 59.201014382498606, 58.039650780814036, 57.15257774080549, 54.1838834626334, 50.30424908229283, 44.33799423490252, 45.394832611083984, 41.23808322634016, 42.013679368155344, 42.30180031912667, 45.20481327601841, 51.958351135253906, 54.96022653579712, 51.85393360682896, 51.31982210704258, 50.24690212522234, 54.85823392868042, 53.44580411911011, 50.208075591496055, 48.04954126902989, 48.66249745232718, 46.06252670288086, 46.809086322784424, 53.179893084934776, 51.80224248341152, 50.5147829736982, 51.74744551522391, 48.171711444854736, 48.62881258555821, 50.09592819213867, 49.84320136478969, 44.30014392307827, 43.39373057229178, 40.32509340558733, 40.05517326082502, 41.507176535470144, 41.973574365888325, 43.92330142429897, 42.45517832892281, 40.651630946568076, 41.41840982437134, 38.38422877447945, 39.87550674165998, 39.65188939230782, 37.64159141268049, 38.30451904024397, 41.716841902051655, 44.10931512287685, 46.81721918923514, 45.94618953977312, 45.43190472466605, 42.76984487261091, 47.00367062432425, 49.25467504773821, 45.380314350128174, 50.53960541316441, 46.209755556924, 45.2464816229684, 44.732853412628174, 46.877328055245535, 44.40909515108381, 41.84272241592407, 38.46565123966762, 39.760666915348594, 36.29834829057966, 38.72292913709368, 39.067038672310964, 35.35643311909267, 37.68033109392439, 37.44030557359968, 36.57240261350359, 37.84338794435774, 37.268421036856516, 38.50850772857666, 38.11616032464163, 40.307764598301475, 40.52317612511771, 43.00955424989973, 46.86178840909685, 47.12727560315813, 47.083432470049175, 48.760644231523784, 50.74042572293963, 51.034320626940044, 52.14718232836042, 51.85902663639614, 46.75665521621704, 46.600282532828196, 48.2213111604963, 47.88434089933123, 54.53406572341919, 55.34077589852469, 54.0772841998509, 53.167553084237234, 51.05445998055594, 56.24314192363194, 55.25735930034092, 53.29415621076311, 50.65020336423601, 44.2041962487357, 45.10197993687221, 43.507528168814524, 44.58983169283186, 45.78640181677682, 44.95830856050764, 44.899151597704204, 51.4013557434082, 51.226250716618125, 54.49428381238665, 56.034873144967214, 59.2622002192906, 59.54959855760847, 61.866885321480886, 50.265155042920796, 62.76470375061035, 61.43363734654018, 66.0496939250401, 59.412288257053916, 67.26972116742814, 60.46274471282959, 69.39765562329973, 31.879478113991873, 0.28929633647203445, 0.0918476739898324, 48.094113962990896, 63.77768162318638, 64.40256091526577, 42.090085233960835, 51.925489630017964, 31.095099449157715, 39.72140959330967, 60.67797211238316, 55.59642791748047, 11.847265720367432, 0.3624394530696528, 0.1218212324061564, 0.04278537843908582, 0.07771663261311394, 0.0832590219963874, 0.04362750146538019, 0.025645059699724828, 0.19023322287414754, 0.15340217921350682, 0.18946778109031065, 0.15800126242850507, 0.2309407778084278, 0.13387244859976427, 0.17498640529811382, 0.11663076521030494, 0.11001970352871077, 1.1078313142061234, 54.68017244338989, 65.59160614013672, 54.74131659099034, 41.022362504686626, 34.14914539882115, 51.75630446842739, 52.77977759497506, 65.01787948608398, 67.39689404623849, 33.23735761642456, 0.7388380542397499, 1.3757851187671934, 0.4365886742515223, 9.192455445017133, 38.27740716934204, 56.32883753095354, 53.17993824822562, 63.675529207502095, 60.219307626996724, 60.42287594931466, 61.83706365312849, 60.496012687683105, 56.918263639722554, 51.86086790902274, 51.35174560546875, 63.25797026497977, 59.6325044631958, 61.509025301252095, 56.231760774339946, 53.01310852595738, 47.00351081575666, 46.4218111038208, 44.745554719652446, 45.28388377598354, 45.70897456577846, 46.11733409336635, 53.06740174974714, 57.52444880349295, 54.74360949652535, 53.008699893951416, 52.21241896493094, 57.40615224838257, 53.80776705060686, 53.328296184539795, 49.72255631855556, 51.92188351494925, 48.378132002694265, 49.46564320155552, 55.2539199420384, 55.190458570207866, 53.382627623421804, 55.16036939620972, 51.49563932418823, 52.62763636452811, 52.56450503213065, 50.7960912159511, 45.8424459866115, 46.798591068812776, 42.93388489314488, 40.70074428830828, 43.31308283124651, 44.709785393306184, 44.633570602961946, 43.63592045647757, 44.5691225869315, 41.79695463180542, 41.85034111567906, 43.565378870282856, 43.85851294653756, 41.99776451928275, 42.35285568237305, 45.3622316632952, 46.438518047332764, 48.015067781720845, 47.25910030092512, 47.096397808619905, 47.164427621024, 50.72610548564366, 51.28625535964966, 46.432174342019216, 52.7457001549857, 47.069814000810894, 47.11341047286987, 46.29105295453753, 49.111274651118684, 47.182253224509104, 45.228645597185405, 43.824946199144634, 43.63676118850708, 40.068732670375276, 41.490351472582134, 41.14160401480538, 38.241154943193706, 40.69916704722813, 40.62499155317034, 39.12607751573835, 41.57800299780709, 39.05958672932216, 42.577275548662456, 41.71866927828108, 41.81891441345215, 44.70204162597656, 45.42091267449515, 50.338805947984966, 50.34767532348633, 49.633608954293386, 52.63280235018049, 51.93894829068865, 54.30751970836094, 55.53382812227522, 54.08494111469814, 49.27530772345406, 49.55918332508632, 51.90588181359427, 49.54268135343279, 57.38721145902361, 57.418506145477295, 55.11838490622384, 54.8278147152492, 52.31488404955183, 59.16530064174107, 57.53698335375105, 54.57900667190552, 53.632158279418945, 46.138241222926546, 47.38278865814209, 46.127735546657014, 44.74954298564366, 49.44571924209595, 46.75537327357701, 49.19208567483084, 53.367716789245605, 54.45931700297764, 55.82471445628575, 57.56678417750767, 61.31314863477434, 60.78302192687988, 64.31739684513637, 54.20322377341134, 66.8896963936942, 65.238450050354, 69.05415752955845, 63.58763449532645, 70.41670622144426, 63.959932872227256, 70.28437083108085, 40.776142665318076, 0.5200140391077314, 0.16557030699082784, 51.87775550569807, 70.54254504612514, 68.58916323525565, 51.60744973591396, 59.833731242588584, 41.12953151975359, 61.54669843401228, 70.6365055356707, 65.56530720846993, 16.393517221723283, 0.3454237761242049, 0.263182699148144, 0.2130353921758277, 0.2347196207514831, 0.22741002083889075, 0.15285219943949155, 0.19453220362109797], [0.01963088831066021, 0.018517464931522096, 0.017814884328150322, 0.0347974742097514, 0.08091349607067448, 0.05943219017769609, 0.06443815691662685, 0.023763809486159256, 0.032162485245083056, 1.5547973130430495, 39.97629036222185, 51.47035135541643, 42.26843854359218, 37.51303584235055, 18.794312647410802, 31.380069392068044, 28.258889947618755, 54.371519565582275, 58.477060726710725, 49.68656464985439, 0.6267073197024209, 1.5748244098254611, 0.1549926788679191, 0.021253156974645596, 5.274384932858603, 32.721238476889475, 43.69491761071341, 40.67168344770159, 47.83618640899658, 53.552049023764475, 54.44424288613455, 55.02131509780884, 54.57803739820208, 51.585500376565115, 54.66473354612078, 57.181186948503765, 52.68219709396362, 54.07039853504726, 47.60005187988281, 44.57887438365391, 43.17081846509661, 43.655663762773784, 39.389594895499094, 41.384853499276296, 41.560910429273335, 49.30898216792515, 52.104377950940815, 53.01249361038208, 47.426360811506, 49.93915251323155, 50.650040081569124, 52.94660036904471, 50.68395076479231, 49.006384645189556, 46.32349756785801, 48.585052830832346, 47.76095478875296, 43.40661253247942, 50.717322962624685, 50.529697281973704, 47.80720199857439, 50.30152538844517, 47.884820325034006, 48.79726471219744, 47.40636389596121, 46.59058632169451, 46.0837082862854, 43.66732631410871, 41.33262389046805, 37.49140957423619, 37.15915366581508, 38.89819744655064, 41.16342830657959, 42.14398241043091, 40.90834951400757, 40.011837346213206, 35.70925916944231, 38.93493604660034, 34.967945439474924, 36.543498107365195, 36.02282442365374, 37.9045216696603, 41.31294659205845, 45.79750851222447, 45.025355202811106, 46.80763067517962, 45.893386704581125, 43.39906678880964, 48.36324201311384, 43.98140573501587, 48.51708902631487, 43.94793973650251, 42.594475814274375, 43.88243906838553, 42.74313252312796, 41.536306858062744, 38.834815979003906, 37.552824701581685, 34.76293189185006, 33.87091520854405, 32.85376494271414, 38.30642979485648, 34.59684910093035, 35.043569632938926, 33.724714687892366, 35.822334153311594, 36.81331055504935, 36.30154793603079, 35.86385658809117, 35.375575406210764, 38.35072456087385, 37.41148097174508, 42.72023126057216, 44.669850621904644, 43.5948600769043, 45.4099623135158, 45.74867309842791, 49.045374461582725, 49.494064807891846, 47.9799724306379, 50.71786839621407, 43.27913393293108, 48.22336435317993, 45.834097726004465, 48.089781761169434, 51.17925657544817, 53.11355863298689, 50.61859253474644, 52.533623763493125, 50.804925850459504, 51.69904783793858, 52.68096031461443, 53.198621954236714, 47.655800751277376, 43.50700010572161, 42.94938285010201, 42.4468856539045, 40.824866907937185, 44.00233023507254, 44.14722102028983, 44.9496511050633, 52.81298303604126, 54.719130992889404, 54.719113622392925, 56.13667467662266, 56.20945010866438, 58.12538112912859, 57.78264038903372, 52.44724028451102, 58.60798563276018, 59.44392340523856, 60.58645738874163, 57.82502440043858, 61.045191356113975, 55.795059544699534, 59.44204044342041, 9.291231904711042, 0.27760086261800354, 2.2617020436695645, 51.361754485539024, 55.27817610331944, 43.74683455058506, 19.534922872270855, 27.78346640723092, 45.96160411834717, 30.58826310294015, 39.85606915610177, 51.14055858339582, 13.6118015732084, 0.4441805583025728, 0.04684547075469579, 0.06788046684648309, 0.002497089020575264, 0.07387455699167081, 0.0461384067311883, 0.0638710373480405, 0.03805246436968446, 0.03924842305215342, 0.030198285821825266, 0.0621323117188045, 0.01897826654437397, 0.034914205981684585, 0.011948557237961462, 0.13564729264804296, 0.03045449046684163, 2.0020289719104767, 52.85965061187744, 58.37897300720215, 48.99042463302612, 34.04249749864851, 20.54552272387913, 40.511829716818674, 34.713339124407085, 60.849550928388325, 61.64638423919678, 55.9743960244315, 0.677666819521359, 1.6539086976221629, 0.15995233559182712, 0.1678270466093506, 3.9029308216912404, 33.7326078414917, 47.133271898542134, 46.9580522264753, 52.84415265492031, 57.53119550432478, 56.001963002341135, 57.774778502328054, 56.51848513739449, 52.89537130083357, 56.77155590057373, 58.271248136247905, 56.12017617906843, 58.058685370853965, 50.45495203563145, 46.88444995880127, 44.56917469842093, 45.059227670942036, 42.127720151628765, 43.135080405644004, 43.273759501320974, 52.002100467681885, 54.10489286695208, 56.81981808798653, 46.55158608300345, 50.42845160620553, 51.57338271822248, 54.66414294924055, 53.522977760859895, 52.54856586456299, 49.139890807015554, 49.02251141411917, 49.743421758924214, 46.79201112474714, 53.37724624361311, 52.94125720432827, 50.079895223890034, 52.686313901628765, 50.609643254961284, 49.8106803212847, 47.81816973005022, 47.863440717969624, 47.3362843649728, 44.44252988270351, 44.54387978145054, 38.5304570879255, 38.68384204592024, 38.42728328704834, 43.0609188079834, 42.628956249782014, 40.79019539696829, 41.27349124635969, 37.068924358912874, 41.613501344408306, 38.38337067195347, 38.8112268447876, 40.19731950759888, 41.053233351026265, 45.14924505778721, 47.605996063777376, 45.72188779285976, 47.979041372026714, 47.55414860589163, 46.02597917829241, 47.84884255273001, 43.57953929901123, 50.219130175454275, 44.62526403154646, 43.97195618493216, 45.008109773908345, 45.83634546824864, 43.50870588847569, 42.43047053473336, 40.571195125579834, 38.637706007276265, 36.95514760698591, 35.32078538622175, 40.356940473829, 37.525667667388916, 35.86282130650112, 35.657331807272776, 37.11705800465175, 37.99399014881679, 37.58262552533831, 38.45472172328404, 37.77935334614345, 39.01901619774954, 40.283557074410574, 45.43480559757778, 46.39546353476388, 47.365960121154785, 46.61392879486084, 47.95200593130929, 51.841485909053254, 52.191386767796104, 50.70341614314488, 51.03033930914742, 47.317166396549766, 48.535699776240754, 48.301993642534526, 48.79279007230486, 53.029019900730674, 54.71500376292637, 53.777705669403076, 54.499390738351, 51.11180346352713, 52.612121037074495, 54.958628450121196, 58.16427367074149, 50.68682731900896, 46.51213421140398, 46.64654016494751, 44.17865119661604, 44.55689375741141, 45.62405368259975, 45.45170361655099, 49.335156032017295, 56.43887962613787, 57.70652287346976, 57.04119464329311, 58.46399811335972, 61.143619537353516, 59.94436046055385, 63.240877696446006, 54.88090590068272, 62.26597595214844, 61.38172040666853, 64.76343645368303, 60.37874099186489, 65.717438016619, 59.136931146894185, 61.62104415893555, 8.546517031533376, 0.39367763112698284, 3.244550790105547, 62.07360117776053, 61.04158524104527, 52.96747275761196, 23.04344528062003, 34.7917217527117, 47.866671630314414, 35.19701712472098, 52.322478430611746, 61.33150577545166, 23.965815169470652, 0.5092412371720586, 0.03366019862837025, 0.037128581266318045, 0.04762702435255051, 0.0528502580044525, 0.015239240036212971, 0.08325683711362736, 0.11113192420452833, 0.10887215831982237, 0.09667156942720924, 0.1652299945375749, 0.12219441309571266, 0.16848564626915113, 0.18887654638716153, 0.294503034225532, 0.1260436201202018, 2.967571709837232, 63.274784905569895, 67.16854149954659, 58.98940699441092, 47.947579928806846, 29.51975522722517, 43.5641907283238, 39.819632802690776, 65.19204998016357, 67.52575533730644, 59.69836643763951, 0.8540934153965541, 4.447996590818677, 0.38024974880473955, 0.1393952758184501, 8.14085340499878, 39.940962246486116, 46.79888984135219, 50.58133281980242, 57.79421261378697, 58.79052870614188, 58.880320276532856, 57.625176838466096, 59.15741443634033, 55.546532903398784, 58.29434394836426, 61.71613025665283, 58.11082812717983, 59.4287485395159, 52.023014545440674, 48.95456150599888, 47.71832064219883, 47.1260735648019, 44.557988098689485, 45.16074085235596, 44.599972588675364, 54.2575934273856, 55.66722311292376, 56.66476903642927, 47.81182949883597, 52.58425876072475, 53.32200806481497, 58.24477202551705, 55.19415848595755, 54.01501096997942, 50.39720555714199, 50.48347091674805, 52.73564958572388, 48.741529737200054, 54.58223411015102, 55.6722640310015, 54.37384373801095, 56.92857824053083, 52.466479846409385, 53.786040033612935, 51.128270694187705, 51.82505341938564, 51.64164529527937, 48.27641384942191, 47.645312445504324, 42.95560148784092, 40.87286506380354, 42.30636181150164, 47.93771348680769, 45.19468975067139, 45.70835270200457, 44.76219565527779, 39.42132384436471, 42.44161197117397, 40.859125001089915, 43.43757370540074, 45.293569564819336, 45.15962219238281, 48.00536114828927, 49.445903369358604, 48.33258308683123, 50.21255717958723, 49.20371348517281, 49.30091878346035, 50.28192799431937, 44.555785519736155, 50.58716583251953, 46.466870171683176, 47.178532464163645, 46.959077085767476, 46.71459082194737, 45.41472182955061, 44.690886293138774, 45.41826541083199, 43.63810566493443, 39.66579621178763, 39.707777227674214, 43.05870928083147, 40.11362845557076, 40.44596426827567, 37.54661648614066, 40.27178682599749, 40.629282065800254, 41.67824813297817, 42.104832785470144, 41.68226071766445, 43.72836971282959, 42.58981704711914, 48.3673449243818, 50.339997564043315, 50.24645396641323, 50.858228955950054, 52.94094800949097, 55.353696073804585, 55.217236927577424, 54.05966009412493, 54.45866387231009, 48.78237819671631, 52.87757696424212, 51.559319564274375, 52.47072866984776, 56.5944949558803, 56.87207548958914, 55.72006416320801, 56.35397958755493, 55.86728259495327, 55.9862322807312, 57.701058115277974, 58.723221506391255, 51.749450070517405, 49.91689395904541, 48.51539019175938, 46.24152272088187, 45.84610421316964, 48.99614300046648, 49.145491055079866, 50.02121421269008, 58.07621914999825, 62.07986845288958, 60.91626058306013, 63.072599274771555, 64.46533094133649, 62.406906264168875, 64.9548454284668, 57.83749294281006, 65.95576817648751, 66.60591111864362, 68.08996990748814, 65.05327360970634, 69.81453364236015, 61.345478602818076, 66.37729454040527, 13.507246817861285, 0.38097838684916496, 3.7198779242379323, 68.03802517482212, 68.61487851824079, 58.39405059814453, 31.680127348218644, 43.27325575692313, 61.55512659890311, 43.97991187231881, 56.765128816877095, 73.40167318071637, 30.8314083644322, 0.8247924276760646, 0.21013388144118444, 0.2944356421274798, 0.16206749209335872, 0.13302007290933812, 0.10848305241337844, 0.20074652587728842], [0.008667287416756153, 0.020980348577722907, 0.05867653965417828, 0.04106975692723479, 0.03325509625886168, 0.02066195959092251, 0.03689677674057228, 0.020590006041207483, 0.041584510555756946, 4.575703612395695, 51.00056627818516, 51.960581507001606, 38.233470235552105, 27.292735985347203, 51.32290015901838, 45.09868996483939, 25.920676946640015, 52.47209399087088, 57.329916613442556, 63.77894619532994, 5.534198922770364, 1.8178366784538542, 0.5355347948414939, 0.3374024065477507, 0.23208158516458102, 7.869051166943141, 35.80936534064156, 37.90134981700352, 40.24081175667899, 48.09227269036429, 53.68317890167236, 55.90811368397304, 54.10970796857561, 52.984207493918284, 57.37595885140555, 54.317288875579834, 54.237606934138704, 52.98028176171439, 48.10337938581194, 43.36783116204398, 42.242584296635215, 40.537058625902446, 40.88577481678554, 40.50494752611433, 44.58990117481777, 50.37425218309675, 52.685052803584504, 52.60548203332083, 43.323546818324495, 49.339126927512034, 53.035763127463206, 51.30338266917637, 50.45594910212925, 46.2216717175075, 47.411905084337505, 47.850464957101, 49.226732867104666, 45.78393520627703, 50.04237495149885, 48.85493128640311, 49.87570851189749, 49.65591614586966, 47.57571928841727, 46.25354657854353, 45.5122641154698, 47.77243321282523, 48.337658745901926, 45.83254827771868, 42.10904686791556, 41.124803270612446, 42.1685859816415, 39.85849755150931, 42.27660962513515, 37.78973742893764, 40.79333945683071, 37.65285096849714, 39.11270570755005, 36.027649947575156, 37.41253709793091, 33.96129390171596, 34.4474697794233, 37.49077728816441, 43.39843102863857, 45.42626278741019, 47.45477894374302, 52.69315092904227, 50.10733018602644, 49.07555743626186, 47.98503419331142, 44.09925413131714, 47.071599687848774, 46.91034936904907, 48.44144746235439, 46.318275996616904, 44.56540877478463, 42.68101910182408, 38.491627080099924, 35.34113318579537, 37.0506888117109, 35.470418316977366, 33.46923289980207, 36.661374296460835, 35.88272442136492, 37.903899805886404, 35.47771392549787, 35.91033656256539, 36.468732016427175, 34.85140677860805, 33.74133130482265, 34.56162173407418, 40.58884702410017, 43.95170913423811, 42.951891149793354, 43.882668358939036, 42.95886366707938, 45.40066909790039, 45.89851100104195, 46.58468382699149, 47.623592376708984, 47.90103047234671, 50.77263062340872, 47.835682664598735, 47.252631528036936, 46.58904382160732, 47.73045219693865, 48.317442962101524, 51.916734899793354, 51.39602647508894, 55.005063261304585, 52.781122071402415, 48.57814979553223, 52.81055464063372, 52.658145904541016, 51.896341936928884, 48.574675696236746, 44.13059745516096, 45.000810691288535, 41.60880088806152, 43.57914325169155, 42.38730832508632, 53.15816606794085, 55.44368914195469, 56.35842643465315, 56.11223438807896, 54.67879670006888, 54.952976090567454, 58.77911976405552, 54.518883909497944, 57.4696935244969, 55.801319871629985, 61.479662214006694, 56.45129953111921, 60.467483384268625, 53.39548526491438, 56.841909885406494, 34.39292294638497, 2.211539089679718, 0.30963547793882235, 8.452302064214434, 62.05338191986084, 49.98639678955078, 41.294023173195974, 37.87498835154942, 49.19527489798409, 36.861423356192454, 32.66744204929897, 32.63364601135254, 53.88135889598301, 29.661199705941335, 0.4355485343507358, 0.02209384998838816, 0.04608712983982904, 0.010991634568199515, 0.011207893008499272, 0.0018268056238801883, 0.06947731758866992, 0.02430630841159395, 0.031594846597207446, 0.021337522626189247, 0.04175761840971453, 0.0658985949786646, 0.0042771840817295015, 0.0008741987018895868, 0.0975902040622064, 0.05184590404054948, 7.283592045307159, 61.32622514452253, 58.03308820724487, 43.81634085518973, 19.689817326409475, 43.93796212332589, 46.92553118297032, 31.894969122750418, 57.421403544289724, 60.765623637608115, 70.044755254473, 7.829432538577488, 1.520184970327786, 2.601063136543546, 0.6099344768694469, 0.38276586521949085, 6.623810648918152, 35.623303004673545, 40.92485843385969, 46.503785950796946, 50.23565993990217, 57.83325801576887, 56.171766553606304, 55.5928669657026, 54.19509438105992, 59.85065010615757, 56.06533752168928, 57.3003693989345, 53.83664723805019, 49.84888499123709, 45.12045519692557, 45.06215633664812, 42.25034890856062, 43.00169931139265, 43.681365149361746, 47.95731782913208, 49.92450223650251, 54.55890205928257, 54.87435374941145, 44.05384070532662, 51.85526418685913, 55.63128702981131, 53.44307000296456, 53.71697841371809, 48.663463251931326, 49.73645271573748, 47.474289485386436, 50.28746223449707, 47.40021474020821, 51.84078761509487, 50.87774991989136, 55.64985956464495, 51.75731890542166, 50.13259731020246, 50.07156433377947, 46.91897555759975, 48.455291748046875, 49.816551549094065, 47.29996960503714, 44.52429975782122, 43.163543701171875, 42.785985537937705, 40.64750371660505, 43.87972232273647, 39.76162576675415, 42.18758235658918, 39.64532681873867, 41.33336387361799, 37.63893025262015, 40.16952323913574, 37.50557000296456, 39.0517943246024, 40.280659675598145, 45.41647277559553, 46.586723123277935, 48.05255331311907, 53.456511293138774, 50.12866462979998, 49.783193247658865, 47.701043946402415, 44.64258589063372, 48.570826394217356, 46.50377205439976, 48.969263894217356, 48.82463366644723, 46.33230093547276, 44.22926882335118, 41.04131024224417, 38.38514593669346, 40.42514051709856, 37.88902023860386, 35.304839270455496, 39.007930346897666, 37.286906719207764, 40.07313782828194, 38.72797005517142, 37.994608538491384, 38.175039359501426, 38.968843255724224, 37.38324349267142, 38.91497734614781, 42.18729748044695, 45.40345879963466, 46.78801243645804, 45.903718675885884, 45.863054343632285, 49.055612632206504, 48.31028979165213, 50.55940777914864, 50.87737819126674, 52.70417077200753, 51.272282532283235, 49.469746112823486, 50.252196652548655, 48.67880834851946, 51.09586777005877, 50.83810002463204, 54.70067310333252, 54.56593016215733, 57.48901299067906, 55.33112832478115, 50.40289613178798, 53.68503754479544, 57.092409815107075, 54.36276136125837, 50.61257539476667, 47.28096628189087, 46.46737044198172, 44.344372681209016, 45.634062562670024, 44.47208057131086, 55.69353594098772, 59.02746227809361, 60.68364879063198, 59.154878343854634, 60.080149105616975, 58.32823726109096, 62.50417409624372, 58.69478252955845, 59.25072874341692, 57.98247058050973, 65.78288309914726, 59.01754719870431, 64.73724174499512, 57.46314137322562, 61.969982692173545, 33.56594487598964, 1.7671863734722137, 0.26725857758096283, 12.689103381974356, 71.33950342450822, 54.87538208280291, 47.828060490744456, 39.84283978598458, 51.58471523012434, 44.11189637865339, 35.85243374960763, 45.94442122323172, 60.88759231567383, 43.31477124350411, 0.651719694691045, 0.05575067290504064, 0.08254886724586998, 0.043692461015390496, 0.09136736619153193, 0.02427610851425145, 0.052877100849790235, 0.11092338325189692, 0.10062185781342642, 0.13170129938849381, 0.14220278231160982, 0.18706177733838558, 0.12841834340776714, 0.1416735928505659, 0.2834047254707132, 0.10566243662365846, 8.412405507905142, 73.12154960632324, 63.721456800188335, 52.53549630301339, 39.424040590013774, 65.35870252336774, 59.44282558986119, 38.03888940811157, 65.3194660459246, 66.50357804979596, 79.01931953430176, 7.566382425171988, 7.503043515341623, 3.599829988820212, 0.6413739355547088, 0.8045623674988747, 9.00411149433681, 41.40254361288888, 43.23951530456543, 52.09790570395333, 53.131297383989605, 62.06461020878383, 58.20059190477644, 59.60617773873465, 57.26273100716727, 62.262904848371235, 60.74429266793387, 59.77459512438093, 56.57917070388794, 53.50978660583496, 47.76278911318098, 48.83251987184797, 46.513930320739746, 45.721693243299214, 45.4614554132734, 49.769713742392405, 52.24042020525251, 55.59635148729597, 56.656472887311665, 45.80572823115757, 54.343216078622, 57.50586584636143, 55.3031896182469, 54.64429889406477, 49.780132566179546, 52.45265293121338, 51.19717945371355, 53.39896283830915, 50.232825074877056, 54.77746459415981, 52.55119923182896, 57.927631923130576, 53.52861622401646, 53.6660863331386, 51.63425588607788, 50.37472813470023, 51.37045363017491, 52.195976052965435, 51.86695800508772, 47.40029117039272, 47.02815955025809, 46.82162087304251, 43.55924013682774, 46.118226936885286, 43.76097413471767, 44.43122863769531, 41.63400200435093, 43.97533995764596, 41.12495960508074, 42.55689648219517, 40.44677025931222, 42.156113965170725, 45.31432383401053, 48.65860298701695, 48.84845209121704, 50.58080128261021, 56.04075479507446, 52.05428491319929, 51.497734206063406, 48.646061488560264, 45.98893485750471, 48.183457374572754, 48.837248120989116, 49.7664133480617, 51.86778484072004, 48.608016627175466, 47.836735316685264, 44.54090595245361, 41.90372065135411, 43.78976399557931, 40.20701224463326, 38.056367601667134, 41.510271957942415, 40.44092682429722, 44.24078893661499, 41.513051237378804, 41.51215839385986, 40.682922158922466, 41.94803278786795, 39.68346200670515, 41.06209577832903, 46.46883998598371, 49.81784043993269, 50.056278296879356, 49.25078405652727, 48.8072874886649, 53.015995502471924, 51.40382930210659, 52.285218715667725, 55.05524662562779, 57.85325493131365, 54.26289142881121, 52.77059555053711, 53.37976496560233, 51.95053093773978, 51.76918295451573, 54.14036342075893, 55.59206097466605, 56.05504376547677, 58.66472462245396, 58.506201471601216, 52.146101883479524, 55.095462799072266, 57.94256707600185, 56.461909430367605, 52.992913586752756, 49.20261914389474, 49.6292941229684, 48.81822395324707, 47.75188738959176, 48.288823332105366, 58.831043652125764, 59.78869996752058, 62.4450866154262, 61.31912408556257, 61.540042059762136, 62.56158011300223, 63.90907205854143, 60.70201287950788, 62.25937516348702, 60.88411126817976, 68.17343861716134, 63.707685470581055, 69.23090580531529, 62.449165207999094, 64.19521972111293, 41.338554177965435, 4.199552893638611, 0.4293039765741144, 13.281292268208094, 79.64852755410331, 60.02692590441023, 58.96295520237514, 48.24157558168684, 62.67607947758266, 54.26719583783831, 42.59183897290911, 49.2494569505964, 75.60708005087716, 51.632775919778005, 1.0540127392326082, 0.14702817052602768, 0.18229683302342892, 0.14757901882486685, 0.16491136806351797, 0.10871590527572803, 0.19049569379006112], [0.04478100421173232, 0.02375692405205752, 0.06540578856532063, 0.07944738545588084, 0.018750366987660527, 0.02224315144121647, 0.06154147735131638, 0.2267812088664089, 0.02258777428817536, 14.204563685825892, 66.94880471910749, 48.681188106536865, 39.51480490820748, 59.00611046382359, 91.78859383719308, 58.955263546534944, 22.996379920414515, 56.67205074855259, 58.23713248116629, 62.56381048474993, 31.20654855455671, 1.17404362985066, 0.16816438707922185, 0.3395176444734846, 0.06545732329998698, 0.27581715690238134, 16.141243764332362, 32.94077375956944, 31.034747396196636, 43.08764852796282, 52.48924214499337, 56.383137702941895, 56.55256257738386, 55.26287964412144, 56.120315143040244, 52.92718015398298, 54.97982045582363, 46.118897438049316, 47.29809359141758, 43.28589800425938, 41.93558161599295, 40.038171018872944, 42.17757000241961, 42.00873919895717, 46.62701572690691, 50.813614572797505, 56.48400122778756, 50.71448114940098, 48.43391561508179, 56.13366263253348, 53.83534792491368, 53.08968809672764, 52.20231281008039, 47.410140241895405, 44.46295063836234, 47.141606262751985, 47.931974274771555, 46.80338185174124, 47.94924749646868, 47.71796975816999, 48.98020730699812, 48.48621470587594, 46.87678609575544, 47.43343755177089, 49.69578490938459, 46.44742216382708, 49.478122166224885, 44.51406506129673, 48.316543170383994, 43.28900037493025, 42.27938543047224, 38.6216139793396, 40.738420895167756, 42.18105104991368, 40.27455915723528, 37.442365714481895, 40.47316993985857, 36.22962713241577, 36.91731466565813, 35.89429317201887, 32.54383707046509, 37.44613858631679, 43.21591922215053, 45.99651881626674, 50.48794208254133, 51.93444585800171, 54.067278793879915, 51.8541316304888, 43.21583931786673, 36.736730984279085, 49.34724589756557, 52.887464250837056, 52.64543764931815, 48.49468108585903, 45.08572115216936, 40.44782638549805, 37.358261244637625, 34.473146847316194, 34.08948121752058, 35.21404715946743, 35.393831798008506, 37.437213625226704, 36.425215448652, 36.800386905670166, 38.15679339000157, 36.516667638506206, 35.92149536950247, 32.876329217638286, 36.70529385975429, 39.32986470631191, 44.476979051317485, 42.7896854536874, 46.55937501362392, 42.70412881033761, 43.453307901109966, 45.678131512233186, 50.05229697908674, 51.98982994897025, 50.83207941055298, 48.95515905107771, 47.172984327588765, 48.587769576481406, 50.00208582196917, 45.6828875541687, 49.727402687072754, 46.225725991385325, 51.28166954857962, 52.24905334200178, 54.52262551443917, 54.32840599332537, 51.75416789736067, 50.32536118371146, 55.07787343433925, 52.15117406845093, 50.70103638512747, 47.563017981392996, 46.45295640400478, 42.042622089385986, 42.993601185934885, 41.09520047051566, 50.88070637839181, 56.396704060690745, 59.50100980486189, 58.54552827562605, 57.05285024642944, 54.45505428314209, 57.92180585861206, 55.81700890404837, 57.30546242850167, 54.21598414012364, 57.51116384778704, 55.99345145906721, 57.39254420144217, 48.9367220061166, 48.16884183883667, 12.215393441064016, 0.2768635664667402, 0.4000571630895138, 23.574860879353114, 57.41030379704067, 52.628946099962505, 34.62482949665615, 26.28800388744899, 54.41161414555141, 43.70940113067627, 35.35529014042446, 38.82439715521676, 54.44695268358503, 40.43849148069109, 2.0933882296085358, 0.20248478331736156, 0.03363994775073869, 0.14783528793070996, 0.03627998501594577, 0.028078233690134118, 0.025762034047927176, 0.07511852881205933, 0.10701452621391841, 0.012864849230806743, 0.033756241867584844, 0.07920516881027392, 0.06537371421498911, 0.02936053934640118, 0.19512399472296238, 0.15903338204537118, 19.91508834702628, 74.45906393868583, 53.361046518598286, 45.09182167053223, 53.54751532418387, 91.16695935385567, 58.829431670052664, 27.264788593564713, 61.16959190368652, 64.11334909711564, 67.58489145551408, 37.59516702379499, 0.5254399308136531, 1.937032482453755, 0.5616204493812152, 0.19900183592523846, 0.46534164994955063, 15.191907916750226, 37.052248682294575, 38.6372960635594, 50.212449482509065, 56.271730286734446, 59.354861395699636, 57.31521422522408, 56.48661722455706, 58.58458409990583, 57.61743654523577, 55.74533476148333, 48.626648221697124, 50.75239746911185, 45.27113035746983, 43.522397313799175, 42.56013781683785, 43.861726488385884, 45.006230286189485, 48.30904606410435, 55.51590176991054, 55.93298476082938, 51.73991019385201, 48.977254322596956, 57.61780479976109, 54.9046687398638, 54.405562264578684, 53.99064016342163, 49.50279174532209, 47.71712555204119, 49.10309662137713, 50.04454626355852, 49.603491987500874, 51.034904275621685, 51.18066358566284, 51.54879304340908, 50.05296400615147, 49.61439023699079, 48.99400642939976, 51.38467311859131, 47.65341404506138, 49.838410581861226, 47.068528584071565, 50.672183990478516, 46.07275445120675, 45.63857194355556, 40.68245315551758, 43.14548533303397, 43.61144890104021, 41.373507090977256, 40.637585163116455, 41.56215763092041, 38.214769159044536, 38.526013714926584, 37.456157888684956, 35.480722495487754, 40.09484052658081, 44.45518602643694, 46.9107106753758, 51.93742316109793, 52.57996129989624, 53.59503058024815, 50.56575148446219, 42.7839948790414, 35.62327173777989, 50.65460157394409, 54.57253442491804, 52.75347171510969, 48.38336052213396, 46.55025897707258, 43.28244822365897, 40.51712771824428, 36.96088334492275, 35.57500260216849, 36.11482204709734, 36.97031552450997, 39.69643776757376, 39.26435708999634, 39.10719926016671, 39.757693086351665, 38.27986683164324, 39.64871059145246, 35.06759997776577, 39.33446093967983, 41.91653312955584, 46.87587240764073, 45.105103152138845, 48.9390982900347, 46.949221066066194, 48.316397258213584, 49.48607785361153, 51.530936173030305, 52.99278504507882, 53.800540924072266, 52.60661458969116, 49.259969575064524, 50.70488568714687, 51.32574544634138, 47.47944157464163, 49.931415694100515, 48.83004978724888, 52.188979216984336, 55.91035795211792, 57.40832008634295, 57.04698249271938, 54.54336936133248, 50.73704195022583, 60.00428867340088, 55.10895620073591, 53.26925734111241, 49.61327157701765, 49.14690153939383, 46.10620655332293, 44.10168947492327, 42.84976652690342, 54.53643158503941, 59.56416198185512, 61.79082339150565, 61.675837653023855, 59.23468535287039, 58.073453766959055, 62.07598440987723, 62.73763356889997, 57.4040504183088, 59.73733193533761, 61.7837153843471, 58.58731474195208, 61.01122856140137, 52.01022638593401, 51.78831481933594, 9.095979707581655, 0.40125979855656624, 0.3540036071624075, 30.87377153124128, 63.60772173745291, 58.21057994025094, 40.72482327052525, 26.1695579460689, 63.7422388621739, 55.081510816301616, 34.18577282769339, 52.96015283039638, 63.39169529506138, 54.481075286865234, 4.082850081580026, 0.25656432285904884, 0.06159326314393963, 0.17543696612119675, 0.04292919732896345, 0.07672275522989885, 0.0741792463564447, 0.14446602229561123, 0.1860528364777565, 0.16772921543036187, 0.21068033283310278, 0.1331519122634615, 0.1445139811507293, 0.11723201509032931, 0.3825968014342444, 0.29619063224111286, 23.352716548102244, 85.25206211635044, 62.62792151314871, 55.74501861844744, 71.58183574676514, 97.70068400246757, 72.46891920907157, 33.99368987764631, 66.97028854915074, 69.2292868750436, 74.84985147203717, 38.97128207342965, 3.0992689515863145, 2.738716721534729, 1.1173698880842753, 0.2413375356367656, 0.8367578227605138, 20.29212886946542, 41.58347817829677, 45.35808706283569, 54.31893559864589, 61.3817412512643, 62.137045179094585, 59.43924726758684, 61.157946722848074, 61.18006978716169, 59.15108462742397, 59.87262031010219, 50.78257349559239, 53.917677130017964, 47.21086938040597, 47.30332905905587, 43.93263980320522, 46.17429542541504, 47.14756781714303, 52.206575529915945, 55.03556932721819, 57.27219097954886, 54.28542791094099, 50.105843271527974, 61.11289460318429, 56.98687015260969, 56.169178349631174, 56.28159325463431, 51.141100542885916, 48.28784016200474, 51.56088638305664, 52.933794839041575, 51.38195289884295, 52.785468169621055, 52.830763476235525, 54.783961159842356, 53.213397298540386, 51.44441720417568, 51.44337150028774, 52.9344653402056, 51.483063084738596, 54.560764176504954, 50.35022531236921, 54.13188314437866, 48.62224306379046, 47.98878274645124, 43.56737300327846, 45.92803042275565, 46.90698644093105, 45.62942116601126, 42.49313286372593, 44.94905355998448, 40.43797731399536, 42.459604331425254, 41.17751925332205, 39.410905020577566, 45.846760817936485, 46.55256230490548, 48.92446885790144, 55.950991017477854, 53.865034103393555, 55.34367329733712, 52.351678235190256, 43.25266477039882, 36.830045291355674, 51.624782017299104, 57.29446343013218, 54.63027048110962, 51.42100177492414, 49.78443350110735, 46.28384419849941, 44.52247585569109, 41.16186843599592, 38.919820240565706, 40.48589209147862, 40.66167804173061, 42.30061565126692, 43.64331333977835, 43.456462383270264, 41.95466831752232, 41.79670449665615, 43.52359587805611, 39.56948028291975, 42.36831889833723, 45.14414855412075, 49.17836993081229, 49.28367335455758, 52.14772081375122, 50.24021100997925, 48.08106524603707, 51.148535115378245, 55.06728785378592, 57.91073737825666, 56.59730897630964, 55.426745959690635, 51.7396878514971, 54.36475202015468, 54.70293126787458, 51.208039488111226, 52.31391477584839, 51.271101338522776, 55.026157992226736, 58.45051860809326, 58.84080587114607, 60.39257485525948, 57.06484631129673, 52.43051597050258, 59.17208208356585, 57.32376398359026, 56.63726806640625, 52.59615060261318, 51.882587977818076, 47.748903138296946, 47.594378675733296, 43.84402595247541, 56.5745119367327, 62.433531761169434, 64.72785472869873, 64.35448632921491, 61.44056470053536, 60.07042162758963, 61.92158848898751, 62.24692399161202, 60.43509783063616, 62.54318823133196, 68.88612924303327, 62.156861441476, 69.31816128322056, 56.67206117085048, 58.88792855398995, 14.496627739497594, 0.8286705538630486, 0.455160774822746, 32.703993047986714, 71.12968172345842, 63.32376275743757, 48.98138502665928, 36.26103299004691, 68.83401775360107, 61.31413527897426, 48.60018948146275, 53.18460396357945, 72.0647702898298, 67.32604326520647, 5.9242581980569025, 0.43323307431169916, 0.16756070804383072, 0.32370357162186075, 0.22942913749388286, 0.16007095708378724, 0.13129762533519948], [0.04070110206625291, 0.05530531983822584, 0.0265469463941242, 0.018436539452522993, 0.018733493518084288, 0.10814624120082174, 0.030189349515629665, 0.1325603790049042, 0.03235400514677167, 21.112679856164114, 59.73740141732352, 42.048854623522075, 32.57282842908587, 54.704682213919504, 89.29066780635289, 54.98731061390468, 23.785792555127824, 43.05758714675903, 62.40233434949602, 52.36981998171125, 64.93933010101318, 3.421505340508052, 1.8785525347505296, 0.6319751398903983, 0.6139742572392736, 0.258289918835674, 4.27304572718484, 26.515963860920497, 25.40355031830924, 41.75153078351702, 52.79766225814819, 52.90463672365461, 54.927215644291465, 55.07451050622122, 54.510712827954976, 51.30887869426182, 51.78663682937622, 50.007307393210276, 42.23074804033552, 43.8353476524353, 39.897313662937705, 40.44808346884591, 42.746634415217805, 46.661669867379324, 51.18471091134207, 54.25497395651681, 54.65162924357823, 48.78629698072161, 52.62362725394112, 54.48316322054182, 52.24325507027762, 54.658650398254395, 49.51929024287632, 48.784125668661936, 42.75728600365775, 47.20005798339844, 49.12772103718349, 46.699683461870464, 48.30160454341343, 48.65395811625889, 45.587148325783865, 50.84077508108956, 49.89218963895525, 47.36890268325806, 46.78947850636074, 48.0936484336853, 49.07100289208548, 44.875854287828716, 38.2883505821228, 46.98047406332833, 45.13025215693882, 41.71391323634556, 41.35446555273873, 40.91081265040806, 43.56854377474104, 42.29014124189104, 38.46768706185477, 38.87356260844639, 39.56431777136666, 35.79729979378836, 40.43097005571638, 40.21397433962141, 44.55057784489223, 48.7290472984314, 49.84577567236764, 53.78797163282122, 57.30697018759591, 54.75425066266741, 39.745276655469624, 33.37092978613717, 44.38136836460659, 57.367954526628765, 54.7285874911717, 51.870977537972585, 47.04636035646711, 45.45741156169346, 34.676062038966585, 33.95520380565098, 36.423669474465505, 34.72700275693621, 36.14203119277954, 37.315950189317974, 37.31291382653372, 36.09811857768467, 39.1882187298366, 37.551184926714214, 36.02700029100691, 38.0649972643171, 39.919832774571006, 44.36747196742466, 44.898783343178884, 45.02309703826904, 43.88502032416207, 45.35484920229231, 47.16504601069859, 44.985625403267996, 48.25225148882185, 51.3671567099435, 48.9611622946603, 47.818937505994526, 47.95178358895438, 49.44933230536324, 48.698742730276926, 47.32858228683472, 46.78708832604544, 49.752141748155864, 48.720838001796174, 52.213912827628, 52.44461039134434, 53.62175335202898, 51.956565448216026, 49.390342099326, 55.23749440056937, 53.884645393916536, 49.216314043317524, 47.93804005214146, 48.167997632707866, 43.74700130735125, 41.71247843333653, 42.45845787865775, 48.218497140066965, 55.27357986995152, 55.16460084915161, 57.89386715207781, 58.421433448791504, 58.290439060756135, 58.02721003123692, 57.007676533290315, 55.09789119447981, 56.051312582833425, 54.97997679029192, 55.289122990199495, 43.122493743896484, 42.36532769884382, 18.960147040230886, 0.5320724749139377, 0.30061307922005653, 0.08583252211766583, 41.508729457855225, 59.98845372881208, 51.51217256273542, 26.073942048209055, 25.014437300818308, 33.38847746167864, 47.124319144657676, 34.58962297439575, 29.30032069342477, 44.27442169189453, 48.49691145760672, 3.1777627510683875, 0.3769729132098811, 0.07572691688047987, 0.13981807098856994, 0.11554319571171488, 0.050329015257635286, 0.04041855329913752, 0.03309472789987922, 0.03546163785670485, 0.037789185997098684, 0.006076035123052341, 0.05055298948926585, 0.04761567246168852, 0.02662348175155265, 0.10538240522146225, 0.04992323096043297, 27.023043394088745, 70.52634184701103, 46.02640996660505, 35.80202109473092, 60.38257639748709, 92.80802658626011, 60.92984431130545, 31.357011795043945, 48.34817484446934, 69.28748498644147, 56.06122071402413, 73.492201260158, 4.41018362556185, 0.7755566239356995, 0.005656418889494879, 0.48704331687518526, 0.13640934175678662, 4.133889377117157, 28.333129712513514, 31.81402955736433, 49.4482866014753, 55.67905936922346, 55.90049498421805, 57.91414546966553, 56.92862687792097, 55.07763719558716, 53.82836151123047, 52.761253697531565, 50.77262714930943, 45.2279611996242, 44.48489304951259, 41.82475437436785, 43.811140128544395, 44.552148137773784, 49.24049030031477, 54.67222023010254, 57.8559820992606, 57.59762723105294, 50.749256883348735, 54.06746292114258, 57.01996789659773, 54.12980215890067, 54.50962543487549, 53.696126869746614, 51.801999296460835, 44.31706278664725, 50.89180612564087, 49.50211429595947, 48.62068666730608, 51.65897062846592, 50.36500065667288, 49.62042474746704, 52.985579763139995, 51.488326345171245, 50.99826642445156, 47.4917642048427, 48.83958966391427, 51.642635413578574, 46.934994629451204, 42.15088544573103, 50.10444320951189, 47.12507997240339, 43.99246726717268, 42.93155377251761, 42.66909599304199, 44.116829599652974, 42.98031275612967, 39.58905335835048, 42.233485630580354, 40.17038481576102, 37.6973055430821, 42.30460739135742, 41.89589350564139, 46.85345751898629, 49.9590208871024, 52.137048380715505, 54.25470297677176, 57.8111696924482, 56.11641720363072, 37.69038166318621, 32.948951789310996, 42.97755432128906, 57.58640589032854, 55.41374240602766, 52.768945353371755, 49.08549683434622, 48.708386829921174, 36.95023175648281, 36.98319748469761, 38.399188246045796, 37.01368965421404, 37.05397183554513, 39.419308866773335, 39.464645862579346, 38.16915076119559, 40.5218003817967, 40.54254075459072, 39.22938333238874, 40.60668999808175, 42.4196834564209, 47.68973227909633, 46.49758815765381, 47.388906547001426, 46.97518995829991, 47.82399926866804, 48.94625146048409, 50.28337321962629, 51.67891543252127, 51.565030983516145, 53.149623257773264, 49.54703439985003, 51.76265859603882, 50.315713609967915, 51.1252794946943, 47.21949209485735, 49.119636808122905, 51.32409872327532, 51.74370043618338, 54.17375298908779, 54.14196845463344, 55.316127164023264, 54.24995388303484, 50.052394253867014, 59.82297543116978, 57.1678637777056, 53.72900921957833, 52.40723255702427, 51.695983682359966, 47.594232763562886, 44.693922655923025, 44.27179527282715, 52.282613141196116, 58.59855692727225, 57.954712527138845, 58.609000069754465, 61.09117453438895, 60.90608842032296, 62.08193901606968, 65.72829110281808, 57.82800170353481, 57.32551492963518, 58.22368424279349, 60.05105699811663, 48.31322193145752, 48.49574416024344, 18.59311887196132, 0.414555909378188, 0.06724210788628884, 0.24780530429312161, 47.604582105364116, 66.38707065582275, 56.98676592963082, 31.049991743905203, 26.304111548832484, 41.489152908325195, 58.47319752829415, 30.18821014676775, 41.196755341121126, 53.10867404937744, 60.84921741485596, 7.630713190351214, 0.38939775792615755, 0.08070447335817985, 0.05603107410882201, 0.04240264736914209, 0.05418454622849822, 0.011458961143424469, 0.12846578657627106, 0.04279244877398014, 0.08454681360828024, 0.08077316824346781, 0.22696970589458942, 0.1534225352640663, 0.15330181031354836, 0.20404719162200177, 0.2129576863454921, 32.94099957602364, 82.55573722294399, 54.14179127556937, 48.27391597202846, 65.43857901436942, 96.20553588867188, 63.126468658447266, 38.28483826773507, 53.82455389840262, 74.41924381256104, 60.777956690107075, 80.00628335135323, 4.109766968658992, 5.539159068039485, 0.8500133029052189, 1.4429084083863666, 0.8520087929708617, 6.616193686212812, 35.673924105507986, 40.50001777921404, 57.23997565678188, 59.28554616655622, 60.58403941563198, 60.281160490853445, 58.81643853868757, 57.51044123513358, 57.04974092755999, 56.900153160095215, 55.74667576381138, 46.740914072309224, 48.451862812042236, 44.21676901408604, 45.112152099609375, 48.665151664188926, 51.00026055744716, 56.58209589549473, 58.50380434308733, 57.31367519923619, 52.069167954581125, 54.96831423895699, 60.718202182224815, 55.92937169756208, 57.12219326836722, 55.181592668805806, 54.091941424778526, 46.74118505205427, 53.49919407708304, 52.39755024228777, 50.39019135066441, 52.61948612758091, 52.44625016621181, 50.23902634211949, 55.61988851002285, 54.633077553340364, 54.197665214538574, 49.85163995197841, 50.711826937539236, 53.331940514700754, 52.192467212677, 46.07074989591326, 52.57916573115757, 49.41666187558855, 47.18768671580723, 46.10738427298409, 45.73914016996111, 46.440936020442415, 46.84943798610142, 41.84357009615217, 46.08090121405465, 46.45991849899292, 41.852387360164094, 46.86277852739607, 44.1573862348284, 49.07766621453421, 53.2875519480024, 54.26490988050188, 57.69458586829049, 61.68032618931362, 58.63602161407471, 39.960549218314036, 33.12030826296125, 45.29714788709368, 60.640854835510254, 57.842513016292024, 55.39452716282436, 51.693788051605225, 51.69776936939785, 39.18474463054112, 38.900629316057476, 41.512099334171836, 41.12970175061907, 40.882227761404856, 43.429631914411274, 42.70628275190081, 40.31624487468174, 44.024005140577046, 44.0311096736363, 43.50932080405099, 46.26718936647688, 45.350266865321565, 51.72096593039376, 50.25488213130406, 49.6014700617109, 49.113129820142476, 49.03406974247524, 52.5888306753976, 51.69417715072632, 54.917672293526785, 55.406151499067036, 55.34717171532767, 53.17921216147286, 53.82684680393764, 55.56086703709194, 53.995993750435964, 51.167118072509766, 51.86680514471871, 54.91260705675398, 53.14192117963518, 56.42497280665806, 56.32296977724348, 58.134594440460205, 56.72581590924944, 52.792989594595774, 56.315100942339214, 59.24956144605364, 54.36556495938982, 54.60797718593052, 53.12148305347988, 50.29003654207502, 48.299513135637554, 48.48491539273943, 54.119167940957205, 61.76923533848354, 60.33270222800118, 62.38937595912388, 64.34765625, 62.69612503051758, 63.678829601832796, 61.32297338758196, 61.54248782566616, 60.24584974561419, 63.24632508414132, 67.02499866485596, 55.31496681485857, 54.241664682115825, 25.38985194478716, 0.6740161382726261, 0.5540458272610391, 0.46065764129161835, 53.42533125196184, 72.61173943110875, 63.67050565992083, 39.35019860948835, 36.47715323311942, 45.77921043123518, 64.69022328513009, 46.26173503058297, 43.720723220280235, 60.46735831669399, 75.31509590148926, 11.175397498267037, 0.5911890513130597, 0.19371633311467512, 0.17092236051602022, 0.21644288647387708, 0.2246132216283253, 0.14242013064878328], [0.11129325269056217, 0.03244870827932443, 0.03990580474159547, 0.08557747437485627, 0.018009325323094214, 0.021091392529862266, 0.06984517177832977, 0.1924960014543363, 0.12417292621518884, 33.12385184424264, 56.90084450585501, 46.14371987751552, 36.23843744822911, 52.76935877118792, 84.23152460370744, 37.91669838769095, 16.57688365663801, 38.60464300428118, 68.33977154323033, 49.629269804273335, 67.5942576272147, 21.736867802483694, 0.27276611062032835, 0.5237692690321377, 0.4055829080087798, 0.3838302695325443, 2.324499645403453, 9.703842861311776, 17.49441065107073, 37.064765862056184, 50.65388938358852, 50.48848404203142, 54.0807409286499, 51.30780519757952, 49.405499594552175, 46.02491610390799, 46.312498569488525, 44.763244833265034, 40.90043551581246, 39.60882098334176, 40.000327655247276, 41.0009377343314, 45.3456324168614, 48.470247745513916, 50.39259195327759, 55.716100215911865, 48.68897703715733, 48.05310569490705, 56.00928292955671, 53.523064613342285, 53.5136011668614, 52.543674332754954, 48.590177127293174, 46.263576303209575, 43.80753401347569, 47.18321555001395, 49.95724562236241, 48.78060640607561, 51.05993863514492, 50.822077478681294, 47.1173848424639, 46.30930239813668, 49.969429288591655, 45.78153460366385, 47.528947489602224, 45.378059659685405, 49.954560143607004, 48.22779382978167, 43.32641295024327, 44.25302471433367, 43.36430147715977, 42.21825170516968, 43.62213870457241, 43.64086757387434, 41.02532243728638, 41.699759755815776, 42.58107621329171, 40.54244000571114, 41.67158481052944, 37.987945216042654, 41.21656118120466, 46.53275646482195, 44.581073488507954, 51.142059394291465, 48.43938384737287, 50.90995134626116, 58.137860093797954, 50.93332856042044, 36.210901737213135, 34.03941944667271, 41.17213439941406, 55.41454839706421, 54.75896154131208, 51.377919469560894, 49.2652918951852, 47.5039895602635, 39.422393866947715, 37.70382642745972, 37.34263474600655, 33.96478884560721, 38.56806421279907, 37.28645856039864, 37.345955984933035, 40.18435764312744, 39.23121418271746, 37.907082080841064, 38.495083808898926, 41.28157894951956, 43.457115513937815, 43.829921109335764, 44.92984873907906, 44.95164523805891, 44.90620749337332, 46.35112360545567, 45.604650838034495, 48.499735900333945, 45.71226453781128, 48.91275419507708, 47.10304028647286, 48.81635141372681, 48.95657648359026, 47.92806938716343, 48.38422209875924, 47.168148381369456, 46.551301206861226, 48.596764019557405, 50.36104365757534, 50.49617222377232, 51.4840601512364, 53.774738788604736, 53.48391498838152, 49.581890038081575, 56.58095986502511, 51.96171406337193, 48.03004114968436, 50.434434005192344, 49.6412797655378, 46.30193035943167, 40.86761222566877, 40.81326341629028, 44.07096801485334, 55.0779116494315, 55.28811550140381, 58.47999286651611, 56.81142813818795, 59.143087250845774, 58.98916380746024, 52.89033733095442, 53.25390182222639, 51.40093190329415, 50.98479386738369, 45.18458706992013, 37.469032900674, 21.78181743621826, 1.7152342583451952, 0.10015875766319887, 0.07874533919883625, 0.7161611425025123, 57.05462203707014, 53.26135376521519, 61.190102985927034, 31.31790385927473, 19.388366256441387, 41.0451352255685, 42.916594300951274, 35.54109191894531, 35.78891331808907, 48.15953820092337, 47.0150100844247, 12.796087401253835, 0.3690308508064066, 0.03528306779584714, 0.11288177780807018, 0.0171890138049743, 0.05811839031853846, 0.06535520377968039, 0.046995223433311493, 0.04104544162484152, 0.061461695203823705, 0.015566511046407478, 0.009964145104666906, 0.048572986985423734, 0.0236831113163914, 0.13330462335475854, 0.1332168209233454, 39.489683696201865, 67.70481041499546, 51.81935242244175, 53.10757623400007, 66.6230662209647, 87.32664830344063, 46.054762090955464, 25.729565007346018, 44.285983494349885, 76.29698058537075, 52.89676788875035, 72.86973299298967, 26.45136993271964, 0.4112306535243988, 1.082089324082647, 0.048244311407740624, 0.30189586324351175, 1.966957505260195, 12.185288633619036, 26.9534432888031, 47.30208533150809, 54.04864372525896, 54.56625325339181, 55.3345433643886, 54.146043573107036, 50.554943561553955, 48.29821382250105, 46.675236225128174, 45.620822770254954, 43.34130641392299, 43.59707307815552, 41.39535570144653, 42.0127135685512, 48.764719349997385, 50.812353474753245, 52.65959807804653, 62.07348305838448, 51.269256591796875, 48.733942304338726, 57.41779742922102, 55.46614224570138, 54.96697671072823, 54.385238783700125, 50.856085436684744, 48.107902663094656, 46.90994984763009, 49.382629598890034, 50.961767537253245, 50.35686084202358, 53.58836030960083, 52.533366680145264, 48.03956018175398, 50.31805862699236, 52.5509421484811, 48.75798307146345, 48.46926804951259, 47.46576057161604, 51.13092490604946, 50.888450145721436, 46.27225112915039, 47.53877919060843, 45.13561964035034, 43.428336075374055, 47.17825453622, 46.555751528058735, 43.17681476048061, 43.863519123622346, 43.32952226911272, 42.24172966820853, 43.034651143210276, 40.367199489048545, 44.92595427376883, 45.99410431725638, 45.23311676297869, 52.780142375401084, 49.991218839372905, 51.31615693228585, 58.62704454149519, 51.43102107729231, 35.85160343987601, 33.92573996952602, 40.3673905645098, 57.16705778666905, 54.11208425249372, 52.37980454308646, 51.71428871154785, 47.90855189732143, 43.491578578948975, 39.51362371444702, 38.01152740206037, 34.53029925482613, 39.46624742235456, 39.80297449656895, 39.72152771268572, 42.87548180988857, 40.94427170072283, 41.22506925037929, 38.921105657305034, 42.783643995012554, 45.101184368133545, 46.59225736345564, 46.51191534314837, 48.34255722590855, 47.0379182951791, 47.93052557536534, 48.76474714279175, 50.810262066977366, 48.308396407536094, 49.96926253182547, 49.13673285075596, 50.96622828074864, 50.863999434879844, 50.767798151288716, 51.74439525604248, 49.85615628106253, 50.463856152125764, 51.303865568978445, 51.49733121054513, 52.87959541593279, 54.556595257350374, 54.47843149730137, 56.22466318947928, 50.28558274677822, 58.809830801827566, 55.519195216042654, 51.26770714351109, 53.87708922794887, 51.553952080862864, 49.50535215650286, 43.688129220690044, 41.8573066847665, 46.67608390535627, 58.66348089490618, 56.902296679360525, 62.83996663774763, 58.54280458177839, 62.71469061715262, 60.48409652709961, 65.93260288238525, 57.42547171456473, 55.25390257154192, 57.34100941249302, 51.792872837611604, 46.53840882437569, 24.043588093348912, 0.9289515699659074, 0.25461041341934887, 0.5443717635103634, 1.548353293112346, 62.37936360495431, 59.82246821267264, 66.60015106201172, 35.26566185270037, 22.019893986838206, 46.23792355401175, 55.65538338252476, 33.08420889718192, 42.515884740012034, 56.63789687837873, 58.27404826028006, 19.375409603118896, 0.36656253039836884, 0.06653046714408056, 0.05452705713521157, 0.08012601546943188, 0.04345174393217478, 0.06875811118100371, 0.14739405017878326, 0.09001098147460393, 0.16270787987325872, 0.13988103903830051, 0.08747372190867152, 0.09664915741554328, 0.1337570705051933, 0.3037301062473229, 0.1961084133280175, 46.78428472791399, 77.74802153451103, 59.828888348170686, 53.83600800377982, 64.11922032492501, 87.75710310254777, 48.23144163404192, 31.242307458605083, 52.6447046143668, 79.32251112801688, 57.062386648995535, 79.68961920057023, 26.740805830274308, 2.4147339463233948, 3.1355044586317877, 0.4648597815207073, 0.8336317305053983, 2.0928553896290913, 17.126018898827688, 37.50037622451782, 55.63361120223999, 58.530270031520296, 59.68278857639858, 57.41298580169678, 59.70527989523751, 53.58636270250593, 51.0674079486302, 49.351466928209575, 48.99415234157017, 43.57755558831351, 45.83585909434727, 42.995442458561485, 45.52620915004185, 51.91809327261788, 53.17039489746094, 54.92166403361729, 58.36754322052002, 54.30891282217843, 49.950787271772114, 59.58033043997628, 56.813047068459646, 56.84762825284685, 56.52622543062483, 51.89145735331944, 50.557635988507954, 49.453622817993164, 52.29551247188023, 53.49841935294015, 53.301396233694895, 54.643986225128174, 55.95503486905779, 50.4579883984157, 54.03337505885533, 56.410381589617046, 49.83269568852016, 49.69509356362479, 48.261697564806255, 56.23937599999564, 53.77452686854771, 49.121714319501606, 49.96706690107073, 48.79521151951381, 47.380193505968364, 49.40216793332781, 50.10316126687186, 47.77118601117815, 47.51333141326904, 48.45606647218977, 44.79436581475394, 47.50278057370867, 43.28469944000244, 46.941505091530935, 50.59846360342843, 49.38735089983259, 56.43726764406477, 51.689035483769004, 55.0357152393886, 61.25174740382603, 52.23670986720494, 36.60982213701521, 34.83196571895054, 39.42266137259347, 56.89034925188337, 57.799104145595, 54.398794719151084, 54.397311278751914, 50.77359642301287, 46.36239010947091, 42.95309318814959, 41.926948479243684, 38.43600327627999, 43.177693707602366, 43.155011313302175, 42.49831621987479, 46.40175860268729, 44.14911093030657, 43.470963273729595, 44.76721225466047, 48.003241947719026, 49.15190076828003, 51.6128693308149, 49.69005264554705, 51.29017414365496, 48.5465007509504, 51.46257979529244, 48.85768972124372, 53.74664374760219, 50.07328748703003, 54.69231789452689, 52.14314195087978, 55.896847179957796, 54.06385333197457, 51.13960320608956, 55.49487999507359, 53.95889384405953, 52.93301316670009, 52.94436999729702, 53.8500120980399, 53.80161442075457, 57.47404657091413, 57.962866238185335, 58.70417649405343, 52.666376045772004, 57.38251447677612, 56.35914209910801, 53.964025088718955, 57.567079475947786, 54.64990956442696, 51.533003262111116, 45.142157895224436, 46.330411025456016, 48.68411677224295, 62.49380043574742, 59.37034893035889, 64.94010829925537, 60.71089962550572, 64.77659634181431, 62.45398030962263, 58.84256376538958, 58.606547355651855, 58.85399355207171, 61.99679579053606, 57.37463174547468, 54.26861327035086, 32.20291675840105, 2.877658328839711, 0.3146647523556437, 0.36180950115833965, 1.4642636967556817, 69.23957020895821, 65.08889702388218, 72.52294840131486, 44.005470820835654, 34.188399246760774, 51.80352790015084, 61.81434999193464, 45.339240074157715, 50.7484404700143, 64.92465550558907, 72.4925639288766, 26.563062225069316, 0.5354130385177476, 0.1842273058635848, 0.2577698081731796, 0.18115499429404736, 0.15959617256053857, 0.15228726475366525], [0.0379824090216841, 0.06280529632100038, 0.037641960861427445, 0.08003201801329851, 0.1315144444150584, 0.10401726740279368, 0.16478421060102327, 0.16798909434250422, 0.2011171688458749, 28.771477665219987, 55.97273540496826, 40.84869922910418, 20.252128090177262, 20.578094141823904, 35.97058091844831, 34.095147473471506, 30.11201967511858, 23.088646786553518, 62.39283616202218, 55.798214026859824, 58.682984488351, 49.238103594098774, 1.0111255262579237, 0.2780710331031254, 0.2617221118084022, 0.21007661308561051, 0.678124912083149, 8.182569520814077, 17.245053700038365, 34.10013975415911, 49.14657844815935, 50.318225383758545, 53.85266978400094, 45.69634968893868, 47.395218985421316, 42.462640694209504, 45.6819634437561, 41.13603850773403, 43.46937908445086, 38.378468717847554, 43.89520638329642, 41.7496999331883, 47.664489473615376, 49.81290027073452, 56.89965983799526, 50.60184390204293, 42.660025119781494, 48.19414022990635, 55.61668191637312, 52.37672649111067, 53.04845053809029, 48.97480508259365, 48.62872920717512, 43.007827622549875, 43.67868661880493, 44.914159706660676, 48.940630367824006, 46.39735344478062, 49.06896359579903, 48.84938314982823, 50.020578452519004, 44.72170155388968, 46.68488032477242, 46.70793444769723, 51.32270908355713, 48.96302093778338, 49.630426679338726, 46.608575207846506, 48.60026938574654, 43.44311836787632, 42.84264809744698, 44.770172187260215, 45.412283011845176, 41.93476867675781, 40.557757309504915, 39.791617665972026, 41.38021905081612, 38.958966391427175, 42.08878592082432, 41.793202604566304, 46.27794170379639, 47.27861084256853, 49.731064387730186, 49.193544796534944, 48.37130192347935, 50.57601397378104, 59.317223003932405, 48.00061205455235, 36.77583197184971, 35.01488746915545, 39.95652273723057, 55.44960553305489, 55.953561850956504, 46.36790697915213, 46.63894925798689, 47.97909000941685, 44.41039446422032, 38.39332744053432, 41.97049283981323, 39.08216837474278, 39.810763427189414, 41.03947591781616, 39.144601413181846, 38.31550761631557, 35.699708870479036, 38.26277426310948, 41.76895339148385, 43.02066789354597, 43.51748146329607, 46.49610471725464, 46.24282203401838, 47.30411420549665, 44.846011774880544, 44.67009033475603, 47.97284357888358, 44.79815605708531, 44.417631013052805, 41.25682599203927, 44.0809907913208, 49.8431145123073, 48.57938657488142, 48.58638341086251, 48.82740947178432, 44.76891108921596, 45.07096317836216, 49.428696155548096, 47.519070625305176, 48.59072603498186, 52.36457756587437, 53.10242761884417, 54.320109844207764, 51.254189423152376, 56.20254012516567, 51.26374667031424, 52.28484351294381, 49.31426279885428, 51.45759098870413, 47.007130827222554, 42.541207449776785, 41.244270597185405, 41.87800189426967, 48.91141666684832, 55.04938929421561, 53.943607807159424, 57.35365513392857, 57.14858947481428, 55.79618167877197, 44.44442674091884, 55.116144112178254, 49.57594238008772, 51.59633261816842, 36.29506526674543, 15.584276165281024, 3.356593532221658, 0.17814457868891104, 0.05359712489215391, 0.4309598191508225, 6.114998408726283, 65.07370131356376, 54.729695728846956, 65.92530727386475, 32.79948908942086, 19.445529086249216, 31.91929476601737, 47.00477191380092, 31.36343887874058, 28.47099413190569, 41.74236958367484, 53.15117965425764, 21.571789026260376, 0.19177254741745337, 0.018119124163474356, 0.03593351146472352, 0.005968380029246743, 0.035172093393547196, 0.03198936042775001, 0.014644963799842765, 0.08525559771806002, 0.04959843321038144, 0.062172996678522656, 0.019967526496787156, 0.05113057546051485, 0.029027795951281275, 0.30339786836079186, 0.11449608047093664, 32.59474304744175, 69.32187856946672, 45.4403988974435, 29.960107735225133, 37.872017996651785, 44.09512690135411, 36.752621514456614, 42.927478654044016, 33.95415115356445, 66.27152906145368, 64.32387951442173, 64.00941794259208, 55.595799105507986, 1.4172066961015974, 0.03916174020352108, 0.14277603583676474, 0.6599365366356713, 0.39337020048073357, 9.55657752922603, 23.206352744783672, 44.774796213422505, 56.06317663192749, 53.241513184138704, 56.01584897722517, 48.25175469262259, 47.53130987712315, 44.29957069669451, 49.22202893665859, 43.51044641222273, 44.69213696888515, 40.251383440835134, 44.2676819392613, 43.69814852305821, 50.08216381072998, 52.88997255052839, 61.1985103062221, 54.11949798039028, 41.97288996832711, 49.60082387924194, 55.254128387996126, 53.87347616468157, 54.17744943073818, 51.500930377415244, 49.71157816478184, 45.79870012828282, 44.81423418862479, 45.71070466722761, 52.15308829716274, 50.238783155168804, 49.023873261043, 49.15549646105085, 52.24631922585623, 46.75640855516706, 48.82887554168701, 47.68106092725481, 52.310676915305, 51.451393195560996, 50.496477944510325, 49.06252956390381, 50.84414495740618, 45.88822766712734, 45.23230034964425, 45.91835158211844, 48.21145166669573, 43.66704143796648, 43.403006417410715, 43.30443927219936, 42.10851880482265, 41.26801259177071, 43.31063706534249, 41.995947565351216, 48.78688757760184, 48.79863698141915, 50.49546698161534, 50.94645718165806, 50.08979640688215, 50.64365121296474, 57.59300320489066, 48.79722302300589, 35.17706189836775, 33.69008486611502, 39.19346809387207, 56.23913628714425, 57.127310616629465, 46.31778267451695, 46.94573654447283, 49.43910108293806, 46.4266539982387, 41.23247603007725, 43.29516690117972, 39.32740156991141, 39.55880437578474, 43.103893416268484, 41.61814968926566, 39.7989410672869, 38.2617633002145, 43.0636876651219, 43.00912693568638, 46.76642438343593, 46.43513427461897, 48.34837634222848, 48.57335901260376, 50.18966981342861, 47.56160054888044, 47.55886990683419, 50.598369802747456, 47.70469869886126, 46.9569022996085, 45.616653851100374, 44.764248847961426, 53.577986649104524, 49.645413943699424, 49.03196096420288, 51.408884116581504, 49.17348882130214, 45.9437472479684, 51.25968892233712, 50.691169943128315, 50.503825664520264, 53.46027374267578, 56.779629707336426, 56.163432189396445, 49.70591538293021, 56.51702948978969, 55.2623724256243, 55.47037717274257, 54.50674193246024, 52.7543854032244, 51.02143519265311, 45.95072323935372, 44.67389794758388, 43.39975813456944, 52.804898806980674, 56.24397570746285, 57.807038988385884, 59.20865045275007, 60.41250923701695, 55.58205904279436, 54.7462671824864, 67.14577920096261, 49.4412202835083, 54.82238817214966, 42.460618768419536, 19.920334236962454, 2.504930032151086, 0.1532853219125952, 0.759204092834677, 0.6456179278237479, 6.291585138865879, 75.28938061850411, 56.279293400900706, 75.94255992344448, 37.85922983714512, 27.40947093282427, 40.21975176674979, 58.03542627607073, 32.08081259046282, 26.44497585296631, 54.250204018184114, 62.82242938450405, 32.73577758244106, 0.3484439083508083, 0.04144138716427343, 0.05309924303687044, 0.03224937504689608, 0.020596693003816263, 0.0338980353304318, 0.15273085023675645, 0.15106899583978312, 0.16874369313674314, 0.13572259646441254, 0.2761937981205327, 0.1622952220163175, 0.2512236822928701, 0.41139808882560047, 0.20944173501006194, 42.62319619315011, 77.29248373849052, 54.77888202667236, 31.333975042615617, 30.2613434110369, 52.04309136526925, 47.42194870540074, 43.05418600354876, 36.33358260563442, 73.61408655984062, 65.90435150691441, 70.13262217385429, 58.520709310259136, 1.8647538466112954, 1.4306721964052744, 1.0187544311795915, 1.6233300013201577, 1.3434455969503947, 11.166197214807783, 32.06798621586391, 54.109530789511545, 61.702206066676546, 58.94113785879952, 58.26309095110212, 52.33230665751866, 50.69121858051845, 46.525669302259175, 51.523835114070344, 46.73652975899832, 46.84088127953665, 42.65742301940918, 47.89723328181675, 47.34696027210781, 50.39725072043282, 55.129359585898264, 57.52808618545532, 54.453181743621826, 43.73268454415457, 49.44853326252529, 58.58159637451172, 56.78347206115723, 57.74161127635411, 53.03595767702375, 51.71075555256435, 46.73103025981358, 48.8484069279262, 47.34171438217163, 52.509847027914866, 51.478036063058035, 50.12524611609322, 52.64351299830845, 56.10894094194685, 49.85360629217965, 51.599177905491416, 53.527935300554546, 56.92769929340908, 53.27385704857962, 54.37809950964791, 51.19350038255964, 54.00218459538051, 50.6984030178615, 50.08339711597988, 49.498678411756245, 51.812581402914866, 47.32272495542254, 47.74490097590855, 46.1078393799918, 46.81261600766863, 45.00049802235195, 44.69600016730172, 44.82637963976179, 52.54945175988333, 51.85394402912685, 54.76995359148298, 53.128406933375764, 50.68730674471174, 53.4036146572658, 61.32307761056082, 50.7030166217259, 37.190007141658235, 34.60556909016201, 39.74726384026663, 57.17372110911778, 59.3585786819458, 50.060898848942344, 49.75888497488839, 50.99159267970494, 49.45994567871094, 42.03789036614554, 47.88933318001883, 42.17030913489205, 42.49395969935826, 46.95230259214129, 44.48137378692627, 44.63864973613194, 44.35601438794817, 46.586664063589915, 47.993174007960725, 48.997192178453716, 49.229769229888916, 50.85772521155221, 51.09881033216204, 52.93613985606602, 49.80409342902047, 49.60727528163365, 53.042982305799214, 51.12296574456351, 50.196406091962544, 49.40642717906407, 47.64496503557478, 56.036373955862864, 52.55490609577724, 53.39856679098946, 54.87591014589582, 52.247712339673726, 49.01625803538731, 52.79449387959072, 52.52403177533831, 52.400899274008616, 56.492207050323486, 58.17519276482718, 59.91501126970564, 52.27596371514456, 55.4838080406189, 56.586191858564106, 55.55329350062779, 55.811901978084016, 54.59827750069754, 53.121041842869346, 47.49570730754307, 48.51761014120919, 46.94486454554966, 54.47960574286324, 58.97048704964774, 60.07258251735142, 62.0491087777274, 62.8744227545602, 59.556609289986746, 50.968576771872385, 60.17010743277413, 54.456061771937776, 57.68769325528826, 54.54906341007778, 31.162451812199183, 5.027615751538958, 0.2800922260752746, 0.37722063277448925, 0.7988672330975533, 7.963551878929138, 79.19863864353725, 63.96718679155622, 79.25856685638428, 45.56756482805525, 32.83785704204014, 43.87312500817435, 65.94085734231132, 44.07666901179722, 44.84825256892613, 59.38123675755092, 72.75040463038853, 41.62724835532052, 0.34263255447149277, 0.1659725425498826, 0.17627358622848988, 0.08530422832284655, 0.08748575233455215, 0.10682313862655844], [0.017183590613837754, 0.06126207698668752, 0.04889463972566383, 0.11446600779891014, 0.06254273719553437, 0.05768533569893666, 0.038818666112742255, 0.13349649948733194, 0.19348421985549585, 21.991418531962804, 67.32147135053361, 42.441580704280305, 42.10988065174648, 26.908069814954484, 35.22047771726336, 49.32507072176252, 24.77470186778477, 9.181003945214407, 33.28782933098929, 62.48004995073591, 51.62460136413574, 66.1323219026838, 22.51166663851057, 0.374550461769104, 0.17038478436214582, 0.34366267919540405, 0.05933728348463774, 1.797289443867547, 11.291910103389196, 32.79299599783761, 48.792004925864084, 48.18283551079886, 55.27343395778111, 52.65784018380301, 54.156368596213206, 50.97570562362671, 46.955234731946675, 43.42153031485421, 42.77403811046055, 40.74110637392317, 41.42510093961443, 46.026496819087434, 52.29134007862636, 50.84163318361555, 54.05851016725813, 43.339628423963276, 44.165126528058735, 47.15709032331194, 56.54034764426095, 53.97801528658186, 55.297175952366416, 50.739633628300254, 52.16830832617623, 43.57837894984654, 42.60402611323765, 45.82937642506191, 49.07333748681204, 48.24707855497088, 47.42423118863787, 46.413118907383506, 49.165078026907786, 46.87305491311209, 45.5806691305978, 44.4247841835022, 44.931453772953574, 45.128737449645996, 48.982399463653564, 48.334003993443076, 50.43738351549421, 45.353602000645225, 43.58098799841744, 46.13536466870989, 44.98702546528408, 45.67848587036133, 43.413140365055625, 41.218871457236155, 39.19410037994385, 41.42654963902065, 40.49576548167637, 40.80660356794085, 41.442158767155235, 44.99274730682373, 47.712105478559224, 51.04383965900966, 47.086475781032014, 42.573151792798726, 55.81946856634957, 51.26563310623169, 36.88403626850673, 38.19556781223842, 41.94454479217529, 55.25336061205183, 52.74533190046038, 42.06991113935198, 44.597047397068565, 47.917139870779856, 46.008414132254465, 43.816028186253135, 39.61836780820574, 42.77417360033308, 42.628306593213765, 42.01152890069144, 41.81714609691075, 34.74525220053536, 36.29756661823818, 41.59651647295271, 41.71859632219587, 43.90379088265555, 47.25896481105259, 48.05313001360212, 47.78904635565621, 48.827472005571636, 46.76152242933001, 47.346296719142366, 41.49793890544346, 42.3844804082598, 41.599667481013704, 43.804247515542166, 44.54289313725063, 48.07272393362862, 46.5716107913426, 49.094751834869385, 48.761279991694856, 45.86403056553432, 41.207681383405415, 48.05067035130092, 48.608555112566265, 48.95017719268799, 54.328155858176096, 54.350629806518555, 52.17178242547171, 52.67077772957938, 52.7789820262364, 47.54417446681431, 52.804103238242014, 52.99858331680298, 52.99629388536726, 48.380112239292686, 44.26100124631609, 41.30333375930786, 41.25076021466936, 42.64376286097935, 54.42257840292794, 51.657619203839985, 55.816369669778005, 57.54940325873238, 59.370654651096885, 35.754804611206055, 41.68405335290091, 58.448454993111746, 34.191880294254844, 11.832142097609383, 3.658694693020412, 0.022446360804938843, 0.18451214129371302, 0.8804706771458898, 1.4003345157418932, 14.906701735087804, 67.9155353818621, 54.40561785016741, 65.0072556904384, 25.253906965255737, 14.52620187827519, 24.96768982069833, 47.30336380004883, 48.037201268332346, 52.42637137004307, 40.38156836373465, 50.24763516017369, 38.152099881853374, 0.254500680736133, 0.060532278647380214, 0.032873247284442186, 0.08087557274848223, 0.03344185963006956, 0.030646485343043293, 0.011030389095789619, 0.05724514289093869, 0.06860485726169177, 0.09064315898077828, 0.08519300964793988, 0.04908434793885265, 0.07892590415264879, 0.08292386640927621, 0.1916194563465459, 29.24352264404297, 77.88167708260673, 48.583687509809224, 38.61453029087612, 29.675596373421804, 45.8728790964399, 54.37262780325753, 29.325931753431046, 17.460182087762014, 37.33363682883126, 68.39930370875767, 54.696726526532856, 69.99165712084088, 25.600125278745377, 0.4502841436437198, 0.14417870342731476, 0.4067610890737602, 0.12015014993292944, 1.3950548619031906, 14.503840838159833, 44.63805219105312, 54.559999874659944, 52.39890514101301, 59.01139804295131, 55.493306228092735, 57.190320355551584, 51.5171092578343, 49.0602262360709, 45.02149895259312, 45.273871421813965, 42.272041184561594, 43.47369391577584, 46.918860912323, 55.097606318337576, 53.084966795785085, 58.68033027648926, 45.402096952710835, 44.067591190338135, 49.66252735682896, 59.74816417694092, 53.62606470925467, 55.43434034075056, 52.35401977811541, 51.660645144326345, 45.88776561192104, 45.484648500170024, 47.80653149741036, 50.30598265784127, 51.51905822753906, 48.15661300931658, 48.44545309884207, 51.329660756247385, 46.65244613374983, 47.731237343379426, 46.24605989456177, 47.50800561904907, 47.02273300715855, 52.472045353480745, 50.31051983152117, 51.538902282714844, 47.07923575810024, 47.57877996989659, 48.321003913879395, 48.74065773827689, 48.44187477656773, 48.28122895104544, 41.7146497453962, 40.52412802832467, 44.341371059417725, 43.487413133893696, 42.34737007958548, 43.56554215294974, 48.26578310557774, 48.47632047108242, 52.77137722287859, 47.69180979047503, 43.58026191166469, 58.439498765128, 50.57735497610909, 36.193347113473074, 38.393414293016704, 41.07501942770821, 55.06106226784842, 53.38821397508894, 43.5214558328901, 45.526229994637625, 47.89332144601004, 48.18521179471697, 45.71043021338326, 42.648671763283865, 44.068157468523296, 43.43523563657488, 44.12245069231306, 45.06368841443743, 38.25584690911429, 38.636048861912315, 41.86205577850342, 46.5410977772304, 45.04445232663836, 49.95322608947754, 48.54191146578108, 49.44061926433018, 51.26493828637259, 48.08061361312866, 50.189562116350444, 45.53465815952846, 43.89071784700666, 43.333486216408865, 46.05031871795654, 47.341846397944856, 50.28763941356114, 49.028327056339805, 49.753489698682515, 50.90252372196743, 47.461289405822754, 44.98403426579067, 50.026060581207275, 53.34403385434832, 51.31718526567732, 56.25741352353777, 55.56367063522339, 57.18287188666207, 53.51037720271519, 52.42623240607125, 52.75695276260376, 51.18821975163051, 54.004029342106406, 54.87987061909267, 53.39329310825893, 46.507513659340994, 44.34103059768677, 44.31070518493652, 46.75527947289603, 56.93612398420061, 55.23528487341744, 57.83135768345424, 60.21295002528599, 62.175003187997, 39.819983686719624, 50.52876622336251, 62.6675192969186, 39.69282817840576, 20.33131844656808, 2.8432141542434692, 0.07650624827614852, 0.19086111203900405, 3.267931478364127, 0.8012229981166976, 18.12872733388628, 73.29800605773926, 58.68897383553641, 71.46020058223179, 29.329999923706055, 29.551866327013286, 26.722669294902257, 55.505767822265625, 52.90386547361101, 50.62662812641689, 46.07092707497733, 58.22686651774815, 50.0069009235927, 0.4298533999494144, 0.04767226567491889, 0.044939133405153237, 0.06844505547944989, 0.03270319623074361, 0.024620821267100315, 0.07057447478707347, 0.16071145342929022, 0.1344209491674389, 0.26317648376737324, 0.13360653072595596, 0.1555106725011553, 0.17619414334850653, 0.36257548577019144, 0.3642110808619431, 35.82817758832659, 89.3059468950544, 55.39254692622593, 56.944975989205496, 35.79262365613665, 51.18340812410627, 69.37433746882847, 30.42548418045044, 18.56300711631775, 47.364535740443635, 71.70408930097307, 61.71836062840053, 74.71103341238839, 28.604034764426096, 1.246740460395813, 1.2364887190716607, 1.5258638198886598, 0.22801287206155912, 2.7386481080736433, 22.13788308416094, 53.730110509055, 58.93696893964495, 54.90747581209455, 61.330088342939106, 58.64506122044155, 59.256606919424875, 54.763637678963796, 52.94241407939366, 49.26095969336373, 46.63434260232108, 44.48236043112618, 46.38094179970877, 51.001264572143555, 56.349112374441965, 54.99745498384748, 56.04626819065639, 43.93291425704956, 45.27392700740269, 49.694989340645925, 61.734765325273784, 55.42063849312918, 59.82455267224993, 54.00595051901681, 56.51836354391915, 46.95507492337908, 47.86501448495047, 49.79063824244908, 52.65461621965681, 52.50594908850533, 50.48272051130022, 49.89966937473842, 55.99265589032854, 50.76103407996041, 49.19413539341518, 49.58240073067801, 49.91861711229597, 48.70727859224592, 54.14411892209734, 53.32410989488874, 56.264302662440706, 50.47273942402431, 52.64334971564156, 50.46488101141793, 51.89822489874703, 51.14094768251692, 50.431588717869346, 45.91624627794538, 44.566093172345845, 48.54187672478812, 45.20101261138916, 46.3754631451198, 48.19223294939314, 49.98792886734009, 51.208414690835134, 54.127689906529014, 50.39629186902727, 46.48907661437988, 61.1330999646868, 53.78242349624634, 37.92875698634556, 39.06403357642037, 41.48785359518868, 56.14055871963501, 54.2441451890128, 45.3040509223938, 48.928015913282124, 52.704347951071604, 49.2657470021929, 50.194443225860596, 44.47385583605085, 47.90768684659685, 47.45597055980137, 48.80849647521973, 48.62890291213989, 43.27816118512835, 44.891564164842876, 46.75536632537842, 48.35037047522408, 49.38044786453247, 54.53216191700527, 51.343560627528596, 51.960657937186106, 53.36566012246268, 50.066947255815776, 53.172382082257954, 46.68466145651681, 46.505953788757324, 45.180015155247276, 49.24608360018049, 50.9371292250497, 53.114045006888254, 50.873278754098074, 51.37359421593802, 54.956783703395296, 52.05510480063302, 47.64253316606794, 51.85306855610439, 54.66262476784842, 52.628053256443565, 60.19823374067034, 57.57358298982893, 60.76135744367327, 54.440223353249685, 54.597117151532856, 55.232759203229634, 55.7175350189209, 57.569771902901785, 59.29350880214146, 56.6745798928397, 49.93633501870291, 47.82943623406546, 45.946012360709055, 48.58005012784685, 60.87772587367466, 57.14916270119803, 60.84308215550014, 63.351326261247905, 63.53992121560233, 42.86909988948277, 43.734977449689595, 66.78192288534981, 51.20091758455549, 29.642700127192906, 4.711450134004865, 0.31584689606513294, 0.25921880613480297, 3.5963773855141232, 2.595154127904347, 19.72368632044111, 79.9338275364467, 65.32321112496513, 74.77617972237724, 38.28308037349156, 27.363793475287302, 35.85579320362636, 68.0947572163173, 65.53039251055036, 71.64418193272182, 57.15083374295916, 69.22588920593262, 62.102957316807334, 0.7443928675992149, 0.13120310540710176, 0.22134212643972465, 0.15425663122109004, 0.12020462272422654, 0.19919553053166184], [0.0793615100639207, 0.0390244759619236, 0.007991150171229882, 0.06734914678548064, 0.027641859337953583, 0.08863785729876586, 0.08420745110405342, 0.09187115130147763, 0.14342276113373892, 23.411817925316946, 70.56411225455147, 43.582422801426475, 43.86069120679583, 42.69956036976406, 24.78629493713379, 42.91391577039446, 47.40467548370361, 6.7631350585392545, 15.83726007597787, 45.32661172321865, 57.8373817716326, 50.867946011679514, 55.6531252179827, 0.8450857273169926, 0.25331441153373035, 0.13594565806644304, 0.009750320060577775, 0.12174928055277892, 3.141989516360419, 21.936661515917095, 54.55272511073521, 57.563984053475515, 54.292351790836875, 56.05565173285348, 55.79460096359253, 55.01851497377668, 50.940929889678955, 42.68060915810721, 41.18563822337559, 42.646743638174875, 42.438718046460835, 49.91863448279244, 50.898035185677664, 55.752758911677766, 52.17145586013794, 37.6487306867327, 44.93940946034023, 50.635146617889404, 54.1678261756897, 53.751497064317974, 50.72164821624756, 50.01488440377371, 51.378503118242534, 45.74881206239973, 39.62501376015799, 44.80511815207345, 46.06427764892578, 46.78894002096993, 47.7444041797093, 47.27262496948242, 50.13296903882708, 48.3578919001988, 44.27893107278006, 43.56319713592529, 43.07422113418579, 41.627314363207134, 46.23352187020438, 46.63783059801374, 48.67994785308838, 47.58591576984951, 39.90363999775478, 43.49991641725813, 47.27395902361189, 46.142622062138145, 43.5358281816755, 42.178348200661794, 44.49224076952253, 43.769509996686665, 41.7438564981733, 45.06838539668492, 43.53049891335623, 45.916729177747456, 50.74603986740112, 52.358115741184776, 47.507946559361045, 43.099564688546316, 52.7857460975647, 53.04588317871094, 38.90571887152535, 43.278786523001536, 41.14210775920323, 54.67054224014282, 46.50449119295393, 39.45344884055001, 45.862988335745676, 52.78918545586722, 48.246133599962505, 43.08909027917044, 42.961281640189036, 43.604000432150706, 40.21254301071167, 39.56341450554984, 42.39584766115461, 42.05323893683297, 43.929728507995605, 43.762176173073904, 46.32854543413435, 46.33208554131644, 46.34670107705252, 48.667013781411306, 48.081232002803254, 47.19026102338518, 45.59519781385149, 40.21896662030901, 40.519281659807476, 39.549462522779194, 40.548290388924734, 44.30024814605713, 45.97559779030936, 44.88595002038138, 46.830045563834055, 47.16146074022566, 47.05548334121704, 42.521724700927734, 41.638712882995605, 46.224138328007285, 47.24801445007324, 49.30681085586548, 51.99233130046299, 52.44173036302839, 51.388272285461426, 56.23818090983799, 45.5779767036438, 51.52566943849836, 57.30002893720354, 51.83257484436035, 55.068878991263254, 52.28274515696934, 48.28813893454415, 40.972728048052105, 42.85959127971104, 41.245917320251465, 46.431444781167166, 52.31926488876343, 54.11516925266811, 54.552686895642964, 58.876116616385325, 52.550157002040315, 27.083218267985753, 40.11276340484619, 32.305013588496614, 7.224459835461207, 0.4347919949463436, 0.027564445277675986, 0.4919663869908878, 2.9448838872568945, 0.6342561574918884, 34.138056073869976, 64.74919959477016, 56.25966126578194, 51.775582245418, 9.725529926163809, 14.591560976845876, 31.410203729357036, 48.73599897112165, 35.20592124121529, 53.311617033822195, 63.756906509399414, 42.33747584479195, 37.59887736184256, 0.3850247082965714, 0.07960432382034403, 0.005511760312531675, 0.034465372030224116, 0.012708969380972641, 0.07148701617760317, 0.05867586111915963, 0.01887604863648968, 0.03281868289091757, 0.08109096690480198, 0.0363956888073257, 0.11250035291803734, 0.07199281653655426, 0.13908614883465426, 0.16875839020524705, 26.47120703969683, 79.50366456168038, 49.683309418814524, 46.33104331152779, 38.59251492364066, 28.268966572625295, 62.55465970720564, 40.22141586031233, 3.5025838698659624, 21.160622426441737, 48.31805787767683, 65.86154365539551, 54.38159792763846, 62.975227219717844, 1.1659514755010605, 0.07829538905727011, 0.1891970591885703, 0.06776205570037876, 0.073384376508849, 2.886328160762787, 30.73069769995553, 58.48616286686489, 58.641239711216514, 59.28677599770682, 57.478507314409526, 59.69370419638497, 55.77766820362636, 54.35929421016148, 45.11632101876395, 44.20850413186209, 43.289306095668245, 44.41746078218733, 52.99427195957729, 52.204730783190044, 55.8461948122297, 56.65885264532906, 40.1246691431318, 45.642817292894634, 51.7635931287493, 55.54515716007778, 55.30362735475813, 53.69724900381905, 51.06349958692278, 52.33915410723005, 45.90007781982422, 42.915395736694336, 46.513113907405305, 49.280188832964214, 49.19700847353254, 49.38028458186558, 48.28412287575858, 52.51537779399327, 49.42687572751726, 47.48495497022356, 44.17625754220145, 44.51670190266201, 42.93658774239676, 48.77862616947719, 48.504530157361714, 52.35801499230521, 50.12123353140694, 43.96046733856201, 45.10202857426235, 49.20022896357945, 47.91830021994454, 47.92481763022286, 45.382965087890625, 44.60908167702811, 46.93687411717006, 43.950677326747346, 45.2722281728472, 45.01573889596121, 47.76742008754185, 52.8121839932033, 53.15817649023873, 48.01570701599121, 43.06830474308559, 52.2396559034075, 52.13803849901472, 36.96665729795183, 41.36089263643537, 41.05154146466936, 56.75186470576695, 48.64492545809065, 40.87490783418928, 46.34572485515049, 52.246743065970286, 49.69824457168579, 44.463482175554546, 45.930834020887104, 44.68785687855312, 42.00689097813198, 43.36383594785418, 43.98240974971226, 43.90239429473877, 46.223780495779856, 45.674358640398296, 48.271216596875874, 47.61285393578665, 47.912043367113384, 48.55192034585135, 50.522933210645405, 48.93742377417428, 46.68102060045515, 43.13465656552996, 40.91686800548008, 42.14193269184658, 43.69058888299124, 46.99895279748099, 48.51709597451346, 48.315490518297466, 48.63447536740984, 49.366388184683665, 48.69508450371878, 45.39663914271763, 44.54362964630127, 48.14894219807216, 50.28885882241385, 52.232909202575684, 53.07848412649972, 54.338991573878694, 54.47842802320208, 53.6205860546657, 43.02738332748413, 55.86169971738543, 60.61500753675188, 54.31440189906529, 57.46572610310146, 56.11392280033657, 52.10933896473476, 43.81524651391165, 43.89913558959961, 44.444951329912456, 47.44029194968087, 54.59893757956368, 56.87082133974348, 59.61379991258894, 60.445631299700054, 56.3661458832877, 29.645649637494767, 46.505206857408794, 39.69029208592006, 10.711020725114004, 0.9414446481636592, 0.045831671583333185, 1.5449644178152084, 4.99887843642916, 0.19936003456158297, 41.27784776687622, 68.08565507616315, 65.12279033660889, 50.53735419682094, 16.394470861979894, 13.635764173098973, 21.57493829727173, 58.33820097787039, 38.5386073248727, 48.31306559698922, 63.83826296670096, 52.54359095437186, 46.019142150878906, 0.7829188374536378, 0.020412083981292586, 0.032942634275449176, 0.05927198127444301, 0.019662240021196858, 0.08315323160162993, 0.24379255675843783, 0.13903192031596387, 0.1429643157337393, 0.16962656219090733, 0.11353637411126069, 0.20387938991189003, 0.17775447533598968, 0.23679208382964134, 0.2560373997049672, 30.971914836338588, 93.58103452410016, 57.80228989464896, 58.89896924155099, 54.424225125994, 36.3390508379255, 57.94659355708531, 54.52632543018886, 12.116635220391409, 30.54389190673828, 56.58851950509207, 69.18469333648682, 59.713756697518484, 66.08802018846784, 1.205392490540232, 0.824121275118419, 0.37509353405662943, 0.16748970613947936, 0.15840306372514792, 4.363338436399188, 40.01206316266741, 63.7727484021868, 63.902651923043386, 62.91757106781006, 61.16544382912772, 62.84100191933768, 58.25477395738874, 56.18717418398176, 46.19102668762207, 46.02693108149937, 46.78199529647827, 47.08854634421212, 55.44055550439017, 55.01135832922799, 59.18660381862095, 50.75580556052071, 38.728112493242534, 45.52436440331595, 54.14636319024222, 57.64267587661743, 57.72105850492205, 56.35423667090279, 54.79111780439104, 56.697588852473665, 49.09892422812325, 46.23655823298863, 48.01476900918143, 51.15954801014492, 50.356916427612305, 52.78458227430071, 51.56359270640782, 52.888562066214426, 54.04743126460484, 49.70850011280605, 47.71183449881417, 47.98407186780657, 46.27628803253174, 51.25881344931466, 49.79700626645769, 54.46982615334647, 51.78057452610561, 47.83773238318307, 50.392331395830425, 53.07937349591936, 51.249085971287315, 51.078476428985596, 49.21670661653791, 50.08340059007917, 51.46156188419887, 47.62797669001988, 50.72245420728411, 49.247553144182476, 50.265384333474294, 56.36355767931257, 55.24091291427612, 50.60404995509556, 46.850282192230225, 54.882385866982595, 55.045081411089214, 39.68259000778198, 44.06047970908028, 40.794346945626394, 57.24200800486973, 50.51006862095424, 44.60273797171456, 49.30628974097115, 55.46629163197109, 51.057148933410645, 48.218024662562776, 50.3998840876988, 48.50505127225603, 45.5511531829834, 46.842847619737896, 49.01415620531355, 47.265412739345, 49.94323110580444, 48.39138221740723, 51.700666768210276, 50.30891827174595, 51.19118315832955, 52.0624976839338, 52.58676011221749, 52.20454665592739, 49.84748840332031, 45.157061781202046, 43.55618987764631, 45.0122196333749, 45.77092470441546, 48.596541677202495, 51.64035293034145, 51.04694550377982, 51.9761871610369, 52.36277103424072, 53.88508660452706, 48.87737396785191, 47.17700386047363, 51.248359884534565, 51.96757139478411, 55.73733738490513, 55.75928674425398, 58.568721362522666, 56.08132880074637, 56.66663810185024, 51.57510587147304, 57.69755622318813, 59.99385247911726, 58.06824609211513, 59.692106110709055, 59.67072650364467, 54.49344655445644, 47.083279609680176, 48.07791076387678, 48.86348104476929, 50.070299761635916, 57.5256404195513, 58.5321877343314, 63.03508595057896, 61.838147572108674, 61.45524624415806, 31.535900115966797, 47.83811453410557, 45.44397027151925, 16.421426398413523, 1.5058113187551498, 0.09323003302727427, 0.8890448627727372, 8.25565675326756, 2.0399700445788245, 42.78564855030605, 74.89673096793038, 66.45607321602958, 65.35498523712158, 21.85302778652736, 21.934620482581003, 44.046770913260325, 67.81774643489292, 48.019115107400076, 63.11232907431466, 77.35719926016671, 60.26216411590576, 62.202698707580566, 1.159801885485649, 0.29023447898881777, 0.1630991231650114, 0.20030603451388224, 0.14606562788997376, 0.16731330060533114], [0.08231800927647523, 0.05275476437860301, 0.07463633468640701, 0.06833045770015035, 0.0430963476454573, 0.024882617040670345, 0.037077158489929776, 0.08755298836955003, 0.10392813504274402, 9.312684467860631, 72.39444146837506, 44.264228684561594, 47.52490711212158, 27.910151175090245, 38.89565787996565, 22.433073827198573, 43.404198033469065, 10.769273553575788, 14.01590359210968, 39.62918962751116, 61.56514590127127, 48.81513547897339, 64.15000779288155, 10.675874999591283, 1.474173890692847, 0.43526952075106756, 0.03493956622800656, 0.09996798754270587, 0.12597065046429634, 4.5644397139549255, 55.25608083180019, 52.547784192221506, 57.77956928525652, 56.51599768229893, 58.752848625183105, 58.12880311693464, 53.770225933619905, 42.70520578111921, 41.50578342165266, 42.57568441118513, 46.682834080287385, 54.860707487378804, 52.96108388900757, 48.162018707820344, 44.54816681998116, 43.291835239955354, 44.78124066761562, 50.2038163457598, 52.77135637828282, 52.85946995871407, 51.77168083190918, 49.99831642423357, 49.94179630279541, 44.750845772879465, 39.88469920839582, 40.86777203423636, 45.67667933872768, 47.62570810317993, 49.91389581135341, 44.906263078962056, 45.68898459843227, 47.93393019267491, 47.80216108049665, 41.73771776471819, 41.45224755150931, 42.05378784452166, 42.34132514681135, 44.99516180583409, 45.758730615888325, 47.60546105248587, 41.05294500078474, 44.399537903921946, 49.88764551707676, 46.0917021887643, 48.581655161721365, 47.508307865687776, 47.066155774252756, 45.15605081830706, 47.247750418526785, 45.67546687807356, 48.82187870570591, 47.935952118464876, 48.140368121010916, 48.837394033159526, 49.56402621950422, 45.516686643872944, 53.37509230204991, 54.94898087637765, 37.62708009992327, 39.78232445035662, 41.2769375528608, 56.20705992834908, 47.07909332002912, 42.749448435647146, 50.622660705021445, 51.87278406960623, 48.21455751146589, 46.665943009512766, 43.33329514094761, 41.97798299789429, 41.99206352233887, 41.859189646584646, 43.062589849744526, 45.7351519039699, 43.47298172542027, 43.89413636071341, 43.222832679748535, 48.22459071023123, 46.5244186265128, 48.21160452706473, 50.87934800556728, 44.52220140184675, 40.534501688820974, 38.252692426954, 39.934830461229595, 41.05210426875523, 43.36534023284912, 46.52320963995797, 48.86648614065987, 46.85679612840925, 47.05349268232073, 46.884078230176655, 45.478405543736045, 44.449926240103586, 43.545955181121826, 46.310361998421804, 48.54521186011178, 45.93980761936733, 52.00471299035208, 51.708879538944785, 54.03050545283726, 49.50399030957903, 38.39071839196341, 43.65241200583321, 43.76199551991054, 57.024098600660054, 52.5020546231951, 53.147462368011475, 49.98368351800101, 46.068064417157856, 41.453908170972554, 40.91309513364519, 40.624515601566856, 45.89971651349749, 52.875534193856375, 53.84076057161604, 56.66345930099487, 59.183511870247976, 55.92380966459002, 45.78446674346924, 48.68002775737217, 4.461561211517878, 0.6276459779058183, 0.07629147837204592, 0.3535101222140448, 2.158683708735875, 1.7588122742516654, 54.744290419987266, 60.27617168426514, 53.60807582310268, 32.6109219278608, 8.849742497716631, 28.127310173852102, 30.641805921282085, 34.4175751549857, 39.682968684605186, 24.65677877834865, 42.96186181477138, 45.82529435838972, 28.5043055330004, 0.536676362156868, 0.03675582466114845, 0.06955707259476185, 0.061738021804818084, 0.03548052487894893, 0.03853005802791033, 0.026649744449449436, 0.07154034224471875, 0.06852396910211869, 0.03674217253657324, 0.11659953902874674, 0.0927018274420074, 0.03597251705027052, 0.0987647617501872, 0.07684107816645078, 10.386653627668109, 80.92928205217633, 50.761718477521626, 53.88491289956229, 31.40251554761614, 47.569302627018516, 21.716792719704763, 45.78163535254342, 8.687471662248884, 18.682097503117152, 43.79678167615618, 67.24825818198067, 53.25379065104893, 69.96524701799665, 12.812579819134303, 0.8118070587515831, 0.24830875013555798, 0.1255808320960828, 0.04612617274480207, 0.19468030067426817, 8.208421162196569, 61.34613173348563, 55.90535872323172, 59.62800203050886, 59.448655128479004, 60.17188617161342, 60.95089735303606, 56.195254938943044, 44.17423561641148, 42.508443219321116, 45.16322830745152, 49.68677656991141, 56.07804230281285, 55.71214321681431, 50.817446504320415, 46.20710481916155, 45.51275396347046, 46.1362054007394, 52.52406651633126, 55.18433720724923, 55.54838112422398, 52.937387057713096, 52.48776912689209, 50.05861289160592, 46.77852119718279, 41.60399620873587, 44.96269287381853, 49.24972445624215, 49.39670664923531, 51.815409319741384, 47.00253111975533, 46.966786112104145, 47.32914856501988, 49.34119054249355, 45.87275055476597, 43.75286211286272, 42.63918399810791, 43.39526959827968, 48.698756626674104, 47.8072749546596, 50.89206320898873, 45.72101926803589, 47.85227843693325, 50.64822660173689, 49.40541621616909, 51.363515853881836, 51.192909785679404, 50.15481417519705, 48.082930837358745, 48.284379959106445, 48.106502601078574, 50.06263242449079, 48.53249665669033, 50.46543339320591, 50.762670380728586, 51.22653559276036, 46.49404110227312, 55.559974193573, 51.82758951187134, 37.84520489828927, 38.699291365487234, 40.43291555132185, 54.5474305834089, 47.786392143794465, 43.86654853820801, 52.32861021586827, 52.39679636274065, 50.69647489275251, 48.66434219905308, 46.07364729472569, 44.24956451143537, 43.418956007276265, 43.21900422232491, 45.08012785230364, 48.57728474480765, 46.53712340763637, 45.33378573826381, 45.913772719247, 50.12993615014212, 49.77319131578718, 49.67004183360508, 50.3374718938555, 45.51638439723423, 42.357896600450786, 40.15663085665022, 41.19240229470389, 42.346129826136995, 46.26780775615147, 49.55600105013166, 54.01857886995588, 50.44465480531965, 49.79126010622297, 48.92566394805908, 47.81298984800066, 45.73084054674421, 45.125947747911724, 48.729432923453196, 51.0388126373291, 47.08983523505074, 54.21066182000296, 52.31220204489571, 57.21769278390067, 48.0788939339774, 39.06424897057669, 42.356506960732595, 40.71147230693272, 59.2575101852417, 56.82317754200527, 55.61290904453823, 52.3187507220677, 50.26800727844238, 43.379716055733816, 43.07352978842599, 44.467897755759104, 49.79167004993984, 55.9488787651062, 56.83662578037807, 58.80197933741978, 59.89111641475132, 61.39998027256557, 48.30930314745222, 52.55198090417044, 7.0235544102532526, 0.711179175547191, 0.0548954337968358, 2.8303586840629578, 1.765041551419667, 2.2373709721224646, 62.39000824519566, 67.04596138000488, 58.769218581063406, 38.08734267098563, 11.12826873574938, 16.49265238216945, 26.77494580405099, 41.452991008758545, 44.51187637874058, 24.07025875364031, 50.58793708256313, 52.71248081752232, 38.67288473674229, 0.7353958189487457, 0.04212644290445106, 0.03663467223356877, 0.0443938965909183, 0.03471847577020526, 0.07084244183663811, 0.19151686185172626, 0.21114488504827023, 0.1221793767596994, 0.13489310097481522, 0.1939496813075883, 0.21209264919161797, 0.09102540489818368, 0.3485145574169499, 0.19452662606324467, 13.88309485571725, 94.21750341142926, 58.81340912410191, 65.06625284467424, 35.831801073891775, 56.02416597093855, 34.56455387387957, 51.93224327904837, 16.607752765927994, 24.755583899361746, 50.35842418670654, 73.73492268153599, 57.77288511821202, 75.03540311540876, 14.254552500588552, 2.071583262511662, 0.8219152763485909, 0.14717047289013863, 0.2617404865367072, 0.4067180428121771, 11.219481212752205, 64.25247982570103, 56.34460299355643, 61.789364269801546, 62.09008925301688, 63.80161816733224, 62.85294587271554, 59.734726360866, 46.10840218407767, 44.02924060821533, 46.747782366616384, 51.40637581689017, 59.038711411612375, 56.89821113858904, 49.69225869859968, 43.933011531829834, 45.27835995810372, 46.010470799037385, 54.42136594227382, 56.75671454838344, 57.89575706209455, 55.81499392645699, 54.38524920599801, 52.33149719238281, 47.98831026894705, 42.401218618665425, 46.770506450108115, 50.34099810464041, 51.04124450683594, 54.95466102872576, 50.84216819490705, 48.16462428229195, 50.78759356907436, 51.086664881025044, 47.04663828441075, 46.43329300199236, 46.15300267083304, 47.987188134874614, 50.92527559825352, 50.91910907200405, 54.19012989316668, 47.684434277670725, 50.515925952366416, 56.46331296648298, 54.28890201023647, 54.757780347551616, 55.01613521575928, 52.07228422164917, 53.14379719325474, 52.87084763390677, 52.79508447647095, 53.5949958392552, 51.88118096760341, 51.965483461107524, 53.4691743850708, 52.5264949117388, 50.65577234540667, 58.141532216753276, 54.35377386638096, 37.99558128629412, 41.06610141481672, 42.61304834910801, 57.473146779196604, 52.2680219241551, 47.692716530391145, 55.62325143814087, 55.0787558555603, 53.19093377249581, 52.80026435852051, 48.81201573780605, 49.38644068581717, 48.403583254132954, 46.36321347100394, 48.26092978886196, 50.78597811290196, 49.76703521183559, 48.995889391217915, 48.36394378117153, 52.446055616651265, 52.418478216443745, 52.83126722063337, 54.06453078133719, 48.63898127419608, 44.8986930165972, 43.073196274893625, 44.68911450249808, 45.463459968566895, 49.33126156670706, 52.5944378716605, 55.60227482659476, 51.63409260341099, 52.46641036442348, 53.028370244162424, 51.051600796835764, 48.75178180422102, 47.47567565100533, 51.25987304959978, 53.12542268208095, 50.701765945979524, 57.16877746582031, 57.57511159351894, 57.85330704280308, 54.435568060193745, 47.52586248942784, 45.675859451293945, 49.17348534720284, 62.74110071999686, 58.94285406385149, 58.86389473506382, 55.460403033665244, 52.318114961896626, 47.16947201320103, 44.937905175345286, 46.17293357849121, 51.85848815100533, 58.76096412113735, 59.90463760920933, 62.76211902073452, 62.95411164419991, 61.65553501674107, 48.93368911743164, 55.42301477704729, 11.33164598260607, 0.8556342869997025, 0.15460066204624517, 2.5566908546856473, 7.9289324794496805, 2.317741219486509, 65.97121402195522, 70.11743341173444, 63.603608403887065, 45.9108510017395, 17.909628050667898, 37.24258416039603, 42.803505420684814, 46.74810545785086, 55.15812165396554, 34.028670583452495, 60.821980476379395, 62.10354791368757, 54.86465059007917, 1.0972898112876075, 0.13455521767692907, 0.16589309966989926, 0.12608525502894605, 0.12313864885696343, 0.17490124915327343], [0.0649088905858142, 0.04629122978076339, 0.01715346535534731, 0.06167635654232331, 0.018921047382588898, 0.01626441823983831, 0.051444370765239, 0.017384096015510813, 0.09364887912358556, 4.011537679604121, 64.79910850524902, 47.070029394967214, 39.71235956464495, 25.20871935571943, 30.477359431130544, 62.93373952593122, 47.684357847486226, 3.5819453256470815, 29.798061847686768, 52.652563026973176, 57.11531802586147, 50.21547542299543, 54.27307053974697, 37.828063692365376, 0.022522558591195514, 0.15905257101569856, 0.05816579277494124, 0.0836714491514223, 0.21236083337238856, 0.5418053269386292, 28.14358285495213, 50.76975754329136, 55.53543315614973, 58.64792387826102, 60.05482986995152, 57.007780756269185, 52.26922048841204, 42.38544620786394, 43.08457742418562, 43.099477836063926, 51.267488275255474, 51.21681158883231, 52.05006388255528, 47.38532475062779, 47.60506500516619, 44.506571429116384, 43.66800028937203, 52.04955666405814, 51.6229442187718, 52.29187856401716, 51.10264573778425, 50.375085966927664, 48.9407172203064, 45.19334527424404, 40.761718205043245, 41.02674681799752, 43.4621981212071, 47.0157014301845, 49.10177298954555, 46.9792685508728, 48.2878749029977, 44.274484225681846, 46.029977866581504, 48.52623632975987, 44.53611864362444, 38.80003677095686, 42.33878558022635, 42.761923926217214, 42.00657830919538, 43.57964699608939, 45.001265798296245, 49.36527647290911, 48.18652153015137, 46.59223999295916, 45.50226565769741, 48.34883144923619, 48.1348477772304, 44.5425318309239, 44.81529726300921, 48.669112137385774, 50.53083331244332, 47.41658469608852, 52.49089234215872, 51.62712356022426, 53.809716020311626, 52.03454508100237, 55.58214242117745, 55.346980639866416, 40.05589587347848, 35.5019805090768, 42.84635843549456, 55.98743084498814, 53.83851282937186, 51.36486380440848, 54.15417296545846, 49.54376874651228, 46.805862358638215, 48.12174347468785, 48.148230007716585, 43.8039140020098, 45.50866494859968, 47.14882891518729, 46.89792251586914, 45.46309518814087, 48.39244876589094, 45.97819294248308, 46.82762064252581, 46.64082179750715, 48.40966987609863, 47.94477980477469, 44.90496029172625, 41.2530392238072, 39.50732864652361, 37.09804425920759, 40.62369918823242, 41.969481876918245, 46.794012205941335, 44.898390769958496, 49.13281406675066, 46.318602561950684, 45.35069070543562, 45.39444351196289, 43.179253578186035, 42.49006175994873, 43.1272428376334, 46.27380405153547, 51.35087708064488, 44.29981388364519, 51.02489539555141, 47.897629329136436, 58.018965993608745, 40.58365671975272, 34.938078607831685, 27.164065769740514, 15.70294097491673, 40.71329968316214, 52.48744603565761, 53.00830732073103, 50.75199099949428, 52.280167375292095, 45.31876720700945, 39.06204291752407, 42.15012114388602, 41.38021905081612, 47.562218938555034, 53.27293988636562, 57.20549522127424, 56.181542669023784, 59.68719373430525, 67.22088227953229, 33.43100391115461, 2.0384618512221744, 0.49077498806374414, 0.09203998438481774, 3.294069732938494, 1.496758684515953, 9.4630252463477, 67.84173161642892, 52.057606152125764, 57.75410761151995, 34.84651524680001, 21.34217711857387, 21.190640381404332, 18.886873074940272, 33.36570474079677, 40.56782177516392, 18.30556419917515, 35.57317522593907, 44.12751245498657, 26.67894775526864, 0.6646961069532803, 0.035664960875042846, 0.026152386762467877, 0.13453764361994608, 0.1464489187513079, 0.01955926215409168, 0.08449047484568187, 0.0032574386111394104, 0.030900522068675076, 0.07255728981856789, 0.050823813171258996, 0.03259247288640056, 0.05501930036449006, 0.019138663741094724, 0.06024795890386615, 4.60367054598672, 73.00518117632184, 54.378241947719026, 46.38936301640102, 24.426428624561854, 36.792083808353965, 69.49087960379464, 46.09597533089774, 5.857987582683563, 33.299109731401714, 58.9924989427839, 62.021725927080425, 55.998541014535085, 60.68859590802874, 43.079421860831125, 0.12349091709724494, 0.508310829954488, 0.10169281677475997, 0.12956565112939902, 0.2276380764586585, 0.7877230825168746, 33.38022300175258, 53.417222704206196, 56.03023522240775, 62.055459431239534, 60.646052088056294, 58.64089924948556, 53.39153173991612, 44.85593032836914, 45.11031430108206, 44.927382128579275, 53.588930061885286, 54.04770919254848, 54.138803550175254, 51.01907627923148, 47.1047043800354, 43.85354151044573, 45.2184282711574, 52.88412911551339, 54.25440420423235, 54.231923307691304, 52.371605668749126, 51.78839472361973, 50.083351952689036, 47.13261876787458, 42.51507180077689, 42.47702693939209, 45.85295513698033, 48.940526144845144, 50.43782820020403, 48.50741713387625, 49.907114369528635, 45.843505586896626, 48.84618697847639, 51.2815375328064, 46.66862154006958, 41.194413798195974, 45.25079992839268, 45.41839395250593, 46.14894839695522, 46.98406628199986, 48.02064371109009, 49.5101637840271, 51.210113525390625, 49.029966831207275, 49.99923358644758, 51.579017707279746, 50.09795706612723, 47.36219767161778, 47.595799582345144, 50.470366614205496, 54.05606440135411, 49.4131669316973, 53.58506686346871, 51.877116271427695, 53.521073954445974, 51.787206581660676, 57.3161244392395, 54.581070286887034, 39.332887172698975, 35.19324425288609, 40.399084772382466, 58.76386846814837, 54.24097333635603, 51.265845026288716, 56.611702169690815, 52.00109297888619, 50.15856967653547, 49.26746320724487, 50.944199017116, 46.54067393711635, 47.788191727229524, 48.638064111982075, 49.20231342315674, 48.03013495036534, 49.98052208764212, 46.57444565636771, 48.30520371028355, 47.65742315564837, 50.99005017961775, 48.71408435276577, 46.76966919217791, 42.50881494794573, 42.81620325360979, 38.426602363586426, 42.79930176053728, 44.27432789121355, 50.537434101104736, 46.879231861659456, 49.14612334115164, 48.45883532932827, 46.40449619293213, 46.6801312310355, 45.27190855571202, 43.630678040640696, 45.539428097861155, 47.85945245197841, 51.45357492991856, 45.852986403873985, 53.02380527768816, 51.03041921343122, 58.6069781439645, 43.687170369284495, 36.29617697851998, 32.78363677433559, 25.902278116771154, 41.905176298958914, 54.25998708180019, 55.956445353371755, 54.437555244990754, 53.39553042820522, 48.275555746895925, 40.64833402633667, 44.809936727796284, 45.79907533100673, 50.08894525255476, 55.1702948978969, 61.23596109662737, 58.74674115862165, 60.38438292912075, 70.24250793457031, 38.448169572012766, 3.4101619720458984, 0.4519723930529186, 0.06519631801971368, 2.917940075908388, 1.6091050846236092, 14.183008636747088, 72.91518115997314, 57.94717720576695, 62.39088371821812, 40.152305603027344, 24.84004099028451, 23.53333670752389, 22.435439688818796, 45.25556639262608, 46.592590876988, 19.970774684633525, 45.244577816554475, 51.697286469595774, 39.02714559010097, 0.7192389773471015, 0.027489870886451433, 0.049962938829724274, 0.055950939123119624, 0.06265447834240538, 0.05930029654077121, 0.11375479453376361, 0.11143729888967105, 0.11159919734512057, 0.19499704082097324, 0.1724954353911536, 0.09679023163127047, 0.12886893137225083, 0.14155680340315613, 0.22773138859442302, 6.130951472691127, 87.24568094526018, 62.311806270054404, 57.29338298525129, 31.645594801221574, 44.36223997388567, 75.7538537979126, 56.230447564806255, 8.802534699440002, 40.476887226104736, 61.721716608319966, 68.45484066009521, 61.288350514003206, 67.26431546892438, 45.963959557669504, 0.16924888959952764, 0.3474382108875683, 0.12583849898406438, 0.42178982549480026, 0.4613124004432133, 1.3291645518371036, 37.11118677684239, 55.08272327695574, 57.85243851797921, 65.27362877982003, 64.50777053833008, 62.12722042628697, 54.77948999404907, 46.59564808436802, 47.40872628348214, 46.2302006312779, 55.45771060671125, 56.784302370888845, 54.858289514269146, 51.57877452032906, 46.555133138384136, 42.401055335998535, 47.00488655907767, 54.28559119360787, 57.78529460089547, 57.3122056552342, 55.06463016782488, 54.653616428375244, 51.60250261851719, 48.04131807599749, 45.06265313284737, 44.823923451559885, 49.781633377075195, 51.73211778913225, 54.805226121629985, 50.43847785677229, 54.375024931771414, 46.90664597920009, 51.03307342529297, 51.43779904501778, 49.731297152382986, 43.08844757080078, 47.15230996268136, 48.759171213422505, 49.876775060381206, 49.238214765276226, 52.21502801350185, 52.74889980043684, 55.2851243019104, 53.877467904772075, 54.034455503736226, 53.93265049798148, 55.46085466657366, 52.86853040967669, 50.17167397907802, 55.47454956599644, 56.985556943076, 50.5906468800136, 55.83737754821777, 55.497690541403635, 58.05700043269566, 54.10834959575108, 60.559915270124165, 57.1219778742109, 40.90815149034773, 34.944290297372, 41.55900314876011, 61.745055607386995, 57.26282480784825, 54.90423100335257, 61.296994073050364, 56.49847085135323, 51.85504879270281, 51.616972242082866, 55.83012362888881, 48.38315555027553, 49.63538769313267, 51.98691170556204, 51.87590728487287, 51.25001702989851, 54.371071406773154, 49.25510583605085, 49.4619710786002, 50.15032911300659, 54.004515716007774, 52.74164588110787, 49.881412982940674, 45.23982524871826, 45.21639244897025, 41.95751707894461, 46.2365790775844, 48.039945806775776, 53.11996834618704, 50.040363448006765, 53.58378144672939, 52.24635396684919, 49.25144413539341, 51.88029507228306, 47.32518809182303, 47.63490056991577, 48.73873656136649, 49.690556389944895, 55.99973610469273, 47.91734831673758, 56.993245124816895, 54.55858939034598, 60.63934012821743, 50.65422984531948, 45.22462259020124, 31.968640872410365, 23.465572663715907, 45.65787056514195, 57.384043080466135, 59.00511687142508, 56.056971890585764, 57.75462872641427, 50.648396832602366, 42.83696099690029, 47.48241192953927, 48.76184974397932, 53.759876591818674, 58.693121910095215, 62.99868433816092, 61.23322350638253, 63.524607385907856, 71.37000601632255, 43.870522907802034, 5.201919564179011, 1.3217323677880424, 0.18908702794994625, 5.803950139454432, 7.238676284040723, 13.167991467884608, 80.50094645363944, 61.30825015476772, 67.99426542009626, 46.12843036651611, 29.6178776877267, 31.627727508544922, 27.784095219203405, 47.85204914637974, 57.45963600703648, 26.184927361352102, 54.265597752162385, 61.291317394801546, 55.64151477813721, 1.29981720660414, 0.09678132925182581, 0.07843505870550871, 0.21860640895153793, 0.1903782800904342, 0.13181917449193342], [0.044446863034473996, 0.043542158723409684, 0.0337341725161033, 0.07087871631873505, 0.07732170487621001, 0.06805143052978174, 0.04533040044563157, 0.04981627348544342, 0.02164593036286533, 0.9866926201752254, 55.40500157220023, 47.29884052276611, 41.62764092854091, 26.850333758762904, 36.7318047114781, 36.03669997623989, 65.36970846993583, 3.852513824190412, 17.58191626412528, 62.99193068913051, 50.83182232720511, 57.24216781343733, 44.85500274385725, 54.72627721514021, 2.464910145316805, 0.4289579779974052, 0.1229492968746594, 0.09095472869064126, 0.20968367345631123, 0.5160971550004823, 8.967372025762286, 58.35393169948033, 58.45452077048165, 59.124000549316406, 58.422163009643555, 56.60603938783918, 46.645866189684185, 43.10531432288033, 46.39777728489467, 48.87749208722796, 52.231554303850444, 55.13542536326817, 53.24324328558785, 50.28242826461792, 44.352158137730186, 46.089558669498985, 44.14054380144392, 52.59859984261649, 51.82211780548096, 51.46499082020351, 52.69657639094761, 52.84005321775164, 50.10338013512747, 45.97121000289917, 40.24146836144583, 39.157594544546946, 41.19652605056763, 43.3787294115339, 46.53927387510027, 46.300648416791645, 46.97269902910505, 49.024529865809846, 46.43342849186489, 47.927152224949424, 51.68226446424212, 45.33577292306082, 40.67868375778198, 41.12831558500017, 41.752538272312705, 42.796456473214285, 43.792241028376985, 43.60298252105713, 46.47504472732544, 45.834028244018555, 45.23031663894653, 45.736124651772634, 46.82926736559187, 43.63424594061715, 45.66960607256208, 47.280191557747976, 46.50660344532558, 48.11174849101475, 51.646557671683176, 51.870095116751536, 53.287753445761545, 55.297339235033306, 56.03100299835205, 56.73540094920567, 41.08579955782209, 39.0507173538208, 44.75372232709612, 57.332411016736714, 53.7993597303118, 55.408885615212576, 55.112791606358115, 53.27159888403756, 50.80881684167044, 53.047047001974924, 49.07570334843227, 47.83838898794991, 46.622138091496055, 44.166832310812815, 43.111345359257285, 48.596034458705354, 47.10275888442993, 48.32938344138009, 46.11992924554007, 45.99320452553885, 45.700014863695415, 43.97007669721331, 39.61732905251639, 40.975104331970215, 42.215093748910085, 43.9454105922154, 45.65992375782558, 45.3733800479344, 46.47065346581595, 43.138933181762695, 41.56295319965908, 39.9096918787275, 44.675228527614046, 41.7159594808306, 40.73121561322893, 40.94704403196062, 44.39727973937988, 42.135668890816824, 49.80815117699759, 47.96679517201015, 50.53056580679757, 47.970964091164724, 52.57620579855782, 39.88010992322649, 34.95998280388968, 47.89546843937465, 48.45636177062988, 35.21496779578072, 46.446254866463796, 52.18975394112723, 53.63654954092843, 52.07941654750279, 50.41316556930542, 45.384733404432026, 40.74762725830078, 41.565496240343364, 45.222694465092246, 45.52073744365147, 57.85608284814017, 57.69888680321829, 58.295420919145855, 59.1628201348441, 30.758577346801758, 0.330672451960189, 0.07194521051964589, 0.21347557141312531, 4.1128363353865485, 0.3804761623697621, 35.5835280418396, 64.88222980499268, 55.768691131046836, 58.482410839625764, 48.52651078360421, 38.403475284576416, 22.10465853554862, 17.851169381822857, 25.062266962868826, 40.61189767292568, 29.88046748297555, 44.93846450533186, 48.5090708051409, 30.17946583884103, 0.6795068436435291, 0.0874302006725754, 0.040562192377235205, 0.0021547589858528227, 0.09479849386428084, 0.01588143271926258, 0.08203134180179664, 0.05475757922977209, 0.0027557448733464946, 0.06343656459024974, 0.03009953522788627, 0.09672706680638449, 0.1261767079787595, 0.03348476679197379, 0.051652348533804925, 1.2909294835158756, 64.05531774248395, 56.70072249003819, 41.858904770442415, 25.8363709790366, 38.1588465826852, 57.15735115323748, 67.31280694689069, 4.669664970466068, 22.775218759264263, 67.7383702141898, 57.701985699789866, 62.383720125470845, 48.93680191040039, 60.367880957467214, 3.166438707283565, 0.8265783861279488, 0.05684228986501694, 0.06410917599818536, 0.674229578248092, 0.5018796750477382, 10.824489150728498, 59.25880255017962, 59.654168946402415, 62.111913544791086, 59.57152707236153, 59.70704473767962, 48.13834272112165, 44.082383905138286, 47.403664520808626, 52.97532769611904, 53.23111867904663, 57.38665212903704, 56.36650371551514, 52.524605001722065, 43.33357654299055, 45.244671617235454, 44.874825954437256, 54.6720951625279, 54.40050050190517, 53.34791094916207, 55.10609354291643, 53.20228712899344, 51.69315229143415, 47.86501448495047, 41.42711591720581, 43.381282874516074, 45.49314962114607, 44.845626149858745, 47.11103418895176, 47.60956743785313, 46.70294911520821, 50.95868253707886, 50.901328631809776, 49.784669739859446, 51.756471225193565, 47.01840080533709, 42.80959551674979, 42.53696557453701, 44.340488638196675, 43.48673915863037, 45.59178972244263, 45.61729308537075, 46.67325251443045, 50.20093284334455, 50.31656476429531, 48.92704316547939, 50.09880822045462, 47.427093846457346, 47.6859906741551, 49.659171376909526, 51.05367136001587, 49.92442233221871, 53.89589105333601, 52.7379355430603, 53.75524909155709, 56.892906188964844, 57.62806381498064, 56.56447526386806, 40.47903421946934, 36.764523778642925, 43.5443570954459, 56.314631938934326, 54.70242057527815, 57.540255955287385, 56.567942414964946, 55.52796731676374, 51.558840138571604, 51.5121864591326, 52.205109460013254, 49.14193705150059, 48.73942790712629, 47.320237500326975, 47.432572501046316, 48.71337216241019, 49.79052012307303, 50.33905955723354, 49.56977585383824, 45.89513765062605, 46.169386523110525, 46.550168650490896, 43.87174579075405, 43.81312383924212, 43.35944468634469, 45.341612883976524, 48.64359835215977, 48.00899853025164, 49.42380462374006, 44.5986385345459, 44.11033303397042, 42.67469276700701, 47.60620103563581, 43.27964115142822, 42.933850152151926, 43.21823297228132, 46.00774710518973, 44.348781313214985, 52.011602129255024, 50.67262520108904, 54.15727186203003, 52.342034135546, 55.31472362790789, 43.17414665222168, 39.66198512486049, 50.530975750514436, 56.966765539986746, 42.38086387089321, 44.60620512281145, 54.149712221963064, 57.18901062011719, 55.44118084226336, 53.944827216012136, 47.89894948686872, 42.325174059186665, 44.59729405811855, 47.363361494881765, 49.258632046835764, 60.499855041503906, 59.079483440944124, 61.93788201468331, 61.003397941589355, 32.147953033447266, 0.6796000472136906, 0.20337213070264884, 0.014069150501329983, 1.3934642672538757, 0.8981751757008689, 39.07124580655779, 70.38928168160575, 59.32005786895752, 64.97065952845982, 59.23498412540981, 45.74556725365775, 26.955552067075455, 22.20349666050502, 36.836830207279746, 50.09384373256138, 33.318894726889475, 50.60701336179461, 57.8097175189427, 41.89131464276995, 0.715514308639935, 0.16369365554835114, 0.015439865877851844, 0.013678729085118642, 0.07476287468203477, 0.04423822369426489, 0.1502636426261493, 0.10046534014067479, 0.11205368688596146, 0.17880159057676792, 0.11285876190023762, 0.14537505566009454, 0.1583735067397356, 0.16652230519269193, 0.09857304168066808, 2.1718983139310564, 79.13509041922433, 63.358427320207866, 57.0259815624782, 33.92441981179373, 52.780142375401084, 47.021006379808696, 70.54177379608154, 10.51526825768607, 29.13246090071542, 75.06853212629045, 62.58552360534668, 67.31286253247941, 55.467392921447754, 64.97709356035504, 3.4732424957411627, 1.1494233395372118, 0.1432291343808174, 0.17123725504747458, 1.312869940485273, 1.0284331632511956, 12.90360643182482, 61.59389754704067, 61.34426266806466, 63.939095224652974, 62.82960687364851, 63.06419890267508, 51.31520502907889, 47.00424037660871, 50.32747343608311, 54.494273390088765, 54.862319469451904, 60.35345649719238, 57.80573967524937, 53.904840333121165, 47.53640638078962, 48.151266370500835, 44.417485100882395, 59.632594789777485, 55.54188455854143, 55.75507961000715, 56.78793280465262, 58.04610913140433, 52.93816178185599, 50.466232436043875, 44.638500349862234, 45.57968596049717, 45.81972885131836, 47.106990337371826, 49.894843850817, 49.16790246963501, 50.20457369940621, 52.57266916547503, 50.14873450142996, 53.309619426727295, 55.542357036045615, 50.4586797441755, 45.71187891278948, 45.75619452340262, 49.13895280020577, 47.256050041743684, 49.09173631668091, 49.582251344408306, 51.337873526981895, 53.711631774902344, 54.137441703251426, 54.295544488089426, 55.344131878444124, 51.186128343854634, 52.337820053100586, 53.69397292818342, 55.53621135439192, 53.248461382729666, 57.83356373650687, 56.16983495439802, 54.47183765683855, 60.18533788408552, 61.29912717001778, 60.75032370431082, 40.57178224836077, 37.92928157533918, 45.03917516980852, 58.5500237601144, 57.24421753202166, 58.81439576830183, 60.5199214390346, 58.576670101710725, 56.042575223105295, 56.634075369153706, 55.53032275608608, 53.4269015448434, 52.87192113058907, 51.32635341371809, 49.25140592030117, 54.1095655305045, 53.28120824268886, 53.17947966711861, 51.077215330941335, 48.29984664916992, 47.89467634473528, 49.35193593161446, 45.75631264277867, 46.382814339229036, 47.130416188921245, 49.13782719203404, 52.082852431706016, 50.166580949510845, 51.76453460965838, 47.81707886287144, 47.10822711672102, 44.58820581436157, 50.3003511428833, 46.43821580069405, 44.679463454655235, 48.53876045772007, 49.71627862112862, 46.19076265607561, 55.18624448776245, 52.935931410108296, 57.40175403867449, 56.306631088256836, 56.87785986491612, 46.24259621756417, 40.51200689588274, 51.75772884913853, 47.26458590371268, 37.39144236700875, 48.018625259399414, 54.400048868996755, 61.26285062517439, 55.942861625126426, 55.41235624040876, 49.078871726989746, 45.29815190179007, 47.06480434962681, 49.256224496024, 49.20353978020804, 63.32033034733364, 61.295159748622346, 64.83952617645264, 63.3189754486084, 38.0310275214059, 1.7079691567591258, 0.7983792849949428, 0.46151205258710043, 8.811182601111275, 1.5863712302276065, 43.77536732809884, 75.81464358738491, 63.80269513811384, 69.78563608442033, 60.37314074380057, 49.779514176504954, 34.3328766141619, 25.05166401181902, 36.075113092150005, 59.51466996329171, 40.45860651561192, 60.97520215170724, 67.33072635105678, 56.146641867501394, 1.1103009645427977, 0.3520916040454592, 0.24637459963560104, 0.051753521497760496, 0.17337668953197344, 0.09221300402922289], [0.011352478642947972, 0.10057064199021884, 0.046501962401505025, 0.029575601020561795, 0.021023321896791458, 0.038935889822563956, 0.05358520642455135, 0.09624088289482252, 0.046549368250582895, 0.19712058401533536, 46.161677496773855, 51.505502292088096, 32.08446734292166, 25.988374982561382, 49.01913806370327, 23.808931793485367, 16.633534056799753, 11.593707714762006, 21.977065290723527, 60.64899812425886, 51.58322484152657, 56.322288853781565, 48.22818292890276, 57.639146191733225, 7.386947802134922, 0.08828871710492031, 0.10850640080337014, 0.07650786997484309, 0.17202711052128247, 0.1592383946159056, 3.9964088456971303, 57.989502157483784, 58.956055641174316, 55.45629317419869, 56.38089690889631, 49.23796115602766, 41.72346006120954, 46.727434567042756, 52.06607253210885, 54.23469911302839, 56.57972655977522, 52.54397657939366, 50.576371806008474, 50.66290814535958, 48.75619738442557, 49.65952573503767, 39.640883445739746, 48.63336712973458, 52.201249735695974, 50.58719709941319, 53.159388950892854, 52.00560930797032, 50.35605485098702, 45.79039355686733, 38.76936742237636, 40.354519026620046, 42.19739668709891, 42.96727793557303, 45.446652276175364, 44.54393536703927, 45.43404476983206, 47.43393087387085, 46.51146371023995, 48.685561997549875, 47.73427718026297, 50.43159566606794, 47.70880855832781, 42.85981362206595, 42.48804678235735, 42.9794477054051, 40.79667806625366, 41.124949182782856, 42.88677263259888, 40.047405174800325, 41.47275168555123, 44.57324286869594, 45.097797121320454, 41.823027747017996, 44.203456265585764, 45.01492943082537, 43.57036072867257, 45.91675002234322, 48.09206077030727, 51.03998688289097, 52.995734555380686, 53.92499358313424, 54.427223273685996, 56.93288612365723, 40.79742847170149, 34.31361968176705, 46.30883339473179, 58.67102663857596, 58.8245609828404, 56.67552832194737, 53.38607392992292, 52.572186265672954, 50.24933399472918, 47.022712162562776, 45.69914633887154, 47.06892810549055, 45.7814164842878, 45.10602378845215, 44.14433056967599, 46.683820724487305, 46.614199774605886, 46.13206774847848, 44.31597886766706, 44.08433287484305, 46.10516084943499, 43.15263155528477, 39.99176400048392, 37.972631386348176, 42.135446548461914, 45.549940722329275, 46.60285684040615, 44.90669386727469, 46.92905739375523, 45.56843682697841, 43.89985472815377, 41.28042207445417, 41.45252200535366, 41.05797897066389, 39.10070616858346, 40.20835324696132, 41.56893212454659, 45.53234788349697, 49.66177347728184, 48.81336716243199, 51.299981525966096, 48.35038437162127, 51.66094739096505, 47.61932618277413, 49.90288986478533, 43.28186804907662, 45.89582552228655, 52.14075524466378, 42.71076781409127, 49.70228842326573, 51.09983171735491, 53.740557125636506, 53.115580558776855, 53.42623451777867, 47.002593653542654, 40.050465856279644, 43.794051034109934, 45.255708830697195, 52.56472042628697, 54.01321833474295, 57.538060324532644, 62.369073322841096, 17.078698192323955, 0.12065639133964266, 0.06037568633577653, 0.16370745695063046, 1.42561151938779, 1.7094601967505045, 50.698885917663574, 54.91532032830374, 60.09057140350342, 54.25184031895229, 55.92055443355015, 45.551552704402376, 17.191420555114746, 21.90855257851737, 28.494499887738908, 33.89106151035854, 22.48659232684544, 48.13744292940412, 47.996811389923096, 35.191225801195415, 0.27837881658758434, 0.015004690836316772, 0.018565796980900422, 0.009104319947904773, 0.049950877869767804, 0.023631344183481166, 0.014665854196729404, 0.07768368295260838, 0.07758855234299387, 0.01962584170645901, 0.028691069555601904, 0.02316844929009676, 0.17066366225481033, 0.08532411618424313, 0.047583038319966624, 0.31834271071212633, 52.466514587402344, 62.105000087193076, 34.35391575949532, 27.6544348852975, 55.46044472285679, 25.21405209813799, 17.978813001087733, 12.657707946641104, 28.49820327758789, 65.8099671772548, 57.052603585379465, 60.970922061375205, 52.317437512534006, 65.83705125536237, 8.108485221862793, 1.101923174091748, 0.5697263372795922, 0.10183318531406776, 0.16639499845249311, 0.3633095792361668, 4.672471174171992, 61.27810886928013, 60.246266637529644, 57.50862775530134, 58.96222564152309, 52.496648924691335, 43.82892404283796, 48.938382625579834, 54.672484261649, 55.34497261047363, 57.441230228969026, 56.00495072773525, 53.01425845282418, 54.51565299715315, 46.362945965358186, 42.98986305509295, 42.71516949789864, 51.51852321624756, 54.730088302067344, 51.9465183530535, 53.69203438077654, 53.60766935348511, 52.64045579092843, 46.6404743875776, 40.17980309895107, 40.504704339163645, 45.56547689437866, 45.36887066704886, 47.31669739314488, 46.154354095458984, 47.261368887765066, 49.40197338376726, 52.006258964538574, 52.32116869517735, 50.582590443747385, 52.631416184561594, 48.03261545726231, 42.80488811220442, 43.44957671846662, 44.03123474121094, 44.10215847832816, 44.187197480882915, 44.301266057150706, 43.40318359647478, 46.64457035064697, 47.46596206937517, 46.95933764321463, 44.71889795575823, 48.42376777103969, 47.72892011914934, 48.88770246505737, 48.810963085719514, 51.982805320194785, 52.207972117832725, 53.67463261740548, 55.0351003238133, 55.61602531160627, 57.20209755216326, 41.494391850062776, 34.68633147648403, 46.947209562574116, 59.49038600921631, 58.44456400190081, 58.661695207868306, 56.40881824493408, 55.683349881853374, 51.89618212836129, 49.72028425761631, 50.63955177579607, 49.34750645501273, 50.08104862485613, 47.46997465406145, 47.51588487625122, 48.74659149987357, 50.28524228504726, 47.57414552143642, 45.017899785723, 47.608313288007466, 46.01711675098964, 44.17469072341919, 41.398888860430034, 39.510573455265586, 44.374489648001536, 48.14409235545567, 49.91914864948818, 48.36970036370413, 47.63327121734619, 47.1274527822222, 45.75717421940395, 43.58253744670323, 44.120182105473106, 43.1925767489842, 41.36153187070574, 41.705050809042795, 43.25785160064697, 49.04543004717146, 51.47082730701992, 52.489898749760215, 53.995309352874756, 53.49762725830078, 55.75141096115112, 50.951466832842144, 50.73344625745501, 43.617789132254465, 45.28281375340053, 56.978254386356895, 44.07152039664132, 51.45052119663784, 53.76941646848406, 55.56043277468, 56.167753968920024, 57.31014551435198, 49.88914285387312, 42.20892027446202, 46.68714196341378, 47.83977862766811, 53.96295506613595, 55.81923927579607, 60.60694762638637, 66.74239458356584, 18.728933572769165, 0.5183978229761124, 0.12803851307502814, 0.26292314593281063, 0.9160818776914051, 2.1389308486666, 57.35753917694092, 55.81610216413225, 65.99839537484306, 63.56543500082833, 62.03526101793562, 50.38746418271746, 21.20370646885463, 22.098681347710745, 32.67411231994629, 40.621788433619905, 23.56170620237078, 52.906946999686106, 56.68904604230608, 44.4558356830052, 0.19190167263150215, 0.01614198847008603, 0.03542751772329211, 0.04046398461131113, 0.0649682352585452, 0.027891324433897222, 0.1615455900984151, 0.20872176864317485, 0.23627780856830732, 0.1470310610852071, 0.09446280901985508, 0.09989901445806026, 0.33413954877427643, 0.21589292027056217, 0.14203274143593653, 0.4964810875909669, 65.38768345969063, 69.85108116694859, 48.26147869655064, 37.79573025022234, 67.6792688369751, 35.8863513810294, 21.87737774848938, 20.77957453046526, 31.354718889508927, 72.79122529711042, 61.556891441345215, 66.03451905931745, 56.80650186538696, 70.08454063960484, 8.831889969961983, 3.354234618800027, 0.22662955628974096, 0.10844623510326658, 0.5776634056653295, 0.6082687005400658, 5.6602557471820285, 62.256283215114046, 61.09719167436872, 60.76590851375035, 60.49913937704903, 55.49128777640206, 46.99401262828282, 52.72826712472098, 54.39973272596087, 59.22833469935826, 60.33940029144287, 56.16735444750105, 56.13662256513323, 54.82456643240792, 53.69526876722063, 47.08020503180367, 42.28371415819441, 55.513032163892476, 57.097124167851035, 54.02661446162632, 54.70442165647234, 56.592799595424104, 54.85254682813372, 50.23144585745675, 42.271561758858816, 43.32999127251761, 46.098751136234824, 48.81470469066075, 49.72802802494594, 48.66822624206543, 51.143372603825156, 52.00989634650094, 52.7262556212289, 56.21498087474278, 51.50401190349034, 55.33503321238926, 50.79740789958409, 47.32685218538557, 45.03120558602469, 47.32770333971296, 46.66227783475603, 47.82542712347848, 49.35302332469395, 48.464432103293284, 51.755057266780305, 52.32424327305385, 52.47133316312517, 49.71948521477835, 53.755339418138774, 51.75286511012486, 53.06743996483939, 54.792285101754324, 56.72586107254028, 56.5083372933524, 58.34221008845738, 58.06044326509748, 60.16896792820522, 60.83976091657366, 43.00339814594814, 34.5901267187936, 48.44322272709438, 63.415881974356516, 62.00559220995222, 64.90239347730363, 58.18089028767177, 59.52602331978934, 54.15877962112427, 53.81305810383388, 53.38496221814837, 54.05934395108904, 53.863189356667654, 50.499274594443186, 54.078461919512065, 51.692749295915874, 53.11075850895473, 50.17954976218087, 48.27776179994856, 50.16345773424421, 50.101806368146626, 46.6586890901838, 45.08553007670811, 41.08289868491036, 47.74383790152413, 52.013787337711875, 53.346226011003765, 53.7939019203186, 50.786909171513145, 49.86629022870745, 47.90771116529192, 42.16400364467076, 45.87931660243443, 46.066226618630544, 43.57184416907174, 45.34427056993757, 45.72602891921997, 50.65965986251831, 53.59951911653791, 55.72512592588152, 55.99155807495117, 57.625107356480186, 59.59160041809082, 50.37975863048008, 52.11114549636841, 46.60612596784319, 46.33193268094744, 53.13962827410017, 45.295240606580464, 53.513632433755056, 55.45053311756679, 57.82241882596697, 58.15032516207014, 57.35216474533081, 52.298482826777864, 44.89788007736206, 49.14045013700213, 49.59725250516619, 56.70979336329869, 57.92359501974923, 62.525915009634836, 68.64777823856899, 23.9310759135655, 0.8622996721948896, 0.8693045963134084, 0.4453282324331147, 5.492818491799491, 2.41115888101714, 62.478576932634624, 63.19120502471924, 70.12470817565918, 65.21567385537284, 67.60192149026054, 57.164688450949534, 31.787223407200404, 29.38237544468471, 41.15167195456368, 48.6078324999128, 33.427884169987266, 66.30770138331822, 62.85560703277588, 55.21651084082467, 0.48028950499636786, 0.11634777539542743, 0.12049378720777375, 0.09237557423434087, 0.13854395864265306, 0.15437542913215502], [0.008723969687707722, 0.06161040293851069, 0.06736051903239318, 0.025657380199325935, 0.020025269826874137, 0.051899854359882217, 0.05307207788739886, 0.12034125253558159, 0.07659016270190477, 0.07757376706493752, 41.692366872514995, 56.6586719921657, 41.343622888837544, 38.0331814629691, 29.429970605032786, 43.94159255708967, 21.012101207460674, 10.627706612859454, 40.02520568030221, 64.23146152496338, 48.701167651585166, 56.650292464665, 47.006231035505024, 63.31340994153704, 19.522763524736675, 0.719245437000479, 0.26777817255684305, 0.04876089708081313, 0.06328909857464687, 0.27054119429418017, 4.119860964162009, 62.24026761736189, 63.55221952710833, 57.30276305334908, 52.30661916732788, 45.20046370370047, 45.8631203515189, 53.11119277136666, 56.17009203774588, 54.94389132090977, 55.39096621104649, 58.51995195661272, 54.96849489212036, 49.79760381153652, 32.15821552276611, 63.218094553266255, 47.218536717551096, 41.869684900556294, 55.3127121244158, 52.65182999202183, 54.671007769448416, 51.2946001461574, 51.48404972893851, 46.38093137741089, 40.746685777391704, 39.33921698161534, 42.24530451638358, 40.939439228602815, 47.72524104799543, 44.95104421888079, 43.95566265923636, 46.30418504987444, 48.43126835141863, 46.91642209461757, 42.75497572762625, 46.693440505436485, 48.53195817129952, 51.27035093307495, 47.33983836855207, 43.19415051596505, 43.2252402305603, 42.32180765696934, 41.82877738135201, 39.48199551446097, 39.405957903180806, 40.75209494999477, 41.512922695704866, 44.84157535008022, 42.497610977717805, 44.17715385981968, 42.025084836142405, 45.1522536277771, 44.292372362954275, 47.63955586297171, 48.745802879333496, 52.69957801273891, 52.16465009961809, 54.515083244868684, 45.095069953373496, 38.73853479112898, 49.395063400268555, 56.723769664764404, 53.663602352142334, 54.50582824434553, 49.88843066351754, 47.92523799623762, 43.711857318878174, 44.431343282972065, 48.527195181165425, 52.14495195661272, 53.23755965914045, 51.39823252814156, 42.857228892190115, 44.48661272866385, 42.73883853639875, 45.49390002659389, 43.198812757219585, 43.50686461584908, 42.72154099600655, 43.35752003533499, 42.14781781605312, 42.838097027369905, 43.93111119951521, 44.11752094541277, 41.196369716099326, 44.21391677856445, 42.963140283312114, 41.38165037972586, 42.1985570362636, 40.52621596200125, 40.805957385471885, 40.68022625786917, 38.97866800853184, 41.162292276109966, 40.49466071810041, 45.18967662538801, 50.73500960213797, 50.47095373698643, 52.65893452508109, 52.30702911104475, 51.37935427256993, 54.16018663133894, 51.34725706917899, 46.06048393249512, 47.03604922975813, 51.25435617991856, 49.98920038768223, 45.47327082497733, 51.17983675003052, 50.33428961890084, 56.315146105630056, 55.09377786091396, 53.78516108649117, 41.897606236594065, 42.33475909914289, 46.64441401617867, 52.183139256068635, 59.02398817879813, 61.263990129743306, 53.084522111075266, 10.908349565097264, 0.05543982922764761, 0.1316655677344118, 0.09220374202621834, 0.5447498975055558, 5.742729995931898, 59.88364710126604, 50.526508058820454, 63.104984828404014, 38.18962015424456, 57.423050267355784, 39.06499937602452, 17.031400067465647, 46.52519335065569, 32.11578287397112, 35.386730739048545, 40.342377049582346, 48.48777110236031, 49.80986043385097, 28.80183608191354, 0.2979609029633658, 0.19334341026842594, 0.10175075009465218, 0.08479998859443835, 0.0893435472888606, 0.05328132112377456, 0.030823881538318734, 0.09814848910484995, 0.02018697320350579, 0.0378375214391521, 0.05055428549115147, 0.03653531435078808, 0.08604142269385712, 0.1015254289710096, 0.03487025048317654, 0.032389163438762934, 47.91916527066912, 65.80385276249477, 43.67474004200527, 34.87025029318673, 45.28435277938843, 34.748688084738596, 23.88415993962969, 15.725425345557076, 42.04643317631313, 72.37654290880475, 55.66629205431257, 64.78787326812744, 51.89769683565412, 68.8512214933123, 21.20919554574149, 0.7011187268154961, 1.421991942184312, 0.08175921533256769, 0.12826441095343658, 0.3949782470507281, 4.786682188510895, 65.81975718906948, 63.56683158874512, 60.165611948285786, 54.98751558576311, 47.30043166024344, 47.60998085566929, 55.38264226913452, 57.96765007291521, 56.919729709625244, 56.274912561689106, 61.718603815351216, 54.939378465924946, 50.64540910720825, 36.28342008590698, 55.792530400412424, 43.81341566358294, 43.11054284232003, 57.64279399599348, 55.978842871529714, 55.77493756158011, 52.89463479178292, 53.26801013946533, 48.08757223401751, 43.74590349197388, 41.1780229977199, 43.7108394077846, 43.822031429835725, 48.93062843595232, 45.484443528311594, 46.934619426727295, 49.25094039099557, 51.04707057135445, 50.09303079332624, 45.782799175807405, 49.13929326193673, 52.33361291885376, 52.67943171092442, 49.16877794265747, 45.61423935209002, 44.40874774115426, 44.358703340802876, 45.323898451668875, 44.699978010995046, 46.10252053397042, 45.01464802878243, 44.79887866973877, 48.50242485318865, 47.36306619644165, 47.83030475888933, 46.67268623624529, 47.742601122174946, 48.403263636997764, 51.53121410097395, 50.69440432957241, 52.8953469821385, 54.70830569948469, 54.718092237200054, 43.59226145063128, 37.83626256670271, 49.30741882324219, 58.425942829677034, 54.39850984300886, 55.96025991439819, 54.11275822775704, 50.471127441951204, 47.47667619160244, 46.47432906287057, 52.36528975622994, 52.08347429547991, 55.58605425698416, 52.89240442003523, 48.432317529405864, 48.081756591796875, 45.34830747331892, 47.5867669241769, 46.85579906191145, 47.79647397994995, 44.85854632513863, 44.26097692762102, 43.889543601444785, 45.205518518175396, 47.381308691842214, 46.866419383457725, 44.40250131062099, 46.51409707750593, 44.53482627868652, 40.84140362058367, 41.47281421933855, 43.19620370864868, 41.75252437591553, 43.936037472316194, 41.72102819170271, 43.463820525578086, 42.06919200079781, 47.70368078776768, 51.32147577830723, 51.32214975357056, 54.54849018369402, 54.55869708742414, 53.79844951629639, 55.57859536579677, 51.632859298161094, 47.53133766991751, 49.304705551692415, 51.26030731201172, 53.961228438786094, 46.10212796075003, 52.71511765888759, 52.785839898245676, 58.980589730399, 57.26857444218227, 57.21448271615164, 45.24408796855381, 44.920315810612266, 47.672514642987935, 54.387538637433735, 60.70993382590157, 63.98800359453474, 54.743776253291536, 12.93414202758244, 0.426914990480457, 0.25700043088623453, 0.6410399334771293, 0.9970305625881467, 6.330830301557269, 68.89657933371407, 52.70177711759295, 73.50281115940639, 39.181551933288574, 63.06339291163853, 40.57841777801514, 21.625898122787476, 43.268933977399556, 30.50218881879534, 42.759026527404785, 34.48664719717843, 51.50385209492275, 59.23900018419538, 33.07131651469639, 0.23056885919400624, 0.23778735899499484, 0.09166585374623537, 0.07070238542343889, 0.09940493918423142, 0.029247905925980637, 0.1585781800427607, 0.195139845300998, 0.15183895666684422, 0.10502172993229968, 0.06974546784268958, 0.12821599069450582, 0.2750517965427467, 0.2121575849929026, 0.450620099902153, 0.14746480781052793, 57.097666127341135, 77.59882981436593, 54.55354847226824, 52.491708755493164, 45.16194289071219, 61.37768350328718, 26.306856087275914, 22.7320739201137, 50.4941919871739, 75.45912511008126, 58.405459540230886, 68.3379511151995, 54.783301080976216, 74.2026754106794, 23.333270277295792, 3.352536652769361, 0.693674871964114, 0.22439843815352234, 0.47564859688282013, 0.5521632454224995, 5.854623786040714, 67.73174858093262, 65.40399782998222, 62.74666622706822, 55.273208141326904, 48.888577938079834, 49.851219585963655, 56.7555889402117, 62.90661375863211, 58.24167660304478, 61.13645594460623, 62.11977890559605, 58.59162957327706, 50.24286869594029, 47.41584471293858, 64.10702623639787, 40.409691197531565, 45.54088027136666, 58.865680422101704, 60.21800136566162, 57.47288274765015, 55.45747784205845, 55.26923029763358, 51.24139084134783, 46.079612323216026, 44.947181020464214, 44.68523045948574, 47.88404560089111, 50.980743067605154, 49.15409639903477, 47.185143675122944, 52.47706542696272, 51.30627311979021, 51.67103964941842, 46.907639571598594, 51.97807012285505, 53.673378467559814, 55.90335069383894, 51.57761764526367, 47.81201710019793, 50.140761443546836, 47.59112344469343, 47.9027327810015, 46.36751788003104, 50.73553419113159, 52.18512644086565, 51.175726890563965, 55.159417493002756, 53.86914048876081, 54.58286987032209, 52.44559703554426, 52.418975012642996, 51.70345994404384, 53.28587743214199, 54.44197429929461, 55.54540729522705, 58.869203158787315, 56.61977597645351, 45.539848463875906, 39.815755707877024, 50.894905022212434, 59.943109784807476, 58.44168744768415, 59.49001080649239, 54.46821069717407, 54.985260895320344, 51.95992490223476, 55.68573658806937, 56.70760120664324, 59.31073338644845, 60.13497039249965, 57.17872381210327, 50.96399096080235, 52.73340879167829, 49.27634647914341, 51.26595272336687, 50.88688332693917, 49.71561854226248, 46.98961789267403, 48.298186029706685, 47.322078772953574, 49.45269175938198, 49.88496698651995, 50.45454209191458, 46.790187222617014, 49.270704541887554, 46.70899404798235, 42.94822597503662, 42.56184359959194, 45.40320519038609, 45.101260798318044, 45.04917362758091, 43.57222284589495, 48.20529556274414, 43.85715457371303, 51.39026294435774, 54.01277712413243, 54.342003617967876, 56.856667859213694, 57.63487652369908, 59.336080414908274, 57.77852010726929, 52.241260937282014, 48.72347136906215, 49.58224787030901, 51.61823681422642, 53.99431576047625, 48.91369220188686, 53.92081771578108, 56.64124591009957, 62.392224720546174, 61.38244996752058, 58.421245847429546, 47.05500391551426, 47.605738980429514, 52.328429562704905, 56.77290037700108, 63.60875007084438, 67.53734493255615, 59.73658152988979, 15.637975318091256, 0.75041706434318, 0.8817980544907706, 0.43673841335943764, 2.520023907933916, 7.600720422608512, 72.31134101322719, 60.107976640973774, 73.67008209228516, 49.72110761914934, 68.61977699824742, 51.89338200432913, 29.385981559753418, 55.43928050994873, 50.5615929876055, 50.385351930345806, 55.85120793751308, 61.528146743774414, 68.00303404671806, 48.853110858372276, 0.3493677744907992, 0.3314618867422853, 0.14888760074973106, 0.14405043316738947, 0.15980465923036846, 0.21977598619248184], [0.016476718276473026, 0.04851926736799734, 0.0332138209736773, 0.1068321902837072, 0.11746487473802907, 0.06061892756926162, 0.23181573514427456, 0.12225482985377312, 0.24050247616001538, 0.21342359563069685, 28.003158024379186, 60.6507351739066, 41.62527159282139, 33.8440534727914, 20.14683335168021, 34.56423078264509, 19.678272894450597, 7.2361814464841565, 16.24857258796692, 66.88600690024239, 39.76977252960205, 61.33183234078543, 49.36818081992013, 57.5817505972726, 32.78113889694214, 0.41835307276674677, 2.5536686054297855, 0.6421107703021595, 0.016726892441511154, 0.7519307945455823, 2.2140523833887915, 55.37373815264021, 59.17725849151611, 54.31956441061837, 50.96069404057094, 45.75399889264788, 48.46390404020037, 57.502509866442, 55.97014372689383, 59.05875696454729, 53.64101723262242, 51.848979541233604, 42.542527607509065, 55.58536638532366, 37.73775100708008, 25.627006122044154, 57.19949892589024, 41.495076247623985, 52.011567388262065, 52.76582561220442, 51.876963411058696, 53.243194648197715, 51.344109535217285, 46.690623010907856, 41.24871744428362, 38.89509160178048, 42.60465839930943, 44.834898131234304, 45.86518396650042, 46.28737040928432, 43.439553941999165, 47.360610008239746, 46.496504238673616, 52.04947675977434, 48.573859282902305, 50.61711951664516, 51.79532207761492, 51.17921141215733, 48.78143671580723, 46.82190922328404, 46.83053541183472, 43.49805430003575, 42.85310861042568, 44.31558282034737, 39.248980726514546, 41.498946394239155, 42.31204196384975, 42.5843905040196, 45.923767702920095, 45.73178897585188, 47.85381746292114, 48.7366555758885, 45.088364941733225, 47.01697642462594, 49.985267707279746, 49.93259341376168, 49.72687809807913, 50.6976387160165, 49.69997467313494, 49.32627623421805, 49.570554052080425, 53.58291639600481, 55.26618003845215, 51.57470982415335, 44.57822125298636, 44.49626725060599, 50.361863545009065, 55.9129843711853, 53.96974345615932, 48.6570257459368, 42.63694320406233, 44.61292403084891, 41.964388847351074, 41.30679396220616, 43.86245952333723, 41.474933419908794, 45.670696939740864, 45.693282059260774, 46.482826709747314, 46.25295945576259, 44.802509103502544, 46.88620090484619, 46.24951662336077, 49.969429288591655, 44.42328684670584, 41.99310922622681, 41.894920757838655, 43.195262227739605, 40.529957566942485, 39.629783698490684, 42.1793452671596, 40.044431345803396, 40.2865378516061, 40.26283754621233, 41.208570752825054, 46.13424253463745, 50.658377919878276, 48.213299887520925, 48.35108961377825, 51.83382204600743, 51.41804184232439, 54.63636752537319, 53.20048754555838, 42.11048167092459, 49.41464342389788, 52.082869802202495, 57.223873206547324, 46.824924741472515, 52.58588463919503, 52.413958413260325, 51.6630596433367, 53.82578372955322, 53.25270325796944, 46.946872574942454, 42.65889603751046, 45.06139898300171, 53.06090865816389, 57.990547861371724, 59.54813248770577, 43.86135823386056, 4.961803283010211, 0.21555078934345925, 0.08392784039356879, 0.04683312481003148, 0.9854176257337842, 12.416709678513662, 60.73761544908796, 50.71544694900513, 45.478568826402935, 47.00775269099644, 69.65049362182617, 11.90760908808027, 24.940892355782644, 53.25764690126692, 49.2755126953125, 27.394384656633648, 27.44584996359689, 45.14190428597586, 55.71171242850167, 13.804428219795227, 0.5540007725358009, 0.03805598596643124, 0.2168725755597864, 0.014372409853552068, 0.10485731411193099, 0.044828779862395356, 0.11605282979352133, 0.04822729714214802, 0.05023053268502865, 0.08017192514879362, 0.10385749276195254, 0.05959411577454635, 0.21574874514979975, 0.07400803840053932, 0.24965914338827133, 0.26534996713910786, 29.455286366598948, 70.1235408782959, 46.282183579036165, 30.93849400111607, 30.080728462764196, 36.38421412876674, 18.611717462539673, 13.051080209868294, 18.99798171860831, 74.2647019795009, 46.0226058278765, 70.04183006286621, 52.902587005070274, 63.39074339185442, 35.831731591905864, 1.2137669154575892, 3.6059153079986572, 0.4014832265675068, 0.025875471532344818, 1.2197558283805847, 3.0015490523406436, 59.03001226697649, 61.970823424203054, 60.18640095846993, 53.28313289369856, 47.060538155691965, 50.49068314688546, 61.3127178464617, 57.633118629455566, 60.90456676483154, 55.48634760720389, 51.69313144683838, 44.05535193852016, 56.41624934332711, 42.22371298926217, 29.351122447422572, 50.75968960353306, 43.36086211885725, 51.44412190573556, 55.66969667162214, 54.79053068161011, 54.47055571419852, 52.58250086648123, 49.49695178440639, 43.37548460279192, 41.71301344462803, 44.508732318878174, 47.171844823019846, 48.334622383117676, 46.19737386703491, 45.224657331194194, 49.40977968488421, 47.62770571027483, 53.77088253838675, 52.17707347869873, 53.31757164001465, 53.91041626249041, 52.80060829435076, 52.16073826381138, 49.652594906943186, 47.65436942236764, 47.86509786333357, 45.92213487625122, 46.780626501355854, 44.44686208452497, 43.91006858008248, 45.742120947156636, 46.24151924678257, 48.035742146628245, 50.41327674048287, 52.70574801308768, 50.82519721984863, 48.123390197753906, 49.272403376443044, 53.18698719569615, 51.65001092638288, 50.89180612564087, 51.425024781908306, 51.369234221322195, 49.58315461022513, 50.806343282972065, 54.92676053728376, 55.32292945044381, 52.517649854932515, 47.63642569950649, 48.437730176108225, 53.39465495518276, 59.16753101348877, 54.833515712193076, 52.10035146985735, 46.65217167990548, 48.30161149161202, 45.159375531332834, 46.22910976409912, 45.918226514543804, 44.880742345537456, 47.93460416793823, 46.72926541737148, 47.541211060115266, 46.91080100195748, 46.629117556980674, 50.17150722231184, 47.41850587299892, 53.208964347839355, 48.644296646118164, 46.05475861685616, 42.72451482500349, 44.36851419721331, 44.13991846357073, 41.168191296713694, 43.48492220469883, 42.56108277184622, 42.343267168317524, 41.27006925855364, 42.76863588605608, 49.99026346206665, 53.852496079036165, 50.72771051951817, 50.58145093917847, 56.21045759746006, 55.83950022288731, 54.637614727020264, 50.30085836138044, 43.355574539729524, 50.00120687484741, 54.62122392654419, 57.62070219857352, 49.82183218002319, 52.22258070537022, 55.372056688581196, 56.195331369127544, 57.30427081244332, 55.145336968558176, 48.04697390965053, 46.02428729193551, 48.42070708956037, 54.015347957611084, 63.13349328722273, 62.677170344761436, 51.695177691323416, 5.874047909464155, 0.31657974102667397, 0.07321778937642064, 0.6982694225651878, 1.2436238676309586, 15.2124103137425, 67.42266491481236, 55.90576171875, 49.780219418661936, 50.92482049124581, 71.25945322854179, 14.292740668569293, 34.045144762311665, 57.08997447150094, 55.336638246263774, 34.19923843656267, 29.88064466203962, 51.69936745507376, 64.12141595567975, 17.388495785849436, 0.6126483455300331, 0.10274460033646651, 0.22699254538331712, 0.048683513554611375, 0.13363217934966087, 0.06815190120999302, 0.2523444321538721, 0.14391459045665606, 0.15932895189949445, 0.22806262224912643, 0.2433849743434361, 0.16453015351934092, 0.42345467901655603, 0.1896883321127721, 0.4509313574859074, 0.37397460266947746, 38.696925503867014, 82.51629229954311, 56.30453968048096, 49.57585205350603, 30.74377073560442, 52.390146936689106, 22.926936149597168, 17.48958339009966, 26.68535225731986, 78.72163786206926, 50.428048610687256, 73.30139677865165, 58.3315862928118, 68.1006840297154, 39.322072301592144, 2.0513466341154913, 9.69204568862915, 1.453167315040316, 0.14704795660717146, 2.1722715624741147, 3.9348486747060503, 62.5804305757795, 61.79233809879848, 60.1705938066755, 55.1513923236302, 51.30446311405727, 51.951413358960835, 64.3395060130528, 58.98829528263637, 64.72458907536098, 57.25313901901245, 54.64150224413191, 44.580899783543174, 57.99716254643032, 43.723168986184255, 41.64911781038557, 53.87067256655012, 42.89733736855643, 53.448350633893696, 57.43380260467529, 59.051892144339426, 57.152442250932964, 54.85014622552054, 53.21303251811436, 46.81376940863473, 44.09744759968349, 46.015581199101035, 49.173454080309185, 50.782031536102295, 50.99436501094273, 47.048910345349995, 53.654017312186106, 51.45865406308855, 58.45543793269566, 56.123163904462544, 55.94275740214756, 57.576296261378694, 56.00071232659476, 56.408109528677805, 53.046522412981304, 53.19816337312971, 50.1200384412493, 49.19238444737026, 50.06856271198818, 49.792660168239046, 50.092850140162874, 51.57558877127511, 51.44641481127058, 54.498688970293315, 54.06779990877424, 56.963232381003245, 56.31800181525094, 53.53918790817261, 55.07513236999512, 57.46770633969988, 54.17841175624302, 54.654620443071636, 55.6503598349435, 52.30051864896502, 52.30605983734131, 55.082153524671284, 56.0406470979963, 58.762263434273855, 55.06895194734846, 50.99970817565918, 55.240905966077534, 57.0403539112636, 62.87023993900844, 58.30890737261091, 54.895094122205464, 50.80666637420654, 53.53503288541521, 50.04430307660784, 50.97362463814871, 53.745469502040315, 48.573654311043875, 50.05538892745972, 51.62428174700056, 52.012665203639436, 50.692858355385916, 50.83177716391427, 52.61897543498448, 51.07912261145455, 56.32096869604928, 50.130113329206196, 45.8456004687718, 45.1264271736145, 45.95513881955828, 46.57582834788731, 45.034384386880056, 45.586505617414204, 45.87936871392386, 44.62044545582363, 45.62801762989589, 44.90457466670445, 52.0986213684082, 54.302798407418386, 53.472308022635325, 53.927494934626985, 56.86180605207171, 57.0428135735648, 56.097764764513286, 50.74781165804182, 43.96883296966553, 51.45273419788906, 54.38178205490112, 58.97281469617571, 53.34855365753174, 57.29984828404018, 56.40759883608137, 58.38970797402518, 58.20566756384713, 57.552922521318706, 50.54963861192976, 47.71052128928048, 50.84930052076067, 56.58011565889631, 66.05921295710972, 64.27755587441581, 56.075725078582764, 8.117556095123291, 0.9108751799379076, 0.19342490232416562, 0.5313790664076805, 2.669453169618334, 15.431681564876012, 73.12648282732282, 58.87530367715018, 55.3718204498291, 55.89238296236311, 79.61226490565709, 20.535418306078228, 36.189171246119905, 61.297723633902415, 67.46758501870292, 41.566826820373535, 43.546493666512625, 60.92812810625349, 72.6016298021589, 29.024216651916504, 0.5727166139653751, 0.2228105440735817, 0.3526893119726862, 0.214764448681048, 0.20335756934114865, 0.16783274630350725], [0.03936185035854578, 0.018496918891157423, 0.050094957995627604, 0.0600245308929256, 0.10983215644955635, 0.06553956174424716, 0.0913979070527213, 0.05370252852195075, 0.14652244480592863, 0.3378221211688859, 13.503276790891375, 63.10686779022217, 41.89361449650356, 40.9234653200422, 29.21059513092041, 35.99369757516043, 26.33681845664978, 17.06304563794817, 16.017680474690028, 55.288660934993196, 41.57018627439226, 49.16148233413696, 55.97020278658186, 56.209276403699604, 38.88630560466221, 1.0783638954162598, 2.367216084684644, 0.03138786627511893, 0.047191472724080086, 0.5082998105457851, 1.8163861334323883, 45.45393746239798, 61.0470187323434, 58.062767437526155, 53.01128462382725, 44.440157072884695, 49.82985040119716, 55.81404897144863, 59.11597537994385, 55.301650592258994, 49.52196877343314, 49.24965150015694, 50.59677866527012, 40.26257004056658, 34.290447439466206, 29.67260864802769, 30.404736859457834, 53.644018854413716, 50.038021905081614, 56.81298106057303, 53.80815962382725, 56.36692755562918, 51.01366710662842, 48.271320819854736, 41.307280336107524, 41.22189392362322, 43.21000630514962, 44.32144015175955, 44.42773369380406, 46.31263753346035, 45.69805894579206, 45.80260501589094, 48.126311915261404, 49.02708680289132, 50.82656601497105, 50.61253023147583, 50.32426684243338, 46.20267881665911, 47.90043640136719, 49.051909242357524, 49.514377866472515, 46.86988653455462, 44.89256470543997, 42.45799582345145, 42.98883124760219, 46.963645526341026, 46.28849949155535, 45.02437898090908, 44.92868491581508, 43.98467486245291, 47.82088647569929, 54.84624481201172, 60.32750497545515, 49.59885059084211, 49.63709347588675, 50.18134934561593, 46.73797845840454, 44.02491882869175, 43.37335497992379, 39.920520646231516, 44.62029954365322, 47.38296236310686, 47.09741571971348, 47.273083550589426, 55.334932463509695, 60.339282172066824, 59.49627113342285, 51.56248794283186, 48.349818093436106, 40.973217896052766, 41.83808101926531, 46.657778876168386, 44.32802356992449, 43.52538503919329, 42.081261021750315, 43.40810292107718, 48.22247845785958, 48.412167753492085, 47.070922238486155, 51.385861260550364, 47.85812882014683, 46.13614634105137, 45.93117448261806, 43.98164892196655, 47.727499212537495, 46.50582872118269, 43.42811720711844, 43.337550912584575, 39.337618895939414, 41.65018088476998, 41.81476633889334, 40.39719138826643, 39.10294001443045, 40.77295691626412, 39.38805586951119, 45.82304661614554, 51.99428721836635, 51.571694305964876, 45.11300325393677, 50.943243639809744, 46.16943516050066, 57.50512933731079, 58.8211007799421, 45.26842056001936, 56.67438881737845, 50.633329663957866, 58.626697131565635, 47.74804850987026, 44.977117334093364, 48.63665362766811, 49.41280909946987, 57.30369063786098, 53.690339020320344, 49.33058411734444, 43.35901737213135, 44.498855454581125, 51.209220681871685, 58.955117634364534, 60.74920504433768, 36.336125646318706, 4.233097059386117, 0.04566998686641455, 0.05243428550394518, 1.6254448592662811, 1.247782364487648, 26.74231011526925, 64.60991600581578, 50.38250316892351, 51.23192739486694, 63.365646498543875, 42.58976493562971, 6.5894036037581305, 24.195526088987076, 15.39557351384844, 35.755593231746126, 28.58285665512085, 38.30360187802996, 44.156747000558035, 60.84096990312849, 7.426572510174342, 0.6603406178099769, 0.06213648470916918, 0.04213931132107973, 0.07475240488669702, 0.06923662764685494, 0.010754266055300832, 0.07510664087853261, 0.03478223770590765, 0.03230045855577503, 0.06681501080415078, 0.02752883915257241, 0.05794950295239687, 0.09795385133475065, 0.0997715312987566, 0.21842870063015393, 0.4933892477835928, 16.335711683545792, 74.33069596971784, 47.34034906114851, 37.2500638961792, 33.097052642277305, 43.914591857365195, 24.798945869718278, 23.99957299232483, 20.063131877354213, 61.275829860142295, 45.20217296055385, 56.74222755432129, 61.18681648799351, 60.505656787327354, 43.509782859257285, 0.8429063271198953, 2.363304683140346, 0.312272916414908, 0.049906725596104345, 0.7357659190893173, 2.4442885432924544, 50.52000107084002, 63.460135051182334, 60.68035534449986, 55.00504241670881, 46.27209479468209, 51.69690779277256, 59.69851234980992, 61.13013308388846, 57.534655707223074, 49.963005678994314, 49.2552934374128, 53.363203934260774, 40.57202890941075, 34.27230221884591, 33.938125133514404, 30.80511290686471, 56.80253096989223, 51.44521277291434, 58.33900696890694, 52.59925297328404, 58.16768871034895, 51.08898210525513, 49.83191401617867, 41.85836975915091, 44.35894652775356, 45.918441908700125, 46.94697332382202, 46.22811269760132, 48.51575149808611, 47.56127050944737, 46.86802789143154, 50.233717918395996, 52.619187355041504, 52.45472002029419, 53.088618074144634, 53.040797097342356, 51.34489120755877, 51.05079827989851, 52.6884400503976, 52.20388657706124, 49.209504808698384, 48.45686551502773, 45.941749640873496, 43.44295161111014, 48.61651079995291, 48.36268615722656, 47.513803890773225, 48.19660684040615, 47.765571866716655, 49.93358700616019, 57.432725633893696, 62.701850346156526, 53.30078479221889, 52.5569349697658, 50.25224528993879, 48.107833181108745, 46.56780317851475, 44.58543348312378, 40.84726095199585, 44.40382841655186, 48.155699321201865, 47.89626053401402, 50.051914828164236, 56.99840068817139, 61.50037479400635, 60.23617785317557, 55.55169888905117, 52.041673932756694, 44.7766409601484, 45.657276494162424, 53.2392897605896, 50.29042911529541, 49.18310512815203, 47.67110415867397, 46.20736885070801, 49.62359312602452, 50.04785360608782, 51.76614659173148, 53.720789500645225, 49.926545006888254, 50.17200749261038, 47.39907176154, 45.851805210113525, 50.16981881005423, 49.19601488113403, 47.09625884464809, 45.51483147484915, 41.667078903743196, 41.96533032826015, 43.904388427734375, 42.31548827035086, 40.92836727414812, 42.54075929096767, 42.8557801927839, 47.37785196304321, 55.09046009608677, 52.1181458064488, 47.785294328417095, 49.75541434969221, 50.36850602286202, 50.76523426600865, 54.430832862854004, 49.420823846544536, 59.03363922664097, 54.39970145906721, 58.332406180245535, 51.81851863861084, 46.73891646521432, 49.517268317086355, 52.58784055709839, 57.28446497235979, 55.27319424492972, 52.459750516074045, 45.863836015973774, 45.83398655482701, 52.96449545451573, 59.48408399309431, 66.63585090637207, 42.113358225141255, 5.236950644424983, 0.0762856633269361, 0.07057397267115967, 1.2667240223714282, 0.17321890299873693, 30.719028200422013, 70.28402342115129, 55.46617003849575, 57.452284812927246, 65.38778073447091, 46.31979417800903, 7.825297491891043, 29.75472593307495, 22.83491768155779, 44.37066466467721, 33.130258083343506, 32.58444234303066, 51.65378032411848, 68.49352822984967, 10.090281690870013, 0.8137344239013535, 0.08612001740506717, 0.14768468029797077, 0.04806878796911665, 0.03407506511679717, 0.06420565689248697, 0.15354300237127713, 0.11445470340549946, 0.12927740945347718, 0.12238863695945058, 0.2042742565806423, 0.23958164985690797, 0.21058501223368303, 0.1315534058958292, 0.40145163397703854, 0.5218146539160183, 20.342494624001638, 88.3572051184518, 53.60422304698399, 56.777190889631, 39.5039518220084, 53.31189843586513, 31.37363188607352, 25.895897933415004, 25.012894800731114, 68.75949832371303, 51.56996073041643, 60.463898113795686, 65.39297798701695, 65.53673621586391, 49.61927134650094, 1.5431870903287614, 9.781044295855931, 1.0016469891582216, 0.16803946878228868, 1.860568642616272, 4.608555563858577, 55.05496174948556, 63.860865456717356, 64.92829636165074, 57.414844444819856, 48.44806214741298, 51.60857881818499, 61.7789489201137, 63.706511225019185, 58.64023917061942, 50.019018581935335, 52.346300329480854, 54.22283853803362, 42.739613260541645, 37.42121539797102, 37.5103052003043, 38.31037984575544, 57.648991789136616, 52.512306690216064, 58.64481108529227, 55.67560958862305, 60.1072609765189, 54.54951156888689, 52.0322139603751, 45.26723936625889, 46.362372738974436, 48.059914929526194, 48.95511736188616, 49.00813211713518, 52.01874835150582, 50.34174851008824, 48.47660534722464, 52.46058429990496, 55.403115136282786, 56.27410657065255, 55.242278235299246, 56.949280398232595, 51.666426045554026, 52.17330755506243, 56.87355545588902, 56.02962725503104, 54.3488267489842, 51.787515776497976, 49.197029318128315, 48.4253693308149, 53.519274371010916, 53.827301910945344, 53.67711312430245, 52.70005396434239, 52.14452811649868, 56.739917278289795, 59.23348331451416, 66.78486892155239, 57.002249990190776, 56.87646327699934, 55.49673168999808, 49.79020398003714, 47.73921387536185, 45.057511465890066, 40.28525243486677, 46.868521213531494, 51.51163060324532, 52.488140855516704, 55.09777307510376, 65.3393656866891, 66.78227724347795, 66.12028762272426, 60.702332496643066, 57.293667861393516, 50.89907741546631, 50.36201640537807, 56.383061272757395, 53.17031499317714, 53.844470909663606, 52.20157977512905, 50.84418664659773, 52.54857628686087, 57.12547976630074, 55.02398668016706, 58.22105434962681, 53.10652010781424, 54.58981806891305, 51.95210123062134, 49.841162068503245, 53.09322820390974, 50.32341916220528, 49.05691889354161, 49.32522358213152, 43.97128568376814, 44.96431180409023, 46.89943722316197, 46.677268573216026, 45.013949734824045, 47.33717026029314, 43.95887272698538, 50.26881674357823, 55.21686519895281, 55.94369888305664, 49.93981606619698, 52.62452357155936, 52.08004188537598, 51.80041858128139, 55.2048830304827, 49.332515716552734, 59.89669581821987, 55.585953508104595, 61.120697430201936, 52.81583874566214, 50.345656871795654, 51.67711932318551, 54.54395995821272, 61.6867949622018, 57.94326536996024, 53.131641319819856, 48.67304481778826, 48.607370444706504, 55.051015172685894, 63.760158266339985, 66.63596207754952, 48.919011047908235, 6.17705146755491, 0.4490695388189384, 0.19836174670074666, 4.825205607073648, 3.2763068803719113, 31.89907898221697, 78.13058240073067, 57.676131452832905, 60.62639563424246, 71.02049773080009, 56.794248717171804, 11.474231702940804, 34.63580070223127, 19.87420862061637, 49.98767178399222, 40.81940562384469, 50.588506834847585, 58.43633038657052, 81.63567066192627, 17.722757986613683, 1.055116634283747, 0.43293001343097004, 0.2323937112731593, 0.16325429055307591, 0.15450720063277654, 0.1467737198940345], [0.022061005500810485, 0.04752363936443414, 0.050026809331029654, 0.05988152963774545, 0.08649570188884224, 0.05262623288269554, 0.07737243893955435, 0.03895898376192365, 0.18138649687170982, 0.16192369695220674, 6.602563491889408, 67.55934292929513, 38.640089239392964, 44.652101448604036, 26.483781542096818, 33.273067883082796, 24.58110421044486, 10.427255426134382, 26.851916210991995, 61.92652170998709, 52.793753896440776, 43.938552720206125, 53.568787234170095, 54.62132467542376, 47.29327154159546, 3.7890263966151645, 1.8369901478290558, 0.10356938679303442, 0.05608895653858781, 0.40703955984541346, 0.5303057868565831, 35.77635792323521, 61.11912713732038, 54.206847258976524, 52.2516484941755, 43.32106978552682, 48.97160543714251, 53.56623377118792, 59.1843387058803, 57.45409829275948, 54.231666224343435, 32.91554485048567, 31.984920501708984, 42.95388528278896, 17.301964657647268, 45.30947399139404, 42.21889788763863, 50.449483803340364, 54.39631073815482, 55.440826484135215, 51.65800830296108, 53.20761292321341, 52.97652278627668, 48.54763330732073, 43.32108020782471, 43.49713018962315, 43.52910579953875, 43.4429863521031, 44.30619927815029, 44.62909596306937, 43.39953579221453, 45.54404517582485, 46.55653320040022, 49.954893657139365, 49.03230837413243, 48.098477431706016, 47.43932267597744, 51.90508624485561, 50.16535806655884, 48.036746161324636, 50.47012690135411, 50.0477910723005, 43.81147711617606, 45.30615970066616, 46.652675424303325, 47.80423511777605, 50.80318880081177, 49.49065671648298, 47.98841796602522, 51.323577608381, 50.69254221235003, 53.96039465495518, 57.229706219264436, 54.436870847429546, 53.74016455241612, 52.6137364932469, 48.66505091530936, 49.2662924357823, 41.669642789023264, 39.53940153121948, 42.44963366644723, 45.96650259835379, 48.385969570704866, 53.23181349890572, 55.17911216190883, 57.1215957232884, 53.843081269945415, 47.30080338886806, 48.14360250745501, 46.44696705681937, 44.118354729243684, 41.012013162885395, 43.199431146894185, 45.683196749006, 43.20015375954764, 47.25872162410191, 48.54191146578108, 48.223812511989046, 47.71443312508719, 49.907114369528635, 49.79160751615252, 46.25157676424299, 43.06875985009329, 49.08633409227644, 44.69674015045166, 45.08493947982788, 44.43733957835606, 43.32582582746233, 40.04116221836635, 42.98417942864554, 42.22449466160366, 41.93426840645926, 40.32076815196446, 40.28072220938546, 39.74359866550991, 45.41439873831612, 50.303450039454866, 50.692934785570415, 50.14615671975272, 53.348095076424734, 44.48939200810024, 53.598424775259836, 51.323400429316926, 48.30358478001186, 52.679556778499055, 55.17873001098633, 52.12100846426827, 48.643706049237935, 50.94938932146345, 50.50583369391305, 54.63272666931152, 56.983462061200825, 53.726785796029226, 49.228490761348176, 42.84604229245867, 46.45023965835571, 52.8127224785941, 56.31344032287598, 60.71891784667969, 32.49003022057669, 2.7105584953512465, 0.2830653765371868, 0.12924346913184437, 2.3753294093268256, 1.0070191408906664, 30.600735119410924, 62.08066749572754, 50.36546271187918, 55.87889303479876, 54.859651361192974, 37.381329263959614, 8.242916362626211, 33.28803082874843, 12.276967508452278, 34.10335329600743, 30.80629062652588, 49.87840093885149, 46.32501574925014, 49.667113167899, 1.917886721236365, 0.40818069289837566, 0.01075776051064687, 0.05553705311779465, 0.06692673838032143, 0.043274310417473316, 0.025499076283137714, 0.07629232654081923, 0.053328740543552806, 0.042116777173110416, 0.07073001536939826, 0.07108450241919075, 0.03664762885974986, 0.1316207165696791, 0.06949321566415684, 0.1289509255439043, 0.29922672361135483, 8.338116237095424, 76.93352590288434, 46.53238821029663, 42.733377252306255, 29.80675404412406, 39.87977293559483, 15.504978111812047, 11.846326845032827, 30.012931415012904, 71.82404300144741, 54.036744935171946, 47.97736685616629, 60.29413972582136, 59.26790469033377, 51.63571500778198, 4.087280426706586, 1.6738063842058182, 0.13761907470013413, 0.10055437750582184, 0.9252562139715467, 1.1100934956754958, 39.97886119570051, 64.3106918334961, 57.60896669115339, 54.250044209616526, 45.96707929883684, 50.376381805964876, 55.456553731645855, 61.334493500845774, 59.75097124917166, 56.02099411828177, 34.13909135546003, 31.473369802747452, 45.96401514325823, 23.24848140989031, 46.494454520089285, 46.422175884246826, 52.44117798124041, 56.371131215776714, 56.924065385546, 52.544188499450684, 54.794042995997835, 55.57355792181832, 50.61804015295846, 44.752357006073, 46.09456484658377, 45.046936307634624, 46.54397433144705, 46.412399768829346, 48.66306373051235, 47.82815081732613, 47.84381553104946, 49.29502671105521, 51.82233667373657, 51.44739103317261, 49.73670285088675, 51.211159229278564, 54.05055100577218, 52.82316214697701, 52.12595905576433, 51.43989740099226, 52.69069821493966, 46.41445296151297, 49.38924775804792, 49.49512440817696, 48.64852115086147, 50.59303706032889, 51.03007527760097, 50.08772931780134, 52.42149373463222, 53.731785024915425, 56.659439768110005, 59.728910718645366, 56.51939535140991, 55.520876680101665, 53.38998923982893, 49.80851943152291, 48.15293393816267, 41.78892251423427, 39.32165888377598, 41.62431968961443, 46.345693588256836, 48.990382943834575, 56.33685227802822, 58.41506889888218, 57.70832245690482, 55.89331749507359, 49.53788014820644, 53.0643584387643, 49.65394980566842, 49.06387404033116, 43.595801557813374, 47.87581545966012, 49.12195750645229, 46.1219025339399, 48.63040024893624, 51.2852235521589, 49.07203469957624, 51.07427624293736, 51.44603960854666, 51.80899265834263, 48.78785685130528, 45.108268056597026, 51.59889302934919, 48.27530908584595, 47.18115540913173, 45.28302219935826, 45.95314816066197, 43.83009828839983, 44.49270977292742, 44.33844586781093, 42.95894009726388, 42.548346723829, 42.886056968144004, 42.38424416950771, 47.7797566141401, 52.44661842073713, 51.336271967206685, 53.5535672051566, 55.38397979736328, 47.71663570404053, 49.27682590484619, 48.81649385179792, 50.94003357206072, 53.708956718444824, 58.067287240709575, 52.938314642224995, 50.42799302509853, 53.78218378339495, 51.28505332129342, 57.80346066611153, 58.962732860020225, 56.27785859789167, 51.260595662253245, 45.28129209790911, 49.69237681797573, 55.876009532383506, 59.77608898707798, 65.53490883963448, 37.12940495354788, 2.399771434920175, 0.027534041819827895, 0.13364013178007944, 0.29145899042487144, 0.5403440339224679, 34.986465862819124, 68.22593225751604, 54.57551520211356, 60.02845450810024, 61.39461626325335, 43.7282828603472, 9.215103098324366, 40.65370498384748, 14.642149073737007, 41.18687152862549, 38.778792653764995, 45.09456968307495, 51.969127791268484, 56.0333480153765, 2.991240314074925, 0.34832920879125595, 0.04851314698212913, 0.07462604809552431, 0.04851197650922196, 0.03859029158151575, 0.015808817597904375, 0.3365514964929649, 0.20601993719381945, 0.13198655551033361, 0.21198903689427034, 0.1509180489395346, 0.1502180179314954, 0.27345941056098255, 0.18535724308873924, 0.5088286878807204, 0.44428942246096476, 10.420206478663854, 92.89177322387695, 50.721394606998985, 61.57499149867466, 35.55911554609026, 49.04746239525931, 31.37545231410435, 17.855397360665457, 36.76445777075631, 74.23916734967912, 63.07075105394636, 57.2800007547651, 65.07988521030971, 64.78335693904332, 57.481474195207866, 5.703270307609013, 5.267221774373736, 0.27874419412442614, 0.23776401739035333, 2.2558701166084836, 1.91649187036923, 43.50939723423549, 66.03985527583531, 60.91392598833357, 56.00785160064697, 48.368296827588765, 52.976078101566856, 56.94445834841047, 64.62266595023019, 60.78344576699393, 59.09254605429513, 37.432652132851736, 34.364098344530376, 44.45087466921125, 20.289502450398036, 48.47555269513811, 47.59618520736694, 54.8611660684858, 57.5167293548584, 60.600965227399556, 53.330748898642405, 57.92842749186924, 58.06330244881766, 52.34229121889387, 47.28084816251482, 47.10936662128994, 46.81577048982893, 48.69872883387974, 48.83531999588013, 50.33607530593872, 49.935053076062886, 52.39859594617571, 50.88833550044468, 56.21279566628592, 54.27169132232666, 52.78156328201294, 52.89737238202776, 57.30504901068551, 57.27651970727103, 56.26910386766706, 55.2382413319179, 57.44952985218593, 48.679284300122944, 54.20888308116368, 52.325667653764995, 53.95582968848092, 55.14957536969866, 56.298935958317344, 54.4351407459804, 58.50062901633126, 58.65113394601004, 60.24896253858294, 60.584352084568565, 60.30099064963204, 58.42563016074044, 60.40614468710763, 54.31561435971941, 51.44966309411185, 45.749597208840505, 43.28873634338379, 45.147268295288086, 49.137010778699604, 52.5344158581325, 64.427748135158, 59.19272518157959, 58.540879930768696, 58.68339443206787, 55.070946080344065, 56.28154809134347, 54.89140115465437, 53.8186479296003, 48.267957891736714, 51.52518653869629, 54.33542367390224, 50.69338641847883, 53.313152585710796, 53.8026635987418, 53.05217824663435, 54.58308873857771, 55.02025202342442, 54.810364314488, 51.762321608407156, 46.35144322259085, 54.782158102308, 49.07632521220616, 49.21078675133841, 47.91414519718715, 48.46548822947911, 44.846536363874165, 47.57628904070173, 46.63435302461897, 45.62809406008039, 43.92231478009905, 44.782623359135215, 42.587006500789094, 50.87828493118286, 54.91326713562012, 56.586191858564106, 53.46609285899571, 58.40581389835903, 47.571105684552876, 54.281554290226524, 55.76106548309326, 50.87523814610073, 55.48186254501343, 58.878611019679475, 56.03028733389718, 50.996154172079905, 52.19726841790335, 53.82977894374302, 58.157568659101216, 61.23049981253487, 59.07169451032366, 52.9307028906686, 47.39593812397548, 52.594514301845, 57.172543389456614, 60.13184370313372, 68.46920258658272, 41.62599073137556, 3.5765081431184496, 0.3773096837103367, 0.4748398917061942, 5.818097974572863, 2.1878958897931233, 37.27800955091204, 76.49583108084542, 59.32803440093994, 66.43370001656669, 65.41527475629533, 49.849069118499756, 14.1303117615836, 42.348085744040354, 17.314641645976476, 50.80082641329084, 48.406522342136924, 72.46775885990688, 57.66079330444336, 73.39705262865338, 6.894648824419294, 0.8623193768518311, 0.13939033608351434, 0.17591483119343007, 0.2895177017365183, 0.17508108807461603, 0.09684948809444904], [0.07996999991259404, 0.07745398527809552, 0.04265974089503288, 0.036390104464122226, 0.054774142269577296, 0.04400219189535294, 0.1055003549637539, 0.07754214054771832, 0.09216934708612305, 0.1647863004888807, 1.950372806617192, 55.0143530028207, 56.2845983505249, 34.97654383523123, 30.13367373602731, 35.42437955311367, 83.12618432726178, 53.98453964505877, 5.7499522141047885, 60.42377921513149, 54.922577721732004, 46.10270466123308, 51.112046650477815, 53.723502772195, 54.350035735539024, 4.572895671640124, 1.3117826559713908, 0.1975064125976392, 0.37325804254838396, 0.3506024368107319, 0.14330141193100385, 30.388057708740234, 57.52811050415039, 60.41326659066336, 56.07166385650635, 49.05897208622524, 45.1006041935512, 49.76138285228184, 58.388505935668945, 56.32350826263428, 65.01192487989152, 43.02915164402553, 21.244937079293386, 57.109363419669016, 45.94187470844814, 44.654710497174946, 53.063410009656636, 58.02914163044521, 51.572680950164795, 54.668940680367605, 51.46896866389683, 52.472476141793386, 51.27852201461792, 52.17021908078875, 44.04037857055664, 43.74389546258109, 40.23859180722918, 45.286381653376985, 47.23483371734619, 47.15045826775687, 45.131864139011924, 45.17736094338553, 45.40116589409964, 50.62755571092878, 47.10711540494646, 50.04034260341099, 49.905175822121755, 54.37262780325753, 51.43735783440726, 51.35369457517351, 49.13880688803536, 49.61363288334438, 47.48474999836513, 49.517869336264475, 47.677392278398784, 48.25910588673183, 49.13673979895455, 50.005889960697715, 52.0110810143607, 50.87011384963989, 51.72444697788784, 52.09076295580183, 52.683649267469136, 53.45089020047869, 54.24006312234061, 52.559933117457796, 50.7398316519601, 53.512680530548096, 49.511060101645334, 45.00813409260341, 44.96575008119856, 47.60206685747419, 52.31488404955183, 53.69735322679792, 53.18003552300589, 53.97577101843697, 52.80700758525303, 52.43238851002285, 54.68021413258144, 47.43343755177089, 48.417198249271934, 47.83949722562517, 45.04262147630964, 46.76929746355329, 48.42633513041905, 50.96588781901768, 49.09923342296055, 53.56121717180525, 50.392091682979036, 47.36613730021885, 49.1197167124067, 49.00687796728951, 43.59016309465681, 46.066594873155864, 45.21766744341169, 42.158386026109966, 42.946937084198, 42.40467882156372, 44.886349541800364, 44.1291800226484, 40.5823643548148, 40.61004597800118, 39.6850392477853, 40.479200976235525, 41.089909417288645, 45.79721321378435, 47.85847623007638, 47.36732196807861, 54.32227768216814, 52.75921092714582, 54.52070433752877, 36.009289332798545, 33.454603467668804, 56.25871978487287, 52.491211959293906, 57.65590524673462, 47.00181198120117, 49.17063658578055, 54.484386103493826, 52.984026840754915, 55.89920261928013, 57.74249717167446, 52.53258153370449, 48.57798303876604, 42.02298648016793, 47.41650479180472, 54.28149175643921, 57.35057708195278, 61.092022214617046, 30.28620059149606, 0.9319782704114914, 0.31312746341739384, 0.1800658641649144, 0.3078070160533701, 1.4782297930547168, 57.79429946626936, 49.785020623888286, 62.22024985722133, 51.21668304715838, 70.43690463474819, 27.82404214995248, 15.102543660572596, 34.220162936619346, 17.528147629329137, 38.58235665730068, 12.464402113642011, 27.53196941103254, 47.971711022513254, 43.82949726922171, 0.4548393392137119, 0.08922374514596802, 0.0570324764453939, 0.08258964041514055, 0.03624294718195285, 0.11214631370135716, 0.05964337741690023, 0.11767725619886603, 0.020726325422791497, 0.046798943608467064, 0.019007202670244232, 0.06748075543769769, 0.0606541299660291, 0.11149466224014759, 0.07488980144262314, 0.024718562540199076, 0.14019689708948135, 1.9831991365977695, 63.47512231554304, 64.04732731410435, 39.77588694436209, 29.017120804105485, 44.142152309417725, 61.76808193751744, 56.832279682159424, 9.990311009543282, 65.17967523847307, 62.409949575151714, 51.277163641793386, 58.42861788613455, 59.3502755846296, 60.97602203914097, 6.02199981042317, 0.5818105574165071, 0.2242995077478034, 0.297931400260755, 1.0235775666577476, 0.35503036635262625, 32.50083119528634, 61.72965839930943, 62.54988629477364, 60.58499826703753, 50.894915444510325, 47.16303103310721, 52.026686668395996, 61.272640636989046, 60.26275471278599, 67.59393106188092, 44.35774448939732, 23.742319413593837, 60.22182982308524, 48.378125054495676, 46.78190496989659, 54.284274509974885, 59.256613867623464, 53.63772031239101, 57.347221102033345, 55.099767208099365, 54.43405335290091, 52.33278260912214, 55.41792174748012, 46.916234493255615, 43.762718132564, 43.093717779432026, 45.97998557771955, 48.07285247530256, 49.26186295918056, 47.13072885785784, 46.22308220182146, 47.92943818228585, 53.00719213485718, 49.01350654874529, 51.69751228604998, 51.417246273585725, 58.27187694822039, 53.5325072152274, 54.993254797799246, 54.236853054591585, 52.027961662837434, 49.003598417554585, 52.297079290662495, 49.34179156167166, 49.50744356427874, 50.390274729047505, 53.468587262289866, 54.01645272118704, 56.130966731480186, 55.87867764064244, 55.80491556440081, 53.8756023134504, 55.043643133980886, 54.0669834954398, 55.23980467660086, 53.24491432734898, 55.672451632363455, 48.69594955444336, 44.36904920850481, 43.77712869644165, 48.61263370513916, 54.40648637499128, 53.428735869271414, 55.319677693503245, 57.66339887891497, 55.599818638392854, 51.96519858496529, 57.21093913487026, 51.28638737542288, 52.08451999936785, 50.66020877020699, 48.873879023960654, 49.0452424458095, 49.60863018035889, 53.409426825387136, 52.67412676130022, 54.911943503788535, 51.27198723384312, 50.119753565107075, 50.39581591742379, 49.34994179861886, 47.27468858446394, 48.672930172511506, 47.884542397090364, 44.511984075818745, 44.059420108795166, 43.30275085994175, 45.65869740077427, 46.22894648143223, 42.78865017209734, 42.648904527936665, 42.464176246098106, 43.45157779966082, 42.00989954812186, 47.58659669331142, 50.75861610685076, 50.38493503843035, 55.66610097885132, 56.14274392809187, 57.74748250416347, 35.638550826481406, 34.90374061039516, 58.9719739641462, 54.61373724256243, 58.45620918273926, 50.951803820473806, 51.27860539300101, 52.65068006515503, 54.97508873258318, 58.69427531106131, 59.313457080296104, 56.31831101008824, 51.022359303065706, 45.59833492551531, 48.70416579927717, 57.0000821522304, 61.70164326259068, 65.79003279549735, 33.33157866341727, 1.7959363907575607, 0.18171542350734982, 0.3078978583216667, 0.3563628191394465, 2.5044794848987033, 63.72988496507917, 53.78134652546474, 67.45518943241665, 56.498234612601145, 77.02814647129604, 29.998611177716935, 19.40454513686044, 45.63453156607491, 14.395560111318316, 46.660832609449116, 19.21886842591422, 29.887919425964355, 55.784425326756065, 49.86580038070679, 0.7912205776997975, 0.08528228450034346, 0.03266549343243241, 0.07707061299255916, 0.05790717593793358, 0.05750224659485476, 0.04395004987184491, 0.2794655039906502, 0.14887842695627893, 0.14881311117538384, 0.12398560983794076, 0.20976454125983374, 0.21259895845183305, 0.35048122331500053, 0.21489989784147057, 0.19492032565176487, 0.3744718059897423, 3.365087922130312, 79.80120726994106, 74.11814362662179, 50.060909271240234, 39.807800020490376, 53.779720646994456, 97.7226333618164, 64.98873179299491, 14.340718848364693, 73.1938247680664, 65.42754527500698, 57.45403228487287, 62.14896133967808, 64.68441459110805, 65.41559437343052, 6.106100806168147, 3.2057129655565535, 0.2759424958910261, 0.46076664115701405, 2.781895216022219, 0.9876726418733597, 36.588664872305735, 63.860650062561035, 64.84772505078996, 60.892581122262136, 53.401801177433555, 49.421320642743794, 53.6105945450919, 62.63526575905936, 61.76173823220389, 68.92731816428048, 39.03249222891671, 23.242420843669347, 59.81249754769461, 45.56141219820295, 49.009358474186485, 55.85321249280657, 61.09954711369106, 55.042680808476035, 57.63924694061279, 55.005619117191856, 56.90840414592198, 55.87272998264858, 58.123498167310444, 49.59833642414638, 47.08932801655361, 45.61383635657174, 49.97014495304653, 50.85418857846941, 51.211193970271516, 48.57866048812866, 49.15079253060477, 48.35896192278181, 56.084455490112305, 52.307984488351, 55.50003208432879, 54.96997833251953, 63.545966148376465, 57.01936687741961, 57.55098049981253, 56.127357142312185, 54.867944036211284, 55.575562477111816, 55.516349928719656, 51.49675451006208, 54.052993297576904, 53.505134786878315, 56.75122894559588, 59.031540870666504, 61.89257975987026, 60.32921423230852, 58.37252507890974, 57.97728375026158, 58.82780579158238, 55.95170668193272, 57.74731922149658, 58.06652641296387, 58.72850213732038, 50.58164201463972, 45.44990750721523, 46.269381523132324, 52.049744265420095, 56.1086699622018, 53.161240645817344, 58.03561387743269, 61.729046957833425, 59.55351039341518, 56.33744634900774, 62.79023838043213, 55.89197996684483, 57.330618381500244, 56.54290805544172, 51.063659395490376, 54.45762859072004, 51.973883833204, 59.79869147709438, 55.78651673453194, 57.346463748386924, 55.2844364302499, 53.53417478288923, 54.54735762732369, 51.82640831811087, 47.9183349609375, 52.56706544331142, 48.80774259567261, 47.95560162408011, 47.49431766782488, 46.784614767347065, 50.21127871104649, 48.55612053189959, 44.23089122772217, 46.460943358285085, 44.95862122944423, 45.65618910108294, 45.31147854668753, 49.275113173893516, 51.4859743799482, 51.92674725396292, 56.983976227896555, 59.11135482788086, 59.31625720432827, 45.61098412105015, 42.04571403775896, 55.15932716642107, 59.45731258392334, 58.40101269313267, 54.93830149514334, 53.29058831078665, 53.946543421064106, 53.97565984725952, 59.74542658669608, 63.00670255933489, 57.21018525532314, 53.636924743652344, 47.38058955328805, 51.36564200265067, 58.939539773123606, 61.98338576725551, 66.91931656428746, 36.60684135981968, 2.847789760146822, 0.31969237114701954, 0.45883384772709435, 2.625246776001794, 1.9741369485855103, 69.60492038726807, 60.11710657392229, 70.6227342060634, 63.37196935926165, 81.00823443276542, 39.52874994277954, 22.10865374973842, 43.24193327767508, 25.246816328593663, 57.306435176304404, 22.276270355497086, 42.88178382601057, 59.91976383754185, 66.6117753982544, 1.7327463243688856, 0.26570375529783113, 0.11071980917560202, 0.12980554039989198, 0.1611530033073255, 0.19002042072159903, 0.14798197363104137], [0.04053660821435707, 0.056291159974145036, 0.03562505283792104, 0.07894925932799067, 0.039516909181007316, 0.014845609997532197, 0.0504459811241499, 0.006162455887533724, 0.05064059853819864, 0.056364397651382854, 0.14965363964438438, 45.11085626057216, 51.62995842524937, 42.44021538325718, 29.460580893925258, 32.674623012542725, 52.13065256391253, 42.163076060158865, 2.1770019829273224, 26.279369013650076, 64.90099688938686, 48.89252798897879, 53.015234674726216, 48.684248788016184, 57.56261873245239, 10.01196767602648, 0.22222500906458922, 0.37984574905463625, 0.1279438574399267, 0.42589349672198296, 0.4524859626378332, 23.555400712149485, 55.95349931716919, 53.30883080618722, 58.33571352277483, 52.01717111042568, 47.78369624274117, 47.87359203611101, 56.0967572757176, 57.40027059827532, 57.48195014681135, 61.8300598689488, 59.68198258536202, 46.03034612110683, 40.528790269579204, 45.466590132032124, 51.26438243048531, 55.07548325402396, 53.12800393785749, 51.982454436165945, 52.79325362614223, 52.50157519749233, 51.94366611753191, 51.19794028145926, 48.0662134715489, 42.95205443246024, 41.95098924636841, 42.627705574035645, 46.60041107450213, 46.90922028677804, 46.95360190527779, 45.22668273108346, 47.986736501966206, 50.64864001955305, 49.409942967551096, 50.747189794267925, 49.27654102870396, 49.18903888974871, 49.74568339756557, 50.62559284482683, 51.4576986857823, 48.589860984257285, 50.5067195892334, 50.96439743041992, 50.84945338112967, 48.84566238948277, 49.299219948904856, 48.060036523001536, 52.29719393593924, 51.887212003980366, 50.70329802376883, 52.191543102264404, 52.84719944000244, 51.2022134235927, 50.84717437199184, 48.81040028163365, 53.383287702287944, 51.90714291163853, 51.51121718542916, 44.294644423893516, 47.88567495346069, 54.9286539213998, 54.476176806858604, 50.86799464906965, 54.61019366128104, 55.43485798154558, 53.50266122817993, 54.46639721734183, 51.093258721487864, 52.88219404220581, 49.49587133952549, 47.382722650255474, 49.209188665662495, 49.64013678686959, 49.078621591840474, 50.69237892968314, 51.60621990476336, 51.22585119519915, 49.72232355390276, 49.23693282263619, 48.05357469831194, 49.19529226848057, 49.301669188908164, 49.20499195371355, 46.623701436179026, 43.516025815691265, 42.91251570837838, 40.428058760506765, 41.23338624409267, 41.890838691166465, 41.912499700273784, 42.08066347667149, 40.15419898714338, 40.50465570177351, 44.73850577218192, 45.710544858660015, 47.558345317840576, 48.02924905504499, 53.572344711848665, 50.57249123709542, 53.742290701184956, 31.46197475705828, 32.42728451320103, 51.469889300210134, 46.63506868907383, 57.658500398908345, 45.36898183822632, 52.05130761010306, 46.03022452763149, 51.607196126665386, 55.24070446831839, 53.256486552102224, 49.1074983051845, 47.544195311410085, 44.281929220472065, 47.5255081312997, 56.0043740272522, 59.01321152278355, 58.23125083105904, 26.41220988546099, 1.7543404570647647, 0.031000517774373293, 0.08134805703801767, 0.39014968329242294, 7.81750682422093, 65.48049749646867, 46.73757546288626, 59.13873767852783, 49.02067361559187, 63.653232438223704, 9.351799351828438, 14.126699566841125, 25.52856057030814, 21.502630131585256, 34.58785465785435, 28.621856893811906, 40.88310323442732, 51.59507499422346, 30.48488780430385, 0.3334016283707959, 0.03252925377871309, 0.09338268305041961, 0.02341383639057832, 0.04298987193033099, 0.03293966568474259, 0.04841203508632524, 0.001030528240205188, 0.0598819571148072, 0.004939727726325924, 0.01506558426522783, 0.04213171512154596, 0.044165837578475475, 0.02758796839043498, 0.03226631467363664, 0.01757082376363022, 0.009948658391035028, 0.11313573310949973, 47.53551006317139, 61.765087263924734, 44.255731037684846, 28.658574649265834, 39.18389000211443, 61.21943828037807, 47.20102378300258, 4.536676015172686, 31.54085418156215, 70.21026829310826, 53.94767597743443, 59.455387932913645, 53.2712653705052, 61.369825090680806, 10.435001799038478, 0.3670751771756581, 0.7007815220526287, 0.1210622638463974, 0.9897791402680534, 0.22468274432633603, 26.158776078905376, 58.087603773389546, 56.05712822505406, 61.76911721910749, 53.98339319229126, 48.715512207576204, 51.9654278755188, 56.58231476375035, 59.235852650233674, 61.0046694619315, 63.702404839651926, 61.1633037839617, 46.70881339481899, 41.860475063323975, 46.83977651596069, 53.216517039707725, 55.959780488695415, 55.69851432527815, 53.38952718462263, 55.10962322780064, 53.26963601793562, 53.57344600132534, 52.53769193376814, 49.88785743713379, 43.18739686693464, 43.59756987435477, 43.6953900882176, 47.02589443751744, 48.29754332133702, 48.29937417166573, 46.34598193849836, 48.75282403400966, 51.95635005405971, 52.958009311131065, 53.02309308733259, 51.992254870278494, 54.11964389256069, 52.5777656691415, 51.85812337057931, 55.56114843913487, 51.25776079722813, 53.02479887008667, 52.96063225609915, 56.006917067936485, 52.402750968933105, 51.35592494692121, 51.818581172398154, 52.79551873888288, 54.08577142442976, 54.977749892643516, 55.67181934629168, 55.098558221544536, 53.532017367226736, 53.41505486624581, 49.68366725104195, 53.672204221997944, 53.867691789354595, 53.709557737622944, 47.95095675332205, 49.09486995424543, 55.13425459180559, 54.52877467019217, 49.200663225991384, 57.11431401116507, 55.87261186327253, 55.86281490325928, 56.3688383102417, 55.50135919025966, 53.50905704498291, 51.47207450866699, 52.246124676295686, 53.31233964647566, 51.88705219541277, 51.144091742379324, 52.471524238586426, 53.069024154118125, 53.028901781354634, 52.14881168093, 50.79095649719238, 49.21737364360264, 51.051882198878694, 52.17167820249285, 49.827672140938894, 48.889828613826204, 43.80726998192923, 46.058389050619944, 42.23171731403896, 44.588000842503135, 44.16200678689139, 44.362913949149, 43.03189270836966, 42.73623991012573, 42.13927500588553, 46.0764092036656, 46.64678335189819, 48.83165829522269, 49.25391074589321, 55.288626194000244, 52.5178895677839, 56.827367305755615, 34.7520683833531, 35.55840335573469, 54.12574788502285, 49.53866182054792, 58.40219388689314, 49.877289227076936, 53.84633650098528, 46.871849400656565, 53.58970826012747, 57.36190611975533, 55.40182277134487, 51.453554085322786, 49.27801057270595, 47.36422307150704, 50.152722767421174, 59.01936762673514, 60.10333524431501, 61.5363803591047, 30.067078726632253, 3.060541863952364, 0.04763736183355961, 0.2529364675283432, 0.4952889287046024, 9.500899008342198, 69.16009671347481, 50.167637075696675, 61.90606621333531, 55.71655879701887, 67.33127525874546, 12.070808376584734, 16.467756986618042, 28.79808405467442, 21.18279239109584, 38.3897317477635, 28.71702115876334, 41.773893560682026, 59.622561591012136, 32.72883980614798, 0.5533004701137543, 0.06195129214652947, 0.008077978904891227, 0.05411160710666861, 0.05949914801333632, 0.04155014954241259, 0.053732241570417366, 0.14303752966225147, 0.21169464769107954, 0.13782240450382233, 0.16485314975891793, 0.15675035598022596, 0.13946743123233318, 0.15124499425292015, 0.12475972329931599, 0.1335079124463456, 0.221130884917719, 0.24227624812296458, 62.660293170383994, 70.03041417258126, 57.14562259401594, 41.24905443191528, 49.49830320903233, 65.92564078739711, 46.07667670931135, 8.219626869474139, 35.45815474646432, 77.79862526484898, 57.35053539276123, 63.661146436418804, 57.58502319880894, 69.25832339695522, 11.894335423197065, 2.1773769685200284, 0.9478716232946941, 0.2290087714791298, 2.076126732996532, 0.5293415071708816, 28.628327403749736, 65.374037197658, 59.39775262560163, 63.748804909842356, 57.231505802699495, 51.68786471230643, 54.470972606113975, 60.90257263183594, 63.39126450674874, 61.98396941593715, 66.13048757825578, 64.55645656585693, 47.42568336214338, 43.027497972760884, 46.992081029074534, 55.56362894603184, 58.05495071411133, 57.1956913130624, 55.88572311401367, 57.52217674255371, 54.61689519882202, 56.42108876364571, 54.486599104745046, 52.22512027195522, 47.56213208607265, 45.99750893456595, 47.89443663188389, 50.47709594454084, 50.349943910326274, 51.488128321511404, 49.517209257398335, 51.88848352432251, 54.8601724760873, 56.343897751399446, 55.91463109425136, 54.266104970659526, 55.25173820768084, 56.995510237557546, 56.08290951592581, 58.98591205051967, 55.679990427834646, 57.51928629193987, 57.59877020972115, 59.86273997170584, 54.97786453792027, 55.90311792918614, 56.24373252051217, 57.33033697945731, 57.932610307421, 58.07860933031355, 58.29499013083321, 57.57602528163365, 56.71360445022583, 55.93646928242275, 53.60193708964756, 56.79976211275373, 56.86097574234009, 59.19071020398821, 49.6023906980242, 51.53718260356358, 58.55127443586077, 57.45872231892177, 55.986107213156565, 60.37220273699079, 59.02913679395403, 59.84307656969343, 59.65111868722098, 58.6025174004691, 57.410043239593506, 55.177962235042024, 56.88407850265503, 57.14343043736049, 54.91595261437552, 56.86274405888149, 54.26638289860317, 56.08759260177612, 56.21190282276699, 55.73215402875628, 53.77688578196934, 54.325050013405935, 53.84685066768101, 54.88485942568098, 53.379455770765034, 51.25554779597691, 46.15154354912894, 48.450910908835276, 46.13318640845162, 47.78581544331142, 48.01842376164028, 45.68448216574532, 45.521668502262656, 45.37816735676357, 45.398518630436485, 47.781882762908936, 49.607376030513215, 52.19317940303257, 52.33376925332205, 59.203835351126536, 54.987946374075754, 59.53776577540806, 40.105957644326345, 39.24981451034546, 53.11200571060181, 51.97795895167759, 61.366941588265554, 53.22296149390084, 55.09957265853882, 48.25745568956648, 55.74538687297276, 59.14365005493164, 58.891979353768484, 53.437664304460796, 52.47795827048165, 49.63963304247175, 52.61316326686314, 61.72401646205357, 61.47297804696219, 65.11605753217424, 35.196492535727366, 4.91519433259964, 0.11186960712075233, 0.5268311447330883, 1.9372515678405762, 9.74111213002886, 76.4777866091047, 54.92816059929984, 69.3746918269566, 58.661917550223215, 73.79435757228306, 16.520486865724834, 22.69663289615086, 31.874072415488108, 32.204289027622764, 50.24203143801008, 40.345847674778526, 59.09294210161482, 64.91517121451241, 50.30655588422503, 0.6793990379997662, 0.07893301519964423, 0.14011099455612047, 0.16268879946853432, 0.1481434242533786, 0.104946568608284, 0.11355442992810692], [0.047463086899369955, 0.0078873843553343, 0.019807953720114062, 0.05045148065047605, 0.11320152386490788, 0.07132285820054156, 0.028081237903929183, 0.11554312785821301, 0.11117159136171852, 0.2270121821867568, 0.2348409699542182, 25.01636368887765, 59.71117891584124, 36.71599408558437, 23.918897458485194, 36.59363283429827, 19.52077807698931, 18.049865279878887, 11.148462806429182, 15.537073578153338, 67.82367324829102, 43.073366505759104, 45.35875061580113, 50.80666637420654, 57.87926551273891, 23.87838772365025, 0.8853676915168762, 0.7093122814382825, 0.10365181522709982, 0.5158392031277929, 0.03169435715036733, 15.577994993754796, 51.80605704443795, 54.154489108494346, 60.210219383239746, 52.08045877729143, 48.841663701193674, 47.77977745873587, 53.341483865465435, 54.61692646571568, 57.64045245306832, 53.02112327303205, 54.24396106175014, 56.44793660300118, 49.85904673167637, 43.239553519657676, 56.0180515561785, 58.97956139700753, 56.03714868000576, 54.33628525052752, 55.38454607554844, 51.72251190458025, 52.21642460141863, 50.56050212042672, 48.78219059535435, 46.79018027441842, 43.728289808545796, 42.42615570340838, 44.50355591092791, 47.5144396509443, 46.19820417676653, 46.686968258449006, 45.72917992728097, 48.525538035801475, 48.87310777391706, 47.479417255946565, 47.74889966419765, 50.25725841522217, 49.36849348885672, 49.11604806355068, 50.74263177599226, 51.482976232256206, 48.98847566332136, 47.74351828438895, 48.55255610602242, 49.20692007882254, 49.21802677427019, 50.37362337112427, 51.40170315333775, 49.93101617268154, 53.561165060315815, 50.38912827627999, 52.08489867619106, 52.274018219539094, 49.90737492697579, 49.589387144361226, 53.01192038399832, 52.53709091459002, 50.16351679393223, 43.359597546713694, 52.64864076886858, 54.30589035579136, 48.08789879935128, 48.06570972715105, 48.92410407747541, 53.409048148563926, 52.07091890062605, 52.88164166041783, 51.813592365809846, 49.76745557785034, 48.439640930720735, 51.25868490764073, 49.99487706593105, 49.69367960521153, 48.84101404462542, 51.875803061894004, 50.73732335226876, 50.03752163478306, 49.00169461114066, 50.70694235392979, 46.66967419215611, 48.29776218959263, 50.74656793049404, 47.965381213596885, 45.86067805971418, 44.47640929903303, 45.478259631565635, 41.46151992252895, 42.40252488000052, 42.58558906827654, 44.60985292707171, 42.544063159397666, 41.046114921569824, 40.6954254422869, 43.812411648886545, 46.915640422276084, 50.44972004209246, 48.12225069318499, 49.40074355261666, 50.41708435331072, 51.56940834862845, 45.45860317775181, 41.314912932259695, 53.53624882016863, 54.81818103790283, 50.774235657283235, 52.11299024309431, 48.04060935974121, 49.376695837293354, 50.05482612337385, 54.76047624860491, 53.39324794496809, 51.47031314032418, 44.869500160217285, 46.11851181302752, 47.55135195595877, 57.75957236971174, 57.28690379006522, 59.60846369607108, 18.76500514575413, 0.701784071113382, 0.1776024020676102, 0.27247805893421173, 0.25577678797500475, 21.164518628801616, 67.7255368913923, 45.026466914585654, 61.54997798374721, 53.46360192980085, 57.545453207833425, 19.481600659234182, 17.641952174050466, 36.89116859436035, 25.654712063925608, 56.61061825071062, 44.70634603500366, 33.12009286880493, 54.7155248778207, 15.198597294943673, 0.36395416036248207, 0.07866521778383426, 0.05820792301424912, 0.08621265100581305, 0.03954155357288463, 0.022088026461590613, 0.08913934896034853, 0.021186241547444036, 0.0331259133693363, 0.04330391829301204, 0.04503621480294636, 0.047672950995287726, 0.11170401743480138, 0.07834264223596879, 0.10570536753428833, 0.15932931830840452, 0.1362698349569525, 0.22526715296719754, 26.329979692186626, 68.8506031036377, 41.06485768726894, 26.86777721132551, 45.52321100234985, 21.85163640975952, 16.692164693559917, 12.043596625328064, 19.397713320595876, 75.76174695151192, 46.27423831394741, 53.59669467381069, 58.680448395865305, 62.86948953356062, 25.38588626044137, 0.4376535942511899, 0.7654092684388161, 0.10308544883238417, 0.9370331934520176, 0.04276805204738464, 17.725167274475098, 58.29203714643206, 57.244651794433594, 62.72618293762207, 54.66598769596645, 53.22114453996931, 49.90280301230294, 55.65840237481253, 57.62446117401123, 60.73784473964146, 54.54905298777989, 55.419287068503245, 57.47625262396676, 50.764324051993235, 45.24074241093227, 58.51290648324149, 59.20095879690987, 59.36324092320034, 54.31949840273176, 57.72512667519705, 52.790425709315706, 54.38324812480381, 52.09297595705305, 52.300233772822786, 47.68956552233015, 44.61657530920846, 43.78836740766253, 47.878379344940186, 47.11082574299404, 47.95674112864903, 47.58049617494856, 47.77254090990339, 48.222339493887766, 52.85319920948574, 50.855390616825645, 52.558595589229036, 54.206103801727295, 52.95207207543509, 52.08481182370867, 53.568342549460276, 53.94860356194632, 51.8105594771249, 53.616663796561106, 50.87821544919695, 52.36898619788033, 52.08656276975359, 54.02293539047241, 55.404331071036204, 51.431431021009175, 54.459938866751536, 54.382511615753174, 53.45639664786202, 53.19211496625628, 50.126938002450125, 51.23923689978463, 54.35378081457955, 53.05294949667794, 51.7512218611581, 47.15655878611973, 53.75334528514317, 56.24977397918701, 50.28803893498012, 51.49699074881417, 51.3108936718532, 55.1470114844186, 54.55364922114781, 55.32283912386213, 52.66995436804635, 54.48128720692226, 51.498046875, 53.44254541397095, 54.24005964824131, 54.30786711829049, 51.56250878742763, 53.80341400418963, 54.1560628754752, 52.666306563786094, 50.643824917929514, 52.52580009187971, 47.166946343013215, 50.57743488039289, 51.8929442678179, 48.276372160230366, 46.40710871560233, 45.767193521772114, 46.8664402280535, 43.92393718447004, 45.58481025695801, 44.07239586966378, 45.50000054495675, 43.959397315979004, 43.06515720912388, 42.53923416137695, 45.77897419248308, 48.50987332207816, 51.61125040054321, 51.46828774043492, 51.25403656278338, 52.16766561780657, 53.661674227033345, 47.92792000089373, 43.90958220618111, 53.52186952318464, 56.83279037475586, 54.59987211227417, 54.50967754636492, 49.59811755589077, 49.645441736493794, 52.3379624911717, 57.162527561187744, 56.48130532673427, 54.71604251861572, 48.59447111402239, 48.416454792022705, 50.785297189440044, 60.38740539550781, 60.208544867379324, 63.52514239719936, 20.70532086917332, 1.2773836446659905, 0.24759278712528093, 0.10746273930583682, 0.03514518608738269, 24.6849102973938, 72.38779204232353, 49.277034350803916, 66.83657741546631, 58.461712156023296, 63.735116958618164, 22.612314769199916, 20.38528163092477, 38.86924777712141, 25.356639555522374, 63.42395578111921, 39.95130116598946, 35.18682411738804, 64.39032513754708, 18.066817147391184, 0.36964867051158634, 0.05045789619907737, 0.11639846196132046, 0.06043397927922862, 0.016497337259352207, 0.012114798317530324, 0.07807373880807843, 0.12685448303818703, 0.19192721268960408, 0.1955619483653988, 0.09574756758021456, 0.22276087531021663, 0.2597287930548191, 0.18134381701903685, 0.22941192984580994, 0.370978626289538, 0.3144817650318146, 0.3476259750979287, 33.92078937802996, 79.04594503130231, 51.64925357273647, 36.08051184245518, 50.4901932988848, 31.72714580808367, 24.06633996963501, 20.316732440676006, 22.14263912609645, 78.63968385968889, 53.18143905912127, 57.74793413707188, 59.93887833186558, 70.96084744589669, 26.822025060653687, 2.74001864024571, 1.8047739565372467, 0.1829650407390935, 2.3438197629792348, 0.1305736963238035, 19.685377427509852, 61.77491201673235, 58.443987301417756, 66.62382357461112, 56.90593753542219, 54.1308582850865, 51.38004214423043, 58.109890120370046, 59.731002126421245, 65.08531175340924, 56.227498054504395, 58.560849053519114, 58.96810381753104, 50.03900507518223, 44.397255420684814, 61.30487333025251, 63.775103841509136, 61.543008940560476, 56.83438846043178, 60.9101322719029, 56.11680282865252, 56.803416865212576, 54.04069151197161, 54.68996940340315, 50.39064645767212, 47.20597090039934, 46.09061132158552, 51.393698828560964, 50.20357663290841, 51.46874632154192, 51.927598408290315, 51.54729223251343, 50.28140687942505, 55.95563588823591, 53.793123722076416, 54.055275780814036, 56.29207113810948, 55.968597752707346, 53.91328239440918, 59.34125682285854, 59.56165368216378, 55.450672081538606, 56.50722558157784, 53.39851120540074, 55.61478158405849, 56.37764515195574, 56.36254671641758, 57.51016330718994, 55.11617885317121, 58.05255011149815, 56.2341822215489, 59.10922867911202, 58.16751153128487, 53.97789716720581, 53.987968581063406, 57.857462065560476, 57.01653896059309, 54.60746996743338, 51.267060961042134, 58.92041138240269, 57.78809125082833, 50.49309417179653, 52.86341306141445, 53.87888881138393, 58.22620643888201, 58.948655809674946, 59.351644379752024, 57.079218660082134, 58.768857274736675, 54.83840376990182, 58.41915443965367, 56.229255948747905, 56.23937252589634, 53.70109830583845, 58.554366384233745, 57.20817722593035, 55.841126101357595, 52.246784755161826, 56.680002961839946, 51.407557010650635, 53.55006183896746, 55.660000460488455, 53.174355370657786, 51.65333563940865, 47.659462451934814, 48.64412294115339, 46.46603986195156, 47.88798175539289, 46.19032144546509, 49.9936854498727, 46.142392771584646, 46.18437726157052, 45.37267827987671, 47.85304968697684, 51.514986583164756, 55.689165524074006, 51.53602225439889, 53.61691740580967, 54.239024366651265, 56.20527424131121, 49.20168808528355, 44.42932135718209, 56.373875754220144, 58.07358578273228, 54.21123504638672, 57.27963250023978, 50.82536745071411, 51.01746777125767, 52.996693406786235, 60.15300791604178, 59.00208050864083, 57.99090569359915, 50.04573440551758, 49.79620374952044, 53.23747280665806, 62.972920417785645, 63.741335596357075, 66.1619212286813, 24.95735090119498, 2.7245239402566637, 0.4319323498223509, 0.7303375846573285, 1.7572795450687408, 25.544965267181396, 79.12209033966064, 53.66756282533918, 73.57491956438336, 61.95596817561558, 69.20810181753976, 28.044122866221837, 27.368624210357666, 45.41409649167742, 38.4027214050293, 77.92054530552456, 57.83580800465175, 44.224936621529714, 73.08565521240234, 30.48528732572283, 0.4125688602881772, 0.16235338603811605, 0.24341833112495287, 0.268013949905123, 0.20583172515034676, 0.09855364914983511, 0.29954563507011955], [0.083495077544025, 0.050516949101750336, 0.01405934227763542, 0.05544352724349924, 0.03699131023937038, 0.08321729887809072, 0.07349460452262845, 0.072521490310984, 0.08231203138296093, 0.225333500121321, 0.3212993049195835, 9.574397921562195, 54.03320830208914, 40.456424781254356, 31.386388778686523, 36.89035218102591, 44.95279516492571, 65.9586238861084, 17.067900691713604, 19.17891107286726, 52.15701750346592, 57.69182048525129, 43.817977155957905, 38.09909554890224, 56.33095325742449, 36.69319009780884, 0.1517230086028576, 0.617271286036287, 0.13848180483494485, 0.0677685085684061, 0.10106872062065772, 7.815680316516331, 49.46319743565151, 53.75609677178519, 60.80784784044538, 54.31006274904524, 53.44380303791591, 46.01488637924194, 51.702362128666465, 53.864012718200684, 53.889328479766846, 56.41983808789934, 61.10937186649868, 52.42900473730904, 50.917194843292236, 44.50733225686209, 48.33845084054129, 55.58962910515921, 55.590028626578196, 51.98719310760498, 51.26338536398751, 52.967438016619, 51.24876288005284, 50.60212182998657, 50.81944758551461, 47.60459252766201, 45.39905364172799, 41.868760790143696, 44.19859600067139, 45.92965630122593, 47.25825956889561, 46.53975330080305, 45.302897521427695, 46.83962712969099, 47.22183016368321, 51.69621297291347, 49.18063851765224, 49.18084348951067, 49.616141183035715, 52.28456211090088, 50.881640911102295, 52.09626592908587, 51.8850337437221, 51.14336218152727, 49.8145226751055, 50.254614625658306, 49.39340625490461, 49.354604039873394, 51.83331830160958, 50.77719906398228, 51.44330201830183, 51.60921457835606, 52.282783372061594, 50.72102287837437, 49.63184411185128, 49.039906229291645, 50.494831221444265, 50.937876156398225, 49.93576526641846, 37.80221291950771, 50.57515239715576, 55.00262791769845, 51.83515957423619, 46.63603796277727, 52.71978684834072, 54.66876350130354, 53.076469148908345, 53.26162127086094, 52.57936722891671, 50.9653319631304, 50.1446350642613, 51.09017024721418, 50.1636974470956, 51.32993868419102, 51.88256713322231, 51.88136509486607, 49.600268023354666, 50.28578771863665, 49.81012099129813, 49.21339232581002, 48.6200578553336, 48.67025859015328, 47.08969974517822, 48.01746491023472, 44.45955296925136, 45.09605312347412, 43.69786017281668, 43.76436832972935, 45.470053809029714, 43.16348116738455, 41.36814655576433, 40.433471407209126, 41.67329406738281, 43.22793960571289, 47.04334136417934, 48.16135515485491, 48.00141109739031, 51.38655260631016, 51.500391892024446, 51.507767404828755, 51.717609950474326, 53.95243549346924, 49.51989473615374, 44.286490712847026, 48.8673164503915, 54.67872721808297, 53.26538372039795, 46.492008754185264, 47.12550033841814, 50.02469178608486, 55.715301173073904, 53.96556411470686, 54.278726373400005, 47.83498437064034, 44.5803439276559, 51.613060406276155, 56.808270181928364, 58.186775411878315, 53.52569798060826, 17.445276464734757, 0.42806103612695423, 0.14090963027306966, 0.2301733275609357, 0.16771423337715013, 39.02926826477051, 59.17889131818499, 50.16483000346592, 61.12913949148995, 45.16052198410034, 70.76734011513847, 12.005493572780065, 18.3335793358939, 33.1755325453622, 27.375640153884888, 60.471471650259836, 33.76560483660017, 41.053514753069194, 51.248196601867676, 5.742797306605747, 0.3823594498847212, 0.09152247929679495, 0.10008740292063781, 0.13286508194037847, 0.1170369227017675, 0.10373562787260328, 0.05806276401770966, 0.06533668655902147, 0.06670499313622713, 0.03861075619767819, 0.07767799004380192, 0.06097237646047558, 0.06769855160798345, 0.07605711237660476, 0.22346972727349826, 0.10925156796084982, 0.2286653241940907, 0.3178343522761549, 10.988120096070425, 64.53556333269391, 47.70771074295044, 34.27543238231114, 52.899915422712056, 46.02450616019112, 65.23409352983747, 24.777967521122523, 17.06143191882542, 62.739752769470215, 59.06100818089077, 49.27798277991158, 44.80541345051357, 62.61082894461495, 38.56982558114188, 0.5164916281189237, 0.02301650833604591, 0.12097896688750812, 0.3457544669508934, 0.0674934983253479, 9.083789093153817, 55.42859418051583, 54.43954937798636, 63.29920782361712, 55.729235785348074, 56.68397733143398, 50.13504655020577, 55.06072180611746, 55.75115735190255, 57.58554431370327, 60.673379353114534, 64.01203046526227, 53.66323757171631, 52.413246222904746, 44.33402681350708, 51.18248748779297, 57.0536527633667, 57.256752082279746, 53.08084303992135, 53.92323221479143, 55.03744534083775, 54.771002769470215, 52.22990410668509, 51.252348150525776, 49.42237329483032, 47.332782472882954, 42.67235817228045, 45.7866484778268, 48.24278456824166, 48.9363363810948, 48.14517627443586, 46.904881136757986, 48.39198671068464, 51.776513304029194, 52.914680344717844, 49.07625920431954, 50.72105414526803, 52.87735114778791, 52.73643125806536, 52.776129790714805, 54.4827880178179, 54.81060402733939, 57.16384424482073, 52.90252794538225, 55.71973759787423, 50.73956414631435, 54.23663418633597, 52.70739473615374, 54.13564906801496, 52.916222844805034, 53.56943689073835, 53.468177318573, 53.60236440386091, 49.22199419566563, 49.63792725971767, 52.34074524470738, 50.69238240378243, 51.038823059626985, 40.511367661612375, 52.67126757758004, 55.44790669849941, 52.51316131864275, 49.35692473820278, 53.12432139260428, 55.2064220564706, 54.20591272626604, 53.25647612980434, 53.54361391067505, 54.10443081174578, 52.596550124032156, 53.97123384475708, 53.0452196257455, 53.82540157863072, 54.01140832901001, 56.16932078770229, 51.84990017754691, 51.48964997700283, 50.21640995570591, 52.052196979522705, 51.067053590502056, 50.91577046258109, 50.064161028180806, 49.00349766867501, 47.50011593954903, 47.67663492475237, 44.31338024139404, 45.14990513665335, 47.1706462587629, 45.07363476072039, 43.035550934927805, 41.26273543494088, 43.41852174486433, 44.629196711948936, 47.05375323976789, 48.8341110093253, 49.731220722198486, 53.975604261670796, 52.263790471213206, 52.458996636526926, 53.45980126517159, 55.25190496444702, 50.13031135286604, 44.69395392281668, 51.99712903159005, 54.83490187781197, 57.402709415980745, 48.62861108779907, 48.37038823536464, 50.74530335835048, 58.57389082227434, 55.74783958707537, 55.353678703308105, 49.5577380997794, 48.51092250006539, 55.180501801627024, 59.81667341504778, 61.44456686292376, 56.66629764011928, 21.17519106183733, 0.6934488383787019, 0.25874081892626627, 0.06465465708502702, 0.613470621407032, 44.34360490526472, 64.50929914202008, 54.34407070704869, 67.25658212389264, 49.15573269980294, 74.9305339540754, 14.859815290996007, 22.148885556629725, 32.29259368351528, 28.06032085418701, 70.85025991712297, 34.52923270634243, 47.00349344526018, 58.191354274749756, 6.4513502802167615, 0.6299751986350332, 0.12219395169189998, 0.12475246297461645, 0.022239243079509054, 0.014024642844950514, 0.02616387775300869, 0.05510771008474486, 0.3382965257125241, 0.2184077746101788, 0.08777436720473425, 0.2164625504187175, 0.12064124643802643, 0.1641358703907047, 0.20964727683791093, 0.4609673246741295, 0.23992756700941495, 0.5128235763737133, 0.49883592980248587, 16.946293319974625, 78.17624596187046, 52.69377279281616, 48.486642020089285, 49.3117857660566, 64.3370532989502, 74.81768826075962, 29.260337284633092, 26.994774648121425, 65.82667064666748, 67.04284163883754, 54.870355061122346, 49.01979466847011, 69.81019796643938, 42.71130977358137, 1.1534383126667567, 2.3001079942498888, 0.46313027718237465, 1.4539445361920764, 0.16515382219638142, 10.512545432363238, 60.22815268380301, 56.92669527871268, 66.97771617344448, 59.255182538713726, 59.99751417977469, 52.439305441720144, 57.28885970796858, 58.15141255514962, 58.58236762455532, 62.09000587463379, 69.36155973161969, 55.7356732913426, 54.91067198344639, 44.93986109324864, 54.724825041634695, 59.23682539803641, 60.479573249816895, 55.897507258823936, 56.69083520344326, 56.390968322753906, 58.127031326293945, 52.980031626565115, 55.39211961201259, 51.27591644014631, 49.81861168997628, 46.49730328151158, 49.55952378681728, 49.98956864220755, 51.40290519169399, 50.74310425349644, 50.75272056034633, 50.414628165108816, 55.45293024608067, 56.625404017312185, 52.688492161887034, 52.93456261498587, 55.500424657549175, 56.613390581948416, 54.81088890348162, 58.118901933942524, 61.56554889678955, 59.57559176853725, 57.30649423599243, 58.634201186043875, 55.03154979433332, 56.54530865805489, 57.90900380270821, 59.38249438149588, 56.46742977414812, 57.9815742628915, 57.745342458997456, 56.88198709487915, 54.26479523522513, 54.28497627803257, 54.9645483153207, 53.97764008385794, 55.86373553957258, 41.235738209315706, 54.63473469870431, 60.16116510118757, 54.89094257354736, 53.65694597789219, 55.999885490962434, 60.20603656768799, 58.13856881005423, 58.98463358197893, 57.908044951302664, 59.01169681549072, 55.75676107406616, 57.79160009111677, 54.84114136014666, 56.48032563073294, 59.335156304495676, 61.24065807887486, 53.43175833565848, 55.31969158990042, 54.83371720995222, 55.670711108616416, 56.18372092928205, 53.995625495910645, 52.35727848325457, 52.071912493024556, 50.07286017281668, 50.3889719418117, 47.45367070606777, 47.290797982897075, 50.16130379268101, 47.489502566201345, 46.122145720890586, 44.959111077444895, 47.40446008954729, 47.63781533922468, 50.58987562997, 53.89461258479527, 51.57230922154018, 56.708188329424175, 55.52432993480137, 56.22829362324306, 54.948939187186106, 58.56276675633022, 53.64696489061628, 46.295930589948384, 53.590149470738, 58.24539736339024, 57.43699530192784, 49.249922479902, 51.06889138902937, 52.86801624298096, 59.94925199236189, 59.21467454092843, 59.039447920663015, 52.360637937273296, 50.327803475516184, 58.025862080710276, 62.30000128064837, 62.5540691103254, 58.6319499697004, 27.099195650645665, 1.2792412021330424, 0.5706962080938476, 0.6552645244768688, 0.5753556809255055, 46.36235189437866, 71.67483043670654, 57.422654220036094, 72.77278477805001, 52.80366897583008, 82.45646830967495, 18.234890597207205, 27.70037637438093, 39.895222255161826, 42.88484798158918, 76.46275070735386, 47.40538419995989, 56.73475824083601, 69.05825696672711, 13.537739855902535, 0.9366113075188228, 0.35367633615221294, 0.24257388072354452, 0.3838611293051924, 0.24987451040319034, 0.21014788640396936, 0.2303427713257926], [0.08727425296923944, 0.08424935064145497, 0.01816229086502322, 0.019296150022585477, 0.028087882458099296, 0.06244938434766872, 0.03309937925743205, 0.09541497007012367, 0.07304072566330433, 0.05178913101553917, 0.06313408724963665, 1.2970742966447557, 46.620647702898296, 43.83393021992275, 30.26255934579032, 32.27934694290161, 31.335204873766216, 39.60987710952759, 25.38029817172459, 6.730458114828382, 54.1857316834586, 52.25032486234392, 49.910800388881135, 43.66598183768136, 52.17253630501883, 48.981704643794465, 1.5637879563229424, 0.4759619172130312, 0.14676241550062383, 0.30723235117537634, 0.14121396679963383, 3.585128251995359, 48.834305558885845, 52.544709614345, 59.53747395106724, 54.53906842640468, 55.34254421506609, 49.99489096232823, 51.71405594689505, 50.92044660023281, 54.77424757821219, 51.92249148232596, 55.86164065769741, 56.554025173187256, 59.27902180807931, 46.46283674240112, 49.29425893511091, 54.636277198791504, 57.083054065704346, 55.590087686266216, 56.4670649937221, 53.20364202771868, 55.311642101832796, 52.07980564662388, 52.090894971575054, 50.122685704912456, 46.495562757764546, 42.83706521987915, 44.261828081948416, 45.93806709562029, 45.992798055921284, 46.94811977658953, 44.82129355839321, 45.93574292319161, 47.28397832598005, 49.930738244737896, 48.82762834003994, 50.2812123298645, 48.46129151753017, 51.77560656411307, 50.17474855695452, 52.399801458631245, 48.56104333060128, 50.6981702532087, 51.10083225795201, 51.55736364637102, 50.14177935464041, 49.759558950151714, 51.52218491690499, 50.94097852706909, 50.48880018506731, 51.18020153045654, 51.615811892918174, 51.46540423801967, 48.99544470650809, 47.97434786387852, 49.52744395392281, 51.16028799329485, 48.4580397605896, 43.70256757736206, 48.87992395673479, 52.179967403411865, 48.9112742287772, 48.78112404687064, 50.994076660701204, 52.77560520172119, 53.23310586384365, 52.55150147846767, 51.006263801029746, 49.604888575417654, 48.92839111600603, 48.62837832314627, 50.1276467187064, 50.456876686641145, 49.527259826660156, 49.74335922513689, 47.60191747120449, 48.84756966999599, 48.69210720062256, 49.20004136221749, 49.38617665427071, 47.70248222351074, 46.62554965700422, 45.42716257912772, 44.77927085331508, 44.67115340914045, 41.14882319314139, 43.6339784349714, 44.53602136884417, 41.358346121651785, 40.30981084278652, 41.768394061497276, 41.55204105377197, 43.63456555775234, 45.32068838391985, 47.93550048555647, 50.29192645209176, 54.54329987934658, 52.83033616202218, 52.46344348362514, 50.74739129202706, 52.0061616897583, 40.046831948416575, 48.971122537340435, 61.48106575012207, 52.87541954857962, 56.573455810546875, 46.75065892083304, 47.56427213123867, 49.574128900255474, 48.67942673819405, 56.690206391470774, 53.472874300820486, 51.47446468898228, 48.81859220777239, 54.458024638039724, 54.98842232567923, 57.16211414337158, 51.56856066840035, 12.140859246253967, 0.6491172686219215, 0.18992286095661776, 0.3343581184744835, 5.2096068773950845, 45.21380771909441, 54.34660332543509, 50.381638118198936, 49.451917035239084, 52.06462730680193, 63.1867025920323, 11.551317623683385, 27.609294176101685, 23.492646319525583, 35.95955065318516, 47.38599872589111, 22.585689272199357, 49.92948409489223, 39.17472185407366, 1.3394916376897266, 0.19609093426593713, 0.08468401338905096, 0.10267269598054034, 0.06438424052404505, 0.04116838877754552, 0.06531119399837085, 0.060020588604467254, 0.02185309897842152, 0.039001962170004845, 0.03812651628894465, 0.03310545893119914, 0.02686770516447723, 0.11908812049244132, 0.004783857630432716, 0.07026459462940693, 0.029437553071017777, 0.10064961668103933, 0.09487350591059242, 1.8285430925233024, 53.85534484045846, 53.918097496032715, 32.11753729411534, 40.87208686556135, 41.9406225340707, 43.39852482931954, 34.28743886947632, 6.051534865583692, 58.20166540145874, 60.53904982975551, 50.486159869602744, 43.79333189555577, 59.090829849243164, 52.44557271684919, 1.8937358685902186, 0.6138729112488883, 0.40301489723580225, 0.4906992092728615, 0.11459374880152089, 4.38458776473999, 54.712304387773784, 56.233199051448274, 63.5548528943743, 56.34996700286865, 57.240486349378315, 51.08818653651646, 53.875418186187744, 53.248280729566304, 59.98279789515904, 54.11056954520089, 58.082979747227256, 57.02586691720145, 59.95087092263358, 46.32520682471139, 50.64431824002947, 56.11441959653582, 58.53187506539481, 55.06378596169608, 57.10673352650234, 53.34484331948416, 54.670622144426616, 53.61344678061349, 53.447621073041645, 51.29433958871024, 49.342163290296284, 44.70172200884138, 45.66486740112305, 46.10896151406424, 46.5719165120806, 47.85057612827846, 46.056450503213064, 46.23259775979178, 50.430449213300435, 50.157902649470735, 50.37597186224801, 52.20789916174752, 51.751277446746826, 55.0645363671439, 52.51092747279576, 55.974899768829346, 52.77693578175136, 53.02759552001953, 52.286983558109824, 53.588141441345215, 55.05374581473214, 52.63125985009329, 52.38327864238194, 52.472038405282156, 52.09168359211513, 53.5139798436846, 53.54111950738089, 54.08364527566092, 51.39299358640398, 48.737749917166575, 51.43666301454817, 53.35794414792742, 50.009621143341064, 44.17211294174194, 49.91005693163191, 55.331906523023335, 51.67110913140433, 52.78148685182844, 52.965350082942415, 55.298245974949424, 54.63226114000593, 55.673719678606304, 54.69884920120239, 53.14695167541504, 52.95673084259033, 52.17378698076521, 53.06766925539289, 54.02357462474278, 53.67624807357788, 55.07762677328927, 50.47486904689244, 51.81689970833914, 51.56210231781006, 50.282817363739014, 50.4632898739406, 50.33699246815273, 47.747367586408345, 48.72915846960885, 47.90212828772408, 45.15204518181937, 41.95543609346662, 44.51758432388306, 44.48314210346767, 45.15436935424805, 43.26483106613159, 42.21302318572998, 43.765744073050364, 45.89733675548008, 47.38585976191929, 48.804841722760884, 51.03361538478306, 55.14561142240252, 54.822676522391184, 55.41702195576259, 53.26205553327288, 54.285775320870535, 42.75625767026629, 48.549120221819194, 63.80553000313895, 54.63408156803676, 57.80728217533657, 51.85516343797956, 47.26169545309884, 52.426187242780415, 49.069324902125764, 60.178660665239605, 55.72082846505301, 56.110473019736155, 49.91553558622088, 57.82333946228027, 58.143640995025635, 61.227894238063264, 52.4198956489563, 13.621464780398778, 1.0171305068901606, 0.8116181546023914, 0.5303323854293142, 7.8919758796691895, 54.636468274252756, 61.06106104169573, 53.44633565630232, 57.301463740212576, 56.41099303109305, 68.64287281036377, 13.043588314737592, 33.79384231567383, 26.165715592248098, 38.24634872164045, 50.89523506164551, 22.7320339679718, 54.68111392429897, 45.86490603855678, 1.6272125244140625, 0.19784696932349885, 0.012005972326733172, 0.12368660659662314, 0.09545505113367524, 0.029436131540153707, 0.034022451511451175, 0.03687611874192953, 0.1535312230033534, 0.2159322617309434, 0.1352290300918477, 0.1172402525054557, 0.12984408118895122, 0.1829745809414557, 0.1415015570819378, 0.14912550869796956, 0.13724365484501633, 0.19521467414285454, 0.19611000109996113, 3.397120637553079, 71.49312809535435, 61.8784818649292, 48.38618843896048, 42.483857018607004, 45.32667078290667, 50.540348870413645, 35.66550983701433, 12.846453155790057, 67.18912206377301, 64.06694902692522, 59.15954753330776, 52.56125327519008, 63.1493421282087, 57.47233731406075, 2.453134902885982, 1.159823164343834, 1.0775460707289832, 1.2575266701834542, 0.27163976963077274, 5.033323696681431, 59.781133379255024, 59.85955769675118, 65.51141003199986, 60.79532718658447, 61.64889253888811, 52.58718047823225, 57.140335014888215, 56.266970770699636, 61.8156076158796, 56.449253286634175, 61.81152902330671, 59.37298229762486, 62.808595521109446, 46.49501385007586, 53.01193428039551, 58.105405058179585, 60.939794131687705, 58.377673694065635, 58.669324329921174, 57.37193584442139, 59.50130162920271, 56.231048583984375, 56.4690591267177, 53.985001700265066, 50.93884890420096, 46.64163473674229, 48.800631114414756, 48.84203890391758, 49.932770592825754, 50.375867639269146, 49.44940526144845, 50.697419847760884, 51.753188201359336, 51.9951731136867, 54.86988953181675, 54.27701016834804, 54.61697162900652, 57.085221903664724, 56.73866660254342, 59.19762366158621, 54.954932008470806, 55.86415590558733, 56.03837503705706, 57.238839626312256, 56.25174379348755, 56.60750545774187, 57.17190762928554, 57.09348678588867, 56.02338777269636, 58.21473148890904, 57.950185775756836, 59.655850410461426, 54.66617182322911, 52.41669600350516, 54.167763641902376, 56.558406012398855, 52.738460132053916, 47.466288634708945, 52.499185017177034, 56.6220132963998, 55.15988997050694, 56.94940199170794, 56.065709250313894, 58.04961797169277, 58.42895139966692, 59.81562423706055, 57.274195534842356, 57.77518844604492, 56.250444480351035, 53.61706679207938, 57.24699681145804, 56.17112731933594, 57.431325571877615, 57.93666458129883, 54.874298163822715, 55.66193553379604, 52.8818917955671, 53.459606715611045, 53.76544557298933, 52.854387351444785, 49.8423502104623, 51.04088320050921, 50.41200869424002, 47.04325451169695, 44.641081605638774, 46.587167807987754, 46.02653503417969, 47.98945672171456, 44.806959424700054, 45.042037827628, 45.48316158567156, 49.237572056906565, 49.63913624627249, 52.62230362210955, 53.68370349066598, 58.253978388650076, 56.675278186798096, 57.74751724515642, 55.001109736306326, 57.00106879643032, 44.04448843002319, 49.7805564062936, 63.813520431518555, 57.00424412318638, 58.78965323311942, 50.93976606641497, 49.52775662285941, 52.31927531106131, 51.360625403267996, 60.923563139779226, 58.67290265219552, 56.82819414138794, 51.73420224870954, 60.62156663622175, 60.09843676430838, 63.152142252240864, 56.96366664341518, 19.700802428381785, 2.9678654883589064, 1.1648483404091425, 0.7514119052461216, 7.891418286732264, 54.39638022014073, 65.05553872244698, 58.4278952734811, 61.54655947004046, 60.86444091796875, 74.98363208770752, 16.856484379087174, 39.01445123127529, 29.323089940207346, 53.88561814171927, 57.36622789927891, 33.01929187774658, 63.6192626953125, 58.697040694100515, 3.9866527063505988, 0.46693810714142664, 0.19317810556718282, 0.3299421854317188, 0.28587738850287026, 0.1595565868275506, 0.15481118432113103, 0.10252236654715878], [0.007641328049690596, 0.03208590239020331, 0.051988956185856035, 0.045755943682576926, 0.045282831748149226, 0.05774463287421635, 0.08283031678625516, 0.055784277351839204, 0.07317371174160923, 0.06595269457570144, 0.02376222680322826, 0.1585787907242775, 30.379817145211355, 54.39446946552822, 42.85440444946289, 26.453086137771606, 32.581683908190044, 43.36321060998099, 32.29759986060006, 3.344890811613628, 42.46550335202898, 62.66929803575788, 54.83587809971401, 63.59126145499093, 47.07289900098528, 58.83050169263567, 6.935970629964556, 0.489085707281317, 0.8330207775746072, 0.433343132691724, 0.04709445239443864, 0.7314037531614304, 41.82623781476702, 51.4336370740618, 62.37440953935896, 55.924365520477295, 56.542901107243125, 53.479099886757986, 53.90195683070591, 49.31686837332589, 54.99195201056344, 56.7419878414699, 58.43976974487305, 51.49524327686855, 54.733333110809326, 49.226062365940635, 42.47272947856358, 61.31945759909493, 56.70667014803205, 54.53371483939034, 55.14949893951416, 55.07064035960606, 52.98430129459926, 55.49089520318167, 55.16347524097988, 49.179836000714985, 50.322418621608186, 48.15846470424107, 43.78596680504935, 45.03394317626953, 44.684122221810476, 43.99757766723633, 44.789064339229036, 44.85158770424979, 46.73969118935721, 49.043745109013145, 49.45764582497733, 53.04796763828823, 51.55423348290579, 52.36106525148664, 53.051841259002686, 52.36684962681362, 51.60116856438773, 48.439470699855256, 48.876845904758994, 50.038932119097026, 50.685173647744314, 47.135630811963765, 49.93370859963553, 51.748188972473145, 50.12992920194353, 53.72692128590175, 50.45475401197161, 49.45222970417568, 45.38372591563633, 46.220733710697715, 50.6416779245649, 49.99558230808803, 50.1125031198774, 41.93845469611031, 46.56950896126883, 51.18102489198957, 52.37325586591448, 47.25052969796317, 49.68859352384295, 52.79715851375035, 51.889129706791465, 52.022972856249126, 51.711273193359375, 47.879536220005576, 48.10666240964617, 48.368192604609895, 50.06358085359846, 49.53855759756905, 48.06316668646676, 48.023926734924316, 49.735240255083355, 51.82789175851004, 50.586078439440044, 49.934827259608674, 50.03091389792306, 49.2952629498073, 47.99103396279471, 44.7865560395377, 47.161696978977744, 44.416352544512065, 44.515239306858604, 43.805515561785015, 44.440664291381836, 41.207465989249094, 40.49130473818098, 41.84771817071097, 45.01427282605852, 42.246186937604634, 44.21170725141253, 45.195311614445274, 49.9897631917681, 48.920709882463726, 53.51862818854195, 44.15379054205758, 44.58684744153704, 42.84068175724575, 47.095654351370676, 45.46366146632603, 37.15809406552996, 62.85769149235317, 50.28326899664742, 54.59091935838972, 38.284973757607595, 52.770574705941335, 49.48565053939819, 57.16320153645107, 54.446671281542095, 53.764893191201345, 51.31579910005842, 58.49728693280901, 54.74894223894392, 59.2668833051409, 42.0086419241769, 3.637766935995647, 0.6919171405690057, 1.0263105971472604, 0.20128733185785158, 25.53329576764788, 49.21313524246216, 48.987954548427034, 57.23392377580915, 49.18823984691075, 49.62708459581648, 62.82928030831473, 16.516073022569927, 24.542482648577007, 18.53531333378383, 39.32219042096819, 34.977926526750835, 28.746339082717896, 54.23127365112305, 32.596855299813406, 0.14447392044322832, 0.06021246473704066, 0.07754340940820319, 0.08250147836016757, 0.057803855410643985, 0.029985775439334766, 0.05127032992563077, 0.015045241785368748, 0.054560033937117884, 0.024818771984428167, 0.026870166550257375, 0.07020860870501824, 0.0422722125825073, 0.03667841738622103, 0.045045320742896626, 0.026183173592601503, 0.033140539191663265, 0.021529544643791657, 0.04296846075781754, 0.21827296327267373, 34.31080218723842, 63.94095734187535, 44.19301659720284, 33.06619916643415, 48.55605104991368, 47.151469230651855, 39.931186131068635, 5.144650340080261, 45.96684306008475, 74.22449970245361, 59.78704629625593, 70.48918288094657, 53.78027997698103, 64.37097440447126, 7.31626204081944, 0.6983124145439693, 1.8426616149289268, 0.9689610345023019, 0.12518000788986683, 0.82060499808618, 46.13310997826712, 55.62631559371948, 63.400755746024, 58.47391319274902, 59.746718951633994, 54.80080706732613, 56.35136706488473, 50.877183641706196, 57.42612484523228, 59.527565819876536, 59.35108157566616, 52.1962366104126, 56.06784929547991, 51.450545515332905, 43.66061782836914, 59.12051255362374, 58.283483913966585, 54.96607344491141, 55.65860039847237, 56.52704184395926, 54.43324736186436, 55.960329396384104, 55.02791936056954, 52.069751603262766, 51.938291685921804, 50.03825119563511, 47.49177115304129, 46.476729665483745, 46.66077354976109, 46.11079931259155, 45.69872597285679, 46.66815948486328, 47.866821016584126, 49.22379725319998, 51.255328927721294, 54.36732285363333, 54.48316322054182, 53.993336064474924, 54.88389710017613, 55.118965080806184, 55.9127585547311, 51.331887653895784, 53.90480211802891, 53.82554054260254, 52.26391553878784, 48.449573380606516, 51.2362630707877, 53.0216235433306, 52.715239252362935, 55.3963371685573, 52.21032060895647, 51.053365639277864, 47.19479124886649, 49.56912619726998, 51.45694480623518, 52.856628145490376, 49.99261195319039, 43.21402931213379, 50.63472625187465, 51.45428017207554, 52.33685425349644, 50.5453758920942, 50.84002120154244, 55.17303943634033, 53.55951486315046, 54.44563947405134, 53.33987535749163, 52.61296871730259, 52.027138301304404, 53.314559595925466, 53.62407752445766, 55.13600901194981, 53.180820669446675, 53.476671491350444, 52.077168805258616, 53.26608548845564, 52.779190472194124, 52.33854613985334, 50.50529868262154, 51.28063079289028, 48.10966055733817, 46.33627530506679, 49.24765041896275, 44.78121634892055, 45.96950422014509, 45.25285659517561, 45.529850006103516, 41.82185697555542, 41.833418778010774, 43.25704213551113, 46.71416350773403, 45.48645503180367, 45.73583630153111, 47.99179826463972, 53.251522064208984, 50.792193276541575, 55.38402148655483, 45.57404402324131, 48.60817296164376, 42.28154979433332, 49.42281103134155, 41.947160788944785, 33.05986935751778, 65.78232724325997, 50.75057356698172, 59.7626233782087, 43.70444706508091, 51.43779557091849, 51.39572075435093, 61.13218975067139, 56.28816625050136, 56.96548359734671, 54.49291501726423, 60.79658481052944, 57.001742771693635, 60.9157464163644, 45.50858504431588, 4.287666039807456, 0.7467986813613346, 2.0749941766262054, 0.35978008434176445, 31.89091832297189, 52.96406119210379, 54.26430886132376, 61.6169308253697, 57.081362179347444, 53.23148693357195, 66.20278358459473, 15.118684325899396, 35.094576358795166, 19.210509743009293, 45.194397926330566, 39.312417779650005, 28.91207446370806, 61.18983200618199, 32.98627751214163, 0.12560228737337248, 0.040367581748536656, 0.11157328409275838, 0.05280778171228511, 0.16680794129414217, 0.05273594181718571, 0.026357470579179268, 0.03821187260161553, 0.22367592049496515, 0.08957144684557404, 0.1484036831451314, 0.21673097887209483, 0.21731940444026673, 0.11846096414540495, 0.13282500766217709, 0.22849189064332417, 0.15088155732623168, 0.12302016307200704, 0.1468814169721944, 0.19806072142507347, 50.38153736931937, 67.7812614440918, 58.43866498129708, 39.529722690582275, 48.05399853842599, 60.93563216073172, 39.92044421604702, 9.338259049824305, 53.37490470068795, 75.46979754311698, 62.27871200016567, 75.39066450936454, 58.338624817984446, 71.7524140221732, 7.878948875835963, 1.1372466215065546, 2.8058209036077773, 2.040709810597556, 0.18347156713051455, 1.0650938131979533, 49.8630245753697, 58.66136169433594, 70.6102066040039, 60.925140380859375, 64.45743083953857, 58.24095399039132, 58.62730162484305, 55.52805069514683, 60.83432742527553, 63.65351036616734, 62.680241448538645, 55.16442019598824, 57.69546481541225, 52.77785989216396, 44.26306138719831, 63.59329727717808, 59.91917324066162, 57.59716517584664, 59.7457948412214, 57.87385286603655, 58.12819514955793, 58.48047924041748, 58.274635383060996, 54.15472534724644, 53.495358671460835, 51.727212360927034, 49.70248644692557, 48.9093530518668, 49.51394360406058, 47.40239300046648, 47.92920194353376, 48.74504899978638, 51.11454105377197, 51.253452914101736, 53.613471099308555, 58.44579383305141, 59.43918473379952, 58.45333957672119, 57.99086053030831, 58.750361170087544, 61.89394160679409, 54.99744803564889, 58.54673726218087, 58.4903039932251, 57.53994676045009, 50.361401489802766, 54.065110955919536, 56.05972337722778, 56.50035381317139, 61.43827179500035, 54.78519793919155, 53.061471462249756, 50.09605325971331, 54.99294212886265, 57.275779724121094, 55.92887837546212, 55.08230985913958, 44.022768361227854, 51.38302639552525, 55.20838144847325, 57.337872300829204, 54.05701977866036, 53.612126622881206, 58.11911732809884, 58.06992408207485, 59.23299694061279, 58.29800564902169, 55.075462409428184, 56.501698289598735, 54.63421705790928, 55.24316413061959, 58.22069304330008, 57.03827639988491, 55.37199762889317, 55.451589243752615, 56.99777882439749, 55.589222635541645, 55.900620051792686, 53.09012235913958, 54.23974003110613, 52.547329085213796, 49.700547899518696, 53.36893619809832, 45.90670640127999, 48.56826598303658, 48.66092021124703, 48.32482542310442, 44.28154012135097, 43.85965592520577, 45.7677389553615, 49.54473107201712, 47.82785551888602, 48.530589376177105, 48.70441940852574, 54.64724145616804, 53.08402531487601, 56.50130571637835, 50.176982402801514, 53.68191432952881, 42.89100061144148, 48.907539572034565, 44.58461706978934, 41.1020861353193, 66.82834380013603, 54.782046931130544, 54.9232690674918, 46.125036171504426, 55.12716048104422, 51.4925890650068, 63.26403604234968, 60.99372604915074, 60.267868586948936, 58.92007092067173, 62.26544788905552, 59.51781749725342, 65.13248307364327, 50.75701454707554, 8.479199409484863, 0.988558754324913, 3.8054584520203725, 0.6923537914242063, 32.56940991537911, 57.800101212092805, 57.75148466655186, 67.07471997397286, 59.98150553022112, 57.67852510724749, 74.27811200278146, 24.643693583352224, 36.283225536346436, 26.384611640657695, 56.36789335523333, 41.80278417042324, 45.22443151473999, 69.91721412113735, 48.117901120867046, 0.4455505476466247, 0.24183498322963715, 0.20965611136385373, 0.2497077536370073, 0.29427501931786537, 0.2242823950946331, 0.20627045232270444, 0.15726915028478416], [0.038984958082437515, 0.03377177014148661, 0.09580798433827502, 0.03883964302284377, 0.0510777379386127, 0.03262049977534583, 0.09795771219900676, 0.07024998577045542, 0.10438335061605487, 0.11451239245278494, 0.11480712092348508, 0.5073622379984174, 16.885369777679443, 55.2504562650408, 39.780948707035606, 25.92279962130955, 29.248441968645366, 37.40861136572701, 29.612086364201136, 4.933155860219683, 38.72469745363508, 44.99190310069493, 46.9293909072876, 55.632937226976665, 49.81641953332083, 54.902400153023855, 16.272776637758525, 1.625425860285759, 0.8672915729028838, 0.5122242942452431, 0.10426254424133471, 0.2595696901636464, 31.669666835239955, 59.8769142968314, 56.63506548745291, 56.84472737993513, 55.83418485096523, 55.97410767418997, 52.41855812072754, 53.183905669621055, 54.322357586451936, 51.49922806876046, 53.235350131988525, 55.71670470918928, 56.513145446777344, 53.8404027393886, 41.612566811697825, 55.92041546957833, 55.96642991474697, 54.996214730399, 54.37230123792376, 55.091613497052876, 55.57400260652815, 54.98159919466291, 54.76728548322405, 49.64650133677891, 48.576166084834504, 47.20452914919172, 48.370843342372346, 43.208012172154014, 45.40359776360648, 44.403790201459614, 44.81756584984915, 42.63125262941633, 45.865163121904644, 46.53838103158133, 49.194121497017996, 49.341631753104075, 52.36921548843384, 51.58476734161377, 51.57142332621983, 52.97730098451887, 46.407803535461426, 51.428821972438264, 47.871722970690044, 49.220635822841096, 47.654918330056326, 48.59969615936279, 51.462242807660786, 50.38368088858468, 49.263947418757844, 50.805578981127056, 50.38577924455915, 47.24971675872803, 47.97937141145979, 45.362238611493794, 50.42130538395473, 50.80027403150286, 51.915963649749756, 43.31310714994158, 46.97770868028913, 49.7562655040196, 49.06042078563145, 46.63018757956368, 47.315092359270366, 51.627655097416465, 50.695293698992046, 50.27968372617449, 51.01625531060355, 49.44742502485003, 46.11974164417812, 47.22748599733625, 46.4490966796875, 48.518874713352744, 49.81568997246878, 49.92268875667027, 49.53660862786429, 51.30048179626465, 49.737470626831055, 50.424369539533345, 48.98140239715576, 47.69266789300101, 46.66910791397095, 44.07887853894915, 44.19048745291573, 45.22528614316668, 45.55588143212454, 42.51504748208182, 42.96697221483503, 40.83513287135533, 44.444127968379426, 41.368261201041086, 44.84449359348842, 44.70766966683524, 48.110793113708496, 44.1931277683803, 50.03902244567871, 47.81097487040928, 53.427672794886995, 46.7024245262146, 52.972093309674946, 41.09971679959978, 46.85003205708095, 21.80564280918666, 23.42083321298872, 60.65807247161865, 50.000421728406636, 55.49615846361433, 53.590482984270366, 43.96917690549578, 50.08838244846889, 54.83430085863386, 54.82240554264614, 54.56028822490147, 54.199284144810264, 55.52707099914551, 55.303307737622944, 59.8443272454398, 35.117574896131245, 0.20033921487629414, 0.4077331040586744, 0.18708936657224381, 0.743934340775013, 41.45399154935564, 54.91113403865269, 50.554936613355366, 58.73616600036621, 35.665982314518516, 49.26750142233712, 42.20256962094988, 4.5877127051353455, 33.900747299194336, 22.196241004126414, 44.554044995989116, 23.157446111951554, 31.570189476013184, 52.932439940316335, 17.977779456547328, 0.5384003296494484, 0.03771879816693919, 0.04490763580958758, 0.034505049365439584, 0.06771746916430336, 0.024836505497140542, 0.07183709274977446, 0.04567022096099598, 0.02743482812573867, 0.029802448847996335, 0.0346618248814983, 0.0119387617367985, 0.023229712520592978, 0.015107037665854608, 0.04436090961098671, 0.09706783387809992, 0.11512724017458302, 0.10658191942742892, 0.11288092285394669, 0.48342971077987124, 18.15549874305725, 68.32869611467633, 41.67982884815761, 21.777033601488384, 41.80057116917202, 44.73804719107491, 37.10400233949934, 8.94170798574175, 44.34673159463065, 52.76714924403599, 49.00197948728289, 61.256930759974885, 54.08834573200771, 62.32832213810512, 18.77968842642648, 1.5940054548638207, 1.4432782913957323, 0.5949501980628286, 0.15744932847363607, 0.3205998167395592, 35.044615336826865, 61.63056319100516, 58.55520016806466, 60.13570690155029, 57.98667771475655, 56.94767883845738, 55.38844401495797, 56.02414512634277, 55.81347574506487, 52.33216074534825, 53.71148238863264, 57.823683398110525, 58.125617367880686, 55.92632143838065, 44.234275000435964, 56.125727789742605, 57.64818927219936, 55.96828160967146, 56.90995012010847, 58.22376414707729, 55.665093490055625, 54.388428006853374, 55.53742034094674, 49.706617150987896, 52.444784096309114, 49.3443728174482, 50.4259363583156, 46.49633748190743, 45.11273227419172, 45.069396359579905, 46.213035106658936, 44.890612261635916, 46.47329725537981, 47.08327613558088, 50.253878116607666, 50.57913718904768, 52.10201556341988, 54.34949377604893, 54.37280150822231, 54.746444361550466, 52.492017950330464, 53.419063976832796, 49.551807812282014, 50.63450390951974, 51.9552001271929, 49.47643722806658, 51.46635614122663, 50.47371564592634, 51.28765542166573, 52.287869453430176, 52.58935179029192, 51.11914076123919, 49.00079481942313, 48.24487597601754, 53.77162252153669, 52.31554412841797, 52.64467682157244, 43.03756938661848, 49.65245941707066, 53.087728704724995, 51.16354669843401, 50.742232254573274, 49.83208424704415, 54.0535317829677, 52.892428738730295, 55.55061844417027, 52.46813004357474, 51.44883278438023, 48.55843775612967, 50.54867281232561, 49.8906888280596, 52.08811221803938, 54.00543287822178, 53.39739601952689, 52.317100524902344, 52.791464465005056, 52.29562016895839, 50.73598582404, 50.63932943344116, 48.72938776016235, 48.712041582380024, 45.1717016356332, 44.28173119681222, 42.89425931658064, 48.76603603363037, 43.676390239170615, 45.77954741886684, 41.412444795881, 45.867643628801616, 44.31946338926043, 47.33439098085676, 44.92489814758301, 50.161470549447195, 46.84742995670864, 52.61276721954346, 48.913011278424946, 55.45780093329293, 50.365278584616526, 57.84544515609741, 42.86806460789272, 47.124423367636545, 23.84460037095206, 27.178573608398438, 61.896984917776926, 53.38890184674944, 57.201937743595664, 58.61041055406843, 49.61083623341152, 51.118060316358296, 57.74416821343558, 57.59678302492414, 55.75456196921212, 57.13737508228847, 57.200961521693635, 57.88443149839129, 59.842701366969514, 36.798483099256245, 0.5345074385404587, 0.45113163388201166, 0.0785360179309334, 1.3467180899211337, 45.583795819963726, 52.82494783401489, 53.7965213911874, 63.957771982465474, 39.64946099690029, 54.23756177084786, 43.96526506968907, 8.498568381581988, 46.41889633451189, 22.912447418485367, 53.534160886492046, 26.24270510673523, 33.607112952641074, 59.94042778015137, 21.401066575731548, 0.5201029000537736, 0.06822506085570369, 0.17592997609504632, 0.049967803925807984, 0.1303654403558799, 0.0491478282825223, 0.019032143921192204, 0.019955692846061926, 0.23683594433324678, 0.13618315889367036, 0.2878806138677256, 0.1803055770163025, 0.08587394668055431, 0.14757255917148931, 0.19327243550547532, 0.18594505797539437, 0.2444594209747655, 0.22031045465597085, 0.44624463468790054, 0.6223210522106716, 26.37776940209525, 79.53118637629917, 52.2475768498012, 41.24021632330758, 42.218567848205566, 58.32952962602888, 34.84205102920532, 12.044941970280238, 49.57772806712559, 59.79368877410889, 57.21384000778198, 68.14346408843994, 58.04507384981428, 69.8117960521153, 19.18230526787894, 3.145716356379645, 1.9513221042496818, 1.168593310884067, 0.2120526291962181, 0.6470574534365109, 39.343451908656526, 66.64838545663017, 61.88023975917271, 62.074059758867534, 59.62199183872768, 60.90879126957485, 56.15176616396223, 59.35513237544468, 58.786429268973215, 54.956484930855886, 56.74292584827968, 59.7271180834089, 60.612916128976, 56.02793189457485, 43.546726431165425, 59.750999041966026, 58.5107455934797, 58.65568501608712, 58.76755796160017, 60.44311605181013, 56.60068580082485, 57.4294877733503, 57.490993227277485, 51.08968734741211, 53.463414328438894, 51.131425176348, 52.85747235161917, 48.934439522879465, 48.939101764133994, 47.49093736921038, 48.027664865766255, 45.967061928340364, 50.075615133558, 49.25359460285732, 52.36823926653181, 56.351922920772004, 57.03158528464181, 56.7466778755188, 58.10328238351004, 59.229397773742676, 54.044606821877615, 56.301749978746685, 53.770517757960725, 54.92572178159441, 57.091214724949424, 53.723971775599885, 57.459802763802664, 51.94771344321114, 53.44699573516846, 58.15879154205322, 57.16803400857108, 53.61617742265974, 52.301734583718435, 50.53694772720337, 57.48234966823033, 57.47747550691877, 57.45929901940482, 45.523957933698384, 53.76766899653843, 54.91165515354702, 53.687219279153005, 54.86243758882795, 54.92721217019217, 55.77910648073469, 57.60469702311924, 58.3719344820295, 56.229384490421836, 56.2009003502982, 52.99982009615217, 54.38730934688023, 53.505065304892405, 55.14960663659232, 58.23129946844918, 55.69835451671055, 55.33548831939697, 55.557622228349956, 54.34758302143642, 53.004513604300364, 54.163587774549214, 52.953267165592735, 52.138625621795654, 47.137413024902344, 47.81444896970476, 48.25424909591675, 51.21931988852364, 46.74326603753226, 48.28508520126343, 43.540198598589214, 49.33084467479161, 47.19243928364345, 51.11802904946463, 46.710842268807546, 51.42081764766148, 47.29296234675816, 56.07886913844517, 50.768381799970356, 58.31616824013846, 50.66780662536621, 57.40745850971767, 42.46736546925136, 49.220152923039024, 28.092176607676915, 28.350001675742014, 64.2973165512085, 54.985132353646414, 59.100675446646555, 55.930316652570454, 51.79303959437779, 53.73261533464704, 58.64399119785854, 59.876059668404714, 58.093245710645405, 60.55954701559884, 59.59140586853027, 61.55347292763846, 64.29091031210763, 45.59733438491821, 1.246479685817446, 0.8386425216283117, 1.7610436230897903, 1.0343835353851318, 51.83275897162301, 65.8858345576695, 59.74478735242571, 68.00452096121651, 45.071223735809326, 59.74905354636056, 51.98430960518973, 11.004399725369044, 45.288414001464844, 33.5818110874721, 58.00571925299508, 30.79616015298026, 45.47115509850638, 63.90384006500244, 32.942965916224885, 0.7354381595339093, 0.13715509245438234, 0.2891763171979359, 0.1569682742868151, 0.2558123974927834, 0.17783581811402524, 0.2119954829769475, 0.18129482679069042], [0.08607043006590434, 0.07091286698622362, 0.08786221713359867, 0.0366677406377026, 0.10005762880401951, 0.06043121764170272, 0.041104355427835665, 0.09082033804484776, 0.07600103824266366, 0.13180325606039592, 0.0680005471887333, 0.22548725615654672, 4.727502644062042, 56.037739276885986, 48.149275711604524, 38.764281341007774, 27.268521513257706, 31.162021023886545, 28.853033883231028, 2.022946523768561, 33.58128997257778, 47.83810411180769, 43.30119098935808, 62.99612740107945, 48.148146629333496, 53.29770674024309, 30.09696987697056, 0.22833436195339474, 0.4275468965726239, 0.8537206553987094, 0.17304742362882408, 0.16497015633753367, 23.35089612007141, 63.18194307599749, 54.95527247020176, 60.339240482875276, 55.368214334760395, 56.43807363510132, 52.32700865609305, 53.656056608472554, 53.47771372113909, 56.59417533874512, 54.74581207547869, 53.30766003472464, 55.77026489802769, 56.241186005728586, 53.47879764011928, 50.60527631214687, 55.38858992712838, 47.89145932878767, 52.11290339061192, 52.973642757960725, 53.946859564099995, 55.54872158595494, 55.29392766952515, 51.906093733651296, 51.13724776676723, 52.65330648422241, 51.216992241995676, 45.809581007276265, 45.570410115378245, 45.58024181638445, 45.838040828704834, 44.404964447021484, 44.917203017643516, 46.60460778645107, 49.66635234015328, 50.03076798575265, 50.02457366670881, 53.0343839100429, 50.35783358982631, 49.57651908057076, 48.995271001543315, 46.74079942703247, 50.26557193483625, 46.46273946762085, 46.012478828430176, 46.7856569971357, 49.455387660435264, 47.509311880384175, 49.06619473866054, 46.98389605113438, 48.21666281563895, 44.214253766196116, 44.20591940198626, 45.01649972370693, 49.28944730758667, 48.50451973506382, 50.42623513085501, 46.275214535849436, 47.66379465375628, 52.84250593185425, 51.27709068570818, 46.48314980098179, 44.70128774642944, 48.27057041440691, 50.551615374428884, 48.8431784084865, 48.0658278465271, 48.43087577819824, 44.313046727861675, 46.228949955531526, 46.85609088625227, 46.158411843436106, 47.83379970278059, 49.097840309143066, 48.123199122292654, 51.70661095210484, 49.96998514447893, 50.29552909306118, 48.08997631072998, 45.55521093096052, 44.07977138246809, 43.33988203321184, 41.92667402539934, 41.84064490454537, 43.48918839863369, 42.96026372909546, 44.02729858670916, 40.29044621331351, 42.52039064679827, 44.41374002184187, 47.41831827163696, 46.49739013399397, 47.09131867544991, 46.37800965990339, 47.07252727236067, 49.328176566532676, 50.15188898359026, 50.72189487729754, 51.562758922576904, 52.21863760266985, 43.92323889051165, 40.1155982698713, 49.12457002912249, 51.85301297051566, 53.44474799292428, 53.8273401260376, 58.03971331460135, 55.949052470070974, 48.836004393441335, 48.78352812358311, 53.56051540374756, 56.48822225843157, 55.87135076522827, 59.3640330178397, 64.65544755118233, 58.22968748637608, 11.375924246651785, 0.7566927533064569, 0.3360227277236325, 0.20134351455739566, 4.175488242081233, 52.894426345825195, 51.882407324654714, 50.95082759857178, 55.84968975612095, 41.8159510067531, 66.00111906869071, 21.80832133974348, 7.751406873975482, 29.23040097100394, 24.52804776600429, 41.00833756583077, 19.894485201154435, 44.64250946044922, 47.43478202819824, 12.001210008348737, 0.6494657099246979, 0.11159415582993201, 0.20856884042067186, 0.10692392821822848, 0.12512704144631112, 0.06666999429996524, 0.05836797585444791, 0.020174489855500202, 0.04442026446174298, 0.02882805559784174, 0.020463869773915837, 0.024662393411355357, 0.13525584579578467, 0.018280250785340155, 0.0360758952530367, 0.036457398174596686, 0.12696395787809575, 0.10709295129137379, 0.11373666407806532, 0.26038490927645136, 4.014514982700348, 62.79979910169329, 54.63301501955305, 38.01931980678013, 38.62654372623989, 39.29790646689278, 33.60914877482823, 6.815637818404606, 36.360385281699045, 54.195935113089426, 52.09672451019287, 73.85306985037667, 52.53881754193987, 62.19499315534319, 31.772941384996685, 0.1285492599542652, 0.19507657869585923, 1.199441249881472, 0.2142009117773601, 0.13664237782359123, 25.684241907937185, 67.57623400006975, 58.418939045497346, 62.43879849570138, 57.64940868105207, 59.27945259639195, 53.86109447479248, 57.03353425434658, 54.883671283721924, 58.98794092450823, 55.20526170730591, 56.43906375340053, 55.818461077553884, 58.613544191632954, 53.7537065914699, 52.61907965796334, 54.28751931871687, 49.54648201806204, 52.84573337009975, 55.990797247205464, 54.79631853103638, 59.05825669424874, 56.14799329212734, 52.189545495169504, 52.881912640162874, 53.6989026750837, 52.3434967313494, 48.892548833574565, 47.59865181786673, 46.115242685590474, 47.07546288626534, 46.55976063864571, 47.00022431782314, 46.73977109364101, 50.783567087990896, 49.61066600254604, 51.87259994234358, 52.61184310913086, 53.93024294716971, 49.798388957977295, 54.2579026222229, 51.85499668121338, 52.74402216502598, 48.60803052357265, 47.25785657337734, 50.60840994971139, 51.32102414539882, 49.947424343654085, 51.44999313354492, 49.526099477495464, 47.94191714695522, 48.86212614604405, 47.88680403573172, 49.488231795174734, 51.85232857295445, 50.699358395167756, 52.998555524008616, 46.870956557137625, 50.76387241908482, 54.82313162939889, 52.64439194543021, 50.126715660095215, 46.76926967075893, 51.7293940952846, 53.402909415108816, 51.80797127314976, 53.02157143184117, 53.13648074013846, 47.50126239231655, 48.42303473608834, 50.35267802647182, 50.16741125924246, 52.08272736413138, 52.602303232465474, 52.79597037179129, 52.0929342678615, 51.89911774226597, 52.285208293369834, 49.76389810017177, 48.0581431388855, 46.849229540143696, 44.81822592871529, 44.11431435176304, 43.517012459891184, 47.47443192345755, 45.513299397059846, 45.78330986840384, 41.89094638824463, 44.64946460723877, 44.84733888081142, 47.862652097429546, 47.71401275907244, 49.08795302254813, 46.31214768545968, 49.2496132850647, 51.51068564823696, 53.31188801356724, 52.44595834187099, 53.15803405216762, 53.63905784061977, 46.02789340700422, 41.8968106678554, 51.622999804360525, 53.82430723735264, 56.04190124784197, 56.33168281827654, 58.36058807373047, 60.85631847381592, 54.082550934382844, 50.70291587284633, 54.70916032791138, 56.43045493534633, 59.83315454210554, 60.9348817552839, 67.64143589564732, 59.77501201629639, 10.288388729095459, 0.9103369116783142, 0.5565192231110164, 0.23600986866014345, 5.650965137141092, 57.747208050319124, 56.1550144468035, 53.6610176222665, 63.036489486694336, 40.15008217947823, 69.52496746608189, 25.582160711288452, 13.469703963824681, 34.138816901615684, 24.02500687326704, 50.41080665588379, 18.853860446384974, 46.25781624657767, 54.745138100215364, 12.210017272404261, 0.7118181384035519, 0.15695124305784702, 0.14767280593514442, 0.09258717537990638, 0.05156053596043161, 0.025914953788742423, 0.025826474518648217, 0.08053534171943154, 0.17567773748721394, 0.13089575618505478, 0.19688305604670728, 0.11650434056563036, 0.16348259044545038, 0.14214969373175076, 0.15725351683795452, 0.15625013996447834, 0.13459248282015324, 0.23112132240618977, 0.24516952144248144, 0.37043492974979536, 8.077225276402064, 80.602431842259, 57.124093600681846, 61.62528256007603, 38.77840008054461, 52.13825389317104, 36.58475998469761, 8.503650988851275, 43.96368088041033, 62.63188198634556, 51.75215291976929, 76.40064076014927, 57.40030186516898, 68.5167213167463, 36.94227259499686, 0.37970377238733427, 0.3474777830498559, 1.9019723066261836, 0.24697922862001828, 0.16125870549253055, 28.473519802093506, 69.93404960632324, 61.02198437282017, 65.641202381679, 60.361877713884624, 63.245560782296316, 54.86894110270909, 59.42923491341727, 56.87950311388288, 62.8496732711792, 57.702214990343364, 58.193598542894634, 58.163210596357075, 60.218091692243306, 53.35561997549874, 52.88910749980381, 58.38580308641706, 51.94734171458653, 55.83487272262573, 57.99851049695696, 56.189526149204795, 60.763935225350515, 57.81259059906006, 54.0368561063494, 54.809728554316926, 54.77948304585048, 55.763684953962056, 50.08892788205828, 49.23136731556484, 49.39346531459263, 48.78224965504238, 48.57883766719273, 48.90495136805943, 50.3307078225272, 53.98269142423357, 54.868065629686626, 55.853302819388254, 57.6129584312439, 56.95443248748779, 52.86925302233015, 56.309521538870676, 54.76969303403582, 57.130131585257395, 51.70322717939104, 51.34814991269793, 53.85396214893886, 56.456524576459614, 52.79537630081177, 54.719704219273154, 54.606545857020784, 50.7934786932809, 52.345091342926025, 51.526597023010254, 52.5531690461295, 56.16428681782314, 52.16342374256679, 58.958814076014924, 50.216660090855186, 53.830518926892964, 59.481388092041016, 57.718928882053916, 52.8503087588719, 50.36615058353969, 53.57459940229143, 56.260564531598774, 55.89591612134661, 56.892204420907156, 55.95227296011788, 49.71466316495623, 52.277912684849326, 54.31448875154768, 52.12840829576765, 55.10413415091378, 55.11123520987374, 55.07841886792864, 56.47899157660348, 55.15539796011788, 54.426639625004356, 51.90450954437256, 49.37657424381801, 48.62719365528652, 46.77358102798462, 46.7157998085022, 45.6760435785566, 49.7758663722447, 47.580982548849924, 49.512724195207866, 44.48538984571184, 45.673121861049104, 47.09329891204834, 50.57560403006417, 50.79474326542446, 51.5875118800572, 49.31377295085362, 51.68324416024344, 51.56163331440517, 55.48164020265852, 54.45784398487636, 55.63983678817749, 56.74891172136579, 46.82691192626953, 40.70890842165266, 51.74460717609951, 56.08847849709647, 58.11693559374128, 59.09220559256417, 60.57301957266671, 58.30717032296317, 56.40450341360909, 55.155120032174246, 57.60501316615513, 59.206037930079866, 61.31414222717285, 65.39818218776158, 67.59691878727504, 63.16381522587368, 17.50280407496861, 1.093726362500872, 0.9346841595002583, 0.24386703276208468, 6.582269540854862, 58.069646154131206, 63.872156279427664, 58.976907185145784, 69.80286066872733, 47.37622261047363, 76.52304717472622, 28.54296009881156, 14.22079815183367, 37.49449110031128, 36.80062314442226, 54.35767180579049, 30.23541968209403, 58.476657731192454, 65.01589924948556, 23.279701403209142, 1.0762087596314294, 0.28736674572740284, 0.2814114609999316, 0.26271681700434, 0.2127354254147836, 0.17609015107154846, 0.13109080786151545, 0.1279879215040377], [0.04815658361517957, 0.05024298380262085, 0.0386750134639442, 0.02548829436169139, 0.014000912779010832, 0.08265395874955825, 0.06319083313324622, 0.022622808747525727, 0.05497317016124725, 0.030651414899953773, 0.053546984546950886, 0.08656500745564699, 0.08205485982554299, 33.724065031324116, 49.04250485556466, 34.44738292694092, 22.054449115480693, 24.762021405356272, 53.56445155824934, 5.487178725855691, 16.77433235304696, 61.05846241542271, 35.898781708308626, 38.6406763621739, 58.16949871608189, 43.690832069941926, 62.24607631138393, 3.1957119022096907, 0.06264865651194539, 0.07060641343040125, 2.805053779057094, 3.34444808108466, 6.626506549971444, 67.68832233973912, 55.51648194449288, 62.466709409441265, 56.140468393053325, 58.47469139099121, 50.541609968457905, 52.98379407610212, 52.432996477399556, 53.632311139787944, 51.165711062295095, 55.0204222542899, 55.450637340545654, 57.97468512398856, 53.434575830187114, 52.18356309618269, 49.2639092036656, 48.07690327508109, 39.80644512176514, 47.979173387799946, 55.50688648223877, 53.94144344329834, 53.46815994807652, 51.38147347314017, 49.6199175289699, 49.66247524533953, 50.43929427010672, 47.65727029527937, 47.18881579807827, 44.32692575454712, 43.75566918509347, 42.16626180921282, 42.022024154663086, 42.98275852203369, 47.52117592947823, 46.097097464970176, 48.41340800694057, 49.776446546827046, 50.85351112910679, 50.07851600646973, 47.68315233503069, 46.778250217437744, 43.78981263296944, 41.61167744227818, 48.302876063755576, 46.37766224997384, 48.144613470349995, 47.234750338963096, 46.37766224997384, 45.36879423686436, 45.495703084128245, 44.87725782394409, 43.89100272314889, 45.62775707244873, 47.26614577429635, 47.11719029290335, 50.91857058661324, 46.6929680279323, 47.38760028566633, 48.889588900974815, 49.32465730394636, 45.780270031520296, 42.7315012386867, 46.13448919568743, 48.280058179582866, 47.39525025231497, 47.25406633104597, 48.3853303364345, 46.65471124649048, 45.07241187776838, 42.65235430853707, 43.468065874917166, 46.96250254767281, 45.3609288760594, 48.35099581309727, 47.79600150244576, 49.537702969142366, 48.63445452281407, 48.23661456789289, 44.70949704306466, 45.2587764603751, 41.478636809757774, 42.276157992226736, 42.0362332207816, 42.2961688041687, 42.27888863427298, 41.47213329587664, 42.05365235464913, 43.17229495729719, 43.52615628923689, 46.13887003489903, 47.16600833620344, 48.318679741450715, 46.93132945469448, 46.278935296194895, 48.16547891071865, 48.205205236162456, 49.516983440944124, 50.06464392798287, 51.939688273838584, 47.96624626432146, 41.38714293071202, 48.8949807030814, 53.73362282344273, 51.981057848249165, 53.31743267604283, 53.837807587214876, 55.27135992050171, 58.73825740814209, 53.71927826745169, 53.03326872416905, 55.69020080566406, 58.83167593819754, 59.44621631077358, 55.46379028047834, 33.222818510872976, 0.4436705442411559, 0.31061387115291184, 1.8884204966681344, 0.05891758243420294, 3.128057292529515, 43.27357537405831, 56.59890358788626, 51.233379568372456, 52.05611228942871, 45.95077535084316, 69.78780392238072, 18.54675006866455, 17.96206784248352, 29.416789872305735, 29.606847422463552, 31.215042727334158, 25.396998167037964, 42.19699021748134, 39.831722668239046, 2.9058415251118794, 0.5860625835401672, 0.05884299786495311, 0.1511482215885605, 0.013253664215361434, 0.12214103953114577, 0.06859699304082564, 0.05314909161201545, 0.07754186913371086, 0.0633291524967977, 0.022334441542625427, 0.037678330338427, 0.04942737453218017, 0.033077828985239775, 0.046540560866040845, 0.013721031502687504, 0.0450232446060649, 0.07618342167032616, 0.031575257291219065, 0.08075548562088183, 0.005635293549858034, 0.2700178266635963, 36.04134137289864, 56.45209509985787, 31.847433022090367, 29.527578898838588, 38.69328464780535, 47.80239731924874, 8.827157378196716, 18.482098817825317, 70.07941286904472, 41.73879820959908, 46.70609317507063, 65.6820786339896, 50.008540698460166, 68.46594388144356, 3.6101135398660387, 0.11540638948125498, 0.5390952037913459, 3.7911712186677113, 4.807549365929194, 7.755533235413687, 73.1759262084961, 57.9735039302281, 65.70819691249302, 57.021791798727854, 62.46869659423828, 54.486536570957725, 57.128304209027974, 53.889206886291504, 55.62506144387381, 51.78018890108381, 56.67031022480556, 56.41189629690987, 59.76672281537737, 54.22097989491054, 54.22997086388724, 49.494228090558735, 49.186342988695415, 41.313599722726, 52.92374774387905, 56.168990748269216, 56.66006163188389, 54.76235573632376, 52.694554465157644, 50.86663280214582, 51.99805661610195, 52.30012954984392, 50.867303303309846, 47.897073473249165, 47.94880281175886, 44.89246048246111, 43.671373639787944, 43.4692713873727, 44.56541224888393, 48.511193479810444, 48.212195123944966, 51.08627230780465, 51.80946166174752, 52.34966673169817, 51.65536798749651, 51.62225982121059, 48.83490310396467, 48.91899367741176, 45.10480090550014, 49.22907441002982, 50.638252462659565, 49.5877925327846, 49.12227017538888, 49.16548102242606, 47.951217310769216, 47.728888852255686, 45.82945285524641, 47.33049304144723, 47.11475494929722, 49.8322787966047, 49.60306119918823, 53.11971126283918, 48.29024771281651, 49.63649245670864, 51.81880351475307, 51.88719115938459, 48.91156257901873, 47.88967364174979, 49.788932459695, 51.15421526772635, 48.97708756583077, 48.29592786516462, 49.46998929977417, 51.1937609400068, 47.20737443651472, 45.64657279423305, 46.87955495289394, 49.27140283584595, 48.95651394980294, 50.36149876458304, 51.44598054885864, 51.9906394141061, 49.691671575818745, 49.23137426376343, 45.98884105682373, 45.89198316846575, 42.62106657028198, 43.72967250006539, 44.288665499006, 44.49005903516497, 42.48519802093506, 42.14303745542254, 43.07641329084124, 45.12388413293021, 44.5130158833095, 47.68181480680193, 47.515672956194194, 50.80933100836617, 47.68630681719099, 49.13005910600935, 50.723718779427664, 50.09077957698277, 50.72359718595232, 52.92919165747506, 54.44750506537301, 51.71980210712978, 41.94224493844168, 51.29365866524832, 55.96291412625994, 55.70990937096732, 54.10353102002825, 57.66458354677473, 56.13056026186262, 61.41869177137102, 57.16387551171439, 56.77224724633353, 57.23945106778826, 60.52501446860177, 57.99956314904349, 59.26925264086042, 35.68365853173392, 0.422496641853026, 0.6417271537440163, 2.7802919191973547, 0.10383740812540054, 4.929493291037423, 46.34670802525112, 60.65815585000174, 55.83340317862374, 55.42213582992554, 48.15442432676043, 74.89347226279122, 21.80800345965794, 20.512395450047084, 28.787979636873516, 31.468311514173234, 40.91750029155186, 22.782029730933054, 47.95731782913208, 47.83238227026803, 3.1184053761618475, 0.5115571043321064, 0.13891384165201867, 0.12122014537453651, 0.033487806628857336, 0.06088215844439609, 0.1460730917751789, 0.022590388344334703, 0.17925747111439705, 0.1829218180584056, 0.30577806064060753, 0.29838987280215534, 0.20535225873546942, 0.15681189910641738, 0.24784368223377637, 0.10524088995797293, 0.17483045080942766, 0.2796079692031656, 0.15331938437053136, 0.23511493525334767, 0.2393654685999666, 0.5229765772819519, 59.12264565059117, 64.73912470681327, 49.896796294621055, 31.259886401040212, 43.19589103971209, 68.0583417075021, 9.947266919272286, 26.68619646344866, 74.45738247462681, 44.25104100363595, 49.1462345123291, 71.41988018580845, 53.116772174835205, 75.23933969225202, 4.177627418722425, 0.3931297819529261, 1.2388691284826823, 4.442796298435756, 5.179463854857853, 9.928657906396047, 75.91959612710136, 61.56618813105992, 70.10210568564278, 60.19613538469587, 65.1149458203997, 55.5630452973502, 58.615823200770784, 56.60192952837263, 57.810040610177175, 54.112125941685264, 58.76664079938616, 58.69570663997105, 63.66651739392962, 55.698820046016145, 54.40035458973476, 50.89753491537911, 51.41144105366298, 42.87601682118007, 55.97592462812151, 58.80791309901646, 59.43873310089111, 56.90133087975638, 53.90745632989066, 51.46941682270595, 53.245716844286235, 53.47697721208845, 51.96640409742083, 49.91698081152779, 48.71293095179966, 46.34776067733765, 46.67386743000576, 43.48573514393398, 47.081382751464844, 50.88058825901577, 50.63933638163975, 54.07733283724104, 54.48203066417149, 55.91121258054461, 55.79171746117728, 54.347808837890625, 51.29007339477539, 50.61335359300886, 49.14847878047398, 53.373803411211284, 52.68384034293038, 54.442676067352295, 53.07248435701643, 52.87151118687221, 50.631999083927695, 52.2684770311628, 50.27388892854963, 50.50208166667393, 49.950908865247456, 55.71951525551932, 52.721207754952566, 55.51019035066877, 49.40407868794033, 54.2549079486302, 54.80166516985212, 55.76128087724958, 50.21025732585362, 51.35145378112793, 52.21132114955357, 55.49504327774048, 52.854422092437744, 52.706397669655935, 54.824264185769216, 53.97453423908779, 50.28196620941162, 47.08317191260201, 49.873189789908274, 53.899240085056846, 50.74403531210763, 54.17372519629342, 52.59570244380406, 54.2895690373012, 51.80602577754429, 52.70345858165196, 49.22826147079468, 48.750416483197895, 44.772565841674805, 47.098704610552105, 46.90461015701294, 46.381570611681255, 45.826079504830496, 45.79123081479754, 44.61177410398211, 47.56049925940377, 46.463816438402446, 50.2016658782959, 49.98835270745413, 53.079418659210205, 51.3408647264753, 51.9515141078404, 52.8666022845677, 53.57336262294224, 52.60433210645403, 55.00782169614519, 58.776472500392366, 52.901020186288015, 41.44421195983887, 52.82467338017055, 58.4904568535941, 56.98807219096592, 56.46907997131348, 60.54510171072823, 57.21681036267962, 60.61010210854666, 57.481936250414165, 58.46513761792864, 59.944832938058035, 62.93010561806815, 60.526112283979145, 58.696519579206196, 40.53872619356428, 1.6715266151087624, 1.059111197079931, 3.8145962016923085, 0.19221754425338336, 6.919166845934732, 51.042529923575266, 66.21206637791225, 59.53679302760533, 65.21260275159563, 54.17918995448521, 82.02895259857178, 26.127533503941127, 26.717866352626256, 36.60359307697841, 43.62139177322388, 46.87544509342739, 38.2058824130467, 53.27809892381941, 57.49434573309762, 8.58956720147814, 1.2225533468382699, 0.3091841707272189, 0.2515941895544529, 0.16515367291867733, 0.22505820489355496, 0.3074780622763293, 0.13355120298053536, 0.28145214595964974], [0.03494381046454821, 0.04844160903511303, 0.03647085352401648, 0.04543191606977156, 0.03183576724092875, 0.01692107050413532, 0.02396375679277948, 0.06263284664601088, 0.05206527441207852, 0.06572512750114713, 0.05449578006352697, 0.07585870873715196, 0.3829915188252926, 13.609243767602102, 50.534731251852854, 39.73047351837158, 28.30400460106986, 20.367704425539287, 56.799369539533345, 11.479297808238439, 5.290137801851545, 52.10064329419817, 45.559664726257324, 42.99464341572353, 50.9495004926409, 52.87208441325596, 56.062520027160645, 21.756913355418614, 0.3492848032287189, 0.8469415477343968, 2.657029790537698, 4.645130012716566, 0.5326965099998883, 46.31616721834455, 59.79227828979492, 65.99533121926444, 58.95248426709856, 59.46983323778425, 54.24901935032436, 55.53413731711251, 54.949700014931814, 58.917896134512766, 56.86755568640572, 55.665909903390066, 55.927460942949565, 56.5176374571664, 54.38329676219395, 51.29763650894165, 47.86288833618164, 51.825254917144775, 46.611232893807546, 51.422940322331016, 53.31424345288958, 56.61314044679914, 54.21373987197876, 52.1320595741272, 52.53238698414394, 50.80355358123779, 50.18968718392508, 48.49080746514456, 49.43179505211966, 46.557300976344514, 45.74615437643868, 43.216151986803325, 42.93271064758301, 43.66304274967739, 44.69341891152518, 44.59274646214077, 47.217334679194856, 48.56351688929966, 49.13919946125576, 47.988827909742085, 46.432285513196675, 44.7562757900783, 40.03204965591431, 44.256957394736155, 45.83065141950335, 47.541999680655344, 45.62128829956055, 45.11653641292027, 44.514631339481895, 44.88115923745291, 43.991459778376985, 44.864740644182476, 44.606239863804404, 45.61499670573643, 45.512656688690186, 47.99936137880598, 48.54265144893101, 45.854761668613975, 46.56650039127895, 49.79865298952375, 49.4990153993879, 45.62143421173096, 44.31743104117257, 42.52566432952881, 44.36235809326172, 46.173329625810894, 44.35363462993077, 46.483504159109934, 46.912597111293245, 46.53154747826712, 42.11029059546334, 42.20087773459298, 45.12239721843174, 43.76651879719326, 47.9340170451573, 48.753518853868755, 49.33452722004482, 46.726951667240684, 45.9063173021589, 42.211987904139924, 44.511973653520855, 38.945990630558555, 41.625111784253804, 41.01314919335501, 42.36694662911551, 41.0064754486084, 41.651403767721995, 42.53110824312483, 44.34837484359741, 44.2880471093314, 47.53922387531826, 46.38057701928275, 48.032236780439106, 43.8822340965271, 48.301399571555, 45.106878416878835, 48.072553702763145, 51.61681938171387, 50.00440304619925, 50.86290509360177, 50.88434028625488, 46.056245531354634, 52.2339757510594, 52.190118721553254, 51.76577833720616, 52.13368892669678, 56.63750083105904, 49.86123194013323, 55.26138925552368, 56.286109583718435, 59.064357212611604, 53.718767574855256, 58.30569730486189, 48.225229944501606, 42.817801339285715, 5.513474183423178, 0.33168773033789223, 0.77580333926848, 1.2636588897023882, 0.1036425871508462, 13.623815877096993, 55.69980321611677, 49.96457944597517, 52.59284326008388, 50.301622663225444, 53.18950939178467, 59.770947320120676, 15.648689440318517, 25.868442126682826, 27.127447026116506, 31.49995013645717, 24.49139949253627, 28.37755823135376, 46.96174866812569, 34.17718138013567, 0.36237458512187004, 0.08660425392112561, 0.015072401845827699, 0.0780430283131344, 0.06192387254642589, 0.02716050829206194, 0.036782491087381325, 0.06262997644288198, 0.01978741955411221, 0.020362108180831586, 0.021107217662834694, 0.05986622188772474, 0.03790237920890961, 0.053898801561445, 0.03523145502965365, 0.05519844039476343, 0.014726048734571253, 0.11140873256538596, 0.11759522131511144, 0.21103298105299473, 0.07672425479229007, 0.3436957374215126, 13.99598136969975, 61.90756702423096, 38.60653638839722, 20.27074578830174, 32.692493779318674, 58.37164960588728, 15.93995097705296, 7.441397360392979, 55.19538484300886, 45.87137828554426, 43.8791560445513, 59.70124299185616, 58.059654644557405, 62.2355706351144, 25.174468210765294, 0.2689479940703937, 0.6742134019732475, 2.6775747452463423, 5.801051872117179, 1.5857622857604707, 52.22349786758423, 64.16705172402519, 67.98299544198173, 61.08478913988386, 60.983484404427664, 56.25508935110909, 58.074628012520925, 54.101314544677734, 60.31160054888044, 58.57995659964425, 56.36718463897705, 56.41015229906355, 57.698424748011995, 54.81944908414568, 50.99138423374721, 47.21809550694057, 51.455270290374756, 47.033172675541465, 52.49957759039742, 55.189489296504426, 58.03513445172991, 54.81802122933524, 53.53460209710257, 52.585565022059846, 53.48440831048148, 50.02931581224714, 51.76108135495867, 50.34958607809884, 47.911866188049316, 46.79648576463972, 44.10971117019653, 45.60858351843697, 44.647209916796, 46.73642553601946, 47.88657821927752, 47.42369965144566, 50.62118073872158, 51.205569403512136, 51.089597020830425, 49.329976149967735, 48.344190052577424, 42.62839691979544, 45.36544173104422, 50.30942549024309, 48.75236545290266, 47.520140647888184, 47.210827691214426, 46.66270167487008, 45.35094778878348, 47.07078327451433, 45.574464389256065, 46.648086139133994, 48.36733797618321, 48.9005184173584, 50.30306788853237, 51.04987416948591, 45.89547463825771, 50.40653003965105, 51.967491490500315, 52.951519693647114, 49.03367369515555, 48.206987449101035, 45.9642722266061, 47.96684033530099, 49.74623230525425, 48.79830346788679, 47.974882875170024, 50.96886512211391, 49.416991915021626, 45.729374476841514, 44.973618916102815, 47.58670439038958, 48.03941426958357, 52.92961202348982, 49.98029627118792, 53.27579212188721, 50.52650111062186, 47.947590351104736, 44.9684042930603, 45.994239807128906, 42.746884550367085, 42.00859676088606, 42.028927189963206, 44.26936687741961, 42.898671422685894, 43.15501478740147, 43.96797834123884, 46.62812049048287, 46.471164158412385, 47.5384977885655, 47.95543139321463, 51.41200385774885, 47.33955349240984, 50.649484225681846, 49.700554847717285, 51.424329962049214, 54.00782653263637, 53.23738595417568, 53.00342273712158, 52.28134509495327, 47.57857847213745, 54.131619112832205, 54.445048877171104, 54.67021567480904, 53.196572235652376, 60.87847627912249, 53.15636648450579, 55.8749395098005, 56.43682643345424, 61.74687603541783, 54.60617412839617, 60.22445624215262, 49.79974038260323, 48.02917609895979, 5.771475996289935, 0.8337624434913907, 1.9779276251792908, 1.2787207386323383, 0.09874989504792861, 17.147301231111797, 57.56503323146275, 53.96540430613926, 56.32736103875296, 53.615986347198486, 55.46913691929409, 64.59384482247489, 17.896263190678187, 29.958530494144984, 27.674284151622228, 37.72822502681187, 27.632410832813807, 29.105171850749425, 54.50406340190342, 33.940098421914236, 0.3025494281734739, 0.1905287384454693, 0.043368290910231214, 0.0806980204901525, 0.07972088935119764, 0.03600136157391327, 0.1074177660048008, 0.07361640155847583, 0.0031870005269800977, 0.13941092283598014, 0.09790222839053188, 0.14201416314712592, 0.15791056943791254, 0.17066790988402708, 0.14744902508599417, 0.11738953020955835, 0.13749366785798753, 0.19318626155810698, 0.2167131741132055, 0.3813598320952484, 0.1844408679753542, 0.47507466482264654, 27.66169227872576, 77.18739223480225, 52.848179136003765, 43.01503637858799, 30.17019346782139, 79.64880548204694, 15.239581244332449, 12.490721889904567, 59.78762994493757, 55.24471705300467, 53.44121830804007, 64.689834186009, 61.78161008017403, 69.13192871638707, 26.701677049909318, 0.33120420628360336, 2.3620670352663313, 4.69450260911669, 9.387202160699026, 2.5358697090830122, 55.57753576551165, 67.98945031847272, 73.59521525246757, 62.758714403424946, 63.836254937308176, 58.43257141113281, 60.60619027273995, 57.9519054549081, 64.12444537026542, 60.442581040518625, 60.06828853062221, 58.561140877859934, 61.213462829589844, 57.62606273378645, 50.776973247528076, 47.29791988645281, 52.43511915206909, 46.131220068250386, 53.58697761808123, 55.84972449711391, 61.8622647694179, 56.891183035714285, 54.108036926814485, 53.21167761938912, 55.66871697562081, 53.47263806206839, 53.81607362202236, 51.60878379004342, 51.255829198019846, 48.88586119243077, 47.188600403921946, 46.35616452353341, 47.78080231802804, 48.71915306363787, 49.175979750497, 50.96665906906128, 54.90647874559675, 53.08470276423863, 52.78485325404576, 51.29941872188023, 50.6122453553336, 44.764231477464946, 51.20598976952689, 53.047158173152376, 53.27613605771746, 51.099442618233816, 52.000144549778526, 50.837144647325786, 48.90636532647269, 51.47338424410139, 49.55450371333531, 50.247805391039165, 50.773353236062185, 52.90063803536551, 53.53857299259731, 55.682286807468955, 49.03875977652413, 54.14188855034964, 55.84482601710728, 58.167421204703196, 52.77699484143938, 52.126629556928364, 48.06100927080427, 49.228275367191856, 52.448053223746165, 51.157067503247944, 50.79073068073818, 55.0077348436628, 52.417363030569895, 49.610155309949604, 47.59432656424386, 51.427769320351736, 50.67224652426583, 55.41992630277361, 54.38912630081177, 56.436562401907786, 51.983937876565115, 51.283764430454795, 45.46725368499756, 47.844472135816304, 42.23163740975516, 45.41368307386126, 42.786534445626394, 46.930905614580425, 44.43380641937256, 45.37973764964512, 45.2638521194458, 48.52012538909912, 46.92710494995117, 51.33561536243984, 49.2083340372358, 53.11331197193691, 48.76114797592163, 53.06107888902937, 51.32607201167515, 52.74012075151716, 57.25015129361834, 55.84493718828474, 54.829596928187776, 54.98394768578665, 48.35534191131592, 56.5296230997358, 55.88447938646589, 56.35042558397566, 56.00140019825527, 64.6685379573277, 55.136787210192, 60.152952330453054, 58.22733204705374, 63.241725376674104, 56.232841219220845, 64.27807004111153, 48.244834286826, 54.275092465536936, 9.229557088443212, 1.0718535419021333, 2.9704645488943373, 3.120514805827822, 0.2297321440918105, 18.893018756593975, 66.15803718566895, 60.3460636138916, 62.958461216517854, 59.945194244384766, 61.55342429024832, 69.76795986720494, 22.89430914606367, 37.28186927522932, 35.799182755606516, 45.50615317480904, 36.64502171107701, 41.85723720278059, 61.19798224312918, 54.06675073078701, 1.5631476363965442, 0.3654697361801352, 0.16647958462791784, 0.30637576856783455, 0.21126881268407616, 0.1683284297053303, 0.23610016810042517, 0.22495603109044687, 0.14176849275827408], [0.05523364279153092, 0.027840008526774387, 0.029499065663133348, 0.07434932115886893, 0.015258939604141881, 0.02747653258432235, 0.01156621378114713, 0.006653068088261145, 0.0970269792846271, 0.06411519460380077, 0.0683383626331176, 0.036067769796188386, 0.15852924409721578, 2.2373807430267334, 31.039882114955358, 45.27205099378313, 43.76633814402989, 21.06655423981803, 36.085187980106895, 26.748818840299332, 1.4336466767958231, 38.13280126026699, 51.202404499053955, 59.39630740029471, 48.00804315294538, 52.19045918328421, 50.674129486083984, 44.94142096383231, 0.3737409423504557, 0.06024434231221676, 0.2248802658702646, 8.180995753833226, 13.19353825705392, 16.891894136156353, 62.72907338823591, 56.32119451250349, 65.19745567866734, 57.99522747312273, 60.4124675478254, 56.71786717006138, 61.133808680943076, 55.212744917188374, 57.91521896634783, 55.92707184382847, 56.23084013802664, 56.48848976407732, 57.08672618865967, 49.72902856554304, 52.0829427582877, 55.00213459559849, 50.09408344541277, 55.87384516852242, 56.92730324608939, 55.10838644845145, 51.38696255002703, 52.1119966506958, 52.91187674658639, 49.726426465170725, 52.559547492435996, 51.70747600282942, 51.74831404004778, 49.83272695541382, 47.26268209729876, 47.419544628688264, 44.0677683694022, 41.37289912360055, 42.88808931623186, 44.34086036682129, 43.84093747820173, 46.853394985198975, 48.05682298115322, 48.059960092817036, 43.76032795224871, 39.443523338862825, 41.60118218830654, 44.14757537841797, 43.15001555851528, 45.18083504268101, 42.72651243209839, 44.67812245232718, 42.24914687020438, 41.85136944907052, 42.684448037828716, 44.42002814156668, 46.56857442855835, 46.89408711024693, 47.67528697422573, 49.11693743297032, 47.54168006352016, 48.295167037418906, 47.927444049290244, 48.011371340070454, 46.256767068590435, 46.38031646183559, 45.94342415673392, 42.94805921827044, 42.49335173198155, 44.634067399161204, 44.04087536675589, 45.51506771360125, 45.36896446772984, 45.41381508963448, 42.50374623707363, 42.802157470158164, 42.42926154817854, 43.07424545288086, 46.068522998264854, 46.89751604625157, 47.8885098184858, 47.12116813659668, 44.44736235482352, 39.86373996734619, 40.32659074238369, 38.558600766318186, 40.418814182281494, 43.19625582013811, 43.58369779586792, 43.4401410647801, 45.18112339292254, 46.95044394901821, 49.62718187059675, 49.18692316327776, 48.701879841940745, 47.361422947474885, 46.47217859540667, 45.56056451797485, 46.24332577841622, 48.518138204302105, 48.4807117325919, 50.7920160974775, 48.13686275482178, 52.05143962587629, 47.669905594417024, 44.69827570234026, 47.367356709071565, 53.25269283567156, 50.78229904174805, 49.8691737311227, 53.95469018391201, 54.106487478528706, 51.41302176884243, 55.77063315255301, 56.29729618344988, 59.37148148672921, 57.53844942365374, 57.249439103262766, 18.675941399165563, 1.6534716125045503, 2.432648790734155, 1.4863255300692149, 0.10251248707728726, 1.325602405837604, 45.244511808667866, 46.238819871629985, 53.354379722050254, 52.75058821269444, 49.144323757716585, 53.51056480407715, 53.652453967503135, 14.38387497833797, 33.55764177867344, 22.01676729747227, 30.818790435791016, 24.97832751274109, 29.889142308916362, 41.53102970123291, 11.310680661882673, 0.2526419833302498, 0.026502962057877864, 0.030474432611039708, 0.07861988485923835, 0.07968470307865314, 0.03449398585196052, 0.08042512727635247, 0.03063587305535163, 0.06342129755233016, 0.04609796943675194, 0.03253709764352866, 0.010959590751943844, 0.04598150907882622, 0.04230061266571283, 0.04835742658802441, 0.08523001016250678, 0.02128640010154673, 0.0441428318486682, 0.0504006956970053, 0.04077497756640826, 0.086574140536998, 0.1568852351712329, 1.5089651495218277, 38.2594564982823, 48.07187625340053, 38.729974610464915, 35.486051763807026, 40.65810319355556, 29.98516641344343, 4.811799926417215, 36.89594895499093, 58.788048199244905, 61.026987075805664, 56.17099182946341, 57.32213463102068, 58.89162499564034, 50.6177795955113, 0.174044313707522, 0.18218879667775972, 0.3629000426403114, 12.839217475482396, 17.84794541767665, 20.874198572976248, 68.61997154780796, 60.318368094308035, 65.56270163399833, 61.755491801670615, 63.63937773023333, 58.31174223763602, 63.73474175589425, 55.367210320064, 58.372789110456196, 57.44536788122994, 56.56017085484096, 58.51565102168492, 56.54095213753836, 49.369980403355186, 52.1893926348005, 54.9341846874782, 49.77425439017159, 56.347020966666086, 57.280351638793945, 56.35566452571324, 53.01003394808088, 53.13496950694493, 54.22145584651402, 51.84030818939209, 52.922132287706646, 53.22323942184448, 52.6826730455671, 51.55813142231533, 49.64574745723179, 47.94033990587507, 46.34170879636492, 41.912037645067485, 43.75136477606637, 46.43859795161656, 45.71685034888131, 48.13026544025966, 48.61985983167376, 48.67641816820417, 46.08775213786534, 42.418241705213276, 44.08983237402779, 46.93705824443272, 44.08902638299124, 47.175794873918804, 44.80624723434448, 48.09604556219918, 45.99142231260027, 45.796084131513325, 45.38499048777989, 46.02536426271711, 48.78884696960449, 50.53039557593209, 49.90377228600638, 51.582901750292095, 50.555079051426475, 49.59690509523664, 49.890383107321604, 51.76801218305315, 50.031865801130024, 50.58061368124825, 48.93282754080636, 46.21826362609863, 44.955088070460725, 47.039262771606445, 47.13846220288958, 47.58581502096993, 48.45362418038504, 50.61215155465262, 44.93482712336949, 45.044337681361604, 45.52210623877389, 47.845312867845806, 48.828243255615234, 50.12605905532837, 49.518956729343955, 48.94059215273176, 46.513509954724995, 42.587829862322124, 42.351671014513286, 40.010996614183696, 40.48223386492048, 43.86453356061663, 43.36546877452305, 44.7030143737793, 44.778482232775005, 48.43338060379028, 51.44480282919747, 48.620843001774375, 49.78091423852103, 49.53869308744158, 47.21196372168404, 48.23034381866455, 49.10545553479876, 51.9633468900408, 51.72472490583147, 53.93614196777344, 52.185317516326904, 53.65406942367554, 50.73338024956839, 44.52153090068272, 48.84804562159947, 55.499250411987305, 51.117646898542134, 51.24790130342756, 55.247423376355854, 56.664438996996196, 54.50550167901175, 59.585583278111045, 58.23022944586617, 61.62368447440011, 57.1773932320731, 58.8458502633231, 21.730815921510967, 2.740904752697263, 4.388915623937335, 2.1768866862569536, 0.050698250266058106, 1.856968172958919, 52.326484067099436, 50.32885612760271, 57.168874740600586, 57.70107201167515, 52.069459778921946, 59.24404457637242, 57.57944032124111, 18.204193455832346, 42.38310466493879, 21.931005682264054, 39.71075105667114, 24.91987579209464, 32.62929991313389, 49.76787941796439, 10.246402502059937, 0.28519489083971294, 0.0826329445200307, 0.14303588760750635, 0.11937875061162881, 0.11138133332133293, 0.019552858479853188, 0.10822942280875784, 0.025763542092006122, 0.028018758399412036, 0.10115047051970448, 0.2211070004850626, 0.15399924931781633, 0.1529633163341454, 0.13715976077531064, 0.17931194390569413, 0.15401400066912174, 0.11514907543148313, 0.19902439042925835, 0.13823662299130643, 0.25384684439216343, 0.26714292807238443, 0.3584937447948115, 5.685135509286608, 62.718616349356516, 56.94162348338536, 67.45020757402692, 32.70313147136143, 54.449030194963726, 34.16313212258475, 5.52041586807796, 49.651872294289724, 63.18823119572231, 67.54268114907401, 62.88022450038365, 61.20279039655413, 62.3357914515904, 53.99251617704119, 0.5609039164015225, 0.9867705702781677, 1.719591538820948, 14.804702179772512, 20.064469405582972, 25.177509784698486, 70.57835606166294, 64.04087243761334, 69.1162188393729, 64.34868458339146, 68.60264274052211, 61.04212025233677, 66.28225013187954, 58.647319384983604, 62.39850589207241, 59.73753343309675, 58.362693377903526, 59.73196792602539, 58.12817430496216, 50.61923524311611, 52.58925798961094, 53.43454108919416, 49.80649403163365, 57.96351589475359, 59.84161049979073, 58.22972570146833, 55.7301355770656, 54.558596338544575, 55.35407822472708, 52.53122663497925, 55.96175725119454, 55.4350768498012, 56.68823310307094, 53.96097135543823, 53.78681475775582, 51.906111104147776, 47.295626980917795, 45.36490324565342, 45.74815198353359, 47.80333185195923, 49.52506767000471, 52.298013823372976, 51.774977752140586, 52.55428770610264, 48.02607025418963, 45.28759411403111, 47.190094266619, 49.74037149974278, 46.91192313602993, 48.334691865103586, 47.227298395974294, 51.550384180886404, 49.75381626401629, 50.32249852589199, 50.65245805467878, 49.96072319575718, 52.80455487115042, 54.09777443749564, 53.675883293151855, 55.20378174100603, 52.68206855228969, 52.841147559029714, 52.74726002556937, 55.71525253568377, 51.75095782961164, 52.32925987243652, 52.650735650743755, 50.4553029196603, 46.73913185937064, 50.454371861049104, 49.66347926003592, 51.17476109095982, 52.0965438570295, 53.88269989831107, 48.49691145760672, 49.913819381168906, 47.82384640829903, 50.46120888846261, 50.95241526194981, 52.42724336896624, 50.97703272955758, 51.96804734638759, 48.60451126098633, 45.05715363366263, 42.69963679994856, 42.05885655539376, 42.872407232012065, 46.83057362692696, 45.50499629974365, 47.24923733302525, 47.58604431152344, 50.043997355869834, 52.10787289483206, 51.73341710226876, 50.3292487008231, 50.78911869866507, 50.25530249731881, 49.49395363671439, 51.90222011293684, 53.12758009774344, 53.42994485582624, 56.07626356397356, 52.41115134102957, 55.92226021630423, 52.343392508370535, 46.45790352140154, 51.015296459198, 56.5832006590707, 55.39752531051636, 52.736094270433696, 60.31483840942383, 59.169893401009695, 57.02112129756382, 63.09609808240618, 61.21361568995884, 63.47180107661656, 59.357036181858604, 61.40012618473598, 27.701475926807948, 3.3780990753855025, 5.507943851607187, 4.114545592239924, 0.27322642877697945, 1.6510203097547804, 56.74523612431118, 55.35125725609915, 61.76238441467285, 62.827862875802175, 59.32524817330496, 63.05463123321533, 64.36444309779576, 21.430757965360367, 42.58490467071533, 30.83283621924264, 45.63447250638689, 37.545723642621724, 41.829336711338584, 55.65349694660732, 23.89574432373047, 0.5396833036627088, 0.15418412296899728, 0.1839856116899422, 0.220104044303298, 0.25478257132428034, 0.07009374629706144, 0.24352486112288066, 0.11560708656907082, 0.14747007324227265], [0.058707168724920065, 0.13686385165367806, 0.07325856254569121, 0.03225004679656454, 0.11835959101361887, 0.012160062540455588, 0.054853161065174, 0.03578108875080943, 0.04785055075106876, 0.05724686636988606, 0.03028374391474894, 0.02087538260301309, 0.0508867642576141, 0.07375308565263237, 17.210715702601842, 38.71051270621163, 33.5902670451573, 22.78412982395717, 32.979607241494314, 53.72098057610648, 3.9830830693244934, 14.47491635595049, 54.355594294411794, 50.45642505373274, 56.979532854897634, 56.46926062447684, 47.09777702604021, 51.74001441683088, 6.0136663147381375, 0.4341447539627552, 0.2083531612796443, 11.077975937298365, 15.549029690878731, 1.8780277286257063, 42.90475804465157, 59.85229682922363, 63.983000891549246, 57.52283682141985, 62.91456249782017, 57.51207058770316, 58.48881013052804, 56.25346347263881, 60.6705653326852, 57.34206206457955, 56.40915870666504, 54.215289320264546, 50.728822231292725, 51.40976306370327, 48.103897026606965, 49.37425354548863, 53.224236488342285, 51.52693053654262, 58.80885110582624, 54.72906344277518, 50.12932818276541, 51.664716788700645, 52.750181743076865, 53.26402882167271, 56.22346115112305, 52.71725075585501, 54.4880964415414, 50.97743919917515, 46.02988406590053, 44.479070459093364, 44.97789553233555, 42.126177651541575, 39.011824812207905, 42.49897629874093, 41.362667901175364, 45.894765922001426, 44.651014055524556, 44.22227546146938, 40.70070954731533, 43.208005223955425, 41.339738845825195, 44.009354863848, 44.63562379564558, 44.51727165494646, 42.30148417609078, 42.153671673366, 40.28706244059971, 40.554429122379844, 41.565864494868684, 43.57357774462019, 45.95370749064854, 46.43965407780239, 46.9705103465489, 47.62517656598772, 45.26862900597708, 44.70333399091448, 47.99448721749442, 48.13235684803554, 48.551864760262625, 46.34253215789795, 45.62067685808454, 43.684870515550884, 42.55913380214146, 42.83275386265346, 43.32174376079014, 44.40445722852434, 44.368993622916086, 44.58344977242606, 42.32840844563076, 41.14975772585188, 40.619294030325754, 42.03345741544451, 42.8912160055978, 45.65042209625244, 48.12071514129639, 44.27786452429635, 42.56177064350673, 38.700674057006836, 40.75950172969273, 41.27127129690987, 41.874110903058735, 41.57049894332886, 42.21274873188564, 44.456311634608674, 46.50568975721087, 48.83952365602766, 48.0317816734314, 50.05212674822126, 48.027716977255686, 51.13113682610648, 46.73579324994768, 48.8081316947937, 47.14980861118862, 47.28558335985456, 48.3190028326852, 52.191973890577046, 50.181356293814524, 51.471803528921946, 46.46286106109619, 44.34454986027309, 47.729708739689414, 50.276650837489534, 51.863192081451416, 50.741342885153635, 50.94184010369437, 57.07968766348702, 51.32700307028634, 59.90332439967564, 54.008274691445486, 60.70681408473423, 51.28100946971348, 30.435725825173513, 1.229432497705732, 8.289237397057668, 3.720815931047712, 1.5418175352471215, 0.24655161585126603, 15.328881229673113, 55.93575014386858, 48.102156502859934, 51.37405627114432, 52.508867331913535, 52.78780971254621, 63.19643701825823, 18.247086422783987, 15.855686698641096, 38.56576088496617, 25.38773795536586, 34.73863751547677, 22.95508851323809, 40.975764410836355, 42.555777822222026, 2.9880120073046004, 0.4653143999832017, 0.2467737410749708, 0.07857476228049823, 0.13082859478890896, 0.051903878072542806, 0.11917862349322864, 0.018573593348264694, 0.09704622932310615, 0.037841792817094495, 0.057007438503205776, 0.13985596038401127, 0.03515202572037067, 0.01913902845366725, 0.06583020543413502, 0.060560451421354494, 0.037062732835433314, 0.11171146096395594, 0.051166629418730736, 0.10691560937889985, 0.17516035453549453, 0.039574398060462306, 0.02898975388546075, 0.4748017851795469, 24.275439058031353, 51.1972975730896, 29.708284173692974, 26.937816790172032, 44.767858437129426, 50.19960226331438, 9.922377603394644, 13.396773065839495, 57.72783647264753, 57.17858484813145, 64.05019692012242, 62.02887562343052, 51.58760220663888, 58.72760581970215, 6.972116027559553, 0.4155972163592066, 0.4014873249190194, 12.158853343554906, 25.496690920421056, 5.083959996700287, 48.55646446772984, 62.83932045527867, 66.57712473188127, 59.30494553702218, 65.6315860748291, 58.87133625575474, 61.44412912641253, 58.783768108912874, 62.61956977844238, 59.045305252075195, 57.47418206078665, 54.47909157616751, 50.66940818514143, 51.58760915483747, 48.621513502938406, 49.586461952754426, 52.74074956348964, 51.52114963531494, 59.59101676940918, 54.75207587650844, 53.089330264500205, 52.261507987976074, 54.53477096557617, 54.44558041436331, 57.84912770135062, 53.37259095055716, 55.182749543871196, 50.03442621231079, 48.88721261705671, 46.257437569754465, 47.05734198434012, 43.87259694508144, 40.70889105115618, 45.20517805644444, 44.33292899812971, 48.29619884490967, 46.64521305901663, 46.876866000039236, 41.35408340181623, 43.293818950653076, 43.01697840009417, 45.74662337984358, 45.257407665252686, 46.729776109967915, 42.724605151585166, 46.262409005846294, 43.10998698643276, 43.69262817927769, 43.037687505994526, 45.94876732145037, 48.70909207207816, 48.73225041798183, 49.253351415906636, 50.8848683493478, 48.71851035526821, 46.949523312704905, 49.72500555855887, 50.93418666294643, 51.260578291756765, 49.45645768301827, 48.701931953430176, 46.31912020274571, 46.09821959904262, 45.847962856292725, 46.494822774614605, 46.72719485419137, 47.00307655334473, 47.56657198497227, 45.669203077043804, 45.44000979832241, 43.111227239881245, 45.38009895597185, 44.97909409659249, 48.88188682283674, 50.710308756147114, 48.224496909550254, 44.61409132821219, 42.86868299756731, 41.75426489966256, 42.73880379540579, 42.92421300070626, 45.889679840632844, 43.7744779586792, 46.77512352807181, 46.8420763696943, 51.950735909598215, 49.00340386799404, 50.80422060830252, 49.496437617710654, 52.466181073869976, 47.65043674196516, 51.36598593848092, 50.01846272604806, 51.04189763750349, 52.47197239739554, 55.22676985604422, 53.048863955906455, 54.66698128836495, 47.256126471928184, 45.14664643151419, 49.14033896582467, 51.02224118368966, 53.367209570748464, 53.93003102711269, 53.249739851270405, 59.843576839991975, 54.61864614486694, 61.333062171936035, 55.809577805655344, 60.029427255902974, 50.56914915357317, 35.76431322097778, 3.7461442862238203, 11.424846512930733, 4.428074368408748, 1.803062419806208, 0.22071212024560996, 20.326088190078735, 60.514536585126606, 53.80879885809762, 55.39870997837612, 58.42290646689278, 61.255832944597515, 63.98978233337402, 20.26377500806536, 27.76031674657549, 40.65011623927525, 26.856317894799368, 41.47383213043213, 25.805470602852957, 48.133430344717844, 48.34320688247681, 4.243652675833021, 0.5703475496598652, 0.1806423475167581, 0.14492282564086573, 0.0745910085471613, 0.15975817958159105, 0.02574040913688285, 0.039157702920160124, 0.038621823103832345, 0.11130638912852321, 0.30532558634877205, 0.3411854292665209, 0.1924993127052273, 0.08803785592317581, 0.15888456574508122, 0.16537851228245667, 0.17631034925580025, 0.17891167609819345, 0.19245250735964092, 0.30882804840803146, 0.21919773864958966, 0.09362308800752674, 0.26283748767205645, 0.6102013311215809, 45.0036802973066, 61.719562666756765, 46.84712423597063, 32.81366341454642, 50.36347900118147, 66.84967476981026, 8.665741171155657, 19.656766482761928, 71.71001611437116, 59.47210529872349, 69.18157359531948, 65.57492351531982, 57.330816405160085, 61.872381346566335, 7.708486982754298, 0.5666073560714722, 0.7533242340598787, 15.669655629566737, 31.48535544531686, 6.755369143826621, 52.82355472019741, 61.70317186628069, 70.99449757167271, 61.120370864868164, 71.45514924185616, 60.21561118534633, 64.57583509172711, 61.22271088191441, 65.87190341949463, 59.45922333853585, 59.28223187582833, 55.61012976510184, 52.92508527210781, 51.06401375361851, 46.853745869227815, 48.729783807482036, 53.64992134911673, 52.4987542288644, 63.095132282802034, 56.77836166109358, 52.40103823798043, 54.979851722717285, 55.29112754549299, 56.553389413016184, 61.32421016693115, 56.28541823795864, 57.89751148223877, 52.606343609946116, 50.36427456992013, 48.46716274533953, 49.26157113483974, 46.31539249420166, 43.60427141189575, 46.55185011454991, 48.02049085072109, 52.119049072265625, 48.39894185747419, 49.80363484791347, 44.582661151885986, 47.20551579339163, 46.19074528557913, 50.59757423400879, 48.98168379919869, 50.353779315948486, 44.490159784044536, 50.273093359810964, 46.73094688143049, 46.744732107434956, 45.5482314654759, 47.08919947487967, 51.40149818147932, 52.97204467228481, 51.13810934339251, 52.778943811144146, 49.2873489516122, 49.64667156764439, 52.98309578214373, 54.222174985068186, 54.424958160945344, 54.40729236602783, 50.913223947797505, 49.773187841687886, 49.06091758183071, 47.520425524030415, 49.60236985342843, 50.6358379636492, 50.442410537174766, 51.153190408434185, 47.47251074654715, 48.58472279139927, 45.38572004863194, 48.564760616847444, 47.57230077471052, 50.5694375038147, 52.29323346274239, 49.189011096954346, 48.74598005839756, 44.7394437789917, 43.40196418762207, 45.760040351322715, 45.08528341565813, 47.15361622401646, 44.10149492536272, 48.01396649224417, 46.958191190447124, 52.313782760075156, 48.888501507895334, 52.57032414845058, 49.86856576374599, 55.575885568346294, 50.60682576043265, 54.36013494219099, 50.790032386779785, 52.833139760153635, 55.16421175003052, 57.60707678113665, 54.560156209128245, 56.92357553754534, 49.661134243011475, 46.96039376940046, 50.49993119921003, 53.94253431047712, 54.370567662375315, 57.82438169206892, 55.38584886278425, 61.071802956717356, 56.7080146244594, 65.34988525935582, 59.477399826049805, 65.03994696480888, 53.981159346444265, 44.12166901997158, 4.736731588840485, 12.1774389062609, 6.984337908881051, 3.96738144329616, 0.5606457473976272, 20.48674270084926, 66.41617665972028, 56.90786566053118, 59.06492696489607, 64.27315071650914, 60.801281792776926, 72.75366333552769, 25.65125186102731, 25.531279053006852, 46.62129388536726, 38.83227988651821, 48.77570097787039, 35.68422480991909, 55.044362272535054, 59.22845976693289, 10.159138338906423, 1.3012047835758753, 0.6945169610636575, 0.37920613480465754, 0.34257664318595615, 0.2735022668327604, 0.34815059123294695, 0.16360061482659408, 0.2053954949868577, 0.21221756748855114], [0.03329099076134818, 0.033121173802231035, 0.014448102131219847, 0.03686945892072149, 0.03684203592794282, 0.01602519563000117, 0.021037174189197164, 0.07025869816009488, 0.0459313687336232, 0.036017880508942265, 0.027028567157685757, 0.04820605221071413, 0.09235625634235994, 0.14317327737808228, 7.99453215939658, 35.03287288120815, 35.81427076884678, 42.94126388004848, 30.12809780665806, 54.92912292480469, 23.42443585395813, 2.0194552711078098, 48.96050916399275, 47.38312564577375, 57.10162660053798, 54.103228773389546, 53.740675245012554, 48.8348787852696, 23.46918225288391, 0.12827491467552526, 0.48036305819238934, 1.3216999066727502, 24.315604857036046, 11.454563958304268, 17.079450334821427, 44.68557786941528, 66.73554365975517, 60.258231435503276, 59.3851694379534, 58.19482837404524, 60.31864602225167, 56.45861945833479, 55.95777940750122, 53.38807153701782, 53.03749670301165, 51.201237201690674, 52.467911175319124, 55.290154797690256, 52.91484362738473, 45.68590307235718, 53.12841388157436, 52.91730676378523, 59.37792246682303, 54.316364765167236, 55.509109905787874, 54.35438878195626, 57.37810584477016, 53.660670212336946, 54.72601318359375, 57.09814207894461, 53.742158685411724, 52.88361494881766, 47.58833026885986, 45.89685385567801, 44.46017483302525, 43.729342460632324, 40.23281438010079, 41.43907029288155, 40.128285680498394, 41.51724794932774, 40.73678806849888, 38.242732184273855, 36.98985038484846, 39.59098495755877, 43.00965847287859, 42.841303621019634, 42.19325903483799, 42.34053305217198, 43.37807280676705, 40.575930322919575, 40.38882923126221, 40.170673166002544, 43.876279490334646, 44.31898396355765, 47.50265898023333, 43.711530753544395, 38.92042473384312, 46.81574617113386, 43.85071011951992, 46.87487186704363, 48.984397070748464, 51.453050340924946, 48.3199964250837, 46.4413355418614, 45.55032287325178, 45.2873717716762, 41.09053128106253, 40.78355291911534, 41.946431228092735, 40.34012235913958, 43.077775137765066, 43.45002835137503, 43.120940821511404, 40.8991049357823, 38.93230267933437, 37.00690473828997, 40.739775793892996, 42.8368706703186, 43.77937296458653, 43.223861013139995, 42.42578744888306, 40.257952962602886, 38.175418036324636, 41.51192562920706, 41.309382166181294, 43.313763754708425, 46.497192110334126, 47.69195917674473, 49.81117016928536, 51.82886103221348, 52.11579384122576, 49.319748401641846, 48.31347206660679, 47.474101884024485, 50.28627756663731, 48.61695548466274, 50.240252699170796, 47.73450647081648, 49.85052824020386, 51.21362236567906, 51.67647661481585, 49.194934436253135, 44.033343519483296, 41.803538049970356, 46.933924606868196, 46.03273630142212, 51.89645310810634, 52.29154505048479, 48.82267427444458, 53.51878799710955, 53.25968967165266, 55.29100595201765, 55.668345246996196, 43.32003797803606, 27.72513801710946, 3.4533530601433347, 9.71325419630323, 7.744781766619001, 1.0761358035462243, 0.7078876293131283, 1.453307798930577, 45.43030663899013, 50.06019708088466, 50.24095099312918, 52.81369522639683, 54.81934833526611, 45.5433086667742, 33.746837752205984, 4.002565383911133, 40.096112046922954, 31.61002697263445, 29.607514449528285, 27.04364480291094, 23.171144485473633, 45.4046573638916, 27.13719708578927, 0.6841404778616769, 0.07189472751425845, 0.03371415234037808, 0.039275279468191523, 0.012693747295998037, 0.021302286302670836, 0.04678469437307545, 0.011968958241465901, 0.08573486057243176, 0.016182927880436182, 0.05234117353601115, 0.06208571671907391, 0.03465115152565496, 0.02822189312428236, 0.04257663053327373, 0.027094839672957147, 0.022027073660865426, 0.02482640041437532, 0.007406582074638988, 0.01874823129868933, 0.05723170789756945, 0.03246301179751754, 0.04195485496893525, 0.2559949505542006, 8.97490039893559, 49.02765655517578, 35.915193353380474, 37.61131463732038, 42.13220173971993, 52.477405888693674, 29.61522000176566, 4.7769182324409485, 49.28801597867693, 56.034539631434846, 62.01602145603725, 60.842116355895996, 59.67033740452358, 56.43035766056606, 29.10575897353036, 0.06876166670450143, 0.43793545769793646, 1.3288587225334985, 25.270923103604996, 12.948609045573644, 21.284319468906947, 50.29093633379255, 67.91371495383126, 63.555519921439036, 61.34579127175467, 60.06163215637207, 61.471671785627095, 56.14553015572684, 56.037377970559255, 54.392655985695974, 54.64075878688267, 51.947244439806255, 52.32108531679426, 55.30512121745518, 52.84747041974749, 47.94146203994751, 53.62730148860386, 53.12598548616682, 58.6247238431658, 55.128605706351145, 57.65905278069632, 54.58293240410941, 59.314659118652344, 54.785976137433735, 57.1460394859314, 56.33100189481463, 55.527779715401785, 54.30830832890102, 49.385655539376394, 47.529402596609934, 46.66108621869768, 45.70201594488961, 42.75630283355713, 42.75654602050781, 43.76419115066528, 43.22089065824236, 43.13327039991106, 41.7749844278608, 38.51161009924752, 41.97850063868931, 43.79518706457955, 44.19324936185564, 44.71378755569458, 44.82136304037911, 44.56716319492885, 42.01989800589425, 42.131784847804475, 41.84380980900356, 45.90690789903913, 47.44249452863421, 50.59462819780622, 46.88400527409145, 43.56325966971261, 50.1723027910505, 45.86282852717808, 49.85111883708409, 50.88139425005232, 52.08226530892508, 52.43776988983154, 50.34018169130598, 48.22341646466936, 48.241811820438926, 44.29597847802298, 44.12885693141392, 43.33023793356759, 43.68527003696987, 45.4533086504255, 46.728713035583496, 45.616570472717285, 43.57875762666975, 42.35736506325858, 39.8037804876055, 43.68737881524222, 45.17196914127895, 46.43894188744681, 45.96422011511666, 44.053965772901265, 40.72436121531895, 39.904320921216694, 41.062047140938894, 41.3159829548427, 44.44001463481358, 47.171188218253, 49.6847859110151, 51.525947366442, 51.53929485593523, 53.01918819972447, 52.275557245527, 51.25808736256191, 50.87351846694946, 53.502209595271516, 50.770883151463096, 52.3585638999939, 50.652906213487896, 52.55857821873256, 53.72164065497262, 54.446355138506206, 52.30832495008196, 45.96368857792446, 43.41238995960781, 48.35134669712612, 47.84608064379011, 53.64189965384347, 54.74589892796108, 50.885500635419575, 53.98129136221749, 56.26812417166573, 55.782292229788645, 54.56314393452236, 45.837630884987966, 35.10619722093855, 5.344216934272221, 13.557332038879395, 7.051589523042951, 1.2008841953107288, 0.586888713496072, 2.5125148594379425, 55.58466461726597, 53.03070831298828, 57.33855322429112, 55.296772956848145, 64.89101232801164, 48.56775876453945, 37.20590114593506, 7.418973786490304, 48.27087960924421, 32.63316658564976, 32.524600982666016, 33.907219546181814, 25.309105191911968, 50.66908509390694, 30.199667726244243, 0.38265216989176615, 0.10099348465778998, 0.02148934992562447, 0.082652676318373, 0.04806817050224968, 0.05615287793001958, 0.011778744519688189, 0.020643659501469562, 0.050790402106940746, 0.03353052040828126, 0.140008807182312, 0.16418152222675936, 0.142219854252679, 0.09826291725039482, 0.11477309917765004, 0.19276670978537627, 0.11710963451436587, 0.18472739974302904, 0.13632494557116712, 0.12641921639442444, 0.14807004747646196, 0.12502208564962658, 0.24332344478794507, 0.37924985960125923, 22.940509455544607, 64.2233738218035, 47.58551972252982, 62.191762242998394, 43.34095900399344, 75.23980522155762, 31.90279279436384, 6.65174674987793, 59.82169001443045, 62.85707310267857, 65.59432983398438, 67.12093244280133, 63.43244647979736, 66.02465261731828, 32.681397506168906, 0.25269170637641636, 0.7633333855441639, 2.689010828733444, 30.856658118111746, 16.84752467700413, 28.376394408089773, 52.63390016555786, 70.14716475350517, 64.19258635384696, 63.24584565843855, 61.96722425733294, 64.22073350633893, 57.33713926587786, 58.22385794775826, 56.54728194645473, 55.939380577632356, 51.85500710351126, 52.807584285736084, 55.92788825716291, 54.03660249710083, 49.39414971215384, 52.847727503095356, 56.00833102634975, 61.919066292899, 57.2325758252825, 61.33173506600516, 56.58109188079834, 59.62376362936837, 57.81045055389404, 58.67165197644915, 60.25073432922363, 58.67712715693882, 57.725686005183626, 51.87523330960955, 48.85689762660435, 48.13127987725394, 47.577800273895264, 44.89120633261544, 44.96076474870954, 47.977002075740266, 46.027452196393696, 46.15924562726702, 44.13773325511387, 41.91607802254813, 45.09233236312866, 47.3202930859157, 48.5818636076791, 46.13383953911917, 46.77869837624686, 49.54414742333548, 45.161800452641074, 47.530201639447895, 44.63770478112357, 49.333988734654014, 52.514947005680625, 55.15307378768921, 51.185503005981445, 43.70209162575858, 54.01358311516898, 46.870074135916575, 51.99954005650112, 55.103324685777935, 55.75070571899414, 56.50245564324515, 52.99075617109026, 52.335700852530344, 51.270927633558, 47.01855713980538, 47.86390624727522, 47.05050148282732, 45.60675266810826, 49.760066168648855, 50.093496322631836, 49.116833209991455, 45.85040862219674, 45.79423243658883, 42.54448005131313, 45.89454705374581, 48.11552831104824, 48.859360763004844, 48.51452514103481, 46.798702239990234, 43.077636173793245, 41.94765758514404, 44.40611089978899, 44.14039094107491, 46.57064151763916, 50.806513513837544, 50.83106844765799, 50.091658524104524, 52.445676939828054, 55.9855444090707, 54.454595702035085, 53.484397888183594, 50.68366936274937, 55.53506490162441, 51.98375722340175, 53.87914589473179, 53.372177532741, 56.070083141326904, 56.04028926576887, 56.31004612786429, 54.170525550842285, 45.6609069279262, 43.3786529813494, 49.758676528930664, 47.6100538117545, 55.452565465654644, 55.95420455932617, 53.06446613584246, 55.03268929890224, 56.859120573316304, 57.239079339163645, 58.49592508588518, 49.95170790808541, 40.6680634362357, 9.60507595539093, 13.391056435448782, 13.630696330751691, 2.6438536175659726, 0.9027558299047607, 2.0175549387931824, 59.25940009525844, 55.6214588029044, 62.697938510349815, 57.98809167316982, 66.20122023991176, 53.64634997504098, 44.66092218671526, 7.910433769226074, 53.75620794296265, 39.10085902895246, 44.25476871218, 37.29200669697353, 37.09331948416573, 57.316444056374685, 46.383561270577566, 1.3517299124172755, 0.1728248777134078, 0.11911005074424402, 0.21240487029509886, 0.14895145089498588, 0.13003971640552792, 0.17368709216160433, 0.17102655635348388, 0.15102932868259294, 0.07076350107256855], [0.059755430689879825, 0.08144820880677019, 0.04484806043495025, 0.04346247496349471, 0.011268517567909189, 0.032916907620217116, 0.028986710655902113, 0.03667581181174942, 0.04932328047496932, 0.03682669085849609, 0.1206311226955482, 0.06266974538032498, 0.011844854186555105, 0.19227315698351177, 0.8493837309735162, 32.340577942984446, 42.2679625919887, 32.292117731911794, 24.905878646033152, 36.5553343636649, 61.135893140520366, 6.738333897931235, 19.93072005680629, 56.10538346426827, 50.02776983806065, 59.22711181640625, 52.398140839168, 53.684467792510986, 49.78414167676653, 5.650108771664756, 0.4652735250336783, 0.48897839018276756, 6.5086716158049445, 20.350353036608013, 5.835448494979313, 28.630050557000295, 40.98713166373116, 65.35207394191197, 56.05461992536272, 58.35596752166748, 53.565889835357666, 51.92675767626081, 49.54569687162127, 49.240684849875315, 54.38940075465611, 55.61034515925816, 56.788512979234966, 54.47459609167916, 55.09727280480521, 47.508394718170166, 52.89754261289324, 57.200600215366904, 56.01736715861729, 58.05455814089094, 54.230498926980154, 57.62227596555437, 55.584615979875835, 52.99328531537737, 46.220400197165354, 50.55325167519705, 53.614742619650706, 52.87485327039446, 53.26709645135062, 44.94772297995431, 46.83190073285784, 44.72635684694563, 42.263713768550325, 39.787810053144185, 40.396854400634766, 37.04390042168753, 37.82113981246948, 34.80833836964199, 38.48356716973441, 40.53942796162197, 43.525364194597515, 41.313360009874614, 41.18925128664289, 41.80406263896397, 41.060376099177766, 40.49865245819092, 40.01242446899414, 39.824024064200266, 42.405411856515066, 48.09591702052525, 48.4189908845084, 46.17520563943045, 21.76593038014003, 31.355656896318706, 43.80922589983259, 44.39819342749459, 42.92483833857945, 43.97839021682739, 51.464302948543, 44.65860496248518, 49.203320911952424, 43.48205607278006, 42.47342429842268, 40.2365733555385, 39.345036097935264, 40.26356015886579, 41.151873452322825, 41.64220435278756, 42.4880085672651, 41.36846269880022, 37.98636450086321, 35.27515656607491, 37.31817708696638, 38.44463293892996, 40.24735001155308, 40.195839541299, 40.08974402291434, 40.4616185597011, 39.40299449648176, 41.03220115389143, 44.04366854258946, 44.16804824556623, 49.01348917824881, 50.56688404083252, 52.1881662777492, 47.4440335546221, 45.4596905708313, 47.28244277409145, 46.43131276539394, 48.275573117392405, 47.38188191822597, 51.49301985331944, 49.54112148284912, 48.81707055228097, 47.63433081763131, 49.43348346437727, 49.94602428163801, 46.14780541828701, 41.33438178471157, 43.54262351989746, 43.40963847296578, 45.51155539921352, 45.88319717134748, 53.65163408006941, 49.1274014200483, 48.569144930158345, 53.71017265319824, 48.83566740580967, 36.41059991291591, 25.008013691220963, 8.3572142294475, 16.57364579609462, 13.326472061020986, 0.45419253249253544, 0.3255288579634258, 3.170492329767772, 37.11007506506783, 46.921181610652376, 52.674891063145225, 50.36077267783028, 52.028649534497944, 32.79681403296334, 52.41452816554478, 22.01160999706813, 11.501393948282514, 53.76862089974539, 30.875414780208043, 37.028152329581125, 23.721738849367412, 27.455457585198538, 44.24278654370989, 13.994622128350393, 0.31296369220529285, 0.04208696912974119, 0.06221969345850604, 0.0069104563528006625, 0.1069557447252529, 0.04784791124984622, 0.0409096023067832, 0.05135173037914293, 0.014995696854644587, 0.03803123640162604, 0.03977003666971411, 0.04564494213887623, 0.049430414369063716, 0.05941999011806079, 0.06449976111096994, 0.052542796824127436, 0.06381017954221793, 0.07389097075377192, 0.06446527117597205, 0.06376004937504019, 0.08523955036486898, 0.1271700289632593, 0.16277638476874146, 0.21509903429874352, 2.7121263997895375, 43.5775660106114, 47.98647941861834, 28.25838794027056, 35.4807641846793, 41.74946369443621, 65.93685517992292, 12.142653618540082, 21.152967248644146, 63.526413917541504, 54.27068730763027, 64.31959247589111, 59.21560559953962, 59.70555782318115, 56.6527556010655, 8.292537791388375, 0.5010731411831719, 0.6098027325102261, 4.818890563079289, 18.141586712428502, 15.382712398256574, 34.347196851457866, 45.868473938533235, 65.1235407420567, 55.796393598829, 60.13141291482108, 53.64051696232387, 52.14147785731724, 48.775753089359824, 50.698326587677, 54.14499092102051, 56.081787381853374, 57.86232233047485, 55.71429368427822, 54.6059205191476, 50.621083463941304, 55.00329147066389, 56.868184498378206, 56.92585802078247, 57.346140657152446, 55.27680035999843, 58.23988744190761, 56.38690710067749, 54.23483460290091, 47.888523714882986, 52.60478721346174, 55.70705018724714, 53.21872309276036, 53.06130123138428, 45.435976369040354, 48.03023222514561, 45.73193488802229, 45.6264716557094, 41.572065762111116, 42.577018465314595, 39.0698561668396, 40.702877385275706, 37.55239391326904, 40.206776005881174, 41.75081164496285, 45.94688435963222, 42.09603289195469, 45.57862983431135, 43.9286584854126, 41.75613049098423, 42.90300709860665, 40.6413128716605, 41.87257535117013, 46.51247467313494, 50.35700328009469, 49.250530447278706, 47.07923228400094, 26.04522340638297, 38.24331930705479, 46.27829606192452, 47.375614643096924, 49.013603823525564, 46.64006791796003, 54.46300649642944, 48.55892760413033, 50.87342119216919, 48.05118451799665, 45.992051124572754, 41.754862444741384, 42.37454795837402, 42.09886080878121, 44.56518643242972, 44.11015585490635, 45.498565741947715, 44.03960384641375, 40.77592727116176, 38.055964606148855, 42.197806630815776, 40.516339097704204, 43.01062774658203, 42.430355889456614, 41.84805515834263, 41.02624307359968, 40.087058544158936, 42.37262330736433, 43.86497824532645, 45.82545416695731, 50.01560354232788, 50.815004212515696, 52.25924634933472, 49.53449637549264, 47.794538906642366, 48.37905958720616, 48.79625722340175, 49.99603394099644, 50.30463470731463, 53.233873639787944, 51.73746790204729, 51.105306897844585, 50.93600014277867, 52.04153149468558, 52.46767841066633, 49.08831432887486, 42.06087153298514, 45.035412720271516, 44.887756552015034, 47.364639963422505, 47.965106759752544, 54.4560478755406, 52.94957767214094, 49.14481013161795, 54.193791593824116, 48.70039292744228, 38.79913003104073, 28.83208680152893, 13.50626972743443, 20.630080563681467, 10.670155763626099, 1.0070206608091081, 0.38003356754779816, 5.254608622619084, 44.87536791392735, 51.981801305498394, 57.30113022668021, 55.163377966199604, 57.66917283194405, 36.95891353062221, 52.51632969720023, 26.684787716184342, 11.430645653179713, 60.46289757319859, 32.362527302333284, 40.54772063664028, 30.82269879749843, 26.93109440803528, 52.799711976732524, 15.953053542545863, 0.2920618009354387, 0.08261231705546379, 0.1256700594510351, 0.044536280379231484, 0.029058394487947226, 0.051220603486789126, 0.019640674481966665, 0.10667483801288263, 0.0220067040396056, 0.04294085456058383, 0.21030241596911634, 0.09396362437733582, 0.16430607411478246, 0.23018624686769076, 0.22925554109471186, 0.14748353537704262, 0.13240732864609786, 0.1668636625898736, 0.1496799803738083, 0.12519607559910842, 0.21245031857064792, 0.29596978266324314, 0.46713010541030336, 0.6700771067823682, 7.9197235107421875, 61.865196909223286, 59.33647646222796, 51.12787464686802, 37.10228613444737, 53.36422184535435, 71.04936749594552, 12.780149102210999, 24.869082723345073, 69.68510954720634, 59.7952938079834, 70.16411140986851, 65.40026664733887, 65.923723084586, 65.28605215890067, 9.751620411872864, 0.6073449158242771, 1.0999063508851188, 6.998312039034707, 23.789680072239467, 29.359297003064835, 44.37860298156738, 48.43665320532662, 70.14375318799699, 56.47445092882429, 59.71800899505615, 54.75050210952759, 55.54301364081246, 50.93413455145699, 51.726083278656006, 54.63886887686593, 59.53456960405622, 59.001795632498606, 57.833570684705464, 54.10011945452009, 52.465830189841135, 55.85432073048183, 56.49286712918963, 59.482562337602886, 60.4943242754255, 59.13946723937988, 59.714111055646626, 60.152729988098145, 55.37948431287493, 50.120041915348594, 55.51825373513358, 55.88041121619088, 57.15043074744088, 56.990799358912874, 47.94795165743147, 50.214235169546946, 48.43821655000959, 48.653034005846294, 43.01014832087925, 46.206284931727815, 42.169378076280864, 43.19988625390189, 40.383743149893625, 45.062090328761506, 45.331520625523154, 49.892047200884136, 45.06219802583967, 48.06340639931815, 46.55412564958845, 46.097413608006065, 45.64150755746024, 44.984492846897666, 45.636550017765586, 49.629999365125386, 53.21722228186471, 53.90574707303728, 51.74468013218471, 23.09935048648289, 35.77238007954189, 47.591050488608225, 48.83299234935215, 49.26546212605068, 48.18223796572004, 59.550974300929475, 50.132771015167236, 55.58449786049979, 48.54776879719326, 47.931870051792686, 44.534819330487935, 45.25968667439052, 44.903431688036235, 48.22129031590053, 46.44674471446446, 48.87843704223633, 47.60387338910784, 44.276978628976, 41.00511360168457, 44.339262281145366, 44.74489116668701, 45.52143921170916, 44.30788769040789, 44.31457880565098, 43.92747729165213, 42.18517133167812, 43.3635892868042, 45.606415680476594, 48.83124835150582, 52.298826762608115, 53.63923154558454, 54.98988839558193, 53.43429095404488, 51.35311787469046, 51.44820397240775, 50.98921292168753, 49.73162719181606, 50.36938844408308, 56.41489791870117, 53.92620256968907, 52.5057441166469, 53.63110562733242, 54.677462645939414, 53.663421698978965, 49.64510474886213, 42.069462980542866, 45.14553471973964, 45.85677317210606, 48.195960657937185, 50.52512536730085, 52.99757930210659, 51.12111404963902, 50.074096952165874, 55.43748787471226, 51.048609597342356, 43.21818780899048, 33.57299034936087, 19.625188657215663, 20.093735218048096, 18.700895854404994, 3.2973075934818814, 1.0495963990688324, 4.490355849266052, 47.864392621176584, 57.83666263307844, 62.334353174482075, 60.427086557660786, 62.77954510280064, 43.15218339647566, 61.440995488848, 29.62001425879342, 16.053646087646484, 66.31398950304303, 40.601930482046946, 51.86421346664429, 35.0105413709368, 42.486361844199045, 58.87497016361782, 30.37074974605015, 0.7340627961925098, 0.3317677160458905, 0.21339888338531765, 0.16673402168921062, 0.21325882018676826, 0.15245183663708822, 0.09536104689219169, 0.11070619776312794, 0.13278631759541376, 0.14439069133784088], [0.08112749244485583, 0.023755863841090883, 0.1014690969937614, 0.04322874000562089, 0.06364936674279825, 0.06956701313278504, 0.0142430963460356, 0.0357454079868538, 0.023514395280342017, 0.02469057636335492, 0.0669247434873666, 0.02681466408206948, 0.06669689142810446, 0.03605698108939188, 0.05408005862097655, 26.28595416886466, 38.84024599620274, 35.44474819728306, 28.525263037000382, 25.37558208193098, 34.264197145189556, 19.931070940835134, 11.354905077389308, 51.87521941321236, 50.51436955588204, 62.66524028778076, 52.00018623897007, 59.047841344560894, 52.3647860118321, 45.54974617276873, 12.027407322611127, 0.09242878495050327, 0.7346793402518544, 3.7954104883330206, 6.164820466722761, 21.125308207103185, 32.29243040084839, 45.354734557015554, 59.27540179661342, 51.4929712159293, 52.325820514133994, 58.355842454092844, 56.56295360837664, 58.96993119376046, 59.94434656415667, 58.66182722364153, 57.38469968523298, 56.7512880052839, 54.92313357761928, 52.37749079295567, 48.72805718013218, 57.257617133004324, 54.75770391736712, 57.4131247656686, 56.950746468135286, 53.90621607644217, 54.63532529558454, 53.007584708077566, 48.86077472141811, 38.35917704445975, 55.24472747530256, 52.16291652406965, 53.14993592670986, 46.296257155282156, 43.446387495313374, 44.31750052315848, 40.08624560492379, 39.87921360560826, 38.71125268936157, 36.886506353105815, 37.65225689751761, 36.91820056097848, 38.29567745753697, 41.41752392905099, 41.457868644169395, 39.35700784410749, 40.393602643694194, 40.47441366740635, 37.74930238723755, 40.05004549026489, 39.07659591947283, 41.022293022700715, 42.60072224480765, 52.605030400412424, 46.93664830071585, 53.586967195783345, 14.063461405890328, 14.977173839296613, 43.87599808829171, 38.31134911945888, 13.649773478507996, 30.369749205453054, 56.42282581329346, 46.90718446459089, 52.00048153741019, 44.022681508745464, 43.840579645974294, 38.847044808524, 39.1066711970738, 38.481447969164165, 41.60773433957781, 40.22915267944336, 42.49848297664097, 40.02326018469674, 38.680677141462056, 35.628569739205496, 34.497159821646555, 36.25426197052002, 37.50524691173008, 36.98024797439575, 37.12772348948887, 40.823967116219656, 40.1684810093471, 42.419725145612446, 44.46052919115339, 46.69447578702654, 50.992586272103445, 51.59919875008719, 49.79461261204311, 46.94644178662981, 46.15477098737444, 47.845629010881694, 47.40755551201956, 46.705585956573486, 50.322237968444824, 51.58078254972185, 47.39124114172799, 48.04534455708095, 49.826421465192524, 47.86735602787563, 45.61683797836304, 41.68580429894583, 41.706954615456716, 42.172192096710205, 41.79614864076887, 45.899688720703125, 44.94028493336269, 45.90143271854946, 51.30863550731114, 49.69465235301426, 44.98507649557931, 42.1664320400783, 33.781405040196006, 11.728857125554766, 15.512652397155762, 16.418650593076432, 2.038370656115668, 0.8475578746625355, 3.775155186653137, 40.54815489905221, 54.027576787131174, 50.69191687447684, 51.56836264474051, 51.185631547655376, 45.507862431662424, 47.9775197165353, 64.55626201629639, 12.043793780463082, 16.883691787719727, 35.82287958690098, 26.98882177897862, 35.69627298627581, 21.16016037123544, 34.54538031986782, 38.40239136559622, 4.507841859545026, 0.3673996797629765, 0.06190559959837368, 0.12304241902061872, 0.012312448783112424, 0.018345559780885066, 0.014534355806452888, 0.05765216890722513, 0.08734231003160987, 0.023223106982186437, 0.06493351462164096, 0.01921461895108223, 0.0817898783300604, 0.049725373541670184, 0.03128098343898143, 0.029998070493872677, 0.10035862015294177, 0.011426218436099589, 0.006187500615072037, 0.03370663417237146, 0.017569193583247916, 0.12513008128319467, 0.046421878305929046, 0.11453117430210114, 0.026124702533707023, 0.2779021593076842, 30.73163570676531, 48.86432525089809, 31.78795644215175, 30.373383113316127, 33.57825013569423, 33.23742362431118, 26.51802052770342, 14.94975277355739, 60.25682095118931, 55.1454689843314, 67.211272920881, 57.64901958193098, 62.6962570462908, 58.1501271384103, 52.97802012307303, 14.830907310758318, 0.03587797676612224, 0.5792610027960369, 6.196987586362021, 2.5171573417527333, 31.07042987006051, 37.51961578641619, 49.30452489852905, 58.913108825683594, 52.795786244528635, 53.92312799181257, 57.473198890686035, 55.38196134567261, 58.90674427577427, 59.74936621529715, 58.50190053667341, 59.55139814104353, 59.06626796722412, 56.60197469166347, 53.11212035587856, 51.12206595284598, 58.38705376216343, 55.931852204459055, 59.60064002445766, 57.95849929537092, 55.94655111857823, 55.46610403060913, 55.455191884722026, 51.01522697721209, 40.19568668093, 55.13072838102068, 52.2368175642831, 54.78317601340157, 46.999661513737266, 45.51232317515782, 45.56688043049404, 42.70357295445034, 41.9927270753043, 40.62020077024187, 39.676975863320486, 38.85468087877546, 39.866477557591026, 40.76646382468087, 41.78047350474766, 43.93622507367815, 42.156412737710134, 42.42784758976528, 42.59027215412685, 41.004432678222656, 42.4374361038208, 42.42025668280465, 43.12948363167899, 43.67977401188442, 54.211283683776855, 48.840315750667024, 54.498779296875, 16.39572674887521, 21.53605965205601, 46.35369791303362, 41.84582826069423, 20.604262794767106, 35.54448611395699, 59.32814557211739, 50.40983738218035, 54.66089814049857, 48.00145973478045, 47.575159958430696, 42.592103004455566, 43.25613192149571, 40.49248940604073, 44.425287927900044, 43.40851633889334, 45.01850427900042, 42.53747626713344, 41.08300985608782, 37.61035231181553, 39.58451271057129, 39.45212173461914, 40.88700464793614, 40.43823439734322, 41.25839281082153, 40.164579595838276, 40.97022669655936, 43.86706617900303, 44.1869021824428, 47.062021596091135, 50.30016354152134, 52.63559552601406, 49.83309520993914, 47.77766520636422, 47.19160549981253, 48.69557435171944, 49.267824513571604, 48.460495948791504, 52.00368813105992, 52.65490109579903, 49.66729729516165, 50.74292360033308, 52.31419965199062, 49.8843868119376, 47.5621703011649, 42.3855539049421, 43.1800491469247, 43.04574046816145, 42.868839332035606, 46.01669985907418, 45.871065616607666, 47.130569049290244, 54.718505655016216, 50.622688497815815, 46.87189456394741, 46.69399983542306, 37.60554068429129, 17.826041221618652, 18.2760899407523, 14.033023953437805, 3.5819338176931654, 1.4916733631065913, 5.427369935171945, 46.812379768916536, 58.51754093170166, 54.06715720040457, 56.15192597252982, 55.8983063016619, 48.41739627293178, 51.93741621289934, 64.10987499782017, 14.500095759119306, 19.638299907956803, 44.089346000126426, 26.864961453846522, 42.024108614240376, 21.67643063408988, 39.11449834278652, 46.432764938899446, 3.4961250850132535, 0.4783980207783835, 0.057609821536711285, 0.08750004228204489, 0.07080772119973387, 0.017627600181315626, 0.05275689158588648, 0.04036577684538705, 0.035186600472245894, 0.04972927851070251, 0.11638148501515388, 0.09669788980058261, 0.11703813049410071, 0.26469607651233673, 0.12802833504974842, 0.1391107253730297, 0.30116068412150654, 0.08912826169814382, 0.13753146225852625, 0.10200901409345013, 0.11458334007433482, 0.317496658968074, 0.1985445168933698, 0.2641669006219932, 0.06793012882449798, 0.8770975438611848, 53.29399292809622, 56.512485367911204, 54.002511160714285, 41.862121786390034, 41.24791145324707, 42.650360175541465, 27.428399562835693, 18.088730028697423, 62.33693790435791, 59.718808037894114, 71.59369632175991, 62.68125588553292, 70.30250562940324, 61.03059319087437, 58.814117840358186, 15.684120041983467, 0.11637383114014353, 0.8648897760680744, 10.516853315489632, 10.28921035357884, 47.7086626461574, 45.95217541285923, 53.38384008407593, 63.750152860369, 56.341153212956016, 57.12012617928641, 57.47635684694563, 57.37698718479702, 60.79702949523926, 64.9290884562901, 63.03223718915667, 62.3275647844587, 59.59962558746338, 56.99873072760445, 54.65586764471871, 53.87423004422869, 58.53401511056082, 57.20603718076433, 61.06538282121931, 61.54782404218401, 57.50942332404, 57.396622794015066, 56.31529549189976, 52.41614362171718, 41.16240692138672, 57.351059981754844, 53.52524634769985, 59.0060270854405, 50.252401624407085, 46.2995262827192, 48.270615577697754, 45.091752188546316, 44.90849692480904, 43.09538534709385, 42.50566393988473, 41.5781523840768, 42.99928133828299, 43.43351248332432, 45.561148166656494, 46.52101400920323, 45.85976437159947, 45.208408968789236, 46.507951395852224, 44.09191335950579, 44.80433300563267, 45.28368922642299, 46.585969243730815, 48.02174152646746, 61.49235657283238, 52.44066381454468, 59.78284958430699, 13.948141285351344, 19.392635924475535, 49.29869883401053, 42.32933603014265, 15.897883108683995, 33.39898313794817, 64.6265013558524, 52.406197275434224, 58.761679785592214, 49.15993288585118, 50.31255217960903, 44.73878370012556, 45.117536953517366, 42.87533589771816, 48.08969838278634, 45.86266524451119, 48.64633594240461, 45.412078039986746, 44.37362807137625, 40.88531970977783, 41.29125779015677, 42.59447234017508, 44.69564233507429, 42.60334171567644, 43.21843447004046, 42.74738482066563, 43.202533517565044, 45.79969024658203, 47.991040910993306, 49.12874589647566, 54.13609722682408, 55.71971675327846, 51.18378332683018, 49.19251993724278, 48.48756265640259, 50.74078355516706, 51.47007690157209, 49.22635766438076, 54.908858503614155, 54.39790882383074, 49.964430059705464, 50.93227938243321, 53.68976926803589, 53.52739334106445, 48.75421714782715, 42.447198322841096, 42.74094384057181, 42.10261978421892, 44.75635916846139, 48.3381346975054, 48.030287810734336, 48.05273049218314, 52.721867833818706, 51.96083859034947, 47.506174768720356, 49.68682868140084, 42.926498958042686, 23.876101766313823, 21.578422818865093, 22.42128794533866, 6.936528657163892, 2.198252179792949, 6.056665675980704, 48.42573758534023, 63.92974989754813, 58.47607408251081, 62.17610100337437, 58.03357458114624, 56.358690466199604, 57.2828495161874, 73.53821917942592, 18.015033960342407, 24.058172362191335, 43.684999057224815, 37.64296020780291, 49.064954485212056, 33.8070056779044, 51.83512830734253, 58.716968127659385, 11.773336018834796, 1.1753334977797099, 0.22902595198580197, 0.45156880042382647, 0.18364291079342365, 0.1726904192141124, 0.13974826330585138, 0.17408248808767113, 0.2394154087773391, 0.12329217419028282, 0.20950409237827572], [0.049927081646663804, 0.10325236844697169, 0.16946866709206784, 0.06597888602742127, 0.030838961979108195, 0.017496290084506785, 0.03451478973563228, 0.036684093331652026, 0.029294911439397504, 0.06872759746121508, 0.044652625386204035, 0.22388589994183608, 0.05192756233736873, 0.026489321807665483, 0.15195832454732486, 10.087079439844404, 38.08349336896624, 44.043727602277485, 45.278610093253, 28.09509485108512, 39.604332447052, 24.084189891815186, 3.4107497462204526, 33.56420087814331, 58.21105241775513, 55.38271869931902, 57.669176306043354, 52.006627219063894, 59.18774332318987, 44.93686989375523, 52.70477873938424, 15.781981945037842, 0.09041203638272625, 1.9296148461954934, 1.8489108681678772, 9.480321049690247, 33.43527357918875, 42.68821396146502, 46.58896391732352, 56.12486968721662, 59.12029715946743, 56.80455984388079, 61.30278887067522, 61.204784529549734, 55.95028230122158, 56.4543011529105, 56.406136240277974, 55.175735337393625, 54.951930386679514, 54.666873591286794, 49.82823494502476, 51.2658554485866, 55.062653405325754, 55.40574850354876, 56.9436662537711, 52.98266499383109, 55.332924434116904, 52.58773980821882, 50.4585268838065, 38.557339668273926, 50.20233637945992, 51.91540779386248, 53.998790400368826, 46.83614608219692, 42.83486611502511, 44.5220103263855, 42.634170872824534, 38.82135731833321, 39.38280997957502, 37.52645281382969, 37.92277806145804, 38.48313638142177, 38.49574736186436, 40.183541229793, 41.97765990665981, 42.4735563141959, 39.865817478724885, 40.06724575587681, 37.82774754932949, 40.17340728214809, 35.96886123929705, 39.36869124003819, 41.55150604248047, 51.334548813956125, 46.44209636960711, 53.73626661300659, 17.190543345042638, 5.151242443493434, 45.62637438092913, 29.40965407235282, 6.437793476240976, 34.8482140813555, 53.01840305328369, 49.214514459882466, 51.18209491457258, 44.13465172903878, 42.46044506345476, 37.08308826174055, 42.028934138161794, 38.051823479788645, 42.52457693644932, 41.583891596112935, 41.29764665876116, 39.66686623437064, 40.87553317206246, 37.94585650307791, 35.17599534988403, 35.95211260659354, 36.01534468787057, 38.230433872767854, 38.96603965759277, 39.18373714174543, 40.64714935847691, 42.94418907165527, 44.546342917851035, 46.93659618922642, 50.51853847503662, 51.19576896939959, 50.249445165906636, 50.842786584581646, 49.208681447165354, 47.12098053523472, 49.638795784541536, 48.706114768981934, 51.31833866664341, 50.02364608219692, 51.20126152038574, 48.006827218191965, 49.938079016549246, 49.481620584215435, 48.478477886744905, 39.51043101719448, 41.73426103591919, 41.14405672890799, 42.38997643334525, 42.74440404347011, 42.745529651641846, 44.25367784500122, 46.72980390276228, 45.982087407793315, 46.37445913042341, 38.926507881709504, 22.436070237840923, 5.630585202148982, 7.635308555194309, 1.6901779685701643, 1.1417687045676368, 0.20963247120380402, 11.82405960559845, 48.12478331157139, 48.35618264334542, 51.59368535450527, 52.485243456704275, 52.1365897996085, 45.248315947396414, 60.36813109261649, 24.613010338374547, 4.81280437537602, 36.70785427093506, 21.046902997153147, 33.97093800136021, 29.088383265904017, 19.864595787865774, 45.18764427730015, 27.194908823285783, 0.42289173922368456, 0.36089689869965824, 0.027095027966424823, 0.07334650746945824, 0.04769424342417291, 0.06306444920067276, 0.14078659830348833, 0.13621716706880502, 0.07924927358648606, 0.047255882660725286, 0.06489133688488177, 0.03847733924963644, 0.040712844114750624, 0.10262169050318853, 0.08698227256536484, 0.058166016691497395, 0.19158163480460644, 0.06180141054626022, 0.04956951404788664, 0.12295627221465111, 0.0432313964702189, 0.0488549454270729, 0.06789855659008026, 0.03555032577631729, 0.057431163266301155, 0.20772003382444382, 10.718521305492946, 52.146619524274556, 50.87083993639265, 49.055244377681184, 40.67655413491385, 35.072126729147776, 28.41121530532837, 4.906772681644984, 35.01911544799805, 64.964829989842, 58.31549426487514, 64.28396906171525, 57.17020532063076, 63.121570178440635, 50.179581029074534, 61.8348263331822, 17.447668382099696, 0.11873510586363928, 0.7967524294342313, 1.8178224563598633, 12.494588562420436, 43.43726103646414, 45.463880334581646, 49.639601775578086, 59.073799814496724, 57.867992060525076, 55.28065661021641, 62.633368900844026, 61.40793595995222, 57.80181046894619, 57.695972033909385, 58.63348552158901, 55.19147300720215, 57.091242517743794, 56.02839742388044, 52.29848630087716, 55.10321004050118, 57.23421907424927, 55.510492597307476, 58.12669781276158, 54.875500202178955, 56.28918068749564, 52.80231755120413, 52.26541634968349, 42.42861189161028, 51.65526723861694, 52.92055852072579, 54.910383633204866, 48.88223423276629, 43.79243557793753, 47.68488243647984, 45.096407481602256, 41.947410924094065, 42.42892108644758, 38.9368884904044, 39.908128534044536, 40.7990265573774, 40.38255500793457, 41.45155273165022, 44.0404862676348, 42.81353167125157, 40.745709555489675, 41.96672691617693, 38.434617110661094, 42.69769477844238, 39.35642072132656, 42.771005221775596, 43.389936855861116, 53.74381583077567, 48.63622978755406, 57.48317650386265, 22.71137523651123, 11.087554029056005, 46.99100405829293, 32.51762499128069, 8.399068440709796, 35.59449577331543, 55.8317425591605, 51.42468779427664, 53.236771038600374, 46.36744144984654, 45.253402028764995, 40.37081255231585, 45.27225596564156, 42.09778731209891, 44.99371658052717, 44.1437851360866, 45.40725251606533, 42.25733184814453, 41.62583439690726, 40.02426419939314, 37.592544078826904, 38.80566481181553, 38.87948594774519, 39.02760417120797, 39.75385420663016, 41.84687396458217, 41.965041978018625, 42.753822326660156, 45.85955939974104, 47.74353218078613, 51.38544436863491, 50.49451855250767, 51.31100136893136, 50.88042497634888, 50.698729583195274, 47.615626267024446, 52.40840680258614, 49.3720440183367, 52.995220388684956, 51.61183404922485, 52.31135783876692, 49.558109828404014, 50.96358101708548, 51.134986128125874, 49.91360746111189, 41.61835813522339, 42.252516746520996, 42.571237564086914, 42.83444574901036, 44.17367628642491, 46.40274177278791, 45.9458977154323, 49.75781842640468, 48.16990838732038, 49.472796372004915, 40.42173589978899, 26.761445454188756, 8.557316269193377, 6.29833140543529, 2.545715306486402, 1.4607638674122947, 0.7120525858231953, 14.990655081612722, 53.79478781563895, 52.56382063456944, 53.9575319971357, 57.96186917168753, 54.284361362457275, 49.07384817940848, 61.30089201245989, 26.65392902919224, 8.797008275985718, 43.570409366062705, 21.573578187397548, 33.61766726630074, 35.892024585178916, 16.229199273245676, 50.27011258261544, 31.7291225705828, 0.5399657913616726, 0.2249958339546408, 0.058675854333809445, 0.07159603639904942, 0.03784541958676917, 0.016868258427296366, 0.07564343671713557, 0.09177220053970814, 0.04417231758790357, 0.05506037548184395, 0.013844517242562557, 0.15966541027384146, 0.1902463457414082, 0.3566136599651405, 0.15041125113410608, 0.13884355899478706, 0.25631760752626825, 0.14648067419018063, 0.11122372999255146, 0.42590709456375664, 0.1357915084809065, 0.46680245442049845, 0.3466646266835076, 0.21091454955083982, 0.11608655298394815, 0.2734193769948823, 26.821265969957622, 64.76342255728585, 64.6443234852382, 64.14161436898368, 42.00779076984951, 54.23592547007969, 31.51907852717808, 6.803831526211329, 41.900885786329, 69.48545306069511, 63.96019690377371, 69.07716996329171, 63.75144522530692, 68.4711480821882, 51.95985542024885, 65.49329607827323, 18.696082489831106, 0.17393644021025725, 4.022529295512608, 2.5956402846745084, 19.11686018535069, 57.12357595988682, 50.21055957249233, 51.052236557006836, 61.85278047834124, 59.413386072431294, 56.971344402858186, 66.7772467476981, 65.38989298684257, 60.540689604622976, 62.3975053514753, 63.13004003252302, 58.25403050013951, 59.79551615033831, 58.09951645987374, 55.35594034194946, 52.91773060389927, 56.95313664845058, 57.76271990367344, 60.88069970267159, 57.88241304670061, 56.34209816796439, 54.179572105407715, 52.40292467389788, 43.26050928660801, 51.52251843043736, 53.27184207098824, 56.43311956950596, 49.44164064952305, 45.4215658051627, 48.43179988861084, 46.38415881565639, 44.708319323403494, 45.88119261605399, 43.480808871132986, 43.88917882101876, 44.662193707057405, 43.29013640539986, 45.552223205566406, 47.13398061479841, 48.07026774542672, 44.76237630844116, 44.31347056797573, 40.170666217803955, 47.03425312042236, 41.312470640454976, 46.44597346442086, 46.7918825830732, 58.65355886731829, 53.62779828480312, 63.096369062151226, 16.75494166782924, 9.050865922655378, 53.632151331220356, 31.546544756208146, 8.082867213657924, 36.02420016697475, 59.50829151698521, 54.94809150695801, 56.65576069695609, 49.2243253162929, 47.712689127240864, 43.13973569869995, 50.41844620023455, 42.984106472560335, 48.55999762671334, 45.009627955300466, 49.08353744234358, 43.82713835580008, 46.17152656827654, 43.849396909986226, 42.954010350363596, 43.03433500017439, 42.86019924708775, 43.05369962964739, 43.0274840763637, 43.11708457129342, 44.87300205230713, 44.118844577244346, 46.99300513948713, 48.43592364447457, 54.4784836087908, 54.0958046231951, 52.29757956096104, 51.180048670087544, 53.47062655857631, 49.33979742867606, 55.13464716502598, 51.012343474796836, 55.93758794239589, 52.43586260931832, 53.283303124564036, 50.26470341001238, 53.31817265919277, 52.61705425807408, 52.075845173427034, 40.344159262520925, 43.4933295249939, 42.04945911679949, 43.58345113481794, 46.305466992514475, 47.767732756478445, 46.18186548777989, 51.85929066794259, 50.94593954086304, 51.582526547568186, 44.11035735266549, 33.17566108703613, 13.129536662782941, 11.062093223844256, 4.739920811993735, 1.9128744644778115, 1.8414693474769592, 16.13425735064915, 59.948967116219656, 58.10101727076939, 58.972397804260254, 61.67914499555315, 61.115527970450266, 53.89272962297712, 69.62900979178292, 33.316494124276296, 8.101829716137477, 46.742981161390034, 26.378804683685303, 51.36544050489153, 41.94782781600952, 32.531281675611226, 60.607350621904644, 45.772793769836426, 1.8118156301123756, 0.6778701628957475, 0.1473096947052649, 0.38697831918086323, 0.09640953955905777, 0.1225531002772706, 0.18584287060158594, 0.3089344698403563, 0.30108341255358284, 0.1353433903838907, 0.13797265929835184], [0.07526169291564397, 0.13094595420573438, 0.0944804712863905, 0.005601735328257616, 0.02502063784881362, 0.1349240421716656, 0.04285756438704474, 0.13565984554588795, 0.16601519526115485, 0.09512184294206755, 0.15685647885714257, 0.039042949077806303, 0.048711221532097886, 0.03758651776505368, 0.04787851317918726, 1.0754451091800417, 27.901396444865636, 37.3709625516619, 44.19609464917864, 23.867468629564556, 27.210427624838694, 42.10603482382638, 16.316188982554845, 6.356620711939676, 42.42325135639736, 55.50016757420131, 56.42771734510149, 54.19138404301235, 55.5495206287929, 49.766677379608154, 42.236678327832905, 45.59955086026873, 1.0373431422880717, 0.388711759022304, 0.3223985587911946, 2.234684190579823, 20.494785240718297, 39.2575443812779, 49.217196464538574, 62.07473373413086, 56.92923484529768, 58.925372396196636, 60.648108754839214, 57.17527750560215, 56.858571665627615, 56.08213479178292, 54.66711677823748, 54.630333014896934, 56.011541094098774, 55.985419341496055, 54.094394138881135, 51.161715848105295, 57.13614525113787, 53.30668381282261, 54.486091886247905, 55.64842128753662, 55.49319505691528, 52.22761467524937, 51.273081575121196, 46.13531603131975, 52.128206798008506, 51.41654103142874, 52.07922199794224, 47.61325693130493, 43.05633299691336, 41.91727311270577, 41.4618638583592, 39.292334011622835, 38.025712149483816, 38.15774876730782, 39.87291158948626, 37.861838885716026, 38.39890684400286, 40.11900288718087, 39.873637676239014, 41.22071967806135, 40.07189062663487, 36.72986616407122, 38.47270713533674, 38.946025371551514, 39.02034330368042, 40.46326528276716, 43.14697224753243, 45.06301096507481, 47.77674804415022, 52.29044028690883, 30.153667177472794, 12.45385127408164, 37.927662645067485, 23.094161919185094, 11.684031690870013, 47.55039657865252, 46.12820107596261, 49.57814843314034, 49.396751812526155, 48.56257193429129, 40.75073657717024, 37.96386275972639, 38.71937165941511, 39.91781084878104, 39.144215788160054, 39.40370668683733, 39.43453236988613, 40.11393070220947, 38.42026560647147, 38.5057110786438, 36.2912472316197, 34.47599213463919, 34.27041578292847, 35.28549548557827, 37.86098773138863, 38.78136348724365, 40.93005221230643, 42.251279967171804, 41.70515155792236, 47.350670610155376, 52.00336503982544, 49.0403995513916, 50.64888668060303, 46.737123829977854, 49.97517197472708, 49.13868529456002, 50.59827252796718, 47.16085277284895, 48.92090095792498, 48.21444981438773, 49.95493187223162, 49.88501909800938, 49.227872371673584, 48.46362958635603, 43.22949947629656, 44.454769134521484, 43.22414588928223, 44.56611054284232, 46.63858100346157, 49.81642648151943, 46.90877907616751, 45.013855934143066, 46.18495396205357, 44.68285417556763, 41.35538966315133, 25.421950885227748, 14.481746435165405, 2.8804797317300523, 0.984945148229599, 1.1532735100814273, 0.2192707218761955, 0.4094775090260165, 16.46124131338937, 52.96154941831316, 49.46985728400094, 52.163083280835835, 46.65115376881191, 52.90855550765991, 53.8300325529916, 51.18532930101667, 10.764003344944545, 20.672994375228882, 51.58819627761841, 28.505893196378434, 39.74651343481881, 18.822279146739415, 22.069875853402273, 39.732269627707346, 16.832322018487112, 0.16789996198245458, 0.09810232158218112, 0.04553225782832929, 0.08201625118298189, 0.03901188574465258, 0.03202534992513912, 0.07687516776578766, 0.10791789381099598, 0.02082360359574003, 0.05459207096802337, 0.10530562898410217, 0.06511363852769136, 0.05799615902027913, 0.11793794935303074, 0.03550594958609768, 0.031653980924082656, 0.009417644518959736, 0.017372186029595987, 0.023062122852674553, 0.24744177237153053, 0.05100071742864592, 0.09575142844447068, 0.06521693191358022, 0.05681535881012678, 0.04772183605070625, 0.12335541365402085, 1.3799712998526437, 35.70229360035488, 43.91732944761004, 46.3607816014971, 35.07904713494437, 31.924207142421178, 41.193823201315745, 25.152068955557688, 6.943928054400852, 46.22145979745047, 61.18708746773856, 61.582898548671174, 58.33249650682722, 61.067126819065635, 56.471445832933696, 46.77531112943377, 50.496321610042024, 1.8388340260301317, 0.6640925364834922, 1.1040023139544894, 3.979164719581604, 29.331573690686906, 44.53242220197405, 48.25584718159267, 61.7952424458095, 56.172916480473106, 58.23866803305489, 62.195382254464285, 58.583145822797505, 57.624780791146414, 56.430642536708284, 54.3334503855024, 55.64091723305838, 56.61003112792969, 58.51259381430489, 54.728392941611155, 52.378209931509836, 58.224392959049766, 54.50484160014561, 56.39248650414603, 56.68175738198416, 56.117452485220774, 52.187245641435894, 53.0615166255406, 47.492024762289866, 54.6760174206325, 52.34277411869594, 53.5262816292899, 50.63058859961373, 44.458885942186626, 43.6742501940046, 42.78804220472063, 42.00755453109741, 39.03897837230137, 39.60421780177525, 40.18108851569039, 40.03526667186192, 40.78862510408674, 42.01976251602173, 40.754516397203716, 41.93997982570103, 41.0901734488351, 38.580174922943115, 41.093303612300325, 40.76627969741821, 41.6445563180106, 42.52424342291695, 47.04773262568882, 45.53634657178606, 51.19336836678641, 52.14185306004116, 46.09360252107893, 17.66819552012852, 38.10678720474243, 26.636859042303904, 16.04346350261143, 53.72240843091692, 46.04972812107631, 53.33698838097708, 50.26526968819754, 52.71814012527466, 44.09983083180019, 42.29729093824114, 41.19715486254011, 43.51938874380929, 42.71156338282994, 43.17987196786063, 40.87976115090506, 41.84250354766846, 41.71613665989467, 40.43418707166399, 38.68232039042881, 37.069080693381174, 37.68264136995588, 38.566316740853445, 39.39054332460676, 41.02747985294887, 41.73468835013253, 43.418132645743235, 43.770958696092876, 48.99866172245571, 51.28188494273594, 49.85582971572876, 52.25128371374947, 46.76128271647862, 52.186199937547954, 51.25228909083775, 52.62136214120047, 51.18432181222098, 49.91063015801566, 50.26546423775809, 52.51198359898159, 51.67829009464809, 51.119165079934255, 49.616492067064556, 46.37775605065482, 45.5370830808367, 45.360918453761506, 47.85598530088152, 48.96466418675014, 51.87032788140433, 48.89484521320888, 46.84713813236782, 50.59600394112723, 44.82106079374041, 45.00250257764544, 27.69415773664202, 18.27420003073556, 4.657012300831931, 2.073251698698316, 1.544406173484666, 0.48139502853155136, 0.713213423533099, 19.138568094798497, 57.558342116219656, 53.32136188234602, 56.38834885188511, 53.08283369881766, 54.272003991263254, 58.45349938528878, 52.93292284011841, 16.375076702662877, 21.977456126894268, 56.27754592895508, 23.78600447518485, 42.86954110009329, 22.90036276408604, 22.208721705845424, 49.70116976329258, 20.81637566430228, 0.323371089462723, 0.09325613626944167, 0.06413354219070502, 0.15726290776261262, 0.04122064954468182, 0.08311982732266188, 0.0830109224521688, 0.042931904683687856, 0.13016090275985853, 0.08045098624591317, 0.016867316959957992, 0.2395434347646577, 0.1646342815033027, 0.4198971470551831, 0.09935586074633257, 0.08214720165623085, 0.2858948404235499, 0.1367568602519376, 0.17273463255592755, 0.5053770616650581, 0.19323085487953254, 0.5480711907148361, 0.33991874009370804, 0.22256651573947497, 0.32091967814735, 0.4562658912369183, 7.548932892935617, 60.77612236567906, 52.80388784408569, 60.27653993879046, 37.57044880730765, 40.315946102142334, 48.923600333077566, 22.174140521458217, 7.734358600207737, 54.72823313304356, 61.79112911224365, 67.82471547807965, 63.105818612234934, 65.73499611445835, 58.283442224775044, 54.08516345705305, 56.64016546521868, 2.7199088164738248, 0.7283172330686024, 0.8881628758140973, 5.1618766614368985, 39.78549630301339, 52.16275324140276, 52.429008211408345, 62.158869470868794, 55.65216636657715, 62.71750463758196, 67.93651894160679, 62.659549713134766, 61.1072735105242, 59.43910830361502, 60.56263896397182, 58.407189641680034, 58.28242431368147, 61.73746122632708, 59.5763977595738, 53.259119919368196, 56.705770356314524, 56.11968980516706, 58.94395882742745, 60.371730259486604, 58.5564786366054, 54.62502806527274, 54.63170528411865, 48.12847975322178, 55.64642368044172, 54.611871651240754, 54.44003922598702, 52.369100843157085, 46.03609575544085, 46.53688022068569, 46.0744115965707, 44.445298739842, 44.49211917604719, 43.091820921216694, 44.84636613300869, 44.36997331891741, 42.95937088557652, 46.67174128123692, 42.7288817678179, 47.7718391418457, 44.6546688079834, 42.36314596448626, 43.80147171020508, 43.004113810403005, 42.13602672304426, 46.31462124415806, 47.93075486591884, 48.10382407052176, 55.13448388235909, 55.87848309108189, 39.027746609279085, 10.722619874136788, 37.21052517209734, 25.096677916390554, 10.872675776481628, 54.64591435023716, 48.53519950594221, 56.80031796864101, 52.87632976259504, 56.35355922154018, 47.34755434308733, 43.639853136880056, 43.28885098866054, 44.8550374848502, 44.782015391758506, 45.1576315334865, 41.937523637499126, 45.709363664899556, 44.42910943712507, 45.25674063818795, 42.83230570384434, 40.20315252031599, 40.920196192605154, 39.48615748541695, 43.51157202039446, 43.206813607897075, 44.224544048309326, 46.7690612248012, 44.37101207460676, 51.20326607567923, 55.28310932431902, 52.549729687826975, 53.562672819410054, 47.5134391103472, 54.69011878967285, 55.12671232223511, 54.214257512773784, 52.308123452322825, 51.3090489251273, 51.881132330213276, 53.913786138807026, 51.057141985212056, 51.82623808724539, 51.12960474831717, 44.29470695768084, 45.7924085344587, 45.1631692477635, 47.88704374858311, 47.959662846156526, 54.2715870993478, 49.42070920126778, 44.76999153409685, 51.60579606464931, 50.35974434443882, 47.96856696265084, 32.3216232572283, 21.587743827274867, 5.513362143720899, 3.677616809095655, 3.016838780471257, 0.7584385424852371, 0.7431405633687973, 21.071376289640153, 65.49087810516357, 58.089059420994346, 63.03917843954903, 55.99102653775896, 58.69055107661656, 63.61323165893555, 61.649399757385254, 16.178380148751394, 28.93772894995553, 63.69676290239607, 38.568804195949006, 60.91838673182896, 27.112951346806117, 34.18370573861258, 54.92151812144688, 37.846816880362375, 0.49856755563191, 0.2996623973761286, 0.20331851286547525, 0.3635074400476047, 0.14123638559664997, 0.20110458880662918, 0.2194257942693574, 0.24697171045201166, 0.1594676851694073, 0.2505978015916688, 0.12657038042587893], [0.015632914179669957, 0.08503264468163252, 0.14317635792706693, 0.0500578115960317, 0.06286924824650798, 0.0974490280662264, 0.038715308266026635, 0.0577778946608305, 0.04776686363454376, 0.02751051531439381, 0.05151418523330774, 0.0507380124181509, 0.07365063365016665, 0.010965924876342927, 0.027735878846475055, 0.15368447692266532, 11.41892751625606, 42.17523193359375, 32.1214873450143, 21.880445378167288, 30.055850437709264, 54.38728155408587, 51.70065287181309, 3.228867403098515, 15.972527606146675, 59.52714892796108, 55.349141529628206, 54.94890444619315, 53.9802109173366, 59.03206198556082, 51.97192791530064, 50.29986129488264, 6.821522942611149, 1.2444607998643602, 0.24789109826087952, 0.05528723009462867, 11.616996339389257, 29.20092671258109, 46.353642327444895, 60.14314147404262, 58.26614121028355, 63.37168448311942, 57.562069824763704, 56.24764435631888, 53.08775302342006, 48.70622246606009, 48.74857868467058, 52.049827643803184, 58.5983693259103, 55.48843206678118, 56.5873452595302, 49.277805600847515, 55.26078128814697, 55.78656884602138, 53.744885853358674, 56.04329783575875, 54.35336739676339, 54.93544231142317, 53.10936886923653, 49.007663113730295, 53.14155639920916, 53.954384463174, 52.4115161214556, 43.660544872283936, 42.870117800576345, 39.735604763031006, 40.264213289533345, 38.56959629058838, 35.27645240511213, 37.30608722141811, 37.973770890917095, 38.18495443889073, 41.40411043167114, 40.42117656980242, 41.599719592503135, 40.958348751068115, 36.6101313318525, 38.876790046691895, 38.20167180470058, 38.71044322422573, 38.32541574750628, 39.728031226566856, 44.78043467657906, 41.62176275253296, 47.232554708208355, 46.332203660692485, 46.27623592104231, 30.078897612435476, 39.333460399082725, 26.291236536843435, 25.05349486214774, 51.99279335566929, 46.25231327329363, 50.33267763682774, 46.66804831368582, 50.70145675114223, 40.51438665390015, 39.09131220408848, 38.21222959245954, 41.007604530879426, 38.6254563331604, 41.102857385362896, 38.950072697230745, 39.056053570338655, 38.284049647195, 39.96658720288958, 35.618922165461946, 35.128824029650005, 33.48644706181118, 34.7854961667742, 35.121313026973176, 39.23534141268049, 38.577155930655344, 41.32228149686541, 42.61128698076521, 44.17849833624703, 46.47293247495379, 47.69689587184361, 47.48810945238386, 50.78765957696097, 48.51638725825718, 48.08979913166591, 49.26360348292759, 50.34187705176217, 49.48471948078701, 49.65684025628226, 48.726764815194265, 50.998315061841694, 47.069591658455984, 46.395411423274446, 46.355785846710205, 45.43827622277396, 45.77713986805507, 51.32155220849173, 50.58054072516305, 51.8743508883885, 51.65973493031093, 52.02571392059326, 50.19731978007725, 45.33851746150425, 33.47727196557181, 20.66684521947588, 10.602795583861214, 6.668055040495736, 3.6503816076687405, 2.399709552526474, 0.5159609051687377, 2.1014520483357564, 33.83577816826956, 49.96454470498221, 47.98346390042986, 52.96497140611921, 44.924630641937256, 53.989820275987896, 51.7774269921439, 38.10225003106253, 10.37164204461234, 47.13624572753906, 33.385857990809846, 24.915897948401316, 35.953047139304026, 31.16998713357108, 36.08868292399815, 40.64613492148263, 6.200531167643411, 0.3294158051056521, 0.15495438235146658, 0.06840156138475452, 0.03195730982614415, 0.10019032989761659, 0.0357414453423449, 0.03994909866846033, 0.0927757809736899, 0.01988343395558851, 0.0636242948738592, 0.06978124699422292, 0.07488662589873586, 0.11032779913927827, 0.09802304833595242, 0.0404045585143779, 0.13786992909652845, 0.022074348891952207, 0.03474457901237266, 0.027381159398438673, 0.04494449043912547, 0.062194838720772944, 0.03682636855436223, 0.014364493046221989, 0.09080523385533265, 0.036125669189329655, 0.0513236831341471, 0.3122341313532421, 16.63019371032715, 54.305567264556885, 32.23190811702183, 27.738303116389684, 40.47729369572231, 52.6211120060512, 58.821621894836426, 8.972015159470693, 17.705338852746145, 63.727967262268066, 61.144536699567524, 61.04886000497, 59.593608447483604, 63.04577228001186, 54.27131264550345, 56.80559859957014, 7.4440281220844815, 1.1110774257353373, 1.4597607212407249, 0.3156951756349632, 14.435910037585668, 36.651417527879985, 50.862370082310264, 57.484243052346365, 61.18363421303885, 64.47626045772007, 61.15996864863804, 60.32072353363037, 55.121546336582725, 50.99528217315674, 50.0392621585301, 54.07848276410784, 58.73590891701834, 58.68493693215506, 57.07864195959908, 51.99667045048305, 59.06619848523821, 56.258532183510916, 54.7095285824367, 56.499478340148926, 55.616438729422434, 55.063448974064414, 52.70502887453352, 52.68077271325247, 55.26972014563424, 53.536106382097515, 54.00820868355887, 47.04140281677246, 44.86278125217983, 43.78607102802822, 41.18124696186611, 41.923248563494, 38.081467969076975, 38.30680499758039, 38.34466225760323, 39.97703381947109, 41.57350056512015, 42.29881259373256, 42.22223997116089, 40.07070595877511, 40.16979769298008, 39.31194530214582, 37.178587777274, 40.23078898021153, 43.743930203574045, 42.84050805228097, 47.93742513656616, 44.21183579308646, 50.192615849631174, 49.27041271754673, 51.70269911629813, 55.38890954426357, 40.24897936412266, 31.003518717629568, 40.637070996420725, 58.41686848231724, 48.25625017711094, 51.72936977658953, 47.729194572993684, 51.73026262010847, 45.397705691201345, 42.24401909964425, 40.53150006702968, 44.2000412259783, 43.27526378631592, 44.58453369140625, 41.621613366263254, 41.213125297001426, 40.61317614146641, 40.04044655391148, 38.089083194732666, 38.745451722826274, 35.97887706756592, 37.02408068520682, 35.89178139822823, 41.22602462768555, 39.04185145241873, 41.47018085207258, 44.1398663520813, 44.65562418528965, 46.074380329677034, 48.66281706946236, 48.91976145335606, 51.753754479544504, 51.083920342581614, 50.1608486856733, 50.10491221291678, 51.22971786771502, 50.91100747244698, 51.15604611805507, 50.77740750994001, 52.34812423161098, 49.35857840946743, 47.72390351976667, 48.13474702835083, 48.27344349452427, 49.962842396327424, 54.058016845158164, 51.606209482465474, 53.53533860615322, 53.761127267565044, 54.16801725115095, 53.893848282950266, 48.53568935394287, 39.576723779950825, 23.33772233554295, 12.884630901472908, 6.9641004119600565, 4.20464505468096, 4.094895652362278, 1.4271311121327537, 3.904161955629076, 37.85813202176775, 54.72976173673357, 54.4181524004255, 59.27850069318499, 48.476806844983784, 58.447134835379465, 54.51502071108137, 40.154056549072266, 13.406063675880432, 48.63402026040213, 40.504412514822825, 21.51007338932582, 43.56398228236607, 34.919367109026226, 38.66781602587019, 52.287251063755576, 9.119155423981802, 0.3774507918528148, 0.12808400206267834, 0.06318238537226405, 0.03848699141027672, 0.2626677724931921, 0.03480312301378165, 0.018957075895741582, 0.08104468403117997, 0.08124957446541105, 0.03169870995251196, 0.07150239178112575, 0.22327519128365175, 0.16250412937785896, 0.1600039449653455, 0.07093192024954728, 0.22591541175331387, 0.1225981278611081, 0.1731302049010992, 0.11438442074826785, 0.2605415423001562, 0.16444939428142138, 0.19020293307091507, 0.1296590989721673, 0.21203932990985258, 0.2822320269686835, 0.1400728201759713, 0.41251056055937496, 38.10216665267944, 68.22338226863316, 50.81765147617885, 34.47359153202602, 48.061002322605674, 63.67804445539202, 62.564998626708984, 5.401395397526877, 22.404466356549943, 69.87822083064488, 65.23080703190395, 66.12973022460938, 63.916020257132395, 65.94572108132499, 63.458807945251465, 63.19797257014683, 7.988449011530195, 1.4970617996794837, 1.5745093524456024, 0.8394192542348589, 18.334244625908987, 42.69956731796265, 53.63985340935843, 61.588679449898855, 61.16225460597447, 68.22256238119942, 63.349637848990305, 63.13127681187221, 59.00554071153913, 53.474760736737935, 53.853388922555105, 55.91876527241298, 62.527207374572754, 62.030258314950125, 59.608435903276714, 54.41015154974801, 57.071117060525076, 55.82749720982143, 55.25954450879778, 57.581434454236714, 58.40317358289446, 57.408483369009836, 53.74931532996041, 53.10838917323521, 59.115218026297434, 56.86484588895525, 56.78327751159668, 49.33378028869629, 45.083914620535715, 44.82242611476353, 44.64739056995937, 44.34407390866961, 42.527477809361045, 41.35220391409737, 43.75689901624407, 43.463890007564, 47.39301988056728, 46.25184774398804, 45.51219810758318, 44.75311088562012, 43.15569918496268, 41.63672569819859, 41.25677040645054, 42.67686755316598, 44.66395854949951, 44.47819151197161, 48.56369406836373, 44.386614254542756, 52.28740045002529, 49.15140049798148, 57.78539882387434, 42.81997959954398, 40.035624504089355, 27.734405176980154, 29.26434292112078, 61.34770202636719, 50.0288850239345, 56.67421163831438, 50.558653899601524, 57.93893664223807, 46.58424956457955, 45.99704687935965, 41.89760276249477, 46.2909973689488, 44.32775606427874, 48.49874578203474, 44.112285477774485, 44.10823815209525, 44.600452014378135, 46.34743411200387, 40.533362184252056, 41.17744629723685, 38.81376641137259, 40.44668688092913, 38.95436668395996, 43.546219212668284, 41.30712400163923, 43.9109023639134, 45.71315738133022, 48.871495791843955, 48.88578476224627, 50.50119924545288, 49.56099680491856, 53.108326639447895, 53.436927795410156, 53.07056665420532, 52.14375686645508, 53.02230794089181, 51.97821256092617, 52.173269339970176, 51.463931219918386, 53.88502754483904, 49.53509044647217, 49.32149587358747, 48.356102739061626, 49.449971539633616, 51.35740491322109, 55.992016656058176, 53.03447423662458, 55.57982519694737, 57.329975673130576, 55.54382658004761, 56.52143464769636, 49.06787272862026, 43.84781619480678, 29.973448276519775, 19.131543466023036, 9.845928311347961, 7.695503405162266, 5.541628284113748, 1.662826493382454, 4.395338365009852, 41.38881744657244, 59.36671502249581, 57.558779852730886, 63.472204072134836, 51.18747282028198, 61.564221790858674, 62.29710388183594, 46.241213526044575, 16.17460032871791, 57.95112725666591, 44.19452435629708, 35.11676890509469, 51.87108523505074, 41.26390273230416, 49.21171086175101, 61.29894651685442, 19.285308837890625, 0.597235558288438, 0.28410027814762934, 0.36213973058121546, 0.10871382217322077, 0.31186457404068535, 0.17496368794568948, 0.07326364477298089, 0.17117311991751194, 0.11477077858788626, 0.15206727012991905, 0.15899721612887724], [0.0348980839896415, 0.04050635912322572, 0.10923412282552038, 0.020537668938881586, 0.07706365800861802, 0.03735468949058226, 0.061622894768204005, 0.034209228453359435, 0.07653837012393133, 0.023885031463578343, 0.03411032518904124, 0.04945607317079391, 0.032802917129759274, 0.026118629645290117, 0.0728189872045602, 0.11927922309509345, 2.2941203841141293, 28.622110503060476, 38.17319113867623, 25.324934925351823, 26.499932629721506, 43.91953897476196, 62.73150525774275, 17.401754685810634, 5.343320182391575, 44.43614796229771, 56.349411146981375, 58.09169626235962, 52.75739049911499, 59.72867447989327, 44.127043451581685, 53.79177229745047, 12.834920014653887, 2.0006015513624464, 2.3574147820472717, 0.09679550384836537, 3.1081797991480147, 21.763067722320557, 52.50937802450997, 59.12179797036307, 60.3289988381522, 60.145990235464915, 56.80141230991909, 55.52613646643502, 48.40747424534389, 46.65176521028791, 44.831236430576865, 45.53602695465088, 53.1757276398795, 54.22703177588326, 55.57037564686367, 53.73192746298653, 48.868476799556184, 58.677710805620464, 54.36360556738717, 54.54341799872262, 56.219994000026155, 55.38310432434082, 52.17882095064436, 51.50912577765328, 52.0426709992545, 51.756610189165386, 49.78225176674979, 40.91564164842878, 41.631073338644846, 41.4192019190107, 39.84101588385445, 37.1655946459089, 37.35614899226597, 37.47352491106306, 36.4587960924421, 37.561475208827424, 40.40876361301967, 41.55064793995449, 42.315036637442454, 39.14274277005877, 36.24687256131853, 38.24910715648106, 37.6891587802342, 39.01899535315377, 38.428033692496165, 41.97409200668335, 47.40774311338152, 46.73810352597918, 48.21506125586373, 46.50833354677473, 49.11730568749564, 36.86433812550136, 46.110476221357075, 33.79162584032331, 35.26231976917812, 51.10974679674421, 48.414988722120015, 50.97432293210711, 47.637002399989534, 44.91356216158186, 38.508573736463276, 38.712770870753694, 38.309497424534385, 39.42959220068795, 38.26358372824532, 37.322245257241384, 40.587478228977744, 40.175700187683105, 40.24483476366316, 38.979932580675396, 37.12850168773106, 34.99511637006487, 35.66959537778582, 34.984537737710134, 36.46804761886597, 37.975410665784565, 38.329522132873535, 39.337535517556326, 40.81877681187221, 41.13520124980381, 42.8830692427499, 42.41997528076172, 46.55008527210781, 44.970954281943186, 47.605961322784424, 48.25045885358538, 48.89428240912301, 48.543815272195, 49.408098220825195, 49.64241927010672, 49.263415881565635, 48.058698994772776, 48.74261365618025, 48.21853188105992, 47.35992561067854, 45.42047493798392, 49.08992978504726, 49.55883591515677, 48.766063826424734, 48.58123826980591, 49.762348651885986, 49.495916502816335, 48.966825076511924, 51.340232440403526, 34.72796160834176, 14.154461094311305, 2.2167059438569203, 0.2597131867493902, 0.5482751854828426, 0.833333935056414, 0.8528365514108113, 9.006748335702078, 48.05811187199184, 50.37861565181187, 49.436780384608674, 44.85315104893276, 54.65622200284685, 51.22768899372646, 53.40214163916451, 15.07085292679923, 23.270922354289464, 47.79986122676304, 27.430294684001378, 30.1543550491333, 32.928155830928254, 45.2972069467817, 39.568180969783235, 38.65214783804757, 2.120033702680043, 0.14972210382776602, 0.0908357340044209, 0.10093741730919906, 0.036916064098477364, 0.06549659690686635, 0.05254693588774119, 0.03756531693839601, 0.014751359787104385, 0.04805235045828989, 0.05542828056163021, 0.04731610942898052, 0.04444581130519509, 0.023082258379352943, 0.03655971786273377, 0.026485732357416834, 0.1623049114963838, 0.0391603254580072, 0.016482194054073522, 0.043112428925399265, 0.04568106734326907, 0.018135052773037126, 0.035692139595214806, 0.03402070767645325, 0.052681737047220976, 0.05271718371659517, 0.023510098457336426, 0.24312989945922578, 4.723580385957446, 41.01970134462629, 40.826350348336355, 29.51990113939558, 38.29643481118338, 48.34595489501953, 62.739245550973074, 20.047824995858328, 8.299518125397817, 45.20069299425398, 62.49718420846121, 61.8931634085519, 58.43152918134417, 62.562400000435964, 51.20609746660505, 60.25619561331612, 12.627736892019, 2.7848707820687975, 5.167895972728729, 0.34446777456573074, 4.512915347303663, 24.746561663491384, 54.821391105651855, 60.28264045715332, 61.812439237322124, 61.26984051295689, 59.98562581198556, 57.89737251826695, 51.86427252633231, 47.868096011025564, 46.50791665485927, 47.794170652117046, 56.42956904002598, 56.32420655659267, 58.11904089791434, 54.9483242716108, 52.27033567428589, 60.21035834721157, 55.001933097839355, 55.69402231488909, 56.785132680620464, 56.61580508095877, 52.65259429386684, 54.29969951084682, 50.46825783593314, 54.3874066216605, 50.75279351643154, 43.99796676635742, 43.460877963474815, 44.36088160106114, 41.612410477229524, 41.94106027058193, 39.25572395324707, 38.88520431518555, 38.74122026988438, 39.589341708592, 42.71361310141427, 42.09373303822109, 43.075398853846956, 40.682279450552805, 38.27696248463222, 40.48105614525931, 38.358204296657014, 39.29235485621861, 42.312566552843364, 45.651676246098106, 50.83728013719831, 48.80014474051339, 50.96116304397583, 50.152733189719065, 52.90475136893136, 53.89711046218872, 52.75972856794085, 41.06514603751046, 57.341603483472554, 53.95045873097011, 53.8842111315046, 51.910689967019216, 51.675820010049, 47.6673903465271, 42.507029260907856, 41.81239005497524, 42.051890986306326, 41.423732144492014, 41.35608100891113, 39.30644927706037, 43.15589720862252, 41.301252773829866, 41.669969354357036, 39.71194614682879, 39.63536310195923, 37.47539397648403, 38.80949674333845, 37.51271275111607, 38.588123662131174, 39.694023268563406, 38.759730270930696, 40.195120402744834, 41.970426831926616, 41.92984587805611, 44.07715885979788, 44.87057018280029, 46.584864480154856, 46.71640082768032, 48.158836432865684, 49.91684879575457, 50.661945819854736, 50.762600898742676, 50.8645726612636, 50.55347054345267, 51.98068264552525, 50.042781421116416, 52.047659805842805, 51.11732728140694, 49.54266398293631, 49.96951961517334, 51.41911881310599, 51.31476729256766, 52.76402950286865, 52.80355085645403, 51.43995646068028, 52.48077229091099, 50.64258813858032, 53.13394464765276, 39.8325321333749, 17.770406995500835, 2.610605618783406, 0.14999267645180225, 0.14112274455172674, 1.8337800800800323, 2.148529350757599, 10.025785037449428, 52.90576580592564, 55.97627203805106, 52.81520298549107, 51.604819842747276, 57.63951097215925, 54.68952471869332, 56.92106376375471, 18.98374833379473, 26.17057412011283, 48.46659646715437, 34.4616128376552, 28.76265345300947, 44.11638491494315, 42.83281987054007, 41.98816558292934, 45.290696484701975, 2.6326783086572374, 0.19562604278326035, 0.06780023008052792, 0.11029739398509264, 0.09295903971152646, 0.05993854693536248, 0.04952620315764632, 0.10180549429995672, 0.021918755723163486, 0.07416315829115254, 0.12272630312613078, 0.017236173685107912, 0.08524744851248604, 0.13028086775115558, 0.11833702293889863, 0.10813078417309693, 0.3206307850778103, 0.14230692386627197, 0.18333381095102855, 0.14665815180965833, 0.2472274095884391, 0.09688051750085183, 0.13035881785409792, 0.12237304422472205, 0.20682208772216523, 0.1878198773733207, 0.15365169011056423, 0.5797144270368985, 15.692044462476458, 61.99230030604771, 58.14451994214739, 41.99430431638445, 42.25644595282418, 58.37427602495466, 72.8610269001552, 23.45686309678214, 9.062330450330462, 52.514391149793354, 64.53929451533726, 68.05149773189, 62.969738142830984, 69.70912946973527, 55.65819045475551, 65.72936112540108, 15.945917742592947, 4.148807159491947, 7.029618884835925, 0.4433829811002527, 6.93826744386128, 30.367136682782853, 57.98207800728934, 62.074643407549175, 62.92916761125837, 63.156797545296804, 64.45736135755266, 60.122484479631694, 53.96080807277134, 49.71891893659319, 49.77447673252651, 51.35420526776995, 59.469124521527974, 58.31155463627407, 60.46864373343331, 58.340097836085725, 53.58160318647112, 61.33634172167097, 56.95512383324759, 57.991114139556885, 59.25425842830113, 59.43874699728829, 55.22966030665806, 53.49209301812308, 53.752389907836914, 57.249359198978965, 53.425960063934326, 44.94577053615025, 45.054690497262136, 46.74760171345302, 44.884164333343506, 43.60027272360665, 43.927626677921836, 42.70354168755667, 41.209300313677105, 40.75040306363787, 46.07409197943551, 44.923703057425364, 45.488268511635916, 43.50423124858311, 40.984887395586284, 43.79306786400931, 41.857852118355886, 41.36441537312099, 44.690938404628206, 48.86108044215611, 54.39295128413609, 51.005551610674175, 54.23131186621529, 53.01707942145211, 56.336584772382466, 52.53933865683419, 54.56678131648472, 35.984789984566824, 50.16279765537807, 56.87912096296038, 55.79364906038557, 56.319082260131836, 54.060987200055806, 49.64083855492728, 44.24241134098598, 44.544800417763845, 44.291257177080425, 45.84127174104963, 43.243944781167166, 42.27055079596383, 45.03775773729597, 43.740327562604634, 45.391626017434255, 44.19583409173148, 42.918445995875764, 40.980162620544434, 41.56351947784424, 41.52381747109549, 42.090460436684744, 42.05336747850691, 39.96037898744856, 43.86328983306885, 44.23067583356585, 42.433538164411274, 46.620835304260254, 44.63041959490095, 50.31076649257115, 46.61528021948678, 50.45311771120344, 50.103063992091585, 52.41999987193516, 50.3184095110212, 54.05271189553397, 53.65748446328299, 53.07257815769741, 51.38371426718575, 52.56642968314034, 50.46720518384661, 51.1176712172372, 51.79060425077166, 54.851275307791575, 53.8315611566816, 52.88905886241368, 53.42533472606114, 56.22562551498413, 55.06139925548008, 54.5924722807748, 56.49008437565395, 40.31096771785191, 23.252749340874807, 4.757324746676853, 0.4294867196253368, 1.279096158487456, 1.747926075543676, 2.0203448576586585, 12.093244978359767, 57.41405929837908, 60.30795274462019, 56.32769455228533, 54.85461391721453, 62.303968702043804, 59.90277549198696, 61.70849418640137, 22.430089575903757, 29.45675938470023, 58.771532331194194, 34.95811026436942, 42.16537938799177, 46.121468271527974, 52.31355694362095, 49.698727471487864, 61.00353690556118, 5.988489082881382, 0.49793022125959396, 0.29934278024094446, 0.2919701172837189, 0.15356497333518096, 0.13680568763187953, 0.2135937993547746, 0.14473850838840008, 0.11181676281349999, 0.11782031852219786, 0.1673848589083978, 0.148718441969582], [0.058782710028546195, 0.05337826681456395, 0.05400117213970848, 0.026912803994491696, 0.02858340640419296, 0.07623093947768211, 0.02439745602064899, 0.011486116963039552, 0.0607125654018351, 0.02831960895231792, 0.003259690075148163, 0.08577676689518349, 0.08032800177378313, 0.006126808626244643, 0.06986697310847895, 0.06194888334721327, 1.1040762471301215, 16.8110796383449, 34.14994444165911, 31.539742469787598, 24.4172465801239, 26.481825624193462, 57.423745087214876, 61.18760163443429, 8.068854434149605, 37.59175893238613, 59.59752723148891, 57.87589563642229, 56.56846352985927, 54.04421077455793, 45.72857195990426, 59.92070184435163, 13.563984939030238, 1.9378126348767961, 0.7680832392403057, 0.9118256717920303, 1.1075287418706077, 12.881932394845144, 47.05788046973092, 61.37245150974819, 60.20835031781878, 60.50394753047398, 57.22501271111624, 55.943386214120046, 52.00315311976841, 45.403236457279746, 44.8671794618879, 42.212588923318044, 46.56498915808541, 52.05483382088797, 52.30692836216518, 54.592055388859336, 52.115790367126465, 49.28898525238037, 60.597018650599885, 54.4522020476205, 57.34534508841378, 51.244131905691965, 52.80760165623256, 52.38377891268049, 48.61118153163365, 47.35179969242641, 46.21508135114397, 42.555058683667866, 42.78242458615984, 39.61921548843384, 38.20771326337542, 38.357228074754985, 36.50694710867745, 37.08287634168352, 36.70105198451451, 38.60541078022548, 40.24896894182478, 42.62791749409267, 42.06120157241821, 37.86542763028826, 37.06649596350533, 38.40870727811541, 38.59383160727364, 39.46759189878191, 39.702409744262695, 42.65428243364607, 47.79616131101336, 45.57865762710571, 45.87244135992867, 47.18940986905779, 49.24649006979806, 45.963421072278706, 45.874546664101736, 38.3811993598938, 41.16240692138672, 51.55243737357003, 48.10319178444998, 48.82101365498134, 44.078378268650596, 44.15166439328875, 39.54969181333269, 38.745382240840364, 39.059906346457346, 37.73948458262852, 37.93246037619454, 36.23113489151001, 39.57808215277535, 40.34520149230957, 38.76305498395647, 37.10655232838222, 36.72144494737898, 34.951033524104524, 34.08523934228079, 35.30682992935181, 35.86509336744036, 37.93320383344378, 36.56121253967285, 40.771591595241, 38.946164335523335, 38.745660168784006, 39.89797374180385, 41.40323148454939, 42.50972168786185, 45.494407245091026, 46.30849640710013, 45.582645893096924, 49.96008743558611, 48.86428356170654, 48.564760616847444, 49.78797360828945, 51.767595291137695, 50.04869086401803, 49.715646335056846, 49.71640716280256, 46.42239127840315, 46.34343194961548, 48.84816026687622, 48.71786069869995, 47.37558337620327, 47.22280291148594, 48.02271774836949, 47.702346733638215, 49.14596005848476, 50.805433068956646, 43.851033210754395, 18.770865951265606, 1.9642259946891238, 0.05396729288622737, 1.510799365384238, 1.2897474212305886, 1.0095240750483103, 10.296647531645638, 46.13831417901175, 49.60497890199934, 46.78798464366368, 42.43410791669573, 45.87358086449759, 51.41670778819493, 42.72799934659685, 17.224997724805558, 41.003550257001606, 47.158733572278706, 21.20267813546317, 32.04110363551548, 38.235339300973074, 33.572066238948274, 47.31848655428205, 27.026326417922974, 0.15824666140334948, 0.008284517331048846, 0.04157599154859781, 0.007034941659575062, 0.042258631704109054, 0.0329346377402544, 0.05782550067773887, 0.0502363816568894, 0.049103065327342064, 0.06742413169039146, 0.06880935414561204, 0.014222825112353479, 0.05406285436557872, 0.0015938668844423123, 0.022780686882989745, 0.02090999637065189, 0.031957486245248995, 0.021645307806985717, 0.03267036531386631, 0.027528320073283145, 0.014408865843766501, 0.05141219463465469, 0.04521618603861757, 0.03634105656029923, 0.13832187413104943, 0.04472858738154173, 0.11989704280027322, 0.12570197773831232, 1.1324574670621326, 27.418416738510132, 43.32730579376221, 31.081800597054617, 33.76551103591919, 32.86438179016113, 58.61568423679897, 54.271052088056294, 10.611291493688311, 40.94494220188686, 63.96555396488735, 63.13078348977225, 61.17600509098598, 59.432097571236746, 51.158380712781636, 66.0996514729091, 14.171210595539637, 1.4929066683564867, 4.024562077862876, 0.8193399373974118, 1.6773296637194497, 15.965631519045148, 52.353898184640066, 62.10393006461007, 60.7377405166626, 61.64825330461775, 60.12653527941023, 58.90401363372803, 52.147929259708945, 47.01261643001011, 46.87044586454119, 43.16649668557303, 47.640271527426584, 55.525924546378, 54.6658730506897, 57.75634493146624, 54.27739231927054, 50.65962164742606, 62.211008753095356, 54.19731433050973, 59.11864348820278, 54.764888354710166, 53.41355752944946, 55.645103522709434, 50.559692655290874, 51.021244117191856, 47.47466121401106, 44.080427987234934, 44.694634846278596, 41.62377773012434, 40.73985569817679, 40.976407119206016, 38.94512210573469, 38.571659905569895, 38.38293988364083, 40.45978076117379, 41.5463331086295, 45.68643460954939, 42.877896308898926, 39.22337661470686, 39.65960884094238, 39.50565760476248, 39.163347652980256, 40.137238434382844, 42.32815831048148, 47.43990632465908, 52.11887884140015, 48.17298991339547, 48.505909374782014, 51.21453605379377, 50.95193236214774, 54.60047313145229, 49.27988658632551, 50.75087233952114, 55.59028918402535, 52.52981615066528, 52.663951124463765, 48.53969151633126, 48.308792454855784, 45.370659828186035, 42.027468068259104, 39.32306241989136, 42.449074336460654, 40.99954114641462, 43.09856762204851, 39.658743790217805, 41.8078042439052, 41.94175509044102, 40.87001977648054, 39.184449332101, 39.905512537275044, 37.76891367776053, 35.860879284994944, 37.908040932246614, 40.01494319098336, 39.91784906387329, 39.633174419403076, 40.318732329777305, 38.746775354657856, 40.83163097926548, 41.497237137385774, 41.28663028989519, 44.106101581028526, 45.946165221078054, 47.48811640058245, 47.188746316092356, 49.215789454323904, 49.52077715737479, 49.625024454934255, 51.20911645889282, 52.760069029671804, 53.33196830749512, 51.33811671393258, 51.93831600461687, 49.26211656842913, 50.06231280735561, 52.205700056893484, 53.06385816846575, 49.36859771183559, 51.23645762034825, 50.1464763368879, 51.22032042912075, 50.64762558255877, 52.4207433291844, 47.47288247517177, 24.900240182876587, 3.670857080391475, 0.2735833653381893, 0.2661066693919045, 0.46095451393297737, 0.8598253535372871, 12.569294725145612, 50.30402673993792, 54.04803575788225, 49.58491250446865, 46.145359652382986, 49.733895778656006, 56.92485400608608, 45.21021202632359, 20.003839424678258, 40.5389381136213, 55.564316817692344, 21.258975914546422, 36.57584892000471, 45.076247283390586, 27.62320099558149, 54.21716185978481, 27.425014053072246, 0.2692804219467299, 0.05899292017732348, 0.05103338210444365, 0.04125363652461341, 0.03518141646470342, 0.05382373183965683, 0.0584785770624876, 0.06451942505581038, 0.032224276036556275, 0.017255209985056093, 0.025078603399119208, 0.04734786147517817, 0.1879244124782937, 0.12399025101746831, 0.14499088270323618, 0.09960588733000414, 0.1277076051171337, 0.1284932265324252, 0.09198591871453182, 0.11578600268278803, 0.136284844151565, 0.1058104590379766, 0.1564006797437157, 0.20115456969610282, 0.266389184232269, 0.10261592295553003, 0.24670135495918138, 0.23794977313705853, 1.9212303246770586, 51.92889772142683, 55.74399375915527, 52.27192333766392, 39.84734221867153, 40.49731840406145, 68.04129777635846, 71.55048547472272, 12.265146017074585, 46.43187556947981, 68.4963491984776, 70.03108814784459, 64.82907608577183, 64.71815504346574, 55.513174601963584, 71.36075796399797, 16.74718747820173, 2.5569828961576735, 5.735697116170611, 1.949716636112758, 3.296011754444667, 20.658014059066772, 58.07637548446655, 62.05129746028355, 62.878543036324636, 64.72709042685372, 61.66601290021624, 62.68536227090018, 56.52600308826992, 49.94432544708252, 49.86736025129046, 46.35329144341605, 50.89489459991455, 56.105744770595, 57.082453046526226, 57.93205792563302, 57.11542224884033, 51.1411908694676, 61.74919673374721, 57.743358748299734, 61.89902768816267, 58.54167897360665, 54.88095106397356, 56.439758573259624, 51.94907876423427, 51.74293613433838, 49.59213515690395, 47.0752718108041, 47.32800906045096, 44.322301728384836, 42.194443702697754, 43.35712398801531, 41.521816389901296, 42.036198479788645, 41.00445352281843, 43.40829747063773, 45.53410577774048, 47.78466551644461, 46.77148267201015, 42.24786145346505, 42.77652209145682, 43.34374870572771, 41.14875718525478, 43.296226501464844, 45.85000910077776, 49.48429911477225, 53.37182664871216, 51.02223423549107, 50.837453842163086, 51.95407451902117, 55.117276668548584, 56.73635285241263, 50.61295059749058, 44.737098761967246, 53.32462058748518, 56.243266991206575, 53.67084584917341, 52.59052603585379, 48.65741484505789, 48.02877310344151, 44.31421055112566, 42.27745035716465, 43.90906456538609, 42.37211956296648, 45.14753927503313, 39.81460230691092, 43.304804052625386, 44.60795259475708, 43.349213463919504, 41.94304745537894, 42.91782065800258, 40.28055545261928, 37.43226650782994, 41.42367655890328, 40.21288347244263, 40.79515988486153, 41.7344833782741, 43.607762881687705, 39.892943246024, 42.342725208827424, 43.98574488503592, 43.970358099256245, 46.13170296805245, 47.12213741030012, 50.13352142061506, 48.68460314614432, 51.80859661102295, 52.07666506086077, 52.0777177129473, 53.35006141662598, 55.20690843037197, 54.61541175842285, 53.10602331161499, 52.00122152056013, 53.098533153533936, 52.2211389541626, 52.26001065117972, 55.04187134334019, 49.3466796193804, 53.18780708312988, 52.396250929151265, 52.97849260057722, 54.78621237618582, 56.64197199685233, 50.6104735646929, 27.913797242300852, 5.326433888503483, 0.754347519150802, 4.472759970596858, 4.770510690552848, 3.159016077007566, 16.56382278033665, 53.85442073004586, 57.92161478315081, 55.46194205965315, 51.61854600906372, 54.57190561294556, 59.931645257132395, 49.5691123008728, 22.065262249537877, 48.37569318498884, 58.050660201481406, 27.37977433204651, 46.942613329206196, 49.56968205315726, 41.94330106462751, 61.23066656930106, 44.7465100969587, 0.5456967524119786, 0.09740602251674448, 0.15454205019133432, 0.19479907144393238, 0.07243926543742418, 0.1211606649948018, 0.0688584190128105, 0.13354227345968994, 0.08941315141107355, 0.10397962906530925, 0.09675528707781009, 0.08290823296244655], [0.06809563708624669, 0.036161736718245914, 0.04471264859395368, 0.04523267783224583, 0.04221797727846673, 0.08004911031041827, 0.004054430789048118, 0.04547556283484612, 0.025687110211168016, 0.10874102464211838, 0.04396591062790581, 0.02520234104511993, 0.0758351974987558, 0.0630330058879086, 0.06639457693589584, 0.15402457224471228, 0.11062446143478155, 4.918298874582563, 30.118804591042654, 34.183935029166086, 29.17966522489275, 29.2365049634661, 36.672779764447895, 64.51735210418701, 15.368699618748256, 29.463134356907435, 58.46637439727783, 59.45005866459438, 57.33617694037301, 60.03617395673479, 51.31995759691511, 56.402537073407856, 21.51298815863473, 0.9354251197406224, 6.632222746099744, 0.6011573278478214, 0.6587820500135422, 8.459607226508004, 44.21169335501534, 62.64993340628487, 62.70883328574044, 58.189141273498535, 60.02105467660086, 56.080078125, 52.26579850060599, 46.291591439928325, 46.029686042240684, 45.374800954546245, 42.93243619373867, 45.37410613468715, 52.93175554275513, 52.483468191964285, 55.08431788853237, 51.3324157169887, 50.83100938796997, 57.32095691135952, 51.73332330158779, 53.61080993924822, 52.50240898132324, 49.923039640699116, 47.59676538194929, 47.01240798405239, 44.514881474631174, 42.57091447285244, 40.17728090286255, 40.219654491969514, 40.182731764657156, 36.07539449419294, 36.99159090859549, 37.410115650721956, 37.38799606050764, 39.39146048682076, 41.00573893955776, 42.50294719423567, 43.14443268094744, 38.42024476187569, 36.96080344063895, 38.60033859525408, 36.99363367898123, 37.633722577776226, 38.26049872807094, 46.2876170703343, 48.25937686647688, 50.24613434927804, 47.64134502410889, 48.242722034454346, 46.77586351122175, 49.536716324942454, 49.67130987984793, 43.39522443498884, 48.592921665736604, 49.75447634288243, 46.03662381853376, 49.536174365452354, 45.16899878638131, 44.83041306904384, 37.4478200503758, 38.02803284781319, 37.82077503204346, 37.72248928887503, 36.90879617418562, 37.560509409223286, 36.79910148893084, 39.872585024152485, 40.11928081512451, 37.309787137167795, 37.06042323793684, 35.860698631831575, 35.072356019701274, 33.634092807769775, 35.63149493081229, 37.21619142804827, 38.265112331935335, 38.108718803950715, 38.65890148707798, 39.53408963339669, 39.8476687840053, 38.574960299900596, 39.87745223726545, 42.48617424283709, 45.73786170142037, 46.598198073250906, 48.37912906919207, 49.192287172589985, 47.31219843455723, 49.217411858694895, 49.3938752583095, 49.49519041606358, 49.26373897280012, 49.11009693145752, 43.958633014133994, 49.60711199896676, 48.58209637233189, 49.25379957471575, 46.70001002720424, 46.918027128492085, 44.407597814287456, 45.584233556474956, 49.27026680537632, 52.08150448117937, 52.70461893081665, 39.336892809186665, 7.038700180394309, 0.1689156610518694, 0.36926749667951037, 2.559856410537447, 1.1986491552421024, 15.665974821363177, 45.01346336092268, 52.38078423908779, 50.87697172164917, 46.63988379069737, 56.12285818372454, 57.90756205150059, 34.76122610909598, 22.844450610024587, 46.083694389888215, 36.1256160736084, 23.899623155593872, 31.413386004311697, 24.734365837914602, 31.551950454711914, 45.714765889304026, 8.617973174367632, 0.3097684165196759, 0.14776636234351567, 0.09251042628394705, 0.016584797030580894, 0.14992737424160751, 0.015213418386078306, 0.07832056270646197, 0.015453207572656018, 0.03828429603683097, 0.041085349661963325, 0.06447279612932887, 0.0205928083908345, 0.07871769568217651, 0.020603559778204987, 0.058198810288948674, 0.022158974083140492, 0.029762130297188247, 0.05553949584386178, 0.0554795947724155, 0.015033537056297064, 0.028838253979172026, 0.06019037842218365, 0.009458352379234774, 0.08680626736687762, 0.031755499940897734, 0.07166228177292006, 0.06260630914143153, 0.12083989435008594, 0.1276814950896161, 8.016201853752136, 42.84846026556832, 35.791942732674734, 36.47187955038888, 36.199485846928184, 35.02858236857823, 61.37343120574951, 16.571429320744105, 34.13654136657715, 61.95522471836635, 64.25354984828404, 61.925013950892854, 62.85307788848877, 54.057356766292024, 61.652505602155415, 24.396653856549943, 0.8772421532443592, 2.1070755294391086, 1.0628773378474372, 0.5135850555130413, 10.052479147911072, 49.865206309727256, 63.432224137442454, 62.69650023324149, 61.07844543457031, 62.401556151253835, 58.961259841918945, 55.845576422555105, 48.45444059371948, 48.27819953645979, 46.31433984211513, 43.07862976619175, 47.3750970023019, 55.40380300794329, 54.2586738722665, 56.106081758226665, 52.64156402860369, 52.162850516183035, 58.2553437096732, 53.65406247547695, 54.20701401574271, 54.148141929081504, 51.96852329799107, 47.799152510506765, 49.904317719595774, 44.81074966703142, 45.65041167395455, 43.250229426792686, 42.951137270246235, 43.68110111781529, 39.25591850280762, 39.35634429114205, 39.96524272646223, 38.324859891619, 41.29836927141462, 42.59312091554914, 43.45857116154262, 43.92547273635864, 41.41467864172799, 39.74974087306431, 40.00779002053397, 38.90414163044521, 39.61073521205357, 40.66923073359898, 48.26168366840908, 51.036328656332834, 52.72777032852173, 50.579811164310996, 52.72573103223528, 50.835018498556956, 52.561562470027376, 51.0261356489999, 50.27717195238386, 55.26948390688215, 51.325707231249126, 49.65743432726179, 51.8640467098781, 50.13023144858224, 45.531795501708984, 41.8496984073094, 40.70496531895229, 40.833475725991384, 40.01630851200649, 40.47033854893276, 39.64978756223406, 39.59487247467041, 43.04782840183803, 42.56024898801531, 39.5911100251334, 38.64822210584368, 38.22121013913836, 38.01915652411324, 36.643732820238384, 37.744772161756245, 39.16578299658639, 38.12401526314871, 40.83656072616577, 40.20645638874599, 39.9404411315918, 41.385899203164236, 40.626308236803325, 40.82280329295567, 44.539363452366416, 45.49633537020002, 48.562599727085654, 49.98302343913487, 49.581824030194966, 48.33534499577114, 51.17082493645804, 50.12905372892107, 51.90922737121582, 51.42886018753052, 51.17967694146292, 48.42351763589041, 50.890704836164204, 51.97886569159371, 50.62734726497105, 50.25716808864048, 49.65388379778181, 46.61666291100638, 50.406095777239116, 52.79146793910435, 54.75251708711897, 55.24113178253174, 44.37398590360369, 8.850683110100881, 0.18484026725803102, 0.31150603613683153, 0.9932298979588917, 1.0139653853007724, 19.1755724634443, 47.063734327043804, 59.04257461002895, 52.93137686593192, 50.17119107927595, 56.90129613876343, 61.94294030325753, 38.813255718776155, 25.4621479511261, 46.161625385284424, 44.26225887026106, 23.26499206679208, 41.09781299318586, 25.000467947551183, 31.217005593436106, 56.93917424338204, 6.822419694491795, 0.17418333196214267, 0.14455438112573965, 0.022697992123929516, 0.014085261467179018, 0.04106028797104955, 0.03329852928540536, 0.055701085565877814, 0.013011925936942654, 0.03952769110245364, 0.02987371538100498, 0.03184182655864528, 0.05446135798203094, 0.12894844210573606, 0.13882544210978917, 0.16085290083927767, 0.1401505802891084, 0.10848982419286456, 0.26638378309352057, 0.17180400820715086, 0.1111791298857757, 0.16030193040413515, 0.1985968726554087, 0.14348819905093738, 0.2015420946159533, 0.14622763491102628, 0.2540194908423083, 0.19235264057559626, 0.3732086723404271, 0.31868167966604233, 21.68350737435477, 61.52542999812535, 56.52521446772984, 44.015427589416504, 43.20582348959786, 47.35807391575405, 73.44388348715646, 19.783963680267334, 38.68114267076765, 68.07233537946428, 70.04934106554303, 66.83955819266183, 70.12234578813825, 58.65231513977051, 67.54837172372001, 28.248276574271067, 1.756489513175828, 13.345273886408124, 2.412712889058249, 1.3647096902132034, 14.463347605296544, 55.798738615853445, 63.507514817374094, 65.5160653250558, 62.4146535055978, 64.66840594155448, 60.66314465659005, 57.39970779418945, 49.99327550615583, 50.80169841221401, 48.64821890422276, 46.057558740888325, 50.46959883826119, 59.189667974199565, 55.63390302658081, 58.2489652633667, 58.567185810634065, 53.51202392578125, 60.10081304822649, 55.18241603033883, 56.750113759722026, 54.49650723593575, 53.82216024398804, 49.42104271480015, 53.50728178024292, 48.15753017153059, 48.20065764018467, 45.99726922171456, 45.735481943402974, 46.185937132154194, 42.27820771081107, 42.00352457591465, 43.95748308726719, 42.420093400137766, 43.83448954990932, 43.83906493868147, 46.394348348890034, 45.848244258335654, 43.56962769372122, 41.725673062460764, 42.8218069757734, 39.85397774832589, 41.585520948682515, 43.21487351826259, 52.54897928237915, 54.50637020383562, 57.20343508039202, 50.84525319508144, 56.403753008161274, 51.309396335056846, 54.76887662070138, 54.33687237330845, 49.89359664916992, 57.32784605026245, 53.40474026543753, 52.35860906328474, 54.84920127051217, 51.130716460091726, 49.205586024693076, 43.26035990033831, 44.181802204677034, 42.059659072331016, 42.388965470450266, 42.31283753258841, 40.73163945334298, 40.88563585281372, 44.88308388846261, 45.68136937277657, 41.868937969207764, 39.46558734348842, 40.3443329674857, 41.18080227715628, 38.48108318873814, 39.90362957545689, 43.09375946862357, 40.46443952832903, 42.15698248999459, 42.20463671003069, 42.15509605407715, 43.284796714782715, 40.49452870232718, 42.03719902038574, 47.13929598672049, 48.27632004874093, 50.31729432514736, 51.555126326424734, 52.41437183107649, 49.82888460159302, 51.80818666730608, 51.88237258366176, 52.94392531258719, 52.701492241450715, 54.48190907069615, 50.69460235323225, 52.47205924987793, 53.666854109082905, 52.08629526410784, 53.74046679905483, 50.08901820863996, 50.27742208753313, 51.84770802089146, 56.79368591308594, 57.19520493916103, 57.76692008972168, 45.87036384854998, 10.876474704061236, 0.6514056144016129, 1.0783572729144777, 6.42341765335628, 3.5915670607771193, 21.84544382776533, 52.354804924556184, 61.36887318747384, 59.0744321005685, 54.103603976113455, 62.50251347678048, 66.41441181727818, 42.62470047814505, 29.40708323887416, 55.91407176426479, 43.195974418095176, 34.36357375553676, 46.9638991355896, 33.67064380645752, 41.94256108147757, 66.23507186344692, 19.00064982686724, 0.5224252811500004, 0.24133921840361186, 0.214973084628582, 0.15868078810828073, 0.20631862830902847, 0.13957894167729787, 0.1468964261668069, 0.0697412405695234, 0.18496753328612872, 0.13997128419578075, 0.24555226947580064, 0.08048101820583854], [0.03239243397755282, 0.006135701675832803, 0.01664097633744989, 0.04342373739928007, 0.048745412911687575, 0.04430770568017449, 0.005991105439274439, 0.017668973854077712, 0.04210651093827827, 0.036308500450104475, 0.053374229531202994, 0.05244699107216937, 0.017125906655564904, 0.13326988236180373, 0.08997252210974693, 0.061014866323343346, 0.14786093655441487, 1.9512263493878501, 12.467128413064138, 29.710212298801967, 26.717657906668528, 27.945395912442887, 30.849894046783447, 70.06898362295968, 37.700967243739534, 19.02610628945487, 59.007889202662874, 57.26445068631853, 56.585830552237375, 57.07564033780779, 54.40945325578962, 54.05581774030413, 25.30150386265346, 0.3806119779390948, 3.105104135615485, 0.7904650153858321, 0.2779597262186663, 9.441437193325587, 45.01133026395525, 61.02290848323277, 64.27161516462053, 63.289799962724956, 60.54353141784668, 60.15497425624302, 57.88318429674421, 48.297428676060264, 43.42820405960083, 43.885951382773264, 43.87559161867414, 43.146357331957134, 42.738564082554404, 51.95571429388863, 53.63874169758388, 52.98915113721575, 51.56974186216082, 52.52284363337925, 50.36275291442871, 50.63549402781895, 48.241700649261475, 49.17127582005092, 45.05797699519566, 44.09843076978411, 40.84787586757115, 40.67037718636649, 39.780681201389854, 40.56093611036028, 37.30802924292428, 38.17868716376168, 37.03710855756487, 37.92100279671805, 36.85663604736328, 41.202268736703054, 39.92959499359131, 44.00794785363333, 43.867712361471995, 37.86851610456194, 39.53527430125645, 36.109774180821006, 38.102142333984375, 38.34058713912964, 40.25666407176426, 46.47845976693289, 48.199452127729145, 46.002761772700715, 48.00876923969814, 48.73406737191336, 49.46204056058611, 50.56438268933977, 49.40188305718558, 47.045043672834126, 50.90630006790161, 48.937465463365825, 48.6005403654916, 47.16552543640137, 45.65933663504464, 45.6755120413644, 40.41955416543143, 38.788224833352224, 37.21427372523716, 36.50900724955967, 38.921466963631765, 38.37048871176583, 36.186489241463796, 38.822826862335205, 41.18493298121861, 37.994747502463206, 37.56893062591553, 36.76757403782436, 36.18882731028965, 35.0115419115339, 36.319720949445454, 36.19721031188965, 38.957628863198416, 37.57545498439244, 39.09857307161604, 38.79504796436855, 38.6654953275408, 37.56942047391619, 37.964408193315776, 41.887579986027305, 42.18812779017857, 44.21413564682007, 45.772269180842805, 46.470597880227224, 47.32817929131644, 48.18914794921875, 49.78374910354614, 49.94698313304356, 50.19094828196934, 47.079874992370605, 47.40525565828596, 49.42554514748709, 49.51007693154471, 48.41874074935913, 45.15003020422799, 45.15516144888741, 43.28082929338728, 46.75751331874302, 47.94591236114502, 52.44398505347115, 51.90744515827724, 53.69104426247733, 26.51390024593898, 0.44031377722110066, 0.20218345948628016, 0.20651464350521564, 0.16623851470649242, 10.751274245125906, 41.78330489567348, 50.03711863926479, 48.11098766326904, 53.52156032834734, 54.613827569144114, 48.34799419130598, 28.49505226952689, 37.55741398675101, 54.13530513218471, 18.749123300824845, 25.615432160241262, 27.082200356892177, 23.8453368800027, 45.76030438286917, 35.1508081299918, 0.5622140318155289, 0.08443870940910918, 0.05689062869974545, 0.05164461662726743, 0.07330035351748977, 0.031118012898202454, 0.041102564095386436, 0.023593312295685922, 0.017719867373151437, 0.037341871964079995, 0.11523143601204668, 0.022759723543588604, 0.03112870321742126, 0.03282180754467845, 0.024916964483314326, 0.017838875630072186, 0.03134753754628556, 0.007933328809615756, 0.02664172586186656, 0.019038788475362316, 0.02956518211535045, 0.019754245977050493, 0.04791827533128006, 0.01687227196193167, 0.05071103725848453, 0.057328772331987105, 0.06519428241465773, 0.07025209601436343, 0.0519298863198076, 0.06754503984536443, 1.7213209888764789, 22.290138959884644, 39.2217298916408, 27.8870883669172, 39.868409156799316, 35.643053259168354, 68.91516576494489, 38.60510853358677, 22.691586766924175, 63.66808073861258, 62.754149436950684, 60.804116657802034, 62.94471767970494, 61.56670229775565, 58.24522713252476, 29.524090903145925, 0.16567305076335156, 0.49726487696170807, 0.6306162785206522, 0.29894738431487766, 11.20350990976606, 49.18307386125837, 63.970549719674246, 64.41031510489327, 62.23136002676827, 63.08788531167166, 60.96616949353899, 59.53468772343227, 50.07948180607387, 46.35142585209438, 43.568078245435444, 46.475169794900076, 45.18303067343575, 44.79609939030239, 51.38642406463623, 54.554274559020996, 54.37046691349575, 53.71776008605957, 54.14583165305001, 52.77533074787685, 50.52420820508684, 50.53097227641514, 50.572487762996126, 47.07790865216936, 45.71459913253784, 43.77434246880667, 41.69285672051566, 42.4329058783395, 43.381300245012554, 40.56969778878348, 41.624201570238384, 39.28015034539359, 40.154355321611675, 39.48886033466884, 42.73407554626465, 41.543209893362864, 45.04759986060006, 44.91654988697597, 41.745892320360454, 41.271205289023264, 39.35018471309117, 40.84416552952358, 40.3534767968314, 40.999534198216026, 48.76456648962838, 51.84753779002598, 50.97492047718593, 51.202831813267295, 51.49422189167568, 50.41215808050973, 55.27755423954555, 51.43044785090855, 53.392316886356895, 53.02021305901663, 52.04383829661778, 52.24877193995884, 50.94671426500593, 48.80766269138881, 48.15701600483486, 42.05369751793997, 40.585352080208914, 39.709656715393066, 39.234813349587576, 41.214865820748464, 40.44253185817173, 38.98048843656267, 42.241441317967, 41.85448224203927, 39.92993892942156, 38.662976605551584, 39.162840434483115, 37.17843491690499, 38.27594109943935, 38.08327797480992, 38.52734776905605, 40.61284957613264, 38.455149037497385, 38.98476505279541, 39.32335077013288, 39.321078709193635, 38.27018799100603, 39.050772939409526, 43.89976787567139, 43.79613201958792, 46.002271924700054, 47.14376367841448, 48.438449314662385, 49.326283182416645, 49.719162123543875, 52.089842319488525, 53.366170815059114, 52.25677973883492, 50.76592908586775, 50.89561026436942, 52.40057965687343, 52.56916379928589, 50.04883677618844, 48.2122437613351, 47.000363281794954, 46.26212065560477, 47.32893317086356, 52.406464781079976, 53.722512653895784, 53.582645416259766, 54.95479999269758, 32.78457130704607, 0.6687211224011013, 0.06985684258065053, 0.23191955100212777, 0.4868458903261593, 12.785856178828649, 48.690800939287456, 55.400002343314036, 53.725198132651194, 54.050300870622905, 59.86266354152134, 50.856849738529746, 32.11237130846296, 38.78658505848476, 58.77356815338135, 22.224853685923986, 26.975693157741002, 35.64633975710188, 21.366891860961914, 53.47151940209525, 35.436476366860525, 0.8859361410140991, 0.15789119047777994, 0.07392309260155473, 0.10941702193979706, 0.06472973698484046, 0.06006375700235367, 0.04423399302842362, 0.05529850395396352, 0.011019345938361116, 0.08022985168333564, 0.06725715779300247, 0.043552380853465626, 0.00511803018993565, 0.097426344640553, 0.12274264224937984, 0.12152593396604061, 0.0989071319678, 0.15669204268072331, 0.12644261228186743, 0.05756248014846018, 0.12111394107341766, 0.09147132454173905, 0.15219779312610626, 0.10003542713820934, 0.16668674136911119, 0.1459117904305458, 0.3722158670425415, 0.18265884502657823, 0.21847731087888989, 0.48742617347410744, 3.4461692741939, 46.26660919189453, 52.892102173396516, 39.87607996804373, 42.960645880017964, 42.96857724870954, 81.5094496863229, 44.58746235711234, 25.05249432155064, 70.22574887956891, 67.72472395215715, 66.4599781036377, 67.54325784955705, 65.42889322553361, 63.05855696541922, 32.47837461744036, 1.4084291671003615, 10.257572599819728, 2.642638768468584, 1.5054255851677485, 14.31739548274449, 55.4298483303615, 65.34472969600132, 66.75656196049282, 65.37824085780552, 64.90702097756522, 65.97127655574253, 63.50263718196324, 52.72167328425816, 48.79065350123814, 45.86008051463536, 49.74201127461025, 47.38931649071829, 46.485262053353445, 55.33799661908831, 57.96755279813494, 55.90131139755249, 58.83915219988142, 57.372853006635395, 55.022374698093955, 52.34112739562988, 52.16279493059431, 54.31909193311419, 49.16032893317086, 47.91435364314488, 44.91029303414481, 42.74543585096087, 43.93374456678118, 46.53460815974644, 41.509236676352366, 44.36069399969918, 41.53942312513079, 43.85492072786604, 42.46862309319632, 48.07398503167288, 43.24505649294172, 48.43953670774187, 47.512827668871196, 43.46967090879168, 41.93921552385603, 42.33341114861624, 43.30402932848249, 43.63884217398507, 43.66494655609131, 50.93713617324829, 54.05081156321934, 52.77114445822579, 53.71410880770002, 54.49582631247384, 52.91660846982683, 57.302662304469514, 55.102939060756135, 53.78318779809134, 57.78534671238491, 53.94527537482125, 55.175057888031006, 51.771666935511995, 49.51965502330235, 50.90535511289324, 44.91124841145107, 43.24014064243862, 41.766035148075645, 40.55542966297695, 44.60258511134556, 41.864901065826416, 40.945407731192454, 44.53296068736485, 44.389932019369944, 40.701393944876536, 42.07766880307879, 41.15776899882725, 41.42709854670933, 40.93034403664725, 41.994213989802766, 42.35276882989066, 43.93890013013567, 40.406508922576904, 40.956479685647146, 41.685335295540945, 42.16428852081299, 39.47203179768154, 41.37671715872628, 46.34175395965576, 45.98007937840053, 47.39048031398228, 51.50104849679129, 50.786325522831504, 51.659186022622244, 52.47448764528547, 55.905817304338726, 54.38614204951695, 55.472180230276926, 54.0136456489563, 52.782080922807964, 52.520564624241416, 54.288665771484375, 51.840457575661794, 50.722673075539724, 49.53266205106463, 48.63121666227068, 50.73226853779384, 56.00021553039551, 57.60811901092529, 57.254855224064414, 58.4607116154262, 34.831694739205496, 0.9979487018925803, 0.36024906060525347, 0.8626704237290791, 0.8935868133391652, 16.88097677912031, 52.20718002319336, 59.288478306361604, 58.95146983010428, 61.96693243299212, 65.22478294372559, 56.6554445539202, 35.70896734510149, 42.54901375089373, 64.70129871368408, 23.06069939477103, 40.303547041756765, 38.012917041778564, 37.457742077963694, 57.67407826014927, 53.48315068653652, 2.0430242121219635, 0.4055381789803505, 0.18645944180233137, 0.2160474769771099, 0.16715062861996038, 0.16621179399745806, 0.12252255263073103, 0.15277513143207344, 0.1512998877359288, 0.15450707849647316, 0.12685319382165158, 0.12242100307984011, 0.15528097482664244], [0.022063058069241897, 0.005722180383080351, 0.055672332644462585, 0.01414181651281459, 0.06313985479729516, 0.030093302883739983, 0.031119855120778084, 0.018382648505004387, 0.03689021530694195, 0.06470403407833406, 0.04647189312215362, 0.032286948923553736, 0.04786296794191003, 0.028829863893666437, 0.06843126764787094, 0.05531672261921423, 0.025074442283117344, 0.05827494870339121, 3.5581273351396834, 38.919236591884065, 33.753039019448416, 29.934441089630127, 22.107166835239955, 39.82504544939314, 63.61852618626186, 13.337423290525164, 39.042421204703196, 64.8591478892735, 55.21322781699044, 58.48201479230608, 53.257344654628206, 56.20738649368286, 35.63929080963135, 0.6691494137048721, 1.293372969542231, 0.2629901309098516, 0.8319801762700081, 18.353543247495377, 52.77826983588082, 61.75872271401541, 63.18782820020403, 60.993913650512695, 60.662901469639365, 61.762182916913716, 58.283973761967246, 50.32418693814959, 44.23900324957711, 45.855894224984304, 41.26403474807739, 42.50277348927089, 40.99185643877302, 42.53299467904227, 44.2021222114563, 46.32046467917306, 49.571571963174, 49.93509129115513, 48.68351227896554, 46.89028991971697, 45.54773119517735, 42.61368758337838, 42.947576318468364, 41.246869223458425, 40.09844664164952, 40.30906738553728, 39.93676553453718, 39.26770959581648, 38.623701913016184, 37.74629034314837, 36.98928410666329, 36.06278003965105, 38.22173820223127, 40.42950051171439, 41.057075704847065, 41.64129761287144, 40.38212769372122, 35.93089280809675, 37.91499955313546, 38.502157075064524, 36.96077912194388, 38.57702391488211, 43.16862283434187, 47.03910296303885, 48.86037867409842, 48.93357794625418, 48.90602486474173, 49.151664529527935, 49.16178805487496, 50.34390939985003, 49.76780646187918, 49.43812138693673, 51.716067450387136, 48.16286986214774, 47.82289797919137, 49.764207295009065, 47.41624423435756, 45.241767270224436, 39.87516280582973, 38.672068323407856, 38.101576055799214, 36.89337812151228, 37.25088725771223, 37.40023183822632, 36.40628855569022, 37.790571212768555, 42.19408934456961, 38.10579708644322, 38.93486309051514, 36.1027877671378, 33.56540639059884, 35.21832030160086, 35.99499341419765, 36.1579703603472, 35.044333934783936, 36.4080742427281, 39.03946474620274, 37.127511569431846, 38.301962103162495, 38.3996433530535, 38.082489354269846, 37.934180055345806, 39.67303623471941, 41.38772657939366, 43.112623827798025, 45.69843067441668, 44.540496008736746, 44.78877598898751, 46.91361154828753, 46.089166096278596, 49.128606932503835, 48.25307832445417, 51.281322138650076, 50.48297759464809, 48.76098469325474, 47.26134456907, 44.923307010105674, 43.54098374502999, 43.05923734392439, 45.370041438511436, 48.65359680993216, 51.097615242004395, 54.44846739087786, 51.18419327054705, 45.98161840438843, 5.062986859253474, 0.11876935831138066, 0.03980338666588068, 0.22497319802641869, 7.5011866092681885, 41.104125431605745, 50.723461696079795, 53.67879458836147, 52.55792856216431, 55.000585147312705, 45.82029512950352, 32.01607275009155, 53.287263597760884, 38.50520038604736, 23.80874071802412, 27.25577504294259, 26.26603889465332, 30.488195146833146, 48.11989525386265, 9.780425906181335, 0.22467044927179813, 0.06920487899333239, 0.07682256773114204, 0.0540385153144598, 0.05589394557422825, 0.038402591831982136, 0.024335551574560146, 0.0475659799495978, 0.03432792119149651, 0.019317944567384462, 0.0443148269051952, 0.034912221266755035, 0.07483605468379599, 0.025612839464364306, 0.016813112189993262, 0.053319532823349745, 0.043778719779636176, 0.03928030062732952, 0.024109204166701863, 0.05425008592594947, 0.05949817770825965, 0.025491795602387617, 0.04618664378566401, 0.03910505538806319, 0.06255229775394712, 0.040887739908482344, 0.051968376218740425, 0.030686858176652874, 0.0409109084866941, 0.03530440432950854, 0.2542482657091958, 9.865905250821795, 53.10151393072945, 32.79736641475132, 36.31662205287388, 29.803005490984233, 46.66051994051252, 65.37577424730573, 13.92774224281311, 45.67433084760393, 66.50019427708217, 58.450469970703125, 62.50722435542515, 58.95879323141915, 60.304562023707796, 40.59513861792428, 0.8644840121269226, 0.5905885206801551, 0.326716239963259, 1.0642808739628111, 21.580736568995885, 58.019000734601704, 63.82188606262207, 64.44624423980713, 62.14365291595459, 60.734203883579795, 62.92558928898403, 60.738219942365376, 52.143531050000874, 47.07873896190098, 47.415858609335764, 41.91245801108224, 43.346819809504915, 43.34540237699236, 45.14855718612671, 47.59739071982247, 48.2144706589835, 52.586774008614675, 51.720017501286094, 51.24935695103237, 48.584972926548545, 46.131390299115864, 45.03855330603463, 43.72099420002529, 43.305464131491526, 42.000078269413535, 43.83254752840315, 41.231836795806885, 40.6577662059239, 41.159856932503835, 39.89750821249825, 41.0377562386649, 38.77980014256069, 40.25081021445138, 42.364087445395334, 43.21672521318708, 43.69726610183716, 42.71783760615757, 40.27460432052612, 39.363337653023855, 40.98496729987008, 40.13986485345023, 41.689306191035676, 46.27054187229702, 49.207163265773225, 51.492939949035645, 52.516791752406526, 50.87670769010271, 50.568714891161235, 51.672582149505615, 52.10470451627459, 53.42161743981497, 52.08699008396694, 54.6989985874721, 53.170804841177805, 50.411970479147776, 52.62924139840262, 49.79129832131522, 46.48246192932129, 42.23261710575649, 40.30174051012312, 40.109952858516145, 38.377026966639924, 38.735435894557405, 40.16190453938076, 38.51795727866036, 40.222082887377056, 44.770773206438335, 40.95160205023629, 40.95042780467442, 38.08663395472935, 35.911465644836426, 36.167965344020296, 37.229128973824636, 37.9101288659232, 35.840788568769185, 38.29028565543038, 39.73339523587908, 39.51917879922049, 41.10752657481602, 39.62083094460623, 41.25782305853707, 39.05743973595755, 41.8161038671221, 42.88883624758039, 45.5283214024135, 46.09123318535941, 47.18045016697475, 47.20550537109375, 49.843083245413645, 48.947644574301584, 52.30569158281599, 51.86923354012625, 53.591493947165354, 52.77227701459612, 52.58397388458252, 47.77659518378121, 47.1658797945295, 44.717480523245676, 45.930601256234304, 47.77498320170811, 52.50647020339966, 51.885023321424214, 57.45763839994158, 53.18512160437447, 51.423617771693635, 6.714490285941532, 0.03106923301571182, 0.44046194212777273, 0.5927120638745171, 8.34122121334076, 45.975604738507954, 52.91373886380877, 58.32561779022217, 57.003441606249126, 60.37371744428362, 49.32128742762974, 37.68844311577933, 54.45701020104544, 46.98485490253994, 23.14906484740121, 33.586369105747764, 31.741195065634592, 29.892036233629497, 53.734303746904644, 6.970346408230918, 0.3868343069085053, 0.06539398884134633, 0.17282299138605595, 0.07885889881955725, 0.05305000853591731, 0.029123323503881693, 0.01744898092666907, 0.04460839168833835, 0.018411825510806272, 0.018748701184189746, 0.07127139810472727, 0.015066900623164006, 0.04127861339864986, 0.14208939910999366, 0.10187278461775609, 0.1342937374221427, 0.10611938924661704, 0.11361967107014996, 0.13639239195202077, 0.1346189049737794, 0.13330736463623388, 0.14466395096055099, 0.18403836100229196, 0.1282502431422472, 0.15111567904906614, 0.14978550613990851, 0.11689954650189195, 0.1312886415315526, 0.142674893406885, 0.20692686709974492, 0.5837917711053575, 24.7637654032026, 65.32110582079206, 52.01076487132481, 45.007953439440044, 35.8252489226205, 47.59534794943673, 75.0888625553676, 16.73208383151463, 51.41709688731602, 74.62339578356061, 65.08018398284912, 66.67020974840436, 64.12688418797084, 65.58069052015031, 44.317257336207796, 1.3357868364879062, 1.9184186926909854, 1.2471530096871513, 1.658743666751044, 25.146929025650024, 62.72372327532087, 69.43198667253766, 68.01878561292375, 64.97654465266636, 64.09398446764264, 66.20789745875767, 63.5109680720738, 55.14519453048706, 48.58228744779314, 50.451707226889475, 43.63138675689697, 45.97406571252005, 44.26087965284075, 45.71465819222586, 49.58936282566616, 48.55597809382847, 55.548325538635254, 53.89574861526489, 53.995615073612754, 51.666321822575156, 47.31691973549979, 48.289215905325754, 44.98699419839041, 45.229760783059255, 43.89173575810024, 45.07896750313895, 43.629090377262656, 44.0200377191816, 43.15596669060843, 42.3013973236084, 42.03953014101301, 42.07648760931832, 42.568836961473735, 45.104957239968435, 46.03819758551461, 45.53159400394985, 43.51272542136056, 40.20342697416033, 42.39479153496878, 43.30007232938494, 41.763506003788535, 44.840877056121826, 49.18045786448887, 52.23698084694998, 55.94564437866211, 53.24838147844587, 53.414742197309224, 53.35661704199654, 52.42914022718157, 53.14904308319092, 55.537667001996724, 54.207017489842, 56.783777781895225, 54.28768607548305, 52.65544305528913, 55.13996601104736, 52.91736582347325, 48.388252053942, 44.63243804659162, 44.291660172598704, 41.474266392844065, 41.75303854261126, 39.309544699532644, 41.44844341278076, 39.55747726985386, 42.97255161830357, 47.45253120149885, 43.95984894888741, 43.85293006896973, 39.94714961733137, 38.39986569540841, 38.30099630355835, 40.367310660226, 40.313486439841135, 38.84744780404227, 39.91667481831142, 44.18168755940029, 40.47081102643694, 41.53973579406738, 41.13537495476859, 42.73686524799892, 41.891801016671316, 42.85227830069405, 42.59834943498884, 48.14300148827689, 49.60155691419329, 47.893307549612864, 50.479642459324424, 52.46525001525879, 51.556352683476035, 54.74589892796108, 53.72774812153408, 56.20418684823172, 55.231550216674805, 54.55428498131888, 52.677712031773154, 49.632448605128694, 48.49529947553362, 48.44903836931501, 50.58190952028547, 53.46936893463135, 57.63892732347761, 59.693058013916016, 55.17132323128836, 52.682617459978374, 8.330866660390582, 0.13717440356101307, 0.9009584177817617, 0.5518169754317829, 10.950597218104772, 49.91960028239659, 60.75830718449184, 61.69929477146694, 61.558392252240864, 64.51761613573346, 55.5372188431876, 39.24095903124128, 63.86842509678432, 47.822880608694895, 31.279758249010357, 43.0444689478193, 38.587154388427734, 44.68166603360857, 61.22082792009626, 23.175586121422903, 0.725594624876976, 0.24058832441057476, 0.2948665932885238, 0.18811504010643276, 0.17106797413102218, 0.10273000504821539, 0.0684112101527197, 0.18532451055943966, 0.1326518998082195, 0.08009518962353468, 0.10247984954289027, 0.14399889164737292, 0.1375368633972747], [0.029795697424560785, 0.05488625321803348, 0.009125979633868804, 0.01374914066400379, 0.015536555421671696, 0.019118803021098887, 0.027741025534591505, 0.04778825784368174, 0.039235133943813186, 0.041699820796826055, 0.04678002265947206, 0.06637726072221994, 0.03137284690248115, 0.09581240160124642, 0.042925519669162374, 0.031006841720747094, 0.11266156605311803, 0.20320355546261581, 0.788074075111321, 30.141924721854075, 35.9635979788644, 24.897495644433157, 30.568019526345388, 18.06962421962193, 60.4047828401838, 39.3658390045166, 44.21322543280465, 66.78989941733224, 56.0411091532026, 56.3249500138419, 48.98101677213396, 57.87311635698591, 33.3826687676566, 0.7932989576033184, 0.07406494034720318, 0.20719639477985247, 3.9652852586337497, 24.687371696744645, 54.8716995375497, 63.251570974077495, 60.15361935751778, 60.10264042445591, 62.62268951960972, 61.77497455051967, 58.49095017569405, 49.30646692003523, 42.502961090632844, 42.60176794869559, 44.202170848846436, 44.261459827423096, 41.39480331965855, 42.57223463058472, 41.45100729806082, 44.31428350721087, 42.794594355991904, 45.44273001807076, 44.616332122257774, 44.27595376968384, 42.61023432867867, 40.55319929122925, 39.641164847782676, 40.626051153455464, 41.94257150377546, 41.10033171517508, 39.95933328356062, 37.00600494657244, 37.06723247255598, 37.03651796068464, 39.14856536047799, 36.02581214904785, 38.45846332822527, 40.36623021534511, 39.53495121002197, 41.34724637440273, 39.69983891078404, 37.30094902856009, 40.00263793127877, 37.78941433770316, 38.900886399405344, 41.09804228373936, 41.673415660858154, 47.57933235168457, 48.44628340857369, 48.32517630713326, 48.513173716408865, 48.1744316646031, 50.68683079310826, 50.69164589473179, 48.815861565726145, 50.985606806618826, 49.19875941957746, 50.682943275996614, 49.34855910709926, 48.24148178100586, 49.54312603814261, 46.90150431224278, 40.10855974469866, 37.31464392798287, 38.2926549911499, 37.54192992619106, 36.36409909384591, 37.47073520932879, 36.98707110541207, 37.84860256740025, 39.86044652121407, 37.74512651988438, 38.98774930409023, 38.41162552152361, 36.19790513174874, 34.67765665054321, 35.63512536457607, 35.53106566837856, 37.08620800290789, 39.06938368933541, 39.2921325138637, 39.335760252816335, 41.18990789140974, 40.408593382154194, 38.078431606292725, 37.669161864689414, 40.11200257710048, 38.659116881234304, 41.10939564023699, 42.15895577839443, 43.31421191351754, 45.65893016542707, 47.3028496333531, 47.19004562922886, 48.84760788508824, 49.38843134471348, 50.628775119781494, 48.30903911590576, 46.26381949016026, 43.58620262145996, 41.82718276977539, 42.46693468093872, 43.701507977076936, 46.27991846629551, 46.469253403799875, 48.573716844831196, 52.43871831893921, 51.25224045344761, 53.574404852730886, 17.602370023727417, 0.04815041912453515, 0.33031236699649263, 0.2641921692660877, 12.854520882878985, 44.92125381742205, 56.386601379939485, 46.334725856781006, 54.79362262998308, 48.26698166983468, 46.056742327553884, 42.91337728500366, 49.66982643944876, 32.51983104433332, 18.46442607470921, 36.60161631447928, 21.921988657542638, 41.01183598382132, 37.094181060791016, 0.3340942769178322, 0.15362304236207688, 0.05289877325828586, 0.052883570681193044, 0.056817404593208005, 0.05638702679425478, 0.030524043698928187, 0.0687429459233369, 0.019441997732168863, 0.01830246432551316, 0.019477254411737834, 0.063294961117208, 0.06236015699271645, 0.025521291519648263, 0.05815461051783391, 0.010077435855886765, 0.030211252626031637, 0.026882527761959603, 0.006954428814684174, 0.03780999666612063, 0.05251230685306447, 0.03500373189204505, 0.04258529203278678, 0.06265149278832333, 0.09960716976118938, 0.07401686614113194, 0.027985980068998675, 0.09171886768724237, 0.0652543870466096, 0.039627707164202414, 0.06873724622918026, 0.37335624013628277, 2.5446040289742604, 44.870931489127024, 38.38375282287598, 29.323534624917166, 39.78147677012852, 22.440447602953228, 66.30581147330147, 41.398228781563894, 49.45207336970738, 72.46370111192975, 61.3809700012207, 61.54954024723598, 54.84258311135428, 62.942890303475515, 36.63931029183524, 1.1894842641694205, 0.26868078698004993, 1.3616419519696916, 5.3881121788706094, 27.15205407142639, 57.530705656324116, 65.5867840903146, 62.257936886378694, 63.18773092542376, 64.52121530260358, 63.46802125658308, 59.406396184648784, 51.512509550367085, 44.301564829690115, 44.60741410936628, 46.07990762165615, 45.79933588845389, 43.41474887302944, 44.63957037244524, 42.105211462293354, 45.18851627622332, 45.04471983228411, 46.72592680794852, 45.123112882886616, 46.066494124276296, 43.05847304207938, 43.25512443270002, 41.226031575884136, 42.82323135648455, 43.939202376774375, 43.43193176814488, 41.42402744293213, 40.68630940573556, 38.758615085056846, 40.415777819497244, 40.015137740543906, 38.4935691016061, 40.560519218444824, 41.23317084993635, 41.97044767652239, 43.21704135622297, 42.84880420139858, 38.430684430258616, 40.147014549800325, 39.438739504132954, 41.79006896700178, 42.831819329942974, 45.55190358843122, 49.37044940676008, 51.49064704350063, 49.76975195748465, 50.636887141636436, 50.88757814679827, 52.25307982308524, 53.468173844473704, 52.235817023685996, 54.24081005368914, 54.46414252689907, 53.07633713313511, 51.23786115646362, 51.76772035871233, 50.95273835318429, 48.351582935878206, 42.33733688082014, 40.33898980276925, 40.960398469652446, 38.897679805755615, 38.647256306239534, 39.41635240827288, 38.94283267429897, 39.980865750994, 41.871873583112446, 41.036133834293906, 40.61377368654524, 39.19858544213431, 36.78155033929007, 36.24326297215053, 36.868232590811594, 37.92040177753994, 38.17823553085327, 40.59447506495884, 39.82716812406267, 41.06946781703404, 42.359703132084434, 43.17270837511335, 40.68944999149868, 39.740815911974224, 40.551670687539236, 40.6662186895098, 41.46765865598406, 44.607011113848, 45.60191672188895, 49.69681324277605, 49.79344878877912, 50.50938422339303, 52.921034472329275, 51.79752465656826, 52.194544724055696, 50.016395636967246, 50.019678660801475, 45.776799406324116, 43.981478691101074, 45.135501520974294, 47.860713550022666, 50.01592663356236, 50.05816125869751, 51.170418466840474, 55.45049490247454, 54.98346478598458, 59.53124141693115, 20.9007910660335, 0.024180419809584106, 0.1459728314408234, 0.9316084959677288, 15.152992793491908, 47.524292196546284, 59.4645665032523, 50.61979457310268, 58.178402832576204, 50.88698754991804, 52.26708391734532, 44.585482120513916, 53.282872336251394, 37.83512653623308, 16.027804000037058, 46.08131810597011, 21.99880620411464, 46.090837138039724, 40.22980581011091, 1.0782656435455595, 0.10984956087278468, 0.08748535878424134, 0.04432468941169126, 0.073347627052239, 0.05703014228492975, 0.07511804705219609, 0.06049399570162807, 0.04251548095739313, 0.057120190667254586, 0.06658096372016839, 0.04944287905735629, 0.03961387862052236, 0.07888044909174953, 0.10294470031346593, 0.12196487826960427, 0.10689070035836526, 0.0764135807486517, 0.09162993888769831, 0.1523907549147095, 0.18530001544526645, 0.1516671787415232, 0.16326634133500711, 0.22927467578223773, 0.3156023249030113, 0.15830853022634983, 0.14894823463899748, 0.30503712754164425, 0.17112748165215763, 0.12232366044606481, 0.23395369042243275, 0.5978645331093243, 9.930150032043457, 61.77274417877197, 55.629362378801616, 40.41541998726981, 47.36843020575387, 25.807277134486608, 70.64821325029645, 47.909274509974885, 53.14189338684082, 80.18728392464774, 67.42156015123639, 66.73103427886963, 60.778769629342214, 68.57171630859375, 39.44817863191877, 2.016467545713697, 0.8513514825275966, 3.081764919417245, 6.846570764269147, 30.60740886415754, 61.95223004477364, 68.74077987670898, 66.7165333884103, 65.25639029911586, 66.97529125213623, 67.40354347229004, 60.78705188206264, 54.77980266298567, 47.329489026750835, 47.9548407963344, 48.39182342801775, 49.34640863963536, 46.32755184173584, 45.74072783333914, 44.47911214828491, 47.337892872946604, 46.81189686911446, 50.5239337512425, 47.42930684770857, 46.84257663999285, 46.55274990626744, 44.7980831010001, 43.37412622996739, 44.54384504045759, 46.561650548662456, 46.16065958568028, 44.1626911844526, 43.442340169634136, 41.58777911322457, 43.26608174187796, 43.79154968261719, 41.41281305040632, 44.820202691214426, 43.872145312173025, 44.09173270634243, 46.38177558353969, 45.29453536442348, 41.39394869123186, 45.3729110445295, 42.34599781036377, 43.134472438267295, 46.742425305502756, 48.82005827767508, 50.35498135430472, 53.58844368798392, 51.92090729304722, 52.80833469118391, 51.93748222078596, 56.36734792164394, 56.48268107005528, 52.69723299571446, 56.04475000926426, 55.287347725459504, 55.311461448669434, 54.79831613813128, 52.449380329677034, 54.76606260027204, 51.56324182237898, 45.50990867614746, 41.81785133906773, 42.514967577798025, 41.32339668273926, 40.57015289579119, 42.029208592006135, 40.967711448669434, 42.10560056141445, 43.1825852394104, 41.060539381844656, 42.859236921582905, 43.86413056509835, 39.23481682368687, 38.52754579271589, 39.63568271909441, 39.45121846880232, 39.667046887534006, 43.370565278189524, 42.306188106536865, 43.49316276822771, 44.02391133989607, 44.64372886930193, 42.719091756003245, 42.01353693008423, 42.78344944545201, 42.94772917883736, 43.861316544669016, 45.56908995764596, 47.38914973395211, 52.083185945238384, 51.60727603094918, 52.452771050589426, 53.42449746813093, 53.95528425489153, 54.851188455309185, 53.09009804044451, 51.94875914709908, 48.27131387165615, 46.6005083492824, 48.474277700696675, 50.84702498572213, 53.52991206305367, 51.240529264722554, 54.406934533800396, 59.06355816977364, 57.34180498123169, 61.74675096784319, 23.88515874317714, 0.11844071666044848, 0.6194129596863474, 1.4106408655643463, 17.47071381977626, 53.12171234403338, 65.72091211591447, 54.62076881953648, 63.944035393851145, 56.310369219098774, 55.38623101370675, 48.25355775015694, 59.2619639805385, 37.500678471156526, 30.713254247392925, 53.098164899008616, 35.41508633749825, 53.602607590811594, 55.062576975141255, 2.379657485655376, 0.583397949380534, 0.249574353652341, 0.1965653116681746, 0.17120809161237308, 0.16800434780972345, 0.10301608898277793, 0.16862877644598484, 0.1428596992045641, 0.14307407555835588, 0.14299612545541354, 0.23194115555712155, 0.1554635821708611, 0.15720671149236815], [0.009179259051701852, 0.02761816150242729, 0.10749600109245096, 0.028147233916180472, 0.03273800846987537, 0.013535142593484904, 0.031207474347736155, 0.043002261979771514, 0.028017945853727202, 0.029013970800276314, 0.029588028389428343, 0.03122318582609296, 0.036408119568867345, 0.07242908062679426, 0.03383185102471283, 0.044167126795010905, 0.04916838789358735, 0.015616802365652152, 0.19970639954720223, 21.615614788872854, 42.06856318882534, 24.863581487110682, 28.597411394119263, 20.942787715366908, 45.37272344316755, 52.79716893604824, 43.65079307556152, 60.154890877859934, 54.31210899353027, 59.437670026506694, 53.81638976505825, 59.042039598737446, 28.13974223818098, 0.4699186129229409, 0.12001285515725613, 0.6528828122786113, 10.816698483058385, 34.673112528664724, 58.54878003256661, 63.74490697043282, 58.484488351004465, 54.88931669507708, 57.90959439958845, 58.35423047201974, 55.20652280535017, 47.27177381515503, 42.78296307155064, 45.42340360369001, 44.16098887579781, 45.57216106142317, 44.33949504579817, 43.89206232343401, 41.910887718200684, 41.093116010938374, 41.940122263772146, 42.111513478415354, 41.09613847732544, 41.4707783971514, 41.113001755305696, 40.44462674004691, 38.9644832611084, 40.01982430049351, 39.678337710244314, 39.21952731268746, 37.73064994812012, 37.54998983655657, 38.333819593702046, 37.36443819318499, 37.18543870108468, 38.82719380514962, 39.1678500856672, 37.25580310821533, 37.28669827325003, 37.67121853147234, 37.744615827287944, 37.54252747126988, 37.47461577824184, 37.669523171016145, 37.7848458971296, 39.080160345349995, 43.73318134035383, 47.44699348722185, 46.943950857434956, 49.81968518665859, 49.806560039520264, 49.930498531886506, 51.01987879616873, 52.06771578107561, 51.271195139203755, 52.928573267800466, 51.14795841489519, 49.62482990537371, 48.20607723508562, 49.23267010280064, 47.27920143944876, 46.72217130661011, 41.72952583857945, 38.21188218252999, 37.57213374546596, 37.34454550061907, 36.997007029397146, 37.78931358882359, 36.333492279052734, 37.12734133856637, 38.6535895892552, 38.41636419296265, 40.801576546260286, 37.440163135528564, 35.49597726549421, 35.98428276606968, 36.31990507670811, 37.3379933493478, 38.089243003300254, 37.58974742889404, 39.220878737313406, 40.76277780532837, 44.28886352266584, 41.869743960244314, 38.49432298115322, 37.3409880229405, 37.14914131164551, 36.909643854413716, 38.29280437741961, 38.30388675417219, 40.91707992553711, 43.47454507010323, 43.00649356842041, 44.54656526020595, 46.5029730115618, 46.65754263741629, 48.68277924401419, 44.70833321980068, 42.016104289463584, 39.787997654506135, 39.80351645605904, 43.63842528206961, 47.10706329345703, 48.41210174560547, 50.53141001292637, 48.325891971588135, 49.493779931749614, 51.827099663870676, 50.53045116152082, 33.15119647979736, 0.46211638301610947, 0.5408882190074239, 2.6406719940049306, 20.843558754239762, 45.619408811841694, 49.923661504473, 53.27751874923706, 55.721686567579, 51.399865354810444, 52.568260533469065, 41.4446496963501, 42.380731855119976, 35.41874803815569, 30.52520820072719, 30.01321976525443, 26.387474298477173, 49.32018266405378, 16.37518092564174, 0.27407058062297956, 0.07141880983752863, 0.10689167744879212, 0.06114242412149906, 0.04555972831855927, 0.03807777033320495, 0.07184603584132024, 0.029682127625814507, 0.01066667481791228, 0.01923959412878113, 0.04307367439780917, 0.0789394002141697, 0.006134113903889167, 0.0018164068626772079, 0.02474145800806582, 0.030736404803714583, 0.05324508735377874, 0.024057567651782717, 0.02383142041175493, 0.004544132056513003, 0.051252752475972684, 0.05817922098296029, 0.03689526700015579, 0.0233977313619107, 0.06494767564748015, 0.020934637369854108, 0.01835276751912066, 0.03940613494653787, 0.04891607464690294, 0.018247163721493313, 0.0570220337914569, 0.03908028546720743, 0.5319368221930095, 29.375152792249406, 50.92998647689819, 25.99817715372358, 44.37361764907837, 23.230223281042917, 49.88230235236031, 56.543804373059956, 47.43078681400844, 65.71581908634731, 60.07272148132324, 63.98539802006313, 55.77912385123116, 63.51266343252999, 32.45992367608206, 1.0700207373925616, 0.05523508807112064, 0.9205460952860969, 12.358488116945539, 37.557764870779856, 60.39927986689976, 65.19320338112968, 59.2932517187936, 56.21103082384382, 58.43046610695975, 61.15529251098633, 56.32711090360369, 49.54591921397618, 44.91653251647949, 47.2875531741551, 45.65097100394112, 47.963699749537874, 45.08594696862357, 45.03908484322684, 43.27562509264265, 42.44646181379046, 43.056534494672505, 42.79079369136265, 41.962589263916016, 43.99396807806832, 42.6462642124721, 40.30612482343401, 41.06343330655779, 41.91831186839512, 42.07114444460188, 41.24454157693045, 42.10946028573172, 40.68536792482649, 41.260272298540386, 39.729695320129395, 40.00105374200003, 40.405977385384695, 40.566960198538645, 40.81905126571655, 40.926380089351106, 39.66719627380371, 40.70847068514143, 39.577022552490234, 39.31055566242763, 38.59933805465698, 40.646093232291086, 41.3265164239066, 46.559222153254915, 48.39806638445173, 51.240425041743684, 52.90297957829067, 53.32264035088675, 52.80927617209298, 54.83067389896938, 52.57792895180838, 54.38509634562901, 54.732808521815706, 53.17224311828613, 52.84405885423933, 52.05476781300136, 52.62938731057303, 50.53204229899815, 49.270318916865754, 43.110351766858784, 40.39711495808193, 41.09890038626534, 39.14845418930054, 40.51748207637242, 39.818885871342246, 39.41682488577706, 40.25163357598441, 43.064722946711946, 39.425972189222065, 42.08014236177717, 38.981054714747835, 37.94936534336635, 37.01446785245623, 37.808827604566304, 38.8441196169172, 39.38333804266793, 39.63711404800415, 40.78287894385201, 42.265634945460725, 45.87490102222988, 43.35589068276541, 40.856234550476074, 39.80222061702183, 39.00889267240252, 39.47549894877842, 39.84015778132847, 40.92618553979056, 42.982563972473145, 45.099707875932964, 46.40295716694423, 46.80411836079189, 48.47245379856655, 49.250881331307546, 50.5795818737575, 47.68986429486956, 44.093386377607075, 42.47987570081438, 41.005408900124685, 45.32460021972656, 49.70733281544277, 51.65615660803658, 51.41548490524292, 52.40331377301897, 51.43748985018049, 56.51649100439889, 53.62374748502459, 38.21154172079903, 0.7737797307116645, 0.44652511392320904, 4.403417817183903, 24.28727184023176, 49.80512523651123, 55.03444719314575, 57.51168843678066, 64.47475964682442, 55.13235773359026, 58.456917898995535, 44.488933426993235, 51.25371694564819, 38.6756466456822, 32.5578168460301, 39.18272965294974, 26.03871989250183, 53.65262419836861, 10.78762982572828, 0.1806056930550507, 0.03125471395573445, 0.08486972163830485, 0.0557629917083042, 0.015710107716066495, 0.013169309590011835, 0.03953371310074415, 0.028762254664408307, 0.03171233154301133, 0.0440213401535792, 0.029106071751032556, 0.04396076054711427, 0.04199894617444702, 0.02689014601388148, 0.05820860154926777, 0.227020012480872, 0.19421454066676752, 0.10673039646020957, 0.052020538598299026, 0.09848052343087536, 0.07409632937716586, 0.11436453967222146, 0.19355712165789946, 0.12295369378158025, 0.1926727055438927, 0.08147468524319784, 0.06036077892141683, 0.16726782518838132, 0.1270192584821156, 0.09459223957466227, 0.12167667730578355, 0.11206934747419187, 0.8964887719069208, 50.29432358060564, 60.55195958273751, 41.66678013120379, 46.478737694876536, 34.03150544847761, 53.583100523267476, 63.76299313136509, 51.80791221346174, 71.50268881661552, 65.44001729147774, 67.42802892412458, 61.04926994868687, 68.59366566794259, 36.513888359069824, 1.7624108982937676, 0.2577025517821312, 1.2475294066326958, 15.509906121662684, 42.75246047973633, 65.54344817570278, 68.95916870662144, 64.21634919302804, 60.56158978598458, 61.89688764299665, 63.422517504010884, 58.765014920915874, 52.38152422223772, 46.94559758050101, 50.534234455653596, 48.64659997395107, 50.27386808395386, 48.12009675162179, 48.03042677470616, 45.526983874184744, 45.164107254573274, 45.3389447757176, 44.55754688807896, 44.790050983428955, 45.97284977776663, 45.28144495827811, 43.93117025920323, 44.535187585013254, 43.51289217812674, 43.46026652199881, 44.387976101466585, 42.947149004255024, 42.57052537373134, 44.26980808803013, 44.036643913814, 42.61564697538103, 44.38795525687081, 44.5160939352853, 42.98000356129238, 43.022575174059185, 42.11249317441668, 41.714781761169434, 42.474556854793, 42.98811558314732, 41.29750074659075, 42.19442285810198, 44.32428543908255, 49.837524686540874, 52.50911399296352, 52.18599149159023, 56.23861517224993, 55.99477856499808, 55.79616430827549, 57.91866527284895, 54.66089466639927, 57.88709265845162, 58.82475553240095, 55.41656684875488, 52.79653664997646, 54.47913326535906, 54.47346353530884, 52.837701252528596, 51.94773428780692, 46.45483936582293, 43.009154728480745, 43.22420842306954, 40.697009631565635, 41.80329833711897, 41.67935637065342, 40.75279324395316, 41.16389036178589, 43.918924059186665, 41.19219037464687, 44.40395695822579, 41.53143617085048, 39.82821035385132, 39.43004730769566, 39.493946416037424, 42.848404679979595, 42.04608924048287, 41.536956514631, 43.58301339830671, 44.341405800410676, 48.02346467971802, 45.13101645878383, 42.11836092812674, 42.07134246826172, 41.46400737762451, 40.382197175707134, 41.86662769317627, 41.894733156476704, 44.358331612178254, 48.41639920643398, 50.00268336704799, 48.09651109150478, 50.91221645900181, 51.43973411832537, 53.687768186841694, 50.027311256953645, 47.10603148596627, 45.20455619267055, 44.62889099121094, 47.02261141368321, 52.74451548712594, 53.62025254113333, 54.139345509665354, 56.1571683883667, 54.315291268484934, 59.37190532684326, 58.73672185625349, 41.47474929264614, 0.99724280834198, 0.9461989530495235, 7.595932245254517, 25.0382696219853, 55.74844755445208, 57.888954775674, 62.45741271972656, 64.16706562042236, 60.4878693989345, 60.48236642565046, 50.839253425598145, 56.39033951078142, 42.18929508754185, 47.05062655040196, 42.49227476119995, 40.17712456839425, 61.08310072762625, 28.35644439288548, 0.38601414806076456, 0.1485961563885212, 0.19279675531600202, 0.18371575831302575, 0.07624005898833275, 0.14434854074248246, 0.12410102864461285, 0.09257162335727896, 0.13281903655401298, 0.11566436849534512, 0.18650419797216142, 0.13448705204895564, 0.10446378415716545, 0.09478652450655188], [0.03459488061655845, 0.036188755982688496, 0.03601021306323154, 0.012214622693136334, 0.03192934739802565, 0.03368922635646803, 0.07637393394751207, 0.016540149426353828, 0.027805605104991367, 0.04184631311467715, 0.056287003947155814, 0.011293367216629642, 0.01757116981648973, 0.05818588419684342, 0.07590105610766582, 0.05434421569641147, 0.042295767925679684, 0.13611404331667082, 0.3073186065469469, 7.448486260005406, 54.14080115727016, 32.38705791745867, 26.891976049968175, 25.244514737810405, 30.427130903516495, 63.32637528010777, 48.15565415791103, 54.7509572165353, 60.11978163037981, 55.31011002404349, 56.23777444022042, 58.67083903721401, 29.44859525135585, 0.7359399497509003, 0.08223835605063609, 2.361867925950459, 18.927216053009033, 48.15141575677054, 63.20137023925781, 62.300341742379324, 58.55100345611572, 56.491046701158794, 54.31287676947457, 55.991637979234966, 52.083641052246094, 44.49853236334664, 43.42695338385445, 43.786376748766216, 46.85765075683594, 48.55945219312395, 49.16082920346941, 46.23163890838623, 44.09102399008614, 42.70280517850603, 42.466931206839426, 39.82905455998012, 39.084746156420024, 41.02849776404244, 38.15573031561715, 40.87921919141497, 40.34274183000837, 40.80872276851109, 41.55635935919625, 41.665182045527864, 39.81148951394217, 39.00151021139962, 38.24337141854422, 40.14225155966622, 39.517073495047434, 37.195034163338796, 37.04514414923531, 38.21568284715925, 38.31611558369228, 37.222319739205496, 37.557625906808035, 39.01442691258022, 39.416571276528494, 37.94267422812325, 39.96334934234619, 38.952389921460835, 42.009743213653564, 45.53403976985386, 48.95186907904488, 50.22409118924822, 51.04158844266619, 51.312988553728374, 50.082254137311665, 37.786496094294954, 52.22481802531651, 53.65286043712071, 49.507697173527305, 49.59847886221749, 48.2915609223502, 49.34978893824986, 46.67723730632237, 47.36650902884347, 41.15403781618391, 39.920812470572336, 39.149600642068044, 38.062756470271516, 36.20280361175537, 36.745041029793875, 35.77683734893799, 36.57897560937064, 37.96990074430193, 37.61402790887015, 39.692994935171946, 36.65860196522304, 35.75718436922346, 35.54729666028704, 37.5137654032026, 37.03858504976545, 37.204139777592246, 37.038664954049246, 38.85979127883911, 41.52524880000523, 42.165966510772705, 39.92125020708357, 38.22868292672293, 37.66132429667881, 34.96188661030361, 34.64358268465315, 38.15418086733137, 39.19258567265102, 39.82809223447527, 39.60207775660923, 39.24251890182495, 40.53591912133353, 40.0351242337908, 41.37152338027954, 39.767264229910715, 40.22154440198626, 38.505228178841726, 38.40244000298636, 42.030417578560964, 48.419036047799246, 50.64245959690639, 52.04788909639631, 47.82660831723894, 50.040422507694785, 47.773023809705464, 54.1698203086853, 49.39673096793038, 44.775369439806255, 5.479075823511396, 0.9281771715198244, 2.900579567466463, 23.99318586077009, 51.84486968176705, 49.43556097575596, 48.94250290734427, 45.58559192929949, 55.56501511165074, 55.336193561553955, 45.85711710793631, 35.63984319141933, 21.483991588865006, 23.561397007533483, 24.249013321740286, 35.80230597087315, 39.93596996579851, 0.3892596624791622, 0.16294490572597298, 0.06188706202166421, 0.058003147930971215, 0.07753865287772246, 0.04702245982896004, 0.016439424295510565, 0.009765741465214108, 0.020275203111980642, 0.05321754901004689, 0.02514369017444551, 0.02291687734292022, 0.05770325580877917, 0.0619091551218714, 0.04561546318499105, 0.04990978918171354, 0.005905691451126975, 0.02502414757119758, 0.05682025444028633, 0.01732874452136457, 0.008852682691732687, 0.002493674717178302, 0.028452730737626553, 0.02406400186009705, 0.03867171917642866, 0.03214777121320367, 0.023670458334631155, 0.03108837448858789, 0.05340989672445825, 0.07263376071516957, 0.05811568974916424, 0.04453851275944284, 0.1430878091071333, 0.42128963662045343, 10.568954382623945, 66.02777930668422, 30.14276545388358, 31.731512750898087, 29.38429662159511, 35.98138536725725, 69.03534875597272, 51.86233745302473, 61.613866669791086, 65.5652585710798, 61.07031604221889, 61.537005696977886, 63.85854475838797, 33.34135825293404, 0.7641138093812125, 0.1084844773369176, 3.587399661540985, 21.00281146594456, 50.625200271606445, 63.84518337249756, 63.92655372619629, 60.897486550467356, 59.789123807634624, 55.735360622406006, 57.79012707301548, 53.92345455714634, 46.994714396340505, 44.07360485621861, 44.36590167454311, 50.25570549283709, 50.57090009961809, 49.218697275434224, 50.19518320901053, 46.20795944758824, 44.227166993277415, 44.81905276434762, 42.22563416617257, 40.81867953709194, 40.75001049041748, 40.080197198050364, 42.89809124810355, 41.1080060005188, 41.61015231268746, 43.84048237119402, 43.58522639955793, 42.1336886542184, 40.9618193762643, 40.449094431740896, 43.47288792473929, 41.792584214891704, 40.42790937423706, 40.390260560171946, 40.505895955221995, 38.30471011570522, 38.74738679613386, 39.48733173097883, 40.71008961541312, 41.69480569022042, 40.46873351505825, 41.05226755142212, 40.49583148956299, 44.47438737324306, 48.80490773064749, 50.21854305267334, 51.33613300323486, 53.195912156786235, 52.0543509210859, 54.844757897513254, 45.92086335590908, 52.838302271706716, 56.686923367636545, 53.16119548252651, 52.88690839494978, 53.096473012651714, 53.125964641571045, 50.47429929460798, 49.49438789912632, 44.2647567476545, 42.84703241075788, 42.57170309339251, 40.28923027856009, 40.33583532060896, 39.01156425476074, 39.53998517990112, 39.39783893312727, 40.56625148228237, 41.53942312513079, 42.439576148986816, 40.47605344227382, 38.931774616241455, 36.929512228284565, 39.226965359279085, 39.470784596034456, 38.94135965619768, 38.89483799253191, 39.05979517527989, 42.67647845404488, 43.63283198220389, 41.30508470535278, 38.283351353236604, 37.987868785858154, 37.2079439163208, 38.8622578893389, 39.1575528553554, 40.65716866084507, 40.71346296582903, 40.501497745513916, 41.0470529283796, 42.775789056505474, 41.10228763307844, 43.900247301374165, 42.16273559842791, 42.36594956261771, 39.63480724607195, 41.56040668487549, 43.48163570676531, 51.659477846963064, 52.688141277858186, 55.52497959136963, 50.98430749348232, 53.281288146972656, 52.140682288578574, 57.937460150037495, 52.504486492701936, 51.905141830444336, 6.16179496049881, 0.6785896271467209, 4.203961959906986, 26.379179886409215, 56.49924904959542, 54.74614211491176, 54.06202595574515, 50.734919275556294, 60.32918643951416, 58.89701679774693, 49.38841050011771, 45.8077049936567, 21.208137682506017, 32.539598669324604, 25.09950409616743, 37.68741825648716, 45.3679951940264, 0.8783616274595261, 0.12121870688029698, 0.031036381742783954, 0.044413764096264324, 0.03790975488456232, 0.04123057311932955, 0.01603302762045392, 0.08464957095150437, 0.017583473352715373, 0.03274003389690604, 0.020090936749641384, 0.04956925281190446, 0.013560717426506537, 0.06365710204201085, 0.01795569391522024, 0.14251975316022122, 0.1282835184995617, 0.16893672277884825, 0.19293539359101228, 0.11551612216447081, 0.06582990687872682, 0.1594660702560629, 0.10763862236802067, 0.12106820781316076, 0.1352440392864602, 0.17861968890896865, 0.08744366280734539, 0.14183365926146507, 0.13767841937286512, 0.31486025186521666, 0.10763685139162199, 0.1376232137637479, 0.40707945770451, 0.6658098814742905, 21.371248381478445, 76.37359142303467, 47.45472683225359, 40.9187023299081, 38.43818848473685, 40.11525085994175, 72.77252769470215, 57.98623303004673, 65.88423647199357, 73.36090809958321, 65.30345739637102, 65.74246542794364, 68.2536347252982, 36.95865992137364, 1.7581381904227393, 0.640620653118406, 5.384520394461496, 23.935124976294382, 57.48077590124947, 69.30325044904436, 68.8358381816319, 64.46126624516079, 63.144193513052805, 58.06393126079014, 62.4130345753261, 56.23169476645333, 49.94761194501604, 47.14398602076939, 47.47263581412179, 53.69971561431885, 52.59735264096941, 53.735995633261545, 52.809043407440186, 47.83730854306902, 45.882721219744, 48.57015936715262, 45.216871874673025, 41.04584741592407, 43.265963622501914, 42.206578731536865, 45.413644858769004, 44.96503789084298, 43.735053879874094, 45.627691064562114, 46.353357451302664, 46.01244756153652, 43.799220493861604, 43.98421975544521, 47.93564292362758, 46.244496549878804, 42.181443623134065, 42.04088503973824, 43.714817251477925, 42.51338686261858, 42.66909599304199, 41.17673758098057, 44.772635323660715, 45.89431081499372, 43.383273533412385, 43.93023920059204, 42.53958504540579, 47.538337979997905, 52.86818994794573, 54.40399544579642, 54.92315442221505, 54.51355116707938, 54.109916414533345, 56.315146105630056, 45.76934746333531, 55.730420453207834, 59.22129617418562, 55.68124457768032, 54.292522021702354, 54.57114825929914, 54.61691951751709, 52.020596572331016, 52.995870045253206, 45.76008551461356, 44.58108391080584, 42.82730300085885, 43.3715797151838, 41.88186856678554, 41.25660712378365, 40.28200762612479, 41.57101658412388, 42.535489082336426, 44.23065846306937, 44.352064337049214, 42.51356404168265, 40.11294405800955, 38.91958747591291, 41.59494618007115, 42.976553780691965, 41.64714799608503, 41.048894201006206, 41.31600032533918, 44.25797530582973, 44.25632163456508, 43.77898039136614, 39.6723518371582, 40.41252953665597, 38.79504449026925, 38.74822057996477, 41.75145435333252, 42.44930362701416, 43.7201360974993, 41.99528748648507, 42.524830545697895, 44.7685741015843, 42.78580835887364, 45.483929361615864, 43.525124481746126, 43.98902096067156, 42.411217076437815, 43.134559290749685, 45.349523408072336, 53.62998349325997, 56.7867168698992, 56.845477785382954, 52.96412372589111, 55.51655142647879, 56.61296326773507, 61.19493893214634, 56.18270301818848, 55.26783718381609, 7.463820065770831, 1.3295661360025406, 4.978980098451887, 30.181689262390137, 63.51767308371407, 57.83603382110596, 59.77763148716518, 55.312618323734824, 64.92829636165074, 61.58072376251221, 56.116014208112446, 47.572415419987266, 28.220527206148418, 37.95183890206473, 34.64358268465315, 48.69188485826765, 58.298082079206196, 4.602820260184152, 0.8163700710449899, 0.21237468905746937, 0.1521855659250702, 0.15602272216762814, 0.12184869950371129, 0.08949925750494003, 0.13989486758198055, 0.12962574219065054, 0.1248428031269993, 0.16458917249526295, 0.19940035311239107, 0.1673366693513734, 0.15528754304562295, 0.17104191838630609], [0.026149195951542685, 0.03889216163328715, 0.09076851154012339, 0.026046094251796603, 0.02716419443355075, 0.01562090071716479, 0.03415283540795956, 0.031193879898637533, 0.06371166982821055, 0.024580643512308598, 0.05800613348505326, 0.037149405506040366, 0.02255485176907054, 0.07830667987998043, 0.014672385096283895, 0.04015615702207599, 0.04096956783905625, 0.05590696666123612, 0.10111074907971279, 2.7279585216726576, 45.81288487570626, 39.44669171742031, 39.17216144289289, 30.235791410718644, 24.682660818099976, 53.286089352199006, 64.36281027112688, 50.5278560093471, 56.59408848626273, 59.91536562783377, 53.841392857687815, 59.35835633959089, 35.86825827189854, 1.869337486369269, 0.1623049114963838, 4.025768893105643, 24.873317650386266, 56.636455127171104, 65.98040648869106, 62.723132678440635, 59.58402688162667, 52.132726601191926, 52.14072050367083, 50.11359051295689, 48.05754559380667, 46.63307108197893, 44.056908335004536, 44.74080562591553, 49.758652210235596, 50.78667640686035, 50.853632722582134, 50.877857616969514, 52.49084717886788, 50.251449721200125, 49.66819708687918, 46.493933405194966, 39.586121218545095, 38.54782063620431, 39.92562757219587, 39.98973165239607, 39.755052770887104, 42.626951694488525, 39.68161725997925, 41.191346168518066, 41.8133419581822, 42.24579783848354, 39.19957556043352, 39.09794773374285, 38.68093422480992, 37.68898160117013, 37.70542451313564, 38.76624073301043, 38.31953409739903, 37.24740273611886, 38.35331971304757, 38.03404998779297, 37.699390002659385, 36.821061270577566, 41.170310497283936, 37.39289106641497, 41.608707087380544, 43.41613156454903, 50.26238965988159, 51.60579259055001, 54.42194264275687, 51.14839962550572, 50.29103013447353, 39.80156053815569, 48.32775061471121, 53.15238516671317, 50.4267840385437, 50.57233142852783, 48.563211168561665, 48.797612122126985, 47.88153730119978, 46.40099082674299, 42.18180840356009, 40.65112372807094, 38.67735242843628, 38.00259896687099, 36.32076665333339, 36.212805543627056, 36.200972761426655, 38.0456326348441, 36.94962726320539, 37.62591280255999, 38.10741949081421, 37.363604409354075, 37.54321186883109, 37.095320565359934, 35.43983582087925, 37.33204916545323, 36.61294535228184, 37.56580741064889, 38.22149501528059, 43.16708728245327, 43.65366962977818, 43.2459944997515, 41.51724100112915, 40.19708326884678, 38.30917433329991, 41.046955653599326, 40.729766913822715, 42.19864388874599, 38.602391787937705, 39.1875239099775, 39.109846523829866, 37.4452874319894, 39.97037397112165, 39.79215267726353, 40.0760178565979, 40.075395992824006, 39.37589999607631, 42.052773407527376, 44.931241852896555, 49.08487149647304, 51.503376143319265, 53.692089966365266, 53.71678386415754, 49.57605702536446, 50.47897890635899, 51.76765782492501, 52.50416340146746, 48.80449431283133, 16.149317571095057, 0.22962783968874387, 4.358585000038147, 30.579404149736675, 49.77551548821585, 46.77269165856497, 44.817749977111816, 41.02604157584054, 49.828856808798655, 53.54752574648176, 53.61792836870466, 36.01538290296282, 22.35142728260585, 23.564851999282837, 23.610260214124406, 46.19744682312012, 25.611317089625768, 0.09798674671245472, 0.03399060447035091, 0.04203301202505827, 0.0160014587787113, 0.041130814900887866, 0.07466777799917118, 0.020630599398698126, 0.0827666837722063, 0.0485059341548809, 0.02441310982352921, 0.04410021984949708, 0.047544015771044154, 0.08187010831066541, 0.0036987783553610954, 0.06901090618755136, 0.04049920736412917, 0.031627243251672814, 0.038675892166793346, 0.036798453623695035, 0.030128081196120808, 0.02586310523162995, 0.0637306213112814, 0.0295641032446708, 0.006650035884896559, 0.058374489790626934, 0.013546614076143928, 0.035693187931818623, 0.07579713168420962, 0.041384257908378325, 0.027556599716522863, 0.08058006396251065, 0.012976508953475525, 0.021016921615228057, 0.08714164687054497, 3.7424413306372504, 52.40168442044939, 45.28134420939854, 40.038299560546875, 37.20795781271798, 26.94133084160941, 62.12703282492501, 68.48573929922921, 54.21627943856375, 60.8255101612636, 65.21617412567139, 58.570041520254954, 63.34256458282471, 40.26176404953003, 2.059024827820914, 0.3081521461052554, 5.180306323937007, 27.9252496106284, 59.21466759272984, 67.7395236151559, 65.84096309116909, 61.516063826424734, 53.935752868652344, 53.05861922672817, 52.19125822612217, 51.538655621664866, 48.07987362997872, 46.156560148511616, 49.07166644505092, 50.32625750132969, 53.19597816467285, 52.602261543273926, 53.765313557216096, 52.0534268106733, 52.71220983777727, 50.650787012917654, 46.60120664324079, 42.66317960194179, 39.39867271695818, 41.20475966589791, 41.16287592479161, 39.99497406823294, 44.5276209967477, 42.16467067173549, 44.88078056062971, 44.82534088407244, 44.375062874385286, 41.07117359978812, 40.00662619726998, 42.434917381831575, 39.64779690333775, 40.851193632398335, 40.89005143301827, 41.099925245557515, 38.539382049015586, 40.31240599496024, 39.53362757819039, 40.28693389892578, 38.64708954947335, 42.293445110321045, 40.689515999385286, 44.01197780881609, 46.812987736293245, 52.80302626746041, 54.75872530255999, 56.45440884998867, 55.17520727430071, 54.3294586454119, 39.56780924115862, 51.69077600751604, 56.37981298991612, 54.64533417565482, 53.006066526685444, 50.15869474411011, 51.292665072849815, 51.09976570946829, 49.397995540073936, 45.569277559007915, 42.85314335141863, 40.85647773742676, 42.28373152869088, 38.02368327549526, 40.28391490663801, 38.76215519223894, 40.27290201187134, 39.215254170554026, 40.65211732046944, 41.396043573107036, 41.1119247845241, 38.41441869735718, 38.36276578903198, 37.75362416676113, 39.36715221405029, 39.163750648498535, 39.74811846869332, 39.358390535627095, 43.61419691358294, 46.45359563827515, 45.28225442341396, 43.43216453279768, 40.85473721367972, 41.266643796648296, 43.30675649642944, 42.52265228543963, 42.59389911379133, 40.61719567435128, 41.13617747170584, 40.9195465360369, 39.13617672239031, 41.142680985586985, 41.09202514375959, 43.13996498925345, 42.47003705160958, 42.1277687890189, 43.60310411453247, 47.93658440453665, 50.9628757749285, 55.06266035352434, 55.01606225967407, 56.921428544180735, 53.40454224177769, 54.31916836329869, 54.16167007173811, 55.645610741206575, 56.225938183920725, 20.67043570109776, 0.13445749506354332, 4.693175503185817, 35.11948912484305, 54.83838292530605, 50.972005707877024, 48.107961722782676, 41.85180718558175, 55.59133836201259, 57.42744500296456, 58.90147059304373, 38.5346086365836, 25.62715377126421, 29.057868514742168, 24.201317412512644, 54.34374761581421, 23.49842200960432, 0.023001003810869794, 0.048991385248622725, 0.03671264269256166, 0.011916057106905749, 0.02064101491123438, 0.05153370668579425, 0.02203630343345659, 0.027684993809089065, 0.007200893513592226, 0.03204009788376944, 0.029589388852140734, 0.020295915393424884, 0.06282155402004719, 0.058888181511844905, 0.01836540693018053, 0.13506629025297506, 0.2604251056909561, 0.08098322911454098, 0.12976157133068356, 0.13765127797211918, 0.08572371224207537, 0.1304921635559627, 0.07777041329869203, 0.11741539596446923, 0.1230211401624339, 0.08362595337842192, 0.1944136092705386, 0.11768731208784239, 0.14179354427116259, 0.16825642356915133, 0.21038932273430483, 0.07171049168599503, 0.25854654077972683, 0.3375651463866234, 7.5117826121194025, 73.9975437436785, 52.43484122412545, 53.58347920009068, 44.415195669446675, 36.34134374346052, 64.92412049429757, 75.78038896833147, 61.07596492767334, 67.84323242732457, 69.57363264901298, 64.13219955989292, 67.84535162789481, 43.09768867492676, 2.707863679953984, 0.527978954570634, 6.15400516135352, 31.973237105778285, 65.64114679609025, 73.46594401768276, 67.13676043919155, 65.17823001316616, 56.44925676073347, 59.14368479592459, 53.31458738871983, 56.38586834498814, 51.870925426483154, 49.19527837208339, 51.54911266054426, 53.50242151532854, 56.845349243709016, 53.505923407418386, 54.98657063075474, 55.51077399935041, 54.08148091179984, 53.42016526630947, 48.89929553440639, 44.49505131585257, 41.950690473829, 43.81684807368687, 43.04708841868809, 42.07290233884539, 48.1539865902492, 43.81585100718907, 48.54892914635794, 45.66395371300833, 47.7115044593811, 44.19635173252651, 43.95236226490566, 45.09031738553728, 43.968648842402864, 43.60638019016811, 44.74936580657959, 41.83489874431065, 41.320040702819824, 43.66578033992222, 42.48189762660435, 42.05139766420637, 41.63028471810477, 44.73846755708967, 42.5474191393171, 47.207360540117534, 48.65070983341762, 57.558015550885884, 56.16434587751116, 58.42367771693638, 57.62036173684256, 57.28686557497297, 47.748454979487825, 53.69815574373518, 56.7675815309797, 56.92473588671003, 54.6697154045105, 54.05420575823103, 54.754743984767366, 54.22589227131435, 51.792212758745464, 48.09913751057216, 46.083711760384695, 42.96424157278878, 43.52553442546299, 39.10428449085781, 39.64477791104998, 40.366112095969065, 42.222288608551025, 40.248176847185405, 43.097212723323274, 43.17988933835711, 41.8095760345459, 41.4656297819955, 41.09587444577898, 39.535315990448, 40.5916610445295, 39.847456863948274, 42.13400132315499, 41.37503569466727, 47.76111112322126, 49.513057708740234, 48.927536487579346, 46.244333267211914, 44.81031540461949, 45.502578326633994, 45.913237707955496, 45.84108761378697, 47.35428714752197, 41.98018905094692, 42.45836060387747, 43.5893223626273, 42.310784339904785, 43.52526691981724, 42.74662399291992, 46.35506323405674, 44.8068447794233, 43.92203337805611, 47.26095199584961, 51.63858808789934, 52.98062917164394, 57.71516295841762, 55.7535787991115, 58.36608409881592, 58.33974347795759, 55.25714043208531, 58.22385099955967, 57.53627116339547, 58.85759966714041, 22.02186553818839, 0.2715799499835287, 6.400707900524139, 39.421174458095, 61.452376638139995, 56.13337080819266, 53.24383735656738, 48.15139143807547, 59.68947969164167, 63.83247511727469, 62.84026541028704, 44.57537596566336, 35.507427896772114, 33.401018960135325, 37.88902023860386, 58.091751847948345, 40.95769909449986, 0.20816550563488687, 0.144330695271492, 0.13611233340842382, 0.08426232423101153, 0.1116597769515855, 0.16031148417719773, 0.08385898944522653, 0.20260827669075557, 0.2067991260971342, 0.11094761373741285, 0.13635640245463165, 0.22859681929860795, 0.1803536308663232, 0.1312498293284859, 0.16820424422621727], [0.02413176715240947, 0.037954819787825854, 0.02198941327099289, 0.04664969304576516, 0.02585654379799962, 0.0737468431304608, 0.0961101156260286, 0.023517246823757887, 0.08861470568392958, 0.040845782695604224, 0.01935099600814283, 0.0645116897565978, 0.04815999664632337, 0.04785404859908989, 0.025329413690737317, 0.054221896188599725, 0.14420123078993388, 0.04243665215160165, 0.21328579873910972, 0.22437167673238687, 19.22803657395499, 51.391906193324495, 57.84181819643293, 45.551347732543945, 17.39054376738412, 42.14916924067906, 67.76384231022426, 59.5765506199428, 60.51895563943045, 56.61817441667829, 60.20605741228376, 56.56324543271746, 43.452647822243826, 5.691583003316607, 0.8293731361627579, 5.374556677682059, 29.99293449946812, 63.05177552359444, 65.87322357722691, 66.2782062802996, 63.491659028189524, 59.873600006103516, 53.15507064546858, 49.63464770998274, 48.02039705004011, 45.997015612465994, 43.38747719355992, 46.1331273487636, 48.21666281563895, 51.676372391836985, 55.99327775410244, 53.651126861572266, 54.63900784083775, 55.21576738357544, 54.29750735419137, 53.008904865809846, 48.43478066580636, 44.387910093579976, 41.90729897362845, 41.54535688672747, 41.00042356763567, 43.2886494909014, 40.32767118726458, 41.58554179327828, 42.79411493028913, 42.02074916022164, 39.590554169246126, 40.14403029850551, 38.70213317871094, 38.57003402709961, 39.905418736594065, 39.34924670628139, 38.857348987034385, 38.99246365683419, 37.642991474696565, 38.77575976508004, 38.04150193078177, 40.101840836661204, 37.073402472904746, 37.87858404432024, 40.489647592817036, 43.02069221224104, 51.09208447592599, 52.24633312225342, 51.30131210599627, 53.99406215122768, 52.83937576838902, 56.39210435322353, 52.041976179395405, 51.74940490722656, 51.762269496917725, 48.37899705341884, 49.884876659938264, 48.372642925807405, 47.79318748201643, 48.21779537200928, 44.296815735953196, 42.8936687197004, 38.92120293208531, 39.220423630305696, 35.65944405964443, 36.76103925704956, 38.31830079214913, 38.60666145597185, 35.766432421548025, 36.56476306915283, 36.179989201681956, 38.43673978533064, 39.13302571432931, 36.22641706466675, 35.52752556119646, 36.66579335076468, 37.77467026029314, 38.1228722844805, 39.40437718800136, 43.76353801999773, 46.187851360866, 46.48403569630214, 45.368610109601704, 45.227606841496055, 45.608642578125, 45.53431074959891, 44.315329211098806, 44.88051305498396, 41.34947674615042, 40.17988300323486, 38.5578156198774, 36.85854680197579, 35.64934485299246, 38.55809702192034, 39.14132186344692, 40.09955140522548, 40.112044266292024, 43.030558654240195, 44.708510398864746, 49.25788164138794, 51.58104658126831, 53.57710770198277, 58.57690634046282, 52.862398624420166, 50.25364187785557, 51.72523559842791, 54.20622192110334, 49.96789721080235, 33.812480858394075, 0.6743265816143581, 3.562565496989659, 33.10471303122384, 49.039082867758616, 52.67621469497681, 48.22614015851702, 54.776926108769004, 57.072934014456614, 55.46492978504726, 59.56319618225098, 31.51998179299491, 22.217973232269287, 33.45631272452218, 32.74939605167934, 51.52895246233259, 5.0023117150579175, 0.2916086752499853, 0.06415400680686746, 0.07335152862859623, 0.1196859912680728, 0.05089847916471107, 0.019668367192415253, 0.056877024072621546, 0.06285229165639196, 0.017408938878881078, 0.014821764580639345, 0.042925573951963863, 0.06578479787068707, 0.018533262923093777, 0.0643859300762415, 0.07203451251345021, 0.06117007442350898, 0.045398294659597535, 0.03939929870622499, 0.08152068313211203, 0.04260604841900723, 0.01761346629687718, 0.0513721271418035, 0.0353257103290941, 0.028297000165496553, 0.03592881939506956, 0.06596734414675406, 0.031492608333272595, 0.02205273076625807, 0.06186393754822867, 0.018757566244208386, 0.0371539075858891, 0.15359667449125222, 0.04519485968298145, 0.2213506216981581, 0.3035263828933239, 23.878545795168193, 61.431351389203755, 50.91052457264492, 50.805287156786235, 24.0478994505746, 47.90881592886788, 75.69280692509243, 65.30915491921562, 67.91338144029889, 63.05463818141392, 64.62041473388672, 62.22820554460798, 47.31068025316511, 7.124330648354121, 0.9112557023763657, 6.684324247496469, 33.02779647282192, 65.47979572841099, 67.21977056775773, 67.8664949962071, 64.72693061828613, 60.82610075814383, 54.92072950090681, 51.364509446280344, 49.66890927723476, 48.438612597329275, 46.62393420083182, 47.89172683443342, 50.77621241978237, 53.13595267704555, 56.82412249701363, 54.227146421160015, 55.93020895549229, 56.70548548017229, 55.34305838176182, 55.80203553608486, 50.16236686706543, 45.39916481290545, 43.776069096156526, 43.96809646061489, 43.40461145128523, 44.72665561948504, 41.63729197638375, 43.937736306871685, 44.724397454942974, 44.74561725343977, 43.16861936024257, 40.941530636378694, 40.92919410978045, 40.02782167707171, 41.645932061331614, 42.01050056729998, 42.37810891015189, 41.19145733969552, 38.950458322252544, 41.712818895067485, 41.0691898890904, 41.085792609623496, 39.97413294655936, 41.39632150105068, 43.12077406474522, 45.25569493430001, 54.18508202689034, 53.01472050803048, 54.18018702098301, 56.62987865720476, 55.59577131271362, 50.704864842551096, 54.10682446616036, 56.24923201969692, 53.795058795383994, 51.47626774651663, 50.465332644326345, 50.1088935307094, 50.345879214150564, 50.28440155301775, 46.722716740199495, 43.43733399254935, 42.380294118608745, 40.62877137320382, 38.84207337243216, 40.47877366202218, 39.663274015699116, 39.4755927494594, 39.12045642307827, 39.62058080945696, 38.995503493717735, 39.85694462912423, 40.69610289164952, 38.6697267804827, 37.9935975755964, 38.19853469303676, 39.99888590403965, 40.335755416325156, 41.21525491986956, 44.78877946308681, 45.7980991091047, 46.63129581723894, 48.21128143583025, 46.97618702479771, 47.417564392089844, 46.44688367843628, 46.51416655949184, 47.34474032265799, 43.92865153721401, 41.349667821611675, 40.39401953560965, 38.6027843611581, 39.088022232055664, 41.714319705963135, 42.419961384364534, 42.92175333840506, 41.8730582509722, 44.858959742954795, 47.740902287619456, 52.118371622903005, 54.207423959459575, 55.89108712332589, 59.11651039123535, 55.60267782211304, 54.107960496629985, 54.31580890927996, 59.21805831364223, 53.71246555873326, 39.52829483577183, 1.571351939014026, 3.794934102467128, 38.41856329781668, 54.58052485329764, 55.75829662595476, 54.435849462236675, 56.96266262871878, 60.322509220668245, 60.26617322649275, 64.80939183916364, 29.715708323887416, 26.277894258499146, 33.86642319815499, 35.19314002990723, 56.980991976601736, 3.7570108345576694, 0.33531124304447857, 0.12870898709765502, 0.07060460174190146, 0.041184015439024994, 0.03125704133084842, 0.01560860566262688, 0.03648787796763437, 0.029159184079617262, 0.0017460339814923437, 0.010945550166070461, 0.09092692911092724, 0.007249753123947552, 0.014203354549993361, 0.034250534272619655, 0.1003665386566094, 0.12809940480760165, 0.19619785781417573, 0.11863180569240026, 0.15021894073912076, 0.09620589762926102, 0.1308891743953739, 0.20426303361143383, 0.17097638547420502, 0.09738038746373993, 0.13903413234012468, 0.14196283875831536, 0.11350937520286866, 0.07926756010523864, 0.15356125496327877, 0.09709994215518236, 0.23116803275687353, 0.2291449127452714, 0.1293826773762703, 0.2812915774328368, 0.30075877425926073, 42.67300435474941, 69.35696697235107, 72.44932528904506, 60.835904666355674, 30.624876635415212, 51.76706722804478, 80.79215240478516, 69.83180686405727, 73.138336454119, 67.2144135066441, 70.07958657400948, 67.01946789877755, 52.406833035605295, 7.362325123378208, 1.0789445042610168, 9.169832110404968, 36.3883170400347, 70.66705676487514, 71.73995590209961, 74.23415075029645, 68.94964967455182, 65.7623928615025, 58.25263391222273, 55.929569721221924, 51.61826113292149, 52.084825720105854, 49.56645114081246, 51.61404357637678, 53.91823993410383, 57.36221531459263, 59.95298317500523, 59.22393648965018, 59.53745310647147, 59.0325414112636, 57.923970222473145, 59.04518018450056, 52.155356884002686, 48.63290160042899, 45.9918600491115, 45.50551046643938, 46.40214422770909, 48.05516583578927, 45.537944657461985, 46.95268474306379, 48.508810247693745, 46.47267539160592, 46.08454207011631, 44.469749450683594, 44.428640433720176, 42.15967839104788, 45.256841387067524, 46.17000491278512, 46.91348648071289, 44.081438950129915, 41.94410705566406, 44.54144443784441, 45.24077367782593, 45.848014967782156, 42.04611703327724, 41.252966267721995, 47.14559800284249, 48.05516236168997, 55.69465460096087, 55.72925315584455, 54.55302388327462, 59.134221349443706, 58.40812070029122, 58.46570042201451, 61.04601124354771, 56.77755914415632, 57.38881649289812, 52.52425411769322, 55.58467156546456, 53.79931456702096, 53.56489971705845, 52.20250735964094, 48.477004868643625, 45.175693375723704, 44.567781584603445, 42.77882194519043, 41.58296748570034, 42.37955066135952, 41.85451003483364, 42.47075966426304, 41.09731272288731, 41.99193498066494, 40.80851084845406, 40.64852510179792, 44.19608770098005, 39.74318872179304, 39.52726650238037, 40.166490350450786, 42.4552651814052, 42.48885972159249, 43.49039738518851, 46.89638001578194, 49.348371505737305, 49.0576171875, 50.92482743944441, 48.07088960920061, 50.809848649161204, 49.49457550048828, 47.55345031193325, 48.90955454962594, 46.066803319113596, 43.2912654876709, 42.31491504396711, 40.15026978084019, 39.5947265625, 43.024899346487864, 44.07402869633266, 45.58719348907471, 43.1600661277771, 48.971216338021414, 49.621244634900776, 54.55343730109078, 56.521281787327354, 58.09303726468767, 61.614756039210725, 56.33543831961495, 57.2308144569397, 57.08634403773716, 61.40726893288748, 55.6752587045942, 43.980888094220845, 1.8203861245087214, 4.6580076302800855, 44.11451932362148, 59.34794793810163, 60.789240564618794, 57.13056584766933, 63.07719898223877, 66.0294051851545, 64.22991902487618, 71.75679833548409, 41.74666357040405, 34.49324451174055, 46.95587049211775, 43.82311187471662, 65.80319963182721, 13.522888949939183, 0.9007847670997892, 0.14341711572238378, 0.3012392856180668, 0.17523358203470707, 0.18556864745914936, 0.19484116775648935, 0.09726874809712172, 0.10223705614251749, 0.11835147573479585, 0.07396405576063053, 0.2097064179501363, 0.1932587833809001, 0.13830500575048582, 0.1280140858143568, 0.18543944082089833], [0.0244382919544088, 0.04981450250904475, 0.025425938689815145, 0.06653683858790568, 0.052426692697086504, 0.024615689846021787, 0.024134048726409674, 0.03352312437657799, 0.017343178657548766, 0.04866083352161305, 0.06791391183755227, 0.04530407328690801, 0.02531702533763434, 0.02605424345737057, 0.07912572593029056, 0.06014534405299595, 0.11509126424789429, 0.03340188373944589, 0.15892070452017443, 0.11698197493595736, 5.633389234542847, 50.6960197857448, 37.11846848896572, 35.399355615888325, 18.168523141316005, 32.13579716001238, 63.209423201424734, 59.098729951041086, 60.044873101370676, 60.09500435420445, 51.82260765348162, 60.59021636417934, 46.384454114096506, 13.286274995122637, 1.022993917976107, 3.100169828959874, 24.28376647404262, 59.67037909371512, 63.84056976863316, 67.34356662205288, 64.19163445064, 61.586997985839844, 59.43420287540981, 57.05765839985439, 49.30576862607683, 46.10317019053868, 44.933437483651296, 43.59292152949742, 48.08200325284685, 52.83196551459176, 55.92456007003784, 58.259175641196116, 57.16930552891323, 57.10536125728062, 58.1589617729187, 55.23210259846279, 50.28350176130022, 48.100141525268555, 43.89400087084089, 41.169487135750906, 42.10001768384661, 38.87922886439732, 41.31411041532244, 42.66475336892264, 41.77482114519392, 39.79411901746477, 40.476508549281526, 39.211015769413535, 38.84491865975516, 38.394908155713765, 39.07489708491734, 39.77266992841448, 38.41956731251308, 38.24226318086897, 37.76651654924665, 37.127230167388916, 37.22385876519339, 38.14241409301758, 38.339742933000835, 39.330364976610454, 42.655696392059326, 46.41501923969814, 49.21108552387783, 51.61392545700073, 52.09245484215872, 53.511204038347515, 51.93700279508318, 53.867872442517964, 54.41583865029471, 53.012000288282124, 50.96888944080898, 49.6781017439706, 47.159313746861045, 49.12396206174578, 47.13615540095738, 45.669213499341694, 45.505333287375315, 41.97144474302019, 39.12394789287022, 39.43305240358625, 38.03400135040283, 36.57434116091047, 37.453858034951345, 37.43155084337507, 35.222207818712505, 37.864892618996755, 38.68602378027779, 37.04109682355608, 39.6339248248509, 37.111655780247276, 36.81413739068167, 36.983114106314524, 38.53282642364502, 39.04366493225098, 39.4775903565543, 44.090416022709434, 47.74671792984009, 48.47224882670811, 47.70874949863979, 49.845893791743684, 48.32224416732788, 50.797293254307334, 50.74435492924282, 47.180238246917725, 44.50820425578526, 42.112458433423726, 40.118561676570344, 38.349897725241526, 37.89765337535313, 40.00512886047363, 41.057683672223774, 39.90804862976074, 42.49536323547363, 40.07555232729231, 44.8711017199925, 46.97203895023891, 52.21127598626273, 52.283349650246755, 53.584580489567344, 57.64019536972046, 54.21488285064697, 48.87705782481602, 60.85546384538923, 51.31710883549282, 43.90613242558071, 5.896754188197, 1.5211640149354935, 31.78502777644566, 49.35749101638794, 38.90539925439017, 46.99875824792044, 59.006409236363, 53.37128816332136, 58.05783421652657, 43.06550461905343, 19.009922197886876, 33.40873493467058, 39.71237693514143, 37.951595715114046, 36.450604166303364, 0.2103752770594188, 0.09000442004097359, 0.014641645763601576, 0.020138919353485107, 0.05246407997661403, 0.018601660949311087, 0.020417634397745132, 0.013323035939330501, 0.04344032418781093, 0.032305432217461724, 0.11239590602261679, 0.06852434908172914, 0.03779994077714426, 0.04322706063144973, 0.021088386619729654, 0.033367627899029424, 0.06644978933036327, 0.03978624347863453, 0.03605953577373709, 0.03708846288334046, 0.004210785189310887, 0.05717361851462296, 0.05783995347363608, 0.023087310072566782, 0.01775618426368705, 0.06065768548952682, 0.0862266831099987, 0.016613122474934374, 0.04584367486781307, 0.0332746652087995, 0.06176596387688603, 0.009259000487093414, 0.09445373700665576, 0.08101109654775687, 0.09807235069040741, 0.14648371402706417, 7.547463348933628, 61.66860457829067, 42.010788917541504, 36.259480067661826, 26.043543679373606, 35.44667632239205, 72.5754976272583, 65.34384727478027, 66.53724902016776, 65.11361871446881, 58.119377885546, 64.72439452580043, 51.91286127907889, 15.046966757093157, 1.5903855519635337, 3.9344977906772067, 26.08803299495152, 61.443656648908345, 65.9540867124285, 67.90960856846401, 65.40770816802979, 62.51813302721296, 61.94794995444161, 57.80330433164324, 51.14729833602905, 46.72641665594918, 48.40685932976859, 47.657131331307546, 49.74467243467058, 54.14719697407314, 58.68809141431536, 59.33711569649832, 59.19726930345808, 60.38085324423653, 60.74448026929583, 58.343898500714985, 52.74239976065499, 50.791137150355745, 44.6651223727635, 42.90164177758353, 43.346743379320415, 42.544664178575786, 42.9556223324367, 44.23490033830915, 44.620073727199006, 43.167299202510286, 43.874882902417866, 40.04457030977522, 41.63861213411604, 41.4388826915196, 42.22745112010411, 40.65718255724226, 41.81527008329119, 42.063758509499685, 39.12473998750959, 40.5164989062718, 40.326545579092844, 40.49672433308193, 40.246203558785574, 42.123433113098145, 44.90469626017979, 47.57588604518345, 52.063831738063264, 54.46790845053536, 56.349831512996126, 55.65253462110247, 56.04961027417864, 52.87341846738543, 54.96922445297241, 56.06402431215559, 53.32338728223528, 54.34224680491856, 50.177694593157085, 52.23795706885201, 49.239389010838096, 49.794022015162874, 47.869777475084575, 45.269275188446045, 41.16812181472778, 43.27109486716134, 39.95497676304409, 40.43013974598476, 40.34579903738839, 39.66174193790981, 38.70966155188424, 38.98541818346296, 40.304721287318635, 40.09939507075718, 43.473492418016704, 38.775850091661724, 39.482756342206685, 39.56532526016235, 41.101690087999614, 40.454882281167166, 41.137990951538086, 43.849310057503835, 48.45497213091169, 50.61002887998308, 50.60025971276419, 50.02079732077462, 50.7062475340707, 52.408966132572715, 52.92942789622715, 48.495740686144146, 46.22041409356253, 43.08692938940865, 42.2409862109593, 40.53151396342686, 40.91192088808332, 42.31622477940151, 42.424241474696565, 41.79808023997715, 43.41412353515625, 42.20779814038958, 47.8231828553336, 49.504070213862825, 54.145039558410645, 54.42556612832205, 56.29303346361433, 59.36986950465611, 60.331778117588584, 51.95103120803833, 61.080015727451865, 54.010366099221365, 48.73960856028965, 7.788651823997498, 1.5368552186659403, 36.611680780138286, 55.44209105627877, 44.20129190172468, 50.913265636989046, 62.22832366398403, 56.250180448804585, 61.71858297075544, 49.679595606667654, 21.921243463243755, 39.87220287322998, 41.03841284343174, 44.27423061643328, 37.48052174704415, 0.25713155099323814, 0.13072017846362932, 0.023378447396680713, 0.06025234902543681, 0.037990459839680364, 0.041977494289832454, 0.04526329333228724, 0.02841629001445004, 0.08428109250962734, 0.03192049590870738, 0.0362535119721932, 0.021566662205649272, 0.055546257445322614, 0.025618327116327624, 0.014878646171252643, 0.03247566647561533, 0.06879000911223036, 0.1561770210308688, 0.11494358788643565, 0.0926732679030725, 0.07433117713247027, 0.11895320058933326, 0.14941142978412764, 0.10955943965486117, 0.07119265411581312, 0.15832257590123586, 0.2028599860412734, 0.1037761296278664, 0.15467492091868604, 0.1724641684974943, 0.14909057771520956, 0.14707623794674873, 0.31756649379219326, 0.22986700971211704, 0.37999605813196724, 0.45355595807944027, 14.531632763998848, 76.630966595241, 53.43897403989519, 49.86728729520525, 30.576708248683385, 43.53775978088379, 74.62759944370815, 71.91287572043282, 70.29881613595145, 71.14279297419957, 63.91750717163086, 70.56999737875802, 53.48647887366158, 16.53760027885437, 2.114296010562352, 5.597139613968985, 29.253121580396378, 65.42358480181012, 69.39502225603376, 72.66815185546875, 69.08251312800816, 65.79770360674176, 65.89210183279855, 61.03927843911307, 54.954563753945486, 48.45764718736921, 49.822784083230154, 49.21282952172415, 52.04047189440046, 56.515716280256, 60.52211706978934, 64.40431880950928, 61.515799794878276, 63.15690871647426, 63.044438225882395, 59.39006791796003, 54.889427866254536, 53.79539230891636, 48.851627417973106, 44.69437428883144, 45.26128476006644, 45.12972409384591, 45.56771421432495, 47.913262775966096, 47.557143279484336, 43.53600536073957, 46.91685288293021, 43.91388661520821, 44.692824840545654, 44.594459193093435, 46.06932898930141, 43.23870931352888, 44.586083139692036, 44.63741990498134, 40.297123432159424, 41.58741085869925, 42.770386832101, 43.22771726335798, 44.31285217830113, 44.2244849886213, 48.6916903087071, 51.1393461227417, 55.07900946480887, 56.91594294139317, 58.22663722719465, 56.70072943823678, 57.64636189596993, 56.4565315246582, 58.0242257799421, 57.92639514378139, 55.75075783048357, 55.13643980026245, 52.384289605276926, 54.32765906197684, 52.33210168566023, 50.290630613054546, 50.591998304639546, 47.78145892279488, 44.05551174708775, 45.36558416911534, 41.651841504233225, 41.87282548631941, 43.20849159785679, 40.617880071912495, 41.07851089750017, 40.90435777391706, 43.806828771318706, 42.104311670575825, 45.66995695659092, 41.056422574179514, 41.73779419490269, 39.613837582724436, 43.41727801731655, 42.88922187260219, 42.992486000061035, 45.468657221112935, 51.52401576723371, 51.989941120147705, 51.7710520199367, 54.2320796421596, 54.7864659854344, 54.04406486238752, 56.17008508954729, 51.45852204731533, 49.01948199953352, 46.5660765511649, 44.9153721673148, 41.80390283039638, 42.021860871996196, 42.12412793295724, 44.71493053436279, 43.89735337666103, 45.844978604997905, 44.190292903355186, 50.11059583936419, 52.024345125470845, 57.26179647445679, 57.57590021405901, 59.01851299830845, 62.66271809169224, 62.11713859013149, 57.075650760105674, 64.1543504170009, 57.62497534070696, 53.84886564527239, 9.60827820641654, 2.0373399342809404, 40.39509303229195, 59.002823965890066, 47.8547728402274, 56.332099710192, 69.60825552259172, 60.64417607443673, 67.90040915352958, 54.304073401859824, 30.029085976736887, 48.462330273219514, 53.57549224581037, 46.40340532575335, 56.435610498700825, 0.724742764873164, 0.2673104719391891, 0.0711430124938488, 0.11794887376683098, 0.13449713507933275, 0.11784984836620943, 0.1109006048313209, 0.13567541113921575, 0.1732621392501252, 0.09446764697453805, 0.2259425124419587, 0.07190550943570477, 0.14644125130559715, 0.1661463560802596, 0.10402682796120644, 0.14328575134277344], [0.07213264903319733, 0.02539283805526793, 0.031265363562852144, 0.046202701316880326, 0.042125587950327566, 0.010564676585740276, 0.029282195693148032, 0.057581329851278236, 0.019918431095512848, 0.020347573960732137, 0.046704342256167104, 0.02367508763979588, 0.059976348121251376, 0.05169763056827443, 0.004518929145498467, 0.06166822090744972, 0.073259173227208, 0.028109032394630567, 0.0549181748979858, 0.08829502748059374, 0.1774023428027119, 26.045873062951223, 44.511330945151194, 20.4028970514025, 34.778433322906494, 27.76879702295576, 60.012292998177664, 61.70825794764927, 69.7928135735648, 61.21814591544015, 52.43629339763096, 58.73734719412667, 53.23617001942226, 23.176670040403092, 2.2284412341458455, 1.1531907830919539, 16.377128158296856, 56.28148555755615, 64.98890549795968, 64.03973988124302, 66.533066204616, 62.88262162889753, 61.668771335056846, 60.60370976584298, 58.040154525211875, 50.35946989059448, 45.03028147561209, 44.83606195449829, 48.23068080629621, 51.33281871250698, 57.67633989879063, 57.881343024117605, 55.84462104524885, 56.27334574290684, 55.80760451725551, 53.493291582380024, 52.92140620095389, 49.75843334197998, 47.10656302315848, 41.965771538870676, 40.51679767881121, 39.60941505432129, 39.92420319148472, 39.15787942068917, 38.39587048121861, 38.487527642931255, 38.010884693690706, 37.79920087541853, 39.34412588391985, 38.82145111901419, 38.71385826383318, 39.05987855366298, 39.73325974600655, 36.91057143892561, 39.34121111461094, 38.79813643864223, 39.536993980407715, 40.344458035060335, 40.72390958241054, 41.4763126373291, 41.97299766540527, 48.93752104895455, 52.32503189359392, 51.90703174046108, 50.29628644670759, 51.10854475838797, 53.27015365873064, 53.58378144672939, 54.196532658168245, 53.29000118800572, 50.06102391651699, 50.3023487499782, 47.45236097063337, 47.237203053065706, 47.735413210732595, 45.88521214893886, 46.846568380083355, 43.7275150844029, 39.80042798178536, 40.649984223502024, 38.14146218981062, 37.19693796975272, 35.98504706791469, 37.85759006227766, 36.12825638907296, 36.09573881966727, 37.25061280386788, 37.35750389099121, 38.243975911821636, 38.8543438911438, 37.40354265485491, 37.641824177333284, 38.757089955466135, 37.081514494759695, 38.93189968381609, 42.53123331069946, 46.89440325328282, 49.53787667410714, 51.409151622227256, 51.51775891440255, 48.713747365134104, 47.64057377406529, 47.579165594918386, 48.3907082421439, 47.96047231129238, 48.09790767942156, 47.7058173588344, 46.23428617204939, 43.095378398895264, 43.19337579182216, 42.850833075387136, 40.06607845851353, 40.72330856323242, 39.512296608516145, 40.430820669446675, 42.052627495356965, 45.4124984060015, 49.65703133174351, 54.42776870727539, 52.16888155255999, 57.621403966631206, 52.54591512680054, 56.28286477497646, 54.27580465589251, 46.56959581375122, 7.599321229117257, 0.7313195605363164, 38.04000806808472, 47.62708037240164, 47.59609488078526, 52.68229784284319, 55.397111892700195, 50.38126638957432, 54.08374949863979, 26.18338486126491, 21.938928365707397, 32.86784894125802, 25.419176816940308, 49.34639126913888, 8.452928270612444, 0.26562881789037157, 0.12620781202401432, 0.05633743266974177, 0.033495379079665454, 0.0061786304660407555, 0.03970521961205772, 0.024515953679968203, 0.0453296303083854, 0.07560809182801417, 0.02037663900825594, 0.044894499371626546, 0.029970104673079083, 0.009411860007925757, 0.1686192091022219, 0.04487190754818065, 0.05363731112863336, 0.04570245137438178, 0.008532303900990103, 0.05573296653372901, 0.022875264486564056, 0.03223551257646509, 0.046631796684648306, 0.006420841598550656, 0.04267573057274733, 0.07296519793037858, 0.01723116440033274, 0.031576091889292, 0.021592919814533422, 0.023017660149240067, 0.013460993134815778, 0.02623436227440834, 0.015246086454551135, 0.03706059205744948, 0.04710428775953395, 0.046151027482535155, 0.023530502005347183, 0.23904319160750934, 31.968230928693497, 53.895904949733186, 24.274884939193726, 38.04043885639736, 35.4254287311009, 62.45953886849539, 68.1600980758667, 78.15840298788888, 65.87179224831718, 56.742884159088135, 63.23991189684187, 59.0692070552281, 26.809080566678727, 3.0056793221405576, 2.01249143907002, 18.337287936891826, 57.41740138190133, 66.058851650783, 66.54268945966447, 68.54233932495117, 64.18369960784912, 64.05999388013566, 62.93132850102016, 59.54763221740723, 52.55925219399588, 47.70023100716727, 46.595067909785676, 51.17568867547171, 54.69178635733468, 58.822504316057476, 59.7718505859375, 56.701868942805696, 58.24261808395386, 60.80117756979806, 56.87801619938442, 54.44422204153878, 52.36799955368042, 49.29271643502371, 44.26426689965384, 43.66539818899972, 41.81144162586757, 42.38004398345947, 41.82255179541451, 41.87985011509487, 41.545634814671104, 42.17940085274832, 40.450157506125315, 41.51422895703997, 40.78528649466378, 42.419259616306846, 42.5066088948931, 41.65348822729928, 39.4188676561628, 39.61879859651838, 42.28592368534633, 41.70978600638253, 41.91290616989136, 41.91107184546334, 44.03343732016427, 44.25620004108974, 50.74802705219814, 53.68554476329258, 53.95354373114449, 53.4455783026559, 54.467380387442454, 57.40596464702061, 56.5002634865897, 53.660850865500315, 57.768483434404644, 53.2844808442252, 52.64789383752005, 53.33553620747158, 51.01105458395821, 51.16783373696463, 48.726420879364014, 50.254631996154785, 45.596785477229524, 42.1466018812997, 42.075087547302246, 41.31895678383963, 40.006640093667166, 38.08538327898298, 39.34187814167568, 38.12698909214565, 38.85920763015747, 40.06452553612845, 40.33832624980381, 41.022293022700715, 39.99645403453282, 37.925460066114155, 40.255250113351, 41.86559935978481, 39.063165051596506, 39.74742364883423, 43.89924676077706, 48.511315073285786, 50.22835043498448, 52.400812421526226, 52.11666931424822, 50.58641195297241, 50.142286573137554, 49.97864607402256, 50.22183302470616, 50.56698478971209, 50.66139691216605, 49.34996959141323, 46.898422786167686, 44.98603187288557, 45.38966315133231, 45.57189702987671, 41.567563329424175, 41.80825240271432, 43.084983893803184, 41.59739889417376, 44.15195274353027, 48.15103013174874, 51.38269288199288, 55.74030426570347, 53.47699110848563, 58.564983231680735, 56.65826552254813, 59.07528672899519, 57.17262329374041, 52.569358348846436, 9.29249039718083, 0.7152283468416759, 41.94107069287981, 53.02045972006661, 51.953101771218435, 53.720233644757954, 64.0173944745745, 54.994738238198416, 62.40301527295794, 32.9944555418832, 27.654592956815446, 39.58003459657942, 27.918902431215557, 56.61265754699707, 5.632695717470987, 0.2871519758233002, 0.14682652348918573, 0.05914978390293462, 0.04199223546311259, 0.04042661090248397, 0.03672872057982853, 0.008383596166303115, 0.06809454464486667, 0.05706242698111704, 0.01912474020251206, 0.0268451269117317, 0.0669993959101183, 0.021308325264336805, 0.004674747079012117, 0.0071288517543247765, 0.035904436239174435, 0.09681984968483448, 0.08891932040985141, 0.15652395598590374, 0.10504843707063369, 0.09714119708431618, 0.12566891951220377, 0.07330952052559171, 0.113766852101045, 0.23453926614352635, 0.11141564683722598, 0.15352888884288923, 0.07939303480088711, 0.11948788618402821, 0.13618530306432927, 0.0724357438406774, 0.17329921440354415, 0.2504838891327381, 0.168893961501973, 0.11341946252754756, 0.09842259689633336, 0.5542696895343917, 53.72300597599575, 63.75471087864467, 37.62891789845058, 49.173377650124685, 41.51047692980085, 67.9275210244315, 75.10321753365653, 82.25130884987968, 70.09949316297258, 64.7683766228812, 68.60219110761369, 65.10085487365723, 29.686181953975133, 3.6902191042900085, 3.588347222123827, 19.819574935095652, 61.060567719595774, 68.02982630048479, 69.15559428078788, 71.04545566013881, 67.497649874006, 68.01965413774762, 66.69541781289237, 62.57508741106306, 55.498367990766255, 51.679766586848665, 50.51317793982369, 54.159797532217844, 56.01063435418265, 61.74969005584717, 61.8522732598441, 60.22565828050886, 61.17362880706787, 61.88650008610317, 60.03980091639927, 57.26725428444998, 56.263541834695, 52.05815853391375, 47.901284081595286, 46.89881535938808, 44.128638063158306, 44.63332741601126, 44.86906589780535, 43.70003843307495, 43.48347350529262, 44.12470885685512, 43.73885801860264, 44.074938910348074, 43.435986042022705, 45.851461274283274, 46.5537747655596, 46.19026933397566, 41.450913497379844, 42.80837263379778, 45.07580607278006, 45.65328822817121, 44.224474566323416, 44.205144677843364, 46.62046010153634, 46.70730563572475, 52.88615451540266, 57.90301098142351, 55.60838924135481, 54.747344153267996, 54.73830802100045, 60.537750516619, 57.643485341753276, 55.41921411241804, 58.13543517248971, 54.979782240731375, 56.925990036555696, 55.554686614445274, 54.13817473820278, 53.5630202293396, 51.39214938027518, 52.305378913879395, 47.564775875636506, 44.92210149765015, 45.006813934871126, 43.063017163957866, 42.851434094565256, 41.66779456819807, 40.485367502485005, 39.759047985076904, 41.38731663567679, 42.14324590138027, 41.22645541599819, 43.81122350692749, 43.33713749476841, 40.303932666778564, 43.004200662885395, 44.13836554118565, 41.77400820595877, 42.891924721854075, 46.245191369737896, 50.29754754475185, 52.702572686331614, 55.74141945157732, 56.89628996167864, 53.45146690096174, 53.52100099836077, 52.47567926134382, 53.84200777326311, 53.791845253535676, 53.210729190281455, 51.72993605477469, 50.60214614868164, 47.96616983413696, 46.26228393827166, 47.505212443215505, 44.04181684766497, 44.854964528764995, 45.17688499178205, 44.68544585364205, 46.82721069880894, 51.870095116751536, 54.64249236243111, 58.758851868765696, 58.69487285614014, 64.40496499197823, 58.065657888139995, 64.16577325548444, 60.24283422742571, 57.59549413408552, 12.64991293634687, 0.9540881982871464, 47.344736848558696, 58.79475321088518, 58.638106073652, 60.95536504473005, 67.01137324741909, 60.11055442265102, 68.60804843902588, 35.19448103223528, 33.43966136659895, 47.177160194941926, 35.37563793999808, 66.84892436436245, 17.344475473676408, 0.47142300648348673, 0.3109591097704002, 0.14555437889482292, 0.13982526345976762, 0.13884725022528852, 0.125711463657873, 0.0966074342972466, 0.20316270765449318, 0.17388709714370115, 0.07847584544547967, 0.16642028066728795, 0.0857691333762237, 0.1261487930480923, 0.24933328373091562, 0.10463153158447572, 0.1582926796483142], [0.02254653801875455, 0.014955963540290083, 0.015093483928857105, 0.027262705843895674, 0.040790726364191086, 0.09626351203769445, 0.026114468529288257, 0.042398141896618266, 0.01599128414610667, 0.058668444731405804, 0.024092169545058693, 0.03605800906994513, 0.022704158310911486, 0.025502407890079275, 0.056088685124580345, 0.049310293314712386, 0.060430573033435006, 0.033008068799972534, 0.032758900563099554, 0.07719057119850602, 0.1597225157810109, 0.38118045457771843, 42.93775156566075, 35.074106965746196, 33.93454681124006, 22.154035908835276, 45.06887524468558, 56.875858783721924, 52.551365988595144, 64.36622878483364, 54.78613247190203, 60.74509865897042, 58.64588805607387, 38.69288165228707, 5.302650638989039, 0.17800123138087137, 11.303021141460963, 53.35021775109427, 63.139691080365864, 64.24941567012242, 63.21241787501744, 63.643268721444265, 64.32941722869873, 62.16305228642055, 61.06193651471819, 57.248768602098735, 48.305842944553916, 46.90448161533901, 50.28899431228638, 53.46305997031075, 58.52845655168806, 58.29262774331229, 58.62323692866734, 56.38278334481375, 55.1317914554051, 51.83730656760079, 48.56962782996041, 45.383882250104634, 44.75723811558315, 42.5640982900347, 41.15559073856899, 41.414744649614605, 40.51886824199131, 39.50928456442696, 41.448505946568076, 39.575813565935405, 40.01169490814209, 36.44107123783657, 38.99289444514683, 39.34012719563076, 40.815441676548545, 40.25030299595424, 39.888447761535645, 38.57316766466413, 37.817231450762065, 39.483201026916504, 39.866359438214985, 38.72787972858974, 40.39255346570696, 41.887211731501985, 47.437477929251536, 50.59040716716221, 53.886205264500205, 53.326434067317415, 53.71310479300362, 52.887471199035645, 52.55855737413679, 49.53701857158116, 50.914019516536165, 52.52209322793143, 51.86014529636928, 49.81525223595755, 46.615578992026194, 48.42599466868809, 47.91445786612374, 49.10267972946167, 47.38903856277466, 46.31081015723092, 39.330441406794954, 40.63293334415981, 39.03474344526018, 38.427338872637065, 36.64937823159354, 36.96113348007202, 37.81156519481114, 38.83501400266375, 40.61370767865862, 39.888558932713096, 37.83339296068464, 37.40247958047049, 37.03474269594465, 37.450839042663574, 38.15272521972656, 38.61119168145316, 37.71776103973389, 38.68949440547398, 44.51964446476528, 50.28040286472866, 51.79719809123448, 49.530244077954976, 49.92511020387922, 46.005377769470215, 45.44619369506836, 48.00331490380423, 48.51959385190691, 48.01322998319353, 50.84836251395089, 49.32150282178606, 50.64753873007638, 47.381051608494346, 44.739429882594514, 40.26138537270682, 39.53782429013933, 38.481955187661306, 39.680001803806846, 38.01216663633074, 40.75599636350359, 41.096597058432444, 47.43914549691336, 51.75359467097691, 52.467973709106445, 53.56348923274449, 62.2342643737793, 50.797595500946045, 48.503974301474436, 6.52100944519043, 0.9829376616648265, 44.65110438210623, 44.53081716809954, 46.081533500126426, 56.1619348526001, 53.075551986694336, 56.571628434317454, 29.088784524372645, 7.82196843624115, 27.137384687151226, 22.108174324035645, 33.98206206730434, 39.56968525477818, 0.37696810918194906, 0.06581966778529541, 0.005639835917723498, 0.0746072798169085, 0.02203705151831465, 0.029632055134113346, 0.04256457635866744, 0.04918870323204568, 0.012736347420806331, 0.05391848925501108, 0.04239827760362199, 0.07567433041653462, 0.03311241730781538, 0.025610681723005006, 0.019305825931951404, 0.03306297246100647, 0.020293470971020203, 0.11178780293890409, 0.041739929001778364, 0.016085059382021427, 0.012129943219146557, 0.013894755975343287, 0.05610441017363753, 0.06884267021502767, 0.04955089504697493, 0.03414892704625215, 0.016907286065231477, 0.031283622940203974, 0.03697648085653782, 0.02741364935146911, 0.06174389791807958, 0.023377321028549756, 0.021357770111145716, 0.06002590831901346, 0.05631174333393574, 0.0540819381629782, 0.01102127637048917, 0.05871088709682226, 2.289674839803151, 55.31713465281895, 37.8248154095241, 37.8221229825701, 31.721257209777832, 47.65304231643677, 68.91928604670933, 60.27360779898507, 67.73934296199253, 58.973863874162944, 66.58939525059291, 61.95276505606515, 44.21248892375401, 6.484180952821459, 0.6539988123944828, 12.004203813416616, 57.07080091748919, 63.24863188607352, 65.88803713662284, 65.33348751068115, 65.4046995980399, 65.32757459368024, 64.18615927015031, 62.10299205780029, 56.85852302823748, 49.33822366169521, 48.64164938245501, 52.000238350459504, 55.66601412636893, 59.96348190307617, 60.35460989815848, 60.11330590929304, 58.11472259249006, 58.091470445905415, 53.494705540793284, 51.10703352519444, 48.81568786076137, 47.5348847252982, 43.999748979296, 42.90236439023699, 41.77195501327515, 43.63819946561541, 41.8196439743042, 43.34192132949829, 41.186267035348074, 42.85845872334072, 40.58872195652553, 40.986353465488975, 42.7889142036438, 42.3365934235709, 42.618770190647666, 41.163133008139475, 41.20348814555577, 39.82594524111067, 41.36304310389927, 41.893010003226145, 42.13294172286987, 42.870725767953054, 42.526164599827354, 50.333737237112864, 53.6878376688276, 56.48280266353062, 54.92985595975603, 55.2138010433742, 54.95950044904436, 55.52401379176548, 52.00659247807094, 52.948313099997385, 54.588470118386404, 55.920422417776926, 51.66881275177002, 50.636741229466026, 50.32115057536534, 51.319575445992605, 51.090614931924, 49.67962687356131, 47.37293611254011, 41.54462037767683, 42.71829618726458, 42.32508373260498, 39.98253331865583, 39.30747413635254, 40.258501870291575, 40.95776162828718, 41.05585977009365, 42.96734046936035, 41.11388765062605, 39.13616977419172, 40.00416653496878, 40.76031814302717, 38.93684332711356, 41.497831208365305, 40.609570026397705, 39.50328826904297, 40.130432673863, 46.654311725071494, 51.38382543836321, 52.67958804539272, 50.512993812561035, 51.367090702056885, 49.349340779440745, 49.12519189289638, 50.91400214603969, 50.46893875939505, 51.18669809613909, 51.75240305491856, 50.499872139522004, 54.196345056806294, 48.663254805973594, 47.758178983415874, 42.47972978864397, 41.68886498042515, 40.679774624960764, 41.78223834718977, 39.631843839372905, 43.56076526641846, 44.809763022831504, 50.0256541115897, 54.604239055088584, 56.19192327771868, 56.204516887664795, 65.65615490504673, 53.9740617615836, 54.95100975036621, 8.606233324323382, 1.0332112440041132, 50.50605256216866, 49.28576128823416, 53.13398633684431, 57.11526244027274, 60.09832559313093, 58.61843572344099, 42.54490041732788, 14.4644193649292, 30.80162491117205, 24.626663548605784, 38.997073786599294, 43.5269900730678, 0.2927251639110701, 0.10951628482767514, 0.04591438839478152, 0.11769675729530198, 0.09946154936083726, 0.035048990177788904, 0.021391552673386674, 0.02471307828091085, 0.02136331543858562, 0.0027744622618359116, 0.040390081969755035, 0.04283339496968048, 0.06000237672456673, 0.048704371721084626, 0.049992726517042944, 0.019606525510815636, 0.051536794020129104, 0.18832124689860003, 0.12272829801908561, 0.1387618769492422, 0.09368317906877824, 0.10298294254711696, 0.12842006688671453, 0.172322327537196, 0.10796963210616793, 0.06747230767671551, 0.12869537568518094, 0.11295352610094206, 0.1090234580582806, 0.10652418288269214, 0.1329312798167978, 0.25200663028018816, 0.13103712217084, 0.11669523960777692, 0.15668911140944275, 0.13772284984588623, 0.2363360540143081, 0.4404590922806944, 7.823556099619184, 74.11228629520961, 49.521485873631065, 53.30928591319493, 35.727998461042134, 56.4050418989999, 70.7071339743478, 63.86652129037039, 73.93991538456508, 64.09342861175537, 72.89118208203996, 67.60743141174316, 49.01838765825544, 7.855525629861014, 1.2809507846832275, 14.838261978966848, 62.557049887520925, 66.54375253404889, 71.69183267865861, 68.65913159506661, 68.92160674503872, 69.44643197740827, 66.88837623596191, 65.9387172971453, 62.133855955941335, 53.15735312870571, 51.312123503003804, 53.952553612845286, 60.765804290771484, 62.090054512023926, 60.91309220450265, 62.522962025233674, 63.131269863673616, 59.56140354701451, 56.797566481998985, 52.41368743351528, 51.289222240448, 49.16193049294608, 48.27114016669137, 45.07382583618164, 46.26366662979126, 45.34284618922642, 46.20067426136562, 47.34590414592198, 44.26789385931832, 46.522007601601736, 42.6563286781311, 43.13131448200771, 44.98470476695469, 46.205058574676514, 44.75379180908203, 44.44371107646397, 43.9950589452471, 42.95910337993077, 44.027055399758474, 45.24775314331055, 45.57776825768607, 44.34702341897147, 45.1805362701416, 53.00243956702096, 55.723010199410574, 58.529644693647114, 57.52636998040335, 57.28001465116228, 57.99100991657802, 57.32412528991699, 55.02175978251866, 54.36053098951067, 57.05783905301775, 57.439173562186106, 55.1602269581386, 51.69011245455061, 52.4642460005624, 53.466881479535786, 55.38187796728951, 52.59565380641392, 49.517713001796174, 44.26313434328352, 45.213536739349365, 42.73517683574131, 43.04682438714163, 40.370614528656006, 41.4017584664481, 41.76271390914917, 44.05879477092198, 45.88786288670131, 42.581767559051514, 40.8572142464774, 41.84981305258614, 41.764037540980745, 41.65297406060355, 42.94542237690517, 43.605251107897075, 41.31717804500035, 41.21473380497524, 48.95848029000418, 53.395276818956646, 55.77199499947684, 52.11992801938738, 53.29787697110857, 51.026458740234375, 51.43559646606445, 52.2732469694955, 55.366411277226035, 54.386843817574636, 55.14445454733712, 52.33610732214791, 55.16523313522339, 50.8745676449367, 50.83717591421944, 44.42067779813494, 44.39453520093645, 42.25287457874843, 44.03227002280099, 41.799924986703054, 46.58503123692104, 46.92118855885097, 52.27252088274275, 59.62749481201172, 59.557276317051475, 58.027293409620015, 69.0033939906529, 58.57295976366316, 58.83190522875105, 10.396871822220938, 1.7773956656455994, 55.037528719220845, 53.58878762381417, 57.460198811122346, 63.7367011478969, 63.28334508623396, 66.39049611772809, 40.58202389308384, 13.534288338252477, 40.491044180733816, 34.54675258908953, 46.80752297810146, 55.845996788569856, 1.4784313993794578, 0.43100473816905704, 0.12990604500685418, 0.290850534502949, 0.19390559010207653, 0.09822491928935051, 0.07305812330118247, 0.13478700523929937, 0.09581960764314447, 0.20471620000898838, 0.12976104207336903, 0.17112046560006483, 0.14738072375101702, 0.09520118404179811, 0.09685666020959616, 0.10125283431261778, 0.14638885483145714], [0.02818029553496412, 0.03353677989382829, 0.015844852896407247, 0.05170624457033617, 0.0706671898120216, 0.08567977709961788, 0.020195819603811418, 0.016828474222815464, 0.01766489416227809, 0.015174592612311244, 0.03234964895195194, 0.08393478180680956, 0.013609597392912422, 0.009360151398660881, 0.08168567570724658, 0.05930531769990921, 0.029937762301415205, 0.07057594042271376, 0.018364592688158154, 0.02037910039403609, 0.003380587415969265, 0.2030275027666773, 18.65401462146214, 54.39099189213344, 31.508465153830393, 45.53253548485892, 28.829463856560842, 47.222618784223286, 65.69504397256034, 63.852993147713796, 59.81185136522566, 57.19250903810774, 57.00729438236782, 47.63719694955008, 13.101544976234436, 0.307085923318352, 1.922121865408761, 27.927019664219447, 63.61266885484968, 64.00313677106584, 64.58818204062325, 63.88282871246338, 62.70501177651541, 64.43722547803605, 63.026782853262766, 56.24939182826451, 48.337356499263215, 45.313351086207796, 50.11777332850865, 52.62091745649065, 58.94088772365025, 59.09768772125244, 58.54157475062779, 57.733909198216026, 53.648795740945, 47.73131029946463, 45.18939869744437, 43.30253546578543, 44.131973198481965, 41.1952406338283, 40.625502245766775, 40.221961293901714, 40.950132506234304, 40.62966421672276, 39.23211744853428, 40.212813990456716, 38.85890538351876, 38.83570882252285, 38.94900614874703, 38.66201775414603, 38.4393036706107, 38.67707102639334, 39.916890212467735, 39.36070775985718, 38.57433843612671, 40.08323703493391, 40.72627196993147, 39.83742713928223, 39.79368822915213, 42.38241331917899, 46.647332259586875, 51.37016180583409, 54.41039473669869, 54.95440394537789, 52.57804012298584, 52.73183849879673, 53.16563190732683, 51.18102836608887, 51.53618901116507, 55.662453174591064, 52.416900975363596, 48.80132940837315, 50.24584252493722, 48.21813235964094, 50.40978527069092, 47.85867772783552, 50.520907810756135, 47.71656969615391, 40.30507217134748, 38.85742541721889, 39.26635817119053, 37.57069546835763, 37.93976640701294, 36.093035970415386, 37.75811965124947, 38.74415935788836, 37.80324820109776, 38.9262820652553, 38.57770136424473, 37.00707844325474, 37.63920818056379, 37.04132611410958, 38.85375329426357, 37.71135132653372, 37.77094602584839, 38.69726596559797, 39.13009010042463, 42.14505590711321, 48.846218245370046, 52.02781922476632, 53.11962441035679, 52.01332875660488, 50.6403021812439, 50.42958763667515, 52.21190479823521, 50.43269000734602, 50.16000100544521, 48.93973405020577, 50.95238052095686, 51.19885744367327, 48.94220413480486, 43.58028623035976, 42.52972902570452, 40.67738444464547, 40.526038782937185, 42.22551952089582, 46.39996944155012, 43.13808897563389, 46.35960735593523, 43.13623380661011, 55.75107397351946, 52.94457844325474, 64.54139287131173, 52.89029564176287, 49.6684159551348, 7.496219515800476, 1.5741003858191627, 39.38654463631766, 51.37448705945696, 46.22233527047293, 58.016162395477295, 51.63799054282052, 58.18527807508196, 11.888369526181902, 14.26490010534014, 39.38057613372803, 21.325725521360123, 48.024114336286274, 18.64139495577131, 0.19273259304463863, 0.06450983735599689, 0.0481660084665886, 0.07215452500219856, 0.009537081101111003, 0.02599371813370713, 0.03764108894392848, 0.009077456746516483, 0.014004149391049785, 0.009811908139714172, 0.04215206438675523, 0.08372182359120675, 0.01964919688180089, 0.04499395564198494, 0.04150689632764884, 0.018767990238432373, 0.02537845311287258, 0.02230632135511509, 0.029443381686827967, 0.023999457912785665, 0.03294574875118477, 0.030447861179709435, 0.027932538650929928, 0.01374931538677109, 0.01756389592108982, 0.051428506616503, 0.031781711748668125, 0.02627095566796405, 0.09204909032476799, 0.03178286186552473, 0.017004202918282578, 0.06008353629814727, 0.03365221227120076, 0.04542368543999536, 0.03900010298405375, 0.03959959206570472, 0.023926788508625965, 0.049355826407138786, 0.09762280766985246, 26.451637438365392, 63.699298994881765, 34.01883888244629, 47.25627933229719, 35.471592562539236, 53.03525243486677, 69.94290161132812, 70.0604442868914, 63.882509095328196, 63.785505294799805, 63.38335745675223, 52.29903868266514, 13.427522318703787, 0.40803700632282663, 2.5708834188325063, 29.98398174558367, 64.83171640123639, 66.50681591033936, 68.39125769478935, 66.67076560429165, 63.61061218806675, 65.86432988303048, 65.05250235966274, 57.37600401469639, 50.86089359010969, 47.57295043127877, 51.79467589514596, 55.01270975385393, 60.237324305943076, 61.27909551348005, 61.69533429827009, 59.08627183096749, 56.01528269904, 49.74582930973598, 46.91543197631836, 45.70842218399048, 45.45150906699044, 44.28194659096854, 42.990186146327424, 42.1711220741272, 42.918946266174316, 41.40569462094988, 41.62192256110055, 41.05048533848354, 42.92870848519461, 42.76417861665998, 40.966349601745605, 40.10000998633248, 42.040631430489675, 42.4420497076852, 42.14028249468122, 41.94659798485892, 41.26914862224034, 41.58034454073225, 42.7062132699149, 43.03325802939278, 43.10842711584908, 44.39339917046683, 48.37969534737723, 56.77650996616909, 57.071339402879985, 56.6615172794887, 55.61947856630598, 55.93151521682739, 54.186662742069785, 54.44468409674508, 55.16916234152657, 58.16697651999337, 54.568490573338096, 52.6758325440543, 51.48915318080357, 50.93037557601929, 52.547370774405344, 52.475081716264995, 53.600575242723735, 50.787270477839876, 42.8015147617885, 41.0273791040693, 41.9004202570234, 40.929072516305105, 41.50863218307495, 38.34149735314505, 39.48032794679914, 41.113463810511995, 41.4244304384504, 42.4012325150626, 40.41338069098336, 40.96169430868966, 40.03967530386788, 39.737567629132954, 41.56077493940081, 39.68374688284737, 39.80082055500576, 40.20649807793753, 41.120231355939595, 44.07483121326992, 51.63133416857038, 51.44079719270979, 52.738512243543354, 52.82441977092198, 51.817167213984895, 50.87842736925398, 54.370119503566194, 53.27622638429914, 52.25728348323277, 51.51208918435233, 54.05946207046509, 52.91514934812273, 49.92323419025966, 45.695307459150044, 45.0310492515564, 41.87035887581961, 41.569494928632466, 43.997393539973665, 48.79578821999686, 45.538465772356304, 48.629159995487754, 45.48741735730852, 57.697313036237446, 55.885889870779856, 66.12984139578683, 56.45910930633545, 55.95322486332485, 9.192664759499685, 1.5296119387660707, 46.35249934877668, 55.49566166741507, 50.47483777999878, 62.6987236567906, 56.67530597959246, 64.37016841343471, 21.225614139011928, 15.677687747137886, 44.51245655332293, 22.376956701278687, 54.08422545024327, 17.19559642246791, 0.11537912594420568, 0.10495190867888075, 0.032404243879552395, 0.0744850349479488, 0.037769824000341554, 0.051433772048247714, 0.05660287896171212, 0.049627671284335, 0.03046657856819885, 0.039616121178759, 0.0830985756058778, 0.05375579012823956, 0.030879521409847906, 0.028951616824737618, 0.06205485694642578, 0.03310428506561688, 0.05249327394579138, 0.07662370268787656, 0.07378780628953661, 0.14447822235524654, 0.18314193481845514, 0.131790852440255, 0.19410514725106104, 0.07541196806622402, 0.14226984871285303, 0.10858901244189058, 0.09082881294723068, 0.10891074660633292, 0.2122207973152399, 0.1188178328531129, 0.13011305247034344, 0.15246039974902356, 0.11860956331448895, 0.08939970284700394, 0.08965152754847493, 0.13277793090258325, 0.18459459686917917, 0.07060266113174812, 0.1838283408433199, 41.27727454049246, 78.01178904942104, 45.91056612559727, 62.01393699645996, 41.46878426415579, 58.79267569950649, 75.8976537159511, 73.65084253038678, 71.31371865953717, 68.33201735360282, 68.31607818603516, 57.826212542397634, 16.170101370130265, 0.6917004436254501, 2.92375202689852, 33.62858983448574, 67.0978227342878, 68.45956543513707, 69.03468867710659, 70.33674635205949, 67.17869976588658, 68.08387633732387, 66.30258750915527, 61.48777770996094, 53.42897210802351, 50.37622547149658, 55.75991555622646, 57.05875621523176, 61.57685361589704, 64.00458894457135, 64.51365566253662, 62.451506750924246, 59.075446537562776, 52.63737079075405, 49.25507804325649, 47.38864598955427, 48.61208132335118, 45.67015150615147, 45.262518065316335, 43.34235906600952, 44.89622988019671, 44.36708286830357, 45.11064086641584, 44.809901986803325, 45.08459554399763, 46.5500123160226, 44.27943481717791, 43.42379890169416, 43.93066304070609, 44.72905274799892, 45.95598302568708, 44.484139169965474, 43.55069037846157, 44.72298002243042, 45.64558267593384, 46.005384717668804, 46.60817221232823, 47.27148199081421, 50.47356973375593, 59.02246652330671, 58.924865177699495, 58.54805741991316, 56.49530594689505, 57.0507310458592, 55.37111520767212, 55.580989020211355, 56.92498254776001, 60.56735679081508, 56.62912130355835, 54.5366712978908, 53.54013633728027, 52.932776927948, 54.18055527550833, 52.26397459847586, 55.53714936120169, 52.08930383409773, 44.97226401737758, 41.61861521857125, 43.88802889415196, 42.599596636635916, 44.052173137664795, 38.7923937525068, 43.14033324377877, 42.769400187901084, 42.12472200393677, 43.754244804382324, 43.35813842500959, 42.93235281535557, 42.66759865624564, 41.99213995252337, 43.902974469321116, 41.899371079036165, 41.69664348874773, 42.549045017787385, 43.05847304207938, 44.896921225956504, 52.48385034288679, 53.54235976082938, 56.39523104258946, 54.288151604788645, 52.7816675049918, 52.207916532244, 56.63892868586949, 56.045111315590994, 57.19660152707781, 56.61285209655762, 57.85401228496006, 54.18879583903721, 51.68395982469831, 46.81676408222744, 47.338775294167654, 44.114276136670796, 42.7155099596296, 46.191784041268484, 50.881564480917795, 48.02300609861101, 51.94975273949759, 48.14162227085659, 60.98624978746687, 58.65929807935442, 68.9872463771275, 58.956215449741904, 59.86567211151123, 11.209293416568212, 2.049297784055982, 49.80500364303589, 62.03968702043806, 55.93683753694807, 67.23515387943813, 60.317492621285574, 69.4932141985212, 16.746760163988384, 21.36901800973075, 57.11229903357369, 30.873052392687114, 64.69696998596191, 31.5847042628697, 0.21478059781449182, 0.20823360340935843, 0.0718477118228163, 0.11482530566198484, 0.12282380860831056, 0.19071403278836183, 0.14545444425727638, 0.1704239494034222, 0.11768501863947936, 0.13151521794497967, 0.09684044322265045, 0.20299132327948297, 0.1067485540573086, 0.11028328045670475, 0.2036200538277626, 0.10293898704860892, 0.11046426610222884], [0.036846395515437634, 0.03333862731233239, 0.03182363164212022, 0.03390027449599334, 0.048947331362536976, 0.03673133633232542, 0.03610463121107646, 0.00932436715811491, 0.03711046438132014, 0.07751584053039551, 0.009286362411720412, 0.03700252981590373, 0.02415966342336365, 0.04091075920899, 0.010612612540301467, 0.01142643895998065, 0.08881171832659415, 0.026979861914047172, 0.03540584870747157, 0.02826095638530595, 0.024260685413277576, 0.1676909460553101, 5.327157369681767, 59.09590203421456, 32.68789407185146, 74.77290712084088, 33.49584797450474, 23.20489536012922, 70.52164486476353, 58.4072174344744, 64.15392657688686, 58.753209931509836, 58.63223484584263, 53.29776232583182, 22.38772119794573, 0.7624531899179731, 0.04162781126797199, 6.8215533409799844, 64.60680321284703, 62.67398806980678, 63.67987183162144, 64.14840275900704, 68.73050349099296, 63.056750433785574, 61.91293798174177, 56.82714148930141, 49.495829650333945, 46.43014546803066, 47.52780451093401, 51.0933837890625, 58.17541858128139, 61.26833970206124, 61.19206237792969, 58.77688244410923, 56.285671847207205, 50.26786484037127, 43.801245893750874, 45.06436586380005, 44.19888087681362, 43.228217533656526, 42.15422405515398, 42.84584774289812, 42.033592905317036, 42.37710836955479, 40.41683394568307, 39.80235263279506, 39.10126897266933, 39.45016929081508, 40.979985441480366, 39.18366418566023, 39.36365727015904, 39.194149017333984, 39.60307829720633, 38.616788455418174, 38.052320275987896, 38.722668579646516, 41.559718813214985, 40.32521152496338, 42.50660194669451, 41.20006268365042, 46.31054612568447, 50.40057890755789, 55.01948772157942, 53.72735902241298, 56.007670947483604, 53.72414895466396, 54.93597732271467, 49.81912933077131, 51.952347891671316, 55.18770360946655, 53.37792716707502, 50.477776868002756, 48.50726427350725, 50.95105341502598, 48.58261053902762, 50.50177247183663, 51.21908017567226, 50.44697897774832, 43.81141110828945, 38.959959983825684, 38.46358067648751, 38.897377559116904, 37.389879022325786, 37.34569195338658, 38.19913918631417, 38.36931446620396, 38.8611843926566, 39.321738788059776, 38.29045936039516, 38.14214311327253, 36.72167076383318, 39.008607796260286, 39.63946948732649, 40.844829082489014, 36.65671900340489, 39.37021289552961, 38.87918022700718, 39.306723730904714, 42.424345697675435, 47.74353218078613, 52.34892674854824, 52.54898623057774, 55.55589212690081, 54.2483731678554, 52.136079107012065, 52.350424085344585, 50.54917655672346, 48.59862961087908, 48.7209734916687, 52.161797864096506, 47.84695611681257, 45.43614312580654, 42.32432985305786, 39.281004973820274, 45.390656743730815, 50.50834199360439, 57.07232257298061, 54.08028582164219, 51.2607797895159, 46.29843888963972, 51.8800345148359, 53.786846024649485, 61.96608475276402, 54.379853929792134, 46.63926192692348, 4.633748863424573, 1.3936409034899302, 44.11874730246407, 48.623056003025596, 55.22421639306204, 47.836290631975444, 57.468963963644846, 39.73615714481899, 9.498059800692968, 30.346698556627544, 22.34039875439235, 29.233819484710693, 43.507510798318044, 2.2184317026819502, 0.09147927697215762, 0.06933671834745578, 0.07945863556649004, 0.06173360454184668, 0.026458039646968246, 0.03377150890550443, 0.07342067813234669, 0.011061075842007995, 0.04124636941456369, 0.026102285433028425, 0.01248404011130333, 0.021794860317770923, 0.0935209481311696, 0.09359216716672693, 0.058705485958073816, 0.036336578229176145, 0.01130307959725282, 0.03877605072089604, 0.05487152222277863, 0.031369623861142566, 0.05714861449918576, 0.059251632009233744, 0.05671504758564489, 0.05269367926354919, 0.0210314337829394, 0.013652661466039717, 0.03600343789107033, 0.05023349109770996, 0.01802784763276577, 0.022545179252379706, 0.06909144829426493, 0.020477328516010727, 0.0693703872550811, 0.13659498893788882, 0.09474915758307491, 0.05682149615937045, 0.09862103446253709, 0.13315424642392568, 0.07809205246823174, 6.011504556451525, 69.93547398703438, 35.363475118364605, 78.37348447527204, 45.23535755702427, 33.0987480027335, 80.04563794817243, 61.17093290601458, 69.40973854064941, 65.7039793559483, 64.19592148917062, 59.334864480154856, 26.187868186405726, 0.649608202278614, 0.011814586435710745, 8.127260991505214, 64.64005729130336, 63.82205976758684, 65.38566153390067, 64.25026335035051, 71.87687710353306, 66.27448204585484, 66.5663480758667, 58.6232716696603, 50.69821889059884, 48.807019983019146, 49.55770335878645, 53.6663156236921, 59.21600859505789, 60.84456212180001, 63.020918573652, 60.99623434884207, 59.94496495383126, 52.06682293755667, 46.068140847342356, 46.02403020858765, 44.89579561778477, 45.422639301845, 44.20879943030221, 44.889931338174, 44.16093676430838, 44.58446420942034, 42.844829831804546, 40.74188804626465, 41.63671875, 41.70237922668457, 42.54728364944458, 43.16758755275181, 42.15366472516741, 42.19719866343907, 42.27674164090838, 41.34763547352382, 41.85551404953003, 41.57194764273507, 44.30695315769741, 41.06014333452497, 43.38329437800816, 43.48608602796282, 47.69053132193429, 54.33460031236921, 57.34384775161743, 55.994319983891074, 56.99340493338448, 54.78435025896345, 60.049424171447754, 53.63178655079433, 53.727386815207346, 58.45066452026367, 55.96635001046317, 52.92482818875994, 51.05113179343087, 52.752575397491455, 51.93886491230556, 53.204969133649556, 53.827208110264365, 52.1910845211574, 43.95927919660296, 41.982304777417866, 41.032961981637136, 41.39917026247297, 41.11603464399065, 41.206104142325266, 40.58703007016863, 40.56780440466744, 41.82396922792707, 40.75451987130301, 39.90329258782523, 40.222597054072786, 40.234089374542236, 40.22303826468331, 41.52182681219918, 42.59995446886335, 39.15702826636178, 39.89275911876133, 40.37095846448626, 40.531593867710654, 43.277164118630544, 49.733260018484934, 52.37036541530064, 54.32600539071219, 58.14401272365025, 55.467427662440706, 53.987607274736675, 54.90752444948469, 54.56989063535418, 50.160939012254985, 52.477249554225374, 53.28090252195086, 50.52168253489903, 46.83859879629952, 44.20242098399571, 40.61823443004063, 50.26260852813721, 53.33171122414725, 58.22905172620501, 55.850179604121614, 51.85101536342076, 48.00119570323399, 53.91863598142351, 55.58380651473999, 65.0374734061105, 56.55816282544817, 54.97844818660191, 5.243821544306619, 1.7085510683911187, 49.05143676485334, 55.822973932538716, 56.90751825060163, 55.17904962812151, 59.18116337912423, 49.62571232659476, 13.108303836413793, 27.948797055653163, 30.6193528175354, 30.417160238538468, 52.36586645671299, 0.6332635964666093, 0.10894503298082522, 0.08125970499323946, 0.017526330526119897, 0.043647094164043665, 0.06772324349731207, 0.008037774008698761, 0.049167946845825226, 0.048011892807802985, 0.033422721549868584, 0.021754501054861715, 0.01596917408252401, 0.01448814248267029, 0.02091549420064049, 0.006241888589491802, 0.04674551576109869, 0.03089639657576169, 0.019631945128951753, 0.1729943621903658, 0.1543566065707377, 0.12117329931684903, 0.21288771581436905, 0.10958815525685038, 0.1721242903066533, 0.1735961820398058, 0.0856336367183498, 0.15310451947152615, 0.143397221075637, 0.12219225535435335, 0.07678953664643423, 0.16148875600525311, 0.12927290398095334, 0.08832765144429036, 0.15178744228822844, 0.1478019311491932, 0.2604415805212089, 0.12540229596197605, 0.19880047387310437, 0.32122439465352465, 0.26180497450487955, 14.426184296607971, 87.537123135158, 46.21177748271397, 92.19636971609933, 44.02610697065081, 31.874266965048655, 81.06507069723946, 69.55265603746686, 74.5483204977853, 70.01730987003872, 69.52258423396519, 64.91064098903111, 28.013003621782573, 0.8156104918037141, 0.144410016015172, 9.932046890258789, 70.03849492754254, 65.35501302991594, 68.43752574920654, 65.06122234889439, 74.1495703288487, 68.20307268415178, 70.7782974243164, 61.79959201812744, 54.72958108357021, 51.537488324301584, 52.43469878605434, 56.52082668031965, 62.62519781930106, 64.08063697814941, 66.90723364693778, 64.83105632237026, 64.00873701913017, 54.770728315625874, 49.113272258213584, 49.75669281823294, 48.19907692500523, 46.86692312785557, 47.84876612254551, 47.392043658665244, 47.700495038713726, 48.42269427435738, 45.00410066332136, 42.93877989905221, 43.93714918409075, 45.51585980824062, 46.22308915002005, 45.04712043489729, 44.923532826559885, 43.731357438223704, 46.126477922712056, 44.09171533584595, 43.01571035385132, 44.12443092891148, 47.099743366241455, 43.15841245651245, 45.59415210996355, 45.91252899169922, 49.95506041390555, 55.81451102665493, 58.128983770098, 57.65117699759347, 61.400994709559846, 59.08440276554653, 60.76918111528669, 55.37960590635027, 56.38521521432059, 60.400252614702495, 57.35470083781651, 53.983681542532786, 52.27471651349749, 55.81576517650059, 53.38832514626639, 57.207343442099436, 57.16502891268049, 54.0063430922372, 46.94128622327532, 42.06299768175398, 41.909911496298655, 43.02291216169085, 41.829322814941406, 41.761612619672505, 43.42827354158674, 44.145539556230815, 44.32054383414132, 43.5880195753915, 42.70622716631208, 42.08654860087803, 42.23549018587385, 41.97782666342599, 44.91413538796561, 45.816164425441194, 43.30954967226301, 40.94081844602312, 44.60579170499529, 42.80380766732352, 47.93158517565046, 50.96351500919887, 54.94974865232195, 57.24088934489659, 60.53663880484444, 59.030762672424316, 56.123876094818115, 58.93158408573696, 56.94138377053397, 52.310798508780344, 56.50335543496268, 56.65251241411482, 52.806795665196006, 50.74933678763253, 47.76880625316075, 42.965731961386545, 53.45182473318917, 54.24117136001587, 61.11968994140625, 59.29515552520752, 54.27494307926723, 52.80337367738996, 57.51970665795462, 58.83783899034773, 67.28394412994385, 60.919435909816194, 57.405144759586875, 7.324688468660627, 1.7829267574208123, 53.97702864238194, 60.27794347490583, 63.79294681549072, 58.36185959407261, 65.57377706255231, 48.780283314841135, 14.718766859599523, 47.10996069226946, 34.59031432015555, 40.803824288504465, 64.1959284373692, 6.3841364468847, 0.5982003265193531, 0.27629565979753223, 0.2417861015668937, 0.11246070611689772, 0.1541990235980068, 0.08750424241381032, 0.1087078849918076, 0.11673173122107983, 0.12479469499417714, 0.05025542134951268, 0.13606627445135797, 0.11621502680437905, 0.1137220687898142, 0.1209092949117933, 0.1222277291651283, 0.05577425878228886, 0.09146488524441208], [0.0404416099190712, 0.044585857540369034, 0.03737133056191461, 0.0609149859685983, 0.04077265019129429, 0.033349012290792804, 0.019187031413561532, 0.021447974556524838, 0.013006758892775645, 0.06193664257547685, 0.02633146402825202, 0.010851668060890265, 0.019158583832904696, 0.047530638453151496, 0.04457352855908019, 0.059310786692159514, 0.043903387018612454, 0.04024826815085752, 0.10614811163395643, 0.011908730625041893, 0.1009461364841887, 0.06924921447145087, 0.807075172662735, 34.77539348602295, 52.89405114310128, 21.97896214893886, 34.94773660387312, 9.233676501682826, 34.535489559173584, 72.81324413844517, 58.87595680781773, 60.3735784803118, 58.46930653708321, 61.43173354012625, 37.23132460457938, 1.0323927679232188, 0.21627251990139484, 0.1184369440057448, 33.29828289576939, 71.97078200748989, 61.35556043897356, 70.59748445238385, 64.84041554587228, 65.54064110347203, 57.93123803819929, 53.179910455431255, 45.01158734730312, 46.466672148023335, 45.198066575186594, 52.18482072012765, 55.14354085922241, 60.77890164511544, 59.35291590009417, 61.735265595572336, 60.2285487311227, 57.94784770693098, 48.62361533301217, 43.10516841070992, 43.92961038861956, 42.73441253389631, 44.37593834740775, 43.02741459437779, 41.43189975193569, 41.214344705854145, 41.77980995178223, 40.290804045540945, 41.46836737224034, 39.258239201136995, 38.56511470249721, 40.190055165972026, 38.78934349332537, 39.627153805324006, 38.73886135646275, 37.8235056740897, 39.733374391283306, 37.75014311926705, 41.522219385419575, 41.189216545649934, 44.270350047520225, 43.43577412196568, 44.10547276905605, 49.38965422766549, 51.649736472538535, 52.584356035505024, 52.95855474472046, 52.68851300648281, 54.34608221054077, 53.392549651009695, 55.68219995498657, 54.83141040802002, 53.106259550367085, 52.96038212094988, 52.6025116784232, 51.7520625931876, 52.54711716515677, 52.23982266017369, 50.994490078517366, 52.75742176600865, 47.73761926378523, 40.69457081386021, 39.59035961968558, 40.01498140607561, 38.341448715754915, 38.35956614358084, 39.508172852652415, 37.74220132827759, 40.082691601344514, 38.036540916987825, 38.26885741097586, 36.82969093322754, 38.135396412440706, 38.76962103162493, 38.4754308291844, 38.16515902110508, 39.53060858590262, 38.94099487577166, 38.15886047908238, 37.638113839285715, 37.748756953648154, 41.77876772199358, 47.161929743630544, 50.74422638756888, 54.01330518722534, 53.22134951182774, 53.67759255000523, 53.86869232995169, 54.43091624123709, 51.85686574663435, 53.37049259458269, 53.22069985525948, 49.87468365260533, 45.02654334477016, 42.260611397879465, 44.02035386221749, 51.4800614629473, 56.180344104766846, 55.794732979365754, 57.00813511439732, 57.8453756741115, 51.31605618340628, 56.66747188568115, 53.46998037610735, 61.45272404806954, 51.89860010147095, 43.827152252197266, 2.695069440773555, 2.4761636214596883, 44.54628733226231, 46.490681648254395, 59.40145601545061, 47.53378343582153, 66.94461495535714, 16.91776749065944, 19.665991953441075, 36.43111446925572, 29.479413986206055, 38.91520663670131, 26.858127900532313, 0.42363185808062553, 0.14590515435806342, 0.050669100401656966, 0.01856952722716544, 0.024579586694017053, 0.03727871731721929, 0.021118398223604475, 0.022855318949690888, 0.0217327200807631, 0.03406450371923191, 0.03036269485684378, 0.05371537318985377, 0.0569212781265378, 0.04035304752843721, 0.029719484371266196, 0.013179944778260375, 0.014402716620160001, 0.013935775961726904, 0.03009869045178805, 0.06096340622752905, 0.03797360842249223, 0.0903749680146575, 0.053380706147955995, 0.08005609243576016, 0.04668875630678875, 0.0389066958533866, 0.02834535257092544, 0.044138692785054445, 0.04902559359158788, 0.04578665078484586, 0.033369124068745544, 0.0593641602567264, 0.009110509883612394, 0.08096199096845728, 0.04015144120369639, 0.08469668163784913, 0.025530807973284806, 0.04213399839188371, 0.08346957141267401, 0.06178900014076914, 0.7716057587947164, 43.20811986923218, 59.6288913999285, 28.082381384713308, 41.13120950971331, 15.601229769842965, 47.21072346823556, 77.63660717010498, 67.82413182939801, 66.42989935193742, 64.12942028045654, 66.27218914031982, 39.821560927799766, 1.548212917787688, 0.17219284948493752, 0.3057379185089043, 36.3301362991333, 73.03943579537528, 62.58489826747349, 72.75356606074742, 65.63321890149797, 69.5775305884225, 59.63077436174665, 55.777223518916536, 48.23483582905361, 47.61098139626639, 47.81328167234148, 53.45942953654698, 56.34489481789725, 62.84384373256138, 61.96254117148263, 62.77997589111328, 60.8903021131243, 61.27979728153774, 49.22033705030169, 44.01565340587071, 47.78043058940342, 46.21990687506539, 45.67626939501081, 44.976877621241975, 42.3920886857169, 44.596380370003835, 43.921651227133616, 41.3368171283177, 42.148488317217144, 42.310416085379465, 41.95719746180943, 42.88778706959316, 41.4733943939209, 42.02467141832624, 42.08835513251168, 40.03285912105015, 41.24109179633004, 40.46488421303885, 44.17863382611956, 42.61377790996006, 45.15554012571062, 45.229270935058594, 46.84357370649065, 51.556147711617605, 54.96464559010097, 54.70704460144043, 57.29805564880371, 54.0830477305821, 57.032895020076204, 55.36104726791382, 55.86435740334647, 58.12754201889038, 55.52337108339582, 54.86786413192749, 53.76306928907122, 53.92337812696184, 54.36655855178833, 55.68422188077654, 53.44594655718122, 55.75965847287859, 48.7886107308524, 43.16033363342285, 43.10177768979754, 43.20989165987287, 41.40573978424072, 41.06852981022426, 41.346985816955566, 40.55985566547939, 42.134102072034565, 40.673917293548584, 39.980733735220774, 39.54074600764683, 40.527299880981445, 41.04653876168387, 42.5085300718035, 40.77802562713623, 40.911382402692524, 40.67926393236433, 40.54061262948172, 40.11648416519165, 39.51646205357143, 44.07267032350813, 49.35079642704555, 54.09530782699585, 55.12189722061157, 54.7690155846732, 54.723716803959434, 55.040485177721294, 56.24670287540981, 54.50820452826363, 55.83551890509469, 56.19535916192191, 52.95420864650181, 46.80576160975865, 44.94964415686471, 44.54032925197056, 54.18887226922171, 56.29913050787789, 59.33077893938337, 59.60771329062325, 60.23625428336007, 53.74833563395909, 61.22753987993513, 56.3118839263916, 65.85334478105817, 55.508512360709055, 51.784187589372905, 2.7858771852084567, 3.3178662274565016, 50.21160875047956, 52.94618000302996, 63.886726651872905, 54.692675726754324, 67.14996201651437, 31.133248533521378, 15.796776396887642, 39.459670952388215, 33.57364000592913, 43.8059845651899, 32.60860470363072, 0.4971323726432664, 0.11444969581706183, 0.04767857605059232, 0.01882364198432437, 0.05809985952717917, 0.054418796872986216, 0.050038856720285754, 0.04056892005194511, 0.03296480201450842, 0.03963432288063424, 0.01429646142891475, 0.028142088924401572, 0.048021263376410515, 0.031193350641322986, 0.028920139585222517, 0.027942224738321135, 0.06742132255541426, 0.029577219326581274, 0.07941491076988832, 0.1504211848867791, 0.11945600860885211, 0.15769693947264127, 0.1738011267568384, 0.1311093047261238, 0.11208682653627225, 0.18598107461418423, 0.09715349213885409, 0.12790021406752722, 0.12011971085199288, 0.12672713558588708, 0.11653805018535682, 0.1963468233921698, 0.16333837461258682, 0.1699341285441603, 0.1831940734492881, 0.25888998806476593, 0.17134861621473516, 0.09344479614602667, 0.23308893825326646, 0.38555391132831573, 1.8530111738613673, 58.55041285923549, 71.95199407849992, 36.24077551705496, 49.44981867926461, 15.222768340791974, 42.66235971450806, 86.86059093475342, 71.04906872340611, 72.21961784362793, 69.28782544817243, 73.67154816218785, 43.894442081451416, 2.1393342784472873, 0.26148543879389763, 0.5841306586350713, 40.10320268358503, 75.04801409585136, 63.0827089037214, 75.57783508300781, 69.03439685276577, 73.0650885445731, 61.48971625736782, 60.01512091500418, 52.360502447400776, 51.13530227116176, 50.53545386450631, 57.094911166599815, 60.32889461517334, 65.81829111916679, 64.29302951267788, 65.73087583269391, 63.46740286690848, 64.30580724988664, 52.45976788657052, 46.04085179737636, 50.1980493409293, 48.30414063589913, 47.831388677869526, 48.27924524034773, 45.59742818559919, 48.16614941188267, 47.25508771623884, 44.73701538358416, 45.00579949787685, 45.44512367248535, 44.119546345302034, 46.201858929225374, 43.775287423815044, 43.60982302256993, 44.05819027764456, 42.90914583206177, 42.723378794533865, 42.1060209274292, 48.68548904146467, 45.429201875414165, 50.446433544158936, 48.609969070979524, 48.33969109398978, 53.737836905888145, 56.56184189660208, 56.89342382975987, 57.73890495300293, 55.10921328408377, 58.19089221954346, 58.34253665379116, 58.43751852852957, 59.65835871015276, 57.36020728519985, 58.61732401166643, 55.81100218636649, 56.84267766135079, 57.120845317840576, 58.604059900556294, 54.80661228724888, 55.174029554639546, 51.64081151144845, 45.487914153507774, 44.214236395699636, 45.73868158885411, 43.07581227166312, 42.34180457251412, 45.02030038833618, 42.4033864566258, 46.182591574532644, 42.25738048553467, 42.65321241106306, 40.60869107927595, 44.12254796709333, 42.33425188064575, 43.90485395703997, 42.21750129972185, 43.589225087847026, 43.76894719260079, 41.98566770553589, 40.757215772356304, 39.66206155504499, 46.34038169043404, 51.89939914430891, 53.77990477425711, 59.143455505371094, 56.18617364338466, 58.26875720705305, 59.056033270699636, 59.338359424046104, 57.494713987622944, 56.6659710747855, 58.421065194266184, 55.83524445125035, 50.50377355303083, 48.43499605996268, 48.11101198196411, 55.80326884133475, 59.66783605303083, 62.513540267944336, 62.96494388580322, 63.98145144326346, 55.61180428096226, 64.41904899052211, 57.665128980364116, 68.72103309631348, 60.129578590393066, 54.87945372717721, 4.02464849608285, 3.713172044072832, 55.67048529216221, 56.63918229511806, 69.30608531406948, 54.53231825147356, 77.62281499590192, 24.666919674192155, 28.263494866234915, 57.576230253492085, 41.44100884028843, 51.70267479760306, 46.98179074696132, 0.7707389167376927, 0.43747725657054354, 0.13844114701662744, 0.18836516168500694, 0.10410872035260711, 0.15762338627661976, 0.15717156337840216, 0.10783765704504081, 0.13609724278960908, 0.13170053942927293, 0.11167661140539817, 0.12036741684590067, 0.14843443435217651, 0.07477248273789883, 0.12405472541494028, 0.11249869729259185, 0.14632374261106762, 0.06523031262414795], [0.03274827470470752, 0.03174103696697524, 0.02113677464824702, 0.07200513194714274, 0.04053988893117223, 0.046863468896065436, 0.04708117346412369, 0.009667838191879647, 0.038484697961913686, 0.04933691902884415, 0.06658698232578379, 0.0012291678826191596, 0.0648348895566804, 0.09296205240700926, 0.019089554769120047, 0.008586343278044035, 0.051985722966492176, 0.02835524730783488, 0.05699335890156882, 0.13396748421447618, 0.04797008826530405, 0.029080399378601993, 0.04267292483044522, 17.507719925471715, 59.527864592415945, 33.683442388262065, 38.194789613996235, 30.429031235831125, 8.769465616771154, 64.47960254124233, 52.71225847516741, 50.67122861317226, 66.91023526872907, 55.764428411211284, 53.179413659232004, 4.037292914731162, 0.1945819402379649, 0.039530021870242696, 15.649794203894478, 73.80937262943813, 62.08223778860909, 67.38106604984829, 62.18978895459856, 63.61145292009626, 54.004956926618306, 52.38814238139561, 45.449077197483604, 48.472252300807405, 44.78548601695469, 50.502043451581685, 54.02473497390747, 56.80888509750366, 57.642926011766704, 62.417599541800364, 57.982564381190706, 60.5126953125, 51.58277668271746, 45.8143961088998, 42.428837708064485, 45.96814932141985, 45.51005458831787, 47.74398381369454, 45.45203365598406, 41.21912506648472, 41.11377995354788, 41.03522709437779, 39.60819564546858, 40.135626452309744, 40.14974519184658, 37.081514494759695, 39.676829951150076, 40.127677713121685, 39.33454779216221, 40.78561305999756, 39.08687577928816, 39.275588853018625, 41.64821107046944, 41.582595757075715, 45.76157242911202, 44.44888401031494, 45.315494605473106, 45.0752397945949, 47.85497086388724, 50.236674376896445, 53.64015565599714, 51.52630867276873, 54.751589502607075, 54.134895188467844, 55.21726124627249, 54.13618755340576, 49.93783582959856, 53.78762769699097, 53.33948973246983, 54.85392257145473, 54.73548705237252, 53.59856721333095, 53.464810916355674, 52.437530176980154, 49.475919587271555, 41.77941737856184, 38.18949508666992, 39.86475093024117, 39.35413476399013, 38.971674646650044, 37.949007511138916, 37.58440426417759, 38.6971686908177, 37.35739619391305, 39.449245180402485, 38.178760119846885, 38.374737535204204, 39.86540058680943, 39.57989910670689, 39.74089929035732, 38.173872062138145, 40.728422437395366, 38.67196062632969, 39.814039502825054, 38.751583508082796, 39.601598330906455, 38.48677723748343, 42.795581000191824, 45.912671429770334, 46.31178290503365, 45.00026178359985, 51.726527963365825, 52.31295592444283, 53.40317344665527, 55.88856145313808, 55.23926966530936, 50.902836390904014, 45.58755826950073, 41.01842287608555, 43.384173325129915, 53.31597702843802, 54.34356696265084, 59.07880251748221, 59.956992285592214, 57.059145314352854, 55.6765649659293, 56.088315214429585, 57.38625955581665, 59.5329715183803, 44.74255657196045, 31.46463939121791, 0.24874274113348552, 5.440634046282087, 37.505712441035676, 51.18910564695086, 45.19809784208025, 48.041203430720735, 43.33082505634853, 3.7183875356401717, 33.32115289143154, 30.656956468309673, 20.989358016422816, 47.61534833908081, 11.795162916183472, 0.6880329347082547, 0.07272747997194529, 0.1292461154184171, 0.0924249105155468, 0.030671737023762295, 0.05663960127692137, 0.045218286104500294, 0.025644925689058642, 0.11714087426662445, 0.05308218466650162, 0.01599165564402938, 0.029379093886486123, 0.01682374144106039, 0.09093883061515433, 0.051125995349138975, 0.036444780815924914, 0.07172254246792623, 0.06168516392686537, 0.060745793261698315, 0.04663132171013525, 0.03275946035448994, 0.02112742613202759, 0.05931463398571525, 0.026546030371849026, 0.06536690850875207, 0.045430450434131284, 0.040463848904307397, 0.017608428174363713, 0.052573137517486296, 0.01228171623578029, 0.06566808984747954, 0.006807894936563181, 0.04674163454079202, 0.06072669250092336, 0.0597788876454745, 0.017531913172985827, 0.02787822701169976, 0.154507254915578, 0.0759721937190209, 0.10734060300248009, 0.07619132660329342, 15.711113793509346, 71.41289724622453, 33.988332816532676, 44.90190655844552, 28.96795187677656, 19.204263312476023, 78.36436149052211, 59.502670424325125, 59.247018405369346, 68.86046259743827, 60.307230131966726, 56.96959693091256, 4.53646148954119, 0.3389446623623371, 0.12767599895596504, 20.557235649653844, 77.58434282030377, 64.04710497174943, 71.61793858664376, 65.01552404676164, 67.7929413659232, 56.156417982918875, 54.012596470969065, 47.74307707377842, 51.18686832700457, 47.093389238630024, 52.09706497192383, 54.27275092261178, 60.193453380039756, 59.2062463760376, 65.089341708592, 58.13507734026228, 63.9771921975272, 54.56742055075509, 48.01929576056344, 45.46752119064331, 47.324326515197754, 47.0681985446385, 49.36197260447911, 47.463863713400706, 43.78010947363717, 44.05337170192173, 42.34996523175921, 42.19836596080235, 43.397062233516145, 42.63233307429722, 42.758151054382324, 41.21179124287197, 41.54884488242013, 42.5287458556039, 42.72083922794887, 40.70738329206194, 42.472288267953054, 42.81317731312343, 44.96818195070539, 47.07927744729178, 46.05179173605782, 48.343529973711284, 48.169067655290874, 50.036642687661306, 53.79758446557181, 54.54713181086949, 54.73748465946743, 57.79899297441755, 56.36240080424717, 57.78620481491089, 57.7285486630031, 53.39148310252598, 56.440349170139854, 55.22156565529959, 57.88847534997122, 57.05777651923043, 56.60456984383719, 56.05162525177002, 55.160814080919536, 52.29877117701939, 43.93894876752581, 40.04424721854073, 42.64091409955706, 42.392727919987266, 40.82794148581368, 39.777356488364084, 40.263063362666536, 41.095155307224815, 40.70551422664097, 39.85375540597098, 40.989469732557026, 41.75991725921631, 41.71769653047834, 41.75699554170881, 42.45101635796683, 40.58260754176548, 41.907733236040386, 41.67619841439383, 42.040416036333355, 42.33135795593262, 40.82298394611904, 41.75486591884068, 44.27227469852993, 48.23572519847325, 48.58235692977905, 46.923856667109895, 54.475440297807964, 55.03474596568516, 55.14798075812203, 57.314821652003694, 57.72339309964861, 51.36159815107073, 47.723913942064556, 42.389288561684744, 46.242002146584646, 56.00236599785941, 56.6180910382952, 60.76190635136196, 61.310987745012554, 58.40439646584647, 59.964642252240864, 57.93976695196969, 61.65058789934431, 62.75660909925188, 51.52838618414742, 35.769923891339985, 0.24799054435321263, 6.113736876419612, 44.404731682368684, 55.05752216066633, 51.978320258004324, 53.182912077222554, 55.095900535583496, 11.125616260937282, 27.677982330322266, 36.948932443346294, 19.981245619910105, 57.905199663979666, 14.460771560668945, 0.5784725451043674, 0.10660442643399749, 0.09743320462959153, 0.03457812758694802, 0.07849085464009217, 0.01891413819976151, 0.0425248345626252, 0.052798848798764605, 0.062146031696881564, 0.02612251934728452, 0.0279548675420561, 0.05780249834060669, 0.00961325004962938, 0.04111515770533255, 0.05767913388886622, 0.0443193968385458, 0.04565317276865244, 0.04170667060783931, 0.18074283855301992, 0.11830251264785017, 0.1606378188090665, 0.11627305511917387, 0.1712346901851041, 0.07829221351338284, 0.11536699373807226, 0.1293122861534357, 0.23671747211899075, 0.13827992709619658, 0.1579508472766195, 0.1219501540596996, 0.20650188704686506, 0.1719063041465623, 0.10493323539516755, 0.11684986416782651, 0.19884875842503139, 0.16898511589637824, 0.12939062980668886, 0.2906598933041096, 0.271813447454146, 0.25067292898893356, 0.2186916193791798, 28.487763609204972, 80.39686243874687, 47.258565289633616, 56.764305455344065, 41.5539413860866, 13.98581268106188, 76.31636605943952, 65.4638774054391, 63.25144590650286, 76.56426388876778, 65.03170640127999, 64.5156636919294, 4.355547768729074, 0.2569006862384932, 0.12115341824080263, 23.610758747373307, 77.87941891806466, 66.23343903677804, 74.11178602491105, 69.19059930528913, 69.62723105294364, 59.769967624119346, 56.85173463821411, 49.564311095646445, 54.65447800500052, 48.43177556991577, 55.53650317873274, 60.08538804735456, 61.66179534367153, 62.252656255449565, 68.37726402282715, 63.60352502550398, 67.3068106515067, 56.43333148956299, 51.36549956457955, 45.93476670128958, 50.07642807279314, 50.97534779139927, 53.46419252668108, 52.108671937670024, 46.83343628474644, 46.00954668862479, 44.889111450740266, 44.1930513381958, 46.80768278666905, 45.647500378744944, 45.73375531605312, 44.122447218213765, 45.239724499838694, 46.095579283578054, 46.17644936697823, 42.88987152917044, 45.98952545438494, 45.805540629795615, 48.361178398132324, 48.738778250558035, 49.78076832635062, 51.154802390507285, 49.789033208574565, 53.46488387244088, 55.42980316707066, 56.671574796949116, 56.16268178394863, 60.472729274204795, 58.4101356778826, 61.25841072627476, 59.2090881892613, 53.44313948495047, 58.16033751623971, 57.44651780809675, 58.02952378136771, 58.94633511134556, 57.44497183391026, 58.66327244894845, 56.515761443546836, 54.36710051127842, 45.80228539875576, 41.0049398967198, 44.05267688206264, 43.8562582560948, 44.07860061100551, 41.69574022293091, 41.93204150881086, 44.44732066563198, 42.60238633837019, 43.79244252613613, 42.45907279423305, 44.06207432065691, 43.27577100481306, 43.068846702575684, 43.93451929092407, 42.603703022003174, 44.605340072086875, 43.75804199491228, 43.35603659493582, 44.785274096897666, 43.295566422598704, 42.313219683510916, 46.46634210859026, 52.25959723336356, 51.06132827486311, 50.26969569069998, 56.11450644901821, 57.86793647493635, 58.49785668509347, 60.36279487609863, 59.60046631949288, 57.18072836739676, 49.67850821358817, 46.15942628043038, 48.462038448878694, 60.56857967376709, 57.52947235107422, 62.68154770987374, 63.747269357953755, 62.27953883579799, 63.25869287763323, 61.468677112034385, 63.154997961861746, 67.11099651881626, 56.0131322315761, 39.036845275333945, 0.6043311346854482, 7.195103696414402, 50.099575996398926, 61.93422031402588, 53.404580456869944, 55.893230642591206, 52.82110548019409, 6.35740281854357, 48.4155341557094, 45.05758094787598, 32.99751622336251, 65.32900592258999, 26.685275827135357, 0.8439256495663098, 0.177357301648174, 0.14811194022851332, 0.25234877477799145, 0.15602489347968782, 0.11636422308427946, 0.14100959205201694, 0.21092419831880502, 0.16864237428775855, 0.17416411585041455, 0.057529340498149395, 0.20952459770653928, 0.11285974577601467, 0.14359998090990952, 0.14342517671840532, 0.10556580645165273, 0.14959432211305412, 0.1401078054415328], [0.05681030372423785, 0.027290429088420103, 0.06346331244068486, 0.02561692424517657, 0.12296182263110365, 0.10462996416858264, 0.11469335774225847, 0.013503240421414375, 0.028660450662885393, 0.05665377587346094, 0.006994609113982213, 0.035623146154518635, 0.02952946742464389, 0.05262534400182111, 0.02051563181781343, 0.06732642943305628, 0.01610614825040102, 0.005936921025360269, 0.03719065025714891, 0.12346954324415751, 0.048696585531745634, 0.07595214979457003, 0.1013440429898245, 0.8408633396029472, 44.663315841129844, 50.41984278815133, 25.40963694027492, 51.35415315628052, 12.717298303331647, 21.448852811540874, 75.14283616202218, 59.384606633867534, 72.73465306418282, 58.07476350239345, 59.958708490644185, 10.132166300501142, 0.1939267875360591, 0.03627221918265734, 6.858826518058777, 58.48687853131975, 66.99815082550049, 66.82976123264858, 60.01097284044538, 58.06295156478882, 49.81965739386422, 48.39011417116438, 46.178123882838655, 47.0451374735151, 46.536456380571636, 48.71026979173933, 50.10386650902884, 55.37417936325073, 55.72998966489519, 59.539502825055806, 60.769507680620464, 59.94912692478725, 55.076115540095735, 45.067965030670166, 45.24334798540388, 46.08949613571167, 49.14437239510672, 48.5584134374346, 48.06547696249825, 47.15629822867257, 43.352076121738975, 41.40849127088274, 40.44287926810128, 40.986224923815044, 40.00405536379133, 41.094745363507954, 38.02231795447213, 38.70288358415876, 38.61772646222796, 39.46678243364607, 38.91126353400094, 41.062794072287424, 42.618940421513145, 44.34785720280239, 47.84796013150896, 48.11934634617397, 44.995134013039724, 46.19638722283499, 47.44324145998274, 46.39828102929251, 48.934943267277305, 52.998760495867046, 53.49048451014927, 56.08840206691197, 56.1119703565325, 56.886962005070274, 51.29799434116909, 48.27745260511126, 59.18424143110003, 54.09105205535889, 56.211041246141704, 52.27062749862671, 56.00568723678589, 54.394431250435964, 52.22980335780552, 44.34939275469099, 41.187872069222585, 39.46067844118391, 39.25761733736311, 39.87655591964722, 37.758310726710725, 38.309181281498496, 38.29741103308541, 37.092628138405935, 39.21684878213065, 39.40483924320766, 38.51076241901943, 40.036833490644185, 38.954599448612754, 40.72252689089094, 40.72172784805298, 39.43051978519985, 40.10221256528582, 38.77445697784424, 38.873548712049214, 39.5408467565264, 41.25915363856724, 40.376708098820274, 39.33950880595616, 40.51982361929757, 47.24098287309919, 52.42428343636649, 53.855806895664756, 53.137001855032786, 56.389807973589214, 55.49983058656965, 49.527489117213655, 45.23396096910749, 41.082422733306885, 43.0108049256461, 51.487899030957905, 58.99014350346157, 61.94952024732317, 58.661479813711985, 62.04088905879429, 56.552746704646516, 59.438990184238975, 56.91098540169852, 48.235843317849294, 35.11278411320278, 16.074336086000713, 0.1362999483410801, 10.359684194837298, 40.74857221330915, 52.79833970751081, 42.98086166381836, 56.59328596932547, 8.896548168999807, 14.890519380569458, 40.395068713596885, 23.605955805097306, 27.038051503045217, 47.13446004050118, 2.6733515432902744, 0.2949614796255316, 0.06186629206474338, 0.11509188850011144, 0.03534891961940697, 0.044656764449817796, 0.0220981993978577, 0.008045915580753769, 0.018020285359982933, 0.08654163192425456, 0.04546920156904629, 0.07796768378466368, 0.043661146624279876, 0.05356271977403334, 0.014704194817958134, 0.033127294188099246, 0.01795979735574552, 0.016707292957497493, 0.04377592082268425, 0.055730401671358516, 0.04338650957548192, 0.022214025325540985, 0.01044046226888895, 0.03051424226058381, 0.08103806152939796, 0.02874466703672494, 0.036130605531590324, 0.0229628463940961, 0.057415394112467766, 0.07550593838095665, 0.02825924986973405, 0.04216726017849786, 0.05795392021536827, 0.02271520995002772, 0.13632599051509584, 0.03950916709644454, 0.04022780353469508, 0.03776160694126572, 0.02577279900599803, 0.043746767565608025, 0.04609158781490155, 0.08358810469508171, 0.9356826373508998, 52.81603676932198, 52.93048054831368, 26.74109591756548, 48.46027708053589, 12.053988524845668, 37.14751543317522, 74.76340893336705, 63.81962094988142, 77.19675840650285, 63.16560786111014, 67.79096807752336, 11.792737126350403, 0.4196963006896632, 0.07754667316164289, 9.148173706872122, 65.28758771078927, 69.4378717967442, 69.74496132986886, 63.583139010838096, 60.99902057647705, 51.95469638279506, 51.03736046382359, 49.35010160718645, 47.20757940837315, 49.93420886993408, 50.07970067432949, 51.54440178189959, 56.930259704589844, 58.1068502834865, 62.22309167044503, 62.367169516427175, 62.001395498003276, 58.46070466722761, 46.979751450674875, 46.49944680077689, 47.38430336543492, 50.90151970727103, 51.528698853084016, 51.809013502938406, 50.09170716149466, 45.375169209071565, 44.417988845280235, 42.32657412120274, 45.26432459694998, 42.5426526750837, 43.6783253124782, 41.789120537894114, 41.78316593170166, 41.86347321101597, 42.136460985456196, 42.010625634874614, 43.88193184988839, 44.667158194950645, 46.71285377229963, 49.62848465783255, 50.28821611404419, 47.59847811290196, 48.228512968335835, 49.950040340423584, 49.18975108010428, 51.33407981055123, 54.531387192862375, 53.94591808319092, 58.215818881988525, 58.40085983276367, 60.05163369859968, 52.311965806143625, 51.413567202431814, 61.92871734074184, 56.01245478221348, 58.96260779244559, 55.83115891047886, 58.80282006944929, 55.99936090196882, 55.66366216114589, 46.480304513658794, 43.483758381434846, 42.88311093194144, 42.063921792166575, 41.73006432397025, 41.25275434766497, 39.855443818228586, 40.160195282527376, 39.58630187170846, 41.71541404724121, 41.5379501070295, 42.30114024026053, 41.505668776375906, 43.20197418757847, 41.140964780535015, 42.575799056461875, 40.332163197653635, 41.41241352898734, 40.375585964747835, 40.83396904809134, 41.794289997645784, 41.4483322416033, 40.17613097599575, 39.7886438369751, 41.918127741132466, 48.507906981876914, 54.63867780140468, 54.647237982068745, 57.38190998349871, 58.26180900846209, 57.440313066755024, 52.07262120928083, 47.44663912909371, 43.30652373177664, 46.04290151596069, 53.270525387355256, 59.77301093510219, 60.541064807346885, 60.28966508592878, 63.794482367379324, 59.92328657422747, 61.575019291469026, 61.51648071834019, 52.86920091084072, 43.89728389467512, 15.435334580285208, 0.01687714723604066, 11.569296087537493, 47.93290185928345, 54.707690783909385, 50.52160610471453, 56.94285331453596, 21.562202249254497, 13.251899651118688, 37.22088841029576, 32.046130657196045, 31.121909073420934, 57.23220409665789, 2.8661972752639224, 0.2667099413062845, 0.08685084711760283, 0.07582100933151585, 0.05494865129834839, 0.0151410034325506, 0.02076372966569449, 0.029104867351374457, 0.09011127573571034, 0.04769080664430346, 0.01805834608551647, 0.06794891067381416, 0.04831923185182469, 0.08012971348528351, 0.024390735131289278, 0.026373886037617922, 0.04700683656015566, 0.007621031370945275, 0.042312456494463344, 0.1285291210349117, 0.14336343003170832, 0.15425668550389154, 0.155116131529212, 0.25953052512237, 0.14864411524363927, 0.20741712222141878, 0.06928114632942847, 0.12686201477689402, 0.10981587839445897, 0.11900957327868257, 0.14783811063638755, 0.09315966894584042, 0.2240503496889557, 0.15560599310057505, 0.2856972510261195, 0.13650976493954659, 0.1659969426691532, 0.11707881545381886, 0.3132353776267597, 0.17888419542993816, 0.14840641085590633, 0.35883958052311626, 3.2291731238365173, 66.20102569035122, 67.231096131461, 39.814313956669395, 71.24684224809918, 18.95261345590864, 28.911384854997905, 90.94391523088727, 66.72200162070138, 85.64898490905762, 69.27236570630754, 71.9342622756958, 11.988502621650696, 0.6895159951278141, 0.07894609735480376, 11.580348934446063, 69.7785211290632, 73.85040869031633, 76.80303873334611, 67.33955751146588, 64.33382238660539, 53.642695222582134, 55.80068063735962, 52.81760706220354, 50.062385763440815, 52.99771479197911, 54.01357964106968, 55.34594535827637, 59.69736589704241, 61.14769812992641, 64.598055430821, 63.92901338849749, 66.75204563140869, 60.53737531389509, 50.975608348846436, 49.94753551483154, 51.85240847723824, 53.29546594619751, 54.359367166246685, 54.231228487832205, 53.880295821598594, 49.010466711861746, 48.274516991206575, 45.47002601623535, 47.0140130179269, 46.05439731052944, 47.90637016296387, 44.143917151859824, 44.34696088518415, 45.642799922398154, 44.76560027258736, 45.046071256910054, 47.734023571014404, 46.161444732121055, 49.04625340870449, 52.3388796533857, 53.018663610730854, 50.150923183986116, 51.43973759242466, 52.65218435014997, 50.6608966418675, 53.178864751543315, 56.76073408126831, 56.8819488797869, 61.45130661555699, 59.149535179138184, 62.31525257655552, 53.163686411721365, 53.62286506380354, 61.646175793239046, 57.75794996534075, 59.92623955862862, 57.27655097416469, 60.06785774230957, 57.386784144810264, 57.509961809430806, 48.7011433328901, 45.202850409916465, 44.13756649834769, 44.611273833683555, 45.045317377362935, 42.991961411067415, 42.397761889866416, 42.21763331549508, 41.95157984324864, 43.68195227214268, 43.38954428264073, 42.851757185799734, 44.59887824739729, 44.07946566173008, 44.609953675951274, 44.667588983263286, 42.70312826974051, 46.07099308286394, 42.32343700953892, 43.686235836574006, 43.53384099687849, 45.63120685304914, 44.73091833932059, 42.29430668694632, 44.842068672180176, 51.772139413016184, 56.89910398210798, 58.23531552723476, 59.538926124572754, 61.761425563267295, 59.72577708108084, 55.4663576398577, 49.21699149268014, 45.727352551051546, 49.195990562438965, 56.09732007980347, 63.0182991027832, 63.08438341958182, 63.00012261526925, 66.6462801524571, 61.07267842973982, 65.20473739079067, 62.69448525565011, 64.25047874450684, 44.77509151186262, 17.140408618109568, 0.1818678089018379, 12.623345630509512, 51.17798158100673, 62.812882559640066, 52.256157875061035, 66.37695407867432, 14.439637746129717, 21.025730098996842, 58.52966553824288, 38.051969391959055, 41.38398844855172, 65.32416302817208, 8.69431129523686, 0.7818984836339951, 0.30213131489498274, 0.26586177253297394, 0.12261604118560042, 0.18210991019649164, 0.15672112469162258, 0.15482588138963493, 0.08997171465307474, 0.11168765795550176, 0.12886969133147172, 0.22513819060155324, 0.12398901608373437, 0.14774653555027076, 0.1510268316737243, 0.10257271384554249, 0.14023736491799355, 0.10256354683744055, 0.2051661094384534], [0.0329943793559713, 0.034998371465397735, 0.13578443814601215, 0.06987012829631567, 0.0609490212851337, 0.05738595247800861, 0.0561156161794705, 0.0029582360501600696, 0.019891820648419004, 0.06701691568429981, 0.026823242461042743, 0.05178071718130793, 0.044544012285768986, 0.06756330600806645, 0.014468597281458122, 0.0653514311249767, 0.022328478916149055, 0.03564302383788994, 0.12019775594983782, 0.0305336246133915, 0.06030970559056316, 0.03957097824396832, 0.07973493502608367, 0.018666432205853716, 21.506352628980363, 59.98867607116699, 36.1470582144601, 40.17114216940743, 52.945165566035676, 10.431351389203753, 65.53918198176792, 69.07250077383858, 65.24327210017613, 61.984372411455425, 55.941471985408235, 23.77939326422555, 0.42959808079259737, 0.4233564542872565, 1.9047344326972961, 48.3422132900783, 70.85975115639823, 64.41879190717424, 63.43077891213553, 57.90776354925973, 59.26424993787493, 59.854186739240376, 58.68888350895473, 54.625601291656494, 51.90228612082345, 46.97354323523385, 49.61213902064732, 51.50502634048462, 54.483270917619976, 57.22437347684588, 60.602653639657156, 59.22804287501744, 54.21671370097569, 45.29957628250122, 43.25508621760777, 47.2532742364066, 49.55041469846453, 53.62468201773507, 54.28724486487252, 50.33061054774693, 48.0477625301906, 40.84320667811802, 42.41661582674299, 40.43828303473336, 41.63888658796038, 39.720433371407644, 39.638309138161794, 37.79698092596871, 40.75371388026646, 39.56740971973964, 40.32782752173287, 41.971507276807515, 41.52414403642927, 47.53440877369472, 54.43234409604754, 50.03877578462873, 50.885260922568186, 50.32232482092721, 47.730448722839355, 50.60350799560547, 51.67711932318551, 51.86060735157558, 53.66426590510777, 55.1325592313494, 56.74491650717599, 54.95081867490496, 57.34735311780657, 45.87725646155221, 47.927006312779014, 58.00753968102591, 52.32475396565029, 53.74756785801479, 55.187714031764436, 51.47827230181013, 49.75597367967878, 45.370718887874055, 40.26575926371983, 39.47553368977138, 40.380234309605186, 41.58396107809884, 40.5709866796221, 38.6269154548645, 39.04890387398856, 38.95343215124947, 38.75983796800886, 40.00467722756522, 38.59946312223162, 38.91700622013637, 39.41897535324097, 40.04939930779593, 39.40309524536133, 39.5697477885655, 40.99699463163103, 42.29998336519514, 40.23745925085885, 40.64967155456543, 40.39742067881993, 41.57989638192313, 42.535496030535015, 41.85755334581648, 50.98392881665911, 52.22024611064366, 56.61637135914394, 57.03261709213257, 58.064765044621055, 54.50711713518415, 50.23435367856707, 46.61650310243879, 42.835387229919434, 44.34393147059849, 49.52531780515398, 57.307404450007844, 63.002540588378906, 63.58074883052281, 57.68244736535208, 62.623446873256135, 54.32288217544556, 42.308706828526084, 27.289124659129552, 23.51177818434579, 3.079680242708751, 0.23901672874178204, 15.516956806182861, 47.03478118351528, 55.55229990822928, 65.55347442626953, 45.56527887071882, 5.457701861858368, 38.42116887228829, 34.016983713422505, 20.09774259158543, 36.79041624069214, 31.28275987080165, 0.03196536064414041, 0.047481461627674956, 0.015203314999650632, 0.1254550859864269, 0.015990524186885784, 0.038413797837815115, 0.028957682927804332, 0.04572317044117621, 0.039101737351822, 0.039491297876728435, 0.06298180363540139, 0.03401846172554152, 0.029435059454824244, 0.0497102557814547, 0.1557655573955604, 0.029379704568002905, 0.006663929313487772, 0.04907095026490944, 0.03365208674222231, 0.058823137144957266, 0.029460948958460773, 0.12899714734937462, 0.04315290693193674, 0.013985264065143253, 0.036518751310982873, 0.034714241711688895, 0.03386115695216826, 0.005605261165848268, 0.02451519202440977, 0.06089378174926553, 0.013129598328045436, 0.06196634205324309, 0.014893453501697098, 0.03917727526277304, 0.02365702503759946, 0.04797396270026054, 0.022820328595116735, 0.04887774081102439, 0.03595817621265139, 0.0352650662618024, 0.04470447903232915, 0.14861735382250377, 0.06213051360100508, 23.570556470326014, 70.82448210035051, 33.11634431566511, 48.73087467466082, 38.31456960950579, 17.154529094696045, 79.29350239889962, 68.88619872501918, 72.79510934012276, 65.58344200679234, 63.70221723828997, 24.81490240778242, 0.257247906178236, 0.4940650686621666, 2.39763833795275, 54.681982449122835, 73.1175057547433, 67.73616068703788, 66.96356964111328, 59.564523288181846, 61.38014316558838, 59.94372122628348, 61.67786652701241, 58.35359123774937, 53.383888721466064, 49.827133655548096, 52.42455441611153, 51.47733776909964, 54.43428264345442, 60.425592694963726, 61.901786123003276, 60.64123698643276, 57.106935024261475, 48.947773115975515, 45.41903666087559, 50.043253898620605, 50.733769348689485, 55.175339290073936, 57.55521542685372, 53.00073378426688, 48.77570445196969, 43.08192668642317, 45.21155997685024, 43.295250279562815, 43.73524495533535, 43.750874928065706, 42.617140838078086, 40.899650369371685, 43.622017111097065, 42.02485901968819, 41.935157775878906, 45.2463287625994, 43.24057490485055, 48.37217739650181, 54.97091633932931, 51.77809749330793, 52.31699630192348, 50.61697013037545, 50.190385477883474, 51.599160534994944, 52.34846121924264, 53.390089988708496, 56.80984047480992, 56.928512232644216, 59.46189144679478, 55.82522514888218, 60.44142069135393, 46.98802675519671, 54.366853850228445, 60.90064798082624, 53.80704096385411, 56.864435945238384, 58.69569969177246, 55.64546830313546, 52.76246268408639, 48.22601161684309, 44.02882719039917, 41.70707968303135, 42.23098080498831, 42.900724615369526, 43.49146045957293, 41.68034301485334, 39.601761613573345, 41.91393102918352, 41.05214248384748, 43.551878520420615, 41.84783281598772, 41.52770846230643, 41.45078842980521, 42.903132166181294, 41.84005083356585, 42.68302713121687, 43.64851754052298, 44.03346858705793, 42.30908203125, 40.917941502162385, 41.61498131070818, 42.8227276120867, 44.04512766429356, 43.66696848188128, 50.00585521970476, 53.64036062785557, 56.60837745666504, 57.28881801877703, 59.17954444885254, 55.25189801624843, 51.962954316820415, 48.70493357522147, 43.92825548989432, 47.008711542402, 53.11571952274868, 58.92046001979283, 64.00891767229352, 64.18929290771484, 59.980393818446565, 65.5926900591169, 60.003385407584055, 49.265493392944336, 34.434209142412456, 27.404617616108485, 2.3716981070382253, 0.33192649324025425, 17.759071009499685, 51.92365877968924, 59.80602877480643, 66.77413395472935, 51.754098415374756, 13.084428089005606, 20.885543244225637, 40.74108900342669, 22.416596174240112, 43.84579774311611, 33.57275758470808, 0.21920362833355153, 0.05842861652906452, 0.023973873749907528, 0.05072893022692629, 0.02489938703365624, 0.0540629120410553, 0.011969552807775992, 0.05751423630863428, 0.028735354143593992, 0.012922760498310839, 0.017218050014759814, 0.022313854790159633, 0.01706590210752828, 0.07537708458091531, 0.06340712295579058, 0.008083601415689503, 0.0623778531860028, 0.052319277210959365, 0.005344531540426293, 0.11392640961068017, 0.1687411554157734, 0.18998300630067075, 0.16395951913935797, 0.16297784181577818, 0.15184993536344596, 0.1227815223059484, 0.15074838804347174, 0.07358085989419903, 0.20624616076903685, 0.1497051404522998, 0.1297773133431162, 0.12526592399392808, 0.12688949544514927, 0.1123519708801593, 0.16026804436530384, 0.11318572078432355, 0.12100845601941858, 0.23032341950706073, 0.09213914549244301, 0.12820221643362725, 0.19263913163117, 0.19239812956324645, 0.15186816081404686, 37.87828179768154, 79.4236421585083, 50.485604013715474, 60.75982883998326, 70.59378106253487, 13.844104170799255, 79.20460714612688, 78.04623821803501, 76.05378668648856, 72.41292367662702, 68.99497277396065, 27.80712502343314, 0.9666203601019723, 0.3678750885384423, 3.4614151418209076, 60.93236650739397, 77.577561378479, 71.08376802716936, 70.72868033817836, 62.285104342869346, 66.02477073669434, 65.38511957441057, 63.87002318246024, 61.91962909698486, 57.35413108553205, 52.69468995503017, 55.889068671635215, 55.60959127971104, 58.79644857134138, 64.34184755597795, 65.26055921827043, 63.00410393306187, 60.291443824768066, 50.23635823386056, 48.447297845567974, 52.73043843678066, 52.790672370365684, 59.24362073625837, 61.68610709054129, 54.70320919581822, 52.86843660899571, 44.825267927987234, 48.26516124180385, 47.386891569410054, 47.1529735156468, 45.167633465358186, 45.57272733960833, 43.11324569157192, 47.944998673030305, 45.883308342524934, 46.34455060958862, 49.80090420586722, 47.052075249808176, 52.98106343405587, 59.02129922594343, 55.01546818869454, 55.220728397369385, 54.57290267944336, 52.31710399900164, 54.49571166719709, 55.578984464917866, 57.30478497913906, 60.198796544756206, 59.74066012246268, 58.29345457894461, 57.97694328853062, 60.4932473046439, 47.26643759863717, 55.63834292548043, 60.87751047951834, 56.17267329352242, 58.43741430555071, 61.708577564784456, 56.326892035348074, 54.17621612548828, 49.90335539409092, 45.35381044660296, 43.222780568259104, 45.17298705237252, 45.82141031537737, 45.45719269343785, 42.887328488486155, 42.78547831944057, 43.80520984104702, 42.41311393465315, 45.33822216306414, 43.877995695386616, 42.47851037979126, 43.72195652553013, 45.779516151973176, 43.66606869016375, 44.814001423971995, 46.70184782573155, 45.920046942574636, 44.53527443749564, 43.828625270298545, 44.59437928880964, 45.05121292386736, 46.836073126111714, 45.69393866402762, 53.457112312316895, 55.659333433423726, 59.798823492867605, 60.482943126133506, 64.27869537898472, 57.21954795292446, 55.49305609294346, 50.29902056285313, 46.963235582624165, 48.85961437225342, 55.68892581122262, 61.54006290435791, 66.67624078478131, 63.667365074157715, 62.32623767852783, 65.71983514513288, 61.99650396619524, 58.728752272469656, 37.46568039485386, 26.58064811570304, 3.7863487345831732, 0.37348418469939915, 19.737007754189626, 56.84902484076363, 65.08992535727364, 75.25501482827323, 56.953053270067485, 8.222385304314749, 53.97195298331124, 50.358976568494526, 31.833651270185197, 51.00676754542759, 48.59094837733677, 0.4892755342381341, 0.1784502315734114, 0.07460337824055127, 0.19243893665926798, 0.1458791528961488, 0.0997575263359717, 0.1298385172017983, 0.12302403072161333, 0.13187788134174688, 0.1791272602443184, 0.16928889602422714, 0.11972462705203465, 0.114294080595885, 0.23475683161190578, 0.1992017323417323, 0.10997971746006183, 0.14309031968670233, 0.13891369237431458, 0.09589466040155717], [0.014485374059794205, 0.07270925452134439, 0.03975978400558233, 0.06359575569097485, 0.063498684471207, 0.06723472542528595, 0.010978284391707607, 0.03639843348147614, 0.023975410631724765, 0.05750041455030441, 0.1331142671406269, 0.020319781166368296, 0.0808186029483165, 0.07770300762993948, 0.056865404160427194, 0.08628845015274626, 0.019298270444518754, 0.019833895810214535, 0.04079161524506552, 0.03670142990137849, 0.17430879308709077, 0.08376930068646159, 0.3303495778569153, 0.31717416484441074, 5.0437138591493875, 55.847403798784526, 44.54880952835083, 23.54153037071228, 48.024354049137656, 21.594947372164043, 13.91426534312112, 79.76276288713727, 61.717950684683665, 69.44593170710972, 62.058780670166016, 43.28690549305507, 0.5695908474070686, 0.27935672125646044, 0.9199047982692719, 47.105169909340994, 73.51604052952358, 69.29358550480434, 67.05350017547607, 66.89155156271798, 67.17273821149553, 65.44459615434918, 66.98717961992536, 64.93703719547817, 60.413217953273225, 51.36789321899414, 47.59385756083897, 48.61214733123779, 55.07066467830113, 56.4231766973223, 59.50112097603934, 59.75423690250942, 57.779433795383994, 45.76542173113142, 44.08142505373274, 48.12374455588204, 52.502436774117605, 53.41880341938564, 54.521680559430806, 54.84122821262905, 55.46125766209194, 44.10402406964983, 42.846184730529785, 42.35096229825701, 41.052416937691824, 39.62718507221767, 39.88070746830532, 39.10886335372925, 40.87637390409197, 40.31537634985787, 41.90845584869385, 41.451139313834055, 42.009305477142334, 53.12265729904175, 55.7342072214399, 54.86611665998186, 51.772552830832346, 50.58070748192923, 53.3621825490679, 52.03360707419259, 51.15003940037319, 50.78872959954398, 53.01521035603115, 57.01813357216971, 55.93816464287894, 55.85454307283674, 55.31155872344971, 59.516622407095774, 49.03638001850673, 48.76948928833008, 53.13804061072213, 52.63834353855678, 52.23351716995239, 52.04818092073713, 49.999254431043354, 43.44678354263306, 41.82080432346889, 40.39134100505284, 40.51628351211548, 39.629700320107595, 40.03121934618269, 37.971978255680625, 39.705529485430034, 38.605699130467, 38.59836878095354, 39.46498285021101, 39.787990706307546, 39.58057655606951, 39.21804387228829, 39.057467528751914, 41.373371601104736, 40.55248015267508, 40.56673090798514, 39.62381519590105, 41.15188387462071, 40.07501036780221, 42.28199447904314, 39.6834967476981, 41.18419647216797, 47.35492985589163, 53.980874470302034, 56.042248657771516, 57.42451286315918, 56.640214102608816, 56.65501723970686, 54.354308877672466, 49.33211619513375, 45.934572151729036, 42.507328033447266, 44.77027293613979, 48.114666734422954, 57.35439511707851, 56.72623627526419, 61.758090427943635, 63.82176794324602, 59.772079876491, 43.1147187096732, 18.939276388713292, 18.766761302947998, 8.431810958044869, 0.1882972131882395, 1.5993308148213794, 15.207692486899239, 47.13027375085013, 52.130187034606934, 55.75914083208357, 11.306370173181806, 15.464817523956299, 42.68409367970058, 24.766292810440063, 26.533105066844396, 53.1191588810512, 8.742764558110919, 0.4859481613550867, 0.053712709939905574, 0.14064817715968403, 0.021172580941181098, 0.050557338898735385, 0.025287051053185548, 0.12082782999745437, 0.03874296535338674, 0.04293507004954985, 0.06264747586101294, 0.021810006915724704, 0.023805530908118402, 0.03778382557045136, 0.05878679480935846, 0.0754655044791954, 0.051404289701687436, 0.02010221400165132, 0.024768953943359, 0.047550936828234365, 0.08471790621323244, 0.09648664827857699, 0.047122703199940066, 0.029045671956347566, 0.02275361672842077, 0.07060276969735112, 0.021868262539750764, 0.027743169705250433, 0.05561710667929479, 0.020206984897543277, 0.1058016720094851, 0.06620141158678702, 0.030005771866334335, 0.030866123735904694, 0.033160576330763955, 0.09926030944500651, 0.06095989141613245, 0.027773476471858363, 0.050277402491441796, 0.034245217950748544, 0.0922868964927537, 0.06393371362771307, 0.11541721890015261, 0.2793956420251301, 5.692385954516275, 67.06019823891776, 47.01979739325387, 27.68638791356768, 52.3744683265686, 19.11240291595459, 34.48430218015398, 83.28624303000313, 69.10975701468331, 73.15995229993547, 68.79962417057583, 48.28461619785854, 0.7263830825686455, 1.2233835480042865, 1.4387462202991759, 52.339928831372944, 76.97563893454415, 72.4640554700579, 68.14399909973145, 69.80197824750627, 68.12207753317696, 69.35235336848667, 69.22111579350063, 67.8365899494716, 61.48037787846157, 54.80386774880545, 49.71741465159825, 52.29440770830427, 56.55409465517317, 58.32579149518694, 62.357247488839285, 62.136023793901714, 58.19740268162319, 49.20957429068429, 45.66341175351824, 50.045800413404194, 54.21751274381365, 55.63288858958653, 58.80828135354178, 57.211630480630056, 57.344827447618755, 46.742088317871094, 45.233248778751914, 45.39337348937988, 44.5055639403207, 42.40024239676339, 43.04063354219709, 41.12909378324236, 42.538035597120015, 42.703277656010215, 45.80079501015799, 42.95563275473458, 44.68876361846924, 54.533231939588276, 57.97279173987252, 57.534433364868164, 53.59091029848371, 53.291696548461914, 53.20449318204607, 52.18925019672939, 53.480162961142405, 54.63850062234061, 55.398671763283865, 59.33833857945034, 57.26379755565098, 57.98567022596087, 58.52088301522391, 64.63400541033063, 50.054888657161165, 53.99913781029837, 56.49114745003836, 55.05414881025042, 57.53715705871582, 54.91752290725708, 53.864228112357004, 47.519094944000244, 45.51729461124965, 42.73604883466448, 44.0200411932809, 42.577807085854666, 42.75923497336251, 40.211149896894185, 42.513636997767854, 42.42856672831944, 40.07527092524937, 42.360314573560444, 41.87133509772164, 41.36348778860909, 42.95321478162493, 40.4924442427499, 42.09736694608416, 42.6805431502206, 42.092947891780305, 42.63726282119751, 43.04669237136841, 43.081120695386616, 44.39090476717268, 42.247138840811594, 43.1137181690761, 49.35297816140311, 56.775478158678325, 58.236062458583284, 58.651321547372, 57.99745784487043, 59.14393493107387, 56.12709311076573, 50.11002608707973, 47.833341121673584, 44.248560496738975, 45.21609020233154, 49.62761613300869, 58.44236837114607, 61.17146791730608, 65.329923084804, 64.09554086412702, 58.663925579616, 50.87589822496687, 22.03768311228071, 24.732932771955216, 6.757549141134534, 0.041329126938113143, 1.7303600524153029, 19.02632863180978, 50.79719945362636, 61.63425963265555, 57.26360648018973, 24.275473799024308, 15.022559472492762, 35.495782715933665, 31.21100582395281, 26.36193445750645, 63.2939202444894, 7.922390750476292, 0.5243668683937618, 0.026677722144605856, 0.09136003801333052, 0.0005009746497047932, 0.023970248676570396, 0.010330396255345216, 0.03188279989574637, 0.06227481085807085, 0.030454246194234917, 0.021364228068185703, 0.02746056156632091, 0.011047880032232829, 0.03390271722206047, 0.015034341120294161, 0.0383998980479581, 0.03129456092470458, 0.03740534552239946, 0.039740405045449734, 0.038187526765146425, 0.14965707303157874, 0.2197759590510811, 0.11334850812064749, 0.22997348542724336, 0.1493292591933693, 0.1900846372757639, 0.11639349508498396, 0.274278103773083, 0.15443637514753, 0.08974995583828006, 0.2984129158513886, 0.2125712199402707, 0.18217617592641286, 0.09713421495897429, 0.2210607651088919, 0.2782294846006802, 0.2322803416422435, 0.17658888788095542, 0.15631605285618985, 0.13293887940900667, 0.3219359607568809, 0.43499482263411793, 0.6288372682673591, 0.9641923989568437, 10.176322971071516, 79.42560849870954, 58.51215607779366, 36.97193445478167, 69.48896190098354, 29.921951702662877, 21.248666524887085, 96.05485725402832, 70.72758947099958, 82.36677401406425, 73.57683031899589, 53.350224699292866, 0.8613765388727188, 1.4515211348022734, 2.0402714226927077, 56.63337707519531, 78.18962819235665, 79.4588347843715, 70.5329704284668, 76.26414339882987, 72.7614244733538, 73.8502002443586, 72.53904737745012, 71.78668253762382, 65.96429361615861, 59.408994810921804, 51.90910925183977, 55.418102400643484, 59.44998918260847, 60.90064798082624, 64.8510810307094, 65.87805257524762, 62.93533761160714, 51.165787492479595, 49.347169467381065, 51.191898822784424, 56.821277209690635, 57.47502279281616, 61.17817987714495, 59.55032811846052, 62.01887021745954, 50.022638593401226, 48.19859402520316, 48.00456557955061, 47.35070187704903, 44.37602867398943, 46.42836325509207, 43.66541903359549, 46.00567306791033, 45.55323764256069, 48.7279703276498, 46.19766916547503, 47.39950949805123, 56.85219669342041, 62.94623933519636, 60.962778772626606, 58.03470713751656, 54.786344391959055, 57.01682383673531, 54.5867052759443, 56.7609737941197, 54.96504858561924, 58.12263659068516, 61.23643357413155, 59.07891368865967, 58.084567410605295, 59.10055037907192, 61.419706208365305, 52.36046770640782, 55.64149393354143, 58.96573448181152, 55.43281173706055, 57.840414660317556, 55.17085075378418, 55.21931096485683, 49.15627465929304, 46.622440338134766, 44.66179071153913, 45.206546851566856, 43.43896334511893, 45.893532616751536, 42.967944962637766, 43.97263363429478, 45.13268402644566, 43.33558457238333, 44.052593503679546, 45.170173031943186, 44.86279514857701, 44.68981974465506, 44.317045416150776, 45.65494189943586, 44.44274180276053, 43.9889931678772, 44.85879646028791, 46.38844585418701, 45.06377526691982, 45.85464702333723, 43.814794881003245, 44.77613721575056, 52.055841309683665, 59.07620389120919, 61.664303643362864, 60.734127453395296, 59.713096618652344, 61.98918751307896, 58.90989875793457, 52.04149327959333, 51.61169161115374, 47.094931738717214, 49.38008655820574, 52.97832236971174, 61.184308188302175, 63.317592757088796, 65.99219063350132, 64.98372214181083, 61.18293244498116, 57.944721017565044, 28.850405727113994, 25.077539103371755, 12.02735607964652, 0.18971753625997476, 2.8454825239522115, 21.867702381951467, 58.698430333818706, 62.7939487184797, 66.84041282108852, 18.38909023148673, 20.183561529432023, 64.1505080631801, 37.70248542513166, 39.956164905003135, 68.66370350973946, 17.01327395439148, 1.0029494506972176, 0.16101698417748722, 0.31662740132638384, 0.16694469324180058, 0.17305077559181622, 0.08697093424520322, 0.13310286775231361, 0.1710179118173463, 0.18474878716681684, 0.1495855147285121, 0.04567313866157617, 0.09178066865674087, 0.12175309391958372, 0.08836856032056467, 0.19386280168380055, 0.13130436997328485, 0.08852178031312567, 0.11834813734250409, 0.16988040214138372], [0.03704215965366789, 0.06826546761606421, 0.05224163584145052, 0.07580350991338491, 0.03590470765318189, 0.019487369672528336, 0.038059850223362446, 0.07084603807223694, 0.049993639146643024, 0.030079074004398923, 0.049367446319333146, 0.03192434659493821, 0.06787959832165923, 0.029318694091801132, 0.032729906761752706, 0.18099465646914073, 0.022255984234756658, 0.0980394281713026, 0.06259833635496241, 0.041026629241449494, 0.04447822153036084, 0.1217645068785974, 0.05012808407523802, 0.1997363500829254, 0.1278028307216508, 27.60196556363787, 57.95163794926235, 39.49887268883841, 37.540953704289024, 53.30490507398333, 5.899392766611917, 38.42919404166085, 73.25651141575405, 61.29821695600237, 60.514689445495605, 46.265146596091135, 6.835126646927424, 1.5125663791384016, 0.19343179623995507, 40.25605957848685, 76.03178868974958, 64.54328972952706, 74.272463117327, 65.00662340436662, 68.26403617858887, 69.7595386505127, 71.82924025399345, 69.65671225956508, 64.31144223894391, 54.70674235480172, 50.21449225289481, 50.69711760112217, 54.44302347728184, 57.52352121898106, 59.36110087803432, 59.45052419389997, 56.42372213091169, 47.04650626863752, 44.89463526862008, 48.01154157093593, 54.13075406210763, 56.338314873831614, 55.07732800074986, 57.04602364131382, 55.61227675846645, 52.61111354827881, 47.5088324546814, 44.97153098242623, 40.54780748912266, 41.45835154397147, 40.7179410798209, 40.93070534297398, 40.25719560895647, 40.50175830296108, 40.29374313354492, 42.30000420979091, 44.760079928806846, 54.902924742017476, 57.22277886526925, 55.6749529838562, 56.0643995148795, 50.15395607267107, 50.91426270348685, 55.63145726067679, 56.01533828462873, 54.96767153058733, 54.46048777444022, 55.85493912015642, 54.67607648032052, 52.954503944941926, 55.70813758032662, 56.2726092338562, 61.7169223512922, 50.90494516917637, 51.73430299758911, 56.177418913160054, 49.150712626320974, 50.88214465550014, 45.67671060562134, 45.00728293827602, 39.88140228816441, 41.0924003464835, 40.350683620997835, 40.45879064287458, 40.26648882457188, 39.22154923847744, 40.565424646650044, 41.016446113586426, 39.27441808155605, 40.149828570229666, 41.149771622249055, 39.95204809733799, 38.80060652324131, 39.46543100902012, 40.05115720203945, 40.3716914994376, 41.79475900105068, 42.06602362224034, 43.22820711135864, 43.5903958593096, 40.921446868351524, 39.291305678231375, 40.04153394699097, 48.90068517412458, 53.63056019374302, 55.15111092158726, 58.99850913456508, 58.61703218732561, 55.97109910420009, 55.07451398032052, 50.94365010942732, 46.35751594815935, 45.559577873774934, 45.188161918095176, 47.52243702752249, 54.094039780753, 59.29676750728062, 57.45321934563773, 62.705887249537874, 59.9990427834647, 26.188092265810283, 13.175028256007604, 12.738512890679495, 0.3985864520072937, 0.05037955254582422, 1.2700692542961665, 24.290042434419902, 49.751697063446045, 55.852496828351704, 33.169393811907085, 4.78206684759685, 41.24971103668213, 32.22464724949428, 20.745983464377268, 39.63651302882603, 40.04076617104666, 0.5394057556986809, 0.03866613144055009, 0.07124109473079443, 0.054085290125970326, 0.05315611784213355, 0.044401686172932386, 0.01557060600524502, 0.03272871932547007, 0.017925643295581852, 0.02914108755066991, 0.02565456597533609, 0.0771563866042665, 0.03961108644892063, 0.01955612562596798, 0.003618795615953526, 0.012428275558964481, 0.017130644526332617, 0.03274524165317416, 0.012123229963305806, 0.0763815063983202, 0.06176244906548943, 0.024555434240028262, 0.02634163187550647, 0.012126950879714318, 0.027238580531307628, 0.053123592266014645, 0.04741089398573552, 0.06060901417263916, 0.047351963219365904, 0.012424637763095754, 0.031620902341923544, 0.010470385663211346, 0.06949030474892684, 0.023364408507144878, 0.025965572501133596, 0.11130179544644696, 0.055286188543375046, 0.02482994575984776, 0.030688537550824027, 0.04656202971403088, 0.029354999107973914, 0.13294901672218526, 0.026917000733582035, 0.07075038499065808, 0.08264715982867138, 30.153250285557338, 68.93539197104317, 35.624119418007986, 49.709670884268625, 39.89270005907331, 10.980362432343618, 63.81093570164272, 70.68395478384835, 72.35851233346122, 63.905146326337544, 54.8125946862357, 7.708867396627154, 1.3575136363506317, 0.20824344216712884, 46.418562820979524, 75.52994809831891, 67.69575691223145, 76.97518730163574, 67.30954824175153, 70.96338353838239, 69.88833740779332, 71.97082369668144, 69.68631853376115, 66.52794538225446, 57.5921242577689, 51.86421694074358, 52.56288610185896, 56.48593282699585, 59.140009198869976, 62.13292489733015, 60.97199208395821, 59.52781595502581, 48.74247816630772, 47.355044501168386, 49.73078645978655, 56.2263377053397, 58.82853535243443, 59.44288117544991, 57.85759060723441, 60.06255626678467, 54.93526513235909, 50.456602232796804, 47.56530046463013, 44.12064068658011, 42.97814839226859, 43.937718936375205, 42.535360540662495, 43.06141907828194, 43.153930868421284, 42.87674290793282, 44.402032307216096, 44.84165872846331, 57.028986658368794, 60.271092551095144, 59.44368716648647, 58.722380774361746, 53.66618013381958, 54.23148209708077, 58.11788054874965, 57.65930986404419, 58.187209674290244, 58.94693265642439, 59.01825591496059, 57.06893880026681, 56.944399288722444, 58.02796738488333, 59.53003243037632, 66.03599902561733, 53.69017573765346, 55.30293600899832, 57.23029334204537, 53.246592317308696, 53.14403690610613, 50.612474645887104, 48.435729094914024, 44.56745849336897, 43.06281566619873, 41.54098646981375, 42.53201845714024, 42.86022356578282, 40.943969454084126, 42.13457454953875, 42.15185819353376, 41.923095703125, 42.26601709638323, 43.06809629712786, 42.35141740526472, 40.27731759207589, 41.400674547467915, 41.367076533181326, 42.37376281193325, 43.62633889062064, 43.501465865543906, 45.70203331538609, 45.52667120524815, 42.664329528808594, 42.04064185278756, 41.539676734379356, 51.89524064745222, 54.0078056880406, 56.8157742364066, 59.21316678183419, 59.637611389160156, 58.28952884674072, 55.85597440174648, 53.41756664003645, 49.61973340170724, 46.22001804624285, 46.141319274902344, 48.85899945667812, 55.312267439705984, 61.930718421936035, 60.10398837498256, 63.6925870350429, 63.53964328765869, 34.35298122678484, 22.25756754193987, 11.673156891550336, 0.3586601758641856, 0.4727552149977003, 1.0897997617721558, 29.96783413205828, 54.44453818457467, 62.34517151968819, 40.893869468144004, 13.651266472680227, 23.568511962890625, 36.84921884536743, 23.62279302733285, 42.931258474077495, 41.6397134235927, 0.41194164965833935, 0.03313211178673165, 0.05053121190784233, 0.031102328561246395, 0.02769264598776187, 0.06021778445158686, 0.056312540612582646, 0.055002564298255105, 0.008524531282351484, 0.003270354737261576, 0.04586516746452876, 0.026505168993026018, 0.06946648816977229, 0.02930951351299882, 0.01676559607897486, 0.03710871036829693, 0.05860215186008385, 0.048623069655150175, 0.03642598200323326, 0.024076714213671427, 0.10993934462645225, 0.1271239835768938, 0.1041844312899879, 0.1478174424597195, 0.1501243800989219, 0.09707297717354127, 0.16428505309990474, 0.12406550055103642, 0.11478863762957708, 0.0755584773474506, 0.1454013828188181, 0.11893061894391264, 0.20334739131586893, 0.11229488572904042, 0.15932843621288026, 0.2669414303132466, 0.13867563514837197, 0.19599061964878015, 0.12143420960221972, 0.1471760640186923, 0.14741759534393037, 0.327038544097117, 0.14171427781028406, 0.2797369451395103, 0.2700375041791371, 48.55190297535488, 74.17866938454765, 57.192311014447895, 55.90591805321829, 76.02274213518415, 6.635362897600446, 54.73260007585798, 81.41471099853516, 74.05881295885358, 70.08244228363037, 58.75693416595459, 7.5984770229884555, 2.8671168259211948, 0.4770869282739503, 48.87506716591971, 76.912111554827, 68.61751883370536, 80.95961093902588, 72.15796647753034, 74.32993166787284, 74.57420253753662, 75.51665619441441, 73.2254251752581, 70.69662829807827, 62.72889968327114, 56.40623351505825, 56.683140073503765, 60.86818599700928, 63.41401290893555, 67.15865421295166, 63.25357205527169, 63.28381061553955, 51.56523248127529, 50.08186156409127, 52.85066311700003, 59.28444835117885, 61.89924308231899, 61.422124181474956, 62.29731232779366, 61.53560216086251, 57.875947747911724, 55.227402142116, 51.48850005013602, 46.085778849465505, 45.89453315734863, 46.38028172084263, 45.275115149361746, 47.28049727848598, 46.092397008623394, 47.012824875967844, 46.747403689793174, 48.08105482373919, 58.79487827845982, 63.848205838884624, 62.10240146092006, 62.251627922058105, 55.51500545229231, 54.72411979947771, 59.47248050144741, 59.99292836870466, 61.780352456229075, 58.94311114719936, 61.733660561697825, 57.81860773903983, 57.36620705468314, 58.14358193533761, 60.646753856113975, 62.542222431727815, 55.70724473680769, 57.421962874276296, 59.24078587123326, 52.61066538946969, 54.81694425855364, 49.60023675646101, 51.266425200871055, 44.95654371806553, 44.71664326531546, 43.46047496795654, 44.86852741241455, 45.36595242364066, 43.37294503620693, 43.872437136513845, 45.03341163907732, 44.08103248051235, 44.81392846788679, 45.25183173588344, 43.73255600248064, 42.83853128978184, 43.79442623683384, 44.4931822504316, 44.08004583631243, 46.80591099602835, 47.235608441489084, 48.92793600899832, 48.26138489586966, 44.42885930197579, 43.27660131454468, 42.76467888695853, 53.41128199441092, 57.227597440992085, 59.37558787209647, 61.871728215898784, 63.01379667009626, 60.57681328909737, 60.470373834882466, 56.02217878614153, 52.77003969464983, 49.207010405404226, 48.358246258326936, 51.011485372270855, 59.183657782418386, 63.86162975856236, 63.7782096862793, 66.6211485181536, 66.75715950557164, 40.74087013517107, 23.901165655681066, 18.677569014685496, 0.9320680541651589, 0.26526083477905815, 3.0989276213305335, 31.3665759904044, 60.09601879119873, 65.45524079459054, 44.667741843632285, 7.8068274429866245, 58.4425698689052, 49.83705915723528, 34.559783935546875, 50.61463206154959, 60.317784445626394, 2.4157557657786777, 0.2712429352104664, 0.13630419597029686, 0.17044389833297047, 0.17373399250209332, 0.11263452643262488, 0.11205549178911106, 0.19358868710696697, 0.18673563269632204, 0.10539680373455797, 0.11392085919422762, 0.193311247708542, 0.21680831829352037, 0.0956625539277281, 0.14030915392296656, 0.1388357558420726, 0.07983670849353075, 0.13270136501107896, 0.11366499720939569, 0.14776381105184555], [0.037373406879071674, 0.03160407806613615, 0.09664317952202899, 0.05710365476885012, 0.05133509948583586, 0.02301012841053307, 0.029144727891044955, 0.08960947873336927, 0.008932151864948017, 0.07174781789737088, 0.004091671335377863, 0.03348344364868743, 0.007828637641588492, 0.1289633155933448, 0.050052064404423745, 0.10702627165509121, 0.03950619850573795, 0.12966444582811423, 0.09966480452567339, 0.05272355855309537, 0.0620440003861274, 0.024575754667499235, 0.10491433819489819, 0.11529117423508849, 0.16385294842932904, 3.1277715478624617, 56.938305718558176, 47.944338594164165, 40.55950130735125, 51.531332220349995, 36.640620027269634, 6.650108277797699, 61.67906161717006, 66.2278526851109, 58.0506706237793, 64.77942425864083, 20.500156198229107, 0.8615524151495525, 0.16453243339700357, 7.257133305072784, 71.55575220925468, 69.8617605481829, 71.63364151545933, 71.04486506325858, 73.48874105725969, 72.7551988874163, 71.8765366418021, 68.2776963370187, 64.05031503949846, 58.63837010519845, 49.0938972064427, 49.79172910962786, 54.28769302368164, 59.43837179456438, 61.97010775974819, 61.76253727504185, 59.158282961164204, 46.99590948649815, 43.95142425809588, 48.66550602231707, 53.16897399084908, 60.93235261099679, 59.340367453438894, 58.80202797480992, 56.04545177732195, 57.502423013959614, 53.522018909454346, 49.084805488586426, 44.5837277003697, 40.64106273651123, 42.01062216077532, 40.427106857299805, 40.50567013876778, 41.143726689474924, 40.81597668784005, 42.73970358712332, 43.865544523511616, 55.17701728003365, 56.923186438424246, 57.78500625065395, 54.91337135859898, 58.90897464752197, 50.2128073147365, 47.45160361698696, 51.88186189106533, 57.722170216696604, 55.2662946837289, 58.450845173427034, 53.65102958679199, 55.59928362710135, 57.13095842088972, 57.30043888092041, 53.499875000544954, 57.7841967855181, 53.221259185246055, 50.88353776931763, 49.98214101791382, 48.85395506450108, 47.30785928453718, 43.21501248223441, 40.8787328175136, 42.107921259743826, 39.17008393151419, 41.33764396395002, 39.15127863202776, 40.32953677858625, 40.83495569229126, 40.72521584374564, 39.77168328421456, 39.45529358727591, 39.15282460621425, 38.087735244206016, 40.38241604396275, 38.48861851011004, 40.149314403533936, 40.93867840085711, 41.80987480708531, 43.37156581878662, 42.43813787187849, 44.53535781587873, 44.55260671888079, 42.373179163251606, 41.33575752803257, 49.88910811288016, 54.568799768175396, 57.51650701250349, 58.0357528414045, 56.778497150966096, 54.943783623831614, 54.93620661326817, 49.97881630488804, 46.585538455418174, 45.406453473227366, 46.94281830106463, 47.11338268007551, 51.466116428375244, 54.98972858701433, 62.164844921657014, 59.33642087663923, 55.55223042624337, 27.482513870511735, 18.066978693008423, 1.2079727692263467, 0.03342287761292287, 0.18263923536453927, 3.5589194297790527, 35.47206504004342, 55.542367458343506, 53.753334862845286, 10.038090297154017, 14.292545250483922, 43.812369959695, 34.787146363939556, 24.50493458339146, 52.68030023574829, 9.439061777932302, 0.5450312995484897, 0.049147797748446465, 0.09840336721390486, 0.0998117412839617, 0.10461735020258597, 0.020942150448848094, 0.04216083784454635, 0.025715837687520043, 0.03308217500203422, 0.04241994661944253, 0.04635277629962989, 0.020259506900661757, 0.0842933604227645, 0.03263819596863218, 0.06032856886408158, 0.03067889217553394, 0.0468870344172631, 0.034831261861005, 0.054234656039625406, 0.026331557326817086, 0.03616693429648876, 0.013188652927055955, 0.0549194301877703, 0.025428174462701594, 0.044971380781914504, 0.015060775148283159, 0.03654411494997995, 0.07112762331962585, 0.011951196739184005, 0.009748506675740438, 0.01972865842149726, 0.0685666421694415, 0.013502146283696805, 0.012580861121283045, 0.05961985260780368, 0.03532549659056323, 0.07174648796873433, 0.05524870626894491, 0.04580938849332077, 0.021275891290445412, 0.10462314489164523, 0.07119624356606177, 0.019745022989809513, 0.05537592140691621, 0.2046430403632777, 3.8876955934933255, 67.54179872785295, 50.35874727794102, 42.47391414642334, 53.75944232940674, 20.399042538234166, 22.834274973188126, 69.3583288192749, 71.51704379490444, 63.383044787815635, 67.96010112762451, 21.42780671800886, 0.14911535781409058, 0.23668997788003512, 8.597458618027822, 76.82322325025285, 69.50276102338518, 73.97834587097168, 73.56758226667131, 72.95438289642334, 73.12478746686662, 75.34498705182756, 70.37305763789585, 69.56111894335065, 58.64579772949219, 54.23617213112967, 53.727598735264365, 56.90678868974958, 61.13564995356968, 64.07682241712297, 62.54803807394845, 61.99483639853341, 49.51781027657645, 47.54954889842442, 51.43531158992222, 54.72674969264439, 62.6489189692906, 61.82834366389683, 61.62770053318569, 57.961090973445344, 60.061472347804475, 55.6339864049639, 52.52464321681431, 45.85686002458845, 42.16709211894444, 44.55919361114502, 43.61175462177822, 42.96700695582798, 42.90880537033081, 43.05125386374337, 44.98950597218105, 44.90540150233677, 57.70156185967581, 59.857313428606304, 60.31022480555943, 58.85985088348389, 60.08493641444615, 51.90034409931728, 52.20921237128121, 57.24144867488316, 59.89435427529471, 57.71842166355678, 59.952705247061594, 56.512683391571045, 56.87891946520124, 59.874704769679475, 57.64305107934134, 56.05474846703665, 60.354616846357075, 55.88086632319859, 54.82790504183088, 52.19201905386788, 51.776857239859446, 49.63056216921125, 46.97152130944388, 44.87120941707066, 44.17270701272147, 42.0369210924421, 45.25698382513863, 42.136485304151265, 42.44200107029506, 42.69319929395403, 41.43709700448172, 41.758791651044575, 42.25509800229754, 42.037612438201904, 41.872179303850444, 41.86638103212629, 41.44108527047293, 43.12775353022984, 41.674461364746094, 45.47408029011318, 46.13158137457711, 44.03123126711164, 47.57932192938668, 47.38421998705183, 45.62887920652117, 42.29041916983468, 52.32308292388916, 58.283459595271516, 59.00946644374302, 58.68622234889439, 59.23702689579555, 56.85047006607056, 57.60791751316616, 52.067906856536865, 49.682607650756836, 44.954556533268516, 48.28286525181362, 49.33984954016549, 54.57026236397879, 57.466407026563374, 64.04301248277936, 61.697988510131836, 60.684399196079795, 41.09804228373936, 20.678945507322037, 0.5219694141830716, 0.10011248836027724, 1.0951318527970995, 4.868814672742571, 38.772490637642996, 62.04632255009243, 55.8295955657959, 21.826923404421123, 15.81058941568647, 35.32002108437674, 45.10119826453072, 24.879214933940343, 60.493045806884766, 10.713945048195974, 0.6605598660452026, 0.03352610993066004, 0.025013540372518555, 0.02767848496192268, 0.05655496421137026, 0.012842204820896898, 0.03253063799015113, 0.047122574278286526, 0.01580836806845452, 0.06997946064387049, 0.05292058815913541, 0.010240378407096224, 0.07615591386067015, 0.037046400497534444, 0.012203355619151677, 0.05587974383628794, 0.04090416384860873, 0.013941874295207006, 0.052948693079607825, 0.05595753448350089, 0.135011491764869, 0.0698932595551014, 0.19380786748869078, 0.089762142327215, 0.14574047390903744, 0.08860047001923833, 0.08833758519696337, 0.14915689772793225, 0.15387335393045629, 0.16017119027674198, 0.07212108679647956, 0.1888615507632494, 0.1477733648249081, 0.17032587395182677, 0.16355298166828497, 0.12462640473885195, 0.11884968328688826, 0.26254867602671894, 0.2784273182707173, 0.17577843208398136, 0.1483412172113146, 0.33388441960726467, 0.25728557844247135, 0.5095630256193024, 0.5245374792388507, 7.817036083766392, 80.89383234296525, 61.9219081061227, 55.75899491991316, 75.06944928850446, 48.07407883235386, 11.704541036060878, 75.63845811571393, 75.91765063149589, 69.3756228855678, 76.04496247427804, 22.497150114604406, 0.7108238403286252, 0.2098517601511308, 9.556481122970581, 80.09617219652448, 71.60962159293038, 75.73464897700718, 73.86877277919224, 74.22313785552979, 73.88022341047014, 78.1177977153233, 71.60410472324916, 72.10185282570976, 63.94518184661865, 59.04519408089774, 55.9398078918457, 60.82512106214251, 62.80928339276995, 67.72981003352574, 67.33092090061733, 65.79885005950928, 52.583977358681814, 50.28865385055542, 55.14707749230521, 59.22544424874442, 63.83023084912981, 64.09319237300328, 65.31921591077531, 62.02226788657052, 61.75052383967808, 58.1835549218314, 55.424397468566895, 49.0912812096732, 44.420674324035645, 47.23505258560181, 45.72503532682146, 46.77831275122506, 47.104193687438965, 45.34021977015904, 49.06896012169974, 49.632434708731516, 60.48028891427176, 62.2997441973005, 63.68932832990374, 58.9843556540353, 62.490798813956125, 54.434372970036094, 54.08992992128645, 58.540747914995464, 61.58327375139509, 59.46331582750593, 61.36509336744036, 56.05070114135742, 58.82113552093506, 61.911305155072895, 59.14531762259347, 56.73109654017857, 57.89814376831055, 54.711352484566824, 56.55142307281494, 53.53200694492885, 53.343808037894114, 51.08672046661377, 48.5079973084586, 46.173305307115825, 49.34232657296317, 43.59796939577375, 47.648675373622346, 44.42625372750418, 46.27812583105904, 45.8870256287711, 44.36503314971924, 44.155187129974365, 44.15801157270159, 44.16411556516375, 43.036895411355154, 43.19054440089634, 43.194379806518555, 45.436612129211426, 45.17109019415719, 48.26672806058611, 48.645161696842735, 47.444919449942454, 50.52281856536865, 51.246178150177, 48.00398540496826, 45.15050615583147, 54.67396075384957, 60.144934109279085, 61.421394620622905, 61.43854277474539, 61.98952102661133, 60.567683356148855, 60.105593408857075, 54.89782476425171, 51.8295384815761, 48.937389033181326, 50.323335783822195, 52.212175777980256, 54.612712383270264, 60.737754413059776, 66.73403590066093, 64.76049736567906, 64.19043241228376, 48.22879089627947, 23.013832058225358, 2.500416091510228, 0.147613881954125, 0.6987634503415653, 5.613711067608424, 44.90660354069301, 65.02033914838518, 65.31636020115444, 16.841613497052872, 19.39664156096322, 66.676025390625, 49.91972882407052, 37.642022200993125, 67.69520800454276, 25.169321332659038, 0.838146268257073, 0.14893064701131412, 0.2229300340903657, 0.18941410897033556, 0.2831567887748991, 0.08035596420190164, 0.06948632853371756, 0.16639634195183003, 0.11229816983853068, 0.14381407227899345, 0.15841942998979772, 0.1288528229509081, 0.25085051517401424, 0.15103468910924026, 0.13669094736022608, 0.12884387985936233, 0.13321513815649919, 0.12433657529098646, 0.1329073275306395, 0.14063242157655104], [0.027088968648708293, 0.08091010339558125, 0.007026622820246432, 0.028331476529794078, 0.04082950803318194, 0.04851514526775905, 0.054177330008574894, 0.030016967694142034, 0.03622747997620276, 0.0018930109217762947, 0.04346331973959293, 0.013730441935227385, 0.06297742029918091, 0.029696838265018802, 0.02962043522191899, 0.02370454284495541, 0.056179659707205634, 0.043713376857340336, 0.05881723389029503, 0.05631556348609073, 0.06116797775030136, 0.0369979768459286, 0.15542778266327723, 0.07932958499129329, 0.21663654036819935, 0.14431229340178625, 36.42600754329136, 61.58283601488386, 38.220126220158164, 45.961892468588694, 61.527889660426546, 12.792247653007507, 18.371408803122385, 70.9951923915318, 44.052669933864046, 65.6330451965332, 20.990596532821655, 0.1439053216683013, 0.036544423683413436, 0.04240707141746368, 9.345454777990069, 79.68836157662528, 76.11441666739327, 74.97666304452079, 72.70867374965123, 68.0858496257237, 70.88380581992013, 70.09567165374756, 61.05007593972342, 56.06141178948538, 51.31059489931379, 51.33910683223179, 54.67042064666748, 59.355007307870046, 62.93250274658203, 58.78712408883231, 61.13008444649832, 49.95406682150704, 45.89817748750959, 47.8619190624782, 54.17964506149292, 57.47266387939453, 60.06722545623779, 58.930215290614534, 58.05741037641253, 54.19899926866804, 54.656704902648926, 47.38090222222464, 44.875399180821006, 42.43942676271711, 41.01025179454258, 40.71019383839199, 42.09875658580235, 41.239306109292166, 41.681107316698345, 41.38555874143328, 47.10661860874721, 53.63660512651716, 57.311924253191265, 56.70544726508004, 57.89537838527134, 56.96502849033901, 57.877518040793284, 55.40417126246861, 48.72897434234619, 46.09126445225307, 55.88134574890137, 54.233896596091135, 52.063790048871724, 52.40079157693045, 55.81014060974121, 54.867697375161306, 53.95759800502232, 53.41681970868792, 53.24200998033796, 50.074451310294016, 49.21892656598772, 47.01979739325387, 46.224162646702354, 45.46458210263933, 40.952057157244, 40.42290667125157, 40.905500752585276, 40.07091440473284, 40.09056043624878, 40.27245037896292, 41.69321802684239, 39.92542607443673, 41.269780908312114, 41.141874994550435, 39.077235153743196, 41.022831508091514, 39.83285869870867, 39.61944825308663, 39.51960611343384, 41.49262005942208, 41.80136326381138, 43.87953124727522, 45.159125396183555, 42.68854400089809, 44.73681388582502, 42.40940359660557, 41.53504228591919, 47.868300982883994, 55.27688373838152, 55.52751915795462, 57.86400032043457, 56.700051988874165, 55.880546706063406, 53.44721807752337, 48.91631167275565, 47.40694407054356, 45.96154505865914, 45.08787509373256, 49.993122645786826, 48.64035701751709, 55.44740990230015, 59.441623551504954, 61.01228468758719, 60.557323592049734, 41.28828396115984, 8.065877999578204, 0.12106192457888808, 0.9437765287501472, 0.6149973794817924, 3.509735086134502, 34.15406819752285, 61.07467256273542, 33.993554387773784, 6.16341997044427, 36.56673288345337, 43.329626492091585, 23.893963847841533, 32.709447383880615, 43.82945210593087, 1.9849611563341958, 0.07525703138006584, 0.02877764723130635, 0.01394360710401088, 0.044566899271948, 0.03500866484163063, 0.07873385160097054, 0.05787318133349929, 0.04513860573726041, 0.05816098874700921, 0.0503017992180373, 0.04752404309277024, 0.04850499438388007, 0.009005382756835647, 0.017702478216961026, 0.031824405172041485, 0.025587129772507718, 0.03566030951749001, 0.016614126706761972, 0.03001755801960826, 0.011714437211464559, 0.04235839331522584, 0.05803606366472585, 0.023683369159698486, 0.021151419130287, 0.07157808914780617, 0.024346170647601997, 0.04080963034981063, 0.05561438236119492, 0.06866457512868301, 0.037943132022129636, 0.07596013615173952, 0.020347406023315022, 0.048168848135641644, 0.02842060549716864, 0.04358449252322316, 0.03434818224715335, 0.04640763246321252, 0.008530604170768388, 0.07331973247762237, 0.012361635786614247, 0.08738901359694344, 0.024646150979346464, 0.059956053138843605, 0.03911000869369932, 0.11048637277313642, 0.09036046093595879, 39.28450339181082, 73.14339474269322, 34.036508151463096, 56.9064621244158, 37.833980083465576, 16.483209780284337, 38.18762254714966, 73.55950151171002, 55.30572918483189, 69.37865924835205, 26.522258928843907, 0.6775143391319683, 0.057714356641684256, 0.18508835323154926, 11.710440925189427, 81.79559734889439, 74.73697103772844, 75.35030937194824, 76.17661694117955, 70.43569564819336, 70.30051149640764, 71.49007783617292, 63.11631039210728, 58.48711477007185, 52.78408200400216, 55.3318578856332, 58.07659087862287, 63.518096923828125, 66.05610711233956, 61.630681310381206, 60.8232033593314, 50.58551910945347, 47.8772919518607, 49.88385874884469, 57.625510351998464, 60.45736680712019, 61.0161965233939, 61.70432526724679, 59.179384640284944, 57.276061126164024, 56.02941186087472, 51.18905006136213, 47.163489614214214, 46.43592984335763, 43.77561051504952, 44.16343464170183, 44.80703585488455, 44.38355009896414, 44.260309900556294, 44.18991770063128, 48.474336760384695, 55.57285615376064, 58.38749844687325, 56.95597151347569, 59.090315682547434, 58.47220393589565, 59.712318420410156, 56.38823420660836, 51.17211382729666, 50.903774397713796, 60.99181529453823, 57.1723175730024, 55.562510286058696, 53.51201350348336, 61.614498955862864, 56.83223104476929, 56.12284081322806, 55.94638088771275, 55.575423513139995, 53.54565668106079, 51.967175347464426, 48.95114994049072, 48.38276297705514, 45.41967589514596, 44.808401175907676, 42.468001229422434, 42.51309156417847, 42.47514745167324, 42.80525984082903, 42.433899470738, 41.88218123572213, 42.471558707101, 43.57423782348633, 44.56203542436872, 41.89947182791573, 44.097603934151785, 41.80222136633736, 42.51300471169608, 43.49886376517159, 43.412428174700054, 44.81549876076834, 45.72336081096104, 50.14558001926967, 45.88883910860334, 47.28950909205845, 43.47294003622872, 44.462238448006765, 49.021253790174214, 56.92843927655901, 57.6880476134164, 59.63412339346749, 58.57460648672921, 57.59947197777884, 55.84598984037127, 50.26938649586269, 49.5308381489345, 48.808777877262656, 46.45587464741298, 51.872690268925254, 50.775069441114155, 59.22942556653704, 62.85437025342669, 65.33928230830601, 63.588120869227815, 47.54339279447283, 7.077608789716448, 0.07230686289923531, 1.8635776468685694, 2.852388164826802, 4.8167683226721625, 39.27971608298165, 66.83321448734829, 38.03072874886649, 13.66955326284681, 23.80075897489275, 42.664440699986045, 25.589904478618077, 35.895248549325125, 50.38231209346226, 2.3127096380506242, 0.11961216665804386, 0.0096621639427862, 0.035456687943743806, 0.0057886946264521354, 0.02715075944018151, 0.06934583785810641, 0.020386131713166833, 0.023998881158019816, 0.03611486012648259, 0.014672181535778301, 0.08044532726385764, 0.0394369438290596, 0.003490872257056513, 0.028629536607435772, 0.026330950037975396, 0.04447655911956515, 0.06007371111107724, 0.023943656889189566, 0.028572705906948874, 0.019852857471310666, 0.1343488616070577, 0.20611262507736683, 0.07014423608779907, 0.14201227681977407, 0.1481516073857035, 0.1346330592142684, 0.11645023418324334, 0.11257498498473849, 0.18060056333030972, 0.1814847487424101, 0.17887413954096182, 0.07576193607279233, 0.1676868341330971, 0.10680270115179674, 0.14674659206398896, 0.11243354436010122, 0.18124947351004395, 0.1502736442323242, 0.17224996856280736, 0.09344119991042785, 0.14047787844070367, 0.15979718177446298, 0.23189889639616013, 0.1510419358632394, 0.3290636454309736, 0.13971155456134252, 56.566021238054546, 79.3749839237758, 54.23882286889212, 65.68109893798828, 89.83383628300258, 15.833273547036306, 29.73710182734898, 81.18597630092076, 56.68116678510393, 77.46705027988979, 28.294535943440028, 1.4399704060384204, 0.09520710765251092, 0.18436538773987973, 13.063134465898786, 84.35851682935441, 76.77068097250802, 76.7653933933803, 79.44019276755196, 72.02073955535889, 74.25969232831682, 75.28546878269741, 65.169739314488, 61.62619277409145, 57.11311197280884, 58.368585450308665, 61.48915345328194, 66.95105593545097, 69.64784635816301, 64.54904283796037, 65.3209946496146, 55.211494241442, 51.157873494284495, 52.97022771835327, 60.1283209664481, 62.807935442243306, 64.94307518005371, 66.0784386226109, 63.081138610839844, 59.012530599321636, 60.893539973667686, 54.02600996834891, 50.23000063214983, 48.06102316720145, 46.176011630467, 46.436871324266704, 48.432585035051616, 46.412861824035645, 47.624561650412424, 46.218961920057026, 52.94333471570696, 55.20513316563198, 62.333373478480745, 59.017283167157856, 62.65338666098458, 60.114639963422505, 59.93561962672642, 58.353167397635325, 52.536403042929514, 51.49057061331612, 61.00772666931152, 58.17736060278756, 53.61130673544747, 53.1802578653608, 62.08355794634138, 57.00920861107962, 57.09525162833077, 56.49240159988403, 56.26189511162894, 54.28859976359776, 54.66155474526541, 51.85858195168631, 50.44418232781546, 49.582181862422395, 47.023389611925396, 44.80540302821568, 45.06034633091518, 44.35932173047747, 45.71851791654314, 46.406361784253804, 44.51158455439976, 44.70013434546334, 46.320739133017405, 46.99472829273769, 43.6823969568525, 47.0747263772147, 43.58945090430123, 43.68341486794608, 44.992691721235005, 46.234894139426096, 46.874500138419016, 48.71525859832764, 53.08852079936436, 49.00087124960763, 50.13173573357718, 47.2385162625994, 47.46373864582607, 51.59144803455898, 59.09918853214809, 59.51158496311733, 63.169318199157715, 60.06826768602644, 60.79467405591692, 57.04138919285366, 53.856425285339355, 51.936106477464946, 51.01822165080479, 48.92427430834089, 55.27506678444998, 53.34158114024571, 62.49859469277518, 65.82835211072648, 66.74374253409249, 66.07112911769322, 47.27193014962332, 8.791536569595337, 0.17852852094386304, 2.444826377289636, 5.053298030580793, 5.065835620675768, 43.746226583208355, 70.34170041765485, 43.3496025630406, 8.453540580613272, 51.54967893872942, 63.1812413079398, 35.0386711529323, 45.69725295475551, 63.23618071419852, 5.390041172504425, 0.3057756450559412, 0.13422232839678014, 0.13124915079346725, 0.1261597853153944, 0.11753088262464319, 0.09392401828829731, 0.10879705127860818, 0.1127052026401673, 0.13760245059217724, 0.12095631738858563, 0.15960381286484854, 0.1192380360194615, 0.10231481625565461, 0.11500180619103567, 0.25345247983932495, 0.14186578110924788, 0.16827990088079656, 0.19188666343688965, 0.17081265497420514, 0.09229097448821579], [0.01179343310650438, 0.03865990588175399, 0.04058760351368359, 0.0617885658783572, 0.05972517481339829, 0.004350327188149095, 0.03992141104702439, 0.019080986568172063, 0.13788658034588608, 0.05233458835365517, 0.016830101010522673, 0.03773677934493337, 0.047357031875955205, 0.02061905073268073, 0.06606078520417213, 0.05495617964438029, 0.025040479909096445, 0.030783780118716613, 0.058719646983913014, 0.010000799566374292, 0.01922517186695976, 0.028876971187336103, 0.07207000668027572, 0.008804600852142488, 0.12397388475281851, 0.2721391985458987, 4.520841070583888, 58.500017574855256, 42.69126769474575, 35.25091082709176, 45.053686482565745, 48.069972446986604, 4.387509047985077, 49.39183248792376, 55.04993125370571, 58.26954582759312, 36.10564695085798, 1.1950925460883548, 1.1660030441624778, 0.08748263785881655, 0.4104014023074082, 11.130879521369934, 80.88629354749406, 72.40496104104179, 76.71273994445801, 71.43887656075614, 71.77750396728516, 63.7821284702846, 61.7020879473005, 52.89393302372524, 51.86716992514474, 52.469130584171836, 58.002741949898855, 62.952923502240864, 63.82130241394043, 64.87384332929338, 60.56677314213344, 50.923076493399485, 44.14012690952846, 50.07836662020002, 53.61565978186471, 55.526657581329346, 58.78909042903355, 60.63041169302804, 54.38307441983904, 54.71181801387242, 51.766421045575825, 49.89480216162545, 44.41957998275757, 40.370906352996826, 42.076939242226736, 42.26623943873814, 43.01824644633702, 43.66584634780884, 42.065102985927034, 42.508279936654226, 44.5246958051409, 53.4589501108442, 56.51313502447945, 56.14430032457624, 56.52041326250349, 55.674657685416086, 57.0770925113133, 56.296340806143625, 60.79527160099575, 50.21307482038225, 46.54683698926653, 57.07206548963274, 52.523583616529194, 59.98128318786621, 54.90005513599941, 57.564293248312815, 51.71368074417114, 53.374859537397114, 48.62262521471296, 49.00326490402222, 47.712293079921174, 47.1636563709804, 46.50587041037423, 43.38067838123867, 41.72132001604353, 41.090423583984375, 39.314425809042795, 39.747701576777864, 40.39698641640799, 39.79281970432827, 39.67502341951643, 39.96975905554635, 41.236731801714214, 41.3936117036002, 40.63566746030535, 42.49900756563459, 41.4305795942034, 41.11313377107893, 42.20210061754499, 42.48884582519531, 41.984069619859966, 40.83455269677298, 41.8973456791469, 45.60584592819214, 42.19336673191616, 43.344686712537495, 39.425277369362966, 46.68334477288382, 55.71973064967564, 59.014760971069336, 55.6542786189488, 58.139506816864014, 53.99134193147932, 54.26003571919033, 51.516060079847065, 47.72711706161499, 47.59458712169102, 49.969884395599365, 50.357215200151714, 53.814767360687256, 53.79688964571272, 62.81433473314558, 62.055959701538086, 65.781069619315, 55.896419865744456, 2.17488061104502, 0.009915143850126436, 0.790983361857278, 3.1870598750455037, 5.979237990719931, 49.854033606392996, 53.18511118207659, 14.365366714341299, 14.481878450938634, 45.63186345781599, 38.34117773600987, 34.56362281526838, 49.30009889602661, 28.117620910917008, 0.30194197648337906, 0.1304587796330452, 0.050759854460401196, 0.01785486700412418, 0.029230783094785044, 0.05013653862157038, 0.02951528943542923, 0.0314795024293874, 0.031410295250160356, 0.04539710043796471, 0.05291382655767458, 0.05871162669999259, 0.0728513193981988, 0.07371303851583175, 0.029762140475213528, 0.01288180666909154, 0.036184749233403375, 0.042641020113868375, 0.04072411797408547, 0.01978325504543526, 0.046589496811585765, 0.0288900262010949, 0.02782959131790059, 0.03083152523530381, 0.10443539425198521, 0.02762528442378555, 0.03642172419599124, 0.04519470701260226, 0.020806708073775684, 0.04549386292429907, 0.04501954319753817, 0.01989691305373396, 0.03099829557218722, 0.08300769941083022, 0.032667199948004315, 0.05304946570790239, 0.04047610324674419, 0.0690181665122509, 0.05652122405756797, 0.05788713879883289, 0.017113933905160854, 0.009864387734393989, 0.08161410383347954, 0.08430193032005004, 0.047670572730047364, 0.030107063573918173, 0.2708247947905745, 4.719010208334241, 69.1168372290475, 44.97429289136614, 38.76645960126604, 53.461246490478516, 26.859864950180054, 15.315436465399605, 56.71905531202044, 58.94582789284842, 66.44601222446987, 40.34195668356759, 1.4457696548530032, 2.080789408513478, 0.6782026993376868, 0.8286853730678558, 13.370019027165004, 84.32284477778843, 74.5527742930821, 78.05406188964844, 74.3172720500401, 73.4792011805943, 66.5449754170009, 64.284024647304, 54.31275517599923, 54.65591280800955, 55.461125646318706, 60.031254632132395, 64.25844138009208, 65.76564461844308, 65.5433578491211, 63.01658289773123, 51.48672131129673, 47.22432804107666, 51.09334557397025, 56.94026163646153, 59.090023858206614, 60.90976401737758, 61.546128681727815, 55.90244395392281, 57.09812123434884, 54.86338254383632, 53.393525872911724, 46.818553243364605, 43.05478007452828, 44.35892915725708, 43.733851841517854, 45.48184142793928, 45.27289867401123, 44.2546888078962, 44.981380053928916, 47.39987080437796, 56.299085344587056, 58.88599695478167, 59.46826294490269, 58.89702374594552, 57.18197904314314, 57.190164021083284, 60.281236921037944, 61.05162538800921, 51.676869188036235, 51.16432837077549, 59.531561034066335, 54.314648560115266, 59.84126308986119, 59.238597188677105, 58.911830357142854, 54.8115177154541, 55.529322215488975, 51.299877302987234, 52.65909433364868, 49.3697441646031, 49.29133374350411, 49.650757108415874, 46.1451164654323, 43.577989850725444, 44.360037394932334, 42.33923026493618, 41.44991990498134, 43.17188153948103, 42.647487095424104, 42.15007250649588, 42.0677433013916, 43.97126831327166, 44.53560100282942, 43.43379735946655, 44.32608502251761, 43.4819518498012, 42.73093843460083, 43.89906958171299, 45.88381903512137, 44.28616067341396, 42.41779007230486, 44.92753846304757, 47.79925673348563, 45.67861788613455, 45.63015072686331, 41.29442269461495, 48.52871683665684, 59.31675747462681, 60.098527090890066, 58.46825041089739, 59.61268820081438, 56.53196464266096, 56.363936356135774, 53.83583082471575, 49.79670054571969, 50.21591315950666, 52.839459146772114, 51.676730224064414, 56.07461336680821, 57.42446075166975, 65.0125641141619, 64.99392904554094, 67.09238229479108, 56.572125230516704, 2.382308223417827, 0.039382454074387035, 4.78785252571106, 4.642045012542179, 5.868851091180529, 57.38257006236485, 56.349779401506694, 24.092784813472203, 18.412896496909006, 28.771481139319285, 44.723421233040945, 36.41313600540161, 54.968890939440044, 32.838409423828125, 0.5018326118588448, 0.13009815184133394, 0.07148058366562639, 0.020762498124635646, 0.009178633103147149, 0.014296687041808451, 0.015044951711648276, 0.029751504438796213, 0.011679139819794467, 0.06706133937197072, 0.02714959405628698, 0.0069544343277812, 0.008277835457452705, 0.09401744577501502, 0.04591752661924277, 0.05752520143453564, 0.10149883718362876, 0.07121514076633112, 0.07845061751348631, 0.023623011773452163, 0.020389003612633263, 0.09741300464208637, 0.08894017179097448, 0.09437865710684232, 0.18536687828600407, 0.16970672431801045, 0.13154387926416738, 0.14131628988044603, 0.1391141451895237, 0.21172873729041644, 0.21105546770351274, 0.14404537129615033, 0.13649863696524075, 0.24810836517385074, 0.12988714102123464, 0.19789401894169195, 0.11111028572278363, 0.1097005477973393, 0.07871108675109488, 0.1554175910672971, 0.05892885968621288, 0.11530007661453315, 0.11122790298291615, 0.26161913733397213, 0.16828034871390887, 0.29436108469963074, 0.6205162576266697, 9.620567832674299, 85.52477196284703, 58.144968100956504, 52.40557541166033, 68.85523060389927, 66.24732153756278, 7.509379403931754, 61.651748248508994, 65.96509265899658, 72.39676216670445, 44.34947613307408, 3.400566509791783, 2.8895432225295474, 0.40787480931196896, 0.4735979554908616, 14.0775671175548, 85.82476738521031, 77.86743327549526, 82.31557273864746, 77.40936633518764, 77.41465391431535, 69.1913844517299, 66.77131993430001, 56.57468564169747, 58.49553598676409, 58.34736565181187, 63.33084992000035, 65.87917818341936, 68.97997856140137, 70.23896435328892, 65.51209790366036, 55.44981745311192, 49.35668502535139, 53.48844173976353, 61.02816826956612, 60.58054447174072, 63.459398542131694, 64.58323492322648, 59.43581485748291, 60.10532242911202, 57.417029653276714, 54.08014338357108, 50.40046426228115, 45.02817269733974, 47.48037263325283, 45.98767375946045, 47.19244623184204, 48.677099091666086, 46.76083108357021, 48.20868975775582, 49.14894778387887, 58.329293387276785, 60.633336884634836, 62.09136772155762, 59.85926587241036, 59.528740065438406, 59.45970971243722, 60.918880053928916, 60.56179128374372, 52.19416604723249, 53.03016982759748, 61.80080100468227, 55.009444100516184, 61.054891041346956, 59.66070025307791, 62.383504731314524, 54.397759437561035, 56.61941467012678, 52.83269507544381, 52.86345822470528, 50.1277300970895, 51.45048645564488, 51.06084884916033, 47.003476074763704, 46.06237036841256, 47.22785425186157, 44.81562382834298, 43.17387219837734, 45.51142338344029, 43.842080456869944, 44.47471393857683, 43.94453164509365, 46.1501122202192, 45.73298059191023, 46.5669207572937, 46.52177136284964, 46.04177590778896, 44.19003929410662, 47.24170201165335, 47.850492749895366, 46.66478960854666, 42.556910378592356, 46.84938587461199, 51.16808039801461, 48.04319756371634, 49.77268409729004, 43.02498272487095, 50.12578807558332, 59.43984481266567, 63.64784063611712, 59.32972976139614, 61.56847408839634, 58.50307478223528, 59.626230239868164, 56.56340176718575, 54.198961053575786, 53.19803135735648, 54.40307828358242, 54.55748462677002, 58.4130608694894, 59.0285461970738, 67.60131004878453, 68.65719304765973, 68.21530151367188, 57.49909482683454, 3.083420979125159, 0.14179532203291143, 6.6068896140371045, 13.831209182739258, 8.319693957056318, 58.44865649087088, 63.42938232421875, 20.577503544943674, 20.456849813461304, 71.20427758353097, 50.61426728112357, 45.63435091291155, 62.207895960126606, 48.188550404139924, 0.8638782703450748, 0.27048156463674133, 0.1863262453781707, 0.12152353195207459, 0.11117773888898747, 0.11375302355736494, 0.11122714302369527, 0.11539667285978794, 0.13590060334120477, 0.15956620845411504, 0.1508215476891824, 0.12246942333877087, 0.12237545980938844, 0.22267409068133148, 0.09972676834357636, 0.119958599497165, 0.18062435276806355, 0.18659961356648377, 0.23849973934037344, 0.1089078356911029, 0.09922746156475373], [0.02637109556235373, 0.011379991541616619, 0.027916898418750082, 0.05373936279543808, 0.03942214498030288, 0.015573822261233414, 0.012999477363856775, 0.10457271616905928, 0.01919228836361851, 0.008813970572581249, 0.06694220897874661, 0.07332145595656973, 0.009490365661414606, 0.03634610486083797, 0.03413887454995087, 0.08024507800915412, 0.030820868842835938, 0.015618756546505859, 0.057193234962012084, 0.07259527420891182, 0.006957982641844345, 0.06128644317920719, 0.03914741972195251, 0.030043766434703554, 0.09375763471637454, 0.12408954783209733, 0.19037963716047152, 27.528684650148662, 64.1913148335048, 39.58912631443569, 36.88483531134469, 57.76028108596802, 17.0123359475817, 13.149491889136177, 81.64632225036621, 50.68207822527204, 54.645306382860454, 2.2270850326333727, 1.1231656627995628, 0.43167401797005106, 0.33993459067174364, 0.20877322873898915, 52.89537477493286, 85.49876485552106, 66.22595582689557, 74.5200274331229, 61.97467967442104, 62.348061970302034, 56.955075195857454, 54.86580746514456, 53.14070871898106, 55.51130206244332, 57.82916900089809, 67.38219860621861, 66.172440801348, 64.15636539459229, 63.16717120579311, 52.71429429735456, 47.66021285738264, 51.10259015219552, 54.83431822913033, 59.55700533730643, 60.12821674346924, 58.26297977992466, 53.56608091081892, 50.11328131811959, 47.78929649080549, 47.374714851379395, 44.238478660583496, 43.41102116448538, 43.32608985900879, 44.88855559485299, 41.82643583842686, 44.4290121623448, 43.8101395879473, 44.198026248386924, 45.25776549748012, 51.29019151415144, 54.17136975697109, 56.7938665662493, 55.13451862335205, 58.374852725437705, 56.54487092154366, 58.65091160365513, 55.90899610519409, 58.79213374001639, 51.8324601990836, 55.36483403614589, 55.049979891095845, 54.41493191037859, 55.10787922995431, 55.62646845408848, 54.29069811957223, 51.15397208077567, 51.238128662109375, 49.50114154815674, 48.48237930025373, 47.07731458118984, 47.31779520852225, 46.601317814418245, 42.240201064518516, 41.74923440388271, 40.60174982888358, 38.721435274396626, 41.032086508614675, 41.51721668243408, 40.52943297794887, 40.53550222941807, 40.23760863712856, 42.296102796282085, 41.10534831455776, 41.92037548337664, 40.70467002051217, 42.11738470622471, 42.304933956691194, 42.38550526755196, 42.82488850184849, 42.611026423318044, 41.767956324986045, 42.58943142209734, 42.30728939601353, 42.794288635253906, 41.94916187013899, 43.692787987845286, 53.728929315294536, 59.30043615613665, 57.45918090002877, 58.88904026576451, 58.30225099836077, 55.147866112845286, 50.38882602964129, 51.7486058643886, 49.4481372152056, 52.722399371010916, 52.7061961718968, 55.31954915182931, 60.26721545628139, 63.82652051108224, 61.67544160570417, 70.37339809962681, 21.110107285635813, 0.7004771041018623, 0.2699737490287849, 1.9975280591419764, 2.125320847545351, 11.030979190553937, 55.15850727898734, 36.144546440669465, 5.153987416199275, 34.498049191066194, 41.870671544756206, 70.62860543387276, 53.03336599894932, 50.58448035376412, 18.262339455740793, 0.545894124678203, 0.12336973074291434, 0.18299588694104127, 0.046997974892812114, 0.044676930510572026, 0.03624073855046715, 0.07646219099738769, 0.019862401066347957, 0.04731428756245545, 0.0331869611649641, 0.0161505125662578, 0.0401862229087523, 0.03766127536073327, 0.04242166331303971, 0.012739515331174647, 0.04482855933851429, 0.05176954510222588, 0.0386646183074585, 0.08080323413014412, 0.013839178868303341, 0.05211912634383355, 0.03355716647846358, 0.02861555539337652, 0.02873977819191558, 0.026363041351682374, 0.019248311607433215, 0.07167986261525325, 0.06759557034820318, 0.034926294083041806, 0.023930394922250083, 0.029991420850689923, 0.10487568205488579, 0.03498119095872555, 0.05952408417527165, 0.0362468894704112, 0.05363293457776308, 0.08896833777959857, 0.02502252078349037, 0.06155031866260937, 0.0413491301504629, 0.02169804015595998, 0.057693369553557465, 0.07233470997640065, 0.07725292178136961, 0.02040759038313159, 0.06032274703362158, 0.18234590467597755, 0.25111367819564684, 30.42400074005127, 75.98499952043805, 34.56714902605329, 50.51779849188668, 44.56512042454311, 17.047342709132604, 32.93627827508109, 76.71859032767159, 61.69500773293631, 56.70874418531145, 2.6273998490401675, 2.498322295291083, 3.8758363212857927, 0.728911249765328, 0.1250898034444877, 54.60994005203247, 89.14373425074986, 68.98703098297119, 78.30693462916783, 66.22351006099156, 66.6475864137922, 58.02450718198504, 58.074714865003315, 54.24598298754011, 57.885852405003135, 61.34516593388149, 68.53651673453194, 68.1866957800729, 65.86266231536865, 65.32875578744071, 55.69943496159145, 48.842983858925955, 52.73100471496582, 57.75661243711199, 61.659766469682964, 63.08965710231236, 61.0720739364624, 57.877278327941895, 53.76553937367031, 51.81034755706787, 49.6256810597011, 47.31205252238682, 46.1594888142177, 46.317532539367676, 46.76112985610962, 45.37965774536133, 47.540147985730854, 46.50305986404419, 45.03777858189174, 46.94987767083304, 52.40694768088204, 57.083901745932444, 58.965915134974885, 55.71492249625069, 60.02675914764404, 60.2287015914917, 60.43357617514474, 58.89682919638497, 62.8223876953125, 55.43091140474592, 58.42592198508126, 54.517532484872, 56.30067995616368, 57.852650438036235, 58.60649177006313, 56.69442742211478, 53.72906480516706, 54.2714272907802, 51.43113224846976, 50.4845027242388, 51.1592561858041, 49.339314528873985, 48.41931397574288, 44.40392221723284, 43.23487738200596, 42.75356176921299, 41.29237297603062, 44.21258619853428, 43.27021244594029, 41.91697781426566, 42.41685206549508, 42.75420100348336, 44.03308991023472, 43.62607833317348, 43.95563834054129, 42.31268119812012, 43.93273707798549, 44.08138336454119, 44.978892598833355, 45.150183064596995, 45.72167239870344, 45.33831943784441, 45.47731120245797, 43.751277923583984, 47.06665257045201, 45.62208039419991, 46.118473597935264, 55.80674988882882, 61.964340754917686, 59.57929515838623, 61.40305137634277, 60.613680430821006, 56.828996658325195, 52.725967270987375, 53.99791145324707, 51.58917597361973, 57.41008840288435, 57.9217780658177, 58.40083203996931, 62.4069618497576, 66.40485804421562, 63.675647326878135, 70.75126893179757, 21.871025357927593, 0.4731983797890799, 1.077841694865908, 6.30468944140843, 1.4167978380407606, 14.009236795561653, 63.59579862867083, 39.661377157483784, 13.533042873655047, 26.167278936931066, 44.804729052952354, 72.95109639848981, 51.566601276397705, 58.71563407352993, 20.297242743628367, 0.39158511055367334, 0.06839464711291449, 0.0713439267128706, 0.018628133993063654, 0.02278780810801046, 0.04531957781208413, 0.015117948508954473, 0.017253796935879757, 0.031215542129107883, 0.028040897300732986, 0.02250556637799101, 0.03933167590626648, 0.006911144217675818, 0.07778886266584907, 0.03392164156373058, 0.033091223266507895, 0.01940983856496002, 0.0871152789997203, 0.04570853104814887, 0.05652734444343618, 0.04121541125433786, 0.11153342694576297, 0.09671979291098458, 0.06757564856005566, 0.13714811711439065, 0.10635738540440798, 0.11639971046575479, 0.1537589393556118, 0.1940492359655244, 0.11595582642725535, 0.09874386965696301, 0.14382507811699594, 0.11401476844080857, 0.12464691006711551, 0.1877378967723676, 0.18738106877676078, 0.20634847027914865, 0.09741757118276187, 0.16136801748403481, 0.08641777892730065, 0.23322746796267374, 0.18457015603780746, 0.1344255767762661, 0.2110312847154481, 0.18820783655558312, 0.1441628257078784, 0.25698107906750267, 0.4252492684338774, 49.58104235785348, 82.64778695787702, 54.84411518914359, 53.676946367536274, 85.92168780735561, 20.859204360416957, 23.70245065007891, 91.2730027607509, 64.43275778634208, 63.543145179748535, 2.220638407128198, 5.084339542048318, 2.6082712411880493, 1.1176623638187135, 0.26927092245646883, 59.589599336896626, 91.87075628553117, 72.52698530469621, 81.75292846134731, 67.79005091530937, 67.79202420370919, 60.94934095655169, 59.89771025521414, 57.37128618785313, 61.31125177655901, 63.958758626665386, 73.26193795885358, 71.07370008741105, 69.01986816951207, 67.43341377803257, 59.92350196838379, 52.23989561625889, 55.880470275878906, 59.512522969927105, 65.26272705623082, 65.12185232979911, 63.65881184169224, 60.0087285723005, 55.31983402797154, 53.61798048019409, 53.890690326690674, 50.16237381526402, 50.10975858143398, 47.317190715244834, 49.59582812445504, 47.46193906239101, 50.675689356667654, 48.75688873018537, 49.30321168899536, 49.789769717625205, 56.95698595046997, 58.119537694113596, 61.148893220084055, 57.61916664668492, 63.98862893240792, 61.23917811257498, 62.1992107118879, 60.00401769365583, 60.17390809740339, 57.599124567849294, 61.228512627737864, 54.43743365151541, 56.62318059376308, 59.49334594181606, 60.561687060764854, 57.809981550489155, 57.05214153017317, 56.360027994428364, 54.91652236665998, 52.74324744088309, 54.199954645974294, 51.81914397648403, 50.78753798348563, 45.71325465611049, 47.036233357020784, 44.15721947806222, 44.22609697069441, 45.838033880506245, 47.63938563210623, 44.223105771201, 44.76198720932007, 45.275490352085654, 46.319220951625276, 46.442325660160606, 47.26615619659424, 43.27781030109951, 48.774811608450754, 45.95307173047747, 46.43314708982195, 46.86815643310547, 48.80184357506888, 47.29194443566458, 49.12889528274536, 47.71470063073294, 51.392441204616, 48.68709754943848, 49.103635106767925, 58.1648017338344, 64.73668588910783, 61.6070157459804, 63.747088704790386, 62.928973061697825, 61.41057627541678, 55.67960132871355, 58.112057958330425, 54.384363310677664, 59.47558634621756, 60.2146384375436, 61.30055849892752, 63.87590135846819, 70.66064357757568, 66.13991628374372, 72.38328960963658, 24.177617107118877, 1.2581065190689904, 0.87386304885149, 8.433600119182042, 5.624733081885746, 14.384726132665362, 64.6909875869751, 45.783084051949636, 8.733273318835668, 48.067478043692454, 65.48434679848808, 74.26874583108085, 61.560150146484375, 63.47794328417097, 33.24558080945696, 0.8741854886923517, 0.3853814277265753, 0.35972178461296217, 0.14224371154393467, 0.06047047767788172, 0.1577779022710664, 0.1565961656825883, 0.10792257570262466, 0.11869857353823525, 0.19018693321517535, 0.1544928021196808, 0.18791494012943336, 0.10937511561704533, 0.13986286787050112, 0.16405407977955683, 0.13003265964133398, 0.1372423113456794, 0.1566592287272215, 0.144910937707339, 0.13264610511916025, 0.1781448365322181], [0.02946162410080433, 0.07011039754641907, 0.014315289079344698, 0.06295633143080132, 0.036338691865759234, 0.002537553880496749, 0.04561599922765579, 0.024544718475746255, 0.023735567162345563, 0.02652203058823943, 0.01890673877538315, 0.048861924159739695, 0.02200216464033084, 0.0185061927685248, 0.03853626662333097, 0.07630037396614041, 0.04760166410622852, 0.022090299553903084, 0.019956225496051565, 0.017170486406290104, 0.056377252497311146, 0.14602727709071978, 0.0787164471777422, 0.0244694926909038, 0.0648149134857314, 0.08866071714354412, 0.11169282160699368, 4.048841689314161, 59.451219013759065, 47.97438260487148, 37.99255187170846, 42.44411332266671, 55.346122537340435, 3.2246769879545485, 47.48942961011614, 67.13907418932233, 47.884459018707275, 6.22065097945077, 2.4280160793236325, 3.5373719802924564, 1.2251150608062744, 0.10923997858273131, 41.01049845559256, 90.69631617409843, 66.71904168810163, 67.88455336434501, 59.83670507158552, 59.185054370335166, 54.50243057523455, 55.577514920915874, 56.56010137285505, 63.49263177599226, 66.50277205875942, 67.97926425933838, 66.79052475520542, 66.23289012908936, 61.47190107618059, 49.5355281829834, 47.19536794934954, 52.37246724537441, 57.7613719531468, 59.99524906703404, 60.14696298326765, 57.759857245853965, 54.146721022469656, 47.14477811540876, 46.1691746030535, 44.24696935926165, 43.93558931350708, 42.10022265570504, 43.47540317262922, 42.95618513652256, 41.72423825945173, 41.32719734736851, 44.510247026171, 43.742523193359375, 44.53017445972988, 48.734842096056255, 55.23737975529262, 58.3983793258667, 55.694008418491904, 56.28454276493618, 56.35628638948713, 58.34699044908796, 57.50448315484183, 55.29994828360421, 55.43458005360195, 59.20446068899972, 58.41190052032471, 58.09534754071917, 57.69047253472464, 54.63401208605085, 54.49688243865967, 52.410011836460654, 50.867577757154194, 50.328376701899934, 49.985524790627615, 48.30152811322893, 49.16708953039986, 47.04280635288784, 40.81225940159389, 41.03449058532715, 41.17717184339251, 41.368191719055176, 40.85099213463919, 40.64900452750069, 40.50753573008946, 38.86242812020438, 42.23885658809117, 42.218480995723176, 42.49937929425921, 41.73178052902222, 44.22942515781948, 44.197446073804585, 43.807377679007395, 44.60100787026541, 44.184914997645784, 43.67031403950283, 42.023087229047505, 41.07303919110979, 42.28890446254185, 40.98304264886038, 42.17440857206072, 42.92499119894845, 52.868467875889365, 60.09510857718331, 60.486820220947266, 62.45745440891811, 59.607880047389436, 58.56130068642752, 53.149004868098665, 51.150894028799875, 51.997948919023784, 55.83308008738926, 54.29135125023978, 60.32253006526402, 58.527560234069824, 62.44325923919678, 66.82398727961949, 44.81027371542794, 0.4226379399853093, 0.14778973108955792, 0.26807292816894396, 4.741420320102146, 2.2316751863275255, 17.183673313685826, 61.6824175970895, 23.860159124646867, 11.893898555210658, 45.56205143247332, 32.673115253448486, 27.83772141592843, 42.39551762172154, 43.06324645451137, 2.373201523508344, 0.10595587587782315, 0.04684867343998381, 0.03428267986912813, 0.04064531291701964, 0.08196551033428737, 0.060395302783165655, 0.05431006842159799, 0.09632831213197537, 0.12700251223785536, 0.11047179105558566, 0.09315058336194072, 0.010443865122007472, 0.01993947077010359, 0.0636738482862711, 0.02884228786985789, 0.010009444102511873, 0.05598409573680588, 0.024222840122612457, 0.04066728048824838, 0.024475453621042625, 0.05372913388003196, 0.02795048081316054, 0.014043632495616163, 0.03695597213559917, 0.049114200086998086, 0.10905091158513512, 0.0354889217498047, 0.04776918422430754, 0.07618801535240241, 0.049881809790219576, 0.027390149987435768, 0.03291504504159093, 0.046638456505856345, 0.06020456658942359, 0.04179862906624164, 0.013133248846445764, 0.01532696104342384, 0.04212615452706814, 0.027884749429566518, 0.02627782753136541, 0.008531739868755852, 0.04317451148693051, 0.075529056069042, 0.05228645647210734, 0.058759361638554504, 0.013482666391480182, 0.09836691631270306, 0.14724451463137353, 5.947291910648346, 72.14368098122733, 52.10466282708304, 37.33689900806972, 49.724908283778596, 26.90099481173924, 10.640790070806231, 63.142623220171245, 72.716066632952, 55.90202358790806, 8.997651406696864, 2.0164677628449033, 6.611375110489981, 1.7717245242425372, 0.22965565962450846, 46.65095574515206, 92.60397189004081, 70.5431217466082, 74.71424348013741, 61.93861157553536, 63.394321714128765, 57.81987231118338, 58.68578461238316, 59.23725618634905, 66.11101177760533, 70.10665675571987, 70.30512510027204, 69.06647668566022, 70.82667773110526, 62.58797631944929, 51.24965919767107, 48.73527635846819, 53.892979758126394, 58.877839769635884, 63.026136670793804, 62.5723637172154, 62.18621758052281, 57.36682891845703, 51.17853396279471, 47.80060468401228, 48.502404008592876, 46.5693804195949, 46.21958030973162, 45.771737643650596, 46.81186212812151, 45.601659638541086, 45.59731354032244, 45.41641024180821, 47.156972203935894, 46.41378246034895, 52.14299603870937, 57.648345606667654, 61.23143087114607, 57.61189535685948, 58.4985237121582, 58.555686541966026, 60.43839127676827, 58.952915055411204, 58.622111320495605, 59.570776666913716, 59.944249289376394, 59.729390144348145, 59.62067168099539, 60.83386884416853, 57.216337885175435, 57.42736857278006, 55.66070222854614, 53.26130165372576, 52.61845432009016, 51.66759334291731, 51.92010130201067, 51.869219643729075, 48.7265876361302, 44.191192695072715, 44.75563308170864, 43.97031988416399, 43.04895053591047, 42.554766859327046, 43.02480207170759, 43.72475664956229, 42.65582840783255, 44.983214378356934, 45.39475270680019, 43.65004961831229, 44.559419427599224, 45.59036534173148, 45.63481991631644, 46.359850542885916, 47.16691507611956, 46.87937429973057, 45.51001289912632, 44.30169684546334, 44.193509919302805, 44.881788049425396, 43.73772198813302, 44.77874973842076, 46.550915581839426, 56.17516074861799, 61.8060816356114, 62.56044060843331, 65.06763553619385, 62.00435543060303, 60.558893884931294, 54.260230268750874, 52.96012503760201, 54.412361076899934, 58.96100275857108, 57.77642869949341, 63.77210916791643, 61.559934752328054, 62.94437721797398, 68.26043006352016, 45.8522116797311, 0.3148118316062859, 0.17002098102654728, 2.2889363765716553, 5.891809242112296, 0.16495697918747151, 22.647380590438843, 61.32916423252651, 31.7875326020377, 16.435703209468297, 33.87530299595424, 43.2044929095677, 29.787830625261577, 48.953981331416536, 45.86013610022408, 1.1936316873346056, 0.0838094021060637, 0.058950294607451985, 0.07893578362252031, 0.03296083597732442, 0.029655549409134046, 0.047518122874732525, 0.04221365501039794, 0.06738956033119134, 0.03991319059527346, 0.025449183603216494, 0.08360260498843022, 0.00783640262670815, 0.030792255021099533, 0.019218450977600048, 0.03750824875065258, 0.06267163849302701, 0.07320191844233445, 0.03348103824204632, 0.005716507406240063, 0.038246532170368094, 0.09158267213829926, 0.07651517101164375, 0.09475209563970566, 0.16232286553297723, 0.21460451797715255, 0.30171021606240955, 0.11598109507134982, 0.14265128038823605, 0.1967273186892271, 0.14585088512727193, 0.09038933938635246, 0.13394845809255326, 0.10106936522892543, 0.10097707768103906, 0.13189324337456906, 0.09932308071958167, 0.1421118179070098, 0.12030922568270139, 0.15332019861255372, 0.16466769256762095, 0.13494966365396976, 0.22139070954705986, 0.186298384730305, 0.1617571437465293, 0.0936365637129971, 0.13997098564037255, 0.26425779717309134, 0.3634828227971281, 10.848930307797023, 89.31226280757359, 61.87214510781424, 53.863988399505615, 62.55046994345528, 74.36937659127372, 5.531460898263114, 61.025118010384695, 80.37512847355434, 60.93337399618966, 7.882036481584821, 6.05038320166724, 11.538262827055794, 2.25264658672469, 0.2959397371326174, 48.20891557421003, 96.80756255558559, 73.47076606750488, 76.96201351710728, 64.64081464494977, 65.79468808855329, 59.67968967982701, 61.19996247972761, 61.2403176171439, 71.82754489353725, 71.06987857818604, 73.3764512198312, 70.56977503640312, 74.17867633274624, 65.63160691942487, 55.795486858912874, 51.92469753537859, 57.67669425691877, 60.9687750680106, 65.72392763410295, 64.11809471675328, 64.8875868661063, 59.953511238098145, 53.12504400525774, 51.31921066556658, 50.25531986781529, 49.84853410720825, 49.69313069752285, 48.86333513259888, 48.19152075903756, 46.167020661490305, 47.936466285160606, 49.015413829258506, 50.108177866254536, 49.54465464183262, 52.54685313361031, 60.8171375819615, 63.454305512564524, 60.52443081992013, 60.11175646100725, 61.737141609191895, 61.66388675144741, 59.91136346544538, 58.33823571886335, 56.60882214137486, 61.937965393066406, 61.76660197121756, 59.32679067339216, 61.62788813454764, 59.41980620792934, 58.84778186253139, 57.61688763754708, 54.57613359178816, 54.99117728642055, 55.09327759061541, 53.9901259967259, 55.20418473652431, 51.96649789810181, 45.30127511705671, 47.719324656895225, 45.788691248212544, 48.692319120679585, 44.85457195554461, 46.00747612544468, 45.36336421966553, 43.68083708626883, 46.001962729862754, 46.821940490177695, 46.08433362415859, 48.18398543766567, 48.64686400549752, 49.420410428728374, 48.73324053628104, 49.700228282383506, 48.94821432658604, 49.777533939906526, 47.410129819597515, 47.82445437567574, 47.31077752794538, 48.62796490533011, 46.883168016161235, 48.184239046914236, 57.07426806858608, 66.07307461329869, 63.91205978393555, 70.07682813916887, 64.77639484405518, 64.36119134085519, 56.78010218484061, 57.57511854171753, 56.063489300864084, 62.730706214904785, 56.81859173093523, 68.04116576058524, 62.97846508026123, 67.0582527433123, 70.3064661026001, 51.21986184801374, 0.528904639184475, 0.4747130327991077, 1.5803609298808234, 14.635485751288277, 8.017722640718732, 20.854502167020524, 69.14151723044259, 31.157070432390483, 16.078972271510533, 68.2929128919329, 47.31872974123274, 39.419590268816265, 53.732889788491384, 62.506946427481516, 6.5417715311050415, 0.6408290990761348, 0.16914191176848753, 0.21689621571983608, 0.09241670702717134, 0.1317119523882866, 0.14858588336833886, 0.10038354274417673, 0.19212968753916876, 0.25280933720724924, 0.21916242768721922, 0.21932264337582247, 0.08223801678312676, 0.1924479068922145, 0.19491074473730155, 0.13783578521439008, 0.19214902578720025, 0.15369017661682197, 0.2815733865967819, 0.1228236864720072, 0.08032213244587183, 0.20624887490911142], [0.015261894624148096, 0.10113312037927763, 0.04734459772173848, 0.03814575614939843, 0.06457064087901797, 0.024308028497866223, 0.04934890195727348, 0.047981938879404745, 0.02037847614181893, 0.02546018604854388, 0.050203577881412845, 0.03297795880852001, 0.05542947817593813, 0.010785869671963155, 0.016685985261574388, 0.03959187712254269, 0.08173360063561372, 0.08257912312235151, 0.015511777019128203, 0.06621088393564735, 0.040252264722117355, 0.03482788275661213, 0.07636951668454067, 0.044486930527325184, 0.011797370305950088, 0.058808847197464535, 0.19059556057410582, 0.04600799908595426, 34.122936793736045, 55.99029350280762, 50.27000488553728, 66.51142951420375, 64.36080918993268, 26.5792932169778, 11.355454853602819, 74.4974318913051, 68.95839050837925, 23.21190435545785, 1.042858926313264, 5.245923374380384, 0.700037304844175, 0.07843137426035744, 45.68687234606062, 88.35607951028007, 69.04191480364118, 78.12207780565534, 61.49776227133614, 62.42295660291399, 57.24590941837856, 62.3397102355957, 64.77388654436383, 67.33817481994629, 67.51957838875907, 70.35813290732247, 67.91570213862828, 63.78895854949951, 57.0989967073713, 48.4756430217198, 49.40521124431065, 52.44854654584612, 57.47512354169573, 61.7978549684797, 61.88404042380196, 58.0682669367109, 53.797924927302766, 47.633059297289165, 45.017566272190635, 43.96245104925973, 44.849767276218955, 45.849435874394004, 45.232710293361116, 44.23910052435738, 45.1818390573774, 42.0826541355678, 44.742150102342876, 44.71751526423863, 44.268053667885916, 46.99565240315029, 53.067780426570344, 53.672753129686626, 59.32287883758545, 59.769008772713796, 60.02101993560791, 58.31849588666643, 59.84980937412807, 57.013832637241904, 54.49300534384591, 57.7596765926906, 62.252371379307334, 46.885071822575156, 55.75251225062779, 58.72284630366734, 55.42004442214966, 52.21011216299874, 52.98510728563581, 49.32044669560024, 51.15004982267107, 48.47507674353463, 49.93244055339268, 47.520738192967, 43.85982615607125, 42.028395652770996, 40.80228526251656, 38.71436548233032, 40.24382380076817, 40.89258405140468, 41.3966063771929, 41.558961459568565, 42.27888516017369, 41.78563254220145, 42.67019033432007, 41.79086453574044, 44.407090595790315, 43.983674321855815, 45.02340623310634, 45.46055909565517, 46.75529336929321, 45.533935546875, 45.96483850479126, 42.681498527526855, 40.87680469240461, 40.846149240221294, 42.97805111748831, 41.84627989360264, 51.01147147587368, 59.02742058890206, 60.89923749651228, 62.78317206246512, 62.325570651463096, 56.22501059940883, 56.433807441166465, 51.550738539014546, 53.54758480616978, 51.90572200502668, 60.80642345973423, 56.87759583336966, 68.0859260559082, 58.1393609046936, 64.45686108725411, 8.266410827636719, 0.1632036039871829, 0.4151941936995302, 2.9915755646569386, 4.899946076529367, 0.8381307433758463, 36.44475378308977, 54.60694537843977, 20.08504475866045, 32.575013637542725, 47.092489446912495, 22.314495870045253, 26.90132311412266, 49.74772616795131, 18.9953761441367, 0.3309220171400479, 0.04457533685490489, 0.06866952843431916, 0.05907462936426912, 0.06483144938413586, 0.02706159315338092, 0.06996295867221695, 0.14697500052196638, 0.015407112992501684, 0.04798032057338527, 0.047989253486905775, 0.028524482423173528, 0.03199309915570276, 0.025677776961986507, 0.06983037971492324, 0.02057593492125826, 0.04972871532663703, 0.0536324697812753, 0.045675917262477536, 0.15011481275515898, 0.03421420550772122, 0.041560863610357046, 0.02557330292516521, 0.03839077853730746, 0.0942586785448449, 0.06868936201291424, 0.013041150440195841, 0.04115488932334951, 0.020798577527914728, 0.051091193288032494, 0.06665609790278332, 0.041332645142184835, 0.03391769927527223, 0.08680236579052039, 0.02893873144473348, 0.024924991552584937, 0.03966565423512033, 0.04884491667949727, 0.03144919227010437, 0.02815258246846497, 0.023737210913428237, 0.004648517883781875, 0.054518521164676974, 0.020271908824465106, 0.012902763223142495, 0.03298842521118266, 0.07418742270341941, 0.014170427790044673, 0.1778566762804985, 0.29539028661591665, 41.85361024311611, 66.1122624533517, 45.835355349949424, 66.34180314200265, 40.65920795713152, 18.039635794503347, 30.797414302825928, 75.33224405561174, 72.05960083007812, 24.275531121662684, 0.39242410553353174, 5.983316149030413, 1.9617387567247664, 0.0924409239419869, 50.18239157540457, 90.0408022744315, 73.30943584442139, 78.20783247266496, 64.64122458866665, 65.54765878404889, 58.1963152885437, 65.91311318533761, 67.84993743896484, 68.67050579616001, 69.00271306719098, 71.8474931716919, 67.67644786834717, 67.68719673156738, 59.80324254717146, 50.942430700574604, 50.70766496658325, 54.70284441539219, 60.60999093736921, 64.07687800271171, 62.68137400490897, 60.65331990378243, 57.06575652531215, 50.426624229976106, 48.2069388117109, 46.45744841439383, 48.24615444455828, 48.45048706872122, 47.76657240731375, 46.68265690122332, 48.24579661233084, 44.22381796155657, 47.29392467226301, 47.590355668749126, 45.99563986914498, 48.95824057715279, 55.256796496255056, 57.08436727523804, 60.390101296561106, 62.86654349735805, 62.73450687953404, 62.797763279506135, 63.027338709150044, 60.91641344342913, 59.05144051143101, 62.34485190255301, 64.56710120609829, 49.37825918197632, 56.97244569233486, 60.36364950452532, 57.776571137564524, 55.43190152304513, 53.98545333317348, 53.23649658475603, 53.513486521584646, 52.1013902255467, 53.7590115410941, 50.73653473172869, 46.04624012538365, 44.75448315484183, 43.62915638514927, 42.135585512433735, 43.741401059286936, 43.19404629298619, 45.575246061597554, 44.29548863002232, 43.60144002096993, 44.52014126096453, 44.24346399307251, 44.81466497693743, 47.09833983012608, 46.798608439309255, 47.437460558755056, 49.32441064289638, 49.37455926622663, 47.97263860702515, 48.255524090358186, 45.44132648195539, 42.87962988444737, 43.73833342960903, 46.82852390834263, 44.4559086390904, 53.66450214385986, 60.89565222603934, 62.059670039585654, 64.6690799168178, 64.09034361158098, 59.19836711883545, 58.42219080243792, 54.13195957456316, 55.81443459647042, 56.32688161305019, 62.64468056815011, 59.48515401567732, 68.85967050279889, 60.420506613595144, 64.69179357801164, 9.278541019984655, 0.21006772427686624, 0.9065952524542809, 5.627749468599047, 2.9043941284929002, 1.088888896363122, 40.73803179604666, 55.145045144217356, 25.53174458231245, 17.453715051923478, 47.864090374537874, 26.42609064919608, 29.866876806531632, 58.543270111083984, 19.142042194093975, 0.31704434752464294, 0.04895027620451791, 0.1092330507401909, 0.07399161785308804, 0.05239630789895143, 0.05337304209492036, 0.0075845100717352966, 0.019882728279169117, 0.02423221747657018, 0.03188310184382966, 0.024910179133127843, 0.028766071423888206, 0.037247728622917614, 0.026007414363058548, 0.050292649173310826, 0.04787109339875834, 0.06552878660815102, 0.03682092670351267, 0.061810794685568125, 0.04439584059374673, 0.07080135654125895, 0.04268811383683767, 0.08353241054075104, 0.17523177713155746, 0.2148823102137872, 0.09365278748529297, 0.13069144929093973, 0.2686636064733778, 0.11826969869434834, 0.18357147462666035, 0.11513847671449184, 0.10403740632214717, 0.13203778490424156, 0.15495807358196803, 0.11348783850137677, 0.14999262216900075, 0.1057393214266215, 0.13342680037021637, 0.20003292416887625, 0.20772253083331244, 0.16604798207325594, 0.1167524808219501, 0.07967433506356818, 0.13313945436051913, 0.12235008259969098, 0.1138388921639749, 0.31715866710458485, 0.1706593467720917, 0.4094867099608694, 0.4551168871777398, 61.50297342027937, 74.26951708112443, 67.84829071589878, 82.3359934943063, 90.76125403812954, 35.49984393801008, 19.16729368482317, 88.42888968331474, 80.40776416233608, 28.505125420434133, 2.845467976161412, 12.996509058134896, 3.221755487578256, 0.1817788393901927, 54.55289534160069, 92.08992331368583, 76.76014055524553, 81.93620109558105, 67.99249362945557, 67.54585647583008, 60.6574957711356, 68.543548311506, 70.96876839229039, 71.47767530168805, 72.97327504839215, 75.37526035308838, 71.1156394141061, 69.99505478995187, 63.1920804977417, 55.37063578196934, 54.975102628980366, 57.689524105616975, 62.290600367954795, 69.28480298178536, 65.45884690965924, 63.674549511500764, 60.96840681348528, 52.091624532427105, 50.98234115328108, 50.430028847285676, 50.588513783046174, 50.90827683040074, 50.27195038114275, 49.02830968584333, 51.71007810320173, 46.2375796181815, 50.731111662728445, 50.36940581457955, 49.22699342455183, 51.25346333639962, 58.85552215576172, 58.09544481549944, 65.95161315373012, 65.26900822775704, 67.11219160897392, 64.27746554783413, 64.53433350154332, 61.07047585078648, 59.13050406319754, 61.82065200805664, 65.41033458709717, 48.924208300454275, 59.45911911555699, 62.19425664629255, 59.331383432660786, 58.086412157331196, 56.70527008601597, 53.93855994088309, 57.5631537437439, 54.680929797036306, 55.48755659375872, 50.376965454646516, 48.101829937526155, 45.589746952056885, 45.042239325387136, 42.97005026681082, 45.99051557268415, 45.416768074035645, 45.80023915427071, 46.158255508967805, 47.495453698294504, 45.53956011363438, 46.8245530128479, 45.6331592968532, 49.694336209978374, 48.12918152127947, 49.701659611293245, 52.04185111182076, 53.2611974307469, 50.801069600241526, 52.20156935283116, 47.19164718900408, 47.377792903355186, 47.94011408942086, 49.425830023629324, 46.12934752873012, 57.51213659558977, 63.93148694719587, 65.05067498343331, 66.92297826494489, 68.2755354472569, 62.57912431444441, 61.92092841012137, 55.694147382463726, 58.781822613307405, 57.6905072757176, 67.21891593933105, 61.54771981920515, 75.69316823141915, 62.06598595210484, 69.59540135519845, 10.847627520561218, 0.18723740934261254, 1.1922763543469566, 7.701413716588702, 11.278988191059657, 2.8098647551877156, 43.66490486689976, 64.15547602517265, 25.53351637295314, 44.9900791985648, 68.34997844696045, 32.68646969114031, 40.05010802405221, 63.483342034476145, 38.80895825794765, 0.5537508002349308, 0.15695819125643798, 0.2548117483300822, 0.18378859226192745, 0.17613599289740833, 0.09414711381707873, 0.1833906586148909, 0.2733389027416706, 0.12966374015169485, 0.14692237334592, 0.1316544126187052, 0.17531998668398174, 0.16498300779078687, 0.19760253386838095, 0.15436567179858685, 0.2270834826465164, 0.22029597471867288, 0.10584427043795586, 0.12146983269069876, 0.17643802240490913, 0.15472978726029396, 0.09169896625514541], [0.003940475497594369, 0.03892023941235883, 0.03690666978114417, 0.020136841339990497, 0.02988597990146705, 0.012560915584409875, 0.005429266569470721, 0.0312770818626242, 0.015603241843304463, 0.02920517179050616, 0.02202037482389382, 0.0818929477993931, 0.016829432653529302, 0.05779600476047822, 0.030509526442204202, 0.06404117321861641, 0.04806937490190778, 0.07314505042242152, 0.023792672669515014, 0.028123252792283893, 0.039337633443730216, 0.021198010737342492, 0.04011290041463716, 0.015576319270102041, 0.1547994999481099, 0.009353210833588881, 0.05805579546306815, 0.01454341594528939, 3.9334985528673445, 73.06471334184918, 43.55254554748535, 87.08971473148891, 79.09540925707135, 53.66738912037441, 8.832905275481087, 33.64306640625, 86.13956941877092, 38.698186601911274, 0.4054386786052159, 3.303957453795842, 2.469713087592806, 0.3267498681587832, 31.17625788279942, 94.6827061516898, 74.76078251429966, 78.44380024501255, 71.90881797245571, 67.7962417602539, 66.03869492667062, 67.55218628474644, 66.25219917297363, 71.00721277509416, 71.28215299333844, 70.16259670257568, 65.99554661342076, 59.144998005458284, 52.18223251615252, 50.89460277557373, 48.73367132459368, 53.73515837533133, 60.67542907169887, 61.345040866306846, 60.364552770342144, 59.67147690909249, 54.421261719294954, 48.39958456584385, 45.55649287360055, 46.19562986918858, 45.12738255092076, 45.47046722684588, 43.60943044934954, 43.76367003577096, 45.1085181917463, 43.006934779030935, 43.97748695101057, 42.34593180247715, 45.09996495928083, 45.56634194510323, 50.993399211338584, 52.5089750289917, 56.48805897576468, 58.0551244190761, 62.01112992422921, 60.141779627118794, 60.75980799538748, 55.029003279549734, 57.667220388139995, 57.016215869358604, 61.54194586617606, 40.25434684753418, 53.95756673812866, 59.282898902893066, 53.55872624261038, 56.50649949482509, 50.01180635179792, 53.53417478288923, 51.15351349966866, 53.82405015400478, 51.599650382995605, 50.65394149507795, 44.610186440604075, 41.558697428022114, 42.63617542811802, 41.508496693202424, 39.42496817452567, 40.466200896671836, 39.970057828085764, 43.345854009900776, 43.42081117630005, 43.23656232016427, 47.39746672766549, 46.951659883771626, 46.33105720792498, 48.4759452683585, 44.98450674329485, 48.231924533843994, 46.03900357655117, 47.33579451697213, 46.23513732637678, 49.16979932785034, 44.2474661554609, 43.18524292537144, 43.052890164511545, 44.47310543060303, 48.830157484327046, 60.79028974260603, 60.262851987566265, 64.87227303641183, 60.58681174686977, 62.77482727595738, 58.26114545549665, 56.895400592258994, 53.80965001242501, 56.992866447993684, 57.144253798893516, 66.84481103079659, 57.64065742492676, 67.50935758863176, 27.3785114969526, 0.057856462230639796, 0.02749063932736005, 0.24809232460600988, 3.830611799444471, 2.358520414148058, 1.0181736052036285, 47.83838551385062, 36.25123255593436, 33.189880575452534, 67.43851375579834, 31.436599935804093, 34.85762194224766, 48.21386616570609, 40.165632247924805, 1.8254841480936324, 0.0726830902110253, 0.13291806195463451, 0.05791704862245491, 0.03338575835472771, 0.02199142682366073, 0.035341747504259856, 0.053678942644702535, 0.034914395971489806, 0.09558665300054209, 0.04399210886497583, 0.03747957046808941, 0.02029182213092489, 0.02816973753007395, 0.0186185479895877, 0.0122667002558176, 0.04877443385443517, 0.016283990582451224, 0.009409386747782784, 0.010024959653882044, 0.03213883490700807, 0.03595819317602685, 0.02909297602517264, 0.007290921539866498, 0.024611079200570072, 0.015944453355457102, 0.03142442574192371, 0.041505881917795966, 0.01057309381264661, 0.02641106297128967, 0.0256033280997404, 0.04346472091440644, 0.029429013707808087, 0.0049251680611632764, 0.022658363982502903, 0.0020587146864272654, 0.05271484277078083, 0.0445017836588834, 0.04391579403142844, 0.05733235499688557, 0.008555162897599595, 0.00439348880068532, 0.043767310213297606, 0.028234008367040327, 0.035830055230430195, 0.010057871994961585, 0.06021523315991674, 0.12021721633417265, 0.023582871338086467, 0.0867955804403339, 0.08670580347201653, 7.339901549475534, 84.90798037392753, 49.64010899407523, 83.49050617218018, 93.79642868041992, 27.478386640548706, 15.061978340148926, 51.82632841382708, 85.52522359575543, 43.86516237258911, 0.8291627360241753, 4.686734088829585, 3.3169101987566267, 0.12165784117366586, 33.60122088023594, 98.72329207829067, 73.45507703508649, 84.20925562722343, 74.80882930755615, 71.2693544115339, 68.53618322099958, 67.5020341873169, 70.76010704040527, 75.10248102460588, 72.85638550349644, 71.17348316737584, 68.04940632411412, 62.06076785496303, 54.96100125994001, 53.683574948992046, 52.347054209027974, 56.65341567993164, 62.12164797101702, 64.39035293034145, 64.55123152051652, 61.72609397343227, 57.17144209997994, 49.94198390415737, 48.279936586107524, 49.10989890779768, 49.1115734236581, 48.66750362941197, 45.519320011138916, 46.82400410515921, 49.186190128326416, 45.84840406690325, 46.597270488739014, 47.72112424033028, 48.20393024172102, 49.02660737718855, 54.026583194732666, 55.66567366463797, 61.39036396571568, 60.05390575953892, 63.77311665671212, 63.54288809640067, 61.79404040745327, 58.6029759815761, 60.53039237431118, 58.057504177093506, 63.044875962393625, 41.493954113551546, 54.008531774793354, 63.39607266017369, 56.44979177202497, 58.35376494271414, 50.9738643510001, 55.4599791935512, 54.019857338496614, 55.74603305544172, 53.025969641549246, 52.50714070456368, 47.080236298697336, 44.8545754296439, 43.749099663325715, 44.38180610111782, 43.11493757792881, 42.155728340148926, 43.39342485155378, 47.40826770237514, 46.862785475594656, 46.78311743055071, 49.43992791857038, 49.03609166826521, 49.79113851274763, 49.95206921441214, 47.984488759722026, 50.24873297555106, 49.870796135493684, 50.402381965092246, 49.688541412353516, 48.93955339704241, 48.06438609531948, 45.66264745167324, 45.11710269110543, 45.97019904000418, 52.491913727351594, 63.69116265433175, 60.82506547655378, 66.39213589259556, 64.53386797223772, 63.271567889622276, 60.83377851758684, 58.695942878723145, 56.89760317121233, 60.18410805293492, 60.76933397565569, 69.0244539805821, 60.037118911743164, 69.13479137420654, 28.78445863723755, 0.021744338296619908, 0.2563890979758331, 1.4401380313294274, 5.7554508447647095, 1.9239479388509477, 1.7531590461730957, 50.63165862219674, 44.59258665357317, 34.45529692513602, 53.28811822618757, 37.13290337153843, 35.37127794538225, 53.51246861049107, 45.25898143223354, 0.828848058623927, 0.04162990454850452, 0.03992636435266052, 0.02344504221608596, 0.02504855447581836, 0.024532455651621734, 0.02774662005582026, 0.11284369842282363, 0.0331296792386898, 0.021849329716392925, 0.0379615271064852, 0.04504199931398034, 0.016492200749261037, 0.0319197325568114, 0.01544485311023891, 0.040030672148402245, 0.04078086046501994, 0.0258942313292729, 0.02966010577178427, 0.027365931376282657, 0.04145177214273384, 0.034559298240180523, 0.02973730948620609, 0.07991942869765417, 0.14902059361338615, 0.05722482755248036, 0.08850432160709586, 0.17807597879852566, 0.08807972153382641, 0.16628366442663328, 0.11615298156227384, 0.10391618604106562, 0.09170210787228175, 0.14371474832296371, 0.14430959283241204, 0.08359324799052306, 0.14683218247124127, 0.17330696327345713, 0.08547791293156998, 0.16292877016322954, 0.117941233462521, 0.16893349295215948, 0.07953423115291766, 0.10420068898903471, 0.12299944061253752, 0.08685970199959618, 0.14820063832615102, 0.31145197046654566, 0.08601564514849867, 0.3495673994932856, 0.23196455144456454, 12.258731961250305, 103.95012310573033, 58.18041781016758, 97.22805363791329, 92.21340669904436, 80.6627699988229, 11.714298912457057, 47.498333726610454, 97.26955522809709, 48.0698230607169, 1.5538770024265562, 16.761785643441335, 9.045567921229772, 0.2678493915924004, 38.107499395098, 99.67758546556745, 78.17182690756661, 87.49367604936872, 78.47746426718575, 73.2564697265625, 71.74402059827531, 70.939863886152, 75.44813305991036, 76.67699841090611, 77.5926320212228, 75.51050703866142, 71.94015434810093, 64.90105247497559, 57.703417028699604, 56.39948334012713, 55.5938675062997, 58.4495667048863, 65.92413997650146, 67.53117493220738, 67.43110697610038, 65.2547505242484, 59.74905354636056, 53.84068066733224, 52.38032218388149, 53.19290011269705, 51.707465580531526, 50.01469680241176, 48.42628301892962, 49.08998884473528, 51.546722480228965, 49.47556175504412, 49.400448254176546, 52.247830459049766, 49.74605165209089, 51.090642724718364, 56.176244667598176, 58.38136318751744, 61.969649178641184, 61.62283679417202, 65.83609935215541, 62.205304282052175, 63.768475260053364, 60.79712677001953, 60.03497191837856, 59.425795555114746, 65.33885151999337, 44.76005213601248, 58.088503565107075, 65.02968447549003, 56.86403642381941, 60.67030130113874, 52.85135098866054, 59.20627416883196, 55.38452523095267, 59.16629423413958, 56.21075636999947, 53.96816621507917, 49.45031547546387, 47.53162949425833, 46.94156762531826, 45.94652305330549, 43.525492736271445, 45.25784192766462, 44.630412646702354, 47.8219495500837, 49.20617662157331, 49.88180903026036, 51.46060650689261, 53.065921783447266, 53.886823654174805, 51.92225524357387, 50.28532566343035, 52.88464675630842, 52.29546383449009, 53.0112498828343, 51.52994952883039, 53.83891582489014, 51.44285038539341, 48.70636143003191, 49.66560540880476, 49.28881502151489, 54.41021408353533, 65.75930786132812, 64.00934151240757, 69.11446789332798, 65.75598662240165, 67.65526281084333, 65.00527545383999, 60.96311923435756, 60.560290472848074, 61.48761095319475, 63.73912606920515, 71.7021438053676, 63.99127619607108, 72.8073798588344, 33.48989684241158, 0.10035025381616183, 0.634949186018535, 0.785562627017498, 10.620200821331569, 7.624738608087812, 2.0093033015727997, 54.67676435198103, 48.024322782244, 40.96700620651245, 93.81094346727643, 43.70182064601353, 51.016158035823274, 58.59920310974121, 63.18509060995919, 5.575691827705928, 0.4034060319619519, 0.2059370202145406, 0.22707893646189145, 0.15039067795234068, 0.1504825380231653, 0.11190169504178421, 0.227511108985969, 0.18803547509014606, 0.18221665732562542, 0.18299173430672713, 0.1519401805209262, 0.0625853424093553, 0.12812118578170026, 0.10851999185979366, 0.14431377260812692, 0.10347158954079662, 0.08494674893362181, 0.1161218232342175, 0.128020423331431, 0.14216505576457295, 0.0959648277078356, 0.10761510434427432], [0.05380932993388601, 0.01479727794815387, 0.022050751140341163, 0.041045821604451964, 0.10430123430809804, 0.017210246862045357, 0.04077099795852389, 0.05056663482849087, 0.043067309739334245, 0.01579250391971852, 0.056544402813805, 0.03419870776789529, 0.022836684681741253, 0.010782368431266929, 0.03244558362556355, 0.04813293666977968, 0.05320035153999925, 0.08377891552767583, 0.018964488890820315, 0.06899354247642414, 0.04081614767866475, 0.05310477309727243, 0.01902801842827882, 0.037909079742218764, 0.05531052080914378, 0.10731397050299815, 0.11562369710632733, 0.08213823142328433, 0.2938345143837588, 44.70360844475882, 50.83699526105608, 33.475031171526226, 35.56259659358433, 55.926356179373606, 43.753483976636616, 7.422659805842808, 66.05959510803223, 49.6106208392552, 0.6586135561977113, 3.6843200836862837, 1.1782149374485016, 0.6026230177709034, 5.508420237473079, 80.73692117418561, 81.73956707545689, 78.93137618473598, 75.52261080060686, 75.1807107925415, 66.76119640895298, 66.64086055755615, 69.10283660888672, 69.93950394221714, 69.54528399876186, 68.9728010722569, 61.70649310520717, 54.261456625802175, 52.930313791547505, 52.28648328781128, 50.63436147144863, 52.58742019108364, 58.19399459021432, 62.6307007925851, 60.39381858280727, 58.47586563655308, 53.27507298333304, 48.87398672103882, 44.814001423971995, 45.34431225912911, 44.82904427392142, 46.990788664136616, 48.136164460863384, 48.33134283338274, 46.958389214106965, 44.52685669490269, 45.41431188583374, 44.06850835255214, 45.97470147269112, 45.534779753003804, 48.78963906424386, 53.38389914376395, 56.95002385548183, 59.959875788007466, 61.71221842084612, 58.93422440120152, 61.39904226575579, 55.51803139277867, 59.28201648167202, 56.47907842908587, 59.75152710505894, 48.37600932802473, 55.955938134874614, 58.70156397138323, 55.742941107068745, 54.24807439531599, 50.507299763815745, 55.06886509486607, 54.064853872571675, 54.983923367091585, 54.5953106198992, 53.240752356392996, 46.120398248944966, 41.10340281895229, 41.84921203340803, 41.11083739144461, 41.583721365247456, 42.234163079942974, 43.3722710609436, 42.897688252585276, 45.597549779074534, 50.926230975559776, 52.454869406563894, 51.61399493898664, 50.574700764247346, 47.98786905833653, 47.989494936806814, 49.29170894622803, 47.70088413783482, 48.54152584075928, 49.99668707166399, 49.290472166878835, 47.760718550000874, 46.05630111694336, 43.59499556677682, 43.34032671792166, 45.68883521216256, 58.702467237200054, 60.0046569279262, 63.17163889748709, 63.223125049046104, 61.75592258998326, 60.65712751661028, 57.46159192493984, 55.81929833548409, 54.83538130351475, 63.21338367462158, 61.26628998347691, 68.86331135886056, 37.162155287606375, 0.11885901992874486, 0.05797203031501599, 0.08227594010531902, 1.305215414081301, 4.95042039666857, 1.4047802771840776, 2.240149600165231, 50.79095649719238, 20.266582080296107, 22.006449222564697, 44.52550179617745, 38.92707415989467, 36.906409467969624, 53.27081026349749, 17.816975559507096, 0.663569195994309, 0.061482404092592854, 0.14433574357203074, 0.06915295749370541, 0.05263942699613316, 0.004850502915879977, 0.02714371624668794, 0.024306707050917403, 0.08037910224603755, 0.023300354801384465, 0.08219951670616865, 0.0421208517758974, 0.04730241998497929, 0.03657597556178059, 0.05811456338103328, 0.013911818586555975, 0.0402921015130622, 0.06675026499267135, 0.07835813319044453, 0.057490765782339234, 0.047268879999007495, 0.020568396397201077, 0.02441994097482945, 0.049863943963178566, 0.02844852551684848, 0.03754407200696213, 0.036213335913739035, 0.06263242595429931, 0.013446997501887381, 0.07208439162267105, 0.03415689644004617, 0.04905907590208309, 0.04541620798408985, 0.020269798580557108, 0.055086763708719184, 0.027812868822366, 0.032332821283489466, 0.04385771482650723, 0.029891326757414, 0.03652678516560367, 0.022810457606932948, 0.01656356397350984, 0.0347828144606735, 0.006382691391211535, 0.05408990755677223, 0.05639103693621499, 0.03060735422851784, 0.03764636116102338, 0.10254509747028351, 0.0861760847536581, 0.009142951491022748, 0.7520896260227475, 54.22109801428658, 60.29624502999442, 38.0085118838719, 49.16665874208723, 53.92504916872297, 22.829242740358623, 19.420465196881974, 75.27170440128872, 53.5940717288426, 2.578512975147792, 4.2677238413265774, 7.077670020716531, 0.5501435995101929, 5.771974095276423, 83.3377708707537, 82.1865724836077, 85.09205899919782, 77.8701639175415, 78.43448271070207, 67.34153774806431, 71.46236842019218, 71.93658297402519, 73.00216565813336, 72.128262928554, 72.93041161128453, 63.36365931374686, 56.6768866947719, 56.08956241607666, 57.463328974587576, 53.19706555775234, 55.65054048810686, 61.56965528215681, 65.35852187020438, 62.21003600529262, 60.556503704616, 57.04121548788888, 51.39003017970494, 46.730133942195344, 48.16452005931309, 48.407356125967844, 49.30491399765015, 50.16463892800467, 50.24445635931832, 49.83962304251534, 48.83868292399815, 48.43164702824184, 47.67329284123012, 48.561925751822336, 45.99812732424055, 50.796059949057444, 55.055305685315815, 61.251948901585166, 61.605271748134065, 61.75511659894671, 62.0241300037929, 64.53854410988944, 58.115368774959016, 65.41491344996861, 57.62296731131417, 61.94355174473354, 48.621350220271516, 56.42043215887887, 62.007732255118235, 59.34979615892683, 58.973926407950266, 53.01653746196202, 57.73263072967529, 56.696407658713206, 58.034686292920796, 56.260109424591064, 56.02247755868094, 47.732984815325054, 43.88381481170654, 44.42878981998989, 43.29840823582241, 43.7016921043396, 45.693108354296, 43.88967561721802, 44.26295369012015, 48.15074178150722, 53.642670903887065, 54.63697896684919, 56.18512446539742, 52.23418419701712, 52.18637364251273, 51.61322716304234, 52.284232071467805, 51.024513244628906, 50.62676361628941, 53.55214977264404, 51.281124114990234, 51.772552830832346, 47.411529881613596, 45.37335920333862, 47.26159470421927, 48.519020625523154, 62.225523539951865, 64.11767087663922, 64.6201229095459, 66.36593423570905, 63.665641920907156, 62.01517377580915, 60.1179473059518, 59.95203821999686, 59.23462976728167, 66.30318505423409, 63.96214239937918, 69.16363334655762, 38.964111532483784, 0.31161864580852644, 0.25374400562473703, 0.48292743201766697, 3.6057355233601163, 5.716909187180655, 1.1338762023619242, 3.1145556398800442, 54.21931232724871, 24.651180267333984, 25.0032958643777, 54.88851070404053, 46.151446274348665, 38.40224892752511, 62.947656767708914, 15.507894618170601, 0.7568517476320267, 0.09664311845387731, 0.07061580435505935, 0.05251486153740968, 0.04592568939551711, 0.0419645681977272, 0.048486894462257624, 0.05024443586756076, 0.0036693960927160723, 0.049875580838748386, 0.04194633596177612, 0.014535926615021058, 0.004477052508653807, 0.04533173715961831, 0.036809130372213464, 0.05353275906028492, 0.013829521618650427, 0.06731987478477613, 0.05421902259279575, 0.06963758077472448, 0.07295571201081787, 0.032707141911877055, 0.03524825216404029, 0.17132699808904103, 0.07282771316490003, 0.1526881025305816, 0.12276485748589039, 0.2069154405700309, 0.13285594885902746, 0.1192041906927313, 0.16093580424785614, 0.11548333535236971, 0.127478314563632, 0.13135631861431257, 0.10075660808277981, 0.09711664768734149, 0.15411690729004995, 0.13861159501331194, 0.11337764441434826, 0.19051386495786055, 0.18933679669031075, 0.10097927613449947, 0.13537918989147457, 0.13394425117543765, 0.2521942859249455, 0.16143189477069037, 0.10851008524852139, 0.13017209858766624, 0.1541605642331498, 0.197243154581104, 0.11373622981565339, 1.2769646900040763, 74.20217514038086, 66.74981525966099, 52.39785943712507, 51.54581574031285, 82.00658634730748, 59.946514402117046, 13.285372597830635, 82.19622353145054, 59.86581802368164, 2.010891833475658, 6.266378377165113, 3.590446663754327, 0.9695384949445724, 8.463711874825613, 82.49088273729596, 86.31243365151542, 87.74112919398716, 80.1941556930542, 80.50323241097587, 70.27435152871269, 74.4134212221418, 75.08011477334159, 74.59848649161202, 76.11215155465263, 73.29822840009416, 67.64418043409074, 57.854536873953684, 56.80667209625244, 59.616481917245046, 56.741261754717144, 58.2734819820949, 64.16313294001988, 68.32493713923863, 65.0218608038766, 63.617268562316895, 58.7307950428554, 55.231018679482595, 49.83459949493408, 51.86034332002912, 50.71084029333932, 53.117800508226665, 52.99568591799055, 52.733700616019114, 53.33003323418753, 50.68170649664742, 50.6220840045384, 50.003840242113384, 51.51222120012556, 49.96414518356323, 52.184476784297395, 58.036631788526265, 61.80934034075056, 64.55768639700753, 63.661146436418804, 63.83194705418178, 65.0179420198713, 59.92396054949079, 64.26201970236642, 61.287106786455425, 62.42607634408133, 52.4863794871739, 58.358732904706685, 64.56748335702079, 60.43542439596993, 60.435521670750205, 53.822062969207764, 59.111403465270996, 59.429353032793315, 61.63311317988804, 58.20494147709438, 57.889128480638774, 49.72401891435896, 45.826614516122, 45.87950767789568, 46.668263707842144, 45.54628596987043, 47.42593002319336, 47.62094858714512, 46.403780528477256, 50.04735680988857, 55.187654972076416, 56.96291276386806, 58.64303234645298, 55.77185256140572, 55.54097434452602, 53.34783451897757, 55.42094421386719, 52.77266263961792, 53.83928060531616, 56.85294015066964, 53.8623104095459, 53.94429567881993, 51.49675451006208, 49.21665103094918, 49.245812620435444, 52.287379605429514, 64.52302878243583, 65.38915647779191, 66.92167895180839, 69.14403247833252, 66.03480393545968, 65.44921670641217, 62.61800643375942, 61.78396551949637, 62.22543321337019, 68.96232318878174, 68.15798582349504, 73.31404944828579, 44.44044542312622, 0.6599040212375777, 0.5919603556394577, 0.263510241572346, 3.998395596231733, 14.949247292109899, 5.3373942375183105, 2.6831320013318742, 61.98684597015381, 26.32621897969927, 36.18662473133632, 57.86786699295044, 52.64011532919747, 50.96542576381138, 68.84755284445626, 31.61749976021903, 0.9450914753334863, 0.2343217549579484, 0.310838194830077, 0.13483550692243235, 0.1377788425556251, 0.12319229383553777, 0.20794373324939183, 0.16245524771511555, 0.1465691008738109, 0.20625362465424196, 0.18728102557361126, 0.12800782972148486, 0.08336110758994307, 0.13304284454456397, 0.13530068338981696, 0.09450664916740996, 0.10810588872326271, 0.1353167918111597, 0.1298818891601903, 0.18726803841335432, 0.13944942291293824, 0.136437663808465, 0.1947037372738123], [0.007702250316339944, 0.03567645186558366, 0.0068811589070329705, 0.05497280035966209, 0.08237524370529822, 0.01494042169568794, 0.06096477686826672, 0.07697866471218211, 0.03526672527992299, 0.06227219171289887, 0.08939403707959823, 0.1042242952223335, 0.04957660134615643, 0.05639607845140355, 0.027160007872485688, 0.04140715167990752, 0.05268165223034365, 0.03433342071782265, 0.030251038526850085, 0.06594561067010675, 0.022029624952535545, 0.008206093949931008, 0.012927959772891231, 0.0766698227130941, 0.0032133026647248437, 0.009810012482505823, 0.07575876052890505, 0.07782000742320504, 0.1967848584588085, 15.250403063637869, 81.76987511771065, 44.63350806917463, 89.4970293045044, 44.766777992248535, 61.379601206098286, 23.796287809099468, 33.85691806248256, 69.58569472176688, 1.5947083085775375, 3.090614970241274, 4.998713416712625, 0.5303347738725799, 0.1491605889584337, 37.17783042362758, 90.84696701594761, 76.81491320473808, 80.99626963479179, 74.62644604274205, 70.98918219975063, 65.23873492649624, 65.72682503291539, 70.05633790152413, 69.76631314413888, 60.86817904881069, 58.64527661459786, 59.56994983128139, 60.85844462258475, 56.29016733169556, 51.20264073780605, 54.92668063299996, 59.13163661956787, 61.08642891475132, 60.88219356536865, 59.04518713269915, 57.24965449741909, 47.1830974306379, 46.17962121963501, 45.8445999281747, 47.44699001312256, 47.63861438206264, 47.61311796733311, 50.76155866895403, 55.9918429510934, 51.3655412537711, 47.065339360918315, 44.322246142796104, 46.814985343388145, 44.932072162628174, 47.14773109980992, 50.011080265045166, 57.3804543358939, 58.13012327466692, 61.23673234667097, 59.391777174813406, 57.1551068850926, 56.069252831595286, 60.03903661455427, 56.45259884425572, 61.18316868373326, 41.86763865607125, 54.01370470864432, 60.28095204489571, 59.947007724217, 53.53512668609619, 52.36620691844395, 59.21610586983817, 56.575797353472026, 60.43520205361502, 56.57499483653477, 58.3135209764753, 45.954072271074565, 41.477695328848704, 41.729737758636475, 40.84290443147932, 39.934083529881065, 42.345959595271516, 41.64489677974156, 47.78459256035941, 55.589014189583914, 59.22884886605399, 61.636170387268066, 56.97904995509556, 54.43904215948922, 51.97859818594796, 49.940865244184224, 49.19785267966134, 50.306048665727886, 48.663848876953125, 50.329860142299104, 52.0890919140407, 52.92414379119873, 50.14198432649885, 45.89120149612427, 46.83511080060686, 47.49489436830793, 54.35523993628365, 64.79876804351807, 62.810395104544504, 65.2960923058646, 66.04388523101807, 65.7021380833217, 59.38748318808419, 61.157946722848074, 59.22671576908657, 63.58791937146868, 64.9799770627703, 43.975742953164236, 0.9352158052580697, 0.047860399686864445, 0.1374894202287708, 0.49623942055872505, 3.340649587767465, 3.5489465934889655, 0.7716093414596149, 6.816054276057652, 43.324019295828684, 16.45900399344308, 37.21247066770281, 45.991140910557334, 53.00016403198242, 41.42231123788016, 47.15406438282558, 0.09042625847671713, 0.029474014150244848, 0.031135614096586193, 0.01707748300395906, 0.011741850874386728, 0.03780032754210489, 0.0505216377787292, 0.0359937144842531, 0.05342393900666918, 0.05331413168460131, 0.053039440353001864, 0.017446974159351418, 0.03619834368250199, 0.09955838309334857, 0.016901264066940973, 0.043084761660013876, 0.05237284076533147, 0.08621037112815039, 0.02203460200689733, 0.03776732359879783, 0.0432464056648314, 0.013982154678420296, 0.08040780427732638, 0.05281232789691005, 0.08998392828341041, 0.04207841280315604, 0.029320838262460062, 0.0818191571161151, 0.039667113085410426, 0.010699740677539791, 0.05870272432054792, 0.0696536891960672, 0.025099027303180525, 0.028159880112590532, 0.0323373199706631, 0.0362592354150755, 0.05573248816654086, 0.09546449634113482, 0.03999467586566295, 0.03847084906218307, 0.05258994822257331, 0.0783601620101503, 0.022797339828684926, 0.05365092932645764, 0.060718197242489884, 0.008254274177098913, 0.05249925523198076, 0.060448622064931054, 0.05842546812657799, 0.08901737550539629, 0.15065361027206692, 0.08972922659346036, 0.24356679458703312, 22.113673823220388, 90.47895567757743, 49.33263036182949, 78.23116452353341, 54.75174931117466, 46.602940218789236, 22.074770859309606, 54.16035338810512, 67.1561667578561, 2.9047649885926927, 3.207189674888338, 16.374790089471, 0.8539197647145816, 0.09826865765665259, 40.374481201171875, 89.73448399135044, 79.28641523633684, 86.90170342581612, 75.28523254394531, 77.37101227896554, 68.263167653765, 70.82373169490269, 75.76611042022705, 69.57657868521554, 64.45819514138358, 61.3292476109096, 60.59340558733259, 62.67508588518415, 57.206398487091064, 53.89465774808611, 57.857409954071045, 62.29838235037667, 63.31091553824288, 64.73908301762172, 62.36316735403878, 58.1482059614999, 50.39852571487427, 48.18245335987636, 48.694094385419575, 49.98875917707171, 51.04575041362217, 50.35997016089303, 53.31536558696202, 56.58039011274065, 52.80415187563215, 47.0709604535784, 48.053956849234446, 48.61824090140206, 48.415200642177034, 50.80166367122105, 54.87744917188372, 57.90731191635132, 60.7228296824864, 61.74037252153669, 63.08764212472098, 59.185749190194265, 58.80241012573242, 61.35034234183175, 59.31638922010149, 63.55704157693045, 46.671241010938374, 55.61889839172363, 60.36961105891636, 62.26629556928362, 57.65624223436628, 54.69184194292341, 61.265748023986816, 57.61413267680577, 62.06898062569754, 59.35547978537423, 60.73437064034598, 48.48959847858974, 45.13739143099104, 45.65399694442749, 44.21072060721261, 43.27836268288748, 45.28077793121338, 44.32315983091082, 49.77397646222796, 57.944001879010884, 61.11064338684082, 63.65005711146763, 60.52774511064802, 57.23459775107247, 54.56425217219761, 52.7233373778207, 52.97609894616263, 53.54629591533116, 52.58628068651472, 54.64645283562796, 55.95926979609898, 57.48615033285958, 54.3789576121739, 48.117018699645996, 48.17679405212402, 51.11202580588204, 57.54545668193272, 67.04823344094413, 66.1001864842006, 66.60614040919712, 67.72064535958427, 68.03286961146763, 62.18811443873814, 62.772826194763184, 61.66915348597935, 64.86549854278564, 68.31129087720598, 45.9063937323434, 1.1962374789374215, 0.08662043698132038, 0.38221112212964464, 2.1331479932580675, 4.838513144424983, 2.4619230713163103, 0.6784592941403389, 7.624117612838745, 53.69395208358765, 20.36553485052926, 41.88308450153896, 51.734511443546836, 50.35671145575387, 48.36830724988665, 49.77886799403599, 1.1489691010543277, 0.05882449421499457, 0.02327425834456725, 0.0271970016017024, 0.03584753429251058, 0.07732013746031693, 0.023144731098519902, 0.06228427642158099, 0.03425763174891472, 0.04545791074633598, 0.11490188512418952, 0.025019857533542172, 0.004412662503974778, 0.03772708647219198, 0.010532229041148509, 0.049888357653149536, 0.05655766138806939, 0.03614880044811538, 0.029225941747426987, 0.02979103588898267, 0.058533884451857636, 0.03758638884340014, 0.025840657596875514, 0.04549081290939024, 0.09977047278412751, 0.19523637369275093, 0.13453668010021957, 0.24390530213713646, 0.20069288089871407, 0.12097242580992834, 0.11610089721424238, 0.21731151986335004, 0.09238486337874617, 0.19165047896759851, 0.10095892008394003, 0.1245733704417944, 0.16326455000255788, 0.12488665005990437, 0.12880130857229233, 0.11786474899521895, 0.1506033715392862, 0.23622195156557219, 0.14736031341765607, 0.14466883641268524, 0.09137116598763637, 0.1272635446595294, 0.14258857018181256, 0.16138565939451965, 0.1314555611461401, 0.19808881277484552, 0.23750641835587366, 0.27118748532874243, 0.2722121003483023, 30.1364460672651, 108.9309184210641, 57.160151277269634, 99.89851038796562, 63.72258240836007, 89.7495893750872, 29.763338225228445, 49.054771900177, 81.04387869153703, 4.027613205569131, 12.626716375350952, 22.194170440946305, 1.5011703563588006, 0.19398957916668483, 46.35821076801845, 90.03563976287842, 80.78349494934082, 88.0399364743914, 77.08856105804443, 79.63322762080601, 72.87230382646833, 75.25959369114467, 79.1301919392177, 76.85952758789062, 66.17053699493408, 66.69465351104736, 64.45349815913609, 68.60592229025704, 60.407214709690635, 56.821808746882844, 61.75056552886963, 64.61704485757011, 66.87322916303361, 68.1171304157802, 63.199820790972026, 61.23584297725132, 53.0492912701198, 51.64055790219988, 52.277474948338096, 54.74984203066145, 54.912329128810335, 53.978724002838135, 57.84579256602696, 61.03995936257498, 55.81513289042881, 51.569866929735454, 49.63438367843628, 52.974149976457866, 49.98757103511265, 54.50519595827375, 55.37848029817854, 60.32282188960484, 61.68195901598249, 64.67467321668352, 62.037428855895996, 61.26023115430559, 59.45882034301758, 62.43965312412807, 60.564056396484375, 65.19254330226353, 46.76262719290597, 55.8047661781311, 61.65076160430908, 64.99376923697335, 58.232282638549805, 55.97320440837315, 63.670908655439106, 59.21882956368582, 65.75205394199916, 61.18341881888253, 62.148905754089355, 51.059563432421, 46.56677484512329, 47.39101879937308, 46.36819185529436, 44.6423704964774, 48.5085323197501, 45.3935089792524, 52.33395685468401, 61.5363039289202, 63.70143904004778, 67.13942854745048, 64.15758827754429, 59.04052489144461, 57.26773023605347, 56.558767318725586, 56.51134238924299, 56.643531867435996, 53.959230831691194, 58.02575090953282, 58.87057890210833, 60.17515877314976, 56.89512961251395, 51.12607158933367, 52.95181846618652, 53.33767277853829, 58.60331644330706, 69.77616568974086, 67.9158411026001, 67.87832777840751, 71.90256459372384, 69.84209714617047, 65.05191176278251, 67.62190450940813, 66.2854254586356, 66.90812301635742, 72.28202656337193, 50.99484096254621, 1.4576956949063709, 0.20094644943518297, 0.31731312881623, 2.9304511759962355, 13.754871930394854, 9.361883793558393, 1.9335399270057678, 8.79699785368783, 54.70872259140015, 24.307767289025442, 56.29429108755929, 53.83827659061977, 62.07059260777065, 51.548935481480186, 72.35501044137138, 2.9000389107636044, 0.1923826996769224, 0.1433062023882355, 0.1847654791282756, 0.08932969160377979, 0.14033647174281733, 0.2738354818097183, 0.08229410448776824, 0.1676152894007308, 0.1404895085309233, 0.3072836212813854, 0.12521994646106446, 0.1092693048662373, 0.1661219966730901, 0.07322272232600621, 0.12649958208203316, 0.18989063054323196, 0.27995725188936504, 0.11389877966472081, 0.11816261229770524, 0.15102562388139112, 0.07246599971715893, 0.10811396328998463, 0.11469729324536664], [0.04573439001770956, 0.05503716958420617, 0.031004660230662142, 0.008243340433442166, 0.02956165712592857, 0.0910840303237949, 0.017043547771338905, 0.03413397213444114, 0.035600832530430386, 0.0707925423713667, 0.012012024859099515, 0.05766076594591141, 0.01575279944310231, 0.02088189314651702, 0.0314727238645511, 0.061198158987930844, 0.015247623336368372, 0.01757729359503303, 0.07614093859280859, 0.04114431435508387, 0.04593247813837869, 0.04832405962848237, 0.04732200589829257, 0.021897626142682772, 0.021296578126826456, 0.03299595694988966, 0.039627639310700555, 0.046165639734161754, 0.04223870313061135, 1.3365579779658998, 60.490162304469514, 60.87284129006522, 75.5533982685634, 55.32933221544538, 35.89126375743321, 37.987389360155376, 14.69171404838562, 60.89598573957171, 4.592148261410849, 3.907111031668527, 20.686440876552037, 0.10584747990859406, 0.15926392110330717, 0.6765109758291925, 33.54505859102522, 83.22343131474086, 77.19751576014927, 74.92437785012382, 62.965729032244, 62.13420336587088, 70.06091676439557, 73.39381476811, 65.63654014042446, 62.42945316859654, 64.43828855242047, 72.32144369397844, 74.51273877280099, 70.56990705217633, 54.47827863693237, 52.58808374404907, 57.99580069950649, 62.87119879041399, 63.36511843545096, 60.343631744384766, 55.221739360264365, 49.72867768151419, 47.99789183480399, 46.13998522077288, 48.53009952817644, 49.631559235709055, 53.119978768484934, 59.94675064086914, 63.84370340619768, 62.148989132472444, 55.04414687837873, 47.40878186907087, 45.67425094332014, 46.09969956534249, 45.9213045665196, 48.849115644182476, 56.14360897881644, 59.47232069287981, 60.90251704624721, 59.9812901360648, 57.99174295152937, 61.638039452689036, 57.47346292223249, 58.31122807094029, 60.9884523664202, 34.55931493214199, 50.45485128675188, 61.714990752083914, 53.376332555498394, 50.44970267159598, 57.52800628117153, 57.9498279435294, 58.042899063655305, 58.464421953473774, 57.11292437144688, 58.270886829921174, 47.48652873720442, 41.988005774361746, 43.337054116385325, 42.547193322862896, 43.50683682305472, 42.70500428336007, 45.7601306779044, 56.1579396384103, 60.55536420004708, 61.50442559378487, 62.20141329084124, 59.47744846343994, 55.11289930343628, 52.6788341658456, 52.442400864192415, 52.788952691214426, 50.843120098114014, 51.211082799094065, 52.204484122140066, 53.604622568402974, 51.84995228903634, 53.53400455202375, 53.9593802179609, 44.63674940381731, 43.16438095910208, 49.968161242348806, 62.33777863638741, 63.70678915296282, 66.97863333565849, 65.02252088274274, 65.76057938167027, 63.23356819152832, 58.40753705160958, 57.04150036403111, 61.111546652657644, 43.40338509423392, 6.354191013744899, 0.22732072563043662, 0.06772326385336262, 0.1505847525383745, 2.0889483307089125, 2.9479391404560635, 2.720981878893716, 1.2132240874426705, 10.619327085358755, 20.71561983653477, 22.57544067927769, 43.134243147713796, 87.93524101802281, 51.65854678835188, 43.81135899680001, 8.217788202422005, 0.29222331941127777, 0.11948278360068798, 0.1527028674525874, 0.09884509351104498, 0.025926611020362804, 0.12749918630080564, 0.07024975506854908, 0.05117973532261593, 0.017197313984589915, 0.049314520587878566, 0.008895378659612365, 0.0031888181526613024, 0.016200593539646695, 0.054476560559123755, 0.019101995708686963, 0.028343320358544588, 0.029637931247374842, 0.10301539009170872, 0.0269259794482163, 0.046948445229125876, 0.01943883066996932, 0.09180285675185067, 0.013219396500582141, 0.06962937050099884, 0.023980229926694716, 0.014211676781997085, 0.01785948104225099, 0.05927199484514339, 0.030891975920115198, 0.004759161076175847, 0.044784027085240395, 0.02570483524219266, 0.035598824066775184, 0.03893585589581302, 0.03196619863488844, 0.07284382837159292, 0.019931798235380223, 0.04329814396000334, 0.012761101226455398, 0.04391853870557887, 0.02933761164812105, 0.0484199841240687, 0.06318172719329596, 0.01201179500536195, 0.0343340008652636, 0.055090173347187896, 0.10785023708428655, 0.0275998817690249, 0.026470791016306196, 0.046185320642377646, 0.06559418381324836, 0.04746167893920626, 0.006569872909624661, 1.5627011060714722, 69.01276016235352, 68.40094348362514, 73.04257638113839, 62.44184875488281, 50.48792471204485, 28.717830623899186, 25.614751236779348, 72.87541661943708, 3.7526278240340094, 0.6648372422371591, 2.959818822996957, 2.871978827885219, 0.6340861437576157, 0.46982692927122116, 40.04871143613543, 83.22253499712262, 80.4884535925729, 79.7910212108067, 67.70030103410993, 68.78643648965019, 72.03129386901855, 73.87440776824951, 67.69580554962158, 63.97525365012032, 65.87397398267473, 75.8536924634661, 76.63113335200718, 70.31162166595459, 56.10549463544573, 56.357710770198274, 61.89680426461356, 64.5810740334647, 66.06724507468087, 63.375415665762766, 56.8281455039978, 51.443802288600374, 50.55980035236904, 49.576487813677105, 50.93730640411377, 54.03597021102905, 55.11713770457676, 62.53471837724958, 66.24443108694894, 64.0931645802089, 55.581350326538086, 48.74525397164481, 47.65230928148542, 47.86685575757708, 48.8573249408177, 49.306720529283794, 58.691190310886924, 61.889598982674734, 62.87823036738804, 63.3112907409668, 61.348257882254465, 63.430097988673616, 61.54124409811837, 60.9161285672869, 63.67153399331229, 38.995239462171284, 51.4593870980399, 63.07200867789132, 56.994798047201975, 55.05919667652675, 62.43642915998186, 61.06973239353725, 60.825537954057964, 62.230720792497905, 59.181357928684776, 60.50325271061489, 50.84133093697684, 44.228341238839285, 45.551108019692556, 45.42616203853062, 45.586477824619834, 46.46058552605765, 46.41878168923514, 57.795470237731934, 63.497773442949565, 65.51664202553886, 64.52632222856793, 60.37159129551479, 58.004232338496614, 56.0152062688555, 56.43666315078735, 56.176595551627024, 56.20069537843977, 55.21669496808733, 56.60212755203247, 56.83715384347098, 57.80726133074079, 57.259941305433, 56.15929453713553, 46.53545931407383, 46.217554909842356, 52.26519053322928, 65.75072683606828, 65.40905611855644, 71.18593433925084, 66.23348072596959, 69.6975120816912, 66.1356222970145, 63.084904534476145, 59.9532402583531, 64.19486536298479, 45.07829352787563, 7.293560538973127, 0.2941259044621672, 0.7149218118616513, 0.8801749444433621, 4.243326110499246, 3.6644356421061923, 1.2895662252392088, 0.83531753718853, 12.907988139561244, 28.968940258026123, 24.949766942432948, 54.019120829445974, 75.689298084804, 51.280464036124094, 52.20712791170393, 13.445228934288025, 0.4434246431503977, 0.07099583146295377, 0.19852131099573203, 0.19813474959560803, 0.047269080166838, 0.0708779360034636, 0.17056327978415148, 0.03570964579869594, 0.032748593616166284, 0.02286102882187281, 0.0433230665512383, 0.04797299578785896, 0.04391984149281468, 0.02522687517505671, 0.11483506299555302, 0.017239259323105216, 0.003602902205394847, 0.08932372049561568, 0.04235564185572522, 0.045048306296978674, 0.00511531053676403, 0.04954961261578968, 0.028225311244438802, 0.030281216371804476, 0.18202596184398445, 0.12613678297826222, 0.1323698056595666, 0.11811696046165057, 0.15768152315701756, 0.10424897354096174, 0.15208559057542256, 0.1006286974464144, 0.11779753331627164, 0.08535988176507608, 0.07987202624125139, 0.10580665245652199, 0.07976392882743052, 0.10995985674006598, 0.08830433019569942, 0.17252096187855515, 0.17352948204747268, 0.09380005672574043, 0.14319558760949544, 0.14689892317567552, 0.13720655255019665, 0.12962277020726884, 0.2758767051356179, 0.14459726453891822, 0.05268105851220233, 0.1475777703204325, 0.13854186875479563, 0.1468327660113573, 0.05996771715581417, 3.8929905550820485, 89.78037684304374, 73.22420229230607, 87.50655106135777, 62.92734023502895, 60.629202706473215, 53.88369696480887, 21.729897022247314, 73.77874497004917, 6.79091135093144, 9.767141819000244, 44.020082882472444, 2.383224082844598, 0.41909870132803917, 1.0833656213113239, 41.77005468096052, 84.98613371167863, 82.08621965135846, 82.21779768807548, 70.79722431727818, 74.97389766148159, 76.6724681854248, 79.04716096605573, 72.17072337014335, 68.28015599931989, 70.2608859198434, 77.428147315979, 80.07047080993652, 76.71654060908726, 60.723983083452495, 59.48671041216169, 65.84258896963937, 67.73008101327079, 69.47899123600551, 64.96296787261963, 59.66257626669747, 54.697160788944785, 53.36320740836007, 53.08862502234322, 54.97275413785662, 56.87094293321882, 60.2082530430385, 66.24686990465436, 69.33787332262311, 67.86823899405343, 61.05657945360456, 52.48056384495327, 49.70645039422171, 49.46116508756365, 50.875380584171836, 52.86038712092808, 61.28995554787772, 64.33205754416329, 64.28820051465715, 63.71924727303641, 64.28262111118862, 64.31723703656877, 63.491394996643066, 62.684674399239675, 65.08816051483154, 38.8883171081543, 50.761357171194895, 63.542082105364116, 57.074014459337505, 57.484329904828755, 63.29813085283552, 62.85777487073626, 62.793184416634695, 64.54215022495815, 61.897874287196565, 61.968155315944124, 52.59852341243199, 46.68323360170637, 47.30234241485596, 47.59228726795742, 48.239154134477886, 47.1228461265564, 49.57350703648159, 61.73533507755825, 65.46938037872314, 66.20630632128034, 66.85929107666016, 63.22078350612095, 60.03764002663748, 58.462413924080984, 59.20374502454485, 60.14316231863839, 57.46854707172939, 59.21525124141148, 58.36794621603829, 60.50307205745152, 59.72052424294608, 61.5611298424857, 61.64482089451381, 49.84867654527937, 50.37300498144967, 53.70247057506016, 66.77320984431675, 67.9744769505092, 73.98106956481934, 68.22493171691895, 71.03782653808594, 68.49336842128209, 64.9714446749006, 63.07558700016567, 67.53596224103654, 47.04138544627598, 8.466096843991961, 0.4849837188209806, 0.7166456165058273, 0.3589634267347199, 7.6024401017597745, 11.553125023841858, 7.675951174327305, 2.2931424251624515, 13.997912100383214, 30.64389385495867, 37.12527077538626, 58.670679228646414, 86.56989915030343, 61.67870725904192, 60.44725022997175, 28.20895324434553, 0.6964283127869878, 0.22596615260200842, 0.3212396481207439, 0.3510984187679631, 0.20208281917231424, 0.16208159205104622, 0.3037700041064194, 0.11242532730102539, 0.19311083560543402, 0.09785133826413325, 0.0793788805603981, 0.12047894086156573, 0.09590034652501345, 0.11453838034399919, 0.18813488047037805, 0.10885558849466698, 0.09774881162281547, 0.17128701880574226, 0.12748754263988563, 0.1428548137524298, 0.09668729108359132, 0.20176731395934308, 0.15444386617413589, 0.12702304470751966], [0.015268724079110792, 0.0285720409426306, 0.11027578264474869, 0.02380578705508794, 0.03362729985799108, 0.047082089486398866, 0.06016762035765818, 0.0923414235668523, 0.116817389481834, 0.047153067642024586, 0.057379282478775294, 0.10815793235919305, 0.0015999935255552242, 0.04298712047083037, 0.03333207944940243, 0.08390118075268609, 0.13708555618567125, 0.06293898129037448, 0.04995068787996258, 0.09460001558597599, 0.07111834774592093, 0.02038427422355328, 0.04844788548403552, 0.0430090948274093, 0.0689816138307963, 0.02111324983915048, 0.05385313615468996, 0.08883719053119421, 0.03798221903187888, 0.20549521249319824, 21.517355101449148, 83.43605313982282, 30.01769093104771, 31.05478252683367, 38.67729336874825, 54.78857476370675, 15.401555912835256, 36.95769412176949, 11.534478664398193, 1.1849100696189063, 7.606573411396571, 1.4948056978838784, 0.5114492444055421, 0.42304345965385437, 0.1423026898077556, 14.239606056894575, 62.03985377720424, 58.60624163491385, 66.4452896118164, 72.74396365029472, 81.56741155896867, 73.87970924377441, 69.2570240838187, 68.55686106000627, 74.92211273738316, 77.14681475503104, 71.63246032169887, 74.85776547023228, 61.45774064745222, 54.988880906786235, 61.43627766200474, 61.53405271257673, 62.4855112348284, 59.69874164036342, 55.858979497637065, 48.90982205527169, 48.640711375645225, 50.80379676818848, 49.95708581379482, 51.76066446304321, 54.07999052320208, 61.21303898947579, 66.09497533525739, 65.11407034737724, 61.848062651497976, 52.32874917984009, 47.326094831739155, 44.75626189368111, 47.95548350470406, 46.38234186172485, 49.637989793504985, 53.84907756532942, 59.6427252633231, 58.01911537987845, 59.97102764674595, 54.64452818461827, 57.43682507106236, 56.71838828495571, 62.395559855869834, 31.536539350237163, 50.3287866456168, 58.37776402064732, 49.96714333125523, 63.55472782679966, 58.160379205431255, 63.03689248221261, 59.96428789411272, 61.34866087777274, 58.56456633976528, 56.504897935049875, 46.98744658061436, 42.27498722076416, 42.74736745016915, 44.02100351878575, 43.29363134929112, 44.94604846409389, 49.34573466437203, 57.42212268284389, 61.212100982666016, 57.94149705341884, 58.2047712462289, 60.2060296194894, 56.5753561428615, 55.403267996651785, 51.955759457179475, 52.26675387791225, 50.48506900242397, 50.45589351654053, 50.40342419488089, 52.41176625660488, 55.77308586665562, 55.65129089355469, 55.23914459773472, 50.85930940083095, 46.22546195983887, 51.957552092415945, 60.68291228158133, 62.64509746006557, 65.65422330583844, 65.0207768848964, 65.84263065883091, 64.77667972019741, 55.46850115912301, 47.80614239828927, 35.508817536490305, 7.089475444384983, 0.011472290115697044, 0.03910199519512909, 0.17099096040640557, 0.818955560880048, 1.9605623398508345, 1.8184707015752792, 0.964230396917888, 0.14717473409005574, 17.010671854019165, 31.19696351460048, 43.61529472896031, 28.690576314926147, 38.28429283414568, 44.615408011845176, 50.76005438395909, 1.1523707870926176, 0.23521353996225766, 0.04673802134181772, 0.07701987214386463, 0.009968599687064332, 0.02563929384840386, 0.03238252058093037, 0.03942778021363275, 0.0748442310307707, 0.054556648047374826, 0.05119662745190518, 0.03152927975835545, 0.11932986894888536, 0.07431881422443049, 0.08135292891945158, 0.009833885040799422, 0.021686294714787176, 0.04946075506242258, 0.02556593912387533, 0.04651909880340099, 0.02368207655048796, 0.031666469361100874, 0.0406644611752459, 0.06992309473987136, 0.04544020776769944, 0.059110632432358604, 0.04756011401436158, 0.09068953006395272, 0.04520517002258982, 0.02241101591581745, 0.06078033069414752, 0.012984643740180348, 0.07235417036073548, 0.0679028517167483, 0.032783368535872014, 0.01570149201766721, 0.03293888536947114, 0.02550899307243526, 0.01810801145620644, 0.09311187972447701, 0.044883194978215864, 0.059120457619428635, 0.024378490966877768, 0.0036152277940085954, 0.037961014812546115, 0.03793432463758758, 0.03612775907718709, 0.02561219994510923, 0.0298841478569167, 0.04868648214531796, 0.028298248669930866, 0.04118236320625458, 0.07963118702173233, 0.1123984098168356, 0.33749479587588993, 24.699223586491176, 93.24570056370327, 36.92635079792568, 33.89965295791626, 48.94491045815604, 52.14549739020211, 14.314224498612539, 52.57190833772932, 10.285259434155055, 0.8947354917015348, 3.300636866262981, 6.892874428204127, 1.6882912069559097, 0.8884066598755973, 0.1257539942328419, 17.578793048858643, 65.19098690577916, 65.4442834854126, 71.8235844203404, 75.96468993595668, 80.99920177459717, 76.4597977229527, 71.58510834830147, 68.82350512913295, 79.17113767351422, 80.54565116337368, 76.46546050480434, 75.63408075060163, 66.1518463407244, 56.2604637827192, 63.492062023707796, 64.45949445452008, 64.0841875076294, 62.4027373450143, 58.3658687046596, 51.2421864100865, 53.3089975629534, 54.895653452192036, 54.54499176570347, 52.975060190473286, 57.673977511269705, 63.064984049115864, 67.32154083251953, 69.0232241494315, 63.33963244301932, 52.36180523463658, 48.468239716121126, 47.23645959581648, 51.70382472446987, 49.73890542984009, 53.51730803080967, 55.4841867174421, 63.47920090811593, 59.36110087803432, 62.48617131369454, 57.914340019226074, 60.10962336403983, 59.059736660548616, 66.78791223253522, 33.72232450757708, 52.313431876046316, 62.026666096278596, 52.260660307747976, 65.00303118569511, 61.32798303876604, 62.455904960632324, 61.08531025477818, 62.861374037606375, 60.671322686331614, 59.896417890276226, 50.70912408828735, 44.25878129686628, 45.5722096988133, 47.97330215999058, 45.970511708940776, 47.8440066065107, 53.19854204995291, 61.57111440386091, 64.31932844434465, 61.02316556658064, 64.03707177298409, 61.94261373792376, 61.55976104736328, 60.20157582419259, 57.38582876750401, 57.26298461641584, 54.67995704923357, 54.071809019361226, 57.34661660875593, 57.75371503829956, 59.997819900512695, 59.762456621442524, 59.203988211495535, 53.354056630815776, 49.69894981384277, 53.41644103186471, 63.096445492335725, 67.21294743674142, 68.48173713684082, 66.7514202935355, 69.863831111363, 68.24237169538225, 58.75209127153669, 51.272223472595215, 37.429598399571006, 8.040897488594055, 0.10374590089278561, 0.062324900313147476, 1.1749531924724579, 2.8218230392251695, 4.959487361567361, 4.346923317228045, 0.851886330970696, 0.06774419665868793, 20.2852258341653, 30.01556130817958, 52.75826249803816, 37.95488568714687, 40.9600510597229, 49.45978587014334, 57.96764312471662, 2.2037751291479384, 0.27353014105132645, 0.03929392561050398, 0.10283951381487505, 0.017921383792002286, 0.04224582435563207, 0.027341183507815003, 0.06420988416565315, 0.03894800506532192, 0.07661496994218656, 0.010420553203273033, 0.017947636311873794, 0.09182820003479719, 0.030956602987966368, 0.05750806163996458, 0.0628936347950782, 0.07091512650783573, 0.0844051151403359, 0.046342598274350166, 0.05105591964508806, 0.029528113747281686, 0.036517329780118804, 0.09439255350402423, 0.04925208518813763, 0.042954693282289166, 0.11672920707081046, 0.08053711948118039, 0.21139835858983652, 0.0945271612810237, 0.13031152396329812, 0.19173725002578326, 0.13062592994953903, 0.19384190280522617, 0.1654855851083994, 0.09892466531268188, 0.15164896686162266, 0.17468086097921642, 0.07360697670706681, 0.09307220578193665, 0.31455371688519207, 0.16413026569145067, 0.22647293683673653, 0.10684652772865125, 0.1281016439731632, 0.23557674618703978, 0.1801177313817399, 0.146727090967553, 0.08490153135997908, 0.11441268851714474, 0.23728898859449796, 0.13241095202309744, 0.17306050578398363, 0.13047887784029755, 0.2747403218277863, 0.27323921237673077, 35.32703876495361, 111.42361940656389, 43.28839588165283, 49.69972453798567, 49.44608749662127, 82.1287704195295, 22.636709894452775, 51.03558867318289, 14.439686383519854, 3.022040809903826, 17.784918308258057, 7.977102603231158, 0.7142654785088131, 0.6023359160338129, 0.2586003893188068, 18.387354918888636, 66.1610666002546, 70.81423350742885, 79.03547409602574, 82.5509568623134, 87.88497774941581, 80.95954145703996, 74.1502651487078, 72.39378138950893, 81.56382628849575, 85.55270372118268, 79.35534831455776, 80.52999687194824, 69.83925533294678, 60.111124174935476, 65.72713770185197, 66.89330945696149, 67.85746928623745, 65.50180067334855, 62.45632880074637, 55.32657725470406, 55.08316101346697, 57.45334441321236, 57.48816531045096, 57.65658269609724, 59.55025863647461, 65.66764722551618, 70.91637897491455, 70.85408837454659, 66.2423813683646, 57.16405963897705, 50.27980531964983, 49.24397829600743, 53.19271945953369, 51.74597944532122, 55.64143487385341, 58.27653571537563, 65.4762521471296, 63.072675704956055, 64.87445477076939, 58.29148823874337, 61.55654403141567, 62.32160323006766, 68.52206448146275, 37.14206804547991, 53.026080812726704, 62.097350120544434, 55.96154533113752, 65.0552191053118, 61.706124850681846, 65.34677246638707, 64.2479704448155, 64.34856646401542, 62.44735172816685, 61.51702962602888, 51.969172954559326, 46.270854541233604, 46.88108008248465, 49.22379725319998, 47.36921535219465, 50.676394598824636, 55.20777348109654, 62.35140405382429, 65.32021645137242, 62.162274088178364, 64.0379194532122, 64.77243437085832, 62.53626087733677, 63.04768998282296, 61.11966214861189, 60.88907923017229, 57.9222366469247, 58.71936525617327, 59.63989734649658, 59.8866000856672, 63.3717748097011, 62.446240016392295, 61.618855476379395, 57.340161732264924, 53.736565385546, 55.80953959056309, 65.44879981449672, 68.89603737422398, 71.45514229365757, 68.51647118159703, 72.35258552006313, 70.51132678985596, 63.413880893162315, 53.76640789849417, 39.0354973248073, 8.721429245812551, 0.39074755406805445, 0.11736818349787168, 1.0745449917657035, 4.656436468873705, 13.232019117900304, 6.772604150431497, 2.895583595548357, 0.5766426175832748, 24.31251811981201, 42.623470646994456, 62.27983066013881, 40.08299732208252, 52.78050715582711, 55.61082805906023, 74.64082186562675, 5.593794056347438, 0.782837196120194, 0.23207303562334605, 0.2243632628981556, 0.18777593544551305, 0.16980424337089062, 0.16617884433695249, 0.16326582564839295, 0.3029592361833368, 0.17000133065240725, 0.10236474286232676, 0.09149731921830348, 0.2788300695163863, 0.18486189895442554, 0.09911583576883588, 0.1262283037815775, 0.13993609536971363, 0.16010162686663015, 0.16501753165253571, 0.24172177644712584, 0.10991451024476971, 0.17561398233686173, 0.17338773608207703, 0.12914026395550796, 0.18724222694124493], [0.02903102238529495, 0.06781440467706748, 0.00512770821972351, 0.07824535388499498, 0.03965658900727119, 0.007929114258981176, 0.04400725715926715, 0.025055270276165435, 0.0825069337817175, 0.017628558612029468, 0.07424809730478696, 0.05223038233816624, 0.0710238346031734, 0.06160655564495495, 0.023593894139464413, 0.058377733188016076, 0.07962651870080403, 0.08427335721041475, 0.0197732178161719, 0.12012644191937787, 0.05068628769367933, 0.05037423283127802, 0.13186418850507053, 0.08396065434707062, 0.06685638786958796, 0.04846133744078023, 0.08965308139366762, 0.07745452132076025, 0.05461152456700802, 0.03471866576001048, 0.20185527923916066, 50.492618220193044, 72.52352510179792, 45.718048913138254, 41.785587378910606, 55.731295926230295, 31.460717133113317, 22.79789767946516, 22.590763194220408, 0.5195575750299862, 0.561501570045948, 7.393755299704416, 5.747327966349466, 0.5834513093744005, 1.3535886641059602, 0.17663254482405527, 13.406055859157018, 58.590830530439106, 65.20605060032436, 87.12417084830147, 79.72891126360211, 77.72146551949638, 72.16004398890904, 79.35565403529576, 77.56366498129708, 77.39213480268205, 81.2906300680978, 75.93579237801688, 65.44928618839809, 56.58045612062727, 63.202759878976, 66.49842943464006, 65.500230380467, 60.97160298483712, 54.73997906276158, 47.5513345854623, 50.466722284044536, 50.990203039986746, 53.88897064753941, 56.397947788238525, 64.45697225843156, 65.6777776990618, 67.6453685760498, 66.11354787009103, 63.87691579546247, 56.45573248182024, 53.29280478613717, 47.231887681143625, 47.91501372201102, 46.5161190032959, 50.33137484959194, 54.89048746653965, 58.33352484021868, 58.508035796029226, 61.78518145424979, 53.37237903050014, 61.53789506639753, 55.94430685043335, 64.03613376617432, 23.33822086879185, 46.98861040387835, 58.07079608099801, 61.7774133682251, 64.78674765995571, 60.173199381147114, 63.055645670209614, 59.73153018951416, 59.87747710091727, 55.74290289197649, 55.095546177455354, 47.083425521850586, 42.708655561719624, 46.166624614170615, 45.08402579171317, 45.051806994846885, 50.44726037979126, 52.63374730518886, 59.02284867422921, 59.112945965358186, 56.26708541597639, 55.64363745280674, 58.77117797306606, 59.31404767717634, 56.799960136413574, 54.532648290906636, 51.583613940647666, 51.64376449584961, 48.70893226351057, 51.8728848184858, 53.19713156563895, 55.18306916100638, 56.763919830322266, 57.46795994894845, 52.02316740580967, 44.877518381391255, 47.715277331215994, 53.1313807623727, 63.596576826913015, 65.31029442378453, 64.47321714673723, 59.80114419119698, 58.44072164808001, 39.25043290002005, 23.829178844179424, 8.255799191338674, 0.023230458909113492, 0.04695402617965426, 0.045768757816404104, 1.0215737713234765, 5.335894729409899, 2.71191252555166, 2.4844402287687575, 0.5727015233465603, 0.24335669300385884, 13.089875476700918, 52.533349309648784, 30.71075984409877, 18.44249929700579, 26.877958059310913, 56.16585711070469, 24.173601048333303, 0.26438661026103155, 0.08381257764995098, 0.0756558742640274, 0.02962863531761936, 0.03180497871445758, 0.07440952078572341, 0.023849340521597436, 0.037029284451689036, 0.03122548945248127, 0.15464635459440096, 0.023705681087449193, 0.018506082506584268, 0.08232586671199117, 0.05626268864476255, 0.07000835266496454, 0.04476880754477211, 0.114804243935006, 0.08868990772004638, 0.004408731241710484, 0.0882622135270919, 0.041088867866035016, 0.09253489425671951, 0.029242002671318393, 0.0370141938328743, 0.07802717773509876, 0.013520130006197308, 0.04115340672433376, 0.06699960625597409, 0.023846480496493832, 0.04463434226012655, 0.01186192867213062, 0.036438874168587584, 0.02251910654428814, 0.05994081324232476, 0.028963464046163217, 0.039828149801386256, 0.04923118970223835, 0.021720626890393238, 0.03662598698533007, 0.006735668700587536, 0.08497375462736402, 0.05585314187088183, 0.12589970284274646, 0.0307422707389508, 0.022170685597562363, 0.01301158921393965, 0.040324854398412366, 0.09057831138904605, 0.024261435194473182, 0.04576290884454336, 0.03914956049993634, 0.007626024540513754, 0.027741878792377453, 0.07154203858226538, 0.02579326701483556, 0.3732797013861792, 54.85711179460798, 81.02896785736084, 41.9657506942749, 45.859205041612896, 68.72573007856096, 22.821118559156144, 31.5091495513916, 26.482280731201172, 0.404455725635801, 1.0070694067648478, 4.296746901103428, 5.359235899788993, 3.7278596673692976, 4.784732350281306, 0.04524294067440288, 14.811462777001516, 63.281225885663716, 68.99798134395054, 86.39202526637486, 79.17765508379254, 77.6608007975987, 74.20448889051164, 80.78981086186, 79.69980525970459, 80.8848900113787, 84.24357972826276, 77.03398990631104, 69.34093747820172, 59.98205443790981, 67.54717663356236, 69.3966759272984, 67.26348168509347, 63.820482526506694, 57.495631149836946, 50.71233763013567, 51.58433307920183, 55.235184124537874, 56.70327247892107, 58.85924639020647, 65.03893947601318, 67.9433490208217, 70.101473399571, 68.77655615125383, 66.3279275894165, 58.342258725847515, 54.9907534463065, 49.04029532841274, 50.518833773476736, 49.199384757450645, 53.675667898995535, 58.49511909484863, 61.39999416896275, 61.28665515354702, 64.3307443346296, 57.30731759752546, 64.93955244336809, 61.846158845084055, 66.38560458592006, 25.592157432011195, 49.77151679992676, 60.7118376323155, 63.06180872235979, 67.354537827628, 61.485957281930105, 65.80252565656389, 63.24408776419503, 63.52679606846401, 57.984357016427175, 59.77879878452846, 50.44366121292114, 45.74532754080636, 47.74937908990042, 48.298397949763704, 45.97234255926949, 52.81090552466256, 54.39258997780936, 63.15532452719552, 64.02555165972028, 60.07141521998814, 57.97973299026489, 61.313655853271484, 62.77537618364607, 61.01641886574881, 58.804126330784385, 57.5244904926845, 56.545242650168284, 55.80794150488717, 55.86111606870379, 56.54444013323103, 58.66180637904576, 62.089172090802876, 60.99293395451137, 56.726281438555034, 48.94071027210781, 52.32608454568045, 56.792181628090994, 66.43294266292027, 68.8435367856707, 68.5089532307216, 62.6378504889352, 62.24733393532889, 41.801547391074045, 25.35909574372428, 8.631331086158752, 0.05261486742113318, 0.29919377395084923, 0.4548872709274292, 2.7899468754019057, 6.19877370766231, 2.4011226424149106, 1.946237977061953, 0.5654753968119621, 0.2907495956335749, 16.468529973711284, 56.43060084751674, 41.40494768960135, 24.108715295791626, 29.804343019212993, 66.5211569922311, 23.42938470840454, 0.3409528003207275, 0.08463372037346874, 0.04463032194014106, 0.01801066712609359, 0.015528178906866481, 0.07552903571299144, 0.014693490928038955, 0.011282804122726833, 0.033168301451951265, 0.13781454706830637, 0.039528451061674526, 0.06243492476642132, 0.014836086758545466, 0.03673068493870752, 0.03249517775007656, 0.06350296602717467, 0.053289843523608785, 0.06582221907696553, 0.01807477341831795, 0.055263423693499396, 0.018067129721332873, 0.029519815264003615, 0.027307375500510846, 0.030633752633418356, 0.039283303144787035, 0.07587096986493894, 0.10434957314282656, 0.1526881025305816, 0.1272772510669061, 0.1318883036396333, 0.07319979462772608, 0.10543231825743403, 0.1425226301487003, 0.11852709416832242, 0.1161457212375743, 0.12020923676235334, 0.11395584445978914, 0.16486539053065435, 0.06338059902191162, 0.22752035063292297, 0.18386274256876536, 0.3222511809851442, 0.31661765756351606, 0.1336710729769298, 0.19473371495093617, 0.13842167306159223, 0.14206620678305626, 0.23497700265475682, 0.18059387297502585, 0.21089834613459452, 0.1302303033215659, 0.15028695708939008, 0.20520247891545296, 0.19250855435218128, 0.2183770098324333, 0.9691998788288662, 79.76702213287354, 85.22390106746128, 65.08136517660958, 60.60809407915388, 73.04037380218506, 50.29371908732823, 34.25744697025844, 28.91540959903172, 0.4790688476392201, 4.243372142314911, 18.312936237880162, 13.053039601870946, 1.7073105978114265, 2.968896644456046, 0.1529069979275976, 15.581109523773193, 67.58610044206891, 73.95647294180733, 92.93844427381242, 83.17250796726772, 80.90869453975132, 76.88842514583042, 86.03342178889683, 82.2709653036935, 80.68514319828579, 89.43746934618268, 81.83006736210415, 72.48114803859166, 60.950480461120605, 70.50284303937639, 73.42229543413434, 72.03941631317139, 67.85216781071254, 60.40353911263602, 52.47430351802281, 57.32464293071202, 59.26029641287667, 59.64185673849923, 62.24142101832798, 70.27658884865897, 71.18802574702671, 72.46598012106759, 71.48710400717599, 67.7767312186105, 62.05506338391985, 58.61938067844936, 51.94838047027588, 52.979576519557405, 51.99256406511579, 56.014799799237935, 60.27348273141043, 65.50116838727678, 62.54293114798409, 64.87776211329869, 59.90474183218819, 65.60544000353131, 61.41605840410505, 68.0918389729091, 27.73488286563328, 52.21350983210972, 63.91732651846749, 62.93686621529715, 67.13903944832938, 65.24323041098458, 69.13636861528668, 66.25591645921979, 64.23669351850236, 59.986098289489746, 60.649206570216585, 53.018646240234375, 48.972932543073384, 50.4579883984157, 50.0693895476205, 48.573268686022075, 53.817449365343364, 56.54383216585432, 65.06874029976981, 65.233370917184, 62.042563574654714, 58.50212287902832, 63.037483079092844, 64.09324101039341, 63.08568273271833, 63.55444295065743, 60.90907614571707, 60.92163154057094, 58.099915981292725, 60.78625283922468, 60.08214323861258, 62.18419565473284, 65.33618341173444, 64.21382004874093, 58.05086169924055, 50.152517795562744, 53.77002790996006, 59.218127795628135, 69.36950847080776, 71.52130304064069, 69.70138917650495, 64.3813202721732, 64.68173258645194, 45.078151089804514, 28.02954728262765, 10.135722041130066, 0.18909644601600512, 0.29220529752118246, 0.22916502452322415, 2.848366677761078, 15.961893388203212, 7.190224758216313, 6.015081141676221, 1.4237496192966188, 0.6111124136618206, 21.57755776814052, 71.3975556237357, 41.62644931248256, 29.347731726510183, 39.84859636851719, 72.2291716166905, 41.08927713121687, 0.3728357766355787, 0.17711881015981945, 0.22228926633085522, 0.09605302368955952, 0.10315497153039489, 0.12674116769007274, 0.15077597727733, 0.1014426884108356, 0.10466600794877325, 0.3168455639055797, 0.1974263997482402, 0.22581747200872215, 0.14050192572176456, 0.14419557180787834, 0.15154436390314782, 0.14512999595275947, 0.15762273488300188, 0.13843828359884874, 0.11334101709404162, 0.15242507521595272, 0.06741856770323855, 0.17985424266329833, 0.06851140263357333, 0.10164881377880063, 0.22681372426450253], [0.015106364219848598, 0.04571757252727236, 0.04188458588240402, 0.05746205018035003, 0.10411019277359758, 0.021507342977981483, 0.10159107723406383, 0.0886058033044849, 0.05378807143175176, 0.04765495963926826, 0.040566290728747845, 0.09283068802739892, 0.09145717708660023, 0.05189566101346697, 0.08742627874016762, 0.04418373733226742, 0.035270942375063896, 0.10051790624856949, 0.05044983520305582, 0.08475553776536669, 0.07070450245269708, 0.04275308695754834, 0.11944418852882725, 0.047927428768681626, 0.029171160222696405, 0.08964088133403234, 0.08925225718745164, 0.01384009828325361, 0.07815661507525615, 0.047490869515708516, 0.2195985357144049, 3.7009718758719305, 64.18645804268974, 64.056047303336, 37.54647404806954, 37.97764451163155, 57.8579866545541, 21.36488209451948, 25.57907223701477, 0.6419969935502324, 0.3972878174058029, 5.1945983341762, 2.145797840186528, 7.026869569505964, 0.76343549149377, 0.9646371922322682, 0.14472311921417713, 29.412666116441997, 77.89356545039585, 85.54214940752301, 85.26473563058036, 88.764557157244, 81.1084760938372, 79.28069686889648, 79.742995262146, 81.62192712511334, 76.84229605538505, 73.91401250021798, 67.84294755118233, 62.91493770054409, 64.81185844966343, 64.79070118495396, 63.37884112766811, 60.29111725943429, 53.74161672592163, 50.33936527797154, 52.836791038513184, 55.915756702423096, 56.76374612535749, 57.74596084867205, 62.7630500793457, 65.72595650809151, 67.05792617797852, 65.08531870160783, 64.86331680842808, 56.95512383324759, 55.606586183820454, 51.55880192347935, 50.19414792742048, 47.17166764395577, 48.77988379342215, 51.22591372898647, 55.15996640069144, 57.596869877406526, 56.67864111491612, 52.010393142700195, 60.27294772011893, 58.25684104646955, 64.45714596339634, 21.134436403002056, 43.80326434544155, 69.56649684906006, 58.159368242536274, 61.46158300127302, 55.87652022497994, 58.38521943773542, 55.6512040410723, 57.97016879490444, 54.69434329441616, 51.51112685884748, 45.59043829781668, 44.30450391769409, 43.995774609701975, 44.309041091373985, 48.791310106004985, 51.61790330069405, 53.60912847518921, 58.07089335577828, 59.29265417371477, 57.830499580928254, 52.83488375799996, 56.7158556665693, 55.737733432224815, 60.48899500710623, 53.53940677642822, 53.53031505857195, 49.760142598833355, 49.19961404800415, 48.2073209626334, 54.476909841809956, 55.03564575740269, 56.99110507965088, 54.54591587611607, 58.870988845825195, 50.507744448525564, 50.32872411182949, 51.52513790130615, 61.9779383795602, 61.78758553096226, 66.96172142028809, 58.52817167554583, 45.112169470105854, 17.010690961565288, 6.147109942776816, 0.043051594868302345, 0.1649977455713919, 0.07666596863418818, 0.6763312997562545, 1.2025234273501804, 2.5843060357230048, 1.3566863664558955, 3.047645138842719, 0.3677077075200421, 0.39778996046100346, 23.51259286063058, 34.30508381979806, 25.08354582105364, 33.363877364567344, 53.41938706806728, 48.93238980429513, 1.2378867183412825, 0.3267636831317629, 0.055123319782848866, 0.06109421420842409, 0.0323149825978492, 0.09492643164204699, 0.008627925600324358, 0.041276598149644475, 0.07527419153068747, 0.005351517482527665, 0.07794816911752735, 0.07071499260408537, 0.04788315775138991, 0.03918345671679292, 0.029359256915215935, 0.026500726284991418, 0.045311262365430593, 0.030600477276103835, 0.042510510688381534, 0.08673180493393115, 0.05936356993126018, 0.020794721752671257, 0.022901196398639252, 0.02164500076988978, 0.01091644271010799, 0.013854391623421438, 0.056360133058790646, 0.02364281821064651, 0.04768547675173197, 0.049446502434355874, 0.017586698090391498, 0.014325877618310707, 0.0218428666703403, 0.0691069799608418, 0.09525186382234097, 0.0375748096433069, 0.04727657797879406, 0.05334176502323576, 0.04991422340806041, 0.04348197266725557, 0.04287145060620137, 0.10627530980855227, 0.034420938164527924, 0.043189317121037414, 0.04377883852326444, 0.09217246834720884, 0.087712247323777, 0.040751832736922164, 0.10958082029329878, 0.05533532465675047, 0.07231322077236005, 0.11378616999302592, 0.08867890866739409, 0.061814798042178154, 0.08157100328909499, 0.10701093676366977, 0.32230454097901073, 5.686839554991041, 74.24032075064522, 73.59382561274937, 32.815720081329346, 49.543053082057405, 63.61384310041155, 23.642327887671335, 36.13131707055228, 0.37305714190006256, 0.4034975527652672, 2.4845952604498183, 4.920524903706141, 5.441885156290872, 1.980557952608381, 1.8967298907893044, 0.06179711541959217, 31.4058506829398, 78.82363741738456, 87.318845476423, 87.14419555664062, 88.30879701886857, 81.30573545183454, 83.04961517878941, 83.29160703931535, 82.69708442687988, 79.97705922807965, 78.70089748927525, 70.15437698364258, 65.27708203451974, 65.78481469835553, 69.73035621643066, 66.45799786703927, 62.786875452314106, 56.69808564867292, 53.99606670652117, 55.96023212160383, 57.93823834827968, 58.26497738701956, 61.03674929482596, 63.256184577941895, 69.1635638645717, 67.72371646336147, 67.93885353633335, 65.86168261936733, 59.92389801570347, 57.146372999463765, 55.84750802176339, 51.66017614092146, 51.36229991912842, 52.329405784606934, 54.6440418107169, 58.870439938136506, 61.13760239737374, 59.55220413208008, 56.58371482576643, 62.13330704825265, 60.487640108381, 67.01392323630196, 22.32074577467782, 45.352222783224924, 71.88943944658551, 60.050667898995535, 64.57853099278041, 59.78118201664516, 62.87914752960205, 59.159123693193706, 60.48650060381208, 58.00664683750698, 56.42020286832537, 47.62386335645403, 48.35864577974592, 45.68651103973389, 48.08511257171631, 51.166895730154856, 55.78181280408587, 55.39891495023455, 61.070489747183665, 61.918420110430034, 63.25206429617745, 58.284529617854524, 59.70621790204729, 60.58357388632638, 65.25777993883405, 57.755417346954346, 60.29692595345633, 54.29937641961234, 56.07142761775425, 52.85155943461827, 61.44543538774763, 60.31365721566336, 62.04232733590262, 59.52454335348946, 63.01950808933803, 54.861933844430105, 53.1715726171221, 56.58357586179461, 66.21411609649658, 64.05285113198417, 72.30357987540108, 61.94161319732666, 49.695736271994456, 18.607227189200266, 7.272159218788147, 0.23526600428989955, 0.6028723386781556, 0.27471092769077843, 3.3314792684146335, 2.0540916068213324, 2.2195436315877095, 0.4516368710568973, 1.0786170704024178, 0.1813922237072672, 0.7774930000305176, 35.49697780609131, 42.415375573294504, 34.39452798025948, 28.866056544440134, 59.04551369803292, 50.55992194584438, 0.92129356946264, 0.23828154961977685, 0.015092157392895647, 0.02714229641216142, 0.02630870426738901, 0.01160853061758514, 0.05578825356704848, 0.0731332642691476, 0.0162883450809334, 0.044462408271751235, 0.036446317697742155, 0.06484619395009109, 0.03339113235207541, 0.024366640352777073, 0.08096030141626086, 0.047083636546241384, 0.015798731174852167, 0.0868097414661731, 0.036805089696177413, 0.06530336370425564, 0.022844101069495082, 0.029631773542080606, 0.019503415329381824, 0.020956423432965363, 0.017301877927301184, 0.060627612817500315, 0.1341304276138544, 0.08700099334652935, 0.14481166803411075, 0.1480955739638635, 0.17185245560748236, 0.12518033358667577, 0.16841254090624197, 0.18092080471771105, 0.1390372807426112, 0.14482593084020273, 0.12445104414863245, 0.1970838617001261, 0.19239080138504505, 0.11874486319720745, 0.15812681854835578, 0.1904820959482874, 0.13314176137958253, 0.16181069373020104, 0.11696444159107548, 0.1261292105274541, 0.13808486184903554, 0.1617917897445815, 0.3124659189156124, 0.11694825174553053, 0.28424057204808506, 0.18115078737693174, 0.1712042103920664, 0.1420434351478304, 0.25573287318859783, 0.19457165364708218, 0.5703537921820367, 10.611313206808907, 99.00046266828264, 78.02636637006486, 60.31879193442208, 51.794957297188894, 81.73021480015346, 31.650361265454972, 38.624723298209055, 0.7098184142793927, 1.075355976819992, 10.846074598176138, 15.309091023036412, 14.921602146966116, 1.6355034623827254, 2.0983192792960574, 0.4378660299948284, 33.06125899723598, 84.39894144875663, 89.4278530393328, 91.76476151602608, 91.85133607046944, 86.57397079467773, 84.48953206198556, 85.9548932484218, 84.1671564919608, 83.16257204328264, 79.21582848685128, 73.66364111219133, 68.26409176417759, 71.13018894195557, 71.04527500697544, 69.0150808606829, 65.6169879095895, 59.93723160879952, 57.10950238364083, 60.67683260781424, 62.11826419830322, 63.9197792325701, 65.86518451145717, 65.05332224709647, 73.37156663622174, 70.2605037689209, 70.46883160727364, 69.10878426688058, 63.532820156642366, 61.06476443154471, 57.06970657621111, 55.73747982297625, 53.38484409877232, 54.019704478127615, 57.33001388822283, 58.946870122637065, 63.2199010848999, 61.0931339263916, 59.56325871603829, 64.82936791011265, 63.90693201337542, 68.92009203774589, 25.35228477205549, 48.723447050367085, 72.33386707305908, 62.22191742488316, 67.29141344342912, 61.5561340876988, 63.406001635960166, 59.93664796011788, 62.77737031664167, 58.55060740879604, 58.10722896030971, 50.83309037344796, 50.21998480388096, 47.735100541796, 49.46662637165615, 53.81805733272007, 57.35538870947701, 58.00235979897635, 62.99638448442732, 63.28164972577776, 65.1157031740461, 60.905956404549734, 61.63000733511788, 61.745972769601, 68.59361703055245, 60.65063789912632, 66.86027772086007, 59.110305649893625, 61.391003199986045, 57.19013622828892, 66.29463182176862, 65.94746507917131, 67.23525810241699, 62.68543175288609, 66.48819473811558, 57.24463789803641, 57.2600177356175, 57.87284190314156, 68.7689687183925, 66.95129217420305, 76.21452631269182, 63.89461285727364, 51.78691128322056, 20.715908186776296, 8.630132521901812, 0.26494547884379116, 0.45710401769195286, 0.21357827447354794, 3.782920232840947, 9.233032924788338, 9.02078456538064, 4.817893062319074, 7.154985666275024, 0.7218347809144429, 1.2082939062799727, 36.65675721849714, 51.38961328778948, 34.34228447505406, 50.33068697793143, 65.07254791259766, 67.12207194737026, 4.053945575441633, 1.0082695995058333, 0.2174022128539426, 0.19213626932884964, 0.22359991100217613, 0.14055658850286687, 0.1657047247780221, 0.123468796855637, 0.14818853326141834, 0.1899732489671026, 0.09014895478529589, 0.11799468845129013, 0.16510971742016928, 0.12890394377921308, 0.23042215992297443, 0.11247944725411278, 0.12027639815849916, 0.16277584194072656, 0.08619209139474801, 0.16102702649576323, 0.11552061406629426, 0.20088029227086476, 0.10669199816350426, 0.21072276841316903, 0.13205233269504138, 0.1698130914675338], [0.0698570122144052, 0.04929406614974141, 0.016486679170546786, 0.09424274654260703, 0.02617485136059778, 0.10164593679032155, 0.06309950231973614, 0.11395801577184882, 0.06880589361701693, 0.0705231096861618, 0.018541729343788962, 0.09106292788471494, 0.045870246299143345, 0.04977513729993786, 0.14269067613141878, 0.04063773707353643, 0.0848762220037835, 0.1098125535728676, 0.08102751709520817, 0.09264217064316783, 0.06238545277821166, 0.04069824204114931, 0.007687900148864303, 0.0751881804317236, 0.05711913215262549, 0.07202863640018872, 0.11735685196306024, 0.14423762740833418, 0.19690376493547643, 0.1280840563454798, 0.19448728460286344, 0.8666950591972896, 19.995383466993058, 74.22541686466762, 61.77591950552804, 33.22168248040335, 54.426855019160676, 42.7753061567034, 22.551947082792008, 1.9411740430763789, 0.20381829461881093, 1.7077331351382392, 1.1417719615357262, 5.499342850276402, 9.065715960093907, 0.4903934342520577, 0.00700489231218983, 0.8412231260112354, 27.42763352394104, 82.5353651046753, 86.05503068651471, 82.83950860159737, 83.80207034519741, 85.86691515786308, 84.15955516270229, 80.69010421207973, 78.68428434644426, 75.28282846723283, 72.13735812050956, 64.71468789236886, 64.87171718052456, 64.16523824419293, 64.65649672916958, 57.71419368471418, 54.502531324114116, 52.79677288872855, 56.86095837184361, 54.58403021948678, 58.991185733250205, 59.31998143877302, 67.23421587262834, 65.82797690800258, 68.31689807346889, 64.32615852355957, 68.38278784070695, 59.07216698782784, 58.62222943987165, 53.105074882507324, 52.65953207015991, 45.87443201882498, 50.960489068712505, 47.841755390167236, 53.921939849853516, 50.42842033931187, 60.791144371032715, 53.91299751826695, 63.217955589294434, 55.999816008976524, 65.97915581294468, 16.983825751713344, 46.34922674724034, 65.93724427904401, 55.73858111245291, 64.44599410465786, 54.399447849818635, 53.0150158064706, 51.08909327643258, 53.67590413774763, 50.38648796081543, 48.432112557547434, 43.12672867093767, 46.54738242285592, 45.53936903817313, 49.443909236363, 53.67518152509417, 53.686781542641775, 53.99461453301566, 57.026311601911274, 57.93729339327131, 57.868593079703196, 52.22809757505144, 51.419424533843994, 53.608447551727295, 55.14395775113787, 53.53807619639805, 52.59116179602486, 51.25117737906319, 49.83868156160627, 49.20886557442801, 51.52767399379185, 52.427806173052105, 54.47629492623465, 56.543158190590994, 54.89980500085013, 52.74778461456299, 46.968783719199045, 54.88094411577497, 62.49549579620361, 65.70015784672329, 61.091584478105815, 53.313076155526296, 30.805415153503418, 1.8410939276218414, 0.23069832367556437, 0.17485764649297508, 0.1273377085370677, 0.8424122993435178, 2.7334673574992587, 4.378908046654292, 3.940670830862863, 1.0469265537602561, 1.0238699338265826, 0.3396227631185736, 7.3680773632867, 32.491062028067454, 43.23466198784964, 24.996175697871617, 45.82118797302246, 53.64099291392735, 10.959723676953997, 0.4191017954477242, 0.013977038524379688, 0.08701277271445308, 0.03204742266929575, 0.05449853491570268, 0.03863311053386756, 0.02797583766680743, 0.03657148705263223, 0.09315284966890301, 0.02297852564203952, 0.04527098113404853, 0.027207188108669858, 0.04555319741900478, 0.04882536808561001, 0.03217291432831969, 0.0693048746990306, 0.02159154917379575, 0.017634561950606958, 0.05988638794847897, 0.021300081063860228, 0.01858290284872055, 0.0186029094537454, 0.006883741580947701, 0.03423858866361635, 0.020797574992424676, 0.03537967421912721, 0.009199677018581756, 0.029709333487387215, 0.021312452453587736, 0.055555108934640884, 0.04169446376285382, 0.0887365366465279, 0.03325067221054009, 0.030589685176632235, 0.02774617900805814, 0.09146092938525335, 0.041092287682529004, 0.012853917183487542, 0.09555287552731377, 0.04584489623084664, 0.08765032421797514, 0.09263617917895317, 0.028401301175888096, 0.18784655737025396, 0.033771169637995105, 0.08136469471667494, 0.0359930088078337, 0.09552627016923257, 0.011217072739132812, 0.07969580391155821, 0.019294358690136244, 0.06118688852127109, 0.08687745926103421, 0.0350099811995668, 0.1432463555995907, 0.05551605924431767, 0.060656260565987656, 0.8508158741252763, 23.37223924909319, 84.26198550633022, 58.67394488198416, 37.25168630055019, 70.92255592346191, 41.30221509933472, 29.571797234671457, 2.2682070774691443, 0.13228672583188328, 1.2508856036833353, 0.730845074568476, 2.672707749264581, 6.661053861890521, 1.7706105325903212, 0.023252429873017327, 1.2205091650996889, 31.690754617963517, 84.89055429186139, 86.54929774148124, 85.83857345581055, 84.06826972961426, 86.11794662475586, 83.88350323268345, 83.50393009185791, 82.19853728158134, 78.33726351601737, 75.40559618813651, 69.13692447117397, 68.51551927839006, 69.61341108594621, 67.31262629372733, 61.07698631286621, 59.67932142530169, 57.11855241230556, 59.02140344892229, 56.30067648206438, 61.805845396859304, 63.258526120867046, 69.48400783538818, 66.65750844138009, 67.73629965100969, 68.05643095288957, 69.65910938807896, 62.06883471352713, 61.083962304251536, 55.53880303246634, 53.553334440503804, 48.09067113058907, 53.15590442929949, 51.95440803255354, 56.77335548400879, 54.568011147635325, 61.582384381975444, 58.12508583068848, 67.95013046264648, 60.29498045785086, 67.4207124710083, 18.802987473351614, 48.71414688655308, 69.67320033482143, 57.78976576668875, 67.84590748378209, 58.71819795880999, 56.37887150900704, 55.37390490940639, 55.25929437364851, 53.74325997488839, 52.18927451542446, 46.546187332698274, 49.9358868598938, 47.903865337371826, 52.15809447424752, 55.35209451402937, 57.44593415941511, 57.1419608933585, 62.13997731889997, 63.822129249572754, 63.45971815926688, 58.274541582380024, 57.66117892946516, 58.99254758017403, 61.25376238141741, 59.40367943899972, 60.197108132498606, 59.10951355525425, 57.617502553122385, 57.27866670063564, 56.73822886603219, 58.0652687890189, 61.849355016435894, 62.60608332497733, 62.73921080998012, 57.22664206368582, 51.03847564969744, 57.61693280083792, 66.3819637298584, 70.5736243384225, 65.96679496765137, 57.530782086508616, 34.315999439784456, 2.329779190676553, 0.843109127666269, 0.9240596038954598, 1.0096572850431715, 3.0710023769310544, 3.7859023128237044, 2.5206305725233893, 1.4596030839851923, 0.9428678346531731, 1.1475883637155806, 0.39308147025959833, 15.013332264763967, 37.45393793923514, 53.0575179372515, 28.421300615583146, 42.46336678096226, 62.001881871904644, 9.69621547630855, 0.33447642784033504, 0.03688616445288062, 0.04203553956800273, 0.058283627166279724, 0.017915344830336313, 0.06699539933885847, 0.018763238796964288, 0.017625666356512477, 0.06143496770943914, 0.04290093295276165, 0.08824558263378483, 0.01574499120137521, 0.07895236701837607, 0.023015422680016075, 0.045022884982505014, 0.089837242583079, 0.09912422924701657, 0.037585964759013483, 0.01659572483705623, 0.004144835826342127, 0.0300212017526584, 0.03689730599788683, 0.03274407796561718, 0.0031074681651911563, 0.04861787207690733, 0.061893650596695285, 0.09633692274136202, 0.15867056937089988, 0.12299709288137299, 0.19790596115802014, 0.14309596509805747, 0.19207058713904449, 0.11501634041113512, 0.1548996924289635, 0.2250717891646283, 0.2269260353807892, 0.10942597181669303, 0.20175020130617277, 0.1468366879437651, 0.12015773595443793, 0.16548846209687845, 0.17637775492455277, 0.1982812588768346, 0.2604580282100609, 0.11155594752303191, 0.17498130271477358, 0.2028802199555295, 0.20169328578880855, 0.12685115821659565, 0.13896450107651098, 0.18736186623573303, 0.1015788432476776, 0.36982025844710215, 0.3207523242703506, 0.45989127670015606, 0.2638884569917406, 0.32663709563868387, 1.2807787082024982, 45.09765468324934, 96.434937613351, 78.67677334376744, 51.32792023250035, 70.27901376996721, 59.19556699480329, 36.31861271177019, 3.8040570872170583, 0.21560984903148242, 5.3471382175173074, 5.066288990633828, 16.357621090752737, 18.938928978783743, 1.1880226454564502, 0.30201246270111626, 1.828692261661802, 30.82591233934675, 86.38741861070905, 90.30129023960659, 87.62806810651506, 89.07512773786272, 90.72260815756661, 88.02845805031913, 82.11122621808732, 83.21355792454311, 84.11783123016357, 79.41491522107805, 71.21734714508057, 70.90492139543805, 70.93758487701416, 71.21904945373535, 63.663814544677734, 63.90845366886684, 59.022786140441895, 66.60587637765067, 59.354361125401084, 68.54058837890625, 66.45742116655622, 72.43137809208461, 67.32688399723598, 69.33730357033866, 69.89767578669957, 72.26809542519706, 62.52374022347586, 65.31986209324428, 58.69201714651925, 57.1083767754691, 50.59309612001692, 57.47381380626133, 52.33816398893084, 58.197913374219624, 56.40091814313616, 64.17083154405866, 60.361321857997346, 69.33889470781598, 62.206812041146414, 70.76127433776855, 21.821281467165264, 51.63472488948277, 69.49079622541154, 62.90444592067173, 70.0316162109375, 62.887297766549246, 58.501372473580496, 57.45076315743582, 59.30199950081961, 57.70378180912563, 53.557895932878765, 49.40831708908081, 51.81214019230434, 51.317053249904085, 54.97940008980887, 59.547750336783274, 59.530755043029785, 59.92448166438511, 62.742497307913645, 66.60987854003906, 65.89529800415039, 61.901244163513184, 59.191057613917756, 62.93755408695766, 63.8439952305385, 62.87222017560686, 63.8008052280971, 65.53265762329102, 62.90006160736084, 63.28762517656599, 61.92287390572684, 64.60396139962333, 65.68781089782715, 69.60371834891183, 65.2728853225708, 60.86373220171247, 52.739901883261545, 61.11572252001081, 70.44412381308419, 74.05798612322126, 67.72447381700788, 64.91432353428432, 35.7079633304051, 3.208313980272838, 0.5121687629393169, 0.858232641858714, 0.4914316471133913, 4.021593025752476, 10.35663480418069, 13.904467514583043, 8.87074863910675, 3.998344353267125, 3.9009827205113004, 0.5120349015508379, 13.067955647196088, 48.04613665172032, 56.32224021639143, 39.746947697230745, 62.97873606000628, 70.41606698717389, 26.420644998550415, 1.0197278303759438, 0.30608310284359114, 0.18793617827551706, 0.11304363555141858, 0.19397594061280998, 0.13210348066474709, 0.16194327947284493, 0.1632724752915757, 0.15229998049991472, 0.16808003160570348, 0.12318807334772178, 0.13535230633403572, 0.1448687328291791, 0.19815818619515213, 0.18254324980080128, 0.24185295083693095, 0.14259414773966583, 0.10381904018244573, 0.13017526056085313, 0.14015309086867742, 0.11784748706434454, 0.10834632760712079, 0.07721039120640073, 0.13601336229060376, 0.1018196146136948, 0.18679524878306047], [0.06820841639169625, 0.03495232268635716, 0.03460641231920038, 0.04288803739473224, 0.11246213104043688, 0.009870399554659213, 0.12228117058319704, 0.02679031654926283, 0.11233910585620574, 0.1763333244515317, 0.1199891200023038, 0.08199901639350823, 0.028557452439729656, 0.12642839018787655, 0.06323533824511937, 0.06753869554294006, 0.02752998418041638, 0.08442669255392891, 0.11162018443324737, 0.020194961257012825, 0.1722130833991936, 0.15474007385117666, 0.07607866943414722, 0.04442747050364103, 0.11213426970477615, 0.10852316061833076, 0.008689595951831766, 0.06291928341878311, 0.04270087029518826, 0.030768553792898144, 0.07486641234053032, 0.050916972636644325, 0.07601220014372043, 50.67020375388009, 72.92926515851701, 42.85431064878191, 45.50768525259835, 76.12127453940255, 32.51782648903983, 5.858048379421234, 0.3432618821305888, 0.4751351358635085, 1.2250387391873767, 2.3358152210712433, 2.05777154650007, 1.561886104089873, 0.13184179684945516, 0.08310930324452263, 0.22077280841767788, 36.68594312667847, 84.5647463117327, 92.72770541054862, 90.30015768323625, 76.49080058506557, 81.23147310529436, 83.42521395002092, 83.08257048470634, 78.4362406049456, 71.73731558663505, 67.89395427703857, 66.75759029388428, 59.97592612675258, 61.87921837397984, 59.46506677355085, 58.47257219042097, 56.63134820120675, 58.15605395180838, 59.27654824938093, 63.151739256722585, 61.40535123007638, 66.73486273629325, 67.21337127685547, 66.60677964346749, 67.32702990940639, 66.95903246743339, 59.668232100350515, 58.41844572339739, 52.77186707087925, 53.16329036440168, 46.2032277243478, 48.10016236986433, 44.224707330976216, 47.80185535975865, 49.1755941254752, 59.178571701049805, 54.19768953323364, 63.195387840270996, 56.53567150660923, 62.77144350324358, 22.332886014665874, 38.56755004610334, 68.84347425188336, 55.87574897493635, 62.56132997785296, 53.642903668539866, 54.595355783190044, 49.84499747412545, 51.42045981543404, 48.22623743329729, 48.37757267270769, 45.59578493663243, 47.16372585296631, 46.51324939727783, 52.76350143977574, 52.58119807924543, 54.43912901197161, 51.927230153764995, 56.54347780772618, 57.18071099690029, 55.84028884342739, 50.43243987219674, 51.851255076272146, 50.25087302071707, 51.757666315351216, 51.30365364892142, 50.83460855484009, 50.96976143973214, 50.904319831303184, 50.949014118739534, 51.80673449380057, 53.77524253300258, 56.92537859507969, 57.35969659260341, 59.34885120391846, 56.508688177381245, 51.32093729291643, 59.60719912392752, 63.395822525024414, 62.758422579084126, 61.364488874162944, 44.86205516542707, 14.433586733681814, 0.5914844040359769, 0.7716063016227314, 0.6060437027897153, 1.8824687131813593, 2.8837099926812306, 4.266578691346305, 1.168779500893184, 0.4852247344596045, 0.6772777204002652, 1.0593353850500924, 5.796327097075326, 20.14627402169364, 69.56532260349819, 29.65134368624006, 33.710085255759104, 55.846854891095845, 32.684166363307405, 0.21402437053620815, 0.08385753738028662, 0.04296834540686437, 0.047489332633891275, 0.023493832276601876, 0.053751400006668906, 0.059941573201545646, 0.04264074530718582, 0.05364450020715594, 0.03480782526146088, 0.06136706671012299, 0.031532981166882176, 0.026288563651697974, 0.06518727993326527, 0.034685434507472176, 0.013015484853115464, 0.06903266680559941, 0.03565016541896122, 0.029881610135946955, 0.060432330439133305, 0.04096976122153657, 0.045651744452438185, 0.06661276665649243, 0.11678965097027165, 0.04376616009644099, 0.055104721137987714, 0.05245446513539978, 0.0430011627530413, 0.03032222363565649, 0.046350862830877304, 0.038625904491969516, 0.06644923293164798, 0.0026026145746332724, 0.07794076630047389, 0.09663445356168918, 0.05904412242983069, 0.08601802680641413, 0.11956548344876085, 0.0813503097742796, 0.04076673336593168, 0.06361710240266152, 0.03623788531071373, 0.022965421434491873, 0.05208533190722976, 0.0912128569824355, 0.15231066064110824, 0.034759883369718275, 0.17182505636342935, 0.09217304510197469, 0.09424423931964807, 0.010640665722478713, 0.08843345540974822, 0.13904239689665182, 0.016845371441117356, 0.05140572480325188, 0.17389551097793238, 0.024976972424026047, 0.1167360602744988, 0.08411225942628724, 0.7384340273482459, 56.425823960985454, 87.9270212990897, 34.68839509146554, 56.89326054709298, 80.05754021235875, 40.36136647633144, 8.080479638917105, 0.48131235582487925, 0.5648407765797206, 0.9629031824214118, 1.7409096977540424, 2.8430701962539127, 5.25173510823931, 0.37515935195343836, 0.33136814034410883, 0.26906977753554073, 43.12124654224941, 88.49634279523576, 93.53108392442975, 91.88773768288749, 82.07674230848039, 84.86952209472656, 84.02152919769287, 82.37400708879743, 78.42949390411377, 78.65104416438511, 73.16866534096854, 69.94208867209298, 65.79242297581264, 66.2935756955828, 64.03926740373883, 60.2300842830113, 58.90953745160784, 61.614756039210725, 62.27684988294329, 65.09798526763916, 63.42518561226981, 69.11997781481061, 68.78522055489677, 68.26629434313092, 67.48041834150041, 69.96608775002616, 61.111768995012554, 64.19556713104248, 56.18100765773228, 58.099599838256836, 49.02566589627947, 51.26268707002912, 48.474173477717805, 51.41499505724226, 51.41541542325701, 62.31398800441197, 56.96576847348894, 66.89954199109758, 58.93633665357317, 66.08031463623047, 23.00863480567932, 43.46802418572562, 71.97732026236397, 59.853457178388325, 66.33044283730644, 58.15679740905762, 57.34249285289219, 54.5717180115836, 56.3010447365897, 53.07090711593628, 51.37489005497524, 47.94926834106445, 50.432068143572124, 50.00872482572283, 55.77866179602486, 56.29504149300711, 57.360846519470215, 57.06783056259155, 60.397980553763254, 62.42022596086775, 62.169604437691824, 58.3052248273577, 59.30566120147705, 58.37212903159005, 56.931802204677034, 59.28168991633824, 59.255550793239046, 59.42828301021031, 57.48327725274222, 58.42760344914028, 59.58153247833252, 62.09277820587158, 62.34415013449532, 62.195667130606516, 64.15038299560547, 61.09533650534493, 54.68791273662022, 64.67709813799176, 66.33663368225098, 67.7213888168335, 65.24351528712681, 52.147064208984375, 16.345618077686854, 1.4645002612045832, 1.0535641461610794, 2.4470654342855727, 2.060194947889873, 1.117666489311627, 3.0728781734194075, 0.6012354407991681, 0.9413017758301326, 1.6073611953428812, 1.993036265884127, 10.31424297605242, 28.39483666419983, 68.96994536263603, 40.27244690486363, 24.949589763368877, 62.88793700081961, 34.360040596553254, 0.5473110686455454, 0.03564498819676893, 0.02899946372157761, 0.03900591802916356, 0.013525537082127162, 0.06893695265586887, 0.0040076508885249496, 0.0760269243536251, 0.06601534371397325, 0.09130935144743749, 0.01345445036089846, 0.05263220399085965, 0.11055929493159056, 0.023446439998224378, 0.031565320145870955, 0.04102869198790618, 0.03908869590876358, 0.09737755797271218, 0.059333219059876034, 0.033728537282773426, 0.04249699427081006, 0.05229158280417323, 0.06634326611778565, 0.1562826960746731, 0.039067362767777274, 0.046209228823759725, 0.042890778676207574, 0.11092763088111367, 0.09415211462016616, 0.07517805668924536, 0.09595352331442492, 0.16690953155713423, 0.10211128967681102, 0.135470751406891, 0.1915741302073002, 0.11283054841416222, 0.19559648579784802, 0.17842986195215157, 0.16066300602895872, 0.11744120743657861, 0.13798958196171693, 0.1505196267472846, 0.18164036396358693, 0.10432340883250747, 0.22682416013308934, 0.20345873891242913, 0.1751820676560913, 0.19385833692337784, 0.1972818582185677, 0.14229259320667811, 0.0776420548292143, 0.11752879273678575, 0.17067009476678713, 0.10751361586153507, 0.12348729372024536, 0.18128384809408868, 0.07662130745926074, 0.16913166588970593, 0.14061133270817144, 1.0234704124076026, 83.55495766230992, 90.41879122597831, 59.57608509063721, 60.110471044267925, 95.45581831250871, 49.202730315072195, 10.915612169674464, 0.5770430618098804, 2.403049898999078, 4.83833509683609, 6.166006003107343, 6.368409633636475, 4.118193830762591, 0.3079545838492257, 0.320333831012249, 0.3002180904150009, 42.096738134111675, 87.58448900495256, 97.69640391213554, 96.9641193662371, 82.84272561754499, 83.83205877031598, 85.31975146702358, 83.18939903804234, 83.7206027167184, 79.22600759778703, 77.4863315309797, 73.03620488303048, 69.56941509246826, 68.75667040688651, 68.74037688119071, 63.86763995034354, 65.58163547515869, 66.2210920878819, 67.44257150377545, 70.14332934788295, 68.42599173954555, 72.68591839926583, 71.9797590800694, 70.3951668058123, 71.72206429072789, 71.97178949628557, 65.40912560054234, 64.25007574898856, 59.76802212851388, 60.87197971343994, 51.49908215659005, 54.27226802280971, 50.13122156688145, 53.08677332741873, 54.696285315922324, 65.35085105895996, 60.04431029728481, 68.06543581826347, 62.35022286006382, 68.61278711046491, 28.24950119427272, 43.561064038957866, 74.17397935049874, 64.0608137675694, 69.41492189679826, 60.27926363263811, 61.07813276563372, 57.099576881953645, 58.386206081935335, 54.25880241394043, 55.28646877833775, 50.79381915501186, 53.105939933231895, 52.18938568660191, 57.9642767224993, 58.49850286756243, 61.255318777901785, 59.543713433401926, 62.028569902692524, 65.3040827342442, 65.42249393463135, 62.79847199576241, 65.48979418618339, 61.83588940756661, 61.78543158939907, 63.45110239301409, 65.3123858315604, 66.11278356824602, 63.68477031162807, 63.893501145499094, 65.34969070979527, 66.26764501844133, 66.67251655033657, 66.85316971370152, 70.7754556110927, 64.25724628993443, 59.85376289912632, 69.60982581547329, 72.97959790910993, 69.82975019727434, 73.32846696036202, 54.95003352846418, 19.570339577538626, 2.2553159977708543, 1.7910746059247424, 1.9147706712995256, 6.002246081829071, 9.745036993707929, 11.396363241331917, 4.301304919379098, 2.299260748284204, 2.525155803986958, 2.8581473529338837, 8.002918635095869, 32.3708165032523, 88.56405993870327, 44.22570092337472, 53.330078397478374, 69.68769427708217, 53.79438829421997, 0.6784603255135673, 0.26668999237673624, 0.13308624364435673, 0.08924916985311679, 0.08746528093303953, 0.13753200508654118, 0.1034709992153304, 0.15710987097450665, 0.14237204965736183, 0.1258819116545575, 0.09443963026361805, 0.17859471882028238, 0.2226589322090149, 0.12489058556301252, 0.20424908293145044, 0.12350845044212681, 0.13075474303747925, 0.20427086390554905, 0.14687683007546834, 0.1781679881470544, 0.11111881490796804, 0.14821547110165867, 0.23473069444298744, 0.22615269544933522, 0.1406348371612174, 0.22394163480826787, 0.1257258757416691], [0.10186845556433712, 0.10014131252786942, 0.16360609738954476, 0.09403666867209332, 0.09642655043197529, 0.03224615879090769, 0.21516680637640612, 0.058284882456064224, 0.14451028992022785, 0.08007821267736809, 0.11544878434922014, 0.12977126081074986, 0.13057679044348852, 0.12065006739326886, 0.11867048218846321, 0.10580374154129199, 0.13296329309897764, 0.1295111919088023, 0.07743248250335455, 0.12866473304373877, 0.17797955897237572, 0.03510413471875446, 0.04739932157099247, 0.08644940544451986, 0.13545697714601243, 0.09119524899870157, 0.15102831088006496, 0.07544294997517552, 0.05756992367761476, 0.08619092431451593, 0.03437612431922129, 0.13384024532777922, 0.19661544183535234, 3.3564124447958807, 56.09872709001814, 68.88408647264752, 32.53125040871756, 54.049279485430034, 64.34053434644426, 12.20942667552403, 0.4620746395417622, 0.21916945731001242, 0.41642245064888683, 0.13738373161426612, 7.049706995487213, 5.807742118835449, 0.24580194322126253, 0.14498036541044712, 0.03426880043532167, 0.5643944633858544, 13.15126281125205, 31.263134683881486, 36.61303220476423, 32.0872848374503, 29.485163620540074, 48.79377324240548, 78.03282124655587, 81.84332452501569, 73.36536189488002, 68.73248372759137, 60.95869323185512, 62.870378902980256, 62.44494765145438, 61.74741104670933, 60.02793339320591, 60.358063152858186, 62.096293994358604, 63.1622588293893, 60.12028884887695, 63.62584958757673, 69.60890170506069, 69.44805090767997, 66.33668231964111, 66.0538489477975, 65.7324252809797, 62.267851965767996, 57.53611830302647, 55.12182079042707, 51.49564279828753, 46.31513541085379, 46.8675971031189, 46.631848199026926, 48.87309735161917, 50.04351445606777, 60.818020003182546, 59.866943631853374, 66.32648236410958, 55.47164521898542, 61.5972535269601, 27.969254289354595, 29.369653293064662, 65.80369990212577, 53.6513283593314, 63.987176758902415, 54.84443480627877, 56.419393403189524, 49.883077076503206, 51.355824198041645, 47.075664384024485, 47.125767844063894, 44.113306862967356, 48.686427048274446, 47.28330782481602, 53.59093114307949, 54.089412280491416, 57.19406196049282, 52.66173117501395, 57.97841630663191, 54.69021953855242, 55.598620074135916, 48.985039779118125, 51.54470402853829, 44.311434745788574, 47.38407407488142, 43.75122233799526, 50.39494391850063, 49.31720188685826, 54.531977789742605, 53.00420788356236, 55.86289133344378, 53.97654226848057, 57.02723918642317, 56.374389920915874, 58.532354491097585, 51.75906637736729, 51.32784727641514, 58.928922925676616, 62.88910429818289, 65.14282894134521, 56.365558760506765, 32.726272446768625, 3.913254107747759, 0.2896210290491581, 1.3114051733698164, 1.944419503211975, 4.356740253312247, 2.4111884108611514, 2.226014575787953, 1.2921478067125594, 0.2860165424644947, 0.9770397267171315, 6.612789937428065, 20.489713055746897, 65.04636015210832, 39.98188018798828, 29.772985798971995, 57.09754453386579, 55.128289563315256, 9.504145554133824, 0.7700244465044567, 0.1311519302959953, 0.16344784945249557, 0.11861036398581096, 0.02244162293417113, 0.009604245889931917, 0.01979469514584967, 0.05077192899105804, 0.02745310616280351, 0.028072050539776683, 0.03442132492948856, 0.03675526826243315, 0.04454644822648593, 0.018275071866810322, 0.0510948030943317, 0.028790766705891917, 0.02920330921187997, 0.01373419423388051, 0.012565857863851955, 0.0808876371011138, 0.11389735474118165, 0.04264207862849746, 0.022527971604306782, 0.17512705203677925, 0.08843465641673122, 0.137651562956827, 0.047729354218712876, 0.08015384219054665, 0.1261924635618925, 0.03130508839551892, 0.04198039841971227, 0.040747547788279395, 0.02148703781754843, 0.13944034411438874, 0.06045279505529574, 0.08304612484893628, 0.08992516036544528, 0.07834579742380551, 0.018886370850460868, 0.14860912997807774, 0.09457839067493166, 0.10226991759347064, 0.12371191595281873, 0.1742777433246374, 0.1209886156554733, 0.09006375114300422, 0.09464346218322005, 0.09759774258626358, 0.042032492945769, 0.13728071642773493, 0.02748500239769263, 0.10717130172997713, 0.08086724712380342, 0.12304415607026645, 0.05339364920343671, 0.043790957158697505, 0.10665028861590795, 0.13660442057464803, 0.15518329292535782, 0.19375225475856236, 5.047712547438485, 66.90298134940011, 71.94884654453823, 29.03611023085458, 83.34741497039795, 60.094017710004536, 22.84941336086818, 0.21151020830231054, 0.25353941374591416, 0.10223835214440312, 0.5398984806878226, 3.3211811695780074, 4.107282553400312, 1.8525182860238212, 0.6744018175772258, 0.08656721947980778, 1.114286516393934, 18.263861111232213, 39.76251861027309, 46.334597315107075, 38.6385224206107, 35.20381246294294, 56.63226883752005, 83.36033167157854, 83.17917128971645, 76.86434963771275, 72.43104457855225, 68.54566056387765, 67.000214440482, 66.29505566188267, 65.44824395860944, 63.20624092647007, 63.93799046107701, 62.01264463152204, 63.173243931361604, 60.47914246150425, 66.49185643877301, 70.94567952837262, 70.04658957890102, 68.32379763466972, 69.4080570765904, 69.97330692836216, 63.823379925319124, 61.459366525922505, 57.605718408312114, 53.79456894738333, 50.92078358786446, 51.067567757197786, 51.51010199955532, 53.017221859523225, 52.62077849251883, 64.23708261762346, 63.71073572976248, 70.57434000287736, 60.28742776598249, 66.10714163099016, 32.38880886350359, 32.05756739207676, 68.62990747179303, 58.54957907540457, 69.23903519766671, 59.56633676801409, 61.05842072623116, 53.337495599474224, 53.63158852713448, 46.86408131463187, 50.45893682752337, 47.33753156661987, 51.24009152821132, 50.33860445022583, 58.072012015751426, 57.05809266226632, 60.27169704437256, 57.49161856515067, 63.484585762023926, 60.365212849208284, 63.87285109928676, 58.657964025224956, 59.84698840550014, 53.274770736694336, 56.66414022445679, 53.48682280949184, 57.12117188317435, 59.544526372637065, 61.5990183694022, 59.532151630946565, 62.21272495814732, 58.21428680419922, 63.458293778555735, 62.79893057686942, 63.8466147014073, 56.54793855122158, 57.14137724467686, 63.44380678449358, 68.44352899278913, 70.35686833517892, 61.44825635637556, 38.185301848820274, 4.682832675320761, 0.3029821978083679, 3.9848748360361372, 2.181264268500464, 1.9537980513913291, 2.3344905035836354, 0.4589357908282961, 0.8642427250742912, 1.0019134091479438, 1.8255036899021693, 10.583230325153895, 28.323113884244645, 62.29480402810233, 60.033637864249094, 30.032514912741526, 56.114586353302, 62.182090350559776, 9.230218904358999, 1.08694546350411, 0.11583415152771132, 0.1302657499909401, 0.09647591385458197, 0.09774294908025435, 0.020925472058089714, 0.06593063540224518, 0.050679519306868315, 0.050491066383464, 0.05635701519037996, 0.01085035000661654, 0.058560089474277835, 0.09111652536583797, 0.042183521270219765, 0.01072222223904516, 0.020486610875065838, 0.02208512063537325, 0.045850582354302914, 0.04287767277232238, 0.10410310886800289, 0.07540743545229946, 0.13146527776760714, 0.07863106033099548, 0.09176485200545617, 0.08068623433687858, 0.032171112817845175, 0.05778094806841441, 0.14831491719399179, 0.3443413499210562, 0.21888065923537525, 0.24550667192254746, 0.1386858538857528, 0.06468672465000834, 0.16521660025630677, 0.2303524608058589, 0.16063677386513778, 0.12252837446119104, 0.22910216503909656, 0.1573314940822976, 0.2714935317635536, 0.16885567855622086, 0.22324290658746446, 0.15425661765038967, 0.3018911134983812, 0.17824014356093748, 0.15818616322108678, 0.14527744161231176, 0.27118194848299026, 0.10426076647958585, 0.15814150204615934, 0.1809840306107487, 0.17695073703570025, 0.19362162319677217, 0.3023872311626162, 0.29492334595748354, 0.23751950051103318, 0.2358731302831854, 0.13655601388641767, 0.295646962842771, 0.6414522113544601, 15.848834037780762, 88.69504737854004, 86.94490732465471, 51.49516337258475, 70.53399181365967, 79.87100192478725, 23.81596163340977, 0.5475715175271034, 0.5343804167849677, 2.1058819591999054, 0.9339896653379712, 13.537303856440953, 15.095227207456317, 1.546429184930665, 0.26021323991673334, 0.21868066782397882, 1.2023766466549464, 15.844837086541311, 34.81386913572039, 41.83172689165388, 36.971222264426096, 32.68434354237148, 53.912730012621196, 81.1812515258789, 86.48718779427665, 79.96009172712053, 75.11665534973145, 72.8395847593035, 72.84009892599923, 72.76729570116315, 70.69475923265729, 68.64094815935407, 68.69991057259696, 67.97531768253872, 68.83852713448661, 65.04113510676792, 70.10376630510602, 72.54518263680595, 73.35391126360211, 69.85321426391602, 72.55277701786586, 71.97690337044853, 67.71330111367362, 62.86721052442278, 61.835430826459614, 56.28359433582851, 53.594804763793945, 53.9166453225272, 53.60377836227417, 54.71228354317801, 56.146040848323274, 67.0341911315918, 68.57101454053605, 73.92590086800712, 62.61661679404122, 65.71954332079206, 36.69646964754377, 34.99917759214129, 68.77472877502441, 59.912127767290386, 72.04746232713971, 62.37497929164341, 63.69371264321463, 57.6209453855242, 56.7585141318185, 49.98382943017142, 51.51061616625105, 48.917298316955566, 53.05483940669468, 53.43693126950945, 62.60667392185756, 59.41996601649693, 64.2572671345302, 60.73195266723633, 67.20138563428605, 64.96382250104631, 67.69051797049386, 66.19669696262905, 64.93636322021484, 57.93337113516671, 63.14230360303606, 58.31997585296631, 63.542193276541575, 64.83191789899553, 69.30195113590786, 64.95137827736991, 66.46857302529472, 64.15471867152623, 68.21914386749268, 67.83055196489606, 69.26037311553955, 61.19366046360561, 61.85720648084368, 68.70840127127511, 71.59676742553711, 72.03312819344657, 64.21723856244768, 40.7658280645098, 5.71762832573482, 0.42292580168162075, 5.410109741347177, 6.279138309614999, 9.190129535538809, 9.574300646781921, 4.365379469735282, 2.153238275221416, 1.3380086315529687, 2.5016131358487264, 9.907035112380981, 34.38234083993094, 84.52289036342076, 52.15161527906145, 42.87617662974766, 70.5629380089896, 69.60364886692592, 19.939104795455933, 1.7181167836700166, 0.28965693712234497, 0.4640303945967129, 0.24102521953838213, 0.19982157408126763, 0.13052904871957643, 0.12239804145480905, 0.1698587704449892, 0.15925634865249905, 0.16669822218162672, 0.14268668634550913, 0.07620079895215374, 0.20599947257765702, 0.07226694468408823, 0.10716927291027137, 0.1346776389649936, 0.12601622087614878, 0.20611191940094742, 0.23979503554957254, 0.1655757488416774, 0.19196834548243455, 0.17784866956727846, 0.16726745877947125, 0.22554133539753302, 0.16079223980861052, 0.24454651772975922, 0.09100419389350073], [0.06479127332568169, 0.21158179374677794, 0.03821784031710454, 0.1006050572863647, 0.14460858250302927, 0.11654672186289515, 0.19157115822391851, 0.20077217450099333, 0.12376500453267779, 0.11011803003826312, 0.08014996097023998, 0.13809012728078024, 0.08198785449245147, 0.13456642707543714, 0.11990833362298352, 0.14089857015226567, 0.07109225128910371, 0.17845373281410762, 0.040842749644070864, 0.1601206122764519, 0.09247617383620568, 0.04336499323004058, 0.02966680969776852, 0.04792363236525229, 0.12586923662040914, 0.053430208670241494, 0.10876538404928786, 0.11191165593585797, 0.013497283732119416, 0.06801567173429898, 0.16554377627159866, 0.10547571057187659, 0.1538189761340618, 1.22443522300039, 27.102270228522165, 77.90850407736642, 58.132725375039236, 21.537126200539724, 73.90229088919503, 55.57948126111712, 12.543192948613848, 0.14861465325312956, 0.07096896147621529, 0.6017632324780736, 1.3396758735179901, 2.507374712399074, 3.292941084929875, 1.5268818395478385, 0.2634060728762831, 0.3713730179837772, 0.040387707097189765, 0.15568983288747923, 0.8641695518578801, 0.8798745977027076, 2.2005411769662584, 5.279229998588562, 27.211714778627666, 71.57506820133754, 69.48083250863212, 64.88655158451625, 56.970177105494905, 55.94334799902779, 67.57564340318952, 71.62938226972307, 72.47737516675676, 71.34188665662492, 66.00412763868059, 64.02555860791887, 66.57807663508824, 65.4635786328997, 69.62965597425188, 66.10205554962158, 65.07276330675397, 66.34086513519287, 63.564503942217144, 58.12654495239258, 56.03310135432652, 53.14142785753523, 51.19785690307617, 47.301783084869385, 47.19520466668265, 42.67347683225359, 47.23983989443098, 48.435729094914024, 59.02658680507115, 56.5391525541033, 62.692511967250276, 52.628595215933665, 61.240560804094585, 26.919695888246807, 30.014293261936732, 59.70545360020229, 55.81121410642351, 64.58128942762102, 56.72179985046387, 57.40947001320975, 51.64421612875802, 52.20046806335449, 48.02679981504168, 48.424952438899446, 47.49690587180001, 49.25384473800659, 50.332451820373535, 56.08869389125279, 53.31804411751883, 55.18447617122105, 53.31521620069231, 58.36683450426374, 56.24112694604056, 53.77206373214722, 46.77389022282192, 46.932475907461985, 46.621325152260916, 45.73043755122593, 46.18911593300955, 45.5722131729126, 48.38343347821917, 52.67501960481916, 58.2541903087071, 63.17798955099923, 61.749523299080984, 64.70828165326799, 66.04647690909249, 65.23082787649972, 62.7032538822719, 62.14540386199951, 62.4129581451416, 66.39001669202531, 62.74344226292202, 57.0675630569458, 13.941388504845754, 0.754652099949973, 10.843098163604736, 1.0111857801675797, 4.895147042615073, 0.29612239875963753, 0.9371704203741891, 0.2963572804416929, 0.7097827504788126, 0.9109361938067845, 10.330256836754934, 24.3215559891292, 67.8155438559396, 48.62422330038888, 14.280174851417542, 47.55100802012852, 54.28947523662022, 38.12624216079712, 0.12510703823396138, 0.07420990935393743, 0.04430249113855617, 0.05313796703038471, 0.026492147906018153, 0.10956112920705761, 0.02453485088023756, 0.030345310789666007, 0.02050320614528443, 0.02977449999057821, 0.016338770410844257, 0.0488789927081338, 0.008953147434762545, 0.03466676122375897, 0.04295956855639815, 0.03344838035159877, 0.04619185832728233, 0.0235335554129311, 0.010074379903796529, 0.010496560151555707, 0.11138689730848585, 0.033726267583136044, 0.06345019635877439, 0.06257970378335033, 0.02609672992756324, 0.09586057080222027, 0.09368121131722416, 0.06210370468241828, 0.09083867884640183, 0.12932071355836733, 0.10229814465024642, 0.10002812610140868, 0.06107410243047135, 0.04348487340446029, 0.18065366548086914, 0.1411561963281461, 0.023266399212713753, 0.08539734368345567, 0.05714849236288241, 0.11642522338245596, 0.0600655483348029, 0.11296707644526448, 0.07665244543126651, 0.1251873496387686, 0.09576149790414742, 0.16533523531896727, 0.028674201175038303, 0.06648381786154849, 0.04838569096422621, 0.05508456864793386, 0.051208518778107, 0.024366609818701233, 0.022782520623877645, 0.11061114179236547, 0.04161340257685099, 0.0585781317204237, 0.054908220789262226, 0.05915737670979329, 0.09302158706954547, 0.05457687856895583, 0.21965288636939867, 1.4143624944346291, 33.57251787185669, 91.68395396641323, 48.62814903259277, 27.229462214878627, 100.53480557032994, 53.0598976952689, 18.27948760986328, 0.16415818062211784, 0.12742808940155165, 0.1979339982249907, 0.299183650208371, 1.4087165402514594, 3.652473883969443, 1.4505851907389504, 0.5478868463209697, 0.6662364357284137, 0.03952215086402638, 0.40716373175382614, 1.8416141739913394, 2.0324903087956563, 3.7440394163131714, 8.01439184801919, 33.16025693075997, 74.39343125479562, 75.18126664842877, 72.41613374437604, 68.05183819362095, 63.368245124816895, 70.48836299351284, 69.6381744657244, 70.42462021963937, 69.97770513807023, 66.76035567692348, 65.84254033224923, 69.05793734959194, 68.30130631583077, 70.54162788391113, 67.74278232029506, 67.845212663923, 69.26796054840088, 65.94946616036552, 61.70591640472412, 59.70511313847133, 58.36380508967808, 57.03588274547032, 52.869728973933626, 50.12583671297346, 46.83586120605469, 50.66119541440691, 52.69545078277588, 63.709221022469656, 60.633427211216514, 66.88744517735073, 56.3589961869376, 66.21518611907959, 30.62955277306693, 33.307232175554546, 64.54492950439453, 61.12020410810198, 68.35675294058663, 62.33906405312674, 60.086770738874165, 55.11402491160801, 55.70021315983364, 52.2347400529044, 51.53447280611311, 49.994922229221885, 52.61093636921474, 53.521949427468435, 59.2278413772583, 56.11338778904506, 59.863976751055034, 57.92482485089983, 62.41552897862026, 61.420359339032856, 61.83064351763044, 56.542602334703716, 54.54765292576381, 54.9374920300075, 55.956323759896414, 54.20747259684971, 54.35539627075195, 55.973072392599924, 59.236874035426546, 61.110004152570454, 67.94976915631975, 64.78253705160958, 66.20290865216936, 67.02016271863664, 71.04793616703579, 67.47868129185268, 67.80938080378941, 65.20982347215924, 73.02370507376534, 65.48281124659947, 63.14194924490792, 15.668924331665039, 1.7280976538147246, 13.583120277949742, 2.2948621043137143, 3.899307336126055, 1.626341394015721, 0.5017465193356786, 0.43796287051268984, 0.9821048549243382, 1.4804496339389255, 15.7647590977805, 35.494719641549246, 61.83984988076346, 77.28184604644775, 18.867702995027813, 43.28582157407488, 62.30361434391567, 39.61441775730678, 0.40180344081350733, 0.0325783457873123, 0.044460311598543606, 0.015146582686741437, 0.07099638107631888, 0.014308585153360451, 0.025032335792535117, 0.01152969163376838, 0.03155891138261982, 0.02216610887886158, 0.015192371926137378, 0.09333068012659039, 0.008746526736233915, 0.028434551088139415, 0.03288343548774719, 0.009412971957187568, 0.05583519461963858, 0.03273557252915842, 0.04905195467706237, 0.03965419717133045, 0.03218913810061557, 0.060809358422245295, 0.12432699437652316, 0.10144888343555586, 0.017367704305797815, 0.08776584480490003, 0.09990157253508057, 0.1209989565291575, 0.14321070536971092, 0.20748975260981492, 0.2397478095122746, 0.12895467105720723, 0.13860261120966502, 0.16154412446277483, 0.1303392489041601, 0.21405730662601336, 0.18625421210059098, 0.1482358407229185, 0.13889573833772115, 0.19118708026196274, 0.12399306015244552, 0.16648598999849387, 0.13454278691538743, 0.21005868619041784, 0.13781234861484595, 0.25474229348557337, 0.11450350364404065, 0.2099119190658842, 0.15727907046675682, 0.14222734527928488, 0.12694307257022175, 0.18455163203179836, 0.14131517708301544, 0.20167013417397225, 0.1541646354432617, 0.1978187286960227, 0.14407358478222573, 0.1755038968154362, 0.3049614301749638, 0.20851351267525128, 0.42615891247987747, 1.9334973692893982, 57.34827028002058, 96.2004428591047, 76.2869404384068, 35.68519755772182, 90.49877888815743, 73.01704175131661, 21.263191734041484, 0.2016492217246975, 0.3248571354363646, 3.6229238467557088, 2.916106185742787, 9.90064103262765, 11.309418695313589, 2.8743703109877448, 0.5005405183349336, 0.5642836721880096, 0.10470367342765842, 0.3995703277843339, 1.796749438558306, 1.3255344437701362, 3.574869019644601, 6.647541352680751, 30.004145417894634, 75.50257914406913, 79.10207952771867, 75.95953437260219, 75.38195841653007, 69.47650378090995, 76.92368725367955, 77.38585363115583, 77.71500369480678, 76.75508226667131, 72.27917780194963, 73.06842367989677, 75.56095096043178, 73.89705889565604, 76.12133707318986, 68.40175642286027, 70.18322590419224, 71.08134310586112, 70.87771224975586, 65.71269934517997, 63.83370494842529, 61.5805014201573, 58.69621385846819, 56.57192373275757, 53.463980606624055, 47.96743788037981, 54.919232164110454, 55.346980639866416, 65.80027444022042, 62.593048504420686, 69.88730907440186, 58.32099723815918, 67.67555155072893, 34.86722782679966, 40.73021159853254, 67.29508209228516, 64.91144003186906, 72.84024483816964, 65.49497754233224, 62.73728615897042, 57.93857533591134, 57.94692359651838, 55.70662634713309, 54.11311258588518, 53.306704657418386, 54.950130803244456, 56.08724519184658, 62.697125571114675, 60.611561230250764, 62.214281354631694, 60.91917882646833, 66.21392154693604, 65.94543620518276, 68.57607282911027, 63.0389769417899, 63.44952515193394, 65.8428043637957, 65.02490411485944, 64.89275632585797, 63.85346562521798, 65.12326976231166, 67.69789695739746, 68.69474806104387, 73.82470730372837, 69.6919813156128, 70.7154301234654, 74.89261763436454, 77.13090338025773, 74.38943604060582, 73.5147203717913, 70.71738256726945, 74.19899286542619, 69.26135281154087, 67.62357207706997, 17.097609451838903, 2.875918673617499, 17.812921285629272, 4.612035742827824, 12.133254442896162, 6.641021771090371, 3.2756374648639133, 0.7010837686913354, 1.6999028410230363, 1.7653041716132845, 15.056741135460989, 38.82631138392857, 83.67112459455217, 63.241565568106516, 24.671934536525182, 65.05157824925014, 66.58213438306535, 61.1633802141462, 0.5078042085681642, 0.12461022846400738, 0.1365322380193642, 0.12413412758282252, 0.22754874053810323, 0.12964432047946112, 0.07257641772074358, 0.08434146177023649, 0.13461186178028584, 0.08274146262556314, 0.13934735767543316, 0.17070350583110536, 0.10392646584659815, 0.1500776426068374, 0.11014662350394896, 0.07273276575974055, 0.20201989183468477, 0.07106656873864786, 0.2632490870143686, 0.11356279626488686, 0.203819461699043, 0.15185805064226898, 0.15019198932818004, 0.19542621422026837, 0.11568756082228251, 0.21078904771379062, 0.09947486900325332, 0.14649538482938493], [0.17713220444108757, 0.19377308578363486, 0.09527725460273878, 0.07494341249444655, 0.1146295890212059, 0.09229282010346651, 0.13153580469744547, 0.0496847021526524, 0.1650383219655071, 0.1502496919461659, 0.09421978491757597, 0.15454207733273506, 0.11817519233695098, 0.1630226658391101, 0.10752861827079739, 0.1617418767086097, 0.06533639478896346, 0.10766739903816155, 0.07668389552938086, 0.13958610700709478, 0.04331102594733238, 0.08649361878633499, 0.020381521067715118, 0.0771921861118504, 0.03648046497255564, 0.07976034616253205, 0.08886916310127292, 0.04869649392951812, 0.051965064967849424, 0.07964024546423129, 0.03746667491006, 0.05904277893049376, 0.042138771885739904, 0.04573725682816335, 3.9104874219213213, 71.98625564575195, 70.51322364807129, 60.81793662479946, 29.55948850086757, 72.73692512512207, 58.008606229509624, 10.945223655019488, 0.16105635277926922, 0.8273841057504926, 0.9895662431206022, 1.1185731206621443, 1.3725000321865082, 3.3791080840996335, 1.0764212225164687, 0.3641807639173099, 0.15688229032925197, 1.2555053957871027, 7.12049263715744, 0.509048478943961, 0.24570678547024727, 0.11041811215026037, 0.9102187923022679, 19.781604766845703, 62.96486745561872, 59.03601551055908, 45.95866503034319, 62.395115171160015, 85.50691509246826, 85.32643563406808, 83.23291560581752, 79.15943690708706, 77.68737765720913, 73.1045195715768, 77.0202533176967, 71.19863564627511, 68.16955457414899, 68.24856948852539, 63.47417736053467, 60.74074213845389, 57.217143876211985, 58.45487512860979, 56.7764231136867, 53.985807691301616, 51.80743278775896, 50.073523725782124, 48.55125331878662, 48.428871222904746, 46.63692385809762, 46.633133615766255, 57.91221387045724, 61.20871720995222, 63.91952214922224, 57.97913891928536, 58.050972870418, 36.659272466387065, 50.41809531620571, 55.30628851481846, 55.6392114503043, 66.5702599116734, 56.601846149989534, 56.73275368554251, 49.07242032459804, 49.63420302527291, 48.41543688092913, 50.1314126423427, 48.68645484106881, 50.44031565529959, 50.755465098789756, 53.818839005061555, 54.21574790137154, 56.57485934666225, 54.53414215360369, 57.82825878688267, 54.93959386008126, 51.420727321079795, 45.76584209714617, 42.8237316267831, 39.902785369328086, 39.295901911599294, 39.9216045652117, 43.85455247334072, 48.74742875780378, 54.029994760240825, 57.73548296519688, 63.35172230856759, 69.79594721112932, 70.47851044791085, 70.43277045658657, 63.95419366019112, 55.791595867701936, 56.52053485597883, 58.856522696358816, 72.51349190303257, 63.33084992000035, 23.305632080350602, 0.5510882288217545, 25.843776021684917, 54.65327944074358, 14.344205975532532, 1.261408650449344, 0.9977285308497292, 0.44999611909900394, 0.15248566839311803, 0.3718204168336732, 13.582327314785548, 23.828607354845317, 59.828672954014365, 46.908952781132285, 10.30180743762425, 48.306666306086946, 50.472305161612375, 53.287538051605225, 2.573117698941912, 0.204043961795313, 0.09614964707621507, 0.07818617884601865, 0.03478473471477628, 0.039209034094320874, 0.03256248503125139, 0.08530473722411053, 0.026184673154992715, 0.08510964483554874, 0.05994776822626591, 0.03819423069113067, 0.023698259610682726, 0.048387560328202586, 0.09740322695246764, 0.028607585999582495, 0.05939453826951129, 0.0551972020683544, 0.007451540956805859, 0.06150067025529487, 0.004930588707793504, 0.04769840284383722, 0.056142228322901895, 0.06303559789167983, 0.09954189469239541, 0.11100630701652595, 0.0482132480745869, 0.061821644460516315, 0.11624064828668322, 0.05886652267404965, 0.15299583173223905, 0.05942943532552038, 0.0359956720577819, 0.16541822015174798, 0.08357922945703779, 0.09796947121087994, 0.041307861650628705, 0.14707963062184198, 0.08161390027297394, 0.11674523406795093, 0.10500125853078705, 0.03700970532372594, 0.09238221709217344, 0.05495874789942588, 0.08477698625730616, 0.04695930518209934, 0.054914727940091064, 0.10132146812975407, 0.15887710185987608, 0.04146989920575704, 0.03484828630462289, 0.04617829101958445, 0.13629384152591228, 0.05749219749122858, 0.06412148462342364, 0.06842404124992234, 0.03829751729166933, 0.08362378206636224, 0.08980723097920418, 0.09213854159627642, 0.08507778083107301, 0.1128503887781075, 0.22140255676848547, 4.49829112631934, 81.39144842965263, 76.34536089215959, 42.06585686547415, 41.76582670211792, 106.06657218933105, 56.64131539208548, 16.634277514048986, 0.14802275358566216, 0.44757431905184475, 0.6905710899404117, 0.8262334732072694, 0.13661017455160618, 2.048444024154118, 0.8898994911994252, 2.079458177089691, 0.4342532381415367, 2.272403572286878, 10.659035171781268, 1.4534171244927814, 1.3246207556554248, 0.17915142966168268, 2.0290922054222653, 25.225200482777186, 64.02783066885812, 65.66579205649239, 57.30149153300694, 67.33001068660191, 83.7895427431379, 80.39280469076974, 80.15678133283342, 76.69891997746059, 75.24944932120187, 68.13402148655483, 77.21738760811942, 72.2947278703962, 67.11275441305978, 66.85473305838448, 67.37787682669503, 65.31412982940674, 64.21221501486642, 63.49468844277518, 60.04349735804966, 57.17880024228777, 55.564396721976145, 52.85331732886178, 53.83134228842599, 50.757994243076865, 53.933369636535645, 52.59899588993618, 64.98660564422607, 66.6115391595023, 69.34412670135498, 64.53074128287179, 63.49108927590506, 40.4602358681815, 49.848492418016704, 60.17164298466274, 60.78937952859061, 72.73330511365617, 61.99416937146868, 62.909379141671316, 55.73539188929966, 53.66359192984444, 50.9925445829119, 52.12316240583147, 53.381658349718364, 52.34742593765259, 54.14178432737078, 56.81643778937203, 57.2355774470738, 60.90080084119524, 58.77293586730957, 63.082590784345356, 61.40424646650042, 59.15199484143938, 55.01228938783918, 54.36451578140259, 50.785589013780864, 51.28442798342024, 52.534078870500835, 54.549230166843955, 57.66334329332624, 58.794669832502095, 61.58308615003313, 64.43423775264195, 66.9212064743042, 70.50411455971854, 71.89624868120465, 66.3677407673427, 59.98563970838274, 61.118932587759836, 62.77372946058001, 76.55182661328996, 66.89169747488839, 25.8538213797978, 0.728557000202792, 31.677427973066056, 57.18317413330078, 15.091348375592913, 0.8087576138121741, 0.11688493085759026, 0.32322227316243307, 0.3371045025331633, 0.8434653856924602, 21.515751804624283, 35.77907814298357, 57.57420832770211, 86.20452812739781, 15.14484429359436, 37.59960692269461, 55.955201625823975, 59.127113342285156, 2.009322843381337, 0.1669961397669145, 0.07660429658634321, 0.01603911747224629, 0.06985014544001647, 0.05950447451323271, 0.035449244414589236, 0.06456173171422311, 0.06188507391405957, 0.02525576889248831, 0.025478652379076396, 0.03827970574742981, 0.01385443827270397, 0.0933704829907843, 0.071905299089849, 0.04717008190761719, 0.04548936423712543, 0.0643093641847372, 0.0457402932723718, 0.06077623912798507, 0.05705616410289492, 0.08073700911232404, 0.019769524889332906, 0.08770468165831906, 0.08722176828554698, 0.021625068803716983, 0.01053822729071336, 0.031076282994555574, 0.1108014030115945, 0.2017113348203046, 0.20083067779030117, 0.21200480604810373, 0.11575681210628577, 0.23763143164770945, 0.09122809009360415, 0.20730618174586976, 0.14751649860824856, 0.17670204038066523, 0.1475347647709506, 0.12892400127436432, 0.24136671264256748, 0.18008923291095666, 0.21498144418001175, 0.1118775527658207, 0.19089478094662937, 0.18356154087398732, 0.16739733038204058, 0.2034841568342277, 0.16773093890930924, 0.15892710989075048, 0.16004449421805994, 0.12193314997213227, 0.13526297041348048, 0.15466588283223764, 0.08375308369951588, 0.12441191981945719, 0.1473019594060523, 0.1373926339937108, 0.13111043109425477, 0.22017507334905012, 0.14367706248802797, 0.1975090317428112, 0.40559547447732514, 7.838604160717555, 109.82914679391044, 82.52647835867745, 83.92407376425606, 44.149399280548096, 90.27831949506486, 73.46110807146344, 20.406907899039133, 0.2677296980151108, 1.976463943719864, 2.608955421618053, 1.5469057879277637, 3.2432846980435506, 10.651148097855703, 2.5798422523907254, 1.775186898452895, 0.2124038389218705, 2.186288467475346, 14.85712286404201, 1.3134606459311076, 0.5706418167267526, 0.11568879575601645, 1.4225615859031677, 22.441413402557373, 70.28550338745117, 72.72605119432721, 65.12445790427071, 78.89559991019112, 90.2483936037336, 89.63779980795724, 89.4577441896711, 84.09585407802037, 81.79923125675747, 75.0711099079677, 81.97299875531877, 79.35976736886161, 70.47299357822963, 67.39025156838554, 72.08792863573346, 68.32201889583042, 67.91710567474365, 66.24374321528843, 65.02114513942173, 61.85981205531529, 59.65143135615757, 58.7601511819022, 57.867974690028596, 56.863459723336355, 57.071485315050396, 55.82722623007638, 66.92529201507568, 71.04251657213483, 73.65956946781704, 66.5660354069301, 64.28313527788434, 45.98661763327462, 61.19069358280727, 68.98671831403459, 64.44278403690883, 75.99623475755963, 64.98397922515869, 65.4412123816354, 60.51573862348284, 57.30237742832729, 54.830017294202534, 56.439835003444124, 55.17655175072806, 54.604558672223774, 59.252368518284385, 59.408883639744346, 60.88700866699219, 64.78431579044887, 61.96009540557861, 67.78597232273647, 68.11633832114083, 67.64642470223563, 62.35378728594099, 62.07019656045096, 60.17151096888951, 61.188150542122976, 60.82954706464495, 61.77029146466936, 64.30903121403286, 65.36325359344482, 67.17086219787598, 70.5326577595302, 72.57371888841901, 74.76650782993862, 76.93279634203229, 73.82017707824707, 64.38607978820801, 63.59424223218645, 67.42757034301758, 80.16661303383964, 71.3130099432809, 27.136957372937882, 1.7745971700974872, 33.06679671151297, 66.38497924804688, 21.209859098706925, 6.516980792794909, 2.6912355550697873, 1.0662391803094318, 0.4249093495309353, 0.6059996794377054, 17.863438163484844, 37.41389199665615, 73.33077376229423, 65.23401015145438, 18.316863707133702, 67.29070472717285, 60.96283435821533, 79.70512757982526, 6.280617841652461, 0.6979973571641105, 0.31039443292788094, 0.3019709906407765, 0.22586114252252237, 0.12669400950627668, 0.1563402765563556, 0.19985110392527922, 0.18608554186565535, 0.17822269164025784, 0.18723090897713388, 0.15184251219034195, 0.07249751766877514, 0.1312802955508232, 0.17731650812285288, 0.2016708669917924, 0.06646272899316889, 0.2342148721218109, 0.12720078017030442, 0.14963708338992937, 0.14544679038226604, 0.13091440232736723, 0.13239554927817412, 0.12698872440627643, 0.14123387501708098, 0.18300637709242956, 0.0993147279535021, 0.16424435456948622, 0.29899642882602556], [0.1759788713284901, 0.08876755248223032, 0.07644619114164795, 0.017833326909957186, 0.15533844674272196, 0.05287187613014664, 0.23619736145649636, 0.15073101754699433, 0.1962737723120621, 0.19908478004591806, 0.30854469218424385, 0.10615402845931904, 0.23103835114410945, 0.03940733934619597, 0.1997636136199747, 0.07800249263112034, 0.1714736566479717, 0.08542357584727661, 0.17314042363848003, 0.09829512730773006, 0.19314753077924252, 0.13442901016346046, 0.20123329332896642, 0.039420072055820904, 0.15137918133820805, 0.05432026001757809, 0.138187849894166, 0.041521573040102205, 0.2444612665900162, 0.07572860643267632, 0.06915069118674312, 0.06850461049803666, 0.16352588097964013, 0.160402421440397, 0.5188649264829499, 13.759449924741473, 73.38491412571499, 69.9140874317714, 58.96848596845354, 21.402546542031423, 76.08238547188895, 66.1000475202288, 17.75407178061349, 1.3522527643612452, 0.8892340926187379, 0.5436823719314167, 0.5694100856781006, 1.117358597261565, 0.3007748962513038, 3.684171565941402, 0.8576987162232399, 0.5542194779430116, 3.3701737863676886, 1.6871545250926698, 3.687757270676749, 0.4526488110423088, 0.28624474736196653, 0.25835866800376345, 20.604995829718455, 64.05018302372524, 40.16003547395979, 67.59200641087124, 83.97725527627128, 74.13372148786272, 77.14520277295793, 82.42585454668317, 83.16744273049491, 80.29516165597099, 80.6426341193063, 67.77603639875139, 61.957670484270366, 67.75832544054303, 60.86590698787144, 61.47203309195382, 58.56410081045968, 55.643665245601106, 52.10325581686837, 51.653683049338206, 50.987260477883474, 53.055270195007324, 49.766489778246196, 48.8473334312439, 48.83929783957345, 44.09704807826451, 47.06425196783883, 54.168131896427695, 57.87820243835449, 55.39162628991263, 68.06719371250698, 34.68956238882882, 11.481865167617798, 62.10938440050398, 60.214548110961914, 59.240751130240305, 58.60542174748012, 54.354902948652, 49.56063897269112, 51.258219378335134, 48.30960886819022, 51.81343950544085, 52.25146089281355, 57.34760672705514, 60.85921587262835, 62.57317665645054, 60.39866147722517, 61.23869868687221, 58.246734891619, 63.009947368076865, 58.211076736450195, 51.20733077185494, 45.585143770490376, 42.611019475119456, 42.51637806211199, 42.12356512887137, 42.00811038698469, 43.96212795802525, 49.20436314174107, 58.892771448407856, 64.36399841308594, 65.36825629643032, 62.9640336717878, 65.19627448490688, 69.40001106262207, 79.49525724138532, 75.58701365334647, 74.3687720979963, 72.18187522888184, 52.550559997558594, 7.402628149305071, 0.12605071759649686, 0.11444590959165778, 6.191665700503758, 19.58410743304661, 9.028973017420087, 1.5123806233916963, 0.4299367240497044, 0.014626017405784555, 0.06571545837713139, 20.307018859045847, 22.350100176674978, 66.56843253544399, 44.84001200539725, 5.879299444811685, 49.05016524451119, 44.024870191301616, 64.12189538138253, 10.265704597745623, 0.36931404418178965, 0.19594352931848594, 0.07040797586419753, 0.08286092550094638, 0.022125534181083952, 0.1477936123098646, 0.038228649379951615, 0.10692082052784306, 0.04245346285668867, 0.05659703338252647, 0.04861043533310294, 0.04318730865738221, 0.041198176464864185, 0.12394192575344018, 0.07187550461718015, 0.043271087376134734, 0.0904626211683665, 0.07030541529612881, 0.04979227709450892, 0.09003163608057158, 0.10521079692989588, 0.07499124921326127, 0.042188688314386776, 0.10717713713113751, 0.01782830066180655, 0.07313307427934237, 0.09186260176024266, 0.06597260279314858, 0.022697866594951068, 0.04865701676213315, 0.040795513428747654, 0.12543292503271783, 0.013910106981971433, 0.17801356714751038, 0.03193199707727347, 0.14879051595926285, 0.1119887035872255, 0.13585795062993253, 0.16608755423554353, 0.24012841337493487, 0.08564847627920763, 0.20746308618358203, 0.08504607967500176, 0.1406091478254114, 0.015726373896801045, 0.1701369969440358, 0.06379515677690506, 0.10982834986810174, 0.12098809996885912, 0.1361888992999281, 0.104447648594422, 0.14754609630576201, 0.045190601875739436, 0.1326695688601051, 0.04709790613768356, 0.14763550007981913, 0.06398258171975613, 0.19947017436581, 0.09941118170640298, 0.10050831854875598, 0.06942479219287634, 0.2530691346951893, 0.1063653581908771, 0.6423694278512682, 16.41265603474208, 84.44947569710868, 73.12712900979179, 42.780308859688894, 35.31749194008963, 103.14107486179897, 60.42726721082415, 26.293411323002406, 0.6013603998082024, 0.8549052689756665, 0.7925983294844627, 0.7859630712441036, 0.10114546293126685, 0.7149409194077764, 2.5265884356839314, 1.2952395379543304, 1.26655270584992, 7.73864563873836, 6.475727600710733, 7.775702118873596, 1.7847691157034464, 0.9025215453335217, 0.47975997626781464, 28.392535073416575, 65.43002578190395, 46.83752529961722, 70.10172353472028, 83.7564137322562, 78.93900530678886, 82.52098928179059, 82.78001117706299, 86.02662645067487, 81.36351667131696, 78.83116926465715, 68.6169490814209, 65.98088591439384, 68.87784004211426, 64.98775209699357, 68.80614158085415, 64.29610061645508, 61.286523137773784, 60.11170087541853, 59.98237405504499, 58.0779527255467, 58.62820489065987, 54.45970957619803, 53.017242704119, 54.465278557368684, 50.56645325251988, 54.66359404155186, 61.824292864118306, 64.62855802263532, 61.36178602491106, 71.43707002912248, 40.84423153741019, 19.736870527267456, 69.64502538953508, 64.50457436697823, 66.12496376037598, 62.327182633536204, 58.415430205208914, 53.29189804622105, 53.95971025739397, 52.065315178462434, 53.48000315257481, 54.292737415858674, 58.013313634055, 62.347394943237305, 63.57289736611502, 64.9404696055821, 63.8728927884783, 61.35486561911446, 65.24689905984062, 63.756350653512136, 59.61081913539341, 55.447927543095176, 54.02379696709769, 52.46030289786202, 53.31699841363089, 52.73507635934012, 56.235575335366384, 56.9571909223284, 62.944682938711985, 67.56000300816127, 68.72156115940639, 70.41028608594621, 70.02350071498326, 73.32005269186837, 81.64441844395229, 79.88261236463273, 79.73339285169328, 77.54173646654401, 54.78809186390468, 9.414554612977163, 0.2221616203231471, 0.5093120219452041, 10.153114250728063, 26.796709299087524, 9.947488393102374, 1.7752860188484192, 1.0559364131518771, 0.16454889465655598, 0.3057045888687883, 33.59320960726057, 35.891399247305735, 54.31652109963553, 74.88464110238212, 9.719183615275792, 31.338074479784282, 44.802408354622976, 73.1447149004255, 10.243744816098895, 0.2544203693313258, 0.06998399325779506, 0.0409430371198271, 0.10508011108530418, 0.018967703450471163, 0.05100873092721615, 0.03040691837668419, 0.06364075613341161, 0.07182059077812092, 0.07645328861794301, 0.03304642638457673, 0.010519778771725084, 0.02279774864603366, 0.07965913587915045, 0.03039491848487939, 0.012915411115890103, 0.08028251957148314, 0.04808772588148713, 0.03475427867046424, 0.08353458185281072, 0.06857379392853805, 0.13326133282056876, 0.13030898624232837, 0.13077537050204618, 0.01415220573211887, 0.10300373286008835, 0.10944600895579372, 0.05562662313293133, 0.05065212006281529, 0.30184244896684376, 0.2627742753497192, 0.14258479752710887, 0.2293528972991875, 0.20735438487359456, 0.10870558475809437, 0.19213926845363208, 0.21236970861043247, 0.18233090905206545, 0.14795377371566637, 0.30872683812464985, 0.1930517487760101, 0.2409982681274414, 0.10088103104914938, 0.21180733878697666, 0.10782807613057749, 0.20516541733273438, 0.1234427411109209, 0.24034391609685762, 0.24850335397890636, 0.2237311668161835, 0.1788046575550522, 0.34177276917866295, 0.0996321194938251, 0.21831834369472095, 0.09575040385659252, 0.2682635150849819, 0.23652088695338794, 0.31206645177943365, 0.3126464363719736, 0.2567171018038477, 0.1798120784972395, 0.36411842011979645, 0.2883926363927977, 1.0572774154799325, 28.147385256631033, 103.20000948224748, 82.81516906193325, 79.49729306357247, 31.943940026419504, 94.4137761252267, 80.95708874293736, 32.51401192801339, 1.482443984065737, 0.9922346770763397, 0.8523265102079937, 3.0758493968418668, 2.154934069940022, 4.874506115913391, 10.38474634715489, 3.731836642537798, 1.9929203178201402, 6.576248926775796, 4.667167093072619, 6.7350760613168985, 1.218063942023686, 0.7103129306009838, 0.5020774272935731, 22.923797300883702, 70.03397859845842, 53.225049427577424, 77.1141026360648, 91.97117859976632, 89.39755889347622, 88.7987561907087, 90.0301923751831, 91.07853657858712, 88.29831218719482, 84.5576730455671, 74.18061488015312, 69.85192884717668, 71.72953360421317, 65.69441168648856, 72.7873898914882, 68.32632677895683, 67.66907582964215, 63.654983384268625, 65.3420546395438, 62.025241715567454, 64.50633226122174, 58.90664005279541, 57.993806566510884, 58.36584786006382, 52.15882403509957, 55.81724861689976, 65.32967294965471, 69.55993774959019, 64.89069965907505, 76.92631367274693, 42.796977588108604, 16.14355751446315, 70.92810753413609, 71.30975818634033, 69.42129339490617, 66.44601917266846, 61.653318541390554, 57.29996987751552, 56.53583478927612, 56.4941212790353, 56.24699469975063, 58.854542459760395, 62.29597132546561, 68.7547527040754, 69.48672458103725, 69.78177288600376, 72.05855165209088, 68.15398366110665, 74.73963219778878, 72.61005796704973, 66.2350857598441, 63.23222024100167, 64.90582588740757, 59.76932838984898, 61.82146494729178, 63.14454787118094, 65.46930394853864, 65.44218512943813, 71.34975201742989, 72.56447778429303, 71.04064055851528, 70.8553876876831, 72.54146535055978, 78.93432222093854, 86.3608625956944, 84.38052872249058, 84.61719826289585, 82.68121474129813, 57.65503324781145, 9.138658148901802, 0.4845421282308442, 0.5486722641757557, 10.00366371018546, 33.58814089638846, 15.923389945711408, 3.4077416104929785, 2.3084467010838643, 0.25415321652378353, 0.1892254219523498, 27.29176150049482, 37.88173157828194, 77.23427867889404, 61.92569487435477, 10.958767431122915, 72.29654829842704, 54.13050740105765, 87.06539603642055, 20.932896954672678, 0.9903602919408253, 0.34135750574725016, 0.27642686132873806, 0.1915732752531767, 0.10818453771727425, 0.2409448538507734, 0.1443312923823084, 0.19025883078575134, 0.160026703029871, 0.13736375554331712, 0.16597893434975827, 0.11137459546859775, 0.13903205602296762, 0.15636217966675758, 0.16176384767251356, 0.16828569556985581, 0.21435484423169068, 0.11369983998260327, 0.07879854991499867, 0.13189005425998143, 0.1908958394612585, 0.2484049935426031, 0.15011608840099402, 0.23914820168699535, 0.0763741239373173, 0.2509163873536246, 0.1698387808033398, 0.08672342502645083, 0.1124910366322313], [0.18924927924360546, 0.140740267932415, 0.09775332388068948, 0.12998065671750478, 0.16121318936347961, 0.2344924472272396, 0.21692296357027122, 0.14214920518653734, 0.2078778339283807, 0.309644597449473, 0.14170344839138643, 0.2643854431807995, 0.13993483329457895, 0.0809345713683537, 0.10550679426108088, 0.1556998344936541, 0.16146438302738325, 0.1111285247440849, 0.08513716621590511, 0.1728855658854757, 0.056546048261225224, 0.1918471726988043, 0.0747802248224616, 0.13538688447858604, 0.04372006042727402, 0.1060329642412918, 0.10147753796939339, 0.14836659442101205, 0.09242530406585761, 0.07601956903402295, 0.0554328063902046, 0.07433106178151709, 0.11271483783743211, 0.1897770030690091, 0.23755049599068506, 0.16216522827744484, 42.12355123247419, 77.55370126451764, 71.12924398694719, 58.46637439727783, 30.386824403490337, 66.87450763157436, 69.5467917578561, 26.14822350229536, 10.041413273130145, 0.7290320289986474, 0.15726003077413353, 0.39650687788214, 1.0576193971293313, 0.5197282944406781, 3.90218562739236, 3.5600120340074812, 1.0073911952120918, 6.694391752992358, 8.769111258643013, 1.4056037472827094, 0.49567878778491703, 0.18904597658131803, 0.44972486793994904, 14.462848203522817, 26.596100909369333, 50.50028555733817, 65.09624126979283, 64.69031361171177, 62.26883166176932, 64.84800992693219, 78.95197759355817, 85.14966651371547, 82.55470888955253, 76.30544349125454, 59.38152858189174, 60.78801073346819, 61.551096643720356, 49.78021594456264, 54.41802385875157, 53.40051923479353, 52.443960734776084, 49.20646844591413, 51.58222777502877, 48.481951986040386, 55.47793333871024, 57.400051730019705, 56.29307862690517, 50.25698396137783, 48.103417600904194, 48.06214530127389, 61.52179609026228, 53.76781143460955, 62.80861636570522, 26.610785927091325, 0.34774480015039444, 58.733115741184776, 65.24154894692558, 58.892187799726216, 58.439338956560405, 50.05883870806013, 48.632196358272004, 49.843013763427734, 54.31565604891096, 60.0094233921596, 67.06552055903843, 66.54026453835624, 68.20093958718437, 68.1515587397984, 66.56681360517229, 68.9708833694458, 65.10780307224819, 62.61021055494036, 58.21203211375645, 51.032135418483186, 45.53151757376534, 46.49969693592617, 40.84306424004691, 34.94104896272932, 35.587144579206196, 42.770525796072825, 50.44619730540684, 44.33596536091396, 31.706082344055176, 16.178395782198223, 8.9992573090962, 8.91933478627886, 10.992689405168806, 23.673038925443375, 29.68652241570609, 27.632327454430715, 18.926528181348527, 1.344605946115085, 0.08104553898530346, 0.12091840085174356, 0.18504385490502628, 0.5671377533248493, 0.6067203379103115, 1.38144442651953, 0.2257502834711756, 0.6219415068626404, 0.49930086199726376, 27.809723649706157, 19.794590950012207, 66.59737873077393, 53.15593222209385, 11.217851860182625, 62.49582930973598, 56.11017424719674, 66.47629247392926, 27.78861849648612, 0.0639010693079659, 0.05314858610342656, 0.056539259518363645, 0.07909220630036932, 0.04270861577242613, 0.1715271116367408, 0.04891329265332647, 0.07970132718661002, 0.018751216852771382, 0.08071076337780271, 0.024029572993250828, 0.08229717146605253, 0.07013251100267683, 0.08249028253235988, 0.11107045571718897, 0.03286165112097349, 0.026867893457944905, 0.06949836574494839, 0.09834461286664009, 0.02191681511301015, 0.043172448740473816, 0.0757281653849142, 0.04452833134148802, 0.0871303356917841, 0.1106889426176037, 0.054837134068033526, 0.07684236738298621, 0.03421452102650489, 0.07103951554745436, 0.027236799376883676, 0.1908524539321661, 0.10759902306433235, 0.12336430246276514, 0.16627759832356656, 0.13059068684067043, 0.09776766811098371, 0.11414962049041476, 0.07935711994235005, 0.175153094210795, 0.18544761038252286, 0.18559490676437104, 0.21741122379899025, 0.12111330325050013, 0.10818643082997628, 0.08067985610770327, 0.09644282170172248, 0.13039304316043854, 0.13178839614348753, 0.06992341365133013, 0.18339193426072598, 0.08032215958727257, 0.142851217516831, 0.024418315883459787, 0.1902503083859171, 0.058587549786482535, 0.0926414378253477, 0.15775091014802456, 0.14907768554985523, 0.04715961889762964, 0.111486418039671, 0.03428305645606347, 0.016279179769169008, 0.1589132406349693, 0.14190922092114175, 0.18733438556747778, 0.18074990888791426, 49.08723388399397, 87.30518531799316, 67.75077274867466, 37.23704297201974, 43.935009138924734, 109.70905412946428, 67.280289377485, 40.900918415614534, 11.01564277921404, 1.6642038651875086, 0.5640416251761573, 0.5512003770896367, 0.2701881932360785, 0.763934079025473, 1.334172248840332, 2.4682808901582445, 1.5067608335188456, 3.8267008321625844, 10.807737912450518, 5.748818354947226, 2.4412784533841267, 0.220792024529406, 0.8872403938855443, 22.755004712513514, 33.5486091205052, 56.775641441345215, 75.52882943834577, 73.78074605124337, 74.19216278621128, 79.01567867824009, 79.07661437988281, 78.73495061056954, 78.262375831604, 69.66570322854179, 61.668076515197754, 64.50634615761894, 69.81584685189384, 60.49475506373814, 66.73394557407924, 64.36419296264648, 60.191396713256836, 56.23992143358503, 57.456537110464915, 57.288686003003804, 62.80371788569859, 64.41116278512138, 62.017577852521626, 55.336982182094026, 52.77842269624983, 55.26334864752633, 68.00909287588937, 61.03708975655692, 68.57892853873116, 29.257283551352366, 0.22351099577333244, 64.27721541268485, 70.89565944671631, 64.46728338514055, 64.6579280580793, 55.30936656679426, 54.947900431496755, 53.454308714185444, 54.11001716341291, 61.20531259264265, 69.26716150556291, 67.49651036943708, 70.42985221317836, 71.17171137673515, 69.91328144073486, 71.28976821899414, 69.11689976283482, 67.15072631835938, 64.04883507319859, 58.56820024762835, 54.532252243586946, 55.45637655258179, 54.15085172653198, 49.572621141161235, 48.02553524289812, 55.9344299861363, 60.07806464603969, 51.59898683003017, 37.018296309879844, 21.242100477218628, 11.985023311206273, 14.174275619643074, 17.621029411043438, 31.56339066369193, 34.73972143445696, 33.74426691872733, 22.273805482046946, 2.218370471681867, 0.1615071850163596, 0.18195538063134464, 0.6877292767167091, 0.6844534182122776, 0.0909276008605957, 0.669347491647516, 0.38387445573295864, 0.5844641721674374, 1.0319493860006332, 50.19453007834298, 31.49445411137172, 46.855309213910786, 87.8227288382394, 15.539757319859095, 30.63712978363037, 55.673865590776714, 72.61970901489258, 29.399471487317765, 0.08579552160309893, 0.06787091985877071, 0.03232643626896398, 0.07099402655980416, 0.07696193882397243, 0.05234524813879814, 0.07442963256367616, 0.07653497066348791, 0.06115719582885504, 0.062760601219322, 0.06822248920798302, 0.09865273561860834, 0.05005549779161811, 0.0951020365048732, 0.05743403346943004, 0.07343299354293517, 0.029815056028642824, 0.07299527738775526, 0.0455071011425129, 0.05213668004476598, 0.029076246744287864, 0.03292247500004513, 0.06019897546086993, 0.04546687758660742, 0.028873877067651068, 0.03925081488809415, 0.08437812301729407, 0.015672404917755296, 0.028552492348743335, 0.046069559175521135, 0.342792770160096, 0.1828963187124048, 0.19335961368467125, 0.21092955874545233, 0.1873832672302212, 0.16827623679169587, 0.17041474846856935, 0.1895281028534685, 0.2453705035150051, 0.2567447860326086, 0.24310631358197757, 0.24491216668060847, 0.14158853170062813, 0.15239606105855533, 0.2132084864590849, 0.1828761933637517, 0.3538169286080769, 0.2417267704648631, 0.18568977953067847, 0.27687021610992296, 0.2474339013653142, 0.20913111524922506, 0.1622106358408928, 0.17979238741099834, 0.15570694554064954, 0.18951469500149998, 0.33456034905144144, 0.2045792716422251, 0.11812242945390088, 0.2577645427414349, 0.10999026867960181, 0.3241955909345831, 0.26628629118204117, 0.33069193948592457, 0.32830555896673885, 0.1746055707335472, 71.44710322788784, 99.0277065549578, 86.27049432482038, 81.87943431309291, 45.833034651620046, 86.5522437776838, 84.342862537929, 43.11219303948538, 12.796257632119314, 0.9830448159149715, 0.77064348757267, 2.3064762353897095, 1.4361705013683863, 4.103303841182163, 10.460112588746206, 10.402526787349156, 5.430965627942767, 12.78135027204241, 18.422340835843766, 5.4427667089871, 1.4648922915969576, 0.4278385852064405, 1.1383488880736488, 18.536046368735178, 32.469856125967844, 57.767250129154746, 75.4829991204398, 80.64327335357666, 89.34500966753278, 88.66857474190849, 88.75214767456055, 83.34727600642613, 83.07403809683663, 72.85377298082624, 69.27818134852818, 67.84291975838798, 72.1088149206979, 67.55428464072091, 71.03481101989746, 70.83516842978341, 66.46253504071916, 61.96178381783621, 61.79054546356201, 64.2003127506801, 68.66629518781389, 69.28995159694126, 67.44260624476841, 61.90097318376814, 58.483904702322825, 61.08611624581473, 75.16947555541992, 64.81615938459123, 71.46523802621024, 34.54920877729143, 0.3781584495944636, 68.89723246438163, 74.33507333483014, 71.0876520701817, 69.07021481650216, 57.35094881057739, 57.30910675866263, 55.855574880327495, 58.55714566367013, 65.5651751926967, 74.4165062223162, 72.5004084450858, 75.32868657793317, 73.78452587127686, 74.30550180162702, 75.04656192234584, 74.11074379512242, 71.39194147927421, 74.59845869881767, 66.99592045375279, 65.07036617824009, 63.75963715144566, 64.42334992544991, 60.230035645621165, 59.76759134020124, 64.5301159449986, 66.67749840872628, 54.686554363795686, 38.257333823612754, 19.487478835242136, 11.503185714994158, 12.987457292420522, 17.223946809768677, 30.16481556211199, 35.37753479821341, 35.44266721180507, 25.226746456963674, 2.7381031087466647, 0.2371276058256626, 0.2922370529600552, 1.282564178109169, 4.352753724370684, 2.3374445736408234, 4.200295048100608, 0.9496391798768724, 1.1067697597401482, 1.4377409028155463, 38.7829407283238, 33.46684271948678, 76.84317152840751, 70.86055714743478, 20.036735670907156, 81.78015150342668, 67.34303161076137, 81.30233083452497, 43.97785520553589, 0.15128111945731298, 0.20223268041653292, 0.1615190865205867, 0.16277494627450192, 0.1485335004648992, 0.19544723523514612, 0.1027685526226248, 0.18726807912545546, 0.13123800924846105, 0.18081335191215786, 0.08011230227670499, 0.2736065169530255, 0.21765371864395483, 0.24554043582507543, 0.20779220280902727, 0.10695350555969135, 0.08592674349035535, 0.11280005505042416, 0.11658375630421297, 0.12199511379003525, 0.09933733674032347, 0.12088758179119655, 0.18356759340635367, 0.1792290404971157, 0.18770824479205267, 0.16039917804300785, 0.15077814858938965, 0.11145215880657945, 0.12237062864005566, 0.1550695297441312], [0.30043329458151546, 0.05054758156516722, 0.21199008183819906, 0.08281671894448144, 0.22163093808506215, 0.12842161394655704, 0.2794178436909403, 0.20943105486886843, 0.12348691374063492, 0.34461973926850725, 0.14647790576730454, 0.17948658524879388, 0.1841402498206922, 0.1215282002730029, 0.18867086885230883, 0.05394189192780426, 0.11655166159783091, 0.016217656999028156, 0.04629269202372857, 0.023804650508931706, 0.13797682550336632, 0.07074874293591295, 0.05407015200970428, 0.07068110656525407, 0.07739510879452739, 0.23613281920552254, 0.08726978142346654, 0.0939361165676798, 0.05928703796650682, 0.03155432787856885, 0.12079133838415146, 0.05161975510418415, 0.10113548846649272, 0.023890196811407804, 0.06989670651299612, 0.03673228628135153, 0.18108191607253893, 48.15468488420759, 76.91327885219029, 65.6034528187343, 54.69340181350708, 21.596307482038224, 52.548614501953125, 63.14516626085554, 26.04405437197004, 25.1839542388916, 0.32153464800545145, 0.5201415494084358, 0.36844367374266895, 0.38280171900987625, 0.9889308086463383, 0.2568948508373329, 5.5182832053729465, 4.555078753403254, 5.05902682031904, 7.481558816773551, 2.018393499510629, 0.4101097679563931, 5.409492654459817, 3.8695143290928433, 1.334600105881691, 1.2446251681872775, 6.177270770072937, 13.97683995110648, 20.352604252951487, 30.554109232766287, 38.128458636147634, 50.112009797777446, 57.22959157398769, 63.672388621738975, 54.80223492213658, 40.29454912458147, 40.07002503531319, 36.52993174961635, 37.62346008845738, 36.6301942552839, 40.57276194436209, 41.806494508470806, 49.63181979315621, 51.750999518803184, 50.99186365944998, 52.594990253448486, 54.50808293478829, 52.423057079315186, 51.55729763848441, 46.51893997192383, 50.465624468667166, 51.262558528355186, 59.63722923823765, 21.179987055914744, 0.41750376405460493, 61.14837210518973, 60.84965515136719, 55.96367147990635, 53.25065701348441, 49.72065251214163, 53.688626289367676, 63.210083280290874, 66.55800328935895, 70.91115392957414, 67.80147375379289, 74.38312012808663, 68.781649180821, 74.71968391963414, 74.01431669507707, 72.38098975590297, 69.81962667192731, 69.5191240310669, 66.1141801561628, 56.31784895488194, 52.21435056413923, 46.69065080370222, 40.64770174026489, 37.15740966796875, 28.005907773971558, 26.975990193230764, 16.077603476388113, 10.444962041718618, 2.073181999581201, 0.3843140107180391, 0.21982300866927418, 0.4413313354764666, 0.06475809296326977, 0.4429081694356033, 0.10168588893221957, 0.22857266345194407, 0.04696662657495056, 0.1917144376784563, 0.10008711793592998, 0.19956189872963087, 0.9044129752687046, 0.8646329641342163, 0.6297379827925137, 0.0528190793203456, 0.5703571577157293, 7.691742692674909, 36.046892983572825, 17.79509047099522, 74.36830656869071, 68.10772255488804, 14.105795911380223, 48.36133125850132, 59.14569977351597, 53.1008677482605, 18.011116913386754, 0.0688985815005643, 0.04952982992732099, 0.027079082393486584, 0.06852801995618002, 0.043446889014116356, 0.025067797728947232, 0.02956314311761941, 0.06964853232992546, 0.014879568978878004, 0.04918632157413023, 0.07799279636570386, 0.029623515770903656, 0.05789320490189961, 0.05598721360521657, 0.05556640315002628, 0.0703745037317276, 0.046248176733830144, 0.12476186746997492, 0.13622311103556836, 0.17995545294667992, 0.10880526833768402, 0.056751030297683816, 0.031206731351890733, 0.12629250676504203, 0.017855767759361436, 0.14712278544902802, 0.08508191310933658, 0.0715683385995882, 0.1460914665034839, 0.07959361653774977, 0.0556026912028236, 0.277633188026292, 0.07255364608551775, 0.11627111450902053, 0.0602320201162781, 0.1510060413607529, 0.10458558119301285, 0.20745562229837688, 0.1747327417667423, 0.19501427561044693, 0.3019555743251528, 0.2135768359793084, 0.1252821816929749, 0.14386441957737717, 0.1132940896121519, 0.17498354188033513, 0.06716079224965402, 0.17141028147722992, 0.029123961326799223, 0.09708705677517823, 0.06780755147337914, 0.018424914451316, 0.044841577032847066, 0.11888886189886502, 0.059564070243920596, 0.06721520397279944, 0.1992775382740157, 0.1580072742487703, 0.08013977615961007, 0.0662878230214119, 0.018170390876808336, 0.06406739181173698, 0.08719092208359923, 0.1652063950896263, 0.039156858144061904, 0.11582558841577598, 0.04946617316454649, 0.36127261711018427, 61.28001962389265, 84.54964092799595, 64.12939248766217, 41.56062207903181, 34.4217267036438, 87.77918447766984, 55.81296157836914, 45.5130284173148, 35.62942089353289, 1.0848830427442278, 0.3078718568597521, 0.2110592946410179, 0.59038202890328, 0.06033195475382464, 0.09552297927439213, 2.1322219286646162, 6.020512895924704, 1.5970807926995414, 6.817791759967804, 5.324049353599548, 1.1515449285507202, 6.053769579955509, 3.9333239793777466, 2.3613898030349185, 6.811379875455584, 13.345532706805638, 26.97255778312683, 36.174336842128206, 45.16353055409023, 57.78830317088536, 65.01967212132045, 68.33547060830253, 75.65029089791435, 64.2704895564488, 53.74468435559954, 56.380205563136506, 51.33212389264788, 52.80238355909075, 51.003752027239116, 54.16627672740391, 55.58352163859776, 61.17842306409563, 60.87893486022949, 58.65306554521833, 59.81938321249825, 61.16927228655134, 60.78968524932861, 58.142147132328574, 52.37233175550188, 58.34221008845738, 56.45565257753645, 67.41389628819057, 25.142515182495117, 0.2976787681026118, 69.68171882629395, 67.21882561274937, 62.605256489345, 57.51806688308716, 52.65064532416207, 54.41696425846645, 63.73692349025181, 68.45383317129952, 72.51245662144252, 71.4366044998169, 76.80793721335274, 70.93292958395821, 77.37067181723458, 75.36849280766079, 75.927551814488, 71.94020993368966, 73.61378778730119, 69.32046808515275, 64.26644570486886, 62.05015795571463, 60.869256019592285, 54.23396955217634, 52.00989982060024, 42.53673280988421, 38.00406156267439, 24.94020622117179, 13.561854447637286, 3.6270623675414493, 0.9070567648325647, 0.4670154058507511, 0.15660128183662891, 0.030166296288371086, 0.29407205592308727, 0.08534040781004087, 0.1676463255924838, 0.11018852982670069, 0.42454546477113453, 0.14568966520684107, 0.45565075853041237, 1.3675033003091812, 0.3188611657491752, 0.10744978607233081, 0.1990178357809782, 0.6146327619041715, 10.025030289377485, 66.74720273699079, 20.890787397112163, 47.302186080387656, 105.39486898694719, 15.816757678985596, 28.564636741365703, 59.782126971653526, 61.17954172406878, 22.293712071010045, 0.013405598384062094, 0.051358380022325685, 0.011076539655082991, 0.03939551926617112, 0.065659228180136, 0.026186145575983182, 0.07275337286825691, 0.01320703952972378, 0.032289941262985976, 0.04744846446971808, 0.0867285140390907, 0.03287537109905055, 0.0630233164078423, 0.04203074571809598, 0.10879741090216807, 0.014689102502805846, 0.026096741801926067, 0.14644472540489265, 0.13470047845372132, 0.08256684842386416, 0.026982928892331462, 0.029968550827886378, 0.049638175006423674, 0.04226387677980321, 0.09283429104834795, 0.07898731157183647, 0.1542639322578907, 0.030854792201093266, 0.12034615155841623, 0.09203649671482188, 0.10105694125273398, 0.3980796406311648, 0.06366772790040288, 0.2291286007634231, 0.09680494227047477, 0.2198587946061577, 0.12550535186060838, 0.22653564704316004, 0.20183064841798373, 0.24669807084969111, 0.3265528758721692, 0.2363989134984357, 0.2328471897968224, 0.219937762511628, 0.2872021331318787, 0.29219636800033705, 0.18096455665571348, 0.2679168651146548, 0.16363393089600972, 0.14867369937045233, 0.22577275655099324, 0.24294612503477506, 0.16990923987967627, 0.208664066025189, 0.16822537380669797, 0.21591960026749543, 0.3129763943808419, 0.21629997342824936, 0.19159060503755296, 0.139125436012234, 0.0841434041836432, 0.1360316691654069, 0.11624860071710177, 0.2313549013010093, 0.13265876658260822, 0.1206844826894147, 0.08268137834966183, 0.8731398933700153, 86.62512343270438, 93.46729946136475, 86.17584596361432, 70.2204613004412, 33.290038858141216, 68.53877489907401, 75.91794245583671, 42.61639738082886, 34.225985527038574, 1.2269104101828165, 1.067354149052075, 0.889457466346877, 1.5675639765603202, 3.1975288561412265, 3.5201964676380157, 14.77014878817967, 16.477705069950648, 19.27665659359523, 22.64736843109131, 8.099657535552979, 0.40921125188469887, 13.489579285894122, 6.759983616215842, 1.9292811155319214, 4.995853798730033, 9.37342735699245, 19.919627257755824, 27.04858844620841, 41.304890155792236, 49.59781878335135, 58.24269451413836, 64.78758144378662, 77.5894775390625, 68.47733892713273, 60.93586145128523, 60.68438529968262, 60.007387569972444, 60.353046553475515, 60.61490331377302, 62.57464272635323, 62.885762214660645, 67.52564416612897, 68.3998109272548, 64.12057522365025, 64.77706187111991, 65.89143480573381, 65.41502462114606, 64.43945584978376, 56.14547109603882, 63.56532382965088, 63.20569896697998, 72.4851085117885, 28.02905569757734, 0.40285213025552885, 74.04022652762276, 71.7721677507673, 68.58862822396415, 63.37980692727225, 58.41138635362898, 57.7895746912275, 68.31415353502545, 71.76437882014683, 76.5550297328404, 74.16594723292759, 82.85813672201974, 74.57311861855644, 82.582168170384, 79.85547964913505, 80.8733490535191, 78.77934265136719, 79.16376563480922, 77.93328135354179, 73.90702956063407, 70.67597130366734, 71.2356070109776, 67.77369485582624, 65.13080855778286, 53.44451870237078, 48.009554386138916, 27.65416737965175, 13.603309137480599, 3.4076163257871355, 1.2352338092667716, 0.9895706943103245, 0.6952445677348545, 0.17278090864419937, 0.4758825014744486, 0.17112224336181367, 0.22386380684162888, 0.23292456993034907, 0.7607475157294954, 0.26855398235576494, 0.783385235284056, 4.475257847990308, 3.1563612137522017, 1.7848669333117348, 0.4342170315129416, 0.9085586071014404, 11.459275705473763, 52.90155519757952, 29.18620000566755, 84.57230595179966, 84.78889519827706, 22.715366976601736, 63.38667869567871, 75.26157392774309, 73.10873017992292, 40.23318958282471, 0.2451905831694603, 0.08960861699389559, 0.19378403733883584, 0.16190315091184207, 0.16694579246853078, 0.11407732936952795, 0.19818759390286037, 0.11764327516513211, 0.12945365213922091, 0.14754653056817396, 0.1887758925024952, 0.20932721186961445, 0.16776462138763495, 0.07380090880074672, 0.22384777984448842, 0.14739523082971573, 0.06849979289940425, 0.2243997816528593, 0.22588288278451987, 0.17760096357337066, 0.18273649657411234, 0.06636151192443711, 0.18823010607489518, 0.1973521408757993, 0.1544085552117654, 0.28824392865811077, 0.17785233365637915, 0.10557765367307834, 0.30199058673211504, 0.2091463687164443, 0.14822216145694256], [0.22627799372587884, 0.09287106764635869, 0.2265679860221488, 0.112006223361407, 0.1467660524483238, 0.010029730603231915, 0.1567394451371261, 0.13072757449533257, 0.1426045157547508, 0.24797979635851725, 0.15211683032768114, 0.08839970507792064, 0.2164007630199194, 0.14891744271985122, 0.14396583342126437, 0.08246110552655798, 0.03575636972008007, 0.029572720639407635, 0.056711590449724875, 0.06121807399072817, 0.15248349708105835, 0.13094602205923625, 0.06260417175612279, 0.09742952018444027, 0.1623730364122561, 0.07262177778674023, 0.11868483998945781, 0.02440498267034335, 0.03383044984989932, 0.03313622031626957, 0.09484423390988793, 0.03092432507712926, 0.08202984223940543, 0.03843811992555857, 0.041404576639511755, 0.009475339503426636, 0.07926256608750139, 0.5990122343812669, 72.39560876573834, 81.90685885293144, 71.7840769631522, 67.40808759416852, 17.921367032187327, 62.753385135105674, 80.40158721378872, 23.346214771270752, 27.743036576679774, 5.388663257871356, 0.8348556448306356, 0.0835480982703822, 0.1768862083554268, 0.3700933823628085, 0.36935505483831677, 0.20807124355009624, 3.1097342414515357, 4.286958192076002, 5.078160422188895, 3.4327716273920874, 5.844402117388589, 15.530945266996111, 18.077427046639578, 4.343043182577405, 0.9838792511395046, 0.11051778215914965, 0.008019901396307563, 0.2179302352347544, 0.04526283871382475, 0.7435086007629121, 2.9399867100375037, 5.634231703622, 8.07112649508885, 11.540374210902623, 11.238462822777883, 11.425078409058706, 13.86475247996194, 23.40323690005711, 30.874966621398926, 37.009680543627056, 43.143185479300364, 44.81636381149292, 55.34597315107073, 61.099158014569966, 64.29204286847795, 54.01672717503139, 58.545104435511995, 52.86481659752982, 56.327552114214214, 46.99242843900408, 47.133685316358296, 10.461151344435555, 0.06502600573003292, 54.348562717437744, 52.546074935368125, 61.58811664581299, 56.23257371357509, 59.01936762673514, 56.35649136134556, 69.47157055991036, 65.67099625723702, 71.84688867841447, 70.96038886478969, 73.62006201062883, 76.73848302023751, 84.16448838370187, 75.51110458374023, 73.44397381373814, 75.69024998801095, 79.88934516906738, 72.57235009329659, 63.09012957981655, 43.58979136603219, 33.028359276907786, 27.07194307872227, 20.987954480307444, 12.017961246626717, 4.24343033347811, 0.7522934036595481, 1.3659372414861406, 1.5215495313916887, 1.9073953756264277, 0.4212694162768977, 0.37623990539993557, 0.5169997694236892, 0.9556220131261008, 0.2298983580299786, 0.1329767145216465, 0.246356550604105, 0.1579979918897152, 0.17053231144590036, 0.3638569941478116, 0.4809290649635451, 0.030590567272156477, 0.016475074525390352, 0.11955170918788229, 18.08334517478943, 34.41751956939697, 17.381302663258143, 85.68410110473633, 56.9967748097011, 14.598436219351631, 43.68335928235735, 46.73418126787458, 46.854405948093955, 17.84719501222883, 0.142471170052886, 0.05333108488204224, 0.028488957722272192, 0.022629085196448222, 0.06259983591735363, 0.032080677670559714, 0.08735612500458956, 0.027199269605002234, 0.05498003015028579, 0.14001013711094856, 0.033708181232213974, 0.04740987279053245, 0.05923097740326609, 0.027248551603406668, 0.0629070969298482, 0.02298812860889094, 0.015478396488885795, 0.0212265991140157, 0.14830047796879495, 0.061526664931859286, 0.14532696109797272, 0.06564136913844518, 0.1283700724265405, 0.14506568440369197, 0.1308510135859251, 0.10339504400534288, 0.080728893833501, 0.08664622131202902, 0.038506601072315655, 0.12100686824747495, 0.12484661649380412, 0.0861283837418471, 0.08981253712305001, 0.03439696552231908, 0.3117090266730104, 0.10421736737979309, 0.15137595151151928, 0.13751209686909402, 0.19172769625272068, 0.20548054256609508, 0.23953371814319066, 0.23690442208732876, 0.09811327313738209, 0.09879756213298865, 0.12824363421116555, 0.09356073742466313, 0.15754905955067702, 0.025454727234318852, 0.09401414809482438, 0.007714578449460012, 0.07445770355739764, 0.019607687502035072, 0.18267633765935898, 0.08921692586903061, 0.13139955486570085, 0.10992589606238262, 0.21548130735754967, 0.07814914440470082, 0.09333973856908934, 0.09163645282387733, 0.05573158571496606, 0.027083849101992588, 0.062397523916193416, 0.06014270455177341, 0.023788596370390484, 0.032067341064768176, 0.058388223339404376, 0.013516622828319669, 0.03677584483687367, 1.6442324625594276, 86.01073592049735, 84.1244945526123, 70.73376641954694, 38.75010354178292, 26.010277441569738, 102.60092885153634, 55.370194571358816, 35.83969075339181, 53.76017883845738, 4.604192095143454, 0.6455445374761308, 0.17832219201539243, 0.1714563811463969, 0.3798538100506578, 0.3056028357573918, 0.6357850325959069, 1.9776212530476707, 5.656705217702048, 3.4145150184631348, 6.011340405259814, 11.023758275168282, 18.320370810372488, 20.964933361325944, 3.1140705687659125, 1.831377740417208, 0.4449505055589335, 0.25935565307736397, 1.1810593562466758, 0.3783668412693909, 2.5787392258644104, 9.052352837153844, 10.934978536197118, 16.975750207901, 22.290913684027537, 22.086191960743495, 25.337167228971207, 34.20263957977295, 40.862658160073416, 48.25185891560146, 47.819371768406455, 51.1198216847011, 54.88019718442644, 64.29188305991036, 67.65260859898159, 73.01954310280937, 60.898883138384136, 67.06053175245012, 60.0300178527832, 67.67840031215123, 57.67369263512747, 59.31725079672677, 14.169308526175362, 0.06055019875722272, 66.64575903756278, 60.99164158957345, 69.38248075757707, 62.37408297402518, 64.68354606628418, 62.38404669080462, 75.94034344809396, 69.5827556337629, 75.30807822091239, 73.23190784454346, 77.85133429936, 76.63521889277867, 88.48999908992222, 77.24899496350969, 75.4700824192592, 76.78195789882115, 78.57327992575509, 73.27067879268101, 66.21705518450055, 50.29795054027012, 38.78095006942749, 33.19352490561349, 29.832573550088064, 18.547913891928538, 7.89778196811676, 2.797184075628008, 2.472539050238473, 2.335903593472072, 2.497520864009857, 0.8741845658847264, 0.8726069991077695, 1.1762449060167586, 1.204257111464228, 0.20222217669444426, 0.4988328899656023, 0.6740606501698494, 0.3477556567106928, 0.594821113560881, 0.4856745760355677, 0.29503961971827913, 0.14353409515959875, 0.01195969114944871, 0.11927846313587256, 26.404728412628174, 65.44522149222237, 15.981390033449445, 63.348289898463655, 100.45185102735246, 22.55070856639317, 32.62579802104405, 45.93635089056832, 53.57475226266043, 25.213732481002808, 0.20946509018540382, 0.08487462066113949, 0.06933563269142594, 0.033731902816465924, 0.11184645550591604, 0.05620457212041531, 0.11638567836156913, 0.0927680456744773, 0.05523873858952096, 0.06853524635412864, 0.0894897308732782, 0.07041142960744244, 0.0679880010762385, 0.052180320024490356, 0.06096444438610758, 0.05604138784110546, 0.07664716642882143, 0.07218376307615212, 0.11988877824374608, 0.1119942811450788, 0.04480802686884999, 0.06439464246588093, 0.06631609079028879, 0.07638900421027627, 0.08937509916722775, 0.060794451007885594, 0.11427614012999193, 0.13288299526487077, 0.09296611004642077, 0.22235656343400478, 0.2045223018420594, 0.09561188771788563, 0.34759318828582764, 0.16580563650599547, 0.46250602496521814, 0.1778545185391392, 0.2562520339020661, 0.293303872857775, 0.25463978041495594, 0.2470275674547468, 0.28216930319155964, 0.22467386908829212, 0.2438796806548323, 0.23647960488285336, 0.1914465520530939, 0.23997701864157403, 0.2557068717266832, 0.21546946013612406, 0.20342960261872836, 0.15408030711114407, 0.12998476863971778, 0.14067217015794345, 0.27311957308224266, 0.21391191014221736, 0.23027209511825017, 0.1542309011731829, 0.40077426603862215, 0.24909677356481552, 0.16881656779774598, 0.1047655829627599, 0.24790428898164205, 0.15245113096066884, 0.29750036767550875, 0.1552625186741352, 0.18034497275948524, 0.09856352183435645, 0.13034614281994955, 0.09214822429099254, 0.3395690774278981, 5.040998416287558, 107.29645197732108, 93.59165137154716, 91.51570333753313, 86.56186703273228, 31.80278389794486, 82.78089359828404, 90.15016692025321, 36.03756850106375, 44.78787967136928, 8.12432450907571, 1.1250971534422465, 0.2961068738784109, 0.4798485115170479, 1.10295150748321, 1.1877687105110712, 5.056598859173911, 13.72755595615932, 18.001156670706614, 20.48567267826625, 9.635414396013532, 11.881313630512782, 27.238081455230713, 24.580223526273453, 9.320342251232692, 1.8258076735905238, 0.28929438229118076, 0.14021984514381203, 0.348245124731745, 0.21810472730015004, 0.6930018195084163, 5.12583201272147, 6.365906110831669, 13.456193191664559, 19.928677286420548, 23.892449140548706, 31.601543222154888, 42.42954642432076, 53.45333249228341, 60.415823527744834, 60.97898197174072, 61.47518062591553, 62.43226024082729, 70.83727373395647, 75.40631185259137, 77.47287981850761, 66.974853515625, 75.11076327732631, 68.00167219979423, 74.93170125143868, 64.8246431350708, 64.67573629106793, 15.801911115646362, 0.2179708116288696, 70.30194977351597, 64.43229920523507, 74.34860147748674, 66.43873746054513, 70.53192819867814, 64.7934318270002, 79.37033557891846, 71.6088364464896, 77.47984191349575, 75.79831532069615, 81.12394278390067, 82.24682031358991, 95.5041777747018, 79.09314414433071, 77.70607525961739, 77.82487555912563, 83.61460099901471, 80.86842278071812, 72.2806647164481, 55.75725439616612, 45.973193713596885, 37.03919996534075, 35.561787128448486, 20.965280771255493, 9.592432839529854, 3.754918558256967, 3.197821766138077, 2.9530866699559346, 3.2472519023077826, 2.151758526052747, 1.787104036126818, 2.514555241380419, 2.030315522636686, 0.6562899808798517, 0.9500047202621187, 0.5791377808366502, 0.5653329587408474, 0.5551535221082824, 3.3532846697739194, 1.8829099237918854, 0.3139876015484333, 0.1341528735522713, 0.4313134716025421, 27.394162314278738, 52.4955997467041, 24.288949830191477, 98.51303264072963, 75.66436794825962, 22.4114545072828, 58.14988047736031, 62.0839262008667, 63.94140897478376, 44.571589197431294, 0.22365808859467506, 0.12223566802484648, 0.12465119840843336, 0.18163196370005608, 0.21342719186629566, 0.2157377257410969, 0.1825981568545103, 0.15050986941371644, 0.09693521420870509, 0.2599221212523324, 0.15500890942556517, 0.10266462141381842, 0.12293972953089646, 0.15179426835051604, 0.13251037097402982, 0.14151762479117938, 0.1972922940871545, 0.16390371641942433, 0.2327359371951648, 0.20614303701690265, 0.22479570683624062, 0.07237062483493771, 0.19791286864451, 0.2054415810853243, 0.17376660289508955, 0.1274714342185429, 0.13685703916209085, 0.17490921515439237, 0.19803385143833502, 0.2902999169060162, 0.2684361072523253, 0.2026090637913772], [0.02649137267975935, 0.10309156921825238, 0.09961216377892665, 0.08002813679299184, 0.11664927564561367, 0.10136570182761975, 0.11040598672947713, 0.16847388047192777, 0.12136486332331385, 0.11129910844777312, 0.23176994760121616, 0.11931241702820573, 0.08400387024240834, 0.0787832693063787, 0.1489243773477418, 0.1436039435544184, 0.08394617440977267, 0.013610007058429931, 0.033511585888585875, 0.046936971201960526, 0.029301136998193603, 0.045653149019926786, 0.049160350646291456, 0.16531086234109743, 0.05212793033570051, 0.04112387688032218, 0.031424300212945254, 0.007803135751081365, 0.11524401605129242, 0.02453483222052455, 0.07459958522979702, 0.032547319773584604, 0.03874451241322926, 0.07049568330070802, 0.022265901024054204, 0.05576035559975675, 0.006797602832583445, 0.10326219363404171, 4.243454217910767, 73.69957024710519, 76.7587022781372, 54.95890637806484, 51.15738712038313, 18.195836509977067, 51.11930056980678, 90.62491648537772, 33.17729391370501, 40.26711416244507, 21.408370869500295, 0.21360947351370538, 0.14358404890767165, 0.21499292499252728, 0.2617239031408514, 1.3644177573067802, 0.3390386530331203, 1.7874222419091632, 4.213498796735491, 4.77593332529068, 2.7177448868751526, 10.632764032908849, 15.02955630847386, 12.250698106629507, 4.348389387130737, 0.6700919259871755, 4.193546610219138, 4.583393965448652, 6.397576868534088, 6.642624199390411, 0.5718591085502079, 0.4430795673813139, 0.14417362798537525, 0.5073495358228683, 0.2411843224295548, 1.119422429374286, 3.352190762758255, 7.373378838811602, 13.402510540825979, 21.491511276790074, 40.404546056474956, 49.702844279153005, 53.004993030003135, 50.80495016915457, 55.90381274904524, 57.013012749808176, 52.12915522711617, 45.4517696244376, 43.16876527241298, 40.24056509562901, 47.9040390423366, 3.3448315347943987, 0.07105472830257245, 48.67358677727835, 50.725230012621196, 54.922344957079204, 58.59489522661482, 62.92440809522356, 67.54193074362618, 67.81464753832135, 69.35852336883545, 68.46809782300676, 70.39257512773786, 70.81906250544957, 72.14529296330043, 69.83160536629813, 75.51132692609514, 77.18015916006905, 84.49131080082485, 77.30166925702775, 60.03313064575195, 35.35229546683175, 18.8222496168954, 12.715376257896423, 7.395690373011997, 3.819951091493879, 0.9311402525220598, 0.15141351521015167, 1.7203803764922279, 0.5559829090322767, 0.4896007967846734, 0.08158555107989482, 0.08496617539120571, 0.09280342449034963, 0.039133102633059025, 0.5355172072138105, 0.08013522318963494, 0.4306737759283611, 0.09667888403471027, 0.3608858250081539, 1.042912014893123, 0.24161725491285324, 0.3133375107177666, 0.08613514873598303, 0.496523591024535, 22.332132135118755, 27.784677130835398, 23.833330392837524, 89.69361468723842, 36.510535853249685, 15.122611795152936, 43.346444606781006, 31.17529903139387, 53.74558414731707, 44.44080325535366, 0.8216800689697266, 0.11798818808581148, 0.08534985980285065, 0.09169678137238536, 0.017809992090665867, 0.0671123041372214, 0.09312938592795815, 0.053512409795075655, 0.06664869508572988, 0.06358167608933789, 0.020446750335395336, 0.14961549240563596, 0.07787129788526467, 0.08646461819963795, 0.11502901544528348, 0.04316734276445849, 0.06210681237280369, 0.01097039133310318, 0.07250027252095086, 0.023853511815624576, 0.041536375281534026, 0.14539949649146625, 0.01800470789229231, 0.10791983442114932, 0.09620051684656314, 0.18466132400291307, 0.16042607517114707, 0.0805852615407535, 0.047305198585880656, 0.05461820474426661, 0.13165380193718842, 0.03251190363828625, 0.03876137061576758, 0.1314056073980672, 0.03280581108161381, 0.07198161392339639, 0.05740406936300652, 0.08700601450566735, 0.1166654247790575, 0.1174325764711414, 0.10880834888666868, 0.2353149673768452, 0.11702977094267096, 0.16471035884959356, 0.12959845151220048, 0.11519987056297915, 0.014476183302966612, 0.028819814790040255, 0.12613685083176407, 0.09413720720580646, 0.048340656595038514, 0.046751524188688824, 0.09762653282710484, 0.10210862981953792, 0.0700802638062409, 0.06254387034901551, 0.06717291088508708, 0.10896470371101584, 0.03663859755865165, 0.10337397549301386, 0.08170277478971652, 0.061417434364557266, 0.053057815081306865, 0.032861193109835894, 0.06432816639010396, 0.06867054623684712, 0.013218049608570124, 0.04346546730292695, 0.031531013415328095, 0.018171546082677584, 0.07990448057119336, 6.105696942125048, 89.47423226492745, 80.15939385550362, 54.07828821454729, 32.410772119249614, 25.349074704306467, 100.432833807809, 77.77851022992814, 28.328712395259313, 66.03154523032052, 20.951259306498937, 0.47016820524420055, 0.055329740313546996, 0.21791314972298487, 0.5311442932912281, 0.2658908138317721, 0.4114691721541541, 0.1273125484585762, 2.411192102091653, 7.787549665996006, 3.2772205684866225, 14.862125567027501, 19.91129115649632, 16.846077714647564, 5.6117416875703, 0.7623762711882591, 2.5075362580163136, 0.25797648993985994, 2.8528975546360016, 3.0318377699170793, 1.0145196127040046, 0.9686251325266702, 0.7040636230792318, 1.1614695617130824, 0.9901378410203117, 4.04126467875072, 8.311801671981812, 15.572262729917254, 29.290061678205216, 39.70215613501412, 59.884119578770225, 61.512395177568706, 61.64948313576834, 57.24227551051548, 63.44053418295724, 63.87326799120222, 60.06186144692557, 50.168071338108604, 55.73590953009469, 46.460453510284424, 57.75877332687378, 5.340165265968867, 0.5900687085730689, 63.579991476876394, 59.62497956412179, 63.645950726100374, 64.95413671221051, 67.73646640777588, 68.51519966125488, 71.5784797668457, 73.84200137002128, 74.41176755087716, 74.00396387917655, 76.15032495771135, 77.7318183353969, 75.0525929587228, 74.40365205492292, 77.94257804325649, 80.34955215454102, 83.6545739855085, 66.60034561157227, 41.256301403045654, 25.36496697153364, 17.528369971684047, 10.881973334721156, 5.036290143217359, 1.4017157959086555, 1.0735076474291938, 2.3914099293095723, 0.8757178921784673, 0.41739050298929214, 0.07006326650402375, 0.19008661859801837, 0.0574746166488954, 0.05903844987707479, 0.6148542357342583, 1.4313515999487467, 0.34557742359382765, 1.0544120435203825, 0.48576104853834423, 0.523630250777517, 0.06227349450013467, 0.2174084282347134, 0.07052983396819659, 1.1471406391688754, 37.07726567132132, 54.5272147996085, 15.861384221485682, 72.55246434892926, 77.09295231955392, 19.222750731876918, 26.42805698939732, 30.9018874168396, 62.09509890420096, 54.37689052309309, 1.2342325087104524, 0.22092808437134537, 0.056924955786338875, 0.12065588922372886, 0.010333918700260776, 0.0449493962473103, 0.047894686061356745, 0.12032361062509672, 0.007029003205908728, 0.053579306562564204, 0.10289655825389282, 0.18085110560059547, 0.06389076236103262, 0.047681575175374746, 0.008421633143110998, 0.037002136265592914, 0.037908747260059626, 0.015440842968278697, 0.06776522445891585, 0.018738908227533102, 0.08055014735353844, 0.08624421645488058, 0.03302210429683328, 0.09588858072779008, 0.042384706903249025, 0.1541419452322381, 0.12051490321755409, 0.10112954449972936, 0.10175923856773547, 0.09192495234310627, 0.11991720886102744, 0.04845258773171476, 0.041645344612853866, 0.2619884232325213, 0.10770937321441514, 0.18648566039545195, 0.11309998109936714, 0.16795813957495348, 0.1665932528142418, 0.2907564081251621, 0.16198495509369032, 0.2915384333048548, 0.13852357545069285, 0.25380808647189823, 0.1577989775687456, 0.10832492661263261, 0.13391682478998387, 0.2006125966353076, 0.23734359709279879, 0.14402517809399537, 0.09143669211438724, 0.2791736253670284, 0.22383822607142584, 0.10522651180092778, 0.08348527949835573, 0.1164386583758252, 0.23918025568127632, 0.1961061605917556, 0.11449812964669295, 0.17463267142219202, 0.29757989197969437, 0.1904517247208527, 0.17529836855828762, 0.23300398566893168, 0.16941042164606707, 0.16071545678590024, 0.11847240424581937, 0.10011771986527102, 0.19187956596059458, 0.11371267107980591, 0.275614220649004, 10.185906273978096, 109.0375315802438, 90.51180676051548, 76.1166261945452, 66.1662985937936, 27.20087558882577, 73.28878579820905, 107.06591769627163, 45.23232814243862, 61.679971831185476, 32.841101850782124, 0.2885385757046086, 0.3741138923381056, 0.6526227976594652, 1.6404710986784525, 3.537771067449025, 2.032230402742113, 7.994001490729196, 14.488235184124537, 20.46336374964033, 8.66271001952035, 13.318988851138524, 22.87808162825448, 16.55524696622576, 7.264851450920105, 1.3107281582696098, 8.179025071007864, 6.7115564090865, 12.59348748411451, 8.820356828825814, 1.9149346053600311, 1.071495275412287, 0.36439189687371254, 0.6711257419415882, 0.49729364684649874, 2.896019377878734, 8.187539219856262, 19.455004692077637, 34.784804821014404, 48.06771428244454, 70.10492665427071, 70.68587248665946, 69.61476598467145, 61.49473980494908, 66.44642216818673, 64.74505152021135, 65.28901209150041, 55.923635959625244, 65.14705344608852, 54.411607197352815, 68.67693982805524, 6.069213254111154, 1.2270023652485438, 69.51876967293876, 66.34926550728935, 69.75732912336076, 68.57727486746651, 73.20157895769391, 73.9598845073155, 71.44869436536516, 74.69057791573661, 76.8143504006522, 75.43675885881696, 75.73061902182442, 78.51181616101945, 76.30493627275739, 78.55848026275635, 83.32350621904645, 88.6492726462228, 92.78253364562988, 69.78502464294434, 42.65199647630964, 27.684098482131958, 19.697204998561315, 11.972610354423523, 5.172291142599923, 1.8258487113884516, 2.178900795323508, 3.831615379878453, 1.464001185127667, 0.698996052145958, 0.24066418462565967, 0.3521265893110207, 0.14142119139432907, 0.3612879791430065, 1.1614449173212051, 2.2893749816077094, 0.7294374129601887, 1.2205664877380644, 1.9460432103702, 3.036968146051679, 0.7127889320254326, 0.8536160524402345, 0.1930481253990105, 0.9999872382198061, 32.906599044799805, 41.27197306496756, 28.367130722318375, 103.58889320918492, 54.91530990600586, 22.76082730293274, 51.92760535648891, 45.60283388410296, 69.2278277533395, 70.27434458051408, 2.015331949506487, 0.5106140492217881, 0.24512718085731777, 0.26393519448382513, 0.1390998281006302, 0.12463253869542054, 0.2160295500819172, 0.15567280165851116, 0.09512676910630294, 0.14767960485603127, 0.23255403552736553, 0.19409790049706185, 0.1936114723128932, 0.1233523738171373, 0.12922517582774162, 0.20680319730724606, 0.12347083246069294, 0.1279260798224381, 0.19672567663448198, 0.12544721498021058, 0.10103937398110117, 0.1579986839954342, 0.12966118886002473, 0.17665047171924794, 0.15214709298951284, 0.3047389792544501, 0.13063074754817144, 0.17038010247051716, 0.19151318419192517, 0.16249982746584074, 0.30260561087301796, 0.10061505889253956, 0.10709269344806671], [0.012342569800759, 0.07543689744280917, 0.10060298775455781, 0.07389481804732766, 0.031139078017856394, 0.14264117021645817, 0.2208130591149841, 0.15119969525507518, 0.1691267125840698, 0.17614839651754924, 0.10984468899135079, 0.07284990804536001, 0.02812191947097225, 0.04237890542883958, 0.19427013982619556, 0.07870727338429008, 0.02916565051834498, 0.06984339401658092, 0.04608668539939182, 0.11596734795187201, 0.0921990465638893, 0.0978800810075232, 0.059385690172868114, 0.0017481723209909561, 0.06487775261380843, 0.06384148036262818, 0.04856643233714359, 0.028034848161041737, 0.022627473675778935, 0.042672823050192425, 0.04283927786829216, 0.016731253725343516, 0.019077385243560587, 0.024694725604993955, 0.026822199213451574, 0.07431129605642386, 0.10131340713373252, 0.13390659248190268, 0.3178349493869713, 3.828835231917245, 69.67939812796456, 77.48016847882951, 56.57111774172102, 60.886077608381, 14.395679967744009, 26.32063783918108, 82.27286216190883, 35.23293236323765, 39.89090394973755, 38.487948008946006, 3.284783031259264, 0.19150148624820368, 0.17293850518763065, 0.04171918618625828, 0.1349657585046121, 0.7912222061838422, 1.4207344268049513, 3.0409073403903415, 5.822381104741778, 7.320735812187195, 9.091964517320905, 9.165749175207955, 4.8924068467957635, 2.8747565874031613, 36.301165785108296, 39.90251438958304, 30.641660009111675, 20.967170681272233, 3.7821389947618758, 0.4669918471149036, 0.25704874257956234, 0.4950808084436825, 0.03707521787977644, 0.23346826647009167, 0.4912053421139717, 0.359647987144334, 1.360210188797542, 4.749728194304875, 12.84598502090999, 28.169565643583024, 49.857660566057476, 58.694657461983816, 57.14375352859497, 54.82891600472586, 55.95373903002058, 54.932874952043804, 50.156162125723704, 49.96807091576712, 18.045197827475413, 0.09287441282400064, 0.36538304654615267, 31.63802821295602, 50.36225264413016, 53.531965255737305, 63.2434207371303, 64.63012831551688, 68.10647882734025, 65.89618737357003, 65.72837448120117, 72.8124520438058, 76.17545659201485, 76.06327792576381, 75.60518319266183, 80.02343845367432, 76.35787459782192, 69.7118114743914, 49.565513134002686, 31.96140432357788, 19.124155793871196, 10.027680158615112, 4.390019084726061, 2.940654171364648, 1.2352787554264069, 1.292897886463574, 0.6001764919076646, 0.8407896235585213, 0.35273933357426096, 0.02343354613653251, 0.07245745017592396, 0.02524168759451381, 0.06581301814211266, 0.15380159206688404, 0.1635368868176426, 0.1737474546368633, 0.6268461751086372, 0.3070141614547798, 0.8253593029720443, 0.6503897117716926, 0.2993301866309983, 0.16650433758539812, 0.18915034883788653, 3.2718311548233032, 35.44028050558907, 25.308702196393693, 32.40618978227888, 76.75668035234723, 28.4109217439379, 21.458423955099924, 81.35137122017997, 53.981829847608296, 60.50017465863909, 55.22014822278704, 3.9020883526120866, 0.21104824809091433, 0.016883941067914878, 0.07874414497720343, 0.02077304764783808, 0.03569742877568517, 0.018136559120778526, 0.02358100706312273, 0.08264314290136099, 0.046459404685135396, 0.046613408385642936, 0.055649415124207735, 0.0931808188823717, 0.03314988940422024, 0.011359217343851924, 0.04816001360969884, 0.09228342917880841, 0.11585240411971297, 0.05603017844259739, 0.06298071797937155, 0.10972912769232478, 0.035080592946282456, 0.055222541958625825, 0.017898610460438898, 0.07506425958126783, 0.15736805354910238, 0.129427094278591, 0.204546810526933, 0.17556581992123807, 0.14023024030029774, 0.04888038370492203, 0.108627960351961, 0.039486286895615716, 0.060814705278192244, 0.14113761803933553, 0.14691281957285746, 0.08987576980143785, 0.09401686223489897, 0.040750258535678895, 0.16011033925626958, 0.17420546577445098, 0.18534779788127967, 0.160560954362154, 0.2178717048040458, 0.11022371186741761, 0.08433967722313744, 0.048522999310599904, 0.008194194142041462, 0.16534740823720182, 0.10946873309356825, 0.07012503354677133, 0.15543502941727638, 0.10951171828699963, 0.06589385201888424, 0.06765655029032912, 0.12951421817498548, 0.07175471181316034, 0.014932769517015134, 0.046304505318403244, 0.0326856323517859, 0.041257517744920084, 0.032446581072040966, 0.06232939221497093, 0.027594718117532984, 0.010919554641337266, 0.06948930051709924, 0.04618598221402083, 0.04718900964196239, 0.036877306178212166, 0.03197226473795516, 0.08816661472831454, 0.1349201202392578, 0.2454682939818927, 5.946014744894845, 90.96558666229248, 78.71767044067383, 53.80700969696045, 34.10259594236101, 15.862313543047224, 66.44624846322196, 85.59014756338937, 32.44984531402588, 67.05630029950822, 51.82034254074097, 4.4605936748640875, 0.19279086563204015, 0.07100016730172293, 0.10220418790621416, 0.5538616457155773, 0.3285429376576628, 0.5466597293104444, 3.1547993889876773, 2.8652288700853075, 6.2013614773750305, 6.595947938305991, 9.226474693843297, 6.127916846956525, 5.887973836490086, 28.199024268559047, 29.617054326193674, 40.128296102796284, 33.275520597185405, 6.151537248066493, 0.9176239435161863, 0.927117896931512, 0.03009493136778474, 0.23366178465741022, 0.48215384781360626, 1.015852906874248, 1.7892817535570689, 3.0499788650444577, 7.7895524842398505, 19.97306064196995, 40.359285490853445, 63.35119424547468, 71.02246407100132, 66.20615346091134, 67.50863497597831, 66.18307154519218, 68.55909143175397, 64.17603574480329, 64.28911767687116, 28.694621903555735, 0.0616831418925098, 0.5773577934929303, 46.25213609422956, 60.216306005205425, 63.61976991380964, 71.02843952178955, 74.22809886932373, 77.40302262987409, 72.71869305201939, 72.62794263022286, 76.68885203770229, 79.65957518986293, 80.31104523794991, 79.54675034114292, 82.33520139966691, 84.79211221422467, 79.88950497763497, 64.24630982535226, 42.28505516052246, 26.12780795778547, 13.873059051377432, 7.608862842832293, 5.674308044569833, 2.033769211598805, 0.9921086324112756, 1.379969237106187, 1.1481981767075402, 0.578845196536609, 0.09350245126656123, 0.07272695071463074, 0.014401094921465431, 0.05707020977778094, 0.17826630787125655, 0.12529829011431762, 0.08668778158192124, 0.665887614446027, 1.7530080314193452, 0.34971616151077406, 0.31322538959128515, 0.34042047602789743, 0.13071688078343868, 0.21366797680301325, 5.762542349951608, 55.64725399017334, 38.6316054889134, 13.479976875441414, 74.10055773598808, 60.10194560459682, 17.40342399052211, 51.07100364140102, 47.30293301173619, 62.100858960832866, 65.24828175136021, 3.9947230390139987, 0.1710368293736662, 0.08869409428111144, 0.0798812611028552, 0.02806269863088216, 0.027943788761539117, 0.018543836195021868, 0.024140671228191683, 0.03593847494838493, 0.096267752881561, 0.005946869196902428, 0.01189797923767141, 0.05433534724371774, 0.08445919438132218, 0.03620432157601629, 0.03519413899630308, 0.09530809401933636, 0.11241812804447752, 0.04151343061987843, 0.050407321591462405, 0.11907047858195645, 0.022345779862787043, 0.04988062913928713, 0.10001458254243646, 0.08791525143065623, 0.12739371481750691, 0.2132669218948909, 0.21921573339828423, 0.17522744807813848, 0.10960834845900536, 0.11239488822008882, 0.1394511056797845, 0.09572917928120919, 0.04341049918106624, 0.252132810652256, 0.17090030812791415, 0.1488748850034816, 0.25713893345424105, 0.19904267016266072, 0.20406434498727322, 0.32930558387722286, 0.33917039739234106, 0.3367950091404574, 0.28505511262587135, 0.18340085021087102, 0.1107815151501979, 0.17266192074332917, 0.09273776944194521, 0.4266319056706769, 0.18132798001170158, 0.17097023794693605, 0.29766131618193215, 0.2264227523867573, 0.20413492619991302, 0.23741275338189943, 0.2686328552663326, 0.13573417227183068, 0.10414696258625813, 0.17063656156616552, 0.11180387064814568, 0.12631005368062428, 0.14283266636942113, 0.14452696831098624, 0.1155758196754115, 0.07066737301647663, 0.13034209875123842, 0.1385161115654877, 0.21202442928084306, 0.16498142001884325, 0.22763723507523537, 0.20604517869651318, 0.21598860727889196, 0.43736038569893154, 8.9722227369036, 105.59912518092564, 95.59646374838692, 76.44681848798479, 78.72242995670864, 21.30439976283482, 39.61549820218767, 98.83829171316964, 43.419984340667725, 59.005728312901084, 54.4418283871242, 5.36264659677233, 0.17059745080769062, 0.17757667201970304, 0.25006493447082384, 1.2781932183674403, 2.1475029715469907, 4.112448973315103, 10.23987032685961, 15.418134314673287, 14.9058210509164, 16.27491668292454, 13.457934583936419, 10.739219989095416, 10.54870993750436, 42.784304073878694, 49.43048184258597, 57.05068588256836, 43.682125977107454, 6.760766591344561, 0.8993739028062139, 2.645479930298669, 0.7329210117459297, 0.43078785123569624, 0.927571809717587, 0.5862367770501545, 0.7753684797457286, 1.7441156400101525, 6.223457183156695, 18.937634876796178, 44.528541633060996, 69.89630699157715, 80.61101981571743, 74.67058794839042, 79.87842260088239, 76.04874924251011, 81.04661628178188, 77.12649127415249, 71.73152078901018, 26.647917100361415, 0.13704793820423739, 0.8995320286069597, 50.428621837071006, 67.1513238634382, 69.02078533172607, 76.84953607831682, 79.36989784240723, 79.24826267787388, 74.11602442605155, 74.65389837537492, 77.30961799621582, 79.1972906930106, 81.53477587018693, 81.55628054482597, 83.23425660814557, 83.98895604269845, 77.93712370736259, 59.507284028189524, 37.55439846856253, 22.48352469716753, 11.735873937606812, 6.848148873874119, 5.24541528735842, 2.4987476553235735, 1.9007724395820071, 2.0809338007654463, 1.6296517763819014, 0.4899051604526383, 0.08770324316407953, 0.13513305809881004, 0.11534515848117215, 0.20529433898627758, 0.48422734226499287, 0.24767689832619258, 0.31290734665734427, 1.6984345998082842, 3.8323584028652737, 5.453661484377725, 2.389163924115045, 0.9540859184094838, 0.3705941954893725, 0.25301987305283546, 5.34765498978751, 51.831136567252024, 37.138093675885884, 36.08122403281075, 95.78757395063127, 47.10932493209839, 27.375412600381033, 91.62715939113072, 68.90338856833321, 71.38361753736223, 79.93195847102574, 6.366471520492008, 0.3134936009134565, 0.26281531314764706, 0.2270434219390154, 0.19792463444173336, 0.12010341244084494, 0.21938154021544115, 0.14759201955582413, 0.14326677950365202, 0.20497010781296662, 0.17604255862534046, 0.0785968214539545, 0.1850753796419927, 0.2005114270640271, 0.14791507007820265, 0.10688883438706398, 0.15506625920534134, 0.18044428314481462, 0.22778179017560823, 0.07594368846288749, 0.2830384794090475, 0.08811082557908126, 0.14563839510083199, 0.24356367332594736, 0.2281232289969921, 0.18777946382761002, 0.22398010774382524, 0.325853061995336, 0.24583367151873453, 0.15730148926377296, 0.16165130585432053, 0.2653356636209147, 0.16074785004769052, 0.20117065097604478], [0.0470980384520122, 0.05133505877373474, 0.023155368831274763, 0.08744663479072706, 0.08614456001669168, 0.10518404229411057, 0.08123159328741686, 0.09368012566119432, 0.048282797913998365, 0.042964342050254345, 0.013305635756946035, 0.022974876819976738, 0.03977569904444473, 0.14064416023237364, 0.02858104170965297, 0.17388618790677615, 0.014840356440150311, 0.11437834107450076, 0.03973787410983017, 0.035132802823292356, 0.023126829648390412, 0.06663451370384012, 0.030221810630921806, 0.1427950891000884, 0.0432680441465761, 0.06009531566607101, 0.08059529707367931, 0.012290549913554319, 0.04483890360487359, 0.06766812609774725, 0.0384809761973364, 0.06771753023245505, 0.051692402455955744, 0.030748659146151373, 0.1891033263610942, 0.019772841229236553, 0.023839082768453018, 0.11641412254955087, 0.10690640165869679, 0.13563217488782747, 3.1899883236203874, 53.2515845979963, 79.5927265712193, 60.60326508113316, 60.32102230616978, 36.04192154748099, 24.773447717939103, 71.12688854762486, 41.81650686264038, 34.51256397792271, 48.75190339769636, 16.698993035725184, 1.4223189417804991, 0.22921328193375043, 0.03821567579039505, 0.18341960491878645, 0.5922036511557442, 3.232715402330671, 2.1159559786319733, 1.796542946781431, 4.914918141705649, 4.656436468873705, 2.0691948192460194, 1.594190124954496, 25.387949875422887, 28.956308432987758, 23.47174961226327, 18.841732365744456, 2.5781618739877428, 2.1842344062668935, 1.0619344455855233, 0.3078907201332705, 0.031295500695705414, 0.06493540094899279, 0.07198574620165996, 0.18448371067643166, 0.09370981156826019, 0.2896217075841767, 0.2350389664726598, 0.5507094434329441, 4.614725129944937, 9.231331484658376, 16.549516439437866, 26.16414529936654, 22.61969201905387, 16.241127593176707, 7.6921074731009345, 4.508881483759199, 0.1999155240399497, 0.8810683307903153, 0.7591596352202552, 26.849123035158428, 57.58703122820173, 44.964520250047954, 58.482619285583496, 57.953100545065745, 67.02041285378593, 68.00190149034772, 79.34286934988839, 74.58709839412144, 80.03108147212437, 74.53782871791294, 73.13927446092877, 58.54663303920201, 36.80985730034964, 17.44186316217695, 8.92532934461321, 7.708961197308131, 3.304014559303011, 0.6605424412659237, 0.7238347764526094, 0.43132465385964935, 0.345842106533902, 0.39411143213510513, 0.18584642612508365, 0.10197141646806683, 0.10047860550028936, 0.04314246427799974, 0.0010219784869280244, 0.04743834751259003, 0.08167789969593287, 0.07695767762405531, 0.08227110893598624, 0.024998951869617616, 0.11824206874838897, 0.4661626230393137, 0.17479600837188108, 0.21504559288067476, 0.01529727513635797, 0.08486913131283862, 10.961926255907331, 43.288354192461284, 25.272698368344987, 38.32245928900582, 96.36027227129254, 28.65049042020525, 26.699648175920757, 64.26691818237305, 46.35173504693167, 58.39020129612514, 50.696047578539165, 3.3265115235533034, 0.242457172700337, 0.04570915190769093, 0.016756205154316764, 0.05878440636609282, 0.0750055934435555, 0.043030207444514544, 0.05781436591808285, 0.015342419767486197, 0.06641461407499653, 0.01840044478220599, 0.08780994958111218, 0.03425422211044601, 0.04410183137016637, 0.038539978209882975, 0.06057381856122187, 0.06416679719196898, 0.0211969522227134, 0.008344632989194776, 0.07183213944413833, 0.053685269983751435, 0.03854338445567659, 0.03191015164234808, 0.08062982772077833, 0.050444702085639746, 0.0659827876037785, 0.04831146941121135, 0.10099373571574688, 0.2311756323490824, 0.07936784758099488, 0.04120190840746675, 0.051603110640176704, 0.01887979923880526, 0.0435767436533102, 0.007834104089332479, 0.05770902335643768, 0.09620994169797216, 0.09831622974681002, 0.046201934572309256, 0.08161599016083138, 0.14035108738711902, 0.05019822424011571, 0.15489065434251512, 0.025549379476745213, 0.022103152703493834, 0.023584725435024927, 0.040631559012191634, 0.035350704166506014, 0.035869769885071685, 0.05355336277612618, 0.052047547684716325, 0.0198356956243515, 0.11335097120276519, 0.03755510498636535, 0.03829763942797269, 0.009631452599673398, 0.01660456954102431, 0.03798566598977361, 0.07939286516713244, 0.009549773946803595, 0.021525561643232192, 0.04041609700237002, 0.02041389906246747, 0.013697851050112928, 0.07314660426761423, 0.021573700310130204, 0.03063958464190364, 0.024190504536298767, 0.030088173158999, 0.055624940366085084, 0.09825085968311344, 0.025517050675781708, 0.08199297064649207, 0.02849867773641433, 0.09388697027627911, 6.134378671646118, 73.6779613494873, 88.12291186196464, 55.17354318073818, 35.02034180504935, 8.316242439406258, 52.53538513183594, 88.64301231929234, 33.68039560317993, 48.237771442958284, 64.2209836414882, 21.308921303067887, 1.5981367017541612, 0.07874249613710813, 0.056993196053164344, 0.26383059152535027, 0.29781876344765934, 1.1537335025412696, 1.6723201211009706, 4.838946104049683, 3.64852774143219, 6.239069351128169, 6.858235486916133, 3.1241048531872884, 31.569157668522426, 40.225984300885884, 27.368577310017177, 23.167383772986277, 7.595097592898777, 2.4008814096450806, 3.274851667029517, 0.13896025344729424, 0.07100457777934414, 0.041231794482363124, 0.26619460753032137, 0.24060911472354615, 0.0765407449964966, 0.21028528974524566, 0.40710602913584026, 1.4234907988991057, 9.075725708689008, 17.43829005105155, 25.578379154205322, 40.58678688321795, 33.540132318224224, 24.69872852734157, 13.498528565679278, 8.17942372390202, 0.29193526772516115, 0.4726278675454003, 1.405699502144541, 36.21146106719971, 66.95305006844657, 52.38121850149972, 67.67499569484166, 64.05814565931047, 69.86920206887382, 71.4808714730399, 81.5527091707502, 81.51918411254883, 89.30171544211251, 84.04561165400914, 84.25140339987618, 70.95895753587995, 47.57574013301304, 24.8984214918954, 14.258294105529785, 12.079303417887006, 6.706366973263877, 1.0255266449281146, 0.7651195068444524, 0.7115250112754958, 0.7982657796570233, 1.0949439257383347, 0.18629827616470201, 0.07709966786205769, 0.12489917581634861, 0.024996405666960136, 0.030413683370820115, 0.05889863095113209, 0.06296842971018382, 0.037067075459552665, 0.10308913327753544, 0.10122002035911594, 0.3360042172883238, 0.44790066725441385, 0.3341932344649519, 0.318949538150004, 0.03345593923170652, 0.16573133692145348, 17.48000529834202, 57.46160929543631, 30.859034402029856, 22.687567234039307, 92.98401056017194, 51.171867166246685, 21.662905965532573, 47.577647413526265, 48.257316725594656, 62.56142030443464, 61.02981499263218, 4.63394124167306, 0.1654141896537372, 0.019331016544518725, 0.03540815572653498, 0.044650847624455176, 0.14797399405922207, 0.04183864227629133, 0.07193329544471842, 0.05590277670749596, 0.07621650025248528, 0.06635457051119634, 0.10424409487417766, 0.03949044292260494, 0.007458464558502393, 0.04492176290867584, 0.17783124478799955, 0.05165523570030928, 0.01587855233810842, 0.012066621483037514, 0.025702553668192456, 0.037795319953667264, 0.024230863799207976, 0.10806184501520225, 0.01726412254252604, 0.05243760354018637, 0.010009723150038292, 0.13953726605645247, 0.07656673288771085, 0.15316587260791234, 0.09669569813247238, 0.07371387989925486, 0.08850769392613854, 0.08449818300349371, 0.03926346278084176, 0.01831408084503242, 0.15675160448466027, 0.24209377648574965, 0.19037131832114287, 0.1856693420559168, 0.15571843992386544, 0.17145609616168908, 0.1165390137050833, 0.18134412914514542, 0.12044003366359643, 0.09274546402905669, 0.10442032398922102, 0.146579292469791, 0.1502597342644419, 0.16995091550052166, 0.1598090697079897, 0.2273241047348295, 0.12709434516727924, 0.16230502006198677, 0.19859299143510206, 0.15418623999825545, 0.08118377692465271, 0.08823016631816115, 0.17422119421618326, 0.16978593649608748, 0.2676127457192966, 0.13424752918737276, 0.12529606451945646, 0.1827661349837269, 0.09757668085928474, 0.20098294104848588, 0.2136197058217866, 0.1349872409233025, 0.14442786148616246, 0.11180328710802964, 0.39381420665553635, 0.18839313089847565, 0.11093326950711863, 0.23491077763693674, 0.17095969351274626, 0.25866145747048513, 7.479357974869864, 89.9451881136213, 100.8129905973162, 81.28761454990932, 81.84756292615617, 46.97924770627703, 38.0640036719186, 90.94062178475517, 52.688672815050396, 47.32351705006191, 72.98734515053886, 28.546927520206996, 1.4583668474640166, 0.3160464125020163, 0.15681337831275804, 0.33516568371227806, 1.4702424045119966, 6.288933966841016, 7.395540118217468, 10.756099769047328, 7.358372466904776, 9.966067007609777, 5.575856847422464, 7.7554203271865845, 31.784562247140066, 43.09485033580235, 34.286511284964426, 29.081282206944056, 5.384709732873099, 2.3225419904504503, 4.544462774481092, 1.1187701672315598, 0.14033681101032666, 0.10245074039059025, 0.4501748452229159, 0.8664901416216577, 0.4918975021157946, 0.9584312566689083, 0.5092358088919094, 0.8846700489521027, 6.721180966922215, 15.727594920567103, 26.92783396584647, 44.42485366548811, 35.17473077774048, 23.91901557786124, 11.693390914372035, 6.606661192008427, 0.4659094480531556, 1.6827565325157983, 2.080034009047917, 39.256165163857595, 82.35154356275285, 56.97574608666556, 70.06946304866246, 64.42993681771415, 72.88944503239223, 69.69439234052385, 79.87690789358956, 78.4895749773298, 90.25874641963414, 81.14686489105225, 80.85932064056396, 67.86322239467076, 42.794681208474294, 20.884514910834177, 12.238274727548871, 11.015840802873884, 7.958498801503863, 2.848076807601111, 1.0505258291959763, 0.78162831813097, 0.747009624327932, 0.7402373562966074, 0.1406052258930036, 0.21297045637454304, 0.17039265536836215, 0.09233609028160572, 0.12522340698965959, 0.18280088954738208, 0.16351893278104918, 0.2114623851541962, 0.33082232677510803, 0.21736071365220205, 0.4369250919137682, 1.7790148130484988, 2.479472483907427, 0.4452509337237903, 0.12852732970246247, 0.31808771725211826, 15.019905260631017, 58.6915168762207, 32.27263845716204, 44.19939504350935, 108.70651245117188, 43.526455061776296, 35.86979382378714, 77.1768240247454, 59.31214387076241, 72.2710553577968, 75.19796316964286, 6.767602750233241, 0.30055477949125425, 0.16650616962994846, 0.12911069339939527, 0.17969944168414387, 0.14580583040203365, 0.18904818860547884, 0.09834367648831435, 0.12313088641635009, 0.15207173489034176, 0.0922361963561603, 0.28422436863183975, 0.1598083097487688, 0.15093954492892536, 0.18494799147759164, 0.3669030735535281, 0.09997351081775767, 0.10011974868497678, 0.08905302573527608, 0.16239720582962036, 0.11631507000752858, 0.08531309677554028, 0.22325866217059748, 0.16523539567632334, 0.13455850178641932, 0.17700158644999775, 0.16479988475995405, 0.14468404916780336, 0.2504601132656847, 0.15479214462850774, 0.21219883992203645, 0.13505744215633186, 0.18549855479172297, 0.10195790683584553, 0.09570228215306997], [0.02419773263058492, 0.016741726913356354, 0.03113839609016265, 0.09900465780603034, 0.09939503935830933, 0.025717213417270353, 0.023659433836915662, 0.07084767334163189, 0.14456001296639442, 0.06999413735632386, 0.03528731203238879, 0.06568704811590058, 0.020262153187234486, 0.11566865683666297, 0.004224419502341854, 0.04728232517040201, 0.07911835025463786, 0.03590380859428218, 0.05524895732690181, 0.047649561893194914, 0.030118272972426245, 0.05945252587220498, 0.02716372285171279, 0.05790655168571642, 0.043399201573005745, 0.038076511650745354, 0.055209168033408265, 0.075678964810712, 0.0703192777665598, 0.03223945486492344, 0.03520891748900924, 0.04576201657099383, 0.08655359449663333, 0.02932767789544804, 0.024372116130377566, 0.01043202044508819, 0.026568622195294926, 0.058442309365740845, 0.04212525886084352, 0.058372433829520426, 0.05149975957881127, 2.3559580487864356, 46.840832642146516, 87.54538454328264, 52.876486097063335, 96.36372552599225, 46.84562342507498, 20.222322055271693, 74.77583926064628, 67.06172684260777, 35.01924398967198, 38.935307775224956, 29.888919966561453, 7.880207368305751, 0.3100088621888842, 0.27014425130827086, 0.012931921569231366, 0.4447909141225474, 2.188024648598262, 1.650328746863774, 0.41485473620040075, 1.31513483609472, 1.9102052705628532, 2.4162091357367377, 3.5449407398700714, 19.371159042630875, 15.120091336114065, 2.1061095127037595, 4.315239097390856, 3.690976457936423, 4.919385399137225, 0.11285147443413734, 0.0898024473073227, 0.00999558248024966, 0.04655627573707274, 0.04313649995518582, 0.38483333427991184, 1.1470066692147936, 0.11621483681457383, 0.6292143166065216, 0.7218197988612312, 0.1618732139468193, 0.2089593508946044, 0.4844660780259541, 0.10621497447469405, 0.10797904338687658, 0.05784623670790877, 0.03957827928076897, 1.4575471771614892, 2.965457937547139, 0.5069819869739669, 3.816825270652771, 59.841818945748464, 74.31322819846017, 78.90288162231445, 82.36009679521833, 90.00171170915876, 84.10230895451137, 70.82983916146415, 61.28346593039376, 46.90331779207502, 32.32275233949934, 23.008601801736013, 12.25166390623365, 2.988670131989888, 0.44657136287008015, 0.35177282829369816, 1.6242537860359465, 1.1538358799048831, 0.22027806139418057, 0.08476313735757555, 0.04851462618846979, 0.032134312471108775, 0.01188089796674571, 0.040277519795511446, 0.047050588498158116, 0.02367961346837027, 0.04350042203441262, 0.07469757247184004, 0.056091850490442345, 0.04129921032914093, 0.031182694248855114, 0.09011574728148324, 0.1648687289229461, 0.3106432110071182, 0.2383326297359807, 0.050655892717518976, 0.034796293558818955, 1.9785622996943337, 18.3754335471562, 45.558462687901084, 38.09988764354161, 52.45621735709054, 79.87218311854771, 40.31203774043492, 38.29294334139143, 56.37988594600132, 38.505613803863525, 59.3813270841326, 44.404071603502544, 2.311683693102428, 0.09984342208398239, 0.19593804675553525, 0.058506736265761514, 0.0834551186167768, 0.02173709832797093, 0.03162242565304041, 0.014350829047283955, 0.02252019559299307, 0.041567560750991106, 0.046758143297795735, 0.10025745736701147, 0.009967665005076145, 0.04191038378381303, 0.040870138710098605, 0.02088977433075862, 0.047814418761325736, 0.06273299841476337, 0.04354986009587135, 0.036013537884822915, 0.018602325913629363, 0.0244556624508862, 0.0704651695809194, 0.05011566349172166, 0.03808784318555679, 0.0688231216211404, 0.02782515878789127, 0.008556090794237596, 0.08628776483237743, 0.017592397784548144, 0.0770769165828824, 0.027227055614015887, 0.033994909775044234, 0.07954569839473281, 0.007327313917422933, 0.04081982873114092, 0.008786037830369813, 0.02899170806631446, 0.016318662025566612, 0.05082493953938995, 0.03453901343579803, 0.02359098322423441, 0.010352743806184402, 0.06503604126295873, 0.0621137334299939, 0.021404295561036894, 0.03610773550878678, 0.06492950447968074, 0.025479376715208803, 0.04727572641734566, 0.012199303916921573, 0.04785459142710481, 0.031702350292887004, 0.05032189742528966, 0.08422262314707041, 0.12864558478551252, 0.04172445161800299, 0.017732559370675256, 0.061711809997047694, 0.014404351889554943, 0.07465672466371741, 0.015847740062911595, 0.046676563032503636, 0.06662094300346715, 0.08553977496922016, 0.06996450573205948, 0.029192150703498294, 0.006060214655008167, 0.016058959532529116, 0.0057642720307090455, 0.0654257849923202, 0.0317154561967722, 0.04587236672107663, 0.027978926697479825, 0.02163026129294719, 0.12890473087983473, 0.07190716506115027, 5.426140104021345, 64.85017081669399, 99.0751280103411, 49.008013997759136, 80.11059665679932, 26.706215960638865, 38.71566826956612, 104.30017335074288, 49.32951756886074, 44.58736855643136, 60.768444606236045, 45.907508918217246, 8.961942008563451, 0.3471921740898064, 0.21633200028112956, 0.03938572461317692, 0.2854807712137699, 0.515287309885025, 0.39593194159013884, 1.606501572898456, 0.6058601726378713, 2.655804302011217, 1.6742217562028339, 9.820239084107534, 29.589007922581263, 23.659112998417445, 7.863905157361712, 5.187816458089011, 7.826114773750305, 3.8013099431991577, 0.9503284628902162, 0.07350284193775483, 0.04273155364873154, 0.14306566172412463, 0.1084668557824833, 1.3512616689716066, 1.2046079954930713, 0.6281664414065224, 0.7030782273837498, 0.6064502809728894, 0.22246879312608922, 0.2590541663978781, 0.8813761685575757, 0.2397808948797839, 0.052717655298433135, 0.05317844842959728, 0.14387292840651103, 2.0185431029115404, 3.731390220778329, 0.1899328354213919, 6.066077445234571, 69.03842680794853, 80.94070489065987, 82.72828183855329, 88.83753408704484, 96.66134466443742, 92.88340759277344, 81.91117368425641, 70.42423112051827, 56.04662602288382, 41.23884752818516, 30.644081456320627, 17.14441772869655, 4.665780058928898, 0.5671139231749943, 0.3161440129790987, 2.597953166280474, 0.7561332061886787, 1.0130887180566788, 0.43928753371749607, 0.11477483622729778, 0.10424136037805251, 0.017279810272157192, 0.059138981625437737, 0.02680641139990517, 0.06873352107192789, 0.03565729682200721, 0.14914137284670556, 0.041581328226519484, 0.15874017349311284, 0.06056287379137107, 0.18924788146146707, 0.20899159487869057, 0.49266744937215534, 0.29203688512955395, 0.022929430240765214, 0.07609453358288322, 4.742456470217023, 33.505422592163086, 58.7274112701416, 39.27870512008667, 36.242363180433, 87.88189969744, 60.14118903023856, 33.86602020263672, 46.58130700247628, 40.78522048677717, 65.50669915335519, 57.07485866546631, 3.858985636915479, 0.2547387922448771, 0.2305823213287762, 0.019151043612509966, 0.03723481270883765, 0.056104647660894055, 0.09756722886647497, 0.061966260629040856, 0.04047081067359873, 0.010453045700809785, 0.03942839768049972, 0.041574834646391015, 0.014284939904298102, 0.03384378645569086, 0.013225013074199004, 0.015258512127080133, 0.009369640710896679, 0.04243739514744707, 0.048872326101575575, 0.060581933840044906, 0.04532852429630501, 0.026739173668569753, 0.10274789123130695, 0.019762781947585087, 0.09338878986558743, 0.012187521156322743, 0.04598630971408316, 0.06798650829919747, 0.06025146014456238, 0.051778589974024465, 0.07097025069275073, 0.044349167562488995, 0.02894878733370985, 0.046356158796697855, 0.016751326487532685, 0.06736981496214867, 0.09383185966206448, 0.12873360434813158, 0.08112411334046296, 0.3084498058472361, 0.160861572516816, 0.1333758288196155, 0.039169977618647475, 0.16893696705145494, 0.20636273308524064, 0.13635888589279993, 0.10497700768922057, 0.1409845676805292, 0.0638863043859601, 0.1961811522820166, 0.12685242029173033, 0.1676655417042119, 0.15177985626671994, 0.14478063184235776, 0.17582951220018522, 0.14674385078251362, 0.10777076027755227, 0.10908096390111105, 0.07473472904946123, 0.10205276603145258, 0.172137196042708, 0.0909320724063686, 0.14685962242739542, 0.151136632210442, 0.13742729356246336, 0.1912493154938732, 0.08502494330917086, 0.15925026897873196, 0.22302135133317538, 0.16719554763819489, 0.13380549076412404, 0.11819733971995966, 0.13084113411605358, 0.12660879907863481, 0.15795527132494108, 0.2019015417567321, 0.187642616885049, 5.520370704787118, 76.42133249555314, 116.19655936104911, 69.79958111899239, 113.29740265437535, 56.96422249930245, 28.94257184437343, 94.99692453656877, 83.5336058480399, 46.83795608792986, 60.17263657706124, 49.122527258736746, 11.312974435942513, 0.3250046489494187, 0.29536670073866844, 0.12116612041635172, 1.8712940556662423, 4.692724304539817, 3.072091724191393, 3.2520085956369127, 6.521196178027561, 6.237010947295597, 5.398960053920746, 7.412009085927691, 29.666167667933873, 22.700306756155832, 5.127920814922877, 12.019281404358999, 14.482087765421186, 11.634869711739675, 1.6060504828180586, 0.7626641328845705, 0.2661680903817926, 0.24157084311757768, 0.27639399309243473, 1.7064060292073657, 2.928678951093129, 2.3659958073071072, 1.245711692741939, 0.8088992376412664, 0.3679371609219483, 0.5396627847637449, 1.0761893263884952, 0.4968793605055128, 0.18467649604593003, 0.15360428765416145, 0.19277470292789595, 3.44770656313215, 6.258278948920114, 0.4697597271629742, 4.171224653720856, 69.79988683973039, 90.40663882664272, 88.69244180406842, 90.37613623482841, 95.92701039995465, 89.13020610809326, 80.2756233215332, 68.04962171827043, 53.605154105595176, 38.7316004889352, 28.97210168838501, 15.53471987588065, 4.336400270462036, 1.291435724922589, 0.36921877786517143, 3.473594682557242, 3.2132663088185445, 3.5271257758140564, 0.43748599610158373, 0.19929766362266882, 0.19713370688259602, 0.18396099443946565, 0.14394591163311685, 0.13600683478372438, 0.18429387014891419, 0.1724315716751984, 0.30547239418540684, 0.1966397198183196, 0.19564170337149075, 0.2526799812912941, 0.4169268464403493, 0.5422966948577336, 1.2181602397135325, 0.3536438207541193, 0.2046099549957684, 0.1288614674870457, 2.6938428665910448, 26.747766188212804, 60.808028493608745, 46.91352816990444, 62.199516432625906, 96.46992874145508, 57.842558179582866, 48.478529998234336, 67.40627411433628, 50.53225769315447, 76.9429407119751, 65.7849119731358, 4.139118330819266, 0.38145257426159723, 0.32840948339019504, 0.11166959535330534, 0.1770678793213197, 0.18967922617282185, 0.1563926323183945, 0.19668641659830297, 0.15781528955059393, 0.12226370509181704, 0.11360601216022458, 0.18357603438198566, 0.0856647068368537, 0.1912111004016229, 0.14672631743763173, 0.11404139415494033, 0.14104170032909938, 0.13343191652425698, 0.1188797831003155, 0.16547432142708982, 0.13280987633126123, 0.0440046753335212, 0.2308316422360284, 0.15748443587550096, 0.16443581001034804, 0.10603259783238173, 0.07239754231912748, 0.15710805250065668, 0.18487077419246944, 0.11231026811791317, 0.17534217477909156, 0.33384346323353903, 0.1417972897844655, 0.12888422555157117, 0.07328030280768871, 0.1188384603176798], [0.050997209402599504, 0.030013625909175192, 0.03134204141263451, 0.034034495508032184, 0.017630950447970202, 0.0388188425318471, 0.04336866071181638, 0.04372466089470046, 0.01057013709630285, 0.005317675548472575, 0.023953490557947328, 0.0658649599977902, 0.09521927378539528, 0.07212880852499179, 0.025429056558225836, 0.017327852247815047, 0.035830309681062184, 0.043157911127699275, 0.013062249486600714, 0.01243480306584388, 0.021978823035689335, 0.01725817857576268, 0.08055545349738427, 0.03382953382762415, 0.02020421647466719, 0.029356356178011214, 0.054537581213350804, 0.050086059008858035, 0.020901324693113565, 0.008708410879730113, 0.030170221613453965, 0.035589680807398896, 0.03171614830249122, 0.01514978876470455, 0.02336568245664239, 0.07819843997380563, 0.026038657507992218, 0.017635964821758013, 0.07539917089577232, 0.057558035744088035, 0.07788226979651622, 0.06578439074967589, 1.7365766274077552, 38.95709385190691, 76.42859336308071, 54.25977863584246, 50.538941860198975, 38.02205739702497, 14.010947789464678, 53.236097063337056, 74.10593564169747, 44.38416848863874, 27.347618068967545, 32.29226016998291, 28.443444524492534, 5.799983586583819, 0.5080384931394032, 0.17363854976637022, 0.2186122172112976, 0.11257576530000993, 0.9496138840913773, 1.7884036749601364, 2.869455111878259, 1.855136671236583, 1.1228130417210715, 2.6421838785920824, 2.982315787247249, 2.728088800396238, 1.6513469836541583, 6.345538769449506, 1.5625846151794707, 0.14872008402432713, 0.21796063360358986, 0.05702284124812909, 0.06824636006993906, 0.022870721694614207, 0.03995553796578731, 0.03659963268520577, 0.01010791480075568, 0.060494830299701007, 0.4623551187770707, 0.8782762948955808, 1.9899923035076685, 0.9890233065400804, 1.5057947082178933, 1.067414185830525, 1.0629628875425883, 0.7958592602184841, 0.3837595119007996, 0.298306901540075, 0.08296988465424095, 0.058127720175044875, 3.280355508838381, 19.654025418417795, 43.671887806483674, 47.861998966761995, 30.527455942971365, 13.317058988979884, 7.017040908336639, 4.492233165672847, 1.8165988134486335, 1.3908478362219674, 0.650179963026728, 0.2826282371367727, 0.49326445162296295, 0.583635436637061, 0.3094183195914541, 1.700011515191623, 2.2562433651515414, 0.8850823268294334, 0.00979331458386566, 0.09048813408506767, 0.03563252350847636, 0.05606449535116553, 0.034270981925406625, 0.04099355744464057, 0.0346284409585808, 0.034279382188937495, 0.04674608573051436, 0.0044277374316672126, 0.08032082287328583, 0.10548811419201748, 0.2573189895067896, 0.3203063096318926, 0.09972615766205958, 0.2124237742807184, 0.027060515979038816, 8.826660581997462, 24.33021170752389, 45.36603580202375, 46.645352022988455, 68.43395437513078, 75.17578451974052, 33.699881826128276, 40.20703656332833, 42.50813055038452, 41.45561047962734, 65.97770363943917, 30.702091966356548, 0.3361420141799109, 0.014116093250257629, 0.04209940667663302, 0.0973784468535866, 0.04421089569638882, 0.055684118797736507, 0.03396417213869946, 0.038118669031453986, 0.03447435244119593, 0.016649573376136165, 0.059388967497008185, 0.17026825275804314, 0.0755624874894108, 0.004286043628651116, 0.02929613958778126, 0.016792177688330412, 0.03997911027233515, 0.06250514635550124, 0.08118102885782719, 0.07969822628157479, 0.053247472404369285, 0.0745082747723375, 0.04473458563110658, 0.0383134967913585, 0.04392612472708736, 0.020293401421180794, 0.04318142915144563, 0.031070902211857692, 0.04624820387523089, 0.027507290576717684, 0.047417852362351756, 0.026959225967792527, 0.029305018218500272, 0.017019983946478794, 0.009316206926346889, 0.10277347200151, 0.011764709022827446, 0.05312960747895496, 0.056256307022912164, 0.008648710824283106, 0.1016506797501019, 0.018620717605309825, 0.0719943093135953, 0.027431387953194122, 0.05648972646200231, 0.06913705263286829, 0.04996991416971598, 0.0616301279515028, 0.04699364583939314, 0.07841378663267408, 0.026345563985939537, 0.030557224061340094, 0.04684561324704971, 0.008328988516171063, 0.007843769820673125, 0.07238266204616853, 0.0200625383627734, 0.04948998974370105, 0.04231714856411729, 0.077465282886156, 0.03487376868724823, 0.023981882159465125, 0.03889567644468375, 0.09661339183471032, 0.04449436387845448, 0.08749430187578712, 0.030709958901362758, 0.028995212699685777, 0.03720469593203493, 0.05396894172632268, 0.043813962888504775, 0.02316102950966784, 0.05216122604906559, 0.07976666332355567, 0.023683681285807064, 0.09976999102426426, 0.03468027764133044, 0.08018785036568131, 0.06714488060346671, 3.9518869604383196, 60.726720673697336, 89.18395737239292, 59.83520426068987, 41.074147428785054, 17.74739977291652, 27.37669106892177, 94.1037266595023, 67.71416963849748, 42.10944986343384, 40.76680081231253, 50.33879899978638, 36.33501393454415, 8.940786480903625, 0.5446052881223815, 0.13729887402483396, 0.10646068557564702, 0.3083064721098968, 0.11871499408568655, 0.5288187095097133, 1.8703430209841048, 3.800968178680965, 1.8915778015341078, 8.327519365719386, 6.045899876526423, 2.9210654624870847, 7.222899096352713, 10.20465338230133, 1.657321348786354, 0.10632797091134957, 0.09746967588684388, 0.06457928541515555, 0.07014743877308709, 0.011821954477844494, 0.12678775590445313, 0.11193402045007263, 0.08747946910027947, 0.12152670749596187, 0.40001075129423824, 1.0323961334569114, 2.6536345098699843, 1.6849275188786643, 1.6920213039432253, 1.128587320446968, 1.469632048692022, 1.5771005962576186, 0.7460421962397439, 0.2144319393805095, 0.732571213373116, 0.07202767966581242, 3.974768246923174, 23.853544439588273, 49.41610949380057, 54.037540503910606, 34.59585550853184, 17.254680429186138, 8.220185330935887, 5.604437828063965, 2.1355822512081692, 1.6851415016821452, 0.8204671197703907, 0.5975792769874845, 0.7134157898170608, 0.9940790981054306, 0.935681334563664, 1.5239771668400084, 2.0960407044206346, 1.115328311920166, 0.04453736264258623, 0.018973923920254623, 0.03183505477915917, 0.04854669036077602, 0.020933879106970768, 0.02420892845839262, 0.007993492813381766, 0.04832648539117404, 0.07523029031498091, 0.12683343488190854, 0.07100545987486839, 0.023969704152217934, 1.1868456857545036, 0.3034228655908789, 0.046791333838232925, 0.2752008299742426, 0.2679818687694413, 18.44971673829215, 47.67721162523542, 47.56204175949097, 42.857975823538645, 63.76658535003662, 98.7602287020002, 50.79299579347883, 37.84031684058053, 37.93974208831787, 44.92164291654314, 70.9603819165911, 40.109077385493684, 1.3979184968130929, 0.07123987336776086, 0.0977901140494006, 0.008037747715466788, 0.05597222476665463, 0.08623388236654655, 0.05648786049070103, 0.07501173418547426, 0.018837239826098084, 0.042403936585677524, 0.04263736281011786, 0.0826313363920365, 0.056335295284433026, 0.036658495598073514, 0.05079631893230336, 0.042668538101549656, 0.03941759201032775, 0.056769269318985086, 0.016036208253353834, 0.05318415151642902, 0.01600845786742866, 0.06852061713912658, 0.04159082771678056, 0.08668754409466471, 0.033243601875645776, 0.07225459534674883, 0.010122410853260329, 0.04657863346593721, 0.029392796901187727, 0.017454083510009304, 0.006184657129259514, 0.03585142908351762, 0.03287567304713385, 0.03719887749425002, 0.07491076817469937, 0.03624658412965281, 0.026145737119285122, 0.11210066186530249, 0.10132045032722609, 0.08456691181553261, 0.1920935759054763, 0.13001379636781557, 0.12803820094891957, 0.1802403155182089, 0.19566153016473564, 0.12001432079289641, 0.08479015662201814, 0.12111457889633519, 0.15368009358644485, 0.2600528070969241, 0.14155642342354569, 0.12871528390262807, 0.15958044411880629, 0.10233036149293184, 0.10374765151313373, 0.19009138191384928, 0.1524044070392847, 0.11450845694967679, 0.08360898321760551, 0.23740349816424505, 0.14820666371711663, 0.1681899135666234, 0.2133085432329348, 0.24524877433265957, 0.13287683416690144, 0.24188296922615596, 0.07906967215240002, 0.08588436219309058, 0.20528341457247734, 0.11075101500110966, 0.18147070306752408, 0.11591416437711034, 0.17948410181062563, 0.12516052036413125, 0.13016605962600025, 0.15427385243986333, 0.12466642473425184, 0.13784799884472573, 0.25795811521155493, 3.4188268099512373, 64.20665645599365, 106.76277473994664, 77.63358470371791, 64.94119916643415, 52.41457680293492, 19.5890371799469, 78.45440319606236, 92.83559703826904, 59.469166210719514, 40.38815178189959, 49.34566865648542, 41.631132398332866, 9.15406664780208, 0.5002597676856178, 0.2518215530685016, 0.3495095340268952, 0.7714990930897849, 4.484534127371652, 6.7846588407244, 9.44843316078186, 6.557497475828443, 3.4984151678425923, 5.850021472999027, 5.370594467435565, 5.7565204330853055, 10.794026511056082, 14.405378784452166, 3.809451060635703, 0.6921828005995069, 0.222971234736698, 0.1561510738517557, 0.21265803171055658, 0.06109651444213731, 0.3028462193906307, 0.17074869626334735, 0.1874268834612199, 0.13057902960905007, 0.6306887460606438, 1.7774174873317992, 3.590573685509818, 2.771522641181946, 2.8800172422613417, 2.72798262323652, 2.44742956331798, 2.566391191312245, 0.8457642080528396, 0.6551242034350122, 0.7851296131099973, 0.2915551524077143, 4.5066046459334235, 21.16096636227199, 47.62514877319336, 51.91918413979666, 34.078621183122905, 17.798067774091447, 9.283875499452863, 6.347749165126255, 2.8488810615880147, 2.238605145897184, 1.5850359818765094, 0.6509325397866113, 1.1628050271953856, 1.840421038014548, 1.5268068207161767, 3.5178840202944617, 5.4489284583500455, 2.6743681515966142, 0.16525030987603323, 0.22253349822546753, 0.1960294997053487, 0.14207449848098413, 0.10453211941889354, 0.1668188249958413, 0.12428907783968107, 0.15536869583385332, 0.13924071911190236, 0.3341658487915993, 0.14988048747181892, 0.308213187115533, 1.468964044536863, 1.3705462855952126, 0.1327597868761846, 0.20921241731515952, 0.34787597454019953, 14.718059880392891, 39.78010450090681, 54.94922406332833, 55.485899448394775, 81.80233015332902, 91.07384654453823, 48.061002322605674, 53.40263843536377, 54.08032751083374, 55.159785747528076, 85.64865834372384, 45.78820487431118, 1.3712810575962067, 0.1259080081113747, 0.17445102759769984, 0.24718764743634633, 0.16893456503748894, 0.19439351106328623, 0.11227975439812456, 0.10076618221189294, 0.10868135427257844, 0.08491923433861562, 0.07550240999885968, 0.35025586826460703, 0.22157818877271243, 0.17110975831747055, 0.2603039193366255, 0.12152625966284956, 0.12787730672529765, 0.18674108811787196, 0.148810315611107, 0.15945988201669284, 0.14310607526983532, 0.1419906315526792, 0.17920466751924582, 0.11209151521325111, 0.16042055189609528, 0.19635666214994021, 0.09808196553162166, 0.14433928552482808, 0.1635825386536973, 0.11442620493471622, 0.2119134616638933, 0.14854202286473342, 0.16211817865925177, 0.15325412287243775, 0.1658327914774418, 0.16888634833906377, 0.12393693173570292], [0.045121533796191216, 0.030563320698482648, 0.02011440897227398, 0.034913944745702405, 0.008662354467170579, 0.040602039346205335, 0.03165273581232343, 0.039685782976448536, 0.0647021002535309, 0.04593389966924276, 0.03389810657660876, 0.014155256595196468, 0.02836809027940035, 0.0373777630738914, 0.019748127287519828, 0.023532327264547348, 0.023933536539386426, 0.016478446844433035, 0.01714904809237591, 0.013104694396523493, 0.04389611651588764, 0.04647558095997997, 0.03824620647355914, 0.05120779613831213, 0.013708034164405294, 0.027935079764574766, 0.051111735935722075, 0.004313922936229834, 0.008631537102961113, 0.061677557549306324, 0.043485348378973346, 0.03597137711143919, 0.07534218752490622, 0.045795057833726914, 0.01137059467977711, 0.059060950098293166, 0.10255159783576216, 0.049267769525093694, 0.14294294188065187, 0.027049311669543386, 0.04169343238962548, 0.04496774044153946, 0.04675462170104895, 0.3458317928016186, 20.482344491141184, 68.7889517375401, 73.1238842010498, 64.76480524880546, 57.95044980730329, 22.083563804626465, 38.56841509682791, 61.511922700064524, 69.85336712428501, 51.823205198560444, 56.29411390849522, 30.81600420815604, 27.161522729056223, 4.717003915991102, 0.11782912590673991, 0.06115729082375765, 0.09685690448220287, 0.2448688761464187, 1.4437162450381686, 2.5660911159855977, 0.07977654279342719, 0.4759406383548464, 3.6742912275450568, 4.891674680369241, 5.466846125466483, 10.029132332120623, 1.6660296129328864, 0.14880658366850444, 0.37882770225405693, 0.123541495097535, 0.031926280419741354, 0.04874145705252886, 0.05462371784129313, 0.06398502444582325, 0.04353216390258499, 0.020916812254914215, 0.14734090731612273, 0.046678507035332065, 0.11143759065972907, 0.027627342081229602, 0.19411702161388739, 0.04674165828951767, 0.05398355058527418, 0.0972508822700807, 0.052245547595833025, 0.03246330696025065, 0.02026320661285094, 0.3121508615357535, 0.7756436935492924, 0.11900247580238751, 0.06684728192963771, 0.14234223482864244, 0.2379900509757655, 0.5187328021441187, 0.16233833613140242, 0.24496995072279656, 0.2220091942165579, 0.6231120611940111, 0.8257924254451479, 1.201231605240277, 0.24947040208748408, 0.10712588059582881, 0.02847182471305132, 0.11045737218643938, 0.305913469088929, 0.2070451493241957, 0.02352922805584967, 0.06959220713802747, 0.050345883638198884, 0.07324343800012555, 0.02996873063966632, 0.061675277671643665, 0.05735675511615617, 0.020734518733141676, 0.05896106295819793, 0.05882082334054368, 0.10402118254985128, 1.1884602734020777, 1.0659293340785163, 0.07118968213243143, 0.033264605927148035, 1.7088326875652586, 16.484241587775095, 39.50246838160923, 49.962630476270405, 48.89619663783482, 64.81991141183036, 62.89043140411377, 20.537502765655518, 33.3665246282305, 36.38989428111485, 48.618640422821045, 52.624950885772705, 12.642985582351685, 0.059736445280058045, 0.04978497605770826, 0.05849063462976899, 0.03057347497503672, 0.0196467812971345, 0.03701911999710968, 0.05686390459803598, 0.054813690683139224, 0.08213120180049113, 0.04303014976903796, 0.02172957337461412, 0.11669840158096381, 0.01075939238736672, 0.030502476463360444, 0.11668219816471849, 0.07887721247971058, 0.06505958642810583, 0.07756493932434491, 0.03593149960839322, 0.06973494376455035, 0.0495541214809886, 0.0383595353923738, 0.09718222809689385, 0.021166601351329258, 0.024917237593659332, 0.07560590694525413, 0.05572260869666934, 0.048981950219188414, 0.04620240615414722, 0.036165366880595684, 0.010977392118158085, 0.05427950381168297, 0.011190589517354965, 0.013780265913477965, 0.05740540607699326, 0.025706573988177946, 0.028508357038455348, 0.032077142503112555, 0.07614936599774019, 0.03855231736919709, 0.012323223071039786, 0.08425055164843798, 0.09272419874157224, 0.0902037668441023, 0.039148593587534766, 0.04467858613601752, 0.027512832511482493, 0.06205409698720489, 0.08247599937021732, 0.02614908229692706, 0.0038720511781450894, 0.03481056993561132, 0.00512867810071579, 0.02511730364390782, 0.014987335606877292, 0.05395851603576115, 0.03921495431235858, 0.012933795174051608, 0.01137769639691604, 0.05803033682916846, 0.0214938299530851, 0.0638724961983306, 0.013890106314127999, 0.046371927950531244, 0.030473173928580115, 0.011164181782597942, 0.018870484649336765, 0.08847445928092514, 0.019907900232023427, 0.035236930807254145, 0.06739553822470562, 0.022495910824675645, 0.08963467952396188, 0.04563623992726207, 0.04019667913338967, 0.023739702833284224, 0.07442755624651909, 0.054254255523639064, 0.05153600352683237, 0.045570605234908204, 0.03140860230528882, 1.4398639031818934, 34.29695790154593, 87.70139244624546, 72.5268393925258, 46.39676284790039, 17.538309369768413, 26.389841897147043, 69.31944669995988, 83.00295802525112, 57.25243725095476, 44.68729754856655, 65.38505009242466, 47.526400974818635, 35.86621897561209, 5.013928668839591, 0.1337375829794577, 0.021927395170288425, 0.16430934465357236, 0.36966503677623613, 0.7820895590952465, 0.6448594342385019, 1.3306597173213959, 2.401707811014993, 2.3900545963219235, 2.138288574559348, 2.275517016649246, 4.665236362389155, 2.2326748583998, 0.10255151641155992, 0.06519072689116001, 0.062127290559666495, 0.08916198488857065, 0.03872362371268017, 0.11245382577180862, 0.06578426861337253, 0.039193451537617614, 0.072641672433487, 0.13813379779458046, 0.056857984379998276, 0.20840753907603876, 0.030934269007827555, 0.09055380948952266, 0.10459240725530045, 0.06931714939751796, 0.07057767747236149, 0.04305323013769729, 0.025239168533257077, 0.019903845985287, 0.26209438326103346, 1.2251006215810776, 0.13938023948243686, 0.05752722346889121, 0.4167625866830349, 0.6153576001524925, 0.8789417477590697, 0.7640051352126258, 0.6329353483659881, 0.4061398224106857, 0.7414303837077958, 0.95897419324943, 1.2424872943333216, 0.32864501646586824, 0.15224554842071875, 0.13526453104402336, 0.14315837674907275, 0.3031792443777834, 0.29854083327310427, 0.06908575538545847, 0.128871849072831, 0.043304315235997946, 0.11130632806037154, 0.14910675399005413, 0.10067179120544877, 0.028586079832166433, 0.06049242828573499, 0.1929899885186127, 0.2519401338483606, 0.2727811469563416, 2.1314122463975633, 0.39515102920787676, 0.039002165730510435, 0.07527997943439654, 4.098181281770978, 31.464451789855957, 52.04803153446743, 36.273001262119834, 45.263365745544434, 68.80211162567139, 81.9235623223441, 31.90653439930507, 32.47664104189192, 38.131804193769185, 52.09217344011579, 67.65611743927002, 21.971002987452916, 0.18072504736483097, 0.10360160363571984, 0.04753988688545568, 0.037798722806785784, 0.025518141420824186, 0.058164781757763455, 0.03421017500971045, 0.05670834705233574, 0.0324553002470306, 0.006321113066016031, 0.06329464220574924, 0.02347303008926766, 0.02075076286148812, 0.002415357781241515, 0.021602410823106766, 0.0397650731860527, 0.016227499149473648, 0.04048318715233888, 0.030847518305693353, 0.04885575966909528, 0.06804585975727864, 0.0704241996364934, 0.04769775823556951, 0.02945167338475585, 0.040658255972500355, 0.04851315716015441, 0.013683368568308651, 0.016201049854446734, 0.00868735254542636, 0.015059133093538029, 0.020542488233851533, 0.012911816576628812, 0.05651883561430233, 0.034342105966061354, 0.011351101216860116, 0.028007257230845944, 0.0076949636984084335, 0.003976094345229545, 0.15064994618296623, 0.1342955016131912, 0.10049498533563954, 0.15495704220873968, 0.14095009810158185, 0.19581033289432526, 0.12405711385820593, 0.1624286220009838, 0.11072010094566004, 0.188159402725952, 0.15227853879332542, 0.0978159187361598, 0.10659628401377372, 0.09967764240822621, 0.1479787438043526, 0.1463532317429781, 0.11472761018999986, 0.1295754491750683, 0.08835160373044865, 0.12160150919641767, 0.1187221458447831, 0.1642727173332657, 0.12841725775173732, 0.16861885626401218, 0.15141621577952588, 0.1402646013136421, 0.1802516741944211, 0.08830410627914326, 0.21898402726011618, 0.14226994370775564, 0.11201654387904064, 0.11483321738030229, 0.09527926985174417, 0.1500073735203062, 0.11989392153918743, 0.1493407128644841, 0.1784652950508254, 0.09887948166579008, 0.20916566625237465, 0.13494713950370038, 0.1841814640377249, 0.09113360409225736, 0.1932798722492797, 0.8726534651858466, 31.773441655295237, 99.20250933510917, 99.69272559029716, 78.70059176853725, 76.6911449432373, 32.207697119031636, 58.08658586229597, 83.00683512006486, 87.03058556147984, 65.1809606552124, 75.79517473493303, 51.81370006288801, 39.92013502120972, 7.690348710332598, 0.236931319215468, 0.12429488609944071, 0.3143296646220343, 0.7972929775714874, 2.426641638789858, 6.388759170259748, 1.6454163704599654, 4.479166643960135, 5.889366081782749, 6.72743695122855, 15.057250091007777, 18.350393976484025, 5.21038464137486, 0.9988412197147096, 1.4681593562875475, 0.22156373597681522, 0.18749770894646645, 0.14828819648495742, 0.22856509100113595, 0.16019044710057123, 0.15232170719121182, 0.22667978145182133, 0.32909754504050526, 0.1403373945504427, 0.4151281586715153, 0.26027333097798483, 0.4505865259894303, 0.310639492635216, 0.22125828665282044, 0.19418871562395776, 0.14183285859014305, 0.13655146770179272, 0.06898227879511458, 0.7935426873820168, 2.313853050981249, 0.14590653856950148, 0.20595847549183027, 0.7100926509925297, 0.9238603860139847, 1.2014422225100654, 1.2304090453045708, 0.7595602422952652, 1.237674581153052, 1.1809721780674798, 1.8157985763890403, 1.6717605739831924, 0.7794396355748177, 0.5425672946231705, 0.23666411212512425, 0.3290029029761042, 0.30892440038067953, 0.5937546736427716, 0.12793168452169212, 0.43241066272769657, 0.2060203714562314, 0.193971720124994, 0.1460265035607985, 0.2107028601957219, 0.20060517346220358, 0.24907663464546204, 0.3738216608762741, 0.31549397643123356, 0.19310229963489942, 3.0875584142548695, 1.4131600218159812, 0.12776817115289824, 0.25666121765971184, 2.219952706779752, 27.848407745361328, 54.6425826890128, 60.7665616444179, 57.96382508959089, 80.73771326882499, 77.0524651663644, 34.816797801426475, 45.858621392931255, 49.991666998182026, 64.4035336630685, 79.3927435193743, 22.970508302961075, 0.20047344267368317, 0.14345989056995936, 0.12563432779695305, 0.13625236946557248, 0.11170387494244746, 0.11071757679539067, 0.08624875585415534, 0.19572626240551472, 0.2275107018649578, 0.11934719873326165, 0.1556684590343918, 0.28720517296876225, 0.17198550275393895, 0.13807913501347813, 0.18262153917125293, 0.16515615635684558, 0.15981330376650604, 0.15236448203878744, 0.18142412842384406, 0.0978343952447176, 0.2384696395269462, 0.14824255821960314, 0.21693420011018003, 0.11502953113189765, 0.11550454635705266, 0.19728104397654533, 0.13133475477141993, 0.10481205582618713, 0.10258600634655782, 0.13790927055690969, 0.14930575474032334, 0.1078818907429065, 0.06447129656693765, 0.154557575072561, 0.1184110375387328, 0.08476147494677987, 0.08844366057642869, 0.14022521914115973], [0.03297908517665096, 0.020280587287353616, 0.03073969230587993, 0.025907518741275583, 0.04791377664410642, 0.03077252661543233, 0.049722269243959866, 0.01560737072889294, 0.024542024691722224, 0.05981166088687522, 0.07479213311203889, 0.0665643396122115, 0.04946875159761735, 0.028138677589595318, 0.034745858050882816, 0.040914535256368775, 0.012532999805573906, 0.06907400315893547, 0.01680047786794603, 0.009973531788481134, 0.04754808019580586, 0.05746937835855143, 0.04901126293199403, 0.03973024398354547, 0.052678032246019156, 0.018652812311691896, 0.058041851568434916, 0.018054905912971923, 0.034920977761170695, 0.046168428513088396, 0.03641774119543178, 0.025097366588722383, 0.028524248328592097, 0.003989333835696536, 0.018889928070296134, 0.0475077921790736, 0.021837151709145734, 0.03659362765029073, 0.034795821976980994, 0.06462756996708256, 0.06242753552006824, 0.030265443825295994, 0.08608860123370375, 0.018019024981185794, 0.04623522010764905, 6.07743992124285, 42.199908460889546, 64.20040307726178, 75.47432776859829, 53.12413379124233, 24.724318742752075, 17.211818729128154, 42.473146370479036, 70.19853278568813, 60.171114921569824, 47.83040203366961, 40.737389087677, 43.373566899980815, 13.77058093888419, 0.6538221761584282, 0.23399421253374644, 0.1180969165371997, 0.4486330236707415, 0.4678113545690264, 0.3414752722850868, 1.489584235208375, 1.013861813715526, 0.48932775429316927, 0.45085715289626804, 2.1163717848914008, 0.9178524741104671, 0.18567607312330178, 0.055958328369472704, 0.15065632441214152, 0.0499788402978863, 0.0070352614192026, 0.04752872159172382, 0.01748634106479585, 0.05383477160441024, 0.02381020092538425, 0.025738158096958483, 0.06762516804571662, 0.06435688199209315, 0.05531411365206752, 0.04097671959815281, 0.06861128977366857, 0.007002776979269194, 0.07684642502239772, 0.029395612821515118, 0.027482951525598764, 0.036004350520670414, 0.26993167985762867, 0.19127628047551426, 0.28723353573254173, 0.27135386211531504, 0.4824604370764324, 0.23497781689677918, 0.22090130937950953, 0.17270625622144767, 0.04588842085961785, 0.07684329019061156, 0.10623733220355851, 0.07550903250064168, 0.020234954111011963, 0.025727547505604367, 0.022065380355343223, 0.027760377353323356, 0.019381972828081677, 0.16246619927031652, 0.17498546891978808, 0.10946036675678832, 0.09909463833485331, 0.12294954114726611, 0.023039307112672498, 0.04791078091199909, 0.029682473678674017, 0.07894091334726129, 0.055844066465007405, 0.08077616736825023, 0.8581504576972553, 2.785415781395776, 0.5362821061696325, 0.13990394638053008, 0.053795565851032734, 4.080906757286616, 18.616940770830425, 42.97385093144008, 53.18697329929897, 63.35738509041922, 66.5928624016898, 53.52848073414394, 29.243373257773264, 38.64897945949009, 55.15084341594151, 64.70564828600202, 32.93178973879133, 4.219780402524131, 0.09795309816087995, 0.017187086765521338, 0.030590451921203306, 0.0789123945204275, 0.05825119319238833, 0.030831698261733567, 0.061400688120297024, 0.0323543919117323, 0.014471888176298566, 0.029096188888485943, 0.05381224424179111, 0.02338906986239765, 0.033635432100189586, 0.007911822642199695, 0.05070083887715425, 0.02530672517605126, 0.04425682233912604, 0.06038154209298747, 0.100947384988623, 0.03095609408670238, 0.03190947310732944, 0.023429049145696417, 0.05148511340043374, 0.014267104611332928, 0.050244917627424, 0.008721426029556563, 0.040914121350007396, 0.09336483757942915, 0.018542743753641844, 0.09316867310553789, 0.04483455419540405, 0.05738591855125768, 0.014806779134752495, 0.052832483779639006, 0.004864812795338886, 0.05777776573917695, 0.041900049695479016, 0.01626558362373284, 0.057657407197569094, 0.025277161405288746, 0.027818281835477267, 0.06979498732835054, 0.025420698703133633, 0.11539068818092346, 0.03779469230877502, 0.06083715121660914, 0.01424703184914376, 0.015823733493951813, 0.0260729540605098, 0.018540947332179973, 0.051781341433525085, 0.09088587095694882, 0.025722124314467822, 0.07150436631803002, 0.017446220985480716, 0.009454253179553365, 0.043364219700119326, 0.02324254870680826, 0.01426033622452191, 0.015010768813746316, 0.07685497456363269, 0.08974823914468288, 0.07019572332501411, 0.03111560070621116, 0.03764242226524012, 0.05283597484230995, 0.013736675127542444, 0.03350388112344912, 0.058517531757908206, 0.06881636341235467, 0.01755995363263147, 0.0376474061049521, 0.027425532195983187, 0.035739131537931304, 0.012427553767338395, 0.03636325144075921, 0.0471146523819438, 0.02423226667035903, 0.07025173639080354, 0.01578752008000655, 0.03655630483158997, 0.030816248019358942, 0.0516038163165961, 0.09101055855197565, 14.183052931513105, 65.81057861873082, 78.8287582397461, 66.49536527906145, 35.23721592766898, 24.53301225389753, 35.76922559738159, 74.67916897365025, 83.34642832619804, 66.10079097747803, 48.181966985974995, 58.795545305524556, 58.03894206455776, 16.444702863693237, 0.5063371615750449, 0.13042414720569337, 0.08451933294002499, 0.2080036343208381, 0.48003079316445757, 0.2792500284101282, 0.42861797767026083, 0.7700933856623513, 1.653601456965719, 2.3473550932747975, 1.938928472144263, 1.45437510737351, 0.2584441091333117, 0.501136054950101, 0.19376581188823494, 0.037251192544187815, 0.018309594032221606, 0.028599640354514122, 0.05147729328434382, 0.038194464785712104, 0.05159953136795333, 0.05049940897151828, 0.020227598791409816, 0.0991062412836722, 0.043989197949745824, 0.0239237842948309, 0.04729645226949027, 0.07248250168881246, 0.03658685926347971, 0.01740896432394428, 0.071727882538523, 0.023760301460112845, 0.18821429620896066, 0.7391372067587716, 0.1541515261467014, 0.6606209341968808, 0.4385752076549189, 0.5821498792086328, 0.22720089634614332, 0.14307555476469652, 0.03838383712406669, 0.02184558759576508, 0.05207929294556379, 0.04148433503827878, 0.02583692904694804, 0.0528642629672374, 0.01772900384717754, 0.09065967452313219, 0.02653884807867663, 0.2769120952912739, 0.44556778243609835, 0.1001574413052627, 0.0805259168680225, 0.11352262020643268, 0.025235207585085715, 0.11592128899480615, 0.07639168442359992, 0.07198288956923143, 0.11657010417963777, 0.15887033008038998, 1.7465757365737642, 3.129724208797727, 0.07439723251653568, 0.21351028526467936, 0.11414123379758426, 11.871793729918343, 37.90403529575893, 44.645035130637034, 44.70050607408796, 71.72095952715192, 73.3771390914917, 66.98070389883858, 34.6822772026062, 29.81272602081299, 51.382870061056956, 70.82384286608014, 49.43623495101929, 8.15719383103507, 0.04427053213917783, 0.03221126512757369, 0.023867367500705377, 0.1057881216651627, 0.038965914997139146, 0.026784258927883844, 0.012527857358301324, 0.03636394015380314, 0.032391392426299195, 0.032984126691839526, 0.050528328134013076, 0.01997760613448918, 0.050220303769622526, 0.03634097852877208, 0.023834500960739594, 0.04030245256477168, 0.024083860883755342, 0.015297229335244213, 0.011762879522783416, 0.06827555064644132, 0.013802928983100822, 0.06071796654058354, 0.005867573050116854, 0.010008093817824764, 0.02549205005301961, 0.01531934448783951, 0.04198219993018678, 0.04078360853184547, 0.01292466972621956, 0.02608118299394846, 0.049003449601254294, 0.05060197293226208, 0.046344990110290904, 0.02143794920162431, 0.0817608709580132, 0.030357626200254475, 0.05443221490297999, 0.02332370658405125, 0.013383499346673489, 0.13174851185509137, 0.11508465531681265, 0.13321945363921778, 0.09683936435197081, 0.21382200425224646, 0.10405050204800707, 0.20590451838714735, 0.07463612434055124, 0.10412558873317071, 0.1870899229709591, 0.1588040507797684, 0.14174935807074818, 0.20173274938549313, 0.08240252081304789, 0.12062242387660913, 0.1004060972481966, 0.20317648191537174, 0.13052010562803062, 0.10533739120832511, 0.08483377963836704, 0.10466515977999993, 0.16941025879766258, 0.27901313826441765, 0.13943340948649816, 0.1430820958422763, 0.08758701690073524, 0.094524006093187, 0.10683802568486758, 0.07855889134641204, 0.2157093086945159, 0.1457498919750963, 0.18780497674431118, 0.12848421558737755, 0.11466983971851212, 0.20714030707521097, 0.1329973012741123, 0.06654039411140339, 0.127277210354805, 0.14612337122006075, 0.09876902973545448, 0.15421952892627033, 0.11854335186736924, 0.16856215787785395, 0.1990694044423955, 0.16010819508561067, 11.047382150377546, 68.44519656045097, 98.73263740539551, 94.48275089263916, 72.11939702715192, 39.09642260415213, 32.554037025996614, 64.75557804107666, 95.92302908216203, 74.84386212485177, 60.99433749062674, 61.65029607500349, 64.4826944896153, 21.826035772051128, 0.5369002244302205, 0.3599717297724315, 0.13706502371600696, 1.1578368480716432, 1.4463788164513451, 1.3210291883775165, 4.328428081103733, 3.2115440240928104, 2.7262466592448096, 4.569493659905024, 5.22817029271807, 3.589169932263238, 0.460586422256061, 0.3341278779719557, 0.31282038560935427, 0.12582665176263877, 0.05527263480637755, 0.13014178164303303, 0.21355764700898103, 0.1489474746797766, 0.1976617971169097, 0.1909653485885688, 0.16481238337499754, 0.2647722624242306, 0.24716636857816152, 0.11378403939306736, 0.22957779094576836, 0.2657770642212459, 0.16968668039355958, 0.08609801929976259, 0.16312325187027454, 0.14868858642876148, 0.8740606925317219, 2.100186173404966, 1.2944296385560716, 1.257687998669488, 1.0066832389150346, 1.2223275303840637, 0.5524496414831707, 0.35363176997218815, 0.17300914068307194, 0.2017495363418545, 0.22241408963288578, 0.1570342414613281, 0.08806939423084259, 0.20374843265329087, 0.12547689410192625, 0.2059828620404005, 0.10070913777287517, 0.5102282613515854, 0.2983103756393705, 0.2980441727808544, 0.29558744175093515, 0.26190998458436554, 0.214365917923195, 0.17537687505994523, 0.21122553572058678, 0.1809800543955394, 0.37377400057656424, 0.2788006482379777, 2.196830404656274, 5.114891639777592, 1.1489249148539133, 0.43937473903809277, 0.25597717293671196, 8.333886521203176, 34.92558227266584, 58.74752630506243, 66.90908186776298, 80.84019224984306, 79.62015111105782, 65.48366587502616, 42.610797132764546, 50.367661816733225, 67.32931586674282, 87.91845417022705, 59.40526362827846, 9.386635882513863, 0.1514682187033551, 0.13720413696553024, 0.14620034423257622, 0.2397550834076745, 0.14628341048955917, 0.13095800498766558, 0.1993741752313716, 0.22732994013598987, 0.10692017591957535, 0.09741241431662015, 0.1107955811811345, 0.08783662279269525, 0.24432211262839182, 0.1340069342404604, 0.12647143644945963, 0.11614525983376162, 0.21676904468664102, 0.17120066843926907, 0.12168186131332602, 0.10986469898905073, 0.18741477839648724, 0.11758196274084703, 0.18594423016267164, 0.12419579284531729, 0.08368856180459261, 0.08109834936580487, 0.13774898701480456, 0.17753023308302673, 0.11190219715769802, 0.13366310697581085, 0.16845801632319177, 0.18523615172931127, 0.15611420225884232, 0.10725911094674043, 0.12591008442853177, 0.10135160186993224, 0.14091371505388192, 0.11249664811683552, 0.1682595448302371], [0.006037227160829518, 0.08216140339417116, 0.09011922816612891, 0.03339807037264109, 0.05680427494059716, 0.04096411241750632, 0.006676533101459167, 0.028066065860912204, 0.007238161201322717, 0.018090484896674752, 0.09349535379026618, 0.07646887456732136, 0.004171351702617747, 0.02273148630878755, 0.04396419393430863, 0.0535819698125124, 0.022880485813532556, 0.0276141886798931, 0.06904826632567815, 0.047235119489154646, 0.023573689062946608, 0.06642743838684899, 0.03948621904211385, 0.014954263810068369, 0.04518299889085548, 0.03001692019669073, 0.04438521473535469, 0.04379012256062456, 0.02620523446239531, 0.02774754286344562, 0.02604178385809064, 0.0625543605004038, 0.053188304150743146, 0.017960769357159734, 0.039966095970677476, 0.0652987632368292, 0.057465415714042525, 0.056017974990286996, 0.05221300505633865, 0.08083036196018968, 0.02570773597939738, 0.03824894775503448, 0.1254955538149391, 0.0977188746577927, 0.0822279608941504, 0.1694890774254288, 0.08405197158988033, 23.48814388683864, 49.494596345084055, 66.82849666050502, 58.51747144971575, 43.51272194726126, 25.594816855021886, 27.874043124062673, 52.49826785496303, 56.380247252328054, 56.49802269254412, 53.09488187517439, 48.10950769696917, 31.857692037309917, 6.902944105012076, 0.09604488805468593, 0.03991799462320549, 0.12154592360769, 0.1465111675539187, 0.24210688578230993, 0.09352824916797024, 1.0341912657022476, 1.3285155466624667, 1.0153720698186328, 0.3565988950431347, 0.300312623913799, 0.022718792614926184, 0.061748349107801914, 0.023887781226741414, 0.06580698596579687, 0.06150227838328906, 0.07335608838392155, 0.06810463446059398, 0.037020639915551455, 0.057361735563193045, 0.030613281231905733, 0.02310434978322259, 0.033631109832120795, 0.04671662034732955, 0.07628711539187602, 0.008489241524200355, 0.07956790684589318, 0.07504355069249868, 0.04339395649731159, 0.023880627771307315, 0.10441786090710334, 0.10232709095414196, 0.232429103659732, 0.03635319894445794, 0.02258568100764283, 0.11528642448995795, 0.020747281976842454, 0.04555145019133176, 0.025420507016990865, 0.028704467229545116, 0.04544343759438821, 0.07016337756067514, 0.015772254738424505, 0.011967456982737141, 0.04375289134415133, 0.029104585759341717, 0.03511165627943618, 0.04982998328549521, 0.10206959369991507, 0.6049193974052156, 0.2913259161370141, 0.14754121085362776, 0.03918118362448045, 0.08135535128946815, 0.14195088297128677, 0.019771648703941276, 0.9540520459413528, 2.892764363970075, 1.3897796592542102, 0.03511017028774534, 0.17456840058522566, 3.563994003193719, 18.203121696199688, 22.765786579677037, 40.50780323573521, 69.6910502570016, 62.47971643720354, 54.929901123046875, 45.155491488320486, 31.984649521963938, 48.3663443837847, 65.21511799948556, 60.37856728690011, 19.857027462550572, 1.5307488377605165, 0.04222914596487369, 0.020715630014560053, 0.047971764246800115, 0.01917061934779797, 0.035462391030575545, 0.020621719071641564, 0.03912034278203334, 0.045723675949765105, 0.02387612060244594, 0.04302854842639395, 0.003961989722613777, 0.03248684534004756, 0.08877182725284781, 0.04667693961943899, 0.03689469363806503, 0.009696211981853204, 0.04634197402213301, 0.053032953558223586, 0.06951133254915476, 0.03146005900842803, 0.01987326441199652, 0.06857892365327903, 0.044279502372124364, 0.01998409123292991, 0.046724287793040276, 0.08443655845310007, 0.016676268640107343, 0.013455014393132712, 0.03964300134352275, 0.0469351289793849, 0.046085925440170934, 0.014153195545077324, 0.030722260741250854, 0.03916666976043156, 0.051878188736736774, 0.05987400468438864, 0.026319608325138688, 0.06001125196261065, 0.04450585486899529, 0.06120993157050439, 0.03797385608777404, 0.01765018861208643, 0.06058050213115556, 0.024517841703657593, 0.032686860500169654, 0.0587721655943564, 0.042439990543893406, 0.06402815213160855, 0.07260826136916876, 0.019197514779599648, 0.02181690083151417, 0.055159909783729484, 0.023587968832414066, 0.044089471854801686, 0.055332769972405264, 0.04542694580075996, 0.036993797070213726, 0.024243725430486456, 0.03169181942939758, 0.06070191240204232, 0.03282236394339374, 0.05644842742809227, 0.02332296358820583, 0.03107283603666084, 0.09929426333733968, 0.002481580678639667, 0.022526719707197378, 0.01324254387457456, 0.020096582160996537, 0.043661329828734906, 0.026759283750184944, 0.06314664014748164, 0.025180480343156626, 0.00579485487625269, 0.06801781590495791, 0.0383805699779519, 0.030189359693654945, 0.016039726457425525, 0.021400288811751773, 0.03363316918590239, 0.0246859691105783, 0.032509908745331426, 0.05608185566961765, 0.06081553987626519, 0.01875140344990151, 0.04475971856819732, 2.045365972178323, 41.248446464538574, 73.27649443490165, 69.8677498953683, 50.13288566044399, 28.94580623081752, 29.095288038253784, 49.163525104522705, 77.30510861533028, 63.3964478628976, 51.8001059123448, 55.63363899503435, 56.51461499077933, 33.40119961329869, 5.96518873316901, 0.05539649458868163, 0.15821137758237974, 0.07110322320035525, 0.3626890182495117, 0.0972192557528615, 0.5919426594461713, 0.4528780201716082, 1.3901729924338204, 1.2955992157970155, 0.1359954761075122, 0.49207934950079235, 0.1583576425909996, 0.0564208517649344, 0.00989455879399819, 0.05003689914675696, 0.034584298862942627, 0.062231248909873624, 0.0698341659403273, 0.005161453038454056, 0.08798281316246305, 0.01871040297139968, 0.09335744154772588, 0.011417191375845244, 0.07978032223348107, 0.043367924501321146, 0.020220404623874595, 0.021927008405327797, 0.036347448360174894, 0.02108362500023629, 0.12400692940822669, 0.29809498148305075, 0.21949026866682939, 0.20597948293600762, 0.05526927945071033, 0.05327774863690138, 0.09339486953935452, 0.11489051287727696, 0.02720820591119783, 0.021922038136316196, 0.04128346831670829, 0.013721156183497181, 0.039054870938083956, 0.027771040531141416, 0.04305116060589041, 0.04204214510640927, 0.08517207005726439, 0.017578727000259926, 0.04596201816041555, 0.07846627131636653, 0.663098292691367, 0.15264292566904, 0.0937308461538383, 0.05102861539593764, 0.12087544958506312, 0.18285792720104965, 0.05883654499692576, 2.0363697920526778, 4.946796476840973, 1.7510369143315723, 0.0742857288569212, 0.01811291217537863, 5.203172845499856, 30.54175533567156, 32.67790256227766, 31.86197212764195, 69.20879663739885, 76.1509780883789, 63.30464826311384, 52.371716839926584, 34.1363468170166, 45.734161785670686, 62.77463272639683, 71.22086988176618, 32.83942386082241, 1.9913526305130549, 0.11627798128340926, 0.0306283073898937, 0.051944264476852756, 0.052950491197407246, 0.10535696694361311, 0.08656888189060347, 0.033418724978608746, 0.04394561903817313, 0.018876935821026564, 0.014487431717238255, 0.004754516079888812, 0.08993966065879379, 0.06416721109833036, 0.039307737190808566, 0.02465635784236448, 0.025993562070652843, 0.026806168823636005, 0.03378319667120065, 0.02436999401210674, 0.061585480347275734, 0.043368345193032704, 0.09637673917625632, 0.039164512019072256, 0.027031379685338055, 0.03520818806386419, 0.05187297419511846, 0.02574510290287435, 0.0020995673715203467, 0.04002328968739935, 0.03355089342221618, 0.04786988899910024, 0.019268623553216457, 0.03906380385160446, 0.03741690775911723, 0.03648862435615488, 0.0005303207061453057, 0.0181161386093923, 0.03991369271118726, 0.030905963919524635, 0.021100403474909917, 0.1516207398048469, 0.14608598394053324, 0.1038625817745924, 0.07738187736166374, 0.14303412341645785, 0.16807492902236326, 0.0770035737327167, 0.20438626914152078, 0.23815615634833062, 0.10786162290189948, 0.1752767368618931, 0.11396082490682602, 0.08816110502396311, 0.08896702142166239, 0.14718833193182945, 0.11553261056542397, 0.10783616426799979, 0.14024030975997448, 0.15502999829394476, 0.20237188866095884, 0.12725960915642126, 0.17386699893644877, 0.14538228884339333, 0.14108294168753283, 0.13410290623349802, 0.10971875289188963, 0.08742184790649585, 0.10820458164172513, 0.09184954674648386, 0.17655249126255512, 0.09046386967280082, 0.3156886345573834, 0.1654332700584616, 0.0806325486462031, 0.16753173459853443, 0.2058987779808896, 0.09488512243011168, 0.17188897436218603, 0.13212010477270397, 0.20055627822875977, 0.12080372843359198, 0.10941616698567357, 0.15504717880061694, 0.1416697794837611, 0.16406105511954852, 0.2575946647141661, 0.7880126269800323, 37.81757538659232, 84.42220401763916, 93.47106538500104, 78.47141933441162, 61.0800713130406, 42.66737631389073, 45.45887415749686, 75.30515302930559, 76.61388097490583, 73.00802993774414, 66.56946086883545, 64.7474764415196, 47.42528731482369, 9.964791144643511, 0.1399172863789967, 0.20385542405503138, 0.6508079064743859, 1.4777107409068515, 0.7459533352937017, 2.6056719635214125, 5.3143492341041565, 3.6072995194367, 3.48515322804451, 1.4281695421252931, 1.8386603210653578, 0.300752124616078, 0.230079499738557, 0.19826823100447655, 0.2506448104977608, 0.203543732208865, 0.2144260225551469, 0.18328989616462163, 0.11669742449053697, 0.2324801023517336, 0.13947929202445916, 0.24839090715561593, 0.14921165550393717, 0.20417186564632825, 0.12223488092422485, 0.08026039932987519, 0.12188675174755709, 0.21957098719264778, 0.12072267064026423, 0.2596605052905423, 0.6170018262096814, 0.6697587381516183, 0.28861193891082493, 0.1666392032057047, 0.19842250272631645, 0.2844212794942515, 0.24952283927372523, 0.13230296996022972, 0.0786387345620564, 0.14835980907082558, 0.08039651345461607, 0.15807934823845113, 0.059538984804281166, 0.1317703878240926, 0.12493792016591344, 0.20461925092552388, 0.22579444253018924, 0.15616684300558908, 0.12325417622923851, 1.5402082673140933, 0.5008158949869019, 0.21774498160396302, 0.13436510573540414, 0.09291941326643739, 0.37033719356570927, 0.17244290321000985, 2.6392172149249484, 7.073872395924159, 2.533619144133159, 0.18689214358372347, 0.5494231581687927, 5.950937977858952, 29.359599249703543, 40.17982046944754, 51.56757402420044, 85.82091113499233, 77.63191713605607, 66.76293345860073, 56.47626093455723, 45.645158835819785, 62.06418636866978, 79.90843881879533, 81.70795277186802, 34.60181358882359, 2.1754777218614305, 0.22582176035004004, 0.06558665207454137, 0.1367661426109927, 0.28174397030047005, 0.17639264198286192, 0.13170980821762765, 0.21628725768199988, 0.07617952009396893, 0.11193901446780988, 0.11170972391430821, 0.06092217843979597, 0.17606831581464835, 0.19620830725346292, 0.1339376965271575, 0.09649603241788489, 0.08531437242137534, 0.07132290569799286, 0.18023405942533696, 0.1452539371592658, 0.09737452492117882, 0.1392846746104104, 0.16036021656223706, 0.1449010989495686, 0.08866466621735267, 0.07492383675915854, 0.2055856069283826, 0.1319317841636283, 0.1177632130150284, 0.09187678314213242, 0.1362743947122778, 0.1242902177785124, 0.07896076049655676, 0.15813806865896496, 0.10664507068161454, 0.14411429688334465, 0.1704380629318101, 0.16620496793517045, 0.11447792287383761, 0.1215687630964177, 0.17328677007130214], [0.02602882044655936, 0.012698312988504767, 0.037823550403118134, 0.02997324289754033, 0.03509438077786139, 0.047055426452841075, 0.03908825146832636, 0.027343641500920057, 0.051840923593512604, 0.06639410874673299, 0.02471577885028507, 0.03758296224155596, 0.01183313927945814, 0.0376168822071382, 0.03540129234482135, 0.02904839288177235, 0.030702576440359865, 0.053055867685803344, 0.04732151056772896, 0.018069552091349448, 0.05489433117743049, 0.11056535424930708, 0.03717278103743281, 0.04201740911230445, 0.028122733712994626, 0.08412466304642813, 0.0024470873509666747, 0.010316767879495663, 0.04195665308673467, 0.03962892513456089, 0.027941400318273475, 0.030101665827844824, 0.05283204951722707, 0.07368864518191133, 0.055261157386537106, 0.028381313230576258, 0.033465343727064986, 0.04351109539025596, 0.039474534669092724, 0.06428636863295521, 0.018334345293364356, 0.01490514466006841, 0.048136183459843905, 0.025514696159267, 0.09618553479335137, 0.025796542642638087, 0.0871288836268442, 0.10410170430051428, 8.145374945231847, 35.410167012895855, 61.49438544682094, 79.24846417563302, 54.722354957035606, 33.92151199068342, 20.62918598311288, 43.53530706678118, 64.60015378679547, 58.68600695473807, 68.2550243650164, 63.81470857347761, 40.46105228151594, 14.055002842630659, 0.9182931418929781, 0.33420088833996225, 0.12849636136421136, 0.058561921518828185, 0.2410501353442669, 0.4085088052919933, 0.10593487521899597, 0.31940559510673794, 0.058507801565740786, 0.32241934910416603, 0.06079796581928219, 0.021519641425194483, 0.04490906073312674, 0.04240768549165555, 0.06816773821732827, 0.0176012560592166, 0.010782673772025322, 0.02329053300698953, 0.02779403269024832, 0.04574650186779244, 0.11803055581237588, 0.02666590884993119, 0.06936197342084986, 0.0013450739622515226, 0.03923409578523465, 0.07492760941386223, 0.025986547714897563, 0.013757191482000053, 0.10962605822299208, 0.013650256059398609, 0.0506845438586814, 0.18135390004941396, 0.04453209042549133, 0.10729823527591568, 0.028453331241118054, 0.021202850388363004, 0.04918527323752642, 0.023989273102155755, 0.06463380570390395, 0.027882491604291966, 0.034284749400935004, 0.025397136574611068, 0.05966278351843357, 0.08945849112101964, 0.021408105535166602, 0.12196422687598638, 0.16121012238519533, 1.1561565782342638, 3.071425565651485, 0.3285758601767676, 0.2719231258545603, 0.04055382604045527, 0.13295011594891548, 1.6711971185037067, 3.738208140645708, 1.1971114320414407, 0.08372579980641603, 0.3796136629368578, 3.2217448481491635, 16.67079029764448, 37.5442019871303, 40.56660236631121, 45.001634052821565, 62.14409760066441, 53.82415785108294, 44.73084190913609, 39.86438962391445, 42.505184514181956, 61.01908697400774, 61.654708181108745, 35.97517715181623, 7.991855365889413, 0.24646766749875887, 0.077215676994196, 0.05275672195213182, 0.028894501139542887, 0.021835960880188004, 0.03039222809353045, 0.06802229423608099, 0.057099359642182074, 0.025408152590638826, 0.024547430919483304, 0.03519917033346636, 0.08068498583244425, 0.020595244331551448, 0.04282691156757729, 0.02754560236020812, 0.039594659116119146, 0.02992921954553042, 0.028559284484280006, 0.012630615549694215, 0.03184506317068424, 0.028179538968418325, 0.010066751473849373, 0.01903785379337413, 0.025601918443239162, 0.029110855422914028, 0.08214718808553048, 0.02892461113099541, 0.05348985868373087, 0.009220997437036462, 0.012202953587153127, 0.021776124269568493, 0.04595174174755812, 0.0704129630965846, 0.043747683587883196, 0.038816345522978475, 0.01861506880127958, 0.017985308576109152, 0.017678542894178202, 0.025846952705511024, 0.027569909180913652, 0.03416048589029482, 0.008756565661834819, 0.07410773555082933, 0.03665824793279171, 0.08205235603132419, 0.03399232794929828, 0.051149825498993905, 0.05120870198256203, 0.050600588720824034, 0.014810438134840556, 0.021924782810466628, 0.008793768040569765, 0.06587642045425517, 0.035840491099017005, 0.071114493667015, 0.0142410624373172, 0.033650281839072704, 0.0539460411694433, 0.048886063043028116, 0.013874340552969702, 0.03482656639867595, 0.043396558679108105, 0.07010141374277216, 0.027710079248728495, 0.05634617559345705, 0.04265317267605236, 0.026683776373309747, 0.020844035981489078, 0.07601190158831221, 0.03525339545948165, 0.025109098459194814, 0.030298440983252864, 0.01971924883712615, 0.04127371437581522, 0.042597166395613124, 0.01127122322629605, 0.03922677439238344, 0.00590688779318173, 0.02760636686746563, 0.04259956501690405, 0.08885762122060571, 0.052209239186985154, 0.06334645513977323, 0.03877388280151146, 0.039811345881649425, 0.05212928740573781, 0.05230246989854744, 0.061386242109749994, 0.10522163313414369, 0.3157389275729656, 17.310960837772914, 59.63441521780831, 78.56462941850934, 75.85770157405308, 49.455380712236675, 35.035579204559326, 33.554633208683555, 58.3153691973005, 82.12966673714774, 71.28020054953438, 63.56590747833252, 63.050705501011436, 49.75521980013166, 13.423251782144819, 0.7842216789722443, 0.17993531402732643, 0.17739839372890337, 0.1260483834360327, 0.05154172357703958, 0.07169588282704353, 0.15657426257218632, 0.37071961590221947, 0.1267594609941755, 0.2627142657126699, 0.06765049775796277, 0.02001234034209379, 0.11763437278568745, 0.07549890197281327, 0.015086978474365813, 0.03219670715874859, 0.034286194680524726, 0.0066396174037696, 0.030759848188608885, 0.020012744070429887, 0.07531232519873551, 0.05350604513660073, 0.03955344489908644, 0.046835184163813076, 0.02284855056287987, 0.03584283543750644, 0.04686123651585408, 0.03770836229835238, 0.16365035144346102, 0.009214214631356299, 0.06404689326882362, 0.08475793299398252, 0.03179904831839459, 0.09814875373350722, 0.0575364651158452, 0.031376972395394526, 0.02334880898706615, 0.04389909867729459, 0.036768906816307984, 0.02661396699425365, 0.039584348776510785, 0.034046132383602004, 0.04023590863549283, 0.043336640644286356, 0.09357459989509412, 0.07481103709765843, 0.11255432359342064, 0.9956610075065068, 2.631705777985709, 0.8055654051048415, 0.33392176617469105, 0.18533611350825854, 0.45636919140815735, 2.694689895425524, 4.787151191915784, 2.6048970222473145, 0.09524666624409811, 0.04674126473920686, 6.550860643386841, 27.651497534343175, 50.75285257611956, 46.175157002040315, 43.95783049719674, 72.86574472699846, 72.1075086593628, 51.420668261391775, 44.4214768409729, 43.74373912811279, 60.02892003740583, 68.13643945966447, 51.77244165965489, 13.640960557120186, 0.27136851847171783, 0.05717753366168056, 0.028842101272727762, 0.03732423344627023, 0.055810109179999144, 0.026238803286105394, 0.009844314124036049, 0.04797847495813455, 0.04690548039174505, 0.033378124835767915, 0.009940915458303477, 0.07260621219341244, 0.01331572387633579, 0.013501173434113818, 0.063568763567933, 0.05825922026165894, 0.037828754766711166, 0.02046230575069785, 0.028313668378229653, 0.08700522740504571, 0.028071380486445766, 0.034742675721645355, 0.06531606587980475, 0.026846902977143015, 0.04631357393892748, 0.019938178160893064, 0.024193393399140666, 0.0856011009642056, 0.08420105930417776, 0.026869730591507893, 0.0058631842007993585, 0.028805165218987634, 0.024285358642893176, 0.026311119852055396, 0.04057791403361729, 0.003488554847925635, 0.016898346366360784, 0.037798838157738955, 0.040511926503053734, 0.039765385312161276, 0.06492051389068365, 0.008246911223977804, 0.13469619011240347, 0.09316656964698009, 0.16414427065423556, 0.11223702704800026, 0.1193956189921924, 0.09195902837174279, 0.1051971787320716, 0.07531784168843712, 0.1120823889172503, 0.17679951872144425, 0.16911086200603417, 0.09469887813819305, 0.1713776032307318, 0.1237014936549323, 0.13903118749814375, 0.11955350052033152, 0.14272764271923474, 0.16656455078295299, 0.1347146462649107, 0.1315422100680215, 0.12620629210557255, 0.3105986719684941, 0.13488185086420604, 0.1546359322965145, 0.06403724450085845, 0.14698886977774756, 0.16790634021162987, 0.1441732480057648, 0.09535208344459534, 0.12948999447481974, 0.1175732503512076, 0.09227627741971187, 0.1561517659574747, 0.11250985240829842, 0.26559244841337204, 0.10051108697163207, 0.08293485189122812, 0.1656833373542343, 0.19731398006635054, 0.10792484879493713, 0.12711362913250923, 0.15685305904064858, 0.14396307856908866, 0.09078809406076159, 0.15930225833186082, 0.11587248875626496, 0.14594334230891295, 0.17156243616981165, 12.460078597068787, 61.00287682669503, 93.96342168535504, 101.90632438659668, 77.2580623626709, 56.02598292487008, 32.2117965562003, 57.994174821036204, 89.8747055871146, 81.65068571908134, 84.37899317060197, 79.7874984741211, 62.79569271632603, 23.652104003088816, 1.862679375069482, 0.7260601541825703, 0.560122515474047, 0.4500219848539148, 1.2776440935475486, 1.3071562413658415, 3.979824798447745, 0.7055680709225791, 0.2206246977938073, 0.746769368648529, 0.21121444845838205, 0.13970662839710712, 0.13222807326487132, 0.12773682283503668, 0.17403906184647763, 0.10622009062873465, 0.20374851407749311, 0.15166370464222773, 0.12508795782923698, 0.10448348202875682, 0.21650058909186295, 0.20309471844562463, 0.27482147461601664, 0.11896609275468759, 0.14387870952486992, 0.18970102071762085, 0.09310873810734067, 0.14786911968673977, 0.5037600312914167, 0.16656993835100106, 0.17132758162915707, 0.3509832578045981, 0.16461184913558619, 0.2356824076601437, 0.15209157525428704, 0.15350212742175373, 0.14029274694621563, 0.08838479766356093, 0.10081979326371636, 0.157325360125729, 0.15406624786555767, 0.07875968342913048, 0.12283595438514437, 0.19573471695184708, 0.2631826720067433, 0.36262610448258265, 0.1878473987536771, 1.1439025614942824, 5.422947841031211, 2.34955940927778, 0.596363396516868, 0.23405813053250313, 0.37283493525215555, 3.179256613765444, 7.698414700371878, 3.204692666019712, 0.24493216989295824, 0.33240437188318794, 6.769722819328308, 29.17648642403739, 61.79574271610805, 60.310092789786204, 57.72038452965872, 79.14806270599365, 70.95233590262276, 59.747740336826865, 54.751304626464844, 57.21575771059309, 75.8601473399571, 81.03108705793107, 54.7441896711077, 12.291592597961426, 0.4109451531299523, 0.1499640287033149, 0.08884801995009184, 0.16743744537234306, 0.13550306324447903, 0.12890329238559517, 0.11831355919795376, 0.16403506722833427, 0.1783052829227277, 0.09754323586821556, 0.15939502763961041, 0.2283945344388485, 0.10599394169236932, 0.1518946508211749, 0.1396008719291006, 0.11298273024814469, 0.09845225566199847, 0.1160937590258462, 0.10847218228237969, 0.14950734749436378, 0.17411554631377968, 0.22888207542044775, 0.09882157548729863, 0.05322523681180818, 0.16445145702787808, 0.10867416180138077, 0.08137352924261775, 0.14474143965968064, 0.10251652436064822, 0.12456824071705341, 0.09096688803817544, 0.09866340897445168, 0.13571681534605368, 0.15297528569187435, 0.12069922047001974, 0.05727047938853502, 0.11416639387607574, 0.10797700099647045, 0.10181124827691487, 0.11840360079492841, 0.15200580842792988, 0.06911430135369301], [0.03856400852756841, 0.052959037345967123, 0.04890882789290377, 0.06057299074849912, 0.05178061879373022, 0.07056546384202582, 0.020814031162964444, 0.023733227912868773, 0.034140363934316804, 0.018899610765012245, 0.020388750858338814, 0.022000185014413934, 0.03635635073961956, 0.08017760448689971, 0.021825022895687392, 0.022570386828322495, 0.07040193011718136, 0.05238698822047029, 0.03304777666926384, 0.014853340207732149, 0.028621024385626827, 0.023555767256766558, 0.029686941831771816, 0.03537377096446497, 0.01677365877133395, 0.03416336287877389, 0.021582695988139937, 0.0660753601363727, 0.03633571648970246, 0.05673430101679904, 0.05617307113217456, 0.007157502047318433, 0.060758196881839206, 0.008170922087239367, 0.021103789364652972, 0.04509751365653106, 0.06141085257487638, 0.0220900671556592, 0.053923337387719324, 0.026111952860706618, 0.02862412529066205, 0.048998788065676174, 0.04915563143523676, 0.1148620822599956, 0.025210049202931777, 0.14893036202660628, 0.029629995780331746, 0.05185352059613381, 0.23771095595189504, 2.0581673766885484, 15.487022229603358, 42.41316952024187, 73.85967063903809, 68.67594623565674, 55.88398606436593, 37.073385102408274, 33.66365391867501, 35.84051411492484, 56.788332326071604, 70.46349539075578, 68.40163135528564, 72.05551528930664, 41.822075843811035, 10.238438997949872, 0.4194156586059502, 0.13471888032342705, 0.31854249856301714, 0.30962177153144566, 0.348305161510195, 0.7550645406757082, 0.1164486464112997, 0.1761502149913992, 0.049715514427849224, 0.09595478538955961, 0.032438197771885564, 0.025593753970627273, 0.0517426785081625, 0.03843391979379313, 0.04911241214722395, 0.05803032325846808, 0.09516936753477369, 0.06918716244399548, 0.07874082015561205, 0.07483179348387889, 0.028087663630555783, 0.022638029984331558, 0.022360727989247868, 0.033056970818766525, 0.010355313757567533, 0.02517277897069497, 0.18809004287634576, 0.08223082431192909, 0.030225576500275304, 0.2828884688871247, 0.023550040421209166, 0.06081435922533274, 0.09508731229496853, 0.15293766771044048, 0.013893388727280711, 0.08972402222986732, 0.025594600443063036, 0.04574287170544267, 0.05095352192542382, 0.09837625973990985, 0.06544734204986266, 0.038205653828169615, 0.07985101201172386, 0.08277730963059834, 0.11248730468962874, 1.0770098652158464, 2.579990335873195, 1.175026148557663, 0.6808533828173364, 4.213150518281119, 5.113816840308053, 1.1736181612525667, 0.03225578720282231, 0.218491614397083, 3.0054304897785187, 14.876926967075892, 35.46191719600132, 48.52642740522112, 54.46275288718087, 56.02638244628906, 60.58810411180769, 41.72558968407767, 34.94012485231672, 45.067002705165315, 62.82484040941511, 67.47168445587158, 49.83082662309919, 14.846565076283046, 0.3229454037334238, 0.13027831645948545, 0.023114955285564065, 0.028526653735233203, 0.038400773358132155, 0.05868858365075929, 0.0565134276902037, 0.04747530731505581, 0.057069415891809125, 0.07054257007049662, 0.02158356112028871, 0.009794577507169118, 0.01673807469861848, 0.024717412423342466, 0.029346710802721124, 0.056403837499341795, 0.08217934386006423, 0.03652846114709973, 0.0436701711400279, 0.029206393153539727, 0.05842743587813207, 0.008538701638047184, 0.04284428545672979, 0.07490167580544949, 0.005162326228206179, 0.01374914066400379, 0.01757280169320958, 0.02301542946536626, 0.023441374734310166, 0.006791043095290661, 0.06501793794866119, 0.04321570534791265, 0.021568226228867258, 0.016877859697810242, 0.08749608642288617, 0.055236892974270244, 0.02823780646680721, 0.04452426352405122, 0.10018945458744254, 0.04730428256360548, 0.059964059852063656, 0.022795969187947254, 0.029146400479865924, 0.0368341140316001, 0.09722546434828214, 0.04571482785312193, 0.04006782533334834, 0.06464201597762959, 0.036050032890800915, 0.13458579246486935, 0.04921234678477049, 0.008921100225831782, 0.04382355058831828, 0.01520671446009406, 0.008343915438412555, 0.032210098047341616, 0.08582526179296629, 0.05059844455016511, 0.050602763425558805, 0.04063126724213362, 0.00625224642655147, 0.04477716709620186, 0.022728404063465338, 0.020068589198802198, 0.03284503040569169, 0.024697166634723544, 0.061563577236873765, 0.00990422791801393, 0.027309061660032188, 0.04195017646998167, 0.02510787031081106, 0.04048123297148517, 0.061210135131009986, 0.02765292624410774, 0.040615043469837735, 0.0933260050203119, 0.018656096421182156, 0.04503792131851826, 0.017904218552368026, 0.023262657092085907, 0.07778710526015077, 0.032194233898605616, 0.012257224514282175, 0.016649110275985937, 0.05371762592611568, 0.030831216501870325, 0.01924331589335842, 0.03767468321270176, 0.0585714006530387, 0.09318115814988102, 0.06103478132614067, 0.09823529408978564, 0.2861835706446852, 5.802639535495213, 36.35460090637207, 71.93667330060686, 79.62238148280552, 66.94393403189522, 40.7128723689488, 44.71196017946516, 48.18917226791382, 53.767054080963135, 77.40824072701591, 78.38319110870361, 61.31942285810198, 63.89543969290597, 31.618896348135813, 3.3624799592154364, 0.720755258841174, 0.13846698563013757, 0.17385607452264853, 0.07299916539341211, 0.0555051484012178, 0.33913017383643557, 0.1117760439270309, 0.11953976697155408, 0.18587856154356683, 0.06294633660997663, 0.05022054125687905, 0.04110828414559364, 0.06133694654064519, 0.03086619158940656, 0.024351919535547495, 0.008338655095680483, 0.16098129323550633, 0.04957407380321196, 0.1263393121106284, 0.029980499829564775, 0.008090235791834337, 0.06225082464516163, 0.07084637733974627, 0.06964720918663911, 0.029933976076011146, 0.013218122551084628, 0.1171406978475196, 0.07543533681226627, 0.1108369921733226, 0.23771375151617186, 0.08200998151940958, 0.04672768386080861, 0.09161564894020557, 0.03156459072072591, 0.04612417445917215, 0.04216652736067772, 0.046614755277654955, 0.039854931578572304, 0.01887306308240763, 0.06253160243587834, 0.03912349796987005, 0.1611365963305746, 0.03810516279190779, 0.09292249381542206, 0.11695832120520727, 4.187948533466884, 5.0011730790138245, 0.936804011464119, 1.7564000551189696, 4.771261530263083, 4.846245186669486, 1.1323317480938775, 0.022296604733648043, 0.18357466374124798, 7.0592933382306775, 27.659682512283325, 46.58223111288888, 58.33317048209054, 67.86116572788784, 69.23108645847866, 67.22801113128662, 55.4890261377607, 37.185737473624094, 48.07245295388358, 61.678151403154644, 72.36143752506801, 64.29773344312395, 27.22520296914237, 1.5438278445175715, 0.17815209685691766, 0.05128655709060175, 0.05564402077080948, 0.01923394702108843, 0.004953395542023438, 0.025297200240726982, 0.03901168218414698, 0.08356161468795367, 0.05789671292794602, 0.0256124170763152, 0.029140870419463942, 0.017423659696110656, 0.039517821810607395, 0.0290409866720438, 0.04582642311496394, 0.03192698948883584, 0.009581304620951414, 0.025615714756505828, 0.0680788162031344, 0.052735405774520974, 0.05448467244527169, 0.03221775870770216, 0.0333943486080638, 0.07781924067863397, 0.05015062161588243, 0.03330349616174187, 0.01739381263697786, 0.06978628172406129, 0.03139727755582758, 0.028328650431441407, 0.007528942294551858, 0.007814545317419937, 0.03219592005812696, 0.042023183445313146, 0.05103210645860859, 0.02483334013127855, 0.08795879302280289, 0.09673430677503347, 0.02048358291254512, 0.03973190300166607, 0.009845563476639134, 0.013578969170339406, 0.027461021273796047, 0.15902954153716564, 0.17431684051241192, 0.14669348991342954, 0.2438133199300085, 0.11234477840896163, 0.22994835249015264, 0.10450981597283057, 0.10236992008451905, 0.16004880970077856, 0.11600738151797227, 0.1571084460509675, 0.19263860237385544, 0.21192422322928905, 0.20272512042096683, 0.12135184902165617, 0.10241097823849746, 0.11677952722779342, 0.19478668139449187, 0.0823619987017342, 0.08243929741105863, 0.08601751790515014, 0.16673004547400133, 0.14262838661670685, 0.10652491570051227, 0.09676800282405955, 0.16778067552617618, 0.08346569697771754, 0.1710948712591614, 0.12289018290383474, 0.14291791750916413, 0.11637788877955504, 0.14754407427140645, 0.1497398814452546, 0.0987419086907591, 0.10949415101536683, 0.1706448939761945, 0.21896823096488202, 0.1310472052012171, 0.2023029766444649, 0.17583803460001945, 0.20096292426543577, 0.17285386472940445, 0.18615247255989484, 0.18182048786963734, 0.1291711644402572, 0.16223943286708423, 0.15968634986451694, 0.1564464537160737, 0.28614074151430813, 3.1321610723223006, 32.10752146584647, 79.12067290714809, 100.92988014221191, 89.63386017935616, 75.13380350385393, 58.981993266514365, 51.119397844587056, 52.630950655256, 76.53769397735596, 92.46504960741315, 85.19108472551618, 91.52945382254464, 59.475530760628835, 16.569101674216135, 1.1469392499753406, 0.22517819702625275, 0.6032808710421834, 1.1618875392845698, 1.1298751256295612, 2.2358949141842976, 0.9515774015869413, 0.5370818004012108, 0.3021325633994171, 0.1945807731577328, 0.1127173552023513, 0.07930715262357678, 0.2479054560618741, 0.1345421490924699, 0.25294094585946625, 0.12263214960694313, 0.2563961275986263, 0.12533118549202169, 0.23006299776690348, 0.22700688961361135, 0.18846576128687176, 0.1552300439881427, 0.06964919729424374, 0.15861670726111957, 0.0925907309034041, 0.16173734409468515, 0.671791629067489, 0.319963133760861, 0.4063200413116387, 1.1572735011577606, 0.2983329844261919, 0.12516372304941925, 0.14216209735189164, 0.2220241626990693, 0.16593131476214953, 0.23695789064679826, 0.13808913661965302, 0.2753058129123279, 0.17154972042356217, 0.17547150355364594, 0.1464786792972258, 0.213888500684074, 0.19366580939718656, 0.1737029698810407, 0.1808456773204463, 6.545754151684897, 7.483737077031817, 3.632496075970786, 4.581611318247659, 6.32673260143825, 8.2259966305324, 2.06212546144213, 0.14679282744015965, 0.4727576034409659, 8.341268982206072, 31.910404545920237, 53.496001379830496, 71.62914603097099, 69.99235194069999, 69.99897357395717, 73.37158748081752, 56.689004353114534, 49.378220966884065, 59.19570595877511, 77.57480989183698, 84.83925574166435, 70.51865713936942, 24.414797340120586, 1.099222604717527, 0.3062423143003668, 0.12585726726268018, 0.18559384824974196, 0.07871000109506504, 0.13440321226205143, 0.2173922248184681, 0.12141222506761551, 0.21805623918771744, 0.1846621518156358, 0.0889866514397519, 0.10083429355706487, 0.08071172689752919, 0.09561872056552342, 0.14720309685383523, 0.1578381968928235, 0.13143188027398928, 0.20474697835743427, 0.12877483213586466, 0.1900114912007536, 0.17890106381050178, 0.16600034891494683, 0.13256825001112052, 0.12635651975870132, 0.09237325364457709, 0.12788413278758526, 0.1085652569308877, 0.10270201547869615, 0.22983167160834583, 0.1081250234107886, 0.2653962975101811, 0.10917417425662279, 0.07657286005892924, 0.17800083783056053, 0.20707549341022968, 0.15561036286609514, 0.11210832252566304, 0.1892604207886117, 0.24299215685044015, 0.09591841591256005, 0.16261236928403378, 0.13573630287178926, 0.09062065875955991, 0.13278593761580332], [0.04935478146321007, 0.0719209596780794, 0.03388275811448693, 0.017579880509791628, 0.052191108731286864, 0.02659614018297621, 0.037246588684086285, 0.07877849241984741, 0.05272985535806843, 0.06679574040962116, 0.0448887012898922, 0.06298341854874577, 0.050028420851698945, 0.013969535623410982, 0.04750797877620373, 0.023593571835330555, 0.023862134299374053, 0.03213240918038147, 0.03420814958267978, 0.061360166008983336, 0.019868892950138876, 0.011605408508330584, 0.022899186238646507, 0.08672166083540235, 0.024807633832097054, 0.020742888462596705, 0.03877347568050027, 0.02319997233072562, 0.044797499398035664, 0.054156587193054814, 0.02958850675661649, 0.06928149238228798, 0.05424300880570497, 0.04652636930612581, 0.025539908824222426, 0.03202366715829287, 0.1688458669398512, 0.005904796633071133, 0.04633277647995523, 0.03751533604892237, 0.0661471016438944, 0.0700719246108617, 0.04475088404225452, 0.005584476365973907, 0.1228056645819119, 0.03644683677703142, 0.06855399427669388, 0.030755400391561643, 0.1446286399981805, 0.1003324965547238, 0.3817238254206521, 7.847437058176313, 32.99074172973633, 52.93385737282889, 71.72969341278076, 63.91360923222133, 54.073730196271626, 45.17674255371094, 32.91757719857352, 39.545825140816824, 63.1239047731672, 62.174905913216726, 57.31165327344622, 63.3028347832816, 32.09843669618879, 10.495471102850777, 0.9483059942722321, 0.05739909570131983, 0.140337842383555, 0.19539253174194268, 0.15116616205445357, 0.20410026663116046, 0.06538089311548642, 0.03124735185078212, 0.18054100152637276, 0.12665251030453614, 0.021916175593755076, 0.02867480167852981, 0.07114348068301167, 0.06614623311907053, 0.06842467228748969, 0.07528273428657226, 0.07029487086193902, 0.0667796116322279, 0.042651099751570394, 0.10604823806456157, 0.011597855565404254, 0.04600689307387386, 0.29978385514446665, 0.039924637481038056, 0.32957767641970087, 0.10763495827891997, 0.6246010384389332, 0.08352869895419904, 0.025630776537582278, 0.025816751111830984, 0.02132503079649593, 0.09040161408483982, 0.08844627972160067, 0.021746455325878093, 0.06416857495371785, 0.06448375446988003, 0.04359861283696123, 0.05457772673772914, 0.0347158939444593, 0.1335940049695117, 0.07196888460644654, 0.041544134329472265, 1.3887627252510615, 0.6098572867257255, 0.3157298894865172, 0.5752178026097161, 0.6335396245121956, 0.15020121740443365, 0.2209507610116686, 0.10999243999166147, 3.279348237173898, 22.592116355895996, 33.62439659663609, 53.06279509408133, 59.63409560067313, 55.096567562648225, 36.32526213782174, 52.060513973236084, 46.31619848523821, 44.61845132282802, 55.43078981127058, 64.04941872188023, 48.887841429029194, 17.83631065913609, 2.3346713738782063, 0.03049014408939651, 0.04128243015812976, 0.06779307832143136, 0.09375482558139733, 0.024239264062738845, 0.040256325754203966, 0.014494737843051553, 0.036397995826389105, 0.049996675590851476, 0.005608647055591324, 0.029945979360491037, 0.005901751707174948, 0.03358074217768652, 0.013910799935859228, 0.07234767678060702, 0.025413126252325516, 0.06429352717740194, 0.02384989522397518, 0.039111118098454814, 0.0498673909210733, 0.07921888878835098, 0.0326362824998796, 0.0743735787857856, 0.07477873204542057, 0.032032209914177656, 0.06784169535551753, 0.0027326087375903235, 0.008421949510063444, 0.059654844658715386, 0.04935269157535263, 0.019959965920341865, 0.06384170427918434, 0.04038962735129254, 0.05615031985299928, 0.031160438300243447, 0.04347278869577816, 0.004028763929714582, 0.08433895797601768, 0.05925359297543764, 0.0373110427255077, 0.04729472539786782, 0.02741367310019476, 0.041910431281264336, 0.036597664933651686, 0.03631432567323957, 0.020983712415077856, 0.02369783043728343, 0.0817441518551537, 0.0401790474009301, 0.003678849357779005, 0.017140881923426474, 0.024196129591603364, 0.025006994205926145, 0.038832436980945725, 0.05720428151211568, 0.05772630564336266, 0.05272883755554046, 0.04988450696691871, 0.006671137899892139, 0.046019069384783506, 0.017625345748716166, 0.05267023927132998, 0.010390181975838329, 0.0017401517190072419, 0.0521616229920515, 0.008069528599402733, 0.02984612275447164, 0.009499463119677134, 0.10275094463889088, 0.021394465284954225, 0.014739817906437176, 0.030047922461692776, 0.024956441650699292, 0.08529322927019425, 0.056584663689136505, 0.0381672046413379, 0.06516923090176922, 0.0444968133898718, 0.015198056353256106, 0.02943942922034434, 0.01753888851297753, 0.054887586539345126, 0.05492513666727713, 0.03988877690530249, 0.03828159546745675, 0.0011420537401655956, 0.04848014982417226, 0.020948399756369845, 0.022686460421287587, 0.06522589536117655, 0.05801712575235537, 0.03652666302930031, 0.059170519933104515, 0.0854605356497424, 0.13637871268604482, 1.4246592904840196, 18.677344935280935, 56.89567157200405, 71.63437107631138, 78.58431366511753, 62.9246095929827, 57.17578819819859, 47.96965782982962, 45.747161865234375, 67.11576993124825, 86.78350761958531, 77.64862060546875, 70.09754071916852, 58.02473299843924, 23.39943970952715, 8.449881485530309, 0.9939279747860772, 0.02894435989271317, 0.02503844939305314, 0.2231848104191678, 0.19768462303493703, 0.1602133001599993, 0.21608170228345053, 0.12289068501974855, 0.11862081342509814, 0.09685465853129115, 0.047579034963356595, 0.006563649895334882, 0.02955303294584155, 0.0270187046511897, 0.07386173267981835, 0.12305531118597303, 0.09845091894801174, 0.1285711902060679, 0.03390733465286238, 0.02948266886440771, 0.043743788796876154, 0.06516576358782393, 0.3097970778388636, 0.046847530108477385, 0.10389609461916344, 0.08047620060720614, 0.52040476671287, 0.47654464308704647, 0.07471895989562784, 0.02661327997754727, 0.0194049039190369, 0.09423944207706622, 0.11188354423003537, 0.03672305481242282, 0.08588189911097288, 0.008244456623547843, 0.0367209547465401, 0.04455597146547266, 0.04568904012973819, 0.06357813413654055, 0.06905262252049786, 0.1026886347681284, 1.6772114357778003, 0.030293399468064308, 0.3529101072677544, 0.15356619469821453, 0.19775265295590672, 0.3089198406253542, 0.293019919523171, 0.05829310630049024, 4.148991286754608, 32.220231669289724, 51.30830199377877, 62.080285344805034, 67.48306560516357, 66.77469675881522, 57.327582018715994, 55.89862591879708, 52.50718934195382, 40.53154870441982, 57.30386781692505, 68.06829152788434, 64.22930758340019, 31.924464225769043, 6.216473809310368, 0.02406198321841657, 0.06219913384744099, 0.06461467101637806, 0.04682676354423165, 0.032991230953484774, 0.04879337515948074, 0.009960306292798902, 0.02597077007937644, 0.032340865316135545, 0.036819647665002515, 0.028300056965755563, 0.02123875167619969, 0.04195560135745576, 0.023418653989210725, 0.08124149311333895, 0.01799821600850139, 0.07812398432620934, 0.04075623642919319, 0.044503412142928155, 0.06227550296378987, 0.058268427981862, 0.040438196887927394, 0.06121244215007339, 0.03397287095763853, 0.021080729352044206, 0.08718324106718812, 0.026564403403816477, 0.03647559987647193, 0.06436815245875291, 0.02034786912346525, 0.06820737144776753, 0.056959784988846095, 0.0646906126556652, 0.024127400779564465, 0.02720085228793323, 0.03566474035116179, 0.06625004219157354, 0.09863346522407872, 0.05616484728774854, 0.016951911617070436, 0.022286864363455346, 0.02742561531652297, 0.04269797973600881, 0.0380586186823036, 0.02226504437359316, 0.07983401470950671, 0.14161051623523235, 0.13646146681691917, 0.2017530511532511, 0.14040166538740906, 0.06589672900736332, 0.15475141895668848, 0.19872773491910525, 0.10487921043698277, 0.0686739728386913, 0.15930149837263993, 0.16578251203255995, 0.13942974539739744, 0.11555862559803895, 0.14291824320597307, 0.08100532221474818, 0.08950751527611699, 0.1394335723349026, 0.07494247611612082, 0.12562003784946033, 0.15415650659373828, 0.09001161929752145, 0.08541112472968442, 0.24884639414293425, 0.11026376578956842, 0.1162663104810885, 0.1779176222958735, 0.08881428997431483, 0.21496848416115555, 0.11162146686443261, 0.09238560976726667, 0.10454780714852469, 0.1669332938534873, 0.18037174775132112, 0.09626560871090208, 0.19430786637323244, 0.335916170584304, 0.11177337049905743, 0.13424501860780375, 0.16875286693019526, 0.12940075354916708, 0.2650708992566381, 0.08883429318666458, 0.09167837271732943, 0.17724849177258356, 0.12508622077958925, 0.16719326776053223, 0.16766616595642908, 0.2741594687104225, 0.34196750872901505, 0.627932102552482, 13.658119133540563, 53.28629779815674, 82.3757232938494, 95.16143008640834, 86.01425865718296, 75.05634498596191, 65.77398940495083, 47.82046263558524, 57.80814027786255, 86.89194120679582, 82.8142866407122, 76.84481825147355, 85.85431112561906, 47.99494579860142, 17.473508732659475, 1.5052135565451212, 0.08527783331062112, 0.3965641190963132, 0.49822166562080383, 0.8548097312450409, 1.024615996650287, 0.4297925760703427, 0.38262535418782917, 0.4916200084345681, 0.3377360829285213, 0.18460535843457493, 0.08612104877829552, 0.1916510217956134, 0.12403921410441399, 0.2365455042038645, 0.30643219553998535, 0.23903700336813927, 0.4183684619409697, 0.21580385576401437, 0.30402317909257753, 0.22596905673188822, 0.12493817800922052, 0.4593131648642676, 0.3567265953336443, 0.7769265589969498, 0.22408042236098222, 1.325020168508802, 0.4993279491152082, 0.42911246685045107, 0.13764859097344534, 0.1138199610369546, 0.2018960863351822, 0.29870802430169924, 0.091753493329244, 0.25548702638064114, 0.19335309974849224, 0.22897956733192715, 0.14901511105043547, 0.11844364793172904, 0.29031506180763245, 0.2114541477390698, 0.4040327269051756, 3.0179491894585744, 0.9449917035443443, 1.1318065077066422, 1.5669722940240587, 1.3177210858889987, 0.39938245500837055, 0.4889611282518932, 0.4034447898822171, 5.650543034076691, 36.73105083193098, 55.469202927180696, 77.78617409297398, 78.11714458465576, 69.18448489052909, 52.43991688319615, 65.52963515690395, 61.653645106724326, 58.13253082547869, 73.19593702043805, 85.43582112448556, 70.66085202353341, 29.18456370489938, 3.8535534484045844, 0.086597427858838, 0.1965769146169935, 0.15489813179842063, 0.14765561185777187, 0.14001053066125937, 0.09667649559144463, 0.09444421037499394, 0.11208076043320553, 0.12190053957913603, 0.09453649113753013, 0.15675978761698517, 0.13783550022968225, 0.167515599035791, 0.11210594765309777, 0.2553719739828791, 0.1584626119583845, 0.25482263203178135, 0.17161249848348753, 0.1221815887838602, 0.27751555719545906, 0.11040224800152437, 0.15691981331578322, 0.1488488292587655, 0.10567719476031405, 0.066202029053654, 0.15331926223422798, 0.06124780060989516, 0.18015781923064164, 0.15109815927488462, 0.14445367295827183, 0.21488544504557336, 0.22008271116231168, 0.13461866070117268, 0.11371482882116522, 0.10824133788368531, 0.14949984289705753, 0.131111313189779, 0.19003924328301633, 0.12558041140437126, 0.0968514626313533, 0.13636826324675763, 0.20303369100604737, 0.10519122797995806, 0.11366555360811097, 0.1178791339376143], [0.05200595688074827, 0.030088125661547695, 0.06812786071428231, 0.024187354437474693, 0.05407974310219288, 0.008528832346200943, 0.055192109663039446, 0.04650691231446607, 0.03336721399266805, 0.02992362841697676, 0.06601307062166077, 0.04975024524277874, 0.029379327981067554, 0.06676676017897469, 0.008153885769258653, 0.019379552154402648, 0.035571177157440355, 0.04550653795844742, 0.10076982594494309, 0.022031618149152825, 0.07205423752644233, 0.036321915087423155, 0.031981394426631074, 0.03397413303277322, 0.009322190757042595, 0.05515434918925166, 0.05012776516377926, 0.037048307180936844, 0.024644015290375267, 0.012381777250474053, 0.011449555799897228, 0.04039541186232652, 0.017920715435008918, 0.06338334030338696, 0.0208223618766559, 0.016556737911222235, 0.040181717436228476, 0.03996239456215075, 0.013903744019834059, 0.052293950891388316, 0.09896641557237931, 0.006403352782529379, 0.0315686110407114, 0.06947098685694592, 0.03348637491996799, 0.08729478543890373, 0.06557114754936524, 0.06151412560471466, 0.07108871612165656, 0.10573076510003634, 0.09921018606317894, 0.02121460940023618, 1.3100019629512514, 11.591048291751317, 37.34382288796561, 65.8055203301566, 71.12087140764508, 66.2655258178711, 53.59328658240182, 49.996725286756245, 39.55569158281599, 55.99671711240496, 60.419804845537456, 54.18425866535732, 74.08046354566301, 55.962396485464915, 28.989336694989884, 13.80402956690107, 4.294820947306497, 0.886387285377298, 0.055145314495478354, 0.0775286512715476, 0.04004248883575201, 0.011322109960019588, 0.09509843348392419, 0.39817059146506445, 0.17613744496234826, 0.11627089737781457, 0.10496100783348083, 0.07123010246349232, 0.1911067824278559, 0.7118454426527023, 0.16293634261403764, 0.28005691511290415, 0.0019643442480758366, 0.08544408117554017, 0.07364247087389231, 0.33348891511559486, 0.19649375336510794, 0.09171304585678236, 0.04928763363776462, 0.1415957784546273, 0.06732098758220673, 0.09583568892308644, 0.41740157668079647, 0.1222605566893305, 0.008072603211205984, 0.020767580351925323, 0.11758815098021712, 0.19369318149983883, 0.15588075907102653, 0.22373956707971437, 0.25358786114624565, 0.2627533221883433, 0.09837993061436073, 0.11289553171289818, 0.4450262300670147, 0.33617773226329256, 0.41815977171063423, 0.04486755135336092, 0.04869195453024336, 0.029323528653809, 0.13061467983892985, 0.3478076867759228, 5.270329790455954, 23.494579655783518, 51.31361736570086, 47.4946859223502, 67.05468831743512, 59.27842426300049, 49.94596869604928, 31.63177136012486, 40.87509890965053, 43.743492467062815, 53.93982798712594, 68.31331280299595, 57.54681852885655, 24.262326070240565, 4.374229303428105, 0.06879167830837624, 0.08916726389101573, 0.07220275527132408, 0.015103376969428999, 0.08726537773119551, 0.03525515625785504, 0.044453706060137065, 0.0684170862659812, 0.03689929749816656, 0.11948107369244099, 0.057772798862840445, 0.015094623867688435, 0.03958622831851244, 0.04915884429855006, 0.013781143768158342, 0.04186187870800495, 0.05661995429545641, 0.037846617201077085, 0.03314025081428034, 0.020583027308540683, 0.06620371860585042, 0.07697075977921486, 0.04372506123036146, 0.0666592191638691, 0.033782189046697955, 0.008048199699260294, 0.008016567244859678, 0.07188055970306907, 0.02428417290294809, 0.018332915280812552, 0.05015306434194956, 0.016214116742568355, 0.01784314870435212, 0.008247700020936983, 0.020159326294170957, 0.00786203852788146, 0.09140946250408888, 0.04960825839745147, 0.019645600646202053, 0.02500026992389134, 0.04065998284412282, 0.03224523937595742, 0.04533140807013426, 0.023310336051508784, 0.010659735949177827, 0.023875786423949257, 0.05636111693456769, 0.021964622994086573, 0.08624672703444958, 0.025409109325015118, 0.015875587140076926, 0.010563384824698525, 0.00833963303427611, 0.038864443477775366, 0.021537396990294968, 0.03221787066598024, 0.003418422316566908, 0.05011452355289033, 0.020303855949480618, 0.025283371697046926, 0.06514373155576841, 0.06937356279896838, 0.08000710899276392, 0.019728636369109154, 0.05620177994881358, 0.013554860821126826, 0.01789783693051764, 0.0551459964231721, 0.01748848014644214, 0.02324881497770548, 0.053174512926489115, 0.056605895049870014, 0.040060327521392276, 0.01565248821862042, 0.03247204649129084, 0.09420130840901818, 0.09536151508135454, 0.032901121503008265, 0.004081798226772142, 0.013768530650330442, 0.04163917333685926, 0.023741650228787745, 0.022915818828291128, 0.04884962910520179, 0.03394710359030536, 0.01511237773645137, 0.03460174399827208, 0.06972457574946539, 0.04318679975611823, 0.009224313776940107, 0.07144703689430441, 0.0262610388786665, 0.05735771185053246, 0.04799293793205704, 0.06098525505512953, 0.13152869365045003, 0.05925725706453834, 0.021184477356395552, 0.28706952024783405, 5.517610532896859, 26.977270398821148, 62.87336662837437, 80.25856549399239, 75.46642071860177, 69.36918190547398, 50.19085448128836, 47.12749447141375, 56.97559322629656, 70.70549419948033, 70.40003749302456, 75.47402204786027, 73.17219502585274, 46.81510693686349, 21.53135745865958, 4.805559141295297, 0.671859374003751, 0.4574054500886372, 0.12308000986065183, 0.11647995401706014, 0.13280292813267025, 0.038456243595906665, 0.062316723966172764, 0.1763928048312664, 0.18621299788355827, 0.09452418251229183, 0.08906164313001291, 0.17267749990735734, 0.4836712692465101, 0.6655741855502129, 0.48781158136469976, 0.10952828132680484, 0.025744532933458686, 0.10568401403725147, 0.18874892752085412, 0.16876400847520145, 0.8761217562215668, 0.26858790910669733, 0.10853182551051889, 0.1380137920911823, 0.03339090843551925, 0.09118457564285823, 0.3285088480583259, 0.17519052220242365, 0.044560697461877546, 0.10680428892374039, 0.1461728907057217, 0.014171744147980852, 0.13305024057626724, 0.09879921097308397, 0.3406811148992607, 0.12345726176031999, 0.09358373297644512, 0.11885159675564085, 0.18431537970900536, 1.9795439498765128, 0.22209000773727894, 0.039345060009509325, 0.11691739197288241, 0.19054576967443737, 0.07087961877030985, 0.5332422692860875, 8.362566079412188, 31.383057117462158, 66.96684224264962, 53.10168763569423, 64.51810250963483, 82.11298411233085, 67.33422824314663, 43.11346803392683, 35.0548882484436, 45.93389817646572, 53.35129124777657, 75.6792996270316, 66.53731850215367, 39.82863071986607, 9.792556592396327, 0.1913397777825594, 0.12450445842530046, 0.05507996818050742, 0.050628540970917256, 0.02097739864672933, 0.06507095188966819, 0.04459125867911747, 0.07183196981038366, 0.03979566154469337, 0.06729675031134061, 0.0512701636845512, 0.012098990147933364, 0.005228675502751554, 0.018797182511272173, 0.019152300598632013, 0.04348581996081131, 0.025773691279547553, 0.03271109777103577, 0.03694976354017854, 0.012711999039830906, 0.06956112344882318, 0.03109147200094802, 0.02562494283275945, 0.019540965457313826, 0.035674616428358216, 0.045366674927728515, 0.03312612371519208, 0.045434528429593356, 0.051165241814617596, 0.03689677334789719, 0.05257240469966616, 0.017922918977481977, 0.09035705469016518, 0.012030102728333856, 0.07027376842285905, 0.0196703010172184, 0.009796054169003452, 0.05168475875897067, 0.02049028853486691, 0.025096837331407836, 0.030805326998233795, 0.023977615870535374, 0.04583244850592954, 0.020559477054380944, 0.07078671375555651, 0.012557318500642265, 0.06614718306809664, 0.12222668422119957, 0.12441056274941989, 0.15685810734118733, 0.12436660725091185, 0.1856614981911012, 0.07869709535901036, 0.16540722788444587, 0.1700908022799662, 0.07955322334808962, 0.10746750940701791, 0.09556881431490183, 0.22086724692157336, 0.13117866457573005, 0.17437902146152087, 0.10908451263925859, 0.19652852149946348, 0.15346852636763028, 0.10648718915347542, 0.17458894662559032, 0.10724902113101312, 0.10197483628456082, 0.11539556006235735, 0.11775036156177521, 0.11452014132269792, 0.11742269700126988, 0.15176878257521562, 0.10849808196404151, 0.0910977910139731, 0.13003389457506792, 0.19196918686585768, 0.0884689020791224, 0.1199774763413838, 0.19604844440306934, 0.12112045500959669, 0.12923103837030275, 0.13093398484800542, 0.15584041337881768, 0.20815627755863325, 0.16349006790135587, 0.12208026993487563, 0.21569611797375338, 0.1723085804177182, 0.08943203504064254, 0.15394645929336548, 0.1410865243524313, 0.2837435858590262, 0.19005262399358408, 0.1776208175080163, 0.25959360173770357, 0.18782385358853, 0.2160087733396462, 0.14607694585408482, 2.0794145337172916, 20.108755486352102, 62.64829363141741, 92.25626318795341, 91.23901217324394, 86.4027602331979, 73.25028582981655, 69.01595633370536, 57.289537157331196, 75.70300688062395, 81.41689968109131, 71.75260162353516, 91.27167565482003, 72.88130174364362, 40.98052740097046, 20.955396958759852, 6.088188350200653, 1.268456946526255, 0.17616241505103453, 0.42610642101083485, 0.6020905034882682, 0.07044028770178556, 0.18654708138534, 0.6564178711601666, 0.3608361562447888, 0.360041863151959, 0.3946970892804009, 0.4478275483208043, 0.9287302047014236, 2.335014875446047, 1.3306015261581965, 1.403929448553494, 0.17378587328961917, 0.6472489631601742, 0.5908334989632879, 0.8983819388917514, 1.403441880430494, 0.260247248091868, 0.1848242674022913, 0.3186410218477249, 0.16195622592100076, 0.13921688896204742, 0.3937690705060959, 0.4554654913289206, 0.3734043075570038, 0.36027066516024725, 0.2723092937043735, 0.3307306431233883, 0.45740772996629986, 0.8402283936738968, 0.9028760663100651, 0.4412092263145106, 0.4012057328862803, 0.41245728198971066, 1.0712017140218189, 3.9951950822557722, 1.0317958742380142, 0.13025004869060858, 0.1660458921853985, 0.33305587406669346, 0.321896849998406, 0.3698410487600735, 10.190842969076973, 32.072061334337505, 75.45629719325474, 69.47733061654228, 81.87189551762172, 74.29504476274762, 66.072984286717, 49.11952216284615, 51.30048527036394, 60.11099910736084, 69.35283974238804, 92.08626161302838, 78.57954720088414, 37.7923812185015, 6.8902827501297, 0.13629404508641788, 0.2728193349071911, 0.21204257330724172, 0.06334738473274878, 0.1904693937727383, 0.08987284531550747, 0.18085619461323532, 0.2319407755775111, 0.1495239037488188, 0.1678496825375727, 0.11235063416617257, 0.11327664447682244, 0.12147184115435396, 0.12216640317014285, 0.16584991770131247, 0.17844493900026592, 0.13823878073266574, 0.1344764804733651, 0.10703969986311027, 0.09433699505669729, 0.1373084277978965, 0.2649038167936461, 0.22064004625592912, 0.16298884765378066, 0.09095360910786049, 0.20518238070820058, 0.07048382929393224, 0.17015759726720198, 0.17350053574357713, 0.11092464532703161, 0.18317193963697978, 0.11245767306536436, 0.12868578120001725, 0.10637390773211207, 0.210311426914164, 0.09057740893747125, 0.1414587279515607, 0.16852249072066375, 0.16244764812290668, 0.07102943930242743, 0.13767799868115357, 0.17183454228299005, 0.12091451963143689, 0.10384277533739805, 0.12172958946653775, 0.12000940819936139, 0.17005831402327332], [0.02418451476842165, 0.016884053026192954, 0.01838280287172113, 0.015133941579344017, 0.022862840510372604, 0.07117668818682432, 0.041390605603477786, 0.0031148107622617056, 0.03388642220358763, 0.03141233424789139, 0.031848181039094925, 0.03393695949177657, 0.08298550453037024, 0.01892354948047016, 0.06884714854615075, 0.038573999955718, 0.05321373564324208, 0.04358429914074285, 0.04960105235555342, 0.014548671199008822, 0.040199305063911846, 0.017541307490319014, 0.044810910642679246, 0.04815658700785466, 0.02143259216765208, 0.07679543990109648, 0.052468615983213694, 0.03456887576196875, 0.04185766161286405, 0.025053421268239617, 0.056562417918550115, 0.03648606627913458, 0.02590584445611707, 0.062387664802372456, 0.032835364674351046, 0.01771031360008887, 0.026112207311338613, 0.046779791957565715, 0.05741519733731236, 0.04588597813355071, 0.03310933675883072, 0.05631453211286238, 0.01963425045167761, 0.044123819297445674, 0.0870260177180171, 0.0910890039854816, 0.03203106318999614, 0.08290728979877063, 0.040213282885296006, 0.05324608480025615, 0.057434399878340106, 0.02005477761849761, 0.0980945455708674, 0.16287680795150145, 1.0310709817068917, 10.067006962639944, 43.62441423961094, 77.99447413853237, 75.93478488922119, 67.07210745130266, 56.14685378755842, 47.23184599195208, 57.98618786675589, 44.38930320739746, 45.062020846775596, 77.24693134852818, 76.90044552939278, 61.44957651410784, 38.81350932802473, 15.082656179155622, 9.006935937064034, 3.8128283194133212, 2.1659945164408003, 0.9030832637633596, 0.6093979456595012, 0.36285572073289324, 0.3652746437915734, 0.27717797245298115, 0.31577374999012264, 0.5633371429783958, 2.841385258095605, 1.8167308292218616, 0.441976432289396, 0.1354191013212715, 0.098933947671737, 0.23431103410465376, 0.16329391699816498, 0.5264336317777634, 0.042564359227461476, 0.054791841855538745, 0.20773076824843884, 0.20788024951304707, 0.08821928261646203, 0.06209846639207431, 0.0474373127466866, 0.0798715716227889, 0.2996623973761286, 1.2396085688046046, 2.2002050578594208, 0.8684855231216976, 0.1672675402036735, 0.12380494310387544, 0.24678660609892436, 0.3384887682540076, 0.16832036870930875, 0.16901627422443458, 1.1085590294429233, 0.3605977733220373, 0.2685099318623543, 0.10348644267235484, 1.347773021885327, 4.627662675721305, 13.10569999899183, 35.956073079790386, 52.85880987984793, 58.00883552006313, 60.74470261165074, 87.70196914672852, 50.726300035204204, 44.359603132520405, 42.03183848517281, 44.02186162131173, 56.61142771584647, 63.63154016222273, 63.14168521336147, 41.62811688014439, 9.17135202884674, 0.26315781048366, 0.16304607529725346, 0.05010782641225627, 0.02167932955282075, 0.01557886038374688, 0.028217969495537024, 0.05038271451901112, 0.044291777070611715, 0.01826053425403578, 0.011110742909035512, 0.04573468178776758, 0.05983876157552004, 0.041204296850732396, 0.08747499076915638, 0.031646605248429945, 0.05104705797774451, 0.03546799912250467, 0.08897306038332836, 0.025952062868912305, 0.014277141840596284, 0.01903264773344355, 0.02172450641436236, 0.11977862486881868, 0.05611013700919492, 0.10069123123373304, 0.02996802157057183, 0.01651269250682422, 0.044478119750108035, 0.03106432720752699, 0.0257226620534701, 0.058058353540088446, 0.028109756730762974, 0.02413979422168008, 0.020188359111281376, 0.034557208352323086, 0.10163769258984498, 0.01606625208764204, 0.07201962545514107, 0.1087333911231586, 0.021172887978277037, 0.05137753506590213, 0.03531689615920186, 0.08472764319075005, 0.0295296133096729, 0.0490336681583098, 0.07878620057765927, 0.026136480205293213, 0.018706900034365908, 0.01288801696084972, 0.022114599589258432, 0.028722597685243403, 0.036767712594675164, 0.03274242573284677, 0.054372809162097316, 0.015446401866418975, 0.04634868812614253, 0.024744029655786495, 0.04738376276301486, 0.07506147080234118, 0.041828528711838384, 0.02389357252312558, 0.1102059478206294, 0.056837194067026885, 0.05502045726669686, 0.04729777541277664, 0.04767103413386004, 0.0956129530178649, 0.04630972325269665, 0.05816032378269093, 0.032810499758592675, 0.01471252553164959, 0.025523793617529527, 0.007819581743595856, 0.0432906834674733, 0.056452756481511254, 0.011125724114078497, 0.06155303280268397, 0.026639247512710944, 0.04316665744408965, 0.02737443850907896, 0.10130932235292026, 0.023924751207232475, 0.05473086191341281, 0.06632383966020175, 0.04732243337535432, 0.0314853751499738, 0.07363643191222634, 0.010790828914780701, 0.01366176740598998, 0.012739404221065342, 0.055556734026010544, 0.044922278595290015, 0.033516525623521636, 0.05728246231696435, 0.01748855478529419, 0.01291380892507732, 0.09529727138578892, 0.01585853555505829, 0.140641079683389, 0.023158286531854953, 0.03973545852516379, 0.07103911521179335, 0.5601916174803461, 6.17156673329217, 30.15824604034424, 65.52900981903076, 87.35863780975342, 76.77116734640938, 70.42694786616734, 51.53520931516375, 57.83866024017334, 71.35061359405518, 51.8491393498012, 71.75948728833879, 84.29752554212297, 70.99984073638916, 61.10741247449602, 33.030877998897004, 12.246033259800502, 3.883769427027021, 1.9260597569601876, 0.6924666996513094, 0.20517497110579694, 0.475836523941585, 0.4982152602502278, 0.3641994914838246, 0.2161642528538193, 0.27240363721336636, 0.23993494947041782, 3.9425416333334784, 2.860335166965212, 0.8195128281201635, 0.07142794970422983, 0.04219282737800053, 0.39524534557546886, 0.25550426117011477, 0.6498860759394509, 0.1377341542392969, 0.11521943951291697, 0.1486452551824706, 0.18825659608202322, 0.239584852542196, 0.09774263695414577, 0.07690392407987799, 0.056020913046917746, 0.26751511810081346, 1.745514290673392, 2.238505482673645, 1.3561925015279224, 0.6322795035583633, 0.2663126183407647, 0.43795174253838404, 0.5599333399108478, 0.23372711400900567, 0.28619328726615223, 1.214102491736412, 0.1400024832359382, 0.1125595618837646, 0.3513138400656836, 1.0820343898875373, 4.868016932691846, 14.959806816918508, 44.05762052536011, 64.4264349256243, 71.54185581207275, 84.00502027784074, 95.06185545240129, 73.99906539916992, 46.54326908929007, 41.15131759643555, 41.71563638959612, 55.33691964830671, 68.81279100690568, 75.771377154759, 55.606336048671174, 18.188196965626307, 0.502880161362035, 0.24064390999930246, 0.022116424848458598, 0.046188258699008396, 0.05280244164168835, 0.10801299727920975, 0.0714767092306699, 0.005078524608896779, 0.04135224462619849, 0.03728495305404067, 0.09035782822008644, 0.010225586343689688, 0.020107326763016835, 0.03994786712740149, 0.029590393083968332, 0.016721613439066068, 0.020305576035752892, 0.017570057019059147, 0.026673516923827783, 0.030211595286216055, 0.018260826024093797, 0.026762681514290825, 0.07888249826750585, 0.07178690151444503, 0.05658120655321649, 0.015522043253960354, 0.03496010548302105, 0.035849451153938255, 0.02620687990981553, 0.06566448004118033, 0.03494169343529003, 0.02723748130457742, 0.052577870299241374, 0.017549380360703384, 0.055282426066696644, 0.02115762433303254, 0.027044841820108037, 0.077134754907872, 0.0617654753316726, 0.013537610764615238, 0.03277305819626365, 0.028998588411403552, 0.038388505444994996, 0.01688528965626444, 0.007965279327306365, 0.024889660234163915, 0.0022266800931122687, 0.019892317675320164, 0.06368749362549611, 0.07641326862254313, 0.09161307050713471, 0.16065972191946848, 0.20091339120907442, 0.22573238371738366, 0.09715412317642144, 0.07785905032817807, 0.2105765983994518, 0.12998281445886406, 0.1214104201644659, 0.10306349143918071, 0.1299870213759797, 0.25744544129286495, 0.12044609976666314, 0.15319965008114064, 0.0769890123712165, 0.19106645030634745, 0.1593244057148695, 0.12225310637482575, 0.0908214711983289, 0.09539275483361312, 0.06226518923150642, 0.08246573992073536, 0.17626836150884628, 0.10521819974694933, 0.15485691758138792, 0.12695147283375263, 0.218722954126341, 0.12488408519753388, 0.11895480193197727, 0.135437313201172, 0.2300410403737, 0.1442516323711191, 0.10619666081454072, 0.2292402604860919, 0.1305731399250882, 0.14616571180522442, 0.1357245370745659, 0.12153217648821217, 0.1267487129994801, 0.16555949114263058, 0.19201226026884147, 0.30217297694512774, 0.278039033391646, 0.15511720361454145, 0.22125413401850633, 0.11788980050810746, 0.20012614130973816, 0.08617028327924864, 0.2349527653838907, 0.11232348598007645, 0.11321086050676447, 0.21868069496537956, 0.24260379054716655, 2.535362273454666, 20.406273875917705, 66.90258530208042, 101.56242329733712, 98.24794496808732, 91.03511033739362, 73.68739700317383, 65.95014708382743, 77.91125556400844, 57.76073966707502, 59.280995096479145, 94.07632991245815, 93.11387934003557, 86.31572014944894, 63.52997834341866, 29.81905582972935, 14.91286826133728, 7.062697955540248, 2.465634060757501, 1.7360954646553313, 1.0323860368558337, 0.8826107223119054, 0.4946160390973091, 1.0312043002673557, 1.2776900167976106, 1.1458470800093241, 8.138188770839147, 4.787748302732195, 2.2337244706494466, 1.059291524546487, 0.21962005884519645, 0.8686833296503339, 0.578514559992722, 1.571518478649003, 0.2667704394885472, 0.15879322136087076, 0.44734071301562445, 0.6632423592465264, 0.6287359765597752, 0.2887319310435227, 0.5061951577663422, 0.4691176159041268, 1.1262383950608117, 2.6574714354106357, 2.783022778374808, 2.2038335374423434, 1.2372340219361442, 0.4209777276430811, 0.6969142524259431, 1.116731739469937, 0.4175742231309414, 0.4546288847923279, 1.2479875534772873, 0.39213985364351955, 0.7067730405500957, 0.6132547387054988, 1.476045018860272, 5.620581533227648, 16.543304749897548, 51.091535568237305, 67.07686001913888, 79.72217845916748, 81.32118824550084, 103.04498127528599, 69.40516662597656, 60.34554944719587, 56.17181519099644, 59.08283247266497, 72.52209377288818, 84.15984003884452, 86.80467183249337, 56.542532852717805, 13.906742181096758, 0.5800920724868774, 0.5475562640598842, 0.10568906233779021, 0.24638010933995247, 0.11926320966865335, 0.18230695676590714, 0.131799510547093, 0.17173447193843977, 0.2094427121004888, 0.14947209081479482, 0.12614997369902475, 0.17001739836164884, 0.13489319596971783, 0.1191913935222796, 0.14584533471081937, 0.09119630072798048, 0.1032723445179207, 0.23787290869014605, 0.17916414540793213, 0.09250903528715883, 0.08359314621027027, 0.07357782684266567, 0.3856378053980214, 0.2644865448985781, 0.18734248727560043, 0.15411796580467904, 0.1516829886074577, 0.1007325675870691, 0.18103550427726336, 0.17955792642065457, 0.22647833797548497, 0.1369078207228865, 0.08482774746205125, 0.1173277020986591, 0.13428813272288867, 0.16707472769277437, 0.20664315803774766, 0.15436702886862413, 0.33288477467639105, 0.13281769305467606, 0.14179311000875064, 0.08683895918407611, 0.1251377487289054, 0.11979150346347264, 0.07089885523808853, 0.13100120052695274, 0.08268055732228927, 0.08558111132255622, 0.18343652758215154], [0.07171446111585413, 0.08414856783513512, 0.08233514228569609, 0.05141571283872638, 0.011559299509307104, 0.10517874293561492, 0.0433720635649349, 0.01915193927873458, 0.020464463492057154, 0.09098434674420527, 0.06752298067190818, 0.0428432235494256, 0.041594444308429956, 0.01748713495076767, 0.022627985969718014, 0.01512586192360946, 0.0073620328579896265, 0.05256203668458121, 0.055567271674850156, 0.06480756495147943, 0.03241881202640278, 0.05170474840062005, 0.0367494701806988, 0.06918038387915917, 0.007387544926522034, 0.023936674763847674, 0.025552901073492, 0.02969335059502295, 0.0016391169005406222, 0.027593808880607997, 0.03000545295487557, 0.024408431324575628, 0.033558839067284546, 0.04476662605468716, 0.05937351046928337, 0.025121734477579594, 0.08017899548368794, 0.05757917889526912, 0.053831599453198056, 0.02478229394182563, 0.0029431136250163293, 0.05076635143320475, 0.034162758982607296, 0.03414097461583359, 0.05412224653576102, 0.12951102906039783, 0.02883201145700046, 0.0441481040657631, 0.12554045926247323, 0.022926171576338153, 0.021393184550106525, 0.04915748383583767, 0.09564812148788146, 0.031850047010396204, 0.019173148587079983, 0.3022925348154136, 1.2030033958809716, 13.233190757887703, 45.02879108701433, 76.15179797581264, 76.51126997811454, 71.0418564932687, 54.97085727964129, 60.51522445678711, 40.36029297964913, 35.65003967285156, 56.2160439491272, 45.21401963915144, 51.65411731175014, 43.3501375743321, 29.099597658429825, 14.902221884046282, 11.141376512391226, 8.440133162907191, 4.965065027986254, 2.6211099922657013, 2.2310746014118195, 1.6298302582332065, 1.2194584671940123, 0.6547503577811378, 0.07182674509074007, 1.462297682251249, 0.8826872067792075, 0.2073513993195125, 0.3267370845590319, 1.0244602050100053, 0.9260322409016746, 0.6241539652858461, 0.7529442001666341, 1.176054916211537, 0.8466965151684624, 0.2494088996733938, 0.2399824469217232, 0.1986204178205558, 0.812021692948682, 0.521435977092811, 0.4130047783255577, 0.15105287384774002, 0.6214576299701418, 1.1032614622797285, 1.2378504574298859, 2.4134307248251776, 2.682946571281978, 2.593995515789304, 1.9475561806133814, 1.9272559327738625, 2.9849126764706204, 6.345619107995715, 14.86879757472447, 28.601222481046403, 41.8102639062064, 48.85180459703718, 67.47779887063163, 64.33236326490129, 70.81514372144426, 51.81476313727242, 34.22809777941023, 63.67949662889753, 46.09111506598336, 57.34050219399588, 56.764142172677175, 63.887609073093955, 63.72110939025879, 40.6104211807251, 14.205010976110186, 0.5818034463695118, 0.033446181898138354, 0.0925479628411787, 0.013145892498349505, 0.041166356565164666, 0.03952674115342753, 0.11386787917997156, 0.03655374675456967, 0.04291399475187063, 0.06459588916706187, 0.07108134044600384, 0.009216475849305945, 0.04116168145888618, 0.031464167537965944, 0.07048252650669642, 0.049292817645307095, 0.034644216897764375, 0.031749542403434, 0.024074793959568654, 0.042390973174146244, 0.021252446209213564, 0.032168731159929714, 0.023735070135444403, 0.021226600810353245, 0.029926702180611234, 0.0748438849779112, 0.024964548447834592, 0.09081844493214573, 0.0707551415211388, 0.015578717891392964, 0.024997355615986244, 0.021846062570278133, 0.03641518311841147, 0.023972467486081377, 0.05589780304580927, 0.05178767895059926, 0.015279746880488736, 0.06130357618842806, 0.019427100495834435, 0.06987614690193109, 0.02527092057945473, 0.023904944770038128, 0.03361326775380543, 0.03472790062161429, 0.07903382514736482, 0.026990313049671904, 0.04583600063675216, 0.0793956471607089, 0.03872027514236314, 0.030217959944690977, 0.0660103971936873, 0.02959137356707028, 0.05734227517885821, 0.030533702644918646, 0.017964908420773487, 0.0690777554575886, 0.12927821012479918, 0.02375278159576867, 0.04767254387427654, 0.04160198961783733, 0.09158033119248492, 0.03184099196057234, 0.006361710240266153, 0.0717508713049548, 0.032730490301868746, 0.044199791470808644, 0.03358930528962186, 0.02437191765888461, 0.018267714850870625, 0.05537730561835425, 0.046801359193133454, 0.09704453977090971, 0.05247888561072094, 0.0825015122869185, 0.014897316062290753, 0.053869794189397774, 0.02495261132051902, 0.015367486547412617, 0.10819913300552539, 0.021193922563855137, 0.014872692026464003, 0.057427757020507536, 0.015547936150271977, 0.029006204966987883, 0.05930194538086653, 0.11723896328892026, 0.04055810759642294, 0.01595737605488726, 0.03280449133100254, 0.03590485693088599, 0.04533764719963074, 0.0199970733041742, 0.007883182527231318, 0.09316813027752296, 0.016191350196355155, 0.06877075907375131, 0.06229471229016781, 0.009275692448552166, 0.00851082063413092, 0.10186414008161851, 0.0362852402696652, 0.06384379416704178, 0.00733326212503016, 0.05211870565212198, 0.05474133849410074, 0.12594996871692793, 0.6901355790240424, 6.022137905870165, 34.95960065296718, 66.97788293021065, 84.70266805376325, 75.77462196350098, 63.27019909449986, 57.702423436301096, 54.67963743209839, 40.18724461964199, 62.21387835911342, 83.2174906049456, 78.27007443564278, 84.94862733568463, 63.311485290527344, 36.72378649030413, 17.42152578490121, 10.392802783421107, 6.869859823158809, 3.666613902364458, 0.6498376013977187, 1.1895308388131005, 0.8628039594207491, 2.2369920781680515, 1.4290488149438585, 1.9156474471092224, 1.2115606452737535, 0.48619911074638367, 0.08959587410624538, 0.8645605508770261, 0.24496408818023546, 0.4065589670624052, 0.38671765316809925, 0.4603212507707732, 1.108782023191452, 0.2602817719536168, 0.3890090930674757, 0.12726969218679837, 0.09922213506485734, 0.2059895931077855, 0.13152048337672437, 0.18287347922367708, 0.2572236960487706, 0.3335993806166308, 1.2831772480692183, 1.1384167415755135, 1.0808244262422835, 1.5395592621394565, 1.7318858333996363, 1.5127950182982852, 1.8140112608671188, 3.3881181606224606, 7.157226460320609, 17.93432715960911, 28.623989990779332, 47.52565056937081, 63.36745303017752, 83.399172101702, 83.54815537588937, 78.75607313428605, 65.93008763449532, 48.77978999274117, 80.2201350075858, 44.24745225906372, 56.993887833186555, 58.660784993852886, 68.93350206102643, 75.5496323449271, 62.182090350559776, 25.148827620915004, 3.7309120978627885, 0.038441051196839125, 0.09095822314598731, 0.034863617803369246, 0.029771982625659024, 0.04106358225856509, 0.04668107868305274, 0.010870382904873362, 0.02989020717463323, 0.024962066706003885, 0.06182882336101361, 0.020581853442958424, 0.008342699164391627, 0.08547618945262261, 0.02868741564452648, 0.010563792793878486, 0.035910851787775755, 0.01251470819780869, 0.056176501126693826, 0.035617890900799205, 0.08180345581578356, 0.0632955175159233, 0.05813942490411656, 0.054691720620862076, 0.020149487536400557, 0.10118580862347569, 0.03754925262182951, 0.017447306641510556, 0.038717513504837237, 0.04755928620163884, 0.07953051278101546, 0.04531914694234729, 0.05827392411551305, 0.11845818215182849, 0.010203198928918158, 0.011814294665652727, 0.06467248898531709, 0.06873232685029507, 0.06098372835133757, 0.09572337102144957, 0.030339577168758427, 0.09680391768259661, 0.030083270743489265, 0.035759453661739826, 0.0030035929355238166, 0.035545959403472285, 0.018267470578263913, 0.03251352194430573, 0.0353922305096473, 0.007580197133523012, 0.04761561817888703, 0.20219818369618484, 0.25031458107488497, 0.176241097971797, 0.20984635901238236, 0.2420534443642412, 0.18581709984157765, 0.1407451398138489, 0.1285084799996444, 0.16869630425104074, 0.2665736371917384, 0.23112509506089346, 0.21476914414337703, 0.18051704924021447, 0.08152231840150696, 0.08580927550792694, 0.12203252821096353, 0.11340004964066402, 0.17759003915957042, 0.17478019850594656, 0.2448177688888141, 0.2233625730233533, 0.15204881397741182, 0.11743809974619321, 0.08952607999422721, 0.09698915774268763, 0.0838757221187864, 0.12132291628846101, 0.1954980575080429, 0.10007023598466601, 0.10079850083483116, 0.11547219380736351, 0.1432826572230884, 0.26223340151565416, 0.1334625320242984, 0.25261535761611803, 0.18730514070817403, 0.14273525588214397, 0.10770601446607284, 0.1734451265739543, 0.16064995101519994, 0.10504887133304562, 0.22008881797747953, 0.1323181962860482, 0.09567295586956398, 0.11579280160367489, 0.21743090131453105, 0.20628932916692325, 0.08848373485463006, 0.22919042887432234, 0.11545540685100214, 0.16341152068759712, 0.2740128237221922, 0.13995105028152466, 0.14582652572010243, 0.19421770263995441, 0.4124183069382395, 1.9402416816779544, 21.58137580326625, 62.68353489467076, 103.28076839447021, 94.35402856554303, 89.65618474142892, 75.07031781332833, 78.09789112636021, 53.856869970049175, 53.94266980034964, 75.02729456765312, 68.64567988259452, 84.23466518947056, 86.2279018674578, 69.79045118604387, 46.211207730429514, 33.299342496054514, 20.473603657313756, 15.902316059385027, 11.142854741641454, 10.912482006209236, 9.633546199117388, 9.36217735494886, 5.662568194525583, 4.844803435461862, 2.780364223888942, 1.276258687887873, 0.7186497918197087, 2.6084482031209126, 3.1431090448583876, 1.7220412130866731, 2.0979323514870236, 2.649104501519884, 1.7578894666263034, 1.2146179612193788, 0.39931427580969675, 0.3468165099620819, 0.33054586446710993, 1.6682288263525282, 1.0600970813206263, 0.8565545976161957, 1.3571560212544032, 1.9227739104202815, 3.4728994284357344, 3.240585105759757, 4.556396305561066, 4.972155664648328, 4.472318759986332, 3.671591418130057, 4.149022987910679, 8.25652962071555, 15.147382123129708, 25.437964745930262, 40.56609167371477, 59.420639991760254, 68.87767328534807, 93.28427696228027, 83.59235286712646, 88.17994962419782, 63.976122174944194, 47.862540926252095, 81.3834788458688, 61.23167405809675, 75.12325613839286, 73.36900275094169, 84.3363173348563, 89.10432406834194, 66.4157806124006, 22.286489418574742, 1.906398309128625, 0.1298626187656607, 0.2028915514903409, 0.21944460326007434, 0.09965137631765433, 0.12684961115675314, 0.26768249911921366, 0.1204820214105504, 0.0861903407743999, 0.11769453170044081, 0.18988385876374586, 0.07234999737037079, 0.18472212074058397, 0.39454561312283787, 0.16099821589887142, 0.13759623521140643, 0.1514269094914198, 0.15552184118756227, 0.18478416598268918, 0.22380488286060946, 0.1353095450571605, 0.15174909148897442, 0.11105814709195069, 0.1209749092480966, 0.19708494735615595, 0.1972889964069639, 0.11451191747827189, 0.16988213919103146, 0.16628940483289106, 0.10455027023064238, 0.1768724883773497, 0.17306606977113656, 0.15650023440165178, 0.099957185265209, 0.2136116855378662, 0.09692413373185055, 0.19910424043025288, 0.1269522463636739, 0.14229005548570836, 0.1500238347798586, 0.21061775833368301, 0.16904893890023232, 0.09763028512575797, 0.14879081451467105, 0.26886643416115213, 0.13347606201257023, 0.15361914757106984, 0.1629116167979581, 0.15425497559564455, 0.18329897496317113, 0.1849241206156356], [0.14000617446643965, 0.1842409444174596, 0.08989605799849544, 0.10850226173975638, 0.0429135604894587, 0.11183861842645065, 0.07047883527619497, 0.08846571296453476, 0.041874136443116834, 0.00902876676991582, 0.10598550750208752, 0.022598310240677426, 0.025606978618140732, 0.09878279721098286, 0.06669338340205805, 0.054128054795520644, 0.09824015918586936, 0.06128940837723868, 0.06724296284041234, 0.02225929718198521, 0.08213532050805432, 0.03185538708099297, 0.005482525207168821, 0.03861731084595833, 0.04070790098713977, 0.03609717750389661, 0.04296812488298331, 0.016488982796935097, 0.016739496229482547, 0.09498909435101918, 0.06675831241799252, 0.04667536881087082, 0.027087309630587697, 0.09617227621908699, 0.11450351721474103, 0.04064723317112241, 0.01901955370392118, 0.022206198424100876, 0.025892456960199133, 0.05963509250432253, 0.03000592114403844, 0.015012996104945029, 0.04258557362481952, 0.03309643441545112, 0.023611875317458595, 0.03570595796086958, 0.06131996959447861, 0.02981018414720893, 0.03990263259038329, 0.08199474162289075, 0.03801997272031648, 0.07705966143735818, 0.04672060674056411, 0.12378290428646974, 0.0898168593911188, 0.04024357608120356, 0.0419681338992502, 0.2083740872996194, 0.7656706401279995, 12.658028432301112, 49.001069273267476, 79.51569884163993, 75.75429153442383, 68.84895638057164, 82.00696155003139, 65.5714007786342, 58.128386225019185, 44.71820660999843, 46.866850171770366, 38.53219761167254, 32.1957357951573, 27.936936480658396, 10.69593618597303, 14.4358857188906, 14.639764104570661, 8.89247739315033, 5.652030382837568, 5.753464962754931, 6.582431954996927, 7.818265046392169, 6.380697957106999, 4.958750852516719, 5.998203533036368, 6.397381450448718, 4.986795084817069, 4.752771505287715, 2.3694861914430345, 13.471032806805201, 24.546457018171036, 32.305281094142366, 30.416246550423757, 25.641241243907384, 28.891863891056605, 33.62818683896746, 36.9167240687779, 40.092571939740864, 35.173285552433555, 33.72770936148507, 31.070502826145717, 25.988819667271205, 23.726769345147268, 16.99149830000741, 9.83645965371813, 5.995593181678227, 8.510968310492379, 11.120541470391409, 14.74181056022644, 31.887968812670024, 46.020351137433735, 63.888116291591096, 71.8248211996896, 66.70330401829311, 48.78747122628348, 44.834967613220215, 43.37203482219151, 48.72038984298706, 51.297417640686035, 43.99774442400251, 58.32095554896763, 66.84644385746547, 68.79427405766079, 58.59096254621233, 19.059850215911865, 1.2102648062365395, 0.0694418302071946, 0.03868160543165036, 0.020297906893704618, 0.1472021740462099, 0.14800565450319222, 0.04195968953094312, 0.0990264116387282, 0.07549808773079089, 0.017040691138910394, 0.003099757674915184, 0.005848308168684265, 0.04219884259094085, 0.023498958608667766, 0.018833119422197342, 0.0911458787907447, 0.003192639152985066, 0.04777982704607504, 0.05466204828449658, 0.023579975689894388, 0.030574509740940163, 0.03824084604691182, 0.016305583263082162, 0.022923840808549097, 0.021215384626494985, 0.02407630709266024, 0.0737439864980323, 0.03593165906412261, 0.045394752706800184, 0.04927813754017864, 0.05240739516115614, 0.016904515946017842, 0.05214721769360559, 0.04993383985544954, 0.05488281983083912, 0.08971309781606708, 0.07831701396831445, 0.023256838654300997, 0.015960485441610217, 0.04554440699783819, 0.046299999845879417, 0.10613397774951798, 0.02243984177974718, 0.0375823888794652, 0.02561636275744864, 0.07472446959997926, 0.09013939422688313, 0.07754689029284886, 0.10045407645936523, 0.04321864679721849, 0.056864847761711905, 0.09619316831231117, 0.07944367386932884, 0.27513946326715605, 0.1874607830707516, 0.19975263492337295, 0.18674425009105886, 0.08014244280223336, 0.13561872632375785, 0.06534478148179394, 0.09425983883972679, 0.047227519896945784, 0.09177207161805459, 0.08176948156739984, 0.042514832956450324, 0.10922897274472884, 0.09212942208562579, 0.09507217417870249, 0.10449070842670542, 0.08936240377702884, 0.026858631454940354, 0.1288261158125741, 0.0594570856275303, 0.06425643166793243, 0.012088801944628358, 0.09707001197550978, 0.06073712158415999, 0.029896755037563186, 0.019823349679687192, 0.03693433026117938, 0.03967673810464995, 0.03371806409476059, 0.05256624699437192, 0.043790319335779974, 0.031087112413453202, 0.05256473386128034, 0.027750484312751462, 0.029457644492919956, 0.036805428963686736, 0.030058592424861023, 0.04355094575190118, 0.013313589883702142, 0.09818852267095021, 0.036866358015686274, 0.006744620273821056, 0.057356782257556915, 0.03915582677083356, 0.03429286128708294, 0.038636282685079744, 0.05839090355272804, 0.021640731088284935, 0.05700395761856011, 0.11896393501332828, 0.0719725147687963, 0.06327624712139368, 0.02354147900561137, 0.0507281736603805, 0.05469705051343356, 0.020555582263373902, 0.25150454150778906, 0.7672589006168502, 5.701249250343867, 34.22900799342564, 73.27238804953438, 92.6063620703561, 75.89411013466972, 69.25997012002128, 54.68608883449009, 45.01136153084891, 56.6541382925851, 50.14830023901803, 68.4857462474278, 70.1044750213623, 67.98473943982805, 54.478681632450645, 37.02908686229161, 26.759432213647024, 19.213282074247086, 9.229573590414864, 10.294004610606603, 8.65259952204568, 10.020292486463275, 11.741988352366857, 14.936306272234235, 12.816087790897914, 8.063582488468715, 4.3680163111005506, 2.201820731163025, 2.735864268881934, 6.929098427295685, 20.511922972542898, 33.827033860342844, 39.022035190037315, 34.47756937571934, 33.034136704036165, 37.28516272136143, 33.31461116245815, 41.769585677555625, 47.318239893232075, 47.72756174632481, 46.91411181858608, 49.66768986838204, 42.22447381700788, 36.826352323804585, 34.45824990953718, 26.59509689467294, 20.643483638763428, 20.317347356251307, 26.940299034118652, 34.1863043648856, 54.871511936187744, 71.94872842516217, 82.48659569876534, 88.74829837254116, 81.58426788875035, 69.63014929635185, 56.79184116636004, 58.94271509987967, 51.87977395738874, 43.696328095027376, 48.865947655269075, 62.95147827693394, 70.6497904913766, 81.99623353140694, 72.98152256011963, 33.37000914982387, 4.726354454244886, 0.19840552578014986, 0.07750893982925586, 0.0352196824470801, 0.08041038949574743, 0.07857073178248745, 0.05274802991854293, 0.11039652116596699, 0.07165747774498803, 0.06080694283757891, 0.07503472295190607, 0.053201416839978526, 0.07194302563688584, 0.05901164095848799, 0.05242760193401149, 0.04739430719720466, 0.05696312338113785, 0.07606843712606601, 0.039918394958866496, 0.009289476887456008, 0.029854014116738523, 0.01124297411713217, 0.03691370618928756, 0.02020827920309135, 0.047979977913200855, 0.07000052915619952, 0.03129934798926115, 0.046935291827789376, 0.10281899491591112, 0.024380283995664546, 0.037710296123155525, 0.0036731946165673435, 0.05502736136051161, 0.0368739270738193, 0.08130667318723031, 0.2053853441029787, 0.0820453128378306, 0.05494588966082249, 0.015490455752504724, 0.10736410067017589, 0.03735696936824492, 0.09198324528655835, 0.01658997425277318, 0.07517013140022755, 0.0953978370609028, 0.07812563995165483, 0.11327393033674785, 0.10783769097179174, 0.16407512793583529, 0.07326140560741935, 0.13317860583109514, 0.09543163489018168, 0.12261157642517771, 0.29861593352896826, 0.31550963701946394, 0.3267928601375648, 0.30758318092141834, 0.2609533044908728, 0.2232692473168884, 0.16219998284110002, 0.293218730283635, 0.2100504623459918, 0.15489910888884748, 0.27288162442190306, 0.1978397768523012, 0.1524458655289241, 0.17176820869956697, 0.16662679958556378, 0.3889278859964439, 0.15366919631404535, 0.19842008714165005, 0.2279081605374813, 0.15439881144889764, 0.13235543428787164, 0.10919361428490706, 0.15972540634019033, 0.18353724932031973, 0.12016260783587183, 0.15695128376994813, 0.15412456116506032, 0.1844335397971528, 0.1323916951992682, 0.15579260380140372, 0.2483904186104025, 0.17266067223889486, 0.10676253187869277, 0.15095790608653, 0.17710750576640877, 0.16032873253737176, 0.1004651365801692, 0.1534092224070004, 0.1275869073080165, 0.18926932316805634, 0.09315035944538456, 0.07210127357393503, 0.1664119753986597, 0.1910032515547105, 0.16053006744810513, 0.27377729064651896, 0.17163988415684017, 0.2099500663046326, 0.08147384385977473, 0.31943211225526674, 0.19274663871952466, 0.1757348429943834, 0.2655884586274624, 0.374458696693182, 0.18482710367866925, 0.13706517299371107, 0.30873422058565275, 0.5455679393240384, 1.575480688895498, 21.323632376534597, 74.36879294259208, 107.70698629106793, 100.73023060389927, 86.89529023851667, 96.19056946890694, 81.80472033364433, 76.08961159842355, 60.227291107177734, 69.91872188023159, 62.67884486062186, 66.09157071794782, 73.99181842803955, 51.539041246686665, 58.26430688585554, 54.52511644363403, 49.90238264628819, 39.69164003644671, 41.586761202131, 39.79547391619001, 39.90726695741926, 37.55822345188686, 36.01879446847098, 30.022207260131836, 20.54736225945609, 16.681674650737218, 20.88448190689087, 34.44535057885306, 50.884246485573904, 62.743011474609375, 62.103686877659385, 52.27919462748936, 45.198143005371094, 52.24172994068691, 61.6934791292463, 62.937908445085796, 66.9230477469308, 57.91379805973598, 58.454979351588655, 55.683926582336426, 52.281789779663086, 54.748844964163645, 47.64352675846645, 44.84311090196882, 36.01665442330496, 44.13591282708304, 52.55458647864205, 54.389664786202566, 65.98262296404157, 78.29514353615897, 86.18178667340959, 87.54289708818708, 79.76122038705009, 61.04516356331961, 57.63756200245449, 60.39916869572231, 67.95670345851353, 65.31856972830636, 62.51952961512974, 77.31503064291817, 86.32660797664097, 97.5055091040475, 83.00924614497593, 32.5214638710022, 2.947226732969284, 0.27581691262977465, 0.11328167242131063, 0.14564231703323977, 0.2317112950342042, 0.2772876237119947, 0.17268769150333746, 0.18805741891264915, 0.1567304613334792, 0.14301690219768456, 0.12450308778456279, 0.18082190145339283, 0.1578338271273034, 0.1723883489945105, 0.10309352339910609, 0.13574242325765745, 0.12099153335605349, 0.14788041050945008, 0.14964025893381663, 0.10039517961974655, 0.0788587291858026, 0.12324683448033673, 0.1415240844445569, 0.09883867456976857, 0.10934085638395377, 0.1231835950165987, 0.1343791785516909, 0.1639888318521636, 0.34803480601736475, 0.20987382610993727, 0.1790758544313056, 0.08226251868265015, 0.15252878250820295, 0.13207871413656644, 0.12657008187047072, 0.2561273191656385, 0.23262186188782963, 0.21044334769248962, 0.11691150228892054, 0.30907242958034786, 0.118575799411961, 0.33825345230954035, 0.14405210236353533, 0.15782796458474227, 0.1366383201841797, 0.1606741747153657, 0.18359899600701673, 0.18781032360025815, 0.21338884106704167, 0.17555679540549005, 0.16539569278912886, 0.21208207761602743, 0.3441852054425648], [0.11945660571966853, 0.16748077661863395, 0.08610608029578413, 0.10456432947622878, 0.07880956253835134, 0.09811868784683091, 0.040879977467869005, 0.11067159247717687, 0.09310594932841403, 0.08506653072046381, 0.14642728705491337, 0.06220869440585375, 0.12036824465862342, 0.16607189364731312, 0.11188708618283272, 0.1347013469785452, 0.13104415179363318, 0.13322741964033671, 0.14360695624990122, 0.009147484104947319, 0.053769153875431845, 0.020269919020522918, 0.09699109156749078, 0.006946280457278979, 0.049565466586500406, 0.03985146426462701, 0.05056350338937981, 0.07380798592099122, 0.15086265334061214, 0.09919588254498583, 0.06763064382331711, 0.05058196293456214, 0.06842505226710013, 0.023836658702098897, 0.02833772074830319, 0.03710133469264422, 0.015847689172785197, 0.02304928157744663, 0.06719271732228142, 0.05403186906395214, 0.06479283395622458, 0.09749656622963292, 0.07218611080731664, 0.020364142089549984, 0.07320486328431539, 0.032176690375698466, 0.018409075747643198, 0.10096440943224089, 0.04370810803292053, 0.15396906808018684, 0.02823040704242885, 0.04772187337013228, 0.06227865815162659, 0.04517400830185839, 0.0673065958544612, 0.0961562560072967, 0.030231018351124864, 0.039416316364492686, 0.025351208235536302, 0.2942338729543345, 2.8611986977713446, 22.970008032662527, 49.05153751373291, 86.27218273707798, 82.80763026646206, 79.23899378095354, 64.14474105834961, 73.12608678000313, 65.53780623844692, 42.2409097807748, 47.787368365696494, 33.152947425842285, 19.793656417301722, 11.902367540768214, 5.153105863503047, 13.37542906829289, 9.017995732171194, 9.08484695638929, 12.010518857410975, 11.173292194093976, 7.448798060417175, 11.027502485683986, 4.822438486984797, 2.6382303535938263, 3.0562074908188412, 7.169683711869376, 16.434695720672607, 21.79515971456255, 30.01492554800851, 31.959295545305523, 35.940536907741, 25.48444472040449, 24.848969425473893, 51.4950522014073, 55.04797880990164, 48.17407035827637, 24.857708522251674, 28.66287558419364, 26.825817040034703, 31.588164465767996, 22.371361664363317, 16.85465179170881, 15.089349031448364, 11.238563571657453, 25.394248417445592, 33.23467213766915, 38.62369149071829, 38.309455735342844, 42.732932567596436, 51.20423187528338, 50.62475906099592, 49.133640902382986, 44.19295058931623, 56.69870056424822, 51.422964641026084, 58.57967867170061, 67.06898771013532, 80.51486369541713, 78.10113593510219, 54.95893069675991, 19.89730269568307, 3.834077213491712, 0.23138155415654182, 0.12474448340279715, 0.05440948058718017, 0.0938495694260512, 0.05104570430038231, 0.0523247326325093, 0.016072302923670838, 0.025570997602439353, 0.05626671575009823, 0.08284378570637532, 0.027255169016176035, 0.019188841405723776, 0.05242052481376699, 0.08477208044912134, 0.045249251050076315, 0.006376937414253396, 0.005593868986969548, 0.07162547803350858, 0.07260425801255874, 0.04161362649340715, 0.021238448031778847, 0.03802815245996628, 0.08721645535635096, 0.005587380495853722, 0.0209711646062455, 0.06261271451200758, 0.019039007302905833, 0.04904782918414899, 0.05811349129570382, 0.06771644457642521, 0.11568781866558961, 0.07571176519351346, 0.0213454530042197, 0.11870018845157963, 0.06289666784661156, 0.042853421930755885, 0.06511127044047628, 0.16115388540284975, 0.17345463963491575, 0.0659985431869115, 0.05351591442844697, 0.12422644905745983, 0.14477707631886005, 0.1324842745172126, 0.10103258863091469, 0.06526174915156194, 0.09256917384586164, 0.05976516766739743, 0.09443255992872374, 0.08893206329750163, 0.14386257396212646, 0.12708092374461039, 0.10453902690538339, 0.15405260931168283, 0.22139931337109633, 0.22375939387295926, 0.16070035259638513, 0.24485538687024797, 0.12163395674100944, 0.13234528340399265, 0.176125937008432, 0.06737889376069818, 0.20647729693778924, 0.10304399034274475, 0.1874423540596451, 0.09962057761315789, 0.1586460606860263, 0.22992294813905442, 0.1902238048080887, 0.19557399914733, 0.20527144521474838, 0.11926737587366786, 0.2689999969942229, 0.11579698137938976, 0.06298031085836035, 0.041263560099261146, 0.09794346974896533, 0.04623941684673939, 0.04285483667626977, 0.03382481461656945, 0.050239628446953635, 0.07145710635398116, 0.1413705183991364, 0.04569197479369385, 0.06982700061053038, 0.032030201450522454, 0.0365187411329576, 0.024616544800145284, 0.05369541747495532, 0.033880817504333596, 0.04243187865774546, 0.06047781264143331, 0.03806503762358001, 0.08869804335491997, 0.042195833288133144, 0.071162086113223, 0.0693124064377376, 0.050022042622523646, 0.1268930916807481, 0.16654708529157297, 0.038492877701563497, 0.07846913473414523, 0.05120478344282933, 0.14986509829759598, 0.036165852033134015, 0.10498911953930344, 0.05881464188652379, 0.08280318895620958, 0.08753237447568349, 0.24565394116299494, 0.07591664205704417, 0.027880111642714058, 0.048628311338169236, 1.0705943980387278, 10.701017924717494, 48.85185323442732, 75.72640841347831, 91.85294110434396, 90.96693461281913, 82.32681492396763, 63.24740900312151, 54.59510217394148, 52.13739579064505, 40.75020851407732, 55.89428676877703, 61.55512659890311, 47.16760989597866, 47.75797053745815, 38.62037372589111, 45.407738889966694, 37.62280695778983, 38.700458662850515, 37.47388621738979, 39.24658012390137, 36.72532204219273, 37.84519795009068, 28.857154164995464, 28.09786023412432, 25.85840024266924, 29.969098704201834, 45.92228078842163, 58.76642540522984, 69.07521057128906, 73.93127182551792, 69.86566543579102, 58.47502490452358, 66.55723898751395, 88.55470071520124, 83.02221148354667, 75.3245176587786, 37.91341188975743, 51.78182520185198, 53.35399409702846, 56.19810022626604, 54.75791931152344, 47.04094423566546, 47.62972068786621, 42.18976409094674, 56.87536546162197, 74.26395157405308, 68.6204787663051, 65.17421395438058, 64.82896491459438, 64.99779224395752, 58.97822734287807, 51.80022750582014, 44.53062261853899, 51.17855480739048, 50.2829007421221, 58.30580152784075, 67.97100979941231, 78.64233112335205, 86.35784707750592, 75.63459491729736, 37.385237625667024, 12.40621703011649, 0.824966729751655, 0.1658808317567621, 0.17470942730350153, 0.11315469137792077, 0.1104347701849682, 0.05506197343181286, 0.04467385335426245, 0.059326447280389924, 0.04061589163861104, 0.011724907854971076, 0.039204470946320465, 0.041774106810667684, 0.11205766988652092, 0.07505422404834203, 0.004539615981879511, 0.016818920449752892, 0.07752816272633416, 0.052025101746299436, 0.02959431501637612, 0.03276420670694538, 0.02621056605130434, 0.042460960668644736, 0.03425257666302579, 0.011116636833841247, 0.0052030620780507365, 0.09516144224575587, 0.0341007544526032, 0.011654324945993721, 0.10011157912335225, 0.07279396283307246, 0.08740125436867986, 0.08601168928933994, 0.07402721380016633, 0.09749736011560474, 0.12490098071949822, 0.03539414058572479, 0.10349015425890684, 0.10093737659709794, 0.09274857850479228, 0.14268260156469686, 0.17322752039347375, 0.08678872045129538, 0.13612549698778562, 0.09681890652115856, 0.20094684298549378, 0.24219547531434468, 0.12408213822969369, 0.12890378093080862, 0.10673566867730447, 0.14552947665963853, 0.20090945570596627, 0.26737164865647045, 0.18896337172814778, 0.2554663989160742, 0.29831998369523455, 0.3018578109996659, 0.21537458736981663, 0.23385698561157497, 0.18105127343109675, 0.18782416571463856, 0.23823828622698784, 0.20791636114673956, 0.29647325564708027, 0.22870818046586855, 0.3904127648898533, 0.16237200503902777, 0.23919765331915446, 0.23013807088136673, 0.24912817616547855, 0.20972775109112263, 0.2386305337505681, 0.22850589560610907, 0.3744033825184618, 0.3116070292890072, 0.15534498782030173, 0.09023673686065845, 0.1894101191844259, 0.14449042241488183, 0.15829527165208543, 0.19902629032731056, 0.1611754492457424, 0.15603899343737535, 0.30201151275209015, 0.27223831894142286, 0.2013250719755888, 0.1308920378131526, 0.21052505687943526, 0.1131924722077591, 0.23260468138115747, 0.13940070409859928, 0.17890936907913002, 0.1575742196291685, 0.16023786312767438, 0.255424438310521, 0.1577836698187249, 0.30721994755523546, 0.15680271174226487, 0.2036335159625326, 0.25620442788515774, 0.27355730959347313, 0.18747972776847227, 0.2279203198850155, 0.2997118490082877, 0.3931831962295941, 0.2361006566456386, 0.2652063619877611, 0.1938878803380898, 0.2722329720854759, 0.19675224806581224, 0.48128944848264965, 0.24768148522291863, 0.1459048693733556, 0.12605208823723452, 0.6673550414187568, 4.182940185070038, 37.00319440024239, 78.55857058933803, 110.78513554164341, 107.02925205230713, 99.40676552908761, 85.67649977547782, 92.95415415082658, 88.7319006238665, 67.62402370997837, 81.00212696620396, 71.27993651798793, 63.837429182870046, 53.040050165993826, 42.9935872895377, 60.0340894971575, 65.98524938310895, 55.67177765710013, 52.86060946328299, 51.70737177985055, 49.38411998748779, 51.21432065963745, 34.19488539014544, 32.15052386692592, 34.674974645887104, 33.66950082778931, 51.48639474596296, 54.134182998112266, 60.934221676417756, 63.86631979261126, 69.50007207053048, 51.94051858357021, 52.14504228319441, 83.88849898747036, 93.79272529057094, 78.94778088160923, 53.532830306461875, 59.95153100149972, 57.41686289651053, 69.60805402483258, 55.63269404002598, 52.939249174935476, 53.973690032958984, 54.89612592969622, 68.73722239903041, 70.80813298906598, 72.94327967507499, 64.00244889940534, 58.85848903656006, 68.94035298483712, 67.85247353145054, 69.91049521309989, 61.35820770263672, 74.1501887185233, 69.00722244807652, 76.47481278010777, 87.31528105054582, 100.99555451529366, 104.46860463278634, 81.61452034541539, 36.051016739436555, 8.464522208486285, 0.4154816211334297, 0.2680824005178043, 0.21847908864063875, 0.21878989839128085, 0.18715929639126572, 0.23485603343163217, 0.15592335749949726, 0.08523116367203848, 0.10833336080291442, 0.1803792252072266, 0.172060277312994, 0.12445837232683386, 0.2115107239889247, 0.23421538780842507, 0.11077396984079055, 0.12517855582492693, 0.14075885979192598, 0.16785198955663613, 0.20556644509945596, 0.10868617187121085, 0.1967144672359739, 0.13052150341016905, 0.24581792950630188, 0.12889779625194414, 0.09629158303141594, 0.14901425609631197, 0.1875493861734867, 0.14440527984074183, 0.15904993829982622, 0.18359052788998398, 0.194471949711442, 0.20555758343211242, 0.135928409706269, 0.4160064815410546, 0.2188052875655038, 0.06938102668417351, 0.10518461904887642, 0.24830514032925877, 0.23981389882309095, 0.2430590604032789, 0.16547213654432977, 0.22696935305637972, 0.17781624916408742, 0.1955654631767954, 0.33066705082144054, 0.5258350553257125, 0.24672969058156013, 0.20487104170024395, 0.31648531609347885, 0.18635582950498375, 0.20876098796725273, 0.2931830936244556, 0.2304676760520254, 0.29027774238160675], [0.07121659961662122, 0.2913237991077559, 0.09128197934478521, 0.04161301241921527, 0.0695186403713056, 0.11504429605390344, 0.057781518037830076, 0.14528609971914971, 0.1607543911252703, 0.13356807136109897, 0.19385413000626223, 0.09179894160479307, 0.17680749829326356, 0.16583980752953462, 0.14162578327315195, 0.09683018377316849, 0.11511193242456232, 0.06354162895253726, 0.07917704353375093, 0.027476571600085924, 0.042373049671628644, 0.03375574653702123, 0.08724398352205753, 0.023915485811552832, 0.05176881228440574, 0.06784869105155979, 0.04349298868328333, 0.04487551396180477, 0.07249947863497905, 0.08124899092529501, 0.012050695417981063, 0.04424771300650068, 0.041601792842681916, 0.01594448897854558, 0.018440569950533763, 0.02457588698182787, 0.03366582029099975, 0.04022098086508257, 0.02186408785304853, 0.027262403895812373, 0.027221584925428033, 0.032774954701640775, 0.03219046463657703, 0.027891032663839202, 0.029599692406398908, 0.017407676803746393, 0.08389169483312539, 0.16353215064321244, 0.06841652308191572, 0.05583280956904803, 0.04779557923653296, 0.06917965106133904, 0.06785914049084697, 0.11984345210450036, 0.026131041747118746, 0.013203991211152502, 0.03674489346199802, 0.08857939472155911, 0.09976037618305002, 0.10822159929999284, 0.03534566604399255, 0.22851941202368053, 3.996116587093898, 22.907000030790055, 49.16378913606916, 76.86321013314384, 88.19143499646867, 79.09486729758126, 75.2551121030535, 64.8164164679391, 67.1794432231358, 58.57217461722237, 44.04218510219029, 32.62282419204712, 26.416985034942627, 12.391910689217703, 15.591709000723702, 18.275388172694615, 13.334404298237391, 16.76066177231925, 15.816533599581037, 3.6143419529710497, 7.960947172982352, 5.250726316656385, 3.234290037836347, 8.027546525001526, 8.425790343965803, 22.88574375425066, 33.40054300853184, 33.6774982043675, 45.763094084603445, 40.59347105026245, 43.823584352220806, 39.12867266791207, 50.87919861929757, 48.34039633614676, 97.12856933048793, 53.44209378106253, 43.71972962788173, 47.756834506988525, 29.110872847693308, 43.77818134852818, 33.98840577261788, 48.59848369870867, 37.17761502947126, 32.4960160936628, 29.887089116232737, 50.97641086578369, 49.31127159936087, 53.26452909197126, 50.75887666429792, 61.21146174839565, 63.153893198285786, 73.44803850991386, 80.00874996185303, 77.07708263397217, 62.09605080740792, 52.29896920067923, 24.071565014975413, 4.810918373720987, 0.10505106978650604, 0.14255248568952084, 0.04172719629215343, 0.05901854165962764, 0.030800651891955307, 0.07317770152751889, 0.03357722736628992, 0.05144807556644082, 0.04032395194683756, 0.05054612950022731, 0.015262213535606861, 0.027999369261254157, 0.008747936392735158, 0.022650535384725248, 0.0053222662619581175, 0.037621248579983196, 0.06882796636117355, 0.054704436367111545, 0.022989159982119287, 0.03172378521412611, 0.021939635942024843, 0.02923064399510622, 0.037220610970897336, 0.06586115341633558, 0.03596530422302229, 0.04333344813702362, 0.06312152756644146, 0.0326021929005427, 0.02741516418089824, 0.023127119722110883, 0.03352283599919506, 0.03919490360255752, 0.07263047660567931, 0.013641189983380693, 0.005827472902767892, 0.0441489556272115, 0.012060294143988617, 0.09918763155915908, 0.058442234726888795, 0.10146406904927321, 0.019831756728568246, 0.1511293990271432, 0.12350978037076336, 0.06777740416250058, 0.10498629004827567, 0.051565007506204505, 0.17240124115986483, 0.1396152704421963, 0.06653692001210791, 0.05029456264206341, 0.16399979697806494, 0.10215690080076456, 0.20965726487338543, 0.12989661337009498, 0.12572960768427166, 0.19229241380734102, 0.1898095320378031, 0.17120851230408463, 0.13384765493018286, 0.07739085437996046, 0.17522758378514222, 0.16012791331325257, 0.03488245054281183, 0.22225327683346613, 0.17138171515294484, 0.12661847498800072, 0.07582997956446239, 0.1034384159637349, 0.09444232404764209, 0.08943574662719454, 0.09043163925941501, 0.07611024845391512, 0.050098944388862164, 0.02063059770236058, 0.05944412560867412, 0.04323536929275308, 0.04746957030147314, 0.007482419389167002, 0.07734064957393066, 0.01289532647933811, 0.007205485499330929, 0.05052272682743413, 0.03273134186331715, 0.06480719854256936, 0.03356170587773834, 0.024139432901782647, 0.04068874255088823, 0.027958365390077233, 0.022628316755539606, 0.029965894363288368, 0.022517637515972768, 0.015975414908358028, 0.04027993877285293, 0.06812919064291886, 0.019613092033458606, 0.03554262440385563, 0.07574834501636879, 0.049371948399181874, 0.05211838674066322, 0.04339855357206293, 0.07787646153675658, 0.030254421023918048, 0.010156418180226215, 0.08138703208948884, 0.06098866808627333, 0.16208525614014693, 0.051371679308691194, 0.03351562995729702, 0.09413873390959841, 0.09981575142592192, 0.049988163369042535, 0.0809554091787764, 0.09981050635022776, 0.11672493230019297, 0.11954245397022792, 0.07046557670193059, 0.13049338491899626, 1.8681780057294028, 13.251282998493739, 47.127286025456016, 74.97093078068325, 89.06919397626604, 88.33309486934117, 83.73444352831159, 78.21143163953508, 57.40778854915074, 57.810408864702495, 48.08257300513131, 36.35774496623448, 31.112119061606272, 30.012959207807267, 38.83415242603847, 44.45539447239467, 41.23808670043945, 44.81091642379761, 42.885542801448274, 45.91327939714704, 36.64221463884626, 23.65372293336051, 22.635158709117345, 29.05139626775469, 19.654746294021606, 22.963268280029297, 27.603692190987722, 40.32485369273594, 38.40028953552246, 53.94978822980608, 33.66764565876552, 40.52151550565447, 64.63914707728794, 71.85426766531808, 60.53620106833321, 100.89165810176304, 57.93710579190935, 43.25509663990566, 54.88370255061558, 34.12800203050886, 49.31281757354736, 45.69547769001552, 60.485652923583984, 57.94788939612252, 53.21417897088187, 47.04001317705427, 47.9933511870248, 41.300300870622905, 53.983139583042686, 50.87062454223633, 58.821045194353374, 64.65475967952183, 80.83862890516008, 84.24288490840367, 90.37953390393938, 86.11943353925432, 74.20858137948173, 42.3886319569179, 12.95864919253758, 1.0731423241751534, 0.08176882338843175, 0.1157204561999866, 0.11943285699401583, 0.025457987595083456, 0.017453052136780958, 0.03138800198212266, 0.05543958834771599, 0.1067985078053815, 0.09212117109979902, 0.0604655650843467, 0.07888139225542545, 0.08681992627680302, 0.03257280894156013, 0.03574402377541576, 0.021006165138844932, 0.06002280062862805, 0.019869188112871985, 0.015482099593750067, 0.04533871589228511, 0.0035215935661524, 0.05200950901157089, 0.028876034809010367, 0.03847132742937122, 0.07691716229809181, 0.032787958825273175, 0.07713107724807092, 0.09232822606073958, 0.0076144215916948655, 0.08492019107299191, 0.019667388405650854, 0.04426709875198347, 0.027579556252541285, 0.0764159963333181, 0.11736308091453143, 0.07439553617898907, 0.04266450760353889, 0.13411951677075454, 0.1181154405432088, 0.0460305671606745, 0.0883729165153844, 0.06249325842197452, 0.09659570921212435, 0.047631075206611834, 0.1969716184373413, 0.02230640617199242, 0.19140380434691906, 0.11549238700951849, 0.07078290717410189, 0.04598148533010057, 0.12457905656525067, 0.1263638615076031, 0.16198875488979475, 0.0847818377826895, 0.11240600262369428, 0.13548519063208783, 0.23013926510299954, 0.3351749932127339, 0.2413001890693392, 0.09844551780926329, 0.177294754290155, 0.26053052289145334, 0.08597766075815473, 0.26606394882713047, 0.21711549109646253, 0.13978552844907555, 0.18665709905326366, 0.20274878772241728, 0.27737073068107876, 0.2135797943919897, 0.17908842089985097, 0.1287529290254627, 0.21256571023591928, 0.20419649646750518, 0.17595671037478106, 0.19545293492930277, 0.15225192664989404, 0.14958318056804792, 0.12183686585298606, 0.07465167636317865, 0.16084528767636844, 0.12228711454996041, 0.12035132199525833, 0.11069866602442094, 0.1476303432136774, 0.14531410964471952, 0.21907679656786577, 0.08634540638221161, 0.07014092483690806, 0.10285822102533919, 0.14128312308873447, 0.13182883683059896, 0.12518535474581377, 0.1461270081677607, 0.08267305272498301, 0.10474748643381254, 0.14478966992880615, 0.18248862773180008, 0.1554426425801856, 0.12811381689139775, 0.17918048453118118, 0.10032056790909596, 0.1856973519814866, 0.22703346104494163, 0.19470328944069998, 0.27863310437117306, 0.17143875280661242, 0.10491359180637769, 0.17250688906226838, 0.22249885222741536, 0.11402148593749319, 0.13788704174969876, 0.18689758543457302, 0.3172694040196282, 0.24858659665499414, 0.12367878987320832, 0.156173207664064, 0.45640822074243, 6.052650485719953, 33.61458226612636, 72.61137117658342, 103.59694617135185, 115.19963182721818, 103.85095841544015, 99.48687131064278, 83.64549268995012, 93.421142578125, 88.55605561392647, 81.08394200461251, 70.69997038160051, 72.03099509647915, 58.37831292833601, 71.4462069102696, 66.45910263061523, 64.7961346762521, 62.972593852451865, 73.51853493281773, 53.63356181553432, 57.87007304600307, 47.897448675973074, 52.81413991110665, 64.4766981942313, 45.23569107055664, 64.91889544895717, 80.3187507901873, 76.82292447771344, 87.56672940935407, 66.2417699268886, 85.09811088017055, 77.9125896181379, 88.69895921434674, 82.10177666800362, 128.67997087751115, 82.15323502676827, 80.93282563345772, 90.22586754390171, 70.69553048270089, 96.33680125645229, 86.39585372379848, 96.54851981571743, 72.97194794246128, 59.60394041878836, 59.73831857953753, 78.22614097595215, 69.18671526227678, 77.21995149339948, 68.11372579847063, 76.99396133422852, 80.70362540653774, 97.60394423348563, 102.15800203595842, 106.29689802442277, 91.79978738512311, 76.71238558632987, 38.58687646048409, 8.691935011318751, 0.533162636416299, 0.2602726253015654, 0.28524333824004444, 0.34370298417551176, 0.07681750585990292, 0.15939714466886862, 0.15710715683443205, 0.14806368281798704, 0.18405501225164958, 0.20890129543840885, 0.15371513313480786, 0.11251779126801661, 0.18761968240141869, 0.20599266008606978, 0.1482016154165779, 0.08229798570807491, 0.18234281055629253, 0.1569980891155345, 0.13303889547075542, 0.10032203354473625, 0.13137833029031754, 0.1729151364415884, 0.12531373357134207, 0.22693012016160147, 0.12865760842604296, 0.16147221332149847, 0.17296472378075123, 0.21838596649467945, 0.16364712161677225, 0.14983726479113102, 0.1939147367541279, 0.16192305912928923, 0.13811393028923444, 0.13258614976491245, 0.17120176766599926, 0.21349053989563668, 0.09289214294403791, 0.15261602854090078, 0.28646182428513256, 0.21821557278079645, 0.17132272331842355, 0.16357674396463803, 0.32481764469827923, 0.11681219190359116, 0.2932153647499425, 0.10194183234125376, 0.24246642791799136, 0.19427712873688766, 0.22910235502890178, 0.09883631326790367, 0.3079080634883472, 0.1571458876132965, 0.22474724586520875, 0.21868433191307954, 0.26454685309103554, 0.22137374617159367], [0.04214067517646721, 0.15618367067405156, 0.11187490647924797, 0.10413787700235844, 0.027302766551396677, 0.1347917007016284, 0.05238589917176536, 0.09369605766343218, 0.09266642827008452, 0.06830273275928837, 0.112576532044581, 0.20768286367612226, 0.14953224972954818, 0.1735757581357445, 0.07395342990223851, 0.07307657266833953, 0.1170849222689867, 0.07304529220397983, 0.10834870247968606, 0.06977831572294235, 0.03664694693205612, 0.028655103806938444, 0.022804196425048367, 0.05864888256681817, 0.009670382698199578, 0.020992187317460775, 0.0637850466051272, 0.013741479155474474, 0.040114220165248425, 0.052893355156161954, 0.04466562272448625, 0.019703111578045145, 0.06571327349437134, 0.07677191509199993, 0.009607837884686887, 0.08928444010338613, 0.05094105384445616, 0.051984145372573815, 0.11790410402630057, 0.008020978570649666, 0.04103337727220995, 0.0409986125305295, 0.0598082546410816, 0.03791411107938204, 0.02741782064549625, 0.07485847348081213, 0.13308644720486232, 0.04872179989303861, 0.06088766136339732, 0.0683381658579622, 0.08116591788296189, 0.053517495415040424, 0.051636229934436936, 0.03328006974022303, 0.03509029938972422, 0.09332785063556262, 0.02865170095381992, 0.01802881624150489, 0.05060802546462842, 0.11322296557149716, 0.04097244143486023, 0.09772438436214413, 0.07690063318503754, 0.01970636854613466, 2.345836260489055, 12.867864029748098, 39.464979376111714, 61.34063570840018, 78.2662251336234, 87.0450656073434, 75.09335803985596, 64.2564264025007, 53.17903845650809, 54.0543794631958, 43.31612614222935, 44.612329959869385, 41.825796604156494, 39.0101363999503, 29.330083302089147, 40.35374430247715, 38.486756392887656, 35.25830718449184, 35.076181003025596, 31.507023402622767, 26.838796275002615, 26.960287264415197, 32.72761344909668, 35.69354581832886, 42.587075982775005, 52.83282361711775, 49.32572732652937, 54.15693487439837, 50.116870062691824, 51.20223774228777, 51.10663052967617, 54.878373282296316, 61.50330693381173, 51.42862394877842, 33.53535195759365, 33.159266812460764, 32.41302333559309, 34.99187503542219, 36.470052174159456, 38.2825870513916, 44.41810349055699, 55.73987347739083, 52.51544032778059, 53.8678411756243, 62.08805343082973, 64.99495043073381, 75.71433244432721, 90.7110880443028, 87.77036026545933, 61.117403984069824, 45.848991189684185, 18.081140858786448, 1.1907588243484497, 1.7977065529142107, 0.04485553449818066, 0.21830808424523898, 0.04446638109428542, 0.05444075765886477, 0.02452512238440769, 0.027910835708358457, 0.0337851779934551, 0.05056794440107686, 0.03704232589474746, 0.07410913333296776, 0.022555503162688444, 0.06261337947632585, 0.10165845576141562, 0.02822436808076288, 0.029864751933408634, 0.024191434129274318, 0.02416616548517985, 0.031570768782070706, 0.0359365818356829, 0.07015902136585542, 0.0549708868909095, 0.05064791653837476, 0.028092019825375507, 0.02534124055611236, 0.02809709357097745, 0.019776635936328342, 0.014275131680603539, 0.09154624837849822, 0.07446583919227123, 0.02182330789842776, 0.033433595073542426, 0.07621479712958847, 0.02633809161904667, 0.030522547529212067, 0.03581466605620725, 0.052387283383203406, 0.07456071874392883, 0.0270541479278888, 0.029324441283409084, 0.01494451835086303, 0.05246381874063185, 0.10250245832971164, 0.08160699957183429, 0.05609952811417835, 0.08609276065336806, 0.08031750483704464, 0.0750095560880644, 0.08963729866913386, 0.06787396648100444, 0.06678070407360792, 0.11333372962794133, 0.12031879302646432, 0.1886943733053548, 0.06150343867817095, 0.08632127767694847, 0.07360722097967352, 0.12375151525650706, 0.05270769440435937, 0.041325686765568595, 0.11974069476127625, 0.17171098105609417, 0.052589958400598595, 0.07541061778153692, 0.08961542948548283, 0.0779633072337934, 0.06962044098015342, 0.12059715523251466, 0.23009342327713966, 0.09038256760686636, 0.18412490135857038, 0.14622075456593717, 0.18249256323490823, 0.04991720896214247, 0.04865750530734658, 0.09294223239911453, 0.10817767772823572, 0.1779898048511573, 0.08137838755335126, 0.040168038170252524, 0.08140756455915314, 0.015051156914393817, 0.009344027710280247, 0.039794592852039, 0.036738790039505274, 0.05491953196802309, 0.022578575049660037, 0.025710908130609562, 0.04998143230165754, 0.031059122843933955, 0.03518357759873782, 0.022662504742454206, 0.015326065377199223, 0.021412524494475553, 0.021021109872630665, 0.024942075368016958, 0.03794648398512176, 0.06283395764018808, 0.013869357561426503, 0.06794129751090493, 0.02872133900278381, 0.038334907963871956, 0.03035387729427644, 0.020722530715699707, 0.08167962317488023, 0.021788310758503418, 0.10056356486997434, 0.05336749507114291, 0.0694403713569045, 0.04364333847271545, 0.10880541083003793, 0.03113874214302216, 0.07518264358597142, 0.06277422620249645, 0.11982290606413569, 0.00521865947770753, 0.009095001965761185, 0.094012933517141, 0.03524226409250072, 0.034247144990201504, 0.08471002842166594, 0.10532606645886387, 1.270740298288209, 8.436366370746068, 31.55965600694929, 64.59271921430314, 78.86235277993339, 88.97627571650914, 94.88554491315568, 91.27918665749687, 78.56357329232353, 67.96007333483014, 58.14189004898071, 49.72508198874337, 42.0476838520595, 38.77378647668021, 41.35882207325527, 32.24761799403599, 40.54554237638201, 35.497756004333496, 30.61454119001116, 38.959352016448975, 30.320611545017787, 30.99487168448312, 38.71584892272949, 36.425368309020996, 47.45672443934849, 49.63123614447457, 52.284919943128315, 53.543388094220845, 49.38537413733346, 44.08883530752999, 47.42612109865461, 61.927015032087056, 63.8831205368042, 91.6215591430664, 65.51402950286865, 47.83787482125418, 49.45445312772478, 43.31536878858294, 48.39834778649466, 42.672597885131836, 48.900626114436555, 43.73802770887102, 38.45237670625959, 48.718069144657676, 59.28588662828718, 60.53066335405622, 69.05952153887067, 77.46191556113106, 92.1710296358381, 92.45507894243512, 80.16972582680839, 66.28291021074567, 38.633057662418906, 10.48945483139583, 7.3291118655885965, 1.2488064638205936, 0.15819159150123596, 0.1420330942741462, 0.04000767320394516, 0.08806278529976096, 0.02356527522871537, 0.12564407155982085, 0.06657102996749537, 0.04378467731709991, 0.02163590331162725, 0.12574524113110133, 0.057664653951568265, 0.03750925976783037, 0.0179126917584134, 0.0063559189438819885, 0.05455586773210338, 0.025942790687882473, 0.06020139104553631, 0.022931342013180256, 0.04413750195609672, 0.04466299679396408, 0.015090990312663572, 0.014252719668937581, 0.05557715114472168, 0.032872212518538745, 0.08188642029251371, 0.0427521539718977, 0.05097726386572633, 0.14608130204890454, 0.026888308880318488, 0.023736920839707767, 0.03685736742668918, 0.03457731334492564, 0.02200877696408757, 0.043562701371099265, 0.035250830597111156, 0.021656897185104232, 0.007238780364527234, 0.02238735879239227, 0.09156903358442442, 0.16529973436679157, 0.11720617647681918, 0.16930195103798593, 0.19169376950178826, 0.05548312993986266, 0.13817959890833922, 0.131264132846679, 0.08743917090552193, 0.056530092510261705, 0.10968887699501854, 0.09054087661206722, 0.07102532738021441, 0.10532103851437569, 0.0369391410744616, 0.1943788682775838, 0.1271633928907769, 0.09262763642306839, 0.10671643899487597, 0.15382197525884422, 0.20919940301350184, 0.23283701177154267, 0.2914761166487421, 0.10632157232612371, 0.19711530501289026, 0.13189947232604027, 0.136896814884884, 0.14328325433390482, 0.3286297358572483, 0.25079587953431265, 0.3011071341378348, 0.2730050635124956, 0.30597972124814987, 0.10562041494995356, 0.16064617836049624, 0.1784691491297313, 0.1545195092580148, 0.2655308374336788, 0.13026361939098152, 0.2018574234098196, 0.122691453567573, 0.1140152027032205, 0.1564909384718963, 0.14241927569465979, 0.12079706521970884, 0.15525827104491846, 0.07389154750853777, 0.10449935974819319, 0.12078301954482283, 0.21294901466795377, 0.16755974452410424, 0.1955817344465426, 0.2301524015409606, 0.1836570514632123, 0.16401785958026135, 0.16056328852261814, 0.15260851037289414, 0.3332604659455163, 0.11108935291745833, 0.14154733105429582, 0.15588044694491796, 0.1390122699418238, 0.19772604081247533, 0.1277209044034992, 0.21419526636600494, 0.28795679977961947, 0.17292059186313832, 0.15728554369083472, 0.14506796428135463, 0.16711249495191233, 0.2364711639072214, 0.1484120562672615, 0.15687521999435766, 0.12755398478891167, 0.2066890677171094, 0.12201453346226897, 0.12238166161945888, 0.11169678425150258, 0.27387847378849983, 0.11758562682994775, 0.2642599956265518, 0.1524706727692059, 0.3680729222084795, 3.2333479055336545, 17.76675919124058, 53.153823443821494, 85.29524517059326, 107.31178665161133, 120.88321658543178, 112.65510422842843, 102.25069100516183, 94.43163994380406, 86.15451499394008, 76.81292601994106, 75.23157855442592, 76.3474314553397, 73.92556040627616, 64.7544663293021, 84.43479415348598, 71.8722287586757, 68.03232070377895, 74.52153519221714, 67.91281168801444, 63.67228439876011, 63.903492655072895, 70.0369941166469, 80.6500825881958, 82.81592641557965, 84.46412944793701, 78.47874968392509, 83.08660738808769, 82.64072063991001, 81.78259032113212, 81.4596311024257, 86.21381092071533, 87.76102883475167, 79.755446434021, 68.61866528647286, 64.47526686532157, 62.77990640912737, 65.3092382975987, 63.62418896811349, 70.23426042284284, 70.20111751556396, 79.23336574009487, 74.28120395115444, 80.16794013977051, 79.22768211364746, 84.78842272077287, 97.0933141708374, 115.91675540379116, 112.03028747013637, 89.22998918805803, 65.45195429665702, 34.89119216373989, 8.010126522609166, 3.854224383831024, 0.6085095533302852, 0.364136414868491, 0.2722396217286587, 0.15960108515407356, 0.15400194988719054, 0.11135485688490526, 0.23644554242491722, 0.2951392558004175, 0.13357712301824773, 0.20308226054268225, 0.20009562080459936, 0.09644494551633086, 0.25491369143128395, 0.14291505409138544, 0.10482200314956051, 0.069887532719544, 0.1550728002829211, 0.15182668875370706, 0.127445677029235, 0.13536650128662586, 0.17188733230744088, 0.10918494260736875, 0.1626521721482277, 0.125485945759075, 0.11998602588261877, 0.2374886135969843, 0.08724346105009317, 0.130173727071711, 0.2168235174779381, 0.08470867135162864, 0.1311326599014657, 0.11096960505736725, 0.11455002400491919, 0.10589447524398565, 0.12488537441406931, 0.11609369117234435, 0.1743628451866763, 0.10273535868951253, 0.09453840460628271, 0.1661372637110097, 0.2541979726936136, 0.40917716228536194, 0.24033381949578012, 0.19842658750712872, 0.13937664324683802, 0.3810426305447306, 0.18504517126296247, 0.19378354879362242, 0.18577011807688645, 0.21014840209058352, 0.24640665362988198, 0.2837773769029549, 0.2511040972811835, 0.19997971345271381, 0.2413753436080047, 0.2745328258190836, 0.21054149099758693, 0.22682896416102136], [0.13778428440647467, 0.08100162419889655, 0.08646979542183024, 0.02095825208484062, 0.04529823110039745, 0.07491268842880215, 0.07468833082488605, 0.04943506572661655, 0.1352861084576164, 0.07436274936688797, 0.07064544276467391, 0.10907306575349399, 0.1540003214031458, 0.08069244971764938, 0.17796958450760159, 0.15299207264823572, 0.1882936983768429, 0.13101122927452835, 0.1301952094904014, 0.22474538667925767, 0.07862922150109496, 0.07420460999544178, 0.04390695611281054, 0.047603000820215256, 0.01788288032236908, 0.021852718998811076, 0.02607133745082787, 0.046485803090035915, 0.040613733897251744, 0.05925480755312102, 0.029427307192236185, 0.0384570306965283, 0.1122944921787296, 0.016004193274836456, 0.07172844572258846, 0.017736893513106873, 0.009294172349785055, 0.0718103584700397, 0.06357687884675604, 0.11647687346807548, 0.016664255177602172, 0.09175268587257181, 0.054885618787791045, 0.03181137051433325, 0.1022670813170927, 0.05056306573429278, 0.0954879465113793, 0.1250985972583294, 0.02554230235650071, 0.025769462310043827, 0.0989689804347498, 0.010523057792202702, 0.05666356034842985, 0.10958368371107749, 0.037906762545130084, 0.026646769073392664, 0.044505064375698566, 0.07615364755370788, 0.043181985550160916, 0.03626089782587119, 0.01964974819150354, 0.2851154479597296, 0.13406907447746821, 0.04100053617730737, 0.17171578508402618, 0.30989237129688263, 0.19773870227592333, 1.8478045846734727, 11.60615541253771, 28.1877212865012, 40.37632942199707, 62.43729073660714, 65.8936790738787, 66.87645312717983, 70.64254352024624, 62.35437788282122, 77.81509944370815, 72.80944347381592, 73.31567532675606, 68.20886053357805, 50.00244018009731, 57.30549716949463, 61.27730287824358, 49.375580651419504, 37.80824048178536, 30.23884514399937, 24.29535606929234, 23.64113974571228, 38.630486828940256, 60.81222520555769, 71.15277058737618, 68.4414792742048, 65.67572103227887, 68.89507157461983, 65.18647752489362, 65.8244958605085, 69.99293558938163, 76.44984095437187, 80.93953759329659, 79.78985391344342, 66.63600376674107, 63.63664708818708, 57.59470551354544, 59.136305809020996, 56.795499392918174, 54.97723920004708, 61.07952240535191, 75.21529197692871, 84.35279846191406, 75.78937993730817, 60.079933711460654, 42.19572911943708, 14.745649439947945, 4.690147391387394, 0.8336765680994306, 0.1475789374006646, 0.10292289898331676, 0.2189361633999007, 0.06392398343554564, 0.04622542206197977, 0.02119563756111477, 0.026694280095398426, 0.030028143165899173, 0.0320905232136803, 0.025738694139623215, 0.08315984053271157, 0.03950395594750132, 0.05387250493679728, 0.037530908427600346, 0.034930412790605, 0.01705509134834366, 0.02638857632077166, 0.021361671687502946, 0.07824135731373515, 0.03587398358753749, 0.02990651237113135, 0.06281411049089261, 0.08564973156899214, 0.0349543074012867, 0.03855042764917016, 0.04418947773852518, 0.022239533153229525, 0.030349100407745157, 0.054065181740692685, 0.030616446597767726, 0.02954311276386891, 0.01331129389083279, 0.012465599225834012, 0.03915230178141168, 0.05089850630611181, 0.03607281470405204, 0.02004449950930263, 0.026501888276210854, 0.03849447565153241, 0.019874458633629338, 0.05764030132974897, 0.03409184528780835, 0.07756958050387246, 0.01671673816495708, 0.004882137490702527, 0.10006693830447537, 0.07489203382283449, 0.024264205313686813, 0.15376828956816876, 0.23479461244174413, 0.12568513649914945, 0.17669503789927277, 0.17448039459330694, 0.1772582491061517, 0.08853916438030345, 0.10937130225024053, 0.07595440931618214, 0.0362625500586416, 0.1802231485822371, 0.06692719299878393, 0.052097986585327556, 0.0873715141788125, 0.05240213990743671, 0.049967956596187184, 0.06115066832197564, 0.0599572609311768, 0.07481352732117687, 0.04800937883555889, 0.04980206496215292, 0.14328322719250405, 0.04653284592287881, 0.024371810789619173, 0.10961375638310399, 0.12598431615957192, 0.045521798211016824, 0.14730278721877507, 0.06501535951559033, 0.1396494007536343, 0.07905576218451772, 0.054451397087957175, 0.059069370717874596, 0.06823355611413717, 0.03478932161150234, 0.015908636884497743, 0.0191579799367381, 0.03395679307037166, 0.10921663697808981, 0.07920858184141771, 0.08342446240463428, 0.021293562038668563, 0.04227167993251767, 0.046996760315128734, 0.032281744559960704, 0.06011659452425582, 0.07985534106514283, 0.04964922494920237, 0.0262656088120171, 0.06832319059010063, 0.0711739401199988, 0.04807485407218337, 0.09436321364981787, 0.045262323027210574, 0.047400132420339754, 0.044278942580733976, 0.06846355912940842, 0.0673507209867239, 0.03763173533869641, 0.014278344543916839, 0.1356759268258299, 0.03873489757201501, 0.025386173145047257, 0.05902913359126874, 0.04509248910471797, 0.06767464681927647, 0.10412291530519724, 0.042110656787242205, 0.041454547350960116, 0.04938034866271274, 0.12408375314303807, 0.0761882256982582, 0.028808428972427334, 0.035322497465780804, 0.10231953207403421, 0.005359952520978237, 0.07894347820963178, 0.10026013079498496, 0.7018325456551143, 1.8366114710058485, 10.326780131884984, 29.794459206717356, 52.18274668284825, 62.17437785012381, 77.2989525113787, 79.73016193934849, 80.42036819458008, 76.81678921835763, 77.5212323325021, 85.769056728908, 79.07049301692417, 73.62846933092389, 78.28781318664551, 72.36326490129743, 73.28952925545829, 70.80889729091099, 64.48222896030971, 57.452298709324424, 53.423917293548584, 56.61654159000942, 55.331545216696604, 66.06973947797502, 80.76089940752301, 80.05179405212402, 77.49000712803432, 71.61588191986084, 75.2621158872332, 71.68013886043003, 69.96373925890241, 68.48881040300641, 78.3611444745745, 81.15780830383301, 84.61099352155412, 71.9158912386213, 71.10607174464634, 68.06674207959855, 67.52242715018136, 67.4233249936785, 70.84846728188651, 73.09570230756486, 80.5062757219587, 89.30055509294782, 85.36330277579171, 80.42120892660958, 65.44558279854911, 36.76537493297032, 14.624549286706106, 4.176724587168012, 0.6631035581231117, 0.5017048844269344, 0.16228192272995198, 0.26143321873886244, 0.0984936598688364, 0.011298312888746815, 0.031051709848855222, 0.1107249931831445, 0.12212778095688138, 0.052708522217082124, 0.043444001847612004, 0.01584860180238528, 0.06467442281012024, 0.017076314227389436, 0.08231061324477196, 0.013624384367306317, 0.04491003782355359, 0.05105510201039059, 0.07598994419510875, 0.03610667699415769, 0.0430322905470218, 0.0505512083348419, 0.03587372235155531, 0.03688996424898505, 0.011873216102165835, 0.02717637922614813, 0.01249122410081327, 0.028725552705249617, 0.01963921563167657, 0.009938123286701739, 0.08058028109371662, 0.07251632665949208, 0.01098649127275816, 0.026263998987685357, 0.041998824038143666, 0.04965549122009959, 0.10615486984274217, 0.025532970803656747, 0.0490509368745344, 0.019389940525538156, 0.05678825472880687, 0.011688551100503122, 0.06953407704297986, 0.030400825132216727, 0.05630816745438746, 0.1204446612724236, 0.09997618424573115, 0.15614195434110506, 0.13332824994410786, 0.13314879100237573, 0.14067055524459907, 0.1130072253623179, 0.12276678452534334, 0.042343455366790295, 0.08397786878049374, 0.11680103678788457, 0.15020444723112242, 0.1852327183421169, 0.19021953003747122, 0.14033922659499304, 0.1208404643195016, 0.17998416854866914, 0.1563783830830029, 0.21425143549484865, 0.14436867966183595, 0.22089974874896662, 0.17110888979264668, 0.22664151207676955, 0.09638679506523268, 0.21773704274424485, 0.1718370257211583, 0.1565777909542833, 0.13375964893826417, 0.2442949983690466, 0.1011673321149179, 0.24293963823999676, 0.29170603145446095, 0.26376374225531307, 0.2517527767590114, 0.2947772980800697, 0.268797549286059, 0.14147799834609032, 0.1433882779840912, 0.11261389896805797, 0.12543110655886786, 0.10163098866386072, 0.18755956419876643, 0.11013408417680434, 0.15508246262158665, 0.09896521456539631, 0.18852345033415727, 0.17479317209550313, 0.11962100118398666, 0.23355853876897267, 0.11068208262856517, 0.1557929159275123, 0.07799302028226, 0.17970841191709042, 0.3110251990812165, 0.13265404397887842, 0.22638377733528614, 0.15401728477861198, 0.20222763211599418, 0.16685671439128263, 0.20741029615913117, 0.15881918211068424, 0.14384551559175762, 0.20294891484081745, 0.1794512335743223, 0.2158041000366211, 0.14043872697012766, 0.16409865953028202, 0.20559725058930262, 0.1550326852926186, 0.3491719492844173, 0.09835381380149297, 0.15261137379067286, 0.10977885752384152, 0.2019554174372128, 0.16471072525850364, 0.1698511844234807, 0.09626276564917394, 0.435684187071664, 0.19523311672466143, 0.11495145889265196, 0.2572088497025626, 0.4668421894311905, 0.39846949971147944, 3.4233982903616766, 15.63910266331264, 38.10212843758719, 58.85117258344378, 89.92593465532575, 100.02047211783272, 105.54598535810197, 113.75779029301235, 109.04866259438651, 121.93635504586356, 112.27940818241665, 110.0162478855678, 108.0861564363752, 100.00101716177804, 102.77953229631696, 107.7823464529855, 102.17947891780308, 94.69424016135079, 90.25137438092912, 79.34095859527588, 87.00425188882011, 103.72892720358712, 116.20744024004254, 115.96463544028146, 109.64707619803292, 101.97606345585415, 103.37438842228481, 101.76230907440186, 98.77027579716274, 107.66164234706334, 111.7756290435791, 118.75659533909389, 118.80669185093471, 105.73678983960832, 102.25902189527238, 95.10920742579869, 95.28061253683907, 92.35065446581159, 92.43614510127476, 98.64569459642682, 106.45327418191093, 114.3474144254412, 104.3070729119437, 85.47370270320347, 59.75172165461949, 26.314104795455933, 8.458256670406886, 1.6110857554844447, 0.19811351144952433, 0.2950335943273136, 0.38690734441791264, 0.33165825477668215, 0.18307413559939179, 0.07766939300511565, 0.1113314474267619, 0.254213741847447, 0.16336597741714545, 0.19556384826345102, 0.15392513972307953, 0.13563935378832476, 0.1792044232466391, 0.09979449292378766, 0.235725643911532, 0.09391455951013736, 0.09757631445037467, 0.15299300902656146, 0.18851232235985144, 0.11746537685394287, 0.13586074619420938, 0.1633267988051687, 0.15775282361677714, 0.1490449123084545, 0.1588214619883469, 0.12843487252082142, 0.14468125360352652, 0.12886985417987618, 0.16698982939124107, 0.15298127037073883, 0.15268093720078468, 0.15807051371250833, 0.12867268547415733, 0.21300500737769262, 0.12870982848107815, 0.17136457535837377, 0.18414221757224628, 0.12406714260578156, 0.2187453864940575, 0.21641197241842747, 0.10351694282144308, 0.0981283773268972, 0.2659030274621078, 0.15941759571433067, 0.12956723890134267, 0.15964147155838354, 0.14044631299163612, 0.22679617734892027, 0.29925761052540367, 0.23051197081804276, 0.21349030919373035, 0.14869260335607187, 0.17217110922294004, 0.24293597415089607, 0.12520884562815937, 0.18414384605629103, 0.1909412063126053, 0.37713901858244625, 0.34353440893547876, 0.19380148925951549, 0.19353303366473742], [0.012999941312175776, 0.03234259558043309, 0.004186210347272987, 0.05910785722413233, 0.039518853183835745, 0.10935166544680085, 0.15974668519837515, 0.023058509653700248, 0.028408922820485065, 0.03301860305613705, 0.07436717341520957, 0.09319702229861702, 0.028219828681488122, 0.05884222433503185, 0.13732136067535194, 0.13757487492901938, 0.017370523618800298, 0.09384691635412828, 0.13475591476474488, 0.02363559859804809, 0.009992266140346016, 0.06122813666505473, 0.0495226951315999, 0.01840916395719562, 0.05032536134655986, 0.02156308802243854, 0.028554321000618593, 0.07085046890590872, 0.05029700876080564, 0.04178309400698968, 0.014650359849578567, 0.05461265093513897, 0.12988297481622013, 0.022345230249421935, 0.046119329719139, 0.09892186974840504, 0.07040076982229948, 0.07662301058215754, 0.024996807698958685, 0.012275725619734397, 0.07234899313854319, 0.05935542072568621, 0.0043763579118863815, 0.05271048318328602, 0.10679610579141549, 0.03615658324477928, 0.009066499254134084, 0.03246813812958343, 0.08225194032170943, 0.058209660063896856, 0.038943126398537836, 0.03217559114896825, 0.016014267823525836, 0.0537202247152371, 0.035022853008870564, 0.07782578175621373, 0.0511969192219632, 0.012673873853470598, 0.00709959544474259, 0.035488884430378675, 0.0751177417114377, 0.029861006420105696, 0.01253332635055163, 0.04359870104651366, 0.043747948216540475, 0.045764941056924205, 0.008273627692168313, 0.04949160126437034, 0.135097543575934, 0.15694938387189591, 0.6278995871543884, 3.7347197106906345, 6.789444846766336, 15.791212626865931, 31.405378205435618, 43.65572282246181, 50.85174281256539, 58.007317338671, 67.47967488425118, 56.4558401788984, 63.68940476008824, 50.7406758580889, 59.252438000270296, 56.65180022375924, 48.7647818837847, 33.19050938742501, 19.838192633220128, 13.402612158230372, 16.685053212302073, 23.39269127164568, 38.83037608010428, 45.91269227436611, 55.23410715375628, 52.194065298352925, 54.00401891980852, 64.72178200313023, 61.85767895834786, 45.45339550290789, 39.116509846278596, 34.70838505881173, 56.02161250795637, 63.272700445992605, 60.1968024117606, 53.78015143530709, 51.73730114528111, 47.18775967189244, 48.4636469568525, 35.236288343157085, 24.620642934526714, 13.087328961917333, 3.563968381711415, 0.2917869399700846, 0.09108251719070332, 0.022287074709311128, 0.03293899393507412, 0.010331384371966124, 0.02291494860712971, 0.043026879230248075, 0.16959798229592188, 0.03242571272754243, 0.015902055094816854, 0.011719358286687305, 0.05434448032506874, 0.049547278455325534, 0.04618688127292054, 0.03409409463139517, 0.038225524726190736, 0.046659426630607674, 0.07324562966823578, 0.06645028466092688, 0.10925724051360573, 0.05487045692279935, 0.030360184277274778, 0.04379840408052717, 0.07502269252602543, 0.009766436963608223, 0.022859771835750768, 0.04622004467195698, 0.039696106886757274, 0.05547735221417887, 0.03336977206968835, 0.03278157381074769, 0.04007866493027125, 0.02227944797570152, 0.02698700688779354, 0.036800248348819356, 0.028815913213683025, 0.026108639913478067, 0.025809482305443714, 0.0565249763562211, 0.05245424121884363, 0.0671648702451161, 0.030539249668696096, 0.021865684106679897, 0.03529511857777834, 0.036239635931061845, 0.13652827537485532, 0.07500285216208015, 0.07215789732124124, 0.06144838234675782, 0.07197235870574202, 0.024594134484816874, 0.1867154123527663, 0.0336329113425953, 0.0844053661982928, 0.10079414464001145, 0.030765293432133536, 0.05487544076251132, 0.04503490862303546, 0.13131499583167688, 0.07447434802140508, 0.09502986752028976, 0.07002408789204699, 0.0499362724034914, 0.0675484189497573, 0.031062362848648002, 0.0843399486371449, 0.06025494781455823, 0.07934394957763807, 0.053994244297168086, 0.07790250371077231, 0.09668324701488018, 0.11171688924410514, 0.05634746141731739, 0.02564029299121882, 0.1100569958133357, 0.027252768698547567, 0.0692482984491757, 0.11635762772389821, 0.1085073711084468, 0.1288539764604398, 0.1955476991300072, 0.046424239607793946, 0.048764812227870734, 0.08791839304779257, 0.05530760310856359, 0.06734002048947982, 0.05302012924637113, 0.005661964641019169, 0.03571834461763501, 0.0501110765949956, 0.012240461306646466, 0.016925586154684424, 0.011221009938578521, 0.021041627075257044, 0.08441875369421073, 0.048625651480896134, 0.01460366985494537, 0.14098698326519557, 0.045656870784504075, 0.02771414876250284, 0.08399863873741456, 0.05746559213314738, 0.049527482196156464, 0.09494085051119328, 0.06609878995056663, 0.027602282086653367, 0.05839631826217685, 0.047273575461336544, 0.08636513139520373, 0.04745263406740768, 0.057807526285094876, 0.042337073744939904, 0.011863379888901753, 0.013630543768938099, 0.03730005385088069, 0.0052528012394239855, 0.022655090051037923, 0.01884032885677048, 0.04467276430555752, 0.060858090807284625, 0.10007568462086575, 0.023460629861801863, 0.07661089873207466, 0.042381076740899255, 0.036736065721405406, 0.01904276299423405, 0.03268991390775357, 0.10702784585633449, 0.0951461141396846, 0.051362793892621994, 0.021753376383068304, 0.04921700153499842, 0.20318295513944967, 0.7363974452018738, 0.8339767519916806, 3.848095638411386, 15.617806434631348, 23.98920280592782, 36.926569666181294, 54.94400596618652, 63.37381758008684, 75.75060898917062, 80.01583017621721, 88.2735904966082, 82.11848708561489, 82.24162306104387, 80.82991586412702, 86.31280190604073, 80.14993735722133, 74.32820851462228, 54.477816581726074, 34.16485527583531, 27.063803264072963, 33.27171298435756, 48.039042540958945, 62.866612979343955, 70.20134680611747, 78.45755767822266, 72.40175792149135, 78.84362043653215, 85.59594236101422, 86.69211101531982, 71.4817955834525, 64.86642265319824, 59.616780689784456, 79.6486873626709, 86.45365578787667, 81.8598403930664, 76.46320928846086, 73.20993764059884, 67.03223868778774, 70.9537602833339, 59.12098503112793, 45.243250710623606, 28.72038756098066, 10.897422654288155, 1.7290401118142265, 0.36451875578079906, 0.13222158647009305, 0.11557911735560213, 0.05039750997509275, 0.03342226693140609, 0.029633239177720885, 0.0349256935795503, 0.05030489333772233, 0.09211413469165564, 0.010328090932619358, 0.027543410692097883, 0.07805885853511946, 0.04518532965864454, 0.045445693723325215, 0.017222662356549075, 0.020995323845584477, 0.13675616814621858, 0.11677507603807108, 0.04334301548078656, 0.030509550190929855, 0.0484724450590355, 0.0383740933611989, 0.03272050565906933, 0.027061978222004006, 0.031350126157381704, 0.031025050207972527, 0.020105781399511864, 0.1249782522874219, 0.08169872393565518, 0.038226810550051074, 0.01085031607986561, 0.03811852993177516, 0.031387282735002894, 0.012366210808977485, 0.00803049247977989, 0.020744754433897988, 0.027100870152935386, 0.0280290432939572, 0.06021365895867348, 0.05382396932691336, 0.021561451056706052, 0.11342592896627528, 0.06609038968703576, 0.020544919085555842, 0.1548891072826726, 0.04325676689456616, 0.04052758030593395, 0.05571699042671493, 0.17225861309894494, 0.05136020867420094, 0.1314638935561691, 0.11051054219050066, 0.3332095758191177, 0.1455469557217189, 0.06034100641097341, 0.069197842585189, 0.03942285404939737, 0.09784582177443163, 0.1280395444482565, 0.10225154965051583, 0.06250111585749046, 0.10792148326124464, 0.18753451268587792, 0.09172140540821211, 0.2588507415992873, 0.26746631786227226, 0.2722508854099682, 0.19010212990854466, 0.23887464350887708, 0.40420591618333546, 0.29250170875872883, 0.2359412551990577, 0.1371730329202754, 0.15765064981366905, 0.20496280677616596, 0.16591759478407248, 0.16332715164337838, 0.24778378116233007, 0.38606943509408403, 0.29473658597895075, 0.14475976010518415, 0.18075608355658396, 0.1993470745427268, 0.13887177248086247, 0.12050141394138336, 0.24773777648806572, 0.12230931621577058, 0.09574768293116774, 0.13779814009155544, 0.0877261505063091, 0.10029554353760821, 0.1985289648707424, 0.1627100104732173, 0.09281979075499944, 0.20174128535602773, 0.08851422143301793, 0.2525607762592179, 0.15537868386932782, 0.12710995147270815, 0.19177386377538952, 0.1577265914529562, 0.2271603470934289, 0.18232770636677742, 0.24403506517410278, 0.1675200502255133, 0.09093132601784808, 0.1879699964608465, 0.17065713474793093, 0.18623450744364942, 0.14457736989217146, 0.13053155929914542, 0.1080207054370216, 0.15794570398117813, 0.09888801085097448, 0.06603109929710627, 0.20515143951135023, 0.10593492271644728, 0.11628475306289536, 0.15058894588478974, 0.10064507049641438, 0.19734701115105832, 0.141714712072696, 0.10563804328973804, 0.14137879652636393, 0.16440678228225025, 0.17979886063507625, 0.16384731658867427, 0.11511242096977574, 0.14572804314749582, 0.11768096100006785, 0.15400003641843796, 0.3488651971731867, 0.42479098588228226, 0.21505654443587574, 1.0130681991577148, 6.58357971055167, 12.278968589646475, 25.109288896833146, 45.307365213121685, 59.945937701633994, 72.04382841927665, 82.92371382032121, 94.07787241254533, 87.51283918108258, 97.5934316090175, 91.13959039960588, 92.12408065795898, 89.85743236541748, 89.69338539668492, 74.47528103419712, 60.502759388514924, 45.27759565625872, 36.440494537353516, 45.93366193771362, 63.06417805807931, 70.65308393750871, 79.87736647469657, 80.2938345500401, 90.57709898267473, 93.89318234579903, 88.61204419817243, 75.50948565346854, 62.21032782963344, 56.986196177346365, 80.92736434936523, 91.42356327601841, 92.01647390638078, 88.09864180428642, 86.75709751674107, 77.16401154654366, 74.44263144901821, 55.51537370681763, 33.94011231831142, 19.946740865707397, 5.463091926915305, 0.5339328008038657, 0.26585213733570917, 0.3218469098210335, 0.1703101455100945, 0.1344972707863365, 0.04831008180709822, 0.08776447416416236, 0.45724900705473764, 0.18992866921637738, 0.12178653212530272, 0.10587810219398566, 0.11928888543375901, 0.161801777780056, 0.1555215154907533, 0.2607294422175203, 0.10484122604663883, 0.15600185043045453, 0.16433420617665562, 0.3362106547823974, 0.17056736456496374, 0.09189472360802547, 0.1076174181486879, 0.15111555691276277, 0.1511910507189376, 0.11214036294924361, 0.08497875543045146, 0.1226015883897032, 0.06858173278825623, 0.33143222119127, 0.10053061520946877, 0.16866230964660645, 0.16847396189613, 0.08426436662141766, 0.1762307978102139, 0.06250900043440716, 0.11669043557984488, 0.13909229636192322, 0.20514478986816748, 0.18418020196259022, 0.12269031362874167, 0.16862740580524715, 0.12739991662757738, 0.2094246766396931, 0.19119891391268798, 0.10453579029334442, 0.30871690437197685, 0.13317487388849258, 0.11879326988543783, 0.2118844339357955, 0.2922354516174112, 0.13669451645442418, 0.21453975859497273, 0.2397194467484951, 0.35197313183120316, 0.2369245338652815, 0.273761901472296, 0.1879155779523509, 0.13623843235628946, 0.3416620594050203, 0.36523053901536123, 0.32160627416202, 0.20139132413480962, 0.16846377030014992, 0.28525172493287493, 0.18359400198927947], [0.04988388950005174, 0.010895912784950008, 0.04937964977164354, 0.022288421601323143, 0.03747966207031693, 0.06871676804231745, 0.028730007287647043, 0.02798216330951878, 0.08372086007148027, 0.06526097562164068, 0.07176190428435802, 0.03754686078588877, 0.09741637696112905, 0.05385638294475419, 0.09812575139637504, 0.020566995222387568, 0.0218892801619534, 0.022048691786559563, 0.03416686751214521, 0.011728848447091877, 0.018963094501356994, 0.07884840866816895, 0.009285043509277915, 0.04490852129778691, 0.023447601989443814, 0.033600969306592426, 0.030033164325037172, 0.018844121867524724, 0.03153918297695262, 0.030520311756325618, 0.019335669598409107, 0.046362689696252346, 0.08483778299497706, 0.017121436806129556, 0.03414720356730478, 0.01892830601095089, 0.04544046221833144, 0.025519386532583406, 0.03621560222070132, 0.04120923997834325, 0.04914197252531137, 0.04761272422703249, 0.020288439633856927, 0.0172109033446759, 0.026079959934577346, 0.06481803474681717, 0.02451860505555357, 0.08410632224487406, 0.05240660806053451, 0.1012386597160782, 0.015299634741885322, 0.0256787082512996, 0.07780754952026264, 0.012604987282039863, 0.028343562934813753, 0.059249263922018666, 0.051320365097905905, 0.03925326779218657, 0.046412114187010696, 0.04685461740674717, 0.019477580108546784, 0.04362467875970261, 0.011419991180965943, 0.05861978019986834, 0.06510100420564413, 0.031761379446834326, 0.08165577266897474, 0.016917219817904488, 0.04828966808106218, 0.023009717896846787, 0.06809539281363998, 0.09119987660752875, 0.14771391158657415, 0.07597037524517093, 0.05325159450460758, 0.4257160191025053, 0.3324349873832294, 1.99898761510849, 2.3328296669891904, 1.619186812213489, 3.549618180309023, 0.39143021457961624, 1.5821610561438968, 1.2014464565685816, 1.3887358009815216, 1.3122467739241463, 1.5616201183625629, 0.23965886714203016, 0.008939196754779135, 0.045896397038762055, 0.08050832924033914, 0.18281984781580313, 0.13654499447771482, 0.3131882058722632, 1.0750425479241779, 0.21921752473073347, 0.32351586169430185, 0.18994084213461193, 0.01752588608568268, 0.06167850071298225, 0.06558651636753764, 0.6664662691099303, 1.4150532973664147, 0.9536570842776979, 1.221430778503418, 1.525421415056501, 0.843416802585125, 0.08445638524634497, 0.1397398766130209, 0.09690200670489243, 0.0666080169113619, 0.03165483587820615, 0.07803589012473822, 0.01137983802306865, 0.03454813633912376, 0.023508627732683505, 0.03337880337078657, 0.048985580381538184, 0.0447599289140531, 0.05950323279414858, 0.028984943072178533, 0.1013699969542878, 0.05191274652523654, 0.07971647208822624, 0.01368312259936439, 0.07756236089127404, 0.025185024831444025, 0.02671375235409609, 0.04457842418923974, 0.023422530120504752, 0.06541967139180217, 0.04760550461443407, 0.05308264267763921, 0.014856977155432105, 0.047396939913077016, 0.046721366699784994, 0.08601488518927779, 0.03267146793327161, 0.012278913886153271, 0.01958686326231275, 0.004084532722897295, 0.03530259942635894, 0.05824770552239247, 0.03882517326357109, 0.021544801503685967, 0.04096710475693856, 0.01641841515499566, 0.030318376342100755, 0.0469565672932991, 0.07063655395592962, 0.039319801543440135, 0.036407746374607086, 0.0214327821574573, 0.01712756397734795, 0.03450180257537535, 0.04563832642244441, 0.01305757777299732, 0.05057371873408556, 0.03538981492498091, 0.015652493307633058, 0.057653838103371005, 0.03711985191330314, 0.028434685098805597, 0.04359125751735909, 0.009121907575588142, 0.0961992276300277, 0.0662393756210804, 0.06813935509749822, 0.05432705215311476, 0.07487378123083285, 0.006861752381415239, 0.05276061674313886, 0.01530365675820836, 0.021541061079395667, 0.022034384875691364, 0.045220549018787484, 0.025258944436375583, 0.045285691773252826, 0.0812256968181048, 0.05193180996658547, 0.10380972389663969, 0.0501965720073453, 0.025305346053625857, 0.14362295610564096, 0.10423852410167456, 0.035572188174618144, 0.036625875027051995, 0.046664661528276544, 0.03321445540391973, 0.018353147498731102, 0.06973789539188147, 0.04702431901491114, 0.045257685240358114, 0.008370977959462574, 0.06043450853654316, 0.03467540575989655, 0.07136483916214534, 0.0074601430845047745, 0.07777375169098377, 0.04727029474452138, 0.04420323842870338, 0.017380168994090388, 0.008463965246586927, 0.035405187135828395, 0.013306227778749806, 0.025444941063012396, 0.028844007956130163, 0.045818236589963944, 0.07824471606207745, 0.008384602942637034, 0.025251533137634397, 0.022509020121235932, 0.0008628488254284353, 0.011101323994807899, 0.002888660129558827, 0.13709122873842716, 0.05052904738113284, 0.06280097405293159, 0.04574068682268262, 0.03140313331303852, 0.014993489919496434, 0.026338259556463788, 0.017579185011397516, 0.04370807749884469, 0.024137337924912572, 0.07665807048657111, 0.03155735753742712, 0.008458613301627338, 0.0329909663248275, 0.011185012807670449, 0.06842879099505288, 0.04703895840793848, 0.08457721876246588, 0.022178811054410677, 0.03597938382465925, 0.03313426613541586, 0.034106427005359104, 0.028010393758969646, 0.0035734690526234253, 0.05772551175739084, 0.040350143398557387, 0.04825088980474642, 0.05636831958379064, 0.07011833640613727, 0.11115279594170195, 0.06929861182080847, 0.06724239287099668, 0.025918047908427458, 0.3780145730291094, 0.21485762510980877, 0.9733068070241383, 3.893023124762944, 3.6788761700902666, 8.302931427955627, 10.842728172029767, 9.818442974771772, 13.406115787369863, 5.52492698601314, 7.0098603793552945, 6.6701981254986356, 5.277113403592791, 4.689798678670611, 3.7650142908096313, 0.30961875883596285, 0.046350862830877304, 0.09049356915056705, 0.4116694756916591, 1.11519455909729, 1.1614606593336378, 1.8131238456283296, 3.235087126493454, 1.6828574985265732, 1.5887389374630791, 0.46302241725581034, 0.11997217019753796, 0.15143269060977868, 1.1842292547225952, 2.5105309316090176, 4.206739068031311, 3.890127028737749, 4.535157833780561, 4.863976555211203, 3.378041752747127, 0.38062611860888346, 0.35144490588988575, 0.11257737342800413, 0.05183311704812305, 0.05569922637992671, 0.058663206441061835, 0.04577808767291052, 0.08272128299410854, 0.08195351383515767, 0.07524384065930333, 0.02540975054060774, 0.036635900381952524, 0.04747053382119962, 0.037904577662370036, 0.0630415825705443, 0.03438526757859758, 0.06282402388751507, 0.02586320022653256, 0.018004826635920575, 0.011635412478686442, 0.023568735757310475, 0.04177065646009786, 0.07659300576363291, 0.03250275020088468, 0.05119269534147211, 0.04580384486221841, 0.03760488910068359, 0.02320621146022209, 0.028864167231534208, 0.062221742634262354, 0.05963052596364703, 0.0538170177356473, 0.04407625399263842, 0.01646350380698485, 0.014949883866522993, 0.0506696873344481, 0.014383810938202908, 0.06975420058837958, 0.048983025697192976, 0.04120044616450157, 0.020076921608831202, 0.02981832656743271, 0.1024711032264999, 0.026769280267347182, 0.004388514290829855, 0.019080282588090216, 0.03965604617925627, 0.03332062917096274, 0.08373814235840525, 0.09649048200143234, 0.09118220077029296, 0.03862175185765539, 0.047492104449442456, 0.004190115740389696, 0.04785943277446287, 0.04188793106004596, 0.01510011830500194, 0.02146720763162843, 0.07612193282693624, 0.07333549484610558, 0.10206800592797143, 0.029183373853032078, 0.036287455686501095, 0.062070490393255434, 0.07733759616634675, 0.025266995254371847, 0.017793425658185567, 0.012982586082736296, 0.03783474283825074, 0.06759964155831508, 0.15985155957085745, 0.18149090984037944, 0.15872170376990521, 0.141172019764781, 0.15855036010699614, 0.1214679056512458, 0.15440122703356401, 0.21167676150798798, 0.16270554571279458, 0.13508497710738862, 0.25554814881512095, 0.2444597195301737, 0.09801882784813643, 0.15856394437806948, 0.13605560788086482, 0.16285651975444385, 0.05723186396062374, 0.14477677776345185, 0.08725821240139858, 0.13317294684903963, 0.13527766748198441, 0.14358972146042756, 0.086339489556849, 0.13250810466706753, 0.12266912976545946, 0.07459845886166606, 0.06822111856724535, 0.08986717954810176, 0.1722049681203706, 0.14318189477281912, 0.15562565704541548, 0.13746795138078077, 0.13908316328057221, 0.1665425526776484, 0.15106287545391492, 0.14023387724799768, 0.11982657015323639, 0.17056927803371633, 0.195051282910364, 0.12175694799848966, 0.17508658420826706, 0.13894649275711604, 0.07879101139094148, 0.1512707650129284, 0.14574202096887998, 0.11519870348274708, 0.14999076298304967, 0.1578992921859026, 0.15955881242241177, 0.09690115853611912, 0.09289984431649957, 0.2179933525621891, 0.11792479934436934, 0.20267912931740284, 0.14949240615325315, 0.0996531540794032, 0.08458133747002908, 0.11082199654941048, 0.16170891347740377, 0.09389591336782489, 0.1212328475500856, 0.1007334700386439, 0.12006063759326935, 0.14343589757169994, 0.26141785670604023, 0.27803813772542135, 0.11379018013498612, 0.20666644535958767, 0.11795956747872488, 0.09510629770479032, 0.1748376025685242, 0.24802631671939576, 0.17704356062625135, 0.24871234276465007, 1.0444511494466235, 1.200662070087024, 3.2946073498044695, 4.524266966751643, 4.415808626583644, 6.072555771895817, 2.35571551322937, 3.271458991936275, 3.2563412317207883, 2.488883601767676, 3.1308244126183644, 4.3740981561797, 0.36535669224602835, 0.06833809121911015, 0.09707503991999797, 0.1665593667754105, 0.5351701229810715, 0.41144393065146034, 0.8321056238242558, 1.6697970564876283, 0.8069877773523331, 0.8309552084122385, 0.3228684850037098, 0.1590650967721428, 0.10395953085805688, 0.4654111862182617, 1.1796667852572031, 2.176971367427281, 2.107145662818636, 2.2288411898272376, 2.5794060357979367, 1.5187588525669915, 0.10756929644516536, 0.20376592528607163, 0.1261829233595303, 0.22289120831659862, 0.12547781690955162, 0.234155785292387, 0.14014388993382454, 0.10613956209272146, 0.15184826616730007, 0.19796620149697575, 0.10119598664875541, 0.13825513342661516, 0.12488320310200964, 0.11198734651718821, 0.27715764354382244, 0.0885120297649077, 0.19139323277132853, 0.13704630972019263, 0.1409386715718678, 0.0884475689381361, 0.13614034333399364, 0.19337080951247895, 0.24190690794161387, 0.20685577020049095, 0.12285407127014228, 0.10073714769844498, 0.15433618266667637, 0.08173748185592038, 0.12011683386351381, 0.16668960478688988, 0.118705223181418, 0.15680809931031295, 0.14724294043013028, 0.1480771042406559, 0.10473484532641512, 0.11566500631826264, 0.08444681111723185, 0.16425875308258192, 0.2018726904477392, 0.17000931022422655, 0.0836141129423465, 0.13825412919478758, 0.27396605908870697, 0.1344537902623415, 0.13327042518981866, 0.07725140186292784, 0.12789991551211902, 0.07457338020737682, 0.11950011338506426, 0.1656214685312339, 0.17870036672268594, 0.07636712824127503, 0.11028768414897577, 0.1306541162942137, 0.10857698201600995, 0.11922837368079595, 0.2121982020991189, 0.10195730293967895, 0.18543104055736745, 0.18590430516217435, 0.16152261490268366, 0.2119735527251448, 0.23832958989909717, 0.15134140050836972, 0.16781849706811564, 0.058736420369574, 0.11460301758987562, 0.13097906671464443, 0.11423803360334464], [0.03351941618270107, 0.032463398562478166, 0.07464565775756325, 0.013332312361204197, 0.03428567899391055, 0.041147757920303514, 0.026392174252708043, 0.015369289754224675, 0.016250067224193896, 0.08912027534097433, 0.02747566405949848, 0.05007014396999564, 0.015876567623178874, 0.05084270019350307, 0.021510203003085086, 0.03032821849254625, 0.02844411673556481, 0.11736211739480495, 0.04821427266246506, 0.034718017759067674, 0.04616798407265118, 0.01994137236449335, 0.019295150879770517, 0.07452887509550367, 0.03811279631086758, 0.024260641308501363, 0.019073239394596646, 0.06303139097456421, 0.011820889177865215, 0.05814378788428647, 0.0058806713204830885, 0.010370460355521312, 0.05855824385902711, 0.05889187952769654, 0.035390781837382486, 0.017864469970975603, 0.037721125542053154, 0.02650990347111864, 0.005199387810924756, 0.015931050592501248, 0.018669731582381895, 0.03115252318925091, 0.06743018422275782, 0.09138433635234833, 0.036583497122462304, 0.039243177976459265, 0.034732758932347806, 0.0347673031501472, 0.10395925265869924, 0.014053235462467586, 0.08893065194466285, 0.05735821396644626, 0.06585498553301607, 0.048370664806238244, 0.03406155548457589, 0.02590726429064359, 0.021677604377535836, 0.01746084341513259, 0.02232941529447479, 0.04179572493636182, 0.012947472743690014, 0.05581929993682674, 0.0064239446240078124, 0.0224415126722306, 0.024281312877844487, 0.033873553786958964, 0.10313330590724945, 0.03096892179122993, 0.04723621193053467, 0.07247548563671963, 0.09919709033731904, 0.03170290329892721, 0.029344458066459213, 0.03166424376623971, 0.05830915365368128, 0.013731698921349431, 0.07148696189480168, 0.07581304333039693, 0.11168455026511635, 0.09282855064209018, 0.025298382587996975, 0.03861912592713322, 0.07794901050095047, 0.029366581700742245, 0.1407563356416566, 0.06804931350052357, 0.24258015038711683, 0.07308212308479206, 0.03867333748244813, 0.10939312393644027, 0.048945587527539046, 0.023846083553507924, 0.09361073867018734, 0.04010043911901968, 0.09092451352626085, 0.03473207700465407, 0.040165181537824016, 0.032852663924651485, 0.04050959234258958, 0.06111474667808839, 0.03448012677420463, 0.04239128530025482, 0.0063975720882548815, 0.03367352505613651, 0.08177574444562197, 0.15432075278035232, 0.057733572753412385, 0.051283361190663915, 0.0850768783794982, 0.01801883668771812, 0.05941428363855396, 0.030812173416571956, 0.08005041309765407, 0.03268018371558615, 0.018088914088106582, 0.06934361226324524, 0.045599602428930144, 0.019158867121274983, 0.03748405558456268, 0.025894796209675924, 0.03520912444218993, 0.02622130047529936, 0.006942243173918021, 0.016880551785496727, 0.016696243014718806, 0.025365511753729413, 0.007009439344983548, 0.02929535587983472, 0.026206711972398416, 0.008292474850480045, 0.0076607757114938325, 0.011347824740888817, 0.06752513841326747, 0.025562933213742714, 0.011572540272027254, 0.08694977752332177, 0.03805858814822776, 0.037421260561261854, 0.03829024339626942, 0.06158369580017669, 0.06318761687725782, 0.051724951780800305, 0.019982852906520878, 0.03275682085326739, 0.02564200629214091, 0.04148647581626262, 0.03543400791074548, 0.06025761445718152, 0.061152703927031586, 0.025160716314400946, 0.05347748559766582, 0.057069395535758564, 0.04360889942784395, 0.034520075523427556, 0.07763340350772653, 0.08300475456884929, 0.037951023384396515, 0.053327933086880615, 0.007861485521841263, 0.04716121345492346, 0.04446936325569238, 0.05991521890142134, 0.0525640010434602, 0.020428708089249473, 0.04486694745719433, 0.019653671820248877, 0.07963788416236639, 0.0521598655863532, 0.012501973791846206, 0.02799055678769946, 0.026267776731401682, 0.05236038964773927, 0.008944584322827203, 0.03350019667829786, 0.014205899904482067, 0.014028591918759048, 0.05946543160825968, 0.025676477567425797, 0.025445110696767057, 0.0812252489849925, 0.04485316641096558, 0.05837055428751877, 0.010928967618383467, 0.008215053156683487, 0.039161407721361945, 0.044325021893850396, 0.03308586623253567, 0.03403748784746442, 0.02363625168800354, 0.0339032057672739, 0.013716371663446938, 0.02862212700503213, 0.023588109628430436, 0.13895644008048944, 0.027140274377805845, 0.04052611806296876, 0.044534655287861824, 0.03080553395141448, 0.03931743684890015, 0.04588973721755402, 0.08339080028235912, 0.013678419503516384, 0.012602324880260442, 0.042396099506212134, 0.01243497439593609, 0.029697896779647896, 0.05264162884226867, 0.046881263476929495, 0.042377538180777004, 0.009649865495573198, 0.07063071855476924, 0.01846317873735513, 0.025379811879247427, 0.0459534075510289, 0.014130965889697629, 0.05174406611227563, 0.022712567056130086, 0.026513272397486225, 0.029565691016614437, 0.07463003109608378, 0.018103719722213488, 0.04805700181584273, 0.04419686359220317, 0.05477002016933901, 0.007534835371188819, 0.042521475814282894, 0.05473784064607961, 0.004985537745856813, 0.009172833325075251, 0.024993761076724956, 0.04125697830958026, 0.018297741721783365, 0.02105675670983536, 0.04361748289582985, 0.02254953883987452, 0.01396514380550278, 0.03686814256278532, 0.07145639389221158, 0.00916142460690545, 0.024547754919954708, 0.04780396592936345, 0.050980354592736275, 0.11056076056723084, 0.043912947577025206, 0.039272266772708724, 0.05976295564323664, 0.09818975760468415, 0.02720551721618644, 0.057594086309628825, 0.05349856089534504, 0.019132304171632444, 0.017389468316520964, 0.0731367247977427, 0.10561544807361704, 0.10981002942259822, 0.024058877224368707, 0.029875645813133036, 0.03734612298597183, 0.14840160682797432, 0.10890151853007929, 0.16356894081192358, 0.18581119658691542, 0.291546955704689, 0.01627221460720258, 0.02914698401998196, 0.08478925417044333, 0.07180427201092243, 0.0624154033139348, 0.1194390452333859, 0.08241364878735372, 0.12534459334399017, 0.07017826461898428, 0.0196262997175966, 0.023682476886148964, 0.054449751640536954, 0.03997978202200361, 0.057470952559794695, 0.05128389384065356, 0.07007657936108963, 0.17380285023578576, 0.16891127771564893, 0.2908850855060986, 0.14707000899527753, 0.05498904788068362, 0.04659392085990735, 0.03338599244930914, 0.03753542068547436, 0.07241215117807899, 0.051019248220005205, 0.027501953898796012, 0.02162775071337819, 0.01494130548754973, 0.018903975441519703, 0.046245018153318336, 0.023408323293551803, 0.025784418918192387, 0.02228411629662982, 0.03711338547457542, 0.08065257221460342, 0.04509103025442787, 0.0267090772478176, 0.024308186257258058, 0.024566292496664182, 0.042403431077088626, 0.028017915319651365, 0.02988907741382718, 0.035374205226876905, 0.018346199300140142, 0.064109854533204, 0.040612387005239725, 0.04495949963373797, 0.07089373908404793, 0.013198388208236014, 0.0235221085271665, 0.012233047463398958, 0.0203704338055104, 0.05971815876130547, 0.004374878705545727, 0.04194104678130575, 0.014708907243662646, 0.05051722390843289, 0.07421199245644466, 0.057046311774424145, 0.008756553787471992, 0.022918208967894316, 0.004856178013142198, 0.010592358269994813, 0.04429547508646335, 0.017435457723747407, 0.01997547723086817, 0.014346803638285823, 0.054245821333357265, 0.01426752021403185, 0.054352870410574336, 0.041431314311921597, 0.02871780044266156, 0.0202556697851313, 0.09450832514890603, 0.011703221875775074, 0.03429702749209745, 0.0319404685869813, 0.00881130138545164, 0.03776880619781358, 0.07224785070866346, 0.03352102431069527, 0.08130173345229455, 0.01984449283086828, 0.05131235499201076, 0.04808912705630064, 0.017816163366660476, 0.04439317734379854, 0.03895561483555606, 0.07010952223624502, 0.17257683245199068, 0.18379197136632033, 0.18267545556383474, 0.1182877884379455, 0.18847120313772134, 0.11197200484041657, 0.14936794926013264, 0.16407611859696253, 0.15932402573525906, 0.15139067572142395, 0.14993106547210897, 0.08146456150071961, 0.20791394556207315, 0.10817446825759751, 0.14845139772764274, 0.08628891155655895, 0.2549110587154116, 0.1798762543393033, 0.07918545058263199, 0.14056231533842428, 0.10373779239931277, 0.12250097521713801, 0.18549957259425096, 0.22333558090031147, 0.13742966843502863, 0.10289455657558781, 0.1521512863359281, 0.12904517405799457, 0.14371454476245812, 0.09401739827756371, 0.11667295651776449, 0.18984990487141268, 0.09053886136306183, 0.15603811134185108, 0.07173257800085203, 0.09305804475609745, 0.07191472394125802, 0.06120857450046709, 0.11415005475282669, 0.0926808403538806, 0.19994411750563554, 0.12667344989521162, 0.21216701662966184, 0.08944625034928322, 0.0843653054907918, 0.12620987477047102, 0.10379622104976859, 0.18667206753577503, 0.10295105818659067, 0.24257643201521464, 0.10987235964941126, 0.07677161653659173, 0.15522990828113897, 0.1031501471464123, 0.1112210497792278, 0.08428635115602187, 0.15213865201388085, 0.16406679552580627, 0.13682719719197067, 0.15535747286464485, 0.21897840899016174, 0.09049243599708591, 0.13426456041634083, 0.1062111339664885, 0.1353090429412467, 0.27497935614415575, 0.13791984213250025, 0.1822318293686424, 0.1323231224502836, 0.18174632399209908, 0.13965580612421036, 0.09706890596342937, 0.15461447701922484, 0.14572633323924883, 0.09384617675095797, 0.12503068947366305, 0.23384143358894757, 0.20288843022925512, 0.23787185017551693, 0.24304065853357315, 0.21630580882940972, 0.23291080924017088, 0.14543772515441689, 0.2145757209509611, 0.22932301461696625, 0.36265636714441435, 0.14786899755043642, 0.19379454106092453, 0.28075569761650904, 0.10354975677494492, 0.17840272055140563, 0.17002833634614944, 0.15324736466365202, 0.16944681826446736, 0.11915093926446778, 0.11952573486736842, 0.10079831763037614, 0.15794434691114084, 0.08563227964831249, 0.16153177512543543, 0.12342653769467558, 0.11742762316550527, 0.24047536190067018, 0.18174367770552635, 0.2662859654852322, 0.13188454455563, 0.13489083466785295, 0.13105445195521626, 0.14440993459096976, 0.118666071710842, 0.15069201535412244, 0.16515999686505112, 0.10869206155517272, 0.11185393296182156, 0.08033250046095677, 0.12554393336176872, 0.08052356913685799, 0.06516628605978829, 0.10518897524369614, 0.08923120903117315, 0.24789880641869136, 0.20602408982813358, 0.17759772017598152, 0.1094552098906466, 0.16466503271034785, 0.1546037154538291, 0.07821013113217694, 0.12513115336852415, 0.10670341112251792, 0.09922630126987185, 0.14481455859329018, 0.14923939401549952, 0.10742050728627614, 0.14519039914011955, 0.19988940044173173, 0.11513245132352624, 0.12735058713172162, 0.09197189339569636, 0.11313788406550884, 0.21552003813641413, 0.11709971433239323, 0.0919434084956135, 0.12819076276251248, 0.09798372723162174, 0.1205168573984078, 0.1552096472254821, 0.13890461357576506, 0.17273441542472157, 0.13698410162968294, 0.09449656613703285, 0.13577575289777347, 0.14561973538781914, 0.16176449906613144, 0.20264166061367306, 0.13601427152752876, 0.07932391922388758, 0.12607813041125024, 0.14192515292337962, 0.1725552278969969, 0.10980544931122235, 0.20984736324420997, 0.12430823966860771, 0.12974881487233297, 0.13405330532363482, 0.20366783626377583, 0.08995099219360522, 0.13667468966117927, 0.0894218570153628, 0.18722942977079324, 0.09762763205383505, 0.16646906733512878, 0.07074499063725982, 0.10631765039371592, 0.1341236558343683, 0.1833388592515673], [0.11695933900773525, 0.06771697383373976, 0.04294417938217521, 0.04748526820912957, 0.06142449112875121, 0.05969902407377958, 0.030175999339137758, 0.05590732289212091, 0.035444640554487705, 0.038434428695057116, 0.03481629337849362, 0.059326501563191414, 0.02836184436455369, 0.025490701464670043, 0.03194881117503558, 0.008655400331398206, 0.07311462491218533, 0.018202039446415644, 0.02614131985631372, 0.02258585742674768, 0.060535460976617675, 0.1101231054802026, 0.021344014509980167, 0.00843149225693196, 0.05106758026938353, 0.06239840601171766, 0.036521221178450754, 0.04444958735257387, 0.012808096561846989, 0.053290287964046, 0.027946988054152046, 0.04004879921142544, 0.04536100237497261, 0.06331985656704221, 0.03877093456685543, 0.01294045923610351, 0.0329946304139282, 0.021591779875702093, 0.040095119404473474, 0.05162835553554552, 0.022932814434170723, 0.07808792697531836, 0.027653755753168037, 0.04839282915262239, 0.03381020915029304, 0.058921334732856066, 0.05941735061683825, 0.029912154389811412, 0.0032799182642650393, 0.029304370217557465, 0.0027383167013925102, 0.04050213185005954, 0.062422962194042544, 0.03846078299518142, 0.03230409550347498, 0.030544616880693605, 0.045181394155536375, 0.00959800336776035, 0.0458763938264123, 0.05959668742226703, 0.02702198367166732, 0.01617089406188045, 0.032451184932142496, 0.03303611943764346, 0.03616510225193841, 0.06057043267147882, 0.022011284150981476, 0.02104658546990582, 0.0480376398190856, 0.02577555725084884, 0.04223840118252805, 0.05470771369125162, 0.08292556274682283, 0.05718166593994413, 0.03802089213526674, 0.04186301864683628, 0.06814075966498681, 0.07559697063905851, 0.05579326115548611, 0.03597078339329787, 0.03365468553134373, 0.040166192555001805, 0.10705102461257152, 0.03246773440124733, 0.1030167607324464, 0.07556200572954756, 0.0645851818844676, 0.050019664357283285, 0.06293579896113702, 0.024086193347881948, 0.06677691784820386, 0.01707037365330117, 0.07273367499666554, 0.03525859982307468, 0.020427669930670942, 0.020254860632121563, 0.08921955179955278, 0.06263224953519446, 0.04712473201964583, 0.0401464132592082, 0.01084778259973973, 0.03612334181421569, 0.060699713948581896, 0.05777004401066473, 0.021238149476370642, 0.046852452880037684, 0.019912622835753218, 0.04916743115921106, 0.046270799091351886, 0.03432178384225283, 0.011244998695994062, 0.04626984574965068, 0.04376762233940618, 0.024908263968037705, 0.04269340640998312, 0.033510554515357525, 0.04525061829813889, 0.011345746727394206, 0.029264200944453478, 0.052245452600930414, 0.016115121876022646, 0.019465062833790268, 0.07292666392666952, 0.04741723828815988, 0.04657390068418213, 0.07917920127511024, 0.0266522974374571, 0.06718084974480526, 0.019524131003501158, 0.009009147778020372, 0.06177061862711396, 0.047989070282450745, 0.0332546314623739, 0.009178209018760493, 0.05878908825772149, 0.05963699918772493, 0.049166688163365634, 0.03878232716981854, 0.008058929034242672, 0.04811370359467609, 0.033218228058623414, 0.024505582272208164, 0.014582898201686996, 0.05829022252666099, 0.017323711487863745, 0.037721502128988504, 0.0851786925590464, 0.051412014822874746, 0.014395530934312513, 0.004128787200897932, 0.017386245275182382, 0.03192070286188807, 0.05965668348861592, 0.009611114360658186, 0.031270055632506094, 0.014300269706706916, 0.041671386786869595, 0.02369738938952131, 0.06004534834729774, 0.042366030226860724, 0.05613722412713936, 0.008374212026995207, 0.027977881753551107, 0.03172868084428566, 0.0531386252093528, 0.06903702978576932, 0.023114427724587064, 0.06057214257972581, 0.014988085388072898, 0.041468874617878876, 0.03740671616313713, 0.04453105905226298, 0.02567363789837275, 0.011791820737666317, 0.03388436284980603, 0.027480607187109332, 0.051972756162285805, 0.04307047510519624, 0.02768008121555405, 0.04015168886897819, 0.008950057555921376, 0.05986080039292574, 0.04859986036483731, 0.06225821389151471, 0.010878417607662933, 0.02760922858890678, 0.037761125181402476, 0.044061102305672, 0.03163146034681371, 0.01968869101256132, 0.05813504835324628, 0.036782491087381325, 0.07510475455118076, 0.03023730158539755, 0.04006324861464756, 0.005424522761521595, 0.05730520681078945, 0.03937881373401199, 0.009841554182847696, 0.025359449043337787, 0.03519974369555712, 0.027840665009404932, 0.009755474382213183, 0.054007916777793846, 0.008769707188808491, 0.06015689950436354, 0.07034892296152455, 0.025025078860510672, 0.05577968366976295, 0.015649283836994852, 0.03852974250912666, 0.04245800904131361, 0.03228368177743895, 0.022054340590589812, 0.02037813008895942, 0.033805513687963994, 0.05012826049434287, 0.0583304800093174, 0.023740203252860477, 0.06397945367332016, 0.027844468198184456, 0.050434507096984556, 0.008641743117810359, 0.014429975068196654, 0.04494274999680264, 0.05303934196542416, 0.044534675643912384, 0.028758027391242127, 0.05604415626398154, 0.015949038555845618, 0.03405867849609681, 0.08181113683219467, 0.06877095584890672, 0.06089919645871435, 0.019617572060919235, 0.041576520805912356, 0.0448606845789722, 0.0410210516835962, 0.03626038213925702, 0.02441083503487919, 0.02839667526339846, 0.05244834474953158, 0.0417517592598285, 0.035317371133714914, 0.08890725605721984, 0.013426184288359113, 0.024299587522234236, 0.09716597718319722, 0.06848165565835578, 0.061859601709459505, 0.027550219791010022, 0.03009372018277645, 0.030803372817380086, 0.03830889971660716, 0.05548254979242172, 0.03335194016939827, 0.010571302480197378, 0.012900669942609966, 0.04709011655566948, 0.04775036505556532, 0.018985569277512174, 0.05050966163565006, 0.07130468024739198, 0.043504018270011456, 0.06402934635324137, 0.01746336417272687, 0.06342935854835169, 0.048172064391630035, 0.07445370698613779, 0.011767301026598682, 0.013139943442573505, 0.036147127859294415, 0.01066630840900221, 0.039301433600485325, 0.030137159994670322, 0.016386503653068627, 0.07691186972494636, 0.07555942051112652, 0.07349818040217672, 0.029430058651736805, 0.04732763095359717, 0.058503370732069016, 0.056212605975036106, 0.028843587264418602, 0.08059834369591304, 0.025900073515783464, 0.035935285833797286, 0.014524576420496618, 0.05352545463080917, 0.003264865176918517, 0.02954880567267537, 0.13585377085421765, 0.06860326270439795, 0.07444201582776648, 0.019332331206117357, 0.007996982179715164, 0.005614498571958393, 0.04268130134525044, 0.05271306840170707, 0.037858830831412754, 0.00469287541428847, 0.06351808378739016, 0.0336823154773031, 0.059885410858052116, 0.029847588390111923, 0.030161431192287376, 0.04598820621946028, 0.0593623010707753, 0.031627351817275794, 0.00841871798703713, 0.028960800796215023, 0.016916532801198106, 0.018399333681112955, 0.015797842293977737, 0.06063972466758319, 0.02075183155414249, 0.012410836360816444, 0.009880888857878745, 0.06255921202578715, 0.00484035924143557, 0.05062559273626123, 0.03391423874667712, 0.1014952545187303, 0.06411600206047297, 0.028669512498059442, 0.021865363498883586, 0.02965321864134499, 0.08432963490486145, 0.06553184001573495, 0.06997662436749254, 0.018100941121312122, 0.028769328391977718, 0.031230415616716658, 0.05963427147694996, 0.04451065889692732, 0.015435825201815792, 0.06768004117267472, 0.02786483273043164, 0.03685768633814795, 0.029330117228840078, 0.06530466649149146, 0.047047908284834454, 0.010858379620393472, 0.05597145123673337, 0.02553184443552579, 0.007642633381432721, 0.05230750462838581, 0.03215549294171589, 0.020788341827158417, 0.04281993962026068, 0.056677714588918855, 0.012428770041359323, 0.14748642593622208, 0.08878704679331609, 0.1435343122908047, 0.17247070957507404, 0.1279743779450655, 0.16772692198199884, 0.13726439087518624, 0.15987790030028137, 0.09774516110441514, 0.12181953606860978, 0.10145766367869717, 0.09955292767179863, 0.138261240241783, 0.16021122384284223, 0.2329848509814058, 0.09553511148052556, 0.15361844189465046, 0.1344338006206921, 0.22094804687159403, 0.0838382737711072, 0.1129273007224713, 0.19417947397700377, 0.26042358577251434, 0.11992243358067103, 0.08321626071951219, 0.2067639237003667, 0.1325854712298938, 0.14562942486788544, 0.12605192538883003, 0.13025463558733463, 0.14506252243050508, 0.10040117108396121, 0.18113185624991143, 0.14537683342184338, 0.16826801294726984, 0.10172632961933102, 0.10485602489539556, 0.16878044259335312, 0.11501396553856985, 0.1346092154937131, 0.11327983359141008, 0.1689486785658768, 0.11031639975096498, 0.10503364500722714, 0.1649284671459879, 0.25487889615552767, 0.11279670308743205, 0.2032704318740538, 0.08629434662205832, 0.16194503009319305, 0.27325302734971046, 0.22851455371294702, 0.16178828850388527, 0.11064611348722662, 0.08778751042804547, 0.14514617222760404, 0.1742493398487568, 0.12527394427784852, 0.10740096547773906, 0.2150338813662529, 0.099843116743224, 0.16909053309687547, 0.25130518791931017, 0.10910558115158762, 0.11652138536529881, 0.20740271013762268, 0.19135570978479727, 0.11965302803686687, 0.11139221702303205, 0.10881387216172048, 0.2228866485612733, 0.18899225017854146, 0.17937584833375045, 0.10659055717821632, 0.11849182391805307, 0.1166525733258043, 0.14935323862092836, 0.1544270385056734, 0.12484468945435115, 0.13081300205418042, 0.06948557535984687, 0.1449532104390008, 0.29604724422097206, 0.17460201521004948, 0.17166333432708467, 0.11882373610777514, 0.210469050598996, 0.1162798133279596, 0.23729968230639184, 0.19634391926229, 0.16619066441697733, 0.1315604355186224, 0.13933620255972656, 0.11498288863471576, 0.09362392260559968, 0.16497202909418515, 0.1209582444280386, 0.18939558496432646, 0.13259256870618888, 0.11404405401221343, 0.16502992170197622, 0.122055177709886, 0.2074114360979625, 0.15899337562067167, 0.09872452462358133, 0.1509514735745532, 0.11397085365440164, 0.11183113418519497, 0.20787345059216022, 0.17398481975708688, 0.10755493185882058, 0.1540500715907131, 0.15457486414483615, 0.10974798418049302, 0.12289312774581568, 0.12762144474046572, 0.11916054732033185, 0.17306573050362722, 0.08996233729911701, 0.10686054626213652, 0.0824912189106856, 0.13403787543731077, 0.1871260210339512, 0.14139373786747456, 0.13091688576553548, 0.12571174864258083, 0.13217685744166374, 0.09982657405946936, 0.1778728389846427, 0.17696049436926842, 0.12682601170880453, 0.16053341941109725, 0.14900557084807328, 0.0673064940742084, 0.15119966811367444, 0.0708417904430202, 0.07591844017484359, 0.09312459547072649, 0.14517237725002424, 0.13681008453880036, 0.1383679330881153, 0.10342999534415347, 0.1338795596467597, 0.09253556600638799, 0.14901460893452168, 0.08325788205755608, 0.26344966196588104, 0.18233721942773887, 0.12608938052185945, 0.12592512076454504, 0.08943428777690444, 0.12295254027204854, 0.12653614154883794, 0.19107778184115887, 0.1457013495798622, 0.09210012972887073, 0.1261360773018428, 0.14627110186432088, 0.16565544956496783, 0.18827222952885286, 0.2134215600256409, 0.14066691829689912, 0.09260806068778038, 0.12981888039835862, 0.15009434813899653, 0.18203320859798364, 0.14631840932582105, 0.16328961508614676, 0.17079240748924868, 0.0845406117982098, 0.07817549191947494, 0.1109435764540519, 0.10965849219688348, 0.13144021268401826, 0.1494035587779113, 0.07578793753470693], [0.00486765755340457, 0.09554383744086538, 0.06186326579856021, 0.029126746713050773, 0.06535848110382046, 0.06644049340060779, 0.025306514830195477, 0.0323418424065624, 0.013134880723165614, 0.03248155955225229, 0.04714929837999599, 0.05450313199045403, 0.03583144622721842, 0.020484247876863395, 0.033715441556913514, 0.02450879174284637, 0.021570618064807992, 0.018739900584997873, 0.08557372207620315, 0.06501455884426832, 0.018479974175404226, 0.03471112045060311, 0.019480206039068953, 0.06982687847422701, 0.029573243111371994, 0.030226288962044885, 0.07440255223108189, 0.04510368832520076, 0.06903014944068023, 0.036841384534324916, 0.008981130218931606, 0.024326773027756383, 0.022160081791558435, 0.03589628703360047, 0.03304868590618883, 0.044832891784608364, 0.029141301289200783, 0.037826641130128076, 0.036536437326243947, 0.02643164463474282, 0.049721037702901025, 0.045930520564849885, 0.056574146396347454, 0.01590547151863575, 0.04229654824095113, 0.041871500334569385, 0.06011911867452519, 0.06427593954971858, 0.07016693308417286, 0.0424164962688727, 0.028971141669899225, 0.04981896048411727, 0.03533470770344138, 0.0218458030306335, 0.03186950400205595, 0.0048261532626513925, 0.03855239200804915, 0.05914792471698352, 0.04055890487506986, 0.01996990985104016, 0.05865215989095824, 0.047080237085797956, 0.02379238259579454, 0.01758060654226158, 0.03798990683364017, 0.01946797374902027, 0.08582283263759953, 0.06309190272752728, 0.04468428583017417, 0.004869544728925186, 0.05855722605649914, 0.011295440141111612, 0.04381246332611356, 0.010218992679645973, 0.08840682291026626, 0.037700928947223086, 0.03612182868112411, 0.028137927808399712, 0.05606128927320242, 0.03105233410107238, 0.03370754001662135, 0.055547326137976985, 0.05284045317343303, 0.017078916409185955, 0.05483571932251964, 0.005193697022540229, 0.03371919046289154, 0.0522081603163055, 0.07201220228203706, 0.028283912921324372, 0.01908742416916149, 0.015006202273070812, 0.15881873427757195, 0.03510993280048881, 0.07646803996924843, 0.0371301113627851, 0.07133041029529912, 0.016006322178457464, 0.06398976062025342, 0.038251356554350684, 0.03506402312112706, 0.016965197332735573, 0.03744703810662031, 0.07693360320159368, 0.04926822414355619, 0.019025070193622793, 0.02200830029323697, 0.05022233598200338, 0.05115919606760144, 0.059220276906022, 0.040267080534249544, 0.03791323237653289, 0.017394250292064886, 0.02602819280166711, 0.024394797859713435, 0.04928074311465025, 0.10112628074628965, 0.06523204288844552, 0.030160657662366117, 0.019965389111478413, 0.07337474809693438, 0.058625079558363984, 0.026281976773004447, 0.04764483928946512, 0.026965412510825053, 0.04351001312690122, 0.022877839526959827, 0.04995155640478645, 0.04362046166456171, 0.05579579209110566, 0.070726731259908, 0.03248434154582875, 0.057084716856479645, 0.004569361260759511, 0.01677373849919864, 0.05987650169325726, 0.009814670625408846, 0.015035864431411028, 0.0360238855438573, 0.06219145283102989, 0.015001667962808694, 0.029648065167878355, 0.007410204603469798, 0.05543503537774086, 0.03395271507490959, 0.037307951998497756, 0.08166846805917365, 0.02467165032534727, 0.06534729206136294, 0.03143024417970862, 0.04097217680620296, 0.05212273954280785, 0.022739589713247757, 0.03890502326456564, 0.03835519276825445, 0.03311813735802259, 0.018643786099606326, 0.04753893354375448, 0.05266021052375436, 0.03156823106110096, 0.02122447869208242, 0.022529515271474208, 0.023611098394862244, 0.0375295276088374, 0.03150504927283951, 0.009457979184974517, 0.010876226787721472, 0.028280376057539667, 0.025896802976993576, 0.03780780839068549, 0.09334873594343662, 0.003928454401570239, 0.0681329904390233, 0.02317653742751905, 0.03904152076159205, 0.050398493850869794, 0.020482626178168824, 0.015508840658835002, 0.04163191979750991, 0.06592158374509641, 0.04946244800729411, 0.11803724616765976, 0.05246376785050545, 0.041834014667464156, 0.012224305387852448, 0.047579408157616854, 0.035134712899369855, 0.040869205724447966, 0.050905732704060416, 0.028988291642495563, 0.0022989544626657982, 0.02581328888689833, 0.007155625049823097, 0.025448220083490014, 0.07180515410644667, 0.04762781823852232, 0.025010770253304924, 0.022029543528333306, 0.005939852296640831, 0.03166307329333254, 0.01673859547424529, 0.05188068235293031, 0.03749698846201811, 0.07177638422165598, 0.05418602204216378, 0.05792685345347438, 0.009080244677274354, 0.05288509059963482, 0.03154512355104089, 0.03581826229180608, 0.06273345981857606, 0.024705549934878945, 0.03323338653094002, 0.09342850452022892, 0.011928621879113572, 0.014504247511337911, 0.054660063569567034, 0.04655674392623561, 0.04904678084754518, 0.05962121646319117, 0.04942537624655025, 0.01811426754907838, 0.015682633833161423, 0.07402117483850036, 0.047047647048852274, 0.025551155542156527, 0.04981011578014918, 0.07697295144732509, 0.021452022017911077, 0.031014363281428814, 0.008328829908610454, 0.007836360218269485, 0.0339369425284011, 0.06652835011482239, 0.018530901621228883, 0.038080504829330106, 0.046276203622775416, 0.027193405366103564, 0.044151920825242996, 0.0690793093027813, 0.02207428782380053, 0.04716974264010787, 0.08018126179065023, 0.03259755511369024, 0.0508046309862818, 0.01729102136700281, 0.08889274897852115, 0.04898770758882165, 0.07980930924947773, 0.002894970717274451, 0.06467764585145883, 0.0229522290173918, 0.09283959719219378, 0.051660843792238405, 0.05687997569995267, 0.02620818608972643, 0.012995782740680235, 0.0561918292327651, 0.05477459688803979, 0.015824792008580904, 0.07849111248339925, 0.05416385430310454, 0.13102849120540278, 0.054678998089262416, 0.019544375095782534, 0.030479484304253544, 0.06442451157740184, 0.019734956922807863, 0.07987305761447974, 0.05880092190844672, 0.04283406671934894, 0.04988311936280557, 0.020504032261669636, 0.0017485961933354183, 0.05287747743672558, 0.09458343219012022, 0.03385839870731745, 0.05143240819286023, 0.0720631874033383, 0.07223409001848527, 0.03977786357115422, 0.10051504961614098, 0.025561382761225104, 0.038575299350278716, 0.03063617500343493, 0.0843550596120102, 0.04792705896709647, 0.07428380181746823, 0.06888183525630406, 0.008120132044755986, 0.019727214838245084, 0.06014889957649367, 0.03221577060009752, 0.0011115214666850598, 0.06669192455176796, 0.04497191343190415, 0.02056676791315632, 0.01963733778601246, 0.02841834258288145, 0.05384481731536133, 0.01426683659000056, 0.06747872661799192, 0.040978066490164826, 0.04417065178443279, 0.007270146493933031, 0.0291508822036641, 0.016547954275405834, 0.02194510493427515, 0.03575367254338094, 0.02831882015535874, 0.02637575370525675, 0.0894995289189475, 0.04447986697778106, 0.027560294339699403, 0.03278873574786952, 0.01442464517562517, 0.07757780434829847, 0.039633023486073525, 0.018127300510449067, 0.05237032000773719, 0.0007513949957293724, 0.03472796847511615, 0.062471979563789706, 0.043506824012313566, 0.02391585730947554, 0.025290399623502578, 0.030534601703818356, 0.02893671958840319, 0.00242222603992559, 0.11924862116575241, 0.013027748525408762, 0.03295058670586773, 0.06528919589306627, 0.034651701139020066, 0.016145832370966673, 0.07222589331546, 0.02674940088763833, 0.055045420570032935, 0.004973067120382828, 0.023925718119634048, 0.04161072236352733, 0.04611766391566821, 0.03493054510493364, 0.05987236262964351, 0.017879747186920474, 0.023115879789526974, 0.014013689593411982, 0.049524418610547266, 0.044639658581997664, 0.014555504046646612, 0.07955716563654797, 0.05234100729493158, 0.12156485473471028, 0.20564025613878453, 0.1573070396802255, 0.1209014103348766, 0.18530308242355073, 0.19199031644633838, 0.16654112775410923, 0.09849612973630428, 0.15929364093712398, 0.1251770630478859, 0.16563878474490984, 0.09967767633497715, 0.1438716934727771, 0.11490508780947753, 0.10833966439323765, 0.15933142176696233, 0.0918059576568859, 0.18656396333660397, 0.1915801420275654, 0.1327529472431966, 0.16977115800338133, 0.11928663269749709, 0.07095940770315272, 0.09242260349648339, 0.10750387209866728, 0.13227755203843117, 0.17378571044121469, 0.1783107112028769, 0.0815763705010925, 0.09688593221030065, 0.08626837908689465, 0.13119106819587095, 0.08063446890030589, 0.1402730287185737, 0.17549544226910385, 0.08591708793703999, 0.16594697535037994, 0.1467176457600934, 0.15545195208064147, 0.10904800066990511, 0.1478147418903453, 0.22716608749968664, 0.1848986076989344, 0.15994802010910852, 0.07851418945938349, 0.10692565169717584, 0.18486435525119305, 0.15627277589270047, 0.11138923146895, 0.1409872139671019, 0.15066433112536157, 0.17596440496189253, 0.13487389843378747, 0.12481480677212987, 0.19883315211960248, 0.07758857948439461, 0.16844376708780015, 0.12730064695434912, 0.13948362107787812, 0.11995680816471577, 0.1297923225377287, 0.11954934788601738, 0.0889387061553342, 0.0814655182350959, 0.08495588201497282, 0.08688281968768154, 0.15907973955784524, 0.12674055700855597, 0.11563829917992864, 0.11198860859232289, 0.1826665803257908, 0.11513445978718144, 0.12886840211493628, 0.09838719772441046, 0.2165873194379466, 0.14550627076200076, 0.1790528656648738, 0.14089751163763659, 0.1190469605582101, 0.14008256393883908, 0.06756150789026703, 0.19900094025901385, 0.14560081783149922, 0.08902688178100757, 0.17564584634133748, 0.06511052405195576, 0.17924782234643186, 0.12014592944511346, 0.20161000240061963, 0.1476232185959816, 0.16518328418689115, 0.07187209158603634, 0.25349465757608414, 0.10673020647040435, 0.11965161668402807, 0.09138189362628119, 0.15026631605412277, 0.12268058343657426, 0.17657995836011, 0.2655702196061611, 0.1013240601335253, 0.2044168167880603, 0.1672750719423805, 0.12402784185750143, 0.14951874688267708, 0.2798965365758964, 0.1856221024479185, 0.12294950043516499, 0.14221662442599023, 0.17775018699467182, 0.13678885996341705, 0.13570667803287506, 0.22381077254457132, 0.12763554469815322, 0.23290725371667317, 0.1120836917044861, 0.18759084466312612, 0.19028704427182674, 0.15245338369693073, 0.1384051168071372, 0.21685854345560074, 0.14998761458056314, 0.16151563956269196, 0.15998239469315323, 0.09532617019223315, 0.20292352406041964, 0.07690166455826589, 0.1454926457788263, 0.1296862539436136, 0.09689651735659156, 0.14296424788023743, 0.10816554552210228, 0.179890652852399, 0.12117138584809643, 0.16460011047976358, 0.2063414135149547, 0.1157783352370773, 0.14220407152814524, 0.11106935649045876, 0.13315222438957008, 0.1335003807076386, 0.07576885712998253, 0.09458940329828433, 0.11589348262974195, 0.14277543872594833, 0.07666478798325572, 0.20695885324052402, 0.09551493184907095, 0.13621057170842374, 0.12020678046558585, 0.1414188572338649, 0.07860182904239212, 0.08997794360454593, 0.20802084196891102, 0.12216299692434923, 0.11393457917230469, 0.10244127482708011, 0.07969734418605055, 0.11494452426476137, 0.16320194836173738, 0.08043141729597535, 0.19035048729607038, 0.056710718532225916, 0.16194322519004345, 0.1352906817836421, 0.19696886358516558, 0.10606374937508788, 0.1276756596884557, 0.13426565964307102, 0.1463960608733552, 0.13878163588898523, 0.13735227473080158, 0.154338788241148, 0.1508232575974294, 0.18932584513510975, 0.16128409627292836], [0.031864286067762544, 0.031892479197787385, 0.038521834183484316, 0.018705244408920407, 0.06375971689288105, 0.040902820349271805, 0.09307565273983137, 0.05881779707436051, 0.05228960487459387, 0.02018423531470554, 0.019599599364612783, 0.004613192078457879, 0.019734103665021912, 0.012986272224225104, 0.02798597837266113, 0.005121152299190206, 0.012793910090944596, 0.053750538267195225, 0.025685897329822183, 0.057526178524962494, 0.059293802960642746, 0.04689785026546035, 0.026922529097646475, 0.034732124502105374, 0.10757036853049483, 0.004039973328222654, 0.057968596927821636, 0.0327966813929379, 0.014011279097758234, 0.04841916988204632, 0.021077411315803016, 0.02296109577374799, 0.012764387880451977, 0.04488472846735801, 0.060029755612569194, 0.0857986021520836, 0.008885094613235976, 0.021748519768672328, 0.04250523168593645, 0.02021000098570117, 0.07340667995491199, 0.02127267503445702, 0.07536744259830032, 0.020398901742217795, 0.010519228310191205, 0.029666758807642118, 0.04870312321665032, 0.06491655803152493, 0.010719772727627839, 0.034385345610124726, 0.05228646665013262, 0.05739139432885817, 0.05015670128964952, 0.031353892026735206, 0.04821072731699262, 0.004098047868215612, 0.027552628590326225, 0.06726646729345832, 0.03515079078663673, 0.04169451126030513, 0.028337663072826605, 0.0701700272038579, 0.01749466160046203, 0.09065355413726398, 0.031617177184671164, 0.008399946315746223, 0.04835865134373307, 0.034852075922702036, 0.04174971008407218, 0.04443259683570691, 0.045571375372154374, 0.06147380705390658, 0.07193141590271677, 0.035309306745018275, 0.021259175580261008, 0.041360858628260236, 0.04075299981715424, 0.031650890197072706, 0.05547273478337696, 0.06076399835624865, 0.04435977306483047, 0.0526786632835865, 0.027361447956146936, 0.03605610577921782, 0.01129356908079769, 0.06478798921619143, 0.046658395257379325, 0.018035297947270528, 0.08063612452575139, 0.01473341932121132, 0.014925163139456084, 0.0311016737749534, 0.04569038023640003, 0.07941259018012456, 0.01659898180514574, 0.03719972227034824, 0.07439517655542918, 0.07114794544343438, 0.02378751241069819, 0.023562033527663777, 0.0940164483285376, 0.04705896840563842, 0.021786487195640802, 0.022618769767827222, 0.024731780402362347, 0.044565094368798394, 0.04048650858125516, 0.02270270454963403, 0.02693923802248069, 0.03796225992430534, 0.019830740622377822, 0.04345668366711054, 0.030232344887086322, 0.030717717949301004, 0.011964516381600072, 0.09071099891194276, 0.022720936785585115, 0.015060836216434836, 0.09154117293655872, 0.014493938868067094, 0.06763671671173402, 0.01874364440196327, 0.05454456673136779, 0.0054885298179994735, 0.01260053609231753, 0.04972232013408627, 0.03515486538942371, 0.03511358331888914, 0.01864566733794553, 0.03360402610685144, 0.031043601355382373, 0.017033366353384087, 0.07734497862734965, 0.04281663854739495, 0.02933877533567803, 0.04756249567227704, 0.043584390742970366, 0.014192912744225135, 0.04950682080483862, 0.029219570303601877, 0.03057500167882868, 0.02228274056687951, 0.04399473818817309, 0.03758577137653317, 0.045510029021118364, 0.006359689054079354, 0.05521702886159931, 0.04639958843056645, 0.017185385338962078, 0.03186748196770038, 0.0643903473392129, 0.06032662146857806, 0.03735549355457936, 0.03349363863734262, 0.03749750414863229, 0.05236615380272269, 0.013893152088192957, 0.017859155345442038, 0.07089978483106409, 0.005683750280046037, 0.036848458261894326, 0.03422452602535486, 0.026819802288498198, 0.05631202492596848, 0.026384036921496903, 0.01733315839166088, 0.018518915300124457, 0.037655429781547615, 0.11451478089605059, 0.03583161246829799, 0.04972276457452348, 0.03049539934311594, 0.02437065728008747, 0.033544023255152364, 0.021621011164305464, 0.025582205304609876, 0.020560074165197353, 0.04048822866752744, 0.049131974311811585, 0.008855686905527753, 0.03324575961700507, 0.050056037226957936, 0.007713567432282227, 0.026377611194870303, 0.02001714945903846, 0.0035887420277244276, 0.01718436584009656, 0.020511022868699262, 0.04434059427252837, 0.02119184285402298, 0.05922116578689643, 0.05719290926520314, 0.008719934948853083, 0.033243109937757254, 0.027644095110840032, 0.01265472305073802, 0.03931351152381726, 0.06754263104604823, 0.02505168252225433, 0.03331153340903776, 0.03411333788452404, 0.0092433687366013, 0.014184333517083099, 0.021063545452696935, 0.061779704211013656, 0.01774896974010127, 0.07781812109585319, 0.03224944629307304, 0.03126971297232168, 0.027254733057426553, 0.04823053036151188, 0.030107050003217797, 0.02211462164164654, 0.01544495319415416, 0.03593725358535137, 0.05042361321726015, 0.04882081511563488, 0.05847067212952035, 0.03581558207848242, 0.03790114427517567, 0.04762429664177554, 0.005246051088241594, 0.06973835001034395, 0.05753964065973248, 0.015103059754307781, 0.011456203746742435, 0.06766794967864241, 0.04416998003476432, 0.10114574791597468, 0.021101987854178463, 0.00775831936126841, 0.0113982746676941, 0.015163167778934752, 0.048790467636925836, 0.025417570656697665, 0.08014122822454997, 0.02591963398403355, 0.02284521725960076, 0.05382889549114874, 0.03286064688914588, 0.040733427474541326, 0.02001225552521646, 0.026464660452412705, 0.041133054066449404, 0.04862403996022684, 0.04514730455619948, 0.07681579595165593, 0.06269702248807464, 0.07040072911019836, 0.09561557894838707, 0.042550062494618554, 0.014987841115466185, 0.04131030437669583, 0.025322577450424433, 0.047817556985786984, 0.02107741979749075, 0.014872444361182196, 0.03363722003996372, 0.028297351307368705, 0.02159130320485149, 0.02395684930628964, 0.036507270498467345, 0.08553797685142074, 0.006620009438068206, 0.05294455401599407, 0.035304984476949484, 0.02417305770463177, 0.028150439994143586, 0.06389557995966502, 0.03556745878553816, 0.042719645359154255, 0.02813017215313656, 0.04839072908673968, 0.016521440519552146, 0.05933535644518478, 0.0926184422735657, 0.0583942351596696, 0.05988616403192282, 0.02720135949285967, 0.05611228457252894, 0.016584778370867883, 0.05512615605922682, 0.012007578758389821, 0.02705319967520024, 0.029556052426674535, 0.025265787462038652, 0.05274454903389726, 0.10542467795312405, 0.011602529823513967, 0.02415150573610195, 0.05955140878047262, 0.051841544453054667, 0.0314516858862979, 0.032661249195890765, 0.014831126667559147, 0.06926268339157104, 0.05734788666346243, 0.06743720027485064, 0.03516339457460812, 0.03209968004375696, 0.00575020642385685, 0.05066189435975892, 0.09615319581436259, 0.07305371960891144, 0.020891684406836118, 0.05596241315028497, 0.028119951719418168, 0.01912452476764364, 0.015867636405995915, 0.08043158692973, 0.0039341842057183385, 0.056964019047362466, 0.017455252286578928, 0.056271482458604236, 0.06959919604871954, 0.005678730393161199, 0.033079158913876326, 0.02224317179726703, 0.0473175275671695, 0.030177302126373564, 0.04545489805085318, 0.0409013173942055, 0.0069509301184942675, 0.04180691397881933, 0.027964273733752112, 0.027005088149702976, 0.031044022047093937, 0.014829462560425912, 0.0251485145584281, 0.011685398457172726, 0.025607443414628506, 0.028764985767858367, 0.01293473579322121, 0.024191167804279497, 0.022131574839087467, 0.01678256454345371, 0.05914977711758443, 0.0206033019348979, 0.011193589490306164, 0.016453254535528164, 0.03318055918706315, 0.03496988995798996, 0.026271576527506113, 0.017846375138365796, 0.04811601061373949, 0.04046473778518183, 0.06129753722676209, 0.026957770510177528, 0.0533236752796386, 0.057152516075542996, 0.021603108017838428, 0.006451767104278717, 0.08416447269597224, 0.16150354806865963, 0.12212764524987765, 0.20054695515760354, 0.16146761285407202, 0.17120218835771084, 0.1392293604356902, 0.08560270230684962, 0.09332132991403341, 0.1532728232975517, 0.1081671468647463, 0.0917698595938938, 0.1275830396584102, 0.10020721184888057, 0.12023728740002428, 0.1298820520085948, 0.08320097332554204, 0.21122951193579606, 0.09440739306488208, 0.08549202645995788, 0.11950679016964776, 0.1572632741715227, 0.08809862551944596, 0.1578634519662176, 0.14188769779035024, 0.09872358145990542, 0.14794997391956194, 0.09029085681374584, 0.144162703571575, 0.09432460500725678, 0.14757239632308483, 0.12631265925509588, 0.1008532518254859, 0.16237553342112473, 0.18410683875637396, 0.16074804003749574, 0.08714860185448613, 0.11745059836123671, 0.11785497809095041, 0.11774034638489995, 0.2354975204382624, 0.09953809489629098, 0.14014063296573503, 0.10640693203146968, 0.1307523138821125, 0.1289776326822383, 0.15478587496493543, 0.15314561155225548, 0.05866765763078417, 0.08945190933133874, 0.13590749725699425, 0.15914714522659779, 0.1070745697777186, 0.09974031868789877, 0.1500212699174881, 0.1551464484738452, 0.12492767428713185, 0.18127874551074846, 0.19131293493722165, 0.1372373987521444, 0.1102162344115121, 0.08400745290730681, 0.0922871543360608, 0.214216409517186, 0.07499062496104411, 0.10297268988298518, 0.10970244769539152, 0.09572316067559378, 0.0778409605845809, 0.15187031855540617, 0.1757508157087224, 0.14707416162959167, 0.14525632560253143, 0.1351937869829791, 0.0826263695157, 0.08971628014530454, 0.10614304976271731, 0.11239351757935115, 0.1450613010674715, 0.204068266919681, 0.14415274267750128, 0.09638646258307354, 0.14412234430866583, 0.07363965495356492, 0.16894816287926265, 0.16131518674748285, 0.1709420651729618, 0.07169192696788482, 0.1005680567717978, 0.13858697776283535, 0.240214397332498, 0.06545215964849506, 0.2481876994882311, 0.1624840311706066, 0.1641857155731746, 0.13463866391352244, 0.20853926986455917, 0.11040212586522102, 0.13776630322848046, 0.19028091031525815, 0.16943141551954405, 0.1431478594562837, 0.1585276834666729, 0.10118663643619843, 0.07170747899051223, 0.17336739360221795, 0.13101409269230707, 0.10689948738685676, 0.17077560696218694, 0.205893553261246, 0.1319990541253771, 0.166221944881337, 0.12175128901643412, 0.10484014717595917, 0.10251710790076426, 0.28811457274215563, 0.08906196204147168, 0.11322155421865837, 0.23949219180004938, 0.20111207983323506, 0.26420899693455013, 0.291448676692588, 0.19026679678687028, 0.21600217797926494, 0.09193589032760688, 0.1244996679680688, 0.1734805325312274, 0.11932130583695003, 0.1673058502908264, 0.16871226339467935, 0.08042530369545732, 0.09281644557735749, 0.12161596199231488, 0.1845553775451013, 0.070663166099361, 0.16377619254801953, 0.1371634520058121, 0.12488856352865696, 0.17130589564996107, 0.14665443343775614, 0.05218233527349574, 0.08715620144669499, 0.18627295323780604, 0.1512018937085356, 0.14592582253473146, 0.1563716113035168, 0.15189386372055325, 0.13981345695044312, 0.13451039365359715, 0.11179978586733341, 0.13137637610946382, 0.12966258664216312, 0.11825323743479592, 0.0850333571434021, 0.1384105043751853, 0.1676870376936027, 0.09872902331075498, 0.10305424979222672, 0.29402143721069607, 0.09717887613390173, 0.1592774646622794, 0.12860977170722826, 0.10802282925162997, 0.12660472786852292, 0.11620339671415941, 0.09581953300429241, 0.07522640909467425, 0.07839300989040307, 0.2544215092701571, 0.11711175154362406, 0.18767327309719153, 0.12338372213499886, 0.11832444289965288, 0.14951599203050137, 0.1287393176129886, 0.1573024256420987], [0.05581545942862119, 0.015481188660487533, 0.043926884686308246, 0.04104498700637903, 0.04087472560682467, 0.09391626263303415, 0.06509807971971375, 0.032340488729200194, 0.029348994073058878, 0.02715763808893306, 0.058958450598376136, 0.022466014571753994, 0.04860330053738185, 0.030525916455579654, 0.03946420058075871, 0.08291256201586553, 0.01200354317136641, 0.0411015768269343, 0.02243525318668357, 0.012546952181894864, 0.08957513807607548, 0.019928734649771025, 0.015799197667677487, 0.02036125322670809, 0.010284259266752218, 0.03378661988036973, 0.00978250297651227, 0.05255771780918751, 0.027825184232954468, 0.05243304378486105, 0.06475886649319104, 0.03565211959981492, 0.0252719383819827, 0.04265831936416881, 0.04465989928160395, 0.018965364200994372, 0.03080771883417453, 0.00029034449835307896, 0.02638671883115811, 0.035055823025426695, 0.06547864287027291, 0.02609241783751973, 0.016424082618738924, 0.016984659413407956, 0.007994558961529816, 0.09964309819042683, 0.048169971111097505, 0.015947055537253618, 0.015817285714937106, 0.04670186899602413, 0.008660142443009784, 0.006095462004720632, 0.04253978608176112, 0.018124728862728392, 0.03462617465161851, 0.05081948751051511, 0.052736175911767144, 0.05790473999721663, 0.029531730338931084, 0.08164809165256363, 0.04290476667561701, 0.006471786431835166, 0.0482925179281405, 0.040387781736041815, 0.0684806921386293, 0.054777925102306266, 0.013791801856963761, 0.031919959866042645, 0.06152824591845274, 0.02711347902991942, 0.027453918708488345, 0.028908916616014073, 0.005071591677343739, 0.057307167776993344, 0.007398238638415933, 0.08859731483140162, 0.04913639836013317, 0.02014081585886223, 0.046907339577696154, 0.036186896796737394, 0.03606432283829365, 0.06309855915606022, 0.033472766900168996, 0.015498265690569366, 0.09140700620732137, 0.029751256773514406, 0.09116740192153625, 0.01097847692601915, 0.10264754947274923, 0.029919533458139216, 0.06082871024097715, 0.002801466895367152, 0.05117047331961138, 0.0645534060895443, 0.0234339023674173, 0.009733450831845403, 0.05936293210834265, 0.011398160164909703, 0.04298117650406701, 0.044071175158023834, 0.023160047330228344, 0.037254839669913054, 0.01164344887781356, 0.00934992587592985, 0.0439657647428768, 0.020666319178417325, 0.031935844370829206, 0.037084344175777266, 0.037973757700196335, 0.02307099978705602, 0.06897085226540055, 0.047768322484833856, 0.040431448857166936, 0.04583850782364607, 0.039307397923299243, 0.05808210226574114, 0.05385314294004014, 0.02101492672227323, 0.017062724867303456, 0.013217157335020602, 0.013173001668682056, 0.04496543002980096, 0.02813161743272628, 0.013939745391585996, 0.03162452571892312, 0.023542437436325208, 0.06330992959971939, 0.005048643198928663, 0.042810938853238306, 0.0228945213103933, 0.047388101994459114, 0.04621045018679329, 0.03877660372693624, 0.029731290880590677, 0.023607802411009158, 0.07112462419484343, 0.01227117349792804, 0.06398944849414484, 0.018588242919317315, 0.054393032898328135, 0.011507685046776064, 0.01058548640659345, 0.040125561878085136, 0.012870939930767884, 0.013276138143347842, 0.049507808073290756, 0.06420028289513928, 0.016351737215050628, 0.00963000816825245, 0.03812941702614937, 0.04610832388113652, 0.02656631517623152, 0.026507735551734055, 0.02405563721965466, 0.023984207838241543, 0.020457628948081816, 0.059761625714600086, 0.015330938954970666, 0.02730438146474106, 0.07743045368364879, 0.06923675656850849, 0.025383265622492348, 0.006486701903798218, 0.059785367654902596, 0.024426018952258995, 0.08046319987624884, 0.0422107678438936, 0.02763822578292872, 0.024706898523228507, 0.06645892241171428, 0.025094448888142194, 0.01026409659867308, 0.12306209653615952, 0.029115642487470592, 0.03703642603276031, 0.057884261810353825, 0.015012013925505536, 0.04172875013734613, 0.0444367698260716, 0.03008776603798781, 0.019850272252889614, 0.05797249850417886, 0.0416028072525348, 0.0023515458035814974, 0.04564763253022518, 0.056827148356075795, 0.0294462756386825, 0.029965354927948544, 0.07984860321240765, 0.036853004446519275, 0.04445357035313334, 0.02098227392083832, 0.04438816297001072, 0.011507825842792434, 0.035967258403876, 0.03190427552908659, 0.0632717687902706, 0.030096203620944704, 0.04020094033330679, 0.03967832926926868, 0.04996528995356389, 0.019509306709681238, 0.027191641175055077, 0.014981203346646257, 0.05146685741575701, 0.04974526818841696, 0.03151505087901439, 0.05452230739008103, 0.02898351475596428, 0.019384303595870733, 0.05889812204986811, 0.03665031246574862, 0.02197288755061371, 0.0233167804378484, 0.028943718677120547, 0.06784436199814081, 0.05199631829080837, 0.03916504127638681, 0.01327730861625501, 0.019660407976646508, 0.030547554937324355, 0.0908000837745411, 0.004847254005393812, 0.04210200885842953, 0.03228233488542693, 0.16692162305116653, 0.010477077714832765, 0.012659915539968227, 0.014084850953492736, 0.02104890436333205, 0.021049735568729893, 0.050208442977496555, 0.06106472507651363, 0.018358509621715972, 0.07896197507424013, 0.03291910946635263, 0.024360328280766095, 0.014496386683146869, 0.02521818144513028, 0.048075122093515735, 0.046497063378670385, 0.049384579328554015, 0.02598531956651381, 0.06449454996202673, 0.07264662573912314, 0.05864015660647835, 0.01712839857542089, 0.0366024248568075, 0.02034730085038713, 0.060307344288698266, 0.026996569142543843, 0.08379414863884449, 0.020053247522030557, 0.041170488843428235, 0.003573840550546135, 0.03555683631982122, 0.0304042008439345, 0.03345831749694688, 0.03980947991034814, 0.022855310468003154, 0.026307007929842387, 0.06743030635906117, 0.030631533823907375, 0.011726043552958539, 0.03866460134408303, 0.07331907429865428, 0.02267301864256816, 0.04790965115119304, 0.012214825405473155, 0.03304078775857176, 0.03310688046206321, 0.030555517545768192, 0.10611752327531576, 0.045486066556934796, 0.036076936804290326, 0.008144125043015395, 0.06351115594484977, 0.012552722274059696, 0.031806105082588534, 0.020508334173687866, 0.10247588689838137, 0.018906463968700597, 0.032956472997154505, 0.04711810273251363, 0.03357557174084442, 0.028497965274644748, 0.017064831718536358, 0.01840969660718526, 0.05544622102752328, 0.025982189823740294, 0.039994455341781886, 0.022212127123826315, 0.07709753726209913, 0.06056268380156585, 0.04299305425956845, 0.01786558616108128, 0.06278561880545956, 0.04706004388364298, 0.04728078828858478, 0.06467510134513889, 0.018359159318996326, 0.0857861035370401, 0.022423891117796302, 0.015931288079757775, 0.038737248695854626, 0.015976615915341035, 0.05956535267510584, 0.03841647805113878, 0.024920479294710925, 0.04128985333123377, 0.02073429651292307, 0.007255120335945061, 0.014948077267035842, 0.01592307780603213, 0.039015621079930236, 0.013459104262957615, 0.03793619400156396, 0.02332517900504172, 0.012066539210666503, 0.00637033866119704, 0.0152612652829183, 0.028044788699064935, 0.05615502210067851, 0.03567197014178548, 0.024119277019053698, 0.030496681774301187, 0.012995296739973128, 0.020065951393917203, 0.025996211749900664, 0.04965681775606104, 0.02191997199718441, 0.06604642740317754, 0.04865057746480618, 0.018136513319664767, 0.05195001166846071, 0.05762058988745723, 0.04734140521447573, 0.01678599284163543, 0.031062512126352106, 0.03684315551072359, 0.0586189456017954, 0.05282327945211104, 0.02613309261921261, 0.04845495581892984, 0.05189909100798624, 0.013946355170836406, 0.02490321566749896, 0.03123440540262631, 0.012394318273956222, 0.020014857707012976, 0.02942291707066553, 0.06668123762522425, 0.14895810053816863, 0.09337458812764712, 0.13442514251385415, 0.0953224314642804, 0.08659780105309826, 0.09992195572704077, 0.11573524826339313, 0.08545652550778218, 0.10090759569512946, 0.08103500812181405, 0.11066763661801815, 0.13479014007108553, 0.14253176323005132, 0.1384869481303862, 0.14395921091948236, 0.17746527014034136, 0.09524695801415614, 0.1756353969020503, 0.11671764483409268, 0.11134792904236487, 0.1350591384938785, 0.10182825914983239, 0.06279194953718356, 0.09992739757789032, 0.11661739807043757, 0.09214574085282427, 0.06551271889890943, 0.09052502603403159, 0.17861864396503993, 0.15357378071972302, 0.11714152566024236, 0.10785049492759363, 0.07470879544104848, 0.11202838431511607, 0.1680137658757823, 0.0946472484086241, 0.19235717318952084, 0.13580639553921564, 0.1485842006014926, 0.2441765804375921, 0.20967017060944013, 0.09815464341746909, 0.050729876783277304, 0.1252460972006832, 0.12320518600089209, 0.2391032555273601, 0.05092468757980636, 0.13600748617734226, 0.11390024530036108, 0.32655705564788406, 0.0821672116539308, 0.08834230780069317, 0.1279114234660353, 0.07649365466620241, 0.0905048396172268, 0.1269294068749462, 0.16678641816335066, 0.12373524398675986, 0.1664139431502138, 0.17804560757109097, 0.08458196850759642, 0.11210883142692701, 0.06327674245195729, 0.12458740254598004, 0.1306257399597338, 0.1797481333570821, 0.08571635692247323, 0.1518434485686677, 0.1520929051829236, 0.15265067453895295, 0.13128089266163961, 0.07988143752196006, 0.1835951826402119, 0.10151257751775639, 0.12221413132335458, 0.11407561946128096, 0.1353269698364394, 0.19088344941181795, 0.11394509646509375, 0.19299631246498652, 0.1445897463709116, 0.1777364941579955, 0.11903471978647368, 0.18118806609085628, 0.15824567074222223, 0.13057788967021874, 0.18425874917634896, 0.06301675497421197, 0.16572109104267188, 0.10530811920762062, 0.10399974762861218, 0.11328578434352364, 0.16848514415323734, 0.16711219639650413, 0.10110493403460298, 0.12304822728037834, 0.32914770234908375, 0.09116891505462782, 0.14260071595864637, 0.10858648829162121, 0.1308354479925973, 0.11832372365253312, 0.08353998977690935, 0.11304581364882843, 0.21117746829986572, 0.08718218255255904, 0.17922544426151685, 0.1815268179135663, 0.12992828738476547, 0.1566519005490201, 0.11073013647858586, 0.10833421575703792, 0.1847029317702566, 0.10987684476588454, 0.1111372574897749, 0.180188868993095, 0.16515963045614107, 0.14651880785822868, 0.11965221379484449, 0.0993418897102986, 0.12265532836318016, 0.2102083167327302, 0.14878706900136812, 0.17036502542240278, 0.10736319821860109, 0.12448186320917946, 0.15492330544761249, 0.09144425777984516, 0.1519222129136324, 0.12608434579202107, 0.17948426465903008, 0.11175834773374455, 0.08055768587759563, 0.10911493814949479, 0.1386294811964035, 0.1507741723741804, 0.1222684955490487, 0.1067130123930318, 0.10369211342185736, 0.12263125394071851, 0.12080036289989948, 0.10142370300101382, 0.15067946245627745, 0.1355373156922204, 0.08637602188225303, 0.13593567003096851, 0.14811890199780464, 0.14219227858952113, 0.1406620599861656, 0.14972815636013234, 0.12530930952302047, 0.15434418937989644, 0.07024565671703645, 0.16199706015842302, 0.12875651169036115, 0.15072510072163173, 0.1974634884723595, 0.1096911093752299, 0.14470508375338145, 0.20835377196116106, 0.14187291929764406, 0.11340906058571168, 0.1632075530609914, 0.13319227152637073, 0.16620826561536106, 0.1744057150291545, 0.16755283703761442, 0.15879544695573194, 0.11586617838059153, 0.20319561660289764, 0.05748654529452324, 0.1771031767129898, 0.16022769867309503, 0.08194425183215312, 0.20589223690330982, 0.16103872443948472], [0.0267090772478176, 0.037005705359791, 0.007937094678969255, 0.01407585697182055, 0.07264927881104605, 0.017740138606833558, 0.01635345390864781, 0.03705802380240389, 0.017624830062101995, 0.01453054413598563, 0.012858226729024733, 0.019752568299216882, 0.019735869552407945, 0.033955853299370835, 0.011537107173353434, 0.029660872516355345, 0.011913247123759772, 0.014328330522403121, 0.038148724740105014, 0.019122378900647163, 0.03595846119735922, 0.08795704240245478, 0.022475587004529576, 0.04068297500322972, 0.0619748712384275, 0.034409301288958104, 0.008324863871426454, 0.07145776453294925, 0.03466482739895582, 0.06375981867313385, 0.04408870171755552, 0.031444395027522526, 0.0228214990680239, 0.010972574519525682, 0.015385162384648408, 0.03577650185408337, 0.01804961164348892, 0.05898601269083364, 0.04232607808496271, 0.027539734728634357, 0.039963490396205864, 0.010186091364760484, 0.021658181312627027, 0.07237556456987347, 0.05465097798566733, 0.09402058060680117, 0.04433098282398922, 0.10155195290488855, 0.026678994397765825, 0.027688722359016538, 0.015002997891445245, 0.033640219164746146, 0.021879828169143627, 0.02415709347198052, 0.01865691235954208, 0.03173751537022846, 0.06352581908660275, 0.07024015379803521, 0.025887099926226904, 0.007680770442155855, 0.04317639781428235, 0.05889443760471685, 0.024916743959433267, 0.0537385519460908, 0.02576309595523136, 0.0420560381109161, 0.04946688562631607, 0.04277886789558189, 0.05860369891992637, 0.028642696794122458, 0.06976414112640278, 0.05915487291557448, 0.05844822619110346, 0.009626064183456557, 0.0384972949645349, 0.01085508194020284, 0.014279906870797276, 0.01889354466194553, 0.09617751450943095, 0.03132855552913887, 0.01981451006473175, 0.0530348534562758, 0.09749398101121187, 0.06574539534215416, 0.045606808470828195, 0.04047702266169446, 0.026230296153309088, 0.015828596893697977, 0.03974514800523009, 0.032208133688462634, 0.016244223341345787, 0.06952102881457124, 0.03320974297821522, 0.050777323344456296, 0.016767153316842656, 0.12406820112041064, 0.02541220174836261, 0.03287937106298549, 0.048612521828285286, 0.039784557319113185, 0.006265508393490953, 0.01949763421102294, 0.019012602112655128, 0.008311131170817783, 0.039344758061426024, 0.04860884416848421, 0.07989652814077479, 0.05027350091508456, 0.03476528450846672, 0.05908657158059733, 0.031247606301414113, 0.05236979414309774, 0.06270902577255454, 0.04448291699268988, 0.08663015360278742, 0.03789403322818024, 0.013874271851299065, 0.041250444017350674, 0.06757697848869221, 0.020013417516435896, 0.0651418384430664, 0.0647397046642644, 0.09469577044780765, 0.05623809853568673, 0.08937083118196044, 0.03273805257465158, 0.031366326180951934, 0.03711048473737069, 0.009781281613478703, 0.06579036864319018, 0.03196161173816238, 0.035894818005285094, 0.023589180017422353, 0.029053821161921536, 0.012572793339911317, 0.040653166959860494, 0.034476462685103924, 0.01528787742634969, 0.054139169199126105, 0.051868702817176066, 0.036161943671426604, 0.028570755118770257, 0.010668915679811366, 0.020195855226899897, 0.06339013922427382, 0.02828241335893316, 0.01646644525629069, 0.0434485242835113, 0.04893231538257428, 0.05876195364232574, 0.05967584531754255, 0.03139469912275672, 0.005651256934340511, 0.04110846056469849, 0.04665497883356043, 0.035737991599099975, 0.00417821338799383, 0.053716092436973534, 0.016157589686502303, 0.02716649297092642, 0.026713374070823193, 0.033426467063171525, 0.014312805641176445, 0.042091145512780974, 0.054063234345189164, 0.06275821277605635, 0.009205874587808336, 0.04299430954935295, 0.04552004759066871, 0.04357722880584853, 0.0034371797810308635, 0.029149151939366545, 0.07759208751044103, 0.04677838060472693, 0.04354906281722443, 0.03038742745827351, 0.03861267984445606, 0.031333607222352705, 0.08162907231599092, 0.01559506549632975, 0.11377003443028245, 0.031199535488017967, 0.04332294102225985, 0.03822732623666525, 0.014253605157136917, 0.07707606841410909, 0.017510849749669433, 0.028329194955793873, 0.02715145324223808, 0.018595124960743954, 0.0754371349300657, 0.026155424903013876, 0.059167547949722836, 0.03997008914926222, 0.05341420542182667, 0.011907073303258844, 0.044297049287706614, 0.07090215970362936, 0.035586067608424594, 0.02632757941527026, 0.024497448333672116, 0.09089710749685764, 0.04570579994469881, 0.06640312647713081, 0.03079239751345345, 0.03843557881191373, 0.037494186112391095, 0.03725683456286788, 0.013190721610694059, 0.021358056792191098, 0.030127385697726692, 0.03497710957058838, 0.023594727041199803, 0.05017328807818038, 0.01423823633896453, 0.03664820561451571, 0.019657186631645476, 0.02607881829940847, 0.06810581511152641, 0.034188146370330026, 0.048429707530885935, 0.0711932647973299, 0.06398554013243743, 0.047330131355140886, 0.04221164654674275, 0.03246196685358882, 0.044991533271968365, 0.04012770604874406, 0.014028831950521894, 0.04175469053110906, 0.035869091350053034, 0.020929858786985278, 0.07031288596668414, 0.0437737359399242, 0.04418351680838636, 0.03900548715942672, 0.013484160016689981, 0.027403277943709066, 0.038045702768223624, 0.019406681680785756, 0.013192341613051082, 0.059082554653286934, 0.006914946558286569, 0.03433233506179281, 0.04859406906845314, 0.04351398255676031, 0.0858194874599576, 0.023303428565018942, 0.10118080782038824, 0.017845145293644497, 0.017702059221587012, 0.01704230435591723, 0.0458355765523655, 0.014862839697993227, 0.07088780868798494, 0.02611441763916186, 0.06579601405454533, 0.024001420575327108, 0.020532461182613457, 0.009985339145974388, 0.03163954169888582, 0.015005237057006784, 0.05188276206276246, 0.02005831278594477, 0.04850707409371223, 0.06485833294157471, 0.0433224117649453, 0.03954374524099486, 0.04023494850844145, 0.024472066034962024, 0.02875271106937102, 0.06449593417346478, 0.01648306766791003, 0.03668801187138472, 0.08131919215832438, 0.021312454149925282, 0.020770099413182055, 0.026979565054976513, 0.021924158558249474, 0.0226651934374656, 0.029835598676332405, 0.126528175547719, 0.04127393829237137, 0.04740886177335467, 0.04009567919586386, 0.026439522426309328, 0.03165456785687378, 0.08433426251368863, 0.03928252961486578, 0.0025725760413999005, 0.0430933858401009, 0.030486802304429666, 0.004018641883573894, 0.021135054561974745, 0.01929828062254403, 0.03266046888061932, 0.02633660053834319, 0.03266176827518003, 0.07082855901015656, 0.10505558204438005, 0.04097207163327506, 0.01983781434994723, 0.008083689625241926, 0.071358786629779, 0.025237611295389276, 0.02758374620628144, 0.01911765968959246, 0.03634257987141609, 0.005894499864163143, 0.08391971832939557, 0.06882722675800323, 0.047014626142169745, 0.026770179326246892, 0.07723483882312264, 0.06952373616929565, 0.03031245612406305, 0.024534313141235282, 0.06233912240713835, 0.021837672484772544, 0.028794844701353992, 0.01875429061640586, 0.04873569289754544, 0.03156215478000896, 0.06606670881488494, 0.025750456544171487, 0.06355592568538018, 0.09084701125643083, 0.06743099167943001, 0.0357371773570776, 0.03459990516837154, 0.012045407085679471, 0.032488857196377854, 0.028810634211237942, 0.06779527677489178, 0.04813410375001175, 0.05704511755279132, 0.04320385812648705, 0.027744111172588806, 0.025245763893638338, 0.05176400825647371, 0.031985173866684945, 0.05285168292799166, 0.027871100697666407, 0.05697500452931438, 0.0155394154467753, 0.01817739335820079, 0.07540084009191819, 0.041208537694598944, 0.0546111310166972, 0.013520498959613698, 0.039547063277236054, 0.022501920948603323, 0.26320476510695046, 0.07098721406821694, 0.12584638356098107, 0.14662204017596586, 0.16429308695452555, 0.1002496135021959, 0.15910099127462932, 0.13005404706512178, 0.11848100806985583, 0.20233588559286936, 0.05327468505129218, 0.16230066386716707, 0.11000725241111857, 0.1619467128600393, 0.1403554571526391, 0.192275056881564, 0.12887319257216795, 0.11639722702758652, 0.17301687598228455, 0.12691647399749073, 0.1295904583696808, 0.16406410852713244, 0.14397398941218853, 0.10047500247934035, 0.16070963495544024, 0.19354268243270262, 0.0889823834544846, 0.2020825884704079, 0.17174390357519898, 0.09422427681939942, 0.10830940851675612, 0.07842550493244614, 0.10941316107554094, 0.07003793679177761, 0.08749842058335032, 0.269820970083986, 0.15209386870265007, 0.08812101038971118, 0.16158934203641756, 0.1011734525007861, 0.09532275037573916, 0.10411384329199791, 0.17693092381315573, 0.19936386149908814, 0.132566811516881, 0.22694116671170506, 0.12560314232749598, 0.09431504444884402, 0.12947566381522588, 0.15297942475548812, 0.08442648899342332, 0.13659622387162276, 0.09657362968261753, 0.23854161852172442, 0.10091121228677885, 0.14288556495947496, 0.15290828714413301, 0.17811822438878672, 0.1681965496391058, 0.15369385427662305, 0.12897284222500666, 0.08648772231702294, 0.08704448744122471, 0.1861589593546731, 0.17812442619885716, 0.2372408668909754, 0.06451546919665166, 0.1413059082946607, 0.12307524654482092, 0.11120868687118803, 0.2301574227000986, 0.1895292563630002, 0.14639950783124991, 0.07737283927521535, 0.14231419776167187, 0.1364066954702139, 0.15865717508963176, 0.19465895396258148, 0.2300227199281965, 0.09765102115592786, 0.14834770400609287, 0.14876116253435612, 0.17080634459853172, 0.10077726947409765, 0.10435999544071299, 0.15158188688967908, 0.16447555859174046, 0.06458936166018248, 0.16442291784499372, 0.20721908499087605, 0.09438877406397037, 0.12250140947954995, 0.19313111023179122, 0.14232665566461428, 0.17425543309322425, 0.17895628299031938, 0.09143453437302794, 0.08359467291406222, 0.12565327249467373, 0.10787425722394671, 0.1605155739401068, 0.1399206519126892, 0.08207576548946754, 0.08751733135432005, 0.11184007049139057, 0.09037217923573085, 0.15602949394711427, 0.13949626897062573, 0.0814761169520872, 0.1991535292140075, 0.13112147764435836, 0.14238285193485872, 0.12651805180524076, 0.26635238049285753, 0.2200904464615243, 0.13348394658948692, 0.1221029737165996, 0.08759312371590308, 0.11327406604375158, 0.10879512423915522, 0.14042952603527478, 0.11719002734337534, 0.20807882957160473, 0.2054101513432605, 0.1966349429317883, 0.13901001720556191, 0.09596492948808841, 0.2919928346361433, 0.08473221651677575, 0.12715027002351625, 0.08577969816646405, 0.17188408891005175, 0.09384149485932929, 0.12774706871381827, 0.09910461958497763, 0.1482163124850818, 0.21410078715000833, 0.14145137263195856, 0.18911488859781198, 0.114087846662317, 0.12278917618095875, 0.11057456875486033, 0.22810764983296394, 0.11598355136811733, 0.10144100564398936, 0.10307140994284834, 0.10149716798748289, 0.2025153852467026, 0.10612812199230705, 0.23259309200303896, 0.18754323864621775, 0.14282588101923466, 0.09959786026073353, 0.12786042477403367, 0.1055023634274091, 0.10090058642838683, 0.06340111113552536, 0.16688943334988185, 0.14572270986224922, 0.14875734916755132, 0.15681466752929346, 0.10696916614792176, 0.2153414748609066, 0.09394657279231719, 0.12651418415563448, 0.19012262166610785, 0.16107273261461938, 0.18147062164332184, 0.12097039020487241, 0.09243607920195375, 0.16043360690985406, 0.1002031202827181, 0.11821498163044453, 0.17293869517743587, 0.18038777474846157, 0.08722970035991498], [0.0436399966877486, 0.02176656710383083, 0.07265968753823213, 0.07295911825661149, 0.037189513710992675, 0.013444723561406136, 0.07299461242343698, 0.05743668654135295, 0.061869705095887184, 0.030438687386257306, 0.016714571941910044, 0.009530336463025637, 0.03806885099038482, 0.024610943493566344, 0.03911155236086675, 0.0562491111590394, 0.03599176708874958, 0.045578181078391414, 0.038470048390861065, 0.033356628846377134, 0.04532914176317198, 0.029910434303539138, 0.017200396229912127, 0.013442137494816311, 0.03453714746449675, 0.014271918817290237, 0.06186213264507907, 0.029171085583844354, 0.008221239699716014, 0.014487721790958728, 0.06764807538794619, 0.07306879665702581, 0.029318059661558697, 0.005776814326444375, 0.06056870240718126, 0.05727745472852673, 0.010202197241596878, 0.013959953860778893, 0.04612673592886754, 0.05830743017473391, 0.027864926028996706, 0.030440315870302062, 0.002504353162034282, 0.08208434895745345, 0.015798958484083414, 0.026975963730365038, 0.1174803181950535, 0.0072136669353182825, 0.04468543255435569, 0.032999393729759116, 0.03353844569729907, 0.10441288724541664, 0.007214954455516168, 0.022092930573437895, 0.023564483039081097, 0.027243040202717696, 0.01826355543120631, 0.03359013310234461, 0.0014379609534184315, 0.04494029709271022, 0.004812571111999984, 0.02664383949844965, 0.002178227179683745, 0.01921030007568853, 0.023185626404093843, 0.01864413554514093, 0.040075238328427076, 0.04469634000478046, 0.04851815117789166, 0.04426170100591012, 0.008816001936793327, 0.010834506213931101, 0.013060040855115014, 0.021982624528131316, 0.02191645888212536, 0.0438399066749428, 0.031707727682909796, 0.007246803192953978, 0.02382418722845614, 0.031018851790577173, 0.057301278093031476, 0.03819301950612238, 0.006774816354404071, 0.027126802065010582, 0.07873741390981845, 0.00760756414716265, 0.057194456325045655, 0.03197306880195226, 0.02286281676164695, 0.02840455135862742, 0.029850540017443042, 0.020210489530914595, 0.09364794953061001, 0.05173471250704356, 0.02467509049789182, 0.027844583549137627, 0.05827161031109946, 0.0018827527445474906, 0.025938202094818865, 0.011581958338086094, 0.07988170215061732, 0.050335746325020275, 0.054844784550368786, 0.036993535834231546, 0.013280380683551942, 0.022755950888884918, 0.03580896296937551, 0.10054988560399838, 0.014144627344129341, 0.021749115183151195, 0.06514227270547833, 0.038545833967093907, 0.048457449435123374, 0.06073506562305348, 0.04527530000944223, 0.03092593659779855, 0.018778621185837046, 0.02753842176337327, 0.12138629145920277, 0.02144177783546703, 0.046493076985435824, 0.036214119621685574, 0.014582051729251231, 0.08259862421878747, 0.030599164310842752, 0.033185675341103754, 0.04060417673151408, 0.02492239615613861, 0.0023393811549924847, 0.024767980245607238, 0.06122879484402282, 0.034404738140957694, 0.016328483819961548, 0.022356899355405142, 0.02979043199281607, 0.02577618319940354, 0.04284660604649356, 0.06003195406602962, 0.0179386711679399, 0.0289303888566792, 0.03079054511285254, 0.007146368135831186, 0.059037153875189166, 0.08103166972952229, 0.024720194416918924, 0.01169835084250995, 0.06118087670100587, 0.045281461107411554, 0.0587546933176262, 0.019673909127180065, 0.03660974624965872, 0.044874940599714, 0.017439608661723987, 0.03424999822995492, 0.07929772098681756, 0.06770053293023791, 0.020510013547859023, 0.05362060559647424, 0.10503219294228724, 0.05769579192357404, 0.023645025145794665, 0.03822461888194084, 0.07624929384993655, 0.05406183656305075, 0.015847076794930866, 0.06024715144719396, 0.02756800758652389, 0.026455322114218558, 0.04089470846312387, 0.04499811166897416, 0.06284185578780514, 0.024047907009454708, 0.0657342334410974, 0.059265630186668465, 0.03975078323855996, 0.0072670617041045, 0.022380256227084568, 0.028337810654193163, 0.04601983952202967, 0.06088827204491411, 0.04757509267489825, 0.03173817354919655, 0.026766888431406448, 0.05343607121280261, 0.08165959960647992, 0.027381948195397854, 0.05324518234868135, 0.027015485002526214, 0.03388541457908494, 0.032553446944803, 0.04548224301210471, 0.0374371043539473, 0.021169573334710937, 0.03131723417235272, 0.018259356995778422, 0.062288286563541205, 0.03510172252676316, 0.0242584377660283, 0.025621607833142792, 0.05864486563950777, 0.0364024198747107, 0.03675044048577547, 0.05462415888905525, 0.02020721390311207, 0.05872886148946626, 0.010972116508388093, 0.07434531101690871, 0.05901819560676813, 0.013109942864892738, 0.07751125363366944, 0.022900263412988613, 0.02359374486176031, 0.02417667429628117, 0.04290606946285282, 0.009660127489561481, 0.023921945464930365, 0.0033007707055990715, 0.06468135743801083, 0.03315312601625919, 0.036667048531983576, 0.03166106482967734, 0.054859708928103955, 0.08656593704862253, 0.03246757833819304, 0.04072969213926366, 0.017299467431647435, 0.02165775213922773, 0.03972072752990893, 0.03972878513325538, 0.02416443861355739, 0.064236367387431, 0.004111425186108265, 0.05352461324738605, 0.011153425306214817, 0.02673157916537353, 0.02472442847543529, 0.05444510028298412, 0.07287751084991864, 0.02029055666311511, 0.06698817294090986, 0.01229570253885218, 0.03492959176323243, 0.02559997104773564, 0.03621883883274027, 0.04162285117698567, 0.010796748284649636, 0.017888656351715326, 0.03035257789971573, 0.0224018777454538, 0.017784614880968417, 0.05985050701669284, 0.04171528460990105, 0.049011700587081056, 0.080511016239013, 0.027354058709793856, 0.07526813221297093, 0.027589456078463366, 0.07598270422645978, 0.01610562068942402, 0.026101852866954038, 0.025628971634432673, 0.04600459284016064, 0.05008613025503499, 0.05442253899361406, 0.04460835776158741, 0.03281013674235769, 0.03788267455196806, 0.03519082774541207, 0.03512134915217757, 0.018423056961702447, 0.041433200639273436, 0.039529984550816674, 0.07055606613201754, 0.012608634407765098, 0.02128481911495328, 0.08101797010749578, 0.039090337963508706, 0.03612557080175195, 0.011292540252075663, 0.02736893219740263, 0.04733369366398879, 0.06259344411747796, 0.07643474425588336, 0.026891703251749277, 0.03477309105385627, 0.0706814933302147, 0.013271939707919955, 0.034775486282472096, 0.040220482141843865, 0.05498472221993974, 0.09943278626139675, 0.03275223056386624, 0.031210425975067273, 0.025951389422906295, 0.07019456981548242, 0.03526494073282395, 0.011903353235019105, 0.04346926370635629, 0.0035564125906343436, 0.051554700559271235, 0.017818577254989316, 0.008026791071253163, 0.022627514387880052, 0.006554832756851933, 0.022187318187206984, 0.011479469864363117, 0.01818333223595151, 0.024729315623907105, 0.04693591268733144, 0.0219712607629065, 0.012947200481513781, 0.016458299443391815, 0.0702833900494235, 0.07711209183824913, 0.049289173912256956, 0.005178708608062672, 0.07552111042397362, 0.035199136406715424, 0.03558682756764548, 0.06525163219443389, 0.00745275298998292, 0.032475615585488934, 0.07176870320524488, 0.017880951586578573, 0.0190073689113238, 0.05709962427083935, 0.019577129677470242, 0.021959766379690597, 0.029118723036455255, 0.06363892408886127, 0.06181391594665391, 0.02617291414311954, 0.014536315076319235, 0.02520860222700451, 0.11188973246940545, 0.04912750615871378, 0.016847892198711634, 0.02919202178184475, 0.033730260761720796, 0.03528553766331502, 0.026562730814995508, 0.047090428681778054, 0.016273135718490397, 0.002029158125099327, 0.032581914881510396, 0.055562891731304784, 0.017477267355258976, 0.015299041023744004, 0.059369154274463654, 0.015108203049749136, 0.029977185185998678, 0.009222893942413586, 0.08652639202773571, 0.07357449523572411, 0.15411037978317055, 0.1642174981534481, 0.10486204350101096, 0.09000068809837103, 0.09060244009430919, 0.14092263100402697, 0.13248726007129463, 0.11418080595987183, 0.1044270618419562, 0.09248300668384347, 0.09340071851121527, 0.07308115956506558, 0.198688502024327, 0.2995180051241602, 0.12180283053645066, 0.1980679953204734, 0.13793061726859637, 0.1621553623782737, 0.10267627864543881, 0.12172135205141135, 0.12465763092041016, 0.15674490055867604, 0.11277526816619293, 0.159834514771189, 0.14270515606871673, 0.08221890245165143, 0.1597248635121754, 0.10936261700200182, 0.20868633554450103, 0.1924960557371378, 0.11774327765618052, 0.1459413202745574, 0.0990792288045798, 0.12903158978692122, 0.09604538338524954, 0.13743873366287776, 0.07480140190039362, 0.12407235375472478, 0.11583411081561021, 0.17709812841245107, 0.12302697556359427, 0.13603293124054158, 0.10432678115155015, 0.24143918018255914, 0.23307979160121509, 0.11352867273879902, 0.13705997541546822, 0.13155909201928548, 0.07640646970165627, 0.1630595645734242, 0.09750376548618078, 0.15141328450824532, 0.136229027860931, 0.11520061695149966, 0.09019715791302067, 0.06935941534382956, 0.11233844767723765, 0.17757587134838104, 0.11436987295746803, 0.21642969575311455, 0.1352981999516487, 0.20985587207334383, 0.10714437067508698, 0.07797649116920573, 0.08736346675349133, 0.1342337413557938, 0.21749635280242988, 0.10040995811245271, 0.09722238379929747, 0.13232240320316382, 0.1290980183652469, 0.13091907064829553, 0.12168359836297375, 0.12054368667304516, 0.14139338502926485, 0.1358974685094186, 0.13199002960962908, 0.113729702308774, 0.11870035129998412, 0.19434059890253202, 0.11471447375203882, 0.13445792932595524, 0.1648197386945997, 0.11631042882800102, 0.15154747159353324, 0.1138889409069504, 0.11011262211416449, 0.11472849228552409, 0.36609778819339617, 0.1254328436085156, 0.20106608872967108, 0.18841500686747686, 0.14740563955690178, 0.0988282658425825, 0.10362912501607623, 0.17896920229707444, 0.06620598491281271, 0.18092301674187183, 0.22550842644912855, 0.12638591389570916, 0.2868302959416594, 0.11004951835743018, 0.04702758616102593, 0.20112936890551023, 0.13159779565674917, 0.31137089910251753, 0.07953454327902623, 0.10295934309916836, 0.12614825022007736, 0.14274905728442328, 0.1010293655895761, 0.1494152567216328, 0.14796805009245872, 0.11087759570883853, 0.12424961424299649, 0.11781510737325464, 0.21547572979969637, 0.11103140602686576, 0.1094221720205886, 0.13482701166399888, 0.0826231057622603, 0.14808823221496173, 0.07841428196323769, 0.0894390307366848, 0.2206213865429163, 0.11743731264557157, 0.14793434047273227, 0.07364340725221805, 0.09594446487192597, 0.13325997575053147, 0.10847305759255375, 0.09405249210872821, 0.1277566496282816, 0.09546828935188906, 0.10028833749571017, 0.2033211455813476, 0.14886997240994657, 0.1032142551349742, 0.1351931355893612, 0.13807211896138533, 0.14748125549937996, 0.2259211250181709, 0.04755581210234335, 0.09627013453947646, 0.15849070330815657, 0.10257347380476338, 0.08344631123223475, 0.07678330090961286, 0.1010159170255065, 0.13575256057083607, 0.11831368133425713, 0.18827942200005054, 0.23686976251857622, 0.1294843762048653, 0.09071769605257682, 0.1261405692036663, 0.2712724921958787, 0.1887209311659847, 0.10686955720718418, 0.1905148420482874, 0.15355046625648225, 0.19199240633419581, 0.1020472834685019, 0.1421991725053106, 0.11545912522290434, 0.16567492352000304, 0.13806270089532646, 0.1335807463952473, 0.10480455801423107, 0.07890163295503173, 0.11812711134552956, 0.09098212793469429, 0.061834570552621565, 0.14782023802399635], [0.046152079211814065, 0.018799163833526627, 0.04309868859127164, 0.030921108821140866, 0.03925960870193584, 0.029380932716386657, 0.0028793936736682163, 0.033376665985477824, 0.09104667018566813, 0.03458919110042708, 0.033619171008467674, 0.05593050843370812, 0.02443904003926686, 0.015598922967910767, 0.015819085529074073, 0.027387194967429553, 0.007015245060236859, 0.04717165271618536, 0.011540362445105399, 0.021510520218206302, 0.02941992812390838, 0.049450190272182226, 0.01273477406773184, 0.012066247440608484, 0.03026354731991887, 0.026907745515927672, 0.052808178655271015, 0.04558383666777185, 0.03871955589524337, 0.023148887125509124, 0.031125503924808333, 0.020368328650615046, 0.021036169957369566, 0.03949611208268574, 0.03462906860347305, 0.05085498846269079, 0.05289070208423904, 0.019594836048781872, 0.051259605679661036, 0.0681929729346718, 0.05018716751198683, 0.040132082599614344, 0.018241089136738862, 0.11636188892381531, 0.10433861480227538, 0.00852211909036019, 0.036298885608890226, 0.04069201308967812, 0.04359389362590654, 0.03384839031579239, 0.02298786737290876, 0.05461745496307101, 0.06786205140607697, 0.05316575982474855, 0.03845866935859833, 0.0373366472444364, 0.03226308484694787, 0.008819965429471006, 0.03602994825424893, 0.009966152720153332, 0.04344874820006745, 0.049978568883878846, 0.022276794903778603, 0.040966032671609094, 0.026310079997139316, 0.021035462584612623, 0.012623106711544096, 0.023624884530103633, 0.012492537914243127, 0.029819731134921312, 0.03492715921519058, 0.015402251289093068, 0.00347895612191808, 0.05220369555588279, 0.03890171540634973, 0.057273702429873605, 0.08461254329553672, 0.01879261257792158, 0.009224329043978026, 0.062278074611510546, 0.040501205649759085, 0.06809171515383891, 0.031756097051714144, 0.030183907664780105, 0.014774297663409795, 0.09732624036925179, 0.09245648274996451, 0.037151142555688105, 0.07668607362679072, 0.04112150200775691, 0.059260052628815174, 0.04266710299998522, 0.016674714794914638, 0.015350217831188014, 0.021166319759296517, 0.04600356825228248, 0.017549032611506324, 0.02519542507694236, 0.02739338999214981, 0.03767268153439675, 0.06551377741353852, 0.03953691578603216, 0.010674800274760594, 0.05904218860502754, 0.10362739475177866, 0.03227593630020108, 0.0540497111422675, 0.03521558070289237, 0.037681957108101675, 0.033784679270216396, 0.02086418677520539, 0.04296255411048021, 0.003680927795358002, 0.019251366711354682, 0.022226771605866294, 0.061932618862816265, 0.06014111677982977, 0.028750190311776738, 0.03662280126341751, 0.031352765658604245, 0.015126543851303203, 0.019142042845487595, 0.04540978565013834, 0.05086599090801818, 0.021739454540823187, 0.021526236785575747, 0.06456394373838391, 0.0695069424275841, 0.020067683354552304, 0.015862616943195462, 0.04468314249866775, 0.05565584424350943, 0.017880912570815, 0.013647781102918088, 0.05009452373321567, 0.06581157964787313, 0.04499041708186269, 0.02101754586744521, 0.01851478811087353, 0.008231186174920626, 0.005950495118408331, 0.01776806541186358, 0.02651958616583475, 0.023405780483569418, 0.017414870971281613, 0.015381126797624996, 0.02580654594515051, 0.017969244259542654, 0.05706818774342537, 0.024295852186956575, 0.028372324337916713, 0.021399192977696657, 0.029081688595137427, 0.05360698400597487, 0.04196590830438903, 0.01236327105600919, 0.0458119838897671, 0.01927274904612984, 0.03926068417994039, 0.05803750215896538, 0.032060660887509584, 0.0316264459730259, 0.048466728401503394, 0.00931040121109358, 0.015339698842061418, 0.02024859096854925, 0.036665813598249636, 0.015740562064040984, 0.01612142037733325, 0.032929012684949806, 0.052922576266740046, 0.012911483246300901, 0.06347916980407067, 0.011397232268271702, 0.009554885860000337, 0.023079159170655266, 0.05075286554970911, 0.036472020604248555, 0.04083187272772193, 0.0277714764898909, 0.018552041379734874, 0.0156023699258055, 0.0248721218002694, 0.035670161845960786, 0.015967969682865908, 0.023665347269603183, 0.00729719883695777, 0.03668625107301133, 0.03142213907891086, 0.05659494688734412, 0.037059106065758636, 0.03984015987121633, 0.029321567687605108, 0.062210187182894776, 0.015035097686839955, 0.01799293700605631, 0.08841354719230107, 0.05415454140997358, 0.04683388816192746, 0.04897730903966086, 0.0323042854932802, 0.015765086015952483, 0.048152013681828976, 0.050716730167290995, 0.018408636396218623, 0.03362273670999067, 0.07341863574194056, 0.015443119453266263, 0.0423571074913655, 0.064720732825143, 0.024433414983962263, 0.04042238362931779, 0.0410064937147711, 0.05779590976557561, 0.04756293332736407, 0.034964940045028925, 0.029122387125555958, 0.03189992272694196, 0.02114771263274763, 0.03831969181607876, 0.07342034565018755, 0.017096894194505045, 0.03797649558899658, 0.03393133782914706, 0.031219738868198225, 0.0631719155769263, 0.014819888431312782, 0.0742910010740161, 0.04066845096115555, 0.04357898960422192, 0.050040508953056166, 0.0421980656683445, 0.02817754746813859, 0.02434740218866084, 0.03597837280748146, 0.009850251305449222, 0.05560154787131718, 0.035763921814837625, 0.05780002847313881, 0.023764150450006127, 0.02081907437449055, 0.044552690748657496, 0.023125518379466872, 0.02921377561454262, 0.03292954533493944, 0.027024646921615516, 0.02441534898909075, 0.030547785639230694, 0.027654128947428296, 0.06427823299808161, 0.021050984073164206, 0.003457858135724174, 0.041439076752534935, 0.02462925376104457, 0.045318634648408206, 0.0885531964844891, 0.021749074471050074, 0.03319888302524175, 0.023197721290801252, 0.052621330467185805, 0.04979899798386863, 0.08051033091864415, 0.07369750684925488, 0.03687470738909074, 0.05110006852607642, 0.033359380305877755, 0.042271557796214304, 0.0267944488275264, 0.03029377605499966, 0.019548390326755385, 0.032755294149475436, 0.08270260971039534, 0.04666522131966693, 0.09137514898819582, 0.013661540096758731, 0.03334406916318195, 0.09438621598695006, 0.03654881380498409, 0.04966449198712196, 0.022126278873266916, 0.13213423187179224, 0.03995848959311843, 0.06525114364922047, 0.012285276000121874, 0.016811266574742537, 0.04807567170688084, 0.01914067559742502, 0.03474562056362629, 0.11714840600533144, 0.03803393357832517, 0.010577808782857443, 0.009415154295441295, 0.02769178764096328, 0.0408682354193713, 0.02896700260628547, 0.03187083053801741, 0.027424851964626993, 0.06897096761635371, 0.009668755910492368, 0.033248365191476684, 0.026993897410907915, 0.037456079585743804, 0.017400078907875077, 0.044220147521368096, 0.04978591922138419, 0.05840284576905625, 0.013336587131821682, 0.03964811410488827, 0.04710667620279959, 0.019404535813789283, 0.04781242386837091, 0.06698997105870928, 0.03832516420100417, 0.060947630288345475, 0.015632881949256574, 0.041403121181896756, 0.020460149705676094, 0.06728744081088475, 0.011517496663145721, 0.024279697964500104, 0.012635801253574235, 0.03978415359077709, 0.02689876001594322, 0.044201772793063095, 0.08052337914705276, 0.033259330317378044, 0.04492110812238284, 0.05422416249556201, 0.032987750068839104, 0.008148097865549582, 0.030529034323990345, 0.03074666764587164, 0.08626444358378649, 0.03106170127700482, 0.028242559604612843, 0.04272161650338343, 0.03492569697222539, 0.04464773654139467, 0.046462454700044224, 0.036752465912806134, 0.034565795212984085, 0.011360465000117463, 0.06969889998435974, 0.07282631538276162, 0.0023371379606292714, 0.049328685006392856, 0.06510107205914599, 0.04412220777677638, 0.010476416991358357, 0.0168971063436142, 0.06970185839704104, 0.056885424336152415, 0.10332496490861688, 0.1643904974418027, 0.16619122081569263, 0.152127632605178, 0.13345102407038212, 0.09721462814403431, 0.08833088127097913, 0.10062535905412265, 0.19883666693099908, 0.10896049000855003, 0.12894732930830546, 0.13036905016217912, 0.0949018754597221, 0.1812780669757298, 0.10352454919900213, 0.1465689923082079, 0.06975531338581017, 0.14075857480721815, 0.06401069342557873, 0.0689385472131627, 0.1180831558470215, 0.1250380583639656, 0.14461167662271432, 0.11354450974613428, 0.08506784029304981, 0.08550945123923676, 0.20622824744454452, 0.11340966448187828, 0.14975782191114767, 0.13237519322761468, 0.14169815581824097, 0.09545007068663836, 0.18916068971157074, 0.2148716707846948, 0.102393132767507, 0.16915084128933294, 0.12486035004258156, 0.18166175138737473, 0.11835595406591892, 0.13246646975832327, 0.12171808151262146, 0.19854322767683438, 0.10856196603604726, 0.26097205919878824, 0.1924834078443902, 0.10808218749506132, 0.10702860581555537, 0.10473515745252371, 0.11515495154474463, 0.22906707120793207, 0.08220959295119558, 0.2108645686613662, 0.2283317292375224, 0.13797017586018356, 0.11864908119397503, 0.19572688665773186, 0.12093882475580488, 0.13398816596184457, 0.07704465224274568, 0.10262548351394278, 0.10299149887370211, 0.16261498842920574, 0.1173393457595791, 0.1177282277494669, 0.2306398610983576, 0.1233794880764825, 0.07879035999732358, 0.1332296316644975, 0.11258276778140239, 0.12767663677888258, 0.12259750360889093, 0.10543688479810953, 0.15233435508395943, 0.13304797426930495, 0.09120453814310686, 0.15435204681541237, 0.144359112318073, 0.11601781738655907, 0.09727496347789254, 0.24125822846378597, 0.1011217956298164, 0.25442962454898016, 0.10194446505712611, 0.11797643585928849, 0.13456128377999577, 0.25407382792660166, 0.2009810275797333, 0.1316278004752738, 0.15247367189398833, 0.1739324504243476, 0.09821746218949556, 0.10018465734486069, 0.08196532712983233, 0.11367238645574876, 0.09837068896740675, 0.16673159253384384, 0.15412708531532968, 0.11846872658601829, 0.16721526586583682, 0.15995462904019014, 0.2629318040396486, 0.12060955885265555, 0.09375456095274005, 0.14057661885661737, 0.19976938116763318, 0.11088432677622352, 0.18217081549976552, 0.08036304132214614, 0.18415187991091184, 0.11455250744308744, 0.11599358011569295, 0.09007561193513018, 0.25520437583327293, 0.15305316794131482, 0.13513480871915817, 0.13959933843995842, 0.1552806491298335, 0.1076559250109962, 0.10804504448814051, 0.14449549785682134, 0.1009553713457925, 0.19493970461189747, 0.1259823212666171, 0.2951264993420669, 0.12499335647693702, 0.11573566895510469, 0.12060774037880556, 0.1667594803231103, 0.17621402442455292, 0.18236360086926393, 0.15456607033099445, 0.1176183322178466, 0.10192260265882526, 0.113707107092653, 0.1928997297904321, 0.09811276423611812, 0.1993438582867384, 0.21423121515129293, 0.09751637945217745, 0.09104865829327277, 0.05638424140800323, 0.12120286987296172, 0.09890665020793676, 0.15657701742436203, 0.08011363899069172, 0.10979747652475323, 0.12527351001543657, 0.180233041622809, 0.13525628005819662, 0.1856607382318803, 0.12218464219144412, 0.14446788148156234, 0.1057483595130699, 0.15650875680148602, 0.15852671994694642, 0.08742274357272045, 0.16525985007839544, 0.09852291829884052, 0.14152675787253038, 0.11728712570454393, 0.1160869329635586, 0.09094921220093966, 0.17485010118356772, 0.20295128971338272, 0.12453972867556981, 0.10375025030225515, 0.12756805760519846, 0.15601440332829952, 0.08017590814935309, 0.10817971333329167, 0.1343767765377249, 0.16875807807913848, 0.08263270024742399, 0.12433205624776227, 0.14175836901579583, 0.1291039487613099], [0.04983857014615621, 0.01075977406331471, 0.04506540198677352, 0.06487747441445078, 0.06178117663200412, 0.005705493510634239, 0.021094274607353976, 0.051074043315436156, 0.04644343536347151, 0.01846413716806897, 0.10451660132301704, 0.02056907323588218, 0.025780278158241084, 0.023016530388434018, 0.02904397901147604, 0.015126494657514351, 0.037046475136386495, 0.0273013738582709, 0.022858469048514962, 0.038192972008671076, 0.012133476690256169, 0.06442002646092858, 0.015843117543097054, 0.01018440944608301, 0.005484436555499477, 0.03613344859331846, 0.032524792410965474, 0.03457589181406157, 0.018282003102025816, 0.10235902281211955, 0.01276040487989251, 0.018810841421197568, 0.05252596237031477, 0.0189188353584281, 0.02089531796186098, 0.06175700042928968, 0.08068463977958475, 0.01015461073257029, 0.04036975645327142, 0.006653538397845945, 0.04919365993035691, 0.0641956077888608, 0.05734918945069824, 0.010196960647590458, 0.019257850113457868, 0.04593646792428834, 0.028407927070345198, 0.010986336057872644, 0.04690906305664352, 0.015016127544056092, 0.04339583603931325, 0.05567967439336436, 0.022457001930368797, 0.022316555359533856, 0.023104522809652344, 0.022534005476960113, 0.05178044915997556, 0.03152166659544621, 0.031862040116850815, 0.022680036390998533, 0.04034596362284251, 0.026367329693000232, 0.0149989538227341, 0.03993688164544957, 0.002131512588156121, 0.02514936781621405, 0.041523276162999015, 0.034202270076743195, 0.04592965543270111, 0.015290671294288976, 0.04788176336192659, 0.023555136219199215, 0.03959003829264215, 0.03145310741716197, 0.05103613695661936, 0.06109071975307805, 0.10168323586029665, 0.007042813513960157, 0.04166011632020984, 0.005947702098637819, 0.006034292920958251, 0.054890148009040525, 0.07154504449239799, 0.046783340695713244, 0.04346352669277361, 0.01346453423944435, 0.02266906956875963, 0.013310037752879518, 0.046626185200044086, 0.05042866491047399, 0.038929243572056293, 0.03469315962865949, 0.03291509593171733, 0.10171395314059087, 0.043314533973378797, 0.03604157495179346, 0.029491730699581758, 0.003556594734878412, 0.022168264923883334, 0.02360275580680796, 0.060276959490563185, 0.020955921317051564, 0.0474238065071404, 0.0038976506080611473, 0.02189384330995381, 0.044896894600242376, 0.04284053315807666, 0.018782744982412884, 0.05067247950604983, 0.04763685293229563, 0.048265342600643635, 0.03959537497056382, 0.037462664768099785, 0.027618901105597615, 0.016739538637921214, 0.05007149764735784, 0.055223817604460886, 0.020743382096822773, 0.019680921786597798, 0.01669732527807355, 0.06560074524687869, 0.07559089775064162, 0.027372374066284726, 0.030128003164593662, 0.05323000691298928, 0.06028268632612058, 0.010307567792811563, 0.0012668759819851922, 0.02065113017202488, 0.031146569044462273, 0.04642080282792449, 0.015241857485047408, 0.017327748771224703, 0.02732849320662873, 0.0059588902929265586, 0.04450862668454647, 0.04877404708947454, 0.01213347923476249, 0.03912954371688621, 0.008907295430877378, 0.07690450761999403, 0.017316524105678712, 0.05636771568762405, 0.03164627955162099, 0.02662003648999546, 0.06256101692893676, 0.026863148801827004, 0.05193542316555977, 0.03544081361698253, 0.01309856552896755, 0.030902679810034375, 0.043572672443198304, 0.02334944680998368, 0.032764237241021225, 0.026883369145382727, 0.04270188470504113, 0.019132277030231695, 0.0010594771946281461, 0.08583714294114284, 0.019958797143772244, 0.024601001259205595, 0.08052992022463254, 0.0974824255598443, 0.0425470260504101, 0.0471139534908746, 0.030466564997498478, 0.011576209450140595, 0.023897295984040414, 0.02623142421777759, 0.05580249262441482, 0.025304597968767797, 0.0394843836048884, 0.03855729103088379, 0.032707698310592344, 0.017166096284719448, 0.037805742251553705, 0.03092733777261206, 0.022077794153509394, 0.009164325344110174, 0.03286636693935309, 0.02178999182901212, 0.0037143422523513436, 0.06511390994169883, 0.0648671267554164, 0.010341004302193011, 0.022786542640200684, 0.053580168302037885, 0.05427463871559926, 0.04854212721277561, 0.05911494791507721, 0.036893635123435936, 0.01692259551158973, 0.028396794007026722, 0.03815322342727866, 0.021921848146510974, 0.048422036692500114, 0.06227608650390591, 0.004711730630203549, 0.03302306103120957, 0.039501774457416365, 0.032279559677200656, 0.029578508543116704, 0.03625134405280862, 0.029029074989791428, 0.02512104746087321, 0.04876920234944139, 0.024431582939411913, 0.03898504629198994, 0.016915691417774985, 0.01015491268065359, 0.05356102004381163, 0.029117525422147343, 0.005233129661064595, 0.020310239267668555, 0.09115120529064111, 0.047146384072090895, 0.024913174865235175, 0.03700669941359332, 0.024299974287194864, 0.017389120567323904, 0.042658468641872914, 0.02909092345674123, 0.05344424416710224, 0.02912790361525757, 0.035200076177716255, 0.03137816322435226, 0.05864546275032418, 0.030038365295955112, 0.06614353933504649, 0.022500870915661966, 0.024351288497980152, 0.031147274720881666, 0.051328826429588456, 0.03750624367967248, 0.04400733858346939, 0.11052616885198013, 0.05667198096801128, 0.048467719062630615, 0.05919222626835108, 0.05335396508287106, 0.07601561996021441, 0.05522464541718364, 0.06405591099922146, 0.057080299593508244, 0.09602283566657986, 0.06513320747762918, 0.059664174515221796, 0.022878830188087056, 0.04911740955763629, 0.030355495600295917, 0.04495351495487349, 0.04253513811688338, 0.032147934061608145, 0.029212371047054018, 0.04981989346976791, 0.02911688420655472, 0.04028231703809329, 0.023249561366225992, 0.019387221296450922, 0.022213126266641275, 0.022082012944987843, 0.0328821259151612, 0.04563803804506149, 0.048708334365593534, 0.040966093739760776, 0.01585392321326903, 0.025844713539949486, 0.007435977059815611, 0.0590365839057735, 0.09298484439828567, 0.02213703195697495, 0.024954506129558598, 0.030087423377803395, 0.05953675242406981, 0.008206417102233639, 0.04645507902439151, 0.036284310676689656, 0.026352898949491124, 0.050034062870379, 0.019576641132256815, 0.003611846569193793, 0.09653411180313144, 0.04031714963327561, 0.019642964537654604, 0.045423132433955155, 0.006945342382615698, 0.035182111963097534, 0.03599251686994519, 0.0310579455856766, 0.05719665477850607, 0.03687897876703313, 0.04229149654773729, 0.029253866856119463, 0.012574728861052011, 0.003306953007787732, 0.013623107025133712, 0.036694678477942944, 0.042584430293313096, 0.0320641146307545, 0.03378389556226986, 0.03237297359321799, 0.005697560164013079, 0.04656207381880709, 0.0212416591987546, 0.021296498398961763, 0.04775138285809329, 0.052696237340569496, 0.04743858499984656, 0.0015884531291833679, 0.035491802130958865, 0.027573965123987625, 0.03424878704494663, 0.018351715789841752, 0.05529871769249439, 0.09469762963375875, 0.022844481049105525, 0.08436572618250336, 0.041799042972603014, 0.04397580027580261, 0.022191876246194755, 0.03961688792333007, 0.019131069237898504, 0.10790572089276143, 0.03538961475715041, 0.04526685903381024, 0.05418456658454878, 0.03431425549622093, 0.05497325158544949, 0.02303089158210371, 0.001726795287270631, 0.06636153906583786, 0.07281827474279062, 0.00982464593835175, 0.007385185320994684, 0.06729661460433688, 0.04053976679486888, 0.03542053559795022, 0.027566989783995917, 0.07578874499137912, 0.02079644183894353, 0.019275461489866887, 0.03482251554461462, 0.015834662996764694, 0.02884192146094782, 0.056841984524258544, 0.04557699364210878, 0.028885961776333194, 0.0566157405929906, 0.055745404080620835, 0.031542219421161075, 0.057264718626226695, 0.026975437865725586, 0.09777475880192858, 0.0781323913750904, 0.08898998304669346, 0.18686247803270817, 0.22255605272948742, 0.06863383070698806, 0.11937276593276433, 0.11865294884358134, 0.20311293032552513, 0.061031252944043705, 0.2993433502103601, 0.13513661362230778, 0.1570092306605407, 0.19044202167008603, 0.16224779241851398, 0.11549698747694492, 0.12785958339061054, 0.1342070342174598, 0.09188363634582077, 0.101855861954391, 0.1643387387905802, 0.20979048843894685, 0.10367018317005464, 0.09847561762269054, 0.10521573666483164, 0.17519353489790643, 0.1587208623864821, 0.1645279550658805, 0.1737765637891633, 0.11313622844006334, 0.12271274599645819, 0.08446368628314563, 0.09150587554488863, 0.2568809544401509, 0.09035322096730981, 0.13038298727146216, 0.21659129565315588, 0.11620079113968781, 0.183679090280618, 0.16306891478598118, 0.07828799981091704, 0.1940157027649028, 0.11440724666629519, 0.09731625233377729, 0.11848939476268631, 0.1449250512357269, 0.11556239825274263, 0.08881133834698371, 0.143697839230299, 0.07814476106848035, 0.13685357863349573, 0.12148473331970827, 0.18917203481708253, 0.09459958132356405, 0.08921670873782464, 0.14796361247343676, 0.08827395896826472, 0.07972529982881886, 0.14420113579503127, 0.1319466440805367, 0.07368569355458021, 0.15135930026216166, 0.13434481753834657, 0.14863924336220535, 0.20166451590401785, 0.18722861552877085, 0.13392913341522217, 0.17764257134071418, 0.22997761092015676, 0.11159311767135348, 0.24771999887057713, 0.09621245227754116, 0.1277941454734121, 0.10868806498391287, 0.13617804273962975, 0.15864241016762598, 0.13382799098534243, 0.11569889235709395, 0.1152364978832858, 0.11926854295389992, 0.10232311473893267, 0.18715059757232666, 0.10193848716361181, 0.14854287781885692, 0.15645997013364518, 0.1691777112760714, 0.12290230153926782, 0.2333664319344929, 0.12873977901680128, 0.11830739809998445, 0.12651284065629753, 0.0896687148404973, 0.16341085572327885, 0.16220638821167604, 0.11460144338863236, 0.15382544935813972, 0.0954897581998791, 0.15650206644620213, 0.1044074318238667, 0.110129232651421, 0.13020158771957668, 0.14189266466668674, 0.15822568110057286, 0.10470231635762112, 0.11474618847881045, 0.12354587843375546, 0.10381475184112787, 0.07871447942618813, 0.1954531113484076, 0.14560049213469028, 0.10104617290198803, 0.10899453889578581, 0.11407673225871154, 0.12407000602356025, 0.1630964633077383, 0.1244252191058227, 0.1584733599530799, 0.07957374903240375, 0.06702142115682364, 0.12469537103814737, 0.11717861438436167, 0.14405526433672222, 0.11970223539641925, 0.13260817501161778, 0.14868823359055178, 0.10177986603230238, 0.08320639482034103, 0.12229163359318461, 0.1127596754314644, 0.1285631020686456, 0.19846132850008352, 0.07419887637453419, 0.09260084786053215, 0.11763920395502023, 0.07875009572931699, 0.09541727030383688, 0.1131877088919282, 0.10295763319092137, 0.2479212252157075, 0.05924975246723209, 0.15746500263256685, 0.12718149620507443, 0.16293764540127345, 0.11524743586778641, 0.08224500569381885, 0.1420015695371798, 0.19674414635768958, 0.1322860744382654, 0.10009853089494364, 0.1777573658951691, 0.0957956960690873, 0.13110987469553947, 0.05812771338969469, 0.060125632610704215, 0.14763365446456841, 0.17471986317208835, 0.05770724559468882, 0.11227012598620993, 0.16949249724192278, 0.2019654597554888, 0.19479999425155775, 0.10864689826433148, 0.26252964990479605, 0.15042586677840777, 0.1734248926596982, 0.1471459234931639, 0.10240231334630932, 0.10079702162849051, 0.08505319750734738, 0.1727568885045392, 0.18668806739151478, 0.19130616315773555, 0.12592668139508792, 0.16360293541635784, 0.1498382283108575, 0.08778442309371062], [0.04585630240451012, 0.03790893724986485, 0.03088430847440447, 0.08920013891266924, 0.041812505107373, 0.04990626758496676, 0.017306972028953687, 0.014234989548900297, 0.057338393958551545, 0.010362255170808306, 0.048472112576876364, 0.012487027361722929, 0.004104020672717265, 0.014278502303308674, 0.023708551290578077, 0.02813282352872193, 0.022507707155974846, 0.010489881670634662, 0.061755141243338585, 0.013265569960432393, 0.04311183859993305, 0.0022545969321592046, 0.0481167061121336, 0.0725967398445521, 0.025449980881863406, 0.0354964500958366, 0.02160493836605123, 0.021008913205670457, 0.054876604450068305, 0.031315836390214305, 0.053378297348639796, 0.028812215197831392, 0.004520591132209769, 0.0379496764923845, 0.029274809839470044, 0.03421945058341537, 0.01734483428299427, 0.030559887311288288, 0.09741216325866324, 0.02208550400765879, 0.0443518783098885, 0.08465955220162868, 0.05261012106867773, 0.033289114612021616, 0.05221304237576468, 0.01943167551819767, 0.009784090748455907, 0.04868509114852973, 0.0689996425062418, 0.05796455964446068, 0.03860793009932552, 0.0789872437183346, 0.026883235134716545, 0.07331957641456809, 0.043476408680102656, 0.011123886132346732, 0.05656696410317506, 0.03734657421175923, 0.032902481965720654, 0.008300674098011638, 0.01742799044586718, 0.033663374172257524, 0.005882033055448639, 0.03643371730244585, 0.0163433929306588, 0.0240359647931265, 0.023015191978109733, 0.0055265952084612635, 0.025438415252470543, 0.033328903905515156, 0.05447971235428538, 0.02346193095270012, 0.04106760257855058, 0.046391177989010296, 0.019687457775164927, 0.0426623905742807, 0.01897309610753187, 0.0217540566144245, 0.023472556811092154, 0.10161148756742477, 0.02796583266795746, 0.018816022036064948, 0.014649398026189633, 0.029599973998431648, 0.03772649953940085, 0.03924586158245802, 0.02512188714795879, 0.026036990008183887, 0.023450041322835853, 0.008715196229916598, 0.02140540157311729, 0.04523206375805395, 0.024694320180320313, 0.028580610839916126, 0.0334509282505938, 0.04561760396297489, 0.06623940276248114, 0.05197986720928124, 0.022516877556751882, 0.05522663013211318, 0.02091265792426254, 0.004874313133768737, 0.021941829306472625, 0.01454030825490398, 0.056745042226144245, 0.05080570985696145, 0.03204089516241636, 0.09108968930585043, 0.05165348507996116, 0.023978828751881207, 0.04386976560843842, 0.07391233782150916, 0.022392237459176352, 0.03524014027789235, 0.04201028110193355, 0.06071308787379946, 0.014166427826109742, 0.042241441019411595, 0.02932077719430838, 0.01997506502084434, 0.011732527803230499, 0.008557209528849592, 0.02870148846081325, 0.07305802830627986, 0.06386573798954487, 0.028229034705353633, 0.04211362537794879, 0.03338473037417446, 0.05041519599035382, 0.02230752066576055, 0.06204042450657912, 0.007726094036895249, 0.08628912190241472, 0.01188580207859299, 0.05251162831804582, 0.07645494424338851, 0.024588897890810455, 0.0010339172045600467, 0.032120039486991506, 0.023999978688412478, 0.06419452213283096, 0.029291803749012094, 0.018453190701880624, 0.006922331139711397, 0.03959779055523021, 0.009943360728876931, 0.031717712325709205, 0.003841408960787313, 0.06834595543997628, 0.031017820417348827, 0.047148480745298524, 0.027779920858197978, 0.012852085987105966, 0.028229499501841407, 0.00967094418592751, 0.037685244610267024, 0.027862798821713244, 0.07953291479498148, 0.012406626899194504, 0.014832599088549614, 0.014575032284483314, 0.058028796554676125, 0.009898156725934573, 0.0666577670989292, 0.031588183383324316, 0.003081559365715033, 0.013919553037599793, 0.06431895188455071, 0.07003328882689987, 0.011442496491196965, 0.02595240722543427, 0.008998890024875956, 0.04314635567633169, 0.011438177615803267, 0.02011088907186474, 0.035832202793764215, 0.061315993379269323, 0.052139852195978165, 0.06731089776647942, 0.041724085209092925, 0.07738329549985272, 0.029885952760066305, 0.03598941257223487, 0.05865414799856288, 0.04268652606489403, 0.036415960041007826, 0.02508805539192898, 0.04465484758839011, 0.03196363377251795, 0.026248721771740487, 0.03139203248013343, 0.06462352589837142, 0.04819662396663001, 0.015627097438222597, 0.07231507317296096, 0.02622327670854117, 0.0241431716297354, 0.044855809304863214, 0.040637733680861335, 0.004656382528732398, 0.04038569863353457, 0.02449256457787539, 0.014068062300793827, 0.05621362038488899, 0.08286722230591945, 0.02401145950092801, 0.04382867692038417, 0.05615942918562463, 0.01319711934775114, 0.03157745235200439, 0.02013753853472216, 0.02796284032852522, 0.0035728312297058956, 0.025555328532521213, 0.08927738333919219, 0.08191785681992769, 0.018626072942944508, 0.010077954935176032, 0.05814396430339132, 0.0902138159477285, 0.028982754796743393, 0.060231728346220086, 0.014450504145185863, 0.008817489624821713, 0.046956431586295366, 0.05097820024405207, 0.018766443178589855, 0.011299714911729097, 0.019252730566742163, 0.04740676849282213, 0.0362385061702558, 0.0025351382958303604, 0.04682105027937463, 0.04223443853801914, 0.012965252905684923, 0.013770498401884521, 0.011907817995441812, 0.03292617980124695, 0.028926300683191845, 0.06190695666841098, 0.03092135987909777, 0.040229608437844684, 0.029180276340671947, 0.05031382964391794, 0.12045648135244846, 0.022805675631389022, 0.041867595365537066, 0.03634861883308206, 0.06971642654389143, 0.03919775684231094, 0.012491834782330053, 0.019612632325983474, 0.005004159291274846, 0.009466884957094277, 0.03813610738143325, 0.03223971610090562, 0.06888250022062234, 0.026205170001568537, 0.11493009861026492, 0.008647503031949912, 0.002864587615476921, 0.040446373234902105, 0.034761997006301365, 0.033585030519004376, 0.050037211272865534, 0.022912139472152506, 0.025675117104713405, 0.03665253466793469, 0.021055413210498433, 0.02884189092687198, 0.03999057751415031, 0.021027153923309276, 0.06342131112303052, 0.008288204320706427, 0.02734262539472963, 0.04676999051922134, 0.015208646588559662, 0.05844086408615112, 0.08516019569443804, 0.010587972389268023, 0.061116015538573265, 0.01760222466795572, 0.014178530346336109, 0.026330946645300304, 0.07488055301031896, 0.035659980428005965, 0.011851982196926006, 0.023642714734056165, 0.0586993723575558, 0.02151869486884347, 0.029177585949323008, 0.038242695054837635, 0.018243318124275123, 0.04855275307116764, 0.020134749755795513, 0.09089283272624016, 0.07450302969664335, 0.007901343517005444, 0.017707619816064835, 0.096517467339124, 0.028116855903395584, 0.04388251867411392, 0.15762073999004705, 0.024022529799757258, 0.02745633090047964, 0.011647830517696483, 0.04139483626931906, 0.027373200182669928, 0.05629949577684913, 0.014673150144517422, 0.016425829846411943, 0.01824465483826186, 0.016653831183378185, 0.0662720063701272, 0.019638630395222987, 0.011372059467248619, 0.013072925386950374, 0.024458044108801653, 0.016778260935097933, 0.10007540642150811, 0.07507947912173611, 0.015274517071832503, 0.028449365203934054, 0.03628267540729471, 0.006057828756248844, 0.032511238673967977, 0.059065564136419973, 0.012905762347924923, 0.0453728563817484, 0.032372145780495236, 0.0742985735248242, 0.051922279942248545, 0.02312676518756364, 0.075855981026377, 0.016473094899473444, 0.015746648523158262, 0.01448034611530602, 0.05758095665701798, 0.06545935890504292, 0.023027851745220165, 0.06589782144874334, 0.040274995645242076, 0.007035685503589255, 0.02239122474566102, 0.021645716624334455, 0.03460131652121033, 0.02979552439813103, 0.02755440804841263, 0.0409763701526182, 0.043333872221410275, 0.03436855865376336, 0.012672763600546335, 0.14216751206134046, 0.09354409974600587, 0.09810601959803275, 0.16058677940496377, 0.12251964850085122, 0.1538176326347249, 0.1783948088330882, 0.13877333062035696, 0.14066001081040927, 0.14235047224376882, 0.10180388617196254, 0.10361495041953665, 0.07212495444608585, 0.07106694193290812, 0.13459990599325725, 0.13159595004149846, 0.10751177024628435, 0.09837364738008805, 0.16569601238838264, 0.09636242208736283, 0.09616658331028052, 0.1555157343723944, 0.12108020431229047, 0.18371570403022425, 0.13957136922648974, 0.08459752731557403, 0.13921688896204742, 0.19138139912060328, 0.21238394427512372, 0.11074159014970064, 0.16256046135510716, 0.14823822916618415, 0.10705814244491713, 0.13490893798215048, 0.14863956905901432, 0.10575450025498867, 0.11518256792000361, 0.10587092329348836, 0.18671649800879614, 0.2287771739065647, 0.12074450589716434, 0.17419923682297977, 0.1315219354416643, 0.12445901014975139, 0.11579928839845316, 0.16535435643579277, 0.10655234208596603, 0.0967749578080007, 0.14615333532648428, 0.17150762411100523, 0.12884177640080452, 0.16906625511390821, 0.09673590811767749, 0.14679495804011822, 0.24485468119382858, 0.056530648908976994, 0.13461357168853283, 0.2049665522894689, 0.11092052661946841, 0.15270056043352398, 0.09933711282376732, 0.10473694199962275, 0.10242178730134453, 0.1329612032111202, 0.11676766643566744, 0.11147127992340497, 0.15238163540405886, 0.1253911815583706, 0.1958255185080426, 0.09234321489930153, 0.08542243590844528, 0.15879995242825576, 0.12293442338705063, 0.14839520145739826, 0.12501870654523373, 0.07944564162088291, 0.17689148735787186, 0.08520604430564813, 0.08471154834010772, 0.22698816204709665, 0.17923772574535438, 0.08000524302146264, 0.2533707299402782, 0.13215567357838154, 0.06554500359509673, 0.1179668956569263, 0.12245374917984009, 0.10577398778072425, 0.06982494464942388, 0.09934625269046851, 0.0831809633278421, 0.1134677402941244, 0.10659914064620223, 0.1634989431393998, 0.1394818297454289, 0.18176712787577085, 0.1582786746855293, 0.126832905624594, 0.06220974613513265, 0.13332240097224712, 0.0782052796067936, 0.0936582496921931, 0.23945818362491472, 0.13676592547978672, 0.27181822434067726, 0.07319602197302238, 0.12473221548965999, 0.12222390222762312, 0.11235595388071877, 0.08245721752090113, 0.16644538646297796, 0.25337862808789524, 0.11486651987901755, 0.16636492578046663, 0.1584159287491015, 0.11827796325087547, 0.08861991004752261, 0.08579873785908733, 0.12582395119326456, 0.12348076621336596, 0.14053264978740895, 0.12821943765240057, 0.10282979040805783, 0.24616048112511635, 0.16169553276683601, 0.08961842182491507, 0.22641790764672415, 0.09260874600814921, 0.14641134148197515, 0.09308051783591509, 0.09284716285765171, 0.07597298081964254, 0.14136091034327233, 0.0936036751206432, 0.12876780251307146, 0.12149814117167677, 0.13983664927738054, 0.08730651730937616, 0.14228857627936772, 0.1596322977649314, 0.1282241331147296, 0.08320206576692206, 0.0680695813415306, 0.2384595429258687, 0.15853353243853363, 0.04706584196537733, 0.11796505004167557, 0.15706838534346648, 0.1521129355366741, 0.13556958681770734, 0.14110907885645116, 0.11103202349373273, 0.0972128843090364, 0.13111119105347566, 0.13111200529549802, 0.12596617213317327, 0.11370080350232975, 0.1430266188191516, 0.0769143599484648, 0.0835470397557531, 0.14307725110224315, 0.1610975805670023, 0.12918506083743914, 0.16070085471229895, 0.12095760660512106, 0.11912413713123117, 0.10204740560480527, 0.0828427407624466, 0.11046257655003242, 0.08611863319362913, 0.1404405047318765, 0.13842266372271947, 0.10930830705910921, 0.15962275756256922, 0.11675252153405122, 0.09940483740397862], [0.04490304212751133, 0.06484117279095308, 0.04845650966412254, 0.028936125870261873, 0.0270108489120113, 0.03130899675722633, 0.015058147521423442, 0.031488917102771144, 0.01704854178907616, 0.022692811509062136, 0.057268952684743066, 0.027652812589492117, 0.015876420041812316, 0.018635935449440564, 0.021951875017423714, 0.017689991476280347, 0.043574060047311444, 0.017224172096965567, 0.01693166752478906, 0.05725599945123706, 0.025468236866540143, 0.050679013798279424, 0.10924339161387511, 0.034398471870060475, 0.0423897891305387, 0.04151639921058502, 0.03184483586145299, 0.02419649769685098, 0.07487504330596753, 0.020181626347558837, 0.028074949580643858, 0.024762097346995558, 0.015970968807648336, 0.048179172045950375, 0.02781675004267267, 0.046959573203431706, 0.004873322048557124, 0.044856426771730185, 0.04111778363585472, 0.025169859573777233, 0.040148235125733275, 0.04336215356098754, 0.08177478771124568, 0.012699619168415666, 0.022388480071510588, 0.027304830994190912, 0.07149023921894175, 0.04440215096942016, 0.034095377062580416, 0.03452792278091822, 0.03374227422422596, 0.04327691599194493, 0.012147264521835106, 0.094333527742752, 0.10729628109506198, 0.03539348919210689, 0.04883082689983504, 0.03657267788158996, 0.011807071660379214, 0.026031186837436895, 0.03858465634818588, 0.04534032402027931, 0.019106513055573617, 0.017928045309547867, 0.018784957006573677, 0.05002285686454602, 0.007732573198154569, 0.06733302479343754, 0.03107245944972549, 0.05872908540602241, 0.024439101107418537, 0.029345957628850425, 0.06647897990686552, 0.005647005488364292, 0.017880413847576295, 0.03743637153612716, 0.06419364003730671, 0.05080294482676046, 0.03252119278269155, 0.03249283680426223, 0.06751932336815766, 0.032662443417523584, 0.036065059048788886, 0.024359174771234393, 0.03457003266417554, 0.028106503155348555, 0.0193292218193944, 0.02579799640391554, 0.020180365968761698, 0.05879839097282716, 0.035730792342552116, 0.03606362394722445, 0.029859245621732304, 0.03512171216841255, 0.03090840664559177, 0.017109477626425878, 0.045876081700303724, 0.03956961778125592, 0.04263164954526084, 0.021730031385751705, 0.03270975427169885, 0.02452608081512153, 0.03812318807467818, 0.031214676996959106, 0.021398509353665367, 0.0023377696343231946, 0.06057677697390318, 0.05449915238256965, 0.021916155237704515, 0.05329897999763489, 0.035635122297597785, 0.008741736279002257, 0.044211014440017085, 0.08585384847330195, 0.04579739538686616, 0.03087815416178533, 0.07699180115014315, 0.10588965086000306, 0.09073192493191787, 0.04730509341295276, 0.039328096634043117, 0.03761794411444238, 0.0381241346310292, 0.05388260153787477, 0.035235112333404164, 0.03957597226170557, 0.06065242684313229, 0.02465685995827828, 0.0669009540496128, 0.054836289291935306, 0.042121116404554675, 0.039507776099656305, 0.006663220244393284, 0.023318449633994272, 0.03700379528371351, 0.006850875040981919, 0.015464104845055511, 0.04442306002601981, 0.04783707165292331, 0.044128158528889926, 0.01619404737305428, 0.03281865914219192, 0.03571435822440045, 0.0461700841385339, 0.06111783401242324, 0.02565117838925549, 0.027252716112083623, 0.09930077048816852, 0.030950910079159906, 0.02746167266741395, 0.045273383148014545, 0.01895154922801469, 0.046931848262569735, 0.028913221920707395, 0.08251230099371501, 0.023239088178213154, 0.05031119014269539, 0.004377198871225119, 0.010909265505948236, 0.039035074678914886, 0.02456997354914035, 0.030896606921617473, 0.02205533973340477, 0.039815929385700395, 0.023632456980911747, 0.036088030851845226, 0.029815259589148418, 0.008900881578613604, 0.02938360275168504, 0.03519547571028982, 0.03952986241451331, 0.0435010869987309, 0.03521811503118702, 0.029657252532030855, 0.029097590063299452, 0.014814382119636451, 0.03089668495314462, 0.026572790096646974, 0.006847448863222131, 0.034784280096313784, 0.012758653411375625, 0.024435279258926, 0.05364423218582358, 0.03807772283575364, 0.025713396657790457, 0.015828176201986413, 0.06150727240102632, 0.023985900783113072, 0.08885477815887757, 0.026630357007629106, 0.03535253621105637, 0.06585947064948933, 0.0770874135196209, 0.01774831156113318, 0.05792474999491658, 0.0779165086735572, 0.015240814237456237, 0.038218335647668154, 0.039079033570098023, 0.025198271531345587, 0.03548894889120545, 0.03820562668676887, 0.04631171814565148, 0.0272055850696883, 0.08575872464903764, 0.03341517624046121, 0.014191796554119458, 0.037986459875745435, 0.025648968061432242, 0.061441698776824136, 0.019455928056101714, 0.03945389702650053, 0.007078480707215411, 0.03979443000363452, 0.023443138925358653, 0.015988033963367343, 0.03837818153468626, 0.02693061893140631, 0.060727459245494435, 0.015289088611357977, 0.02655053075536021, 0.009302023848119591, 0.004328946125627096, 0.06608817766287498, 0.03482511433373604, 0.028560176757829528, 0.027889431321195195, 0.025373900142897452, 0.019778535834380558, 0.026171655460659946, 0.07814142946153879, 0.005484450974368623, 0.05535153146567089, 0.013953392427148563, 0.04429647592561586, 0.02460175273673875, 0.07706968339958362, 0.010734107628065561, 0.024410655223099247, 0.04463701229542494, 0.027949552916522537, 0.04001023806631565, 0.0330152137737189, 0.07438134122639894, 0.06942272266106946, 0.039428848906287124, 0.03756460447662643, 0.06486020569822618, 0.10549706406891346, 0.05436935881152749, 0.018758947062971335, 0.028664722040827786, 0.05140956870413252, 0.02555935563785689, 0.0450788675142186, 0.02323807546469782, 0.05825757820691381, 0.030691231334848062, 0.08639498693602425, 0.06112178308623178, 0.0427299658767879, 0.006227898045576045, 0.01179335083413337, 0.028757939181689705, 0.06189758609980345, 0.025766050975237573, 0.05509927589446306, 0.06933360387172018, 0.03151190586920295, 0.045813039011721096, 0.02156719146296382, 0.02938264262463365, 0.017440120955663066, 0.037856927540685446, 0.0687734257163746, 0.026017427843596255, 0.0126164774244119, 0.00940419510672135, 0.017176767944225242, 0.05027653057394283, 0.05362942994439176, 0.057537313284618516, 0.017432434850239327, 0.04437342179673059, 0.040373881946184804, 0.03830554096826485, 0.06181993455226932, 0.014652244480592864, 0.06465866044163704, 0.08651643791901213, 0.03249051960717354, 0.0445385331154934, 0.017821579772446836, 0.06644516850688628, 0.061882617617292066, 0.018468958159376467, 0.01187777500932238, 0.041101013642868826, 0.04187377003420677, 0.03443762334063649, 0.04721261587526117, 0.02777675718867353, 0.006251377477643213, 0.006013520419531102, 0.01844186595241938, 0.0504990968454097, 0.02107525527078126, 0.037359758147171566, 0.09062835334667138, 0.010087064267801387, 0.026478772284463048, 0.03255548254985895, 0.02723643466431115, 0.05042000001828585, 0.0564962064714304, 0.03786720395354288, 0.04912450364125626, 0.03295661209683333, 0.060997224412858486, 0.06137114470558507, 0.023852853636656488, 0.02306347992271185, 0.02437686757184565, 0.03046693140640855, 0.04004553206531065, 0.0409579988169883, 0.009639418600792331, 0.03690667995916946, 0.008283304449703013, 0.054910273357693634, 0.036600752267986536, 0.02916653939921941, 0.10461339434342724, 0.005044176318084023, 0.07991718274674245, 0.04425519385508128, 0.04881564128611769, 0.03598448640799948, 0.018479833379387856, 0.01795566168480686, 0.005503194232005626, 0.025280681305697987, 0.02913961173700435, 0.019513009814545512, 0.008447651568401073, 0.040795089344361, 0.03924612960379038, 0.04637248095657144, 0.0208877031026142, 0.03732712061277457, 0.026677080929013233, 0.03399333557380097, 0.1565469040402344, 0.12882621080747672, 0.16955364681780338, 0.09256119427404233, 0.16752640131328786, 0.1190185435116291, 0.14876979349979333, 0.15255909945283616, 0.14932554082146712, 0.12917580561978476, 0.11512764729559422, 0.0650549316778779, 0.12025935335883073, 0.07662702750946794, 0.12258079807673182, 0.1067230479259576, 0.12259780216429915, 0.12311300023325852, 0.1469448328550373, 0.13322437980345317, 0.19607325164335115, 0.11203332405005183, 0.18369673219110283, 0.14570117316075734, 0.14717014719332966, 0.16068313137761184, 0.1342005609933819, 0.11968984534697873, 0.1918770010982241, 0.09998876428497688, 0.10124065460903303, 0.1282836813479662, 0.07406760698982648, 0.15474870481661387, 0.09638222173920699, 0.1296641608434064, 0.058991732741040845, 0.10148519862975393, 0.1250434730734144, 0.0716842527368239, 0.15535697074873106, 0.09831154106983117, 0.20242097388420785, 0.10676522566271679, 0.12652208230325154, 0.14978746032076223, 0.10061338969639369, 0.12675608188978263, 0.12729253167552607, 0.17306980171373912, 0.16899066631283077, 0.11151060102773563, 0.10120019356587104, 0.2126037081969636, 0.18808523884841374, 0.1855977973235505, 0.1619550995528698, 0.06122221305434193, 0.1341570940400873, 0.21162606137139456, 0.19301145736660275, 0.09293661412916013, 0.14518981560000352, 0.11753821080284459, 0.11071172103817974, 0.12040124860193048, 0.10746109725109168, 0.16323184461465903, 0.15689298404114588, 0.1475351990333625, 0.14798907110733645, 0.09984954925520079, 0.22013871744275093, 0.09544493417654719, 0.12896004505455494, 0.1788589403565441, 0.11753374604242188, 0.07721570413559675, 0.15725329970674856, 0.07948353101632424, 0.1505285291267293, 0.07527328229376248, 0.14235242642462254, 0.07652203778603248, 0.10572826809116773, 0.09319287644965307, 0.09168065259499208, 0.09713433709527765, 0.12845479430896894, 0.0916828103363514, 0.13643486824418816, 0.10922832813646112, 0.19730225498122828, 0.16380486743790762, 0.08124280947127513, 0.1332308937396322, 0.13085892530424253, 0.09045706396656376, 0.17407815903425217, 0.09136980891759906, 0.1439191773533821, 0.09654106678707258, 0.10607133539659636, 0.09985191734241587, 0.2320429358099188, 0.1260156509067331, 0.1252173273158925, 0.12886486016213894, 0.0994557071743267, 0.15879569122833864, 0.14783922343381814, 0.12165839757238116, 0.13078406932098524, 0.19285087526908942, 0.16784102443073476, 0.08315722138753959, 0.13961560970970563, 0.19181878279362405, 0.14780773940895284, 0.08208489178546838, 0.12625909570072377, 0.09137710995439972, 0.13629032671451569, 0.15605852167521203, 0.11363092118075915, 0.10775780704404626, 0.10165218609784331, 0.07756043385182108, 0.12775736887540134, 0.10856630187481642, 0.11230007652193308, 0.08493322573070015, 0.19415041910750525, 0.12164623822484698, 0.13591295267854417, 0.11116533526884657, 0.08164472611887114, 0.11730108995522771, 0.16923639098448412, 0.11115645324545247, 0.13501278098140443, 0.13003552305911267, 0.08768977424395935, 0.1082244287910206, 0.1732221735375268, 0.07145189520503793, 0.11078531494630234, 0.21778243673699244, 0.11857400807951178, 0.06632527815444128, 0.1588891390711069, 0.08881069373871599, 0.08691497546221529, 0.11487118819994585, 0.16773605506334985, 0.08708909433335066, 0.11471604795328208, 0.08445750482912574, 0.1624362894466945, 0.12594276267502988, 0.14530124462076596, 0.0874294000012534, 0.18149586314601557, 0.15807408280670643, 0.11947636465941157, 0.15503838498677525, 0.08199287565158946, 0.15053828646029743, 0.1134896230484758, 0.1376451440155506, 0.1642294539404767, 0.11480104124971799, 0.06905585234718663, 0.12032119504043035, 0.15812870487570763, 0.13808188986565384], [0.04828154601688896, 0.031265682474310906, 0.04191223957708903, 0.03510169877803751, 0.03947664152032562, 0.04275184523846422, 0.051542514070336304, 0.008288700499438813, 0.055749370117804835, 0.029448664081948142, 0.031045630175088133, 0.017135719968272106, 0.04341206320428422, 0.08861091267317533, 0.01941090216860175, 0.015534750518522092, 0.016995027428492904, 0.002578559023926833, 0.023607186640479734, 0.03939991956576705, 0.0360485333284097, 0.003852870689505445, 0.05035308628742184, 0.05009153478645852, 0.06949999422899314, 0.04611085142408099, 0.05516648478806019, 0.04599641649318593, 0.037682628857770135, 0.022666988162589923, 0.023840226099959443, 0.016370756551623344, 0.04029711249417492, 0.05740810664636748, 0.020781902529831444, 0.01479728303716651, 0.030595754672374045, 0.06405302044004202, 0.029913525030549084, 0.024074732891416976, 0.04766040149011782, 0.0783776342868805, 0.041882204224488566, 0.02764624945952424, 0.07164762541651726, 0.029193324569080557, 0.036219785389091284, 0.01219520641357771, 0.03674431670723217, 0.034529785359544415, 0.024721380156864012, 0.05143891873636416, 0.030007892288267612, 0.04276453384331294, 0.08019323793372937, 0.1080505270510912, 0.03435971734247037, 0.11834251907254968, 0.09751515808914389, 0.016827865237636224, 0.018794546402724724, 0.04981980865289058, 0.008995116522003497, 0.017088639816003184, 0.053589301383388896, 0.0344098576876734, 0.01504743006080389, 0.03876223235524126, 0.053648880150701315, 0.01053368704326983, 0.06435241044632026, 0.006794904383631157, 0.04028072926614966, 0.03161799142669354, 0.02265047262023602, 0.010464046449799622, 0.031024096866271327, 0.03282115275838545, 0.03269768652639218, 0.027560117920594554, 0.01730965563495244, 0.027552392799407244, 0.015481585603473442, 0.01920459868519434, 0.06734836647020918, 0.03448227773021374, 0.017793098265039067, 0.018623117922938297, 0.041760675209973536, 0.033842463312404494, 0.020632753747382333, 0.03329954369525824, 0.034402458263295035, 0.0453799335019929, 0.02241939412696021, 0.03407983182530318, 0.07493186382842915, 0.05189033790624567, 0.05667741603351065, 0.038931045082530806, 0.0705249145893114, 0.006429240165743977, 0.022242600131513815, 0.05902768152632883, 0.015593216488403934, 0.02885416562535933, 0.048670400865375996, 0.02606506778725556, 0.05008105820577059, 0.025783767524574484, 0.05133347439446619, 0.01837867059345756, 0.06654833297112159, 0.023124020513413206, 0.09896907542965241, 0.009548334604395288, 0.03785572653370244, 0.02235737772259329, 0.01022934288318668, 0.012452812233407582, 0.07256620576871292, 0.04394000755356891, 0.07026133766131741, 0.05773619868393455, 0.04927729954943061, 0.014113517361693084, 0.07064684733216252, 0.02011762692459992, 0.05171615118160844, 0.024887580524331758, 0.04098324371235711, 0.037575715487556796, 0.050563143765819926, 0.009476952720433474, 0.04383173032796808, 0.039337986281939914, 0.009803614745448743, 0.05712789882506643, 0.05204064019822648, 0.07565664100859847, 0.018118476162531545, 0.029304505924561193, 0.005915098066907376, 0.060202931320028644, 0.018867577126781856, 0.05830842762121132, 0.031211725369627987, 0.03962979365938476, 0.0279920427793903, 0.03735424844282014, 0.023902948180745755, 0.030898700202150003, 0.016231558485222713, 0.0478334618466241, 0.009110199453841363, 0.04500560948093023, 0.05151817841189248, 0.059318759478628635, 0.00860501401725092, 0.04907427169382572, 0.03378127980977297, 0.08609364274889231, 0.021148440361555134, 0.07163579855114222, 0.015671130968257785, 0.05007648148706981, 0.0140159771045936, 0.01836023649333843, 0.020167366934141943, 0.016630508238449693, 0.004830347457235413, 0.04611069875370179, 0.03332287172919937, 0.019131142180413008, 0.026633671651195203, 0.027900779819382087, 0.07000692774142538, 0.021380813160379018, 0.04352160929036992, 0.038999397307634354, 0.029785736530487026, 0.009359023334192378, 0.022599865782207677, 0.08198482822626829, 0.02987414625074182, 0.00675004134453567, 0.034414414050323625, 0.028943016393376247, 0.04120998975953885, 0.02178636166666235, 0.07113406940230302, 0.03240968233772686, 0.007599159642787916, 0.029326178333056823, 0.014188106171786785, 0.023369061561035256, 0.06570268834808043, 0.023445724143779705, 0.049896028491535356, 0.049292556409324916, 0.01975127399366881, 0.04901451311473336, 0.03117372401590858, 0.013943197438493371, 0.015784522651561668, 0.02063721850780504, 0.0062408495827444965, 0.017385254614055157, 0.035984296418194256, 0.03466755510973079, 0.03315903266359653, 0.006714077292209757, 0.05820276614810739, 0.023949024101187075, 0.08165101613849401, 0.013650137315770345, 0.04160256637260318, 0.08566760418138333, 0.026624353669051613, 0.016273593729627982, 0.02033023739100567, 0.05302167630621365, 0.02214804458032761, 0.043216784218592305, 0.0691425691225699, 0.02359872361245964, 0.021229384500267248, 0.05956897605210543, 0.04819334324981485, 0.02553941179732127, 0.08907021981264863, 0.0805110569511141, 0.06048151065728494, 0.029846716472612958, 0.05711327639541455, 0.08612511320305721, 0.03721311315894127, 0.05170032435229846, 0.017530001400570785, 0.05495503292019878, 0.0666616822459868, 0.014246748560773475, 0.024131229413407188, 0.03167645400390029, 0.03305449077327337, 0.03046535381249019, 0.05929186235048941, 0.012063058326020837, 0.027009228909654275, 0.01847142293783171, 0.048623385173933845, 0.07681748550385237, 0.045293043700179884, 0.03669925858931882, 0.03614096676132508, 0.03727287852338382, 0.07402038773787872, 0.01567273909625198, 0.07200154249689408, 0.02194522537424096, 0.01914870266669563, 0.07357754864330802, 0.009342883530605053, 0.019013463852128813, 0.0816885187689747, 0.026989281676443558, 0.0650317393509405, 0.019388434177796756, 0.017601364624819586, 0.057716663660747666, 0.02198352528336857, 0.03085155558905431, 0.11227911657520703, 0.06549595229859863, 0.011616095434874296, 0.09881609970969812, 0.06751274836382695, 0.023964224981942346, 0.003137770266870835, 0.02432919879044805, 0.03071431509618248, 0.035350147767790725, 0.02309689946871783, 0.02712701241086636, 0.057563647228692255, 0.029431653209030628, 0.05091163595872266, 0.04493232091356601, 0.0389345632866025, 0.032731664167451005, 0.026586323477593914, 0.04212464478665164, 0.028074710397049785, 0.03673362638801336, 0.06256599059062344, 0.02619109718528177, 0.052166661114564965, 0.044151917432567904, 0.018210683982553225, 0.04061559647587793, 0.05393603277791824, 0.07592781074345112, 0.08771155521805797, 0.03012727713212371, 0.03579384181648493, 0.03396619078037994, 0.029598946017878394, 0.0056549803952553445, 0.06370035864944969, 0.022867882025561163, 0.013605530423644398, 0.04807868779503873, 0.021283650338383656, 0.02184679708443582, 0.020088829898408482, 0.07575103880039283, 0.03219717534791146, 0.040973126755229065, 0.009177253980721747, 0.06588637456297874, 0.06634602096996137, 0.018565067555755377, 0.06271754817238875, 0.0356163370556065, 0.05851768103561231, 0.007987940700591674, 0.021281280554831028, 0.02042200416326523, 0.04948768272463765, 0.039380717024739297, 0.025182107130863836, 0.03192100141729627, 0.045958941004105976, 0.018238442850166132, 0.0229825781924384, 0.03492657228239945, 0.03992986220068165, 0.07885222882032394, 0.02275260740758053, 0.02258294651151768, 0.0653860771230289, 0.01702272692429168, 0.01203639105161918, 0.04842498831983123, 0.0395067752605038, 0.015414507327867406, 0.030114737804979086, 0.03227293039006846, 0.06274968359087195, 0.023361489110227143, 0.06458721748952355, 0.05735826824924775, 0.11531774566641875, 0.046401824203452895, 0.1260670567197459, 0.15748736714678152, 0.06645255096788917, 0.08893261291086674, 0.10961102867232901, 0.15132803336850234, 0.12976972732160771, 0.12800320211265767, 0.073249931580254, 0.07796374828155551, 0.1194907088897058, 0.1985998446387904, 0.13292397877999715, 0.10054622830024787, 0.12363449510719095, 0.11208150682172605, 0.09458494532321181, 0.1693604543272938, 0.1515662127307483, 0.06050455370651824, 0.12896642328373023, 0.07197654526680708, 0.2852948526186602, 0.13198171077030046, 0.1403501374380929, 0.09397605513887745, 0.08071405427264315, 0.13391318784228393, 0.08266666771045753, 0.07941317372024059, 0.0848030284313219, 0.14926581616912568, 0.09453073716057198, 0.1110895157658628, 0.1359180145497833, 0.14744206331670284, 0.12303544368062701, 0.12149629555642605, 0.11768902199608938, 0.17311917192169599, 0.06145317280398948, 0.08255892992019653, 0.14272779199693883, 0.09305743407458067, 0.09554055333137512, 0.11314740391182047, 0.1235962121614388, 0.07743377850524016, 0.08647782927645103, 0.16041478434843676, 0.09555894841573068, 0.09673111087509564, 0.14222013923738683, 0.3412881594683443, 0.10344288072415761, 0.14766101299652032, 0.20811528047280653, 0.2058534518416439, 0.13406568180237496, 0.08674587096486773, 0.07343321067414113, 0.09795222963605608, 0.1616765202156135, 0.06760303423340831, 0.07763765792229346, 0.12301132854606424, 0.11706235419426646, 0.0946430347061583, 0.18176936704133237, 0.06522825666304145, 0.12169060084436621, 0.14196027389594487, 0.16232195629605226, 0.15691163018345833, 0.19501546983207974, 0.14832713082432747, 0.12364900218588964, 0.09450879333806889, 0.14218181557953358, 0.23882660322955676, 0.138537553272077, 0.10401297227612563, 0.13545321806200913, 0.15060430791761192, 0.08922578075102397, 0.04991132267085569, 0.1420992650091648, 0.1453464621944087, 0.17302866892090865, 0.12058089753346783, 0.08709777279623918, 0.10644927261663334, 0.1757843896214451, 0.11449255208883967, 0.24815152000103677, 0.12895309685596398, 0.1880639192781278, 0.17634477812264646, 0.23037696949073247, 0.10604276228696108, 0.09074974326150757, 0.1385986485651561, 0.1221324899899108, 0.0924345999956131, 0.13177802812840256, 0.2040015940687486, 0.16932713825787815, 0.12392998353711196, 0.18798438140324183, 0.12345545685717038, 0.20220233633049897, 0.13481451304895536, 0.1604880118476493, 0.14128099248877593, 0.1194425600447825, 0.10460972346897636, 0.09153720350669962, 0.10056070823754583, 0.20587061877761567, 0.12336846866777965, 0.1704685427248478, 0.1822992078959942, 0.16446307354739734, 0.1311755840267454, 0.21091564877757005, 0.14346740873796598, 0.13351407354431494, 0.12474935528423105, 0.1414233898477895, 0.13192221681986535, 0.12437417970171996, 0.06341717884476696, 0.11820709705352783, 0.1589984239212104, 0.17249616820897373, 0.13145220918314798, 0.11128483885633093, 0.1474575474858284, 0.08045515245092766, 0.08779301334704671, 0.10532924878810133, 0.11017898962433849, 0.15451233035751752, 0.1684221625328064, 0.22374654241970607, 0.1674139273485967, 0.14043238945305347, 0.11651465429791383, 0.11464220977255277, 0.11634286280189242, 0.17890654637345246, 0.10434646545244114, 0.09781391705785479, 0.10567462311259337, 0.14862302637525968, 0.11174778972885438, 0.14379018784633704, 0.1303583157381841, 0.09174746115292821, 0.22895522149545805, 0.06932362940694604, 0.10901865403034858, 0.13911737501621246, 0.19651317303734167, 0.13376286519425257, 0.14442384455885204, 0.10925704373845033, 0.10114128315555197, 0.11937054033790316, 0.09499263630381652, 0.11174149970923151, 0.10546544433704444, 0.08700311037578753, 0.1064173679000565], [0.019558020435007553, 0.015163096532757794, 0.039983245943273814, 0.034819675875561576, 0.021039016411772797, 0.034100086095609834, 0.03131390595808625, 0.05523770721629262, 0.023735299141013196, 0.05690223843391452, 0.020454894451956664, 0.03795846012820091, 0.021523598980690752, 0.01691858367329197, 0.019012412122849907, 0.029303559368210177, 0.032355867725397856, 0.020170483106215085, 0.02259684630137469, 0.032686789253992696, 0.037643100800258775, 0.03458191381235208, 0.06378451734781265, 0.06085327999400241, 0.00970505498948374, 0.01593513198063842, 0.05941977298685482, 0.018871412545974766, 0.009615547738836279, 0.03460821722234998, 0.024707714461588433, 0.06251982985330479, 0.058331185685736794, 0.06388610082545451, 0.016637770259486775, 0.03617002163082361, 0.057580054205443175, 0.0326398448087275, 0.038005245117736716, 0.03649898897856474, 0.09885825709040676, 0.046504975096987825, 0.06251262381140675, 0.05908872253660645, 0.03803534832383905, 0.06266507705939667, 0.05467124243399926, 0.02542201506106981, 0.016779514528544884, 0.03763554531282612, 0.05882228219083377, 0.021949561213010123, 0.001614865316826451, 0.019963777590809122, 0.04297050654089876, 0.011924690616849278, 0.009708920094583715, 0.06609974668494292, 0.0218854379574103, 0.03569523371489985, 0.006586441886611283, 0.04893105670011469, 0.0637570773916585, 0.0463141167669424, 0.029228041813309704, 0.03484911072467055, 0.03642162920108863, 0.057404293279562674, 0.0222694667255772, 0.02678954810835421, 0.05073656374588609, 0.047968005162796805, 0.05386909869100366, 0.022355803521350026, 0.046634062991610596, 0.028066391557721154, 0.00989851210865059, 0.03791795837293778, 0.030096644668706825, 0.032383351786328216, 0.03590602401111807, 0.10490973094212157, 0.020570362452417612, 0.059390860609710217, 0.03969369130209088, 0.009289729641750455, 0.03996886100087847, 0.05864006161157574, 0.060409728437662125, 0.03596752642520836, 0.04043713498062321, 0.04441083621765886, 0.09386900266898529, 0.016697272691609602, 0.012701066992511707, 0.026265205083681003, 0.03759080949904663, 0.02466095830979092, 0.0850946492116366, 0.011422565373192941, 0.036386209673115184, 0.027523327751883438, 0.0518322383452739, 0.04873321285205228, 0.011046390647866895, 0.04985172015481761, 0.06914612464606762, 0.04320987333942737, 0.055272234470716546, 0.04679581895470619, 0.03788811979549272, 0.030568945753787245, 0.008949542717475976, 0.022584218764677644, 0.013312105588348848, 0.026471338933333755, 0.08434539048799447, 0.05362254620662757, 0.01578716384912176, 0.024520978231781294, 0.015994804046515907, 0.04326782701537013, 0.010610484484849232, 0.02934567942949278, 0.025303698909868087, 0.0024993595683814158, 0.009638900369671839, 0.04774827516770788, 0.011345817125402391, 0.027879485694159354, 0.04227791227666395, 0.014095898351765104, 0.010227694891260138, 0.02799442782998085, 0.035113159234502485, 0.009708617298331643, 0.027932799886912107, 0.014498500319729959, 0.0548401569415416, 0.014542279399133154, 0.010459533343756837, 0.04152427360947643, 0.003549905227763312, 0.03253620197730405, 0.036768180783838034, 0.052632987698806186, 0.036972002525414736, 0.028199318264211928, 0.013681211675118123, 0.006509281428796905, 0.08682467602193356, 0.0382546610198915, 0.011952093253577394, 0.04508071991481951, 0.04483565681480935, 0.032413356604852846, 0.04883598376597677, 0.029763066675513983, 0.010519968761530305, 0.022477159509435296, 0.05471080781093665, 0.014532708662695118, 0.020999059180862138, 0.054707432099218876, 0.045526422427168915, 0.03327259567699262, 0.03566932724788785, 0.036002365805740864, 0.03484288516587444, 0.03615246114454099, 0.0709843710064888, 0.050788939863975556, 0.07181516928332192, 0.03243449975603393, 0.05699622231934752, 0.009230341712412025, 0.04239743622019887, 0.030113608044173037, 0.042464774035449536, 0.03540320920624903, 0.05332160574783172, 0.022203428304887245, 0.017055215180984566, 0.053935204965195487, 0.04162475446771298, 0.025238832658422843, 0.03999248080487762, 0.04727644566446543, 0.0549801251451884, 0.04520466112132583, 0.01744988846725651, 0.06288914967860494, 0.03472413814493588, 0.035890217537858655, 0.04686401850943055, 0.048082792931901555, 0.08400839607098273, 0.045391295570880175, 0.08862921954797846, 0.029998280839728456, 0.018897327494674494, 0.021098663032587086, 0.00754991072296564, 0.006193610822914967, 0.008830456429028084, 0.0703963457739779, 0.04993756162002683, 0.012782354639577014, 0.02423970850317606, 0.01034901780076325, 0.0320156706230981, 0.025902981038338373, 0.07661706661539418, 0.040550691208669117, 0.03230576130694576, 0.07146649727863924, 0.06339147593826056, 0.03830291164506759, 0.03294787935114332, 0.1033477976119944, 0.01841823088138231, 0.028116738856104866, 0.0025690345126869424, 0.025861656559365134, 0.01622595887498132, 0.05896261680339064, 0.025781212840229273, 0.032599085210157294, 0.041687732695468833, 0.022618420322292616, 0.015212777170485683, 0.017842495614396672, 0.032694175107670684, 0.043176241751228056, 0.05260979197919369, 0.03396042662539652, 0.07663922078375306, 0.07284348231873342, 0.07631068091307368, 0.018099158270550624, 0.0270257851641093, 0.020150588459468315, 0.02618883766366967, 0.049553527762847285, 0.06330651656857558, 0.041789468843489885, 0.09201837304447379, 0.06890395549791199, 0.0628200408869556, 0.006870294289131249, 0.020954722006406103, 0.01908837751086269, 0.05697444813059909, 0.029212805309465954, 0.05121903267822095, 0.04562353775171297, 0.12552656286529132, 0.04282772580959967, 0.014411130454391241, 0.0022441387991420925, 0.05563777485596282, 0.058361869039280076, 0.07051859064293758, 0.06406865388687168, 0.07708303018340043, 0.008579424765360142, 0.019117449343736683, 0.06809948437980243, 0.04893053083547524, 0.02956746199301311, 0.004477491860078382, 0.020863387800220932, 0.007614783759761069, 0.02973739430308342, 0.010276252553532166, 0.04699881627623524, 0.023382929120478884, 0.0104634434018018, 0.02769008112539138, 0.04731642494776419, 0.03867084047357951, 0.08027072663285903, 0.06954465540392057, 0.021372852248272727, 0.06943263605769191, 0.05057750156681452, 0.015980446245521307, 0.026274165138602257, 0.013563700436082269, 0.0030282945787933257, 0.03019177188564624, 0.012149892996863594, 0.02897763525002769, 0.021235555776261857, 0.02308875704849405, 0.01675454104718353, 0.048906151072255204, 0.04123838645006929, 0.012990565654555601, 0.009776821093899863, 0.042181054795426984, 0.03828461155561464, 0.04463724639000637, 0.04172211067218866, 0.012649472886031228, 0.025224924386878098, 0.03506443024213825, 0.02781618685860719, 0.003913006279617548, 0.028678221495023797, 0.01844850881025195, 0.025457346379490833, 0.027226412702085714, 0.026682719555018202, 0.06828045645462615, 0.025905866508505175, 0.04203265918684857, 0.028154288984036872, 0.04081983212381601, 0.03630536561831832, 0.022385223103421073, 0.03194746767569866, 0.02123669401875564, 0.024808561728735055, 0.01931316768085318, 0.043736138314540894, 0.09201153341148581, 0.048483393221561394, 0.036349470394530466, 0.05024365894496441, 0.018045343658221618, 0.055486224059547694, 0.01962071198171803, 0.039865245310855765, 0.04985540459996887, 0.07135541431073632, 0.021016680735296438, 0.03994719198505793, 0.015318669345495957, 0.05393202942130821, 0.039864064659923315, 0.01978826433021043, 0.02044415663528655, 0.042716897292328734, 0.05385946010106376, 0.04542493733710476, 0.025615160054128085, 0.017980736946421008, 0.09461065501506839, 0.07118043370012726, 0.04077586305460759, 0.07155366188713483, 0.08452758392585175, 0.13912908653063433, 0.12957809546164104, 0.17387294290321215, 0.07599466001348835, 0.09547652676701546, 0.10571079581443753, 0.18203851474182947, 0.162497398310474, 0.16184749746961252, 0.14308713057211467, 0.09421476375843797, 0.17553388806326048, 0.17464561787034782, 0.11354182953281061, 0.10826082540942089, 0.23792048756565365, 0.09493326448968478, 0.16486302922878945, 0.20363263386700833, 0.10456384771636554, 0.1302160947982754, 0.11546445850815092, 0.11391632658030305, 0.12075370683201722, 0.13244899069624289, 0.16180740962071077, 0.1226095679615225, 0.11370537682835545, 0.20620730785386904, 0.21265056782535144, 0.1753962268786771, 0.11434450931847095, 0.10820125682013375, 0.10973424384636538, 0.06622246652841568, 0.1927511306213481, 0.12049899835671697, 0.09627149839486394, 0.09940659480967692, 0.1782265728605645, 0.13297120481729507, 0.07951318299663918, 0.23686661411608967, 0.12058472447097301, 0.11325301110212292, 0.1269863766751119, 0.10362002586147614, 0.13580323356602872, 0.11775133865220205, 0.20442489135478223, 0.11729112906115395, 0.14295701469693864, 0.1178521825266736, 0.0746867498382926, 0.10151313391647168, 0.1295988586332117, 0.15488654242030211, 0.1367230692080089, 0.1109215851340975, 0.08300040515937976, 0.163668034066047, 0.15890424326062202, 0.095245315959411, 0.10800218821636268, 0.11369528022727796, 0.12930436086441788, 0.125412663977061, 0.13599591036992414, 0.1905441004782915, 0.10585140184100185, 0.09885206885103669, 0.11487630435398646, 0.1327124929853848, 0.13370609895459243, 0.09372891911438533, 0.10504769068211317, 0.12637517947171414, 0.08740400243550539, 0.15136080660990306, 0.18364255795521395, 0.16108821678374494, 0.11792635997491223, 0.08250661487025873, 0.0803611007119928, 0.08285522580678974, 0.18004720445190156, 0.14889167195984296, 0.19783442999635423, 0.15281715989112854, 0.16984040928738459, 0.17894539928862027, 0.1630068424024752, 0.1313639317772218, 0.08562140951731376, 0.09483670217118093, 0.08352134363459689, 0.07718612000878368, 0.24438600348574774, 0.11017890141478606, 0.0943714374942439, 0.07559649566454546, 0.12662048345165594, 0.15883082577160426, 0.06706488811011825, 0.15913309955171176, 0.19664535165897437, 0.1588528510183096, 0.144314831122756, 0.15017235252474034, 0.08790305815637112, 0.10833386291882821, 0.15905407736343996, 0.1645357853599957, 0.13101152782993658, 0.1107034564816526, 0.12039937584527902, 0.1007873932165759, 0.10812018545610563, 0.07988210248627833, 0.15347307255225523, 0.12093013950756618, 0.13377448171377182, 0.09612490768943514, 0.09342978695141417, 0.1560907792299986, 0.07701810795281615, 0.12229311279952526, 0.06928733456879854, 0.09898880044264452, 0.10549425493393626, 0.08615882960813386, 0.07577812591833727, 0.12604003745530332, 0.1660050715186766, 0.12002398313156196, 0.1433608787400382, 0.18208424800208636, 0.2076204384544066, 0.0695740088288273, 0.1296142070953335, 0.1219741063458579, 0.09962278963731867, 0.1370943771409137, 0.21998091733881406, 0.1351996495255402, 0.11735421924718789, 0.10440038863037314, 0.07480461137103182, 0.06993052469832556, 0.1566413561148303, 0.136630435607263, 0.2004607269274337, 0.18912231177091599, 0.12207774578460626, 0.17634209112397262, 0.13422876090875693, 0.15791141082133564, 0.09948753046670131, 0.09984545768903834, 0.15199687890708447, 0.12779531255364418, 0.1987981939954417, 0.1738320001001869, 0.09943425189703703, 0.14757699679051126, 0.11527905559965543, 0.1539073892469917, 0.1252226470304387, 0.10630469716020993, 0.12295756143118654, 0.19284813398761408, 0.1419311783143452, 0.11334893559770924, 0.14164951842810425, 0.14478378024484428], [0.01293942192569375, 0.04030900042770164, 0.05355168679463012, 0.009268462657928467, 0.03662954590150288, 0.04379681970125862, 0.054317525521452935, 0.040556641960782666, 0.01746345916762948, 0.020804207672231963, 0.1247202597026314, 0.019385365503174917, 0.07241496031305619, 0.029981130867132118, 0.026918496903298155, 0.06788740147437368, 0.012515576722632562, 0.041288011108658144, 0.014372723675998194, 0.03298175860462444, 0.041980456095188856, 0.04057703193809305, 0.03780045646375843, 0.04478884129119771, 0.026098064945212433, 0.03260232521487134, 0.06250281219503709, 0.04273070547995823, 0.04743854428774544, 0.08318483097744839, 0.032744084750967364, 0.03489840290110026, 0.060365243681839535, 0.039133665817124505, 0.007079080786622528, 0.03234083138938461, 0.006107092519024653, 0.0433873747076307, 0.023717139847576618, 0.03169636900669762, 0.01846826266098235, 0.06192166730761528, 0.0314477198491139, 0.029223247963402952, 0.03815171368686216, 0.0353897708202047, 0.01833825874408441, 0.020852648287213275, 0.0217612864050482, 0.02450133633932897, 0.03052819972591741, 0.023733151577679173, 0.009825704452980841, 0.040796059649437666, 0.10249776965273277, 0.04181218958858933, 0.025742841684924703, 0.011741302109190395, 0.014387899111690266, 0.024518418458423445, 0.025294833849849443, 0.01062442668314491, 0.015171389927023222, 0.025901959843135307, 0.024979237034650784, 0.05826004807438169, 0.004610994473166231, 0.020222564061571444, 0.03336250835231372, 0.020254624841202582, 0.03556542318048222, 0.02796270462152149, 0.04290330782532692, 0.023999856552109122, 0.01910046221954482, 0.03983020576249276, 0.03319367866164871, 0.09850357326545886, 0.016346230903374295, 0.02896774560213089, 0.03170782267781241, 0.025480900026325668, 0.04059677730713572, 0.016795076729197587, 0.033230282233229706, 0.03919805879039424, 0.015778068087196777, 0.05280419226203646, 0.03339676758540528, 0.05040453959788595, 0.025819360078977685, 0.033362240330981355, 0.02805367750780923, 0.0037212225974404384, 0.07969099988362618, 0.024283323037837232, 0.007951569527254572, 0.06036809352891786, 0.03505167378378766, 0.005525866207400603, 0.017666514164635112, 0.0615656671247312, 0.02408233078728829, 0.019360617634707263, 0.0809859771813665, 0.021573598529877405, 0.02351732485528503, 0.0018054550954340292, 0.09042357147804328, 0.04676681497533407, 0.028139518973018442, 0.03539823554456234, 0.01002250929429595, 0.030317321220146756, 0.045626730258975706, 0.019109936264742697, 0.04118956924815263, 0.03957492731777685, 0.03946461109444499, 0.03479663961167846, 0.022005170550463454, 0.059669996345681806, 0.015363627379494054, 0.017834220879844258, 0.02569993113034538, 0.02807446103543043, 0.03560744485418711, 0.008067140156137092, 0.06102413511169808, 0.041605121056948385, 0.01015329098195902, 0.027193344297951887, 0.06143523233809641, 0.004564103038449372, 0.029846753792038987, 0.03921952424570918, 0.06818084751388856, 0.025202368186520677, 0.026927156706473658, 0.051293895446828434, 0.026610725293202058, 0.028432863232280527, 0.016240969765931368, 0.031684630350875, 0.022695418779871294, 0.02547032166538494, 0.04652743799878018, 0.042738335606242926, 0.09327653303210225, 0.047988395140107186, 0.014761963593108314, 0.0574165815487504, 0.018925276352092624, 0.06137632192777736, 0.02540553344546684, 0.016384205115692954, 0.0044580403815156645, 0.009670992531547589, 0.06194026595247643, 0.02246483731349664, 0.021734053402074745, 0.043115163421524424, 0.017962552207921232, 0.027701846922614744, 0.026183729991316795, 0.0380382863804698, 0.036289830559066365, 0.051876729886446676, 0.016236990158046995, 0.01869598579859095, 0.051221220953656096, 0.005500289678041424, 0.0081771434051916, 0.00966537426159318, 0.0036080535584395485, 0.059859762234347205, 0.010196548437566628, 0.010334351266335164, 0.03620167528944356, 0.023496906040236354, 0.027341583843476007, 0.025416310277900526, 0.0427787118325276, 0.04060976107471755, 0.02745081271444048, 0.035787120927125216, 0.09483853421573128, 0.033607649483851025, 0.025952588733551756, 0.027208660529660325, 0.03729923960885831, 0.07147921302488872, 0.02497762890665659, 0.03826870669477752, 0.010985438695310481, 0.03511025510462267, 0.03265558682116015, 0.05158819644046681, 0.039094897718834024, 0.07229855084525687, 0.009154910670726426, 0.04325552178280694, 0.07443459944001266, 0.013059680383386356, 0.06719672746424164, 0.04787489319486277, 0.05515610659494996, 0.013149820367938705, 0.07063658788268055, 0.020142839589555348, 0.029310005450887338, 0.03661287768876978, 0.03878918376618198, 0.07935310980038983, 0.012228115361982157, 0.057390417238431315, 0.020739030991015688, 0.04368530586361885, 0.033337395771273544, 0.05834205581673554, 0.005202803386574877, 0.044676927117896933, 0.030607323694442, 0.015767396427690983, 0.04159996419080666, 0.05609786231070757, 0.05113765936610954, 0.02397908829152584, 0.02180688056562628, 0.023217690576400076, 0.06408409055854593, 0.04444260183455689, 0.03605777497536369, 0.04597988398745656, 0.031047777738422155, 0.042669135212366066, 0.08190550748258829, 0.048068855822618516, 0.024119901271270852, 0.0399734139708536, 0.0745140491053462, 0.02896924177184701, 0.06143010261335543, 0.051915246926780255, 0.06071890291890927, 0.029523628630808423, 0.01006999402306974, 0.08231710003955023, 0.03157859229083572, 0.02277309407613107, 0.03649239701085857, 0.04235832206904888, 0.053430524189025164, 0.05010327004960605, 0.02566904591263405, 0.03238547220826149, 0.015033676155975886, 0.012556050488326167, 0.023878875454621654, 0.05496033227869442, 0.03322428059098976, 0.013934024493210018, 0.013837828583616232, 0.062208165148539205, 0.018943413593141094, 0.026819206874019334, 0.019797029306313822, 0.03837103995361498, 0.04957138341186302, 0.034477473702281713, 0.06644919900489704, 0.043789606874010394, 0.032071585301309824, 0.08263210992195777, 0.02921697829983064, 0.006926073684423629, 0.06793526533458914, 0.14900496016655648, 0.03614876991403954, 0.03673730404781444, 0.06767556962690183, 0.02825418290948229, 0.024655988040779318, 0.04056472670552986, 0.03755362917269979, 0.02935699400092874, 0.011305683475386883, 0.03971596421407802, 0.06034817174077034, 0.07787927067173378, 0.042248640275959454, 0.024201459484174848, 0.012176798606690551, 0.03255359961518219, 0.04096751527062484, 0.01985566151727523, 0.008543759268442435, 0.0750392759218812, 0.029561887827834914, 0.06599441769399814, 0.05385588761419058, 0.05102815059944987, 0.019027984501527886, 0.05269507026033742, 0.04812250080119286, 0.02668334380723536, 0.028510592811341797, 0.05894100546304669, 0.06150076525019748, 0.042097598380808315, 0.009841492266527243, 0.07573745452931949, 0.0348224748325135, 0.019920200375573974, 0.02055051869579724, 0.024771123559081128, 0.051030664571693966, 0.05019196814724377, 0.033964623364486864, 0.04507134256086179, 0.04237942450812884, 0.048427030710237365, 0.043320440620716126, 0.03193471800269825, 0.05559512893004077, 0.0570789153820702, 0.027695887688813463, 0.0416541621754212, 0.019008607237732837, 0.03321659278922847, 0.058556493238679, 0.05160778574645519, 0.017856069707444737, 0.03907665191218257, 0.006882914616393724, 0.057908953699682436, 0.0110651020991749, 0.06059389641242368, 0.05928442560668502, 0.02479390537233225, 0.006798628268630377, 0.04192733358857887, 0.05841885241014617, 0.04729302227497101, 0.022206089858497893, 0.02582134140123214, 0.031213659194431136, 0.059362063583518775, 0.020694768455411707, 0.011893719734091843, 0.041245653560119014, 0.08215100823768548, 0.09062300649072443, 0.1496036180428096, 0.11721418319003922, 0.15078452681856497, 0.07400081200259072, 0.07500593271106482, 0.1779379512050322, 0.1334379690566233, 0.13125641111816677, 0.11377557127603463, 0.23096021105136189, 0.10296018448259149, 0.15457183787865297, 0.13768326411289827, 0.13097726181149483, 0.1324337236583233, 0.1391058670622962, 0.11311917006969452, 0.08314183899866683, 0.11869375593960285, 0.22046039732439177, 0.11870138267321245, 0.14406579520021165, 0.13779953787369387, 0.13029819753553185, 0.1463042279439313, 0.1493346467614174, 0.09974267320441348, 0.1402897478214332, 0.2032094994293792, 0.11871469553027834, 0.15928783267736435, 0.2057830606188093, 0.10686823406389781, 0.10799046991659061, 0.13256116610552582, 0.11466249796961035, 0.1975868054266487, 0.1386451960674354, 0.1428365475897278, 0.07666225026228599, 0.13008668459951878, 0.07971876553658928, 0.0859397238652621, 0.18885378832263605, 0.1111234018046941, 0.08358603516327483, 0.09867821460855858, 0.10732005017676524, 0.11718700107719217, 0.12149257718452386, 0.0838927465624043, 0.06753199161695582, 0.06527535377868585, 0.3538586177996227, 0.17888822592794895, 0.11086970434657165, 0.10177855645971638, 0.14402297964053495, 0.15062352402934007, 0.12402002513408661, 0.15761113193418297, 0.10700169511671577, 0.1564301010221243, 0.22922028441514286, 0.13567500401820454, 0.11188024654984474, 0.1294684170612267, 0.11736301306102957, 0.11023893140788589, 0.1884226743131876, 0.18335715255567006, 0.15789714801524365, 0.15025582590273448, 0.1380322618143899, 0.09923081352774586, 0.12646796235016414, 0.18436735549143382, 0.09407130109944514, 0.11599370225199632, 0.10762152328555073, 0.12486575118133, 0.08902064604418618, 0.13402131918285573, 0.13954010233283043, 0.15803932824305125, 0.15569892525672913, 0.2212925526712622, 0.07630527977432523, 0.15269711347562925, 0.10333818277078015, 0.13560115226677485, 0.2013330515474081, 0.07763054687529802, 0.21207313452448162, 0.13466948297406944, 0.05644139441262398, 0.20193215725677355, 0.11580748510147844, 0.0877407593652606, 0.1562462451734713, 0.2595626605408532, 0.0801233420414584, 0.06970708990203482, 0.15323352254927158, 0.10195929783263377, 0.08221282956323453, 0.08989491805966411, 0.11339159509433167, 0.1452207432261535, 0.13225126559180872, 0.10629293136298656, 0.12252127698489598, 0.11322090961039066, 0.13420996548874037, 0.18533618136176042, 0.10833535569586925, 0.1791563829673188, 0.10353754314460925, 0.07819832462285246, 0.09601251514894621, 0.16259571803467615, 0.0681786694164787, 0.11377948642309223, 0.16635124651449068, 0.08940101241958992, 0.13449575086789473, 0.15077668295374938, 0.13858538999089173, 0.10061184942190136, 0.15305582779858792, 0.09879502441201891, 0.10643832784678255, 0.11243422289511987, 0.16661582088896207, 0.12679699755140714, 0.18102547552968773, 0.08370374741830997, 0.10595606586762837, 0.1331320854702166, 0.24459675646253995, 0.11390266088502747, 0.08873098623007536, 0.21052287199667521, 0.11368769420576946, 0.15805762154715403, 0.08729307553065674, 0.10492428551827158, 0.1302536992090089, 0.14454315815653118, 0.07920514166887317, 0.17949836461671762, 0.13066075236669608, 0.14345216884144715, 0.10149969213775226, 0.10605583087142025, 0.10209333564021758, 0.12524886562355927, 0.20449482117380413, 0.09946059262646095, 0.07506848685443401, 0.23588349829827035, 0.1269432082772255, 0.055195604118385484, 0.16296850517392159, 0.12271712933267866, 0.11233609994607312, 0.11131395479398114, 0.07253683877310582, 0.08573838216917855, 0.07765437023980276, 0.12829244802040712, 0.14226877662752355, 0.11140447815081903, 0.0769552756100893, 0.1976404096931219], [0.02123947092331946, 0.01792055937195463, 0.03973879352478044, 0.064052728669984, 0.044753947627863715, 0.04499049850606492, 0.07885266308273588, 0.04279784991272858, 0.13602271250316075, 0.04850519455171057, 0.056898313108831644, 0.040035442249583345, 0.027739397050546746, 0.08098947842206274, 0.031223077260489975, 0.02820059560638453, 0.061536110139318874, 0.07438609775687967, 0.06391186480011259, 0.03804644915674414, 0.05306409831557955, 0.02105740810345326, 0.04196263098024896, 0.06942878197878599, 0.03883213164018733, 0.06056497724992888, 0.015365557811622108, 0.02672043253135468, 0.02320324965486569, 0.009561261544669313, 0.03626776799293501, 0.017559219118473784, 0.05082536023110151, 0.02796745267031448, 0.037937815700258525, 0.06759991975767271, 0.03236887524170535, 0.01398501215901758, 0.02934641224731292, 0.0388116636313498, 0.04110231643010463, 0.04137538945568459, 0.056881963807557306, 0.06812258849718741, 0.10998973942228726, 0.051326390488871505, 0.02732076638910387, 0.023161005760942186, 0.019825585452573638, 0.008858436668690826, 0.04422825601484094, 0.0623360350728035, 0.0391198101320437, 0.05226380358050976, 0.011618139521617974, 0.04605523530127747, 0.080222842416593, 0.024593189624803405, 0.03072182308616383, 0.016540466641475047, 0.047023677799318514, 0.04755614458450249, 0.039713114366999695, 0.06779944976525647, 0.014909390592947602, 0.04395689629018307, 0.017680493682356815, 0.008087310457735189, 0.004472915141377598, 0.026335855846160224, 0.06550330761820078, 0.03266847898651447, 0.02406235471633928, 0.045655744416373115, 0.06991706256355558, 0.04449472350201436, 0.018329222353973558, 0.04682893146361623, 0.021602404037756578, 0.023729000639702593, 0.07995577103325299, 0.02328696900180408, 0.05685315999601569, 0.05001105714057173, 0.04896817595830985, 0.042655255778559616, 0.07702397049537726, 0.02695585025607475, 0.041326456902814765, 0.03367675827550037, 0.027610073365004997, 0.014095810990381454, 0.08888760568307978, 0.0689829234033823, 0.04059592913836241, 0.05507457721978426, 0.07314351014792919, 0.10483719554862805, 0.051042298054588695, 0.012198208082866455, 0.07234475229467664, 0.05711230609033789, 0.04487959195726684, 0.03174269598509584, 0.03515525215438434, 0.031975094228982925, 0.03515812914286341, 0.06410802927400384, 0.06410243814545018, 0.02774221805988678, 0.03178851745490517, 0.01638535692888711, 0.026874884064974527, 0.022336891054042747, 0.10538052567946059, 0.005470308184158057, 0.058513155207037926, 0.04193756928933518, 0.01210820974249925, 0.06368973279105765, 0.03203034733555146, 0.04797100428757923, 0.024157933159066097, 0.004206559188397867, 0.07043046251471553, 0.06645565865827457, 0.037006947078875134, 0.06717075992907796, 0.029789376870862076, 0.06764954102358647, 0.029530573436724286, 0.017695755631263767, 0.01547696817267154, 0.025053129498181597, 0.041499890453581295, 0.060712768962340694, 0.031086824036070278, 0.027076156211218665, 0.015369210026359983, 0.05891150276043585, 0.0028188865856334034, 0.04804145997124059, 0.011417441585633372, 0.035584255919924805, 0.03760705702006817, 0.057975551911762783, 0.02396253034073327, 0.048740079626441, 0.0336127317111407, 0.06978829018771648, 0.06050579542560237, 0.040775462718946595, 0.032592947860913615, 0.027257238547982912, 0.04226449763934527, 0.01936163374089769, 0.041399772611579726, 0.015234651443149363, 0.045985844917595387, 0.10246089127446924, 0.02392348743576024, 0.033372211403080394, 0.02973554190248251, 0.06439785872186933, 0.06472347410661833, 0.006850962826449956, 0.04912477505526372, 0.06390245351940393, 0.060282272419759204, 0.006109185375472797, 0.04552230032693062, 0.022452737337776592, 0.06561386132878916, 0.03045553880344544, 0.016715014686009715, 0.037358913371073346, 0.05026476477671947, 0.035453430975654295, 0.012144338339567184, 0.07895129493304662, 0.04511648888832756, 0.025130915056381906, 0.021998295294387, 0.06068627216986247, 0.04313335833804948, 0.005140109295358083, 0.02829612315898495, 0.035702653495328765, 0.10549380031547376, 0.030378148491893495, 0.026900500458266054, 0.025664348753967454, 0.013700093608349562, 0.09241322614252567, 0.04079387815935271, 0.025026111930076565, 0.027219087916559408, 0.06055720802396536, 0.08965659620506422, 0.043443520087748766, 0.046663653903773854, 0.03933173697441816, 0.027002377402303473, 0.013194395029651267, 0.023368345706590583, 0.009912796118961913, 0.018645755547497953, 0.06262584416461842, 0.03026484671447958, 0.05755988135933876, 0.018703961977735162, 0.06731047028941767, 0.045364598610571454, 0.0133859904183607, 0.054846094122954776, 0.03743815269055111, 0.030802711245736906, 0.07829748573047773, 0.03242093923368624, 0.06411894011710371, 0.03069763331274901, 0.025321876863017678, 0.0258535412805421, 0.030806592466043572, 0.027440337830090096, 0.027956852256985645, 0.028213542054540346, 0.07196439270462308, 0.058586470915802887, 0.10553537415606634, 0.04076048405840993, 0.04152960689472301, 0.02681468952713268, 0.07287656768624272, 0.016554676861103092, 0.02424174071555691, 0.022441380357901965, 0.0849035330382841, 0.02827694945569549, 0.030834744883967296, 0.02392436613860939, 0.03265128830181701, 0.11901181244424411, 0.03652213041537574, 0.03789197048172355, 0.051054243663592, 0.019589489192834923, 0.023382622083382945, 0.06864428014627524, 0.03967803410653557, 0.0637726429849863, 0.022915593215397427, 0.042635910745177946, 0.01880350985032107, 0.08174122736922332, 0.03904640621372631, 0.04935591122401612, 0.029336122263755118, 0.018390171762023653, 0.005005311528553388, 0.007785789003329617, 0.0575893297791481, 0.013314066554552742, 0.04669847971360598, 0.002452092606940174, 0.050448108331433365, 0.0296153088898531, 0.08552465042365448, 0.04624158815879907, 0.06545192216123853, 0.02548174649876143, 0.01945737672836653, 0.031185706944337914, 0.020518223821584667, 0.018540251833785857, 0.0998762088960835, 0.019598021770694425, 0.045664521266839335, 0.04842896114236542, 0.060320141459149976, 0.019082486130563275, 0.007687410755482103, 0.04509194627670305, 0.12279913707503251, 0.005287495159011866, 0.05647209133686764, 0.009409159438551536, 0.030263744095074277, 0.05729206358747823, 0.033147277044398446, 0.012931908846699765, 0.04085358924099377, 0.015734796212720017, 0.0505826346842306, 0.0018335250289445476, 0.033229176221149306, 0.026131167276097194, 0.026645537532333816, 0.04304496218849506, 0.010884821281901427, 0.03771031987188118, 0.05579711862706712, 0.02564576198346913, 0.03454557826210346, 0.020529280549713542, 0.06443397714091198, 0.015113573654421737, 0.03089559929711478, 0.03254088047625763, 0.019982452570859875, 0.02502373536117375, 0.05734937944050346, 0.018849307571404746, 0.009510031302592583, 0.03375957008185131, 0.016900409112817476, 0.04208041448146105, 0.06687860310609851, 0.039993312010275464, 0.03804040680240307, 0.049625852810485024, 0.017169107283864702, 0.04908905697188207, 0.027406031099547232, 0.002923326059577188, 0.011842609083812152, 0.012548202382666724, 0.041419093896235736, 0.01568202145530709, 0.03213818012071507, 0.005120554764289409, 0.03759600707728948, 0.02667845835510109, 0.009675506485759147, 0.009551603446847625, 0.04987218137830496, 0.04711500182747841, 0.07459792281900134, 0.029122047858046632, 0.02914230552102838, 0.029410825576633215, 0.01772400813310274, 0.05693169363907405, 0.07866165547498635, 0.03456422779709101, 0.03513916069641709, 0.03859392513654061, 0.05096611553536994, 0.02579678182623216, 0.024206188873254826, 0.037859584005283456, 0.014958826958068779, 0.15755106801433222, 0.12523842975497246, 0.09364074348871197, 0.1823284120431968, 0.1712741402110883, 0.0872494185875569, 0.15897554372038158, 0.19776046967932157, 0.17240812150495394, 0.16781145387462207, 0.14906909529651913, 0.08710344534899507, 0.21680496633052826, 0.1876038589647838, 0.10870457374091659, 0.09641622312899147, 0.1445868829531329, 0.1970365270972252, 0.17657244019210339, 0.10015495786709444, 0.10269428017948355, 0.16590933022754534, 0.13744375482201576, 0.2117848792778594, 0.17005806975066662, 0.14672054988997324, 0.10298485601586954, 0.10918885775442634, 0.0777625422924757, 0.08859865833073854, 0.08496902523828403, 0.08053187440548625, 0.12096331986997809, 0.15104363220078604, 0.07898108940571547, 0.16947766446641513, 0.12163645374987807, 0.1392326716865812, 0.11872001524482455, 0.08984243337597166, 0.07450582526092019, 0.12647257638829096, 0.09756570216268301, 0.13793889539582388, 0.1842596855546747, 0.12392783936645303, 0.1233433900134904, 0.12155402531581265, 0.10638028596128736, 0.14475150911935739, 0.17269602391336644, 0.18354795660291398, 0.11046764520662171, 0.1292613281735352, 0.07210599617766482, 0.12129732194755759, 0.14350794441998005, 0.15348217849220547, 0.13599175773561, 0.13386054709553719, 0.125873524961727, 0.16144702610160622, 0.08823547924735717, 0.13412052100258215, 0.09907729497977666, 0.11939067925725665, 0.1686269444014345, 0.10283661647034542, 0.19089323388678686, 0.23605671471783093, 0.12068575833524976, 0.0874169963811125, 0.19666734976427896, 0.08726858041648354, 0.14226974014725002, 0.11031265423766204, 0.11637621958340917, 0.10201562302453177, 0.2165076458560569, 0.06808025469737393, 0.1641086611364569, 0.1346735270427806, 0.13917365271065915, 0.13424648424344404, 0.11158209826265063, 0.10020967493099825, 0.14320872404745646, 0.21757066595767224, 0.10943562058465821, 0.09411814037178244, 0.0663383738803012, 0.181045533024839, 0.15080446217741283, 0.1478348129561969, 0.09853901314948287, 0.25455328077077866, 0.11520786370549883, 0.2564767918416432, 0.14077909370618208, 0.1352401309247528, 0.21084998015846523, 0.17599172278174333, 0.21076143133853162, 0.22083713353744575, 0.11259878120784249, 0.10662012094897882, 0.08320605555283171, 0.27368547128779547, 0.0891729025170207, 0.10625375953635999, 0.12123006555650916, 0.1826042772403785, 0.12486333559666361, 0.10339095243918044, 0.24129554788981164, 0.08790368240858827, 0.08652141836604901, 0.17821931253586495, 0.13819658942520618, 0.24030925652810506, 0.09782024100422859, 0.1711038550628083, 0.14904834569564887, 0.0686752824112773, 0.17138704843819141, 0.19454760636602128, 0.09581049491784402, 0.17464806059641497, 0.1163299163537366, 0.17229780528162206, 0.18204478440540178, 0.12789813775037015, 0.08894549829087087, 0.08601585549435445, 0.20350462145039014, 0.20855934093041079, 0.1017803545775158, 0.12586399833006517, 0.1130540646346552, 0.09106539775218282, 0.10118264665028878, 0.12613941569413456, 0.14840605801769666, 0.09733125474303961, 0.17898826913109847, 0.09483010002544948, 0.11618584979857717, 0.1736272182315588, 0.13932151906192303, 0.10727411335600273, 0.0810018413301025, 0.1280875304447753, 0.10505136834191424, 0.10396892856806517, 0.14096331596374512, 0.18948223388620786, 0.11323453459356513, 0.040399493250463686, 0.14663836572851452, 0.12166255020669528, 0.11425226926803589, 0.14177556309316838, 0.07215699486966644, 0.08623893066708531, 0.19003796763718128, 0.1169185997652156, 0.07253110515219824, 0.17408957199326583, 0.14892061826373848, 0.1033853002424751, 0.15073384025267192, 0.14501487570149557, 0.17741231726748602, 0.1456506358725684, 0.0924437330769641, 0.15668502662863049], [0.021719173129115785, 0.03220360107453806, 0.034480544073241096, 0.09779423275696379, 0.02919460360759071, 0.013882857863791287, 0.020154227103505815, 0.030391990606273924, 0.014856251122962152, 0.03603792782606823, 0.044843690669430156, 0.031349322093384605, 0.04819702430229102, 0.021256744728556702, 0.04290982854685613, 0.033431742672941515, 0.06962475646287203, 0.07929878628679685, 0.04027923309643354, 0.04379623616114259, 0.013113040377252867, 0.06400784357850041, 0.008034328747141575, 0.04837086158139365, 0.0387189384283764, 0.02950948796101979, 0.07308907806873322, 0.011724422702432742, 0.02291303513837712, 0.055256122656698735, 0.08468647647116866, 0.022939341941050122, 0.015504703291558793, 0.020611230616590807, 0.006319386618477958, 0.04127916979736515, 0.02323637743081365, 0.024504959716328552, 0.046252970583736897, 0.024933449491592388, 0.05408562600080456, 0.08204848838171788, 0.014387929645766104, 0.05713386993323054, 0.03772352077066898, 0.020834580596004213, 0.04455846847434129, 0.03477996800627027, 0.01075830333866179, 0.038372454699128866, 0.02363856040340449, 0.026357748778536916, 0.06751918087580375, 0.03877082260857735, 0.06797889513628823, 0.03276272750060473, 0.0297549242552902, 0.09061395483357565, 0.028281322613890682, 0.10884796854640756, 0.03210409730672836, 0.03255516363840018, 0.02715500028404806, 0.04637790245137044, 0.00883709843869188, 0.008604072549912547, 0.0716060312198741, 0.039353012439927886, 0.011139547568745911, 0.04170678595879248, 0.016126843568469797, 0.02460552199876734, 0.058819527338658056, 0.040913239254483154, 0.029938179600451673, 0.07742940195436988, 0.019097658173580254, 0.024883032643369267, 0.020467152187068547, 0.014470025597672378, 0.03833652287721634, 0.03418791227574859, 0.07054633593985013, 0.01781865698285401, 0.06758415738918952, 0.0272341513939734, 0.12452482804656029, 0.02483389652999384, 0.03732678473794034, 0.03933870213638459, 0.027444222443071858, 0.026960086010928665, 0.024440673612324253, 0.028038678491222005, 0.05163342419213482, 0.048057330905326774, 0.03406513136412416, 0.07334925553628377, 0.032221378692026646, 0.018607486172446182, 0.048366868402808905, 0.049847682871456654, 0.026175226251195585, 0.019047750226621116, 0.02208192303909787, 0.05288471740537456, 0.04423219830329929, 0.033182876384151835, 0.01570949194553707, 0.04057950859091111, 0.0891573369236929, 0.06893331570816891, 0.06889617948659829, 0.014650461629831364, 0.058481182636959214, 0.036622825012143166, 0.07268778567335435, 0.008543157068613385, 0.04099624105063932, 0.034341729379126, 0.03615293272637895, 0.0676189051674945, 0.01882373189021434, 0.04851779494700687, 0.025608549426708902, 0.050139992364815304, 0.04361690953373909, 0.02494854011040713, 0.045876437931188514, 0.034125046006270816, 0.03176143712231091, 0.006907697259781084, 0.04219486637573157, 0.032490750309079885, 0.07792655099183321, 0.03027400354455624, 0.030122961649405103, 0.040926603001675436, 0.04498374708262937, 0.007064689907045769, 0.02120288261877639, 0.0333782300086958, 0.037114125077745745, 0.03705898053678019, 0.027058132624785815, 0.06046090354876859, 0.036641043677393875, 0.04182507496859346, 0.043242164820964844, 0.04007357931030648, 0.0351557237362223, 0.028548726479389837, 0.0017685150128922292, 0.04990729556552001, 0.02516511661399688, 0.03462400673223393, 0.024691080175606266, 0.01521915539966098, 0.013711331844595926, 0.015306340364207114, 0.036316452880523035, 0.027395773346402814, 0.027005388401448727, 0.03440073139167257, 0.013231193680050117, 0.027045632313404764, 0.032249850021409135, 0.08639447124941008, 0.08589586336165667, 0.03511653494622026, 0.03237368944766266, 0.04100181182314243, 0.03419993930895414, 0.044289398805371354, 0.009833381228548075, 0.01782106578217021, 0.043633302939789634, 0.0201817450911871, 0.015140643808990717, 0.08867185868855033, 0.051121802002723725, 0.03178078215569258, 0.027262291937534298, 0.02292126746449087, 0.026471133676490614, 0.03287628712132573, 0.06634308291333062, 0.0676045473664999, 0.028582385208989893, 0.061360335642738004, 0.01613418701370912, 0.0028496931356910083, 0.016171423319194998, 0.019945060202319707, 0.05415319451796157, 0.0018118146648963115, 0.01695629325695336, 0.038335315084883144, 0.01456498318085713, 0.016308484000286887, 0.03319330207471337, 0.06375859731010028, 0.0333558926358819, 0.043359039085251946, 0.006044305129242795, 0.01816554952945028, 0.03108182323298284, 0.022058761246236305, 0.023644694359973073, 0.02042755118704268, 0.016673233892236437, 0.04365344185914312, 0.024750394314261417, 0.05887484151337828, 0.01852662006526121, 0.0038997684854881038, 0.042995561446462355, 0.03959968706060733, 0.06696833936231476, 0.042860682255455425, 0.010840445939850594, 0.011679068573617508, 0.009771096802848791, 0.06495671373392854, 0.04989809123799205, 0.014639299728774598, 0.0430739050997155, 0.044391243518995385, 0.036609654647431204, 0.040112964875463925, 0.07561709598771163, 0.07857980379568678, 0.030479674294058765, 0.06468134386731045, 0.02525340928696096, 0.07573377008416823, 0.03460335212626627, 0.0758285139288221, 0.07221249903419188, 0.006749100301281682, 0.05188377307994025, 0.01131448322640998, 0.027181914375562753, 0.047528677486947606, 0.03169510014621275, 0.01288539866384651, 0.0033172075802992496, 0.04208191743652735, 0.031247796291219335, 0.04729710705578327, 0.01994201697276107, 0.09240646793373994, 0.01728900781433497, 0.012492071421417807, 0.08251798711717129, 0.025605312814669948, 0.05921804452581065, 0.010943116769859833, 0.017660744920639054, 0.04386063591976251, 0.002160107114052932, 0.030651635423834835, 0.03377129177429846, 0.0017537258120553035, 0.01554786999310766, 0.024136727243395786, 0.02246950563442494, 0.027762993105820248, 0.03779953704880817, 0.020541153216202344, 0.062318128533661366, 0.02324936119839549, 0.02238451742700168, 0.02793435882111745, 0.026194293085219603, 0.02428244942400072, 0.13332911846893175, 0.04842491368097918, 0.026257537637970278, 0.004260731727949211, 0.06779789592006377, 0.02473404840566218, 0.03827802298058357, 0.03051980285506163, 0.00803584951375212, 0.04071062869791474, 0.04121000672291432, 0.15273224801889487, 0.06671475725514547, 0.022760283334978988, 0.007691502321644553, 0.06320689405713763, 0.018208110638495003, 0.04517175217292138, 0.008869699501831616, 0.027313682483509183, 0.04924836003088525, 0.021193961579618708, 0.006739454925991595, 0.03483575037015336, 0.025646216601931622, 0.026858975811462318, 0.015361182957089372, 0.05895241163671017, 0.01681534626654216, 0.020915753740285124, 0.008324797714262136, 0.014886535837181976, 0.018549946402864795, 0.04132465539234025, 0.02036565013362893, 0.07041043216096503, 0.029354361285056387, 0.029166077995406728, 0.05366297332303865, 0.05060768958979419, 0.02354867826215923, 0.02304436728757407, 0.05192328756675124, 0.051707839127629995, 0.03165290544607809, 0.060035855642386844, 0.06718173184032951, 0.01619601682094591, 0.01413218810089997, 0.02024624832639737, 0.03380283008196524, 0.05576747343210237, 0.013550850679166615, 0.012846041936427355, 0.013364360418303736, 0.04065027979335614, 0.015719625866040587, 0.05124336155131459, 0.0469905042222568, 0.037851159993026934, 0.009926293876820376, 0.014403651302148188, 0.04444404372147151, 0.02680790756962129, 0.024601445699642812, 0.058447269456727166, 0.011523181090264447, 0.027875037897112112, 0.056939266089882166, 0.013704783133497196, 0.012321677707534815, 0.03754258601527129, 0.03592369984835386, 0.020575928135908077, 0.001490909161345501, 0.02057889163760202, 0.07095922449869768, 0.09593040562633957, 0.10933142474719457, 0.17546129838696548, 0.12311912061912672, 0.12306824406342846, 0.11202318673687321, 0.09546923930091517, 0.10521488849605833, 0.07162965102387325, 0.13607662889574254, 0.1237183077526944, 0.16850061475166253, 0.09745853434183768, 0.1366799008101225, 0.10541417423103537, 0.1743225809186697, 0.2210459459040846, 0.1363621021487883, 0.14083159874592507, 0.08995070720889739, 0.2372642084956169, 0.07004981793995414, 0.07778485930923905, 0.19076033601803438, 0.12354073513831411, 0.1568112748542002, 0.11051539371588401, 0.15210742583232267, 0.16791871669037, 0.2222897820174694, 0.08966732384370905, 0.06658316895897899, 0.08820457876260791, 0.09223990115736212, 0.09484659521175282, 0.1297547181269952, 0.08662792800792626, 0.1284407079219818, 0.1152128984353372, 0.10306092657681022, 0.17084301263093948, 0.10951908717730216, 0.14456497984273092, 0.10781215091368981, 0.08679281201745782, 0.14550025894173554, 0.10546111528362546, 0.23917412172470773, 0.09383525233715773, 0.15123579331806727, 0.20472937715905054, 0.14098828605243138, 0.12595231644809246, 0.12431191732840878, 0.13531759248248168, 0.09465622542692081, 0.15592303180268832, 0.13848080060311727, 0.1639216975974185, 0.12431658564933709, 0.1527789176574775, 0.11808912695518561, 0.10079789693866457, 0.12482399413628237, 0.10047572172646012, 0.22254891454109124, 0.14297975919076375, 0.07391298921512705, 0.09579106167490993, 0.13577914557286672, 0.1409810935812337, 0.12594227412981646, 0.14622934481927327, 0.08687670608716351, 0.10694257436054093, 0.06635340343096427, 0.04565421771258116, 0.12466166141842093, 0.1285792647727898, 0.2520514135914189, 0.1566161010414362, 0.09133722566600357, 0.08996564176465784, 0.11358946269111973, 0.13306849316826888, 0.23550465862665856, 0.09338149561413697, 0.15050834949527467, 0.10840940422245435, 0.07375459878572396, 0.11754811741411686, 0.11746472546032496, 0.07145720813423395, 0.17075256391295365, 0.15539714002183505, 0.08822744539273636, 0.20912131720355578, 0.11607617139816284, 0.12687204352446965, 0.17659264696495874, 0.1197908656405551, 0.09152137328471456, 0.138400814895119, 0.12316452818257467, 0.12021197804382869, 0.14674508571624756, 0.10409481038472482, 0.10224306796278272, 0.19692365958222321, 0.15936977256621632, 0.23635309881397656, 0.17373089838240827, 0.06531508878937789, 0.18751300312578678, 0.10327437333762646, 0.16696234872298582, 0.17331012524664402, 0.11209133879414626, 0.143247821235231, 0.13355201722255775, 0.19069685228168964, 0.12680879049003124, 0.12988714102123464, 0.07490774869386639, 0.14539391893361295, 0.10084448515304498, 0.1309887697654111, 0.12430766969919205, 0.09156642800995282, 0.10246304901582853, 0.12176688175116267, 0.17668419490967477, 0.09056474747402327, 0.21971327598605836, 0.16425195416169508, 0.13699957222810813, 0.22752603675637925, 0.16429821667926653, 0.11422383865075451, 0.12224110987569604, 0.10088776211653437, 0.11466091019766671, 0.13607170273150715, 0.12177570270640509, 0.14701326989701816, 0.09839715861848422, 0.0800695206437792, 0.12906736215310438, 0.09046233618365866, 0.13281754377697194, 0.15057152110551084, 0.10565857575940234, 0.13682590797543526, 0.09383873322180339, 0.13597602929387773, 0.08179354241916112, 0.07385323063603469, 0.1457491862986769, 0.16105040881250585, 0.10174929802971226, 0.0922150599903294, 0.14751750284007617, 0.1297758612781763, 0.06874608075512306, 0.13049362919160298, 0.15064924050654682, 0.1800912685160126, 0.19638349142457756, 0.06950080847101552, 0.12251492589712143, 0.1442655830511025, 0.12054117609347616, 0.1420256711010422, 0.2255373184702226, 0.08309027712259974], [0.07256018716309752, 0.03799512137525848, 0.028730858849095445, 0.0833083243508424, 0.04490928804235799, 0.04658022802323103, 0.010834976947600288, 0.03870881807857326, 0.03567885387954967, 0.011909018154256046, 0.12000094008232866, 0.08787998118038688, 0.02857644124222653, 0.043406288871275525, 0.03274388797581196, 0.05734913516789675, 0.043080405465194156, 0.03833999697651182, 0.057839159587664266, 0.036817445818867, 0.03674013014616711, 0.020484624463798742, 0.029997517487832477, 0.010332339410004871, 0.09858332148620061, 0.08997508018676724, 0.05675924735675965, 0.03601092891767621, 0.09028014274580137, 0.0997868933315788, 0.025277753427092518, 0.022846413177571127, 0.030598068476787636, 0.02422344232244151, 0.02329119118595762, 0.026487354056111405, 0.03325494019580739, 0.04310101257371051, 0.036846263201109, 0.016004344248878102, 0.0374071843523, 0.048557499423623085, 0.07079405550445829, 0.04705040529370308, 0.05334644691486444, 0.024746089009568095, 0.06405682023614645, 0.03460515024406569, 0.04755386809951492, 0.006850907695479691, 0.024330416760806526, 0.08465864975005388, 0.07256132710192885, 0.045017948640244346, 0.047064654529094696, 0.04176574047388775, 0.06285820848175458, 0.0281651692930609, 0.015324728663212486, 0.022185389451416473, 0.07037290917443377, 0.05875813349017075, 0.027270059467160275, 0.014485038184959973, 0.024418197139831524, 0.005436148186812976, 0.051938598709447045, 0.04598154979092734, 0.018205411765458326, 0.01800123888200947, 0.024227611920131103, 0.05285816293741975, 0.05999097055090325, 0.04442137047382338, 0.018573747714981437, 0.0076503143978438205, 0.04763591994664498, 0.0705302275185074, 0.006066399501703147, 0.02040741905303938, 0.03385766588949731, 0.036308259570172856, 0.017229206826803938, 0.05189735735101359, 0.03299183484965137, 0.15073955351752893, 0.03239265789410897, 0.04037662322766014, 0.04530577980247991, 0.03111442005527871, 0.018656925930242454, 0.06756648833730391, 0.039274329519165416, 0.06798034720122814, 0.017977430784542645, 0.011287156076702689, 0.035335291243557415, 0.015615165399919664, 0.04272406262212566, 0.03924410417675972, 0.01636167266406119, 0.08062387696866478, 0.050644578146083016, 0.035271519129829745, 0.011230987796027745, 0.1744139524442809, 0.05021653111491885, 0.015726976096630096, 0.0066580476871292505, 0.009456434669638318, 0.0012076432675322784, 0.024593092933563248, 0.023883815189557414, 0.03860084958640592, 0.06676493491977453, 0.030805293071482862, 0.03219669698072331, 0.03570642615003245, 0.05688846417303596, 0.03956924119432058, 0.022577469037579637, 0.040871675591915846, 0.03501650531377111, 0.04256102083516972, 0.041138648587678156, 0.026146298607013056, 0.05472527078485914, 0.020166503498330712, 0.0003072764120588545, 0.030667479216520275, 0.024790271817307388, 0.04015568544023803, 0.039756774702774625, 0.01689684680396957, 0.02756262680382601, 0.02586728161466973, 0.022761589514889886, 0.039876352929111035, 0.03050113974937371, 0.03916942461260727, 0.03636885274733816, 0.07772328904164688, 0.050044977106153965, 0.025471422588452697, 0.050061289088002274, 0.03539540605353458, 0.03296224393748811, 0.043911448014633994, 0.03641961055940815, 0.02097650128416717, 0.02298865786620549, 0.018986922954874377, 0.02015057488876794, 0.04403362503009183, 0.01969465533537524, 0.02889654352994902, 0.03907018547345485, 0.020191594026982784, 0.02204383008315095, 0.07637996612382786, 0.040833341756037304, 0.014259549123900277, 0.02589692680963448, 0.012433183063486857, 0.029565205864076103, 0.005823760468047112, 0.05041794066450425, 0.04583193960466555, 0.032700702614550076, 0.06731686208929334, 0.04986095501642142, 0.06523623623486076, 0.0869606544396707, 0.031611508024590354, 0.0432269758145724, 0.025047572296378866, 0.007025504085634435, 0.00908427856796022, 0.014705597689109189, 0.03473353924761925, 0.01927134278230369, 0.04695416527933308, 0.054313243965485265, 0.04776707398039954, 0.013273779385989266, 0.03935237122433526, 0.0641336100442069, 0.07215834515435354, 0.01921313804840403, 0.03605464353625264, 0.02782502138454999, 0.04506158183461853, 0.06808848532715014, 0.029344607344163314, 0.011646616788181876, 0.025000738113054206, 0.04663328606901424, 0.04489358674202647, 0.039548708724656274, 0.023993914281683307, 0.06714298749076468, 0.01598187456173556, 0.09561879520437547, 0.02851462670202766, 0.039454090408980846, 0.042844984347798994, 0.029353407943355184, 0.06671044177242688, 0.047309832980058024, 0.005102795806513833, 0.008047308273879545, 0.04971415057246174, 0.01497431960888207, 0.013949304253661206, 0.04364422396091478, 0.008264689689635165, 0.03398263168388179, 0.02257755385445697, 0.039073235488363674, 0.06918843808983054, 0.04134468574609075, 0.03154052308361445, 0.03135746451360839, 0.030473289279533283, 0.013557649600053472, 0.03681858915037342, 0.04693689317043338, 0.0389787393089916, 0.01416857708578131, 0.004435092327184975, 0.01028348658499973, 0.021178090645532523, 0.0545587684693081, 0.05483500346807497, 0.015752081892320087, 0.013036926559704756, 0.09837666007557086, 0.02116808225400746, 0.026306812851024524, 0.031747293059847186, 0.04382505354338458, 0.05246978306344577, 0.004496981930320284, 0.026105281165135757, 0.0073040851192282775, 0.013280202568109547, 0.024463777729709233, 0.07400235906243324, 0.044361574575304985, 0.023376182786055973, 0.027640371649925197, 0.03807375679856964, 0.024973586534282992, 0.059551741262631755, 0.019141983473673463, 0.0849845569048609, 0.07521079600389514, 0.06804338988981076, 0.03174561707835112, 0.09685929971081869, 0.03967387807954635, 0.011968844586850276, 0.0751016265047448, 0.01158017379098705, 0.05880732049367257, 0.04968155714284096, 0.018500655922772627, 0.042707994912884066, 0.023951393884739706, 0.025218624189229946, 0.04107905285699027, 0.031030363137168542, 0.01117076866129147, 0.03238124493509531, 0.002817092284593465, 0.05510590857427035, 0.03951713988291366, 0.043722448870539665, 0.044115629379770586, 0.045888135874910016, 0.024312298179471066, 0.02003284906303244, 0.05896106295819793, 0.014480500482022762, 0.020654039390917336, 0.06414895850632872, 0.04725299210154584, 0.025871502102485726, 0.03195536243064063, 0.00747370021417737, 0.045594533772340844, 0.03634321090898343, 0.020140161072569232, 0.018984446302056313, 0.030338474549353123, 0.04650492759953652, 0.04395804640703967, 0.030856169627181122, 0.02334853248404605, 0.0277158501890621, 0.08052574044891767, 0.03434164795492377, 0.04887038888409734, 0.031187182758003473, 0.03719108791223594, 0.03977574993457113, 0.03870841095756207, 0.0380240269670529, 0.02674907349449183, 0.0050342205130229035, 0.03258228129042046, 0.023506334284320474, 0.020174060682100908, 0.014150938567971545, 0.0717819007113576, 0.03511294549597161, 0.016332436286445175, 0.010474325407163372, 0.017362311648737108, 0.00996344706176647, 0.029573361855000257, 0.018673404153170328, 0.05320823611691594, 0.02067719609476626, 0.021111219323107173, 0.03894625444497381, 0.031575182652367015, 0.015142977969454867, 0.018248858362702385, 0.028604498665247644, 0.04550386453047395, 0.03406903972583158, 0.02437398549435394, 0.024975964799523354, 0.04127141074942691, 0.062419332031692774, 0.02917157073638269, 0.03013321092086179, 0.019454420012022768, 0.07835099500204835, 0.07122799900493451, 0.0033842158819814877, 0.018652133776673248, 0.027706781568537866, 0.009823653580886977, 0.08333092635231358, 0.031815010854708295, 0.01620893443136343, 0.05589441376339112, 0.012788741350440043, 0.03112596532862101, 0.04136255157313176, 0.09839834605476686, 0.08933727083993809, 0.15577747247048787, 0.17371032520064286, 0.09836692309805325, 0.09777178681854691, 0.15545239991375379, 0.16844129722033227, 0.12103250330047947, 0.09411419129797391, 0.29480023256369997, 0.11619761559580054, 0.12668100877531938, 0.09580092757408108, 0.23123585911733763, 0.10452390914516789, 0.13138124799089773, 0.11300926096737385, 0.12737605933632168, 0.1488887406885624, 0.1331232102321727, 0.14126400197190897, 0.1414169573358127, 0.0799896027892828, 0.18330885443304265, 0.15491026400455407, 0.2214435674250126, 0.12058819857026849, 0.1630673405847379, 0.09084686197872673, 0.08947179719273533, 0.133618649361389, 0.16119500462497982, 0.174058467948011, 0.11580562591552734, 0.12380091260586466, 0.12685947705592426, 0.1048110176676086, 0.1301827108753579, 0.08733763492533139, 0.10489226545074157, 0.11487061823053019, 0.2224007767758199, 0.10279350235526051, 0.12252670526504517, 0.11737522669136524, 0.11949313804507256, 0.19476160274020263, 0.11403089043285165, 0.13470855302044324, 0.10677956989301102, 0.1154208422771522, 0.1999423261731863, 0.14586582646838256, 0.12854603012757643, 0.17261443686272415, 0.21863463600831373, 0.10350581484713725, 0.11875747037785393, 0.05207274168995874, 0.1914096126066787, 0.08238711806812457, 0.11746632680296898, 0.08072450371193034, 0.15966741873749665, 0.11417885177901813, 0.0937845589859145, 0.295484792973314, 0.07581277870173965, 0.1238184595214469, 0.07907051353582314, 0.0977427726611495, 0.17368422874382564, 0.09305768513253757, 0.06623955882553544, 0.08671715536287852, 0.10974161273666791, 0.13221223625753606, 0.17594475458775247, 0.17041158649538243, 0.18592736178210803, 0.16038321889936924, 0.12305411696434021, 0.13940322824886867, 0.08083817189825432, 0.2550211985196386, 0.27629384132368223, 0.09200537231351648, 0.15885864570736885, 0.17931691078203066, 0.10796201894325869, 0.12505760017250264, 0.1571754174573081, 0.1578352249094418, 0.14382572951061384, 0.10869358825896468, 0.12998885342053004, 0.12264726736715861, 0.11394126952758857, 0.15392095994736466, 0.1217037101409265, 0.17635710031858512, 0.20027516117053373, 0.10146486972059522, 0.14272114235375608, 0.22459262130515917, 0.13928683235176972, 0.12836624548903533, 0.10852601046540908, 0.18395424980138028, 0.10397206339985132, 0.12196171629641737, 0.195376898295113, 0.09146595732974154, 0.14442084543406963, 0.10886864350842577, 0.11106495958353792, 0.11043179820158652, 0.10677977345351662, 0.18115187303296157, 0.11576481881950583, 0.15983562756861958, 0.10685245812471424, 0.12409812451473304, 0.19202356466225215, 0.12464829427855355, 0.11808919480868749, 0.10614154341497592, 0.10548259770231587, 0.1379628883940833, 0.0888382965432746, 0.10690879010196243, 0.13305038985397133, 0.07574100326746702, 0.07380983153624193, 0.11137851740100554, 0.10010504483112267, 0.08716416744781391, 0.12343363517097064, 0.14505830194268907, 0.19279025495052338, 0.08472761604934931, 0.08983147503542048, 0.05933382295604263, 0.12507807835936546, 0.129448196717671, 0.17348317881780012, 0.06559721007943153, 0.10657258957092251, 0.11292339236076389, 0.09905774638588939, 0.09042142730738435, 0.07833801462714161, 0.18156525013702257, 0.10649148428014346, 0.08366712688335351, 0.11197919731161424, 0.1631599199026823, 0.12864968313702516, 0.17718800716102123, 0.06744621800524847, 0.09956799114921264, 0.06540669780224562, 0.2652990227299077, 0.1566119755485228, 0.06099501238869769, 0.11896108516624995, 0.0840629299304315, 0.116830743051001, 0.1365215578781707, 0.16670483111270837, 0.10799465647765569, 0.10705905168184213, 0.10254566743969917, 0.11239580424236399, 0.12859987866665634], [0.020675766082214456, 0.03195128104250346, 0.068072288696255, 0.013393746073623853, 0.07439318166247436, 0.028266550906534706, 0.04715580553082483, 0.01041046084303941, 0.0910023075661489, 0.05474058532023004, 0.02825318885567997, 0.059495151442076476, 0.004848273080174944, 0.023679438745602965, 0.015284893568605185, 0.04718015815264412, 0.04861561594797032, 0.016428443902571286, 0.05619636523936476, 0.017784816745136465, 0.019470497899289643, 0.01639064441301993, 0.008654726037223424, 0.06302463955112866, 0.048388439031051736, 0.04773808017905269, 0.08059089338140828, 0.03860498186466949, 0.11184471167091813, 0.047294643973665576, 0.01660076804858233, 0.017345668881067207, 0.036172623812620125, 0.02774680156393775, 0.033706508643393, 0.016401088763294474, 0.034279568786067624, 0.029898478516510556, 0.05496286999966417, 0.032871951282556565, 0.06632217724940606, 0.02079327477674399, 0.04840353304254157, 0.06397050379642419, 0.059967778223965845, 0.08190746844879218, 0.033275364099868705, 0.04195133676486356, 0.048301559407263994, 0.024467453693172762, 0.04802275615345154, 0.030328035288091217, 0.0035773422153267476, 0.004988163252294595, 0.05372824160648244, 0.023906174614759426, 0.04090949374118021, 0.036767417431942055, 0.02254996631693627, 0.03857194060193641, 0.028611036350152323, 0.03482256643474102, 0.054624966345727444, 0.011237655250754739, 0.0674593612285597, 0.037789918814918826, 0.028096696627991538, 0.01431413387347545, 0.015421228217227119, 0.059277694539300034, 0.02551724575459957, 0.027667669113725424, 0.038999475339161496, 0.023580834036692977, 0.039586034936032126, 0.019478540235598172, 0.05485800241253205, 0.01947982097044587, 0.009236833596202945, 0.06233800960970776, 0.05372933065518737, 0.032688841822424104, 0.006771912648608642, 0.03331411862745881, 0.011590714832501752, 0.008874915739787477, 0.02035394879723234, 0.0251534848274397, 0.061468914816422124, 0.08025474713316985, 0.030613630677440336, 0.0483680761951421, 0.028304267275546278, 0.09158492487456117, 0.014596647017502358, 0.015227967873215675, 0.0449790651910007, 0.05014566152489611, 0.05445807047986558, 0.04183130052738956, 0.07147518931222813, 0.06515318354857819, 0.0538729459845594, 0.01443459589167365, 0.02753229289581733, 0.023301253860284175, 0.041076881544930596, 0.03147713094949722, 0.03740904353825109, 0.048224596572773795, 0.020521095721051097, 0.014540445658245256, 0.08750064617821149, 0.04041342696707163, 0.023936713779611245, 0.04287478221314294, 0.05378993061770286, 0.029983441278870617, 0.012394499782073711, 0.04623593935476882, 0.032848161844802756, 0.06402871531567403, 0.03021868597716093, 0.02072113971891148, 0.027394984549443637, 0.041063185315579176, 0.033924406593931575, 0.05407851156113403, 0.03819208312779665, 0.01656003389507532, 0.030291377433708737, 0.02342252672782966, 0.013559057560217167, 0.029062194284051657, 0.016448425062532936, 0.027032879247729267, 0.041990237177482674, 0.06245623076600688, 0.08767230875257935, 0.025293135815965276, 0.03234899755833404, 0.017735224316961, 0.020943546534648964, 0.04733108469684209, 0.05178546014108828, 0.012995985453017056, 0.10182392331106321, 0.04461662571078964, 0.033553990934576304, 0.02736918834437217, 0.02841006445565394, 0.03498793559681092, 0.05530064133927226, 0.04084501934370824, 0.06295954090143953, 0.0616846007427999, 0.025050600258899585, 0.031908753860209665, 0.05600688772808228, 0.025960156095347235, 0.05662225452916963, 0.060821239570421834, 0.0286257062772555, 0.04900269642738359, 0.011973372959930981, 0.025482175672160726, 0.029858349955507686, 0.023425870209134052, 0.009956082412307816, 0.07814210121120725, 0.08339094277471304, 0.040907831330384524, 0.08366877572344882, 0.05925465149006673, 0.002124639876585986, 0.06369444182408707, 0.027369422438953604, 0.019458764332479665, 0.04739238694310188, 0.043155814454491646, 0.04581819248518773, 0.025434031916250075, 0.016291269566863775, 0.045585013926029205, 0.06833323969372682, 0.02344961214943656, 0.079478136662926, 0.0424901953499232, 0.050481838307210376, 0.009750715307226139, 0.006611775839701295, 0.034168519744915624, 0.015606273198500276, 0.025113410549238324, 0.05841066249247108, 0.048393565363117626, 0.029342877079865763, 0.021234683858762895, 0.04811727947422436, 0.03187803997259055, 0.03640977519431284, 0.05025834583544305, 0.02923546837908881, 0.0204208642244339, 0.10019251478037663, 0.023164851358160377, 0.08475300004439694, 0.015344499477318354, 0.04532978976411479, 0.015117833158001304, 0.037589852764670334, 0.013363683579622634, 0.05701371495212827, 0.021943612157234123, 0.07073435120816741, 0.027041189605370164, 0.05954711365380457, 0.03076368530413934, 0.035575424786657095, 0.0499263284727931, 0.027499231277033687, 0.02467936696484685, 0.037672715461147685, 0.08525753154286317, 0.0021884611841025098, 0.024715870452512587, 0.03432764299213886, 0.035486099044127126, 0.015861280229208723, 0.012642351661010512, 0.06124756312263863, 0.010671290552376636, 0.013854377204552293, 0.012080494979662555, 0.02840691774950496, 0.05347433719517929, 0.04937129022021379, 0.012193754348637802, 0.04412407374807766, 0.06682315322437457, 0.03761987115389534, 0.013765495054290762, 0.08036939919527088, 0.01976430356236441, 0.04021039232611656, 0.012035945763013192, 0.021264676802924702, 0.09475124747093235, 0.008418290509975382, 0.039291818759271076, 0.037608040895845206, 0.03215054642142994, 0.05796321614512375, 0.06535771435924939, 0.002538872146812667, 0.058690938167274, 0.037818709055760076, 0.04036296431773475, 0.023835364396550825, 0.06614912367824997, 0.10345853452703782, 0.04663778475618788, 0.04675976499649031, 0.0645551092124411, 0.036480760135288746, 0.025403889694384167, 0.017977437569892833, 0.10133520846388169, 0.039774118057851277, 0.027242236138720597, 0.033987093051629405, 0.03391487656959465, 0.05785574298352003, 0.09471825031297547, 0.020807004932846342, 0.06852905132940837, 0.03286255357254829, 0.06016202922910452, 0.027671568993745104, 0.05058950824396951, 0.04353557014837861, 0.02826548899923052, 0.03457667212933302, 0.04735992582780974, 0.026758084439539483, 0.057486742069678645, 0.029214691636817794, 0.06363357044756413, 0.05709431134164333, 0.0423613245865064, 0.04057490812348468, 0.05513511272147298, 0.050624652965260405, 0.048615693979497464, 0.047621314480368576, 0.019282104347699454, 0.039924678193139176, 0.039543636675391874, 0.1497595046779939, 0.04094628051721624, 0.03335265602384295, 0.008440135096731995, 0.01804170331784657, 0.05838639808020421, 0.10142415761947632, 0.07323026763541357, 0.02662920519443495, 0.03285973086687071, 0.04209999700209924, 0.03269899949165327, 0.04049117011683328, 0.019770177979288355, 0.06182333401271275, 0.043735500491623364, 0.022265037588242973, 0.062359451316297054, 0.024918933931205953, 0.006596384545056415, 0.015177223631846053, 0.025185740685888698, 0.014675407969791974, 0.020983725985778228, 0.02382192770684404, 0.00660526953704123, 0.03797402232885361, 0.012447977671399713, 0.05524685047566891, 0.056175568141043186, 0.05017165280878544, 0.020797183138451407, 0.0239842790844185, 0.13223860412836075, 0.05042870222990002, 0.017443988605269363, 0.0502579183583813, 0.009480885679035314, 0.0277588506495314, 0.011386808274047715, 0.017587999181289758, 0.0488766822963953, 0.04969267833179661, 0.041709978466055224, 0.029638803164873804, 0.03956451180524059, 0.040409070772251914, 0.09800876517380987, 0.042613254460905275, 0.0238088201066213, 0.12379876843520574, 0.043854868372104, 0.051958744414150715, 0.05621557456574269, 0.1124720647931099, 0.10639325276549373, 0.20522141004247324, 0.1704087366483041, 0.132261280768684, 0.16941320363964352, 0.09972229679780346, 0.09101908773716007, 0.22903151597295487, 0.14154030143150262, 0.1609813475183078, 0.1513566675462893, 0.10808750042425734, 0.0665154375934175, 0.09151639283767768, 0.12358482634382588, 0.08377297156091247, 0.14942487834819726, 0.2680358258741242, 0.08692190330475569, 0.12795593536325864, 0.1771248219800847, 0.1923078436936651, 0.15539353021553584, 0.1237102738980736, 0.08768539769308907, 0.16496379167905875, 0.08825501427054405, 0.2522718831896782, 0.10954307339021138, 0.16902391452874455, 0.07273910327681474, 0.2679065242409706, 0.06513032370379992, 0.11243961046316794, 0.09670907884304013, 0.27186344191432, 0.10958749707788229, 0.17884566821157932, 0.19118972654853547, 0.15084442789001123, 0.09380563428359372, 0.1334406424845968, 0.13047586514481477, 0.07546553162059613, 0.1383021151913064, 0.18160280026495457, 0.2079325509922845, 0.07758913588310991, 0.12419022885816437, 0.11201587212937218, 0.13423152933163301, 0.08569142754588809, 0.16577635093459062, 0.1525817218103579, 0.08577568123915366, 0.11043534015438386, 0.08239152176039559, 0.11751367497657027, 0.10908924202833857, 0.11483458802103996, 0.07002906155373369, 0.12638279263462338, 0.15515733217554434, 0.14095844408231123, 0.08269681502133608, 0.2117858427975859, 0.10618192303393569, 0.15354589293045656, 0.251894047749894, 0.1928739726011242, 0.17712830965008053, 0.0913817375632269, 0.06313977337309293, 0.10726944503507443, 0.2479803663279329, 0.13007418598447526, 0.09798834805509873, 0.16414200434727327, 0.16422485347305024, 0.1298569326422044, 0.12627054937183857, 0.10996911195772034, 0.1392654584986823, 0.11982813078377928, 0.12334815332932131, 0.21634506886558874, 0.1545497312077454, 0.16694785521498748, 0.21058296305792673, 0.10721071104386024, 0.18117237836122513, 0.09230208889182125, 0.12312293398593153, 0.19796731429440634, 0.09974722617438861, 0.23051517350333078, 0.2032991610467434, 0.10763796418905258, 0.10384524520486593, 0.1744578808013882, 0.11046562317226614, 0.14168265807841504, 0.15127193209316048, 0.08317799812981061, 0.08284061016248805, 0.07031830746148314, 0.1418283259762185, 0.1351591409849269, 0.15489848463663033, 0.13769566773303918, 0.11051282885351352, 0.204746313393116, 0.1559032592922449, 0.2067220038069146, 0.13122713911746228, 0.2599008966769491, 0.14677551122648375, 0.17117425985634327, 0.13067873354469026, 0.14837172414575303, 0.213236252112048, 0.2372421696782112, 0.09517913165369205, 0.16340800587620052, 0.09355862039540495, 0.13554187544754573, 0.1674207534108843, 0.11378802917897701, 0.14174838098032133, 0.09743192219840628, 0.1364506102566208, 0.29961427567260607, 0.182705338246056, 0.0905333584440606, 0.1030969296448997, 0.19467086903750896, 0.1810193687145199, 0.2763695115489619, 0.13251446932554245, 0.1269219158483403, 0.1763388884386846, 0.09667185441191707, 0.0985412523150444, 0.21407224796712399, 0.0798214685970119, 0.19557560048997402, 0.1104975211034928, 0.14847195733870777, 0.13093486694352968, 0.15953357091971807, 0.10017028597316571, 0.15970415462340626, 0.10166928518031325, 0.11200252534555537, 0.3447379400687558, 0.1717999777091401, 0.12632701705609048, 0.1037541925907135, 0.16024589698229516, 0.10061488925878491, 0.1648084885839905, 0.1294973362237215, 0.1927523791257824, 0.11752097601337091, 0.11944346928170749, 0.07066380392227854, 0.20736131950148515, 0.11583587500665869, 0.260716550052166, 0.17106563997055801, 0.11073169032377855, 0.22822747911725724, 0.15489772467740945, 0.1525962831718581, 0.12951496456350597], [0.04276677979422467, 0.007327384315431118, 0.030908606813422272, 0.06228540278971195, 0.03259362978860736, 0.07708771886037928, 0.0198548235265272, 0.005406319787393191, 0.04561617564676063, 0.010614053579047322, 0.024518009641074708, 0.0032235811980042073, 0.07931655033358506, 0.042789951765111515, 0.04132828216201492, 0.05690743940483246, 0.04863220273650118, 0.03098587498867086, 0.026200757827609777, 0.027731736390186206, 0.060793887823820114, 0.02783883466119213, 0.008589936969136553, 0.02380195163589503, 0.01580785577451544, 0.029532419051975012, 0.013888130080886185, 0.05797889708940472, 0.07514014015240328, 0.03545650473928877, 0.03508118666442377, 0.04932381651763405, 0.08183872606605291, 0.015685576978804808, 0.029220014744039093, 0.0438122936923589, 0.04513766935893467, 0.0321578949556819, 0.01988472486846149, 0.053639509582093785, 0.024152632104232907, 0.052101952622511556, 0.05913725136114018, 0.049848246055522134, 0.026981342816725373, 0.03479312140760677, 0.027005089846040522, 0.023633501924840466, 0.01762492336066706, 0.05856505635061434, 0.040966911374458244, 0.038682680909654925, 0.028875634473349367, 0.040845348433192284, 0.04631764514903937, 0.03136772057041526, 0.08582440005349261, 0.028780320659279823, 0.06193925493529864, 0.05575780091541154, 0.021972054648878317, 0.04778011881613305, 0.05566049560106226, 0.04573588279475059, 0.009305448753626218, 0.030085350453321422, 0.014559977288757051, 0.01461584955853011, 0.025984610497419323, 0.01560172701387533, 0.04614666110969015, 0.03432887453319771, 0.0359872378675001, 0.04812640916290028, 0.059452234102146964, 0.028186568591211523, 0.01822200364300183, 0.01428518078422972, 0.030612928393696035, 0.027621320082939098, 0.09136727119662932, 0.01677811674640647, 0.026585434596719484, 0.03482127721820559, 0.14116014540195465, 0.046781590075365136, 0.06924121454358101, 0.05035303539729544, 0.04242624681709068, 0.03162434251446809, 0.029946396659527506, 0.03413281183955925, 0.046658195089548826, 0.01677861377330763, 0.030268096897218908, 0.0751254770106503, 0.008666271310565727, 0.05371415861217039, 0.028312993235886097, 0.08118826882647616, 0.01698130745041583, 0.029622324941945926, 0.06845581704484564, 0.01885872903013868, 0.043304729142359326, 0.02568162086286715, 0.04242261665474091, 0.041372814415288825, 0.05031650307189141, 0.0514767504563289, 0.012318594614043832, 0.06347217410802841, 0.01792957540601492, 0.02696111229514437, 0.0041592436692943525, 0.07973557963435139, 0.020789973703878264, 0.07352395794753518, 0.018934687632801275, 0.01723795653586941, 0.03603718483022281, 0.023607396986335516, 0.023286010571090237, 0.02504059865272471, 0.01687207518677626, 0.01439146142053817, 0.053509190146412165, 0.11044323830200092, 0.06681456975638866, 0.019327050507334725, 0.04200753642778311, 0.05144165323248931, 0.05058129457756877, 0.04036255380404847, 0.04682497899713261, 0.003244627233860748, 0.015623628427939755, 0.07682852526860577, 0.06083084084093571, 0.04067031353978174, 0.08670646165098463, 0.06907181827617542, 0.02650699594856373, 0.045616755794201574, 0.042304602451622486, 0.09105312305369548, 0.029730629308947494, 0.11381010192313365, 0.09100057051650115, 0.037058152724057436, 0.020529350099552954, 0.04772202943318656, 0.03617820815582361, 0.012164931877383163, 0.018349571619182825, 0.013018564553931355, 0.024707722943276167, 0.06282808152692658, 0.037643168653760634, 0.03380365110933781, 0.09541630678411041, 0.026237673525299345, 0.016587857223515, 0.025565448882324354, 0.03552514534177525, 0.03246991249865719, 0.06430396983133894, 0.09463363021079983, 0.05037367303988763, 0.016813046032828943, 0.012702065287157893, 0.041869681860719404, 0.014548711911109942, 0.03614415248323764, 0.030877709721348116, 0.03780283812167389, 0.019593977701983283, 0.039116118901542256, 0.03421060587944729, 0.07859895883926324, 0.04467409084151898, 0.07910021979893957, 0.08416131072278533, 0.03704734366121037, 0.04316727830363171, 0.05869138600038631, 0.023475766281730363, 0.025895869991342937, 0.11201808415353298, 0.024509170026119267, 0.016257514146023562, 0.04444058997822659, 0.03016166528686881, 0.03373372468299099, 0.08398895604269845, 0.04398200887122324, 0.024732582770021896, 0.010955058138019272, 0.043104798799114566, 0.023788104432501962, 0.026260009201775705, 0.05031554973019021, 0.02026856703949826, 0.03665096725204161, 0.04192070769412177, 0.04413930685924632, 0.019891043725822653, 0.022305817542863742, 0.023845018253528645, 0.01924256102315017, 0.015445355226152709, 0.05609807265656335, 0.02284079830029181, 0.06762921211442777, 0.07306658463286501, 0.024103745352476835, 0.01715620663682265, 0.02359198745606201, 0.041475517475711446, 0.020625652878412178, 0.03714305441826582, 0.09984242463750498, 0.022379509838564054, 0.03849514400852578, 0.06426308809646539, 0.09716877953282424, 0.027461353755955185, 0.0449358900077641, 0.038541494735649655, 0.048824323141681295, 0.0067295139638840085, 0.033456641515450816, 0.03472610589648996, 0.052130047364958694, 0.10270924187664475, 0.07009272849453346, 0.031111159694514105, 0.009561967221088707, 0.03727320082751768, 0.010578349066366042, 0.03797812407304134, 0.015254137272547399, 0.051785979220377545, 0.023996652170483555, 0.07345976174942084, 0.05103257464777146, 0.03446338052994438, 0.04264605145103165, 0.09036784339696169, 0.017660331014277678, 0.00961000325956515, 0.019768507086804936, 0.02114581612737051, 0.04133368330076337, 0.10816988814622164, 0.02521393381591354, 0.03717524751222559, 0.02889111524979983, 0.027254822963316525, 0.004159571910609624, 0.0408720996763025, 0.051540983973869255, 0.016551893171189085, 0.03417305914419038, 0.09367495522435222, 0.03166618776906814, 0.06488783564418554, 0.09989000351301261, 0.05266171347882066, 0.04906231929947223, 0.022329922499401227, 0.019329474573688846, 0.02887944444747908, 0.05567460912945015, 0.004017636803577521, 0.00981136191902416, 0.029771446582994292, 0.03871470097718494, 0.01958662238238113, 0.04219795371006642, 0.07065692357718945, 0.014075214908059155, 0.02308640762099198, 0.07130252929138285, 0.02036750253422984, 0.06981017972741808, 0.018703047651797533, 0.07833211137247936, 0.09008352365344763, 0.01967166656894343, 0.03927122861413019, 0.07058783514159066, 0.012044188267152225, 0.0691037094220519, 0.010979228403552302, 0.04623099961983306, 0.028080001273857694, 0.05125991102041943, 0.06324293105197804, 0.048976681394768615, 0.0006703523634184551, 0.08489103442324059, 0.04566715398271169, 0.019833283432360207, 0.0284696262595909, 0.0037624431757389432, 0.03429166367277503, 0.039310207058276446, 0.022702110831492713, 0.0611563612307821, 0.04503063724509307, 0.03872137436909335, 0.01850825042596885, 0.05447136298088091, 0.03790632489004305, 0.032561779354832, 0.03037854204220431, 0.06613040289708547, 0.011692744446918368, 0.0661469998636416, 0.03420294861176184, 0.042783682101539204, 0.03354644223249384, 0.08048689431910004, 0.00926141522359103, 0.01934282135750566, 0.04354272869282535, 0.0501489286710109, 0.06234726482736213, 0.022305846380602037, 0.021010624810255, 0.034955993560808044, 0.07132624409028462, 0.05228247347154787, 0.016124343166926076, 0.04600360557170851, 0.04460302108366575, 0.027782772401613847, 0.051759149945740185, 0.025012417397062694, 0.03003421605431608, 0.04367827624082565, 0.050257531593420675, 0.04591603723487683, 0.03143287350290588, 0.011880477275034147, 0.017261584821556295, 0.04203637416607567, 0.022881788600768362, 0.05309008959946888, 0.05071674034531627, 0.04357229585626295, 0.09595269550170217, 0.07252632826566696, 0.10160972337637629, 0.11305420712700912, 0.05051859454917056, 0.1590774053973811, 0.21993280920599187, 0.13292283884116582, 0.22044333895402296, 0.18427324268434728, 0.09436744092298405, 0.08077243542564766, 0.34419869471873554, 0.12663378273802145, 0.0957579966634512, 0.138961773365736, 0.1320682375558785, 0.10070204029658011, 0.14355479047766753, 0.19234657447252954, 0.08851373967315469, 0.09640428091266326, 0.0954413650823491, 0.09950445991541658, 0.08600981653268848, 0.1075764549896121, 0.04470939162586417, 0.15084545926323958, 0.15298232888536795, 0.13273578030722483, 0.1385853492787906, 0.14967552918408597, 0.14416521415114403, 0.0812267078352826, 0.11535965198917048, 0.12507221581680433, 0.09802648850849696, 0.15285019097583635, 0.11502763123384543, 0.15661546321851866, 0.16422770332012857, 0.09715254897517817, 0.20294124739510672, 0.1021080802061728, 0.14304565851177486, 0.2745060372565474, 0.04353865409003837, 0.14427904518587248, 0.15667142878685678, 0.13930874903287205, 0.07940044440329075, 0.27915044661079136, 0.10524992125907115, 0.14595384603100164, 0.1205050101769822, 0.14320191155586923, 0.13251560926437378, 0.17277678315128597, 0.14699028113058635, 0.11041007151028939, 0.11145511721926075, 0.1588982314403568, 0.0909995866407241, 0.10873997291283947, 0.06191800321851458, 0.0736636615225247, 0.13508318577493938, 0.13105496764183044, 0.16567425855568477, 0.10639774466731719, 0.0760031688426222, 0.07905925663986377, 0.20673523523977824, 0.19253817919109548, 0.08541882610214607, 0.045388605179531236, 0.14607025549880095, 0.12483593635261059, 0.188521075461592, 0.08616818660604102, 0.15323463534670217, 0.09973244768168245, 0.0973506879859737, 0.11134652447487627, 0.18665819827999386, 0.14220721993063176, 0.19340265994625433, 0.13977224273341043, 0.11228674330881663, 0.21030671788113459, 0.1370319654898984, 0.16340317470686777, 0.09774444185729537, 0.13216783292591572, 0.06648868974298239, 0.12922836494232925, 0.09057540047381606, 0.13085570904825414, 0.08607458270021848, 0.1854860968887806, 0.1081445516486253, 0.08229153962539774, 0.2023735578571047, 0.09138262644410133, 0.1772802879235574, 0.0817809963066663, 0.1222729060266699, 0.1700162584228175, 0.12527568132749625, 0.11959271984440939, 0.10947392388646092, 0.13914995826780796, 0.14026898464986257, 0.15253440077815736, 0.06258533562400512, 0.1393897525433983, 0.06913285250110285, 0.1403064669242927, 0.16111351256924017, 0.17086893266865186, 0.13104191262807163, 0.11922747801457133, 0.1368477160909346, 0.18124393666429178, 0.0812919150505747, 0.17241107991763524, 0.1020914628835661, 0.19957791215607099, 0.11540884577802249, 0.10193149825291974, 0.10186271515807935, 0.08790586729134832, 0.11751432637018816, 0.11181963301662888, 0.11467666578079973, 0.1421808520598071, 0.09704989341220685, 0.11945625288145882, 0.1875736370150532, 0.12370283715426922, 0.14423066563904285, 0.16225843184760638, 0.08006363095981733, 0.09859239349939994, 0.12474535192762103, 0.1656145067619426, 0.1184136024011033, 0.22755601443350315, 0.17103247317884648, 0.21829498851937906, 0.07522180862724781, 0.19789051770099572, 0.16158065678817884, 0.1347174011170864, 0.09878720768860408, 0.06736728402652911, 0.22302800097635814, 0.10573810006358794, 0.13586464098521642, 0.09935694640236241, 0.14286564317132744, 0.1029148922700967, 0.07023886458149978, 0.08541681763849088, 0.15788606075303896, 0.1245936993509531, 0.14313884851123604, 0.17492815985211305, 0.11800155522567884, 0.0752401358581015, 0.1283093706837722, 0.1953974850475788, 0.0752302971003311, 0.1584623676857778, 0.12374528630503587, 0.1190661902406386], [0.022437119157984853, 0.039760184341243336, 0.05813148604439838, 0.011142204033343919, 0.06289010641298123, 0.02758880129217037, 0.044252506856407435, 0.02847545487540109, 0.04122052062302828, 0.035272947446044, 0.02917511947453022, 0.0662484612049801, 0.0348962756938168, 0.022688499419018626, 0.048330275009253194, 0.03164364344307354, 0.03396180405148438, 0.10139521810093097, 0.027576409546392303, 0.018962653453594873, 0.03324641779597316, 0.02125814420703266, 0.08158014315579619, 0.0222461471733238, 0.03684046172669955, 0.01784389848554773, 0.08834993453430277, 0.03922584819208298, 0.009597195911088159, 0.01136481186508068, 0.05248645806152906, 0.05285536398046783, 0.020827832565243756, 0.10170998371073178, 0.00490852995842163, 0.024248386966064572, 0.02753115974233619, 0.0374582373271031, 0.05171296885237098, 0.011995017378857093, 0.04348062577524355, 0.047617857344448566, 0.053309117310813496, 0.030383128938930373, 0.04390498157590628, 0.0208953332288989, 0.017913546712536896, 0.030919504085821763, 0.03411032518904124, 0.06277371730123248, 0.06105365817035947, 0.01781347467164908, 0.022615417804835097, 0.034064524075282474, 0.04680862969585827, 0.01576432096771896, 0.01235994538624904, 0.029767205739127736, 0.0191411370012377, 0.06318916393710033, 0.010429763467982411, 0.04365063611684101, 0.028675364862595285, 0.029660882694380622, 0.05476524667548282, 0.06862420229507343, 0.030838961979108195, 0.025463695770927837, 0.0363716924163912, 0.036773605671312125, 0.024391595174425414, 0.020434078693922077, 0.03908315227766122, 0.04053114261478186, 0.029150858454938446, 0.06296865362673998, 0.0313511846720108, 0.058205582068434784, 0.08916319268090384, 0.034646313570972, 0.013873015713345791, 0.03483506165710943, 0.009997807226942053, 0.02572983586495476, 0.026290443193699633, 0.12074119464627334, 0.020516057598537633, 0.039109065530023406, 0.02916823234409094, 0.03833193937316537, 0.08253129318888698, 0.041850380932113955, 0.07460580739591803, 0.049428972482149086, 0.007293995303500975, 0.029359100852161646, 0.05798194371163845, 0.021855288950194205, 0.05244963396606701, 0.0414537534649883, 0.019263403922585503, 0.033356272615492344, 0.01589025028182992, 0.022010305364217077, 0.03547845873981714, 0.02042468437658889, 0.008939630169022297, 0.02461103000678122, 0.014941727875598838, 0.03367384057492018, 0.03286414812984211, 0.03399282327986189, 0.029916228992598395, 0.01573519315570593, 0.015290438896045089, 0.06546461076608726, 0.028295962006918023, 0.04341655171343258, 0.010210813788164939, 0.02386338619648346, 0.06115729082375765, 0.04810676218143531, 0.04171612938599927, 0.052497409616730044, 0.010226768690959682, 0.01589575659350625, 0.07748394259916884, 0.018851757082822065, 0.01924315813396658, 0.04210072981991938, 0.0281911995927138, 0.07526785401361329, 0.040406078432819674, 0.052181568528924666, 0.020466695872268507, 0.05542861982913954, 0.06252164154180459, 0.014390116224863699, 0.021424090123868415, 0.07371091470122337, 0.006793515083180475, 0.05230922471465809, 0.04153769503214529, 0.02811369562654623, 0.03800704323553613, 0.015361025197697538, 0.039643686663891585, 0.012697485175782015, 0.01704745104403368, 0.05448150368673461, 0.039475599969072, 0.04320640941815717, 0.034233475902250836, 0.014234251642067517, 0.06909813864954881, 0.026904128924278275, 0.08290764263698033, 0.00934367232756423, 0.018629552131252627, 0.02942568210086652, 0.027993291283824613, 0.03161930099927953, 0.014067244666096355, 0.013167787127063742, 0.054826732126197646, 0.05598762411890285, 0.01936678551802678, 0.06466668751090765, 0.022555762702333074, 0.021592577154349004, 0.06462866919381277, 0.06504157132336072, 0.03390462729813797, 0.012685358058661222, 0.01931550184131733, 0.021630642968895178, 0.007008495333138853, 0.009457832451776733, 0.04040294360103352, 0.021814447927421758, 0.06842208706906863, 0.02004245202988386, 0.09443817141332797, 0.03698198377553906, 0.08408348954149655, 0.01899785585036235, 0.017848040941836577, 0.016293965047225356, 0.010794635496235319, 0.09886620952082531, 0.01480383429277156, 0.03468835899340255, 0.0554631776176393, 0.08901876650218453, 0.023580411648643867, 0.0066268011495204905, 0.017562331897871833, 0.03606444497459701, 0.06656040410910334, 0.019586006611851708, 0.030924593098461628, 0.0507597492874733, 0.026544354390352964, 0.026777405724195496, 0.04096370868917022, 0.0350279555922108, 0.03604816013414945, 0.037235498029206476, 0.042562164166676145, 0.03036189079284668, 0.06260117263134037, 0.05629841012081929, 0.08007225513990436, 0.0733302633411118, 0.016397278789164763, 0.006192144339105913, 0.02455488801933825, 0.04801115320463266, 0.058488945077572546, 0.04937323422304221, 0.028766678712729896, 0.012796003371477127, 0.00938683224376291, 0.03962813464126416, 0.018287275319120715, 0.042107756050037484, 0.08918453260724034, 0.0365451938206596, 0.036566849265779765, 0.029546997376850674, 0.054622649148638756, 0.027520269255286882, 0.045954449102282524, 0.029637398597385203, 0.023247271310538054, 0.01812618432034339, 0.03657022158482245, 0.028233260282182267, 0.05470267217606306, 0.021761917442615544, 0.02180649380066565, 0.030138805442090546, 0.034662476275116205, 0.0673777266804661, 0.06576695239969663, 0.05711241465594087, 0.04387686987008367, 0.09692889026233129, 0.029414747509041002, 0.01010548903806401, 0.059046599082648754, 0.04155250745160239, 0.04117953710790191, 0.03452313910903675, 0.05933997726866177, 0.05631700537300535, 0.030743064624922614, 0.06016285704182727, 0.00814418780750462, 0.07381593156605959, 0.0365982111543417, 0.0483027638069221, 0.0649300269516451, 0.03962454519101551, 0.06091381210301604, 0.032546549636338434, 0.0447214220517448, 0.03620874223166278, 0.013211285462602973, 0.03596901920224939, 0.0223773792386055, 0.05054614307092769, 0.08444721823824303, 0.020252132921346595, 0.022088959447241256, 0.04176436644047499, 0.049959335808775256, 0.05059515365532466, 0.052224054999117336, 0.043999918803040466, 0.030058931692370346, 0.0224718618472772, 0.011891429678403904, 0.025875637773424387, 0.05688194345150675, 0.04987394217667835, 0.023851745928238546, 0.06556143771324839, 0.018738879389794807, 0.011034770735672541, 0.037517215590924025, 0.05190848871799452, 0.040535627731255124, 0.07836386681135211, 0.021242945022614937, 0.017142542637884617, 0.02435160062408873, 0.04259294590779713, 0.024812185105734637, 0.06431798157947403, 0.024025774893483946, 0.017124067825664366, 0.054201631740267785, 0.028165722299101095, 0.008324236226534205, 0.03473351889156869, 0.03416143244664584, 0.004881791437843016, 0.050390222508992465, 0.03279012335198266, 0.022969954048416445, 0.07472532455410276, 0.0398318919220141, 0.022348256515605108, 0.010313874775809901, 0.05254780101988997, 0.034828350945774994, 0.021136489663539187, 0.07256249418216092, 0.04094714904204011, 0.03603500673281295, 0.08286072872579098, 0.02755617393579866, 0.05294593822743211, 0.0545030437809016, 0.0310045313090086, 0.04311403366071837, 0.03334994527644344, 0.11256211996078491, 0.04171991561140333, 0.06145904891725097, 0.10121874471328088, 0.05138926015102437, 0.03453968857814159, 0.0073187499573188165, 0.05480233539960214, 0.022665934736973474, 0.014743412445698465, 0.020203682128340006, 0.06123732402920723, 0.03209969700713243, 0.009289849233547491, 0.03430162795952388, 0.06492660034980093, 0.04614870350009628, 0.020102251321077347, 0.0500976721357022, 0.01598497207409569, 0.022629436338320374, 0.07032492317791496, 0.021452729390668016, 0.004345072782598436, 0.15002326481044292, 0.1792328538639205, 0.17406164349189826, 0.13977327410663876, 0.1506641682769571, 0.11095186815197979, 0.14148831207837376, 0.11667005238788468, 0.11915582471660205, 0.14102494051413877, 0.17280680154051098, 0.16737264527806214, 0.10549616161733866, 0.18703060543962888, 0.12387100527329103, 0.1548949833959341, 0.12004136719873973, 0.3097154636468206, 0.08604636242879288, 0.12994492506342276, 0.08924796206078359, 0.09772995513464723, 0.19025228970817157, 0.11052012310496398, 0.141892637525286, 0.17299224516110762, 0.13526837155222893, 0.13160397032541887, 0.08178218374294893, 0.07954272641135113, 0.09763226644801241, 0.1280991333935942, 0.0976173183215516, 0.10559045084353004, 0.16854978139911378, 0.13135809637606144, 0.17885112363312924, 0.11631916835904121, 0.16080532196377004, 0.09989158449960606, 0.1151629446872643, 0.13788067709122384, 0.12947598951203482, 0.10150201272751604, 0.13987675069698266, 0.09830257762223482, 0.09273077374590294, 0.11630799967263426, 0.14175885756100925, 0.15040275587567262, 0.12717857850449427, 0.10858680041772978, 0.1589196595762457, 0.0864093718784196, 0.13548390141555242, 0.11929233239165374, 0.15640420812581265, 0.09644835854747466, 0.16866526805928775, 0.09230026363262109, 0.15023556484707765, 0.17092761237706455, 0.1367372777312994, 0.10060174603547369, 0.2324213140777179, 0.163727161607572, 0.1240963331822838, 0.11867486552468368, 0.17989490048161574, 0.10540614037641458, 0.10352281214935438, 0.17106945333736284, 0.15008894700024808, 0.10379039921930858, 0.15811092725821904, 0.1357755764786686, 0.14081364470933164, 0.10678066911974124, 0.17788707464933395, 0.09845181461423635, 0.0974251843456711, 0.11973181952323232, 0.09574319102934428, 0.19334190392068454, 0.07232803997716733, 0.2168590591422149, 0.1256474642349141, 0.09729428136987345, 0.1499783457922084, 0.1040995397738048, 0.19610421998160227, 0.08827655775738613, 0.21000943811876432, 0.10709632361041647, 0.0779038607808096, 0.14037669529872282, 0.24621378683618136, 0.1917303018271923, 0.14859131164848804, 0.18929628814969743, 0.10390480700880289, 0.16121603921055794, 0.11330172313111168, 0.1116845231237156, 0.18828012767646993, 0.11022824448134218, 0.10395917801984719, 0.08208217086004359, 0.08354712117995534, 0.10768679156899452, 0.14804521309477942, 0.12874242530337401, 0.08145296533725091, 0.06944679029818092, 0.13074946403503418, 0.13157237773495062, 0.16541376896202564, 0.1463636133287634, 0.08107628340699843, 0.07090349641761609, 0.14775652358574526, 0.1693028738456113, 0.10938604003084557, 0.18026626269732202, 0.09610214283955948, 0.15544607596737997, 0.19459935144654342, 0.17598180259977067, 0.05639774425487433, 0.12640423434121267, 0.17537023898746285, 0.1974898970552853, 0.2349440258528505, 0.13990454349134648, 0.14003643712827138, 0.11729802297694342, 0.15706017506974085, 0.12621583230793476, 0.13535039286528314, 0.1930170484951564, 0.16015322266944818, 0.07652109462235655, 0.2490441192473684, 0.15022602464471543, 0.10305889097175427, 0.13078929404062883, 0.13309908152690955, 0.09748055280319282, 0.20403982273169927, 0.10324523704392569, 0.14380123439644063, 0.14063646564526217, 0.16849577001162938, 0.17091180251113006, 0.18672293052077293, 0.17371253722480365, 0.18063404224812984, 0.07247578419212784, 0.08215413628412144, 0.1410986158464636, 0.18328402005136013, 0.1001085392864687, 0.13252873213163444, 0.1215769462287426, 0.08482594934425183, 0.07727030584854738, 0.14068371882396086, 0.1522928015994174, 0.11305709768618856, 0.07749163040093013, 0.08378466950463397, 0.23661482334136963, 0.11482143801237855, 0.12372645017291818, 0.13429056187825544, 0.11423941781478268], [0.03165133463750992, 0.034310231783560345, 0.005905926393877182, 0.05506274356905903, 0.04014392303568976, 0.012426824342193348, 0.06289094779640436, 0.038220001451138935, 0.026871638971247842, 0.031044493628931896, 0.02217518937374864, 0.04907867877877184, 0.025269074964204004, 0.010719087407259005, 0.045368771600936136, 0.07488031552306243, 0.024216485642162815, 0.03705546572538359, 0.014196024675454413, 0.008462192573850709, 0.04170696237789733, 0.04148034525236913, 0.09030515354658876, 0.06524608856333153, 0.041764251089521816, 0.03920281532087496, 0.04872159633253302, 0.018667641694524457, 0.030907646686370884, 0.05236608934189592, 0.03720680617594293, 0.012099078357485788, 0.05368772967319403, 0.10477486532181501, 0.015013116544910839, 0.029714453034102917, 0.0998724837388311, 0.03982097429356404, 0.014095384361488479, 0.03760220888735993, 0.0023574882860495044, 0.044730110692658594, 0.01169158160753016, 0.02485554518976382, 0.053535344278705974, 0.046481877764953036, 0.026037225799102868, 0.0193493030632713, 0.059462208566921096, 0.025391204482210532, 0.033321049862674305, 0.04339448914730123, 0.017679497932216952, 0.07540563054914985, 0.03079556966466563, 0.08551427562321935, 0.06973761040717363, 0.04066035943105817, 0.011354602457556342, 0.035175625168319256, 0.009541178604454865, 0.06820664541529757, 0.018409842492214272, 0.03328929103112646, 0.01884716170440827, 0.020364091199423586, 0.0426262450138373, 0.032876816378640275, 0.011694906429121537, 0.04816668700160725, 0.012818054063245654, 0.020762928994372487, 0.06554011135761227, 0.04780897691047617, 0.019703975013856376, 0.07079910380499703, 0.02239781162435455, 0.008417153963819146, 0.020279248877029334, 0.0425879383193595, 0.02122791886462697, 0.055373007099011114, 0.0208242465076702, 0.03331122128292918, 0.01875823799387685, 0.017537514479564767, 0.019407472174082483, 0.05783802643418312, 0.030486123769411018, 0.0746675201558641, 0.02575969310211284, 0.03356655401044658, 0.05173356917553714, 0.03059260287721242, 0.033545349791113815, 0.05119825593594994, 0.03462136723101139, 0.015830579912289977, 0.0371303115306156, 0.06901577806898526, 0.009741990195055093, 0.1013021773791739, 0.04107623354398778, 0.06590671704283782, 0.03646895023328917, 0.04328151985204645, 0.017419815795230012, 0.030160884971597364, 0.021681054728105664, 0.03377587867102452, 0.025448143748300414, 0.02575692467923675, 0.017424278859315172, 0.009004628734796174, 0.031986656465700695, 0.07627513924879686, 0.0582079840824008, 0.02564988747638251, 0.012031709159990507, 0.0419630618499858, 0.056453282346150706, 0.017993720714002848, 0.0480877428448626, 0.03510407365060278, 0.0604248529832278, 0.009110773664100893, 0.026309879829308817, 0.029438319815588847, 0.04974903066509536, 0.07896759334419455, 0.019557150213846138, 0.03046747762709856, 0.02568621963395604, 0.0351486941134291, 0.01814407728878515, 0.04349757558000939, 0.035319277817117314, 0.025324701265032803, 0.04135062632017902, 0.03313744167930313, 0.06755262586687293, 0.031159797084650824, 0.031287080076123984, 0.08425419538148812, 0.021835289130519544, 0.007016522826493851, 0.021445170510560274, 0.026071668236649463, 0.03271842594923718, 0.03770481695287994, 0.004316945385653526, 0.03199066321498581, 0.04649200150743127, 0.03112688135089619, 0.037573204907987795, 0.05059972698135035, 0.03459267537774784, 0.02077717992610165, 0.04789841800395932, 0.06599615474364587, 0.04677470973027604, 0.019439231005630324, 0.04684158614171403, 0.057043767268104215, 0.06861462816596031, 0.022880514651270847, 0.039659435461674414, 0.037126915462847264, 0.041260157246142626, 0.06037217152437993, 0.024179897337619747, 0.012701472417185349, 0.1114803994340556, 0.017537219316831658, 0.01198468922770449, 0.021622051019221544, 0.08324756832527262, 0.038269151135214736, 0.036057540880782266, 0.02957512265337365, 0.04367167070241911, 0.023510816008118645, 0.007639972675990845, 0.04525669797190598, 0.026981402188539505, 0.027534079139253924, 0.04261603984715683, 0.019053950340354016, 0.03889185629252877, 0.019981665470238243, 0.026048121375164816, 0.049012538577829085, 0.030909091965960603, 0.01610109655718718, 0.023487603325130682, 0.01715247130154499, 0.039772248693874905, 0.061495459106351645, 0.062163978948124816, 0.06805737449654511, 0.05125815700739622, 0.047696309563304694, 0.03530321689322591, 0.010501113121530839, 0.0346132282034627, 0.019383514798911552, 0.03900511735784156, 0.020664331070812683, 0.0012013112635551287, 0.038361845804112296, 0.043837745540908406, 0.05115443614444562, 0.0305991405621171, 0.05162726648684059, 0.010910150994147574, 0.06729734742215701, 0.029374903932745968, 0.08889764800135579, 0.020195115623729568, 0.00337681921415164, 0.08082596505326883, 0.045626370635415824, 0.042859542316624095, 0.02264151256531477, 0.03916801665244358, 0.024781596747093966, 0.045665247299309285, 0.016604299823354398, 0.02902104452784572, 0.01385288273117372, 0.04070297821557947, 0.05939825664141348, 0.04561611797128405, 0.006838879814105374, 0.03445571308423366, 0.01270960211487753, 0.05247450227450047, 0.05216160602867603, 0.0677476232605321, 0.06088594466980014, 0.035097054205834866, 0.024158404740904058, 0.08754776364990643, 0.017391532759315202, 0.0244622629002801, 0.06059022553797279, 0.03339453520519393, 0.040908618431006155, 0.035698331227259975, 0.02288675886977996, 0.015113088501883405, 0.040598504178758175, 0.056113719674093385, 0.023764096167204634, 0.030830232626093284, 0.08082378695585898, 0.1260984321790082, 0.06710719476853098, 0.030261555819639137, 0.030570475850254297, 0.09294452584747757, 0.02718284905755094, 0.008934196799860468, 0.011792907241864927, 0.0687370290979743, 0.017148798730756556, 0.02882038475945592, 0.08749012888542243, 0.013569579093850084, 0.011431464359962513, 0.04198218296681132, 0.04630868848679321, 0.04346926709903138, 0.02616783361216741, 0.016775663842314055, 0.014259340474382043, 0.03148460162005254, 0.11019860607172761, 0.013543115379954023, 0.05861389730125666, 0.017055150720157793, 0.02354406252769487, 0.00676097339185487, 0.03792239259928465, 0.009028067030677838, 0.05046892917848059, 0.051363340113312006, 0.02965595313747014, 0.03952569620949881, 0.012528658877792103, 0.051395027698682885, 0.06286253074982337, 0.08235611580312252, 0.016699717114014283, 0.03632631538701909, 0.04064662927495582, 0.07020560279488564, 0.039386423504246135, 0.026111040231106535, 0.04365221371075936, 0.11624820716679096, 0.023818514675700238, 0.03970581672287413, 0.04268272966146469, 0.044296509852366786, 0.013896814480956112, 0.011054119161729301, 0.029203346531305994, 0.03771808570516961, 0.01613830741760986, 0.01989219553901681, 0.06478069496474095, 0.020308792291741287, 0.025323208487991775, 0.029060131537594965, 0.03799152513965964, 0.01757316131676946, 0.017573807621374726, 0.034008253166185956, 0.037006156585578404, 0.03740187820845416, 0.07704991088914019, 0.03973482070224626, 0.012599500478245318, 0.03950852927352701, 0.023835976774405156, 0.020387375128588507, 0.027173967034156834, 0.026448613099221672, 0.01921731443144381, 0.04774826159700751, 0.02794236723067505, 0.04255151455955846, 0.05649803512330566, 0.055202718558056016, 0.06179473376167672, 0.07360668493700878, 0.030494720808097293, 0.05560661992058158, 0.05655268094103251, 0.014172988411571299, 0.03181185905954667, 0.04876828293449112, 0.02994697680696845, 0.01537636517813163, 0.03363799356988498, 0.02893141683723245, 0.029026354064366648, 0.003582173808743911, 0.06257584291909422, 0.006136885719440345, 0.03799465657877071, 0.18021539971232414, 0.10186620282807521, 0.08172490860202483, 0.12912369413035257, 0.09897495154291391, 0.09130433028829948, 0.1447636413254908, 0.09859710931777954, 0.1161225289106369, 0.1501061682190214, 0.10441042416329895, 0.12455220014921256, 0.11821240319737367, 0.08676028304866382, 0.07541508254195962, 0.1889095367597682, 0.1113379206508398, 0.12562497758439609, 0.10294448996761016, 0.11808909981378488, 0.0760593990396176, 0.17063068545290402, 0.1489884853363037, 0.2445836200245789, 0.20556134251611574, 0.12154006106512887, 0.14939608132200582, 0.0840400361589023, 0.12698845299226896, 0.12704231510204927, 0.15383171902171203, 0.09796494538230555, 0.12780739047697612, 0.1800846324435302, 0.0908021465209978, 0.14588629108454498, 0.20319409668445587, 0.14030890965035983, 0.1533832616571869, 0.14906802321118967, 0.17388599791697093, 0.1474463109459196, 0.11287846655717917, 0.13398277839379652, 0.1975240409374237, 0.19208075159362384, 0.1315265494797911, 0.08119274715759925, 0.15150566026568413, 0.1886301567511899, 0.11927436478435993, 0.12954931200614997, 0.07911723745720727, 0.11335435030715806, 0.14930770892117703, 0.23505861684679985, 0.13385885075799056, 0.12603701118912014, 0.09311021731368133, 0.09199963190725871, 0.11667063592800073, 0.17429895432932035, 0.10538295483482735, 0.1295429202062743, 0.0770082895510963, 0.12699203565716743, 0.1586844657680818, 0.08818346275282757, 0.0810633912416441, 0.18085809451128754, 0.06798822499279465, 0.10201210821313517, 0.13487456339810575, 0.0928772898124797, 0.0819248321599194, 0.11155355907976627, 0.10993563303990023, 0.132296211751444, 0.22139156450118336, 0.147595398660217, 0.26804258408291, 0.17191496225340025, 0.12762715800532273, 0.07551847770810127, 0.12177244573831558, 0.13429812075836317, 0.06512991658278874, 0.10167261000190463, 0.13357421888836793, 0.197137927370412, 0.12567076512745448, 0.1467116339398282, 0.10347192880830594, 0.07564988279981272, 0.11039251780935697, 0.11983803739505154, 0.0827220022412283, 0.12462059647909232, 0.17544147159372056, 0.15444381189133438, 0.16351042395191534, 0.3282193850193705, 0.07359077329082148, 0.13452488716159547, 0.16612344873803003, 0.13171377086213656, 0.11113826850695269, 0.13839113898575306, 0.10571935892637287, 0.17260667442211083, 0.1623276559902089, 0.140445580173816, 0.11317225186420338, 0.1396054181137255, 0.11343453957566194, 0.25771435829145567, 0.1440218939845051, 0.1611605757581336, 0.15738744607993535, 0.11564925073512963, 0.15179236845246383, 0.20846131976161683, 0.11676350023065295, 0.15513723396829196, 0.17550587813769067, 0.09832997008093766, 0.13154069014957973, 0.16060219572058745, 0.20780444358076366, 0.14094553834625653, 0.13993072137236595, 0.14901478535362653, 0.08734956357095923, 0.17329412539090427, 0.13870174517588957, 0.13851737364062242, 0.14872578371848377, 0.15520577957587584, 0.10596694278397731, 0.1332216113805771, 0.1355242199663605, 0.10866941205625023, 0.2231284241591181, 0.18572719395160675, 0.09054867297943149, 0.2214618878705161, 0.0855721343042595, 0.12390791757830552, 0.13575406691857747, 0.08747026138007641, 0.1406008561274835, 0.09404963547629969, 0.10715301521122456, 0.06657440228653805, 0.13104062341153622, 0.24082228328500474, 0.13914866905127252, 0.1404488371419055, 0.16043898090720177, 0.13527785747178964, 0.14901842230132648, 0.11905179172754288, 0.09709063944007669, 0.0967280167554106, 0.11571871915033885, 0.10023132698344332, 0.2223405907196658, 0.08675103461635963, 0.0868853981207524, 0.11898076268179075, 0.08402761896806103, 0.09075160244745867, 0.20076680050364562, 0.16686552177582467, 0.0774082113057375, 0.14482617511280946], [0.09157666710338422, 0.029217802719878297, 0.0025367464238245574, 0.004807177606770503, 0.0734296687213438, 0.041112552130860944, 0.04289567769904222, 0.03854510793462396, 0.020590633686099733, 0.024760226286681633, 0.04980849747412971, 0.016570730999644314, 0.032294148180101595, 0.025908872418637787, 0.01401635878054159, 0.010173176298849285, 0.04448012142841305, 0.046673608012497425, 0.02519846152115081, 0.03875673282891512, 0.027091424945475798, 0.04044900595077446, 0.030081041755953004, 0.05366789270192385, 0.05975908799363034, 0.036465645767748356, 0.0642956577773605, 0.017571663450715796, 0.03806460336116808, 0.050896450345005305, 0.027332985108452182, 0.05141322261520794, 0.025324021033676605, 0.022183752485683987, 0.030833068902471235, 0.020502201913456832, 0.024604344740509987, 0.028276793392641202, 0.006388828316370824, 0.0721185083634087, 0.035439734746302874, 0.054018637631088495, 0.02755686773785523, 0.02560302784799465, 0.026931119350982562, 0.05109571572393179, 0.05054741532408765, 0.016663490129368644, 0.06890146527439356, 0.016946992238185236, 0.021210687467828393, 0.07076843402215413, 0.007236874529293605, 0.027871568886829273, 0.06925063939499003, 0.051616097800433636, 0.013472868345810898, 0.035249426029622555, 0.02616154868155718, 0.03724095005808132, 0.05707767366298607, 0.05912546520786626, 0.016155706751825552, 0.007543564724203731, 0.040903475135564804, 0.07032533708427634, 0.015990337589755654, 0.04956533427217177, 0.06516685602920395, 0.014040296647830732, 0.02701640102480139, 0.03879476132403527, 0.04767615368057575, 0.006234673641821635, 0.02716396203530686, 0.034548037951546054, 0.06265868525952101, 0.011412279630479003, 0.019972880138084292, 0.01512986358388194, 0.04306565411388874, 0.02446489391981491, 0.04279451152043683, 0.03242086798750928, 0.06254752765276603, 0.029976564326456616, 0.03873275340135608, 0.03369273438251444, 0.06823955436370202, 0.0395528138615191, 0.04824110193710242, 0.027642451359757354, 0.02602275095081755, 0.0537245944807572, 0.04317267265702997, 0.04125565516629389, 0.03257346372785313, 0.032949385698884726, 0.038635821281267066, 0.028883878673825945, 0.08928021283021995, 0.02791413678122418, 0.006823487247207335, 0.11384147059704576, 0.07476699338959795, 0.06113802042922803, 0.03573260063837681, 0.016998832313609973, 0.05066538542242987, 0.012861490482464433, 0.057914171633975844, 0.02605216544387596, 0.10465703771582671, 0.06052967985825879, 0.018351198406890035, 0.015092391487477081, 0.027675207637782608, 0.051908719419900856, 0.04123135682727609, 0.05549913997362767, 0.037178830177124055, 0.04231283986674888, 0.010663466195442846, 0.04394274204969406, 0.024158246981512223, 0.03342967653380973, 0.01786709250882268, 0.027098291719864522, 0.055064161707248004, 0.05287127562665513, 0.054524058010429144, 0.0531530305077987, 0.03882991961602654, 0.02839972697464483, 0.05793035469417061, 0.03079944070694702, 0.05879761065755572, 0.021327980727489506, 0.03611930453085473, 0.015605497972241469, 0.10831030418298074, 0.009781628514506986, 0.04086859165025609, 0.03412316307159407, 0.026586413383483887, 0.029659956494080167, 0.0438774093054235, 0.012844546614880008, 0.04529262300846832, 0.04456071781792811, 0.02125486857923014, 0.00880484766925552, 0.009818059907826995, 0.05442114121147564, 0.06653323556695666, 0.10275102606309311, 0.044295576866716146, 0.006953562410282237, 0.00530134278648932, 0.05826979862259967, 0.04914388938673905, 0.03226637913446341, 0.004631053664655025, 0.03582795855722257, 0.025083112264318124, 0.007958832396460431, 0.04511919624305197, 0.01751541459400739, 0.023949741651969295, 0.0314472211258752, 0.029353513116283075, 0.02963231297742043, 0.04681628357086863, 0.037417823781392405, 0.023981239247534956, 0.04546414648315736, 0.036521953996270895, 0.038375145090477805, 0.02475415000558964, 0.030354606719421487, 0.06682535846318517, 0.031169130333832333, 0.035511557678026814, 0.025931837436343943, 0.04102972336113453, 0.04516780649178794, 0.06350875393088375, 0.06870943986411605, 0.04521129719380822, 0.023178873284320747, 0.05165757325344852, 0.009326720826460846, 0.04432848920779569, 0.008305308492189007, 0.016515912155487707, 0.018413961199777465, 0.06456625754279749, 0.05539339029097131, 0.04225359358159559, 0.052263532166502306, 0.04398174084989088, 0.03074457436533911, 0.021559176268056035, 0.061902966882501326, 0.03197842922859958, 0.09121504186519555, 0.02375780275490667, 0.02331054300468947, 0.0083561044718538, 0.022416603651696017, 0.03909780863406403, 0.02820196794345975, 0.036232473993940015, 0.014130767418204673, 0.020912912374894534, 0.045405436240668805, 0.014232329691627195, 0.02366980694101325, 0.0415766022301146, 0.029591125901788473, 0.03618436925379293, 0.026806448719331195, 0.05955288798681327, 0.06010084572647299, 0.019068945964266146, 0.052254378729100735, 0.05562613119504281, 0.03656220130090203, 0.06671119494629757, 0.04995041985863021, 0.06493467491652284, 0.03678198218611734, 0.0186779622121581, 0.02999576347480927, 0.03463444938617093, 0.03988778285150017, 0.02099396168653454, 0.04455483491931643, 0.058917501010000706, 0.05055268754118255, 0.04305003084508436, 0.04294928875086563, 0.06024414553706135, 0.02890260284766555, 0.03423524348597441, 0.015386989340186119, 0.05222644004970789, 0.04255888684253607, 0.01999318869119244, 0.0859212473567043, 0.0411897320965571, 0.06152247158544404, 0.014859920301075493, 0.009180171681301934, 0.020081734118450965, 0.031826087938887734, 0.05601158658308642, 0.024675584132117883, 0.03181904135271907, 0.013722783819373165, 0.06150851412011044, 0.04418825976816671, 0.0442802860800709, 0.10096547473222017, 0.02028121323590832, 0.09663001594266721, 0.034903580123292546, 0.02941242352660213, 0.04483880860997098, 0.014563624414482286, 0.025718017481267452, 0.04244811260806663, 0.029254124699426547, 0.04433118638449481, 0.035996418446302414, 0.0346564542768257, 0.12305778105344091, 0.029336427604513507, 0.006786950256875051, 0.023995266262707964, 0.02655085305949407, 0.09517105030161993, 0.04220332770741411, 0.040875041125608344, 0.028750227631202767, 0.010552544379606843, 0.02160301641561091, 0.02472174826211163, 0.05232428479939699, 0.04556049167045525, 0.02460253644468529, 0.02336843391614301, 0.06123734438525779, 0.057920719496905804, 0.07963856269738503, 0.015134976345247455, 0.07487675321421453, 0.016007426494200314, 0.015225626927401339, 0.022449285290869217, 0.027270831300743988, 0.02964431626190032, 0.011731619414474283, 0.03283892019784876, 0.04729996029553669, 0.060299561492034366, 0.028334370481648614, 0.036406362163169045, 0.05187507426100118, 0.049108011847628016, 0.04204651826460447, 0.021598343005669967, 0.027251277617844086, 0.02125544872667108, 0.02815903872916741, 0.017747405716883283, 0.04119751150054591, 0.0398266197049192, 0.01790958915704063, 0.01819314724499626, 0.010570333023289484, 0.033795919202800305, 0.044170173417244635, 0.019167659238779118, 0.013978651741386523, 0.013213970764939274, 0.06426732894033194, 0.026585639853562628, 0.028114024716030275, 0.025493005091058354, 0.019462789741477797, 0.005376192408480814, 0.048839403582470756, 0.011451887415855058, 0.059243550657161644, 0.03163644079385059, 0.04970348739464368, 0.03136525070294738, 0.033139083734048266, 0.00855262772113617, 0.021291197344128574, 0.03401785104402474, 0.060198853324566565, 0.027377159434503744, 0.06115287356078625, 0.06025030663503068, 0.039828404252018244, 0.03170746644692762, 0.05058286199346185, 0.052798149907695394, 0.07705254360501256, 0.054567107664687295, 0.1459766990904297, 0.11230098575885807, 0.07638079393655062, 0.1012044276243874, 0.23988886337195123, 0.07673296718192951, 0.14686005668980734, 0.08272350858896971, 0.13321042912346975, 0.09582911391875573, 0.15209674569112913, 0.15338525655014174, 0.16699570550450257, 0.12631324279521192, 0.12594363119985374, 0.11338053497352771, 0.1890147096876587, 0.07656116211520773, 0.08494045212864876, 0.08994449861347675, 0.09950969142041036, 0.10619045221912009, 0.08613440234746252, 0.11780311087412493, 0.11456149124673434, 0.07457800103085381, 0.12701663933694363, 0.1662797424942255, 0.11023803574166127, 0.2584502159484795, 0.07243789479668651, 0.12243540159293584, 0.057638028237436495, 0.1455713151288884, 0.11303164583763906, 0.2619334618960108, 0.11103688858981643, 0.12708234866814955, 0.06237577686884573, 0.08870710179741893, 0.14799821775938782, 0.15231517968433245, 0.10577083937823772, 0.054250520188361406, 0.06984323116817645, 0.14400680336569036, 0.14148189313709736, 0.0919595304876566, 0.10198334511369467, 0.1440595526780401, 0.16708874622625963, 0.17202123440802097, 0.1377951952495745, 0.1792690876339163, 0.12457987080727305, 0.13537528152976716, 0.09405255317687988, 0.11424200981855392, 0.12012458273342677, 0.1659534214330571, 0.1462724996464593, 0.12195669513727937, 0.10773251804390124, 0.15915129786091192, 0.10622210587774004, 0.12455663776823453, 0.15599549934267998, 0.08463939292622463, 0.21457671161208833, 0.09618387916790587, 0.06632773445120879, 0.16246151737868786, 0.10827947833708354, 0.16144028146352085, 0.1345865252826895, 0.0814680288146649, 0.09372564179024526, 0.13279530139906065, 0.07820833301437752, 0.060145744388656955, 0.1070500271660941, 0.06475429316716534, 0.07008418573864869, 0.07208686827548913, 0.1534190068819693, 0.17035271679716452, 0.09279794871274914, 0.2126456145197153, 0.07862054982355662, 0.16358190083077975, 0.23396997526288033, 0.0764048480029617, 0.09992456130151238, 0.1433817640479122, 0.1140899501208748, 0.16807836240955762, 0.10389004887214728, 0.22293185256421566, 0.08425106054970197, 0.0917803972427334, 0.27716440175260815, 0.1136797960581524, 0.11302937953067677, 0.1211469585874251, 0.18615216043378624, 0.1921297282512699, 0.18019447369234903, 0.06998984901500599, 0.18329232531998838, 0.06058215775660106, 0.14076492589499268, 0.06719135346689395, 0.23358627728053502, 0.12110270453350884, 0.08019665096487318, 0.15927172425602162, 0.14090326561459474, 0.12604083812662534, 0.14595824293792248, 0.11974507809749671, 0.16948112499501022, 0.13586309392537388, 0.05028257292828389, 0.07877596826957804, 0.07537440436759166, 0.16937193513980933, 0.1408506112971476, 0.09073717000761203, 0.12634159198829106, 0.10803658994180815, 0.13396087528339454, 0.09533742708819253, 0.2186448818870953, 0.22236110961862973, 0.1472665263073785, 0.12752866186201572, 0.14044659797634396, 0.12833982333540916, 0.09676521404513291, 0.14705254350389751, 0.2706281824835709, 0.12696342862078122, 0.14251777183796677, 0.08983138682586805, 0.0692339881456324, 0.1472926363348961, 0.1616214503135, 0.11042641741888863, 0.09179615282586642, 0.1281436045787164, 0.12763930378215654, 0.17457868717610836, 0.07280753353344542, 0.10979990568011999, 0.14448099077812263, 0.23362924211791583, 0.1235563550144434, 0.07074808475694486, 0.16687473628137792, 0.07914918288588524, 0.11659371719828673, 0.2768284183527742, 0.15270725078880787, 0.10146790277212858, 0.129423891593303, 0.09564559733761208, 0.15763950826866285, 0.16174345090985298, 0.09522831187184368, 0.15532137480165276, 0.18402977074895585, 0.09743886361164705, 0.12007468326815537, 0.14075230514364584, 0.16563887973981245, 0.24461100569793157]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.010565069287882319, 0.019956381559105854, 0.0739208534359932, 0.04741373026211347, 0.029289299954793284, 0.03653969429433346, 0.020591008576697538, 0.021545393525489738, 0.033780034698013744, 0.07558899106723921, 0.07137918339243957, 0.06559558838073697, 0.03051970786015902, 0.07169112629656281, 0.042141899932175875, 0.04199925490788051, 0.005285311548504978, 0.010187429775084769, 0.03274430866752352, 0.05467712872528604, 0.016462889732792974, 0.027263682934322526, 0.007369495046857212, 0.07088730657207114, 0.009111908513919582, 0.0675275404272335, 0.03307549821745072, 0.10598414364670004, 0.06250996395413365, 0.02161970328805702, 0.0365637212193438, 0.02098918310366571, 0.033303051721304655, 0.02996635915977614, 0.01398046936706773, 0.05502878289137568, 0.03546792109097753, 0.03805934810744865, 0.025447667077449814, 0.04394907956676824, 0.043046841730496714, 0.021574660437181592, 0.0358298516699246, 0.04271688711430345, 0.03608195117807814, 0.008177733730657824, 0.025612744469461695, 0.05397216137498617, 0.044345954699175696, 0.02791313933474677, 0.055149769077875783, 0.03457838203758001, 0.01999594354336815, 0.08526093100330659, 0.020843806975920285, 0.04612425249069929, 0.01817733229004911, 0.027263075645480837, 0.01780372073075601, 0.04062587967408555, 0.036645182741007636, 0.021967623815206543, 0.0265162732186062, 0.00894762500787952, 0.04226114567635315, 0.0476125681639782, 0.014567768567108681, 0.015343342575111558, 0.02942634027983461, 0.0645998857383217, 0.030792153240846734, 0.040728067047894, 0.04898937339229243, 0.036754057077424865, 0.04158715344965458, 0.051134565246424506, 0.03139992044972522, 0.037742770809148035, 0.01817494723945856, 0.026723382462348257, 0.02286454363326941, 0.02263849986983197, 0.06320977783096687, 0.015486766218340822, 0.027867446786590984, 0.0823530081127371, 0.043812802593622885, 0.08655949096594538, 0.047453543304332664, 0.06124310514756611, 0.017837057156222205, 0.03550879264782582, 0.05479930234806878, 0.018876258982345462, 0.03638391622475215, 0.02952206800026553, 0.02267973105024014, 0.018352940545550415, 0.019209638504045348, 0.05021769480247583, 0.035097576677799225, 0.03190525940486363, 0.04452081995883158, 0.016249995978016938, 0.04479178274050355, 0.014982139724971992, 0.024333404011226127, 0.0826845063960978, 0.018667874092768346, 0.023726992176047394, 0.06166809877114637, 0.02106106371086623, 0.039741772293512306, 0.024194770825228522, 0.027149130956136754, 0.0490032935382, 0.015845204038279395, 0.025320358640913452, 0.016861546019624387, 0.032919866032898426, 0.023847243848389814, 0.10642353578337602, 0.02032518569779183, 0.02960131749776857, 0.03183502424508333, 0.05909514826323305, 0.03337637082274471, 0.029585466919732944, 0.07391662616282701, 0.013226449023932219, 0.048277013402964385, 0.03138906728210194, 0.013551718355821711, 0.02822882096682276, 0.03099052973889879, 0.05012527494026082, 0.0507494593039155, 0.00574249996238255, 0.013717313130785311, 0.0346515348979405, 0.04703631551404085, 0.004353931905435664, 0.009877184056676924, 0.03267742547073534, 0.06199520693293639, 0.012242223801357406, 0.06028284238917487, 0.036634869008724175, 0.014949059446475335, 0.023940147166805606, 0.014472637957494174, 0.041538468562066555, 0.044283919635095766, 0.03729935835248657, 0.017751256403114115, 0.0020078088689063278, 0.023763622889029126, 0.017717419558071663, 0.04147585674322077, 0.02732335839287511, 0.07270604505070619, 0.015555739302986434, 0.02613654636245753, 0.033904613727437596, 0.040617018006742, 0.059563066012093, 0.07843945561242954, 0.018850277876481414, 0.006306170452652233, 0.051516163162887096, 0.031232227305216447, 0.015467382169195583, 0.023961144432957684, 0.0646157498870577, 0.08126041066965886, 0.02387893313009824, 0.03204417248655643, 0.04706358922911542, 0.05116035296980824, 0.013087045700688447, 0.015270486573821731, 0.09924873363758836, 0.012295912036539187, 0.02451824543199369, 0.010348076333424874, 0.016011492615299563, 0.0092674796303202, 0.030474544569317783, 0.06282544881105423, 0.03609856850068484, 0.023998066915997436, 0.08054089892123427, 0.04163345667932715, 0.03610751498490572, 0.04544089308806828, 0.02829834705750857, 0.017343891119318347, 0.04621388357398765, 0.03613805245341999, 0.0389883778989315, 0.04153913013370974, 0.09442694844411952, 0.03390534654525774, 0.09436313901096582, 0.03303688957488962, 0.035658575860517364, 0.012360446653994066, 0.039838918152132204, 0.030075308135045425, 0.010426123127607363, 0.01260764544297542, 0.09376976013715778, 0.04942028723391039, 0.02906652333747063, 0.02251031612312155, 0.03128442021885088, 0.0226360011646258, 0.02960808927725468, 0.10241203675312655, 0.10034162285072462, 0.02099600407694067, 0.0306155068267669, 0.015418522558840258, 0.05988154999379601, 0.042582130059599876, 0.013607597410944956, 0.047883819323033094, 0.013895390405585724, 0.027238305724625076, 0.05739967245608568, 0.05086555325293115, 0.031751815495746474, 0.02068283811344632, 0.007120527825983507, 0.04429591613422547, 0.022107118740677834, 0.054544149432331324, 0.0059994789854889465, 0.04211332682254059, 0.0229081768276436, 0.02540875139779278, 0.033436848648956845, 0.04495102133867996, 0.02812057936431042, 0.07533107990665094, 0.03735740023798176, 0.011134556943683751, 0.04322062472679785, 0.10369758241410766, 0.025879926114742244, 0.01620437128336302, 0.07273383784507002, 0.0279690760653466, 0.02425787627830037, 0.05670043872669339, 0.05347210142229285, 0.07119770241635186, 0.031131240938391005, 0.04179239332942026, 0.005274707318416664, 0.08631002756633929, 0.049514115056289096, 0.02860519416364176, 0.05722775203841073, 0.059340832222785266, 0.007013778576427805, 0.03516796450795872, 0.01726955421535032, 0.03547231460522328, 0.04450711015877979, 0.08675946202129126, 0.013443722722253628, 0.02366852111715291, 0.03553884157112666, 0.0667979863605329, 0.06960280585501875, 0.017047873432082788, 0.040567277997199974, 0.04731073882430792, 0.06217260312821184, 0.03743932655613337, 0.028150361962616444, 0.040623050183057785, 0.08706461278987782, 0.068817103015525, 0.011857323963860316, 0.07198014150240592, 0.031380097049155405, 0.04265132027545145, 0.07869388588837214, 0.05829076535467591, 0.02717188053897449, 0.02797328807147486, 0.038207954061882834, 0.02258480909014387, 0.020490361477381418, 0.04908790685502546, 0.08193629940173455, 0.054249675412263186, 0.03866174810432962, 0.025632242173222557, 0.02444860229401716, 0.04922289800431047, 0.011621388856188526, 0.08767500932195357, 0.046744324932140965, 0.012217305450966316, 0.029946271130549054, 0.06334648228117398, 0.03290242089756897, 0.047717154159077575, 0.07184074326817479, 0.10024902317672968, 0.012563934217074087, 0.03592246152194483, 0.0550237515542124, 0.03681806328573397, 0.057179324994129796, 0.007933054002933204, 0.08639286312141589, 0.04892657158364143, 0.05533785559237003, 0.010209326100136553, 0.04210158816671797, 0.021785452429737364, 0.02643627902892019, 0.10526098137987511, 0.009115698980167508, 0.010784235250736986, 0.040910508151033094, 0.042016883247665, 0.024710515114877905, 0.01712135368558977, 0.04108166860948716, 0.005134043616375753, 0.0058663805248215795, 0.030727882403880358, 0.06204393931797572, 0.019210288201325705, 0.012856828946886318, 0.026942684980375425, 0.029297405055591037, 0.07255471138549702, 0.03545858444912093, 0.04364839016592928, 0.09083354912166085, 0.029553433281502554, 0.0056523625223365214, 0.03477356263569423, 0.018990514101460576, 0.04281736118718982, 0.03645470439057265, 0.09851079287805728, 0.0900988517595189, 0.14120742572205408, 0.09757111687213182, 0.19819105443145546, 0.15868723419095787, 0.0865777028458459, 0.0792675329638379, 0.11736739639725004, 0.16990147743906292, 0.15034514825258935, 0.13220296746918134, 0.1350838914513588, 0.09290273487567902, 0.13711283329342092, 0.23798424271600588, 0.06272467279008456, 0.10930572862603835, 0.11728804851216929, 0.11132976465991565, 0.12051243335008621, 0.1950118871671813, 0.08539201718355928, 0.18820692731865815, 0.1053195253812841, 0.18942240066826344, 0.12286016451460974, 0.2570880704692432, 0.13821626694074698, 0.08134559395589999, 0.12560300662049226, 0.16294970975390502, 0.11048518533685378, 0.09241900047553436, 0.19281973051173346, 0.2286529205739498, 0.10604126950992004, 0.1095915072198425, 0.12141491206628935, 0.16399151885083743, 0.08962122417454209, 0.21472685784101486, 0.17242584483964102, 0.1551041214593819, 0.10471836371081215, 0.11099931810583387, 0.06497172971389123, 0.17351369932293892, 0.11104735838515417, 0.1344002809907709, 0.14323874243668147, 0.05840460317475455, 0.14826513986502374, 0.1407332383096218, 0.20423002966812678, 0.061865532105522494, 0.10172286230538573, 0.07973001564719848, 0.11034308653324842, 0.09724269235240561, 0.1354241089097091, 0.1700310776276248, 0.1596070019794362, 0.13161246558385237, 0.16362797335854598, 0.19173807783850602, 0.08435639632599694, 0.10189580731093884, 0.1448816792773349, 0.09846081877393381, 0.12940623611211777, 0.1243949428732906, 0.15687608851918153, 0.10852857532777957, 0.11140016266810042, 0.15070241051060812, 0.17673713421182974, 0.21962396720690386, 0.1141656067754541, 0.12469129982803549, 0.10790110006928444, 0.16957887474979672, 0.1402378806046077, 0.055842085142752955, 0.1627363512026412, 0.14159604986863478, 0.1692968484546457, 0.17093907961887972, 0.1963760003979717, 0.1680544236940997, 0.1610800065100193, 0.11284086214644568, 0.14895713701844215, 0.0831396948280079, 0.17327758270714963, 0.07046177690582615, 0.07076677839670863, 0.1344414816371032, 0.1280499260340418, 0.13915451802313328, 0.1438858477132661, 0.15383251969303402, 0.1606785309101854, 0.1111890704237989, 0.14743458586079733, 0.17184060838605675, 0.14092368951865605, 0.15451266962502683, 0.12897368360842976, 0.1853895413556269, 0.19424597040883132, 0.11300470799739872, 0.07952037546783686, 0.1586934902838298, 0.21561401523649693, 0.18892291747033596, 0.13511783177299158, 0.1654577651726348, 0.13410798167543753, 0.1574886699340173, 0.12063439323433808, 0.23522151953407697, 0.15887976171714918, 0.12309530403997217, 0.11684922634490899, 0.17416422441601753, 0.17263465720627988, 0.12728404998779297, 0.2458652098264013, 0.08425119625670568, 0.08927649445831776, 0.14028579874762467, 0.11886666023305484, 0.13282587618700095, 0.12937682840440953, 0.15196539488221916, 0.25502868954624447, 0.17817026802471705, 0.13232476450502872, 0.0715064290644867, 0.12780063226819038, 0.1325715341206108, 0.08345503040722438, 0.17074602283537388, 0.17120431895766938, 0.12701180816761085, 0.11532096192240715, 0.18874269856938294, 0.14745315057890757, 0.09592634798692805, 0.10359180559005056, 0.16046157612332276, 0.13212013191410474, 0.16057039956961358, 0.11630555694656712, 0.09910786976771695, 0.07936792221984693, 0.07884490064212255, 0.10314898006618023, 0.14730109088122845, 0.14808725512453488, 0.19183837888496263, 0.09748816596610205, 0.2399152990962778, 0.10351246449032, 0.13122339360415936, 0.14542533510497638, 0.13598219039184706, 0.17092616031212465, 0.17878929552223, 0.11607424435870987, 0.07382714096456766, 0.10684195440262556, 0.14924790284463338, 0.14606480007725103, 0.08727339801511594], [0.04635052356336798, 0.056123968945550065, 0.057386692081178935, 0.015700794822935547, 0.027007612299972346, 0.03046510275453329, 0.03842485456594399, 0.004102375225297042, 0.01782540331727692, 0.02450058316545827, 0.01676985388621688, 0.048446148434387784, 0.0771091944937195, 0.032348142604210546, 0.027525848509477716, 0.05817538047475474, 0.07753669191151857, 0.03905938998130815, 0.023072573988299285, 0.03733027580061129, 0.08061423498604979, 0.03910607658326626, 0.008763781881758144, 0.03256072084020291, 0.016177138280389563, 0.027319433067792227, 0.01776896955977593, 0.016558162834761397, 0.02958924975246191, 0.06527290426726852, 0.02135021971272571, 0.04754443646275571, 0.021445842260228734, 0.061364807188510895, 0.06302656659058162, 0.039125862664410045, 0.0654722171436463, 0.028292603258575712, 0.04598519013130239, 0.001118781155258018, 0.03893755562603474, 0.01927017909474671, 0.05155491429780211, 0.0509975622408092, 0.019302772524367486, 0.0551117066560047, 0.056492223470870934, 0.015110396414196916, 0.05042345036885568, 0.008177079792533602, 0.02582614542916417, 0.04828480977032866, 0.05223817531285541, 0.019874278821849396, 0.04166879139042326, 0.06555226391979627, 0.02628662304154464, 0.04416871117427945, 0.021017479710280895, 0.05632878474092909, 0.0017936089342193945, 0.007433900742658547, 0.015088513659845506, 0.04271134687587619, 0.12000712832169873, 0.012709332397207618, 0.05454967270738312, 0.01956146739290229, 0.02284627577422985, 0.059873570421976705, 0.04858558398804494, 0.039373382061187706, 0.021173496963456273, 0.04294075617300613, 0.007515895762480795, 0.05057699266555054, 0.021327741543895433, 0.03970114840194583, 0.027532681357115507, 0.032438815238752534, 0.06417629668223006, 0.057827074878982136, 0.008908568532206118, 0.012014797522819467, 0.05771496732320104, 0.050946848533515415, 0.009183153842708893, 0.03453102707862854, 0.04557359078899026, 0.08378895106060164, 0.01573684878115143, 0.058059303489114554, 0.021489736690585102, 0.09012337401509285, 0.02149984855870051, 0.058653421966092925, 0.03045178989746741, 0.06870437799287693, 0.025030490177284394, 0.03260360425338149, 0.04177933153031128, 0.05936612800828048, 0.013424483709968626, 0.0700927624212844, 0.0898185692993658, 0.019936858410281793, 0.05132139986380935, 0.04421347412945969, 0.03419174939127905, 0.01845347059757582, 0.02972593384661845, 0.0592386041368757, 0.13832430328641618, 0.030380350338029008, 0.016791305770831447, 0.06081401317247322, 0.029625514056533575, 0.023473893525078893, 0.015529429107638342, 0.04653564148715564, 0.012762601637015385, 0.052510579981442006, 0.043401461094617844, 0.034260542664144716, 0.047515449446759055, 0.043317170081926246, 0.022697545987154757, 0.037078987141805034, 0.03568918796788369, 0.03131182624825409, 0.04058804116877062, 0.015981326644708003, 0.04302704207865255, 0.021563237300142646, 0.03783298882522753, 0.015130489532436644, 0.04796606794531856, 0.021832010110041926, 0.06433827656188182, 0.02829197731002101, 0.025011708327968205, 0.08699457440525293, 0.005618588865867683, 0.00656250147481582, 0.012168973401587988, 0.016240143649546162, 0.04753684704857213, 0.01481789693103305, 0.049688854786966524, 0.02388439024798572, 0.027010916765513163, 0.0337932593455272, 0.013268663231948656, 0.06467554917825119, 0.05408449623999851, 0.013135587247753782, 0.031217492917286496, 0.04399959310623152, 0.01040070690214634, 0.04401530458458832, 0.025635675560416918, 0.037079197487660816, 0.01072681083210877, 0.020351165107318332, 0.028897680076105253, 0.024688350768493753, 0.12698529101908207, 0.02100673001924796, 0.03874921466090849, 0.043937150921140394, 0.07204367273620196, 0.010821111932662981, 0.039477303091968806, 0.047130950793091736, 0.04817004914262465, 0.059910869491951804, 0.0068220542660648266, 0.1270420436880418, 0.031742373680961986, 0.11762572824954987, 0.02547332418284246, 0.01658035601888384, 0.02027254325470754, 0.01747611554206482, 0.023515614947038035, 0.01589855894313327, 0.06499415529625756, 0.0442775278352201, 0.03517318922760231, 0.052609710554991446, 0.01329595475856747, 0.04818671057000756, 0.03670722798311284, 0.02090666476371033, 0.051775054806577306, 0.024705281913546578, 0.011135248201234, 0.022964066060792123, 0.06212490211640086, 0.060137791958238394, 0.008804502464564783, 0.018659160006791353, 0.057569672619657855, 0.03470368370679872, 0.03796824460316982, 0.003379188573619883, 0.03216761496982404, 0.03205696965700813, 0.029754350893199444, 0.03273396100848913, 0.025045053235122135, 0.02162721467071346, 0.014911365129851868, 0.011178576903018569, 0.02238464295598013, 0.02868522736909134, 0.030831192753144672, 0.03291916374915412, 0.062245504930615425, 0.047424325586429665, 0.08078515117189713, 0.06760434380599431, 0.08167753328702279, 0.016023953910917044, 0.0216762422184859, 0.0549639590483691, 0.038152168305324655, 0.03593035288421171, 0.07921983873737709, 0.03933707704501493, 0.010753211781515606, 0.008882481405245406, 0.06207488730017628, 0.061991115366773944, 0.04624771872269256, 0.054885544148938994, 0.12318704197449343, 0.025018958474642465, 0.03768518014944025, 0.021419381090838994, 0.06364712079188653, 0.01715495134703815, 0.03931732149794698, 0.044327135530433485, 0.008238274321359183, 0.04340402256431324, 0.007193736665483032, 0.045142263041010926, 0.0332326435350946, 0.06261907238513231, 0.04232455138117075, 0.07291446386703423, 0.12043598959488527, 0.03538865123742393, 0.01568645398531641, 0.030877804716250727, 0.02220184901463134, 0.086712697387806, 0.06176439646099295, 0.01208326340253864, 0.010969979971248125, 0.013493231181720538, 0.024430410770167197, 0.021342182465429817, 0.03770720539614558, 0.03686662942969373, 0.01438868451597435, 0.023659713732610856, 0.04781620670109987, 0.06853973825595208, 0.11578734618212495, 0.020247018463643532, 0.02638950421740966, 0.024005162695954953, 0.03254077869600483, 0.010048318221899015, 0.009828768886758812, 0.04626611041437302, 0.014699928529028381, 0.0408535213874919, 0.02745827490330807, 0.044584154417472224, 0.012671003650341715, 0.026842268582965647, 0.0037067078852227753, 0.04578195192984172, 0.02397667270685945, 0.022249935095065405, 0.06594280832047973, 0.07742829594228949, 0.01906926487572491, 0.025803434862090007, 0.0522888856274741, 0.03413822654900806, 0.02658415216553424, 0.04362395272723266, 0.02882919553667307, 0.01338818802365235, 0.05586907387311969, 0.013602350638913257, 0.017741722986102104, 0.04546631779521704, 0.04164662704403911, 0.0493520571451102, 0.02502687867464764, 0.006441489419168127, 0.029613877180963755, 0.010879396394427334, 0.06884882452764682, 0.06406118321631636, 0.023702836329383508, 0.0520615153280752, 0.0661423315427133, 0.02662451991013118, 0.05625750802989517, 0.005676815228071064, 0.05580727968897138, 0.049050146381237676, 0.044535442388483455, 0.03111839627048799, 0.043394034528838735, 0.009493855027748006, 0.008360898321760553, 0.022799594261284386, 0.005472455323407692, 0.013343148565452014, 0.016720610903576016, 0.0924609067982861, 0.023483004554041793, 0.029308892653456757, 0.0377376207283565, 0.011719057186772781, 0.04089482720675213, 0.035447330945836644, 0.042004774790257215, 0.06459006055125169, 0.05204100660713656, 0.040905928039657216, 0.05262695891516549, 0.030009079724550247, 0.022260426942791258, 0.009398320689797401, 0.04222606202321393, 0.048550686932035854, 0.0018285668463379676, 0.015739009915185825, 0.02010581362992525, 0.016282445218946253, 0.026127752548615848, 0.039068692696413825, 0.05413799533354385, 0.11641053988465241, 0.1047712080180645, 0.2009365428239107, 0.09063821246049233, 0.13929912740630762, 0.16216577110545977, 0.11255768234176294, 0.19941088397588047, 0.07187635278595345, 0.049822468510163684, 0.09160357780222382, 0.09851938313139336, 0.22616417626185076, 0.11941345089248248, 0.11976991247917924, 0.11311322610293116, 0.1589618373130049, 0.15494134090840816, 0.1145847107150725, 0.08947469453726496, 0.1210831491542714, 0.16396977858883993, 0.09407052078417369, 0.17260309175721236, 0.1894738200519766, 0.09703386641506638, 0.11894360610416957, 0.12132322841456958, 0.0785635325259396, 0.14210994515035832, 0.1837784820901496, 0.11926877365580626, 0.10387284122407436, 0.11081346736422606, 0.10769064564790044, 0.16216541826725006, 0.08644351576055799, 0.19492867163249425, 0.14561114513448306, 0.081373902436878, 0.04427807405591011, 0.14752469531127385, 0.09058462855006967, 0.12609546019562654, 0.059962974196033816, 0.16498863963144167, 0.1921142033700432, 0.154623433681471, 0.12741096317768097, 0.13842716919524328, 0.13348967342504434, 0.12258609064987727, 0.17547496408224106, 0.2477170947406973, 0.12432266532310418, 0.1455709622906787, 0.10163374351603643, 0.141270624473691, 0.13985891879669257, 0.09267609060875007, 0.13191838988236018, 0.23865506957684243, 0.07094219326972961, 0.110052022151649, 0.11260916957897799, 0.2456799154835088, 0.08528387227228709, 0.17902930692902633, 0.16662430257669517, 0.0633146929155503, 0.18790406999843462, 0.09570194967091084, 0.1489199532994202, 0.08156440792871372, 0.1395004487463406, 0.10583796006228242, 0.16172373268221105, 0.20331201249999659, 0.17667086848190852, 0.09926919146840062, 0.12760819973690168, 0.12200381260897432, 0.1754924160029207, 0.10981488094798156, 0.11297874046223504, 0.16099045345825808, 0.1294952327651637, 0.062405998818576336, 0.11943163563098226, 0.10974932089447975, 0.14722848763423307, 0.15545100213161536, 0.16867772596223013, 0.16605531025145734, 0.13812342977949552, 0.13699037129325525, 0.14258622245064803, 0.08315638678946666, 0.13547239346163614, 0.13139452013586247, 0.16096000080662115, 0.10056738502212934, 0.09771341245089259, 0.11913192671324525, 0.1477545965462923, 0.137397736577051, 0.08223058682467256, 0.17366307202194417, 0.09188794504318919, 0.1480459323418992, 0.161295834928751, 0.11885433803711619, 0.08464700608913388, 0.17232356247092995, 0.11054003810776131, 0.05006661219522357, 0.14261071756482124, 0.09697726302381073, 0.12832310423254967, 0.10762376245111227, 0.1827668406601463, 0.13610880502632686, 0.1265477037855557, 0.16058705081897123, 0.11581621106181826, 0.13421751079814775, 0.11436338616268975, 0.18021188490092754, 0.09489994842026915, 0.1363468486815691, 0.14730415785951273, 0.10692656093410083, 0.1195183659770659, 0.19338070255305084, 0.14620700744645937, 0.10532656178942748, 0.11759686336985656, 0.12288877155099596, 0.11186278105846473, 0.16727736539074353, 0.08505365891116005, 0.1459914640124355, 0.24502393496888025, 0.1642978774117572, 0.18238962947257928, 0.10237789965633835, 0.10873806622943707, 0.1368878853640386, 0.13461176678538322, 0.1522603269134249, 0.11165879307580845, 0.14171331429055758, 0.13160006196371146, 0.08880794567189046, 0.1539656346929925, 0.1420610092048134, 0.05811045824417046, 0.11609580820160252, 0.09794728990112032, 0.10039180051535368, 0.09870714734175376, 0.16727661900222301, 0.13595236199242727, 0.09679982611643416, 0.15414817418370927, 0.08494544614638601, 0.13516965827771596, 0.24200980099184172, 0.09332687354513577, 0.13651846375848564, 0.10342613447989736, 0.1056381179285901, 0.0837216539574521, 0.14590041818363325, 0.1611118840851954, 0.13127691644643033, 0.18979896046221256], [0.015876196125256162, 0.029030286174799715, 0.03507917480809348, 0.04304508771747351, 0.023953604212562953, 0.06345710384526423, 0.02494550196986113, 0.0405363435856998, 0.03725967762459602, 0.04487878789326974, 0.04922356636130384, 0.060350851954094, 0.04059505382818835, 0.02683499299122819, 0.028574938287160227, 0.07845001361731972, 0.02542033399056111, 0.08583567052015237, 0.03238336874970368, 0.02475521869824401, 0.017022591217287948, 0.014561989145087344, 0.07479122387511389, 0.0466421443436827, 0.044679190032184124, 0.07554857073617832, 0.04572351649403572, 0.0251391270264451, 0.08047124730157, 0.012406399589963257, 0.04446206221889172, 0.03265723905393055, 0.02692780640375401, 0.01838771716159369, 0.07240010718149797, 0.009914667179275836, 0.005837487655558756, 0.027858435841543332, 0.06322233751416206, 0.0203063003718853, 0.049711829982697964, 0.022694911574944854, 0.012477688175360007, 0.04845046391710639, 0.00992983837412404, 0.0009635458076705358, 0.04921947479514139, 0.0248669004733009, 0.010783147050200828, 0.04444341268390417, 0.03632162671004023, 0.06534373653786522, 0.003870192840362766, 0.019650961072849374, 0.02089339431508311, 0.02622366008082671, 0.009678854207907404, 0.016257946712097952, 0.01401982524631811, 0.016911954386159778, 0.016727823730824248, 0.021846595220267773, 0.024822439466203963, 0.031468435523233244, 0.06537097971886396, 0.04447261004575661, 0.027446537943822995, 0.026433198479935527, 0.05798102090401309, 0.09972841039832149, 0.06051044339048011, 0.033032350175614865, 0.014019031360346292, 0.08180251943745784, 0.061974708390023024, 0.040984234373484335, 0.012791863459694599, 0.024280228918152194, 0.014868040668911167, 0.0341078349655228, 0.025571121435080255, 0.061221710938428126, 0.014436790952458978, 0.0529761160723865, 0.036294336031590185, 0.01213556742628238, 0.03265869790422065, 0.029544459655880928, 0.06562750666801419, 0.046773803886026144, 0.016529879798846583, 0.030955714107091938, 0.008071068025726293, 0.039204854318606, 0.04011892241292766, 0.004151283605356834, 0.010836852248758078, 0.02630209194363228, 0.03115990225757871, 0.03780604080696191, 0.011805143772757478, 0.052076019014098814, 0.018313404006351317, 0.042575263285211155, 0.019421868990840654, 0.09709022553371531, 0.029624801594763994, 0.013120049643995506, 0.0074307777852352175, 0.025349057279527187, 0.07224094322217361, 0.07141465720321451, 0.013730921998753079, 0.03655683408890452, 0.03742707560637167, 0.012720012538401144, 0.017262120864221027, 0.021722798202452914, 0.029118393946971213, 0.03305133558543665, 0.02776524584208216, 0.022442756087652276, 0.02765361326081412, 0.08753244911453553, 0.029093437428985323, 0.05289609983031239, 0.0632629274789776, 0.038776535873434374, 0.02032405254431069, 0.043076419071959596, 0.07481011429003306, 0.033149553529386006, 0.04432242989007916, 0.03126489876636437, 0.01769053260795772, 0.04601941543764301, 0.014641681386690055, 0.03081614284643105, 0.010355325631930359, 0.05019414285197854, 0.09484220509018217, 0.026565865646781664, 0.019373620062002113, 0.05269442565206971, 0.013784178516029246, 0.03300304764083453, 0.03172626525961927, 0.02147078181483916, 0.01108600097774927, 0.013852540919158076, 0.04498219663011176, 0.00742868026385882, 0.02604047428550465, 0.025715866525258337, 0.054128000512719154, 0.059615984958197386, 0.047544575562434535, 0.03674563306516834, 0.06701607430087668, 0.062097360379993916, 0.009484503967022257, 0.004225668430860553, 0.030480135697871447, 0.03840089888711061, 0.062131314272327084, 0.03602489656103509, 0.016654889698007276, 0.006788538028818688, 0.08349751348474196, 0.015020811132022312, 0.012011278470579003, 0.025741968071088195, 0.0183495342997568, 0.05807244671242578, 0.04877243556880525, 0.02889976996396269, 0.03897230001166463, 0.030597009962158542, 0.020812558741973977, 0.02857275340440018, 0.014906094609094518, 0.0961940096957343, 0.047108742341931374, 0.022046408516221812, 0.057806983457079957, 0.031171929290784255, 0.033464926428028514, 0.04209136603666203, 0.010934937878378799, 0.026216511714405248, 0.02150303597695061, 0.04401126051587718, 0.06670759871069874, 0.019513422024569342, 0.02643855381757021, 0.03862537523465497, 0.02055431849190167, 0.020486185094341636, 0.048122775607875416, 0.01984561580632414, 0.04119237159777965, 0.04640028392896056, 0.046132751141807864, 0.040337027316646915, 0.036224911721157174, 0.012540746979149324, 0.01941767055541277, 0.03820305843172329, 0.02439227031676897, 0.0034458580318771836, 0.06799996364861727, 0.024560767525274838, 0.03053897146933845, 0.02074132952839136, 0.019592032002817308, 0.01745821748461042, 0.05316051814172949, 0.023476064837138568, 0.039279503348682604, 0.01690325726355825, 0.05413850423480783, 0.003761840551825506, 0.004535214410030416, 0.034211189419563325, 0.07412007131746837, 0.0648245961804475, 0.04175780500684466, 0.034898525037403615, 0.044057014132184644, 0.026420090879712785, 0.027620902783902626, 0.0310470008158258, 0.031780476814934185, 0.04039650769638164, 0.011872675818657237, 0.02777282677457801, 0.0801179680441107, 0.026232988240995576, 0.01669065697517778, 0.010103179474494286, 0.054687296572540484, 0.04811138300491231, 0.01335851992813072, 0.01271035019973559, 0.06476021677787815, 0.06510630356413977, 0.02047317418535905, 0.022276964537533264, 0.038157871392156394, 0.09031982347369194, 0.04864608556298273, 0.018328450520389845, 0.04686945018225482, 0.03140478215313383, 0.07451250883085386, 0.03488757687487772, 0.06222875868635518, 0.0392116328834423, 0.06258880293795041, 0.043469389235334735, 0.06067417389047997, 0.017772859261770333, 0.0199698640499264, 0.0400547431781888, 0.057653953454324176, 0.024605510124404515, 0.028692036468003477, 0.006160319774478141, 0.021512352262756655, 0.014651163913575667, 0.009542324480467608, 0.05651910363563469, 0.02634280574108873, 0.04099376779049635, 0.06648860831878015, 0.062224287140582285, 0.024599937655563866, 0.011571388458833098, 0.05298334247033511, 0.06881679088941642, 0.002263048297858664, 0.05118540109002164, 0.009717051488613444, 0.005721944168076983, 0.01634844292753509, 0.026013244675206285, 0.044216235766985586, 0.027574280642771294, 0.016626584609704356, 0.03367602885035532, 0.07628604330654655, 0.03910119452380708, 0.027567875272195255, 0.028040848106944134, 0.04350698007536786, 0.017566745768168142, 0.027796636568382382, 0.048270618210413625, 0.03485182486474514, 0.05440486315637827, 0.06175491732678243, 0.045993434331778965, 0.06727266231817858, 0.10465680022857018, 0.054715625409569056, 0.024153763561376503, 0.03868398369689073, 0.025800213517088975, 0.011573588608631065, 0.024425189443198696, 0.03944003455606954, 0.023865912043090378, 0.025508321322766796, 0.06275159705962453, 0.025172127577077066, 0.07504037514861141, 0.06553293924246516, 0.018407728855631182, 0.07737844397446939, 0.05180783483332821, 0.04810114051880581, 0.01603160608958985, 0.013775761289122914, 0.011816138584565903, 0.044125318859836886, 0.013425700832158327, 0.04067813365587166, 0.044663105359567065, 0.06634642130562238, 0.04337602620944381, 0.029011758776115518, 0.048190720711967776, 0.04060098422425134, 0.045312008753951104, 0.0639735097065568, 0.02353159953573985, 0.00525250904528158, 0.01799212785304657, 0.028950436173805168, 0.03979993970798595, 0.06829123837607247, 0.02990308916196227, 0.017895568927217807, 0.036917916499078274, 0.02739139849187008, 0.041342673889760456, 0.07343460845627955, 0.014917292133239763, 0.01750390324741602, 0.04401105695537158, 0.016952895492847477, 0.023648051411977837, 0.1113896860874125, 0.17770606864775929, 0.08307253343186208, 0.10636216229093926, 0.06883642769285611, 0.1473591870495251, 0.1448542528918811, 0.11899195850959846, 0.12035153912646429, 0.110132543902312, 0.11355780903249979, 0.12093506567180157, 0.09639139553265912, 0.10141160472163133, 0.10374531735266958, 0.1467175914772919, 0.1585388792944806, 0.16849781918738568, 0.12459291225033146, 0.18622831920427935, 0.21790702933711664, 0.11245867051184177, 0.13224377456520284, 0.09518340642430953, 0.17332471374954495, 0.1504671217075416, 0.1462647236351456, 0.17748667113482952, 0.16410074941813946, 0.10827431468559162, 0.1919430089848382, 0.0890204356983304, 0.11229144555649587, 0.12418215429144246, 0.13086448929139546, 0.07438263044293437, 0.11503620791648116, 0.1666277495345899, 0.16072555338697775, 0.07048071481819664, 0.12006738223135471, 0.07993667027247803, 0.10536356230399438, 0.15023329854011536, 0.13747905221368584, 0.16122099251619407, 0.0793654794937798, 0.1464768743940762, 0.10228914727589913, 0.24612997419067792, 0.11361691621797425, 0.13548532633909158, 0.15950007843119757, 0.09760462293135268, 0.060096822013812404, 0.15085958636232785, 0.1528844027114766, 0.09812448253589016, 0.1407810343163354, 0.15770881383546762, 0.13974998678479875, 0.13627993155802998, 0.15738341558192456, 0.0792784234508872, 0.10231335740536451, 0.14396442206842558, 0.11093246883579663, 0.10119729622134141, 0.1797772560800825, 0.18796861224940845, 0.13417734152504376, 0.08616710095001118, 0.0801128993875214, 0.11328830170844283, 0.11551144027284213, 0.0971175976363676, 0.1346585721309696, 0.1011527164706162, 0.224418292088168, 0.1311479676514864, 0.08461806657058851, 0.12100129068962165, 0.12226112665874617, 0.1327369473874569, 0.1372747996023723, 0.0816176390009267, 0.22078608056264265, 0.13953954593411513, 0.16790007054805756, 0.11406265944242477, 0.09631445644689457, 0.15661449969879218, 0.05223635683900543, 0.13604966391410145, 0.1103444571739861, 0.12475683274013655, 0.08691692964306899, 0.1151806680219514, 0.17091264389455318, 0.1316567196377686, 0.13536365143954754, 0.17431393638253212, 0.11133776458778552, 0.1354721627597298, 0.06379738915711641, 0.2034739652382476, 0.05751192928957088, 0.11226443986275367, 0.11315195009644542, 0.11773808007793767, 0.08722172757344586, 0.1861378297741924, 0.13147762710494654, 0.1375894227198192, 0.194607086745756, 0.1006798589868205, 0.1113869719473379, 0.10344542523047753, 0.16774260971163, 0.1830131895840168, 0.09950339461543731, 0.1638428382575512, 0.15141276882163116, 0.19845628019954475, 0.1824913825839758, 0.09653369111141988, 0.17177526546376093, 0.20749319956770965, 0.11537353481565203, 0.12089675558464867, 0.1699187529406377, 0.09141833095678262, 0.09472908651722328, 0.07142532377370767, 0.15076034383050033, 0.1343438404479197, 0.17372916133276053, 0.14987796332154954, 0.10164831166288682, 0.16733193317694323, 0.1854341346770525, 0.05384735164365598, 0.12258535783205714, 0.1747435847563403, 0.1998441285852875, 0.0931179119007928, 0.13301741305206502, 0.11283198012305157, 0.1313200712736164, 0.10941575986466237, 0.13186353711145266, 0.08136507469628539, 0.1018847811168858, 0.09635970794728824, 0.13145413622260094, 0.19165089965931006, 0.13216760222400936, 0.1636151219052928, 0.20760601279991014, 0.1653897895344666, 0.09134306106716394, 0.10563467097069536, 0.08342818077653646, 0.23134678602218628, 0.10520407264786107, 0.08720173793179647, 0.11357388352709157, 0.08175260640148606, 0.2164334819785186, 0.12310958041676454, 0.17283623638961995, 0.1385716021593128, 0.11192261427640915, 0.19170632239963326, 0.16157117086861814, 0.06900597323796578], [0.07582524339003222, 0.08307323910828147, 0.0850166380405426, 0.04032364660607917, 0.030853821896016598, 0.061810591125062535, 0.044606284837105444, 0.032472636816757064, 0.0206617882608303, 0.014256049579541599, 0.06135716688420091, 0.03698839932414038, 0.06838554117296423, 0.05167917441576719, 0.04603967310062476, 0.06001851228731019, 0.03943527463291373, 0.03234230720305017, 0.060636650903948715, 0.043475584260054996, 0.01627707461427365, 0.020882554718160203, 0.012598561555413263, 0.018086361100098917, 0.037132533732801676, 0.010356122062408497, 0.014432331281048911, 0.045594998568828614, 0.01719573639067156, 0.032685286298926385, 0.06451688733484064, 0.009671001861404096, 0.07993700953998736, 0.014773027106587375, 0.020640748586239557, 0.02706628861570997, 0.07465789174394948, 0.03181090571784547, 0.03552955581939646, 0.00549360059501071, 0.04044410353526473, 0.0413268911652267, 0.049372121425611634, 0.021428113836528997, 0.03743970314306872, 0.031809412940804443, 0.020351595977055173, 0.02985566634950893, 0.025525893683412244, 0.019307296656604325, 0.03539755700954369, 0.02355347041572843, 0.013920639541798403, 0.024398692650720477, 0.05532680225691625, 0.095842331780919, 0.028339530740465437, 0.02614970994181931, 0.08019976544060878, 0.02714367044557418, 0.03730824037588068, 0.015768935005845766, 0.013032256542438907, 0.0326868876415704, 0.029365808170820986, 0.023803995722638707, 0.04768611118197441, 0.02699164637098355, 0.04907147952222398, 0.022522297355213335, 0.10568373583789382, 0.040521110474531136, 0.03326805967039295, 0.04363479571683066, 0.09179930801370315, 0.07378562140677657, 0.012954764450634164, 0.0647642065637878, 0.0687388882839254, 0.06562951513166938, 0.05593140749260783, 0.03655588413987841, 0.013718042555930359, 0.08990904515875237, 0.026816329885540263, 0.03184652202097433, 0.06395053451082536, 0.014141305067044283, 0.0219593372062913, 0.09617553997252669, 0.032913355489394495, 0.04194788980696883, 0.04112992262733834, 0.03362775108377848, 0.03285560876663242, 0.03852905718875783, 0.06273147171097142, 0.03848631626793316, 0.009341588376888206, 0.009338498498047037, 0.0358863770296531, 0.06720304462526526, 0.008836123892771346, 0.017184800102508495, 0.01904925996703761, 0.02553195639380387, 0.06309847094650779, 0.013241972208821347, 0.031874335171388726, 0.019687274570709894, 0.0170529132509338, 0.010980412447159844, 0.01115520646063877, 0.03950291778892279, 0.06612662345703159, 0.03606967308691569, 0.02547543103407536, 0.01863846299238503, 0.0810476288731609, 0.027847326526950513, 0.0262713831450258, 0.027488639345392585, 0.015226571787414806, 0.0268831316581262, 0.002660750182777909, 0.04357515588136656, 0.04941860446706414, 0.058511112816631794, 0.035973911439733844, 0.0645267464486616, 0.01823053282818624, 0.04761173356590526, 0.08805408648082189, 0.0460861934615033, 0.025411326438188553, 0.01403890480287373, 0.04731009082336511, 0.04423409480867641, 0.061012125041868, 0.03763302455523184, 0.011753741352419769, 0.03342484197180186, 0.03693939552509359, 0.04305191377976111, 0.054309841112366745, 0.011825923907703586, 0.026459571439772844, 0.04589982024793114, 0.025086579578263418, 0.023593171499669552, 0.03700198020253863, 0.005981950305535325, 0.042944681498089006, 0.04874793366928186, 0.03129857785201498, 0.04000552903328623, 0.019650202809966037, 0.028059177034135376, 0.0959296320964183, 0.02973909064063004, 0.06186817839209523, 0.038614654381360324, 0.018832215274284993, 0.0408700912126473, 0.0160520893654653, 0.019634089299610684, 0.06271701212972403, 0.03694160415657929, 0.02767479882043387, 0.029482068360916207, 0.010214728935222541, 0.04758362186008266, 0.03723714008395161, 0.03124197106808424, 0.028736636574779238, 0.03041784279048443, 0.028399216377043297, 0.034448720780866485, 0.029965890970613276, 0.042398470986102305, 0.025107464886137416, 0.04243836884519883, 0.04258546505921653, 0.02207268139214388, 0.014716583171061106, 0.02168263741103666, 0.0789464298369629, 0.06678123333092247, 0.003189781248303396, 0.009876374903667186, 0.10158204593296562, 0.008187406247348657, 0.025835712772927115, 0.05910394207707473, 0.04302891483530402, 0.047675641386636665, 0.05315368190141661, 0.03279711565534983, 0.008185882088063019, 0.030421418670032705, 0.04964593405436192, 0.030739600703652416, 0.061024474379207404, 0.008729403905038322, 0.026877240277826786, 0.05073415155389479, 0.03358926797019584, 0.014801681640424898, 0.0257234915625304, 0.0540071398551975, 0.023481393033372502, 0.028054137215284363, 0.0783910828509501, 0.01606119191274047, 0.04058770868661148, 0.03180940276277917, 0.016290244978985617, 0.026754812204412053, 0.060526897864682336, 0.039078025945595334, 0.014620107365772128, 0.03177505192746009, 0.039568464271724224, 0.00992999698168465, 0.018595627076657753, 0.023155947282378162, 0.011091697279230824, 0.021722701511212757, 0.023320410600198165, 0.027642315652753626, 0.026690029073506594, 0.016152634684528624, 0.06268256969217743, 0.0662112096324563, 0.06401281724018709, 0.03896978264674544, 0.016708405754928077, 0.015889573443148817, 0.02310976618900895, 0.03430366017190473, 0.05223944417334028, 0.020297703333199024, 0.03813132370955177, 0.0182166211639664, 0.007484281967793192, 0.05722233732896192, 0.021455762442201376, 0.03932149448831167, 0.026521781226620078, 0.013799983292951115, 0.03065174398943782, 0.0458157463664455, 0.10235299063580376, 0.05569099235747542, 0.06245171172278268, 0.027401230464290296, 0.03473958499463541, 0.050774310648973496, 0.025232995560924922, 0.015405467545081462, 0.02169971613745604, 0.022359201285455908, 0.07462706589805228, 0.027230906300246716, 0.042581227608025074, 0.055958966192390235, 0.03404507726164801, 0.03069522451343281, 0.022147866464885216, 0.023097849417743937, 0.08318539416151387, 0.08065352894897972, 0.059825414791703224, 0.06290718513940062, 0.05662850044401629, 0.02365620231388935, 0.0210388637413936, 0.05535906320437789, 0.06344070365386349, 0.049210263682263236, 0.013882529622476016, 0.06795714808894054, 0.03838717212368335, 0.043295127871845446, 0.041905959735491445, 0.057604562890316756, 0.01559453284634011, 0.02911429220278348, 0.03539580299652048, 0.02439202434782471, 0.05870475314025368, 0.03374333613153015, 0.046213717332908084, 0.04652360088324972, 0.01000142381859145, 0.02514310154531683, 0.020178930867197256, 0.007508115510323218, 0.015574237863932337, 0.034954521139817576, 0.04169080645910331, 0.02203322627714702, 0.014012702324959849, 0.0564493197016418, 0.03527354794953551, 0.05412748143342989, 0.004907953203655779, 0.010648813231715133, 0.014617500094962972, 0.016796644145090665, 0.01988140174320766, 0.039031329165611944, 0.02308222614893956, 0.10875514495585646, 0.030966428175036396, 0.0318704335950315, 0.04176778286429388, 0.09312848347638335, 0.06164004134812525, 0.01746267206700785, 0.06343610997178725, 0.050679291997637065, 0.03324484698740499, 0.022368644796577946, 0.010484994522162845, 0.028257797804794142, 0.04330768755504063, 0.014441703545993992, 0.03971113983009543, 0.022113459650427103, 0.049485206071819575, 0.06157690366464002, 0.12463576852210931, 0.05016204136024628, 0.06997169820325715, 0.04151627028893147, 0.03225216043314763, 0.016398654518915073, 0.05670543952978083, 0.03357554120676858, 0.022696501043226038, 0.044289473444223404, 0.020533305958711674, 0.03668944358027407, 0.049257384546633275, 0.019723752613312433, 0.02810834877059928, 0.05687471705355814, 0.03491860967395561, 0.03379782249352761, 0.024504186186407293, 0.05007068340533546, 0.12750867222036633, 0.1708206616874252, 0.2463504166475364, 0.09832530176000935, 0.17842429796499865, 0.12001147094581809, 0.1401430078383003, 0.10370356030762196, 0.1312586638544287, 0.10359559181545462, 0.14904822355934552, 0.11808865198067256, 0.1914749148168734, 0.07948379564498152, 0.17083800504250185, 0.13317343539425305, 0.19424571256552423, 0.13775487669876643, 0.1570542175322771, 0.15345179369407042, 0.14811926840671472, 0.052757970456566126, 0.12480088323354721, 0.08755990942674023, 0.11381869217646973, 0.10093613487801381, 0.13288712075778417, 0.13630906785173075, 0.1375563373523099, 0.15677949227392673, 0.13864596959735664, 0.17457343531506403, 0.18899952407394136, 0.12117844261229038, 0.14568494260311127, 0.15769467316567898, 0.2011495621076652, 0.16957507495369228, 0.1272838192858866, 0.1297851572079318, 0.10822318707193647, 0.12655524909496307, 0.15378279664686748, 0.13350502188716615, 0.10030341454382453, 0.09152132578726326, 0.14596221915313176, 0.18992538510688714, 0.19791399501264095, 0.10804165859839746, 0.12384940071829728, 0.13114699056105955, 0.06851603702775069, 0.08008355274796486, 0.1353156790137291, 0.19738608119743212, 0.12597978354564734, 0.07099430475916181, 0.25366187574607985, 0.11264038897518601, 0.11301150013293539, 0.16237435277019227, 0.07843420375138521, 0.08809501571314675, 0.09932518417813949, 0.202466680003064, 0.07877777317272765, 0.09179755739335503, 0.09541571645864419, 0.1475838635649, 0.15150059839444502, 0.11486730697963919, 0.09663866047880479, 0.09178288746625185, 0.20658603895987782, 0.1625831922782319, 0.20550468484205858, 0.11018269442554031, 0.1526452326881034, 0.2091927533703191, 0.22846377215215138, 0.11579638426857335, 0.12236931228211947, 0.15122781374624797, 0.12641285173594952, 0.13775277324020863, 0.1256427009190832, 0.10739147277282816, 0.11223366151430778, 0.15763348287769727, 0.11212152003177575, 0.09009541158697434, 0.1630300890122141, 0.20922505163720675, 0.21616182369845255, 0.11583067742841584, 0.13911763285951956, 0.13069094717502594, 0.10323501152119466, 0.19969117322138377, 0.1131607981930886, 0.1368314583918878, 0.18426197900303773, 0.1723689700343779, 0.13129162708563463, 0.09359176004571573, 0.17000761388667993, 0.1487747332347291, 0.18790810049644538, 0.10773606678204876, 0.08193876248385225, 0.07275593094527721, 0.15803402209920542, 0.12231154181063175, 0.18432220577129296, 0.15706723183393478, 0.11159749422222376, 0.18355596331613405, 0.14203479061169283, 0.17430135634328636, 0.11418753702725683, 0.11638495911444936, 0.12209954032940523, 0.09038116982472794, 0.08540684995906693, 0.2519871698958533, 0.11685951293579169, 0.14389552362263203, 0.12461993151477405, 0.128071218462927, 0.12046664580702782, 0.09543554325188909, 0.12552981983338082, 0.1326538132769721, 0.0683208496442863, 0.14389460081500666, 0.15259476325341634, 0.2136820089071989, 0.12881407860134328, 0.09519122993307454, 0.09282449300267867, 0.13366763958973543, 0.15075524124716008, 0.154574131327016, 0.1301383753972394, 0.09136288107505866, 0.14502379165164062, 0.09459582902491093, 0.09361453168094158, 0.10307675679879529, 0.11752978339791298, 0.10699560187224831, 0.10636428610554763, 0.14638348083410943, 0.08814030114029135, 0.10547396673687867, 0.17815426816897734, 0.20026657091719763, 0.12217770756355353, 0.19108863840145723, 0.1513194159737655, 0.07978884463331529, 0.2144788804330996, 0.15130181477538177, 0.10838086503956999, 0.10388529234166656, 0.09121660928108863, 0.12553158402442932, 0.07926281714545828, 0.17420015963060514, 0.08252973934369427, 0.12824951032442705, 0.13187879057867186, 0.10954695461051804, 0.13686520872371538, 0.12590617606682436], [0.0529447406131242, 0.03855531649397952, 0.05796746377434049, 0.04319767667246716, 0.058906386606395245, 0.0258424472329872, 0.024764010815748146, 0.047101956991744895, 0.03577005237873111, 0.025541045370378664, 0.034455906466713974, 0.04001325076179845, 0.04079940143440451, 0.06605860710676227, 0.04007157423932638, 0.046244285335498195, 0.01851158542558551, 0.02769294284683253, 0.04672861345378416, 0.036845537168639045, 0.05253479350358248, 0.03018824689622436, 0.022144383883902004, 0.013136628799007406, 0.009397042499456023, 0.07680263915764433, 0.057021782733500004, 0.03670873433085425, 0.04019984449925167, 0.06827491960887398, 0.05086243538452046, 0.0361957313226802, 0.025048418768814633, 0.0319009574928454, 0.027262919582426548, 0.04292074617530618, 0.020784089108929038, 0.01931689623078065, 0.07275668411914792, 0.06108010746538639, 0.08143503165670804, 0.027660315490460823, 0.03394939025331821, 0.03306939818763307, 0.028093003701152544, 0.042834738469017405, 0.032645534324858866, 0.02886182289304478, 0.0589300539078457, 0.060554575308093, 0.01596052954638643, 0.07847333486591067, 0.052635355786021264, 0.043711724624569924, 0.00777875429152378, 0.06811724842659064, 0.025079928238743117, 0.0461653649274792, 0.01873354271187314, 0.07750242589307682, 0.016780327074229717, 0.03171622294134327, 0.05027541099116206, 0.03559214388951659, 0.0489373297563621, 0.02565494256227144, 0.02641800438453044, 0.03915177591677223, 0.042467206583491394, 0.016564990593386546, 0.054458732051508765, 0.10575469703014408, 0.03756220246266041, 0.0805354570703847, 0.0845880481813635, 0.045419468344854455, 0.047546543313988616, 0.01676461729221046, 0.07282723819038697, 0.050635743620140214, 0.026643790304660797, 0.02421927102841437, 0.030108712414013486, 0.004688253318558314, 0.026817040650972297, 0.06768219212868384, 0.0082446296499776, 0.03904864537928786, 0.01154975252159472, 0.05966248496302536, 0.05532585570056524, 0.019734668545424938, 0.021893241110124757, 0.05907309587512698, 0.00841746524175895, 0.04649064104471888, 0.06176542104887111, 0.05471558130479284, 0.07812143303453922, 0.0195151488961918, 0.0601831723802856, 0.05713447382939713, 0.03818036482802459, 0.012107711867429316, 0.05233240347089512, 0.0535740852355957, 0.07480761049581425, 0.020874071334089552, 0.04262963429625545, 0.06539845360176903, 0.024413637384506207, 0.028331045660057237, 0.04126248801393168, 0.019136726523616483, 0.023057658092251847, 0.017787732749379108, 0.10719922344599452, 0.03000680323956268, 0.040963545840765746, 0.027759139026914324, 0.044300621774579794, 0.03269738797098398, 0.02596164887238826, 0.03414572775363922, 0.027640317367123704, 0.05057110637426376, 0.026664602670020292, 0.02505206928721496, 0.029809006888951575, 0.02757429251713412, 0.07931752063866172, 0.02874166451926742, 0.06924652747277703, 0.026225758450371877, 0.021828827780804465, 0.0021088921390141225, 0.023720447705792527, 0.04370207924927984, 0.03269462972613318, 0.11382099241018295, 0.0017201564582397363, 0.03060553575466786, 0.03203702072745987, 0.016517986776307225, 0.016503567907160947, 0.012141918514056929, 0.04204865225723811, 0.049139567118670256, 0.03407802692215357, 0.01304115298470216, 0.007855491513120276, 0.038018096570989916, 0.031122318202895776, 0.07293015159666538, 0.02945313902039613, 0.012061930261552334, 0.016319437251825417, 0.010468829273512321, 0.02869234180876187, 0.011495048180222511, 0.044215150110955746, 0.01970141184782343, 0.0480068139731884, 0.05431140174290963, 0.026145173935219646, 0.019200047411556755, 0.06420995880450521, 0.025898217722507458, 0.043658374808728695, 0.015477702686829227, 0.04942755773663521, 0.00460808610244255, 0.03337510196225984, 0.002149873533718554, 0.025397659046575427, 0.028035229836989726, 0.025592715812048743, 0.015472601799826537, 0.02637511757867677, 0.026401378580236008, 0.03206712393356221, 0.037610286846756935, 0.09905717641647373, 0.03893649711140564, 0.06199314418647971, 0.03810335788875818, 0.005163003915056054, 0.0375644687696227, 0.042225990777036974, 0.039508132330541096, 0.0993720641625779, 0.03878188272938132, 0.04591719074440854, 0.02836235156948013, 0.019103610622031347, 0.03168633008109672, 0.030883494232382094, 0.059126238737787516, 0.016399039587538158, 0.015069716543491398, 0.03365862103445189, 0.07203625634844814, 0.010317934959727739, 0.044847561711711545, 0.016683832609227726, 0.037937015028936524, 0.04870701800765736, 0.0679426138688411, 0.055043941363692284, 0.038510251590715985, 0.08345197021429028, 0.02678857441060245, 0.03219893275360976, 0.047304479338760884, 0.008378256943875124, 0.07986019937587635, 0.05001573563952531, 0.08848489514951195, 0.04587443286020841, 0.03458381710307939, 0.0522418970774327, 0.007609777867660991, 0.025145313569477627, 0.028250322045226182, 0.0497012176950063, 0.027161677068631564, 0.01870307988221092, 0.04039311841396349, 0.011465724441222847, 0.043277787909443886, 0.046764263683663945, 0.024735429224425128, 0.04643765085243753, 0.09278128389269114, 0.03524304101509707, 0.019941881265757338, 0.07181569854063646, 0.020684777027262107, 0.02518365758338145, 0.024209367809817195, 0.03224969056567975, 0.039815125321703296, 0.012430176305185472, 0.05046409800914781, 0.09469001647084951, 0.02972890922267522, 0.036405948256807666, 0.03240447458145874, 0.03262180595525673, 0.02250765626584845, 0.05507749492036445, 0.04333606388952051, 0.040770590837512694, 0.027280530958835567, 0.024122489882366996, 0.08507429994642735, 0.015417006033073579, 0.09093169921210834, 0.013395439018495381, 0.00619159939066906, 0.018042962000306164, 0.05502474560801472, 0.020602687860706022, 0.015370468708819576, 0.038843995824988396, 0.021956612888191427, 0.004971135416001613, 0.030500915832817554, 0.03828399408874767, 0.027779732564730302, 0.0213135245389172, 0.0695319939404726, 0.021253915237528936, 0.028619765703167235, 0.023408116340371113, 0.025374868751636574, 0.0457540505698749, 0.036066521291754076, 0.03539986402860709, 0.06558270978608302, 0.04675899825191923, 0.023660578864759634, 0.04019626861970339, 0.059149227504219325, 0.029355053390775408, 0.03801279042714408, 0.026266804729987468, 0.02164061234465667, 0.014945968719465392, 0.056366331476186, 0.027415252390450666, 0.05759072077593633, 0.07340009816523109, 0.07018517210547413, 0.0835987509095243, 0.0015517695116743977, 0.060973536755357466, 0.008694834242175733, 0.040305024212492366, 0.0498803950447057, 0.07295839222414152, 0.022010422411507795, 0.021177505409078937, 0.04959735773237688, 0.02150262376692678, 0.04192064662597009, 0.05180177890828677, 0.04127695777320436, 0.02687355244000043, 0.02694255266604679, 0.036807864904403687, 0.022253913006612232, 0.024446804176217744, 0.03286333728049483, 0.07180421094277076, 0.04277171613648534, 0.021507215752665485, 0.040739507148308415, 0.04507690315533962, 0.04412788372220738, 0.01674598132792328, 0.05078979481809905, 0.016006865006472384, 0.005661237336296056, 0.07189296332320996, 0.03849587343367083, 0.02866996033117175, 0.06364064756780863, 0.06460011644022805, 0.06686127332172223, 0.07100115796285016, 0.036843671197337766, 0.04159635438450745, 0.015111527871340513, 0.025943784741684794, 0.006222221251976277, 0.021563685133254955, 0.046527315862476826, 0.034070244125489674, 0.029501861227410178, 0.03943192945527179, 0.0171882606311036, 0.05264057032763958, 0.006247625178990087, 0.041403826858316145, 0.024840018612199595, 0.09943294910980122, 0.04187240617881928, 0.01829447627200612, 0.015666654333472252, 0.011463480186648667, 0.021216448230136718, 0.16796552203595638, 0.13537427729793958, 0.10501307182546173, 0.1857319436967373, 0.13116767230842794, 0.09837594082845108, 0.19239727460912295, 0.10774821255888258, 0.1637708456920726, 0.1238250413111278, 0.12331628932484559, 0.17268015976463044, 0.1456715211804424, 0.12751847026603563, 0.16386596273098672, 0.1032981967021312, 0.1087649090747748, 0.099348016881517, 0.15262244748217718, 0.14774090370961598, 0.10047144017049245, 0.1060673523960369, 0.09065100284559385, 0.11285316398633377, 0.12437973011817251, 0.1711163129657507, 0.11131543400032179, 0.17392886775944913, 0.0820791038817593, 0.21743027706231388, 0.14036845788359642, 0.16192965448967048, 0.08788796075220619, 0.20299289748072624, 0.13081072217651776, 0.15691784556422914, 0.14268731059772627, 0.14545782336166926, 0.14817910162465914, 0.26051122535552296, 0.1392587681433984, 0.14755767211318016, 0.08735553467912333, 0.09479267203382083, 0.15042160557849066, 0.1334130261093378, 0.13680582333888325, 0.1317607526268278, 0.2357185600059373, 0.15107095002063683, 0.1273335830441543, 0.17540021666458674, 0.14459087273904256, 0.12106510012277535, 0.11363742833158799, 0.12907395751348563, 0.13165247200855187, 0.19517546838947705, 0.09422382898628712, 0.22161938941904477, 0.18122617261750357, 0.14861712312059744, 0.134466180311782, 0.11824319511651993, 0.15994834580591746, 0.13294316775032453, 0.0913952471954482, 0.12647573836147785, 0.12595471846205847, 0.1146348137408495, 0.12832899391651154, 0.21463206649890967, 0.07659453925277505, 0.1679481379687786, 0.16240566037595272, 0.15421601411487373, 0.17224720013993128, 0.10396600408213479, 0.12999637158853666, 0.11848330151821886, 0.13514812157622405, 0.15895704685577325, 0.0869913310078638, 0.1255064917994397, 0.10643128465328898, 0.17657572430159363, 0.1064857438738857, 0.14937352681798594, 0.1420454436114856, 0.11901812281991754, 0.12274574993976525, 0.12123390606471471, 0.1645881004099335, 0.16325948813131877, 0.12191466667822429, 0.10923119833959, 0.14243670047393867, 0.10995640978217125, 0.09003450628370047, 0.21112987585365772, 0.1293928011187485, 0.09569941194994108, 0.16444488880889757, 0.19117190821894578, 0.15446291943745954, 0.11372493899294309, 0.1408350999866213, 0.13727804299976143, 0.1517128034361771, 0.23055091872811317, 0.08924452867358923, 0.21452394872903824, 0.12920889098729404, 0.13769004946308477, 0.10444460197218827, 0.08390733506530523, 0.2757933538939272, 0.151320270927889, 0.1386200902717454, 0.11259667096393448, 0.13249416755778448, 0.14546536867107662, 0.07527017460337707, 0.11939047569675104, 0.21916862949728966, 0.11414173591349806, 0.11908318075750556, 0.15178893506526947, 0.13721750410539763, 0.09534727263131312, 0.12986409797200135, 0.11532060908419745, 0.1439944947404521, 0.11821483235274043, 0.10600373295268842, 0.08206079022160598, 0.09632251744291612, 0.11452768663210527, 0.14123941186283315, 0.17545490658708982, 0.06982347222843341, 0.11444847445402827, 0.13517021467643126, 0.07232343272439071, 0.12201808898576669, 0.1219682302325964, 0.08319137884037835, 0.06824574260307209, 0.15531966489340576, 0.1205464279545205, 0.10811520500906877, 0.12763920878725393, 0.13024086132645607, 0.20177297294139862, 0.15471031330525875, 0.15908766484686307, 0.0974992396576064, 0.09623130198035922, 0.10187768364059073, 0.13039981493992464, 0.09468581633908407, 0.08954561501741409, 0.12622807307967118, 0.20187141480190413, 0.13895321025380067, 0.0943567268550396, 0.17095999206815446, 0.067857722352658, 0.1306574818279062, 0.09612881605114255, 0.21032612398266792, 0.10349069030157157, 0.16685691795178823, 0.12320252614361898, 0.10139037336089782, 0.1388728717075927], [0.03834082139655948, 0.012107940872998109, 0.04068314802965947, 0.020335786111120666, 0.03752210782840848, 0.04827944255833115, 0.011941651447809168, 0.07076012196817569, 0.02827369588028107, 0.03428836938525949, 0.053194288829607625, 0.026614850786115442, 0.04384775732510856, 0.03280667960643768, 0.01737799937836826, 0.018123882390292625, 0.0075725076354241794, 0.017667077348700592, 0.01586265765529658, 0.062123701109417846, 0.043418078417224545, 0.014435164164751768, 0.017979273007118275, 0.033480023832193444, 0.012558924084130143, 0.02599866465399308, 0.02908920676314405, 0.04137695687157767, 0.05206465694521155, 0.04379021755552717, 0.04310993870188083, 0.05580645526892372, 0.0447880406198757, 0.06646285112947226, 0.0499462095488395, 0.0036522066802717745, 0.027718313271179795, 0.032912751593227894, 0.024051101213054996, 0.04963852784463337, 0.05395140498876572, 0.04262136634705322, 0.0304230267980269, 0.0646298159179943, 0.025974793792037026, 0.03330039186403155, 0.02544815562266324, 0.0807165919936129, 0.03127495465534074, 0.035018554489527426, 0.10309193562716246, 0.07084694730916194, 0.05167794966005853, 0.03220366892803993, 0.029472667258232832, 0.010245334257238677, 0.006600735226779112, 0.0341436310804316, 0.02698460148115243, 0.04529757970677955, 0.010011623896259283, 0.022694022694070424, 0.07060084944324833, 0.023969878874985234, 0.008259246990616833, 0.012440167733335068, 0.02501072614852871, 0.05733994780374425, 0.02180423936806619, 0.021350070435021604, 0.01214607454104615, 0.05789324561400073, 0.034202042767511945, 0.018461940410946096, 0.0495092906723065, 0.038317486577268155, 0.03918205214930432, 0.013990568512651538, 0.01339259001958583, 0.020803571545651982, 0.029229928140661547, 0.012459463572927883, 0.03594537225684949, 0.07699360605329275, 0.021144806806530272, 0.012363738397003284, 0.13147859062467301, 0.024010212692831243, 0.03300239624721663, 0.01752381316120071, 0.035793553439102004, 0.04405078857338854, 0.06812051218003035, 0.02654926528755043, 0.027587551091398512, 0.03843616235202976, 0.05248962003471596, 0.02645322883368603, 0.03516374062746763, 0.030096349505973712, 0.015132652362808585, 0.04871167275788529, 0.11774369834789208, 0.025755462436271564, 0.039718108384736946, 0.03345376791964684, 0.009548943589574524, 0.011193051751303886, 0.026149029710463116, 0.0379566552250513, 0.015675848482974937, 0.04761541801105652, 0.009349260063442801, 0.02655996408845697, 0.06203895887093885, 0.008012518087135894, 0.016364101819427948, 0.024293875953714763, 0.003787960757368377, 0.019772824265861084, 0.0242081345724208, 0.02991861743586404, 0.04099278052204421, 0.018985172334526266, 0.04407919204926916, 0.033836010444377146, 0.022889040443780165, 0.04103157915441053, 0.04502949391358665, 0.06571102075810943, 0.009343453500020717, 0.030385473277419806, 0.02976005058735609, 0.03542861355734723, 0.018118309921451976, 0.05468492509265031, 0.052419381482260566, 0.04527000065094658, 0.045992874540388584, 0.08992992368127618, 0.008664306103517967, 0.05275088655097144, 0.015614079743889826, 0.027662520729271427, 0.0026868850192321198, 0.04872534863118615, 0.08140304551592895, 0.026775276820574487, 0.09721618198922702, 0.10637823000018086, 0.03781402377145631, 0.09221999293991498, 0.07997284297432218, 0.03235763870179653, 0.020317772702713097, 0.019716314173170497, 0.024668574865375246, 0.05017928293507014, 0.03453781921416521, 0.018925861588546207, 0.02808000466653279, 0.010940035372706396, 0.054809914635760446, 0.04307137416409595, 0.061211030797234604, 0.061537555418908596, 0.07380538713186979, 0.04348857142031193, 0.02137354774666684, 0.034986863511481454, 0.02598985218043838, 0.03301450809729951, 0.006723251933830657, 0.043466939723917415, 0.027149838328893696, 0.04837899382359215, 0.04072400940848248, 0.047236347637538395, 0.07328030280768871, 0.04250887541898659, 0.0641118697822094, 0.021798159694299102, 0.07577031598027263, 0.037831445158060105, 0.014017207797483673, 0.019332658599263856, 0.048608325089194944, 0.02669410197995603, 0.006342749003254409, 0.029822380814169134, 0.021038619468786886, 0.06933198217302561, 0.04357792091156755, 0.0772782311375652, 0.020456646768642322, 0.0324497260818524, 0.03330777432503445, 0.01515040623157152, 0.02307374106853136, 0.013501836702094545, 0.022822678022618805, 0.035779338130461316, 0.040990056203944344, 0.025033648757796203, 0.03256042907014489, 0.01656236975187702, 0.03260685782879591, 0.044918366840907505, 0.019508409347119074, 0.043916462388421805, 0.04862333767648254, 0.03268990712240338, 0.01696074614301324, 0.036764777930719514, 0.025105983983459215, 0.059025666277323446, 0.03837890078180602, 0.01804851750577135, 0.024852442588391047, 0.03432014857285789, 0.03584854870236345, 0.04917695100552269, 0.04111282693754349, 0.0018184666405431926, 0.03663486222337399, 0.008038420313304024, 0.03159898226814611, 0.08375118380146367, 0.0612915593332478, 0.03283138506646667, 0.05440179957076907, 0.07924674943621669, 0.028247796198619262, 0.05908690406275647, 0.03411960415542126, 0.03147877300424235, 0.030998702693198408, 0.02825461038654404, 0.04745480877214244, 0.047952039233808, 0.036031274790210385, 0.031830613767462115, 0.02254262626437204, 0.025871746375092437, 0.03328100951122386, 0.04921506431752017, 0.017194604933527962, 0.020576479445610727, 0.033568155353090594, 0.036024570864226134, 0.06034961023500987, 0.0615474416741303, 0.035607427890811644, 0.03625667055270501, 0.0896360230232988, 0.05116365743534906, 0.02241102439750518, 0.035001367197505066, 0.038080572682831965, 0.0027138911370587137, 0.06768626333879572, 0.018896090864603008, 0.04212780675983854, 0.033991286398044655, 0.04063366925609963, 0.01969024146507893, 0.025625884300097823, 0.023268500974934016, 0.02255434965315674, 0.05843354269329991, 0.04769428074359894, 0.03396920347586274, 0.05019239901698061, 0.05093864504513996, 0.04691324961770858, 0.023274877507771765, 0.010051877138071826, 0.010387376233536218, 0.03951582691765257, 0.0670188766505037, 0.05201626043500645, 0.07261530456266233, 0.011531853615971548, 0.00884084904100746, 0.03946737273197089, 0.030393917645726885, 0.003992362646386027, 0.08569931890815496, 0.031187267574880804, 0.049951810855418444, 0.03504510895748224, 0.0513908038181918, 0.04202862190348761, 0.043018835197601996, 0.02754382459845926, 0.014771274789901716, 0.046345624540533335, 0.032793590665927956, 0.011481601312490446, 0.027824593907488242, 0.026093315200081894, 0.007559751177073589, 0.06555669475346804, 0.023767041009185568, 0.03907786648986595, 0.03548301849514246, 0.03059817704239062, 0.07719422850225653, 0.02094781451991626, 0.06983589620462485, 0.00279520868207328, 0.025980939622968435, 0.012483225869280952, 0.03207488976685064, 0.05080733494833112, 0.046350845867501836, 0.010111338858093535, 0.021893407351204326, 0.06438958059464182, 0.09765748080930539, 0.017277925641142895, 0.030795332177409103, 0.05242872490946736, 0.028253112520490373, 0.015124649042263627, 0.08612232442413058, 0.009601446932979991, 0.029707287704305987, 0.12425558535116059, 0.013296344916203191, 0.03743773199883955, 0.08578345725046736, 0.058343609661928246, 0.029117895223732506, 0.05106042172493679, 0.032707029953598976, 0.016775176993438175, 0.0820616858878306, 0.012483964624282504, 0.05161847945834909, 0.08871470817497798, 0.05862225006733622, 0.04882521541523082, 0.04823386875380363, 0.03774706254314099, 0.02373023048442389, 0.009916335527252938, 0.03621749872607844, 0.02169885779065745, 0.024895916327035854, 0.03838946217937129, 0.0686030862852931, 0.25606513821652954, 0.1388339102268219, 0.17276946854378494, 0.14714339934289455, 0.14186731459839003, 0.15095608761268003, 0.12963406102997915, 0.1305443700402975, 0.10294827619301421, 0.10193542018532753, 0.1572882171188082, 0.11261721021894898, 0.06636724554534469, 0.13225817307829857, 0.0910271555185318, 0.15928837550537928, 0.13823886215686798, 0.18417682285819734, 0.10254291258752346, 0.19715913837509497, 0.14427616819739342, 0.11194878537207842, 0.1394813819123166, 0.16184964164027146, 0.1301688551902771, 0.13162847901029245, 0.08431593528283493, 0.09821885997163397, 0.12620071454771928, 0.14016839861869812, 0.20145008526742458, 0.19469141507787363, 0.10188667422958783, 0.14415420831314155, 0.12755565398505755, 0.18782412500253745, 0.17678904214075633, 0.07230218100760664, 0.0872177988556879, 0.15944412643355982, 0.15789638805602277, 0.0858935359865427, 0.10403847840747663, 0.19372960525963986, 0.11594924463757447, 0.11776671425572463, 0.15919916172112736, 0.1418804238949503, 0.14319277847451822, 0.07413786929100752, 0.1481810693762132, 0.2061471217977149, 0.16846697298543795, 0.0971854172114815, 0.10173263999500445, 0.11918665734784943, 0.07514627410897187, 0.09742097742855549, 0.13477616224970135, 0.18539990937071188, 0.0949909942490714, 0.08167551803801741, 0.1908983364701271, 0.12158917342977864, 0.08572417364588805, 0.14954143709370069, 0.13254827394017152, 0.12274634705058166, 0.11993717136127607, 0.12406632836375918, 0.0779047157349331, 0.1039617768089686, 0.11998754580106054, 0.1699671596288681, 0.0988802212689604, 0.16132513407085622, 0.07399706648928778, 0.1381477213331631, 0.23937819791691645, 0.11782001996678965, 0.1324365192226001, 0.13758775352367333, 0.12465240620076656, 0.10299042678837265, 0.1783693501991885, 0.09770056099763938, 0.1828503818916423, 0.08723288947450263, 0.13474779948592186, 0.0736017112753221, 0.17438820882567338, 0.07696488366595336, 0.19318398168044432, 0.1420923982347761, 0.10355337336659431, 0.11980761188481535, 0.13777327856847219, 0.13350237560059341, 0.16889370365866593, 0.10509605665824243, 0.13790134526789188, 0.12561897933483124, 0.21586613170802593, 0.14631196324314388, 0.17133486909525736, 0.1323284421648298, 0.07608871853777341, 0.054074202863765616, 0.1478403362312487, 0.10659643329147782, 0.05862639591630016, 0.18467831451978, 0.1354470976761409, 0.15239569464964525, 0.12642858017768177, 0.0961765374190041, 0.15257752846394265, 0.10508648931447949, 0.11502897473318235, 0.14052825288048812, 0.10154729136931044, 0.13528028662715638, 0.12245803752115794, 0.07555645531309502, 0.22667761013976165, 0.12095460748033864, 0.1119412672040718, 0.16582390266869748, 0.13189989301775182, 0.14154069498181343, 0.1329113987407514, 0.07870221151305096, 0.07961484789848328, 0.13403155149093696, 0.11250932315098387, 0.1274008530059031, 0.09811680151947907, 0.18473533860274724, 0.16020529344677925, 0.1450654129896845, 0.05448403122967907, 0.09784182520317179, 0.17398076211767538, 0.18288281586553368, 0.12297232635319233, 0.08613028363989932, 0.15889831286455902, 0.08044181923781123, 0.15505134500563145, 0.16818084833877428, 0.13361442887357303, 0.1339067689010075, 0.18445955482976778, 0.17186735623649188, 0.07303413030292306, 0.19813484459051064, 0.08227659149893693, 0.10846762252705437, 0.11564011765377862, 0.09857347594308001, 0.1451267661260707, 0.15014104491897992, 0.15640336674238953, 0.14117735305002757, 0.15171262701707228, 0.1323533851121153, 0.1376923429114478, 0.19666439135159763, 0.1598957593419722, 0.07881246666823115, 0.15423107759228774, 0.09415835035698754, 0.07363452522882394, 0.10601695760020188, 0.16336562457893575, 0.17520231514104775], [0.013750441754902048, 0.025681938077988367, 0.03172367664852312, 0.061001919875187535, 0.04761245620570012, 0.059529763513377736, 0.0331380625388452, 0.026292078463094573, 0.0269084087839084, 0.06013567492898021, 0.05424609953271491, 0.09702775281454835, 0.010834857355803251, 0.04025734694940703, 0.009847772956293608, 0.03900423526231732, 0.012982616616812135, 0.029495499961610352, 0.016925967830632414, 0.03114566659288747, 0.07547980121203832, 0.033566923812031746, 0.03943877587360995, 0.035549721880150695, 0.05590964348188468, 0.011709330387280455, 0.03701282658481172, 0.0521082053227084, 0.04193182209772723, 0.05894638624574457, 0.031970436086079905, 0.08034007969711508, 0.030348418480051414, 0.0359299050510994, 0.010395164967381527, 0.016940922742443423, 0.011074722029401787, 0.021756845393351147, 0.04747970082930156, 0.03038516454398632, 0.013846798816562762, 0.030005666693406444, 0.03404112818783947, 0.05058581701346806, 0.028689122160098383, 0.018797428480216434, 0.027090514012213265, 0.010709637110786778, 0.014292217192373105, 0.018808648056749786, 0.05010723608679005, 0.02366608178376087, 0.04122339761150735, 0.005743324382430208, 0.07527562323957682, 0.005375196658340948, 0.04220649307327611, 0.09600032866001129, 0.07251890509256295, 0.033469116381768665, 0.06494621679719005, 0.02234543889894017, 0.020580345398879478, 0.052607311933700523, 0.03250278752031071, 0.04731829770441566, 0.06903314178011247, 0.004985172609199903, 0.039616789535752366, 0.02598626951553992, 0.012481984998365598, 0.021059116315362707, 0.027705305754872303, 0.0233890715587352, 0.019433095352724195, 0.02386962532597993, 0.04899150738492608, 0.07756946515291929, 0.041275193582155874, 0.053340092434414794, 0.021011523869154707, 0.016200887006042258, 0.023279035231098533, 0.08150935838265078, 0.06116598964269672, 0.019912081704075848, 0.03434188883485539, 0.03367934688659651, 0.06387695417340312, 0.07866118728582348, 0.03539756040221878, 0.036838901096156666, 0.009541684961212533, 0.027798809576779604, 0.041415039649499316, 0.07736627784158502, 0.002398604539588892, 0.026428029739430973, 0.06757790808166776, 0.041153505111911466, 0.01989239570684731, 0.03773210084597979, 0.03208097961864301, 0.032444501362208805, 0.11550458706915379, 0.04936640137540443, 0.06244026483701808, 0.013837438425980508, 0.05942584587527173, 0.023266088782942722, 0.011983296534578716, 0.01600006778192307, 0.031695283350667784, 0.03251362033188343, 0.06368090505046503, 0.08954760991036892, 0.04115527608831014, 0.013060698185914328, 0.06999643759003707, 0.027052746753075292, 0.014667789717870099, 0.07116148221705641, 0.023320548003539443, 0.06161460307027612, 0.04013037608404245, 0.04689191308404718, 0.01710629020817578, 0.022835931507870555, 0.05878904076027019, 0.050642464509499927, 0.04713956818782857, 0.023071328876540065, 0.022725001210346818, 0.03978172104273524, 0.03272743350160973, 0.030446785701704875, 0.035950451091464074, 0.03722088238490479, 0.047456182805555205, 0.04542981939656394, 0.021619776230571524, 0.037681091975952895, 0.05985922619168248, 0.012467268421979887, 0.11771997676364013, 0.04257347195276192, 0.03364209192139762, 0.05001802569521325, 0.04612694627472332, 0.052895655389875174, 0.034221235130514414, 0.07125261625541107, 0.028979097492992878, 0.03524244051160557, 0.03990883779312883, 0.016924042487517, 0.06336404955280678, 0.014767456334084272, 0.06580792234412261, 0.010565888618917336, 0.0348975275909262, 0.053322243570749245, 0.023594950957755958, 0.06888904808355228, 0.028061721540455307, 0.032358615792223384, 0.07451406267604657, 0.00771120358591101, 0.022886326303705573, 0.04151691828987428, 0.06786147465131112, 0.04748934959726674, 0.034369179513305426, 0.03322955620075975, 0.058063008290316374, 0.03211659252909677, 0.045506324219916544, 0.06297211415533509, 0.0022128602431621403, 0.021813791444791213, 0.050571075840187926, 0.021195193120677556, 0.012513838824816048, 0.05012683217812862, 0.013906059520585197, 0.034660026763698885, 0.046400663908571005, 0.004119802124997867, 0.05607422554333295, 0.018912392668426037, 0.06397180658365999, 0.07216848246753216, 0.027678802177043896, 0.07659334503114223, 0.04499975372371929, 0.05044011179623859, 0.03443685659606542, 0.07059533973889691, 0.02742600717049624, 0.06923328246921301, 0.05360060238412448, 0.040725047567061017, 0.04827582257400666, 0.06244721982095923, 0.03130551247990557, 0.03025270433032087, 0.0555934563412198, 0.035370910939361365, 0.017743076663464308, 0.043645089093063555, 0.05186132714152336, 0.05714883841574192, 0.022846650664827654, 0.07222480765943017, 0.04197251384279557, 0.025110056889908652, 0.01812356517517141, 0.05526114720851183, 0.09748872236481734, 0.03810707286798528, 0.05319472309201956, 0.006923350638576916, 0.03965128964877554, 0.023285912183512534, 0.03416989377832838, 0.0421749683363097, 0.044757184239902666, 0.01625477964989841, 0.02241825927714152, 0.05736515537968703, 0.03392119712329336, 0.04692314944363066, 0.013250889855303934, 0.05142771951588137, 0.04529872303828597, 0.04084949767483132, 0.05445111210324934, 0.014443905392129506, 0.02775917125732771, 0.020270064905551926, 0.007878179179637559, 0.04034063033759594, 0.05730536287384374, 0.024478435782449584, 0.0067432899211001185, 0.020388610062322447, 0.034668701833912303, 0.009510609753695982, 0.061368980178875585, 0.019298355261396085, 0.08729255984404258, 0.03657519185383405, 0.0884493263438344, 0.028912841941096952, 0.05010209957669888, 0.026687087624200752, 0.041390846483409405, 0.04322168663410204, 0.019970897119492292, 0.003626521161225225, 0.047304279170930386, 0.04683385084250143, 0.06943628657609224, 0.02798815138105835, 0.05363123484754136, 0.04612287845728653, 0.043659368862531016, 0.07743548162813697, 0.031336565635034015, 0.021858927594231706, 0.05842077266424894, 0.008095953297535223, 0.011248717067896255, 0.02869629766792059, 0.02588003976935787, 0.03843896470165678, 0.02438482000226421, 0.04304908089605825, 0.01766470756514796, 0.025105403836018274, 0.07920794401850019, 0.007040756280600492, 0.042847939367805205, 0.005575171106361917, 0.06548837984779052, 0.05916581768542528, 0.01834288126389895, 0.035740257906062264, 0.027604377063523446, 0.06935423812163727, 0.06570903943585497, 0.012222112871573439, 0.027156671176531484, 0.046253336992646964, 0.027415114987109388, 0.012301825469226708, 0.038129702010857205, 0.04040816832067711, 0.015388436316113387, 0.10632287511335951, 0.012589688013706888, 0.06811065306620938, 0.05699038691818714, 0.023011992685496807, 0.009908947977237403, 0.03400247883317726, 0.02635909567054893, 0.009513905737549067, 0.014113951624105019, 0.012976870273372956, 0.016800711962527463, 0.02105561507466648, 0.022906202290739332, 0.01822396630554327, 0.040717726174209795, 0.018250858344669853, 0.029072070361248085, 0.06405483891389199, 0.037130009582532306, 0.028986764938703606, 0.0260206932933735, 0.040927535987326076, 0.04672564147040248, 0.04680576627807958, 0.04770078110907759, 0.034352487551846674, 0.017375068107087697, 0.07220118107008082, 0.021020914793812802, 0.03176069751914058, 0.037411611793296676, 0.004976528921231095, 0.03611619344779423, 0.016688502626493573, 0.01951398860130991, 0.04140856642542141, 0.08229285598333393, 0.07067516259849072, 0.006988688047775733, 0.07067022286355495, 0.05614371092191764, 0.01966489139678223, 0.03186012325542314, 0.02917309744017465, 0.04151294546734009, 0.07013540156185627, 0.045445021973656755, 0.015053572499060204, 0.03111100702413491, 0.06285576575568744, 0.01586508341798825, 0.016793466904865842, 0.17389876794602188, 0.12395112668829304, 0.0914496114211423, 0.11521082211818014, 0.14199971035122871, 0.08763112846229758, 0.11655596350984913, 0.160065854500447, 0.08953397814184427, 0.14215453847178391, 0.10738123367939677, 0.12945750621812685, 0.22980007901787758, 0.10773530682282788, 0.20221146941184998, 0.2036171361271824, 0.08565742615610361, 0.12559270645890916, 0.1172047108411789, 0.17174608845795902, 0.1507257249738489, 0.26946851185389925, 0.15339804014989308, 0.11360004783741065, 0.10994502396455832, 0.09739625161247593, 0.07924477489931242, 0.10883838763194424, 0.13700544834136963, 0.2005386363182749, 0.21995255457503454, 0.20507859199174813, 0.13920060412159987, 0.10101823082992009, 0.15719658774988993, 0.127683639260275, 0.06431742518075875, 0.16953139086919172, 0.12346507848373481, 0.08292159331696373, 0.11068534638200488, 0.14198210915284498, 0.14555257399167332, 0.14342950577182428, 0.07455664753381695, 0.11382355727255344, 0.08154249803296157, 0.11242283707750694, 0.0823249031922647, 0.08948960195162467, 0.08971733865993363, 0.05839775675641639, 0.1018322692917926, 0.0857471963390708, 0.14247015225035803, 0.11792488076857158, 0.08751035601432834, 0.11297247079866272, 0.16766759087996824, 0.15722037718764373, 0.23531426170042583, 0.15323265402444772, 0.09130017765398536, 0.1297152273889099, 0.07620645793420927, 0.1647633117224489, 0.1800014983330454, 0.07860492316207715, 0.10333567219121115, 0.09488429461738893, 0.1048521368897387, 0.10872959811240435, 0.12328927006040301, 0.09572440239467792, 0.13761788047850132, 0.18093043991497584, 0.13794292589383467, 0.13033695545579704, 0.07877793602113213, 0.06288052549851791, 0.14003087314111845, 0.16218073958797113, 0.15894286547388348, 0.20934367312916688, 0.16283743934971945, 0.08029768482914992, 0.16226919341300214, 0.1384703918759312, 0.26254653185606003, 0.13475690542587213, 0.18356779696685926, 0.16417565968419823, 0.16150589579982416, 0.06533504450427634, 0.10411303583532572, 0.13146569845931871, 0.1627134031483105, 0.10710759407707623, 0.18296898981290205, 0.2101323072399412, 0.07881471261914287, 0.1201574509697301, 0.09932769475770847, 0.12306774194751467, 0.1646433331604515, 0.08049932508064167, 0.1877974992884057, 0.08973871929837124, 0.1360584305865424, 0.16121255154056208, 0.07854576847915139, 0.08917389317814793, 0.17024481615849904, 0.1309784831745284, 0.1498301944562367, 0.19005627451198442, 0.06507598661950656, 0.12426603479044777, 0.15601174347102642, 0.0782807869836688, 0.08841278044772999, 0.15416699674512657, 0.10135922181819167, 0.2533769996038505, 0.13147260594580853, 0.138497601130179, 0.1780828455729144, 0.0831385888159275, 0.1532686570925372, 0.18552603545997823, 0.12043635600379535, 0.1301850586065224, 0.12705277811203683, 0.10709468834102154, 0.11750042997300625, 0.09754912555217743, 0.09781087043562106, 0.07175155662532363, 0.1940534971654415, 0.11380298409078803, 0.10602701348917824, 0.24667166226676532, 0.15963347841586384, 0.14995451564235346, 0.16421080779816422, 0.14787286520004272, 0.12304655808423247, 0.09015408451003687, 0.153597977278488, 0.1219334349568401, 0.15634742831545217, 0.15351799157048973, 0.14938336557575635, 0.1479465812444687, 0.21273249414350304, 0.07117290196142026, 0.1695493177643844, 0.05660601718617337, 0.11628786075328078, 0.07568859322262661, 0.18525728130979197, 0.18273086473345757, 0.05872610663729055, 0.14676954011831964, 0.18968496657907963, 0.09121945912816695, 0.125075187800186, 0.08421277760394982, 0.1286713419748204, 0.09527760744094849, 0.1471039086048092, 0.09389488877994673, 0.10054820962250233, 0.117259075066873, 0.1837710996291467, 0.12244745237486702], [0.06341985905809061, 0.05897898306804044, 0.03820500582722681, 0.010289518761315515, 0.003355385353123503, 0.02197822422853538, 0.04800324148631521, 0.02510710186990244, 0.05933000958923783, 0.035975974186190536, 0.05091073689982295, 0.03067132651007601, 0.033831443903701644, 0.02546176194612469, 0.07585598781172719, 0.010785009628827018, 0.09452403323458773, 0.05138740096507328, 0.03512328297698072, 0.08906460832804441, 0.013685119188656765, 0.034567420304353745, 0.04629214919571366, 0.10353124633963619, 0.049188933933952024, 0.022393725147204738, 0.028171506810135076, 0.024533247841256003, 0.12422837609691278, 0.03499761829152703, 0.0842977776857359, 0.020981683595372096, 0.02572934392706624, 0.015649161700691496, 0.03190687431820801, 0.016362827869930437, 0.04477004247850605, 0.04618095087685755, 0.028404157808316604, 0.02707779317695115, 0.04320749168151191, 0.07317752510841403, 0.025581201072782278, 0.00369054899783805, 0.012789870263077319, 0.03963801411113568, 0.03292951140818851, 0.04274772992357612, 0.0058317175633939245, 0.026939353373433863, 0.0576857699613486, 0.014959196759653943, 0.021292279607483318, 0.021926039796588675, 0.024258235901860253, 0.008688791887834668, 0.029343704892588512, 0.031179274432361126, 0.03729900212160178, 0.036164637455450635, 0.03162649007780211, 0.011360486204336797, 0.01642398932017386, 0.07924265787005424, 0.00238182776125281, 0.029183414565133195, 0.04205074214509555, 0.023052465603021637, 0.009238342488450664, 0.027379785365025913, 0.05835878849029541, 0.006194849997492773, 0.12800914607942104, 0.03894536895677447, 0.011606899589034063, 0.008542230020144155, 0.04262007713051779, 0.04179334667112146, 0.04393898635836584, 0.014407276375485318, 0.03832948307639786, 0.006670578956670527, 0.007757768051565758, 0.06587488696511302, 0.06335795630833932, 0.05292193505114742, 0.03709621514592852, 0.05701896681317261, 0.02481877028809062, 0.06886155384459666, 0.08498123208326952, 0.020482717780396342, 0.042444645294121335, 0.03696670316691909, 0.019045404191794138, 0.07291681159819875, 0.031617234860147746, 0.018085363653621504, 0.02280707680620253, 0.03176082644079413, 0.07270679143922669, 0.030134778336754868, 0.020227563168321337, 0.04289876164070197, 0.05899403297475406, 0.05321550661964076, 0.08304495098335402, 0.055344311853072474, 0.03424253434474979, 0.03736120681943638, 0.018977696574958305, 0.07321594376116991, 0.015671015617304614, 0.023095998713480573, 0.0312219610703843, 0.035404528956860304, 0.021890688122117093, 0.05576997722632118, 0.03607988164627126, 0.03429011661293251, 0.049812351553035636, 0.05728877947798797, 0.03385550814813801, 0.019047436404174993, 0.017479923819856982, 0.04567640920036605, 0.03966047362025295, 0.135691139580948, 0.046602388976940086, 0.09563301729836635, 0.0593801261857152, 0.040088015142828226, 0.04995401609422905, 0.011637428575860602, 0.016435081671391214, 0.06543709617108107, 0.01736520560059164, 0.12990058958530426, 0.03336932762925114, 0.040435258831296644, 0.036306234143142185, 0.02963582778881703, 0.02538810357717531, 0.058303216472268105, 0.06178130555365767, 0.021102971729955504, 0.043543434369244745, 0.03930704169241445, 0.032716658365513594, 0.011312931077554822, 0.028822457683937888, 0.05465028587994831, 0.04708400634782655, 0.02865092403122357, 0.015609060281089373, 0.03762058022298983, 0.06023713627031871, 0.02378292042495949, 0.07958048009978873, 0.004758134791960141, 0.055737919839365144, 0.004950728899400149, 0.05063292430713773, 0.008238916385120578, 0.03337930209402527, 0.03862659659768854, 0.012491425116812544, 0.019781058288312385, 0.04398310809795346, 0.011844934762588568, 0.03420689090022019, 0.04720056848600507, 0.02550584975896137, 0.04330598782481892, 0.0158168887719512, 0.024771462826590453, 0.013498046235846621, 0.0645824202469417, 0.013489272778055497, 0.019624236971139908, 0.027473241689481905, 0.05796747734504087, 0.044981341675988266, 0.0196647302447153, 0.05157869355753064, 0.011543644858258111, 0.007011235342361033, 0.05412991398147174, 0.034706363920122385, 0.023301840793075304, 0.03833070443943143, 0.008491810627414711, 0.12453713667179857, 0.03736292690570865, 0.029813790560833046, 0.022274438690926348, 0.05065971286967397, 0.03229572577401996, 0.021651260255436813, 0.03808400607002633, 0.06115338246205023, 0.03544560746688928, 0.0382990914929126, 0.038942546251096895, 0.014071522829388934, 0.00520890808132078, 0.026741857274568508, 0.011939764272288551, 0.009826675606226283, 0.03365974061723266, 0.04293562984094024, 0.0032921868135287824, 0.026883089249687533, 0.026543826829375963, 0.05758908550654139, 0.04234690911003521, 0.03818582703492471, 0.032263977120497396, 0.037465263557221205, 0.018068646247099553, 0.027990455007446662, 0.06103585341147014, 0.036752452342105765, 0.04339191071423037, 0.06445628737232514, 0.011197016940319111, 0.030163823028228114, 0.021039257291704416, 0.031188648393643752, 0.042463651059993675, 0.02316082764549979, 0.05014161067083478, 0.035342663526535034, 0.03780369646847248, 0.021636137406208684, 0.020908783489306058, 0.010523092567122408, 0.04518680886498519, 0.01313302492988961, 0.09773214001740728, 0.011531225122910525, 0.015667385454954844, 0.03630506367023502, 0.03746418807921665, 0.0184700217630182, 0.03472380566277674, 0.018832987107868706, 0.00021522680201867064, 0.051796659361571074, 0.06337198162717478, 0.05359771861029523, 0.04409651165562017, 0.008757076259436352, 0.0032366684421763887, 0.043903800924973826, 0.05401966221896665, 0.013262285850942135, 0.024348023048202907, 0.04889223092634763, 0.05482135473617485, 0.05194178782403469, 0.029871649241873195, 0.05183221120387316, 0.002876884366352377, 0.06688736977853946, 0.0246608921526266, 0.032941976096481085, 0.11595117167702743, 0.012768085896303611, 0.01081173203419894, 0.02841547577242766, 0.09095758532306977, 0.027173300373501012, 0.07263566061322178, 0.02815462994788374, 0.031793738781873665, 0.12713264168373176, 0.04340631601267627, 0.03845176865745868, 0.018859675586489693, 0.019100375706329942, 0.007475716311351529, 0.0014448751192373622, 0.048836109294955216, 0.028860696524913822, 0.05118466487952641, 0.02016888345990862, 0.03826050320640206, 0.03674563645784344, 0.04342579336038657, 0.017344420376632894, 0.044562210594969134, 0.022693618965734328, 0.02048190014569887, 0.03162394217880709, 0.009447109053975769, 0.04909259553200432, 0.010782571991772523, 0.03192395982997758, 0.00325631775610548, 0.03478362870269588, 0.04103898197146399, 0.007750544198123472, 0.022667162885357226, 0.011597897973842919, 0.03467255930549332, 0.04399534208433969, 0.03093595856002399, 0.028393174022702233, 0.038590284796165567, 0.03908254838149462, 0.03576963168701955, 0.04188535601965018, 0.07790058345666953, 0.05905486363917589, 0.0021407340911017464, 0.027777995515082563, 0.07594889282648053, 0.0339079283710037, 0.053944724811507125, 0.04871186953304069, 0.07742614498628037, 0.015564421158550041, 0.03005154923136745, 0.051646404567041566, 0.05558705097064376, 0.03653903611536537, 0.033299553873283524, 0.06629789926643882, 0.029819137416779995, 0.04784226583849106, 0.019630632163690667, 0.04337483877316117, 0.01744559673326356, 0.052099160450909815, 0.018317487090826035, 0.052216031322521825, 0.03446861882028835, 0.03525252014930759, 0.00952207954001746, 0.03628359482224498, 0.07922046977494444, 0.017878585195701038, 0.019416727391736846, 0.026506213936954737, 0.021075353658358966, 0.040269041500453434, 0.05020159995183349, 0.04279319176982556, 0.02934205944516829, 0.021821872796863317, 0.026298633111374717, 0.10168041993996926, 0.16639296284743718, 0.1288170912968261, 0.08244310399251324, 0.11103126353451184, 0.07995984902871506, 0.14302443393639155, 0.05093720655090042, 0.18296240802322114, 0.09670164888458592, 0.15807128724242958, 0.11558660838220801, 0.08372545375355653, 0.19733338616788387, 0.14995155722967216, 0.14763061462768487, 0.26710620575717514, 0.14369832777551242, 0.19269265447344097, 0.12280438893607684, 0.1184616426804236, 0.07057010502155338, 0.12440085969865322, 0.1580396675105606, 0.19001743516751698, 0.09909961199654, 0.0981195970837559, 0.11002268908279282, 0.23351779952645302, 0.1002158292436174, 0.1505398063787392, 0.11492682807147503, 0.13728305058819906, 0.14965384320488997, 0.11147431976028851, 0.09937675283955676, 0.10233407307948385, 0.12935648592455046, 0.18539548532239028, 0.08637936705989496, 0.16511183444942745, 0.12520184314676694, 0.10535332999591317, 0.1381775633032833, 0.10422048864087888, 0.12283159819032465, 0.11175991514963762, 0.1351701875350305, 0.14871667777853353, 0.09693722267236028, 0.19214936505470956, 0.09278492762574128, 0.14088898923780235, 0.14844932141048567, 0.10568946945880141, 0.10115284539226975, 0.14455286120729788, 0.18575540743768215, 0.10633411843861852, 0.07165198839668717, 0.13010094740561076, 0.19569803534873895, 0.18133165767150267, 0.22007726931146213, 0.12481900011854512, 0.09740007854998112, 0.17196079050855978, 0.11662575762186732, 0.22400704558406556, 0.14015925196664675, 0.1767039538494178, 0.08173613157123327, 0.18751085895512784, 0.10923579880701643, 0.1104196049273014, 0.10407497680612973, 0.11780901412878718, 0.1310322910015072, 0.15099773609212466, 0.09597313297646386, 0.13391430063971452, 0.06352986994066409, 0.12979666516184807, 0.1318929719605616, 0.13174028801066534, 0.1323759803282363, 0.12405237768377576, 0.12615048938563891, 0.16306872479617596, 0.23035593490515435, 0.14367582755429403, 0.19110934729022638, 0.08476257417351007, 0.08133095117019755, 0.1215518404330526, 0.26569501576679094, 0.1645417157560587, 0.1298230601740735, 0.10593761650047132, 0.13628177717328072, 0.3090192867176873, 0.0570711325854063, 0.13907301239669323, 0.09761421063116618, 0.2051161556903805, 0.10518949093031031, 0.21150206588208675, 0.12449556961655617, 0.10322985465505294, 0.13567664607294969, 0.09300663894308464, 0.14306825372789586, 0.1417798242930855, 0.0943242928811482, 0.05349778397274869, 0.1596691964992455, 0.10743249700005565, 0.24600935780576297, 0.14910607545503549, 0.17724044434726238, 0.1307073270103761, 0.12441445754042693, 0.1663751852299486, 0.134965717792511, 0.09517532507223742, 0.12055560174797263, 0.10375392796205622, 0.21103960355477674, 0.11356836025203977, 0.13735809656126158, 0.1543424387595483, 0.14314524031111173, 0.13132088551563875, 0.16222173667379788, 0.15153110532888345, 0.1882651320525578, 0.1147786903062037, 0.2047614175826311, 0.14901724165039404, 0.12948998090411934, 0.127095064414399, 0.13221775953258785, 0.15833021620554583, 0.2250254995056561, 0.14030057724033082, 0.1784635308597769, 0.0771724543135081, 0.21649820064859732, 0.19328577550394194, 0.14649923890829086, 0.15472141413816384, 0.12251498017992292, 0.15535607508250646, 0.1397019736468792, 0.08230611455759831, 0.1045476510854704, 0.11944946753127234, 0.15896726559315408, 0.12192632390984467, 0.12656295725277492, 0.1793626169008868, 0.11928386427462101, 0.11124651519847767, 0.13161610253155231, 0.15094968224210398, 0.14829861878284387, 0.10967376602015325, 0.11825249104627542, 0.11761897004076413, 0.08430426448051419, 0.13596681478832448, 0.12594610106732163, 0.1636606516050441, 0.16140292132539408, 0.0910631992987224, 0.0950818093759673], [0.0683331446988242, 0.040229737359498224, 0.02678068813734821, 0.043599762953817844, 0.01403387007303536, 0.022972361151395098, 0.012102362466976047, 0.048993722801761966, 0.061449814055647166, 0.024845295918307135, 0.07077934486525399, 0.048805527721664736, 0.020927119201847484, 0.01938606609058167, 0.005299699883575418, 0.012271868148153382, 0.03213532009561147, 0.04954747862315603, 0.02732439655145364, 0.04553499910980463, 0.03066212557522314, 0.016005207684689333, 0.019834462386955107, 0.029766340606978962, 0.05512834772733705, 0.054712066493396244, 0.022796006507373283, 0.007867415069735475, 0.014800818204613668, 0.035018500206725936, 0.03260213861774121, 0.03648041408242924, 0.03472491167485714, 0.077925852100764, 0.0146429638178753, 0.035752827767282724, 0.07693897041359118, 0.04025956236624292, 0.02000935309167419, 0.04491556449128049, 0.06609235743858985, 0.04175591867949281, 0.023614275635087063, 0.05937857234052249, 0.025668165513447354, 0.04581848086257066, 0.019009572453796864, 0.03789808747491666, 0.049085426809532304, 0.024376273853704333, 0.059423036740294526, 0.05605024950844901, 0.016082148466791426, 0.05580364952662161, 0.02817179009850536, 0.011496619836959456, 0.023782029847747514, 0.03268026853246348, 0.041813170071691275, 0.025885359483904073, 0.017687216268054078, 0.005628399634068566, 0.046500954777002335, 0.0399633750452527, 0.036713202483952045, 0.013695906199115728, 0.05861405336431094, 0.027924637110637765, 0.042590245338422913, 0.06610270509762423, 0.021439884722765003, 0.020989556297925965, 0.046885117555835416, 0.03322329671521272, 0.03191660451037543, 0.06489637161472014, 0.01370645232964307, 0.03173717610271914, 0.10337557005030767, 0.03637685267520802, 0.009782699751667678, 0.02452115125821105, 0.02595338092318603, 0.019044506829231977, 0.034414865276111026, 0.01700906971070383, 0.12864738968866213, 0.016938644561118314, 0.014650617692885655, 0.04535805753299168, 0.028509106819650958, 0.07087111672652618, 0.06615936955703156, 0.052926243748515844, 0.006119027525918292, 0.01837470455627356, 0.05382466143263238, 0.05944141825394971, 0.0404480865358242, 0.05821605186377253, 0.029804040012615066, 0.07827227136918477, 0.09638963812696082, 0.0248713431813355, 0.04251585415165339, 0.07661837618798018, 0.036870904200311215, 0.03530832286924124, 0.022790074414972748, 0.05052049783989787, 0.06231832530881677, 0.025959830398538282, 0.043838695489934514, 0.06345529215676443, 0.04260638429384146, 0.024936789580221688, 0.05272044407735978, 0.05948434916457959, 0.032442313086773665, 0.03053770600152867, 0.03725271246262959, 0.050665225966700485, 0.11259783125881638, 0.07872429782790796, 0.036229033821395466, 0.04314206733501383, 0.11869562869625432, 0.026317967966731106, 0.014720220118761063, 0.04448370748598661, 0.06615211601768221, 0.03251618519425392, 0.025582476718617336, 0.017768425035423467, 0.01266611395736358, 0.048273831073726924, 0.025240786839276552, 0.06974519642868213, 0.01784588998582746, 0.045937275380960534, 0.0270429775451443, 0.03929947941963162, 0.044230060917990546, 0.05584073146539075, 0.022718326122100865, 0.025899873347952962, 0.030787423851766756, 0.05182012649519103, 0.06565884141517536, 0.021746669064408967, 0.05846979681934629, 0.04699845326000026, 0.05120581142338259, 0.02639869158156216, 0.04877119045704603, 0.07371414452791214, 0.042753921555621285, 0.011243278609721788, 0.04134137788787484, 0.028566388745925257, 0.028136781084218195, 0.011148971571986164, 0.015217866183125546, 0.05135887874556439, 0.03294659691995808, 0.05686763993331364, 0.010731552095551575, 0.031775849206107, 0.01835897781087884, 0.015294854462678944, 0.025672738839473044, 0.00708657647815666, 0.014539991039782763, 0.06702853220381907, 0.028987619892827103, 0.014657659190041679, 0.018895127344876528, 0.04403802872236286, 0.05145415184753282, 0.028452544140496423, 0.06204562887017216, 0.035056172470961294, 0.019678730118487562, 0.023110034210341315, 0.01234048924275807, 0.030295112768986394, 0.05975332723132201, 0.040675748605281115, 0.022597039683855007, 0.050852901967508454, 0.0362396087896611, 0.10697966987001044, 0.036309005958693366, 0.043877477158925364, 0.06072952877730131, 0.05226952363071697, 0.06528099919004099, 0.00788412569090724, 0.025614703739328042, 0.01647749011005674, 0.045856407577438016, 0.04753799716542874, 0.062120539136230946, 0.017485038277560046, 0.07650559009718043, 0.026821451128593514, 0.02612002912376608, 0.023207130875172358, 0.03380481479689479, 0.053982213871287446, 0.014381207060068846, 0.0706104574991124, 0.012541407702623733, 0.048759451801223416, 0.05026941274159721, 0.040355547929980924, 0.047529925991381915, 0.051118249871901104, 0.03314452219222273, 0.03827285593641656, 0.053636700447116575, 0.020658536381753426, 0.052879604644009044, 0.016156495548784733, 0.032533616758883, 0.01869694422930479, 0.0308678777489279, 0.026346464741176794, 0.08901107870042324, 0.021708803417693292, 0.02676259500107595, 0.048996063747576306, 0.010259220476395317, 0.038616849442145655, 0.024402916531211565, 0.05558697633179171, 0.019575170407603894, 0.006796078249213419, 0.025168315906609808, 0.0492233356593975, 0.018497012189722488, 0.027367006854287217, 0.060143871632005484, 0.08481950326157467, 0.027631377668253014, 0.05306528914453728, 0.032060640531459024, 0.016496424629752125, 0.01483929792552122, 0.03543361436043467, 0.025083373500300304, 0.04182485783738749, 0.020002533814736774, 0.027610326119299446, 0.07132889037685734, 0.051446827062006505, 0.06419982827667679, 0.03709594712459615, 0.07316130133611815, 0.0038183739691573593, 0.03259335158924971, 0.049793956468680074, 0.07808056487036602, 0.018079299246892333, 0.015002361764865262, 0.04041586969313877, 0.040479920006224086, 0.06099079868623188, 0.04517227464488574, 0.03752624689202223, 0.03185062715783715, 0.014137300862265485, 0.014767191705426999, 0.01068869327926742, 0.03887709815587316, 0.011652467456380171, 0.014166650894497122, 0.07708145598215715, 0.01910289646392422, 0.05635330360382795, 0.027183500451168845, 0.016574758104979992, 0.03582669648208788, 0.05105375511837857, 0.020829885133675168, 0.02944243173780186, 0.05932716652750969, 0.10520698356309108, 0.027277374074661305, 0.040652250937585316, 0.041730890915329964, 0.042900664931429286, 0.03214513849733131, 0.06657581363937684, 0.04585247885968004, 0.04225793281303985, 0.021773628957037414, 0.0607357102313212, 0.09785629156976938, 0.0340199307538569, 0.01963309015679572, 0.007831277142811035, 0.03693171790135758, 0.017649360799363682, 0.0379147387242743, 0.05309443900893841, 0.043392857270581384, 0.0561412715885256, 0.054385813285729716, 0.04652238291289125, 0.02252671292184719, 0.04396638899509396, 0.06695258377918176, 0.007680308190174401, 0.05046963146222489, 0.05273859488910862, 0.055651267524808645, 0.03574787446164659, 0.014457781433260866, 0.025456196262634227, 0.03397105587646365, 0.006645513873081654, 0.026325784690145935, 0.07379035758120672, 0.023583018919453025, 0.027153056281219636, 0.06957434131098644, 0.059639502981943746, 0.022974951458828788, 0.01936864640031542, 0.05071792099624872, 0.0851895355486444, 0.05119492093633328, 0.022377175678099905, 0.02883406402543187, 0.047743457569075484, 0.025151342353118316, 0.0277587743143418, 0.03241434048062988, 0.03223354482491102, 0.026246859193114296, 0.02680144113089357, 0.043470101697104316, 0.012885058548168411, 0.001395111042906397, 0.07288040819444827, 0.02836794439437134, 0.02175475380915616, 0.009423328097909689, 0.05865917594305106, 0.04320884196619902, 0.03435474368078368, 0.11622854322195053, 0.12503470640097344, 0.16376714089087077, 0.1571270650518792, 0.15606329856174334, 0.19319996796548367, 0.08431983685919217, 0.16990625432559422, 0.1960166482520955, 0.0797090692711728, 0.20014181546866894, 0.08738148864358664, 0.07540105043777398, 0.1927105677979333, 0.09956643051866974, 0.2621527915554387, 0.1125936514831015, 0.20058571307786874, 0.08917864970862865, 0.13946770264634065, 0.10726317537150212, 0.07621403717036758, 0.08129772331033434, 0.0954247477597424, 0.1378950620336192, 0.21145999671093055, 0.2739043938262122, 0.0887582226257239, 0.14040842359619482, 0.13722842851919786, 0.11324729783726589, 0.10509678947606257, 0.1681998608899968, 0.15780353732407093, 0.1117780523906861, 0.17134260439446994, 0.15926117982183183, 0.08718622662127018, 0.14183076870228561, 0.0795266247753586, 0.19276912537004265, 0.20148266851902008, 0.07948320531951529, 0.12870350453470433, 0.1290212082011359, 0.11637507964457784, 0.12204206841332571, 0.1496568423296724, 0.12099736875721387, 0.0776450607393469, 0.1172094741570098, 0.13369100833577768, 0.17959261313080788, 0.20024557704372065, 0.13479628759835446, 0.10029682596879345, 0.09737736798290696, 0.13180398887821607, 0.10373808416937079, 0.15623594501188823, 0.11276307489190783, 0.14676848160369055, 0.1298434840781348, 0.08646191084491354, 0.2133364174515009, 0.0985678101756743, 0.18238345480390958, 0.15479796645896776, 0.144013412296772, 0.1486639827489853, 0.18299113719591073, 0.15348414624375956, 0.12065994686314038, 0.10231465340725013, 0.09209925441869668, 0.1665601267346314, 0.10906219562249524, 0.10837264119514398, 0.285465056342738, 0.10837464965879917, 0.1260690109005996, 0.12764725621257508, 0.15316174711499894, 0.1472182281847511, 0.07528168255729334, 0.19651904915060314, 0.23373199946113996, 0.07207930939538137, 0.11041707399168185, 0.1440664873059307, 0.13329478459698813, 0.24350094954882348, 0.09772726813597338, 0.07031258741127593, 0.14162663822727545, 0.09404341331017868, 0.1183015898402248, 0.09196584764868021, 0.18265463810946259, 0.11217083595693111, 0.1464604674173253, 0.2572124052260603, 0.2253904834921871, 0.15472487466675894, 0.09379603979843003, 0.13340738069798264, 0.12043281405099801, 0.13071838713118009, 0.05333075579255819, 0.16346237010189466, 0.14756342609013828, 0.2930040418037346, 0.07450283970683813, 0.24205927976540156, 0.1314332644854273, 0.09649704343506268, 0.17027733155659266, 0.1955491647656475, 0.11605501467628138, 0.10724689731640474, 0.11511466013533728, 0.18586223599101814, 0.24716398013489588, 0.1511566625641925, 0.1437137983739376, 0.10534169312034335, 0.23252206295728683, 0.07289014517196588, 0.10972080885299615, 0.18340710630374296, 0.24302233808806964, 0.07081287128052541, 0.10588671280337231, 0.09555543360433408, 0.08283376374414989, 0.14434799791446754, 0.12017111666500568, 0.12661168963781425, 0.08494282021586384, 0.12520984985998698, 0.09160776436328888, 0.12581666372716427, 0.1219801724489246, 0.09504692589065858, 0.06167973564671619, 0.10574850200542382, 0.1149516895945583, 0.22091076815766947, 0.12842130182044847, 0.05669888148882559, 0.12720319575497083, 0.12234830483794212, 0.0686462139710784, 0.11482977042240755, 0.1417748031339475, 0.18807184456714562, 0.13353877221899374, 0.11989861700151648, 0.10504948879991259, 0.10339460974293095, 0.07247503101825714, 0.13755355535873345, 0.11812358296343259, 0.09390139593077557, 0.07546995566891772, 0.09689805763108389, 0.09733967536262103, 0.10775799703385149, 0.06111575090991599, 0.1510468620274748, 0.13752413408032485, 0.1014607170862811, 0.10084230705563511, 0.14134443551301956, 0.13902983042810643, 0.1008890988305211], [0.01943117509862142, 0.05068909004330635, 0.02491936819361789, 0.06614013308925287, 0.02723469931100096, 0.003332602691703609, 0.03579836764505931, 0.04595347201185567, 0.02989232081121632, 0.019896093722698942, 0.0158467324384089, 0.04274150775745511, 0.03314498020336032, 0.039909411155219586, 0.029121182725897858, 0.0230447286074715, 0.04097109115017312, 0.07138782792857715, 0.13676580334348337, 0.018008768924378922, 0.04310190484726003, 0.02441658392282469, 0.033755285133208544, 0.044544219238949675, 0.03525284245344145, 0.017071535644520606, 0.009898717365493732, 0.0551126091075795, 0.012464893549414617, 0.018548716558143497, 0.010079116926395466, 0.008051373546810021, 0.0055833262491172975, 0.017921899478616457, 0.023059809048260962, 0.05756087202046599, 0.03065148614613073, 0.022939547197893262, 0.055947149505040476, 0.03733761415683797, 0.010094165136771542, 0.050017068960836956, 0.03744921959670527, 0.05503229770277228, 0.02351480409769075, 0.02500001886593444, 0.01239536830689758, 0.04903163594592895, 0.07772681742374386, 0.015216297070894922, 0.05747696438005992, 0.016604837562356676, 0.03466147882863879, 0.018173471425793, 0.007877217356248625, 0.012068040469395263, 0.017095343741987432, 0.02345814642363361, 0.06667862526540246, 0.026941833418927023, 0.019043831686888422, 0.02951221227911966, 0.02648722513445786, 0.044349428798471174, 0.01642933108710817, 0.05227861260729177, 0.06276845865483795, 0.031313593831977675, 0.015384721336886287, 0.06474484795970575, 0.020945919710876684, 0.05026538563626153, 0.03198843762012465, 0.023580242014889206, 0.035803561830627065, 0.014920208137482405, 0.06852544152310916, 0.02859731637207525, 0.02154526799651129, 0.05836614380989756, 0.03942481840827635, 0.013331932381593754, 0.03320970905146428, 0.03658753101314817, 0.04434205651549356, 0.0409738120755979, 0.0067031032605362785, 0.007328696432523429, 0.026847681596076915, 0.019427580559360128, 0.01507351633959583, 0.1032890093379787, 0.007092593811518911, 0.051832767602588446, 0.03976258635520935, 0.06037206295877695, 0.021299260036487664, 0.02523555194160768, 0.03891700280031987, 0.05020030734262296, 0.03425832385463374, 0.05355238907837442, 0.04471921681293419, 0.04934232695294278, 0.013314488094433077, 0.048997125654880486, 0.03370746877044439, 0.06967585693512644, 0.036811603632356436, 0.04246071639603802, 0.0065293893899901635, 0.019061879022046924, 0.017331718201083795, 0.07548915820994548, 0.04272783527682934, 0.056600561764623435, 0.07552004512399435, 0.005907729600689241, 0.029500809498131275, 0.03253215451591781, 0.04688029656452792, 0.05150894694296377, 0.060578826149659495, 0.062438887410930226, 0.03294975210779479, 0.0529667319330786, 0.05781612332378115, 0.04724500574437635, 0.01581660209090582, 0.007208629660973591, 0.023189259959118705, 0.01569519012368151, 0.06081906147301197, 0.050860664408121786, 0.0025940701224109425, 0.04127391454364572, 0.03997824853286147, 0.03340837053422417, 0.028029078917045678, 0.11751955108983175, 0.07317705691925117, 0.050206892524978945, 0.0045131997654347545, 0.027579646158431257, 0.0671391130558082, 0.05711237394383975, 0.04464933788403869, 0.03808976683233466, 0.013258626850854074, 0.01738128688053361, 0.0505451320537499, 0.008352305523918142, 0.022260554168107252, 0.05903680782232966, 0.030175147777689353, 0.05235698000927057, 0.036216864295836, 0.029805179951446395, 0.07776549391980682, 0.04863034015787499, 0.04828727963779654, 0.207056548712509, 0.012762772967107594, 0.01727194435495351, 0.017894400150648186, 0.02456293544465942, 0.04790009737813047, 0.013330805165294026, 0.038636472674884965, 0.054573597852140665, 0.02214921166055969, 0.0859793842371021, 0.03469193487295082, 0.016719301330990026, 0.004939374039947454, 0.03813421426873122, 0.011517097175653492, 0.06211111428482192, 0.015017835755965539, 0.0535337225800114, 0.06278791903917279, 0.02658134642323213, 0.07773838644581181, 0.027252010435664227, 0.02091349252233548, 0.05620973916458232, 0.025470284345958914, 0.010032258994345154, 0.020934177662378976, 0.03676538861223629, 0.06441190439675536, 0.06058325698333127, 0.021412305666932037, 0.02490937676546829, 0.03733717989442604, 0.04376103376437511, 0.031615005872611485, 0.012768035006177212, 0.01628633152826556, 0.03887418724064316, 0.035271478417728624, 0.041745957785419056, 0.0529759634020073, 0.031061477360448668, 0.01379854479871158, 0.0747126495199544, 0.039366817234882286, 0.04844432317518762, 0.03988165907295687, 0.031051204340266328, 0.026265997273315276, 0.050196510939193625, 0.018665545021316836, 0.012179171782918274, 0.04683797972808991, 0.030160433745809963, 0.0811341285173382, 0.0054325858779650715, 0.01840707067666309, 0.03938414023390838, 0.04782478677641068, 0.04572531800451023, 0.03087460881631289, 0.02537597985272961, 0.07039344164409808, 0.052542220069361587, 0.03192531690001488, 0.00860638720249491, 0.04432630093236055, 0.03621331895036357, 0.03911464648055179, 0.03756119483815772, 0.038522712886333466, 0.0460938744779144, 0.0518017653375864, 0.04332265943022711, 0.051337857730686665, 0.013170365560134607, 0.044395752384194305, 0.05030773639945047, 0.04000536957755685, 0.06323704136801617, 0.05483208916016987, 0.05832507887056895, 0.023392662705321397, 0.02766942821576127, 0.027388389189062372, 0.013634369010105729, 0.02932731487921306, 0.043673227940286906, 0.015681461663916707, 0.046392640231975486, 0.06293047924659081, 0.01783603596101914, 0.07396001847726957, 0.03256959607824683, 0.05874193685927561, 0.01701182117020445, 0.026993963568072234, 0.06803750699119908, 0.021023839279743176, 0.007722624178443636, 0.06417204226766314, 0.024868472978206616, 0.02082495896943978, 0.019951782788016965, 0.02836332526723189, 0.0729326961029853, 0.02891547465696931, 0.030775250933532203, 0.011632531249363507, 0.07585092594048806, 0.03525003671113934, 0.03093599248677492, 0.026518515776842833, 0.02675317014966692, 0.031549571348088126, 0.04322864501071828, 0.010553463794557112, 0.02875974408483931, 0.013966505964552718, 0.02043809392489493, 0.02380168191822512, 0.050183299862380536, 0.019917862822434733, 0.04477038174601538, 0.047553912204291136, 0.06310287463877882, 0.010574089562786477, 0.17799068694668158, 0.018685712778408612, 0.031542796175926924, 0.05186037379982216, 0.022777119485129203, 0.020420820119657686, 0.018982610864830867, 0.04452686231317265, 0.07357824753437724, 0.016979417730388895, 0.04230797477066517, 0.0416820771060884, 0.0212671873824937, 0.020646390604919622, 0.06274977858577456, 0.03090063063427806, 0.018596468460080878, 0.056643119480993064, 0.1073680090318833, 0.05267458528812442, 0.02061060636437365, 0.031098267529159784, 0.09290832600423268, 0.024869302487266914, 0.03872876022277134, 0.020055527399693216, 0.06468701642006636, 0.01129380741622299, 0.04271245628063168, 0.04081450901659472, 0.042097564454057386, 0.06430028538618769, 0.026384225214964578, 0.0650261617930872, 0.02334634929762355, 0.014541675502966558, 0.03570060771224754, 0.044766140902148824, 0.04471023979463747, 0.020998377253168395, 0.01916961172329528, 0.05819613007562501, 0.09801315529538052, 0.021400763786264827, 0.04200158228299447, 0.052969493570604494, 0.046855051669159105, 0.0679045073421938, 0.08170294442347117, 0.039022094304008145, 0.013435858501387494, 0.020331848911674957, 0.014668620923267943, 0.06353805985833917, 0.00904694726757173, 0.005071990740751582, 0.03183531940781644, 0.05709992961159774, 0.03856855810486844, 0.027639369114435146, 0.027014058382649506, 0.013602188638677555, 0.036372615224016566, 0.10581501200795174, 0.1907358273331608, 0.0732515872056995, 0.13466577817286762, 0.134337774344853, 0.14020437454538687, 0.22595347756786005, 0.08662957684802157, 0.07932006514498166, 0.10024954564869404, 0.09193757309445313, 0.10922740532883576, 0.08951472810336522, 0.11821574158966541, 0.16732247439878328, 0.12793008317904814, 0.10305543722850935, 0.12120528545762811, 0.2667296188218253, 0.17191220740122454, 0.0535945193176823, 0.1269527349088873, 0.11459148249455861, 0.10751989231045757, 0.1256285873906953, 0.06916669782783304, 0.09855604437845093, 0.26518755299704416, 0.09760891127267055, 0.15449242214007036, 0.10618089844605752, 0.08426281956157514, 0.10209993100059883, 0.1087843966005104, 0.1470139077199357, 0.1254057836319719, 0.1555557000849928, 0.11013618085001196, 0.14695914994393075, 0.08381030455763851, 0.16095940369580472, 0.09783697367778846, 0.1763891950249672, 0.07801702685121979, 0.11772577145269938, 0.11407669154661042, 0.17655657604336739, 0.16146499370890005, 0.20046178544206278, 0.13637082810912812, 0.19415453102971825, 0.09509656072727271, 0.06810387450137309, 0.11934101049389158, 0.10287700966000557, 0.10168832487293653, 0.11775741832596914, 0.16187390605253832, 0.1507016234099865, 0.1864538506737777, 0.12718925864568778, 0.08870161923446826, 0.14857432113162108, 0.10549421422183514, 0.11863430270126887, 0.1000177241595728, 0.12948168920619146, 0.18624788815421717, 0.0737990021173443, 0.14137118336345467, 0.13326095284095832, 0.20240449905395508, 0.16522263921797276, 0.1460115893610886, 0.10875057841518096, 0.08197710649775607, 0.12478073074349336, 0.10851155088416167, 0.16290656849741936, 0.17234585913164274, 0.10001053168837513, 0.08123356103897095, 0.09969774061547858, 0.1288407721689769, 0.07487923665238277, 0.08756015369934694, 0.08700909505465201, 0.2031841900731836, 0.14695198461413383, 0.1275094321795872, 0.06985467126859085, 0.31188362730400904, 0.1359365385557924, 0.13891857782644884, 0.09202675295195409, 0.18539239120270523, 0.15317682416311332, 0.1260926646313497, 0.15274431237152644, 0.13903987274638244, 0.08997314636196409, 0.13687750377825328, 0.1154265148299081, 0.127426501629608, 0.08294927754572459, 0.10212659064148154, 0.10323676214154277, 0.14538417517074517, 0.12442288494535855, 0.099733777610319, 0.14556923881173134, 0.20869831847293036, 0.10557262572859015, 0.386645891304527, 0.11210234463214874, 0.14555948147816317, 0.15868397722286837, 0.1106175539482917, 0.15693698025175504, 0.20698621177247592, 0.1669590917548963, 0.15075422344463213, 0.1675299025539841, 0.10754555450486285, 0.1222960576415062, 0.08602482572730098, 0.25091847724148203, 0.12212330262575831, 0.10290495851742369, 0.12583347782492638, 0.09615327723856483, 0.11819370277225971, 0.2076690758445433, 0.18185782086636337, 0.09501726712499346, 0.10254376754164696, 0.10240662204367773, 0.08117754118783133, 0.06620114695812974, 0.17945271278066294, 0.17072021136326448, 0.13217072348509515, 0.14616709601666245, 0.12535630485841207, 0.13768270771418298, 0.11285439892006771, 0.15052303299307823, 0.1741033869662455, 0.08647025004029274, 0.07194552264575448, 0.21508595214358397, 0.12450379346098218, 0.05337813789291041, 0.23471666233880178, 0.19110218196042947, 0.15826384191002163, 0.10610736560608659, 0.13045443700892584, 0.13452682777174882, 0.11762023211589881, 0.13685980758496694, 0.2456782598580633, 0.0517924795858562, 0.05393531692347356, 0.14397367728607996, 0.07370870267706257, 0.09295019161488328, 0.08059327503932373, 0.0941382928618363, 0.1768589448183775, 0.09517463975186859, 0.15977895632386208, 0.1514384038746357, 0.13548547561679566, 0.08194448931940965, 0.080193224363029], [0.007037871658602464, 0.026818306118782078, 0.038676523204360685, 0.02935437485575676, 0.0496528211848012, 0.01942061200471861, 0.0292874848736184, 0.07034882796662194, 0.004183785008665706, 0.0364188336368118, 0.023934630677103996, 0.034405430246676715, 0.05786323401012591, 0.01710893479841096, 0.05002776945808104, 0.09214268744524036, 0.017218888005507842, 0.011413340689614415, 0.02716545481234789, 0.021953325386026075, 0.05312302229659898, 0.02645255538768002, 0.04429602130715336, 0.0377103605839823, 0.030873892961868217, 0.027607388062668697, 0.02681855039138879, 0.03544347347425563, 0.05394742198820625, 0.042339112742670944, 0.062304652828191004, 0.06520838915769543, 0.009102436165059251, 0.013886663597077131, 0.011313109192997217, 0.03667953018365162, 0.05963558104953595, 0.01607206543641431, 0.013075177275043513, 0.0277952218228685, 0.052536248961197476, 0.017680855002254248, 0.06456952808158738, 0.007918288232758641, 0.053125719473298104, 0.01725576468743384, 0.037176441733858416, 0.037501388761614046, 0.07302239164710045, 0.012429749676292496, 0.013260901639504092, 0.07992831072104828, 0.010008084487968257, 0.04109717992001346, 0.03517366759479046, 0.0431787794721978, 0.06970744952559471, 0.04385810837681804, 0.011632698338611849, 0.03181204226400171, 0.049098912693027935, 0.02952627491738115, 0.052185344576303444, 0.04139147073562656, 0.03629082800554378, 0.031224352906325033, 0.006396645039785653, 0.05377002240025571, 0.03736543409260256, 0.09067773033997842, 0.020647527151075856, 0.08478899632713624, 0.04903404813792024, 0.03641779887090836, 0.04122771987957614, 0.004914440422518445, 0.020483776295025433, 0.027806741651147604, 0.024079988145136406, 0.046802298964134285, 0.029055361436413865, 0.04641896739069905, 0.019094494504055808, 0.023280801118484566, 0.051628552310700924, 0.02303346662249948, 0.023560518698234643, 0.01950490301741021, 0.010671877485167767, 0.02920237961890442, 0.04854224595640387, 0.018997233294482743, 0.032407578879169056, 0.01885678163463516, 0.03588139997529132, 0.03890586804066386, 0.0274735215851771, 0.019881690120590583, 0.008539028183024908, 0.024088978734133498, 0.007881805101143462, 0.03993654577061534, 0.043459231566105566, 0.012008333628598069, 0.024722920431356345, 0.026486831584147046, 0.03851285037983741, 0.017456158130828823, 0.0649902265784996, 0.013892552432870226, 0.026291169226169586, 0.039382440503686666, 0.029201948749167577, 0.035935601352580955, 0.0072023175889626145, 0.03993675272379603, 0.017307431736428822, 0.044607577446315966, 0.013701247117881264, 0.042485985040132485, 0.04912210841264043, 0.04872479562514594, 0.023479633931336657, 0.04788360558450222, 0.0369367288824703, 0.06947065437478678, 0.023642523047913398, 0.01061335383980934, 0.014457876428163477, 0.04817432052056704, 0.016043176807995354, 0.027978561984907304, 0.016297600298587765, 0.02280316505182002, 0.009090264094993472, 0.0786911038947957, 0.06540366475071226, 0.029757808029119457, 0.033392794762871096, 0.11126125976443291, 0.024282627539443116, 0.027337504151676382, 0.02810862866629447, 0.05183467428599085, 0.0717625692486763, 0.03458058049104043, 0.06741115810083491, 0.010909182385408452, 0.03442070746262159, 0.03409879009372421, 0.07052804942109756, 0.008719709335959383, 0.07939074813787426, 0.07855935275022473, 0.035267458097743135, 0.007764152217922466, 0.025022273118208562, 0.04923900981832828, 0.03188657933580024, 0.011790037038736045, 0.0872929466090032, 0.0024510595373742816, 0.02136577682436577, 0.05168973920600755, 0.04947272102747645, 0.06265061747814928, 0.09079020430466958, 0.02474478961500738, 0.02071177593565413, 0.022805151463087116, 0.11573960445821285, 0.04236093782154577, 0.07070272469094821, 0.08252374787947961, 0.007568148047929364, 0.017241104938355938, 0.032988445567233224, 0.01957311953551003, 0.03298811987042427, 0.025631889335012863, 0.027343651678945338, 0.019963472250050733, 0.005235997743771544, 0.05154806109411376, 0.009053961623327007, 0.016113696952483485, 0.023513913520478776, 0.03132817215685334, 0.01995202197161104, 0.04728003511471408, 0.05976159857319934, 0.06259334233722516, 0.04628433586497392, 0.03070495809827532, 0.06431951506861619, 0.002912915211969188, 0.03104272943788341, 0.0032806286056126866, 0.022206220476488982, 0.1220995131880045, 0.05128030099772981, 0.003852297327414687, 0.07358738061572824, 0.016476748810548867, 0.06539757829159498, 0.06319818845284836, 0.08780492842197418, 0.0879814357363752, 0.01179472656388368, 0.051805358180510144, 0.029639267961361578, 0.054968830929802995, 0.008896271781330662, 0.019708499146093215, 0.035558213745909076, 0.03214426997250744, 0.035141708595412116, 0.041123086387025456, 0.10230028203555516, 0.08086329804999487, 0.06090784778020211, 0.020337409506152784, 0.05236713428582464, 0.02659473561548761, 0.06497546844184399, 0.014808400833447064, 0.12794604232268675, 0.05128588194825819, 0.05178898852318525, 0.0382246901281178, 0.007027902282840971, 0.04473128116556576, 0.06336943033550467, 0.07529198271887642, 0.04215569794178009, 0.0585252670571208, 0.027627525285684636, 0.021853056569982852, 0.022489515632124882, 0.08183062435793025, 0.010797894160662378, 0.037476377960826666, 0.024309889380154864, 0.03045792385403599, 0.010393947845191827, 0.04213321468393717, 0.01038125075865537, 0.00970008217596582, 0.04956760057913406, 0.04966411540018661, 0.050111666920461824, 0.007036495504767767, 0.06643425766378641, 0.031345583365431855, 0.010127392148465982, 0.07026195512818438, 0.010113911353982985, 0.056007087895912785, 0.011424303271009453, 0.061241754862879, 0.058385997744543214, 0.03337871516123414, 0.03602647754762854, 0.05141655082947441, 0.070990199622299, 0.023958569392561913, 0.05104458811027663, 0.04349922102742961, 0.025101575202175548, 0.02194930676237813, 0.07182137787874256, 0.012654795993252524, 0.02812245042462434, 0.0519499166735581, 0.027093299398464814, 0.013203037021282529, 0.046893928333052566, 0.04186781249674303, 0.018656944589955465, 0.03838607289695314, 0.041669547956969054, 0.06534953122692448, 0.05466047747592841, 0.040903176580156596, 0.02251595814180161, 0.04599514084735087, 0.02356658480130136, 0.022743798326700926, 0.008662355315339352, 0.033560206315347126, 0.032252767721989324, 0.05634669128007122, 0.05383769948301571, 0.01743287080898881, 0.039460275255675824, 0.05878439958074263, 0.0563478583603033, 0.02388241231840636, 0.0616978525317141, 0.038135255819984844, 0.04010435087340219, 0.04798806944329824, 0.04699759491320167, 0.02888545287506921, 0.03198462086064475, 0.04559628439268895, 0.025364594035116688, 0.06083014873521669, 0.04067319731361099, 0.02726147260649928, 0.01953526915583227, 0.02466095830979092, 0.051604474495564184, 0.03786912760032075, 0.02339320214066122, 0.03324447040046964, 0.006094722825634692, 0.06114990836275475, 0.038695607001760175, 0.0211960497711386, 0.032915896603039334, 0.041854231618344784, 0.013027527153358927, 0.024479080390717303, 0.023537334852984974, 0.015720670809969306, 0.023978128164474453, 0.030793713871389627, 0.05326748240206923, 0.018643453617447188, 0.06901315892381327, 0.03650570647524936, 0.009658627927170267, 0.024950967569436346, 0.012552330420086426, 0.008611291314342191, 0.0713883029030902, 0.018990067964685813, 0.050971618454371176, 0.01650595974310168, 0.012888720092762793, 0.024553354530196105, 0.042268592598182816, 0.0424534967834396, 0.0625213836984975, 0.050000058087919436, 0.030900111554988792, 0.013910276615726096, 0.05722742634160178, 0.06762492377310991, 0.016552196815609932, 0.06283604074269533, 0.11308568436652422, 0.1798631857548441, 0.13288121750312193, 0.12145518990499632, 0.08838233458144323, 0.10170177343700613, 0.07406124911670174, 0.16941028593906335, 0.05054921683456216, 0.09628651437482663, 0.11073513049632311, 0.13614303033266748, 0.12301180352057729, 0.11514705339712755, 0.10061739305300371, 0.15760338306427002, 0.11353720192398344, 0.08471151441335678, 0.1176671731684889, 0.08296594915113278, 0.12464780573334013, 0.08201098575123719, 0.14978021356676305, 0.1732630349163498, 0.21773613350731985, 0.09819983384971108, 0.07092190507267203, 0.11412329333169119, 0.17650040691452368, 0.10475445498845407, 0.21830363305551664, 0.2254715005734137, 0.07109131491077797, 0.16945956115211758, 0.0926882296002337, 0.188748886808753, 0.2423659504524299, 0.1226863374135324, 0.11375652479806117, 0.1516914702951908, 0.13544747765575135, 0.13225490253950867, 0.16438909965966428, 0.1296654636306422, 0.10160394904336759, 0.12801161594688892, 0.12357985946748938, 0.04753845178389123, 0.13772784386362347, 0.10697770890380655, 0.2925257831811905, 0.1332584015492882, 0.09839458697076355, 0.15414968053145067, 0.10149266251495906, 0.11452651955187321, 0.15889145966087068, 0.17287339296724114, 0.16730320400425366, 0.1477097725229604, 0.1408797747322491, 0.11279360896774701, 0.13303350790270738, 0.1362625474908522, 0.1257928471480097, 0.12201489987117903, 0.1466826062117304, 0.11180485452392272, 0.1603851459388222, 0.16184985877147742, 0.12835553820644105, 0.15406024961599282, 0.12089058091597897, 0.13674376452607767, 0.10423462931066751, 0.13409913357879433, 0.11421887177441802, 0.09616637974977493, 0.11094660950558526, 0.19349568709731102, 0.12876044719346932, 0.13908905296453408, 0.08245163996304784, 0.1510914010660989, 0.17777179154966558, 0.09140902824167695, 0.1359186116605997, 0.14715987417314733, 0.1458926693137203, 0.13113670397017682, 0.12266747414001397, 0.12013881839811802, 0.14149312967700617, 0.10449231655469962, 0.1679006540881736, 0.11447189748287201, 0.14573153081749166, 0.10936462546565703, 0.1642722152173519, 0.08597691436963421, 0.13221321334796293, 0.1349408155573266, 0.10942113386201006, 0.1963703278452158, 0.1886361957128559, 0.17329495320362703, 0.11447090682174478, 0.1459313322390829, 0.15027000728462422, 0.17263152237449372, 0.09464877511241607, 0.1296773651348693, 0.10522981626646859, 0.1605383048632315, 0.14234736455338343, 0.19615489297679492, 0.11565732530185155, 0.1391259788402489, 0.16903394327632018, 0.11545540685100214, 0.145250924463783, 0.1029229329100677, 0.2139782708670412, 0.16292248692895683, 0.08295311805393014, 0.2050044552556106, 0.09782417650733675, 0.13663988081472261, 0.08609323562788111, 0.10165853040026766, 0.11241164124969925, 0.10060912171112639, 0.16351943489696297, 0.24998760862009867, 0.1007482281752995, 0.17205163277685642, 0.14994032068976335, 0.15471590443381242, 0.1557932280536209, 0.1986632062388318, 0.1299598664045334, 0.1588714700192213, 0.10011927371046372, 0.16540513799658843, 0.21927496950541223, 0.1195173617452383, 0.15610293857753277, 0.07576804967331034, 0.09633115519370351, 0.0915548386318343, 0.1268031857907772, 0.10890119283327035, 0.2049026478614126, 0.1291382826332535, 0.1751632315239736, 0.08250193976398025, 0.09888812620192766, 0.1065854410241757, 0.18798565704907688, 0.10448949384902205, 0.15884317510894366, 0.10749277126576219, 0.13984343462756701, 0.15140976969684872, 0.11488303542137146, 0.17714804144842283, 0.13684692899031298, 0.18094046866255148, 0.11160947715065309, 0.12543447209256037, 0.19431503170302936, 0.1330459929470505, 0.10199705152107136, 0.176382966073496, 0.11542935110628605, 0.1306571289896965], [0.04076177327494536, 0.032113098073750734, 0.05012303916737437, 0.04097092490909355, 0.007315235145922218, 0.07649618560182196, 0.022361316618376544, 0.006718537387704211, 0.013882316732113915, 0.04446404014847108, 0.024951154166566472, 0.022677642858720252, 0.009068081088896309, 0.04027705839169877, 0.08599562158009835, 0.03909451434654849, 0.02103341171251876, 0.02490109185289059, 0.037379937778626166, 0.026823753058644276, 0.020519048241632323, 0.026219086754801016, 0.031008534665618624, 0.009751290365654443, 0.09765163183744464, 0.026802871143445373, 0.06851454425070967, 0.04133925746594157, 0.03766719897144607, 0.01933736932863082, 0.050761007969932895, 0.0266682379213827, 0.04952765182991113, 0.010217440530790814, 0.04036777173834188, 0.04432919827689018, 0.04144388756581715, 0.022076367533632686, 0.06230178262506213, 0.04969957564026117, 0.06073570344597101, 0.058361753688326905, 0.01948354103868561, 0.01326691176343177, 0.036767247798187394, 0.026567833398335745, 0.044017523394099305, 0.053405737304793935, 0.04779035790956446, 0.04347394899066005, 0.029119533885802542, 0.05267258021714432, 0.026217527820595672, 0.029886824677565267, 0.022829034199405993, 0.024759724170767834, 0.0365652750645365, 0.03207335967038359, 0.0255719271954149, 0.03466257466269391, 0.03766149588461433, 0.034690340315657, 0.05136824592149683, 0.10889818692313773, 0.031758760301662345, 0.014027896420364934, 0.053040230846298594, 0.02963592278371964, 0.016958754642733505, 0.056823348559971364, 0.02641332588557686, 0.03838982519560626, 0.06058284307696989, 0.041579998297882934, 0.023868634664852704, 0.034980149407471926, 0.0236573066296322, 0.0307434242484825, 0.02423787645862571, 0.09614336384194237, 0.0723659090165581, 0.10336710193327495, 0.025908341464985694, 0.10364476524825607, 0.029700461642018387, 0.01846663248060005, 0.028937370982021093, 0.015964673699012825, 0.06782904067741972, 0.009945081663317978, 0.05198712074863059, 0.04062930288325463, 0.04731311369687319, 0.03030844937477793, 0.056265324753309996, 0.03504338547853487, 0.07791167071887425, 0.09999198054096528, 0.03526652850476759, 0.12441358901560307, 0.041503822564014366, 0.02979245063449655, 0.011744475956740124, 0.03664630910913859, 0.07193873729556799, 0.03380467908989106, 0.04805108159780502, 0.06615903028952223, 0.06611237422163997, 0.050298878124782016, 0.02388569982057171, 0.049434119170265536, 0.020340398452909927, 0.015980120548712354, 0.039026579420481405, 0.012321865152833717, 0.08898455476654427, 0.055422251777989526, 0.02759436358298574, 0.07779610263449804, 0.042077337325151475, 0.054764242443655214, 0.029781363372291838, 0.019582664826884866, 0.027732318233964697, 0.02826776887689318, 0.036771661668483696, 0.10597585873412234, 0.03000801781724606, 0.017618378890412192, 0.019850674284888164, 0.037262605503201485, 0.05927177092858723, 0.055415513925254345, 0.07715261394956283, 0.04446130904502102, 0.00500760497691642, 0.030529285381947244, 0.005475516788594956, 0.022548258105026822, 0.053773937547313314, 0.03876632052872862, 0.037444459673549445, 0.046548041714621444, 0.039488526061177254, 0.006728617449490619, 0.029987939966044257, 0.0452284743078053, 0.013601118249685636, 0.04393010094229664, 0.010052498845782663, 0.03581027593463659, 0.0337750372876014, 0.04746608602415238, 0.03850786314745035, 0.05407955311238766, 0.03621135459148458, 0.06411458392228399, 0.1092867771429675, 0.07304263234670673, 0.01263039926665702, 0.029184853059372733, 0.0405645570717752, 0.0371350816317967, 0.04066624232966985, 0.027399057455893074, 0.05829833780548402, 0.04863207720752273, 0.0335017335601151, 0.03980938491544553, 0.022760459754083837, 0.0017777797724452934, 0.024315049638971686, 0.03163115500605532, 0.032470282300242355, 0.05213052233947175, 0.044604663138410876, 0.03622358857787081, 0.02751437108963728, 0.07002081056790692, 0.03210856545982616, 0.035466377423810105, 0.01865545690192708, 0.022807183675467968, 0.03508331047903214, 0.028889686933585575, 0.01688446693255433, 0.05112667049148253, 0.06856780924967357, 0.0057601338152640635, 0.0904996691803847, 0.019945718381287794, 0.025968006745512997, 0.03980301347162042, 0.047956928078617365, 0.009180309932811983, 0.022039268631488085, 0.031051211125616516, 0.05318333048905645, 0.04382281777049814, 0.043723602380071364, 0.02999279827677778, 0.018975723734391586, 0.018407823850533793, 0.03942135448700615, 0.04422454782096403, 0.021661845401727726, 0.014503190693046366, 0.044998790203992806, 0.012018580355548432, 0.03232684678265026, 0.08495300502649375, 0.06241554580628872, 0.02315292610520763, 0.05981605779379606, 0.003365453752589279, 0.033209888863244226, 0.04749671170221908, 0.052099723634975295, 0.01324784238490143, 0.021788232726976275, 0.03909177306507315, 0.06837013164269072, 0.0408180306133415, 0.033220287412405014, 0.030987835954874754, 0.01720784484807934, 0.01988745597191155, 0.019026254237230335, 0.041217168660036156, 0.02632033096493355, 0.045241580211690495, 0.027455576030271392, 0.06038854457437992, 0.047674124860869985, 0.04797757250655975, 0.016344709288594977, 0.04037335608154535, 0.018537366363619055, 0.04866069781460932, 0.02534025498399777, 0.011880561243742704, 0.03327930299565196, 0.009093040151388516, 0.03129880855392132, 0.013860589192648019, 0.01462932865667556, 0.006422601124670888, 0.051314322743564844, 0.06408632972410747, 0.01962676621042192, 0.07932402100414038, 0.09204744827002287, 0.05486215165417109, 0.043689600990286896, 0.010227327634181296, 0.041415205890578885, 0.031362214258738925, 0.012064361113256641, 0.07038206939718553, 0.03786594866375838, 0.00823068999618824, 0.10487126479191439, 0.052855923771858215, 0.06005323292421443, 0.011990939383395016, 0.03505691207413163, 0.0547293080682201, 0.012981489400512405, 0.03442100601802979, 0.01180907164234668, 0.037178121108029566, 0.03374513424932957, 0.04898173987333264, 0.015069180500826665, 0.0741808002016374, 0.04538966030148523, 0.013233381107316484, 0.039095891772636344, 0.024627962848171592, 0.043507967343819995, 0.003347947761150343, 0.04814029198938182, 0.038928032387048006, 0.016051909553685358, 0.014425578161275812, 0.01367553572968713, 0.018671373637127023, 0.03243347177548068, 0.02010541668693934, 0.013127548304120345, 0.020256249932572246, 0.011653468295532678, 0.05156966225643243, 0.05161216908267566, 0.04617848779473986, 0.013569298349986119, 0.01609788539021143, 0.02064681808198137, 0.0229713060294411, 0.031153432426175902, 0.02464381681888231, 0.024673204170539975, 0.009416224684433212, 0.04393787695361035, 0.04887766956484743, 0.04954342098374452, 0.036596389287816625, 0.07732650211879186, 0.04599499835499695, 0.04860277806541749, 0.02596183546951839, 0.0374829902845834, 0.035472962606166086, 0.03253512649929949, 0.029347704856523445, 0.04001022110294018, 0.04441530776343175, 0.0456637850563441, 0.021640378250075237, 0.05289067494283829, 0.044350670517555306, 0.05208597651549748, 0.04098645318299532, 0.0383664123447878, 0.07621002702840737, 0.04475844292236226, 0.00798165492181267, 0.028274915546977093, 0.03797889081761241, 0.011119267853376056, 0.01525826785447342, 0.03420985609825168, 0.009345880110881158, 0.02097327315381595, 0.0500698114878365, 0.007205537237626101, 0.029297086144132272, 0.01823484831090484, 0.01245205566686179, 0.020813807246408293, 0.029383860594992126, 0.035862682586801906, 0.031750451640358994, 0.03557534675512995, 0.015194711175614169, 0.028800849736269032, 0.02301472718162196, 0.07362943621618406, 0.007138680334069899, 0.002091811292172809, 0.04005731821858457, 0.1259634987051998, 0.0802996050832527, 0.21343773630048546, 0.1497224566659757, 0.1508439393447978, 0.18774597133908952, 0.10059907260750021, 0.09709234934832368, 0.13364798921559537, 0.15136805336390222, 0.11127250308969192, 0.18739326883639607, 0.16341886243649892, 0.12480183318257332, 0.15271878588412488, 0.15447898714670114, 0.14533549706850732, 0.09128834400326014, 0.09302405015166317, 0.14622269517609052, 0.09588053330246891, 0.14056087684418472, 0.09281181118318013, 0.1246371255921466, 0.21849694768232958, 0.1279264869434493, 0.14075986402375357, 0.09799711472753968, 0.12961610699338572, 0.13225950300693512, 0.12099814228713512, 0.17397831939160824, 0.17948174050876073, 0.08720003480889968, 0.15819566271134786, 0.09988683475447552, 0.11309105836387191, 0.11891883957598891, 0.14457830627049717, 0.1044563338426607, 0.18359265848994255, 0.13242967958961213, 0.13297733877386364, 0.10400937604052679, 0.10539219648178134, 0.13543193920382432, 0.1298155691474676, 0.1078740061659898, 0.13322048501244613, 0.17454314551183156, 0.09446335184787001, 0.1408043216381754, 0.15196451278669493, 0.1494436330561127, 0.15256873465010098, 0.1738175880163908, 0.18156960633184227, 0.1855641012745244, 0.1758708349828209, 0.10676228082073586, 0.13234312566263334, 0.14959129584687098, 0.14458427737866128, 0.1750346084258386, 0.09797211749745266, 0.06569034579609122, 0.2304858879319259, 0.0960599108199988, 0.1043225403076836, 0.20057613216340542, 0.10346403744603906, 0.08579305852098124, 0.29904536477157045, 0.08648776302912406, 0.13448178661721094, 0.1789664745862995, 0.1780780686863831, 0.21062234523040907, 0.1352483547691788, 0.21586659311183862, 0.17504535642053398, 0.198875560558268, 0.08998924121260643, 0.150173031059759, 0.12916656397283077, 0.13402874235595974, 0.12014225178531238, 0.09494944076452937, 0.16649254464677402, 0.1115577592115317, 0.12260673168514456, 0.18310570104845933, 0.11768313231212751, 0.12285192709948335, 0.18359472123639925, 0.15466749774558203, 0.20216131210327148, 0.15156983610774788, 0.10316766013524362, 0.14612394118947641, 0.09285187867603131, 0.12703383341431618, 0.12514103283839567, 0.07421453017741442, 0.13294505407767637, 0.1358168585492032, 0.14831803845507757, 0.18986107355781964, 0.137489827349782, 0.13178830114858492, 0.09442062449774571, 0.15811189077794552, 0.13616474345326424, 0.1093213145754167, 0.12173367424735002, 0.09946902681674276, 0.1560008054865258, 0.11012835734124694, 0.15115834533103875, 0.1957396702574832, 0.08026181746806417, 0.1686795444360801, 0.08597723328109298, 0.08469580632767507, 0.12788173077361925, 0.16804820831332887, 0.09760484006255865, 0.18674575643880026, 0.09401692330305066, 0.1641120673822505, 0.15366950844015392, 0.10072722751647234, 0.1823098473250866, 0.1414189657994679, 0.2939755411020347, 0.0923372505764876, 0.1216982411486762, 0.0725560752408845, 0.11381955391594342, 0.09000031490411077, 0.172120422657047, 0.06668089157236473, 0.12909257651439734, 0.11682287204478468, 0.13591672533324786, 0.12550997946943554, 0.1708816619856017, 0.13373182900249958, 0.11795574054121971, 0.16053401652191365, 0.06380261387676, 0.08835939331246273, 0.13192744153950894, 0.1536461261234113, 0.09194244497588702, 0.15094980437840733, 0.13986650481820107, 0.0927844119391271, 0.20682313266609395, 0.17077890464237758, 0.15505931100675038, 0.17814698070287704, 0.12286570136036191, 0.060842131663646014, 0.09224632009863853, 0.17567328629749163, 0.23583795502781868, 0.10343654999243361, 0.11970739226256098, 0.12665613368153572, 0.23520930590374128, 0.1341814398765564, 0.1821091773786715, 0.10243649115519864, 0.1372019656534706, 0.08948008889066321], [0.03255614751417722, 0.03883261679272566, 0.04336250639919724, 0.05402490050931062, 0.04699589518297996, 0.017512530820178132, 0.03583726466500333, 0.00901232417007642, 0.017995951397876655, 0.021859506045335104, 0.015253567303131734, 0.05725361779332161, 0.0648786686360836, 0.016504521248862147, 0.016695506804223572, 0.0034591937894999448, 0.03839724836871028, 0.04226118978112936, 0.027594256713720303, 0.04789547316197838, 0.014692466340160795, 0.04704021369772298, 0.020697002531960607, 0.03122537749420319, 0.04113114059769681, 0.0218622456304729, 0.023140497040003538, 0.10518299735018186, 0.11415852286985942, 0.04139674973807164, 0.009339320373588374, 0.015171449298837354, 0.023983006831258535, 0.04090571430112634, 0.010235411530759717, 0.033895056561699936, 0.007966499842171158, 0.012930182823246079, 0.025988630817404816, 0.03620600434286254, 0.06640335717903716, 0.02566788052873952, 0.03690875627632652, 0.07249700198216097, 0.027464943206203834, 0.03196803746478898, 0.02550487606120961, 0.04916917160153389, 0.0532253284140357, 0.023801015257569294, 0.015936997951939702, 0.023077150707000067, 0.04346564711470689, 0.04250552684866956, 0.03950926887669733, 0.009651725529693067, 0.029697167354502847, 0.043620285245456865, 0.04752589549337115, 0.017769117141142488, 0.05200033861079386, 0.10643912173275437, 0.043996661834950955, 0.021464213595858643, 0.015890326617019515, 0.04789368522220424, 0.02821305181298937, 0.017341562047866837, 0.030343729803072553, 0.06692582914339644, 0.03085061242537839, 0.06327465934945004, 0.030765184866530553, 0.007794296136125922, 0.00653459587400513, 0.012410928811212736, 0.08075240507189717, 0.04722850038004773, 0.004604224814102054, 0.028689980506896973, 0.03490641979234559, 0.04911465809813567, 0.03238947217219642, 0.052735405774520974, 0.021375602011435797, 0.030031657977295772, 0.024446839799306223, 0.011937108655859317, 0.015299171641735094, 0.02829327161556908, 0.03519166573616011, 0.15550266578793526, 0.008306344954429992, 0.03832498099654913, 0.03177811890574438, 0.00663500972690859, 0.06296523381024599, 0.05760919049914394, 0.014617488220600145, 0.06398404057004622, 0.05618472836379494, 0.021078010122956972, 0.04842257273516484, 0.03206836225997124, 0.03085524681955576, 0.07397248995091234, 0.06947179431361811, 0.06041438997324024, 0.04778162516387446, 0.012986304454638489, 0.06016976452831711, 0.04003318951332143, 0.019068779723186578, 0.03597803693264723, 0.03408517189589994, 0.07306442010615553, 0.06139751257640975, 0.033599622414580414, 0.017581831297970245, 0.025231029505708387, 0.005910281316443745, 0.015267899659063135, 0.044764498847403696, 0.02920020491416965, 0.021141337796247432, 0.020720277979437794, 0.014861413078116519, 0.014286995865404606, 0.035715918854943345, 0.020620931971019933, 0.05943162699363061, 0.044673144285167964, 0.015345953238595809, 0.08421040951673474, 0.013601785758510232, 0.06933745116527591, 0.026203739989016737, 0.04118357099858778, 0.013866528070398738, 0.03531242800610406, 0.015027330157213976, 0.0667631910847766, 0.0020463840088008767, 0.04151898442900606, 0.05227268221122878, 0.031112876388111284, 0.07984332420996257, 0.006864089934554483, 0.02519793396017381, 0.01601041035194482, 0.007193706131407193, 0.022035886134420122, 0.044765469152480364, 0.028570269966231923, 0.03915195233587708, 0.08045203797519207, 0.013505162371854697, 0.02961054557402219, 0.03967514354735613, 0.025692874366151433, 0.08318632375448942, 0.03072975855320692, 0.05890270894659417, 0.02924710525465863, 0.05018037537645016, 0.036200162156351974, 0.03791602115545954, 0.07885483439479556, 0.024815063790551255, 0.02453165328396218, 0.043194256855973175, 0.020502061117440462, 0.04768391951386418, 0.035433302234326086, 0.08872357662767172, 0.0071018095893253174, 0.011329385551757045, 0.04758970831919994, 0.06003092269280127, 0.021396714628541043, 0.028329339144485335, 0.05997311829456261, 0.04043796618602105, 0.043235918906118186, 0.040298958109425645, 0.03711566874491317, 0.03794729822714414, 0.02800841922206538, 0.02553340676240623, 0.044471517604376586, 0.06352436023631267, 0.051953825035265515, 0.02982999736975346, 0.023942769704652683, 0.07334337942302227, 0.02576462265902332, 0.09385617157178265, 0.024754021083936095, 0.012452979322655924, 0.00828546388739986, 0.02671478033464934, 0.025125288304739764, 0.047994681767054966, 0.09438364433922938, 0.07944655085780791, 0.03491681155615619, 0.02487328039881374, 0.053347091523132155, 0.046491828481001515, 0.024792270102937306, 0.04647118066038404, 0.019721386222434894, 0.028154792796288217, 0.05631591293162533, 0.0535540582745203, 0.053505471774509976, 0.01782545929641596, 0.021855188866278956, 0.0441385638634009, 0.04153757628851703, 0.13027941568621568, 0.007868186903319188, 0.03872438367190106, 0.05182944956634726, 0.01832631483141865, 0.03298738365992904, 0.011702728241549006, 0.03570291133863585, 0.049625293019094636, 0.017305250246343867, 0.03858478866251452, 0.03854367622573461, 0.07799808215349913, 0.026048608224040697, 0.06647882384381124, 0.02294149120072169, 0.005030194679940385, 0.07821872817086321, 0.020271170917632322, 0.012560765458537, 0.01164655402369265, 0.034816289985818524, 0.02562220155128411, 0.010676675575918384, 0.009777630246909601, 0.023324958481160656, 0.024528090975114276, 0.07321865111589432, 0.0469956237689725, 0.08066400552966765, 0.04080708923616579, 0.05092471132853201, 0.05533324833959341, 0.04238295289022582, 0.026682699198967645, 0.028582052726830755, 0.044501244223543575, 0.03168448446584599, 0.029649476520717144, 0.04993593652865716, 0.09358392296625034, 0.03366162355190941, 0.027984796025391136, 0.013445724400558641, 0.016471534268930554, 0.0629293325224093, 0.07228647970727511, 0.013831938899654363, 0.02021775664096432, 0.06327867627676044, 0.03718568338081241, 0.03348239191940852, 0.0602159049095852, 0.0800262979630913, 0.03396007717986192, 0.03167390949758036, 0.010127647447266748, 0.008790957209255015, 0.01499123718323452, 0.0868988534701722, 0.03235474814261709, 0.007239463140389749, 0.044423104130796025, 0.08310567986752306, 0.0425912529629256, 0.03860788260187421, 0.09427834927503552, 0.026133862756458775, 0.03758979169651866, 0.017356444017163346, 0.042697291022964885, 0.022475186668868576, 0.07146471951689039, 0.06320975068956614, 0.046786638375903876, 0.033014881291559765, 0.016155309808839644, 0.038964452754173956, 0.018637736959915076, 0.015268917461591107, 0.021968480465667586, 0.06322218145110778, 0.0047890810778231496, 0.02978967542627028, 0.02053181827068329, 0.0180204516010625, 0.02648014122886317, 0.05205616847212825, 0.03435868936191712, 0.06349865732980625, 0.03916266640382154, 0.06339348440191575, 0.03706928748371346, 0.08406574585075889, 0.04469208559021354, 0.025276364126641835, 0.04188663845083543, 0.05608043074607849, 0.04817383536802871, 0.038246250578335354, 0.07362223695963621, 0.029797088421349014, 0.04811943721558366, 0.050717792074595175, 0.04115164253328528, 0.033025619108229876, 0.02670563368259796, 0.008948425679201526, 0.04678185470402241, 0.051918218910161934, 0.03007931149165545, 0.04293138560439859, 0.023212995114071027, 0.03089738723688892, 0.0697665431403688, 0.03141536729942475, 0.05244172224774957, 0.03186768552820597, 0.055808110894369226, 0.024868288077414036, 0.021832120371982455, 0.04518271729882274, 0.020973169677225605, 0.01970251277089119, 0.016136560189936842, 0.04451706426750336, 0.01673104677216283, 0.008653536904603243, 0.05382421699219516, 0.0671762628480792, 0.03845523936407907, 0.03216877526470593, 0.11447060826633658, 0.12138520580317293, 0.09611144555466515, 0.14295971526631288, 0.15037348387496813, 0.0979610030938472, 0.15988665340202196, 0.10519109227295433, 0.09933226808373417, 0.15567668287881783, 0.11242270137050323, 0.1537046565541199, 0.17062940980706895, 0.09124496525951795, 0.10090107497360025, 0.1115733248048595, 0.12036842107772827, 0.08730395923235587, 0.12305307202041149, 0.0989786224173648, 0.15817413958055632, 0.14372009517891066, 0.2152580286243132, 0.22511480828481062, 0.08749173022806644, 0.0979778171916093, 0.10423936548509768, 0.2135562085147415, 0.23624380039317266, 0.1843687668442726, 0.11320885204310928, 0.09918237969811473, 0.0782025722520692, 0.09113749209791422, 0.10965008514800242, 0.16178462441478456, 0.1095791578825031, 0.14174653536507062, 0.09697368035891227, 0.1260958130338362, 0.10380342030631644, 0.0713634549507073, 0.08628031451787267, 0.2296481414565018, 0.2755735085478851, 0.21074039675295353, 0.17381709947117738, 0.12051332901631083, 0.16922708148402826, 0.15140869761151926, 0.10284047733460154, 0.07580646154071603, 0.10983975604176521, 0.0739919367645468, 0.16744718913521084, 0.1612412535718509, 0.15038060849266394, 0.09134696942887136, 0.20695882609912328, 0.12710412964224815, 0.11673215191279139, 0.24571557928408894, 0.15957308879920415, 0.08789454254188708, 0.13646219963473932, 0.1023027722590736, 0.07343064581177064, 0.08455766338322844, 0.0659261570711221, 0.19178721734455653, 0.14031678065657616, 0.11987865450126783, 0.2405567318201065, 0.1181076102490936, 0.12643126717635564, 0.07608743610658816, 0.14540050072329386, 0.11912298362169947, 0.15909824999315397, 0.14352735052151339, 0.11803244213972773, 0.09304733747350317, 0.09089990984648466, 0.11249056844306843, 0.18416964395770005, 0.12421675957739353, 0.09373493093465056, 0.15973580149667604, 0.09716297127306461, 0.09456189548862831, 0.1932226310351065, 0.23905589378305844, 0.12358721478709153, 0.1201559446219887, 0.10390576374317918, 0.14718565850385598, 0.14799353586775915, 0.13609280517058714, 0.0878911227253931, 0.11836212873458862, 0.11697669593351227, 0.128630684156503, 0.16745495157582418, 0.19259281483079704, 0.20450033087815556, 0.0663307471466916, 0.14195039442607335, 0.2024165362651859, 0.24142878502607346, 0.0911643552993025, 0.15991990161793573, 0.18328256798642023, 0.18806835689714976, 0.09726967769009726, 0.1186744991157736, 0.156623225659132, 0.2032545677253178, 0.12098493799567223, 0.1157875768840313, 0.12395329800035272, 0.12627396918833256, 0.10738927431936775, 0.126971679606608, 0.11498557563338961, 0.11412327976099082, 0.10242754806365285, 0.10950954018958978, 0.13955694357199327, 0.11773452455443995, 0.13535073213279247, 0.12040401702480656, 0.16857039529298032, 0.11003640227551971, 0.1478007369275604, 0.08596004598907062, 0.09043383092752524, 0.11494141657437597, 0.26566879717367037, 0.12376079761556216, 0.12708324433437415, 0.1177047775792224, 0.11193948265697275, 0.22283269145659038, 0.15781674161553383, 0.15570351215345518, 0.08616658526339702, 0.13230876464928898, 0.08220366934048277, 0.1258033915821995, 0.12767468259802886, 0.1393987499177456, 0.10187420275594507, 0.13943552651575633, 0.15456398044313702, 0.15289562568068504, 0.1759617586753198, 0.09939262377364294, 0.0943186746111938, 0.17254256643354893, 0.060731462602104457, 0.12843671813607216, 0.12449651956558228, 0.16677283389227732, 0.06954733561724424, 0.1609312580632312, 0.08854444338274853, 0.06212212012282439, 0.21583056290234837, 0.05531342833169869, 0.0991049792085375, 0.15542961470782757, 0.06296987498977355, 0.12395932339131832, 0.12574866094759532, 0.11260727646627597, 0.10861612670123577], [0.061613761686853, 0.06806483838175025, 0.016692975868604014, 0.06310885253229312, 0.036289396296654425, 0.05797174533030816, 0.04022890615410038, 0.003858689551374742, 0.0569620920079095, 0.015152652182483246, 0.04845199062089835, 0.03266722708940506, 0.03234215113999588, 0.01797103219931679, 0.10951104653733117, 0.015028035833633371, 0.037772480464939556, 0.059286522279892645, 0.03148703756076949, 0.04345187285382833, 0.031664800164955, 0.022854557294132452, 0.04103004905794348, 0.050401771175009866, 0.020763448073661754, 0.0290774850706969, 0.03563761252111622, 0.03470708655991724, 0.032368586864322424, 0.023632479033299854, 0.02725449896284512, 0.08585707829999072, 0.036302715939070494, 0.06348336315048592, 0.03456309464360986, 0.04197483103988426, 0.020404760892103826, 0.04840082908049226, 0.052597622453634224, 0.027002216250236546, 0.036845031660050154, 0.017546730681455562, 0.04380431751321469, 0.019629941754309193, 0.04711244035778301, 0.03396684217399784, 0.050038032300238094, 0.02937929405431662, 0.04411496102277722, 0.03102438524365425, 0.010846118492606496, 0.037342482645596774, 0.0389958112500608, 0.052100453060120344, 0.017735488945618272, 0.01988985459320247, 0.009130927002323526, 0.06205402234835284, 0.017406721765707647, 0.0732153466503535, 0.04857785886685763, 0.09298004715570382, 0.05798706665102925, 0.039725850469299724, 0.013405561912804842, 0.01631188515706786, 0.049678870144167116, 0.051587660397802076, 0.02347623447089323, 0.05759430344083479, 0.009884678475957896, 0.03493771382740565, 0.04099169147333928, 0.021615072286554744, 0.04377196157085044, 0.02569587009825877, 0.04349984527964677, 0.035194478263812404, 0.04832403248708163, 0.07110266680163996, 0.03977818926796317, 0.09352900912719113, 0.006115710761930261, 0.014774547025029148, 0.04536595228793366, 0.006359723404914672, 0.008475414676857846, 0.03197132157427924, 0.08028229565492698, 0.04090470328394856, 0.020104700832494667, 0.004332802749039339, 0.020790731966761605, 0.022645441283072745, 0.0306862915999123, 0.03253294500921454, 0.0270465686917305, 0.023761095346084664, 0.004422069967923952, 0.024038758661065782, 0.013126836690519537, 0.013985746673175266, 0.05439660877787641, 0.002355637581786141, 0.025200461503118277, 0.03686289409441607, 0.03255522809922695, 0.05276660142200334, 0.018149025505408645, 0.028819889428892305, 0.010831538471393287, 0.007789674464480153, 0.024572465468996336, 0.01333100109228066, 0.07457086962780782, 0.04964234460411327, 0.04830613612596478, 0.003139836618044813, 0.031321132356034856, 0.044187645693974834, 0.026950578038979853, 0.08020719539906297, 0.014134708858494247, 0.021757428933467184, 0.09211906764124121, 0.029374910718096153, 0.03406706518892731, 0.007866806932725012, 0.030162622021245103, 0.04237159760668874, 0.04996469962809767, 0.028188787400722504, 0.03681041280339871, 0.0983276834179248, 0.04978084717211979, 0.0760783776640892, 0.022344802772360187, 0.03484313961650644, 0.02662895922549069, 0.02492872010251241, 0.06692679944847311, 0.05546841251530817, 0.05143668296347771, 0.005743629299104214, 0.0035598385563519385, 0.05782165338418313, 0.04139675313074674, 0.05265182043824877, 0.05902824471039431, 0.02913447522691318, 0.06348251498171262, 0.03299981102879558, 0.08540287374385766, 0.072661248168775, 0.01770822880124407, 0.03763878871021526, 0.038174526034189124, 0.010801846627146006, 0.11680000541465622, 0.013402471185794898, 0.054223260043987205, 0.01621759932355157, 0.04641280968540481, 0.08013858193797724, 0.033578316414994855, 0.023002615331539085, 0.0854789646608489, 0.08651269240570919, 0.05307854771880167, 0.022214271294485246, 0.0364478002967579, 0.008440040101829385, 0.02528895773658795, 0.08811143626059804, 0.04802714288234711, 0.00971384541065033, 0.042483949435076544, 0.01832404173910618, 0.024541380083454505, 0.006071917687742305, 0.05384647633348193, 0.05157601334420698, 0.035949708095618656, 0.02761050423474184, 0.03302940872630902, 0.037928821718586345, 0.05332783469930291, 0.019479990604200532, 0.04938410435404096, 0.02050875486539943, 0.011023311975545116, 0.05399149962301765, 0.01484052777024252, 0.04614717001095414, 0.022444359126633832, 0.03545916459656187, 0.027512513600023727, 0.03918150253593922, 0.013427344583241003, 0.021866997071940984, 0.008816154607172524, 0.011405556196612971, 0.020942661046449627, 0.06773589817540986, 0.03539837125156607, 0.054524112293230634, 0.016933312972209284, 0.07056068017014436, 0.03083239376012768, 0.02115275414793619, 0.006396093305998615, 0.019869244092011025, 0.011904821415165705, 0.058866502317999087, 0.04102899054331439, 0.05422571294807962, 0.022163208141656857, 0.006430410214566759, 0.03533019544556737, 0.030576195900461504, 0.06387856230139732, 0.05046253737860492, 0.023756639067349688, 0.017792546955336417, 0.06570359079965524, 0.024187081327129687, 0.05099253090364592, 0.0277399738053126, 0.008647251125824238, 0.02438841963053814, 0.06488307911370482, 0.022087163025779382, 0.0213085797149688, 0.015384550006794078, 0.014998027622433645, 0.042017565175358734, 0.023749558554430093, 0.05739788790898664, 0.019527311636401073, 0.027139994482110654, 0.06486916236047234, 0.035999655058341365, 0.04752387345901557, 0.08206162481967892, 0.030499830176787715, 0.10116748817797218, 0.04404710412823728, 0.020765933208167553, 0.020898418866896203, 0.014919477015999811, 0.030443050366427218, 0.025529347426657165, 0.017655888306243078, 0.08644640631973743, 0.07595495892954723, 0.07698067317583732, 0.018355931188645105, 0.06070919308279242, 0.017461949427212988, 0.029700546458895718, 0.052972024506224055, 0.04851701802441052, 0.03782571832250271, 0.012517683573865464, 0.005277133929277105, 0.029323637219411985, 0.08341859986207315, 0.04347635778997626, 0.015029537092362131, 0.044244218551154645, 0.011227562890521117, 0.041185453933264525, 0.03695557519261326, 0.058560768009296486, 0.042257345880248716, 0.02278761811820524, 0.019863240753433535, 0.046739887313119004, 0.043100530813847265, 0.01667365967296064, 0.009533937787637115, 0.017669611676995243, 0.038596235548279116, 0.06683122100574629, 0.028596654800432067, 0.07906516667987619, 0.023428156872146895, 0.026095720606723, 0.024663781015468494, 0.017856802525264875, 0.022008614115683094, 0.026269727519580295, 0.019337974921134964, 0.09631835123790161, 0.032696119110499106, 0.021931663155555725, 0.08228904261652913, 0.054542144361351214, 0.05233770961474095, 0.04952325831566538, 0.029556581683989083, 0.03936434058206422, 0.025887583382427692, 0.019397429855806485, 0.016977614523576837, 0.04168405842834285, 0.018624391872435808, 0.023645854654854963, 0.042198415113879104, 0.0690005924552679, 0.024570689403585026, 0.010662696906365454, 0.043929931308541975, 0.02341720531694591, 0.03779863798990846, 0.007518879620225302, 0.027452190140528337, 0.0342276676424912, 0.00775261118542403, 0.02797375456430018, 0.028012392044599568, 0.004758886693577681, 0.047265443219138045, 0.009027738789362567, 0.05809820390173367, 0.04425335502518075, 0.03940974814551217, 0.015919535853234783, 0.07063471512602908, 0.048081388364412954, 0.011827125762855368, 0.02129999115797026, 0.06922201200255326, 0.06558810413948127, 0.09284809245062725, 0.038782276279692135, 0.07261030375957489, 0.0481772042943963, 0.04362195444160274, 0.10358984462384667, 0.024122707013572966, 0.04560013847159488, 0.03068188451496618, 0.06735877519739525, 0.02440037881024182, 0.010333382657596042, 0.0023334721751910236, 0.032619722852749486, 0.016699783271178603, 0.052961018668221574, 0.05489683497164931, 0.035409750283828804, 0.14134355341749533, 0.15071169286966324, 0.14711130463651248, 0.13601733850581305, 0.16581855581275054, 0.1579673085361719, 0.14335515190448078, 0.20692504862589495, 0.18912494448678835, 0.14756490529647895, 0.12268702951925141, 0.0761332507910473, 0.13832263409027032, 0.09110942788954292, 0.1761643828025886, 0.13041304637278828, 0.10900350234338216, 0.12807218198265347, 0.11658634830798421, 0.1435646970889398, 0.0820017441042832, 0.11148572593395199, 0.1483955407249076, 0.09776105917990208, 0.12840935960412025, 0.12142749210553509, 0.10834663973322936, 0.1362821842942919, 0.11659149160342556, 0.16517450394374983, 0.08701794993664537, 0.1611744857260159, 0.11900247580238751, 0.2302555117223944, 0.09262033538626772, 0.1662314986543996, 0.10260659309902362, 0.1450257051203932, 0.1606005672365427, 0.1291097705917699, 0.19850475474127702, 0.12671851819115026, 0.1148445082030126, 0.07272688964647905, 0.23013003702674592, 0.14586262378309453, 0.10956942090498549, 0.09598709722714764, 0.17475927248597145, 0.13479927315243653, 0.16836052441171237, 0.15509707826588834, 0.15660513591553482, 0.14983658625611238, 0.11661268903740815, 0.08464768462415252, 0.0960437481158546, 0.11387389100023679, 0.13633129665894167, 0.18215514134083474, 0.12167054334921495, 0.17385665806276457, 0.17616800617958817, 0.14640961800302776, 0.12427929336471216, 0.19577112714094774, 0.18168664005185875, 0.15899127216211387, 0.07159609068185091, 0.22279982322028705, 0.12982539433453763, 0.14572246558964252, 0.17517483447279247, 0.0775186564507229, 0.15561161137052945, 0.13043233033801827, 0.12224584605012621, 0.13635256194642612, 0.3019553843353476, 0.16566874885133334, 0.10141598805785179, 0.18693757828857216, 0.10975345317274332, 0.09280763819281544, 0.146949989721179, 0.08964914589055947, 0.12239861142422472, 0.04880904931841152, 0.25243587153298513, 0.14892679293240818, 0.14390152187219687, 0.1706486666308982, 0.08618989294128758, 0.15727312649999345, 0.11680675005274159, 0.11887530476919242, 0.13077778608671256, 0.12823085061141423, 0.13363924968455518, 0.09480700269341469, 0.10160719922610692, 0.1624393021421773, 0.09783018154225179, 0.1616894802344697, 0.13275711344821112, 0.08994863089174032, 0.16012597270309925, 0.20118496806493827, 0.12127626022057873, 0.17317064558821066, 0.12347275950014591, 0.08933210718844618, 0.10343948804906436, 0.12253308349422046, 0.22570191749504634, 0.1007145456969738, 0.13026873554502214, 0.1796987767198256, 0.13288843711572035, 0.11877687647938728, 0.17594898864626884, 0.14009738314364636, 0.06592633349022695, 0.12931577382343157, 0.1829552969762257, 0.0989354472341282, 0.14631192253104278, 0.1294432162706341, 0.09064027520694903, 0.12181123079998152, 0.13346269487270288, 0.10593237142477717, 0.08372164038675171, 0.12318379857710429, 0.09931030390518052, 0.1450911294668913, 0.10622819233685732, 0.11398200877010822, 0.16020766831934452, 0.12462352775037289, 0.22347675689629146, 0.09070087516946451, 0.12366847614092485, 0.09459924884140491, 0.11430047239576067, 0.13195880342807087, 0.11921781567590577, 0.1332504762602704, 0.1723351382783481, 0.08639635079141174, 0.16854161183748925, 0.1376314511788743, 0.12287814569260393, 0.1466462095933301, 0.10071811479117189, 0.16741889422493322, 0.07982095969574791, 0.1310111614210265, 0.16667236999741622, 0.1138676077659641, 0.17814304519976887, 0.1294341239013842, 0.10414710507861205, 0.1611384826579264, 0.09296831528523139, 0.09178962531898703, 0.14926322416535445, 0.1806535976273673, 0.10753493543182101, 0.1212571526744536, 0.1311290365244661, 0.1142214366367885, 0.20452222041785717, 0.20849007607570716, 0.15235855164272444, 0.09620409272611141], [0.02087186270260385, 0.010241972964390047, 0.09674267989716359, 0.030881740219358886, 0.023188120020287376, 0.021706813613751104, 0.010702375937918467, 0.05825067750577416, 0.10608616138675384, 0.019361370808577964, 0.05469583593575018, 0.08519609019692455, 0.021077733619936874, 0.02333435958384403, 0.02036470527361546, 0.0749211497604847, 0.05048297485336661, 0.05308654086132135, 0.03590734036905425, 0.01914301484690181, 0.03008558115522776, 0.03003085052062358, 0.032271681885634146, 0.08920872916600533, 0.0407446334803743, 0.05829164066484996, 0.03446655607383166, 0.03877637981038008, 0.05168307938479951, 0.05417029360043151, 0.09233950331274952, 0.05640027519049389, 0.03770608581336481, 0.07102491347385304, 0.02889406348445586, 0.0416314719643976, 0.025972792113732015, 0.01817937976946788, 0.005853030348329672, 0.06205683148333004, 0.028258808821971928, 0.023218701593577862, 0.014015501281911773, 0.03267738815130932, 0.04754421593887465, 0.04851616307028702, 0.026601358117269616, 0.02510929014533758, 0.051800197921693325, 0.038824111356266906, 0.005566318768874875, 0.017459279391914606, 0.01675586249413235, 0.05601227190345526, 0.013572594333839203, 0.01302362303249538, 0.03581651845680816, 0.035417587363294194, 0.04893375048413873, 0.009379168190727276, 0.05351580586284399, 0.10572097383971725, 0.025474857671984603, 0.050012309037681134, 0.0951363839475172, 0.03141356918162533, 0.038189358809696775, 0.018525403791240284, 0.008485551990036453, 0.017583602274368917, 0.03866754618606397, 0.04755354918805616, 0.050108864570834806, 0.062180209505770884, 0.02292351850441524, 0.05059220202799354, 0.03825471869536808, 0.047313123874898465, 0.06611022326563086, 0.021038027446983115, 0.020459757851702825, 0.021025613648816943, 0.023742440722084472, 0.05758130270987749, 0.06082235236785241, 0.02642397888536964, 0.004300083366355726, 0.04729698831215501, 0.057791621424257755, 0.033183205473635874, 0.04486016210700784, 0.041349184433264394, 0.012589533646990145, 0.01936109600189541, 0.07106585627687828, 0.036866381764411926, 0.0785203098452517, 0.01858929295225867, 0.03086191342611398, 0.06320472953042813, 0.05612635738881571, 0.07198715076914855, 0.010347279054777963, 0.024245131694312607, 0.0611513400716441, 0.025264937596927797, 0.05250351643189788, 0.031361932666706185, 0.024209508605833565, 0.04131548159888812, 0.019564249386478747, 0.04495539449687515, 0.062088790482708385, 0.047275448217988014, 0.045021578802594116, 0.006191978098026344, 0.048168305307626724, 0.02993529921929751, 0.027531443030706475, 0.03814062981733254, 0.02038177551834711, 0.03419800887682608, 0.03280755491661174, 0.029505135158875158, 0.025165226875937412, 0.006217086438222655, 0.03521733132324048, 0.053418045930032215, 0.018135895852797797, 0.03242682891764811, 0.020950710168108344, 0.02710396087994533, 0.03176456856142197, 0.03900327852794102, 0.057623460090586116, 0.015854969853535295, 0.028111327539331148, 0.047008546468402655, 0.0556607263029686, 0.02020862525595086, 0.027266525996050665, 0.05526062134387238, 0.02012891774731023, 0.05545556106205497, 0.020759912906214595, 0.04742257835875664, 0.038931041689855714, 0.016477468057668636, 0.017107065434434583, 0.05335867750857558, 0.030491209389375787, 0.031687140930444, 0.03481981836791549, 0.034981791462217054, 0.02722886560617813, 0.04168104234018496, 0.02851142401673964, 0.051816618469144614, 0.07293374104691402, 0.016253059563626136, 0.022611310971634727, 0.027320566221273372, 0.04023531152467642, 0.05266220880938428, 0.046302317042968104, 0.04573614063805767, 0.04204047930293849, 0.056342643818684986, 0.06225742000554289, 0.013164483509691698, 0.06240994110703468, 0.020924133647765433, 0.04451217203001891, 0.04156884318217635, 0.030594675801694393, 0.011172911983781626, 0.05237389588728547, 0.022115417223955904, 0.080564830851342, 0.042263479836817296, 0.04610392697421568, 0.012436634262225457, 0.012834920747471707, 0.01940832712820598, 0.04327337403914758, 0.058103754318186214, 0.04743519571742841, 0.022422432267506207, 0.015677661867812276, 0.016626111331528852, 0.03591433945777161, 0.04225006180682352, 0.04911984549835324, 0.023167417916868414, 0.013134692429697939, 0.005462950320049588, 0.0628133098195706, 0.01818369864486158, 0.032675410221729956, 0.06591551764202969, 0.00940964204658355, 0.037932431524885554, 0.02380214841105044, 0.029149894935211966, 0.018278559536806176, 0.027251901870061244, 0.017012998428461806, 0.06936524395963975, 0.018792953541768447, 0.03440479581643428, 0.0235514789154487, 0.06227373877274139, 0.020469277698014463, 0.05543622620669859, 0.023854946917189018, 0.053368003972406895, 0.0387806410102972, 0.04149726113038404, 0.029841763166976825, 0.061499503175062795, 0.018256651337391565, 0.022210775142801658, 0.058394845841186385, 0.01680827253897275, 0.04430465227259057, 0.10199519912047045, 0.021826541117791618, 0.0174906327987888, 0.012313967853385423, 0.043768019282392094, 0.021302583161741495, 0.01671992558320718, 0.04894408117979765, 0.047128446998872926, 0.0219709588148232, 0.022034086320283156, 0.05256931397265621, 0.05218059143849781, 0.03790167013981512, 0.04635693571929421, 0.060814725634242804, 0.04541498322838119, 0.03721820217158113, 0.03541467644806419, 0.028131710731291344, 0.029021760382290398, 0.015548138014440025, 0.027291353592383008, 0.045437541125076156, 0.035078231644417555, 0.04683855309018067, 0.04031464244638171, 0.003974983668220895, 0.013709896743031484, 0.014665019598656466, 0.030830510825450932, 0.005009705466883523, 0.03196666003870113, 0.013362513954884239, 0.06954002100974321, 0.025072695055444325, 0.013097026950812765, 0.00841403185456459, 0.023080326250887344, 0.012020588819203632, 0.033326512069574425, 0.03999941543276821, 0.12090667576662131, 0.06841004985783782, 0.025955747314063565, 0.06198689487895795, 0.046286995722247024, 0.039734403403209786, 0.028091120766475797, 0.024654474907687733, 0.015414551432643617, 0.029369031212159565, 0.03683368316186326, 0.059797092740024836, 0.009997789415397813, 0.005661062189444367, 0.06383539390351091, 0.017744705147509063, 0.07550342780138765, 0.05329289353851761, 0.01333252779607262, 0.0128287113038823, 0.05396584082128746, 0.03889539485265102, 0.009203330081488405, 0.0512122812547854, 0.014016195932137114, 0.026168574911675284, 0.024158621872110025, 0.013384948867107076, 0.006190205001205738, 0.02786975210931684, 0.04974261850916913, 0.03884643176570535, 0.04936914944222995, 0.024089129708175148, 0.03498142844598208, 0.01842353363255305, 0.017952213030574576, 0.038421373681298325, 0.021665987858016576, 0.0617970543514405, 0.10674562957137823, 0.04877058656087943, 0.03950114681252411, 0.06867582523929221, 0.012875458973992084, 0.04369398432650736, 0.011806069973057933, 0.044764909361089976, 0.04196074465289712, 0.036726820681776316, 0.026501364107908945, 0.043075520013059886, 0.02395627085518624, 0.03986977453210524, 0.02590065196688686, 0.019086609927139113, 0.06109817006758281, 0.02233927949730839, 0.032775182010872025, 0.03410148048507316, 0.03896599642134138, 0.043198297532009225, 0.040288186366004605, 0.02066699940977352, 0.044631811324507, 0.012724447612916785, 0.08704401246671166, 0.03335430147126317, 0.02296453764263008, 0.038310253393969367, 0.010546942224859126, 0.015357201652867454, 0.011588484148627945, 0.0036155165954759078, 0.022344120844666446, 0.045777402352541685, 0.049493117790137015, 0.024727193505636284, 0.016553845655705248, 0.059565121973199506, 0.005653897283731827, 0.01957491086795926, 0.014361270004883409, 0.013403992800574218, 0.02028675177799804, 0.10723912809044123, 0.05951740739068814, 0.15395635233393737, 0.18696233124605247, 0.1306101879371064, 0.06565434272800173, 0.0868012122809887, 0.11864042308713708, 0.16326848550566606, 0.1289798989892006, 0.10059639917952673, 0.09282960237136909, 0.1244026781725032, 0.07159459111945969, 0.1335298019860472, 0.17023566950644764, 0.10653302419398512, 0.11520513599472386, 0.15338138890053543, 0.1498755748782839, 0.22647366965455668, 0.12168579681643418, 0.0650081466883421, 0.20479834345834597, 0.09593210874923638, 0.15344475050057682, 0.08976896838950259, 0.07627442678702728, 0.16673227106886251, 0.1538738424756697, 0.17755930152322563, 0.16348003915378026, 0.07214387200240578, 0.07665146155548946, 0.1480529076818909, 0.10939496955169098, 0.14136510368968758, 0.10971956034856183, 0.07509924484682934, 0.21603702753782272, 0.1050921075844339, 0.14856155110257013, 0.08851129016173737, 0.12570750101336411, 0.20919218340090343, 0.19347348543150084, 0.107308325091643, 0.08061625702040535, 0.12718179476048264, 0.14450677510883125, 0.13109011575579643, 0.10090013180992433, 0.1258860235767705, 0.19572139052408083, 0.11292546867792096, 0.09313290752470493, 0.10593088543308632, 0.1960853295666831, 0.08558139630726405, 0.08959910393293415, 0.12423478146748883, 0.2165823389909097, 0.1149976806981223, 0.11327992180096251, 0.19091215144310678, 0.14610813132354192, 0.10421818840716567, 0.0915177838344659, 0.11402354868394987, 0.08722199898745332, 0.1424059492668935, 0.09609696561736719, 0.10421491786837578, 0.1539352906069585, 0.14661188929208688, 0.1566846195076193, 0.09816636171724115, 0.1358586155942508, 0.16626234485634736, 0.10327889916620084, 0.052230701249625, 0.23413054378969328, 0.1771645705614771, 0.20609833512987408, 0.13792642392218113, 0.12530987949243613, 0.05603532513071384, 0.11286197137087584, 0.1354464055704219, 0.1661742710109268, 0.2021512019314936, 0.2823377970073904, 0.16585022982742104, 0.16802072764507361, 0.2374344122196947, 0.12378759974879877, 0.21077008944536957, 0.09189392293670348, 0.19793716019817761, 0.24022897226469858, 0.15404430404305458, 0.1306926163711718, 0.1281502406511988, 0.11183790596468107, 0.12233782825725419, 0.1258526939366545, 0.1145641239626067, 0.10961800401232072, 0.12705256098083087, 0.18027215238128388, 0.08126705352749143, 0.1450359509991748, 0.24259065410920552, 0.1786901479853051, 0.16061185805925302, 0.10722909255751542, 0.14518734573253564, 0.07465601898729801, 0.07827921278242554, 0.16582417408270494, 0.1164298238498824, 0.12588039173611573, 0.18863475721861633, 0.13660025436963352, 0.06867961825004645, 0.1411665372018303, 0.11712720857134887, 0.08957157576722757, 0.08340291891779218, 0.08499833795108966, 0.10529228220028536, 0.17873714332069668, 0.1215919554233551, 0.08453570599002497, 0.16671998958502496, 0.0766438619632806, 0.09366143202143055, 0.1170613771038396, 0.11343607985015426, 0.1729293992476804, 0.11270459195865051, 0.08821209693061453, 0.18001755247158663, 0.21581912280193397, 0.144567056159888, 0.13731921650469303, 0.0730371769251568, 0.15810241842908518, 0.07458916293191058, 0.093249744469566, 0.1127194654462593, 0.09002071845212153, 0.20924167574516364, 0.08758766150900296, 0.12265414771224771, 0.14270649956805365, 0.15912079092647347, 0.14888339383261545, 0.1226488279977015, 0.11255135839538914, 0.13229737883167608, 0.09157094705317702, 0.08180871446217809, 0.15436632319220475, 0.127205312784229, 0.12597510165401868, 0.11970754154026508, 0.10075946471520833, 0.14548681037766592, 0.08025465213826724, 0.10210137628018856, 0.12972155133528368, 0.11777535879186221, 0.26368587357657297, 0.20009214670530387, 0.08386360348335334], [0.012929559419197696, 0.08109625947794744, 0.05266053622056331, 0.02767030013326023, 0.07482568666871105, 0.031125866941043308, 0.03142953511061413, 0.07496228255331516, 0.034351591885622056, 0.02616602192366762, 0.04835156065278819, 0.023319206200540066, 0.05069243522094829, 0.007858001244520503, 0.04766886621447546, 0.029855262621172836, 0.0700860381392496, 0.06992487928697041, 0.04264882665925792, 0.07197230442294053, 0.018992995843291283, 0.03538587263652256, 0.015125517567087497, 0.05995873335216727, 0.054168057827545066, 0.04392276597874505, 0.0622894943558744, 0.0333425390667149, 0.02481165754475764, 0.01589058615666415, 0.03975520728688155, 0.01892642137993659, 0.02638665776300643, 0.012644640868529677, 0.02663923054933548, 0.06440852529236249, 0.03960084057013903, 0.08441468248409884, 0.029729058500379324, 0.025481062874730145, 0.05375238388244595, 0.052584811712482145, 0.017689194197633436, 0.006919544057122299, 0.04943241604736873, 0.04633759068591254, 0.03164960437321237, 0.05091340693512133, 0.019017604612080113, 0.024233674630522728, 0.047644754472587786, 0.0381881408393383, 0.04775654650958521, 0.02913368134094136, 0.04330285977838295, 0.08094638466302838, 0.05885472973542554, 0.03429258648040039, 0.024973011475854685, 0.005985754766568009, 0.020541117593113865, 0.017405025428161025, 0.08467414748987981, 0.007425963579277907, 0.07863781853978123, 0.021912484363253628, 0.03913249195154224, 0.05109523735674364, 0.043289557099342346, 0.016695879998483827, 0.020379663578101566, 0.009342112545190113, 0.032514020667544434, 0.058736990338989666, 0.028789989783295562, 0.019387394322880676, 0.018730078790602938, 0.03190886242581265, 0.014814578894791859, 0.004758787033746817, 0.02518794422836176, 0.049947359665696106, 0.07277025481952087, 0.0749363557302526, 0.03844444726460746, 0.0865147008693644, 0.01962109705034111, 0.017199595558590124, 0.008009769172141594, 0.06914946303835937, 0.0345997253565916, 0.046962731783943515, 0.11296176351606846, 0.07445183422948633, 0.08273030750985656, 0.08886040321418218, 0.051913530233183076, 0.017428570593308126, 0.024234634757574116, 0.039811661400433095, 0.027529400640300343, 0.055900038818695715, 0.03058766314227666, 0.048291517088988, 0.021600507532379458, 0.056801971314208846, 0.018039857702595846, 0.02834909638789083, 0.020307543787306974, 0.016073470003902912, 0.0014758366721382896, 0.015536528280270951, 0.05410005844065121, 0.0307012024069471, 0.00943903363908508, 0.05495039852602141, 0.03062945750675031, 0.038271315661924224, 0.021932623282607113, 0.0728768730270011, 0.03981390395866973, 0.04585506747077618, 0.02434985339641571, 0.030204826899405037, 0.051147691506360254, 0.0036290796623299165, 0.01927969554838325, 0.0313653423051749, 0.027663385861420205, 0.03546746986519013, 0.04206744767725468, 0.0655766436830163, 0.037593489712370295, 0.04328875642802034, 0.020125294370310645, 0.018311090201937726, 0.03351615242926138, 0.051851284823247364, 0.008555936427520854, 0.01777163620239922, 0.012836870687481548, 0.05465284734964371, 0.008122489105777016, 0.060164526237973144, 0.013352458914076644, 0.01756254054739007, 0.04513267534119742, 0.01193226476399494, 0.022792410271774446, 0.028657315831099237, 0.005473635550255754, 0.057732432814581056, 0.023222530227420584, 0.016300599423370192, 0.051807061303406954, 0.043540662553693564, 0.03457848381783281, 0.07164784933307342, 0.03184295292677624, 0.0073032318614423275, 0.01393554950066443, 0.03646372551364558, 0.06616876726703984, 0.06615318131766149, 0.03001808388424771, 0.055636838477637084, 0.05670752602496317, 0.024511931663645164, 0.03680201253986784, 0.013180284893938472, 0.03349888710571187, 0.01439778197423688, 0.031310336863888164, 0.01545300570848797, 0.06523962212460381, 0.01770022208802402, 0.017139104161677614, 0.050170506084603925, 0.01091733922450138, 0.058136961821998866, 0.04434321341770036, 0.01428464983057763, 0.017139244957693985, 0.07162323208259684, 0.018278420437127352, 0.020808942150324583, 0.05852384213358164, 0.01651032781228423, 0.06261204276233912, 0.03022410747195993, 0.04523528001404234, 0.018183048947581222, 0.009673432713108403, 0.039907107528831275, 0.015255550321723734, 0.019981534852247154, 0.0228704485842692, 0.019542592245021036, 0.08965400420129299, 0.01035803129031722, 0.0194672290568373, 0.08050447516143322, 0.026764661140207733, 0.05622690610055413, 0.044987675800387344, 0.028332753871966685, 0.04683259216004184, 0.09260861030114548, 0.02344099136202463, 0.03274367084460599, 0.07111728923129183, 0.030686610511371067, 0.025687279844922677, 0.05588631884061864, 0.035311688402933736, 0.04050296644813248, 0.008982181100041738, 0.06644862225013119, 0.029232398008129427, 0.06722553806113345, 0.02580721939115652, 0.008281491064865674, 0.07216046218361173, 0.059413170841123374, 0.011370988230087926, 0.04576838122946875, 0.048141981541578255, 0.03748368578297751, 0.029736698804689304, 0.03816207491659692, 0.008741862656149482, 0.03159266510712249, 0.05839275595332895, 0.05923930981329509, 0.03444486330928547, 0.030945369840732644, 0.02834425843320787, 0.02623668795318476, 0.01196190995895969, 0.023727041369836246, 0.025914205703884363, 0.02855450420507363, 0.06671497438635145, 0.021189410305981125, 0.02978857959221516, 0.05416976773579206, 0.04746397238756929, 0.010136575271774615, 0.03241115136604224, 0.04103841200204832, 0.039188742504588196, 0.0898737884791834, 0.012927432211914232, 0.05956841965339013, 0.024736279089535986, 0.030961831100285053, 0.06034908776304551, 0.034010329483343024, 0.09969168129776206, 0.018369713931211402, 0.015356899704784155, 0.034991053465221605, 0.04873405084280031, 0.06592487463993685, 0.06503561378589698, 0.05527572553338749, 0.09361191932111979, 0.06667139886745385, 0.019260552379169633, 0.0771962980340634, 0.05398380503590618, 0.1059713057641472, 0.033198981412819455, 0.02725411898323468, 0.04155691792922361, 0.011741364025510848, 0.019756227299304943, 0.029854434808450084, 0.052165446536881585, 0.0164917189893978, 0.021666856382840445, 0.027574251805033003, 0.041872138157486916, 0.024979077578921403, 0.08049747268004076, 0.018569391520161713, 0.005116713831999472, 0.013188483293301292, 0.022173230103882294, 0.05297182094571846, 0.01922593861153083, 0.04804262026612248, 0.024749276427818195, 0.03792437052886401, 0.02744529622473887, 0.03024080621876887, 0.030249688242162977, 0.015677646600774357, 0.02694476469020758, 0.021100929339549372, 0.010816918586247733, 0.025120784528553486, 0.003227861481718719, 0.08035662238086973, 0.04696739671219673, 0.02634944181357111, 0.03598401482616152, 0.02550521193604384, 0.037975552425320656, 0.024950976051124077, 0.024838990631646345, 0.02104913506523839, 0.010119637341371604, 0.035331121645867825, 0.020046299323439598, 0.05595834194017308, 0.011315680840717894, 0.034247392655483315, 0.030137614613132815, 0.007025761928941522, 0.0084476252751691, 0.054042579739221504, 0.02495368679852358, 0.043451581083770306, 0.008387582559537674, 0.04226167832634278, 0.047990454493888786, 0.021154514946309582, 0.0837361610361508, 0.03135830589703151, 0.01350020058453083, 0.03834239220512765, 0.02414412666777415, 0.04599667094381792, 0.10706350965691463, 0.04143008616353784, 0.025150706226538335, 0.08497500991714851, 0.022813319328374097, 0.048198727425187826, 0.02654096171525972, 0.03266464865633419, 0.02319904782676271, 0.027495134621858597, 0.055716651159205606, 0.009461004602988916, 0.0431673868692347, 0.024241513406325663, 0.03867379888626082, 0.03978479141369462, 0.08250201440283231, 0.02492212474213115, 0.1090250594009246, 0.16889565783951963, 0.1277541254780122, 0.08631227351725101, 0.14506801856415613, 0.09584096792553153, 0.14406473668558256, 0.1602297749902521, 0.09770986371274505, 0.07401892210223845, 0.07183628529310226, 0.15090849516647203, 0.11325731979949133, 0.11516622879675456, 0.1540603581815958, 0.08192912728658744, 0.11813049044992242, 0.17740838176437787, 0.11193757597357035, 0.15259777594889912, 0.15040099168462412, 0.21776655901755604, 0.13954732194542885, 0.1460274535098246, 0.11589264124631882, 0.15493196355445044, 0.18229550309479237, 0.10321899130940437, 0.17855874289359364, 0.11183690851820366, 0.17909154216093676, 0.20930547160761698, 0.21217689609953336, 0.06366998742201499, 0.25637243315577507, 0.18234471045434475, 0.06979361668761287, 0.21299335014607224, 0.09837966598570347, 0.08921470705951963, 0.13165610895625182, 0.20789806784263679, 0.09757041798106261, 0.2201428972184658, 0.1389037450509412, 0.12091211761747088, 0.0903526238564934, 0.11678543048245565, 0.15777547311569962, 0.0948660352400371, 0.15739250795117446, 0.09661642488624368, 0.1848589134003435, 0.15521811534251484, 0.07668870634266309, 0.14321293096457208, 0.09421749146921293, 0.14368245005607605, 0.12008883750864438, 0.1525511063103165, 0.12358492133872849, 0.05493307891967041, 0.15676940924354962, 0.09771396206425768, 0.22824088696922573, 0.17729684417801245, 0.15516976293708595, 0.1403409500739404, 0.10709303271557603, 0.16350519923227175, 0.10852753716920104, 0.10966659390500613, 0.09588595479726791, 0.19915321708789893, 0.08237423268812043, 0.15771467637802872, 0.09522595735532896, 0.17252233251929283, 0.09234560334256717, 0.07332047886614289, 0.18844844507319586, 0.23172160876648767, 0.1732136918497937, 0.11433711328676768, 0.10170714064900364, 0.13459951244294643, 0.10987077866281782, 0.08253800390022141, 0.17373302898236684, 0.11862416538809027, 0.15126898725117954, 0.19322447665035725, 0.2492564192840031, 0.31137768445270403, 0.0997926676645875, 0.24982666011367524, 0.127347289451531, 0.14339181993688854, 0.1378836083625044, 0.12331042678228446, 0.16626047209969588, 0.2691700378698962, 0.13725109158882073, 0.17493233962782792, 0.18183620274066925, 0.14768329608653272, 0.07763438738350358, 0.08030038539852415, 0.18668346692408833, 0.12204395474067756, 0.0572349987924099, 0.06506661605089903, 0.19015888257750443, 0.06582576102976288, 0.11108945469771113, 0.2129487432539463, 0.09894329109894377, 0.22233552884842667, 0.12774793723864214, 0.2523323270891394, 0.12442276280905519, 0.15538825121309074, 0.11800627782940865, 0.11828199374888625, 0.14339659682341985, 0.07366573105433158, 0.054228494941656075, 0.16821864273931297, 0.13172764011791774, 0.07550933784140007, 0.12091921509376594, 0.18424755334854126, 0.07890765156064715, 0.07224610008831535, 0.10526819420712334, 0.14266820305160113, 0.06895839436245815, 0.09454175656927483, 0.11019383597054652, 0.15128749768648828, 0.10779434615480048, 0.1154318345444543, 0.09166283426540238, 0.11975041138274328, 0.11003436667046376, 0.1693539268204144, 0.10179393206323896, 0.11051854211837053, 0.19429844830717358, 0.09609319296266351, 0.1584148295223713, 0.0847142692655325, 0.25771639389651163, 0.07417304454637424, 0.18262578680046967, 0.19568092269556864, 0.11091406696609088, 0.16893153877130576, 0.13102015879537376, 0.11268012398587805, 0.15124766768089362, 0.14752641879022121, 0.08542211699698653, 0.15862198626356466, 0.14371861597257002, 0.0955972924296345, 0.12713336093085154, 0.07040870868201766, 0.11171719458486352, 0.0770926857367158, 0.13929835387638637, 0.12986941768654756, 0.11998772222016539, 0.08777668779449803, 0.18078615622861044, 0.115444740280509], [0.05909034423530102, 0.019078988282542144, 0.041849929706326554, 0.07948216716093676, 0.07169813556330544, 0.05148865196055599, 0.036194211404238424, 0.04572736378759146, 0.05801290526453938, 0.03830534419310944, 0.024514542327129414, 0.05827797496957438, 0.030952748909060444, 0.041149478006575785, 0.023485820474369184, 0.019007511403677717, 0.03763845622805612, 0.021004441659897566, 0.02675046449128006, 0.04806687789303916, 0.01806376249130283, 0.04881159721740654, 0.04716431096728359, 0.02299330583108323, 0.021439535277230398, 0.10577347887946026, 0.03647073817306331, 0.05465767512630139, 0.08522226129259382, 0.04198423892791782, 0.03408923971333674, 0.05792731485728707, 0.02686703171847122, 0.021549977029540708, 0.04068457295319863, 0.03645579683195267, 0.004509427534815456, 0.025616444181650877, 0.03901418937104089, 0.017102470056020787, 0.040345712564885616, 0.013923310425265558, 0.05738378795129912, 0.006147311834086264, 0.0250316911842674, 0.03454692176144038, 0.022624622132363062, 0.04297888305570398, 0.05489646517006414, 0.03320381258215223, 0.05435507564938494, 0.07180488269243922, 0.022875166098986353, 0.04180936349023666, 0.05880286930395024, 0.041720736638775895, 0.045507586295051236, 0.0380990831181407, 0.028737589916480438, 0.025413906567596962, 0.019368744787893126, 0.02732033551936703, 0.020628570578992367, 0.02132263726421765, 0.014489134840135063, 0.024491819885692427, 0.03480310944308128, 0.019514319387131503, 0.08169576552297388, 0.057672138192823956, 0.011266314025436128, 0.0648253493543182, 0.024752406170591712, 0.040967980067112615, 0.03728354170120188, 0.031159905650253807, 0.056164918533925495, 0.022907650963004147, 0.05115110793017915, 0.0405567233849849, 0.06115914322435856, 0.03057280322536826, 0.024461233223389302, 0.04922736955008336, 0.06651057928268399, 0.036536898730056624, 0.023888687070991312, 0.03210399213380047, 0.03755812107452324, 0.024935077975637147, 0.017027447831683924, 0.04465235397219658, 0.010936445074288972, 0.04200951435736247, 0.0327681659587792, 0.010443273948372474, 0.03433193133345672, 0.037771489803812335, 0.03351369273981877, 0.054252423479088714, 0.043722228346658606, 0.06472378623272691, 0.019069327640214136, 0.012048031319864094, 0.02813265728764236, 0.03522165019863418, 0.017493311315774918, 0.07372724025377206, 0.04183747519605926, 0.06212273758969136, 0.026496705965005925, 0.010242810955138078, 0.02638426423072815, 0.039232650505644937, 0.025808401738426516, 0.08459233652268137, 0.031913432359163246, 0.032553046609141996, 0.0442439912419234, 0.01644585680748735, 0.03899964497291616, 0.019538767003853406, 0.009797362045251896, 0.050277751936976395, 0.026981045957654715, 0.03773802784936769, 0.04956152429804206, 0.03560588761631932, 0.09230556977646691, 0.0437777019771082, 0.06999096859778677, 0.026898229062291126, 0.012947995215654373, 0.035348692310175726, 0.018951522086613944, 0.07628207387668745, 0.010596780621978854, 0.013744951558432408, 0.04987465463844793, 0.03975749734256949, 0.03403748784746442, 0.053489346389791796, 0.03105344689850296, 0.10003926086106471, 0.018372448427336555, 0.058680773712694645, 0.06446075213274785, 0.035646606502788405, 0.0823406655607479, 0.05498182487541011, 0.015866913766201054, 0.011863176328396159, 0.035954257672918696, 0.048812014516443014, 0.06514166202396154, 0.012230267166160047, 0.06888353837920086, 0.00489304621338046, 0.02860437652894429, 0.04285472471799169, 0.03712174502600517, 0.04931642048593078, 0.03339273708739451, 0.026920459565839598, 0.03778723181624498, 0.028545690035181384, 0.00796442267684532, 0.037937910695161135, 0.030064041061060767, 0.05037708607103143, 0.02470954311346369, 0.027978595911658237, 0.049459618516266346, 0.04271730441333992, 0.017617283056357076, 0.05609138569395457, 0.08363930694758892, 0.017011251200788786, 0.016935404556404268, 0.06604331292744194, 0.025971185682075362, 0.04161721933633089, 0.0600635398711477, 0.010271040556420172, 0.029101895367992774, 0.09073100212429251, 0.006912568717130593, 0.04470965286184635, 0.016211752048028365, 0.07203054308359112, 0.0640829981171659, 0.03775770536490849, 0.06342382170259953, 0.020728240587881634, 0.060551291198602746, 0.04118574909599764, 0.016709028310807686, 0.04215314665010997, 0.010254536888429096, 0.04582216191504683, 0.0198188526888511, 0.10470017897231237, 0.02800615630777819, 0.04316084239897983, 0.056496175937354565, 0.009924874890462627, 0.00931218745453017, 0.061383962232087336, 0.049173636361956596, 0.05077673980434026, 0.06066439620086125, 0.01384230182572667, 0.047071687544562986, 0.029801651569349424, 0.026062435071383203, 0.02816962217912078, 0.06767247550721679, 0.03760529622169478, 0.041042249117578776, 0.016568892169743776, 0.03292559626113091, 0.015143108587445957, 0.028952027338423898, 0.018363820854574442, 0.020066232985949943, 0.05790894691433225, 0.015835463668086698, 0.09392348224563257, 0.04428717999586037, 0.03595854601423655, 0.07371861607368503, 0.013854292387674962, 0.00959172098165644, 0.02771184852878962, 0.05398201709613204, 0.05652947843606983, 0.026865442250190035, 0.05966456128018243, 0.012620902320902263, 0.050716204302651544, 0.012213008627960724, 0.0220207598925169, 0.06689877595220294, 0.02952938600044165, 0.05535321083984204, 0.04747761094144412, 0.023414345291842307, 0.03956071200913616, 0.05679210880771279, 0.01987329833874745, 0.02801891276612878, 0.053877563415361304, 0.05859059640871627, 0.04093837558424898, 0.025217791287494556, 0.025384666797305857, 0.10260767875505344, 0.027525843420465077, 0.03633649001962372, 0.04638938665656107, 0.06572744809091091, 0.01315412058361939, 0.04573452572471329, 0.05708945981626, 0.06016930312450443, 0.012616512199331607, 0.01053467346355319, 0.031209835649601052, 0.036121743864246776, 0.01881854618633432, 0.02781725555126156, 0.011711704411676951, 0.042803078025047264, 0.042639727504657846, 0.030490853158490996, 0.12990434866930756, 0.009653375217957156, 0.02384464505926839, 0.052920482986207516, 0.036855433601886034, 0.0629032224948917, 0.036809547671249936, 0.044991478989166875, 0.06436623899000031, 0.01162597829742091, 0.06334933891360249, 0.0165079580287316, 0.01079082552210561, 0.044588720958147726, 0.029013458506337235, 0.0016275646298059396, 0.10281311201729945, 0.030988802867276326, 0.01657168603768306, 0.05876296465950353, 0.00474331304264654, 0.039821089644517214, 0.04749862177829657, 0.02603630468781505, 0.01834613483931337, 0.023230469087138772, 0.026392545750630752, 0.02263493586464652, 0.0357496759721211, 0.03589763053293739, 0.03421060927212238, 0.10158366084631, 0.024163902570892657, 0.018655614661318914, 0.04727094274546419, 0.04871740637879286, 0.07365498305963618, 0.0335311039483973, 0.07518791580306632, 0.024824169730501514, 0.03158784411581499, 0.02362093884897019, 0.03561916993930936, 0.05430749338120222, 0.05706873057144029, 0.04234645449157272, 0.0464648227872593, 0.08132729386644703, 0.029265069469277347, 0.04242198561717357, 0.06560582747416836, 0.02751568066222327, 0.030310552833335738, 0.050378456711769104, 0.04876534827053547, 0.03259245931570019, 0.0464353574040745, 0.0635928651317954, 0.022321654550198997, 0.04542211463142719, 0.05501919858423727, 0.030373374998037304, 0.03755123055140887, 0.012917020092053073, 0.032135903635727506, 0.020583066324304258, 0.01358066126704216, 0.03595638148752706, 0.029749977735004256, 0.03082282641636474, 0.006549983351890529, 0.07640066144189664, 0.04039805136354906, 0.06432348449847528, 0.07238160353153944, 0.02865970766703997, 0.026487243794170872, 0.22585519855575903, 0.12162159383296967, 0.18085307335214956, 0.2266203010720866, 0.1706327617700611, 0.10741409513034991, 0.18387133282210144, 0.06216798909008503, 0.10596632531711034, 0.2202893522168909, 0.09536458205963884, 0.12675636687449046, 0.12291391805878707, 0.17817424423992634, 0.07478898470955235, 0.12459990116102354, 0.12757557577320508, 0.06717271410993167, 0.1097111397289804, 0.1915467038218464, 0.15560051053762436, 0.1437755450606346, 0.07809951635343687, 0.15281812341085502, 0.08534717958952699, 0.2137165463396481, 0.07907636929303408, 0.20926652369754656, 0.07365604157426528, 0.10369756205805711, 0.14074196426996163, 0.10748588413532291, 0.1012963012659124, 0.21698647444801672, 0.25877344288996285, 0.26896387178983006, 0.10891318254704986, 0.09015295135655574, 0.13088506247316087, 0.09582285782588379, 0.12495956543300833, 0.11739771334188324, 0.11037808536951031, 0.08981457951345614, 0.11212886178067752, 0.10551533701696567, 0.17860493755766324, 0.09696355661643402, 0.14306445393179143, 0.14122053501861437, 0.16881240159273148, 0.14005627749221666, 0.12493948079645634, 0.13765004303838524, 0.1824678374188287, 0.09416343258427722, 0.08962900697120599, 0.10744623733418328, 0.10177961497434548, 0.14428276355777467, 0.1565512738057545, 0.1500019316694566, 0.19415472101952347, 0.11900262508009161, 0.22876865150673048, 0.08122955768236093, 0.16073874410774025, 0.1284948414457696, 0.20980264778648103, 0.13073974741356714, 0.0810583700825061, 0.148946470447949, 0.13519298631165708, 0.13360573005463394, 0.1014711054574166, 0.2517371433121817, 0.16306070451225552, 0.12681932135352067, 0.14460096934012004, 0.12867203408053943, 0.1752177043152707, 0.1304882416235549, 0.09176409204623528, 0.13288380950689316, 0.16511931190533297, 0.06734000013342925, 0.13038335368037224, 0.1161573648984943, 0.23646991540278706, 0.10336191114038229, 0.09998316637107305, 0.09219987437661205, 0.1327866840043238, 0.10915104299783707, 0.13512984184282167, 0.18501821985202177, 0.12354856543242931, 0.0916283850425056, 0.10898466621126447, 0.28406211733818054, 0.17302098790449755, 0.1683302888912814, 0.11349510561142649, 0.10412944281207663, 0.1384480952152184, 0.08644862512924842, 0.08384503876524312, 0.1622165526662554, 0.11193603569907801, 0.22059029606836184, 0.10393665065722806, 0.10622580389359168, 0.1209374541150672, 0.1286620189036642, 0.15366653645677225, 0.17154719627329282, 0.15233249589800835, 0.09352628141641617, 0.09755603982401745, 0.12597637729985373, 0.18472121150365897, 0.13337896365140164, 0.07076709730816738, 0.11496336039687906, 0.09939951090408222, 0.11978752724826336, 0.1142881637705224, 0.13142039946147374, 0.2311049832829407, 0.13061419129371643, 0.18201385677925178, 0.11793135399264948, 0.1547175193471568, 0.07970419060438871, 0.07166321136589561, 0.11824873196227209, 0.17144593170710973, 0.10588127773787294, 0.12487721842314516, 0.13203371369412967, 0.20529873589319841, 0.1660984650786434, 0.14871465574417794, 0.18802351930311748, 0.14426985782171997, 0.08071110264531203, 0.25742614375693457, 0.0928192547123347, 0.14540005289018154, 0.09115363444600787, 0.10547554772347212, 0.1371946239045688, 0.14420144792113984, 0.13519608043134212, 0.11533552328390734, 0.09451540905450072, 0.13912264044795716, 0.09811083719666515, 0.13729370358799184, 0.26658625794308527, 0.12454217140163694, 0.12467870621808938, 0.1677249406597444, 0.10449549888393708, 0.13759738872093813, 0.07622646114655904, 0.09776309478495802, 0.06487371533044747, 0.12074069253035954, 0.12891436607709952, 0.17583340699119226, 0.12457822875252791, 0.14694207800286158, 0.16203683588121617, 0.08118737316025154, 0.17240806722215243], [0.012595955980941653, 0.019968971776376878, 0.01035839006570833, 0.07667794477726732, 0.03777061788631337, 0.03146350596632276, 0.019263934876237596, 0.020610587704660635, 0.04369811321209584, 0.03142977259787066, 0.04288897377305797, 0.036349938583693335, 0.05928707867860794, 0.01671261097570615, 0.03872997480045472, 0.034195043678794584, 0.010221154661849141, 0.03512752382084727, 0.06340412383100816, 0.07396194551672254, 0.07495717996997492, 0.04738676867314747, 0.010626841419642525, 0.02353016104150031, 0.0432298867298024, 0.07859894526856286, 0.02915079060143658, 0.04494556930980512, 0.02191980236342975, 0.05038039392924734, 0.03042484527187688, 0.05029019626921841, 0.10057474712708167, 0.026655135410172597, 0.015528999934239047, 0.022231977665796876, 0.029596245448504175, 0.0571018091535994, 0.01309996161476842, 0.0543404362563576, 0.08733900556606905, 0.019066080850149904, 0.03479403742988195, 0.019634153760437454, 0.048387685857181034, 0.0037378199880809654, 0.0560017071132149, 0.06919554913682596, 0.03974621330520936, 0.030554832225399356, 0.06445146298834256, 0.020329379044207077, 0.013394667184911668, 0.03160433930211833, 0.034999776032886336, 0.03677507130695241, 0.04589300436366882, 0.05733996815979481, 0.030416309301342283, 0.037746217767042775, 0.030096006845789294, 0.023732423848871673, 0.04476632071392877, 0.014996936877391167, 0.02805653753291283, 0.023752176003264527, 0.011963515542447567, 0.03773644007742405, 0.013748088086556112, 0.009833959679651474, 0.012336250095229064, 0.05538114273388471, 0.07666529688451972, 0.029712882225534747, 0.040257143388901434, 0.06350445880421571, 0.10544569218265158, 0.02806775880578373, 0.055396056933594603, 0.04479353675352676, 0.01250269727980984, 0.02496248061236526, 0.054047689107911925, 0.08980889338999987, 0.05247103496055518, 0.08485871580030237, 0.035115333939237256, 0.044781614893249104, 0.0691751998716167, 0.025579703206728612, 0.04686934161665184, 0.01769458006934396, 0.06227469550711768, 0.027622375204893093, 0.010858585725405386, 0.042735058282102854, 0.06771207481090512, 0.025895106639446955, 0.03761639705459986, 0.07078034909708159, 0.06233321236712592, 0.025845612598849193, 0.061146115352000506, 0.008692721453761416, 0.06681890559515782, 0.03163628133812121, 0.029466024400400262, 0.07922988784100328, 0.019003370643726418, 0.04742296851639237, 0.02220984215715102, 0.007545188119235847, 0.053678647481969426, 0.04667756726433124, 0.022983287261532884, 0.05160575692674943, 0.045493343845009804, 0.05530762007193906, 0.01204969797150365, 0.054582238995603154, 0.01216246116174651, 0.03178701789251395, 0.0336386381781527, 0.05791958634342466, 0.045785113903028626, 0.03998864029667207, 0.09768318371581179, 0.004142378681405846, 0.04382315364533237, 0.03960643509136779, 0.054231399071535895, 0.03129019115918449, 0.036879528380398235, 0.052004128228873014, 0.030868261121213436, 0.017476593909252967, 0.012549532311303275, 0.04265558486804366, 0.03143616100507123, 0.0368656421612416, 0.007398093601555696, 0.035974966561687846, 0.028900628310761282, 0.03230990715590971, 0.028782593751592294, 0.01794629790154951, 0.007317707557896418, 0.014525310934654303, 0.03856236308014818, 0.018673633158739125, 0.035179869404860904, 0.008646257920190692, 0.011022736917116811, 0.022924945124291947, 0.01632182569509106, 0.07619503140449524, 0.02804008305871061, 0.011389780257429396, 0.012506282489214624, 0.04064735870010086, 0.01946550897056503, 0.028224108541118245, 0.11963108421436378, 0.006278313621546009, 0.03966307580204947, 0.01835412289282041, 0.027609311709446565, 0.032261639567358155, 0.04175874477784548, 0.044431748666933606, 0.0013416878604662738, 0.059867131124649725, 0.013296950508707335, 0.05417122319340706, 0.055096772100244246, 0.02591005476590778, 0.023739938624203205, 0.026724583469331264, 0.0399227579390364, 0.11435913853347301, 0.007217509988030153, 0.025344570466716374, 0.07399598761860814, 0.008973532323060291, 0.03627015982887574, 0.03633476993335145, 0.05350804342223065, 0.01060052783161934, 0.03581399430653878, 0.010588533876995956, 0.018391583114862442, 0.047240130470267365, 0.0177800551256431, 0.04246304377115198, 0.029839476503963982, 0.0728530293064458, 0.013617155424851392, 0.04867983250213521, 0.036435318645089865, 0.02172054037717836, 0.008504415263554879, 0.06405786518007517, 0.03303724919844951, 0.026582466006012898, 0.02966627704777888, 0.0485940419270524, 0.03779242939448782, 0.06855922578168766, 0.029350720944681337, 0.01540303330070206, 0.03760863122131143, 0.047816322052053044, 0.01819198016476418, 0.04178370129583137, 0.02073973327475999, 0.027007381598066007, 0.05147392435797623, 0.006867513143723565, 0.02751671033911407, 0.031177975037800412, 0.09444225619414023, 0.02983572759798595, 0.025062325344021832, 0.060055329597422054, 0.02635613895420517, 0.018453467204900723, 0.022404371361647333, 0.013558551203459501, 0.03789805694084082, 0.013350989885761269, 0.04399597990725722, 0.06912511720189027, 0.03740174928680062, 0.038127218572688956, 0.025944687193259597, 0.012253246602735348, 0.041096087478633435, 0.04527745435812643, 0.04851554899609514, 0.023674901042665755, 0.03729494448219027, 0.030388543648379188, 0.03326304529660514, 0.014454488842082875, 0.046443913730659654, 0.03137806822944965, 0.019347082557422773, 0.037730669137090445, 0.03286774097276585, 0.04381424787321261, 0.036279693245887756, 0.023323564091697335, 0.060177303052374294, 0.05588901601731777, 0.03360101680404373, 0.020279172541839734, 0.08177786826023034, 0.022177006151261072, 0.051489384778376134, 0.022915769634502273, 0.0325691584231598, 0.02642632322385907, 0.05626773015995111, 0.005453377887274006, 0.020616275524454455, 0.06498164311051369, 0.057383048348128796, 0.033190079033374786, 0.058445620616631846, 0.048333552333393266, 0.016147321755332605, 0.045213817951402495, 0.02620689008784081, 0.03645446011796594, 0.10908108603741441, 0.07053002395800181, 0.033116013543414216, 0.03789479658007622, 0.04272514149280531, 0.08253851958683558, 0.05057858383016927, 0.04401001540411796, 0.04316276265308261, 0.07007079145738057, 0.016420805294598852, 0.02877605606668762, 0.013821509816417736, 0.07132732974631445, 0.08261788782796689, 0.025459180120378733, 0.04596306649701936, 0.06132241232054574, 0.033792180474847555, 0.02735298832080194, 0.05145056578995926, 0.05997549995247807, 0.007641437463462353, 0.02130514632777444, 0.022493335784279873, 0.05341422577787723, 0.02936117716931871, 0.06190530104296548, 0.08122106920927763, 0.022225380609078065, 0.018990096802424108, 0.07317972356187445, 0.021791735664010048, 0.028698876100991453, 0.030373429280838797, 0.040744514736746035, 0.0719031345631395, 0.033865194235529215, 0.03632823224844677, 0.029159998321639638, 0.036271550825663974, 0.030000214664531604, 0.031076778325119188, 0.014552223329831446, 0.018953306633712988, 0.008873777497293693, 0.02013569970482162, 0.017633131938055158, 0.04810476728848048, 0.017230543540790677, 0.06685376872441598, 0.02002308833678918, 0.042638960760086775, 0.05195053753310016, 0.06472035963088274, 0.02310748800768384, 0.02730939074951623, 0.050684832236064334, 0.040979657654783556, 0.007820129660623414, 0.05943754381899323, 0.05244086729362607, 0.03404253954067826, 0.04892727726006082, 0.026175441686064005, 0.031185404996254613, 0.014281723648309708, 0.02679275248997978, 0.0315486824672137, 0.040458644540714364, 0.036470375156828334, 0.0568037015785064, 0.0036296207940072884, 0.041235499283564944, 0.026727575808763504, 0.028964413995189325, 0.022337308353079215, 0.05064178258180618, 0.09896058695656912, 0.07804460251437766, 0.13828751311770507, 0.2417330944112369, 0.15930096911532537, 0.14259283138172968, 0.15560048339622362, 0.07406047558678047, 0.1643168492508786, 0.0916630717526589, 0.25643168283360346, 0.09385386455271925, 0.08499002589711122, 0.06422767535384212, 0.08705715569002287, 0.16707832392837318, 0.12389198557606765, 0.12216219625302724, 0.115619245916605, 0.16820892611784594, 0.17531261779367924, 0.12657194105642183, 0.16120732682091848, 0.12420574016869068, 0.10247051968638386, 0.16581020983202116, 0.1666359869497163, 0.1014151806011796, 0.11313481708722455, 0.13250729042504514, 0.06491790153086185, 0.34208834224513596, 0.1456929086042302, 0.20242809850190366, 0.1336350291967392, 0.10495760158768722, 0.16015592323882238, 0.10059309471398592, 0.07776146342179605, 0.19979090429842472, 0.11693176334457737, 0.07643791979977063, 0.10332823544740677, 0.12583132008356707, 0.13740207920117037, 0.0835797790704029, 0.1482861473092011, 0.14171030159507478, 0.12873950760279382, 0.13992147972541197, 0.16641516451324734, 0.08863813549812351, 0.11870837158390454, 0.06144095238830362, 0.1260258832148143, 0.16026271108005727, 0.09076902044138738, 0.1462102915559496, 0.12133929612381117, 0.1548279169946909, 0.13049814823482717, 0.0707410890609026, 0.16463002030338558, 0.12405437257673059, 0.14157276254679474, 0.0825033171900681, 0.2198337023811681, 0.08626537996211223, 0.10140806276883398, 0.10786445239292723, 0.1530350103442158, 0.14437826057629927, 0.17536966901804718, 0.1875557236905609, 0.2668415228171008, 0.16995277468647274, 0.23731252018894466, 0.15123796463012695, 0.17286389347698006, 0.14546310236411436, 0.1089261629219566, 0.06693095886813742, 0.205115300736257, 0.13294771393494947, 0.26634773931332995, 0.1390279983835561, 0.0945309746478285, 0.11128544275249753, 0.13290735467204026, 0.20394318577434334, 0.1518426886094468, 0.10167751581008945, 0.17684727401605674, 0.13565652072429657, 0.059984076635113785, 0.1258225669818265, 0.11092149692454509, 0.14202982373535633, 0.1796666413013424, 0.14903039165905543, 0.1524831171014479, 0.13093298061617784, 0.13376502293561185, 0.1284568299140249, 0.13002539931663445, 0.13326334128422396, 0.08116860488163573, 0.1591580424989973, 0.09986074508300849, 0.13947854563593864, 0.13337094336748123, 0.20154322098408425, 0.14540974237024784, 0.19171924170638832, 0.13941460049578122, 0.1080296892406685, 0.1257758702018431, 0.10188755632511207, 0.12404305461261954, 0.129252588642495, 0.12052156643143722, 0.08999664402965989, 0.1187420269208295, 0.14138244704476424, 0.11088613846472331, 0.11764467294727053, 0.24387275959764207, 0.22515972730304512, 0.1461958387600524, 0.12536204526466982, 0.1306808777153492, 0.10146897485745804, 0.14006887110216276, 0.08726482811783041, 0.13421312746192726, 0.10368072081889425, 0.11671721057168075, 0.07349628728947469, 0.13042382150888443, 0.12865200372678892, 0.07619901440505471, 0.21010869422129222, 0.1264852514224393, 0.14263705829424517, 0.1318673233368567, 0.07052183404032673, 0.11231790163687297, 0.13179083886955464, 0.16952977595584734, 0.18591938221028873, 0.11509803602738039, 0.05740870375718389, 0.08845208119601011, 0.09036850157592978, 0.06949999422899314, 0.1532568098711116, 0.10640298974301134, 0.08601063756006104, 0.14375740103423595, 0.09246237243392638, 0.074796794647617, 0.10258362468864236, 0.1738766748458147, 0.15885528017367634, 0.11557607751871858, 0.13941426122827189, 0.12768708621816977, 0.12972016712384565, 0.09475248919001647, 0.11487725430301257, 0.05390060307191951, 0.1895866332841771, 0.1348051628363984, 0.09499499082033123, 0.10886413125055176, 0.14100621294762405], [0.004473430827991771, 0.11083380984408514, 0.04770180569695575, 0.049577978772244284, 0.022400724235922098, 0.015821138097505485, 0.028080744269703115, 0.016298714792355895, 0.10341081315917627, 0.09695449138858489, 0.03184118534305266, 0.023124062921851873, 0.03432180419830339, 0.060939657501876354, 0.05056513526609965, 0.013292819926781314, 0.031650591641664505, 0.017624986125156283, 0.03128383667873485, 0.017360895206885676, 0.019877557842327014, 0.01760047404760761, 0.016527359041252306, 0.028560261574706862, 0.047913528978824615, 0.009275929935808693, 0.05211534011842949, 0.02925238764977881, 0.011818445603629308, 0.03305734062035169, 0.01052870405172663, 0.06728633479880435, 0.07325652015528508, 0.03806151941950832, 0.04071414350931134, 0.05695806150989873, 0.04160945350304246, 0.043187257767255814, 0.030803226932351078, 0.03342034328462822, 0.056963489790047915, 0.05989700023617063, 0.100585420482925, 0.05386928528813379, 0.010184794514706092, 0.00880173234535115, 0.0024583211343269795, 0.016550342718671476, 0.04778784054464527, 0.022046754569081322, 0.04351610976404377, 0.039747848574604304, 0.03245415013017399, 0.022727442240076404, 0.05039555240156395, 0.04216651378997734, 0.06007574671613319, 0.034658194719148536, 0.05084597073229296, 0.03776895547551768, 0.056762874126434326, 0.1055024109248604, 0.02627852133342198, 0.05941008350678852, 0.01467384394657399, 0.031255185537572415, 0.04106040332200272, 0.010150553941327547, 0.020516101703313843, 0.012048295948521366, 0.046197625874940834, 0.04067280715597527, 0.015720166997717958, 0.017835133509444337, 0.06456380124602999, 0.01416624038081084, 0.01969811586397035, 0.030233583213495355, 0.016860864091930643, 0.0677135879439967, 0.050603190902620554, 0.006687334530787277, 0.03509751221697245, 0.028054827624665837, 0.0529339960111039, 0.020029855027262653, 0.042920284771493504, 0.007099238789773413, 0.03196030555825148, 0.03430843705843602, 0.038673602111105404, 0.025691898972062126, 0.032449010227407725, 0.03498575410672596, 0.06013325255896364, 0.044128236560417075, 0.06080572147454534, 0.016800447333870188, 0.017725159946296896, 0.06140522751957178, 0.05036605309162821, 0.03853102494031191, 0.018135229192141975, 0.05824008557413306, 0.025618759682402015, 0.06256624164858035, 0.05128384295052715, 0.001905930440573554, 0.041102357142205746, 0.028746064818863357, 0.03969153695340667, 0.06148528786642211, 0.0516449830361775, 0.04488929161535842, 0.06743603319461856, 0.030630312460873808, 0.04039138814966593, 0.03214420551168067, 0.020082841826868907, 0.05374680293191757, 0.015427165398640292, 0.026915808208286762, 0.05242652306333184, 0.029236411542764733, 0.03405918400468571, 0.03690271392198546, 0.04398844477587512, 0.046056928246148994, 0.05604508924963219, 0.02801953023299575, 0.016478904855570624, 0.03941875569788473, 0.02520053953464542, 0.03326779843441077, 0.06223225314170122, 0.049032786062785556, 0.04186855209991336, 0.019288475791524564, 0.00686271590114172, 0.004584465450274625, 0.019856275591467108, 0.010399927435043668, 0.039130310461457284, 0.02081756802674915, 0.01970728117573474, 0.04147780753139939, 0.00577724477209683, 0.0442225529280092, 0.011774848880512374, 0.03617942951885717, 0.0276757640364979, 0.02243058316941772, 0.05945626460015774, 0.11317280826291867, 0.0262695748492011, 0.04214122139715722, 0.014493033023817199, 0.04471573253561344, 0.010773374449594744, 0.08420857747218438, 0.0375479023371424, 0.018646539255444492, 0.04919670655259064, 0.01075949756029461, 0.07356529430087123, 0.04080895520746708, 0.040389057381876876, 0.05265990179032087, 0.011426189598361296, 0.015848530556208322, 0.014372523508167692, 0.028099575312808156, 0.016787173492567878, 0.02144558441692165, 0.057059984255049906, 0.0102221665271957, 0.03301438935367124, 0.0489117727348847, 0.07376555034092494, 0.03697808898453202, 0.023491884881098355, 0.05923747776874474, 0.032716135893549235, 0.04326248015942318, 0.07779528839247567, 0.09601020134453263, 0.045120393857359886, 0.06608847621828318, 0.051150409039109945, 0.011149604305891054, 0.016068703295396905, 0.02037963134768818, 0.05257727997377515, 0.053007094588662894, 0.00550413697159716, 0.012497017941703754, 0.045835525662239106, 0.04082125026200499, 0.04083744689290013, 0.04287584072777203, 0.048866025903927426, 0.07964831324560301, 0.020329445201371397, 0.055817708772208006, 0.03881494774084006, 0.05788646704916443, 0.024693821457081606, 0.028011499771050045, 0.03947723184579185, 0.017586355430207083, 0.03681915572711399, 0.0334406348743609, 0.008383027893224997, 0.04776330811104604, 0.03530045186302491, 0.0013351225040553669, 0.08956282266548701, 0.0351857930155737, 0.04392586688378027, 0.031053565642131225, 0.028228809092459933, 0.009971054287494292, 0.009517576611999954, 0.014213842156875347, 0.052270595716046434, 0.016128217601882558, 0.02477227706861283, 0.06733644460993153, 0.04667206434533, 0.08594726238931928, 0.020977907547993318, 0.03323382757870214, 0.04772269779017993, 0.02523527034957494, 0.037630941452724595, 0.04825779729123626, 0.023651384715256945, 0.009051390823775103, 0.02039877960591444, 0.07327436562627554, 0.018786931543477943, 0.010801900909947497, 0.026366644372631396, 0.02078468961242054, 0.023271683304171478, 0.04249001553814326, 0.07359903784734861, 0.010940045550731676, 0.007631960025589381, 0.05023362680471369, 0.01828568076182689, 0.007881057864454175, 0.027041571281318153, 0.04935109701805881, 0.03963170712813735, 0.08364216358001743, 0.05781186890921422, 0.01297616629329111, 0.04209728964737483, 0.04399264830031565, 0.05484145972877741, 0.07169668349836554, 0.07681655591087681, 0.10888920990484101, 0.05521703903962459, 0.058429546122040064, 0.01059630819197212, 0.04819236955206309, 0.02844795385109527, 0.06519089652491467, 0.06472752496067967, 0.017356574635154436, 0.07812954152801208, 0.03887835344565766, 0.028277619509026408, 0.060611640103161335, 0.05324516199263079, 0.06295937805303506, 0.029321584650980573, 0.027630251300122057, 0.03580077983705061, 0.06383711059710809, 0.011166804320445018, 0.04317976674064994, 0.02831391604351146, 0.04724042224032538, 0.035112691045339615, 0.03545652170266424, 0.02116919674777559, 0.048214778171053956, 0.05668477813846298, 0.06417394216571536, 0.01850988399902625, 0.016634394547769, 0.02173029092539634, 0.029652733488806655, 0.07470144690679652, 0.07328716958207743, 0.048129808623343706, 0.10718646020229373, 0.037974297135536156, 0.08217215817421675, 0.051438989982541115, 0.01832220969455583, 0.0408685373674546, 0.04493620552654777, 0.015571240435487457, 0.05828059411474636, 0.048162486869841814, 0.03651294305122324, 0.060678292598043165, 0.0819944634235331, 0.020048032980412245, 0.025689144119886414, 0.038793333007821014, 0.060833602478461604, 0.084063784884555, 0.011311160949324923, 0.032776206598750184, 0.005933798492021326, 0.01518449922358351, 0.04825510350721223, 0.03683102669726525, 0.03363991043131266, 0.03794991397964103, 0.023360398365184665, 0.05554206409890737, 0.023521217949954525, 0.020575948491958634, 0.038487300143710206, 0.03382229046630008, 0.014847562482048358, 0.046294951545340676, 0.01868798247804599, 0.04370866782431092, 0.0176664700598589, 0.00724684729773019, 0.049470278301409314, 0.033419037104717324, 0.03455595984788878, 0.03224606379600508, 0.0408275199255773, 0.03835423603387816, 0.05084757546761206, 0.03829255720068302, 0.01502683143397527, 0.04278481864769544, 0.036560661026409695, 0.06396483802901846, 0.03583205012338502, 0.023032462390671884, 0.02549522729324443, 0.15312997810542583, 0.20802610740065575, 0.18403160279350622, 0.13137351269168512, 0.10626267548650503, 0.12551873257117613, 0.13855067613933766, 0.1416168130402054, 0.15012641570397786, 0.2776802240737847, 0.10790144612214395, 0.14457951406283037, 0.11066363326140813, 0.15406003248478684, 0.09940303250082902, 0.19957723362105234, 0.09523463581821748, 0.10523016231932811, 0.08391005599073001, 0.08239577617496252, 0.17972747875111444, 0.12475767412355968, 0.16319485088544233, 0.10207726114562579, 0.18100624584725925, 0.15757082695407526, 0.1886756864509412, 0.1480635471109833, 0.10967054976416485, 0.16352578598473752, 0.10594493789332253, 0.16163920078958782, 0.1485292799770832, 0.09663681486355406, 0.16707267851701804, 0.1334287952631712, 0.12113673985004425, 0.11949695141187736, 0.24247481461082185, 0.14804479240306787, 0.15845707511263235, 0.14718119374343328, 0.27690560849649565, 0.13131996270801338, 0.10499206438128438, 0.15128238153244766, 0.07446073660893099, 0.08876180529062237, 0.19266467168927193, 0.10593748079346758, 0.1154233528567212, 0.11892136372625828, 0.1037910913250276, 0.1541689916380814, 0.11599974121366229, 0.09651874977030925, 0.13224929784025463, 0.11597648103322301, 0.13006394010569367, 0.12755616967167172, 0.15148820834500448, 0.118964979957257, 0.11279510174478803, 0.18629834401820386, 0.09224016578601939, 0.08872311522385903, 0.15373018304152147, 0.10912944522819348, 0.08386859750109059, 0.12471639205302511, 0.2277852642749037, 0.14647501520812511, 0.10152349514620644, 0.1471485969211374, 0.20519194805196353, 0.13876695239118167, 0.07637934865696089, 0.1454265293266092, 0.11550686694681644, 0.12589350103267602, 0.11097363555537802, 0.14264461717435292, 0.13389465026557446, 0.1085381426715425, 0.14849383330770902, 0.10103566239454917, 0.2517091062452112, 0.15410268519605907, 0.10248158659253802, 0.12432487734726497, 0.1646466851234436, 0.1638343972819192, 0.12466641116355147, 0.11110017555100576, 0.21912117275808538, 0.13835076615214348, 0.183234785550407, 0.1424234283289739, 0.13099788927606174, 0.2211968113801309, 0.2959178611636162, 0.14883950618760927, 0.130747238440173, 0.09726768958249263, 0.07983780772026096, 0.2542338807668005, 0.07587768057627337, 0.10846582440925495, 0.10214876516589097, 0.18038142366068705, 0.10266767482140235, 0.139443519658276, 0.2193433115524905, 0.2135533315262624, 0.1887601912021637, 0.1281234792300633, 0.08522786599184785, 0.11030381971171924, 0.10547358675726823, 0.16260338548038686, 0.13356177455612592, 0.2964040993579796, 0.1824897676706314, 0.17375162084187779, 0.18655970213668688, 0.2384205407329968, 0.2556913468454565, 0.16261467630309717, 0.18515147055898393, 0.1283081221793379, 0.11753171043736593, 0.09637293938015189, 0.0666636364268405, 0.09167177735694818, 0.10268520816628422, 0.16990620004279272, 0.14190987231475966, 0.15429639337318285, 0.14520776963659696, 0.13516919687390327, 0.14387155776577337, 0.06682614556380681, 0.1641182963337217, 0.12019128272575991, 0.08513906611395733, 0.11688673576073987, 0.09016723451869828, 0.12347194525812354, 0.12146964270089354, 0.12935200759342738, 0.14472341776958533, 0.07949909660965204, 0.10713995341211557, 0.11114904364304883, 0.08653108749006476, 0.0828649288575564, 0.2844941812966551, 0.0932743956467935, 0.09305933397263288, 0.17101654117660864, 0.12191651229347501, 0.15063056722283363, 0.09158092830330133, 0.06808585261127778, 0.13596076225595816, 0.14529061876237392, 0.16088013723492622, 0.17087801146720136, 0.1259923500141927, 0.10928726568818092, 0.17028209487242357, 0.1356640796044043, 0.14209622517228127, 0.13256117967622622, 0.08564821843590055, 0.11757699586451054], [0.026956425314503055, 0.032611434547496695, 0.03479017995830093, 0.09467137711388723, 0.03169808230761971, 0.006392254494130611, 0.03425592862601791, 0.051253149418958595, 0.06490304839930364, 0.027272564957716634, 0.07450689734624964, 0.015338842191600373, 0.06585658687566008, 0.02082732705665486, 0.05007880886218377, 0.043307327931480746, 0.02541041380858847, 0.01039572136609682, 0.04411111033654638, 0.013441938175154584, 0.04660467224727784, 0.04787604670439448, 0.03132467770150729, 0.027721756836399436, 0.01938052585215441, 0.018618188366027813, 0.02589034671629114, 0.030172426852264574, 0.05491744547284075, 0.029763677357030765, 0.058614548694874556, 0.09796673671475478, 0.07864261578236308, 0.041053136211952994, 0.049996882544032166, 0.015002531398619925, 0.08035308721342257, 0.03469403154615845, 0.027554409744750177, 0.039583805948495865, 0.008194948164080935, 0.054622961274747334, 0.021782850247940848, 0.03795411750408156, 0.0308465412152665, 0.021379914101479307, 0.08022803999483585, 0.02158246698257114, 0.049328423770410676, 0.048000496812164783, 0.033081947692802975, 0.06840420088597707, 0.040594595817050765, 0.048120115750602314, 0.05743038295102971, 0.01638380138735686, 0.02327105905195432, 0.027306798745744994, 0.02135824678199632, 0.07115493435412645, 0.040473534991698604, 0.0893116629283343, 0.03526387204016958, 0.01526369443828506, 0.02470822336285242, 0.030038986155497174, 0.008962188913886036, 0.013028965647598463, 0.015332647166880113, 0.05434898240491748, 0.030537217456315244, 0.0658016526805503, 0.05621099445436682, 0.08299032212900263, 0.027087160352883593, 0.03202359591211591, 0.041600724150027545, 0.008011388326329845, 0.04677196166345051, 0.06027006557477372, 0.040629204495676925, 0.04044204418148313, 0.013039531286007591, 0.005839787465187588, 0.023587526088314395, 0.028413886304146478, 0.05591513283018555, 0.06122570072433778, 0.06620724698794739, 0.0214241223542818, 0.02357933617063931, 0.07556398705180202, 0.03257144169349756, 0.10059547637190137, 0.009773899152475809, 0.052852232541356764, 0.03779604259346213, 0.04934410471469164, 0.015780529472976923, 0.009174944417152022, 0.02948346614305462, 0.03302890321772013, 0.048137998541018794, 0.013625329227319785, 0.03379186834873898, 0.0408686357550323, 0.013698080903850496, 0.013698004568660898, 0.0424831691198051, 0.05614007736689278, 0.015502389487145203, 0.07855144781725747, 0.07333057546722037, 0.009165243062722896, 0.035412050517542024, 0.05468047051025288, 0.05047819118148514, 0.03155780537053943, 0.06501875897603375, 0.014001541272071856, 0.04031131762479033, 0.06517422491950647, 0.038612971614514074, 0.03709596408797162, 0.02480760499435876, 0.03720705044854965, 0.03453553933650255, 0.03647775422515614, 0.03115384972521237, 0.07518354603754622, 0.03529244514980486, 0.03304421096774084, 0.0744194681090968, 0.04371703755376594, 0.024438619347555295, 0.06582204944321088, 0.022596376415874277, 0.0569938203053815, 0.029867713738765036, 0.0015028216917666473, 0.021170343471957103, 0.04782331096274512, 0.06195311740572963, 0.03016168564291937, 0.011907632246480455, 0.018897839788613573, 0.009114079825979258, 0.02247096278837749, 0.024433951026626995, 0.0325633365926998, 0.03789934955005135, 0.011591678352228232, 0.022183796590460197, 0.036089625409139056, 0.024524452331076776, 0.033706535784793754, 0.06101801472582987, 0.03404980665072799, 0.0396316324892853, 0.16145093446331366, 0.01276067374939365, 0.03054609608703426, 0.05659873989809837, 0.012067416217178106, 0.02496075034806771, 0.04591887351125479, 0.05960069077887705, 0.04198120587638446, 0.026471876672336032, 0.017984804763857807, 0.036905699476067505, 0.05731206679982798, 0.03706114167081458, 0.023250333199809705, 0.034125419200531075, 0.01867212511466018, 0.013006331415713897, 0.08517506239669663, 0.02313435120907213, 0.05040842421086771, 0.04391131230763026, 0.017513635135920982, 0.014680325652339628, 0.04194575920701027, 0.02041427734574037, 0.042381731527192254, 0.05003112481374826, 0.06689294733639274, 0.022839219010035907, 0.022551657565470253, 0.02329785779251584, 0.0037201806221024264, 0.014126066866862987, 0.05136508394830993, 0.015424929625753845, 0.10032101574220828, 0.05009828281721898, 0.04652837098443082, 0.024503843526222875, 0.03294572839513421, 0.04473624464922717, 0.034637580825282, 0.04255796064223562, 0.012695692995164012, 0.038986393184001954, 0.0509374677868826, 0.08359324120517288, 0.0318072246653693, 0.05017607346443193, 0.04712586517312697, 0.009694890534904386, 0.013782909655544375, 0.029347199347934554, 0.03596016771293112, 0.02314113316658352, 0.08690329787454434, 0.03474018889080201, 0.01195939683488437, 0.047555947809347084, 0.02717109174201531, 0.08471456103559051, 0.09087068534323148, 0.024288155903507556, 0.07731685335082666, 0.0432605632979955, 0.03426825760730675, 0.028644220105239322, 0.06587837463510887, 0.01956143685882645, 0.025629433038245355, 0.01341713432754789, 0.03604258257629616, 0.030417612088578086, 0.025924816295238476, 0.048840509594551156, 0.009671924669029457, 0.024897286967773522, 0.04835728409567049, 0.019709695064063584, 0.02286735107190907, 0.03142405254766345, 0.040008171927183867, 0.016230172577447126, 0.05850986431219748, 0.030124671557652097, 0.02770471542940608, 0.022745240213615552, 0.053893878789884705, 0.028095051180571318, 0.09499157778918743, 0.01374230272735336, 0.028492737162326063, 0.02874162041449121, 0.009962710851271237, 0.03566477427791272, 0.07200291992298194, 0.010594486325447048, 0.028784144204109907, 0.0390072547431503, 0.02030006972407656, 0.03429189437468137, 0.018749552745638148, 0.027173098509332964, 0.022795986151322722, 0.015687694008062993, 0.03584257759419935, 0.06023159942456654, 0.13729865689362797, 0.056566495914012194, 0.015111841693786638, 0.0325623832509986, 0.042257030361465046, 0.04168913387028234, 0.056047789819006405, 0.0390914473682642, 0.025212266316105212, 0.032902481965720654, 0.021713049350572482, 0.106094609147736, 0.01186808552925608, 0.031249947247228453, 0.057803875766694546, 0.023980711686557958, 0.06030628577406917, 0.026069914223626256, 0.0984869288014514, 0.02781864654804979, 0.05015634505876473, 0.06386656580226761, 0.018991246919280717, 0.03974399110302329, 0.03161604403119002, 0.03952967921005828, 0.027613544071625386, 0.025391859268503528, 0.03403230044724686, 0.09925536971007075, 0.041196290137512345, 0.02137070638127625, 0.04756898585973041, 0.1216994896531105, 0.03167542263067194, 0.026740734299112643, 0.012004827298889202, 0.010336231656505592, 0.024981901980936527, 0.0304789041568126, 0.03828255559450813, 0.07207256475729601, 0.01190366960197155, 0.045457819144108465, 0.06699606430317674, 0.047899588476866484, 0.007796763459087482, 0.005558177196819867, 0.013996542165321963, 0.020093883287959864, 0.0616964954616768, 0.05363671401781695, 0.022787506159927164, 0.052011480155800066, 0.033869794702955654, 0.03284775133111647, 0.0026937301653171225, 0.01905668992549181, 0.058658829890191555, 0.059606607604239664, 0.05661703998755131, 0.02221561818649726, 0.018679818005434105, 0.0447565633803606, 0.018922504536541443, 0.016064715205824802, 0.04184168211317488, 0.051286017655261924, 0.07969655030007873, 0.004276887222658843, 0.014661068828510386, 0.025214176392182708, 0.05862216864313398, 0.018645818311987177, 0.01725363408747528, 0.07444653487099068, 0.0186792429470058, 0.04303066206297704, 0.09552242287567683, 0.02096836395295603, 0.056372685956635644, 0.006732477041493569, 0.07546348923019, 0.0171143104920962, 0.006593158959211516, 0.1246240705783878, 0.16943855370794023, 0.07695139438978263, 0.09020040809576, 0.18976359521704061, 0.09775064366736583, 0.21475551916020258, 0.10294976218470506, 0.13906302436121873, 0.10543796366878919, 0.228518190660647, 0.12474959955683776, 0.09746491935636316, 0.09224691720945494, 0.13574072692011083, 0.17698991564767702, 0.1452945406947817, 0.12717751998986515, 0.19750729469316347, 0.17199660358684404, 0.0991520220413804, 0.0887449708368097, 0.10390382313302585, 0.15231181415063993, 0.09295156904097114, 0.0854667035330619, 0.08746269571461848, 0.08479053660162858, 0.12228798307478428, 0.12561524739222868, 0.16934952991349356, 0.14464663474687509, 0.14192199095019273, 0.1125484678362097, 0.09973725849496466, 0.07193067629954644, 0.1797660602522748, 0.11369724797883204, 0.1384463853069714, 0.11917448442961488, 0.13051979350192205, 0.10550787991711072, 0.10596628460500922, 0.11310346876936299, 0.22163203731179237, 0.10827173625252076, 0.12641343527606555, 0.1591270470193454, 0.08831093234143086, 0.13989862666598388, 0.0791124537853258, 0.16281367705336638, 0.11922506242990494, 0.08486814065171139, 0.11007351814103977, 0.2164171292845692, 0.12224556106541838, 0.15864512430770056, 0.14673344205532754, 0.1420780811458826, 0.135646966951234, 0.11438116378017835, 0.1420154252222606, 0.14141682162880898, 0.17128591957901204, 0.11949426441320352, 0.11418597639671393, 0.194512811090265, 0.10755654677216496, 0.08683294736381088, 0.12147197686135769, 0.13146276718803815, 0.13901906886271068, 0.22585171088576317, 0.0946102478940572, 0.12036899104714394, 0.13089701826018946, 0.16079025848635606, 0.12510718751166547, 0.11522845045796462, 0.12126000252153192, 0.1123895752908928, 0.15355354680546693, 0.14261632226407528, 0.1621567601604121, 0.10261400270142726, 0.10345147097749369, 0.15003458277455398, 0.2086017629397767, 0.11300303201590266, 0.16996945307723113, 0.11121317877301148, 0.17353256259645733, 0.10194975084492139, 0.11589531467429229, 0.17828819741095814, 0.1776620860078505, 0.13938294005181107, 0.1178682909480163, 0.10441033595374652, 0.16283737149621758, 0.11689573313508715, 0.25814327384744373, 0.14793329552880355, 0.15824561645942076, 0.1446549535862037, 0.11386239661702088, 0.11638425343802997, 0.08990633101867777, 0.2193682137876749, 0.15336954167910985, 0.17403332144021988, 0.16106802358158998, 0.09674756534929786, 0.09592077721442495, 0.16864544126604283, 0.24948475988847868, 0.10047135196094002, 0.13913433839167866, 0.12206729634531907, 0.13560933539909975, 0.1319169242467199, 0.13561180526656763, 0.138367159558194, 0.2730884147541863, 0.12534502760640212, 0.09610073827207088, 0.19846743531525135, 0.11686863244644233, 0.15769452388797486, 0.15237776775445255, 0.14083813982350485, 0.15421373423721108, 0.0943274073568838, 0.10668584385088511, 0.13562610878476075, 0.19802199064620904, 0.11376662139913865, 0.11090870653944356, 0.0871499182124223, 0.07963820307382516, 0.15202642232179642, 0.14360625057348184, 0.09768665102975709, 0.10283993450658661, 0.0918357724856053, 0.08521956750856978, 0.09817138966172934, 0.05635534938690918, 0.12519323932273047, 0.13113484478422574, 0.1493701884256942, 0.13644340421472276, 0.13565637144659246, 0.081489572301507, 0.14222943516714232, 0.2395451446729047, 0.14461892337671348, 0.13507496193051338, 0.26358097206268993, 0.06698754868869271, 0.11636733077466488, 0.15583071032805101, 0.09811753433729921, 0.10480649183903422, 0.14474541587488993, 0.13465751361634049, 0.07484613771417312, 0.08456484228372574, 0.1365374627390078, 0.10500902775675058, 0.2050005333232028, 0.12965836615434714, 0.11451129322605473, 0.12603756758783544, 0.1232500643070255], [0.058664217458239624, 0.061041050989712985, 0.008956700413753944, 0.03751895942592195, 0.032422187738120556, 0.020862517579059516, 0.041055982666356225, 0.06477194186300039, 0.025655392091721296, 0.0497605080849358, 0.03539921263498919, 0.022927791578695178, 0.03822934487834573, 0.031113836515162672, 0.05201954115182161, 0.04703749955764838, 0.04170262314645307, 0.03887412617249148, 0.026010623833696758, 0.043137270092431984, 0.026716992358810136, 0.025562799203076532, 0.027359524309369068, 0.01857159675897232, 0.07510942287210907, 0.018143542942457964, 0.02965465374290943, 0.03626441263726779, 0.0687626302242279, 0.01772283935653312, 0.0446411479663636, 0.049393539383475266, 0.027280598812337433, 0.013761216042829412, 0.015419177345133253, 0.03524196892976761, 0.03380925241591675, 0.02565478310654206, 0.02358610795012542, 0.02955506176554731, 0.02778587839566171, 0.03032294288277626, 0.0636215807337846, 0.024179154341774325, 0.0311756714114121, 0.05226454996903028, 0.06192556209862232, 0.034316328420702896, 0.024590514500492384, 0.02958721754008106, 0.030781836115888188, 0.01488967745431832, 0.08415312759046044, 0.03058820597029158, 0.04140894640503185, 0.021917120453768542, 0.0903338012950761, 0.01447422064042517, 0.01427927752956748, 0.01925084593572787, 0.03510821271421654, 0.05175486499709742, 0.06793810161096708, 0.04297894073118057, 0.03448401138718639, 0.02753946670730199, 0.056190906425139735, 0.041468616774571795, 0.05671621805855206, 0.013357463109839176, 0.005711831875877189, 0.05051750210779054, 0.09386579998369728, 0.012257976839984102, 0.05789473160569157, 0.03953298706827419, 0.046448497234710624, 0.026418650689135705, 0.012722831003234854, 0.07196671329438686, 0.04341980189617191, 0.10921415353992156, 0.060715184547007084, 0.06965030330632414, 0.08825767412781715, 0.062045126754258356, 0.016186247613014917, 0.05383761466613837, 0.07173299190721341, 0.047177420263843875, 0.04616222331034286, 0.08227654400148562, 0.07833195530942508, 0.03971548245421477, 0.04256546863221696, 0.040118430475039144, 0.07483171205967665, 0.06274083549422876, 0.06185005472174712, 0.02603787210370813, 0.04141406934442265, 0.03409874259627291, 0.034956319257617, 0.009263187896327248, 0.0025664367837764856, 0.0503973844461143, 0.01506879712854113, 0.01423860783688724, 0.02648837355497692, 0.05163396702014974, 0.05047569417261651, 0.05125789577141404, 0.007371681625954807, 0.06760579587093421, 0.05894835399729865, 0.05432752373495272, 0.010179194904464697, 0.003819114844580846, 0.02733347874267825, 0.010535788805490094, 0.049939319025725126, 0.013878923208851899, 0.05231969790267093, 0.017452658586470143, 0.014830610980944974, 0.058753248038036485, 0.06746301853231021, 0.0351208334655634, 0.03346244298986026, 0.02042572253516742, 0.0326930623102401, 0.04048445262014866, 0.06523962212460381, 0.013535408918479723, 0.04228853813505598, 0.043964227861059565, 0.026169616462928907, 0.01867446436413697, 0.019047862184899192, 0.015327103535777755, 0.021014480585498468, 0.04757509267489825, 0.0346430498175323, 0.02286971067743642, 0.10957462526857853, 0.03241953805887273, 0.06382810643741063, 0.048853506932833364, 0.050072267784604, 0.02780719457327255, 0.06554340225245271, 0.03220325841435364, 0.031340209368084154, 0.08506121100591761, 0.07345104257443122, 0.0359019935131073, 0.011800805389481996, 0.028911539153861146, 0.043982802757195065, 0.008518966447029794, 0.03404863278514572, 0.03716387526531305, 0.014939020520874431, 0.0497231581248343, 0.04538970101358635, 0.05892407601433141, 0.038390201782541614, 0.02987695877839412, 0.04904011084831186, 0.007701244388174797, 0.007325777883774468, 0.07069880275854043, 0.06941124184855393, 0.028716460335999727, 0.01923607931738453, 0.022067080085564936, 0.00912258102159415, 0.08148854771362883, 0.0380909983733935, 0.015550360216626098, 0.03625058748626283, 0.03988247670765434, 0.020746347294854264, 0.04389219797615494, 0.021348558998267566, 0.06897512025066785, 0.038366856785225015, 0.0513869361685855, 0.04045188293925353, 0.04655286270592894, 0.0011257956170343927, 0.045553472225687335, 0.060388700637434206, 0.062298050682459555, 0.002231758079558079, 0.06386749539524317, 0.041411144858492274, 0.0352648660939719, 0.05495407618582249, 0.03301645888547812, 0.05528720295322793, 0.009443549289634185, 0.032455446132059605, 0.036114890660558424, 0.05276217058833156, 0.04387181139151965, 0.022094209611948048, 0.04729672707617283, 0.04432875722912805, 0.0432505718698459, 0.025699736051527516, 0.04667385567777923, 0.038566539463187964, 0.02544986892358533, 0.019528295512178113, 0.08642004523426294, 0.006593898986466229, 0.01998985369157578, 0.03007837850600481, 0.03326208516955376, 0.017839674605056643, 0.03936965011858514, 0.044905834299113066, 0.02226693239728255, 0.023958138522825072, 0.026568128561068858, 0.026810314672599946, 0.03948184588391866, 0.04004459907966001, 0.04965979313211782, 0.031354221116219244, 0.05141498341358133, 0.03534693829715252, 0.11589553180549826, 0.030782735174787895, 0.02191782443385039, 0.052020389320594926, 0.03656817580174122, 0.047479212284088135, 0.03184148729113596, 0.05942107577409063, 0.047822907234409025, 0.08652462105133704, 0.0654511350606169, 0.07413791000310864, 0.018146837229973505, 0.04326509251924498, 0.03391784855297633, 0.0615939823910594, 0.0070083464795191374, 0.06468933700983014, 0.12657560514552252, 0.10078782747898783, 0.06309150239186627, 0.03940836054139903, 0.03128514285864575, 0.042448438304875574, 0.03279877467347043, 0.0194089937888618, 0.02047837515627699, 0.04313348725970302, 0.03692649996706417, 0.0941986349810447, 0.032877715437539985, 0.023502045943002616, 0.066331344257508, 0.05906125543905156, 0.00861865935647594, 0.06711912341415882, 0.021105014120361636, 0.08332277036138944, 0.01285178743169776, 0.011203468960177685, 0.017444689192676117, 0.008535117276811173, 0.008705621252634695, 0.1295347913567509, 0.09423147607594728, 0.010517021375043052, 0.019738208801884736, 0.014954577632514494, 0.011951823535907482, 0.08210130554756948, 0.017328079557046294, 0.050891887197004895, 0.02478614802073155, 0.057190398685634136, 0.027401274569066505, 0.06793073950601475, 0.04115940158122352, 0.08169823539044176, 0.029115622131420032, 0.04793499782681465, 0.0509103094227612, 0.05910249679748501, 0.017348997095333676, 0.03404090087860823, 0.02794077606605632, 0.016636696477819766, 0.03477502487865942, 0.0205491819818105, 0.03722031920083931, 0.010548465535975993, 0.021511794167703817, 0.05503336300275155, 0.05705369423542704, 0.022785687686077187, 0.037928017654589245, 0.06388361060193606, 0.01225913967937231, 0.041323685087263584, 0.06784598369683538, 0.031230988978807415, 0.04061652606885348, 0.03635332447343639, 0.012039781182206102, 0.013815372467174061, 0.052807934382664304, 0.02421525410110397, 0.03965244655098234, 0.017354779910030108, 0.020119296120745794, 0.006275889555191887, 0.03590295024748359, 0.021112133649044802, 0.03641926111387355, 0.054456146833087714, 0.00860302082063364, 0.023692590450601916, 0.08381489145436458, 0.008556005129191493, 0.008656035609809416, 0.005081239597140146, 0.016323695059067438, 0.028684039932808707, 0.0433099606473531, 0.003985134128015488, 0.01217836856708995, 0.03672493774709957, 0.042991412204823325, 0.015549758016797048, 0.09459192066320352, 0.03785271044554455, 0.027206835270460163, 0.05011475086212158, 0.012164876746412898, 0.02440370193549565, 0.04886846523731947, 0.029641364634569203, 0.03515086203281369, 0.01724306760089738, 0.01479270971114082, 0.1525877472013235, 0.18146474553006037, 0.1444930144186531, 0.14260665992540972, 0.2037328127771616, 0.1259794035660369, 0.15737967006862164, 0.10202297155878373, 0.12389442830213479, 0.10295123460569552, 0.09741219040006399, 0.17325111984142236, 0.09285506100526877, 0.12389171416206018, 0.19442909343966416, 0.11232470055775982, 0.16300718166998454, 0.12629815217639717, 0.09536150829600436, 0.18848851935139724, 0.06873688660562038, 0.14204431724335465, 0.21970415647540772, 0.10226600923176322, 0.09507152278508459, 0.10299875241305147, 0.0650720986138497, 0.1446452641061374, 0.14579790511301585, 0.11106349394789763, 0.15929668077400752, 0.11833932995796204, 0.168851607346109, 0.10563380244587149, 0.13499044360859053, 0.09110094620180981, 0.15996790118515491, 0.17213520114975317, 0.06699690568659987, 0.1703153159469366, 0.14008943071322782, 0.14939916187099048, 0.11961808348340647, 0.16965405642986298, 0.06407526281795331, 0.1154682311628546, 0.15295897371002606, 0.12524666717009886, 0.12038661938692842, 0.10175537770347935, 0.11548636161855289, 0.11547345588249819, 0.1495977555002485, 0.1325921073023762, 0.19069583447916166, 0.10130611966763224, 0.12096975238195487, 0.29011834093502586, 0.14477854195450032, 0.13849757398877824, 0.15773895436099597, 0.20646861168955052, 0.17886620068124362, 0.10934426262974739, 0.12174735351332597, 0.14664158198450292, 0.11348558576511485, 0.13701109375272477, 0.1306764129549265, 0.1149753840374095, 0.08057468317981277, 0.1755300068429538, 0.12660300438957556, 0.08403251799089567, 0.18335378702197755, 0.17820249843810285, 0.23726472418223107, 0.13190222717821598, 0.1485843634498971, 0.15998531239373343, 0.13968347678227083, 0.25276303397757666, 0.13932025698678835, 0.14863750631255762, 0.18263593768434866, 0.12470197996922902, 0.1618605660540717, 0.0785495275631547, 0.15358162458453858, 0.1888619036014591, 0.14299586761210645, 0.1980448437056371, 0.16178800351917744, 0.15399687444525106, 0.22785963171294757, 0.18200057106358664, 0.13095762500805513, 0.15870474039443902, 0.10933802010757582, 0.11623699776828289, 0.1353982160133975, 0.13395806614841732, 0.14169384033552238, 0.07766495538609368, 0.16628939126219067, 0.1159050991492612, 0.19243145920336246, 0.14112222886511258, 0.16591344214975834, 0.16376374821577752, 0.4003257272498948, 0.15596428673182214, 0.10547735941197191, 0.1789331856582846, 0.21430432051420212, 0.11110303896878447, 0.13124227044837816, 0.11704947559961251, 0.17711966511394295, 0.11498077160545758, 0.14935486710497312, 0.08916746745152132, 0.09351194397147213, 0.1152788113270487, 0.1705658310758216, 0.18217267468571663, 0.1910906604358128, 0.08548036922833749, 0.08406381881130592, 0.13118815049529076, 0.07420444036168711, 0.12557809081460747, 0.17084693456334726, 0.09950371352689606, 0.10991432025496449, 0.16845204521502766, 0.1549017144633191, 0.08782573909099613, 0.10316796547600202, 0.11430600924151284, 0.13322683610022068, 0.1335516372429473, 0.11704217456281185, 0.14316676344190324, 0.2534044938428061, 0.0831405497821314, 0.15341406714703354, 0.16177247863795075, 0.13103106963847364, 0.16182241881532328, 0.12024670546608311, 0.09622961921351296, 0.05843086926532643, 0.2402758997465883, 0.12403173664850847, 0.10401358295764242, 0.1074092300342662, 0.07746595463582448, 0.1991891794438873, 0.10082733857312373, 0.11337811938886132, 0.11676303882684026, 0.10858265456876584, 0.16524618438311986, 0.22065405121871404, 0.2628143903400217, 0.13927913776465825, 0.1271956775869642, 0.1692374087870121, 0.09788659494370222, 0.12952544114419393, 0.0764604743037905, 0.137397736577051, 0.13873046077787876, 0.09156140006546463, 0.18724388256669044], [0.03189189226499625, 0.0329566290602088, 0.04241606200646077, 0.00897556877628501, 0.01776406035891601, 0.010945672302373817, 0.0780132066990648, 0.025819556854133095, 0.020786309614777565, 0.07908583485654422, 0.062127663753926754, 0.056643740340535126, 0.029266847231026207, 0.04392148354755981, 0.019499725795217922, 0.05118721956387162, 0.06435091766927924, 0.014539807835327727, 0.07989237550646067, 0.03194115051467504, 0.06458265094884805, 0.006389084463340363, 0.02720963762008718, 0.05177549246166434, 0.03542474251506584, 0.030117709788360765, 0.015021528682804533, 0.06097012372421367, 0.028364224326131598, 0.04726978923593249, 0.05163091700524092, 0.01851108330967171, 0.02449103957042098, 0.013093575752074165, 0.03519741292776806, 0.05583070271781512, 0.0449106892171715, 0.026437917690990225, 0.004897893073835543, 0.0652346620336175, 0.044841424362467866, 0.014900593386430825, 0.03457733030830111, 0.008744389350925173, 0.04235743997352464, 0.04401500263650503, 0.06814470873879534, 0.06333232125533478, 0.01742835685477725, 0.060630537303430695, 0.04685122812432902, 0.06424609757959843, 0.018861417725150074, 0.029094099000628506, 0.013960243934499366, 0.02027726755477488, 0.03540696489757725, 0.04557101235591939, 0.024606292136013508, 0.07337427312242133, 0.0320067343169025, 0.011047180292994847, 0.0597569981057729, 0.020553331223449538, 0.0125020280746477, 0.0345168423040637, 0.010396388026752641, 0.07246038144720451, 0.0400076019577682, 0.03879517862307174, 0.020141250121274164, 0.05872613377869129, 0.043850651276963096, 0.04038534579532487, 0.1160151439585856, 0.05972803823117699, 0.027198882840041603, 0.05257245898246765, 0.03654072906023689, 0.033304581817771704, 0.0439269084350339, 0.00998927464908255, 0.08660666272044182, 0.05548103326665504, 0.026953992766461203, 0.09172175146107163, 0.050381062286240716, 0.062193793776844225, 0.058526922682566304, 0.023390496482274363, 0.10790667084178754, 0.08153941069862672, 0.10493239401174442, 0.04386649167697344, 0.022799543371157985, 0.018333269815359796, 0.08138110847877604, 0.01790346028948469, 0.02004810083391411, 0.0902426808274218, 0.03602962255743997, 0.0465600076796753, 0.026972934071506773, 0.006914440201528902, 0.025875983826283897, 0.056332594715058804, 0.022699678283450857, 0.021124622086063027, 0.023105435439252427, 0.03779673130650606, 0.037705037476761, 0.024052327665101205, 0.050066673263375244, 0.019858005855764662, 0.07031711323985032, 0.03278689691796899, 0.029881589779896394, 0.05087417743301817, 0.01573066393445645, 0.022129500218267952, 0.060877415484615734, 0.04202792979776859, 0.010670453409797378, 0.057121988785054, 0.02041978874642934, 0.010594870545901358, 0.036254807974078825, 0.04335277281435473, 0.028763856007052318, 0.014529936847143939, 0.011312795370551092, 0.04196323487641556, 0.008114474759038006, 0.05603849728192602, 0.044121685304812024, 0.019036988661225353, 0.015323453017377427, 0.015382080139326198, 0.008939531781444592, 0.019752066183303083, 0.029206769740475074, 0.046537191939673254, 0.03292433757867132, 0.032683735846408775, 0.04696601589343377, 0.015847014030441642, 0.009004736452230384, 0.041835358166801076, 0.012635478949440377, 0.023673459155751125, 0.03888730671522873, 0.012059837829188576, 0.03763946724523391, 0.010209817189856299, 0.02206138039140829, 0.010421317403337784, 0.024322562717965672, 0.012349777538994593, 0.015354711429349013, 0.025425056594290903, 0.024834932992234826, 0.030925258062779903, 0.05563637368114931, 0.046221500129571984, 0.06339839021010057, 0.02619553480430373, 0.06108940339514187, 0.02602191804908216, 0.05551581157903586, 0.011253843399962144, 0.06019178298967225, 0.033630587360156436, 0.04302984103560448, 0.031190270092338324, 0.03541915138651218, 0.0331970984781427, 0.025405168732894317, 0.00955660849077893, 0.03256853077826755, 0.03218404230262552, 0.06201130856892892, 0.005949514635306383, 0.010700349662719029, 0.035641161259263754, 0.03024970181286335, 0.023266436532139778, 0.020027183295626725, 0.007374428844611559, 0.020529265282675624, 0.020930272693346654, 0.02761484176984855, 0.04847125083740268, 0.0662214487258877, 0.02900014564927135, 0.061090244778565, 0.026819137324179922, 0.04234868008643389, 0.017218477491821562, 0.01976800157821604, 0.0620176935834544, 0.019309905623751025, 0.03674323444387742, 0.04058470277647887, 0.03916736186615058, 0.016128198942169547, 0.018938358507252166, 0.051499342279774804, 0.04757148626127413, 0.01597684492090983, 0.022377004348007695, 0.03407353162765503, 0.02553065021389297, 0.06786932530147688, 0.030871124538992132, 0.025347557717135975, 0.05791677042309727, 0.06359273621014186, 0.039917886057602506, 0.030436695885977576, 0.040234341219599755, 0.03646027177040066, 0.019549581155713116, 0.054886684087770324, 0.060132465458342006, 0.014111629338003695, 0.06974563747644424, 0.029007952194660902, 0.045599958659814935, 0.04233812547421881, 0.0601665550576789, 0.06797225227845566, 0.008800538971887102, 0.01735157722474209, 0.032110139661069424, 0.007419490355200001, 0.04295675942142095, 0.08317533827253751, 0.036613620684615204, 0.10698256721454007, 0.01666145961332534, 0.04790743234168206, 0.1480415625763791, 0.04843197383784822, 0.04636752086558512, 0.009984170369404768, 0.017706434076119746, 0.01717958725722773, 0.05825219063886574, 0.06236270149903638, 0.06887399817683867, 0.10100008680352143, 0.08762063152555909, 0.10846245887556247, 0.07537993442799364, 0.06347346332456384, 0.004049950337503105, 0.0314603236370853, 0.06467115227133036, 0.026161119508157884, 0.03283384136323418, 0.024582962405734828, 0.061547163474772654, 0.02501578632343028, 0.018235972982698252, 0.060372388655585904, 0.041136894574654956, 0.04873349444408502, 0.052606270382446904, 0.10827092201049839, 0.04518441702904446, 0.042801924515515566, 0.02954606099852494, 0.05646922791908894, 0.04759106878191233, 0.05871570469545467, 0.04312975870977555, 0.06925545699362244, 0.03493035850780351, 0.03350414575210639, 0.057592064275273254, 0.010205935121380856, 0.02827156867299761, 0.08792534803173371, 0.05754695526723351, 0.029456185642629862, 0.06495929895234959, 0.059025666277323446, 0.030323143050606762, 0.05282546094219599, 0.010572870744259229, 0.027458873710462024, 0.016966891973944645, 0.00582544959615916, 0.05945327904607568, 0.03642766477007951, 0.0318514074731086, 0.051108930193419964, 0.03893771168908902, 0.045055359668497524, 0.035477973587278805, 0.01119228161405772, 0.030457856000534127, 0.03996109177491494, 0.032117681577801704, 0.016793551721743176, 0.01142438723971801, 0.006265199235973081, 0.061013013922742436, 0.03156159159594348, 0.030602794473192522, 0.044548704355422936, 0.05080614751204848, 0.0012230084809873784, 0.032931648793497255, 0.028539220203778574, 0.014680117002821394, 0.0114347603438156, 0.05374494713864156, 0.06581577299428837, 0.010839445948866861, 0.024953427258878946, 0.044180090206542184, 0.02538834445710693, 0.038558217231184244, 0.026409251282789876, 0.033275455702096224, 0.03758627349244697, 0.059129814617335796, 0.05532043420576623, 0.04380477891702737, 0.006497880768230451, 0.0473474441761417, 0.009280392151725079, 0.05484417047617691, 0.025942724530718157, 0.04734009224921465, 0.034316494661782465, 0.014328439088006104, 0.06663971806743316, 0.053328625192599635, 0.12475601849811417, 0.02653879379587514, 0.06454196598912988, 0.0492048082607133, 0.04572092788293958, 0.014034007476376635, 0.03192889277956315, 0.036244185508361886, 0.037112265891794644, 0.11182271356561355, 0.03226931719109416, 0.0036105420856204417, 0.11804321727582387, 0.11263776983001403, 0.09805537374424082, 0.12790176112736973, 0.15265721561653273, 0.07415310240217618, 0.16270275014851773, 0.06816946848162583, 0.11261309151138578, 0.09935493793870721, 0.1239978913217783, 0.17033046084855283, 0.13293225690722466, 0.14563872079764092, 0.11737734372062342, 0.1496943381748029, 0.1212030870041677, 0.16749157889613084, 0.13029323065919535, 0.07323684942509447, 0.1060740291806204, 0.09618703435574259, 0.1307341291436127, 0.17314758896827698, 0.07577889266290835, 0.06936677744878189, 0.12553095977221215, 0.14360644056328706, 0.1159495296222823, 0.12872262565152987, 0.11441764182278089, 0.12731220919106687, 0.11963740816073758, 0.07850555849394628, 0.07358465290495328, 0.1454957534692117, 0.1519418904291732, 0.08062826030488525, 0.05770776806665318, 0.22816923367125647, 0.1012870664043086, 0.1461430215942008, 0.1539963859000376, 0.08827892584460122, 0.18616886596594537, 0.14578932843038014, 0.17915996563221726, 0.16092740398432526, 0.12947244755923748, 0.17834572360983916, 0.14223560983581202, 0.18839014534439358, 0.11416947442506041, 0.1284431235066482, 0.11554254431809698, 0.13580752190734657, 0.11584069260529109, 0.13916848227381706, 0.14426650585872786, 0.26218242996505325, 0.16478427845452512, 0.09788004708077226, 0.15984919826899255, 0.09438789196844612, 0.11825071328452655, 0.3146830456597464, 0.10713954629110438, 0.16082835144230298, 0.17208014481834003, 0.129101587459445, 0.22696214701448167, 0.0967187276110053, 0.1809921051774706, 0.16981165297329426, 0.2334364296070167, 0.15292539979730332, 0.15679089166224003, 0.15805534166949137, 0.10315413014697176, 0.18268632569483348, 0.14431576750108174, 0.15893204962568624, 0.11687338219157287, 0.15019680692681245, 0.17881338351539203, 0.16596556720989092, 0.0977045236421483, 0.149282928822296, 0.2175715480531965, 0.1495518593915871, 0.15793602807181223, 0.22003361236836227, 0.20155878657741205, 0.13874361078654016, 0.2684384142713887, 0.08745114704860107, 0.2575164974800178, 0.14493851337049687, 0.10337498651019164, 0.26497161601270947, 0.16518500766583852, 0.1448535607861621, 0.10384354208196912, 0.15975116352949822, 0.2403510000024523, 0.18153767447386468, 0.16215419529804162, 0.12377577966877393, 0.11646764539182186, 0.16406260217939103, 0.1680896668029683, 0.1912664281470435, 0.15788033391748155, 0.09668040395315204, 0.14874791753079208, 0.11744811492306845, 0.10365912304925066, 0.12358197649674756, 0.11583872485373702, 0.12579843827656337, 0.23521660694054194, 0.11124271540237324, 0.20407753570803575, 0.09935390656547886, 0.07307518845690147, 0.09723027516156435, 0.16424318748925412, 0.0933927253686956, 0.09402853982256991, 0.0792346986542855, 0.08110160633389439, 0.14974526901330265, 0.0979017669867192, 0.1465609720242875, 0.12335986484374319, 0.10643319133669138, 0.09017549907522542, 0.10413486430687563, 0.08638816765908684, 0.06675308091299874, 0.12347571791282722, 0.15394211666924612, 0.22869585826992989, 0.11486007379634039, 0.3021927630262715, 0.09860628989658185, 0.08531212647046361, 0.11644323170185089, 0.07220983917691878, 0.06786061291183744, 0.08141800721309014, 0.14541726053825446, 0.11809834146073886, 0.14641298353672028, 0.113795160582023, 0.08386726757245404, 0.17317873372563294, 0.11386352298515183, 0.0699978828696268, 0.0802045219710895, 0.1269818576318877, 0.09395219784762178, 0.17338004149496555, 0.16045430222792284, 0.2108062689325639, 0.13785627697195324, 0.19566178800804274, 0.10410322421895606, 0.14188163168728352, 0.07503899093717337, 0.15639302586870535, 0.09390398114919662, 0.10626536248517887, 0.24683261077318872, 0.0755796612107328, 0.0686015324401004], [0.07808384897985629, 0.025122055085375905, 0.026095873277102197, 0.04179311596921512, 0.02483339441408004, 0.028656287850545983, 0.05759735006306853, 0.006911194259633443, 0.008961452703390802, 0.04004047019407153, 0.08243480550923518, 0.03337549551257065, 0.018986678682267666, 0.01650875530737851, 0.024593240514929806, 0.012752193757998092, 0.00815718260128051, 0.02786414571372526, 0.02328088932803699, 0.028072589975116507, 0.05558502893628819, 0.03795528119163854, 0.032171221383448155, 0.0713325273245573, 0.05436464977849807, 0.03211508957403047, 0.045196980104914734, 0.028880798124841282, 0.008186170465445943, 0.02087155227283282, 0.006939416227396578, 0.03005890115829451, 0.02799913686301027, 0.051046715317560096, 0.017131926957517862, 0.03617569079090442, 0.01328370550514332, 0.06707653177103826, 0.006712383075085069, 0.04140923138973968, 0.0664488258106368, 0.06516543110566479, 0.03687420527317694, 0.10240039309220654, 0.019490090597953116, 0.028281638132674352, 0.02878442918881774, 0.038733489611851316, 0.016484109219163656, 0.0344132198286908, 0.01878490442010973, 0.016594455976571356, 0.032555570759411366, 0.028773453884891102, 0.04668380639382771, 0.09877795247094971, 0.028661882371774743, 0.06637565937957593, 0.07279279575284038, 0.032737241725304296, 0.013054593915252813, 0.024448142586542026, 0.006422692726898406, 0.05829768641186612, 0.012511819334966796, 0.07422103732824326, 0.019171414930107336, 0.023878634574690034, 0.05569563014432788, 0.05958728971225875, 0.0287166740745306, 0.010506046919285186, 0.02996599275086607, 0.061429424078336785, 0.05226840065526111, 0.008690988644957542, 0.08307906093874148, 0.0196522282369967, 0.02983080143375056, 0.051021473814866374, 0.0401327102445066, 0.010104341465713722, 0.04490348996062364, 0.022757408042837466, 0.06258849759719201, 0.012930527179768043, 0.02532660964477275, 0.019289474934339523, 0.04777420199077044, 0.024720109600041593, 0.01377985200711659, 0.07447427338255302, 0.04507886412154351, 0.012317914382687636, 0.06613106107605354, 0.04728767881169915, 0.07492148902799402, 0.10476392055196421, 0.0646465757329549, 0.08988845840628658, 0.022453690679477792, 0.059402850323489735, 0.012590589617112917, 0.030669677669980695, 0.021466451065082635, 0.11585909447499684, 0.06570950762501784, 0.052520347493035455, 0.019465083189840828, 0.0404952752536961, 0.006503215749814574, 0.05399739269965461, 0.05201022147334047, 0.009969291792783355, 0.029954566221152033, 0.0488429455352681, 0.07422405002372605, 0.0403744892350265, 0.04229458388207214, 0.01979191484861076, 0.032008749565907886, 0.01227078927747373, 0.02247022488154471, 0.05388959384124194, 0.023834059912977473, 0.010393128514156809, 0.00326265039620921, 0.024185418916334, 0.06266258005052805, 0.0006177399773150682, 0.02718949700439615, 0.054552420774208646, 0.0031348226683413877, 0.009028044978289731, 0.020684763456561735, 0.03452403138258627, 0.03235537578750934, 0.03416273184120655, 0.01979170789543007, 0.06197259136076484, 0.026267532458794967, 0.031390614341944456, 0.06472831884665148, 0.023428865941241384, 0.02575370672691081, 0.10614452896905796, 0.03772785660943814, 0.04538217606022954, 0.041308753924178224, 0.021263143313782554, 0.04662749816530517, 0.01492368393311543, 0.03197360484461699, 0.024238322595400468, 0.06746536626347474, 0.04715511342510581, 0.02069262937376542, 0.10882104427686759, 0.027237135251717906, 0.05045977574107902, 0.038478333303438764, 0.031580624503216574, 0.019826245327879275, 0.023490392104057328, 0.09093640824513775, 0.041113715818417926, 0.03489086437704308, 0.05310102758396949, 0.0373582857261811, 0.0235088312931891, 0.03490201949274965, 0.05031467102734106, 0.07836438928331647, 0.0634012875546302, 0.005948447214905173, 0.018328862730413675, 0.03037253700728927, 0.044994695245155265, 0.04810617524864418, 0.04647543846762606, 0.048231052833476236, 0.012340130467366959, 0.034064747991838625, 0.061137918648975234, 0.02165302275014775, 0.03226492028417332, 0.02666635837938104, 0.03928204106965235, 0.027858283171164136, 0.029693703433232646, 0.05946283960448844, 0.022845188421862464, 0.04493229377216526, 0.08862014074942895, 0.05814271579895701, 0.03799964381115777, 0.030400981195271015, 0.029506427768085684, 0.031668515144182105, 0.04790774107511554, 0.017152644327974746, 0.014369839902168937, 0.055512578359672, 0.07550550411854472, 0.09444701950997114, 0.043908065517566035, 0.025497690375362123, 0.03009493476045983, 0.035289985460362265, 0.021062225702085664, 0.016973792675084302, 0.035259827971458435, 0.05689214861818722, 0.026604576069595556, 0.015413145168817468, 0.043762350122311285, 0.05052452155255845, 0.017947118928922073, 0.06700348747628075, 0.0831166042813233, 0.013470966751421136, 0.03249466545613749, 0.037655463708298545, 0.013023590802081993, 0.02831959877429264, 0.08450819818036896, 0.03471580912758197, 0.006600038880216224, 0.035836470779031515, 0.04656132743028658, 0.03279502916016749, 0.043005196643727164, 0.04926140147394367, 0.08106434119067021, 0.03414129013461726, 0.005589470383711159, 0.03466929555205362, 0.00844963119431798, 0.008291994786954351, 0.037079492650393925, 0.05493387280564223, 0.06334971889321293, 0.06810842068599803, 0.08200487893606935, 0.03877363513622965, 0.06880749495966093, 0.04063261752682073, 0.05484000087848731, 0.055484524329325983, 0.046574141564113755, 0.02532656893267163, 0.05703937714653356, 0.10158321979854788, 0.0804415817505547, 0.036046070246292014, 0.08127101617200033, 0.04461587932226913, 0.009323551219754984, 0.026473637470709424, 0.02587137826984482, 0.0757371016911098, 0.02459400556316333, 0.03210532545511212, 0.06472040712833405, 0.04267561522179416, 0.02012189830254231, 0.04649149260616728, 0.11040245156202998, 0.061801349478108544, 0.012349398407552923, 0.08668297076863901, 0.0027118693147453344, 0.07923165881740195, 0.07922203040548734, 0.03224124280469758, 0.09956856790397849, 0.06868467333593539, 0.08278324681201152, 0.06860662823809044, 0.027005137343491827, 0.034674489737621376, 0.1361317802220583, 0.018795048518638526, 0.01921403032195355, 0.18016704730689526, 0.07546471059322357, 0.022097765135445764, 0.018128538836858103, 0.058773990853556564, 0.07632826854075704, 0.01932132876078997, 0.03259205898003919, 0.03842968912795186, 0.03604464193007775, 0.03470321551763585, 0.09442060414169516, 0.06998967938125134, 0.04895044244559748, 0.03182175210011857, 0.043500557741416354, 0.006943275819399527, 0.03117425666589822, 0.013218451640568674, 0.07817233673163823, 0.040101575665175915, 0.030639265730444874, 0.022768629315708364, 0.03868653838123594, 0.07343718010400023, 0.016232562717050314, 0.06577362239892993, 0.029563367034175565, 0.009190653351002505, 0.0012355427191193613, 0.022830370913392732, 0.022443120800224797, 0.03584889814789806, 0.0302688025736383, 0.01572847565902131, 0.04163316151659403, 0.048110802857471366, 0.12796937035662787, 0.015453460326950465, 0.0347622311008828, 0.029563387390226126, 0.033482045866549015, 0.04794171193082418, 0.020139623333566954, 0.050024193578532765, 0.016792868097711886, 0.043818196947021146, 0.09646397163825375, 0.03036417406318443, 0.08225491909044129, 0.01380337427170681, 0.030091711719121252, 0.02796566642687789, 0.01962957195272403, 0.01883135862382395, 0.06372512517763035, 0.038051653520337174, 0.07243079053504126, 0.04714494897052646, 0.02673860369915409, 0.06721867128674473, 0.004611484714717205, 0.034540933689900806, 0.027547671892014996, 0.06446070463529655, 0.03653533131416355, 0.019154879031702876, 0.07248693252248423, 0.18695364599781378, 0.08882978092879057, 0.1050936139321753, 0.1519629114440509, 0.10806194001010486, 0.08764644978301865, 0.14752234758010932, 0.1257956698536873, 0.07446190368916307, 0.1122003115181412, 0.15456974799079554, 0.2172715812921524, 0.13642372669918196, 0.1193695632474763, 0.11118839188878026, 0.08661848958581686, 0.1687671025948865, 0.17599345983139106, 0.07622983346560172, 0.1784693119781358, 0.11485536476331097, 0.15142252615519933, 0.19425229435520514, 0.11802400116409574, 0.09076781264905419, 0.09864684593464647, 0.16280899516173772, 0.13122684056205408, 0.1769459465784686, 0.09156980711434569, 0.04550121145855103, 0.11594374850392342, 0.12800542770751885, 0.11216778933469738, 0.07468557597271033, 0.18714948477489607, 0.11033184320798942, 0.12941011733242444, 0.15589346124657563, 0.1851191180092948, 0.1924015222383397, 0.14957311110837118, 0.1423979696950742, 0.18670246590461048, 0.08850639792425291, 0.14019422366150788, 0.10887132372174944, 0.10844364309949533, 0.14954937595341886, 0.16571478066699846, 0.15484901943377086, 0.12123873723404748, 0.17446752956935338, 0.1584218591451645, 0.1543847114912101, 0.2761015444993973, 0.15863965531545027, 0.14784898076738628, 0.14891670990203107, 0.11383169969277722, 0.15613166775022233, 0.09271840405251298, 0.20192079858056136, 0.18482886786971772, 0.12056778823690754, 0.16965230580951485, 0.0958001676148602, 0.11875280205692564, 0.14620509397770676, 0.21640098015112536, 0.17336648436529295, 0.14100876423929418, 0.17470531538128853, 0.1454851683229208, 0.13910913760108606, 0.11349256789045674, 0.1908149445163352, 0.14722151229424135, 0.13483622616955213, 0.17495578979807241, 0.14347597184990132, 0.11283116588102919, 0.11922806155468736, 0.18029127349810942, 0.18584637184228214, 0.06690557487308979, 0.09581519716552325, 0.19367354469639914, 0.17842790777129786, 0.10662013451967921, 0.1299072935112885, 0.21264965858842644, 0.13441485592297145, 0.05963689062212195, 0.16021396512431757, 0.26638462447694367, 0.16105674632958003, 0.16078774790678704, 0.11607615782746247, 0.1974880921521357, 0.28805586589234217, 0.25458720752171105, 0.12283656506666116, 0.1135682449010866, 0.15509311562137945, 0.3073479192597525, 0.11500742446099009, 0.16628495364316873, 0.19155902601778507, 0.2239488544208663, 0.17574906508837426, 0.09119550005665847, 0.2002153822353908, 0.14872579728918417, 0.0850884270455156, 0.16265088293169225, 0.12741981127432414, 0.09785739079649959, 0.11140553666544811, 0.179282902606896, 0.17828228058559553, 0.141121007502079, 0.14533658272453717, 0.15223569609224796, 0.11801353815410819, 0.14357605576515198, 0.10962882664586816, 0.141080146123256, 0.1533972259078707, 0.13428341011915887, 0.10717010750834431, 0.09838287545634167, 0.09504907684666769, 0.09954254608601332, 0.16439638712576457, 0.12617341029856885, 0.08803989152823176, 0.061619156040251255, 0.07838839585227625, 0.21534660458564758, 0.11056145945830004, 0.10571956248687846, 0.11572231538593769, 0.0659130002771105, 0.10733962591205325, 0.2459820264152118, 0.12861522712877818, 0.12525645164506777, 0.10850637366196939, 0.12467382076595511, 0.16061424650251865, 0.07017848175019026, 0.14357169957033225, 0.09024116090898003, 0.1228970361075231, 0.1797758447272437, 0.11763441349778857, 0.22467114137751715, 0.08844697861266987, 0.11908098230404512, 0.09814586995967797, 0.08025991757001195, 0.13563545899731771, 0.1666769026113408, 0.17559958382376603, 0.19209345376917294, 0.12855031846889428, 0.10684757945793015, 0.1909330231802804, 0.11880739698452608, 0.11670895958585398, 0.2038634443389518, 0.1683995130338839, 0.1502286030777863, 0.09999300512884345, 0.160700420449887], [0.02236723174740161, 0.029710161300109963, 0.04437836153166635, 0.06706975999155215, 0.03741937084123492, 0.023028545547276735, 0.027228665438347628, 0.01359527775951262, 0.04469540362645473, 0.018844188024689044, 0.019266526880008832, 0.020691882985244905, 0.015083455181281482, 0.03512461969096746, 0.01377612939437053, 0.03913684475368687, 0.0340250977980239, 0.05543002439662814, 0.03214646842596786, 0.019418155707951103, 0.03504707670903631, 0.04155245656147599, 0.03369326703250408, 0.02035456456776176, 0.03928045329770871, 0.023163741953404884, 0.022901917342096567, 0.07467841742826359, 0.031114196138722554, 0.01844473785188581, 0.0034769697106509867, 0.042599466629326344, 0.014158970726254796, 0.029468192319784845, 0.08719261163579566, 0.010519204561465552, 0.074323781100767, 0.05991373969508069, 0.05956540695790734, 0.04288199504039117, 0.057704314323408265, 0.011730515946900206, 0.006374488326920462, 0.05430706251146538, 0.019028223685121963, 0.044564795813390186, 0.036036119530243535, 0.06051678769290447, 0.07326365834368126, 0.03210588863917759, 0.06418997594820601, 0.06654795977686133, 0.019290735313136662, 0.06133434096617358, 0.05771413951047829, 0.06110708601772785, 0.03427265451422759, 0.0438673160970211, 0.01652181032113731, 0.03545558193166341, 0.08861195083175387, 0.01798743917606771, 0.06172008133892502, 0.03702798166445323, 0.037677482169653685, 0.026408087595232894, 0.02459992578120104, 0.03246369033253618, 0.025797872571274638, 0.023318368209792033, 0.04140066149245415, 0.05087901878037623, 0.03177656166787658, 0.031084737540887933, 0.0984412973214473, 0.11458815767296723, 0.0509903324501855, 0.04422665127952184, 0.014986665553546377, 0.021690754386197244, 0.01862404921225139, 0.02878489059263042, 0.09602044043796402, 0.05860370570527656, 0.009713527347360338, 0.03396109498238989, 0.02368794078938663, 0.05285870576543467, 0.1239966292466436, 0.01400235212141914, 0.050050836256039996, 0.07235880475491285, 0.18021910451352596, 0.027970139668988328, 0.07108243288738386, 0.06075173722846167, 0.14957555383443832, 0.02485499727273626, 0.041769659013620446, 0.05929338226893118, 0.05478689533525279, 0.039263866509177854, 0.04715344762163503, 0.026567154863317097, 0.009707137243822217, 0.03750242352751749, 0.06559989029275519, 0.03786129052085536, 0.07362064918769257, 0.04454916915191071, 0.053830832708626986, 0.01332661266704755, 0.019416995413069214, 0.053850455941366296, 0.05340310798159667, 0.04335184661405427, 0.027381993996511613, 0.07358490396291018, 0.033787054142781665, 0.02515824475059552, 0.059614655029560835, 0.10450242672647748, 0.02210305431591613, 0.01162669584820313, 0.04533820699102112, 0.024457762516768913, 0.010886552394367754, 0.0776575661397406, 0.03247459099761077, 0.02599307691811451, 0.0406578352807888, 0.02681103391971971, 0.030036641817007746, 0.013262070416073714, 0.05114505200513771, 0.05903800204396248, 0.0057111932047908855, 0.028281003702431917, 0.05362259031140378, 0.056067677680402994, 0.0161531978685941, 0.04559625725128821, 0.024549955069752674, 0.019291025386857133, 0.03626568489042776, 0.013240958647137242, 0.027400802987228547, 0.05165907960118992, 0.038057865508432896, 0.033678926194884946, 0.025106026391897882, 0.021062120529157773, 0.02768012023131762, 0.11847471126488276, 0.06834334986550467, 0.02390680734866432, 0.01119513315747359, 0.024966902964349304, 0.02664751885458827, 0.033340632383312495, 0.011063878191635013, 0.0533935542085341, 0.041629426181316376, 0.04384730609932116, 0.033322841195123534, 0.026444284045802693, 0.04845103727919715, 0.014836931534643685, 0.07112147579235689, 0.007929054887167044, 0.013803159685007163, 0.025429171909179007, 0.04226303200370499, 0.04430780406775219, 0.055734645907900164, 0.03559463072035994, 0.020181297258074795, 0.014391033943476421, 0.021305558537798266, 0.0711597315967083, 0.0163887004101915, 0.024211510284138576, 0.043875176925212145, 0.021112422026427727, 0.09249706592942987, 0.0019356674498080143, 0.009537105698005428, 0.05728939694485494, 0.017700094862708023, 0.02486038992979697, 0.09026007846529994, 0.046539604131664546, 0.037850725730615, 0.02914963030655469, 0.02508624200709164, 0.03789487800427845, 0.04287827327581389, 0.04235118727332779, 0.01560748607984611, 0.023160237320033566, 0.057597492555422444, 0.04783649829083255, 0.04173149141882147, 0.025761883073885525, 0.11507465371063777, 0.07694737746247224, 0.045439203535871844, 0.003400033169392762, 0.03274690745664494, 0.033395780316953144, 0.07534890502159085, 0.04419588650177632, 0.010094157503252583, 0.011296625881056701, 0.046251881535031965, 0.008022467106846827, 0.03344862123153039, 0.02251807856373489, 0.08067604952624866, 0.051867525558918715, 0.039481194490300756, 0.05127650459430047, 0.025542052994881357, 0.03840575719784413, 0.022057989412652593, 0.05499456776306033, 0.0282283493849848, 0.08017121268702404, 0.036078324408403466, 0.03796064840363605, 0.06058659537562302, 0.04633693589961954, 0.02675374351175768, 0.06138873911861863, 0.026910790441823856, 0.015001216737021292, 0.01991288916074804, 0.056489163277936835, 0.07344363975737776, 0.1392324681260756, 0.09739036871386425, 0.028310026341517056, 0.05895190952079637, 0.027722722052463462, 0.04146106807248933, 0.06538487611604588, 0.08602161625666277, 0.02745534193568996, 0.011934344473827099, 0.051949200819113424, 0.1518019222255264, 0.17882352082857064, 0.07805125215756041, 0.0932636001546468, 0.09474886581301689, 0.013095753849484026, 0.04261178543258991, 0.028769867827317545, 0.10540595038660935, 0.07404800411313772, 0.0505460345053247, 0.10249249065028769, 0.0850064939420138, 0.05326475469129426, 0.09016126341053418, 0.05195442893143211, 0.07032501817281757, 0.1052783586617027, 0.13447113361741814, 0.05249598469319088, 0.03702219036806907, 0.09823192177074296, 0.13924574027104036, 0.006634727286707077, 0.0548838851308184, 0.08204458680536066, 0.15489908174744674, 0.0251593575480261, 0.016476429899090102, 0.0445646906404623, 0.05684091243892908, 0.03270014960850988, 0.0662060391956142, 0.04648282092862895, 0.04197135694058878, 0.02582251187413931, 0.018235365693856562, 0.015332333344433988, 0.10523265932819673, 0.06437426605927092, 0.05488334230280348, 0.022139232106772915, 0.038607699397419176, 0.044104850850999355, 0.018238868630890335, 0.0213631000037172, 0.06819627740021263, 0.021812710877774016, 0.047841644978949, 0.04780598796371903, 0.008418076771444507, 0.03652145866570728, 0.0036112286782424364, 0.044145746156573296, 0.010614678679433252, 0.01784005288832954, 0.016051695815154483, 0.02892659923860005, 0.0126011408366529, 0.02992443587364895, 0.028920597596360103, 0.09259033735309329, 0.02601820306985506, 0.04630537384322711, 0.027009016867460947, 0.0028696361280578586, 0.050191639057759724, 0.05242795816489628, 0.0272893264690148, 0.03957144643313118, 0.02026142885110208, 0.06101173149155719, 0.027415264264813492, 0.022036540920713117, 0.040183566444154294, 0.03968333685770631, 0.0383341310412756, 0.004786044633614698, 0.013714675325900316, 0.008261548920667596, 0.012626261899380811, 0.08735290874860116, 0.01231539192875581, 0.023539246625400016, 0.05028822173231414, 0.028936753515154123, 0.03604355288137283, 0.0667089286393353, 0.013381087154682194, 0.03298309871128627, 0.05337186483666301, 0.08404078254742281, 0.03736181410827807, 0.030907168319182735, 0.06626092589327268, 0.04123894624145968, 0.013150321635683733, 0.01985005003267101, 0.06825780695570366, 0.03611709250669394, 0.04082723154819437, 0.03740340491224613, 0.08016337560755865, 0.1071498328819871, 0.07110048191887991, 0.21169348061084747, 0.1441497571234192, 0.1173870467713901, 0.08595416987580912, 0.15418364799448422, 0.26001638333712307, 0.17670609802007675, 0.06774214069758143, 0.15284113931868756, 0.06449352537414857, 0.11000704885061298, 0.1500118382807289, 0.15863483771681786, 0.12098283453711442, 0.13385650302682603, 0.09435116286788668, 0.07567405900252716, 0.17749893904796668, 0.19288591481745243, 0.12006982495742184, 0.10768925465111222, 0.16370143155966485, 0.19357333864484513, 0.13534035054700716, 0.16222381299095495, 0.11573868165058748, 0.1712972511138235, 0.18614081532827445, 0.12922624791307108, 0.08776583123419966, 0.12167883504714284, 0.3067577837833336, 0.1715836471744946, 0.13252666938517774, 0.08771320405815329, 0.17933453912181513, 0.12206827343574592, 0.14834698475897312, 0.10745946876704693, 0.18215877828853472, 0.12815281908426965, 0.08918431547603436, 0.15101535086120876, 0.12373722530901432, 0.09274785925767251, 0.13974326928811415, 0.07671828368412596, 0.13961087353527546, 0.24418233441455023, 0.11710233347756521, 0.12080670041697365, 0.13318529618637903, 0.24546492844820023, 0.143516602526818, 0.13220106757112912, 0.20963560603559017, 0.10125718372208731, 0.1812077300356967, 0.13834489003888198, 0.17694039616201604, 0.32959189851369175, 0.15837312676012516, 0.20051300126527036, 0.09380481325622116, 0.088654854600983, 0.10982982907444239, 0.1671321453260524, 0.17244595661759377, 0.09365884001765933, 0.15446777774819306, 0.15568717303020613, 0.19413363215114388, 0.23841579098786625, 0.22939605212637357, 0.2502079967941557, 0.17163577223462717, 0.11874236618833882, 0.09435226887996707, 0.09973130774285112, 0.19766236708632537, 0.13551961949893407, 0.17692021653056145, 0.1600153443536588, 0.16009733852531227, 0.1610280850103923, 0.26055085180061205, 0.13399591483175755, 0.17426285626632826, 0.2869042291172913, 0.22933050564357213, 0.15768108889460564, 0.21171953635556356, 0.18427698819765023, 0.22570020758679935, 0.11853773359741483, 0.10459287544446332, 0.17063718581838266, 0.2074454849851983, 0.10098268238029309, 0.15329760339643272, 0.1490025445818901, 0.14563926362565585, 0.08322141080030374, 0.1113216018836413, 0.18611098692885467, 0.25993751042655533, 0.26080918365291184, 0.13311212296996797, 0.10455376468598843, 0.17990492922919138, 0.1641052006078618, 0.1575838548264333, 0.09906941040285996, 0.09814300654189927, 0.1121478471904993, 0.08050667361489364, 0.09796388008232627, 0.11717440746724606, 0.2630349685038839, 0.10862598581505672, 0.14354804583958217, 0.0800297109942351, 0.10628692632807152, 0.14199365781886236, 0.18360048878405774, 0.06346000797514405, 0.11053331382572651, 0.10080182565642254, 0.10308246327830212, 0.09240059860582862, 0.14948039608342306, 0.09952972855951105, 0.16756195654826506, 0.08342788222112826, 0.1340041115347828, 0.12371083029678889, 0.09398760380489485, 0.12284956579761845, 0.13247963333768503, 0.18192294665745326, 0.12776439849819454, 0.10334260003375155, 0.08392435950892312, 0.10097315574863128, 0.13711965935570852, 0.08960780275187322, 0.0910748497449926, 0.11570806615054607, 0.07789130109761443, 0.10325572719531399, 0.21289790741034917, 0.20860389353973524, 0.11325273290276527, 0.08053910080343485, 0.09852272152368512, 0.054953475682330985, 0.10139031907809631, 0.12743046427411692, 0.1860125314976488, 0.1259127307151045, 0.13005201146006584, 0.10709288343787193, 0.1563408872378724, 0.10606199875473976, 0.14113282758210385, 0.13978863613946096, 0.1250017431697675, 0.06784390059432813, 0.07951685387109007, 0.1674341612628528, 0.13649535285575048, 0.09966591732310397, 0.17554494818406446], [0.008706520311534405, 0.02680402295663953, 0.024364630192784325, 0.06478439298059259, 0.028938826439636092, 0.02264237430478845, 0.05305634605299149, 0.02632746915332973, 0.040117273572832346, 0.03907123041738357, 0.02405272630442466, 0.031562239596886296, 0.03519035277089902, 0.004615630563681147, 0.02238489910294967, 0.02033812875327255, 0.03903178717674954, 0.0405694764506604, 0.0209065036116434, 0.030257827269711664, 0.030082212228860174, 0.06505751689629895, 0.04661547452477472, 0.020592855888285806, 0.04106851860082575, 0.05619650773171868, 0.09360146309648242, 0.03041876559810979, 0.07214430626481771, 0.03863584163731762, 0.03817282630396741, 0.042945424493934424, 0.03635930236695068, 0.01861497719905206, 0.06574905264590468, 0.02931156608143023, 0.039309196041098664, 0.050428030480231555, 0.03321377008355089, 0.03877562663650938, 0.01401017902285925, 0.014146855483496827, 0.032641195093414614, 0.0005735749811200158, 0.023399833124130964, 0.050758782375071726, 0.03671012193496738, 0.05977259084050145, 0.0032500860480857746, 0.00578579049657232, 0.06188494499240603, 0.08607412129640579, 0.062234784077320776, 0.03060484704162393, 0.03896545020065137, 0.023478222578497868, 0.0764127800773297, 0.04277415546987738, 0.06352370205734457, 0.07472936183746372, 0.07286875774817807, 0.01594483503140509, 0.09796505394790854, 0.03729761112481356, 0.04547793770741139, 0.028139732711549317, 0.02089400838927499, 0.08448318737958159, 0.10122442405138697, 0.08930095564574003, 0.030278882211340324, 0.07110405101307801, 0.01727224630303681, 0.1289913933724165, 0.20302485648010457, 0.13540455353047165, 0.09260867136929717, 0.04415406499590192, 0.01217301153311772, 0.04664270752774818, 0.03602611113871847, 0.04274599287392838, 0.045717423249568255, 0.028446639189496636, 0.049047340638935566, 0.027573232306167483, 0.05957041454634496, 0.047118116303214004, 0.1363812775484153, 0.08195754433316843, 0.06017001558627401, 0.06803806338991437, 0.10150887950190476, 0.014030878581771893, 0.12412906571158341, 0.1288441919854709, 0.23284561559557915, 0.02178582053498498, 0.07435942454529659, 0.02706179501754897, 0.07051524546529565, 0.06339676851140601, 0.06584366756890501, 0.032801030802407434, 0.037845568864473274, 0.044226634316146374, 0.0664041917771101, 0.034894335083663464, 0.027834352937393954, 0.03633960449535932, 0.042716167867183685, 0.06127352387245212, 0.01991261774674058, 0.052516751257436614, 0.038244862974222214, 0.05602564922134791, 0.030974998072321926, 0.03654261878026383, 0.04743522625150425, 0.04450149867417557, 0.003188516840704584, 0.07198028399475984, 0.011566899101515966, 0.061241714150777886, 0.0688117358035275, 0.0842839220006551, 0.09353514308375971, 0.04611833566533668, 0.02763757269297327, 0.01999390454563711, 0.041271644844008346, 0.019617156458220313, 0.0418207900199507, 0.030717192084661553, 0.0053561942851436985, 0.0647465375119022, 0.03232248719515545, 0.027423832465761473, 0.014689884514414837, 0.03393275596733604, 0.07429056681160416, 0.028509412160409347, 0.028892692843718187, 0.01572183789020138, 0.02891702510948692, 0.038513264286198785, 0.042081978504679034, 0.028208751597308686, 0.06702136008867196, 0.04465745994821191, 0.0032261861363492373, 0.05259713051574571, 0.040613245352038314, 0.04798781838534134, 0.02875637515847172, 0.04720216643597398, 0.02723087915884597, 0.04351813858374953, 0.05052042320104582, 0.013109344057738781, 0.04309980138870222, 0.03126064435179744, 0.08187155359025512, 0.04566672650564994, 0.04461808795375483, 0.05222074714090143, 0.03926793093393956, 0.07363340564604316, 0.059254291866506846, 0.016705030043210303, 0.017796440050005913, 0.0404197678768209, 0.024040543208164827, 0.05619114051972117, 0.02878278713407261, 0.05345166055485606, 0.020188691593440514, 0.00504614703822881, 0.05610958400315472, 0.07612542728228228, 0.04632293093683464, 0.00176513622656265, 0.04874473437666893, 0.04823294933885336, 0.04165143785732133, 0.034516384292926104, 0.026660506014845202, 0.010510554088146558, 0.022827141086703966, 0.012787078939644354, 0.028765294501291852, 0.06950999583516802, 0.04311161468337689, 0.020679664265896593, 0.02168775865408991, 0.0330421244725585, 0.009830421967697995, 0.03063386119902134, 0.020072538272610733, 0.03474610232348953, 0.08997096826455422, 0.03931719257629343, 0.036301501361387115, 0.02767280562381659, 0.029529732053301165, 0.04417102158601795, 0.02459294026318405, 0.07716418297163077, 0.05323789148990597, 0.061074502766132355, 0.03976503925930176, 0.05818747875413724, 0.030504674916820865, 0.02996009967422911, 0.036177373557750664, 0.026506190188229084, 0.03942077433956521, 0.04444872900577528, 0.046255264032099924, 0.01737445403289582, 0.01336113568062761, 0.04479455794872982, 0.03367384396759527, 0.03839562327734061, 0.05941234302840062, 0.0794874190219811, 0.018300710312489952, 0.05048680518354688, 0.03619110371385302, 0.020927309191652706, 0.02378025887134884, 0.03046738263219595, 0.05769692507705518, 0.040532112919858525, 0.008918998463611518, 0.021289478954193846, 0.06550357903220824, 0.09213361543204103, 0.13465344240622862, 0.036106422543525696, 0.06758168752172164, 0.013761188901428665, 0.03133723059935229, 0.03683277392493827, 0.034957720432430506, 0.053237650609974346, 0.09194410060133253, 0.04035258273194943, 0.13879823285554135, 0.07665194331535272, 0.14848787577024528, 0.2331537790596485, 0.23103031728948864, 0.06691858238939728, 0.014071806965927993, 0.028189598250069788, 0.1336458721863372, 0.023523982980155518, 0.020431500260851214, 0.015472296459068145, 0.030436706064002853, 0.07419758715799876, 0.1470934727362224, 0.044539913934256346, 0.06483070299561534, 0.03686161166323083, 0.03172374789470008, 0.0919419564306736, 0.1407028670821871, 0.03700469434261322, 0.09497752532895122, 0.12593092902430467, 0.2420616682086672, 0.004453508615759867, 0.06029861154300826, 0.15827317855187825, 0.13645705633929797, 0.06079966215682881, 0.055575349634247165, 0.0548442247589784, 0.04148682865447231, 0.026388483022206595, 0.04253681409837944, 0.042116553256554265, 0.13790476508438587, 0.13384578217353138, 0.04743275299136128, 0.024189366293804984, 0.07616535906812974, 0.06420127355626651, 0.03396973951852747, 0.035428868007979224, 0.048327323381922076, 0.03395968023687601, 0.023171127807082872, 0.07401630295706646, 0.04845484046797667, 0.03729075452845011, 0.021001206744196158, 0.012621300112056946, 0.033957539458892176, 0.06315683174346175, 0.021809628632451807, 0.019048851149688874, 0.012434171180107763, 0.03742903657257557, 0.02914020206247057, 0.03734623833692499, 0.028186064778960178, 0.06344465951302222, 0.0057667508039490455, 0.03470104081290109, 0.03130723595885294, 0.038715810381940434, 0.06863968646419899, 0.056412610957132917, 0.0351245993349169, 0.04391307310600366, 0.021505197110985006, 0.01899029527391706, 0.06496854059930358, 0.03453877255586641, 0.010263115267402359, 0.04398728448099323, 0.011219974324506308, 0.02769415912085346, 0.07261202045317207, 0.0614756526691573, 0.01773126676146473, 0.028242595227701322, 0.033010928825076134, 0.0624509449782116, 0.04514398991263338, 0.02721686232169824, 0.041596870071121624, 0.0533852217985051, 0.03752232835228954, 0.011938747317929353, 0.09744609679494586, 0.042375220983688316, 0.04182829461725695, 0.026060314649449925, 0.00969719500946147, 0.03198731464466878, 0.0383087809729789, 0.0533674000762403, 0.007417362299747765, 0.028969832097313235, 0.00726248837807881, 0.09034312436623232, 0.022108638659119606, 0.0545237289209451, 0.04483009622033153, 0.08768305674727474, 0.13161845026271685, 0.13867459020444325, 0.14428285855267728, 0.1275395727051156, 0.1263472916824477, 0.13531852886080742, 0.17177027144602366, 0.15204031871897833, 0.15044923552445003, 0.15490259655884334, 0.09518230041222912, 0.1636606923171452, 0.058015999384224415, 0.15767169796994754, 0.10070396055068288, 0.14471207266407354, 0.08077892900577613, 0.10846024006605148, 0.08252021949738264, 0.1400019268372229, 0.07141152915677854, 0.151181714077081, 0.29718088624732836, 0.13762264379433223, 0.2547115965613297, 0.06923282785075051, 0.14506097537066254, 0.10584796166845731, 0.10153678764722177, 0.1503376979380846, 0.1676445206893342, 0.12065769412687846, 0.16819650892700466, 0.12517733446189336, 0.14545752480626106, 0.1415119929505246, 0.11596314103475638, 0.12350926468414919, 0.08676499208169323, 0.12448486233396189, 0.09635126697165625, 0.0670118470277105, 0.09514578844287566, 0.14869978225656919, 0.10949518238859517, 0.12589248323014804, 0.15993051390562738, 0.10515289075140442, 0.1235921952341284, 0.1820796611053603, 0.17179757569517407, 0.11259989400527307, 0.10361195808010441, 0.15295108913310937, 0.18578531726130418, 0.19377198655690464, 0.11854293117565767, 0.15883709543517657, 0.18936640795852455, 0.2272595353424549, 0.22844881724034036, 0.13745805834020886, 0.21323508503181593, 0.06965729221701622, 0.13435962317245348, 0.22949313691684178, 0.16967587811606272, 0.18964322310473236, 0.09382905052708727, 0.18286737240850925, 0.28270708290593966, 0.1927649863064289, 0.30487520194479395, 0.18164092036230223, 0.19730397846017564, 0.24623642276440347, 0.05451357464439102, 0.1724556325269597, 0.16266674708042825, 0.17826018748538836, 0.2283516510256699, 0.17330222709902696, 0.14204370656183787, 0.14775850490799972, 0.32058089918323923, 0.10641303206128733, 0.21015165905867303, 0.21862742996641568, 0.19539908639022283, 0.20199401250907353, 0.15765766586576188, 0.14369444655520575, 0.27858772394912584, 0.22548524769289152, 0.35458874862108913, 0.10887945257127285, 0.13055651581713132, 0.23218149266072682, 0.18495290407112666, 0.23643522869263375, 0.22499812740300382, 0.22739718295633793, 0.2620282939502171, 0.11733619735709258, 0.2376884285892759, 0.22641747338431223, 0.20068376138806343, 0.28281304293445175, 0.15568787870662554, 0.18452694692781993, 0.182586757466197, 0.117110475897789, 0.08558586106768676, 0.09098449602190938, 0.11455751503152506, 0.16901403505887302, 0.09026491641998291, 0.11485151068440505, 0.06880782744182007, 0.1468857867377145, 0.07308032496699265, 0.19707124094877923, 0.1460752630872386, 0.1700775165643011, 0.1711067591926881, 0.1778246494276183, 0.11037341026323182, 0.1276188934487956, 0.0779474430850574, 0.10460622222828013, 0.1188265181013516, 0.303811394742557, 0.1966233399829694, 0.11875238136521407, 0.15082312189042568, 0.1886310524174145, 0.14568245916494302, 0.13106745268617356, 0.192097131428974, 0.19968422502279282, 0.09947238556508507, 0.11138096691242286, 0.10519599129578897, 0.17174030733960016, 0.1624203303030559, 0.1775194172348295, 0.08319663070142269, 0.08910474367439747, 0.11887649899082524, 0.1294198203831911, 0.08419898977237088, 0.15883560265813554, 0.11895762463765484, 0.1652697566896677, 0.10217625940484659, 0.11543433155332293, 0.171962581841009, 0.07918030728719064, 0.13996186612972192, 0.07301650874848876, 0.27946572112185614, 0.1314334273338318, 0.11198575195989438, 0.10750377710376467, 0.07897498937589781, 0.12269787250884942, 0.15439030261976378, 0.1582913225782769, 0.08886238453643662, 0.08975512627512217, 0.14034188645226614, 0.16099151197288716, 0.16469168556588037, 0.18200599934373582], [0.006341434341655778, 0.03901707314487014, 0.0739287855103612, 0.029713126498141458, 0.015821407815175395, 0.012883570011971253, 0.03658682872940387, 0.0161083925049752, 0.002842320852713393, 0.063668277513768, 0.035463537754757066, 0.018151013613013283, 0.0382099285987871, 0.02139937618215169, 0.0657455310491579, 0.01848490203597716, 0.06899715228272335, 0.04173888745052474, 0.04160402522289327, 0.05090304909806166, 0.09197640565357038, 0.04421686001920274, 0.030495870924953903, 0.021308885055727193, 0.02960192139393517, 0.0529821923534785, 0.03389068340350475, 0.07700715639761516, 0.07254068606666156, 0.00810558595029371, 0.050746338042829714, 0.011362409851114665, 0.015166906506887503, 0.024761535859267627, 0.024963754561862776, 0.01605232006737164, 0.03183995719466891, 0.012260029408415514, 0.03796603597168412, 0.07705934252589941, 0.016352824567418014, 0.0017025905648811854, 0.06194942617522819, 0.04828171904331871, 0.03617191474352564, 0.07689690124243498, 0.05542651976325682, 0.03976555833859103, 0.04975322061883552, 0.041280455621225495, 0.021505980818931545, 0.044385822024196386, 0.038025859011603255, 0.03279506308691842, 0.008772160092900907, 0.02116423156777663, 0.08732011515114989, 0.02079476585744747, 0.041965582607580085, 0.12992542396698678, 0.035466787937496386, 0.02394472897451903, 0.03852107761693852, 0.03647706551211221, 0.06803379540464707, 0.022436807031876276, 0.09799506555178336, 0.1060032919049263, 0.18561547994613647, 0.09058894403278828, 0.07627649631883417, 0.19360546049262795, 0.16428342461585999, 0.3498665248709065, 0.4579760708979198, 0.3998228513768741, 0.1000084418005177, 0.2574997240943568, 1.7492729404142924, 0.8833325207233429, 0.8997040508048875, 1.374945146696908, 1.1183651089668274, 2.566919905798776, 2.731590041092464, 1.321300819516182, 1.3994050856147493, 1.0602771916559763, 1.0203074621302741, 1.026032343506813, 1.2365728574139732, 0.15967731177806854, 0.21555191571159021, 0.08815524926675217, 0.07914144080132246, 0.24806474894285202, 0.5007419075284685, 0.12256983295083046, 0.04064271752057331, 0.08482747604804379, 0.11804878126297678, 0.1367043959242957, 0.14072192034551076, 0.04596336165975247, 0.04348432379109519, 0.019621439710525528, 0.03524220302434904, 0.08742519308413778, 0.044069156516343355, 0.13982267145599636, 0.01909331215678581, 0.03796482817935092, 0.054156132574592314, 0.010712186706119349, 0.05486678944102355, 0.04281303891912103, 0.06279441261930124, 0.026053347791145955, 0.05490585948739733, 0.05034844171521919, 0.02605525277821081, 0.07261033090097563, 0.02132127171249262, 0.026616991564099277, 0.05575663383517947, 0.0751086493421878, 0.049328552692064216, 0.06287517864257097, 0.02960096126688378, 0.0311403299149658, 0.05284126063010522, 0.008363173958579344, 0.005434407320405755, 0.02197059240591313, 0.004670463402622512, 0.04919491182746632, 0.057814291279230795, 0.056254902455423555, 0.030830558322902237, 0.03855476688061442, 0.030202241680983986, 0.023369227802114825, 0.0742196124047041, 0.03838106870119061, 0.02628848562017083, 0.09489571436175279, 0.008457485237158835, 0.05735387134232691, 0.0065664153496202615, 0.051427071514938555, 0.035714758560061455, 0.013816431829971927, 0.0299250126284148, 0.0566254300730569, 0.035379443517220874, 0.05303499594862972, 0.011752941529266536, 0.00567930333116757, 0.03191030431272728, 0.014632814630333866, 0.02085517413382019, 0.08812832499721221, 0.029581331248794283, 0.052533273585140705, 0.030701585779232637, 0.022599399289382354, 0.03722601889499596, 0.014595072816259094, 0.011561740539036691, 0.0357096627620714, 0.028698848959590708, 0.021901127383378998, 0.04362906548859818, 0.0669123466525759, 0.0511970176095409, 0.023049230687320232, 0.018448542737002884, 0.035926939853067906, 0.030861984672290937, 0.0550117516624076, 0.05343347581635628, 0.05296591429838112, 0.018401216615789702, 0.045250686151640754, 0.042611829537366114, 0.06035096051969698, 0.030090415717235634, 0.02914418506303004, 0.026588245428034236, 0.031281950351383, 0.03911734026457582, 0.025262398179620504, 0.05128482004095401, 0.0006224709037009493, 0.005588047580593931, 0.04367142982248749, 0.05263179008449827, 0.058205615995185714, 0.0560548194417996, 0.035329459235072136, 0.007237069608111466, 0.03570061110492263, 0.028424714026706557, 0.07048536278307438, 0.04162834391796163, 0.04075997176447085, 0.03120908247573035, 0.03158456000632473, 0.0496401190092521, 0.059736255290252824, 0.054675459529140165, 0.026162929500320127, 0.03552783573312419, 0.01690177127186741, 0.044196181664509435, 0.02046355086245707, 0.03677372441494039, 0.04941480127828462, 0.037553412041493824, 0.014442321012860962, 0.0040848749589973265, 0.029574311804026365, 0.0676646384277514, 0.05491106045831527, 0.02812345974546458, 0.06256856902369431, 0.033830880719636164, 0.05152827501296997, 0.08848579760108675, 0.002969577975038971, 0.047686735434191566, 0.03954084789646523, 0.0852238762059382, 0.07670570364488022, 0.01731140964797565, 0.09387379991156714, 0.06946549750864506, 0.02225760423711368, 0.07371798503611769, 0.09684420230665378, 0.06469711980649404, 0.02391852904111147, 0.0888209328321474, 0.03191915240937045, 0.19942552676158293, 0.11727367714047432, 0.1937345721359764, 0.06401370612106153, 0.06656196473964623, 0.3785493129066059, 0.42966672139508383, 0.47531101214034216, 0.08055271900125913, 0.16535352862307004, 1.1611147693225314, 0.45627419650554657, 0.21231102890201978, 1.0003465903656823, 0.7988147959113121, 2.4263042168957845, 2.394244142941066, 1.3746148901326316, 1.5790509773152215, 1.6675832952771867, 1.596722417644092, 1.6194051376410892, 1.3882532268762589, 0.05815207279686417, 0.2656121530703136, 0.050070571447057385, 0.09007358311542443, 0.25742731083716663, 0.5935187063046864, 0.13725373787539347, 0.09166646442775216, 0.07283124833234719, 0.29949061945080757, 0.2115962194012744, 0.08588011456387383, 0.03231631591916084, 0.051859858113207986, 0.040307938520397456, 0.03164949920028448, 0.08681358875972883, 0.08141380708132472, 0.07785241425569568, 0.10713280165301901, 0.0455089060456625, 0.055186569424612184, 0.027009233998666917, 0.07203233441604034, 0.02683775462875409, 0.06018820711012397, 0.01705658751805978, 0.035281975354467116, 0.06002345880759614, 0.056845668969409804, 0.0038351575328436282, 0.0055991208480138865, 0.06602720450609922, 0.05834541456507785, 0.01275500119663775, 0.014324518851935863, 0.11321147797363144, 0.013854021821836275, 0.018517587067825452, 0.029137935755508285, 0.06505281464861971, 0.05260760370375855, 0.007174614700488746, 0.03886914911812969, 0.0320209937303194, 0.04972823017409869, 0.08049371359603745, 0.06805877227868352, 0.03731971101037093, 0.05184390236224447, 0.04067366550277386, 0.08881586417555809, 0.0467264828538256, 0.01239872196622725, 0.013015184601369714, 0.017289632066552128, 0.050827344946031056, 0.09722505722727094, 0.006395658195417906, 0.042714033874550035, 0.06682372997914042, 0.024160735508693115, 0.0541698966574456, 0.02632374908508999, 0.047641965693661144, 0.018965645793027112, 0.028909269454223768, 0.05099469203768032, 0.06899639910885266, 0.00892412055483354, 0.031979430067752085, 0.0381051085091063, 0.07559514537985836, 0.08957540949008294, 0.04313926837806191, 0.033760302899671454, 0.02372209315321275, 0.021055603200303655, 0.022646835672536066, 0.012795644596086016, 0.03824053731347833, 0.04477487704051392, 0.05637065713692989, 0.03964013792574406, 0.02033892772825701, 0.09163097026092665, 0.1805499717593193, 0.1491853283452136, 0.1731860347624336, 0.13807997639690126, 0.12148157134652138, 0.10884946132344858, 0.13350945950618812, 0.09551117276506764, 0.08370487378644091, 0.11457564548722335, 0.10956097992935351, 0.12992188201418944, 0.06522978336683341, 0.1067181353324226, 0.12706881867987768, 0.16784102443073476, 0.0956311309710145, 0.1459475899381297, 0.08040819104228701, 0.16282864553587778, 0.11601613461971283, 0.1099223948216864, 0.09078615345060825, 0.10142570467931883, 0.15238358958491258, 0.12164441975099699, 0.17391727838133061, 0.10517641556050096, 0.20011096926672117, 0.16559865618390696, 0.14143800549209118, 0.1004762849105256, 0.10298381785729102, 0.20929484574922494, 0.11226528124617678, 0.13304230171654904, 0.12931069838149206, 0.09004314403448786, 0.13964645591165337, 0.060578357960496626, 0.09875954381589379, 0.1899327268557889, 0.10865472177309649, 0.09146727368767772, 0.1957620619130986, 0.19720985208238873, 0.13992795294948987, 0.14579213756535733, 0.14662426577082702, 0.16733278813106672, 0.1493936793080398, 0.15135745464691094, 0.13393752010805265, 0.09748589965913977, 0.1798164075506585, 0.12951220971133026, 0.25252334826758926, 0.09932125546038151, 0.28245013526507784, 0.19401640844132217, 0.09496677733425583, 0.1398955596876996, 0.1799776546124901, 0.11212337921772685, 0.16012681408652238, 0.16943963936397008, 0.14265206748885767, 0.32176860687988146, 0.4284980126789638, 0.20048946967082365, 0.37551048025488853, 0.3565746306308678, 0.520053068442004, 0.5512641593813896, 0.41462490281888414, 0.10720845152224813, 0.38112106919288635, 3.124202127967562, 2.242347836494446, 2.2117566551480974, 3.2362722286156247, 3.3984835701329366, 5.206711649894714, 5.026353784969874, 3.6395847584520067, 4.080193264143808, 3.248681059905461, 2.8297363860266547, 3.7910105415752957, 3.507691664355142, 0.2781437449157238, 0.2978319270270211, 0.1076092892991645, 0.19986139051616192, 0.36179918742605616, 0.7491226366588047, 0.27341302590710775, 0.2012741139956883, 0.2484859020582267, 0.2955822306019919, 0.4633913774575506, 0.2791587518794196, 0.17574626952409744, 0.1280252816421645, 0.1119562696133341, 0.10883652166064296, 0.22768690383860044, 0.1840890882802861, 0.21310123721403734, 0.23303983945931706, 0.1490399997149195, 0.12926453085882322, 0.13868493107812746, 0.17220006909753593, 0.21840329627905572, 0.103584253495293, 0.10120390515242304, 0.10667683969118766, 0.13882032595574856, 0.10697652146752391, 0.1260585750320128, 0.09422547104103224, 0.13916924223303795, 0.11743719050926821, 0.11561183631420135, 0.16991935005145414, 0.16396356320806912, 0.08957920928618737, 0.13425723223813943, 0.11349382996559143, 0.24348594035421098, 0.1299377190215247, 0.04098765418997832, 0.09910356107034854, 0.08815946975456816, 0.12043997938079493, 0.23996909335255623, 0.18193320610693522, 0.164193043751376, 0.10452332560505186, 0.11687237795974527, 0.27894110498683794, 0.14385515078902245, 0.09560192682381187, 0.22722589357623033, 0.1075431728469474, 0.22060016196753296, 0.2054642712963479, 0.12373950518667698, 0.15306539514235087, 0.14905599957065924, 0.08248000951217753, 0.15824681068105356, 0.10344644303300551, 0.20446763906095708, 0.1539291159382888, 0.09594643262348004, 0.14256030241293566, 0.17331723629363946, 0.08991150145551988, 0.16382499278656074, 0.13329447247087955, 0.23214341327548027, 0.1295803346272026, 0.1857678381992238, 0.12406369564788682, 0.13073701970279217, 0.19859003302242073, 0.0953392523473927, 0.10746178257146052, 0.15484485322875635, 0.11307920435709612, 0.1758067812770605, 0.11497850529849529, 0.12921993753739766], [0.04806953435763717, 0.011387186557320612, 0.02884937516812767, 0.0775755380413362, 0.022527362619127547, 0.023817975240360414, 0.06074922664889267, 0.009922952940022307, 0.054322838450648954, 0.023815904012215987, 0.005226071624617491, 0.05100491756041135, 0.01650908778953765, 0.009715076103540403, 0.07652370698217835, 0.0550829910540155, 0.02791806380264461, 0.09406876337847539, 0.043802478683314154, 0.05624843940937093, 0.03152712880234633, 0.017048909894323776, 0.07923812525612967, 0.06296910824520247, 0.04877978071038212, 0.07160309316324336, 0.012580799204962594, 0.009944793285935052, 0.04159063433430024, 0.019228053944451467, 0.11134462457682405, 0.07031830067613296, 0.03936683080558266, 0.019376425804304223, 0.026063603847952824, 0.02639798929781786, 0.017015288484149745, 0.058737906361264844, 0.0026232816910903367, 0.05205054341682366, 0.058689228259027004, 0.06284570308136088, 0.03715193983433502, 0.033738654239901474, 0.023419715896514908, 0.01952928786964289, 0.03906999887632472, 0.04631407944751637, 0.08058540403310742, 0.044551533846450705, 0.02301860161657844, 0.03727066310654793, 0.013238570203871598, 0.02980410786611693, 0.1558604437325682, 0.08124129633818354, 0.02097236391689096, 0.040797762772334475, 0.07147260409380708, 0.0248447598756424, 0.0918130890599319, 0.056333683763763735, 0.15006276911922864, 0.02960491373336741, 0.0826204934024385, 0.0737267584939088, 0.06317978658314262, 0.1797372360846826, 0.3822464330920151, 0.16277718544006348, 0.1342682923589434, 1.9813619894640786, 8.011755006653921, 25.078117540904454, 32.79210662841797, 38.110570498875205, 57.990231718335835, 64.67488861083984, 96.50535065787179, 100.33516992841447, 83.41437476021903, 97.4490133013044, 97.92060838426862, 106.84938403538295, 108.86157539912632, 99.37901442391532, 95.28845705304826, 98.0407635825021, 102.94867924281529, 99.6174488067627, 103.95482008797782, 72.43071801321847, 49.56007964270455, 52.35983542033604, 44.89467000961304, 38.35934032712664, 20.815283060073853, 4.488894121987479, 2.3662817691053664, 0.16992149422211306, 0.0404885475789862, 0.25980953872203827, 0.08356635764773403, 0.06868322805634566, 0.01676902437715658, 0.1694078839250973, 0.27130755888564245, 0.19395745731890202, 0.24734330336962426, 0.015524809980498893, 0.019352514230247055, 0.1490667068532535, 0.141779878575887, 0.09542594198137522, 0.10034240316599607, 0.03252562361636332, 0.07342076634189912, 0.05663674803716796, 0.015451134648174047, 0.041887479834258556, 0.02108296173225556, 0.026558352567787682, 0.030653772809143578, 0.0467608235111194, 0.07317830542368547, 0.07665151583829097, 0.0025668084937413888, 0.03134950190516455, 0.02840134358432676, 0.03410608773784978, 0.0342788766803486, 0.02258874798592712, 0.028293168138978735, 0.03781303989567927, 0.058719646983913014, 0.07480199222585984, 0.047058520572526116, 0.031187532203538076, 0.002491072959466172, 0.043915529402771165, 0.041818109806627035, 0.054912485381854434, 0.018129424325057437, 0.04493815292205129, 0.048222818811024935, 0.027137309179774353, 0.031095356613929783, 0.08038649827774082, 0.02381700663162129, 0.027222930121102502, 0.0416977919771203, 0.03400165780580469, 0.05126683207760964, 0.026987025547506552, 0.025934741566223756, 0.028552740014025142, 0.08579596265086106, 0.04854493634775281, 0.025601748809484497, 0.04440732479893735, 0.07462492851274354, 0.0715554803609848, 0.018095584087339894, 0.03816259738856128, 0.06606061557041747, 0.0865762032834547, 0.04896244912275246, 0.08969595802149602, 0.0407930299905794, 0.028958938217588832, 0.02106138431866254, 0.02358380941274975, 0.042126015427389314, 0.03281286445313266, 0.047569287807813714, 0.04183819105050393, 0.030458157948617424, 0.04382806284619229, 0.04619548848963209, 0.06276510669184582, 0.02465561654285661, 0.026230910227500966, 0.01582746034754174, 0.01774940230617566, 0.06759755167045764, 0.03421769657039216, 0.059388214323137484, 0.030402473972312043, 0.016990954522043467, 0.13890603849930422, 0.08245163317769766, 0.040134650854659934, 0.05553704633244446, 0.06224074161478451, 0.04842515116823571, 0.06144617032259703, 0.01172861604884799, 0.010047041727895183, 0.039446439926645586, 0.04844104924372264, 0.032262854145041535, 0.028096223349816034, 0.03630223757188235, 0.008849422330968082, 0.04535850875877908, 0.010902786344688917, 0.12320893151419503, 0.0604544710367918, 0.06310508666293961, 0.002984226485880624, 0.04847800226083823, 0.04820011842197605, 0.027502669753240686, 0.020051446011556045, 0.03463236967633877, 0.049171634683651586, 0.01656235278850155, 0.03100373742303678, 0.04137146073792662, 0.0189050560085369, 0.015568137834114688, 0.02655618973741574, 0.14901075485561574, 0.03880466454263244, 0.03337490179442933, 0.04488533914887479, 0.023920708834858875, 0.02838140822547887, 0.07255543741796698, 0.11714067070611886, 0.11206214821764401, 0.053526869376323054, 0.017715170214484845, 0.04930444095017655, 0.1104006805856313, 0.07840534565704209, 0.0698575618277703, 0.023771286942064762, 0.2685613105339663, 0.2945598140358925, 0.11260418913194112, 0.09261769588504519, 0.03807368215971759, 0.09317411495638744, 0.3619671112724713, 0.1701442708394357, 0.029866980920944895, 1.653768647994314, 8.180199316569738, 24.830158914838517, 33.768387590135845, 42.57573652267456, 65.35809803009033, 75.24539852142334, 111.31326811654228, 115.205461365836, 100.69180011749268, 108.67097241537911, 113.47634656088692, 122.45444052559989, 126.93816866193498, 119.88402393886021, 116.33598886217389, 116.09512955801827, 118.74986948285783, 116.89371381487165, 121.0582139151437, 83.41144956861223, 58.96597766876221, 63.93336296081543, 51.50044747761318, 44.753854342869346, 25.194817747388566, 6.10020569392613, 2.3301817519324164, 0.01769300756443824, 0.016795049587796842, 0.29327898419329096, 0.20512192323803902, 0.08858854815896068, 0.04142449164230909, 0.15353544349116938, 0.410816557173218, 0.19550754342760357, 0.2374129705131054, 0.07940480738346066, 0.05056172562763095, 0.14670007170311042, 0.12978077387171133, 0.11862469464540482, 0.08021567030144588, 0.010922889640953923, 0.06812290062329598, 0.06777490036828177, 0.07279553024896554, 0.08937435277870723, 0.037303253143493614, 0.029507567706917013, 0.04706145862915686, 0.04661170526274613, 0.031786329179470024, 0.08984383794346026, 0.04999628882589085, 0.05374695899497185, 0.07570282888731786, 0.0601840273344091, 0.05175369791686535, 0.04111076079841171, 0.022069275146350265, 0.05986921422715698, 0.10578182486018964, 0.0709417997194188, 0.053562845303011794, 0.019497815719140426, 0.04107081204918878, 0.05417452087359769, 0.0517456403135189, 0.022054092925308005, 0.008042924937659075, 0.08637321953262601, 0.08363556821963616, 0.018133225817499415, 0.022259327716061046, 0.05810380181563752, 0.04796761839783617, 0.026060611508520584, 0.07587826411638941, 0.04483411654031702, 0.023188598387475525, 0.05620399197297437, 0.02687119792348572, 0.04756126752389329, 0.05586849033300366, 0.014577318947496158, 0.030919015540608337, 0.014519472140818834, 0.01947592957211392, 0.03013776389083692, 0.018824149189250808, 0.026502975628578236, 0.026592657601993, 0.004055900665532265, 0.018516577746985213, 0.06596204478825841, 0.04126752952912024, 0.029234420042485, 0.04524153271423919, 0.03052899700456432, 0.01825136554959629, 0.05729600587593658, 0.03144828981852957, 0.02149163998131241, 0.13166647697133677, 0.10436640759663922, 0.1100754655365433, 0.11442834910537515, 0.15483596442001207, 0.1662935438965048, 0.09434333935912166, 0.09440687059291772, 0.19783114588686398, 0.1112765200170023, 0.18998809531331062, 0.10387833057237522, 0.1384851975100381, 0.19344642545495713, 0.204282032591956, 0.13039769791066647, 0.10558899199323994, 0.2438897229731083, 0.08586402649858169, 0.15057464236659662, 0.11622346778001104, 0.14422131542648586, 0.17336838426334517, 0.21670607663691044, 0.1107037075396095, 0.1763548475823232, 0.10295069856303078, 0.08390778968376772, 0.15501003579369613, 0.11255823874047824, 0.23204526997038297, 0.14904574012117727, 0.13638734365148203, 0.051188491817031584, 0.09723443458122866, 0.11644437164068222, 0.17269463970192842, 0.10628601709114653, 0.06689693033695221, 0.18405612504908017, 0.16210920842630522, 0.15343523743961537, 0.1586014266524996, 0.2094372431082385, 0.09110424388200045, 0.18962807820311614, 0.25779298692941666, 0.16010244110865252, 0.13199435866304807, 0.11233500071934291, 0.12743738533130713, 0.1490786490695817, 0.21644374142800057, 0.2305667150233473, 0.2881855203637055, 0.11776026817304747, 0.12572512935314858, 0.17595224561435835, 0.24619983615619795, 0.3007078841328621, 0.2233338031385626, 0.11529189348220825, 0.43858269868152483, 0.31868235820106094, 0.19821130191641195, 0.28610939319644657, 0.24770300835371017, 0.47847407098327366, 0.5074564186590058, 0.17264668084681034, 0.22492370568215847, 3.271657884120941, 13.062554291316442, 35.212740898132324, 48.253561224256245, 56.879374572208945, 82.58349527631486, 98.31981018611363, 134.28038569859095, 139.82229668753487, 121.20461245945522, 134.12505177089145, 138.39381653921944, 149.36253465924943, 150.09769575936454, 143.1153120313372, 134.59583391462053, 137.19635009765625, 143.24846730913436, 141.31151798793246, 143.87049783979143, 102.61601339067731, 74.38265459878104, 80.6097274507795, 68.79977703094482, 57.93957935060774, 31.99033314841134, 9.358037097113472, 5.075144904000418, 0.6572206052286285, 0.13634983423565114, 0.4845623757158007, 0.5637366643973759, 0.18118205427059106, 0.09557405260524579, 0.20797596366277762, 0.3773968076067311, 0.3397075799959046, 0.4223320563989026, 0.21151440164872579, 0.11469741538167, 0.2205753411565508, 0.458479001053742, 0.25792470414723667, 0.14170449333531515, 0.08596671598830394, 0.1696163434535265, 0.1511337145098618, 0.10720969324133225, 0.16432833006339415, 0.09862051199057273, 0.08366323209234647, 0.19059105510158197, 0.14162163063883781, 0.14913158837173665, 0.23092194167631014, 0.10997742401169879, 0.09525309197072472, 0.1489580733967679, 0.19816726499370166, 0.10828124931348221, 0.19923271425068378, 0.20551589424056665, 0.1972502384866987, 0.2516759123120989, 0.12365782314113208, 0.1528017707169056, 0.11803640478423663, 0.13153621181845665, 0.15954697877168655, 0.16348052769899368, 0.11977135097341877, 0.11012896802276373, 0.21040935308805533, 0.12683099215584143, 0.15948285721242428, 0.08268874723996435, 0.2208093000309808, 0.11196304139282022, 0.12144665393446173, 0.13107309809752873, 0.14833021137331212, 0.1273087758038725, 0.0891898183950356, 0.10200469861073153, 0.09152646229735442, 0.18838551773556642, 0.12357154062816075, 0.11506978182920388, 0.24121086671948433, 0.189638079809291, 0.19053247038807186, 0.09808990439133984, 0.18201963789761066, 0.1097785182563322, 0.23283478617668152, 0.08622595707752875, 0.17154089946831974, 0.12765785492956638, 0.17230091297200748, 0.19268266643796647, 0.137103265949658, 0.11337338321443115, 0.1147253303123372, 0.11991692387631961, 0.11114404283996139], [0.03431474743410945, 0.011706473754851945, 0.025056408518659215, 0.03889470613960709, 0.07165903159018074, 0.05806885726217713, 0.02472612650931946, 0.016048046993091702, 0.07952054510159151, 0.02154557842628232, 0.09062491995947701, 0.01871981255577079, 0.029060592941407646, 0.015612980517159616, 0.06347400615257875, 0.08062619077307837, 0.0560095882974565, 0.027443224996594445, 0.0402584665321878, 0.057236885119761736, 0.08925650481666837, 0.02337612341424184, 0.00938507738257093, 0.026892678645838584, 0.026601258033354367, 0.02060524424138878, 0.03216589488355177, 0.030099314704005207, 0.02638082066550851, 0.07312700817627565, 0.02965410073686923, 0.06345819628664426, 0.0453255149934973, 0.06830973524068083, 0.040426169854721854, 0.03815685019695333, 0.023694188400570835, 0.027045547496527433, 0.025201711703890135, 0.0789651031206761, 0.014906050504318305, 0.08533886075019836, 0.015498957796288388, 0.048065748132233105, 0.029440810039107288, 0.031822847934173684, 0.05569049024156161, 0.03220469012324299, 0.06542886554130486, 0.026051592081785202, 0.028347284699391042, 0.028010032439072217, 0.0801726918933647, 0.14234048420829432, 0.05605416465550661, 0.038942023779132535, 0.17750591438795837, 0.09435318490224225, 0.0046164893345641235, 0.11316508653440646, 0.04093448418591704, 0.05422869850216167, 0.8433930267180715, 0.4215409117085593, 0.12164353765547276, 0.7675887772015163, 1.1371796365295137, 5.670511722564697, 9.446797728538513, 35.789979866572786, 55.04622786385672, 70.82561465672084, 93.1655808857509, 107.57871559688023, 108.20052378518241, 103.88713073730469, 105.15670558384487, 109.94820417676652, 96.4961929321289, 98.42385251181466, 109.09365912846157, 103.6013582774571, 99.09905065808977, 96.05988080160958, 97.57958384922573, 91.03942516871861, 102.8982492174421, 83.47037724086216, 90.45796516963414, 94.27964115142822, 89.7556482042585, 110.16782283782959, 107.8354515348162, 108.5350934437343, 116.10829639434814, 117.88320677621024, 111.12060151781354, 109.53923320770264, 92.0846426827567, 69.04290839603969, 59.133276394435335, 16.87535568646022, 3.618220350572041, 0.2594762151794774, 0.06491049192845821, 0.16711071719016346, 0.41288416194064276, 0.4518414357943194, 0.29961346143058365, 0.09268822281488351, 0.1073916084798319, 0.05513416616512196, 0.09334940769310508, 0.04552598137940679, 0.0265719979070127, 0.03892587125301361, 0.03187256080231496, 0.04552366418231811, 0.10795973906559603, 0.031334543600678444, 0.10466811140733105, 0.01147143600974232, 0.06263015964733702, 0.02662858263855534, 0.05533210840076208, 0.03187231992238334, 0.026854606045942222, 0.007360214384139648, 0.015218729618936777, 0.06691283519778933, 0.012613398571764784, 0.021354893122666647, 0.04934182144435389, 0.013341978940713619, 0.05077848703201328, 0.03905831789597869, 0.02906977691288505, 0.030702671435262476, 0.03626840581585254, 0.03496388153039983, 0.018397745909169316, 0.04274547040196402, 0.07200240423636776, 0.016744653095624278, 0.09939734637737274, 0.05145831805254732, 0.0626720931114895, 0.025589882928345884, 0.09355355173881565, 0.02969687558444483, 0.026103830796533396, 0.03513280621596745, 0.04793936080698456, 0.018218716140836477, 0.021794468463797654, 0.06715495006314345, 0.04161119394536529, 0.09166651871055365, 0.039558737472231896, 0.062084468214639595, 0.03213275862591607, 0.03224769228004983, 0.07994198320167405, 0.018433060264214873, 0.040837250117744715, 0.026875964631991725, 0.05945245123335293, 0.0338653536912586, 0.022277524328923652, 0.022075901040807366, 0.11744394871805396, 0.053165084682404995, 0.062416210770606995, 0.017241788562387228, 0.04895655943879059, 0.07801258244684764, 0.07822425144591502, 0.05513878020324877, 0.07819405663758516, 0.019003294308536818, 0.038238430462245426, 0.0952413465295519, 0.018558136320539882, 0.010689334494860044, 0.08776540375713791, 0.057041616312095096, 0.05619641273681607, 0.06372348990823541, 0.07789172857467618, 0.027272212119506936, 0.01832172623835504, 0.03396774462557264, 0.07522478061062948, 0.06237717465098415, 0.087695073602455, 0.012964527721383741, 0.015289209051323789, 0.016170134102659564, 0.0014097864831066026, 0.06819891011608498, 0.02130171124424253, 0.056567143914955, 0.02367106223079775, 0.038382500410079956, 0.0591698753248368, 0.009041056735441089, 0.04749061506507652, 0.043874427144016535, 0.06749980870102133, 0.02937957564634936, 0.03272536736247795, 0.055883034731128385, 0.05007546707721693, 0.024687521259433458, 0.03813630076391356, 0.07031315738069159, 0.026847647669325982, 0.09605581925383636, 0.053385459285761626, 0.051794287881680896, 0.05230009502598217, 0.030132559527243887, 0.068743203766644, 0.05777931958436966, 0.13433028331824712, 0.05440241025228586, 0.06275838240981102, 0.01778034519936357, 0.021648797173319117, 0.03366116554077182, 0.057619701006582806, 0.011222285584413579, 0.08652751161051647, 0.09876903652080468, 0.030977132064955573, 0.10694910186742033, 0.06077781332922833, 0.06995493160294634, 0.6971408831221717, 0.5948626941868237, 0.1500274852982589, 0.7096117596541132, 1.3375213891267776, 5.29682674578258, 10.861653327941895, 39.69598960876465, 67.24597917284284, 86.59124401637486, 111.43887070247105, 126.37536457606724, 127.94907597133091, 123.23679379054478, 119.32297079903739, 128.60083089556014, 112.94567094530377, 115.4494959967477, 124.18573706490653, 122.67984008789062, 119.42794418334961, 112.9916124343872, 112.1664652143206, 111.40971606118339, 119.09690420968192, 108.3259665625436, 113.76410620553153, 118.57048089163644, 113.94198703765869, 136.77649824959892, 134.43249566214425, 129.1919002532959, 141.63680485316684, 139.42740276881625, 132.09856796264648, 128.78312383379256, 116.07256180899483, 87.26389217376709, 74.29659421103341, 22.2708420753479, 5.512503606932504, 0.7317219046609742, 0.04954794341964381, 0.18447513399379595, 0.34959445946982926, 0.33268960086362703, 0.35264159739017487, 0.12398710261498179, 0.09982480986842088, 0.061211105436086655, 0.10486777033656836, 0.042230462322809866, 0.10133233826075282, 0.018894874590582082, 0.014894986990839243, 0.06581672294331448, 0.11461531264441353, 0.028081107285938094, 0.01716935494914651, 0.031103889191789285, 0.07136880859200444, 0.01119348092470318, 0.04950585049976196, 0.03802810496251498, 0.04053143099216478, 0.02304821627746735, 0.08480992234711136, 0.03451299840318305, 0.055505871041012664, 0.03694142434479935, 0.04047584201076201, 0.03480924679232495, 0.02269851289955633, 0.01691685849800706, 0.02633340803108045, 0.05131500806393368, 0.052637398176427395, 0.04499675120626177, 0.09680932560669524, 0.04058443136247141, 0.07520609375621591, 0.01638610501374517, 0.03947551175951958, 0.029055880515703132, 0.05836136692336627, 0.04865020087787083, 0.03335168232609119, 0.052241547631898096, 0.04462255610685263, 0.018898326637489454, 0.02448360452295414, 0.07903881237975188, 0.014589554630219936, 0.08659700038177626, 0.05138366562979562, 0.020458969054743648, 0.014211150069188858, 0.01128339784086815, 0.02685410562636597, 0.015488650849355119, 0.07675128762743302, 0.048709477697099955, 0.043362944054284265, 0.03461406619421073, 0.11537143135709421, 0.023541489183636646, 0.026697196099641066, 0.02540667847331081, 0.09621997723089797, 0.07010783268404858, 0.06630667950958014, 0.10224637921367373, 0.0459196673972266, 0.07054913150412695, 0.13042000814207963, 0.11083899385162763, 0.22718967337693485, 0.13369726442864963, 0.16273135718490395, 0.24643127088035854, 0.09336641178067241, 0.13315029735011713, 0.16852513700723648, 0.17009243076401098, 0.1353153804583209, 0.18371745465057238, 0.16665509449584143, 0.1297832301684788, 0.12267644437296049, 0.17173937096127442, 0.1474954504519701, 0.09843293098466736, 0.14407817167895182, 0.13332907775683062, 0.1346928110080106, 0.11174863789762769, 0.08287369552999735, 0.13025061866002424, 0.14213457597153528, 0.08469811334673848, 0.11401911106492792, 0.16258351797504084, 0.12752256861754827, 0.1634556254638093, 0.08904667464750153, 0.16006908432713576, 0.1861475056835583, 0.1753866323935134, 0.17520623707345553, 0.13006100883441313, 0.12163576164415904, 0.075836296725486, 0.13337213758911404, 0.23243863029139383, 0.1151055677660874, 0.2123972164200885, 0.1551150187317814, 0.13854726989354404, 0.1201512763010604, 0.15290015829460962, 0.2136195565440825, 0.12966224737465382, 0.1569134486573083, 0.1705730642591204, 0.15097238602382795, 0.08399012312293053, 0.13981754173125538, 0.20596957632473537, 0.19399679877928325, 0.10567545092531613, 0.3343817043517317, 0.3648814191775662, 0.22986375274402754, 0.17930304152624948, 0.14748789157186235, 0.2633629451904978, 1.1037605383566447, 0.7120051969374929, 0.10976120204265628, 1.8637259474822452, 3.216437292950494, 9.360559293201991, 16.978352308273315, 53.84658663613455, 84.7017161505563, 106.7089956828526, 133.21444865635462, 144.9154096330915, 144.23458344595772, 135.8080027444022, 133.5601910182408, 137.03312301635742, 120.01096752711705, 123.06974520002092, 138.08050836835588, 132.67961801801408, 124.51880591256278, 120.57343809945243, 121.34322902134487, 116.02252783094133, 128.89804703848702, 110.24102905818394, 114.02280153547014, 122.49050167628697, 121.95933968680245, 143.93982696533203, 144.28283173697335, 145.76906531197685, 152.82319613865442, 154.42443629673548, 150.15478215898787, 153.63341167994906, 135.53359058925082, 111.7531863621303, 89.1718397140503, 28.663448810577393, 7.622324109077454, 1.1749011895486285, 0.23165150252836092, 0.2474654939557825, 0.4029181924249445, 0.7874346779925483, 0.583084086222308, 0.30385900075946537, 0.2805081680417061, 0.12926373018750123, 0.26794650352426935, 0.17365123837121896, 0.14137363966022218, 0.10926608182489872, 0.18240900843271188, 0.11204180573778492, 0.3024921326764992, 0.192613116598555, 0.16442970319518022, 0.11433828036699976, 0.23839274793863297, 0.12036779682551112, 0.12381863594055176, 0.14508279705686228, 0.09402045168514762, 0.1287352599735771, 0.23388768253581865, 0.15952632416571888, 0.0861928445686187, 0.10758362031940903, 0.10672426250364099, 0.06867024768143892, 0.10148912056216172, 0.11881534941494465, 0.10229017864912748, 0.13131566079599516, 0.14536388697368757, 0.1173352338373661, 0.23003724057759556, 0.1200869647519929, 0.217366169073752, 0.11813549803836004, 0.178209853757705, 0.15773560239800385, 0.151896401441523, 0.17737305723130703, 0.14009708458823816, 0.15765719089124883, 0.0963975362745779, 0.1261854882219008, 0.1478094221757991, 0.14022122935525008, 0.11303571704775095, 0.2046978659927845, 0.10053866942014013, 0.12233975529670715, 0.06617415483508791, 0.09287683519401721, 0.10112057426678282, 0.13239576640938008, 0.15673313476145267, 0.10430012829601765, 0.11719138441341263, 0.15135503906224454, 0.2368984238377639, 0.1100414302200079, 0.10743703639933042, 0.12070790571825844, 0.3023892124848706, 0.14595365604119642, 0.17982155084609985, 0.17093437058585031, 0.10544958018830844, 0.19241942199213163], [0.06015569171203034, 0.008701021633377033, 0.0179742671150182, 0.01212245982605964, 0.04817878528098975, 0.030535741642649685, 0.03969612045745764, 0.057207307778298855, 0.03079936606809497, 0.059631157001214366, 0.04060408852196165, 0.041328512863921266, 0.003672180630798851, 0.04271455973918949, 0.06730584268059049, 0.03337799930678947, 0.054761772576187334, 0.01879718590394727, 0.034295717919511456, 0.050338535103946924, 0.05547628691419959, 0.1294958841587816, 0.0641572502042566, 0.07010531531912939, 0.022332000512895838, 0.011471916073268014, 0.059506734034844806, 0.01499537455051073, 0.029194369513009275, 0.02579375047103635, 0.032027419456945996, 0.03655999606209142, 0.018204144601311003, 0.026650394146729792, 0.03525047775890146, 0.03726725686075432, 0.05660639377310872, 0.026878168174464787, 0.028599297694329704, 0.044221657261784585, 0.053109203930944204, 0.004615038965961763, 0.047854747490159104, 0.03486082223909242, 0.0031665916779145065, 0.023931049708543078, 0.01769732983250703, 0.017481589623327767, 0.07792955690196582, 0.04253019159659743, 0.009695776023103722, 0.08869108158562865, 0.08993900926517588, 0.032021974213421345, 0.04555633564346603, 0.07154456273253475, 0.05379935886178698, 0.10090448121939387, 0.0475383194695626, 0.26891705287354334, 0.20687782258859702, 1.0190626489264625, 12.648947136742727, 22.98641620363508, 37.70363882609776, 60.70847470419747, 75.04747908455985, 83.81017889295305, 92.01984378269741, 94.79770578656877, 92.12474768502372, 89.21737820761544, 73.60766642434257, 70.90833296094621, 76.38305486951555, 78.37599972316197, 66.00314794267926, 53.11945765359061, 73.28878579820905, 81.90410041809082, 64.6246531350272, 77.40092427389962, 72.80394744873047, 65.19658020564488, 83.24725668770927, 70.60027068001884, 73.30982494354248, 101.29920469011579, 106.27893693106515, 96.43786975315639, 73.40545300074986, 75.76226806640625, 79.62222167423793, 83.18823174067906, 81.46441841125488, 73.90510490962437, 92.1184526171003, 90.21044254302979, 104.38805416652134, 109.59709085736955, 107.0996789932251, 103.4417164666312, 94.05409567696708, 72.60930756160191, 55.32427045277187, 44.01703609739031, 29.335999693189347, 19.85390077318464, 5.083153137138911, 0.1878659770424877, 0.30798107385635376, 0.047854167342718155, 0.09097432478197984, 0.07251212652772665, 0.030467799931232418, 0.07281769798802477, 0.05550471753148096, 0.07483697749142136, 0.06749044491776399, 0.16169222151594503, 0.11848982902509825, 0.01852061163767108, 0.0556374321957784, 0.027618709419454848, 0.058039734539176734, 0.0872548400823559, 0.042204779772354026, 0.031036385135459046, 0.06891387567988463, 0.0595556360536388, 0.02469878494074302, 0.028562120760657957, 0.03608565597927996, 0.09580670190708977, 0.07324388583323785, 0.05490616482815572, 0.008452883073394852, 0.02714259157489453, 0.02930951690567391, 0.009931829874403775, 0.03632635270644512, 0.04904297426609056, 0.015746882617739693, 0.041564958569194586, 0.02398546482436359, 0.017421907379425, 0.06286845436053616, 0.060658146893339496, 0.018410933237256746, 0.03858870720224721, 0.04253373694206987, 0.053004275275660415, 0.03324619048674192, 0.07891809421458415, 0.015522407966532877, 0.019647525989317467, 0.024683180331651653, 0.06046137852328164, 0.025683184886085134, 0.05593500712088176, 0.05766943762344973, 0.07020818801330668, 0.036739648386303864, 0.042155348496245484, 0.03703202234048929, 0.100562933832407, 0.06193849497607776, 0.008962114275033985, 0.05686941430238741, 0.044513142335095575, 0.04862240129815681, 0.010433031462265976, 0.005911947543998914, 0.0180561713807817, 0.03149143446769033, 0.060169425260807784, 0.02675886475481093, 0.032138237796191654, 0.06317581715328352, 0.026853528871600117, 0.02549607546201774, 0.024764843717483536, 0.02262822854598718, 0.03471172095409461, 0.06734373886138201, 0.026352939661592245, 0.04751049614112292, 0.023904636036604643, 0.03516166091763547, 0.009615556220524013, 0.016715716969754015, 0.019511793540524583, 0.03690266642453415, 0.010699984950146504, 0.043129955484930954, 0.04943567640813334, 0.0095250209893233, 0.055784823572529216, 0.00850523289825235, 0.045266987955463786, 0.04191944561898708, 0.01964975497685373, 0.018757321971601675, 0.018351035558485558, 0.057586758131427426, 0.055172632315329144, 0.0634292567680989, 0.038407039629029374, 0.05665365034448249, 0.018221102887764573, 0.040479058266750405, 0.0166928554286382, 0.01909633503029389, 0.03489167183371527, 0.026340334177283303, 0.06531449167856149, 0.024490098103082607, 0.020202667718487125, 0.08456619256841284, 0.03250348980405501, 0.016431176702358892, 0.03607692662626505, 0.07905654928513936, 0.03421255327495081, 0.07336866842316729, 0.06463185152305023, 0.03505852359480091, 0.03452174471957343, 0.045951195526868105, 0.028425146592780948, 0.06265449191310576, 0.06688747834414244, 0.01709041927408959, 0.04689337193433728, 0.043296797067991326, 0.30910888048154966, 0.10526958520391158, 1.2665920065982001, 13.69926289149693, 28.938779864992412, 44.31537437438965, 75.12534754616874, 91.83558450426374, 102.82766246795654, 105.2396879196167, 116.82852581569126, 102.72943578447614, 109.72823115757534, 89.55201734815324, 96.22810363769531, 107.58499676840646, 108.65886170523507, 120.44239507402692, 89.46557480948312, 120.61316789899553, 123.36527987888881, 104.80536992209298, 115.70463384900773, 116.07163769858224, 110.82946504865373, 114.17065225328717, 109.22646004813058, 124.1331808907645, 123.01031030927385, 132.53701319013322, 126.11534908839634, 105.00934818812779, 104.26086739131382, 116.09648445674351, 114.29503890446254, 104.8045083454677, 102.57215636117118, 119.3831421988351, 114.97909600394112, 123.19302013942173, 125.33835983276367, 123.37664713178361, 123.51370729718889, 115.14731189182827, 91.73135457720075, 71.74815477643693, 54.4947840826852, 39.290405886513845, 24.441085849489482, 6.807125840868268, 0.10500819315867764, 0.19142568031592028, 0.014455337010856186, 0.13160734942981175, 0.02445267011145396, 0.05742603354156017, 0.06789339293858834, 0.067946976849011, 0.03188848601920264, 0.08263139067483799, 0.21239638860736573, 0.058189697563648224, 0.05270767065563372, 0.07551321227635656, 0.0341326354204544, 0.0804740157244461, 0.02631753879333181, 0.019244547434417263, 0.03253481098051582, 0.16720823624304362, 0.04055740870535374, 0.024083643752549375, 0.007244469032489828, 0.008514848587635373, 0.043030153161713054, 0.04576330239485417, 0.055994928548378606, 0.07218503193663699, 0.03536834268431578, 0.01574383090649332, 0.0254556568272944, 0.027113209312249507, 0.04060143545003874, 0.06272824866963284, 0.06702752118664128, 0.011818892588572842, 0.02372686325439385, 0.05524065884362374, 0.03996931901201606, 0.07625778232301984, 0.02022185329613941, 0.022236622237999524, 0.0407242502884141, 0.01736034220084548, 0.08297639859041997, 0.04624669752748949, 0.038015175477734635, 0.026959765403132354, 0.02918069703238351, 0.08411166910082102, 0.08174289656536919, 0.07155259658715554, 0.026992245178137506, 0.033963052555918694, 0.014672680259017008, 0.012241724229949926, 0.038072718639991114, 0.06291190774313041, 0.039421795534768274, 0.031192722996430736, 0.02980429107057197, 0.0578443096684558, 0.06084677962852376, 0.021415957881669914, 0.04176351148635149, 0.05063646625993507, 0.029323240276426077, 0.1184478819902454, 0.07906046443219696, 0.12009769917598792, 0.07903527721230473, 0.13544536062649318, 0.10684633095349584, 0.13644569766308579, 0.15175356982009752, 0.2114451096526214, 0.22828586027026176, 0.16455399723989622, 0.13687474892607757, 0.17342341345335754, 0.14528448480580533, 0.09582914106015648, 0.11642782895692758, 0.14712661238653318, 0.17414574112210954, 0.1057650718305792, 0.18429412799222128, 0.11491361020931176, 0.19197015038558415, 0.19864198166344846, 0.16116775465863092, 0.1269157411796706, 0.10687099570142371, 0.23673090711236, 0.1063320217654109, 0.17360147461295128, 0.17507328492190155, 0.15289333223232202, 0.24161801487207413, 0.14163552703601973, 0.09733774153781788, 0.11337566987744399, 0.13257464181099618, 0.1340875034885747, 0.0913097517830985, 0.18230802885123662, 0.15075627262038843, 0.12312123764838491, 0.12730389035173825, 0.20388822443783283, 0.08107034622558526, 0.08957420169774975, 0.13529199814157827, 0.19483025691338948, 0.2012301313557795, 0.1813478882291487, 0.1416882492069687, 0.10896434408745595, 0.10263674040990216, 0.09813021615679775, 0.1421514850642, 0.12881905904838017, 0.20632833135979517, 0.11932811832853726, 0.17237662390938827, 0.23375574818679265, 0.2711753802640097, 0.35403582400509287, 2.389052752937589, 21.92460639136178, 36.72084392820086, 56.081214155469624, 88.0431604385376, 107.39476898738316, 117.11312402997697, 125.51976340157645, 127.37465449741909, 118.5089476449149, 114.46504742758614, 93.93854018620083, 90.72105870928083, 97.8028016771589, 98.60200432368687, 90.57591084071568, 73.48026425497872, 100.65002059936523, 108.10285295758928, 88.65693650926862, 104.73613112313407, 98.35435662950788, 93.38789544786725, 115.2332958493914, 97.83003166743687, 99.7960661479405, 127.3083825792585, 134.06340735299247, 125.6127997807094, 97.66374043055943, 101.5668284552438, 104.94613347734723, 106.62196254730225, 103.60708359309605, 100.29227869851249, 115.66557107652936, 114.77992589133126, 127.16216468811035, 136.2547163282122, 135.14898000444686, 138.38935579572404, 129.81941986083984, 105.29936599731445, 83.03639275687081, 66.87216608864921, 47.77155079160418, 34.54144069126674, 10.292445608547755, 0.2867788629872458, 0.44275691040924614, 0.14449073454099043, 0.23982795806867735, 0.13443859107792377, 0.17459647836429731, 0.14960977914077894, 0.23192424646445683, 0.14110378628330572, 0.21164107056600706, 0.28556887220059124, 0.21347076738519327, 0.19908442720770836, 0.17058905054415974, 0.1289510748216084, 0.2772762786064829, 0.17436208522745542, 0.14955783049975122, 0.21621796568589552, 0.25243405305913513, 0.16377383124615463, 0.17001055872866086, 0.06905040371098689, 0.13356234452554158, 0.14232634353850568, 0.15556342181350502, 0.13593953768057482, 0.13121018931269646, 0.0751597091023411, 0.113955111641969, 0.10621382096516234, 0.07914376139108624, 0.11901074035891465, 0.13699301757982799, 0.16020274215510913, 0.10810445022902318, 0.10675697467689003, 0.16663473844528198, 0.16387171670794487, 0.1991601652864899, 0.09027381201407739, 0.1688217653759888, 0.173816176663552, 0.05686018283345869, 0.13529255454029354, 0.13822450435587338, 0.08372330958289759, 0.12641424951808794, 0.1266512753708022, 0.15105383736746653, 0.20207327896995203, 0.1617530725364174, 0.11384297694478716, 0.12034958494561059, 0.11225565283426217, 0.09244728181511164, 0.20246296163116181, 0.17080320976674557, 0.13749170010643347, 0.1315155029296875, 0.07215189907167639, 0.11467928492597171, 0.10587774257042579, 0.09052337040858609, 0.11293255936886583, 0.2095123433641025, 0.1260947816606079], [0.025435351666861346, 0.044476531978164396, 0.01346872843402837, 0.011002650584227272, 0.005890391758709613, 0.015872440433927944, 0.007477437245792576, 0.03545411290334804, 0.01685238240419754, 0.034861375245132616, 0.09648641757667065, 0.037167664883392196, 0.03042007177802069, 0.03795954917690583, 0.02400951210542449, 0.008672690251842141, 0.06320006120949984, 0.06566817805703197, 0.04263310839555093, 0.025219976170254604, 0.02079808389368866, 0.058476595740233145, 0.05439245275088719, 0.03781751822680235, 0.08953143363552434, 0.0258953118962901, 0.012444199927683388, 0.010114962235093117, 0.012184234502326165, 0.007162619049527815, 0.01207817014905491, 0.040268539384539635, 0.036159141321799586, 0.029171167008046592, 0.026892853368605887, 0.011882938660814293, 0.038022693645741255, 0.06648240650870971, 0.053485563557062826, 0.07001623724188123, 0.03778279758989811, 0.07805895353002207, 0.04885053155677659, 0.040869131085595915, 0.005453690861551357, 0.08931655516581875, 0.0465333039340164, 0.037643114370959144, 0.012204517610371113, 0.03646997482116733, 0.03894379136285611, 0.03021945950708219, 0.012284641569879438, 0.11257909690695149, 0.007190320241664137, 0.02148593689448067, 0.14727058394679002, 0.21913012942033155, 1.0438356910433089, 19.395951952253068, 52.63897235052926, 71.12695108141217, 88.8387222290039, 85.07204123905727, 86.94196823665074, 88.00878075190953, 81.39745167323521, 69.70031915392194, 72.44812325068882, 60.587680271693635, 68.08275767735073, 41.009560448782786, 51.619285992213655, 54.418604033333914, 32.30362047467913, 37.64905725206648, 23.35466378075736, 29.712529523032053, 23.640966040747507, 28.94802791731698, 29.008548464093888, 26.936187437602452, 35.384545530591694, 24.118698120117188, 25.01223819596427, 35.18773085730416, 20.491795778274536, 46.684626715523855, 32.57584394727434, 36.03951052256993, 29.763869762420654, 46.19327790396554, 62.8371456691197, 47.289092200142996, 43.85465669631958, 32.95675114222935, 46.40690721784319, 53.965098585401265, 67.200656073434, 83.75826890127999, 85.48902348109654, 70.06300122397286, 88.13573128836495, 94.97811576298305, 96.91002069200788, 98.21234934670585, 100.91694954463414, 99.07504463195801, 84.7344560623169, 45.24993140356881, 5.6177670785358975, 0.2544856444001198, 0.6021507031151226, 0.3644435741007328, 0.128967033965247, 0.09869465551206044, 0.029053420826260532, 0.02830836732339646, 0.09091429478888001, 0.08305316125707966, 0.13887350953051023, 0.05318412098235317, 0.04232158279046416, 0.05096149131921785, 0.04538103612139821, 0.026555925108758465, 0.015517844818532467, 0.08429667167365551, 0.048761243133672645, 0.054027540010533164, 0.05063459011060851, 0.08536538468407733, 0.03296662727370858, 0.053409703341977935, 0.0195728820482535, 0.03971696166055543, 0.05885498757873263, 0.0194874375260302, 0.057483654735343795, 0.00454140010489417, 0.05142150413511055, 0.04831578489392996, 0.0779492004907557, 0.052117962656276565, 0.02699653012678027, 0.024476898900632347, 0.05201502210859742, 0.06145847216248512, 0.10650166230542318, 0.05030726481761251, 0.032725062021719556, 0.057364246142762046, 0.07213963115853922, 0.033335207495838404, 0.038860287450786145, 0.04024934362886207, 0.06505759832050119, 0.01803469065842884, 0.07935727600540433, 0.0208696048773293, 0.043181157737438164, 0.0025389482699600713, 0.012310197743188058, 0.02514770201274327, 0.05761170107871294, 0.01718282726194177, 0.045105065751288614, 0.08574075025639363, 0.03245925949886441, 0.014212153452847685, 0.045984253752976656, 0.04254754852237446, 0.029010038689843247, 0.033234187202262025, 0.061344620771706104, 0.04192339808547071, 0.03234003750341279, 0.04738569658781801, 0.10708045946168047, 0.03240167562450681, 0.036612796264567544, 0.10883101195629154, 0.035016332287341356, 0.08286302895950419, 0.07115407261465277, 0.02700318825165076, 0.06202322364385639, 0.037658517115882466, 0.07235222975058214, 0.03497342512543712, 0.0022977837777164367, 0.02039187042308705, 0.06554756845746722, 0.022454362429146255, 0.016138948633202484, 0.03722059400752187, 0.053136308012264113, 0.06393708594675575, 0.05984803714922496, 0.039109923876821995, 0.13667739023055347, 0.016233570341553007, 0.036867294394012005, 0.05352910175653441, 0.04651757888495922, 0.02808738882387323, 0.03939325974455901, 0.05165112377809627, 0.03967168301876102, 0.01837622786739043, 0.04114921337791851, 0.041854903368013244, 0.02647586476190814, 0.10708896829081432, 0.049576767587236, 0.05091025513995971, 0.027957435797101686, 0.06190979973013912, 0.005544643815872925, 0.01807769451157323, 0.041762975443686755, 0.1308277669761862, 0.014554981574682253, 0.0803858604548233, 0.031473317582692416, 0.06691765279642173, 0.04085264607731785, 0.039752829021641185, 0.02237511802065585, 0.05680941484336342, 0.10345654641943318, 0.04528833805982556, 0.09174563589372806, 0.2552273917411055, 0.9759743724550519, 24.371621234076365, 60.16733510153634, 84.6778838293893, 100.27522781917027, 100.7259088243757, 98.3421972819737, 99.12173652648926, 91.3763016292027, 88.60056577410016, 95.97484179905483, 83.83508818490165, 98.28816808973039, 83.92641530718122, 82.23984432220459, 78.9561048235212, 59.223839214869905, 50.00634159360613, 33.38198437009539, 33.82032537460327, 35.00443390437535, 44.97021082469395, 32.33303219931466, 38.30180924279349, 47.02960130146572, 37.241757324763704, 45.84090348652431, 44.762807096753804, 39.92559283120291, 62.235619272504536, 57.706727845328196, 55.5808014188494, 46.43809073311942, 54.5329053742545, 77.09238256726945, 69.41153117588588, 65.06252861022949, 65.08610384804862, 75.98121970040458, 84.04833534785679, 104.57359886169434, 113.34314959389823, 121.73538534981864, 94.27522904532296, 115.76124082292829, 117.82919148036412, 118.74749319893974, 118.32375035967145, 116.40872955322266, 120.84957340785435, 102.50854560307094, 59.13923794882638, 8.214482596942357, 0.046180849096604755, 0.537938437291554, 0.38213110928024563, 0.11023624440921204, 0.036406731964754205, 0.04073196183890104, 0.008718554130090135, 0.049824188596435955, 0.09672403375485114, 0.09133667605263845, 0.027283197601458857, 0.10300603309380156, 0.12069016881287098, 0.06196830980479717, 0.06243178993463516, 0.006723780767060816, 0.06963861893330302, 0.015164847153105905, 0.02461863129532763, 0.0457597706200821, 0.01766287552059761, 0.06037365073072059, 0.037729675083288124, 0.06622456998697349, 0.08669438372765269, 0.023222564154171517, 0.04657344267304454, 0.07353718259504863, 0.015749418642371893, 0.08472190278449229, 0.03709222536001887, 0.03529470467141696, 0.05404120909848383, 0.07097311411052942, 0.05294212486062731, 0.025624478036271672, 0.03318176358672125, 0.042965671978890896, 0.036964423289256435, 0.0061002304095641845, 0.06805560352014643, 0.051778369450143406, 0.0962565570537533, 0.03020605844046388, 0.03243482206016779, 0.061737648610557826, 0.01606816386005708, 0.06894065745707069, 0.05356343902115311, 0.013014238893187471, 0.02788547206936138, 0.025354064867964814, 0.041070184404296536, 0.021770305831783583, 0.07120336139840738, 0.024411233674202646, 0.054836550527917485, 0.03479397636173027, 0.0750063466174262, 0.029432643870157853, 0.02630385783101831, 0.04651767387986183, 0.040525341140372415, 0.05607358093506523, 0.03208744605737073, 0.08547857111053807, 0.1193932576903275, 0.1446668008076293, 0.11575274089617388, 0.08113134652376175, 0.15964565133409842, 0.07363540732434817, 0.11522702553442546, 0.09504424567733492, 0.10623583942651749, 0.20994386449456215, 0.12448262316840035, 0.23706667338098797, 0.15155045714761528, 0.08244085125625134, 0.1052522554195353, 0.15034855449838297, 0.13658432236739568, 0.24239043199590274, 0.09714146171297346, 0.09747074797217335, 0.18717887891190393, 0.16329526049750193, 0.13875108824244567, 0.3276822024158069, 0.16157429212970392, 0.11877975346786634, 0.12539622985890933, 0.15502995758184365, 0.04121334172253098, 0.09790099345679794, 0.08423037201698337, 0.1311530295227255, 0.12375044317117759, 0.10432070147778306, 0.12156317196786404, 0.0673566378120865, 0.2171588223427534, 0.19183048073734554, 0.20140243853841508, 0.12558366837246077, 0.1858520715364388, 0.1543832594262702, 0.11907108926347323, 0.1080431378047381, 0.24789679795503616, 0.10843871693525996, 0.2528730923576014, 0.0878306245431304, 0.1591881423124245, 0.09316429655466761, 0.19441166866038526, 0.08738624517406736, 0.28484929938401493, 0.10878142461712871, 0.23546039100204194, 0.2658708920436246, 0.3600333678935255, 3.117791546242578, 35.99392339161464, 79.93203490121024, 103.86859294346401, 116.45859677450997, 113.68070697784424, 114.73827838897705, 112.86679499489921, 102.95533561706543, 88.92214924948556, 93.63601561955043, 79.1537115914481, 91.87523787362235, 63.182874134608674, 76.3429707118443, 77.23113114493233, 47.877347537449424, 51.67146348953247, 30.904548576899938, 43.11357225690569, 32.19645840781075, 37.939693450927734, 43.55423048564366, 40.67130824497768, 44.935605321611675, 35.728703703199116, 36.55758558000837, 47.425186565944124, 30.260738917759486, 63.13547352382115, 47.6421023777553, 53.42295496804373, 43.58587953022548, 61.94238444737026, 84.22784900665283, 67.00331333705357, 60.166800090244834, 51.734365531376426, 68.23929364340646, 80.03075490679059, 95.05455984388078, 112.2438542502267, 111.169447353908, 92.60751547132219, 113.77355575561523, 121.06698254176548, 126.90409469604492, 129.12308529445102, 134.81571660723006, 133.76220294407435, 119.98474502563477, 74.99398490360805, 11.921365652765546, 0.4180914025221552, 0.7055725763951028, 0.8074406044823783, 0.2967833732920033, 0.2379526501255376, 0.12262026167341641, 0.14088422592197145, 0.20979948581329413, 0.18919722203697475, 0.1831909114761012, 0.16502192855945655, 0.11707692912646703, 0.21022323093244008, 0.12425569391676358, 0.15973429514893464, 0.10473216511309147, 0.23578535499317305, 0.11925883990313325, 0.1101750676919307, 0.1133874628160681, 0.22322382618274006, 0.0874076122418046, 0.09110961787934814, 0.12523647557411874, 0.12850691936910152, 0.1369815096259117, 0.13195522076317243, 0.1384960947824376, 0.12795847308422836, 0.15962229615875653, 0.13759265254650796, 0.10777021744953734, 0.1491784072880234, 0.19157877138682775, 0.1870989610574075, 0.09481021216405289, 0.10789992620370217, 0.306870773434639, 0.13539764604398183, 0.10740892469350781, 0.23305123884763035, 0.12549969287855284, 0.1844984891691378, 0.10977390421820538, 0.14263118218098367, 0.13241450754659517, 0.09007892997137137, 0.13625880197754928, 0.10929006803780794, 0.118938272818923, 0.0997117387929133, 0.11954606377652713, 0.11301865189203195, 0.10006288745041404, 0.1466153905327831, 0.16200305840798787, 0.13801267929375172, 0.10652220834578786, 0.13969664036163262, 0.15102270618081093, 0.16269429560218537, 0.14038030510502203, 0.17098436504602432, 0.2589836801801409, 0.15501094503062113], [0.04061416815966368, 0.05833294987678528, 0.028388938267848322, 0.07174241675862245, 0.02171544118651322, 0.025597541892368878, 0.05091756974746074, 0.03626168153381773, 0.016533671113263284, 0.026315703356106366, 0.02856972035286682, 0.1012016184894102, 0.011817179287650754, 0.048736754804849625, 0.09544579591602087, 0.05032221294407334, 0.05408885922016842, 0.0679861893877387, 0.005817185039632022, 0.02109889543083097, 0.03469991444477013, 0.04207074196477022, 0.057742732976164134, 0.04969058844393917, 0.06330019262220178, 0.05197862209752202, 0.039887725176023583, 0.052978453625525744, 0.05786909655268703, 0.06993773074022361, 0.03406227133902056, 0.04283866040142519, 0.04068533291241952, 0.09512427209743432, 0.024246929812112024, 0.06035509279796055, 0.02153789232085858, 0.013458470680883952, 0.06638875510543585, 0.05115151505119034, 0.027755836257711053, 0.04191608347796968, 0.09525211488029786, 0.00922790153085121, 0.03014537026839597, 0.032307019989405356, 0.08614732165421758, 0.010537944002343076, 0.024517695818628584, 0.0647059204056859, 0.03236496348732284, 0.0602741435702358, 0.017810862311827283, 0.0884433009528688, 0.021857373749039004, 0.5563979553324836, 6.526570175375257, 25.63173610823495, 61.871436391557964, 78.76608548845563, 79.49130371638707, 76.2469049181257, 76.13241250174386, 65.55990150996617, 78.42648533412388, 62.217018944876536, 53.844557762145996, 38.988920075552805, 21.649254492350988, 45.170746258326936, 32.383427483694895, 50.86563573564802, 30.776611396244594, 55.24288272857666, 77.2675952911377, 74.56612873077393, 122.17565100533622, 91.23003510066441, 108.93212045942033, 111.89898041316441, 88.79886041368756, 80.90127386365617, 108.1780116217477, 109.06002984728131, 72.26810932159424, 101.3546165738787, 135.02892902919223, 68.21685096195766, 68.27989891597203, 75.63506044660295, 63.66977609906878, 84.02781731741769, 84.99499266488212, 62.4389374596732, 47.19280406406948, 61.29983588627407, 54.09405367715018, 41.216839109148296, 46.1382030078343, 51.925249917166575, 37.37243904386248, 44.23492465700422, 36.9627628326416, 42.98362704685756, 48.93259130205427, 64.77417142050606, 84.26720360347203, 83.93438489096505, 91.34268624441964, 92.12435858590263, 89.86318547385079, 62.821637289864675, 22.14964117322649, 8.077981761523656, 3.3777080220835547, 0.033300150984099934, 0.059497153120381494, 0.035347562549369674, 0.10729166027158499, 0.04043521133384534, 0.0948909374752215, 0.02376292230162237, 0.04492005978577903, 0.023174064167376076, 0.05572456627019814, 0.051317956298589706, 0.0461216876283288, 0.015639857289248278, 0.05667583843959229, 0.035468531772494316, 0.052324349260223765, 0.03379611597795572, 0.025009333455402936, 0.05060899916238018, 0.02305551222525537, 0.04215507708223803, 0.07897105387278966, 0.04171619723950114, 0.01801610897694315, 0.05044448834710887, 0.017394728659253036, 0.09164047653653792, 0.014093920422185744, 0.03787129891238042, 0.011603011583377208, 0.017110644706657956, 0.08461587490247828, 0.05896302392440183, 0.044068277813494205, 0.08384443486907653, 0.02803825949584799, 0.054812459142080376, 0.031078796966799667, 0.04801567564053195, 0.07233045556183372, 0.04765009793585964, 0.054536610908274136, 0.025431889441928694, 0.05082569610593574, 0.01779961389755564, 0.013809375065777982, 0.06335288086639983, 0.038433105551770756, 0.048715991633278985, 0.03478478221222758, 0.04737835144624114, 0.045162802296025414, 0.0728614159992763, 0.10120384408427135, 0.03676168381103447, 0.01861223252490163, 0.062414507647710185, 0.0337339214581464, 0.013231574507829334, 0.05725458809839828, 0.024330130079761147, 0.05349965672940016, 0.024373371420162063, 0.024693991090836268, 0.027485060073169212, 0.04301671477566872, 0.014500405306794813, 0.011435951172773327, 0.02026181391972516, 0.045587147918662856, 0.0407147100860519, 0.023472846884812628, 0.05559465395552771, 0.013181374790812177, 0.041937559111309905, 0.06063780441348042, 0.011452048567921987, 0.02694690546819142, 0.03262673890484231, 0.0653005274278777, 0.04302872145282371, 0.02143985588502671, 0.021567152447200248, 0.01053137069434992, 0.026242148463747332, 0.05568399666143315, 0.018804737998704826, 0.008123057378855134, 0.024362508074513504, 0.04310160629185183, 0.008060718670354357, 0.01822574745996722, 0.05901534575968981, 0.02277777936043484, 0.028932865509497266, 0.013787096216609436, 0.05437953005145703, 0.03351650187479598, 0.021342292727370347, 0.048573302504207404, 0.028567735637937273, 0.02598268515430391, 0.06697269555713449, 0.11529711820185184, 0.010909866857608514, 0.06353119308395044, 0.06354525232953684, 0.062053133467478414, 0.014752330092181052, 0.022284374139936905, 0.01527312268236918, 0.08418581940765892, 0.037681000373725376, 0.019639936575133885, 0.06194327186260905, 0.05690219432913831, 0.5007394105195999, 6.343071290424891, 28.400612354278564, 73.96340029580253, 92.73983696528843, 93.49401528494698, 88.1509131022862, 91.03173351287842, 87.75733934129987, 101.01523876190186, 103.14781461443219, 90.26458985464913, 65.6743244443621, 48.47619192940848, 56.62564025606428, 38.5371447290693, 33.37486246653965, 26.190074239458355, 39.25909382956368, 35.174032483782085, 42.43868677956717, 45.460923876081196, 58.85299301147461, 45.53130565370832, 56.0200491632734, 53.34641361236572, 44.822936807359966, 45.628455366407124, 50.88589668273926, 35.35734333310808, 51.87902702604021, 49.44940178734915, 41.85711908340454, 29.69432176862444, 39.58701753616333, 25.377605744770594, 55.358702250889365, 55.58696099690029, 32.43181126458304, 28.827869244984218, 31.553086485181534, 31.06908539363316, 37.90556737354824, 45.92342724118914, 61.18166092463902, 49.68720735822405, 66.16766044071743, 71.40166200910295, 78.26584298270089, 84.50698593684605, 96.70766830444336, 111.63383715493339, 97.17722061702183, 108.85056250435966, 107.87661266326904, 108.00779465266636, 81.01065935407365, 27.737971339906963, 10.191182562283107, 3.6391057670116425, 0.06917631266904728, 0.1004249198096139, 0.13357667518513544, 0.12686715807233537, 0.10200574355466024, 0.06684654911181756, 0.03071256447583437, 0.09013988277209656, 0.04150214318984321, 0.0491774972262127, 0.033020363854510446, 0.05259922718895333, 0.056491575469928126, 0.04603842459619045, 0.030755726088370596, 0.04340350687769907, 0.04964331151651485, 0.016475822610248412, 0.021199639221387248, 0.008792099692592663, 0.04660002767507519, 0.04335157520004681, 0.07028524923537459, 0.040234174978520186, 0.07434163335710764, 0.03829574292259557, 0.06300673979733672, 0.019101340922393968, 0.018328097682180147, 0.06524988835943596, 0.030309060056294714, 0.039725216039057286, 0.034376324487051794, 0.025890361983329058, 0.04760643420740962, 0.0661207948412214, 0.0410198981740645, 0.05347677313589624, 0.06041204224207571, 0.03796663308250053, 0.019838669304070727, 0.058188693331820626, 0.03639997714864356, 0.05066769244149327, 0.03365663292684725, 0.02527877631863313, 0.025688175511147295, 0.025660920455785732, 0.031778604058282714, 0.056918781117669175, 0.07422225190592663, 0.038733279265995534, 0.01743542549333402, 0.027071681272770678, 0.051765623169818094, 0.017688234070582048, 0.07680761960468122, 0.03396681842527219, 0.029683695041707585, 0.017853508237749338, 0.04646760138816067, 0.146287115290761, 0.19163477766726697, 0.07877686393580266, 0.14238332690937178, 0.062099735252559185, 0.11597361761544432, 0.13438907159226282, 0.08315289233412061, 0.09707857508744512, 0.10140386263706855, 0.08696530918989863, 0.0999369445656027, 0.1315543015620538, 0.17971720573093208, 0.15339365681367262, 0.16389185562729836, 0.1180783382483891, 0.19071803614497185, 0.12120402338249342, 0.11314620290483747, 0.1185643050287451, 0.08093330250786883, 0.13396889556731495, 0.1212557413216148, 0.117873664945364, 0.10892604078565325, 0.12494565546512604, 0.22688630037009716, 0.18381521797605924, 0.11269313150218555, 0.10632992509220328, 0.12768255360424519, 0.1653864240007741, 0.15200933681002685, 0.12439373508095741, 0.1296517165111644, 0.1971159835479089, 0.15047693332391127, 0.10755248913275343, 0.13211243732699327, 0.1513574139348098, 0.1360340711793729, 0.246859182204519, 0.10327664642993893, 0.187062265883599, 0.2415637049291815, 0.25098307377525736, 0.11705191832567964, 0.1253477010343756, 0.18453020389590943, 0.13992187327572278, 0.1531983744353056, 0.12362278359276907, 0.2727896422147751, 0.16347451587872847, 1.5475332971130098, 12.006907531193324, 42.845753942217144, 95.72244153703961, 107.88875811440604, 100.3330785206386, 93.56515094212124, 96.41141101292202, 84.99407550266811, 99.28907694135393, 80.2904577255249, 72.67944962637765, 56.12979596001761, 36.80111299242292, 64.97801072256905, 42.25173854827881, 68.21371037619454, 40.221113613673616, 79.29594121660504, 111.91582979474748, 110.17386777060372, 179.79057230268205, 136.4709164755685, 162.34115818568637, 173.0274876185826, 135.67190143040247, 121.99130140032086, 155.62722505841936, 161.29692731584822, 109.92054339817592, 144.607145854405, 192.47926139831543, 95.39731448037284, 99.72945376804897, 110.71349961417062, 92.89865888868059, 115.51108482905796, 126.62217848641532, 91.01528017861503, 71.25684070587158, 86.71977179391044, 76.1958703994751, 57.49520036152431, 61.18432903289795, 67.79884038652692, 51.14441135951451, 62.032891682216096, 50.52206468582153, 61.15916265760149, 66.12021119253976, 84.76536859784807, 107.33207539149693, 105.23150988987514, 118.71451704842704, 121.8267958504813, 123.24550683157784, 99.8612402507237, 39.43239579881941, 14.29073177065168, 6.163044767720359, 0.19858180917799473, 0.21548965333827905, 0.19106327476246016, 0.18879972265235015, 0.23246406178389276, 0.26216074398585726, 0.1273457288209881, 0.14565322787633964, 0.1105635357754571, 0.09212258245263781, 0.12778221682778426, 0.1606593555105584, 0.1198034185384001, 0.11587921982364995, 0.20565298545573438, 0.18762101233005524, 0.17023784081850732, 0.1673781278410128, 0.12938765782330716, 0.06468812243214675, 0.07587208944771971, 0.1414091270416975, 0.1285989015762295, 0.11356812955013343, 0.17763351968356542, 0.09568096258278404, 0.3906411869185311, 0.051116621387856345, 0.09597638315920319, 0.176423827452319, 0.09846789589417831, 0.22508504773889268, 0.15616378959800514, 0.1630951605205025, 0.1553348640778235, 0.21131350100040436, 0.11104598774441651, 0.14088638366333076, 0.14316689914890698, 0.10704894151006426, 0.16477918944188527, 0.1623617863016469, 0.09788249659218959, 0.12377472115414483, 0.1350268673683916, 0.07669720838644675, 0.08705224988183805, 0.08706024302435772, 0.13559990376234055, 0.18328908192259924, 0.20953360865158693, 0.16771227919629642, 0.09904764299946171, 0.17775994432824, 0.18204169028571673, 0.0836887653650982, 0.16469259480280535, 0.16587718123836176, 0.09564289676823787, 0.2521290379975523, 0.10971250358436789], [0.06762192464832749, 0.03274413564109376, 0.07376092951744795, 0.023189555121851817, 0.02886515110731125, 0.05913598250065531, 0.08467685484460422, 0.058058014272579124, 0.04355208229805742, 0.04361475179237979, 0.025679429194756916, 0.06381716845291001, 0.024941184790804982, 0.06116159273577588, 0.039690044176365645, 0.04324746417946049, 0.07863230205007962, 0.03137833625078201, 0.06617224136633532, 0.03282220448766436, 0.0557839279063046, 0.04419337592220732, 0.06109132364924465, 0.05955695919692516, 0.011504287282670183, 0.023305028211325407, 0.05203190066718629, 0.08518539648503065, 0.04614625059600387, 0.07307172114295618, 0.028566795866936445, 0.08466742320784501, 0.034999005895640166, 0.05305783883003252, 0.09429838641413621, 0.0013539863076792763, 0.03829541722578662, 0.036487735475280454, 0.0461970932249512, 0.06757500395178795, 0.06014882493764162, 0.0655269884903516, 0.06022767749215875, 0.049162104659314664, 0.034280243928411176, 0.07751606444695167, 0.06770777289888688, 0.038872317876666784, 0.03560190122308476, 0.09967110811599664, 0.04762109395648752, 0.0802554731656398, 0.9874676700149263, 6.82657037462507, 19.714073487690516, 53.008467129298616, 74.22454139164516, 75.93082441602434, 74.02072293417794, 59.61391108376639, 74.29400253295898, 69.84060328347343, 49.79010670525687, 50.346480233328684, 33.22362797600882, 23.656905208315166, 14.773530823843819, 40.704430307660786, 68.17856638772147, 59.14073181152344, 83.90347235543388, 115.33227293831962, 92.2915391921997, 73.98269544328961, 75.78849751608712, 50.610063620976035, 40.372250829424175, 31.330546106610978, 39.771398408072336, 31.5029239654541, 32.533373083387104, 42.08846630368914, 42.61595617021833, 41.40498243059431, 46.338832242148264, 47.37557642800467, 62.617436681474956, 60.36163452693394, 62.23257596152169, 56.966626576014924, 66.51305539267403, 61.755929538181846, 66.82341752733502, 74.76166493552071, 80.25775255475725, 100.04933493477958, 90.86853422437395, 92.72351564679826, 106.79202665601457, 76.33154787336076, 72.39978463309151, 45.93914754050118, 51.239431449345176, 40.20173856190273, 43.10362243652344, 26.785555703299387, 39.91978413718087, 62.87270654950823, 48.26232985087803, 85.72109331403459, 73.50455515725272, 83.99320139203752, 85.30164446149553, 83.11853436061314, 83.96392168317522, 40.84722621100289, 8.644589986119952, 0.42022390237876345, 0.2077977532254798, 0.21242613558258328, 0.40177225534405026, 0.07048040269208805, 0.06913998390414886, 0.09190081685249295, 0.04079136418710862, 0.021985279296391776, 0.04424321431932705, 0.023955677137044922, 0.0399497704181288, 0.06634963756161076, 0.08330475525664431, 0.06442121389721121, 0.03741715203172394, 0.05443311735455479, 0.02793213152991874, 0.08537776116281748, 0.046335202242646895, 0.010062229037950081, 0.035667261108756065, 0.023350401848022426, 0.05237105282555733, 0.031020789008055414, 0.08180594603930201, 0.028322879491107802, 0.026111727247812917, 0.10846358524369341, 0.08134119704897914, 0.027540241933560798, 0.0379534898591893, 0.05376147625169583, 0.06435172512595143, 0.11218745327953782, 0.0171042715664953, 0.048496268423540254, 0.017602523223363926, 0.03399947631571974, 0.039579934906214476, 0.03362632955291441, 0.014903358416631818, 0.09292790173952069, 0.10783761633293969, 0.019621984234877994, 0.07459560222923756, 0.01930905575864017, 0.03237656304346664, 0.06412138284317084, 0.014104723547851401, 0.10842966527811118, 0.03749343633119549, 0.04069514113611408, 0.01171729723656816, 0.025740616090063537, 0.05843919489000525, 0.08750478524182524, 0.01462773240304419, 0.0990310392475554, 0.027903597436047027, 0.013319935882464051, 0.015443365422210522, 0.0536377419983702, 0.0032612818758934736, 0.03076330871720399, 0.031556434729801755, 0.01899874473123678, 0.05296726119039314, 0.04848840759534921, 0.02472211976003434, 0.05355212784239224, 0.009167199788082923, 0.019861734405692135, 0.08386698937309639, 0.023185183659994175, 0.038268377605293474, 0.06964978083435978, 0.007548645255155861, 0.01997046116074281, 0.05223247901137386, 0.021914838879768337, 0.06595952063798904, 0.01826453591430826, 0.004951618628443352, 0.02520656492561102, 0.028491390270314047, 0.02174496933418725, 0.025302850741094778, 0.045124729696129046, 0.05766877944448164, 0.04476248020572322, 0.08901717873024088, 0.019938413951812044, 0.023073311895132065, 0.039692103530147245, 0.07206068360911948, 0.016588486564744796, 0.01330606238583901, 0.05200016558436411, 0.04223939184365528, 0.032354463157909255, 0.03255279894386019, 0.02042437225048031, 0.08606838767549821, 0.07558523876858608, 0.13955455512872764, 0.06675050247992788, 0.07229856441595725, 0.06416738073208503, 0.05199415376409888, 0.1916682023022856, 0.30844996869564056, 5.808643213340214, 21.93808937072754, 62.20353249141148, 90.32591465541294, 91.81582382747105, 89.87681783948625, 84.34571129935128, 104.20881148747036, 95.12516048976353, 76.94004331316266, 72.26297460283551, 57.52878795351301, 35.90109198434012, 18.74227932521275, 25.391132150377544, 33.067804200308665, 44.13366508483887, 62.07769366673061, 93.85475880759103, 75.29174995422363, 73.31797518048967, 76.89576939174107, 59.727076394217356, 49.866700172424316, 37.75727891921997, 46.79566240310669, 39.81456756591797, 37.470339162009104, 42.642359324863975, 45.76839903422764, 47.56243085861206, 49.285076890672954, 52.66419431141445, 62.73955127171108, 60.17530468532017, 63.25560787745884, 57.09139885221209, 61.38285296303885, 66.57843794141496, 72.91377762385777, 73.18331214359829, 78.27903066362653, 80.55535779680524, 85.64344024658203, 70.04122556958879, 78.46418625967843, 60.51035376957485, 51.03286845343453, 32.82400580814907, 24.34704371861049, 29.430300644465856, 41.06354447773525, 46.87949936730521, 66.02038642338344, 103.53201525551933, 79.81552055903843, 108.51122638157436, 94.77122620173863, 96.53344917297363, 106.50598321642194, 101.55469690050397, 103.1452785219465, 48.68673276901245, 11.01837168421064, 0.8747490527374404, 0.08811036417526857, 0.4313486468579088, 0.3662164775388581, 0.02611741846028183, 0.03380245688770499, 0.17484533786773682, 0.03199120604300073, 0.03755625171054687, 0.028680179068552594, 0.08310874006045715, 0.062003328997109614, 0.047058910730161836, 0.03023974091878959, 0.03601079660334757, 0.028469924814999104, 0.1120993522927165, 0.027448456501588225, 0.023371142967204963, 0.0532363172886627, 0.04764609118657453, 0.02299775362813047, 0.027674951490813067, 0.05613007236804281, 0.01699726829039199, 0.10044724361172744, 0.006480240554083139, 0.060538419389298985, 0.0686487245506474, 0.056127673746751885, 0.002035712985421664, 0.018043494650295804, 0.05725743116012641, 0.09120312679026808, 0.03543610119127801, 0.05068840811561261, 0.0899997992174966, 0.04410032841510006, 0.023505435225420764, 0.06191523479563849, 0.04251737067742007, 0.014957495333094682, 0.025628700220425214, 0.0721925093925425, 0.04086719386811767, 0.08669669074671608, 0.026352057566068003, 0.03456091315352491, 0.09168028618608202, 0.04813273650194917, 0.06364554659064327, 0.04939205339178443, 0.04530740489384957, 0.03800979469503675, 0.017402565738718425, 0.021794733092454926, 0.034074752990688593, 0.01684618229046464, 0.026786396313192587, 0.15700564799564226, 0.1165597497352532, 0.16185260005295277, 0.1520746797323227, 0.133818369358778, 0.14627437240311078, 0.15089005258466515, 0.10375065063791615, 0.30604925751686096, 0.12109974612082754, 0.11453677900135517, 0.12946662572877748, 0.15038128702768258, 0.1566144318452903, 0.17173648040209497, 0.1518208940646478, 0.19759188086858817, 0.16000652339841637, 0.14639272248106344, 0.1380368351404156, 0.16283956994967802, 0.1650888728243964, 0.2180173455604485, 0.21026316950363771, 0.1243440391761916, 0.12325994377689702, 0.15525733466659272, 0.17422176418559893, 0.1233173885515758, 0.14749443264944212, 0.11916759051382542, 0.199081794491836, 0.18569341647837842, 0.18565521495682852, 0.10822399452860866, 0.17061619194490568, 0.17743141124291079, 0.24067202849047525, 0.0836837917034115, 0.3954212489937033, 0.11704985557922296, 0.15148755695138658, 0.1544125857097762, 0.15678027937454836, 0.1175079345703125, 0.1294625002358641, 0.26122648268938065, 0.10907536598720721, 0.20742009420480045, 0.1888858965997185, 0.3831887553845133, 0.2761845700442791, 1.1994242050818034, 13.79833812373025, 35.36689363207136, 83.77449294498989, 105.56970650809151, 102.61845220838273, 90.53839751652309, 77.3205405644008, 94.50522831508091, 93.8815232685634, 66.96202714102608, 64.58534022739956, 45.89346660886492, 32.11737401144845, 22.564822094781057, 57.66116850716727, 90.57746028900146, 85.43980939047677, 120.05105863298688, 168.26516451154436, 140.00757735116142, 117.19026293073381, 120.28051594325474, 78.79948547908238, 65.52917657579694, 48.85590403420584, 62.585725103105815, 54.53111968721662, 51.43987308229719, 62.562212399074006, 67.06006622314453, 65.65810734885079, 75.18089839390346, 74.81447124481201, 99.98626613616943, 91.52499307904924, 102.48626967838833, 93.73547908238002, 108.4032096862793, 91.1327394757952, 103.96571486336845, 112.91636344364711, 128.42789023263114, 155.81998198372978, 137.4308795928955, 139.42586026872908, 156.5070754459926, 113.44077178410122, 112.13044575282505, 70.35779244559151, 71.39167744772774, 54.3372996875218, 57.26089668273926, 39.93379865373884, 56.69494158881051, 80.74460588182721, 64.16346645355225, 110.47975526537213, 93.47402531760079, 102.70917483738491, 112.4007932118007, 114.61776188441685, 117.1030352456229, 62.847046852111816, 13.89082646369934, 1.447035204086985, 0.23661384625094278, 0.4877279858504023, 0.5663694888353348, 0.14165836652474745, 0.19105350385819161, 0.26518158188888, 0.14869155841214315, 0.2624255897743361, 0.1851185616105795, 0.14093135696436676, 0.1474035768104451, 0.14123927615582943, 0.17486684742782796, 0.20571997043277535, 0.12868310777204378, 0.1641307542366641, 0.14257959994886601, 0.1926881761423179, 0.15001571950103554, 0.10512334055134229, 0.17774190886744431, 0.08538434295249836, 0.18952500873378345, 0.13157175348273345, 0.21357587245958193, 0.10922987519630364, 0.18540482196424687, 0.21152741595038346, 0.2057865211474044, 0.17315702060503618, 0.17970522280250276, 0.20271582449121134, 0.20811572830591882, 0.21810634221349443, 0.15336034074425697, 0.18513963690825871, 0.1339499915816954, 0.16267856716045312, 0.21069342855896267, 0.12185499630868435, 0.1738565494971616, 0.15932714699634484, 0.17452302016317844, 0.15592166116195066, 0.23522640498621122, 0.13172947216246808, 0.13666250317224435, 0.3000794792813914, 0.13396364370627062, 0.1991374207926648, 0.1818002268139805, 0.0991813890369875, 0.12449276048157897, 0.155955221503973, 0.19928106665611267, 0.17176048697105475, 0.08331346764628376, 0.16779002573873314], [0.0679549699915307, 0.014112664952075906, 0.028142638537766676, 0.04108079669198819, 0.0553709070331284, 0.02166077501273581, 0.025485805834510496, 0.03071993336613689, 0.07387152394013745, 0.016279668314382434, 0.013887996918388774, 0.04563121537544897, 0.05325517377683094, 0.02955057325639895, 0.04314410972541996, 0.04953001652445112, 0.011322363562482809, 0.03236660554206797, 0.02555126919677215, 0.02228243013710848, 0.020229637789140855, 0.07298383050199066, 0.0912988002278975, 0.027022972636457, 0.09922064228781632, 0.0679786101515804, 0.05020446676228728, 0.020875299482473304, 0.07426423965288059, 0.049909884176616154, 0.07483327947556973, 0.11922472316239562, 0.05561694383089032, 0.04027919577700751, 0.07030715234577656, 0.03535880248195358, 0.07968604657799006, 0.02678544127515384, 0.04076793437291469, 0.04494373047990458, 0.056046744875077686, 0.015518704861668604, 0.017468656745872328, 0.07573374972811767, 0.04045629341687475, 0.04622698947787285, 0.07534422991531235, 0.07611368862645966, 0.010055993301128703, 0.015170265255229813, 1.605225601366588, 12.516560503414699, 40.563836983272004, 68.14595849173409, 86.46883065359933, 72.64983640398297, 72.93438598087856, 68.20494869777134, 65.1627424785069, 42.432996204921174, 28.81181022099086, 26.778367791857036, 33.251674379621235, 48.939602034432546, 45.543947901044575, 79.96705382210868, 89.88002095903668, 109.06304536546979, 85.6917302267892, 51.558565684727256, 30.09376675742013, 12.325559735298157, 7.801603266171046, 3.362477570772171, 0.8289486989378929, 0.5947051112140928, 0.6482045575976372, 0.6429263151117733, 1.207957570041929, 1.2760896512440272, 0.4954544369663511, 1.1580553906304496, 1.1064426515783583, 0.9939896400485719, 1.1782022352729524, 0.44775594930563656, 0.9839173576661518, 1.306957674877984, 2.038992085627147, 0.9926729564155851, 0.9418518777404512, 0.9709473507744926, 0.5250986005578722, 0.7697585693427494, 2.2139538058212826, 2.201686761208943, 2.5348984811987196, 9.619737522942678, 15.214814390454974, 29.35415186200823, 56.34182024002075, 74.90268557412284, 113.30038343157086, 117.73011016845703, 100.90638828277588, 70.93948868342808, 46.25715964181082, 25.08328526360648, 29.26009409768241, 41.443180152348106, 59.898217473711284, 79.28435856955392, 78.47963210514614, 71.67550441196987, 69.74528789520264, 90.25068650926862, 84.6333875656128, 55.50690732683454, 33.24465322494507, 13.752785733767919, 3.7399916563715254, 0.10437186980353934, 0.3288444514785494, 0.03710841181288872, 0.11359007337263652, 0.04870776100350278, 0.03771059467856373, 0.02078949024767748, 0.12131500457014356, 0.06610074413142034, 0.06272315287164279, 0.07861064999763455, 0.043257618456014564, 0.08648083518658366, 0.020639033588979925, 0.06433763873896428, 0.05922434811613389, 0.059710158833435605, 0.022236481441983154, 0.05302677549687879, 0.06996948617909636, 0.08061749873948948, 0.023202177569536225, 0.0354039250606937, 0.02394808772286134, 0.035914756756808074, 0.019008386713851775, 0.039391264851604185, 0.031092432127999406, 0.05448743747547269, 0.08318632375448942, 0.06885634948100362, 0.02242689363525382, 0.014819160702505281, 0.053782863675483635, 0.029917480889707804, 0.045854884266321144, 0.05355629404740674, 0.05238951237073966, 0.02754630464395242, 0.03847020445391536, 0.03313463593700102, 0.03752480161243251, 0.029010720617536987, 0.11496041555489812, 0.06631248776933976, 0.04506725099469934, 0.02093035581388644, 0.0243424268306366, 0.007598267369238394, 0.05694076565227338, 0.04208438391132014, 0.02087314852646419, 0.03755905406017389, 0.035740349508289776, 0.016888741703171815, 0.08202364721468516, 0.05092171220374959, 0.033178496440606456, 0.034794346163315434, 0.026567278695958, 0.002358594934256481, 0.01986002449744514, 0.02357167551027877, 0.07257004627691847, 0.027789081080949733, 0.002903705583386389, 0.03906030261090823, 0.058263332183871946, 0.06102488150021859, 0.06096871915672507, 0.024167273193597794, 0.023693760923509086, 0.060599480755627155, 0.02032568951004318, 0.02927845696519528, 0.07968694902956486, 0.08922253735363483, 0.048374987074307034, 0.04321209214893835, 0.13912882868732723, 0.07061718856649739, 0.052712047206504006, 0.02997558723602976, 0.01944623687969787, 0.054037775711289475, 0.06536585677947317, 0.11932582488017422, 0.031385331946824274, 0.005725506901009274, 0.1106429108019386, 0.0526835826624717, 0.039235693735203574, 0.03887447901070118, 0.025916361748906117, 0.04569700613085713, 0.04491222270631364, 0.03240307340664523, 0.08041847763316971, 0.10472104392413582, 0.029358659804399525, 0.08180545070873839, 0.08617063611745834, 0.13668790752334253, 0.0471130985367511, 0.021121298960809196, 0.9341746611254556, 11.49003711768559, 44.054538999285015, 79.78418418339321, 100.32228796822685, 86.41799068450928, 83.13303525107247, 84.51949964250836, 100.32440022059849, 64.48399380275181, 54.58110850197928, 50.32543761389596, 37.620430673871724, 47.388048444475444, 24.365916763033184, 29.144844327654155, 44.076860087258474, 92.98982620239258, 86.9177885055542, 52.47945213317871, 38.88066714150565, 15.370874404907227, 10.66888163770948, 3.8834862879344394, 0.39325503951736857, 0.3867672676486628, 0.6078841611742973, 0.5602783071143287, 1.262258067727089, 1.5663800686597824, 0.711556712431567, 1.2095289485795158, 1.1218063128846032, 1.3487828991242816, 0.8209948028836931, 0.5279524102807045, 0.9869404754468373, 0.9336698310715812, 1.171491686786924, 0.9423247895070485, 0.47105263492890764, 0.7074326308710235, 0.156651642705713, 0.3902067887995924, 1.8359301132815224, 1.5874103116137641, 2.435946796621595, 9.266353011131287, 17.665341547557286, 33.98482397624424, 61.315816743033274, 69.12576566423688, 92.87761974334717, 87.5808412006923, 64.17351354871477, 26.60375782421657, 30.544982773917063, 25.807207652500697, 38.01871531350272, 78.95081029619489, 90.52468872070312, 111.81324659075055, 98.04483522687639, 89.21247277941022, 77.88476208278111, 107.77997016906738, 103.08900506155831, 70.8772884096418, 41.30033908571516, 21.431537900652202, 6.219935749258314, 0.008080850804357656, 0.5483332137976373, 0.016018946322479417, 0.0854192196524569, 0.005154791520908475, 0.025345357567338005, 0.03098815825900861, 0.06412007327058486, 0.21800085715949535, 0.098218242504767, 0.027872171086658324, 0.09052826264607054, 0.03741057702739324, 0.05067256432292717, 0.020587972132489085, 0.02778775624132582, 0.04179234243929386, 0.0745672123240573, 0.05915075420801129, 0.07961672744048492, 0.032174291754407544, 0.0335948082086231, 0.01021292996925435, 0.042198452433305125, 0.05759610155863421, 0.050033940734075646, 0.019085410616493652, 0.034478131881249804, 0.050586227527154345, 0.05029718517991049, 0.039093106386384795, 0.01853977346659771, 0.02588582767306694, 0.05171301634982228, 0.005316907531648342, 0.0388179400802723, 0.06126869270311935, 0.011668271385133266, 0.019300599515970265, 0.03919756345983062, 0.03085680745009865, 0.09447678684123925, 0.05231503975976791, 0.10099218865590436, 0.06400981811540467, 0.018825019410412227, 0.03367507890132921, 0.01250360142772219, 0.019259894200201546, 0.07254628398056541, 0.06035237865788596, 0.05573890371514218, 0.018820446084386537, 0.02865971784506525, 0.02715688830773745, 0.09626153750079018, 0.1246647826795067, 0.11067714289362941, 0.1238555618162666, 0.12378063797950745, 0.21098070671515806, 0.14865871731724056, 0.14062430629772799, 0.18839019962719508, 0.09713639984173433, 0.1333260786320482, 0.302692463355405, 0.13286728039383888, 0.17620771404887947, 0.18577005022338458, 0.1077833471021482, 0.12409441971353122, 0.14541039376386575, 0.16670468183500425, 0.14278115199080535, 0.2153503500989505, 0.16368881080831799, 0.17288316387150968, 0.14157121548695223, 0.3562443197837898, 0.17698741863880837, 0.12458995383765016, 0.11563082172402314, 0.17658200753586634, 0.17003231256135873, 0.19947421843452112, 0.27118040142314775, 0.1085121954924294, 0.08124348122094359, 0.15764515368001802, 0.12354557987834726, 0.1571277164454971, 0.13455354848078319, 0.08689520295177187, 0.14413930768413202, 0.15497638045677117, 0.08422088609742266, 0.18137067343507493, 0.1924949022276061, 0.12779531255364418, 0.16719626688531466, 0.17371255079550402, 0.2917120297040258, 0.11735905041652066, 0.15079568193427154, 3.3182939759322574, 20.232718297413417, 62.96843188149588, 98.61690820966447, 116.44108731406075, 94.04260335649762, 89.40053272247314, 85.9048592703683, 86.40631771087646, 57.22275802067348, 35.394380705697195, 36.69617434910366, 50.624779905591694, 65.9077422278268, 61.41924067905971, 115.8427015032087, 129.78527641296387, 151.73382977076938, 131.46674047197615, 78.00859982626778, 47.9357019833156, 17.88560812813895, 13.890614543642316, 5.472500656332288, 0.7888347942914281, 1.0518840934549059, 0.9670400747231075, 0.6988157246794019, 1.4157158732414246, 1.955502531358174, 1.0168247861521584, 1.5806935748883655, 1.367771565914154, 1.5895258209535053, 1.5416160374879837, 0.7598693828497614, 1.3542234471866061, 1.5435988796608788, 2.33289589200701, 1.4315285618816103, 1.4238864119563783, 1.2899669408798218, 0.6221730772938047, 1.2039955769266402, 3.086186145033155, 2.8796027387891496, 5.00132463659559, 16.69494571004595, 24.772608722959244, 47.5988324710301, 86.50764329092843, 115.73239190237862, 176.35681424822127, 166.82152339390345, 141.27141298566545, 102.27972752707345, 68.15321241106305, 36.002806663513184, 42.592325346810476, 52.54539401190621, 76.18612207685197, 104.61770602634975, 98.04630129677909, 92.44612271445138, 86.34044878823417, 114.33446993146623, 117.71272577558244, 83.1856609072004, 50.443456241062705, 28.78968368257795, 7.94588087286268, 0.12298340004469667, 0.5863686299749783, 0.11851512481059347, 0.1551895761596305, 0.10608088916965894, 0.15942719019949436, 0.12626540607639722, 0.2050153525280101, 0.3441743760236672, 0.1616096030920744, 0.1495897759284292, 0.26943328231573105, 0.16545723591532024, 0.0944648581956114, 0.10924605147114821, 0.23664020055106708, 0.16856194074664796, 0.11887674326343195, 0.19556975151811326, 0.15071781325553144, 0.16903216551457131, 0.17008949949273042, 0.08296892113451447, 0.20023359411529132, 0.16937649489513465, 0.13472421360867365, 0.09515262129051344, 0.20571812481752463, 0.17191862634250096, 0.22639330396694796, 0.14073824589805944, 0.10313145350664854, 0.14114034575011047, 0.13847797789743968, 0.19695502147078514, 0.18125279833163532, 0.2046789891485657, 0.14141074195504189, 0.2028972376137972, 0.07246236276945897, 0.10437265690416098, 0.20040157224450791, 0.13742238096892834, 0.24175657172288212, 0.23017691022583417, 0.18216715141066483, 0.07815852854400873, 0.07001519229795251, 0.09683114729289498, 0.16437244841030665, 0.14496356488338538, 0.19247962161898613, 0.11059080609785658, 0.07858747124139752, 0.10190215161336319], [0.0012569743537044684, 0.04029416425951889, 0.04113889964563506, 0.030108332434403043, 0.024396485715572323, 0.01942162641457149, 0.04048743138888052, 0.0223485618563635, 0.04778535710647702, 0.024468286594908153, 0.016410642536357045, 0.03691592499879854, 0.03341979027858802, 0.04972578066268137, 0.06727023316281182, 0.01065107953867742, 0.03729314636439085, 0.012480535477932011, 0.022276991678934013, 0.07239670772105455, 0.017576521761449318, 0.003536244833542566, 0.03839823224448732, 0.024888389677341496, 0.02318211498537234, 0.06887507026216813, 0.04705122632107564, 0.10540360265544482, 0.022116976158161248, 0.06385506463370152, 0.03868611090417419, 0.02235105207988194, 0.01875125247585986, 0.09570154254989964, 0.04350657634703176, 0.029778072477451394, 0.014015979649099921, 0.025069809585277523, 0.02103472128510475, 0.018870603392965028, 0.013104164291040173, 0.041113094958875857, 0.05304277195994343, 0.04225398373923131, 0.06536354976040976, 0.0236647874782128, 0.03899138380906411, 0.05315396688612444, 0.19097929926855223, 8.348400439534869, 50.66085147857666, 55.620638915470664, 68.44159739358085, 54.415783064705984, 60.71488094329834, 69.30105481828961, 59.863525118146626, 46.80790512902396, 27.753920929772512, 44.407417161124094, 55.1214143208095, 42.589229924338206, 49.88609606879098, 58.64081587110247, 78.19818837302071, 64.51896408626011, 36.39517491204398, 9.879157202584402, 2.3218641068254198, 0.6624274115477289, 0.3602835844670023, 0.22639360252235616, 0.2275576429175479, 0.07166113504873854, 0.23523134472114698, 0.15514099305229528, 0.15446492790111474, 0.15133661005113805, 0.45943361840077807, 0.4399012550711632, 0.21507733474884713, 0.39044674592358725, 0.22796480464083807, 0.26159717994076864, 0.4026094861328602, 0.16435703209468297, 0.34324318170547485, 0.5423520633152553, 0.4919420140130179, 0.42586372260536465, 0.4475422650575638, 0.43920714088848656, 0.13526123336383275, 0.24846112195934567, 0.10503025911748409, 0.01039814543245094, 0.03554116216089044, 0.45713083339588984, 0.3573429494031838, 0.4683509798986571, 0.4013800892446722, 1.3108515973602022, 4.0346174240112305, 17.95096983228411, 44.10262748173305, 83.40311173030308, 83.11307307652065, 97.3845270701817, 59.45276151384626, 33.169032505580354, 30.803928239004954, 27.9242490700313, 60.092600277491975, 63.473239353724885, 82.99787194388253, 66.3592778614589, 71.53258691515241, 75.06890732901437, 83.14600058964321, 78.91861929212297, 71.08708926609584, 34.50793647766113, 5.170425985540662, 0.26411736756563187, 0.04053501704973834, 0.05153519267748509, 0.03225691017827817, 0.07259475852229766, 0.05297230609825679, 0.05331897981730955, 0.10053955830101456, 0.01973168638401798, 0.06951594658728157, 0.036672320749078474, 0.06690127296107155, 0.0408425325128649, 0.023657067446038127, 0.01304463726202292, 0.0603624481175627, 0.06429681128689221, 0.06990343758038112, 0.0252649342042527, 0.03570651435958488, 0.012298242804328246, 0.06557616192315306, 0.025065341432179724, 0.03921335975506476, 0.04636408747839076, 0.04322485539263912, 0.020401646416368227, 0.008938864272619997, 0.04751254192420414, 0.0578092701200928, 0.012086067448503204, 0.05122906142579658, 0.024650195048057606, 0.03192753910220095, 0.0729993214564664, 0.0403644469167505, 0.03150257262002144, 0.05162959046927946, 0.023460629861801863, 0.08639060359980379, 0.007939114168818508, 0.030589749637459005, 0.04363455483689904, 0.06543653298701559, 0.021448722641382898, 0.044822489842772484, 0.02327796314576907, 0.02406771175031151, 0.013292852157194699, 0.031309105322829316, 0.09536301464374576, 0.058627834410539696, 0.038127147326512, 0.009208265575580299, 0.02285288131263639, 0.025444951241037676, 0.06184466715369906, 0.037647982859717946, 0.012266204077085214, 0.037223671163831434, 0.041219672454254966, 0.04192666183891041, 0.013679433913369263, 0.046721088500427346, 0.0328526062491749, 0.01879715876254652, 0.029908201923327785, 0.052764196015362225, 0.03604021109640598, 0.015000918181613088, 0.09213880622493369, 0.052322754702929936, 0.02265241153405181, 0.09118955608989511, 0.013481501007585652, 0.07659927542720522, 0.015507281724629658, 0.0428340870753995, 0.04821140585201127, 0.05664844937356455, 0.0221453660633415, 0.049684071115085056, 0.041800406827990494, 0.05282381210210068, 0.09743148793599435, 0.0627234446417008, 0.01483582891523838, 0.015811190774132098, 0.03224346161420856, 0.02455376674021993, 0.033976840387497625, 0.02615481591783464, 0.03241884595315371, 0.06656140155558075, 0.024798706007589186, 0.06035748802657638, 0.0143142339573907, 0.13500417715736798, 0.003570773996346231, 0.06614971400371619, 0.04192924705733146, 0.09075999592563935, 8.58812631879534, 56.75239624295916, 67.03339903695243, 86.5404804774693, 62.178025654384065, 80.427656854902, 99.20498984200614, 101.59498255593437, 81.5849279676165, 49.575768675122944, 44.97469241278512, 23.43497279712132, 25.134210348129272, 34.432982785361155, 42.82263381140572, 74.18572875431606, 67.7545873097011, 45.50151525224958, 14.387127603803362, 2.614707661526544, 0.5976706892251968, 0.4440168413732733, 0.26197781094482964, 0.3015315985041005, 0.090402930442776, 0.08477933398847069, 0.03751683561131358, 0.17183649646384375, 0.0966283603172217, 0.3485229712511812, 0.5166705985154424, 0.47607178560325075, 0.402360056660005, 0.32345549921904293, 0.22305336461535522, 0.12248060559587819, 0.3009515867701599, 0.5055428956236158, 0.27904999628663063, 0.34217039069959093, 0.44830214285424774, 0.3506743886641094, 0.3170685033713068, 0.17200378248734133, 0.16010587449584687, 0.0882320933576141, 0.01921795055802379, 0.007152448657767049, 0.5730306399720055, 0.7485083181943212, 0.6163884305528232, 0.25660343361752375, 1.0330488298620497, 3.807085633277893, 21.574262584958756, 48.34785522733416, 82.67635795048305, 74.9472096306937, 61.15254102434431, 38.141708850860596, 13.621308445930481, 35.06823921203613, 51.33470862252371, 94.11721311296735, 95.88928862980434, 115.57117979867118, 87.32939979008266, 80.75575774056571, 91.41963059561593, 98.6172000340053, 96.81005001068115, 86.28509943825858, 47.75067145483834, 7.573464376585824, 0.34754449661288944, 0.01575495718446161, 0.04254569272909846, 0.0838481600263289, 0.09190619084984064, 0.03181537047826818, 0.05319792916998267, 0.06476531936121838, 0.04736469253631575, 0.024697663661624705, 0.02969278741095747, 0.04681982213099088, 0.020559149661234448, 0.0546246372562434, 0.030209335764603953, 0.03907224821991154, 0.03717906766438058, 0.05046243899102722, 0.04314681029479418, 0.04705338066975985, 0.03561208264103957, 0.1108747458617602, 0.04141911764496139, 0.06306516844779253, 0.08340694263045277, 0.03803834066327129, 0.054919440365795574, 0.01010722354320543, 0.06149921140500477, 0.045809110293963125, 0.015063664011125053, 0.032337401394865344, 0.014559795780639564, 0.010087159262703998, 0.0741192027926445, 0.0063504325641718295, 0.04159580137846725, 0.05422246276534029, 0.01359784007737679, 0.026957105545859252, 0.02455158525013498, 0.018549581690292274, 0.01226411249289023, 0.028643283726913587, 0.024660842958837748, 0.08942549396306276, 0.04456071781792811, 0.09867108999086277, 0.01204187361456986, 0.008512903736638171, 0.008030591715526367, 0.025644644097025906, 0.026184411919010536, 0.14663139038852283, 0.17008044783558163, 0.07031018539730992, 0.14074190998716013, 0.08648945258132049, 0.11540895434362547, 0.08725653641990253, 0.1689750871488026, 0.08503026302371706, 0.14243991672992706, 0.09735025372356176, 0.08868933096528053, 0.11643825125481401, 0.19715798486556324, 0.20244442405445234, 0.088350124524108, 0.13492172158190183, 0.1535056150917496, 0.1191913935222796, 0.18364306007112774, 0.24626801535487175, 0.13195374155683176, 0.14877611744616712, 0.14632763740207466, 0.07239503852490868, 0.18924766433026108, 0.13056954368948936, 0.19058360478707723, 0.11313274077006749, 0.16136769178722585, 0.125816690868565, 0.20749049899833544, 0.13217714242637157, 0.21908614678042276, 0.13782167168600218, 0.12777605572981493, 0.12718549956168446, 0.13243567783917698, 0.15018926161740506, 0.19278485381177493, 0.10880110213266951, 0.11466188728809357, 0.10984356940857001, 0.10507439782044717, 0.21070604931030953, 0.07972655511860337, 0.1016924571512001, 0.10190849591578756, 0.4836690979344504, 17.018743923732213, 77.54796205248151, 86.1531114578247, 95.42751135144914, 72.58341162545341, 78.1600844519479, 88.95446532113212, 79.8505950655256, 61.03045422690255, 34.75108868735177, 64.68897260938371, 78.13311154501778, 66.3730491910662, 75.66220011029924, 88.57459340776715, 118.26456560407365, 96.35026686532157, 56.00296701703753, 15.864665508270264, 3.2091640489442006, 1.2504509070089884, 0.6872321548206466, 0.3860717149717467, 0.2771853006311825, 0.12238474216844354, 0.28156185150146484, 0.266459371894598, 0.3359482245785849, 0.3722212681812899, 0.7784885466098785, 0.8449880182743073, 0.8387636265584401, 0.6440571887152535, 0.6317968751702989, 0.8648468926548958, 0.6145430867161069, 0.6997596483145441, 0.9729153194597789, 0.8617152092712266, 0.8631861646260534, 0.8077657041805131, 1.1247544118336268, 0.8455502795321601, 0.44336799904704094, 0.44497569277882576, 0.21363969546343597, 0.1096787600378905, 0.11077537440827914, 0.7075104724083627, 0.7354848427431924, 0.7680287935904094, 0.8419074692896434, 2.9790572992392947, 5.02548656293324, 30.287996700831822, 70.45432376861572, 133.5601771218436, 123.68828773498535, 144.54882267543246, 90.00418526785714, 49.20454379490444, 43.056541442871094, 35.961270332336426, 72.92946665627616, 80.16530677250454, 109.81377043042863, 83.78884097508022, 85.98971761975969, 96.99835314069475, 110.697067124503, 108.40716321127755, 103.67019408089774, 59.8853702545166, 12.493125098092214, 0.38423565349408556, 0.20979797946555273, 0.1307159172637122, 0.17819853579359396, 0.2648401159260954, 0.17578432176794323, 0.08580927550792694, 0.19843512347766332, 0.21555286566061632, 0.13489555727158273, 0.11142553309244768, 0.15514612277703627, 0.13498456749532903, 0.18587895509387764, 0.10328157937952451, 0.11082702449389867, 0.0983054478253637, 0.12406784828220095, 0.229483284588371, 0.2143085952848196, 0.13337862438389234, 0.27830732613801956, 0.08351057528385095, 0.1545953694730997, 0.24184763112238475, 0.1732170166713851, 0.12233367562294006, 0.10953149758279324, 0.14769712463021278, 0.22977576032280922, 0.07092036479817969, 0.1756490354559251, 0.1509299911558628, 0.2108097430318594, 0.16106231031673296, 0.10727470368146896, 0.11883087429617133, 0.2249046524188348, 0.07892424852720328, 0.1918377817741462, 0.09469843030508075, 0.15562009305826255, 0.1305713757340397, 0.1726685839572123, 0.08758667084787573, 0.12837958548750195, 0.09178362706942217, 0.2226328628935984, 0.11379068903625011, 0.09433150570839643, 0.14033877876188072, 0.1662439022745405, 0.16843158059886523], [0.026363285624289086, 0.043261920368032794, 0.028273873995723467, 0.011368781294939774, 0.09560181825820889, 0.0045000056519971365, 0.04355878283136657, 0.05344504823109933, 0.020598745572247674, 0.01177102533568229, 0.058537589253059456, 0.06445543241820165, 0.021979147036160742, 0.02949490285079394, 0.01608435031292694, 0.04039323715759175, 0.02391982334665954, 0.048872682332460365, 0.030821279356522218, 0.054666068604482074, 0.036470225879124234, 0.01907088657441948, 0.03710619978872793, 0.015136007718475801, 0.06312841469688074, 0.05562733220202582, 0.03317415042381201, 0.05599219405225345, 0.0436287499698145, 0.08277770996625934, 0.02318539739852505, 0.05469240594123091, 0.03208507797015565, 0.019836455583572388, 0.044285375092710764, 0.022086525202861855, 0.01299061908918832, 0.0690883541745799, 0.03398183440523488, 0.060986727476119995, 0.08485703981880631, 0.020869586217616285, 0.06517829612961837, 0.047241399330752235, 0.06696340641272919, 0.055484341124870946, 0.1718869251864297, 9.632450120789663, 35.78959424155099, 58.16435010092599, 57.54730142865862, 58.47290570395333, 34.96297400338309, 84.44464669908795, 71.6274367741176, 30.378041880471365, 17.96285993712289, 26.62150526046753, 60.51257719312395, 49.15546172005789, 68.94857965196881, 71.34954357147217, 53.59956080572945, 58.27566371645246, 15.720976761409215, 1.5645885190793445, 0.15939656112875256, 0.049285469111055136, 0.05594923939289791, 0.11314158208136048, 0.07990880962461233, 0.03988362003916076, 0.07653927257550613, 0.05866299609520605, 0.2495196365884372, 0.20323217606970242, 0.27774237788149286, 0.21146328082042082, 0.30316008254885674, 0.1958646292665175, 0.11649154339517866, 0.3704563443149839, 0.24171569677335875, 0.1083183583936521, 0.6113222709723881, 0.1402260876659836, 0.32545164067830357, 0.6401723857436861, 0.7357867636850902, 0.4117213971912861, 0.4276110588439873, 0.35032963859183447, 0.19090771382408483, 0.16260248981416225, 0.44915050161736353, 0.36621351912617683, 0.3336891915116991, 0.5164693178875106, 0.24558264070323535, 0.312722242304257, 0.1553033257701567, 0.08913306572607585, 0.2463788336941174, 0.4485285021364689, 0.09952466668827192, 1.152208372950554, 13.163154653140477, 46.888236727033345, 81.66434587751115, 106.05603872026715, 68.78367805480957, 69.92956801823208, 36.51301983424595, 28.768045255116053, 17.798583677836827, 41.461130823407856, 70.68822792598179, 58.89264638083321, 75.96757343837193, 63.31566115788051, 67.9494981765747, 68.97504534040178, 60.908290999276296, 16.805401223046438, 0.32871129576648983, 0.18158730252512864, 0.007359718205407262, 0.03221184188233955, 0.07353221571871213, 0.10341005319995539, 0.04352475769285645, 0.047981111066682, 0.03750636920865093, 0.03768906136974692, 0.056141322478652, 0.03263192969773497, 0.011372767688174332, 0.07892080156930856, 0.03131511714309454, 0.06709583609231881, 0.06904374728245394, 0.013141646565470313, 0.03279307158663869, 0.06762298316295658, 0.10151139686682395, 0.04983011220714875, 0.06132601534149476, 0.030825187718229632, 0.011839569246928607, 0.07872510528458015, 0.0683828473889402, 0.047512660667832406, 0.021086898931701268, 0.05736896874649184, 0.04135534553123372, 0.0318137046747974, 0.011263526094678258, 0.0041774292559629035, 0.00992207762984825, 0.008212913226868426, 0.03538425772317818, 0.048301332098032744, 0.00619370793823951, 0.08176079631916114, 0.035605860474918566, 0.05789799535913127, 0.05836303611951215, 0.013062293591376926, 0.016034747706726193, 0.02537111984565854, 0.026283067518046925, 0.008430166569139277, 0.07856740696089608, 0.11114918613540274, 0.05851833242923021, 0.008186667492347104, 0.034615742175706794, 0.059424359883580885, 0.054280935520572324, 0.05160407076722809, 0.12751769673611435, 0.06817040485995156, 0.02464191522449255, 0.04514299585883107, 0.042588375974446535, 0.06224749303822007, 0.04211858207626002, 0.053957705186413865, 0.038956259443823776, 0.01633226326001542, 0.06825226332460131, 0.052258324410234175, 0.01246258822668876, 0.03579856442021472, 0.011557444564199873, 0.059058324167771, 0.04135065006890467, 0.012194688182457216, 0.02630027855879494, 0.0013903918318516973, 0.0022654291076053467, 0.05143741238862276, 0.039299862791917155, 0.052226060070097446, 0.028935844278229133, 0.05198559065216354, 0.05769064862813268, 0.052591715806296895, 0.06840877421200275, 0.03246821616111057, 0.07283161474125725, 0.020857664357338632, 0.03827686947105186, 0.032363158584173234, 0.017289764380880764, 0.02181504334190062, 0.021421236884114996, 0.0130518390630771, 0.013425408213931535, 0.06561759327139173, 0.11799820326268673, 0.053078751279307265, 0.12216112416769777, 8.488649828093392, 38.8255227633885, 70.38523088182721, 74.56557982308524, 70.3320563180106, 45.54422582898821, 104.29642827170235, 98.08796269553048, 59.39085306440081, 31.434644017900737, 30.09922456741333, 23.129613365445817, 37.64500992638724, 56.302625451769146, 60.648984227861675, 55.912702969142366, 59.93345178876604, 19.598549263817922, 2.2770569111619676, 0.18674716779163905, 0.19030982947775296, 0.031839200628123114, 0.09730374014803342, 0.06181487946638039, 0.06183267065456935, 0.043762122813080034, 0.24606016650795937, 0.4302838625652449, 0.6534240118094853, 0.6171541437506676, 0.3591705970466137, 0.7096960608448301, 1.0852366409131458, 0.843333261353629, 0.9297069694314684, 1.2276348684515273, 0.9403919960771288, 1.9729681313037872, 0.9897191034896033, 1.2842733263969421, 2.0117358224732533, 1.7491642662457056, 1.470366494996207, 1.221651275243078, 0.9358004310301372, 0.8200708010366985, 0.30860980440463337, 0.533423302429063, 0.2658223360776901, 0.3980321431798594, 0.18050104938447475, 0.09406776593199798, 0.2981258141142981, 0.01785859894672675, 0.07522394601255655, 0.2193893976509571, 0.7897117872323308, 0.33391644646014484, 0.8111186442630631, 13.368520821843829, 53.25067785808018, 71.75219167981828, 76.53722149985177, 34.39920064381191, 31.712683132716588, 25.16183638572693, 31.309833526611328, 39.749094690595356, 71.51259694780622, 113.92652034759521, 82.91399329049247, 92.3628624507359, 80.52771091461182, 81.56190163748605, 83.8914519718715, 79.57721124376569, 25.22236040660313, 0.1008616928011179, 0.2037005823637758, 0.016457641264423728, 0.10591350136590855, 0.1246905941516161, 0.18294809093432768, 0.012973747315949627, 0.11916862188705377, 0.09502774370568139, 0.008523987606167793, 0.03446373676082917, 0.011471870272154254, 0.04873281251639128, 0.07189602351614408, 0.01701712392137519, 0.04652041855401226, 0.03201602685398289, 0.03113595336409552, 0.08093004553977932, 0.016030593376074518, 0.07023330059434686, 0.07375904997544629, 0.02507820984880839, 0.06128865520336798, 0.014528903777578046, 0.044839497323014905, 0.03474758492250528, 0.01320168249575155, 0.03951852748702679, 0.04635172796302608, 0.029862909710833004, 0.025087163118379455, 0.049778489262929985, 0.03340341383591294, 0.03084304675992046, 0.01814382623082825, 0.038634525279381444, 0.013659499402690147, 0.06768573408148118, 0.03738948137366346, 0.030226424669048617, 0.09136173435087715, 0.04669204041627901, 0.030043780005403926, 0.039917173595832925, 0.021439162082970142, 0.017797042249834964, 0.02506239659019879, 0.04499120757515941, 0.05714600892471416, 0.042806243390909264, 0.029919163656554053, 0.08232019415923528, 0.14383079138185295, 0.13842271800552094, 0.14763503867600644, 0.2751458686377321, 0.11930996073143822, 0.14062341063150338, 0.1557538187397378, 0.1122606061398983, 0.12603390349873475, 0.1294922200696809, 0.1879966086042779, 0.08499656697469098, 0.11219608424497501, 0.21946326297308716, 0.094929342557277, 0.13242845822657856, 0.1001749135819929, 0.09681385143526963, 0.1283564203019653, 0.13041330421609537, 0.07046104408800602, 0.17001302859612874, 0.1198657216238124, 0.13466523534485272, 0.23587028043610708, 0.14719777713928903, 0.10712706124676125, 0.18631485956055777, 0.13291357005281107, 0.1884512270667723, 0.13794614214982304, 0.12058863283268043, 0.11597449971096856, 0.1552577010755028, 0.07710682640650443, 0.15735795694802487, 0.14234341547957488, 0.18806264363229275, 0.16229007872087614, 0.22276314161717892, 0.053110343869775534, 0.11671484926981585, 0.15511710861963884, 0.1649513609175171, 0.18372892189238751, 0.1867954387728657, 16.357813903263636, 59.14175319671631, 90.29528699602399, 86.17713138035366, 82.68335478646415, 56.06757831573486, 107.61151109422956, 91.35484559195382, 38.1985763822283, 24.424205201012747, 39.334731919424875, 87.9518402644566, 69.06672682080949, 101.1430995123727, 113.36764199393136, 79.73682526179722, 91.62697178976876, 24.64037929262434, 3.3216358423233032, 0.39702647285802023, 0.2955342174640724, 0.14032322673925332, 0.1748879770083087, 0.23433307292205946, 0.20871600109551633, 0.46263559801237925, 0.4220178946852684, 0.4603752078754561, 0.5186181568673679, 0.6712757796049118, 0.41315972858241623, 0.3746515634868826, 0.721586925642831, 0.4500872056399073, 0.7829143319811139, 0.4133255625409739, 0.35934652760624886, 0.8206137376172202, 0.34015839866229464, 0.5996737788830484, 1.0122233416352953, 0.8740694320627621, 0.8611756925071988, 0.7817286870309285, 0.6748017189758164, 0.5163602094565118, 0.2540225035377911, 0.6143703045589584, 0.7591392248868942, 0.9229008832148143, 0.9621792669807161, 0.48155011449541363, 0.4577254472034318, 0.29178270591156824, 0.1867362026657377, 0.22873391051377567, 0.7115517184138298, 0.6094735073191779, 1.2948984248297555, 22.332927703857422, 73.9730999810355, 123.37695285252163, 157.02638380868095, 101.7057854788644, 97.19823891775948, 52.19717461722237, 42.00162771769932, 26.85497168132237, 54.833918707711355, 89.916366985866, 77.8089850289481, 93.72272218976701, 80.90401145390102, 87.39171123504639, 96.80175386156354, 98.64093508039201, 34.59486539023263, 0.6800946721008846, 0.47554953077009743, 0.10676550386207444, 0.16407268520976814, 0.1632600716714348, 0.3005894662014076, 0.17475094007594244, 0.1605687846562692, 0.26243747770786285, 0.11049870853977543, 0.07651477067598275, 0.11540282038705689, 0.10950458688395363, 0.22093412333301135, 0.09044890797563962, 0.2341436802276543, 0.1283933190362794, 0.1869549352143492, 0.1659216931355851, 0.1482506056449243, 0.186426790697234, 0.10969361316944871, 0.18488156289926597, 0.1467169536543744, 0.12891526174332413, 0.21146823412605695, 0.06804677577955381, 0.15441069938242435, 0.22684785457594053, 0.14695691077836923, 0.07675198651850224, 0.09880405571311712, 0.1738690888243062, 0.05086314784629004, 0.1983887388237885, 0.1701392632509981, 0.10052923099803072, 0.09238693969590323, 0.17261800595692225, 0.14770731622619288, 0.13264123323772634, 0.11511307236339365, 0.09288620576262474, 0.106775057635137, 0.10573542663561446, 0.10776052118412086, 0.09080812441451208, 0.06642443926206656, 0.17591324342148645, 0.2628326022199222, 0.11396497754114014, 0.0957279239914247], [0.03196610024731074, 0.07153090382260935, 0.06647098676434585, 0.03426313127524086, 0.0594266126198428, 0.01822930807247758, 0.09026042451815945, 0.08228477463126183, 0.05037642449938825, 0.03413756837003997, 0.03109494949291859, 0.031152998163763965, 0.04614346520975232, 0.04791211762598582, 0.009291687215279256, 0.03493625497711556, 0.02736479483012642, 0.008398615538940897, 0.0737081869904484, 0.027467141659664254, 0.03621939183878047, 0.021742136450484395, 0.047418110205658844, 0.05380178462447865, 0.03896303800866008, 0.02891512181875961, 0.05895235735390868, 0.013673603601221527, 0.07619055985872235, 0.07307550058301006, 0.04382609509463821, 0.06013557314872742, 0.012009457452222705, 0.041786642745137215, 0.0546198162649359, 0.03854975929217679, 0.05563368328980037, 0.0597044387832284, 0.026903285844517604, 0.06463630271277257, 0.01467062090523541, 0.05620187155104109, 0.010312294637385224, 0.03988173710448401, 0.02145346051215061, 1.1232597891773497, 18.38399199077061, 42.10314784731184, 56.771833828517366, 66.2426870891026, 71.82546043395996, 62.922900336129324, 58.96168368203299, 33.328764642987935, 30.463556834629603, 45.675345284598215, 61.989785058157786, 66.37552274976457, 69.5550879069737, 54.933889389038086, 43.067776679992676, 30.813725199018204, 12.629920363426208, 1.0780239765133177, 0.08290241113198654, 0.08630542031356267, 0.020319521626723663, 0.07071212240095649, 0.1020051667998944, 0.060843502304383686, 0.16065088739352568, 0.007768509260910962, 0.10769655568791286, 0.14007963266755852, 0.12899196334183216, 0.09793620942426579, 0.10909516563905136, 0.12951649805264814, 0.15018525826079504, 0.15456461826605455, 0.1915989645889827, 0.16177207151693956, 0.1832451264240912, 0.17043176612683705, 0.4007633551955223, 0.428468292845147, 0.5189542759742055, 0.37742446469409124, 0.32035890966653824, 0.31955479138663834, 0.3399498169975621, 0.25367262374077526, 0.23211529478430748, 0.22847256596599305, 0.08831425037767206, 0.0892998157069087, 0.033577919472008944, 0.16645527950354985, 0.26023753147040096, 0.27275435839380535, 0.3760613692658288, 0.388630036264658, 0.19185101320700987, 0.33377273274319513, 0.13611051493457385, 0.055873572560293336, 0.18576649469988687, 0.45408982943211285, 8.783203942435128, 28.87547482763018, 69.8125673021589, 91.19308458055768, 97.73371573856899, 71.7099049431937, 55.55206019537789, 25.30476951599121, 16.073910508837017, 32.63968052182879, 42.43856866019112, 55.85402890614101, 69.70120852334159, 67.32426452636719, 62.2474798474993, 67.41267340523856, 31.322809287479945, 3.0437943169048856, 0.3203346723956721, 0.30645594426563805, 0.0681034673803619, 0.07848324147718293, 0.07525915519467422, 0.02723360008427075, 0.027852256083860993, 0.03875731976170625, 0.007950220938905008, 0.048239707547639094, 0.05469872988760471, 0.040054037501769404, 0.03886610249589596, 0.06276136796389307, 0.051379258544849496, 0.014499842122729336, 0.04054483884413328, 0.08364019582846335, 0.05814549779253347, 0.08657441195100546, 0.03026429031576429, 0.03672222360702498, 0.13171994553080626, 0.07689591736665793, 0.03333629315186824, 0.04724397097847291, 0.02873393600540502, 0.04301989371223109, 0.0527919718463506, 0.017344355915806124, 0.021672043783058013, 0.04195900081789919, 0.03722467878833413, 0.013601505014646267, 0.0354474021920136, 0.02120548310423536, 0.03372308525389858, 0.005787711174759481, 0.029320173298141787, 0.03269212593191436, 0.04242689481803349, 0.03887390564861042, 0.0802464893619929, 0.0366428892926446, 0.11500579597694532, 0.05644920435068863, 0.02755896101838776, 0.03504649656159537, 0.015233141702732869, 0.024398828357724205, 0.023112599072711806, 0.07190812179552657, 0.050095728132873774, 0.03797716733866504, 0.02761492658672588, 0.024799756040530543, 0.02055955508590809, 0.11064531281590462, 0.037648037142519436, 0.007670399034395814, 0.07564972673675843, 0.04183792981452175, 0.08867773480181183, 0.05803229101002216, 0.05615623667836189, 0.038144799415022135, 0.04108075937256217, 0.020128451254484907, 0.03144261048042348, 0.04391729020114456, 0.018075774257470454, 0.0285453304116215, 0.04382473463192582, 0.023995456252513186, 0.03608529296304498, 0.06009773803608758, 0.05223371733778289, 0.06290412494646651, 0.037937520537525415, 0.09357869146125657, 0.06413183228245803, 0.03526102558576635, 0.045289905475718636, 0.08239476515778474, 0.05601751358647432, 0.012329836242965289, 0.04504922910460404, 0.03262839113761272, 0.042788716831377575, 0.07853001968136855, 0.03590025307078447, 0.024931866808661392, 0.047788824420422316, 0.06473096513322421, 0.04364717898092099, 0.9011731605444635, 21.44473774092538, 60.543072836739675, 71.97816794259208, 84.26393100193569, 83.95005307878766, 95.7721836907523, 82.96441636766706, 64.87123080662319, 41.94314473015921, 22.33209044592721, 39.7718118258885, 33.776704583849224, 52.933211190359934, 49.912085805620464, 47.53455121176583, 37.694418566567556, 17.086052860532487, 1.6598761145557677, 0.016468697992552603, 0.02441525738686323, 0.06634768338075706, 0.12050108824457441, 0.2588801628776959, 0.3004742780966418, 0.8313476730670247, 0.7402637377381325, 0.3954405736710344, 0.526973365672997, 0.529257803090981, 0.4110793944980417, 0.41474370072994915, 0.7028877490333149, 0.7480216728789466, 1.4317082379545485, 1.3450879773923328, 1.07777481845447, 2.5540075472423007, 2.2001066974231174, 2.1854822593075887, 3.382953477757318, 4.047563220773425, 2.2073402064187184, 1.5836325543267387, 2.195019747529711, 2.7699145674705505, 1.4624484798737933, 1.587576525551932, 1.5841053575277328, 0.32357440569571083, 0.48703012615442276, 0.372643235538687, 0.7021935805678368, 1.2538099267653056, 1.2176383648599898, 1.1812637852770942, 1.0722088771206992, 0.19024450012615748, 0.3610112454210009, 0.21921889537147113, 0.10514796458716903, 0.19470470079353877, 0.13006005888538702, 10.10665946347373, 30.75100381033761, 70.00131511688232, 81.57589530944824, 64.83223056793213, 48.32381098611014, 30.459735325404576, 20.277619293757848, 25.821474041257584, 56.448266642434255, 77.49190398624965, 84.48083986554826, 92.41134003230503, 83.24828502110073, 80.48838411058698, 81.59020165034703, 45.75358200073242, 4.1499305963516235, 0.16852679263268197, 0.39629289507865906, 0.008296920103020966, 0.04480733476313097, 0.04067984017144356, 0.05352261835443122, 0.02262411662377417, 0.02063242974691093, 0.0026793235946180566, 0.06210794552628483, 0.0779098386743239, 0.031895362971616645, 0.1081902374114309, 0.03239843222711768, 0.06307084100054842, 0.030900494927274327, 0.027826466664139713, 0.06432779998119388, 0.03508589569745319, 0.09346803597041539, 0.038660645484924316, 0.025409909996337125, 0.03931081773979323, 0.08074660359748773, 0.017003619378166537, 0.05620701823915754, 0.005671976849303714, 0.023800007633066604, 0.046337692466165335, 0.012308856788357454, 0.029894285170095306, 0.012005117372609675, 0.044994434009173086, 0.0013259509370462702, 0.027964032853820493, 0.019214620647419776, 0.033053038708333454, 0.021279568950246488, 0.029173314571380615, 0.02455127482036395, 0.0697602666914463, 0.02919213374012283, 0.038100368942001035, 0.033162744250148535, 0.05557105450757912, 0.04175240386809621, 0.03667556753914271, 0.004248424799048475, 0.01538358479073005, 0.023524737850363766, 0.14026164290096077, 0.25280521171433584, 0.1726928347987788, 0.13738416587667807, 0.18572776392102242, 0.1255261693149805, 0.13640825610075677, 0.2929653381662709, 0.12864641259823525, 0.10555222218057939, 0.15377458637314184, 0.07832122767078024, 0.16319809428283147, 0.1569531565265996, 0.13689980043896607, 0.14223689905234746, 0.12658707238733768, 0.09402253478765488, 0.1385122981986829, 0.19380124498690876, 0.10056931884693247, 0.1354732077036585, 0.08422710826354367, 0.15155257417687348, 0.19356058218649455, 0.12096591187374932, 0.11949639501316206, 0.11369975177305085, 0.09722681463296924, 0.310501152915614, 0.19236811117402144, 0.10702907400471823, 0.1427559783416135, 0.14668692169444902, 0.14641022868454456, 0.161983815154859, 0.169495089245694, 0.23413518496922084, 0.09479224455675908, 0.1334462607545512, 0.10389888339809009, 0.20734841376543045, 0.2057994675955602, 0.10211057042969124, 0.1751955705029624, 3.2282073242323737, 39.4207193510873, 81.4489517211914, 86.32491956438336, 92.13115392412458, 95.756730897086, 89.20895004272461, 81.94564369746617, 45.972929682050435, 43.037420000348774, 69.18501295362199, 95.60802555084229, 98.7240355355399, 102.82802377428327, 85.6353872844151, 62.8769588470459, 50.24464396068028, 19.954507214682444, 1.8741588847977775, 0.25179682725242203, 0.15669394257877553, 0.17786251168165887, 0.30411760402577265, 0.1781527211091348, 0.30665722489356995, 0.6608795917459896, 0.5316645939435277, 0.2531150308038507, 0.23853076196142606, 0.23291243772421563, 0.1754685722823654, 0.16722289259944642, 0.3846808538905212, 0.3402217738330364, 0.5910924822092056, 0.6031465211084911, 0.6080479323863983, 1.8495233952999115, 1.0580995827913284, 0.5767759904265404, 0.8365967656884874, 2.0303344130516052, 0.7541967215282577, 0.8773654837693486, 0.9657586749110902, 1.1376821867057254, 0.8170920865876334, 0.7307185413581985, 0.5717606395483017, 0.13361468671688012, 0.22223730411912712, 0.1974735307906355, 0.4292691812983581, 0.4097719932241099, 0.539007157087326, 0.7114268679703984, 0.852073823767049, 0.372037086635828, 0.8737366784896169, 0.41970607159393175, 0.2301181490932192, 0.39445129675524576, 1.2733301307473863, 15.210824387414114, 42.35145214625767, 106.83598096030099, 133.01885686601912, 135.45303317478724, 104.55593654087612, 80.69829613821847, 35.25054257256644, 19.598905358995708, 43.76499366760254, 60.4037892477853, 74.90403352464948, 92.84690870557512, 87.59870501926967, 84.28251048496791, 99.90624373299735, 60.443984576633994, 7.260203106062753, 0.382545884166445, 0.7440582684108189, 0.21864374194826397, 0.11231730452605657, 0.09354946695800338, 0.17615872382053308, 0.10385181342384645, 0.16434655551399502, 0.054133832521204434, 0.11728331233773913, 0.19080376225922788, 0.18858435563743114, 0.1636978896068675, 0.17917240996445927, 0.11923355768833842, 0.16448104115469114, 0.18573834906731332, 0.2480709914650236, 0.14489428645798139, 0.1519807976271425, 0.1729429020945515, 0.16639533772000245, 0.2266231102070638, 0.22294691604162964, 0.08410299742328269, 0.18409879133105278, 0.1020777632615396, 0.1396171703402485, 0.12334710838539259, 0.10559331426130873, 0.1717908853398902, 0.11794910446873733, 0.1223864656473909, 0.07577185625476496, 0.09050336041088615, 0.17294231855443545, 0.12055850587785244, 0.1325948214424508, 0.11013688652643136, 0.12984627964241163, 0.12316608881311757, 0.17706185393035412, 0.16276460540081772, 0.10808273710842643, 0.1425109457756792, 0.09816725738346577, 0.13700334488281182, 0.0639844001936061, 0.090779049188963, 0.09823147393763065], [0.04583218387727227, 0.023062850581482053, 0.030831202931169952, 0.03409595721002136, 0.01920217292250267, 0.04020692840484636, 0.050602071319839785, 0.016103920959202305, 0.0623262438124844, 0.04857875453308225, 0.008601668839608985, 0.009255718922109475, 0.03499120274292571, 0.030340869777968953, 0.05113109453980412, 0.04728407579075013, 0.04568237691585507, 0.02732551783057196, 0.0036507206885809346, 0.02783291444315442, 0.05807065537997654, 0.027431779807167392, 0.021009242295154502, 0.02562897333077022, 0.04467606877109834, 0.0632102731615305, 0.06563980850790228, 0.007872783978070532, 0.07225916867277452, 0.032111194783023427, 0.03518671921587416, 0.02130879514983722, 0.013763824161807341, 0.04064316535368562, 0.020584241886224066, 0.02541515676836882, 0.025834026613405774, 0.07485267200640269, 0.04120022903329559, 0.12210431721593652, 0.054802277724125555, 0.07382977368044001, 0.022680991429037282, 0.2850748715656144, 7.291654126984732, 30.642976692744664, 62.96367236546108, 49.53956856046404, 56.09524951662336, 51.850876399448936, 48.765181405203684, 30.23091377530779, 19.001009396144322, 27.80882212093898, 56.26048810141427, 66.64998354230607, 60.6806332724435, 66.20168576921735, 43.772629737854004, 26.394113302230835, 7.49799999168941, 0.9093182406255177, 0.35637017445904867, 0.20719427775059426, 0.03257948233346854, 0.03385050734505057, 0.07518949678965978, 0.11418636994702475, 0.06383453216403723, 0.3240780686693532, 0.644905357488564, 0.20769477875104972, 0.3522743470966816, 0.4290204575019223, 0.7608915822846549, 0.8143835376415933, 1.3259739173310143, 0.6605957469769886, 1.9891713304179055, 1.4161544782774789, 3.102550889764513, 2.0666839139802113, 5.273543766566685, 2.3158219967569624, 8.674133726528712, 6.100969995771136, 6.250903436115809, 8.116091762270246, 4.591559401580265, 4.3736612881932935, 3.824521703379495, 2.358859573091779, 2.0045083931514194, 1.644804711852755, 1.1806253109659468, 0.482890248298645, 0.5485382399388722, 0.3173966700477259, 0.5649175324610302, 0.2819710081177098, 0.352383265537875, 0.10393386187830142, 0.18533249013125896, 0.21211474229182514, 0.1542895265987941, 0.1883177456579038, 0.10049894798014845, 0.044879907476050515, 0.21696356710578713, 0.21178447215684823, 3.943845723356519, 21.304319858551025, 44.788223607199534, 61.395324979509624, 73.37399850572858, 101.41034112657819, 87.73643915993827, 39.5356251852853, 23.420386791229248, 23.787696361541748, 39.68210015978132, 50.6228483063834, 54.57746417181832, 63.62636375427246, 64.29150785718645, 60.1602965763637, 28.41924568584987, 9.189748253141131, 0.911133674638612, 0.08809407254947083, 0.069180668863867, 0.07782878088099615, 0.03619710535609296, 0.047320570796728134, 0.047802364586719444, 0.029872181891862835, 0.04872651910409331, 0.020615810727966682, 0.045293769732649834, 0.025138585894767727, 0.07401400950870343, 0.045045039150863886, 0.06542255516563143, 0.0251662345004401, 0.03335882390716246, 0.02466641033866576, 0.013455380802042782, 0.011325159126759639, 0.014248814699905259, 0.029624309656875472, 0.03733864553006632, 0.05555669331390943, 0.01908887453776385, 0.013437406409398785, 0.01990082989712911, 0.06246704661420413, 0.04326545553547995, 0.03476939643067973, 0.05239764122026307, 0.032209460224424086, 0.02035311928817204, 0.0260362809390894, 0.07572122397167341, 0.06551854072936944, 0.028457499142470102, 0.019813063088804483, 0.013656177125605089, 0.02000450835164104, 0.026968107991186634, 0.07618473802826234, 0.01610140868329576, 0.03001665896070855, 0.0476181423291564, 0.033587496993797164, 0.009582891544726278, 0.0581281069400055, 0.0781220979988575, 0.01785827155358025, 0.03889353566669992, 0.03665547611724053, 0.04394115427775042, 0.030883558693208864, 0.01862008317506739, 0.02902276800679309, 0.02222906335789178, 0.0063885624154603905, 0.03162954348538603, 0.029606094384299855, 0.05212171495492969, 0.0340157611561673, 0.0544662468268403, 0.04775921654488359, 0.017447803668411713, 0.06825600883790425, 0.035838241755430184, 0.025314336642622948, 0.029144066319401776, 0.04502788239291736, 0.013876991928555071, 0.0697166368897472, 0.03580673737451434, 0.08833115268498659, 0.04780397950006383, 0.050997955791120014, 0.04349078005179763, 0.060810464434325695, 0.02926756308547088, 0.06935515414391245, 0.03798310112740312, 0.057607575585799556, 0.03896373350705419, 0.03504796219723565, 0.01623919709319515, 0.036151823321623464, 0.03346334883411016, 0.04364438002396907, 0.020111063794632043, 0.04788072181067296, 0.028075458481907845, 0.06772945887808289, 7.384832075663975, 39.481238160814556, 74.18882765088762, 60.05801214490618, 70.40235124315534, 82.40697629111153, 91.44633252280099, 58.32133075169155, 43.63967595781599, 18.2633695261819, 24.469828810010636, 46.90107699802944, 44.31237275259835, 59.787622996738975, 50.74750246320452, 34.58259834562029, 11.311050653457642, 1.383763604930469, 0.5464008003473282, 0.29372445600373404, 0.10118749817567212, 0.36428821672286305, 0.46767624467611313, 0.6773036132965768, 0.5513148052351815, 1.5821840720517295, 1.5829506537743976, 1.9594058990478516, 2.6882002779415677, 3.5913256108760834, 4.32898610830307, 4.135926067829132, 6.4893564922469, 5.095068863459995, 5.406933111803872, 4.5455540759222846, 5.549825855663844, 6.421131261757441, 7.111694914954049, 10.032337188720703, 13.9847800050463, 12.17245009967259, 14.515966313225881, 10.58764590535845, 8.92992557798113, 8.452596494129725, 8.920205916677203, 9.043324521609716, 7.912632005555289, 4.517179369926453, 5.293149411678314, 3.8804729410580228, 4.595529428550175, 2.504562863281795, 2.9200618820531026, 1.4897166852440153, 1.8375058344432285, 0.5144178079707282, 0.683491798383849, 0.6480931692889759, 0.7859045001012939, 0.559254316346986, 0.1492365984512227, 0.08187865785190038, 0.34483551340443747, 0.0848217017150351, 4.4809562393597195, 23.092061826160975, 51.72584703990391, 61.14521762302944, 58.49370166233608, 57.35998841694423, 38.54238714490618, 29.882875033787318, 28.517267397471837, 43.562425885881694, 69.63843849727085, 82.87337412152971, 73.88118921007428, 75.64032023293632, 78.99171434129987, 75.61063058035714, 36.15719563620431, 10.980061054229736, 0.4264695458114147, 0.18245988498841012, 0.08497144082295043, 0.05321510967665485, 0.07231085268514496, 0.02670722993622933, 0.02130047800684614, 0.08493628592363425, 0.014259985082649758, 0.0630339558369347, 0.03204159405348556, 0.020003824727609754, 0.03623304057068058, 0.09810372614966971, 0.03435221953051431, 0.07056101943765368, 0.029071174695023468, 0.04575971294460552, 0.06483210077775375, 0.06531555697854076, 0.04675907967612147, 0.019665951607748866, 0.06439032019781214, 0.07614053147179739, 0.02087450729283903, 0.04273572663909622, 0.01662438445990639, 0.026003046293876002, 0.016894951994929994, 0.04773498605936766, 0.028521547759217874, 0.028561550791242292, 0.020868883933871984, 0.027945369748132567, 0.025493561489773647, 0.04361967117126499, 0.04688579948352916, 0.05673490830564073, 0.015580214061109083, 0.031511726057423015, 0.002377444425032341, 0.07137722921158586, 0.021016005592952882, 0.07456702233425208, 0.013762427227837699, 0.04072572949475475, 0.043725220686090846, 0.03554405611274498, 0.16799999161490373, 0.06002512800374201, 0.13337747087436064, 0.10756123544914381, 0.13226611193801674, 0.1776303577103785, 0.11869044468871184, 0.13156521240515368, 0.080166917560356, 0.16536941991320678, 0.11570014086152826, 0.07911714246230465, 0.1811953806983573, 0.13603487185069493, 0.12734510456877096, 0.10402376776827232, 0.1261261978319713, 0.29339105103697094, 0.18421582505106926, 0.1208762638270855, 0.09618847284998212, 0.10476168817175285, 0.1326002904347011, 0.1520923487842083, 0.1852038534624236, 0.1949639825948647, 0.195774411250438, 0.1791595449405057, 0.14330576812582357, 0.18561192442263874, 0.11746069496231419, 0.13558207186205046, 0.10052546512867723, 0.11174280249646731, 0.11917433515191078, 0.15382748496319565, 0.15275590174964496, 0.18670357870204107, 0.1964000883911337, 0.236291514975684, 0.16153799050620624, 0.11292501405945846, 0.10910106889371361, 0.48638269518102917, 14.868106228964669, 65.05369050162179, 94.78880514417375, 75.50956903185163, 78.9292847769601, 71.27537849971226, 71.32239695957729, 49.11038875579834, 30.962837014879497, 43.01733275822231, 79.78022371019635, 99.11050823756626, 88.88751942770821, 97.04139028276715, 64.78332219805036, 44.52666909354073, 15.638887269156319, 2.5963846104485646, 0.871772401034832, 0.31373518652149607, 0.11596065759658813, 0.25048796034285, 0.21120260123695644, 0.2995329057531697, 0.25738695157425745, 0.8543333453791482, 1.173650405236653, 1.136489702122552, 2.0403524126325334, 2.6568795357431685, 3.8211770142827715, 4.035123773983546, 4.801475771835872, 4.43531482560294, 5.112749423299517, 6.580126021589551, 7.614822660173688, 9.312159878867012, 10.2958710704531, 13.026015451976232, 24.629104103360856, 14.475493924958364, 16.18550205230713, 18.90874079295567, 12.619913220405579, 11.772084474563599, 10.26885907990592, 7.069972285202571, 6.148050120898655, 4.443462456975665, 3.4827923604420254, 2.1205915127481734, 2.9992585352488925, 1.1723013690539767, 1.3152865022420883, 0.6069527225834983, 1.1101326878581728, 0.19434359802731446, 0.1882326437958649, 0.2563889351274286, 0.5110958090850285, 0.4356000487293516, 0.2279204555920192, 0.13803133900676454, 0.43215151663337437, 0.2826271243393421, 6.782997352736337, 30.68657316480364, 67.32207584381104, 90.62272780282157, 108.36921909877232, 135.48232678004672, 122.59194537571499, 54.91947882516043, 31.507739067077637, 33.84632553373064, 51.514875411987305, 69.40588229043144, 76.00938074929374, 82.64185319628034, 89.43820585523332, 93.46992588043213, 51.81096247264317, 20.984377895082744, 1.4530755771057946, 0.21636306361428329, 0.14135363644787244, 0.15776776495788777, 0.2415082821888583, 0.1841512828000954, 0.12421016421701227, 0.1621606278100184, 0.07138497808149882, 0.11595537859414305, 0.22414482890495233, 0.07981762130345617, 0.21499227359890938, 0.1966682725719043, 0.13326636755040713, 0.16537354540612015, 0.20725124755076, 0.21563684115452425, 0.1743743395698922, 0.12262216157146863, 0.12038452949907098, 0.10278533279363598, 0.13047274388372898, 0.1863413902797869, 0.10499307539846216, 0.1109419140432562, 0.10839307866990566, 0.1633384424660887, 0.1135211545707924, 0.11953275091946125, 0.12375720137996332, 0.14660257979163102, 0.09699590916612319, 0.1380807092147214, 0.14801356622150966, 0.18404544490788663, 0.14798331713037832, 0.08442468409027372, 0.06278840079903603, 0.13784970875297273, 0.0858850475134594, 0.16823699032621725, 0.13684916815587453, 0.1591295711696148, 0.08346957141267401, 0.1422894855162927, 0.16047160487089837, 0.15703262654798372], [0.02979628775002701, 0.03859426101137485, 0.031068483234516213, 0.06294742905135665, 0.005818280449602753, 0.03568768162014229, 0.013993985784639205, 0.04188084715445127, 0.07914585127894368, 0.011421101433890206, 0.03547286082591329, 0.043804592319897244, 0.027914572739973664, 0.004010083012482417, 0.0032880324828771074, 0.03175609026636396, 0.038715114883546314, 0.022716231145230786, 0.00938505448201405, 0.06443129692758832, 0.06763482359903199, 0.012274400780110486, 0.08913966108645711, 0.03765401503603373, 0.09645879441606146, 0.026733740299407924, 0.0160263101237693, 0.010106019143547331, 0.08728956750461034, 0.028764368300991397, 0.012872176560839372, 0.08314016301717077, 0.04285949821184788, 0.04162909709183233, 0.012689781258814037, 0.05459614896348544, 0.06816298847219773, 0.04451740014233759, 0.08016533657376256, 0.016532378504052758, 0.012934396525711885, 0.0020533862781511353, 0.9015694792781557, 16.428589991160802, 47.901575905936106, 60.4078608921596, 64.57650211879185, 79.63864721570695, 68.49088791438511, 32.705580711364746, 22.179933582033428, 31.38380057471139, 32.89179243360247, 55.41399948937552, 65.21637562343052, 48.77103178841727, 55.97036954334804, 22.875328404562815, 5.62941529921123, 0.3720143421420029, 0.5074158694062914, 0.0871350040127124, 0.06630431820771523, 0.028959932271391153, 0.10049246118537017, 0.14725290132420404, 0.04801149247214198, 0.9528195006506783, 0.657537291092532, 1.390529521874019, 0.5128208079508373, 1.5411083847284317, 3.592708085264478, 3.565788809742246, 3.7674570168767656, 4.460959758077349, 3.7790531260626654, 2.5604906507900784, 3.737509846687317, 4.8357438530240735, 6.979760783059256, 2.552623335804258, 4.6566996318953375, 5.175877281597682, 10.511790684291295, 19.10010286739894, 13.261144229343959, 7.868675095694406, 1.9264475532940455, 6.0689131787845065, 10.051892025130135, 5.587899812630244, 6.100258673940386, 6.179252743721008, 2.5905743965080807, 1.5936721584626605, 3.3813032805919647, 4.62840222460883, 5.87749855858939, 5.200768768787384, 2.5992181726864407, 2.9484569983822957, 1.1358893343380518, 0.7338356226682663, 0.5018963398677962, 0.060833453200757504, 0.1527311216507639, 0.14175048443887914, 0.12905787623354367, 0.08017562994999544, 0.04970424056851438, 0.1807483211159706, 3.690560434545789, 25.564203092030116, 44.193287576947895, 68.90935707092285, 76.27761595589774, 69.96879059927804, 57.971888474055696, 42.06387315477644, 18.150661059788295, 21.68865772656032, 47.352386815207346, 57.00510222571236, 57.718081201825825, 57.59616810934884, 73.88505240849086, 65.80117770603725, 41.88713182721819, 10.671667865344457, 1.1165384926966258, 0.1716268291430814, 0.12497310899198055, 0.07086465028779847, 0.03246540024078318, 0.09202370632972036, 0.037837168600942404, 0.08608469287199633, 0.023572371008672884, 0.06368353098098721, 0.06786714720406703, 0.03585578867101243, 0.04204805175374661, 0.009098493876600904, 0.040174138200070174, 0.027366927126422524, 0.05560926281447921, 0.048814335106206794, 0.007901126385799475, 0.016371335002726743, 0.03949256334453821, 0.013258273164475603, 0.032379328073667626, 0.04733866732567549, 0.011357973080261477, 0.02100942549960954, 0.07384852838835546, 0.03327782039663621, 0.032782215026340315, 0.022017516495127763, 0.0678653558716178, 0.03240733799923744, 0.0468879877589643, 0.0104661159816065, 0.030192321499011347, 0.022853064517091428, 0.046674581710249186, 0.02448803366028837, 0.04373115447482892, 0.04990089698029416, 0.04693393136507698, 0.018284864823466966, 0.051458470722926516, 0.023492778850985423, 0.0047772690554016405, 0.04114396830222436, 0.03520178269328816, 0.0034634747093410362, 0.03337970582236137, 0.029502041039190123, 0.015851639942931275, 0.010398578846694102, 0.04831995788429465, 0.03711624210700393, 0.03287020405488355, 0.011977969186513551, 0.0697858203202486, 0.05035399891702192, 0.0176672486787928, 0.03768419288098812, 0.04005179833620787, 0.023885487778378383, 0.018895690528942004, 0.031846684869378805, 0.018037548987194896, 0.012583779670032007, 0.023134744759382944, 0.03984001737886241, 0.044743749246533425, 0.06063272897154093, 0.06446893526507275, 0.02983980220077293, 0.06815544316279036, 0.0573156223233257, 0.10771136132201978, 0.004965688052055026, 0.039633681665041616, 0.01559529619823609, 0.04043816974652665, 0.060304928704031875, 0.06950843520462513, 0.06259169349712984, 0.034066956623324325, 0.05025993700006178, 0.017629216790997555, 0.010314670358119267, 0.061332495350922854, 0.02370899573101529, 0.9348160667078835, 21.263450554439, 67.43599155970982, 85.96230002811977, 93.04553685869489, 115.52999782562256, 94.45797361646379, 53.85083893367222, 33.81586115700858, 19.118640661239624, 19.803639241627284, 40.496891089848106, 61.2535400390625, 50.76006480625698, 54.162344047001426, 28.985631568091257, 8.296714527266365, 0.08498860097357205, 0.7592830743108476, 0.2678164690732956, 0.06365991796233825, 0.11294319879795824, 0.2296783769769328, 0.7247942249689783, 0.7620542656098093, 2.0394113659858704, 1.6467333797897612, 2.914931071656091, 2.9581597234521593, 3.5483670703002383, 3.1434175883020674, 3.5264628742422377, 4.7532882775579175, 4.07718208857945, 6.5828835879053385, 4.539833971432277, 5.626580434186118, 8.83465187890189, 8.019394551004682, 8.784164530890328, 13.183278373309545, 6.443391552993229, 14.43387942654746, 14.781917299543109, 15.036970036370413, 11.685343163354055, 7.654896395547049, 12.051549707140241, 11.695283429963247, 9.669896568570818, 13.604974968092781, 14.706657886505127, 8.232319491250173, 6.330849843365805, 4.807668353830065, 4.5243308033261975, 6.828607499599457, 2.937947630882263, 5.773240838732038, 3.1686994774000983, 1.6142451230968748, 1.188038713165692, 1.6051248524870192, 0.9866631988968168, 0.5396054621253694, 0.3595081546476909, 0.09491752247725214, 0.12370618911726133, 0.06510989301438842, 0.20868793688714504, 4.26533670084817, 29.32906539099557, 45.59682716642107, 69.4806935446603, 67.16321917942592, 41.00175762176514, 37.83141272408621, 13.823322977338519, 20.150529793330602, 38.04976681300572, 73.06859738486153, 86.94586617606026, 77.60229696546281, 74.5682201385498, 86.70774446214948, 82.55110972268241, 48.84575966426304, 11.874941263880048, 0.5482699743338993, 0.010289593400167567, 0.13187423082334654, 0.037930314495627365, 0.037769396523279805, 0.02581389108672738, 0.011832590514261807, 0.09181853769613163, 0.04443613539582916, 0.05680247003744755, 0.01981652870641223, 0.05901347300303834, 0.016105854784005454, 0.02258740279025265, 0.042381823129419766, 0.031695561550025425, 0.01650604116730392, 0.04492952874196427, 0.027307818244610513, 0.03227270647351231, 0.033217593628380976, 0.013063080691998559, 0.04750369722023606, 0.012178382985959095, 0.06661260380808796, 0.008403318634788905, 0.08255109284073114, 0.049904611959521256, 0.04391142426590834, 0.02114491367579571, 0.018315493894208754, 0.030769507134599344, 0.02966757644233959, 0.02989710448309779, 0.006599112255831382, 0.016861600302425877, 0.01795484744278448, 0.02277597615362278, 0.024080590344965458, 0.01986121871907796, 0.029806570948234627, 0.03711111577493804, 0.04938329689736877, 0.09612963029316493, 0.03246538667008281, 0.04949944852186101, 0.14720570242830686, 0.0877468322536775, 0.2025937560413565, 0.10908005466418606, 0.1441049331000873, 0.1107928127582584, 0.12809179164469242, 0.1049448112025857, 0.16053990620587552, 0.07086023302482707, 0.15042136130588396, 0.18879224519644464, 0.08768820682806627, 0.08107598485159022, 0.12030621298721858, 0.08144472113677434, 0.17645608500710555, 0.09943262341299228, 0.12103616738958017, 0.16707750968635082, 0.14224007459623472, 0.16493859088846616, 0.1565524408859866, 0.1810414618147271, 0.17195186098771437, 0.13330688966172083, 0.12447184803230421, 0.2205237996365343, 0.23777259407298906, 0.10986077027129275, 0.17546697093972138, 0.13763804653925554, 0.09074442354696137, 0.09902770764061383, 0.13696029862122877, 0.15090165553348406, 0.1324219714318003, 0.16755939168589457, 0.25931654231888907, 0.17336685077420302, 0.11597962943570954, 0.0733451232580202, 2.657075605222157, 39.815217222486226, 92.79867431095668, 92.65964780535016, 90.62173421042306, 110.59674903324672, 91.69697489057268, 47.46366916384016, 37.61155782427107, 48.3248427936009, 48.81888403211321, 76.55776732308524, 89.65118898664201, 67.60193538665771, 89.55043315887451, 37.41048737934658, 11.554308823176793, 0.7406235784292221, 1.110852260674749, 0.44511183404496735, 0.30313823372125626, 0.17219272734863417, 0.24225754769785063, 0.5854204722813198, 0.5920907429286412, 2.5941631410803114, 4.6597351261547635, 7.499215057918003, 8.61625349521637, 8.084167395319257, 12.872782485825674, 12.045659371784755, 11.465281554630824, 12.109192831175667, 12.970881496156965, 7.927790369306292, 13.870892081941877, 19.346854243959697, 19.215943234307424, 15.480412755693708, 21.522036450249807, 21.230259009769984, 29.77740137917655, 42.05796718597412, 34.149940967559814, 26.89798971584865, 19.374105078833445, 24.595242057527813, 27.86752050263541, 18.404864379337855, 18.502467461994716, 25.02667828968593, 11.521729588508606, 12.582311306680952, 12.25699143750327, 11.17660127367292, 14.813908542905535, 10.79746413230896, 9.393895881516592, 9.891945362091064, 4.51781165599823, 2.9872946058000838, 1.3168966386999403, 0.5159100964665413, 0.4665828804884638, 0.3769799428326743, 0.3412194103002548, 0.24711903397526058, 0.24754854664206505, 0.3144028106970446, 7.645266192299979, 45.016555309295654, 68.13759980882917, 96.13276740482875, 102.96352059500558, 106.1068925857544, 85.04679148537772, 60.75442314147949, 28.495971168790543, 29.625996657780238, 61.154285022190635, 76.43110861097063, 78.28438772474016, 79.73378889901298, 99.99484716142926, 97.00336974007743, 67.90616226196289, 24.02017787524632, 2.515744903257915, 0.3002898794199739, 0.12780291214585304, 0.2088193419788565, 0.1294059646981103, 0.17632687836885452, 0.16017121741814272, 0.23195288064224379, 0.09509997375841651, 0.1714640078800065, 0.1325786044555051, 0.19969851497028554, 0.11423245604549136, 0.11728944629430771, 0.17262963604714188, 0.08059791621885129, 0.13558163759963854, 0.1459183722202267, 0.11339183258158819, 0.0968506076772298, 0.12465883871274334, 0.10673526834164347, 0.07092535203056675, 0.08274174082492079, 0.1385727963809456, 0.0915476054485355, 0.14886591477053507, 0.10726888863635914, 0.1228741423359939, 0.13318798318505287, 0.14453836769929954, 0.12889723985322885, 0.08735307838235583, 0.14204316373382295, 0.0956158232209938, 0.1372636037745646, 0.08418255565421921, 0.10626159661582538, 0.14652832091919013, 0.10129142259912831, 0.15798142206455978, 0.0596637198967593, 0.16270470432937145, 0.16053784345941885, 0.08733198951397624, 0.10788832325488329], [0.04279185505583882, 0.025809434807992408, 0.01035477262589016, 0.08541948428111416, 0.04160496838656919, 0.01718634885868856, 0.015580202186746257, 0.03615267149039677, 0.005689589073881507, 0.02041108314214008, 0.04509228215153728, 0.01251896346054439, 0.038362334349325726, 0.059652354435196946, 0.011156651740228491, 0.07214206031390599, 0.026321436977013946, 0.03897966550929206, 0.02439543228995587, 0.07897144063775029, 0.05162189927484308, 0.07213427073189191, 0.045650061685591936, 0.03919435398919242, 0.030708835925906897, 0.06504868237035615, 0.03327175768624459, 0.007100879572265382, 0.05392186496672886, 0.0074622295796871185, 0.03088448489350932, 0.07111973874270916, 0.05360061256214976, 0.015035077330789395, 0.040576411078550985, 0.018678075866773725, 0.04886405136702316, 0.09185095809932266, 0.10776725903685604, 0.21689857702170098, 0.07453055786234991, 3.834138878754207, 34.07180847440447, 55.77793918337141, 54.89874887466431, 50.81349645342146, 37.06374447686331, 25.188354185649327, 22.540220260620117, 35.4119040625436, 58.470029149736675, 60.99811731066023, 68.35021468571254, 40.56383350917271, 33.080185890197754, 33.366521154131206, 4.270281212670462, 0.25726750226957457, 0.26004661885755403, 0.03836657858586737, 0.17417860935841287, 0.13490547745355538, 0.11281882332903997, 0.06845051090099982, 0.2080652860126325, 1.454969938312258, 1.453459465077945, 1.715169444680214, 2.991997016327722, 4.315257336412158, 5.675052804606302, 8.698623520987374, 5.162881110395704, 6.469390843595777, 5.385029784270695, 4.685174218245915, 8.765536410467965, 7.0851441110883435, 5.835801550320216, 3.3981044590473175, 5.703674171652112, 7.565300243241446, 14.927028690065656, 9.340538927486964, 10.824510863849095, 10.08822762966156, 14.803593942097255, 9.044882655143738, 9.86683544090816, 8.27765040738242, 5.9833343880517145, 14.63092599596296, 13.43818085534232, 5.372452676296234, 9.58840983254569, 10.543129665510994, 8.331377352987017, 6.008006138460977, 9.522191762924194, 5.470632459436144, 5.719647645950317, 5.052832067012787, 6.201375808034625, 2.970520568745477, 0.3033690984760012, 0.9910425181899751, 0.5160161650606564, 0.22886405353035244, 0.08749309408345393, 0.1131154652684927, 0.03632692267586078, 0.10832254495471716, 0.15746464979435715, 0.145608268146004, 5.893296590873173, 25.106839656829834, 42.675589084625244, 48.01070778710501, 47.43206875664847, 101.89036437443325, 97.38380445752824, 58.7483183997018, 16.348178488867624, 16.066997051239014, 44.68368101119995, 48.2376081602914, 56.136163984026226, 59.28622014181954, 58.63466671534947, 62.10209574018206, 28.476002046040126, 3.0675680126462663, 0.3195012956857681, 0.10330347570457629, 0.04194804247734802, 0.0249136888555118, 0.026205287048859254, 0.03778393413605435, 0.04421565901221974, 0.030256412524197782, 0.011092302023566194, 0.012404747357192849, 0.056637511389063935, 0.08324520702340774, 0.05059766762756875, 0.03390559081786445, 0.0280858485493809, 0.059552345158798356, 0.024933441009904658, 0.05099902109109929, 0.08378914783575706, 0.04744316850389753, 0.03727701758699758, 0.04183921903105719, 0.03202781639993191, 0.02929000902388777, 0.07341460524392979, 0.03129480858998639, 0.005667191905169082, 0.04661092155479959, 0.013891840819269419, 0.02749898361175188, 0.04800101589145405, 0.055893731835697374, 0.028892543566014086, 0.02708149458547788, 0.019805073338959898, 0.06087937645081963, 0.001846526183986238, 0.030952307861298323, 0.0446252329275012, 0.023238029663584063, 0.02287518136602427, 0.01618115181502487, 0.07732500255640064, 0.016807107155078223, 0.022686959144526293, 0.022055217597101415, 0.015965978182586174, 0.05174414414380278, 0.06104824346091066, 0.044069356684173853, 0.016135067412895814, 0.0503715288692287, 0.02435507472338421, 0.01305668634761657, 0.007408599019981921, 0.026548410333426933, 0.07089282984712295, 0.052088324246662, 0.04034118673631123, 0.019131645992664353, 0.05030679323577455, 0.06123390421271324, 0.021379057451018264, 0.04690345496471439, 0.08124104528022663, 0.016064021403768232, 0.03924871142953634, 0.03356426056208355, 0.045668354989694696, 0.021253216346459727, 0.02873568662575313, 0.037217672914266586, 0.06104010782603707, 0.029768427102161304, 0.03828894739438381, 0.07427937098379646, 0.03604235526706491, 0.06937432954353945, 0.04791405484346407, 0.010786432856028634, 0.10656374147427933, 0.0753525419692908, 0.07976838001715285, 0.06395954545587301, 0.08444790355861187, 4.636409154960087, 45.852757113320486, 77.3876462663923, 74.9858068738665, 69.37924289703369, 42.44934531620571, 54.22058732169015, 51.58523981911795, 17.271469014031545, 28.75885452542986, 40.651234899248394, 45.50308207103184, 40.32494401931763, 43.731829915727886, 41.48117637634277, 6.938211424010141, 0.14476119859942368, 0.41262954846024513, 0.048987921327352524, 0.27146283483930994, 0.32249987764017923, 0.6278755398733276, 0.6395734835948262, 1.502650756921087, 2.3097759783267975, 1.719343357852527, 2.3196491513933455, 1.3199588400976998, 0.8311898186802864, 0.6907669965709958, 1.9581285161631448, 1.4870031965630395, 2.9521745017596652, 3.027857320649283, 0.9279908729451043, 1.773257036294256, 4.509215865816389, 2.977378006492342, 5.863451038088117, 11.066494907651629, 11.139445781707764, 20.78512266704014, 15.306752954210554, 15.596216644559588, 10.563184772218976, 9.643878170422145, 6.5118135043552945, 7.041105559894016, 4.796754905155726, 7.9747593232563565, 13.973321557044983, 16.09020577158247, 7.780538065092904, 4.534518165247781, 4.422524929046631, 2.0201468339988162, 3.844599825995309, 5.875659891537257, 3.839507664952959, 3.7658880267824446, 3.989377702985491, 2.7753919192722867, 2.2753769670213972, 3.4681772589683533, 2.7389592570917944, 0.5676898094160217, 0.17867900644029888, 0.21160699453737053, 0.1847307924181223, 0.10742598306387663, 0.15626155292349203, 0.21015852583306177, 0.1301346705960376, 7.448171854019165, 28.816691330501012, 46.604583467756, 46.85426351002285, 34.22003786904471, 70.86095319475446, 44.04262631280081, 28.40538055556161, 25.697794369288854, 36.26088012967791, 70.2015552520752, 73.84143161773682, 71.0327821459089, 72.5675836290632, 76.32469000135148, 77.56413051060268, 36.42749098369053, 2.845626699072974, 0.25929010659456253, 0.05730760882475546, 0.06033823798809733, 0.05071485401796443, 0.02139531006105244, 0.029931947256305387, 0.0621463641790407, 0.025997891124071817, 0.03321384132972785, 0.09123136063239404, 0.011613015734058405, 0.03102116220231567, 0.034043068797992806, 0.045338783745786974, 0.01997502600508077, 0.03091227090252297, 0.04833786442343678, 0.09076271006571394, 0.04653417245884027, 0.03738987831664937, 0.04832868045195937, 0.013724931382707186, 0.015166641878230231, 0.05474141652562788, 0.009687180680754994, 0.03972181657861386, 0.06413029879331589, 0.028595962694713047, 0.01539652275719813, 0.06559100826936108, 0.03945338133988636, 0.05329773149320057, 0.05024174547621182, 0.07292196846434049, 0.04870757440637265, 0.02789973487545337, 0.08183408488652535, 0.04376340524426528, 0.01725649750525398, 0.04557912424206734, 0.009852458240597375, 0.02281749401507633, 0.05060139957017132, 0.016438109633911933, 0.11052555138511316, 0.07732709922960826, 0.11401049367019109, 0.10442016792616673, 0.17635317838617734, 0.20810910580413683, 0.09904626557337386, 0.1190850128020559, 0.07442168013325759, 0.14960213883646897, 0.09874469068433557, 0.07837227386023317, 0.18107046240142413, 0.11520875937172345, 0.10931690409779549, 0.1806969695857593, 0.12095867869045053, 0.19967794178852014, 0.08073741623333522, 0.10753364621528558, 0.16948529120002473, 0.13668083718844823, 0.10698166476296526, 0.1289775376873357, 0.13755580809499535, 0.16672372152762754, 0.19100148736366204, 0.1291056586695569, 0.1469894533178636, 0.10924117280436413, 0.0985798609576055, 0.23157490949545587, 0.1243986069623913, 0.10750934109091759, 0.126310189387628, 0.05937690314437662, 0.1585961069379534, 0.1762873740600688, 0.25810606298702105, 0.38826094035591396, 0.2535516545176506, 10.186517715454102, 74.08907931191581, 99.11757455553327, 84.9937002999442, 83.80273737226213, 59.01041834694998, 36.01528910228184, 36.376230648585725, 56.15445164271763, 98.12266199929374, 90.3888931274414, 99.90246391296387, 65.32094601222447, 52.94686787469046, 57.31598547526768, 6.940546887261527, 0.7354333283645766, 0.6917253051485334, 0.12208288908004761, 0.349786674869912, 0.5111910754016468, 0.44545940682291985, 0.31330409965344835, 1.1415697038173676, 3.631654041154044, 6.31106528214046, 6.746483266353607, 6.968507306916373, 9.263349652290344, 11.240218111446925, 16.91137514795576, 13.626251220703125, 18.10115167072841, 17.418703079223633, 15.814852135522024, 26.48935920851571, 22.5938047681536, 18.11191269329616, 13.864696025848389, 15.48754334449768, 19.02482087271554, 28.930480241775513, 23.909520864486694, 25.821769339697703, 28.25547664506095, 37.032317774636404, 22.243683304105485, 27.2221040725708, 21.40148173059736, 24.905307156699045, 37.31670754296439, 33.015675340379985, 18.281943798065186, 28.656330381120952, 26.797166143144878, 26.849084820066178, 23.444662060056412, 30.54819631576538, 21.757257291248866, 20.345298222133092, 28.76024763924735, 20.553881406784058, 17.371929543358938, 12.733672601836068, 7.459129163197108, 1.2568217537232806, 0.47196442314556664, 0.2231679963214057, 0.17619156491543564, 0.12945905327796936, 0.23812849926097052, 0.47494232335260933, 0.3533513993024826, 11.286625129835945, 41.75164195469448, 62.7763489314488, 70.2047027860369, 70.60731615339006, 128.9495470864432, 113.99225030626569, 84.30939306531633, 24.154825278690883, 23.00710620198931, 60.124388286045615, 68.99182523999895, 75.31561701638358, 79.0401085444859, 83.65208653041294, 95.18857669830322, 54.816193853105815, 7.826913816588266, 0.44627430023891584, 0.16475424649459974, 0.2147773408464023, 0.13424508646130562, 0.13784353408430303, 0.14552867598831654, 0.14319317202482904, 0.13830192520150117, 0.11036180731441293, 0.3058358175413949, 0.09866007058215992, 0.21891440956720284, 0.0996735847688147, 0.21031374750392778, 0.10959911359740154, 0.23532571537154062, 0.10824834036507777, 0.20266310232026236, 0.21589218745274202, 0.09850740698831421, 0.12337639395679746, 0.11408665244068418, 0.12530035286077432, 0.16639608410852297, 0.15027603267558984, 0.1548891072826726, 0.19451267538326128, 0.16718306259385177, 0.0909403980310474, 0.19250494454588207, 0.22188975848257542, 0.12057933690292494, 0.15787425424371446, 0.09777056545551334, 0.182016665914229, 0.08956436293997935, 0.14753764175942966, 0.15474289655685425, 0.11083717537777764, 0.08153563804392304, 0.09693298861384392, 0.11841688651059355, 0.16976558044552803, 0.1380932621125664], [0.04929714330605098, 0.046909622848033905, 0.027502946256260787, 0.014100838086700864, 0.038153203071228096, 0.04839052891890917, 0.028727082801716666, 0.10948258877864905, 0.018633053371948854, 0.02591956952320678, 0.039896634340818436, 0.009234590189797538, 0.06409867227609668, 0.02075924794189632, 0.032001923503620286, 0.013226662762463093, 0.058026360613959174, 0.013070866033168775, 0.033333524728992155, 0.02818938620787646, 0.04046975555164473, 0.044909386429935694, 0.05224312861849155, 0.04899760741474373, 0.05189443625775831, 0.05569058862913932, 0.039130744723869224, 0.0562459932906287, 0.008456020449687327, 0.035262674425861666, 0.024505421120141233, 0.0704650203032153, 0.12550684463764938, 0.017495911801233888, 0.10274834584976945, 0.09270211242671524, 0.0971341606761728, 0.19604042411914893, 0.11209320476544754, 2.279478141239711, 14.009840420314244, 43.30442190170288, 57.168058327266145, 44.09325783593314, 74.74251570020402, 66.51598753247941, 117.41475922720772, 94.13643183026994, 29.631638595036097, 52.18412242616926, 44.03678635188511, 32.34473296574184, 35.305568831307546, 32.35260527474539, 11.262441056115286, 0.5169965124555996, 0.10381523360099111, 0.07613914726035935, 0.10994268980409418, 0.18551771662064961, 0.129061526751944, 0.0775854242965579, 0.4722774720617703, 0.4152482050870146, 0.6189893909863063, 0.6274237441165107, 2.8185864814690182, 2.4028566522257666, 2.677005861486707, 6.715182065963745, 13.940598147256033, 18.58252113206046, 26.249165194375173, 22.942248242241995, 16.02962269101824, 5.2140246289117, 4.043283998966217, 4.565848895481654, 4.343022337981632, 5.918631894247873, 5.855562661375318, 8.387351172310964, 12.963912452970233, 3.551570841244289, 8.98413976601192, 7.398018019539969, 9.212732894080025, 5.227805512292044, 3.246380989040647, 6.9043285335813245, 7.958155734198434, 6.889337360858917, 14.835150923047747, 12.492858460971288, 6.0698073250906805, 2.812219977378845, 3.8062518494469777, 7.094519836562021, 13.671787977218628, 8.201552867889404, 15.12433842250279, 12.082069669451032, 16.59701779910496, 21.68447491100856, 21.947316578456334, 16.851813452584402, 3.429958475487573, 1.455797208206994, 0.7809207960963249, 0.27958932306085316, 1.1821232991559165, 0.3773807127560888, 0.053210675450307984, 0.15868916123041085, 0.2693892589637211, 0.32192491420677727, 12.006601810455322, 38.838526317051475, 57.069435596466064, 41.83954014096941, 96.714248248509, 117.96174921308244, 77.02511705671037, 40.70883893966675, 25.83844154221671, 25.128181048801967, 45.543218340192524, 52.3392722266061, 53.032570430210654, 55.436393533434185, 65.9636891228812, 50.55841418675014, 13.419095022337777, 0.2880070927952017, 0.018568789320332662, 0.05478314303659967, 0.04986501944118312, 0.050225674374295134, 0.016780975075172525, 0.018039255502766798, 0.0066004939227631045, 0.011658250271076602, 0.010632816768650497, 0.0660409719816276, 0.03672340425795742, 0.005641854135319591, 0.07122832470174346, 0.0353795792242246, 0.04042502652321543, 0.02630575094372034, 0.0030175205029081553, 0.011838102763119553, 0.030656103576932634, 0.03995551082438656, 0.023744176075394665, 0.04499547216775162, 0.019903221733069847, 0.021119521199060336, 0.02068343013525009, 0.01935077378792422, 0.029528731214148656, 0.009507865079545548, 0.02967350683840258, 0.036025262969945154, 0.0393111875413784, 0.04413336628515806, 0.02415243024006486, 0.011061606795660086, 0.03264428921309965, 0.026817217070077146, 0.017534279563863362, 0.03882892556222422, 0.007565286326488214, 0.023273696856839315, 0.028007552393579056, 0.024088946503720114, 0.008052517726485218, 0.01664090169859784, 0.03294187092355319, 0.049915573692747524, 0.015427869378722139, 0.05052206525579095, 0.04169124072151525, 0.01135053379195077, 0.021318393027676002, 0.024268191706921374, 0.04980504373088479, 0.01697991306095251, 0.037054804153740406, 0.014135670681883181, 0.0421710565819272, 0.01750852237455547, 0.023800682775410156, 0.03636647787477289, 0.031179094620581185, 0.03879306159381356, 0.07512118866933243, 0.041734317517174144, 0.06639131318245615, 0.00351900007808581, 0.04601097446201103, 0.038494780992290804, 0.03833366285211273, 0.013643850688822567, 0.04616340056860021, 0.06327093419219766, 0.03877313641299095, 0.040485137940517495, 0.13713474997452327, 0.03678435705868261, 0.05433070606419018, 0.09882764837571553, 0.09067317737000329, 0.09408237479094948, 0.11846621600644928, 3.595580513988222, 20.48935522351946, 63.54957226344517, 80.58114950997489, 71.96857248033795, 102.26210689544678, 83.4353722163609, 101.96809387207031, 72.4133961541312, 20.28037772859846, 36.27906009129116, 40.684412547520225, 37.56325394766671, 44.2638395854405, 40.999266692570274, 14.26178731237139, 0.5822543193187032, 0.3802864168371473, 0.03899632354399987, 0.04100038350692817, 0.3544861541262695, 1.049238241144589, 1.0309210526091712, 1.4647866572652544, 2.234310507774353, 0.5967840882284301, 0.6257075390645436, 0.8842964747122356, 0.3063632020992892, 3.561161960874285, 10.210421255656652, 20.305542366845266, 30.188335214342388, 37.08065986633301, 32.57432229178292, 22.84680257524763, 10.656747477395193, 4.538539869444711, 1.771647876926831, 1.3301131980759757, 1.150544822216034, 2.632254468543189, 6.337721177509852, 8.158705932753426, 9.169938938958303, 7.458912031991141, 0.7064715538706098, 1.7391818761825562, 3.056560980422156, 2.654704315321786, 1.7803852366549628, 2.670101306268147, 0.8844429839934621, 0.9781798826796668, 1.8973491489887238, 2.2361496090888977, 1.4235714631421226, 7.164270196642194, 13.422236476625715, 19.78431109019688, 17.99031921795436, 23.678774663380214, 20.678202050072805, 25.795397451945714, 32.55869231905256, 34.66294036592756, 26.64929805483137, 9.64405882358551, 1.1734616096530641, 0.9441235044172832, 0.49823024230343954, 3.4432586303779056, 1.1367280036211014, 0.16047233768871852, 0.20477350907666342, 0.513687432876655, 0.3745102382131985, 13.788496868950979, 46.5668443271092, 56.95353616986956, 47.72610609872, 95.68328843797956, 86.77594797951835, 37.74822889055525, 29.118359531675065, 37.429622718266074, 47.48724440165928, 70.55962371826172, 82.64796761104039, 69.10980565207345, 71.98692962101528, 78.90049144199916, 62.24875136784145, 14.614259004592896, 0.12258834338613919, 0.019376731145062616, 0.04870830722419279, 0.05888792366853782, 0.02524536695065243, 0.07651472996388163, 0.03896973514929414, 0.026970667764544487, 0.014860946585291197, 0.010339703211294753, 0.055066204097654135, 0.031796564880226336, 0.022446296344112073, 0.005643061079484011, 0.023637613847053478, 0.027798522895734225, 0.0322957529154207, 0.07509959768503904, 0.05655084889648216, 0.03472745618117707, 0.07285405389432396, 0.011063554191163607, 0.0714066301339439, 0.0345921970105597, 0.031509700630392344, 0.056213993579149246, 0.04087336514411228, 0.041400875230985026, 0.034605716820806265, 0.032248767758054395, 0.0825037243110793, 0.022264874739838496, 0.01959004728788776, 0.01448185246304742, 0.03295017619218145, 0.04774491302669048, 0.026526045819212283, 0.027455363988078067, 0.0455443527150367, 0.08196299975471837, 0.04564829410186835, 0.02078407723456621, 0.04512449220887252, 0.08413249334054333, 0.07447641755321197, 0.1743201653340033, 0.15284264566642897, 0.06737090740352869, 0.12408371243093695, 0.07189050024109227, 0.2177177316376141, 0.13209322121526512, 0.11913409802530493, 0.14665994314210756, 0.07196345632629735, 0.1850001301084246, 0.13664292065160616, 0.1670917724924428, 0.13868890729333672, 0.14158250630966254, 0.1133171801588365, 0.05787816856588636, 0.10051595885306597, 0.14179947466722556, 0.12839288477386746, 0.18391370054866585, 0.1182805145425456, 0.20787308418325015, 0.17033356853893825, 0.11097531832222428, 0.17838537719632896, 0.174688012738313, 0.2094124901507582, 0.12609528377652168, 0.15090018989784376, 0.2992124743759632, 0.11355643160641193, 0.1979790800916297, 0.16363714715199812, 0.21188907511532307, 0.33064761757850647, 0.2561995152916227, 7.029022642544337, 37.82859870365688, 91.30676405770438, 92.24338817596436, 70.87481485094342, 109.31902394975934, 94.46648515973772, 136.10095269339425, 124.05361012050084, 51.369310651506694, 79.34220232282365, 68.85690511975969, 51.037495953696116, 59.51716436658587, 52.81354584012713, 19.66060883658273, 0.6976142834339822, 0.38467433995434214, 0.12459878836359296, 0.19006149923162802, 0.41139583608933855, 0.6176376949463571, 0.4964313102619988, 0.8507132796304566, 3.7976304377828325, 7.834097385406494, 6.2810303909437994, 7.900848729269845, 9.795671122414724, 7.443553039005824, 12.453586374010358, 18.734900338309153, 26.02275119509016, 34.04600286483765, 29.53368636540004, 22.741943836212158, 15.286835942949567, 18.341300521578106, 18.023529870169504, 16.630148547036306, 21.000386544636317, 16.225249222346715, 19.27951577731541, 30.283511638641357, 19.373995644705637, 25.64829366547721, 26.665186847959244, 24.606386968067714, 21.802175658089773, 14.47084297452654, 20.98482084274292, 25.161900656563894, 18.791988474982126, 35.30591624123709, 28.99049357005528, 25.51072801862444, 16.46749816622053, 15.195491450173513, 14.36835617678506, 22.678756918225968, 16.394936391285487, 24.344519785472325, 18.885217666625977, 21.07314808028085, 25.663543224334717, 29.508905615125382, 24.806649684906006, 9.493268149239675, 5.212448256356375, 1.3191711966480528, 0.5933857134410313, 3.3070040217467715, 0.7952340309109006, 0.16621814508523258, 0.412027362201895, 0.4122304341622761, 1.1192912821258818, 21.62712447983878, 62.35387066432408, 86.78029755183628, 54.499769415174214, 112.0782230922154, 137.59638568333216, 106.7457447052002, 59.186485699244905, 36.58794920785086, 34.014298234667095, 64.57559885297502, 74.81441565922329, 75.51498862675258, 78.05561828613281, 91.26256656646729, 85.38220882415771, 27.794500146593364, 0.44785848951765467, 0.09623731380062443, 0.14755949058703013, 0.1250064250613962, 0.1541457585990429, 0.12418252070035253, 0.24656396518860543, 0.12548578291067056, 0.09711706159370286, 0.08677301236561366, 0.13401704441223825, 0.08214836195111275, 0.1600419022142887, 0.1519965667809759, 0.14049807164285863, 0.16850459096687181, 0.15479517089469091, 0.1540677813546998, 0.09500744193792343, 0.15383551881781646, 0.12924485334328242, 0.07736575536962066, 0.15046891303999083, 0.11697692663541862, 0.13168687373399734, 0.12903457534100327, 0.07845216457332883, 0.09917076317859547, 0.1322963610291481, 0.056472420426351685, 0.1481680822159563, 0.1143468434789351, 0.13014518788882665, 0.0325814568703728, 0.10117030409829957, 0.10692543456596987, 0.13604604053710187, 0.0928639362433127, 0.0929453604455505, 0.18817385552184923, 0.14892747146742685, 0.12252069344477994, 0.15435833004968508], [0.029241931425141435, 0.03236471921471613, 0.023760255658999085, 0.022537784917013984, 0.0492254934007568, 0.05370877104412232, 0.034399839118123055, 0.051940033811011484, 0.020119477628863285, 0.016620845899784138, 0.029957314287977557, 0.006973542297990727, 0.032393472136131356, 0.02823037650835301, 0.032137437124869654, 0.006766786316542753, 0.031435004102864435, 0.07503044818128858, 0.05492747761309147, 0.059292323754302094, 0.011623989341647496, 0.02816964253517134, 0.007865188626705535, 0.017450721368991902, 0.017036816703953912, 0.05390254368207284, 0.01761826184312148, 0.061155601271561215, 0.04787920867758138, 0.02633725871731128, 0.04959294046940548, 0.020888843041445528, 0.053437988074230294, 0.06958761345595121, 0.014534045376681855, 0.01821860927157104, 0.11686890386044979, 1.0382650813886096, 15.463016203471593, 44.168743065425325, 71.47226960318429, 59.120602880205425, 64.9633708681379, 60.36548382895333, 28.96233078411647, 20.11337082726615, 39.01271765572684, 86.40225996289934, 63.49311120169503, 35.38884646551949, 33.409363746643066, 29.204855918884277, 16.30259656906128, 1.567750709397452, 0.5048613750508854, 0.12061536711241518, 0.07420628597693783, 0.17167068964668683, 0.038058425299823284, 0.08192974475345441, 0.4571022263595036, 0.248642697930336, 1.1334817835262843, 2.687389510018485, 3.1075935448919023, 1.658243722149304, 3.289402497666223, 26.65071027619498, 63.81445843832833, 96.24593271527971, 115.11589213779995, 119.6479241507394, 120.93303516932896, 124.66802542550224, 119.46996688842773, 97.60782132829938, 65.68126569475446, 33.048793928963796, 5.652680907930646, 2.0479196522917067, 6.473201061998095, 6.723925505365644, 9.336401275226049, 16.304644550595963, 13.339486036981855, 6.889937511512211, 4.196933422769819, 5.029392753328596, 9.417730808258057, 3.0951074148927415, 1.2682504547493798, 5.246536552906036, 6.357534834316798, 3.1936037753309523, 6.1562203339168, 42.049771785736084, 81.3466464451381, 104.10546398162842, 114.38042531694684, 123.57102993556431, 122.50463431222099, 115.8872047151838, 125.38261985778809, 133.7363278525216, 131.64732415335519, 127.81679616655622, 115.27745859963554, 64.53385407584054, 9.922645977565221, 3.9697946395192827, 5.654868721961975, 8.726990410259791, 0.6063714623451233, 0.03371827104794128, 0.15128338576427527, 0.01690429202946169, 0.41965064885360853, 2.053352926458631, 15.383711201804024, 35.38485819952828, 28.908034086227417, 53.30951867784773, 83.94781575884137, 93.38166986192975, 46.03541135787964, 36.51999235153198, 26.1033433505467, 20.958177975245885, 31.582116058894567, 57.14223187310355, 56.821826117379324, 53.06970855167934, 61.657675061907085, 19.918110813413346, 1.1721503543002265, 0.10513175438557353, 0.05635148512997797, 0.0737379611070667, 0.048208172632647414, 0.09083063142108065, 0.10869331684495721, 0.03290246839502028, 0.07193834374525718, 0.03581635221572859, 0.08007108805967228, 0.05453678732737899, 0.024650666629895568, 0.02436868443952075, 0.03381471462281687, 0.015658796897956302, 0.017105710060734833, 0.02857404262093561, 0.08418271171727351, 0.0361761013045907, 0.029811832987304245, 0.053319926373660564, 0.02880678352500711, 0.055714086296835115, 0.03504031171490039, 0.04912273266485759, 0.017884591926953623, 0.018217370945162008, 0.03837204079276749, 0.03373217762314847, 0.049800171849450896, 0.0448126409069768, 0.08098421299031802, 0.03461469044642789, 0.03267481989626374, 0.04000255026455436, 0.04411348520911165, 0.03538383363879152, 0.032210959786815305, 0.017262146309284226, 0.0737641661294869, 0.06679927557706833, 0.05968197927411113, 0.021822946578530327, 0.11049249315900461, 0.01457454204293234, 0.04503662531663265, 0.06803420252565827, 0.07798332401684352, 0.010401762872269111, 0.014819630588005697, 0.07318380834268672, 0.028236719114439826, 0.034142423288098404, 0.03456896397152117, 0.05370621296710201, 0.03796941846875208, 0.02201623745661761, 0.02717241658163922, 0.05163729523441621, 0.03719371045008302, 0.0961465190297791, 0.03504700885553445, 0.031231806613504887, 0.06893288823110716, 0.06054058391600847, 0.015268340706825256, 0.02957717182912997, 0.04003773569794638, 0.04893134847017271, 0.05190062110445329, 0.027211383151422654, 0.018839835222544413, 0.01716984519069748, 0.04568350328398602, 0.037503933267933984, 0.11693829085145678, 0.059444885567895005, 0.1271999523575817, 1.4249938896724155, 24.051998887743267, 62.29393550327846, 96.41694177900041, 85.08918244498116, 95.88167340414864, 92.70670100620815, 64.1946221760341, 45.36865527289254, 73.18930149078369, 82.93394156864711, 43.1353166443961, 41.9023449080331, 38.09179994038173, 38.28168378557478, 21.17305449077061, 1.620321431330272, 0.8167799604790551, 0.12018867715128831, 0.07343954819121531, 0.2881780836199011, 0.31317829926099094, 0.46198800419058117, 1.6112051776477267, 1.5279708611113685, 0.17653311230242252, 0.3913762574749333, 1.3830985320465905, 1.1185620469706399, 6.135273252214704, 33.99316528865269, 77.12266976492745, 108.83781255994523, 127.79176875523159, 129.81049837384904, 129.4648949759347, 132.2712584904262, 127.70169230869838, 112.83131749289376, 81.58872168404716, 44.94307810919625, 11.786453349249703, 3.1107310908181325, 0.36347267191324917, 0.7547196820378304, 5.187521593911307, 5.171750920159476, 1.4506590153489793, 1.2305177194731576, 3.3641714113099233, 5.90074679681233, 11.503266487802778, 3.8023122208459035, 1.5273552941424506, 1.9703664651938846, 2.517040090901511, 4.369093716144562, 10.50848160471235, 53.87964269093105, 94.8916106905256, 117.01589093889508, 126.34494536263603, 133.8979846409389, 132.0296140398298, 123.38016292027065, 132.54882512773787, 137.21228926522392, 139.7685593196324, 136.9798720223563, 131.00563022068567, 79.40246404920305, 18.306316341672623, 1.9105101227760315, 5.795332636151995, 6.897328657763345, 1.2001243446554457, 0.1106911071443132, 0.16231358317392214, 0.10038682685366698, 0.580862996833665, 2.367812761238643, 18.57404954092843, 44.72441482543945, 33.11599690573556, 56.21298326764788, 72.24748706817627, 61.338266372680664, 29.42317874091012, 25.18811447279794, 46.00028126580374, 41.69242593220302, 60.025904519217356, 78.29929855891636, 72.02531841823033, 66.881393296378, 78.0025132043021, 26.391115154538834, 0.5963608452251979, 0.05957314904247012, 0.057545163934784274, 0.04330158752522298, 0.03931236479963575, 0.04855574880327497, 0.06592588565711464, 0.029400321854544536, 0.03208117639379842, 0.01578383393851774, 0.04791707432429705, 0.05029847778912101, 0.026605205410825353, 0.020131862589291165, 0.04415039412145104, 0.019860587681510618, 0.08809842195894037, 0.01436352274114532, 0.03780859209863203, 0.02584808925166726, 0.021328956121578813, 0.02968933366771255, 0.035618186063532314, 0.04058784439361521, 0.03736109146848321, 0.023490468439246927, 0.020003938382225375, 0.010554286518267222, 0.019617792584800293, 0.00974396218745304, 0.021141241105007272, 0.004820852631902588, 0.025157362655071274, 0.06739901232400111, 0.05743275103824479, 0.005597591599715608, 0.05342721972348435, 0.017600394319742918, 0.04504904250747391, 0.013807680424568909, 0.09121766779571772, 0.022911420225032737, 0.128758398017713, 0.15124631061085633, 0.11613816235746656, 0.14387936091848783, 0.12278279795178346, 0.1647194376481431, 0.15843570125954493, 0.11733783941183772, 0.09340450473661933, 0.12590199629110949, 0.13582558450954302, 0.12169096725327627, 0.1120946364743369, 0.13079411163926125, 0.14865076488682202, 0.13282503480357782, 0.12902209029666015, 0.1733423556600298, 0.11923871455448014, 0.1743818305964981, 0.19247032568923064, 0.09993988262223345, 0.15556145406195096, 0.17767075768538884, 0.12359492294490337, 0.1257135806871312, 0.10536398299570594, 0.13990902182246956, 0.18642476866287844, 0.2181454665426697, 0.16847934946417809, 0.13369374961725303, 0.12592480863843644, 0.2280299168612276, 0.1605689882167748, 0.3662078465734209, 0.29466867819428444, 4.192792730672019, 42.50924573625837, 87.24519457135881, 116.50933252062116, 92.0118533543178, 93.10590280805314, 85.16461903708321, 39.02141332626343, 30.96159676143101, 48.74857521057129, 122.2731203351702, 121.77872821262905, 52.260368483407156, 58.58569581168038, 46.73158611570086, 29.15722601754325, 2.3002020120620728, 0.9156934299639293, 0.13802862486668996, 0.25297283700534273, 0.275293409292187, 0.1303817659084286, 0.209043896357928, 0.9247435671942574, 3.719373311315264, 4.542449533939362, 8.141325882502965, 10.53239904131208, 6.405463942459651, 6.458863454205649, 32.72377109527588, 76.8672261919294, 107.83115059988839, 132.1006246294294, 134.72408376421248, 135.8588079724993, 139.29776327950614, 133.99402264186313, 110.18136487688336, 74.98254122052873, 41.552273818424766, 9.369028278759547, 11.605770656040736, 20.37307017190116, 21.18934280531747, 25.909738745008195, 34.276835918426514, 29.306942326681956, 14.897102798734393, 9.923873203141348, 8.835306746619088, 14.824108498437063, 5.0903367059571405, 8.427705441202436, 20.52892347744533, 21.341388498033794, 11.29234002317701, 8.358550020626613, 47.64931460789272, 87.61150360107422, 115.23386560167584, 125.75301442827497, 135.09515925816126, 132.142911366054, 123.83125386919293, 138.06210953848702, 147.73750386919295, 144.3601929800851, 138.65876524788993, 129.79020963396346, 72.2697560446603, 14.420016033308846, 6.396310559340885, 8.21781165259225, 12.33413120678493, 1.1555574046713966, 0.1492031059627022, 0.24520475098064967, 0.26001361491424696, 0.7917496178831372, 3.8015344568661282, 25.50818497794015, 62.93019594464983, 43.87093979971749, 69.69124480656215, 108.8529804774693, 131.932311466762, 66.89554677690778, 55.30844940458025, 39.167874404362266, 31.112414360046387, 48.3766450881958, 82.21224607740129, 80.02584253038678, 75.98426301138741, 94.1375435420445, 41.054390226091655, 1.9995135068893433, 0.25123871862888336, 0.10419205802359752, 0.15571373089083604, 0.09696644039026328, 0.13740114282284463, 0.28479618366275516, 0.20372741163841315, 0.19422200455197267, 0.10750236575092588, 0.10619431986872639, 0.32975784103785244, 0.08680824868913208, 0.11407868643956524, 0.1010295148672802, 0.07240955917430775, 0.16724250226148538, 0.12006381313715662, 0.11654989740678243, 0.1344115175306797, 0.12596751563251019, 0.0910565225141389, 0.13300293311476707, 0.13951224168496473, 0.16225860826671124, 0.11609735526144505, 0.1103469677535551, 0.10188212804496288, 0.12218160235456058, 0.1625626055257661, 0.12508958631328174, 0.14826463774910995, 0.16410572986517633, 0.16834618018141814, 0.14871156162449292, 0.16420069762638637, 0.1406872607767582, 0.16688445290284498, 0.1687737386673689, 0.16652796417474747, 0.1935069914907217, 0.15327054341988905], [0.060525920774255476, 0.03771990078634449, 0.07231740054807492, 0.05725696297096355, 0.010506605862506797, 0.025043684290722013, 0.04936324279489262, 0.026468020897092562, 0.02956347559977855, 0.06364488841167518, 0.07758300871189151, 0.02392070713852133, 0.03937349062679069, 0.08765021565237216, 0.019910404026242237, 0.03752870997413993, 0.09701878258160182, 0.02276240036423717, 0.02690960979089141, 0.0345179924209203, 0.04159175391708102, 0.012057649553753436, 0.022388581851763383, 0.05847189349255391, 0.021147008652665784, 0.05836316504116569, 0.0531983668250697, 0.023698602270867144, 0.06374097575566598, 0.08210654383791344, 0.09143262768962554, 0.029245666760419096, 0.05150247371888586, 0.030313667309071337, 0.08015550460134234, 1.2965019387858254, 9.78375061920711, 43.46658590861729, 66.05598899296352, 72.63368879045758, 52.50617490495954, 39.08264780044556, 23.15606689453125, 41.51565333775112, 30.839145183563232, 37.67394917351859, 25.75930850846427, 35.02126244136265, 30.890141487121582, 35.49013730457851, 24.72826358250209, 4.787182458809443, 0.3074674499886376, 0.15444573893078736, 0.24341572555048124, 0.16702953726053238, 0.15636431026671613, 0.05337283853441477, 0.35622876776116236, 0.6722462475299835, 2.1355785599776675, 3.2853158712387085, 5.450128759656634, 1.8672686602388109, 10.022799917629786, 45.61441305705479, 90.43034608023507, 111.26285893576485, 107.55781541551862, 102.44713742392403, 91.83634880610875, 88.09322915758405, 87.65993254525321, 88.24749306270054, 90.58118452344621, 98.8122637612479, 108.4719134739467, 115.60558032989502, 102.59200736454555, 50.43069934844971, 7.644866670880999, 2.4611650662762776, 3.3466678134032657, 3.4794893605368475, 2.670656727893012, 5.5759033135005405, 35.24141958781651, 68.09139428819928, 72.12269047328404, 46.048699787684846, 8.42211561543601, 0.5394489105258669, 8.110359498432704, 37.932165077754426, 96.21753542763847, 120.71736308506557, 112.71089131491524, 103.00029741014752, 101.3628293446132, 105.80302006857735, 101.720077923366, 102.60197802952358, 100.94693102155412, 97.22740050724575, 98.2921633039202, 99.27905763898576, 105.14945166451591, 125.95841707502092, 125.13907160077775, 52.0177686555045, 1.7203265279531479, 2.852608770132065, 0.545219715152468, 0.3401212420846735, 0.03766419645398855, 0.06637766784323113, 0.2601052171417645, 0.03895147577194231, 0.0571604956473623, 6.23329279252461, 31.972674301692418, 36.63507536479405, 40.71720804486956, 41.24795661653791, 59.90187222617013, 67.7363691329956, 27.501463345118932, 35.33226033619472, 20.910777364458355, 28.09815205846514, 48.383836473737446, 57.66661589486258, 59.086792945861816, 54.602303981781006, 26.051666123526438, 3.947900865759168, 0.17070487647184304, 0.04486126811908824, 0.04477511452777045, 0.007097101404464671, 0.008943140739575028, 0.03702723188325763, 0.09928249075476613, 0.02277931454591453, 0.009791005020295935, 0.011095123881075, 0.022461778816900084, 0.06990478107971804, 0.03744872426614165, 0.04064792527684143, 0.042417066238288365, 0.0885687552924667, 0.14302276474024567, 0.011583588518468397, 0.07660943309643439, 0.0871189905862723, 0.021346716775691936, 0.0049699373776093125, 0.059602923159088404, 0.0685217095805066, 0.048032937571406364, 0.05506238055282405, 0.03213432264913406, 0.07358733990362712, 0.023813184783128754, 0.013446783763356507, 0.033488234105919085, 0.049516744379486353, 0.007351117774045893, 0.028272345595593964, 0.0550673779632364, 0.01993405775699232, 0.040998619315879684, 0.04616179244060602, 0.05322544037231377, 0.04169532210965242, 0.01925955493269222, 0.051233057997056415, 0.01704358509076493, 0.03746941279886024, 0.01474375680222043, 0.07020538566367966, 0.04646649876875537, 0.03209140530920454, 0.04975145982046213, 0.02765653605040695, 0.0335093636863998, 0.047339912437434704, 0.031484896782785654, 0.01980019297583827, 0.03455815151599901, 0.0077526654682255215, 0.0496019174877022, 0.028930595809859887, 0.016318539889263253, 0.061689459053533416, 0.052057990338653326, 0.018082086329481432, 0.0327581745306296, 0.04319112541686211, 0.09266822638788394, 0.0140201687546713, 0.03941817215776869, 0.009144588456755238, 0.014614068404106157, 0.04196330612259252, 0.0346884336322546, 0.02347801562531718, 0.0085805384109595, 0.0414561113741781, 0.08496626360075814, 0.8653806011591638, 17.89942114693778, 60.299698284694124, 90.27347660064697, 94.16735131399972, 77.56371361868722, 74.7223242350987, 53.28995949881417, 70.50054318564278, 30.449361664908274, 21.93962492261614, 19.133534124919347, 32.76360164369856, 37.11467824663435, 42.79402460370745, 32.64549963814871, 6.222596909318652, 0.07980607263743877, 0.16409860524748052, 0.2732724877340453, 0.1946602160377162, 0.8940605393477848, 0.11923226847180299, 0.9818383263690131, 0.8308803524289812, 0.4365713308964457, 0.9499503288950238, 0.850587072116988, 3.2764058922018324, 16.130496638161794, 54.83611781256539, 102.95432118007115, 120.15925598144531, 114.54333972930908, 105.39222172328404, 96.32863712310791, 93.30701841626848, 93.22996289389474, 94.367890221732, 96.78662763323102, 101.45200252532959, 113.25276742662702, 121.60124342782157, 112.71334402901786, 63.140712465558735, 13.196778723171779, 1.3973191061190195, 1.2519414041723524, 2.470669550555093, 1.5431664628641946, 10.021128007343837, 47.64837660108294, 83.22599520002092, 95.39735616956438, 66.33732850211007, 14.92272254398891, 2.445507517882756, 15.998195988791329, 49.15215785162789, 106.9076099395752, 122.14432852608817, 114.27488218035016, 103.40488406590053, 105.32670715876988, 105.84766224452427, 105.19051551818848, 103.73957184382847, 101.76822199140275, 101.33781582968575, 103.80350916726249, 103.1264419555664, 106.43996838160923, 127.38582720075334, 139.85999761308943, 65.66718864440918, 3.4271427180085863, 2.943614103964397, 0.365442513355187, 0.2987922712096146, 0.2736682907811233, 0.14589237075831207, 0.11628441379538604, 0.16233559484992707, 0.014867977904421943, 6.44912815945489, 40.212299823760986, 42.834324155535015, 39.94410630634853, 38.067971093314036, 43.4436742237636, 48.71545662198748, 19.28643444606236, 30.803066662379674, 23.75878143310547, 52.15294585909162, 74.44496604374477, 77.50030435834611, 74.05526937757219, 70.85643686567033, 34.726092542920796, 3.8619516491889954, 0.13912881511662686, 0.032999017142823765, 0.05093933715085898, 0.036650529596954584, 0.10842583834060601, 0.020023427604298507, 0.060961194203368256, 0.04216175386682153, 0.038785814839814386, 0.0066021898362253395, 0.020863711800692335, 0.02504118388917829, 0.03336411648030792, 0.040702316643936295, 0.038944096703614504, 0.050978895742446184, 0.07384810091129371, 0.020930181091119136, 0.0427057693180229, 0.06622517388314009, 0.01878588490321168, 0.035352302116474936, 0.06268565702651228, 0.10063430893101863, 0.06763662171683141, 0.043194317924124856, 0.06711640927408423, 0.0900174207719309, 0.017979420588484833, 0.02130899701400527, 0.02671111624554864, 0.02904142771980592, 0.005506047895843429, 0.033368099480867386, 0.03884853522426315, 0.02209487627260387, 0.06016137105013643, 0.048362471495888064, 0.021127996101443256, 0.0635775098843234, 0.1258738370878356, 0.08293263986706734, 0.13003939070871898, 0.18342610528426512, 0.15197132527828217, 0.14277458377182484, 0.13687196693250112, 0.1757232536162649, 0.13885297706084593, 0.11152167471923999, 0.25393301833953175, 0.11645235121250153, 0.15962237758295877, 0.1372037569859198, 0.12967238468783243, 0.05188621919868248, 0.11586130649915763, 0.08150777739605733, 0.08371717562632901, 0.23105868005326816, 0.1095682131126523, 0.07752652067158904, 0.14356631200228417, 0.13669808554862226, 0.15107575404856885, 0.09599644743970462, 0.13606620659785612, 0.09755196861390557, 0.2583655890609537, 0.2535006286842482, 0.20345413844500268, 0.15781085193157196, 0.18004520955894673, 0.1208042169788054, 0.1761980652809143, 3.374112546443939, 37.006345408303396, 91.76339272090367, 109.97021606990269, 105.51049395969936, 76.44467149462018, 67.76812934875488, 36.86395944867815, 60.449028968811035, 51.859283719744, 57.98125811985561, 49.83157702854702, 55.63450057165963, 49.62697689873831, 56.33123813356672, 41.198659147535054, 7.668555685452052, 0.8469146234648568, 0.315130064530032, 0.6917106487921306, 0.3165050207504204, 0.4828423165849277, 0.11691374145448208, 1.5965528381722314, 5.886751387800489, 10.113930753299169, 11.776909129960195, 13.707814386912755, 5.526548956121717, 15.348214592252459, 55.580551283700125, 104.89341054643903, 124.57837976728166, 119.2693862915039, 114.05001068115234, 103.408511025565, 99.22419466291154, 100.4517468043736, 101.41192531585693, 104.9429373059954, 112.02176203046525, 125.99842480250767, 130.96331569126673, 119.15922955104283, 60.06359849657331, 12.160518305642263, 7.623758043561663, 14.31140352998461, 15.072233881269183, 7.078495119299207, 12.02065019948142, 54.14007159641811, 93.91668810163225, 108.78098324366978, 79.57192366463798, 16.025512831551687, 1.9320045922483717, 15.23175757271903, 46.55637686593192, 110.45831312452043, 126.57572283063615, 126.78002766200474, 110.13345009940011, 112.71057169778007, 113.23288863045829, 112.06929465702602, 105.25587027413505, 105.3719538279942, 103.85558591570172, 109.67889199938092, 112.91885784694126, 116.59691456386021, 138.89045987810408, 142.75631250653947, 55.48899139676775, 3.8771378057343617, 7.061391694205148, 1.9687427580356598, 0.6948393466217178, 0.2117018537329776, 0.27694461068936754, 0.23547675726669176, 0.3022437888596739, 0.3496573460953576, 9.199246440614973, 56.51332262584141, 58.99079663412911, 57.99331324441092, 59.58977999005999, 92.19034562792096, 105.03480638776506, 40.35653053011213, 51.33652210235596, 31.845751558031353, 41.38765709740775, 67.45805209023612, 81.39921651567731, 78.68625068664551, 86.02670288085938, 53.89472028187343, 8.212953993252345, 0.31560389910425457, 0.09939978231808969, 0.09988528090928282, 0.1449361927807331, 0.2209466898015567, 0.19914864376187325, 0.20035254130406038, 0.13622818647750787, 0.15482661420745508, 0.07933172237660203, 0.11822419613599777, 0.18324245299611772, 0.13066517641501768, 0.12908148925219262, 0.24795458199722425, 0.185269617076431, 0.2241418297801699, 0.09469219456825938, 0.09856599848717451, 0.17912848160735198, 0.10781675138111625, 0.13658211034323486, 0.12712863832712173, 0.18975785481078283, 0.14142929310245173, 0.16659283212253026, 0.18030430137046746, 0.1851476707628795, 0.07774319725909404, 0.11789988353848457, 0.09376831485756806, 0.12257999740540981, 0.11470915403749261, 0.07251503065760646, 0.10293401338692222, 0.11142745334655046, 0.07701440993696451, 0.10709458656076874, 0.2283367503966604, 0.11879401627395834], [0.02311746925780816, 0.03586281829380563, 0.09376912231424026, 0.028308206171329533, 0.04398681968450546, 0.03950403397902846, 0.04077206325850316, 0.023069191491231322, 0.08458308130502701, 0.10231442270534379, 0.08501454136733498, 0.1290726140141487, 0.09650279062667064, 0.057248684843736034, 0.046570993161627224, 0.019567562333707298, 0.050743216781743934, 0.06779524963349104, 0.034979457301752906, 0.037399337094809325, 0.0509685446907367, 0.05789297419999327, 0.030917054574404444, 0.0453305870427617, 0.08904499866600547, 0.05282921663352421, 0.030310413733656918, 0.06572220301521675, 0.10927993072462933, 0.022393954152773534, 0.05012751749849745, 0.04317793469609959, 0.04881571592496974, 0.035035616252571344, 6.060499344553266, 22.81648932184492, 50.86523968832833, 62.40270955221993, 69.77014854976109, 50.14908538545881, 57.827671664101736, 34.81189932141985, 35.60746111188616, 49.53833525521414, 68.06418514251709, 69.11346040453229, 55.56311477933611, 31.096228531428746, 31.8521716935294, 14.704660279410225, 0.6026978737541607, 0.4462880880704948, 0.028232422291434238, 0.1655662086393152, 0.04774483499516334, 0.12692936616284506, 0.05838835904640811, 0.9055871665477753, 1.52135454756873, 3.499626325709479, 4.523969496999468, 8.29856448514121, 39.87782743998936, 80.11186817714146, 103.29036385672433, 114.87890298025948, 100.27715941837856, 100.54154532296317, 97.21696431296212, 91.75989777701241, 91.30773680550712, 87.76664297921317, 93.3474291392735, 94.0150398526873, 96.37762192317417, 87.02629852294922, 88.23981530325753, 84.66782978602818, 97.95919867924282, 105.88751711164201, 81.119843346732, 16.573199374335154, 1.9454046274934496, 4.501291445323399, 24.265376329421997, 72.95930222102574, 90.89354773930141, 91.73331396920341, 90.38591235024589, 105.19109221867153, 83.90166582380022, 61.7500444139753, 66.82126358577183, 90.15872710091728, 100.24478081294468, 103.23585523877824, 95.52383422851562, 99.0419225692749, 97.55656446729387, 100.12477152688163, 109.44540473393032, 102.51160281045097, 109.1184572492327, 108.41230487823486, 104.39863627297538, 97.14900398254395, 97.0213725226266, 94.0486969266619, 101.34398583003453, 122.3934075491769, 100.41389996664864, 17.742548193250382, 1.3774475838456834, 1.4742527093206133, 0.9441321896655219, 0.12160369407917772, 0.14572216703423432, 0.18152086037610257, 0.09065983737153666, 0.2012108473905495, 0.6492368536336082, 18.574761731284006, 31.797468526022776, 40.780224731990266, 38.531287397657124, 35.06550856998989, 63.8435366494315, 108.09833662850517, 134.31116621834892, 47.22777087347848, 25.244955948420934, 29.483784403119767, 46.66129813875471, 57.46596929005214, 61.46609238215855, 42.527279785701204, 8.191581334386553, 0.3918264518891062, 0.06450516224971839, 0.0237396146237318, 0.019464022978874188, 0.09024914048079934, 0.028095483746645705, 0.005038696299639663, 0.041297961824706624, 0.06422279668705803, 0.13689199728625162, 0.04247225149135504, 0.09726450725325517, 0.053910862521401474, 0.07576794110770736, 0.1467513825212206, 0.06154864268111331, 0.1343201867171696, 0.08477999895278897, 0.062024906410702636, 0.04193141158404095, 0.14918452767389162, 0.09591458897505488, 0.08339460686381374, 0.19512565034840787, 0.1965389980801514, 0.05174765895519938, 0.03813706750848463, 0.023308222414925694, 0.09712006071848528, 0.018353037236790572, 0.12230447147573743, 0.1497615131416491, 0.08919317714337792, 0.11717296897300652, 0.07407594618520566, 0.0518807366357318, 0.05086799937167338, 0.06507700442203454, 0.05011302399049912, 0.016382615647411773, 0.041259047841387134, 0.03620934273515429, 0.007789598977459329, 0.08791684598795005, 0.029811666746224676, 0.044489271473139524, 0.059948059996323924, 0.0578146916148918, 0.0987193745427898, 0.045224701653101614, 0.14674077023352894, 0.00814605038613081, 0.09139918269855635, 0.06968133271272693, 0.06825807158436094, 0.03255122474261692, 0.05527591213051762, 0.04622986985902701, 0.04214287023725254, 0.016274492788527693, 0.024265957630372474, 0.025683585221746137, 0.055575258032019646, 0.05693295571420874, 0.17419232933648995, 0.10349160632384674, 0.05589511265446033, 0.027054076681711843, 0.03371904118518744, 0.039949838271630664, 0.03341023650552545, 0.03979212298457112, 0.027945858293345997, 4.3056957466261725, 30.78542866025652, 76.04321152823312, 83.8327327455793, 91.75982134682792, 80.69223730904716, 93.50132478986467, 59.009973662240164, 28.223455871854508, 27.198528834751674, 36.51789052145821, 47.87809099469866, 51.83973843710763, 41.09193134307861, 40.381596156529014, 18.980117900030955, 0.5065757344876016, 0.633927257997649, 0.03388054269765105, 0.23888995125889778, 0.9224141836166382, 0.2973465844988823, 0.5993024302380425, 1.1659697145223618, 0.2328635017786707, 0.2987107113003731, 2.3412843218871524, 12.36920918737139, 48.064476421901155, 90.10218266078404, 113.02381038665771, 122.77965790884835, 107.00104236602783, 104.59181009020124, 105.48789841788155, 100.60805347987584, 97.38579164232526, 93.28728553227016, 99.18731362479073, 99.84017331259591, 102.41662788391113, 95.4371554510934, 96.0867008481707, 89.70985957554409, 99.9678395135062, 106.64402307782854, 92.15267944335938, 25.142846958977835, 4.471234406743731, 8.721564735685076, 33.07648597444807, 93.11889593941825, 101.85675593784877, 99.55353232792446, 95.40446417672294, 117.11662592206682, 102.85714367457798, 77.02012825012207, 75.07091535840715, 95.65463406699044, 103.19930076599121, 108.62806728907994, 101.53398432050432, 105.96908201490129, 103.55460384913853, 105.92530836377824, 114.30071558271135, 106.83017921447754, 112.33140850067139, 113.3700669152396, 108.14506326402936, 101.07832145690918, 103.73435374668666, 100.07534899030412, 101.07916218893868, 124.99334008353097, 116.73175130571637, 28.26607264791216, 3.1896797801767076, 0.9826498542513166, 0.11871131642588548, 0.2567231814776148, 0.11467851139605045, 0.23865452674882753, 0.026737511257774065, 0.3636247180402279, 0.16451509004192694, 22.641252279281616, 43.10761070251465, 42.98103189468384, 38.28071103777204, 41.82593904222761, 39.13263661520821, 78.05324895041329, 81.98171179635185, 25.664427382605417, 43.208303996494834, 50.08200052806309, 64.95729119437081, 72.09446689060756, 75.16162409101213, 58.389694077628, 10.696576288768224, 0.26947882558618275, 0.13519050287348883, 0.04749186017683574, 0.03697320692507284, 0.11261917118515287, 0.041597938763775995, 0.05018553902794208, 0.07200553906815392, 0.027591883537492583, 0.08714584021696023, 0.04414134585697736, 0.14826089223580702, 0.04460152830662472, 0.14514807212565625, 0.11868528782257012, 0.09270022609936339, 0.15665494038590363, 0.06108084028320653, 0.051298607872532945, 0.07163964584469795, 0.18807398873780454, 0.06565137074462005, 0.13140036910772324, 0.18199698839868816, 0.12862488946744374, 0.010649205933857177, 0.0699665549078158, 0.038773204266492806, 0.055617649507309706, 0.03384649381041527, 0.09940786367016179, 0.06730068581444876, 0.07873345805065972, 0.048136912884988954, 0.08881768264940806, 0.034764093679508994, 0.06771519607199089, 0.03275842898126159, 0.03708649513178638, 0.07306551254753556, 0.13205014781228133, 0.15953647504959786, 0.09136427207184689, 0.18505245872906276, 0.2250607426145247, 0.15936551136629923, 0.14351968307580265, 0.18223330857498304, 0.19486141524144582, 0.11326078711343662, 0.19570069520601205, 0.12689724431506225, 0.1569895124328988, 0.257072274174009, 0.20243202043431147, 0.1694818985249315, 0.2356236736689295, 0.16601724443691118, 0.16283507804785455, 0.12686181121638843, 0.14070510624774865, 0.11421188286372594, 0.12563785617905004, 0.3251644846584116, 0.2566826050834996, 0.17152696235903672, 0.21832200778382166, 0.1705806367099285, 0.12461210122065884, 0.2163127027451992, 0.12849193731588976, 0.13272903566913946, 0.13959065319171973, 13.060065967696053, 61.89043276650565, 107.8512795312064, 93.37740366799491, 96.92848205566406, 74.3758523123605, 80.37865815843854, 48.42410128457205, 60.463099070957725, 74.79184791019985, 112.76045281546456, 108.76945618220738, 86.27396147591728, 54.259879384722026, 55.763681479862754, 24.52167453084673, 0.8936366449509348, 0.832514644733497, 0.09307902505887405, 0.597402532185827, 0.5006139629653522, 0.1938650951321636, 0.606639945081302, 4.339243820735386, 9.794385705675397, 11.391311032431465, 11.788796629224505, 12.95514382634844, 47.54304885864258, 95.09107262747628, 118.66615758623395, 129.98003441946847, 111.20278481074742, 109.32037190028599, 111.26721545628139, 103.8510001046317, 101.38408388410295, 95.88090910230363, 103.38924367087228, 105.40896688188825, 107.05190317971366, 96.81152302878243, 98.18507071903774, 93.97809628077916, 106.96104853493827, 112.40307222093854, 92.56549276624406, 23.96832868031093, 5.552437075546809, 8.024123668670654, 36.318355628422324, 103.76478685651506, 104.21683665684291, 100.0423936843872, 96.23323140825543, 118.69679914202008, 122.29399272373745, 88.06057262420654, 80.7138739994594, 104.89600222451347, 105.04529816763741, 111.56886454990932, 103.47255952017647, 108.35059792654855, 106.5735752923148, 109.25189045497349, 115.7113527570452, 112.14820534842355, 117.01179150172642, 119.63134574890137, 113.15754931313651, 104.04198523930141, 106.39677837916783, 102.85930456433977, 110.06491306849888, 139.97487912859236, 118.42872374398368, 21.579409463065012, 5.182305668081556, 5.704501007284437, 2.2317164412566592, 0.6573429043803896, 0.29529244186622755, 0.5416600661618369, 0.17612645269504615, 0.45924769980566843, 1.0093784885747092, 32.25041464396885, 55.48709453855242, 62.38218457358224, 58.627093178885325, 56.51530633653913, 93.48384312220982, 140.8128318786621, 164.5980164664132, 62.5825080871582, 37.91509682791573, 42.29419551576887, 66.59451607295445, 78.76338263920375, 86.91027055467877, 80.47031879425049, 21.00033269609724, 0.7275023396526064, 0.2809969575277397, 0.19463920859353884, 0.20378496497869492, 0.1904644811792033, 0.2038975746503898, 0.14561251577522072, 0.17210595629044942, 0.17188383106674465, 0.1415371937411172, 0.11124721408954688, 0.38451287576130455, 0.16779875169907296, 0.23176940477320127, 0.21258639198328766, 0.17437053977378777, 0.3040383239941937, 0.17244029763553823, 0.22323062510362693, 0.16868178360164165, 0.29644511001450674, 0.1567070654460362, 0.18873043065624578, 0.2809630036354065, 0.39778694776552065, 0.09845919028988906, 0.16868717116968973, 0.1328052215810333, 0.1451501077307122, 0.1496699380555323, 0.16960697967026914, 0.23913210683635303, 0.2110874538442918, 0.14449954192553247, 0.20235419246767247, 0.1406405232846737, 0.1484278254210949, 0.10200564177440745, 0.07874780228095395], [0.09032827123467412, 0.0374528667224305, 0.010843014194896179, 0.035268828738480806, 0.057333522077117643, 0.05542253337002226, 0.09882006913955722, 0.047036213733788045, 0.0648326368204185, 0.15168286647115434, 0.2043565764491047, 0.029056294422064508, 0.03271010032455836, 0.11018728132226638, 0.15944897117359297, 0.1278847570398024, 0.050862309855542014, 0.07668654860130378, 0.027976908055799346, 0.07605333972190108, 0.06412052788904735, 0.05182788215045418, 0.02748548924656851, 0.08930316088455063, 0.025749990051346164, 0.016762863279187253, 0.0918409972052489, 0.01791878161020577, 0.07567656279674598, 0.04157567602981414, 0.04533699241333774, 0.062238169967063835, 0.12089082518858568, 9.933369653565542, 52.728847299303325, 62.48654651641846, 69.56243910108293, 58.36674417768206, 59.66056823730469, 51.855437891823904, 25.598942347935267, 50.15752397264753, 54.858365944453645, 68.42432417188371, 48.1482960156032, 28.244112866265432, 33.55841302871704, 27.179211105619157, 2.9916921641145433, 0.41737036406993866, 0.22092311749500887, 0.04877865434225116, 0.06770900783262082, 0.2202482737068619, 0.12132413765149457, 0.8376324272581509, 1.4497445672750473, 4.049720636435917, 1.563950044768197, 10.271560192108154, 54.82544537952968, 101.06329250335693, 117.154299054827, 98.37266513279506, 91.27223151070731, 92.00865718296596, 99.52011844090053, 101.24394566672188, 101.66911288670131, 86.12840366363525, 75.05119637080601, 71.8281980242048, 79.09602069854736, 76.42633519853864, 80.8422211238316, 82.57149573734829, 96.33674567086356, 94.01755510057721, 94.74622658320835, 83.76563399178642, 91.93306078229631, 76.86027799333844, 26.71443567957197, 60.72077301570347, 65.7224337714059, 93.83550534929547, 78.07073061806815, 74.34899752480644, 78.60619354248047, 82.89456612723214, 95.91389914921352, 61.241769790649414, 77.98708125523159, 100.16519614628383, 102.73310443333217, 106.55591991969517, 96.65464660099575, 98.4165291104998, 90.94785485948834, 91.34348528725761, 101.93314443315778, 100.49351242610386, 97.5768323625837, 102.84439373016357, 95.99463721684047, 92.00097942352295, 79.11442647661481, 93.91028881072998, 98.41877337864467, 91.25427736554826, 99.35536970411027, 124.29062707083565, 76.5440376826695, 30.891989707946777, 8.377126898084368, 1.8800418376922607, 0.3676727222544806, 0.05114890947671873, 0.10183124470391444, 0.11447005186762128, 0.07549474255314895, 0.18305614085069724, 5.531432236943926, 21.942494528634207, 36.27632597514561, 42.12691068649292, 45.150836195264546, 62.10796001979283, 139.76848983764648, 140.3164108821324, 45.105652059827534, 30.692180361066544, 42.989140442439485, 53.43818889345442, 58.08023868288313, 64.12496648515973, 52.48947490964617, 14.644752911158971, 0.15457144432834216, 0.021741588533456837, 0.0629669844305941, 0.14136160244899137, 0.010056737145142896, 0.06838524940290622, 0.07368633816284792, 0.07571196875401906, 0.0468058035975056, 0.20253603985267027, 0.0693603992196066, 0.049386411373104365, 0.1074646527745894, 0.197226489761046, 0.04095577661480222, 0.11045629331575972, 0.05699531986777272, 0.14918209851852485, 0.1244029224451099, 0.18991997039743833, 0.07849248312413692, 0.014491056790575385, 0.06627984344959259, 0.010581426222675612, 0.06385162446115698, 0.11248845819916044, 0.1069828996966992, 0.013085468106770089, 0.039715713156121116, 0.03977204513336931, 0.05204252652557833, 0.044184656747217686, 0.05128576998998012, 0.05196093608226095, 0.02095707821925836, 0.03007087390869856, 0.06457701232284307, 0.03657309518062642, 0.014109576769572283, 0.06268186401575804, 0.016530125767790844, 0.0258780906775168, 0.059791555894272666, 0.14649538482938493, 0.21954309940338135, 0.07961100060492754, 0.05720360976244722, 0.11333733943424054, 0.24426972972495214, 0.04860733782074281, 0.046078685471521955, 0.18625468707510404, 0.07112766403172698, 0.1146967097052506, 0.03246883362797754, 0.1393214783498219, 0.05105999764055014, 0.07028974113719803, 0.07880195616079227, 0.09498673983450447, 0.051673529004412036, 0.15987876882510527, 0.10960316445146288, 0.039500888969217024, 0.1769012582621404, 0.03008885508669274, 0.027765101653390696, 0.019083464917327677, 0.11709780086364065, 0.1252978965640068, 0.10450151070420231, 8.895617110388619, 70.85689544677734, 85.48658466339111, 85.98729269845145, 84.31347860608781, 88.29032870701381, 79.05592959267753, 38.9996828351702, 29.73148420878819, 41.7663790839059, 43.408287048339844, 40.84647233145577, 32.450175353458945, 39.27019705091204, 31.760281767163956, 3.9225646938596452, 0.6194162166544369, 0.23795452288218907, 0.0568217743587281, 0.18871061743370124, 0.4704864653093474, 0.27508990306939396, 0.5709106251597404, 0.21478375978767872, 0.6219077972429139, 2.6923418385641913, 13.871976000922066, 64.28565747397286, 112.84775693075997, 128.25141988481795, 105.14712401798793, 97.0397505078997, 97.00065994262695, 107.658522605896, 104.10136454445976, 105.82867976597377, 90.2636171068464, 79.66650254385812, 76.69530691419328, 82.4542796271188, 82.38390132359096, 84.22390242985317, 87.11841773986816, 100.60015337807792, 98.80671215057373, 101.42897619519914, 86.3980632509504, 94.08024174826485, 86.91158376421247, 37.52704341070992, 72.93251691545758, 78.22838524409703, 103.61057158878872, 85.53059455326625, 79.27770914350236, 87.46049840109688, 88.01305389404297, 104.68132373264858, 69.1839359828404, 82.49749047415597, 105.0363210950579, 106.25588280814034, 108.81822558811733, 101.0247300011771, 101.28332805633545, 93.95664024353027, 94.692537852696, 104.01998029436383, 104.39805957249233, 100.22219916752407, 106.99680396488735, 101.49095412663051, 95.83168806348527, 82.37761320386613, 95.65675326756069, 105.09360204424176, 94.83558736528668, 100.6074698311942, 129.12817137581962, 91.12972395760673, 40.537280968257356, 13.580502544130598, 3.7769499932016646, 0.2083787556205477, 0.2457569699202265, 0.19624458173555986, 0.03686257518295731, 0.06242199867431607, 0.25285862599100384, 4.830112772328513, 29.605075631822857, 42.271603448050364, 43.18452031271798, 45.80654811859131, 58.32110146113804, 141.41836738586426, 117.96344457353864, 36.1874863079616, 38.77490861075265, 56.34000676018851, 71.54929733276367, 68.21439129965646, 78.27015781402588, 69.10399000985282, 21.34675771849496, 0.08454762785030262, 0.024946670746430755, 0.08071036304214171, 0.15210963785648346, 0.00563220027834177, 0.09705615629042898, 0.14205879718065262, 0.0070233531296253204, 0.0416017487379057, 0.11560369389397757, 0.04353177035227418, 0.08381690670336996, 0.12426534268472876, 0.21952245836811407, 0.01353173125867865, 0.10399950335600547, 0.11133365945092269, 0.1240844859608582, 0.1420969579901014, 0.14124771713146142, 0.08748829005552189, 0.010730558041749256, 0.04525278961019857, 0.023342386653114642, 0.08149538056126662, 0.0923673232485141, 0.13822586142591067, 0.05167099467611738, 0.016866677440702915, 0.05063314822369388, 0.14748703661773885, 0.02929294708051852, 0.12188181201262133, 0.10195075507674899, 0.028212054366511956, 0.04983472963795066, 0.01678512092413647, 0.059400753650282107, 0.20900611552808965, 0.21494297124445438, 0.1130955841924463, 0.19369979043092045, 0.19350183462457998, 0.21940633388502256, 0.2866040995078427, 0.17987005252923283, 0.2015166902648551, 0.2116161954722234, 0.34460513719490593, 0.15666391061885016, 0.22408727556467056, 0.25037285366228645, 0.23959663191011973, 0.37614051359040396, 0.2177158860223634, 0.2538004054554871, 0.24454741339598382, 0.15078443182366236, 0.21884347551635333, 0.21582464607698576, 0.11596038618258067, 0.21028584614396095, 0.2087516648960965, 0.1245072539895773, 0.3788467283759798, 0.21523902964379105, 0.23629984738571302, 0.08602909371256828, 0.14706329149859293, 0.2776288182607719, 0.29758314894778387, 20.267622573035105, 106.55588517870221, 106.64990125383649, 98.18700926644462, 86.46641268048967, 84.14484582628522, 65.04613780975342, 38.28144754682268, 80.35730634416852, 86.42892714909145, 105.36526271275112, 77.13822678157261, 45.92587300709316, 48.50050367627825, 41.39193023954119, 5.1872910005705695, 0.8818622167621339, 0.3989245795777866, 0.25547312998345917, 0.21321372474942887, 0.2375638224184513, 0.3630147964826652, 2.6995690507548193, 9.636918681008474, 13.126543726239886, 5.936539139066424, 14.715999739510671, 67.10155391693115, 116.08099692208427, 131.11532838003976, 107.41970607212612, 98.94332763126918, 100.65874058859688, 110.99526296343122, 111.22798592703683, 113.84848512922014, 97.47128227778843, 84.59133011954171, 81.12577016013009, 90.94524233681815, 88.11185727800641, 92.10348619733537, 93.86636924743652, 108.74078791482108, 104.08600902557373, 106.30523586273193, 88.16941615513393, 95.89762646811349, 92.08676883152553, 44.97150318963187, 77.94192491258893, 100.16405664171491, 108.41883618491036, 93.42485291617257, 85.40447085244315, 96.58917372567313, 99.05931391034807, 107.47929382324219, 84.48130539485386, 84.49446528298515, 105.5774815423148, 111.52799524579729, 113.77582086835588, 109.89900398254395, 106.33797577449253, 100.53062970297677, 101.0920580455235, 110.66356985909599, 108.15827178955078, 103.29330294472831, 108.51160853249687, 107.14598178863525, 102.34711810520717, 88.83744376046317, 102.34768785749162, 108.01106030600411, 94.51770727975028, 105.55501106807164, 139.62985937935966, 88.50275598253522, 36.40014982223511, 12.150195019585745, 5.005645113331931, 0.5691769410456929, 0.3572438290076596, 0.37861944628613337, 0.1487983191119773, 0.14590689140771115, 0.4355827325156757, 10.999469978468758, 40.089354923793245, 58.27192211151123, 65.37124402182442, 68.52749797276088, 82.5691750390189, 143.24852289472307, 153.4589979989188, 60.1888884135655, 48.05435289655413, 57.75336068017142, 76.34394345964704, 79.90081664494106, 89.24900640760148, 89.19686712537492, 36.09122943878174, 0.8156971271548952, 0.2540610714682511, 0.1602740968976702, 0.2750430298703057, 0.07332657211061035, 0.15375921076961926, 0.2796105204948357, 0.2152577843517065, 0.08769002530191626, 0.3116367762642247, 0.16081625994827065, 0.11586241929658822, 0.2395452803799084, 0.3632274493575096, 0.09957616749618735, 0.3123638672488076, 0.1908682230859995, 0.23535999496068272, 0.343275208558355, 0.2407091036438942, 0.19410271809569427, 0.12237199928079333, 0.1875880490988493, 0.26876020271863255, 0.2091411847089018, 0.17792537116578647, 0.26967750063964296, 0.11449582262762956, 0.10606916408453669, 0.1731940686170544, 0.1916345062532595, 0.1177076409970011, 0.16720256369028771, 0.1860386822372675, 0.19493314996361732, 0.09822126877095018, 0.21621263240064892, 0.17805700695940427], [0.06573090183415584, 0.030058762058615685, 0.02085516565213246, 0.04422312629009996, 0.044812372885644436, 0.04772302348698888, 0.13868072416101182, 0.03910057366426502, 0.11849003258560385, 0.18515152484178543, 0.12874300884349005, 0.04375263010816915, 0.0505563278815576, 0.030084414074995687, 0.06623529762561832, 0.09032734164169856, 0.04459379640008722, 0.02846940912838493, 0.04354545979627541, 0.05891591323805707, 0.027074020522247468, 0.06286958072866712, 0.055091442207672765, 0.03737625672615, 0.05313116132414766, 0.04142183857038617, 0.10102218668907881, 0.03630299413842814, 0.07055410516581365, 0.041416474751063755, 0.10073379573545285, 0.0450116959400475, 7.158363359315055, 61.43153204236712, 72.58557946341378, 71.57775020599365, 67.83994592939104, 69.81294250488281, 37.304881708962576, 33.71530335290091, 66.68741348811558, 62.307595661708284, 57.53457580293928, 40.61055319649832, 28.722176722117833, 33.27042409351894, 12.022735527583531, 0.2566875176770346, 0.3601178047912461, 0.02607067587918469, 0.048125465999224355, 0.2077306868242366, 0.25245077216199463, 0.25862972917301313, 1.8506893898759569, 2.144794911146164, 2.425678010497774, 14.259827920368739, 55.40178803035191, 107.36869934626988, 108.11405345371791, 98.7555456161499, 90.96843542371477, 94.25225830078125, 99.3813281740461, 99.84708677019391, 91.84144878387451, 85.65351513453892, 79.18560382298061, 79.11145264761788, 79.18777166094098, 89.8394365310669, 88.18913514273507, 89.34141744886125, 88.89389787401471, 90.19953387124198, 91.50532272883824, 93.68425001416887, 91.52424962180001, 98.73663261958531, 89.31437505994523, 89.68236555371965, 53.225591387067524, 45.247047901153564, 77.53296783992222, 87.6114480154855, 82.75875663757324, 82.05178437914167, 80.67392880575997, 91.06108270372663, 105.51155703408378, 56.54906415939331, 110.91047409602574, 106.57010814121791, 99.41716698237828, 89.12491852896554, 89.80222197941372, 92.18047223772321, 89.37086391448975, 93.32748780931745, 94.17168004172188, 103.20577648707798, 100.17857837677002, 102.78944042750767, 108.94140325273786, 98.45737062181745, 95.27335861751011, 73.24120453425816, 80.45344856807164, 98.51064246041435, 99.53334086281913, 89.10756192888532, 96.79529898507255, 101.70545891353062, 93.68381922585624, 65.79046358380998, 26.922982386180333, 0.6875562774283546, 0.4536811342196805, 0.269390018922942, 0.11530934540288788, 0.1196817843509572, 0.31406319034951075, 0.6216843149491719, 11.818320393562317, 29.2827730178833, 46.84525864464896, 49.14246164049421, 20.54874668802534, 30.943295206342423, 42.2452072416033, 28.690216745649064, 21.85511745725359, 38.99985654013497, 53.46992826461792, 67.84248897007534, 59.75389644077846, 70.08875819614956, 29.392915861947195, 0.9086961054376194, 0.06327387224882841, 0.04917932587808796, 0.039858772086777856, 0.08796241639980248, 0.008547034048076187, 0.06049628236464091, 0.05359237514702337, 0.04791409555556519, 0.10743549612483808, 0.04336357509185161, 0.2435720328773771, 0.05187447375750967, 0.06427855190954038, 0.07904249003955297, 0.047555296415729184, 0.13106399215757847, 0.03648669392402683, 0.04977476071300251, 0.08128470900867667, 0.08431005238422326, 0.0795707091955202, 0.07252269810331718, 0.044261992775968144, 0.08395079523324966, 0.04029236953439457, 0.01907666090742818, 0.06709511684519903, 0.015353737731597253, 0.043463723467929025, 0.022485117028866495, 0.08678355001445327, 0.1117257916235498, 0.029850506090692112, 0.024482591809438806, 0.019371075555682182, 0.04730615532025695, 0.027207261051184366, 0.04864958680367895, 0.04505914928657668, 0.05522313567676714, 0.03489419259130955, 0.05705679514046226, 0.13372190882052692, 0.030004577644701515, 0.05962889069425208, 0.18121634743043355, 0.19863016158342361, 0.0400889820552298, 0.034956987614610364, 0.14954416480447563, 0.07000643919621195, 0.11202139540442399, 0.04972075950354338, 0.024511824794379727, 0.032426099492503066, 0.006397639093587973, 0.019172093465125987, 0.057168454863131046, 0.06269157385187489, 0.04464598931372166, 0.1007128900715283, 0.04829159172784005, 0.1289114212351186, 0.0400918420803334, 0.0254318351591272, 0.038663281593471766, 0.11667378433048725, 0.05434789674888764, 9.174973777362279, 77.65889699118478, 88.59019906180245, 87.66792297363281, 89.0895938873291, 90.45531095777238, 65.26649297986711, 44.74073266983032, 32.08261912209647, 42.511701924460276, 49.22028146471296, 43.08967392785208, 37.78315053667341, 43.45690706798008, 16.33922573498317, 0.656108133494854, 0.5331567195909364, 0.06051937969667571, 0.06308112759143114, 0.6209171903984887, 0.3281034640967846, 0.7218022112335477, 1.3677866565329688, 0.4582190950001989, 3.511304510491235, 18.92471817561558, 65.68271092006138, 120.7055789402553, 118.24966866629464, 104.5221196583339, 96.23169585636684, 99.35492501940045, 104.08106190817696, 105.05302456447056, 95.5187759399414, 91.05350916726249, 85.17980085100446, 84.86317144121442, 85.99606827327183, 94.20139053889683, 93.26569053104946, 94.56346116747174, 93.52668571472168, 97.61551993233817, 97.48056507110596, 97.93701308114188, 93.46263722011021, 100.31261607578823, 90.6230891091483, 94.12718377794538, 60.845493180411204, 52.37630612509591, 85.98868928636823, 94.0316390991211, 92.73245103018624, 89.36823054722377, 87.94627475738525, 99.03402246747697, 108.88568564823696, 62.745102882385254, 112.26458072662354, 110.06191144670758, 102.68344565800258, 91.68710844857353, 92.02679198128837, 95.06457219805036, 94.40552166530064, 97.08291271754673, 98.29925741468156, 106.29197869982038, 105.50954900469098, 105.14063440050397, 113.20145498003278, 104.45718874250139, 99.32047585078648, 77.688246182033, 80.57431248256138, 100.08502783094133, 106.02742603846959, 93.90249293191093, 99.64305291857038, 109.36765439169747, 105.25325775146484, 79.00941140311105, 37.76170144762312, 3.9097044467926025, 0.5833081656268665, 0.27964067459106445, 0.06976349651813507, 0.03418065195104905, 0.28414449148944443, 0.4673492450799261, 14.787083285195486, 37.77428463527134, 47.645312445504324, 42.043400287628174, 31.345582008361816, 48.27452046530587, 35.4767689704895, 30.51753044128418, 43.65408999579293, 61.351308141435894, 76.82346643720354, 85.38461984906877, 72.7634116581508, 84.15153694152832, 38.56663635798863, 0.41263104123728617, 0.021865665446966887, 0.09155772919101374, 0.035384922687496455, 0.05040480761921831, 0.04329211517636265, 0.06799294759652444, 0.10321071318217687, 0.05402786910001721, 0.12973019587142126, 0.0414526983430343, 0.1617050458277975, 0.041280414909124374, 0.07910283215876136, 0.005324503731182111, 0.052031819242984056, 0.048648114382688484, 0.0311011207689132, 0.06218534601586206, 0.02301502912970526, 0.05084956696789179, 0.06571829465350934, 0.07641264437032597, 0.09961497969925404, 0.08237958632941757, 0.05463691195473075, 0.008350862788834741, 0.12309481549475874, 0.0828591613098979, 0.024977092863991857, 0.030308954883366823, 0.10253422055393457, 0.12435129950089113, 0.053575364274105856, 0.029610019709382738, 0.006791247079880642, 0.10587519127875566, 0.09576866323394434, 0.13043625227042607, 0.14037945015089853, 0.18833324339772972, 0.16165250007595333, 0.21704911680093833, 0.20917304871337755, 0.1355481179697173, 0.2516496665775776, 0.3370569236576557, 0.2528635114431381, 0.1462902772639479, 0.25374617693679674, 0.20949072523840837, 0.12151754727321011, 0.3009849978344781, 0.24633567886693136, 0.08768785398985658, 0.22673045444701398, 0.1340383639825242, 0.18871960123734816, 0.1703358077044998, 0.1625909140067441, 0.1566399447619915, 0.2932955947305475, 0.1146054467452424, 0.2175214450274195, 0.1382293083838054, 0.2959769751344408, 0.18617535276072367, 0.32422091386147905, 0.10391929373145103, 24.499426398958477, 107.02129636492047, 104.78694329942975, 101.85506752559117, 97.47855009351457, 90.69705963134766, 48.079210077013286, 46.159311635153635, 96.8131628036499, 94.01644338880266, 82.83896664210728, 63.88238402775356, 49.42794575010027, 56.176995073046, 23.900826930999756, 0.8137304069740432, 0.6033797200237001, 0.1461315814937864, 0.19851844757795334, 0.41793675082070486, 0.3283777008099215, 1.2948156978402818, 5.254235156944819, 4.996832191944122, 6.7286980492728095, 18.222732986722672, 67.47185121263776, 126.07766205923897, 124.10299791608537, 107.2445628302438, 96.93855694362095, 102.35667187826974, 109.40202018192836, 111.095810345241, 103.81931631905692, 95.68846484592983, 90.29808017185756, 89.0713757106236, 89.63686180114746, 98.39947823115757, 97.43438734327043, 98.56588063921247, 98.60217108045305, 101.84784139905656, 101.80221952710832, 101.96809387207031, 98.43982642037528, 101.3529281616211, 91.2486493246896, 93.87355368477958, 65.54001576559884, 64.4581742967878, 93.81176335471017, 104.85825266156877, 101.51003387996128, 96.17440795898438, 94.66081932612828, 108.98642757960728, 120.06274550301688, 67.61683927263532, 112.72716399601528, 118.40678133283342, 104.46050303322929, 96.06779479980469, 95.72911180768693, 99.90001119886125, 98.45736367361886, 101.78828144073486, 103.62128571101597, 108.90200696672711, 109.87840257372174, 110.0161714553833, 114.90578556060791, 107.98115525926862, 102.77651677812848, 81.04774188995361, 85.05022389548165, 108.90659972599575, 108.29264300210136, 93.3618049621582, 101.77977684565953, 112.37468882969448, 106.6524303981236, 75.35706996917725, 32.40713126318795, 3.4637317146573747, 0.7860571433390889, 0.4192785402493817, 0.23589584763560975, 0.12118131960076944, 0.6468816314424787, 1.9350170705999648, 21.59752689089094, 50.36549745287214, 66.7667897088187, 69.67088658469063, 32.451978410993306, 43.98807947976248, 61.80721419198172, 43.45367268153599, 32.98818131855556, 53.87870468412127, 73.68310996464321, 90.3289440699986, 79.18330396924699, 100.12813445499965, 53.927640846797395, 2.66643265741212, 0.15327941865793296, 0.18999209866992064, 0.12477496319583484, 0.2593961480472769, 0.11734679607408387, 0.21213467765067304, 0.12247052256550107, 0.13364405371248722, 0.32231678175074713, 0.07576410059950181, 0.3742666984243052, 0.15322896279394627, 0.13703451678156853, 0.10663968311356646, 0.14463063489113534, 0.198735402364816, 0.18518725649586745, 0.11912900901266507, 0.11321160689528499, 0.1379437129944563, 0.10813715561692204, 0.17576948899243558, 0.14281448163092136, 0.20235972931342466, 0.1894360799342394, 0.07679772656410933, 0.16639973462692328, 0.14612603107733385, 0.21431690055344785, 0.09254987630993128, 0.23040047394377844, 0.1818391882947513, 0.14384540702615464, 0.11210064150925193, 0.11436671098428113, 0.18820791797978537], [0.012914463711370314, 0.0249283486045897, 0.08632059235657964, 0.03540318545752338, 0.029226243695510284, 0.06755612032221896, 0.057772798862840445, 0.03000416713101523, 0.013398038655785578, 0.029003782596971308, 0.04137964726292661, 0.07518596162221261, 0.142441952334983, 0.11125200454677854, 0.09235398325004748, 0.09331375746322529, 0.030732788212065185, 0.054280189132051807, 0.03739506232419184, 0.058858122410518784, 0.04418281113196697, 0.11481511406600475, 0.055367158127150366, 0.07706743744867188, 0.10375068456466709, 0.06556202125336442, 0.009817322000994213, 0.0036140047346374816, 0.05688074244452374, 0.12486070288079125, 0.23716796508857182, 21.552568571908132, 85.12903731209892, 84.18592357635498, 78.4147081375122, 74.61969239371163, 65.23470497131348, 46.20586803981236, 33.73873267854963, 62.91452080862862, 59.28547668457031, 51.9911709512983, 55.58422340665545, 39.91923522949219, 24.988605635506765, 2.5998105066163197, 0.9044583556907517, 0.06342799469296422, 0.02922994171136192, 0.07836348004639149, 0.19275745456772192, 0.2642524503171444, 0.8624404817819595, 3.418540848152978, 2.550872824021748, 30.510637828281947, 79.07152135031563, 113.2603201184954, 113.14457702636719, 94.2923424584525, 92.81692028045654, 94.23827157701764, 90.34288910457066, 83.9969881602696, 79.18577057974679, 78.6824152810233, 79.21339661734444, 77.5063840321132, 77.37299251556396, 80.94411645616803, 83.47275352478027, 86.16984272003174, 88.81404222760881, 84.93632207598004, 87.80048765454973, 92.59903172084263, 94.32044792175293, 94.51549775259835, 92.33770997183663, 89.90866838182721, 84.82285104479108, 91.58096776689801, 89.19931289127895, 45.152316161564414, 88.72500106266567, 80.95677607400077, 70.53545788356236, 81.45289134979248, 73.46425560542515, 90.6908757346017, 60.46833801269531, 75.01289095197404, 102.4426280430385, 98.55117130279541, 100.73084899357387, 84.06619221823556, 86.0351379939488, 88.62937300545829, 89.69056442805699, 86.50192492348808, 86.91644055502755, 93.20203808375767, 103.06408882141113, 89.83276626041958, 96.62435245513916, 100.34124960218156, 98.92681871141706, 90.62980106898716, 76.16993277413505, 83.84359972817558, 91.6375399998256, 104.26160390036446, 95.08739008222307, 84.60480962480817, 89.72508307865688, 97.46201338086809, 108.0484207698277, 80.95699841635567, 10.201996564865112, 0.4250891613108771, 0.15201642071562155, 0.03585015683035765, 0.035753689506756406, 0.34026362587298664, 0.1726888178714684, 4.7489825657435825, 19.720997367586406, 50.37154933384487, 51.08743265696934, 32.696909359523225, 39.92718744277954, 51.55197531836373, 30.73465469905308, 22.838436944144114, 30.253009046827042, 43.781033584049766, 59.43043000357491, 51.8590544291905, 66.40254429408482, 51.23785768236433, 2.8582789344446997, 0.39499683891023907, 0.05282416833298547, 0.045990238431841135, 0.02096645218054099, 0.039261305039482455, 0.06360122468322515, 0.08526048995554447, 0.04739369312301278, 0.05681395424263818, 0.29001115954348017, 0.02517037695672895, 0.06520460293229137, 0.058402065453784804, 0.07415226101875305, 0.055649018181221824, 0.01454517844000033, 0.015901938047526137, 0.023687682946079543, 0.03744721791840025, 0.021208110731095076, 0.026347467276666845, 0.0805209024942347, 0.08788372669368982, 0.02156314909059022, 0.047737004701048136, 0.06103830970823765, 0.06416712967412812, 0.14815706280725344, 0.03751499338873795, 0.08187816252133676, 0.04211384929450495, 0.08622704273355858, 0.02829760406166315, 0.06152104666190488, 0.07566841359117202, 0.01980381635283785, 0.03935783003856029, 0.09899083604770047, 0.049880405222730975, 0.046970870811492205, 0.06186089092599494, 0.024104829312169125, 0.02027414968636419, 0.05481417244300246, 0.05502931893404041, 0.019036669749766588, 0.05466786672228149, 0.0399647287226149, 0.07616968812154871, 0.13672695042831556, 0.12301607829119478, 0.052258700997169526, 0.05280340176873973, 0.03734165144019893, 0.031238144130579064, 0.033411797136068344, 0.09124993213585444, 0.08579592872411013, 0.1410649876509394, 0.18731366310800823, 0.08352618837463004, 0.045074989686587026, 0.03263203487066286, 0.11733216685908181, 0.1361295681978975, 0.1859482606606824, 21.231431518282207, 103.21611540658134, 98.16424696786063, 103.56605448041643, 102.14146532331193, 92.23555060795375, 69.42599732535226, 32.58307007380894, 26.912207467215403, 53.859006541115896, 54.31251893724714, 63.52723380497524, 50.61979109900338, 30.403684207371303, 3.3847026867525916, 1.2341169949088777, 0.3728772486959185, 0.030501007435045073, 0.2980846134679658, 0.5513224048273904, 0.10395366153014557, 0.5752004321132387, 2.0001275539398193, 5.1750361153057645, 36.582877022879465, 89.07510689326695, 121.73360661097935, 120.08652223859514, 97.50653743743896, 97.05448068891252, 99.28861141204834, 95.29472432817731, 89.33267661503383, 83.18514674050468, 82.6730853489467, 85.25777353559221, 80.85968889508928, 82.97941752842495, 85.98779296875, 87.77325071607316, 90.07977472032819, 92.59315354483468, 89.26413958413261, 92.83526352473667, 96.82145200456891, 97.81289740971157, 96.14430141448975, 93.96878569466728, 91.1891588483538, 85.50507381984166, 94.12594699859619, 92.23381355830601, 53.356328691755024, 93.49266038622174, 88.05735560825893, 79.98631422860282, 89.33059215545654, 83.00737013135637, 99.12415449959892, 68.2938231059483, 78.13584913526262, 106.73170934404645, 101.14275210244315, 105.71510451180595, 84.59654821668352, 89.98291683197021, 92.46983691624233, 93.84443378448486, 90.27544294084821, 89.3707527433123, 94.92360019683838, 103.33313001905168, 92.4051352909633, 100.39163099016461, 104.3574959891183, 102.56752886090959, 92.75881944383893, 80.62250518798828, 85.55370426177979, 96.6002561024257, 110.03102670397077, 103.97475446973527, 89.41643714904785, 94.88093825748989, 101.87324401310512, 117.84909112112862, 95.57509803771973, 20.234583888735088, 0.19888527717973503, 0.16360312540616306, 0.02452762787496405, 0.05278970893206341, 0.15405134723654815, 0.11590215430728026, 5.3568795919418335, 25.704942328589304, 56.73519945144653, 41.82524422236851, 31.247980662754603, 30.46470328739711, 31.663187640053884, 17.133099113191875, 36.06505210059029, 55.19619083404541, 70.55846336909703, 80.01783125741142, 62.11571420942034, 82.06619494301933, 63.980186871119905, 4.885098644665309, 0.5116147526672908, 0.0023179712547321935, 0.059148576110601425, 0.07591164803930692, 0.04375936117555414, 0.010943357649791454, 0.07037018146365881, 0.03772869799286127, 0.0778010423694338, 0.11731607200843946, 0.09307852972831045, 0.018818685286013142, 0.053818412125110626, 0.1045024199411273, 0.08186372329613992, 0.03846992286188262, 0.0097851110954902, 0.07706099815134491, 0.017321435002876178, 0.07492381640310798, 0.06607362987207514, 0.15259054276560033, 0.09429942457271473, 0.07591291689979178, 0.008642160416846829, 0.047095426092190404, 0.008229014014692178, 0.08702494563268763, 0.010706136718259325, 0.03203217259475163, 0.01005011549152966, 0.09289313360516514, 0.047871001796530824, 0.03832801744075758, 0.05582925404555031, 0.10871728270181588, 0.09239665631737028, 0.185741429616298, 0.129443175558533, 0.1309247160596507, 0.20041371802134172, 0.12789996979492052, 0.14038088864513806, 0.19690039940178394, 0.16457471969936574, 0.10473932365753821, 0.16933059878647327, 0.24554613551923207, 0.17642992069678648, 0.24134885360087666, 0.18876939213701657, 0.10102391016802617, 0.1317200676671096, 0.1283847423536437, 0.14880992206079618, 0.13216776507241385, 0.2118670634393181, 0.1993035533066307, 0.30774575791188646, 0.3301443074430738, 0.14713437482714653, 0.19302538090518542, 0.09907525937472071, 0.24629721950207437, 0.2770544247967856, 0.35370619169303347, 46.39588737487793, 131.03761972699846, 112.68086814880371, 108.95708533695766, 103.47721481323242, 83.90995502471924, 66.60026223318917, 49.02446385792324, 97.02960613795689, 92.9359290259225, 74.58782795497349, 82.53207165854317, 61.14619037083217, 41.51476744243077, 5.183569371700287, 1.8956453204154968, 0.4839129362787519, 0.27692930293934687, 0.29627667048147743, 0.42066508584788864, 0.5499734229275158, 3.063475740807397, 7.326935342379978, 5.799830726214817, 33.26986823763166, 92.93485205514091, 129.5619613102504, 124.5928737095424, 98.18520968300956, 97.07135091509137, 100.5645786012922, 100.37792219434465, 94.04161671229771, 87.16986915043422, 86.8226398740496, 88.54361139025006, 85.67023944854736, 87.16178839547294, 91.38964217049735, 93.89214706420898, 96.26690932682583, 98.11009965624127, 95.68558829171317, 99.3347474506923, 102.74166461399624, 103.71938037872314, 101.49599157060895, 97.32771859850202, 92.93098885672433, 88.53615597316197, 97.7032687323434, 92.98600469316754, 59.10937459128243, 105.00516537257603, 96.24650246756417, 88.2524471282959, 98.45498738970075, 95.04151807512555, 110.6632502419608, 76.98745087214878, 81.04460825238908, 110.01368400028774, 104.94791916438511, 110.66117967878068, 90.72850022997174, 96.11444500514439, 98.0753447668893, 100.3401517868042, 95.37093911852155, 95.121109689985, 100.99588108062744, 110.04055268423897, 95.74757317134312, 102.27503749302456, 109.86431162697929, 108.87029538835797, 97.54013197762626, 84.52134786333356, 88.47300379616874, 101.98970971788678, 116.793215070452, 106.15665558406285, 90.47287600381034, 97.79702077593122, 107.7257672718593, 123.75312832423619, 92.41155542646135, 16.18649911880493, 0.2868592015334538, 0.5168965778180531, 0.15196259931794234, 0.3057927169970104, 0.44633425559316364, 0.46354706053222927, 9.82828596660069, 36.03357328687395, 75.04339354378837, 72.9103035245623, 57.46273490360805, 62.61920847211565, 69.8672913142613, 43.77174036843436, 30.424733775002615, 41.24638284955706, 57.89794227055141, 80.10740048544747, 70.32870033809117, 92.97034345354352, 80.87684399741036, 8.230446083205086, 0.6123924021209989, 0.13931930703776224, 0.166474387049675, 0.14816069975495338, 0.09944988534386669, 0.10281690502805368, 0.2749391325882503, 0.1393802666238376, 0.193046578339168, 0.27517178867544445, 0.11679351861987795, 0.17226212791034154, 0.21612719127110072, 0.20509248838893004, 0.18686779774725437, 0.11090167013130017, 0.10570966266095638, 0.23578147377286637, 0.11581897948469434, 0.22826569420950754, 0.16437181058738912, 0.21280091761478356, 0.20516986852245672, 0.1958336066454649, 0.11245578673801251, 0.32337771196450504, 0.17706971136587007, 0.3385245677615915, 0.1106642032308238, 0.10741022748074361, 0.12775173703474657, 0.22861674108675548, 0.10709248988756112, 0.09057278811399426, 0.1974210257508925], [0.02125629180643175, 0.02328169678470918, 0.09199857339262962, 0.08145275499139513, 0.0669379477788295, 0.0595241045313222, 0.0377990179695189, 0.03674552110689027, 0.04410606882135783, 0.10534340981394053, 0.029165640340319703, 0.0612190646518554, 0.11442634064171996, 0.06594093556382827, 0.10494272131472826, 0.19005741445081575, 0.054148763684289794, 0.025359062278377156, 0.05011102909754429, 0.03913573195625629, 0.05981920619628259, 0.048645725939422846, 0.033183622772672346, 0.050318966154009104, 0.014341516154153007, 0.05723692583186286, 0.051423614379018545, 0.04410139710775443, 0.19682609981724195, 0.35897960300956455, 24.91576245852879, 98.98537812914167, 80.44772325243268, 84.21063831874302, 53.703981808253694, 74.5098900113787, 30.61255053111485, 23.460846151624406, 72.14084611620221, 69.02093124389648, 54.74125753130232, 34.84871782575335, 33.08287484305245, 17.568759850093297, 0.13379057656441415, 0.1933888178318739, 0.18404929898679256, 0.13302704824932984, 0.1692976084138666, 0.08214071486145258, 0.30587389692664146, 1.8194135938371931, 0.4570166766643524, 31.170494352068218, 99.34696238381522, 117.94603238786969, 108.0848501750401, 91.72008459908622, 90.6534457887922, 92.23864950452531, 89.68975843702043, 83.71186883108956, 83.74507427215576, 83.34710924965995, 83.58115237099784, 82.26807485307965, 82.15226922716413, 76.20544501713344, 75.06569726126534, 78.46783406393868, 85.47596086774553, 89.09070559910366, 93.49252142224992, 92.98345470428467, 94.18971061706543, 86.6354901450021, 86.81344740731376, 86.5306418282645, 91.37947000776018, 90.32387883322579, 93.88326031821114, 86.93655558994838, 100.7770962033953, 63.89477961403983, 54.23105130876814, 90.46157823290143, 70.41662979125977, 76.01988642556327, 74.20286996023995, 90.92656557900565, 63.221832684108186, 94.60919421059745, 100.47802489144462, 99.96884005410331, 88.005341393607, 81.64957400730678, 82.15893949781145, 87.02045508793422, 85.89438833509172, 89.00991194588798, 83.2831997190203, 85.93008123125348, 94.77989755358014, 100.1962754385812, 92.12746443067277, 94.82318483080182, 98.4352058683123, 89.59672900608608, 75.40030860900879, 74.70543316432408, 87.73854446411133, 91.8681229182652, 98.18015139443534, 98.93658093043736, 92.25868810926164, 84.32852145603725, 86.28362642015729, 95.27030141013009, 110.31149074009487, 24.08397797175816, 0.33307137180651936, 0.06354556445564542, 0.1827042390193258, 0.21463083156517573, 0.05493584055719631, 0.13831067830324173, 0.8633931992309434, 11.996901256697518, 27.08348056248256, 45.84125437055315, 46.807293687547954, 46.13538203920637, 76.44954913003104, 41.99793822424752, 23.76941738809858, 25.139289481299265, 46.751256465911865, 62.19445814405169, 55.60156611033848, 67.90769781385148, 56.99771976470947, 6.915384420326777, 0.2667209335735866, 0.04883969535252877, 0.026189411025760428, 0.06738536698477608, 0.05193592867414866, 0.04086689531270947, 0.03134250620912228, 0.08576270086424691, 0.07228037289210729, 0.03644772905058094, 0.16800847330263682, 0.09572835825383663, 0.018786242830434015, 0.03771420109218784, 0.0321838014226939, 0.03898452042735048, 0.03122830537280866, 0.0582756543798106, 0.03572408163121768, 0.03696384992716568, 0.0006906018097652122, 0.08233302525643792, 0.0694279270246625, 0.007043429284489581, 0.034715228980141025, 0.0830281436709421, 0.013676819857209921, 0.03160961491188832, 0.029911038199705735, 0.09880558920225926, 0.025441276973911693, 0.04216478352567979, 0.09066347431923662, 0.022442700108513236, 0.06379916013351508, 0.02697481700618352, 0.10066181674067463, 0.054307255893945694, 0.1190531352268798, 0.02761277902339186, 0.058431866711803844, 0.03094582785187023, 0.05512569804808923, 0.05622092820703983, 0.0412065529796694, 0.0493700756425304, 0.06002888708774533, 0.0537959831500692, 0.1253345917378153, 0.1857616635305541, 0.03435570720051016, 0.01825604065587478, 0.0951037939105715, 0.06281527078577451, 0.015192721371671982, 0.04007115354761481, 0.10755927448293992, 0.026088675716891885, 0.03655214880460075, 0.09672968595155648, 0.17086662564958843, 0.06476111244410276, 0.20855517472539628, 0.261631540954113, 26.525878940309795, 113.64018508366176, 92.95616912841797, 101.3738283429827, 74.8007207598005, 86.16479137965611, 59.89351354326521, 30.233248370034353, 22.06478977203369, 58.3888463973999, 58.61212675912039, 43.53671407699585, 42.08079201834542, 22.058560711996897, 0.233292498758861, 0.37833117746881073, 0.22066619699554785, 0.11579993979207107, 0.35912090114184786, 0.22008628025650978, 0.17901519340063843, 0.999106336917196, 0.7968461758324078, 39.12199892316546, 107.8495146887643, 121.14470509120396, 112.24252714429582, 95.08692455291748, 95.86484486716134, 97.65555545261928, 94.91701330457414, 87.73297895703996, 87.0884154183524, 88.01624311719621, 89.8748584474836, 88.84526743207658, 87.7358068738665, 80.8372392654419, 80.06609344482422, 84.40600081852504, 92.12765203203473, 93.7953656060355, 100.54095472608293, 97.2730154309954, 97.4609294618879, 91.13671384538922, 89.33753340584892, 88.43195383889335, 94.13254778725761, 93.38952827453613, 96.9801002229963, 92.31517001560756, 105.49456868852887, 68.26928901672363, 59.47038909367153, 96.9857838494437, 76.86979702540806, 82.80863775525773, 79.20118168422154, 97.55305562700543, 68.82656233651298, 97.51659842899868, 102.16297694614956, 101.67018290928432, 89.59645107814244, 85.18657534463065, 85.78748335157121, 92.05457782745361, 91.05640656607491, 91.8924902507237, 87.61362974984306, 90.04327583312988, 97.88364396776471, 103.22258417946952, 94.79107025691441, 96.36766515459333, 101.44802120753697, 94.59212248665946, 77.06465925489152, 78.72366673605782, 90.66747420174735, 95.20126410893032, 98.61226681300572, 103.33917495182583, 100.92009707859584, 91.78869111197335, 89.19114180973598, 98.70510864257812, 118.6253855569022, 37.2124776159014, 0.02450797750082399, 0.10285910312086344, 0.05481162454400744, 0.04018221276679209, 0.02425755906317915, 0.165717929069485, 0.6592222292508397, 13.592535087040492, 34.799830300467356, 44.889778477805, 42.665951933179585, 45.46908106122698, 45.57915094920567, 20.05393246241978, 26.924672535487584, 46.38278307233538, 67.34075954982212, 83.01135839734758, 70.42741339547294, 77.64068576267788, 76.37943485804966, 14.475781406675067, 0.21978606922285898, 0.06035015306302479, 0.08240245974489621, 0.04096537109996591, 0.03397079124780638, 0.027710301468947103, 0.032742815890482495, 0.09314319411558764, 0.07130333674805504, 0.04137631565598505, 0.079771514848939, 0.06457414890506438, 0.033206143349941285, 0.023290534703327075, 0.01836797179255102, 0.012447583272920122, 0.10817806449319635, 0.011438026641761618, 0.054331371028508456, 0.07783093183700528, 0.03312422042446477, 0.03096715760018144, 0.04033150743427021, 0.03515825806451695, 0.02866083403517093, 0.05103835576613035, 0.010901453871546047, 0.01567962622669126, 0.041443246350224526, 0.04773628545392837, 0.06707799740667854, 0.034172282221594026, 0.07908486455146756, 0.08373391508523907, 0.1987652579056365, 0.21166905335017613, 0.1938109208962747, 0.15088885836303234, 0.38697826489806175, 0.19718474628669874, 0.1908417602202722, 0.14203161506780557, 0.29758982573236736, 0.09671602704163108, 0.12298045520271574, 0.1459469792566129, 0.22567925442542347, 0.2103477149669613, 0.1892563902906009, 0.2870163773851735, 0.16375404516501085, 0.13585216951157364, 0.13676270922379835, 0.12481553958995001, 0.10853306044425283, 0.12804539342011723, 0.24480085979614938, 0.10258672559367758, 0.16047311121863977, 0.1760396273540599, 0.23483757727912494, 0.20587665773928165, 0.3135894371994904, 0.44188700137393816, 51.565110887799946, 139.01688929966517, 102.79616628374372, 111.53114972795758, 70.6600877216884, 94.93019403730119, 43.64277832848685, 35.44361216681344, 107.80417769295829, 110.86960479191372, 76.39898708888462, 55.3176383972168, 52.63691568374634, 29.448247841426305, 0.8159395541463579, 0.6136731505393982, 0.5943846798368863, 0.4701786818248885, 0.4504840129188129, 0.1577115822583437, 0.7399748989513942, 3.328095495700836, 2.25225944178445, 36.6979843548366, 108.5278742653983, 130.33624076843262, 119.01109395708356, 98.8677590233939, 97.04207815442766, 103.76241752079555, 100.02707290649414, 92.36154924120221, 89.50351892198834, 91.17005130222866, 92.0340597970145, 91.80902848924909, 93.13065923963273, 85.17886979239327, 84.58127607618059, 89.80939252035958, 97.2812282017299, 97.89063385554722, 104.38111986432756, 103.51913329533168, 102.50566904885429, 92.54051399230957, 92.62590040479387, 91.12603446415493, 98.47567217690604, 96.16527107783726, 100.66290950775146, 94.15223898206438, 107.78538281576974, 71.05942153930664, 66.84843799046108, 106.41972133091518, 88.92572062356132, 92.44166197095598, 92.66410854884556, 105.62278379712785, 75.59065450940813, 100.44742502485002, 106.9891609464373, 108.31834438868931, 94.00117819649833, 89.02797726222447, 90.47965744563511, 97.09451620919364, 95.75900990622384, 97.64655753544399, 91.71923691885812, 93.39176559448242, 103.91880757468087, 104.82688849312919, 97.54678835187639, 98.72340324946812, 105.83424527304513, 97.3381895337786, 81.05392578669957, 83.41264465876988, 95.75318036760602, 98.36366026742118, 102.86526611873082, 108.96101801736015, 103.21578189304897, 93.68689727783203, 92.10098484584263, 107.95732293810163, 122.59587805611747, 32.372237409864155, 0.28612350672483444, 0.186442763411573, 0.20206190672303947, 0.2980520437870707, 0.14879255156431878, 0.338918606617621, 1.7699376429830278, 22.089582681655884, 45.98929268973214, 65.75137301853725, 67.81072875431606, 75.10728222983224, 117.57887567792619, 60.52308981759207, 34.606785024915425, 34.08785533905029, 58.28396681376866, 83.35912268502372, 74.05982739584786, 88.6564153943743, 93.59335368020194, 22.670130729675293, 0.40467445818441256, 0.19242907076009683, 0.17987024251903805, 0.1723963421370302, 0.13756917523486273, 0.3360402067857129, 0.09178872965276241, 0.1734403089753219, 0.2644893947456564, 0.07738098169543914, 0.24500623877559388, 0.21097720547446183, 0.14184934699109622, 0.11124857794493437, 0.09774531716746943, 0.08180408685335092, 0.12280757805066449, 0.17677001601883344, 0.2040552119059222, 0.15902441181242466, 0.0885979730103697, 0.1464003085025719, 0.2406336505498205, 0.2162952372538192, 0.1079524312434452, 0.12130351018692766, 0.12195482238062791, 0.10674433356949262, 0.19660432743174688, 0.17743158766201564, 0.17899851500988007, 0.16984101996890136, 0.1518493246819292, 0.17585786139326437], [0.0115118088433519, 0.053539462986269167, 0.054100445205611844, 0.044258793483355215, 0.06360073613801173, 0.04353752772190741, 0.05891262912856681, 0.056365055830350945, 0.031216458151383058, 0.13089114214692796, 0.05887068209371396, 0.029485732450016906, 0.05414144229143858, 0.08468391839414835, 0.04232143012008496, 0.08516881308917489, 0.0905043917841145, 0.05724598427436181, 0.05143621816698994, 0.052871095814875195, 0.036983001578067026, 0.032002439190234454, 0.013004287328970219, 0.07383258960076741, 0.08039445749350957, 0.09118654339441232, 0.18170215136238507, 0.18946691256548676, 0.2485465088060924, 20.083288601466588, 92.35859625680106, 81.47850240979875, 100.16001973833356, 71.74922479901994, 74.28872885022844, 35.42679752622332, 44.34887858799526, 64.77336542946952, 64.8498511995588, 57.78753192084176, 34.371018750326975, 31.10108879634312, 11.95562287739345, 0.07299377104001385, 0.0612493883818388, 0.06282997463962861, 0.1661585561398949, 0.22121230911995682, 0.03763637312554887, 0.16772025876811572, 1.6688925964491708, 4.175053545406886, 75.71146283830915, 117.99586486816406, 98.72697462354387, 85.82587909698486, 87.24256815229143, 87.10978807721818, 84.10908344813755, 79.51401042938232, 79.99749388013566, 85.1653277533395, 94.49622344970703, 94.65225914546421, 89.65608051845005, 84.19242709023612, 81.6702310017177, 81.22310052599225, 78.50634098052979, 83.51836844852993, 85.11087472098214, 88.62468297140938, 86.0770286832537, 81.11890533992222, 81.5850669315883, 85.29471015930176, 88.80655206952775, 88.17364760807583, 85.57964188711983, 91.63121019090924, 86.94555350712368, 97.27083369663784, 98.756240436009, 90.87450967516217, 46.64422294071743, 74.37749208722795, 74.43158381325858, 65.81283678327287, 77.78949533190045, 59.38956069946289, 67.95601558685303, 95.17786257607597, 90.03666809626988, 88.5225305557251, 84.86800738743374, 86.67495591299874, 76.05897004263741, 84.17105443137032, 81.57966123308454, 83.31732927049909, 80.97498035430908, 81.52470098223004, 85.53422846112932, 91.54025132315499, 93.56806918552944, 86.66766030447823, 89.35113103049142, 97.8290797642299, 84.54055268423897, 73.1025254385812, 71.42920466831752, 83.42656190054757, 83.32834911346436, 85.40384551456997, 81.40367031097412, 81.20011588505336, 84.92073726654053, 87.74385288783482, 78.87588092258999, 112.68123640332902, 26.75487072127206, 0.807419054210186, 0.15407954715192318, 0.06883731657373053, 0.06968662528587238, 0.08140375119234834, 0.03966859907710126, 0.2979737679873194, 6.239481466157096, 26.536101477486746, 39.71106025150844, 37.92413990838187, 35.72348213195801, 71.36626788548061, 60.45244748251778, 31.409359523228236, 25.863100699016027, 27.560264212744578, 62.76653112683977, 58.207293442317415, 62.101887294224326, 62.554812567574636, 16.85551163128444, 0.5307171419262886, 0.12771500114883694, 0.03919417417741247, 0.043662904029978175, 0.03949508410213249, 0.04954353294202259, 0.1106992359938366, 0.07752930945051567, 0.014991632429882884, 0.00678797357250005, 0.06450383232108184, 0.060536173438387256, 0.03683823613183839, 0.037584451625921896, 0.06770172715187073, 0.005381897615734488, 0.009986873483285308, 0.03860047299947057, 0.04156684150387134, 0.04155181195320828, 0.021344277442299893, 0.01610795145721308, 0.036508312049720965, 0.03911916213110089, 0.08396718185395002, 0.014226412866264582, 0.03630350982504232, 0.03547076754538076, 0.06068313055272613, 0.07470137226794447, 0.08453285614294664, 0.0940854281985334, 0.03172812783824546, 0.008920283439303083, 0.012145634341452802, 0.02390483790077269, 0.06457805048142161, 0.12859284904386314, 0.02308648734885667, 0.03933400667405554, 0.1110620079562068, 0.03247214487886854, 0.03752543604267495, 0.04974799929186702, 0.04144857285012092, 0.047608965143029175, 0.0446140879898199, 0.08539403921791486, 0.0812610892046775, 0.05440030000837786, 0.022264691535383463, 0.0022426568362529254, 0.02883434561746461, 0.05064746531258736, 0.15301128875996384, 0.03984274848231247, 0.1114439010354025, 0.12116700251187597, 0.05116321299491184, 0.1490538146878992, 0.29718715591090067, 0.3079336849706513, 20.59348440170288, 110.81451252528599, 98.40533556256975, 115.88475894927979, 84.2998045512608, 90.82416302817208, 70.67005838666643, 22.64908116204398, 27.704729420798166, 61.77516910008022, 67.34111390795026, 44.86292021615164, 40.25635487692696, 15.979908330099923, 0.06993901317140885, 0.0434031913589154, 0.03233885345980525, 0.3557702680783612, 0.4914369668279375, 0.22173981581415447, 0.176753771890487, 1.17805914580822, 6.952289777142661, 86.16723019736153, 122.4993953704834, 102.5519232068743, 88.1951870237078, 90.01073741912842, 93.87777818952287, 91.4559279850551, 83.8016881942749, 84.23388699122837, 89.14670807974679, 99.8005963734218, 98.33575630187988, 93.92539419446672, 87.36352239336286, 86.98661041259766, 86.07067802974156, 82.73190185001918, 88.5751006262643, 89.55480357578823, 93.75493403843471, 91.09221063341413, 87.53137697492326, 85.25919791630336, 84.77166366577148, 89.29045936039516, 92.98822116851807, 92.33736256190709, 93.9523115158081, 90.41986124856132, 99.07595484597343, 103.24937643323625, 96.38069997514997, 53.0246981212071, 80.15892137799943, 82.00872639247349, 70.47236824035645, 85.66443770272392, 68.22043623243059, 71.50740664345878, 97.39922945840019, 94.50886222294399, 88.97282246180943, 88.57152925218854, 87.99948406219482, 79.44449370247978, 89.30600248064313, 85.31242111751011, 86.63452434539795, 85.09341389792306, 85.06591987609863, 88.76871218000139, 95.21793978554862, 94.12252848488944, 89.67777974264962, 90.46462849208287, 99.90377712249756, 87.79899379185268, 76.63793563842773, 74.86094079698834, 87.11422102791923, 87.30787427084786, 88.6058464050293, 83.47462259020124, 84.26671722957066, 90.20823301587785, 94.66713523864746, 82.80410058157784, 119.14765385219029, 40.388200419289724, 0.4489403728927885, 0.14577039730335983, 0.06535576017839567, 0.058454428001173904, 0.04617015877738595, 0.03249303697209273, 0.13137169421783515, 6.1969467656953, 32.587318897247314, 41.04216487067086, 34.15051071984427, 43.25405788421631, 51.10312168938773, 35.92804752077375, 26.03297199521746, 42.34502158846174, 52.09610959461757, 83.31876059940883, 77.39451803479875, 70.06500925336564, 80.40380368913922, 27.963070392608643, 0.393557964691094, 0.17154191727084772, 0.02001322922296822, 0.06931357351796967, 0.00953506161126175, 0.10579325817525387, 0.040939936214791875, 0.049084622745535204, 0.034431058514331064, 0.0334696524244334, 0.07892692874052695, 0.06048029607960156, 0.023822066806522862, 0.01402677598941539, 0.06296756118535995, 0.042688049376010895, 0.010353480016679635, 0.04487107295010771, 0.05131734561707292, 0.047905803857637305, 0.009926140358272408, 0.004657500415175621, 0.021850841153146963, 0.04586613776960543, 0.044355494901537895, 0.018948236280786138, 0.04188575974798628, 0.032922726058002026, 0.06812689719455582, 0.07157667100961719, 0.031202744958656173, 0.029053519213838235, 0.04929717384012682, 0.15521983882146223, 0.20355351668383392, 0.21269176847168378, 0.17253116704523563, 0.24531266519001552, 0.10209263674914837, 0.13289932081741945, 0.25815931441528456, 0.07997137055333171, 0.16195395961403847, 0.1454855075904301, 0.1011653168659125, 0.09804854089660303, 0.25051445034997805, 0.1549883633852005, 0.13665167375334672, 0.20929238945245743, 0.12978719281298773, 0.15853374956973962, 0.15107017649071558, 0.12416002047913414, 0.20680702424475125, 0.09511404657470328, 0.21474050996559008, 0.20002607096518787, 0.21738743436123642, 0.3028240448662213, 0.40460603471313206, 0.8990091223801885, 43.885058539254324, 130.33000128609794, 103.1246771131243, 126.9803581237793, 92.00035408564976, 92.29771614074707, 53.27800859723772, 65.72990308489118, 93.70033509390694, 96.48149749210903, 76.40240560259137, 57.624680042266846, 51.79734747750418, 23.94291043281555, 0.32041989639401436, 0.1676539116139923, 0.198397125516619, 0.4329113944300583, 0.36289105883666445, 0.23259890026279859, 1.6375553522791182, 4.2090402245521545, 6.0829250897680005, 89.65400995526994, 132.0620621272496, 110.82601874215263, 90.93310383387974, 94.91947991507394, 98.63316699436733, 95.17347826276506, 86.45637948172433, 85.22315761021206, 91.8526770727975, 103.79022421155656, 101.62152467455182, 97.95672512054443, 92.85941546303886, 90.64848477499825, 90.33899116516113, 86.19726031167167, 92.31762967790876, 95.25392450605119, 98.18650204794747, 97.7187145778111, 91.76878452301025, 90.96831730433873, 89.52106312343052, 97.49155017307827, 97.14405686514718, 96.41634423392159, 101.29033184051514, 94.0081958770752, 103.23698084694999, 107.21238572256905, 98.2615773337228, 60.96177128383091, 88.8047455378941, 92.30739498138428, 83.58265318189348, 96.5702885219029, 75.15794154575893, 76.12874385288784, 103.28394372122628, 97.82845442635673, 93.81115191323417, 90.7117064339774, 93.66768550872803, 86.45059163229806, 95.04192107064384, 90.24388422284807, 92.73284012930733, 89.32991818019322, 88.30196693965367, 93.00928810664585, 99.10073212214878, 96.42537689208984, 91.33098547799247, 93.73990508488247, 106.02105454036167, 91.38585540226528, 80.30846050807408, 78.78679806845528, 93.00511223929269, 91.47504942757743, 94.51831177302769, 88.57300921848842, 89.9178191593715, 95.43641199384416, 97.76182815006801, 88.66644164494106, 128.11145537240165, 35.78729091371809, 0.7652641162276268, 0.5939560085535049, 0.1166832973914487, 0.2782452808959143, 0.1921951933098691, 0.26827081612178255, 0.3738013319671154, 10.950234174728394, 45.25476387568882, 60.3286166872297, 56.74915838241577, 53.11221763065883, 105.09271267482212, 85.61652987343925, 42.641091278621126, 35.33046770095825, 36.07925769260952, 83.65469905308315, 80.47232682364327, 83.33859075818742, 96.06864942823137, 39.71831069673811, 1.056345596909523, 0.2365338605429445, 0.11256762966513634, 0.21255691642207758, 0.12732624129525252, 0.1316834810589041, 0.2201818179871355, 0.17038983266268456, 0.13041025080851146, 0.15390685998967715, 0.1740062478929758, 0.25652073376945084, 0.1275696318064417, 0.17753777839243412, 0.20881950482726097, 0.0926484131653394, 0.10627214105001517, 0.16009246664387838, 0.18261896073818207, 0.18899139522441796, 0.08226036094129086, 0.10109974324171032, 0.1625941302627325, 0.23105094475405558, 0.10208562748240572, 0.061078153284532685, 0.21605914777943067, 0.13179330873702252, 0.19012902703668388, 0.22460768478257315, 0.15284411130206926, 0.13147038035094738, 0.11503092891403607], [0.04857663071847387, 0.01968644336531205, 0.03245865221002272, 0.032667013350874186, 0.02519878212894712, 0.03446115832775831, 0.005096459561692817, 0.0815417787858418, 0.011414165957830846, 0.04501833879788007, 0.012963801688913788, 0.06485912682754652, 0.046766791226608415, 0.008190920210576482, 0.021774850320070982, 0.012666691560298204, 0.017065868180777346, 0.03397908294573426, 0.05688644213868039, 0.018132830570851053, 0.0532819046638906, 0.02422053988889924, 0.04645161171044622, 0.0044870812562294304, 0.02552142722665199, 0.06295534755502429, 0.16331693290599755, 0.12383006247026579, 11.175420948437282, 97.2305827822004, 103.19381168910435, 98.41570227486747, 65.00169713156563, 68.24237169538225, 50.760919434683665, 24.363142694745743, 66.3260029384068, 85.36781910487584, 53.19462674004691, 38.258143288748606, 32.4113974571228, 5.874880824770246, 0.6164354937417167, 0.0572692376694509, 0.04502676959548678, 0.054584203354482136, 0.07022497496966805, 0.1660993200327669, 0.19519692366676672, 1.5474198460578918, 14.829793861934117, 104.50761876787458, 101.59025083269391, 84.2176490511213, 84.31281157902309, 84.16168825966972, 76.89856951577323, 74.6261681147984, 76.50245966230119, 79.71334729875836, 81.65909998757499, 93.59074810573033, 94.0958890914917, 94.52321720123291, 89.79137584141323, 88.68866198403495, 82.61419241768974, 77.58845615386963, 76.72600405556815, 80.12458338056291, 86.65140151977539, 91.26384503500802, 92.32869815826416, 87.7229666028704, 79.20049381256104, 83.18054703303746, 82.9522431237357, 85.08885587964738, 86.1541189466204, 87.67837306431362, 91.77095236097063, 98.20069026947021, 84.16188975742885, 100.20029844556535, 59.7889917918614, 49.839654309409006, 75.49704837799072, 57.7257068497794, 74.14579745701381, 57.678420884268625, 90.42756680079869, 90.52873257228306, 92.6997319630214, 82.22085489545549, 84.15793623243059, 81.02213082994733, 76.27514239719936, 81.63017463684082, 84.99817493983677, 79.69412858145577, 80.48857866014752, 80.55512155805314, 84.47738661084855, 87.60028226034981, 97.62140505654472, 93.89486380985805, 88.70331573486328, 90.34125627790178, 86.02390275682721, 76.68107005528041, 76.4112298148019, 67.51210907527378, 68.38811710902623, 72.42098358699253, 73.83770043509347, 68.88298865727016, 70.48375633784703, 73.99689061301095, 90.27833339146206, 77.83640262058803, 110.19224575587681, 23.26366322381156, 0.7866434518780027, 0.13380323802786215, 0.08952779668782439, 0.12125108657138688, 0.03849991410970688, 0.00711172934721357, 0.3510124348104, 2.9096028889928545, 17.565240587506974, 43.678071703229634, 32.898580823625835, 30.779362882886613, 55.91185876301357, 73.14603505815778, 44.65047557013375, 26.48746756144932, 22.102501119886124, 50.518670490809846, 69.36573559897286, 58.080936976841514, 71.91855239868164, 29.940739631652832, 1.0609127346958434, 0.09480720625392028, 0.016124757073287452, 0.07555973263723509, 0.026245851568611603, 0.0338071184232831, 0.028594056011310647, 0.01503772022468703, 0.07161887588777713, 0.020548004723553146, 0.08586423005908728, 0.026253904082945416, 0.015723953223122016, 0.03408094123005867, 0.03368236976010459, 0.026390462648123503, 0.04460451725338187, 0.02050141990184784, 0.01989431935362518, 0.0077183434706447375, 0.04152515231232558, 0.04756705542760236, 0.0038972426388811853, 0.03066780830600432, 0.04822629291032042, 0.01846373513607042, 0.02049560485673802, 0.02591211411968938, 0.014652498931224858, 0.02404065177376781, 0.03451277787930199, 0.05688156007922121, 0.055943760222622325, 0.03175856013383184, 0.018475229519286325, 0.02397937836524631, 0.035713893427912674, 0.04452029409419213, 0.009450761268713644, 0.024185781932568977, 0.025548762009878243, 0.07386004312762193, 0.02970485176358904, 0.039331947320273945, 0.10241665079125337, 0.015649526413264017, 0.032550797265555174, 0.05136832056034889, 0.031314302901072164, 0.0313495256538902, 0.027701399089502435, 0.019734312314540148, 0.03248184114428503, 0.02525960431168122, 0.10189954603889159, 0.060252959706953595, 0.07958997280469962, 0.16630902806563036, 0.2166698971497161, 0.05879341731114047, 13.481550642422267, 110.49590982709611, 109.13463960375104, 109.94579315185547, 83.28477696010044, 100.38168811798096, 69.11995697021484, 25.15632472719465, 42.328269481658936, 77.17309284210205, 64.45563125610352, 48.460933685302734, 41.095909186771934, 8.896686264446803, 0.7218277241502489, 0.06269494617091757, 0.04965467019272702, 0.046058763683374436, 0.5666638101850237, 0.5528406947851181, 0.6310543407286916, 0.7448380951370511, 19.634348120008195, 117.41060420445034, 102.91678701128278, 89.36144910539899, 88.32237379891532, 89.39604418618339, 81.81471184321812, 79.2380210331508, 78.29380253383091, 84.64502579825265, 86.51924678257534, 98.06711809975761, 97.71053654806954, 97.41756575448173, 94.73870168413434, 94.84186853681291, 85.48741844722203, 82.3072418485369, 79.9500515801566, 85.17228290012905, 90.75076225825718, 96.34126199994768, 94.96699169703892, 93.4540353502546, 83.35802486964634, 88.46241474151611, 87.45478698185512, 88.07628944941929, 89.54465225764683, 91.55038874489921, 96.39354719434465, 101.49893065861293, 87.12481008257184, 100.72704138074602, 64.52484226226807, 55.31980970927647, 85.87191091264997, 68.32714666639055, 79.70539161137172, 61.61842468806675, 94.38280800410679, 93.33199719020298, 95.50401101793561, 84.24031407492501, 85.47020775931222, 84.71987179347447, 80.44413103376115, 85.34950365339006, 87.28082493373326, 83.86774471827916, 84.56988103049142, 85.35594463348389, 87.20449202401298, 89.27399212973458, 100.26511124202183, 94.55563749585832, 90.52380629948208, 93.88887446267265, 88.53774016244071, 79.1089790889195, 80.1634863444737, 71.15064443860734, 69.65680258614677, 74.86963299342564, 78.21073681967599, 72.61126000540597, 74.74202932630266, 76.45911679949079, 95.50286456516811, 81.668917792184, 115.04379068102155, 35.99828686032976, 0.31392050800578936, 0.078088205174676, 0.07900887541472912, 0.0785935577005148, 0.04621805317167725, 0.08653150139642612, 0.3435726511691298, 2.9951169746262685, 23.371851887021744, 51.304070540836875, 34.89799445016043, 37.698438099452424, 43.66547809328352, 30.396440710340226, 31.646178449903214, 30.609660080501012, 45.03732000078474, 69.1592629296439, 87.04250172206334, 70.76820169176374, 87.80816541399274, 47.75308247974941, 1.317960255912372, 0.13360388443938323, 0.017522691882082393, 0.1532497802483184, 0.02006733221268015, 0.025657741519223367, 0.08967877751482384, 0.026809458022138903, 0.03615939237975648, 0.09564972283052546, 0.11087558045983315, 0.029197999675359045, 0.039755074972552915, 0.06705593144787209, 0.02558501952859972, 0.040762960711227994, 0.051041005445378165, 0.0246206533296832, 0.027375415599505817, 0.0176267842429557, 0.04495216127751129, 0.03369098376216633, 0.07155856769531965, 0.027320459352007935, 0.030055749363132885, 0.06114618320550237, 0.07019051896142108, 0.028999531575079476, 0.02910151199570724, 0.016892285352306705, 0.01422145277527826, 0.04191384091973305, 0.11601593105920724, 0.07404087949544191, 0.0707699539405959, 0.09029540978372097, 0.2179311444716794, 0.11425635404884815, 0.08626389397042138, 0.21321354833032402, 0.11157004069536924, 0.1845893178667341, 0.05690477276220918, 0.1632907007421766, 0.2045283815158265, 0.15758741034993104, 0.10047337399529559, 0.14269368882690156, 0.11117930630488054, 0.14564960449934006, 0.16147988076720918, 0.1485911759414843, 0.12845575782869542, 0.15231227555445262, 0.24789332385574067, 0.12086588224130017, 0.10526923915105206, 0.22705118437962873, 0.27543275324361666, 0.44904435159904615, 36.98565714699881, 133.99933106558663, 120.0247527531215, 127.38577161516461, 86.94597734723772, 86.67338562011719, 65.37006282806396, 34.97591502325875, 104.04133210863385, 125.94920376368931, 72.44505909511021, 63.045536041259766, 53.30498150416783, 13.421892540795461, 1.566227751118796, 0.23694475420883723, 0.2719035569046225, 0.23996784484812192, 0.3398332989641598, 0.3984773978590965, 1.881127493722098, 5.032900725092206, 18.676709175109863, 122.68313353402274, 109.26232664925712, 93.0234624317714, 90.45241355895996, 97.61937618255615, 85.61366026742118, 81.66323416573661, 81.47705718449184, 89.61713586534772, 92.35949257441929, 102.36728872571672, 99.22920431409563, 102.07599939618791, 99.59220600128174, 98.59609835488456, 88.42110770089286, 88.68429156712124, 85.85258797236851, 89.11753954206193, 94.92705345153809, 102.01564039502824, 99.31860678536552, 96.41289792742047, 87.29552732195172, 94.57658631461007, 94.1777458190918, 93.78210149492536, 93.98177187783378, 94.01069722856793, 96.6927991594587, 103.19358934674943, 92.25644384111676, 107.04612922668457, 65.69184085300991, 60.758070945739746, 89.66557870592389, 74.20654555729458, 86.0352908543178, 66.33914893014091, 98.67206301007951, 98.09366716657365, 98.5165901184082, 87.50959437234062, 89.13110242571149, 89.63925198146275, 84.86208057403564, 91.05735846928188, 92.73345157078334, 89.50693743569511, 89.49608434949602, 89.91324029650006, 92.81619071960449, 94.98300034659249, 105.66000529697963, 96.25727912357875, 89.74494103022984, 98.07373973301479, 92.92665318080357, 85.1135219846453, 83.49368844713483, 75.43145738329206, 73.87137140546525, 81.06930909837995, 83.91841793060303, 76.2280683517456, 76.13295446123395, 81.5112909589495, 100.55117552621024, 87.21336487361363, 123.24003165108817, 31.73822123663766, 1.0034928215401513, 0.5688265455620629, 0.17894725847457135, 0.25432431591408594, 0.23634096660784312, 0.17331448144146375, 0.49273139451231274, 4.746440393584115, 33.210923194885254, 71.6371156147548, 52.76485633850098, 46.81853934696743, 81.23180661882672, 104.69354561397007, 58.089549268995015, 35.76123864310128, 29.91256468636649, 65.56932326725551, 90.18705490657261, 78.07485089983258, 100.55435085296631, 62.56853525979178, 2.9424943583352223, 0.2751095805849348, 0.10984661603080374, 0.28001720724361284, 0.06702338212302753, 0.13633517787924834, 0.12142632502530303, 0.07881366767521415, 0.21900265983172826, 0.13619868377489702, 0.28586194504584583, 0.09787359421274491, 0.12786906931017125, 0.08373956049659423, 0.146838940680027, 0.10957943608186074, 0.07687170045184237, 0.1391234818313803, 0.21409401537052222, 0.06474839669785329, 0.0766281063801476, 0.16696439789874212, 0.14216042815574578, 0.10512996983847447, 0.1021472927449005, 0.10932305841041462, 0.1419464453522648, 0.12066059825675828, 0.3316515237092972, 0.0819571100707565, 0.16091875944818768, 0.16480551660060883], [0.02086345395738525, 0.030547548151974167, 0.024108325463852713, 0.027371824452919618, 0.03581530048644968, 0.049959576688706875, 0.028769033229244605, 0.05907849022852523, 0.040927023693386994, 0.023908861613433276, 0.029595736547240188, 0.04266749655029603, 0.010922323912382126, 0.02165869191022856, 0.013421636407396622, 0.026763816364109516, 0.017464744991489818, 0.04230828011142356, 0.013296847880285765, 0.024705483777714626, 0.031106260671679462, 0.06143671154443707, 0.08084906917065382, 0.10143991998795952, 0.06036461264427219, 0.24481823029262678, 0.637681456548827, 13.773215174674988, 93.69816030774797, 108.75646999904087, 98.41408334459577, 75.97252750396729, 85.98559733799526, 44.92111832754952, 42.818770612989155, 86.79781396048409, 53.52616350991385, 53.36485760552542, 38.33393423897879, 29.230519090379985, 3.022019096783229, 0.9522245611463274, 0.10173533377902848, 0.04651136689686349, 0.11340124386229686, 0.04316672869026661, 0.009800257693443979, 1.271728788103376, 1.5893447335277284, 17.307425941739762, 97.27696895599365, 81.53530393327985, 84.46533148629325, 87.86302839006696, 78.90567479814801, 75.82309954507011, 78.98905318123954, 79.55232974461147, 80.71713270459855, 82.88600594656808, 84.91504669189453, 88.65802737644741, 89.59672205788749, 88.12585094996861, 88.90550136566162, 83.99218695504325, 77.0276323046003, 73.30305739811489, 72.12969425746373, 80.1557252066476, 87.84977122715541, 89.7059268951416, 87.61679118020194, 87.60166495186942, 83.76365375518799, 79.22816848754883, 80.59676906040737, 80.38886506216866, 82.86720412118095, 84.74818570273263, 84.57554381234306, 84.66064534868512, 87.57798549107143, 86.69614097050258, 87.2914070401873, 42.058502197265625, 67.98849841526577, 96.29015799931118, 58.53054101126534, 71.1336144038609, 89.40741838727678, 85.93064403533936, 81.2192164829799, 78.3221720286778, 82.23569624764579, 81.07268592289516, 77.68142305101667, 76.07777186802456, 79.90557616097587, 78.57966532026018, 79.76024069104875, 78.4134018761771, 79.25680201394218, 78.27502155303955, 89.06961781638009, 94.89734295436314, 86.26931313105992, 87.6525605065482, 87.20110825129917, 69.86160768781389, 72.64971133640834, 71.68406459263393, 67.12562247685024, 66.9739294052124, 67.28679983956474, 74.27745887211391, 71.87439659663609, 73.41045570373535, 75.01388454437256, 89.66933073316301, 80.64623328617641, 97.69470855167934, 27.05325937271118, 0.5445378146001271, 0.1461628619581461, 0.05249817296862602, 0.09205253049731255, 0.019422722248626605, 0.06451403748776231, 0.2994663821799414, 0.9101723805069923, 11.590403846332006, 30.39849042892456, 35.819735527038574, 56.51000486101423, 95.09478991372245, 104.05861227852958, 71.14605167933873, 26.229705027171544, 21.555745635713848, 35.33935792105538, 65.17576340266636, 60.2669792175293, 72.63420295715332, 37.53876849583217, 0.854431434401444, 0.04115548643416592, 0.13241613603063992, 0.05098954534956387, 0.024112666391634514, 0.048946184638355456, 0.013575266065475131, 0.0396571318352861, 0.12276111197258745, 0.025935091011758362, 0.03456273162737489, 0.05305829344849501, 0.03693500879619803, 0.052064894432468076, 0.024395079451746175, 0.018468742724508047, 0.023572711972519755, 0.07274765960339989, 0.048958666290023496, 0.008113722433336079, 0.03285936785063573, 0.08503417817077466, 0.04500609802614365, 0.03901944462476032, 0.03429445245170167, 0.041860090768230815, 0.00516527912779046, 0.030785015052450553, 0.12611675262451172, 0.004825498900442783, 0.028506104302193438, 0.03426488868093916, 0.0691306269062417, 0.04104591999202967, 0.034148150123655796, 0.020478744957862154, 0.0924330936478717, 0.011138573022825378, 0.017405525847737278, 0.0334638305939734, 0.019249307357573082, 0.04305984585412911, 0.029181504489055703, 0.010016278646487211, 0.07628940205488886, 0.06373389185007129, 0.037583444001419206, 0.030776339982237135, 0.054425337950565984, 0.008660956685032164, 0.03415865384574447, 0.058127889808799536, 0.04778333507212145, 0.027487253437616994, 0.07550135148423058, 0.0784562968515924, 0.36124384722539354, 0.6122191857014383, 15.213214567729406, 106.6366024017334, 115.61714213235038, 110.87075124468122, 93.0722735268729, 100.59399032592773, 64.96102932521275, 55.56142636707851, 35.46459920065743, 54.16707924434117, 63.21173695155552, 46.87656375340053, 38.35264573778425, 5.077883362770081, 0.7791529138173375, 0.10523077978619508, 0.061878648187432966, 0.09485595899501018, 0.29814223466174944, 0.3355846383741924, 1.348713525703975, 0.6026454365679196, 20.62981653213501, 110.83216094970703, 84.78419126783098, 91.24747507912772, 91.72975649152482, 84.68937614985875, 79.06781101226807, 81.75005885532924, 84.1129674911499, 86.04408727373395, 86.34170641217912, 88.10205336979458, 93.54001930781773, 95.41062028067452, 92.9265489578247, 93.98886598859514, 86.65701566423688, 80.83501584189278, 76.59685788835797, 79.47263390677315, 82.39454596383231, 94.05352592468262, 93.42365782601493, 90.97669683183942, 89.46137809753418, 86.81454522269112, 84.59552683149064, 85.57223510742188, 85.97106865474156, 88.21350942339215, 84.47815091269356, 85.46676840100969, 86.95424570356096, 89.36401299067906, 91.0461093357631, 92.78947489602226, 47.47936167035784, 68.9846408026559, 99.11314160483224, 62.77825968606131, 76.18639305659703, 92.32354954310826, 89.2676692690168, 84.20590659550258, 80.26593058449882, 85.5242508479527, 83.41360351017543, 81.16593074798584, 79.33018888745988, 82.277038029262, 82.41024194444928, 84.10968099321637, 81.92673070090157, 83.65574128287179, 82.83159460340227, 91.09666442871094, 97.80328110286167, 87.38126809256417, 91.60732228415353, 92.25655501229423, 74.34965760367257, 74.71874591282436, 75.08627782549176, 72.75456660134452, 69.7647567476545, 70.64502402714321, 77.24985654013497, 77.60754980359758, 79.18593038831438, 80.53401987893241, 95.78247397286552, 85.29597473144531, 102.39884744371686, 39.86577231543404, 0.7333457203848022, 0.057041202405733724, 0.1597250263605799, 0.2646410608930247, 0.04984903654881886, 0.05952263889568193, 0.3561747835150787, 0.4106555815253939, 12.945466722760882, 37.41097722734724, 36.685692991529194, 56.56515966142927, 85.57224900381905, 70.45107895987374, 40.83148506709507, 21.530577523367747, 43.89894451413836, 59.3579602922712, 77.70197582244873, 74.91252422332764, 82.77306992667062, 59.952239717756, 1.9743905578340804, 0.08898277700479541, 0.09714077639260463, 0.04838186063404594, 0.04425212009144681, 0.02451388245182378, 0.012280234484933317, 0.051308300745274336, 0.03920798575771706, 0.06825203940804515, 0.08219977454947573, 0.027984785847365856, 0.05056096566841006, 0.04258194685514484, 0.05001421232840844, 0.004763280207823429, 0.05758577425565038, 0.04941868928394147, 0.04013555669890983, 0.014929158014378377, 0.10275860529925142, 0.036938890016504695, 0.03924526447164161, 0.02636097521255059, 0.023105662748483673, 0.025916494063234756, 0.08003929190869842, 0.04995287276272263, 0.08325628071491208, 0.015302328525909355, 0.05925738598619189, 0.14471641528819287, 0.1327143114592348, 0.1878280605056456, 0.10983615302081619, 0.16802166402339935, 0.13774701926325048, 0.11199932944561754, 0.18500948032098158, 0.10244192622069802, 0.06542091989623648, 0.15723472141793796, 0.12433862446674279, 0.08239272955272879, 0.19266928572739872, 0.16013499721884727, 0.13462290833038942, 0.11057089109505926, 0.09676311737192528, 0.11986393029136316, 0.20074724512440817, 0.19636789868984902, 0.1195694732346705, 0.0883556477991598, 0.18585916901273386, 0.19474085313933237, 0.5521609112620354, 0.5177382326551846, 41.27731622968401, 130.92612893240792, 127.8215765271868, 122.68710790361676, 94.20212009974888, 107.3330272947039, 55.70800903865269, 61.516710008893696, 129.30450275966098, 73.81156826019287, 75.04786818368095, 63.51954909733364, 49.184731006622314, 6.979891496045249, 1.2898863852024078, 0.39223834978682653, 0.195940584476505, 0.1975541678922517, 0.21700518844383104, 0.10531562380492687, 4.712388575077057, 4.573570949690683, 21.876993860517228, 119.45291600908551, 88.3259173801967, 95.73182160513741, 97.76379449026925, 92.6957506452288, 81.5178917476109, 85.90658937181745, 87.83272729601178, 91.68487112862724, 90.18079457964215, 91.77944305964878, 97.37908663068498, 100.83755942753383, 96.43243626185826, 97.93569292340959, 91.5929673058646, 86.88200528281075, 81.52359621865409, 83.5451329095023, 86.48117065429688, 98.27188846043178, 98.68718229021344, 96.32269641331264, 93.24713884081159, 91.55306380135673, 88.2771132332938, 93.57965183258057, 92.97841726030622, 93.22025626046317, 89.9680893761771, 88.56016199929374, 91.91746207645961, 92.4408768245152, 94.93931007385254, 95.36993857792446, 53.784084115709575, 75.75140803200858, 101.4855067389352, 72.80467700958252, 80.76647881099156, 97.66223961966378, 94.37356689998082, 89.18474946703229, 83.39962373461042, 89.28269822256905, 91.03355394090924, 87.80374635968889, 82.32867009299142, 88.37862641470772, 85.82817200251988, 89.63750103541783, 85.36629744938442, 87.57073851994106, 85.3431738444737, 97.44239861624581, 103.03074441637311, 90.92121546609062, 96.1677793775286, 95.56356402805874, 76.85951369149345, 81.38144302368164, 81.81950610024589, 77.92712524959019, 72.64250605446952, 74.08757850102016, 83.37472139086042, 81.82899039132255, 80.53255380902971, 85.31080913543701, 99.10029438563755, 89.8616429737636, 106.95129326411656, 35.097848960331504, 1.0130310697214944, 0.5900351075189454, 0.2846339595104967, 0.33750757947564125, 0.0728388207831553, 0.22156689795000212, 0.4815427320344107, 1.2442384575094496, 18.224542992455618, 49.407507623944966, 53.09351308005196, 82.16209397997174, 128.8006749834333, 145.73447717939104, 103.79741559709821, 37.953516892024446, 30.62871551513672, 49.166561467306956, 85.11322321210588, 80.20071479252407, 96.60474463871547, 72.85277244022915, 2.8284325131348202, 0.2653358264693192, 0.2183795611241034, 0.1845060344785452, 0.12277662328311376, 0.1528252615992512, 0.06982436789465801, 0.0820305614865252, 0.32500264048576355, 0.1635370496660471, 0.175037024010505, 0.10993833360927445, 0.12449285547648158, 0.13785086226250443, 0.17568848548190935, 0.07391499767878226, 0.1313792395272425, 0.1787729835403817, 0.24147639104298182, 0.08670894508915288, 0.11897871350603444, 0.13328949202384266, 0.12930166029504367, 0.13013138648654732, 0.12853859338377202, 0.18596559044505867, 0.12716840047921452, 0.1602698764098542, 0.2250519623713834, 0.10144578253052064, 0.07405780894415719], [0.0012060493463650346, 0.009453628079167433, 0.024265898258558342, 0.051036052139742036, 0.006350413056290043, 0.017055452668241093, 0.06216098660869258, 0.037882464206112285, 0.08034873101860285, 0.014476057773988162, 0.04528040937813265, 0.048737501193370135, 0.07408946938812733, 0.029740831082952873, 0.022340039456529275, 0.011330988590738602, 0.01759762080785419, 0.030618170076715093, 0.038953752256929874, 0.018941415307511176, 0.051152390361364396, 0.004999175451562873, 0.09098549346838679, 0.09575003066233226, 0.10359727458230086, 1.0130654850176402, 32.088215896061485, 101.28463431767055, 103.78381102425712, 92.06524331229073, 86.70178290775844, 89.09506906781877, 43.242238998413086, 51.01078360421317, 45.806589807782856, 59.2187739780971, 37.856016295296804, 36.13192503792899, 22.95176206316267, 1.2859277576208115, 0.2635132542678288, 0.2020111387329442, 0.3161415702530316, 0.1539511140435934, 0.2159742766192981, 3.328803994825908, 27.13215443066188, 1.2669957620756966, 4.314093513148172, 81.7473976952689, 84.25366851261684, 89.6279889515468, 82.2813389641898, 78.86508342197963, 86.7866690499442, 93.23968342372349, 90.23076602390834, 85.5353193283081, 83.19540228162492, 79.99151148114885, 82.93426813398088, 85.98281111036027, 85.36083616529191, 90.26809869493756, 88.09256907871791, 75.0150796345302, 72.56106621878487, 69.06664344242641, 72.77299322400773, 80.0347431727818, 87.83447129385812, 89.12030492510114, 89.99003178732735, 87.67158467429024, 85.53274154663086, 88.34071009499687, 85.02978229522705, 81.41416209084647, 80.37419046674455, 83.75927639007568, 78.74989618573869, 83.0233370917184, 81.49271842411586, 84.84376512254987, 89.23158032553536, 69.2757077898298, 22.820564440318517, 53.82124308177403, 43.80717270714896, 82.90685054234096, 88.79379517691476, 84.46972969600132, 78.16296795436314, 80.204605783735, 81.39927904946464, 78.73561763763428, 78.46700722830636, 77.0822868347168, 75.58473464420864, 77.34740924835205, 77.79499830518449, 75.7613022668021, 79.31394399915422, 79.50567259107316, 83.30177225385393, 93.79041848863874, 90.3911234991891, 90.20498820713588, 80.08353342328752, 68.80159745897565, 68.24107238224575, 65.07991300310407, 67.87092099870954, 69.79475212097168, 72.08399595533098, 73.47487245287213, 77.27859428950718, 80.96294607434953, 85.1407311303275, 81.57221971239362, 94.54211630140031, 78.44100012098039, 90.16125624520438, 30.38820709500994, 0.6732164440410477, 0.2587220642183508, 0.10731509008577891, 0.1426348869821855, 0.09887448086270265, 0.03565888459395085, 0.15136829763650894, 0.25884479763252394, 9.053342955453054, 33.55364309038435, 65.39087963104248, 77.2418522153582, 86.07390199388776, 116.20236805507115, 84.51617840358189, 26.724051986421856, 23.037905829293386, 41.2637985093253, 55.43076549257551, 58.85427842821394, 69.09479754311698, 52.11631495612008, 0.6766593850084713, 0.34800231776067186, 0.028733325323888233, 0.03535727917083672, 0.02398223160499973, 0.03887422795274428, 0.029657313600182533, 0.050163741090468, 0.04474544558408005, 0.03386626292818359, 0.046160683035850525, 0.03917585373190897, 0.032914610779178996, 0.0342339949815401, 0.012659052952325769, 0.0507696423280452, 0.08130223556820836, 0.016241175022774508, 0.006403325217044247, 0.028565811991159405, 0.022281649821837033, 0.03842147546155112, 0.05945471754031522, 0.08706366284085171, 0.0654699644073844, 0.03157569833898118, 0.040850610472261906, 0.0250492364035121, 0.008807264102090682, 0.06363884266465902, 0.005837719629718257, 0.024700043623202612, 0.02504330431111157, 0.01497899810783565, 0.01918963698803314, 0.05045995894553406, 0.04113143576042993, 0.01997160449224923, 0.08525542808430535, 0.05008987576833793, 0.03762136732361146, 0.10548305910612855, 0.04498362494632602, 0.051254384352692535, 0.03168131570730891, 0.057879545991974216, 0.0656066620722413, 0.04998025504340019, 0.031115800874041658, 0.041696869169494936, 0.06639392554227795, 0.06662681911672864, 0.05001607151435954, 0.08518284519336053, 0.09586248427097287, 0.864221066236496, 38.93365410396031, 114.73902879442487, 113.24875136784145, 108.54774611336845, 110.32402529035295, 103.712876864842, 69.1616461617606, 60.065245219639365, 27.520350285938807, 55.04111398969378, 46.56427696772984, 45.54117556980678, 29.853122847420828, 1.888136271919523, 0.271966850651162, 0.11838251192654882, 0.24603150518877165, 0.11409551410802773, 0.5983976987855775, 7.271728430475507, 23.431693247386388, 1.294500749026026, 6.431828882013049, 92.33725139072963, 89.74485070364815, 95.47713538578579, 89.34329346248082, 83.07589326586042, 91.91482176099504, 99.61578123910087, 96.57923085348946, 88.00022751944405, 86.1642633165632, 85.79651600973946, 88.30867195129395, 89.46720068795341, 89.79832404000419, 94.14133725847516, 90.66693919045585, 78.74501855032784, 74.66423729487828, 74.01780469076974, 77.82623740604946, 84.43096569606236, 91.11758545466832, 92.32518236977714, 93.79946504320417, 92.6406375340053, 89.73743002755302, 92.43035725184849, 89.59475571768624, 86.7238712310791, 86.64758001055036, 88.06866032736642, 80.9064850125994, 84.38679599761963, 84.82792322976249, 88.79119655064174, 90.93098463330949, 77.17539964403424, 26.27565520150321, 53.32505137579781, 48.022193159375874, 86.10794121878487, 92.4427250453404, 87.1136234828404, 79.94256142207554, 84.3639225278582, 84.06959683554513, 82.09514113834926, 80.23027242933, 82.3494313103812, 77.86981650761196, 81.40892314910889, 82.66019644056047, 78.78893116542271, 83.79176616668701, 82.4733385358538, 87.07687446049282, 96.86782428196499, 93.78561728341239, 92.57497705732072, 81.31332288469586, 72.62017454419816, 73.51827784946987, 68.06436579568046, 71.74081747872489, 74.17788423810686, 78.11273942674909, 77.28727953774589, 81.2419023513794, 84.51057120731899, 89.01859024592808, 84.64190605708531, 98.34863826206752, 83.69579764774868, 94.96642889295305, 41.58678552082607, 1.92890265583992, 0.27737534471920555, 0.16371981985867023, 0.3279526936156409, 0.16064141504466534, 0.05891466473362275, 0.08489511920405285, 0.2575058309095246, 10.039710095950536, 40.90461833136422, 69.49758461543492, 80.57875932965959, 71.07358196803501, 93.82197025844029, 51.522508008139475, 18.760591302599224, 37.13806240899222, 65.50064032418388, 72.69469397408622, 74.78013324737549, 76.59393964494977, 75.38341059003557, 2.1817951542990546, 0.3179679965334279, 0.09932607984436409, 0.016869881822328483, 0.05453840224072337, 0.04324777291289397, 0.06550743989646435, 0.054796421966914616, 0.0652458578614252, 0.014285553978489978, 0.03667869219290359, 0.0027788576844614, 0.005276609336890812, 0.027128457690456083, 0.034213174134492874, 0.05451024643012455, 0.02607768853860242, 0.020425478262560706, 0.05291038638513003, 0.04425279184111527, 0.040914830419101884, 0.027930497956861342, 0.05002801712336285, 0.04169591922046883, 0.05872792511114052, 0.01372359466872045, 0.015417952589424593, 0.02597881411202252, 0.012907702958078256, 0.028195321692952087, 0.0430036733326103, 0.07873165314751011, 0.09784782345273665, 0.13827966925288948, 0.1612173691391945, 0.09012191516480275, 0.14570042677223682, 0.19052860273846559, 0.1823210838649954, 0.1236010840428727, 0.13994833614145005, 0.20695915179593222, 0.12548727568771156, 0.08959196574453797, 0.08069086194570575, 0.15336371984864983, 0.14724693021603993, 0.10652180122477667, 0.10672638631824936, 0.10740772368652479, 0.2744992790477616, 0.12207716224449021, 0.1878983974456787, 0.19077671585338457, 0.29200154702578274, 1.4808026892798287, 71.1916527066912, 138.13785879952567, 124.72586223057338, 116.28447491782052, 108.78953647613525, 111.65354224613735, 53.020987783159526, 70.84920379093715, 65.5951566696167, 82.66490037100655, 63.51653357914516, 61.767498288835796, 40.24259049551827, 2.317214676312038, 0.6316489545362336, 0.3298140237373965, 0.5526851202760423, 0.466925567814282, 0.38037381214754923, 4.253609010151454, 48.16217851638794, 7.769207290240696, 6.045617605958666, 103.20230238778251, 92.10985769544328, 98.47736753736223, 91.47953796386719, 86.90586539677211, 93.46046243395124, 104.03827490125383, 101.21661145346505, 93.67432798658098, 89.49942643301827, 91.19075693402971, 92.78419426509312, 94.79443318503243, 93.24666636330741, 98.87115669250488, 94.63902282714844, 84.12858704158238, 79.43815694536481, 77.80025114331926, 82.45299421037946, 87.45359883989606, 96.80580466134208, 99.05595098223004, 99.03194495609829, 96.76130144936698, 92.30221162523542, 97.14776720319475, 92.48512295314244, 91.36494827270508, 89.33153711046491, 90.95002269744873, 83.15159388950893, 87.07827104840959, 87.04812976292202, 93.65950053078788, 93.14845357622418, 79.88689940316337, 33.87442752293178, 67.67708710261753, 54.547680718558176, 88.30731010437012, 97.45992197309221, 92.07199696132115, 85.1112916128976, 88.47688783918107, 87.53168964385986, 86.80567237309047, 84.40077577318463, 86.08852100372314, 83.45347922188895, 87.5001448222569, 87.16064194270542, 83.85522406441825, 89.1992712020874, 87.61240686689104, 92.51214449746269, 102.46693284170968, 97.0515832901001, 96.32463496071952, 86.45858206067766, 78.83731842041016, 77.90580817631313, 71.03403282165527, 76.73360538482666, 78.75822012765067, 83.44238989693778, 82.37928077152797, 85.48119286128453, 90.15325886862618, 92.7744528906686, 89.6821710041591, 102.74067102159772, 86.03268527984619, 102.00646877288818, 38.339923586164204, 1.9382803354944502, 0.800301656126976, 0.20884808472224645, 0.3903643717723233, 0.27282324326889856, 0.1898645476571151, 0.16898561801229203, 0.5244749454515321, 16.053090231759207, 53.17367444719587, 76.02678598676408, 84.75184740339006, 100.1276341847011, 148.69870376586914, 131.74176406860352, 39.420465741838726, 31.81893151147025, 54.974088191986084, 74.48254884992326, 78.83903462546212, 89.45208140781948, 89.29436424800328, 3.576456683022635, 0.5752603060432843, 0.1559722391622407, 0.15000537862735136, 0.12826217178787502, 0.1259052668298994, 0.22241555526852608, 0.1391027865133115, 0.24476001198802674, 0.1268209634082658, 0.13540539491389478, 0.09576932141291243, 0.11008642387709447, 0.1185554162200008, 0.06293272519750254, 0.1371376541044031, 0.10793088097125292, 0.08347143059862511, 0.11113839064325605, 0.15685231265212807, 0.15992903469928674, 0.13705500853913172, 0.09313755548958268, 0.18820200115442276, 0.12103296470429216, 0.06131429025637252, 0.10587936426912035, 0.06257219918604408, 0.11444786377251148, 0.12122239811079842], [0.054411723145416806, 0.06283248521919761, 0.055181707721203566, 0.05055645341053605, 0.020774913619139364, 0.03128219123131462, 0.07379988421286855, 0.044520236418715546, 0.029025139486683265, 0.015262831002473831, 0.0449145534741027, 0.01712796261667141, 0.07357771827706269, 0.028420836199074984, 0.029475876728871038, 0.04909571340041501, 0.07715553843549319, 0.04369840158947876, 0.017490279960579107, 0.044610501932246346, 0.01453662380975272, 0.03438965770016823, 0.034004789244915755, 0.391475323587656, 4.279735539640699, 63.19365079062325, 98.79137052808488, 99.50539520808628, 85.53915473393032, 103.66050134386334, 55.96627358027867, 33.56550366537911, 44.057481561388286, 42.89466231209891, 104.36774458203996, 36.94099065235683, 26.623007808412822, 25.05500783239092, 0.5473276791828019, 0.30907283670135904, 0.06860748997756413, 0.3181947357952595, 0.05799130070954561, 0.15640028619340487, 0.060523267702332566, 20.466332367488317, 10.55629997594016, 0.9230111858674458, 52.59096029826573, 88.77157483782086, 99.13732133592877, 86.58845778873989, 89.74250221252441, 98.23424312046596, 95.21076924460274, 91.61240141732353, 92.93279538835797, 91.48472826821464, 89.60771410805839, 86.05566992078508, 82.7727781023298, 82.15096991402763, 85.98008046831403, 82.91219370705741, 78.22493893759591, 68.5218699319022, 68.64511707850865, 70.76454693930489, 75.9364733014788, 85.66631371634347, 88.77680683135986, 84.93327876499721, 88.03059809548515, 79.7587468283517, 84.50634670257568, 86.22785323006767, 82.67460005623954, 87.36911569322858, 85.58510317121232, 82.93180847167969, 84.74367632184709, 85.24707330976213, 82.45566926683698, 83.22964995247978, 82.45252868107387, 84.40905802590507, 46.14424099240984, 15.06748652458191, 42.7646233013698, 85.31837572370256, 82.43478993007115, 78.75660119737897, 71.6906931740897, 77.45702402932304, 79.7495265688215, 78.85348687853131, 77.10444464002336, 77.74094826834542, 72.94892161233085, 73.95833505902971, 73.75691373007638, 73.51155894143241, 74.00424875531877, 74.46834673200334, 74.11353697095598, 81.01896245138985, 87.76359966823033, 85.3127407346453, 68.63671670641217, 66.5167657307216, 64.21070725577218, 66.53079414367676, 66.64135387965611, 70.63130828312465, 71.56903716496059, 78.91161550794328, 82.45764255523682, 80.8272408076695, 80.6241032736642, 84.67994744437081, 80.4261977331979, 89.44676603589738, 72.64974607740129, 82.27182688031877, 32.48760182516915, 0.38965722971728867, 0.3329826465674809, 0.09509172277258975, 0.08115798580859389, 0.18489216161625727, 0.04741105004878981, 0.08203582013291971, 0.36135105575834003, 6.654595077037811, 41.14683600834438, 73.91396386282784, 96.42987932477678, 103.70845086233956, 100.79040895189557, 88.69722216469901, 31.517233780452184, 18.99035780770438, 38.11833511080061, 58.82601315634591, 65.13679095676967, 62.43922233581543, 55.12429434912545, 3.2509819992950986, 0.15410037817699568, 0.06291951412068945, 0.09886193475020782, 0.031349250847207646, 0.03703283318983657, 0.03582832496613264, 0.015869958692097237, 0.04227450942354543, 0.019125476413007294, 0.02661132749303111, 0.061710934686873636, 0.06723321229219437, 0.02682157326489687, 0.04440237149330122, 0.02517922844604722, 0.03337505446480853, 0.04541792467768703, 0.06203062646090984, 0.05966054435287203, 0.07902405424309628, 0.06347481360925095, 0.06480674392410687, 0.04705627801428948, 0.06432187637048108, 0.05991249797599656, 0.04346917210412877, 0.02167637114013944, 0.05031853189159717, 0.06094393227249384, 0.028850247085626637, 0.1730516441166401, 0.02159713182066168, 0.03098876215517521, 0.03373914957046509, 0.006359702624779726, 0.04300373779343707, 0.01840739806980959, 0.034524190838315656, 0.020088220913229243, 0.027942798100411892, 0.0672852559281247, 0.0792594923238669, 0.0016909097965773462, 0.016848384136600152, 0.02598071570641228, 0.06535301211157016, 0.030228704546711276, 0.04294819291681051, 0.02747477517862405, 0.03848952573857137, 0.08784053793975286, 0.3329926346029554, 5.288338652678898, 78.40304906027657, 118.45423752920968, 109.1030878339495, 104.45506259373256, 109.43205029623849, 73.1857579095023, 64.01264885493687, 49.520328998565674, 22.01704522541591, 55.5313059261867, 40.35714544568743, 32.25396169934954, 34.323632035936626, 0.7685768327542714, 0.3473245155598436, 0.026273281346740465, 0.4597385248967579, 0.043949408656252284, 0.4055164930011545, 0.1675192495541913, 12.031902807099478, 4.842385896614619, 0.7100050385509218, 60.785426003592356, 94.85280500139508, 102.76847076416016, 92.28467437199184, 92.9989491871425, 103.462936265128, 99.6333532333374, 96.51903166089738, 97.3424209867205, 97.82798889705113, 96.41358579908098, 88.49491841452462, 86.35596411568778, 86.46373762403215, 90.54735374450684, 85.68944426945278, 81.67422621590751, 71.4806352342878, 70.49578366960797, 73.79918657030377, 79.27172674451555, 87.64335414341518, 92.63592665536063, 90.13879271915981, 90.96990149361747, 84.60805443355015, 88.15169130052838, 89.81843212672642, 88.2062555040632, 89.5164703641619, 89.17668955666679, 86.0329006740025, 86.49818679264614, 86.1698774610247, 84.4865721293858, 85.71626431601388, 84.44659219469342, 86.1325169972011, 52.06483575275966, 18.889725310461863, 48.019372190747944, 91.03999492100307, 84.432619367327, 80.92960861751011, 74.68479701450893, 81.0091724395752, 83.43455927712577, 82.46614715031215, 80.75127615247453, 81.07814720698765, 77.47283118111747, 77.65062168666294, 78.70879759107316, 77.43490096500942, 77.50359085627964, 79.76447909218925, 78.66209874834333, 84.20661531175885, 90.74943515232631, 87.5236714226859, 73.20746408190045, 70.18884699685233, 68.18083150046212, 69.98384039742606, 70.97078336988176, 74.80484104156494, 75.75834233420235, 82.00436987195695, 87.27712849208287, 86.84058012281145, 84.06989560808454, 87.64828041621617, 85.23164136069161, 93.27169377463204, 78.82511738368443, 87.31785883222307, 46.26303086962019, 1.447374471596309, 0.34625623002648354, 0.11967807954975537, 0.18263117436851772, 0.09439140677984272, 0.05442666448652744, 0.10488184315285512, 0.3294403680733272, 7.973932487624032, 43.84066302435738, 75.35866110665458, 95.26754992348808, 99.49634865352085, 94.30111108507428, 39.75937802450997, 9.80538991519383, 28.32516881397792, 53.390861238752095, 74.0812347957066, 81.83251312800816, 69.81201839447021, 80.2436477116176, 7.176519436495645, 0.21418336486177786, 0.04995882351483617, 0.06447316253823893, 0.05684659177703517, 0.03631084478859391, 0.046123584133705924, 0.03643232291298253, 0.03934011688189847, 0.044935130048543215, 0.03403590346819588, 0.05548886016809514, 0.022086131652551036, 0.04219209795285549, 0.02821772183025522, 0.037299365137836764, 0.03798475336017353, 0.0414561622643045, 0.07225539601807084, 0.023826865745442252, 0.03998238081112504, 0.04927265836990305, 0.01811058140758957, 0.019405938684940338, 0.02530668955296278, 0.0743524424199547, 0.07479083032480308, 0.03811155119910836, 0.03261626910950456, 0.16718517962310994, 0.13391607840146336, 0.2111025308924062, 0.1506367147501026, 0.09238351309405905, 0.15836623284433568, 0.08985100327325718, 0.18181663379073143, 0.0705063905833023, 0.1608214575265135, 0.0750461019841688, 0.07644352449902467, 0.15431926000331128, 0.18334363613809856, 0.05640722338908485, 0.13536988039101872, 0.21281864094947064, 0.18721569622201578, 0.1769831438681909, 0.08363165985792875, 0.10683386626520328, 0.15275789664259978, 0.12130796137665, 0.45447151895080296, 8.570728029523577, 109.42433084760393, 129.82750756399972, 120.20132037571499, 109.47470528738839, 122.66966792515346, 70.70545945848737, 45.50116089412144, 57.92072193963187, 60.495727811540874, 153.69793265206474, 58.66319601876395, 45.75844921384539, 42.877965790884836, 1.1744559620107924, 0.4865282273718289, 0.27296633273363113, 0.6178071658526147, 0.12120004716728415, 0.346403499266931, 0.1069821533081787, 31.126995154789515, 19.980265923908778, 1.1788480920451028, 69.1821641921997, 96.90875611986432, 106.90444156101772, 94.72536809103829, 97.10280541011265, 108.22240366254533, 105.27708312443325, 97.72899096352714, 101.36063371385846, 103.30936023167202, 101.28330026354108, 92.66641535077775, 91.15061719076974, 90.99932711465019, 94.79171643938336, 89.68693052019391, 87.6031379699707, 76.15879481179374, 75.80832767486572, 78.2282532283238, 83.60786124638149, 92.87707778385708, 96.99810995374406, 93.81559181213379, 95.85990469796317, 88.20127364567348, 93.99757208142961, 93.8470949445452, 92.56971727098737, 95.38895579746791, 93.17291818346295, 90.52788489205497, 89.44726630619594, 89.86580494471959, 87.10297189440045, 87.8952054977417, 87.87859235491071, 92.74299144744873, 52.704750946589876, 27.742345230919973, 56.093269280024934, 93.29025936126709, 91.3120446886335, 87.5611708504813, 80.2272777557373, 84.56902640206474, 86.89768041883195, 85.632246698652, 86.80656174251011, 85.81011363438198, 81.63842214856828, 81.32771955217633, 83.4940219606672, 83.48604542868478, 82.47221987588065, 82.17530250549316, 82.41286141531808, 89.61860888344901, 98.3616452898298, 94.11772727966309, 77.22071579524449, 74.59335177285331, 72.83495725904191, 75.29568263462612, 76.22682462419782, 77.77818366459438, 78.06779153006417, 86.80685356685093, 92.40111923217773, 88.19447135925293, 88.2887931551252, 92.67356504712785, 87.69227640969413, 96.94881248474121, 79.1275794165475, 90.82278728485107, 41.47137941632952, 1.4826405963727405, 1.348768025636673, 0.17758424447051116, 0.3173507739390646, 0.2851618326136044, 0.4374468853431088, 0.17226547987333365, 0.6902272083929607, 13.222221289362226, 58.6521692276001, 84.21086066109794, 102.05351502554757, 102.86776747022355, 123.52567209516252, 131.88047790527344, 44.872828347342356, 28.189908232007706, 54.293904713221956, 76.42845439910889, 86.78008215767997, 79.95126751491001, 91.45069599151611, 9.265210032463074, 0.28120692340391024, 0.12209351493843965, 0.1704240579690252, 0.11341755584414516, 0.16195801725345, 0.1365773334567036, 0.0796077504221882, 0.12556736996131285, 0.1610814585749592, 0.11424810306302138, 0.15576140476124628, 0.11630415916442871, 0.16796759835311345, 0.11512695518987519, 0.12448460449065481, 0.129099185445479, 0.16130015041146958, 0.09700230775134903, 0.11220411131424562, 0.15327716592167104, 0.1484971988414015, 0.12082150605108057, 0.21488799633724348, 0.11191580857017211, 0.11506683698722295, 0.16740411573222705, 0.1739880767251764, 0.21161688757794245], [0.08801909442991018, 0.03503357046949012, 0.02702296754744436, 0.06131828682763236, 0.02852461813017726, 0.013050786485629422, 0.05225976290447371, 0.04472715567265238, 0.05495406261512211, 0.010237046800154661, 0.08344766151692186, 0.04603083518200687, 0.019042483098538857, 0.018376533208148818, 0.03042149670155985, 0.02872087081362094, 0.01730790501460433, 0.032291810626962354, 0.04201569581138236, 0.02214095728205783, 0.0353426804899105, 0.07922029335583959, 0.053841346608740945, 11.74308008807046, 92.43283775874546, 96.20458398546491, 94.43499592372349, 99.23642349243164, 78.7136960710798, 65.55146639687675, 80.18321922847203, 46.525137765066965, 58.40295124053955, 112.73358413151333, 41.524790218898225, 31.00643696103777, 33.162198952266145, 0.7191800805074828, 0.3608941574181829, 0.1103318499933396, 0.16167783657354967, 0.12538056927067892, 0.1419655257569892, 0.1917045989206859, 1.4392224975994654, 3.0658565844808305, 1.1477753136839186, 21.762836694717407, 93.05903026035854, 87.86559922354562, 93.71450941903251, 93.2498138972691, 98.54445934295654, 88.07262080056327, 95.38186863490513, 90.47254249027797, 90.12406948634556, 91.28612095969063, 93.83647809709821, 88.26987321036202, 86.35465785435268, 82.6036103112357, 82.0747412272862, 79.45416559491838, 75.50080735342843, 65.13911165509904, 67.62123053414481, 66.05132675170898, 76.35564422607422, 81.88117136274064, 89.35627269744873, 85.71529156821114, 84.71975367409843, 77.80979796818325, 87.63873359135219, 85.53529848371232, 86.9775777544294, 81.00045939854213, 83.41497925349644, 81.52133805411202, 86.04702636173793, 83.53935200827462, 91.36555276598249, 83.92262853894914, 88.46220629555839, 77.90768418993268, 92.08306544167655, 30.822671004704066, 41.15437132971627, 92.86937223161969, 78.16114752633231, 77.47135121481759, 72.53527450561523, 79.87840175628662, 72.65715980529785, 77.91675853729248, 75.19098717825753, 78.31930242265973, 76.06514699118478, 74.91563701629639, 70.49287237439836, 71.31287097930908, 71.27644852229527, 75.56740583692277, 73.1470286505563, 73.98156288691929, 75.10576752253941, 70.85941069466728, 63.909141540527344, 65.60446725572858, 65.05871404920305, 64.2515765598842, 67.84615761893136, 72.12050179072789, 75.08324841090611, 75.39527116503034, 77.67016002110073, 79.83894293648856, 84.44014426640102, 82.42622974940709, 89.03275762285504, 77.76230008261544, 84.57200023106166, 79.02444035666329, 95.16026973724365, 24.727141448429652, 0.8994010984897614, 0.3877407754106181, 0.09231851622462273, 0.07034620203609977, 0.1176023187914065, 0.13092512318066188, 0.04446647269651294, 0.15313289580600603, 9.480150818824768, 38.48360538482666, 74.72619438171387, 83.3661195210048, 85.676819392613, 83.9944520677839, 81.11409023829869, 44.118434633527485, 22.614442655018397, 33.20923130852835, 47.50665766852242, 75.63361522129604, 84.66027014596122, 44.260111876896445, 1.6563821477549416, 0.07834607562316315, 0.06250781978347472, 0.025045329738142233, 0.026613982261291573, 0.022008685361860052, 0.060437677295080254, 0.07088831758924893, 0.008368023787625134, 0.00835829189912017, 0.03954448823684028, 0.05854554168347802, 0.02447637133965535, 0.05923808166491134, 0.008306043854515468, 0.047235696243920496, 0.03840177080460957, 0.009655717860109039, 0.028899753000587225, 0.046272461502147574, 0.0701661663396018, 0.020276156453681842, 0.04055670302893434, 0.037161215408039946, 0.043308169314903874, 0.019184992415830493, 0.0746321277692914, 0.012035710820262986, 0.025565342013058916, 0.019282942338447486, 0.02841574209742248, 0.010236899218788105, 0.020477957857240523, 0.03142620350367256, 0.01562848673867328, 0.04172552031065736, 0.0244704714776682, 0.041551805167858086, 0.02641617742899273, 0.006010882614646107, 0.03242900701505797, 0.04793891975922244, 0.07311408886952059, 0.00374261341390333, 0.06191371487719672, 0.028186522790097764, 0.0068363599046798685, 0.02594169315748981, 0.07187617636684861, 0.04955503071791359, 0.04321508448837059, 16.904567650386266, 112.81841468811035, 117.12030846732003, 104.67573738098145, 120.56151499067033, 91.3925951548985, 101.43326323372978, 86.99582372392926, 29.20094060897827, 41.52106598445347, 59.41333048684256, 47.02038104193551, 36.88051005772182, 44.301849705832346, 0.8869441183550018, 0.2917715236544609, 0.21679964661598206, 0.3550660844360079, 0.04290490238262074, 0.60359766547169, 1.1375221610069275, 0.9835976319653648, 1.4391737516437257, 0.7986348484243665, 29.399711200169154, 100.00538757869175, 93.97884668622697, 97.74764687674386, 98.0791106905256, 101.1983585357666, 91.74410452161516, 96.35031550271171, 93.72725241524833, 92.40094552721295, 93.5372817175729, 97.06745297568185, 93.56920174189976, 90.18016229357038, 87.32061726706368, 86.44815281459263, 82.69957883017403, 78.8672651563372, 70.15925461905343, 69.26108877999442, 68.7501529966082, 80.39311735970634, 86.35362952096122, 91.7675199508667, 88.22198622567313, 88.2932538986206, 81.84174033573696, 90.03010899680001, 90.46328054155622, 91.17547784532819, 83.95750849587577, 88.8554882322039, 84.47928346906389, 89.40620245252336, 86.53398391178676, 93.44890757969448, 86.83133901868547, 92.08305154527936, 80.8470014844622, 93.79202352251325, 38.73562697001866, 44.342701639447895, 98.104311806815, 83.58607169560024, 80.15115329197475, 74.28316334315709, 82.84788118089948, 77.22567680903843, 81.6834464754377, 79.84125668661935, 81.566251209804, 79.26993410927909, 77.25709656306675, 74.09514508928571, 75.80868898119245, 75.15990788596017, 79.64198929922921, 74.54796613965715, 77.00529384613037, 78.35794135502407, 72.28315911974225, 67.58376584734235, 69.67123399462018, 67.90355668749127, 67.031265939985, 71.52208818708147, 75.43122114453996, 77.97881984710693, 79.78563635689872, 82.09441157749721, 82.65706975119454, 88.46102510179792, 84.98565428597587, 91.00577504294259, 79.43999821799142, 88.17824731554303, 83.73744515010289, 98.039151600429, 36.07979965209961, 0.47555745605911526, 0.60251591780356, 0.15078910014459065, 0.11953980768365519, 0.05986606582467045, 0.09998233855835029, 0.0637386076684509, 0.3934529003288065, 11.011241095406668, 42.49682930537632, 78.50788348061698, 89.36255386897496, 85.41592148372105, 87.2277615410941, 48.97972788129534, 22.41769051551819, 40.190089906964985, 53.95523909160069, 61.57587391989571, 87.36168806893485, 91.08966064453125, 67.36716965266636, 1.2592937925032206, 0.02436544273846916, 0.022433911383684193, 0.0613186668072428, 0.037408565171062946, 0.0034875054511108567, 0.04764728540820735, 0.036891236502145014, 0.008055986736768057, 0.035818472637661865, 0.03025923522987536, 0.06424348521977663, 0.01173319700839264, 0.05937963764050177, 0.08033122481512171, 0.054572267923504114, 0.041635597457310984, 0.018223944253155162, 0.038106899841555526, 0.006111329122047339, 0.055525253393820355, 0.04623970861679741, 0.013346145145728119, 0.03859843400173953, 0.04334811467145171, 0.019167752537344183, 0.022725389671644995, 0.07133657139326845, 0.14668689455304826, 0.1341523714363575, 0.13604865968227386, 0.11061302811971732, 0.07955688743719033, 0.07126106401639325, 0.07570287638476916, 0.24957875055926187, 0.17114823125302792, 0.19782889315060206, 0.1862343174538442, 0.21439291004623684, 0.0759635084707822, 0.12935637735894748, 0.09819217318935053, 0.1575242251689945, 0.11879542762679712, 0.13229965870933874, 0.1879765103970255, 0.08985438916300025, 0.10885607025453023, 0.16332360969058105, 0.10672628453799657, 24.362156050545828, 141.3216345650809, 124.73647907802037, 119.58402851649693, 125.27881377083915, 102.93415750776018, 85.13816029684884, 94.08391039712089, 59.72052424294608, 81.76134272984096, 159.9305362701416, 59.43515477861677, 51.038465227399556, 56.821089608328684, 1.664902919105121, 0.5955480688384601, 0.41896085015365053, 0.4049282574227878, 0.25970189592667986, 0.4959633925131389, 0.788201531129224, 3.8565737434795926, 12.465713586126055, 2.0427571407386234, 33.86122941970825, 101.02179786137172, 94.78094673156738, 101.53536701202393, 100.14671393803188, 105.62130383082798, 94.93739931924003, 98.73827239445278, 94.9402689252581, 94.16441917419434, 96.5264731815883, 98.96103164127895, 97.65927273886544, 95.90194824763707, 92.57478945595878, 90.30574403490338, 88.09502179282052, 82.17059162684849, 73.17090266091483, 72.82855796813965, 73.212737764631, 83.75315502711705, 89.67061614990234, 96.8297620500837, 93.30778966631208, 90.64074448176792, 84.78740133558, 92.73818329402378, 93.75846372331891, 93.54272215706962, 89.01278155190604, 92.10029697418213, 89.23168454851422, 93.36699526650565, 92.29631955283028, 98.16848536900112, 91.36398942129952, 94.98910781315395, 83.42987619127545, 95.67777851649693, 42.6316556249346, 50.27612624849592, 100.64296817779541, 87.1250741141183, 83.66035488673619, 81.42086710248674, 86.49848556518555, 81.22624111175537, 85.62515953608921, 84.58998216901506, 85.68740844726562, 85.77956240517753, 81.14158426012311, 77.80390589577812, 80.35299846104213, 80.69887283870152, 82.5546463557652, 78.767336164202, 79.96689401354108, 81.4724018914359, 76.25185898372105, 71.5740190233503, 75.46879005432129, 72.71455192565918, 70.30995409829276, 76.04781818389893, 79.57173606327602, 83.75323145730155, 83.75466278621128, 86.02862753186906, 87.11538832528251, 91.56001894814628, 89.00738280160087, 96.24254894256592, 84.29598999023438, 91.94150284358433, 86.0098465510777, 102.2106624330793, 32.37760836737496, 2.439883819648198, 2.370351893561227, 0.1700119972229004, 0.19274216038840158, 0.1944602517677205, 0.29116399054016384, 0.13981499043958528, 0.4128379944179739, 17.864424807684763, 53.327583994184224, 86.0431214741298, 90.83620425633022, 92.82946872711182, 102.68187536512102, 112.78122098105294, 69.64119693211147, 34.374260084969656, 47.46223783493042, 63.13268034798758, 96.85588727678571, 100.29590565817696, 85.58439445495605, 2.5103111948285783, 0.1020820244614567, 0.08867883402854204, 0.12045084951179368, 0.13038998975285462, 0.1452066839805671, 0.13604255286710604, 0.17384717214320386, 0.06681694462895393, 0.07862497387187821, 0.0723936203867197, 0.09274397803736584, 0.15561086498200893, 0.152353951175298, 0.1658165066369942, 0.11967225771929536, 0.14432285140667642, 0.07078391819127969, 0.09339094082159655, 0.1102775332650968, 0.14310398538197788, 0.11402265301772527, 0.1133082438526409, 0.07360579605613436, 0.12986972981265613, 0.09901111067405768, 0.11700603578771863, 0.13481147321207182], [0.06296463669942957, 0.018403750944084356, 0.01829735834949783, 0.04946287548435586, 0.02683846539418612, 0.022463147761300206, 0.044298063697559495, 0.07064042160553591, 0.04814685003033706, 0.018783250491001775, 0.04011121425511582, 0.05118978442624211, 0.058221710845828056, 0.028148329750235592, 0.05502139364502259, 0.04819820495322347, 0.00685467483708635, 0.049506423861852715, 0.0076332594201500925, 0.022000390271257077, 0.045640874321439436, 0.4590856656432152, 14.548886009625026, 113.61606788635254, 89.92093195234025, 99.7853033883231, 86.6367130279541, 68.30643408639091, 65.599686895098, 36.23620360238211, 20.077625819614955, 77.13201509203229, 99.19948686872209, 53.70387063707624, 34.99936866760254, 33.99743843078613, 1.2211957339729582, 0.14696417110306875, 0.166280597448349, 0.1883153436439378, 0.14084548157240662, 0.38042011537722176, 0.061753757031900544, 0.8410855191094535, 1.0768098873751504, 1.5140165984630585, 17.486128398350306, 90.62686892918178, 91.35464409419468, 92.64482034955705, 92.8101805278233, 91.88306849343437, 91.49223927089146, 98.48824841635567, 93.03580243246896, 91.89987618582589, 91.88661207471574, 89.21236160823277, 87.43352549416679, 92.06204714093889, 90.36110033307756, 87.24824483054024, 85.6789663859776, 76.92620250156948, 70.76012093680245, 64.81084401266915, 65.67272635868618, 65.14187008993966, 70.49590178898403, 83.24897289276123, 89.10935456412179, 81.23426628112793, 80.6071913582938, 77.74584674835205, 84.19203799111503, 85.19930444444928, 85.96103545597622, 83.65415014539445, 83.20196832929338, 77.97203145708356, 80.30116489955357, 79.72859859466553, 81.4987564086914, 81.04591451372418, 89.64402539389474, 77.57186385563442, 87.40214048113141, 69.41280964442662, 38.892850807734895, 87.97665228162492, 77.01115117754254, 71.38340214320591, 66.968551499503, 77.14985111781529, 74.01143319266183, 73.0823756626674, 73.74841608319963, 76.66732651846749, 73.25585828508649, 72.06508990696499, 67.3281694139753, 70.19469043186733, 68.2288157599313, 71.15831524985177, 69.28636632646833, 66.17173208509172, 64.55743626185826, 68.42125306810651, 65.40044035230363, 62.94188976287842, 62.64786284310477, 66.25044822692871, 64.43548842838833, 68.46333135877336, 70.53587477547782, 76.13981233324323, 78.76032543182373, 80.89037214006696, 78.64125415257045, 83.30614267076764, 78.08764948163713, 84.31536156790597, 78.73778547559465, 85.67990439278739, 82.43166324070522, 85.5931978225708, 11.08590383189065, 1.135894762618201, 0.3759651258587837, 0.06391748307006699, 0.02300173832502748, 0.08622791125838246, 0.007778916291759482, 0.057634906976350715, 0.09192291673805032, 11.337828142302376, 34.279847962515696, 72.16032191685268, 82.61648532322475, 78.20620659419468, 62.26462800162179, 38.054102488926475, 29.70031806400844, 26.170652287346975, 43.55678047452654, 57.551987988608225, 68.20237786429269, 73.90213108062744, 40.5956597328186, 0.38097597126449856, 0.05682712121467505, 0.04764986723395331, 0.006662623981745648, 0.06633815674909524, 0.05324895839606013, 0.04045055640329208, 0.0522025352610009, 0.0466796435814883, 0.04965379488255296, 0.06368494911917619, 0.03749683239896383, 0.0690019495253052, 0.04408000289861645, 0.03510495913880212, 0.06560202767806393, 0.023141026297318082, 0.060392276516982486, 0.02800505538471043, 0.0875913052420531, 0.06387690667595182, 0.0027932950012784985, 0.03498967603913375, 0.04654617913599525, 0.02206474931777588, 0.02216797145748777, 0.07560070936701127, 0.03478264143424375, 0.02458583769787635, 0.0008732098961315517, 0.057124411155070574, 0.023739170183294585, 0.0201731616232012, 0.0615559301472136, 0.04735504037567547, 0.011173406466176468, 0.017898900534159372, 0.04403953167742916, 0.07214429269411735, 0.01613819376299424, 0.03960430449140923, 0.07519971552704062, 0.06449748801865748, 0.05202415518994842, 0.02653859362804464, 0.07981694276843752, 0.029645083006471395, 0.1610212182360036, 0.502595665199416, 22.222406182970317, 140.27447155543734, 103.42130960736955, 109.42526190621513, 104.35675948006767, 75.09450449262346, 81.6313419342041, 53.2146931375776, 42.09634556089129, 53.13546977724348, 66.5008682523455, 59.547673906598774, 38.47636883599417, 46.370519501822336, 1.0599295645952225, 0.10571873467415571, 0.08264023198613099, 0.4181790421051638, 0.10388317531240837, 1.0386611287082945, 0.5643270441464016, 1.3207629855190004, 0.9519164519650596, 0.33104274209056583, 22.647611618041992, 97.76822744097028, 95.43103408813477, 96.68639292035783, 94.70619106292725, 95.89520849500383, 95.86294106074742, 101.95975603376115, 97.21191297258649, 93.50734887804303, 92.81276525769914, 90.4605360031128, 90.42181369236538, 94.46420615059989, 91.58860383714948, 92.0274520601545, 90.02917098999023, 82.54843466622489, 73.15506771632603, 67.11069774627686, 67.71380138397217, 67.92303248814174, 72.4429885319301, 86.42061710357666, 91.45430905478341, 86.89852809906006, 81.6706965310233, 80.87441907610211, 86.79766804831368, 88.48728929247174, 88.86632047380719, 88.84170995439801, 86.28232710702079, 81.39337308066231, 83.43093926565987, 82.09830951690674, 83.65060656411308, 85.01258550371442, 90.58584676470075, 82.5714887891497, 87.69033786228725, 75.04606165204729, 41.798938342503135, 89.72774423871721, 81.24286815098354, 73.7396821975708, 71.3041718346732, 79.71782888684953, 77.68351445879254, 75.6879848752703, 76.73044395446777, 79.32194832393101, 79.74097333635602, 76.01609270913261, 70.17372076851981, 73.82224069322858, 70.96088913508824, 74.72475610460553, 71.2882604598999, 69.98113059997559, 65.85066972460065, 70.52809279305595, 68.91649287087577, 66.78641836983817, 64.65270301273891, 69.55027280535016, 69.91619968414307, 72.8617217200143, 71.98654747009277, 80.09252439226422, 82.45208399636405, 86.04798521314348, 80.73792171478271, 88.87545040675572, 82.20776448931012, 87.04905387333461, 82.44594873700822, 88.4021669115339, 83.491562298366, 93.44739982060024, 18.014771665845597, 0.19657719960170134, 0.3103554035936083, 0.33499230444431305, 0.8039364867976734, 0.22941342262285097, 0.11059227173349687, 0.024821482731827667, 0.11680014112165996, 14.529470137187413, 38.92180395126343, 76.34030260358537, 90.02147238595145, 82.5422716140747, 70.92922619410923, 26.967174666268484, 22.441964047295706, 41.03581769125802, 54.886596475328716, 69.61731597355434, 76.07208129337856, 84.874406678336, 65.5726375579834, 0.5447351868663515, 0.034890257088201385, 0.08255413267761469, 0.05664200329088739, 0.003833733881557626, 0.057625909602003436, 0.05477005748876503, 0.03314720579822149, 0.04562241477625711, 0.033602373874081035, 0.10273857494550091, 0.014373529436332839, 0.02770407760648855, 0.02637853060982057, 0.034162182227841446, 0.04647334857976862, 0.0509485652271126, 0.06377313153019973, 0.028489507335637296, 0.05286953179165721, 0.05939064347850425, 0.054127084490443976, 0.02185729402117431, 0.021454476618341038, 0.03582542762160301, 0.02426111458667687, 0.05685922270640731, 0.22464096013988766, 0.12958498937743052, 0.20175934795822414, 0.10036531729357583, 0.17247136096869195, 0.09209300511117492, 0.13710725573556765, 0.20961602351495198, 0.08226921582328421, 0.08224491069891623, 0.1480332301663501, 0.10148574145776884, 0.12529354036918708, 0.0837932394019195, 0.15926244189696653, 0.1844496075063944, 0.1153332841183458, 0.12893941758998803, 0.15434177379523004, 0.10502778246466603, 0.2038508914411068, 0.6746283939906529, 32.31840624128069, 167.2226290021624, 111.68933241707938, 128.25647817339217, 114.64727088383266, 86.03996699196952, 87.83990478515625, 51.664932182856965, 25.797799791608536, 97.9985602242606, 140.64046096801758, 70.59403119768415, 57.08644478661673, 60.868081774030415, 2.418152677161353, 0.23285962055836404, 0.5548973615680421, 0.5589931617890085, 1.0963218403714043, 1.9614877530506678, 0.6144790330103466, 3.0270024750913893, 7.979062863758632, 4.266356348991394, 24.65204358100891, 98.76043714795793, 95.83318192618233, 97.76803289140973, 97.5834400994437, 99.31834275381905, 98.66064711979458, 108.7589852469308, 102.6334672655378, 95.88960824693952, 96.32024369921002, 93.31748240334647, 94.35115201132638, 97.72273063659668, 97.02638912200928, 94.14449174063546, 97.38256767817906, 85.87762233189174, 77.40458597455705, 70.90884712764195, 71.9855260848999, 72.32002626146588, 77.29857730865479, 91.45464256831578, 95.22158064161027, 90.69938727787563, 87.8811423437936, 85.20880958012172, 92.2839309147426, 94.06639398847307, 93.67387635367257, 92.50032561165946, 89.17707170758928, 86.85659572056362, 88.89289733341762, 89.53450093950543, 88.30720588139125, 90.26495116097587, 97.07253210885185, 86.59013925279889, 89.93624578203473, 77.43834032331193, 47.88553598948887, 96.3214248929705, 87.83683368137905, 76.5281263078962, 75.22261537824357, 85.53757054465157, 84.23313658578056, 80.29565497807094, 82.63280664171491, 84.54347787584577, 83.19543007441929, 80.6510900769915, 75.13328238895961, 78.2920446395874, 75.25490365709577, 79.32896600450788, 77.12856878553117, 74.90420028141567, 70.27321202414376, 75.88677978515625, 73.67826012202671, 70.16678646632603, 70.38748904636928, 74.1731664112636, 74.12976796286446, 76.62702001844133, 77.77097838265556, 84.13291576930455, 88.04901082175118, 90.80848094395229, 86.12133039746965, 92.16688850947789, 85.61277784620012, 92.36710085187639, 85.02307728358677, 92.80827672140938, 88.83359445844377, 95.98690387180874, 15.913280316761561, 1.7671860477754047, 1.8279053781713759, 0.32329685773168293, 0.8307563705103738, 0.3817773482629231, 0.21278140294764722, 0.14010443990784033, 0.2792715515409197, 24.156499794551305, 49.74628094264439, 86.47280502319336, 90.85749353681291, 89.30953216552734, 75.8358633858817, 53.61226211275373, 43.91034650802612, 39.17408261980329, 57.749775409698486, 76.3732579095023, 87.8411693572998, 92.93313585008893, 75.11759335654122, 1.092917983021055, 0.18319179357162543, 0.15810217415647848, 0.18698158806988172, 0.13324933632143907, 0.12785225521240914, 0.16958658290760859, 0.1466529813728162, 0.15528890011566027, 0.19135309063962527, 0.2012854998133012, 0.1136409906404359, 0.17867330674614224, 0.15979487475539955, 0.12058519944548607, 0.10419226836945329, 0.14096370951405593, 0.18603311825011457, 0.06554284585373742, 0.23406092609677995, 0.2736905738711357, 0.08262828976980277, 0.13151698213602814, 0.17465055760528359, 0.13775452386055673, 0.07255140013460602, 0.2586537221712725], [0.12447287940553256, 0.022947883000597358, 0.05284591538033315, 0.05002264651869025, 0.02480292140639254, 0.01970822603574821, 0.028043938833954077, 0.051819556525775363, 0.011201512234817659, 0.06198175836886678, 0.018987850851512382, 0.018587493138121705, 0.020990365450935702, 0.02083933543014739, 0.06313621106424502, 0.0853816152417234, 0.027894591580012014, 0.13591029282127107, 0.029989812722695724, 0.029651026973234754, 0.2772367607269968, 7.921533516475132, 106.22383771623883, 96.27142565590995, 99.09026118687221, 88.79244027818952, 75.82073020935059, 135.59930665152413, 132.22840200151717, 81.23822675432477, 50.34886693954468, 55.92906250272478, 76.75583962031773, 43.617240224565776, 32.78677388599941, 0.9369932413101196, 0.04282483525042023, 0.12605860217341355, 0.052949381792651753, 0.2115723213979176, 0.31022897894893375, 0.09806192839252097, 0.7331010135156768, 3.475258558988571, 0.7087137592690331, 22.588588408061437, 95.37311390468052, 90.55263437543596, 94.96062019893101, 92.61461653028215, 90.94215038844517, 93.51254613058907, 92.65804971967424, 86.11615398951939, 91.77482945578438, 91.40179456983293, 89.93752425057548, 89.54961327144078, 89.7916954585484, 89.02672658647809, 87.96909958975655, 87.64456312997001, 88.29983384268624, 82.60171345302037, 71.7744676045009, 63.843738147190635, 62.80815083639962, 64.17753655569894, 66.72178622654506, 72.70948668888637, 80.53274835859025, 76.2678120476859, 74.01902757372174, 77.8592482975551, 85.25645337785993, 84.44716194697789, 83.73187269483293, 82.07539435795375, 79.23208727155412, 77.07860428946358, 77.67488479614258, 77.59118679591587, 77.6135322025844, 80.31585339137486, 78.75669152396065, 81.05444690159389, 81.91284820011684, 84.57266725812639, 53.406578063964844, 76.31141894204276, 81.68849781581334, 69.56811577933175, 73.74403871808732, 74.861983026777, 72.52979932512555, 68.21232073647636, 72.0582389831543, 74.28401797158378, 71.8876120703561, 72.07280935559953, 68.74189158848354, 68.67272227151054, 70.39802946363176, 70.75652176993233, 71.39951501573834, 65.20495973314557, 65.84144251687187, 60.40525531768799, 61.22190489087786, 60.05749103001186, 62.672813824244905, 60.07746015276228, 63.840000016348704, 68.79682404654366, 70.69249411991665, 74.1654052734375, 76.59289741516113, 78.49425111498151, 80.92202813284737, 79.31158855983189, 85.75067874363491, 78.00511183057512, 82.2060135432652, 80.64827605656215, 80.11842727661133, 84.63333892822266, 72.2419354575021, 4.5156234077044894, 1.152040421962738, 0.2680860917483057, 0.07850314290927989, 0.27021680027246475, 0.07824487891048193, 0.036332788611097, 0.044801991299859116, 0.6383010404450553, 11.502575142042977, 30.195877483912877, 49.30305535452706, 83.09980201721191, 64.30811405181885, 41.54823691504342, 54.24398190634591, 26.527595145361765, 34.93689046587263, 58.04455968311855, 73.55547850472587, 70.74792684827531, 82.5040773664202, 12.25380916254861, 0.473511808684894, 0.20144247210451535, 0.05439012198309813, 0.03387941632952009, 0.050256578251719475, 0.029613093473017216, 0.007239110302180052, 0.004559650576473879, 0.08114107671592917, 0.04653008428535291, 0.08991574908473662, 0.019390483353553072, 0.03498871251940727, 0.024051192815282514, 0.0432258223050407, 0.06392146607062646, 0.028974938073328564, 0.023723741993308067, 0.039403166355831284, 0.04937991100762572, 0.02801328431814909, 0.012521300165514861, 0.04163450162325587, 0.04636309003191335, 0.09717574130211558, 0.05106041154691151, 0.08956029851521764, 0.04555710917338729, 0.049813657732946534, 0.047288618582699976, 0.03849786154127546, 0.019065256430102245, 0.01924968564084598, 0.011506175306359572, 0.03687996942816036, 0.04415206331759691, 0.019003518225092973, 0.02237317232148988, 0.04673544290874686, 0.04987037308248026, 0.05220237919794662, 0.10632392005728823, 0.06179372952984912, 0.11764961268220629, 0.04225264023989439, 0.16582711892468588, 0.25347289017268587, 11.318091784204755, 129.93032700674874, 109.71266719273159, 113.62364837101528, 102.75282342093331, 87.93008545466832, 125.80723817007882, 125.56145259312221, 89.77545751844133, 17.698863131659373, 48.390360832214355, 78.3805091040475, 46.9739670753479, 42.83997998918806, 0.28222065472177094, 0.04470711174820151, 0.132951554443155, 0.04592307364302022, 0.09375605372978107, 0.4349972925015858, 0.3529438983116831, 1.2618620204074043, 1.0076544667993272, 0.6643366462418011, 30.853670392717632, 102.98937484196254, 95.14781856536865, 97.76002161843437, 95.67374161311558, 96.16174834115165, 96.72675500597272, 95.42157758985246, 89.63143525804792, 95.99701350075858, 95.30527864183698, 94.2844215120588, 89.81843212672642, 92.09174374171666, 92.67946406773159, 89.15982627868652, 88.82386698041643, 92.72970649174282, 87.10759244646344, 75.94622162410191, 67.22935908181327, 67.45231982639858, 67.87392262050084, 69.91112749917167, 75.65390396118164, 83.9937572479248, 78.01816054752895, 77.30435820988247, 83.34805420466832, 92.14523097446987, 86.30924442836216, 88.20405292510986, 83.46170588902065, 81.8450129372733, 79.9762601852417, 81.3585765021188, 80.85745157514299, 82.0542301450457, 84.45955058506557, 82.12760312216622, 83.21833828517369, 85.49928597041539, 87.326217515128, 59.12498719351632, 77.06548609052385, 85.86348969595772, 73.56330912453788, 77.57806859697614, 78.45372922079903, 75.37026459830147, 72.68176337650844, 75.10547569819859, 76.36746311187744, 77.21956239427838, 73.31074905395508, 73.09001173291887, 70.31123951503209, 75.3009146281651, 74.16488415854317, 74.10954870496477, 68.70537185668945, 69.80607073647636, 63.56462900979178, 62.89106369018555, 64.2329762322562, 67.97238554273332, 62.746235438755576, 66.79024682726178, 72.97782611846924, 75.33724675859723, 75.88095719473702, 80.69901180267334, 81.47206142970494, 85.97275011880058, 82.58758776528495, 89.45409638541085, 80.46901253291539, 85.57410417284284, 83.56057875497001, 83.70864486694336, 86.63535812922886, 82.07832649775914, 8.829410331589834, 0.5712602606841496, 0.535861143044063, 0.7738352077347892, 0.37155277548091753, 0.04453462475378599, 0.060638374382896085, 0.07378209981002978, 0.21154493572456495, 15.57536162648882, 33.82840960366385, 53.31113413402012, 89.87255164555141, 73.44059004102434, 34.741614818573, 30.904618058885845, 32.90653303691319, 44.91440289361136, 63.13148525782994, 84.45886966160366, 77.79838902609688, 95.15606607709611, 26.709948880331858, 0.4640137297766549, 0.22988845141870634, 0.08791363651731185, 0.05758803377726248, 0.05139255443853991, 0.021197457731302296, 0.04502473059775574, 0.03724222231124129, 0.01807799476331898, 0.018627662411225692, 0.012171193059267742, 0.019061078350724917, 0.04442281914608819, 0.06823530673448529, 0.023224406376747147, 0.0579919588885137, 0.06252360250800848, 0.01724926262561764, 0.034631626680493355, 0.05710214163575854, 0.03147123448018517, 0.030995506793260574, 0.04022713178502662, 0.044275777214871984, 0.04315802308597735, 0.02080839253695948, 0.17636190434651716, 0.1406539718487433, 0.1103205523852791, 0.09965016173997096, 0.09211743237184626, 0.11979018710553646, 0.09623685918216195, 0.08601229997085673, 0.1756634475397212, 0.2745104341634682, 0.12203917785414628, 0.11258033862603561, 0.15793150902858802, 0.07869789603033236, 0.18878395349851676, 0.16989102799977573, 0.11818800307810307, 0.22090956036533627, 0.14566465440605367, 0.326733121914523, 0.5895256634269441, 14.98455456324986, 154.24364416939872, 123.77315303257534, 130.0364954812186, 114.13181182316372, 95.08247075762067, 145.0939783368792, 138.42240142822266, 98.18709959302629, 71.85344777788434, 75.13071155548096, 102.16673592158726, 64.70294543675014, 57.244248798915315, 3.477162365402494, 0.21012824960052967, 0.4024789088538715, 0.18240736637796673, 0.8434131113546235, 1.201858137335096, 0.2820642931120736, 3.6921307274273465, 11.55746591091156, 3.633804074355534, 30.69170788356236, 105.61242403302873, 95.38670458112443, 100.94440882546562, 97.74811240604946, 100.03954492296491, 98.68869699750627, 99.15553951263428, 92.4478041785104, 99.47125176021031, 100.74311256408691, 100.19467735290527, 94.82078075408936, 97.7031923021589, 94.729127066476, 95.34404264177594, 93.29720061165946, 95.32759625571114, 91.47035244532994, 80.32599081311906, 71.1542991910662, 70.19308539799282, 69.72685432434082, 74.24363504137311, 79.32691628592355, 90.00558880397251, 81.74341637747628, 81.07485376085553, 85.7230943952288, 94.31019932883126, 89.51426778520856, 90.65951156616211, 87.29596505846295, 85.68821443830217, 81.82398768833706, 87.20502703530448, 85.92764241354806, 84.84930978502545, 88.36853763035366, 86.08897263663155, 88.08769144330705, 90.36610998426164, 90.62117835453579, 60.544031688145225, 82.22042410714286, 89.9464943749564, 76.47982243129185, 81.62841674259731, 83.10372080121721, 79.63963385990688, 76.1226919719151, 80.59820733751569, 82.34519985743931, 79.74592740195138, 77.65899426596505, 76.729505947658, 74.68334484100342, 80.14436490195138, 80.97609901428223, 77.83017008645194, 73.27265902927944, 72.70859037126813, 66.81247411455426, 67.58441897800991, 68.21968582698277, 71.2858007975987, 66.15227712903703, 71.88203961508614, 77.38128866468156, 80.67188603537423, 81.43836266653878, 84.47250202723912, 85.87913703918457, 88.36110305786133, 87.40189034598214, 94.32153184073312, 84.47473239898682, 89.8183765411377, 87.24952329908098, 87.26535129547119, 93.33317838396344, 82.95905235835484, 6.969990747315543, 3.442006000450679, 1.0406922825745173, 0.22442488744854927, 0.8556247875094414, 0.18682530788438662, 0.1187727509864739, 0.1390426547399589, 1.2434954345226288, 25.3272990499224, 46.380250453948975, 64.47874096461705, 95.82564313071114, 81.43257481711251, 53.211347579956055, 80.01892907278878, 37.543475900377544, 49.584787436894004, 74.40418706621442, 94.12451566968645, 87.25847952706474, 110.51585115705217, 34.074789251599995, 0.729646347463131, 0.26835281029343605, 0.2676753337894167, 0.20849511080554553, 0.16606062996600354, 0.1368306577205658, 0.11173552181571722, 0.11457869889480726, 0.2042759529181889, 0.11632220819592476, 0.1316189116665295, 0.09657614704753671, 0.11779446633798735, 0.11305865153138127, 0.08536940161138773, 0.14900140464305878, 0.11136467528662511, 0.06437444247837577, 0.24453726251210484, 0.10804715473204851, 0.08794868285102503, 0.1111579460224935, 0.15077201463282108, 0.15189972626311438, 0.18689993316573755, 0.1600078126149518], [0.07581012562981673, 0.03009316717673625, 0.07024084590375423, 0.06238547313426222, 0.04871667016829763, 0.04042871775371688, 0.06619928777217865, 0.02436817723459431, 0.051701046992093325, 0.021209040324070623, 0.008254096061656517, 0.042470202315598726, 0.002905882620585284, 0.04812587990558573, 0.029143754193293195, 0.014136652013153901, 0.02710211187201951, 0.022349023260176182, 0.01627377693408302, 0.06204105554414647, 0.08078917488455772, 61.40521226610456, 96.39363752092633, 92.28655038561139, 78.42667293548584, 67.84565734863281, 58.45311723436628, 45.94046769823347, 95.22165707179478, 79.66892746516636, 118.67316137041364, 78.89773995535714, 65.87833050319126, 29.481362955910818, 0.27146894165447777, 0.5246410508240972, 0.030992857114012753, 0.07835294239755188, 0.03908258909359574, 0.5163786656090191, 0.16724281438759395, 1.1498249237026488, 0.49332644258226666, 1.9169487144265855, 29.570984295436315, 114.78128773825509, 94.69344806671143, 95.30370834895542, 91.97782107761928, 93.82980782645089, 89.69556713104248, 89.53712735857282, 86.69323662349156, 85.89438833509172, 85.87244592394147, 85.58892468043736, 79.163327898298, 85.29441833496094, 82.35414913722447, 85.28959628513881, 85.38200732639858, 88.35043757302421, 83.67354951586042, 84.7798000063215, 73.0276655469622, 61.60345132010323, 64.45272690909249, 65.42102786472866, 67.62968649183, 67.69905730656215, 67.46477794647217, 69.84936496189663, 73.07660170963833, 79.5985700062343, 83.09619590214321, 80.94727788652692, 81.42575863429478, 82.53949928283691, 80.85335213797433, 74.28255884987968, 71.34485353742326, 73.94316714150565, 72.28378445761544, 74.29746273585728, 76.9521609715053, 77.41794736044747, 75.35099029541016, 85.09471321105957, 63.99195711953299, 72.22731644766671, 81.2651857648577, 63.47382995060512, 68.214585849217, 73.24244131360734, 70.75702898842948, 67.5227884565081, 66.21236515045166, 69.508896282741, 71.12059347970145, 71.21483189719063, 68.21471091679165, 64.3069189616612, 66.25961290087018, 68.78747177124023, 66.08462251935686, 62.27047838483538, 62.41493143354143, 61.288426944187705, 59.53948198046003, 60.46070889064244, 62.33870274680001, 61.32572487422398, 60.75366578783308, 63.74952752249581, 68.6433800288609, 69.5829084941319, 76.45854704720634, 75.69258458273751, 75.80801500592912, 81.12369959694999, 78.2758205958775, 81.21948746272496, 79.38000747135708, 77.5184600012643, 78.05941895076207, 78.69162164415631, 85.61712741851807, 60.37214020320347, 0.6321868428162166, 1.1231548062392642, 1.9763720972197396, 0.1903750638344458, 0.37988673256976263, 0.045061385059463124, 0.07251751409577471, 0.04531946924648114, 0.6423300185373851, 12.158016954149518, 21.595569235937937, 51.40903697695051, 83.36434773036412, 57.07228783198765, 44.44280086244856, 49.28899914877755, 27.899452686309814, 31.422818183898926, 53.93722588675362, 66.69979517800468, 69.17204066685268, 58.596993582589285, 5.432932836668832, 0.21544811342443737, 0.04596998416153448, 0.011959536782731968, 0.0058805695402302915, 0.11765520381075995, 0.023743178628917252, 0.05886301464800324, 0.050577599954392226, 0.023912812383579354, 0.049359714412795644, 0.013979981670023074, 0.045518320719046254, 0.06062963485185589, 0.056437940669379065, 0.02845719889072435, 0.03617222347695913, 0.04610592865252069, 0.06901399352188621, 0.020572299669895853, 0.05822056412164654, 0.05566255495484386, 0.040787527071578164, 0.03192795979391251, 0.06110700459352561, 0.019850687855588536, 0.03583804837294987, 0.045553560435239754, 0.023731071867847016, 0.043127003857599835, 0.045370549362684996, 0.0505086879378983, 0.008267538688544716, 0.03230864508077502, 0.02595130290969142, 0.10774435169462647, 0.06392019721014158, 0.09640806713806731, 0.03709989959107978, 0.049965690289224894, 0.057018831106168885, 0.019440001142876487, 0.05180007917806506, 0.03100983066750424, 0.03734773450664111, 0.05492330801540187, 0.08370110791708742, 81.31828389848981, 113.03387137821743, 104.29726205553327, 93.75746318272182, 79.04078251974923, 82.29575647626604, 84.48567581176758, 121.47367450169155, 50.59416266850063, 92.06078951699394, 79.48072855813163, 67.64321463448661, 39.0617858341762, 0.31050780255879673, 0.6022133454680443, 0.01891621112424348, 0.05236446085785117, 0.06055219365017755, 0.7809246501752308, 0.29682945939046995, 2.129818286214556, 0.5880515053868294, 1.218397889818464, 39.101776191166465, 120.58295713152204, 97.16178866795131, 100.85836233411516, 94.55463000706264, 94.4716546194894, 91.36833899361747, 93.49853161403111, 89.16703850882394, 90.53241511753627, 90.02248682294572, 89.26468849182129, 81.21088559286935, 89.41504750932965, 86.69921207427979, 91.72858224596295, 88.32465975625175, 89.47007029397147, 87.29164327893938, 89.95650672912598, 76.34572914668492, 65.05633081708635, 66.33434772491455, 67.50395883832658, 70.60056250435966, 70.15122250148228, 68.72088718414307, 73.88722024645124, 75.91053567613874, 83.47774927956718, 84.7171550478254, 85.35678536551339, 83.40700272151402, 86.98813206808907, 82.09794126238141, 77.34494263785226, 73.70467717306954, 77.35171713147844, 74.90660435812813, 78.33053765978131, 79.00617354256767, 78.75618430546352, 79.93889972141811, 88.68581322261265, 66.67833219255719, 73.25145312717983, 84.88454410008022, 66.89886801583427, 70.7333356312343, 77.55836350577218, 74.71750913347516, 71.62126677376884, 70.43745354243687, 72.8916962487357, 75.09299673352922, 74.48462636130196, 71.12551280430385, 66.61955738067627, 70.20004054478237, 71.91986560821533, 69.22954395839146, 67.2732161113194, 64.61514105115617, 64.60719231196812, 63.872809410095215, 63.186605317252024, 62.95812770298549, 65.83993475777763, 64.32138511112758, 67.83479036603654, 71.72629574366978, 74.08280508858817, 79.52721200670514, 80.28057738712856, 80.24996362413678, 84.4961884362357, 82.67198753356934, 86.493059022086, 83.82398496355329, 80.17337363106864, 80.31642314365932, 82.53390598297119, 86.92418779645647, 71.59920624324253, 3.0914001166820526, 0.19019081443548203, 1.0267426882471358, 0.2063505465963057, 0.5697253601891654, 0.047900826803275516, 0.120879520795175, 0.015505732968449593, 0.12594565323420934, 14.735986232757568, 25.538534709385463, 56.32314000810896, 89.44248594556535, 68.78171866280692, 33.75137839998518, 12.940596904073443, 33.42049823488508, 50.447385447365896, 60.75803620474679, 76.65111637115479, 75.50795010157994, 79.09055246625627, 11.725938882146563, 0.3873684768165861, 0.1573981533625296, 0.07878098942871604, 0.01639647302883012, 0.040205751146589, 0.013685851158308131, 0.04111083543726376, 0.019400890384401594, 0.005336957817365016, 0.0057532628000314745, 0.03362125750365002, 0.02482118078374437, 0.018714211249191846, 0.06775624065526895, 0.031227012763598135, 0.05657015321776271, 0.053378127714885135, 0.043634693936577866, 0.03398649933348809, 0.019690838575895344, 0.029783789134983505, 0.021852293218086873, 0.012267109073166336, 0.09288738641355719, 0.018118253942312937, 0.12969994678028993, 0.1253380115543093, 0.09821586763220173, 0.12363140098750591, 0.2730378231831959, 0.12811464470412048, 0.12224455683359078, 0.16184134994234356, 0.12401971300797802, 0.1507688526596342, 0.08722037050340857, 0.2061055547424725, 0.13433222392840044, 0.15432700887322426, 0.12360244111291, 0.09949142525770835, 0.19771674488271984, 0.1567832784993308, 0.06333073348339115, 0.12460276457880225, 0.41960890537926127, 100.32399027688163, 126.77701214381626, 118.8070809500558, 105.4980775288173, 89.30096503666469, 83.99227033342633, 56.68399470193045, 103.80340494428361, 95.25724574497768, 169.63326481410434, 104.61387756892613, 86.23485701424735, 50.761715003422324, 0.909456770334925, 0.9115666342633111, 0.30350727534719874, 0.17671766025679453, 0.1648548868085657, 2.418600401708058, 0.4099943627204214, 4.142267601830619, 4.91918694121497, 4.925033850329263, 37.757497787475586, 124.0836124420166, 97.62952055249895, 103.221437726702, 95.82520539419991, 99.03033297402519, 93.44821970803397, 97.79752799442836, 93.08168138776506, 94.91792351858956, 96.25279058728898, 92.71697044372559, 84.21659987313407, 93.31392492566789, 91.16641739436558, 95.83220223018101, 91.6162576675415, 92.30736024039132, 91.90635885511125, 93.86311749049595, 80.45643629346574, 68.62103462219238, 70.02410520826066, 72.32804448263985, 73.75244603838239, 73.1360366003854, 73.29649135044643, 78.07941586630685, 80.82477419716972, 88.74105140141079, 88.47115557534354, 88.60378973824638, 89.40290900639125, 90.49070508139474, 87.04418318612235, 82.07798603602818, 79.3679940359933, 82.2921781539917, 79.25679506574357, 82.99279281071254, 84.24418422154018, 84.56731714521135, 85.0264402117048, 91.26451206207275, 72.11460277012416, 78.31377165658134, 88.04004069737026, 70.96364756992885, 75.05419104439872, 81.73752430507115, 78.2384670802525, 76.18969345092773, 74.55104419163295, 75.61180482591901, 78.1185689653669, 78.33668681553432, 74.6689064843314, 70.97326387677873, 74.40950243813651, 76.48843124934605, 75.29493917737688, 71.57664544241769, 70.48681354522705, 69.85767500741142, 67.42441586085728, 65.99146802084786, 68.16576085771833, 70.17709759303501, 68.60937554495675, 73.29545606885637, 76.12642315455845, 77.14471639905656, 85.89454119546073, 84.01191289084298, 85.1023701259068, 90.56055532182965, 87.12981278555733, 90.81309454781669, 86.00481605529785, 85.29286193847656, 87.91873904636928, 87.87142181396484, 92.17583778926304, 72.55775887625558, 2.4166410097054074, 3.868246717112405, 8.110534940447126, 0.280262999768768, 1.1509300129754203, 0.1929944125669343, 0.21374371488179478, 0.15702950528689794, 1.9681083006518227, 24.912330048424856, 37.06835460662842, 68.1894611631121, 97.15376349857875, 77.36232703072685, 63.06865964617048, 67.58341148921421, 40.33614798954555, 48.18690715517317, 70.17750753675188, 87.18295955657959, 86.83015087672642, 91.02019950321743, 13.076884082385472, 0.4306226415293557, 0.17729651848120348, 0.1633421065551894, 0.12170143026326384, 0.17280400597623416, 0.15984062158635684, 0.19636564595358713, 0.19597684538790158, 0.12629197750772747, 0.17796047856765135, 0.0750909327928509, 0.10765661711671523, 0.1753295133156436, 0.17025449206786497, 0.11675542566393103, 0.08247523941099644, 0.09345726761966944, 0.15495640438582214, 0.14500792750290462, 0.09471905776964766, 0.11617355474403926, 0.14548922596233232, 0.0935700876372201, 0.24306907558015414, 0.11323562024959496], [0.0594685325132949, 0.03638291199292455, 0.012249013392387756, 0.07115886307188443, 0.05885559147489922, 0.03406535867335541, 0.0027159577002748847, 0.052063693425485065, 0.02461479078712208, 0.012112790702043899, 0.045011176860758235, 0.030314074430082525, 0.029253673473639146, 0.02578465131643627, 0.09484696162066289, 0.006938122770017279, 0.06856907811015844, 0.05203020093696458, 0.07460157333740167, 0.19097697867878846, 8.336182032312665, 83.48400265829903, 95.09186472211564, 85.86245441436768, 66.2529148374285, 48.387744835444856, 19.791304452078684, 7.274420857429504, 35.52589620862688, 120.16370282854352, 61.46975408281599, 54.922765323093955, 29.069557121821813, 0.172655691791858, 0.18350098840892315, 0.1813747582158872, 0.1021675198738064, 0.06175552800829921, 0.15208967535623483, 0.02873694191553763, 0.5436364486813545, 0.9103962970631463, 2.393543243408203, 21.91210310799735, 120.25268145969936, 88.27992030552456, 96.75278295789445, 93.11308029719761, 100.44511822291783, 89.86013521466936, 94.74152960096086, 94.15710966927665, 91.0761741910662, 81.39524214608329, 80.4480289731707, 78.66266850062779, 76.64836488451276, 77.06642409733364, 77.9790769304548, 81.53677695138114, 87.3571925844465, 85.9367584500994, 84.30632890973772, 84.5774267741612, 73.78222601754325, 62.07271875653948, 65.09283665248326, 63.12543337685721, 65.97242300851005, 68.0889971596854, 67.4479146684919, 66.27002130235944, 75.96313353947231, 80.23090471540178, 83.84828281402588, 84.77775723593575, 82.20743097577775, 77.46802997589111, 72.62657383510044, 71.81239087241036, 68.19793796539307, 70.78609330313546, 70.2852532523019, 73.5852723802839, 71.4301426751273, 75.98470074789864, 76.63571916307721, 83.70670631953648, 63.77499961853027, 65.81940283094133, 82.90513433728898, 67.53004932403564, 69.05127402714321, 75.36565794263566, 73.53379317692348, 68.71366105760846, 65.15495354788644, 64.73130103519985, 70.01995713370187, 67.50440352303642, 66.61352634429932, 64.76549312046596, 64.34106935773576, 63.88132790156773, 64.4780878339495, 63.04058197566441, 58.32096249716622, 57.119841303144185, 58.69345542362758, 56.54855694089617, 59.57309736524309, 58.827993392944336, 58.17411579404558, 61.0988245010376, 66.49538612365723, 70.1970945085798, 72.26290512084961, 73.17511326926095, 75.98064994812012, 77.33194950648716, 78.51082951681954, 77.3944832938058, 79.7423768724714, 78.68889100211007, 71.57683304377964, 76.73578017098563, 76.04927730560303, 88.18880857740129, 41.315110955919536, 0.46240321333919254, 8.749155163764954, 0.9993451812437603, 0.19761374326688902, 0.21656369284859725, 0.07577337617320673, 0.03314088863719787, 0.07994726220411913, 0.3335454777947494, 5.792887738772801, 31.41887855529785, 50.38217312949044, 48.80664825439453, 66.65737642560686, 94.5776424407959, 34.96483612060547, 17.983775751931326, 39.0869174684797, 50.54778344290597, 67.732999256679, 74.99344989231655, 48.54188019888741, 1.0268500596284866, 0.11601977156741278, 0.08444245492241212, 0.04379638543884669, 0.05281706067866512, 0.03672718709068639, 0.038857278147978444, 0.026548571485493864, 0.05473047175577708, 0.03874180845117994, 0.04523519519716501, 0.03128034222338881, 0.015336904974122132, 0.03993032360449433, 0.07628757679568869, 0.054926330888909955, 0.009140133026189037, 0.06144275729145322, 0.025261017360857556, 0.015165861562958785, 0.028871257922479084, 0.03882470168173313, 0.03041344927623868, 0.03810436212058578, 0.04019835511488574, 0.04418894848121064, 0.06399461893098694, 0.029178067709186246, 0.05599232975925718, 0.052569626098764796, 0.02658479338112686, 0.014069690784838582, 0.015116671166781868, 0.037117192056030035, 0.00853959221525916, 0.0740054463967681, 0.026548335694574883, 0.04797390841745904, 0.03183352129001703, 0.06946749918695007, 0.01302843469394637, 0.016752227242769938, 0.07473527866282634, 0.10646403753863913, 0.2329421304166317, 12.606248719351631, 106.11761365618024, 105.8497119631086, 101.26151071275983, 72.94330746786935, 69.2210602079119, 32.15449128832136, 12.883546113967896, 26.04636812210083, 83.46901539393834, 70.30539608001709, 60.23296083722796, 40.0934613091605, 0.2349556695137705, 0.08101518132856914, 0.03897850860708526, 0.1984905462179865, 0.05782968045345374, 0.22680687106081418, 0.07889908166336161, 0.6390553542545864, 1.2842762576682227, 1.4953790328332355, 31.45871605191912, 125.65479469299316, 91.95915126800537, 104.69025911603654, 96.12338038853237, 104.27014323643276, 92.39911815098354, 99.2444486618042, 98.14487539018903, 95.00776372637067, 85.69614233289445, 84.24373953683036, 84.85876628330776, 81.17476885659354, 79.50133691515241, 79.61607251848493, 83.89881706237793, 90.321259362357, 90.11938640049526, 90.01902662004743, 88.3995613370623, 76.88419369288853, 65.08661801474435, 67.89953368050712, 66.66652025495256, 68.94703020368303, 71.20145661490304, 68.76131180354527, 69.47787257603237, 77.27227142878941, 84.96360765184674, 87.81907408578056, 86.67403180258614, 82.81002044677734, 79.34550966535295, 74.42790821620396, 73.48603125980922, 72.16444914681571, 73.56891632080078, 73.7071785245623, 76.50562109266008, 74.65266854422433, 79.68436636243547, 80.26305403028215, 87.61006532396588, 65.43223530905587, 66.48142719268799, 88.3277725492205, 71.27002143859863, 72.53465611594063, 76.7800679888044, 77.41452884674072, 72.58091027396065, 68.69425473894391, 67.09033257620675, 72.45493943350655, 70.56242384229387, 71.7122881753104, 67.93409402029855, 67.3828934260777, 67.08128602164132, 68.2028364453997, 65.68678256443569, 62.26997116633824, 61.04041794368199, 62.300223623003276, 60.270356042044504, 62.85831683022635, 61.44255188533238, 61.36040333339146, 64.65866456712995, 70.98014259338379, 73.67022105625698, 75.36364991324288, 76.6494140625, 78.17230633326939, 79.62211745125907, 83.38141250610352, 80.0248280933925, 84.33046000344413, 81.9474571772984, 74.74329389844621, 79.28241307394845, 80.98355443137032, 88.17362676348004, 53.87286819730486, 1.2031163041080748, 0.7978278260145868, 0.6371732609612601, 0.5313308089971542, 0.3769012327705111, 0.08346039761922189, 0.06510089564004115, 0.19107657404882566, 0.12808565768812383, 5.731319316795894, 36.09793445042202, 52.071328844342915, 50.38577577045986, 71.96526513780866, 68.77184527260917, 42.513407707214355, 29.83631862912859, 51.180229323250906, 58.89031873430525, 75.18340669359479, 83.07407978602818, 70.66372857775006, 1.5284070777041572, 0.08119440956839494, 0.1142622030207089, 0.05813177102910621, 0.044949291074382405, 0.05033898293705923, 0.0540074384106057, 0.05011520208790898, 0.021358404541388154, 0.024374820092426877, 0.03591167960049851, 0.02293363885421838, 0.04616871689047132, 0.028866090878312076, 0.024753256035702567, 0.07878529812608447, 0.037074895575642586, 0.04152987491605537, 0.0387764714126076, 0.025858117999242883, 0.023919998069426844, 0.02676928535635982, 0.027085321522983055, 0.06381329401795353, 0.011003791371227374, 0.13751907220908574, 0.14970356625105652, 0.10043828694948129, 0.16646004281938076, 0.15061437737728867, 0.14485242084733077, 0.21501906216144562, 0.10934855097106524, 0.11690179923815386, 0.09346794776086297, 0.22641982111547673, 0.10002057400665113, 0.1014046904497913, 0.1539881077728101, 0.1025635739788413, 0.12314563776765551, 0.1466901379504374, 0.1823810799313443, 0.28093841352633064, 0.5499897077679634, 20.60770389011928, 130.83246721540178, 121.6540219443185, 117.98207964215959, 90.98972470419747, 71.85150228227887, 29.083637646266393, 19.01967399460929, 45.990036146981375, 162.66166469029017, 75.21513911655971, 70.82063974652971, 50.805141244615825, 0.6661429607442447, 0.3966632123504366, 0.338335745036602, 0.38168463323797497, 0.2464987172612122, 0.6234720104507038, 0.3867575510271958, 1.6071017235517502, 4.670491371835981, 8.17930907862527, 29.980028220585414, 131.76340075901575, 94.89035306658063, 106.60013130732945, 101.19188281467983, 107.00270993368966, 96.26305307660783, 103.16506004333496, 100.67497158050537, 98.85104860578264, 88.81825283595494, 87.78847421918596, 88.56824275425502, 86.28120149884904, 84.36814703260148, 84.04035881587437, 89.27911990029472, 96.92417417253766, 95.19626140594482, 93.59559100014823, 90.91314860752651, 81.20951679774693, 68.98644038609096, 72.10653591156006, 71.05145195552281, 71.21721512930733, 75.57790456499372, 72.54743385314941, 73.33280958448137, 80.80040686471122, 87.23814909798759, 91.13023117610386, 90.26705646514893, 89.34933144705636, 84.33751242501395, 80.0800176348005, 77.84356621333531, 76.35171849387032, 78.37646525246757, 76.11321462903703, 81.7324799128941, 77.6355232511248, 83.71594742366246, 85.75815500531877, 92.11895983559745, 69.28292696816581, 73.11783926827567, 90.67546463012695, 75.61057499476841, 75.2568838936942, 83.72489670344761, 80.576918057033, 76.15138108389718, 71.40168980189732, 71.87647410801479, 77.74797984531948, 76.033616065979, 74.49898828778947, 73.11315618242536, 71.89824281420026, 71.28552981785366, 71.07250499725342, 69.07390430995396, 65.57513890947614, 64.58955083574567, 65.51196588788713, 65.15474510192871, 67.51443672180176, 65.70802320752824, 64.64613001687187, 69.3919164112636, 75.53396415710449, 78.51745809827531, 79.22601454598563, 81.72843606131417, 83.12168189457485, 84.42729009900773, 86.56727967943463, 83.27054704938615, 88.25389930180141, 85.49678461892265, 80.15539864131382, 82.23236806052071, 83.48127896445138, 93.7334293637957, 49.36847959245954, 1.3687334571565901, 21.12611072404044, 4.639406434127262, 0.5656103981392724, 0.5568946972489357, 0.19811583203928812, 0.3027806186250278, 0.26366011638726505, 0.7551991077406066, 11.763615489006042, 48.94765847069876, 67.10645934513637, 58.32902240753174, 89.4409990310669, 135.9603350503104, 48.80765226909092, 27.07827636173793, 55.9720127923148, 68.44852474757603, 88.94730172838483, 94.00276238577706, 80.56839261736188, 1.5693234992878777, 0.19126420255218232, 0.1993460024573973, 0.1072348193930728, 0.14093514318977082, 0.21391663274594716, 0.14482783073825495, 0.1316168082079717, 0.16545521388096468, 0.1387182878596442, 0.10413664885397468, 0.10797691278691803, 0.1536343331847872, 0.11638737469911575, 0.17531421913632325, 0.14196473865636758, 0.08241746893950871, 0.1893394429768835, 0.09295658341475896, 0.06575504411011934, 0.12894373307270662, 0.0870286300778389, 0.1464399213769606, 0.11652198247611523, 0.10291962844452687], [0.05082191327320678, 0.019333791752744998, 0.03520573176709669, 0.029187994676509073, 0.08260244437094245, 0.040109884326479266, 0.02368769821311746, 0.011329079362829881, 0.04411209760499852, 0.04468660302726286, 0.03746467323175498, 0.017644544897068824, 0.03813537456361311, 0.007894675214109676, 0.04353885425786887, 0.0047392532828130895, 0.053084308481109996, 0.057503115119678636, 0.14058736685131276, 0.5367270622934613, 36.71794305528913, 92.94082055773053, 77.9939043862479, 74.48374394008091, 58.95863342285156, 30.07481207166399, 46.15815476008824, 111.19428021567208, 111.26854951041085, 92.33148438589913, 98.56733281271798, 45.38954503195626, 1.5034412230764116, 0.09442499426326581, 0.17432370728680066, 0.17828660963901452, 0.07069653645157814, 0.13735488030527318, 0.05426106122987611, 0.46227613730090006, 1.3016060420445033, 2.5433791918413977, 7.093097627162933, 112.1931254523141, 87.94518389020647, 98.85113893236432, 92.59973348890031, 96.90556689671108, 91.43685517992292, 93.25044618334088, 93.20089163099016, 92.09482179369245, 86.77970000675747, 94.51803384508405, 82.98717171805245, 79.63088607788086, 71.8184427533831, 71.18023681640625, 70.2666459764753, 77.34411580221993, 81.19512013026646, 83.88433006831578, 82.3303029196603, 80.92202118464878, 63.303967339651926, 61.79039260319301, 60.93750817435128, 63.281302315848215, 65.62042031969342, 66.61723668234688, 64.3004710333688, 63.80829538617815, 68.73790332249233, 77.04251534598214, 75.79008170536586, 73.6564497266497, 66.17505332401821, 63.00113705226353, 59.13090705871582, 60.54555334363665, 57.17368984222412, 61.99509348188128, 63.170131138392854, 69.40525695255825, 70.8097310747419, 75.80729934147426, 74.41395623343331, 84.94169998168945, 63.33856936863491, 56.54088960375105, 84.09286635262626, 64.96654619489397, 65.5529602595738, 69.1950808933803, 76.1776522227696, 68.73193481990269, 68.10205282483781, 60.16857188088553, 66.34734085627964, 65.2909436907087, 64.1546630859375, 60.985534123011995, 61.281353678022114, 59.67953681945801, 62.02122565678188, 59.12169374738421, 57.76112181799752, 57.08409629549299, 58.56005695887974, 55.10454409463065, 55.10860531670706, 57.11739901133946, 59.615238189697266, 56.81716735022408, 62.256317956107004, 67.18546731131417, 71.36252975463867, 67.62997831617082, 72.07308728354317, 72.51452023642403, 75.89586802891323, 76.79371425083706, 81.33807236807687, 75.17078876495361, 75.57247802189418, 67.91616071973527, 80.36022458757672, 75.76279612949916, 91.68365519387382, 29.62571178163801, 1.2217229285410471, 0.5648761689662933, 0.31708945653268267, 0.12960489759487764, 0.019139969921005622, 0.01169029832817614, 0.02597088203765452, 0.04259750905579754, 0.3837509352181639, 2.1793648047106604, 22.371101106916154, 54.78194270815168, 87.08888789585659, 51.512189933231895, 37.243122645786826, 29.893123626708984, 16.988986526216777, 50.34051867893764, 59.76042079925537, 69.87583759852818, 74.76702199663434, 22.992928402764456, 0.8330354339310101, 0.21502492470400675, 0.13112899581236498, 0.009701023643304194, 0.060328724927135875, 0.03605079963537199, 0.010474799533507653, 0.013855137163773179, 0.052567658347210715, 0.029953365214169025, 0.036780214602393765, 0.03439509276566761, 0.03189022306885038, 0.06828468372779233, 0.03630388980465276, 0.0894684452297432, 0.06406075573925461, 0.04175185086205602, 0.1421088594943285, 0.04213279059955052, 0.05547451933047601, 0.028452898675043668, 0.060035217819469314, 0.04998857049005372, 0.10640660633466073, 0.02749410833764289, 0.02354385387817664, 0.03982367825561336, 0.0822693243888872, 0.061037536178316386, 0.013480200764856167, 0.012194743313427483, 0.027274240939212695, 0.02906018921307155, 0.04214431890951736, 0.018894034903496504, 0.07016163372567721, 0.0453955499854471, 0.05704008282295295, 0.021115633193403482, 0.04671374675152557, 0.04792585117476327, 0.13406793453863688, 0.6432868071964809, 57.73215477807181, 112.13228702545166, 89.28360148838588, 87.82247175489152, 71.61171994890485, 42.759318351745605, 41.76128952843802, 66.80096789768764, 110.11066695622036, 98.03526755741665, 89.54269286564418, 54.45435946328299, 1.5034583764416831, 0.037759008152144294, 0.16610993232045854, 0.11055069789290428, 0.17938373291066714, 0.05137683278215783, 0.19471493310162, 0.5359351305024964, 1.9891448404107774, 1.81290117757661, 11.05940340246473, 119.04245812552315, 89.51813793182373, 103.70271859850202, 95.2230258669172, 100.85283851623535, 94.03805228642055, 97.57198251996721, 94.90572248186383, 94.81620189121791, 91.97709151676723, 96.94769382476807, 86.13465009416852, 82.992445400783, 75.01972797938755, 75.53268568856376, 75.23525415148053, 80.14652579171317, 83.55909184047154, 88.42126750946045, 87.42622988564628, 82.7085211617606, 64.91485854557583, 63.36174161093575, 63.072682653154644, 65.32887390681675, 68.69561658586774, 67.74816022600446, 66.66484573909214, 66.54981136322021, 71.34097644260952, 77.89706039428711, 77.68600886208671, 75.21123422895158, 66.7947006225586, 66.40200928279332, 60.961326599121094, 62.23970481327602, 59.83102144513811, 67.12058503287179, 66.6787977218628, 72.21488612038749, 74.18725040980748, 77.61242049080985, 75.72050939287458, 88.31013107299805, 65.85598509652274, 58.35882323128836, 84.61110469273159, 68.89795507703508, 67.85987336294991, 71.96311814444405, 77.90971306392125, 72.0653053011213, 71.27287714821952, 62.53652490888323, 69.21080466679165, 69.07230622427804, 66.24277741568429, 64.97319562094552, 64.59142684936523, 60.73054218292236, 65.10900511060441, 64.25681550162179, 60.95739391871861, 61.386855125427246, 61.350099154881065, 57.94608981268746, 59.438656670706614, 60.011222975594656, 64.5281982421875, 59.72560337611607, 65.61409745897565, 71.41610731397355, 74.0854662486485, 71.60065841674805, 74.7612202508109, 77.03272533416748, 80.09012726375035, 81.02779361179897, 84.753751209804, 77.66150951385498, 77.17057064601353, 70.06036785670689, 82.95367445264543, 79.99632658277238, 95.34331308092389, 39.68351411819458, 1.5931800305843353, 0.26640177784221514, 0.6793925240635872, 0.2667282888931887, 0.17544061663959706, 0.10021285726023571, 0.05954767683787005, 0.03867067762517503, 0.46050516090222765, 0.9803417495318821, 26.569921834128245, 55.55336645671299, 88.99639769962856, 61.02382564544678, 36.85380118233817, 37.12499284744263, 30.988378592899867, 54.70650264195034, 70.09244074140275, 75.72926412309918, 89.65756048474992, 38.066049916403635, 0.8604472173111779, 0.2541686328394072, 0.2229513536606516, 0.0662068941497377, 0.032512188622994084, 0.037756195624492, 0.035489871698830805, 0.023352902249566147, 0.06283828669360705, 0.009119372399124717, 0.04937158199027181, 0.05134266175861869, 0.005417651746289006, 0.06138253052319799, 0.025825760360541086, 0.08079577024493899, 0.05012843691344772, 0.038283756601491144, 0.041629385469215255, 0.013538578525185585, 0.025587720097973943, 0.10073059983551502, 0.04691885431696262, 0.028843400667288473, 0.15489165857434273, 0.11446292724992548, 0.1148874323282923, 0.16367842922253267, 0.18975876404770783, 0.11992461846343108, 0.21706332532422884, 0.10201764505888734, 0.15513097787542002, 0.12682203549359525, 0.18936021971915448, 0.13743924934949192, 0.15932048378246172, 0.07523201379392828, 0.11312701393451009, 0.12403249660772936, 0.11117182206362486, 0.14131350788686955, 0.2820747425513608, 1.1490685471466608, 78.40568937574113, 130.8495041983468, 104.99536146436418, 102.82177039555141, 84.0129759652274, 47.608455726078574, 73.40237494877407, 147.25820323399134, 137.7539291381836, 105.88527979169572, 124.22637013026646, 70.97962147848946, 2.9626465226922716, 0.5417853508676801, 0.3394622488745621, 0.4088516826076167, 0.5207002280013902, 0.41042892368776457, 0.5484640353492328, 1.5989367216825485, 3.9695770740509033, 5.476534519876752, 10.38929307460785, 126.30081040518624, 92.71756104060582, 110.42769936152867, 99.66321659088135, 106.85861124311174, 97.91418130057198, 97.78465298243931, 98.88108566829136, 99.00682721819196, 93.25385080065045, 102.15672356741769, 90.09025260380336, 87.08081408909389, 79.93759346008301, 79.66881629398891, 78.44800390516008, 83.75816467830113, 87.5556331362043, 90.00604738507951, 91.2899911063058, 87.77890654972622, 69.91867324284145, 67.28286021096366, 66.34939057486397, 68.88842214856828, 72.6487455368042, 70.23531654902867, 70.39068521772111, 69.88056237357003, 75.08160863603864, 81.46630832127163, 81.60787786756242, 81.12340777260917, 72.73468780517578, 68.61833872113908, 65.65341036660331, 69.10835347856793, 63.606936591012136, 70.88103348868233, 72.04315444401333, 76.29060908726284, 78.67662743159703, 80.76646491459438, 81.09039688110352, 94.02860968453544, 70.57663985661098, 62.02715941837856, 89.3133328301566, 73.8498945236206, 71.47485433306012, 76.28636373792375, 82.9281815120152, 76.4549617767334, 75.559248651777, 67.16286482129777, 73.73112896510533, 74.07306371416364, 70.50108514513288, 68.20417049952916, 69.28492804936, 65.06350135803223, 70.89531203678676, 67.6819508416312, 65.43856511797223, 64.11490549360002, 64.901656968253, 61.959914752415244, 62.369768142700195, 66.15969780513218, 67.85162585122245, 65.42903913770402, 69.12740543910435, 75.91967950548444, 79.23919527871269, 75.5801488331386, 80.32805442810059, 80.53560406821114, 83.0835154397147, 83.65487275804792, 87.50412614004952, 82.43924372536796, 82.57886777605329, 74.66036020006452, 87.83868190220424, 84.13972500392369, 100.61960833413261, 36.758214814322336, 2.528177401849202, 4.746917647974832, 0.8792826437524387, 0.8501163316624505, 0.6392492524215153, 0.291124445519277, 0.22876354892339024, 0.20802921509104116, 0.6956986433693341, 2.629115185567311, 38.33244037628174, 73.04366030011857, 95.78767817361015, 63.01072556631905, 53.915439810071675, 39.864813464028494, 27.934278794697352, 65.84216512952531, 83.81055409567696, 88.19011483873639, 103.40247998918805, 41.36347736631121, 1.1283443506274904, 0.42742524881448063, 0.3298412194209439, 0.17629399656185082, 0.1731534515108381, 0.0774334053109799, 0.0892218995307173, 0.09908932540565729, 0.14619839005172253, 0.14878158643841743, 0.15987441263028554, 0.13811741795923027, 0.1585138684936932, 0.11548132688871451, 0.1286043162856783, 0.24062105693987437, 0.19775551637368544, 0.07229032021548067, 0.2274281105824879, 0.0920091788949711, 0.12053144590130874, 0.17323761699455126, 0.09215944047485079, 0.12589769437909126], [0.033129068557173014, 0.10105540097824164, 0.055520554538816214, 0.03518394061497279, 0.04221073052446757, 0.024416692488427674, 0.012172178631382329, 0.043985360834215365, 0.016328541495438133, 0.0028787673010291265, 0.10629154715154852, 0.027986382100997225, 0.024278834528688873, 0.033154774856354506, 0.02657126000017992, 0.04535868178520884, 0.017578560759180357, 0.0918061544320413, 0.14990081638097763, 5.709019507680621, 82.32106876373291, 80.59610898154122, 80.86097431182861, 56.64395918164934, 43.99688284737723, 28.09922555514744, 77.83525616782052, 64.53739765712193, 41.88485976627895, 93.97332981654576, 58.106124196733745, 5.575733082635062, 0.19066644034215383, 0.08637978096625634, 0.10988934338092804, 0.0834017586229103, 0.10881402143942458, 0.05010795872658491, 0.048858711296426396, 0.20679513631122454, 1.9502698864255632, 0.27201125398278236, 74.03694002968925, 90.96496827261788, 90.65994930267334, 88.78236539023263, 86.36640725816999, 91.51820468902588, 89.48669038500104, 94.51729038783482, 88.67196546282086, 91.9898762021746, 95.71931484767369, 90.85770198277065, 85.77786704472133, 79.60453156062535, 72.21437890189034, 68.98869855063302, 68.97405174800328, 71.66779885973249, 74.44921834128243, 79.37715176173619, 79.80710629054478, 71.61709090641567, 59.202334540230886, 58.92396191188267, 60.88055379050118, 65.93637575422014, 65.45293399265834, 66.59521784101213, 63.53880255562918, 63.7426974432809, 60.20808628627232, 62.25172519683838, 58.5666230065482, 57.70105116707938, 55.73174408503941, 56.513951437813894, 56.190693446568076, 60.3160890851702, 59.85242189679827, 65.03912012917655, 65.73709447043282, 70.4412681034633, 69.55334390912736, 77.83693068368095, 68.82959175109863, 82.19377776554653, 63.4153539112636, 54.24705301012312, 86.97538907187325, 68.19740990230015, 67.73216547284807, 70.03440243857247, 73.5592096873692, 69.71588311876569, 66.894455909729, 61.046977043151855, 57.49830968039376, 60.33368192400251, 59.17274216243199, 57.57219335011074, 60.74211093357631, 60.22965349469866, 60.514480999537874, 61.387119156973704, 58.23801142828805, 58.956027848379954, 55.45262452534267, 58.28856304713658, 56.68841028213501, 57.36321585518973, 56.53448683874947, 58.586814471653526, 56.80569934844971, 60.46382168361119, 63.79421138763428, 67.13585717337472, 69.45174734933036, 73.16107790810722, 73.94134671347481, 76.49867984226772, 77.94783782958984, 79.83911664145333, 71.06599453517369, 69.77378940582275, 69.41968836103166, 82.06994002205985, 77.04179968152727, 74.68645763397217, 15.237805979592459, 0.8128157960517066, 0.629302091896534, 0.1422307515250785, 0.12471845479948179, 0.06420922598668508, 0.03383168478363326, 0.10489855547036443, 0.15422659926116467, 0.10541298679475274, 0.11578080510454518, 20.816426038742065, 48.206122398376465, 46.4351030077253, 68.41747324807304, 35.272974831717356, 26.775741372789653, 35.078487804957796, 52.72059978757586, 62.92446368081229, 70.24765654972622, 56.8093957901001, 4.99030522789274, 0.10624824983200856, 0.12725684073354515, 0.00937284594069102, 0.047095093610031266, 0.032759110908955336, 0.04840996555451836, 0.035745587798633745, 0.04336484055966139, 0.02345224147263382, 0.028460184444806406, 0.011849560675078204, 0.05029147530772856, 0.0181407643415566, 0.028909004825566496, 0.025421631688784276, 0.015466288031478013, 0.051386532440249405, 0.014331903009276305, 0.024550698065598096, 0.06240710483065673, 0.06836008932441473, 0.03894153184124401, 0.04399659398144909, 0.044020760006138256, 0.06469980001981769, 0.02779852459207177, 0.026062960936022655, 0.02658469838622425, 0.05266386443482978, 0.043805640656501055, 0.03696550555261118, 0.0026063098339363933, 0.03221566203449454, 0.05093311159206288, 0.05832011877958264, 0.029556524008512497, 0.014835947658866644, 0.01285218183017735, 0.0722846273066742, 0.03959233174100518, 0.04247836848454816, 0.12752544560602733, 9.086775950023107, 105.89592443193708, 94.34334223611015, 95.83773994445801, 69.08081776755196, 63.25140421731131, 33.73385156903948, 69.84826019832066, 75.8745231628418, 47.043911116463796, 93.98434965951103, 68.6641412462507, 6.363115974834987, 0.05623725036691342, 0.092055312490889, 0.12269666471651622, 0.03506643531311836, 0.13355015803660664, 0.09767707690064396, 0.12792043441108294, 0.21007688449961798, 2.18003682579313, 1.2764330442462648, 82.00550937652588, 93.01533998761857, 94.80425793784005, 91.14112595149449, 90.4393231528146, 96.25260298592704, 92.48173918042863, 97.49564961024693, 92.37856537955147, 94.59566606794084, 98.48951298849923, 93.64218561989921, 87.82167966025216, 84.17532757350376, 77.46001175471714, 72.8447264262608, 70.78947707584926, 72.71566363743374, 77.39758219037736, 83.36377102988106, 80.87508610316685, 74.56143174852643, 61.59833744594029, 61.98073155539376, 64.16086782727922, 67.77855164664132, 66.7586394718715, 67.76025703975132, 65.36329528263637, 66.8015307017735, 62.883601324898855, 65.175124168396, 60.90055070604597, 60.430345262799946, 58.183568818228586, 60.86934634617397, 60.811870847429546, 63.06714493887765, 63.50168527875628, 68.24182278769356, 68.93810871669224, 74.0722438267299, 74.06089047023228, 83.01717403956822, 73.88188402993339, 85.59205831800188, 64.41158662523542, 55.928291252681184, 88.68830067770821, 73.52480220794678, 69.50954246520996, 72.87564590999058, 76.84458896092006, 75.2518811907087, 71.5590317589896, 63.36133166721889, 59.53891222817557, 62.49047919682094, 62.10134533473423, 61.157029560634065, 62.19169970921108, 64.34671824319022, 62.941723006112234, 64.41524832589286, 63.03179250444685, 62.41988549913679, 58.0452857698713, 60.50710201263428, 60.822786467415945, 59.835113934108186, 60.55163996560233, 61.551874841962544, 59.244517053876606, 64.35477815355573, 66.60238838195801, 72.55011585780552, 72.60030964442662, 74.82722813742501, 78.10460308619908, 80.09264945983887, 80.52702304295131, 83.52392700740269, 73.32769571031842, 72.67125770023891, 73.57414831433977, 84.891784123012, 78.85940674373082, 80.68744305201939, 22.948812552860804, 0.7334286102226802, 0.24822982294218882, 0.19782809247928007, 0.04085602178903563, 0.24905218024338993, 0.11234337384147303, 0.35040739870497156, 0.0762640248451914, 0.07072133012115955, 0.09365411062857934, 22.313948699406215, 45.91914020265852, 46.67972823551723, 43.97608341489519, 29.60331426348005, 34.54322637830462, 49.123479161943706, 59.065739904131206, 71.23034722464425, 76.59211226872036, 76.5632494517735, 9.323412486485072, 0.6603533742683274, 0.2488783938544137, 0.05379512141059552, 0.025819723095212663, 0.011048968232768987, 0.03460041406963553, 0.019277208717539907, 0.03154809892709766, 0.015864052044759904, 0.049789020126419406, 0.061340617415096076, 0.025476001003491025, 0.011226327956787177, 0.022667749818148356, 0.0930054040093507, 0.06361299726579871, 0.03420936416036316, 0.024760392527761202, 0.06332937641335384, 0.06747029242771012, 0.028984451134290014, 0.046276125591248274, 0.06283621716180018, 0.14375643751450948, 0.14363719177033218, 0.12247721292078495, 0.11114123370498419, 0.13877501338720322, 0.2016571063016142, 0.13432699920875685, 0.1325055126632963, 0.061416084079870155, 0.09147734993270465, 0.16080245854599134, 0.09819427664790835, 0.12253380274134022, 0.12476325168141297, 0.147077703582389, 0.12253902746098382, 0.1441493092903069, 0.23811007024986403, 0.364280318575246, 13.313105463981628, 130.48215293884277, 109.77507591247559, 113.19561154501778, 85.51999160221645, 66.90553828648159, 42.69219527925764, 101.20083209446499, 83.74855531964982, 59.0669766834804, 112.10047122410366, 85.2867683683123, 8.287126881735665, 0.2913629912904331, 0.17065467845116342, 0.4885340854525566, 0.20216866742287362, 0.5437442543251174, 0.42315886488982607, 0.3454464391938278, 1.1070666866643089, 3.3145979685442786, 1.5170033467667443, 82.836270741054, 96.22017574310303, 99.54246384756905, 95.16962201254708, 95.81506797245571, 102.24316610608781, 96.08488736833844, 101.43616758074079, 95.93088749476841, 95.32200990404401, 99.02458681379045, 96.53594357626778, 92.74064990452358, 86.73842770712716, 80.36990342821393, 76.2668879372733, 74.84983757564, 78.48622594560895, 82.6807839529855, 87.33865479060582, 87.09429359436035, 78.66177218300956, 63.87414346422468, 65.39137990134103, 66.90776865822929, 72.28738362448556, 71.65193612234933, 70.49601990836007, 70.460875919887, 69.49753597804478, 64.66812801361084, 67.82855088370187, 64.12409796033586, 63.22010953085763, 60.10715675354004, 64.28610215868268, 64.55034909929547, 67.72590514591762, 65.34111663273403, 70.36528955187116, 71.26393481663295, 78.31242370605469, 77.15247058868408, 86.41961656297956, 79.46630409785679, 90.74377237047467, 68.63559109824044, 60.487640108381, 92.61790997641427, 78.29648453848702, 72.22050026484898, 77.0630750656128, 80.0473472050258, 79.20687225886753, 73.07634462629045, 68.72726563044957, 64.96187005724225, 66.27146652766636, 65.5112224306379, 65.10034070696149, 66.04175908224923, 66.09762954711914, 65.50350298200334, 68.81716837201799, 65.75858524867466, 67.02554757254464, 62.769268717084614, 66.86362675258091, 63.423545837402344, 64.62266595023019, 63.672451155526296, 66.50341824122837, 62.749758175441194, 66.8973811013358, 69.69398934500558, 76.89203820909772, 77.65800762176514, 79.77470684051514, 82.15927301134381, 83.5520463671003, 83.24570723942348, 86.20142923082624, 76.60971900394985, 77.76756681714738, 77.19860662732805, 90.7048624583653, 81.80758299146379, 85.50125925881522, 22.781920296805247, 2.2227582590920583, 3.2279741253171648, 0.5799676020230565, 0.19682650693825313, 0.41911951878241127, 0.3436131461390427, 0.6239860685808318, 0.2383950820990971, 0.1531540389571871, 0.2116122463984149, 32.56374018532889, 64.48765550340924, 64.07332747323173, 89.99884905133928, 49.44905437741961, 37.99466412408011, 51.60139438084194, 69.08550780160087, 84.84945569719586, 88.79142584119523, 93.05245031629289, 10.650964839117867, 0.7562204386506761, 0.3956974670290947, 0.12957738978522165, 0.1800055152603558, 0.06438811495900154, 0.1308972489620958, 0.22350471253905976, 0.15379502384790353, 0.10547398709292923, 0.14194161418293202, 0.12903775088489056, 0.19988214011703218, 0.1557021008006164, 0.09434018417128495, 0.18944305527423108, 0.0852416945355279, 0.11133377480187587, 0.1340060792863369, 0.12310204867805753, 0.10854700433888606, 0.18767226886536392, 0.13917581045201846, 0.13221105560660362], [0.04268927752439465, 0.07234362592654568, 0.022569479287735054, 0.02826081050027694, 0.07085049604730946, 0.10080478406910386, 0.018145157855802348, 0.0659068256084408, 0.06793198122509889, 0.05131666368937918, 0.027347597360078777, 0.0413005334724273, 0.06670857580112559, 0.015033165558374353, 0.030579035569514548, 0.04281704906108124, 0.10177959461829492, 0.0820805559466992, 0.22164707364780561, 20.838917357581003, 80.68072414398193, 75.33746910095215, 61.85573346274239, 49.27504369190761, 27.34182153429304, 44.69613913127354, 63.59891836983817, 48.67072064535958, 148.24758502415247, 81.85309369223458, 13.179374354226248, 0.09191000421664544, 0.01960248313844204, 0.16001233165817602, 0.04882468276524118, 0.13368278449135168, 0.06252516992390156, 0.050950142821030955, 0.050568229385784695, 0.33530733468277113, 0.7726936947022165, 45.77763319015503, 110.49783447810582, 88.18053327287946, 91.64275114876884, 83.89775398799351, 87.376327923366, 82.06162997654506, 87.73252732413155, 85.96437753949846, 95.49104567936489, 87.00639888218471, 84.33765833718437, 85.49225439344133, 86.31680406842912, 76.46035357883999, 74.57603686196464, 68.01346329280308, 66.75192056383405, 65.73633711678642, 72.01311043330601, 73.42453970227922, 69.7927301951817, 60.051029205322266, 59.526586123875205, 59.14446299416678, 61.657973834446494, 59.44653592790876, 64.28540733882359, 61.3012672151838, 61.093523025512695, 63.14571516854422, 59.53213078635079, 57.069400855473106, 58.372434752328054, 55.6848645891462, 57.63308736256191, 60.439683641706196, 61.46060330527169, 63.88571916307722, 63.28927189963204, 69.51007747650146, 67.67783750806535, 70.4026917048863, 72.04088238307408, 75.38387611934117, 69.08078997475761, 84.15768609728131, 61.00469725472586, 41.947032247270855, 86.27995082310268, 65.32035541534424, 63.87897941044399, 60.94263594491141, 73.36865534101213, 68.79508699689592, 70.56152057647705, 61.55942753383091, 60.62950842721121, 55.612794399261475, 57.9057867867606, 56.61734758104597, 60.5385981968471, 58.600766454424175, 59.372739110674175, 56.502358368464876, 57.62247051511492, 55.2284825869969, 57.47808347429548, 53.276493889944895, 56.23497779028756, 54.26870707103184, 57.322655745915, 54.784902640751426, 58.57337665557861, 54.961036000932964, 61.256263732910156, 62.258291244506836, 65.4106194632394, 68.60053743634904, 74.70094462803432, 77.07809012276786, 78.54240213121686, 74.54934883117676, 75.07419490814209, 64.63191400255475, 70.06527328491211, 72.05584185464042, 83.11144719805036, 69.7641453061785, 68.20066165924072, 7.61573200566428, 0.8252856954932213, 0.05061984893732837, 0.06760192822132792, 0.058577670316611014, 0.11688498514039175, 0.10116306412965059, 0.13885741467986787, 0.17127567370023045, 0.06925840183560338, 0.58160726832492, 18.02817300387791, 20.71576748575483, 69.19736685071672, 55.286705017089844, 27.493429490498134, 13.16446612562452, 54.706064905439106, 58.77008710588728, 61.23357786451067, 68.46818120138985, 28.270420483180455, 0.7594204097986221, 0.03690167576340692, 0.018894888161282455, 0.01791792835241982, 0.04334391453968627, 0.03441487206146121, 0.01718707489115851, 0.01885346190205642, 0.011434233631007373, 0.02324016365621771, 0.05747726972081831, 0.02279631863348186, 0.024814369988494685, 0.050561698486230204, 0.04510862806013652, 0.019150095359821404, 0.018462335657594458, 0.035619838296302726, 0.08999656939080783, 0.008355587088902081, 0.06277507437126977, 0.08536623285285064, 0.00897713195133422, 0.12157922610640526, 0.012918807183658438, 0.009714730898849666, 0.016559711590941464, 0.08146357083959238, 0.038196038986955366, 0.02461967115024371, 0.04718040242525084, 0.006621520450737859, 0.020654721318611076, 0.028197109632726227, 0.006722271026644323, 0.026364425563120415, 0.01619066996499896, 0.014432209144745554, 0.009921435566086854, 0.13181960875434534, 0.22568172429289135, 0.1975651058767523, 29.8509133202689, 105.71124826158795, 88.27088069915771, 77.36155578068325, 60.22843755994524, 41.05422346932547, 48.24876349312918, 57.79816266468593, 48.38032068525042, 122.51891980852399, 94.45956475394112, 15.833629642214094, 0.04608058536957417, 0.04940086416900158, 0.19983931098665508, 0.15550662843244417, 0.11157863773405552, 0.11211387972746577, 0.1617628162992852, 0.05366855088089194, 1.2312002714191164, 1.3275420389005115, 51.63346379143851, 114.6194989340646, 93.91908523014614, 93.36382688794816, 86.87623827798026, 93.05881486620221, 87.32730838230678, 91.69008922576904, 87.48867334638322, 97.2844660622733, 91.70545864105225, 87.68946238926479, 89.88828236716134, 89.21051338740757, 81.40011978149414, 78.82874434334892, 73.07612228393555, 71.48599924360002, 69.17462539672852, 75.59639372144426, 74.47042424338204, 71.97727162497384, 61.78384740012032, 62.13703128269741, 61.171558243887766, 64.09112875802177, 61.61440862928118, 66.01030458722795, 63.9594395501273, 63.60634599413191, 64.37313529423305, 61.50793443407331, 60.903573172433035, 60.41455895560128, 59.10612978254046, 60.34970446995327, 64.51057066236223, 65.97475760323661, 67.00765596117292, 67.40915761675153, 71.96913528442383, 70.35572188241142, 74.68383816310337, 75.16908645629883, 77.58751814705985, 72.19645949772426, 86.80308764321464, 64.90439455849784, 45.162464005606516, 87.07666601453508, 70.92604391915458, 68.19112178257534, 64.3247549874442, 77.89161995479039, 72.83691665104458, 73.59024034227643, 66.87814153943742, 65.10031986236572, 60.13483837672642, 61.917461259024485, 58.857516288757324, 62.14153371538435, 60.67602661677769, 63.36932209559849, 59.86062771933419, 60.71103164127895, 58.317286900111604, 61.40565000261579, 57.398585660117014, 60.621115003313335, 58.69292041233608, 60.56989983149937, 58.714689118521555, 60.96020793914795, 58.38813073294503, 66.8080689566476, 65.51961585453579, 68.79441302163261, 71.89458806174142, 78.57359259469169, 78.6385165623256, 79.57135391235352, 77.38033676147461, 78.93172359466553, 68.44339697701591, 72.66810321807861, 76.43418666294643, 85.39048412867955, 76.18490614209855, 78.43701880318778, 12.801037124225072, 0.6609548277088574, 0.27134726675493376, 0.060905628970691135, 0.15007657052150794, 0.2791479496019227, 0.061259423914764605, 0.2626916297844478, 0.1256034815950053, 0.030814758634993007, 0.38048984163573807, 19.725032533918107, 20.21759728022984, 52.922434534345356, 45.53158358165196, 35.402183532714844, 26.815483331680298, 65.30415221623012, 66.30370616912842, 69.17645972115653, 79.75047152382987, 54.19346502849034, 1.0474560282060077, 0.04129754113299506, 0.05303026316687465, 0.022052912274375558, 0.04888675514874714, 0.028238473127463033, 0.009541664605161973, 0.02680859967534031, 0.03361836015912039, 0.028158840257674456, 0.009375641504967851, 0.0463696378948433, 0.0159470657152789, 0.021726428364802684, 0.03506267283643995, 0.0031249976933135516, 0.024604772217571735, 0.01593150181828865, 0.04383111625377621, 0.009680125612898596, 0.02621621824800968, 0.03121993225067854, 0.07799405844083854, 0.15340262704661914, 0.09850258260433163, 0.09416853516761746, 0.16431245234395775, 0.21493797722671712, 0.15405836328864098, 0.0844786072682057, 0.14317312810037816, 0.15842811523803643, 0.11780301587922232, 0.08213188712085996, 0.0720633366810424, 0.13430471611874445, 0.27570449294788496, 0.08906308162425246, 0.11503858278904643, 0.2556287316339356, 0.30990833044052124, 0.38244071123855455, 43.16135501861572, 128.72438376290458, 106.79564666748047, 90.8738704408918, 69.77051680428642, 41.35438912255423, 65.06983116694859, 82.52304594857353, 69.99245616367885, 169.28639684404646, 104.73576286860875, 23.972645248685563, 0.2599127031862736, 0.1777346892548459, 0.5853890968220574, 0.19375312328338623, 0.35928999206849505, 0.26385683725987163, 0.49116028738873346, 0.23755011601107462, 2.624432099717004, 2.742337167263031, 51.80343062537057, 123.22209140232631, 96.39748682294572, 100.14534514290946, 91.37867791312081, 97.79114259992326, 89.34343242645264, 95.28966603960309, 92.57578304835728, 103.87945992606026, 92.24544484274728, 90.015670640128, 93.85368183680943, 92.35394096374512, 83.2299278804234, 83.89793464115688, 76.5094495500837, 76.33292361668178, 72.8081441606794, 77.63219506399972, 78.97906167166573, 77.52255943843296, 65.71424184526715, 65.29605756487165, 65.19791425977434, 67.5316960471017, 65.57526397705078, 69.80409744807652, 67.94006947108677, 67.08603164127895, 68.24212850843156, 64.67847388131278, 63.94332667759487, 64.73424012320382, 62.160182680402485, 63.419224057878765, 67.90693351200649, 70.95331559862409, 70.97437558855329, 73.70378085545131, 75.68095329829625, 75.25320134844098, 77.01555633544922, 78.80614185333252, 82.327607018607, 76.21318531036377, 89.7937729699271, 71.70622934613908, 50.89040953772408, 91.38553578513009, 73.27354839869908, 72.33355440412248, 68.22095734732491, 81.78700937543596, 76.33772482190813, 78.53846250261579, 70.01661505017961, 67.38746534075055, 63.1564918245588, 65.93208176749093, 63.37624250139509, 67.12455245426723, 64.86535957881382, 66.67312104361397, 63.50032343183245, 64.21862125396729, 62.27197224753243, 64.80636242457798, 59.85498578207833, 64.27262960161481, 62.64924553462437, 63.85736356462751, 63.07944325038365, 64.63781997135708, 61.618924958365305, 70.56530734470913, 70.95956202915737, 73.81498677389962, 76.1698910849435, 82.83067744118827, 84.20976284572056, 82.98403113228935, 79.33435780661446, 83.8554880959647, 71.50432859148297, 77.13860198429653, 80.24297373635429, 89.23886898585728, 78.37529795510429, 79.1305740901402, 10.61029269014086, 2.3462739970002855, 0.8015974408813885, 0.31854396419865744, 0.44936405015843256, 0.8548906669020653, 0.40648155978747774, 0.5918636779700006, 0.5724914489047868, 0.12027037276753358, 0.96529292847429, 30.148039136614116, 32.71795197895595, 92.12510204315186, 76.9488605771746, 39.96024349757603, 22.470347438539775, 75.34825270516532, 82.00247996194022, 80.98133100782121, 92.5753870010376, 65.19095911298479, 1.4678057581186295, 0.11277876940688916, 0.13028130201356752, 0.10295901740235941, 0.20174781286290713, 0.12942898060594285, 0.0921847837577973, 0.2430272235402039, 0.11322971699493271, 0.0976476895489863, 0.16433820953326567, 0.13478358542280539, 0.16227664372750691, 0.08370891106980187, 0.14068029900746687, 0.11735442280769348, 0.1265624687075615, 0.07345793649022068, 0.3372302215014185, 0.09234219709677355, 0.1060993792489171, 0.17776348628103733, 0.1441688375281436], [0.06861810226525579, 0.07373616977461747, 0.03483599125008498, 0.063753019752247, 0.022601794517998184, 0.01928918994963169, 0.040993367454835346, 0.026143884718684212, 0.03771062521263957, 0.012694177317566105, 0.05663894309795328, 0.03164014559505241, 0.04618269131918039, 0.06888329410659415, 0.03035566523405058, 0.04842678643763065, 0.08917660731822252, 0.0654484209205423, 1.1738646051713397, 33.090365001133506, 72.40154252733502, 72.55418055398124, 60.370701926095144, 36.51783493586949, 40.080325739724294, 59.26577854156494, 66.14855289459229, 76.77912998199463, 85.49656227656773, 35.38009173529488, 0.6106281567897115, 0.059444810929042954, 0.06442014859723193, 0.2733171081968716, 0.0850450008043221, 0.12173972677971635, 0.14531903580895492, 0.24160596409014293, 0.29108050359146936, 3.00964218378067, 15.329727172851562, 110.98166533878872, 88.91190760476249, 93.73946040017265, 83.23718874795097, 83.33562387738908, 76.00491305759975, 83.14520154680524, 77.49204295022147, 85.15013899121965, 85.92011056627545, 89.39653056008476, 86.14463465554374, 86.69224303109306, 86.9184763772147, 81.73544679369245, 73.00661250523159, 70.9133426121303, 65.1339282989502, 64.97971303122384, 64.76529857090541, 68.22901030949184, 61.42388207571847, 60.01550306592669, 58.03311252593994, 61.272751808166504, 57.40141357694353, 61.5175507409232, 63.503860064915244, 61.22720636640276, 61.7483560017177, 59.030985014779226, 59.81457505907331, 62.58628790719168, 63.03222329275948, 63.334803444998606, 63.66125760759626, 64.70287595476422, 64.49691050393241, 65.64211954389299, 65.18447644369942, 70.20628697531563, 68.10732650756836, 71.5367488861084, 67.19205420357841, 72.7727917262486, 69.82330226898193, 80.52994128635952, 61.554070472717285, 39.79900707517351, 82.00196579524449, 72.52585969652448, 65.23726885659354, 58.704079219273154, 68.768433707101, 68.73693752288818, 71.12031555175781, 67.94099358149937, 68.52252306256975, 63.40309034075056, 62.29622146061489, 55.95007038116455, 57.83568641117641, 55.97226292746407, 58.18694216864449, 58.58650180271694, 59.45786149161202, 53.983448777879985, 57.51531539644514, 55.91787937709263, 54.070985657828196, 54.487130641937256, 55.225779737745015, 54.243311405181885, 57.81748907906668, 54.75943749291556, 55.79848500660488, 58.79989487784249, 64.97816358293805, 68.99979482378278, 73.37649985722133, 71.99457263946533, 77.98012610844204, 76.52973134177071, 71.73125675746373, 65.76325443812779, 65.72725582122803, 72.63186141422817, 77.73526464189801, 78.20052296774728, 75.71182414463588, 59.06997830527169, 2.4329649337700436, 0.37541760238153593, 0.09756160381117038, 0.16231451955224785, 0.08746053797325917, 0.05087780759536794, 0.13994255502309116, 0.24384626959051403, 0.1989934899445091, 0.2590866817959717, 3.316588193178177, 26.33548961366926, 42.959489004952566, 51.98131145749773, 39.70531061717442, 23.96723781313215, 26.201670782906668, 47.686928680964876, 55.98209115437099, 63.49449389321463, 67.01384680611747, 10.600007619176592, 0.22301419957407884, 0.2743795040462698, 0.07645425213766949, 0.12617035689098494, 0.05575484250273023, 0.03277161630934902, 0.08623260672071151, 0.046044433023780584, 0.07056481923375811, 0.04320752900093794, 0.02741159508670015, 0.14716378253485474, 0.050420776940882206, 0.010336693908487047, 0.0698599231296352, 0.09284082534057753, 0.025314725103921125, 0.014441601765741195, 0.07762698456645012, 0.08927048263805253, 0.0415521003305912, 0.09074360251958881, 0.05362606101802417, 0.016965302505663464, 0.04986857157200575, 0.006038990503709231, 0.003946938119562609, 0.0287831942550838, 0.055223457980901, 0.0714344432843583, 0.03538890568805592, 0.028106207992615442, 0.04149417718872428, 0.04551776432033096, 0.014019063590759677, 0.04647862079686352, 0.031446057438318215, 0.05422487835000668, 0.055745122488588095, 0.09931678391460862, 1.402513970221792, 49.61189930779593, 92.4252850668771, 85.62389496394566, 70.74315343584333, 43.79264749799456, 44.725255557468955, 45.7720433643886, 54.097809178488596, 76.62616539001465, 102.10126304626465, 40.55522469111851, 0.5277661659887859, 0.12916014503155435, 0.24953201306717737, 0.4213765976684434, 0.1847719523523535, 0.2984806607876505, 0.1672282394553934, 0.4223061906439917, 0.7793663537928036, 2.637898142848696, 20.581745420183452, 117.8582627432687, 92.06807122911725, 96.78379276820591, 87.33618123190743, 86.46149335588727, 81.95150797707694, 85.25856563023159, 80.88559177943638, 89.7634857722691, 89.92262036459786, 92.18812915257045, 89.02940164293561, 88.70542103903634, 90.28056376320976, 85.9320684160505, 77.12181513650077, 73.60616561344692, 69.34330681392125, 68.44512013026646, 68.18502126421247, 71.26371942247663, 63.70546204703194, 62.69843878064837, 61.44173894609724, 64.12516103472028, 61.12961196899414, 64.46892316000802, 66.1972736631121, 65.77425343649728, 63.103796686444966, 62.00573812212263, 63.20323930467878, 63.91533933367048, 67.0783886228289, 67.94796957288469, 67.32315281459263, 68.64477661677769, 66.45542703356061, 69.92567702702114, 68.30632291521344, 73.91121237618583, 70.32068906511579, 75.24226488385881, 70.28452369144985, 76.50450243268693, 73.69772897447858, 84.0445555278233, 64.30147157396588, 44.169764450618196, 85.63524832044328, 76.24679374694824, 69.08185999734062, 62.65520708901541, 71.61784131186349, 71.48041984013149, 75.77859633309501, 71.41965784345354, 73.20625509534563, 67.3559205191476, 66.00186252593994, 58.42891665867397, 60.41690049852644, 57.76373086656843, 61.49496214730399, 60.141084807259695, 61.109969411577495, 56.92049748556954, 59.427525656563894, 58.72744601113455, 58.44378580365862, 56.943697520664756, 58.200237546648296, 57.171188490731375, 61.12023190089634, 59.26890523093087, 58.889088903154644, 62.298681122916086, 68.15255233219692, 71.98369176047188, 77.0430086680821, 74.92350237710136, 80.31730556488037, 77.40648978097099, 74.39650235857282, 68.2382583618164, 69.26331220354352, 75.71218545096261, 80.9922605242048, 80.04637445722307, 77.09936550685337, 68.77165767124721, 5.37063615662711, 0.3461250013538769, 0.11342213595552103, 0.33662260696291924, 0.10038384129958493, 0.18660320980208261, 0.20464249753526279, 0.4302940405905247, 0.09907553757407836, 0.3709870944065707, 2.957422128745488, 28.975871086120605, 39.4416994367327, 32.1416232245309, 34.78243548529488, 27.09069105557033, 45.11961793899536, 56.79464129039219, 65.66796684265137, 69.73642894199916, 85.66108172280448, 21.367138522011892, 0.5548212027975491, 0.28176096081733704, 0.030248826502689292, 0.15129323809274606, 0.062158889935484955, 0.05007539243836488, 0.1118857901809471, 0.014333758802552308, 0.09770158558551754, 0.01019405566954187, 0.024529719459159032, 0.0695178396999836, 0.03065852594694921, 0.019044740923813412, 0.04117843109582152, 0.06676010375044175, 0.05087120884231158, 0.017802735158641423, 0.09750325658491679, 0.0859248571630035, 0.052301842253655195, 0.04906035154791815, 0.10190718634320156, 0.11405766542468752, 0.11343922825264079, 0.12474924671862807, 0.13592953607439995, 0.07528355531394482, 0.10642019060573407, 0.13785721335027898, 0.1486465036869049, 0.1261891115989004, 0.15017897502652236, 0.10713331733963319, 0.18853258341550827, 0.16965744910495623, 0.1375995193208967, 0.08479661627539567, 0.20268402834023747, 0.1896945067814418, 1.6232227385044098, 70.38128430502755, 114.6087292262486, 100.04959201812744, 92.82687704903739, 56.786831515175955, 59.69209916251046, 80.42018754141671, 88.45453548431396, 95.63376862662179, 104.76960059574672, 55.5550548689706, 1.0613131246396472, 0.39031546296817915, 0.6726161305393491, 0.6693684990916933, 0.36590736412576264, 0.6230438819953373, 0.6035531535744667, 0.6089757883122989, 2.143771137510027, 4.335954282964979, 22.87094235420227, 127.77606582641602, 95.31870256151471, 102.6160203388759, 91.676602772304, 90.68483080182756, 85.64441994258335, 90.7524367741176, 83.4636583328247, 95.29962975638253, 93.71498884473527, 96.63240541730607, 90.67898736681256, 91.0499655859811, 92.93785367693219, 90.38268838609967, 81.85890238625663, 77.37739767347063, 70.80683367592948, 72.74322714124406, 71.71811771392822, 76.3094595500401, 66.1597603389195, 66.06001894814628, 63.46463748386928, 68.7623679297311, 63.97460051945278, 66.57758331298828, 71.27097334180559, 69.05687427520752, 67.13361985342843, 65.57376316615513, 66.11982209341866, 68.12801129477364, 72.20672198704311, 69.87259973798479, 71.21021134512765, 73.01587445395333, 72.14174938201904, 74.03998334067208, 72.16772174835205, 77.73195035117013, 73.93922056470598, 78.01664584023612, 74.3494769505092, 77.81286212376186, 79.06061962672642, 86.60099233899797, 67.33406148638043, 48.274534361703054, 88.2694285256522, 81.34556947435651, 70.68285696847099, 65.09735992976597, 76.6864549091884, 75.72831221989223, 79.86978599003383, 76.01953206743512, 75.87610735212053, 71.20876611982072, 69.59611701965332, 62.576456206185476, 63.34192534855434, 62.43347617558071, 63.20672730037144, 65.37245300837925, 65.36049515860421, 60.71198354448591, 62.02828502655029, 62.954535484313965, 61.32953943525042, 61.48111438751221, 61.82026290893555, 61.46594646998814, 67.45389011928013, 61.990459033421104, 61.48842389242989, 65.5264459337507, 71.56789071219308, 77.37874562399728, 80.40855625697544, 78.72674478803361, 83.3897294998169, 81.47138745444161, 80.05730397360665, 72.30799892970494, 72.86870465959821, 79.55005073547363, 85.25345870426723, 83.25091144016811, 83.37558991568429, 70.09262139456612, 4.114282429218292, 0.7588949522801808, 0.4436780624091625, 0.7706279626914433, 0.3504588045179844, 0.3039771744183132, 0.4064692375915391, 0.7185796041573796, 0.5058504076940673, 0.6354839258960315, 5.874224654265812, 41.66115556444441, 57.046093123299734, 66.63531589508057, 53.434860706329346, 33.414352553231375, 42.2382937840053, 66.33858612605503, 77.79012761797223, 83.71326541900635, 98.84169633047921, 25.395320177078247, 0.6899626883012908, 0.5083083329456193, 0.331888278148004, 0.27231572621635025, 0.23435893867697033, 0.12072883173823357, 0.1583610624074936, 0.11750656392957483, 0.1476056852510997, 0.13388657569885254, 0.1998051128217152, 0.2317702461566244, 0.12054129822977952, 0.10919824867908444, 0.17438678390213422, 0.15238728081541403, 0.09877944524799075, 0.09678983808095966, 0.19771403074264526, 0.22150509698050364, 0.11537187919020653, 0.20859085209667683], [0.009318188248601342, 0.033114829499806674, 0.024125283750306283, 0.04763440342087831, 0.0487327989456909, 0.056757496736411533, 0.01789106515103153, 0.07831732609442302, 0.016487391632316366, 0.018374979362956116, 0.09567698636757475, 0.03658964804240635, 0.050577525315540175, 0.023855377786925862, 0.008946262000660812, 0.04080129115443144, 0.06156141949551446, 0.24875441193580627, 2.747586965560913, 36.17720644814627, 77.11590221949986, 58.197447844914024, 49.38982793263027, 33.487739426749094, 41.290816579546245, 77.1339327948434, 96.29846109662736, 57.41007798058646, 57.826566900525776, 5.229186032499586, 0.3435498523925032, 0.07517051137983799, 0.19150220549532346, 0.22433743785534585, 0.17746114464742796, 0.20245552488735744, 0.08187987242958375, 0.18179506994783878, 0.7687802304114614, 3.352371198790414, 69.39470263889858, 84.70789309910366, 95.63941056387765, 86.92963518415178, 82.69784178052629, 80.24100044795445, 75.68977751050676, 75.00176688602993, 75.08714635031563, 75.336044720241, 81.5009103502546, 88.43476091112409, 84.4871905190604, 87.0509924207415, 82.64214502062116, 78.88563619341168, 70.75383281707764, 65.25802312578473, 64.34500898633684, 62.50938524518694, 62.606965746198384, 59.11296680995396, 57.85747248785836, 57.646546023232595, 59.423488753182546, 55.32718869618007, 54.49082360948835, 62.53550352369036, 58.80732945033482, 61.2620724269322, 59.84677301134382, 60.07924583980015, 61.25267846243722, 62.99689865112305, 66.48362282344273, 65.1693571635655, 60.47033909388951, 64.45815345219204, 61.63692079271589, 62.47745132446289, 64.01559489113944, 67.15937682560512, 67.449526650565, 68.92416368212018, 69.77522768293107, 73.48480142865861, 68.24768706730434, 81.75228922707694, 61.99771990094866, 39.76848016466413, 77.35255091530937, 68.5404702595302, 64.99563135419572, 54.50754792349679, 66.27756704602922, 64.06061921800885, 68.8610531943185, 66.2419297354562, 70.51218141828264, 68.01531846182687, 68.93850476401192, 61.210787773132324, 57.47255965641567, 55.20090171269008, 55.461990697043284, 57.77303450448172, 58.57168129512242, 53.88285623277937, 53.785140241895405, 53.331252643040244, 54.46596295492989, 55.4157052721296, 54.51351295198713, 54.08947481427874, 55.14329767227173, 54.28666121619088, 57.09338256290981, 57.548215116773335, 63.26496710096087, 71.1092609677996, 70.61840547834123, 76.15968418121338, 75.5700808933803, 70.71716022491455, 70.89122649601528, 66.45518384660993, 61.97158772604806, 69.31381171090263, 74.75834369659424, 78.3661332811628, 71.82568972451347, 76.51911449432373, 42.512685094560894, 0.3209028776202883, 0.14338751802487032, 0.05794503819197416, 0.046360460708716085, 0.03019198223150202, 0.05406760071803417, 0.07462870795279741, 0.04739547088476164, 0.07002532282578093, 0.12274625205567904, 7.200865055833544, 35.226873534066335, 70.07546629224504, 49.48505299431937, 33.494753633226665, 15.378545216151647, 27.608747005462646, 44.88088478360857, 52.0406699180603, 67.31714262281145, 35.52971771785191, 0.3433464547353131, 0.07172026259026357, 0.01525117885986609, 0.02667640409033213, 0.09571814630180597, 0.05862625342394624, 0.007220541343225965, 0.017310631029041748, 0.050676245375403335, 0.1145789838795151, 0.02601588417642883, 0.029737852314221006, 0.035003117817853174, 0.06393433787993022, 0.024312759583283747, 0.04137929442471691, 0.05007387251992311, 0.05155253603256174, 0.05836459675005504, 0.06470273129109826, 0.03489790078518646, 0.07120241823473147, 0.037240610790572, 0.05859111209533044, 0.028686499622251307, 0.0680271525468145, 0.013465080460134362, 0.047015545557120016, 0.02627118636987039, 0.026095011537628512, 0.035944914245711904, 0.01761669951624104, 0.0878473911434412, 0.015306935778685977, 0.025252320238256028, 0.02502791174421353, 0.011391014342994561, 0.07678444763379437, 0.03971096341099058, 0.2524676269718579, 3.900110287325723, 59.02774715423584, 93.85976845877511, 76.95309897831508, 61.33505630493164, 39.7117793900626, 48.00990179606846, 58.25545835494995, 90.31997394561768, 63.36090782710484, 64.55631065368652, 6.02401522227696, 0.390258221754006, 0.2732206205172198, 0.37078022265008515, 0.32008510721581324, 0.6867487664733614, 0.07155328869287457, 0.12381894806666033, 0.06820477944399629, 0.8534838738186019, 5.236924588680267, 85.42027105603898, 91.12348447527204, 98.80537114824567, 89.73396982465471, 86.19060393742153, 82.8228120803833, 77.32838508061, 77.81602355412075, 77.52995926993233, 78.51519993373326, 85.8453618458339, 89.38438510894775, 87.32285458700997, 90.46776212964738, 87.11629853929792, 81.77541978018624, 73.8409035546439, 69.79720483507428, 67.85279314858573, 66.02204009464809, 65.33127798352922, 63.984216826302664, 60.73078536987305, 59.99256706237793, 61.16685431344168, 58.0821008001055, 57.96401616505214, 66.63048689705985, 65.01985972268241, 64.48045716966901, 61.73082569667271, 63.85112408229283, 64.30880192347935, 65.99237128666469, 68.30202198028564, 66.89751311710903, 63.72887747628348, 67.72919164385114, 65.81655406951904, 66.85743590763637, 66.41378647940499, 70.56200695037842, 69.27790342058454, 72.08068861280168, 72.28761291503906, 77.68432739802769, 71.31420503343854, 84.32137870788574, 63.03940078190395, 41.09165688923427, 78.6731185913086, 73.01063551221574, 67.10479872567313, 57.54491124834333, 67.7332215990339, 65.62943213326591, 71.9532447542463, 70.27899987357003, 73.16037614004952, 72.90366104670933, 73.60615171704973, 65.08664580753872, 60.33849007742745, 57.495287214006694, 58.3494987487793, 61.157905033656526, 60.514981269836426, 58.761381013052805, 57.89678539548601, 56.81219938823155, 57.263328552246094, 58.9814304624285, 57.620844636644634, 58.38816547393799, 57.29572452817644, 57.78459283283779, 59.84985801151821, 60.323787689208984, 68.69966738564628, 74.15935339246477, 75.21972492762974, 78.17571789877755, 75.8226409639631, 75.23093932015556, 74.87783881596157, 68.65734590802873, 65.86733150482178, 72.18773256029401, 76.20666790008545, 81.59623963492257, 77.00976848602295, 79.37073857443673, 53.70395054136004, 1.0310741301093782, 0.16710112270499977, 0.16449850664607116, 0.09433280849563223, 0.11454633277441774, 0.47458166841949734, 0.06587789287524563, 0.14391820026295526, 0.06125041296971696, 0.2984446441488606, 7.0576010176113675, 38.15536206109183, 47.35685798100063, 24.92737810952323, 30.596527985164098, 26.317448616027832, 40.22771440233503, 53.9877427646092, 60.186310631888254, 75.32042516980852, 55.00429548536028, 0.47874901337283, 0.04457840383318918, 0.017609783548063467, 0.00943558752935912, 0.026792799987431084, 0.09346709280673947, 0.02812116968977664, 0.0034477420267648995, 0.04164954813729439, 0.031376487242856195, 0.018868878217680112, 0.054312331335885186, 0.020054463796051483, 0.07593587852482285, 0.05243172403424978, 0.026020494821880544, 0.06307930911758117, 0.049313882764961035, 0.039855454050536664, 0.029962532222270966, 0.03609216991545899, 0.03261121063094054, 0.12332000769674778, 0.07934918786798205, 0.11802295622016702, 0.12071652311299529, 0.06191147571163518, 0.2039417065680027, 0.13469627153660568, 0.23871334216424397, 0.09019325633666345, 0.14424870109983853, 0.23219408627067292, 0.17248622088560037, 0.21431650700313704, 0.1160777998822076, 0.1482921727001667, 0.1367050473179136, 0.15966591238975525, 0.308966550976038, 5.179389161723001, 81.15403543199811, 115.324435370309, 90.26037229810441, 75.52214527130127, 47.734641960689, 57.52437237330845, 98.90825312478202, 119.73907061985561, 76.24217319488525, 85.96697616577148, 8.871208088738577, 0.4093196546392781, 1.0729324668645859, 0.5860987901687622, 0.7313013757978166, 0.7559473961591721, 0.4544190817645618, 0.34784625470638275, 0.6567783632448742, 1.532515960080283, 5.299569981438773, 91.40975025721959, 95.71281828199113, 103.66572638920375, 95.98941217150006, 88.23329789297921, 89.06289890834263, 80.59918008531842, 83.32830047607422, 81.1780275617327, 82.47197668892997, 87.92754936218262, 96.54764434269497, 91.86156381879533, 96.51009627750942, 89.8807852608817, 86.68501690455845, 78.5735786982945, 72.95824609483991, 74.03261130196708, 70.48558371407645, 70.1838026046753, 66.88614586421421, 63.173160552978516, 64.35847459520612, 64.98279803139823, 63.10256685529436, 61.07632623400007, 68.47758211408342, 67.18124280657086, 66.51150594438825, 63.47688020978655, 67.29837553841728, 66.92991256713867, 69.18446404593331, 73.61268302372524, 73.41799449920654, 68.22659233638218, 74.18145561218262, 70.78325148991176, 70.47441795894078, 70.87571811676025, 76.72220339093889, 72.48184285845075, 76.37265341622489, 77.16669355119977, 81.90439224243164, 74.87487888336182, 87.54280676160539, 66.91978209359306, 47.47422347749983, 80.42028481619698, 76.5958503995623, 68.56250994546073, 61.88691002982003, 72.03615760803223, 71.6451894215175, 76.79224818093437, 75.80507591792515, 76.62995215824672, 77.28131103515625, 76.50878947121757, 69.03672449929374, 62.90847587585449, 61.5702736718314, 60.621045521327424, 65.49551255362374, 64.47422463553292, 61.71469892774309, 60.827219418116975, 59.933111327035085, 61.15788418906075, 62.283353396824424, 62.35440567561558, 63.370628356933594, 60.92022105625698, 60.998235430036274, 63.80422374180385, 64.26984337397984, 71.25529820578438, 79.4832090650286, 77.87838363647461, 81.99806090763637, 78.37784099578857, 78.66586467197963, 76.59755270821708, 72.34710339137486, 67.24348476954869, 76.51430634089878, 80.28975595746721, 86.54989528656006, 78.35351535252163, 83.52176611764091, 52.13533564976284, 1.0455136810030257, 0.36738388346774237, 0.25821701703327044, 0.23160500930888311, 0.23874903310622486, 0.4997039660811424, 0.34308188036084175, 0.23801827803254128, 0.20482205147189753, 0.3579565893326487, 12.148459706987653, 54.12492452348982, 92.86271585736955, 68.18295070103237, 46.50057935714722, 25.067196709769114, 44.389167717524934, 63.86033044542585, 72.61588055746896, 90.81693690163749, 62.93045997619629, 0.5652833442602838, 0.14278643099325045, 0.12646121771207877, 0.1107145030317562, 0.15927728824317455, 0.20146988491926873, 0.1961813694132226, 0.11090533422040087, 0.1941619406321219, 0.11565775956426348, 0.09016162303409406, 0.1348686194313424, 0.15803441564951623, 0.13220607515956673, 0.19698881251471384, 0.1490495263465813, 0.11931370624474116, 0.13765309644596918, 0.14451832377484866, 0.07143128809652158, 0.09655995720199176, 0.12465832302612917], [0.007536587687874479, 0.09323105082980224, 0.01970201913666512, 0.03197025627429996, 0.05957281656031098, 0.038655665037887435, 0.03408849671749132, 0.060052880086004734, 0.034011676375355036, 0.01665753428824246, 0.0353402208004679, 0.05564172053709626, 0.017214960984087417, 0.03715077953945313, 0.10276835584746939, 0.08385547463382993, 0.19699918052979878, 0.4185817933508328, 10.154105237552098, 51.64926746913365, 69.29241125924247, 64.82293387821743, 83.19520078386579, 53.45253692354475, 44.487432616097585, 68.79529544285366, 66.9208173751831, 89.77948747362409, 16.640457936695643, 0.10344972035714559, 0.12260067915277821, 0.11031840821462018, 0.1335850754486663, 0.19659170668040002, 0.1501256286033562, 0.10217298208070652, 0.11007228320730583, 0.24528327105300768, 0.20607853547802993, 59.1610483442034, 106.83668967655727, 93.10953671591622, 88.32773086002895, 82.56618036542619, 81.41027109963554, 69.19934013911656, 67.12239851270402, 70.37804644448417, 67.93549755641392, 67.76327950613839, 70.40950788770402, 79.5731395993914, 84.49378435952323, 83.78583240509033, 82.35960347311837, 72.85411344255719, 63.85938549041748, 60.25067179543631, 59.499224117824006, 57.86299630573818, 56.3157262802124, 58.984550203595845, 59.48678684234619, 57.278360979897634, 55.54494176592146, 53.1364494732448, 59.792959213256836, 63.94354207175118, 61.068981988089426, 60.58283042907715, 56.10804115022932, 59.174729347229004, 63.22083214351109, 63.82899406978062, 61.29356166294643, 63.7789739881243, 60.724643162318635, 60.67635318211147, 61.13466330936977, 60.263949802943635, 57.36169767379761, 62.01762648991176, 66.37437629699707, 70.69434234074184, 68.51952838897705, 74.31882149832589, 69.0855494907924, 78.31268773760114, 59.4021577835083, 37.279242856161936, 78.294344493321, 69.54108033861432, 66.83694566999162, 54.46968718937465, 57.40757315499442, 54.077002797807964, 59.373176847185405, 61.686530930655344, 64.50307355608258, 66.19825335911342, 66.06611946650914, 64.30156884874616, 63.22302777426583, 58.99867589133126, 55.486583845955984, 56.720219135284424, 60.415705408368794, 55.21427352087838, 51.993130343300955, 51.84486273356846, 55.070921761649, 54.765670027051655, 53.741269315992085, 54.04990482330322, 55.14480890546526, 53.980120590754915, 55.60088866097586, 58.808434213910786, 67.49215384892055, 71.33493845803397, 77.1469259262085, 72.88074588775635, 68.40911456516811, 73.77427727835519, 71.64211136954171, 67.01715414864677, 63.69824981689453, 63.73219871520996, 74.12722492218018, 75.36606788635254, 76.72456577845982, 69.65630231584821, 73.86402021135602, 17.881909949438914, 0.3938383353607995, 0.3203898508633886, 0.07881467869239193, 0.1420182886400393, 0.08275881276598998, 0.03064411725582821, 0.1585008813334363, 0.19953053684106895, 0.09314091423792498, 0.09232517943850585, 14.34283631188529, 25.895696435655864, 67.86429936545235, 45.39487430027553, 27.41234401294163, 22.92720886639186, 46.03623471941267, 59.17971815381731, 57.34790897369385, 66.70030239650181, 9.367566551480975, 0.32879662833043505, 0.20613413463745797, 0.0386228001942592, 0.033977403571563106, 0.02682027726301125, 0.020766447198444178, 0.027480103374857987, 0.001500779831465999, 0.060869015221084864, 0.038160697490509064, 0.03576570296926158, 0.0528844968814935, 0.03165975525709135, 0.07917346086885248, 0.011988942794102644, 0.05238935970036047, 0.07029512191989593, 0.02176061295904219, 0.029690656810998917, 0.03163373004645109, 0.0516903668508998, 0.03513692492353065, 0.027077296150049994, 0.023394674561651688, 0.09522179793566465, 0.06103944286171879, 0.057718326071543355, 0.02940999097856028, 0.04899141239002347, 0.009925788368231483, 0.033433629000293355, 0.023101360836465443, 0.07650723893727575, 0.075569517112204, 0.04548521838816149, 0.04973752949652927, 0.05784859800977366, 0.08059014020753758, 0.4018051235803536, 16.903758185250418, 76.83888448987688, 83.2820463180542, 75.4744736807687, 86.15438992636544, 59.2092410496303, 41.79491880961827, 68.60046100616455, 74.57123565673828, 91.89401190621513, 20.514778682163783, 0.0909730830628957, 0.06018240563571453, 0.10131631804896252, 0.15659950407488005, 0.3411198556423187, 0.18598800924207481, 0.16230442295117037, 0.08445388145212616, 0.17128351756504603, 0.28731322288513184, 68.3550089427403, 109.90147754124233, 98.17635767800468, 90.7293062210083, 86.29843997955322, 83.73433235713414, 72.1476970400129, 71.40818636757987, 73.28015613555908, 71.63928345271519, 72.58419677189418, 72.68098517826625, 82.66385814121791, 85.96776131221226, 85.30141517094204, 83.07441329956055, 75.30406216212681, 68.00759206499372, 64.0000170298985, 63.2035311290196, 61.328226225716726, 60.86653927394322, 63.39065306527274, 61.467655726841514, 61.356178828648154, 59.339012554713655, 57.08215079988752, 62.664642742701936, 66.70711163112095, 63.033390590122764, 62.28420107705252, 58.15013756070818, 62.96078886304583, 66.79060813358852, 68.27309662955147, 65.90771443503243, 69.1712555204119, 64.47660091945103, 64.04108783176967, 61.633321625845774, 63.59948812212263, 61.515841484069824, 64.70719078608921, 69.87922831944057, 74.29282828739711, 71.99594838278634, 78.16393375396729, 71.92478493281773, 81.47807162148612, 61.394039562770296, 40.4428653717041, 80.46636526925224, 73.65565068381173, 69.64322580610002, 58.80094405582973, 60.584199224199565, 57.721989563533235, 61.92149816240583, 62.90657901763916, 66.61861242566789, 66.8676289149693, 69.45667362213135, 67.26152229309082, 67.86755807059151, 59.99879959651402, 57.761736733572825, 59.846314430236816, 60.868415287562776, 59.87458665030343, 54.54990414210728, 55.7178442137582, 58.32768835340227, 57.47536325454712, 57.448261805943076, 58.17869813101632, 59.11253602164132, 56.49253708975655, 57.955237116132466, 59.58024706159319, 70.5838451385498, 74.7569054194859, 78.26665592193604, 73.63105406079973, 72.30032811846051, 76.70884200504848, 73.96506786346436, 70.46565628051758, 66.81611497061593, 66.16135147639683, 77.00349426269531, 75.27388613564628, 79.65121650695801, 72.69111565181187, 77.0579195022583, 26.245651142937795, 0.24914543809635298, 0.34210137011749403, 0.46539826691150665, 0.2067022312964712, 0.13890435573245796, 0.1724119484424591, 0.15752527011292322, 0.5186274935092244, 0.027859870943107774, 0.17715030775538512, 16.419166496821813, 28.3477817262922, 43.37166656766619, 33.46615137372698, 30.87670019694737, 33.25853572572981, 50.72196783338274, 68.79219654628209, 63.864534105573384, 83.8416472843715, 20.078317165374756, 0.49996761764798847, 0.2718504140419619, 0.011290020342650158, 0.015797533560544252, 0.04547251621261239, 0.008172084078458803, 0.010998709992106472, 0.02723371034621128, 0.14960152815495217, 0.023864814512697712, 0.03537780485515084, 0.06867028160818986, 0.06939617837113993, 0.023964857715847235, 0.023751823165054833, 0.03759724201102342, 0.04496261750214866, 0.08863185904920101, 0.04358591405408723, 0.017297423344903758, 0.0645184140386326, 0.11086977220007352, 0.17123042898518698, 0.1414469757250377, 0.13045568551336015, 0.1333902951862131, 0.17858298016445978, 0.09681900151606117, 0.1859272260751043, 0.12133287718253476, 0.11136050229626042, 0.09946707263588905, 0.17125947028398514, 0.19705116988292762, 0.1543548966624907, 0.10385201019900185, 0.12174535862037114, 0.37163286975451876, 0.4376015370445592, 25.235072135925293, 101.85519259316581, 98.59436130523682, 92.44286400931222, 101.42739200592041, 71.14342526027134, 62.88059970310756, 93.57754652840751, 81.60273620060512, 109.81297138759068, 26.10529579435076, 0.3242173311965806, 0.18690141237207822, 0.2887838254017489, 0.4088571923119681, 0.8502915565456662, 0.37862587879811016, 0.5292240391884531, 0.19409548491239548, 0.6842418238520622, 0.5005325930459159, 73.08682945796421, 109.9768932887486, 101.537930897304, 94.32962649209159, 90.90891020638603, 90.60772664206368, 76.22317681993756, 75.2940776007516, 78.878326688494, 75.0390578678676, 76.94758905683244, 77.53268296377999, 88.36513301304409, 92.22854682377407, 87.96824496132987, 87.38428361075265, 80.65717669895717, 72.26148074013847, 67.39244719914028, 66.20343671526227, 66.21731921604702, 64.79104164668492, 67.47131620134626, 65.1608942576817, 63.88044548034668, 64.53115122658866, 60.1503050667899, 65.34692532675606, 71.09405136108398, 66.38939830235073, 67.27736418587821, 61.01118687220982, 64.86941037859235, 69.56118147713798, 73.42389351981026, 68.66292531149728, 72.20747239249093, 67.54974051884243, 67.79358060019356, 67.03267642429897, 67.73611899784633, 63.911740166800364, 67.74356051853725, 74.38559368678501, 78.35139615195138, 75.62367234911237, 81.64370277949742, 77.6980014528547, 84.92663628714425, 64.69757447923932, 44.1819029535566, 86.26788180215019, 76.23747621263776, 71.91579396384103, 61.99222387586321, 64.61006886618478, 62.04909488133022, 66.58497619628906, 68.37536021641323, 71.64066614423479, 72.197279385158, 72.95652294158936, 71.51762049538749, 70.25732844216483, 63.93080602373396, 60.05627509525844, 62.65513065883091, 65.3018523624965, 61.46190956660679, 56.91265296936035, 58.34425285884312, 62.239545004708425, 61.16558974129813, 59.902942248753135, 61.0311073575701, 62.813396726335796, 60.74996239798409, 62.54058265686035, 64.80668204171317, 74.34588473183769, 80.10619149889264, 83.4765680858067, 78.21430819375175, 75.50669942583356, 80.84210995265416, 77.75618566785539, 74.94445814405168, 70.69220924377441, 69.0118499483381, 80.42559323992047, 80.86235700334821, 83.54001903533936, 78.15003735678536, 82.7132181440081, 23.845548800059728, 0.47003211826086044, 0.6058357996600015, 0.3714018964341709, 0.3729234162185873, 0.30202747189572876, 0.4241306356021336, 0.33832290715404917, 0.739355206489563, 0.1924250538327864, 0.5085935890674591, 24.323730775288173, 41.061369691576274, 89.86039924621582, 62.814835003444124, 38.64478274754116, 36.28178031103951, 63.3467196055821, 81.10315377371651, 72.8226797921317, 98.57146004268101, 20.692932231085642, 0.540974420096193, 0.3894064431743962, 0.13312720001808234, 0.10721558292529412, 0.16768205724656582, 0.15328424982726574, 0.11290198458092553, 0.17013354998614105, 0.2764224644218172, 0.09546524951500551, 0.12922987129007066, 0.12896393984556198, 0.1523178666830063, 0.17255334156964505, 0.14883696846663952, 0.16821325517126492, 0.08316929931087153, 0.11228782217949629, 0.1027985777972, 0.11465477624109813, 0.13824062634791645], [0.10463166050612926, 0.024398594263142774, 0.03754893031769565, 0.0629526266295995, 0.12475885477449213, 0.008542140114254184, 0.045213906160954914, 0.03548515248777611, 0.025564680441415737, 0.012464718826647316, 0.05501581608716931, 0.07410198835922138, 0.04095414473808237, 0.043076907617173026, 0.01634091288516564, 0.1391044557094574, 0.0715749611013702, 0.6328590267470905, 27.694187266486033, 56.11072315488543, 59.02690642220633, 66.37154143197196, 59.290006910051616, 31.72452286311558, 46.04452739443098, 69.07099996294293, 83.56904860905239, 50.60757269178118, 2.1249328340802873, 0.03764353506267071, 0.07746298943779298, 0.02937963671450104, 0.09684925060719252, 0.10687218992305653, 0.2382278639291014, 0.04838265112734266, 0.13729130157402583, 0.24631730413862638, 40.565306527274, 108.48822089603969, 85.57379845210484, 90.01093891688755, 82.07096835545131, 85.06844902038574, 73.14088644300188, 69.25386960165841, 65.86913108825684, 63.970341273716514, 63.70184203556606, 64.48788479396275, 60.323488916669575, 63.51859024592808, 66.93844495500836, 70.80877222333635, 65.48157446725028, 59.639404024396626, 58.133187430245535, 58.62231281825474, 59.227973393031526, 59.66432721274239, 59.42815794263567, 56.80561597006661, 58.64327553340367, 57.56812865393502, 50.85120780127389, 59.645045961652485, 61.27797685350691, 63.21145902361189, 58.964004380362375, 57.43992049353463, 54.838052885872976, 61.80925696236746, 62.52535915374756, 62.07023824964251, 59.3898594720023, 60.344145911080496, 57.14396892275129, 55.480566705976216, 55.30874817711966, 57.16383382252285, 55.34924922670637, 63.69560950142996, 63.76813479832241, 66.70110143933977, 68.10993208203996, 71.15670326777867, 68.02762372153146, 74.7422377722604, 60.58722169058663, 41.726555483681814, 76.66646494184221, 69.80832195281982, 65.84910637991769, 53.74949598312378, 56.15705026899065, 50.71317488806588, 51.11679574421474, 53.86033364704677, 54.08784893580845, 56.03947980063302, 62.29747213636126, 61.91599518912179, 64.56691360473633, 56.040327480861116, 53.839537688664024, 52.83567932673863, 57.615442412240164, 57.480463232312886, 53.45039687837873, 50.23491995675223, 53.930249895368306, 54.519029821668354, 52.78358173370361, 54.37730394090925, 53.994357449667795, 52.44818523951939, 52.69828217370169, 56.8216906275068, 67.3699072429112, 69.3976139341082, 71.61117104121617, 68.62150709969657, 70.06782327379499, 73.29745715005058, 70.32729680197579, 65.67222608838762, 62.87386689867292, 59.630955014910015, 68.02846445356096, 72.88558183397565, 73.21819904872349, 75.15244552067348, 71.23379353114537, 59.45829227992466, 4.428300184862954, 1.2681985603911536, 0.29410424562437193, 0.2858418604092938, 0.16091763308005674, 0.13733271935156413, 0.09761616481201989, 0.20398454926908016, 0.17626078905803816, 0.15608445528362477, 3.069551940475191, 21.29922161783491, 39.66583095278059, 59.59037058694022, 34.70039810453142, 30.571778501783097, 42.635192258017405, 49.536407130105154, 60.9222777230399, 65.83212498256138, 41.724179199763704, 0.5136881928358759, 0.02418103558011353, 0.032464952407670875, 0.05386361612805298, 0.04253285484654563, 0.05717682119991098, 0.036559293778347116, 0.023895504651591182, 0.015892329991662076, 0.039196033363363574, 0.06783960546766009, 0.017812523026285425, 0.0423785424126046, 0.0447674606527601, 0.042758423635470014, 0.04133080970495939, 0.06483438744076661, 0.05517226590641907, 0.021080990588026385, 0.06774146216256277, 0.0572186800252114, 0.06444407374198947, 0.031497018810893805, 0.06782731719847236, 0.036008934024721384, 0.049962697949792655, 0.04019285898123469, 0.04323669243603945, 0.029338924613382136, 0.013877772243826516, 0.02728037489578128, 0.026828801359183023, 0.03217755550784724, 0.05800668988376856, 0.044746951931821446, 0.024292162652792673, 0.058393088435488086, 0.06378331634082965, 0.8088601540241922, 43.89238888876778, 76.0404530933925, 75.13044752393449, 80.74236161368233, 68.12794876098633, 51.87422929491316, 51.17626537595476, 69.14551939283098, 93.68188067844936, 58.759845461164204, 2.4351434111595154, 0.2287475626383509, 0.223209196967738, 0.23630310435380253, 0.12526403766657623, 0.1278586605829852, 0.32065141254237717, 0.07412304330085005, 0.0677134318809424, 0.2978982606104442, 50.28564180646624, 111.45187773023332, 90.91596957615444, 94.94691140311105, 86.52892562321254, 89.07574612753731, 77.7667121887207, 72.93956238882882, 69.15479523794991, 69.15266908918107, 66.1159519468035, 66.56736946105957, 64.32565130506242, 64.89934321812221, 67.18941388811383, 72.77523749215263, 67.55674430302211, 62.529118129185264, 59.89588287898472, 63.18528515951974, 61.99819237845284, 61.02045576913016, 60.372390338352744, 60.595851353236604, 62.567486081804546, 59.692627225603374, 53.64034673145839, 61.73102024623326, 65.6107484272548, 65.26750741686139, 62.662377629961284, 61.27321038927351, 58.2912381035941, 64.81736837114606, 65.58974402291435, 65.35764639718192, 61.40983976636614, 63.35682923453194, 58.736443928309846, 59.1545934677124, 58.33055101122175, 59.219190870012554, 59.826977593558176, 65.35547161102295, 66.47250570569719, 68.71218803950718, 70.89593042646135, 73.92823546273368, 70.2199193409511, 78.32381875174386, 62.60010092599051, 46.04670565468924, 78.34282902308873, 72.40733732495988, 67.88297612326485, 55.556232588631765, 58.502727372305735, 53.312791279384065, 53.83092539651053, 56.648385184151785, 56.30072511945452, 58.86891828264509, 64.58524295261928, 65.7265818459647, 66.70289407457624, 59.59533160073416, 56.40650449480329, 56.83404105050223, 58.87526198795864, 60.11821828569685, 57.391380378178184, 53.192191396440776, 57.73403773988996, 56.68932397024972, 55.70935351508004, 55.89599255153111, 56.56822034290859, 55.331295081547324, 56.27317203794207, 59.08384690965925, 70.09065505436489, 72.99956703186035, 74.68841702597481, 74.47580909729004, 74.76193591526577, 76.33559172494071, 72.79531778608049, 68.55941799708775, 64.34455040522984, 63.187341826302664, 69.85610471452985, 76.8161152430943, 77.1925825391497, 78.3406125477382, 74.787581716265, 68.15343475341797, 8.209666626793997, 0.7125117097582135, 0.3847128807434014, 0.806046513574464, 0.5306276295866285, 0.11313510207193238, 0.05419803889734404, 0.34438667606030193, 0.10439996115331139, 0.5223176926374435, 2.609695621899196, 24.81190426009042, 40.07766110556466, 33.56414181845528, 29.4170469556536, 39.80089351109096, 50.289678709847585, 58.65466363089425, 68.26527990613664, 73.96594333648682, 58.59983539581299, 1.5633333921432495, 0.08784270925181252, 0.013072729459963739, 0.032184093192751916, 0.03322861982243402, 0.019256635535774485, 0.00323338814944561, 0.014637815433421304, 0.06149629370442458, 0.04052294251908149, 0.01085018037286188, 0.05155665474012494, 0.026849070896527598, 0.05399011201890452, 0.01589574641548097, 0.03533547105533736, 0.023850709465997558, 0.026820492697879672, 0.043089233205786774, 0.020815296630774225, 0.03131438771794949, 0.16346337433372224, 0.11567313516778605, 0.18318937798695906, 0.13803029406283582, 0.23590244299599103, 0.1091371194592544, 0.13164772226342134, 0.14103290651525768, 0.08550558358963047, 0.15984819403716496, 0.16742817658398831, 0.13423607551625796, 0.20815017074346542, 0.13897328131965228, 0.08390191357050623, 0.19052800562764916, 0.1570573387933629, 1.1392994884933745, 60.20591150011335, 98.65488706316266, 89.85159587860107, 100.26796695164272, 82.19134589603969, 47.17475264413016, 66.7366692679269, 88.60965401785714, 102.05805914742606, 69.59019020625523, 4.502278089523315, 0.27722449281385964, 0.2573303346123014, 0.2331392312688487, 0.5203182942100933, 0.4516739190689155, 0.753275705235345, 0.2645811598215784, 0.3082573190331459, 0.7428274058869907, 51.528219427381245, 113.77771772657121, 94.9951388495309, 99.0006502696446, 91.15753759656633, 94.35845456804547, 81.04559489658901, 78.10555498940604, 71.42375728062221, 73.35997704097203, 71.23247337341309, 71.65162345341274, 68.24926430838448, 69.82152353014264, 71.95678833552769, 79.54368618556431, 72.14889213017055, 65.88233961377824, 61.916321754455566, 66.50504411969865, 66.87060274396623, 64.80533409118652, 63.22812080383301, 62.527533939906526, 65.18297563280377, 65.19011838095528, 58.16225869315011, 65.4173036302839, 68.22236783163888, 70.20486259460449, 66.22623375483921, 63.08576611110142, 60.76846545083182, 68.43518420628139, 68.96583202907017, 69.41816670554024, 65.70684896196637, 68.72464615958077, 64.43727411542619, 62.862249510628835, 62.6619051524571, 64.1876322882516, 62.05485493796212, 70.81590802328927, 71.19948332650321, 72.74549920218331, 75.31970950535366, 78.28105953761509, 75.17837619781494, 82.7205137525286, 66.95559310913086, 48.895970821380615, 82.29806327819824, 77.90921974182129, 70.55131367274693, 59.786518233163015, 61.173066002982004, 56.28193024226597, 59.116823060171946, 61.1655341557094, 60.11722469329834, 61.96274961744036, 69.03791264125279, 69.5569291796003, 70.06880296979631, 62.574448176792686, 59.75581414358956, 59.677132742745535, 63.15293434688023, 64.52162524632045, 60.32073048182896, 56.35029704230172, 61.64838532039097, 60.89746570587158, 59.19298226492745, 60.24782998221261, 60.085645130702424, 58.60836778368269, 59.24787998199463, 64.2473451069423, 74.40717479160854, 76.18331500462124, 79.61103507450649, 77.05445235116142, 77.85796288081578, 80.85980006626674, 77.19486849648612, 71.56921781812395, 68.72144998822893, 67.05416025434221, 73.64233793531145, 80.52678680419922, 80.67783369336809, 81.56327043260846, 79.92817865099225, 70.8073547908238, 6.311280242034367, 1.9318508633545466, 0.8573669397405216, 0.8074628061481884, 1.4803900314228875, 0.2400793417223862, 0.5764753722718784, 0.6183899460094315, 0.6237232855388096, 0.498127213546208, 4.884623561586652, 36.50858688354492, 56.385951723371235, 79.56097330365861, 46.109058788844514, 43.053557191576274, 60.047409193856375, 69.13240119389125, 81.0189277103969, 87.22771985190255, 67.28461810520717, 1.3279388461794173, 0.1282084318143981, 0.15396164490708283, 0.12074502158377852, 0.07876298110932112, 0.1288431877536433, 0.11770114063152246, 0.11381360316382987, 0.14159781405968325, 0.2515526632113116, 0.11370899342000484, 0.148421243631414, 0.13311760553291865, 0.15802103493894848, 0.1284614439521517, 0.09774968014763934, 0.12902911991945334, 0.2089877272290843, 0.14964510367384978, 0.07933566466506038, 0.13524462282657623], [0.024428957008889744, 0.06839495923902307, 0.036064930127135346, 0.038029635058982034, 0.031878562444554906, 0.004645159135439566, 0.02104457700625062, 0.024231145391240716, 0.013564206792839935, 0.024495314341038465, 0.03693590106974755, 0.03008101800722735, 0.04208276899797576, 0.038632035055863004, 0.02297938907785075, 0.011713791755028069, 0.07924928715718643, 10.083936248506818, 49.859383719308035, 63.52473245348249, 65.26339408329555, 45.03425931930542, 41.06772034508841, 19.07060602733067, 48.9231903893607, 54.40549278259277, 69.90638882773263, 29.979382038116455, 0.4652534946799278, 0.11888261937669345, 0.13161437905260495, 0.3013884276151657, 0.17378984950482845, 0.07489342481962272, 0.10963627696037292, 0.21643091711614812, 0.5288759778652872, 28.030582564217703, 104.40486185891288, 86.0530435017177, 97.62956918988908, 88.88389246804374, 85.74674606323242, 78.78242070334298, 72.78159509386334, 62.212113516671316, 63.17006165640694, 62.26302991594587, 60.26741000584194, 61.43415151323591, 60.273725918361116, 57.61008187702724, 57.01953363418579, 54.96355472292219, 58.122237069266184, 58.56597682407924, 60.19796970912388, 60.05876949855259, 58.18843255724226, 58.10304961885725, 57.620538915906636, 58.45762661525181, 56.644605364118306, 52.53201525551932, 55.10116727011544, 58.55244173322405, 58.99477795192173, 59.92204284667969, 56.8162328175136, 56.39411238261631, 58.519986697605674, 64.01196793147496, 62.73113005501883, 60.58410194941929, 54.833498341696604, 54.28112350191389, 50.96086079733712, 54.41053370067051, 53.71414702279227, 55.88622338431222, 57.88637351989746, 60.35308129446847, 60.71850790296282, 66.20459011622837, 64.57681478772844, 70.437502179827, 64.59686034066337, 75.42284856523786, 56.53175967080252, 44.46378442219326, 77.46666812896729, 66.27487114497593, 62.93958990914481, 52.589233670915874, 58.231014592306956, 54.34400469916207, 58.01710735048567, 55.18510845729283, 57.25405618122646, 57.24642358507429, 58.22183602196829, 60.52346502031599, 61.24906539916992, 55.69300092969622, 53.47928053992135, 54.57319450378418, 55.760398456028526, 55.20362193243844, 53.4770883832659, 51.1009121622358, 50.5763509614127, 50.94339302607945, 52.460434913635254, 53.603052275521414, 52.23640067236764, 51.939611843654085, 53.56936740875244, 56.101374353681294, 67.29158020019531, 71.2227042061942, 73.49958024706159, 71.75788920266288, 73.58896882193429, 71.4610413142613, 70.61726597377232, 65.94804177965436, 59.597742625645225, 58.61792850494385, 60.29173564910889, 71.36583709716797, 72.35331508091518, 76.35200337001255, 73.24774973733085, 73.75653157915387, 41.34191015788487, 0.33635447706495014, 0.836208697940622, 0.32998490599649294, 0.1157802487058299, 0.17696269282272883, 0.15775989395167145, 0.33089653136474745, 0.20258289948105812, 0.02305079810321331, 0.12878775144261972, 9.39033579826355, 24.53700920513698, 60.273691177368164, 53.21893848691668, 19.297429970332555, 22.61967291150774, 43.56863062722342, 59.74623257773263, 54.692967551095144, 70.8292485645839, 15.804839781352452, 0.21061197721532413, 0.09511366659509284, 0.04325113844658647, 0.02318975868235741, 0.02544847283778446, 0.03873493489144104, 0.12442995528025286, 0.04661343552704368, 0.018779761124668375, 0.03639927486489926, 0.057476170494088104, 0.01532878799896155, 0.036018908489495516, 0.081892398186028, 0.0896047493442893, 0.04369852711845722, 0.006345727347901889, 0.0507865582060601, 0.057393782772123814, 0.0015932764529549915, 0.046872113432203016, 0.048469252551772764, 0.03842835580664022, 0.022980496786268692, 0.048085710632481744, 0.012717411204773401, 0.022612276187698756, 0.05344955709629825, 0.011291815915943255, 0.026766165791611587, 0.03439526918477245, 0.04426279005461505, 0.03147379594988056, 0.023128222341516187, 0.03935498358415706, 0.03284983104094863, 0.1812372598797083, 11.970214094434466, 70.4289003099714, 79.78326007298061, 80.37171690804618, 59.519040380205425, 55.091113226754324, 25.226440736225673, 47.15483910696847, 64.70054830823625, 77.6870858328683, 34.04867097309658, 0.5126077479549817, 0.16060410918934004, 0.7000454472643989, 0.08696305645363671, 0.44386373673166546, 0.07513691032571451, 0.6694083969507898, 0.19559035184127943, 0.46095538245780127, 38.20061220441546, 111.28228609902519, 93.78548526763916, 102.15213080814907, 93.69278935023716, 89.66668346949986, 81.90330137525285, 76.5534177507673, 65.51584298270089, 68.37503365107945, 65.9215760912214, 65.98810509272984, 63.83814484732491, 62.233541761125835, 61.534990719386506, 59.98143604823521, 57.95802681786673, 60.99489334651402, 60.72583825247628, 64.14447007860456, 62.68706457955496, 60.69587762015206, 60.82200826917376, 61.760758536202566, 62.001395498003276, 59.04324858529227, 56.96997908183506, 59.39750943865095, 62.29903548104422, 63.42597770690918, 62.148989132472444, 58.45264475686209, 59.74600328717913, 60.69202136993408, 65.48190798078264, 66.67651176452637, 63.9289300101144, 58.30853911808559, 56.75534575326102, 54.42809179850987, 56.33093588692801, 57.64626809528896, 60.39060156685965, 61.95505101340157, 63.44625949859619, 64.36577715192522, 67.73688329969133, 67.89410018920898, 72.72377913338798, 70.34397942679269, 78.92540768214634, 60.440711975097656, 46.87732458114624, 80.56335517338344, 70.27285071781704, 64.98484080178397, 56.18867152077811, 62.39494841439383, 58.53318132672991, 60.293028014046804, 57.60352277755737, 61.5596707207816, 59.7032927104405, 61.86788586207798, 63.21692030770438, 65.14442007882255, 59.21313898903983, 54.45242091587612, 58.96121120452881, 58.40624468667166, 57.24847330365862, 56.29349899291992, 52.273479734148296, 53.74884285245623, 53.64657231739589, 55.83091919762747, 56.01223938805716, 55.81759950092861, 55.033085346221924, 56.63282469340733, 58.45020593915667, 70.61109597342355, 73.49044336591447, 76.29427773611886, 74.43191732679094, 75.25309017726353, 74.75886481148856, 71.95091015951974, 70.07573727199009, 63.58285413469587, 61.22870717729841, 62.11645071847098, 72.19031034197126, 75.31456089019775, 78.78796536581856, 77.50121457236153, 76.8924342564174, 50.3188020842416, 0.8623921700886318, 0.2842754216066429, 0.433125730071749, 0.433224117649453, 0.4576093905738422, 0.22399435697921685, 0.5397810669881957, 0.6929595332060541, 0.24457447337252752, 0.42760294356516426, 9.336682677268982, 28.93594673701695, 49.720833165305, 26.25956491061619, 21.277451174599783, 40.38043928146362, 51.78945779800415, 70.41503170558384, 61.81995023999895, 87.1718076978411, 31.866005556924, 0.36835114870752605, 0.058905110960560184, 0.04954032686405948, 0.06489116046577692, 0.06406012470168726, 0.06330775150230952, 0.04622316254036767, 0.014046784290777785, 0.024049635577414716, 0.00776799357429679, 0.04916483237008963, 0.03527802288798349, 0.01154223011274423, 0.08938884628670556, 0.028519654646515846, 0.021880769636482, 0.04699044654678021, 0.030233047170830623, 0.05320783578125494, 0.03810217384515064, 0.13735002199453966, 0.11365282429116112, 0.10244535960789238, 0.16409617609211377, 0.1368320690734046, 0.09994206071964332, 0.12137228649641786, 0.15349965755428585, 0.09743605447666985, 0.09444710093417338, 0.10098604791398559, 0.09232414127992732, 0.1992131724421467, 0.12481161765754223, 0.07491099209125553, 0.07803317598466362, 0.2330178820661136, 16.63481773648943, 93.99623107910156, 100.54545021057129, 94.89525849478585, 74.30360494341168, 66.43087904793876, 28.643507480621338, 66.40948554447719, 76.50284876142229, 89.75456428527832, 43.86013535090855, 0.8902502666626657, 0.32254284247756004, 0.47963034893785206, 0.8997025308864457, 0.4529276617935726, 0.3735460942345006, 0.829810384128775, 0.35498466023377007, 0.7020045135702405, 36.81028808866228, 111.27134268624442, 94.46817357199532, 105.16443198067802, 97.71036284310478, 92.24854373931885, 85.4365576335362, 82.53118923732212, 70.55539921351841, 72.40375900268555, 70.35091372898647, 69.61961582728794, 68.20357990264893, 67.9867057800293, 64.65514183044434, 64.39809322357178, 60.39169243403843, 63.43259934016636, 63.76716205051967, 68.6461523600987, 67.25493540082658, 64.36816733224052, 63.20398276192801, 64.66332680838448, 64.35468782697404, 61.914202553885325, 59.25220176151821, 62.64752932957241, 64.23831939697266, 67.05296516418457, 66.49661595480782, 61.925007002694265, 62.093764850071494, 64.55013370513916, 71.53815242222377, 70.65371622358049, 68.62685721261161, 61.22405188424246, 60.24820518493652, 59.04288033076695, 60.92160374777657, 61.688664027622764, 63.538059098379954, 65.68641430991036, 66.59052780696324, 68.73810482025146, 71.80278846195766, 72.73891925811768, 76.24753025599888, 74.96222468784877, 81.34586824689592, 64.91596330915178, 50.4107198034014, 83.21689305986676, 74.31490966251918, 68.86892550332206, 59.63690267290388, 64.32579026903424, 61.60796070098877, 64.48207609994071, 60.28712204524449, 65.09984043666294, 63.63856479099819, 65.25072751726422, 67.97753415788922, 69.99005208696637, 62.28994723728725, 59.674673080444336, 61.00330761500767, 60.743250438145225, 60.0906617300851, 59.64858259473528, 56.05890001569475, 56.39041594096592, 57.00042608806065, 59.34751714978899, 59.63768087114607, 59.2598934173584, 57.71361698423113, 59.958458355494905, 62.8232353755406, 74.01215580531529, 77.40672601972307, 81.88979407719204, 78.99581377846854, 80.55045236860002, 79.53215217590332, 75.6556201662336, 72.36942795344761, 66.89251041412354, 64.7931261062622, 67.361298424857, 77.62983962467739, 79.85229042598179, 83.31389686039516, 80.3144359588623, 84.8040075302124, 48.34095219203404, 1.6271857087101256, 3.1319400327546254, 1.2405541752065932, 0.33610466761248453, 0.9155842129673276, 0.38208646167601856, 1.8054479318005698, 0.4778863510915211, 0.33107083344033783, 0.4152375656579222, 15.173962456839424, 38.53790903091431, 81.08509540557861, 70.93959290640694, 26.928113630839757, 38.27464178630284, 59.26099818093436, 82.75392069135393, 72.36664172581264, 100.71969713483537, 33.338606766292024, 0.36272875326020376, 0.12867256333785398, 0.19459567378674233, 0.1332593514983143, 0.14492978741015705, 0.13253679312765598, 0.2495985637818064, 0.13484936260751315, 0.1490379912512643, 0.10230004454829864, 0.14895857551268168, 0.16223219968378544, 0.11120125691273383, 0.277910301727908, 0.1266650767730815, 0.09687242936342955, 0.11111306771636009, 0.1492592343794448, 0.12295406019049031, 0.11810780023889882], [0.0647728918120265, 0.026033436181023717, 0.13902083305375917, 0.02903402490275247, 0.009765901769112264, 0.08442602758961064, 0.021576003936518515, 0.02827777048306806, 0.05954929853656462, 0.055256906364645274, 0.04261822472991688, 0.07748951337167195, 0.042854100465774536, 0.03010410855391196, 0.061288743412920406, 0.022497858220179166, 0.16856591696185724, 19.69523344721113, 64.78587218693325, 58.46418571472168, 52.83516863414219, 41.16017654963902, 41.655159269060405, 45.12194905962263, 90.60232094355992, 63.24521337236677, 48.56619541985648, 3.2612483969756534, 0.10649577940681151, 0.03701279265806079, 1.1619033898626054, 0.4754208805305617, 0.1522222203867776, 0.16033772991171905, 0.25170636496373583, 0.24805869641048567, 9.499367799077715, 95.86077322278703, 85.63711738586426, 97.37022072928292, 85.3356489453997, 87.77195835113525, 80.0764740535191, 74.93202781677246, 62.3198036466326, 67.31052793775285, 63.02984006064278, 64.3067661012922, 59.29636451176235, 58.433516366141184, 56.25868156978062, 60.48827934265137, 55.953419412885395, 58.56594903128487, 57.98328699384417, 58.80399431501116, 58.697589601789204, 59.48070022038051, 57.7763557434082, 59.467436109270366, 57.97430297306606, 56.02595860617501, 50.75391912460327, 54.28505618231637, 55.9161353792463, 59.80437510354178, 60.67030824933733, 59.963579177856445, 54.56604480743408, 58.608895846775596, 60.366748401096885, 62.681783948625835, 63.391577175685335, 61.53786032540457, 53.2405925478254, 54.17533370426723, 50.957282475062776, 53.74641445704869, 52.98335633959089, 55.32861655099051, 56.75980649675642, 60.37486389705113, 57.39172083990914, 61.145565032958984, 60.33028425489153, 66.04830428532192, 63.4254982812064, 75.87647560664585, 55.58072846276419, 47.69548191343035, 76.06775951385498, 62.72297286987305, 60.14098058428083, 58.118231432778494, 65.99490737915039, 63.201182637895855, 64.86133657182965, 62.01345757075718, 64.48326424189976, 62.4347824369158, 63.51738820757185, 60.419110025678364, 60.8186731338501, 54.28455243791853, 50.31165933609009, 54.98207514626639, 54.426306111471995, 53.42495952333723, 51.56767129898071, 50.998082297188894, 51.520062242235454, 48.05242477144514, 50.214526993887766, 51.846099512917654, 53.244824000767295, 51.55267013822283, 53.38805069242205, 53.23587472098214, 60.297787530081614, 65.51569012233189, 68.28401919773647, 68.32532623835972, 72.20931366511753, 69.22302654811314, 67.73010185786656, 63.23921012878418, 60.49098914010184, 53.382235050201416, 56.35052285875593, 62.589567456926616, 71.14264011383057, 70.14127268110002, 77.94872719900948, 71.11728613717216, 80.99667957850865, 13.56196996143886, 2.1729342469147275, 0.29891098769647734, 0.39500161579677034, 0.038870933665228743, 0.3549858544554029, 0.14905191478984697, 0.5524866080709866, 0.09060257580131292, 0.06900429725646973, 0.5477698126009533, 21.35159019061497, 27.561091048376902, 58.40825966426304, 34.653699261801584, 15.925792285374232, 32.127379417419434, 47.254705565316335, 56.94934640611921, 65.38434137616838, 56.316198757716585, 3.715183113302503, 0.17280921712517738, 0.035492589231580496, 0.026334305393642614, 0.026958481275609562, 0.06830233920897756, 0.04314192144998482, 0.011305545223876834, 0.04384253939081516, 0.07308911199548415, 0.01887364492618612, 0.04247181722894311, 0.025000286887266805, 0.03713203161688788, 0.06952517466353518, 0.045292952097952366, 0.04375740020935025, 0.019386100017332604, 0.036647818849555085, 0.026713728605370437, 0.07892073371580668, 0.008581149940645056, 0.05023920775524207, 0.046655725222080946, 0.0850587614945003, 0.026988348690792918, 0.031879661671285114, 0.05461413014147963, 0.040493385533669164, 0.045612847432494164, 0.03255456992025886, 0.030492970187749182, 0.04230006305234773, 0.0407350966706872, 0.07286265093301024, 0.04211828691352691, 0.270331825528826, 29.748267582484655, 88.13527270725795, 69.93172890799386, 68.03177179609025, 50.46203919819423, 56.719232491084504, 46.67139734540667, 73.36984348297119, 66.27479471479143, 53.39615229197911, 2.983706295490265, 0.08641062038285391, 0.27105555097971645, 1.5289939833538873, 1.0062874087265559, 0.6579943522810936, 0.5046673140355519, 0.09960362780839205, 0.6245100604636329, 15.063314131328038, 103.25312151227678, 88.26669788360596, 103.28217193058559, 89.33514322553361, 94.58742550441197, 84.38495472499302, 78.95740413665771, 64.61265359606061, 70.5447267804827, 66.18383584703717, 67.4643680027553, 62.0348927634103, 62.65162876674107, 59.616120610918315, 63.47717203412737, 60.54130799429757, 62.40566948481968, 62.511643409729004, 59.86394201006208, 60.908659253801616, 62.433635984148296, 60.886383329119, 61.358562060764854, 59.38220950535366, 58.33744362422398, 52.8726680619376, 56.844397340502056, 59.017283167157856, 63.82098279680525, 62.636738777160645, 62.25033555712019, 56.967519419533865, 61.843157223292756, 65.16256877354213, 67.03863103049142, 65.63194043295724, 64.29112570626395, 56.94562217167446, 56.27857773644583, 54.66953475134713, 57.51075390407017, 54.62093210220337, 58.334386416843955, 59.787984303065706, 64.58627128601074, 61.41880989074707, 64.66725948878697, 64.17371504647392, 68.53471715109688, 65.557101385934, 78.79789434160504, 57.95452839987618, 53.1586593900408, 77.40356458936418, 65.30596569606236, 62.49927561623709, 63.76150621686663, 69.26784242902482, 67.33273438044957, 69.76871027265275, 67.42671571459088, 68.89024952479771, 67.03735256195068, 67.65419278826032, 64.28753348759243, 62.83101735796247, 56.29703910010201, 54.588411058698384, 58.53888579777309, 58.70221710205078, 56.665029593876426, 53.5491099357605, 54.20561742782593, 53.82826771054949, 49.926732608250205, 54.07627323695591, 54.03049503053938, 55.5142411504473, 53.68262651988438, 56.16698619297573, 56.290712765284944, 62.88040515354702, 67.40850448608398, 73.11395522526333, 71.02179704393659, 75.15013871874127, 72.7159902027675, 71.00139713287354, 65.55110509055001, 63.39938000270298, 56.226007665906636, 60.32453809465681, 64.63946669442313, 76.21410247257778, 70.9742157799857, 82.87347139630998, 72.0787570135934, 86.47348594665527, 19.014789410999843, 1.5166428003992354, 0.2019758956240756, 0.7343391499349049, 0.13452830697808946, 0.2694748358002731, 0.30969831028154915, 0.7357430660298893, 0.5304895341396332, 0.055501531809568405, 0.7238506270306451, 23.459112576075963, 32.782608440944124, 38.484129973820274, 27.20641677720206, 25.66030536379133, 36.86205216816494, 54.99460622242519, 64.67218576158795, 69.36607606070382, 72.06304713657924, 7.1542165875434875, 0.22393531086189405, 0.026547852238374095, 0.018717378311391388, 0.032980696697320254, 0.07121213485619851, 0.06223679932632616, 0.0634496942428606, 0.03370602688352976, 0.08470996735351426, 0.0497714019646602, 0.09236054468367781, 0.013685192131171269, 0.04565393951322351, 0.028241585906861082, 0.07097839989832469, 0.026292378714840327, 0.03616098354437521, 0.06037376608167376, 0.02632501455289977, 0.1683741086827857, 0.16574118924992426, 0.176628460043243, 0.1570706380797284, 0.17225132563284465, 0.12424983137420245, 0.15238390171102115, 0.0858610545152, 0.16436256894043513, 0.1317590427185808, 0.10004522518387862, 0.15570989038263047, 0.22301253037793295, 0.08848382306418248, 0.17329426109790802, 0.08499890792050532, 0.4535597578755447, 40.03306756700788, 110.34615530286516, 86.08396993364606, 84.26421587807792, 65.56837831224713, 60.25659166063581, 64.46473339625767, 117.51247869219098, 78.88155760083879, 72.01269354139055, 5.071586992059435, 0.08345140024487462, 0.344673289252179, 3.6289985265050615, 1.6210332959890366, 0.42781356083495276, 0.6652235729353768, 0.6800843040857996, 1.2156228444405963, 13.584975446973528, 103.44178594861711, 90.54657554626465, 107.37056841169084, 93.56649889264787, 98.7570881162371, 88.50190830230713, 83.60957050323486, 68.00493090493339, 73.61896419525146, 72.25079441070557, 72.61268438611711, 67.69115720476422, 66.14472443716866, 63.58725234440395, 68.14743150983537, 63.02043219975063, 66.97741045270647, 66.40511512756348, 63.65412875584194, 63.95732034955706, 65.94309466225761, 64.88912241799491, 65.79448659079415, 63.09811305999756, 60.3384553364345, 56.118894236428396, 59.809516770499094, 61.02688980102539, 67.70706163133893, 66.13380186898368, 67.02210126604352, 61.22596958705357, 63.75978306361607, 67.1483986718314, 70.3983907699585, 70.37753922598702, 69.40432589394706, 60.89169175284249, 60.6739421572004, 58.67022064753941, 60.44026729038784, 60.4410593850272, 61.127583095005576, 63.552990777151926, 66.85762350899833, 63.728967802865164, 67.85398823874337, 68.6109597342355, 71.86767768859863, 70.38400105067662, 82.02455438886369, 63.63073417118618, 56.7125517981393, 80.78259168352399, 70.0183937890189, 65.98684052058628, 64.7231855392456, 71.96253449576241, 69.14938259124756, 70.2219899041312, 69.88316794804165, 72.08280086517334, 68.22101988111223, 71.35178783961705, 68.71522440229143, 67.96645872933524, 60.288518633161274, 57.784915924072266, 62.340655190604075, 61.16590935843331, 58.69465051378523, 56.35398653575352, 59.04763289860317, 56.536084924425396, 53.85242312295096, 56.45549624306815, 57.12944718769619, 57.996516363961355, 56.58785595212664, 60.21122687203543, 58.85826669420515, 65.68795680999756, 72.14033194950649, 77.23839896065849, 75.09931959424699, 78.39699717930385, 76.258042880467, 75.16244397844586, 68.89480754307338, 67.41536930629185, 59.57273605891636, 61.79923071180071, 69.00257410321916, 79.4463141305106, 75.22308090754917, 87.05026980808803, 77.92524923597063, 92.00116007668632, 15.808359043938772, 4.2518797772271295, 1.9127124845981598, 1.723571228129523, 0.19730080291628838, 1.0471797287464142, 1.1092670943055833, 2.4124647080898285, 0.34063931714211193, 0.13163852132856846, 1.2852100304194858, 37.10184839793614, 40.62826762880598, 83.26491900852749, 49.253281933920725, 21.743030854633876, 45.5722096988133, 68.86647278921944, 77.34993144444057, 85.63457434517997, 84.87373965127128, 7.842179008892604, 0.2419644205697945, 0.18414784941290105, 0.08704893863094704, 0.0996496392680066, 0.2228444165417126, 0.1242628592465605, 0.10222681026373591, 0.1261846468384777, 0.1365469486585685, 0.11709986361009733, 0.17220338034842694, 0.05515008459665945, 0.17798513653022902, 0.17048543824681214, 0.16996512402381214, 0.06929709868771688, 0.11743105655269963, 0.1471126481358494, 0.21172068986509526], [0.09595225445394005, 0.03985680094254868, 0.015840255821655904, 0.10103786084800959, 0.026491864617647867, 0.041730480401643684, 0.06601467196430479, 0.04432809565748487, 0.022899988606306057, 0.02098389053052025, 0.016305997169443538, 0.05926230536507709, 0.07097766708050456, 0.020527531625702977, 0.1223134688500847, 0.32324518050466267, 6.26973956823349, 62.33490208217076, 65.27393450055803, 71.60941314697266, 51.92854336329869, 41.90275137765067, 20.059537921633037, 50.481188433510916, 92.32978902544293, 77.13657311030796, 23.759050675800868, 0.026186394937602536, 0.13017740473151207, 1.2730368950537272, 0.759942176086562, 0.410342451184988, 0.5333425839032445, 0.40956463292241096, 0.4950696804693767, 0.4527802839875221, 69.97983128683907, 93.35086849757603, 88.48137637547084, 87.11083725520542, 93.34525435311454, 85.15194552285331, 78.77780709947858, 63.364625113351, 63.87845829554966, 64.00101062229702, 60.93561826433454, 61.71562303815569, 59.48113795689174, 58.55358818599156, 56.28970180238996, 57.29531111036028, 56.10735675266811, 55.715714590890066, 58.314313071114675, 58.58198547363281, 59.15776184626988, 57.184539454323904, 58.24793345587594, 55.60407788412911, 57.39943681444441, 54.40436717442104, 53.65921803883144, 55.22719022205898, 55.80178887503487, 58.52733094351632, 58.29203019823347, 55.32102216993059, 55.231835092817036, 62.61644308907645, 65.34896114894322, 67.65813241686139, 65.67611707959855, 61.98815223148891, 53.32424885886056, 53.20821394239153, 52.18408421107701, 51.53496265411377, 52.812079770224436, 54.560962200164795, 56.53527545928955, 58.674952370779856, 58.79783821105957, 61.05776759556362, 56.6087144442967, 64.7221988950457, 64.78909615107945, 75.52505656651088, 53.114920479910715, 51.35554279599871, 76.48165675571987, 59.94429792676653, 60.813448088509695, 63.26858711242676, 70.33652400970459, 67.46272822788784, 68.97564288548061, 68.57714285169328, 69.48418848855155, 67.66344084058488, 66.09787968226841, 61.65637574877058, 61.24281202043806, 52.45145436695644, 52.03909962517874, 55.01796606608799, 54.571672848292756, 52.60357822690691, 52.1099990436009, 50.18497977937971, 49.53740419660296, 48.61807067053658, 50.55915764399937, 49.170848505837576, 52.13070814950125, 51.321197850363596, 53.34557982853481, 52.768146310533794, 55.04097849982125, 54.652622835976736, 56.43500600542341, 60.060228620256694, 67.40348788670131, 66.61080959865025, 63.07849134717669, 59.16348716190883, 57.038272925785606, 54.57155472891671, 55.125416483197895, 56.72445058822632, 64.30725942339215, 66.89465740748814, 73.65353843144008, 71.7509549004691, 78.39015320369175, 65.21087959834507, 0.4463266831423555, 0.4420362790780408, 0.1969055969800268, 0.284104159367936, 0.04669185381914888, 0.5430800499660628, 0.8228164251361574, 0.597605495580605, 0.17011271896106855, 0.22498329462749617, 6.07444394486291, 25.49854608944484, 31.626657485961914, 53.61885942731585, 25.581337349755422, 26.386433805738175, 37.23941578183855, 55.677322319575715, 53.29067168916975, 55.98994609287807, 20.48800901004246, 1.1123347239834922, 0.12085034378937312, 0.023059851456699625, 0.024319634839360203, 0.02970635811133044, 0.016236571162672978, 0.04977302366335477, 0.01680678315460682, 0.024512764565380554, 0.07020941616169044, 0.007722135633230209, 0.025930714460888078, 0.0417508059181273, 0.019750844820269516, 0.05324939605114715, 0.07284057140350342, 0.06680627805846077, 0.05622516905090638, 0.036236514669976065, 0.029879957903176546, 0.059295316093734333, 0.025486660788633993, 0.0475616101840777, 0.029944802102233683, 0.03545191784256271, 0.05267902629982148, 0.08237631579062768, 0.014837652478100998, 0.01965389404046748, 0.02313310100830027, 0.03405407802867038, 0.05039668216237, 0.03664150847388165, 0.15255097060331277, 0.3203337495880467, 8.57541458947318, 82.87639658791679, 81.07473564147949, 86.23968601226807, 65.49324049268449, 54.49981805256435, 31.24376310620989, 52.77891254425049, 77.5615040915353, 86.83783558436802, 25.11123091833932, 0.026634718291461468, 0.1856161720518555, 2.4986803446497237, 1.4475182124546595, 0.9618675751345498, 0.9655648853097643, 0.8455517451678003, 0.2937639738832201, 1.2343995911734444, 81.63314846583775, 95.92975493839809, 94.17894785744804, 90.69412749154228, 96.50192519596645, 89.98070730481828, 80.44666712624687, 66.24274962288993, 70.09013393947056, 67.61023848397392, 65.96416854858398, 64.4989880153111, 62.14829431261335, 60.7357394354684, 59.824677739824565, 61.40035547528948, 60.31492873600551, 58.387331690107075, 62.67953273228237, 62.07578986031668, 61.787349292210166, 59.82783917018345, 60.81598418099539, 59.29892839704241, 59.22979382106236, 56.99376971381051, 56.78634514127459, 57.54114185060774, 60.65568923950195, 60.68586526598249, 59.60603182656424, 57.10155711855207, 59.26081057957241, 67.20214993613106, 68.53018692561558, 70.40665217808315, 69.23303195408413, 65.07112353188651, 57.953837054116384, 55.27360766274588, 55.22283717564174, 56.21933739525931, 56.833085673195974, 58.00287743977138, 60.76245525905064, 62.33490208217076, 63.36064379555838, 64.39978858402797, 58.988218852451865, 69.18297018323625, 67.5794927052089, 78.36865547725132, 55.07813399178641, 54.80253716877529, 80.37040369851249, 63.7178715297154, 62.59669630868094, 66.4870969227382, 73.73977947235107, 70.08900833129883, 73.10235173361642, 72.55004637581962, 73.64812578473772, 70.74605083465576, 68.83763776506696, 65.01560047694615, 64.10312134878976, 56.39387961796352, 55.849064418247764, 59.37016132899693, 57.759113788604736, 54.74468994140625, 54.72840683800833, 53.915783745901926, 53.343860149383545, 52.126560074942454, 52.17784125464303, 51.79974113191877, 53.051841259002686, 54.51250546319144, 54.61952856608799, 56.73780502591814, 57.431478432246614, 57.34783949170794, 59.48705782209124, 61.099276133946006, 69.11979021344865, 69.89405577523368, 65.95832511356899, 61.75467191423689, 60.01045867374965, 57.65257705960955, 58.59478405543736, 58.822101320539204, 65.22517204284668, 70.64788668496269, 73.56025886535645, 74.95046138763428, 80.64016056060791, 73.78620038713727, 1.1941225124256951, 0.5789700469800404, 0.16234790347516537, 0.6520155359591756, 0.4347257427871227, 0.20117670350841113, 0.8659028559923172, 1.6667576538664954, 0.40564101774777683, 0.6605803849441665, 4.9830916949680875, 31.61392491204398, 34.190021651131765, 39.9647250856672, 26.757313013076782, 39.56694419043404, 46.076054845537456, 63.94097123827253, 64.4877736227853, 68.82652759552002, 37.55255024773734, 1.913719973393849, 0.076643366632717, 0.09250805141138178, 0.03279511058436973, 0.13768314197659492, 0.09191600925156049, 0.033852665086409876, 0.010811598023532756, 0.0343635171385748, 0.039170143859727044, 0.04314194519871047, 0.04632407087566597, 0.06790728255042008, 0.05812864976802042, 0.033623795224619765, 0.0361489904379206, 0.05131018707262618, 0.07963494610573564, 0.05726064741611481, 0.13755088193075998, 0.1035728066095284, 0.13608506987137453, 0.19810888384069714, 0.07849767391702958, 0.15289304724761418, 0.16367006967110292, 0.1432951558381319, 0.10509703374866929, 0.11285828014037438, 0.1304779550326722, 0.21714069188705512, 0.20277014800480433, 0.16493019062493527, 0.17867703868874482, 0.48311845319611685, 10.226098997252327, 100.87849126543317, 99.94106115613664, 106.1014313016619, 80.22939000810895, 64.64110646929059, 29.164361817496165, 68.55340780530656, 110.61081913539341, 98.33972372327531, 36.139238016945974, 0.22550440952181816, 0.245616757443973, 3.621468416282109, 4.740107110568455, 2.9684193900653293, 2.043902290718896, 1.2332908106701714, 0.9072005056909153, 0.7463913975017411, 82.93328843797956, 97.79958466121128, 97.48911135537284, 93.86459050859723, 101.0862979888916, 90.4323263168335, 87.81984533582414, 69.76964827946254, 74.97594738006592, 71.62775639125279, 69.85524313790458, 68.66658006395612, 66.25556904929024, 64.95057923453194, 63.49302782331194, 64.38463456290108, 63.67101287841797, 62.24977275303432, 66.91683605739048, 65.18741553170341, 65.859938621521, 62.63379968915667, 64.02760832650321, 60.700324467250276, 65.32082094464982, 59.875142506190706, 61.603256770542686, 61.131870133536204, 64.01687335968018, 61.99032006944929, 64.50777053833008, 59.339700426374165, 62.794761657714844, 68.88546221596854, 72.77470248086112, 73.53840678078788, 72.65055901663644, 67.43475478036063, 60.36103698185512, 57.51425232206072, 59.48866980416434, 58.01553010940552, 61.491967473711284, 62.0613306590489, 64.25730187552315, 66.06408364432198, 67.63576616559709, 69.1705607005528, 62.93488597869873, 73.47534493037632, 72.77709266117641, 81.08961173466274, 59.756634031023296, 59.09945256369454, 83.8038421358381, 68.70130716051374, 67.34037045070103, 69.56944983346122, 78.51229558672223, 74.31134523664201, 75.4984519141061, 75.89099734170097, 75.39507661546979, 74.5776696886335, 71.4225343976702, 69.30349363599504, 68.64488778795514, 58.517089298793245, 58.0271509715489, 61.900313104902, 60.11249297005789, 58.3680990764073, 58.54827281406948, 56.658394064222065, 56.31613622392927, 54.97652700969151, 56.26067917687552, 54.233448437282014, 57.863705021994456, 56.55443164280483, 58.63601466587612, 60.42334147862026, 60.8092930657523, 61.69933646065848, 63.52614293779646, 65.41027205330985, 74.04461084093366, 74.55319813319615, 70.17699337005615, 65.567565373012, 62.48630332946777, 61.571100507463726, 61.308166776384624, 62.58524567740304, 69.44444479261125, 73.64137213570731, 78.26890019008091, 77.76129954201835, 87.49442645481655, 74.92912346976144, 0.801865217941148, 1.0380356822695052, 0.712155180318015, 0.8742294577615601, 0.32530998970781055, 1.5112429644380296, 3.575381015028272, 2.2623972977910722, 0.5221706948110035, 0.7876309103199414, 9.313047511237007, 42.90846490859985, 45.917448316301616, 76.10247966221401, 32.009232248578755, 40.50589942932129, 54.72312273297991, 79.32777786254883, 75.47227110181535, 89.8434247970581, 44.835780552455354, 2.187898929630007, 0.21512689494660922, 0.10651488016758646, 0.12092268919306141, 0.1914676816335746, 0.15462294513625757, 0.15384667393352303, 0.11700186958270413, 0.051987310738435814, 0.20510760614914553, 0.08776315780622618, 0.09580360100205455, 0.16042171897632734, 0.10478243098727294, 0.09002523749534573, 0.12869848337556633, 0.1745870467275381, 0.22934670905981744, 0.15805424244276114], [0.039242112676479986, 0.022458706749603152, 0.07241228009973254, 0.06537737151873962, 0.031855590641498566, 0.04061060245814068, 0.046073430217802525, 0.020278987641047155, 0.11458601350230829, 0.028192777186632156, 0.0910762543124812, 0.031318140016602616, 0.03631625271269253, 0.05120193698842611, 0.06486083673579351, 0.13429324887692928, 20.875661168779644, 63.097154208592, 59.969214166913716, 61.839710916791645, 41.38981451307024, 31.861659458705358, 23.01379210608346, 67.9311271395002, 85.6627562386649, 60.790817805698936, 3.5725350763116563, 0.06494086315589291, 0.45460966868059977, 1.5144228509494235, 1.0759188894714629, 0.5489034546273095, 1.140270607812064, 2.289285306419645, 0.7024819850921631, 29.53676094327654, 102.13161277770996, 83.34264155796596, 92.60204723903111, 85.53745937347412, 88.70480264936174, 75.52029010227749, 70.08844552721295, 59.99846608298165, 65.90782560620988, 64.13140051705497, 68.41966887882778, 63.79020922524588, 61.31172425406319, 58.69071783338274, 59.060646874564036, 57.032516343253, 55.18938159942627, 58.31447982788086, 55.533619676317485, 57.724966866629465, 57.66637618201119, 57.57962792260306, 55.28298773084368, 56.95592982428414, 54.34626981190273, 52.27527584348406, 54.269158703940256, 55.291353361947195, 57.50612987790789, 58.628934451511924, 55.64463104520525, 55.083817618233816, 58.747984886169434, 67.25567190987724, 70.91236986432756, 69.77854892185756, 65.25799533299038, 61.49125180925642, 57.011529309409006, 51.037947586604524, 50.06426872525896, 51.94471876961844, 51.90592697688511, 54.066945280347554, 52.119469438280376, 57.617422648838584, 57.809293678828645, 61.648190770830425, 56.41606521606445, 62.190261432102744, 61.96289552961077, 74.02735151563371, 51.69135618209839, 55.18505981990269, 73.50301265716553, 57.2199752671378, 56.03009973253523, 64.8422429221017, 66.69021361214774, 64.59425476619175, 68.66892855507987, 67.4122565133231, 70.08140700204032, 66.66206645965576, 68.61410726819719, 63.54073415483747, 55.23351655687605, 49.96922779083252, 52.740895475660054, 52.629102434430806, 52.76624597821917, 51.19754076004028, 50.99922180175781, 52.76649611336844, 49.527103492191856, 48.965171405247276, 46.032722405024934, 47.57068184443882, 50.075941698891775, 50.34892947333199, 50.91316141401018, 51.18939399719238, 51.89046376092093, 51.99486739294869, 50.52361413410732, 54.09221935272217, 51.82187809262957, 56.59488752910069, 55.36870765686035, 54.90023578916277, 50.06086758204869, 54.770703996930806, 53.09281826019287, 55.98744821548462, 54.492796897888184, 60.76970223018101, 64.21334757123674, 76.5034532546997, 68.52920722961426, 87.68310478755406, 25.51095036097935, 0.8451452755502292, 0.3451285862496921, 0.506787871675832, 0.114814286253282, 0.5582435705832073, 0.348854910582304, 0.5860125347971916, 0.060459716112485955, 0.17028824239969254, 0.028512865903654268, 19.341662202562603, 21.261584963117325, 48.18464551653181, 44.425169808524, 15.459293706076485, 41.98786333629063, 41.49892554964338, 56.05460950306484, 43.76493460791451, 42.56904540743147, 14.784618411745344, 1.2193459932293211, 0.04026877008644598, 0.02072745857627264, 0.03533392399549484, 0.02889336459338665, 0.041873970202037265, 0.024800312439245836, 0.0350374449044466, 0.028611385795686926, 0.030683689418115785, 0.017906221927010586, 0.01590092363767326, 0.02975099893020732, 0.06450005288102797, 0.038063551631889174, 0.03259909538818257, 0.07887555685426507, 0.06092911985303674, 0.054205502782549174, 0.024829901655071547, 0.020469759457877705, 0.09139142025794302, 0.005894542272601808, 0.03364050414945398, 0.02748799304078732, 0.020644395711964796, 0.03136727612997804, 0.06171502625303609, 0.035885634033807685, 0.05656924398083772, 0.016136522870510817, 0.040830800642392466, 0.05070606359679784, 0.19733695526208195, 32.139198303222656, 85.69744859422956, 72.09338991982597, 76.10172230856759, 55.86208534240723, 48.16433940614973, 29.642908573150635, 53.80134344100952, 84.8982320513044, 65.52700873783657, 2.593297004699707, 0.15977149243865693, 0.9308511423213142, 2.4567455777100156, 1.402206620999745, 0.5636310300656727, 3.391956171819142, 3.556853426354272, 0.736692797924791, 40.395377908434185, 106.79665415627616, 89.6855617250715, 98.39781761169434, 90.65979644230434, 91.79129668644497, 77.61211477007184, 71.6135334287371, 64.51187692369733, 69.25375148228237, 67.97548443930489, 72.90554400852749, 68.40662711007255, 63.704503195626394, 61.77799701690674, 62.576859201703755, 58.629657064165386, 57.12049790791103, 59.64983327048165, 59.04773017338344, 62.47607558114188, 59.846064295087544, 60.61497279575893, 59.439052718026296, 60.87587070465088, 55.87798629488264, 53.79065711157662, 58.731350898742676, 57.25507756641933, 61.25709056854248, 60.52873870304653, 58.23577758244106, 55.96643686294556, 60.495137214660645, 71.23992184230259, 73.14730657849992, 73.16171714237758, 68.80822604043144, 64.37365640912736, 59.44370106288365, 54.73491382598877, 53.359441484723774, 54.74931049346924, 54.29157359259469, 56.73927109582083, 54.45562056132725, 60.73814351218087, 62.048928124564036, 64.75819751194545, 59.237054688589915, 63.381863594055176, 67.45209748404366, 76.2561946596418, 53.49074159349714, 57.15713923318045, 77.39374678475517, 59.252542223249165, 57.83464765548706, 68.31554317474365, 69.01337855202812, 64.05893080575126, 70.85879230499268, 69.63586071559361, 69.83492660522461, 69.24107101985386, 71.51274285997663, 65.81733226776123, 57.44733769553048, 52.442703110831125, 55.947044440678184, 55.18642166682652, 54.05044330869402, 54.042772497449604, 54.04606246948242, 53.88500670024327, 52.34846816744123, 50.82500614438738, 49.87556259972708, 49.673439502716064, 52.21570198876517, 54.07496697562081, 53.216544832502095, 54.07377535956246, 54.03329168047224, 53.80720772062029, 55.15908745356968, 56.71431316648211, 56.23597833088466, 58.82267802102225, 58.25029236929757, 57.13307762145996, 53.27782446997506, 57.50990274974278, 55.337385177612305, 59.96564974103655, 57.35316181182861, 61.972435406276155, 66.04334327152797, 80.38830920628139, 71.71206583295549, 91.15213189806256, 32.99314233234951, 0.5243726223707199, 0.1139160008834941, 0.4733976519533566, 0.46585375389882494, 1.0947867227452142, 1.2074933435235704, 2.322770629610334, 0.7669872694781849, 0.30435943390641895, 0.0684779305011034, 19.810712507792882, 30.1708014351981, 36.190519196646555, 29.717900480542863, 24.846961396081106, 51.07114607947213, 51.99317898069109, 65.78209100450788, 57.08656985419137, 60.36061314174107, 24.005980968475342, 1.9042943077428, 0.05493266162063394, 0.004843995765051139, 0.03243516132767711, 0.03921406203880906, 0.04349177749827504, 0.026451211888343096, 0.0405595868027636, 0.024184239961739098, 0.06366331063743148, 0.039059579971113374, 0.008798728131556084, 0.03239658661186695, 0.022191392789993967, 0.034696128219366074, 0.03539350276280727, 0.049772497798715315, 0.05054984108677932, 0.11321900971233845, 0.20688373941395963, 0.09922131403748478, 0.30742624934230534, 0.1642464173159429, 0.09022692524428878, 0.1495576947927475, 0.09761715547314712, 0.15038085276527063, 0.14617369137704372, 0.17226824829620974, 0.16357780247926712, 0.09644496587238141, 0.21585983490305288, 0.12345139921775886, 0.26196044044835226, 38.91041932787214, 109.5846049445016, 85.65202127184186, 93.01443672180176, 64.77203832353864, 50.8307557787214, 33.653196879795615, 89.42601871490479, 102.48915318080357, 81.74919033050537, 5.170265742710658, 0.27968008390494753, 1.0411404413836343, 5.491261226790292, 2.6480077717985426, 2.068083541733878, 8.077777658190046, 10.257426687649318, 1.0242139782224382, 38.23067705971854, 109.24293422698975, 91.055878502982, 102.56079605647496, 93.2768007005964, 99.22971153259277, 82.52854892185756, 76.5644028527396, 66.6881638935634, 74.64965997423444, 72.27496719360352, 75.72515773773193, 70.9195612498692, 69.43348748343331, 65.48067814963204, 66.63150133405412, 63.2597906930106, 60.74286133902413, 64.86387266431535, 62.80603163582938, 65.64770589556012, 63.98342473166329, 63.373338154384065, 62.07022435324532, 63.98921952928816, 59.3993159702846, 58.481827190944124, 62.03222465515137, 62.359220777239116, 64.66451495034354, 64.36299787248883, 63.26569666181292, 60.102077620370046, 64.4992242540632, 74.18893882206508, 75.16221468789237, 75.71429075513566, 73.06910460335868, 68.09125532422746, 63.39386313302176, 57.601629393441335, 57.77034902572632, 58.47820717947823, 59.22900867462158, 61.63513510567801, 58.984334809439524, 65.27767957959855, 65.31875038146973, 68.10687487465995, 63.403944969177246, 66.4945592880249, 70.49014173235211, 81.03712504250663, 59.68194784436907, 60.53294236319405, 81.49710273742676, 64.65002795628139, 61.11802932194301, 72.14945493425641, 72.3934131349836, 68.46581186567033, 73.32008048466274, 73.69435909816197, 75.27803421020508, 72.20060757228306, 76.35095419202531, 71.74179022652763, 59.75197178976876, 54.82198517663138, 59.16034657614571, 59.373065676007954, 57.867133957999094, 56.38592045647757, 57.0936952318464, 59.1726587840489, 56.29702172960554, 56.37722826004028, 52.149774006434846, 53.37507145745413, 56.50175040108817, 57.77685948780605, 55.861133439200266, 58.37401894160679, 56.44218002046858, 58.959182330540244, 56.187459060123985, 60.49938256399972, 58.04511553900582, 63.19178172520229, 62.67027078356062, 61.582961082458496, 55.97866569246565, 62.4252564566476, 57.83457122530256, 63.64918163844517, 60.84623663766043, 65.53636101314, 70.01892185211182, 82.33754294259208, 75.38179165976388, 96.21015644073486, 30.981569358280726, 1.1220530825001853, 0.5295983191047395, 3.070389415536608, 0.6574914221252713, 0.8921253574745995, 3.487671298640115, 4.932784131595066, 0.4478388120021139, 0.2780207943703447, 0.10798411204346589, 30.63277326311384, 35.17449801308768, 67.18460573468889, 60.92694691249302, 23.764984437397548, 58.84926182883126, 62.86866269792829, 77.48150948115757, 72.18437658037458, 82.1349265234811, 28.138309172221593, 1.6361416109970637, 0.23722181362765177, 0.10630314331501722, 0.11710476263293199, 0.10614016598888806, 0.1858914808503219, 0.08568196198237793, 0.15736936990703854, 0.15108624419995717, 0.16382259077259473, 0.06486985446619135, 0.08846764000398771, 0.13713399001530238, 0.15253616496920586, 0.076283003469663, 0.21520424793873513, 0.1360703320907695, 0.16359034180641174], [0.029882895959807292, 0.041819304028259854, 0.03364533192611166, 0.04275370103174022, 0.032696828179593594, 0.03314830841762679, 0.034515322385621924, 0.029257028829306364, 0.03928310636963163, 0.02294682278963072, 0.03106218303686806, 0.0491422575100192, 0.026464665541425347, 0.03294303800378527, 0.06905751475798232, 1.850930622645787, 50.270762239183696, 61.8986177444458, 67.07116944449288, 54.611083030700684, 43.8783083643232, 21.29775207383292, 43.58586910792759, 94.42647743225098, 69.39105483463833, 28.533317736216954, 0.17514881944017752, 0.17594871723226138, 0.5346284891877855, 0.35658299018229755, 1.7272978510175432, 0.9873937368392944, 2.580208335603986, 2.539691001176834, 5.5557348643030435, 89.58573000771659, 86.29293700626918, 89.80598790305001, 84.83464908599854, 85.63353906358991, 77.99485628945487, 67.91438892909459, 63.90051187787737, 63.98934459686279, 61.71677643912179, 61.94883237566267, 60.55259881700788, 59.887739590236116, 59.46537249428885, 60.492163385663716, 57.47844478062221, 57.75234971727644, 56.84512690135411, 56.36420038768223, 56.44044991901943, 57.842009271894185, 56.275013310568674, 56.99805327824184, 55.67050961085728, 54.91556698935372, 48.71401834487915, 53.05985253197806, 53.0289226259504, 56.75921242577689, 55.945314339229036, 55.89121219090053, 54.80408661706107, 54.50109652110508, 56.012534686497276, 69.16239656720842, 69.64575495038713, 72.20431791033063, 63.89285496303013, 64.10304491860526, 56.42997898374285, 53.4481143951416, 49.275259086063926, 52.47157287597656, 49.8773170198713, 53.38741493225098, 50.20356968470982, 57.765749318259104, 59.304473059517996, 62.18196528298514, 55.230511460985454, 61.08204460144043, 62.96506895337786, 71.48627717154366, 47.04915700639997, 58.15891660962786, 71.39774322509766, 58.514706066676546, 58.82531138828823, 67.77025549752372, 65.94049603598458, 63.800596782139365, 65.11370209285191, 62.96719510214669, 61.788447107587544, 62.553874560764854, 58.947196687970845, 54.15432582582746, 50.66826868057251, 50.898320061819895, 55.45345483507429, 53.714657715388704, 52.03105708530971, 48.095375061035156, 50.1956661088126, 48.24694306509835, 45.26666613987514, 46.70799698148455, 47.24630866731916, 44.77958699635097, 47.91897766930716, 49.700245652879985, 50.81149189812796, 49.94313383102417, 51.89892666680472, 52.07503570829119, 53.17891686303275, 51.21365710667202, 51.5715240750994, 50.71702071598598, 49.658552987234934, 49.94680942807879, 51.23560299192156, 51.36836222239903, 53.979109627859934, 55.71393237795149, 55.61244351523263, 56.213553019932334, 59.51773411887032, 66.40788745880127, 74.19189180646623, 73.29956245422363, 76.33466066632951, 4.108505436352321, 0.3143788719815867, 0.5358441525271961, 0.9583614489861897, 0.35247375496796196, 1.3742286137172153, 1.5620014007602419, 1.5594112426042557, 0.4532825084669249, 0.5388241154806954, 4.369015548910413, 26.92828212465559, 33.06552171707153, 68.46712507520402, 20.298559427261353, 21.136645930153982, 39.02469287599836, 55.4718918800354, 48.70654903139387, 42.91144221169608, 32.95884949820382, 22.52197081702096, 2.3954733226980482, 0.14336049876042775, 0.03545674901189549, 0.05910926857697112, 0.08305264557046549, 0.03632318734058312, 0.016800242077027048, 0.06798433020178761, 0.02721379873608904, 0.0763124790308731, 0.024518394709697792, 0.03906795648591859, 0.05964711614485298, 0.035495897089796405, 0.04125018956671868, 0.05724367046994822, 0.08495236720357623, 0.017595727695152164, 0.02226086120520319, 0.007881229194546384, 0.045727078802883625, 0.0173910306434014, 0.027354701621724025, 0.050436413780386956, 0.05037307592907122, 0.07649352574454886, 0.01128515524656645, 0.01732415083928832, 0.022081290305192982, 0.07297418851937566, 0.06513150435473238, 0.211951364630035, 3.1406155100890567, 72.48585196903774, 77.62076527731759, 82.24503462655204, 67.19264480045864, 56.333763803754536, 31.506165300096782, 44.880415780203684, 70.89307471684047, 77.65730585370744, 29.506637028285436, 0.05158804377008762, 0.38047841510602404, 1.4023101925849915, 2.037046807152884, 2.8572636289255957, 2.0074387959071567, 1.998405703476497, 2.2829224935599735, 9.599713683128357, 101.72947883605957, 88.22498089926583, 94.66933781760079, 87.58557987213135, 91.54590715680803, 79.40858541216168, 71.74862030574253, 64.70137514386857, 68.39630208696637, 64.87296785627092, 65.74459157671247, 62.8595883505685, 63.40853772844587, 62.11579063960484, 65.10707351139614, 60.732800347464426, 63.746247972760884, 60.27591460091727, 60.29876722608294, 57.88495608738491, 58.89177090781075, 59.10032108851841, 59.432035037449424, 57.06492274148123, 57.524848324911936, 52.820834500449045, 56.318849495479036, 56.74913058962141, 59.070874622889924, 58.404521533421104, 58.201731409345356, 57.579332624162944, 56.06726564679827, 58.107392242976594, 72.15890448434013, 71.87709249768938, 75.40242780957902, 67.50725923265729, 66.73741272517613, 60.593384742736816, 55.549638748168945, 52.08827897480556, 53.82858732768467, 52.75971467154366, 56.86217083249773, 54.65556539808001, 62.01796695164272, 61.44722802298409, 66.5825582231794, 57.68375015258789, 64.28335067204067, 66.096205166408, 73.39797673906598, 50.320608615875244, 62.41948250361851, 73.66755989619664, 60.15994221823556, 60.965162004743306, 70.29730837685722, 68.593658719744, 68.39662170410156, 67.12921469552177, 64.99403326851981, 64.17994063241142, 65.58440780639648, 63.87558174133301, 55.51259790148054, 53.07182080405099, 55.094184330531526, 56.78580665588379, 55.92983375276838, 55.15551607949393, 52.84154708044869, 53.79256091799055, 50.999624797276084, 49.29694441386631, 50.50730323791504, 49.3442234311785, 48.67214502607073, 52.068532194410054, 52.130694253104075, 53.03088549205235, 52.464551721300396, 54.30803387505667, 55.153782503945486, 54.93047782352993, 55.769618715558735, 53.85660941260201, 53.220102310180664, 51.86515147345406, 53.42888872964041, 53.8438629422869, 54.333710942949565, 57.07519217899868, 58.16958556856428, 59.36847291673933, 57.96122298921858, 62.67560700007847, 67.84784603118896, 77.7515651157924, 76.78889914921352, 83.65076637268066, 7.577244196619306, 0.3711540683039597, 0.6585978684680802, 1.2530889425958907, 0.43058521353772705, 2.5635287506239752, 1.5523578439440047, 3.006115755864552, 1.5918168808732713, 0.6436329143387931, 3.5521336453301564, 32.92757913044521, 37.40540477207729, 41.126731395721436, 23.96608441216605, 36.37987845284598, 51.95776053837368, 67.06136553628104, 60.93127564021519, 57.747201102120535, 48.53420243944441, 31.331393786839076, 3.176028524126325, 0.08492138529462473, 0.04669969089861427, 0.02425792547208922, 0.0628050316923431, 0.034751802017646174, 0.018021613592281938, 0.034237099279250414, 0.05154163876016225, 0.05119914820949946, 0.03540207605276789, 0.037311280212764225, 0.03635409461068256, 0.05078780671049442, 0.10850474517792463, 0.03339381595807416, 0.030815450740712028, 0.11012306476810149, 0.12632370580519947, 0.16410969250968524, 0.10984266017164503, 0.08247421482311827, 0.11398214447711195, 0.1767932219164712, 0.13294099643826485, 0.16087369115224906, 0.10624734059508358, 0.06653894204646349, 0.07901865310434784, 0.14297214602785452, 0.19852322446448462, 0.34506968941007343, 3.7992337346076965, 88.30341911315918, 96.20592498779297, 97.80951363699776, 80.30538940429688, 63.412338393075125, 30.847045285361155, 62.50871821812221, 115.48029736110142, 87.09199374062675, 43.192364828927175, 0.22802902119500296, 0.482529593365533, 1.8611129905496324, 3.668999740055629, 8.381146430969238, 3.7183871013777594, 7.946597405842372, 6.497261805193765, 8.36933970451355, 103.74066271100725, 91.15427889142717, 98.85594708578927, 90.24015304020473, 95.82692854745048, 83.2085621697562, 75.8613007409232, 68.50993292672294, 72.32247202736991, 70.53260217394147, 71.39834771837506, 68.33644335610526, 68.73750032697404, 64.50050272260393, 69.63390827178955, 64.43206991468156, 66.9663211277553, 63.66283484867641, 63.65457344055176, 62.048677989414756, 63.95926584516253, 63.33259391784668, 62.9485113961356, 59.869868823460166, 63.16286332266671, 58.30557223728725, 60.27978474753243, 60.04271221160889, 62.01953724452427, 62.877959387642996, 61.532906259809224, 59.16340378352574, 59.51339149475098, 61.24996171678816, 74.7732058933803, 74.4073554447719, 78.15675626482282, 69.6189557484218, 70.60385595049176, 64.55105781555176, 59.532332284109934, 53.69987194878714, 58.65010561261858, 55.976442268916536, 59.65756661551339, 57.76399837221418, 65.23337786538261, 64.34439059666225, 70.68627548217773, 62.51104586465018, 66.53490052904401, 70.50274576459611, 77.17073045458112, 53.95865413120815, 64.96032755715507, 76.10427229745048, 65.11810725075858, 63.47114099775042, 75.72114167894635, 70.62539536612374, 70.4603270121983, 73.17810099465507, 69.96468421391079, 67.64805058070591, 71.32565566471645, 68.26495334080288, 59.02175085885184, 55.67697490964617, 56.79290771484375, 60.616501399448936, 58.58866964067732, 58.98952511378697, 55.520355565207346, 56.64685658046177, 53.76536219460623, 52.06545761653355, 52.73822389330183, 52.82682384763445, 52.49563796179635, 55.338611534663606, 54.6388897214617, 55.5170065334865, 55.1499297278268, 56.42326354980469, 57.45377172742571, 57.37390218462263, 58.0312990461077, 57.11861842019217, 56.21277482169015, 54.476169858660015, 56.572743620191304, 56.300884928022114, 57.300021989004954, 59.723095076424734, 62.40830980028425, 62.09992790222168, 61.65018490382603, 66.15321513584682, 72.57795728955949, 81.42006805964878, 79.72087914603097, 84.69221796308244, 6.039599597454071, 0.5932661827121462, 3.4455109323774065, 3.4008023142814636, 0.40340402349829674, 3.6672123159681047, 5.17441338300705, 3.925793869154794, 1.6603792075599944, 0.5664110694612775, 6.800356558391026, 42.21359641211373, 46.830834184374126, 91.51786422729492, 28.19174255643572, 35.78625563212803, 57.42899445125035, 79.49964155469621, 71.68226500919887, 73.81924601963588, 65.85688141414097, 34.61407021113804, 3.424516950334821, 0.2317858524620533, 0.12468633295169898, 0.1123901316896081, 0.204202711848276, 0.12241020080234323, 0.10350748404328312, 0.15417755475001677, 0.10457429715565272, 0.14290807875139372, 0.12363149598240852, 0.1749271691909858, 0.10299513582140207, 0.11653642170131207, 0.171132624947599, 0.21180267046604837, 0.13731823941426619], [0.05989511390881879, 0.07598600869200059, 0.08374527376145124, 0.020750450735379542, 0.027140157330515127, 0.01996838823626084, 0.017723343168784465, 0.039887392693864446, 0.04099659388884902, 0.03150881514219301, 0.04127002314531377, 0.06698832221861396, 0.04066541112427201, 0.1251465425427471, 0.3867047610027449, 15.008174964359828, 78.54201998029436, 58.63089384351458, 64.8273320879255, 40.80450521196638, 29.412551471165248, 22.334028993334087, 59.69105693272182, 82.8049065726144, 56.86120503289359, 5.5339453135217935, 0.057773267052003315, 0.5011602107967649, 1.1962896989924567, 0.9865868772779192, 0.783354782632419, 0.6297506306852613, 1.7210642312254225, 0.10366280070905175, 52.76580824170794, 93.06788921356201, 84.97641318184989, 88.60175391605922, 78.95104653494698, 81.21869536808559, 65.4163795198713, 63.73766694750105, 60.18756825583321, 63.329279627118794, 61.29256807054792, 60.888599804469514, 58.374116216387065, 60.43586908067976, 59.97584274836949, 59.58241489955357, 60.53615937914167, 59.603454044886995, 57.93938480104719, 55.87578024183001, 55.16146373748779, 57.58071184158325, 54.57310765130179, 56.1087463923863, 54.848075662340435, 51.12715898241316, 49.79699584415981, 51.8665897505624, 53.20017140252249, 55.880564076559885, 54.37785284859793, 53.988705090114046, 54.1359269959586, 53.17639119284493, 61.58649771554129, 69.03933702196393, 71.7546443939209, 71.6046953201294, 67.42426994868687, 61.80389295305525, 56.51555299758911, 53.95819207600185, 50.99347564152309, 51.34378644398281, 52.06629140036446, 58.16890117100307, 59.77426855904715, 61.92543084280831, 61.915599141802105, 61.47638266427176, 54.9932895387922, 59.86112798963274, 65.03301266261509, 67.964033808027, 50.811582224709646, 58.126336506434846, 69.25994232722691, 54.498525687626426, 59.445903641836985, 66.78407682691301, 66.69996888296944, 63.022447177342, 61.73170811789376, 57.23843663079398, 51.66004065104893, 50.616831166403635, 50.55521106719971, 49.07269130434309, 50.56492117473057, 51.66103771754673, 51.73360817773001, 49.204008783612935, 48.463744231632774, 47.90726300648281, 47.98270307268415, 48.938003948756624, 47.309690134865896, 45.517468316214426, 45.221006052834646, 45.74213136945452, 46.131074156079976, 48.140625204358784, 50.5980223928179, 50.461472920009065, 51.39295537131173, 51.88556528091431, 51.18110479627337, 50.648858887808665, 51.96033137185233, 51.48256976263863, 52.2894675391061, 52.539884090423584, 51.449576241629465, 51.82169049126761, 56.770152364458355, 58.815952164786204, 60.86319024222237, 58.29756096431187, 62.645597730364116, 62.78660447256905, 71.30681909833635, 69.65278652736119, 79.09703513554165, 46.948039872305735, 0.21007726447922842, 0.2832601975117411, 1.2519992696387428, 1.1752890944480896, 0.7636433403406824, 1.3797105252742767, 3.135324239730835, 0.5117892175912857, 0.10900200278099094, 0.05133749810712678, 17.596245186669485, 28.650318452290126, 51.89789833341326, 41.874708448137554, 11.520535366875784, 27.828047786440166, 47.8341714314052, 49.95333726065499, 40.825096198490684, 47.2404339654105, 35.16457598549979, 22.555047716413224, 2.3947435447147916, 0.08974882268479892, 0.05743391133312668, 0.038430615328252316, 0.03391246437760336, 0.02943034702911973, 0.061263115145266056, 0.041986047223742516, 0.040819981401520114, 0.028920204046049287, 0.04649811510794929, 0.023691189275788407, 0.038533803541213274, 0.027750243432819843, 0.017332846265552298, 0.02266901867863323, 0.02492481343714254, 0.04836834082379937, 0.06758580622928483, 0.03484286820249898, 0.08943183148013693, 0.014493021149454373, 0.035599617952747006, 0.02275442418509296, 0.01999549231758075, 0.019044286305350915, 0.10240515640803746, 0.10439934368644442, 0.13559691820825848, 0.12006431525307042, 0.2187167794576713, 22.147643566131592, 96.78546033586774, 69.88326522282192, 77.30572700500488, 51.28819043295724, 39.239479064941406, 28.389120033809117, 52.61163813727242, 74.0275877543858, 65.55722645350865, 5.435093292168208, 0.13795633374580316, 1.2018130826098579, 4.326924230371203, 3.441915891000203, 1.4677249853100096, 2.5955899102347235, 2.6765383780002594, 0.5739589844431195, 70.43188803536552, 96.72896453312465, 88.95659841809953, 91.25196361541748, 82.42243603297642, 84.52522495814732, 69.22957175118583, 65.57765415736607, 62.846942629132954, 66.85937445504325, 64.5364943913051, 64.22393662588937, 64.77912548610142, 64.76158823285783, 62.43011324746268, 62.06756319318499, 63.36929430280413, 64.80222824641636, 62.94270965031215, 58.477387292044504, 57.47403267451695, 59.54696519034249, 57.32648420333862, 60.2738162449428, 57.86762728009905, 53.075447763715474, 53.3349039213998, 56.645932470049175, 57.10118886402675, 56.120547907693044, 54.512734753744944, 56.694288458142964, 56.758878912244526, 56.38226917811802, 64.55443464006696, 72.65487384796143, 74.67276968274797, 72.84894398280552, 69.40396458762032, 64.74044486454555, 60.75099767957415, 57.134342193603516, 53.959894384656636, 51.88953617640904, 56.131491320473806, 60.705007553100586, 63.42879172733852, 63.875338554382324, 65.36683886391776, 65.11131191253662, 57.07160690852574, 62.91774477277483, 70.26156684330532, 70.93964849199567, 52.85418585368565, 63.37480422428676, 71.90254374912807, 58.679392269679475, 61.921595437186106, 69.7995046888079, 68.49040154048375, 67.76339067731584, 63.58839184897286, 58.73510292598179, 54.11073630196707, 52.686244419642854, 53.23731647218977, 52.34639760426113, 54.46599422182356, 53.20588282176426, 53.36789396830967, 52.25101620810372, 52.291923727308, 51.07205629348755, 51.022143908909385, 51.777465207236155, 51.32537719181606, 49.91494498934065, 48.27629920414516, 49.850337164742605, 51.35236399514334, 51.81149748393467, 52.99050951004028, 53.31989581244332, 52.542302063533235, 52.90178796223232, 53.4942295891898, 53.95911271231515, 55.48514209474836, 53.84889343806675, 55.70272840772356, 54.8274290902274, 53.80211121695382, 55.26344244820731, 60.197698729378835, 61.19607148851667, 63.65145369938442, 60.70397227151053, 65.14640031542096, 66.22142560141427, 72.22487762996128, 72.23152705601284, 81.49075208391461, 55.78810092381069, 1.5415353732449668, 0.425463929772377, 0.910324209502765, 1.296277533684458, 1.33169358755861, 1.850956461259297, 3.8415317620549883, 1.8235940209456851, 0.1888772520635809, 0.3003643554236208, 17.063535485948833, 37.26386649268014, 49.289659227643696, 22.53030170713152, 17.532778603690012, 41.19901697976248, 52.02541862215315, 60.68676158360073, 54.83842461449759, 61.310063634599956, 46.6523870740618, 30.672311987195695, 3.4191127717494965, 0.027982989425903985, 0.07263879544500794, 0.040843367110937834, 0.021184419680918967, 0.05261000571772456, 0.013096903966340636, 0.04200679682461279, 0.034052364727748294, 0.06952920516154595, 0.034054213735674105, 0.040656440891325474, 0.05400658006380711, 0.07388358150741883, 0.01627321375001754, 0.031119081590856825, 0.23634463069694384, 0.09766158594616822, 0.16557656308369978, 0.077225719312472, 0.15264232855822357, 0.08761367654161793, 0.18683602873768124, 0.17523340561560222, 0.15548578383667128, 0.16130579582282475, 0.18666358584804194, 0.20152865962258407, 0.27554826704519136, 0.2873111329972744, 0.483057113630431, 27.330379588263376, 117.57738876342773, 84.9650320325579, 94.11569840567452, 61.7879398890904, 44.35778270448957, 33.05878891263689, 81.18405164991105, 96.44934817722866, 80.6549185344151, 9.68905622618539, 0.23277879346694264, 1.7609751181943076, 7.790447064808436, 9.226074303899493, 2.9323521597044806, 5.2620649082320075, 11.02388334274292, 0.42633286171725815, 68.26017992837089, 101.28574602944511, 93.96694442204067, 97.01608494349888, 87.26289163316999, 89.60886056082589, 72.3125638961792, 70.81139864240373, 67.70894459315709, 70.9304838180542, 68.49060998644147, 68.7717410496303, 66.27088287898472, 68.00864124298096, 68.02642863137382, 67.21733175005231, 69.241119657244, 68.78973688398088, 67.04805973597935, 62.84911741529192, 62.07435853140694, 62.20599215371268, 59.40128925868443, 63.35664163316999, 61.35243374960763, 55.82439136505127, 55.84738295418875, 60.80837590353829, 59.74683012281145, 61.29147025517055, 58.89707933153425, 59.34500190189907, 61.63728209904262, 59.218926838466096, 68.82916791098458, 78.42890330723354, 77.55243669237409, 76.26217705862862, 73.04984419686454, 69.27073287963867, 63.130033084324424, 59.97517572130476, 57.382455417088096, 57.15314401899065, 58.72500024523054, 65.73610087803432, 66.04514285496303, 68.19956384386334, 68.40584891183036, 69.1545659473964, 62.06937667301723, 64.90231704711914, 72.48905508858817, 75.4589375087193, 57.31850419725691, 65.40979957580566, 75.41731779915946, 61.87199224744524, 65.73716395241874, 73.3205738067627, 70.50367682320731, 71.164596421378, 68.16137654440743, 63.631338664463584, 58.51647090911865, 56.335038798195974, 57.52771793093, 56.18926559175764, 56.255290848868235, 58.41454083578927, 57.983252252851216, 55.080437319619314, 54.97591209411621, 54.09868465151106, 53.77425936290196, 53.23763608932495, 55.84406866346087, 52.80978339059012, 51.26942682266235, 52.27471998759678, 53.048419271196636, 54.3050148827689, 56.47929034914289, 54.52744409016201, 57.366985252925325, 56.16705567496163, 57.056136744362966, 56.22411775588989, 59.12813472747803, 56.26594591140747, 58.943694795881, 58.415680340358186, 56.94212375368391, 58.30213982718331, 63.182429449898855, 64.09175409589494, 67.4563011441912, 62.10905088697161, 70.09422642844063, 69.39639799935478, 75.89678519112724, 74.94793919154576, 85.5722906930106, 54.300738266536165, 1.0820337384939194, 1.0765888478074754, 4.953306070395878, 2.4494297759873525, 2.8959205831800188, 5.025536503110613, 9.574201634952, 1.7429674501929964, 0.25070558009403093, 0.3711032324603626, 27.388322353363037, 43.38296781267439, 73.49171488625663, 56.201386724199565, 15.72181054524013, 39.89255067280361, 64.18151092529297, 76.23758043561662, 68.96256637573242, 77.7277466910226, 58.9738986151559, 34.521151951381135, 3.6654852543558394, 0.18946505337953568, 0.2585478978497641, 0.12345560613487448, 0.09990655976746764, 0.07325282213943345, 0.08702438923397235, 0.15229961409100465, 0.09215942011880023, 0.24111014498131617, 0.09729519739214863, 0.12725070677697659, 0.19083600624331407, 0.18538428949458258, 0.0926137196698359, 0.11874277330935001], [0.048842226288148334, 0.02278059528076223, 0.1185696247432913, 0.024493444977062087, 0.08128764027995722, 0.035636727032916884, 0.07797316634761435, 0.009341289821480001, 0.030265521856823137, 0.099195197224617, 0.02419180393085948, 0.03523493930697441, 0.026034428538488488, 0.05679188149848154, 0.7663955326591219, 44.55124487195696, 69.95009299686977, 65.91513511112758, 60.14202281406948, 55.63768284661429, 32.12236976623535, 44.33676092965262, 83.76892048971993, 53.58590064729963, 32.69788210732596, 0.3107811436057091, 0.03024182402129684, 0.525557778775692, 1.2828059537070138, 3.6009684077330997, 1.2695702867848533, 1.7697599210909434, 2.0002597868442535, 18.97759744099208, 94.48351519448417, 84.3372414452689, 89.96690123421806, 78.79398250579834, 75.87134783608573, 65.33526624952043, 65.56694003513881, 64.13952990940639, 59.851998056684224, 58.76520252227783, 58.32744516645159, 59.61508532932827, 55.783080850328716, 58.717072350638254, 56.94471195765904, 58.669025557381765, 58.383927072797505, 58.0897090775626, 58.103525570460725, 56.02841132027762, 55.52275616782052, 54.21069656099592, 55.99232585089547, 57.09211104256766, 51.6382406779698, 49.700252601078574, 51.38422495978219, 53.638085092817036, 52.345834800175254, 53.08778429031372, 51.06653594970703, 52.87015281404768, 53.209547996520996, 57.8208589553833, 69.08920424325126, 67.59605721064976, 72.00605801173619, 67.16718660082135, 66.8886194229126, 62.03621292114258, 57.80768864495413, 55.736635616847444, 51.689191818237305, 50.758741174425396, 57.36356673921858, 64.8945072719029, 63.757934842790874, 62.37179701668875, 62.728468894958496, 62.018682616097585, 53.43877601623535, 61.934866496494834, 65.87985910688127, 60.9444911139352, 55.37123680114746, 63.236701829092844, 65.34631388528007, 57.44144909722464, 61.075728688921245, 67.7106191090175, 66.88548578534807, 64.30824606759208, 58.18072700500488, 51.91510902132307, 50.190448011670796, 48.477004868643625, 47.14903736114502, 50.20502880641392, 50.46883801051548, 50.66523231778826, 50.6339237349374, 48.969878809792654, 49.50234011241368, 47.47115237372262, 47.554812158857075, 48.707170895167756, 46.68432446888515, 47.65845843723842, 45.29193326405117, 45.91517278126308, 45.53197268077305, 48.37179177148001, 50.14415563855852, 50.792714391435894, 50.53076383045742, 49.84387534005301, 51.5129577091762, 49.358293533325195, 50.056142807006836, 49.695083141326904, 50.1272610936846, 51.07856328146798, 52.55475670950753, 58.55292810712542, 63.12177862439837, 65.0029547555106, 64.77588067735944, 66.16488810947963, 66.96489674704415, 68.42865289960588, 68.47002247401646, 71.61938381195068, 72.48699147360665, 74.18198367527553, 34.07487262998308, 0.18504177858786924, 0.7022085626210485, 0.4108533337712288, 2.0890143385955264, 0.3316142314246723, 2.060294393982206, 1.497686920421464, 0.08327762742659875, 0.06898621429822274, 1.1270730474165507, 38.09899827412197, 31.36746883392334, 77.12527533939907, 30.63250228336879, 15.97207076208932, 37.26572513580322, 34.26232113157, 45.70853335516793, 51.31945385251726, 40.246762888772146, 40.99492406845093, 23.84542546953474, 3.9722825288772583, 0.07530583840395723, 0.031170870776155164, 0.018229269056714008, 0.044205592945218086, 0.024975908820384314, 0.010085747061696435, 0.05017856029527528, 0.052143933584115336, 0.07015461767358439, 0.05238077623237457, 0.04459347748862846, 0.10354033192353589, 0.06613169889897108, 0.03445041372573801, 0.016958006557875445, 0.03323853321905647, 0.03226650805611696, 0.04792401913021292, 0.03057614161766001, 0.0431658805214933, 0.004034483979921788, 0.034122962903763564, 0.01839301991276443, 0.04871882451698184, 0.013372725906914898, 0.03294104650350554, 0.03423328251977052, 0.04479432385414839, 1.0652208349534442, 60.57452038356236, 84.68627030508858, 77.01696681976318, 71.30237225123814, 69.25014536721366, 40.31333705357143, 37.16089071546282, 49.30957971300398, 54.054640020642964, 37.252881390707834, 0.14751797781458922, 0.06690288108906575, 2.8068409860134125, 4.587155546460833, 6.490855131830488, 1.8737782537937164, 1.096743834870202, 1.1386732820953642, 29.64889097213745, 102.98096057346889, 84.39784363337925, 95.17470114571708, 82.11966133117676, 80.41608115604946, 68.56980555398124, 70.02350071498326, 67.6253855569022, 64.75612694876534, 62.44906793321882, 62.22821944100516, 62.26652485983712, 62.42355414799282, 62.46570192064558, 62.38645076751709, 62.355670247759136, 62.026770319257466, 61.67266927446638, 61.268728801182334, 58.85286794389997, 59.24225888933454, 56.37952463967459, 57.75160278592791, 59.15402371542794, 56.04954774039132, 51.81981100354876, 54.86059979030064, 55.54722077505929, 54.928570543016704, 54.65086146763393, 54.63022531781878, 54.979344504220144, 56.4460779598781, 62.258145332336426, 71.42136015210832, 69.39180524008614, 72.05963557107108, 69.69163390568325, 68.43267590659005, 64.86016927446637, 60.72032138279506, 58.94099889482771, 54.99997023173741, 53.87401465007237, 60.496380942208425, 68.9501291002546, 69.27774361201695, 65.47687748500279, 66.00846331460136, 63.531833512442454, 57.058012757982524, 65.39582674843925, 69.28401783534459, 61.85825565883091, 60.13128784724644, 67.90449469430106, 70.62770216805595, 60.68305819375174, 63.3134377343314, 70.38418865203857, 68.85548768724713, 66.81656660352434, 61.33750901903425, 55.0648455619812, 51.510564054761616, 51.57448053359985, 49.59691204343523, 51.226420947483604, 52.46394722802298, 53.97592735290527, 53.36767510005406, 51.733132226126536, 52.54093674251011, 50.62119116101946, 50.30066728591919, 51.626970699855256, 50.426203863961355, 50.532563413892476, 48.438379832676475, 48.51178755078997, 48.46748236247471, 50.15827785219465, 52.47871215002877, 51.683994565691265, 52.08437756129673, 52.34388583047049, 52.921934264046804, 52.75909628186907, 52.349447863442556, 52.378741468702046, 51.67011553900582, 54.53654970441546, 55.75259215491158, 63.474337169102256, 65.17264366149902, 67.38274751390729, 68.27572999681745, 69.67791816166469, 70.08012158530099, 71.99876240321568, 71.60841260637555, 72.228942326137, 76.42012350899833, 75.73376655578613, 43.945678097861155, 0.49165203528744833, 0.8436245971492359, 0.5645136141351291, 1.7888521594660622, 2.2217166806970323, 3.7679933309555054, 2.0959073858601704, 0.9433390093701226, 0.0683390140267355, 0.5182092988065311, 37.85434872763497, 38.92948171070644, 54.49390513556344, 25.93255489213126, 25.42463115283421, 50.542784214019775, 47.500317437308176, 56.99785525458199, 64.53077602386475, 53.55326495851789, 57.00511612210955, 32.682641233716694, 5.095532221453531, 0.01627319848297962, 0.06371324402945382, 0.04549455503001809, 0.0415721306843417, 0.0340943321186517, 0.06284014587955815, 0.035065213950084786, 0.03114606692854847, 0.05073389031791261, 0.029642613139003515, 0.011858981285643364, 0.06162775307893753, 0.023314641356202107, 0.055944415008915324, 0.11717321324561324, 0.10230208693870477, 0.15823754189269884, 0.15263305976986885, 0.17075196680213722, 0.11094656200813395, 0.10511541526232447, 0.11293946007000548, 0.13222776113876275, 0.14831786203597272, 0.11720519938639232, 0.1321776716836861, 0.1450804764670985, 0.19553321919270925, 1.217281726854188, 75.72777720860073, 102.10470935276577, 91.24266692570278, 84.345614024571, 78.75940132141113, 46.282854080200195, 62.158758299691335, 102.87613310132707, 71.55652345929826, 47.82232822690691, 0.8915529996156693, 0.13145875026072773, 3.215822377375194, 8.373591133526393, 10.299966164997645, 3.481577077082225, 11.269076585769653, 2.7514840364456177, 28.893606151853287, 111.91973468235561, 89.67267976488385, 101.61725153241838, 86.89866011483329, 85.84219346727643, 73.32978016989571, 72.78742463248116, 71.97656985691616, 68.4927430834089, 65.64774758475167, 67.2667542866298, 68.08989347730363, 64.64889539991105, 66.61471448625836, 66.76443426949638, 67.20479025159563, 66.56057412283761, 65.4095355442592, 64.56153569902692, 62.28112302507673, 62.55013642992292, 58.89943477085659, 62.78844574519566, 63.71506445748465, 59.00062138693673, 56.16663530894688, 59.502823284694124, 59.77288586752755, 59.387941769191194, 58.04394824164254, 56.165381159101216, 59.030484744480674, 59.49026094164167, 63.18511145455496, 75.38436944144112, 71.60970497131348, 77.4527369907924, 72.88234397343227, 71.87163816179547, 68.92982646397182, 64.01499039786202, 63.55183737618582, 57.684705529894146, 56.356915201459614, 64.47459983825684, 72.20879255022321, 70.22435923985073, 69.09647900717599, 69.05500520978654, 69.46033532278878, 60.56960800715855, 69.45372063773019, 73.36615398951939, 64.54038538251604, 60.2861909866333, 70.69631562914167, 73.61279419490269, 63.752577781677246, 69.25185462406704, 74.18127495901925, 71.7400323322841, 73.17177118573869, 64.24224512917655, 58.34356498718262, 55.53277547018868, 54.63216386522566, 52.053833280290874, 55.65318080357143, 55.97207185200283, 57.01244299752371, 56.34051397868565, 54.0616820199149, 56.2136607170105, 52.53309222630092, 53.85180820737566, 54.96521534238543, 53.714581285204204, 51.71085977554321, 51.526871476854595, 51.64312178747994, 52.6089630808149, 54.23299333027431, 54.76621893474034, 55.48731688090733, 55.48923805781773, 54.40164695467268, 57.864973068237305, 54.2255448613848, 55.69107627868652, 53.433085441589355, 55.03799424852644, 56.887590817042756, 57.5226457459586, 65.80066353934151, 68.7240069253104, 70.96054172515869, 70.30674403054374, 71.47188745226178, 74.30482782636369, 74.00531877790178, 74.66679423195976, 76.78140899113247, 77.74755600520542, 79.3614627293178, 40.99710232870919, 0.3411951730293887, 2.630068608692714, 5.160612089293344, 5.123215581689562, 2.763336794716971, 8.107792139053345, 4.893096021243504, 1.1391635643584388, 0.16161340288817883, 2.052640518971852, 55.31766619001116, 42.75997148241316, 105.0310057231358, 42.49698911394392, 22.88204904964992, 54.62938805988857, 54.74798338753836, 69.26274939945766, 76.51070022583008, 69.08430576324463, 67.62073721204484, 36.790242535727366, 5.485308357647487, 0.21027669949190958, 0.17941706255078316, 0.1218874981360776, 0.15762669752751077, 0.15542634416903767, 0.09208562943552222, 0.13936589525214263, 0.23359892517328262, 0.1524936615356377, 0.10449683559792382, 0.16306420575295175, 0.18306568105305943, 0.11016721025641475, 0.0949157854276044], [0.055930477899632285, 0.017012421673695956, 0.058588974710021696, 0.034939406772277186, 0.04226258756326778, 0.016916317366329685, 0.037484120045389445, 0.03061456705576607, 0.032653374796999354, 0.08001331080283437, 0.06557014331753765, 0.08340879503105368, 0.07763774613184588, 0.4721849741680281, 13.543429562023707, 80.29996286119733, 63.539226395743235, 60.28432886941092, 46.01875305175781, 30.449045521872385, 19.01073340007237, 65.65212494986397, 75.7610729762486, 40.80102069037301, 14.3478615965162, 0.4809344932436943, 0.970256547842707, 2.1757582553795407, 3.5279254700456346, 2.2136863001755307, 1.4851011271987642, 0.1483999104904277, 0.737347774207592, 62.0389644077846, 86.41603824070522, 82.61892414093018, 83.56349005017961, 70.46887329646519, 67.77844742366246, 66.08515058244977, 64.91363566262382, 61.8893210547311, 63.60565117427281, 59.843826975141255, 56.32144117355347, 55.977394172123496, 56.52182027271816, 55.41100481578282, 55.8620297568185, 54.605725969587056, 56.66836125510079, 56.93939658573696, 56.6180146081107, 54.58880363191877, 57.013335841042654, 54.84438616888863, 56.47560085569109, 53.27200535365513, 49.77564402988979, 49.259934834071565, 53.247123854500906, 52.975734165736604, 52.07465008326939, 50.778849261147634, 50.40680796759469, 52.73644168036324, 58.92196083068848, 67.22539166041783, 68.7665160042899, 69.71798147474016, 71.17071083613804, 69.68319184439522, 67.75153010232108, 62.205443246024, 59.414699281964985, 55.54684904643467, 51.84855917521885, 50.16351331983294, 58.41327626364571, 64.33417674473354, 66.50448826381138, 64.95041247776577, 65.60301508222307, 58.130623544965474, 55.48506219046456, 60.320049558367046, 65.90878445761544, 56.772587708064485, 65.09186390468052, 63.77815410069057, 67.51685469491142, 56.46645702634539, 61.281166076660156, 66.75911889757428, 64.79154191698346, 61.41949776240757, 56.97592673982893, 51.9494435446603, 50.100468839917866, 48.95212268829346, 47.031915051596506, 48.81885276521955, 48.33904838562012, 48.62906619480678, 47.41955157688686, 48.768860476357595, 47.5229685647147, 49.65625660760062, 47.79980216707502, 50.36228391102382, 50.45287799835205, 48.436007022857666, 46.36498873574393, 47.08936275754656, 46.08085257666451, 47.45159666878836, 49.041070052555625, 50.37895611354283, 49.51547915594918, 51.09533970696585, 49.75620297023228, 51.77956356321062, 49.011057308741975, 50.27053989682879, 52.033596651894705, 52.07754748208182, 57.52494559969221, 65.84538909367153, 67.98421832493374, 70.99241311209542, 68.34205055236816, 70.44859845297677, 68.81748798915318, 73.42976474761963, 69.48853806086949, 70.82770606449672, 77.58897032056535, 73.45765481676374, 72.84597710200718, 44.203730719430105, 0.8692892342805862, 1.2648603852306093, 0.6547621371490615, 0.47015002050570076, 2.444895859275545, 2.5359200835227966, 0.38387993829590933, 0.15555561866079057, 0.168155986815691, 13.147080864225115, 30.469125815800258, 42.55806377955845, 58.82218469892229, 19.54083926337106, 16.09951983179365, 24.342223405838013, 38.63502400262015, 44.17434331348964, 48.45599351610456, 48.655309540884836, 50.34875576836722, 27.888809783118113, 1.1258673178298133, 0.05580529836671693, 0.0086776554318411, 0.021409394751702036, 0.015012629696034958, 0.03995093749836087, 0.046470159465180974, 0.09615941119513341, 0.05999903154692479, 0.017530277903590883, 0.05502802971750498, 0.04813564741717918, 0.049532486391919, 0.011111207705523287, 0.011184607382996805, 0.0420425861541714, 0.07210987061262131, 0.053156443538942506, 0.052681268858058114, 0.03203239311863269, 0.022224900545552373, 0.02821165742352605, 0.03460619518799441, 0.06830890064260789, 0.06775391328015498, 0.11196544340678624, 0.07946759901408638, 0.24263334753257887, 17.367065804345266, 97.14824662889752, 73.79926300048828, 70.74024908883231, 56.52873373031616, 45.27702590397426, 26.215450797762188, 58.27835266930716, 70.95710236685616, 50.49442475182669, 15.273641313825335, 0.6236418613365718, 0.9490970032555717, 6.337367253644126, 7.32294533933912, 3.3362481210912978, 1.923725813627243, 0.9018555496420179, 2.511575332709721, 76.70217173440116, 89.87070342472622, 87.12488651275635, 86.19779532296317, 74.49834210532052, 71.02090072631836, 69.26907226017543, 66.71981988634381, 65.46020180838448, 66.98401818956647, 61.52268545968192, 62.49207033429827, 61.425313404628206, 59.469159262520925, 59.26244340624128, 58.94966329847063, 57.817106928144185, 59.70348726000105, 60.41171019417899, 60.255528586251394, 57.90015179770333, 58.6464022227696, 56.74558006014143, 58.17077718462263, 54.99649265834263, 53.89499820981707, 52.43149219240461, 54.887256554194856, 54.04672602244786, 54.63319219861712, 52.89008719580514, 53.60616159439087, 56.0153626033238, 62.62585094996861, 70.31162166595459, 70.76565170288086, 71.46166665213448, 72.06820964813232, 69.26361792428153, 69.97022192818778, 66.34859848022461, 63.67103372301374, 58.50176157270159, 55.70187030519758, 52.958037103925435, 60.43274933951241, 67.12651879446847, 69.90027441297258, 68.1607859475272, 68.94811412266323, 59.969665799822124, 57.67645801816668, 65.34092208317348, 70.85424818311418, 62.088921955653596, 68.3153555733817, 68.15526212964738, 67.84388555799211, 59.76297773633684, 63.68121978214809, 70.38613414764404, 67.2677617754255, 65.84686211177281, 60.899105480739046, 56.98305211748396, 53.929287569863455, 52.48419080461775, 48.71086038861956, 51.527316161564414, 51.4507782799857, 51.92422505787441, 49.30751609802246, 50.92789854322161, 50.79500729697091, 52.3147485596793, 51.07096890040806, 53.542484828404014, 52.33654505865914, 51.2570138658796, 50.885097639901296, 49.19494833265032, 49.51702513013567, 48.943579878125874, 49.668964862823486, 52.17628485815865, 51.39952836717878, 52.986410072871614, 50.100552218300955, 52.93635525022234, 53.95267520632063, 52.843867778778076, 53.53361545290266, 55.517162867954795, 59.331098556518555, 69.77855587005615, 70.86159937722343, 74.69034167698452, 72.8727137701852, 74.90278284890312, 71.11301299503872, 76.56568826947893, 71.78102670397077, 74.25912952423096, 78.31604371752057, 77.57375376565116, 74.87730380467006, 58.20813764844622, 3.059907406568527, 0.36476568824478556, 0.6277453154325485, 1.0233150550297327, 4.65055525302887, 3.490842282772064, 1.7066174064363753, 0.625077098608017, 0.22547896445861884, 12.130152940750122, 35.50253636496407, 46.97820895058768, 43.4515117917742, 21.119426556995936, 30.703700474330358, 32.00265577861241, 49.20846257890974, 52.75866549355643, 62.864125524248394, 60.604300362723215, 67.24205344063895, 35.81936379841396, 1.423448241182736, 0.051480970944144895, 0.006570486559732152, 0.03890162041144712, 0.029445776915443794, 0.058479533796863895, 0.03694997049335923, 0.09829803822296006, 0.0035193836624135394, 0.02192760381980666, 0.02925527820895825, 0.03021133065755878, 0.01642794517933258, 0.011876814034102219, 0.14156057605785982, 0.07898878399282694, 0.13392819703689643, 0.18318004134510243, 0.20751607976853848, 0.12052309992057936, 0.16142825782299042, 0.19511374884418078, 0.19961341310824665, 0.13159288306321415, 0.20337739613439354, 0.18565810551600798, 0.2903602793812752, 0.4981625516499792, 20.88836247580392, 112.59629467555455, 86.97767502920968, 84.9199938092913, 68.08281326293945, 47.43824570519583, 29.92017991202218, 92.10945469992501, 98.31136117662702, 63.43048013959612, 23.32866014753069, 0.8499959324087415, 3.830144967351641, 7.485778110367911, 12.258380208696638, 7.024015596934727, 6.532565167972019, 4.188433604581015, 1.8959940331322807, 83.86245713915143, 94.25988047463554, 95.17042105538505, 88.26497473035539, 80.02990027836391, 74.55299663543701, 72.68341704777309, 70.30095618111747, 68.80670438494, 71.1644366128104, 66.33295808519635, 64.17476422446114, 64.66494573865617, 61.01507786342076, 62.44695568084717, 62.195305824279785, 62.422838483537944, 64.64267676217216, 64.4350437436785, 63.34816483088902, 62.42658356257847, 64.39491789681571, 59.526183128356934, 60.84326975686209, 58.317794118608745, 58.200536319187705, 56.50058657782418, 59.78895705086844, 58.368043490818565, 58.84812927246094, 57.46324559620449, 56.157818044934956, 57.71289784567696, 65.23854037693569, 73.05043479374477, 74.60491357530866, 75.9859653200422, 76.03840337480817, 72.46292986188615, 72.58656610761369, 69.56409277234758, 65.22587381090436, 61.86526639120919, 58.50534684317452, 56.430576528821675, 63.75381456102644, 67.83808381216866, 72.0158132825579, 71.93255996704102, 73.45818287985665, 63.97389875139509, 61.46827411651611, 66.8396554674421, 72.67985262189592, 62.28012943267822, 63.27827984946114, 68.89612770080566, 73.16578878675188, 61.37119388580322, 68.07651819501604, 73.76261125292096, 69.60280118669782, 68.89129870278495, 62.62519087110247, 60.23088332584926, 56.276941435677664, 54.79393877301897, 52.84867245810372, 54.44581317901611, 55.2501540184021, 55.33649580819266, 53.72591379710606, 54.75132199696132, 53.90925243922642, 55.758109024592805, 54.08872093473162, 56.22558729989188, 56.246251242501394, 55.42125340870449, 54.49362025942121, 52.372686113630024, 51.98869044440133, 52.17763975688389, 53.69441066469465, 56.54654891150338, 55.1806755065918, 56.831577914101736, 54.75070013318743, 56.17094666617257, 56.045052255902974, 55.45724507740566, 55.31796843664986, 58.46715954371861, 63.29794325147356, 73.0777690070016, 73.9931663785662, 76.65685558319092, 75.34951727730888, 77.45027038029262, 74.30206939152309, 79.28772149767194, 75.78957448686872, 76.06996209280831, 80.26292201450893, 79.10202394212995, 78.76735006059918, 51.744329248155864, 1.3702311196497508, 2.838260522910527, 5.811131971223014, 4.728833224092211, 9.788958294051033, 10.503071563584463, 1.700225172298295, 0.681741720863751, 0.23498465652976716, 20.835163593292236, 45.929246357509065, 58.41178240094866, 77.78788334982735, 26.496034690311976, 25.17247234072004, 36.17555625098092, 61.55878135136196, 67.45910821642194, 74.26998955862862, 75.49986934661865, 78.39178603036063, 38.10767657416207, 1.824436055762427, 0.2584196004484381, 0.13240966280656202, 0.19134783877858094, 0.09671893795686108, 0.1894097663462162, 0.25628693774342537, 0.17907521660838807, 0.11898943435932909, 0.09221052737640482, 0.26871924634490696, 0.1397825021828924, 0.08729635964014701, 0.058885657361575534], [0.061369238022182665, 0.018363054110003368, 0.057083522634846826, 0.08535568163331066, 0.0494947327034814, 0.055894390014665465, 0.10896053072065115, 0.032325655953692536, 0.0553118677011558, 0.0779463845704283, 0.09602153287934405, 0.03285067920972194, 0.01793684421240219, 0.1263986025005579, 33.57201412745884, 73.33850710732597, 60.570281982421875, 51.5600699697222, 31.999386651175364, 25.340919256210327, 38.717523438589915, 68.71199348994664, 46.70638499941145, 34.5235629762922, 1.8582833366734641, 0.1780620009771415, 1.2265634345156806, 3.074442603758403, 3.045959983553205, 2.779258591788156, 0.8136560938188008, 0.8179772762315614, 15.27465227672032, 90.14546993800572, 79.0867587498256, 84.87869371686662, 73.26891395023891, 68.3498603275844, 65.473952293396, 65.38215964181083, 63.0775602885655, 61.974380901881624, 59.818563325064524, 58.698360851832796, 57.99555056435721, 56.89350373404366, 55.43280478886196, 55.418755531311035, 54.20893171855381, 54.13601732254028, 54.192158767155235, 53.986415658678325, 54.23781885419573, 54.2170124735151, 55.459718636104036, 53.350068364824565, 55.38681813648769, 48.735168661390034, 47.09989970070975, 50.818287236349924, 51.93017271586827, 51.56392969403948, 52.946749755314414, 50.2418646812439, 49.72228881290981, 56.42910351072039, 64.93674537113735, 64.63512407030377, 66.93875762394497, 67.51540946960449, 70.08228247506278, 68.72028963906425, 62.30871432168143, 60.25553553444998, 58.7249516078404, 56.072303090776714, 53.87985461098807, 49.186214447021484, 55.582034724099294, 65.39694540841239, 66.66883400508335, 62.39667851584298, 65.22397000449044, 57.980069977896555, 58.1831762450082, 62.18716948372977, 68.15398366110665, 49.96014996937343, 71.4351384299142, 61.76159232003348, 64.04686873299735, 57.05776957103184, 56.73619304384504, 64.011627469744, 62.698230334690635, 63.18035888671875, 58.723881585257395, 57.869562353406636, 55.403764792851035, 52.52597032274519, 48.72881800787789, 49.031912326812744, 48.18422515051705, 48.37107263292585, 46.13816131864275, 46.127033778599326, 48.59129926136562, 49.77597406932286, 50.78878518513271, 50.13996240070888, 50.09471920558384, 52.97185012272426, 49.68853793825422, 46.98906551088606, 46.85696983337402, 44.82041113717215, 46.50068358012608, 49.47014563424246, 49.807692595890586, 50.123978069850374, 52.236890520368306, 50.416726521083284, 50.03105286189488, 49.59458439690726, 53.563454491751536, 49.6553498676845, 60.87268842969622, 68.62484918321881, 68.9452931540353, 68.20361464364188, 71.94392721993583, 68.99211011614118, 71.51954514639718, 72.11260168892997, 68.03273064749581, 75.13094779423305, 71.43181024278913, 70.70115157536098, 72.32636301858085, 78.62708677564348, 69.26939187731061, 3.902813136577606, 0.8152567307863916, 2.1511846482753754, 2.259346387216023, 1.3504193084580558, 1.5754171780177524, 0.4403722126569067, 0.030030982834952216, 0.5613866533551897, 26.04903449331011, 29.929792744772776, 62.83941773005894, 37.410595076424734, 15.294854164123535, 23.268097911562236, 31.429550988333567, 35.341470173427034, 44.315131187438965, 54.2975629397801, 51.941970757075715, 58.66289029802595, 12.309503316879272, 0.05426584150908249, 0.07284047640860081, 0.12889235440109456, 0.01470609471601035, 0.033498005010187626, 0.07232115284672805, 0.03077352066923465, 0.032487754576972554, 0.06454854777881078, 0.06264516205659934, 0.013599491461978426, 0.06761826055922679, 0.057836574369243214, 0.0187313289913748, 0.027470788785389492, 0.030130591775689806, 0.04381415966366019, 0.03869038906746677, 0.03874650391350899, 0.048011539969593287, 0.028710054965423684, 0.06350803468376398, 0.042897309575762065, 0.05765811287398849, 0.006070154344862593, 0.05731180217117071, 0.1081273372152022, 43.46875722067696, 88.39423206874302, 67.89276613507951, 63.16191141945975, 38.55110018593924, 34.158087730407715, 40.30602060045515, 59.044061524527415, 55.012522152491975, 42.50561877659389, 1.5486736702067512, 0.41082247399858063, 3.3487333825656345, 5.549068936279841, 4.643590552466256, 2.9288183493273596, 2.4167999497481754, 0.6783477972660745, 23.594951595578873, 98.43828392028809, 80.97161742619106, 88.7683230808803, 76.71905585697719, 72.94136892046247, 68.03075735909599, 67.43125288827079, 66.35038416726249, 66.47140094212124, 63.4721554347447, 62.5594539642334, 61.878030232020784, 61.640936851501465, 60.77574021475655, 59.6575596673148, 58.25631298337664, 58.162376812526155, 58.4690841947283, 57.95862088884626, 59.58791787283761, 56.9350574357169, 57.68127659388951, 55.31199298586164, 58.380564144679475, 53.61767475945609, 50.29869052342006, 51.98660945892334, 53.47826262882778, 53.1795699937003, 53.29069600786482, 52.7817508833749, 52.20396300724575, 59.242036546979634, 66.81080654689244, 69.53863457271031, 69.56556579044887, 69.36948762621198, 70.25462559291294, 69.9428460257394, 65.76952171325684, 62.885838644845144, 62.11794458116804, 59.17807143075125, 57.010695525578086, 52.793135506766184, 58.391695158822195, 69.95373385293144, 70.83892740522111, 66.18362740107945, 69.66525854383195, 63.68097659519741, 58.84990106310163, 65.76746504647392, 68.31951059613908, 59.26575074877058, 77.43014144897461, 69.75197901044572, 66.93663842337472, 59.457222257341655, 60.336058207920615, 67.6477518081665, 65.62945992606026, 68.74965272630963, 65.29598113468715, 62.24616663796561, 59.14684622628348, 57.66640397480556, 53.328681809561594, 49.450485706329346, 50.53490148271833, 51.91578299658639, 50.978394576481406, 49.489510263715474, 51.07160813467843, 51.98407336643764, 54.96391255514962, 53.80644689287458, 53.45202970504761, 54.20562437602452, 51.98015110833304, 49.70585979734148, 48.325513294764924, 47.330597264426096, 49.91505963461739, 50.802653789520264, 51.88859469549996, 52.1467411177499, 53.89826038905552, 52.03807476588658, 53.9124972479684, 52.03173106057303, 54.611333165849956, 52.127102034432546, 63.000608989170615, 71.26337896074567, 72.1198069708688, 70.25899600982666, 72.7299143927438, 72.63430718013218, 73.21589919498989, 74.24068205697196, 69.45912633623395, 75.65175696781704, 74.12637029375348, 72.46685559409005, 75.498521396092, 77.15754972185407, 80.26073333195278, 10.061028906277247, 0.7844631288732801, 1.8665278085640498, 0.5426708662084171, 2.8682482966354916, 2.822221257856914, 1.1157671340874262, 0.06523337281708207, 0.37563647063715117, 26.19489107813154, 38.91533865247454, 50.00011600766863, 31.111132417406353, 24.667442526136124, 36.21367754255022, 44.1315597806658, 49.89509398596627, 56.0883013180324, 63.71097891671317, 60.6799384525844, 72.49783761160714, 17.434374741145543, 0.13561264664999076, 0.04840408604858177, 0.03018696785771421, 0.04071550057934863, 0.02755523586113538, 0.06501090154051781, 0.002352610255392002, 0.06845608167350292, 0.07664439122059516, 0.03526217570262296, 0.043659870978444815, 0.06488851417920419, 0.02184059697070292, 0.1082628338730761, 0.0805700487856354, 0.2054732008171933, 0.17096004635095596, 0.20685190255088465, 0.14066482840904168, 0.16022406172539505, 0.09949368477932044, 0.16066585587603704, 0.11505376840276377, 0.12971659802964755, 0.10111212650580065, 0.20798292543206895, 0.3401009131755148, 49.6301383290972, 103.01725101470947, 81.38838427407401, 75.15093081338065, 51.05407435553414, 41.19350011008126, 57.07284368787493, 89.55880573817662, 62.10561152866909, 54.64783900124686, 2.8674822577408383, 0.3988875315657684, 5.819635697773524, 10.296133364949908, 8.898387704576765, 9.161152941840035, 7.585267628942217, 1.0003469160624912, 24.39294351850237, 105.46311419350761, 86.60723182133266, 94.34403010777065, 82.01616096496582, 77.17110565730503, 72.51318618229458, 73.12200123923165, 69.01567840576172, 68.52412809644426, 66.41214670453752, 65.55407197134835, 66.09431525639125, 65.10160527910504, 63.6287191935948, 62.80571896689278, 61.854399408612935, 61.05166012900216, 62.701634952000205, 61.54164709363665, 62.02960518428257, 60.16067177908761, 60.10136195591518, 58.476949555533274, 62.46228340693882, 56.163355759211946, 53.73386253629412, 55.433659417288645, 57.682252815791536, 57.13789619718279, 58.30077798025948, 56.61890745162964, 55.68187338965279, 63.755190304347444, 71.23605864388603, 72.22957461220878, 71.35660294124058, 72.0879772731236, 74.56573268345424, 72.93758215223039, 68.08904579707554, 66.24518149239677, 67.58688558850969, 62.68902397155762, 59.28820732661656, 55.746189389910015, 59.75721767970494, 72.57023089272636, 72.91825921194894, 68.04067938668388, 72.54285499027797, 65.57882145472935, 63.7632224219186, 69.10242666516984, 73.85361875806535, 54.03318050929478, 65.18454592568534, 64.72757680075509, 70.57596588134766, 63.58119351523263, 63.37320613861084, 68.70647662026542, 68.56915937151227, 70.64569105420793, 66.80056490216936, 66.14703818729946, 61.220119203839985, 59.79856640951974, 55.50559759140015, 55.288907596043174, 53.312801701681956, 54.52874687739781, 54.09859432492937, 51.264385904584614, 54.68878126144409, 55.06666946411133, 59.954101834978374, 56.76513923917498, 55.28646183013916, 59.40172004699707, 56.18396759033203, 53.824199540274485, 52.79746076038906, 49.74649633680071, 52.16757876532418, 54.247358730861116, 55.66040345600673, 55.28027098519461, 56.96401405334473, 54.87671266283308, 56.95904609135219, 54.20200089045933, 59.80081067766462, 54.31158440453665, 67.82281167166573, 74.88760103498186, 76.83602183205741, 74.6082626070295, 75.17483956473214, 75.53831372942243, 74.95381736755371, 77.90765639713833, 71.39418574741909, 77.44022328513009, 76.45007024492536, 75.46911661965507, 78.25760241917202, 82.56713226863316, 77.13925511496407, 6.68064170224326, 3.674224785396031, 8.989679217338562, 4.611364373138972, 6.2181248750005444, 5.728582160813468, 1.4772887464080537, 0.07801467912005526, 1.0903892729963576, 42.59847450256348, 44.696392740522114, 81.31712354932512, 54.06468711580549, 21.737493140356882, 36.30091912405831, 48.529929297310964, 57.154029914310996, 64.55749184744698, 73.20956938607353, 71.53302465166364, 82.2698813847133, 18.71606203487941, 0.24112338998488017, 0.1966962960681745, 0.16421149990388326, 0.0991539287247828, 0.2102654765227011, 0.16697078969861778, 0.1306007020175457, 0.162131505087018, 0.19117330600108418, 0.13639928586781025, 0.10347085672297648, 0.11411660297640733, 0.12229592193450246], [0.008606620448907571, 0.05567886693669217, 0.1140300083373274, 0.05373528479997601, 0.05851941808526005, 0.06262849045119115, 0.037733922712504864, 0.03505020136279719, 0.018931595209453787, 0.14732766231255873, 0.02211847572055246, 0.08245083929172584, 0.05238545133865305, 1.1188857895987374, 61.345513343811035, 69.83940819331578, 64.97646822248186, 48.86255693435669, 46.73131513595581, 49.41671746117728, 50.98441866465977, 77.47727108001709, 55.65148891721453, 18.120479822158813, 0.03451536988307323, 0.11600891500711441, 0.429079354341541, 5.481254083769662, 2.233092401708875, 1.516170865723065, 1.5998175144195557, 0.4383837250726563, 48.38892255510603, 90.8688816343035, 80.5773696899414, 79.91567884172711, 71.03507505144391, 71.10603700365338, 64.41589450836182, 64.76005962916783, 61.370262827192036, 60.482831954956055, 56.244382177080425, 57.59229448863438, 57.46464565822056, 57.67127118791853, 54.736376421792166, 57.56105886186872, 54.727639062064036, 56.144644260406494, 54.614890643528526, 54.29778528213501, 52.29894488198416, 54.17355843952724, 54.05190937859671, 56.492523193359375, 53.50777857644217, 47.47428601128714, 48.76932600566319, 52.44235222680228, 48.33024501800537, 51.270705291203086, 49.95761735098702, 50.0732353755406, 55.35310895102364, 63.50917543683733, 65.38115215301514, 65.73471123831612, 69.48665509905133, 69.70010375976562, 67.61729090554374, 66.52128900800432, 61.04289150238037, 57.60048641477312, 53.66306734085083, 52.085409368787495, 52.25672762734549, 47.48091459274292, 54.09329284940447, 61.98658193860735, 64.63235868726457, 61.64733614240374, 67.07369858877999, 59.34719753265381, 56.79251514162336, 61.531481879098074, 69.8725233078003, 42.11930935723441, 63.77449934823172, 58.65971497126988, 60.909541675022666, 60.06316770826067, 57.518174580165315, 61.47230407169887, 59.33345399584089, 61.25150421687535, 60.2294658933367, 61.36571175711495, 59.12281935555594, 59.14078739711216, 59.06034810202462, 51.75868770054409, 44.66813094275338, 47.28447164808001, 45.351948329380576, 46.85390567779541, 45.8455240385873, 49.112511430467876, 51.23120130811419, 50.52105719702584, 50.97677217211042, 51.41188226427351, 47.472660132816856, 46.44009181431362, 44.923300061907085, 46.23043687002999, 46.31433984211513, 49.508676869528635, 47.2780202456883, 48.482740606580464, 49.71523986543928, 49.72172948292324, 46.6094194139753, 50.15053061076573, 50.693396840776714, 52.245610509599956, 58.93571826389858, 69.49980803898403, 65.56000573294503, 66.29020581926618, 69.64002963474819, 69.64280196598598, 67.62655980246407, 64.53707803998674, 70.76194136483329, 68.30415507725307, 69.09704181126186, 72.62226595197404, 73.04814188820976, 70.25772448948452, 71.97933523995536, 75.87929657527378, 3.9292171597480774, 0.4962455545152937, 3.0662823787757327, 0.521876753440925, 1.5851116521017892, 1.5259743396724974, 0.1520183884671756, 0.05028050678915211, 9.784966553960528, 31.593396459306987, 31.31412056514195, 53.05308151245117, 31.245826721191406, 17.106975623539515, 14.915169852120535, 20.871030194418772, 26.18767363684518, 45.356485503060476, 54.21605709620884, 62.52022443498884, 39.85214342389788, 1.4515614126409804, 0.07293872827930109, 0.0545118308093931, 0.0640146764261382, 0.05203745108363884, 0.06860029072101627, 0.022357325136129345, 0.0547248399151223, 0.06509719083883933, 0.09200034436902829, 0.09047935384192637, 0.061382408386894634, 0.018745135482666746, 0.031023981515318155, 0.03644163580611348, 0.07010066735425166, 0.112405737995037, 0.06908176559954882, 0.07073237667126314, 0.09451233529086624, 0.0712632963966046, 0.04985606277893696, 0.016426733994324292, 0.07989502857838358, 0.007368912354909948, 0.1044412160824452, 1.5873669939381736, 76.84561034611293, 79.42450373513358, 73.08201435634068, 60.901961190359934, 56.914372648511616, 48.278897830418174, 49.9056066104344, 71.84528364453996, 68.45133181980678, 20.495092698505946, 0.04965805947514517, 1.8535622528621127, 2.9751274415424893, 5.164292463234492, 3.7182155677250455, 1.411631743822779, 2.4809585298810686, 0.9235782240118299, 55.53855984551566, 96.57589571816581, 84.78461510794503, 82.89796379634312, 71.67139107840401, 73.54268687111991, 68.24815259660993, 69.82585225786481, 64.16352898733956, 62.937317848205566, 61.17414992196219, 62.329121180943076, 61.31086267743792, 63.537510190691265, 58.38399655478341, 60.79609843662807, 58.609667096819194, 58.831849643162315, 57.665754318237305, 59.57633522578648, 55.07347869873047, 58.86508287702288, 57.428452491760254, 57.29512003489903, 55.264821665627615, 51.87663337162563, 52.30897808074951, 53.52954033442906, 52.67342846734183, 52.395889622824534, 52.866581439971924, 51.37257283074515, 57.823322091783794, 65.10990837642125, 67.82930823734829, 69.45613861083984, 69.94456917898995, 71.10423742021833, 69.04096984863281, 68.66885212489537, 62.90196541377476, 61.37632165636335, 56.21180207388741, 54.580146176474436, 55.4651312828064, 50.766544001443044, 56.354531969342915, 66.21336569104875, 67.47991807120187, 65.8266498020717, 67.41568892342704, 60.888669286455425, 59.653036390032085, 66.93437331063407, 67.96327645438058, 57.17431518009731, 76.59206363133022, 66.01447350638253, 65.85176753997803, 63.68923800332205, 60.17991828918457, 65.08720166342599, 64.1594295501709, 64.15863745553153, 63.02995123182024, 65.07063715798515, 62.55348546164376, 62.19925240107945, 64.21975381033761, 55.747870853969026, 47.30539962223598, 50.07546922138759, 48.28321613584246, 48.27605949129377, 47.10768863133022, 51.25357103347778, 52.915785108293804, 54.265107904161724, 54.42552791322981, 55.850978646959575, 50.85325404575893, 49.26790789195469, 47.64542361668178, 47.445402349744526, 47.242709500449045, 51.67985691343035, 49.73069960730416, 51.06533391135079, 51.77561003821236, 51.68515144075666, 51.087196418217246, 52.64494432721819, 53.66966118131365, 54.08083472933088, 59.145428793770925, 70.88719654083252, 68.31114496503557, 70.23829732622418, 71.2669711794172, 73.09222820826939, 70.2184671674456, 67.16788142068046, 72.14160346984863, 70.39987073625836, 70.5933780670166, 76.89755507877895, 74.56589249202183, 72.92877183641706, 72.15412412370954, 85.19052192143032, 8.670012576239449, 0.7959134344543729, 0.5882068627646991, 3.4253652819565366, 3.0702224416392188, 2.770259154694421, 0.9424173959663936, 0.24704596932445252, 6.889860212802887, 39.28283929824829, 37.529259886060444, 38.43451983588082, 25.634468487330846, 24.792808873312815, 29.75293677193778, 38.25227206093924, 33.77012116568429, 55.431112902505056, 62.28095626831055, 73.26191016605922, 53.69800983156477, 1.8779111291681017, 0.10964654319520507, 0.03533305207799588, 0.030145417765847275, 0.02691790827416948, 0.050421241737369976, 0.019093556429392526, 0.047824013246489425, 0.04733905748331121, 0.11983345049832549, 0.07768725883215666, 0.033578781211482625, 0.023339672513040047, 0.08875987146581922, 0.09263446248535599, 0.1863647047430277, 0.21049330144056252, 0.20103452328060353, 0.2429617584816047, 0.2250413772250925, 0.3607334531843662, 0.09776653495750257, 0.1520692514521735, 0.1092206064079489, 0.13870772985475405, 0.15238865145615169, 2.0337996099676405, 91.74641132354736, 91.74024827139718, 88.21973500932965, 70.28101485116142, 65.42438384464809, 63.309685707092285, 69.3075235911778, 93.29796491350446, 82.01254790169853, 29.80953332356044, 0.14299499908728258, 1.294286983353751, 4.0149171096937994, 14.56361619063786, 7.393439156668527, 8.301142266818456, 6.5780763030052185, 0.9901623768465859, 59.007111004420686, 104.38954108101981, 89.03703771318708, 89.18902955736432, 77.62441308157784, 79.55416406903947, 72.8494234085083, 71.6066060747419, 68.31652287074498, 65.26151806967599, 63.648104667663574, 63.95860576629639, 63.759977613176616, 65.90845094408307, 60.5921688079834, 66.22174521854946, 61.87104729243687, 62.215372221810476, 61.07570784432547, 62.947434425354004, 57.961896964481895, 61.65907164982387, 60.95296791621617, 61.121461732046946, 59.635422706604004, 54.25203834261213, 57.09648840767996, 58.382502692086355, 56.542525904519216, 56.838540009089876, 54.86976793834141, 54.21472651617867, 61.13357244219099, 69.29441234043666, 71.50147983006069, 74.02467645917619, 75.26119872501918, 77.5157779966082, 73.57867853982108, 72.98601804460797, 67.29510988507951, 64.49907834189278, 59.00184426988874, 56.80346202850342, 57.67960555212838, 54.586284909929546, 59.97139590127127, 68.29719298226493, 70.78771223340715, 66.7721745627267, 70.80224091666085, 64.46719305855888, 62.789196150643484, 70.05097389221191, 73.52987439291817, 49.828839438302175, 63.844349588666645, 60.53433200291225, 68.61323179517473, 66.22487885611397, 63.667073249816895, 67.55381911141532, 63.6058874130249, 65.57053225381034, 66.49020971570695, 67.23165198734829, 64.1380638395037, 64.44090802328927, 67.7435952595302, 59.01954133169991, 49.48040464946202, 52.03397185461861, 51.54083388192313, 52.05089766638619, 50.191921029772075, 56.31284277779715, 57.25296531404768, 58.451824869428364, 56.746886321476524, 59.06329413822719, 53.420728070395334, 52.45889241354806, 50.39525311333792, 52.54619652884347, 52.011859212602886, 55.987382207598, 52.725328036717, 53.44963257653372, 54.87385695321219, 54.981206621442524, 54.0536915915353, 54.6911610194615, 56.48895876748221, 57.563539368765696, 62.72464738573347, 73.66284901755196, 71.41769845145089, 72.41019303458077, 74.68759713854108, 76.01552295684814, 72.25228827340263, 69.43209784371513, 73.52652536119733, 73.35070814405168, 72.05259009769985, 79.05238601139614, 78.51458154405866, 75.57832145690918, 77.46233245304653, 84.78761672973633, 5.684992202690669, 3.6358937450817654, 11.109178560120718, 6.4062021885599405, 6.2761584009443006, 4.298969890390124, 0.6197188432727541, 0.24198738219482557, 14.832739898136683, 52.298531464168, 47.04917090279715, 71.5487345286778, 41.908101490565706, 24.45218559673854, 24.591844388416835, 34.81037419182913, 43.818533011845176, 66.90208503178188, 72.06349182128906, 82.2482169015067, 62.59880856105259, 2.1296526151044026, 0.16169558704963752, 0.22882741263934545, 0.21158320509961673, 0.11591439507901669, 0.15752844565681048, 0.07308153954467603, 0.13262876176408359, 0.1652847116014787, 0.31127313577703064, 0.21699241841478006, 0.18755450232752732, 0.16711562978369848], [0.06589839820350919, 0.04261842489774738, 0.014327889474641, 0.020619595257033194, 0.03439472296408244, 0.1885173028068883, 0.07594626689595835, 0.09208493732980319, 0.05095412242891533, 0.09327020230037825, 0.03773300329755459, 0.05144369562289544, 0.37569330473031315, 4.688566676207951, 70.55917208535331, 56.92796679905483, 57.774323395320344, 30.427332401275635, 35.78081519263131, 64.99981416974748, 64.30662713732038, 70.14514977591378, 43.30563088825771, 4.896001236779349, 0.1595330009503024, 0.4011911850954805, 3.5577165228979926, 3.301811328956059, 2.404866852930614, 0.823824619608266, 1.4213166641337531, 1.4228160636765617, 70.59143257141113, 90.08265127454484, 86.18250928606305, 79.85800184522355, 79.31737640925816, 73.3543142591204, 76.25849451337541, 71.26738807133266, 72.75479589189801, 68.76326424734933, 65.87828186580113, 60.942899976457866, 57.705765519823345, 56.76947838919503, 54.89628226416451, 55.11425072806222, 55.32434688295637, 54.63831649507795, 54.31956441061837, 53.2865583556039, 53.398500783102854, 51.35874938964844, 53.667649677821565, 54.51036194392613, 52.05108526774815, 46.89520577022007, 49.21885360990252, 49.9919935635158, 48.38869673865182, 49.73458365031651, 52.37899160385132, 57.77452836717878, 66.0705315726144, 64.78481606074742, 64.65560041155133, 64.56892163412911, 69.77595724378313, 67.74471391950334, 64.5423308781215, 61.265310287475586, 54.09409884044102, 51.814123903002056, 52.773267132895334, 50.38776642935616, 50.43702915736607, 48.21926144191197, 52.21619183676583, 60.806777817862375, 63.04036658150809, 63.667580468314036, 65.92914267948696, 56.861239773886545, 60.969080788748606, 60.71524919782366, 69.47885227203369, 31.549119063786097, 46.532398632594514, 47.94187545776367, 58.91514464787075, 63.53930977412632, 57.4786045891898, 59.68506758553641, 55.716725553785054, 60.97375692640032, 59.703369140625, 65.60517597198486, 60.24473108564104, 62.434296063014436, 59.952851159232004, 56.11434316635132, 45.93577071598598, 47.58989013944353, 48.059664794376914, 47.74139213562012, 44.6133200781686, 48.140882287706646, 48.23436682564871, 49.648658752441406, 52.39255101340157, 52.33162225995745, 48.78152356828962, 48.035175868443076, 45.852281161717, 45.839069162096294, 44.730324268341064, 46.42563261304583, 47.64383942740304, 49.3455296925136, 49.99177469526018, 46.509726660592214, 47.96103858947754, 48.397941316877095, 50.04487977709089, 48.6787805557251, 57.09857981545584, 66.82227802276611, 63.82738903590611, 69.5773846762521, 68.68376295907157, 68.811172076634, 69.57617568969727, 67.61745071411133, 64.55867304120744, 71.20834227970668, 70.16821084703717, 72.52006489889962, 67.16444901057652, 75.78670488085065, 73.04432732718331, 75.15383516039167, 63.39856011526925, 0.5373265615531376, 0.09199349116533995, 2.4113799205848148, 0.3202744184860161, 1.8949376898152488, 0.5990473553538322, 0.04539824716214623, 0.7367465921810695, 21.9530314717974, 27.09111315863473, 52.57856471197945, 68.10158729553223, 31.23185736792428, 18.512875863483973, 12.442158324377877, 17.277678966522217, 31.576213564191544, 54.57670334407261, 55.259308270045686, 61.525909423828125, 7.040969201496669, 0.25549457169004847, 0.0997766542381474, 0.09865428267845086, 0.020384791606505002, 0.08561816611992461, 0.07031507763479437, 0.06401726164455925, 0.06342637299426965, 0.0501460177557809, 0.08612229728272983, 0.03839705159355487, 0.008125114188130413, 0.0760392669056143, 0.005887094926687756, 0.010069457980405008, 0.11256110215825693, 0.06896551219480378, 0.042494521010667086, 0.09348527075988905, 0.13587130419909954, 0.10903250971542937, 0.08154838771692344, 0.09124417815889631, 0.06313124418790851, 0.3136145701365811, 6.657439061573573, 88.99330575125558, 66.77572509220668, 66.40016801016671, 40.465335845947266, 51.59802450452532, 60.39780684879848, 56.763558523995535, 74.15712996891567, 50.86146681649344, 5.457814335823059, 0.4692775330373219, 1.8564051517418452, 6.758077638489859, 5.191104693072183, 1.0919733537094933, 3.6254521225179945, 3.1618859001568387, 3.342070711510522, 81.28950445992606, 89.26408399854387, 90.24466936928886, 82.71337795257568, 83.73433235713414, 76.64643328530448, 79.54003143310547, 74.48570333208356, 76.53664479936872, 72.2570686340332, 69.86854199000767, 63.32674353463309, 60.16565363747733, 58.8799728666033, 57.89585781097412, 57.091523919786724, 57.53667415891375, 57.28037943158831, 58.04156500952584, 55.7612635067531, 56.449743134634836, 55.126024450574604, 55.56413269042969, 55.83019658497402, 55.25923531396048, 48.760706765311106, 52.63836438315255, 52.57644203730992, 52.96634020124163, 50.86293288639614, 54.56153195244925, 60.90674155099051, 68.63506998334611, 66.76934664590019, 67.8897784096854, 68.04470934186662, 72.69636848994664, 71.03016962323869, 66.50999818529401, 62.721888950892854, 57.65521042687552, 56.2269560950143, 56.09503412246704, 53.02956880841936, 53.38506644112723, 49.43358073915754, 56.55746800558907, 64.09877177647182, 66.73995576586042, 66.258681842259, 66.7625652040754, 59.997090339660645, 61.320249693734304, 63.29409394945417, 70.70101955958775, 46.82911797932216, 59.61140973227364, 57.172063963753835, 63.20592825753348, 66.46224321637834, 61.2762120110648, 63.493194580078125, 59.30657141549246, 62.8792587007795, 62.83355345044817, 67.05750233786446, 64.12666184561593, 63.20401750292097, 63.0000114440918, 58.91470691135952, 49.02274070467268, 48.50133398600987, 49.27178151266915, 50.49399396351406, 48.13360057558332, 51.79269565854754, 50.872173990522114, 52.863083021981375, 56.06744282586234, 56.18474578857422, 52.99347986493792, 51.685922690800254, 49.47695139476231, 47.68779720578875, 47.2196102142334, 48.18776873179844, 50.441906792776926, 51.61183057512556, 51.918416363852366, 49.51246016366141, 50.77100474493844, 50.7021724155971, 52.845212255205425, 50.498030866895405, 58.44398035321917, 68.49652290344238, 66.63976274217877, 70.41654641287667, 70.38290323529924, 71.45653193337577, 71.72648334503174, 71.79212992531913, 69.81598581586564, 72.70945194789341, 73.09420844486782, 74.03118692125592, 71.90262712751115, 74.05208015441895, 77.788925579616, 75.9494525364467, 74.73906244550432, 1.7846076786518097, 0.7800888035978589, 0.8566381931304932, 1.7722624668053217, 2.107709118298122, 2.16435170173645, 0.17446869664958545, 0.288225418222802, 23.83326264790126, 35.43507283074515, 41.94489567620413, 35.138197149549214, 20.642326763698033, 21.669459853853496, 18.31728754724775, 24.59971148627145, 38.829764638628276, 63.00843266078404, 60.543621744428364, 75.3900808606829, 11.064532041549683, 0.16364048554428987, 0.11442796912576471, 0.051238482884530506, 0.07251382286527328, 0.04375218566773193, 0.06787668740642921, 0.027784110811938132, 0.06867524848452636, 0.05600518460518547, 0.06353258408073868, 0.02859369638775076, 0.14568097995860235, 0.17928402897502693, 0.13633687421679497, 0.07563160985176053, 0.1223891797874655, 0.253169693584953, 0.227331582190735, 0.22101033638630593, 0.23053957362260136, 0.32223248056003023, 0.17467980246458734, 0.1229730456003121, 0.2579403375940663, 0.5630959644913673, 8.64173080239977, 104.45905085972377, 77.9405630656651, 81.96476513998849, 48.63222415106637, 54.43917417526245, 71.33466747828892, 83.58301448822021, 85.43930217197963, 62.05338191986084, 7.743719560759408, 0.46715377271175385, 1.6344205204929625, 7.846268023763384, 7.581965497561863, 6.7950316326958795, 4.959337975297656, 4.3541442326137, 4.296317415578025, 88.48449611663818, 96.0444974899292, 96.76500483921596, 84.65509373801095, 89.51958315713065, 79.00955036708287, 83.37913349696568, 79.04094927651542, 78.86183861323765, 75.77703298841203, 72.00449466705322, 64.6897577558245, 63.16883877345494, 61.45555196489607, 61.85569177355085, 61.98005758013044, 61.22340570177351, 61.136963163103374, 62.81363296508789, 58.73788915361677, 60.182760102408274, 56.317313943590435, 58.11412852151053, 61.354379245213096, 59.54249749864851, 54.46806825910296, 55.71345295224871, 55.51053428649902, 56.18202556882586, 54.274310793195454, 58.554442814418245, 64.57198578970772, 72.54876790727887, 69.18012142181396, 73.23729269845145, 71.52594443729946, 78.00096375601632, 73.87298338753837, 71.69357667650495, 68.03475257328579, 59.25455025264195, 59.54390103476388, 60.35353987557547, 55.41174132483346, 56.54888698032924, 52.65571403503418, 60.307820728846956, 68.03095190865653, 68.61160591670445, 68.2777658190046, 71.2248511995588, 62.54947635105678, 64.73260034833635, 66.64971256256104, 76.67951365879604, 40.134271553584504, 54.38440152576992, 53.04194007601057, 67.34629726409912, 71.0742837360927, 62.73336042676653, 63.799123764038086, 57.10471854891096, 65.79241602761405, 64.43310519627163, 70.80026762826103, 66.80483109610421, 66.56984996795654, 66.84424822671073, 63.83861037663051, 51.0800849369594, 53.281757150377544, 53.939004625592915, 53.50478737694876, 51.34972367967878, 55.57356834411621, 55.042329924447195, 56.621492181505474, 59.23717975616455, 58.315702710832866, 55.85224321910313, 54.08709158216204, 53.82291064943586, 52.826236724853516, 51.53738757542202, 51.23312595912388, 53.41623258590698, 53.74070303780692, 54.7228239604405, 52.70585571016584, 54.16657897404262, 54.057450566973, 55.6448255947658, 54.534051827022004, 63.0746350969587, 72.59124224526542, 70.28353009905133, 76.11856474195207, 73.41314465659005, 74.26012311662946, 74.72935581207275, 71.98422677176339, 71.62692955562046, 75.32110609327043, 74.29755306243896, 78.23158836364746, 75.13242776053292, 79.78624085017613, 79.73566491263253, 81.01918479374477, 73.92495591299874, 1.2038058042526245, 1.5170106206621443, 9.178592920303345, 3.8327379482133046, 5.886167739118848, 2.2337711538587297, 0.1315840213958706, 1.2012117377349307, 35.861205850328716, 44.39744302204677, 70.20963600703648, 87.18158381325858, 41.299032824380056, 26.164327689579554, 20.39897131919861, 30.498273508889334, 48.40296139035906, 73.82135827200753, 71.17153072357178, 87.1436049597604, 13.310096893991743, 0.5985103898814746, 0.16870744579604693, 0.28522762336901253, 0.15477064863911696, 0.16244931731905254, 0.20150373024599894, 0.1264873548809971, 0.13868373685649463, 0.15533102356961795, 0.13057437485882215, 0.14085677239511693, 0.19849936717322894], [0.08122343729649271, 0.044560249628765244, 0.05893035924860409, 0.062255174054631164, 0.05392557655328086, 0.2839306443929672, 0.037520604873342175, 0.08994774879621607, 0.048093442539019246, 0.037196119249399216, 0.0642613714028682, 0.05305926714624677, 0.49740525228636606, 17.756319522857666, 81.33852400098527, 63.091859681265696, 62.05140863146101, 33.44133588245937, 35.503842626299175, 65.8976742880685, 85.05468463897705, 62.96731322152274, 29.26250512259347, 0.03828857759279864, 0.08761499289955411, 3.1500431299209595, 1.7970513595002038, 1.1880929959671838, 1.6287140952689307, 7.547864607402256, 1.723411310996328, 23.520968914031982, 99.25618416922433, 85.24988038199288, 88.79051562717983, 81.60199274335588, 87.09393923623222, 81.17037064688546, 82.55298573630196, 78.67063808441162, 81.88502066476005, 81.35483837127686, 79.39263929639543, 73.71507167816162, 68.19574928283691, 57.66784920011248, 57.50110633032662, 55.62050689969744, 54.71204383032662, 54.803819111415315, 55.57651090621948, 52.32172802516392, 53.25597933360508, 53.33523048673357, 52.96361650739397, 53.67910030909947, 49.90210124424526, 47.63873597553798, 52.11744403839111, 48.885611057281494, 49.047966139657156, 50.16834579195295, 59.00331033979143, 64.26751572745187, 65.28819915226528, 62.84708159310477, 66.71540778023856, 65.5754793712071, 66.80289949689592, 64.3563484464373, 62.660911560058594, 55.10833781106131, 52.240441049848286, 49.13034398215157, 49.02294567653111, 46.938176904405864, 49.730883734566824, 47.717712674822124, 51.42106430871146, 58.8589962550572, 63.00650800977434, 59.704564230782644, 67.48528208051408, 57.29866361618042, 63.87959780011858, 59.67804990495954, 60.651659284319194, 22.795339005334036, 21.742377723966325, 41.149764674050466, 52.789772578648154, 57.572137764522004, 59.09670107705252, 60.12391580854143, 59.29088238307408, 58.02932228360857, 58.443070139203755, 62.72277137211391, 60.058797291346956, 60.879254477364675, 62.19796003614153, 54.83876507622855, 45.574012756347656, 49.3241674559457, 48.44162464141846, 46.453929151807515, 45.61159903662545, 44.52419206074306, 46.25827830178397, 46.625980445316856, 49.099792752947124, 51.392885889325825, 49.94337701797485, 49.42405823298863, 46.7994943346296, 43.90072325297764, 43.05467932564871, 45.248361110687256, 46.54992546354021, 46.79829229627337, 47.985610893794465, 47.48016766139439, 47.39283575330462, 48.07507242475237, 48.44716930389404, 48.06377465384347, 53.17581101826259, 59.73113414219448, 61.40368366241455, 64.48405633653913, 66.01846177237374, 65.20706503731864, 67.04050009591239, 65.08935560498918, 71.28369549342564, 68.86471489497593, 69.54641655513218, 64.57386875152588, 66.35330935886928, 61.35895810808454, 71.94746385301862, 67.83620779854911, 78.24448422023228, 28.131213324410574, 0.5347844979592732, 1.0218735209533145, 3.1575519612857272, 2.4914266424519673, 2.6963133854525427, 0.28134360749806675, 0.23248721339872905, 9.557744826589312, 29.165376254490443, 31.53187710898263, 62.57768603733608, 66.62549809047154, 83.23488194601876, 37.50865847723824, 18.594975778034755, 22.50074233327593, 41.7905900818961, 46.95153481619698, 62.37898145403181, 26.430683408464702, 0.4041731565126351, 0.1413526457867452, 0.03967165248468518, 0.020817113408286656, 0.09240646114838974, 0.03522874428225415, 0.0672101963843618, 0.048655635943370204, 0.05906709084021194, 0.0492659578365939, 0.0312543916516006, 0.04905317943277104, 0.06552620138972998, 0.015206149579691035, 0.039415054289358, 0.032896249621574364, 0.03863981106717672, 0.16743877530097961, 0.023328078045908893, 0.0381462718360126, 0.0603185197604554, 0.031065423041582108, 0.16654309550566332, 0.1346953080168792, 0.48440310997622354, 24.13994918550764, 93.53785146985734, 73.5679713657924, 72.83567987169538, 41.953327315194265, 41.75570665087019, 61.38167176927839, 75.45175307137626, 69.63789653778076, 32.69180243355887, 0.020203449730096117, 0.2946582016135965, 4.274123566491263, 4.703538741384234, 4.329250139849527, 3.045675107410976, 8.896914686475482, 1.3404362670012882, 27.62758878299168, 100.75098487309047, 86.99945068359375, 89.63254696982247, 84.73041915893555, 89.15972900390625, 83.35633645738874, 86.01910155160087, 79.44652952466691, 84.46733256748745, 83.32130364009312, 84.18108763013566, 78.78950786590576, 70.52154758998326, 58.877582686288015, 59.07538400377546, 56.96829761777605, 56.53047425406319, 55.45866598401751, 56.965598242623464, 54.03437212535313, 56.318189416612896, 55.56372969491141, 57.34377479553223, 54.91425377982003, 51.162966523851665, 50.035854067121235, 51.80737025397164, 51.89434780393328, 51.30562693732125, 52.41606024333409, 60.68792193276541, 66.29438863481793, 69.10470567430768, 66.76257910047258, 69.80354159218925, 67.82290199824742, 69.28150258745465, 65.9693796975272, 63.7095684323992, 55.79051194872175, 54.503747258867534, 50.627823216574534, 52.35397808892386, 49.5852494921003, 52.85480076926095, 47.89161566325596, 55.37296690259661, 62.53773389543806, 65.0043304988316, 59.94366564069475, 67.61274678366524, 59.03075572422573, 68.55788244519914, 62.741184098379954, 65.09169714791435, 33.889717033931184, 32.52989203589303, 50.18238810130528, 57.6623010635376, 60.064654622759136, 60.76893098013741, 62.306046213422505, 61.013333865574424, 61.850661277770996, 60.920450346810476, 65.30303355625698, 63.22232600620815, 64.19877025059291, 63.72322164263044, 55.835939271109446, 48.48488065174648, 51.648225239345, 49.61526223591396, 49.50937516348702, 49.19962099620274, 48.82969542912075, 47.47383437837873, 49.68886797768729, 51.81292186464582, 54.83192457471575, 52.733349731990266, 51.97012485776629, 50.08407456534249, 46.19769695826939, 46.941960198538645, 47.66816507066999, 48.53223262514387, 50.59708786010742, 50.36305863516671, 49.05418130329677, 50.38672767366682, 50.93717786243984, 51.81377649307251, 49.82722398212978, 55.64081301007952, 61.971782275608604, 64.73375374930245, 66.34278283800397, 66.81539930616105, 66.28475843157086, 69.32210786002022, 67.09034647260393, 73.35612773895264, 71.10650948115757, 70.98176152365548, 68.65184988294328, 68.93923432486397, 64.57806546347481, 73.88996478489467, 71.68689250946045, 80.68689414433071, 37.233603613717214, 0.6096395584089416, 0.8455460997564452, 2.9854911140033176, 4.111781077725547, 3.258479756968362, 0.9991681107452938, 0.4085251986980438, 8.198906472751073, 41.83621195384434, 34.8387645312718, 52.64502770560128, 50.95823437826974, 57.47607544490269, 31.25953551701137, 27.499696765627178, 30.216683864593506, 50.43099464688982, 52.71189716884068, 71.60864189692906, 34.17339808600289, 0.2601707636245659, 0.10833387648952858, 0.05860648091350283, 0.04793113696255854, 0.10490979201027326, 0.0032599816331639886, 0.06309712066182069, 0.016068803379312158, 0.036658933253160546, 0.002231927925354934, 0.05513136042281985, 0.023911959125793407, 0.17559752107730933, 0.15757089480757713, 0.23033066626105989, 0.11209541000425816, 0.1392968339579446, 0.3969370690839631, 0.10879325826785394, 0.16956850673471177, 0.13029458772923264, 0.2825744157390935, 0.22562836429902486, 0.27794295283300535, 0.7615348334823335, 26.727995089122228, 108.87593732561383, 84.68646485464913, 83.40682901654924, 52.1418912751334, 46.78081062861851, 73.09001173291887, 103.28650760650635, 81.2502054486956, 45.10545751026699, 0.3636273236146995, 0.4120401458016464, 7.050002728189741, 6.010479697159358, 4.783508598804474, 8.220129745347158, 12.417024953024727, 2.248262707676206, 28.263093607766287, 104.21534974234444, 93.00557776859829, 95.35999570574079, 89.98681477137974, 94.72753592899868, 87.63277898515973, 89.29343318939209, 82.7779267174857, 88.30419036320278, 87.5657844543457, 86.84505476270402, 80.12833540780204, 74.82915278843471, 62.899533544267925, 61.47576427459717, 61.16524233136858, 59.53930132729666, 61.29788344247, 62.14757169995989, 58.04012325831822, 59.45224734715053, 59.363477161952424, 60.47446632385254, 59.67704241616385, 56.492891447884695, 52.67994587762015, 57.33738592692784, 55.07024778638567, 54.349052565438406, 54.4445138658796, 65.21847397940499, 71.00114004952567, 73.33665193830217, 72.66490704672677, 71.5690232685634, 71.86323778969901, 73.19234480176652, 71.3749670301165, 68.86831406184605, 61.705464771815706, 57.62556593758719, 54.45354652404785, 55.877725737435476, 53.34476688929966, 56.209370204380576, 52.31492573874337, 57.92885480608259, 64.26305498395647, 67.25386537824357, 62.04148660387312, 70.86125891549247, 63.19047546386719, 71.25039277757917, 66.20795999254499, 72.1862873349871, 31.52469961983817, 32.69023214067732, 50.716628142765586, 63.468584060668945, 63.66569750649588, 62.17819935934884, 62.72288254329136, 62.57189818790981, 64.14196872711182, 65.20361178261894, 70.79718262808663, 66.42559146881104, 66.99491991315568, 65.92923995426723, 62.18778092520577, 50.68616376604353, 55.097682748522075, 52.739599636622835, 53.61604193278721, 52.03333609444754, 51.26908983503069, 52.45880208696638, 53.39881345203945, 55.555332796914236, 59.14141273498535, 56.778969628470286, 54.9472507749285, 54.61420972006661, 49.833091735839844, 50.58714498792376, 51.206288542066304, 51.971264362335205, 54.43248306001936, 53.55653756005423, 51.94704989024571, 52.869378089904785, 53.3962356703622, 54.300971031188965, 53.53303875241961, 60.122560909816194, 66.34062889644078, 68.15811783926827, 70.10462093353271, 73.25558730534145, 69.55652618408203, 72.64978081839425, 69.86077390398297, 76.3592642375401, 75.34213829040527, 75.27370548248291, 71.76134245736259, 73.7701083592006, 67.42606258392334, 79.22140094212124, 75.12670939309257, 86.10380009242466, 34.920120988573345, 1.5001073905399867, 6.9460377011980325, 7.556480373655047, 6.571575394698551, 6.543608895369938, 1.1357966193131037, 0.5076656245759555, 13.912644675799779, 50.52741479873657, 47.136495862688335, 84.47077192578996, 86.06593241010393, 100.45007923671177, 51.28346218381609, 28.93277141026088, 36.78800174168178, 59.47455106462751, 61.683716910226, 83.35685062408447, 40.01459925515311, 0.4315885496991021, 0.1528819871268102, 0.14095505140721798, 0.1167761752648013, 0.207743728267295, 0.08881182010684695, 0.15559861063957214, 0.11740439012646675, 0.18238820454904012, 0.11691656416015965, 0.13203853129276208, 0.18362369468169554], [0.06792036470557962, 0.043813871286277256, 0.04138384060934186, 0.0378548444381782, 0.03783816604741982, 0.10252730628209454, 0.026021853588255386, 0.03515372545059238, 0.03385955221684916, 0.015883802502815212, 0.0560564275697938, 0.13960064122719423, 0.08297320269048214, 46.58963441848755, 65.83245154789516, 57.31144830158779, 48.13567461286272, 39.46367311477661, 30.38510819843837, 39.492438656943186, 72.09508528028215, 46.533590248652864, 8.445535387311663, 0.257777353482587, 0.7284052254898208, 1.8197052010468073, 5.8505999105317255, 3.503313647849219, 2.474301721368517, 0.5821722437228475, 1.1098829869713103, 39.30735601697649, 81.34274850572858, 88.32749462127686, 85.14561571393693, 85.22601331983293, 85.46300942557198, 82.01536887032645, 82.93566472189767, 79.24321828569684, 80.03552137102399, 79.00196293422154, 80.2362756729126, 77.36903204236711, 80.34812082563127, 72.10545894077846, 55.86851590020316, 55.03674357278006, 56.72230012076241, 53.94097791399275, 52.09998321533203, 51.94942964826311, 53.45239101137434, 52.87864351272583, 52.436408042907715, 49.62231813158308, 48.041488306862966, 49.56490516662598, 50.03077145985195, 48.83297150475638, 48.29518093381609, 51.69839818137032, 62.247570174080984, 64.20970671517509, 64.26154722486223, 64.91516426631382, 65.08471420833042, 62.94324466160366, 61.93719414302281, 57.332796641758506, 54.860433033534456, 51.30819429670061, 46.8831958089556, 45.44591229302542, 46.21187128339495, 48.02264826638358, 49.17148774010794, 49.263408933367046, 50.014338970184326, 59.75687026977539, 65.36623437064034, 61.32689911978585, 63.49642549242292, 59.98133877345494, 61.64791284288679, 59.479227202279226, 49.112983907972065, 16.90147396496364, 9.434560213770185, 32.352212701525005, 46.70820195334298, 51.29175138473511, 60.70568152836391, 58.4609409059797, 60.48782076154436, 54.8622465133667, 54.05297245298113, 53.943969113486155, 56.09902933665684, 55.49049915586199, 52.80707359313965, 48.59681265694754, 46.14985861097063, 47.53060116086687, 48.58703654153006, 46.8417706489563, 45.0680935723441, 45.15066596439907, 43.76857546397618, 43.27772692271641, 46.99416548865182, 50.20420544488089, 49.88782269614083, 47.59004299981253, 46.36010415213448, 43.22753313609532, 45.24618979862758, 44.76912995747158, 46.899409430367605, 46.663205419267925, 48.45134517124721, 47.3155300957816, 47.55047300883702, 46.78117888314383, 49.74774006434849, 47.80380432946341, 49.31908484867641, 53.77972412109375, 57.66965225764683, 57.176083496638704, 58.477158001491, 58.34409999847412, 58.300840514046804, 60.826962334769114, 63.0349052974156, 59.1768832887922, 58.64603396824428, 59.22950894492013, 59.35408319745745, 59.25095108577183, 64.56258487701416, 66.7251422064645, 75.51010404314313, 60.00484452928816, 1.3713821321725845, 0.10485753124313694, 0.3910652713051864, 0.9038439829434667, 1.4962038057191032, 1.5808275448424476, 0.14543013913290842, 0.20866698372576917, 28.25106453895569, 37.54054376057216, 27.753912244524273, 78.78775691986084, 123.91228376116071, 77.72600964137486, 21.879679339272634, 18.726522547858103, 30.73847620827811, 54.31974506378174, 59.131657464163645, 50.02378852026803, 0.6718195304274559, 0.1543417873659304, 0.07452771480062179, 0.04944246854367001, 0.013902580332277077, 0.02436626885485436, 0.04336450807750225, 0.03736951548073973, 0.012732832609409732, 0.01686496244344328, 0.04370619795684304, 0.03263772777946932, 0.02786277507298759, 0.06068034855914967, 0.04570487035172326, 0.037655650305428674, 0.0636825810319611, 0.050006304002766094, 0.03805826245141881, 0.02487569089446749, 0.02992783533409238, 0.047193901879446845, 0.0502158016897738, 0.019737979796315943, 0.036616239829787185, 60.53050354548863, 78.16640036446708, 65.18344116210938, 58.42576912471226, 55.41989156178066, 30.045987469809397, 39.851754324776785, 75.77327401297433, 56.02611494064331, 9.208411983081273, 0.5041986906102726, 1.4999653867312839, 4.667145814214434, 4.873387890202658, 3.2174480387142728, 3.0952956676483154, 0.4356430949909346, 2.770839329276766, 52.04299061638968, 79.16521086011613, 89.45565278189522, 89.03205585479736, 89.51987498147147, 88.44609342302594, 85.91836656842912, 85.48868996756417, 83.55209500449044, 82.6122955594744, 83.37506880078996, 82.88525554112026, 80.31436647687639, 84.04570198059082, 75.47896916525704, 60.19653838021414, 57.80201196670532, 59.173555101667134, 56.71377468109131, 56.57382753917149, 55.25237396785191, 56.69776603153774, 55.002808570861816, 55.54145377022879, 53.961770398276194, 52.02955974851336, 52.631912980760845, 52.34513998031616, 51.225420406886506, 49.88912548337664, 56.09797668457031, 64.43277863093785, 67.45778111049107, 69.32474817548479, 68.0337381362915, 68.39056982312883, 66.69025530133928, 64.57356997898647, 58.733518736703054, 57.74212196895054, 54.29069464547293, 49.985611643110005, 48.51078353609358, 49.075380257197786, 49.26771681649344, 52.52423674719674, 50.88135950905936, 53.53107588631766, 64.0020111628941, 67.70136410849435, 63.670776639665874, 64.0100849696568, 63.806085859026226, 65.92917047228131, 60.14497579847063, 56.03436245237078, 23.723774671554565, 14.309664743287222, 40.13154091153826, 51.593337944575715, 54.58811576025826, 61.806026050022666, 63.13092940194266, 60.93600041525704, 56.24374989100865, 57.020933696201865, 56.83754989079067, 56.933271748679026, 58.60887500217983, 53.50667033876692, 50.78033964974539, 49.644225801740376, 50.31120770318167, 49.52705485480172, 48.73823281696865, 48.86530147280012, 47.91004923411778, 46.66241332462856, 45.320202010018484, 49.78257833208357, 54.11219889777047, 51.67272458757673, 51.98315273012434, 50.6149343081883, 46.4915189061846, 47.240034443991526, 47.075956208365305, 47.94610343660627, 49.8543358530317, 50.53985902241298, 49.31544051851545, 49.58797318594796, 50.99855130059378, 51.37736708777291, 49.812021323612754, 52.23010560444423, 56.640745639801025, 57.52829463141305, 58.70967946733747, 59.927691732134136, 59.775533131190706, 60.81471960885184, 61.886194365365164, 64.30828775678361, 61.159343310764854, 60.696412631443565, 61.053272111075266, 62.22113922664097, 61.14291776929583, 67.90994903019497, 70.38695403507778, 75.9024132319859, 67.7849509375436, 2.358764035361154, 0.7084698123591286, 0.8482019401022366, 3.715799765927451, 3.078904215778623, 2.0442138739994595, 0.1953626083476203, 0.4515764814402376, 28.736385788236344, 47.18097823006766, 31.512359619140625, 78.90992709568569, 107.49622658320835, 61.39637415749686, 26.120215313775198, 30.70422158922468, 39.14451108660017, 62.466049330575125, 64.86949375697544, 59.84382002694266, 0.8488121873566082, 0.13223660923540592, 0.06530909053981304, 0.055128670031470914, 0.043443632046026845, 0.02567152595812721, 0.018237835561324443, 0.06827130980257477, 0.025859222314985733, 0.04612857475876808, 0.11181852700454847, 0.04507702189896788, 0.2620030253061226, 0.13736116353954586, 0.1785297015947955, 0.1389781396303858, 0.11616940210972514, 0.2185117940285376, 0.13984632518674645, 0.15341842334185327, 0.10691331593053681, 0.138151792543275, 0.14521687557654722, 0.28256488910743166, 0.15286179392465524, 71.89784676688058, 91.48251179286412, 75.74930272783551, 68.78881277356828, 58.22088759286063, 38.90623998641968, 50.65542493547712, 87.33219991411481, 69.12056841169084, 13.596545934677124, 0.6501007644193513, 1.9366375207901, 5.144285993916648, 15.952499423708234, 12.96816040788378, 5.314956332956042, 1.4119127116033008, 3.100300107683454, 63.09775870186942, 88.54477173941476, 91.19103486197335, 92.83688245500836, 91.43174130575997, 91.42577280317033, 88.56322615487235, 89.45376982007707, 86.14078535352434, 85.32269055502755, 85.83031899588448, 85.35010119846889, 84.28748539515904, 87.46790518079484, 79.65050084250313, 62.27182633536202, 61.2295618057251, 62.71351637159075, 59.87913077218192, 58.25418683460781, 59.82550457545689, 59.099577631269185, 58.11329126358032, 56.93559939520699, 56.527562958853586, 55.356037616729736, 57.32898555483137, 56.58823462894985, 53.87289946419852, 53.44668306623186, 57.458698000226704, 69.94895349230084, 70.21509729112897, 73.17921270642961, 70.7013600213187, 70.91428756713867, 71.23139640263149, 69.94404806409563, 64.42398221152169, 61.87027604239327, 59.18160111563546, 53.1447560446603, 51.7671297618321, 51.71055058070591, 52.97783599581037, 53.96635273524693, 54.330830914633616, 57.74277509961809, 66.2742805480957, 71.55718353816441, 64.77970218658447, 68.31898253304618, 64.38090338025773, 69.5560884475708, 64.65112577165876, 63.74594225202288, 21.331271920885357, 13.806888750621251, 42.630877426692415, 59.67129625592913, 56.59985201699393, 65.3791788646153, 64.34061077662876, 64.17800903320312, 59.50272600991385, 60.38525840214321, 60.152257510593955, 61.269743238176616, 61.72554506574358, 58.7361729485648, 54.527819292885916, 51.744304929460796, 53.07882111413138, 53.55234432220459, 51.19651590074812, 51.67725828715733, 50.51297296796526, 50.92969812665667, 48.70857095718384, 53.389138085501536, 58.232949665614534, 54.916247912815635, 55.26673242024013, 55.08170536586216, 49.309610979897634, 50.66500302723476, 50.73312316622053, 52.61587653841291, 52.85746192932129, 54.09806278773716, 51.87186343329293, 53.81510782241821, 52.64238044193813, 54.63011414664132, 52.91765764781407, 54.83749008178711, 60.216959135872976, 61.70274107796805, 61.60960047585623, 64.13824449266706, 64.36685412270683, 63.04680061340332, 65.62542302267892, 68.78892394474575, 65.02566841670445, 62.879321234566824, 64.26178346361432, 65.39574337005615, 66.08757550375802, 70.06894888196672, 73.81291621071952, 81.06470939091274, 68.90295083182198, 2.0081030002662112, 2.5225400243486678, 8.480428372110639, 6.3308663453374585, 7.239691589559827, 3.4361404180526733, 0.39673662983945435, 0.518239751458168, 38.31045280184065, 54.89516707829067, 40.69362933295113, 91.04575497763497, 134.00333322797502, 88.86097036089215, 32.640965938568115, 31.5945394379752, 47.7603120803833, 72.24932834080288, 73.60814585004533, 68.46925122397286, 0.8974923523409026, 0.2645754872688225, 0.1443661962236677, 0.17551638185977936, 0.09706094674766064, 0.15454760060778686, 0.1143388639071158, 0.1677245742508343, 0.12349687463470868, 0.1678501439413854, 0.12176219985953399, 0.1657873567725931], [0.007014422336526747, 0.06924561823585204, 0.016193088942340443, 0.041152473738683124, 0.03590341165129628, 0.016342451463320425, 0.012819434882008603, 0.07602009829133749, 0.022049673965999057, 0.05647685465269855, 0.01663112740165421, 0.011585015138345105, 0.3767342045903206, 61.34930011204311, 68.1506415775844, 58.73874378204346, 38.49616425377982, 23.2780407837459, 24.788666009902954, 47.58350127083914, 59.610186849321636, 31.541444778442383, 1.629834275160517, 0.1327488353209836, 1.0899044190134322, 3.0299515511308397, 3.5874652351651872, 4.964277275971003, 2.0852649169308797, 0.2694676976118769, 23.07897663116455, 79.24503871372768, 71.6072244644165, 92.79276834215436, 81.93083013807023, 85.4400108882359, 84.98630046844482, 87.83022594451904, 79.17482021876744, 81.75935554504395, 78.61840847560337, 79.78290571485246, 78.10752827780587, 79.78785283224923, 75.950772694179, 78.23948151724679, 66.19506413596017, 56.230002880096436, 54.64881522314889, 54.97109004429409, 53.2652656010219, 53.13569906779698, 54.80576113292149, 54.85857786451067, 51.96805082048689, 47.75875220979963, 46.216165270124165, 49.99008975710188, 45.36732121876308, 50.695217268807546, 50.132725851876394, 54.35850558962141, 57.752679756709504, 62.50699506487165, 61.46549483707973, 61.77093069893973, 59.09652737208775, 55.43539299283709, 55.3931097303118, 53.49456657682146, 50.13919809886387, 48.25877584729876, 44.825910636356895, 46.4656959261213, 43.76666470936367, 47.06180967603411, 46.01229817526681, 49.43569646562849, 47.0103964805603, 58.62931660243443, 62.032641547066824, 66.78681441715786, 61.15498679024832, 60.196378571646555, 57.56096158708845, 54.52484893798828, 45.053144523075645, 24.04211507524763, 15.232504504067556, 34.77459444318499, 46.98497302191598, 49.880950927734375, 64.24073737008231, 59.73914541516985, 57.54150663103376, 53.80584587369646, 47.96765674863543, 47.54657506942749, 45.499931062970845, 44.453490665980745, 42.81917360850743, 43.93161494391305, 46.17093597139631, 46.42828335080828, 45.68440920966012, 45.63231856482369, 44.04322733197893, 42.54715510777065, 42.866539478302, 44.33555889129639, 41.97100353240967, 44.9964611189706, 47.24660743985857, 47.25600835255214, 46.29810190200806, 45.54117209570748, 45.02796425138201, 44.352467332567485, 43.58034529004778, 46.8330089705331, 45.46909148352486, 46.89352430616106, 46.273439271109446, 48.13895763669695, 46.02401283809117, 48.55226080758231, 47.490933895111084, 50.23495122364589, 48.16546154022217, 51.38339812414986, 51.14506449018206, 52.26835196358817, 51.17833941323416, 51.0382011958531, 51.99520785467965, 50.69957031522478, 55.05312047685896, 59.65161895751953, 59.80584117344448, 63.220658438546316, 62.09634263174874, 72.39476108551025, 67.00316742488316, 78.76410525185722, 18.10134448323931, 0.2700640484690666, 1.6503223414931978, 5.303898274898529, 1.6921279153653552, 0.7441496263657297, 0.05972322063254459, 0.07993983224566494, 6.008844264916011, 53.244243826184956, 36.527590206691194, 92.20632648468018, 103.83172580174038, 87.74204635620117, 29.783606120518275, 18.980128322328838, 29.553374086107524, 52.21555607659476, 51.29716403143746, 59.04743834904262, 2.395072932754244, 0.1369860286691359, 0.07553991941469056, 0.009128046621169363, 0.04018998538543071, 0.02047365764155984, 0.04442574702469366, 0.03549568674394062, 0.08703506258981568, 0.024182611477694342, 0.06069676910660096, 0.06681699212640524, 0.04918610444292426, 0.035554139143122096, 0.06312057083206517, 0.036856305519385, 0.035780013272804875, 0.022141330476318086, 0.0650431794513549, 0.04099734027736953, 0.051349185872823, 0.09793603979051113, 0.031853999476879835, 0.019682032887690833, 0.6671269993696893, 75.53967557634626, 74.94067137581962, 68.87410885947091, 48.071963105882915, 28.32510106904166, 26.684311764580862, 46.84136765343802, 64.09048952375139, 36.949498721531455, 1.4042679561035973, 0.13829960461173738, 3.3505572846957614, 4.372573895113809, 2.6510243756430487, 1.814625199351992, 1.1868439487048557, 0.21413886653525488, 30.087384837014334, 92.69979449680874, 78.97451754978725, 90.3155826841082, 83.69872978755406, 84.6718111038208, 86.99335711342948, 88.37538855416435, 82.74796608516148, 85.34086009434291, 83.23490279061454, 83.47116238730294, 80.59056431906563, 82.97081565856934, 77.46754360198975, 82.37034538814, 68.61922809055874, 58.75641999925886, 57.79056133542742, 57.76608630589077, 56.26823534284319, 56.48133659362793, 56.254526547023225, 58.32435321807861, 53.96813842228481, 52.76977218900408, 48.90126187460763, 54.769880635397776, 50.78619350705828, 52.18630416052682, 56.38280766350882, 58.42782579149519, 60.50822067260742, 65.03219277518136, 63.52908897399902, 63.415305273873464, 62.56542246682303, 59.39113099234444, 57.37695939200265, 56.451740741729736, 52.60540212903704, 50.05507973262242, 48.499589988163535, 50.86277307782854, 45.30268907546997, 50.54528556551252, 48.42215926306588, 51.91244091306414, 49.4738108089992, 59.20431477682931, 64.91939571925572, 69.30209009987968, 64.48317391531808, 59.12056813921247, 61.233827999659944, 56.6960255077907, 50.30327980858939, 28.7808837890625, 19.182854175567627, 39.93520218985421, 52.23455592564174, 52.66426379340035, 64.95702021462577, 60.96368203844343, 60.18526840209961, 56.14540161405291, 51.574087960379465, 48.4849397114345, 48.41935913903372, 47.68535143988473, 46.619310174669536, 46.93101678575788, 47.605551379067556, 48.88288736343384, 48.15967716489519, 47.95372561046055, 47.737136363983154, 45.230292320251465, 45.059543813977925, 46.3504878452846, 44.997277532305034, 47.40002713884626, 49.94332143238613, 48.928137506757466, 50.96920558384487, 49.08267933981759, 46.65797342572893, 46.60428122111729, 46.04995046343122, 48.464769090924946, 48.47394418716431, 50.09400701522827, 48.99562188557216, 48.88642052241734, 48.263858454568044, 49.732711110796245, 50.569913455418174, 53.36439902441842, 51.97982454299927, 53.074523653302876, 53.592591762542725, 53.98310831614903, 53.274638720921104, 52.88292360305786, 54.59797177995954, 53.81267247881208, 56.99755648204258, 63.4537843976702, 62.109398296901155, 66.50495379311698, 64.3166116986956, 75.3698616027832, 69.76055308750698, 80.14484432765416, 28.63970855304173, 0.4321581119937556, 0.29850668939096586, 2.427696679319654, 3.5920729764870236, 1.8749976626464298, 0.5056336021849087, 0.07177768700889178, 3.398902416229248, 58.411254337855745, 42.98548568998064, 87.88724981035504, 109.01551273890904, 76.39574228014264, 32.07932915006365, 28.82389313834054, 38.31550761631557, 59.12647410801479, 55.22030455725533, 68.12953295026506, 3.1866388576371327, 0.09733187220990658, 0.08440198030854974, 0.08027178514748812, 0.01950220244803599, 0.012049647929546024, 0.036670098546892405, 0.04346632564972554, 0.07951641282332794, 0.0653295890827264, 0.032398557756096125, 0.061892924564225335, 0.10015336330980062, 0.1772435384669474, 0.16986643789069994, 0.11991249982799802, 0.10453562744493995, 0.12182336300611496, 0.14033033778624876, 0.1107030493606414, 0.09203701918678624, 0.19603297380464418, 0.17072671172874315, 0.1223820008869682, 0.9791572988033295, 85.94396373203823, 87.59088134765625, 79.07911573137555, 56.215835503169465, 35.59526007516043, 36.74850123269217, 64.11827536991665, 76.89813872746059, 52.32466016496931, 2.470961809158325, 0.32105419092944687, 3.120220810174942, 7.55560142653329, 10.547657285417829, 12.471002902303423, 5.032922438212803, 0.31951158227665083, 29.2956098147801, 93.26894228799003, 81.7592304774693, 92.8242575781686, 87.29072611672538, 88.41951656341553, 91.13282980237688, 92.83535385131836, 86.38265214647565, 88.30918611798967, 85.62536103384835, 87.24907166617257, 83.30075781685966, 86.68311309814453, 81.6454884665353, 86.85688754490444, 72.57480280739921, 60.529954637799946, 61.037854058401926, 61.906615121024, 60.91569777897426, 59.83563504900251, 59.99147619519915, 61.61231027330671, 57.38409171785627, 54.632702350616455, 53.15268741335188, 59.538884435381206, 53.19037791660854, 55.200929505484446, 57.18434490476336, 61.10358401707241, 65.5969215120588, 67.44871371132987, 67.70216315133231, 67.71325942448208, 66.86613505227226, 61.28297955649239, 63.302952902657644, 61.76954800742013, 56.37099920000349, 54.29846273149763, 53.01904923575265, 54.308885029384065, 48.50607960564749, 53.357947622026714, 52.06689936774117, 55.40184014184134, 50.85527944564819, 64.70521749768938, 68.99072742462158, 73.1500997543335, 65.84035164969308, 62.20791680472237, 66.18617044176374, 62.19585473196847, 56.768731457846506, 28.405031408582413, 17.55097246170044, 41.90861913136074, 57.29639850343977, 55.906793526240754, 68.84135505131313, 66.05361270904541, 62.45791299002511, 59.5880012512207, 54.04361322947911, 53.24669654028756, 51.24230800356184, 50.60626295634678, 48.02843264171055, 49.283499649592805, 52.24647208622524, 52.45828792027065, 51.32501935958862, 51.82801335198538, 49.46967315673828, 47.76578031267439, 48.4919365474156, 49.52904551369803, 47.625068868909565, 51.88225099018642, 54.30403866086687, 53.957455566951204, 53.91109371185303, 53.48913655962263, 50.74891642161778, 51.0030745778765, 49.4951765196664, 53.59974145889282, 50.72542456218174, 53.957868984767366, 51.25896978378296, 52.61549438749041, 51.791920934404644, 54.27430384499686, 53.03100708552769, 56.932635988507954, 52.47455365317208, 57.682218074798584, 56.568585123334614, 57.87924814224243, 56.31753976004464, 55.98701395307268, 56.77366467884609, 55.136366844177246, 60.317853927612305, 64.04811246054513, 64.16161823272705, 69.67229012080601, 67.13557229723249, 79.30016572134835, 72.21884659358433, 87.53021662575858, 24.893410103661672, 1.1448544647012437, 5.598021600927625, 12.250203916004725, 5.002772901739393, 3.7126426781926836, 0.5381134993263653, 0.17180220330400126, 8.313534379005432, 68.53671823229108, 53.61622258595058, 100.60519082205636, 104.39674636295864, 99.29477446419853, 41.93524462836129, 29.770522662571498, 44.43082216807774, 70.3847028187343, 63.87556784493582, 79.53540393284389, 3.633405638592584, 0.2887046810771738, 0.18258738171841415, 0.14544537902942725, 0.15126408822834492, 0.14690975259457315, 0.13059194891580514, 0.19554685774658406, 0.1814835002379758, 0.1583603024482727, 0.14618291945329734, 0.16202540935150214], [0.06738733473633017, 0.03448659999828253, 0.011811704358219035, 0.014138718152285686, 0.04350474430248141, 0.04918221304459231, 0.10582389403134584, 0.05568496357383473, 0.06960613746196032, 0.04632840332176004, 0.1868683405752693, 0.2418864704668522, 3.4481966282640184, 74.42578206743512, 60.78837898799351, 60.929580279758994, 36.109044619968955, 40.37905311584473, 23.69395474025181, 49.78729963302612, 43.23739957809448, 16.38809241567339, 0.16410928538867406, 0.14827705493995122, 1.7718233189412524, 5.443263939448765, 1.8925132027694156, 1.346671081015042, 0.3456339048487799, 11.068782602037702, 87.81200081961495, 98.04808698381696, 93.4221361705235, 86.77572563716343, 83.36747441973004, 73.8800358091082, 72.3835119519915, 78.15469264984131, 77.64554950169155, 80.38108307974679, 80.19034808022636, 80.20372336251395, 78.29254490988595, 77.6657131740025, 74.94003214154924, 74.04843235015869, 70.45563002995083, 58.64251817975725, 54.01022713524954, 56.85295057296753, 53.97502408708845, 54.15886647360665, 52.42961270468575, 54.657465730394634, 50.906560625348774, 45.99458374295916, 49.18285151890346, 50.39139338902065, 48.218643052237375, 48.32961968013218, 52.284919943128315, 54.06690011705671, 54.743717193603516, 57.55037600653512, 56.09804964065552, 53.84632955278669, 51.47161245346069, 51.05140624727522, 49.80969020298549, 48.0510698727199, 45.012612206595286, 45.1863762310573, 45.07221385410854, 44.596217087336946, 47.45256246839251, 51.31303719111851, 52.205144201006206, 52.498389448438374, 46.941591944013325, 48.98458814620972, 57.309197085244314, 64.16775349208287, 65.26993928636823, 56.64760003771101, 49.26427745819092, 51.55952106203352, 44.52578319822039, 35.686177253723145, 26.70391263280596, 41.374132428850444, 48.29162345613752, 53.1830267224993, 58.52423204694475, 56.200803075517925, 55.6588887487139, 49.47177498681204, 49.624458176749094, 51.454961095537456, 50.019140175410676, 47.25208262034825, 45.419870444706504, 43.74361406053816, 45.00623376028878, 46.11392600195748, 47.12518419538225, 47.22089910507202, 46.91220801217215, 44.90088864735195, 42.12176207133702, 42.59549372536795, 41.63069118772234, 44.13859830583845, 43.61142805644444, 46.170519079480854, 44.929296357291086, 44.120929036821636, 44.673463685171946, 43.396186760493684, 44.155315671648296, 46.40917927878243, 48.14242826189314, 46.557231494358604, 45.27602883747646, 47.229810169764924, 46.85742494038173, 48.067599637167795, 48.876050336020334, 48.226233959198, 47.04793759754726, 48.497550691877095, 48.37342112404959, 50.071116174970356, 48.5559572492327, 51.22840813228062, 52.8282447542463, 56.00933504104614, 60.3305343900408, 62.18377876281738, 64.45700005122593, 64.74663570949009, 67.77901022774833, 68.99598026275635, 71.87527901785714, 69.43514115469796, 70.27630397251674, 5.472557978970664, 0.2054430874330657, 1.9842244301523482, 2.1059818395546506, 1.13471291746412, 0.1661073403166873, 0.11648692935705185, 0.49110687311206547, 40.10958112989153, 43.75637442725045, 47.16659893308367, 91.54608086177281, 57.01051834651402, 33.63214731216431, 20.653885092054093, 24.423927273069108, 51.67087289265224, 50.126878942762104, 63.812603269304546, 9.321215987205505, 0.3520518961761679, 0.12616795487701893, 0.13241806307009288, 0.08780739150409188, 0.07095636786626917, 0.021877585610906993, 0.029107401679669107, 0.05061536042818001, 0.03927447201151933, 0.0802538243255445, 0.06059384212962218, 0.0015656828722317836, 0.015082786824288113, 0.04041962538446699, 0.025336772403014556, 0.03605986825589623, 0.044197284283914735, 0.05017532368323632, 0.05657599201159818, 0.07195257940994841, 0.06531062402895518, 0.22659351250955037, 0.37628951988049913, 4.442981728485652, 86.31738076891217, 66.82670402526855, 69.03942040034703, 45.72029318128313, 41.41384833199637, 27.779891559055873, 49.311420985630576, 49.222223486219136, 18.745798587799072, 0.2535871554698263, 0.46696888548987253, 3.687992206641606, 2.093384321246828, 2.3226863827024187, 1.1762450145823615, 0.48645635694265366, 17.775725841522217, 93.47354589189801, 96.7967164175851, 94.05765315464565, 88.85595376150948, 85.80482605525425, 76.7233498437064, 76.64833014351981, 80.77949973515102, 82.02136516571045, 83.2039555140904, 83.34805420466832, 83.7006961277553, 80.7763591493879, 79.06707450321743, 77.72224371773856, 75.22435937608991, 73.01570074898856, 61.829392841884065, 55.765776361737935, 58.65131459917341, 57.89508308683123, 56.50786828994751, 54.95819418770926, 57.1498818397522, 54.13816084180559, 50.07099805559431, 52.6413243157523, 51.514145851135254, 51.57677343913487, 50.969160420554026, 55.54825953074864, 59.11751093183245, 55.22284412384033, 60.56860746656145, 58.779696464538574, 56.428047384534565, 54.07178817476545, 53.48514134543282, 52.272242954799104, 50.676797594342915, 47.87215723310198, 46.73898594720023, 47.15426240648542, 47.992284638541086, 51.86553362437657, 54.4225297655378, 56.325606618608745, 54.999567236219136, 49.8193655695234, 50.44535657337734, 60.09429563794817, 65.74043655395508, 68.4589956828526, 57.2152852330889, 49.99543639591762, 54.32240274974278, 47.36415358952114, 38.32103838239397, 31.63284833090646, 45.255941595349995, 53.59215750013079, 56.3503873688834, 62.54321602412632, 58.22073473249163, 57.72888912473406, 51.39824295043945, 53.25578825814383, 52.98447152546474, 53.61874825613839, 50.42690910611834, 47.32955503463745, 46.454683031354634, 47.60695491518293, 48.393702915736604, 49.12398985454014, 50.36723797661917, 48.32680913380214, 49.18664870943342, 45.54320444379534, 43.92488561357771, 45.45217261995588, 45.69197232382638, 46.743717670440674, 48.91734348024641, 47.68203714915684, 47.565307412828716, 46.9838022504534, 46.538231645311626, 46.34737852641514, 47.6079763003758, 49.18038143430437, 49.95476164136614, 49.2894229888916, 48.29258925574166, 49.83752121244158, 50.631880964551655, 52.33109072276524, 50.050344535282676, 50.03512103216988, 51.12780516488211, 51.53541776112148, 51.66649552753994, 51.971066338675364, 54.78090047836304, 56.35600846154349, 59.97724628448486, 62.50886413029262, 65.00472654615129, 68.20791557856968, 66.62731851850236, 71.3666639328003, 68.32855020250592, 76.75472790854317, 68.96763161250523, 81.53842367444719, 9.707673924309866, 2.7828794717788696, 0.23891120297568186, 2.8654045292309354, 2.6758429067475453, 1.778794642005648, 0.37428567026342663, 0.22898298714842114, 39.25338588442121, 53.280773980276926, 49.36200039727347, 86.4147389275687, 62.721520696367534, 27.972928149359568, 23.68871406146458, 34.85727105821882, 59.74913692474365, 55.782146317618235, 71.87334741864885, 13.52029379776546, 0.49324045862470356, 0.14433317870966025, 0.1253801214375666, 0.10831577317523104, 0.06461846402713231, 0.04672599430861218, 0.01794775335916451, 0.04906869752864752, 0.03263827400015933, 0.05391465213948062, 0.04057576986295836, 0.1346555594354868, 0.10207912033157689, 0.18491912659789833, 0.14310037557567867, 0.1813502088189125, 0.13257420754858426, 0.1525217393147094, 0.14243242570332118, 0.286842726703201, 0.16227458098105021, 0.40764112185154644, 0.4266485162079334, 4.70726123877934, 96.9092355455671, 77.97228159223283, 77.81081935337612, 51.3599305834089, 54.698498317173545, 35.855213029044016, 66.73776708330426, 63.01296288626534, 25.04780776160104, 0.45528570669037954, 0.5813794976898602, 4.425204762390681, 11.55601634298052, 8.441556675093514, 7.684566940580096, 1.6238602357251304, 16.0821875504085, 95.19710908617292, 100.61689853668213, 99.95632634844098, 92.35958290100098, 87.92415169307164, 78.59644521985734, 80.88814871651786, 84.52072947365897, 82.13099384307861, 86.76695701054165, 84.8624210357666, 86.14206382206508, 84.63494396209717, 82.6338836124965, 79.7154039655413, 79.83756024496896, 78.23780005318778, 64.43736444200788, 59.51082760947091, 63.0644976752145, 60.43144307817732, 60.61108875274658, 58.56972190311977, 60.08487388065883, 57.540103094918386, 53.42840582983834, 57.292715958186555, 56.06909997122628, 54.55423634392874, 53.553730487823486, 57.48946114948818, 60.504440852573936, 58.437879834856304, 63.78833321162632, 63.68103218078613, 60.364323479788645, 58.98848983219692, 56.99098696027483, 57.09849991117205, 54.432274614061626, 51.327593667166575, 48.932296003614155, 51.72905363355364, 51.981314931597026, 56.12069729396275, 57.054448332105366, 60.53132343292236, 58.249184131622314, 51.951274394989014, 54.117264134543284, 64.39741230010986, 70.81697804587228, 72.22692040034703, 60.43656390053885, 55.13635294778006, 58.57657282693045, 51.80090148108346, 41.19718265533447, 31.787140028817312, 49.150104658944265, 57.11934450694493, 60.016503606523784, 65.61796065739223, 62.41271495819092, 60.97272859300886, 55.62367875235421, 54.818347794669016, 56.064868518284385, 56.77308103016445, 52.78128187997, 51.25181661333357, 48.57295254298619, 50.97765111923218, 51.24724122456142, 51.523227146693635, 53.382936818259104, 52.39922823224749, 53.52990511485508, 48.35607494626726, 47.21188381740025, 48.979130336216514, 49.85922391074044, 50.95555932181222, 53.01539100919451, 51.176609311785015, 50.032199314662385, 49.12018918991089, 50.32032026563372, 49.93162414005825, 51.94938448497227, 51.88234479086739, 52.42441545213972, 52.32362488337925, 51.6751251901899, 52.2592567716326, 53.62253155027117, 55.057723658425466, 53.74938481194632, 54.01166888645717, 53.40840196609497, 53.92088719776699, 56.24252700805664, 54.598426886967246, 57.02911172594343, 58.256267820085796, 60.80058002471924, 66.25930718013218, 66.74955817631313, 72.3696641921997, 70.77154377528599, 74.45473521096366, 72.66968045915876, 79.14171205248151, 75.01482255118233, 79.72844573429653, 7.712992889540536, 4.557314770562308, 6.64054799079895, 8.815500038010732, 4.110241183212825, 2.417088951383318, 0.4314979517034122, 1.0498678130762917, 49.42696952819824, 57.52666875294277, 60.44083704267229, 91.01774678911481, 70.22438703264508, 47.01901224681309, 29.686115946088517, 38.663337911878315, 67.9451208114624, 63.42378207615444, 83.34355872017997, 15.064649922507149, 0.6648177547114236, 0.2218250533831971, 0.24440638667770795, 0.23559783505541937, 0.13452545713101113, 0.15237877198628016, 0.12010362957205091, 0.17685700420822414, 0.09698554793638842, 0.25837061022009167, 0.10980342727686677], [0.06446867063641548, 0.0673705952774201, 0.04063565397102918, 0.09349726725901876, 0.021506869699805975, 0.06425598383482013, 0.03248975286260247, 0.04522421650056328, 0.06818645899849278, 0.04624780693224498, 0.12679849032844814, 0.307192860437291, 5.018500583512442, 65.70626531328473, 62.71028545924595, 57.03826945168631, 44.3494552884783, 26.193596976143972, 36.379086358206614, 45.47096402304513, 34.005432333265034, 4.71235339982169, 0.09407078541283097, 0.09841596760920115, 3.8164478966167996, 3.1087877665247237, 1.2154764980077744, 0.6196386675749506, 7.655202116285052, 97.64511231013707, 88.18059580666679, 84.53357669285366, 80.41278076171875, 83.87729154314313, 79.4056532723563, 84.7569682257516, 74.11118847983224, 74.15592793055943, 80.19533688681466, 80.79443836212158, 72.8337413242885, 75.64961692265102, 67.37402752467564, 71.57311575753349, 69.7509298324585, 73.47376074109758, 68.13459123883928, 62.13216059548514, 52.66464594432286, 53.773495061056956, 52.231529985155376, 52.53373146057129, 52.24039241245815, 54.93144014903477, 45.41968979154314, 46.250458104269846, 47.94774668557303, 48.19675275257656, 48.42325707844326, 48.99879026412964, 51.84507465362549, 54.457969052451, 53.66776779719761, 52.54864229474749, 50.130349567958284, 47.57712629863194, 46.65984943934849, 46.98052617481777, 44.689413275037495, 46.10035269601004, 45.0741628238133, 46.415092195783345, 45.61364528111049, 47.51378652027675, 51.259470054081504, 58.35493918827602, 57.35883501597813, 57.054472650800435, 53.87559189115252, 49.16428245816912, 52.325737135750906, 58.88478102002825, 61.321201596941265, 56.487565653664724, 46.63315793446132, 47.59470176696777, 48.70601054600307, 43.86285557065691, 41.8214122908456, 46.47900172642299, 50.37428344999041, 52.36539050510952, 54.73679678780692, 57.61236783436367, 56.89877046857561, 50.07501758847918, 49.226302078792024, 54.22889389310564, 52.90555388586861, 54.34242745808193, 50.28335237503052, 48.10076686314174, 46.15615715299334, 49.01215859821865, 48.151714529309956, 47.51139633996146, 45.689922605242046, 44.58893190111433, 44.012220995766775, 42.306650161743164, 41.59880590438843, 41.07058300290789, 40.61533008302961, 41.425403186253135, 44.967907496861045, 42.85360540662493, 42.757233892168315, 42.11146831512451, 43.45929030009678, 44.30472278594971, 47.7649256842477, 46.53213112694876, 45.73355034419468, 47.00595310756138, 47.47248642785208, 46.32786103657314, 47.74305622918265, 46.05358437129429, 46.524769510541645, 49.36368533543178, 49.47443267277309, 52.134022440229145, 54.48607798985073, 58.46712480272566, 62.9520480292184, 61.29460389273507, 62.37307548522949, 62.280004365103586, 65.28314781188965, 62.61457402365548, 65.07391670772007, 64.16315378461564, 65.16356236594063, 69.43166705540249, 76.50403690338135, 49.92178201675415, 0.6151889977710587, 0.7139658917273793, 3.1983969467026845, 1.2507356745856149, 0.6337063812783786, 0.19502716777580126, 0.13395460561982223, 13.116639069148473, 69.95923682621547, 34.25185367039272, 43.62885413851057, 42.16963168552944, 44.652170930589946, 34.4679912839617, 17.750583784920828, 48.03081587382725, 52.73122705732073, 64.65429415021623, 19.740051065172466, 0.2692696468106338, 0.17046304659119674, 0.023667357429595928, 0.04649383355198162, 0.07427692825772933, 0.029125586418168883, 0.007584946030484778, 0.14500133214252336, 0.0404088773897716, 0.05720924838845219, 0.015548263543418475, 0.044617076936577044, 0.052083954481141906, 0.010349206942399698, 0.02859632231827293, 0.007443552055130047, 0.0365732071389045, 0.16648434794374875, 0.0403295532534165, 0.06941865145095757, 0.06581012758293323, 0.1721635503428323, 0.3520990407892636, 7.1305679593767435, 76.81452410561698, 69.9767323902675, 66.03295571463448, 50.048604011535645, 34.85723284312657, 37.39872407913208, 47.97668940680367, 43.789934226444785, 4.575636735984257, 0.1590162965336016, 0.9712567627429962, 4.39187034538814, 2.432687005826405, 0.19828359303729876, 0.2286757193505764, 13.51779852594648, 106.56425080980573, 89.4020335333688, 89.50431101662772, 83.05537523542131, 86.84442942483085, 82.18875421796525, 89.38495486123222, 78.85016563960484, 77.38491562434605, 81.0917100906372, 82.26792894090924, 74.90887641906738, 77.65644427708217, 70.616744858878, 74.49900218418666, 71.7772468839373, 75.64720589773995, 70.73688616071428, 65.2362196786063, 55.746241501399446, 55.71278245108468, 55.30596194948469, 55.7490416254316, 54.86254528590611, 57.978954792022705, 49.706488609313965, 49.72770145961216, 51.775286946977886, 51.72459636415754, 49.93137747900826, 52.4801539012364, 55.018747738429475, 57.49030882971627, 57.54335137775966, 56.31817899431501, 50.99916969026838, 49.748122215270996, 49.784839970724924, 48.70462090628487, 47.19456890651158, 49.85799755368914, 46.76232494626726, 48.099078450884136, 47.99940306799752, 49.42329740524292, 54.61585296903338, 61.47271401541573, 59.26731409345354, 59.96954768044608, 57.56358800615583, 51.12942409515381, 57.6528445652553, 61.564284324645996, 62.73527812957764, 60.41620567866734, 49.22045169557844, 50.3181072643825, 51.01338223048619, 46.02615983145577, 45.62594359261649, 50.28276177815029, 50.1981327193124, 52.62416921343122, 56.83249855041504, 60.29409108843122, 58.86819566999163, 51.702164105006624, 51.589179447719026, 56.86403294972011, 55.25482668195452, 57.77138430731637, 53.89041587284633, 51.50426551273891, 48.979408264160156, 52.07598066329956, 51.748925481523784, 49.94187273297991, 48.91315024239676, 48.35510567256382, 47.354252406529014, 43.636841092790874, 44.87256778989519, 43.82231283187866, 43.23952225276402, 45.23032011304583, 46.44468109948294, 46.091205392565044, 45.85477556501116, 44.223050185612266, 45.1680121421814, 47.47733279636928, 49.92332451684134, 48.71226739883423, 49.91639021464756, 50.320052759987966, 49.80004262924194, 49.85166427067348, 49.18830932889666, 50.42016240528652, 49.06345020021711, 50.07540668760027, 53.05533620289394, 54.729695728846956, 58.09425319944109, 60.49249689919608, 65.0551426751273, 63.802014214651926, 62.70062051500593, 64.33605275835309, 67.32729394095284, 64.90285900660923, 63.954659189496724, 67.96213694981166, 64.19498348236084, 72.69107396262032, 75.23988165174211, 63.568964685712544, 1.2623398176261356, 2.7558774692671637, 0.8804829993418285, 2.0102767007691518, 1.8989274757249015, 1.1920819133520126, 0.20367027898984297, 11.275359494345528, 77.52442155565534, 42.75490624564034, 44.650343554360525, 48.51002270834786, 34.13622522354126, 31.09579426901681, 22.2075491973332, 54.50748191561018, 58.51934051513672, 72.86969825199672, 26.463753359658376, 0.41231253689953257, 0.1421179518635784, 0.01887424203700253, 0.0561343946361116, 0.06527113329086985, 0.03700454845758421, 0.02965532549257789, 0.06693690283490078, 0.03857270395383239, 0.07205979472824506, 0.05643871080662523, 0.19480702387435095, 0.23055688983627728, 0.10989259356366736, 0.24952142792088644, 0.23370037972927094, 0.14654793058122906, 0.3368784418063504, 0.21360405880425656, 0.19280777472470487, 0.2137970748756613, 0.43494355252810885, 0.5913148788469178, 8.322529690606252, 89.65663637433732, 79.9697288785662, 74.65805339813232, 60.68673379080636, 38.04088701520647, 50.21151842389788, 62.43811757223946, 52.994240692683626, 7.7716339485985895, 0.17111939351473535, 0.9830089892659868, 9.151963080678668, 9.00273140839168, 4.95103748355593, 1.954534343310765, 12.100267001560756, 106.75409643990653, 94.76577186584473, 94.7458166394915, 86.74893338339669, 90.01834569658551, 85.02357060568673, 93.6194372177124, 78.89239679064069, 80.45291355678013, 85.70354216439384, 87.8108821596418, 78.37042726789201, 82.88756234305245, 73.97616413661412, 79.3763040815081, 75.35289410182408, 80.79986490522111, 75.65764904022217, 68.83787400381905, 59.644170488630024, 60.243292808532715, 58.81490298679897, 58.68039281027657, 58.404577119009836, 61.433296884809224, 52.34320838110787, 51.87129715510777, 56.031367778778076, 53.72074433735439, 54.396995135716026, 54.82138415745327, 57.028128555842805, 60.46500287737165, 61.96974645342146, 58.8296331678118, 55.55833441870553, 52.938081877572195, 52.58233410971505, 52.49090623855591, 48.80854163851057, 52.61167287826538, 49.277437346322195, 51.86171906335013, 52.16422625950405, 53.791192122868125, 59.151515415736604, 65.24365425109863, 62.72714178902762, 62.800354957580566, 60.08133029937744, 53.80653721945626, 59.42108467647007, 62.829287256513325, 67.87729249681745, 64.76241506849016, 53.71563046319144, 53.955958230154856, 50.922072478703086, 50.08589499337332, 46.75863545281546, 52.22296980449131, 55.44454377038138, 56.86783708844866, 61.714914321899414, 64.16553701673234, 62.181138447352815, 55.45795031956264, 55.59293644768851, 60.837398529052734, 58.688070569719585, 60.72799914223807, 56.283048902239116, 52.79150268009731, 52.05188431058611, 55.53981399536133, 54.57144703183855, 53.43890803200858, 51.97398110798427, 51.52998774392264, 51.38894626072475, 47.23980515343802, 46.63698986598423, 46.12425797326224, 46.66949701309204, 48.52343620572771, 51.650757857731406, 49.74045140402657, 50.48313740321568, 46.925065653664724, 49.638719354357036, 48.8531699180603, 53.644164766584126, 51.9613492829459, 52.024928774152485, 53.755356788635254, 52.211446217128206, 53.85818665368216, 53.90943309238979, 52.12872096470424, 51.06900256020682, 54.22765016555786, 55.43178340366909, 58.09392316000802, 61.55265998840332, 63.49200643811907, 68.48304339817592, 68.14140047345842, 67.35141113826207, 67.80314132145473, 70.4019135066441, 67.53858866010393, 71.16002450670514, 70.35744503566197, 69.10196808406285, 75.94712488991874, 82.52417155674526, 62.561302185058594, 2.1674892476626804, 6.14584493637085, 10.453269481658936, 4.699328567300524, 4.564900466373988, 1.6256161757877894, 0.3049126299364226, 16.39058334486825, 84.50288649967739, 48.56300272260393, 56.34622539792742, 57.19262368338448, 60.62822995867048, 44.3707515171596, 29.657364300319127, 64.05154487064907, 67.53737967354911, 82.38389437539237, 32.2100247655596, 0.5819268854601043, 0.39878740693841663, 0.1350864563137293, 0.15871783612029894, 0.23296289358820232, 0.11076389359576361, 0.10635331419429608, 0.17633196738149437, 0.119527756901724, 0.17701097737465585, 0.13335627344037804], [0.09636387415230274, 0.05196581474904503, 0.047564144512372356, 0.010469673201441765, 0.08243650863213198, 0.03260809276252985, 0.07793978242469685, 0.034075546876660416, 0.05473277877484049, 0.08239529441509928, 0.16937008952455862, 0.33959372181977543, 6.339483414377485, 62.87816088540213, 57.77748135157994, 51.06213426589966, 31.746670246124268, 28.97632966722761, 51.921827929360525, 47.81756523677281, 24.339515345437185, 0.7649465075560978, 0.008783235480742795, 2.1754197478294373, 3.1559608238083974, 0.689353960965361, 0.60953289270401, 3.9356811557497298, 94.66165310995919, 85.46145302908761, 81.86510712759835, 82.77894115447998, 78.2227155140468, 78.70797075544084, 79.46278830936977, 80.54406697409493, 84.30400821140834, 76.43605572836739, 75.82350948878697, 78.12897041865757, 70.42091682979039, 65.32355158669608, 61.262503215244834, 66.0828229359218, 64.64398302350725, 66.540743964059, 64.08472946711949, 59.04953670501709, 53.55308083125523, 51.38854673930577, 52.87340457098824, 53.80814225333077, 53.10802786690848, 53.26933377129691, 45.62398420061384, 49.0602262360709, 48.3684983253479, 49.21753345217024, 47.59073087147304, 47.36569956370762, 52.20292772565569, 57.05615758895874, 55.296078136989046, 51.01047788347517, 47.366995402744834, 46.92217867715018, 47.565616607666016, 46.64620665141514, 48.149647440229145, 46.27995320728847, 44.815304211207796, 44.75267662320818, 45.46958827972412, 47.409976959228516, 50.573679379054475, 56.94441318511963, 60.77304431370327, 59.21550832475935, 55.91321018763951, 54.53634820665632, 54.587483474186485, 56.741862773895264, 57.41393770490374, 56.39718001229422, 45.776677812848774, 47.4469552721296, 49.69176885059902, 46.13302659988403, 48.797768456595286, 50.35641268321446, 47.22609288351876, 49.015670912606375, 53.59298433576311, 53.909856932503835, 55.706831318991526, 49.074730600629536, 49.31216791697911, 52.88332312447684, 54.79658603668213, 56.11822720936367, 53.9643794468471, 54.30220086233956, 51.72656617845808, 51.046094349452424, 50.62150730405535, 45.86828981127058, 45.12685796192714, 46.40663971219744, 45.91899429048811, 43.84361948285784, 39.79384803771973, 41.03017922810146, 41.51384333201817, 45.240016324179514, 41.564898695264546, 43.52854299545288, 43.851609911237446, 43.059647287641255, 42.110801288059776, 44.420750754220144, 45.91275133405413, 47.43375716890608, 48.86671543121338, 47.996811389923096, 45.515946660723, 46.951350688934326, 47.42921999522618, 47.23065437589373, 47.484305313655305, 50.01461689812796, 52.48623704910278, 60.54946517944336, 58.273683479854036, 59.10435799189976, 61.23712839399065, 63.19083677019392, 58.050976344517295, 63.342495100838796, 57.80091067722866, 64.29520429883684, 60.38566139766148, 65.29375076293945, 59.48349339621407, 73.58960805620465, 65.74539756774902, 81.23746940067836, 22.94307507787432, 3.9754791344915117, 0.9712466661419187, 2.424036715711866, 1.1942810182060515, 0.605341446186815, 0.01792246096634439, 2.0610788890293668, 54.10405560902187, 59.11138956887381, 28.32464075088501, 42.807476316179546, 37.78957067217146, 28.17452665737697, 24.163526160376414, 39.41005386625017, 52.503680501665386, 60.19434969765799, 36.260112353733604, 0.2498510330915451, 0.062179035640188625, 0.021334721972899776, 0.10865042664642845, 0.016383769156943475, 0.0047562942657220575, 0.04605929972603917, 0.12741138386939252, 0.054289447742381265, 0.02297152655332216, 0.008937987266108394, 0.05014211617942367, 0.05829520297369786, 0.03127767897344061, 0.06618232439671244, 0.03270159149542451, 0.04975209425070456, 0.08920868166855403, 0.04141968082902687, 0.09840743842401675, 0.02786308211008353, 0.13433230535260268, 0.3292865034724985, 9.499686547688075, 75.01817853110177, 63.42533152444022, 58.38318361554827, 38.80077675410679, 32.75759145191738, 39.17773389816284, 58.11804730551583, 27.483389343534196, 0.5235401413270405, 0.11856586565928799, 3.8186773998396735, 4.026677804333823, 0.7164986186793872, 0.6815686672925949, 8.324438708169119, 100.91614355359758, 85.95811026436942, 86.56449345179966, 82.24042102268764, 81.89815970829555, 81.25853633880615, 80.57998221261161, 81.90882519313267, 84.96367713383266, 80.42052105494908, 78.7461997440883, 80.47104140690395, 73.78560979025704, 68.58318778446743, 64.58854334694999, 68.66808782305036, 68.39257090432304, 67.91313825334821, 67.78149768284389, 61.093460491725374, 56.966379914964946, 53.367348534720286, 56.17498704365322, 56.47345038822719, 55.393550940922324, 53.498461042131694, 49.26687261036464, 50.837471212659565, 50.854956354413716, 52.87625333241054, 49.864271777016775, 50.52982234954834, 56.43191058295113, 58.99504893166678, 58.94718973977225, 53.30564853123256, 50.60831962312971, 49.96073709215437, 50.03638560431344, 50.46879979542324, 49.85887997491019, 48.855469771793906, 47.21045248849051, 48.869001388549805, 46.761716978890554, 49.5317587852478, 54.697702748434885, 60.99685968671526, 63.44212532043457, 62.908948353358674, 61.28108964647566, 58.346907070704866, 57.14923913138253, 60.969817297799246, 61.46890640258789, 59.89896787915911, 47.74050971439907, 48.06767954145159, 51.18136535372053, 49.306703158787315, 51.66581807817732, 53.694928305489675, 49.64209270477295, 51.6619861466544, 56.88119152614048, 57.79720033918108, 59.18519333430699, 54.161701338631765, 51.92586830684117, 53.496334893362864, 55.81774888719831, 59.81544358389718, 57.075730664389475, 56.97620119367327, 53.362390995025635, 53.64857339859009, 53.50991514750889, 48.904871463775635, 46.6098050389971, 48.12929616655622, 49.02516910008022, 47.48819630486624, 43.14178889138358, 43.65469796316964, 44.612604413713726, 45.45094973700387, 44.332762241363525, 44.39873538698469, 45.70117173876081, 45.66241816111973, 43.78660256522042, 47.27195446831839, 48.118491717747276, 49.40553780964443, 49.391109875270296, 49.94961650030953, 48.338600226810996, 49.77614777428763, 50.41735533305577, 50.928642000470845, 51.35609517778669, 52.34192991256714, 56.26294428961617, 63.74594225202288, 61.43328298841204, 61.14997019086565, 63.969083649771555, 64.09335218157086, 61.197495869227815, 65.4203052520752, 60.59173107147217, 65.83966377803257, 62.83007935115269, 67.40652424948556, 62.20678424835205, 74.56333555494035, 70.90062740870884, 81.84361634935651, 29.70006445475987, 3.5441714440073286, 0.4252345306532723, 0.46797767707279747, 2.4693606836455206, 2.0957406290939877, 0.07134545341666255, 1.4810371909822737, 54.71276991707938, 68.63781452178955, 34.20482131413051, 49.115933418273926, 38.277761527470176, 29.7940388407026, 33.93987955365862, 46.433914865766255, 59.678779465811594, 65.48513889312744, 44.598301546914236, 0.17198078015020915, 0.06841014485274043, 0.09676445408591203, 0.07595861623329775, 0.01449083796303187, 0.031111465035272495, 0.03633288360599961, 0.07496258789407355, 0.09188725972282034, 0.042636860694204054, 0.03552650919716273, 0.15068801199751242, 0.15042240624981268, 0.17065265641680785, 0.20056576414832047, 0.19096240374658788, 0.14770950110895292, 0.144927602527397, 0.12796086152749403, 0.1801653238279479, 0.13711853298757756, 0.28264207925115314, 0.7861721143126488, 10.786196759768895, 87.12494209834507, 70.69856684548515, 69.64463629041398, 45.32750456673758, 39.909962858472554, 65.6455727985927, 68.31741224016461, 38.21304253169468, 1.1931258801903044, 0.10351481900683471, 7.255688514028277, 9.70510482788086, 6.091149151325226, 3.4692831082003455, 7.491032685552325, 100.6568089893886, 91.82906709398542, 89.24175248827252, 86.43434674399239, 85.81057221548897, 86.19828864506313, 84.71678679330009, 87.68900380815778, 89.9506424495152, 83.72150598253522, 84.52787222181047, 83.11244773864746, 76.10737119402204, 71.75534616197858, 67.53127915518624, 72.07957690102714, 70.72905554090227, 71.88820266723633, 73.16557339259556, 64.98784937177385, 59.84634917122977, 56.02010127476284, 58.69767992837088, 59.948828152247835, 59.03800964355469, 57.94065284729004, 53.9015017236982, 53.883488518851145, 55.18889175142561, 56.085400445120676, 53.781947544642854, 53.37729140690395, 59.94456195831299, 62.31555134909493, 61.197349957057405, 55.89429024287632, 54.54845544270107, 52.265041146959575, 54.7157506942749, 51.42720651626587, 53.00233881814139, 52.18634237561907, 49.47599949155535, 51.71840899331229, 50.20131846836635, 54.093372753688264, 57.849339621407644, 62.83931350708008, 66.863251549857, 64.67798055921281, 62.2467155456543, 60.480816977364675, 59.88437666211809, 63.9021030153547, 66.2560623713902, 62.173002106802805, 52.160766056605745, 50.81193658283779, 53.19166680744716, 51.516511712755474, 53.349401337759836, 55.073054858616416, 51.27018765040806, 53.181393895830425, 61.303511483328684, 62.06964070456368, 62.10138007572719, 57.199623993464876, 54.23431348800659, 58.13231890542166, 58.98729474203927, 63.53131239754813, 59.42228671482631, 58.697631290980745, 55.46072612489973, 56.062950815473286, 57.025231157030376, 50.71056931359427, 50.360911641802105, 52.942163944244385, 51.61168813705444, 50.43936375209263, 45.45631374631609, 46.40249163763863, 47.79533447538103, 50.32851913997105, 46.82046052387783, 49.01363509041922, 50.469491141183035, 48.73162160600935, 47.341186319078716, 50.378226552690776, 51.061984879629954, 53.35568945748465, 53.831102575574604, 54.251096861703054, 51.180340494428364, 52.9474584715707, 54.561896732875276, 53.15970161982945, 54.018453802381245, 54.57441738673619, 57.7924998828343, 64.34833022526333, 63.75607967376709, 64.43267440795898, 67.38111468723842, 67.921142578125, 63.67705086299351, 70.05214813777378, 64.1960118157523, 70.6669316973005, 65.99169731140137, 72.37677219935826, 66.25419330596924, 81.35708958762032, 71.79151848384312, 87.73089449746269, 30.115608419690812, 6.614932153906141, 5.77205182824816, 7.447443161691938, 6.054261599268232, 2.3216719457081387, 0.1136384257780654, 3.0371477135590146, 64.17052582332066, 72.79683249337333, 44.4489917073931, 57.45722150802612, 54.02893515995571, 40.35316412789481, 38.222228050231934, 52.405735220227925, 69.29903289249965, 74.87315573011125, 52.11019011906215, 0.3052002473601273, 0.20242398657969066, 0.13300750644079276, 0.28164178292666164, 0.12396282463201455, 0.1502594357090337, 0.10192904195615224, 0.26045710540243555, 0.1464979089796543, 0.1711844785937241, 0.19628716659333023], [0.06273236059184585, 0.11191158129700593, 0.04311604890972376, 0.052329733435596736, 0.09642038933400597, 0.07445835495101553, 0.03391530065398131, 0.03500700243083494, 0.07560410204210452, 0.06942478540752615, 0.02790316995898528, 0.16569257900118828, 11.286652054105486, 67.46664701189313, 51.82607480457851, 57.327206815992085, 30.826919828142437, 43.906524998801096, 58.45830059051514, 37.882565362112864, 14.251492687634059, 0.21692088725311415, 0.7891692849142211, 3.181080515895571, 1.4192893100636346, 0.39717287357364384, 0.26570921071938103, 74.06122398376465, 87.41029071807861, 79.06020968300956, 85.48927361624581, 73.79095295497349, 71.99918624332973, 66.61095551082066, 74.11826869419643, 78.84933880397251, 79.14790289742606, 79.58761269705636, 73.39168167114258, 78.08041640690395, 74.45779241834367, 66.38658428192139, 58.99953746795654, 59.66938550131661, 61.91972637176514, 61.741359165736604, 63.13882255554199, 57.418353285108296, 52.48355851854597, 51.021417822156636, 52.20062787192208, 51.440185751233784, 54.156059401375906, 46.99710805075509, 45.82977247238159, 47.851048605782644, 48.22484431947981, 49.872356006077354, 46.34882722582136, 50.004038265773225, 53.07989461081368, 56.077809538160054, 54.923442772456575, 51.5525346483503, 48.32782357079642, 48.39568315233503, 48.089389187949045, 48.42812776565552, 46.60679299490792, 46.34447765350342, 47.19584390095302, 46.67453098297119, 45.13549109867641, 46.547389371054514, 48.68032652991158, 56.87227003914969, 62.230505398341585, 58.85427148001534, 61.19857978820801, 56.39848974772862, 55.83593232291085, 58.73228195735386, 60.23225906917027, 51.36864709854126, 43.037975856236045, 49.55332946777344, 49.73684181485857, 52.48913444791521, 54.30749191556658, 57.476096289498464, 50.917639528002056, 48.72894654955183, 47.07205132075718, 52.35530866895403, 57.86675875527518, 54.30054371697562, 49.76369660241263, 47.91897766930716, 52.70389979226248, 55.10033696038382, 56.56226921081543, 54.28186001096453, 55.78940371104649, 51.712575980595176, 49.244089467184885, 43.675664152417866, 43.506558895111084, 44.53470121111189, 48.59309189660208, 49.11405740465437, 43.253342219761436, 41.26775550842285, 40.92667538779122, 40.9489860534668, 41.604701450892854, 40.25980118342808, 41.58869627543858, 40.72493444170271, 40.59191117967878, 42.57673011507307, 45.19912617547171, 46.879704339163645, 46.96746703556606, 45.656296798161094, 46.991309779030935, 43.9089012827192, 44.4548316683088, 45.16925934382847, 49.39757864815848, 52.97211415427071, 57.475335461752756, 59.353478704180034, 62.75096716199602, 58.736846923828125, 60.87065955570766, 58.15914590018136, 59.097791944231304, 55.846538748059956, 62.47709001813616, 58.445411682128906, 60.0904324395316, 61.56003202710833, 63.81687641143799, 65.84984288896833, 73.9950145993914, 68.0408114024571, 51.02518374579293, 2.994613230228424, 1.8839534563677651, 1.1229854438986098, 1.2544200654540743, 0.956021317413875, 0.011829689777057086, 0.03046050567978195, 27.18860159601484, 77.59407029833112, 40.466673374176025, 41.90412017277309, 37.44726072038923, 29.652497087206157, 17.975062710898264, 29.184859003339493, 57.00355972562517, 54.94924143382481, 48.383558545793804, 0.37700632427419933, 0.09909081818269831, 0.017267408348353844, 0.005798439661573086, 0.042224681204450984, 0.02691772676605199, 0.015276328760332294, 0.046286469857607565, 0.04991045753870692, 0.02807387919165194, 0.049407327215054204, 0.024879682376714687, 0.03846367694703596, 0.015235472470521927, 0.06884699248309646, 0.04089867789298296, 0.023271644288407903, 0.03632018821580069, 0.049818706033485274, 0.08351223090929644, 0.12279423805219786, 0.16247227894408361, 0.15908131375908852, 14.247153537614004, 77.49863679068429, 59.850782121930806, 64.31463841029576, 36.77163873400007, 33.42758887154715, 48.85516405105591, 54.06642069135393, 14.597539901733398, 0.3496442639401981, 2.1118928023747037, 4.949111529758998, 1.7833180278539658, 0.10219717185412135, 1.395258748105594, 84.7451284953526, 89.1606114251273, 85.80774429866246, 84.93845517294747, 78.19133744921002, 72.04182038988385, 70.97100571223667, 73.93242522648403, 80.4948250906808, 82.32726655687604, 80.84734889439174, 78.70937429155622, 81.13644259316581, 76.87100601196289, 68.89416136060441, 62.460706165858674, 61.54482242039272, 63.29971504211426, 66.47792530059814, 66.65707070486886, 62.85178552355085, 55.69853169577462, 55.86693518502371, 55.185226576668875, 54.51043490001133, 56.31086254119873, 49.772378376552034, 48.71925033841814, 50.69127416610718, 50.53030524935041, 51.01850305284773, 48.637539522988455, 52.74535969325474, 55.5819548198155, 58.76325702667236, 57.59656068256923, 55.041635104588096, 52.63247231074742, 50.99980545043945, 50.67468881607056, 50.77884578704834, 50.278512954711914, 49.71095977510725, 48.853788307734895, 50.556625025612966, 48.46812159674508, 50.01200784955706, 50.49577965055193, 59.893193926130024, 63.94190924508231, 61.57367134094238, 63.91744463784354, 60.17531163351876, 59.61971977778843, 60.771369797842844, 62.19163717542376, 53.62813874653408, 45.066908904484336, 50.54959692273821, 49.60573278154646, 55.23540299279349, 57.856277397700715, 61.31369754246303, 52.943345138004844, 50.34305477142334, 50.29786021368844, 55.611422130039756, 59.300922530038015, 58.05961990356445, 51.63604504721505, 49.41998658861433, 55.75311326980591, 57.074083941323416, 58.59141417912075, 58.82782663617815, 56.737096309661865, 53.67252383913313, 53.314139229910715, 46.40117495400565, 47.851340430123464, 49.351765700748985, 51.05645063945225, 51.536880356924875, 46.44804402760097, 43.765667642865864, 44.34579011372158, 44.309412819998606, 44.893648624420166, 43.400723934173584, 44.48295797620501, 42.68616076878139, 44.414507797786165, 44.8356693812779, 48.033056667872835, 48.586088112422395, 48.737749917166575, 47.78210163116455, 48.743145193372456, 48.4549617086138, 47.11193745476859, 48.97761562892369, 52.24770539147513, 56.79244218553816, 60.84737614222935, 62.25279521942139, 65.00945132119315, 62.623446873256135, 64.45060076032365, 60.34196417672293, 62.31036799294608, 59.0498354775565, 62.464687483651296, 62.41136005946568, 62.2962075642177, 63.518173354012625, 65.68883228302002, 67.74794483184814, 76.16777883257184, 69.16959490094865, 62.58846269335066, 11.43768765245165, 2.5421057173183987, 0.588181132716792, 1.7837619526045663, 2.7084275696958815, 0.3200598657131195, 0.016491435701027513, 25.672020026615687, 82.15476363045829, 49.57952765056065, 48.14315087454659, 40.29123135975429, 24.247693164008005, 23.549857786723546, 35.7658383505685, 60.70445169721331, 61.6073214667184, 57.76170546667916, 0.45586170149700983, 0.0052608011672938505, 0.03367103822529316, 0.047495900852871795, 0.08994488537843738, 0.005770582830466862, 0.05366121931001544, 0.027599488218714083, 0.00277241096565766, 0.10195813753775188, 0.01731039014911013, 0.11825979208307606, 0.23092338017054967, 0.11927136565957751, 0.1601576738591705, 0.1489911994763783, 0.11344586432512317, 0.1299798424754824, 0.11882543244532176, 0.1908653053854193, 0.1454681506646531, 0.2642462620777743, 0.38892533470477375, 16.821137155805314, 91.05239050728935, 66.8365009852818, 75.56440421513149, 42.565355913979666, 58.55858394077846, 78.58643286568778, 60.44062859671456, 23.47600190980094, 0.3694444043295724, 2.326116838625499, 9.950105258396693, 8.180835945265633, 3.893881227288927, 1.1844339008842195, 84.25458567483085, 94.319308417184, 86.14170251573834, 93.26712880815778, 81.15700926099504, 77.11263656616211, 74.70416859218052, 79.97152151380266, 86.91742719922746, 85.97360474722726, 84.20468371255058, 81.8042825971331, 84.52894919259208, 80.29768385205949, 72.57558795383999, 67.32418114798409, 67.01761967795235, 68.05108083997453, 69.73241288321358, 70.24309158325195, 65.62675012860979, 58.87606797899519, 57.618471826825825, 58.80151380811419, 57.70070028305054, 58.983424595424104, 53.103754724775044, 53.74865525109427, 53.69144030979702, 53.98161097935268, 54.39520250047956, 50.961691107068745, 57.59398637499128, 57.92985882077898, 61.79570797511509, 60.5369028363909, 57.12378440584455, 54.769706930433, 54.00465815407889, 54.45859439032418, 54.05244786398751, 52.7957376071385, 53.169123377118794, 52.845083713531494, 53.460284164973665, 50.300149645124165, 54.469944272722515, 52.637099811008994, 65.91436386108398, 67.77483436039516, 64.23349039895194, 66.36412075587681, 62.86097799028669, 62.61536611829485, 64.51053592136928, 65.59931864057268, 56.61122621808733, 47.27905900137765, 50.593478270939414, 51.658640589032856, 56.786386830466135, 59.334947858537944, 61.64487648010254, 52.48226615360805, 53.28810780388968, 54.23666892732893, 59.555587904793875, 62.33037880488804, 60.17009353637695, 55.254753725869314, 52.06184802736555, 58.431904384068076, 61.35809653145926, 62.571335383823936, 62.17276586805071, 61.00136906760079, 57.1645633833749, 56.67656012943813, 50.099437032427105, 51.21124608176095, 51.87407990864345, 54.806803362710134, 53.982420444488525, 49.162135464804514, 47.56233358383179, 45.996390274592805, 46.34558589117867, 47.70199237551008, 46.47862304959978, 48.09411743709019, 45.092658928462434, 47.896274430411204, 47.12608051300049, 50.47869055611746, 51.92191825594221, 51.71736328942435, 50.591414655957905, 52.09830175127302, 51.095874718257356, 48.27483313424246, 50.5870372908456, 54.73308644975935, 58.16930069242205, 63.33446298326765, 64.72606209346226, 70.49781949179513, 64.53455584389823, 66.94647012438092, 63.81739752633231, 64.47272382463727, 62.63122190747942, 67.8508129119873, 64.58809866224016, 66.44795772007534, 67.46261010851178, 69.0978616986956, 71.61638219015938, 79.99714647020612, 72.92454733167375, 67.83365086146763, 11.316284384046282, 3.6122713897909438, 5.006735980510712, 5.785071449620383, 4.166093843323844, 0.17784558901829378, 0.13113583544535296, 35.28010368347168, 89.43859495435441, 55.825544766017366, 56.72222021647862, 51.87907566343035, 40.638929639543804, 26.351748398372106, 42.50080714906965, 71.19544642312187, 70.1539670399257, 67.85231372288295, 0.781911620071956, 0.21929375135472842, 0.12098564367209162, 0.1222131678036281, 0.10148660998259272, 0.14009291838322366, 0.14349379017949104, 0.11550362354942731, 0.1220562362245151, 0.14879578139100755, 0.11192019869174276], [0.08149008120277099, 0.05378576780536345, 0.03847222988094602, 0.010699459085507053, 0.02538663794153503, 0.03060794455398406, 0.011232176928647926, 0.0700135909553085, 0.03142275654577783, 0.04803660844585725, 0.057378855001713545, 0.10785695458097116, 9.529430917331151, 59.215702874319895, 51.1604825428554, 50.82818841934204, 33.10381323950631, 56.5105641910008, 49.521221842084614, 29.976192814963206, 3.5225369249071394, 0.3294638182435717, 1.6210982182196207, 3.4462300709315707, 0.15150770944144043, 0.9190762255872998, 43.48014184406826, 89.53511932918003, 76.19691957746232, 84.80637686593192, 76.19240324837821, 84.38491303580147, 73.19047573634556, 70.84149823869977, 63.504367283412385, 73.33187852587018, 76.94442762647355, 80.02330643790108, 75.31077412196568, 73.50412436894008, 77.32101999010358, 72.08585112435478, 58.31961454663958, 56.87357630048479, 59.78156416756766, 58.4857668195452, 57.39103296824864, 56.99259894234793, 51.33099133627755, 52.31912592479161, 51.57536990301949, 52.87836905888149, 52.73357902254377, 43.740275451115195, 46.8934965133667, 47.90013762882778, 48.4714879989624, 49.222633429935996, 45.91899429048811, 48.59495748792376, 54.77480690819876, 55.56191621507917, 54.250026839120046, 53.670831952776226, 50.24036734444754, 49.51464537211827, 46.48848601749965, 46.01577227456229, 46.06997864586966, 46.51574380057198, 48.620408739362446, 46.87503514971052, 48.07319293703352, 44.663232462746755, 44.59835713250296, 53.09135913848877, 58.179855006081716, 59.84074892316546, 61.36608695983887, 60.10997772216797, 58.40903786250523, 58.98221560886928, 54.7030737059457, 46.213636125837056, 45.68899154663086, 52.017577580043245, 55.094476154872346, 57.42313017163958, 58.33572741917202, 57.84621293204171, 56.29986354282924, 48.61747659955706, 47.365074225834434, 50.979096344539094, 52.62274830681937, 55.70929792949131, 49.55676187787737, 45.686021191733225, 46.91595656531197, 50.11032485961914, 53.892833845955984, 53.87707185745239, 53.96547031402588, 51.51124150412423, 47.057373251233784, 41.03956624439785, 43.435471875326975, 46.85839768818447, 49.3290833064488, 47.55030625207083, 47.85985197339739, 40.93066365378243, 41.07843099321638, 41.69005312238421, 40.19493280138288, 40.96883010864258, 41.693343094417024, 41.58583014351981, 40.984727587018696, 43.816577093941824, 44.20264332635062, 44.58535705293928, 46.84163863318307, 46.57445955276489, 46.668541635785786, 46.23526586805071, 45.74711322784424, 49.199839864458355, 53.22953448976789, 55.86058453151158, 59.15346785954067, 59.31262329646519, 59.973139899117605, 57.41547325679234, 57.685004302433555, 56.98149919509888, 57.60582263129098, 58.10454000745501, 60.25860663822719, 60.02266665867397, 63.90381922040667, 63.56888130732945, 66.21459552219936, 64.70943505423409, 72.22218867710659, 66.3686648777553, 61.58154364994594, 45.51313958849226, 4.629698932170868, 1.0196771302393504, 1.4302523732185364, 2.587638999734606, 0.3312942885926792, 0.16872279425816877, 5.8395192708287915, 66.67084203447614, 57.51962327957153, 41.0380654335022, 41.23876067570278, 38.147778102329795, 30.654281411852153, 28.49550042833601, 48.391354424612864, 54.30652264186314, 43.68897690091814, 0.46178938341992243, 0.046474742969231944, 0.09009997134229966, 0.014508683434022325, 0.027341046104473726, 0.01998970950288432, 0.021890942572749088, 0.008721233495245022, 0.026099191313343387, 0.04808275561247553, 0.0250461507655148, 0.06405336649290153, 0.0357096152646201, 0.056257826941353936, 0.05323131648557527, 0.04663435136899352, 0.027432792520682727, 0.05249730444380215, 0.03540429486227887, 0.05257910184030022, 0.03421353715072785, 0.09514924897147076, 0.13848040705280645, 12.11188004698072, 70.29658576420375, 56.29367617198399, 60.601778166634695, 38.23113216672625, 40.98709692273821, 52.68699829918997, 39.649919578007285, 2.458619637148721, 0.3976529506700379, 2.5617721591676985, 3.7533500024250577, 0.528646741594587, 0.414222178714616, 51.44200965336391, 92.30232279641288, 82.00990758623395, 87.50080490112305, 79.45558997562954, 84.03209045955113, 76.68248748779297, 72.28389562879289, 65.22053759438651, 75.9885778427124, 79.23616586412702, 82.35730361938477, 77.59675925118583, 77.76687894548688, 78.49692617143903, 73.97719941820417, 62.60221317836216, 60.112083026341026, 63.430285590035574, 62.89826202392578, 61.860555512564524, 58.72776562826974, 55.913491589682444, 54.67836938585554, 54.01093585150582, 55.39630242756435, 55.35787541525704, 47.721023491450715, 49.88799292700631, 52.036247389657156, 51.36798701967512, 52.1356691632952, 49.75605010986328, 51.24901301520211, 57.77971519742693, 58.759734289986746, 57.34474059513637, 56.717818532671245, 53.768023354666575, 51.367844581604004, 48.6676321710859, 48.632780006953645, 50.04102005277361, 49.12419135229928, 50.79784216199602, 50.655814034598215, 50.92077316556658, 48.31975671223232, 47.696360860552105, 55.427232333592, 60.90307290213448, 64.18774345942906, 64.03384780883789, 60.756278310503276, 61.06460462297712, 61.99141093662807, 56.98761360985892, 49.556192125592915, 46.887875420706614, 53.32881382533482, 57.8066394669669, 59.31602791377476, 61.00806018284389, 60.523451123918804, 58.26503644670759, 51.48812484741211, 51.51745319366455, 53.384677342006135, 57.25893381663731, 59.37865202767508, 53.73666613442557, 47.51660054070609, 48.74612944466727, 52.70187439237322, 54.165731293814524, 57.086646284375874, 56.05324418204171, 54.584690298352925, 48.71522385733468, 44.36679451806204, 45.965442998068674, 48.49860681806292, 50.14597954068865, 50.16737304415022, 51.219229561941965, 44.92895589556013, 42.78270946230207, 43.80935096740723, 43.34285933630807, 43.84283781051636, 43.2425342968532, 42.52233266830444, 44.416078090667725, 46.27712876456124, 46.273387159620015, 48.57528713771275, 48.592897347041536, 49.89298520769392, 49.20883778163365, 47.79140179497855, 47.42083699362618, 52.65672499792916, 55.57156726292202, 56.41511331285749, 61.21640191759382, 61.5586701801845, 61.706152643476216, 60.795431409563335, 59.564113344464985, 59.5462703704834, 59.013225419180735, 60.31585284641811, 61.16689600263323, 62.08227252960205, 65.41601126534599, 67.55363845825195, 67.37645939418248, 70.68662289210728, 71.44399043491909, 69.44158908299038, 65.90103026798793, 58.342321259634836, 12.573739835194178, 0.6408771936382566, 0.4129420002656323, 3.7556733063289096, 1.764145885195051, 0.13523593757833752, 5.394134529999324, 69.94673701695034, 64.98954473223004, 50.08265713282994, 43.72312729699271, 34.75409378324236, 33.3262528691973, 35.14271347863333, 55.45133563450405, 58.5912960597447, 52.36572749274117, 1.2694964621748244, 0.04747516482270189, 0.15088508570832865, 0.01127554803887116, 0.011838673580703991, 0.01844343336831246, 0.03207947327090161, 0.043920916970819235, 0.03700321174359747, 0.04550179499866707, 0.029925562241779904, 0.11403158253857068, 0.14423769526183605, 0.12491331648613725, 0.07914226182869502, 0.09474358002522162, 0.17624624126723834, 0.1403756503547941, 0.12085468641349248, 0.19429851616067545, 0.2084133473357984, 0.19483848075781549, 0.23485706480486052, 15.870368242263794, 85.2529375893729, 63.76246506827218, 67.39030020577567, 42.221850872039795, 77.53695610591343, 66.46032551356724, 49.0811333656311, 4.693834713527134, 0.44613281211682726, 5.323920377663203, 7.4574989421027045, 3.738664550440652, 1.3155540078878403, 53.11015401567732, 96.75708389282227, 83.51317814418248, 90.5821920122419, 82.07787486485073, 87.90452998025077, 80.35943249293736, 75.01464884621757, 69.73367050715855, 80.8321531840733, 85.26279013497489, 84.79611437661308, 81.06064469473702, 81.19622489384243, 80.41568510872978, 76.8105914252145, 65.90562302725655, 63.174154145377024, 68.83881201062883, 65.749253817967, 66.07027448926652, 64.92095906393868, 58.97132083347866, 58.71067305973598, 57.57334327697754, 57.959840297698975, 59.73037678854806, 50.40327133451189, 52.61891290119716, 54.245079721723286, 54.72487020492554, 55.16888441358294, 51.365134784153526, 52.68665436335972, 62.38234438214983, 62.121224130902974, 60.8664767401559, 59.51677526746477, 56.70580162320818, 54.559332847595215, 52.039290700639995, 51.596235343388145, 53.03089591435024, 52.11828129632132, 53.93648937770298, 53.823838233947754, 53.04536553791591, 50.303672381809776, 48.78456687927246, 60.379665102277485, 65.00947216578892, 66.00822012765067, 65.98768125261579, 66.32997730800084, 65.77789429255894, 67.76657295227051, 61.6847174508231, 51.31533704485212, 48.515609060014995, 53.423302377973286, 58.14994995934622, 59.765388761247905, 64.61057608468192, 62.70089149475098, 59.35547283717564, 53.18214430127825, 53.866423743111746, 57.53157418114798, 61.876855986458914, 60.922798837934224, 57.34612676075527, 51.30980627877371, 53.03370646068028, 56.7251558303833, 58.57489831107003, 59.51809542519705, 59.32080132620675, 58.97134862627302, 51.49380152566092, 46.73775611604963, 49.116138390132356, 54.33585793631417, 54.51973853792463, 53.113239015851704, 53.830331325531006, 47.78025688443865, 46.90160853522164, 46.92122677394322, 47.51514489310128, 47.18691546576363, 46.637111459459575, 46.356866291591096, 48.12883758544922, 49.29283455439976, 49.573812757219585, 50.58068316323416, 51.53159277779715, 51.81648281642369, 52.2607957976205, 50.49605063029698, 50.34366273880005, 56.512672969273154, 58.78475475311279, 58.669977460588726, 63.76151316506522, 65.42166015080043, 64.62675843920026, 64.41177422659737, 62.607952390398296, 63.126392228262766, 63.98374434879848, 64.25374439784459, 64.76193564278739, 65.4565679005214, 69.09452656337193, 70.96154921395438, 70.50533049447196, 72.79495647975376, 73.48852566310337, 71.67140497480119, 66.22789437430245, 57.03017480032784, 12.421164342335292, 1.7322634245668138, 5.769429751804896, 9.29934913771493, 2.0609807457242693, 0.33662675959723337, 8.691396525927953, 79.8201550074986, 70.59000124250139, 57.950811113630024, 54.59945522035871, 54.66880519049508, 42.61463948658535, 40.26500538417271, 64.18435968671525, 66.75629098074776, 65.17904990059989, 2.2465501938547408, 0.14550380089453288, 0.30633516503231867, 0.06379240871007953, 0.08607777181480612, 0.11995067420814719, 0.10230051273746149, 0.09581133630126715, 0.13838511359478745, 0.17818318733147212, 0.13192516166184629], [0.033689253497868776, 0.0367829558838691, 0.04210553724052651, 0.10755562396453959, 0.02278969273902476, 0.018561795320627943, 0.05821891528155122, 0.0453383664467505, 0.06998536389853273, 0.048707632081849236, 0.04646983037569693, 0.12160762958228588, 6.017367967537471, 56.655701637268066, 51.33347879137312, 40.602006912231445, 33.07752473013741, 60.090696471078054, 40.524572713034495, 26.79737458910261, 0.09308300127408334, 0.307879239320755, 2.568233983857291, 1.5703327251332146, 1.7623669292245592, 9.957983647074018, 83.44474533626011, 71.88429083142961, 83.23365211486816, 78.80657264164516, 84.02138328552246, 81.16070570264543, 86.37441158294678, 71.57876464298793, 68.51763847896031, 62.8136260168893, 71.3454441343035, 75.510666847229, 76.06495938982282, 73.52858202798026, 77.61856964656285, 72.65470709119523, 63.337374278477256, 57.1372708593096, 59.344432149614605, 58.206789697919575, 59.20983164651053, 53.795576436179026, 51.71465696607317, 51.802728857312886, 51.145807947431294, 52.266927582877024, 49.27918481826782, 43.13629634039742, 47.467567103249685, 48.05725724356515, 48.32348789487566, 47.247663566044395, 46.57834359577724, 48.28424794333321, 54.61246919631958, 53.03803866250174, 54.83165012087141, 51.98851326533726, 50.57798726218087, 47.79055758884975, 46.58573300497872, 46.52685397011893, 48.27040365764073, 49.549681663513184, 47.44454077311924, 47.54852056503296, 47.06382465362549, 45.222145557403564, 45.76246527263096, 49.11730568749564, 60.406033515930176, 60.17402621677944, 62.925311361040386, 61.520128522600444, 59.76889760153634, 56.681048665727886, 50.68896041597639, 44.744696617126465, 49.91828012466431, 57.744018827165874, 56.699485710689, 59.391304697309224, 58.87284401484898, 59.17858559744698, 60.00706795283726, 51.12607158933367, 50.06766292027065, 48.17889935629708, 52.168099880218506, 53.38605308532715, 52.34050900595528, 47.79156160354614, 45.43287399836949, 45.80922317504883, 47.28395053318569, 51.062610217503135, 50.096598693302695, 48.37468222209385, 45.41517693655831, 41.20510360172817, 44.02848325456892, 45.730156149183, 47.033457551683696, 46.83186599186489, 49.52843754632132, 45.27028962544033, 40.36572299684797, 40.588680267333984, 41.40861981255667, 40.175005367824006, 40.53246586663382, 41.306783539908274, 39.51990488597325, 42.24261556352888, 43.289229665483745, 45.566293307713096, 45.94816977637154, 46.207983766283306, 47.21183865410941, 43.50996698651995, 46.60000807898385, 51.46725940704346, 54.88942091805594, 56.218194416591096, 58.23393630981445, 58.58394486563546, 55.397428035736084, 56.68482501166207, 55.21749748502459, 56.48103782108852, 58.007845401763916, 58.876116616385325, 62.57156467437744, 64.14985493251255, 65.74534893035889, 66.04004982539585, 67.64835630144391, 70.11651624952043, 69.61633627755302, 68.52599021366665, 69.44985743931362, 74.39422334943498, 47.088209356580464, 1.994531648499625, 0.8082782423921994, 3.1087951489857266, 0.716049211365836, 0.12701277168733732, 0.43755479955247467, 41.51196037020002, 72.38309506007603, 43.02091108049665, 42.02025236402239, 29.86014747619629, 25.78955749103001, 35.06705454417637, 48.70688949312483, 53.71468898228237, 49.313168457576204, 2.6153931447437833, 0.10476313345134258, 0.07974938782198088, 0.08276837332440273, 0.029439391900918314, 0.12456115681145873, 0.06885318750781672, 0.029525993325348412, 0.030782914986567836, 0.024555040689717447, 0.03700586820819548, 0.042128692248037884, 0.018921344241659557, 0.012882810052750366, 0.056284123566001654, 0.0743174571543932, 0.017772575973400047, 0.0616739545283573, 0.011405962469455386, 0.02639416236031268, 0.04783590118001614, 0.06468522508761712, 0.21579563191958837, 9.716437339782715, 70.83324377877372, 57.7971899168832, 54.66363573074341, 24.381843771253312, 44.97334098815918, 49.20724664415632, 26.44460759844099, 0.14195139865790093, 0.653445833495685, 4.131547834192004, 1.6794155346495765, 0.7219546916229385, 12.802352939333234, 89.9866966520037, 76.49598394121442, 89.00908511025565, 81.57349123273576, 87.13908168247768, 83.5996345792498, 87.74348463330949, 76.20878710065568, 71.02790451049805, 65.05210631234306, 74.11994321005685, 77.60990524291992, 80.38611357552665, 77.9669314793178, 79.50521400996617, 75.90392793927873, 67.84210681915283, 60.109373228890554, 62.37691783905029, 60.27004337310791, 63.39364079066685, 56.397072315216064, 55.38053349086216, 54.13133076259068, 54.13144193376814, 56.519867828914094, 52.131045137132915, 46.90398481913975, 52.05060236794608, 51.36556209836687, 51.88639906474522, 49.22434268678938, 48.81185940333775, 51.50169815335955, 55.894463947841096, 57.5208009992327, 56.0507949420384, 55.53856331961495, 52.95850610733032, 50.311381408146445, 48.793172223227366, 49.83501638684954, 52.104530811309814, 51.6671382359096, 50.37063911982945, 52.23184960229056, 49.95679746355329, 48.242961747305735, 49.19916588919503, 52.510986532483784, 63.611181940351216, 64.10758904048375, 63.0993845803397, 63.192573819841655, 61.504488127572195, 57.913877964019775, 51.63311290740967, 45.566088335854666, 51.4468594959804, 59.144108636038645, 56.92155361175537, 61.427258900233674, 61.29752908434187, 61.82848262786865, 60.66570159367153, 52.23637635367257, 52.071148191179546, 50.23151533944266, 53.06204816273281, 57.46704626083374, 55.406742095947266, 51.29139355250767, 50.30077150889805, 47.395833900996614, 49.2579858643668, 52.95451436723982, 52.36975049972534, 50.78057241439819, 45.64718770980835, 43.581814834049766, 46.14103439876011, 49.108061109270366, 49.52454308101109, 50.59258195332119, 51.30093690327236, 48.22755411693028, 43.18885598863874, 42.543934617723735, 43.01419564655849, 43.10214247022356, 43.13242966788155, 44.77481010981968, 43.34251887457711, 44.11897659301758, 44.95029728753226, 49.04008688245501, 48.26982000895909, 48.918326650347026, 50.178955691201345, 47.519755022866384, 49.030633858272004, 53.82844141551426, 58.871940749032156, 59.174270766122, 61.30331693376814, 59.62504209790911, 57.614570413317, 58.66593360900879, 57.5363267489842, 59.18105220794678, 61.214699608939036, 61.06557042258126, 66.02524321419853, 66.08142634800502, 70.79158932822091, 68.10903576442173, 71.00664302280971, 70.77924237932477, 70.53192125047956, 67.50408390590123, 71.45318290165493, 73.60739544459751, 62.79437950679234, 6.737680333001273, 0.921827169401305, 1.7279113552400043, 2.33122941000121, 0.2223819542144026, 0.17316386023802416, 42.40047516141619, 77.70071125030518, 51.72390154429844, 47.13911880765642, 29.302669184548513, 27.84271890776498, 40.906692368643625, 56.3389367376055, 59.64166218893868, 57.985927309308735, 3.9104735255241394, 0.07307307821299348, 0.16474089292543276, 0.04456756762894137, 0.03357853015352573, 0.054124295711517334, 0.11175969801843166, 0.05044057659272637, 0.0232626350396978, 0.027944311233503476, 0.05462187901139259, 0.18536816750253948, 0.1440818357680525, 0.13669180231434958, 0.13360232380884035, 0.1975568820323263, 0.12496122105845384, 0.1498241690652711, 0.13385499667908463, 0.16781838850251266, 0.1584500183484384, 0.18862547485956124, 0.3355610796383449, 14.841308764048986, 84.8352118900844, 66.50698961530412, 57.83063159670149, 43.55448409489223, 77.33463151114327, 56.39090231486729, 39.059176785605295, 0.28899259705628666, 0.6423986319984708, 8.19272083895547, 10.908249684742518, 3.651939306940351, 12.732439296586172, 95.8947012765067, 79.37993798937116, 91.42794064113072, 84.95519338335309, 92.0449823651995, 87.49243232182094, 91.03638880593437, 78.16190487997872, 73.23998165130615, 69.56389127458844, 77.70425483158657, 81.45334298270089, 82.94196673801967, 80.9605211530413, 83.94906643458775, 79.49923855917794, 69.42344038827079, 62.60281072344099, 66.2363086427961, 65.65098544529506, 67.5850443158831, 61.255541120256694, 59.1136268888201, 56.69733871732439, 56.45201519557408, 59.98822443825858, 55.158764362335205, 51.60828351974487, 54.96084145137242, 55.9607150214059, 54.919600418635774, 52.86194699151175, 52.21728270394461, 54.19779028211321, 59.9550051007952, 60.29216643742153, 60.18499742235456, 58.386602129255024, 56.008376189640586, 54.451448168073384, 52.289814949035645, 53.31128699438912, 56.3211076600211, 54.964742864881245, 53.76034212112427, 54.70180565970284, 52.56272629329136, 50.67805174418858, 52.315318311963765, 55.096105507441926, 67.14948953901018, 68.34039688110352, 66.79348468780518, 64.7161192212786, 66.24497999463762, 61.479078565325054, 56.83825165884835, 47.80245637893677, 52.882576193128315, 59.486585344587056, 61.25588158198765, 64.85489559173584, 63.53218787057059, 64.59372670309884, 62.06931413922991, 54.01513256345476, 55.064831665584016, 55.6772597857884, 57.295425755637034, 59.0901072365897, 57.90256977081299, 54.861735820770264, 52.260083607264924, 51.19982671737671, 53.230691364833284, 58.485155378069194, 56.00374174118042, 55.19015979766846, 51.04069907324654, 48.04755061013358, 50.71491888591221, 52.335513251168386, 53.55401536396572, 52.45800304412842, 56.151985032217844, 50.9811669077192, 46.31276260103498, 45.89530440739223, 46.13751513617379, 46.05377197265625, 45.828247342790874, 46.186159474509104, 45.262097699301584, 48.0752808707101, 48.37867048808506, 51.93400117329189, 48.78235387802124, 51.969635009765625, 54.21204798562186, 49.85299137660435, 51.9519761630467, 56.939393111637656, 60.37783077784947, 62.075046403067454, 64.42346804482597, 64.6856027330671, 61.42841230119978, 63.147417477199006, 61.013181005205425, 61.89921528952462, 66.37131214141846, 65.007874080113, 68.83795738220215, 69.35646670205253, 73.51773588997978, 70.86847809382847, 74.12218747820172, 73.47138445717948, 73.46151801518032, 70.43010929652623, 76.66449165344238, 78.04100622449602, 64.25586359841483, 6.05904803957258, 3.3491331211158206, 11.122858694621495, 3.6813818642071316, 0.2030304204672575, 0.5826876046402114, 52.43500798089163, 84.1621537889753, 58.070090838841026, 58.17189931869507, 41.52613122122628, 36.66753734861101, 48.18640341077532, 63.868564060756135, 66.71008546011788, 69.95212187085832, 5.544748893805912, 0.2590856504227434, 0.3993024693003723, 0.17394257416682585, 0.11326887525085892, 0.17376169030155453, 0.11451178177126817, 0.16909780699227536, 0.12493858513023172, 0.14533788551177296, 0.20525934015001568], [0.022729981657383696, 0.01452634739689529, 0.020758481197325245, 0.022517557788108076, 0.036547548337174315, 0.0650857100263238, 0.04005213760371719, 0.04217362483697278, 0.04522237767066274, 0.037493005461458645, 0.0924021185242704, 0.11956549701946122, 8.067803519112722, 53.25218561717442, 45.368721280779155, 24.923660823277064, 44.276499203273225, 59.74646186828613, 48.4131509235927, 15.400916678564888, 0.5309206481490816, 0.6081302251134599, 4.078341569219317, 1.3480272825275148, 0.8960179771695818, 51.107210704258506, 78.2414687020438, 78.69218444824219, 86.35829871041435, 83.08934497833252, 82.62694931030273, 89.3819671358381, 84.26405606951032, 79.6505286352975, 71.23549583980015, 63.177600451878135, 62.05960055759975, 71.11632033756801, 76.13527515956334, 72.63632215772355, 74.03652313777378, 73.027651650565, 63.16764368329729, 59.228084564208984, 56.4343980380467, 55.74226713180542, 53.697381019592285, 53.64361933299473, 49.27672863006592, 52.22880629130772, 52.045259203229634, 54.785871914454866, 45.580922739846365, 45.76380280085972, 46.708868980407715, 47.47942420414516, 47.46562508174351, 47.38379962103707, 48.06523724964687, 49.69694525854928, 52.22284126281738, 54.93822853905814, 52.184699126652305, 52.340502057756694, 47.61076947620937, 44.903706141880576, 46.95703084128243, 45.918803215026855, 49.22248404366629, 50.72951357705252, 47.38743352890015, 49.80796357563564, 46.42694929667881, 47.44206026622227, 42.246829645974294, 49.89609105246407, 55.05326638902937, 59.89124148232596, 61.08120386941092, 61.51882920946394, 54.92881372996739, 53.002095631190706, 45.78254904065813, 47.53899458476475, 50.56630039215088, 55.81553588594709, 55.50745970862252, 55.56292370387486, 53.44569294793265, 54.55362490245274, 53.41633333478655, 49.725766386304585, 45.514570917402, 43.50279991967337, 51.180785179138184, 55.469453062329976, 54.05198233468192, 52.41724143709455, 48.706604616982595, 48.87109974452427, 48.095680781773154, 42.94612414496285, 44.05336127962385, 43.55217729296003, 43.51255519049508, 40.08528675351824, 40.76648466927664, 42.92903505052839, 46.576134068625315, 47.582226276397705, 46.64507409504482, 47.73685496194022, 43.93481458936419, 39.325007915496826, 40.144099780491416, 41.900854519435335, 42.14288806915283, 39.31038890566145, 41.2769445010594, 40.849922112056184, 41.71755409240723, 43.76688705171858, 45.209770815713064, 46.09835161481585, 45.73670482635498, 45.1347267968314, 47.71128559112549, 52.86019951956612, 55.85839237485613, 54.89666094098772, 55.84844602857317, 53.6375709261213, 52.28390203203474, 54.4777193069458, 53.296456064496724, 57.71987383706229, 60.0365561076573, 64.05285113198417, 63.94190924508231, 67.02039895738874, 66.13290555136544, 68.12464141845703, 68.37501975468227, 69.25291769845145, 66.01489734649658, 68.18400682721818, 68.00679302215576, 71.11736951555524, 73.40642574855259, 37.994351455143516, 0.058715602915201864, 1.7997153422662189, 1.382112864937101, 0.09618696650224072, 0.22045572900346347, 16.041844572339738, 69.92848409925188, 55.86954770769392, 44.26281820024763, 55.34490312848772, 36.45766006197248, 23.732081242970057, 44.80297115870884, 50.291950770786826, 48.71354934147426, 1.8262794997010912, 0.14179023302027158, 0.15291440753000124, 0.014968623307400515, 0.039181068273527284, 0.03733110700600913, 0.07745474523731641, 0.046104320524526496, 0.014446889249874013, 0.011115743712122952, 0.027550730388611555, 0.012339385775183993, 0.10967156078134264, 0.04921081329562834, 0.03248033479654363, 0.06408555619418621, 0.030153811244027953, 0.044436688401869366, 0.057320772404117246, 0.026087126960711818, 0.03981167497113347, 0.10653262385832411, 0.1809796608452286, 14.746290411267962, 65.77921445029122, 53.01379987171718, 30.546132700783865, 39.25081852504185, 56.27508626665388, 56.14837544304984, 14.386888759476797, 0.6231586901204926, 2.6637728001390184, 4.545382976531982, 1.4035940894058772, 0.8503691266689981, 58.57227884020124, 84.0339525767735, 83.56984070369175, 87.9774443762643, 85.96905367715019, 83.37533283233643, 90.79776682172502, 85.54783303397042, 81.77753898075649, 75.2508875983102, 66.64944158281598, 62.4755197252546, 73.11399691445487, 77.59160368783134, 77.0083371571132, 76.50109781537736, 73.9608016695295, 64.97252859388078, 62.87050397055489, 61.60026904514858, 59.08432633536202, 57.1690171786717, 55.014752524239675, 52.814317090170725, 54.530581201825825, 55.2720616885594, 56.074755804879324, 49.49741036551339, 50.181846141815186, 50.326834201812744, 52.23550435474941, 50.038932119097026, 50.27286754335676, 50.37309530803135, 54.36638832092285, 55.00586577824184, 56.342337880815776, 55.24941750935146, 54.334096567971365, 49.62235287257603, 48.25073330742972, 49.03696019308907, 50.48967218399048, 52.176767757960725, 54.414344787597656, 50.18259654726301, 51.1079854284014, 50.180883816310335, 50.28519712175642, 46.09264019557408, 51.60131795065743, 57.738085065569194, 63.4063629422869, 64.37439291817802, 64.82920115334647, 56.777930872780935, 54.72047199521746, 47.7676146371024, 49.48765509469168, 51.776770387377056, 57.4835204396929, 56.6254700251988, 58.20442383629935, 54.99357441493443, 57.14124870300293, 53.0678151675633, 53.36177955354963, 45.833882331848145, 46.04895339693342, 53.97192171641758, 57.87388413293021, 58.10534599849156, 55.26498147419521, 50.48510374341692, 50.933818408421104, 48.959383555821006, 47.627132483891074, 45.97957215990339, 45.477068015507285, 46.31952667236328, 42.74288586207798, 43.67389236177717, 46.84266349247524, 48.3652674130031, 49.975877216884065, 49.76239728927612, 50.61192226409912, 46.44259316580636, 42.699522154671804, 41.79121541976929, 45.948652676173616, 44.33830342973982, 42.77542427607945, 43.954286915915354, 44.33256074360439, 43.96766914640154, 45.090181895664756, 47.96549585887364, 48.6326584134783, 47.62280723026821, 48.37231983457293, 50.61959654944283, 55.148894446236746, 57.687328474862234, 59.612201826913015, 56.619470255715505, 56.52353647777012, 52.8789735521589, 56.68904604230608, 57.145952633449006, 61.000952175685335, 62.56212902069092, 68.11907591138566, 67.2150388445173, 69.4849180494036, 68.21969277518136, 69.2785565512521, 70.0752786908831, 73.35731588091168, 65.574020249503, 68.92620645250592, 69.52131271362305, 73.99575805664062, 73.9066196169172, 53.40759597505842, 0.5482789309961456, 0.9504449537822178, 2.3488335396562303, 0.5797105186751911, 0.16901632850723608, 13.53982605252947, 78.17141001565116, 59.688076155526296, 54.665511744362966, 45.07156419754028, 25.221137523651123, 33.92732763290405, 54.16747876576015, 55.59575046811785, 57.66366638456072, 3.9097630722182135, 0.17887457380337374, 0.050681646514151774, 0.036784458838935406, 0.09433892209615026, 0.03321264710809503, 0.016930279920675924, 0.03710682064826999, 0.04476369817608169, 0.02864172648904579, 0.035768389967935424, 0.16912011722368853, 0.1222173882914441, 0.22683593950101308, 0.14010182076266833, 0.20023466620062078, 0.2171319252146142, 0.1290402750351599, 0.287828122398683, 0.10296099872461387, 0.1701215806284121, 0.3281270499740328, 0.31161875437412945, 22.446381364549907, 79.00400570460728, 59.46973596300398, 35.18874182019915, 54.38965783800398, 76.58567823682512, 64.89940575190953, 20.946739503315516, 0.9269726361547197, 2.5702787084238867, 7.644668647221156, 4.231936275959015, 1.487534842320851, 62.109398296901155, 88.33417184012276, 89.41683319636753, 89.55762454441616, 91.76002979278564, 84.57892758505685, 89.73976462227958, 88.5886982509068, 87.01404190063477, 79.57860088348389, 70.0640504019601, 67.47399125780377, 77.3266132899693, 80.76270593915666, 80.25873225075858, 81.30270603724888, 79.15485109601701, 68.72691822052002, 66.87767601013184, 65.28935255323137, 63.093555041721885, 61.86592647007534, 60.01231384277344, 55.08932406561715, 57.73137310573033, 57.69991166251046, 59.76474952697754, 53.24622406278338, 53.10398748942784, 53.55081919261387, 54.51797022138323, 52.81107922962734, 52.951081957135884, 53.786245005471365, 57.99719033922468, 57.26282133374895, 62.12187726157052, 57.47895894731794, 60.00385788508824, 53.120329652513774, 50.279885223933626, 52.474661350250244, 53.0373021534511, 54.84477179391043, 58.14412042072841, 52.36883681161063, 55.160154002053396, 53.24288545336042, 54.75257614680699, 48.43915803091866, 56.62315280096871, 58.39278602600098, 65.26099000658307, 68.64511013031006, 67.63146523066929, 58.3862338747297, 59.587438447134836, 49.98372868129185, 51.458080836704795, 54.61920894895281, 59.21467454092843, 57.471114431108745, 58.96549824305943, 55.84678193501064, 57.84379495893206, 55.48043121610369, 54.39324310847691, 49.03007452828543, 49.17568792615618, 58.9904978615897, 62.043737820216585, 60.90153040204729, 58.733442306518555, 53.981579712459016, 55.55572189603533, 51.922720772879465, 50.88322857448033, 49.99961921146938, 48.947859968457905, 48.76051221575056, 45.250230176108225, 48.63394035611834, 49.380614621298655, 51.37453917094639, 54.22661140986851, 52.54630422592163, 53.80756207874843, 49.88112810679844, 45.99565723964146, 43.80682529721941, 49.203974042619976, 48.29006358555385, 45.43499319893973, 45.84974159513201, 47.49040583201817, 46.94439901624407, 49.59700584411621, 50.21545805249895, 52.12944705145699, 50.29138796670096, 51.611733300345286, 52.892230715070454, 60.61039393288748, 62.75209971836635, 61.388543537684846, 60.349502972194124, 60.334592138017925, 55.28846985953194, 61.15961429050991, 59.818153381347656, 64.14921569824219, 64.77215644291469, 70.48370770045689, 68.61516339438302, 73.56709589276994, 70.67679119110107, 73.6376895904541, 71.16947405678886, 76.07460348946708, 67.96190071105957, 73.4953418459211, 73.46653461456299, 79.04877989632743, 78.57399559020996, 54.137896810259136, 0.3931009035025324, 8.716510789734976, 5.517421628747668, 0.6945387284670557, 0.37501631677150726, 20.73516685622079, 85.10281481061662, 67.08343996320451, 60.94599887302944, 73.07835265568325, 48.55374424798148, 32.140157154628206, 61.587428774152485, 61.854767663138254, 70.30375630514962, 6.656519293785095, 0.40599469734089716, 0.2610224336385727, 0.17382529617420264, 0.21955987278904232, 0.28776173453245846, 0.17213706033570425, 0.16398580558598042, 0.09424438181200198, 0.14376156723925046, 0.17790823137121542], [0.08869929864470448, 0.016560015235362307, 0.06381565531981842, 0.07432579634977238, 0.023442977773291723, 0.07022278330155782, 0.024713217380589673, 0.054775282208408625, 0.07987232479665961, 0.12852206427071775, 0.19195477478206158, 0.22981590245451244, 13.52426382473537, 50.09204762322562, 48.356436252593994, 29.583258288247244, 39.64466673987252, 45.527129786355154, 52.68881177902222, 4.017279497214726, 0.20430629700422287, 1.8520232268742152, 1.956456823008401, 2.5616525198732103, 5.530736982822418, 83.74085671561105, 64.71755749838692, 86.629257610866, 77.64568846566337, 84.797865322658, 83.33104501451764, 81.02431256430489, 74.39640508379254, 82.19298567090715, 72.33296380724225, 69.57700252532959, 55.91564900534493, 62.26702513013567, 69.01769338335309, 74.47533661978585, 67.33560398646763, 69.39170796530587, 59.385190282549175, 60.70733519962856, 55.239936692374094, 55.46633332116263, 52.81878130776541, 52.499094690595356, 50.194519656045095, 52.137131759098594, 52.39208548409598, 51.52268866130284, 42.32592446463448, 46.718113558632986, 47.161262716565815, 48.49137026923043, 46.72014243262154, 50.335272789001465, 46.03424058641706, 51.77434894016811, 52.059304986681255, 50.01340096337454, 49.14875670841762, 46.52776418413435, 44.81164945874895, 47.542840412684846, 45.9330609185355, 45.83247879573277, 49.7784754208156, 50.968413489205496, 51.48311867032732, 50.242754050663535, 51.28450093950544, 49.21943725858416, 45.05950212478638, 45.279506410871235, 52.1147585596357, 57.611488887241904, 58.59188665662493, 59.92453724997384, 52.66803319113595, 47.233044556209016, 46.64212111064366, 52.20514072690691, 52.80560752323696, 58.84922708783831, 57.19009453909737, 59.045680454799104, 56.87623746054513, 59.11526666368757, 55.316026415143696, 55.40703739438738, 47.61346190316336, 44.02317483084542, 50.393651553562705, 50.822661127362935, 52.805663108825684, 54.472105162484304, 53.213320868355886, 52.60751438140869, 51.10493516921997, 48.57217781884329, 41.876469816480366, 41.40359973907471, 41.86377198355538, 40.38536902836391, 39.611923354012625, 42.527734892708914, 46.06246764319283, 47.30880076544625, 46.299085072108674, 46.86160775593349, 46.32469960621425, 41.563182490212576, 38.224621704646516, 42.12439891270229, 39.94818837302071, 41.11603116989136, 41.02895287105015, 41.850150040217805, 40.72123800005232, 43.02160937445504, 44.546499252319336, 45.899098123822895, 42.340720653533936, 45.49430649621146, 49.005293778010774, 52.735510621752056, 51.682948861803325, 54.23022099903652, 52.01462459564209, 49.56862245287214, 49.54031549181257, 55.41204704557146, 56.355789593287874, 61.022526332310264, 63.39976215362549, 65.86412838527134, 64.25318159375871, 68.62541893550328, 64.15759522574288, 67.6203203201294, 67.09300068446568, 73.79916572570801, 64.20344638824463, 68.56827000209263, 67.87638923100063, 74.73779092516217, 65.16905839102608, 79.19684600830078, 19.91963073185512, 0.9590846044676644, 2.7442681150776997, 0.13235928836677754, 0.04701142006420663, 2.3464127438408986, 54.30311802455357, 65.89998803819928, 41.76166820526123, 55.858903067452566, 44.8093079158238, 24.165193728038243, 53.955065386635916, 45.994340556008474, 40.30132014410836, 5.883657268115452, 0.2020591925829649, 0.09906521705644471, 0.03214985431571092, 0.14056648154343876, 0.021818726090714335, 0.025077855314261148, 0.11601065205676214, 0.02953914672668491, 0.04296262874933226, 0.05877354980579444, 0.02180741321561592, 0.062248605835650644, 0.09643852657505445, 0.05543505573379142, 0.01756723940239421, 0.05387276956545455, 0.06366316135972738, 0.05851777603051492, 0.08582086488604546, 0.08787473610469274, 0.2182169977043356, 0.27627600942339214, 23.400118895939418, 61.45642743791853, 55.48802212306431, 35.3168283871242, 42.055809770311626, 52.75114059448242, 60.061576570783345, 3.6226587295532227, 0.18958558834024838, 2.514146383319582, 3.1092967220715115, 1.1067459838730949, 7.743043848446437, 88.08995655604771, 70.0954006740025, 91.51868411472866, 81.54283578055245, 86.99783870152065, 83.66958209446499, 85.18664482661656, 75.32626165662492, 84.25631577627999, 75.20946938650948, 72.47943183353969, 58.3823915209089, 63.85261099679129, 71.31796400887626, 77.8863115310669, 69.52946989876884, 72.48112024579729, 63.54214463915144, 64.54642336709159, 57.886015687670024, 59.74809469495501, 55.55044821330479, 54.03933661324637, 52.628053256443565, 54.72595064980643, 52.84610857282366, 53.48220920562744, 46.19349329812186, 50.159677914210725, 49.497761249542236, 51.2288041796003, 50.49186086654663, 52.63175317219326, 48.292533670152935, 54.02787555967058, 54.24751159123012, 54.4370619228908, 52.01227610451834, 49.84133924756731, 47.44545793533325, 48.51254143033709, 48.31998600278582, 49.04935577937535, 53.44793026787894, 54.71103981563023, 53.55835451398577, 53.09246390206473, 52.617985316685264, 50.629744393484934, 48.93841389247349, 46.292473861149375, 55.49305609294346, 60.696412631443565, 59.90870925358364, 63.05884878976004, 52.581733090536936, 50.48716041019985, 48.82062455586025, 54.3812609400068, 53.25202580860683, 62.062372888837544, 59.10014738355364, 60.29739843096052, 59.75822516850063, 61.24691145760672, 57.051658630371094, 59.42288425990513, 49.50312525885445, 46.19742250442505, 53.644119603293284, 53.77961294991629, 57.159696170261924, 57.22118425369263, 57.24152857916695, 54.72839641571045, 54.048973764692036, 52.48374959400722, 44.535993576049805, 44.790349755968364, 45.392456327165874, 42.39153977802822, 42.418609959738596, 44.50238166536604, 48.89910445894514, 50.64257771628243, 50.417414392743794, 49.675325938633506, 48.777177470070974, 44.420795917510986, 42.44582952771868, 43.76750544139317, 42.94691971370152, 45.30118479047503, 44.4517605645316, 44.6053991317749, 41.221004554203574, 45.43466663360596, 45.482859339032856, 47.93372869491577, 44.960215841020855, 49.323820046016145, 51.43979665211269, 54.98031725202288, 54.8254314831325, 57.68952757971627, 54.96226235798427, 51.3483236176627, 52.917355401175364, 57.665479864392964, 60.13706180027553, 64.42844295501709, 66.73320211683, 67.99043001447404, 65.50049441201347, 70.7289513179234, 67.20276832580566, 70.26015635899135, 68.83481679643903, 73.68462467193604, 64.87412125723702, 72.13948426927838, 68.55376216343471, 75.85647869110107, 67.62587193080357, 81.92981570107597, 28.666061333247594, 0.5476595099483217, 0.9633396161454064, 0.789847765650068, 0.04073506613661136, 1.5572874822786875, 57.66192586081368, 72.84626197814941, 48.93754884174892, 57.627285616738455, 30.350183078220912, 28.436947958809988, 62.55966241019112, 52.720332281930105, 50.23150144304548, 7.052726856299809, 0.1214997289436204, 0.04944558980475579, 0.041215407861662764, 0.09770176878997258, 0.08310605306178331, 0.03557886156652655, 0.043350072244980505, 0.049256417634231706, 0.048211161579404554, 0.053596704200442345, 0.14023859985172749, 0.16722201050392219, 0.2121102096779006, 0.19597339843000683, 0.0944771600354995, 0.14123806836349623, 0.16718401254287787, 0.22781590691634587, 0.2600026497883456, 0.2367796530680997, 0.4292151970522744, 0.5727070601923125, 30.186771869659424, 74.65144566127232, 60.65218039921352, 40.88359655652727, 49.319671971457346, 60.363190923418315, 67.49996362413678, 5.235420737947736, 0.4166527997170176, 5.00931202513831, 6.568624147347041, 4.758422562054225, 7.064021153109414, 94.18615313938686, 74.84931646074567, 93.96149703434536, 86.04970836639404, 90.99620737348283, 85.15493324824742, 87.14070756094796, 78.28906386239188, 87.5267425264631, 78.2143359865461, 76.07105990818569, 62.66362830570766, 68.3467822756086, 73.67976093292236, 82.0718160356794, 72.8088459287371, 77.09279251098633, 67.40877546582902, 68.03814329419816, 60.78948375156948, 63.8961831501552, 59.592072895595, 58.99702916826521, 55.922263690403526, 56.8992464201791, 55.16438545499529, 58.1661878994533, 48.84635026114327, 54.12060274396624, 53.10206631251744, 55.10057667323521, 51.493197032383506, 56.497480733054026, 51.54705599376133, 58.131721360342844, 59.155906677246094, 57.04323741367885, 55.436299732753206, 52.084790979112896, 49.47811869212559, 53.02579246248518, 53.36819968904768, 49.98175539289202, 56.99999877384731, 58.43154307774135, 56.76656361988613, 57.66765465055193, 57.8493708883013, 54.8700076511928, 53.15364626475743, 48.63625063214983, 58.16479478563581, 64.26924582890102, 64.07571765354702, 67.66988182067871, 55.012376240321565, 53.90809209006173, 50.10668747765677, 56.387991019657676, 55.03936651774815, 64.40927982330322, 61.71519224984305, 63.41080284118652, 63.078025817871094, 63.74842970711844, 59.22623634338379, 60.15941415514265, 49.82011597497122, 49.849736145564485, 56.808989320482524, 55.5629688671657, 58.82278919219971, 60.181335721697124, 60.54196112496512, 57.82697684424264, 57.85987309047154, 55.076647077287944, 46.505773135593955, 46.136636189052034, 47.4751614843096, 45.9525089263916, 46.03965323311942, 48.12652383531843, 53.99926287787301, 53.608044556209016, 51.97495385578701, 54.35871403557913, 50.988684858594624, 46.39439698628017, 43.5798728125436, 48.12531137466431, 45.66567686625889, 48.14277914592198, 47.362374850681846, 48.23759773799351, 45.49299676077706, 49.97676658630371, 48.03911897114345, 51.45857415880476, 47.45425088065011, 51.883644104003906, 53.841462339673726, 59.734920910426546, 57.13418933323452, 60.73618412017822, 57.07984399795532, 53.59478044509888, 55.86549343381609, 61.270111492701936, 61.636622020176475, 66.97028854915074, 70.37355095999581, 72.33056667872837, 69.67576422010148, 73.10014915466309, 69.08900274549211, 72.83419990539551, 71.29248496464321, 79.07138238634381, 67.22932434082031, 76.53364317757743, 73.82156671796525, 80.58292130061558, 70.39719567980084, 86.82582909720284, 25.967283725738525, 2.5764793242727007, 10.213588765689305, 1.2947096292461668, 0.13173351623117924, 3.2277713247707913, 68.02525438581193, 78.94871888841901, 54.32829829624721, 75.6004306248256, 63.98209762573242, 29.38567236491612, 68.35658618382045, 58.225817339760916, 64.17061614990234, 11.673895137650625, 0.2589372412434646, 0.20809759785022053, 0.18648276983627252, 0.21268585164632114, 0.13754879204290255, 0.14305760072810308, 0.13007187896541186, 0.13876666740647384, 0.16648136238966668, 0.18138576405388968], [0.01485709929173546, 0.04161468500803624, 0.011687949748842843, 0.030794297411505665, 0.05512739438563585, 0.016191085567697883, 0.033494452879365, 0.026009600942156146, 0.028285521049318568, 0.06709380727261305, 0.16625003623110907, 0.11558147865746703, 27.196354048592703, 59.98078291756766, 38.48394584655762, 28.206081901277813, 62.074129240853445, 52.14091157913208, 51.66220848900931, 0.3505568392574787, 0.12921197153627872, 2.7634067109652927, 1.313063838652202, 1.709303862282208, 33.41975130353655, 78.74631786346436, 69.40504155840192, 85.25434112548828, 78.33845165797642, 82.94974872044155, 79.81163651602608, 79.71573747907365, 80.45806912013462, 80.15673269544328, 75.24770532335553, 75.34935052054269, 64.17978082384381, 54.64752285821097, 56.706413064684185, 65.98058019365583, 67.93426772526333, 68.39287662506104, 63.47137723650251, 59.482715197971885, 53.29095309121268, 53.786981514522004, 48.85657106127058, 53.153979778289795, 51.340138639722554, 51.85548652921404, 52.964175837380544, 46.29462432861328, 45.04059260232108, 47.95127984455654, 46.88249751499721, 48.35355275017874, 47.947614669799805, 47.295710359300884, 45.57065677642822, 49.84110648291451, 48.88225507736206, 48.2674298286438, 46.131588322775706, 46.99615267344883, 44.63966417312622, 44.93504251752581, 47.943275519779746, 49.659720284598215, 50.34002883093697, 50.255667277744834, 51.260380268096924, 49.1416973386492, 50.365344592503135, 50.5029536655971, 48.3994733946664, 47.08094501495361, 46.981738635471885, 54.313123430524556, 57.43128735678536, 61.74056012289864, 51.97428682872227, 43.739691802433555, 52.3932979447501, 50.20602239881243, 52.47593634469168, 59.17825903211321, 56.24872480119978, 54.487092426845, 56.46784666606358, 54.28634507315499, 56.35749537604195, 58.35552978515625, 52.40805244445801, 43.39593315124512, 48.16811227798462, 57.56938280378069, 54.89202996662685, 55.22542537961687, 54.659817695617676, 52.647633280072895, 54.38094827107021, 53.85315268380301, 46.88699994768415, 42.688471044812886, 41.44266945975167, 42.52304833275931, 40.24030801228115, 41.925833293369834, 42.696444102696006, 45.82482188088553, 47.70536920002529, 47.64872401101248, 45.866271359579905, 45.345604624067036, 40.1626410484314, 39.520099435533794, 41.21051277433123, 41.141256604875835, 39.052332809993196, 42.69684362411499, 40.73580142429897, 40.786714349474224, 43.54035840715681, 44.45492894308907, 45.701731068747385, 46.43734727587019, 47.629355907440186, 51.148979800088064, 52.3900739806039, 51.812202726091655, 48.459742069244385, 46.77433838163103, 51.783440658024375, 54.77296216147286, 58.39009012494768, 61.04050132206508, 63.48050022125244, 62.57391316550118, 62.04912267412458, 64.35204751150948, 67.51710483006069, 63.77117810930525, 68.27924578530448, 65.90186405181885, 65.86582374572754, 65.47015857696533, 70.91429451533726, 64.08136653900146, 69.25639874594552, 70.29849651881626, 70.935701915196, 2.4583801414285387, 1.1974740411554063, 0.9453839510679245, 0.03958379916314568, 0.06965191143431834, 28.041308845792496, 70.99358735765729, 50.00518471854073, 43.19900730678013, 40.2747745513916, 31.522583893367223, 32.81057841437203, 47.03069911684309, 29.848405020577566, 2.3736759551933835, 0.048902541265955994, 0.05350212998954313, 0.04290019674226642, 0.07039159602884736, 0.006848684645124844, 0.06104977695005281, 0.0422819020625736, 0.01696258158023868, 0.015029260589342033, 0.03613339431051697, 0.026714914345315526, 0.07584300743682043, 0.035989575420639346, 0.044970712424921136, 0.023932715512013862, 0.019435514330065677, 0.036040421442261765, 0.007168937058720205, 0.042995150932776074, 0.07536630265946899, 0.07150142147604908, 0.059395087882876396, 38.28493901661464, 66.51327078683036, 45.4121857370649, 34.10640008108956, 61.862966537475586, 60.30777209145682, 56.91804824556623, 0.2283132459436144, 0.06235920704369034, 2.7201428839138577, 0.942735167486327, 0.8633192117725099, 38.409322193690706, 85.04467923300606, 75.12684140886579, 87.65975189208984, 81.66363716125488, 84.87558092389787, 81.93966824667794, 83.08373083387102, 80.38047163827079, 81.34614617483956, 76.91828155517578, 76.83381230490548, 65.99332318987165, 58.941638129098074, 59.63781288691929, 70.04973711286272, 69.81344972337995, 71.14532906668526, 66.45798397064209, 61.65333938598633, 57.16493163790022, 55.60003055844988, 52.68881177902222, 55.316273076193674, 53.94822488512312, 53.22938162939889, 56.01556757518223, 49.23013053621565, 48.55129153387887, 50.86192192350115, 49.13047252382551, 51.88077449798584, 51.81121260779244, 51.45289748055594, 48.959109101976665, 50.73619079589844, 52.00513335636684, 52.39450693130493, 49.933430671691895, 48.32945639746529, 48.51342037745884, 47.95087684903826, 48.72067124502999, 51.688917364392964, 51.22013977595738, 53.720438616616384, 52.835272857121055, 52.39718198776245, 53.286989143916536, 53.94169705254691, 50.07018511635916, 48.2907966205052, 48.49252714429583, 57.16870103563581, 59.30904497419085, 64.03457042149135, 54.67719514029366, 47.44291836874825, 54.9226576260158, 49.385714599064414, 52.173251969473704, 60.728235380990164, 56.32668358939034, 58.404076848711284, 57.51141398293631, 56.36806011199951, 58.638773100716726, 59.60763686043875, 50.91316488810948, 43.910579272678916, 48.64533192770821, 57.71346412386213, 59.05490071432931, 58.84791387830462, 57.671087060655864, 56.350234508514404, 56.99973126820156, 55.17852503912789, 50.74055773871285, 45.77186271122524, 43.04982253483364, 45.353622845241, 45.04289245605469, 45.10476963860648, 44.93653638022286, 47.72006116594587, 49.01976687567574, 49.443238735198975, 48.89830889020647, 48.15458066122872, 42.59529570170811, 41.60593475614275, 43.69436870302473, 43.2849565233503, 42.976046562194824, 44.99637426648821, 42.954156262534006, 43.20191512789045, 45.62288638523647, 47.39782108579363, 46.03275714601789, 50.60518251146589, 52.18758610316685, 53.25703893389021, 54.4346786907741, 53.52874476569039, 49.10714047295706, 49.641773087637766, 53.96190588814871, 59.209810801914756, 61.19985130855015, 64.2069204875401, 66.12043353489467, 65.73043809618268, 66.34385286058698, 65.66670227050781, 69.79769120897565, 65.44652080535889, 69.79165322440011, 66.80462265014648, 67.9973087310791, 67.18362603868756, 74.37326758248466, 66.31135613577706, 72.32758590153286, 71.60570975712368, 77.79920891353062, 4.884291350841522, 1.470694037420409, 2.037531009742192, 0.30625811059560093, 0.17508256728095667, 28.081346103123256, 81.0343805040632, 57.44387401853289, 53.44920178822109, 34.67667695454189, 27.10069819859096, 40.324985708509175, 50.886820793151855, 42.64952291761126, 4.139402338436671, 0.05536469165235758, 0.008416396549104579, 0.07065680822623627, 0.051582557814461846, 0.08048157460455384, 0.06226969470403024, 0.034553802106529474, 0.05022179315398846, 0.052490729439471445, 0.043241381113018305, 0.11419797289584364, 0.1612256879785231, 0.11877888494304248, 0.12038811216396944, 0.15172512563211576, 0.10110415371933154, 0.1633309514394828, 0.1757920706378562, 0.10563236395163195, 0.2203672073249306, 0.35219197294541765, 0.25790206821901457, 43.32219191959926, 77.35956859588623, 51.78232199805123, 38.31052228382656, 76.93807697296143, 69.48372295924595, 63.00451387677874, 0.4769765170557158, 0.32884086881365093, 7.963577934673854, 8.446263211114065, 3.1420796258108954, 38.83885635648455, 93.41825212751115, 79.02260603223527, 93.09222875322614, 84.33398274012974, 88.95413180759975, 81.66707651955741, 82.91364588056291, 85.75425011771065, 84.53090163639614, 82.41152041299003, 80.4012120110648, 68.37324101584298, 62.0531039919172, 62.91186659676688, 73.9696467263358, 72.10960701533726, 76.13408006940568, 70.41733850751604, 65.5571847643171, 59.737992014203755, 60.1879643031529, 54.10978439876011, 59.961932454790386, 57.509676933288574, 55.4530587877546, 59.50136416299002, 52.12009825025286, 52.92146178654262, 55.93641717093331, 52.76358481815883, 55.45209298815046, 54.077801840645925, 52.70498718534197, 51.89125238146101, 54.849739755902974, 56.502288886478965, 55.630123206547324, 52.2468055997576, 52.89098003932408, 51.284400190625874, 50.52480227606637, 51.90076099123274, 55.61170700618199, 54.79208360399519, 56.00039618355887, 55.214176246098106, 56.15137011664254, 57.80143526622227, 57.403001240321565, 54.70055150985718, 52.947969164167134, 50.84352656773159, 60.41238416944231, 64.70594011034284, 69.65405804770333, 57.83078098297119, 49.512842314583914, 56.69842611040388, 51.47170972824097, 54.05685997009277, 63.4583215713501, 59.300623757498606, 59.84207602909633, 61.87269401550293, 59.58436039515904, 60.560728209359304, 62.33987004416329, 56.20350245067051, 46.09132351194109, 53.319600514003206, 59.865727697099956, 61.992175238473074, 61.44674859728132, 62.21291255950928, 57.950630460466655, 59.751728602818076, 57.911501680101665, 52.26491607938494, 46.97218138831002, 46.71038021360125, 48.26637717655727, 46.5095077923366, 49.13435656683785, 48.838526589529856, 51.30864592960903, 52.88077660969326, 53.181574548993794, 53.28110749380929, 53.001744747161865, 46.302395888737266, 44.18740592684065, 46.19521992547171, 47.479201861790244, 45.2190431867327, 48.39662115914481, 45.25625426428658, 45.73426948274885, 46.527736391339985, 49.308179650987896, 51.251677649361746, 53.288104329790386, 54.74709054401943, 56.37271193095616, 59.7431823185512, 58.34635121481759, 52.69604137965611, 52.26679556710379, 57.22880295344761, 61.25087193080357, 64.39882973262242, 66.21649238041469, 69.63097613198417, 68.54819665636334, 69.4814508983067, 68.11449010031563, 73.5381566456386, 69.11608682359967, 73.53735065460205, 70.54930564335415, 72.944502558027, 69.11024338858468, 76.55947657993862, 69.3022151674543, 76.36756038665771, 75.73164735521588, 79.23751381465367, 3.4651893164430345, 6.425651933465685, 4.59601319687707, 0.34723614315901485, 0.3867021011454718, 36.91337851115635, 84.14797251565116, 64.42250919342041, 59.93276391710554, 56.59629801341465, 40.593550954546245, 45.11635575975691, 59.33715738568987, 57.25170421600342, 8.133087924548558, 0.1743688705776419, 0.13522896223834582, 0.13125041286860192, 0.18022644626242773, 0.15257157092647894, 0.14838804969830172, 0.1061955208757094, 0.11560399244938578, 0.19339286190058502, 0.1818799003958702], [0.08926421297448021, 0.023081210042749132, 0.04165520711934992, 0.08904013356992177, 0.029607220752430812, 0.11868752698813166, 0.03762020702872958, 0.030118398501404693, 0.024421903637370894, 0.03395348521215575, 0.09574586445731775, 0.19182049270187104, 42.49325793130057, 55.55635070800781, 37.07532364981515, 44.1296420778547, 48.328560079847065, 56.52057307107108, 38.013928004673545, 0.13120116479694843, 0.21236740159136908, 2.819354474544525, 1.2410011397940772, 0.7817876924361501, 70.11903844560895, 68.52328736441476, 81.84480449131557, 79.53168664659772, 74.19380256107875, 80.66431944710868, 84.12187508174351, 75.09218379429409, 80.24542645045689, 76.65260328565324, 78.73369993482316, 72.69723006657192, 67.22911589486259, 57.01202263150896, 55.653792245047434, 54.218898909432546, 56.10071427481515, 54.604926926749094, 58.47382286616734, 52.307161126817974, 50.52983972004482, 51.4147310256958, 53.18103606360299, 50.742447648729595, 51.400817258017405, 51.21993827819824, 50.250754901341026, 42.19951936176845, 47.45701278959002, 47.83538736615862, 47.29602650233677, 46.95480046953474, 50.1725355557033, 45.796230043683735, 47.255330903189524, 47.79053327015468, 46.530616419655935, 45.640802315303254, 46.32752057484218, 45.18352746963501, 46.76997143881661, 47.04516526630947, 49.43149280548096, 51.07006563459124, 50.510464668273926, 51.568102087293354, 52.97305563517979, 49.98077917098999, 52.36995894568307, 50.83071061543056, 50.695953777858186, 49.394677775246755, 45.81774166652134, 50.08648211615426, 57.05097075871059, 56.58159909929548, 53.552931444985525, 46.35382645470755, 52.58956023624965, 44.752242360796245, 54.02731275558472, 58.25739342825753, 57.565467493874685, 53.12716667992728, 54.12240580150059, 53.035231590270996, 54.27584981918335, 51.39251068660191, 42.345393317086355, 41.16370970862252, 39.1583171572004, 45.58573089327131, 58.300729342869346, 55.2280205317906, 55.165299143110005, 55.670290742601665, 53.626241888318745, 55.29523740495954, 51.92526728766305, 47.21577480861119, 41.69207157407488, 40.09238086427961, 39.791770526341026, 39.22645814078194, 41.62904446465628, 42.76543624060494, 45.297710691179546, 44.36348022733416, 44.26367630277361, 43.62554332188198, 41.91203417096819, 40.508852413722444, 41.2588027545384, 41.93852417809622, 40.915954317365376, 41.031777313777376, 40.349346092769075, 38.80220113481794, 40.57660777228219, 44.39599084854126, 43.962503160749165, 43.32578761237008, 46.852915559496196, 46.94055666242327, 50.50781045641218, 46.01739467893328, 47.2322107723781, 48.360792773110525, 53.487187589917866, 52.96899788720267, 59.85128934042794, 59.850934982299805, 64.51961026872907, 62.86117948804583, 65.24809414999825, 62.14153371538435, 66.54257828848702, 61.42554269518171, 64.83944279806954, 62.98567731039864, 66.59136853899274, 65.5227494921003, 72.50640474046979, 61.693305424281526, 69.5629254749843, 67.10898848942348, 83.82495076315743, 28.946325608662196, 0.6929941113506044, 0.6465790048241615, 0.1818325115101678, 0.19541241281798907, 7.8682078293391635, 64.8189595086234, 55.68600409371512, 40.779651505606516, 36.10562263216291, 34.383907658713206, 18.15147921017238, 45.19494683401925, 35.295414039066856, 1.2989923251526696, 0.14467180839606694, 0.0072436819318681955, 0.09810613494898592, 0.028577855987740413, 0.09417091682553291, 0.04799733483897788, 0.02265342933657978, 0.03875641731013145, 0.016163725339408432, 0.010225661830710513, 0.03829848420407091, 0.04399217671847769, 0.03700265534488218, 0.05503330871995006, 0.04546223979975496, 0.04435979342088103, 0.03718074703855174, 0.05454916719879423, 0.02164628659375012, 0.042272589169442654, 0.10808922390320472, 0.6285997810108321, 52.40041290010725, 60.913495200020925, 48.553382941654746, 43.098011766161235, 46.321861267089844, 67.42841107504708, 39.64784901482718, 0.05446291182722364, 0.6246203088334629, 3.623937849487577, 1.7947039540324892, 1.2917827005897249, 76.55679457528251, 76.06545966012138, 87.02602754320417, 82.53055695125035, 81.36778286525181, 80.04386615753174, 85.88488319941929, 76.98614461081368, 80.37792859758649, 79.69740118299211, 80.54629039764404, 73.17957401275635, 68.1930742263794, 59.15979766845703, 56.58708470208304, 57.48259285518101, 59.30514703478132, 57.53482593808855, 60.53993919917515, 53.7065873827253, 54.58988755089896, 54.31063597542899, 55.54322556086949, 54.87567390714373, 53.984074115753174, 53.35995217732021, 53.09175865990775, 44.69623293195452, 50.35022531236921, 51.7915700503758, 49.50473376682827, 49.65744822365897, 51.61368574414934, 47.68285356249128, 51.22134876251221, 48.968499592372346, 50.49899666649954, 46.60767194202968, 49.078784874507356, 49.07536636080061, 49.56195913042341, 49.147669315338135, 51.513280800410676, 53.550256388528005, 53.74864482879639, 54.76858827045986, 53.74159588132586, 54.61956678118025, 54.709021363939556, 55.15156602859497, 53.68654530388968, 52.103478159223286, 48.76835673195975, 53.357357025146484, 59.80151244572231, 57.90709999629429, 56.63966866901943, 49.324198722839355, 51.69892277036394, 44.640164443424766, 56.47591699872698, 59.85110173906599, 56.36959218978882, 54.378019605364116, 55.53702776772635, 54.19861364364624, 56.016463892800466, 51.50943497249058, 42.66815103803362, 41.09673602240426, 43.16525990622384, 49.79325771331787, 58.70293276650565, 58.91124670846121, 57.04382106236049, 58.15225328717913, 57.707231589726035, 57.36097853524344, 53.73639168058123, 50.378980432237896, 43.88528782980782, 44.555278301239014, 42.3827120917184, 41.89462545939854, 44.3159510748727, 45.92421933582851, 47.40557180132185, 47.817916120801655, 44.94272722516741, 46.222811222076416, 44.90961905888149, 44.2987334387643, 43.16276897702898, 43.251361983163015, 42.41074112483433, 42.89792449133736, 42.676627840314595, 42.82102530343192, 44.24910593032837, 47.18442801066807, 47.47602653503418, 46.13730321611677, 50.19715302331107, 50.84061874662127, 51.79752813066755, 49.28568485804966, 49.642457485198975, 50.94116265433175, 54.53863416399275, 55.61125537327358, 60.50321796962193, 62.710250718253, 66.2315421785627, 65.38991383143834, 66.9989846093314, 66.35876369476318, 69.74774060930524, 65.7349544252668, 69.08228383745465, 65.43933636801583, 68.28963334219796, 66.35395554133824, 73.66948454720634, 64.25400842939104, 70.92706530434745, 69.34310531616211, 84.21823269980294, 37.806246348789756, 0.3166460474686963, 0.5525001244885581, 0.7176953916038785, 0.2769036000328404, 7.322504128728594, 69.32356003352574, 62.531563895089285, 49.77290643964495, 38.51550109045846, 27.612346172332764, 26.823956659861974, 49.01497956684658, 50.4871187210083, 3.179035791328975, 0.24194672437650816, 0.07751583374504532, 0.06611050825033869, 0.008658748053546463, 0.06877212971448898, 0.009849069806348, 0.03697698636512671, 0.041862519923597574, 0.06677090602793864, 0.03532832947426608, 0.2139082731945174, 0.11941803778920855, 0.17381594596164568, 0.2473788314632007, 0.17415262146719865, 0.19024483939366682, 0.10245608724653721, 0.1749838132943426, 0.1141172136579241, 0.2250079797314746, 0.27495226902621134, 0.8136314494269234, 62.23878070286342, 72.69042083195278, 50.28408193588257, 58.93719128199986, 63.343196868896484, 72.95300020490373, 45.44264663968767, 0.27165100617068155, 0.5957394157137189, 7.543477688516889, 7.868173956871033, 1.0762533800942558, 82.69881452832902, 79.89976746695382, 91.71203858511788, 84.63696588788713, 87.02558285849435, 81.79880741664341, 90.33956786564418, 82.54249395642961, 83.83668627057756, 82.76453753880092, 83.96219852992466, 77.64947523389543, 73.38231549944196, 63.36043534960066, 60.67350442068917, 59.821134158543174, 62.93265560695103, 59.284552574157715, 66.17131519317627, 57.56748941966465, 56.97482892445156, 56.427891050066265, 58.819245610918315, 57.10182115009853, 57.70289938790457, 57.50130435398647, 56.97340454374041, 48.42851339067732, 51.873061997549875, 55.75808123179844, 53.57306732450213, 53.98073550633022, 55.55842474528721, 51.81330748966762, 53.16335637228829, 53.09021963391985, 54.35125861849104, 50.29820762361799, 52.92059326171875, 51.49608400889805, 52.158778871808735, 53.039782660348074, 54.09607907703945, 56.36005578722273, 56.96399668284825, 57.81723199571882, 57.005077907017295, 57.56828498840332, 58.158020292009624, 58.560293197631836, 54.71071672439575, 56.044048241206575, 52.45762436730521, 56.30362946646554, 62.69208117893764, 61.05158369881766, 59.57561261313302, 53.32417937687465, 56.13238416399275, 44.74407475335257, 57.63116271155221, 62.92745835440499, 58.74451078687395, 55.28886938095093, 55.868019104003906, 55.40783296312605, 58.579998288835796, 52.95399325234549, 43.03484569277082, 42.61529609135219, 45.53804540634155, 55.17958811351231, 61.16283825465611, 61.05750356401716, 62.20228181566511, 60.53138596670968, 59.90744468144008, 60.83159678322928, 55.30946036747524, 53.715467180524556, 47.43070690972464, 46.12747498920986, 45.66639947891235, 44.25486251286098, 49.429672377450125, 48.62483821596418, 51.89371204376221, 51.28878450393677, 48.51180144718715, 49.00288275309971, 46.98532738004412, 47.906769684382844, 47.69845226832798, 46.05505738939558, 45.34942960739136, 45.57505151203701, 44.58800431660244, 44.753760542188374, 46.66758973257882, 49.213680676051546, 49.49669122695923, 48.855706010546, 53.91233743940081, 51.91172177450997, 56.452786445617676, 51.94635854448591, 53.862814153943745, 52.929705824170796, 58.989504269191194, 58.71375805991036, 64.63355377742222, 64.54406792776925, 70.49365057264055, 68.03720528738839, 70.75854369572231, 68.69028036934989, 73.22714138031006, 70.0543646131243, 72.30214854649135, 69.82590089525495, 71.35886805398124, 69.85348524366105, 78.7422879082816, 67.47237232753209, 75.98183114188058, 71.96090166909354, 86.81804016658238, 36.24513898577009, 1.2836418002843857, 2.978453891617911, 0.7533359048621995, 0.5164871769292014, 10.593334742954799, 77.45746176583427, 69.49178286961147, 55.401854038238525, 52.702659538814, 46.2066844531468, 30.41643762588501, 57.265506812504356, 62.642151423863, 6.864194001470294, 0.5199569336005619, 0.2377522380224296, 0.17463092080184392, 0.18896751079176152, 0.15142889081367425, 0.13258304207452706, 0.11073295239891325, 0.18081259195293697, 0.21033419854938984, 0.07248857457722936], [0.03311198643807854, 0.060550110547670295, 0.0835570345765778, 0.061616048349865844, 0.049097623476492505, 0.07669009055410113, 0.021502844290807843, 0.05810268223285675, 0.0690093319863081, 0.10210417862981558, 0.08964225876012019, 1.9449701479503085, 50.353511810302734, 49.60787977491106, 21.76540231704712, 43.15976388113839, 43.790688105991904, 69.72895268031529, 23.898575714656285, 0.26916686232600895, 0.28819550839918, 0.5186820477247238, 2.8233258043016707, 9.971347638538905, 86.07968984331403, 63.65683160509382, 93.38478960309709, 77.73702253614152, 88.91023308890206, 77.73546613965715, 76.2109271458217, 75.77703993661063, 79.95256682804653, 72.01994746071952, 77.69962038312639, 69.3985241481236, 68.54222815377372, 57.948716231754844, 54.99901485443115, 52.89198752811977, 56.16081271852766, 49.98751197542463, 49.97202444076538, 50.00956903185163, 52.03462151118687, 51.871422222682405, 51.592309611184255, 51.2666197504316, 50.966071946280344, 52.24017007010323, 46.94967269897461, 43.5775590624128, 48.65405886513846, 47.16148158482143, 47.5777724811009, 46.53414263044085, 49.5314530645098, 46.86017990112305, 48.6519535609654, 45.632700715746196, 46.64852040154593, 44.21607072012765, 48.14558274405343, 45.641910552978516, 48.49856512887137, 49.39109250477382, 51.875136034829275, 53.559295994894846, 51.938138825552805, 51.53552893229893, 52.167009013039724, 52.43994467599051, 53.78490400314331, 53.419647625514436, 63.49814864567348, 49.751704011644634, 48.5814779826573, 50.75211606706892, 55.336186613355366, 55.97730384554182, 48.67469154085432, 47.47126007080078, 48.19359132221767, 44.76191077913557, 49.07374048233032, 47.745300497327534, 51.17622021266392, 56.81479801450457, 55.62365443365914, 56.304786341530935, 54.35590696334839, 49.417582511901855, 44.00655821391514, 40.23652819224766, 41.115249497549875, 43.14725364957537, 47.613354206085205, 57.03417696271624, 54.71618495668684, 54.37237419400896, 52.349625042506624, 54.34479679380144, 53.39355019160679, 50.68703229086739, 44.01827982493809, 39.172644342694966, 39.1268070765904, 39.78546156202044, 40.38976376397269, 41.45444665636335, 43.57560314450945, 45.8484422819955, 43.69021715436663, 44.0255754334586, 41.80145706449236, 39.318035398210796, 40.71115616389683, 40.81940214974539, 40.507011141095845, 41.06124462400164, 41.771979331970215, 39.845528738839285, 41.39547382082258, 43.568814754486084, 43.283441816057476, 45.02267319815499, 45.64364760262625, 47.03930793489729, 44.60101481846401, 44.65201807022095, 46.92233848571777, 46.38437073571341, 48.18907151903425, 50.77086230686733, 53.769857679094585, 56.05619716644287, 56.95583254950387, 62.73907879420689, 61.82425117492676, 67.78898089272636, 64.7790699005127, 62.494140897478374, 66.57985537392753, 66.22864477975028, 64.21302795410156, 65.9555527823312, 68.29883275713239, 62.93954127175467, 62.23602226802281, 70.27275344303676, 69.49317250932965, 72.4846499306815, 2.8364537741456712, 0.3178623622017247, 1.5659623082195009, 0.10868224993880306, 1.0004296430519648, 46.588498388017925, 64.95108645302909, 43.857703481401714, 35.529721191951204, 32.820083550044465, 29.33785833631243, 34.91668163027082, 40.82892118181501, 3.278646469116211, 0.17135190032422543, 0.05649324127339891, 0.016060749168640802, 0.00797582630600248, 0.024500630662909577, 0.06017460248300007, 0.03339310010362949, 0.04424812012751188, 0.032043683941343, 0.03163705826071756, 0.06420915134783302, 0.08387864660471678, 0.03509651816317013, 0.07417900886918817, 0.08555647371602909, 0.05549710097589663, 0.039764767845294306, 0.11312323449445622, 0.1117121327136244, 0.07707668588097606, 0.24499853061778204, 3.6540341888155257, 60.91585063934326, 55.163058349064414, 31.286633491516113, 38.15094300678798, 42.74592569896153, 81.3611751283918, 22.185280220849172, 0.11147952412388154, 0.8131629345672471, 3.8394598960876465, 1.9980706700256892, 11.549301777567182, 94.47175189426967, 70.00897897992814, 94.27551392146519, 79.4945902143206, 89.34170927320207, 78.53718403407505, 79.9422834941319, 78.61847100939069, 82.59158992767334, 74.43945612226213, 79.14752769470215, 70.99009241376604, 71.08460181100028, 59.950620787484304, 59.40620163508824, 55.700303486415315, 55.82775776726859, 53.28341776984078, 54.624409675598145, 53.508931977408274, 55.827361719948904, 54.489941188267295, 54.3415971483503, 53.88351631164551, 55.852910246167866, 54.182393074035645, 50.66625370298113, 45.209378242492676, 51.78024101257324, 49.27905280249459, 49.5013222013201, 47.83313962391445, 51.67901965550014, 49.500068051474436, 50.45495203563145, 49.50120408194405, 49.27792372022356, 46.72976916176932, 49.31313024248396, 48.04902362823486, 50.41967255728585, 51.579806327819824, 55.22278159005301, 55.838982582092285, 54.47931391852242, 52.505532196589876, 55.16073417663574, 55.15659305027553, 57.72215632029942, 56.844630105154856, 64.0490643637521, 52.99970545087542, 51.9540502003261, 53.508581093379426, 59.261581829616, 59.71549374716622, 52.69449887956892, 48.872604029519216, 49.702715737479075, 45.21364443642752, 49.70665884017944, 46.17245762688773, 53.46467195238386, 57.66523320334298, 58.31384754180908, 59.09670802525112, 55.435090746198384, 51.22764730453491, 46.04011181422642, 42.17587464196341, 42.259933948516846, 47.09748520169939, 49.77476855686733, 58.413415227617534, 56.73329564503261, 55.99472645350865, 54.64224222728184, 57.34280204772949, 55.027443408966064, 52.44700057165963, 45.26096166883196, 42.74385166168213, 41.611059052603586, 42.756195136478965, 43.737933908190044, 42.75654949460711, 45.34703247887747, 46.52230984824044, 46.13633394241333, 46.21725961140224, 45.40161405290876, 42.53791747774397, 43.586153984069824, 43.182494912828716, 43.40501792090279, 43.45381164550781, 45.35023212432861, 40.99848502022879, 43.7385835647583, 46.12893063681466, 45.74819367272513, 47.77057804380144, 49.68761730194092, 49.02199029922485, 47.492340905325754, 47.68528890609741, 48.24573060444423, 48.96440362930298, 50.263876574380056, 52.77666480200631, 55.197448457990376, 58.09222779955183, 57.617554664611816, 64.18445696149553, 65.10451657431466, 66.8404267174857, 66.96096406664167, 64.52108328683036, 69.28822844369071, 68.63678618839809, 65.37000029427665, 69.8569871357509, 71.03629793439592, 66.10161781311035, 62.2098970413208, 73.1029006413051, 70.04048211233956, 79.05205249786377, 5.542004789624896, 1.3011867616857802, 1.2667783051729202, 0.17513648367353848, 0.6093963171754564, 48.52105297361101, 73.31548077719552, 50.82478380203247, 43.79629530225481, 29.08552929333278, 34.20645066670009, 40.93962682996477, 53.90610490526472, 6.206463626452854, 0.22106023585157736, 0.11878543959132262, 0.06877682517681803, 0.06529507200632777, 0.015517458053571838, 0.08411211693393332, 0.022417227903913175, 0.05913595535925456, 0.02155998202839068, 0.029691060539335012, 0.142642364438091, 0.14052624441683292, 0.16522903101784842, 0.2654768260461943, 0.17277121916413307, 0.20123066061309405, 0.14120222814381123, 0.18734212086669036, 0.19173950276204518, 0.26488009520939415, 0.32503306599599974, 4.377909243106842, 68.91744477408272, 66.21724278586251, 32.55622223445347, 57.354481969560894, 61.18195969717843, 84.08677278246198, 27.692679507391794, 0.4284122187112059, 0.7754268880401338, 6.953496158123016, 4.99898396219526, 12.122351850782122, 97.58650425502232, 73.33592932564872, 99.16975552695138, 83.64946011134556, 90.17663955688477, 80.46551064082554, 86.75325516292027, 78.90832206181118, 87.28334018162319, 78.22907311575753, 86.55622509547642, 74.47961671011788, 76.2352180480957, 62.827786445617676, 63.75520420074463, 59.60958930424282, 60.04856954302107, 55.58082226344517, 59.79496029445103, 56.40072011947632, 58.127090385981965, 57.01433290754046, 56.39743709564209, 57.9597430229187, 56.37693296160017, 56.20663956233433, 53.950236388615195, 49.137927940913606, 55.44780247552054, 52.87502697535923, 52.14938490731375, 51.95847967692784, 56.369147505079, 50.71557549067906, 54.282165731702534, 52.425871099744526, 52.931477614811485, 50.17712484087263, 52.66203689575195, 51.18493325369698, 52.670666558401926, 55.350110803331646, 58.84173692975725, 59.084861346653526, 57.87854290008545, 56.693072523389546, 58.10998739515032, 58.99811308724539, 60.55214023590088, 60.01616314479283, 63.851895332336426, 56.26229115894863, 54.62711252485003, 57.29678760256086, 62.61489364079067, 63.45982238224575, 55.25552497591291, 54.26807478496006, 51.33444806507656, 46.001354762486045, 51.23748942783901, 48.83170345851353, 54.065513951437815, 61.143543107169016, 60.833000319344656, 62.4603031703404, 57.71930408477783, 53.337797846112935, 49.93644618988037, 41.01153026308332, 44.900551659720286, 49.556233814784456, 53.68405784879412, 62.11208030155727, 60.44563824789864, 58.484488351004465, 58.397337096078054, 60.889690671648296, 57.41039064952305, 56.968943800245015, 49.95920154026577, 44.35926961898804, 43.21337965556553, 45.69733285903931, 47.0188489641462, 46.84153093610491, 48.49764796665737, 51.53297199521746, 49.820786476135254, 49.61861474173409, 47.94733674185616, 44.47717707497733, 45.944528920309885, 46.49787998199463, 45.96570702961513, 45.29614039829799, 47.00987189156668, 44.3797424861363, 46.69275958197457, 49.37990590504238, 49.118667534419465, 50.73398126874651, 53.09825522559029, 51.576769965035574, 50.11325699942452, 50.25051171439034, 51.48059300013951, 51.70722239358084, 52.76432132720947, 54.954355307987754, 58.960787364414756, 61.58224541800362, 62.148287364414756, 68.53763539450509, 67.3494656426566, 72.46295070648193, 69.39919812338692, 67.43970884595598, 71.1606012071882, 71.13306549617222, 67.6800261906215, 71.61856392451695, 72.5720443725586, 69.08169324057442, 65.34885692596436, 73.86537511008126, 72.43551227024624, 79.60388537815639, 4.0439201933997015, 2.4435442175183977, 4.903141379356384, 0.20224806959075586, 1.6176952293940952, 56.70431470870972, 78.41087968008858, 57.51201152801514, 51.84454659053257, 44.79404967171805, 42.32036937986101, 47.19992249352591, 65.93199144090924, 10.630563191005162, 0.35217948790107456, 0.19059547914990357, 0.17338845532919678, 0.143756274666105, 0.09941555825727326, 0.16765068178730352, 0.11097124711211238, 0.12067522747176034, 0.12606325692364148, 0.14578586790178502], [0.041915164063019414, 0.029290002238537585, 0.021502340478556495, 0.06344952460910593, 0.04460090744708266, 0.08026839925774507, 0.0974456218204328, 0.045955721355442486, 0.07087081817111798, 0.18247534201613494, 0.18007095317755425, 4.757049858570099, 58.52970027923584, 43.60155119214739, 25.638524498258317, 44.374368054526194, 38.400094985961914, 70.36676951817104, 9.001214095524379, 0.1969845106026956, 1.3122716354472297, 16.60940817424229, 3.8323987892695834, 25.206581047603063, 83.99400738307408, 71.70037201472691, 92.50596060071672, 76.3271427154541, 87.83869579860142, 71.26564407348633, 78.09504931313651, 76.65116500854492, 77.69369356972831, 72.9783124923706, 71.85395499638149, 62.767038345336914, 61.6839531489781, 55.31561647142683, 54.99693039485386, 52.49551984242031, 52.131785120282856, 50.15249695096697, 53.32672936575753, 49.59136043276106, 53.35643638883318, 49.89323534284319, 51.936474731990266, 49.37375674928938, 52.192178862435476, 52.0555807522365, 45.68079614639282, 44.57031767708914, 47.81299679619925, 46.187250341687886, 46.49050446919033, 48.36092826298305, 50.29134975160871, 46.6706087248666, 47.01475300107683, 46.31498602458409, 45.6117901120867, 44.54874699456351, 45.81920426232474, 43.76012645448957, 48.9905948638916, 50.23241860525948, 54.58176163264683, 54.61428615025112, 52.97260400227138, 51.08578245980399, 54.83863653455462, 56.95731251580374, 55.047989232199534, 59.099410874503, 61.39727047511509, 52.42463779449463, 49.89526769093105, 49.078440938677105, 56.059167521340505, 53.53305959701538, 47.52653993879046, 41.95540830067226, 44.276242119925364, 44.88451174327305, 43.176783493586946, 49.562733854566304, 55.35041652406965, 52.27538354056222, 49.27290712084089, 47.929434708186555, 54.360253061567036, 52.2372761453901, 47.61726256779262, 46.047834736960276, 39.06900153841291, 43.278991494859966, 44.17188017708914, 51.737443583352224, 53.81799827303205, 53.35296923773629, 53.57500239780971, 50.86209562846592, 51.43497460229056, 48.5003890310015, 45.88676159722464, 40.17796182632446, 41.793400628226145, 40.150512967790874, 40.55892808096749, 38.23836176736014, 40.24320888519287, 39.59252745764596, 42.794465814317974, 41.70523146220616, 41.205503123147146, 40.20240906306675, 40.86156381879534, 41.036397865840364, 41.690824372427805, 40.952560901641846, 39.93016821997506, 40.41011503764561, 38.305279867989675, 40.07806062698364, 43.973366669246126, 44.80776194163731, 43.94878741673061, 44.55193969181606, 45.798088686806814, 46.524981430598665, 44.59919786453247, 45.49260418755667, 47.019529887608115, 47.313727038247244, 50.24081550325666, 50.309897967747276, 52.42676394326346, 52.64629922594343, 59.35857173374721, 61.466474533081055, 60.923132351466585, 65.5841646194458, 66.02005290985107, 67.10971805027553, 65.54858289446149, 70.85829203469413, 66.6202174595424, 63.17949731009347, 55.170030866350444, 72.73944732121059, 67.17747688293457, 82.45491886138916, 28.140951224735804, 0.5044045309935297, 1.165881450687136, 0.05345196250293936, 0.055720227038753886, 22.444760697228567, 72.79359463282994, 49.47155611855643, 41.154461656297954, 31.76984248842512, 24.844569478716167, 30.989789077213832, 53.182133878980366, 5.735910773277283, 0.17321551032364368, 0.0397970016513552, 0.04457101119416101, 0.03040048247203231, 0.03942738327064684, 0.03260642017370888, 0.048025548325053284, 0.05446935112455061, 0.009872758312017789, 0.05346309047724519, 0.03432903738160219, 0.10525648269270148, 0.02146304481928902, 0.10340279966060605, 0.04296704601230366, 0.06071136439485209, 0.035837515722960234, 0.04826238079528723, 0.10834893996694259, 0.3104660319430487, 0.38286026301128523, 9.503581881523132, 67.83831310272217, 53.64855602809361, 30.494302613394602, 34.52043628692627, 43.94245065961565, 79.04482637132917, 8.356679218155996, 0.10468276097838368, 2.012073678629739, 25.150811331612722, 5.9703842486654, 29.564439092363628, 94.08866991315568, 72.71794264657157, 95.12338175092424, 76.7132124219622, 90.78965827396938, 74.66672474997384, 83.64306082044328, 79.29179314204625, 79.58098411560059, 74.0537338256836, 73.72787720816476, 65.3007892881121, 64.21234008244106, 56.94490998131888, 58.40219388689314, 54.898095743996755, 56.44120727266584, 52.3043019430978, 57.63059295926775, 52.39620229176113, 55.14405502591814, 52.651447841099326, 55.93730306625366, 50.56504624230521, 55.023740019117085, 53.74543476104736, 47.414215360369, 47.74981335231236, 49.94281421388899, 48.925615310668945, 50.581749711717876, 49.36262226104736, 54.181868485042024, 49.57425396783011, 50.495328017643516, 49.041577271052766, 48.507660320826936, 47.138733182634624, 47.82689666748047, 47.301397459847585, 52.077526637486045, 52.80625023160662, 57.888958249773296, 56.11114699499947, 56.04260301589966, 54.44754328046526, 57.72877100535801, 60.16668891906738, 60.92457757677351, 58.79111235482352, 65.32706042698452, 55.74127006530762, 54.61231286185128, 51.13395432063511, 59.01475402287075, 54.94233839852469, 50.60123940876552, 44.609234537397114, 45.00497613634382, 44.958878312792095, 46.12978179114205, 51.12525517599923, 55.86726175035749, 53.05824402400425, 50.533060210091726, 50.463196073259624, 55.06203154155186, 54.213427203042166, 53.82029465266636, 46.487200600760325, 41.52682951518467, 43.88221672603062, 47.891970021384104, 52.24986975533621, 55.58717291695731, 55.94432422092983, 56.666169098445344, 53.294798919132774, 52.94095148359026, 51.182741097041536, 48.879736355372835, 43.252015113830566, 43.94732482092721, 43.10271222250802, 42.91398525238037, 42.19395385469709, 43.28578335898263, 42.55894272668021, 44.533318519592285, 43.327680996486116, 44.71575042179653, 42.412912436894004, 43.5183812550136, 44.84893349238804, 44.3130258832659, 42.47307341439383, 43.251011099134175, 42.781844411577495, 41.038183552878245, 42.341481481279644, 47.40201084954398, 47.2438976424081, 47.69234480176653, 45.87869126456124, 48.82683971949986, 48.66957766669137, 47.708315236227854, 49.03082493373326, 49.29020466123308, 49.37545905794416, 52.321842670440674, 51.07350499289376, 54.10666465759277, 54.62183884211949, 60.18556022644043, 62.80683067866734, 62.69026075090681, 67.94864354814801, 67.93419824327741, 68.93111188071114, 65.8231895991734, 71.60171454293388, 68.76022788456508, 64.8081203188215, 58.39469678061349, 73.50292233058384, 70.5556424004691, 81.95370360783168, 37.14593471799578, 0.2635185196995735, 0.5980286300182343, 0.21286137508494513, 0.0657394513753908, 20.819009031568253, 80.99158654894147, 54.86929893493652, 50.944539478846956, 25.688224962779454, 27.349370752062114, 40.81749486923218, 62.856468609401155, 9.083531141281128, 0.30647670743720873, 0.07188796252012253, 0.003518104411861194, 0.04329218642253961, 0.02469738376592951, 0.03555926208251289, 0.06960738596639462, 0.06172740273177624, 0.02477562054991722, 0.05265033105388284, 0.1308797834707158, 0.1821587918592351, 0.11973829274731022, 0.25275204171027454, 0.22778613279972756, 0.21816793962248734, 0.30519172496029306, 0.29404524021915024, 0.2454206065407821, 0.5423904955387115, 0.55940109704222, 11.151688507625035, 80.6719833101545, 58.21567644391741, 35.10916410173689, 60.363885743277415, 54.087133271353586, 82.68636335645402, 11.717349171638489, 0.22818901975240025, 2.9401704030377522, 30.75225101198469, 7.532284140586853, 32.502363273075645, 99.8304110935756, 74.96223858424595, 99.31493813650948, 77.74546459742955, 95.43536281585693, 78.48684433528355, 86.58316326141357, 82.40932478223527, 85.05957617078508, 77.48551164354596, 77.50277096884591, 67.4837395804269, 68.90842601231166, 59.752270562308176, 60.694800649370464, 58.561759267534526, 58.690155029296875, 55.6574261529105, 61.02915491376604, 54.627873352595735, 58.132270268031526, 55.84709112984793, 58.624939237322124, 53.86231735774449, 57.16695703778948, 57.46789394106184, 52.82274178096226, 50.24349403381348, 53.77521126610892, 51.77172599520002, 51.93769414084298, 52.22977556501116, 57.870118209293906, 52.46082401275635, 53.47422572544643, 51.85383633204869, 51.808068547930034, 51.25067016056606, 51.10395547321865, 49.59965658187866, 55.11410828999111, 55.68044900894165, 61.03659643445696, 59.39637688228062, 59.955130168369834, 55.47983019692557, 61.904648780822754, 60.10030582972935, 64.20476654597691, 60.55203601292202, 68.13991355895996, 59.25483512878418, 56.9049265725272, 55.374054295676096, 61.88681970323835, 59.25237546648298, 53.46312945229666, 47.561458110809326, 46.63744497299194, 45.639982427869526, 45.20499740328108, 51.00513471875872, 57.0032296861921, 54.97196551731655, 50.905344690595356, 50.58685316358294, 56.015699590955464, 56.6674336705889, 56.194494111197336, 47.26662172589983, 43.78878429957798, 49.20917476926531, 51.044836725507466, 57.31633635929653, 57.53727517809187, 58.76825278145926, 59.09681224822998, 56.46843726294381, 55.850464480263845, 53.79584394182478, 51.88391855784825, 46.153530733925955, 46.575182165418354, 46.19936105183193, 45.57255710874285, 45.37889344351632, 44.780705656324116, 45.91114282608032, 48.82899366106306, 46.54563842500959, 48.6045321055821, 46.888587611062185, 47.330381870269775, 48.094937324523926, 46.06612934385027, 46.0660285949707, 45.237230096544536, 46.30675935745239, 43.852732045309885, 45.24149629047939, 48.69872535978045, 49.777936935424805, 51.19659233093262, 48.03975125721523, 52.620729855128694, 50.97990928377424, 50.09371171678816, 50.581843512398855, 52.90522384643555, 51.79342174530029, 57.07901021412441, 54.97310502188546, 58.32288714817592, 58.49667549133301, 65.60466875348772, 68.47342709132603, 66.31512205941337, 70.96819169180733, 71.87943404061454, 71.18330792018345, 68.73125389644078, 75.24684374673026, 72.17636530739921, 68.61412116459438, 61.21290002550398, 78.23223454611642, 72.97723552158901, 86.72078623090471, 34.62918949127197, 0.9683764087302345, 4.309101232460566, 0.29477906227111816, 0.11357450099395854, 28.271773644856044, 86.7411583491734, 60.691792079380576, 57.354930128370015, 43.496063641139436, 34.21731764929635, 45.283956732068745, 75.27306624821254, 10.850508417401995, 0.3731222269790513, 0.24984324350953102, 0.1928809615118163, 0.22349940639521393, 0.13494905297245297, 0.07400394004902669, 0.18584145924874715, 0.23076889131750378, 0.09715210792741605, 0.21538285192634377], [0.08273437193461827, 0.05422171298414469, 0.04467530541920236, 0.05719301783080612, 0.07120990926133734, 0.05281875701621175, 0.04572168444948537, 0.07797984991754804, 0.005749683103723717, 0.19403223187795707, 0.2031752062695367, 14.454340134348188, 60.56609221867153, 38.2174129486084, 34.53742463248116, 44.80201230730329, 45.80233403614589, 69.3023819242205, 2.4418406060763767, 0.11473324203065463, 1.8370190262794495, 2.7729622210775102, 3.1337687117712836, 39.21457324709211, 79.11515603746686, 81.873521396092, 84.80781514304024, 78.53212574550084, 74.70053468431745, 75.91003540584019, 79.72527735573905, 73.8768813269479, 76.01075649261475, 68.92021710532052, 61.24094295501709, 56.217113971710205, 54.906867844717844, 53.056051867348806, 54.71570553098406, 51.11528103692191, 53.53215285709926, 49.89996119907924, 50.4933443069458, 49.109777314322336, 52.67938654763358, 49.42194250651768, 51.43964726584298, 49.786896637507844, 51.92251927512032, 46.93603685923985, 44.44028214045933, 45.9224579674857, 46.52003083910261, 46.94641399383545, 48.563982418605256, 49.61729110990252, 51.751868043627056, 49.159022671835764, 49.575219767434255, 45.984762464250835, 45.23492329461234, 45.15597438812256, 45.17664180483137, 43.83710207257952, 50.876238686697825, 52.70503234863281, 55.07505593981062, 53.312732219696045, 54.185113293784006, 54.36912243706839, 54.090708119528635, 58.869752066476, 55.31472710200718, 60.48020553588867, 52.812010288238525, 56.38915136882237, 48.9742249080113, 49.47143452508109, 53.29488229751587, 56.15562241418021, 44.35129656110491, 39.06668431418282, 45.215913023267476, 43.5443605695452, 56.654749734061106, 58.864290782383506, 56.53658866882324, 54.591857365199495, 54.82092557634626, 55.14730678285871, 55.41746316637312, 55.057001045772004, 58.10554749625069, 46.984552655901226, 42.54695013591221, 37.58054453986031, 45.28490168707711, 48.837341921670095, 52.22830254690987, 53.09183161599295, 51.949252469199045, 48.094576018197195, 49.87853642872402, 49.04442950657436, 46.09790693010603, 41.2059999193464, 42.59909289223807, 39.363209111349924, 40.93370696476528, 39.915114947727744, 38.306016377040315, 39.70028706959316, 40.797004631587434, 39.71513884408133, 40.39933490753174, 41.27777133669172, 40.42363623210362, 41.30025570733206, 43.58042172023228, 41.95773942129952, 42.22199331011091, 39.895427227020264, 38.391916956220356, 39.4559189251491, 42.90479278564453, 45.141855648585725, 42.93203319822039, 46.31576769692557, 45.97378431047712, 46.4198134967259, 46.8924230166844, 46.340239252362935, 46.43803514753069, 46.963127885546, 47.478920459747314, 49.31856025968279, 49.660217080797466, 51.0801613671439, 54.4937870161874, 59.710748127528596, 63.23705618722098, 62.99940000261579, 66.76957593645368, 64.71240193503243, 67.79315676007951, 68.01278931753976, 64.48840590885708, 58.00168582371303, 58.93415491921561, 62.68159634726388, 69.29047271183559, 70.70829432351249, 70.08347756522042, 1.6230229777949197, 0.3818735373871667, 0.7249304205179214, 0.5025131553411484, 6.655583892549787, 63.70905426570347, 58.80320916857038, 42.6126001902989, 41.0814847264971, 27.69408999170576, 30.760960578918457, 57.28996794564383, 9.408415879522051, 0.14695492945611477, 0.03829590916367514, 0.014667728649718421, 0.03328673295410616, 0.030721161514520645, 0.02656608956333782, 0.027743495402059386, 0.02584871689655951, 0.012846411738012518, 0.036512820914919884, 0.053057136546288214, 0.0009536877540605408, 0.025497647966923456, 0.04513950818883521, 0.0606384150949972, 0.02575789837698851, 0.04250583897477814, 0.028916818156306232, 0.07277923862316779, 0.15569384981478962, 0.17171982915273734, 22.658999715532573, 68.59304727826799, 49.86584554399763, 40.72707448686872, 40.05878284999302, 59.21395192827497, 73.03405094146729, 2.189635327884129, 0.06222016164766891, 2.5757104626723697, 1.143590326820101, 2.5595595921788896, 45.93866811479841, 83.91362367357526, 83.76428604125977, 89.06828376225063, 82.20121928623745, 80.67791707175118, 77.90443243299211, 80.63108621324811, 78.15616566794259, 78.67613410949707, 71.8219724382673, 63.25586496080671, 58.15309401920864, 57.47242416654314, 54.736901010785786, 56.24890545436314, 54.28485121045794, 55.260534627096995, 54.09004456656319, 53.98414012363979, 51.82788481031145, 55.58900376728603, 52.32533761433193, 53.23919595990862, 51.622947692871094, 53.90876259122576, 48.855890137808665, 46.95353242329189, 48.23178209577288, 49.411374296460835, 48.91274029867989, 51.25736474990845, 51.65357535226004, 53.16363777433123, 51.15899215425764, 52.774535179138184, 48.567807401929585, 47.486226490565706, 47.16702972139631, 48.729714325496126, 47.01816456658499, 54.08464929035732, 56.797139167785645, 58.33044678824288, 56.13440261568342, 56.86912945338658, 57.21723420279366, 55.82516608919416, 62.74725682394845, 58.29426056998116, 62.28193596431187, 55.16060563496181, 57.57481976917812, 52.69418968473162, 52.26109457015991, 56.161983489990234, 58.441715240478516, 46.99460322516305, 41.78178671428135, 46.984424114227295, 45.664238589150564, 59.302569253104075, 58.44759341648647, 58.793759618486675, 56.154420375823975, 59.75245121547154, 57.43352815083095, 59.69682393755232, 58.079644611903596, 61.31553881508963, 48.79195281437465, 42.03394378934588, 40.07318993977138, 47.38934775761196, 51.61145189830235, 54.34682566779, 53.57200425011771, 53.6230457169669, 48.959289755140034, 51.495819977351594, 52.11094747270857, 47.067430768694194, 44.345744950430735, 45.1535598891122, 42.27942017146519, 43.47391625813076, 42.68867949077061, 41.593434946877615, 42.53265074321202, 43.201696259634836, 42.98620482853481, 42.59566395623343, 43.89012377602713, 42.951119899749756, 44.028014251164024, 46.68664864131382, 43.307545116969514, 44.03769309180123, 43.1163341658456, 39.9311374936785, 43.001007965632844, 44.32436186926705, 48.29290887287685, 46.80453177860805, 47.73680632455008, 47.89843532017299, 48.91160079411098, 48.06797136579241, 48.06605018888201, 49.52377183096749, 48.242506640298025, 49.63349778311593, 52.163229193006245, 52.879376547677175, 51.57593618120466, 57.50085966927664, 61.63903999328613, 65.69364738464355, 65.53064959389823, 68.42722157069615, 66.56320749010358, 70.5344990321568, 67.98085539681571, 64.97191715240479, 59.74106311798096, 60.69971302577427, 63.43431554521833, 73.40682874407086, 69.85343660627092, 78.87527642931256, 2.739771979195731, 0.35839006464396206, 2.3292059642927985, 0.5727528748767716, 5.9888977238110135, 68.11180809565953, 65.68379483904157, 50.83001579557146, 38.11920363562447, 28.739507266453334, 38.64779479163033, 63.33335127149309, 15.669518402644567, 0.24872637486883573, 0.06177930387535265, 0.038861427389617474, 0.03513121844402381, 0.0834731405068721, 0.10379428722496543, 0.01587493235378393, 0.029058048435087715, 0.03878218467746462, 0.08988982904702425, 0.18580304059599126, 0.1197645113404308, 0.12874686292239598, 0.2155823955046279, 0.17152640596032143, 0.06486558648092405, 0.16453932731279305, 0.1958257627806493, 0.20551920549145766, 0.3073579615780285, 0.3629692260708128, 23.792685168130056, 80.15152849469865, 51.73753390993391, 45.3018969808306, 64.88714912959507, 62.38539464133126, 81.29134573255266, 3.2793506256171634, 0.17240117330636295, 4.50025703225817, 5.588978520461491, 4.700782477855682, 45.17782299859183, 87.3565672465733, 85.96323803492955, 91.8916425704956, 86.25898115975517, 84.3515408379691, 80.5367157799857, 84.10144737788609, 80.31754180363247, 83.81835692269462, 74.72153908865792, 67.17935984475272, 62.12077249799456, 61.40391295296805, 57.44915117536272, 61.39754145486014, 56.41809409005301, 58.52659443446568, 57.228188037872314, 56.471084526606965, 54.7369635445731, 59.229842458452495, 55.00083875656128, 57.52661664145333, 54.02884483337402, 54.969252245766775, 50.938845430101665, 50.64839335850307, 51.43952219826834, 51.34311941691807, 51.93651294708252, 55.66759136744908, 55.46824060167585, 57.73883547101702, 52.69492966788155, 54.440129552568706, 50.53752095358712, 50.18547657557896, 51.816302163260325, 50.36684192929949, 49.24358572278704, 57.94274772916521, 58.505152293613975, 61.446686063494, 56.63111196245466, 59.5850830078125, 60.52924592154366, 58.7121947152274, 66.1626091003418, 59.863907269069124, 62.77023451668875, 58.67901011875698, 61.28639112200056, 54.90293863841465, 55.44608974456787, 59.46216937473842, 63.600460869925364, 50.34098073414394, 43.82292774745396, 46.33454172951834, 46.576502323150635, 62.78961304255894, 63.086891719273154, 59.756821632385254, 58.953936440604075, 61.77417550768171, 59.4823955808367, 61.87368760790144, 60.117502621241975, 64.81066335950578, 51.717429297310964, 42.30555582046509, 42.453819956098286, 50.53632933752877, 55.567808287484304, 57.51261254719326, 57.78484296798706, 56.53455284663609, 52.15317514964512, 54.85396078654698, 54.48861060823713, 50.65654706954956, 46.19189521244594, 48.55523116247994, 44.83394970212664, 46.46203075136457, 46.09199401310512, 42.673567158835276, 45.42752388545445, 45.75264399392264, 45.96307018824986, 45.849067619868684, 47.42308126177107, 47.105840410505024, 48.50984900338309, 49.65425205230713, 44.951315198625835, 48.09800148010254, 44.57785994665963, 42.94295229230608, 45.06922265461513, 48.045507839747835, 50.066082205091206, 47.63820096424648, 51.819480964115684, 50.11977788380214, 52.275932448250906, 51.002268586839946, 51.033438205718994, 51.16348416464669, 52.34771081379482, 50.50642081669399, 55.00280509676252, 55.09792940957205, 56.00435665675572, 59.87658078329903, 65.1642849785941, 68.93754591260637, 68.24119744982038, 71.14513451712472, 66.39070456368583, 73.56748499189104, 70.68480941227504, 67.62709481375558, 61.43643052237374, 65.31251089913505, 66.97008010319301, 74.6483050755092, 72.59999002729143, 79.69117559705461, 2.433680381093706, 3.4798380732536316, 3.2339128809315816, 0.7131597921252251, 9.061857972826276, 77.37582043239048, 69.89561217171806, 57.97239221845354, 59.22872379847935, 37.72518171582903, 42.394367694854736, 75.68218312944684, 18.275402069091797, 0.31968455442360466, 0.26315015660864965, 0.11150265538266727, 0.12426418917519705, 0.20971242977040155, 0.27661139571240967, 0.15697774663567543, 0.11666266992688179, 0.15125628507563046, 0.2075141120169844], [0.1032086368650198, 0.06260215650711741, 0.0374423222882407, 0.030801350783024515, 0.040589187892952135, 0.03924227213220937, 0.07281733157911471, 0.0313008780857282, 0.018952728182609593, 0.027532896791983928, 0.05246953200548887, 29.35900170462472, 61.34754221779959, 22.76181742123195, 34.56472757884434, 39.96265799658639, 52.900412218911306, 59.073987415858674, 0.2607504768030984, 0.024849957453885248, 0.4860615038446018, 1.2131048824105943, 2.9346385513033186, 81.91378620692662, 77.06417288099016, 80.88092953818185, 77.95090198516846, 79.2535502570016, 78.41726507459367, 77.7046091897147, 74.36117771693638, 75.31657586778913, 69.92535740988595, 62.97230897630964, 54.85968610218593, 56.090465681893484, 51.116000175476074, 54.02407489504133, 51.72012172426496, 51.166294710976736, 50.25339869090489, 50.31474086216518, 48.853857789720806, 50.3664493560791, 49.48780100686209, 50.736232485089985, 49.22013207844326, 49.975807734898154, 49.843065874917166, 44.23188134602138, 45.83304507391793, 45.12797314780099, 45.31687382289341, 48.23270273208618, 48.36155012675694, 51.4165028163365, 49.08855056762695, 49.214743750435964, 48.85026904514858, 47.37481907435826, 47.08150781903948, 42.962233543395996, 46.0720978464399, 44.74775035040719, 51.10056822640555, 56.15612963267735, 52.83077389853341, 56.40973540714809, 54.810954911368235, 54.31790379115513, 55.447979654584614, 55.20594263076782, 57.56191349029541, 55.55031967163086, 52.2109181540353, 57.50192621776036, 50.851318972451345, 52.64641039712088, 53.70277629579817, 53.183940410614014, 39.47319562094552, 42.44609355926514, 48.38980845042637, 52.71109812600272, 55.791304043361116, 53.08901759556362, 54.48126983642578, 55.03743839263916, 53.6007524217878, 52.00384446552822, 52.78816754477364, 50.95751176561628, 54.5469650541033, 46.973463330950054, 41.28989941733224, 36.95741966792515, 42.163058689662385, 52.941479546683176, 52.04977205821446, 49.96297093800136, 47.98563173839024, 50.160518646240234, 49.44777938297817, 48.37943131583077, 44.99413694654192, 40.4802188873291, 40.104981422424316, 42.01110506057739, 41.29432194573538, 39.90957375935146, 40.394446849823, 39.460289342062815, 41.11712203707014, 39.259482928684776, 39.18009975978306, 39.60038587025234, 39.22195223399571, 40.062448024749756, 41.128576142447336, 41.311046259743826, 42.038324628557476, 40.30995675495693, 39.18869815553938, 37.160518986838206, 40.88189424787249, 45.463598932538716, 46.892763478415354, 44.1151168687003, 45.37113577978951, 44.96031311580113, 45.71970953260149, 43.33360433578491, 45.354220390319824, 45.94982344763619, 50.00922509602138, 53.75995997020176, 58.83204419272286, 58.36506271362305, 63.01583249228341, 62.178275789533345, 66.54673331124442, 64.5841451372419, 67.66501113346645, 65.455963407244, 66.55069378444126, 62.802001680646626, 58.19158703940255, 53.92405905042376, 61.62955570220947, 58.39903245653425, 74.74002824510846, 64.91380241939, 83.79650483812604, 17.793806791305542, 0.3224785444991929, 2.036517007010324, 0.07149080918835742, 0.4537967023040567, 41.779886381966726, 67.68238162994385, 49.2059577533177, 32.98408535548619, 27.331499985286168, 27.80380552155631, 55.765005111694336, 18.1305182320731, 0.25512591004371643, 0.15431772651416914, 0.06638259400746652, 0.05297564109787345, 0.05965713132172823, 0.03206336824223399, 0.017664923000016382, 0.016133184478219067, 0.020016392892492667, 0.03756569352533136, 0.014596786117181182, 0.01762916929354625, 0.036348588299006224, 0.03580984167222466, 0.03778725217229553, 0.046704810445329974, 0.01804607986871685, 0.004838069609832019, 0.016566401946225336, 0.04030423032652054, 0.15543147389377865, 40.36695630209786, 69.78023038591657, 31.6659426007952, 30.043451377323695, 38.14307764598301, 64.3268186024257, 58.20788403919765, 0.38764933603150503, 0.02274217493166881, 2.2464705067021504, 0.9160249893154416, 5.212931590420859, 85.28187683650425, 79.72713947296143, 83.49785041809082, 79.84351485116142, 83.75316892351422, 78.93822710854667, 81.08205209459577, 76.13389246804374, 77.54180594852993, 71.9768408366612, 66.15416009085519, 58.27579573222569, 58.233637537275044, 53.0738114629473, 57.57019574301583, 54.86655787059239, 54.265959058489116, 52.80917542321341, 53.29265192576817, 52.77266958781651, 52.82043150493077, 52.42675699506487, 54.254122802189414, 54.41621732711792, 52.50132506234305, 53.45211655752999, 46.93498420715332, 45.894276074000764, 48.0534531048366, 46.53906890324184, 50.090185506003245, 50.15573481151036, 54.098347663879395, 52.65050288609096, 49.59790563583374, 49.852035999298096, 49.627838475363596, 48.320097173963276, 46.24093907220023, 48.94103683744158, 44.40296336582729, 52.998065676007954, 59.178057534354075, 57.509735992976594, 56.76471192496163, 56.781050613948274, 57.539710521698, 59.80902344839913, 58.42394869668143, 61.58924920218331, 61.54289082118443, 55.60791676385062, 59.6816212790353, 52.9973326410566, 55.52189459119524, 56.39027350289481, 56.363554205213276, 42.51673242024013, 44.38042688369751, 49.73455933162144, 56.30461263656616, 57.13885504858834, 56.18225138528006, 56.45886264528547, 56.79085799625942, 57.120991230010986, 53.523717744009836, 55.41694899967739, 54.73628609521048, 56.93817022868565, 46.64905193873814, 42.057008334568565, 38.87595278876168, 43.885558809552876, 55.66374206542969, 53.04352426528931, 53.34959936141968, 52.5083601134164, 51.730523177555625, 51.39324719565255, 50.720060552869526, 47.99393483570644, 42.282150813511436, 42.50055353982108, 43.853399072374614, 43.58501100540161, 43.455340249197825, 41.19112382616316, 42.51347371510097, 44.40945298331124, 42.44386666161673, 41.984472615378245, 42.70253072466169, 42.21036549976894, 42.983602728162495, 44.21220057351248, 43.30956356866019, 44.64249208995274, 41.21342406954084, 42.83905587877546, 38.54911300114223, 41.80883257729666, 46.98179422106062, 48.10752746037075, 47.44663912909371, 48.1676641191755, 48.45389168603079, 46.86913960320609, 45.300316265651155, 48.41161189760481, 48.214404651096885, 52.648008482796804, 56.221470492226736, 63.29022380283901, 62.705727440970286, 66.40788745880127, 64.01207910265241, 68.94953850337437, 66.90084130423409, 69.4460984638759, 65.35759775979179, 67.81926809038434, 64.22794573647636, 61.012159620012554, 55.803987979888916, 63.464922360011506, 59.8062094279698, 77.18537030901227, 66.61505494798932, 86.42549473898751, 23.940485511507305, 0.0926696445260729, 1.5071182314838683, 0.06316194111215216, 0.1739060825535229, 42.7250428880964, 73.18747411455426, 54.470552240099224, 37.079652377537315, 23.769214153289795, 37.34353106362479, 62.638712065560476, 26.68909559931074, 0.3636994925992829, 0.14639869358922752, 0.051860251663518805, 0.08522103314421006, 0.014027200073802044, 0.01974690762082381, 0.00657302258436435, 0.036919229464339356, 0.0366820000511195, 0.011930958584084042, 0.16928227352244513, 0.12986531933503492, 0.12405175343155861, 0.13008242339960166, 0.16196463975523198, 0.1836145751710449, 0.161548643505999, 0.0855063706902521, 0.04206140871558871, 0.17720454984477588, 0.19302984566560813, 45.45978784561157, 83.42650631495884, 31.87476028714861, 46.52995981488909, 55.67845835004534, 67.67505822862897, 67.24578462328229, 0.7541729999440057, 0.07186634439442839, 4.705142906733921, 5.8853964890752515, 5.4446227465357095, 87.97658279963902, 84.35258306775773, 88.20358739580426, 82.47784096854073, 86.95064653669084, 84.01624161856515, 83.94538388933454, 79.07179927825928, 79.53045681544712, 74.13087272644043, 70.54437937055314, 61.929836000714985, 63.41960620880127, 56.310060024261475, 59.93689809526716, 59.17961393083845, 57.48257548468453, 56.260640961783274, 56.15594550541469, 55.50706018720354, 56.98335089002337, 53.37003748757498, 56.747410910470144, 55.84400960377285, 53.63434001377651, 55.23915154593331, 49.921271324157715, 50.95735543114798, 51.65510048185076, 50.38536582674299, 54.80500030517578, 53.79048688071114, 55.42384161267962, 52.287278856549946, 52.919867174965994, 51.87439257758004, 53.55945927756173, 52.701252528599326, 49.189900466373985, 51.401178564344136, 49.178960527692524, 56.84298685618809, 61.78699493408203, 60.629279136657715, 59.933882577078684, 59.6560241154262, 61.76041112627302, 61.12254565102713, 60.988056319100515, 62.03766509464809, 62.727301597595215, 60.66876574925014, 63.82271984645298, 55.81739105497088, 56.53888157435826, 61.506579535348074, 59.44174861907959, 45.037684781210764, 45.72686965124947, 50.81816911697388, 57.91551079068865, 59.26102597372872, 58.904277665274485, 60.356312206813264, 61.45070212227957, 59.41751330239432, 56.53629337038313, 58.106270108904155, 55.572404520852224, 58.60532447269985, 48.11228697640555, 43.74915177481515, 41.0635792187282, 47.01687567574637, 57.02901445116316, 55.85337577547346, 55.388503074645996, 54.83061831338065, 54.27482843399048, 54.949366501399446, 54.59673152651106, 51.572500297001426, 46.02659409386771, 45.04754080091204, 46.19792972292219, 46.392983027866904, 44.35951975413731, 45.11363901410784, 44.1225722857884, 47.60161175046648, 45.05445425851004, 44.897890499659944, 45.96644006456648, 44.36201415743147, 45.10991825376238, 46.296951975141255, 45.63433354241507, 48.264938899448936, 44.698980944497244, 46.24419777733939, 41.47391898291451, 46.10049860818045, 50.16305821282523, 50.978120122637065, 50.402621677943635, 49.783613613673616, 50.72014740535191, 49.284357752118794, 47.23670278276716, 50.67816986356463, 51.1649398122515, 55.00036627905709, 59.19053649902344, 66.32688535962785, 64.22203281947544, 70.46897057124546, 65.387252671378, 71.97068473270961, 69.328736441476, 70.93135234287807, 69.64219747270856, 72.57900646754673, 68.99873174939836, 65.0397732598441, 58.45361750466483, 67.11324078696114, 63.54650115966797, 80.6820512499128, 69.73162773677281, 90.80418695722307, 21.351763895579747, 0.7123348021081516, 5.079614767006465, 0.14292635848479612, 0.6367452410714967, 51.44150938306536, 78.63141550336564, 61.60725893293108, 48.71428237642561, 39.89586843763079, 39.702562604631694, 73.44019399370465, 31.577901976449148, 0.5130335965326854, 0.24137762348566735, 0.2903337622327464, 0.21181898244789668, 0.17160892938928946, 0.12415860912629537, 0.09433171605425221, 0.17773810907133988, 0.08871098980307579, 0.10226674883493356], [0.07416391825037343, 0.024511536416996802, 0.08378135146839277, 0.03405463782006076, 0.0419618099528764, 0.045328476798853705, 0.010468652006238699, 0.09077415016612836, 0.17388487154883997, 0.13597110312964233, 2.0156643773828233, 46.81884159360613, 51.834228515625, 39.523187909807476, 49.231766836983816, 38.6281418119158, 67.92144135066441, 40.74715825489589, 0.1012245597583907, 0.12432740149753434, 0.7184363518442426, 1.8036048135587146, 18.59876949446542, 92.47721590314592, 70.3541168485369, 84.82865973881313, 77.40886606488908, 82.24065031324113, 73.6071036202567, 77.71743556431362, 70.30171353476388, 73.48541287013462, 62.07697105407715, 55.957404204777305, 51.87325307301113, 54.83938346590315, 51.97558961595808, 51.607435839516775, 49.03467423575265, 51.297580923352925, 48.34348481042044, 52.041819844927105, 47.74259417397635, 50.761871337890625, 50.68941552298409, 49.761181354522705, 48.48358481270926, 51.44619594301496, 47.629519190107075, 43.829629284994944, 44.559610503060476, 46.135962213788716, 46.6658387865339, 45.6368522644043, 47.899901390075684, 54.12098142078945, 47.89273084912981, 49.93272890363421, 47.472403049468994, 46.199385370527, 43.82500525883266, 44.73231840133667, 44.31405769075666, 44.772805554526194, 49.14991358348301, 57.497628756931846, 56.04138708114624, 55.71488080705915, 54.28946828842163, 58.19669049126761, 55.975646700177876, 54.17025457109724, 58.20161328996931, 52.85434913635254, 55.4584436416626, 55.46844557353428, 53.659888539995464, 54.044881275721956, 52.783616474696565, 54.02637127467564, 38.66360541752407, 43.848597867148264, 52.850107261112754, 54.72893490110125, 57.20666251863752, 58.7013555254255, 55.32060875211443, 55.97182866505214, 55.54181855065482, 53.60827384676252, 54.66519907542637, 56.05397374289376, 57.18686710085188, 48.24058198928833, 42.89105272293091, 38.10768004826137, 46.226059504917686, 53.258991377694265, 53.36248132160732, 50.468306473323274, 46.1117651121957, 48.22319759641375, 47.621202196393696, 45.172597953251426, 42.33652394158499, 42.31110395703997, 40.52047674996512, 41.8353225844247, 42.595316546303884, 43.38908917563302, 42.82793181283133, 41.654954297201975, 42.03948150362287, 39.51861946923392, 38.93817738124302, 39.13051741463797, 39.7476737839835, 40.70068870271955, 41.769929613385884, 42.35980040686471, 42.476509298597065, 40.81066826411656, 41.856229713984895, 39.63035345077515, 38.176265716552734, 41.46734946114676, 43.4405197416033, 44.99710382734026, 45.35506807054792, 43.87651572908674, 47.097283703940256, 45.461368560791016, 48.5910074370248, 51.79653453826904, 57.80864749635969, 58.670165061950684, 62.77453545161656, 60.60037463051932, 64.39526530674526, 64.88903903961182, 64.05355290004185, 62.8070182800293, 66.4975609098162, 63.44497408185686, 64.39901038578579, 55.277425697871614, 56.40208196640015, 56.469052178519114, 61.604611669267925, 59.65204279763358, 69.41099616459438, 67.20626326969692, 77.63104166303361, 54.29142768042428, 0.04539162805303931, 0.4923501121146338, 0.15398246236145496, 0.22159749987934316, 19.838277748652867, 73.37657628740583, 54.17983613695417, 40.92781489236014, 33.14595406396048, 24.50208408491952, 49.53324569974627, 27.897574935640606, 0.0422110663993018, 0.02392803701306028, 0.11298623148884092, 0.034999884598489316, 0.09264485085649149, 0.025807149841317108, 0.03133715935317533, 0.06401929724961519, 0.0511619271710515, 0.0434017867914268, 0.0851510286863361, 0.038746246070201905, 0.04687311427135553, 0.05029560758599213, 0.0364377070883555, 0.03440482974318521, 0.09461365413985082, 0.055053970111267905, 0.23129478309835705, 0.22350953013769218, 3.7548399567604065, 57.71996416364397, 58.40446594783238, 46.03143004008702, 35.461799076625276, 41.83403716768537, 78.58291012900216, 40.31611633300781, 0.029649435808616023, 0.35915827485067503, 1.7019202070576804, 1.0214585832187106, 23.121728897094727, 97.58540643964494, 73.72650146484375, 89.75663484845842, 78.05142852238247, 83.94128445216587, 76.20643860953194, 81.09498269217355, 73.0664781842913, 76.78101989201137, 66.19307000296456, 58.67277758462088, 54.18320253917149, 57.954104559762136, 54.03721393857683, 54.01986428669521, 50.95512158530099, 54.809822354997905, 50.641639709472656, 54.574896812438965, 50.39344310760498, 53.481490067073274, 52.49660376140049, 52.17688240323748, 50.25245720999581, 53.368838923318044, 49.73911040169852, 46.52778850282942, 47.91873100825718, 48.799026080540244, 49.37033128738403, 49.22469357081822, 51.476191316332134, 56.906524658203125, 49.36394936697823, 52.2211389541626, 48.68996715545654, 47.73828281675066, 46.34340763092041, 47.5833032471793, 47.588580404009136, 46.078962666647776, 51.949259417397634, 59.29936613355364, 57.632260526929585, 58.64156627655029, 56.19399036679949, 60.65762778690883, 59.36459582192557, 58.75709397452218, 60.73938723972866, 58.357308523995535, 56.27454778126308, 60.12290831974575, 56.761911800929475, 57.49582917349679, 55.73865754263741, 55.65363243647984, 40.30503395625523, 44.65311935969761, 55.64490897314889, 55.978842871529714, 58.887588092258994, 62.099907057625906, 58.61586488996233, 56.554125922066824, 55.85359116962978, 54.678338118961875, 57.0119948387146, 56.254981654030935, 61.14172962733677, 50.22190250669207, 43.07279327937535, 39.8209216935294, 47.97733211517334, 56.05704484667097, 55.93611145019531, 54.03066178730556, 48.9046664919172, 50.50338445390974, 49.15348148345947, 49.11575971330915, 43.15957627977644, 43.43940108163016, 42.73340851919991, 44.502763816288535, 45.202183382851736, 45.15245165143694, 44.78614262172154, 44.74834442138672, 44.07665858949934, 43.15474033355713, 42.67255967003958, 41.22298131670271, 41.717595781598774, 42.882440430777415, 44.26566696166992, 45.71822261810303, 46.09210865838187, 43.209978512355256, 43.733494009290425, 43.56930807658604, 40.38648074013846, 44.85591990607125, 46.07575607299805, 48.02163035529, 47.497579847063335, 47.4105223928179, 49.87002141135079, 47.25672401700701, 49.20646844591413, 55.4393812588283, 62.021281242370605, 60.95867933545794, 67.41446604047502, 63.04814856392996, 65.85740947723389, 66.05247320447648, 67.08603164127895, 65.9553999219622, 68.44867065974644, 66.61672946384975, 65.2844818660191, 57.46601445334298, 58.53482804979597, 59.2916327885219, 64.15728950500488, 61.189838954380576, 69.09205300467355, 69.38374532972063, 77.56482533046177, 61.97812598092215, 0.2792379233453955, 1.323518489088331, 0.32874956514154163, 0.26808275335601395, 18.603799990245275, 77.46199199131557, 59.93306963784354, 45.47455971581595, 26.697077342442103, 32.14267587661743, 55.9539509500776, 37.20883328574044, 0.09176155432526555, 0.014800624822133353, 0.03673683246597648, 0.025348913090835725, 0.03112783808527248, 0.016812501508476477, 0.024905880613784705, 0.07359616085886955, 0.02507570944726467, 0.0310134167250778, 0.22747765720954963, 0.11806773953139782, 0.2178121701415096, 0.12206626497209072, 0.10277947025107485, 0.24750471327986034, 0.2048734844263111, 0.13113830531282084, 0.30581652000546455, 0.4634808897972107, 3.7107605848993575, 67.26359285627092, 68.80833721160889, 47.61885717936924, 65.1818013872419, 56.59186506271362, 83.05274186815534, 48.88067088808332, 0.24436686879822186, 0.4425836397068841, 5.182657420635223, 4.424265452793666, 23.567511422293528, 99.48446723393032, 76.52884892054966, 92.99016666412354, 82.65360260009766, 87.53322519574846, 79.99392250605992, 82.37609154837472, 75.60564872196743, 78.46165711539132, 68.07498264312744, 61.279116358075825, 58.133993421282085, 61.99571187155587, 57.81318467003958, 58.02073083605085, 55.28201150894165, 59.002685001918245, 55.61911725997925, 57.48513242176601, 51.619657720838276, 55.28221648080008, 57.296061515808105, 55.653330189841135, 52.451402255467, 57.34775958742414, 51.43875789642334, 50.775795527866904, 50.695224217006135, 53.03129196166992, 52.92120470319475, 50.60825708934239, 53.65011242457798, 59.36008644104004, 49.43458475385393, 53.52516296931675, 50.42994894300188, 51.075679779052734, 49.668534074510845, 50.43970421382359, 50.12376962389265, 48.874771867479595, 55.71420335769653, 62.711223466055735, 61.99717794145857, 58.89408465794155, 57.10570519311087, 64.74742085593087, 62.544230461120605, 58.74525424412319, 60.27531705583845, 61.12148257664272, 59.99674987792969, 62.37147045135498, 60.234538078308105, 60.755847522190635, 58.63857855115618, 58.845204080854145, 42.463474478040425, 47.145928042275564, 57.697309562138145, 57.86153023583548, 62.2646974836077, 64.42395441872733, 59.35730716160366, 59.31390176500593, 58.277046407972065, 57.579777308872764, 61.029259136744905, 60.19222354888916, 63.13607106889997, 51.39015872137887, 44.31211566925049, 40.48456498554775, 50.65027979442051, 59.96977697099958, 59.46310043334961, 57.35752875464303, 51.3614696093968, 54.081668513161794, 54.279171058109824, 51.562526157924104, 47.4758563041687, 46.64031457901001, 45.32812295641218, 46.53889867237636, 46.718954290662495, 47.765519755227224, 48.96426119123186, 47.7509354863848, 47.35806696755545, 45.796667780194966, 46.62393420083182, 43.86534997395107, 44.18158333642142, 45.542471408843994, 46.01718623297555, 48.000497409275596, 47.7602356501988, 46.15379476547241, 47.78710780824934, 45.96083981650216, 43.804125922066824, 45.94824620655605, 47.382423877716064, 50.2723776953561, 51.179277420043945, 49.867613860539024, 54.26026848384312, 49.478111743927, 52.8838164465768, 57.453914165496826, 63.43454483577183, 63.40555695125035, 69.32638100215367, 65.12650762285504, 69.74518367222377, 67.00223636627197, 69.19797134399414, 67.01795319148472, 71.66553374699184, 70.30636882781982, 69.21798910413469, 61.41288307734898, 61.599553380693706, 63.13044997623989, 67.93229443686349, 64.95665196010044, 73.0923741204398, 73.06381702423096, 81.56456974574498, 61.24372223445347, 0.45705538030181614, 4.9084619624274115, 0.6185166963509151, 0.40830619473542484, 25.997195720672607, 84.95222650255475, 64.90835503169468, 57.228188037872314, 49.264291354588096, 35.27266216278076, 65.34603595733643, 44.04630538395473, 0.16257840182100022, 0.11909481084772519, 0.20319917212639535, 0.0855759476710643, 0.204616998189262, 0.1619561987796, 0.11839207927031176, 0.2168000265955925, 0.09468538207667214, 0.1610545478761196], [0.07420523424765893, 0.01848175363349063, 0.03402642094131027, 0.024587069238935198, 0.0698718246338623, 0.0497587031817862, 0.061230131558009555, 0.061481413431465626, 0.2592090895133359, 0.2616741258118834, 7.46665666784559, 60.151013783046174, 41.87170682634626, 31.95757586615426, 47.55962726048061, 36.14818729673113, 76.39405386788505, 21.305037260055542, 0.2184553806270872, 0.3111354203096458, 2.2973775693348477, 0.17332096823624202, 53.84502329145159, 90.43607834407261, 78.77870341709682, 80.45416423252651, 73.16819286346436, 75.90524809701103, 73.88104329790387, 77.13280718667167, 70.30132443564278, 67.66684545789445, 57.42920637130737, 55.34506293705532, 55.23698023387364, 53.75641986301967, 52.234281471797395, 52.69160842895508, 49.14655065536499, 48.80499458312988, 49.58647237505232, 50.619565282549175, 47.39913082122803, 49.707433564322336, 49.68806198665074, 49.602435861315044, 50.011448519570486, 51.59424468449184, 43.788555009024485, 43.406014987400596, 43.17610951832363, 46.03116600854056, 48.63629926953997, 50.670120375497, 50.26723950249808, 53.11414575576782, 47.445398875645225, 48.30196932383946, 47.18905898502895, 46.952677794865195, 44.740381785801475, 44.50180843898228, 43.259474005017964, 46.167910030909944, 46.002271924700054, 58.142980916159495, 54.83625330243792, 56.37805162157331, 53.55778476170131, 59.33612905229841, 54.16032559531075, 58.52999905177525, 56.77310534885952, 53.68646887370518, 57.87181009565081, 54.10217612130301, 55.581409386226106, 53.79007693699428, 59.022271973746165, 49.1098815373012, 38.76338849748884, 48.0671375819615, 52.734034129551475, 50.65560211454119, 53.2155373437064, 52.78469691957746, 52.50301347460066, 53.172937938145225, 53.68444347381592, 53.5697808265686, 52.86889866420201, 50.25405182157244, 54.98741831098284, 47.9097261428833, 41.4962227003915, 44.62545163290841, 37.768628801618306, 50.452898842947825, 51.64735671452114, 51.65769215992519, 49.269822120666504, 47.303857122148784, 44.94659389768328, 44.12646675109863, 40.45623370579311, 40.7517649105617, 39.87058046885899, 40.50620167595999, 45.28442573547363, 49.176327160426546, 45.69734328133719, 43.980596269880024, 39.674266065870015, 40.775955063956125, 39.13527693067278, 38.62187453678676, 38.28277117865426, 40.271012101854595, 43.54512139729091, 43.56148093087332, 42.080274377550396, 43.54095247813633, 43.187897137233186, 40.64407478060041, 38.50142056601388, 39.40793119158064, 44.39328452519008, 45.89389739717756, 44.36426189967564, 45.4640714100429, 46.857320717402864, 45.51978554044451, 53.5449549130031, 57.58293179103306, 61.65616035461426, 62.47177464621407, 63.11776951381138, 63.56676210675921, 62.86585562569754, 64.4690829685756, 62.81836468832833, 63.708929198128835, 64.44429874420166, 62.041319847106934, 53.68479783194405, 53.16785880497524, 56.705068588256836, 60.569698333740234, 57.877646582467214, 62.65488747188023, 64.51921422140938, 71.65818255288261, 65.8506280354091, 75.379088810512, 7.594460964202881, 1.372382021376065, 0.8618887513875961, 0.29862510732242037, 2.8010748497077396, 57.56511313574654, 63.22561250414167, 43.1590690612793, 38.66954265322004, 18.728056362697057, 45.291432993752615, 35.156231198992046, 0.3367790499968188, 0.09471795854291745, 0.05390249279194644, 0.06722966355404683, 0.057554914483002255, 0.014015383386452283, 0.07033306559813873, 0.02694999789153891, 0.04044500259416444, 0.04467793134972453, 0.06693378157381501, 0.018945622224626795, 0.0887144028342196, 0.006527732068207115, 0.050295821324523, 0.049623569540147267, 0.12348726657884461, 0.09950844291597605, 0.2350075910133975, 0.5033883569496018, 12.351476516042437, 70.66766125815255, 49.63838931492397, 32.63611957005092, 36.35774149213518, 46.0352897644043, 81.51787785121373, 21.2795912197658, 0.4298193103500775, 0.8812794908881187, 1.6388927719422748, 1.0269832696233476, 60.19009740012032, 91.19458539145333, 78.57601056780133, 83.52218995775495, 74.04322120121547, 80.04580470493862, 77.03913157326835, 79.57355649130685, 71.8145865031651, 70.27214200156075, 57.295606408800396, 58.19150366101946, 56.04783500943865, 57.828338691166465, 54.821467535836355, 55.80447087969099, 53.38593149185181, 52.7445467540196, 52.40774324962071, 52.73317602702549, 50.88093914304461, 53.57317502158028, 51.17548022951399, 54.08280454363142, 52.37310995374407, 53.98260804585048, 47.11224317550659, 47.110582556043354, 46.34305327279227, 49.2835830279759, 49.59376450947353, 52.682155404772075, 52.79823548453194, 54.956064564841135, 47.66172061647688, 50.74569593157087, 48.069124766758506, 50.73501655033657, 46.91688067572457, 46.18437726157052, 47.198494638715474, 46.761616230010986, 49.23018959590367, 59.53925963810512, 59.76802212851388, 59.07597460065569, 55.47720030375889, 62.306233814784456, 58.377395766122, 59.54476955958775, 61.18347440447126, 56.57150336674282, 59.74045862470354, 56.88610737664359, 59.66880880083357, 57.72113493510655, 62.43310097285679, 50.899032252175466, 40.69893428257534, 48.674222537449424, 52.296916007995605, 50.07158170427595, 54.05647087097168, 54.953524998256135, 53.861834457942415, 55.99305541174752, 55.856697014399934, 56.30201748439244, 54.80653585706438, 53.36798776899065, 55.535318510872976, 49.01507684162685, 42.373939990997314, 48.15410123552595, 42.295435769217356, 52.57654626028878, 54.79789229801723, 55.31458118983677, 50.86020919254848, 50.956202030181885, 48.23214340209961, 46.75189222608294, 43.085887159620015, 42.954104151044575, 41.554031712668284, 43.90185233524868, 48.41951199940273, 51.07186869212559, 50.128181729997905, 46.782005718776155, 43.1396974836077, 42.534974915640696, 41.47310256958008, 40.66518688201904, 40.77133451189314, 42.260524545397075, 45.27535138811384, 45.56916291373116, 44.445284843444824, 46.59493589401245, 45.75193527766636, 43.60955899102347, 41.278004101344514, 42.24631895337786, 46.32885462897164, 47.55482605525425, 48.40774869918823, 49.25740221568516, 47.9921943119594, 49.24014636448452, 54.65156323569161, 60.57660484313965, 63.01806286403111, 65.51728820800781, 64.88822610037667, 65.92716244288853, 64.20084081377301, 66.79114314488002, 64.90424169812883, 65.10239042554582, 64.7101229258946, 63.748658997671946, 54.496482917240684, 55.702464376177105, 57.38951131275722, 61.9222138268607, 60.2402286529541, 65.92959431239537, 66.08285767691476, 73.72167246682304, 65.10116754259381, 79.86508900778634, 10.841486181531634, 1.4996401241847446, 1.6380723416805267, 0.12655205998037541, 1.6994555507387434, 57.73985685620989, 71.07531206948417, 48.8655481338501, 35.66305364881243, 26.73409734453474, 53.252335003444124, 42.7265054838998, 0.48030948106731686, 0.11538384854793549, 0.010039480303281119, 0.11794009352368967, 0.07809147571346589, 0.029281588404306343, 0.03642301341252668, 0.053260116904441795, 0.018636512204206417, 0.018040057870426347, 0.19850056139486177, 0.08387364580162934, 0.17983816138335637, 0.09125752494271312, 0.2866123504936695, 0.27694146228688105, 0.2525939701923302, 0.23743446650249617, 0.30899827927351, 0.4621141574212483, 12.83481058052608, 83.16717175074986, 54.37252358027867, 42.474786145346506, 64.97334153311593, 50.42066962378365, 90.00709656306675, 25.543615579605103, 0.4095502479800156, 0.7276892353381429, 5.587020865508488, 0.9936231225728989, 61.078396797180176, 95.43418857029506, 84.61090319497245, 88.12210587092808, 77.31241117204938, 83.71186188289097, 80.01749079568046, 82.96750136784145, 75.29901082175118, 74.43486336299351, 61.70720876966204, 62.11922999790737, 59.055887358529226, 60.36207226344517, 58.564774785723, 58.82596451895577, 55.43082455226353, 55.58109324319022, 55.45079367501395, 57.97354561941964, 53.03761829648699, 58.08870158876692, 54.854096276419504, 56.71280888148716, 53.5969899722508, 57.8825033732823, 50.32186623982021, 50.362756388528005, 47.80389813014439, 52.66055692945208, 53.50902925218855, 56.24175228391375, 55.51475879124233, 57.43813828059605, 49.33767127990723, 52.16104051045009, 52.40841375078474, 51.972233636038645, 48.75836522238595, 49.76984575816563, 50.95429474966866, 47.796828338078086, 51.76095281328474, 63.433287211826865, 61.68776076180594, 61.03062098366873, 57.73213045937674, 65.06300108773368, 60.777484212602886, 58.79685156685965, 62.988303729466026, 60.2419170652117, 63.34116104670933, 60.86177280970982, 61.24397931780134, 61.09463473728725, 66.91356345585415, 56.75406381062099, 44.035125732421875, 49.65054866245815, 55.107552664620535, 52.51261241095406, 55.472795145852224, 57.56547096797398, 58.63601466587612, 59.05733258383614, 58.54358972821917, 60.320091247558594, 57.980900287628174, 55.79785966873169, 57.67194168908255, 49.424982343401226, 41.647398131234304, 48.243114607674734, 46.703824588230674, 55.31473405020577, 56.77120501654488, 58.71763515472412, 55.14513547079903, 53.50348458971296, 51.10986144202096, 49.1434691292899, 44.103308405194966, 46.2059132031032, 43.98633895601545, 45.12686491012573, 51.12204163415091, 54.385231835501536, 51.31954417909895, 48.28600236347744, 45.023347173418315, 44.76727131434849, 44.728806086948936, 43.23696878978184, 44.699481214795796, 44.95195095879691, 47.43091535568237, 47.51161173411778, 46.67545856748308, 49.966538837977815, 50.26786484037127, 46.76747703552246, 44.40322739737374, 45.58700936181204, 48.59621163776943, 50.68444756099156, 50.42890323911394, 51.07619047164917, 51.26404891695295, 50.61471891403198, 59.40353352682931, 63.213786670139854, 66.29683440072196, 67.54902485438755, 68.88373906271798, 68.76609911237443, 65.65176364353725, 69.64408043452671, 69.13745948246547, 68.18343012673515, 69.52017320905412, 69.91137763432094, 59.646817752293174, 59.89771025521414, 61.86552347455706, 65.95175211770194, 62.350514684404644, 69.34701020377022, 69.29090350014823, 77.70771503448486, 69.69373226165771, 82.01017161778041, 10.249911342348371, 2.8396918518202643, 2.4231640653950826, 0.40129367102469715, 3.74768374647413, 69.69737311771938, 73.96519293103898, 59.21835708618164, 53.61140053612845, 25.897450855800084, 59.303194590977256, 54.326248577662874, 0.8875648964728627, 0.19323663599789143, 0.15185062746916497, 0.21940858662128448, 0.2186658621898719, 0.11854807447109904, 0.16035991800682886, 0.16334627276020391, 0.145357861582722, 0.08626563102006912], [0.05874343642166682, 0.036939110540385754, 0.03088533306228263, 0.08433982650084154, 0.04653692731101598, 0.03134998366502779, 0.12556715283010686, 0.012252307679903294, 0.15312273135142668, 0.401216019477163, 12.697404742240906, 69.24906144823346, 33.3794378553118, 28.64049369948251, 39.74735416684832, 46.117945534842356, 74.3489349910191, 9.659083434513636, 0.2148032473134143, 0.24419674649834633, 2.8564871677330563, 9.83607576574598, 82.4191425868443, 77.34615162440709, 78.91894585745675, 75.89543724060059, 75.52436869485038, 72.19822434016636, 74.10673468453544, 70.93685531616211, 68.14654908861432, 57.46725818089077, 53.513573374067036, 51.038927282605854, 51.85427059446062, 52.22942120688302, 52.475227628435405, 49.258107457842144, 49.073629311152864, 49.70208692550659, 49.378804615565706, 48.681941986083984, 49.54293148858206, 48.70309577669416, 49.88349049431937, 49.095575196402415, 49.2911878313337, 48.12638487134661, 43.00454459871565, 42.44757352556501, 42.37611130305699, 45.12198380061558, 46.826769488198416, 48.93200765337263, 49.7804000718253, 49.40796273095267, 45.53498819896153, 48.135865688323975, 45.951126234872, 47.12628548485892, 43.24807895932879, 44.02455404826573, 42.60535669326782, 45.75867850439889, 45.16167538506644, 55.1302559035165, 58.36641066414969, 52.69071905953543, 56.08016497748238, 55.25996140071324, 55.75946739741734, 61.07549939836775, 51.913886138371055, 56.16986274719238, 56.27510016305106, 56.57601622172764, 56.636003494262695, 57.51792791911534, 56.024124281747, 43.03619016919817, 41.309236254010884, 46.43369599751064, 53.05553075245449, 55.48190770830427, 53.15321200234549, 52.76909473964146, 54.946288449423655, 52.60706969669887, 53.03689915793282, 51.38704940250942, 51.83740036828177, 55.33708987917219, 53.350144795009065, 50.21236263002668, 44.86353513172695, 42.36594608851841, 38.18962710244315, 47.2271385874067, 55.114653723580496, 52.13617985589163, 51.00808770315987, 47.639739990234375, 44.55761637006487, 43.30988665989467, 41.50807980128697, 42.3070045198713, 46.87903036390032, 49.51167501722063, 51.334333419799805, 53.168206214904785, 50.76523774010794, 45.49468169893537, 41.98652580806187, 41.67251239504133, 40.326503889901296, 38.80588715417044, 40.50468349456787, 39.84792934145246, 41.633001463753835, 45.30979708262852, 44.42409283774239, 43.115823473249165, 41.35452808652605, 42.42493282045637, 41.6285719871521, 38.364860670907156, 40.496616636003765, 44.93934692655291, 44.354683807918, 45.98715264456612, 45.09604617527553, 47.15508229391915, 55.044713156563894, 60.84737614222935, 59.6635559626988, 63.28629112243652, 63.09582710266113, 63.979151589529856, 61.32904611315046, 64.45816734858921, 61.50626686641148, 63.89507838657924, 54.699467590876985, 51.76703943525042, 49.90601308005196, 53.667444705963135, 56.0095191683088, 58.90267957959856, 57.784280163901194, 62.7275447845459, 59.718335560389924, 72.7783294405256, 62.820650645664756, 85.0371195929391, 23.185827766145977, 0.5625423884817532, 0.17750248100076402, 0.10624086737100567, 0.08233783606972013, 25.58117754118783, 75.10652487618583, 46.56390871320452, 41.38649327414376, 23.825913190841675, 41.30388961519514, 38.9126740183149, 0.837488089288984, 0.284064207226038, 0.06788113859615155, 0.09203667991927691, 0.04372580422620688, 0.018488839235422865, 0.06806562548237187, 0.06008929027510541, 0.014966238256809967, 0.06314407528511115, 0.018738360310505544, 0.031186775636992285, 0.020803045681012527, 0.07404507284185716, 0.09875806460955314, 0.11375905573368073, 0.016947879422722117, 0.1305395524416651, 0.1467686173106943, 0.3290474962975298, 17.403443098068237, 75.5468669618879, 45.84108066558838, 32.29338230405535, 38.29987416948591, 57.001760142190115, 77.92849404471261, 10.543040207454137, 0.5337104041661535, 1.0685262233018875, 2.1286370924540927, 13.709192735808235, 90.27998011452812, 78.05529172079903, 80.18567889077323, 78.48992238725934, 75.97117260524205, 74.5124955858503, 76.03670801435197, 73.17660713195801, 69.70153508867536, 61.40767887660435, 57.53145258767264, 54.09606170654297, 54.54086453574044, 55.331545216696604, 55.49979931967599, 52.59478875568935, 52.37181064060756, 52.457099778311594, 51.968571935381206, 51.06682429994856, 52.22883408410208, 50.81906196049282, 52.06131649017334, 51.86663491385323, 52.687807764325825, 50.09799528121948, 45.696884700230186, 47.11460556302752, 44.71523625510079, 48.15628644398281, 49.9090633392334, 52.06459256580898, 52.02302149363926, 48.95887981142317, 47.82006311416626, 48.998665196555, 48.68135486330305, 48.705857685634065, 46.450653076171875, 48.88700417109898, 45.33623150416783, 48.65943329674857, 46.82325369971139, 58.901567867824006, 60.949716159275596, 54.60494777134487, 59.03951045445034, 59.022855622427805, 55.64224086488996, 63.542234965733115, 55.54599789210728, 60.027780532836914, 58.52626092093331, 60.71645123617989, 58.74020985194615, 60.670912742614746, 57.69170583997454, 45.96644006456648, 42.030702454703196, 47.415466036115376, 53.995100906917024, 58.47755404881069, 56.692641735076904, 56.49581316539219, 57.18919127328055, 55.182492460523335, 53.56704671042306, 53.168289593287874, 55.13841656276158, 57.26131010055542, 56.820412158966064, 50.3165717124939, 44.7776449748448, 43.58582394463675, 42.16090474809919, 52.728572845458984, 57.88517495564052, 53.71139553615025, 54.24095596585955, 49.337824140276226, 48.89385509490967, 45.91128526415144, 44.72672162737165, 46.29947764532906, 50.81444835662842, 50.88758856909615, 54.897967202322825, 55.69095121111189, 51.24499348231724, 48.85914536884853, 45.90256527491978, 44.382848330906455, 43.25796972002302, 41.835795061928884, 42.07010221481323, 43.13894707815987, 44.422654560634065, 47.37713629858834, 47.13000971930367, 45.20334720611572, 44.20531490870884, 44.314693450927734, 43.18783460344587, 41.66670370101929, 41.42522600718907, 46.99852548326765, 47.70083202634539, 47.808619431086946, 46.79297692435128, 51.08283642360142, 57.00353193283081, 63.323304176330566, 62.42881393432617, 64.2587262562343, 63.607964924403596, 67.21489293234688, 62.76603085654122, 65.47336169651577, 63.710763522556846, 63.81739752633231, 56.291518756321494, 53.820186955588206, 51.69020625523159, 56.88812582833426, 56.258004120418, 62.787799562726704, 58.5711601802281, 66.69706453595842, 60.10071577344622, 75.99758270808628, 63.8724342073713, 88.15258761814663, 28.307704516819545, 0.6109658500977925, 0.5336441248655319, 0.06793544853904418, 0.18024224255766186, 24.483032124383108, 80.22526972634452, 56.01123884746006, 40.63296113695417, 30.286846773965017, 50.466454778398784, 47.05679655075073, 1.673607926283564, 0.3147635470543589, 0.04316124951999102, 0.1279046923986503, 0.10303478940789189, 0.051423987573278804, 0.0357727190213544, 0.05154134699010423, 0.062281399433101924, 0.0822663116934044, 0.22719222466860498, 0.18409077104713234, 0.13498663024178573, 0.165890724797334, 0.16229505916791304, 0.20867782671536717, 0.13736480048724584, 0.26127588003873825, 0.28259466322404997, 0.3458179235458374, 20.54314296586173, 92.64627947126115, 44.52191652570452, 39.60349171502249, 55.10605532782418, 60.79043565477644, 88.13043676103864, 12.46807771069663, 0.4283408096858433, 1.295809941632407, 7.4058495078768045, 12.995690907750811, 90.30352755955288, 84.92763682774135, 84.17281232561383, 82.46673774719238, 78.6796429497855, 79.1667811529977, 79.48013796125139, 77.21397604261125, 72.45927510942731, 62.71218926565987, 59.80538954053606, 58.21182714189802, 58.015029839106965, 59.29377283368792, 58.964073862348286, 56.9369021824428, 55.20046397617885, 58.377451351710725, 54.383230754307334, 55.830019405909944, 54.65268536976406, 53.69264234815325, 55.84060846056257, 53.52540615626744, 53.21258783340454, 53.47760254996163, 47.846983909606934, 50.86210257666451, 50.088479723249165, 53.15611982345581, 52.545133454459055, 53.9587653023856, 54.3472911970956, 50.47221483503069, 47.9639116695949, 50.98510306222098, 50.34855079650879, 51.0692457471575, 48.75082295281546, 50.4603716305324, 49.16331665856497, 50.59837327684675, 48.972588607243125, 60.8892251423427, 64.51353059496198, 59.92159816196987, 58.281468936375205, 60.90378161839077, 60.00747094835554, 65.09638718196324, 59.34184047154018, 63.173681667872835, 61.967891284397666, 62.34392779214041, 62.10715402875628, 63.093110357012065, 61.81867177145821, 50.57768154144287, 45.35591575077602, 49.475155285426546, 55.67307349613735, 60.389086859566824, 59.349226406642366, 59.460258620125906, 60.31615856715611, 57.17781707218715, 57.19361727578299, 56.77067347935268, 57.76032624925886, 59.43288966587612, 60.88045651572091, 52.72288574491228, 45.15405668531145, 44.2693703515189, 45.477092334202354, 56.04897451400757, 60.62595789773123, 56.5058012008667, 55.79496921811785, 53.28624221256801, 50.287955556597026, 48.463282176426475, 49.076127188546316, 48.109702246529714, 53.09810583932059, 52.47985165459769, 56.90452010290963, 57.62376635415213, 55.105040890829905, 51.046316691807334, 47.54698501314436, 47.30888066973005, 45.6176300730024, 44.73850924628121, 47.13414389746529, 46.732426847730366, 47.446326460157124, 50.05145624705723, 48.73975099836077, 47.48704637799944, 48.104772499629426, 46.60610859734671, 46.753469467163086, 44.414215973445344, 45.17146192278181, 48.71341732570103, 50.541999067579, 51.03138848713466, 48.254589557647705, 53.15548753738403, 59.70827456883022, 66.83657046726772, 66.07922376905168, 67.24383912767682, 68.37531157902309, 70.79957975660051, 64.81168474469865, 69.37560898917062, 66.76601845877511, 69.32352529253278, 59.104003633771626, 55.07607037680489, 54.9578572000776, 59.310490199497764, 60.58564444950649, 63.69784682137625, 62.60376957484654, 69.94560446058, 64.35873862675258, 79.0049159186227, 68.47091879163469, 92.91581399100167, 27.849102565220424, 1.2290818308080946, 1.6818954987185342, 0.29888159355946947, 0.3333682173064777, 33.27924830572945, 88.62325164249965, 60.234461648123606, 57.34272909164429, 32.101997647966655, 53.72014331817627, 56.567049571446006, 1.5074520707130432, 0.41698140065584866, 0.21820582901792868, 0.25434925886137144, 0.22118462489119597, 0.10192942872111287, 0.15434523432382516, 0.2836547520543848, 0.1540338003209659, 0.13091767286615713], [0.00875728830162968, 0.05889429511236293, 0.08520080601530415, 0.024627803392442207, 0.06890472224248306, 0.03727616602554917, 0.07000441716185637, 0.055249405160014115, 0.13493071895624908, 0.17878272730324948, 21.39123661177499, 58.499614579336985, 29.88306610924857, 31.56959193093436, 35.5133547101702, 52.95863464900425, 69.09670829772949, 2.7555370075362067, 0.163808192259499, 1.1331991872617175, 1.101774656346866, 39.382896832057405, 86.36414214542934, 78.81466034480503, 79.39985847473145, 73.11836038316999, 71.09947790418352, 68.99458367483956, 70.14100170135498, 66.7471263068063, 59.673213958740234, 53.13896472113473, 53.01878867830549, 50.81598738261631, 51.94000094277518, 53.196968282972065, 51.814224651881624, 50.57416922705514, 50.36390631539481, 49.52946240561349, 50.397313254220144, 49.092684745788574, 49.965885707310264, 48.734602383204866, 49.45898335320609, 48.69052301134382, 51.58463879993984, 47.089574677603586, 44.44166135787964, 42.17025702340262, 45.29384749276297, 44.80207136699131, 46.7218655858721, 46.42625447681972, 51.930231775556294, 47.76504727772304, 46.013670444488525, 44.59533814021519, 44.121297291346956, 47.559595993586946, 47.365762097494944, 44.37446532930647, 45.86792503084455, 41.9453820501055, 44.54959467479161, 49.2035675730024, 57.78852898733956, 51.74159860610962, 53.771143095833914, 54.84075920922415, 58.657595770699636, 55.902489117213655, 53.256375380924766, 57.40600633621216, 57.50902380262102, 58.04013368061611, 55.428882530757356, 58.60225336892264, 48.477192470005576, 45.61081041608538, 42.754454612731934, 43.94562251227242, 53.304748739515034, 57.204390457698274, 53.40857914515904, 57.037400926862446, 53.09096656526838, 51.602085726601736, 49.70251076562064, 46.263319219861714, 49.14986842019217, 56.275940895080566, 54.7624842779977, 51.60678618294852, 44.495766980307444, 44.70978886740548, 41.83648640768868, 39.51914405822754, 50.004347460610525, 54.47627408163888, 52.68816212245396, 49.65945625305176, 46.458455903189524, 46.50837871006557, 47.03056362697056, 49.78744901929583, 50.25773089272635, 54.127307755606516, 53.22911759785244, 56.557290826525005, 49.90471724101475, 47.10021931784493, 44.84683166231428, 40.79395089830671, 40.560845783778596, 38.202179023197715, 38.65202277047293, 41.98494509288243, 42.83312906537737, 45.67995541436331, 43.10376140049526, 42.25613328388759, 41.05894129616873, 43.09651442936489, 40.02616800580706, 39.861384528023855, 38.93862901415144, 44.69897747039795, 43.48600959777832, 46.334065777914866, 45.46275472640991, 48.247926235198975, 55.06191689627511, 60.50050817217146, 59.5343542098999, 60.85272625514439, 59.23524120875767, 62.13512747628348, 60.754013197762625, 59.118038994925364, 55.588131768362864, 53.555182661329, 47.90469912120274, 51.12039491108486, 49.77645696912493, 54.582623209272114, 55.07893303462437, 58.30232742854527, 57.200311865125386, 61.07785483769008, 61.31847095489502, 69.80867631094796, 64.86478287833077, 79.41189275469098, 50.08253901345389, 0.1274811779814107, 0.6211074516177177, 0.19772293312208994, 0.2642695222582136, 6.977193423679896, 71.17596367427281, 52.784603118896484, 46.36990458624703, 43.19181939533779, 38.14540181841169, 53.40688725880214, 3.2577849371092658, 0.39195127519113676, 0.08538825809955597, 0.09037491373185601, 0.14174652179437025, 0.09237475320696831, 0.04045746728245701, 0.046918939133839946, 0.036818378804517646, 0.024335303909278343, 0.03869814472272992, 0.03406092105433345, 0.051165224851242135, 0.02460323872842959, 0.0714343890015568, 0.027651324901463728, 0.11866707594266959, 0.07513176024492298, 0.10086746713412659, 0.09435050468891859, 29.359696524483816, 67.62667097364152, 35.990414551326204, 30.606144292013987, 40.25607000078474, 61.343574796404155, 72.596022605896, 2.3622926345893314, 0.1880243606865406, 0.3338447931621756, 0.29507045234952656, 47.209729875837056, 89.1413162776402, 79.67848123822893, 80.36369868687221, 75.13044752393449, 74.23279585157121, 71.84857709067208, 72.26095267704555, 69.37866619655064, 61.70587471553257, 55.04110009329659, 55.41826915740967, 54.13740348815918, 55.7431252343314, 55.776271615709575, 53.53287546975272, 54.7986843926566, 53.355727672576904, 53.1765718460083, 53.293708051954, 50.68845667157854, 51.56790058953421, 52.38694034303938, 52.86318029676165, 53.459832532065256, 52.805544989449636, 49.974942684173584, 46.10750239236014, 44.16918427603585, 47.04346990585327, 46.97659696851458, 48.192111355917795, 49.33987385886056, 54.46592126573835, 47.014266627175466, 47.27198920931135, 45.18733508246285, 46.90994984763009, 47.91888039452689, 48.692173208509175, 46.757284028189524, 47.996655055454795, 46.21069008963448, 46.7627592086792, 51.00198023659842, 59.96009118216378, 57.2944530078343, 57.67129898071289, 54.74531875337873, 59.12450776781355, 59.65582956586565, 58.14283847808838, 59.93481363568987, 60.34255477360317, 59.274519375392366, 57.93980516706194, 61.06696006229946, 53.23898751395089, 50.39836243220738, 44.87477731704712, 44.810030528477256, 53.345857756478445, 60.914926528930664, 54.71931512015206, 58.532291957310264, 55.311103616442, 53.519548824855256, 50.648379462105886, 49.055880137852256, 52.78788266863142, 58.812505858285085, 55.13357366834368, 52.57474667685372, 45.825805050986155, 46.03254522596087, 42.17190374646868, 44.20510993685041, 53.08204160417829, 58.18347501754761, 55.312312602996826, 53.06302785873413, 47.714943817683626, 47.855439867292134, 51.13385704585484, 53.562836102076936, 53.87442111968994, 55.230125835963655, 55.31600209644863, 58.67823192051479, 52.93591056551252, 48.568783623831614, 46.505293709891184, 43.81702177865164, 44.54723228727068, 41.82542487553188, 41.92191103526524, 44.866522857121055, 46.03703376225063, 47.490478788103374, 45.27311406816755, 46.17494855608259, 43.991828032902305, 45.42036376680647, 42.717497144426616, 43.29947478430611, 40.18699101039341, 45.88952350616455, 48.40499373844692, 47.62409264700753, 47.81522716794695, 50.220210620335166, 57.07385465076992, 61.8171501159668, 60.79152652195522, 62.95425755637032, 61.07700020926339, 64.11581570761544, 60.95378085545131, 59.47053500584194, 57.774170534951345, 54.470243045261924, 51.09487417766026, 52.36360829217093, 50.537656443459646, 56.17202016285488, 57.11839607783726, 61.584142276218955, 59.474731717790874, 62.040548597063335, 62.81880242483956, 72.3462974003383, 67.06003843035016, 77.95592553274972, 56.9897849219186, 0.2248886525630951, 1.1775871025664466, 0.3093910153423037, 0.4434271401592663, 6.655901772635324, 74.84292411804199, 61.831248010907856, 45.541957242148264, 31.815301077706472, 44.27315017155239, 63.065060479300364, 5.729079391275134, 0.31431598535605837, 0.19284122650112423, 0.026328610788498606, 0.15298292599618435, 0.04266945073114974, 0.027366189219589745, 0.08158368510859353, 0.025983955711126328, 0.0191544905704047, 0.14749156923166343, 0.15277112807546342, 0.2020776623061725, 0.09035362130297081, 0.18423490545579366, 0.08655078536165611, 0.2340341918170452, 0.1810945232531854, 0.22824047984821455, 0.4180592399622713, 33.80503586360386, 80.09912518092564, 40.65710960115705, 43.21746172223772, 51.71982989992414, 67.53624016898019, 82.0395347050258, 3.3852780844484056, 0.23136999191982405, 4.797409772872925, 2.487455529826028, 48.62102712903704, 90.84741864885602, 86.07814734322685, 86.36490644727434, 80.09110695975167, 76.51747471945626, 75.37079266139439, 75.24869891575405, 73.693407194955, 64.09253229413713, 60.39068494524275, 59.22066388811384, 57.510020869118826, 58.2347457749503, 58.48497472490583, 58.37438024793352, 57.82867915289742, 57.14778348377773, 56.39847237723214, 57.54683242525373, 55.23778622491019, 56.369050230298726, 55.83708572387695, 55.50374589647566, 55.44073615755354, 55.520970480782644, 53.866295201437815, 49.67307472229004, 47.88281576974051, 50.31022800718035, 49.90364374433245, 50.659722396305625, 51.05856984002249, 55.86452416011265, 49.899183000837056, 47.77451419830322, 45.239245074135916, 48.22032104219709, 51.86179549353463, 52.07235370363508, 50.85111052649361, 50.707383564540315, 47.79149906975882, 48.72177253450666, 52.89217512948172, 62.335089683532715, 60.61665425981794, 60.6538062776838, 58.18126549039568, 60.863843372889924, 62.24944618770054, 60.42133344922747, 61.45833124433245, 63.63600785391671, 60.4307621547154, 64.08038684300014, 63.67734268733433, 56.40673725945609, 51.65625040871756, 46.333502973829, 45.12861238207136, 53.59647233145577, 63.588051387241904, 56.646224294389995, 60.659274509974885, 57.55878332683018, 55.66674368722098, 53.040804045540945, 51.995471886226106, 53.792241300855366, 60.513077463422505, 59.35932213919503, 55.60806615012032, 48.11608764103481, 47.078408922467915, 45.54785973685128, 45.27567447934832, 55.63089445659092, 59.478636605399, 56.67213412693569, 55.64899451392037, 50.76537322998047, 50.92873580115182, 51.16960552760533, 55.30071258544922, 55.67985493796212, 57.91242579051426, 58.25638593946184, 62.33733395167759, 56.636750425611226, 51.44123492922102, 49.19380187988281, 45.39706993103027, 45.63542440959385, 43.61877230235508, 43.736759662628174, 47.1136223929269, 46.38641003199986, 49.45694753101894, 46.75313595363072, 48.37325436728341, 45.7125563621521, 49.613559927259175, 46.61401217324393, 45.0763897214617, 43.49087681089129, 48.06002957480294, 50.167439052036826, 50.885062898908345, 49.073236737932476, 54.07050623212542, 60.352240562438965, 64.28225285666329, 63.43201569148472, 67.6527406147548, 63.39678832462856, 67.99102061135429, 66.29946776798793, 62.659105028424946, 61.72865785871233, 58.14639942986624, 54.89876971926008, 56.106450012751985, 53.13077279499599, 61.40442017146519, 62.173662185668945, 64.95023877280099, 63.07719203404018, 66.48481096540178, 68.22614070347377, 76.13747079031808, 71.5529590334211, 82.6262128012521, 57.72453260421753, 0.3380768432148865, 4.088849416800907, 0.5398947894573212, 0.5170290278536933, 9.584141901561193, 83.03728212629045, 64.46537263052804, 62.80976281847273, 56.1245049067906, 49.219110693250386, 72.40191078186035, 6.062006235122681, 0.5227383300662041, 0.23528467757361277, 0.1394864437835557, 0.26988220108406885, 0.2196625487080642, 0.179268531235201, 0.20691126079431602, 0.09733711728560072, 0.12387739707316671], [0.042651194746473005, 0.05042101103546364, 0.042232986473079236, 0.026369003978158747, 0.020204903491373574, 0.06367975154093333, 0.07151055455740009, 0.023414514925596968, 0.06370738827224288, 0.03888411420796599, 33.60876662390572, 57.9051718711853, 29.01740915434701, 40.79974569593157, 40.499454975128174, 61.67332935333252, 56.67799145834786, 0.3542642188923699, 0.035573813265987804, 0.20539610566837446, 1.1715407584394728, 65.8523233958653, 81.39904281071254, 73.01731273106166, 73.71334157671247, 70.66583388192313, 68.66537107740129, 68.4280275617327, 64.5547959463937, 60.08356761932373, 53.750204699380056, 54.47889007840838, 52.444547857557026, 52.268265111105784, 51.63867841448103, 51.803027629852295, 51.48864596230643, 52.07796089989798, 49.34876755305699, 49.18829543249947, 47.78601694107056, 49.46168967655727, 49.03887789590018, 49.13929673603603, 47.14594888687134, 48.52837984902518, 50.20710284369332, 47.12562540599278, 40.75480474744524, 42.9373277255467, 44.8700247492109, 44.64325639179775, 45.67870821271624, 47.370170729500906, 49.16845137732369, 47.15330008098057, 44.12720673424857, 44.99259097235543, 46.62492431913103, 46.74977649961199, 48.89094727379935, 44.55035202843802, 43.08707182747977, 43.04403121130807, 45.04935775484358, 46.84447002410889, 56.52536385399954, 57.31625645501273, 51.30093342917306, 52.16658169882638, 60.35232394082205, 57.715319292885916, 58.384114674159456, 58.89370250701904, 56.11871705736433, 54.31675386428833, 56.90952627999442, 55.91031278882708, 47.341339179447715, 45.54837737764631, 42.475248200552805, 44.61222921098982, 55.878170422145296, 54.067879813058035, 56.718718324388774, 55.63814490182059, 51.3587771824428, 46.98632097244263, 49.38862589427403, 44.5597494670323, 49.96162298747471, 54.63747576304844, 58.83310726710728, 52.09826701028006, 46.90891804013933, 42.40591907501221, 41.49040010997227, 39.00500862939017, 42.06356395993914, 53.847437790461946, 53.03208753040859, 51.27411685671125, 48.2840290750776, 50.00303425107683, 53.944997446877615, 53.64058991840908, 54.9909097807748, 54.51798759187971, 55.6134649004255, 52.685421058109824, 51.064531394413535, 51.69916595731463, 45.88753979546683, 40.59264421463013, 41.52427952630179, 40.88116121292114, 39.422498089926584, 42.41710914884295, 44.20305674416678, 45.230361802237375, 43.61387382234846, 45.954440525599885, 42.525695596422466, 41.82595641272408, 40.46055201121739, 42.06710754122053, 37.67674929755074, 39.6798107283456, 45.389430386679514, 44.49067742483956, 45.760787282671245, 46.290990420750205, 50.691812651497976, 53.97540276391165, 59.69323171888079, 57.54051998683384, 55.102956431252615, 53.268166473933626, 53.1523608480181, 51.28838498251778, 50.08288642338344, 48.2098570551191, 48.788565567561555, 47.19020891189575, 49.68865258353097, 51.608398165021626, 55.024546010153635, 53.61331476484026, 56.402345997946604, 56.66755526406424, 59.77453259059361, 65.84291553497314, 72.49642017909459, 71.92992659977504, 72.57708876473563, 2.9369555584021976, 0.4054192996450833, 0.32296063005924225, 0.11235013883560896, 2.0944782282624925, 60.49827085222517, 60.741193771362305, 47.08133063997541, 49.12338188716343, 27.460764271872385, 52.98744535446167, 8.365841286523, 0.22587973438203335, 0.05354465717183692, 0.04528667904170496, 0.03605881652661732, 0.04563204997352191, 0.025047696129019772, 0.07180482840963773, 0.05652419604094965, 0.015260138914787343, 0.03961292188614607, 0.07896604628435203, 0.032471761506583006, 0.051837503777018616, 0.02130524980436478, 0.06679179812116282, 0.045905469051961384, 0.07637064305267163, 0.09285144441361938, 0.09181242409561362, 44.26282862254551, 64.2823292868478, 37.807139192308696, 36.44267627171108, 47.20745086669922, 70.12654944828579, 62.02306692940848, 0.20732611710471766, 0.05090342568499701, 0.8737549717937196, 1.8019438683986664, 73.03715678623745, 82.23488330841064, 75.56955283028739, 75.46594129289899, 72.31396048409599, 71.73334121704102, 70.29782254355294, 66.27869265420097, 62.82360363006592, 57.64311013902937, 58.042683669498985, 57.39062302453177, 54.86277110236031, 54.49823038918631, 54.65247344970703, 54.47282082693917, 55.71369961329869, 53.424052783421104, 52.40016276495797, 51.431858335222515, 53.00701495579311, 50.68563570295061, 51.60419797897339, 51.98983342306954, 51.84287902287075, 51.09972054617745, 49.310573305402485, 43.64447716304234, 45.96977172579084, 46.09520755495344, 48.341153689793174, 46.78905119214739, 50.24681874683925, 52.51140342439924, 48.3634261403765, 44.68633869716099, 46.98379877635411, 47.96462038585118, 48.38184928894043, 51.24503864560808, 49.13046210152762, 46.093949931008474, 46.536637033735005, 47.4616368157523, 49.833942890167236, 58.825394766671316, 61.18428039550781, 56.5426162311009, 56.8188488142831, 60.86499677385603, 59.6989083971296, 58.13378497532436, 60.6651040485927, 59.818528584071565, 59.292098317827495, 59.22700064522879, 59.19378825596401, 52.2753244808742, 50.226769719805034, 44.84315953935896, 46.123879296439036, 59.43118040902274, 57.04182692936489, 58.900477000645225, 55.02953829084124, 52.14294392721993, 49.184706687927246, 52.770119598933626, 46.81189339501517, 50.803744656699045, 55.79864134107317, 59.23513698577881, 51.71602923529488, 45.8193883895874, 43.769867828914094, 41.40293271200997, 42.37470429284232, 46.07539824077061, 56.21900040762765, 54.855013438633506, 54.869034903390066, 51.094485078539165, 54.537828172956196, 54.9439434323992, 56.73389319011143, 57.26280743735177, 57.42368255342756, 56.42027235031128, 53.241051128932405, 53.89544984272548, 52.306983947753906, 47.57635504858834, 43.05549226488386, 43.904551710401265, 41.375007901872905, 43.67458370753697, 43.446300642830984, 46.76092141015189, 46.016689436776296, 45.39734091077532, 47.99725260053362, 45.563927446092876, 44.91353089468819, 43.59953621455601, 43.26396948950631, 40.46316800798689, 41.99117415291922, 48.225903919764924, 46.33077580588204, 48.0550650869097, 46.99298776899065, 53.64706563949585, 56.95325476782662, 59.93767629350935, 58.98142351422991, 58.13697419847761, 55.38713775362287, 55.143627711704795, 52.60329335076468, 52.05592816216605, 48.965473651885986, 50.64694465909685, 50.76953520093645, 52.31484236036028, 53.200577872140066, 58.1359806060791, 56.171005725860596, 58.54245022365025, 57.78203589575631, 61.91062423161098, 67.0118943623134, 75.58088534218925, 73.4564597266061, 75.83887890407017, 4.514154297964914, 0.8621197789907455, 0.3639331529183047, 0.16584078461996146, 2.1567143286977495, 65.56712763650077, 70.05715778895787, 51.68416132245745, 35.72256844384329, 31.970628057207378, 62.42541626521519, 13.531255449567523, 0.3133436989571367, 0.048341073894074986, 0.07216017041355371, 0.033712673134037426, 0.014015435972916228, 0.027471524995884726, 0.03620333430756416, 0.01823762182279357, 0.054062616878322194, 0.1200733126274177, 0.15178802582834447, 0.07882565060364348, 0.09640378558209964, 0.12807378332529748, 0.1391316649637052, 0.12411077240748064, 0.12289862387946673, 0.16366708411702088, 0.22216516227594443, 50.093871525355745, 74.44536209106445, 39.39151954650879, 52.65876429421561, 57.58883775983538, 75.67437335423061, 71.00910963330949, 0.6435954592057637, 0.14652125058429583, 2.3229087250573293, 2.0913576185703278, 73.06697845458984, 85.25095735277448, 78.73670155661446, 78.84859534672329, 77.58444704328264, 75.72417804173061, 75.63929884774345, 69.63380404881069, 67.40466908046177, 60.02675914764404, 59.68651281084333, 62.2401008605957, 58.114948408944265, 60.1878114427839, 57.94541583742414, 59.07088157108852, 61.35055773598807, 56.05460255486624, 55.86281490325928, 53.97159167698452, 57.51126112256731, 53.16663939612252, 54.7046092578343, 56.19880894252232, 54.697709696633474, 54.83349139349801, 53.4657176562718, 47.745418616703574, 49.558356489454, 49.11517953872681, 50.89308112008231, 50.27272163118635, 53.86641679491316, 52.91899517604283, 47.968118803841726, 45.42623152051653, 46.92341545649937, 50.477655274527415, 51.73829473767962, 55.05872767312186, 50.87211840493338, 48.090441840035574, 48.67819343294416, 50.08901126044137, 51.176918506622314, 61.71184321812221, 61.51817607879639, 59.372085980006624, 61.82985837118966, 66.42573043278286, 62.234854970659526, 63.17941393171038, 62.46204716818673, 62.270012855529785, 59.652001108442036, 63.8039527620588, 61.565937995910645, 53.83238104411534, 51.776343073163716, 46.03956985473633, 46.60242257799421, 60.81844384329659, 58.98263250078474, 62.52857616969517, 60.1260141645159, 54.531540053231375, 50.21504463468279, 55.81150593076433, 49.19977385657174, 51.56635461534773, 58.67786366598946, 62.64349242619106, 54.19757488795689, 46.920754296439036, 46.134777545928955, 43.43837969643729, 41.75910084588187, 49.530747822352815, 57.9465206010001, 58.522057260785786, 57.53282833099365, 51.93365028926304, 57.15256037030901, 58.822942052568706, 59.1440669468471, 59.01339912414551, 60.31830556052071, 59.6404184613909, 57.8920293535505, 56.80522339684622, 54.370755263737266, 49.417495659419465, 44.21116876602173, 45.888634136744905, 45.549040930611746, 45.54132495607649, 46.12460190909249, 48.43540252958025, 47.645048413957866, 46.32718358721052, 51.21267393657139, 48.44079433168684, 48.224952016557964, 46.79937621525356, 45.9832547051566, 43.92144625527518, 44.04192801884243, 50.37045499256679, 48.8829915864127, 50.14360325677054, 50.841893741062705, 56.353791986192974, 59.68248980385916, 65.41915185110909, 62.84894371032715, 60.4090907233102, 58.5687005179269, 57.676259994506836, 57.60118818283081, 54.337191990443635, 52.98882457188198, 54.286598682403564, 54.04685109002249, 54.459834643772666, 57.20049599238804, 62.15829971858433, 60.0513140814645, 62.47002370016915, 61.13708128247942, 65.87248706817627, 71.15426445007324, 79.31912735530308, 77.4912508555821, 78.36620276314872, 4.321673129286085, 1.5849623743976866, 0.6298310235142708, 0.3243760812495436, 3.698349799428667, 74.29771287100655, 72.57653985704694, 65.22963278634208, 68.08030496324811, 39.20691633224487, 71.84401212419782, 14.588380438940865, 0.3743029593357018, 0.27617466343300684, 0.17101483126836164, 0.1451954474406583, 0.08024710004350968, 0.14744610738541397, 0.13275897263416223, 0.14564864097961358, 0.13264710935098784], [0.024030843550073247, 0.048591287074876685, 0.09372516003038202, 0.06371871302170412, 0.012943192884059889, 0.07285993000758545, 0.040450020360627344, 0.07212514443589108, 0.03458470259127872, 0.9153253925698144, 49.676336901528494, 43.672617367335725, 28.764868191310338, 41.03533479145595, 42.10322080339704, 62.39023058755057, 47.84094245093209, 0.19336459413170815, 0.4299032858439854, 1.6325549291712897, 5.75607705116272, 80.15482194083077, 78.71967847006661, 80.73604570116315, 73.40050588335309, 70.20029762813023, 62.82137325831822, 61.09467642647879, 57.80847379139492, 55.56313214983259, 54.60479491097586, 52.610818249838694, 53.536346094948904, 52.30488211768014, 50.98621824809483, 50.12606600352696, 52.34806169782366, 51.166378089359824, 50.243827547345845, 48.42246845790318, 47.9633002281189, 50.44746535164969, 48.55089201245989, 49.89618485314505, 49.80193601335798, 48.49719633374895, 48.73494284493582, 46.25876120158604, 41.549685614449636, 42.462470463344026, 45.03409603663853, 45.469616072518484, 45.71211167744228, 49.20713894707816, 51.10791594641549, 47.974945408957346, 45.111568450927734, 43.04368380137852, 45.62550238200596, 48.15325008119856, 47.78445707048689, 45.75089652197701, 44.918960911887034, 42.99039111818586, 45.27212047576904, 44.44458654948643, 53.063965865543906, 58.43655967712402, 56.680628299713135, 51.55113458633423, 46.85156066077096, 57.64526408059256, 54.94138649531773, 58.24563012804304, 59.408181871686665, 56.24507352284023, 56.019618374960764, 56.85987445286342, 49.68839202608381, 37.46088266372681, 43.70690672738211, 50.99981934683663, 54.79662772587368, 55.259572301592144, 56.63808100564139, 49.37814106260027, 52.288098743983674, 52.32454204559326, 50.13774592535836, 49.71525723593575, 52.11329596383231, 46.728858947753906, 51.936860357012065, 51.535257952553884, 45.87457793099539, 44.95240606580462, 39.17570155007498, 38.83571229662214, 36.055022375924246, 54.56278262819563, 51.73343447276524, 54.21103354862758, 52.007210867745535, 52.937123026166645, 52.71563877378191, 55.98129905973162, 51.80962494441441, 51.82387917382376, 47.88928801672799, 48.356634276253835, 55.5044025012425, 52.12850557054792, 43.299596377781455, 41.82024151938302, 42.11176013946533, 40.41323477881295, 40.244859082358225, 43.84973042351859, 42.72164174488613, 41.405705043247764, 42.871660300663535, 47.3621837752206, 43.336136954171316, 43.01820475714547, 42.860265254974365, 41.12682867050171, 38.61829274041312, 36.891720976148335, 44.530007702963694, 45.5155645098005, 44.754173960004536, 42.69070141656058, 44.19287415913173, 49.104475838797434, 53.424956049237935, 53.1926395552499, 51.93927138192313, 51.313401971544536, 50.121733801705496, 48.109111649649485, 48.05932780674526, 47.64993299756731, 46.59080171585083, 47.40031896318708, 50.17510291508266, 47.87150757653372, 52.43931238991873, 50.56290967123849, 54.06826196398054, 58.28734711238316, 63.278404917035786, 64.11536407470703, 72.08929743085588, 64.9661362511771, 86.18954086303711, 15.009123393467494, 0.9236542199339185, 0.3506789212780339, 0.05616363610274025, 1.1575971352202552, 50.320813587733674, 66.0859774180821, 46.195188658578054, 40.52918284279959, 17.52840644972665, 54.24851213182722, 19.614396367754253, 0.3552628053086144, 0.03088186914101243, 0.04275778581255248, 0.03278016924325909, 0.060738594005150456, 0.05291194362299783, 0.028886986364211355, 0.03684586965079818, 0.0510075502762837, 0.0592830346098968, 0.02699805174155959, 0.06733185771320548, 0.12007424900574343, 0.026333194292549576, 0.052417230526251454, 0.01680911222605833, 0.05369410450969424, 0.02400177002086171, 1.3137327113321848, 59.5103759765625, 51.14247281210763, 38.654607500348774, 40.69515446254185, 49.16799627031599, 69.8865795135498, 52.0933198928833, 0.4168680581663336, 0.32169638361249653, 1.856913673026221, 7.202618173190525, 85.79027652740479, 78.60444954463414, 81.73115975516183, 76.9477071762085, 73.59570162636894, 65.44341496058873, 61.910867418561665, 60.74373681204659, 58.37212903159005, 56.25811529159546, 55.48569795063564, 54.45339018957955, 54.53625440597534, 54.18446363721575, 53.981888907296316, 54.09899732044765, 54.15713289805821, 53.46384859085083, 51.81234516416277, 52.49739933013916, 53.11471550805228, 49.96758106776646, 51.22999232155936, 51.59517226900373, 51.238555976322715, 49.615856306893484, 48.081061771937776, 46.06350292478289, 44.12030022484915, 46.386879035404746, 47.1739570753915, 48.62427888597761, 52.86094297681536, 52.26123006003243, 48.76819692339216, 47.437828813280376, 45.34185259682791, 47.48295736312866, 49.52509546279907, 49.735618931906565, 48.0647508757455, 47.07087707519531, 46.312943254198345, 47.11628007888794, 47.812058789389475, 54.786764757973806, 58.440214429582866, 58.99677208491734, 57.882628440856934, 50.662612846919465, 55.367707116263254, 57.46851927893502, 59.5678653717041, 59.03448690686907, 60.97287450517927, 56.864703450884136, 58.722860200064524, 54.62128298623221, 43.834225518362864, 46.99555165427071, 50.9194530078343, 55.77235630580357, 57.076835427965435, 57.057352679116384, 50.38040133884975, 53.01335866110665, 53.00675439834595, 50.22536965778896, 52.243414878845215, 54.00523485456194, 47.57489940098354, 50.7369898387364, 51.77178505488804, 46.165922846112935, 46.61693736485073, 39.845236914498464, 41.99988719395229, 41.97668021065848, 56.03113848822457, 54.27138907568795, 56.04578876495361, 54.760465826307026, 55.01845243998936, 54.84804786954607, 56.434408460344585, 52.72431359972273, 51.176894187927246, 48.80588742664882, 52.18437603541783, 54.82213108880179, 53.30481127330235, 44.206166063036235, 42.72583498273577, 43.36408608300345, 41.97158718109131, 42.96693399974278, 47.32223858152117, 45.68977321897234, 43.40727955954415, 44.46470158440726, 49.85816431045532, 47.11992788314819, 45.74741200038365, 45.39176498140608, 42.814250809805735, 41.80735261099679, 38.84898335593087, 46.62820386886597, 48.44690179824829, 47.46152911867414, 46.15483699526106, 46.598385674612864, 52.2953005518232, 55.23606307165963, 55.44626692363194, 54.19947869437081, 53.80564785003662, 53.74421535219465, 50.44698245184762, 50.52952357700893, 49.42202935900007, 48.61861263002668, 50.34640727724348, 52.25981610161917, 49.32719687053135, 55.150610651288716, 54.26705339976719, 57.36326796667916, 59.566531317574636, 66.29443727220807, 64.91385800497872, 75.43143653869629, 65.84902300153459, 88.79039055960519, 19.014002527509415, 0.96381057373115, 0.299190598406962, 0.13596840256026813, 0.8964568536196436, 54.87504856927054, 72.63354287828717, 52.35566302708217, 41.59718350001744, 23.97947880199977, 63.28014196668352, 25.786559343338013, 0.3517552949488163, 0.06479996535927057, 0.018898101024595753, 0.06904797455562012, 0.0594934822459306, 0.058260638399847915, 0.035442472635103126, 0.009594288388533252, 0.06717051565647125, 0.11306036143962826, 0.12562214130801813, 0.09194085720394339, 0.23322996497154236, 0.10003770023052182, 0.13154941610991955, 0.12994938982384546, 0.12484182603657246, 0.12153913825750351, 1.543310420853751, 67.41746071406773, 57.90590143203735, 39.15850823266165, 53.04561219896589, 57.344056197575156, 74.55203083583287, 57.952714920043945, 0.40153807933841434, 0.8760026054722923, 4.198976193155561, 8.41784942150116, 86.2072309766497, 81.35466466631208, 87.27298041752407, 82.20838982718331, 76.57519340515137, 69.82196821485246, 64.84621729169572, 63.701459884643555, 62.00471673692976, 61.44121783120291, 60.92591857910156, 60.19924817766462, 58.817994935171946, 59.1795722416469, 57.15305716650826, 59.52106925419399, 57.86533784866333, 61.34011459350586, 55.50654949460711, 56.08820056915283, 57.53050068446568, 53.18870340074812, 53.86672946384975, 55.842866625104634, 55.178615365709575, 53.870821952819824, 51.62229456220354, 47.848425660814556, 47.65171521050589, 49.80558729171753, 50.73682655606951, 50.25452429907662, 55.180255140577046, 55.74213859013149, 48.1913366317749, 47.999941553388325, 47.17789670399257, 49.61724942071097, 52.719019072396414, 52.917261600494385, 51.45517648969378, 49.34200348172869, 50.02076257978167, 50.21797677448818, 48.85291978291103, 58.418605531964985, 62.56146894182478, 62.01534053257534, 60.39993299756731, 56.459463664463584, 60.42431422642299, 58.234870842524934, 61.97055244445801, 62.95582784925188, 65.23881135668073, 62.157813344682964, 61.74718870435442, 57.12495517730713, 45.88342646190098, 46.4791476385934, 55.04252447400774, 58.41519396645682, 58.715196337018696, 59.89399296896798, 53.59000008446829, 55.31344515936715, 57.15193850653512, 55.89788246154785, 53.083730016435894, 55.09711994443621, 48.151551246643066, 52.811416217258994, 53.262858050210134, 47.5295033454895, 46.27882065091814, 43.01803452627999, 41.588168212345664, 45.13424737112862, 58.8340174811227, 56.742522852761404, 56.942161968776155, 55.692382540021626, 57.85177149091448, 56.4304792540414, 58.683790479387554, 56.45118488584246, 52.83994552067348, 51.995506627219065, 53.86514180047171, 58.01905632019043, 58.11955506461007, 44.96244273866926, 44.52823938642229, 47.103523186274934, 45.62843452181135, 46.652803965977256, 50.33811807632446, 47.54637704576765, 45.34876952852522, 45.182537351335796, 52.27175310679844, 49.0301787512643, 48.804584639413015, 48.29665395191738, 46.8037223134722, 43.01836803981236, 42.85653754643032, 48.828003542763845, 50.20569930757795, 49.83588491167341, 47.98981802804129, 49.53618131365095, 54.19500405447823, 59.895472935267854, 58.2780191557748, 56.729762486049104, 55.86967624936785, 55.45288508278983, 53.69580030441284, 54.5141521862575, 52.83328914642334, 53.48309857504708, 55.10621166229248, 55.475293023245676, 53.47579949242728, 59.592934472220286, 57.53980432237898, 60.30531242915562, 64.4379550388881, 68.66631603240967, 67.41215923854283, 77.21443462371826, 69.79270935058594, 92.73782198769706, 18.64480131013053, 0.9775289233241762, 1.3084000774792262, 0.24013338025127137, 2.0500262592520033, 59.81832708631243, 78.59399945395333, 60.52004650660923, 58.58559158870152, 26.649562086377824, 72.81940024239677, 28.833703994750977, 0.4282413093107087, 0.23259971450482095, 0.11926827153989247, 0.27042329204933985, 0.1502361348164933, 0.10323943556951624, 0.08772426417895726, 0.16360773944428988, 0.11445604690483638], [0.03340989723801613, 0.022670085674950054, 0.051979755251003165, 0.08079675412071602, 0.03440452440242682, 0.012843741702714136, 0.019064542271995118, 0.07082252004849059, 0.18521070666611195, 2.3885963431426456, 55.55429751532418, 48.05257763181414, 29.953169958932058, 40.50306803839547, 46.522608620779856, 73.00928061349052, 35.19163921901158, 0.3637751356831619, 0.22827120391385897, 1.3888589143753052, 12.770423361233302, 82.04778221675328, 77.975998878479, 77.81170872279576, 72.12267657688686, 71.74736268179757, 67.2373356137957, 59.827067920139854, 56.3145728792463, 53.78585243225098, 54.1719777243478, 51.79698617117745, 51.69177654811314, 50.48984588895525, 50.27760968889509, 51.29355444226946, 50.84617730549404, 48.612244606018066, 48.399775641305105, 48.2181601524353, 48.66118424279349, 50.01462384632656, 49.91295780454363, 47.445760181971956, 48.148223059517996, 47.308592319488525, 47.7179628099714, 46.28422287532261, 42.5093013218471, 42.399099418095176, 44.39176286969866, 44.97930254255022, 46.96171045303345, 49.409651143210276, 48.792786598205566, 44.68601213182722, 46.36814669200352, 42.76604768208095, 44.57011617933001, 46.32188905988421, 44.898672172001426, 44.99433497020176, 44.09806598935808, 43.11028923307146, 43.615704672677175, 45.98035730634417, 50.77636875425066, 54.822443757738384, 55.35125378199986, 58.77595138549805, 47.65252467564174, 47.95317322867257, 52.655564648764475, 56.63044146129063, 58.1711801801409, 55.74334757668631, 54.85701104572841, 54.22637864521572, 53.624970367976594, 45.66916486195156, 43.34893206187657, 48.85644599369594, 49.984770911080496, 53.73419952392578, 58.02022361755371, 47.15091337476458, 54.34047154017857, 52.80353348595755, 49.65040275028774, 49.87614277430943, 52.6524692262922, 48.56536511012486, 46.88266774586269, 51.626036167144775, 48.16880362374442, 45.1875296320234, 40.877499512263704, 39.10300949641636, 33.367077010018484, 48.43577078410557, 55.489335332598, 56.00956085750035, 52.8277132170541, 52.98848063605172, 53.93811873027256, 49.21414620535714, 47.10577440261841, 48.3772600037711, 49.23252419063023, 56.10317741121565, 53.69993100847517, 51.15166527884347, 42.56006138665335, 41.77557155064174, 41.08481638772147, 40.54921102523804, 41.30136741910662, 44.972847666059224, 42.81726285389492, 42.34624794551304, 42.690242835453574, 44.533155236925396, 45.25696645464216, 43.02373552322388, 41.63193144117083, 41.764107022966655, 40.518913405282156, 34.243831975119456, 40.0439658164978, 45.233978339603965, 43.670859473092214, 44.30482700892857, 45.49093314579555, 44.54508529390608, 49.25103766577584, 49.51160206113543, 49.6206088747297, 47.598380838121685, 47.29211119243077, 44.169729709625244, 46.93072843551636, 46.31646946498326, 47.24498503548758, 46.334639004298616, 50.328824860709055, 50.170447622026714, 56.643226146698, 53.61386367252895, 60.14044557298933, 56.99376623971121, 62.40796933855329, 58.73341451372419, 73.89085415431431, 65.96769823346818, 80.58684703281948, 32.67829166139875, 0.22485137384917053, 0.1976620006774153, 0.008991646663551884, 0.16617505811154842, 40.911347661699565, 69.88187558310372, 48.87987879344395, 36.850431306021555, 17.783872604370117, 48.280812059129985, 28.24931185586112, 0.15489739898060048, 0.08019736342664276, 0.1301683530743633, 0.028044819233140776, 0.03469582287860768, 0.03641564791489925, 0.07143791738365378, 0.05828966612794569, 0.10307975592357771, 0.02601638120332999, 0.007398043559598071, 0.017440879218546406, 0.06470699249101536, 0.055268041124301295, 0.0511080107784697, 0.043602609408221076, 0.13209556894642965, 0.32297422790101593, 3.789431997707912, 62.53422505514962, 53.080721446446006, 29.792346954345703, 39.47589152199881, 54.54309490748814, 79.17295115334647, 38.675695283072336, 0.425170151250703, 0.131318564925875, 2.1962652121271407, 16.266634430204117, 84.61097962515694, 80.46555233001709, 81.25468703678676, 76.1752689906529, 75.2561126436506, 71.79042066846574, 62.2408721106393, 59.06967258453369, 57.21902336393084, 56.207191944122314, 53.75635385513306, 55.7857072693961, 53.834642682756694, 53.18200533730643, 54.24879353387015, 53.921641077314106, 52.35150105612618, 51.733347620282856, 52.46405145100185, 51.4390983581543, 52.06731973375593, 52.32287447793143, 50.086096491132466, 52.662957532065256, 51.872426237378804, 50.636390345437185, 47.050324303763254, 45.25805732182094, 45.138235637119834, 48.18412092753819, 48.18337747028896, 47.93857853753226, 51.89770378385271, 51.90354374476841, 45.60875374930245, 45.24210773195539, 43.169769287109375, 45.43255090713501, 47.575236388615195, 48.83662278311593, 47.993858405521934, 45.22306271961757, 44.321707657405305, 45.04107550212315, 48.49458033697945, 52.42278609957014, 56.07797976902553, 57.267334188733784, 62.09501552581787, 56.13147047587803, 50.06451538630894, 54.2296199798584, 59.03440352848598, 60.509346280779155, 58.641892841884065, 57.2750814301627, 57.74081570761544, 57.79189886365618, 49.75911773954119, 48.61668797901699, 50.72462551934378, 52.28015347889492, 57.64864785330636, 58.963128907339915, 48.435346943991526, 58.381773131234304, 54.228028842381065, 55.14152588163103, 52.38640880584717, 55.25041457584926, 49.56608288628714, 48.30429697036743, 51.635162625994, 48.382669176374165, 46.249144894736155, 42.523774419512065, 41.06392662865775, 38.97365140914917, 50.407679966517854, 58.66832378932408, 57.44998843329293, 54.11044795172555, 55.3213973726545, 53.904840333121165, 50.92627961294991, 50.02937487193516, 48.222329071589876, 52.38359131131853, 59.460918698992046, 55.23869643892561, 52.932439940316335, 44.96941525595528, 44.84200961249215, 43.66714218684605, 44.087226799556184, 43.56167548043387, 46.73463290078299, 45.74075910023281, 43.98483119692121, 44.5170110974993, 44.86700923102242, 46.85741104398455, 46.741765226636616, 45.35285159519741, 42.544612067086355, 42.33830615452358, 37.891354833330425, 44.23962163925171, 47.67981372560774, 47.92634275981358, 45.13484491620745, 48.304255281175884, 46.55098506382534, 51.70991134643555, 53.46136808395386, 52.184323923928396, 50.521300383976524, 51.232709067208425, 47.33832713535854, 48.420251982552664, 47.77849204199654, 50.68260281426566, 47.87888656343733, 53.805126735142295, 52.207082748413086, 59.30054037911551, 55.77489587238857, 62.78188664572579, 59.43324402400425, 66.39262921469552, 61.88612488337925, 75.65092318398612, 66.96264553070068, 81.29089409964425, 36.79899031775338, 0.2946268804371357, 0.12729717285505363, 0.07149982691875525, 0.19463314249047212, 43.61388771874564, 73.61736610957554, 56.50269883019583, 36.888118335178916, 22.51411066736494, 56.71641499655587, 37.407767159598215, 0.07824621562446867, 0.07262467513126986, 0.08932011068931647, 0.020768381023247327, 0.00859328723579113, 0.07010686237897192, 0.0232283961626568, 0.008286810779411877, 0.105341062082776, 0.12349250486918859, 0.1346709621804101, 0.12300978148622171, 0.25546696888548986, 0.11656778358987399, 0.1024045864386218, 0.1384367908218077, 0.26769018013562473, 0.48749044431107386, 4.040074799742017, 76.57045473371232, 59.429137638636995, 38.758271149226594, 52.10856076649257, 62.04612800053188, 84.66190992082868, 43.65867928096226, 0.7911609209009579, 0.7460137520517621, 2.593403833253043, 20.832775150026592, 85.55586515154157, 84.9967019217355, 83.46162251063755, 78.77135222298759, 77.76779610770089, 75.64354419708252, 65.50446878160749, 62.87306785583496, 59.75136729649135, 62.031356130327495, 57.185414927346365, 60.44283812386649, 58.12318549837385, 58.12536028453282, 59.12551525660923, 59.04704924992153, 55.879910945892334, 52.91657025473458, 56.274909087589805, 54.48451117106846, 55.64263343811035, 56.21813883100237, 51.95832681655884, 55.568075793130056, 55.08456802368164, 53.11930479322161, 51.000510692596436, 47.90349360874721, 49.04085465839931, 49.95011329650879, 52.534586088997976, 52.25484119142805, 55.803282737731934, 51.50992134639195, 45.90252358572823, 47.80378348486764, 43.28822912488665, 46.611128670828684, 50.67798226220267, 50.22631113869803, 50.51208707264492, 49.361079760960166, 47.70204448699951, 47.79220083781651, 49.77020011629377, 55.73980746950422, 58.40090152195522, 61.8292121887207, 63.05571515219552, 58.57270268031529, 55.348345960889546, 57.043716839381624, 60.46038927350725, 61.2145675931658, 61.83395780835833, 59.50382382529122, 61.04630306788853, 58.84286253792899, 55.24168416431972, 48.99161624908447, 52.868346282414024, 56.7884122303554, 59.2171550478254, 61.268867765154155, 49.84638016564505, 60.705744062151226, 58.17612729753767, 59.479449544634136, 55.07135949816023, 57.5003593989781, 50.45703649520874, 49.61955622264317, 53.361352239336284, 50.52660533360073, 46.7017297063555, 44.49624293191092, 42.71068096160889, 42.72866289956229, 56.73773554393223, 56.853760038103374, 61.2564582824707, 56.26268720626831, 56.46328864778791, 58.00448942184448, 51.455895628247944, 48.95788621902466, 52.78278963906424, 56.320134912218364, 61.034824643816265, 59.062446457999094, 55.987066064562114, 47.61473342350551, 46.73801319939749, 46.609019892556326, 46.59203502110073, 45.478124141693115, 49.9218237059457, 46.97095850535801, 44.64297498975481, 45.54640061514718, 47.223525524139404, 49.12730414526803, 47.82547576086861, 46.79953949792044, 47.947176933288574, 46.30393838882446, 40.98886176518032, 46.332151549203054, 50.12158441543579, 50.2735276222229, 48.54977682658604, 50.9250602040972, 49.31904663358416, 54.93829107284546, 56.51263475418091, 56.873173304966514, 53.747348989759175, 54.20851135253906, 49.74048614501953, 51.77707610811506, 51.49558373859951, 53.5404177393232, 52.10968637466431, 56.76301656450544, 55.0946672303336, 61.92763342176165, 58.77697277069092, 66.59621838160923, 62.942369188581196, 67.8475889478411, 63.63681384495327, 80.22638838631767, 72.0384088243757, 84.01284394945417, 37.733349323272705, 0.7248804260577474, 0.5280165182692664, 0.17221273056098393, 0.7685785155211176, 51.46486227852957, 80.77656759534563, 63.55151775905064, 50.32008750098092, 26.78214761189052, 62.964895248413086, 43.800644874572754, 0.2169782913156918, 0.1360870919057301, 0.30906675702759195, 0.0906294457880514, 0.1114347679540515, 0.16730042201067719, 0.16621530880885466, 0.11620383097657136, 0.29436073186142103], [0.04915464755945972, 0.058939485544604917, 0.030959890490131717, 0.018230173204626356, 0.01707973065120833, 0.13642022545848573, 0.04756125395319291, 0.10152936447411776, 0.15491373810384954, 4.275185772350856, 56.83220672607422, 35.31324659075056, 35.80570363998413, 39.151726790836875, 46.10171454293387, 73.24761077335903, 25.225579159600393, 0.8399043253489903, 0.9527686919484819, 0.9505492853266853, 10.807175976889473, 84.86679145268032, 75.34108911241803, 75.34247875213623, 77.93032836914062, 73.00557722364152, 74.09117766789028, 62.624544688633506, 53.174859115055625, 53.391889572143555, 51.618275029318674, 52.90997641427176, 52.88607461111886, 54.16720083781651, 52.92864622388567, 49.91262081691197, 48.56729323523385, 50.72370835712978, 49.764978545052664, 47.95659869057791, 47.09147153581892, 48.36935295377459, 49.38181665965489, 46.934035778045654, 47.87547847202846, 50.74385118484497, 48.9066675731114, 43.49551125935146, 42.54602255140032, 41.133471148354666, 45.29730074746268, 44.45785066059658, 45.37893860680716, 46.62398631232125, 49.821113041469026, 46.11338404246739, 46.27182381493704, 45.296268939971924, 44.173210757119314, 46.99557944706508, 44.71159192493984, 46.49157101767403, 44.30640425000872, 42.00142274584089, 43.105585302625386, 45.876554693494526, 45.23023326056344, 51.51190505708967, 54.18629796164376, 56.82645014354161, 55.4150903565543, 53.069514002118794, 52.59806135722569, 54.69422517504011, 56.92845664705549, 53.30540534428188, 54.33174807684762, 55.73629515511649, 56.548174789973665, 45.91959530966622, 43.575922761644634, 57.16129078183855, 47.360015937260215, 53.239088262830464, 52.704983711242676, 46.547080176217214, 55.68535096304757, 55.22823245184762, 49.709841115134104, 50.0892961365836, 45.450313976832796, 45.20092575890677, 43.474875109536306, 48.568717615945, 50.00192253930228, 44.499814305986675, 45.09559801646641, 38.11097696849278, 30.094892365591868, 49.57648433957781, 56.55586297171456, 49.95962538037981, 56.29148401532854, 55.8673277582441, 52.4266562461853, 50.80932058606829, 52.334929602486746, 48.40411131722586, 52.03674071175711, 54.356990882328574, 52.99604375021798, 45.79747029713222, 42.29441090992519, 41.449294567108154, 41.379176821027485, 41.01425743103027, 43.32396371023995, 42.19980076381138, 41.60573673248291, 39.838240078517366, 39.932558400290354, 41.73739467348371, 44.50781168256487, 43.33254126140049, 40.96640171323504, 39.45774630137852, 41.444809504917686, 35.90877321788243, 39.19292960848127, 45.33614117758614, 43.11765432357788, 44.129544803074424, 45.10102455956595, 45.85816281182425, 46.409818513052805, 47.06829234531948, 48.23357820510864, 47.24936587469918, 47.49121182305472, 45.4730658531189, 44.71058096204485, 47.54884713036673, 51.35349655151367, 51.487065247126985, 57.7710542678833, 56.2883677482605, 56.51767219815935, 54.1552221434457, 57.09081172943115, 56.52768802642822, 62.20532512664795, 64.13485377175468, 69.99599279676164, 65.53087193625313, 80.18550518580845, 51.317424978528706, 0.06660494314772741, 0.0778177682576435, 0.12358041586620466, 0.203076248722417, 28.762585708073207, 71.98250361851284, 48.73585305895124, 50.21831028802054, 23.20036166054862, 38.230597155434744, 45.36080033438546, 0.37967350972550257, 0.023830112535506487, 0.04807928490585514, 0.01991913846826979, 0.039628836925008466, 0.030079620225088935, 0.11897245741316251, 0.02440758145946477, 0.04984412056260875, 0.03658609591158373, 0.037045620182263, 0.03184009290167263, 0.08600442217929022, 0.015121605812704988, 0.080437008424529, 0.06810579475547586, 0.11486384645104408, 0.26500329002738, 6.5803388101713995, 66.5539663859776, 39.388170514787944, 38.240581716809956, 39.78419351577759, 54.800793170928955, 80.66475023542131, 27.432356561933243, 1.3345677533320017, 1.8609473194394792, 2.028634709971292, 12.32204828943525, 90.51113973345075, 78.40251404898507, 79.90591662270683, 79.65538542611259, 77.9138194492885, 74.92553125108991, 65.78200067792619, 56.66767685753958, 57.44656297138759, 52.89745576041085, 57.16224615914481, 55.402531487601145, 55.67678036008562, 56.85408312933785, 52.659004007067, 51.70600993292672, 53.730086190359934, 53.49831165586199, 50.29831532069615, 50.78890677860805, 51.65240805489676, 52.920426504952566, 49.67870971134731, 50.702839442661826, 52.65382412501744, 50.67710331508091, 46.241442816598074, 45.11092226845877, 45.13109983716692, 48.104574475969585, 47.34995494570051, 47.638485840388704, 50.55172654560634, 51.799588271549766, 46.30842692511422, 46.626400811331614, 44.27022845404488, 46.544860226767405, 47.25168309892927, 46.84228828975132, 49.792951992579866, 45.24079104832241, 44.335385186331614, 46.80276346206665, 46.66861459187099, 47.343972546713694, 54.090200901031494, 55.70518112182617, 58.97707394191197, 57.85465151923043, 56.907716274261475, 55.07872806276594, 57.37048714501517, 59.50895159585135, 54.08938448769705, 54.019475187574116, 58.27617788314819, 57.29054464612688, 49.26889106205532, 44.85761179242815, 57.51206016540527, 48.63094220842634, 55.478430134909495, 53.199240343911306, 46.1000018119812, 56.34703833716256, 55.836536816188264, 54.226871967315674, 50.99209989820208, 46.85882152829851, 45.5832017489842, 43.2423015322004, 50.41989837374006, 50.56619616917202, 45.64628096989223, 43.97332845415388, 39.848134313310894, 38.42412533078875, 50.504753249032156, 58.62975433894566, 52.44582980019705, 55.67694364275251, 56.68465478079659, 54.428001471928184, 54.99681574957711, 53.454280921391074, 51.11741065979004, 54.277989864349365, 56.093168531145366, 54.794421672821045, 45.69892052241734, 43.09010124206543, 44.134700366428916, 44.10568468911307, 42.317635263715474, 45.902749402182444, 42.89948436192104, 42.58298349380493, 41.635436807359966, 41.7080454826355, 42.520668574741904, 48.71141971860613, 46.395522594451904, 43.66404676437378, 42.37115376336234, 43.74785940987723, 39.29577684402466, 41.361021178109304, 47.4796986579895, 46.37533112934658, 45.68871014458792, 47.3928461756025, 47.373453753335134, 49.739238943372456, 48.86457191194807, 49.35162673677717, 48.98244462694441, 49.62217569351196, 47.4284348487854, 47.957460267203196, 48.92514978136335, 55.28640277045113, 54.88292782647269, 61.2794429234096, 59.1343047278268, 59.88742692129952, 57.402111870901926, 59.40362385341099, 59.481249128069194, 64.68266364506313, 65.4957835333688, 71.16135161263603, 68.3986644744873, 81.28557177952358, 53.199410574776785, 0.1406038145401648, 0.42120910808444023, 0.18463061350796903, 0.3424214757978916, 31.501989432743617, 73.79290539877755, 56.92793205806187, 48.89448390688215, 28.80400218282427, 49.7010794367109, 54.573257037571494, 1.151079073548317, 0.04953890194052032, 0.035333628832761727, 0.026678772177547216, 0.06791677525533096, 0.08734114295137779, 0.02181336566406701, 0.029890203781958138, 0.0777900501021317, 0.14250403828918934, 0.07518151043249027, 0.08333765063434839, 0.1713391574365752, 0.11691467783280782, 0.17324565084917204, 0.1677455681243113, 0.23919314784663065, 0.4272885375789234, 7.036301749093192, 79.82449068341936, 47.44074705668858, 45.75936985015869, 54.03252737862723, 61.61188643319266, 87.78921072823661, 30.886233125414165, 1.1941014506987162, 2.3569147288799286, 1.9673207657677787, 20.55630806514195, 92.81705924442836, 81.81676851000104, 83.49469593593052, 84.28415025983537, 78.67013781411308, 81.08975764683315, 68.23875863211495, 61.288315773010254, 59.87519114358084, 57.88383047921317, 59.13777187892369, 60.07837731497628, 59.353923388889854, 63.021439688546316, 56.74669872011457, 54.958291462489534, 57.01298148291451, 56.20734480449131, 52.6859039579119, 53.504961081913535, 53.743986061641145, 55.743893010275706, 52.893516131809776, 53.386608941214426, 55.32707405090332, 53.17911488669259, 48.050500120435444, 47.560957840510774, 47.455477237701416, 51.02292905535017, 49.526599747794016, 50.951890672956196, 52.47239623750959, 54.20767756870815, 46.56855705806187, 47.78194529669625, 45.757254123687744, 48.36244991847447, 49.260751247406006, 48.23255681991577, 51.58019890104021, 48.788204261234824, 47.098336356026785, 48.37732948575701, 51.090514183044434, 49.73015764781407, 55.79697377341134, 57.34926734651838, 63.36764757973807, 60.970338412693565, 60.293688092912944, 58.567324774605886, 60.74944823128836, 60.89355387006487, 59.81953607286726, 57.52555704116821, 61.397367749895366, 61.86027063642229, 55.53607586451939, 46.957840306418284, 53.298231329236714, 50.450581618717735, 56.40253012520926, 55.97165148598807, 47.82600382396153, 59.89595236097063, 60.27440684182303, 56.46329212188721, 53.868223326546804, 49.173599992479595, 46.510233879089355, 44.3863502229963, 50.305763789585654, 51.890168462480815, 46.09783744812012, 44.784572328839985, 44.13712876183646, 41.56717075620379, 52.50484432492937, 62.25385134560721, 55.91251189368111, 59.22019141060965, 58.093329089028494, 55.97304459980556, 56.7014867918832, 56.74395418167114, 52.89641353062221, 57.577369758060996, 60.70447949000767, 57.78758750643049, 48.73956339699881, 44.406416620527, 44.72509227480207, 47.64082390921456, 44.48020996366228, 46.30513000488281, 45.840767996651785, 45.51952150889805, 43.16284540721348, 42.835380281720845, 44.96490240097046, 49.28541040420532, 49.05845097133091, 45.2942852292742, 45.46246290206909, 47.71935592378889, 41.456909792763845, 43.36210584640503, 49.71403087888445, 47.464179856436594, 47.90124239240374, 49.59080457687378, 50.52801929201399, 52.283064774104524, 53.573605809892925, 52.36798218318394, 52.81942401613508, 52.33767761502947, 51.237510272434776, 50.48239047186715, 52.57251977920532, 57.318886348179404, 57.13159418106079, 63.58480657849993, 63.40730789729527, 61.97551345825195, 59.74706636156355, 62.45867729187012, 62.681638036455425, 67.88615145002092, 70.49640205928257, 75.80207429613385, 70.38976110730852, 83.20339965820312, 57.67868144171578, 0.20271277108362742, 0.5717012541634696, 0.38567963029657093, 0.625517874956131, 37.460312911442344, 82.97962597438267, 60.71364416394915, 65.56942054203579, 34.24275153023856, 51.87223168781826, 65.40289306640625, 1.1676027583224433, 0.14545342645474843, 0.19933814502188138, 0.08044188709131309, 0.17522230478269712, 0.07335604767182044, 0.22669537418654986, 0.12892067645277294, 0.14108128606208734], [0.0257197002481137, 0.08057724125683308, 0.05410344433039427, 0.020260333017046963, 0.013772830017842352, 0.09386822235371385, 0.07713415779705558, 0.24829064682126045, 0.33768926401223454, 11.335283364568438, 59.58252607073103, 32.765237944466726, 29.85152476174491, 33.97225815909249, 53.33641515459333, 78.2484655380249, 14.550155792917524, 0.5095411496503013, 0.6432373555643218, 1.7499624405588423, 10.364843232291085, 80.03520175388881, 75.69449533735002, 71.15156160082135, 75.60859475816999, 76.95066710880825, 73.17118753705705, 65.13524150848389, 55.487306458609446, 55.25969736916678, 52.68168292726789, 54.2974865095956, 53.85273926598685, 50.303536891937256, 51.61139283861433, 48.511766706194194, 51.14865323475429, 48.00281115940639, 46.7343931879316, 48.329115935734336, 47.45644998550415, 47.59016111918858, 48.23987327303205, 49.97386571339199, 48.52985634122576, 49.42680277143206, 48.41766030447823, 43.653846808842246, 43.39066989081246, 41.59127753121512, 43.74377039500645, 44.71632712227957, 46.62275995526995, 47.061059270586284, 46.89707483564104, 45.365591117313926, 46.517849104745046, 45.21894938605172, 43.91552986417498, 45.573060853140696, 43.8949875150408, 47.640632833753315, 48.00160217285156, 44.325122697012766, 42.580207688467844, 44.423408440181184, 44.538668632507324, 47.368009839739116, 51.87032788140433, 52.14131110055106, 55.90974303654262, 56.49541016987392, 52.66014003753662, 56.092445918491904, 52.179950032915386, 53.168352127075195, 50.81228746686663, 54.75423329217093, 53.64562736238752, 46.248988560267854, 48.929697377341135, 56.475149222782676, 51.314996583121165, 51.644264766148154, 48.17202411379133, 40.36610514777047, 41.78410741261074, 46.77003049850464, 46.17114094325474, 39.27461610521589, 39.10946089880807, 41.79314701897757, 42.84831782749721, 46.32388319287981, 57.92772919791085, 47.88678666523525, 50.75285605021885, 35.62868438448225, 41.69030325753348, 43.779046399252756, 46.76329769407, 51.74625389916556, 55.66958550044468, 55.500751222882954, 52.08049699238369, 53.3574994632176, 48.523335456848145, 52.75439582552229, 51.00929321561541, 52.753819125039236, 47.778478145599365, 41.45636435917446, 42.864329951150076, 41.00219188417707, 39.92672886167254, 43.877703871045796, 42.34078666142055, 40.04923949922834, 39.682395458221436, 39.823961530412944, 40.713740893772666, 39.736726897103445, 45.25215482711792, 45.78356695175171, 39.75350332260132, 41.56368276051113, 40.16418354851859, 38.39883041381836, 36.54566247122628, 44.02983120509556, 44.13875811440604, 44.665959630693706, 43.85273551940918, 45.13992404937744, 45.56641837528774, 45.85702330725533, 44.42634405408587, 45.697072301592144, 46.75146838596889, 46.06521218163626, 48.23426955086844, 51.757690634046284, 58.339472498212544, 55.61635882513863, 62.49357809339251, 54.959347588675364, 54.034882817949565, 56.75441469464983, 53.33618238994053, 53.57158041000366, 60.155259132385254, 57.829908984048025, 69.27620806012834, 69.02403708866665, 77.35058457510812, 58.161709785461426, 0.2837897805230958, 0.14722307292478426, 0.16161786764860153, 0.2972220868936607, 18.838970456804546, 71.45738656180245, 51.68574551173619, 47.37845645632063, 29.539126804896764, 23.076167821884155, 52.1405085836138, 1.4397653256143843, 0.20603466140372412, 0.10204363973545176, 0.046799656070236645, 0.08227311061429125, 0.0728719061506646, 0.05169638206384011, 0.13820402616901056, 0.03735985653474927, 0.02218908068191792, 0.020787342684343457, 0.005340006984105068, 0.014487341811348284, 0.01651309453882277, 0.11207583426897015, 0.06263260915875435, 0.30545032822660034, 0.4254427051969937, 16.15363413946969, 66.16781330108643, 42.85682242257254, 31.99572147641863, 37.320966788700645, 63.841354915073936, 83.59911346435547, 15.800123691558838, 0.9105290185127939, 1.0922072040183204, 4.008206018379756, 13.579342194965907, 83.39636502947126, 77.23136738368443, 75.04615892682756, 78.43690068381173, 80.57185282026018, 75.5559413092477, 68.77482604980469, 56.89250666754586, 59.06477410452706, 56.96556697572981, 57.67012126105172, 56.789103576115195, 53.79738644191197, 54.93636989593506, 52.66993352345058, 54.15093510491507, 50.18924944741385, 50.75911637714931, 50.860091073172434, 49.797506536756245, 51.36695868628365, 49.89380856922695, 52.41673769269671, 49.124757630484446, 52.245686939784456, 49.6292975970677, 46.991660663059776, 45.875370025634766, 43.95927572250366, 47.39808859143938, 46.47311312811715, 47.421851430620464, 48.8012147630964, 48.38826595033918, 45.376121112278526, 49.131136076790945, 46.828245980399, 46.37027631487165, 47.85418571744646, 46.3199713570731, 50.24425833565848, 51.310376031058176, 47.02436235972813, 44.8056948525565, 45.826614516122, 47.44393627984183, 49.95462267739432, 53.477786677224294, 53.87887144088745, 56.66319874354771, 58.480833598545615, 55.70545557567051, 57.14128344399588, 55.53005525044033, 53.76970134462629, 52.523910181862966, 56.36447136742728, 56.707444872174946, 51.70539501735142, 50.04530361720494, 55.86799478530884, 49.729299545288086, 54.47642346790859, 50.75703191757202, 42.57882847104754, 42.46001427514212, 46.023453508104595, 48.45881448473249, 41.33841173989432, 40.62853513445173, 43.341949122292654, 40.758709635053364, 45.38176652363369, 58.69222559247698, 48.8070581981114, 51.89035953794207, 39.18490096500942, 47.660063471112935, 47.996297223227366, 47.10949168886457, 53.493427072252544, 55.925546714237754, 55.74756165913173, 52.981567178453716, 57.044008663722444, 51.742161410195486, 53.78568567548479, 53.44498770577567, 55.57379068647112, 50.14506932667324, 44.86285768236433, 45.26944889341082, 42.68625456946236, 42.34219714573452, 44.76741027832031, 45.61051859174456, 41.33674417223249, 42.9224203654698, 38.12623521259853, 42.50270748138428, 41.57657514299665, 44.930279527391704, 49.156347615378245, 42.07331575666155, 44.46220370701381, 40.76720380783081, 40.66572536740984, 39.17908879688808, 45.76092277254377, 46.63843856539045, 47.24552699497768, 46.734730175563264, 47.268518584115164, 47.17631598881313, 48.84221955708095, 48.26425797598702, 48.319065366472515, 50.53612436567034, 49.14601216997419, 50.345656871795654, 54.43020057678223, 61.46279198782784, 57.964103017534526, 64.5534896850586, 58.4583283833095, 55.96690934044974, 57.586881841932026, 56.88758039474487, 56.07862247739519, 61.116188049316406, 60.559658186776296, 71.3959436416626, 70.96187577928815, 78.80673939841134, 60.16511862618582, 0.6106125233428819, 0.17589476012757846, 0.09977921910051789, 0.28759264360581127, 20.976463896887644, 76.3691098349435, 58.28858389173235, 52.175371170043945, 30.901053633008683, 32.364090647016255, 61.51827335357666, 4.593798458576202, 0.460412717291287, 0.18963373718517168, 0.052121728525630066, 0.08150920231959649, 0.08556310978851148, 0.03646157116496137, 0.04161442377205406, 0.045870544854551554, 0.0616841461243374, 0.19429022446274757, 0.12545637520296232, 0.15259685314127377, 0.1124329472492848, 0.1630473238016878, 0.13281207478472165, 0.44414671297584263, 0.5331693674836839, 16.561797380447388, 78.809615952628, 45.13605390276228, 38.2875828061785, 47.6103595324925, 69.11897032601493, 93.31451552254813, 19.348004170826503, 0.9014357264552797, 1.4751053835664476, 6.012883339609418, 24.902672052383423, 87.25714547293526, 80.40208748408726, 80.60028484889439, 80.37619154793876, 82.66174588884626, 77.19099140167236, 72.43536635807583, 61.4495278767177, 63.23255375453404, 60.34841905321394, 63.18317290714809, 59.776380811418804, 56.54221323558262, 58.225466455732075, 55.27499730246407, 59.022529057094026, 51.762474468776155, 53.01084688731602, 54.60836975915091, 53.4285170010158, 52.69534655979702, 51.8225451196943, 55.20804098674229, 53.68787240982056, 55.567867347172324, 53.188022477286204, 50.59421130589077, 51.00731645311628, 47.52108907699585, 49.46382277352469, 49.177897453308105, 51.707715715680806, 51.141083172389436, 49.56472798756191, 44.742518356868196, 49.86446285247803, 49.45685025623867, 45.17025293622698, 47.86143616267613, 47.68986429486956, 51.70044789995466, 52.902041571480886, 49.789495263780864, 47.70723131724766, 49.68399034227644, 50.27415643419538, 52.85577699116298, 56.02778250830514, 56.99535390308925, 59.444117954799104, 61.913952418736045, 58.74749156406948, 60.130829266139436, 58.344996316092356, 56.49217925752912, 55.932974338531494, 60.12422847747803, 62.386520249503, 51.045934540884836, 55.51364707946777, 57.37330116544451, 48.89533158711025, 57.52672781263079, 49.964430059705464, 42.782282148088726, 43.01359115328108, 47.541152000427246, 51.58149126597813, 46.15701525551932, 38.27976260866438, 44.97105155672346, 43.113662583487375, 47.99446289879935, 60.26265743800572, 50.865013871874126, 51.57012401308332, 45.56776632581438, 47.70531014033726, 52.70472315379551, 53.77947746004377, 54.96942942483084, 58.35652337755476, 58.27060890197754, 56.233320644923616, 57.748309339795796, 53.63908910751343, 57.45003359658377, 57.035479749952046, 57.08289425713675, 53.71418523788452, 47.06294223240444, 47.743945598602295, 45.872924259730745, 46.02899817058018, 46.207236834934776, 47.891653878348215, 44.374256883348735, 42.34112712315151, 40.17333780016218, 43.76590040751866, 41.87719242913382, 47.29498079844883, 52.05968713760376, 43.18496152332851, 46.353315762111116, 44.943682602473665, 43.095996788569856, 42.64527756827218, 48.59334897994995, 49.19244350705828, 50.549746309007915, 47.45851012638637, 50.692326818193706, 49.09676333836147, 51.788724763052805, 49.643392017909456, 51.99333878925869, 54.07425478526524, 51.92086212975638, 53.04524394444057, 57.07442787715367, 64.90258802686418, 60.24211161477225, 68.23476341792515, 59.41856248038155, 58.26820829936436, 61.18084103720528, 58.678363936288015, 59.534590448652, 64.71566064017159, 65.0320885522025, 74.5964298248291, 75.2432723726545, 82.88241372789655, 63.55964020320347, 1.0244312179940087, 0.4130982533097267, 0.2640285337609904, 0.6699321174195835, 25.874516589300974, 84.21021447862897, 62.72325774601528, 64.15140438079834, 41.481155531747, 33.42695311137608, 75.80934211186, 5.898192465305328, 0.5599807287965501, 0.30033791969929424, 0.1145092983330999, 0.1298457910971982, 0.23918459830539568, 0.13612055725284986, 0.1959196041737284, 0.1879039207207305], [0.028091400662170987, 0.08110184382115092, 0.03480430705738919, 0.06598815481577601, 0.04322791897824832, 0.06813898190323796, 0.04234930094597595, 0.25526430404611994, 0.2251697831920215, 21.178395918437413, 66.3676643371582, 20.81801196507045, 41.610558782305034, 48.65163046973092, 58.31678662981306, 76.7309650693621, 8.14765569141933, 0.689970993569919, 0.7011715439813477, 4.486384519508906, 7.757701073374067, 77.13293920244489, 72.27411951337541, 77.38213634490967, 74.07835824148995, 77.08261340005058, 73.06144768851144, 64.52731582096645, 53.5312773840768, 54.06676115308489, 52.31319216319493, 54.75436530794416, 50.91636105946132, 50.3160262789045, 47.460671016148154, 46.00841760635376, 49.25267744064331, 48.38729320253645, 47.739477906908306, 47.86482340948922, 47.18486227308001, 48.61955063683646, 48.38995436259678, 47.52090147563389, 46.37344816752842, 49.92688546861921, 47.71905715124947, 44.34450817108154, 42.318441254752024, 41.79993540900094, 42.963921955653596, 45.21777514048985, 44.8412765775408, 46.200601305280415, 46.48129463195801, 46.36687169756208, 46.3721592766898, 48.61811930792672, 44.917814459119526, 47.32259293964931, 45.21347073146275, 47.519379820142476, 48.989792346954346, 46.64884001868111, 44.05130461284092, 43.331797804151265, 42.69429016113281, 44.23646715709141, 45.87342800412859, 48.54215465273176, 50.32969338553292, 55.093781335013254, 52.19890471867153, 54.490389347076416, 50.18205458777291, 53.17848954881941, 45.522217409951345, 53.05287306649344, 52.475321429116384, 55.45603609085083, 49.67801489148821, 44.17848443984985, 55.15634291512625, 49.63303572790963, 47.64638941628592, 45.29184988566807, 44.84649467468262, 42.80934885569981, 44.05463627406529, 38.927709920065745, 38.962148666381836, 44.909066677093506, 41.2800920350211, 43.07552392142159, 51.882219723292756, 54.98004974637713, 49.28962101255144, 38.67047718593052, 50.60330302374703, 34.654494830540244, 45.20300327028547, 50.64276531764439, 50.82571138654436, 52.83794443947928, 54.29511717387608, 53.8406320299421, 50.97866555622646, 50.67067275728498, 50.56832579204014, 47.532122816358296, 45.08011048180716, 41.63534995487758, 40.734363147190635, 40.117456912994385, 42.304979119982036, 45.53160442624773, 41.90267147336687, 39.17809867858887, 39.27857310431344, 37.92100279671805, 40.7020331791469, 40.712299142565044, 45.984633922576904, 45.35276126861572, 40.86774771554129, 41.27591616766793, 38.676678453172954, 37.39853995186942, 37.12853295462472, 39.3182646887643, 46.49299192428589, 45.107041699545725, 44.77592529569353, 44.3866594178336, 45.16951642717634, 45.52067838396345, 46.11469725200108, 44.43006134033203, 47.489012718200684, 49.5861805507115, 52.382392747061594, 57.16343777520316, 58.657123293195454, 58.68611117771694, 58.652106693812776, 59.60884584699358, 59.98327037266323, 57.444197109767366, 54.96850184031895, 53.92331559317452, 54.758457796914236, 58.375728198460166, 68.7343944822039, 66.50411306108747, 76.2041665485927, 59.97839968545096, 0.4940434641071728, 0.13946141941206797, 0.2754440712077277, 0.10232591708855969, 15.400848933628627, 67.59470231192452, 53.816414083753315, 45.385306630815776, 38.78055402210781, 28.18606414113726, 52.353689738682334, 5.8991239581789285, 0.44600451471550123, 0.07834751411740269, 0.05442567043272512, 0.10145400637494666, 0.01218066964897194, 0.01685772756380694, 0.059248585387000015, 0.05749277424599443, 0.07635102660528251, 0.06127814469592912, 0.028726824958409582, 0.02680753607169858, 0.02013196436954396, 0.09688988128410918, 0.03173043824998396, 0.22296221022094997, 0.15557788818010262, 26.944445371627808, 72.62909603118896, 29.461258343287877, 41.3688622202192, 52.81827061516898, 66.17927782876151, 78.44589165278843, 8.835397941725594, 0.9132793652159827, 0.21936824092907564, 5.506603283541543, 12.68438902923039, 82.54799692971366, 73.97366278512138, 79.27931417737688, 76.36050796508789, 80.92999076843262, 74.22852965763637, 67.081682068961, 57.387214933122905, 57.991312163216726, 56.05811834335327, 57.501137597220286, 53.507201875959126, 52.996710777282715, 50.06497744151524, 50.31947258540562, 50.497798102242605, 50.295671531132285, 50.8850212097168, 51.411423683166504, 51.38516991479056, 50.24464743477957, 50.488511834825786, 51.97189664840698, 48.18236998149327, 53.431678431374685, 50.57580552782331, 48.49175589425223, 47.12899875640869, 44.151858942849294, 45.287281445094514, 48.41121585028512, 47.009840624673025, 49.7168344770159, 50.06073209217617, 46.45122977665493, 48.70473902566092, 48.56835630961827, 46.449263436453684, 46.71407665525164, 47.461511748177664, 46.769658769880024, 49.43302835736956, 48.922672748565674, 46.39526203700474, 45.50778947557722, 44.66645295279366, 46.08191565104893, 49.0911283493042, 51.53460482188633, 52.081702504839214, 55.644499029432026, 55.991738728114534, 55.44695479529244, 53.897027083805625, 54.267744745527, 49.05370535169329, 53.462806361062185, 53.93456820079258, 57.34667566844395, 52.30323886871338, 47.35497849328177, 56.13175882611956, 48.92936038970947, 48.78989267349243, 44.78376286370413, 45.61503839492798, 44.16343464170183, 47.6709999356951, 41.15116821016584, 37.07445165089199, 44.060173988342285, 39.64259965079171, 44.736258029937744, 53.49896131243025, 54.02174377441406, 50.16180058888027, 41.542730467660085, 51.25961249215262, 41.600911208561485, 47.44735826764788, 50.14219972065517, 52.2242864881243, 56.54404408591134, 57.30730022702898, 56.114443915230886, 53.86251885550362, 52.8848169871739, 52.356083393096924, 48.01034300667899, 47.17192472730364, 42.52541766847883, 43.138022967747276, 42.73630244391305, 45.96095446177891, 46.403301102774485, 44.629471165793284, 40.426300866263254, 41.389216967991416, 38.91552972793579, 40.55756275994437, 42.475102288382395, 46.09527703693935, 47.866150515420095, 43.19032553264073, 42.822112696511404, 41.5424143246242, 40.38871111188616, 38.62612336022513, 42.10797337123326, 46.47836249215262, 46.97334173747471, 47.07470900671822, 45.357350553785054, 48.111776283809114, 47.46601070676531, 46.53529255730765, 48.11388853618077, 49.80249881744385, 52.037654399871826, 54.94233839852469, 58.80109691619873, 61.72826875959124, 60.544643129621235, 62.08833135877337, 61.28587000710623, 61.8916973386492, 60.01281411307198, 59.146971293858115, 56.12286513192313, 56.71573059899466, 63.70390565054757, 70.76343522753034, 69.78829724448067, 79.3095041002546, 62.00146497998919, 0.6134287693670818, 0.3574078173509666, 0.21736192144453526, 0.1128966241542782, 17.20134779385158, 75.04093388148716, 61.051298822675435, 51.46858998707363, 37.70322888238089, 39.319011620112825, 63.71306337629046, 11.988848294530596, 0.6058866626449994, 0.07089545577764511, 0.06850277166813612, 0.028434188071904436, 0.05353510339877435, 0.06541301496326923, 0.009393023875808077, 0.041594498591231446, 0.16123469892357076, 0.13362430834344455, 0.1631522388862712, 0.25525084191134995, 0.09757545949625117, 0.16816444136202335, 0.15754417409854277, 0.36130980082920616, 0.3314194104501179, 29.580590179988317, 85.84254087720598, 30.08189923422677, 54.20293194907052, 65.74520301818848, 73.42483152662004, 89.17976760864258, 10.20624451977866, 1.0249400649751936, 2.4677853967462267, 5.649054816790989, 20.082885605948313, 87.52303913661412, 75.72964627402169, 84.86656216212681, 80.01643466949463, 83.53029155731201, 79.22512517656598, 72.28824520111084, 62.53594126020159, 60.56279182434082, 59.48292364392962, 63.17641230991909, 58.40381281716483, 55.87392854690552, 54.47992188589913, 53.88550002234322, 54.42942932673863, 53.49851662772042, 54.75631775174822, 54.38545765195574, 53.59603459494454, 55.31104455675398, 53.57381772994995, 54.103527545928955, 51.1228962625776, 56.020709242139546, 52.8815860748291, 50.99040106364659, 50.01578072139195, 48.84146220343453, 47.97540051596505, 51.26010581425258, 48.22458028793335, 52.14602892739432, 49.93898228236607, 46.72069134031023, 48.17636326381138, 49.681895460401265, 48.16585758754185, 49.46892622538975, 48.133843762534006, 51.46172864096505, 51.71190200533186, 50.94296223776681, 49.40110485894339, 49.315443992614746, 48.65647336414882, 48.997661181858604, 51.12895509174892, 53.852419648851665, 54.43631499154227, 60.66399928501674, 58.54542405264718, 61.75671468462263, 55.98067372185843, 56.799404280526296, 50.160278933388845, 57.99570689882551, 57.98677151543753, 60.730903489249094, 54.37829405920846, 49.49587133952549, 53.5680958884103, 51.50607899257115, 49.85335963112967, 46.02976942062378, 45.94352837971279, 44.39441360746111, 50.684145314352854, 42.252680029187886, 38.456632477896555, 46.30194772992815, 40.45855440412249, 45.3554675919669, 57.589633328574045, 57.661529813494, 52.913686752319336, 44.28642817905971, 53.962704930986675, 46.24719592503139, 46.64918742861067, 52.711191926683696, 55.567724909101216, 59.61900411333357, 58.094882011413574, 60.039613315037315, 55.58097859791347, 55.615591049194336, 54.134422710963655, 50.86779662540981, 49.63115276609148, 45.80106598990304, 43.98773206983294, 45.03155994415283, 48.621673311506, 49.175889423915315, 45.78669016701834, 41.574132851191926, 42.675196511404856, 40.48526675360543, 41.562855924878804, 43.443041937691824, 47.260938099452424, 50.207502365112305, 45.59658745356968, 46.23894493920462, 43.36576059886387, 42.90831552233015, 41.56458255222866, 45.38828393391201, 50.677172797066824, 49.30991322653634, 48.79935959407261, 48.51056119373867, 48.84399482182094, 50.2968179838998, 50.21411010197231, 49.17999580928257, 54.32348319462368, 56.24983303887503, 57.210748059409006, 62.28104659489223, 64.81274087088448, 62.9165427344186, 63.27237388065883, 63.4271172114781, 66.59860161372593, 63.56340612683977, 60.80133043016706, 58.8879702431815, 59.991371972220286, 66.37584236689976, 74.35233960832868, 72.17189761570522, 83.36798163822719, 65.63530336107526, 1.1568283821855272, 0.35543727023260935, 0.7074404475944382, 0.3514896620597158, 20.801433563232422, 81.07193551744733, 67.23849596296037, 61.22149494716099, 53.57482174464634, 39.876013960157124, 74.69587939126151, 13.621282390185765, 0.7558872508151191, 0.37429487119827953, 0.14168583362230233, 0.2459616975060531, 0.09697418247482606, 0.17071476951241493, 0.1180723128574235, 0.13526389322110585], [0.08223798964172602, 0.05109707957931927, 0.03463324159383774, 0.05765843178544726, 0.1287143203829016, 0.06212678165840251, 0.0376000613240259, 0.269688927169357, 0.15429874110434735, 26.337085962295532, 59.4101482118879, 29.593093463352748, 36.39199611118862, 47.46943269457136, 62.68547344207764, 72.30539335523332, 3.4305017377649034, 0.13023403526416846, 0.387607782546963, 3.319391357047217, 24.58600790160043, 75.34051241193498, 72.22445378984723, 76.44155870165143, 71.26695728302002, 73.5068689073835, 71.5122286932809, 64.06545516422817, 51.668955189841135, 52.758613382067, 51.276357650756836, 51.234922068459646, 49.47478008270264, 48.554077761513845, 45.45729691641671, 46.93037060328892, 47.25830125808716, 47.64406871795654, 47.238790716443745, 47.823540687561035, 47.59522983006069, 47.395594188145225, 47.76961919239589, 47.78241082600185, 48.45635134833199, 48.46869134902954, 48.665839535849436, 43.81266873223441, 41.607591901506694, 40.04691532679966, 42.492080211639404, 43.971660886492046, 43.37539080211094, 45.97692142214094, 49.971795150211875, 47.68318707602364, 48.43412406103951, 48.364506585257395, 48.79404769624983, 46.355931758880615, 48.21350138528006, 43.79547194072178, 45.27854061126709, 42.91831398010254, 45.7532901763916, 42.645635400499614, 44.616849763052805, 42.66933223179409, 43.36182791846139, 44.66482012612479, 46.31060171127319, 46.39453247615269, 50.85510574068342, 49.49974148614066, 51.20785188674927, 48.71065541676113, 48.9862904548645, 49.10812711715698, 51.09459277561733, 51.54490205219814, 55.56812443052019, 45.49106168746948, 51.519023486546104, 50.5359992980957, 43.894577571323936, 39.718109198978965, 41.46651915141514, 43.488045419965474, 39.91891213825771, 41.178717817579, 38.66237906047276, 42.13479341779436, 40.0123028755188, 45.13935429709298, 45.22325379507882, 39.24803924560547, 35.99519143785749, 47.24178886413574, 40.400943415505544, 40.316418579646516, 44.0822970526559, 50.16918999808175, 54.45457485743931, 53.68827540533883, 53.96289253234863, 51.12105846405029, 50.975281783512656, 47.75543097087315, 45.572015149252756, 45.147567067827495, 42.84658077784947, 41.68373026166643, 41.73524420601981, 42.50536516734532, 42.60162551062447, 40.94970519202096, 40.26794794627598, 40.03562797818865, 39.03714057377407, 38.92602150780814, 41.217318534851074, 41.37074170793806, 48.27463163648333, 42.22893803460257, 41.67351988383702, 41.1712589263916, 40.09996829714094, 39.226357391902376, 37.28407532828194, 39.3133453641619, 45.2846029145377, 42.427611351013184, 45.262733459472656, 45.29716873168945, 44.60792132786342, 45.33332020895821, 47.50167581013271, 44.67116730553763, 45.66780996322632, 49.72088180269514, 55.44249752589634, 56.223766871861045, 61.340017318725586, 58.796879359654014, 60.10174410683768, 56.92995745795113, 58.36235291617257, 54.33410004207066, 55.37328651973179, 51.67355489730835, 59.16799654279436, 65.30664661952427, 69.31234564099992, 67.95590441567558, 76.60511929648263, 48.572521754673545, 0.24991313261645182, 0.21567407915634768, 0.2575033881834575, 0.06223065179905721, 10.017957891736712, 65.29213878086635, 58.71331337520054, 45.38863481794085, 48.012392725263325, 19.45555533681597, 56.05669048854283, 16.38763209751674, 0.9657035235847745, 0.1638002126876797, 0.05311747866549662, 0.05206720484420657, 0.042360333925379176, 0.020237281486125927, 0.1015390810955848, 0.028531454370490143, 0.02711387936558042, 0.06035453639924526, 0.02938410486759884, 0.05436531135014125, 0.11137230880558491, 0.07648804996694837, 0.007832266955769487, 0.17167131389890397, 0.17103127895721368, 33.80170767647879, 63.984647614615305, 34.709333487919395, 34.963178975241526, 54.7222055707659, 67.53063297271729, 78.61517061505998, 3.3115692053522383, 0.11146196363759892, 0.423431608825922, 6.895162122590201, 36.72487735748291, 77.2313117980957, 73.34622655596051, 79.9658031463623, 74.02840764181954, 75.15127127511161, 73.7851790019444, 65.45902061462402, 54.73297527858189, 55.50586857114519, 54.27186502729143, 54.85413449151175, 52.445506708962576, 50.29796096256801, 49.00017990384783, 49.313248361860005, 49.59535217285156, 48.851335593632285, 48.423107692173545, 50.48189714976719, 51.33529921940395, 50.26681218828474, 49.39739452089582, 48.56945412499564, 50.82470737184797, 49.973879609789165, 51.45150784083775, 46.16910164696829, 44.88506759916033, 43.67758532932827, 45.98949418749128, 47.566585881369456, 47.27780485153198, 51.0272855758667, 52.32682800292969, 46.528782095227925, 47.984606879098074, 50.38955906459263, 50.558049406324116, 47.59196070262364, 48.009568282536094, 44.6272303717477, 46.89527872630528, 45.19274425506592, 47.27142987932478, 44.55665751865932, 47.51472800118582, 44.21946144104004, 46.30392796652657, 46.34315054757254, 46.668367930821006, 47.55053554262434, 50.57591322490147, 50.3327818598066, 51.96195725032261, 52.27849980763027, 50.181321552821565, 52.270811625889365, 54.32307325090681, 55.46155643463135, 56.70616292953491, 49.72893476486206, 52.5191193989345, 50.164232458387104, 45.36143956865583, 38.94063356944493, 41.403933252607075, 43.04497616631644, 42.231265681130544, 42.311437470572336, 40.28602368491036, 42.65790939331055, 41.39735678264073, 45.74940960747855, 45.844311577933176, 43.784309659685405, 38.63690001623971, 47.58131258828299, 42.12007713317871, 45.7048716545105, 46.14615522112165, 52.14033487864903, 55.73120559964861, 55.481397015707834, 55.6771034513201, 54.924557958330425, 52.86308997017996, 49.19387136186872, 48.60600164958409, 45.15602649961199, 44.941368852342876, 43.43385641915457, 42.92604385103498, 44.21070671081543, 44.08791814531599, 42.992479051862446, 41.26522289003645, 41.81208780833653, 41.134447370256694, 39.92110429491316, 43.259432315826416, 41.136841024671284, 49.33178962979998, 45.70418725694929, 44.375868865421836, 44.656312056950156, 43.317560945238384, 41.2771703175136, 38.63997112001692, 41.59017971583775, 47.03797040666853, 44.185894693647114, 46.09749698638916, 46.72185516357422, 47.700039931706016, 46.86066974912371, 49.30261066981724, 46.687944480351035, 48.49160998208182, 52.12958948952811, 59.06784520830427, 59.58763299669538, 62.77033873966762, 60.94016933441162, 61.490091460091726, 59.173006193978445, 59.49191461290632, 57.26913724626814, 58.42991719927107, 53.852874755859375, 63.00169290815081, 67.36566189357212, 71.44692952292306, 71.973922593253, 78.07259968348912, 50.377479621342246, 0.2254593547965799, 0.32776099390217234, 0.13409261964261532, 0.05339765256004674, 8.696116958345685, 68.90136664254325, 66.64395250592912, 53.444268567221506, 45.01687840053013, 24.21144093785967, 65.35415145329067, 24.15581887108939, 0.788628736776965, 0.10701888240873814, 0.01847351961103933, 0.025018858390727212, 0.0211330189569188, 0.015441077062860131, 0.06503632624766656, 0.02735560237696128, 0.11930291753794466, 0.1781486498990229, 0.09269501495042018, 0.11805062687822751, 0.2663762649255139, 0.19883427848773344, 0.2155886108853987, 0.33962745858090265, 0.31115061949406353, 37.172393458230154, 76.73781599317277, 38.573400429316926, 45.66388423102242, 67.63289655957902, 73.63197817121232, 87.0567455291748, 5.045569462435586, 0.3505835463958127, 1.4389365358012063, 9.17474101270948, 41.85232482637678, 81.05027798243931, 76.1698077065604, 83.7067619051252, 81.32693440573556, 77.37495190756661, 77.75803388868059, 68.74740150996617, 58.40464660099575, 57.891556876046316, 58.06841632298061, 57.5686080796378, 56.753594807216096, 54.1394636290414, 51.290281840733115, 52.56541872024536, 54.16023874282837, 52.12928376879011, 52.169083050319124, 53.564045088631765, 55.5663526398795, 52.85747582571847, 53.99828665597098, 51.73141949517386, 53.601527145930696, 53.24910756519863, 54.98024777003697, 49.206788063049316, 48.467947891780305, 44.54123946598598, 49.05436890465872, 49.90868466241019, 48.22512572152274, 53.11822782244001, 54.62058121817452, 47.52838468551636, 48.06705072947911, 52.119184562138145, 51.1056021962847, 48.81720951625279, 50.683648518153596, 45.79258223942348, 48.34375579016549, 45.91735798971993, 50.73031261989048, 45.94859709058489, 49.412326199667795, 46.71019261223929, 49.19462871551514, 49.946163245609824, 50.023298672267366, 50.69466488701956, 53.93211896078927, 54.85701451982771, 55.09447962897164, 55.75232464926583, 53.519444601876394, 54.66147831508091, 57.36308036531721, 59.07316058022635, 59.160548073904856, 53.45105695724487, 52.60936260223389, 51.26099518367222, 46.26107842581612, 40.0411240032741, 42.45407009124756, 44.97194440024239, 42.9677643094744, 43.35207264763968, 40.43957192557198, 43.37946244648525, 39.40756293705532, 44.82734196526663, 47.13211154937744, 44.70044354030064, 44.00289651325771, 53.814558914729524, 47.23909296308245, 45.59480176653181, 49.59450101852417, 54.57722445896694, 58.9338561466762, 58.44473770686558, 59.59708949497768, 54.799156870160786, 54.094008513859336, 52.12782464708601, 51.551329135894775, 48.68723998750959, 47.40106242043631, 45.35787514277867, 46.46088777269636, 47.78631223951067, 45.75246681485857, 44.84562267575945, 43.37628364562988, 42.87961251395089, 41.96816866738455, 41.81003114155361, 43.59848356246948, 41.46054022652762, 51.134284360068186, 48.41259159360613, 45.67515768323626, 46.14731904438564, 45.82755252293178, 46.12589774812971, 42.43685940333775, 45.254524162837434, 49.872512340545654, 46.531721183231895, 49.209622928074424, 48.95396048682076, 50.1311798776899, 49.32541465759277, 52.316190310886924, 49.25096123559134, 51.184002195085796, 55.64603110722133, 62.77331256866455, 61.11796678815569, 66.42850971221924, 64.44650132315499, 64.4010670525687, 62.05541774204799, 63.56370489937918, 60.73624665396554, 62.362514223371235, 56.92575032370431, 65.0297817502703, 69.09212248665946, 75.99140575953892, 73.69302504403251, 81.33869770595005, 54.55114786965506, 0.4479158121560301, 0.6787714745317186, 0.39527682960033417, 0.29006082830684526, 14.222483958516802, 78.08018016815186, 72.56186526162284, 61.4021064213344, 63.13564722878592, 27.255222661154612, 74.9976396560669, 27.294308015278407, 1.0222445981843131, 0.41382637566753794, 0.1660531796514988, 0.11834877516542162, 0.14709767965333803, 0.16970494655626162, 0.17158535708274159, 0.11130264361522027], [0.03424228328679289, 0.13985837596867765, 0.04283091153151222, 0.004793193848204932, 0.15416027924844197, 0.055861386071358404, 0.15466002028967651, 0.2280724202947957, 0.12966477152492317, 32.68968670708792, 48.70003162111555, 32.373248372759136, 45.80411624908447, 42.87934153420584, 65.47270856584821, 67.38588809967041, 1.9734423458576202, 0.01376514051974352, 0.30358720677239553, 7.0962768622807095, 53.28630127225603, 70.91947787148612, 78.06547083173479, 75.20267404828752, 71.72002846854073, 71.17645699637276, 72.01375661577497, 60.389079911368235, 52.857458455221995, 52.47383451461792, 50.12273781640189, 50.63240555354527, 49.377210003989084, 47.811228479657856, 48.25189018249512, 46.65128925868443, 46.83080639157976, 45.20735284260341, 46.62152665002005, 46.449881826128276, 47.92929574421474, 45.1112106187003, 44.18677364076887, 46.54261943272182, 47.362607615334646, 47.604759284428184, 48.998623507363455, 44.30184275763375, 41.71217966079712, 40.75096239362444, 41.7875919342041, 46.116409982953755, 46.635652337755474, 45.02121407645089, 50.03853259767805, 45.34105355398995, 43.91465091705322, 44.91941254479544, 51.6405405317034, 46.82987185886928, 42.32654980250767, 41.31607675552368, 43.303619384765625, 44.481790678841726, 44.468481404440745, 45.03694479806082, 41.614821502140586, 41.26017849785941, 41.97116681507656, 43.57385567256382, 44.317583901541575, 46.18258115223476, 44.048890113830566, 44.04512071609497, 46.20033727373396, 46.9813460622515, 48.830379826681956, 47.09305225099836, 51.35660239628383, 50.38438613074166, 54.22924130303519, 50.255163533346995, 42.41195705958775, 48.12142038345337, 38.82072850636074, 36.192864213671, 37.26100383486067, 43.7969970703125, 41.151769229343955, 39.79780156271798, 41.58835581370762, 41.600886889866416, 48.32064608165196, 44.457513672964915, 47.31571422304426, 45.56656081335885, 32.83084283556257, 36.52243116923741, 40.90616430555071, 47.49134036472866, 49.531991549900596, 50.57307835987636, 52.239204270499094, 49.87558691842215, 49.74571813855852, 49.371790409088135, 47.088542870112825, 45.45158897127424, 44.45685011999947, 41.49074057170323, 38.91624886648995, 39.88618264879499, 39.67124359948294, 41.150747844151084, 39.57199553080967, 40.56251335144043, 37.327254908425466, 38.450618812016074, 42.911768777029856, 41.46281576156616, 43.676827975681846, 41.76008749008179, 46.274491923195974, 44.573861258370535, 41.7271842956543, 41.07335533414568, 41.07165649959019, 38.609520639692036, 36.9849762235369, 39.91741827556065, 44.96560069492885, 45.289213044302805, 46.02738618850708, 45.889311586107524, 43.81370053972517, 44.99693012237549, 46.37567506517683, 44.67591987337385, 43.77003805977957, 50.673545837402344, 53.29599748338972, 54.91208246776036, 57.49746894836426, 56.98720714024135, 56.48692641939436, 57.517799377441406, 55.764591693878174, 55.14253684452602, 55.433433600834434, 57.447327273232595, 64.72323417663574, 66.88989789145333, 70.03226934160504, 66.97895990099225, 72.75660242353166, 44.143548897334504, 0.35737087790455135, 0.24363291103925022, 0.13222392063055718, 0.19362432376614638, 2.160170840365546, 45.85955245154244, 65.25332614353725, 45.80262238638741, 40.81956890651158, 31.596213953835623, 49.393187386649, 26.71888600076948, 0.22961573462401116, 0.05498568234699113, 0.0561082405038178, 0.019067348014297228, 0.09446276830775396, 0.017846100331683244, 0.040406980884394476, 0.06452409337673869, 0.006827101718434798, 0.026902300272403017, 0.017694010099928294, 0.0756012929071273, 0.07563293978039708, 0.07898033623184476, 0.07057955701436315, 0.10050198103168181, 0.12261908102248396, 41.09150055476597, 56.67748771395002, 37.168509415217805, 40.75417593547276, 50.91340112686157, 70.50771372658866, 73.94604369572231, 2.3050312272139957, 0.1355896307421582, 0.283405919692346, 9.536042128290449, 59.73952061789376, 71.57879243578229, 80.19403757367814, 76.917954989842, 76.25767462594169, 72.6575072152274, 73.79676164899553, 61.62505326952253, 55.19776112692696, 55.73134108952114, 53.77824068069458, 53.378931181771414, 53.18589980261666, 50.8235296521868, 52.1901604107448, 49.74848352159773, 51.1428792817252, 47.90540436335972, 51.06180075236729, 49.920319420950754, 51.167562757219585, 48.98344169344221, 48.23370674678257, 49.28340237481253, 47.95749153409685, 48.97900874274117, 51.888702392578125, 45.85153423036848, 44.117534841809956, 44.32244764055525, 44.52779470171247, 48.260196753910606, 48.85294757570539, 48.6088365146092, 51.30556092943464, 46.355125767844065, 44.79725973946707, 45.37663180487496, 54.14359780720302, 51.43205288478306, 43.47627517155239, 42.32551104681832, 44.66523354394095, 45.29266282490322, 44.342038086482454, 47.73903669629778, 43.27801179885864, 43.10548455374581, 44.52971935272217, 45.26558569499424, 46.40760898590088, 46.54735810416085, 47.13762147086007, 47.52977779933384, 47.6332607950483, 48.7135979788644, 50.761423179081504, 50.55107341493879, 54.38009016854422, 52.16830832617623, 56.30167007446289, 53.24285766056606, 48.31152657100132, 47.01617738178798, 39.448182106018066, 38.20744228363037, 37.96122244426182, 44.413350922720774, 42.54287154333932, 41.08660207475935, 42.72178070885794, 41.72937992640904, 46.47439159665789, 44.07487637656075, 48.334483419145855, 46.48526552745274, 38.42206866400582, 43.21693365914481, 44.853515829358784, 50.26449496405465, 51.134642192295615, 53.08284412111555, 54.42381518227713, 52.04170867374965, 52.589365686689106, 50.8186867577689, 47.47526570728847, 48.08898271833147, 45.78644003186907, 42.451544421059744, 42.05695969717843, 39.835221086229595, 42.35173354830061, 42.855512687138145, 39.24022947038923, 42.411130223955425, 38.23149694715227, 37.946863991873606, 44.09514774594988, 43.23901850836617, 43.4180840083531, 42.931310585566926, 46.78184938430786, 48.579650606427876, 44.15113633019583, 44.81178147452218, 43.30582891191755, 41.25107635770525, 38.442541531154085, 42.66204357147217, 46.85995755876814, 48.50067738124302, 48.03126750673567, 47.236407484327046, 45.71503339494978, 48.8943692616054, 47.83854532241821, 45.80630145754133, 46.474078927721294, 52.42060783931187, 55.88765818732125, 58.463136536734446, 59.80323559897286, 60.32736601148333, 59.60428088051932, 59.700027057102744, 58.52670560564314, 58.036082880837576, 58.21879965918404, 60.19951915740967, 65.4731810433524, 70.06640584128243, 71.73039518083844, 69.21548775264195, 74.0852439062936, 48.345367772238596, 0.4193666955190045, 0.22651575239641325, 0.1825112500893218, 0.4262639225593635, 2.091382588659014, 48.49313858577183, 72.66109248570034, 55.41247088568551, 40.300889355795725, 29.432694298880442, 59.426094327654155, 35.156272888183594, 0.08455143443175725, 0.04688583341028009, 0.04525311191433242, 0.007791252906567284, 0.04075254859136684, 0.06995119966034379, 0.057002946601382325, 0.07078769763133355, 0.13923782855272293, 0.2975263148546219, 0.14629307282822474, 0.18141267475272926, 0.27679755858012606, 0.16707700757043703, 0.27013670599886347, 0.36148225728954586, 0.305073795574052, 49.035977022988455, 63.30482196807861, 45.260100092206685, 61.18717084612165, 59.35840497698103, 77.35331521715436, 81.32892159053257, 2.9792852870055606, 0.2733995094895363, 0.8183592643056596, 16.189368724822998, 71.29108837672642, 72.14056124005998, 84.86312975202287, 81.00298159463065, 82.64974634987968, 74.40798773084367, 79.00814683096749, 64.75780841282436, 61.01390361785889, 59.05881255013602, 58.10384518759591, 57.29395273753575, 57.619593960898264, 54.406198024749756, 54.62986053739275, 53.72275584084647, 54.60545151574271, 48.596770967756, 54.91548013687134, 52.66189098358154, 55.10596152714321, 50.31523765836443, 49.90987280436924, 51.184405190604075, 51.362487520490376, 52.745595932006836, 55.38175984791347, 49.160249028887065, 47.73331485475813, 46.7091121673584, 47.16153022221157, 51.071083545684814, 52.34958682741438, 50.710677010672434, 55.045126574380056, 46.196508816310335, 44.8342866897583, 46.13990879058838, 56.03375448499407, 51.347357818058555, 44.85974488939558, 43.509953090122764, 46.38727160862514, 46.28986133847918, 47.986031259809224, 50.16581664766584, 45.256052766527446, 46.69205086571829, 47.4137533051627, 47.2305223601205, 50.26641614096505, 49.108960900987896, 49.84836735044207, 49.665789536067415, 50.88375663757324, 52.082081181662424, 53.61957161767142, 51.6506154196603, 58.11852673121861, 54.50029400416783, 59.97903891972133, 56.133746010916575, 48.71191304070609, 48.5301307950701, 41.56674691608974, 37.10105630329677, 36.79261881964547, 45.786255904606406, 44.378835746220176, 40.6980379649571, 45.440246037074495, 42.3365204674857, 47.17901536396572, 45.98531484603882, 49.22705595833914, 45.51902123859951, 40.748297759464805, 45.48556913648333, 50.103515625, 53.14604146139962, 52.97100939069475, 55.75179311207363, 57.09489032200405, 53.6297333581107, 54.12305545806885, 54.26733480181013, 50.81137030465262, 50.265307903289795, 48.308174065181184, 48.41313355309622, 43.72483307974679, 42.26990113939558, 44.250943728855674, 44.63243109839303, 42.2658121245248, 44.61007874352591, 39.407833916800364, 39.86880867821829, 44.94401611600603, 43.937830107552664, 45.35891737256731, 42.47995907919747, 48.80384465626308, 51.3685359273638, 46.77235467093331, 47.617717674800325, 45.4211871283395, 44.14279849188668, 41.11736869812012, 44.860787119184224, 49.44408294132778, 51.19349690846035, 52.482036863054546, 51.25085081372942, 49.86887843268258, 51.49155725751604, 51.178530488695415, 49.99312959398542, 49.10043198721749, 56.44809988566807, 58.203169686453684, 60.07039383479527, 64.42921420506069, 62.505341393607004, 61.828885623386924, 64.10948589869908, 62.59212439400809, 60.59706033979143, 61.35736002240862, 63.36388165610177, 69.10256562914167, 72.73649433680943, 73.53945595877511, 73.14896024976457, 76.39867441994804, 49.558172362191335, 0.678134520139013, 1.0651908708470208, 0.4357587444995131, 1.1050573544842857, 5.0853939311844965, 57.74518265042986, 78.74861076899937, 60.46428721291678, 55.25888442993164, 43.22135966164725, 67.8175379889352, 39.22090653010777, 0.308477055813585, 0.1342061792633363, 0.1360046091888632, 0.10334859828331641, 0.19619758640016827, 0.1580308194139174, 0.11526718123682908, 0.14777261843638761], [0.02751626250600176, 0.09664607008120843, 0.10633877997419663, 0.06825863476842642, 0.11334794493658201, 0.03608051946918879, 0.12153113154428345, 0.023917009122669697, 0.10256178943174225, 37.04604394095284, 47.36353519984654, 30.17905936922346, 42.55271366664341, 47.221896171569824, 66.52150440216064, 61.749294008527485, 1.3174702993461063, 0.1560067901653903, 0.1611384419458253, 1.0405453933136803, 23.672740152903966, 79.61570426395961, 68.26796885899135, 73.45709896087646, 70.0575955254691, 72.31674671173096, 65.73668452671596, 59.605135508946006, 50.72937461308071, 54.15427371433803, 49.43620021002633, 50.173706327165874, 46.727382455553325, 49.42740726470947, 46.98885359082903, 50.24146168572562, 49.03280169623238, 50.01606559753418, 45.83557769230434, 47.81761734826224, 48.150022642953054, 45.84785863331386, 45.22224630628313, 48.12814276559012, 47.93091467448643, 47.48358964920044, 47.634699072156636, 45.27433695111956, 42.02003002166748, 40.12912293842861, 44.54720796857561, 43.31831135068621, 45.30933502742222, 46.34121200016567, 47.8815963608878, 45.56888151168823, 44.741076605660574, 45.33085707255772, 48.01250042234148, 49.325911453792024, 45.530586515154155, 46.12155859810965, 44.52835055759975, 45.696012701307026, 48.98531770706177, 50.07475355693272, 44.90783337184361, 44.07705116271973, 45.88386419841221, 43.99291542598179, 43.85448299135481, 43.70905024664742, 43.6262902532305, 43.665596212659565, 44.1262583051409, 43.142407281058176, 46.08448995862688, 47.51666307449341, 50.12179633549282, 52.53010450090681, 52.79752329417637, 52.651652812957764, 43.71248265675136, 44.229432106018066, 42.644513266427175, 41.84597764696394, 42.446468761989046, 38.30093029567173, 40.82237597874233, 43.77303620747158, 40.590875898088726, 42.318177223205566, 44.24082367760794, 46.46228436061314, 41.46826662336077, 46.15835625784737, 39.460063525608604, 44.13830648149763, 42.20395578656878, 46.34121547426496, 48.72546202795846, 50.002075399671284, 48.89202424458095, 50.00302382877895, 47.60999475206648, 47.98018087659563, 45.16016067777361, 42.67353241784232, 40.56721033368792, 38.80588368007115, 38.102587018694194, 40.20286417007446, 42.12859215055193, 42.32944025312151, 37.636765888759065, 39.39070313317435, 37.1884959084647, 39.613347734723774, 41.26857539585659, 44.10450349535261, 43.40583086013794, 43.446217264447895, 44.566048009055, 43.999161856515066, 38.37985140936715, 41.932180472782676, 39.775581223624094, 38.214202880859375, 37.91286645616804, 41.6978246825082, 43.66967133113316, 46.185662678309846, 44.19676167624337, 46.19906575339181, 42.823075022016255, 45.22475113187517, 44.03152309145246, 43.796211923871724, 44.64638655526297, 46.4656194959368, 49.89658090046474, 53.95619446890694, 54.96801546641758, 56.576061385018484, 56.614127090999055, 55.57693474633353, 56.14112152372088, 57.272239616939, 53.95260572433472, 57.57502474103655, 62.547190393720356, 67.65287957872663, 69.92252949305943, 70.83557837350028, 68.95272772652763, 47.32027571541922, 0.8456531997237886, 0.17786377375679358, 0.13832937872835568, 0.12013462505170278, 0.9522399774619511, 31.320349625178746, 73.64553410666329, 44.03727272578648, 45.36606012071882, 29.575226170676096, 39.16214908872332, 38.93818780354091, 0.1959733712886061, 0.0884230195411614, 0.0366863664239645, 0.0679810189508966, 0.042746318570737324, 0.03135859088173934, 0.03679900662973523, 0.02378366850981755, 0.0400284872656422, 0.03353834391704627, 0.172082872529115, 0.025787567320678915, 0.016041329496407082, 0.04296985514728086, 0.04124340421653219, 0.011274546351549881, 0.026768545753189495, 45.61026150839669, 54.7156742640904, 30.920699664524623, 38.000243527548655, 56.15645619801113, 69.3849265234811, 67.81365394592285, 1.1928781334842955, 0.16416504739650659, 0.2465609253517219, 1.3529461728675025, 26.34269663265773, 81.95635087149483, 68.25576782226562, 75.36125973292759, 71.32091004507882, 76.35709639957973, 66.07611097608293, 62.05889878954206, 56.08618211746216, 57.03423602240426, 53.68836225782122, 53.593303952898296, 50.99995483670916, 52.32611928667341, 50.5880343573434, 52.77849217823574, 50.48909548350743, 51.202317646571565, 49.81028774806431, 50.53328602654593, 49.819303035736084, 48.17975745882307, 49.48508426121303, 49.76899112973894, 49.835002490452354, 50.184813022613525, 48.81149809701102, 46.91633871623448, 44.74069445473807, 43.87079388754708, 47.29485920497349, 45.970073972429546, 47.67477280752999, 49.24014983858381, 50.312864848545615, 47.51384905406407, 45.69814927237374, 45.94872563225882, 49.59079762867519, 50.90276343481881, 47.076459952763145, 47.22347341264997, 46.072514738355366, 47.48026146207537, 50.49017940248762, 53.055579389844624, 50.438793999808176, 46.870956557137625, 48.80952133451189, 47.01331124986921, 45.27807855606079, 45.65000173023769, 44.654932839529856, 46.16734722682408, 46.70505094528198, 46.031968525477815, 46.69148458753313, 50.750441551208496, 52.438020024980815, 56.256868089948384, 55.635535853249685, 55.17576313018799, 49.6395948273795, 45.51359469549996, 41.518290179116384, 43.35764510290963, 42.62790707179478, 40.10961587088448, 41.16619716371809, 43.28177424839565, 42.44583647591727, 42.99563005992344, 43.82642616544451, 45.094906670706614, 44.60869605200631, 49.163379192352295, 41.30232627051217, 46.902376311165945, 43.68428686686924, 49.57008852277483, 51.517216954912456, 50.541530064174104, 51.265105043138774, 51.06316954748971, 48.90534741537911, 49.29919215611049, 47.06833750861031, 45.29622377668108, 42.39858177730015, 41.54260540008545, 41.205294677189414, 43.42840903145926, 44.788789885384695, 42.43111324310303, 39.03132493155343, 38.07163974217006, 37.715711321149556, 40.08827100481306, 41.42670944758824, 45.43437133516584, 45.26790639332363, 44.387034620557515, 45.62667315346854, 48.30482850755964, 40.8765024457659, 44.292903900146484, 41.982506275177, 40.606679575783865, 40.20840883255005, 43.021376609802246, 46.359284264700754, 48.57218476704189, 45.77585097721645, 46.682010718754356, 45.048548289707725, 48.47496904645647, 46.78375666482108, 46.753639698028564, 46.738360609327046, 49.17840467180525, 53.31419134140015, 56.36973810195923, 57.79146112714495, 58.99230439322335, 58.75997747693743, 58.471460478646414, 57.80883509772164, 58.47934668404715, 55.46320315769741, 61.35631084442139, 64.71192250932965, 70.68403816223145, 71.4016342163086, 74.13476371765137, 69.79185472215924, 52.067246777670725, 0.9607965754611152, 0.18366881726043566, 0.059932066925934384, 0.17370961952422345, 1.6803118522678102, 33.59305674689156, 78.72209644317627, 52.796293463025776, 48.51195430755615, 31.308242389133998, 50.259825774601524, 45.97834927695138, 0.17424639500677586, 0.05246849723958543, 0.011377555600899671, 0.0683520690404943, 0.05255008089755263, 0.01917744880276067, 0.045901604795030186, 0.05886924359947443, 0.10509835010660545, 0.23777424969843455, 0.3930487377302987, 0.142868791573814, 0.2976417743733951, 0.14735963488263742, 0.21069284501884664, 0.15236126578279904, 0.16516208675290855, 52.66317640032087, 63.31923253195626, 40.55636419568743, 58.10014874594552, 63.492610931396484, 76.84405394962856, 76.37153475625175, 1.9796672804015023, 0.1955060235091618, 0.685335785150528, 2.280080028942653, 30.885110991341726, 82.38385963439941, 72.83214323861259, 78.63618196759904, 73.7768064226423, 78.44688524518693, 68.6050329208374, 65.83095073699951, 58.26797553471157, 60.881929533822195, 57.4171199798584, 57.36433798926217, 52.17087915965489, 56.70245606558663, 53.33438975470406, 57.98470095225743, 54.86737428392683, 54.259243624550955, 52.767573084150044, 55.48947082247053, 54.212054933820454, 51.096295084272114, 52.22735759190151, 51.90077141353062, 54.150417464120046, 52.42997053691319, 52.71031297956194, 51.262009620666504, 47.63674879074097, 47.93895026615688, 50.76702690124512, 47.47680820737566, 49.63078451156616, 50.92481354304722, 53.331992626190186, 48.54861300332205, 46.44514315468924, 47.972937379564556, 49.87490599496024, 52.0111574445452, 45.922944341387065, 47.072687080928254, 46.43996327263968, 48.90925577708653, 51.78032439095633, 53.61514561516898, 50.21863685335432, 49.47283111299787, 49.23031118937901, 48.38973549434117, 48.262805802481516, 47.92358085087368, 47.97746760504586, 51.1652455329895, 51.390568665095735, 48.14621155602591, 51.32105541229248, 54.225381578717915, 55.52512550354004, 59.213111196245464, 58.750694683619905, 56.24673414230347, 46.304667949676514, 45.26113189969744, 41.96476752417428, 45.856547355651855, 42.83066245487758, 42.988754817417686, 44.92103842326573, 43.67466361182076, 45.24333756310599, 44.22572176797049, 45.477985177721294, 43.8729304586138, 45.088201659066335, 49.63540506362915, 43.932309763772146, 48.061082226889475, 46.13780001231602, 50.44635363987514, 53.15246854509626, 54.12721048082624, 53.07223422186715, 54.01383325031826, 52.37469414302281, 50.28619418825422, 48.22757496152605, 48.38067156927926, 45.029145445142476, 43.40763739177159, 42.51991816929409, 45.26648201261248, 46.71727282660348, 43.585552964891704, 39.93838446480887, 39.751391070229666, 36.716254643031526, 40.61945036479405, 41.46759612219674, 46.443517276218955, 47.42740651539394, 44.703330516815186, 47.8324100630624, 50.636623110089985, 43.137147494724815, 47.30926629475185, 45.05146653311593, 43.28072854450771, 44.48993396759033, 46.20766067504883, 48.418744223458425, 52.282894543239046, 48.55522421428135, 50.90752295085362, 47.26973451886858, 51.41277858189174, 49.27624225616455, 49.86057186126709, 49.25770446232387, 52.40556846346174, 56.38873447690691, 60.068969454084126, 60.92953164236886, 63.359490394592285, 63.6968879699707, 61.380421093532014, 62.55776555197579, 62.37623691558838, 58.31664071764265, 63.25578853062221, 68.38519886561802, 73.84387738364083, 73.80370984758649, 76.57407474517822, 71.34542328970772, 55.61639356613159, 1.2708889245986938, 2.176678023168019, 0.5667151617152351, 0.841843958411898, 4.000723677022116, 39.83467217854091, 86.77534348624093, 57.63263920375279, 63.262375422886436, 43.28609602791922, 54.060017926352366, 54.62457990646362, 0.27185969640101704, 0.21972318259733065, 0.18015167170337268, 0.15053635942084448, 0.08111204898783139, 0.10560611821711063, 0.08804698900452682, 0.13765469778861317], [0.0314971748739481, 0.017826585664546916, 0.04011494280504329, 0.04986281420237251, 0.03566986329055258, 0.020227098371833563, 0.03615629826007145, 0.05003055823700769, 0.21338377919580254, 48.88861962727138, 34.12772757666451, 37.34707464490618, 45.56731469290597, 43.04648739950997, 69.11134120396206, 44.9106890814645, 0.0735208841839007, 0.059756706335714886, 0.46655915890421185, 2.1725629525525227, 19.11939627783639, 83.4954810823713, 67.6080914906093, 79.01638739449638, 70.04589475904191, 75.05189813886369, 62.28302683149065, 56.40751893179757, 50.914683069501606, 51.06611210959298, 48.14641652788435, 52.893662043980186, 46.373434271131245, 50.82287652151925, 49.512526171548025, 50.84268583570208, 50.521783283778596, 50.27204418182373, 46.87839807782854, 48.114145619528635, 45.58223247528076, 47.057887417929514, 45.03159815924508, 45.82664925711495, 46.11295672825405, 47.296165466308594, 46.27063914707729, 44.25491462435041, 42.72112757819039, 41.02633687428066, 42.52500425066267, 42.05095297949654, 43.05743776048933, 44.86627619607108, 45.99026543753487, 46.546704973493306, 44.97034631456648, 43.596350465502056, 49.92277908325195, 54.01855802536011, 48.593282972063335, 49.22352279935564, 49.537675176348, 54.38159792763846, 56.60871097019741, 57.95118284225464, 54.090030670166016, 54.64460114070347, 52.363253934042795, 51.68736444200788, 46.99008689607893, 46.79671158109392, 46.85712964194161, 44.45375122342791, 42.24179220199585, 41.75018630708967, 44.111771311078755, 47.24388722011021, 48.4039306640625, 48.70273099626814, 51.31469086238316, 53.14316143308367, 39.15369313103812, 42.143214634486604, 42.80640629359654, 43.232014724186485, 46.689678055899485, 36.83061851773943, 37.963775907244, 40.42607504980904, 36.69253349304199, 36.81614542007446, 36.01889521735055, 52.02558537891933, 42.26928274972098, 46.11038589477539, 41.52493960516793, 42.81714473451887, 52.7153434753418, 49.22343247277396, 49.68176691872733, 48.2227702822004, 47.39696645736694, 43.92236689158848, 44.13099002838135, 42.707453523363384, 41.50934089933123, 37.78781625202724, 40.83491052900042, 37.55099037715367, 39.73862028121948, 41.61629104614258, 43.98854848316738, 41.13458286012922, 38.98762771061489, 37.293399810791016, 38.72555555616106, 41.997576917920796, 42.55183124542236, 43.830212933676584, 44.147321769169395, 48.03319910594395, 44.92507880074637, 43.171614033835276, 40.98659665243966, 41.40400273459298, 39.01636893408639, 37.47321571622576, 36.36901147024972, 40.603841236659456, 43.30080883843558, 45.14058412824358, 45.28242812837873, 44.1155024937221, 43.90004232951573, 45.63794660568237, 43.43462419509888, 45.52589300700596, 45.087232385362896, 46.99442604609898, 44.845865862710134, 51.92697654451643, 50.35858746937343, 57.04470695768084, 53.45653213773455, 54.91248893737793, 52.654904569898335, 54.138084411621094, 52.6361757005964, 57.13119465964181, 58.092814922332764, 68.97164767129081, 64.23863206590924, 75.7095868246896, 63.22947570255825, 68.87378924233573, 4.107648202351161, 0.252824319260461, 0.04360105895570346, 0.26906334502356394, 0.40626100876501625, 23.649708611624582, 73.83932631356376, 48.465144293648855, 39.181861128125874, 17.076170785086497, 37.94179875510079, 37.9491742679051, 0.37196030361311777, 0.0035889748500527014, 0.08213671150484256, 0.016106377255969813, 0.07842802908271551, 0.028842735702970197, 0.0565530880620437, 0.07145518609987837, 0.16321049790297235, 0.00393534916552848, 0.08676001842000655, 0.011748686266530837, 0.054540488735905716, 0.03711385366373828, 0.004109238182926285, 0.056441899921212874, 0.47162103014332907, 58.01916054316929, 42.8371763910566, 34.05968386786324, 44.356573717934744, 52.01593085697719, 75.66474315098354, 51.323581082480295, 0.20913232304155827, 0.20739952102303505, 0.4519506799323218, 2.94419384428433, 23.259306703295024, 86.91738551003593, 69.45306055886405, 82.09187548501151, 72.58378682817731, 76.37726702008928, 65.06946291242326, 58.609000069754465, 54.21013723100935, 54.43008245740618, 51.15841545377459, 54.78170646939959, 50.62947688783918, 54.28739425114223, 53.44134337561471, 54.432813099452424, 54.13911621911185, 52.23084558759417, 50.172222886766704, 51.75179508754185, 48.65494128635952, 49.53492716380528, 48.44308723722185, 47.847637040274485, 48.743496077401296, 48.807704380580354, 47.557476793016704, 47.595038754599436, 44.4344664982387, 43.816062927246094, 46.38660110746111, 44.639976842062815, 44.96021236692156, 47.63842330660139, 48.013414110456196, 48.36490610667637, 43.80056497028896, 44.47275454657418, 50.26926490238735, 55.31814908981323, 49.507287229810444, 50.764667987823486, 51.877296924591064, 57.25355243682861, 57.80712931496756, 60.06714902605329, 55.84195293698992, 58.14426633289882, 54.70895535605294, 55.68712622778756, 48.81206437519619, 49.80092852456229, 49.36790289197649, 47.72876031058175, 44.883563314165386, 42.312403270176475, 46.100964137486045, 48.592417921338765, 50.900692871638704, 52.81843042373657, 52.50476442064558, 54.41635629108974, 46.88209451947893, 43.12660012926374, 41.939837387629915, 45.06628704071045, 48.06015116827828, 38.899618353162495, 38.98360122953142, 38.17304870060512, 40.08619696753365, 39.121602875845774, 38.68032625743321, 48.129803385053364, 40.744524887629915, 47.353807721819194, 43.59363371985299, 44.54384504045759, 53.37835448128836, 52.06566606249128, 50.64480808803013, 49.89673376083374, 48.506194250924246, 46.90884508405413, 46.321347100394114, 45.38223900113787, 43.651633807591026, 41.005933489118306, 41.01115158626011, 41.40009784698486, 41.71426064627511, 42.12812662124634, 44.431162629808696, 42.15906694957188, 40.62130553381783, 37.30423552649361, 38.315285273960654, 43.14873014177595, 43.32827854156494, 43.265501567295615, 44.24797337395804, 49.06433956963675, 48.29683460508074, 45.942649432591026, 42.624592781066895, 43.166562693459646, 41.88119459152222, 41.5676988192967, 39.00287205832345, 41.85501377923148, 44.60978691918509, 46.65279354367937, 46.72551686423165, 45.77000406810215, 46.359576089041575, 48.23526314326695, 45.20452145167759, 47.38613074166434, 47.69086136136736, 52.779878343854634, 47.244106088365825, 54.068376609257285, 54.02498858315604, 59.479602405003135, 55.12865434374128, 57.183278356279644, 55.333278792245046, 56.6911860874721, 54.60718856539045, 58.944125584193635, 60.55316162109375, 73.40295164925712, 66.77902548653739, 75.72415719713483, 63.517186709812705, 75.14209965297154, 6.093435108661652, 0.7282259293964931, 0.09176732865827424, 0.2917407995888165, 1.21940635570458, 26.129423413957866, 80.43058899470738, 56.300978728703086, 46.164265700748985, 22.814707108906337, 46.39556080954415, 44.49183429990496, 0.22647890794490064, 0.02275629524540688, 0.09211403291140284, 0.020898442615621855, 0.03469528005059276, 0.020540556105385934, 0.05404440839109676, 0.06788117930825267, 0.23333269517336572, 0.1433268298528024, 0.19902688743812696, 0.213652139795678, 0.13306385198874132, 0.11497984879783221, 0.20809557581586496, 0.1705808809825352, 0.8757711978895324, 68.83742931910923, 49.02442216873169, 48.06277411324637, 61.865940366472515, 57.74900763375418, 82.62148107801164, 57.56070102964129, 1.1283039642231805, 0.27386512021933285, 0.8245557003787586, 2.7968690182481493, 24.375800575528825, 87.18388366699219, 70.8018935067313, 84.64340686798096, 77.77874646868024, 79.82731165204729, 68.84254319327218, 61.598156792776926, 56.29177931376866, 58.27406563077654, 55.22602987289429, 59.212228775024414, 52.58112512316023, 56.38821683611189, 56.98609890256609, 57.19633749553135, 56.229249000549316, 55.264067786080496, 52.49024963378906, 55.936010701315745, 52.96376589366368, 52.84860645021711, 50.94287191118513, 52.23357275554112, 51.14397014890398, 52.40493270329067, 50.91109779902867, 50.13646398271833, 48.07354729516165, 46.60764067513602, 48.04378816059658, 47.21159546715872, 47.52655036108834, 49.104475838797434, 50.984748704092844, 47.9981906073434, 43.58923551014492, 43.61542674473354, 51.052260875701904, 56.735018798283164, 51.38389144624983, 52.74320922579084, 51.58869307381766, 58.56190517970494, 60.692994117736816, 60.741346631731304, 57.78408561434065, 58.9494618007115, 57.432802064078196, 57.34467806134905, 51.9888676234654, 52.39973892484392, 51.257302216121126, 50.57492658070156, 47.532275676727295, 46.396071502140586, 50.90039757319859, 52.28959608078003, 52.60447107042585, 54.304538931165425, 54.83382838112967, 54.996968609946116, 45.405421665736604, 44.66774879183088, 41.44565371104649, 45.07326650619507, 49.43838194438389, 39.0189710344587, 40.53786809103829, 38.65283570970808, 41.20088604518345, 41.624545506068635, 40.63230800628662, 48.307635579790386, 39.64276640755789, 48.072862897600444, 46.05378239495413, 47.08708374840872, 56.375411306108745, 56.442419733319966, 52.59659876142229, 53.01053074428013, 51.412170614515034, 50.31527934755598, 48.649757930210654, 48.02517393657139, 46.983017104012625, 42.634532179151265, 44.19929082053048, 44.82187025887625, 44.78376633780343, 44.28344740186419, 48.12269190379551, 43.217687538691926, 41.693284034729004, 37.2776586668832, 38.90798051016671, 45.01125035967146, 43.96463973181588, 45.86874491827828, 45.08899375370571, 49.02646493911743, 48.94794682094029, 48.90140083857945, 43.78681795937674, 45.91494696480887, 45.160157203674316, 43.96480301448277, 41.62121384484427, 45.21460676193237, 47.97549431664603, 49.326863356998985, 48.97950553894043, 46.87970781326294, 48.72726508549282, 50.37324122020176, 47.67410230636597, 49.720353739602224, 50.91548558643886, 54.81883416857038, 51.22845676967076, 57.08726119995117, 56.49183184759957, 62.32834298270089, 60.15521049499512, 60.94749273572649, 58.48904636928013, 60.2972594669887, 57.832250526973176, 62.348499706813264, 64.14943804059709, 74.90166418892997, 67.82351343972343, 79.35689081464494, 66.15227712903703, 79.19594969068254, 5.855559187276023, 1.9790799404893602, 0.3814180503998484, 1.0265308767557144, 3.1045591362885068, 31.964822837284633, 89.50069100516183, 60.27578953334263, 58.135803427015034, 28.100187880652292, 54.285045760018484, 55.13099588666643, 0.7238812425306865, 0.1773383840918541, 0.17019590735435486, 0.10065843763628177, 0.12332749872335366, 0.0532000733406416, 0.19124741559582098, 0.13161927807543958], [0.04178545530885458, 0.054672372194805315, 0.051557265421641726, 0.017565856887293712, 0.11566143722406455, 0.04598944793854441, 0.0941856817475387, 0.025049183817048157, 0.5332079082727432, 38.24972207205636, 44.74665948322841, 25.275357791355678, 33.65937382834298, 52.83999763216291, 62.82295049939837, 57.61473022188459, 0.5143184161611966, 0.19069078617862292, 0.47783065693719046, 0.4891975298523903, 21.420643125261577, 83.11992400033134, 69.11457211630685, 79.13213743482316, 66.52042048318046, 70.10462093353271, 54.867704323359895, 53.51776661191668, 50.33176742281233, 50.75228977203369, 50.257341793605256, 51.91712399891445, 52.21745293481009, 56.345836298806326, 52.37092127118792, 54.283742972782676, 50.5811938558306, 51.52444655554635, 48.002178873334614, 47.69008316312517, 46.18911940710885, 45.827587263924734, 44.86350039073399, 45.21415860312325, 47.06314025606428, 45.36504915782383, 46.68732261657715, 46.568636962345664, 40.63334328787667, 41.415043422154014, 40.41461399623326, 43.90488869803292, 43.33372245516096, 46.13670219693865, 44.995443207877024, 49.21178034373692, 42.634111813136506, 44.392343044281006, 52.397063868386404, 51.80287824358259, 47.359727587018696, 49.817364488329204, 55.526716641017366, 58.32977281297956, 58.12535333633423, 56.97489145823887, 54.238260064806255, 55.630553994859966, 57.17679221289498, 55.61459745679583, 49.617999826158794, 48.85574769973755, 47.00448703765869, 43.96224955150059, 41.349514961242676, 40.90851974487305, 44.60659074783325, 46.27444328580584, 46.60832854679653, 50.071474007197786, 50.9720960344587, 47.61315965652466, 35.85890599659511, 41.922484261649, 47.259249687194824, 45.69970914295742, 40.02602209363665, 38.939045906066895, 36.04277270180838, 38.69293028967721, 35.04009553364345, 37.556632314409526, 35.637376580919536, 42.71178225108555, 47.92539433070591, 42.72425774165562, 43.64538390295846, 43.40252351760864, 45.846910204206196, 46.172516686575754, 46.46373653411865, 45.462765148707796, 42.15371683665684, 42.64732033865792, 42.49366092681885, 41.479376792907715, 39.77072443280901, 38.932802949632915, 40.78453608921596, 40.760741983141216, 43.95190020969936, 47.892647470746724, 45.16924892153059, 42.573520047324045, 39.663649218423025, 36.86348349707467, 37.811467920030864, 40.98168427603585, 41.359905992235454, 45.20586592810494, 44.89102220535278, 47.409622601100374, 46.58604219981602, 42.518827302115305, 40.913706575121196, 40.47196790150234, 38.72173057283674, 39.0840721811567, 36.63783032553536, 39.99719401768276, 41.83139337812151, 45.30720887865339, 44.47722918646676, 43.29559074129377, 42.390747683388845, 45.90603242601667, 44.02439423969814, 46.083864620753694, 43.01675953183855, 49.02614879608154, 44.470548493521555, 48.775023528507774, 48.68628808430263, 54.01288482121059, 50.607482365199495, 52.832625593457905, 51.135121617998394, 56.13289138248989, 50.563597542899, 57.371119431086946, 51.84209387642996, 65.12232480730329, 59.54874392918178, 70.28147343226841, 61.975027084350586, 79.57860783168248, 26.133510691779, 0.6604008174368313, 0.05353063524567655, 0.20942610156323227, 0.48621914110013414, 17.068840435573033, 73.1633152280535, 45.266214506966726, 48.06550822939192, 26.88502437727792, 32.6693389075143, 40.62652015686035, 0.5885585610355649, 0.041161735741687674, 0.09111125993409327, 0.014472709203671132, 0.01577596123596387, 0.032773397463772974, 0.06640202046505042, 0.04628450549872858, 0.04890704334580472, 0.031524221279791424, 0.09369796434683458, 0.061377285447503836, 0.1002334507980517, 0.029843537536050593, 0.1459202721182789, 0.05653146993634956, 0.8556051371353013, 48.505172865731375, 53.06060988562447, 37.13387611934117, 39.54904563086373, 59.57855864933559, 70.57115077972412, 65.52186012268066, 0.816243592117514, 0.09740129991301469, 0.2613169992608683, 1.4022206259625298, 26.099287339619227, 86.27135590144566, 69.58433982304165, 81.48713207244873, 71.08791610172817, 72.1443202154977, 57.563966682979036, 56.919875621795654, 53.85379539217268, 54.40819215774536, 53.2146966116769, 54.980664661952424, 53.40079368863787, 57.05166905266898, 55.052046980176655, 56.180413586752756, 54.56408888953072, 55.031129428318565, 52.01597602026803, 51.35008498600551, 49.41236094066075, 49.32625886372158, 46.990451676504954, 49.533474990299766, 49.028792585645405, 48.887584345681326, 47.494595595768516, 48.32372065952846, 43.6356703213283, 43.67598376955305, 44.655342783246724, 47.77996506009783, 45.385855538504465, 47.18104771205357, 47.40111453192574, 50.02474389757429, 44.92661435263497, 45.810678822653635, 54.79334470203945, 51.04991238457816, 47.02135378973824, 52.71777187074934, 56.823875835963655, 62.09758635929653, 58.50865418570382, 58.566379819597515, 55.49098552976336, 58.23638207571847, 58.06047453199114, 56.58928728103638, 52.42467948368618, 49.91048077174595, 48.38280814034598, 47.087420736040386, 43.60647399084908, 45.39420032501221, 46.59558902468, 47.03579562050955, 49.11407824925014, 53.02927350997925, 52.66251632145473, 50.232609680720735, 42.30675785882132, 41.81457526343209, 46.594717025756836, 45.86214412961687, 40.959265913282124, 37.9978220803397, 36.75343445369175, 38.361480372292654, 37.50706039156233, 37.68496206828526, 38.75668695994786, 43.648239612579346, 46.37063414709908, 42.60963330950056, 44.36593988963536, 46.29786218915667, 48.81901257378714, 47.33179235458374, 44.95931952340262, 47.47990362984793, 44.62482976913452, 45.348064286368235, 44.39513969421387, 43.65821027755737, 42.8332645552499, 41.28208269391741, 43.0092658996582, 43.511568546295166, 47.286312920706614, 50.44618340900966, 49.38914353506905, 45.19868149076189, 39.75200251170567, 36.84751653671265, 38.27917201178414, 41.28753355571202, 41.81430428368704, 47.78130258832659, 47.09733581542969, 49.1994959286281, 49.18698917116438, 44.39016478402274, 42.884274755205425, 42.98363052095686, 40.8592848096575, 41.705634457724436, 38.03689180101667, 42.16100549697876, 44.17353384835379, 46.01786020823887, 45.97668865748814, 44.967608724321636, 45.385237148829866, 46.64745037896292, 45.787774085998535, 48.11983272007534, 45.70839091709682, 50.22221170152937, 46.25938653945923, 51.6083391053336, 50.950379439762656, 55.21551030022757, 53.33094344820295, 54.3448280606951, 52.957547255924766, 59.07587732587542, 55.35255309513637, 59.38891451699393, 55.80938673019409, 66.40845026288713, 61.976312501089915, 73.11170400891984, 64.42319011688232, 81.94975008283342, 31.78897087914603, 0.44693372771143913, 0.046448510805411, 0.17961841103221687, 0.9128438000168119, 18.668819495609828, 80.11969879695347, 50.855272497449604, 57.12231138774327, 31.4992344720023, 39.659952776772634, 50.590059757232666, 1.0314616007464272, 0.12485971221966402, 0.07008727307298354, 0.030697806339178766, 0.03646757619987641, 0.07451514154672623, 0.1105439600401691, 0.017421295001570667, 0.16727627973471368, 0.125000087544322, 0.23141762507813318, 0.11828195303678513, 0.18302006992910588, 0.1160472793770688, 0.174975277323808, 0.17156942508050374, 1.2238368093967438, 59.72613838740757, 60.74277796064104, 34.495454038892476, 47.19798394611904, 68.4803683417184, 74.39539064679826, 70.8958192552839, 1.5572136576686586, 0.18238171775426182, 0.770088174513408, 1.7845432992492403, 28.985456126076834, 87.39556053706578, 74.2823851449149, 84.35685620989118, 74.94748755863735, 75.14905479976109, 61.589485440935405, 59.40215083530971, 58.984953199114116, 56.74994005475725, 55.3132575580052, 58.5476405279977, 57.16719675064087, 62.21447590419224, 58.32968248639788, 60.07101222446987, 57.01455177579607, 57.53354746954781, 54.45482151848929, 53.87648126057216, 52.61122471945626, 52.402302810123985, 50.22724914550781, 52.435987676892964, 52.65802083696638, 50.12860904421125, 52.68419122695923, 52.306528840746196, 46.1865450995309, 47.15123299189976, 46.994224548339844, 49.01141514096941, 47.76869855608259, 49.18269518443516, 49.17990895680019, 52.00435168402535, 44.66640084130423, 45.38328470502581, 57.05842617579869, 53.41329002380371, 49.11390801838466, 52.92884772164481, 58.36215141841343, 65.93117850167411, 61.94047369275774, 61.66648537772042, 57.940263748168945, 59.72274766649519, 61.696828160967144, 61.159926959446494, 54.003977230616975, 54.16437986918858, 52.021232332502095, 49.619997433253694, 46.23155900410244, 49.63735750743321, 48.91448082242693, 51.17713042667934, 51.1786972454616, 56.44113084248134, 55.41913768223354, 51.50432109832764, 39.12667506081717, 42.843287331717356, 46.61467225211007, 47.40172597340175, 40.84255007335118, 38.29930094310215, 35.946227482386995, 38.59314373561314, 36.50077016013009, 39.108304023742676, 40.3543244770595, 47.40324762889317, 44.36923680986677, 44.00490454265049, 47.04357065473284, 48.044719219207764, 51.148284980228965, 49.52932691574097, 49.15527759279524, 49.332071031842915, 46.93997648784092, 45.76920849936349, 46.08958298819405, 45.51527615955898, 44.308683259146555, 42.827883175441194, 45.012240477970664, 44.51590633392334, 47.438857146671836, 52.077846254621235, 49.585433619362966, 46.60948889596121, 41.254817962646484, 37.31157282420567, 37.747429847717285, 42.75696291242327, 43.73975433622088, 48.98136418206351, 48.509091649736675, 50.41332537787301, 51.1914576121739, 48.05569737298148, 45.18123803819929, 46.11273785999843, 43.19470289775303, 46.20858825956072, 40.811908517565044, 44.853567940848215, 45.776438099997385, 51.242123876299175, 49.62547261374337, 46.97038875307356, 48.51063762392317, 50.52200215203421, 47.61276708330427, 50.919859477451865, 48.01236840656826, 54.29343223571777, 48.58551836013794, 54.4947806085859, 53.92274931498936, 60.97329139709473, 58.29232202257429, 57.87031275885445, 56.84126022883824, 62.346846035548616, 57.86254119873047, 62.3890563419887, 57.13490152359009, 71.80717277526855, 65.42150034223283, 77.26681709289551, 66.55829511369977, 85.89862673623222, 31.860078743525914, 0.9386048976864133, 0.11756565075899873, 0.6068853033440453, 2.9199884917054857, 21.838021414620535, 89.6954768044608, 55.40004055840628, 67.78412410191127, 38.312106473105295, 45.70072705405099, 62.889528138296946, 1.2621362571205412, 0.28471299526946886, 0.16568219741540297, 0.08295969984361104, 0.1842064205557108, 0.1376302840986422, 0.20560090110770293, 0.14501734556896345], [0.08039804015840803, 0.0832301639020443, 0.01255245934173997, 0.06166593424443688, 0.03473669782813106, 0.012929101408060108, 0.1342041707996811, 0.05900687764265707, 0.6595085710287094, 43.968117305210654, 41.3238239969526, 19.075513192585536, 27.82107526915414, 54.13930034637451, 63.830439295087544, 55.96089220046997, 0.5499072521924973, 0.3092318853097302, 0.1260557116142341, 0.3976329745990889, 26.39372420310974, 81.87947600228446, 71.53399045126778, 73.3539321081979, 69.23682567051479, 62.195458684648784, 50.52990920203072, 53.12301860536848, 50.54007094247, 52.97672080993652, 49.31727484294346, 54.33079269954136, 51.44375017711094, 56.273717471531455, 53.70234898158482, 52.39940193721226, 50.27800226211548, 49.00276115962437, 47.72119719641549, 47.77538619722639, 46.37071057728359, 45.879983629499165, 43.67914867401123, 45.078564507620676, 45.68692793164934, 46.85756043025425, 46.64982666288103, 45.31879499980381, 41.32535260064261, 40.315286023276194, 39.65499871117728, 40.98339353288923, 44.66120706285749, 42.88136345999581, 44.254511628832134, 46.90789665494646, 43.21784039906093, 51.480787549700054, 48.92453833988735, 46.798333985464915, 53.72395787920271, 53.80579376220703, 56.30798946108137, 55.5125492640904, 53.91200392586844, 55.31901066643851, 51.993773051670615, 54.79461622238159, 54.93316330228533, 56.636611461639404, 54.14716918127877, 51.66133649008614, 48.90266193662371, 47.66525377546038, 44.56848682676043, 44.6580491065979, 47.20121833256313, 46.678203105926514, 51.015689032418386, 50.100329875946045, 48.97181388310024, 40.98051003047398, 31.2260799407959, 45.522818429129465, 49.90833725248064, 37.719946248190745, 39.03629289354597, 33.88530145372663, 36.51672322409493, 35.23597567422049, 39.384251730782644, 39.71699053900582, 39.196087564740864, 29.50532729285104, 43.97412402289254, 53.88599681854248, 41.73766565322876, 47.72958367211478, 46.11436373846871, 47.900047302246094, 44.60374893460955, 45.63788059779576, 43.41365453175136, 42.865743909563335, 41.726496423993794, 45.697134835379465, 40.53353588921683, 41.62931891850063, 46.55014433179583, 49.61943810326712, 51.56825147356306, 55.33376169204712, 55.91403702327183, 52.307317461286274, 47.12395436423165, 38.16443640845162, 35.37491880144392, 38.5137049811227, 40.00786645071847, 46.21423714501517, 50.4642904145377, 48.6560252053397, 45.65648439952305, 42.606920037950786, 41.99939734595162, 42.40790973390852, 37.10311644417899, 36.83174065181187, 36.68984106608799, 40.41479812349592, 42.77508381434849, 42.597727571214946, 43.732722759246826, 43.741546971457346, 43.868070193699424, 44.622182505471365, 43.225052629198345, 44.78128235680716, 42.50810275759016, 46.01943744931902, 45.52338470731463, 43.78331954138619, 45.63095671789986, 50.39002806799752, 49.59334414345877, 50.42750665119716, 51.6159473827907, 54.33850867407662, 56.874847820826936, 59.11680916377476, 55.95868614741734, 60.13260800497872, 59.16101360321045, 67.43635981423515, 66.89171137128557, 70.49578366960797, 55.30736548560006, 0.4015391921358449, 0.15866244052137646, 0.3593149078743798, 0.26318997304354397, 16.462363447461808, 69.17450032915387, 50.29017898014614, 40.091637407030376, 29.956393923078263, 37.63606412070138, 42.02320882252285, 1.3663798634495055, 0.19937228890401976, 0.16751326487532683, 0.06769843625703029, 0.06852680537849665, 0.039333107615155835, 0.05378904173682843, 0.035693934320339134, 0.006699679203198424, 0.0810452268591949, 0.09589863661676645, 0.036355736665427685, 0.09557619677590472, 0.056178726721554995, 0.07007555477321148, 0.030940043340836252, 1.0821084316287721, 54.7956098147801, 47.54331636428833, 20.02510264941624, 35.54591744286673, 59.58937699454171, 69.44048431941441, 61.4893410546439, 0.473224761230605, 0.19856124956692967, 0.07648471157465662, 0.749635609132903, 31.359895297459193, 84.76855087280273, 74.4762190410069, 76.89804145268032, 70.5068382535662, 63.11389241899763, 52.4440267426627, 56.50002377373831, 52.85468264988491, 55.97757829938616, 53.41456849234444, 58.06608172825405, 55.20625182560512, 58.83607414790562, 54.6345853124346, 56.34838628768921, 52.976474148886545, 51.0670952796936, 50.25214106695992, 49.27384165355137, 48.039796420506065, 48.8099799156189, 46.73676252365112, 47.85253552028111, 48.06827013833182, 49.09607546670096, 47.38246209280831, 46.32516860961914, 44.31000689097813, 42.61008494240897, 41.96596261433193, 44.595873151506694, 47.080389159066335, 45.250615801130024, 46.609183175223215, 49.078503472464426, 44.5655129977635, 52.9376927784511, 50.19112546103341, 46.138404505593435, 55.98871626172747, 56.93343850544521, 58.909294264657156, 57.44602448599679, 56.18034757886614, 57.322085993630544, 55.95711932863508, 55.55526678902762, 58.19628749574934, 57.25971548897879, 56.02547918047224, 55.17941788264683, 50.40268768583025, 51.44615077972412, 46.31890828268868, 48.26425102778843, 50.064511912209646, 51.01547711236136, 53.516495091574534, 51.633880683353965, 49.20600986480713, 42.54802710669381, 37.54051596777779, 45.38906908035278, 50.26586028507778, 39.40306050436837, 37.602893420628135, 36.12316335950579, 37.22870513371059, 37.628758089882986, 38.355609144483296, 38.755234786442344, 41.11548226220267, 31.88320929663522, 43.41665267944336, 52.41188437598092, 44.479945932115825, 48.71894114358084, 49.78471490315029, 49.92517968586513, 45.51143727983747, 46.60091481889997, 44.404293945857454, 44.98937395640782, 44.17579548699515, 44.4243221282959, 44.93245083945138, 44.78899833134243, 48.16737576893398, 52.45567192350115, 52.89831386293684, 56.824098178318565, 56.965007645743235, 54.67512805121285, 48.14858783994402, 39.29401200158255, 36.16245542253767, 37.70803008760725, 42.14730364935738, 48.172680718558176, 52.203601700919016, 50.25691447939192, 47.44938366753714, 44.612218788691926, 43.64347662244524, 44.310382093702046, 41.004422255924766, 39.30839477266584, 40.546911171504426, 42.9828314781189, 43.175341742379324, 46.35805095945086, 45.25983258656093, 45.691878523145405, 46.247439111982075, 47.96044451849801, 46.14962237221854, 47.55453423091343, 44.30571985244751, 48.548418453761506, 48.480263573782786, 47.220902579171316, 47.57639673777989, 52.34424713679722, 52.99921907697405, 53.13069289071219, 54.136145864214214, 57.43204123633248, 59.013190678187776, 62.345894132341655, 58.68026079450335, 64.03798198699951, 61.546295438494, 69.88607924325126, 69.45300497327531, 72.64111641475132, 63.11221790313721, 0.751922489276954, 0.4698721468448639, 0.3348248420017106, 0.7618631358657564, 19.528992584773473, 75.67083672114781, 58.04963534218924, 43.51318400246756, 30.424657344818115, 41.876174518040244, 53.68825108664376, 3.2166783085891177, 0.2551751716860703, 0.1135449982913477, 0.08982952085456677, 0.031075224479926482, 0.05579678614490798, 0.03039944770612887, 0.07785942352243833, 0.205935432442597, 0.1799973864108324, 0.15609350694077356, 0.23319288981812342, 0.3021536794091974, 0.10634172481617757, 0.2590337289231164, 0.1301899847707578, 1.779990166425705, 66.63118866511753, 55.0895950453622, 25.737868104662212, 41.97378281184605, 68.55924429212297, 75.16239534105573, 68.77820287431989, 0.9756689774138587, 0.31787031463214327, 0.2034659856664283, 0.896668230848653, 32.27896479197911, 84.92706707545689, 77.83523532322475, 79.3424038205828, 75.2402846472604, 65.59331539699009, 54.643371309552876, 61.16775063105992, 55.60566554750715, 59.700027057102744, 56.908247811453684, 61.30118383680071, 58.62490449632917, 61.53714466094971, 59.69257858821324, 59.53716128213065, 55.533480712345664, 54.22728191103254, 53.18152591160366, 53.43326609475272, 50.98497799464634, 53.62982021059309, 47.901874678475515, 49.98212364741734, 52.64554534639631, 52.68622704914638, 50.975076811654226, 48.67486524581909, 46.025822843824116, 44.718088490622385, 44.949463503701345, 47.27435507093157, 49.11400529316494, 47.24749680927822, 48.97742107936314, 51.046959400177, 44.305723326546804, 54.9558595929827, 50.750431128910606, 46.08282586506435, 58.84212602887835, 57.802922180720735, 62.12411458151681, 60.93684809548514, 60.378087861197336, 59.78334290640694, 57.900672912597656, 58.91542952401297, 60.731417655944824, 60.858486311776296, 59.398989404950825, 58.39491217476981, 55.27393422807966, 52.73104987825666, 48.18985319137573, 49.05206905092512, 52.534089292798726, 52.52412557601929, 56.38885607038225, 53.865610803876606, 51.051437514168875, 41.64691175733294, 35.67834663391113, 45.18420491899763, 50.87477956499372, 42.554791178022114, 37.92198944091797, 35.925056321280344, 36.329264300210134, 37.02417795998709, 38.37119395392281, 40.52053580965315, 41.2584171295166, 36.83506189073835, 48.52596535001482, 49.278851304735454, 44.17362070083618, 50.7531270299639, 50.44259466443743, 53.19514438084194, 47.87946673801967, 50.97934995378767, 48.23135130746024, 47.27363245827811, 45.93232093538557, 48.69860029220581, 44.666842051914756, 45.08105543681553, 49.368222509111675, 54.25161450249808, 55.867126260484966, 58.34095246451241, 59.21937847137451, 55.52468081883022, 51.43812561035156, 38.84433848517281, 35.61178983960833, 38.117723669324604, 42.350948401859824, 49.04450593675886, 53.9018908228193, 52.55836282457624, 49.523580755506245, 47.63004377910069, 46.1502685546875, 49.164296354566304, 44.37483010973249, 41.75452198301043, 42.841581548963276, 45.814298834119526, 48.08931623186384, 47.60470717293875, 48.71972976412092, 48.426915305001394, 48.36713300432478, 52.000926222120015, 50.03656625747681, 51.0207507950919, 46.573980127062114, 53.76893009458269, 50.93653515407017, 50.25716461454119, 51.357519558497835, 56.893816402980256, 56.831081117902485, 57.097065108163015, 57.547666209084646, 60.51378617967878, 62.599538121904644, 64.68978554861886, 61.47784873417446, 66.72637898581368, 63.56030028206961, 74.33252334594727, 72.42531926291329, 77.35073048727853, 65.68774836403983, 0.805224997656686, 0.5218429352555956, 1.0072314952101027, 1.1278829468148095, 21.898340463638306, 83.80098642621721, 64.85290840693882, 55.1089631489345, 43.02051503317696, 49.89258916037423, 65.7188971383231, 3.6056304318564276, 0.2897355386189052, 0.2480037622153759, 0.2951650672725269, 0.18168032967618533, 0.16008501632937364, 0.11610996244209153, 0.14282140268811158], [0.012475074119200664, 0.06527985925120966, 0.013177582628226705, 0.03538514660405261, 0.039601071272045374, 0.019696333013208847, 0.093275250600917, 0.044764254574796984, 0.9924438829932893, 44.49008335386004, 43.45895331246512, 41.34333453859602, 31.93234348297119, 54.96026822498867, 62.27863556998116, 59.43623174939837, 0.7364267579146794, 0.11578474060765334, 0.1842755904155118, 0.3667686693370342, 30.413189343043737, 81.9097284589495, 68.55736133030483, 70.49847957066127, 64.3959184374128, 59.38616303035191, 52.064099243709016, 53.658637864249094, 49.4693535396031, 52.59796755654471, 51.09671892438616, 54.27407455444336, 51.439345019204275, 53.159983021872385, 52.22731590270996, 50.415614809308735, 47.3159886768886, 45.7092490196228, 47.83169787270682, 47.858938285282676, 46.48416076387678, 44.430759634290425, 43.19115236827305, 46.22294323784964, 45.85452195576259, 46.204672949654714, 44.44381529944283, 45.34171710695539, 42.74348340715681, 39.54757956096104, 41.026503631046836, 42.51304292678833, 41.58155700138637, 45.59300913129534, 43.68647902352469, 47.23730032784598, 49.4050201688494, 51.97308479036604, 52.3295065334865, 50.381836141858784, 53.344075543539866, 54.74791043145316, 54.58831378391811, 56.310650621141704, 55.60926818847656, 53.80814225333077, 51.48406362533569, 51.46763113566807, 53.76074511664254, 57.23874582563128, 54.49342570986067, 55.34291941779, 51.79557568686349, 49.571231501443044, 48.61568743841988, 50.23593439374651, 48.154181139809744, 53.45314836502075, 49.81833028793335, 46.40772015707833, 43.73326471873692, 29.57954100200108, 35.68157754625593, 56.53735991886684, 37.1756625856672, 38.78504603249686, 36.69109869003296, 38.21860456466675, 35.91273716517857, 36.1537458556039, 34.78247022628784, 39.51451308386666, 35.03005886077881, 29.950137070247106, 29.935017790113175, 52.78559671129499, 52.03947830200195, 41.278598172324045, 50.03615978785923, 47.42655883516584, 45.5702155658177, 45.23331478663853, 42.19584376471383, 43.287753173283164, 47.59925283704485, 44.89076859610421, 47.5643971988133, 48.59298767362322, 48.937680857522146, 53.291515895298545, 51.68676689692906, 52.70280197688511, 52.30637945447649, 53.970740522657124, 53.31078324999128, 45.39125428880964, 38.47268976484026, 38.369130338941304, 42.7225797516959, 47.77344764981951, 45.22200659343174, 46.71357985905239, 43.16460330145699, 41.852759088788716, 40.70735549926758, 39.589251382010325, 38.61680582591465, 36.99860858917236, 37.142356395721436, 39.061302934374126, 41.4578651700701, 41.60591391154698, 43.569311550685335, 42.638235569000244, 43.7447327205113, 44.40409244809832, 42.93468393598284, 43.06779752458845, 44.24682344709124, 43.970031533922466, 44.22937652042934, 45.4520822933742, 45.92137404850551, 46.63044466291155, 50.2938163621085, 50.14923824582781, 56.55601235798427, 56.398423739842, 63.48425224849156, 63.65421213422503, 64.52874020167759, 62.25077329363142, 66.48665223802838, 63.85657146998814, 65.96390451703752, 65.7261996950422, 71.99352346147809, 9.259654079164777, 0.7094984171645982, 0.6056517266801426, 0.9575024779353822, 18.767501286097936, 71.48949418749127, 48.255489349365234, 42.60252182824271, 37.423536096300396, 34.711570807865684, 53.62537683759417, 2.3690191422189986, 0.21246618271938392, 0.08387286548635789, 0.09672996415091412, 0.05421524993809206, 0.01192011813899236, 0.042396584658750465, 0.05626039519639952, 0.11289268186581985, 0.04506177860977394, 0.13178477276648792, 0.02205916667090995, 0.015043101007384914, 0.0698323610371777, 0.025581647209557037, 0.1714226579559701, 1.753918896828379, 54.902546065194265, 49.662093094417024, 41.47537463051932, 34.340995584215435, 64.14217022487095, 68.03622559138707, 66.33932958330426, 0.6312910680259977, 0.1624964483614479, 0.15986244327255658, 0.318274911493063, 33.66520684106009, 84.35681452069963, 71.01532132284981, 72.72579411097935, 65.84822395869664, 60.253291266305105, 55.41776541301182, 56.32867772238595, 52.05234636579241, 55.905372619628906, 55.07624060767037, 58.35468210492815, 54.395271982465474, 55.27078322001866, 54.88935491016933, 53.124241488320486, 50.97344398498535, 49.55754007611956, 49.3124041557312, 51.33281176430838, 49.15857451302664, 48.080846377781455, 48.06376423154558, 49.14222540174212, 48.289431299482075, 48.51274640219552, 47.810179301670615, 47.631145068577354, 44.96399218695504, 42.8746897152492, 43.717335973467144, 44.41203423908779, 43.465554101126536, 46.40146677834647, 44.68977458136422, 48.986832414354595, 49.303736277988975, 54.7222854750497, 53.53756897790091, 50.55070168631417, 54.8050593648638, 54.89792203903198, 57.013645035879954, 59.55781132834298, 59.192266600472585, 57.08209521429879, 54.34634624208723, 55.02511576243809, 55.02899980545044, 58.11009856632778, 55.9883063180106, 57.60305724825178, 55.568822724478586, 54.018742152622764, 51.26576164790562, 52.439673696245464, 51.67317622048514, 55.385286058698384, 53.249062401907786, 46.832942962646484, 41.942488125392366, 33.564273834228516, 37.25479909351894, 55.73087208611624, 40.514480454581125, 40.53672511237008, 37.36095714569092, 39.26659788404192, 36.801224163600374, 36.597916398729595, 36.51494795935494, 39.290037631988525, 35.44799648012434, 32.89314385822841, 33.386320046016145, 50.401447432381765, 50.70172425678798, 42.865452085222515, 53.90113694327218, 49.27272299357823, 47.67006540298462, 47.277738843645366, 43.77313000815255, 45.65073823928833, 49.4271536554609, 47.29542548315865, 50.54586574009487, 51.53951025009155, 51.74206066131592, 54.82863807678223, 54.3136237008231, 54.86360836029053, 53.27924190248762, 55.61024441037859, 54.40827553612845, 48.156171798706055, 40.865882124219624, 39.6433014188494, 42.142547607421875, 49.17387097222464, 45.65559155600411, 47.772551332201274, 46.04672302518572, 43.44122150966099, 42.76630476542881, 42.886435644967214, 40.686736719948904, 39.280021803719656, 39.89004584721157, 42.211310454777305, 45.282292638506206, 44.36335515975952, 46.26454210281372, 43.59261233466012, 44.803103174482075, 46.55881568363735, 46.21634244918823, 47.00810704912458, 47.40238952636719, 46.89256198065621, 46.78634486879621, 48.41917153767177, 47.1546619279044, 49.15705633163452, 53.14102486201695, 51.7556791305542, 60.446722166878835, 60.38983726501465, 64.35807854788644, 66.21101025172642, 66.94590037209647, 66.39501244681222, 68.82442229134696, 66.16118471963065, 70.69564165387834, 67.52466447012765, 77.0244083404541, 13.243633031845093, 0.8655337329421724, 0.3973059207201004, 1.5194801624332155, 21.80695254462106, 78.25413526807512, 54.19208928516933, 50.17701366969517, 31.96891532625471, 37.76338638578142, 67.4930362701416, 3.6032335204737524, 0.32739005237817764, 0.10367987265012094, 0.041006439431969605, 0.013572099851444364, 0.0128825674764812, 0.009411066970122712, 0.04709913767874241, 0.14602392512772763, 0.09663138658340488, 0.19988119016800607, 0.1548238864966801, 0.130465904250741, 0.16992796744619096, 0.21914326585829258, 0.26728080638817375, 2.1689079829624722, 66.56179700578961, 60.23283576965332, 58.658950669424875, 44.20272670473371, 71.63261318206787, 73.25782462528774, 70.17816066741943, 0.819071997489248, 0.18907976762524673, 0.30151957486357006, 0.5301928243466786, 36.50936508178711, 85.87317548479352, 73.65162072862897, 75.43253435407365, 69.4195077078683, 64.92365496499198, 58.43715722220284, 59.08172770908901, 53.98901775905064, 59.49429784502302, 57.06854622704642, 62.86156163896833, 55.520737716129844, 59.09311580657959, 58.01123264857701, 56.579448631831575, 54.43999406269619, 52.3776228087289, 53.1592777797154, 55.236893381391255, 52.62045540128435, 51.50393547330584, 50.542336055210654, 51.748720509665354, 50.864395482199534, 50.67891332081386, 49.826859201703755, 49.78461415427071, 48.85042190551758, 45.52427060263497, 47.249386719294954, 47.174304485321045, 46.817438057490754, 49.82646662848336, 47.16283995764596, 52.34905876432146, 51.615811892918174, 55.959394863673616, 54.25392825262887, 52.79963902064732, 57.05366318566458, 58.087575980595176, 59.81290749141148, 62.2925945009504, 60.15305655343192, 59.10590049198696, 58.12246983391898, 55.86926283155169, 57.204477310180664, 61.9142164502825, 58.60517161233084, 60.21966198512486, 57.95041854040963, 57.22326176507132, 53.30676024300711, 54.09631878989083, 53.10716281618391, 58.317418915884836, 56.82500491823469, 48.681872504098074, 45.5608354977199, 34.766513688223704, 34.96506888525826, 56.174194949013845, 44.88062422616141, 42.57070255279541, 36.72531509399414, 38.596544878823416, 38.738440990448, 36.87536491666521, 36.01661620821272, 39.534173011779785, 35.49565070016043, 34.80503102711269, 38.69747788565499, 56.23144463130406, 51.501670360565186, 46.60137340000698, 53.38251992634365, 53.02164786202567, 49.384825229644775, 49.38471058436802, 45.6886510848999, 47.699987820216585, 52.48455211094448, 48.902279785701204, 52.6527784211295, 53.21086120605469, 54.212235586983816, 58.324638094220845, 57.11978571755545, 58.34249496459961, 56.540104457310264, 57.91334990092686, 56.21460567201887, 48.717204093933105, 40.08257695606777, 40.11853388377598, 43.583176680973594, 49.72141681398664, 47.695054599217, 50.3942734173366, 47.03930098669869, 45.276803561619346, 45.667625835963655, 45.42469596862793, 42.430758884974885, 42.20236117499215, 43.53923279898507, 43.47871746335711, 46.939121859414236, 46.30778421674456, 49.64938831329346, 46.98556014469692, 48.1225459916251, 49.416390895843506, 49.679005009787424, 48.02700826099941, 49.77919108527047, 49.802814960479736, 49.58910574231829, 51.92355803080967, 51.26890570776803, 52.17823035376412, 57.681960991450715, 54.820505210331504, 63.94111715044294, 61.49955490657261, 68.18445151192802, 68.88032054901123, 70.59281526293073, 68.63415976933071, 71.96229825701032, 68.4234139578683, 73.34829017094204, 70.29796150752476, 79.03370925358364, 12.645295858383179, 1.2629370370081492, 1.2476896494627, 2.027623095682689, 25.314604691096715, 84.81176171983991, 62.65126051221575, 59.98776585715157, 54.856514249529155, 48.21328946522304, 78.43936729431152, 5.52388345343726, 0.4828543130840574, 0.272446303495339, 0.1663651836237737, 0.1897365352404969, 0.17366616614162922, 0.12905149800436838, 0.12437006777950696], [0.023352261033973525, 0.009091069855328118, 0.11662821391863482, 0.017275998601689935, 0.059774348246199746, 0.046161785655255826, 0.1255897344755275, 0.07510807937277214, 1.7811755942446845, 46.12546348571777, 46.43619734900338, 32.00199222564697, 27.613188641411917, 54.19228730882917, 64.20056983402797, 56.468829836164204, 1.024570290531431, 0.14077823875205858, 0.0962291442389999, 0.36867817544511383, 35.332131794520784, 80.27396965026855, 69.18962655748639, 72.665497643607, 60.95977020263672, 56.88705927985055, 52.70251710074288, 52.36545303889683, 50.23093516486031, 50.547533307756694, 52.53761897768293, 50.32221017565046, 50.65967375891549, 50.063730239868164, 48.91790975843157, 48.98953526360648, 46.57547746385847, 48.110525608062744, 46.18595797674996, 47.708596638270784, 44.61849648611886, 44.29273019518171, 44.525237764631, 44.352578503744944, 47.52057491030012, 45.28177499771118, 45.275226320539204, 44.68377481188093, 43.7374301637922, 41.330692291259766, 41.43718038286482, 43.00615658078875, 42.65308039528983, 42.72831201553345, 43.37705142157418, 43.268332958221436, 50.26525231770107, 54.3392972946167, 53.875324385506765, 52.42895957401821, 50.24351487840925, 51.4156551361084, 54.19244016919817, 58.791598728724885, 56.49377734320504, 55.9064530645098, 53.541869912828716, 52.360023021698, 49.20661783218384, 47.43748140335083, 53.525979382651194, 55.08699641908918, 52.733057907649446, 52.06266096660069, 49.36286892209734, 50.90560872214181, 51.401425225394114, 47.37047645023891, 49.26977695737566, 40.40455995287214, 36.30211421421596, 38.50637810570853, 47.315116677965435, 41.38315119062151, 32.164194447653635, 44.02612434114729, 38.486954416547505, 39.135169233594624, 35.3872275352478, 35.66570438657488, 36.795738560812815, 36.950836249760215, 36.23386205945696, 33.90430130277361, 30.629636151450022, 31.437253066471644, 48.477664947509766, 44.97569295338222, 50.145065852573936, 55.2742851121085, 47.437915665762766, 47.454316888536724, 46.56843546458653, 48.606265681130544, 48.37847593852452, 51.962078843797954, 48.96588012150356, 50.90367712293352, 50.49722487585885, 54.66663040433611, 51.10297925131661, 50.34926993506295, 50.99662664958409, 51.00728518622262, 50.15683957508632, 52.42057309831892, 43.671495233263286, 38.49599402291434, 42.006519249507356, 46.7866644859314, 39.00874328613281, 40.776260784694124, 43.393803528376985, 41.888980048043386, 40.86166109357561, 39.10185956954956, 36.26763377870832, 36.97969906670706, 37.01498201915196, 40.398647035871235, 42.755528109414236, 40.60502937861851, 41.07790987832205, 42.13960157121931, 42.82960285459246, 43.76122774396624, 42.97743272781372, 45.00386095046997, 44.62657724108015, 44.03658138002668, 44.46103988374983, 44.051554747990195, 43.63506930215018, 46.86846910204206, 45.50594472885132, 51.17990970611572, 53.49947895322527, 59.55420521327427, 65.9765988758632, 67.1190494809832, 68.50734819684709, 69.05549158368791, 68.79974228995187, 70.2307515825544, 68.46408871241978, 67.95231219700405, 71.46377890450614, 34.83849702562605, 0.3389364113765103, 0.5437811666301319, 0.8286569288798741, 20.700339010783605, 66.60489668164934, 49.73996850422451, 38.15579284940447, 30.900876453944615, 37.42186158043997, 52.228861876896445, 3.874979521547045, 0.4609659676040922, 0.14452529911484036, 0.07799992098339967, 0.0527184729331306, 0.02934248692223004, 0.07104562914797238, 0.01271934587774532, 0.07217924403292791, 0.06388941886169569, 0.04495365744722741, 0.02651301964319178, 0.11137824598699808, 0.10793926087873322, 0.10117530490138701, 0.1763020304164716, 2.3183978242533545, 56.363776547568186, 53.557656220027376, 34.02245889391218, 30.29026528767177, 61.096052169799805, 67.22138949802944, 61.44819382258824, 0.8068586928503854, 0.17632972821593285, 0.03965464500444276, 0.3377182510282312, 38.27383232116699, 82.87167181287492, 69.7556893484933, 74.71181855882917, 64.37594236646379, 60.197809900556294, 55.27242994308472, 55.06088508878435, 54.42587184906006, 55.429688521793906, 57.53708757672991, 54.823336601257324, 52.62927613939558, 52.416563987731934, 51.85123075757708, 52.39167554037911, 48.573379857199534, 50.82782016481672, 48.1559077671596, 50.72690800258091, 47.701165539877756, 46.48782246453421, 48.58378825868879, 48.37247964314052, 48.591302735464915, 48.40375348499843, 46.91739484242031, 48.26143700735909, 44.401472977229524, 43.61956092289516, 43.715998445238384, 44.977923325129915, 45.01539148603167, 44.80241182872227, 45.05616351536342, 45.31724555151803, 52.73850529534476, 55.29790203911917, 55.46941832133702, 54.62195348739624, 54.22111191068377, 54.31588881356375, 56.967203276497976, 59.064711570739746, 58.93971347808838, 58.78740201677595, 54.9765339578901, 53.79899842398507, 49.41646385192871, 51.33882195608956, 55.67658928462437, 57.64235625948225, 56.09805658885411, 55.12284564971924, 51.12878486088344, 52.78267151968819, 55.99040467398507, 49.6422073500497, 49.50003678458077, 40.84320667811802, 38.672151701790945, 39.96162271499634, 45.20560884475708, 43.61410311290196, 36.27186175755092, 43.0276369367327, 39.53303350721087, 39.63902480261666, 34.84576136725289, 36.17158882958548, 36.21551186697823, 37.229531969342915, 37.27034568786621, 35.022766726357595, 35.634159564971924, 32.253110545022146, 46.314127922058105, 44.9176025390625, 52.04399463108608, 57.7571439743042, 49.83057648794991, 51.34856333051409, 49.45347343172346, 50.62406076703753, 50.15063830784389, 53.483181953430176, 51.4347904750279, 53.87169395174299, 50.61296101978847, 56.35882248197283, 53.228370666503906, 53.28638812473842, 52.55166128703526, 52.38045767375401, 51.78206491470337, 51.65262344905308, 45.44823299135481, 39.26195648738316, 41.21438986914498, 50.193671975817, 39.874794551304404, 41.6032840183803, 45.0682429586138, 44.16260085787092, 42.55355092457363, 41.433629853384836, 39.98423562731062, 39.309648922511506, 40.023774351392476, 42.449654511043, 44.03376388549805, 43.43183101926531, 43.19298669270107, 45.5195631980896, 45.06613070624215, 47.84561511448452, 45.2195851462228, 46.73730100904192, 47.484631878989084, 48.10616213934762, 47.0326828275408, 46.507874965667725, 46.48336866923741, 49.7428172656468, 49.06971747534615, 53.32953296388899, 56.90726464135306, 62.54700974055699, 67.50435488564628, 70.30682740892682, 71.03877844129289, 71.95886584690639, 71.36310645512172, 71.84977912902832, 71.56621619633266, 69.61550249372209, 74.83593423025948, 41.59505040305001, 0.5187216741698129, 0.2505505212715694, 0.8666279113718441, 25.235230207443237, 72.31072957175118, 55.45030035291399, 45.54417371749878, 36.29089634759085, 43.25823375156948, 62.706540380205425, 6.883760562964848, 0.5798302122524807, 0.135319533092635, 0.07871954808277742, 0.03861924806343658, 0.03015581631500806, 0.04691283231867211, 0.051519172465694804, 0.23153004476002284, 0.16808859471763882, 0.21895850077271461, 0.07739307997482163, 0.2691532373428345, 0.2056124090616192, 0.28695349075964516, 0.36886091849633623, 3.0954365858009885, 68.76448018210274, 63.471182686941965, 42.1647366796221, 39.404387610299246, 68.511885370527, 72.68499428885323, 68.37684713091168, 0.9739577663796288, 0.2952267053936209, 0.11943867882447583, 0.34035701943295343, 39.03546953201294, 87.07840306418282, 71.92003236498151, 81.43482603345598, 68.0157561983381, 63.52305098942348, 58.22119678769793, 59.92148699079241, 55.652430398123606, 57.99506766455514, 59.944985798427034, 58.13487236840384, 55.25157839911324, 55.04709986277989, 55.10697596413748, 56.32186848776681, 50.8997757094247, 55.04371609006609, 50.54005357197353, 54.1677497455052, 48.36729628699166, 49.80264820371355, 49.941851888384136, 51.12125996180943, 51.53188112803868, 50.640086787087576, 49.28779016222273, 50.60562719617571, 46.09620462145124, 47.896993568965364, 46.979605538504465, 47.96830987930298, 48.13310030528477, 46.32672848020281, 47.111541407448904, 47.367203848702566, 54.24785205296108, 56.04166153499058, 55.5914877482823, 56.17481681278774, 54.88348020826067, 55.5539014680045, 59.542803219386506, 63.28909124646868, 60.16862746647426, 58.24720389502389, 57.18059982572283, 55.517197608947754, 51.07853896277291, 53.47254078728812, 59.28086308070591, 60.92315319606236, 59.67011506216866, 56.980929442814414, 53.162717138017925, 55.31522042410714, 58.79810919080462, 51.268228258405415, 51.39095081601824, 43.43031631197248, 39.61321571895054, 39.51116752624512, 49.630503109523225, 51.63875831876482, 39.378550733838765, 43.05120175225394, 37.282560620989116, 40.30225815091814, 36.02166060038975, 36.93958364214216, 37.10393633161272, 37.55991186414446, 37.21311685017177, 35.84981427873884, 39.220434052603586, 40.76266663415091, 48.76376397269112, 47.69937290464129, 54.46233252116612, 57.33228594916207, 52.06306396211897, 51.41237211227417, 50.74465022768293, 52.447750977107454, 53.99693175724575, 55.225324630737305, 53.73907368523734, 55.50292253494263, 53.80205563136509, 57.64637579236712, 56.20963771002633, 55.44202504839216, 55.393408502851216, 56.434408460344585, 53.97796664919172, 55.32229369027274, 46.29824434007917, 39.60615982328142, 42.51479039873396, 50.70953403200422, 40.42849997111729, 42.4672577721732, 49.33021933691842, 47.14476421901158, 44.96416589191982, 45.64448138645717, 42.87868840353829, 41.87995433807373, 44.29765994208199, 45.68531942367554, 45.821629183632986, 46.766202041081016, 46.029672145843506, 48.04386459078108, 47.35035446711949, 51.05473443440029, 47.90128060749599, 49.619705608912874, 50.39299494879586, 50.51721831730434, 49.801407950265066, 50.47048820768084, 48.71136065891811, 52.333824838910786, 50.88875239236014, 56.74522917611258, 58.86285250527518, 65.82721260615757, 68.94323648725236, 73.81611238207135, 72.38021850585938, 75.85151767730713, 72.44413498469761, 75.83465439932687, 71.40825584956578, 71.85078661782401, 75.36170441763741, 41.83891132899693, 0.719923592039517, 1.4048017731734683, 1.6181352457829883, 26.797133139201573, 78.07252325330461, 63.1344312940325, 56.107672895704, 45.49226719992501, 52.49963665008545, 73.94242368425641, 7.46109550339835, 0.7485940850206784, 0.39943339941757067, 0.2075702811458281, 0.24698164420468466, 0.1219352398599897, 0.11493696538465363, 0.12828511984220572], [0.05734329976673637, 0.0365958498524768, 0.020632960700563023, 0.11696119819368635, 0.04506645371605243, 0.01657978774580572, 0.17973654397896358, 0.07296010213238852, 0.7277800504650388, 40.88978392737252, 46.192075865609304, 30.609225818089076, 41.34607907703945, 49.61356340135847, 69.72467258998326, 35.836029052734375, 0.011810695037378796, 0.1489847805351019, 0.08917886683983461, 1.0309251781020845, 39.257923058101106, 83.77810600825718, 66.24359035491943, 69.02827548980713, 55.816866465977256, 57.31500577926636, 54.88697862625122, 55.581718581063406, 50.38606064660208, 49.79107250486101, 50.78426538194929, 50.1203476360866, 48.51029716219221, 48.25459997994559, 45.544031279427664, 49.52830900464739, 46.34454713548933, 50.518840721675325, 48.253679343632285, 49.99534954343523, 50.65042918069022, 49.70197228022984, 48.40161343983242, 47.54789522715977, 45.619176047188894, 45.56956590924944, 42.98791755948748, 44.116374492645264, 44.73762682506016, 40.68886981691633, 39.451020445142476, 42.181169169289724, 40.539511340005056, 43.447992529187886, 42.797981602805, 45.08032240186419, 49.486852577754426, 57.860821519579204, 57.86148854664394, 57.52023472104754, 52.62589236668178, 51.97654499326433, 52.597526345934185, 54.63149683816092, 56.05424472263881, 55.96108327593122, 54.976822308131624, 43.67381593159267, 37.83500146865845, 49.03518492834908, 46.28185701370239, 49.15155683244978, 49.935341426304404, 48.529904978615896, 47.72714138031006, 49.82315928595406, 46.11027819769723, 48.907014983040945, 41.75205537251064, 39.985364709581646, 44.3676769392831, 43.340510845184326, 30.385160309927805, 31.826567581721715, 43.22483376094273, 42.93197761263166, 43.19402892248971, 38.76193632398333, 36.397512980869834, 36.30815914699009, 37.45394836153303, 38.98032167979649, 39.991659777505056, 37.37135165078299, 33.41653081348964, 27.52764242036002, 30.862060342516216, 45.12522860935756, 39.588778904506135, 56.104726859501426, 50.44629805428641, 51.20021234239851, 47.68420498711722, 49.45546409061977, 50.939960615975515, 53.6405725479126, 51.661228793007986, 52.071002279009136, 51.22757087435041, 50.83920131410871, 51.462069102696006, 51.742710317884175, 52.57364886147635, 54.183747972760884, 50.4465342930385, 48.591507707323345, 46.26892989022391, 42.65320198876517, 46.441384179251536, 45.353841713496614, 36.49906437737601, 40.76407364436558, 41.480241843632285, 39.77209670203072, 37.990158217293875, 37.42185810634068, 35.09500019890921, 38.25046900340489, 38.41295610155378, 41.527527809143066, 39.39591080801827, 41.83992576599121, 41.0067776952471, 45.00097049985613, 44.48506328037807, 46.516852038247244, 45.576840673174175, 47.17561074665615, 46.64699179785592, 46.88141707011631, 45.023423603602815, 46.32833351407732, 46.601825032915386, 47.68028620311192, 47.43693249566214, 50.439117091042654, 51.72649322237287, 59.2495128086635, 66.06686292375836, 68.4441612788609, 66.4740412575858, 68.28843825204032, 66.5262222290039, 69.3481080191476, 66.14625998905727, 70.35568019321987, 64.2779449735369, 58.3118325642177, 0.8192405455878803, 0.12435987618352685, 0.6255223804286548, 23.611038412366593, 70.79525797707694, 48.22488948277065, 39.81203842163086, 29.081739051001414, 26.976797921316965, 61.3060336794172, 8.195479273796082, 0.5015322651181902, 0.21550112058009419, 0.11433572907532964, 0.09703723194875888, 0.05892077154879059, 0.01106744898217065, 0.06322662585547992, 0.05801196210086346, 0.07811384022768054, 0.10707750783434936, 0.0920255451596209, 0.14920975560588495, 0.06177263387611934, 0.12231027973549706, 0.10929827831153359, 1.2614770467792238, 52.240045002528596, 50.533084528786794, 27.99214165551322, 49.0340176309858, 56.671050207955496, 74.75568948473249, 38.843956334250315, 0.5066968937005315, 0.330069397177015, 0.07857409053082977, 1.342702248266765, 40.94667230333601, 86.8461525780814, 66.4376882825579, 69.95007910047258, 59.6109858921596, 61.72884546007429, 57.291618142809185, 58.56893675667899, 52.732877254486084, 53.78642218453543, 52.516062191554475, 52.88623789378575, 52.10850518090384, 51.283552510397776, 48.7635555267334, 51.7710520199367, 49.709524972098215, 52.55241516658238, 50.62641273226057, 54.50454977580479, 53.61268942696707, 52.968403816223145, 50.30516277040754, 48.38722719464983, 47.72806201662336, 46.44798149381365, 43.9706985609872, 46.27331072943551, 46.449596949986045, 44.199374198913574, 42.48623677662441, 45.6879597391401, 42.755587169102256, 46.15765448978969, 43.990629468645366, 48.210649149758474, 50.75015320096697, 58.700077056884766, 59.73038373674665, 59.65405082702637, 55.21873426437378, 53.83646311078753, 54.21046379634312, 56.980853012629915, 57.94709382738386, 58.954603467668804, 57.247455392565044, 41.82848555701119, 39.2301059450422, 49.747913769313264, 48.886118275778635, 50.270640645708355, 50.96338994162423, 50.05087259837559, 51.0503431728908, 53.10469967978341, 48.48683656964983, 49.436780384608674, 40.97532320022583, 40.93887642451695, 41.36805622918265, 42.026061058044434, 37.25822802952358, 37.12750809533255, 43.649337427956716, 43.720372336251394, 41.62208931786673, 39.46607024329049, 37.935687814440044, 35.92888477870396, 37.226426124572754, 39.433677741459434, 40.03201491492135, 37.236483642033164, 35.781096594674246, 31.827745301382883, 29.27839912687029, 43.781189918518066, 42.092082841055735, 58.58443818773542, 51.495580264500205, 53.60661322729928, 51.28694323131016, 52.064484868730815, 53.14564541407994, 54.41676276070731, 52.98338065828596, 53.99367652620588, 53.149897711617605, 52.23239850997925, 51.555265290396555, 52.31668710708618, 53.64396326882498, 55.55721228463309, 53.346792289188926, 50.955163274492534, 47.00692932946341, 44.84195402690342, 46.87751565660749, 46.04938071114676, 37.23549699783325, 43.309956141880576, 43.89842687334333, 42.695895195007324, 41.06793573924473, 40.1207503591265, 38.38871036257063, 42.545220034463064, 39.856135163988384, 43.536985056740896, 43.01407057898385, 46.07158715384347, 43.66751044137137, 45.57163299833025, 47.19619478498186, 50.391122409275596, 48.43487099238804, 49.89150176729475, 49.11344248907906, 50.94318805422102, 49.098319734845845, 49.356903893607004, 47.74337237221854, 52.10824809755598, 49.228299685886924, 52.43202025549752, 53.76451798847744, 64.12150628226144, 66.8154409953526, 72.04995673043388, 66.3638984135219, 73.38296863010952, 69.11069502149309, 74.25052070617676, 69.33540671212333, 76.97670200892857, 65.17369283948625, 67.83731951032365, 1.209586271217891, 0.4584035479596683, 0.911700712782996, 27.076153687068395, 78.64558288029262, 54.80136292321341, 46.30856588908604, 34.27923999513899, 34.841915539332796, 68.0425831930978, 11.147032346044268, 0.9264556467533112, 0.19917533732950687, 0.09264049466167178, 0.17679741526288645, 0.05175364363406386, 0.02173088294720011, 0.0489446579345635, 0.18115119449794292, 0.21910613642207213, 0.17454653818692478, 0.16242923268250056, 0.18895053384559496, 0.1798404548317194, 0.29201845611844746, 0.1851610243320465, 2.2374589102608815, 63.22398662567139, 61.5602821622576, 37.790699754442485, 57.624832902635845, 62.914215087890625, 78.87298352377755, 43.410430567605154, 1.141306540795735, 0.4052613638341427, 0.3883543610572815, 1.6198952027729578, 44.26346785681588, 89.68170547485352, 71.74465288434709, 75.11804498944963, 61.378406115940635, 64.70693370274135, 58.500927788870676, 61.7182286126273, 54.816666330610005, 57.15813282557896, 55.183468682425364, 55.38188491548811, 54.592375005994526, 55.20971550260271, 51.09497492653983, 57.72980628694807, 51.224937507084434, 56.368688923971995, 53.587995529174805, 57.73358610698155, 56.40117175238473, 55.15890680040632, 52.299538952963694, 51.209599358694895, 49.39836726869856, 48.51328488758632, 46.80594226292202, 49.108679498944966, 49.426028047289165, 45.99204765047346, 45.66844572339739, 49.03273916244507, 43.634906019483296, 48.65809229442051, 45.77049739020211, 51.63324839728219, 53.556996141161235, 63.32298455919538, 62.6608281816755, 64.00121906825474, 57.89631291798183, 56.25538117544991, 55.62546443939209, 60.356013434273855, 61.15452126094273, 61.27243219103132, 58.72766835348946, 48.02454512459891, 41.55113083975655, 49.916810580662315, 51.90215063095093, 51.41873318808419, 53.524770396096365, 52.01583705629621, 52.30527816499983, 54.89213766370501, 51.091834340776714, 50.06323691776821, 44.58892147881644, 44.25790582384382, 44.61886821474348, 49.06440905162266, 45.06375094822475, 38.708921568734304, 45.118471486227854, 42.75009461811611, 43.21228878838675, 39.340888023376465, 37.808226585388184, 36.84000553403582, 38.207539558410645, 38.71493870871407, 39.963189533778596, 37.41660179410662, 36.45245238712856, 36.96098061970302, 38.133013180324006, 46.85787657329014, 46.69497605732509, 57.96891117095947, 55.78880616596767, 57.667581694466726, 51.95623540878296, 54.278153147016255, 56.62021023886544, 56.38959605353219, 57.100778920309885, 56.462569509233745, 56.10079417909895, 54.79201064790998, 55.26373774664742, 56.02149786267962, 57.18468884059361, 59.89999621255057, 57.87552738189697, 52.75670262745449, 49.3155516896929, 46.88860150745937, 48.82056202207293, 47.27912848336356, 36.601595469883506, 42.92588751656668, 45.50468363080706, 45.040978227342876, 42.92483833857945, 40.75206020900181, 40.46613141468593, 45.51046453203474, 42.07310731070382, 45.30393975121634, 43.66583592551095, 48.20044572012765, 45.99509790965489, 49.63576636995588, 49.84842988422939, 52.94151776177542, 50.585463523864746, 51.11501005717686, 51.5414731161935, 53.388332094464985, 51.23714896610805, 52.681366784232004, 50.90800585065569, 55.37745196478707, 52.15131998062134, 55.95527458190918, 56.488097190856934, 65.74228477478027, 71.24980912889752, 73.43640722547258, 70.45595659528459, 74.8516788482666, 70.82743508475167, 76.33637687138149, 69.8284022467477, 77.85123702457973, 65.2782632282802, 68.40024171556745, 1.2824302081550871, 0.9937669719968523, 1.9666118323802948, 31.198561600276403, 86.92776611873082, 62.75719969613211, 58.0119309425354, 42.811937059674946, 38.02392993654524, 79.54145581381661, 12.613890869276863, 1.1075171253510883, 0.37814555742910927, 0.2692619929356234, 0.26899104033197674, 0.12617039760308607, 0.15746475835996016, 0.20673488240156854], [0.0728309904890401, 0.030327282114220516, 0.09104120797876801, 0.012330263720027037, 0.11748319518353258, 0.07181769343359129, 0.10679969524166413, 0.08223392521696431, 0.9832170009613037, 41.99397427695138, 40.22300699778965, 46.04395416804722, 51.338165351322715, 44.517976897103445, 75.21533366612026, 19.623948403767177, 0.3453763872385025, 0.13493043397154125, 0.25858095607587267, 1.103016538279397, 36.54429715020316, 86.2846200125558, 64.75593934740338, 69.89661271231515, 61.797528403145925, 63.55590207236153, 57.98119906016758, 56.06696687425886, 50.357559135981965, 50.499743597848074, 48.55389710835048, 49.97120802743094, 47.291218348911826, 47.22324064799717, 46.57080480030605, 51.30332013538906, 51.335156781332834, 54.82756805419922, 53.77171284811837, 56.22141490663801, 54.336455481392996, 55.47339269093105, 52.5303372655596, 51.16406086512974, 49.155944619859966, 47.90126323699951, 43.58752972739083, 43.594276428222656, 45.388864108494346, 42.205546924046104, 37.87641968045916, 40.1507248878479, 42.0613648550851, 44.586218629564556, 43.12465810775757, 43.49421542031424, 46.847158976963584, 50.77630622046334, 48.82966763632638, 48.28829526901245, 45.76227419716971, 52.84619195120675, 46.936384269169395, 51.61734744480678, 53.468628951481406, 57.27126686913626, 49.67301913670131, 36.58211619513375, 44.870083808898926, 49.66027614048549, 48.26161071232387, 48.18963432312012, 48.61837639127459, 46.45723302023751, 46.074828488486155, 46.23931666782924, 46.61520726340157, 38.87592847006661, 37.089199202401296, 39.80688285827637, 29.85269900730678, 26.26401002066476, 34.81344876970564, 45.00561537061419, 43.483483927590505, 43.51711320877075, 43.6973876953125, 40.90938132149832, 37.70020294189453, 38.05521420070103, 39.38981376375471, 41.21427869796753, 40.79219995226179, 42.417717116219656, 37.15315042223249, 33.09712559836251, 23.824146611349924, 34.12646300452096, 38.378270694187705, 43.49113736833845, 54.08399615968977, 48.0107216835022, 50.551393032073975, 47.76673221588135, 51.38371426718575, 51.52253927503313, 52.377178124019075, 52.89458615439278, 53.97098370960781, 51.34073965890067, 47.19465575899397, 51.27001394544329, 52.575052397591726, 52.30324234281267, 50.40260430744716, 48.62632860456194, 49.40584005628313, 49.59262153080532, 51.10370186397007, 51.61169855935233, 38.73808315822056, 40.854563508714946, 40.89934464863369, 38.62063775743757, 38.48860113961356, 38.30236857278006, 36.8794469833374, 36.87899187632969, 40.38254805973598, 42.60850075313023, 40.99664374760219, 43.062912940979004, 41.182640075683594, 45.02871813092913, 44.012384278433665, 48.70944990430559, 50.02746064322335, 51.14691965920584, 49.55713013240269, 49.73780414036342, 48.98119395119803, 50.13353531701224, 46.42525046212332, 50.75326599393572, 47.7457069669451, 48.65406928743635, 50.11213833945138, 55.36938510622297, 62.126421383449006, 70.76586014883858, 64.17739064352853, 67.83392878941127, 63.48317527770996, 74.45217827388218, 66.39023903438023, 79.29077175685337, 61.65611171722412, 78.75014632088798, 8.200328247887747, 0.46265687687056406, 0.2357479270015444, 23.67694902420044, 73.17900426047188, 45.20475421633039, 40.32403380530221, 30.622861657823833, 33.26449728012085, 63.31416729518345, 12.40495158944811, 0.889690773827689, 0.1611784483705248, 0.20556279458105564, 0.09816205301987273, 0.07099032175860234, 0.10315095460308449, 0.07848450355231762, 0.12129258577312742, 0.10362915215747696, 0.14228242875209876, 0.012995191567045237, 0.06448439907814775, 0.06859574453639132, 0.09239615420145647, 0.10733406192490033, 1.7842882786478316, 51.57638781411307, 47.9848952293396, 45.59822722843715, 60.49182987213135, 49.655193533216206, 81.83165849958147, 20.490206377846853, 0.5672011013541902, 0.22010563207524164, 0.568528587264674, 1.7356334094490324, 38.85552508490426, 88.328919001988, 67.27058969225202, 74.02262674059186, 64.50512327466691, 67.33596529279436, 62.09871891566685, 59.774212973458425, 51.59946625573294, 52.49248000553676, 51.14309467588152, 53.0931066104344, 49.46207530157906, 50.4415420123509, 49.96317938395909, 53.730881759098594, 52.835925987788606, 55.55014944076538, 57.31123290743147, 59.9121208190918, 56.45547539847237, 58.21318204062325, 58.07137972967965, 54.654773303440635, 51.06766503197806, 50.42696816580636, 48.007254532405305, 46.95546402250017, 45.396281310490195, 44.0952867099217, 41.05325072152274, 42.92996263504028, 44.92008999415806, 45.90067883900234, 45.784720352717805, 45.45608098166329, 49.40673637390137, 53.738740171704976, 50.22050244467599, 49.26496185575213, 44.91826261792864, 51.9632739339556, 50.1043633052281, 53.808326380593435, 53.99046298435756, 59.754945618765696, 50.553512232644216, 39.56835814884731, 46.358228138514924, 48.711353710719514, 51.07471397944859, 51.07274416514805, 49.588577679225374, 46.75010306494576, 47.71944277627127, 47.416536058698384, 47.874220848083496, 39.16629021508353, 38.06490346363613, 37.61265911374773, 30.826930250440324, 33.63160882677351, 40.263459409986226, 44.90073926108224, 45.15177072797503, 45.275552885872976, 44.36828143256051, 40.457873480660574, 37.511920656476704, 39.464774404253276, 39.88252442223685, 40.727564334869385, 41.597131388528005, 43.25587831224714, 37.75074066434588, 37.07330172402518, 26.86831569671631, 33.932021141052246, 38.33076933452061, 45.549777439662385, 56.13727222170149, 49.403595788138254, 52.31249039513724, 50.28458915437971, 51.977333613804404, 53.205320017678396, 53.387713704790386, 53.70055982044765, 56.112960474831716, 55.041781016758506, 47.91619838987078, 53.77961294991629, 55.99529273169381, 54.05884368079049, 53.74255820683071, 50.80335555757795, 50.75568049294608, 52.52320841380528, 51.40928363800049, 51.9715006010873, 38.23224040440151, 41.29871668134417, 43.325315134865896, 41.38921349389212, 41.059097630637034, 40.97963455745152, 39.38819483348301, 39.91670608520508, 42.00718975067139, 45.4835159437997, 43.412268366132466, 44.95246859959194, 44.20812545503889, 47.20703050068447, 46.49150153568813, 51.50667653764997, 51.673026834215435, 54.03246137074062, 50.26103128705706, 54.228185176849365, 51.18648965018136, 53.43372467585972, 48.08729430607387, 52.50675507954189, 50.452450684138704, 52.40569353103638, 50.25044223240444, 58.23386335372925, 63.95946734292166, 72.42783451080322, 65.406464440482, 70.57595893314907, 64.98025499071393, 76.03866045815604, 66.51166575295585, 81.12751415797642, 63.21958841596331, 84.06836005619594, 10.988093171800886, 0.7353121148688453, 0.3934262203318732, 26.247473308018275, 78.58161776406425, 51.36549261638096, 48.71174280984061, 33.60953439985003, 41.174837248665945, 69.68619346618652, 17.60674044064113, 0.9351259129387992, 0.3849868189011301, 0.09990027653319494, 0.16679152074669087, 0.09796608532113688, 0.09186610300093889, 0.10034974491489784, 0.22999959545476095, 0.161760699270027, 0.2864561245909759, 0.23854853957891464, 0.2646145166030952, 0.18275421990879945, 0.22725855825202806, 0.2436036526092461, 2.5898057520389557, 60.34596633911133, 56.73747846058437, 57.051102774483816, 64.83645507267543, 57.460601806640625, 89.17944799150739, 24.163517475128174, 1.108307374375207, 0.34113092933382305, 1.5469476942505156, 3.5728006277765547, 41.72892481940133, 94.63970375061035, 70.3058477129255, 77.83926527840751, 66.27721963609967, 71.27497550419399, 64.07105541229248, 62.18715558733259, 54.62678248541695, 56.046775409153526, 54.001764229365754, 57.08884538922991, 52.32550089699881, 53.3670323916844, 52.77057818004063, 58.79292583465576, 55.911910874503, 58.46598529815674, 58.943576676504954, 61.29247079576765, 59.86651979173933, 61.03572790963309, 58.6856039592198, 56.60147442136492, 53.21973752975464, 53.26721804482596, 49.59070035389492, 46.71373271942139, 48.68109777995518, 48.989629064287456, 41.38620144980294, 46.06124128614153, 47.67144809450422, 49.218061515263145, 47.57892935616629, 47.677374907902305, 50.755388668605256, 56.4816701071603, 52.57954093388149, 51.39593614850725, 48.35788147790091, 55.463974407741, 51.23132290158953, 56.35149908065796, 57.531303201402935, 62.126900809151785, 52.51299108777727, 41.01505994796753, 48.05653463091169, 50.33087805339268, 51.972886766706196, 53.792095388684956, 51.559020791734966, 49.83248724256243, 47.50148126057216, 49.180280685424805, 49.21105773108346, 40.94318083354405, 40.61739369801113, 42.517437662397114, 34.84267289297921, 36.80976349966866, 42.09521300452096, 46.23836823872158, 45.49347966057913, 44.14196470805577, 44.68818691798619, 41.31041397367205, 37.81623785836356, 39.269509179251536, 40.020515646253315, 41.89288493565151, 42.5103748185294, 44.59901026317051, 38.41180617468697, 38.14719097954886, 31.255137307303293, 38.89417791366577, 40.48105614525931, 48.1725834437779, 56.529730796813965, 52.724654061453684, 52.29022141865322, 50.897263935634065, 56.44284009933472, 56.847065448760986, 55.88286393029349, 57.51931061063494, 57.72404970441546, 55.93238721575056, 51.57745436259678, 56.42329134259905, 56.89994471413748, 56.93346977233887, 56.55339636121477, 51.85146352222988, 53.87404244286673, 54.9814567565918, 53.560647419520784, 53.9503093447004, 39.57634162902832, 43.78151648385184, 45.96567923682076, 42.65708255767822, 44.93023089000157, 43.2471479007176, 42.702634947640554, 42.9531626701355, 44.318699087415425, 47.86590385437012, 45.88895375388009, 46.6617636680603, 46.252309799194336, 50.08874722889492, 48.16132388796125, 54.208959511348176, 55.550743511744905, 57.35214737483433, 54.181569712502615, 55.639069012233186, 54.051106861659456, 55.62481825692313, 51.13457271030971, 57.1147517476763, 53.24761022840227, 54.203084809439524, 54.33202600479126, 60.73729583195278, 66.87595980507987, 75.98311655861991, 66.15795380728585, 72.71695600237165, 65.7463355745588, 79.26825959341866, 68.5767468043736, 84.10647787366594, 66.54853289467948, 86.05975546155656, 9.767478806631905, 0.9533623286655971, 1.1369942064796175, 29.42310925892421, 87.81906713758195, 57.91592768260411, 58.34391239711216, 41.9380829674857, 45.26603037970406, 82.83545085362026, 20.090160369873047, 1.219447067805699, 0.5131055212446621, 0.25109790904181345, 0.46462810252393993, 0.1540094137723957, 0.41192262353641645, 0.16215929788138184], [0.09863040503114462, 0.04285433795303106, 0.04131025687924453, 0.037144275781299384, 0.07026448606380395, 0.05465259289901171, 0.08725643463964973, 0.019159716986385838, 0.5505311244300434, 43.93912247249058, 43.502435139247346, 35.20280844824654, 36.82008157457624, 49.69749764033726, 72.8554961340768, 12.596704500062124, 0.30920029271926197, 0.23164262729031698, 1.0423328174012048, 2.0375540256500244, 35.508233887808665, 84.03873988560268, 64.93251391819545, 71.15411853790283, 64.32601261138916, 67.36097185952323, 63.23217160361153, 61.23013850620815, 52.20385878426688, 49.86788484028408, 48.74998916898455, 52.60193845203945, 48.273085662296836, 48.644432135990684, 48.40434408187866, 53.24752337591988, 53.316206318991526, 56.149351664951865, 54.22689281191145, 57.26457575389317, 56.50158017022269, 56.6070225579398, 53.06810351780483, 55.73777512141636, 52.851868629455566, 50.26283087049212, 43.28298323495047, 45.01499196461269, 44.093375955309185, 41.245257241385325, 37.740311418260845, 39.57058504649571, 39.31293889454433, 40.56223542349679, 41.959782191685264, 44.14069666181292, 50.382940905434744, 54.70849677494594, 51.042752265930176, 42.611293928963796, 41.990173612322124, 45.3020463671003, 43.53750964573452, 46.79286922727312, 47.46344334738595, 48.95421757016863, 42.74502938134329, 46.180354254586355, 44.04968568256923, 47.568712030138286, 49.31272029876709, 50.43544496808733, 51.263183866228374, 50.92450434820992, 52.535194056374685, 50.178055899483816, 43.75562054770333, 42.86765466417585, 36.20529801504952, 28.836530174527848, 26.891274281910487, 38.8526520047869, 44.94415855407715, 46.23700291769845, 49.83170904432024, 47.90500831604004, 50.226693289620535, 46.57976450238909, 39.86765875135149, 39.22878926140921, 41.89549745832171, 46.2298949105399, 47.17122643334525, 46.658696038382395, 44.89348881585257, 34.88938910620553, 29.647928646632604, 27.362059899738856, 36.347590173993794, 34.56033979143415, 44.65279279436384, 50.22530712400164, 48.049798352377756, 47.59166887828282, 47.05125536237444, 49.61765589032854, 45.803782735552105, 50.42397001811436, 47.35637160709926, 44.316743169512065, 38.45205361502511, 45.22962876728603, 53.3809426852635, 54.08269337245396, 49.889928000313894, 45.125760146549766, 45.45361089706421, 46.452289376940044, 51.300238609313965, 49.874596800122944, 41.72786174501692, 43.28883361816406, 39.110360690525596, 40.8242380959647, 37.472388880593435, 38.0560062953404, 36.96789060320173, 40.08736079079764, 41.98221445083618, 44.26505899429321, 41.29965121405465, 43.35319825581142, 42.038470540727886, 45.81471225193569, 43.95647212437221, 48.42902060917446, 49.71265166146414, 52.84138379778181, 49.55791875294277, 52.14282233374459, 51.79304654257638, 52.77012307303292, 51.52111489432198, 50.03898423058646, 47.75163378034319, 49.42734125682286, 48.99348184040615, 52.24986628123692, 54.20961959021432, 67.66171073913574, 66.44472680773053, 72.88533864702497, 67.84753336225236, 72.12137031555176, 63.18303394317627, 73.59391593933105, 64.33529540470668, 83.03068828582764, 26.235324382781982, 0.2490202619561127, 0.11556957715323993, 27.10380056926182, 70.28796304975236, 46.208918298993794, 41.284292221069336, 38.00477722712925, 25.156135388783046, 60.25026185171944, 17.85603485788618, 0.8751231698053223, 0.19880210235714912, 0.13782834847058567, 0.13126938470772334, 0.08462175101573978, 0.15460778666394098, 0.1169606689363718, 0.04031288164800831, 0.022642352252400348, 0.03592221046398793, 0.04378595635561006, 0.07689825152712208, 0.05763146680380617, 0.06312027227665697, 0.04026024768661175, 1.5948436898844582, 54.389251368386404, 50.72381605420794, 35.1533442224775, 42.680167947496685, 56.8363721711295, 78.8158415385655, 13.666723608970642, 0.35187108016439844, 0.41246040325079647, 1.1078980820519584, 3.2549383469990323, 37.66099773134504, 86.03884833199638, 66.58983298710415, 74.10408047267369, 68.78654071262905, 72.65284497397286, 66.84114238194057, 65.04451887948173, 56.05056912558419, 53.352368218558176, 50.57675395693098, 54.18498822620937, 50.70623711177281, 51.971083709171836, 51.36459629876273, 56.70712178094046, 55.439447266714915, 58.31717572893415, 58.13019275665283, 60.589250564575195, 59.227313314165386, 58.20985732759748, 57.40962634767805, 59.701305525643484, 54.50459841319493, 52.5347181047712, 46.207778794424875, 48.532510553087505, 46.93693317685808, 44.340763092041016, 41.170619692121235, 42.0505291393825, 43.29309981209891, 42.271294253213064, 43.731152466365266, 45.515192781175884, 51.58598327636719, 56.32858739580427, 51.25873007093157, 43.92610502243042, 45.5191775730678, 47.10242884499686, 46.37923949105399, 48.650265148707796, 47.96266794204712, 50.772540296827046, 44.96485376358032, 49.227024691445486, 48.61882107598441, 49.7996952193124, 51.932924202510286, 54.38704531533377, 53.78888532093593, 54.155569553375244, 53.931733335767476, 51.055005414145334, 46.31153276988438, 44.26032379695347, 35.995365142822266, 31.001354353768484, 32.67658587864467, 39.35176542827061, 45.36497620173863, 48.296101570129395, 50.734429427555625, 48.249701499938965, 52.137718881879536, 47.64797707966396, 39.75609500067574, 41.514638900756836, 43.5626551764352, 48.134545530591694, 48.08182954788208, 47.89346735818045, 46.066525391169954, 36.8282596043178, 31.874579633985245, 29.31960541861398, 37.10269260406494, 35.75978299549648, 44.12411478587559, 49.25581455230713, 47.95971148354666, 49.4300024168832, 49.2492276600429, 49.340995992933, 48.5819365637643, 52.000085490090505, 46.60813052313668, 44.83350501741682, 39.64715419496809, 47.305941581726074, 54.48666858673096, 54.231291021619526, 51.119370051792686, 47.2815568787711, 46.32715579441616, 50.878330094473704, 53.723346437726704, 51.33809586933681, 44.28433677128383, 44.27394226619175, 41.84239585059029, 42.668310846601216, 40.722016198294504, 40.858207838875906, 38.764583587646484, 42.184042249407085, 43.279137407030376, 45.83077648707798, 44.53143555777413, 45.077386787959504, 44.132935523986816, 48.25781004769461, 47.325295788901194, 52.06602736881801, 51.51844678606306, 54.46715457098824, 52.25419153485979, 55.437672001974924, 54.35764748709542, 57.2765405518668, 54.579788344247, 54.681238991873606, 49.82575791222708, 51.1544827733721, 50.55489492416382, 53.81152950014387, 58.344926834106445, 69.19773510524205, 67.36618995666504, 75.13467897687639, 69.64587306976318, 75.3180627822876, 65.2764219556536, 74.95408834729875, 66.82115241459438, 88.87076732090541, 32.31430333001273, 0.4871537280934197, 0.11959034497184412, 32.1716741834368, 77.83935560498918, 52.40272317613874, 50.73810155051095, 44.7033235686166, 28.934204476220266, 66.2513792855399, 22.16731912749154, 0.7732801660895348, 0.29908165282436777, 0.09404772879289729, 0.1983431005584342, 0.05436617648229003, 0.11053247922765357, 0.10989504307508469, 0.21224226616322994, 0.16595274289803846, 0.246207734303815, 0.1757935227027961, 0.34074951122914043, 0.19616277755371161, 0.3461201430431434, 0.2334756760724953, 2.7443973081452504, 63.50431864602225, 58.8129574911935, 43.21984495435442, 54.192384583609446, 63.75692040579659, 85.17237322671073, 15.45986693246024, 0.4190074790801321, 0.8033298222082002, 1.7438900406871523, 3.303248086145946, 40.21007292611258, 93.5052296774728, 69.85594490596226, 78.9497958592006, 69.58658409118652, 76.10411943708147, 67.64720290047782, 67.70858328683036, 57.87426628385271, 56.07373094558716, 51.97640950339181, 58.69373335157122, 52.92852463041033, 55.48569795063564, 52.81102016993931, 58.937830516270225, 58.28294195447649, 61.94188417707171, 59.46150234767369, 63.73381764548165, 62.0106782913208, 60.13106550489153, 58.01353597640991, 62.52478245326451, 56.78420509610857, 56.249725341796875, 48.18745606286185, 50.731924601963584, 50.02978828975132, 46.603402273995535, 43.722526277814595, 43.77325160162789, 46.02762590135847, 43.9203519139971, 46.410631452287944, 47.76610687800816, 54.961397307259695, 58.86643082754952, 52.81651619502476, 49.61712782723563, 46.617569650922505, 48.78263528006417, 48.587710516793386, 51.62965617861067, 50.29997246606009, 52.90921558652605, 46.66585963112967, 50.14544105529785, 49.965218680245535, 52.31062132971627, 54.70064878463745, 56.97417231968471, 56.695789269038606, 57.194381577628, 57.408851623535156, 54.01551471437727, 49.772364480154856, 47.38860430036272, 38.19753762653896, 33.71868712561471, 34.187721797398154, 40.864211082458496, 47.01010813031878, 50.50965172903878, 53.442295278821675, 50.17167745317732, 53.53575897216797, 47.14690426417759, 41.63936601366316, 41.6858286176409, 44.097002914973665, 49.86139522280012, 48.31046002251761, 49.90093394688198, 47.402764729091096, 36.85930068152291, 34.16576548985073, 31.26948881149292, 37.79887778418404, 38.06185320445469, 45.698548793792725, 51.978379317692344, 51.35853746959141, 50.50713995524815, 53.41701773234776, 53.09154673985073, 50.40213877814156, 53.13553578513009, 51.160882064274375, 45.754117012023926, 42.17176130839756, 48.83137689317976, 55.77965191432408, 57.76563119888306, 52.6041271345956, 48.232327529362266, 50.207707336970735, 52.547002519880024, 55.1915841783796, 50.600152015686035, 45.95121308735439, 45.887056895664756, 43.61655930110386, 45.74296167918614, 42.756737095969065, 43.46262543542044, 41.67409658432007, 45.727456774030415, 47.49309478487287, 47.723733288901194, 45.95353031158447, 49.21731458391462, 47.30987078802926, 51.358711174556184, 49.28724820273263, 54.77697474615914, 54.013763768332346, 59.07282011849539, 54.847398212977815, 56.464421204158235, 56.75949035372053, 58.77209513528006, 55.65980591092791, 56.250910009656636, 51.21590484891619, 54.74702453613281, 54.11104549680437, 57.01628187724522, 59.993824686322895, 72.64575086321149, 70.90576907566616, 76.38197789873395, 69.9037207194737, 76.89674908774239, 66.18659428187779, 77.8082971572876, 66.77400888715471, 91.08035005841936, 31.6402724811009, 1.0527743313993727, 0.39133703815085547, 34.360325472695486, 86.50439153398786, 58.93025697980608, 59.50458812713623, 52.43929154532296, 37.3522857938494, 77.45877497536796, 28.372183799743652, 0.9847017441477094, 0.5208191073366574, 0.16982320163931164, 0.3366933917360646, 0.16543709699596676, 0.19060301088861056, 0.1747235951146909], [0.05097020710153239, 0.0503944226407579, 0.027423016527401547, 0.035394859832844565, 0.13634074186640127, 0.04522746329062751, 0.056426303793809245, 0.0935766219294497, 1.3053743541240692, 52.11677353722708, 37.43557385035923, 28.89166760444641, 48.210555349077495, 49.90061085564749, 77.09093039376395, 18.45036292076111, 0.2743972273809569, 0.403098357043096, 0.44055576995015144, 2.4778472568307603, 31.63751404626029, 84.66839953831264, 65.74316024780273, 74.24309308188302, 69.23702022007534, 73.50565297263009, 65.56407042912075, 66.76127978733608, 53.09461089542934, 51.331752164023264, 49.177880082811626, 52.37773050580706, 49.35454845428467, 50.06122541427612, 47.97695343835013, 53.45161281313215, 53.98654072625296, 58.54702908652169, 54.02224404471261, 55.00402103151594, 55.85284423828125, 54.103965282440186, 53.988524436950684, 55.16978073120117, 50.827531814575195, 50.88457652500698, 45.27577870232718, 45.32845646994454, 43.526396002088276, 41.60550396783011, 37.63833270754133, 39.321936811719624, 38.68558256966727, 42.35186208997454, 41.61661066327776, 46.97748286383492, 49.23765543528965, 49.6292176927839, 47.642053740365164, 48.03173303604126, 47.87802846091134, 42.59865862982613, 44.16956990105765, 41.03965309688023, 45.427478722163606, 44.199339457920615, 45.41753237588065, 47.246867997305735, 48.02530247824532, 49.403338704790386, 48.95679882594517, 49.583682673318044, 49.83225447790963, 52.79751634597778, 53.17142670495169, 48.64370257513863, 47.72513335091727, 43.87648793629238, 34.126977171216694, 36.76183829988752, 37.43009866986956, 43.69740506580898, 48.12988676343645, 49.27612066268921, 47.71065330505371, 46.83818537848336, 49.68500130517142, 49.44741807665144, 46.56897047587803, 43.67412860052926, 47.619340079171316, 49.56531858444214, 48.92667143685477, 45.98649603979928, 46.92540264129639, 44.68637343815395, 34.500939641680034, 30.470557144709996, 37.85551255089896, 39.70289264406477, 34.521589687892366, 44.452222619737896, 41.533485889434814, 46.38075419834682, 45.20614038194929, 45.948214939662385, 46.74459661756243, 45.43153647014073, 44.177438735961914, 42.7116710799081, 36.80838080814907, 43.92956869942801, 48.99828651973179, 48.86059406825474, 46.06010178157261, 42.78101062774658, 39.69675391060965, 45.229847635541645, 51.016957078661235, 53.625640869140625, 49.7714056287493, 45.26771184376308, 40.734064374651226, 40.047954082489014, 37.850235394069124, 36.94896023614066, 36.531099046979634, 40.28619738987514, 41.77629763739449, 42.673358712877544, 42.127661091940745, 42.968698842184885, 43.15632104873657, 42.8575485093253, 46.261603014809744, 47.71564558574131, 47.56743008749825, 51.35752303259713, 49.899412291390554, 52.04892437798636, 51.091594627925325, 53.235006196158274, 52.172720432281494, 53.083045618874685, 52.1295165334429, 53.91185801369803, 47.67899036407471, 49.59429257256644, 49.80413511821202, 61.104362215314595, 65.34249932425362, 69.58535426003593, 64.75373676845005, 71.04339204515729, 68.47826998574394, 73.57104941776821, 66.84274741581508, 79.77809756142753, 43.62927450452532, 0.2267808017453977, 0.08463427677218403, 35.79822390420096, 68.7711296081543, 47.477419648851665, 46.69288812364851, 31.531338623591832, 36.81062160219465, 58.595520564488, 16.937455211366924, 0.5896463883774621, 0.11158272251486778, 0.011703245624500726, 0.040648885403892825, 0.026179478969424963, 0.04288263964865889, 0.03703978138842753, 0.07720511220395565, 0.060671839730015824, 0.12601350673607417, 0.08355297693716628, 0.03875978623649903, 0.05454280932566949, 0.07821905386767217, 0.17483924462326936, 2.6260362650666917, 61.30760397229876, 39.44040012359619, 36.33589635576521, 56.35806165422712, 53.199334144592285, 85.02255616869245, 19.832536799567087, 0.20134257817906992, 0.4769413418003491, 0.1159007293837411, 1.829186452286584, 34.999115058353965, 87.32684285300118, 67.90018681117466, 77.2908022744315, 70.2749490737915, 77.81945596422467, 67.41415337153843, 69.71858596801758, 55.270696367536274, 53.87147160938808, 50.43448959078108, 55.1640693119594, 51.429645333971294, 51.98916987010411, 51.44103690556118, 56.654294627053396, 56.027310030800955, 61.149080821446006, 55.56374706540789, 58.12375177655901, 57.41330541883196, 55.155325004032676, 55.8811685698373, 57.81038802010672, 52.66963822501046, 54.30767604282924, 47.82766791752407, 48.18869284221104, 46.188407216753276, 43.73959452765328, 39.7312273979187, 41.80624784742083, 42.06852149963379, 44.067848273685996, 42.79450402941023, 47.835237979888916, 51.95202480043684, 51.74559729439871, 49.67128208705357, 49.60263041087559, 48.61350917816162, 44.23287146432059, 46.33282552446638, 43.61899811880929, 47.506925174168174, 46.08783204214913, 46.44045659473964, 49.021896498543875, 50.77880409785679, 52.76913642883301, 51.92304039001465, 52.60137217385428, 53.87648473467146, 54.71664006369454, 53.650286129542756, 51.232476302555625, 49.01323209490095, 45.60675266810826, 36.444791998182026, 39.46072360447475, 39.054886272975374, 44.91685560771397, 51.28679731913975, 48.59013543810163, 49.17366600036621, 49.376959868839805, 50.33937222617013, 54.03072084699358, 46.6222562108721, 45.13619634083339, 49.131497383117676, 49.601880005427766, 50.02531017575945, 46.616343293871196, 50.137700762067524, 46.98935386112758, 37.3132403918675, 32.360435894557405, 37.5558054787772, 39.35065024239676, 35.42786407470703, 44.07062407902309, 43.4753406388419, 49.16540459224156, 47.01427704947335, 48.17978177751814, 49.128016335623606, 46.094026361192974, 46.329750946589876, 42.94750336238316, 37.83231251580374, 46.011585984911235, 48.5345116342817, 50.896433625902446, 48.21709360395159, 44.82669578279768, 42.45902068274361, 46.740358216421946, 53.060592515128, 55.39075081689017, 50.38942704881941, 47.52580690383911, 42.54453216280256, 43.619922229221885, 40.26699604306902, 40.355606419699534, 38.4108681678772, 41.646995135716026, 42.73676797321865, 45.18587943485805, 45.740241459437776, 46.32177094050816, 44.72214623859951, 45.97109883172171, 49.99246951511928, 50.443046297345845, 49.83177505220686, 53.59098672866821, 51.721949100494385, 55.307664258139475, 53.95173372541155, 55.94786432811192, 54.30627598081316, 57.25850302832467, 54.34416103363037, 56.47469411577497, 49.97487667628697, 51.404607500348774, 52.49776063646589, 63.840000016348704, 68.21113954271588, 70.05182157244, 67.78722299848283, 74.0497386114938, 70.12013626098633, 77.66450418744768, 69.94864777156285, 81.96608529772077, 49.290781361716135, 0.5854264976722854, 0.07329915929585695, 40.71289668764387, 75.8941240310669, 54.91680029460362, 50.6344552721296, 32.39200850895473, 46.15125519888741, 67.20629801068986, 22.016009943825857, 0.8262601260628019, 0.2184087381299053, 0.07009390236011573, 0.07226036967975752, 0.014584082245294536, 0.025323805598808185, 0.056422788982412646, 0.18632015213370323, 0.21184488891490869, 0.20973723701068334, 0.23191138144050324, 0.3050996613289629, 0.10949192542050566, 0.3441405849797385, 0.2883702447371823, 3.5663429285798753, 71.74506282806396, 51.17449358531407, 37.81857245309012, 64.85881437574113, 61.12991768973214, 92.84526198250907, 21.90989531789507, 0.4054410399070808, 0.9587128758430481, 0.7326078542641231, 3.037190705537796, 35.66256380081177, 94.19258717128209, 69.0313743863787, 81.57627746037075, 72.5720443725586, 77.4949403490339, 70.292861529759, 71.52846663338798, 57.891271999904085, 56.956902572086875, 54.31315817151751, 58.43715722220284, 55.011785643441335, 54.57116910389492, 52.423216887882774, 60.2194813319615, 58.826680183410645, 64.99548544202531, 57.116117068699424, 61.711287362234934, 60.21026802062988, 59.07986559186663, 60.04035677228655, 59.94044862474714, 53.88994686944144, 56.931110858917236, 49.657507283346995, 50.92531728744507, 47.496019976479666, 44.60019493103027, 41.95066615513393, 45.05422149385725, 45.288233348301475, 48.0114859853472, 47.13534593582153, 51.095402240753174, 53.53971944536482, 55.14406892231533, 53.620728492736816, 51.956985814230784, 49.69925900868007, 46.70917122704642, 49.42896713529314, 44.73263454437256, 48.810441970825195, 49.5605069569179, 47.88790185110909, 52.36845118658883, 54.12417411804199, 55.5735752923148, 55.49711384092058, 55.55455807277134, 56.79288339614868, 58.49531364440918, 57.081268378666465, 54.092035225459504, 50.71912949425833, 49.108377252306255, 38.06099162782942, 39.09963614600045, 39.52265289851597, 46.532770361219136, 53.14542654582432, 53.275437763759065, 52.73059129714966, 51.97894212177822, 53.041867119925364, 56.24354491915022, 47.90940652574812, 47.12527104786464, 50.244557108197895, 52.79288189751761, 53.3018478666033, 49.0172689982823, 52.554829665592735, 48.68775068010603, 36.836858000074116, 33.79853582382202, 40.236104352133616, 39.92078815187727, 38.60294416972569, 43.79991183962141, 43.65939841951643, 50.2639981678554, 47.69865376608712, 49.761848381587434, 51.528535570417134, 49.86137785230364, 45.86606986182076, 44.811496598379954, 37.57391595840454, 48.742269720349995, 50.14856774466378, 52.349343640463694, 50.52879401615688, 46.492592402866904, 44.30278076444353, 48.614617415836875, 56.40938452311924, 58.26699236461094, 52.39213064738682, 49.648384298597065, 46.41785410472325, 44.281609603336875, 43.026942116873606, 41.76439189910889, 41.96807139260428, 44.11526625497, 46.58016402380807, 47.701224599565776, 47.77697038650513, 47.87881360735212, 47.6839131627764, 47.29313605172293, 52.766207763126914, 52.905522618974956, 51.6040346963065, 55.733439445495605, 55.486635957445415, 58.243695054735454, 56.249732289995464, 59.308433532714844, 57.1908414704459, 58.95253985268729, 57.679397106170654, 59.83013207571847, 53.3755647795541, 54.3129358291626, 54.53409699031285, 69.334121295384, 71.14618369511196, 75.78616292136056, 69.97962978907994, 75.73745604923793, 74.43438393729073, 78.5567432131086, 73.03576019832066, 83.52938829149518, 49.96348857879639, 1.1222203820943832, 0.20061489008367062, 44.158807141440256, 83.81548731667655, 61.95601681300572, 64.30627972739083, 42.27293055398123, 51.07079866954258, 80.22552680969238, 26.41939605985369, 0.9029450054679597, 0.3294145294598171, 0.17967249027320317, 0.21237838028797082, 0.11158258002251387, 0.11022936406412295, 0.2075703354286296], [0.05098043601693852, 0.05900595483503171, 0.022765828662418892, 0.05265880595626576, 0.020562065665477088, 0.04857361463031598, 0.03375060324157987, 0.12434266853545393, 1.6135535602058684, 57.30334322793143, 41.31244632175991, 19.400567293167114, 35.443104948316304, 51.85048730032784, 74.56964451926095, 16.07005599566868, 0.17554124338286264, 0.4352220504411629, 0.22779180535248347, 0.3433353810438088, 40.87869807652065, 76.78789860861642, 63.57567664555141, 74.8971061706543, 70.21770286560059, 69.88571098872593, 64.39448016030448, 64.68615858895438, 51.60440295083182, 48.58478879928589, 48.845308031354634, 51.699798243386404, 50.085950578962056, 48.02537543433053, 48.40701913833618, 52.437384264809744, 54.12697771617344, 55.374481609889436, 52.77979843957083, 55.161644390651155, 50.59480537687029, 52.62675394330706, 53.28178494317191, 54.67118494851248, 51.984024729047505, 53.29714046205793, 47.12718875067574, 45.35510628564017, 46.48746115820748, 43.29055677141462, 38.90719536372593, 38.46700266429356, 37.794635908944265, 39.73328406470162, 38.15641123907906, 44.56422758102417, 45.36227682658604, 47.938147749219624, 48.34975208554949, 47.70541436331612, 42.38358061654227, 44.10258231844221, 43.44210740498134, 41.89528553826468, 43.689744676862446, 45.20394475119454, 44.86138813836234, 47.24400533948626, 47.84364530018398, 50.237018312726704, 49.43347304207938, 49.3645156451634, 47.702047961098806, 50.7937079838344, 50.91253955023629, 52.48275252750942, 48.044041769845144, 42.45208290645054, 40.025111879621235, 40.46641281672886, 42.462453092847554, 48.212552956172395, 47.72029045649937, 44.45425149372646, 46.08006395612444, 47.59203365870884, 47.47583545957293, 48.1482195854187, 48.303647313799175, 48.240053926195415, 46.89788430077689, 47.428198610033306, 46.97408866882324, 47.08467967169625, 46.45532921382359, 47.53587484359741, 44.51212303979056, 38.179447991507395, 36.263895647866384, 41.276805537087576, 36.36997379575457, 38.20429474966866, 45.13925354821341, 43.964420863560264, 47.54327814919608, 48.51872532708304, 47.60985926219395, 46.12901748929705, 46.88876826422555, 44.74061107635498, 41.65315818786621, 45.353431769779746, 45.93857431411743, 43.83549703870501, 41.00005183901106, 43.474590233394075, 42.64919982637678, 42.41858564104353, 44.70469583783831, 51.16377946308681, 52.05761310032436, 47.50671672821045, 38.11707053865705, 38.58597666876656, 36.81523520605904, 37.33000986916678, 36.275002343314036, 41.21765204838344, 41.0892528125218, 42.44400215148926, 43.07844911302839, 46.89900990894863, 45.894276074000764, 47.407461711338584, 43.5053186416626, 47.9420804296221, 49.6373644556318, 49.489861147744314, 52.77474709919521, 52.182659830365864, 50.28752129418509, 53.11709874016898, 55.1925048146929, 55.26956728526524, 53.536123752593994, 53.88055637904576, 49.24254696709769, 50.75317914145333, 49.377116203308105, 50.92474058696202, 54.30093281609671, 62.119834491184776, 65.39967605045864, 66.75162873949323, 65.67497757502964, 68.51217719486782, 67.19618838174003, 72.42219257354736, 57.707318442208425, 1.349168741277286, 0.09791744114564997, 37.261163643428254, 65.78540529523576, 52.21202291761126, 44.8288254056658, 39.306466647556846, 25.960540499005997, 61.4092561176845, 20.38358279636928, 0.6046334356069565, 0.10360670621906008, 0.10634242370724678, 0.0766812695988587, 0.014079260673107845, 0.02073154166074736, 0.039569007099739144, 0.10873867012560368, 0.014026533413146223, 0.07851327343710832, 0.041483938095292876, 0.08074823886688266, 0.06489536738289253, 0.10009556569691215, 0.1534926686435938, 2.6745594441890717, 65.89657647269112, 46.996951716286794, 24.787144354411534, 42.03902987071446, 58.346802847726, 80.32299613952637, 19.163024016789027, 0.21808559261262417, 1.3355057601417815, 0.3690040351024696, 0.5108877431069101, 44.55478845323835, 78.82936968122209, 66.45487117767334, 76.79693821498326, 71.96173545292446, 71.1321552821568, 66.4056292942592, 67.05721746172223, 53.21225084577288, 52.9101813861302, 51.94749457495553, 53.53792333602905, 52.391404560634065, 51.96877343314034, 50.378122329711914, 55.669321468898225, 56.00880350385393, 57.56846216746739, 53.74587597165789, 57.97555364881243, 53.45467349461147, 56.36989443642752, 54.749376501355854, 57.7568347794669, 54.37023067474365, 54.80867937632969, 49.104149273463655, 47.51021862030029, 47.50746365955898, 45.860052721840994, 41.529858929770334, 41.43733671733311, 40.17736775534493, 43.06681088038853, 40.42247935703823, 46.700413022722515, 47.753131117139546, 50.17599923270089, 50.66172695159912, 49.718373503003804, 44.478841168539866, 46.67993320737566, 46.250096797943115, 45.25483683177403, 44.334304741450715, 47.78682293210711, 48.85220411845616, 51.36203588758196, 52.583807127816335, 51.727299213409424, 53.69156190327236, 53.893160411289756, 51.94089726039341, 53.81299557004656, 50.783205781664165, 54.12797130857195, 49.53935316630772, 43.66890702928816, 42.065318380083355, 41.50681522914341, 43.15218687057495, 50.97913803373064, 48.545347349984304, 48.72745268685477, 47.72124235970633, 51.0941480909075, 50.63780777794974, 49.69389499936785, 50.67867708206177, 49.898133822849815, 48.55182307107108, 47.83030475888933, 48.57895231246948, 50.586266040802, 46.73638037272862, 48.972237723214285, 44.70728404181344, 38.87621334620884, 37.129338945661274, 40.524614402226035, 35.49839176450457, 40.95546177455357, 45.89992495945522, 45.21148354666573, 49.73469134739467, 50.11305202756609, 49.504045895167756, 48.34302622931344, 48.385479722704204, 47.49335881641933, 44.958013262067524, 46.003859588078086, 46.81886938640049, 46.0310617855617, 43.05632257461548, 45.94153077261788, 43.875532558986116, 43.50194876534598, 45.99361099515642, 52.84037978308541, 53.43847724369594, 49.356681551252095, 40.43669884545462, 40.2159024647304, 39.413656507219585, 39.29594707489014, 39.2205764906747, 42.18230519975935, 43.15057141440255, 44.15714652197701, 45.33804498400007, 50.80093758446829, 48.189818450382774, 48.03688512529646, 46.924534116472515, 50.34148447854178, 50.835153988429475, 52.80804981504168, 52.90262174606323, 54.94951936176845, 53.91642298017229, 57.14408704212734, 56.23684338160923, 56.59105907167707, 55.32933221544538, 57.5822890826634, 52.91050795146397, 53.303015163966585, 51.817313126155305, 52.849183150700156, 54.976394993918284, 63.05955750601632, 68.0725577218192, 69.49379089900425, 68.35535635266984, 69.76295716421944, 71.0914249420166, 76.32234845842633, 66.0723658970424, 2.0455357687813893, 0.15066597318010672, 41.04256091799055, 73.181533404759, 58.352729661124094, 53.5084490776062, 36.23409135001046, 30.633238792419434, 69.78091825757707, 24.78207564353943, 0.4971848098295075, 0.23080336089645112, 0.1650053315929004, 0.08419869121696268, 0.09595511108636856, 0.06991108467004128, 0.08223018648901156, 0.2608626250709806, 0.12946327376578534, 0.2115619940949338, 0.21599965382899555, 0.18775834781782968, 0.2539685735745089, 0.3955028903271471, 0.32622487204415457, 4.635722151824406, 77.10905824388776, 55.60022858210972, 25.43688256399972, 48.3422897202628, 64.26915550231934, 84.36218547821045, 20.241948979241506, 0.25898520009858267, 2.5213180099214827, 0.4275161996483803, 0.9366310664585659, 47.82040357589722, 81.25736209324428, 67.51918928963798, 77.86969144003731, 72.51207447052002, 74.80081108638218, 67.97121129717145, 72.44492013113839, 55.1880510193961, 55.36737707683018, 53.76581730161394, 56.402783734457834, 54.18233748844692, 54.20055219105312, 52.09258338383266, 59.63417897905622, 58.767974853515625, 60.885264669145855, 56.83999913079398, 62.16806888580322, 55.383340563092915, 57.632840701511924, 58.4235873903547, 61.366566385541645, 56.52519709723336, 58.27872439793178, 51.5850487436567, 50.97995444706508, 49.46426745823452, 48.57940741947719, 43.494538511548726, 43.46302843093872, 41.528410230364116, 43.88448878696987, 42.586332525525776, 50.995792865753174, 51.32956000736782, 53.912952354976106, 50.75177560533796, 50.96333088193621, 45.33764893668038, 47.54159321103777, 48.2423746245248, 46.37558821269444, 47.710872173309326, 50.79994051797049, 51.31673015866961, 54.05035298211234, 56.50536346435547, 54.2591289792742, 57.28981161117554, 55.36031075886318, 53.88664994921003, 57.98822716304234, 56.331523009708945, 56.665818214416504, 53.22694975989205, 45.87668323516846, 43.325624329703196, 44.465521471840994, 44.455849579402376, 53.81954424721854, 53.67792953763689, 51.514875411987305, 51.604889324733186, 54.361736501966206, 54.09016963413784, 52.211387157440186, 51.243100098201204, 50.585470472063335, 51.70007617133004, 52.46634088243757, 51.585125173841206, 53.65501437868391, 50.27480261666434, 53.42500468662807, 45.648733683994834, 39.72483158111572, 37.078109877450125, 41.5065199307033, 36.902403831481934, 43.26169742856707, 47.53369310923985, 47.42338350840977, 51.93413666316441, 53.02371147700718, 52.56455019542149, 51.95262929371425, 49.388323647635325, 48.861059597560335, 45.3023555619376, 48.867010729653494, 49.20684364863804, 48.26823581968035, 44.97935812813895, 50.70713342939104, 44.885748522622244, 47.17393275669643, 49.21943031038557, 55.248736585889546, 56.41730546951294, 51.597788265773225, 42.1559784752982, 42.82233503886631, 41.97352572849819, 41.47460338047573, 41.816347054072786, 44.16523422513689, 45.68285281317574, 46.53800582885742, 47.88116209847586, 54.08911003385271, 51.754834924425396, 51.37942722865513, 48.734112535204204, 54.01863445554461, 53.072890826633994, 53.94465698514666, 57.618906089237754, 57.73422186715262, 56.497564111437114, 59.92076437813895, 59.14204502105713, 59.73601177760533, 59.10000841958182, 60.82045187268938, 55.66418675013951, 56.16054173878261, 53.886660371507915, 55.843544074467246, 60.29429258619036, 67.5680490221296, 72.00267423902238, 73.04104777744838, 72.72515487670898, 72.26550374712262, 74.00520065852574, 77.66567148481096, 66.77233437129429, 2.8570317327976227, 0.22817658899085863, 45.85692950657436, 80.37856088365827, 65.66994013105119, 60.885841369628906, 52.05921466009957, 35.61085530689785, 80.91173090253557, 29.429025650024414, 0.49338202817099436, 0.4260529524513653, 0.23950836807489395, 0.13527287702475274, 0.12118984200060368, 0.23203338203685625, 0.11166772938200406], [0.050505651493689845, 0.005606755639226841, 0.04969550443014928, 0.03407206938468984, 0.05616126801552517, 0.015163849706628492, 0.07070236506738833, 0.24620189890265465, 3.272187032869884, 61.17758233206612, 41.74426644189017, 39.78168174198696, 39.39665426526751, 48.125283581869944, 72.45379992893764, 25.29895387377058, 0.22558419166931085, 0.22814296079533442, 0.37100294498460634, 1.7264001220464706, 59.19785295213972, 73.83710289001465, 68.86937713623047, 69.59309455326625, 66.06327070508684, 69.45246301378522, 67.09692641666958, 57.162082876477925, 46.743332045418875, 50.72649458476475, 56.172565596444265, 58.320316314697266, 54.99726390838623, 55.609973430633545, 55.69572114944458, 55.81546640396118, 52.250762598855154, 52.69043418339321, 51.4328692981175, 53.471484661102295, 50.99387863704136, 54.11662837437221, 52.83236156191145, 53.83384711401803, 52.99162817001343, 52.477774143218994, 47.02596391950335, 44.832917894635884, 41.985740661621094, 43.51358699798584, 40.60255581992013, 39.33361325945173, 38.79619789123535, 39.8158529826573, 39.36053058079311, 42.93456581660679, 42.28607307161604, 48.39596108027867, 45.50271034240723, 42.34947885785784, 42.86983987263271, 44.01989180701119, 42.22198288781302, 43.8301990372794, 43.719917229243684, 45.825916222163606, 46.19124902997698, 45.944365637642996, 45.4872054372515, 49.53970405033657, 48.10851410457066, 49.83211898803711, 47.97764825820923, 49.39761338915144, 49.98964507239205, 51.825897625514436, 47.20155184609549, 41.29709080287388, 35.846430506025044, 41.39001601082938, 44.75302403313773, 43.1135653087071, 47.45569263185774, 46.247136865343364, 45.089959553309846, 46.52227858134678, 47.727499212537495, 47.759895188467844, 50.92167295728411, 49.36274038042341, 47.84196383612496, 45.59429802213396, 45.80776752744402, 44.192665713174, 47.527894837515696, 42.95489624568394, 46.43140656607491, 40.696419034685405, 37.139115061078755, 39.337330545697895, 41.360420158931184, 40.0131436075483, 41.25753123419625, 49.09852123260498, 45.72920772007534, 48.92284297943115, 47.69919572557722, 46.04821341378348, 46.56098352159773, 46.165589332580566, 43.5640413420541, 43.145328998565674, 40.62403270176479, 40.70284264428275, 39.297093527657644, 43.20574705941336, 43.03722892488752, 45.0161349432809, 46.29610082081386, 48.47540330886841, 49.701885427747456, 45.27201277869088, 40.875699928828645, 37.609713077545166, 37.47021756853376, 35.08784702845982, 37.988546235220774, 41.65688589641026, 42.545796734946116, 45.315897600991384, 49.01870380129133, 53.90675803593227, 52.20419577189854, 54.8964455468314, 50.224858965192524, 47.748232637132915, 47.08371039799282, 50.813597202301025, 47.72420924050467, 52.514099325452534, 50.560286726270405, 52.98871687480381, 51.32724625723702, 52.6341746194022, 53.325106961386545, 53.70762613841465, 50.471044063568115, 50.038518701280864, 49.245802198137554, 50.7893271446228, 48.05777488436018, 53.50154604230608, 54.64865888868059, 59.292327608381, 60.80006585802351, 66.39137853894914, 65.9031981059483, 72.25502586364746, 61.40309306553432, 2.320552851472582, 0.4400627464056015, 31.35184233529227, 66.76039041791643, 46.97787891115461, 37.58328560420445, 34.959155968257356, 38.01063455854143, 60.24664878845215, 21.1243736743927, 0.48928812784808023, 0.08770838645952088, 0.09025931172072887, 0.054221010700400384, 0.030503436590411832, 0.06556037919861929, 0.04964983563071915, 0.05481958036710109, 0.05882803616779191, 0.04248214113925185, 0.05848184760127749, 0.02088978111610881, 0.01074616180267185, 0.07782420076962028, 0.17356468444424017, 4.416191211768559, 70.90216990879604, 45.8627416746957, 45.08273342677525, 48.89694356918335, 54.13206727164132, 76.75943878718785, 29.50001539502825, 0.3418216508414064, 0.6171042578560966, 0.4297969729772636, 2.63998064824513, 65.60989379882812, 76.40571989331926, 72.83971677507672, 72.93521281651088, 69.72701413290841, 69.26229776654924, 69.75116607121059, 61.55420248849051, 49.34370231628418, 54.042824608939036, 58.389645440237864, 60.71627753121512, 59.24299539838518, 57.753332887377056, 59.73274612426758, 58.635521343776155, 56.01884365081787, 55.31824289049421, 54.874530928475515, 56.96192264556885, 54.438833713531494, 55.80943536758423, 55.28368602480207, 56.462861333574565, 55.35647187914167, 53.847934586661204, 48.031198024749756, 46.578124727521626, 45.02450057438442, 46.72392225265503, 43.67610536302839, 41.60325622558594, 39.811305386679514, 40.89612068448748, 41.60455901282174, 44.07310458592006, 44.41170767375401, 49.37557370322091, 47.059422969818115, 42.21607344491141, 44.18880598885672, 44.63239983149937, 45.25596938814436, 46.76566008159092, 44.66529607772827, 48.23102126802717, 48.26943090983799, 48.60935068130493, 47.660240650177, 51.81226873397827, 50.508765833718435, 52.59954479762486, 50.93193197250366, 50.015666076115195, 53.17283718926566, 52.99092640195574, 49.4828782081604, 42.89443302154541, 38.60540035792759, 44.5943341255188, 46.770061765398296, 45.59930419921875, 48.87325368608747, 49.23895474842617, 50.32835585730416, 48.0556070463998, 51.34514134270804, 47.73751851490566, 51.28517838886806, 51.4819062096732, 49.36914314542498, 49.024752208164756, 47.31865678514753, 46.02566998345511, 48.78190919331142, 47.0809554372515, 48.333274432591026, 40.364635603768484, 38.57215322766985, 40.977918352399556, 42.365133149283274, 42.371549810682026, 43.41718421663557, 51.90499244417463, 47.641028881073, 50.622473103659495, 50.12738616125924, 48.31167248317173, 47.667206219264436, 48.31286757332938, 45.658356939043315, 45.304030077798025, 41.78327015468052, 42.59859957013811, 40.4009746823992, 44.34194081170218, 44.556376116616384, 47.85674612862723, 47.415969780513215, 49.208570275987896, 52.51836551938738, 46.25620426450457, 42.857013498033794, 40.5777507509504, 40.051626205444336, 37.78065960747855, 39.924164976392476, 43.981975487300325, 44.76142093113491, 47.938422203063965, 52.213607106889995, 56.05926479612078, 55.78107976913452, 55.774221897125244, 52.39826243264334, 50.73524236679077, 51.44325338091169, 52.7291009085519, 51.760125977652415, 55.745067255837576, 54.05574131011963, 55.00891951152256, 53.24292366845267, 54.28002916063581, 55.89962993349348, 56.08254820959908, 53.69924661091396, 53.42399719783238, 51.79459251676287, 52.82251249040876, 50.31557812009539, 55.917969703674316, 57.09350068228585, 61.46338953290667, 63.527949469430105, 69.85904380253383, 71.03409535544259, 74.69804722922188, 68.49730804988316, 3.609996940408434, 0.31164806708693504, 34.09306648799351, 75.2066206250872, 53.17238555635725, 45.93489176886422, 34.02402918679373, 36.84663758959089, 69.41962582724435, 26.67435325895037, 0.2638361283711025, 0.1414228334490742, 0.01613581719409142, 0.127981746835368, 0.03541389274011765, 0.09866338861840111, 0.06611338523881775, 0.1406721972993442, 0.15952442426766666, 0.15483375239585126, 0.14319638828081743, 0.12131775942231927, 0.08425825980624982, 0.21704709476658277, 0.3035831084208829, 5.6526826449802945, 81.77737917218889, 56.21941382544381, 51.20927626746041, 53.590747015816824, 59.827241625104634, 84.39118725912911, 32.29995877402169, 0.4886872172355652, 1.5858815993581499, 0.6406366665448461, 2.945062586239406, 66.63823413848877, 78.48995018005371, 71.60952431815011, 75.63507434300014, 71.80235072544643, 74.38571875435966, 71.25722285679409, 64.30256938934326, 50.90551144736153, 55.48157072067261, 61.59627383095877, 63.731087003435405, 60.766617230006624, 59.22977992466518, 61.79487419128418, 61.416676793779644, 56.61023262568882, 57.75329119818551, 57.59046711240496, 59.46528911590576, 56.606932231358115, 58.83182879856655, 56.8949350629534, 59.88988658360073, 57.90700966971261, 56.84435912540981, 49.097135066986084, 50.16963120869228, 45.74288524900164, 47.9240984916687, 44.68219409670149, 45.265200069972444, 43.52266829354422, 43.41688196999686, 44.432851042066304, 47.35998119626726, 46.481110504695344, 51.53536912373134, 48.84736817223685, 46.66238900593349, 47.439690930502756, 48.239772524152485, 47.73304040091378, 49.51312371662685, 47.60582930701119, 52.35054220472063, 51.65066058295113, 53.550471782684326, 50.529749393463135, 54.92762558800833, 55.44101755959647, 56.34229966572353, 54.165491580963135, 52.95255497523716, 54.15387766701834, 55.579960686819895, 52.40484585080828, 45.580109800611226, 39.30303771155221, 45.25188037327358, 47.62858465739659, 49.165144034794395, 52.31209782191685, 51.04400641577584, 51.88940763473511, 51.18137230191912, 53.555068016052246, 50.79882880619594, 54.602766036987305, 52.92506790161133, 52.162551743643625, 51.25942489079067, 50.720960344587056, 47.98454434531075, 52.48611545562744, 50.15445286887032, 52.630189827510286, 42.48757777895246, 37.18836389269148, 40.44644021987915, 43.63182101930891, 45.36041470936367, 46.597468512398855, 53.23237977709089, 50.33147212437221, 54.35599381583077, 52.86393070220947, 50.8930880682809, 50.67582484654018, 51.51208918435233, 47.70440687452044, 46.10949305125645, 43.228450298309326, 44.677861894880024, 42.77247129167829, 48.53218051365444, 47.82076140812465, 50.11709240504673, 49.45152793611799, 52.76294558388846, 55.40975414003645, 48.06591122491019, 46.1122202192034, 42.45842661176409, 42.794382435934885, 39.82319722856794, 42.518868991306846, 48.05850444521223, 46.49931825910296, 49.62903356552124, 55.01017713546753, 58.20303419658116, 57.22038868495396, 59.17970425742013, 55.067360809871126, 51.49850198200771, 54.74173348290579, 55.579592432294575, 54.383918625967844, 59.260609081813264, 56.548355443137034, 58.426227705819265, 58.462038721357075, 57.687766211373464, 58.73583943503243, 57.71662555422102, 55.65426124845232, 56.917721680232454, 54.93001924242292, 55.77007382256644, 52.1682562146868, 57.51555858339582, 60.86851256234305, 66.50183405194963, 67.99432100568498, 72.64547293526786, 74.57009615216936, 76.71639469691685, 71.22589342934745, 4.83881539106369, 0.42957707334842, 39.563970361437114, 81.7773722239903, 60.871673992701936, 54.584902218409944, 48.654371534075054, 51.630983284541536, 79.73696422576904, 35.479308537074495, 0.48496993098940167, 0.281338342066322, 0.1004531875784908, 0.21404783427715302, 0.06326943462980644, 0.17635571610714706, 0.1765739465398448], [0.07834776517535959, 0.017313284100964665, 0.0564544867458088, 0.041700774138527255, 0.05956825680498566, 0.16852494701743126, 0.035727128253451416, 0.03343760521550264, 2.7253451304776326, 58.57236221858433, 40.01485286440168, 25.007238967078074, 47.48470483507429, 46.89861733572823, 64.23296928405762, 41.31038965497698, 0.3725340728248869, 0.5801896186811584, 0.6289725410086768, 10.10211099897112, 82.12904139927456, 67.69165747506278, 70.40381036485944, 66.94321836744035, 68.22009577069963, 66.04783875601632, 57.770387240818565, 48.85940245219639, 51.82402856009347, 62.34079415457589, 64.95570700509208, 62.26664297921317, 61.96718256814139, 57.779520647866384, 57.50718947819301, 56.243173190525596, 57.336083139692036, 55.10567317690168, 54.5776344026838, 53.61455501828875, 56.527191230228965, 56.38562863213675, 57.50805452891758, 56.02953345435006, 55.09210681915283, 54.40432895932879, 50.05879354476929, 44.58138268334525, 44.659185137067524, 44.454880305698936, 41.4162141936166, 39.606656619480674, 40.31171464920044, 39.45539781025478, 38.9916159766061, 37.826931135995046, 39.34785706656319, 42.36832932063511, 43.01805884497506, 39.99067660740444, 40.960429736546104, 41.44054331098284, 40.98200389317104, 41.52584981918335, 42.84554549625942, 43.8278158051627, 45.46853910173689, 46.51604604721069, 46.86791672025408, 48.86941133226667, 50.225560733250205, 49.967438629695344, 50.022767135075156, 48.91423068727766, 46.615853445870535, 45.06834718159267, 43.408109869275776, 41.5732295853751, 41.69614321844918, 45.22179814747402, 42.907103061676025, 44.28850221633911, 46.52530104773385, 45.76047461373465, 45.625214031764436, 45.037743840898784, 45.970699310302734, 48.178013460976736, 48.168365887233186, 46.424284662519185, 48.079355989183696, 48.08563716070992, 45.5889652797154, 44.3626047543117, 45.281288623809814, 43.50015960420881, 43.19812488555908, 44.81973368780953, 40.22292709350586, 39.35344689232962, 38.74482985905239, 45.34778635842459, 42.77228021621704, 45.40575170516968, 50.519896847861155, 47.02634954452515, 46.73219755717686, 47.59633111953735, 46.38302625928606, 45.225977488926475, 44.477885791233604, 44.8724079813276, 42.82313060760498, 40.71938977922712, 38.51979507718767, 41.47619799205235, 40.53893116542271, 42.383260999407085, 43.562495367867605, 42.774899687085835, 43.99190446308681, 41.85874148777553, 38.99769565037319, 35.659860951559885, 37.23596600123814, 35.63674429484776, 37.27751275471279, 41.41337932859148, 42.111805302756174, 48.99640008381435, 54.24879700796944, 57.62311322348458, 55.383312770298545, 56.39136437007359, 54.145202841077534, 53.087495940072195, 52.14302035740444, 52.36934750420706, 52.55858516693115, 53.471182414463584, 52.35873065676008, 54.000461442129954, 55.90006767000471, 54.899082388196675, 52.569587639399934, 52.450637953622, 52.01265478134155, 53.72121681485857, 51.337289878300254, 53.63413156781878, 51.64994491849627, 54.405708176749094, 51.990910393851145, 55.87051003319876, 53.77895287105015, 64.68877111162458, 68.1959924697876, 68.92180129459926, 63.526886395045686, 4.078491824013846, 0.5854098328522274, 27.14798069000244, 67.84690107618059, 47.223577635628835, 35.91158376421247, 33.74508680616106, 32.93326275689261, 57.698664460863384, 17.047019617898123, 0.4521552989525454, 0.15919941956443445, 0.0735041650810412, 0.03491271320464356, 0.12043345187391553, 0.06631595508328506, 0.04571937403774687, 0.015179683321288653, 0.028460771377597536, 0.0030154490627215375, 0.02036583673075906, 0.035269181576690505, 0.08360913249530963, 0.008629123214632273, 0.07349511342389242, 3.337162026337215, 66.62247562408447, 43.575967924935476, 26.030354261398315, 50.06306668690273, 54.83939388820103, 68.66079916272844, 47.20983757291521, 0.28458613636238234, 0.968953434910093, 0.6171691258038793, 12.223348259925842, 87.2443607875279, 68.84454427446637, 72.9856984274728, 70.51611409868512, 71.46280615670341, 67.68310424259731, 60.83053370884487, 49.89818593433925, 55.53849383762905, 65.20746108463833, 66.63471835000175, 64.4928458077567, 64.08906514304024, 60.57923821040562, 61.312516348702566, 59.735254423958914, 60.8100643157959, 58.40543174743652, 55.80841398239136, 56.19439336231777, 60.18424006870815, 60.187408447265625, 59.52202810559954, 59.729820932660786, 59.02089623042515, 56.378062043871196, 52.03386415754046, 47.20924002783639, 48.04528202329363, 45.84357506888253, 43.83110230309622, 41.53745331083025, 41.34783697128296, 42.64053542273385, 42.928180422101704, 40.38296495165144, 41.94983237130301, 43.516988141196116, 44.52082913262503, 44.21376739229475, 43.06205136435372, 42.04234068734305, 43.23981407710484, 43.55267756325858, 43.622899532318115, 47.71788985388619, 46.46349682126726, 49.78857115336827, 50.1637738772801, 51.85161985669817, 52.974011012486045, 51.84193754196167, 53.27019534792219, 51.449145453316824, 50.648396832602366, 48.782444204602925, 44.68508802141462, 45.43418720790318, 43.52325889042446, 47.64235598700387, 46.571895667484824, 45.40375757217407, 47.57726526260376, 48.13494157791138, 47.82232127870832, 47.47415746961321, 48.23417227608817, 49.91557380131313, 49.18585314069475, 49.333519731249126, 49.83299446105957, 49.15203973225185, 48.56130736214774, 47.49518966674805, 47.32794305256435, 46.14583212988717, 46.54964753559658, 45.05028533935547, 42.44034392493111, 38.41613490240914, 37.71588850021362, 47.014377798352925, 44.90564816338675, 47.94006545203072, 53.2929368019104, 50.441715717315674, 49.836249692099436, 49.31906052998134, 49.88279914855957, 47.88592161451067, 46.64233650479998, 46.80630704334804, 44.16907657895769, 41.630875314985005, 41.724557876586914, 42.6871508870806, 41.83116408756801, 43.70305395126343, 45.91939033780779, 43.782544817243306, 44.96389143807547, 44.49977956499372, 40.28483206885201, 39.52660642351423, 40.33243417739868, 39.52270153590611, 39.86920125143868, 43.562109742845806, 44.73880107062203, 51.91038772038051, 56.79530484335763, 58.67070007324219, 57.687311104365754, 58.80753789629255, 55.82793494633266, 57.16049173900059, 56.11304037911551, 52.921395778656006, 55.66976615360805, 55.42111097063337, 54.47863299506051, 56.65534380504063, 58.64279610770089, 56.873148986271445, 56.09204987117222, 56.17391354697091, 54.46476786477225, 56.08657816478184, 54.49868202209473, 55.31328535079956, 55.6638115474156, 56.94641774041312, 56.34177507672991, 58.50631264277867, 57.42390489578247, 67.15342221941266, 69.35608455113002, 72.81286893572126, 70.15616267068046, 4.537356070109776, 0.5603081626551492, 31.45653084346226, 73.91934176853725, 53.548387323107036, 43.234905174800325, 35.4499454498291, 34.49030194963728, 67.16596371786935, 22.029023919786724, 0.42486293773565975, 0.15928811766207218, 0.008397328866911786, 0.03063135061945234, 0.0461250531620213, 0.05919766133385045, 0.07207832551960434, 0.12546807314668382, 0.14432872751993792, 0.1262341256120375, 0.1212011192526136, 0.11268255314124481, 0.2769893668591976, 0.17895289031522615, 0.22977030490125927, 5.42121513400759, 79.83982535770961, 51.023061071123394, 34.244936738695415, 59.663799149649485, 63.61072335924421, 73.69972310747418, 50.759109428950715, 0.5173552674906594, 2.0262962068830217, 0.9571094704525811, 13.192611541066851, 87.73882934025356, 72.84200273241315, 75.76927185058594, 74.02203614371163, 73.95081015995571, 68.99197115216936, 62.84510830470494, 53.514976910182405, 57.48931871141706, 67.6736546925136, 68.95922429221017, 67.76359217507499, 66.79918915884835, 63.76728711809431, 63.0203766141619, 61.82617582593645, 63.922169412885395, 60.88110964638846, 58.10772228240967, 57.3480236189706, 64.41809013911656, 62.13047218322754, 61.31568472726004, 63.34605952671596, 59.95089176722935, 58.51209354400635, 54.77760008403233, 49.60445083890642, 49.784951141902376, 48.60394845690046, 45.62652724129813, 43.95883103779384, 45.3208829334804, 43.86825432096209, 44.53796339035034, 42.47176020486014, 44.68105459213257, 46.34252173560006, 47.08422803878784, 46.12328175136021, 45.21345336096627, 46.340426853724885, 47.67533908571516, 45.76423358917236, 45.88851254326956, 49.38217796598162, 50.463574750082834, 52.96286610194615, 53.000636509486604, 54.51183148792812, 55.93723358426775, 54.70212875093733, 56.51764440536499, 54.670653411320274, 51.57971600123814, 50.72632435389927, 49.94153227124895, 47.44482912336077, 46.0142263003758, 50.41372489929199, 47.518417494637625, 48.63964135306222, 52.0323737689427, 51.051951680864605, 50.49279192515782, 49.32150976998465, 51.81327969687325, 51.397746154240195, 52.49427958897182, 51.191857133592876, 53.26155873707363, 50.88795682362148, 49.31379379544939, 51.43781294141497, 48.55487680435181, 48.762120723724365, 49.25690541948591, 47.76872634887695, 43.34074708393642, 39.877883025578086, 38.35623795645577, 48.84913648877825, 45.97882522855486, 50.601618085588726, 53.256503922598704, 51.334076336451936, 51.026003633226665, 52.280407088143484, 53.7569375038147, 49.77127013887678, 48.535967281886506, 49.957276889256065, 46.6436253956386, 44.19041449683053, 42.27976063319615, 45.99488946369716, 43.907046113695415, 47.877778325762065, 48.483143602098735, 47.219384397779194, 47.68738726207188, 47.8907401902335, 43.54104280471802, 40.955826554979595, 42.92268092291695, 42.69641630990164, 42.15883765901838, 46.16721868515015, 46.549585001809255, 53.95709426062447, 60.34950992039272, 61.00097302028111, 60.36524064200265, 62.33630561828613, 58.51856926509312, 59.37560871669224, 58.3680226462228, 55.76939984730312, 57.56944186346871, 57.18713460649763, 57.749782357897075, 57.75066825321743, 60.796237400599885, 59.656038011823384, 58.97070939200265, 58.859204701014924, 57.42424535751343, 57.82828310557774, 56.183953693934846, 57.60712889262608, 58.810713223048616, 58.179288727896555, 58.13886758259365, 61.3416223526001, 61.5828012738909, 69.16512720925468, 76.19243104117257, 77.16369887760708, 74.21409824916294, 5.714809962681361, 0.7204734768186296, 37.23959296090262, 81.63275241851807, 61.589082445417134, 52.7485419682094, 48.94869722638811, 47.58639172145298, 76.07313741956438, 27.644670929227555, 0.4604880618197577, 0.2664826863578388, 0.17383703483002527, 0.20933825841971807, 0.23291971161961555, 0.11152287572622299, 0.121222710236907], [0.011867812418911074, 0.036406002539609156, 0.05994035183851208, 0.005675429744379861, 0.10592401187334742, 0.0448985875451139, 0.036100549822939296, 0.16516708077064582, 2.599943390914372, 54.10973228727068, 42.840018204280305, 50.81529951095581, 42.400892053331646, 46.86835445676531, 60.01480824606759, 52.415184770311626, 0.10480520262249879, 0.6750020767961229, 0.5135423349482673, 24.471051692962646, 84.32415103912354, 63.033300263541086, 71.43748692103794, 65.44702802385602, 63.29822812761579, 58.529790605817524, 48.83342661176409, 55.179671491895405, 63.599905014038086, 63.38817950657436, 61.36993626185826, 61.12953553880964, 61.010686601911274, 59.47746235983712, 59.59312207358224, 57.39781093597412, 57.51775074005127, 56.85782126017979, 57.751703534807476, 58.80040904453823, 59.30994129180908, 58.70864418574742, 55.869370528629844, 55.55540227890015, 57.355065618242534, 58.18436786106655, 49.52536644254412, 42.98819201333182, 44.31977605819702, 42.925126688820974, 42.045776571546284, 39.938829149518696, 39.317924227033345, 37.40357392174857, 38.63606970650809, 36.35704319817679, 38.78202356610979, 39.81666244779314, 42.14411095210484, 39.69348130907331, 41.68826396124703, 38.00959927695138, 38.80877065658569, 38.51993751525879, 42.43614721298218, 44.99160432815552, 45.2172783442906, 47.843704359872, 49.83318901062012, 47.228344099862234, 48.12246608734131, 47.90685306276594, 49.203174999782014, 47.103960922786165, 45.42276436941964, 42.743667534419465, 41.70620421000889, 45.52557338987078, 40.66187259129116, 40.62250757217407, 40.63111639022827, 44.168743065425325, 45.919557094573975, 45.33870506286621, 45.43584087916783, 46.69327374867031, 47.46851205825806, 49.66336114065987, 45.671801703316824, 43.538621357509065, 48.6887720652989, 47.583324091775076, 48.48118073599679, 44.92586047308785, 42.939113412584575, 43.67211709703718, 43.347490310668945, 44.25564418520246, 43.680051939828054, 36.69057757513863, 37.665826729365754, 39.322426659720286, 46.03285442079817, 41.821707589285715, 45.01884126663208, 50.24911512647356, 48.669800009046284, 45.67106866836548, 46.60022347314017, 44.94366175787789, 43.68858780179705, 42.72786038262503, 41.10147469384329, 41.40863718305315, 37.42710052217756, 36.57697800227574, 40.117380482809885, 39.543733733040945, 39.35226222446987, 39.20503337042672, 37.52697392872402, 37.46967213494437, 37.555791582380024, 38.68782336371285, 36.24681697572981, 35.38706772668021, 39.28697347640991, 41.55684225899832, 43.1297789301191, 52.52453899383545, 55.19907086236136, 55.1915077481951, 56.610218729291645, 55.196503502982004, 56.796228953770225, 54.53138371876308, 53.65392351150513, 57.16276727403913, 53.925358363560264, 57.842738832746235, 57.478146008082796, 58.11825227737427, 55.86562892368862, 58.91205964769636, 58.137707233428955, 59.57999692644392, 57.39430556978498, 59.69395433153425, 58.76363917759487, 59.99109404427664, 58.38876301901681, 60.46318244934082, 59.3159236907959, 61.671953610011506, 58.48623234885079, 65.61951010567802, 64.62600108555385, 69.64223916190011, 57.7516826902117, 3.451281411307199, 0.2672474224652563, 29.581260681152344, 65.97729369572231, 46.4509414264134, 37.90584877559117, 29.057786873408727, 27.773071902138845, 64.28955541338239, 17.29247341837202, 0.4103136813001973, 0.057526178524962494, 0.09569616176720176, 0.06756576230483395, 0.05077730977375593, 0.04309944176514234, 0.008419880826425339, 0.03150265743689878, 0.05015348503366113, 0.04544686419623239, 0.0855059160717896, 0.05871172848024538, 0.03385916205921343, 0.059974570359502516, 0.08865509887358972, 3.4755071742194037, 66.39037799835205, 44.64215510232108, 48.87860032490322, 48.94839497974941, 53.09127228600638, 64.92766407557896, 59.45036438533238, 0.0976692805332797, 0.9211699132408414, 0.5506876760295459, 28.295581647327968, 88.04556451525006, 63.877645356314524, 75.04938289097377, 66.98226724352155, 66.90446826389858, 59.529622486659456, 51.99525301797049, 56.23277868543352, 67.54596764700753, 65.27894415174211, 64.92358548300606, 66.38222081320626, 64.55826309749058, 62.284993171691895, 63.01809065682547, 61.036429677690776, 58.75889355795724, 58.644046783447266, 59.989690508161274, 60.606579371861045, 61.88295650482178, 59.670462472098215, 59.51863043648856, 58.58283315386091, 60.54465702601841, 61.23743411472866, 51.52180624008179, 45.473434107644216, 46.00888313565935, 44.260455812726704, 44.22708708899361, 41.48950726645333, 40.738684926714214, 39.846334729875835, 39.53440925053188, 38.428214345659526, 40.29096385410854, 41.18244900022234, 42.942733424050466, 43.17794384275164, 42.79501819610596, 39.74847977502005, 42.23627185821533, 41.024738788604736, 45.48101806640625, 48.807405608040945, 49.00709336144583, 50.15422705241612, 53.4152181489127, 49.00524166652134, 51.116806166512625, 51.319874218532014, 52.10832452774048, 47.27012709208897, 47.96432161331177, 44.65612098148891, 43.99925218309675, 47.24356065477644, 42.98363052095686, 45.10607589994158, 43.96843344824654, 46.706124441964285, 49.20425891876221, 48.05892481122698, 48.60858290536063, 48.70969656535557, 49.76030935559954, 51.46918058395386, 46.601911885397776, 44.379822390420095, 49.655269963400706, 47.89854996544974, 49.15271718161446, 45.42428949901036, 45.55581195013863, 47.79838126046317, 46.51355511801583, 45.842602321079795, 45.206334931509836, 38.63615655899048, 38.450775146484375, 41.9140248298645, 46.698245184762136, 44.758474894932334, 48.22524036679949, 53.23830311638968, 50.24362257548741, 46.46942016056606, 48.19253519603184, 47.45967742374965, 47.878216062273296, 45.29389613015311, 42.62365477425711, 41.34376185280936, 40.377611364637104, 38.79347767148699, 40.83264889035906, 42.28431865147182, 41.2687907900129, 42.042424065726145, 39.96248776572091, 39.77618571690151, 39.30698428835188, 40.88929755347115, 38.34492628914969, 37.71742752620152, 40.62283761160714, 43.65051514761788, 45.28704868044172, 53.58756474086216, 58.37553364889962, 56.81050750187465, 61.72885935647147, 59.02899088178362, 58.486579758780344, 58.87111391339983, 57.946968759809224, 59.609318324497764, 57.30958618436541, 61.19138145446777, 60.29399381365095, 59.875142506190706, 61.52804946899414, 60.659712246486116, 61.55971935817173, 62.703316416059224, 59.336184637887136, 62.1780742917742, 62.6283175604684, 63.097355706351145, 63.26073564801897, 64.14779826572963, 63.04690483638218, 65.27192647116524, 61.67079326084682, 67.10056032453264, 69.56869942801339, 73.4019580568586, 62.70718656267439, 3.374676436185837, 0.19599749999386923, 34.83886875425066, 72.67180660792759, 53.45437819617135, 46.996986457279746, 27.044195447649273, 32.78605127334595, 72.36450168064663, 20.534593207495554, 0.40629425698093, 0.07676237488963775, 0.06283179311347858, 0.017409837937780788, 0.026664399109514694, 0.05939723205353532, 0.025260740857837454, 0.09308160349194493, 0.1275788870240961, 0.3145667447575501, 0.07905878166535071, 0.2894876833472933, 0.11808379366993904, 0.10225836214210306, 0.16969456497047627, 4.547262029988425, 77.00102765219552, 52.88458769662039, 64.84412588391984, 56.29733787264143, 60.899869782584055, 69.46043259756905, 65.22640187399728, 0.2888476076935019, 2.322630145720073, 0.686154206948621, 28.89932973044259, 89.57575934273856, 66.62656811305455, 78.38275337219238, 69.62930856432233, 69.12215954916817, 62.33064978463309, 54.45955671582903, 59.199555260794504, 70.007860319955, 66.55855914524624, 66.77837930406842, 67.30205808367047, 66.3111824308123, 62.297583307538716, 65.43426418304443, 61.97022587912423, 59.49199799128941, 59.1352288382394, 61.96158232007708, 62.56367152077811, 64.74612154279436, 63.30891445704869, 62.23085280827114, 61.00678171430315, 61.90853977203369, 64.50342791421073, 53.72972140993391, 47.358987603868755, 47.73308209010533, 47.47598484584263, 46.483212334769114, 44.79471322468349, 44.628029414585654, 42.85583577837263, 42.414381980895996, 40.268121651240754, 43.077285289764404, 43.7747802053179, 45.695873737335205, 44.325591700417654, 46.35721370152065, 43.37817702974592, 44.12301002229963, 43.85979836327689, 46.618358271462576, 51.034518650599885, 53.293902601514546, 55.35619395119803, 55.87849003928048, 54.282568727220806, 55.588569504874094, 54.79872260774885, 55.55635418210711, 51.435443605695454, 52.41133894239153, 46.40360682351248, 46.72369991030012, 52.114324297223774, 43.85218661172049, 46.67057398387364, 47.128470693315776, 49.48508426121303, 52.239708014896934, 51.54215056555611, 51.89615086146763, 50.93977301461356, 51.59111104692732, 54.22793504170009, 48.20762668337141, 47.694345882960725, 53.57454381670271, 52.85516554968697, 52.08541284288679, 49.02689225333077, 48.09997476850237, 50.299187319619314, 48.41920280456543, 47.6376451083592, 47.70057494299752, 41.31293964385986, 38.661055428641184, 43.71008900233677, 47.9517696925572, 47.66863407407488, 51.16947003773281, 54.26794971738543, 51.37723854609898, 50.60507481438773, 52.32837050301688, 50.070522103990825, 48.94931214196341, 47.81417451586042, 46.75654751913888, 45.22773885726929, 42.38514396122524, 39.25829826082502, 44.57009186063494, 44.26381179264614, 43.91975089481899, 42.639117990221294, 42.82570491518293, 42.200568539755686, 42.35277230398995, 43.23183754512242, 40.35511657169887, 39.40951190676008, 43.38952691214425, 48.02988134111677, 48.27733448573521, 57.646382740565706, 60.255667550223215, 58.50138636997768, 62.73113700321743, 59.02676051003592, 62.192338943481445, 60.25614697592599, 59.720420019967214, 60.93519442422049, 60.03951604025704, 62.89164733886719, 65.02436910356793, 60.78937952859061, 64.5702348436628, 63.303279467991416, 63.88278702327183, 65.38687746865409, 63.45370101928711, 64.47904668535504, 64.54877185821533, 65.07731437683105, 65.44030911581856, 67.10793236323765, 66.72191824231828, 68.87883363451276, 65.06657941000802, 69.21953160422188, 75.36228111812046, 76.07125445774624, 70.94242777143205, 5.129896708897181, 0.4078166995729719, 40.51261486325945, 81.72205761500767, 62.54531438010079, 56.913358211517334, 40.9503687449864, 41.24239458356585, 83.6052348273141, 23.955351182392665, 0.5113857335277966, 0.146449068029012, 0.20817952416837215, 0.08866179601422378, 0.17808710677283152, 0.16947474676583493, 0.1574643240975482], [0.03821988949286086, 0.008155687279733164, 0.03706321459529655, 0.01296418675753687, 0.05378388826336179, 0.04939338671309607, 0.010952167578839829, 0.09158554912677833, 2.3935732075146268, 57.69747631890433, 43.334677832467214, 30.23040655681065, 30.35778440747942, 51.37062733513968, 53.49097783224923, 67.94651739937919, 0.8797609295163835, 0.5403043531945774, 0.21141491484429153, 40.30852542604719, 81.60258334023612, 63.05189364297049, 65.90047441210065, 58.01847961970738, 55.85747521264212, 50.16457986831665, 54.09590537207467, 61.642145838056294, 64.10249601091657, 63.963962827410015, 64.17894009181431, 65.8391009739467, 66.1509291785104, 59.69817188807896, 61.74909251076834, 61.252205984933035, 60.261566570826936, 59.97448784964425, 58.41519396645682, 57.15516594478062, 55.45546286446707, 53.331252643040244, 51.73984071186611, 55.94043322971889, 56.69830104282924, 56.19981643131801, 51.81019469669887, 43.588280132838655, 41.549341678619385, 42.7623998778207, 41.070266859872, 38.885801860264365, 38.76956197193691, 38.46629394803728, 38.149862561907085, 37.91432210377285, 37.763216154915945, 37.478013447352815, 40.00243295942034, 40.58373314993722, 38.86014216286795, 37.11721781321934, 38.33817611421858, 37.288091387067524, 43.68761157989502, 45.085731574467246, 46.01992382322039, 48.01506083352225, 45.459207671029226, 44.13291467939104, 45.91182722364153, 45.64640256336757, 45.73778179713658, 43.55313267026629, 48.017433643341064, 48.93015595844814, 48.828517709459575, 50.40104096276419, 48.42278807503836, 44.632643018450054, 45.358729771205354, 46.79672200339181, 44.54656178610665, 44.908184255872456, 45.701678957257954, 47.2702591078622, 46.98259673799787, 51.88198695863996, 44.64824519838606, 44.08052526201521, 48.025802748543875, 46.60245731898716, 46.9953327860151, 45.603056226457866, 46.123361655644004, 45.83400739942278, 45.77503456388201, 42.01445756639753, 40.57755272729056, 41.891446658543174, 37.21014649527413, 40.67295149394444, 40.53121171678816, 39.86802353177752, 41.929015568324495, 43.59677083151681, 48.0109474999564, 49.362545830862864, 47.74239615031651, 47.42537416730608, 45.0032182421003, 45.99443088259016, 41.23261499404907, 38.13983631134033, 36.11486373628889, 35.78764874594552, 36.67808818817139, 38.91860777991158, 38.68390110560826, 38.35913535526821, 37.82851879937308, 38.24002933502197, 36.82624115262713, 38.21969543184553, 36.40491281236921, 37.869454111371724, 38.861045428684776, 40.75221654347011, 42.054590361458914, 50.83698831285749, 54.62821728842599, 53.20452444893973, 50.98662124361311, 59.938975606645855, 62.03469821384975, 56.622273853846956, 55.94514758246285, 54.355740206582205, 58.0465920312064, 58.34751156398228, 57.89315843582153, 59.58120591299874, 61.20390905652727, 61.12229551587786, 58.63149833679199, 61.39761093684605, 61.068467821393696, 62.519480977739605, 62.77625165666853, 64.96243286132812, 63.09756415230887, 64.48280566079276, 62.78008706229073, 66.08731842041016, 61.37454291752407, 66.35296889713833, 61.67376014164516, 68.655914579119, 45.32362052372524, 2.15450827564512, 0.017645674657874873, 34.11590869086129, 65.33058316367013, 47.064755712236675, 34.65623535428728, 44.19404493059431, 37.116450037275044, 57.336510453905376, 16.182889529636928, 0.4817629030772618, 0.08128515684178897, 0.24240386698927197, 0.027138250647112727, 0.0750371113951717, 0.1083397458174399, 0.004350080795120448, 0.04343126913798707, 0.038253884097295146, 0.030718060609485422, 0.028429987940139005, 0.07294989018035786, 0.021090880235923187, 0.06586588280541555, 0.09867587366274425, 2.791346503155572, 63.75985254560198, 48.22862761361258, 29.11660511153085, 36.52824681145804, 61.184815406799316, 58.78721441541399, 73.26516887119838, 0.887707280261176, 0.7714371564132827, 0.48507909370320185, 45.48556566238403, 85.20324407305036, 65.85108661651611, 69.32513727460588, 60.68617793491909, 57.942056383405415, 53.14870956965855, 55.1334798676627, 64.9469244820731, 66.08862468174526, 66.52708380562919, 68.64727102007184, 66.74271420070103, 65.59637260437012, 61.932337352207725, 61.54336329868862, 63.128629548209055, 60.487813813345774, 61.48479693276541, 60.29191630227225, 58.275604656764436, 57.7517625944955, 56.47287368774414, 55.18436847414289, 59.11182035718645, 57.65627350125994, 58.630713190351216, 52.07401084899902, 45.23563895906721, 44.60497876576015, 44.970874377659385, 44.60691383906773, 41.48549815586635, 41.1313658441816, 39.78790732792446, 40.02874231338501, 40.38649811063494, 39.51426642281668, 41.034674712589805, 41.15270376205444, 42.50340577534267, 40.4900540624346, 39.02237912586757, 40.632902077266145, 39.517202036721365, 46.2033041545323, 45.922614301954, 47.74766288484846, 49.81042671203613, 49.20401920591082, 48.411556312016074, 49.925096307482036, 47.894103118351524, 46.10662691933768, 47.105607645852224, 50.688776288713726, 51.865189688546316, 51.113623891557964, 53.94382667541504, 51.159200600215364, 46.41434179033552, 47.420670236860005, 48.74178334644863, 47.67373405184065, 47.58241387775966, 48.26364653451102, 48.93360226494925, 51.559121540614534, 53.19365051814488, 45.89439419337681, 44.49806683404105, 50.570945262908936, 49.499654633658274, 48.22866930280413, 46.073414530072895, 48.886246817452566, 47.28616353443691, 45.835063525608604, 42.599468094961985, 42.16088737760271, 42.62590251650129, 39.66714416231428, 44.27247967038836, 41.34007235935756, 42.466003622327534, 44.565877778189524, 45.629827635628835, 50.59775488717215, 52.778909070151194, 49.91594205583845, 48.64870180402483, 47.3391991342817, 47.91555915560041, 43.08170434406826, 40.37901142665318, 37.28093474251883, 36.60953378677368, 39.058884961264475, 40.41322783061436, 40.469032287597656, 40.25029257365635, 38.698752880096436, 38.28570679255894, 39.61684615271432, 39.76545075007847, 39.290722029549734, 40.93923773084368, 41.480790751320974, 43.08725248064314, 44.032655647822786, 52.84316601072039, 55.254454953329905, 56.32395642144339, 52.235997676849365, 60.15570381709507, 61.81735856192452, 59.504789624895366, 58.64192063467843, 57.08317218508039, 61.093342372349326, 60.745779582432334, 60.38782923562186, 63.236847741263254, 63.60896546500069, 64.9684500013079, 62.46659129006522, 63.54354122706822, 64.58843217577252, 65.51508562905448, 64.72979327610561, 67.41761357443673, 65.00523376464844, 68.14098358154297, 66.70492989676339, 69.72420706067766, 65.3866273335048, 70.35463796343122, 66.35947935921806, 74.041428565979, 50.06885801042829, 2.5862984316689626, 0.10899887473455497, 39.84887777056013, 72.03767926352364, 52.475752217429026, 43.15304149900164, 47.28906093324934, 44.96634067807879, 62.55340208326067, 19.86553032057626, 0.6226996204682759, 0.053459599414574246, 0.13306299703461782, 0.0326240315501179, 0.04539427773228713, 0.07943910732865334, 0.04075173095666936, 0.16755959524640016, 0.12482932742152895, 0.1559555200593812, 0.08562725170382432, 0.14774076800261224, 0.11026139091700315, 0.13415566911654814, 0.1767240927687713, 3.8825699942452565, 76.45934609004429, 55.68857840129307, 41.30120413643973, 41.20788982936314, 68.83070346287319, 61.048811367579866, 80.76428318023682, 1.1188325924532754, 1.7993255917515074, 0.7866735245500291, 47.00920833860125, 87.21112755366734, 69.5072912488665, 72.293185370309, 62.935532161167686, 60.121240752083914, 56.440710476466585, 57.960052217756, 66.9031481061663, 67.63504355294364, 68.88519123622349, 68.83548382350376, 67.87995365687779, 68.78868075779506, 64.19056442805699, 65.94872965131486, 64.66927446637834, 66.23564161573137, 66.35623455047607, 62.435505049569265, 60.044213022504536, 60.12805693490164, 57.98522554125105, 57.48895740509033, 58.8739070892334, 60.02054745810372, 60.170711926051546, 56.09597907747541, 48.606182302747456, 46.45164319447109, 47.659445081438335, 45.48607982907976, 44.146741594587056, 43.58072049277169, 44.16561985015869, 42.000328404562815, 43.27984959738595, 43.203443731580464, 44.08889089311872, 44.6044784954616, 43.4745693887983, 43.51265246527535, 42.68588631493704, 43.37940338679722, 41.577450616019114, 49.42949519838606, 50.95104646682739, 50.87242065157209, 53.327969619206016, 51.57112455368042, 50.66168873650687, 53.524693965911865, 51.52026373999459, 49.872050285339355, 50.03499249049595, 54.353794710976736, 54.51310995646885, 53.79992948259626, 57.28090749468122, 53.444841793605256, 49.069119930267334, 50.642271995544434, 51.85429491315569, 48.80760710580008, 51.7247804914202, 50.88758162089756, 50.79192577089582, 52.28948490960257, 56.524095807756694, 48.112054211752756, 46.391072273254395, 52.76965406962803, 51.18492977959769, 51.22381884711129, 50.08988673346383, 51.23509577342442, 51.57761417116438, 47.77687658582415, 45.93664966310774, 44.11255298342024, 45.16883202961513, 41.54331064224243, 45.18579258237566, 45.00205441883632, 45.101097515651155, 47.40459210532052, 48.81548636300223, 51.55307313374111, 52.77853386742728, 53.322532653808594, 52.40402943747384, 51.7667476109096, 53.23285920279366, 46.04387078966413, 43.581154755183626, 39.896646635872976, 38.5442145211356, 41.40655967167446, 42.97497306551252, 41.84126329421997, 41.51163727896554, 42.110888140542166, 42.81236089978899, 41.259303024836946, 43.07712548119681, 40.67396593093872, 42.79840196881975, 45.05705983298165, 45.6219414302281, 47.763633319309776, 55.1251802444458, 59.72852161952427, 57.13637106759207, 53.27814061301095, 62.913478578839985, 62.167735372270855, 63.23185198647635, 60.10070882524763, 59.32816641671317, 63.632832527160645, 62.65308094024658, 64.07240336281913, 65.92043658665249, 65.4234458378383, 66.41724668230329, 63.808469091142925, 67.11203180040631, 66.63356494903564, 68.22130475725446, 69.89427116939, 70.77636582510812, 68.30475957053048, 71.27960995265416, 69.25724642617362, 71.79058047703334, 69.06045954568046, 71.70190061841691, 71.11241544995988, 75.38341059003557, 58.75414099012102, 3.804774488721575, 0.16810747156185762, 46.73148884092058, 81.34020546504429, 62.00313254765102, 50.56617879867554, 64.29706641605922, 52.88758931841169, 73.55108029501778, 26.451071160180227, 0.751893339412553, 0.17941445697631153, 0.41887041500636507, 0.18000495886164053, 0.12744441495410033, 0.1947226005473307, 0.1161530494157757], [0.039584179142756123, 0.01888344806086804, 0.025365543984142796, 0.034296871429043155, 0.07365001618329968, 0.03643292680914913, 0.020690500470144407, 0.027494774998298714, 0.6089520667280469, 43.29905094419207, 49.04524939400809, 49.05912494659424, 29.202281611306326, 46.48167330878121, 51.13214431490217, 71.76442050933838, 3.386251266513552, 0.26977792382240295, 0.3455898272139685, 50.274191175188335, 76.53809697287423, 62.48549733843122, 64.21263190678188, 54.70967102050781, 53.396159240177695, 52.597380433763774, 59.218412671770366, 60.324593680245535, 64.63328279767717, 65.45532417297363, 59.701486178806846, 56.892350333077566, 48.38965559005737, 59.69531617845808, 62.61390699659075, 49.51309592383248, 51.79824726922171, 56.1299592426845, 57.7582174709865, 54.36219160897391, 56.236013071877615, 55.71939713614327, 57.643148354121614, 56.43104900632586, 56.90191452843802, 54.597398553575786, 44.77407360076904, 40.89091648374285, 42.44177872794015, 43.15443808691842, 42.887818336486816, 40.48488460268293, 38.82143374851772, 35.61194617407662, 37.24470683506557, 38.23678800037929, 36.11306415285383, 37.80588851656233, 41.34060737064907, 39.34302806854248, 36.68904897144863, 33.968447072165354, 35.79031685420445, 36.13832432883126, 38.095152446201865, 39.82533379963466, 43.95542642048427, 45.580005577632356, 44.727871554238455, 46.22337055206299, 43.71699898583548, 40.68093844822475, 45.564254011426655, 47.64672640391758, 48.14329331261771, 47.52607788358416, 46.611420495169504, 49.1612217766898, 46.28261089324951, 44.7194572857448, 45.3460909979684, 43.1050329208374, 45.046481200626914, 45.812624318259104, 43.865457671029226, 46.14690562656948, 48.89216668265206, 50.31859016418457, 44.265145846775596, 41.89443438393729, 49.85538155691964, 46.4006017276219, 48.24770041874477, 44.29254259381975, 46.073105335235596, 43.315334047589985, 44.43854856491089, 43.90785905293056, 42.21271399089268, 45.97076531818935, 49.03769670213972, 47.53800099236624, 45.49329900741577, 44.816120624542236, 43.871064867292134, 41.58600732258388, 39.68473352704729, 46.37903799329485, 47.01075083868844, 44.51564577647618, 44.84807538986206, 41.87857164655413, 40.593867097582134, 37.38008206231253, 35.255128383636475, 33.792834826878135, 34.70232275554112, 36.81475578035627, 40.68056671960013, 38.03406041009085, 37.07237066541399, 36.50993135997227, 36.345026288713726, 36.565635068076, 35.86903299604143, 38.56848457881382, 40.14309923989432, 42.16075883592878, 42.384299755096436, 47.83374759129116, 55.66528109141758, 54.01270416804722, 51.915970597948345, 50.13304894311087, 71.64400127955845, 66.74801567622593, 54.151299885341096, 62.14090837751116, 56.53195422036307, 60.743570055280415, 58.357378005981445, 58.679503440856934, 58.387852805001394, 64.32192707061768, 61.38579205104283, 64.95463003431047, 61.33737005506243, 63.27989877973284, 63.18721675872803, 67.54288959503174, 62.1126708984375, 65.24635710035051, 63.45999608721052, 67.142715045384, 64.32613767896379, 67.703934941973, 60.95414216177804, 69.52798298427037, 33.92013624736241, 1.2771691190344947, 0.17915661366922514, 37.364007404872346, 65.33807332175118, 42.72020346777779, 44.718241350991384, 28.608545882361277, 29.92819118499756, 58.606484821864534, 11.796753185135977, 0.4295312315225601, 0.02589176655081766, 0.05420608971534031, 0.023513799865863154, 0.07738595535712582, 0.04564024667654719, 0.040235148676271947, 0.05205159853877766, 0.07233113409685236, 0.021447565739176104, 0.04912389635241457, 0.037940010761043856, 0.03385515530992832, 0.028863400486963134, 0.035089478362351656, 0.5983852680240358, 54.695239612034385, 51.98904480252947, 42.12856435775757, 33.05675309044974, 52.48054647445679, 55.822706426892964, 78.46384579794747, 4.242255219391414, 0.20174193674964563, 0.5510987054024423, 55.21898439952305, 81.080655506679, 66.61836229051862, 66.94758878435407, 56.19231237683977, 56.0588618006025, 54.29640259061541, 63.01505429404122, 63.552990777151926, 67.66718591962541, 66.12627696990967, 63.259589195251465, 59.373503412519185, 52.03835269383022, 56.94982235772269, 61.329442160470144, 51.22499656677246, 54.19866228103638, 57.89563546861921, 59.157845224652974, 56.81633356639317, 58.040849345070974, 57.965645517621724, 58.61386380876814, 60.18467780521938, 59.00664547511509, 56.63514886583601, 46.95818076814924, 44.0663092476981, 44.59072801045009, 43.630778789520264, 46.426626205444336, 42.937810625348774, 41.218475409916465, 39.603536878313335, 40.76971558162144, 41.11403356279646, 39.34841292245047, 39.687009062085835, 42.154345648629324, 42.40670769555228, 37.96944216319493, 36.6075188091823, 37.21394715990339, 37.84179333278111, 39.89959614617484, 40.87480708530971, 44.889479705265586, 46.895188399723594, 47.32890885216849, 47.5206652368818, 45.54667854309082, 44.026079177856445, 47.1636563709804, 50.89781631742205, 51.77882705415998, 50.94708946772984, 49.078493050166536, 50.82291126251221, 48.81983246122088, 44.89911338261196, 46.26381949016026, 46.6992700440543, 47.008450984954834, 48.18937723977225, 45.60103777476719, 48.65085227148873, 51.55201700755528, 52.80120236533028, 47.21320397513253, 43.39957748140608, 54.16431386130196, 48.387984548296245, 49.94975199018206, 48.66308804920742, 47.023406982421875, 45.145062242235454, 47.0362229347229, 46.21560594013759, 44.835405349731445, 46.49834551130022, 50.81505284990583, 50.31509174619402, 46.44096381323678, 48.262753690992085, 46.081634249006, 44.27831615720476, 44.42068127223423, 47.96887615748814, 49.19098091125488, 47.31930296761649, 47.40467548370361, 44.18639496394566, 41.98590741838728, 38.52671548298427, 37.72308335985456, 36.29935577937535, 36.450937679835725, 38.71871852874756, 41.396842615945, 41.4789251599993, 39.91867937360491, 38.82362243107387, 38.25736856460571, 39.36358083997454, 38.284751415252686, 39.82554224559239, 41.709858962467735, 43.76198162351336, 45.55044446672712, 51.218902996608186, 57.472007274627686, 56.92845664705549, 55.35023239680699, 51.534264360155376, 68.33038452693394, 65.08420004163469, 57.502766949789866, 62.33990478515625, 58.655622482299805, 64.42141832624162, 59.84402847290039, 63.0538113457816, 60.21126856122698, 65.70328453608921, 63.08523109980992, 66.92046301705497, 65.06901822771344, 67.27693339756557, 66.84528350830078, 69.17458370753697, 65.55063956124442, 69.56020178113664, 65.97992706298828, 70.44217136928013, 68.4164171218872, 71.53451156616211, 65.04433127811977, 75.86694962637765, 35.464870180402485, 1.2976119135107314, 0.20316091632204397, 45.99868665422712, 70.81813839503697, 51.76903009414673, 52.18049199240548, 33.32528706959316, 34.224415234157014, 68.91069112505231, 15.494970968791417, 0.48304804840258186, 0.0318914172904832, 0.08539954892226628, 0.005596914761034506, 0.06561462807336024, 0.054834399571908374, 0.028364606002079587, 0.15003466419875622, 0.143929871065276, 0.07716304303279944, 0.13522574598235743, 0.1582131010613271, 0.08266151762966599, 0.1525482971753393, 0.11534898541867733, 0.9945142290421894, 65.39541680472237, 60.51133346557617, 61.00334235600063, 39.136635303497314, 61.05607223510742, 59.98806462969099, 84.548994745527, 4.568536111286708, 0.7186303585767746, 1.401431354028838, 55.89689234324864, 83.54431997026715, 68.32486765725272, 70.42363357543945, 58.554296902247835, 58.534883635384695, 57.49322707312447, 65.30310998644147, 65.3846401487078, 69.16311917986188, 69.72039944784981, 65.30117143903459, 62.68586948939732, 55.33645064490182, 54.6222175189427, 61.92304066249302, 53.357923303331646, 55.00335053035191, 60.55831023624965, 61.50212574005127, 58.379674775259836, 60.399085317339214, 60.24880967821394, 61.01890632084438, 61.38653550829206, 60.63478210994175, 60.19291836874825, 48.831623554229736, 45.61987434114729, 46.74011850357056, 47.11844791684832, 47.64242546898978, 47.08748326982771, 44.81592607498169, 40.67038066046578, 43.30188928331648, 42.931119510105674, 40.51817342213222, 41.89636598314558, 46.76809195109776, 46.07491534096854, 41.23001636777605, 40.39429746355329, 41.32089185714722, 42.04838562011719, 43.404274463653564, 42.61458737509591, 48.362859862191335, 51.301979133060996, 51.46889223371233, 50.512837478092735, 47.85395990099226, 48.952292919158936, 49.88393865312849, 52.24730934415545, 56.06120334352766, 52.74797569002424, 50.87859412602016, 56.24774510519845, 52.09817320959908, 48.00112969534737, 50.229430879865376, 50.13591854912894, 51.27867834908621, 51.79329320362636, 49.54065942764282, 52.20328208378383, 54.86228125435965, 56.230131421770366, 48.57045119149344, 45.288174288613455, 55.85123920440674, 51.982145241328645, 52.55118533543178, 51.48277473449707, 51.15423263822283, 48.28493234089443, 48.16432898385184, 49.589213439396445, 46.643267563411165, 50.29050554547991, 51.65359272275652, 50.44320610591343, 47.1813325881958, 50.197726249694824, 49.1604505266462, 46.04042100906372, 46.84199299131121, 50.68294675009591, 52.39370094026838, 50.72354507446289, 49.47067717143467, 45.29654686791556, 44.61332702636719, 41.525981834956575, 39.67887272153582, 39.18886491230556, 39.08660132544381, 40.60463333129883, 44.54566199438912, 42.192067418779644, 42.51270593915667, 42.424147674015586, 40.16819960730416, 42.71796267373221, 40.41654559544155, 43.14624963487898, 44.53062956673758, 45.62358815329415, 47.37505531311035, 53.222746099744526, 59.653481074741904, 59.96861662183489, 56.37376805714199, 53.64795500891549, 71.05821255275181, 62.98057038443429, 62.0139856338501, 63.177447591509136, 60.69386959075928, 66.31114074162075, 62.14661979675293, 65.00442082541329, 64.81538813454765, 70.04259436471122, 65.99831199645996, 68.7843381336757, 66.29251262119838, 68.60153102874756, 68.67245129176548, 72.82264505113874, 67.70663779122489, 70.77378804343087, 68.38189847128731, 72.41930212293352, 72.68354211534772, 74.71446582249233, 70.61594581604004, 77.37575789860317, 45.53756945473807, 1.7674337944814136, 0.23543612658977509, 50.713994775499614, 78.89544010162354, 59.025162424360005, 62.08264773232596, 39.534857409340994, 40.13137762887137, 80.35392951965332, 19.346267121178762, 0.6944614297577313, 0.20054472956274236, 0.14029419901115553, 0.20325399775590214, 0.17238165863922664, 0.10148899164050817, 0.10157812400055782], [0.03375121731577175, 0.042067373038402626, 0.032903771182256084, 0.07271844867084708, 0.01672359136864543, 0.04687365031402026, 0.006578507691821349, 0.11584028548427991, 0.2310697537447725, 43.76038006373814, 46.99458238056728, 40.45951672962734, 31.380267415727886, 43.417420455387656, 45.368293966565815, 75.14162717546735, 11.129775626318795, 0.1697508833770241, 0.5470128932169506, 55.64957468850272, 77.48096752166748, 60.86748422895159, 64.84762777600969, 53.6813063621521, 61.01468876429966, 58.550086293901714, 62.57154382978167, 60.31891005379813, 63.45610509599958, 57.96149396896362, 59.93056828635079, 51.706916672842844, 72.29451942443848, 79.65954044886998, 46.872200284685405, 51.625136375427246, 56.97343928473336, 59.82827690669468, 55.83775275094168, 58.66348089490618, 58.025347914014546, 56.418851443699424, 55.49306304114205, 54.20813962391445, 52.68757152557373, 45.586331912449424, 42.843655586242676, 43.496841839381624, 41.96708474840437, 42.57285302025931, 42.527616773332866, 41.455801555088584, 39.63450847353254, 38.604545729500906, 38.204933983939036, 38.675035204206196, 38.09511423110962, 37.300000599452424, 39.03898532049996, 39.115130628858296, 36.81717722756522, 34.26565974099295, 34.727454389844624, 34.52482754843575, 35.63113362448556, 38.20225197928292, 43.74336739948818, 39.52344846725464, 40.959703649793354, 41.57393830163138, 40.27889135905674, 44.0026706968035, 47.787809576307026, 46.356383391789024, 47.17478738512312, 46.94766814368111, 49.1580672945295, 47.14407287325178, 42.173890931265696, 43.89712061200823, 43.457122462136404, 43.50873020717076, 45.19302913120815, 44.1132686478751, 43.55606828417097, 45.71725334439959, 45.17190660749163, 46.343386786324636, 42.9673022542681, 40.51744386128017, 47.213818890707834, 47.032220772334504, 48.65690415246146, 44.584742137363975, 44.20290388379778, 43.68234831946236, 43.89679404667446, 42.72845445360456, 42.16429546901158, 46.73314251218523, 48.08310454232352, 47.96018048695156, 52.63646752493722, 48.74337100982666, 47.210327420915874, 47.43299981525966, 41.65460688727242, 40.414183207920615, 45.39932114737374, 44.88717290333339, 44.07121467590332, 43.11571230207171, 39.42259189060756, 35.425303663526265, 32.657936913626536, 32.995025294167654, 33.30751705169678, 36.089415958949495, 39.116902419498985, 37.546067578451975, 37.17487743922642, 34.304020745413645, 39.04998084477016, 36.352519920894075, 36.15353740964617, 40.10332080296108, 39.54636015210833, 41.468252726963584, 40.2780054637364, 44.23465020315987, 52.040412834712434, 56.891989026750835, 58.69150297982352, 54.625368527003694, 45.54359006881714, 73.37545067923409, 62.5041879926409, 54.65015275137765, 63.85509845188686, 61.23519679478237, 60.047707966395784, 61.18202223096575, 62.75146048409598, 60.591744967869346, 59.49884196690151, 59.46353816986084, 62.16544246673584, 63.50164358956473, 64.08920410701207, 66.03391456604004, 66.05580833980015, 69.33932549612862, 68.00862039838518, 68.99402781895229, 64.88675308227539, 65.8182772227696, 62.21549728938511, 64.56142452784947, 21.21644251687186, 0.906557417341641, 0.617334742631231, 45.63659518105643, 63.378750801086426, 44.14782203946795, 40.33836446489607, 32.03674364089966, 46.578190735408235, 57.806868757520405, 11.157568420682635, 0.6080340902720178, 0.11695389715688569, 0.08563103792922837, 0.059655984597546716, 0.06002153176814318, 0.04221123264038137, 0.09927449761224644, 0.06388768859739814, 0.0750342004799417, 0.039187405790601454, 0.036391186727476973, 0.013584385576125766, 0.03780458534934691, 0.03489356833909239, 0.039747387170791626, 0.40014010721019333, 50.15706886563982, 51.19655064174107, 42.01582636151995, 38.65454496656145, 48.572865690503804, 47.38409491947719, 82.40657329559326, 13.044242313929967, 0.19384401983448438, 1.2467509912593024, 58.63001837049212, 79.00525638035366, 63.92421913146973, 66.041168485369, 56.65952314649309, 63.599022592817036, 61.55616882869175, 65.83370222364152, 63.80500888824463, 64.42012596130371, 60.454809870038716, 61.477313722882954, 57.55905778067452, 63.13768999917166, 74.93441799708775, 52.4079829624721, 51.0918482371739, 60.595184326171875, 59.31991195678711, 59.1968663079398, 58.58190209524972, 58.90237385886056, 59.78770637512207, 56.33420154026577, 56.773317268916536, 53.96692248753139, 48.169505391802105, 46.82004363196236, 44.72603028161185, 44.71603182383946, 44.88225705283028, 45.3958956854684, 43.745507444654194, 40.98255974905831, 40.45272486550467, 39.460032258714946, 40.016107014247346, 39.97772863933018, 40.20903417042324, 40.453030586242676, 40.58380263192313, 39.1956011908395, 36.2820200238909, 36.694183690207346, 36.58457933153425, 37.823971203395296, 41.096055098942344, 44.0796080998012, 42.08471080235073, 43.08095393862043, 43.222016266414094, 43.62259381158011, 47.41631719044277, 49.85640294211251, 48.54351649965559, 47.00589404787336, 48.15964242390224, 49.15644489015852, 48.82194471359253, 44.936265400477815, 45.843648024967735, 46.882431507110596, 47.61219385692051, 47.79309368133545, 46.71147802897862, 47.583727087293354, 47.54286820547921, 48.69575153078352, 48.78025204794747, 45.24169084003994, 41.26734903880528, 50.021669319697786, 47.07322209221976, 48.28839949199131, 48.52772324425833, 45.423070090157644, 45.55767754146031, 47.11991398675101, 44.54497759682791, 42.33526284354073, 48.19484199796404, 50.62309149333409, 49.79110377175467, 53.87988935198103, 53.150790555136545, 48.741394247327534, 49.274984632219585, 44.22208438600813, 43.71143000466483, 45.65446247373308, 47.112187589917866, 44.81384856360299, 43.777493476867676, 40.23863697052002, 36.862118176051546, 34.40625653948103, 36.36305686405727, 36.50930602209908, 38.634721755981445, 41.16106244495937, 39.30140835898263, 39.361305304935996, 37.84491307394845, 39.84908274241856, 39.617179666246685, 38.714848382132395, 41.80746725627354, 42.0436886378697, 43.50528737476894, 42.945279938834055, 45.57813998631069, 54.395153863089426, 58.031493595668245, 58.487205096653526, 58.41303307669503, 49.59001248223441, 70.37700421469552, 59.99160821097237, 56.31045954568045, 65.23075144631522, 62.36293806348528, 63.185465812683105, 63.916061946323936, 63.92450400761196, 62.285361426217214, 62.02900069100516, 62.74779878343855, 63.034703799656455, 65.91922760009766, 67.1114342553275, 68.31016526903424, 66.63601071493966, 70.51027066367013, 69.33107798440116, 70.71116392953056, 69.8961888722011, 70.42878913879395, 68.13139506748745, 71.07632650647844, 22.301487105233328, 0.7285252990467208, 0.8037643560341426, 52.39410046168736, 70.30018493107387, 54.19938836778913, 46.51447922842843, 33.0711532320295, 47.92800685337612, 65.64708750588554, 15.041297027042933, 0.5668613995824541, 0.1275492621851819, 0.06528215948492289, 0.06291648785450629, 0.031426831148564816, 0.011041143027666424, 0.08044998879943575, 0.16260736169559614, 0.1404907163232565, 0.11677912010678224, 0.18597678627286637, 0.16808878470744404, 0.1713949330151081, 0.17964670594249452, 0.2685287137116705, 0.6483855907406125, 63.24821499415806, 58.765230315072195, 51.86721856253487, 39.5190954208374, 60.50735214778355, 51.799616064344136, 90.64719935825893, 13.79590972832271, 0.25094936415553093, 1.8435776914869035, 60.53517968314034, 81.10851778302873, 66.22181470053536, 70.26330389295305, 58.62897614070347, 65.52855123792375, 63.451338631766184, 66.67297513144356, 66.47435392652238, 67.65945952279228, 63.713584491184776, 61.88742419651577, 56.63508633204869, 63.29098115648542, 75.49612426757812, 56.680927072252544, 50.27085256576538, 64.40579877580915, 60.898077147347585, 62.77750928061349, 62.597773279462544, 63.57188292912075, 61.67608083997454, 58.40774549756731, 59.44808537619454, 57.32280513218471, 49.73433004106794, 48.570826394217356, 47.785329069410054, 46.45734766551426, 46.24992656707764, 47.21331514630999, 46.373621872493196, 44.71443721226284, 43.75790997913906, 42.24772596359253, 40.80654450825283, 44.523525033678325, 42.30850533076695, 43.96497671944754, 43.00092111315046, 42.26881374631609, 39.075126375470845, 41.04932151521955, 39.73202991485596, 40.25988456181118, 44.46148109436035, 48.28559589385986, 44.48901680537632, 45.643317563193186, 46.18922363008772, 46.897839137486045, 50.86828299931118, 54.74560710362026, 52.27574137278965, 52.91822392599923, 52.32031406675066, 53.56305497033255, 52.8593726839338, 47.47138513837542, 48.67083876473563, 49.36821208681379, 49.36896596636091, 50.8949362891061, 51.54056290217808, 50.32749080657959, 50.804060799734934, 50.52750859941755, 51.20112950461251, 46.03014809744698, 43.71671758379255, 51.22631672450474, 50.722964899880544, 52.34590775626046, 49.72354643685477, 47.461949484688894, 47.53149053028652, 47.92596755708967, 46.817646503448486, 45.6534549849374, 50.07442351749965, 51.58157811846052, 51.23386941637312, 56.621905599321636, 55.03554153442383, 51.65084818431309, 52.61594602039882, 46.658925328935894, 47.190142904009136, 49.84945126942226, 49.339384010859895, 47.61623076030186, 47.25806849343436, 43.471640723092214, 40.53496374402727, 37.033707414354595, 38.326690741947715, 37.3726544380188, 41.38549620764596, 42.86939866202218, 42.504652976989746, 41.08307933807373, 41.24391623905727, 44.30448307309832, 41.1234518459865, 41.32036031995501, 45.63042170660836, 45.27096707480294, 45.6571375301906, 44.660779748644146, 46.354121753147666, 57.99352169036865, 60.68200206756592, 62.96433939252581, 58.41709082467215, 57.422511781964985, 71.48166356767926, 56.22861671447754, 61.2213351385934, 63.634298597063335, 63.568040575299946, 64.37624113900321, 65.49381719316754, 64.8946531840733, 64.89150565011161, 64.17058835710797, 67.9390480858939, 65.11690521240234, 67.93962478637695, 69.16153499058315, 72.9556405203683, 67.48454557146344, 75.68542793818882, 72.3229375566755, 74.69184943607875, 71.84455408368791, 76.09815093449184, 68.68631294795445, 77.2129407610212, 27.60045085634504, 1.1963785056556975, 0.848810396024159, 58.92030715942383, 76.39732646942139, 62.948448862348286, 57.036198888506206, 47.370545932224815, 67.44413484845842, 74.21914264133999, 20.720269918441772, 1.0473854605640684, 0.2995937296322414, 0.18284001387655735, 0.1395104503525155, 0.1339552705841405, 0.27337152670536724, 0.20756345508354052], [0.020156437431329062, 0.04439984395035675, 0.06979531981050968, 0.013660689383479101, 0.035183709913066456, 0.0653507797313588, 0.05745001296911921, 0.05594293240989957, 0.0554312966497881, 33.55884381702968, 55.59382929120745, 32.964918749673025, 28.830608572278702, 49.09255967821394, 48.33970499038696, 71.40972886766706, 21.798392363956996, 0.1879195270261594, 0.7217913546732494, 53.87604004996163, 76.07586806161063, 62.50284699031285, 66.85894366673061, 60.879184995378765, 67.14213139670235, 63.232963698250906, 65.2619627543858, 61.4985682623727, 65.72831194741386, 60.55628831045968, 61.837709835597444, 53.347118854522705, 58.47494847433907, 42.54830156053816, 53.90233550752912, 61.743916102818076, 57.01128612245832, 57.63745083127703, 54.65767070225307, 54.2736611366272, 53.241652148110525, 50.844398566654746, 50.30556576592581, 47.889430454799104, 44.01963472366333, 42.65271214076451, 44.402442250932964, 40.786474636622835, 40.99299594334194, 42.99485533578055, 42.51966456004551, 41.76058776038033, 40.4845997265407, 37.170156138283865, 38.256607736860005, 37.953954628535676, 35.88792862210955, 33.8107716015407, 38.10356671469552, 37.62995318004063, 37.22391087668282, 34.24915082114083, 35.396360942295615, 33.62495592662266, 37.029496806008474, 36.906374726976665, 39.67074680328369, 39.25726645333426, 39.311528410230366, 39.07812452316284, 43.25964770998274, 47.00705439703805, 43.74460417883736, 43.03653063092913, 42.97041504723685, 39.488141196114675, 40.53930984224592, 39.875551904950825, 41.58948489597866, 40.57863317217146, 44.523507663181846, 44.64990929194859, 44.25055462973458, 44.07550171443394, 44.03824199948992, 42.60942833764212, 40.73197644097464, 45.92063059125628, 42.29183660234724, 39.20869159698486, 46.244892597198486, 44.204845905303955, 43.04874208995274, 42.77439941678728, 43.1747441973005, 44.017769132341655, 44.411575657980784, 42.24639538356236, 43.016915866306846, 42.87580142702375, 45.71288292748587, 45.30792801720755, 48.18052870886666, 44.59450783048357, 47.91097681862967, 47.21377372741699, 43.9155923979623, 42.287636416299, 40.49177374158587, 42.63372966221401, 42.87446389879499, 39.6761976650783, 40.36560835157122, 38.223454407283235, 32.12630592073713, 33.260137285505024, 32.394968441554475, 35.020331382751465, 36.846974577222554, 37.38700941630772, 36.224356923784526, 36.09389407294137, 37.438318388802664, 37.71354695728847, 37.83119732992989, 38.987582547324045, 40.332309109824045, 40.89513404028756, 41.51236336571829, 40.10230984006609, 45.4389328275408, 54.292549814496724, 54.25173609597342, 57.153317723955425, 49.14659234455654, 41.10222509929112, 65.8690824508667, 63.22152696337019, 50.74671384266445, 56.40620919636318, 58.884940828595845, 59.75627967289516, 61.06480612073626, 62.36401503426688, 63.323860032217844, 63.4052859715053, 58.213897705078125, 62.22077792031424, 63.48280702318464, 62.19470827920096, 61.05395998273577, 63.9169374193464, 61.52508953639439, 62.778211048671174, 63.000317164829795, 67.37211677006313, 63.099342891148154, 54.60892561503819, 8.669310808181763, 0.21283192666513578, 0.8400105025087083, 47.51243509565081, 63.090254647391184, 41.02086864198957, 39.563303334372385, 36.52692665372576, 37.81256226130894, 54.45207003184727, 8.047804866518293, 0.2682489672941821, 0.11940130511564867, 0.08633840390081916, 0.11961051103259836, 0.10240893584809133, 0.027533410782260553, 0.06788738111832313, 0.03649067013923611, 0.1291993372142315, 0.04497119079210928, 0.04900039280099528, 0.015384738300261753, 0.01381714513991028, 0.02529325964860618, 0.03495841932349971, 0.03864925966731139, 40.66756664003645, 64.58284582410539, 32.720105920519146, 28.467064925602504, 53.092245033809114, 52.27038778577532, 78.45053999764579, 24.435852118900844, 0.18733305563884123, 0.9741410251174654, 57.18629387446812, 78.41377013070243, 64.83173724583217, 70.29803098951066, 62.96646554129464, 68.89357076372418, 64.77605438232422, 67.02570043291364, 65.1176347732544, 66.89557456970215, 62.91111619131905, 62.37848118373326, 54.99094104766846, 55.20267697743007, 48.377068928309846, 53.42347608293806, 63.48109776633126, 61.67253725869315, 60.24261883326939, 57.68928786686489, 56.48979949951172, 55.41966227122715, 53.471852915627615, 53.24642903464181, 50.247145312173025, 46.96024785723005, 45.147282191685264, 46.63529450552804, 43.555599280766074, 43.36599336351667, 44.90426894596645, 44.53929744447981, 44.561410086495535, 41.615669182368684, 40.19153165817261, 40.80050304957798, 40.15816640853882, 37.960180214473176, 36.80147777284895, 41.293321405138286, 40.6872752053397, 39.24548578262329, 36.78121335165841, 36.60120637076241, 36.1010924066816, 38.38080678667341, 39.25192676271711, 42.15581519263131, 40.924879278455464, 42.16903414045061, 40.50058058329991, 46.15826940536499, 51.18337685721261, 46.771013668605256, 47.227479049137656, 44.61990697043282, 42.401562554495676, 41.65800108228411, 41.88237925938198, 44.21463591711861, 43.29084859575544, 46.37932286943708, 45.871750014168875, 47.193898405347554, 45.48333529063633, 47.68503182274954, 43.603201389312744, 44.57301705224173, 47.9918121610369, 43.90389163153512, 39.53242553983416, 48.26530715397426, 46.260463510240825, 44.276224749428884, 46.630302224840435, 43.918451581682476, 46.43431438718523, 47.32100180217198, 45.453305176326204, 44.62897089549473, 43.95943900517055, 47.84475353785923, 48.20182146344866, 50.29751975195748, 46.69710220609392, 51.41328927448818, 49.888798918042866, 46.312342235020225, 47.526348863329204, 43.843435355595176, 44.72577319826399, 44.07926416397095, 43.32712514059884, 42.47050952911377, 39.21545219421387, 34.97789525985718, 35.68240090778896, 33.17515386853899, 37.223740645817344, 39.04778521401541, 40.69892038617815, 38.310390268053325, 39.139147077287944, 39.7770333971296, 40.958209787096294, 39.57965244565691, 40.01130928312029, 42.896058900015696, 44.23712723595755, 42.81547369275774, 42.80576705932617, 47.452447823115754, 57.660994802202495, 55.636498178754536, 58.685027258736746, 53.57836880002703, 45.90444128853934, 64.81547846112932, 59.7640060697283, 55.410369055611746, 58.61289800916399, 62.27732930864607, 62.49997738429478, 62.546683175223215, 63.8954188483102, 64.52845532553536, 64.86180210113525, 61.9305169241769, 63.273659297398154, 64.89627211434501, 65.01242515019008, 63.32984243120466, 64.67687579563686, 62.757220540727886, 64.2021540233067, 67.37985706329346, 67.9530278614589, 68.3752976826259, 56.82581090927124, 7.51272930417742, 0.16083805449306965, 0.8609587784324373, 54.0406984601702, 71.82722527640206, 46.85396473748343, 45.277783257620676, 43.923954554966514, 38.632706778390066, 64.22024713243756, 11.457524759428841, 0.390870993158647, 0.08524417118834597, 0.07928840470101152, 0.03503852716780134, 0.06346477807632514, 0.05464663875422307, 0.031244407008801187, 0.15182263111429556, 0.2308855450579098, 0.22290836168187006, 0.06787556103829827, 0.11224028401608978, 0.15284457270588192, 0.12715850743864263, 0.14054105005093984, 0.11607941479555198, 52.45515775680542, 69.29302270071847, 43.6332106590271, 39.25102002280099, 64.91416372571672, 60.25363867623465, 82.27514117104667, 26.60446654047285, 0.3348450352038656, 1.6693161108664103, 61.72828265598842, 82.22094522203717, 67.54512691497803, 72.68744005475725, 66.53181552886963, 70.36108589172363, 65.91378716060093, 70.05456611088344, 67.24548585074288, 71.22227341788155, 61.30001653943743, 62.61738109588623, 58.11328431538173, 66.24329853057861, 57.92665570122855, 54.123302119118826, 66.00745582580566, 62.17980439322335, 63.53354276929583, 59.46245425088065, 59.3337527683803, 59.13732719421387, 55.931654180799214, 56.85485437938145, 53.8502448626927, 48.87708909170968, 47.09206560679844, 49.5394469669887, 45.939203126089915, 45.90291963304792, 47.19384976795742, 47.0582070350647, 48.876265730176655, 44.75911065510341, 43.504029750823975, 43.092095375061035, 41.728990827287944, 39.811013562338694, 37.08980369567871, 42.72395202091762, 42.061298847198486, 40.61074774605887, 38.98895134244646, 39.98074415751866, 39.65961231504168, 41.32619333267212, 40.83364595685686, 45.80782311303275, 43.93649952752249, 44.37144981111799, 41.50320563997541, 48.70470428466797, 54.79813895906721, 49.65892818995884, 49.305289200374055, 47.39778981889997, 43.941801003047395, 46.18528747558594, 43.65397882461548, 46.69255461011614, 45.009798186165945, 50.06421661376953, 51.14630821772984, 49.34235783985683, 48.682140009743826, 51.28429249354771, 47.34747096470424, 46.87795339311872, 50.965849603925435, 45.71242087227957, 40.9034023966108, 51.10305220740182, 47.71515573774065, 46.36306755883353, 47.84103625161307, 46.755550452641074, 47.59627900804792, 49.80841173444475, 47.29322290420532, 46.73337180273873, 47.539908272879465, 51.75577640533447, 50.925167901175364, 54.40541982650757, 48.89707211085728, 55.601955209459575, 52.846414293561665, 48.014963558741975, 48.297550269535606, 45.59275552204677, 47.315418924604145, 48.25480147770473, 45.36162717001778, 43.129765033721924, 41.426004205431255, 37.32032755443028, 38.184763363429475, 34.434226512908936, 41.21424395697457, 41.705992289951865, 42.84054626737322, 42.079082761492046, 40.60943801062447, 42.06126063210623, 43.13351706096104, 42.967722620282856, 43.15623072215489, 45.04666532788958, 48.63259587969099, 43.36859546388899, 44.97846181052071, 49.37102263314383, 60.96245220729283, 57.806034973689485, 61.52850110190255, 52.66903025763375, 57.27818380083357, 63.031472887311665, 53.68481867653983, 57.92068372453962, 63.140163557870046, 64.10920797075543, 64.10533087594169, 65.06281348637172, 66.67366995130266, 66.75958442687988, 67.11479023524693, 62.29881313868931, 65.02479989188058, 67.30223178863525, 68.45182514190674, 65.82495444161552, 69.64045347486223, 66.27330780029297, 68.93672602517265, 68.53457123892647, 70.56560611724854, 70.49459552764893, 66.20112296513149, 11.669028793062482, 0.2742161128137793, 1.0334044907774245, 63.542193276541575, 76.41946343013218, 56.09937674658639, 55.904566628592356, 55.81130790710449, 56.0079801423209, 75.12636893136161, 18.35912091391427, 0.662093246621745, 0.3212332156087671, 0.23374198749661446, 0.23731189593672752, 0.1734586294208254, 0.1772399286606482, 0.1541669424623251], [0.0684300394994872, 0.04095149166615946, 0.02563276294884937, 0.13434219839317457, 0.03266932376261268, 0.1616478046136243, 0.03332937548735312, 0.18167832121253014, 0.0010222583826232168, 32.8268198285784, 58.1023165839059, 40.84605196544102, 40.46726049695696, 44.9672543661935, 35.51093673706055, 70.74013791765485, 29.702496324266704, 0.04304944730496832, 0.10940075067004987, 45.75729581287929, 76.10210445949009, 62.01134531838553, 68.25464221409389, 62.053771018981934, 65.53609003339494, 65.23631695338658, 65.05455902644566, 63.2823862348284, 58.787311690194265, 60.57637555258614, 54.697650636945454, 49.267206123897004, 30.541960307529994, 45.55763932636806, 63.02102974482945, 57.46128273010254, 57.32069635391235, 54.0410041809082, 51.09762219020298, 48.117678778512136, 47.387183393750874, 45.946602957589285, 43.0483912059239, 42.628125940050396, 43.960488183157786, 40.98883049828665, 41.547180788857595, 39.45113509041922, 41.71258265631539, 39.830631801060264, 42.71225125449044, 40.005799361637656, 40.25281824384417, 38.66017995561872, 37.831252915518625, 38.10564770017351, 37.01377303259713, 34.66648742130825, 36.87392316545759, 38.7287552016122, 37.40510252543858, 35.99190493992397, 35.6001307623727, 35.59017399379185, 35.805106094905305, 37.94328219549996, 39.58060087476458, 37.51969221660069, 39.287234033857075, 38.939285618918284, 45.17823641640799, 39.99319532939366, 40.48502009255545, 40.39346020562308, 41.03437941414969, 39.30639716557094, 41.21351787022182, 41.434769357953755, 41.24875913347517, 37.09782886505127, 38.43842124938965, 40.58952447346279, 43.822177342006135, 42.74661009652274, 46.05439036233084, 41.786952699933735, 43.60400390625, 45.921759673527305, 40.13462591171265, 36.59237173625401, 43.4750349181039, 44.33949157169887, 39.45706537791661, 44.371512344905305, 43.620669160570415, 44.36148956843785, 44.91781793321882, 42.39371109008789, 40.16336366108486, 41.4780079977853, 38.49782487324306, 41.590777260916575, 43.9361903326852, 42.82377331597464, 44.21389593396868, 46.43792050225394, 45.49471296582903, 46.67470816203526, 40.18705701828003, 37.51406764984131, 40.36401721409389, 39.79607146126883, 39.3250287600926, 37.97478185381208, 36.020548888615195, 34.0113000869751, 31.66270821435111, 33.60864503043038, 39.41919074739729, 38.42157881600516, 35.76646716254098, 35.5522472517831, 38.34614222390311, 37.41603551592146, 38.26310430254255, 39.9887832232884, 40.51266350064959, 41.446532658168245, 42.02410166604178, 41.761011600494385, 42.7750039100647, 48.26349714824131, 53.8660763331822, 54.009285654340474, 56.9439754486084, 53.28948702130999, 39.86228779384068, 57.74626309531075, 62.98838015965053, 55.481900760105674, 56.55822883333479, 58.071626390729634, 62.51909187861851, 60.56814888545445, 59.417853764125276, 60.83350058964321, 64.16323021480015, 62.25296892438616, 62.90285478319441, 64.41608905792236, 63.704357283455984, 63.04990645817348, 63.803195408412385, 62.01618821280343, 66.70670168740409, 61.13085569654192, 54.293484347207205, 29.698754719325475, 0.88740943052939, 0.15697448966758593, 1.1282494642904826, 60.561172894069124, 56.52954319545201, 38.91803107942854, 36.71726213182722, 25.822773354394094, 39.311226163591655, 55.22853817258562, 5.485298369612012, 0.3854898304811546, 0.039494422530489307, 0.027905200475028584, 0.012764687284028955, 0.09220621867903642, 0.06478508508631162, 0.046878081147692034, 0.02448459857675646, 0.044161006409142695, 0.04004839548308935, 0.052835957878934484, 0.05482467955776623, 0.05956351384520531, 0.10095289469297443, 0.15904873050749302, 0.08337355870753527, 38.942321981702534, 60.404866218566895, 41.71006393432617, 51.076485770089285, 50.357131821768625, 39.611047880990164, 78.35672542027065, 33.605897017887656, 0.0738206948818905, 0.3657426158232348, 48.63201570510864, 78.96081570216587, 63.70687253134591, 70.94422735486711, 64.54542282649449, 69.08900274549211, 67.88211454663957, 66.72340515681675, 65.58622128622872, 61.28912871224539, 60.44209466661726, 55.520619596753804, 51.073973996298655, 35.360741002219065, 48.59977258954729, 64.03516101837158, 59.31148379189627, 59.02398817879813, 58.09866877964565, 52.92311198370797, 49.167409147535054, 50.79844318117414, 47.86310373033796, 46.83355093002319, 45.78402205875942, 45.40885407584054, 42.380200317927766, 44.79445266723633, 41.939941610608784, 43.30427598953247, 42.850617681230815, 43.89890282494681, 42.275042806352886, 43.384868144989014, 41.62074136734009, 40.40727322442191, 41.06139053617205, 40.04446608679635, 37.13567917687552, 39.63850368772234, 40.47262103216988, 39.475012574877056, 38.33282600130354, 36.65352283205305, 37.96148994990757, 38.517609868730815, 39.69803237915039, 41.07333101545061, 39.68236766542707, 42.10121972220284, 42.394888809749055, 46.48048169272286, 43.5891695022583, 43.10781567437308, 43.52434628350394, 42.47097505841936, 41.22807782036917, 43.706611428942, 44.191991737910676, 41.149472849709646, 38.99374907357352, 40.71497419902256, 42.79635572433472, 45.891680921827046, 44.90346990312849, 47.1389798436846, 44.75921140398298, 46.83698334012713, 47.68693215506417, 40.813906124659944, 37.89912291935512, 44.16646058218819, 46.65411022731236, 43.06326729910714, 46.02341181891305, 44.663395745413645, 46.753424303872244, 45.89735412597656, 42.97672748565674, 43.11406905310494, 42.58243458611624, 41.01559148515974, 43.4555139541626, 45.37863983426775, 44.86967386518206, 47.602667876652305, 49.95067262649536, 48.50797298976353, 48.155261584690635, 42.27023812702724, 39.709312779562815, 40.94887488228934, 42.0835747718811, 41.85391596385411, 40.65311091286795, 37.01528426579067, 35.89076348713466, 33.81168876375471, 37.53687858581543, 40.67164870670864, 40.027974537440706, 37.489665576389854, 38.00841113499233, 40.43818923405239, 40.044010979788645, 40.95367956161499, 42.93246398653303, 43.07914393288748, 43.38148437227522, 43.004489013126914, 42.66903345925467, 46.82166256223406, 50.657776900700156, 56.069680145808626, 58.25210237503052, 58.97024386269705, 55.49067980902535, 44.7010931968689, 61.43017714364188, 62.38633264814104, 57.50182546888079, 58.40789140973772, 61.05932399204799, 63.71810776846749, 63.26630115509033, 60.488876887730186, 63.38035583496094, 65.28735147203717, 64.16191700526646, 64.38095201764787, 64.63169166019985, 66.18150125231061, 67.41593211037772, 68.28310203552246, 66.72728225163051, 69.04568767547607, 64.92973463875907, 58.13722085952759, 28.880472319466726, 0.39286520757845467, 0.07788053953221866, 1.9287728113787515, 68.88247449057442, 61.67246082850865, 46.894959109170095, 42.98091377530779, 41.77335507529122, 46.67506946836199, 64.46993064880371, 9.208127975463867, 0.7298511021903583, 0.10080835994865213, 0.062285796340022764, 0.006474049770206745, 0.09052494460982935, 0.05826959506209407, 0.02128909558190831, 0.11549972875842027, 0.15331035985478333, 0.13173233558024677, 0.1857044765991824, 0.08991432416119746, 0.2636441301022257, 0.23355579748749733, 0.27130764030984467, 0.18144315454576695, 50.16656010491507, 69.4524004799979, 52.13993535723005, 56.369126660483225, 62.04791368756975, 44.61739867074149, 84.20307173047746, 35.651912212371826, 0.20384403823741845, 0.9339833685329982, 53.03432832445417, 80.96858801160539, 69.17532021658761, 74.6649877003261, 65.95468425750732, 70.65857996259416, 70.74641214098249, 69.24845000675747, 67.15446444920131, 61.67240524291992, 60.84817518506731, 60.4512871333531, 52.854456833430696, 40.06520298549107, 48.536453655787874, 64.46733897072929, 62.93162727355957, 60.92033917563302, 59.63745852879116, 54.423818656376426, 52.86365624836513, 54.190591948372976, 50.73294946125576, 48.53576578412737, 48.56218630926949, 49.77530009405953, 45.609914098467144, 47.740068503788535, 44.28397199085781, 44.79116269520351, 45.10347032546997, 47.01756007330758, 44.358057158333914, 44.59983362470354, 44.64381572178432, 41.731898648398264, 43.01532472882952, 43.262562479291645, 38.62993097305298, 41.790791579655235, 42.95258944375174, 41.58185229982649, 41.625087465558735, 39.95762750080654, 39.63774980817522, 40.37026364462716, 41.96895728792463, 44.252559185028076, 41.852543694632395, 45.50367266791207, 43.7522610936846, 51.027205671582905, 46.56594453539167, 45.51124620437622, 46.65444721494402, 45.0430348941258, 45.47166926520211, 47.08998114722115, 48.960377148219514, 44.64914151600429, 42.00678675515311, 43.07875483376639, 46.34371335165841, 47.210233620234895, 47.58360201971871, 50.023694719587056, 47.85377924782889, 48.48674624306815, 49.93256562096732, 43.257090772901265, 38.58364207404, 46.41356011799404, 49.279049328395296, 46.05831956863403, 49.16993134362357, 48.21526275362287, 49.34355640411377, 49.62235287257603, 44.95734623500279, 45.18143606185913, 45.629553181784495, 42.328696795872276, 45.22899300711495, 49.16189227785383, 48.103897026606965, 51.69520895821707, 53.378754002707346, 50.08481107439314, 50.80437346867153, 45.85864571162632, 42.68789087023054, 42.89219570159912, 45.39574977329799, 43.790691580091206, 41.347955090659006, 40.20557049342564, 39.70749929973057, 35.50454092025757, 39.12778329849243, 44.46384000778198, 43.58438914162772, 38.16401604243687, 40.718507358006065, 43.64155197143555, 43.21876103537423, 43.43989092963082, 44.42061179024832, 45.62827123914446, 47.11865636280605, 44.29153510502407, 45.125134808676584, 47.699473653520855, 52.25670678274972, 60.53861904144287, 59.62818963187081, 60.65643269675118, 56.40911701747349, 53.57682629993984, 66.81171676090786, 58.53778798239571, 56.82713801520211, 62.10955115727016, 63.67671734946114, 64.70767715999058, 67.67920630318778, 63.243142809186665, 67.7882443836757, 66.9581708908081, 67.21153695242745, 67.22719819205147, 68.27905818394252, 66.65422194344657, 69.93691226414272, 68.72801603589738, 69.75092288425991, 70.05319036756242, 70.98494379861015, 64.04189382280622, 36.71771723883492, 1.3522929336343492, 0.16366678556161268, 1.768373429775238, 75.27629716055733, 67.88407393864223, 57.15549945831299, 52.81878825596401, 39.361656188964844, 55.54182897295271, 76.25322083064488, 13.639490144593374, 1.1554415651730128, 0.28247543105057304, 0.20931919158569404, 0.18798904972417013, 0.1985327782375472, 0.14928862851645264, 0.12984944161559853], [0.05876156009201493, 0.06188698738281216, 0.06704027764499187, 0.10520232881286315, 0.03112331564937319, 0.09254356593425785, 0.05343678367457219, 0.18034797188426765, 0.10833248549274035, 23.679061276572092, 54.64690446853638, 34.895503520965576, 20.315389701298304, 40.36583069392613, 42.85182319368635, 64.59280954088483, 40.15549830027989, 0.06727851807538952, 0.1948530285486153, 31.280605929238455, 74.56703199659074, 62.280970164707725, 68.47922883714948, 65.01919269561768, 65.45541449955532, 61.68381418500628, 62.45635659354073, 58.78915991101946, 63.46398435320173, 58.51317746298653, 58.74829060690743, 53.02136645998274, 53.910353728703086, 60.26558262961251, 58.252296924591064, 58.67981610979353, 55.840455600193565, 49.42963416235787, 48.95212268829346, 43.73307364327567, 43.889175346919465, 43.77937296458653, 43.86853919710432, 43.210895674569265, 41.506054401397705, 40.425084931509836, 40.40796109608242, 40.53105190822056, 41.57320179258074, 41.73633507319859, 42.39235619136265, 41.596110003335134, 40.59223427091326, 37.177635874067036, 37.541471345084055, 38.813693455287385, 38.060039724622456, 35.506020886557444, 36.93684605189732, 39.332192352839876, 41.01642526899065, 38.32407127107893, 36.10560178756714, 37.01152181625366, 38.74892929622105, 38.94071347372872, 39.82937070301601, 39.17178276606968, 41.016446113586426, 39.175239494868684, 40.33543579918997, 39.23972920009068, 40.50777544294085, 38.98178774969918, 42.64321047919137, 40.677023138318745, 43.90364497048514, 44.481085436684744, 39.067768233163015, 36.60906825746809, 40.60966730117798, 40.806697368621826, 42.191615785871235, 42.65915659495762, 43.52361324855259, 44.12051909310477, 45.6039525440761, 41.442186559949604, 40.58191967010498, 35.93767077582223, 39.454209668295725, 42.61635569163731, 42.52644600187029, 42.57504170281546, 43.365402766636436, 41.46668243408203, 44.08471155166626, 41.50996971130371, 37.7618682043893, 38.04241214479719, 40.68822363444737, 40.91135113579886, 40.06218746730259, 38.81443691253662, 38.617160184042795, 43.09040001460484, 42.384984152657644, 42.39414187840053, 39.09965351649693, 37.55928652627127, 38.98332677568708, 39.121047019958496, 37.540887696402415, 38.826822076525005, 36.63902194159371, 34.70427867344448, 34.12870379856655, 36.53221423285348, 37.90963554382324, 38.19869450160435, 37.1494539805821, 35.04080772399902, 37.861890997205464, 38.07676403863089, 38.230281012398855, 39.33546495437622, 39.71229355675833, 41.936366762433735, 42.60599592753819, 42.860862800053184, 41.540826661246165, 45.42857653754098, 52.82375969205584, 53.896728311266216, 54.02965777260916, 60.647302763802664, 54.85900865282331, 40.630529267447336, 50.88966955457415, 62.90164579663958, 63.971869877406526, 56.66279227393014, 56.68244525364467, 57.159682273864746, 63.28622164045061, 59.947355134146555, 58.39358506883894, 58.791855812072754, 63.409149169921875, 58.94509833199637, 62.86479255131313, 60.307487215314595, 66.00694165910993, 61.655361311776296, 67.86217321668352, 54.596530028751914, 54.418135029929026, 15.467904261180333, 0.2244619626019682, 0.13059224747121334, 3.5171236268111636, 63.097869873046875, 48.974228382110596, 41.976857389722554, 35.70828294754028, 19.162047794887, 24.776610885347637, 55.79320090157645, 5.296776805605207, 0.2704329272466046, 0.0791852470221264, 0.12037521999861513, 0.011629443066859884, 0.07727959499295269, 0.024682802048378756, 0.0697380310988852, 0.006006210901042712, 0.019695640907489827, 0.0441447385320706, 0.06914566324225493, 0.020352383077676808, 0.07396197265812329, 0.11094555777630635, 0.1727643795311451, 0.09807085791336638, 27.819433757237025, 61.43404034205845, 37.9444078036717, 31.674492359161377, 51.010088784354075, 43.90419735227312, 69.95532499040876, 43.79979372024536, 0.12845996474581106, 0.15197034818785532, 31.407716274261475, 77.23706490652901, 65.99150276184082, 72.51795959472656, 66.76222474234444, 68.39332130977085, 64.15099443708147, 64.28641482761928, 60.805499349321636, 64.22012901306152, 61.25929314749581, 61.04373223440987, 53.251820836748394, 54.520957946777344, 61.699781145368306, 61.405677795410156, 61.539680753435405, 58.559570584978374, 51.856844902038574, 50.239384174346924, 45.00720303399222, 45.62855611528669, 46.6335574558803, 45.92097800118582, 46.556540148598806, 44.526940073285786, 42.85812520980835, 42.46268238340105, 43.02135229110718, 43.711909430367605, 43.630323682512554, 43.81238385609218, 42.72005755560738, 42.01219245365688, 42.187189783368794, 41.33809559685843, 42.622716767447336, 38.97387375150408, 37.719876766204834, 38.412622588021414, 41.02532591138567, 42.83870152064732, 40.56405585152762, 40.55844865526472, 40.95357881273542, 40.513365268707275, 41.70815665381295, 40.66761180332729, 39.629116671425955, 41.610319069453645, 41.83571515764509, 42.36294099262783, 42.67851775033133, 42.98327268872942, 42.773277282714844, 44.6791855267116, 41.95852109364101, 45.26117706298828, 46.38286645071847, 41.410422870091026, 39.85692378452846, 41.069662366594585, 43.40364565168108, 42.016104289463584, 45.62957055228097, 45.98876115253994, 45.427642004830496, 48.74493782860892, 43.97212641579764, 40.755426611219136, 37.52970804486956, 39.88730478286743, 45.5503819329398, 44.19807835987636, 45.365000520433696, 45.56479597091675, 43.81543411527361, 43.65247801371983, 42.241246768406455, 39.60311303819929, 39.660279342106406, 41.47961303165981, 43.040522371019634, 42.36348295211792, 39.23267330442156, 40.69678381511143, 44.15737233843122, 44.70145102909633, 44.716313225882395, 40.99253041403634, 39.77229472569057, 41.075227873665945, 41.24455547332764, 40.14493703842163, 39.67341491154262, 38.19393498556954, 36.318494592394146, 36.194729804992676, 38.61637503760201, 40.36014706747872, 40.04365314756121, 37.38307326180594, 37.06725679125105, 39.90793398448399, 40.513938495091026, 41.501843793051584, 42.37876898901803, 42.697944913591655, 42.93212699890137, 44.90948009490967, 44.656037603105815, 44.16319145475115, 46.77299043110439, 53.407359736306326, 56.629117829459055, 58.888609477451865, 62.03217601776123, 58.508883476257324, 45.359101499829976, 53.67607436861311, 65.38422325679234, 66.31504562922886, 58.96427536010742, 58.284230845315115, 60.37708732060024, 64.70641953604562, 62.776189122881206, 61.34280354636056, 62.980389731270925, 66.37559223175049, 62.7339232308524, 66.63408606392997, 62.89300223759243, 66.94614355904716, 65.249678339277, 71.7608699798584, 59.44807842799595, 58.84040982382638, 17.306265592575073, 0.11616077114428792, 0.10707081747906548, 4.4046845606395175, 73.60736765180314, 55.56922919409615, 48.83462865012032, 41.22304732458932, 27.27867977959769, 30.26843752179827, 67.34260777064732, 7.359723891530718, 0.40454428802643505, 0.10528484545648098, 0.058947322624070306, 0.040395415255001614, 0.06304650194942951, 0.02727528249046632, 0.05701694477881704, 0.16040563769638538, 0.10688650701195002, 0.2002932509141309, 0.20156091717737062, 0.08216774091124535, 0.14607964642345905, 0.1689031081540244, 0.26512499206832474, 0.19479833862611226, 38.47837686538696, 68.40307658059257, 46.094894886016846, 27.658273765019008, 56.275440624782014, 54.923373290470664, 75.62329019818986, 48.0772020476205, 0.1958914449704545, 0.234404590513025, 35.468625681740896, 80.67005171094621, 68.05961322784424, 74.18635409218925, 70.58106585911342, 70.43746049063546, 64.3362125669207, 67.19650105067662, 61.44998645782471, 69.09921659742082, 61.92351313999721, 63.55693735395159, 54.58086878912789, 55.162082127162385, 64.54711818695068, 64.44220733642578, 63.29729012080601, 60.575597354343955, 53.58668231964111, 54.29826818193708, 48.5173773765564, 48.453801359449116, 50.48656286512102, 49.16333402906145, 50.33855928693499, 47.23309666769845, 44.03755065373012, 43.463820525578086, 43.281736033303396, 48.35526548113142, 46.23384843553816, 45.41438831601824, 46.587358883449006, 44.927878924778526, 42.890680994306294, 41.846971239362446, 44.48282248633248, 42.67236859457833, 40.078018937792095, 41.01291642870222, 44.601619311741416, 45.16606664657593, 42.61683511734009, 40.677485193525044, 43.724944250924246, 42.43127652576992, 44.885373319898335, 42.710757391793386, 42.932957308632986, 44.793010916028706, 43.60117251532418, 45.672736236027305, 45.57668086460659, 45.39633689607893, 45.334258215767996, 46.75598471505301, 44.67224775041853, 48.821802275521414, 49.00268472943987, 44.707770415714805, 44.177490847451345, 45.20832559040615, 47.11682898657662, 47.23876987184797, 48.19358784811837, 48.26574489048549, 49.05617543629238, 52.78103869301932, 47.88488285882132, 42.62267855235508, 38.04750517436436, 41.87058121817452, 47.97142614637102, 47.44070884159633, 47.07346527917044, 47.396931716373985, 47.345362186431885, 49.08708449772426, 47.34517111097063, 41.49520478929792, 41.83865771974836, 45.17630481719971, 45.76023142678397, 45.86305086953299, 42.749257360185894, 42.68464258738926, 47.78528390611921, 45.9142347744533, 47.96655893325806, 42.440003463200156, 42.998763697487966, 42.51001698630196, 43.11085898535592, 42.975890227726524, 42.90404238019671, 41.082259450639995, 39.554402691977366, 37.47101313727242, 41.5856842313494, 43.026108333042686, 41.91401440756661, 39.7602812903268, 38.77293879645211, 44.13371024812971, 42.274598121643066, 43.19492524010794, 44.59650196347918, 44.80464220046997, 45.14740725925991, 47.60123307364327, 46.408779757363455, 44.958954742976594, 49.071496214185444, 57.68098476954869, 60.17073277064732, 59.300637653895784, 66.43469360896519, 56.97113248280117, 48.97038950238909, 58.56349631718227, 63.02172456468855, 64.15684482029506, 58.27833529881069, 62.33674335479736, 62.85856696537563, 65.43154743739537, 64.64075905936105, 64.81923048836845, 64.876296043396, 68.42827769688198, 64.22481209891183, 68.22709260668073, 65.54426806313651, 71.28368159702846, 68.29339231763566, 76.66623565128872, 63.53082602364676, 65.63487257276262, 21.138525417872838, 0.3477216756769589, 0.18142438626715116, 4.584434458187648, 81.99814428601945, 61.84722191946847, 58.801847321646555, 51.04098742348807, 29.30665397644043, 34.52335105623518, 82.9765270778111, 10.063683986663818, 0.5854006590587753, 0.2268371880054474, 0.1840557586401701, 0.13573208238397325, 0.1906864842666047, 0.12581031263938972, 0.20701324460761888], [0.058584374242595265, 0.07599382541541543, 0.060408507074628554, 0.1296637672930956, 0.061435598747006485, 0.06067751906812191, 0.05207116748871548, 0.16941506282559463, 0.11558812830064978, 22.88804360798427, 59.1781131199428, 41.21412583759853, 32.09559488296509, 32.67865644182478, 45.565271922520225, 55.976758411952424, 55.79866565976824, 0.9529130842004503, 0.24969901410596712, 13.67276680469513, 62.22090298788888, 62.59167970929827, 63.89521735055106, 59.80825219835554, 62.5103371483939, 62.34517846788679, 59.81954302106585, 61.362543378557476, 60.73831026894705, 63.17797565460205, 60.46041011810303, 59.13511071886335, 57.465128558022634, 58.44184725625174, 59.862906728472026, 55.6884046963283, 51.2624716758728, 45.01269905907767, 44.19932556152344, 43.88908502033779, 43.649559770311626, 45.39967203140259, 43.17677654538836, 42.85235473087856, 43.73182644162859, 40.5350957598005, 40.936996936798096, 40.342512539454866, 41.37682485580444, 39.91576113019671, 41.63034725189209, 41.07629789624895, 41.74515233721052, 38.394418307713096, 39.00262539727347, 39.09255940573556, 38.434627532958984, 36.50505025046212, 38.21868446895054, 37.15662799562727, 39.177539348602295, 40.25189413343157, 38.34808424540928, 39.5125606400626, 40.322394030434744, 40.53410564150129, 40.97844988959176, 38.25198023659842, 39.55393368857247, 39.57993037360055, 39.24369314738682, 41.18212243488857, 42.28466953550066, 42.82929365975516, 44.30496597290039, 43.264379433223176, 47.41483722414289, 46.27998447418213, 44.632497106279644, 38.848886081150596, 39.71652848379952, 40.82071883337838, 42.18132550375802, 39.87729242869786, 41.525606632232666, 41.81759078162057, 42.18313203539167, 42.11204848970686, 39.26958908353533, 38.65203319277082, 39.265503542763845, 40.97602496828352, 44.00069393430437, 42.32816873277937, 42.460257462092805, 41.408460003989084, 40.427245821271626, 38.677098819187705, 36.715010915483745, 39.206429958343506, 41.625170843941824, 42.6092164175851, 40.101076534816194, 40.57909175327846, 38.61474568503243, 40.310450077056885, 38.34051765714373, 39.17232125146048, 40.66141401018415, 37.48987749644688, 38.2762120791844, 38.973356110709055, 40.102691990988596, 38.97926902770996, 41.563516003744944, 38.3762001310076, 37.872438362666536, 39.23598064695086, 36.70722893306187, 38.91203825814383, 36.61029461451939, 38.00096614020211, 38.119387762887136, 39.08782073429653, 38.90302644457136, 39.648884296417236, 40.67156880242484, 41.374424253191265, 38.867173739842, 42.20787804467337, 42.837944167000906, 42.722683974674766, 45.434013502938406, 47.96172298703875, 53.0825766154698, 57.17260939734322, 58.048447200230186, 61.9540296282087, 45.552299635750906, 42.424380438668386, 61.22059168134417, 69.14736761365617, 72.92600645337785, 62.71971416473389, 58.50128909519741, 57.44512122017996, 64.36738913399833, 61.18963050842285, 63.78590134211949, 63.08858707972935, 62.199078696114675, 61.62917355128697, 62.17537839072091, 58.84017358507429, 64.7071977342878, 57.692636898585725, 52.365105628967285, 15.91622461591448, 0.09344157989003829, 0.23120510791029247, 5.6329280478613715, 66.639130456107, 49.9065272467477, 44.58212266649519, 29.46373885018485, 37.5040031841823, 34.64663641793387, 44.82595232554844, 5.775591501167842, 0.3303721323609352, 0.017974414696384753, 0.07779508483197008, 0.03519551642239094, 0.0716785733987178, 0.08873481316758053, 0.0281139602552035, 0.016839631034859588, 0.06634151549743754, 0.03996247937902808, 0.03332008634294782, 0.025407429950843965, 0.13574554451874324, 0.019847671767430644, 0.1047323483175465, 0.10218820162117481, 28.47515262876238, 70.35878603799003, 38.916287081582205, 33.30287912913731, 43.73920195443289, 49.06335292543684, 62.295276505606516, 61.16841070992606, 1.2043459181274687, 0.2702622621187142, 13.487084882599966, 64.04538181849888, 64.6897508076259, 66.29477773393903, 62.58985928126744, 61.938271113804404, 63.449837820870535, 60.72034222739083, 62.962956701006206, 64.18661785125732, 63.94607121603829, 64.49090726034981, 61.44305910382952, 60.109658105032786, 61.311779839651926, 60.20352131979806, 56.602937017168315, 54.75114481789725, 46.601543630872456, 46.25078466960362, 46.082683426993235, 46.92209529876709, 46.850403785705566, 46.0407441002982, 45.34350626809256, 45.97916569028582, 43.80936138970511, 42.41050488608224, 41.91228778021676, 43.202106203351704, 43.470449107033865, 43.813231536320274, 44.731679167066304, 44.060389382498606, 41.43198313031878, 40.57677105494908, 40.38718598229544, 39.644684110369, 38.936516761779785, 40.34552110944475, 39.34145777566092, 41.94299186979021, 42.5750139100211, 40.165771211896626, 40.40017911366054, 42.913026400974815, 43.37702710287911, 44.056974342891145, 41.353520597730366, 42.079475334712434, 41.68314661298479, 41.21319130488804, 42.687876973833355, 44.89718525750296, 45.25140789576939, 46.54182038988386, 45.16452414648873, 47.17586088180542, 48.27375963756016, 46.10091550009591, 40.64605849129813, 42.072798115866526, 42.96083000728062, 45.40190935134888, 43.56867579051426, 44.80198451450893, 43.80336162022182, 45.64343568256923, 44.49007640566145, 39.51821994781494, 39.35445090702602, 39.77597727094378, 42.6789276940482, 46.296135561806814, 44.34526552472796, 44.19779348373413, 43.099769660404746, 42.12645557948521, 40.52807807922363, 37.67584603173392, 38.53736359732491, 42.416584559849326, 43.81720243181501, 41.90638528551374, 43.43341868264334, 41.0061662537711, 39.97278152193342, 40.51229524612427, 41.0550468308585, 41.487606934138704, 38.95043747765677, 39.15976585660662, 41.106724057878765, 41.44047730309622, 41.936186109270366, 42.32410403660366, 39.0414206641061, 39.398512908390586, 40.72961752755301, 38.5103941644941, 39.463554995400564, 40.01240015029907, 40.037920883723665, 40.70973178318569, 41.74310956682478, 41.149566650390625, 41.62289530890328, 43.83906146458217, 43.32237952096121, 42.26829263142177, 44.429119859422954, 43.34909881864275, 44.02130923952375, 47.001214436122346, 50.219713824135916, 55.88934312547956, 60.37884521484375, 60.712219783238, 64.0276917048863, 51.3599305834089, 47.76195880344936, 64.01840891156877, 71.3887939453125, 72.33367947169712, 63.70658070700509, 61.572608266557964, 61.08310072762625, 66.69570268903459, 63.854424476623535, 65.75611168997628, 66.49373245239258, 65.27230862208775, 64.40799440656389, 66.70565945761544, 61.84592955453055, 68.8726497377668, 62.194652693612234, 59.62903731209891, 20.316317285810197, 0.1810505406132766, 0.14406982569822244, 6.240713468619755, 75.68209975106376, 58.06183637891497, 54.52162497384207, 34.012317998068674, 39.1884480203901, 41.84947606495449, 55.52153328486851, 7.1579039096832275, 0.5018804350069591, 0.13739002841923917, 0.04700746759772301, 0.029751036249633347, 0.023512503863977532, 0.07146259570228201, 0.05668042872899345, 0.1912393681704998, 0.33117481214659555, 0.19037608163697378, 0.36861151616488186, 0.14990214630961418, 0.2285397137914385, 0.23133419241224015, 0.319902771285602, 0.2534444731261049, 37.87109388623919, 76.84205981663295, 51.063683714185444, 40.13101632254464, 45.52342987060547, 59.76415198189871, 67.43176010676792, 66.2063341140747, 1.3396944382361002, 0.417513589241675, 17.37498848778861, 72.03272519792829, 66.28502941131592, 70.80742427280971, 61.765663964407786, 66.69692557198661, 65.36904839106968, 62.28276974814278, 64.40599332536969, 67.47645092010498, 67.43986170632499, 66.81362056732178, 63.06390707833426, 62.97137791769845, 61.800418853759766, 65.49282360076904, 59.1175456728254, 56.971823828560964, 49.11957080023629, 47.69583279745919, 48.661986759730745, 49.52386563164847, 50.94163165773664, 49.65579455239432, 48.59795216151646, 49.415112427302766, 46.575908252171104, 45.75164345332554, 44.89280789239066, 46.61568668910435, 46.17877353940691, 45.48090689522879, 46.45388398851667, 45.95861291885376, 42.10777187347412, 42.595987047467915, 43.30444622039795, 42.926148074013845, 40.81423963819231, 43.65020595278059, 41.22009434018816, 42.843732016427175, 43.3004857472011, 42.02022804532732, 43.33080073765346, 46.08558429990496, 44.08659451348441, 47.00929866518293, 42.79055050441197, 42.933624335697715, 42.86297505242484, 42.818958214351106, 46.112987995147705, 47.34015103748867, 48.212038789476665, 49.02816029957363, 46.960028988974436, 51.30295882906233, 52.020759854997905, 49.79365723473685, 43.86594751902989, 45.37269565037319, 45.661768504551475, 47.47264971051897, 45.130022866385325, 45.33235093525478, 46.1175251688276, 49.070148263658794, 47.34336805343628, 40.69196176528931, 41.59294509887695, 42.43276344026838, 43.77413054874965, 50.88887398583548, 46.5288758959089, 45.7945624760219, 46.002463000161306, 44.14389630726406, 44.036807196480886, 39.789866719927105, 43.37678044182913, 46.26229783466884, 46.27050018310547, 44.49547515596662, 46.509949002947124, 42.23256846836635, 44.23228434153965, 43.59043754850115, 43.79120227268764, 44.25828102656773, 40.25607694898333, 41.59957020623343, 42.577643803187776, 44.815408434186665, 45.3393998827253, 45.90336084365845, 42.64107043402535, 41.659036363874165, 43.2702819279262, 40.77968277250017, 43.98997286387852, 41.61474854605538, 41.392586844308035, 41.939701897757395, 44.44459697178432, 44.997708320617676, 43.074283667973106, 44.38561371394566, 44.876076630183626, 43.063187394823345, 46.16092014312744, 47.62839010783604, 47.03838382448469, 48.700448513031006, 52.33091354370117, 57.42536401748657, 63.12897000994001, 65.45949309212821, 65.36601897648403, 52.965343134743826, 53.3941581589835, 65.29940659659249, 66.2349328994751, 68.80730193001884, 63.930458613804404, 65.81073147909981, 64.353041103908, 67.67179257529122, 66.8913083757673, 69.96430901118687, 69.21480682918003, 66.2619058064052, 67.47524193355015, 68.04327801295689, 65.90330927712577, 74.26675864628383, 67.58145209721157, 66.55734321049282, 25.263128961835587, 0.2095209743295397, 0.4039264683212553, 6.8221443721226285, 86.44877815246582, 62.007364000592915, 63.55430398668562, 42.92143372126988, 55.53116348811558, 52.38588421685355, 69.03407723563058, 11.160461476870946, 0.8113432664956365, 0.2917959509151322, 0.19398640362279757, 0.09529007891459124, 0.15636697012398923, 0.2435752355626651, 0.1468914050076689], [0.051286173718316216, 0.047985402800674946, 0.12295891850122384, 0.17238502417291912, 0.025998540821352174, 0.11352467616753918, 0.02144581002981535, 0.17664243786462716, 0.2334925580237593, 19.178598403930664, 57.387986183166504, 50.25372873033796, 41.062561307634624, 29.469835894448416, 45.97517047609602, 46.45401947838919, 67.13466208321708, 2.4357568068163733, 0.08667695216302361, 3.4070986849921088, 44.222706249782014, 63.18504892076765, 58.95681299482073, 62.953250067574636, 62.67941461290632, 63.89475876944405, 64.24083464486259, 60.0091871534075, 60.75729969569615, 60.54039083208357, 58.092036724090576, 59.52514089856829, 61.33265222821917, 59.47878251756941, 55.693202427455354, 51.06005328042166, 45.29248564583914, 42.431523186819895, 43.795715127672466, 42.1289187158857, 42.93630634035383, 43.96259696143014, 43.47296435492379, 43.22917638506208, 41.347361019679475, 40.7825072152274, 40.58718293053763, 38.839745725904194, 39.919857093266074, 39.52757569721767, 40.8660488809858, 43.48016963686262, 45.113951683044434, 43.79858125959124, 41.074998583112446, 38.88654184341431, 38.77034364427839, 37.30590309415545, 37.92952823638916, 35.574682985033306, 38.7526535306658, 38.66230263028826, 38.24967690876552, 39.0797677721296, 40.56701578412737, 43.24637317657471, 40.311693804604666, 38.54255390167236, 36.47696910585676, 37.19777870178223, 39.61544261659895, 39.19982916968209, 41.380333696092876, 41.2066912651062, 43.06534481048584, 43.48124313354492, 45.14465229851859, 45.67063788005284, 43.62317746026175, 40.80861507143293, 39.532251834869385, 40.048846926007954, 38.429808957236155, 38.49993017741612, 39.63854537691389, 42.38480349949428, 41.79670449665615, 40.14187288284302, 37.475122996738975, 35.18083129610334, 38.34527717317854, 44.28053263255528, 43.19345917020525, 39.86606413977486, 38.28230217524937, 40.338618074144634, 37.0178724697658, 37.92597770690918, 36.71620600564139, 39.20095477785383, 43.6871634210859, 43.742530141557964, 43.08609560557774, 41.87868281773159, 40.35001311983381, 38.94993025915963, 38.722463607788086, 36.51331513268607, 34.45027685165405, 35.818689823150635, 36.87501750673567, 39.27784354346139, 39.74806635720389, 37.15538774217878, 38.50003440039498, 39.34130491529192, 36.71405553817749, 37.96731948852539, 37.177427428109304, 36.86192710059029, 36.096183504377095, 39.88573101588658, 40.04179450443813, 40.16247081756592, 40.785130160195486, 39.071190220969065, 39.39216225487845, 40.13728012357439, 43.177846567971365, 41.40828629902431, 41.171123436519075, 43.76089423043387, 43.83640725272042, 45.35772923060826, 49.33510044642857, 53.68556560788836, 54.036904743739534, 54.08855765206473, 61.960491452898296, 57.952336243220735, 50.56564726148333, 46.923394611903596, 57.15653821400234, 70.02878134591239, 74.37134293147496, 62.727044514247346, 58.5782264981951, 60.253444126674104, 62.28424971444266, 60.09601879119873, 64.00915391104562, 62.75208582196917, 66.94713020324707, 60.08004488263811, 64.92521136147636, 55.675039836338584, 55.15074266706194, 14.564526404653277, 0.2729973553546837, 0.13246254782591546, 8.218139954975673, 67.8422110421317, 47.25530311039516, 42.212290150778635, 32.55599989209856, 37.2467565536499, 28.511627197265625, 46.546333244868684, 5.353979587554932, 0.3117546242262636, 0.13710349665156432, 0.03661614144220948, 0.037995077270482264, 0.03580716824425118, 0.012801454552183194, 0.016518042755446265, 0.014263798449454563, 0.09753766509571246, 0.027780087099277546, 0.11191183235496283, 0.009176143727797483, 0.11182928856994424, 0.0591889014467597, 0.11356457402663571, 0.2719548541520323, 23.794616767338344, 65.95396859305245, 49.89743552889143, 36.92172677176339, 32.68087986537388, 51.23953219822475, 51.56110872541155, 71.85713727133614, 3.7231405377388, 0.07609774983887162, 2.9427069297858646, 43.85544531685965, 65.43118613106864, 63.24551909310477, 66.50729533604213, 64.43114580426897, 64.733948298863, 66.27801867893764, 63.61077199663435, 61.67161314828055, 62.05818312508719, 60.86134202139718, 62.11991092136928, 63.91850771222796, 59.83325181688581, 57.45952483585903, 55.55772992542812, 48.491314683641704, 44.35355125154768, 47.466896602085654, 44.67712885992867, 46.753399985177175, 45.78219815662929, 47.59918335505894, 45.462483746664866, 45.12456158229283, 43.620971407209126, 40.94572387422834, 42.59138734000069, 43.75796903882708, 41.910561152866904, 45.55006231580462, 45.9717241695949, 46.782057830265586, 44.514794622148784, 43.52337006160191, 42.476217474256245, 40.5636111668178, 39.204387187957764, 39.7784230368478, 38.67804030009678, 42.17051410675049, 41.08636583600725, 41.67017780031477, 41.72998441968645, 41.09537764957973, 44.43882996695382, 42.34982974188668, 41.67618451799665, 38.43693086079189, 39.824406215122764, 41.56679902757917, 41.25131607055664, 43.497529711042134, 43.82525191988264, 46.09525271824428, 46.02246686390468, 47.77540009362357, 46.18423482349941, 43.69204453059605, 42.97495222091675, 42.413676738739014, 41.48495272227696, 39.86076613834926, 41.506943770817344, 41.090371472494944, 43.382012435368125, 44.64647340774536, 43.55298675809588, 35.84703847340175, 35.39803198405674, 40.457866532461985, 45.057334286826, 43.70564562933785, 41.730304036821636, 41.35708849770682, 42.22139923913138, 39.94130965641567, 39.79038436072213, 39.784610407693044, 40.89369576317923, 45.50898803983416, 44.55218635286604, 44.41306952067784, 43.261155469076975, 42.61033507755825, 41.72785479681832, 40.47481318882534, 39.06529120036534, 36.203269141060964, 39.06044135774885, 37.8159773009164, 41.67917224339077, 41.263030733381, 37.810516016823904, 40.88891192844936, 41.829458304813926, 39.366082191467285, 40.89782994134085, 40.04882608141218, 38.567490986415315, 38.9136016028268, 41.48541477748326, 41.80076919283186, 41.54770885195051, 42.69327572413853, 41.078281606946675, 41.93975053514753, 44.114814622061594, 44.2094977242606, 43.63264438084194, 42.13793052945818, 46.177026067461284, 44.96711540222168, 48.13203028270176, 49.34789555413382, 55.22379950114659, 56.496382917676655, 57.091360637119834, 63.82900101797921, 60.481803621564595, 52.208006858825684, 51.21270867756435, 62.70806203569685, 72.60276235852922, 73.81793975830078, 65.387711252485, 60.53357464926583, 62.65419265202114, 65.9714572089059, 61.92887714930943, 66.66627011980329, 64.85178279876709, 69.42124475751604, 62.262772832598, 68.94258335658482, 61.20366586957659, 65.05671296800885, 20.90135039602007, 0.31765977878655705, 0.17350785035107816, 9.378393581935338, 74.5492307118007, 53.66570765631539, 47.06185136522566, 41.30427871431623, 42.005327633449006, 35.64077425003052, 59.984562737601145, 8.353588138307844, 0.26570584518568857, 0.04022915721205728, 0.0855958287471107, 0.017354554297136407, 0.077439084649086, 0.014263857821268695, 0.01879958961425083, 0.08956131631774561, 0.16088023222982883, 0.1729222610592842, 0.2195753433874675, 0.18099287870739186, 0.20734609317566666, 0.16754143764930113, 0.3461644378091608, 0.41437058789389475, 32.75786937986101, 75.23642144884381, 61.924207959856304, 52.423939500536235, 41.718332290649414, 59.708774839128765, 56.16955007825579, 77.32885060991559, 4.1496487600462775, 0.20431643431740149, 5.204859086445399, 50.13355616160801, 67.20310183933803, 66.47455542428153, 66.20460401262555, 68.06207289014543, 67.31828212738037, 70.59631715502057, 65.98084422520229, 64.73364952632359, 65.57859911237443, 64.27253927503313, 62.4707532610212, 67.12531675611223, 62.94826126098633, 62.046621322631836, 57.124882221221924, 51.74972799846104, 46.89152322496687, 50.408694403512136, 46.801113264901296, 49.47024638312203, 49.32583154950823, 50.760311467306956, 48.84719099317278, 47.69091694695609, 45.25114386422293, 44.35364852632795, 45.06526912961687, 44.514402048928396, 43.102917194366455, 47.1795642716544, 47.43735980987549, 49.742351736341206, 47.13141672951834, 45.832235608782085, 43.15149899891445, 42.541061537606375, 42.26912294115339, 42.26718091964722, 40.2186678477696, 44.82372195380074, 43.72995390210833, 42.72478927884783, 45.050907203129356, 43.52143151419503, 47.35383204051426, 45.897399289267405, 43.85145705086844, 41.12208999906267, 42.93514599118914, 45.31823219571795, 44.75929478236607, 48.03038855961391, 45.75224794660296, 46.13501031058175, 48.467673437935964, 50.507136481148855, 50.894314425332205, 46.619928564344136, 46.459477288382395, 44.682749952588765, 44.459733622414724, 43.87738077981131, 45.04633181435721, 44.443655490875244, 46.58712264469692, 47.88143655232021, 45.33063473020281, 38.261846678597585, 37.383740288870676, 43.41312994275774, 47.62259531021118, 47.23921455655779, 46.25528015409197, 44.18350451333182, 45.555266516549246, 41.38497509275164, 42.25931208474295, 40.5523863519941, 43.30285160882132, 49.807640484401155, 48.641621589660645, 46.893878664289204, 46.46173545292446, 45.73804235458374, 44.75540379115513, 43.28447362354824, 40.85803760801043, 38.1014266695295, 41.21334416525704, 42.14479534966605, 44.23994125638689, 45.3232661655971, 41.238045011247905, 43.00537143434797, 43.815062386649, 41.35912431989397, 42.24448810304914, 40.629445348467144, 40.19917467662266, 41.253327574048726, 45.746123109545024, 44.190379755837576, 44.011467116219656, 44.33643436431885, 44.36298343113491, 44.74024282182966, 46.242234911237446, 47.505281925201416, 47.107004233769004, 44.275932925088064, 49.6255281993321, 48.32889011928013, 49.53895364488874, 50.8453608921596, 58.36446516854422, 57.838295459747314, 59.45674283163888, 65.26239354269845, 61.98194054194859, 57.211887563977925, 58.53544643947056, 66.98973655700684, 69.20344652448381, 68.66177885872978, 63.75849069867815, 64.24768556867326, 65.67715236118862, 67.6585145677839, 65.67621435437883, 69.1199152810233, 67.57136331285749, 73.69043336595807, 66.33156149727958, 71.61458260672433, 65.4153025490897, 69.7559255872454, 25.17220136097499, 0.37220731750130653, 0.4291269874998501, 10.404266442571368, 84.39935139247349, 59.18115643092564, 61.5841839654105, 48.13464627947126, 53.07092101233346, 42.342374324798584, 74.34225082397461, 11.311360716819763, 0.5201657052550996, 0.2007956246712378, 0.21388603081660612, 0.1724982038140297, 0.15258792362042836, 0.08789590639727456, 0.14937218331864902], [0.014432251553184219, 0.023489859454067688, 0.015081049774640372, 0.06311710351811987, 0.04753742380333798, 0.03221016590084348, 0.050663241251770935, 0.26814547713313786, 0.18353856567825588, 17.161430392946514, 59.75211770193917, 34.49541582380022, 37.324149063655305, 36.256547927856445, 42.18268387658255, 45.977869851248606, 69.4568681716919, 10.190505981445312, 0.23224986184920582, 0.23248135085616792, 22.519844668252126, 59.2419809613909, 57.984732219151084, 63.06547042301723, 61.23787879943848, 63.13447993142264, 58.34455163138253, 58.85482733590262, 55.823418617248535, 55.55520078114101, 53.39817074366978, 53.09577819279262, 52.102953570229666, 53.14210878099714, 48.99836989811489, 41.329455511910574, 40.66630206789289, 43.035832336970735, 43.179493291037424, 45.09870386123657, 41.58672646113804, 44.69899831499372, 42.47594996861049, 41.902855600629536, 41.962672642299104, 40.849616391318186, 38.48548139844622, 39.22648593357631, 39.917800426483154, 41.70324775150844, 43.00328002657209, 46.93357024874006, 46.90973097937447, 44.91286039352417, 45.321060112544465, 44.32794713973999, 40.812346254076274, 40.70311362402779, 37.99169724328177, 39.05768639700753, 38.411483083452495, 38.48269517081124, 38.244017601013184, 40.89974764415196, 37.57280077253069, 37.16530629566738, 37.316457407815115, 38.34139313016619, 37.66700097492763, 40.309644086020334, 39.29548501968384, 38.24417046138218, 38.59236901147025, 40.63915198189871, 40.141407353537424, 41.06266553061349, 41.8879725592477, 38.99798747471401, 38.90076480593, 37.66791466304234, 38.118460178375244, 40.26572799682617, 39.63832998275757, 36.392763887132915, 37.35139989852905, 40.85507420131138, 41.67533336366926, 40.872535024370464, 35.89364004135132, 35.31273937225342, 37.69893489565168, 42.895173004695344, 40.992075307028635, 39.01217222213745, 38.59635380336216, 37.25939185278756, 37.43804046085903, 40.224990708487375, 41.478869574410574, 40.98866374152047, 41.14299712862287, 41.6484751020159, 41.36185843603951, 44.22130618776594, 41.27774006979806, 40.32899134499686, 36.71354137148176, 38.07809114456177, 35.84931400844029, 34.2271180834089, 33.14089577538626, 35.647983006068635, 35.24268763405936, 35.843335083552766, 35.254655906132285, 38.006521224975586, 37.84608384541103, 38.56231457846505, 37.281118869781494, 36.879912512642996, 40.7623678616115, 40.21140003204346, 41.055804184504915, 40.67755814961025, 41.37081118992397, 41.91608149664742, 42.82729952675955, 41.2653340612139, 41.04287011282784, 41.05878496170044, 40.3742345401219, 41.96009138652256, 44.21392025266375, 42.5359650339399, 42.7930657523019, 47.58208383832659, 52.76241404669625, 55.55796269008091, 53.84031241280692, 57.7735139301845, 62.292323521205354, 57.02838216509138, 46.263267108372276, 41.88324778420584, 58.35616207122803, 72.73324257986886, 79.37034252711705, 62.300341742379324, 62.43493529728481, 61.962360518319265, 62.277565547398154, 60.85482461111886, 63.296435492379324, 60.35481834411621, 60.943817138671875, 55.16919708251953, 54.3572792325701, 21.835200445992605, 0.3498064880924565, 0.3380531487720353, 9.152402554239545, 67.02625628880092, 45.13878454480852, 48.113089493342805, 30.703908920288086, 33.67369753973824, 30.557409627096995, 39.639389583042686, 3.4314701429435184, 0.22246174993259565, 0.0717856597953609, 0.04234887007623911, 0.038887076013322384, 0.040182955762637515, 0.03601034198488508, 0.0918993783582534, 0.022683636019272462, 0.05684766725503972, 0.04240046248638204, 0.10376753258918013, 0.037882091011852026, 0.04519199626520276, 0.10066687861191374, 0.2300384890820299, 0.12879075056740216, 22.860606908798218, 69.00330366407121, 38.656931672777446, 37.269397258758545, 39.21816199166434, 50.424154145377024, 51.48302834374564, 77.71049431392125, 11.060843416622706, 0.12180116134030478, 0.18912600300141744, 22.769734893526348, 62.16629014696394, 59.72167764391218, 63.7795854296003, 62.31855297088623, 62.9375957761492, 60.66479137965611, 59.086132866995676, 57.94030196326119, 58.6230354309082, 54.82826634815761, 56.53662688391549, 56.2982828276498, 55.443494592394146, 50.222979477473665, 45.073853628976, 44.25019679750715, 43.91511297225952, 46.6566150529044, 48.35822193963187, 44.03572327750069, 47.404272488185335, 44.44362422398159, 44.18836825234549, 43.76807171957833, 43.842448711395264, 41.70125361851284, 42.216514655521934, 42.26576001303536, 45.121455737522666, 45.93726805278233, 47.947666781289236, 49.343337535858154, 47.74614470345633, 47.208107471466064, 46.179840087890625, 42.109335218157085, 42.71860190800258, 41.387921128954204, 41.04419027056013, 41.91557080405099, 41.60610498700823, 40.828632831573486, 40.49417781829834, 40.8847325869969, 39.195375374385286, 40.099971771240234, 40.03465870448521, 40.27193621226719, 40.746591976710725, 39.67398813792637, 40.83772802352905, 41.434015478406636, 43.91702720097133, 43.4103159223284, 42.75614649908883, 43.13337114879063, 41.261404854910715, 40.45245041166033, 39.31971338817051, 39.080434799194336, 42.33723613194057, 42.96971675327846, 39.32330213274275, 40.79055322919573, 43.04014022009713, 45.392432008470806, 42.4260584286281, 36.91035257066999, 35.46880633490426, 38.4293086869376, 44.16801003047398, 43.783118043627056, 41.11898068019322, 40.791880335126606, 39.95371913909912, 39.74965054648263, 40.44990389687674, 43.84040246691023, 42.12373535973685, 43.29599721091134, 43.39372362409319, 44.695638860974995, 46.19293049403599, 40.26957729884556, 41.7223414012364, 38.85769639696394, 38.90762267793928, 39.85623591286795, 37.78541912351336, 37.32249886648995, 37.78758348737444, 36.40857103892735, 38.41487727846418, 36.8326404435294, 40.695373330797466, 41.1251472064427, 40.85418135779244, 39.21392706462315, 40.762781279427664, 41.468839849744526, 41.546409538814, 43.30305658067976, 43.41298055648804, 44.935674803597585, 43.05305344717843, 45.03275850840977, 43.551072529384065, 43.10932690756661, 42.53746237073626, 42.43587275913784, 43.566052845546174, 45.863544191632954, 44.09543262209211, 44.316399233681814, 50.00224215643746, 56.34652764456612, 57.97371932438442, 55.59267936434065, 61.05061789921352, 64.9660598209926, 60.025466782706125, 49.48780448096139, 47.64942577907017, 62.15067754473005, 74.4448548725673, 75.76287950788225, 64.04763303484235, 65.50246770041329, 65.98711844852993, 65.01560742514474, 63.32326248713902, 65.68875585283551, 63.656845501491, 65.25632776532854, 60.15572466169085, 60.9665516444615, 27.34662273951939, 0.5100884288549423, 0.30623780882784296, 11.034488030842372, 74.10884693690709, 51.8585124697004, 54.430002553122385, 36.53768593924386, 43.026528699057444, 39.38225759778704, 50.23104286193848, 5.050496169498988, 0.22627316255654606, 0.14539519457944802, 0.018582831602543592, 0.0237637127949191, 0.010758350836113095, 0.03479570662602782, 0.029802380994494473, 0.10840046791625874, 0.15349630559129374, 0.19792046823671886, 0.22095381441925252, 0.18007669358381204, 0.09889447050435202, 0.19916670636406966, 0.29778480955532616, 0.2652402887386935, 29.539185864584788, 79.60692868913922, 42.54414653778076, 49.47100373676845, 51.73028693880354, 58.39555835723877, 57.907138211386545, 86.78257656097412, 12.653224621500287, 0.41399139538407326, 0.6587692392723901, 27.679705483572825, 66.30414390563965, 63.34258542742048, 67.08624703543526, 65.35149724142892, 68.15024553026471, 62.589240891592844, 63.53980309622628, 60.290241786411826, 61.508191517421174, 55.940648623875205, 58.75627408708845, 59.77822208404541, 59.38405772617885, 53.37117351804461, 47.97510869162423, 45.33452919551304, 46.343650817871094, 48.530572005680625, 51.68907022476196, 46.42763022014073, 50.59513194220406, 46.39119039263044, 46.425236565726145, 45.2560145514352, 47.18872199739729, 43.29478475025722, 43.881344727107454, 42.98290096010481, 47.259103775024414, 47.83677353177752, 51.21231957844326, 50.9030761037554, 49.418617793491904, 49.44319357190813, 49.14008188247681, 45.63847466877529, 45.60137128829956, 43.26278134754726, 43.7235163961138, 43.19124616895403, 44.25012036732265, 42.76083653313773, 43.956552028656006, 42.02525159290859, 41.562984466552734, 42.99922227859497, 41.50541516712734, 42.30002505438668, 43.94355542319161, 42.04589121682303, 43.555019106183735, 45.24449791227068, 46.70528718403408, 44.43534197126116, 45.31630407060896, 46.257864883967805, 43.98192684991019, 45.609750815800254, 43.471435751233784, 42.99417093821934, 45.292086124420166, 45.56072432654244, 43.229040895189556, 43.27845300946917, 44.88196522848946, 47.567982469286235, 44.91205440248762, 37.885438442230225, 38.33696017946516, 40.394502435411724, 47.109526429857524, 47.92438336781093, 45.3475535937718, 43.21190663746425, 42.81442104067121, 41.900100639888215, 43.41739266259329, 46.8521408353533, 43.48902859006609, 46.91279166085379, 47.438950947352815, 46.812035833086284, 49.70943464551653, 45.003857476370676, 44.92163944244385, 39.885241167885916, 42.456998756953645, 41.05353559766497, 40.290109225681846, 40.61035517283848, 40.409604345049175, 40.33388982500349, 39.582775660923545, 37.798683234623496, 42.22202457700457, 43.84693029948643, 42.974552699497764, 41.76896381378174, 42.75895357131958, 44.15630578994751, 44.189994130815776, 45.32696260724749, 45.65372249058315, 46.64477184840611, 45.00087669917515, 46.78023392813546, 45.79195690155029, 45.40548767362322, 44.58700030190604, 44.15086187635149, 46.26122086388724, 48.21614864894322, 46.65479809897286, 47.149273599897114, 52.407038007463726, 57.78784458977835, 59.66495949881417, 57.745804514203755, 64.99567304338727, 65.40604754856655, 61.44812434060233, 53.33823210852486, 55.504711696079795, 67.57677595955985, 72.84838812691825, 70.7762268611363, 63.81324945177351, 70.59216908046177, 67.48590047018868, 68.89915016719273, 66.30327538081578, 70.00275339399064, 68.94614778246198, 67.79902103969029, 65.71433912004743, 69.8675970349993, 31.53947843824114, 0.9252651163509914, 0.5692806754793439, 11.687353798321315, 84.64155169895717, 57.189048835209434, 67.79328877585274, 42.83009270259312, 51.42321130207607, 47.11286851337978, 65.37769195011684, 9.524941512516566, 0.5085420204060418, 0.41349573912365095, 0.10709850849317652, 0.10461186763963529, 0.09219927048044545, 0.09639761769878012, 0.09106710087507963], [0.04887972891862903, 0.04591388627886772, 0.09337391637797866, 0.04547045685883079, 0.05569616618699261, 0.12673769359077725, 0.05253950932196208, 0.17640944250992366, 0.18207902328244277, 13.240957975387573, 64.11282103402274, 37.96474865504673, 39.526189531598774, 43.276427609579905, 43.95784786769322, 35.726532391139436, 69.62343733651298, 20.042976890291484, 0.17392212312136376, 0.14407382905483246, 8.716093029294695, 48.41357823780605, 57.91493756430489, 62.19792529514858, 59.547854559762136, 60.37906060900007, 61.23069436209542, 57.18238203866141, 55.239558015550884, 54.186971936907085, 49.36876099450247, 52.43680756432669, 46.76157454081944, 45.336648396083284, 42.34270783833095, 41.30158281326294, 40.84024327141898, 41.89718239648001, 43.46746138163975, 42.603602273123606, 40.765379905700684, 41.44239500590733, 40.35003049033028, 39.660939420972554, 38.64132949284145, 40.75141750063215, 40.689526421683176, 40.10769121987479, 39.77133240018572, 42.34994786126273, 49.722181115831646, 50.60991423470633, 49.545926162174766, 48.90217556272234, 46.42859601974487, 43.38296086447579, 42.20841653006417, 44.052781105041504, 46.894983427865164, 43.41957787105015, 40.38785300936018, 38.67678962435041, 38.73108284814017, 38.34474563598633, 37.974740164620535, 40.11834280831473, 39.26592738287789, 38.024923528943745, 35.4623236656189, 37.834605421338765, 36.77994530541556, 38.300770487104145, 38.173788683755056, 40.05209173474993, 38.92596244812012, 40.4528568812779, 39.767184325626914, 37.2906413759504, 36.388219765254426, 35.55591242653983, 36.24125494275774, 36.52813911437988, 39.370584624154226, 38.73005451474871, 38.86636080060686, 38.15033156531197, 39.748775073460166, 43.978289467947825, 38.06555312020438, 35.074311937604634, 39.66505970273699, 44.57297536305019, 40.3600880077907, 37.40276098251343, 36.94650404793875, 38.24591098512922, 38.56024748938424, 39.723195280347554, 36.97078800201416, 37.493063245500835, 38.23377595629011, 37.963807174137656, 39.22209119796753, 39.54383448192051, 40.93511397497994, 39.091280937194824, 37.66580935886928, 38.61445038659232, 36.727444716862266, 37.643502167293, 36.282700947352815, 36.75764158793858, 34.91445473262242, 36.40637193407331, 36.890647479466026, 35.48474202837263, 38.41718060629708, 37.06127091816494, 37.520418303353445, 40.473361015319824, 42.34652934755598, 40.98033285140991, 40.744167055402485, 42.2023229598999, 43.33025182996477, 46.4081301007952, 44.92215708323887, 44.327412128448486, 43.076524462018696, 42.43518836157662, 39.91460772923061, 39.53858164378575, 40.60330275126866, 42.88066169193813, 43.4495975630624, 45.258050373622346, 46.393361704690115, 50.62278924669538, 56.137244428907124, 56.21539429255894, 55.13665172031948, 56.516609123774934, 64.17882197243827, 55.16282558441162, 45.1337297303336, 43.15593194961548, 63.21063218797956, 82.94512122017997, 61.274725096566335, 60.26906367710659, 62.372262545994346, 61.531954356602256, 63.94978155408587, 60.860654149736675, 64.09180273328508, 54.63509947913033, 54.27464778082711, 18.825058426175797, 0.8714702629617282, 0.12186000389712197, 8.708426560674395, 67.48585878099713, 44.472389766148154, 42.95728990009853, 25.166745288031443, 38.196033341544016, 36.20906741278512, 35.01548154013497, 2.608934359891074, 0.06630823335477284, 0.09310747603220598, 0.03301719509597335, 0.014784874328012978, 0.1351283219243799, 0.055110916162707975, 0.015904299349391034, 0.018481731581102525, 0.024703626288101077, 0.010342486901208758, 0.0689855832606554, 0.02441121501448963, 0.06670674375657525, 0.0802898206082838, 0.2581557588917868, 0.239895404449531, 17.190030915396555, 74.68388680049351, 42.45817647661482, 40.68699380329677, 47.77903400148664, 49.70962224687849, 40.124627453940256, 78.38984748295375, 22.15345573425293, 0.07624290205006089, 0.07860110979527235, 7.418626376560756, 52.12975972039359, 61.51487568446568, 65.5022314616612, 63.087878363473074, 61.956134932381765, 63.07027857644217, 58.624751635960166, 58.14080613000052, 57.51387711933681, 51.292460100991384, 54.18568304606846, 49.01250948224749, 48.23418269838606, 45.6786595753261, 43.697227886744905, 44.455113070351736, 44.12313508987427, 45.89846931185041, 45.32169587271554, 45.08680854524885, 43.82144430705479, 43.42971529279436, 43.58641801561628, 42.23859255654471, 43.86100040163313, 42.48322473253523, 42.57988807133266, 43.316001074654714, 46.44965600967407, 51.402220794132774, 51.64198228291103, 51.298077719552175, 51.47671243122646, 47.72945513044085, 46.197332177843364, 43.63242551258632, 45.770341055733816, 48.89640508379255, 44.973021371024, 41.909216676439556, 41.31597253254482, 39.354051385607036, 41.1739513533456, 40.74790866034371, 41.61644390651158, 40.46635028294155, 39.94104215076992, 37.430508613586426, 39.69722638811384, 38.140027386801584, 40.455087253025596, 39.09733281816755, 42.15780585152762, 41.035654408591135, 41.480919292994905, 41.03174604688372, 40.31679030827114, 37.66586494445801, 38.494284766060964, 36.854624543871196, 38.5810330254691, 43.34035798481533, 43.13131448200771, 40.18641778400966, 41.901969705309185, 44.315989289964946, 45.547289984566824, 39.15702131816319, 35.13924285343715, 40.360657760075156, 45.318993023463655, 43.81105327606201, 40.54717172895159, 38.943572657448904, 40.9571293422154, 40.754825592041016, 43.03385557447161, 40.721835545131135, 40.0330536706107, 40.025539193834575, 39.902545656476704, 40.96012054170881, 42.56576933179583, 42.556128706250874, 40.52017797742571, 40.00566734586443, 40.331784520830425, 39.35313769749233, 39.3386298588344, 38.67283957345145, 39.71584061213902, 37.13261154719761, 39.74189288275582, 39.090912682669504, 37.822206360953196, 41.14591537203108, 38.811935561043875, 39.62087263379778, 43.21298360824585, 44.753965514046804, 43.95838287898472, 43.250924246651785, 44.62318999426705, 45.79337780816214, 49.666168212890625, 49.09746510641915, 47.30223471777779, 45.55853564398629, 43.57903208051409, 44.25679758616856, 42.62500619888306, 43.979918820517405, 43.8964501108442, 45.39007656914847, 45.94530364445278, 49.6709555217198, 54.49281079428536, 57.92448786326817, 58.1108454976763, 58.808038166591096, 59.940587588718955, 66.85045991625104, 57.51177528926304, 49.64190510341099, 49.59950372150966, 64.70136819566999, 77.68491799490792, 64.49204676491874, 61.74946076529366, 64.35067176818848, 63.7499235698155, 68.08329963684082, 64.15829004560197, 67.23366001674107, 59.39919785090855, 62.63327857426235, 23.78691816329956, 0.8485986930983407, 0.2321946562400886, 11.366730911391121, 75.09651252201625, 50.49414334978376, 53.98565483093262, 33.90021228790283, 42.91339118140084, 46.86410910742623, 48.59438426154, 7.181593792779105, 0.25423873907753397, 0.060039601155689785, 0.06858520010220152, 0.022911167470738292, 0.024323283661422983, 0.03440243451456938, 0.02845357042471213, 0.2418622060545853, 0.14278396112578257, 0.18017257058194705, 0.125070275206651, 0.1319081982863801, 0.22454067266413144, 0.19334692507982254, 0.37778547246541294, 0.46772238505738123, 23.58819099834987, 83.6228415625436, 46.95703431538173, 53.731322969709126, 53.4710191317967, 59.31518718174526, 44.80193935121809, 85.98937020983014, 23.78395996774946, 0.20989526781652654, 0.14555066052292073, 9.510891386440822, 58.83845738002232, 64.80113043103898, 70.50290557316372, 65.8731610434396, 67.28816863468715, 67.24891131264823, 63.86964103153774, 60.02069337027413, 60.073041098458425, 52.92561680930001, 56.96284328188215, 51.78549385070801, 51.72380774361746, 48.40555306843349, 45.8186970438276, 47.135613441467285, 47.365300042288645, 49.41226713997977, 48.08755138942173, 46.85547249657767, 47.22933074406215, 47.2710268838065, 45.838245800563264, 43.05668388094221, 46.99669115883963, 44.760173729487825, 45.3642257962908, 46.228682449885774, 47.68980523518154, 53.92470523289272, 55.08688177381243, 53.41167456763131, 53.3226820400783, 50.935072558266775, 49.04831007548741, 46.57871185030256, 49.722730023520334, 51.874906744275776, 47.62041357585362, 44.03107840674264, 43.03333445957729, 42.5928429876055, 43.485696928841726, 41.83672612054007, 43.924823079790386, 43.422127859933035, 42.655592169080464, 39.123103686741416, 42.006911822727744, 40.2693966456822, 44.10176937920706, 43.767571449279785, 44.8978522845677, 44.131389549800325, 45.06648506437029, 45.06389686039516, 43.486218043736045, 39.88146482195173, 40.969743796757285, 39.696406500680105, 40.48611095973423, 45.77161257607596, 45.39400577545166, 46.0152268409729, 44.947917529514854, 45.91442584991455, 47.94415099280221, 39.96607303619385, 35.82222645623343, 44.40484980174473, 49.69705990382603, 45.206838675907676, 42.19431516102382, 41.76448222569057, 43.212584086826865, 44.42787960597447, 45.755899224962505, 42.48359298706055, 45.26475885936192, 43.31582389559065, 41.65615633555821, 42.880484512874055, 44.116857392447336, 45.12056636810303, 43.341563497270855, 42.678111280713765, 41.64842299052647, 41.8247196333749, 40.84953301293509, 40.00866896765572, 41.969124044690815, 39.693748814719065, 40.75520426886422, 41.418913568769185, 40.127080168042866, 44.66038022722517, 40.0413498197283, 42.55912685394287, 45.2713839667184, 46.68795142854963, 46.82659230913435, 45.246815136500764, 47.350917271205354, 47.26757362910679, 51.15457309995379, 50.789354937417166, 49.027812889644075, 48.69848564692906, 46.550252028873985, 44.34009953907558, 43.09156036376953, 47.81701980318342, 47.38025951385498, 47.63637358801705, 49.45703785760062, 51.24488231113979, 57.03080708639962, 60.923500605991904, 60.52413204738072, 61.09233488355364, 61.630278314862935, 68.78200353894914, 56.738809040614534, 52.56887892314366, 57.049497740609304, 74.44918360028947, 76.95914391108921, 63.13458415440151, 67.1018318448748, 65.50350993020194, 67.93634523664201, 71.11099801744733, 70.68133531297956, 71.28402205875942, 65.55903993334088, 67.21650491441999, 31.130226067134313, 1.0036396022353853, 0.25168592748897417, 12.810777630124774, 88.03567722865513, 57.73210961478097, 59.88584968021938, 37.26039586748396, 53.0219292640686, 59.31702150617327, 65.84393692016602, 10.364336013793945, 0.349885279578822, 0.29066363881741253, 0.15477636190397398, 0.10410128360880272, 0.1833731931235109, 0.1303048471787146, 0.13311064376362733], [0.01981976192577609, 0.07763172074088029, 0.03236979804933071, 0.13835745650742734, 0.027567724298153604, 0.0872164892831019, 0.017225661481331502, 0.1565470668886389, 0.12048103074942317, 13.03417090007237, 61.10739162990025, 50.094069549015586, 34.79592888695853, 27.341783319200786, 44.81234080450875, 33.944573061806814, 72.02037824903215, 33.56681340081351, 0.1509239250527961, 0.040145459917507, 1.6718853158610207, 33.34834466661726, 55.09914187022618, 56.41805240086147, 59.99583271571568, 58.289410727364675, 54.639525481632774, 55.29786034992763, 53.65040077481951, 51.75604043688093, 51.85494109562465, 47.15994603293282, 43.184304918561665, 41.470090525490896, 43.26591845921108, 40.30328301021031, 43.4773382459368, 41.92848750523159, 46.49632011141096, 44.12906190327236, 46.234591892787385, 44.984242711748394, 42.36801665169852, 41.475680351257324, 41.70393214906965, 40.56258283342634, 40.71082265036446, 39.524011271340505, 43.90568079267229, 49.85505846568516, 51.740549428122385, 53.25638232912336, 53.52620867320469, 50.62002386365618, 49.50119365964617, 46.05379976545061, 41.97998060498919, 43.2912654876709, 47.863131523132324, 46.53258970805577, 44.0804557800293, 40.95936666216169, 39.90133319582258, 37.34592124394008, 37.62887968335833, 38.1075792993818, 39.91253021785191, 39.85525969096592, 38.57835102081299, 37.71929311752319, 36.736088275909424, 35.740251609257285, 36.82607439586094, 37.28752163478306, 38.675813402448384, 38.275711808885845, 38.79994297027588, 37.14338820321219, 37.113191332135884, 36.32308040346418, 36.722198826926096, 35.35021448135376, 37.60464784077236, 36.461005619594026, 38.809809412275044, 39.682857513427734, 41.79217079707554, 40.11758198056902, 38.58213431494576, 37.48084136417934, 39.01990556716919, 41.110205105372835, 40.162390913282124, 40.09347867965698, 37.35162571498326, 39.13554791041783, 39.19039004189627, 37.9485628264291, 37.566939967019216, 34.41459437779018, 35.70166826248169, 35.784396989004954, 37.01659747532436, 37.82121276855469, 38.78889186041695, 36.493248735155376, 37.239203861781526, 36.42942258289882, 36.817962374006, 37.12548964364188, 36.85196338381086, 38.26618235451834, 37.58802774974278, 35.25478097370693, 38.73851047243391, 37.786833081926616, 42.77454880305699, 39.123927048274446, 41.15267596926008, 46.34662117276873, 45.739213126046316, 42.601611614227295, 43.5594277381897, 44.98729644502912, 48.3465176991054, 48.91645063672747, 49.36353594916207, 51.35525791985648, 48.79857792173113, 45.357909883771626, 43.910975319998606, 40.50519418716431, 41.81811884471348, 40.15328529902867, 42.56610631942749, 41.826449734824045, 43.892854418073384, 45.98728118624006, 48.72138690948486, 52.91942943845476, 55.84804303305489, 55.256469930921284, 54.54484585353306, 59.16288961683001, 59.61677374158587, 50.92929513113839, 44.50537633895874, 49.5769533429827, 72.11927890777588, 55.8050788470677, 61.715866225106375, 56.00792455673218, 59.966073581150596, 55.515328543526785, 60.446138518197195, 49.96115745816912, 54.668933732169016, 15.434307983943395, 1.101727973137583, 0.16351009825510637, 11.400438359805516, 68.07676833016532, 49.61047492708479, 40.63559103012085, 28.863673312323435, 35.74963862555367, 30.04224239076887, 38.69180120740618, 2.375614285469055, 0.1896207093128136, 0.03691532449530704, 0.034959291240998676, 0.03422509599477053, 0.0459335264749825, 0.10162695816584996, 0.018081289050834518, 0.07404659276029893, 0.023941395671239922, 0.02857391709195716, 0.09434333935912166, 0.03883168041439993, 0.08033607634050505, 0.056033479515463114, 0.18946240709296294, 0.31868599514876095, 18.188867466790335, 69.13672297341483, 50.86559404645647, 41.29329013824463, 38.19748898914882, 48.7795398575919, 38.419431822640554, 77.31996386391776, 37.88657099860055, 0.0493342829202967, 0.05606985577781286, 1.0633131201778139, 34.807685238974436, 58.60272584642683, 60.801795959472656, 62.5375462940761, 60.37389809744698, 58.02279792513166, 58.490644454956055, 55.78525216238839, 54.80579587391445, 55.20190225328718, 50.71430744443621, 45.8134754725865, 43.47604240689959, 46.66605070659092, 44.17279039110456, 44.148016589028494, 45.97799144472395, 50.284224373953684, 46.86357409613473, 49.13606929779053, 47.99915293284825, 45.13531739371163, 44.12059204918997, 44.369507789611816, 40.74856179101126, 43.26369156156267, 41.98294053758894, 46.37845434461321, 50.06448759351458, 53.49385438646589, 54.53293316704886, 55.23830039160592, 54.28300298963274, 51.95395639964512, 47.38090917042324, 45.72876303536551, 45.96731206348964, 52.15161527906145, 48.89960125514439, 46.371589524405344, 42.742180619921, 43.15273577826363, 39.92234454836164, 40.374182428632466, 39.7655063356672, 40.50478424344744, 39.4678316116333, 39.20479365757534, 40.37634679249355, 40.0052296093532, 37.557327134268625, 39.80991574696132, 40.00246770041329, 41.1538919040135, 40.286336353846956, 41.45244557516915, 39.656009674072266, 40.82610021318708, 38.32588127681187, 38.59797968183245, 37.88174894877842, 39.96080977576119, 41.144421509334016, 43.5904757635934, 43.52482918330601, 44.0640823500497, 41.45093086787632, 38.43401261738369, 38.790291922433035, 39.990176337105886, 43.876588685171946, 42.106083461216514, 42.07434409005301, 41.80322885513306, 41.36713906696865, 40.99346842084612, 39.10262039729527, 39.21356575829642, 37.106288296835764, 37.49991416931152, 36.187500204358784, 38.57782643181937, 40.26029450552804, 40.04511226926531, 38.70233467647007, 37.93786260059902, 38.151474543980186, 38.64847918919155, 38.89680780683245, 39.12303420475551, 40.323196547372, 38.89860044206892, 36.90070152282715, 40.344708170209614, 39.53421470097133, 44.374548707689556, 41.891884395054404, 42.60848338263375, 49.282523427690776, 45.73563480377197, 43.561981201171875, 44.61033582687378, 47.47302838734218, 50.47915955952236, 49.99515846797398, 52.11524840763637, 54.74766377040318, 50.89014203207833, 49.181017194475444, 45.37609331948416, 42.859674658094136, 43.16210889816284, 42.718525477818076, 45.67582471030099, 45.13052313668387, 47.634233542851035, 47.67137166431972, 50.2898211479187, 53.95579147338867, 58.59123352595738, 56.826029777526855, 57.83643681662423, 61.97925158909389, 60.59656701769148, 53.03870916366577, 49.76686498097011, 53.177468163626536, 69.36504077911377, 58.71768379211426, 63.667184420994346, 58.720219884599956, 63.37872995649065, 62.08364827292306, 65.45245456695557, 57.8259311403547, 63.07489912850516, 20.153394188199723, 0.8270434811711311, 0.19220192437725409, 14.262080005237035, 75.1138413293021, 55.22201034000942, 52.72546700068882, 34.18640858786446, 29.378786700112478, 37.88962473188128, 51.5531565121242, 6.996240607329777, 0.053275550183440955, 0.040445423285876, 0.05977947118559054, 0.048833266233227084, 0.14264566211828164, 0.052426434853779416, 0.018169473158195615, 0.13646244390734605, 0.2723037568586213, 0.11883749679795333, 0.25463682200227467, 0.07682655073170151, 0.18188714714986937, 0.18666263589901583, 0.2555885352194309, 0.5638641204152788, 24.164544071469987, 77.16915321350098, 62.56403282710484, 49.790113653455464, 37.538862296513145, 61.0062050138201, 43.956979342869346, 87.7099734715053, 39.135203974587576, 0.3059844709932804, 0.14054626119988306, 2.6346409576279775, 42.33677407673427, 62.51019123622349, 65.21991225651333, 65.97716167994908, 64.17406245640346, 61.44687366485596, 61.21805558885847, 57.52083226612636, 57.08107382910592, 58.1044670513698, 53.65255471638271, 49.257506438664024, 46.09802852358137, 47.72855881282261, 46.22011184692383, 47.263373443058555, 48.86926194599697, 53.172653062003, 50.869043827056885, 52.98205355235508, 51.209290163857595, 48.63190105983189, 46.703310421534944, 46.12763827187674, 45.983459677015034, 46.98084231785366, 43.98867702484131, 49.53866182054792, 54.19873523712158, 56.35799217224121, 56.905503273010254, 59.64996528625488, 55.71279287338257, 54.74599620274135, 49.668464592524934, 47.41031742095947, 46.52531147003174, 54.02068417412894, 49.10160623277937, 48.13205460139683, 44.69290474482945, 44.772395610809326, 41.89865888868059, 41.811278343200684, 41.21635968344552, 43.66982766560146, 44.509555680411204, 42.34598043986729, 42.28699370792934, 42.52364935193743, 39.69511760984148, 41.976582935878206, 42.26737894330706, 44.46806103842599, 41.67615325110299, 43.26723861694336, 41.80106796537127, 42.130825996398926, 42.75838729313442, 41.52222980771746, 41.119835308619905, 44.09145825249808, 45.130081926073345, 47.47310481752668, 47.32627201080322, 47.28062929425921, 41.960119179316926, 40.30578783580235, 39.267039094652446, 41.95136097499302, 46.34386273792812, 46.91392074312483, 46.86433492388044, 44.935528891427175, 44.99217060634068, 45.00439943586077, 42.459461893354145, 42.62069831575666, 39.165105547223774, 40.09657757622855, 38.09929704666138, 41.52159057344709, 41.51534761701311, 43.9134384563991, 40.59110518864223, 40.72833211081368, 39.76317521503994, 39.28049080712454, 41.33816507884434, 41.93263905388968, 42.622345038822715, 41.28948252541678, 38.69871466500418, 41.30827392850603, 41.4129763330732, 45.911987032209126, 44.213076046534944, 43.31195374897548, 51.51786661148071, 49.59769024167742, 46.583919525146484, 48.76746736254011, 50.91980389186314, 52.35902942929949, 52.94679839270455, 53.13698101043701, 57.269905022212434, 52.669395038059776, 50.984790393284385, 47.53499589647566, 44.28455216544015, 46.21994856425694, 43.82308060782296, 50.186525753566194, 47.00682510648455, 50.13539743423462, 50.8737963948931, 54.26527118682861, 58.49751622336251, 61.21010684967041, 60.013321331569124, 60.327998297555105, 65.55371066502163, 59.72306033543178, 51.30729450498308, 53.77376256670271, 65.567565373012, 70.04510266440255, 60.396618706839426, 67.31194537026542, 60.728853770664756, 68.70166846684047, 66.49148123604911, 70.35836914607457, 64.62779372079032, 70.8088069643293, 24.589184965406144, 1.185766652226448, 0.2790863114808287, 16.394401379993983, 88.40433474949428, 63.06958375658308, 60.445033754621235, 42.52816220692226, 53.82310519899641, 47.64513874053955, 70.32355867113385, 12.764858722686768, 0.35040354462606565, 0.14574514222996576, 0.23005686381033488, 0.14115010308367865, 0.26604712115866797, 0.17819918718721184, 0.10658098983445338], [0.04465407405846885, 0.1362941807934216, 0.034760463517159224, 0.05514334335124918, 0.058356284696076594, 0.09317045086728674, 0.036742664474461756, 0.24730345979332924, 0.13353467386748108, 10.15944058554513, 54.487439836774556, 45.23247752870832, 37.16471569878714, 19.322898592267716, 42.09520953042166, 38.27434648786272, 62.46281147003174, 47.63517154966082, 0.4079746625253132, 0.01597206124902836, 0.1316183145557131, 14.355601889746529, 41.937412466321675, 52.95984016145979, 57.27728748321533, 58.10164608274187, 60.67927142551967, 56.260891096932546, 53.4000745500837, 54.10007776532854, 51.18659039906093, 48.265797001974924, 45.75513144901821, 42.518097741263254, 43.78222172600882, 43.262124742780415, 44.5770400592259, 46.229335580553325, 49.68211432865688, 49.01961054120745, 50.52192572184971, 47.76636048725673, 46.00585719517299, 39.83213261195591, 41.57785013743809, 38.30515480041504, 41.21838160923549, 41.216342312949045, 47.29648508344378, 51.54694482258388, 53.17195476804461, 48.93342508588518, 53.56990589414324, 53.34907129832676, 51.47663600104195, 46.38280044283186, 46.17059898376465, 42.984137739454, 50.90966647011893, 49.5612712587629, 45.01018033708845, 43.867034912109375, 47.590310505458284, 42.91673673902239, 39.70621040889195, 40.101653235299246, 40.662015029362266, 37.65177399771554, 36.62392350605556, 37.27514689309256, 36.50589793069022, 37.03536455971854, 35.090963295527864, 37.41742515563965, 39.406777790614534, 39.67030906677246, 39.34816626140049, 39.53860943658011, 36.242491722106934, 37.05942269733974, 37.46204996109009, 36.362014634268625, 38.38973869596209, 37.67289999553135, 38.18834515980312, 39.51011140005929, 45.770942074911936, 41.66413981573922, 41.64045340674264, 39.86252403259277, 40.25728246143886, 42.409681524549214, 42.455661228724885, 38.90101841517857, 39.94108731406075, 37.80116374152047, 36.56252922330584, 34.4672269821167, 36.127860341753276, 36.017324924468994, 34.9056305204119, 36.2384409223284, 38.856688908168245, 36.38143832342965, 37.67940698351179, 38.69266625813076, 36.484372411455425, 36.14238207680838, 36.006346770695274, 38.35593918391636, 36.3535030909947, 37.67663812637329, 37.27068267549787, 39.47786481039864, 37.77435411725725, 39.73169987542288, 42.91640322549002, 41.497032165527344, 45.236827101026265, 51.53966311046055, 46.748074190957205, 41.4640143258231, 42.53508608681815, 46.5025908606393, 49.53443384170532, 53.76373284203665, 52.516284533909385, 51.46857609067644, 55.72916282926287, 50.481341293879915, 46.54598930903843, 42.45089823859078, 40.88636541366577, 40.17907353809902, 40.872243200029644, 44.40385273524693, 43.71090541567121, 44.020058563777376, 46.93367794581822, 47.31247288840157, 51.8402213369097, 53.40279476983206, 58.446954182216096, 56.06626163210188, 57.48009845188686, 53.95605550493513, 59.6637852532523, 47.572964327675955, 53.10958773749215, 64.40841129847935, 64.79476588112968, 60.19899109431675, 59.54919556209019, 55.98458555766514, 58.21784775597708, 49.46600798198155, 49.176285471235005, 15.77775570324489, 0.3666037310447012, 0.2674523671822888, 18.284827300480433, 68.01864664895194, 42.21134172167097, 36.44967310769217, 25.24359236444746, 49.172168663569856, 33.351266384124756, 38.32837220600673, 8.828102333205086, 0.1511920549507652, 0.014886518873806511, 0.060062834194728305, 0.017759765232247964, 0.024992456593151604, 0.06379204908651964, 0.053533529197531085, 0.05244366964325309, 0.059603676332959106, 0.08128563181630202, 0.037393952919436355, 0.06450466691915478, 0.08602116163820028, 0.06794593869043247, 0.2454755407358919, 0.19808645147298062, 12.938745209148951, 62.64975275312151, 50.095407077244346, 42.5355863571167, 29.77207558495658, 49.519206864493235, 44.10868631090437, 68.06919479370117, 54.68275022506714, 0.9194167958838599, 0.04259667106504951, 0.06883821223995515, 14.089327812194824, 48.32175431932722, 56.48886844090053, 61.8715614591326, 60.57561125074114, 63.617553438459126, 60.151118006025044, 56.62422282355172, 55.63439982278006, 54.30381631851196, 51.56009776251656, 48.3223796572004, 44.89368683951241, 46.207546029772075, 44.92241416658674, 49.28010198048183, 48.96250329698835, 53.07258857999529, 52.59480265208653, 54.02544716426304, 49.154099873134065, 48.31909315926688, 42.51620088304792, 44.677441528865266, 41.358724798474995, 43.83151224681309, 42.13873304639544, 49.8398870740618, 54.73590394428798, 56.330425194331575, 51.4958929334368, 55.236052649361746, 54.56637484686715, 52.78018406459263, 47.20526565824236, 48.09046268463135, 45.07007728304182, 51.52766704559326, 50.7987072127206, 49.200784819466726, 45.01933806283133, 48.88889060701643, 44.03907230922154, 41.73501491546631, 41.72768804005214, 42.29510572978428, 39.648540360586985, 39.80057389395577, 40.31348296574184, 37.322776794433594, 38.12427929469517, 37.837829385484966, 39.33980757849557, 41.54722247804914, 40.92657811301095, 41.92507593972342, 40.96544286182949, 39.61286136082241, 38.11847407477242, 39.36029781614031, 38.5777256829398, 40.534185545785085, 41.06717143739973, 42.53747974123274, 43.08510201317923, 46.867690903799875, 43.80902092797415, 41.13210930143084, 40.29623406273978, 40.8386139188494, 43.916478293282644, 44.684789248875205, 42.945794105529785, 42.535648890904014, 40.31426811218262, 39.0252799987793, 37.96012462888445, 38.20504168101719, 37.593839917864116, 36.634404863630024, 39.32484463282994, 40.124266147613525, 40.11277730124337, 39.57096372331892, 39.5719746862139, 38.22126225062779, 36.13588203702654, 37.53837592261178, 39.247195039476665, 38.76258945465088, 38.91163873672485, 39.43928493772234, 39.42950882230486, 40.0547320502145, 43.16135501861572, 43.70743131637573, 43.17739493506295, 47.15069450650896, 52.58710752214704, 49.91479212897164, 44.14534500667027, 43.77469335283552, 49.362750802721294, 52.46758460998535, 56.68020098549979, 54.52239622388567, 53.394050461905344, 57.271464892796104, 52.384063788822715, 48.70285258974348, 44.27512345995222, 44.552526814596995, 41.25023215157645, 42.92761066981724, 46.80799198150635, 46.63706629616873, 45.15725285666329, 47.972576073237825, 49.62714712960379, 54.497361864362446, 55.15493590491158, 60.91642039162772, 58.77272047315325, 62.35913045065743, 56.65102897371565, 60.30083084106445, 52.42088229315621, 54.62209245136806, 65.83249323708671, 66.61786202022007, 62.73680673326765, 64.45876489366803, 62.147335461207796, 64.99093437194824, 56.48029783793858, 58.29055718013218, 17.89693021774292, 0.33601618664605276, 0.1635665116565568, 22.180921963282994, 75.33548886435372, 48.40596301215035, 48.48412677219936, 26.524393762860978, 37.774235997881206, 41.67323848179409, 55.82272032329014, 14.272094964981079, 0.0906768346737538, 0.09173840949577944, 0.033982641861907074, 0.02099864697083831, 0.024705831526911685, 0.051128217551325045, 0.09398325439542532, 0.13759627592350754, 0.23341409223420279, 0.1769428796001843, 0.19558929332665034, 0.14149122977895395, 0.16222244235021727, 0.21469278181237833, 0.3527004670883928, 0.4087819292076996, 17.766074793679373, 75.65419578552246, 58.54819638388497, 46.96094962528774, 27.297808170318604, 58.58716882978167, 51.08479928970337, 74.35326371874127, 58.8682165145874, 0.8865303748420307, 0.09003739684287991, 0.13840951371405805, 17.07972652571542, 55.93686532974243, 61.838689531598774, 68.76603657858712, 64.26823139190674, 68.67072119031633, 62.16940293993269, 59.63662474496024, 59.02637141091483, 57.22972011566162, 53.63887371335711, 50.62165321622576, 47.91660138538906, 49.3512932232448, 48.142588070460725, 51.700722353799, 50.55430432728359, 56.36791072572981, 54.45428998129708, 56.466307640075684, 51.95817048209054, 51.968064716884065, 44.05830144882202, 47.395312786102295, 43.465484619140625, 46.71919052941458, 44.5090206691197, 51.16274070739746, 55.63520581381661, 58.714001246861045, 53.732375621795654, 56.8470515523638, 56.370325224740164, 55.423918042864116, 50.26712833132063, 51.23614147731236, 47.67902857916695, 56.17076601300921, 53.08280938012259, 50.78376858575003, 48.1621298789978, 51.419184820992605, 46.0465076310294, 43.01379612513951, 44.94767781666347, 44.587649958474294, 42.17848021643502, 40.26289313180106, 42.32766498838152, 40.06860065460205, 41.03055790492466, 39.91057082584926, 41.2990015574864, 43.90124436787197, 43.776016984667095, 46.08954129900251, 44.84411144256592, 42.1833404813494, 40.46286923544747, 43.10087442398071, 43.177822249276296, 44.34103754588536, 45.652353695460725, 45.867744377681184, 45.815514768872944, 51.42105041231428, 46.35236733300345, 42.948604651859824, 41.5661597933088, 42.95011241095406, 45.951654297964915, 47.444440024239675, 45.660302434648784, 45.57332835878645, 44.32773174558367, 42.622688974652974, 39.321662357875276, 40.34446498325893, 40.95795965194702, 39.36245175770351, 41.780747958592, 42.41879061290196, 42.75365904399327, 42.01198400769915, 43.23194176810128, 40.07942247390747, 39.344584465026855, 40.0553434916905, 42.010378973824636, 39.90974746431623, 42.31268119812012, 42.691358021327424, 42.347106048039024, 41.17708499091012, 44.09545694078718, 46.66169766017369, 45.65619257518223, 51.535765171051025, 56.12264626366751, 50.71104873929705, 46.57877785818917, 46.722647258213584, 51.95048924854824, 53.95533636638096, 58.202982085091726, 58.13511902945382, 55.64724704197475, 58.91176782335554, 55.50772721426827, 50.45244026184082, 46.336824212755474, 47.556448459625244, 43.884005887167795, 44.18702725001744, 50.357010228293284, 48.26097495215279, 49.50321905953543, 51.27898754392351, 52.18100963320051, 57.899658475603374, 59.13747310638428, 63.84553773062569, 60.933707509722026, 63.040894644601, 58.50241470336914, 60.128640583583284, 55.01148339680263, 62.76122965131487, 68.55019078935895, 69.5236542565482, 66.77554443904332, 67.4186349596296, 66.28863552638462, 70.3308334350586, 62.77299989972796, 64.24251610892159, 22.36231337274824, 0.6667232438921928, 0.35207740909286905, 24.75738869394575, 84.39797564915249, 54.00490481512887, 57.75510120391846, 37.115626675742014, 66.01323672703334, 56.24065794263567, 70.25615419660295, 17.98059868812561, 0.20650318983410085, 0.2077300897134202, 0.0656283073393362, 0.15161349305084773, 0.08888549543917179, 0.18957013131252357, 0.19600573740899563], [0.020513051688405018, 0.09666791890880891, 0.040674401713269095, 0.07987450289406947, 0.012144788717185813, 0.14916547441056796, 0.012334831957040089, 0.08462698930608374, 0.09553302159266812, 10.878002439226423, 58.666211536952424, 37.06508547919137, 33.33703299931118, 23.86884437288557, 34.03360727855137, 40.88431569508144, 51.892475264413015, 62.87875843048096, 4.701489457062312, 0.18099274300038815, 0.3534349133925778, 2.6701321388993944, 18.564664261681692, 42.66046980449131, 51.78955159868513, 53.26177065713065, 52.61417422975813, 55.46478039877755, 55.00393417903355, 53.37912573133196, 49.381326811654226, 47.02255930219378, 45.12470402036394, 42.64240796225411, 46.05449111121041, 46.98143638883318, 50.97053616387503, 50.049024377550396, 53.80185760770525, 54.54615906306675, 50.48851530892508, 48.71839223589216, 47.96522487912859, 41.676674365997314, 39.692043031964985, 38.31037637165615, 39.09907334191458, 43.51148864201137, 52.82726853234427, 53.189669200352256, 50.7103956086295, 47.59071350097656, 54.10038348606655, 53.4024577822004, 53.30335562569754, 47.921340056828086, 43.933834893362864, 44.81527641841343, 48.51240941456386, 48.6425769669669, 48.423041684286936, 45.746244703020366, 46.36644785744803, 45.80193451472691, 44.024269172123496, 40.794013432094026, 37.996435914720806, 37.38467829568045, 37.087670598711284, 37.86003930228097, 37.34466014589582, 35.82751750946045, 36.471639837537495, 36.34023897988455, 37.74452550070626, 39.094299929482595, 38.782273701259065, 39.45198971884591, 38.211329800742014, 39.56926141466413, 37.89158064978463, 36.47100755146572, 39.357858998434885, 36.90329320090157, 38.753925051007954, 40.19203887666975, 45.02756820406233, 43.098852498190745, 41.707194328308105, 39.53665699277605, 39.839733941214426, 41.411930629185264, 43.75129181998116, 39.730862617492676, 38.29817533493042, 38.67058835710798, 37.30719198499407, 35.9741210256304, 35.768721852983745, 34.20224353245327, 34.11967461449759, 35.328188691820415, 36.44435773577009, 37.08355031694685, 36.274856431143625, 35.44174657549177, 34.764463969639365, 34.74332407542637, 36.3820150239127, 37.13381011145455, 37.08701399394444, 36.8118896484375, 36.1801107951573, 36.59147889273507, 40.8789621080671, 46.0744880267552, 44.64894001824515, 44.85333170209612, 47.13122565405709, 51.7172451700483, 47.929031712668284, 41.67348166874477, 43.00418676648821, 47.69929994855608, 54.12520939963204, 55.70426395961216, 51.271400111062185, 52.93811314446585, 55.87221234185355, 52.977724824632915, 52.209886346544536, 46.607765742710654, 44.33090707233974, 39.63964319229126, 42.48556627546038, 41.99951546532767, 42.7121331351144, 42.53347063064575, 43.47790799822126, 45.633256571633474, 49.180565561567036, 48.65258584703718, 54.971816131046836, 56.50999443871634, 60.75993306296212, 57.13907739094326, 57.39682081767491, 59.052413259233745, 55.55131673812866, 56.57874338967459, 66.15293720790318, 58.7188024520874, 63.62490463256836, 59.17614677974156, 63.64958463396345, 50.94082219260079, 49.69363791601998, 8.455220307622637, 0.16406830187354768, 0.06156821163105113, 33.654989515032085, 65.35201835632324, 48.894786153520855, 29.22775718144008, 80.46772711617606, 46.73971203395298, 29.39624057497297, 52.00344841820853, 17.830649614334106, 0.11794575250574521, 0.06203468410032136, 0.06064973984445844, 0.027997450703488927, 0.012176304124295712, 0.048632352014205286, 0.06950382116649832, 0.014076799287327697, 0.0919226249679923, 0.06741612497717142, 0.01869976014963218, 0.08349815809300967, 0.13593263019408497, 0.013666008249856532, 0.18554328382015228, 0.23427691736391612, 13.807046822139196, 69.24069581712995, 46.20802892957415, 35.4122063091823, 20.688853638512747, 43.38668509892055, 45.94671065466744, 59.11505126953125, 70.85872282300676, 6.029109988893781, 0.22721823970121996, 0.18394369179649012, 2.2918717733451297, 22.707029138292583, 49.180374486105784, 56.728254726954866, 56.940028871808735, 56.39099611554827, 56.53833614076887, 58.557368006025044, 54.97906657627651, 54.180447578430176, 49.04298428126744, 48.81472206115723, 45.97227307728359, 47.10701813016619, 49.0174948147365, 53.35146147864205, 53.34417976651873, 54.15124429975237, 54.97354623249599, 52.89581945964268, 50.27533762795584, 49.89300257819039, 43.35703713553292, 41.74250159944807, 41.49009438923427, 43.092470577784944, 45.618627139500205, 54.16321604592459, 55.34823131561279, 54.35805395671299, 48.431410789489746, 57.029862131391255, 55.31755154473441, 55.14806066240583, 49.341322558266775, 47.10761220114571, 46.67550025667463, 50.587339537484304, 50.72811351503645, 51.14619704655239, 48.09348167691912, 49.0998101234436, 47.688523292541504, 46.86817727770124, 43.956944601876394, 39.46712984357561, 38.63535404205322, 38.19948312214443, 39.17193215233939, 39.167214325496126, 37.05079650878906, 37.81612321308681, 37.241399492536274, 39.50115864617484, 39.787612029484336, 42.003656591687886, 42.09339257649013, 40.520841530391145, 41.707183906010215, 39.606427328927175, 37.81888859612601, 41.87400320598057, 39.25222206115723, 41.75220823287964, 42.44729559762137, 47.22803143092564, 45.08404663630894, 41.06589991705758, 40.79812676565987, 40.19474172592163, 43.34041357040405, 44.66199915749686, 42.325396401541575, 40.77974183218819, 40.538052218300955, 39.42103896822248, 37.57416956765311, 37.334001609257285, 38.99493721553257, 36.64730766841343, 36.96905442646572, 38.81486075265067, 38.81165415900094, 39.30131803240095, 38.620811462402344, 35.365997314453125, 37.02464696339199, 37.115334851401194, 37.957008361816406, 40.27840151105608, 38.949850354875835, 38.90449251447405, 37.04285819189889, 41.74356467383248, 48.67418432235718, 48.19493579864502, 48.04273550851004, 50.30679212297712, 53.76921149662563, 50.296821457999094, 44.9789342880249, 45.68998166493007, 49.85183450153896, 56.22499322891235, 57.17489535467965, 52.842092514038086, 53.85560539790562, 56.1905197416033, 57.05925301143101, 55.16795335497175, 48.47689022336687, 46.403085708618164, 41.76364844185965, 45.28226137161255, 43.65782812663487, 47.08654178891863, 46.25822966439383, 46.3253492627825, 47.13141672951834, 51.03595345360892, 51.19809661592756, 57.481800760541645, 58.609368324279785, 62.60422815595354, 58.84258460998535, 58.05126469475882, 61.38315173557827, 58.308198656354634, 61.13359328678676, 67.54701682499477, 62.25029386792864, 67.70663779122489, 63.08020755222866, 66.38341590336391, 56.573157038007466, 56.442881788526265, 8.773936782564435, 0.2229677742081029, 0.06273694748857192, 38.932813371930806, 72.04668412889752, 55.457147802625386, 36.51125499180385, 80.5192688533238, 54.67849792752947, 39.87553800855364, 62.482495716639924, 24.04843098776681, 0.014524350807602917, 0.09886886937809841, 0.07554901178394045, 0.0278572229601975, 0.016513778162854056, 0.03014427443434085, 0.039572019795221944, 0.06944990477391652, 0.13875529515956128, 0.16342046377914293, 0.137610701578004, 0.11298307630100421, 0.2188938363854374, 0.11366390476801566, 0.28529178564037594, 0.27174952945538927, 17.333709239959717, 81.29997539520264, 49.14770058223179, 43.436878885541645, 33.85231488091605, 49.30150243214199, 52.686907972608296, 64.0363005229405, 73.21179280962262, 6.275623389652797, 0.3213343716093472, 0.3207074323935168, 3.7895370892116, 30.489709854125977, 55.19370685304914, 64.77281652178083, 61.064813068934846, 60.465482303074424, 58.6870630809239, 62.380725451878135, 57.830638544900076, 56.722199371882844, 51.09734773635864, 52.71541295732771, 45.40006807872227, 50.66102865764073, 51.763134547642295, 56.484452860695974, 54.29775748934065, 58.453360421316965, 58.81368705204555, 55.34408671515328, 52.64153970990862, 53.00254378999983, 46.487131118774414, 44.25910438810076, 42.946478503090994, 45.54169321060181, 47.55613579068865, 56.51899582999093, 57.18333741596767, 57.02816677093506, 50.297182764325825, 57.71128586360386, 57.57478155408587, 58.252432414463584, 52.1787862096514, 48.79197365897042, 50.16327013288225, 53.052303314208984, 54.3891019821167, 53.98691940307617, 52.47639839989798, 51.13328381947109, 50.50042452130999, 49.03888831819807, 44.87527411324637, 41.906173365456716, 40.174585001809255, 41.87791156768799, 41.13904707772391, 40.83745009558541, 37.244710309164866, 39.96727507455008, 39.39428492954799, 42.96640246255057, 43.557659421648296, 45.747676031930105, 43.69309023448399, 43.81187316349575, 43.61990833282471, 42.16868673052107, 40.87008578436715, 45.75603471483503, 40.95006649834769, 45.3622316632952, 45.50135891778128, 50.599696908678325, 45.14543744495937, 41.81108726773943, 40.79852628707886, 41.42574364798409, 44.91001510620117, 48.308260917663574, 44.574170453207834, 44.93012319292341, 43.85027238300869, 42.67870535169329, 40.075934478214805, 40.72065087727138, 40.790789467947825, 39.230818135397776, 40.57190384183611, 42.015075956072124, 41.31742818014962, 41.768609455653596, 40.892233167375835, 37.41842917033604, 38.27827569416591, 40.44680847440447, 41.93713106427874, 41.91825975690569, 42.01689638410296, 41.19413587025234, 39.478785446711946, 44.60937697546822, 51.52085781097412, 50.031709466661724, 49.50959055764334, 54.642957891736714, 57.70067596435547, 52.46701833180019, 47.383667605263845, 46.90396397454398, 50.553057125636506, 57.52457387106759, 59.27076039995466, 54.77505704334804, 57.3910677092416, 58.000212805611746, 58.86750085013253, 55.17837217875889, 52.19062941414969, 49.7371301651001, 43.87598419189453, 47.63790913990566, 46.53163085665022, 49.40252229145595, 47.82575021471296, 47.7227258001055, 51.07813596725464, 54.38922357559204, 54.81196240016392, 61.49364198957171, 63.49281937735421, 64.73522676740373, 62.33335958208357, 62.529847690037315, 63.48416192190987, 62.60232434953962, 65.22075298854283, 72.65271295819963, 65.31010682242257, 70.52065127236503, 68.46908446720668, 70.78134768349784, 62.543466159275596, 62.32221467154366, 13.114512051854815, 0.4260605791849749, 0.17773148656955787, 42.38885082517351, 79.57599530901227, 61.570370946611675, 46.99424539293562, 89.16827528817313, 59.094046865190776, 47.87700012751988, 78.834824017116, 29.847536495753697, 0.2071751430630684, 0.11159050531153168, 0.13564769976905414, 0.15785939432680607, 0.11314153458390917, 0.070432335271367, 0.1883879876030343], [0.03539254602843097, 0.08919802188341107, 0.07315622589417867, 0.0870107099679964, 0.02800423775001296, 0.12338193080254964, 0.06464222632348537, 0.2474392210798604, 0.22303990248058522, 8.899592348507472, 55.52409369604928, 46.521191188267295, 36.875771386282786, 59.45076043265206, 54.79971620014736, 36.965646335056846, 56.15733167103359, 56.43416179929461, 25.631763901029313, 0.476153698350702, 0.38620981041874203, 0.1462737481508936, 6.574381164142063, 20.1784702369145, 45.879757813044954, 47.77970102855137, 69.65241132463727, 65.92620359148297, 58.37415790557861, 55.29053347451346, 52.84855086462838, 48.89696093967983, 50.404647077832905, 48.69798885072981, 50.61801930836269, 50.73889364515032, 52.564452920641216, 51.8703487260001, 53.49899952752249, 53.040442739214214, 50.3696802684239, 47.445777552468435, 44.74400874546596, 39.775657653808594, 39.1267271723066, 40.65394122259957, 42.939860343933105, 47.79976742608206, 50.90230137961251, 52.62782049179077, 51.692888259887695, 48.71985135759626, 56.11539929253714, 53.02763373511178, 50.29836048398699, 47.93463543483189, 45.30746596200125, 44.65760442188808, 54.582862922123496, 46.45745536259243, 51.68785776410784, 43.22906868798392, 43.809684480939595, 42.70231533050537, 43.386935234069824, 38.85237407684326, 38.07303633008684, 37.43181487492153, 35.909534045628135, 34.30535479954311, 36.73092229025704, 36.2918586730957, 36.245503766196116, 36.431583472660606, 36.02076775687081, 35.94846827643258, 37.157764026096885, 34.91543442862374, 38.91440759386335, 39.37325620651245, 39.3008142880031, 37.912623269217356, 38.79498543058123, 39.15129600252424, 40.046599183763774, 43.06134959629604, 45.60022830963135, 41.26914167404175, 40.30328301021031, 42.61209297180176, 41.30262851715088, 43.55655118397304, 43.63346774237496, 41.630531379154746, 37.81830494744437, 38.43385975701468, 38.055433068956646, 35.19157668522426, 38.98160709653582, 35.92890214920044, 36.76806388582502, 36.11628464290074, 36.781418323516846, 36.73882934025356, 34.86804076603481, 33.23903908048357, 36.8790648324149, 33.770402567727224, 34.7363862991333, 33.53804438454764, 35.997157778058735, 34.92622150693621, 36.301019872937886, 38.27959585189819, 44.11300809042794, 44.572763442993164, 43.69702986308506, 44.7388253893171, 47.23587942123413, 48.33356973103115, 50.48798377173287, 41.71486513955252, 43.83609805788313, 45.529137815747944, 53.61970363344465, 53.08344166619437, 52.68237427302769, 52.333831787109375, 54.29297712871006, 64.02111870901925, 72.07412951333183, 54.33848435538155, 46.88166373116629, 41.78766489028931, 41.57841641562325, 41.70278917040144, 42.78695133754185, 42.34365974153791, 46.56493009839739, 44.459896905081614, 45.46352250235421, 47.282050200871055, 53.02609123502459, 57.44558327538626, 57.29917083467756, 58.80839252471924, 56.733323437826975, 57.309085914066856, 58.39753859383719, 58.76635592324393, 59.96405165536063, 61.22025121961321, 62.15732002258301, 59.67707715715681, 60.65098530905587, 52.28602818080357, 40.36615725925991, 3.1550990300519124, 0.21709940981652054, 0.42148345336318016, 48.25022956303188, 60.18800599234444, 41.918047836848665, 35.13591466631208, 46.83502047402518, 24.293167386736187, 34.38557522637503, 48.146096910749165, 27.481424740382604, 0.18813418836465903, 0.056831490980195146, 0.036800244956144264, 0.04357279457950166, 0.027914918792833174, 0.04032279843730586, 0.03702571875016604, 0.04680701478251389, 0.11743828973599843, 0.0637074832671455, 0.09972748080534594, 0.05167999883581485, 0.07494457957467862, 0.15711197443306446, 0.16147662379911967, 0.1321264830018793, 12.918084740638733, 66.80840247017997, 50.0998261315482, 33.729998792920796, 52.45879513876778, 62.50083201272147, 42.119472639901296, 62.09442492893764, 61.12092672075544, 29.965131282806396, 0.38938787845628603, 0.5720753169485501, 0.2131273608122553, 6.980795196124485, 30.0819548198155, 52.54026971544538, 52.18031133924212, 72.84770025525773, 69.02351597377232, 61.26182229178292, 56.893788610185894, 53.80338968549456, 52.27442816325596, 54.17501408713204, 51.169056619916645, 55.13162817273821, 53.44552271706717, 56.14028079169137, 54.625132288251606, 55.710329736982075, 55.075917516435894, 53.089288575308665, 50.21891130719866, 45.81867272513253, 43.94830799102783, 40.877475193568635, 41.93015159879412, 44.78859186172485, 49.186266558510916, 55.16657413755144, 55.24775341578892, 51.09652437482561, 52.958954266139436, 56.95362997055054, 54.16599185126168, 52.38550901412964, 49.26110907963344, 47.434663908822195, 47.07478543690273, 54.14670712607247, 48.576999868665425, 52.86061641148159, 46.84985487801688, 46.385291372026714, 43.645512444632395, 45.60445281437465, 40.086533955165315, 38.67312444959368, 40.50428049904959, 38.16144173485892, 36.81007269450596, 39.02986233575003, 38.41194861275809, 38.46281290054321, 37.53873028073992, 38.38120978219168, 38.824463163103374, 40.527213028499055, 38.679252760750906, 41.38264397212437, 42.03891869953701, 41.380726269313264, 40.087128026144846, 40.50146995271955, 40.91679157529558, 42.46559715270996, 44.13044112069266, 47.21393701008388, 43.334326948438374, 40.8883421761649, 41.253574235098704, 40.37263298034668, 45.17917442321777, 44.78970357349941, 41.995190211704795, 39.8480544090271, 39.6855707849775, 40.08242409569876, 38.231069632938926, 39.54729815891811, 37.93001113619123, 40.34086929048811, 38.884474754333496, 39.41538313456944, 37.61514656884329, 37.5046180997576, 36.25843436377389, 38.20794950212751, 36.17270401545933, 36.3604964528765, 34.70384093693325, 36.46007456098284, 37.65651961735317, 39.30355535234724, 40.75042390823364, 44.48705741337368, 46.65840768814087, 45.46133381979806, 44.286977086748394, 49.932384967803955, 51.107776982443674, 54.612611634390696, 43.90694883891514, 47.25587286267962, 49.60221699305943, 54.634828499385286, 55.27508762904576, 54.72218820026943, 53.93852172579084, 55.2218679019383, 67.06463813781738, 72.24203968048096, 54.5936222076416, 50.60585648672921, 45.76057536261422, 45.068100520542686, 44.26688289642334, 45.49479981831142, 45.8876440184457, 48.21728467941284, 46.51785257884434, 47.84266560418265, 48.97061879294259, 54.305970260075156, 59.92705249786377, 60.40779141017369, 61.6254632132394, 60.47694683074951, 59.60228674752371, 61.21333081381661, 62.26730305807931, 62.87874453408377, 63.62490463256836, 65.3904002053397, 61.724655696323936, 64.57434122903007, 58.00349235534668, 46.40733453205654, 2.4809882768562863, 0.2523561029561928, 0.6887206435203552, 58.1412855557033, 65.98319271632603, 51.66422694069998, 43.28302839824131, 60.804401533944265, 40.07412794658116, 45.821156706128804, 59.563647815159385, 33.186826842171804, 0.09440610384834663, 0.060804418687309535, 0.06814132284905229, 0.06668140047362872, 0.012082952124598836, 0.059521695732006004, 0.11550160151507173, 0.20294849414910587, 0.26277620238917215, 0.12614685243793897, 0.19023748407406466, 0.1797080183667796, 0.2360546248299735, 0.1987972847585167, 0.39282395264932085, 0.38928379118442535, 18.12684784616743, 77.06708417619977, 61.73557826450893, 53.57994604110718, 68.68493025643485, 69.28399699074882, 49.037693228040425, 66.09579522269112, 69.13979407719204, 31.413253988538468, 0.5643767671925681, 0.3353668014918055, 0.21275576789464268, 10.855954068047659, 38.387351989746094, 60.78518976484026, 57.60269594192505, 75.360029901777, 66.48607553754533, 65.47696781158447, 59.93243040357317, 56.41401549748012, 55.558386530194966, 55.97264855248587, 53.623709269932334, 55.89256361552647, 55.65255893979754, 59.0193954195295, 55.77323177882603, 59.51309272221157, 59.130010741097585, 55.97909995487758, 51.66341052736555, 47.28791448048183, 45.74002259118216, 43.84466518674578, 44.81214278084891, 48.18398543766567, 51.168233258383616, 56.580265045166016, 57.89536796297346, 53.01133673531668, 52.860004970005576, 58.80632196153913, 56.827450684138704, 53.863463810511995, 51.077385561806814, 49.526829038347515, 48.72814055851528, 58.47030707768032, 54.268453461783274, 59.07246576036726, 49.71817895344326, 51.81230347497122, 47.19998502731323, 48.63945722579956, 41.17574051448277, 41.270896094185964, 42.140702860695974, 40.009905747004915, 38.91952494212559, 41.23408453805106, 41.50618641717093, 41.06314148221697, 41.341222286224365, 41.54587800162179, 41.553826740809846, 42.544987269810264, 40.62708990914481, 44.736539431980674, 47.98133427756173, 43.3919483593532, 41.9167172568185, 43.07417597089495, 44.58001388822283, 44.702764238630024, 46.937638419015066, 50.77243954794747, 43.42209311894008, 41.46220779418945, 43.71127714429583, 42.235236576625276, 48.07801846095494, 48.62675591877529, 45.27383320672171, 42.72802366529192, 42.611224446977886, 45.05536099842617, 40.15886122839791, 41.253470012119834, 42.78833055496216, 42.97578253064837, 41.804503849574495, 41.76151187079293, 41.673537254333496, 40.3379545211792, 39.43825313023159, 41.5514052936009, 37.29232284000942, 37.5078490121024, 37.169857365744456, 39.66208239964077, 40.784021922520225, 40.05576038360596, 40.925351755959646, 47.73180709566389, 49.20984179633004, 50.18381595611572, 50.62441859926496, 52.0843289239066, 55.42687102726528, 56.28338588987078, 46.066803319113596, 48.33743640354702, 50.80140658787319, 56.92008406775338, 56.3111161504473, 55.52661936623709, 55.85920531409127, 57.0342047555106, 68.85658550262451, 67.21920776367188, 54.651875904628206, 52.91948849814278, 46.16431433813912, 46.41726350784302, 48.81714003426688, 47.033867495400564, 48.96334055491856, 49.43044710159302, 49.5124636377607, 51.44567135402134, 51.157248156411306, 57.31502314976284, 63.76622404370989, 62.80095945085798, 65.4973121370588, 61.48674937656948, 62.58424513680594, 64.64406640189034, 64.88465472630092, 64.86158670697893, 66.59238992418561, 69.63882064819336, 65.53142084394182, 70.71370002201625, 62.70293426513672, 54.88230248859951, 4.338147308145251, 0.30763086836252895, 0.8752948663064412, 61.33583450317383, 73.00639711107526, 56.699312005724224, 54.651987075805664, 63.60087081364223, 39.00476196834019, 50.55459615162441, 71.77603789738247, 39.24062899180821, 0.20226883276232652, 0.13060809804924897, 0.16806753299066, 0.11778215771274907, 0.11184011798884187, 0.24499931771840366, 0.17824592467929634], [0.1311712006905249, 0.06863617843815259, 0.04751206694969109, 0.03251359658315778, 0.06918910305414881, 0.05725696975631373, 0.03847751906141639, 0.10733290163001843, 0.324759127838271, 8.904230271066938, 54.77714497702462, 42.40294872011457, 31.49848406655448, 54.32073865618025, 55.428309304373606, 28.290549414498464, 58.59619453975132, 54.80654975346157, 41.686759676252095, 0.42401870446545736, 0.13632789041314805, 0.20109572713928564, 1.0968274303844996, 12.594202280044556, 34.84021323067801, 35.99703965868269, 55.205900941576274, 53.05723306110927, 52.76765298843384, 52.799482686179026, 56.68413366590227, 49.69913741520473, 52.694915771484375, 52.39470842906407, 52.62007325036185, 52.50847823279244, 55.893366132463726, 50.85480349404471, 52.88658530371529, 52.41896806444441, 49.77437250954764, 45.72604281561715, 40.391004017421174, 37.60405029569353, 39.36686386380877, 39.95089817047119, 45.92186737060547, 51.451288972582134, 52.03311375209263, 53.66975498199463, 47.54191630227225, 49.146255356924875, 53.514462743486675, 51.709060192108154, 50.20315279279436, 50.00247492109026, 46.49750130517142, 46.02384955542428, 52.27675928388323, 43.36495113372803, 45.2156594140189, 43.24454232624599, 42.40463365827288, 40.99306542532784, 41.90494006020682, 42.6976808820452, 36.56407172339303, 36.60840123040335, 37.55990491594587, 37.108174732753206, 36.80027226039341, 35.18180404390608, 36.07740947178432, 35.12962654658726, 34.12615033558437, 35.11552517754691, 35.35136440822056, 37.42598186220442, 38.179413250514436, 39.28651489530291, 39.11879580361502, 37.71040984562465, 39.995856489454, 40.06189911706107, 42.45222187042236, 43.09862320763724, 47.4585622378758, 42.83812134606497, 38.103882857731406, 40.19534969329834, 42.286816528865266, 43.07793494633266, 45.9866350037711, 40.736232212611604, 39.70022453580584, 38.56889452253069, 36.463149138859336, 39.14194025312151, 38.50892462049212, 37.22754825864519, 39.042136328560964, 34.110659326825825, 37.32196385519845, 33.2487804549081, 34.58433192116873, 34.44760526929583, 35.08930615016392, 36.847401891435894, 37.062691824776785, 34.86221470151629, 35.600495542798726, 34.5098090171814, 35.076646532331196, 40.41549641745431, 43.40927716663906, 42.32342658724104, 41.351717540196006, 44.282683100019185, 48.79118503843035, 47.89423860822405, 53.365201541355674, 43.802378450121196, 45.68907145091465, 47.2169177872794, 53.70861973081316, 53.36283220563616, 55.43894352231707, 51.50133337293352, 50.50723723002842, 50.73939391544887, 56.365843636649, 64.69494806017194, 48.95832742963518, 47.166946343013215, 41.87308256966727, 40.576364585331504, 41.12815925053188, 44.237742151532856, 42.62579134532383, 43.77119493484497, 45.797779491969514, 46.40941204343523, 46.313176018851145, 53.65391308920724, 56.878353187016074, 61.49409362248012, 56.72408928189959, 60.534137453351704, 59.75921876089913, 60.51820523398263, 54.863066400800435, 58.170002460479736, 57.961691992623464, 62.34371239798409, 56.34980024610247, 58.091692788260325, 30.154657295772008, 1.4188090158360345, 0.37005058037383215, 2.179001978465489, 58.65675503867013, 58.787568773542134, 49.825281960623606, 30.443744046347483, 28.489653519221715, 26.802048989704677, 37.426975454602925, 56.18209505081177, 34.673859460013254, 0.053966858623815436, 0.08515391246016536, 0.029937531599508863, 0.036750016401388814, 0.033415858168154955, 0.010299511885802661, 0.044935862866363356, 0.15223796239921025, 0.014375775387244565, 0.06854400624121938, 0.127394773332136, 0.03263796865940094, 0.02747510596444564, 0.14027211948164872, 0.13861517767821038, 0.3590921312570572, 12.450840967042105, 64.53232547215053, 48.045584269932334, 36.78231464113508, 58.459148270743235, 64.23657539912632, 35.661702224186485, 66.21964686257499, 56.82737077985491, 48.10433823721749, 0.3120178686720984, 0.556902351123946, 0.7277709852371896, 0.6678564516561372, 15.245796407972064, 43.339850766318186, 42.06596456255232, 61.21297645568848, 56.77610697065081, 54.134200368608745, 56.476650033678325, 58.792182377406526, 53.06688410895211, 56.12376492364066, 54.860450404030935, 55.020627226148335, 56.22099454062325, 56.48781926291329, 53.64650630950928, 55.35138579777309, 55.97956201008388, 51.46109635489327, 47.157396044049946, 42.64551033292498, 40.414148466927664, 41.62100887298584, 41.52912242071969, 48.188029289245605, 53.63339158466884, 54.613803250449045, 55.221457958221436, 50.44424833570208, 50.54658487864903, 55.92777361188616, 53.78171130589077, 52.41495547975813, 51.84097869055611, 47.381583145686555, 47.69514492579869, 54.28952387401036, 47.66370432717459, 47.706293310437886, 46.81757354736328, 46.22434329986572, 44.981421743120464, 43.86696195602417, 44.57384736197335, 39.413639136723106, 37.730920927865164, 39.327467577798025, 39.63423401968819, 39.14284004483904, 36.66664797919137, 38.058014324733186, 35.93480464390346, 36.01119661331177, 38.787686347961426, 38.54619475773403, 39.23498705455235, 41.40317242486136, 41.281770024980815, 41.13944659914289, 40.85234008516584, 39.426423822130474, 41.581077575683594, 44.80332899093628, 44.26027863366263, 47.94949415751866, 43.3757312638419, 38.30023200171334, 38.878419399261475, 40.724708625248496, 46.04349211284092, 48.73495674133301, 42.22271939686367, 41.770950998578755, 40.87583541870117, 38.44496645246233, 38.85940912791661, 40.99406944002424, 38.521896907261436, 41.362129415784565, 37.02891663142613, 39.55067498343331, 35.43915489741734, 36.52669388907296, 35.9434620993478, 37.25526809692383, 37.40611001423427, 38.79675374712263, 37.15344224657331, 38.79521124703543, 36.080404145377024, 37.12986006055559, 41.98090818950108, 44.70909057344709, 45.19725016185215, 44.279320171901155, 45.78117329733712, 52.01926251820156, 51.71247523171561, 56.0869186265128, 44.607011113848, 46.932997022356304, 49.73318011420113, 55.070807116372244, 54.14070735658918, 56.54067420959473, 52.92367826189314, 52.63016550881522, 49.746336528233115, 61.60710607256208, 65.84142862047467, 51.59722893578665, 50.57222720554897, 42.89169543130057, 44.70051302228655, 45.85738461358206, 45.770177773066926, 44.481412002018516, 47.03611176354544, 49.02532543454851, 48.923548221588135, 46.836236408778596, 56.246928691864014, 62.00127737862723, 63.833663259233745, 58.335004806518555, 63.760714122227256, 61.85237748282296, 63.4566262108939, 57.28532654898507, 60.71534647260393, 60.848897797720774, 66.37267398834229, 60.994142941066194, 65.84142862047467, 32.843221051352366, 0.6799034337912286, 0.5682821433459009, 3.205982642514365, 65.6875329698835, 67.41397271837506, 52.047163009643555, 42.76096854891096, 36.888521330697195, 25.313288007463726, 43.28962571280343, 62.860199792044504, 44.28856822422573, 0.17978204653731414, 0.07129534360553537, 0.02995771462363856, 0.038622688235981126, 0.11065780464559793, 0.07476319359349352, 0.030470839768115963, 0.2216058187186718, 0.16221762475158485, 0.18116929781224045, 0.22358114272356033, 0.08244957721659116, 0.18642642428832396, 0.20645596379680292, 0.26071557296173914, 0.5695625660674912, 16.277272122246877, 75.93762670244489, 57.2777738571167, 44.68261446271624, 58.3873108455113, 68.0622535433088, 41.96739741734096, 68.32187298366001, 66.26035635811942, 52.15781307220459, 1.0349657727139336, 1.5364349612167902, 0.6327822165829795, 1.9255382078034537, 22.3118850844247, 51.82689469201224, 51.55802025113787, 53.12857716424124, 55.69367837905884, 59.1505982535226, 58.95149762289864, 63.28030177525112, 55.735666343144004, 59.30880873543875, 57.99523442132132, 58.05079569135393, 56.71463278361729, 59.174138750348774, 55.547109603881836, 56.82582480566842, 56.903213841574534, 54.07375798906599, 49.6861686025347, 44.86866290228707, 41.932659898485454, 41.90336629322597, 44.78420407431466, 49.64962107794625, 56.76612935747419, 56.70644085747855, 56.294923373631065, 49.683868748801096, 52.02415752410889, 58.25432232448033, 55.18947540010725, 52.78325169427054, 54.38416181291853, 49.197303771972656, 48.950337001255576, 59.51616382598877, 50.71556159428188, 52.94648224966866, 48.24381637573242, 50.34982231685093, 47.66763353347778, 48.966519355773926, 47.098826204027446, 39.390991483415874, 41.61087492534092, 40.79038299833025, 41.120418957301546, 42.42487376076834, 38.72692435128348, 40.002231461661204, 39.39557729448591, 38.96009199959891, 41.79971306664603, 41.23385872159685, 43.49871437890189, 45.24410533905029, 44.74731608799526, 44.024724279131206, 43.29054634911673, 44.56880644389561, 43.57879931586129, 48.488271372658865, 49.46915899004255, 49.91382285526821, 45.48489168712071, 38.73418869291033, 39.93864849635533, 42.60210493632725, 46.78980507169451, 52.44420392172677, 44.89193589346749, 44.49747971126011, 44.17277302060808, 40.86527763094221, 43.443695068359375, 43.45545489447457, 40.96821519306728, 45.023590360369, 39.75707817077637, 43.58216571807861, 39.63209744862148, 40.11815868105207, 37.48656667981829, 40.5745267868042, 42.382986545562744, 40.48111867904663, 40.86310631888253, 40.2225866317749, 37.40767683301653, 38.34667028699602, 45.65010942731585, 49.14156184877668, 48.71109662737165, 47.95965589795794, 51.087078298841206, 55.09853737694876, 54.00840323311942, 57.26933526992798, 48.24424716404506, 49.57874597821917, 50.8146185874939, 56.957778045109336, 59.3163058417184, 57.57655334472656, 55.63657113483974, 52.8727514403207, 54.23318093163626, 63.32790388379778, 61.99188341413225, 53.55162865774972, 51.775731631687705, 45.23549999509539, 44.800212723868235, 47.74876764842442, 48.362060819353374, 48.57769121442522, 51.0405809538705, 52.72314977645874, 52.16183607918875, 50.2218017578125, 59.46175248282296, 63.37045465196882, 66.04875591823033, 62.013082368033274, 66.16388756888253, 64.33655997685024, 65.89144175393241, 58.86864035470145, 66.01187488010952, 65.63226699829102, 72.02276148114885, 66.58707455226353, 69.57186780657086, 38.57661049706595, 1.7906817070075443, 0.5826954756464277, 3.1500485582011084, 72.22342545645577, 72.69825839996338, 61.650782448904856, 46.7305543082101, 41.69471536363874, 38.71771798815046, 53.1150872366769, 74.47626073019845, 50.38171802248274, 0.5180816799402237, 0.12789629213511944, 0.17044362691896303, 0.13037635119897978, 0.24602246710232326, 0.20053717068263463, 0.1457633405391659], [0.05566335901884096, 0.03828629771513598, 0.08981644548475742, 0.05462447440783892, 0.06571789431784834, 0.023409146017261913, 0.06796256958373956, 0.07083342410624027, 0.24315568378993443, 11.254954372133527, 58.597938537597656, 41.41307360785348, 31.780417646680558, 28.035435880933488, 45.0059106690543, 29.07835180418832, 54.09006541115897, 55.80489124570574, 61.09182071685791, 2.9614709743431638, 0.3182450830936432, 4.233999022415706, 0.7671759564961705, 3.761622267110007, 11.611272760799952, 25.750762224197388, 12.718896389007568, 37.767537934439524, 51.58182825360979, 53.64600256511143, 56.62415681566511, 52.701971667153494, 53.816688537597656, 54.39312498910086, 54.788043226514546, 56.475277764456614, 52.928538526807515, 52.10098723002842, 56.14021825790405, 52.54927805491856, 49.69828973497663, 40.09960004261562, 38.745507308415, 36.564704009464805, 39.17193215233939, 44.90633603504726, 48.72940165655953, 50.00998592376709, 54.80371836253575, 58.248378140585764, 50.18238115310669, 53.27437816347395, 52.05855458123343, 52.27142654146467, 51.052622182028635, 52.40837900979178, 48.69760322570801, 47.46782766069685, 47.45545291900635, 43.836858885628835, 46.114179611206055, 43.87341683251517, 40.88358266013009, 39.67167438779558, 38.10715545926775, 39.98186976569039, 39.775212969098774, 37.447142601013184, 38.29633753640311, 35.31434440612793, 33.47304398672921, 35.39732674189976, 35.62795829772949, 33.79525627408709, 33.94829382215227, 32.55206721169608, 34.20339345932007, 35.03489133289882, 35.455076694488525, 37.59859248570034, 38.259539876665386, 38.06222493307931, 35.46878201620919, 36.729108810424805, 39.514002391270225, 42.92788164956229, 49.32756165095738, 43.49527154650007, 34.60032320022583, 35.67278460093907, 38.67254080091204, 44.77292019980294, 48.17105484008789, 45.40810367039272, 42.1741167477199, 36.54250798906599, 36.29684747968401, 38.29560102735247, 40.675682135990684, 39.51368277413504, 36.474262782505576, 36.197019236428396, 35.795837197984966, 34.22526638848441, 33.65812315259661, 36.327284063611714, 35.46795865467617, 35.74182537623814, 35.19837202344622, 34.16968774795532, 34.695860930851524, 35.058629853384836, 37.54353496006557, 42.27763795852661, 37.938321181706016, 44.07992076873779, 38.610340527125764, 43.65814079557146, 46.43405382973807, 47.68604973384312, 50.16193955285208, 45.951629979269846, 44.73946462358747, 47.21672671181815, 48.919896943228586, 54.07914284297398, 52.1317469051906, 56.95282397951399, 53.86711508887154, 45.90869358607701, 36.16454683031355, 58.72835622514997, 57.406357220241, 48.85783215931484, 44.7911696434021, 40.67013052531651, 41.584826128823416, 41.2700240952628, 43.20274543762207, 40.7802004132952, 43.80451849528721, 45.01042004993984, 45.107941491263254, 50.25204726627895, 58.140809604099815, 57.25276729038784, 56.73876387732369, 61.11584758758545, 58.54775169917515, 56.62394489560808, 53.053032875061035, 57.591655254364014, 54.79543610981533, 62.30193287985665, 55.81841938836234, 57.42631939479283, 15.471647603171212, 0.07669144762413842, 0.5031456042613301, 7.727964520454407, 68.85618945530483, 53.266940116882324, 51.316077028002056, 35.489737783159526, 47.25597013745989, 44.00033957617623, 50.248399462018696, 46.55928816114153, 46.458052907671245, 1.6256712185485023, 0.06568180982555662, 0.059098663074629645, 0.024905831419995854, 0.04887620053653206, 0.020778815195496594, 0.10247848568750278, 0.06990916441593852, 0.06660460388021809, 0.08756451667951685, 0.03840834241626518, 0.025323932824124182, 0.03598134479086314, 0.08285867955003466, 0.09182484807180506, 0.20708063670567103, 15.693562643868582, 70.24207019805908, 47.644680159432546, 31.100157737731934, 38.69091183798653, 51.61296313149588, 33.36954014641898, 59.326200076511924, 60.81196117401123, 64.4893856048584, 3.554522088595799, 0.4410654583147594, 1.9168672902243478, 0.7242055822696004, 4.114330198083605, 16.825656958988734, 34.271596976688926, 17.426915849958146, 42.878796100616455, 55.107983452933176, 57.14009182793753, 61.385903222220286, 56.76986748831612, 56.58781426293509, 56.54818173817226, 57.74173634392874, 59.143087250845774, 55.88287435259138, 55.218362535749165, 57.28398207255772, 54.33895683288574, 50.95518411908831, 42.25090823854719, 40.93965809685843, 40.267906257084434, 42.97835683822632, 47.15183401107788, 51.71019274847848, 53.39590563092913, 55.92738798686436, 58.61384296417236, 52.152973651885986, 54.06250190734863, 54.76822696413313, 53.291036469595774, 52.170354570661274, 52.90565116064889, 50.46173347745623, 49.403957094464985, 52.70964595249721, 47.28196334838867, 47.18163136073521, 47.29640170506069, 44.9997684614999, 43.2999507359096, 39.76622200012207, 42.4345143863133, 40.65304143088204, 38.3164074080331, 40.45436464037214, 38.611209051949636, 36.44832168306623, 37.385967186519075, 37.97298921857561, 34.59539692742484, 36.24262721197945, 36.95533520834786, 36.362674713134766, 37.88189486094883, 38.98076983860561, 41.563498633248464, 38.69154759815761, 41.56175116130284, 38.655771323612754, 37.68536853790283, 41.309569767543245, 45.293586935315815, 51.22026136943272, 44.568844658987864, 35.07378387451172, 34.9475212097168, 37.96106610979353, 46.58516672679356, 49.7719406400408, 46.480526856013704, 43.844505378178184, 39.418054716927664, 38.44148193086897, 40.51600905827114, 43.603545325142996, 41.31130681719099, 39.54202447618757, 37.12790414265224, 37.41586875915527, 35.11552170344761, 36.12990658623831, 36.85551043919155, 37.708516461508616, 36.79401193346296, 38.24024820327759, 36.826008387974326, 35.84284176145281, 37.09778717585972, 40.6290944644383, 43.29637588773455, 40.01395307268415, 46.13632352011544, 41.62305164337158, 46.667579310280935, 50.85967765535627, 51.68486656461443, 53.745111669812886, 49.199464661734446, 47.4081426348005, 49.014694690704346, 51.49636541094099, 55.76686028071812, 54.89365584509713, 59.38714272635323, 53.325065272195, 47.995755263737266, 40.762260164533345, 64.25354984828404, 59.780549730573384, 52.57782472882952, 48.11728967939104, 41.56221669060843, 45.0639385495867, 45.0697055544172, 45.280354091099326, 45.07742500305176, 45.5423915045602, 47.41596283231463, 46.68348721095494, 53.35507106781006, 59.90358148302351, 60.43417372022356, 59.33847754342215, 62.518522126334055, 61.903210503714426, 60.724865504673545, 56.12044021061489, 61.63524627685547, 58.50165040152413, 66.77623925890241, 61.223530769348145, 64.61651679447719, 14.901080642427717, 0.04313279854665909, 0.7088183079447065, 10.066355569022042, 75.6228107724871, 60.37500980922154, 54.79542221341814, 45.47007812772478, 47.075886726379395, 42.27774565560477, 63.05809143611363, 51.93211126327515, 54.49787950515747, 2.471410185098648, 0.06747302692383528, 0.040026203995304446, 0.03599394179348435, 0.045879881496408155, 0.009764870395883918, 0.14445565428052629, 0.0966154138690659, 0.10517695160316569, 0.15830577537417412, 0.1217559709080628, 0.19095830539507525, 0.1644214250679527, 0.13919076536382946, 0.21823952506695474, 0.3118390068411827, 19.09885219165257, 79.60999284471784, 55.35740293775286, 40.691273893628804, 36.278035231998985, 60.85890320369175, 41.580685002463206, 67.2627660206386, 63.67574460165841, 72.13345323290143, 3.368997586624963, 3.693489100251879, 7.206995972565242, 0.6296814201133591, 6.449910266058786, 25.142426592963083, 42.768371854509624, 23.227706296103342, 48.105449948992046, 56.45141417639596, 61.84019729069301, 62.859970501491, 58.80610656738281, 58.19509935379028, 61.6628167288644, 60.123220988682334, 61.539104052952354, 57.47797577721732, 56.60293354306902, 59.80841200692313, 57.29563420159476, 54.54826089314052, 44.83842086791992, 44.164612361363, 41.65509326117379, 45.29526492527553, 49.738533701215474, 53.24394505364554, 53.51236438751221, 56.86337634495327, 56.74474975040981, 53.465825353349956, 58.74030712672642, 58.8971905027117, 55.1599941934858, 55.29160002299717, 57.98134844643729, 53.85401773452759, 51.53079373495919, 54.714698042188374, 52.20998362132481, 51.46647078650338, 51.94361400604248, 47.57022326333182, 45.74865572793143, 42.36920826775687, 46.14076689311436, 41.8759799684797, 41.27937984466553, 43.16979360580444, 40.64894894191197, 37.067493030003135, 39.26446826117379, 39.95327098029, 38.88028499058315, 39.008736337934224, 39.992326804569785, 40.58819389343262, 41.15959984915597, 42.30632012231009, 43.79962001528059, 42.29528290884835, 43.870901584625244, 39.96750089100429, 41.57094710213797, 44.02698591777256, 48.526583739689414, 53.09605264663696, 45.07535443987165, 36.00340073449271, 36.743119852883474, 38.1840546471732, 48.469733578818186, 54.358338832855225, 49.413267680576865, 47.06553738457816, 40.587318420410156, 42.385480948856895, 43.28444930485317, 47.041628633226665, 44.02285868780953, 43.76222481046404, 40.83568525314331, 42.474740982055664, 39.54834386280605, 37.762298992701936, 39.981532778058735, 39.87944637026106, 40.0436566216605, 40.37866054262434, 39.43544953210013, 38.83991248267037, 37.87473474230085, 41.886235509599956, 47.81113120487758, 44.96041733877999, 50.67206587110247, 45.26302875791277, 48.73118734359741, 54.34141649518694, 56.13446167537144, 56.39957366670881, 51.40654604775565, 49.210800647735596, 50.338316099984304, 52.84435415267944, 58.104505266462056, 58.63008785247803, 60.14380155290876, 55.995737416403635, 48.31331920623779, 44.58244923182896, 60.60647514888218, 59.163452420915874, 56.51652921949114, 49.74916097096035, 45.59529161453247, 46.939952169145855, 47.69595439093453, 49.00541189738682, 47.05587591443743, 48.717502866472515, 49.27034670966012, 47.72054753984724, 55.886119161333355, 65.27167633601597, 63.56308650970459, 61.3087990624564, 66.47100489480155, 65.68096692221505, 63.256323541913716, 58.19006538391113, 65.9154964174543, 62.10934965951102, 70.43018572671073, 64.64421231406075, 71.50990799495152, 19.39653560093471, 0.43416057739939007, 0.7699779261435781, 10.455477271761213, 85.02040917532784, 65.93327685764858, 66.06919751848493, 49.46127625874111, 62.50143650599888, 62.60245636531285, 67.79381683894566, 62.24684756142752, 63.257504735674175, 3.335131415299007, 0.23734943249395915, 0.23565719329885074, 0.1441973088575261, 0.17403047159314156, 0.1384364922663995, 0.2632685202573027], [0.07233343433056559, 0.1405204768691744, 0.0072057670913636684, 0.06955568838332381, 0.02303970405565841, 0.02464495336503855, 0.026990136630567055, 0.050599072195057354, 0.09184082757149424, 13.520134857722692, 59.61514786311558, 40.703474930354524, 47.53274120603289, 13.378597446850367, 35.635771547045024, 27.78015559060233, 57.55290167672293, 54.24671949659075, 66.71405288151333, 11.103546176637922, 0.47658627799579073, 1.5651312385286604, 0.09795132718448128, 0.21344260818191937, 1.5032957451684135, 11.874830092702593, 28.70514668737139, 46.07927186148507, 45.79911354609898, 57.965166091918945, 53.224160058157786, 56.47873101915632, 51.644188335963655, 55.7187613759722, 50.66347789764404, 49.64011941637312, 52.22130571092878, 56.136994293757844, 53.97447517939976, 52.13096175874983, 41.65313734327044, 39.758523396083284, 38.99957166399275, 40.65042890821184, 43.677720819200786, 48.7540225982666, 49.98793581553868, 54.02440840857369, 62.259361267089844, 49.791426862989155, 48.132659094674246, 53.35270868028913, 49.72172253472464, 53.41003826686314, 49.442331995282856, 51.92335305895124, 48.81870337894985, 49.60071618216378, 45.59801183428083, 42.78381422587803, 42.915291513715474, 44.21683154787336, 41.85573986598423, 40.885632378714426, 36.799362046378, 41.47499942779541, 41.22920342854091, 44.20518984113421, 38.24774530955723, 34.53980439049857, 35.33689478465489, 35.03930343900408, 36.63185140064785, 33.797757625579834, 33.81910596575056, 34.73628902435303, 33.87284680775234, 34.65856647491455, 35.69360487801688, 37.20845113481794, 37.62230668749128, 39.441018513270784, 36.96191167831421, 35.775541509900776, 39.417054176330566, 40.04118653706142, 44.224200112479075, 47.45536954062325, 33.887205260140554, 34.796071325029644, 38.22454874856131, 47.09221499306815, 47.743500913892476, 44.83967154366629, 37.397261483328684, 35.34143890653338, 36.2739531653268, 38.535564013889854, 39.573902811322895, 37.02950375420706, 34.20944881439209, 36.269735608782085, 33.933521951947895, 33.02138328552246, 34.42388759340559, 32.90697077342442, 35.45119265147618, 34.4763742855617, 33.902185576302664, 34.99404287338257, 35.29703296933855, 40.76519577843802, 41.081436089106965, 37.89007636478969, 37.652013710566926, 39.46273510796683, 38.452463558741975, 43.38756057194301, 44.15023306437901, 46.06055341448103, 48.54677867889404, 48.17398350579398, 45.46664571762085, 50.89707286017281, 49.370591844831196, 52.58427960532052, 50.94926425388881, 56.10889230455671, 54.62190137590681, 50.71067353657314, 36.4860816683088, 43.74364880153111, 63.068465096609934, 51.06236355645316, 49.655047621045796, 44.46153667994908, 40.335317679813926, 43.9192784173148, 41.245754037584575, 41.77317442212786, 42.627740315028596, 45.41060849598476, 42.71805647441319, 46.384992599487305, 50.41059473582676, 58.6739935193743, 54.59303161076137, 60.35845225197928, 57.43514013290405, 57.649196760995046, 51.901831013815745, 56.55467482975551, 56.125206674848286, 59.7697730745588, 53.34357874734061, 49.755768707820344, 5.254189993653979, 0.16157336932207855, 0.5679975929004806, 21.380208083561488, 70.4710133416312, 53.993148463112966, 42.45261444364275, 35.40230860028948, 62.66057109832764, 19.263067654200963, 28.5471168586186, 50.30169561931065, 41.27088219778878, 4.419839016028813, 0.3143008133130414, 0.06547411704169852, 0.058395890785115104, 0.012655165794837688, 0.13252715793039116, 0.052270619464772086, 0.08103185971932751, 0.1523782427289656, 0.030311319577906812, 0.031006716191768646, 0.01786967603090618, 0.01470186744284417, 0.08954999156828437, 0.046225825790315866, 0.045747506099620035, 18.281012739453995, 68.23638929639543, 43.4781094959804, 44.53719561440604, 23.015893936157227, 41.55284704480852, 33.70061138698033, 63.69342776707241, 58.97567735399519, 72.46384007590157, 13.558997869491577, 0.6810650857431548, 1.7357128794704164, 0.11149654856749944, 0.08519194434796061, 1.7963720645223344, 21.04461009161813, 35.88914108276367, 47.85338320050921, 48.50572524751936, 57.55589982441494, 55.378914560590474, 58.83840874263218, 53.7560133934021, 57.58983482633318, 52.34764133180891, 51.71055058070591, 55.591501644679475, 58.10525219781058, 56.51465320587158, 53.98986196517944, 44.760715688977925, 42.34099858147757, 41.24512522561209, 43.61699703761509, 45.33053398132324, 50.75949852807181, 52.18835735321045, 54.62984664099557, 63.37378283909389, 54.504622731889995, 49.48677267347063, 55.58321244376046, 53.835097789764404, 55.22956998007638, 49.87208155223301, 54.66748850686209, 49.67949138368879, 51.69083159310477, 49.54940720966884, 46.235140800476074, 45.77975239072527, 47.45851707458496, 43.07693093163626, 43.34962688173567, 41.250093187604634, 44.621265343257356, 44.59107542037964, 47.05452101571219, 41.07471718106951, 36.95670747756958, 36.51698725564139, 36.09896278381348, 37.65859365463257, 35.93663549423218, 34.73741463252476, 36.766847951071604, 38.597847666059224, 38.761581965855186, 38.10580750874111, 39.61329214913504, 39.33584015710013, 42.25974982125418, 38.23434223447527, 37.023563044411794, 40.54512548446655, 42.27315289633614, 47.610762528010774, 46.53375353131975, 33.6213185446603, 33.2048157283238, 39.02067681721279, 47.01486417225429, 49.48965964998518, 47.0921767779759, 39.13222667149135, 38.67617470877511, 39.16067259652274, 40.794329575129915, 40.724468912397114, 39.899672576359336, 38.20604222161429, 37.23519822529384, 37.2161671093532, 36.229939801352366, 35.996042592184885, 35.128539153507774, 35.3921468598502, 36.37860345840454, 36.98667158399309, 36.060063294001985, 37.67193419592721, 41.00903238568987, 42.395892824445454, 43.0234819139753, 40.78214590890067, 43.08416053227016, 41.9253226007734, 48.4096941947937, 47.54763119561331, 49.28256859098162, 52.047076157161165, 50.63022729328701, 47.27443844931466, 51.83943966456822, 50.857860701424734, 55.97403471810477, 53.90871742793492, 58.82802813393729, 54.71322154998779, 52.1859324319022, 40.76210730416434, 48.83217246191842, 65.03136593954903, 53.84460292543684, 51.76227991921561, 45.32276936939785, 43.7059200831822, 45.89899737494332, 43.54253666741507, 45.71061086654663, 45.56871475492205, 48.31070668356759, 46.17559821265084, 47.79124198641096, 52.93831116812569, 60.44341482434954, 58.31179782322475, 63.07119573865618, 59.22804287501744, 61.431643213544575, 54.19907917295183, 58.5486410685948, 58.182349409375874, 64.42778982434953, 59.65462752750942, 55.277797426496235, 4.418525372232709, 0.08027390896209649, 0.44613026082515717, 24.77933979034424, 76.62352507455009, 58.18949910572597, 47.532268728528706, 37.36517470223563, 67.00742667061942, 18.580318553107126, 31.357341834477015, 61.233091490609304, 51.01046398707798, 6.8524011714117865, 0.3408237158187798, 0.11462595207350594, 0.040878613612481525, 0.0063539821504881334, 0.07684894917266709, 0.038856026250869036, 0.1537897177040577, 0.2922348545065948, 0.19561465696564742, 0.14657508555267537, 0.14283156714269094, 0.13087442304406846, 0.12913088660155023, 0.16021799562232836, 0.17446442187896796, 24.942191668919154, 79.85914134979248, 52.79080091203962, 62.40810830252511, 23.108159065246582, 52.25616829735892, 42.07171072278704, 70.74741268157959, 62.55217225211007, 79.78384372166225, 14.713098866598946, 1.9797100552490778, 5.513505016054426, 0.33477818593382835, 0.37628721286143574, 3.5020608007907867, 31.747684683118546, 45.659677096775596, 50.99810661588396, 52.3848489352635, 60.582406588963096, 59.87839426313128, 61.39306681496756, 56.36794894082205, 59.66443838391985, 55.56177030290876, 54.06000402995518, 56.631268296922954, 59.63196250370571, 59.89577170780727, 56.980502128601074, 48.029961245400564, 44.55029991694859, 44.89464916501726, 45.63009166717529, 47.79009900774275, 53.521417890276226, 54.64424678257534, 56.540837492261616, 60.52248532431466, 56.322354861668174, 53.051087379455566, 58.50949491773333, 55.26728132792881, 55.69990743909563, 54.04733051572527, 57.578735079084126, 52.59295443126133, 55.827361719948904, 53.65576478413173, 51.127645356314524, 49.33933884756905, 50.70224189758301, 46.7450065612793, 46.935974325452534, 43.52705260685512, 47.11213895252773, 46.985435077122276, 49.879818371364046, 43.15426090785435, 37.71709401266915, 38.5412163734436, 38.25988728659493, 40.087777682713096, 38.31392690113613, 37.664565631321494, 38.724614075251985, 40.36439936501639, 42.55081680842808, 41.74266835621425, 42.80895280838013, 43.32870932987758, 44.18771859577724, 40.9100900377546, 39.36324037824358, 44.01045962742397, 43.59998089926583, 50.42587729862758, 48.08705459322248, 32.82755633762905, 35.425894260406494, 40.07885272162301, 50.22434479849679, 52.064922605242046, 49.04457194464547, 40.182884625026155, 40.88419757570539, 42.17146600995745, 44.6967887878418, 43.90370750427246, 44.06305749075753, 40.81077596119472, 42.14383997235979, 40.8507524217878, 39.62704610824585, 38.9584869657244, 37.7368859563555, 39.57442740031651, 38.90926592690604, 36.95226410457066, 38.33787734167916, 40.51730489730835, 43.77565220424107, 45.786742278507774, 44.1880521093096, 44.00195503234863, 46.09539863041469, 45.30168158667428, 50.02565063749041, 53.8227265221732, 53.959936073848176, 55.15700994219099, 52.05172102791922, 48.84765999657767, 55.5655049596514, 53.8289521081107, 57.87484993253435, 56.611538887023926, 60.46424552372524, 56.627950532095774, 52.01716068812779, 43.42052282605852, 49.17110211508614, 59.464649881635395, 56.79323775427682, 54.40679209572928, 49.27493946892874, 47.1888609613691, 48.50112554005214, 47.318983350481304, 48.52272401537214, 45.90726573126656, 51.66201393944876, 49.09468582698277, 51.320843492235454, 54.90747928619385, 64.49335997445243, 61.74407591138567, 66.9144389288766, 61.79187951769148, 66.27483640398297, 56.75815977369036, 62.421407154628206, 61.435631479535786, 70.07998956952775, 63.366160665239605, 62.99641922542027, 6.596226300512042, 0.21401208905237062, 0.8359940094607217, 25.68138098716736, 85.64576789311, 65.21157441820417, 53.9812844140189, 48.413849217551096, 81.30950137547084, 28.104818855013164, 43.00828620365688, 66.95059040614537, 65.04456751687187, 8.715433818953377, 0.5627790072134563, 0.15593510972602026, 0.2118314267801387, 0.06680382176169328, 0.24397413272942814, 0.10304409212299756], [0.057670299362923415, 0.0275207866382386, 0.048092536694769344, 0.04390008255307164, 0.032407327821212153, 0.06046965665050915, 0.07129927910864353, 0.06574613494532448, 0.09260967560112476, 18.495503629956925, 59.44124834878104, 44.48356941768101, 41.50920193535941, 22.745365824018204, 33.20601429258074, 22.77862685067313, 43.12596436909267, 55.322248526981895, 56.37580387932913, 36.21942022868565, 0.2547045669385365, 0.9551446501697812, 0.18842210434377193, 0.4444245866366795, 0.27559552022389, 1.673272241439138, 22.0516767842429, 40.807520730154856, 45.10922343390328, 45.52699777058193, 48.32044805799212, 52.51410279955183, 52.780819824763704, 50.02591814313616, 48.80715547289167, 56.6255464553833, 55.675626959119526, 56.03947632653372, 52.49764599118914, 43.73832300731114, 39.26680285590035, 39.84219707761492, 38.340541975838796, 43.682247570582796, 47.66354104450771, 51.36431837081909, 50.20554992130825, 60.8109050478254, 47.41357960019793, 37.10133423124041, 54.14238882064819, 51.6612183707101, 52.150784969329834, 49.634286403656006, 50.521620001111714, 51.8326130594526, 51.31131403786795, 49.3041045325143, 47.57810252053397, 42.38322625841413, 46.14875732149397, 41.9364675113133, 39.5156386920384, 37.67550557000296, 37.45091894694737, 40.040067877088276, 38.98247562135969, 39.867533683776855, 41.713881969451904, 35.94195086615426, 36.329281670706614, 34.18385859898159, 36.81915051596505, 33.112112862723215, 34.28032044001988, 33.5479907308306, 34.546304430280415, 32.99901008605957, 32.74287864140102, 34.7722806930542, 37.26026732581002, 37.60718393325806, 38.58607741764614, 40.33498069218227, 41.40926252092634, 39.071242332458496, 42.61942679541451, 49.69653878893171, 34.98185920715332, 33.35291658129011, 37.167050293513704, 48.45024388177054, 45.989952768598286, 40.12484632219587, 38.66453995023455, 35.60399743488857, 38.05940049035208, 37.163444178445, 38.32696519579206, 35.17644350869315, 34.38124997275216, 33.87695319311959, 33.67297492708479, 32.82929686137608, 33.66024235316685, 33.40785946164812, 33.815406050000874, 32.68874870027815, 35.28138215201241, 34.966347353799, 39.76034729821341, 40.569333008357454, 39.52103396824428, 39.26800489425659, 39.79621042524065, 38.67847803660801, 39.706620352608816, 43.85283974238804, 44.48493821280343, 41.977097102573936, 47.445176533290315, 51.146151883261545, 49.03200265339443, 51.48983063016619, 51.92503799710955, 50.66729940686907, 51.33082457951137, 54.42000756944929, 57.58468621117728, 49.805573395320344, 43.588005678994314, 34.552040168217246, 57.713905334472656, 56.71719319479806, 50.277998788016184, 49.557658195495605, 41.1905505997794, 41.182633127485005, 44.66438586371285, 42.93526758466448, 41.92776141847883, 44.372988837105886, 43.07835531234741, 44.40305369240897, 43.699260234832764, 50.951536314828054, 54.0513048853193, 56.433741433279856, 56.39833688735962, 56.88181686401367, 53.96087755475725, 56.92748737335205, 58.22425052097866, 58.30898380279541, 57.03288459777832, 34.48728295734951, 0.9710666643721717, 0.2704365370529038, 0.5270727574825287, 39.17068147659302, 64.59442152295793, 57.938762937273296, 45.44085053035191, 46.31540291649954, 48.61088970729283, 35.56075184685843, 45.923545360565186, 48.2525189944676, 54.95468534742083, 9.862074187823705, 0.21283236092754773, 0.0366536847847913, 0.09614547408585038, 0.0766424098983407, 0.05846555597547974, 0.019141749379092028, 0.009896283121114331, 0.02281631845315652, 0.017867528467572162, 0.03120986957635198, 0.026940988642828803, 0.06194316329700606, 0.025471773730324845, 0.16220030853790895, 0.05242926434480718, 25.36636529650007, 69.05476202283586, 50.26923710959298, 49.89048038210188, 31.001045158931188, 42.991370814187185, 31.177817753383092, 48.69991002764021, 60.87944902692522, 62.60200473240444, 39.9161502293178, 0.12137444423777716, 1.9465808272361755, 0.1981321440211364, 0.3295974082180432, 0.2134776884423835, 0.8303284591862133, 27.75711362702506, 45.943688188280376, 46.123354707445415, 48.2273074558803, 50.77365548270089, 55.44200072969709, 55.70278746741158, 52.19148056847708, 50.523068700517925, 58.791411127362935, 57.8871864591326, 58.27920729773385, 54.49517665590559, 45.71902166094099, 41.85063294001988, 42.303589480263845, 40.569471972329275, 45.31775277001517, 49.92563131877354, 54.948431968688965, 50.90210683005196, 60.905734062194824, 52.05610534123012, 39.08952304295131, 54.32037387575422, 53.67873552867344, 54.57564026968819, 49.26834215436663, 51.89169706617083, 53.965887205941335, 54.90375852584839, 50.88626146316528, 50.214593001774375, 46.80569560187203, 49.829068728855674, 44.429779938289094, 42.752894742148264, 40.467976161411826, 41.80816207613264, 43.61747298921858, 41.58169249125889, 43.217558997017996, 45.08766317367554, 39.95710291181292, 38.12384155818394, 35.95034429005214, 39.7973256111145, 35.57624980381557, 36.455335889543804, 35.42721094403948, 37.74743332181658, 36.40316186632429, 37.60729163033621, 35.793700626918245, 38.92296430042812, 38.927247864859446, 39.49626016616821, 40.9555903162275, 42.79362160818917, 39.810009547642295, 44.73496219090053, 48.21008634567261, 34.7922637122018, 34.41374669756208, 36.49065705708095, 49.21450751168387, 46.94021272659302, 43.59123659133911, 39.91891213825771, 38.00440897260393, 40.35810777119228, 37.74766608646938, 41.64554296221052, 39.027739661080496, 36.537897859300884, 36.157598631722585, 36.28312478746687, 35.73911905288696, 35.30984197344099, 34.88397298540388, 34.23736320223127, 36.61212199074881, 37.13860089438302, 36.4996132850647, 41.539541244506836, 43.044364724840435, 42.497166293007986, 42.840789454323904, 40.651665687561035, 41.9393127986363, 41.413622515542166, 48.70035818644932, 47.42355373927525, 48.54274524961199, 52.60447454452515, 50.90540722438267, 51.52508231571743, 51.417023931230815, 53.122285570417134, 52.462630544389995, 56.06299945286342, 55.67849656513759, 57.76484257834298, 51.619056701660156, 45.44778830664498, 37.531441620418, 62.59051936013358, 59.29769856589181, 53.311478069850374, 53.35959087099348, 42.9260299546378, 45.9091591153826, 47.03613608224051, 45.3628431047712, 45.44337272644043, 45.626631464277, 45.506344250270296, 46.36502000263759, 47.45620332445417, 51.48174640110561, 55.54054355621338, 60.80734062194824, 58.34902627127511, 59.63650662558419, 58.22193677084786, 58.83250972202846, 61.47495133536202, 60.45473343985421, 63.06371252877371, 35.81451048169817, 0.540346910910947, 0.33408803439566065, 0.30522291042975014, 46.53915228162493, 71.20133154732841, 62.84823499407087, 49.821363176618306, 48.380946023123606, 61.28771822793143, 33.76041453225272, 53.15641859599522, 56.45178590502058, 64.45312990461076, 13.593102233750479, 0.2937203033694199, 0.1741829248411315, 0.04634367375235472, 0.10490587007786546, 0.025861746465255107, 0.07688928129417555, 0.11610693617590837, 0.11303510636623416, 0.08913895541003772, 0.13180294393428735, 0.09672524154718433, 0.14088432091687406, 0.0959173913246819, 0.2950912969452994, 0.19235691534621374, 31.85270323072161, 78.83389990670341, 58.500135694231304, 55.106857844761436, 31.266219684055873, 48.27054609571184, 36.31238712583269, 55.61845023291451, 64.43679468972343, 70.08055237361363, 42.88839156287057, 0.6380342404757227, 2.6514069608279636, 0.2082298578960555, 0.623269752732345, 0.38349862875682966, 3.6218566468783786, 37.198001044137136, 51.925465311322895, 52.03432273864746, 52.140710081372944, 54.76612860815865, 58.703377451215474, 57.083352838243755, 53.555272987910676, 50.583403382982524, 59.69223117828369, 59.49586813790457, 61.41218825748989, 58.38528891972133, 48.06070702416556, 45.172924518585205, 45.16396481650216, 42.20653704234532, 48.487284728458945, 53.75983490262713, 54.93406309400286, 53.723877974918906, 57.029973302568706, 51.018732343401226, 44.611961705344065, 54.651094232286724, 55.86975267955235, 54.21385451725551, 53.095059054238455, 54.42003883634295, 58.01349776131766, 56.951500347682405, 54.136086804526194, 53.26433106831142, 50.71935878481184, 54.58720554624285, 48.380747999463765, 46.60855783735003, 44.148353576660156, 43.08834334782192, 49.88483844484602, 45.076101371220176, 47.10887329918997, 48.17666898454939, 41.49310990742275, 39.659403869083945, 37.640632561274934, 41.37598759787423, 37.92073876517159, 38.85905476978847, 36.26852314812796, 41.590964862278526, 39.59498017174857, 40.0452755519322, 40.45856830051967, 43.32497467313494, 41.56451654434204, 41.00684370313372, 44.32135329927717, 44.78349188395909, 42.615674768175396, 48.16425950186593, 51.09311975751604, 34.49547140938895, 35.46985898699079, 36.65201159885952, 50.936865193503245, 50.88879060745239, 46.19609887259347, 43.17329202379499, 39.9402882712228, 43.65932546343122, 40.77088287898472, 44.908448287418906, 42.45668956211635, 39.04632261821202, 41.54352951049805, 39.20596095493862, 37.18393441608974, 38.4529047693525, 39.59948260443551, 38.694618701934814, 39.75175585065569, 39.696635791233604, 40.42063808441162, 44.40914378847395, 47.419614110674175, 45.86656665802002, 48.014748164585654, 46.33638647624424, 45.487823826926096, 45.71948024204799, 52.879307065691265, 51.5994245665414, 51.45048298154558, 55.227089473179404, 54.531060627528596, 54.26591042109898, 55.647240093776155, 55.991971492767334, 55.88386794498989, 57.41584498541695, 58.131189823150635, 60.91236959184919, 51.389960697719026, 45.87578344345093, 39.1330361366272, 57.625545092991416, 61.020462717328755, 54.10608100891113, 55.507525716509136, 45.60040896279471, 47.72492837905884, 49.879578658512656, 48.37985168184553, 47.38553319658552, 49.81908416748047, 48.145950998578755, 49.947931562151226, 49.02460282189505, 57.06901175635201, 59.366798400878906, 62.17790753500802, 61.23110430581229, 63.42362921578543, 60.40968826838902, 62.248883383614675, 65.48751517704555, 67.4848860331944, 68.05829307011196, 44.39015783582415, 0.905194810458592, 0.8347537560122353, 0.80222587287426, 49.70116976329258, 77.40876184191022, 72.32030418940953, 59.47084072657994, 60.68497589656285, 69.09945283617292, 49.16932685034615, 63.441159520830425, 63.92926352364676, 75.22717339651925, 18.10616305896214, 0.44550212738769396, 0.27777299338153427, 0.18205441960266658, 0.19862192416829721, 0.2101582544190543, 0.1346133816987276], [0.041146712976374795, 0.039872444567403624, 0.0725703855444278, 0.031970880526517115, 0.034364202458943637, 0.07532772794365883, 0.01297674559256328, 0.08870511368981429, 0.0023921516715615454, 25.300015211105347, 59.32895156315395, 41.70217425482613, 39.475749083927695, 28.026097502027238, 28.372786555971416, 23.71900299617222, 41.028372696467805, 63.53015204838344, 50.332837445395334, 58.10106938225882, 2.157458003078188, 0.676220562841211, 0.2381192169019154, 0.08476581078554903, 0.07116750760802201, 0.4878196695021221, 1.0931999278920037, 34.26652479171753, 46.210075174059185, 49.62571232659476, 54.18348046711513, 53.100291047777446, 57.589692388262065, 55.75874478476388, 57.61768668038504, 55.33015210287911, 53.633502755846294, 52.729396206992014, 45.161803926740376, 37.13936519622803, 37.39055299758911, 39.60911628178188, 46.17473316192627, 50.57203613008772, 52.581173760550364, 49.90853527614048, 50.02595635822841, 51.725061893463135, 26.160601718085154, 47.89889737537929, 53.606456892830984, 50.70846400942121, 54.36313656398228, 51.64925357273647, 50.76610973903111, 52.30725145339966, 49.65910884312221, 48.279550961085725, 46.110476221357075, 45.39537804467337, 43.212080342429026, 44.22254991531372, 39.01191861288888, 39.44682720729283, 38.490880148751394, 39.74603400911604, 40.465179511478965, 39.11523485183716, 40.989622592926025, 39.49062517711094, 36.6351900100708, 36.79033286230904, 36.340867791857036, 37.88904455729893, 35.05363757269723, 34.979444708142964, 36.06849840709141, 33.02085869652884, 33.56402022497994, 33.00996044703892, 37.99998297010149, 40.67987537384033, 38.73425122669765, 37.98563494001116, 43.84920583452497, 43.85790845326015, 48.97921371459961, 46.90459278651646, 32.85539082118443, 32.98245252881731, 39.004028933388845, 50.79476063592093, 42.92438670567104, 37.68220363344465, 39.75815166745867, 38.55404622214181, 35.81923873083932, 36.797572885240825, 36.27208062580654, 34.26765387398856, 32.87174340656826, 33.9186805997576, 32.85919843401228, 30.414158616747173, 36.3415070261274, 34.271555287497385, 36.57150629588536, 33.27845621109009, 34.433625493730815, 36.0822627885001, 40.81613997050694, 37.85323701586042, 39.77386849267142, 38.926980359213694, 38.220925262996126, 37.79400014877319, 37.43663345064436, 43.82586683545794, 45.21387720108032, 44.01193959372384, 47.35369307654244, 49.74357114519392, 49.73310715811593, 51.10009227480207, 48.57838603428432, 48.06340987341744, 52.12989521026611, 51.070020471300396, 56.91980961390904, 52.321818351745605, 49.89788716179984, 36.35884278161185, 50.21366194316319, 59.00280312129429, 51.514927523476736, 53.8209582056318, 48.578458990369526, 43.400244508470806, 43.484015464782715, 44.18442167554583, 44.354190485818044, 43.604135922023225, 44.81401184626988, 42.63113451004028, 44.950807980128694, 45.26219844818115, 47.92398732049124, 51.81348466873169, 58.96834700448172, 53.42638042994908, 54.86287879943848, 55.84654222215925, 60.933304514203755, 54.66685969488961, 55.450088432856965, 10.836089168276105, 0.09103509437824998, 0.3936852035777909, 0.8124876022338867, 56.54881055014474, 59.396467208862305, 51.53740842001778, 32.44305692400251, 36.503667558942524, 45.614270618983674, 31.929887294769287, 23.915070738111222, 44.41245807920183, 51.769387926374165, 10.18457395689828, 0.31845350190997124, 0.030392736994794438, 0.027083650630499636, 0.030569342696773152, 0.056090690195560455, 0.028231609745749404, 0.08800107932516507, 0.10268527601978608, 0.10309591862772192, 0.06860396838081734, 0.04531209696350353, 0.04010592846732054, 0.013184494355560412, 0.056833360344171524, 0.053236151047583134, 34.23478194645473, 66.31813757760185, 48.72505555834089, 49.523768356868196, 24.18749397141593, 33.3553831917899, 28.414352416992188, 43.998362813677105, 69.76195662362235, 54.71122394289289, 66.7472722189767, 2.4458883660180226, 0.755089782178402, 0.16203087834375246, 0.15221206950289862, 0.05717280427260058, 0.24731103224413736, 1.4955316760710307, 41.700273922511506, 48.09888390132359, 52.72587694440569, 56.56561129433768, 56.59493964059012, 59.45571449824742, 55.323655537196565, 59.259761401585166, 55.914255891527446, 56.400306701660156, 55.3771983555385, 46.17483391080584, 39.61848245348249, 40.44433491570609, 42.775465965270996, 47.54513679231916, 52.40401554107666, 54.89995091302054, 51.53470209666661, 50.397143023354666, 55.18792595182146, 30.980638299669536, 49.42172016416277, 54.94835206440517, 53.10852466310774, 54.16234057290213, 52.44109460285732, 51.00648614338466, 52.56349406923567, 52.79004355839321, 50.06372676576887, 50.36289535249983, 48.8263498714992, 49.06823403494698, 45.38734940120152, 41.10956587110247, 41.64170755658831, 41.0350672858102, 42.47037403924124, 43.365718909672324, 42.740488733564106, 44.02399124417986, 40.6151077406747, 38.07997758047921, 39.93054689679827, 37.40198278427124, 37.869634764535085, 36.399795464106965, 35.96019336155483, 38.26966340201241, 38.06888478142874, 36.349646840776714, 36.49626425334385, 40.18525048664638, 40.48640973227364, 39.785888876233784, 40.25668491636004, 43.764896392822266, 45.44295236042568, 49.01260328292847, 48.61679220199585, 33.06940576008388, 33.3052693094526, 37.678545406886506, 48.64168759754726, 44.13896656036377, 40.014717374529155, 40.977411133902415, 40.87616893223354, 38.545565945761545, 37.613888944898335, 39.826389925820486, 36.67773035594395, 35.003728662218364, 37.876228604997905, 35.26747533253261, 35.0521992955889, 37.73594447544643, 36.52722890036446, 37.40926797049386, 36.02603449140276, 35.81819650105068, 39.328426429203574, 44.28333970478603, 40.816848686763215, 42.95791523797171, 41.3358930179051, 40.87957354954311, 39.7946366582598, 42.7192758832659, 47.51770877838135, 49.307373659951345, 48.856626646859304, 49.15569448471069, 52.98430824279785, 51.02479812077114, 53.136192389896934, 50.39932823181152, 50.4961131640843, 54.586531570979524, 53.8769919531686, 58.5716187613351, 54.4024772644043, 49.97781923839024, 40.06516477039882, 53.39001703262329, 60.94540132795061, 54.62085567201887, 55.198518480573384, 50.70114408220564, 46.152321747371126, 45.90989562443325, 45.730698108673096, 46.50092676707676, 46.069641658238, 47.83621767589024, 45.70166506086077, 48.58198172705514, 46.341552461896626, 51.045878955296104, 55.62058680398123, 59.82282951899937, 57.57794298444475, 56.18315117699759, 59.073765073503765, 65.66937732696533, 58.08936166763306, 61.35451126098633, 11.050817166055952, 0.06148273657475199, 0.8991175794175693, 1.317807286977768, 63.15351799556187, 64.86317784445626, 59.88650975908552, 38.0754508290972, 36.50781910760062, 62.38841710771833, 32.90409769330706, 37.868794032505576, 56.48021445955549, 62.779628481183735, 16.5222065448761, 0.3535999059677124, 0.09601228444703988, 0.09175972906606537, 0.07607144303619862, 0.07097185882074492, 0.04273665283939668, 0.2765772518302713, 0.13156950074647153, 0.22467927022704057, 0.18213815082396778, 0.1036460544647915, 0.18929797091654368, 0.05622659736712064, 0.28417426560606274, 0.26580273998635157, 43.53325039999825, 76.28484208243233, 55.67745433534895, 50.96823631014143, 37.88093948364258, 41.21141604014805, 37.260802337101524, 53.219073976789204, 75.0369873046875, 61.77489117213658, 73.2332488468715, 2.8277611434459686, 3.1368029032434737, 0.5257024424416679, 0.24347492094550813, 0.24491699784994125, 1.0882699638605118, 3.8811903425625394, 50.44408852713448, 51.49467005048479, 55.793027196611675, 58.672833170209614, 60.25575787680489, 61.55295876094273, 59.14746461595808, 62.4541540145874, 59.949300629752024, 59.82543509347098, 58.447030612400596, 49.74152142660958, 41.23839936937605, 42.74375786100115, 44.71271405901228, 49.14571687153408, 56.21500866753714, 56.577176570892334, 56.05069419315883, 49.96621574674334, 50.593624183109824, 34.84542785372053, 49.85761887686593, 57.18966375078474, 54.13922739028931, 58.29103660583496, 55.845809187207905, 53.84797280175345, 55.30243226460048, 56.827742508479524, 52.23125205721174, 53.44825335911342, 55.59728602000645, 53.861459255218506, 51.38451678412301, 46.087286608559744, 44.990829604012625, 45.31550850187029, 45.989598410470144, 47.34830127443586, 45.925876481192454, 48.52555193219866, 44.801894187927246, 40.52860961641584, 40.77695907865252, 40.182141167776926, 43.19120447976248, 38.773751735687256, 40.62725666591099, 41.418149266924175, 40.63961403710501, 39.04866416113717, 38.12396662575858, 42.95241573878697, 44.34108965737479, 42.621462617601665, 42.7971373966762, 47.529128142765586, 46.688236304691856, 51.48749256134033, 50.14185578482491, 33.509570666721885, 33.986053807394846, 38.99662562779018, 51.694833755493164, 47.2076975277492, 42.73826878411429, 43.93339715685163, 42.44259861537388, 42.128150939941406, 40.221283844539094, 43.018427099500386, 39.89758811678205, 39.07072121756417, 40.737871987479075, 37.824273450034006, 36.20810161318098, 41.00955697468349, 39.85552372251238, 41.690362317221506, 38.15190533229283, 37.7189804485866, 42.924629892621724, 47.99944823128836, 45.84301226479666, 47.4352753502982, 45.86003882544381, 44.22045503343855, 45.004798957279746, 43.75211865561349, 51.188699177333284, 52.53520447867257, 54.733416489192415, 51.34482519967215, 54.66706814084734, 52.59632083347866, 56.01205178669521, 51.57804495947701, 50.58214575903756, 55.837961196899414, 53.44772529602051, 62.03852667127337, 57.00994512013027, 48.73236853735787, 42.631916182381765, 52.591352871486116, 61.96385438101632, 57.73732076372419, 58.516568183898926, 54.66389281409127, 48.51067583901541, 48.402065072740825, 48.612182072230745, 48.53106532778059, 49.20009694780622, 51.16821241378784, 47.91567727497646, 51.46270833696638, 49.108662128448486, 54.18974426814488, 59.2443641935076, 64.34087480817522, 59.82287815638951, 60.282188824244905, 63.367369651794434, 69.56902599334717, 62.77179091317313, 68.07389872414726, 14.38105400971004, 0.21811235403375967, 1.0537635811737605, 1.732068657875061, 68.08420290265764, 71.2859536579677, 64.78196729932512, 46.63909864425659, 46.48941707611084, 66.4050873347691, 43.046393598829, 36.4000039100647, 62.20085048675537, 75.37837314605713, 23.232825381415232, 0.4494416745645659, 0.1497724104140486, 0.16127968579530716, 0.14599978285176413, 0.17021118796297482, 0.15627221949398518], [0.10126536006906203, 0.06843613274395466, 0.01560657684292112, 0.022424189673204507, 0.06330528842019183, 0.02629946092409747, 0.008146908732929399, 0.025999390686463033, 1.3497142834322793, 45.70998205457415, 56.90526008605957, 46.09133046013968, 41.63554450443813, 60.730139187404085, 48.031649657658164, 32.52031741823469, 31.48298610959734, 63.356669425964355, 48.96016175406319, 65.56004742213658, 9.57792239529746, 0.21665848419070244, 1.0280269107648303, 0.283840182104281, 0.36521813539522036, 0.21655530615576676, 0.5863788351416588, 14.706666571753365, 52.30124126161848, 56.77838250568935, 56.60007088524954, 56.6663601739066, 54.7780100277492, 54.53044918605259, 52.10982881273542, 54.26225566864014, 49.95022794178554, 44.3438515663147, 41.7304117338998, 36.69104310444423, 39.53386729104178, 44.10888433456421, 49.88189240864345, 49.62490633555821, 52.853119305201936, 45.54081078938076, 60.44810485839844, 36.09844861711775, 37.442452566964285, 55.23944337027413, 52.615157399858745, 54.48669637952532, 49.80064017432076, 52.1883920942034, 48.35268422535488, 51.91398341315133, 47.92176737104143, 50.06065566199166, 46.810031277792795, 46.76789392743792, 44.394048827035085, 45.29158238002232, 40.82581533704485, 41.22036531993321, 39.69066728864397, 39.92259815761021, 39.83509949275425, 37.760085991450715, 39.76530136380877, 37.5322893006461, 35.94190222876412, 35.73259122031075, 38.23446382795061, 37.70979493004935, 36.70739916392735, 34.25787081037249, 35.373543058122905, 35.14304004396711, 33.883269105638774, 36.112536089760916, 38.0022098677499, 38.97875486101423, 38.67098787852696, 41.20809827532087, 41.85775831767491, 47.28095933369228, 53.925222873687744, 45.95589617320469, 32.055760860443115, 31.56443289348057, 37.405828612191335, 50.01584325517927, 50.21333537782942, 41.701566287449424, 41.40504843848092, 37.92368132727486, 37.623963832855225, 36.38595812661307, 35.73284830365862, 34.70343099321638, 35.38026196616036, 34.97129099709647, 36.65599986485073, 36.26869337899344, 35.42294822420393, 35.592254979269846, 35.24240623201643, 33.392649854932515, 36.22331121989659, 38.86949443817139, 42.60460628782, 37.3997037751334, 38.86476271493094, 39.75198861530849, 38.36580562591553, 38.16858795710972, 38.976750305720735, 44.06421089172363, 46.861548696245464, 43.044510637010845, 46.89181157520839, 50.301462854657856, 50.30207429613386, 49.811653069087434, 50.289848940713064, 47.40426206588745, 50.22706849234444, 51.055425780160085, 54.75711332048689, 51.43961252485003, 49.51015336172921, 42.25167254039219, 42.25248200552804, 56.16764627184187, 55.09134946550642, 52.797193254743306, 52.338865756988525, 41.179596764700754, 43.153639044080464, 43.2728145463126, 42.85564122881208, 45.470776421683176, 50.736830030168804, 46.262572288513184, 45.01522472926548, 43.702192374638145, 49.38730573654175, 47.92414365495954, 53.793578829084126, 51.94365222113473, 55.686876092638286, 60.480879511152, 62.1491003036499, 60.49922275543213, 40.04029369354248, 1.1054588300841195, 0.08172222160335098, 0.8867779044168336, 3.828126949923379, 63.792905126299175, 54.15463154656546, 59.475496019635884, 36.31824793134417, 48.02382946014404, 40.70630979537964, 35.133750302451, 42.660351685115266, 46.30673156465803, 57.00619656699044, 18.745095082691737, 0.132762202460851, 0.017508921013878923, 0.026398428649242436, 0.008490763138979673, 0.020983702237052575, 0.09293497885976519, 0.08805145376494952, 0.11145416727023465, 0.009078358349922513, 0.040733763349375555, 0.015589375980198383, 0.07291831116058997, 0.060992881788739135, 0.017969809139945676, 1.411818259528705, 60.14171014513288, 59.54476261138916, 60.49196188790457, 35.320326805114746, 37.50654969896589, 52.18561976296561, 33.82039833068848, 39.4778265953064, 68.11271830967495, 54.52411242893764, 73.07473264421735, 12.014031171798706, 1.1326976141759326, 1.6563008321183068, 0.19983656970517977, 0.7215636383209909, 0.15158137120306492, 0.46600178309849327, 18.626324313027517, 61.23871258326939, 56.90222372327532, 58.700292451041086, 58.088715485164094, 58.48103509630476, 56.64905915941511, 54.832282406943186, 55.453680651528494, 54.858734198978965, 44.806215967450825, 43.11509738649641, 40.216260296957834, 43.41828203201294, 46.029258728027344, 52.902725969042095, 51.51328427450997, 57.018446241106304, 44.78936311176845, 58.65799181801932, 40.32576043265206, 39.51377657481602, 57.52416740145002, 54.303253514426096, 55.60364014761788, 50.74088430404663, 54.845119203839985, 51.78905132838658, 55.32198796953474, 50.37028823580061, 53.53577286856515, 49.712474482400076, 50.71127108165196, 47.056473459516255, 48.050097124917166, 44.85698992865426, 44.48831156321934, 42.51411294937134, 42.89893545423235, 43.60652262823922, 41.31953348432268, 44.23087733132498, 40.98346996307373, 38.606258460453574, 38.41418245860508, 39.31376920427595, 38.767397608075825, 39.53748035430908, 37.13934435163225, 37.02179820196969, 37.6943108694894, 36.638813495635986, 37.55907808031355, 40.92320128849575, 40.730812617710654, 39.640737533569336, 42.17793130874634, 43.49941267286028, 48.066331590924946, 57.2622515814645, 46.962478228977744, 30.345923832484655, 30.901734556470597, 37.209145954677034, 51.363067695072715, 50.51858016422817, 43.918830258505686, 43.07955387660435, 40.71720109667097, 39.64976324353899, 38.86401925768171, 40.13641159875052, 36.99107674189976, 37.72248928887503, 36.46341664450509, 38.576992647988455, 38.86316115515572, 38.02333239146641, 35.899733611515586, 38.52299124853951, 35.55198322023664, 38.00775800432478, 42.21243953704834, 43.962871415274485, 41.42670944758824, 42.74584926877703, 42.41745655877249, 42.590772424425396, 42.152170862470356, 43.02546909877232, 47.26176840918404, 49.04065316064017, 47.50326694761004, 51.133606910705566, 53.55563429423741, 53.25402341570173, 52.80730983189174, 52.455605915614534, 49.99483190264021, 52.70383031027657, 53.64816345487322, 56.89757537841797, 54.15416601725987, 51.4452475139073, 44.86511237280709, 46.5623905318124, 57.64572613579886, 58.529755864824565, 55.44036095482962, 56.24506310054234, 44.986962931496755, 44.723636627197266, 45.09320436205183, 45.06887871878487, 47.91067109789167, 53.013723441532676, 51.16208062853132, 48.53577273232596, 47.003813062395366, 52.55703919274466, 49.48738064084734, 56.019833769117085, 52.60089274815151, 59.03138106209891, 61.91052000863211, 65.12193570818219, 63.34732409885952, 44.338609150477815, 0.7750142301831926, 0.06769786628761462, 1.6020082597221648, 5.158319183758326, 71.09793540409633, 58.303515570504324, 65.21017088208879, 40.619002205984934, 47.70130797794887, 50.36866235733032, 40.45744616644723, 43.42266287122454, 53.78574126107352, 66.8122865131923, 26.999626227787562, 0.21088131490562642, 0.014178538828023841, 0.06355197661157165, 0.01661685781021203, 0.036865065406475744, 0.1429520613913025, 0.21886008605360985, 0.15983076925788606, 0.12452937423118524, 0.16547379216977529, 0.1007322147488594, 0.08044922884021487, 0.11603110310222421, 0.1258774468941348, 1.9171311046395982, 68.98085403442383, 69.70322350093296, 63.68312358856201, 55.63066169193813, 81.18492017473493, 60.902148791721885, 47.80060120991298, 43.97009059361049, 75.884507724217, 58.83524036407471, 81.56321484701974, 12.208759648459298, 4.535477016653333, 3.4816880311284746, 0.24746625391500338, 1.4167728679520744, 0.14549993324492658, 0.945280162351472, 22.164348772593907, 67.55236693790981, 59.49890450068882, 64.36212239946637, 60.56514031546456, 62.338313647678916, 58.836894035339355, 57.05018213817051, 59.3042437689645, 56.24411467143467, 49.24247748511178, 46.00330720629011, 41.84911823272705, 44.10548666545323, 49.118076937539236, 57.25921521868025, 54.08931153161185, 60.66978713444301, 47.31047875540597, 54.23689126968384, 41.6367951801845, 43.947838987622944, 58.15955236979893, 57.83107280731201, 58.35667623792376, 53.21005174091884, 57.90011010851179, 53.91990402766636, 58.399636949811665, 53.221088954380576, 54.68473046166556, 54.16839245387486, 56.094238553728374, 51.632105418613975, 53.93813957486834, 47.926134313855854, 48.5392815726144, 45.43021978650774, 47.7046674319676, 49.004626750946045, 44.38409553255354, 48.46467181614467, 45.008332116263254, 41.36792073931013, 41.56553445543562, 42.28607654571533, 42.21645906993321, 41.26075867244175, 38.82354947498867, 38.18187986101423, 41.274085317339214, 40.44389023099627, 39.57325315475464, 43.01278863634382, 44.87718139375959, 41.29935938971383, 45.37426594325474, 44.12419816425869, 50.414412770952495, 60.62085097176688, 48.211437770298545, 30.398108278002056, 31.49232448850359, 38.55938938685826, 52.6510900088719, 55.6878662109375, 47.890556062970845, 45.491586276463096, 43.92851604734148, 42.78694091524397, 40.952258655003135, 41.67994696753365, 40.61123759405953, 40.12393610818045, 40.91358150754656, 41.69985703059605, 40.35473789487566, 41.88222292491368, 39.18303884778704, 40.417476654052734, 38.27793870653425, 42.56792327335903, 45.01707295009068, 48.350648403167725, 44.630853857312886, 45.85101658957345, 46.902744565691265, 46.49514586584908, 44.67712885992867, 47.54985809326172, 49.837361403873985, 51.3882931300572, 50.18165854045323, 54.1283916745867, 56.121506759098594, 54.11667701176235, 54.09074633462088, 54.69197048459734, 51.86787864140102, 53.950924260275706, 56.41043370110648, 57.90922267096383, 55.86199501582554, 50.880928720746724, 46.44965948377337, 47.04703433173043, 59.02126448495047, 61.846679959978374, 56.3198048727853, 59.51425307137625, 45.377055644989014, 46.91361502238682, 47.71936982018607, 48.50912291663033, 50.03529126303536, 55.725275312151226, 52.60145207813808, 51.76671634401594, 50.8719516481672, 55.979888575417654, 53.72610487256731, 60.03304726736886, 57.502370902470176, 62.497330120631624, 66.37630789620536, 71.43065684182304, 68.60368497031075, 54.42812653950283, 1.3935701187167848, 0.2512935171169894, 2.211171269416809, 5.710657111236027, 76.7523307800293, 64.35683482033866, 72.69827924455915, 50.23814739499773, 59.56851155417306, 55.42390762056623, 50.2814485686166, 58.11199195044381, 63.13652270180838, 76.8839088167463, 37.03748376028878, 0.3703997816358294, 0.09410093272370951, 0.1509363693850381, 0.11891630185501915, 0.19293570571712085, 0.16344672308436461], [0.0773464578336903, 0.07201775948383979, 0.02157406502270273, 0.04447912398193564, 0.027522591541388204, 0.03921944282150694, 0.007126122347212264, 0.11084423892732177, 5.454073599406651, 54.12504959106445, 50.908009324754985, 38.16939742224557, 58.70576763153076, 99.94516059330532, 67.7595066343035, 33.735202993665425, 26.055501529148646, 64.75450107029506, 49.66931227275303, 63.13438960484096, 31.988953930991038, 0.08151069509663753, 1.6551738125937325, 0.27137454386268345, 0.06972573604434729, 0.01338640262838453, 0.22436992611203874, 2.0612195900508334, 46.38412060056414, 60.315317835126606, 56.498387472970144, 52.136242389678955, 53.1208472933088, 52.213221481868196, 50.700345039367676, 51.73220811571394, 43.77305357796805, 40.909683568137034, 40.970438616616384, 38.11354085377285, 43.423020703451975, 48.68288346699306, 48.20342649732317, 51.375015122549875, 47.029545715876985, 54.82636601584298, 55.04021072387695, 28.617368357522146, 50.20184653145926, 53.083038670676096, 51.73708575112479, 54.55113744735718, 53.69288206100464, 48.803330489567344, 49.311507838112966, 51.04437814440046, 48.31802313668387, 47.819545473371235, 48.36766801561628, 47.032161712646484, 44.10989877155849, 42.7642411504473, 39.548767702920095, 39.04771225793021, 41.60012606212071, 38.57699612208775, 41.79999794278826, 38.14885854721069, 41.917825494493755, 44.05544226510184, 40.64073964527675, 35.28990759168352, 33.69059208461216, 37.45508439200265, 35.19429343087332, 36.61886174338204, 38.404468876974924, 36.436558382851736, 34.71554865155901, 36.31331818444388, 36.93404245376587, 38.17309386389596, 41.36255325589861, 40.795684473855154, 44.88416085924421, 47.50366299492972, 52.97170768465315, 45.75450611114502, 29.509121009281703, 32.56349005017962, 39.346443108149934, 48.628784792763845, 54.513995851789204, 48.62053380693708, 45.47630023956299, 40.45215163912092, 40.4481703213283, 37.11668627602713, 37.839990275246755, 35.69227082388741, 36.151751722608296, 34.441574232918875, 34.489825998033794, 35.55033997126988, 38.78735283442906, 36.830166884831016, 38.8031530380249, 34.42989083698818, 37.37215416772025, 38.80300712585449, 39.828060967581614, 36.45677069255284, 42.61518839427403, 39.20462690080915, 40.06008563722883, 41.334868158612935, 39.77806520462036, 44.73288467952183, 45.76506389890398, 45.42486619949341, 45.747384207589285, 48.805442741939, 50.8041615486145, 50.55512421471732, 48.58014740262713, 46.550397941044395, 51.34087514877319, 51.90907103674752, 52.83310849325997, 51.88147279194423, 47.92897612707955, 42.22048207691738, 42.014596530369346, 49.58134113039289, 53.61092458452497, 56.03845146724156, 53.374619824545725, 45.603354998997276, 39.52252088274275, 41.85985319955008, 44.33925533294678, 48.81104646410261, 52.63318450110299, 50.75152547018868, 51.30499117715018, 47.40164259501866, 45.19592653002058, 48.940811020987375, 51.042484760284424, 51.781915528433665, 55.928336415972026, 61.75217751094273, 62.21822098323277, 63.96419906616211, 7.7888732978275845, 0.5873875724417823, 0.2541797608137131, 2.2264907445226396, 10.939024993351527, 65.02099227905273, 56.1997504234314, 62.018015589032856, 33.495208740234375, 24.48038833481925, 45.52890852519444, 30.85816935130528, 37.90740517207554, 49.71576445443289, 52.504667145865305, 36.83675377709525, 0.4491180676434721, 0.1328369905906064, 0.10735092352011374, 0.08426174747624568, 0.1664447214986597, 0.08695298020860978, 0.02777469783489193, 0.024133672139474323, 0.019022557917716246, 0.07675862259098462, 0.027724628735865866, 0.054549374151974916, 0.09680366662463971, 0.10665269062987395, 7.631466201373509, 64.26109559195382, 58.07144226346697, 50.69391795567104, 50.472767216818674, 92.59639835357666, 67.57315594809396, 40.91215017863682, 35.01989712033953, 69.33378083365304, 55.392977714538574, 68.61123766217912, 37.98914378029959, 0.19158945152802126, 1.3356838077306747, 0.10616355509098087, 0.019476606410795023, 0.01514197713030236, 0.46855752595833366, 3.8508909855570113, 54.86463669368199, 60.45640795571463, 58.17546027047293, 54.27893829345703, 54.30358355385916, 56.13825191770281, 52.36948994227818, 53.50449207850865, 46.77670424325125, 41.19387183870588, 42.27797147205898, 40.941985743386404, 47.14106777736119, 50.129845823560444, 51.56657695770264, 53.658509322575156, 50.69430358069283, 54.933020864214214, 57.302304472242085, 32.41782454081944, 52.022038323538645, 54.166495595659526, 55.92353173664638, 54.724901471819194, 54.10906178610665, 50.515043531145366, 50.73321001870291, 52.801720006125315, 50.776003973824636, 50.55933134896414, 50.098168986184255, 50.58778769629342, 45.8316067968096, 47.12957545689174, 42.35325867789132, 43.09584045410156, 46.265358516148154, 41.59374066761562, 44.91689382280622, 41.14793382372175, 45.81515693664551, 44.85980742318289, 44.02780927930559, 37.71580164773123, 35.47970111029488, 40.30348103387015, 37.77082095827375, 39.372168813432964, 39.258857590811594, 39.442950112479075, 37.40987593787057, 38.5632769039699, 40.336603096553254, 38.327576637268066, 42.42904267992292, 42.607528005327495, 44.166530064174104, 50.01417916161673, 53.88173757280622, 45.3955864906311, 28.430383648191178, 31.40742097582136, 38.050982747759136, 49.161656039101736, 54.99915729250227, 49.18325451442173, 45.67424399512154, 40.39858797618321, 41.5505576133728, 39.37795666285923, 40.32582296643938, 36.499422209603445, 37.318611349378315, 37.26615939821516, 37.42740624291556, 37.50530249731881, 38.848972933632986, 38.40001160757882, 40.60807268960135, 37.023316383361816, 38.488712310791016, 41.236439977373394, 42.09307295935494, 39.457999910627095, 44.70473405293056, 41.961765902382986, 42.54654366629464, 45.13451140267508, 43.64234059197562, 46.95376171384539, 48.78244767870222, 49.45180933816092, 49.12682124546596, 51.44668231691633, 52.68263135637556, 52.439684118543354, 51.67424971716744, 49.116239139011924, 52.98645871026175, 54.511824539729524, 56.07588488715035, 55.748266901288716, 50.44582210268293, 45.69345229012625, 43.529877049582346, 51.92949874060494, 54.526627676827566, 58.48334189823696, 55.774941035679404, 48.58920785358974, 41.780272006988525, 42.7719258580889, 48.2309969493321, 50.96325445175171, 55.65617895126343, 55.10285915647234, 54.640189034598215, 49.874440465654644, 49.85645157950265, 52.02496004104614, 53.132798194885254, 54.6365829195295, 56.094658919743125, 62.5055706841605, 64.2279943738665, 67.70894459315709, 10.571506108556475, 0.5884562922375542, 0.5941693942461694, 2.4526098796299527, 13.480257408959524, 71.30770151955741, 61.82450131007603, 65.8070558820452, 40.564722878592356, 25.27116107940674, 55.7050004686628, 35.329682554517476, 40.01100008828299, 63.42058590480259, 60.73776830945696, 47.60560001645769, 0.31006637481706484, 0.13033821753093175, 0.0558587296067604, 0.07145180021013532, 0.09161403402686119, 0.052816955505737236, 0.11158462919827018, 0.141353039337056, 0.24105146527290344, 0.16715488981987747, 0.13653647207788058, 0.1117138969046729, 0.17735590386603559, 0.2393449768424034, 9.09877027784075, 75.14031396593366, 65.2089341027396, 51.35986110142299, 78.07519136156354, 107.17097445896694, 71.65008095332554, 51.283330168042866, 38.85308974129813, 76.73999772753034, 58.73741667611258, 75.1657999583653, 39.660630226135254, 1.2232120143515723, 3.826445920126779, 0.24916503418769154, 0.3913738690316677, 0.161111286974379, 0.9484098915542875, 5.225076173033033, 59.4782475062779, 63.213557379586355, 62.88683918544224, 55.85187496457781, 58.52999210357666, 58.91410936628069, 55.812965052468435, 55.172389779772075, 49.14695365088326, 43.903137751988, 45.49764163153512, 42.54502548490252, 49.864330836704795, 52.13550935472761, 55.150978905814036, 55.43125186647688, 52.98696592875889, 51.858637537275044, 57.03715079171317, 36.781032698495046, 51.74382550375802, 56.88858093534197, 58.26162140710013, 58.231407165527344, 58.41072627476284, 50.85861458097185, 54.93116569519043, 55.9630982535226, 51.32999079568045, 52.915778160095215, 54.123534883771626, 55.40168380737305, 51.96536881583077, 50.929489680698936, 46.9956419808524, 46.73049872262137, 47.971009254455566, 45.565452575683594, 48.58342695236206, 43.35563359941755, 48.60260745457241, 48.49918351854597, 48.16895648411342, 39.08143186569214, 37.55255372183663, 43.075544766017366, 40.07786955152239, 41.64795051302229, 42.43483052934919, 41.66208662305559, 40.58225318363735, 40.485655852726524, 40.84036833899361, 40.48358528954642, 45.92496279307774, 45.67195456368582, 47.376851422446116, 54.14111730030605, 56.042342458452495, 46.23115253448486, 27.908546141215734, 33.28531755719866, 39.03541047232491, 51.72095550809588, 59.52645410810198, 52.77251672744751, 48.771459102630615, 44.32481002807617, 43.83331183024815, 42.07791893822806, 41.63084404809134, 39.26718848092215, 40.74709572110857, 41.034170968191965, 39.1185804094587, 39.970561572483604, 42.45256233215332, 42.06602362224034, 42.809140409742085, 40.107885769435335, 41.29444701331002, 46.237138407570974, 45.38480288641793, 44.90213932309832, 48.42626564843314, 46.93288932527815, 47.07101951326643, 50.23013959612165, 47.26507922581264, 51.34365790230887, 51.49968664986746, 51.480401924678254, 53.19826759610857, 52.48757110323225, 55.28319270270211, 56.599257946014404, 55.89028460638863, 51.56946393421718, 54.12837082999093, 57.139522075653076, 56.14868116378784, 59.06664316994803, 51.86887223379952, 46.83541999544416, 46.02695540019444, 51.11880724770682, 57.4918999671936, 61.57303210667202, 58.587724685668945, 50.70645250592913, 43.9892189843314, 45.73238999502999, 50.155766078404014, 52.66218280792236, 58.185462202344624, 57.96763617651803, 57.54058946881975, 52.976686068943565, 52.16660949162075, 54.385127612522666, 55.6637351172311, 58.12554093769619, 60.132990155901226, 67.85056277683803, 69.18509633200509, 73.54464626312256, 17.012843166078838, 0.7964746643389974, 0.8432606852480343, 4.662566517080579, 14.003864969526019, 77.9387287412371, 67.28415952410016, 72.89126546042306, 48.82826410021101, 36.17053965159825, 58.56166199275425, 44.64823130198887, 53.324874196733745, 70.11740561894008, 69.57915646689278, 59.72867447989327, 0.6263495960405895, 0.24600164964795113, 0.20581677023853573, 0.20798500174922602, 0.44574621000460213, 0.22147695134793008], [0.022036627433927994, 0.050448199933660884, 0.0647721861356071, 0.05084024050406047, 0.05591188943279641, 0.023475077568686435, 0.10972096491605043, 0.13498131052723952, 7.072349437645503, 60.64271695273263, 51.19856909343174, 34.256866795676096, 52.136360509055, 73.41438143593925, 75.28979056222099, 34.750463349478586, 20.059124503816875, 54.733048234667095, 60.08690970284598, 50.74732528414045, 59.64455958775112, 4.2880933540208, 0.9804659485816956, 0.17051044904759952, 0.10818342491984367, 0.12572160097105162, 0.16136469266244344, 0.7879683322140149, 35.86705623354231, 60.03329740251814, 53.86308513368879, 51.80637318747384, 45.29246827534267, 45.95138679231916, 43.13584818158831, 44.31454406465803, 41.00456469399588, 41.148750237056184, 38.76514291763306, 43.289813314165386, 47.27315650667463, 51.07791709899902, 50.07824502672468, 51.27014248711722, 50.0931384904044, 61.6590438570295, 37.488783155168804, 38.614474705287385, 51.48386907577515, 51.147489411490305, 54.08917951583862, 53.98899344035557, 53.059463432856965, 48.94826296397618, 48.39294556209019, 50.05106367383684, 49.0540041242327, 48.265505177634104, 49.9419595854623, 47.62722628457205, 42.736205169132774, 43.45915133612496, 41.098625932421, 41.37143652779715, 40.62950093405587, 39.91911016191755, 40.3206604548863, 39.79813855034964, 32.09314911706107, 29.76599591118949, 32.99544218608311, 38.06359025410244, 35.64151075908116, 38.35862466267177, 34.46575048991612, 35.22852373123169, 36.455627713884624, 34.40968200138637, 35.46541561399187, 36.2871721131461, 38.64178459984915, 39.47461305345808, 41.61613123757498, 41.188101359776084, 48.32418271473476, 53.17936849594116, 55.46402999332973, 42.9143465587071, 29.91902651105608, 32.029229164123535, 37.24266059058053, 50.31914949417114, 50.98072917120797, 51.615454060690745, 46.72383540017264, 40.8639748437064, 38.364506312779014, 38.162400586264475, 38.60057830810547, 40.15352153778076, 35.91625642776489, 33.33760969979422, 36.52399103982108, 37.717896529606406, 37.34476089477539, 35.38781813212803, 35.77319649287632, 36.34522083827427, 38.4974878856114, 41.83738619940621, 38.809031214032856, 37.89484282902309, 42.06584644317627, 37.77259622301374, 42.51279626573835, 42.608344418661936, 43.49259649004255, 45.52241543361119, 44.76931755883353, 44.63255616596767, 45.04540075574602, 50.99629313605172, 49.86889927727835, 52.24958487919399, 47.69489826474871, 45.29971177237374, 49.42057718549456, 51.83259221485683, 53.358694553375244, 52.991892201559885, 49.856038161686485, 45.86097683225359, 41.808342729296, 48.08500140053885, 50.75054924828665, 55.01730598722185, 52.81508834021432, 47.26168155670166, 41.32107251031058, 39.78728893824986, 41.877873352595735, 50.464894907815115, 54.187274183545796, 56.09233127321516, 55.57837997164045, 51.62705060413906, 50.56190913064139, 50.193105697631836, 50.58244105747768, 53.03746543611799, 60.46410655975342, 60.31735365731375, 73.04193019866943, 32.75541319165911, 0.6057007983326912, 0.13291040807962418, 0.23783966047423227, 0.5881443832601819, 22.223585639681133, 68.17650277273995, 52.89864042827061, 60.19512789590018, 29.91064350945609, 24.56568268367222, 34.45066247667585, 48.5881586756025, 28.194514887673513, 38.031361034938264, 56.02945702416556, 35.60054418018886, 0.63690982652562, 0.0729087506021772, 0.05523886411849942, 0.017594404551865797, 0.0813315822077649, 0.055246996360697916, 0.053335023777825494, 0.04699623445048928, 0.06409525924495288, 0.05545641601617847, 0.05475073281143393, 0.02066006138920784, 0.18606078890817507, 0.2013640334563596, 10.39668161528451, 70.4842427117484, 57.81345912388393, 39.504598004477366, 53.14247008732387, 79.4297913142613, 78.1505515234811, 39.616950375693186, 27.605932985033306, 61.58553886413574, 65.34996168954032, 54.28056069782802, 66.29988465990338, 5.225822235856738, 1.0273847452231815, 0.7641312341604913, 0.06417732805545841, 0.15240906178951263, 0.05807933384286506, 1.2819981170552117, 44.61310815811157, 61.79080949510847, 56.36991875512259, 54.8310421534947, 47.80456863130842, 50.321623052869526, 46.724544116428916, 48.13921472004482, 43.965150424412315, 43.828343868255615, 41.94916534423828, 45.77626786913191, 47.75489943368094, 54.97411598478045, 51.95402588163103, 55.23550721577236, 52.194072246551514, 61.31730365753174, 44.05503579548427, 39.79958030155727, 51.662548950740266, 53.20622328349522, 55.687758513859336, 55.46510696411133, 54.84604331425258, 52.56709671020508, 51.38919292177473, 52.67920936856951, 50.692215647016255, 50.58617918831961, 52.15008667537144, 50.6357615334647, 46.428939955575125, 47.28714670453753, 43.593126501355854, 45.22153064182827, 43.030774048396516, 42.24124329430716, 43.18418679918562, 43.27374907902309, 36.45922688075474, 34.4550815309797, 36.76528460638863, 40.80502980095999, 38.67439249583653, 39.585162367139546, 35.6586137499128, 38.368796825408936, 38.70700734002249, 36.20656606129238, 37.65905223573957, 37.76622472490583, 40.10670110157558, 40.55275808061872, 43.03748600823538, 41.69110924857003, 48.95445033482143, 53.40110635757446, 56.13047340938023, 44.697824069431846, 29.131180695125035, 32.327584811619346, 36.53598363058907, 49.8653244291033, 54.280074323926655, 53.028867040361675, 47.71138981410435, 42.79179423195975, 42.40044042042324, 40.51098551068987, 40.39199760981968, 41.779525075639995, 37.22148595537458, 36.335840770176475, 39.34052324295044, 37.89446415219988, 38.36589595249721, 40.24050603594099, 37.93488529750279, 38.95428677967617, 41.434244768960134, 45.265724658966064, 41.70202834265572, 42.403723444257466, 44.475127356392996, 41.797017165592735, 44.97122873578753, 46.193114621298655, 44.71382229668753, 47.829182624816895, 47.219752652304514, 48.572678089141846, 49.84325695037842, 52.3711644581386, 50.60920899254935, 52.6712258883885, 52.178928647722515, 46.71053654806954, 49.40803221293858, 54.76636137281145, 56.028640610831125, 56.00050040653774, 51.54719843183245, 47.998746463230674, 44.24695198876517, 48.79231759480068, 51.27255351202828, 56.497633593423025, 55.16269704273769, 49.275078432900564, 43.63977323259626, 41.556474004473, 44.97253499712263, 53.10542229243687, 56.64228466578892, 60.15386254446847, 58.4877679007394, 54.069853101457866, 54.27100692476545, 52.374725409916465, 55.73415163585118, 55.69186837332589, 62.61738109588623, 62.38184411185128, 75.06341130392892, 35.73537744794573, 0.6100859258856092, 0.07763068936765194, 0.7545559651085308, 0.6276078713791711, 25.040890829903738, 75.6135835647583, 59.70243113381522, 67.0439464024135, 34.57426745550973, 30.76018932887486, 45.362384523664204, 49.10709878376552, 27.53009339741298, 50.201790945870535, 63.67408398219517, 47.242629596165244, 0.5389639479773385, 0.14791595217372688, 0.03453666231195841, 0.008193351910449564, 0.11475059895643167, 0.00680768840746688, 0.1376865075102874, 0.1490939161075013, 0.1281027431998934, 0.15139277917998178, 0.12620460933872632, 0.19649387550141129, 0.309154993721417, 0.41917154884764124, 13.843187877110072, 83.36338887895856, 63.42111396789551, 51.085987431662424, 65.45374693189348, 80.3477942602975, 80.40588814871651, 46.42520877293178, 32.703093256269185, 65.07892635890416, 70.69761494227818, 59.96234934670584, 71.86888667515346, 5.644610575267246, 1.7254840454884937, 0.9306361824274063, 0.24549858378512518, 0.5098407364317349, 0.29140763889466015, 2.5940682547433034, 48.627686977386475, 66.43746594020298, 58.12384557723999, 56.989892618996755, 48.9766845703125, 52.47655126026699, 49.4675053187779, 50.87079129900251, 45.64143112727574, 45.341581617082866, 42.40614141736712, 47.50249569756644, 51.34338692256382, 57.08750091280256, 54.87248468399048, 56.343717098236084, 55.2490735735212, 57.85861199242728, 48.343529973711284, 42.90987886701311, 52.95339570726667, 56.06796741485596, 58.20059190477644, 60.439106941223145, 57.55320739746094, 55.273597240448, 52.38299724033901, 55.22861112867083, 52.5214262008667, 52.277662549700054, 56.078657218388145, 53.5728554044451, 50.78302165440151, 50.86086927141462, 47.243393898010254, 48.99272448675973, 48.3151604788644, 46.201775550842285, 46.600873129708425, 47.750299726213726, 42.68828344345093, 40.54835639681135, 42.13500533785139, 45.33000244413103, 40.34055314745222, 42.60063191822597, 39.855030400412424, 41.63416181291853, 40.361137185777935, 39.11779873711722, 40.16285991668701, 40.53127425057547, 42.57583727155413, 43.689306940351216, 45.823463508060996, 45.205990995679585, 52.839330605098176, 56.491314206804546, 59.516511235918315, 45.155223982674734, 28.927973679133824, 32.41464573996407, 37.9763035093035, 52.76690258298601, 54.80587925229754, 56.599438599177766, 50.31611660548619, 43.84981380190168, 43.71987901415144, 43.39860125950405, 43.74714374542236, 45.78623506001064, 39.591488701956614, 38.624636445726665, 40.241961683545796, 40.7590639931815, 41.94611855915615, 42.5443445614406, 42.014151845659526, 44.075644152505056, 45.5438506262643, 50.015384674072266, 44.99148620877947, 45.98173304966518, 48.6936114856175, 43.46837854385376, 49.30831861495972, 50.62011071613857, 51.50729840142386, 52.78172309058053, 50.62089933667864, 50.621865136282786, 52.13995967592512, 54.41913904462542, 53.356154986790244, 56.0267402785165, 52.91654941013881, 46.57742990766253, 52.68222836085728, 55.33564117976597, 56.22915867396763, 58.45851598467146, 54.65926531382969, 48.88830001013619, 47.564998217991416, 50.62656906672886, 53.81349931444441, 58.62715571267264, 56.37316703796387, 51.34829235076904, 46.834648745400564, 42.83255236489432, 47.68547303336007, 55.86002172742571, 58.80181952885219, 60.5096936907087, 61.03651305607387, 56.62901013238089, 55.105047839028494, 54.84084953580584, 59.061682156154085, 59.757148197719026, 67.12384373801095, 66.03866713387626, 78.9647136415754, 43.38339860098702, 0.973870262503624, 0.2004233125065054, 0.7572710279907499, 1.7869279427187783, 26.605336802346365, 82.1622120993478, 62.946225438799175, 72.359297479902, 42.562250069209504, 36.52365057809012, 47.438454151153564, 67.63267421722412, 37.52379512786865, 56.01058919089181, 70.24638502938407, 59.595692907060894, 1.1431906968355179, 0.350247752985784, 0.08145834611994879, 0.0937597585309829, 0.13152355035500868, 0.06931001120912177], [0.012822212634741195, 0.08614481107464858, 0.06909607590309211, 0.05079084654737796, 0.20886396244168282, 0.06562713347375393, 0.10080674503530775, 0.05135477700137666, 10.139889223234993, 65.20664814540318, 48.63912718636649, 44.496701513017925, 52.28416953768049, 92.52679130009243, 54.79281663894653, 36.8968174798148, 18.109498194285802, 30.102288722991943, 62.37762655530657, 48.62147528784615, 60.744674818856375, 20.35630590575082, 0.555846876331738, 0.30419674835034777, 0.06174391827413014, 0.07145065348595381, 0.10445496320192303, 0.44246166625193184, 31.62324939455305, 62.80608722141811, 56.98199599129813, 53.70839044025966, 48.54711219242641, 46.039823463984895, 41.81832729067121, 42.737375940595356, 41.33008779798235, 41.82338557924543, 42.23686245509556, 45.08723585946219, 47.40388338906424, 52.51739624568394, 53.86939409800938, 51.3183525630406, 58.0205397605896, 50.63288845334734, 34.29190656117031, 49.67158085959298, 50.99382305145264, 53.95207071304321, 52.825798988342285, 54.836715357644216, 50.27057463782174, 51.5258709362575, 48.06853069577898, 52.916952405657085, 51.11518723624093, 50.85193388802664, 47.483429840632844, 47.19667073658535, 46.59725659234183, 45.69634968893868, 42.940065315791536, 40.659829820905415, 40.6506929397583, 39.11340747560774, 38.49950633730207, 41.735070501055034, 33.91473749705723, 29.305889674595424, 30.39570767538888, 39.91037975038801, 39.651806013924734, 38.15112713405064, 39.635335309164866, 37.2254637990679, 37.468021937779014, 38.72052158628191, 34.9926358631679, 36.25549874986921, 37.22478287560599, 39.79155165808541, 41.75301422391619, 42.213301113673616, 46.12353883470808, 53.23384237289429, 55.695509229387554, 42.05269002914429, 30.878173215048655, 32.63900307246617, 37.8319616317749, 49.38923386165074, 51.70086826596941, 52.162079266139436, 45.730003288814, 44.282099451337544, 43.15334027154105, 37.3554368019104, 37.918306895664756, 36.56749371119908, 39.09271921430315, 38.08478225980486, 35.85672426223755, 36.58581958498274, 39.829964773995535, 37.58050979886736, 37.30368314470564, 41.101321833474294, 39.108672278267996, 40.10527672086443, 38.08047090257917, 42.77266584123884, 40.396784918648855, 38.70670509338379, 39.94567312513079, 41.66303505216326, 41.2919282913208, 45.1682379586356, 43.60878774097988, 43.49583435058594, 47.605266502925325, 49.11101409367153, 48.81330462864467, 49.82569885253906, 46.62688718523298, 47.94573865618025, 49.38638162612915, 52.18910081045968, 51.282753467559814, 55.6383707182748, 49.360315459115164, 48.30467217309134, 41.51127944673811, 43.07753889901297, 51.249686990465435, 53.040348938533235, 53.42063079561506, 48.00508669444493, 40.757875851222444, 40.38502509253365, 42.39057745252337, 47.78539855139596, 56.36471455437796, 57.46789741516113, 59.947501046316965, 55.61189808164324, 56.194810254233225, 55.81934002467564, 59.080067089625764, 57.47110053471157, 58.4288124356951, 58.698207991463796, 55.463053771427695, 3.447531772511346, 0.375143148537193, 0.02270025503821671, 0.40931121366364615, 0.27687697431870867, 31.79490464074271, 65.8581668308803, 57.89531237738473, 60.31581115722656, 35.83903762272426, 17.203571217400686, 40.111505780901226, 47.67320251464844, 27.322088650294713, 39.0387282371521, 50.73241097586495, 49.35747364589146, 0.9239000124590737, 0.11109421122819185, 0.054378552961030176, 0.0790777602898223, 0.021429883116590123, 0.04555480893967407, 0.05878536310046911, 0.024914272395627837, 0.12994660783026898, 0.015131295292771288, 0.16749547368713788, 0.05027841350861958, 0.2763095290533134, 0.10370761794703347, 13.889879771641322, 75.66688319614956, 52.82704618998936, 53.80449097497122, 66.42517457689557, 95.09478991372245, 59.278326988220215, 41.64634895324707, 19.68870735168457, 37.66015005111694, 68.88744245256696, 52.65487330300467, 66.64052704402378, 24.9747439793178, 0.7422755126442228, 2.280513857092176, 0.05533160628484828, 0.37234394731266157, 0.18622014964265482, 0.34154597563402994, 35.428819452013286, 64.98965590340751, 54.6800126348223, 57.33966841016497, 49.493283135550364, 48.18873800550188, 44.79351118632725, 45.47179085867745, 44.170452322278706, 46.12907654898507, 43.592292717524934, 48.80406699861799, 49.11058677945818, 56.971608434404644, 54.49029902049473, 55.92919799259731, 56.60047735486712, 53.57068061828613, 38.15017523084368, 49.755007880074636, 52.11877809252058, 56.30786439350673, 55.79419101987566, 55.364212172372, 52.07305547169277, 52.09535918916975, 50.84320000239781, 55.67137466158186, 53.273200443812776, 52.286469391414094, 49.55144650595528, 49.574910572596956, 49.81131955555507, 49.332498346056255, 43.45249148777553, 43.59375531332833, 43.72877618244716, 41.39900697980608, 41.711773191179546, 43.04460791179112, 38.09358215332031, 33.493864263807026, 36.08989191055298, 42.85601643153599, 42.98166070665632, 42.72026947566441, 41.87159218106951, 39.62043489728655, 39.11254937308175, 39.9465833391462, 35.81017133167812, 39.67545073372977, 40.85862820489066, 42.038943018232075, 43.81985664367676, 42.5152906690325, 45.994691440037315, 54.19284316471645, 57.70667225973946, 41.28483765465872, 29.2654025214059, 31.99442216328212, 36.58580568858555, 48.273634569985525, 53.56008808953421, 53.38628237588065, 48.02738693782261, 44.26357902799334, 45.43176576069423, 40.341706548418315, 39.17667082377842, 38.44567516871861, 39.784808431352886, 40.48848376955305, 37.947034222739084, 38.38594497953142, 42.315995488848, 40.15595688138689, 38.6276832308088, 44.160676206861226, 41.98045308249337, 42.04483509063721, 41.946459020887104, 45.79654271262032, 41.91519212722778, 40.27512890951974, 45.18756437301636, 44.84663363865444, 44.6502115385873, 49.53509044647217, 46.185318742479595, 47.838392462049214, 49.90667315891811, 51.58390229088919, 49.33491979326521, 51.822294984545024, 48.328188351222444, 48.72353390284947, 51.20673670087542, 53.93482528414045, 52.753551619393484, 56.73450810568673, 51.55995879854475, 49.972840854099815, 42.767857687813894, 45.75347082955496, 53.912969725472585, 55.76897948128836, 57.99105855396816, 51.217461245400564, 43.29357576370239, 42.47766964776175, 44.71679612568447, 50.080520561763215, 57.21040759767805, 60.72656781332833, 63.87210069383894, 57.87103189740862, 58.921022823878694, 57.22775724955967, 62.98598997933524, 59.84010968889509, 61.76747744424002, 60.65214565822056, 63.729773793901714, 4.881022223404475, 0.5130081921815872, 0.056366921801652224, 0.8904441105467933, 0.22085290269127913, 36.33225897380284, 71.62496321541923, 62.04639203207833, 67.25565801348004, 40.60999386651175, 28.751994916370936, 42.399127210889546, 54.29522139685494, 26.358606270381383, 46.5075101852417, 55.469303676060264, 60.142801012311665, 1.9144041538238525, 0.13771495169826917, 0.028906473889946938, 0.07025839281933648, 0.13187248020299844, 0.06709811596998147, 0.09535337944648095, 0.14573364784674986, 0.16770306469074317, 0.15006959518151625, 0.3591961913875171, 0.17983134889176913, 0.40356622050915447, 0.4256063407020909, 18.020441395895823, 85.02423068455288, 61.75982052939278, 57.40022543498448, 67.49644088745117, 93.78664561680385, 62.37693868364607, 49.21101604189192, 29.135530267442974, 42.955125536237446, 74.0803245816912, 57.71015330723354, 71.43269266401018, 26.268307481493267, 1.9156309451375688, 2.7819312598024095, 0.15066923014819622, 0.37243090836065157, 0.4891284821288926, 0.7025719859770366, 37.09191247395107, 70.82168197631836, 58.75213990892683, 60.38099915640694, 52.23406260354178, 52.5367226600647, 47.011084352220806, 48.04554952893938, 47.4844651222229, 47.960889203207834, 46.00253248214722, 51.46606779098511, 50.31974009105137, 60.87455749511719, 57.42376593181065, 59.50892380305699, 55.94506767817906, 53.23562805993216, 42.44556202207293, 51.59453650883266, 54.624076162065776, 57.57076896939959, 57.27941710608346, 58.72481959206717, 53.524325711386545, 55.15959814616612, 52.25930193492344, 58.101031167166575, 55.91586439950125, 55.85959441321236, 51.35207911900112, 53.02233920778547, 53.89930609294346, 52.88767964499337, 48.40011957713536, 48.72799812044416, 47.996575151171, 45.22484493255615, 43.827485765729634, 47.11268091201782, 43.52525997161865, 38.17320850917271, 41.39205183301653, 47.39690044948033, 47.27764156886509, 44.33244262422834, 46.807491711207796, 42.31198637826102, 42.08268192836216, 43.83272818156651, 39.753645760672434, 41.84387929098946, 42.37394346509661, 45.53136123929705, 47.09179810115269, 45.11254467282976, 49.41798203332083, 57.19270706176758, 60.33543981824602, 43.430451801845, 29.129374163491384, 32.868345737457275, 36.96409341267177, 50.080676896231516, 55.38721765790667, 57.76854249409267, 50.079259463718955, 47.965843268803184, 44.96093497957502, 43.64129488808768, 41.51016078676496, 41.26989902768816, 42.77544859477452, 42.67781250817435, 40.87797893796648, 41.113627093178884, 43.728605951581685, 43.039167472294395, 40.45590714045933, 47.30118553979056, 45.5185626574925, 46.479199750082834, 46.20744180679321, 50.804182393210276, 46.59418548856463, 44.66706439426967, 48.47196395056588, 48.874619007110596, 49.03326722553798, 50.72502851486206, 50.34595217023577, 51.145790576934814, 53.69832944869995, 52.453094141823904, 52.064578669411794, 54.73479570661272, 49.70785045623779, 52.107865946633474, 53.84544365746634, 57.24117422103882, 54.01814113344465, 59.34209060668945, 53.97969675064087, 51.66188539777483, 46.58127920968192, 46.53124870572771, 53.82114233289446, 58.484238215855186, 60.64917182922363, 51.68524176733834, 47.529548508780344, 45.488355364118306, 46.990271023341585, 51.54655919756208, 59.64976378849575, 62.68643924168178, 68.40803759438651, 61.50437695639474, 62.452097347804475, 59.97954613821847, 64.67254706791469, 63.44015203203474, 67.03885337284633, 64.21150629861015, 71.55122198377336, 7.884597761290414, 0.9073123282619885, 0.16251487737255438, 0.653599779520716, 0.9345303220408303, 38.40062304905483, 78.06049592154366, 66.62032863071987, 73.02148859841483, 48.09328365325928, 28.421700137002126, 56.064225809914724, 65.31349754333496, 37.769382681165425, 56.94130039215088, 64.87728268759591, 74.74079949515206, 2.982828434024538, 0.5239624072398458, 0.1234826525407178, 0.18817237631550857, 0.22738046385347843, 0.10929163545370102], [0.06062626253281321, 0.024114048906735013, 0.0502502407346453, 0.1396852002612182, 0.043171318979667764, 0.031224950017141442, 0.041566339387957535, 0.0416919667539852, 4.981505768639701, 59.847829137529644, 51.78516728537423, 40.44453641346523, 19.066504853112356, 31.0155599457877, 37.022003173828125, 35.892573492867605, 22.105092797960552, 15.706620046070643, 51.53149202891758, 53.621395519801546, 53.601322174072266, 47.93120649882725, 0.43150460134659496, 1.4562446070568902, 0.07623713450240237, 0.13842427863606385, 0.11428502893873624, 0.3909773331667696, 18.30646399089268, 63.30362687792097, 57.06549596786499, 53.3713298525129, 56.73683227811541, 52.092218603406636, 53.29275267464774, 48.044086933135986, 47.25532742909023, 39.99719054358346, 40.58420215334211, 43.95412015914917, 48.23009715761457, 48.80615840639387, 54.592604296548025, 48.8673129762922, 56.71519558770316, 39.39259999138968, 40.956497056143625, 51.93189934321812, 51.288968631199424, 53.47114419937134, 51.658810819898335, 51.971726417541504, 49.70460912159511, 50.44028091430664, 50.56641503742763, 54.16975777489798, 49.629165581294465, 48.6789334160941, 48.22429541179112, 49.07251065117972, 45.45957245145525, 42.617922510419575, 43.794075352805, 39.057467528751914, 42.91103226797921, 40.46127462387085, 40.37113216945103, 38.31111635480608, 40.3195035798209, 38.23849378313337, 28.20084469658988, 32.35557910374233, 40.59130321230207, 39.34102003914969, 38.88300173623221, 35.08129140308925, 38.27234193256923, 36.08356557573591, 38.4572091783796, 35.9775082724435, 38.2409291267395, 39.63081898008074, 41.56883832386562, 44.1718350137983, 47.46929373059954, 50.64343581880842, 52.32717888695853, 40.02132511138916, 29.490280968802317, 31.518835340227398, 36.04684782028198, 50.076181411743164, 52.97049869809832, 52.610422202519004, 47.20977851322719, 42.816675731113975, 43.28436245237078, 38.732264041900635, 41.39329208646502, 38.02997834341866, 38.66058989933559, 38.335653918130056, 41.64936447143555, 39.08160209655762, 34.646136147635325, 35.69041565486363, 43.27306815556118, 35.78930589130947, 31.235529490879603, 40.34333937508719, 40.54439244951521, 42.56216321672712, 37.19893905094692, 42.36120046888079, 37.11332334790911, 42.5584146635873, 43.51070696966988, 43.56577839170183, 43.188953263419016, 44.6535883631025, 48.02473272596087, 49.865591934749055, 48.73781245095389, 49.3084853717259, 46.28072098323277, 47.76184415817261, 46.83712577819824, 49.96997124808175, 49.23572383608137, 53.46319546018328, 50.577900409698486, 50.779578821999685, 40.56721380778721, 45.34998198917934, 50.27193301064627, 51.213431290217805, 51.087453501565115, 47.21041774749756, 43.842191628047395, 41.28476469857352, 39.231262820107595, 44.552363531930105, 55.86315883908953, 56.35994461604527, 59.639549936567036, 58.65630340576172, 57.95757518495832, 55.85635655266898, 54.86042955943516, 55.43421179907662, 63.289876392909456, 62.015361377171104, 25.581964424678258, 1.9853519925049372, 0.08612468572599546, 0.009188396373896726, 1.723277015345437, 0.8924247271248272, 44.51737935202462, 62.33961296081543, 56.861093861716135, 57.57060916083199, 17.331921815872192, 23.071389198303223, 45.452235153743196, 44.08414874758039, 25.406833342143468, 42.95757825034005, 54.173492431640625, 48.64831965310233, 2.721617204802377, 0.1949459064219679, 0.0871082018794758, 0.07701215720070259, 0.2372876043830599, 0.03332107700407505, 0.03210860277925219, 0.0426908076208617, 0.06108037209404366, 0.0832460755482316, 0.19239979875939234, 0.18759469874203205, 0.07290730532258749, 0.0865282037162355, 7.339621884482248, 72.30637999943325, 60.089668137686594, 38.12163550513131, 32.33076361247471, 49.392294543130056, 44.34429625102452, 48.16938032422747, 23.881498779569352, 20.23170907156808, 55.04559905188424, 60.566724504743306, 58.30935205732073, 53.41574273790632, 0.9423643073865345, 1.969857075384685, 0.13184912502765656, 0.2005643392247813, 0.12663588619657926, 0.496373607644013, 21.856401136943273, 68.25536482674735, 57.30638653891427, 57.12579243523734, 55.85068334851946, 53.820252963474815, 54.95987912586757, 50.83586965288435, 48.12438726425171, 43.64425482068743, 45.07803644452776, 46.90681273596627, 49.69190781457083, 51.17599092211042, 56.260085105895996, 50.029308864048545, 56.95226812362671, 43.68743440083095, 44.28321811131069, 53.702029364449636, 52.3451886177063, 55.93871007646833, 51.869886670793804, 53.769805567605154, 50.08242436817714, 52.06679514476231, 51.60056407111031, 56.278657640729634, 51.54626389912197, 52.75313820157732, 48.929627895355225, 51.322740350450786, 49.613618986947195, 46.95240681512015, 47.76905986240932, 42.46463482720511, 45.239741870335166, 43.91138178961617, 42.85368183680943, 41.41987589427403, 44.89199147905622, 41.43168783187866, 31.979000636509486, 37.92333044324602, 42.92320203781128, 44.30186012813023, 40.22644635609218, 38.867872033800396, 41.18175418036324, 39.390376567840576, 39.80398198536464, 37.96180261884417, 40.440159048352925, 42.47914266586304, 44.77691193989345, 46.99267510005406, 49.14160353796822, 52.90737778799874, 55.325455120631624, 40.956712450299946, 30.219765390668595, 31.044363703046525, 36.40886633736746, 50.31028706686837, 54.445632525852744, 53.07333551134382, 48.72991234915597, 44.62802594048636, 44.31048631668091, 40.54221766335623, 43.9594007900783, 39.749553271702354, 39.08810561043875, 39.50655392238072, 43.052664348057334, 40.483102389744346, 37.58766296931675, 40.39711148398263, 44.596362999507356, 38.800814969199045, 35.692607811519075, 42.121716908046174, 43.30536685671125, 44.751273087092805, 39.71096297672817, 44.71566356931414, 43.64758995601109, 44.65646839141846, 46.08122083118984, 47.505907263074604, 47.604967730385916, 48.379976749420166, 51.4256466456822, 51.60198150362287, 50.593558175223215, 50.64992891039167, 48.02114398138863, 50.28630883353097, 47.76696845463344, 53.13000849315098, 51.69024794442313, 55.467848028455464, 52.03409692219326, 52.690455027988975, 43.56599725995745, 47.7444041797093, 51.59148972375052, 54.605913570949006, 53.95673990249634, 50.82410635266985, 45.64185496738979, 41.57916682107108, 42.206561361040386, 47.20110368728638, 57.16283328192574, 59.74519034794399, 63.346087319510325, 61.83388832637242, 60.15802451542446, 59.21454947335379, 58.56685924530029, 57.603474140167236, 65.47309071677071, 66.92042827606201, 30.51969133104597, 3.396824687719345, 0.08919603377580643, 0.12671728325741632, 2.4815467383180345, 0.6767137763755662, 54.539593015398296, 66.21950095040458, 64.0342160633632, 58.79737268175398, 23.910444974899292, 20.210861001695903, 45.98768418175833, 51.18576356342861, 28.588587181908743, 56.258316789354595, 58.72024072919573, 60.75736917768206, 3.969613117831094, 0.2840380429157189, 0.11304279416799545, 0.04118043277412653, 0.15569535616253102, 0.04073949697028313, 0.17879777720996312, 0.20565035273986204, 0.1716111549841506, 0.1863272360392979, 0.24824483213680132, 0.26814124307462145, 0.19004619148160729, 0.2043878704841648, 9.834328293800354, 85.35049029758999, 65.1979490007673, 55.03534698486328, 32.204643385750906, 42.667418003082275, 51.983996936253135, 49.5342948777335, 31.14240278516497, 31.267480782100133, 63.083473205566406, 63.824797357831685, 64.51617785862514, 57.30671310424805, 1.2745758124760218, 5.723172988210406, 0.3075421159820897, 0.8973697274923325, 0.4379082891557898, 0.6326804363301822, 23.711799451283046, 74.33379486628941, 59.975814955575125, 60.71777139391218, 58.636646951947895, 59.03478567940848, 56.956558636256624, 53.95330054419381, 50.127573762621196, 46.403516496930806, 46.09887967790876, 50.614986419677734, 52.02739538465227, 53.23250484466553, 57.723122119903564, 52.91324554170881, 55.06973014559065, 46.253893988473074, 46.27028131484985, 54.395914690835134, 54.43611349378313, 57.01724420275007, 53.94567837033953, 56.3444744518825, 52.96165016719273, 53.58285386221749, 53.51440715789795, 58.5927551814488, 52.87727819170271, 54.88641929626465, 54.10497971943447, 55.72331244604928, 52.96930708203997, 50.651447091783794, 52.7982736996242, 46.409439836229595, 49.612142494746614, 47.399770055498394, 46.48993819100516, 44.03649800164359, 48.55263948440552, 46.16607918058123, 37.40007202965872, 42.11977488654, 47.18218721662249, 47.55193560464041, 44.186374119349885, 41.4189761025565, 44.202195167541504, 42.31205933434622, 43.40935012272426, 42.348266397203716, 45.532438210078645, 46.900663580213276, 47.4713990347726, 50.673674379076274, 51.237836837768555, 55.57927628925869, 57.819740295410156, 41.53302730832781, 29.562966074262345, 30.332142080579484, 36.45621483666556, 52.30014344624111, 58.56501797267369, 57.51549257550921, 49.63786472593035, 45.627305439540315, 47.45451143809727, 43.10523441859654, 46.654693875994, 42.43940591812134, 42.8686899457659, 42.82263381140572, 45.368002142224995, 44.98640360151018, 40.22683892931257, 43.65268645967756, 48.69412217821394, 43.80553640638079, 42.72614765167236, 47.41914858136858, 47.15636076245989, 50.270494733537944, 45.13278477532523, 49.221090929848806, 45.63247489929199, 49.91685921805245, 49.789015838078086, 50.038536071777344, 50.569093567984446, 53.4821640423366, 54.822659151894705, 52.81826366697039, 55.19414806365967, 53.098762444087434, 52.07605709348406, 51.19596699305943, 51.13132790156773, 54.47635746002197, 53.51428556442261, 57.32745347704206, 54.63690948486328, 54.41779456819807, 47.310906069619314, 50.00065796715872, 52.49937956673758, 56.60298218045916, 54.29028122765677, 53.640457902635845, 47.66282885415213, 44.081584862300325, 43.811647347041536, 50.549437114170615, 61.29015704563686, 60.83262511662075, 66.73905944824219, 63.947078704833984, 61.275169781276155, 61.83124106270926, 60.833882740565706, 63.73386628287179, 66.52155303955078, 69.92817143031529, 36.583853244781494, 4.639169761112758, 0.5474817880562374, 0.1638559339834111, 3.6783350791249956, 2.2556284495762418, 54.77571712221418, 74.290757724217, 67.10624395098004, 70.26892498561314, 29.882857663290842, 34.80585438864571, 62.36540467398507, 60.197997501918245, 35.24684265681675, 62.63534218924386, 67.93894386291504, 74.50307382856096, 6.720377147197723, 0.46072305206741604, 0.1815488160188709, 0.1939064043440989, 0.45237435719796587, 0.15323804159249577], [0.03293412544631532, 0.020448109101770178, 0.0332261703110167, 0.09352693281003407, 0.08933121830757175, 0.04090707815651383, 0.035959363648934026, 0.051870816453759155, 2.1901762017181943, 55.54910026277815, 52.20572437558855, 62.21587944030762, 26.03953630583627, 14.800783395767212, 32.02147844859532, 39.955206053597585, 10.296014377049037, 14.99538333075387, 42.98454768317086, 57.432131562914165, 48.05105250222342, 59.693245615277974, 8.00882807799748, 3.4509329157216206, 0.28826336190104485, 0.7093992424862725, 0.2417117069874491, 0.2708407539342131, 5.006766378879547, 57.66307578768049, 58.208985328674316, 53.80138165610177, 58.30122266496931, 54.49420043400356, 56.16834109170096, 55.5686594418117, 52.76885502679007, 41.93905224118914, 42.36553267070225, 43.49109220504761, 50.0373409816197, 49.86146123068673, 54.24605941772461, 50.804574966430664, 51.877435888562886, 35.8821998323713, 51.43295267650059, 52.12654617854527, 53.51946544647217, 53.29176950454712, 53.760091985974995, 49.76050737925938, 50.42682920183454, 49.77666194098336, 49.09917088917324, 50.532844815935405, 51.74682365145002, 50.68515975134713, 50.212355681828086, 47.789282594408306, 46.37190219334194, 49.11308813095093, 45.350197383335654, 41.86132621765137, 40.36169304166521, 40.090768882206504, 40.997811044965474, 38.42903423309326, 41.46213831220354, 35.10482495171683, 28.487569059644425, 34.87350899832589, 36.92538847242083, 39.48177317210606, 41.99829258237566, 37.02147511073521, 38.764128480638774, 36.48404584612165, 37.63103015082223, 40.630793298993794, 38.547424588884624, 40.299558775765554, 44.22257423400879, 41.773514883858816, 45.008401598249165, 49.90245907647269, 54.02585015978132, 41.03527225766863, 30.37662444795881, 37.94261169433594, 38.34428358078003, 49.07264961515154, 54.250641754695344, 50.82749359948294, 50.570292132241384, 45.95920351573399, 41.795467717306956, 40.733609267643516, 38.313075746808735, 38.246591908591135, 37.17863988876343, 39.76944596426827, 35.153709002903526, 23.66665526798793, 35.39922360011509, 36.08717516490391, 39.74209785461426, 37.641980511801584, 35.620843342372346, 40.25780010223389, 40.91575281960623, 40.678478785923545, 42.02540445327759, 43.775742530822754, 42.410821029118125, 39.47152805328369, 45.18065786361694, 46.15668174198696, 43.01858343396868, 46.00927223478045, 48.55227817807879, 50.123988492148264, 50.16136632646833, 49.6409775188991, 44.750467096056255, 46.871470723833355, 43.94469492776053, 47.09849616459438, 48.7657858984811, 50.214672906058176, 51.039371967315674, 49.82838085719517, 41.34323031561715, 49.14666530064174, 49.264902796064106, 52.44480146680559, 49.834265981401714, 47.659993989127024, 41.02737562997, 41.869848183223176, 40.36852312088013, 42.57257161821638, 51.157425335475374, 57.19374581745693, 58.382064955575125, 60.13874326433454, 58.907904624938965, 61.16616644178118, 60.249733788626536, 66.91349397386823, 51.36170584814889, 45.67361865724836, 11.025239978517805, 1.0898476392030716, 0.037674696783402135, 0.2836396342941693, 1.3617258731807982, 1.9374076851776667, 56.860218388693674, 56.52833768299648, 62.16606085641043, 39.64769268035889, 12.125689591680255, 31.874659538269043, 34.68372590201241, 52.05776596069336, 24.00198575428554, 37.357139110565186, 53.27481937408447, 60.80961268288748, 6.544258551938193, 0.2579552653644766, 0.12096648184316498, 0.10258764161595277, 0.06586761306971312, 0.09641603992453643, 0.0699619340843388, 0.05533886321687272, 0.02635658678731748, 0.07208846961813313, 0.022875259397551417, 0.04883025014506919, 0.041385553910263946, 0.06321969122758933, 2.999201864004135, 66.51267324175153, 59.555358614240376, 59.12092249734061, 28.711245468684606, 20.956317595073156, 39.93495552880423, 55.76115928377424, 14.817573717662267, 17.698453187942505, 49.238607338496614, 62.998329980032786, 53.89980983734131, 64.59342793055943, 10.122112257140023, 2.3962237281458716, 0.3672871786568846, 0.30001111009291237, 0.3970591239631176, 0.448229051062039, 6.364425276006971, 62.52111380440848, 58.970667702811106, 56.59485626220703, 59.616961342947825, 58.34622614724295, 59.60127925872803, 56.468128068106516, 54.47536734172276, 43.057708740234375, 43.81911666052682, 45.03864363261631, 51.372030871255056, 51.68507501057216, 56.71277066639492, 53.793429442814414, 51.98482377188546, 38.86200080599104, 53.61948129108974, 52.58841378348214, 54.52474124091012, 55.44924422672817, 53.63824142728533, 50.77227973937988, 52.111030851091655, 52.25563676016671, 50.5276232446943, 50.243792806352886, 53.83367688315255, 53.76402814047677, 53.32168844767979, 50.84979036876133, 49.83320985521589, 51.97610378265381, 49.59045021874564, 45.29318741389683, 45.47327777317592, 43.53058923993792, 43.673819405691965, 41.55144350869315, 46.077614716121126, 38.7896283694676, 32.69861166817801, 36.49274846485683, 41.37421580723354, 44.62702192578997, 44.817989689963206, 40.91644069126674, 42.74009616034371, 39.24973808016096, 40.58103377478463, 42.41040761130196, 40.53661394119263, 44.44712611607143, 47.23739412852696, 45.53528697150094, 48.73866360528128, 50.02494192123413, 57.126435143607004, 41.69127947943551, 29.25374344417027, 37.155252252306255, 37.181561606270925, 49.876208782196045, 56.525245734623496, 52.240646021706716, 50.549430165972026, 47.41751575469971, 44.56551994596209, 41.03324685777937, 39.86736345291138, 39.62489564078194, 38.371607371738975, 39.731842313494, 36.77763850348336, 26.99067521095276, 40.059488092150005, 41.366499832698274, 42.43758201599121, 40.90505606787545, 37.955952235630576, 43.40159593309675, 44.21676206588745, 41.72237614222935, 43.471289839063374, 43.8720098223005, 45.23215096337454, 42.37543037959507, 48.50794519696917, 47.160001618521555, 44.22213997159685, 49.73450027193342, 51.77194833755493, 51.08887093407767, 49.874440465654644, 52.4119017464774, 48.531919956207275, 49.89967284883772, 46.731825828552246, 50.345646449497764, 51.16597856794085, 52.89861610957554, 54.089516503470286, 51.59352902003697, 43.347069944654194, 49.27385902404785, 51.4408597264971, 55.591793469020296, 52.84967647280012, 52.226443903786794, 44.19733490262713, 43.16314765385219, 43.477095058986116, 45.5396226474217, 54.039180278778076, 58.42255210876465, 61.595189911978586, 62.168471881321494, 61.329657554626465, 64.3819386618478, 64.85420077187675, 70.37218911307198, 54.03736679894583, 49.46074819564819, 11.980451396533422, 1.6382689539875304, 0.09429146535694599, 0.4597533441015652, 3.7089692524501254, 2.9627852695328847, 64.90893868037632, 63.01571437290737, 67.55864116123745, 45.36528192247663, 15.295668840408325, 24.254455498286656, 35.6480837549482, 60.467191559927805, 24.035257203238352, 40.78586319514683, 59.393569810049875, 69.62135982513428, 8.560783420290266, 0.5857778159635407, 0.12709971916462692, 0.14469498715230397, 0.023209853496934687, 0.0702576260747654, 0.11219948370541845, 0.1234516299196652, 0.1242246577250106, 0.23715984980974877, 0.1635775582066604, 0.1676910546209131, 0.14479205837207182, 0.15305432145084652, 3.7327038645744324, 79.3238034929548, 66.0742141178676, 81.16106700897217, 36.97526611600603, 23.761336633137294, 48.29335355758667, 51.27552386692592, 17.414204120635986, 25.913416079112462, 56.65967600686209, 68.44150706699916, 58.12851129259382, 71.11263084411621, 11.224668911525182, 6.356454389435904, 1.6269094092505318, 1.3531255232436317, 0.7461171065058027, 0.5580103173851967, 7.440298676490784, 66.53026608058384, 62.7962555204119, 61.23259122031075, 63.614336422511506, 62.816544260297505, 60.97467408861433, 59.38819885253906, 56.602791104997905, 46.41219479697091, 47.64519085202898, 47.934433937072754, 53.773005213056294, 54.17776904787336, 59.98041466304234, 53.13874237877982, 52.184709548950195, 41.81105252674648, 55.68237018585205, 54.623065199170796, 57.96565593991961, 58.377048356192454, 57.14532034737723, 53.032598223005024, 55.740745476314, 54.33073711395264, 52.33072941643851, 53.2125426701137, 56.607105936322895, 55.161946637289866, 57.931463854653494, 55.43237052645002, 51.24626847675869, 56.77624593462263, 53.53690889903477, 50.347345284053254, 49.61044018609183, 45.51298325402396, 47.1133131980896, 44.958517006465364, 49.816103390284944, 42.9332526070731, 37.77166516440255, 44.627998147692, 45.54196419034685, 47.91367966788155, 51.259772300720215, 46.906406266348704, 46.530915192195344, 41.97170182636806, 43.63579191480364, 46.03053372246878, 43.96596336364746, 47.638933999197825, 50.396396092006135, 46.58361380440848, 51.66365024021694, 52.15370321273804, 58.88603169577462, 43.9686210496085, 31.22115366799491, 38.39499153409685, 38.88667038508824, 51.18198026929583, 58.90246418544224, 55.563649790627615, 53.46869843346732, 50.02970838546753, 46.86653750283377, 43.97574642726353, 42.27864892142159, 42.859674658094136, 41.326103006090435, 44.22697244371687, 42.99215596062796, 32.62907062258039, 44.41687018530709, 44.80647652489798, 47.1674987248012, 45.558226449149, 45.25946780613491, 46.50057588304792, 47.58211163112095, 46.01062365940639, 46.15425334657942, 46.2588723727635, 49.31741380691528, 44.09285831451416, 54.115384646824424, 50.82964406694685, 49.34100294113159, 52.68093947001866, 51.99014261790684, 55.2080340385437, 54.555625983646934, 54.74231365748814, 50.41215113231114, 53.42166607720511, 48.82494633538382, 53.328296184539795, 54.22438798631941, 54.98781088420323, 54.94428736822945, 54.21940960202898, 48.090896947043284, 53.397566250392366, 53.378100872039795, 58.86406149183001, 54.47203915459769, 53.732222761426655, 47.82555913925171, 46.61218132291521, 47.480789525168284, 48.553931849343435, 58.08728068215506, 64.82713753836495, 64.3129083088466, 63.56556701660156, 62.276891572134836, 65.72235039302281, 62.135134424482075, 69.98104722159249, 61.52443640572684, 56.119578633989605, 14.051685946328298, 3.0835710167884827, 0.5201614711965833, 0.5719158883605684, 6.181110518319266, 2.7270485247884477, 68.8320792061942, 68.26037447793144, 71.62428229195731, 55.22295529501778, 23.592469351632253, 41.44035570962088, 49.269512925829204, 69.17052595955985, 35.82625988551548, 54.088196345738, 68.20678997039795, 81.76608834947858, 12.656048195702688, 0.8719329695616449, 0.19087226715471062, 0.19816698000899383, 0.15772355161607265, 0.25908722462398664], [0.023921573967007653, 0.05475856310554913, 0.08479968325367995, 0.013437003529231464, 0.03741582888843758, 0.02109573345764407, 0.07057929917105607, 0.08587717650724308, 0.21430432051420212, 45.84471109935215, 57.89547218595232, 44.46369062151228, 27.889596666608536, 28.078650202069962, 29.411700316837855, 39.705505166734966, 9.268465263502938, 19.591507264545985, 46.91144371032715, 55.25773797716413, 51.31190463474819, 55.14956842150007, 25.713592835835048, 1.0793463055576598, 0.05090603804481881, 0.18691083043813705, 0.15830076778573648, 0.14330013628516877, 0.5573951846786908, 34.40894201823643, 61.51329149518694, 56.73957681655884, 56.89858634131295, 54.252024446214946, 56.07441186904907, 55.43821743556431, 55.19957113265991, 42.86778667994908, 41.271924427577424, 42.25219365528652, 47.48365913118635, 52.10134506225586, 51.59924738747733, 53.051841259002686, 40.011177267347065, 43.07469013759068, 56.12645387649536, 51.9788031578064, 53.424476623535156, 50.366685594831196, 52.133918217250276, 47.46447515487671, 48.55393532344273, 49.74505458559309, 49.082078320639475, 49.99584286553519, 50.13167667388916, 48.37640190124512, 50.36761317934309, 45.16004255839756, 50.61157832826887, 50.6251551083156, 47.00065163203648, 40.65350696018764, 37.764974049159456, 38.8059983253479, 41.82907962799072, 38.51245777947562, 40.86825493403843, 44.83442217963082, 33.55641194752285, 32.241816248212544, 38.025625297001426, 41.39788831983294, 40.79762996946062, 37.71464477266584, 40.90214477266584, 38.44043622698103, 40.20993396214077, 39.567958627428325, 41.19845070157732, 40.59351968765259, 45.1012990134103, 43.70481879370553, 49.02738210133144, 42.34730407169887, 47.85426909582955, 50.045946325574604, 32.73467629296439, 38.983722823006765, 38.690151010240825, 54.117899894714355, 47.972148759024485, 46.78355169296265, 46.952841077532085, 46.725040912628174, 44.73022699356079, 43.653655733381, 39.90071133204869, 40.58800629207066, 40.583621978759766, 39.45609610421317, 33.52345664160592, 31.906385013035365, 35.52526044845581, 31.45773983001709, 32.88902357646397, 35.40817635399954, 39.813792841775076, 42.43270785467965, 43.264775480542866, 40.52999925613403, 43.722807679857524, 42.38423374720982, 41.3285869870867, 42.602264744894846, 45.4049630846296, 44.53118542262486, 45.086805071149556, 44.21512229101998, 49.751235008239746, 49.12424693788801, 48.98404271262032, 49.38947010040283, 43.762822355542866, 45.121497426714214, 47.04442180906023, 46.55251019341605, 46.35598039627075, 48.344266482761924, 49.895684582846506, 50.11721747262137, 45.24387257439749, 51.30173247201102, 47.32656730924334, 48.91946962901524, 49.631190981183735, 49.56138590403965, 45.606537273951936, 41.9529138973781, 40.89151055472237, 40.87063816615513, 44.51271711077009, 55.92815228870937, 56.64508478982108, 63.29838098798479, 59.45267118726458, 59.390463965279714, 52.86353118079049, 56.2968202318464, 56.61634356634957, 38.70858458110264, 8.553034441811697, 0.4060456417500973, 0.04107445578223892, 1.3763394547360284, 2.5791873846735274, 12.39710099356515, 66.16197681427002, 49.64968361173357, 61.214303561619346, 36.44143949236189, 17.660809585026332, 21.73533398764474, 38.47622987202236, 43.39236525126866, 38.90250880377633, 59.83869225638253, 42.33225079945156, 59.62270055498396, 3.0298853261130194, 0.2041405173284667, 0.022600773322795118, 0.02798396990900593, 0.13698514657361166, 0.01974305523825543, 0.07672266023499624, 0.06458296307495662, 0.06622105517557689, 0.028163802044998323, 0.048393114137330225, 0.04618841476206269, 0.08432943134435586, 0.08256408678633825, 0.23534023602093967, 52.91573994500296, 65.0116400037493, 47.4109913962228, 28.960414818355016, 31.027146066938126, 34.93576833180019, 38.591201714106965, 14.501708609717232, 23.221313953399658, 54.70024926321847, 59.55417742047991, 56.87717546735491, 59.97857339041573, 29.265583174569265, 0.44443460181355476, 0.18336564781410353, 0.19194584526121616, 0.1822693252137729, 0.31461595211710247, 1.0245258871998106, 40.64524555206299, 65.52650151933942, 59.0864177431379, 60.95858900887625, 54.29105942589896, 60.03911304473877, 55.6925562449864, 58.56345462799072, 44.778388432094026, 43.19517537525722, 43.81001452037266, 51.18285574231829, 53.14783757073538, 53.31761680330549, 53.548866748809814, 44.0199647630964, 44.77653326307024, 58.19678776604788, 53.03305333001273, 55.43842588152204, 50.86459697995867, 53.28095810753958, 49.61040544509888, 50.94707209723336, 52.40620422363281, 50.936941623687744, 50.95135566166469, 53.39872659955706, 49.54360546384539, 51.378864424569265, 46.56449931008475, 52.468335015433176, 52.995956897735596, 50.99271828787667, 44.42511074883597, 41.438799313136506, 41.40433624812535, 46.09368242536272, 42.47353546960013, 43.12437323161534, 47.506456170763286, 38.29832124710083, 36.6366526058742, 43.255065373011995, 45.787225178309846, 44.212468079158235, 42.45871148790632, 41.91975014550345, 41.10260725021362, 43.546090670994346, 42.64620862688337, 43.67902708053589, 45.224306447165354, 46.47061177662441, 44.67810855593, 49.05993788582938, 44.939763818468364, 48.48085764476231, 49.39125231334141, 33.016936438424246, 38.30651664733887, 36.94888033185686, 55.600179944719585, 50.03586448941912, 47.21424967902047, 47.97512606212071, 49.62948519842965, 47.45298630850655, 44.95493868419102, 41.47743477140154, 42.70910719462803, 41.58489908490862, 42.026557854243684, 36.57548066547939, 36.580500738961355, 39.941441672188894, 35.68875503540039, 36.79170513153076, 37.85195854731968, 41.48194415228707, 46.81101097379412, 45.118231773376465, 43.091914721897666, 47.75027193341936, 46.0962358883449, 45.179219586508616, 43.18261998040335, 48.68450239726475, 48.903096199035645, 49.04356098175049, 48.17998327527727, 52.81301430293492, 50.9426634652274, 52.655185971941265, 50.415521008627756, 48.076277937207905, 47.2276041167123, 49.88099956512451, 49.42823757444109, 49.02820546286446, 50.08608259473528, 53.84408181054251, 50.425818238939556, 48.148893560682026, 52.44165045874459, 48.94472633089338, 52.40279960632324, 53.62054436547415, 52.44548239026751, 49.07196521759033, 44.19018868037632, 44.29736116954258, 41.85561827250889, 46.80670656476702, 58.80402905600411, 58.862164633614675, 63.61898476736886, 61.35980578831264, 60.0791346686227, 56.54368625368391, 64.44970444270542, 64.78340557643345, 42.111617701394216, 11.017603039741516, 1.576562219432422, 0.03900302407730903, 1.9583304481846946, 2.2559211424418857, 15.377515145710536, 71.90001460484096, 53.716870716639924, 68.55167075565883, 42.780729225703645, 20.238620792116436, 22.06992449079241, 41.699485301971436, 52.49595757893154, 35.67885037830898, 60.31541510990688, 50.95525360107422, 68.21887983594621, 5.049305856227875, 0.35975166729518343, 0.10965490274663482, 0.07655921471970421, 0.08397896800722394, 0.06969044543802738, 0.21908896948610032, 0.1876527541982276, 0.11437133859310832, 0.10923960538847105, 0.12657940494162695, 0.11695374787918159, 0.15940369931714876, 0.1880537819649492, 0.40915069941963467, 64.02214009421212, 74.60350309099469, 59.13177558353969, 38.284998076302664, 39.92647525242397, 45.14858497892107, 49.50466775894165, 15.432385069983345, 32.15687799453735, 59.757836069379536, 67.1110451562064, 62.32120023454939, 67.04514844076974, 31.57871491568429, 1.6887294862951552, 0.9388288685253688, 0.24081766924687795, 0.4712482158626829, 0.5885841825178691, 1.7006086260080338, 41.87252671377999, 67.16697815486363, 60.768701689583914, 63.79098047528948, 56.82856239591326, 62.78921004704067, 58.03970289230347, 61.420949935913086, 48.26636675425938, 46.02641691480364, 46.3792290687561, 53.66797971725464, 55.92890616825649, 56.45959915433611, 55.68109171731131, 44.197352273123606, 47.214239256722585, 59.15170996529715, 55.71896634783064, 57.266125202178955, 51.42336416244507, 55.244199412209646, 51.82188504082816, 51.548799991607666, 56.21431384767805, 53.4832375390189, 53.478686468941824, 52.846911089760916, 52.46436411993844, 55.08283792223249, 51.17255851200649, 54.408855710710796, 55.83630405153547, 54.43045766013009, 47.11867025920323, 44.794424874441965, 44.988574913569856, 50.78657913208008, 44.58340113503592, 46.45196975980486, 51.23456423623221, 41.970381668635774, 42.842787061418804, 48.20246417181832, 49.85655232838222, 50.052463735852925, 46.0008544921875, 47.18181896209717, 46.05592591421944, 46.59181267874581, 46.40267923900059, 48.48467915398734, 49.03067207336426, 51.70412697110857, 49.65003449576241, 52.437422479902, 47.630908829825266, 52.17679207665579, 51.68009662628174, 33.37845468521118, 38.154761041913716, 38.31802633830479, 58.69494233812605, 54.139234338487896, 50.00947175707136, 50.58814205442156, 52.49648216792515, 51.359492846897666, 49.06478425434658, 43.73506430217198, 46.11701447623116, 45.832829679761616, 45.44883748463222, 41.12950720105852, 41.71544878823416, 45.4623030935015, 42.50395468303135, 42.74682201657976, 42.71152169363839, 46.1357398714338, 51.06331198556082, 49.039124556950156, 47.014204093388145, 52.58184426171439, 49.43501901626587, 49.57955544335501, 47.249970367976594, 51.61826113292149, 53.46415778568813, 52.92351150512695, 50.9329047203064, 56.111647265298025, 53.3495055607387, 55.116488048008506, 54.2224702835083, 49.86535569599697, 49.57560191835676, 52.557866028376985, 50.646774428231375, 52.611599922180176, 53.80985845838274, 54.752857548849924, 53.30993209566389, 49.36523130961827, 53.471776485443115, 49.49034404754639, 54.28709895270211, 55.829783167157856, 55.98355722427368, 51.3239597593035, 47.07217986243111, 45.43242236546108, 45.10907404763358, 48.911440985543386, 61.140444210597444, 61.51068592071533, 67.71296760014125, 61.93073926653181, 63.348762375967844, 57.81038454600743, 57.673678738730295, 58.913032395499094, 48.2385287966047, 15.030119112559728, 3.016462274960109, 0.1818533425352403, 2.7269840368202756, 7.210113108158112, 14.694561072758265, 79.75127056666783, 58.91708319527762, 73.77807794298444, 48.268367835453574, 27.988222871507915, 31.676576818738663, 56.63238000869751, 60.91640649523054, 56.22502449580601, 77.24506228310722, 55.871100630079, 82.35083484649658, 9.293876562799726, 0.6580946126154491, 0.31911062236343113, 0.21911951713263988, 0.1371412639107023, 0.18492745900792734], [0.025718492455780506, 0.08031540816383702, 0.06886886845209769, 0.02525434736162424, 0.04020187331895743, 0.26489556580781937, 0.04952512428696666, 0.1320600544235536, 0.19859628911529267, 29.07829621859959, 62.1089814049857, 46.932569708142964, 41.13655267442976, 32.53365101133074, 37.95761980329241, 72.55406938280377, 12.14712391580854, 11.909308791160583, 56.410096713474815, 50.97463212694441, 59.354889188494, 45.82443972996303, 47.362538133348735, 0.4597925362842423, 0.08571758507085697, 0.12096463622791426, 0.09289955933179174, 0.260439002088138, 0.269473885851247, 11.813117061342512, 52.54666205814907, 55.70924929210118, 55.50679962975638, 56.09062201636178, 55.6591979435512, 56.782287393297466, 54.7252071925572, 41.26032788412911, 41.44500405447823, 42.2331416947501, 45.32284232548305, 51.695580686841694, 50.56040831974575, 53.299079009464805, 40.513208934238975, 45.213088580540244, 55.70302023206438, 50.80783714566912, 54.01497275488717, 49.557793685368125, 52.50559820447649, 49.0531599181039, 48.219386509486604, 48.23780965805054, 47.0319185256958, 50.408194133213584, 53.16432217189244, 49.96366923195975, 50.518910203661235, 46.42016090665545, 47.88083553314209, 44.60967574800764, 46.417621340070454, 44.14196470805577, 40.94002635138375, 40.54906163896833, 42.62662165505545, 41.579851218632285, 33.29945019313267, 28.042901720319474, 33.52092749731881, 35.3122912134443, 38.988002913338796, 38.573942388807026, 41.313703945704866, 41.70257725034441, 43.4825632912772, 39.73032760620117, 44.79793718882969, 42.99407018933977, 44.13139649799892, 42.64331122807094, 46.6529220853533, 45.672753606523784, 47.622275693076, 41.33185958862305, 43.05082654953003, 50.90545238767351, 35.1959992136274, 32.48468358176095, 39.09121492930821, 54.1551387650626, 40.705458641052246, 42.63241645268032, 49.460209710257395, 46.29831729616438, 45.401787757873535, 43.95221635273525, 40.454527923039024, 40.337092944553916, 39.239642347608296, 42.09828758239746, 43.40453502110073, 43.88405799865723, 35.21318905694144, 23.300688437053136, 23.564436844417028, 34.71952302115304, 42.46913725989205, 40.372261251722065, 42.18890251432146, 40.52920716149466, 41.172787530081614, 39.40414442334856, 40.243948868342805, 46.17408350535801, 47.602660928453716, 46.408025877816335, 49.67052820750645, 46.137949398585725, 50.78707940237862, 49.919058322906494, 50.648164067949565, 45.06032548631941, 44.999035426548545, 46.92293603079659, 49.6908586365836, 50.36079699652535, 47.68099839346749, 46.7988064629691, 50.04320873532976, 51.55544941765921, 50.21514885766165, 52.41100195475987, 51.06725508826119, 54.751957757132395, 52.09906257901873, 51.335233211517334, 46.82398326056344, 43.289813314165386, 41.210106304713655, 43.126242297036306, 41.48790223257882, 50.16422551018851, 56.47909232548305, 55.60057946613857, 58.12689931052071, 57.51830659593855, 57.977839606148855, 37.42098610741751, 36.71601840427944, 25.552415473120554, 7.1864770736013135, 0.14286830302860054, 0.05950674760554518, 0.8350137706313814, 2.3952985320772444, 29.253816400255474, 66.1662985937936, 54.9526356288365, 62.154436520167756, 46.69885662623814, 41.37484114510672, 23.584675209862844, 26.08914123262678, 46.92020538875035, 33.91881956372942, 50.044608797345845, 44.51261288779122, 61.653130940028596, 2.4394578082220892, 0.06360077006476265, 0.07298820705286094, 0.03707992352013077, 0.01714324322529137, 0.008704014820978045, 0.03371416591107845, 0.07649085910192557, 0.03565457250390734, 0.018603357286857705, 0.015777465887367725, 0.263729028403759, 0.05710891341524465, 0.1264491533594472, 0.22972207463213376, 33.504408155168804, 74.33921446119035, 50.303689752306255, 39.459973199026926, 28.770588295800344, 50.80657952172415, 72.54257706233433, 13.249121240207128, 18.2403883593423, 61.46238899230957, 58.9102600642613, 62.38099643162319, 52.93274218695504, 52.46568080357143, 0.7563683592847416, 0.07674379660082714, 0.0552104538572686, 0.2897186023848397, 0.21498780883848667, 0.30009370137538227, 14.258817825998578, 57.21916927610125, 56.98680067062378, 59.665265219552175, 59.00651345934187, 58.56974969591413, 58.58415331159319, 57.37763336726597, 43.43925516945975, 43.62487282071795, 44.31799037115914, 48.46501922607422, 54.944203989846365, 53.90046296800886, 55.047079018184114, 41.49190092086792, 48.07832418169294, 57.06331423350743, 52.11255945478167, 55.978585788181846, 51.78475039345877, 53.5657091821943, 52.57204382760184, 50.991266114371165, 49.23986496244158, 47.234774657658164, 51.16736125946045, 55.52527836390904, 51.22955805914742, 52.1736341203962, 47.56699235098702, 49.927503858293804, 48.01582513536726, 49.12699842453003, 47.25630365099226, 46.059691837855745, 42.48306144986834, 45.35681206839425, 44.8920053754534, 36.20906046458653, 32.722874777657644, 35.969271183013916, 39.05052975245884, 43.867403166634695, 39.52544954844883, 44.88846179417202, 43.67457675933838, 45.67993804386684, 42.59817573002407, 47.68989903586251, 44.85368606022426, 45.266683510371614, 46.40668487548828, 47.951457023620605, 48.04263128553118, 49.726784297398154, 41.24508353642055, 43.968513352530344, 51.69123806272234, 35.921627385275706, 32.551500933510916, 38.64596741540091, 53.80413661684309, 40.45989193235125, 43.17071076801845, 51.81362363270351, 48.029113565172466, 48.49106107439314, 45.82990448815482, 42.79494524002075, 42.749542236328125, 43.03650631223406, 45.57489170346941, 43.713219165802, 45.46829244068691, 39.66809606552124, 27.72404020173209, 28.089016914367676, 38.78541776112148, 45.06064510345459, 43.659394945417134, 43.00049727303641, 43.55001987729754, 44.57715817860195, 43.631053243364605, 42.4907009942191, 50.32308912277222, 52.624666009630474, 50.80997371673584, 53.60220112119402, 49.64610876355852, 53.1735771724156, 52.043174743652344, 52.93181460244315, 47.46361010415213, 46.96460437774658, 50.402329853602815, 51.3755327633449, 51.01833629608154, 49.95452887671334, 49.8408910887582, 51.418952056339805, 52.86576155253819, 53.97216142926897, 54.42788682665144, 52.07616131646292, 55.67889608655657, 53.355137075696675, 53.214012214115684, 49.845938955034526, 44.69718483516148, 44.27015897205898, 44.91916240964617, 43.00289440155029, 51.29616696493966, 57.6094947542463, 56.60782160077776, 61.303421156747, 61.153875078473774, 59.23385156903948, 42.47949702399117, 40.05808455603463, 29.247205189296178, 8.099467328616551, 0.3613705704254763, 0.031910694470363, 1.2773548747811998, 1.0249471217393875, 33.58081749507359, 71.60256222316197, 58.19389384133475, 68.4394781930106, 55.31159346444266, 46.46441398348127, 27.17238450050354, 30.835785729544504, 55.31883348737444, 34.903837885175435, 58.10061774935041, 52.39205074310303, 71.27613585335868, 4.86109869820731, 0.3243563494512013, 0.08752206752875022, 0.09898819654647793, 0.0014384800327076975, 0.028465405771774904, 0.20456243040306227, 0.1855075385953699, 0.16555155228291238, 0.11412846376853329, 0.1042825745950852, 0.4845955967903137, 0.1493185247693743, 0.486744652901377, 0.32095260066645487, 42.116168771471294, 82.537595476423, 60.99829796382359, 54.853926045554026, 43.12815305164882, 52.8094151360648, 77.26988124847412, 21.423059361321585, 21.84718608856201, 68.80951840536935, 61.11413138253348, 68.66323103223527, 57.28529528209141, 58.17224325452532, 0.9139169710023063, 0.1599883929427181, 0.1922199869794505, 0.8138118854590825, 0.5923132481319564, 0.5036960861512593, 16.439592463629587, 60.188179697309224, 57.808831623622346, 62.229400634765625, 60.71784782409668, 62.201093673706055, 62.035531997680664, 59.77613762446812, 44.446674483163015, 44.88471324103219, 47.53794193267822, 52.98616688592093, 56.53866965430123, 56.451987402779714, 55.363402707236155, 42.47792673110962, 48.984706265585764, 60.38506385258266, 54.54736804962158, 58.76890591212681, 51.46960094996861, 55.96815654209682, 55.187203339168, 52.045002119881765, 51.1770852633885, 50.96288619722639, 55.05251598358154, 58.131721360342844, 52.82514238357544, 54.47554799488613, 51.93053749629429, 53.43810551507132, 51.28856910978045, 52.72721447263445, 50.373724120003835, 49.99333109174456, 47.07466731752668, 52.022604601723806, 46.85028566632952, 42.68569871357509, 38.562158243996755, 42.05248853138515, 42.89672245298113, 47.69741003853934, 44.406996795109336, 46.46912486212594, 47.026467663901194, 48.78152356828962, 44.381020954677034, 53.460155623299734, 49.23861081259591, 48.65853697913033, 49.95872906276158, 50.55535350527082, 50.34174503598894, 52.700908592769075, 45.43780721936907, 47.87476628167288, 55.01939044679914, 35.57562794004168, 33.31454515457153, 41.203675746917725, 55.985850129808696, 43.0074246270316, 43.85386460168021, 53.43687915802002, 50.17411627088274, 49.470652852739605, 50.63440316064017, 46.608429295676096, 47.94607216971261, 45.88445826939174, 50.76699563435146, 49.26984643936157, 50.262160369328086, 45.28105238505772, 32.91964776175362, 34.71000746318272, 43.06794343675886, 47.51323413848877, 48.53899322237287, 48.55283750806536, 48.197391986846924, 48.75558941704886, 48.16985280173165, 46.78543465478079, 53.98579379490444, 55.26238284792219, 53.98154844556536, 59.339415550231934, 52.10388115474156, 56.50146552494594, 54.977923597608296, 54.749206270490376, 48.785084520067485, 49.987960134233745, 53.757253646850586, 54.5609587260655, 54.529267992292134, 53.427012716020855, 52.794823919023784, 55.73034749712263, 55.86513212748936, 55.55933148520333, 56.65093517303467, 52.91114371163504, 58.063684599740164, 56.401275975363596, 56.80883993421282, 53.13494518824986, 47.56923314503261, 46.549432141440256, 48.23769153867449, 45.2988988331386, 55.94077716554914, 59.71525056021554, 59.04144900185721, 64.58467320033482, 61.95683670043945, 63.37452629634312, 45.00598015104021, 41.87062985556466, 30.462010860443115, 10.38323598248618, 1.485831882272448, 0.20465837525469915, 1.7166875175067355, 5.321022110325949, 36.10960047585623, 77.56966822487968, 64.81483922685895, 71.77350180489677, 59.002830914088655, 52.86650848388672, 34.24182047162737, 39.598565442221506, 63.76434108189174, 43.79430116925921, 67.38021836962018, 58.12203557150704, 83.5824030467442, 8.284896509987966, 0.6673845169799668, 0.3688683823815414, 0.22211640274950437, 0.09814248406993491, 0.10542489508433], [0.05348169930013163, 0.013813608276125575, 0.013946398427443845, 0.04501889519659536, 0.06157056614756584, 0.17371816906545842, 0.05994058254041842, 0.1311109603515693, 0.3773544670215675, 15.980095931461879, 68.05845287867955, 36.09950474330357, 36.98798131942749, 33.92134175981794, 32.104443413870676, 37.511086872645784, 20.896434545516968, 6.8533804331507, 58.27153301239014, 42.78176103319441, 60.732258387974326, 44.24572215761457, 56.1072108404977, 10.513942888804845, 0.3278534103717123, 0.06490999659789459, 0.2702776512929371, 0.0492092798064862, 0.1677429625498397, 4.546670564583369, 41.32149635042463, 55.96057605743408, 55.155693258558, 56.10589763096401, 55.51744426999773, 55.013852732522146, 48.06557771137783, 41.575546809605186, 41.06941223144531, 43.61836930683681, 46.69475024087088, 49.41948284421648, 49.21076243264334, 53.26540803909302, 36.63801097869873, 43.25962686538696, 53.7188891683306, 52.929865632738384, 53.185621874673025, 50.815355096544536, 52.31623894827706, 52.90689836229597, 50.95787307194301, 45.75652456283569, 47.30219650268555, 47.321324893406455, 49.71785238810948, 52.332733971732004, 49.568462644304546, 49.514523778642925, 47.06302561078753, 47.06657614026751, 46.8687470299857, 46.56972088132586, 44.77127347673689, 40.51880918230329, 39.686251708439414, 44.030460017068044, 35.98014163970947, 24.85779537473406, 30.679406097957067, 42.09662348883492, 43.20083120891026, 38.64646768569946, 39.51892866407122, 42.498896394457134, 42.31836135046822, 43.28304924283709, 46.6624550138201, 40.51502241407122, 39.8692672593253, 43.02830743789673, 49.44751187733242, 49.657576765332905, 51.83588566098894, 42.927562032427105, 41.7338684626988, 51.05772910799299, 36.42943300519671, 34.38755546297346, 40.26162508555821, 49.566565786089214, 40.60712773459298, 40.64736475263323, 47.69665615899222, 47.259454659053254, 45.18749489103045, 44.15061174120222, 42.30458654676165, 42.200884682791575, 44.29721178327288, 45.67861441203526, 45.28613151822771, 39.216237340654644, 34.64644881657192, 23.148291860307964, 30.897027151925222, 42.69695132119315, 40.43040030343192, 39.14342369352068, 40.07403761999947, 40.88355139323643, 41.28863831928798, 40.295306478227886, 43.701309953417095, 44.89896052224295, 48.02549007960728, 49.89289140701294, 42.75523975917271, 48.343074866703574, 48.03866386413574, 51.57546370370047, 50.121441977364675, 44.20884459359305, 43.7374301637922, 50.82146603720528, 48.64707245145525, 51.1278190612793, 51.1922983442034, 50.05390896115984, 49.54024600982666, 52.08567687443325, 53.19989347457886, 56.632974079677034, 37.63510526929583, 42.27834667478289, 55.733585357666016, 50.71476602554321, 53.35040535245623, 46.46104063306536, 44.71894659314837, 40.589194434029714, 41.87329796382359, 42.732956886291504, 53.17438663755144, 57.87276547295706, 56.57917765208653, 57.20278542382376, 62.781983920506065, 63.55026708330427, 48.68601015635899, 24.16050716808864, 3.0086898463112965, 0.26976888573595453, 0.03636508009263447, 2.8344190376145497, 1.4173457686390196, 40.440211159842356, 59.41288580213274, 51.16538449696132, 58.585202489580425, 47.274254322052, 62.535225595746724, 22.833661794662476, 29.48276996612549, 42.11558512278965, 33.01729774475098, 63.33590126037598, 39.48854071753365, 56.11354064941406, 1.1814080689634596, 0.05676774261519313, 0.05826445176665272, 0.09241477320236818, 0.0312623237259686, 0.06183773252580847, 0.05320687565420355, 0.0871948982988085, 0.028406227340123484, 0.009032875299453735, 0.03281213163531252, 0.3464235024792807, 0.02194053160824946, 0.23741647175380162, 0.3768136746117047, 16.822052580969675, 78.586259160723, 41.79928575243269, 38.979359354291645, 35.366004262651714, 40.881918566567556, 41.50868429456438, 17.341411318097794, 10.313654116221837, 62.87237998417446, 48.676015172685894, 66.8232855115618, 49.36521741322109, 60.18225983210972, 12.307561295373098, 0.4364709077136857, 0.2561580975140844, 0.32670687618000166, 0.16641923572335923, 0.2140862393592085, 5.416217642171042, 47.36427170889718, 60.06316770826067, 58.189971583230154, 59.55838802882603, 58.591212681361604, 58.713730267116, 49.25365366254534, 43.494330065590994, 43.41521092823574, 44.56848335266113, 49.12706790651594, 52.22960533414568, 53.33292715890067, 52.877233028411865, 35.47932243347168, 45.45177657263619, 54.34014844894409, 55.514189038957866, 52.97221490315029, 53.332308769226074, 54.89769969667707, 54.54334156853812, 51.661819389888215, 46.82234695979527, 48.51976408277239, 48.1549072265625, 50.528728008270264, 53.316668374197825, 50.7786477633885, 51.43093075071062, 49.10416316986084, 49.46576826913016, 49.75598757607596, 50.595402921949116, 47.661974225725444, 44.42083065850394, 42.889753409794395, 48.02105018070766, 40.3663135937282, 30.793182849884033, 36.07686751229422, 44.31219904763358, 47.060691016060964, 43.41505111966814, 44.15975209644863, 44.97571379797799, 46.59309809548514, 46.88537406921387, 50.18016120365688, 44.384939738682334, 44.599218709128245, 46.03614786693028, 50.21504463468279, 51.26352085386004, 54.41164888654436, 44.61371612548828, 42.22680493763515, 51.00692387989589, 36.754455838884624, 33.127100127083914, 39.99967105048043, 50.77849490301949, 42.10290118626186, 43.02547952107021, 50.38089118685041, 49.032033920288086, 47.104940618787495, 46.19283669335501, 43.951156752450125, 44.381007058279856, 46.79892110824585, 46.25785098757063, 47.192227363586426, 40.83214167186192, 37.65886810847691, 28.521036795207433, 33.75552994864327, 43.39524875368391, 44.92093767438616, 42.754652636391775, 43.94784593582153, 42.620604515075684, 42.512514863695415, 43.574578285217285, 44.450464725494385, 50.23643466404506, 50.77328027997698, 52.349857807159424, 44.19755377088274, 50.55004160744803, 50.03078883034842, 55.03546857833862, 51.07757316316877, 45.97037969316755, 46.43707282202584, 51.69352749415806, 51.576137678963796, 54.71958957399641, 51.69629635129656, 51.99369314738682, 51.62488971437727, 54.78547586713518, 55.006466797419954, 57.991972242082866, 38.49761642728533, 44.40257774080549, 58.956653186253135, 52.66437496457781, 56.77373416083199, 49.328322478703086, 47.62424898147583, 42.64951944351196, 43.90471846716744, 43.68605865750994, 54.74330724988665, 61.108468600681846, 57.17959581102644, 59.162167004176546, 64.14538029261998, 66.3361542565482, 53.62556096485683, 26.5350627217974, 3.7011091027941023, 0.47343744124685017, 0.05180965330717819, 1.7410759116922105, 1.071488761476108, 45.850912366594585, 63.996258054460796, 57.59565046855381, 69.1869376046317, 52.02789912905012, 68.5787478855678, 28.387525422232493, 36.94538191386631, 51.47904355185372, 27.21948286465236, 61.44748510633196, 47.01991203853062, 64.77171175820487, 2.8702647941453114, 0.274458539805242, 0.02608053499300565, 0.1257853154093027, 0.016422886700768555, 0.023513692996597717, 0.15419747653816426, 0.13482889799135073, 0.0495101965165564, 0.13988675230315753, 0.19519773790878908, 0.3323313886565821, 0.1772606646908181, 0.42533378675580025, 0.4410743878356048, 21.144024917057582, 90.34757219042096, 48.28466830934797, 49.748438358306885, 43.624751227242605, 48.78967033113752, 42.03688635144915, 29.632656506129674, 15.872338056564331, 71.2293814250401, 52.09858315331595, 72.37465994698661, 53.12492935998099, 68.9996280670166, 13.041095648493085, 0.624161456312452, 0.34709052954401287, 0.7707416308777673, 0.476841787142413, 0.5707268778766904, 7.022116567407336, 52.155930110386436, 56.63942200796944, 59.36228901999337, 60.529120853969026, 61.484671865190776, 60.315832001822336, 51.31379801886422, 44.951332569122314, 44.92965766361782, 46.99854632786342, 51.42031390326363, 54.830566201891216, 56.16689586639404, 54.391301086970735, 38.037871497017996, 46.23146172932216, 55.86846031461443, 55.13149963106428, 55.87855952126639, 55.49336528778076, 57.92183365140642, 56.90098694392613, 53.71325070517403, 48.92076199395316, 51.17410101209368, 50.09585523605347, 52.276311125074116, 57.035417216164724, 52.2928478377206, 55.41873468671526, 53.33110325677054, 52.81976795196533, 52.30477442060198, 54.01217263085501, 51.83331135341099, 48.81386743273054, 47.61740847996303, 52.545630250658306, 45.26747213091169, 36.31008379799979, 42.51195205960955, 49.35158504758562, 48.81037596293858, 47.34175954546247, 47.98234871455601, 50.15904215403965, 50.8893985748291, 51.667016642434255, 55.35786846705845, 46.98709569658552, 47.49493258340018, 48.10391092300415, 54.26149831499372, 53.207487855638774, 56.343394007001606, 49.04971361160278, 44.933753626687185, 53.46716635567801, 36.52723932266235, 34.36942066465105, 39.102745464869905, 54.31929690497262, 46.238819871629985, 45.819252899714876, 52.14206150599888, 51.445261410304475, 49.99709701538086, 50.875467436654226, 48.17971576963152, 49.093473366328645, 51.02847719192505, 51.54741382598877, 51.59435238157, 43.61963735307966, 43.1267842565264, 33.85832854679653, 40.71975803375244, 49.226972579956055, 47.72447327205113, 44.66426427023751, 46.94444765363421, 47.877555983407156, 46.24512883595058, 46.1179107938494, 48.24634552001953, 52.85710409709385, 55.28422451019287, 55.473146029881065, 45.809949261801584, 52.96186556134905, 52.914242608206614, 58.56609494345528, 52.37640687397548, 47.718751430511475, 48.56997176579067, 53.518339838300435, 53.59282800129482, 56.60712678091866, 54.12372248513358, 54.12556723185948, 54.33464200156075, 57.260618754795615, 56.74606990814209, 61.58642128535679, 41.12180512292044, 49.07319504874093, 60.84338787623814, 55.88788400377546, 60.66506930759975, 51.45620829718453, 49.75379889351981, 44.162347248622346, 46.29200833184378, 47.85521405083792, 58.06340667179653, 64.64346885681152, 61.14730208260672, 62.68040820530483, 66.74318667820522, 67.84476797921317, 56.680388586861746, 31.232131821768625, 5.932060590812138, 0.7479767267193113, 0.2150637504777738, 6.069079501288278, 2.711283279316766, 49.56093774523054, 70.78639902387346, 60.53525611332485, 67.97864586966378, 60.25224208831787, 73.91242831093925, 34.78154264177595, 41.06629596437727, 57.562705584934776, 43.85979488917759, 76.34675748007638, 53.65669584274292, 78.67775303976876, 5.354258384023394, 0.6149604128939765, 0.12266511283814907, 0.20961432717740536, 0.09969174236591373, 0.14727560510592802], [0.022774391774354235, 0.0483874042651483, 0.02294720446557871, 0.0049581783657361355, 0.05691845202818513, 0.1248724279659135, 0.0640041252065982, 0.056680303200015, 0.19104810271944317, 5.663740703037806, 64.97186851501465, 44.02942473547799, 42.869329180036274, 24.55487823486328, 39.253840991428916, 23.012649127415248, 15.612141915730067, 28.420947994504655, 53.1697313444955, 48.71606111526489, 57.79754774911063, 50.76455681664603, 54.70805903843471, 17.897479125431605, 0.45251731095569475, 0.1344564908317157, 0.11812689421432358, 0.2653251327574253, 0.2528708396213395, 3.314166311706815, 41.647398131234304, 53.454058579036165, 55.578769070761545, 57.25416387830462, 54.33394718170166, 50.64081982203892, 43.83818251746041, 43.56152956826346, 42.9968147277832, 47.60833413260323, 49.38338347843715, 52.53545808792114, 50.034686769757954, 60.232342447553364, 50.75171307155064, 33.07243864876883, 47.70799561909267, 49.518536363329204, 55.18704353060041, 54.46708508900234, 52.44757727214268, 52.41631037848336, 48.57073606763567, 46.95351505279541, 47.34444849831717, 45.79377385548183, 51.36250489098685, 49.97989327566964, 49.4699649810791, 46.02720553534371, 48.029301166534424, 47.01492323194231, 49.63797589710781, 47.47079454149519, 45.88811649594988, 41.148451464516775, 37.18059580666678, 37.5029296875, 41.66727345330374, 43.97843885421753, 34.309798172542024, 34.042907442365376, 40.98365756443569, 43.89349365234375, 43.95117064884731, 41.67446483884539, 41.17927714756557, 43.45157085146223, 38.0061286517552, 38.59399488994053, 43.693687779562815, 44.402709756578716, 50.60307373319353, 51.26882927758353, 52.324194635663716, 54.9205036844526, 52.09061009543282, 51.48835413796561, 39.91657754353115, 33.77810117176601, 43.43782384055001, 50.50528826032366, 45.481229986463276, 50.10889005661011, 52.83227470942906, 50.75362382616316, 50.10114976337978, 42.979510239192415, 41.45651027134487, 41.509028230394634, 41.00557565689087, 41.97061790738787, 44.86617544719151, 42.217331068856375, 37.77331188746861, 36.01784951346261, 38.33065121514456, 38.058702196393696, 41.64472654887608, 41.59278181621006, 39.912988798958914, 36.10808229446411, 37.84912715639387, 39.53271736417498, 45.88037620271955, 49.641213757651194, 49.49934891292027, 51.678335257938926, 48.19961541039603, 48.10415063585554, 47.00593226296561, 49.58201510565621, 47.53309556416103, 42.247208322797505, 43.420936243874685, 49.70020743778774, 52.349489552634104, 50.64453363418579, 54.278802803584504, 51.004582336970735, 52.03565331867763, 53.2529742377145, 62.487505367824006, 54.06260960442679, 38.380646978105815, 23.764053378786357, 49.730508531842915, 53.756138460976736, 50.83758238383702, 49.769689423697336, 51.05961554391043, 43.95962313243321, 42.682783944266184, 39.49575294767107, 43.27524641581944, 47.92166314806257, 56.4277903011867, 54.28476435797555, 58.31997585296631, 54.36695459910801, 67.28194999694824, 28.118044751031057, 1.1648036113807132, 0.5356466716953686, 0.27991035154887606, 1.129182259951319, 4.959372282028198, 57.517285210745676, 54.18677738734654, 53.1678101675851, 47.3089987891061, 62.81842722211565, 57.52082879202706, 14.927431685583931, 20.450017997196742, 41.64379896436419, 30.853461946759904, 57.698664460863384, 45.00266933441162, 49.16876057216099, 1.4172108215945107, 0.040350557304918766, 0.034826600325426886, 0.11344471760094166, 0.11663790339870111, 0.09307898434677295, 0.042876773713422675, 0.015948041109368205, 0.04102901768471513, 0.05326489718364818, 0.04637297967981015, 0.12827598676085472, 0.010634488509302693, 0.11803132934229714, 0.13387457919972284, 6.003240542752402, 73.36102621895927, 51.57894822529384, 43.61687544413975, 29.479834352220806, 43.89862142290388, 21.95688077381679, 16.85808767591204, 29.75461823599679, 61.53246852329799, 51.19003670556204, 65.78602368491036, 54.732148442949565, 60.97060244424002, 20.73543436186654, 0.3189350717834064, 0.21542991511523724, 0.09091527866465704, 0.5320062498961176, 0.28409487700888086, 3.705010082040514, 45.72502490452358, 56.06278058460781, 60.173525946480886, 59.514906202043804, 57.00239937646048, 52.07392399651663, 45.7462933404105, 45.32723011289324, 45.85143000738961, 47.41211005619594, 53.22156490598406, 53.92619562149048, 53.21396705082485, 59.32986177716936, 44.591853618621826, 32.75906794411795, 48.95553077970232, 50.786388056618826, 56.774296964917866, 55.269101755959646, 53.74613652910505, 53.758744035448345, 52.64012227739607, 49.13671548025948, 48.61740711757115, 47.39157812935965, 52.23215184892927, 53.22708872386387, 49.96940844399588, 49.15036869049072, 50.44970267159598, 51.253393854413716, 51.29765387943813, 50.94904885973249, 49.74748298100063, 46.33245032174246, 40.63052231924874, 41.16654804774693, 44.95396941048758, 46.83115380150931, 38.3176337650844, 38.81939097813198, 46.41515472957066, 47.61147124426705, 47.23367684228079, 45.47571659088135, 44.599510533469065, 46.20926570892334, 40.76518188204084, 42.52046012878418, 45.589823382241384, 47.05312442779541, 53.06408745901925, 52.219113554273335, 55.103633880615234, 55.29848916190011, 52.5397937638419, 52.33240393229893, 38.6383695602417, 33.29552446092878, 41.59364686693464, 50.879872594560894, 46.53770705631801, 51.49364519119263, 53.83781106131417, 51.33369765962873, 50.78008951459612, 44.16508136476789, 44.26093176433018, 43.91296597889492, 43.78287833077567, 45.892768314906526, 47.26894242422921, 45.68992607934134, 40.473805700029644, 38.30219486781529, 43.45372131892613, 40.6456172806876, 43.6180670601981, 44.142211369105745, 43.49648053305489, 39.91381563459124, 41.26941612788609, 43.732448305402485, 48.34884187153408, 53.9807459286281, 53.587179115840364, 54.2309227670942, 51.83640677588326, 50.07424633843558, 48.98881265095302, 49.94436713627407, 48.63364158357893, 43.19623497554234, 44.78637886047363, 51.16273723329817, 55.77553163255964, 52.5113582611084, 55.33401182719639, 52.799788406917024, 53.74160977772304, 55.33065932137625, 59.67232458932059, 55.56838151386806, 43.133770670209614, 24.698978662490845, 51.17300319671631, 57.412801674434114, 54.29829944883074, 52.31230974197388, 52.57464940207345, 46.30639110292707, 43.51926367623465, 42.60677065168108, 44.60307843344552, 50.24872950145176, 58.87371253967285, 56.26591811861311, 61.41979653494698, 56.308653014046804, 70.99127360752651, 30.03175061089652, 2.2659756200654164, 0.6224229953118733, 0.13310837745666504, 1.2254806011915207, 5.494632405894143, 66.57586015973772, 58.26939296722412, 62.887151854378835, 50.61973898751395, 68.8059331348964, 62.12230804988316, 21.161954743521555, 22.97878360748291, 50.94103758675711, 30.527799878801616, 59.28255149296352, 53.12656913484846, 59.61801052093506, 1.9948972974504744, 0.1479686607739755, 0.023730735993012786, 0.08842160140297242, 0.08270798370774303, 0.03913662422980581, 0.1307255117488759, 0.1588966708098139, 0.09786352475306817, 0.10056901350617409, 0.2064040694385767, 0.3108704930969647, 0.14584268842424664, 0.2087547861571823, 0.18144048111779348, 7.396413854190281, 87.37336799076625, 56.68159409931728, 58.82904257093157, 33.915786675044465, 55.955809593200684, 31.54791702542986, 23.606662784303936, 37.8075213432312, 65.40056541987828, 59.59244115012032, 70.22552653721401, 60.672121729169575, 67.13327939169747, 22.529999460492814, 0.5207932144403458, 0.8872301344360624, 0.3061770392315728, 1.3916031271219254, 0.8405906770910535, 4.850943905966623, 48.091960021427695, 58.20868655613491, 63.5547764641898, 61.35770743233817, 61.39470658983503, 55.70121717453003, 48.919115270887104, 46.72623600278582, 47.789668219430105, 51.291713169642854, 54.81252520424979, 57.14721025739397, 55.530225481305806, 61.00938034057617, 42.51827492032732, 33.48334469114031, 50.87560292652675, 53.424483571733745, 59.45368562425886, 56.256815978458945, 54.93192999703543, 56.26833609172276, 52.51833425249372, 50.05319677080427, 50.52631350925991, 49.981150899614605, 54.355219091687886, 54.90099661690848, 54.18270921707153, 50.439058031354634, 53.77938365936279, 52.976866722106934, 55.52244002478463, 53.079571519579204, 53.83949947357178, 49.13806690488543, 43.95165702274868, 46.772042001996724, 51.68136814662388, 50.941239084516255, 44.30067893436977, 42.16737004688808, 51.23754153932844, 51.48253154754639, 50.93857445035662, 50.18043565750122, 47.563601630074636, 53.48936932427542, 45.021366936819895, 46.919190951756065, 52.30540670667376, 51.48396635055542, 56.88390827178955, 53.55015216554914, 57.936970302036826, 60.108928544180735, 55.31851387023926, 54.32145432063511, 39.47663150514875, 34.30653599330357, 43.73359823226929, 52.50913831165859, 49.88424437386649, 53.36848109109061, 58.177958147866384, 54.12083550861904, 56.09256403786795, 46.513148648398264, 46.75475835800171, 48.209954329899375, 49.648005621773855, 50.76302126475743, 51.37856912612915, 50.750372069222585, 45.774714946746826, 43.64892748423985, 46.16358825138637, 44.770568234579905, 46.587685448782786, 49.10430213383266, 46.8298544883728, 44.72597469602312, 44.40343584333147, 47.87025342668806, 50.62583255767822, 57.63402884347098, 57.94466543197632, 57.830037525721956, 53.777396474565776, 53.16567012241909, 52.04571778433663, 52.69678136280605, 50.68085881641933, 45.193136828286306, 46.72311626161848, 52.88789503914969, 58.57849052974156, 55.3544464792524, 57.383525439671104, 57.424860273088726, 55.78142370496477, 58.8830509185791, 60.58385181427002, 57.5204952784947, 40.95304727554321, 23.840047563825333, 57.013252462659565, 57.17603138514927, 57.452823298318044, 55.14241872514997, 55.27834286008562, 48.0541409764971, 46.488614559173584, 44.714228766305105, 47.54012714113508, 52.37502418245588, 63.946015630449565, 58.39739268166678, 64.99354689461845, 59.51165444510323, 70.71331787109375, 32.41056367329189, 4.143460954938616, 1.5359739916665214, 0.49853493166821344, 3.933519397463117, 6.688452780246735, 70.14131437029157, 64.81538118634904, 64.00750023978097, 59.55804756709507, 73.19975852966309, 67.90121514456612, 25.97757053375244, 29.90676294054304, 57.25080442428589, 40.14363077708653, 76.99490628923688, 57.36319153649466, 73.69969531467983, 3.6980540667261397, 0.4549935023699488, 0.1649177870047944, 0.2304704716163022, 0.17123334668576717, 0.11346183025411197], [0.049730896816721985, 0.015707539461020912, 0.03062407672405243, 0.017890941318390623, 0.034448164382151196, 0.11767353782696383, 0.13658975064754486, 0.13308418089790003, 0.08165071079773562, 0.8117972878473145, 56.6320812361581, 48.759959833962576, 43.07405437741961, 33.249520438058035, 34.29187529427664, 32.67174645832607, 11.201823234558105, 38.282316071646555, 65.6179120200021, 46.45474556514195, 53.17305605752127, 49.90477630070278, 50.91705240522112, 28.22489241191319, 0.09022529676024403, 0.047035596266921074, 0.07010378182998725, 0.6325981436031205, 0.242300132555621, 2.1005889517920355, 36.269641808101106, 52.68683501652309, 57.79394858224051, 53.42256586892264, 51.473207065037315, 42.27058901105608, 45.50889423915318, 46.53884308678763, 53.794530732291086, 51.113342489515034, 53.066828523363384, 50.03641339710781, 51.86601652417864, 48.12172610419137, 60.371438435145784, 48.01436601366316, 39.508009569985525, 51.40322133472988, 54.99155943734305, 54.33601427078247, 54.426375593457905, 56.65105676651001, 50.58107921055385, 49.26351315634591, 46.26898200171334, 45.24419913973127, 49.77908338819231, 51.04023354394095, 50.79481622150966, 47.667748178754536, 46.89908981323242, 48.23695502962385, 46.593164103371755, 46.77477264404297, 49.00559255055019, 45.97601120812552, 44.18047162464687, 39.4935017313276, 38.13226277487618, 40.00383996963501, 39.475158487047466, 39.442512375967844, 36.44189807346889, 41.03463997159685, 40.0001574243818, 43.06748138155256, 41.22738300051008, 28.86405372619629, 37.45491763523647, 41.09528037479946, 42.241274561200825, 43.27162640435355, 40.452290603092735, 48.173583984375, 49.0828287260873, 50.124485288347515, 51.60814108167376, 51.72337000710623, 45.56604317256382, 36.98221778869629, 45.48936980111258, 53.67110640662057, 55.772224290030344, 56.577065399714876, 55.14258895601545, 51.74185916355678, 51.02803945541382, 43.59751081466675, 42.046718052455354, 45.984265668051584, 46.43052067075457, 44.47999109540667, 41.42469446999686, 44.48302745819092, 42.63750600814819, 40.49887480054583, 38.39827108383179, 39.728958811078755, 39.59505312783377, 40.07058783939907, 39.40717731203352, 38.27922412327358, 39.880860328674316, 43.237375259399414, 46.567156996045796, 45.64431810379028, 49.30142600195748, 43.8482608795166, 48.41196278163365, 47.77889503751482, 48.58849913733346, 48.762273584093364, 46.528994015284944, 41.07359504699707, 44.46746349334717, 49.34231962476458, 52.59384380068098, 47.085628100803916, 54.68417460577828, 51.04133135931832, 52.98355783735003, 46.529271943228586, 72.53223814283098, 47.634834562029155, 45.55176115036011, 32.54592500414167, 27.708158356802805, 56.8306815964835, 52.592937060764854, 53.13587277276175, 50.39199440819876, 48.28478990282331, 42.38516133172171, 42.12585803440639, 42.959898948669434, 43.51173530306135, 48.00652149745396, 51.10386167253767, 57.419680391039165, 56.42715801511492, 62.81181253705706, 26.59733247756958, 0.5608479508331844, 0.015453870840636747, 0.44889488390513826, 0.175461936209883, 13.189550859587532, 62.32521629333496, 53.655893325805664, 53.03973054885864, 47.23645959581648, 67.71022306169782, 31.009577546800884, 12.368454439299446, 37.76720789500645, 37.74298300061907, 14.136569482939583, 31.284048761640275, 51.63412734440395, 40.86365870067051, 0.5793377043945449, 0.06132545894277947, 0.0717305423957961, 0.07495044890258994, 0.05120681565521019, 0.02615075827842312, 0.025335152400657535, 0.004285002501481878, 0.018189603595861366, 0.01782973576337099, 0.04553596262953111, 0.11232364882848092, 0.09372235089540482, 0.17933552978294237, 0.02413538713673396, 1.5775097800152642, 65.56007521493095, 57.050286361149375, 41.601203032902305, 40.32410676138741, 44.71165793282645, 31.034764766693115, 15.14488250868661, 39.87105989456177, 76.29894692557198, 52.09058230263846, 64.7669244493757, 53.48289360318865, 61.75938974108015, 32.66524294444493, 0.04897881878007736, 0.23701312339731626, 0.05316370725631714, 1.0386558089937483, 0.24101289734244347, 1.82906551020486, 41.35513257980347, 55.55470745904105, 60.383375440325054, 57.6103389603751, 55.03857789720808, 42.55904694965908, 46.79193469456264, 49.456356934138704, 57.93990591594151, 52.22815316064017, 55.18573726926531, 51.726521015167236, 53.415746212005615, 50.956184659685405, 57.727794783455984, 44.70529685701643, 41.39675228936331, 51.80696725845337, 56.42653267724173, 56.97328642436436, 56.4731377192906, 57.45582144601004, 50.9083845274789, 48.37516164779663, 48.620276723589214, 46.715438502175466, 49.379996231624055, 52.2253634589059, 50.12415177481515, 49.478629384722026, 49.78865800585066, 51.66519274030413, 50.17607913698469, 50.60413333347866, 52.31301498413086, 51.24616425377982, 47.240975924900596, 44.01223489216396, 42.836116790771484, 43.38012252535139, 44.00863919939314, 43.33023445946829, 38.81439869744437, 45.86014999662127, 45.29645654133388, 45.00561189651489, 44.7766409601484, 33.60274600982666, 41.60089383806501, 43.450837816510884, 45.53596094676426, 45.61937059674944, 44.448619978768484, 50.67391756602696, 52.93150888170515, 53.90300253459385, 52.90946919577462, 53.11815139225551, 45.08499506541661, 36.60600757598877, 45.481605189187185, 53.70692784445626, 55.751007965632844, 57.80412074497768, 55.66750104086739, 52.59277377809797, 55.20339959008353, 48.27681337084089, 45.585220200674875, 47.72325038909912, 50.18256875446865, 46.437781538282124, 46.49396467208862, 46.94216864449637, 47.62298093523298, 42.593190397535054, 42.52219023023333, 43.07722275597708, 43.35032170159476, 43.59182718821934, 41.75954900469099, 41.72072941916329, 43.69559506007603, 44.45737470899309, 48.35529327392578, 49.92454045159476, 52.06983845574515, 49.077839919498985, 51.99037190846035, 49.71297475269863, 50.84280742917742, 50.02470915658133, 49.384627205984934, 44.72403614861624, 47.139830998011995, 51.311432157244, 56.873965399605886, 49.45312254769461, 55.44407476697649, 52.482113293239046, 54.155996867588584, 46.88155950818743, 66.56766128540039, 47.918466976710725, 47.53862285614014, 43.61682333265032, 29.297082832881383, 57.29596076692854, 54.860075201307026, 55.136088916233604, 53.942760126931326, 49.688155787331716, 45.770691939762656, 44.20973743711199, 45.64157703944615, 45.55999823978969, 50.32691758019583, 53.138801438467844, 60.86617796761649, 57.47664519718715, 65.4561926977975, 28.1953729901995, 1.0308142240558351, 0.18752327614596911, 0.4205289174403463, 0.36525328350918634, 15.487876858030047, 67.38392175946916, 58.55126748766218, 60.73999868120466, 46.64801318304879, 73.89967836652482, 34.05306223460606, 18.325647967202322, 38.55092995507376, 48.79142475128174, 17.60597961289542, 34.76324108668736, 58.22067567280361, 48.88119895117623, 0.7150434053369931, 0.11874540602522236, 0.03182388948542731, 0.03533412077065025, 0.08403993437864951, 0.020976048362042223, 0.13698482087680272, 0.10070909706077405, 0.12412845503006663, 0.13212781293051584, 0.18315714757357324, 0.20606527690376553, 0.20718327191259178, 0.34764559833066805, 0.1956112100077527, 1.8735163935593195, 79.0876967566354, 63.41872378758022, 56.5127980368478, 42.40938622610909, 51.09089980806623, 43.031375067574636, 19.576283761433192, 50.07467712674822, 80.89338765825543, 57.72204862322126, 64.0173875263759, 58.25623655319214, 64.90542984008789, 34.974462849753245, 0.11825825859393392, 1.219499179295131, 0.29890485373990877, 1.926758268049785, 0.7262142630560058, 3.468831692423139, 43.92495162146432, 59.28582409449986, 63.33061368124825, 60.06108324868338, 56.60915218080793, 45.2311886378697, 49.63010358810425, 51.89608137948172, 59.05187824794224, 55.54923227855137, 57.641710077013286, 54.11793463570731, 57.202993869781494, 56.47547926221575, 62.82370785304478, 43.068374225071494, 44.31728512900216, 55.43601485661098, 58.040324756077354, 58.91532530103411, 58.415784563337056, 62.34134306226458, 53.72935315540859, 52.509853976113455, 52.301203046526226, 49.86309058325631, 52.87232412610735, 56.0876064981733, 54.427900723048616, 54.08739035470145, 54.22119181496756, 57.199933188302175, 53.127653053828645, 52.560044288635254, 55.65663753237043, 53.88377686909267, 51.89377110345023, 50.2895953314645, 45.322210039411274, 50.27847473961966, 48.865134716033936, 48.196860449654714, 44.31715658732823, 51.00033003943307, 49.97933394568307, 51.09642710004534, 51.986665044512065, 42.28891141074044, 47.653681550707134, 47.78778873171125, 52.841293471200125, 51.56011860711234, 47.86992686135428, 55.37195593970162, 54.77224997111729, 54.82399320602417, 57.75193282536098, 56.49518435341971, 46.292723996298655, 36.85691050120762, 47.06078134264265, 56.378412927900044, 57.83448089872088, 60.80069119589669, 58.25693484715053, 54.52849326814924, 59.425587109157014, 50.19555493763515, 50.011681284223286, 54.25981337683541, 52.7343989099775, 49.685591902051655, 48.61774410520281, 50.63375350407192, 51.21765579496111, 45.20268017905099, 46.62399673461914, 48.45966216496059, 46.22365542820522, 46.85686561039516, 46.82588359287807, 44.32964250019619, 47.12981864384243, 46.85735545839582, 52.96165016719273, 53.610736983163015, 56.52657284055437, 52.588403361184255, 55.68105697631836, 53.34714664731707, 54.01784930910383, 52.524003982543945, 52.19691058567592, 47.89525304521833, 48.120669978005544, 53.74408333642142, 58.01920223236084, 51.77236870356968, 59.1050945009504, 56.25548539842878, 58.52710860116141, 48.904055050441194, 66.67578220367432, 48.93364742824009, 46.60606690815517, 36.12988574164254, 30.749100003923687, 61.69782870156424, 57.303548199789866, 58.1292964390346, 57.214896133967805, 50.449775627681184, 47.66949912479946, 46.116701807294575, 47.72774239948818, 49.30416359220232, 52.604953970227925, 57.20902143205915, 62.869315828595845, 59.84043625422886, 66.63503796713692, 32.364896638052805, 1.8143623620271683, 0.4395250752568245, 0.7565644830465317, 1.5590065100363322, 16.16243577003479, 74.32769434792655, 61.865315028599326, 65.06173651559013, 57.70044319970267, 79.09203243255615, 42.81651244844709, 22.05759491239275, 49.25375093732561, 56.59238270350865, 21.008717434746877, 45.36248179844448, 65.91982514517647, 62.261883463178364, 1.230322084256581, 0.27441777342132156, 0.15192781761288643, 0.24264344413365635, 0.1854725940419095, 0.09351117044155087], [0.022135586677385227, 0.027939037320071032, 0.011378425822061087, 0.014374784726117338, 0.03123810002580285, 0.05774108413606882, 0.06781727488019637, 0.021838064338745813, 0.20989507782672132, 0.4865033658487456, 53.27581991468157, 54.38892132895333, 35.8853508404323, 23.702577454703196, 30.171565737043107, 39.08426325661795, 16.451253277914866, 13.937305569648743, 58.400297028677805, 48.446929591042654, 41.95676319939749, 54.98922831671578, 46.96711267743792, 32.939877441951204, 0.25847477891615456, 0.16497007491333143, 0.07857950524027858, 0.28209830128720825, 0.2576873797391142, 0.5773666415895734, 30.054957594190324, 57.8789632661002, 55.096268790108816, 56.04018504279, 46.06824854442051, 43.40415287017822, 49.72639867237636, 55.761524064200266, 53.995771408081055, 52.682085922786165, 50.276643889290945, 55.3884196962629, 54.05663415363857, 45.35902506964547, 20.659910917282104, 39.68450771059309, 50.2136549949646, 49.26238407407488, 54.430499349321636, 52.542236055646626, 54.20133038929531, 52.67910861968994, 50.435344219207764, 48.343050548008506, 42.513484137398855, 43.61450610842024, 46.786122526441304, 49.91155079432896, 47.722343649183, 48.38749817439488, 44.658618858882356, 43.43818514687674, 46.54316486631121, 43.50057997022356, 48.08292736325945, 47.08212273461478, 48.07380090441023, 44.517094475882395, 41.964500018528526, 42.25792939322335, 38.72820629392351, 39.388660362788606, 37.28506197248186, 40.0997633252825, 38.846322195870535, 36.56365483147757, 34.755003997257774, 27.70076894760132, 36.96745981488909, 42.0169415473938, 37.32691444669451, 41.06513908931187, 41.95454324994768, 41.48412936074393, 46.419987201690674, 45.60613080433437, 47.97180482319423, 49.7935460635594, 47.21050459997994, 41.63621153150286, 48.700017724718364, 52.23708854402815, 50.51702724184309, 51.811021532331196, 50.81764105388096, 49.40835183007376, 47.1223805972508, 44.19656712668282, 41.455502782549175, 33.96388905388968, 26.786622251783097, 32.31730842590332, 35.77177906036377, 37.58488021578108, 36.288961274283274, 36.880607332502095, 36.97232007980347, 36.020052092415945, 38.33305876595633, 40.275615283421104, 39.22545065198626, 40.728457178388325, 44.455814838409424, 47.95035226004464, 44.841012545994346, 44.105330330984934, 46.73291669573103, 43.14937285014561, 49.085566316332134, 45.32822370529175, 48.540306431906565, 48.7907646724156, 46.480314935956685, 41.04335648672921, 42.825802189963206, 48.8094344820295, 52.68027939115252, 48.96552923747471, 48.00517007282802, 52.083317961011616, 51.8431430544172, 50.618675913129536, 63.11924253191267, 44.68561608450753, 45.12359578268868, 50.67008563450405, 27.435307809284755, 39.19242238998413, 57.81799977166312, 50.22486591339111, 56.45473888942173, 51.02280746187483, 52.24805280140468, 42.14439582824707, 46.33069242749895, 42.24553728103638, 49.298017910548616, 47.88883638381958, 58.44297981262207, 52.863468647003174, 61.64140932900565, 23.099489450454712, 0.8616693403039659, 0.06343983512903963, 0.38371510856917923, 0.17264947641108716, 26.279799801962717, 63.01570742470877, 49.24580567223685, 45.75173377990723, 60.088605063302175, 52.362670285361155, 12.688229646001544, 33.21888583047049, 29.920909472874232, 39.28049775532314, 27.050434929983957, 45.58229848316738, 49.39027609143938, 33.46188170569283, 0.4785236311810357, 0.07070605629788977, 0.07968808896839619, 0.04419220205662506, 0.07343046939266579, 0.02503838832490146, 0.06026874243148735, 0.034135614189186265, 0.033437781634607484, 0.09757374958800417, 0.02988403589863862, 0.10177625622600317, 0.1175990482526166, 0.016480485842164074, 0.029892046004533768, 0.5013111712677139, 57.73482288633074, 65.29019328526088, 38.62427166530064, 26.444048268454416, 44.787393297467915, 37.54379899161202, 21.007504974092754, 18.36423305102757, 66.43934890202114, 52.3964524269104, 47.8524660382952, 62.20576981135777, 52.03436442783901, 38.27343627384731, 0.7541794053145817, 0.23803841695189476, 0.1886917541601828, 0.40843457356095314, 0.7368266050304685, 0.9139549689633506, 31.8191225869315, 61.415314946855815, 56.97855315889631, 57.03164087023054, 47.92705842426845, 46.531592641557964, 50.78408472878592, 59.63219179425921, 55.79060227530343, 54.38490874426705, 53.41834831237793, 57.96653141294207, 53.902825355529785, 46.588842323848176, 24.88416726248605, 39.566978931427, 50.26239660808018, 50.73899786812918, 57.64530576978411, 54.364401136125835, 57.02784020560128, 54.50288568224226, 52.120911189488, 49.66628285816738, 45.237820693424766, 44.448328154427664, 49.07825333731515, 51.32683283942086, 48.384572982788086, 50.626252923692974, 47.70728342873709, 47.65617595400129, 48.76108544213431, 47.665945121220176, 50.129279545375276, 53.367716789245605, 51.37405974524361, 46.574633257729666, 43.89141614096505, 46.480724879673545, 42.61288159234183, 42.74523435320173, 40.296824659620015, 43.569037096840994, 44.30354159218924, 42.738428592681885, 40.20092909676688, 31.786695344107493, 39.55654968534197, 45.510864053453716, 42.29608889988491, 46.30743680681501, 43.15235015324184, 46.1056124823434, 48.50499568666731, 49.28569180624825, 50.32754986626761, 51.46601220539638, 49.15593419756208, 42.007359981536865, 48.98331315176827, 53.500906808035715, 53.22946848188128, 54.49180677958897, 54.79257345199585, 53.37392153058733, 49.74720157895769, 47.64068147114345, 45.218945911952424, 40.34523623330252, 35.080631324223106, 36.76128591809954, 38.68185486112322, 42.76043006352016, 41.32716955457415, 39.98735884257725, 39.81491150174822, 39.54459878376552, 41.57396262032645, 42.53105960573469, 42.917195320129395, 43.848281724112375, 46.460703645433696, 52.76974439620972, 47.800250325884136, 46.831699235098704, 48.45878669193813, 46.548376015254426, 50.259596484048025, 48.57667677743094, 50.96806607927595, 50.02778026035854, 48.51031453268868, 42.840626171657014, 44.978823116847444, 51.1398846081325, 57.12565347126552, 52.29794086728777, 50.955986636025564, 52.88162776402065, 53.79103231430054, 49.80035877227783, 57.300477096012656, 47.18687725067139, 44.16034616742815, 59.00642313276018, 37.300810064588276, 38.15590054648263, 59.87966578347342, 50.87998029163906, 57.26099395751953, 53.02597311564854, 54.8657796723502, 43.892837047576904, 47.85210820606777, 44.369823932647705, 51.52984183175223, 49.42243930271694, 60.53775746481759, 54.729584557669504, 65.27668598720005, 24.332634891782487, 1.4153844224555152, 0.17497822216578893, 0.4938122736556189, 0.969046909894262, 28.874338797160558, 68.5482313973563, 53.954488686152864, 46.576450211661204, 65.75647299630302, 54.22489520481655, 15.554576090403966, 39.675575801304404, 34.75102962766375, 46.66771480015346, 18.35539494241987, 49.96002490179879, 58.472002438136506, 39.26304735456194, 0.37866170544709477, 0.09236951491662435, 0.09961312729865313, 0.0576832593817796, 0.0692450821931873, 0.04607144889554807, 0.15051574552697794, 0.2548275174839156, 0.1473585899387087, 0.14058239997497626, 0.0995069637096354, 0.233274124030556, 0.31901912870151655, 0.10952052567154169, 0.2713508222784315, 0.7674996448414666, 70.33364745548793, 70.80241462162563, 51.42769636426653, 32.99914557593209, 46.208598681858604, 52.44156013216291, 24.358438764299663, 25.965463297707693, 69.89812741960797, 62.44391931806292, 51.23194129126412, 68.77970368521554, 57.585096154894146, 44.049112456185476, 0.6195570262415069, 0.38833861904484884, 0.3691040240228176, 1.1019737656627382, 1.6546705024583, 1.4342884080750602, 34.21176603862217, 65.5110695702689, 57.811284337724956, 60.41448252541678, 50.89088201522827, 48.11665391921997, 53.370999813079834, 61.912555830819265, 59.399725914001465, 56.380153451647075, 54.370171615055625, 60.009069034031455, 57.46017449242728, 49.19658810751778, 32.01290784563337, 43.668709005628315, 48.89515093394688, 51.920028345925466, 58.15270144598824, 55.49374049050467, 59.81462369646345, 55.889669690813335, 52.89595147541591, 53.397600991385325, 47.595636299678254, 47.875144958496094, 51.611191340855186, 53.122758047921316, 50.413599831717356, 54.36715609686715, 51.274658816201345, 50.885559695107595, 51.638622828892295, 50.224396909986226, 54.949891090393066, 54.7700960295541, 52.712710108075825, 51.674895899636404, 49.36319201333182, 51.75105163029262, 46.92571183613369, 49.0749112537929, 48.07765368052891, 52.50020292827061, 49.51209538323538, 47.94092008045742, 45.176714760916575, 37.56116601399013, 45.76595326832363, 52.726405007498606, 44.87146650041853, 49.6570382799421, 48.938726561410085, 49.682607650756836, 53.16095576967512, 51.58630984170096, 54.99907738821847, 55.00779390335083, 50.01265055792672, 43.95835856028965, 52.07366343906948, 56.41243825639997, 55.68712970188686, 54.491803305489675, 58.083605085100444, 56.56893253326416, 53.61639281681606, 50.30736187526158, 50.11808599744524, 46.319846289498464, 42.03916883468628, 43.74739735467093, 45.23051813670567, 48.758260999407085, 47.12810591288975, 44.0605457169669, 43.74237380708967, 41.34047188077654, 45.49925708770752, 48.01171180180141, 45.352111612047466, 48.48829916545323, 50.074750082833425, 55.598936217171804, 53.906511374882285, 50.32044185910906, 52.144868578229634, 47.41661943708147, 53.46106236321585, 50.409257207598, 53.33017914635794, 53.08217709405081, 51.50750684738159, 47.433187416621614, 47.3992280960083, 51.12682546888079, 60.13014139447893, 54.55922862461635, 53.300572872161865, 54.863632678985596, 58.55779184613909, 50.18528550011771, 61.831039564950125, 47.734221594674246, 46.93057210104806, 52.38730164936611, 33.09761544636318, 43.85949959073748, 61.26063414982387, 56.723401410239084, 60.94039167676653, 56.10437944957188, 57.572224617004395, 45.63749149867466, 49.87669168199812, 45.35752425874983, 55.17666987010411, 51.681458473205566, 62.582834652491975, 57.09792668478829, 64.70707266671317, 26.50614431926182, 2.2046093472412656, 0.2985650434025696, 0.8026726203305381, 1.3599638534443719, 29.948611940656388, 76.4674963269915, 58.851249013628276, 54.544276101248606, 67.97403226579938, 63.87580408368792, 21.53243269239153, 43.23962300164359, 41.17246791294643, 54.853401456560405, 35.94242681775774, 62.28693866729736, 65.23223836081368, 50.36424330302647, 0.588788448699883, 0.1758509674774749, 0.1497472503355571, 0.18863444509250776, 0.10725303805832352, 0.12443574996931211], [0.1173744938735451, 0.04693454543926886, 0.07450342324695416, 0.03525673724444849, 0.10289579150932175, 0.028217643798728074, 0.15397632840488637, 0.0580414105206728, 0.06392185283558709, 0.05789601403687682, 39.14022404806954, 60.17595781598772, 40.14471122196743, 48.595211097172324, 36.375063351222444, 32.640014035361155, 14.191761629922048, 23.917719738824026, 51.861475876399446, 57.603797231401714, 36.356876441410606, 51.56978007725307, 50.787194047655376, 37.46959917885916, 2.1308692012514387, 0.1306940820068121, 0.1979814413934946, 0.2613314113446644, 0.44052051327058245, 0.2465640737542084, 26.68023838315691, 59.919048173086985, 53.22302055358887, 53.89508853639875, 42.71129240308489, 47.58716644559588, 53.92035566057478, 55.61787005833217, 55.38098512377058, 53.71682555334908, 53.530335903167725, 53.93570423126221, 45.17133338110787, 44.56199026107788, 39.98544461386544, 37.23571239198957, 52.16563674381801, 51.44738408497402, 54.75377123696463, 51.39315339497158, 51.171627453395296, 51.25258091517857, 49.17168228966849, 46.38808454786028, 44.31258814675467, 40.334153856549946, 43.10700273513794, 49.15931102207729, 46.93970203399658, 47.412780557359966, 47.68956552233015, 48.10238926751273, 46.21687398638044, 45.65550817762102, 45.735377720424104, 50.11237110410418, 46.64891297476632, 46.289354119982036, 44.27595724378313, 43.7498778615679, 40.543676785060335, 38.915043354034424, 38.71163831438337, 39.1848349571228, 39.11377573013306, 39.16227763039725, 36.006461415972026, 39.562994139535085, 36.567379065922324, 37.321783202035085, 41.19795043127877, 38.956016881125315, 39.44519785472325, 43.45019163404192, 47.43728337969099, 49.049842153276714, 50.293451581682476, 49.660731247493196, 52.311885901859824, 48.528730733054026, 48.448312282562256, 52.068292481558665, 49.99718386786324, 47.17774731772286, 46.38805675506592, 43.45009435926165, 45.437272208077566, 42.606635161808555, 41.741435050964355, 34.96074710573469, 27.28849584715707, 38.96996538979666, 41.110034874507356, 36.064742905753, 34.227006912231445, 35.78978879111153, 34.39594193867275, 36.35056747709002, 39.211599418095176, 39.06323800768171, 41.9342371395656, 43.323890754154746, 46.83132403237479, 46.762978076934814, 45.31518888473511, 46.12102358681815, 48.246595655168804, 48.69272211619786, 48.419268812452046, 45.267798696245464, 47.113601548331125, 46.92241839000157, 41.962460722242085, 41.57562323978969, 42.753631251198904, 47.70702287128994, 50.58625909260341, 52.67610352379935, 53.91072545732771, 51.188539368765696, 49.997892584119526, 50.58345896857125, 39.887763363974436, 41.009216512952534, 49.30363205501011, 50.64292860031128, 53.30572843551636, 27.723308903830393, 53.281878743852886, 54.18206998280117, 55.754860741751536, 50.16189438956124, 53.736165864127024, 49.143896443503245, 48.53528635842459, 43.03252846854073, 49.04821974890572, 47.392543928963796, 60.37740693773542, 54.354479108537944, 57.321418966565815, 17.67985459736415, 0.3345738926104137, 0.2810433693230152, 0.5548760827098573, 0.5140295773744583, 37.673612185886924, 56.28883327756609, 51.3553204536438, 56.8392904145377, 63.88878331865583, 25.115755932671682, 25.4588406085968, 63.37726388658796, 29.525511809757777, 38.45740025384085, 34.12519148417881, 40.847917556762695, 52.840386731284006, 17.568596567426408, 0.95966152208192, 0.3340504435556275, 0.1607162438865219, 0.17131790571979114, 0.1665069024477686, 0.03524520554180656, 0.06191577083830323, 0.07842534886939184, 0.05636460121188845, 0.09661604490663324, 0.00654143508290872, 0.01892263854720763, 0.15136396858308995, 0.07598914352378675, 0.0955647634608405, 0.04395001594509397, 42.49919169289725, 70.31460244315011, 43.92425332750593, 40.45204741614205, 42.394812379564556, 38.782454354422434, 17.97845343181065, 29.741711957114084, 57.907669748578755, 62.528965268816265, 37.39750814437866, 57.854390961783274, 55.290325028555735, 41.514628478458945, 2.7454744960580553, 0.2878277152776718, 0.16091966868511268, 0.3847676249487059, 1.1039510709898812, 0.2931078305201871, 27.58630953516279, 64.64496966770717, 55.941155842372346, 58.43968636648995, 45.310780252729145, 50.9012383052281, 56.37346233640398, 58.63535458700997, 57.201211656842915, 55.59105001177107, 55.335300718035015, 53.17140933445522, 46.79348414284842, 46.67525359562465, 41.8814377784729, 40.404931681496755, 54.359429700034006, 52.617849826812744, 58.72950267791748, 54.793872765132356, 53.162494795663015, 54.4290645463126, 50.921798024858745, 48.41323430197579, 46.06454515457153, 44.24662889753069, 45.37615237917219, 49.99258763449532, 49.49500628880092, 50.169127464294434, 49.745763301849365, 52.11811106545584, 47.52118635177612, 48.411764757973806, 46.99543006079537, 53.595471790858674, 49.44054283414568, 49.72166000093733, 47.281775747026714, 47.04869842529297, 45.2799962588719, 43.77088226590838, 42.50259978430611, 42.890354428972515, 44.19784559522356, 44.10577501569475, 39.918057509831016, 45.10234471729824, 39.74025310788836, 42.3699517250061, 43.69504267828805, 43.68881014415196, 43.8850029536656, 45.82175077710833, 49.8781647000994, 50.510763440813335, 49.743532930101665, 52.09721783229283, 53.48843479156494, 50.807910101754324, 50.61538594109671, 51.634043966020855, 52.334696837833945, 51.09073999949864, 52.001989296504426, 46.2611757005964, 48.718704904828755, 45.624203068869456, 45.27034173692976, 37.32388155800955, 30.097640378134592, 41.05118015834263, 43.46049928665161, 40.28888981682913, 38.33060952595302, 40.578640120370046, 38.57915701184954, 39.568542276109966, 41.65886613300869, 41.89836359024048, 46.012350286756245, 47.272131647382466, 51.283389227730886, 49.98727226257324, 48.498888220105854, 48.97050067356655, 49.548034940447124, 51.79511363165719, 51.44704362324306, 48.455350807734895, 49.44328737258911, 47.24871621813093, 46.22908544540405, 42.86341278893607, 47.331858362470356, 49.15673671449934, 53.29012972967965, 54.52830566678728, 55.62523167473929, 51.94276979991368, 53.683376925332205, 49.25977849960327, 38.86698266438076, 43.32343564714704, 50.01388038907732, 52.96977955954415, 64.39998313358852, 32.1623740196228, 50.0284229687282, 56.143890380859375, 59.6504099709647, 54.33634083611624, 55.550993646894185, 53.917180333818706, 48.932577405657085, 44.823829650878906, 50.6216219493321, 50.28977945872715, 61.7627318246024, 59.323990549360005, 59.63760444096157, 19.269480841500418, 0.4246182580079351, 0.15545615899775708, 0.28100740696702686, 0.4321260308580739, 41.26745326178414, 61.60769666944231, 57.87675026484898, 58.61771311078753, 70.22970935276577, 28.807180983679636, 27.37619079862322, 62.610196658543174, 33.20596218109131, 48.78174591064453, 29.57619891847883, 45.23893240519932, 62.41828046526228, 21.102618864604406, 0.5994755380920002, 0.2920560198170798, 0.15795098298362323, 0.13673784770071507, 0.09300212668521063, 0.07599594923002378, 0.16753367520868778, 0.14663228605474743, 0.12134473797466074, 0.27868160605430603, 0.1265066388462271, 0.10875342147690908, 0.24481559757675442, 0.2019268511129277, 0.21024972093956812, 0.17159564367362432, 52.56762477329799, 78.26085417611259, 54.39898232051304, 64.73953465053013, 53.19917433602469, 47.51395327704293, 20.005979469844274, 34.13849033628191, 62.10524327414376, 70.04442868913922, 45.40055792672293, 62.80824811117989, 62.613705498831614, 51.66037763868059, 3.0784241386822293, 0.29618810809084345, 0.47087925566094263, 0.796500882932118, 2.0431332119873593, 0.6353407821484974, 29.749466146741593, 67.36600930350167, 59.46913841792515, 60.21621567862374, 46.33198479243687, 52.47650957107544, 58.291272844587056, 60.863627978733604, 59.508666719709126, 58.30912276676723, 57.264488901410786, 55.3196325302124, 48.0859637260437, 47.31279945373535, 41.10084588187081, 42.498125144413535, 55.631815092904226, 53.677675928388325, 60.178077016557964, 57.23434066772461, 54.118216037750244, 57.052808557237896, 50.924268109457834, 51.70108713422503, 48.55925069536482, 45.25399957384382, 46.49237353461129, 52.72627993992397, 51.208268778664724, 52.30666085651943, 54.11991139820644, 56.939591135297505, 51.6762056350708, 53.579258169446675, 50.28183419363839, 57.46062612533569, 51.43682977131435, 54.53379126957485, 51.44917672021048, 52.660004547664094, 49.61132608141218, 49.34091261454991, 48.44403566632952, 49.77834340504238, 49.5446720123291, 49.34990010942732, 44.005060877118794, 49.42257826668875, 46.10039438520159, 47.15181316648211, 49.93092237200056, 47.401899678366526, 47.709541593279155, 52.9555218560355, 55.53201811654227, 54.64845391682216, 53.48695829936436, 55.519813605717246, 57.120501382010325, 51.670970167432515, 52.85550948551723, 55.98799017497471, 55.774770804813926, 52.70459113802229, 53.8833669253758, 50.53633975982666, 54.220260756356375, 51.344033105032786, 50.48856047221592, 45.046877247946604, 37.3425235748291, 48.48531491415841, 48.47084181649344, 44.19595915930611, 41.850698947906494, 45.214804785592214, 41.06029272079468, 43.054439612797324, 44.629651818956646, 45.541536876133506, 51.020052501133506, 49.23550149372646, 55.00705739430019, 52.09038427897862, 52.14324269975935, 53.50153909410749, 52.323284421648296, 55.07256153651646, 55.1574615750994, 50.674188545772004, 50.955962317330496, 50.956570284707205, 48.10639142990112, 45.37351553780692, 49.448700019291465, 50.98591947555542, 54.98316601344517, 57.33174398967198, 58.21649980545044, 54.69536815370832, 53.650327818734304, 50.20154775891985, 49.67716373716082, 45.55386298043387, 51.24652208600725, 54.607122557503835, 54.11520051956177, 35.41123703547886, 56.1056718145098, 55.49358068193708, 62.04310553414481, 56.56932858058384, 58.7803634916033, 55.69680854252407, 51.15802982875279, 46.92836257389614, 53.897388390132356, 50.702255793980186, 64.00972366333008, 60.15067332131522, 62.3471656526838, 20.827400718416484, 1.5195270627737045, 0.2576124151902539, 0.8744904494711331, 1.6124087359224046, 44.24862650462559, 66.44702666146415, 62.959482601710725, 66.36107744489397, 75.43943391527448, 35.24372638974871, 35.31395878110613, 72.22113255092076, 43.757288115365164, 55.34701885495867, 51.64792994090489, 54.704147202628, 70.52836377280099, 31.518995148794993, 1.0082218306405204, 0.3553968295454979, 0.3246159298079354, 0.3694719799927303, 0.2742427113865103, 0.17225393120731625], [0.10474112177533762, 0.03385319095104933, 0.05799414377127375, 0.018969272562701787, 0.15543730929493904, 0.06425613989787442, 0.20804864833397524, 0.0345921936178846, 0.06862817172493253, 0.2430163398385048, 21.279469626290457, 68.49408408573696, 37.57724414552961, 38.09314094270979, 37.94861841201782, 41.275818892887656, 9.997011678559439, 22.09279101235526, 62.07121794564383, 55.28762565340315, 49.21261065346854, 46.22000067574637, 49.80160597392491, 42.834772314344136, 4.624025293758937, 0.43447107502392357, 0.2032962026340621, 0.23231120141489164, 0.5507629119924137, 0.2421645884002958, 24.890549182891846, 62.39411463056292, 55.673264571598594, 53.34971400669643, 43.65829365594046, 50.41975940976824, 55.09330538340977, 55.58347994940621, 54.3360663822719, 48.23526661736624, 50.19118104662214, 47.5022212437221, 49.10537910461426, 43.900872639247346, 45.62025301797049, 54.84188134329659, 51.69771030970982, 48.92667143685477, 49.95820099966866, 51.07377249853951, 51.44225631441389, 48.00843225206648, 48.33349677494594, 46.447095598493306, 45.804168360573904, 42.88121059962681, 46.593233585357666, 48.8387246131897, 48.09274516786848, 46.69549717221941, 47.63075944355556, 46.96593148367745, 48.29671648570469, 48.83315215791975, 46.72891105924334, 48.902648040226524, 48.56700488499233, 47.204661164964946, 46.70935882840838, 46.04291541235787, 43.50770534787859, 43.00149086543492, 40.14475291115897, 38.95855297361101, 39.747927393232075, 36.93669319152832, 39.2516245160784, 38.5662750516619, 37.874307428087505, 35.54798105784825, 38.3900374685015, 36.13753570829119, 42.09951393944876, 46.67965875353132, 51.04144600459507, 50.389527797698975, 50.95036901746477, 51.218937737601145, 48.131175654275076, 42.61779396874564, 47.37769562857491, 52.44753558295113, 50.316526549203054, 50.6202392578125, 45.73310218538557, 45.119715213775635, 42.459468841552734, 43.00632333755493, 42.536812714168, 39.731814520699636, 37.07390969140189, 40.347716740199495, 37.44378662109375, 37.91338757106236, 37.26045145307268, 36.112914766584126, 36.040941851479666, 36.30804797581264, 37.65193728038243, 41.257048334394185, 45.62787519182478, 44.834606306893484, 47.77950995309012, 46.45398473739624, 45.75861249651228, 44.71317958831787, 45.250212805611746, 44.49830307279314, 49.263117109026226, 46.28753021785191, 46.73864548546927, 46.75559909003121, 42.63676602499825, 39.467918464115684, 45.71841369356428, 44.1337936265128, 51.33517067773001, 49.128426279340474, 54.45820876530239, 49.879373686654226, 55.666920866285054, 45.031681537628174, 26.37574052810669, 42.93694904872349, 54.263325691223145, 51.802794865199495, 61.674559184483115, 45.178781849997385, 32.46206372124808, 46.93139893668038, 55.174557617732454, 55.86636543273926, 55.34028605052403, 52.197469915662495, 51.287426131112234, 47.17086165291922, 47.711323806217735, 49.830527850559776, 57.77657808576311, 55.334279332842144, 54.182007449013845, 12.453457832336426, 0.1088717986962625, 0.03676500863262585, 0.3715948989348752, 2.618574334042413, 50.67658914838518, 52.99827759606497, 60.51477977207729, 46.06061247416905, 66.41006919315883, 28.047265189034597, 20.69806694984436, 73.68950925554547, 38.78643567221505, 28.880406311580114, 17.69124095780509, 46.789252689906526, 51.05179534639631, 7.71805030958993, 0.728710729096617, 0.2784593179821968, 0.17296800789024147, 0.10430966849837985, 0.11918696947395802, 0.09314746888620512, 0.05562602602211492, 0.05857213347085884, 0.09311185258307628, 0.08398970243121896, 0.023099618697805063, 0.05633216045264687, 0.18179748553250516, 0.012415237508581152, 0.13694362023047038, 0.1439003547919648, 22.608194487435476, 77.96828637804303, 38.663188525608604, 34.80297436032976, 44.11222641808646, 40.557076386043, 11.786684376852852, 28.204230206353323, 66.48365756443569, 62.821894373212544, 49.7170672416687, 51.871036597660606, 54.9346467426845, 49.0068918636867, 4.253558201449258, 0.5450672890458788, 0.1729332126144852, 0.29493887083871023, 1.0010192628417696, 0.18912768576826366, 28.033825635910034, 64.29696219308036, 56.1431052344186, 57.11459541320801, 45.29816232408796, 53.50603110449654, 56.39476898738316, 57.750880173274446, 55.07570559637887, 50.5525255884443, 51.1968355178833, 49.422196115766255, 47.738387039729524, 45.699257510049, 45.72270768029349, 58.147980145045686, 54.3671213558742, 50.48885577065604, 50.6504465511867, 53.81046642575945, 52.24966130937849, 51.869289125714985, 51.8213152885437, 49.414254324776785, 46.8958033152989, 44.579124518803184, 46.81203235898699, 51.66284424918038, 48.99000079291207, 49.05244425364903, 50.84309230531965, 51.55792645045689, 50.56102670942034, 52.034058707101, 50.29759965624128, 50.38707855769566, 52.23493807656424, 49.07149968828474, 51.29730994360787, 48.95675713675362, 47.42357110977173, 46.14477947780064, 45.02454226357596, 42.37772328513009, 42.74188184738159, 44.01026855196272, 43.24095358167376, 41.14848620550973, 41.72369977406093, 39.079799039023264, 41.70474508830479, 39.75039747783116, 47.17128896713257, 48.389683382851736, 51.9598901612418, 52.83020414624895, 52.875878129686626, 52.440875734601704, 51.02747317722866, 42.76675639833723, 50.166452407836914, 54.272271496909006, 52.67220211029053, 51.142969608306885, 48.54559053693499, 45.19168812888009, 46.856473037174766, 45.3766040120806, 47.429108824048726, 42.897910594940186, 42.35984557015555, 44.283565521240234, 40.171173436301096, 39.975383622305735, 40.00519139426095, 39.658674308231895, 40.38463946751186, 39.351855754852295, 41.029599053519114, 44.347673075539724, 48.633252484457834, 47.49257714407784, 50.31051983152117, 49.683021068573, 47.836676256997244, 47.09072807856968, 47.47906289781843, 46.34626334054129, 51.01573419570923, 47.24282761982509, 48.933744703020366, 47.53751114436558, 47.5545585496085, 42.18808610098702, 45.9335229737418, 47.13136114392962, 54.5377447945731, 51.85403782980782, 55.05296761648995, 52.12433317729405, 56.37304197038923, 45.48223052706037, 28.546244859695435, 43.53482069287981, 55.765689509255544, 53.873528276171, 64.14198957170758, 56.87706082207816, 36.12939589364188, 45.32672636849539, 55.752553939819336, 58.896662439618794, 57.819319929395405, 54.5647211756025, 54.902539116995676, 47.605791091918945, 49.01658460072109, 51.886840275355745, 60.69247300284249, 57.663308552333284, 57.54103067943028, 15.896446568625313, 0.496076192174639, 0.051450684533587525, 0.3150443248450756, 2.4605238778250555, 56.92671959740775, 57.17292206627982, 66.37540463038853, 50.24469607216971, 73.9115389415196, 30.897864409855433, 25.746681894574845, 72.78089332580566, 38.64870500564575, 39.165077754429404, 19.46365519932338, 54.63265371322632, 60.34529931204659, 9.131546667643956, 0.6968028641172818, 0.3726087116769382, 0.1761870730136122, 0.13845847680100373, 0.1387521331863744, 0.07386545105172054, 0.17013113440147468, 0.28432552463241983, 0.20200922526419163, 0.18934016222400324, 0.15561296844056674, 0.13163115243826592, 0.5517453221338136, 0.17176750302314758, 0.3268803640135697, 0.2828336975404194, 28.788519859313965, 90.7328359058925, 48.432550294058665, 53.75738218852452, 50.64593022210257, 59.188167163303916, 15.036250897816249, 32.70362131936209, 71.40398270743233, 69.32403251102993, 57.69935580662319, 59.55370494297573, 59.1482150214059, 55.81732504708426, 6.464031611170087, 3.5162820262568335, 0.9469842080559049, 0.6214050842182977, 1.7364133447408676, 0.37772006168961525, 29.14201119967869, 67.1861412865775, 59.299164635794504, 58.68324851989746, 47.122321537562776, 55.99933658327375, 58.31858621324812, 59.39826679229736, 57.48265886306763, 51.74363442829677, 52.04741314479283, 50.63597692762102, 47.9397006716047, 47.34657464708601, 49.23136036736624, 58.774193491254536, 55.61003943852016, 53.876522949763704, 52.117186955043245, 56.07655886241368, 55.516204016549246, 54.2253155708313, 54.09479366030012, 52.436185700552805, 49.596627167293, 46.79390450886318, 50.53230633054461, 54.25096832002912, 50.408941064562114, 50.93106344767979, 52.87223727362496, 54.17985003335135, 54.13193525586809, 56.925201416015625, 53.287819453648154, 55.37776810782296, 56.1112060546875, 53.0994051524571, 56.46067265101841, 54.5872437613351, 50.84092794145857, 53.407429218292236, 48.93438046319144, 48.005239554813926, 48.07854304994856, 47.24732310431344, 47.16008847100394, 45.53186845779419, 45.93958527701241, 43.005614621298655, 47.84454509190151, 43.82954938071114, 49.023817675454275, 52.11124971934727, 57.3049065726144, 56.032052176339285, 56.63858822413853, 55.57541309084211, 53.33396244049072, 45.4894358089992, 53.163248675210134, 56.5332396371024, 54.198109899248394, 54.443172863551546, 53.76365988595145, 50.85638768332345, 53.209356921059744, 49.20982442583357, 52.392846311841694, 46.66535241263253, 46.5283374105181, 50.2267176083156, 44.649144990103586, 44.61876399176461, 45.64736836297171, 44.29912601198469, 42.28779969896589, 44.19531297683716, 45.38693945748465, 48.88435343333653, 50.84894963673183, 51.353955132620676, 53.029398577553884, 53.89868770326887, 51.73660632542202, 52.54003347669329, 51.081057684762136, 50.21556922367641, 54.16033601760864, 50.971029485974995, 52.44165393284389, 49.614873136792866, 49.01316956111363, 43.09149782998221, 48.435652664729524, 48.03460611615862, 57.26182426725115, 53.27414192472185, 57.43903807231358, 53.82686764853341, 58.26449448721749, 51.04975952420916, 36.1623511995588, 45.169975008283345, 58.54684148515974, 57.42422798701695, 61.096851212637766, 49.32913194383894, 40.18767540795462, 50.269303117479595, 57.29284449986049, 60.082462855747764, 59.94181741986956, 56.31272118432181, 57.87647928510393, 50.121435029166086, 51.234407901763916, 52.79830844061715, 63.093040875026155, 58.34545489719936, 61.75645760127476, 19.51195386477879, 0.8348381114857537, 0.18870494488094533, 1.081954919866153, 4.130182513168879, 61.379837444850374, 61.87076241629464, 70.82352324894497, 55.58504676818848, 79.75095789773124, 35.17369202205113, 31.581601892198833, 77.4285364151001, 52.802654538835796, 40.95488159997122, 28.63411177907671, 63.018104553222656, 70.00175980159214, 14.707380499158587, 0.7565067804285458, 0.4711465984582901, 0.30347779978598866, 0.2485795398908002, 0.1986261039440121, 0.25545266536729677], [0.008615660231693514, 0.032602301466145685, 0.036925119148301225, 0.08808616761650358, 0.04000089803178396, 0.027616873982229402, 0.033438639981406074, 0.015730134677141905, 0.17454290123922483, 0.39918630410517963, 7.310406446456909, 58.79825510297503, 39.65975475311279, 36.20084421975272, 31.495232309613908, 40.64905316489083, 25.582589762551443, 5.364527387278421, 45.93434286117554, 59.972410338265554, 52.21791499001639, 49.222897461482454, 44.817155906132285, 50.8822523525783, 10.80699358667646, 0.6161010031189237, 0.16755757321204456, 0.4230749436787197, 0.23907049585665974, 0.3763044205095087, 18.98543327195304, 66.40081419263566, 56.5918859073094, 54.99530104228428, 45.312906401497976, 51.02338763645717, 56.23077065604073, 56.37383753912789, 53.81168930871146, 51.065973145621165, 45.86286326817104, 31.833790234157018, 48.376731940678184, 29.99158307484218, 21.460176638194493, 61.09291158403669, 50.54010568346296, 55.016989844185964, 50.77745962142944, 51.03171852656773, 47.63014105388096, 49.21462215696062, 49.19697025844029, 46.09373453685215, 43.65006004061018, 42.30258893966675, 43.67269032342093, 48.13374648775373, 47.858434540884836, 48.47446182795933, 46.22267573220389, 48.3051689692906, 45.98598882130214, 46.64017908913748, 47.26514523369925, 46.58991582053048, 46.70008298328945, 49.56618710926601, 47.353123324257986, 45.315161091940745, 47.06969935553414, 43.75832339695522, 43.32365798950195, 42.52593183517456, 41.222095421382356, 40.374206747327534, 41.21396255493164, 37.54913520812988, 36.42141478402274, 41.305720465523855, 40.84401961735317, 43.98257998057774, 46.650830677577424, 51.90307126726423, 56.29656662259783, 52.257425921303884, 49.1621458871024, 46.706940855298726, 45.7763477734157, 41.13072313581194, 50.96261174338204, 50.85680457523891, 53.892542021615164, 52.10327666146414, 53.78661673409598, 47.355645520346506, 42.632336548396516, 40.871121065957205, 39.41941656385149, 36.83393628256661, 39.16548422404698, 38.245494093213765, 38.894917896815706, 39.49001720973423, 37.11536264419556, 38.256684167044504, 36.86910458973476, 41.05358076095581, 42.96271991729736, 43.851700237819124, 47.37502752031599, 47.996828760419575, 46.8839670589992, 47.53087561471121, 46.12457064219883, 46.69536863054548, 45.11665105819702, 44.30582407542637, 46.52611746106829, 45.796167509896414, 45.69556106839861, 47.015826497759136, 42.096130166734966, 41.43284470694405, 44.41567162105015, 44.02092708860125, 47.489964621407644, 46.886391980307444, 48.71839223589216, 49.07022469384329, 53.358326298849924, 43.18011515481131, 31.23959071295602, 48.73751367841448, 50.492618220193044, 54.16066605704171, 55.15741293770926, 71.02051857539585, 56.096871920994346, 36.08632748467581, 40.87671783992222, 41.63691329956055, 52.146841866629465, 55.782281807490754, 55.10470042909895, 49.14388949530465, 50.42213569368635, 51.631601674216135, 57.40103490012032, 58.41964776175362, 47.198324407849995, 8.110132813453674, 2.027529512132917, 0.026631430789296116, 0.15256502984889916, 3.171833549227033, 62.13310555049351, 47.47509547642299, 60.77909619467599, 46.94769593647548, 71.47099113464355, 10.96329939365387, 35.10865340914045, 30.471477781023296, 25.623629297528947, 34.23896128790719, 28.03981672014509, 52.89691032682146, 49.534975801195415, 2.029247671365738, 0.28070662596396034, 0.09375411990497794, 0.16714882371681078, 0.05075034139943974, 0.09198629190879208, 0.05575016739645174, 0.050848447385111024, 0.013753755550299371, 0.13740762961762293, 0.054181519962315045, 0.06437414392296757, 0.05475719246481146, 0.02755828757238175, 0.06487370175974709, 0.2455301492341927, 0.38225484692624634, 9.11834248474666, 68.01048251560756, 48.122222900390625, 34.81151369639805, 40.30838646207537, 45.959714208330425, 19.557275227137975, 10.722192559923444, 50.81157527651106, 66.08269786834717, 53.510759353637695, 53.899660451071604, 49.563206332070486, 57.70082187652588, 11.924707736287798, 0.8312746626990182, 0.10473481818501439, 0.3323150495333331, 0.6736932098865509, 0.4471197820135525, 19.90984419413975, 69.87009838649205, 59.21564728873116, 57.86704363141741, 47.025175298963276, 54.03471606118338, 58.013032232012065, 59.13827214922224, 55.802073751177105, 52.03814772197178, 44.72641243253435, 30.744799068995885, 48.89104454857962, 30.147855009351456, 24.736002138682775, 62.99027006966727, 52.69423484802246, 58.1827107157026, 52.59060594013759, 54.116406032017295, 49.13505138669695, 50.9202937398638, 50.756931168692454, 49.27323021207537, 47.31662791115897, 44.559155396052766, 44.03415993281773, 47.94639873504639, 50.00909308024815, 50.48151847294399, 47.388562611171174, 51.13101870673043, 47.58559962681362, 48.49706431797573, 49.8442713873727, 49.41742270333426, 50.572060448782786, 50.90225969042097, 50.84214040211269, 48.637890407017295, 50.11301381247384, 47.764345509665354, 47.5113650730678, 45.88301999228341, 44.56776074000767, 43.559820311410085, 46.17822463171822, 41.894646303994314, 38.244208676474436, 43.472137519291465, 44.70773914882115, 44.898689542497905, 49.57317699704851, 55.23586157390049, 58.637522424970356, 53.02725158418928, 50.83795758656093, 50.59479495457241, 48.86483941759382, 41.49468714850289, 51.879516874040874, 53.76685605730329, 54.12727996281215, 52.182659830365864, 54.69688286100115, 49.37572308949062, 43.77742746898106, 43.96502535683768, 43.71232632228306, 41.37420538493565, 41.447286537715364, 39.214524609701975, 41.21346228463309, 44.836280822753906, 40.326476097106934, 42.33320965085711, 41.57256255831037, 43.777114800044465, 46.33596611022949, 46.60304791586739, 50.726317405700684, 50.27318716049194, 49.72046143668038, 50.70075845718384, 49.08406203133719, 50.35158715929304, 48.84530108315604, 46.77975797653198, 47.0424485206604, 47.979326248168945, 47.77529239654541, 48.906028338841026, 44.283787863595144, 43.54588222503662, 45.75563519341605, 46.91167994907924, 49.15946735654558, 49.86199276787894, 51.405781745910645, 51.73454965863909, 56.40438529423305, 44.96397134235927, 32.97579615456717, 51.31976652145386, 51.038593769073486, 54.56356430053711, 53.51606777736119, 70.22980662754604, 64.10202353341239, 42.21675089427403, 41.89461503710066, 42.282178606305806, 54.31181716918945, 56.53403173174177, 56.08670670645577, 50.74960429327828, 51.35418094907488, 52.72019679205758, 59.745315415518625, 60.99740859440395, 50.27573020117623, 10.213923147746495, 3.105784624814987, 0.1423717239605529, 0.12108025859509196, 3.872373512813023, 68.47441373552594, 51.45533282416207, 69.01255171639579, 52.477009841373985, 80.3614057813372, 10.838785069329397, 46.83313751220703, 36.057971886226106, 31.540753432682582, 41.15649747848511, 29.28437110355922, 62.595834732055664, 55.15586348942348, 2.6050896176270077, 0.3560629609440054, 0.1314826618347849, 0.16367426301751817, 0.07728222770882504, 0.06588899370815073, 0.08371889910527638, 0.16087907872029714, 0.11249677703848907, 0.21906018603060926, 0.21187547727354936, 0.13907837282334054, 0.17926987473453793, 0.15686333206083092, 0.15733133123389312, 0.38176350614854265, 0.6140879254255975, 12.936744996479579, 85.26309585571289, 51.4713762147086, 55.06901100703648, 43.383523668561665, 55.88520547321865, 31.79671117237636, 16.54930451938084, 55.3471473966326, 73.11931228637695, 60.24826077052525, 60.87282044546944, 54.461849621364046, 65.19224452972412, 13.492356828280858, 1.8717237583228519, 1.5175434606415885, 0.5433440272297178, 1.2920664910759245, 0.49634885468653267, 22.874637058803014, 71.80726310185024, 60.448584284101216, 60.305659839085166, 48.828879015786306, 55.93844257082258, 60.81021022796631, 62.69130992889404, 57.22748279571533, 51.70377608707973, 47.93011563164847, 33.334302357264924, 49.356879574911936, 31.744151524135045, 24.187471389770508, 66.70377649579729, 55.10099009105137, 60.155627386910574, 53.420203481401714, 55.77006687436785, 50.24468912397112, 54.16446672167097, 53.93526302065168, 50.34300265993391, 48.72113330023629, 48.45586844852993, 48.19061401912144, 51.49594504492623, 50.75668798174177, 52.625840255192344, 48.77610049928938, 55.134178161621094, 51.17149543762207, 53.7813777923584, 52.016910552978516, 53.215936865125386, 54.04005922589983, 54.35988480704171, 54.19841909408569, 53.1993202481951, 54.507280417851035, 52.46348864691598, 51.37844753265381, 52.17512450899397, 49.139644145965576, 48.25710480553763, 53.55561692374093, 47.31115967886788, 42.664982659476145, 50.31391750063215, 51.55539035797119, 50.68367631094796, 54.18877846854073, 60.67639487130301, 63.75432872772217, 55.455646991729736, 53.733928544180735, 54.585847173418315, 52.53829642704555, 42.909333433423726, 56.19271537235805, 57.22653089250837, 57.65072536468506, 57.78892503465925, 58.84286253792899, 53.85686649594988, 48.55607884270804, 48.779185499463765, 48.876307419368196, 46.345735277448384, 48.249117851257324, 43.83257532119751, 44.961855615888325, 48.44814205169678, 43.19014835357666, 44.68452869142805, 45.874126298086985, 49.798687730516704, 49.99897302900042, 51.03200340270996, 54.07745443071638, 54.53443397794451, 53.588415895189556, 53.813739027295796, 52.55612203053066, 54.86939968381609, 49.67924472263881, 49.19881847926548, 49.73946475982666, 51.75708614076887, 49.841453892844065, 52.09442465645926, 46.44372224807739, 46.378819125039236, 47.932332106998985, 50.06987244742257, 49.82871437072754, 52.17583669934954, 52.64506244659424, 53.11830077852522, 56.91782937731062, 49.56532205854143, 35.46063872746059, 53.4570324080331, 53.90853330067226, 58.04422616958618, 56.80654355457851, 66.01705128805978, 57.374478885105674, 41.54183415004185, 45.11941991533552, 44.76133755275181, 56.150046484810964, 60.28029196602957, 59.559291294642854, 52.55635132108416, 53.948249203818186, 55.15869140625, 60.884667124067036, 64.0006354195731, 52.58233410971505, 15.041302238191877, 3.4465401342936923, 0.6914994886943272, 0.5969555133155414, 4.218572284494128, 74.70599596840995, 56.662097454071045, 73.44078459058488, 57.1308958871024, 84.12455013820103, 17.827404805592128, 48.69582101276943, 35.060815061841694, 40.750889437539236, 49.25086396081107, 48.372292041778564, 66.6435217176165, 70.17225469861711, 5.231345185211726, 0.6393605321645737, 0.3182678275874683, 0.2592164176915373, 0.16283594657267841, 0.2660743168422154, 0.21460686570831708], [0.02961595349812082, 0.048048221572701416, 0.02421073166520468, 0.04082841559180191, 0.048162992378430705, 0.088048705698124, 0.08004920530532088, 0.0688721254201872, 0.10885797693793263, 0.07910203827278954, 2.6594549289771487, 56.643712520599365, 45.54683140345982, 33.7097795350211, 46.878811495644705, 34.998534883771626, 50.66628149577549, 21.9770097051348, 18.829355887004308, 60.510374614170615, 44.63135412761143, 59.99491555350167, 46.42363153185163, 54.15797710418701, 19.328689915793284, 0.7215008331196648, 0.08014240887548242, 0.1821575162134, 0.2939110259924616, 0.42037448287010193, 14.422698037964956, 66.45494760785783, 57.73291213171822, 56.663650376456125, 47.57367999213082, 50.89438043321882, 52.08877229690552, 60.19651753561837, 53.84549924305507, 61.06367356436593, 38.1948903628758, 19.778995718274796, 53.30740295137678, 32.84161949157715, 27.82176661491394, 59.3166879926409, 52.23840870176043, 54.53414215360369, 49.4603590965271, 51.204530647822786, 47.645812715802876, 48.342869894845144, 50.416736943381174, 48.89461939675467, 42.75475338527134, 42.5287423815046, 40.752004623413086, 45.28101069586617, 47.968872683388845, 46.40686900275094, 45.154463154929026, 47.442289556775776, 45.728432995932444, 47.9871950830732, 48.66812201908657, 45.540671825408936, 49.41382006236485, 50.63350336892264, 49.027215344565256, 47.242177963256836, 45.337225096566335, 45.91507550648281, 44.52727358681815, 45.622059549604145, 41.41410888944353, 44.26424258095877, 46.321656295231406, 40.922058309827534, 42.90192665372576, 43.091178212847026, 46.889522143772666, 48.10214955466134, 51.213511194501606, 54.8712374823434, 54.63346665246146, 52.94247661318098, 50.74338218144008, 47.11589445386614, 49.192697116306846, 43.70111887795584, 46.176598753247944, 50.61696318217686, 50.97430556161063, 55.17516905920846, 58.62644004821777, 53.14422450746809, 46.89023086002895, 44.974886962345664, 40.86537143162319, 38.151568344661165, 38.69397251946585, 38.84970596858433, 39.60981110164097, 39.616408416203086, 39.92965405327933, 40.46817765917097, 38.68558604376656, 45.04202045713152, 45.22041545595442, 48.736273424965994, 48.815319606236045, 46.05822924205235, 46.91323634556362, 46.766448702131, 43.82787833895002, 45.40524796077183, 45.2000607081822, 43.149831431252615, 47.39846379416329, 45.246165479932515, 45.29010936192104, 46.333944184439524, 40.77063274383545, 41.27372401101248, 44.99655144555228, 44.59412220546177, 46.64965990611485, 48.647993087768555, 49.22458587374006, 50.30794552394322, 52.4633913721357, 50.53263289587838, 45.928596700940815, 49.518991470336914, 49.64108869007656, 51.21629394803728, 51.34711810520717, 59.634199823652, 60.66673687526158, 62.45826734815325, 52.73359291894095, 47.10497535978045, 47.93048388617379, 55.64993599482945, 53.2286034311567, 49.36754853384835, 46.8180182320731, 54.86161075319563, 54.52381713049752, 57.86303104673113, 39.49045147214617, 4.227283588477543, 1.7073505499533244, 0.16539766054068292, 0.09339348532791648, 13.744883026395526, 59.21737044198172, 51.28323984146118, 59.11123670850481, 53.82372011457171, 53.13923570087978, 12.195739592824664, 31.46633127757481, 13.820204104696002, 29.898063795907156, 20.237955502101354, 29.97841623851231, 53.835629326956614, 32.453958647591726, 0.18850930966436863, 0.045341236649879386, 0.06607352130647216, 0.07192696471299444, 0.059527924683477194, 0.020002930757722685, 0.0863577150074499, 0.1038063040801457, 0.028979966017816747, 0.17551001720130444, 0.007264914988939251, 0.1527800304549081, 0.05144975494061198, 0.06699225093637194, 0.03574341648657407, 0.2206597916249718, 0.1010498505617891, 3.9296644500323703, 67.59983703068325, 53.93779216493879, 37.317725454057964, 46.92196328299386, 37.761499949863975, 37.535579272678916, 27.336945635931833, 24.54128234727042, 68.14171314239502, 48.17286137172154, 66.41373784201485, 50.613701002938406, 61.538575989859446, 20.672977004732402, 0.4827127435377666, 0.23543753794261388, 0.2636570765503815, 0.6119257328765733, 0.36763195587056025, 15.231616871697561, 67.6057152066912, 60.64286981310163, 57.83090605054583, 50.06447369711739, 54.46462542670113, 53.95844568525042, 64.32185758863176, 56.23369237354824, 61.107259614127024, 36.966709409441265, 21.98193597793579, 52.460323742457796, 38.32984175000872, 35.79092134748186, 58.86069161551339, 55.60601643153599, 55.92014796393258, 51.92117827279227, 53.58476114273071, 51.13607004710606, 49.823058537074495, 52.9795799936567, 50.24852800369263, 45.679194586617605, 44.099080426352366, 45.830231053488596, 47.10244621549334, 49.14053698948452, 49.74154574530465, 46.72966493879046, 48.699357645852224, 47.77347544261387, 51.32510273797171, 50.37388392857143, 49.206656047276084, 50.332681110927034, 53.95137936728341, 51.600525856018066, 50.16720976148333, 48.414790698460166, 47.21516336713518, 47.697159903390066, 49.72180243900844, 43.83106756210327, 47.582757813589915, 51.12514400482178, 45.231664589473176, 47.255042552948, 48.62288229806082, 51.05968155179705, 50.284189632960725, 53.59796272005354, 57.20655829565865, 56.89048474175589, 53.06967381068638, 51.82944120679583, 50.046811376299175, 49.9376517023359, 45.24890307017735, 50.84008026123047, 51.24468776157924, 55.33252143859863, 58.06666190283639, 60.34720311846052, 53.934606415884836, 48.69835363115583, 46.86657224382673, 45.61237028666905, 43.520340647016255, 40.38824210848127, 41.74782044546944, 41.91689443588257, 45.10610021863665, 43.443250383649556, 45.00421183449881, 43.8893004144941, 50.736256803785054, 48.25122662952968, 49.81580809184483, 52.9755847794669, 49.985000201633994, 50.178757667541504, 49.319480895996094, 47.28991903577532, 50.55783748626709, 47.88772814614432, 46.58529874256679, 48.10802773066929, 47.8978134563991, 46.32618999481201, 47.595938546316965, 42.23675128391811, 43.02018846784319, 45.18250955854143, 45.704260213034495, 47.908374718257356, 50.19858087812151, 51.50919873373849, 53.26902805055891, 52.08415869304112, 53.414245401109966, 45.999527386256624, 50.13286134174892, 53.764806338718955, 52.500609397888184, 52.33278955732073, 56.90526703425816, 56.698756149836946, 63.04273591722761, 54.736299991607666, 51.24019227709089, 49.277128151484895, 55.88415976933071, 53.70681667327881, 52.88106148583548, 49.21870769773211, 56.39713832310268, 57.40972709655762, 60.02428558894566, 43.47191170283726, 6.381577338491168, 1.4490340054035187, 0.5870743606771741, 0.28107235633901184, 16.908250195639475, 65.67846557072231, 53.597848074776785, 67.43287181854248, 56.09492989948818, 59.84516797746931, 15.746070180620466, 41.760855266026084, 17.395098311560496, 36.64461176736014, 24.43973616191319, 30.899417332240514, 64.96992996760777, 35.40019982201712, 0.31966669538191383, 0.039089028390922716, 0.0629345572420529, 0.03992728716028588, 0.0740448014278497, 0.018215869686433246, 0.03801560295479638, 0.19437282931591782, 0.18372052162885666, 0.23294085477079662, 0.1185734923928976, 0.20944092076803955, 0.1981463661151273, 0.20870426243969373, 0.276918174965041, 0.41246585867234636, 0.331816597708634, 4.767472590718951, 83.31818389892578, 61.420435769217356, 50.58689832687378, 58.1371305329459, 50.30525657108852, 58.435496602739605, 34.86144692557198, 28.035892724990845, 73.5698960168021, 55.14809887749808, 72.59257629939488, 56.92427730560303, 67.13830293927873, 23.653585706438335, 0.9908519855567387, 0.408911583679063, 0.48475974798202515, 1.5711364362921034, 0.6888159098369735, 17.679880653108867, 72.03079359872001, 63.77231066567557, 58.73218468257359, 52.87467956542969, 56.77114595685686, 56.057315826416016, 68.00919015066964, 57.98221697126116, 59.98814105987549, 40.326298918042866, 19.746307918003627, 57.04595068522862, 33.46377508980887, 31.06672648021153, 62.8130910055978, 57.14038712637765, 60.00836031777518, 53.67856877190726, 56.621082237788606, 53.62762805393764, 51.561456135341096, 56.05917794363839, 53.89127744947161, 48.37991768973214, 49.130253655569895, 47.92053753989083, 49.08944341114589, 53.49871117728097, 51.855208601270405, 48.77134098325457, 53.03735426494053, 50.959804671151296, 55.297929831913535, 52.79300349099295, 51.69000823157174, 53.64864635467529, 61.11390904017857, 53.97858851296561, 52.016771589006694, 51.5162615776062, 51.82965660095215, 53.669424942561555, 54.580882685525076, 47.98692757742745, 52.82487835202898, 54.9769161088126, 51.45759446280343, 53.13782869066511, 53.85868692398071, 56.598066329956055, 56.871835776737754, 59.43541186196463, 61.28634248461042, 58.60034261431013, 55.932210036686485, 52.432788031441824, 52.02542904445103, 52.29547425678798, 45.67390005929129, 52.09975045067923, 53.941335746220176, 58.3389652797154, 61.91264615740095, 63.78984791891915, 58.990372794015066, 52.61564724785941, 53.40272528784615, 50.01083360399519, 51.930249146052766, 43.360309737069265, 42.10794905253819, 50.40688092367989, 51.250777857644216, 49.36915356772286, 48.21141692570278, 49.849694456372944, 56.46713100160871, 52.172164576394216, 54.59233679090227, 57.34583493641445, 55.524607862745015, 54.86699908120291, 54.18081930705479, 49.56818471636091, 56.86512381689889, 49.465910707201274, 49.622887883867534, 50.57802547727312, 51.22140434810093, 48.32139996119908, 50.28762551716396, 45.00253731863839, 45.26321635927473, 48.207605838775635, 46.676420892987935, 49.88595363071987, 52.16377462659563, 54.2444543838501, 55.04594646181379, 53.07489538192749, 54.759812695639475, 46.90395702634539, 51.902029037475586, 55.46733386175973, 54.39826318195888, 54.968890939440044, 60.01161902291434, 58.17924356460571, 60.68302345275879, 50.44410242353167, 48.10412631716047, 48.77306761060442, 59.180628367832725, 56.36395025253296, 54.301321915217805, 51.366413252694265, 59.46396895817348, 58.862644059317454, 64.75552940368652, 49.410550934927805, 12.320274761744908, 2.746870215450014, 1.1489434795720237, 1.3575922378471919, 18.388530901500157, 70.09715856824602, 60.690840176173616, 72.85266126905168, 61.32765647343227, 64.87756756373814, 22.130384240831646, 41.02856377192906, 20.842410564422607, 45.574825695582796, 31.583648136683873, 45.055982862200054, 71.08323996407645, 51.16049643925258, 0.5941897502967289, 0.2707185633480549, 0.16133901689733776, 0.17530275189450809, 0.16827097135995114, 0.14349714214248316, 0.19761495105922222], [0.05138710240966507, 0.004983726057357022, 0.03836543864703604, 0.16299958207777568, 0.040881941826747994, 0.02584857270786805, 0.05178314972934978, 0.017597926148612584, 0.03141832571210606, 0.0376904795079359, 0.5129095603312764, 49.6638822555542, 52.97902066367013, 31.410544191087993, 42.99817310060774, 53.19582877840315, 65.62162235804966, 21.60903137070792, 14.481006452015468, 52.73898124694824, 53.54247440610613, 54.60374920708792, 47.01675408227103, 52.01037924630301, 30.953172070639475, 0.08623914779829127, 0.10435623635670968, 0.27583129757216995, 0.1791906761271613, 0.4879871319447245, 10.970997129167829, 65.53463785988944, 56.95564494814192, 55.73304339817592, 51.277830668858115, 50.65738780157906, 51.07001004900251, 57.71347107206072, 55.51558215277535, 50.655675070626394, 54.8926031930106, 58.60546343667166, 45.015287263052805, 46.70509263447353, 32.789257866995676, 42.92891345705305, 55.641212531498496, 54.52590159007481, 53.365479469299316, 54.24651105063302, 54.26840135029384, 51.62627935409546, 51.35006414140974, 50.519827365875244, 46.51687983104161, 42.468567507607595, 42.31526592799595, 44.964367389678955, 49.36079141071865, 47.57794966016497, 49.064704350062776, 48.654201303209575, 49.26847069604056, 48.69448348454067, 49.77994149071829, 50.03883137021746, 50.17961229596819, 50.372643675122944, 48.32936954498291, 50.497120652879985, 47.62082004547119, 48.79126494271414, 44.96559722082955, 42.970265660967144, 46.20334931782314, 44.240517956869944, 43.70011486325945, 41.26527847562517, 42.51303597858974, 43.67331913539341, 44.30896813528878, 49.7306683404105, 51.209811278751914, 53.054516315460205, 56.830327238355366, 51.36733736310686, 46.207101345062256, 45.91489485331944, 52.48737307957241, 45.50236293247768, 49.64965581893921, 51.21584578922817, 46.824917793273926, 53.85157544272286, 54.702358041490825, 54.689107826777864, 51.20844595772879, 49.60699735369001, 43.331651891980854, 42.08321346555437, 40.214745589665, 41.07423775536673, 43.94345120021275, 42.750056403023855, 43.64013801302229, 41.23080151421683, 47.222469397953574, 45.58354221071516, 48.12668364388602, 48.87666525159563, 45.61725834437779, 44.657607895987375, 45.18347535814558, 46.82984059197562, 43.66051013129098, 45.99266604014805, 46.23336900983538, 44.743640490940635, 44.60466262272426, 46.12249313082014, 44.0430223601205, 43.70820951461792, 38.65971095221383, 41.865269320351736, 44.80756739207676, 45.3981225831168, 47.02802753448486, 49.34677342006138, 49.74435976573399, 51.42508731569563, 48.592570781707764, 54.17673029218401, 54.09785086768014, 53.21603413990566, 50.76130158560616, 50.603702545166016, 50.90194354738508, 53.17376477377755, 50.524090085710796, 53.64901808329991, 57.45862851824079, 57.621136460985454, 57.73832825251988, 55.398011684417725, 52.097388063158306, 51.44269405092512, 49.43770796912057, 54.44438879830496, 53.52095583506993, 59.37612288338797, 28.34188096863883, 0.8092685235398156, 0.13301510603300162, 0.1120291171329362, 0.12375783920288086, 30.22871467045375, 56.34822300502232, 46.69967998777117, 58.61594826834542, 49.127415316445486, 56.313294410705566, 16.138273409434728, 11.297160335949489, 37.3960941859654, 26.144236973353795, 34.40484605516706, 38.90126855032784, 55.414159297943115, 20.4847902570452, 0.37476479741079466, 0.08170712419918605, 0.09318419798676457, 0.020247700391337276, 0.043063265670623095, 0.04111845538552318, 0.03394926811701485, 0.009970944025553763, 0.04880132080454912, 0.010510216516974782, 0.05941155592777899, 0.07124975962298256, 0.01708930478032146, 0.06915301856185709, 0.054938900750130415, 0.04467648267745972, 0.0619479130421366, 0.7956843610320772, 51.810788767678396, 64.94028200422014, 32.91179282324654, 51.584711756025044, 60.660691942487446, 66.63510050092424, 28.87769651412964, 14.741569110325404, 61.726225989205496, 58.26437636784145, 59.11812237330845, 52.79901020867484, 57.439128398895264, 32.73240770612444, 0.1105939612856933, 0.023704015283978412, 0.4725793387208666, 0.7372489795088768, 0.3534375732498509, 12.968944685799734, 69.30720397404262, 57.61100946153913, 59.511383465358186, 51.7090219770159, 52.47296598979405, 52.55566692352295, 59.88661398206438, 57.66960709435599, 54.2488317489624, 57.37048019681658, 58.269799436841694, 44.68584884916033, 52.212571825299946, 42.164260728018625, 42.33714233125959, 58.49202714647566, 55.152316434042795, 55.336554867880686, 55.55434615271432, 56.513110705784385, 54.570675781794954, 53.837171827043804, 52.015503542763845, 48.514049189431326, 44.48316642216274, 45.332962376730784, 47.37503446851458, 49.807727336883545, 48.626273018973215, 50.604654448372976, 50.67733260563442, 52.42599269321987, 50.81139462334769, 52.097697257995605, 52.15565913064139, 53.90410729816982, 53.03978613444737, 51.776753016880576, 51.65073701313564, 48.881761755262104, 52.65404994147164, 49.299904346466064, 46.99113607406616, 47.91498940331595, 49.87521171569824, 50.63611241749355, 45.69381707055228, 45.4105007989066, 47.18303142275129, 47.57720620291573, 52.736855098179404, 55.3965699332101, 54.536813735961914, 58.81830760410854, 52.38819101878575, 47.988080978393555, 48.18816825321743, 54.07539428983416, 46.42430203301566, 49.49019118717739, 53.201495034354075, 48.21156283787319, 57.291267258780344, 55.90221118927002, 57.24865395682198, 53.39426238196236, 51.67884247643607, 47.39895364216396, 44.94833789552961, 40.15284408841814, 44.00991071973528, 46.26796061652047, 46.0946239062718, 47.044484342847554, 45.550249917166575, 50.672329902648926, 50.16985355104719, 50.148967266082764, 51.45872701917376, 48.97642401286534, 46.838630063193186, 47.42051042829241, 48.706097398485454, 48.83371843610491, 47.82563556943621, 49.16877099445888, 46.98411839348929, 47.69403668812343, 47.73744208472115, 47.555326325552805, 46.93244811466762, 42.6245128767831, 44.60828958238874, 47.206332206726074, 47.65640524455479, 49.22368260792324, 50.146111556461875, 51.73735325677054, 52.969432149614605, 51.38431528636387, 56.23917102813721, 57.325045926230295, 53.67490707124983, 53.54239102772304, 53.81550734383719, 51.956652300698416, 55.043754305158345, 53.0376113482884, 53.59231383459908, 57.12021997996739, 59.124667576381135, 58.38505268096924, 56.705367360796245, 54.30092586789812, 53.008981295994346, 51.54268557684762, 57.60270636422293, 58.309004647391184, 62.54505729675293, 31.337157317570277, 1.104840440409524, 0.11267456678407532, 0.1936120151409081, 0.14216067242835248, 35.605442660195486, 64.2289810180664, 51.91172524860927, 64.11516952514648, 53.69946895326887, 62.9088510785784, 19.985216515404836, 15.721847023282733, 35.37255293982369, 34.72749260493687, 34.07948623384748, 41.60803311211722, 62.05931568145752, 21.57740143367222, 0.40289485082030296, 0.09060687092798096, 0.11414085381797381, 0.056002144768301926, 0.0420080453290471, 0.02628610565859292, 0.04840403176578028, 0.14273027543510708, 0.09794867411255836, 0.201041417196393, 0.2598209652517523, 0.140025689133576, 0.12542331697685377, 0.2433736835207258, 0.16263438096003874, 0.11118377785065345, 0.18714552213038715, 1.0680976063013077, 67.53667095729283, 69.33321108136857, 44.795991693224224, 55.248587199619834, 70.44413076128278, 70.81084278651646, 30.96607140132359, 23.391381536211284, 60.94944517953055, 65.63336481366838, 63.34446144104004, 57.063783236912315, 63.01244177137102, 37.922312532152446, 0.2131482054080282, 0.3759188497705119, 0.7514805729900087, 1.6653415241411753, 0.7043409539120538, 14.019064153943743, 68.0869196483067, 60.32328047071184, 60.869909150259836, 55.33146183831351, 55.90366683687483, 55.035082953316824, 62.16977119445801, 59.7586281640189, 56.93943132672991, 54.38132347379412, 54.97725657054356, 48.301865100860596, 46.32591554096767, 34.54960829871041, 46.879558426993235, 60.55692754473005, 59.568073817661826, 57.33559329169137, 58.486906324114116, 60.37801143101284, 56.82719707489014, 57.74188225609915, 56.48697853088379, 51.38036870956421, 47.88214874267578, 49.25182628631592, 50.458061354500906, 54.30860015324184, 50.94678374699184, 53.13413919721331, 54.001990045819966, 56.62040478842599, 53.934227739061626, 55.76874671663557, 56.385409763881135, 58.14318936211722, 56.93550212042672, 56.020254135131836, 55.611036505017964, 53.66375521251133, 56.765917437417166, 52.728263650621685, 51.024742535182405, 53.15713773454939, 56.59481109891619, 56.72994661331177, 50.57083409173148, 48.40387855257307, 49.833359241485596, 50.32835933140346, 58.37846578870501, 59.66978849683489, 58.12750380379813, 61.766949381147114, 54.60925218037197, 49.919933795928955, 50.28417226246425, 56.84201758248465, 47.941465514046804, 51.831789697919575, 57.06316484723772, 50.70610162190029, 60.606155531747, 58.67732170649937, 60.78820528302874, 54.47878932952881, 58.14529814038958, 49.89288098471505, 48.618487562452046, 47.744553565979004, 50.59789732524327, 50.1025150844029, 50.236271381378174, 51.82116937637329, 49.44926282337734, 55.05288423810686, 53.04738398960659, 54.01459060396467, 54.51136943272182, 53.40467773165022, 50.88539293834141, 49.392669745853965, 51.232674326215474, 51.92395755222866, 53.33223581314087, 50.89336599622454, 49.079531805855886, 50.6186272757394, 51.56570495877947, 48.97686174937657, 48.27082402365548, 43.77822303771973, 46.91021040507725, 50.714654854365754, 48.566581044878276, 51.24238095964704, 53.46931334904262, 53.673541750226704, 54.04277944564819, 51.711332253047395, 57.79459476470947, 57.621702739170615, 55.44752107347761, 55.30407551356724, 54.83894572939192, 54.416873931884766, 56.67302002225603, 54.76041371481759, 55.4641237940107, 58.66852528708321, 59.68908364432198, 59.729827880859375, 59.094526290893555, 55.64052465983799, 56.997695446014404, 54.37738037109375, 58.967485427856445, 61.319700786045615, 63.82986259460449, 38.70335953576224, 2.6706252438681464, 0.2501585180205958, 1.1761997427259172, 0.3862451213811125, 39.240976401737754, 68.98430728912354, 58.064261300223215, 69.76107420240129, 59.9865151814052, 66.9415646961757, 24.505945546286448, 18.694677216666086, 52.320786544254844, 40.78634262084961, 49.56682634353638, 53.11459044047764, 69.9532891682216, 33.04399619783674, 0.5717302954622677, 0.12449110485613346, 0.24621088270630154, 0.17336522229015827, 0.16259497164615563, 0.1568911112844944, 0.18414833795811447], [0.05564630404114723, 0.04310015422691192, 0.005420737808370697, 0.0072829589314226595, 0.03299677458458713, 0.044972340908965895, 0.04704068188688584, 0.11384166058685098, 0.10744587092527322, 0.23805348042930874, 0.28118070481078966, 27.032974106924875, 57.72749253681728, 35.85962166104998, 24.077936513083323, 34.93411466053554, 28.579231432506017, 31.13520097732544, 10.229491455214363, 47.98462077549526, 56.40945053100586, 52.46488176073347, 46.09336628232683, 44.6492144720895, 49.83561740602766, 2.660343647003174, 0.176590801349708, 0.30623129489166395, 0.7574635148048401, 0.07617271438773189, 7.802387544087001, 59.33833163125174, 55.70261376244681, 61.790795598711284, 52.94041994639805, 51.947022097451345, 51.283903394426616, 56.64751318522862, 54.14598103931972, 53.33380610602242, 58.30714947836739, 66.50288322993687, 54.560284750802175, 48.10808679035732, 46.758812631879536, 37.72068623134068, 46.089569091796875, 53.89048882893154, 54.82296487263271, 51.79029158183506, 53.46145841053554, 52.61564724785941, 51.37995529174805, 51.24985722133091, 47.31794112069266, 43.024211474827354, 41.74711172921317, 44.360982349940706, 47.14632061549595, 45.831436565944124, 45.58365338189261, 46.849611691066194, 50.460229192461284, 48.22039747238159, 48.82551956176758, 49.24746976579939, 50.19799028124128, 49.67458248138428, 49.646796635219026, 49.01612949371338, 50.90818650381905, 50.42795133590698, 48.64389712469918, 46.05031871795654, 47.84966244016375, 45.17874016080584, 41.62699474607195, 41.29265785217285, 42.94167034966605, 46.386476039886475, 47.18194055557251, 49.432778222220286, 50.318190642765586, 52.86071021216256, 53.056975977761404, 50.191097668239046, 47.06500932148525, 51.13060181481497, 52.70451123373849, 51.665661743709016, 50.25279767172677, 53.645252159663606, 47.94328246797834, 51.196991852351594, 56.2634654045105, 53.85914897918701, 53.36672667094639, 48.83658456802368, 45.36067526681082, 42.46180691037859, 40.72880458831787, 43.74605287824358, 44.16988604409354, 43.37561314446585, 44.41935764040266, 46.76005983352661, 49.72539465767996, 47.058616978781565, 46.98027603966849, 46.51286377225603, 48.80849994931902, 47.723570006234304, 45.525785309927805, 44.74474178041731, 42.73855366025652, 46.824754510607036, 47.136033807482036, 45.354196071624756, 42.7280410357884, 43.44357347488403, 44.47886896133423, 41.92562484741211, 39.88031489508492, 43.44453927448818, 44.82747745513916, 44.564797333308626, 47.538185119628906, 47.40325805119106, 47.53955738885062, 49.30063738141741, 51.52419294629778, 52.65327174322945, 50.34819296428135, 51.23400143214634, 52.55071980612618, 49.619313035692485, 51.0295923777989, 50.51223298481533, 55.005250862666536, 56.018854073115754, 54.10607753481184, 53.94167273385184, 53.52963413511004, 54.56027432850429, 53.506823199135916, 51.86591230119978, 51.02916506358555, 57.85393238067627, 53.54567057745797, 54.56588152476719, 11.094148738043648, 1.2997197146926607, 0.20071534040783132, 0.4174807752881731, 1.8968571296760013, 43.61203254972185, 54.809068475450786, 49.96931116921561, 57.64926624298096, 47.09599133900234, 66.13881846836635, 8.961768303598676, 32.5029364994594, 34.46197761808123, 22.422458716801234, 21.782423666545323, 36.23663786479405, 56.24262775693621, 8.38929579939161, 0.2882614348615919, 0.07571999582328967, 0.12091580884797232, 0.0583043699817998, 0.05628524993413261, 0.03421901632100344, 0.015559583203867078, 0.038225823281598945, 0.05357501143589616, 0.03690405063597219, 0.020323713276801363, 0.03053226415067911, 0.05987451358565262, 0.05999774233038936, 0.10075298470578023, 0.06642094480672053, 0.056138859396534305, 0.2644743584096432, 31.575091430119105, 68.48311982836042, 36.58571883610317, 30.82131610597883, 46.504831654684885, 30.46127782549177, 35.025288922446116, 10.036605988230024, 51.990594250815256, 65.28831032344273, 52.925648076193674, 52.863649300166536, 50.26677049909319, 54.9387218611581, 2.8461063419069563, 0.29447008456502644, 0.3211779557168484, 0.9937377678496497, 0.023591463287760104, 8.860066652297974, 62.44459329332624, 58.948148591177805, 62.54348700387137, 55.55856718335833, 55.72922536305019, 55.77095276968819, 58.497891426086426, 56.14535297666277, 54.53194304874965, 60.24304267338344, 64.91358702523368, 52.64333234514509, 51.391367707933696, 56.47557306289673, 40.449931689671104, 47.02648850849697, 54.46353803362165, 56.09303304127285, 55.39274842398507, 56.48482458932059, 54.44506624766758, 53.686027663094656, 53.760005133492605, 51.37382003239223, 45.8121657371521, 44.660498346601216, 46.859464236668174, 48.84804909569876, 48.504512786865234, 46.898054531642366, 48.83056395394461, 52.76453672136579, 49.82862751824515, 50.6516763823373, 52.019154821123394, 53.47643872669765, 53.66564859662737, 51.23813213620867, 50.227054595947266, 52.27988249914986, 53.542634214673726, 52.46082748685564, 50.73745536804199, 50.42519637516567, 49.37471907479422, 45.02101605279105, 45.07673365729195, 47.628077438899446, 49.05320508139474, 52.48034497669765, 53.461468832833425, 55.109258447374614, 54.27224023001534, 55.180519172123496, 53.96054056712559, 48.50401251656668, 53.269305978502544, 54.44170331954956, 50.87053768975394, 51.91156196594238, 54.53672340938023, 49.895090511866975, 53.86212975638253, 57.78652443204607, 56.149344716753276, 53.87084627151489, 52.88537631716047, 47.731570856911794, 47.220617703029085, 46.1261374609811, 47.30044903073992, 49.44646964754377, 48.24348981039864, 47.811964988708496, 49.07046093259539, 52.683416502816335, 50.778463636125835, 49.06976958683559, 48.52515241077968, 48.68832738058907, 50.30684423446655, 47.90935788835798, 47.70406641278948, 47.07788780757359, 48.52810192108154, 49.53810249056135, 46.969735622406006, 44.10925953728812, 46.554559912000386, 46.2156719480242, 44.86878102166312, 43.11428792136056, 43.806255544934956, 46.8081066267831, 46.07647868565151, 48.30927882875715, 49.67737913131714, 50.09320102419172, 53.170342785971506, 54.25046110153198, 54.91905845914568, 50.330478531973704, 53.749704429081504, 55.083841936928884, 53.39233078275408, 52.066506794520784, 50.97735582079206, 55.56057521275112, 59.41094725472586, 54.889132567814414, 54.2114052772522, 55.43118585859026, 56.52208777836391, 53.865635122571675, 54.6239059312003, 53.97933544431414, 60.70279107775007, 55.30378021512713, 57.20302166257586, 13.942156280790057, 1.1413868793419428, 0.32842508969562395, 0.33935615313904627, 2.5358225916113173, 52.27583517347063, 61.28083951132638, 56.386372089385986, 61.83003207615444, 52.21801573889596, 75.01054940904889, 14.792527198791504, 30.142084530421666, 36.210352829524446, 30.199566977364675, 27.182096345084055, 37.592450278145925, 67.02306706564767, 7.816069415637425, 0.3394514465970652, 0.08502101459141288, 0.0718070472191487, 0.041712170134165456, 0.03716343082487583, 0.08694329072854348, 0.019335466037903513, 0.10617063899657556, 0.1324681118130684, 0.13320018324468816, 0.3070136729095663, 0.12604005102600369, 0.12136099567370755, 0.12346729050789561, 0.22113449472401822, 0.16844790615141392, 0.29877449359212604, 0.40142614820173805, 41.65753207887922, 78.9018463407244, 47.09557792118618, 36.859029701777864, 46.903620038713726, 41.22715023585728, 38.866423334394185, 20.0240968976702, 58.048867566244944, 68.67708574022565, 59.30863503047398, 57.172414847782676, 53.950837407793315, 63.67407008579799, 2.9464342040675024, 0.48399674892425537, 0.5232774125678199, 1.6777801024062293, 0.3171391524374485, 10.097342797688075, 62.81143733433315, 58.86955751691546, 64.65651757376534, 58.31803035736084, 57.17294291087559, 56.88708012444632, 60.61570930480957, 59.828263010297505, 56.729977880205425, 62.42752851758684, 63.97892229897635, 49.51715019771031, 48.074262959616526, 46.057979106903076, 41.86763865607125, 48.471352509089876, 60.05529539925711, 60.979822703770225, 57.83003057752337, 59.319529805864605, 58.58755792890276, 54.14556414740426, 56.54576029096331, 54.7090665272304, 48.33435835157122, 47.41386447634016, 49.99456787109375, 53.19857331684658, 52.672354970659526, 51.08431986400059, 51.162219592503135, 55.405342033931184, 53.23123679842268, 54.70702028274536, 55.677176407405305, 56.760591643197195, 58.20450026648385, 54.657597746167866, 52.999590805598665, 57.62131364004952, 58.5172004699707, 56.8525892666408, 53.98961877822876, 57.93416322980608, 52.858427728925435, 49.00766658782959, 49.37958628790719, 51.12270171301705, 53.05829266139439, 56.35752664293562, 55.935117857796804, 57.3440249306815, 58.028665678841726, 57.93555286952427, 56.87800925118582, 52.01073013033186, 57.654407909938264, 55.66989469528198, 55.35927895137242, 54.56535346167428, 58.087447438921245, 52.37284244809832, 57.94095509392874, 61.49238436562674, 59.647873878479004, 58.878103801182334, 56.53756141662598, 52.45600543703352, 49.920962129320415, 49.439028126852854, 51.67262731279646, 52.32250622340611, 51.07555818557739, 50.866351400102886, 53.36141129902431, 57.45544276918684, 53.79595511300223, 51.30701657703945, 52.50827326093401, 54.50282314845494, 54.66312851224627, 52.42602048601423, 51.450983251844136, 50.38331263405936, 51.76627860750471, 53.800676413944785, 49.83164998463222, 46.904450348445344, 48.585719857897075, 47.8726783479963, 48.102191243852886, 45.90137365886143, 47.63730812072754, 48.49890559060233, 48.88195283072335, 50.05441270555769, 51.66445970535278, 51.63349158423287, 53.3438149860927, 55.20652627944946, 57.434257711683, 53.0110171181815, 55.48881769180298, 57.48893656049456, 55.032605920519146, 55.29492473602295, 53.24791942323957, 57.51427664075579, 59.209331376211985, 57.01400286810738, 56.7258471761431, 56.36220278058733, 59.262172426496235, 58.14903974533081, 56.54305049351284, 56.40944358280727, 64.27099677494594, 60.4332982472011, 61.64845480237688, 20.639366831098283, 1.2603763001305717, 0.988157712987491, 0.6658611787217004, 2.4008414575031827, 56.19087757383074, 64.63563128880092, 63.858190400259836, 67.11764594486782, 58.438463483537944, 77.54346656799316, 18.138109139033727, 42.239558356148855, 50.81359025410244, 33.40310341971261, 37.14987434659685, 44.80843244280134, 79.10265622820172, 16.7662707056318, 0.5760475152305194, 0.15718909672328404, 0.19346174677567823, 0.13062328366296633, 0.11978555949670927, 0.1312638342912708, 0.08266609095569168], [0.09107227131192173, 0.05077895522117615, 0.011636785663930433, 0.026786961193595613, 0.0606308833562902, 0.05071179721770542, 0.048538547940552235, 0.18362704664468765, 0.1032480393935527, 0.18325785574104103, 0.3936406916805676, 16.352390834263392, 57.64285652978079, 41.38944625854492, 36.945812702178955, 34.470402308872764, 48.672947543007986, 67.82072026388985, 12.097129021372114, 31.099647045135498, 59.324428285871235, 50.45011608941214, 56.57178824288504, 39.276016167231965, 58.76990645272391, 11.59825096811567, 0.4578259789517948, 0.3163480077471052, 1.6410757005214691, 0.03302787184449179, 5.080230551106589, 52.855169023786274, 63.525969232831685, 57.840053353990825, 57.15500961031233, 53.5396534374782, 52.39213759558541, 55.1976569039481, 54.873783997126985, 51.260654721941265, 55.87534597941807, 44.56363698414394, 59.35045623779297, 42.98677110671997, 47.17597900118147, 49.84585210255214, 42.419131074632915, 48.97590637207031, 49.58393975666591, 51.56638935634068, 51.37820087160383, 50.66041374206543, 48.180705887930735, 50.56477526256016, 48.51996210643223, 45.57279682159424, 41.98063720975603, 43.62759304046631, 46.450764247349326, 47.258332524980815, 46.13991573878697, 46.717675822121755, 49.3718911579677, 50.84280048097883, 48.2622777393886, 49.133151054382324, 47.54347964695522, 49.61393512998308, 48.380866118839805, 49.72128479821341, 49.676809379032676, 49.77687038694109, 48.97286306108747, 49.742118971688406, 50.2695289339338, 46.02385997772217, 44.574451855250764, 40.56852354322161, 42.687064034598215, 47.40744434084211, 51.585576806749614, 51.4971991947719, 50.62209790093558, 49.88101693562099, 51.13725471496582, 52.00392089571272, 48.42774214063372, 51.04069907324654, 52.909896509987966, 48.40262787682669, 52.00276402064732, 53.77301216125488, 50.2359413419451, 49.81071506227766, 56.21658590861729, 52.50918000085013, 53.267284052712576, 49.28121369225638, 47.57240152359009, 42.857538087027415, 40.14475985935756, 45.07452760423933, 45.72697040012905, 44.725255557468955, 46.70699296678816, 50.21153232029506, 49.106310163225444, 48.80877440316336, 48.443260942186626, 48.850015435900005, 49.65710081372942, 47.690649441310335, 48.51794365474156, 46.40338100705828, 45.012987409319194, 49.05330583027431, 45.422906807490754, 47.21527453831264, 44.115141187395366, 44.406902994428364, 43.951243604932515, 41.64200632912772, 39.92370639528547, 43.37616205215454, 45.9102395602635, 47.352171421051025, 48.54372494561331, 51.53544902801514, 49.824635778154644, 50.28563485826765, 50.324586459568565, 50.53037820543562, 51.82883671351841, 50.32112973076956, 50.82932097571236, 51.49485765184675, 49.52313954489571, 49.80323880059378, 52.12128986631121, 54.00467552457537, 54.97386237553188, 55.571866035461426, 54.06720583779471, 54.61745800290789, 52.37322459902082, 52.442598887852256, 55.155582087380544, 54.51327671323504, 54.17791496004377, 50.550517559051514, 2.3212897947856357, 0.7533764541149139, 0.5536153103624071, 0.49134343756096704, 10.549991880144391, 53.345628465924946, 49.60486078262329, 56.445136478969026, 48.24022763116019, 60.84935637882778, 40.75672245025635, 11.885842987469264, 38.25481857572283, 28.10593577793666, 26.424480404172623, 33.67437498910086, 40.86440563201904, 49.976922920772004, 2.2360833840710774, 0.08926641142794065, 0.04857589450797864, 0.06624623561011893, 0.08540887199342251, 0.04011899705177971, 0.027314147279996957, 0.09689335538340466, 0.12714408178414616, 0.01610336795316211, 0.0307477906213275, 0.06350924926144735, 0.03507750221927251, 0.05331935301156981, 0.07330804131925106, 0.12628110737672874, 0.021536732025976692, 0.08819326079849686, 0.3129860838609082, 17.441522700445994, 67.48660223824638, 42.463318143572124, 40.42785031454903, 49.51095935276577, 50.81342349733625, 69.66327135903495, 15.620538813727242, 33.09630571092878, 67.7570469720023, 53.88127204350063, 62.15626389639718, 44.10503155844552, 64.50349044799805, 12.749629139900208, 0.47847575375011986, 0.33926351953830036, 2.1972607587065016, 0.06247134852622237, 5.0713112354278564, 55.055673939841135, 64.02757358551025, 61.502250807625906, 60.68306514195034, 57.15043422154018, 54.714288098471506, 58.8924240384783, 57.682621070316856, 54.605003356933594, 57.708312034606934, 50.90953098024641, 63.828827313014436, 45.455160345349995, 49.45763887677874, 55.21792132513863, 45.816678592136924, 49.419854572841096, 50.882610184805735, 54.52334117889404, 52.98428392410278, 52.760729108537944, 53.130380221775596, 52.496357100350515, 52.3796204158238, 48.44865274429321, 43.50482531956264, 44.864455768040244, 49.43826035090855, 46.933966296059744, 46.841610840388704, 47.832809584481375, 51.86367498125349, 53.854201861790244, 50.035200936453684, 50.99375704356602, 50.51552990504673, 53.227366651807515, 49.42755665097918, 52.438860757010325, 52.14710937227522, 50.091804436274934, 52.87746579306466, 52.402452196393696, 54.517768723624094, 50.93376629693167, 48.15588344846453, 43.41791377748762, 46.841346808842246, 51.681336879730225, 53.57758712768555, 55.579634121486116, 53.267985820770264, 53.45427049909319, 54.284667083195274, 55.264255387442454, 47.79112734113421, 54.30932623999459, 54.18241739273071, 49.47137893949236, 52.65114212036133, 54.70152078356062, 51.71706451688494, 52.44368280683245, 58.306690897260395, 54.13891472135271, 55.394228390284944, 53.26637731279646, 50.42216001238142, 45.81232554571969, 43.355584962027415, 49.06711190087454, 47.48093891143799, 48.33733218056815, 50.32852956226894, 53.053769384111675, 50.57390866960798, 50.64039945602417, 50.893560545785085, 50.131954601832796, 51.75325073514666, 48.646801471710205, 51.54337344850813, 49.10124840055193, 48.10281310762678, 50.57140384401594, 45.98364380427769, 49.04766736711775, 44.34160034997122, 45.18799863542829, 47.50264508383614, 43.50972032546997, 41.21756867000035, 43.34882436479841, 48.037201268332346, 48.16356815610613, 48.12959493909563, 53.126565660749165, 52.620267799922395, 52.788101536887034, 51.51221077782767, 54.80543109348842, 54.17068535940987, 52.76380716051374, 54.74877200807844, 54.47658675057547, 51.70463766370501, 52.221479415893555, 53.8588467325483, 55.95220695223127, 58.0622741154262, 56.697401251111714, 56.84066615785871, 57.86164835521153, 54.19583783830915, 55.09749862125942, 56.939042227608816, 58.465082032339915, 58.64593669346401, 53.983764920915874, 3.554574851478849, 0.6676377462489265, 1.0082688395466124, 0.3463377627943243, 14.258991530963353, 64.95731898716518, 55.80388028281075, 61.2239476612636, 54.13317550931658, 64.61622497013637, 48.815132004874094, 15.80312705039978, 40.69795111247471, 32.33906323569161, 34.05446924482073, 30.809170654841832, 46.79824365888323, 55.74502556664603, 2.5848232422556197, 0.147091966388481, 0.009935404905783278, 0.08633107572261776, 0.06127570875521217, 0.0604363473664437, 0.041866374002503495, 0.012750692499269332, 0.22383878247014113, 0.21793316650603498, 0.17024594252663, 0.16200220345386437, 0.1431747565844229, 0.1894866307931287, 0.20089762205524103, 0.32774337913308826, 0.15935012219207628, 0.23719421082309314, 0.49681470968893593, 23.73851180076599, 80.66104684557233, 53.27443722316197, 55.056049142565044, 44.96372120720999, 64.34856646401542, 77.17408643450055, 21.978130102157593, 39.03107827050345, 74.40388829367501, 57.65894160951887, 68.69922964913505, 48.75142049789429, 70.75951644352504, 13.453046526227679, 0.7671419211796352, 0.7628580310514995, 2.7665360059056963, 0.13614666728036745, 6.579605340957642, 55.42548486164638, 64.24539266313825, 63.39762210845947, 63.723471777779714, 58.58942004612514, 57.5149575642177, 59.569060461861746, 59.27435261862618, 57.096766335623606, 58.301792417253765, 57.92598172596523, 65.80755615234375, 47.26788977214268, 50.240464619227815, 49.507054465157644, 49.66836731774466, 51.73957668031965, 54.00830595833914, 56.64555031912667, 55.90852015359061, 54.112702642168315, 55.6664205959865, 54.37887075969151, 54.7900721005031, 51.21846873419625, 45.791477475847515, 47.888891969408306, 52.58224378313337, 48.92930480412075, 51.27965457098824, 49.96982533591134, 56.203172411237446, 57.24878944669451, 53.52190426417759, 55.30358566556658, 53.6012179510934, 55.9544130052839, 54.42113317762102, 56.474805286952424, 56.350543703351704, 53.175498349326, 55.18553229740688, 57.575021266937256, 60.61388887677874, 54.942953314099995, 53.12903227124895, 47.157969270433696, 50.811168806893484, 54.87750823157174, 57.69307116099766, 58.441652706691194, 56.56370401382446, 57.18753065381731, 59.11615603310721, 57.731404372623985, 53.18336023603167, 56.208220277513774, 58.519180706569124, 51.58354098456246, 53.740803786686485, 57.99008928026472, 55.32702193941389, 55.70943341936384, 60.67474814823696, 57.790318148476736, 58.84204265049526, 57.81535250799996, 54.820043155125205, 51.51193979808262, 47.80004187992641, 52.853060245513916, 52.70877742767334, 51.31281137466431, 54.084541593279155, 57.96231733049665, 52.807695456913535, 54.30603974206107, 54.31847701753889, 55.13659266063145, 55.8632561138698, 52.51162576675415, 54.296176774161204, 52.06139986855643, 53.374550342559814, 54.669489588056294, 50.37382139478411, 53.619613306862966, 48.20051172801426, 47.653580801827566, 50.32107414518084, 45.93952969142369, 44.163281781332834, 46.45687518801008, 50.139687946864534, 52.526317732674734, 53.31672395978655, 54.704904556274414, 54.34608915873936, 53.50302253450666, 52.841001646859304, 54.55748462677002, 54.224780559539795, 55.630442823682515, 55.932126658303396, 55.677124295915874, 54.11073977606637, 53.16724041530064, 55.06211839403425, 59.88548142569405, 58.64548506055559, 57.45064156396048, 56.397808824266704, 60.39584745679583, 57.0080691065107, 57.24749708175659, 60.18729727608817, 62.86733559199742, 60.78603049686977, 60.50196034567696, 6.16284761258534, 0.7793323727590697, 2.2397040469305853, 0.5624805603708539, 13.842358435903277, 69.3847736631121, 59.253723417009624, 70.68385056086949, 57.82625075748989, 71.31023066384452, 50.852948325020925, 20.902314458574565, 50.098280157361714, 42.92938593455723, 37.413082531520296, 50.44685738427298, 53.50559336798531, 69.97730909075055, 6.09484646150044, 0.6032150260039738, 0.11236085968890361, 0.19959910959005356, 0.23881267969097408, 0.11683504496301923, 0.1391275937535933, 0.16713498160243034], [0.016547204494210224, 0.11199861019849777, 0.09847536656473364, 0.06623499907021012, 0.05852274290685143, 0.07691597486180918, 0.06486827347959791, 0.17461357744676725, 0.060939189312713485, 0.21280849006559166, 0.29723530475582394, 5.030614767755781, 54.01313148226057, 46.88695478439331, 30.491992337363108, 23.2596332686288, 33.95522117614746, 49.4622802734375, 13.49800397668566, 24.00064822605678, 64.14403929029191, 47.931682450430735, 59.92336300441197, 46.162639822278706, 59.14893763405936, 29.00532623699733, 0.12657242960163526, 0.21047320323331015, 1.4615799550499236, 0.05054191579776151, 1.6618720931666238, 31.060341085706437, 62.25344140189034, 61.02176203046526, 56.28780147007534, 54.56308140073504, 54.01570578983852, 55.67118011202131, 48.211465563092915, 60.02383395603725, 58.459961209978374, 53.91184064320156, 44.40796259471348, 47.68477821350098, 48.07606949125017, 48.99636534282139, 52.0898631640843, 55.95700468335833, 56.601846149989534, 58.25906794411795, 53.59317888532366, 51.88892820903233, 50.91352619443621, 48.80528293337141, 48.16765022277832, 48.046529224940706, 42.32971818106515, 42.90337535313198, 46.46172850472586, 44.968980993543354, 42.79071031297956, 45.127062933785574, 46.621495383126394, 49.18134723390852, 49.50133957181658, 47.85950108936855, 49.85858120237078, 50.86714349474226, 49.554253578186035, 51.38477734157017, 51.01745387486049, 51.99722630637032, 49.579729148319785, 49.19493096215384, 49.665869440351216, 49.70067644119263, 42.285291399274556, 43.72581624984741, 44.970586027417866, 47.73665346418108, 48.40617493220738, 48.150769574301584, 51.27963720049177, 52.407107489449636, 50.39214726856777, 48.69474056788853, 48.25942202976772, 50.996581486293245, 51.93489749091012, 41.23446668897356, 46.64244072777884, 55.451787267412456, 50.83915267671858, 50.34364536830357, 53.645071506500244, 52.80597230366298, 48.900094577244346, 56.38471841812134, 52.12431580679757, 47.218251841408865, 44.16502577917916, 43.99565996442522, 43.479342801230295, 45.80605479649135, 47.18643256596157, 50.04750967025757, 48.95738247462681, 51.25714240755354, 47.5616318157741, 48.47085918698992, 46.590058258601594, 50.446124349321636, 48.517693519592285, 47.08722618647984, 46.80013704299927, 47.80364799499512, 47.37100451333182, 44.38070828574044, 43.37448058809553, 44.105083669934956, 45.297752380371094, 39.702864851270405, 40.3076707976205, 43.32994958332607, 46.608856609889436, 48.29814781461443, 49.719738824026926, 51.94654614584786, 49.8553398677281, 53.99027190889631, 51.45506879261562, 54.80409009116036, 42.30664668764387, 40.7111804825919, 55.333219732557026, 52.249115875789094, 51.21221188136509, 47.78613158634731, 50.39287335532052, 53.46931334904262, 54.32188858304705, 53.68750068119594, 54.73311424255371, 54.13689626966204, 55.6098553112575, 53.29673399244036, 57.333397660936626, 55.13120780672346, 57.732425757816856, 35.05952269690377, 0.17900209767477854, 0.8965306782296726, 0.396867749946458, 0.11255352292209864, 29.14255142211914, 51.403474943978445, 48.43373496191842, 55.960371085575645, 53.304363114493235, 58.64741665976388, 42.91612529754639, 14.116376280784607, 36.2706423486982, 26.230795894350322, 29.160210268838064, 29.567273957388743, 46.996677262442454, 34.03673396791731, 0.19957369166825498, 0.08694251719862223, 0.014619795239663549, 0.0510142813436687, 0.020838029250236492, 0.01406794525350311, 0.006555990083143115, 0.04497343335034592, 0.020045698819948093, 0.032645008460219414, 0.06854796888572828, 0.06273493902491671, 0.024019640936915363, 0.0580010444724134, 0.02729404907274459, 0.08862345878567014, 0.11709248114909444, 0.28966668088521275, 0.32166378679020063, 5.922716132232121, 59.51059137071882, 52.85155596051897, 35.807833262852256, 32.52813761574881, 41.495687689099995, 51.22917938232422, 16.166728019714355, 26.283230475017003, 71.18004921504429, 55.04146834782192, 67.2194926398141, 48.6476526260376, 66.221481187003, 31.85176522391183, 0.1587827583508832, 0.15117913564401014, 2.592474728822708, 0.04928865483296769, 1.9807618388107844, 35.02225603376116, 65.73446805136544, 60.66109493800572, 60.198212896074565, 57.12613984516689, 56.72863687787737, 57.04611049379621, 51.62430606569563, 61.17462239946638, 60.62247685023716, 55.36861038208008, 48.35383415222168, 49.97124971662249, 49.93929842540196, 48.324262619018555, 54.503455434526714, 57.585044043404714, 58.04291990825108, 59.09165668487549, 56.581474031720845, 54.4351407459804, 53.60614422389439, 50.98302902494158, 49.75562974384853, 48.72332198279244, 45.230427810123985, 46.01971885136196, 46.2722407068525, 48.29494816916329, 45.12179272515433, 46.295451164245605, 49.749303409031455, 52.160998821258545, 53.10953215190342, 50.672423703329905, 51.38249485833304, 52.447667598724365, 49.947073459625244, 52.788907527923584, 53.400001593998496, 54.88381372179304, 49.93700899396624, 51.93617248535156, 55.0133489881243, 52.881975173950195, 45.1393404006958, 45.96736070087978, 48.02280460085188, 49.613566875457764, 52.81542532784598, 52.89061525889805, 52.02419226510184, 57.28380836759295, 53.230298791612896, 50.042764050619944, 50.93950203486851, 53.38574389048985, 53.4781688281468, 42.38584572928292, 49.07894468307495, 57.92810092653547, 51.31428786686489, 52.878785950796946, 55.11319807597569, 54.125890323093955, 52.764640944344656, 58.98710714067732, 53.50776468004499, 47.607344014304026, 48.34819916316441, 48.7702431678772, 47.21948167255947, 49.137420722416465, 49.0629221371242, 53.74041468756539, 52.182736260550364, 53.17681850705828, 48.770566259111675, 51.0272091456822, 50.037671021052766, 51.177700178963796, 50.12607295172555, 49.96178279604231, 48.12987286703927, 49.10595580509731, 46.86386592047555, 46.20661497116089, 45.39094161987305, 45.53796897615705, 48.29305478504726, 41.27211202893938, 41.536435399736675, 46.09909507206508, 48.078994682856965, 50.11772469111851, 52.29483502251761, 52.41822460719517, 51.255005836486816, 54.769804205213276, 54.14001253673008, 56.14364719390869, 37.47643968037197, 39.392665999276296, 57.67986958367484, 52.98756347383772, 55.273645877838135, 50.94044698987688, 52.82957533427647, 55.25086620875767, 55.07173122678484, 54.546478680201936, 57.04520375388009, 56.224520751408164, 56.631080695560996, 57.11117689950125, 60.64439146859305, 59.459786142621724, 58.838950702122276, 37.744410855429514, 0.06445233829851661, 1.220428500856672, 0.47836365976503914, 0.27424054007445064, 39.196900503976, 60.094024658203125, 52.357532092503135, 64.31909915379116, 57.951815128326416, 66.95819868360246, 41.39063440050398, 16.986514704568044, 42.59721687861851, 30.063705376216344, 31.666578360966273, 26.662619488579885, 52.86985056740897, 38.10164901188442, 0.10439310116427285, 0.03275477846286126, 0.04434017697349191, 0.022044629058135406, 0.01730035461618432, 0.07703729692314353, 0.044215207786432335, 0.07820757305515663, 0.10465749233428921, 0.31257068472249167, 0.27098359912633896, 0.18838127010634967, 0.10600484575011901, 0.2601841443351337, 0.10447211656719446, 0.3415566422045231, 0.22448565704481943, 0.4119435766977923, 0.48351607471704483, 9.90064103262765, 78.23892566135952, 59.550786699567524, 46.95732961382185, 31.486151014055523, 50.71545042310442, 57.075678552900044, 22.08632050241743, 31.05780499322074, 76.70013591221401, 55.21948119572231, 73.03100068228585, 53.02544852665493, 69.80310385567802, 33.138925961085725, 0.2969930406127657, 0.5137995811445373, 3.8225510205541338, 0.12084049146090235, 2.7353266520159583, 38.16512428011213, 63.73102446964809, 62.9882481438773, 62.311583927699495, 59.83920642307827, 57.93962451389858, 59.94342940194266, 56.466411863054546, 62.99087456294468, 62.57214137486049, 55.21913031169346, 52.0557336126055, 53.97526379993984, 55.37211922236851, 47.28669159752982, 51.416457653045654, 59.991969517299104, 60.621406827654155, 63.093367440359934, 59.93888528006417, 60.17246287209647, 56.16955007825579, 51.71813801356724, 52.49341801234654, 53.58958319255284, 49.05368798119681, 49.20368569237845, 48.854910441807334, 51.74652140481131, 46.854030745370046, 48.6567964553833, 54.08017465046474, 54.62448263168335, 55.826163155691965, 51.73709617342268, 56.99161229814802, 56.97453710011074, 55.111377647944856, 55.60474491119385, 58.600759506225586, 59.274442945207866, 54.212440558842246, 55.58220148086548, 58.483654567173545, 57.34988921029227, 47.019109521593364, 50.063549586704795, 53.47506645747593, 53.0525221824646, 55.390278339385986, 55.9562577520098, 57.92058644975935, 60.35174724033901, 54.85844932283674, 53.43088633673531, 53.977379526410786, 54.968585218702046, 57.49376903261457, 46.275864192417686, 51.256506647382466, 60.08276162828718, 53.57236903054373, 56.92151192256382, 58.74764442443848, 56.69032451084682, 55.00401060921805, 63.573216983250205, 57.692689010075156, 50.28148678370884, 51.565201214381624, 50.0592417035784, 49.589230809892925, 51.28381306784493, 53.501719747270855, 57.39637613296509, 53.77128553390503, 57.25787769045149, 51.60059881210327, 55.216562952314106, 53.59255007335118, 55.769479751586914, 53.74082463128226, 54.69705656596592, 52.34917688369751, 53.28237554005214, 52.17564214978899, 48.14888661248343, 46.71517447062901, 47.43164839063372, 51.25804567337036, 44.322524070739746, 44.66237088612148, 48.135695457458496, 49.78490250451224, 51.67975616455078, 54.11782693862915, 55.551559925079346, 52.721027101789204, 56.86584990365164, 54.523754596710205, 58.86213684082031, 43.33893360410418, 42.08439465931484, 59.81371348244803, 53.89976119995117, 56.761182240077424, 52.624916144779746, 54.791694504874094, 56.65907498768398, 56.41817052023751, 55.77928018569946, 57.33168492998396, 59.51107079642159, 58.83940233503069, 58.28932040078299, 62.85309178488595, 61.75956344604492, 62.25288554600307, 45.19023595537458, 0.5079712910311562, 1.5775654741695948, 1.5730382885251726, 0.24768468790820666, 37.910667351314, 63.54007407597133, 59.100202969142366, 68.58718994685582, 62.86762046813965, 68.51329585484096, 53.1863305909293, 23.30578146662031, 44.60152203696114, 39.40056610107422, 41.15324919564383, 44.988984857286724, 57.15808071408953, 56.230867930821006, 0.8500217167394502, 0.1685090692979949, 0.15272467556808675, 0.14001119562557765, 0.13390979516719068, 0.1365499070712498, 0.18865328122462544, 0.11739339785916464], [0.024456015289095894, 0.01984847752776529, 0.012463198060036769, 0.028474447250898396, 0.013102542592345603, 0.030894445787583078, 0.06746488450361149, 0.008632782214720334, 0.04240839456075004, 0.05997577136648553, 0.032046218269637654, 0.18498113112790243, 34.308436325618196, 46.502233028411865, 32.4894118309021, 40.62086084910801, 30.142063685825892, 45.10373783111572, 13.915994576045446, 31.06515966142927, 63.13469532557896, 40.6248664855957, 60.278742517743794, 53.62973683220999, 52.29558195386614, 49.60428408214024, 0.5614878907799721, 0.10769595857709646, 0.8358682904924665, 0.06720544663923127, 0.4836020586746079, 23.88124864442008, 57.74727405820574, 59.269349915640696, 63.8956481388637, 54.09533909388951, 54.874110562460764, 50.3341680254255, 62.24166420527867, 56.44015114648001, 53.48022549492972, 57.09737777709961, 57.40176098687308, 55.13881261008126, 59.220358167375835, 38.54998500006539, 50.769872188568115, 57.92798975535801, 55.751299789973665, 52.32999985558646, 53.437518392290386, 50.61914144243513, 51.399257387433735, 48.926945890699116, 47.094761507851736, 47.91259574890137, 46.70062146868025, 43.89797524043492, 43.01173945835659, 46.640318053109304, 43.61338744844709, 42.19321039744786, 46.41266032627651, 49.0979653767177, 52.9240916797093, 50.86925227301461, 50.81985752923148, 46.92030266353062, 48.900702544621055, 49.7928512437003, 50.798050607953755, 49.60397488730294, 47.58965390069144, 50.39347784859793, 47.74781921931675, 45.38438946860177, 42.56798233304705, 43.357839652470176, 45.168859822409495, 48.73866360528128, 50.05602816173008, 49.30338191986084, 50.60952166148594, 52.5045941897801, 52.51180294581822, 46.90842819213867, 48.35235071182251, 51.526134967803955, 51.33605309895107, 45.55607598168509, 41.170112473624094, 53.26178802762713, 50.04701634815761, 49.00797230856759, 55.338569845472065, 52.806993688855854, 54.23745059967041, 53.09585462297712, 51.48419911520821, 50.604560647692, 45.79184225627354, 44.77920831952776, 44.21747078214373, 44.878015177590505, 49.72810098103115, 49.30362510681152, 50.36072751453945, 49.1868953704834, 48.11342648097447, 50.11096061979021, 46.450722558157786, 47.62827893665859, 48.22933285576956, 49.88954584939139, 47.73589958463396, 46.51805060250418, 43.73464393615723, 43.77279302052089, 42.31373732430594, 43.29044560023716, 43.09121642793928, 40.0711020060948, 38.903064659663606, 44.13893876756941, 45.574294158390586, 50.084449768066406, 52.100507804325645, 55.77430527550833, 52.144097328186035, 54.52764211382185, 49.3300004686628, 41.51429843902588, 22.348311015537806, 15.682052952902657, 52.37607683454241, 51.51063353674752, 52.39435754503523, 49.272695200783865, 48.4478884424482, 51.04706709725516, 53.458005155835835, 52.612037658691406, 55.32333592006138, 56.940146991184776, 56.44871827534267, 57.1798528943743, 56.69806827817644, 55.400506087711875, 56.62125594275338, 20.081799949918473, 0.7626285776495934, 2.339763969182968, 0.17398317770234176, 4.288426867553166, 36.21152012688773, 49.67869928904942, 58.17420959472656, 49.69496154785156, 45.358594281332834, 67.85810157230922, 35.974551813943044, 17.998370443071636, 21.273023435047694, 30.612602642604283, 61.34879984174456, 35.08715568270002, 53.369106428963796, 26.566199336733135, 0.12534642538854054, 0.10795379509883267, 0.03412789246067405, 0.04138335884947862, 0.06449038375701223, 0.04263096083221691, 0.03387449695063489, 0.027918016305193305, 0.024684169296441332, 0.021843526545645933, 0.14322810300758906, 0.06963463593274355, 0.01162100293939667, 0.052041040533887487, 0.04136289423331618, 0.01813636743463576, 0.014508588439119714, 0.08234318971101727, 0.06418821175715753, 0.5064578865255628, 40.27726895468575, 58.1972393989563, 29.387735979897634, 42.00947570800781, 40.28355360031128, 53.632842676980154, 17.705371856689453, 33.25014230183193, 70.72786045074463, 44.71882152557373, 67.40969262804303, 57.81807967594692, 58.40185342516218, 51.74557992390224, 0.755860217979976, 0.14273816001202377, 2.3261326892035346, 0.06923463275390011, 0.731001897581986, 25.58699665750776, 62.04152134486607, 62.760778018406455, 65.52294404166085, 54.98692151478359, 57.96317890712193, 54.456454345158164, 64.38109098161969, 59.44895390101841, 55.904358182634624, 58.28054482596261, 58.9986480985369, 52.51605176925659, 62.625100544520784, 42.2213089125497, 51.033719607761924, 60.73655932290213, 56.32463387080601, 54.610294410160606, 55.53443956375122, 53.7563920702253, 52.82474981035505, 52.71607998439244, 48.09297445842198, 49.8459597996303, 49.06119898387364, 45.97508014951433, 45.04849965231759, 47.41003254481724, 45.56941999707903, 44.426052229745046, 46.57223265511649, 53.690279960632324, 54.247726985386436, 53.572594846997944, 53.797719955444336, 51.21692623410906, 52.32747071129935, 51.53129400525774, 51.7239328111921, 52.388430731637136, 47.89605903625488, 52.05171407972063, 51.41291407176426, 48.89789547239031, 44.41064459936959, 47.58957052230835, 49.54038149969918, 50.721766335623606, 53.82120139258248, 53.316049984523225, 54.00479711805071, 54.57893718991961, 53.20959663391113, 49.03658151626587, 51.32505757468087, 51.55780138288225, 52.46356507710048, 43.64826740537371, 44.53219985961914, 57.745401518685476, 49.75628982271467, 53.021974427359446, 56.71121426991054, 54.83919933864048, 54.80908237184797, 56.66546038218907, 51.59302527563912, 53.40944072178432, 45.239123480660574, 48.15101970945086, 45.73549236570086, 48.93617309842791, 51.85322489057268, 54.48972232001168, 55.02827719279698, 51.57307004928589, 49.76914051600865, 52.983839239392964, 49.65863289151873, 51.11481898171561, 49.22927590778896, 51.918312140873496, 50.29402480806623, 50.17348745891026, 46.089096614292686, 45.19882392883301, 43.200886794498985, 43.671203408922466, 45.00902346202305, 42.246666363307405, 40.212470054626465, 44.62805025918143, 45.96924018859863, 52.7918188231332, 54.35781076976231, 56.26959024156843, 50.99751601900373, 57.55403423309326, 49.49479784284319, 43.74315895353045, 27.544748885290964, 16.98933219909668, 52.87872689110892, 53.070764677865164, 54.55051210948399, 51.36214705875942, 49.87219967160906, 53.7700001171657, 55.556729384831016, 55.92161055973598, 56.72521489007132, 57.04918507167271, 58.07170282091413, 59.67206055777413, 59.60298156738281, 58.798296792166575, 59.523028646196636, 22.360088212149485, 0.688541401709829, 3.6548501678875516, 0.32722823534693035, 6.734939702919551, 40.60932683944702, 55.11109972000122, 60.58153806413923, 57.65841702052525, 49.04653828484671, 75.84126908438546, 36.544484751565115, 26.11353462082999, 25.028417076383317, 35.31479951313564, 58.23065676007952, 33.55119732448033, 60.436438832964214, 29.691903795514786, 0.23984486716134207, 0.12170312660081045, 0.02891750686935016, 0.06765452147062335, 0.0673823000064918, 0.03659542916076524, 0.05316363261746509, 0.013943132129497826, 0.1552448496222496, 0.20725959353148937, 0.2704466607953821, 0.15806713460811547, 0.08332432420658213, 0.2674132835652147, 0.13127408017005238, 0.29192169702478815, 0.11268435804439442, 0.15481532338474477, 0.1288421428097146, 1.0607976551566805, 58.45465973445347, 63.25413485935756, 49.47244896207537, 51.97408185686384, 44.85639933177403, 59.19326714106968, 20.331281968525477, 39.202518122536794, 73.72702257973808, 49.51313066482544, 68.64415822710309, 62.771394865853445, 61.30192034585135, 56.41120147705078, 0.7540521664278848, 0.4742880527462278, 3.9039335336003984, 0.2718524496470179, 1.1018116772174835, 31.822867665972026, 64.26081071581159, 64.48800986153739, 65.5992213657924, 57.84633799961635, 59.878401211329866, 59.01508058820452, 66.7560338973999, 58.35299369267055, 57.87134109224592, 60.527210099356516, 60.643265860421316, 52.86227355684553, 61.04366275242397, 45.83851678030831, 51.5028133392334, 64.27808393750871, 59.40333897726876, 57.66412149156843, 58.96754101344517, 55.43735238483974, 56.41661759785244, 53.88278327669416, 51.176258427756174, 51.811327253069194, 51.39909757886614, 49.17110906328474, 48.30778496606009, 48.45448923110962, 48.928109713963096, 45.95339134761265, 51.04598665237427, 56.890231132507324, 58.014310700552805, 56.143237250191824, 60.27876336233956, 54.47294589451381, 57.538557120731895, 55.894919054848806, 58.33331639426095, 56.04503835950579, 51.61222662244524, 56.63375922611782, 56.12966741834368, 52.10222748347691, 49.96651451928275, 51.93232318333217, 51.87710237503052, 53.93523522785732, 59.069547516959055, 57.64560801642281, 59.51899869101388, 59.90536717006138, 56.63663925443377, 50.20709589549473, 53.75759410858154, 54.70367125102452, 54.65183074133736, 46.98407670429775, 46.94192893164498, 61.909880774361746, 56.208796977996826, 55.3438400541033, 61.3711383002145, 59.206003189086914, 59.09999452318464, 60.960854121616904, 55.12849106107439, 56.25673260007586, 50.17780923843384, 51.154948302677695, 50.60203150340489, 51.970965589795796, 55.53441871915545, 57.664924008505686, 58.86162267412458, 54.601129736219136, 52.46924870354788, 57.73041425432478, 53.670481068747385, 54.785152775900706, 52.98019143513271, 55.29399367741176, 54.318754945482524, 51.849274839673726, 48.29228700910296, 48.940338543483186, 46.00956058502197, 45.686167103903635, 48.20999949319022, 44.09185429981777, 42.40033619744437, 48.629292011260986, 49.2891971724374, 54.86714151927403, 56.60714415141514, 57.63143369129726, 52.35398851122175, 61.37566157749721, 52.083401339394705, 46.85004595347813, 27.64937833377293, 15.971070221492223, 56.82447338104248, 54.15420423235212, 57.06793825966971, 52.741993291037424, 52.002993311200825, 54.50315318788801, 57.257241930280415, 55.612554686410085, 58.53735024588448, 59.04549285343715, 61.90503093174526, 61.448833056858604, 62.615824699401855, 61.19170107160296, 63.57926886422293, 25.549193246023997, 0.7869854878102029, 4.288757341248648, 0.4794387306485857, 6.259985165936606, 47.22903891972133, 58.34967245374407, 67.49782357897077, 60.43321486881801, 55.89266783850533, 79.02523245130266, 47.586152008601594, 26.370030845914567, 30.807662895747594, 44.23474400384085, 77.62447561536516, 48.36943980625698, 66.54583004542759, 43.50052785873413, 0.44229575086917194, 0.20004135157380784, 0.11308446300349065, 0.16143546386488847, 0.17137712825621876, 0.1251067803906543, 0.16536662434892996, 0.14186118064182146], [0.06062208954244852, 0.06440165173262358, 0.035857776778617075, 0.04080350657126733, 0.10442419842417751, 0.08185797610453197, 0.04633852027888809, 0.09896693125899349, 0.04570577958864825, 0.08133538200386933, 0.07498343927519661, 0.4949186114328248, 22.06679606437683, 49.94040666307722, 44.5758831841605, 37.397306646619526, 22.713256461279734, 35.23113972800118, 9.39618878705161, 22.217351368495397, 66.80895137786865, 44.24409975324358, 49.328572613852366, 53.42491436004639, 52.696819577898296, 58.263695444379536, 5.452396043709346, 0.29102996630328043, 1.2939979817186082, 0.12507944900010312, 0.1756527538278273, 14.232102870941162, 59.80463218688965, 51.980918884277344, 58.67516776493618, 54.16082239151001, 59.02261243547712, 62.1859188079834, 63.76772485460554, 54.41021408353533, 59.347760336739675, 48.795399120875764, 55.05591017859322, 45.61533716746739, 58.26559577669416, 47.882082734789165, 45.124672753470286, 55.35632944107056, 51.87517772402082, 54.19006388528006, 50.228621414729524, 50.22540439878191, 49.98717846189226, 49.626077107020784, 50.6577456338065, 46.579590797424316, 46.80851309640067, 44.422654560634065, 45.288980279650005, 43.73864957264492, 42.86794996261597, 40.84247711726597, 45.71118756702968, 50.317540986197336, 50.230810097285676, 51.203519684927805, 50.907196385519846, 47.96968214852469, 49.348354135240825, 49.91631031036377, 50.767280510493684, 48.03996665137154, 48.61615296772548, 46.33395460673741, 45.873577390398296, 44.40237971714565, 44.51882110323225, 45.93663229261126, 46.96809237343924, 47.83270883560181, 49.8836225100926, 48.470494406563894, 48.87228093828474, 50.14917571204049, 53.371805804116384, 43.86460999080113, 47.683225291115896, 51.03049216951643, 50.04657861164638, 44.82455573763166, 41.035053389413015, 53.12114953994751, 48.87939241954258, 46.03985125677926, 52.103578908102854, 54.59541136877877, 50.67917387826102, 50.74921866825649, 51.81211239950997, 52.468564305986675, 44.948605401175364, 43.418414047786165, 42.768417017800466, 44.088703291756765, 45.21692051206316, 47.27997268949236, 47.28300905227661, 49.91568497249058, 48.95107698440552, 49.10661588396345, 48.102173873356406, 47.37139361245291, 47.889680589948384, 47.359956877572195, 48.18762976782662, 45.913015365600586, 45.20652600697109, 43.58084556034633, 42.085700920649934, 43.72425290516445, 41.30334765570504, 39.75376388004848, 41.39970874786377, 45.95213024956839, 48.103247370038716, 51.209074769701274, 51.54520082473755, 52.78508949279785, 47.98713949748448, 45.967708110809326, 48.23274094717843, 46.18011801583426, 44.81070102964129, 40.403232846941265, 48.33094678606306, 57.20640890938895, 50.75316871915545, 51.57048184531075, 49.01259980882917, 49.27679811205183, 51.59545019694737, 55.71869189398629, 54.14512988499233, 53.23118816103254, 57.65016950879778, 58.77495779309954, 57.83052042552403, 60.95295401981899, 52.985958439963206, 4.120660441262381, 0.330754391849041, 2.3149543404579163, 0.7541578550423894, 19.92682559149606, 63.48737893785749, 47.040711471012656, 53.31579637527466, 47.72629370008196, 50.05662570680891, 62.37078257969448, 24.654694318771362, 20.224387407302856, 28.83535245486668, 62.48488589695522, 61.77307769230434, 23.38298463821411, 54.29438066482544, 17.009011234555924, 0.22131893411278725, 0.08365143915372235, 0.0913225964510015, 0.13439778398190225, 0.007352297576809568, 0.03310406793441091, 0.04722582016672407, 0.0237489767106516, 0.017181817941101532, 0.03915817789467318, 0.05311119543122394, 0.03672660015789526, 0.1406734050916774, 0.036513085543577156, 0.06991377166871514, 0.16665128112903663, 0.0928247712020363, 0.045625139094356976, 0.03465691568063838, 0.4412635362574032, 27.512755904878887, 62.74761813027518, 43.73782273701259, 35.87556082861764, 31.877549988882883, 44.85948085784912, 13.599791611943926, 25.14890578814915, 74.09646524701799, 48.34668792997088, 59.91382312774658, 57.69407170159476, 57.026867457798545, 65.156829561506, 6.646083968026297, 0.32958245330623215, 2.5558399174894606, 0.06106441295040505, 0.2577907613345555, 18.576396295002528, 63.04810687473842, 54.03318745749337, 65.48254026685441, 57.30949933188302, 61.54746273585728, 63.24254526410784, 63.35580784933907, 57.084065028599326, 64.40401308877128, 53.261794975825715, 57.55330467224121, 47.439201082502095, 56.308448042188374, 51.5996538570949, 47.477437019348145, 58.881716864449636, 55.635445526668, 57.20431055341448, 52.411668981824604, 53.16751834324428, 50.75532266071865, 50.935930660792756, 52.811642033713206, 49.66778366906302, 49.8401962688991, 45.48141411372593, 48.18107761655535, 45.36048419134957, 44.43062761851719, 41.30573088782174, 47.20427206584385, 53.362029688698904, 50.83255188805716, 52.15051051548549, 52.16597720554897, 51.7113287789481, 52.026533808027, 50.617199420928955, 53.38554239273071, 51.184749126434326, 51.9549743107387, 49.64084897722517, 48.877148151397705, 47.15585354396275, 44.36570365088326, 47.07438938958304, 48.67656408037458, 49.33741767065865, 52.71138647624424, 52.91973863329206, 53.9910431589399, 53.10956341879708, 52.87639924458095, 46.617045061928884, 49.47292491367885, 50.125061988830566, 52.92426885877337, 44.780188015529085, 43.095138686043875, 55.60325799669538, 52.29812846864973, 50.94705820083618, 53.350471360342844, 56.2715357371739, 53.86971024104527, 53.13548714773995, 52.77463592801775, 54.63872296469552, 48.94683510916573, 47.274514879499165, 46.35710947854178, 46.988582611083984, 47.665319783346995, 51.604159763881135, 50.5838063785008, 51.32621444974627, 49.59921189716884, 51.15659155164446, 51.65732390539986, 49.96633039202009, 49.26317964281355, 49.565426281520296, 49.762449400765554, 47.472566332135884, 45.74619606563023, 44.913430145808626, 43.047307286943706, 45.39826154708862, 42.51565544945853, 40.23330422810146, 42.7846862248012, 48.346771308353965, 49.5203845841544, 50.48190062386649, 51.57116971697126, 52.59343038286482, 49.907103947230745, 48.34907463618687, 48.96834673200335, 48.426814556121826, 48.892093726566856, 43.02605969565255, 50.499632426670615, 58.27529893602644, 52.31328248977661, 55.32150159563337, 51.980276175907676, 53.158714975629536, 53.387241227286204, 59.26598003932408, 57.63727365221296, 55.131562164851594, 59.695149421691895, 59.823142187935964, 62.88347625732422, 62.10974570683071, 53.649351596832275, 4.600100040435791, 0.3863768114575318, 2.92005341393607, 1.1657288074493408, 24.78986804825919, 61.004315103803364, 48.86317532403128, 59.5840060370309, 50.18987478528704, 53.81465966360909, 65.99472672598702, 31.56591980797904, 25.788499627794536, 30.67725910459246, 72.12667873927525, 62.50674492972237, 27.166747774396622, 61.50880295889718, 18.85789213861738, 0.14998549755130494, 0.06997078896633216, 0.059806185109274726, 0.02808839305570083, 0.03103722651888217, 0.052027870169175525, 0.015586188561948282, 0.03861262556165457, 0.0967245562268155, 0.14116414875856467, 0.15244995030973638, 0.12712069946740354, 0.2695453220180103, 0.14960489368864469, 0.18942344561219215, 0.2515924796462059, 0.16001945627587183, 0.16021236378167356, 0.11248454305210284, 0.5273562765547207, 40.62430020741054, 71.96159648895264, 62.002277919224326, 50.84609392711094, 33.92312397275652, 51.182775838034495, 14.139675327709742, 32.57585436957223, 75.53094169071743, 52.75397893360683, 59.450121198381694, 63.17105524880545, 59.5820813860212, 69.49709129333496, 6.8689135653632025, 0.33207349106669426, 4.065845234053476, 0.49253711636577335, 0.5962539081062589, 23.25185649735587, 64.75502218518938, 57.64391613006592, 69.26036616734096, 62.123127937316895, 63.63962091718401, 64.11371040344238, 64.19991670336042, 60.736760820661274, 65.91823400769914, 54.90444639750889, 60.49596405029297, 51.66366066251482, 57.36290666035244, 50.73672580718994, 49.863208702632356, 62.10240840911865, 56.594293458121165, 60.73495428902762, 56.04476737976074, 55.343336309705464, 54.5279096194676, 54.5015412058149, 56.806178774152485, 51.65195989608765, 51.54025718144008, 48.73281669616699, 52.008694308144705, 47.63911812646048, 47.43202359335763, 44.099379198891775, 48.769683837890625, 56.47896725790841, 52.7438519341605, 56.4810517174857, 56.806529658181326, 54.761508056095664, 55.7322130884443, 55.78662095751081, 57.393405778067454, 53.031972885131836, 55.03576387677874, 52.33478716441563, 51.20287350245884, 51.39782953262329, 50.15560974393572, 52.50574064254761, 53.55658272334507, 52.16308675493513, 55.75200155803135, 55.02025897162301, 59.06905419485909, 56.668587071555, 57.21527828489031, 44.62006677900042, 52.82400982720511, 54.624864782605854, 55.3471473966326, 47.263835498264854, 43.97294977733067, 57.030136585235596, 55.27023778642927, 51.62188114438738, 55.94464036396572, 60.33471720559256, 56.1162782396589, 58.68210901532854, 56.911652428763254, 59.54863970620291, 52.63514041900635, 48.80911833899361, 49.47289712088448, 49.731443064553396, 51.30516140801566, 53.737829957689556, 54.39582436425345, 54.10782848085676, 54.552370752607075, 55.70481981549944, 55.03311661311558, 52.9141001701355, 52.01305430276053, 50.79388516289847, 52.46246031352452, 50.94095420837402, 48.710033552987234, 49.023689133780344, 47.577706473214285, 48.4138422693525, 45.53226797921317, 43.45655618395124, 43.94170372826712, 49.31660781587873, 52.00329903193882, 53.718739782060894, 54.896636622292654, 56.840443815503804, 52.10328360966274, 48.73617615018572, 51.88850089481899, 45.9985476902553, 43.911927223205566, 43.05057988848005, 51.63052122933524, 61.557482038225444, 54.067254475184846, 56.93871218817574, 53.784341199057444, 56.05633960451399, 55.238428933279856, 61.21779155731201, 58.79803276062012, 57.03514971051897, 59.6605612891061, 62.700641359601704, 63.37137876238142, 66.64880234854562, 57.450499125889365, 7.244141042232513, 0.7756658952151025, 7.367524981498718, 1.6001436454909188, 25.773713861192974, 70.22328921726772, 56.946542807987754, 64.8695284979684, 57.33759784698486, 59.46474715641567, 71.78340993608747, 35.871228626796174, 28.08375539098467, 42.535502978733604, 68.21979004996163, 71.3993968963623, 35.834674154009136, 67.76072951725551, 31.29422787257603, 0.3020793933953558, 0.21371179659451756, 0.16468734294176102, 0.11975490328456674, 0.08588263192879302, 0.11314395016857556, 0.19405655057302543, 0.207575153027262], [0.02997357537969947, 0.020055978625480617, 0.044043395934360366, 0.04005735893068569, 0.030139351662780558, 0.037461674106972556, 0.01873750196370695, 0.08619361809853997, 0.0725146574633462, 0.035904510878026485, 0.1353094500622579, 0.20797479658254556, 6.920037976333073, 39.64355502809797, 35.838096141815186, 35.74451085499355, 27.73798176220485, 35.41642386572701, 12.35670416695731, 9.267009615898132, 56.78640420096261, 57.5022006716047, 48.80904885700771, 58.22632803235735, 49.280199255262104, 56.70793472017561, 23.311605794089182, 1.7902872881719043, 1.2285941541194916, 0.12780827257250035, 0.5896582763109888, 6.956318863800593, 57.12840495790754, 57.48254074369158, 60.39151872907366, 55.45355210985456, 60.99591473170689, 54.642871039254324, 57.13785450799124, 53.229148864746094, 56.084507601601736, 53.76359040396554, 57.07259702682495, 52.97213152476719, 50.845631871904644, 52.08199780327933, 41.49313770021711, 52.22017315455845, 58.29462882450649, 51.43266085215977, 52.330725942339214, 52.90604373386928, 51.11207444327218, 49.16661705289568, 52.87783752168928, 50.42692300251552, 50.51499489375523, 48.97731338228498, 44.24495438167027, 45.116199425288606, 42.50546244212559, 41.391256264277864, 41.315368039267405, 45.27501440048218, 51.06106424331665, 50.628167152404785, 51.75053398949759, 50.20802695410592, 49.231544494628906, 51.05408130373274, 47.31472063064575, 48.486263343266074, 50.130617073604036, 46.45548554829189, 45.70867231913975, 42.41272483553205, 43.304699829646516, 45.25122029440743, 47.9410069329398, 49.12161357062203, 49.351689270564485, 48.95406470979963, 51.14046130861555, 50.294796058109824, 50.05073710850307, 42.796678815569194, 46.65581948416573, 50.23005621773856, 49.45365408488682, 44.677750723702566, 44.36572102137974, 51.8287672315325, 49.89966242653983, 45.96235799789429, 52.447222914014546, 53.14862271717617, 50.52206815992083, 51.043308121817454, 52.52029364449637, 52.990537302834646, 48.95750406810215, 46.059855120522634, 41.87326322283064, 42.63104765755789, 46.347131865365164, 50.17856311798096, 50.02766561508179, 47.838486262730186, 49.10094615391323, 47.34301716940743, 48.539979866572786, 47.85624933242798, 44.597947188786094, 46.57292400087629, 47.849026679992676, 44.57529953547886, 43.63307516915457, 41.74999175752912, 41.453487804957796, 44.375577041081016, 42.9549240384783, 40.24558169501168, 43.78463275091988, 47.63462264197213, 45.297133990696494, 47.97501836504255, 47.51163952691214, 47.167349338531494, 49.58866105760847, 51.20799432482038, 49.45486307144165, 52.24958140509469, 44.64624064309256, 45.01886905942644, 45.05781718662807, 48.06776291983468, 53.90224518094744, 53.5345777784075, 50.711559431893484, 51.335851601191926, 50.661455971854075, 51.049860273088726, 55.04626260484968, 57.53881420407976, 56.08577217374529, 59.14446299416678, 55.84999895095825, 58.948113850184846, 28.573728459221975, 0.33421367193971363, 0.05170651598434363, 0.5482251910226685, 0.7827382385730743, 32.17270599092756, 54.54013844898769, 58.13235364641462, 52.80439158848354, 57.192575045994346, 54.176243918282644, 63.26221561431885, 21.36726532663618, 25.140663487570627, 37.979166167122976, 33.715452739170615, 30.203357219696045, 31.36686781474522, 56.71465015411377, 8.918859703200203, 0.335398366940873, 0.08941959749375071, 0.27093873439090593, 0.04532754381320306, 0.015995959252385155, 0.025775740455303873, 0.05307043243997863, 0.06773625101361956, 0.05105283909610339, 0.03749057969876698, 0.08307203810129847, 0.0383997962677053, 0.052556900174490044, 0.09582040152911629, 0.04113678261637688, 0.06746348672147308, 0.11967077851295471, 0.043923909310251474, 0.07104774617723056, 0.22489052531974657, 9.010073917252676, 55.20050566537039, 39.95925337927682, 34.720301219395225, 39.648686272757395, 38.40500388826643, 16.939341647284373, 10.943858333996364, 63.47119658333914, 60.553877285548616, 50.43960346494402, 66.85158552442277, 53.206303187779014, 62.40670476640974, 25.623634508677892, 2.712953018290656, 1.856007150241307, 0.15479564586920397, 0.5630203485488892, 8.394149116107396, 59.78192547389439, 59.22704233442034, 63.982792445591514, 60.18731812068394, 63.49368095397949, 57.757859638759065, 60.10947745186942, 57.242525645664756, 60.03808471134731, 57.883538654872346, 59.27584648132324, 54.25177778516497, 52.22168786185128, 54.26029975073678, 45.339333874838694, 55.95234939030239, 60.355131013052805, 53.075489452907014, 54.84783942358834, 53.65195369720459, 52.98843894686018, 50.99780784334455, 54.38876846858433, 51.987068040030344, 51.047827925000874, 49.3024890763419, 45.16581998552595, 46.72111865452358, 43.58381938934326, 42.75241879054478, 43.95169176374163, 47.502683298928396, 52.60562447139195, 51.510254859924316, 54.25399773461478, 53.34080294200352, 52.52321883610317, 52.84688329696655, 51.20214394160679, 50.278120381491526, 51.19393464497158, 48.60602249417986, 46.94247089113508, 44.75423649379185, 44.598978996276855, 47.79726607458932, 50.25724799292428, 50.78104141780308, 53.64582886014666, 51.599441937037874, 52.33815704073225, 51.50025292805263, 52.06223365238735, 46.09847668239048, 47.67016267776489, 53.57484258924212, 52.15087529591152, 46.65209524972098, 45.88844306128365, 54.48081472941807, 51.200184549604145, 49.232590198516846, 54.010518959590364, 53.78382008416312, 51.980088574545725, 55.26907396316528, 52.42191410064697, 52.65091977800642, 50.05189398356846, 46.60669572012765, 43.20706721714565, 45.319319588797434, 48.179503849574495, 51.62959711892264, 52.319066865103586, 49.8722483089992, 50.83502197265625, 51.17922183445522, 52.27775982448033, 50.0470232963562, 49.496524470193044, 49.10632405962263, 51.22130012512207, 47.50072390692574, 43.90110192980085, 42.95224550792149, 42.20712069102696, 45.688112599509104, 42.6766973223005, 42.09807218824114, 46.070652621132986, 48.48615912028721, 46.95428630283901, 49.25323677062988, 50.45966291427612, 48.384117875780376, 51.85307897840227, 52.61972236633301, 50.898240157536094, 49.49300173350743, 43.098310538700645, 44.67500271115984, 45.35985885347639, 48.670897824423655, 54.629554816654746, 57.564112595149446, 54.103200980595176, 54.97060367039272, 53.830706528254915, 52.70831537246704, 55.69417864935738, 58.43243939535958, 57.632267475128174, 62.36118711744036, 58.67193685259138, 60.6447388785226, 31.816895689283097, 0.32801072193043573, 0.23573956745011465, 1.1068639946835381, 1.0020304428679603, 34.64667463302612, 59.00137179238455, 61.362098693847656, 58.81252670288086, 59.99663870675223, 58.73876462663923, 68.13946192605155, 26.491433245795115, 23.310190098626272, 37.92688792092459, 42.28769895008632, 34.066711970738, 34.32531349999564, 62.48052242824009, 7.826351881027222, 0.39629921902503285, 0.02402043651922473, 0.2836941885096686, 0.07733472596321787, 0.04277953625257526, 0.045616589553122006, 0.06418939240808998, 0.033960603044501374, 0.23136255517601967, 0.09570584446191788, 0.18004400176661356, 0.13034148806972162, 0.19649435047592434, 0.22391304134258203, 0.14692306545163902, 0.17616636412484304, 0.3004050946661404, 0.2020803221634456, 0.27643158393246786, 0.5234675109386444, 14.950173139572144, 71.38465976715088, 48.02249540601458, 51.85416637148176, 41.038569177900044, 53.9613048689706, 17.59458977835519, 15.91388133593968, 68.73431805201939, 67.05427142551967, 53.94449717657906, 71.07410308292934, 54.860690116882324, 66.62624849591936, 29.839768409729004, 3.4420958927699496, 3.600746065378189, 0.3670698031783104, 0.8403986788221768, 13.614507896559578, 61.017655645098, 59.75841971806118, 66.70602771214077, 61.871721267700195, 65.5239862714495, 59.142322949000764, 63.684033802577424, 60.28862285614014, 62.213468415396555, 59.96501745496477, 59.65650354112898, 54.92759779521397, 53.69267014094761, 52.12592084067208, 46.551985604422434, 57.86656073161534, 63.018035071236746, 59.246900285993306, 55.564320291791645, 57.55018493107387, 55.949542318071636, 54.387153012411936, 58.88906111036028, 56.457452160971506, 53.240005425044465, 53.238032136644634, 48.494274616241455, 50.875613348824636, 46.62352425711495, 45.15651287351336, 46.59345245361328, 49.29146228517805, 54.95077698571341, 54.68699904850551, 58.42847197396414, 56.66917419433594, 56.28253820964268, 56.47444398062569, 52.268025398254395, 51.6963449886867, 54.044999395098, 52.608143193381174, 50.05506583622524, 48.09295013972691, 49.10062306267874, 51.85695259911673, 55.54857219968523, 52.580572741372244, 55.97266244888306, 53.34277970450265, 57.82979086467198, 56.346221923828125, 55.62439789090838, 46.97849382672991, 50.168390955243794, 55.85177074159895, 54.020743233816965, 47.83810411180769, 47.17893893378121, 55.91791064398629, 54.8989851134164, 52.602570738111226, 57.56742341177804, 58.91705540248326, 55.594482421875, 59.21763447352818, 58.26116977419172, 57.229817390441895, 54.49789687565395, 52.573954582214355, 45.20166574205671, 46.9928731237139, 51.074317932128906, 55.626986094883506, 57.66917283194405, 54.03346191133772, 55.72824566704886, 54.11992876870291, 57.78177533830915, 53.753265380859375, 50.77118192400251, 50.20703336170742, 52.7897413117545, 50.288931778499055, 45.88380513872419, 45.10700001035418, 46.08906882149832, 47.863868032182964, 46.23464053017752, 43.58547306060791, 48.3777950150626, 50.36717196873256, 47.06405394417899, 50.374248708997456, 51.48964302880423, 50.00172451564244, 52.463797841753276, 54.230234895433696, 49.96938065120152, 49.6109995160784, 45.22323295048305, 45.41437094552176, 47.323023727961946, 50.97831814629691, 55.84967238562447, 58.7683778490339, 56.08771072115217, 58.04161364691598, 56.216384410858154, 56.483184814453125, 59.212555340358186, 60.04484530857631, 61.69520228249686, 63.68821661812918, 61.49594184330532, 61.71002279009138, 37.17946325029646, 0.8159811890551022, 0.2672407456806728, 1.355240706886564, 2.8159129449299405, 42.91144915989467, 62.55784893035889, 66.98944473266602, 64.022550037929, 66.76365607125419, 63.32952281406948, 73.31344495500836, 30.546163967677526, 34.05954837799072, 54.13421426500593, 41.22723708833967, 42.20400789805821, 41.556543486458914, 77.05024174281529, 15.367761611938477, 0.6077019880924905, 0.13613248589847768, 0.3629716687968799, 0.18834632555288927, 0.23698809902582849, 0.11406545500670161, 0.175917993166617, 0.1441692989319563], [0.023686380158843737, 0.017373246240562627, 0.020030235006873096, 0.047152704625789604, 0.05679885344579816, 0.013631168869324028, 0.03965121500992349, 0.01332588239373373, 0.038342202215322425, 0.028574863648308173, 0.10820835429642882, 0.19377304507153376, 1.1879389413765498, 31.62043537412371, 40.49984754834856, 28.452369485582622, 18.820439611162456, 42.07708168029785, 23.48719198363168, 4.317157668726785, 44.30699137278965, 58.26201745441982, 39.945815563201904, 49.88387611934117, 57.43536942345755, 52.41420160021101, 55.52535479409354, 1.2576032089335578, 0.4205254704824516, 0.09753590769001416, 1.4952588507107325, 6.43245986529759, 31.284510816846574, 64.91044643947056, 58.54226957048689, 60.18906211853027, 54.15068844386509, 57.236616202763145, 57.29787499564034, 53.63335336957659, 57.1830838067191, 55.07463557379586, 52.28019864218575, 52.83267075674874, 50.31678015845162, 50.86871031352452, 43.56498629706246, 53.166069643838064, 56.61904641560146, 54.1586788722447, 53.40673439843314, 54.054365566798616, 51.59857341221401, 52.147279603140696, 51.81840051923479, 50.0903765814645, 53.12652049745832, 50.32951620646885, 45.204507555280415, 43.776086466653005, 43.78048120226179, 42.67066976002285, 40.20604644502912, 42.261288847242085, 50.077956676483154, 50.59043148585728, 50.54453863416399, 49.30030039378575, 48.53648492268154, 47.91214411599295, 48.344457558223176, 48.782906259809224, 48.77054194041661, 45.53510284423828, 41.87215151105608, 43.414967741285054, 47.138941628592356, 44.74034704480852, 48.02835621152605, 48.85603257587978, 48.532837118421284, 49.20030886786324, 51.490984031132285, 49.95336505344936, 47.8195732661656, 41.70442199707031, 48.606019020080566, 49.232082980019705, 50.00353799547468, 44.599114486149375, 45.78478636060442, 51.885579177311485, 49.80690744944981, 44.58619778496878, 53.076323236737935, 52.03192213603428, 50.711646284375874, 53.232991218566895, 52.635772705078125, 50.69450855255127, 50.2002067565918, 44.587274755750386, 41.47758068357195, 41.44093588420323, 42.16198866707938, 47.290926524571006, 48.838533537728445, 49.035747732434956, 47.973837171282085, 48.796927724565776, 48.12380361557007, 47.56024217605591, 46.34615911756243, 47.96628795351301, 46.0913165637425, 43.195880617414204, 41.13923815318516, 40.353275299072266, 40.697756562914165, 44.29493277413504, 41.23675264630999, 42.580944197518484, 44.22430433545794, 45.94189207894461, 46.52546780450003, 48.37266377040318, 49.52110719680786, 50.93906429835728, 51.45429754257202, 49.797676767621724, 52.48695271355765, 49.19335719517299, 48.16653503690447, 46.34040600912911, 45.21936280386788, 43.58849205289568, 41.959691865103586, 55.85721812929426, 52.97996909277779, 52.58243138449532, 53.13903767721993, 52.38566534859793, 45.68231085368565, 51.07373775754656, 53.98073203223092, 57.20673547472273, 52.47046116420201, 48.04821068899972, 6.082564217703683, 0.3267405315169266, 1.0062963111060006, 2.166435727051326, 0.3391559310257435, 39.14184297834124, 58.88964475904192, 51.353892598833355, 51.910189696720664, 54.09279257910592, 56.33869007655552, 55.55364785875593, 16.440697227205547, 29.58672891344343, 37.00692905698504, 20.01223111152649, 24.388274329049246, 42.17204965863909, 37.45297908782959, 1.5445007341248649, 0.17497791003968033, 0.03863373478608472, 0.0899978925340942, 0.1254770705210311, 0.13139072033975804, 0.026720390122916018, 0.029947370357279266, 0.02615199321215706, 0.06112567787723882, 0.06420394698423998, 0.013597876548634043, 0.020057627465575933, 0.02148952634472932, 0.05752704704978636, 0.07253071160188743, 0.05311313604137727, 0.014420239787016596, 0.03399179869198373, 0.11140610663486378, 0.13069508623863968, 1.948588422366551, 43.10893086024693, 49.054431438446045, 26.908670834132604, 31.793303080967494, 47.014898913247244, 27.434706790106638, 6.459505294050489, 48.33650534493582, 66.11905084337506, 40.3759194782802, 55.78691278185163, 61.121836934770855, 57.153088433401926, 58.030388832092285, 2.0089491605758667, 0.7523376984255654, 0.1456352195569447, 3.3822569208485738, 10.630640489714485, 35.70117494038173, 66.89203793661935, 61.31243297031948, 66.00365516117641, 56.64670719419207, 62.23359039851597, 60.71511023385184, 57.37442329951695, 58.9844320842198, 58.22925322396414, 53.93243162972586, 54.97714539936611, 51.54998465946743, 51.44726249149868, 47.057116167885916, 55.13544968196324, 59.04173387799944, 56.03614813940865, 55.893004826136995, 56.399577140808105, 53.07485021863665, 54.32693992342268, 54.67680604117257, 52.180856772831504, 53.433606556483674, 51.729633808135986, 45.70170675005232, 45.43657391411917, 45.30462414877755, 41.786111967904226, 40.686361517224995, 43.48172950744629, 51.50229917253767, 51.2304995400565, 51.907285349709646, 52.0793331691197, 51.14523819514683, 49.21352086748396, 51.904026644570486, 49.008767877306255, 50.27927030835833, 47.68735252107893, 45.95042099271502, 44.88025597163609, 49.91914517538888, 49.857525076184956, 52.08022253853934, 51.6362430708749, 52.298124994550435, 52.04693719318935, 52.72014815466744, 53.285092285701204, 50.750309535435264, 43.565153053828645, 49.33918251310076, 51.10445921761649, 50.56269427708217, 47.34478896004813, 47.339428424835205, 53.242173263004844, 51.3201938356672, 48.56104333060128, 54.50887155532837, 52.983290331704275, 52.39183534894671, 55.24989693505423, 53.79189736502511, 53.70719535010201, 53.46100677762713, 45.95746994018555, 43.040574482509065, 43.710658754621235, 46.70508221217564, 49.76027808870588, 50.145461899893625, 50.160362311771934, 49.353919642312185, 50.8729521887643, 51.71998970849173, 50.672475814819336, 49.32963916233608, 51.02963406699044, 49.23433767046247, 44.31560019084385, 42.56023856571743, 41.823486328125, 43.24510513033186, 44.86071068899972, 42.25478185926165, 42.05755376815796, 46.445473194122314, 46.12265988758632, 49.02272680827549, 50.1198091506958, 50.60319880076817, 52.31326164518084, 52.55156748635428, 50.478572436741416, 54.28054680143084, 50.51654781614031, 52.00217342376709, 48.54399592535836, 47.22563082831246, 44.783526624952046, 44.7601181438991, 56.77471385683332, 55.497544629233225, 54.759468759809224, 56.533726011003765, 56.0527161189488, 48.59035430635725, 53.49672051838466, 54.427070413317, 58.296011516026084, 56.16081271852766, 51.182414531707764, 7.680014133453369, 0.31554899205054554, 2.5763944259711673, 4.917778628213065, 0.2214646970054933, 46.95532853262765, 62.32529272351946, 55.32474640437535, 57.60418633052281, 60.18968745640346, 62.1570907320295, 61.254436356680735, 19.64544439315796, 28.68722380910601, 39.636155196598594, 27.306884254728043, 29.84516716003418, 45.98183727264404, 40.269365378788535, 1.3521230284656798, 0.10299193992146424, 0.03845652179526431, 0.0782417237226452, 0.065642454794475, 0.08077057623969656, 0.03157741842525346, 0.03670535522646137, 0.06888790814472096, 0.24973093239324434, 0.09549067422215428, 0.10123373355184283, 0.08056198100426368, 0.2506376180265631, 0.11759471919919763, 0.16150885421250546, 0.12180574823703084, 0.2268669078392642, 0.1444586126932076, 0.2430475524493626, 0.2247258855828217, 3.3702756209032874, 63.593318121773855, 56.63552059446062, 44.596689564841135, 28.974392856870377, 62.63624545506069, 32.15654795510428, 8.754357627459935, 55.61875595365252, 70.7969741821289, 46.73102331161499, 59.359252657209126, 65.5200674874442, 60.017747334071565, 65.07218660627092, 3.4711908229759763, 1.76228181379182, 0.4453703287456717, 4.102218619414738, 11.40928862776075, 39.838344301496235, 69.37472656794957, 63.33254528045654, 68.59941182817731, 58.642872537885395, 64.13683400835309, 62.86359746115548, 61.05865001678467, 61.241908754621235, 60.290714263916016, 55.75342246464321, 57.68495566504342, 52.841286523001536, 51.61966119493757, 45.66434628622872, 57.47775343486241, 60.5719495500837, 59.466115951538086, 58.854403495788574, 59.875357900347026, 54.52674579620361, 57.022649901253835, 56.37396955490112, 52.828053678785054, 54.911363329206196, 53.56837381635393, 49.42394011361258, 49.091107504708425, 47.17043433870588, 45.266530650002615, 43.071883065359934, 45.747009004865376, 55.63672399520874, 54.09535993848528, 55.43573692866734, 55.18042884554182, 53.972831930433, 52.075598512377056, 53.50070183617728, 52.39738695962088, 54.924422468457905, 51.117226532527376, 48.740953036717, 49.48811367579869, 53.59440524237496, 51.372861180986675, 55.12996755327497, 53.85621336528233, 55.15878868103027, 53.35519960948399, 54.857038838522776, 55.88338851928711, 53.53274692807879, 46.03285442079817, 53.52349540165493, 53.83606358936855, 54.61033262525286, 49.09432104655674, 48.2442923273359, 55.93294307163784, 53.92780760356358, 50.91613176890782, 59.515851157052175, 54.89236348015921, 55.61942992891584, 59.27634675162179, 58.7803704398019, 56.675729819706504, 56.375831672123496, 48.297327927180696, 45.22942379542759, 48.63979421343122, 49.81013836179461, 54.37056071417672, 53.65834256580898, 55.61058834620884, 53.32324137006487, 55.89121566499983, 54.83070169176374, 55.416709286826, 51.846665791102815, 55.09789119447981, 50.90828030450003, 47.678781918116975, 44.73902341297695, 43.92769615990775, 44.35854353223528, 46.68471009390694, 43.94960035596575, 45.665027209690635, 48.05303621292114, 48.436142512730186, 50.28907074247088, 51.549724102020264, 52.0281457901001, 52.60198361533028, 53.88123035430908, 51.284271648951936, 55.252801282065256, 52.075153827667236, 52.14663342067173, 49.49681282043457, 48.28291041510445, 48.22779035568237, 49.92426599775042, 58.69713796888079, 57.90944848741804, 54.38713216781616, 57.45935113089425, 55.581204414367676, 50.36193650109427, 57.08409629549299, 56.712253025599885, 57.644395555768696, 56.62367044176374, 53.677436215536936, 12.589231712477547, 0.34351551852055956, 3.04749054142407, 6.706416479178837, 0.9064244787607874, 53.71829857145037, 69.10082857949394, 60.238568033490864, 63.39389092581612, 64.97068037305559, 66.26903465815953, 66.58682441711426, 24.73622100693839, 36.39167301995413, 50.05611154011318, 31.657792363848003, 39.198967593056814, 52.73517710821969, 56.113405159541536, 4.812902084418705, 0.4572242540972573, 0.14411082278404916, 0.3765613410089697, 0.198672637875591, 0.24891929594533785, 0.11067708182547774, 0.09718082352940526, 0.12279594796044485], [0.019917196161778908, 0.04113647388294339, 0.03997007218588676, 0.06965866964310408, 0.042873421750430546, 0.03993789605530245, 0.04475377120875886, 0.025757245287033062, 0.11486715770193509, 0.041082262327628474, 0.07305192149111203, 0.040743320515113216, 0.22408351648066724, 15.256993430001394, 37.779370716639924, 33.7616582598005, 27.134473391941615, 27.024266277040752, 44.994466985974995, 3.985321257795606, 25.705524240221294, 58.18910305840628, 45.272440092904226, 54.36626672744751, 59.19722066606794, 50.82839339120047, 61.78322206224714, 10.309525149209158, 1.0764864704438617, 0.29155762227518217, 6.3455339925629755, 18.6731847013746, 23.30558865410941, 57.605565547943115, 56.692162309374126, 60.86769267490932, 54.53172418049404, 59.80992671421596, 52.72115911756243, 58.120256832667756, 54.45670100620815, 59.329959051949636, 54.998295715876985, 57.81024210793631, 50.552060059138704, 49.8190598487854, 44.16010298047747, 56.02474961962019, 58.0087799344744, 54.40106678009033, 50.066516467503135, 53.12720142092024, 53.614492484501426, 52.95028291429792, 53.71557487760271, 52.0821020262582, 54.021257400512695, 50.84038250786917, 48.69900328772408, 46.18967178889683, 45.3543141910008, 45.17923695700509, 41.97317484446934, 41.15161984307425, 46.081842694963726, 49.871629919324604, 51.19520616531372, 48.88547556740897, 50.24187510354178, 49.22481516429356, 47.718073981148855, 48.34258849280221, 44.04945639201573, 42.748871735164094, 39.86674853733608, 44.20156288146973, 46.04669523239136, 46.186725752694265, 49.99895913260323, 47.97207580293928, 49.663107531411306, 47.88736336571829, 51.79661444255284, 47.52358348029, 43.096528325762065, 40.81719957079206, 44.675409180777415, 50.03506544658116, 51.430374894823345, 46.10022415433611, 48.17703376497541, 50.86994709287371, 48.26380286897932, 43.61774744306292, 47.798190185001914, 54.56611428941999, 51.62487581798008, 51.80853060313633, 52.36498403549194, 51.925079686301096, 51.50374787194388, 48.00383949279785, 41.74949148723057, 39.01817199162075, 40.61377021244594, 46.48719712666103, 47.39209924425398, 47.14649779456002, 47.458520548684255, 46.842058999197825, 48.12009675162179, 48.22979143687657, 50.46328639984131, 47.217067173549104, 45.515946660723, 40.13899632862636, 42.052182810647146, 38.85583080564226, 41.598844119480674, 44.43866321018764, 42.94710384096418, 43.189234665461946, 44.52490077699934, 43.36477395466396, 45.51543596812657, 46.696247577667236, 49.331376211983816, 50.0277350970677, 50.11437913349697, 51.21940674100603, 50.92249631881714, 50.665235791887554, 48.46875735691616, 48.53804131916591, 47.068417412894114, 51.06758165359497, 47.90975046157837, 42.47297266551426, 57.20430360521589, 50.01186888558524, 56.45619453702654, 54.556143624441965, 60.25672367640904, 48.65254415784563, 53.423034872327534, 45.38041509900774, 46.93502589634487, 20.858796153749736, 9.182399664606367, 8.057699101311819, 5.309024742671421, 2.899369929518018, 0.9563055421624864, 51.68958439145769, 51.073442459106445, 52.49332421166556, 53.95560734612601, 51.21785729272025, 57.54826028006417, 49.54398761476789, 19.454238653182983, 39.78540597643171, 30.782319341387065, 35.923777852739605, 34.29295226505825, 49.33659083502633, 25.530394894736155, 0.10793438221194915, 0.13668940030038357, 0.04817391339955585, 0.04238897149584123, 0.0554903902645622, 0.05855691393039056, 0.03469256591051817, 0.050391067285090685, 0.015062659779297454, 0.02468838299890714, 0.04656911701230066, 0.04042990179732442, 0.053851148047085316, 0.02506676296304379, 0.07067227203931127, 0.02487067143166704, 0.03529169197593417, 0.03789399590875421, 0.011567447866712297, 0.07760561749871288, 0.07673806976526976, 0.4197080529161862, 21.379155431474956, 52.781629289899556, 31.590137754167827, 29.478507246289933, 36.58162634713309, 47.483791146959575, 6.581380605697632, 27.382385117667063, 68.1009133202689, 47.070741585322786, 61.13277339935303, 64.55853407723563, 55.638631275721956, 69.04288755144391, 12.847048095294408, 1.4863629852022444, 0.24949710922581808, 7.936519912311009, 27.736692871366227, 29.438961574009486, 63.846955163138254, 57.82125847680228, 65.90815217154366, 58.25001444135393, 62.79808289664132, 56.34449182237898, 60.86759540012905, 57.04556506020682, 61.67536517551967, 55.962396485464915, 57.25343084335327, 50.61028248923165, 51.555703026907786, 48.164516585213796, 58.07512133462088, 56.73846857888358, 55.79853711809431, 52.03072704587664, 55.54826300484793, 54.64075878688267, 55.606106758117676, 54.12335770470755, 54.62727580751692, 54.92425223759243, 53.84890733446394, 48.85699142728533, 47.49806274686541, 45.60350785936628, 45.78654425484793, 43.83044917242867, 41.23701320375715, 47.838288239070344, 52.98133441380092, 51.284254278455464, 50.576208523341585, 53.10964332308088, 50.82547862189156, 50.20399699892317, 49.134189810071675, 46.456552096775596, 43.68530477796282, 42.965429714747835, 44.17911672592163, 51.18330042702811, 50.558733803885325, 53.86565249306815, 51.37639781406948, 54.51410354886736, 49.4468344279698, 52.575893129621235, 50.10223715645926, 47.676065172467915, 43.053043024880544, 47.26170587539673, 50.59476021357945, 54.83236925942557, 48.57026359013149, 48.5979208946228, 52.74576963697161, 50.26147944586617, 45.01279633385794, 49.78896025248936, 54.37389932359968, 53.54175179345267, 51.608901909419465, 51.80011633464268, 55.38648114885603, 53.60924312046596, 50.028051240103586, 44.292570386614116, 41.79127100535801, 43.719694886888774, 47.194756507873535, 50.07482303891863, 50.78592252731323, 49.89135932922363, 51.43473488943917, 49.45490823473249, 51.79289715630667, 52.476804869515554, 48.98871885027204, 46.46718284061977, 43.31407642364502, 43.836042472294395, 41.40335307802473, 43.008786473955425, 45.61175537109375, 43.062666279929026, 43.29939488002232, 46.67772715432303, 45.34495496749878, 46.69453484671456, 47.103815010615754, 50.95133481706892, 50.69118731362479, 51.86571775163923, 53.46580798285348, 51.61002056939261, 52.40010717936924, 49.56431456974575, 48.92200919560024, 49.38746207101004, 49.51542009626116, 50.52228702817644, 46.314711570739746, 61.55329922267369, 52.3338873726981, 57.388931138174875, 56.203349590301514, 62.916778973170686, 51.98708541052682, 56.994266510009766, 48.0354711668832, 51.61123303004673, 24.720109871455602, 14.946167503084455, 12.08127496923719, 7.4454507657459805, 3.027723784957613, 1.8510724093232835, 60.389378683907644, 58.689349038260325, 58.20808553695679, 58.7985052381243, 57.52904156276158, 62.22785118647984, 54.38074677331107, 23.354552609579905, 42.20834009987967, 36.62478508268084, 37.69639880316598, 34.033652441842214, 56.357266085488455, 27.553272587912424, 0.10388508878116097, 0.07686410764498369, 0.02399892356645848, 0.09171837235667876, 0.08795396863882031, 0.0165366481856576, 0.023795223961185132, 0.20106731009270462, 0.04832392392147865, 0.07217328649546419, 0.17859258822032384, 0.20730319619178772, 0.11333651840686798, 0.17241467615323408, 0.2868973080601011, 0.11810325405427388, 0.17526980223400251, 0.21519696047263487, 0.10085504315793514, 0.1126799068546721, 0.11773604447288172, 0.5442717203072139, 40.245835304260254, 60.92057541438511, 49.35364866256714, 38.910669463021414, 43.8050674029759, 62.13998426709856, 7.190193925585065, 34.20274380275181, 70.78719806671143, 52.65330301012312, 64.90344960348946, 71.08471993037632, 57.67365094593593, 73.42089884621757, 13.777243392808096, 1.4812706070286887, 0.7128894637737955, 9.953285796301705, 35.73913989748274, 33.27593054090227, 65.99438626425606, 60.186790057591026, 68.58700929369245, 59.67679922921317, 65.62706974574498, 59.516142981392996, 65.86728286743164, 59.322420256478445, 65.85255963461739, 57.89020545142037, 60.80679171425955, 53.26166296005249, 52.67551292691912, 48.4425174849374, 59.09597151620047, 61.53324672154018, 58.987551825387136, 56.39118024281093, 58.59656279427664, 57.55322476795742, 60.66709818158831, 56.418114934648784, 56.46454974583217, 57.615650858197895, 55.47413962227957, 51.05868795939854, 50.947885036468506, 46.90070179530552, 48.192469188145225, 46.02984932490757, 45.297488348824636, 50.13269458498274, 55.46914039339338, 52.59841571535383, 52.586569036756245, 53.96319825308663, 54.68041910443987, 52.6611579486302, 54.49160875592913, 48.45160225459507, 48.45110545839582, 46.19078697477068, 47.57712629863194, 54.10113736561367, 53.623608521052766, 57.67880998338972, 53.891478947230745, 56.85694578715733, 51.12493208476475, 55.07055698122297, 52.66706044333321, 50.278943743024556, 45.16371815545218, 49.542736939021516, 55.21477031707764, 58.321893555777415, 50.30025386810303, 52.45123897280012, 54.78948150362287, 53.4307473727635, 47.74992104939052, 52.06616633278983, 58.07413469042097, 57.7143361227853, 55.944449288504465, 56.65441622052874, 58.307212012154714, 57.03157833644322, 53.71096474783761, 48.703853130340576, 43.798692430768696, 46.46310077394758, 50.63844701222011, 52.477885314396445, 53.14711148398263, 51.613077776772634, 54.47753865378243, 54.596839223589214, 56.38195998328072, 56.408762659345356, 51.51092536108834, 48.801332882472444, 44.219815799168174, 46.60579940250942, 42.75653559820992, 44.497028078351704, 49.907798767089844, 46.03670024871826, 45.676175594329834, 48.64937230518886, 47.131590434483115, 47.601570061274934, 49.749449321201865, 51.12640510286604, 53.40130090713501, 52.358647278376985, 55.31968464170183, 52.95877708707537, 53.85874250956944, 52.75232178824288, 50.03427335194179, 52.330625193459646, 50.53112861088344, 54.22198738370623, 49.873148100716726, 60.314261708940776, 55.697416509900776, 58.75147288186209, 57.536757537296836, 59.60907513754708, 51.707774775368826, 57.5171879359654, 53.921939849853516, 52.607191290174214, 29.622904709407262, 13.947730473109655, 10.418815970420837, 11.663685628346034, 5.543077852044787, 2.270756197827203, 65.06833730425153, 62.85377965654646, 62.345157623291016, 62.971280642918174, 61.666096278599326, 65.91696943555559, 60.27816581726074, 28.856924874441965, 51.06862040928432, 44.108863489968435, 49.05986840384347, 46.800630365099224, 61.03677708762032, 42.46747664042881, 0.3236546628177166, 0.2642050342900412, 0.12701011183006422, 0.1608340104243585, 0.14124593936971255, 0.09165448828467301, 0.0969016199399318, 0.23740284677062715, 0.18410120691571916], [0.027573174630690898, 0.019912434542285543, 0.03277473757043481, 0.03630873454468591, 0.03345105377957225, 0.05461397407842534, 0.06578434325222458, 0.02940577727609447, 0.01661112079662936, 0.07040573669863598, 0.08197059934692723, 0.07880381534674338, 0.5285631460802895, 8.466124636786324, 44.13730246680123, 37.36510522024972, 45.52605281557356, 18.100116389138357, 39.60472502027239, 12.685096876961843, 9.621901886803762, 59.38878944941929, 42.464409010750906, 54.64090469905308, 56.263388974326, 53.03466183798653, 54.722372327532085, 23.33823823928833, 1.914807800735746, 0.2848213980240481, 3.006422127996172, 57.48272487095424, 39.5708212852478, 37.28619800295149, 58.87005083901541, 56.164040156773154, 52.443696703229634, 53.88672290529524, 56.170053822653635, 54.672268867492676, 55.35158034733364, 53.74166536331177, 51.775373799460276, 51.1454188483102, 51.29594462258475, 45.29970482417515, 51.40148775918143, 47.54964617320469, 49.05084269387381, 55.778227533612935, 43.70698663166591, 54.6139943259103, 50.78604064668928, 52.92158685411726, 53.72556986127581, 53.072001457214355, 48.98899677821568, 49.96664653505598, 47.27651596069336, 45.71888617106846, 46.53177676882063, 46.27963011605399, 43.41774007252285, 41.056783880506245, 40.94378880092076, 49.51120948791504, 50.05113662992205, 50.969587734767366, 50.84429781777518, 49.36007227216448, 50.00185305731637, 47.63886104311262, 44.5771164894104, 42.62162937436785, 43.544485637119834, 45.47364255360195, 47.959551674979075, 49.5563554082598, 48.93451247896467, 49.119577748434885, 49.038863999503, 48.04020983832223, 47.65544639314924, 43.674958910260884, 41.46757527760097, 41.981571742466514, 48.512298243386404, 49.50314957754952, 51.44154759815761, 45.794677121298655, 48.79509687423706, 49.9670147895813, 46.82383040019444, 42.9851313318525, 43.42803382873535, 49.25851392745972, 50.55507557732718, 51.76386758259365, 49.96036883762905, 50.56233297075544, 49.72546761376517, 49.34926782335554, 44.35005978175572, 39.56816012518746, 38.574977670397075, 40.147445338112966, 48.058174405779155, 47.688780375889365, 48.54433638708932, 47.94378273827689, 47.13046135221209, 48.346788678850444, 47.39650092806135, 46.19826323645455, 43.860079765319824, 37.466729572841096, 38.99162292480469, 40.07476370675223, 42.5321226801191, 43.88723679951259, 44.81882694789341, 42.65008919579642, 43.88764674322945, 44.060156617845806, 44.93460825511387, 45.10808392933437, 48.953859737941194, 47.505153383527485, 50.661198888506206, 48.11756065913609, 51.463552543095176, 48.99913419995989, 47.82019860403878, 47.291603973933626, 49.26418365750994, 44.660908290318076, 55.26394271850586, 46.41998372759138, 49.89965547834124, 53.02571603230068, 53.17883695874895, 50.637220655168804, 53.431584630693706, 53.849289485386436, 46.63766384124756, 45.09232888902937, 32.861501761845176, 23.308242865971156, 43.16865757533482, 19.625371047428676, 1.6138781713587897, 1.7550579671348845, 14.144975066184998, 53.18026828765869, 52.03097023282732, 52.44804974964687, 53.66701391765049, 45.95064680916922, 68.66717760903495, 25.944689920970372, 22.400061198643275, 30.73640217099871, 27.36765146255493, 30.028762885502406, 31.227466106414795, 51.13922452926636, 12.507500920976911, 0.25240167336804525, 0.0781366050775562, 0.09677954470472676, 0.026034621920968806, 0.06694172721888338, 0.03088362654671073, 0.03677446062543562, 0.035267366495515616, 0.08804402380649533, 0.08334865647235087, 0.06235160066613129, 0.0288635701207178, 0.10940920521638223, 0.032728281670383046, 0.073538505738335, 0.055631545904491625, 0.04836023911567671, 0.0133706919981965, 0.061479072485651286, 0.04800015075930527, 0.1301759798079729, 0.4828197349395071, 12.344726341111318, 58.46354648045131, 41.86877816064017, 45.55324806485857, 32.96149328776768, 38.64698532649449, 19.495794091905864, 11.595783489091055, 64.84967749459403, 44.60519068581717, 58.888421876089915, 64.04869610922677, 57.025033133370535, 62.936810629708425, 29.450217655726842, 1.9071091966969627, 0.31303792393633295, 4.998591388974871, 65.90783950260708, 45.76381322315761, 44.04321343558175, 60.50899192265102, 58.71031870160784, 56.01485538482666, 57.74705171585083, 56.94834933962141, 56.60727269308907, 57.832361698150635, 54.83632625852312, 53.39207369940621, 54.802790778023855, 49.913760321480886, 48.56814438956124, 52.752710887363975, 47.61260380063738, 53.247860363551546, 57.682322297777446, 47.472257137298584, 57.152511732918875, 53.30985219138009, 55.467445032937185, 54.37713371004377, 54.396731104169575, 50.49922595705305, 51.32616581235613, 47.38095433371407, 47.718511717660085, 46.81795917238508, 45.17709691183907, 44.27618306023734, 41.413407121385845, 42.95728990009853, 50.237643650599885, 51.289948327200754, 52.86098119190761, 51.92697654451643, 50.65331268310547, 51.61927556991577, 48.66432135445731, 47.346915108816965, 44.352331842694966, 44.85811901092529, 48.632126876286094, 51.88870586667742, 53.10335520335606, 53.2651926449367, 51.93908378056118, 51.29277624402727, 52.453462396349224, 52.046614101954866, 45.00997536523001, 44.1722206388201, 43.90232481275286, 50.69044733047485, 53.313625063214985, 52.36195114680699, 47.383462633405415, 50.056802885872976, 51.907740456717356, 49.81884445462908, 44.69057362420218, 45.033679144723074, 50.76303516115461, 52.56176744188581, 52.63889592034476, 53.14570099966866, 52.0012458392552, 50.80780240467617, 50.751786027635845, 45.992026805877686, 42.45594610486712, 42.16807876314436, 43.83860288347517, 50.81105068751744, 50.08263628823416, 49.768692357199534, 49.65620797021048, 48.09786251613072, 50.65088776179722, 50.78555079868862, 48.31165163857596, 45.56230851582119, 38.86202165058681, 40.93162597928728, 40.151808806828086, 44.44647298540388, 44.47176442827497, 45.755951336451936, 43.18328700746809, 44.46194314956665, 44.044891425541465, 45.94095059803554, 47.30454846790859, 49.16753421510969, 49.231704303196494, 52.51018401554653, 49.936310700007844, 54.078548771994456, 50.51451199395316, 52.450582368033274, 50.83256231035505, 51.568751743861604, 46.213212285723, 54.53393370764596, 50.368169035230366, 51.43030888693673, 56.00982141494751, 57.397032737731934, 54.67620849609375, 55.77785233088902, 55.29363931928362, 50.54671342032296, 49.489159379686626, 37.79126603262765, 28.705374240875244, 48.72683777127947, 18.400566918509348, 1.9247452446392603, 1.9067476732390267, 18.358082158224924, 60.733175550188335, 57.7868892124721, 57.64660855701992, 57.39993361064366, 50.61034849711827, 73.46725722721645, 30.767693383353098, 30.763983045305523, 34.13736472811018, 33.59759392057146, 31.95105845587594, 32.631773471832275, 57.87316499437605, 11.675088490758624, 0.3097058284495558, 0.0883052394326244, 0.048572854671095095, 0.0962220196213041, 0.11750124421502862, 0.05947013385593891, 0.018819943968472735, 0.024826324079185724, 0.06336679083428212, 0.12201460131577083, 0.16568276738481863, 0.11126979573496751, 0.23810483195952006, 0.16592615789600781, 0.19776676648429461, 0.20469451402979238, 0.13513849994965962, 0.2273572850972414, 0.15582522776510033, 0.13590710370668344, 0.36557219496795107, 0.795047460922173, 18.776923043387278, 70.57682745797294, 53.75979321343558, 61.8999240057809, 30.67964928490775, 56.49301651545933, 18.16516195024763, 16.31330895423889, 70.8276365825108, 54.6243679864066, 62.7298515864781, 67.35066073281425, 60.686191831316265, 67.74763216291154, 31.082623958587646, 2.4838170622076308, 0.3951562132154192, 9.425171460424151, 75.61425059182304, 52.30042484828404, 51.54653140476772, 62.31095858982631, 62.69927256447928, 57.1184447152274, 60.51132651737758, 60.42743396759033, 58.65387848445347, 60.37702478681292, 56.92924526759556, 55.26368563515799, 57.427792412894114, 50.9157600402832, 50.60435220173427, 50.410254274095806, 50.573971203395296, 55.24501582554409, 61.30531106676374, 50.97242259979248, 60.531170572553364, 57.49937275477818, 57.79012359891619, 57.28808150972639, 56.04685183933803, 52.82425648825509, 53.9684476171221, 49.58765009471348, 51.06799507141113, 48.88293947492327, 48.509949752262656, 45.773985385894775, 43.61406142371041, 43.533382415771484, 52.92251443862915, 52.77854776382446, 55.17355707713536, 56.65053217751639, 54.657920837402344, 54.3607394354684, 52.50092206682478, 51.006409713200156, 48.295125348227366, 48.2908730506897, 51.45152521133423, 55.54011276790074, 56.592570304870605, 57.69362701688494, 55.14803981781006, 54.456353596278596, 54.172207014901296, 51.861329964229036, 48.89515093394688, 47.37081343787057, 47.84078959056309, 53.60036679676601, 55.169655663626536, 55.587634972163606, 51.170015471322195, 52.801257950919016, 52.635248116084504, 51.54891116278512, 48.114152567727224, 47.63370895385742, 51.74777902875628, 53.799578598567415, 57.08909205027989, 54.406444685799734, 53.98534563609532, 55.44082995823452, 54.896577562604634, 48.51116221291678, 44.963245255606516, 44.56084380831037, 45.11892311913626, 53.76770373753139, 55.91180665152413, 54.3041672025408, 53.760151045663015, 52.77915573120117, 55.54553583690098, 52.392606598990305, 52.48987095696585, 46.854124546051025, 41.18215717588152, 43.50202866962978, 42.81505332674299, 45.50498935154506, 46.19501495361328, 49.329437664576936, 45.252519607543945, 46.440713678087505, 46.76817880358015, 47.184448855263845, 48.289643219539094, 51.576686586652485, 52.06028468268258, 55.5336856842041, 49.830090114048545, 54.40707002367292, 53.751507486615864, 52.73718513761248, 51.74794231142317, 52.372300488608225, 47.98869589396885, 54.25742319652012, 54.47237614222935, 51.98220777511597, 55.881085191454204, 60.58451189313616, 54.523025035858154, 57.44322436196463, 55.35899060113089, 53.94741889408657, 53.79479823793684, 42.70108897345406, 35.51337555476597, 52.072134835379465, 23.85757613182068, 4.759947691644941, 2.620054300342287, 19.04026845523289, 66.30080877031598, 61.200018065316335, 64.00697912488664, 60.29121453421456, 57.846647194453645, 78.10614558628627, 36.60733815601894, 31.124466010502406, 42.24405384063721, 38.00876896721976, 42.97733892713274, 43.5245304107666, 68.3996580668858, 21.942564010620117, 0.39242272132209366, 0.18402576739234583, 0.15300158570919717, 0.14854325779846736, 0.18831604932035717, 0.13695075841886656, 0.12755471760673182, 0.24289455637335777, 0.19989381091935293], [0.02620376373774239, 0.05017294202532087, 0.06733301800808736, 0.009411056792097432, 0.0164322284316378, 0.01489306504039892, 0.057637505765472136, 0.009519273797715349, 0.03335346348051514, 0.08915369997599296, 0.007957539787249905, 0.05963457003235817, 0.12286764197051525, 2.071545264550618, 42.40959814616612, 35.08972651617867, 37.208548409598215, 18.7675655569349, 33.10764169692993, 23.321963821138652, 4.068406513759068, 52.75160959788731, 54.88909087862287, 54.899294308253694, 57.36987222943987, 53.86901542118618, 50.84670884268624, 37.00338200160435, 0.7364653529865401, 0.7431415947420257, 0.05529468380180853, 18.416085720062256, 32.47990322113037, 31.336295740944998, 43.35645696095058, 53.43666723796299, 54.40179981504168, 52.489700726100374, 53.823358808244976, 52.471437386104036, 52.03510441098894, 54.03970486777169, 51.9388301713126, 52.830318791525706, 45.71550587245396, 45.91007627759661, 49.285601479666575, 43.5588823046003, 50.9246050970895, 43.3981739452907, 46.70021152496338, 52.25217655726841, 51.94640023367745, 51.8838004384722, 53.202954156058176, 50.47895458766392, 47.4477994782584, 47.81696421759469, 51.48243774686541, 49.56630522864205, 44.77193355560303, 46.2901496887207, 43.83856119428362, 40.121837752205984, 40.27698755264282, 43.03157656533377, 46.459115982055664, 49.58661481312343, 51.22184208461216, 49.96998167037964, 48.08372293199812, 45.04556403841291, 43.68323768888201, 42.80761528015137, 44.517813614436555, 46.5308005469186, 49.98346812384469, 47.29299013955252, 47.52046026502337, 50.18766178403582, 48.736478396824424, 47.84068884168352, 40.36904076167515, 40.114319801330566, 42.715232031685964, 46.89781134469168, 49.0679908479963, 50.55838291985648, 49.60662909916469, 48.63984285082136, 50.201474802834646, 49.735455649239675, 45.80227845055716, 40.956118379320415, 42.363246713365825, 46.70714930125645, 50.0281902040754, 51.66600567953927, 51.48024211611067, 50.13355616160801, 50.62450892584664, 48.22778688158308, 48.96058906827654, 41.50932352883475, 38.52427666527884, 39.27073206220354, 46.485314164842876, 46.51221064158848, 48.319999899183, 49.530098165784565, 47.6655455998012, 47.62099722453526, 46.159405435834614, 45.9312231200082, 39.736511502947124, 37.1034117426191, 40.00648723329817, 41.124080657958984, 42.72809314727783, 43.63094207218715, 43.81196001597813, 43.11431918825422, 41.401504857199534, 43.86001375743321, 44.10038668768746, 43.970726353781565, 46.22038977486746, 47.49320943014962, 48.52564920697893, 51.52224050249372, 51.26578596660069, 50.601916858128135, 48.08843033654349, 47.24576323372977, 48.21397386278425, 47.00031117030552, 49.04697949545724, 52.89720909936087, 43.07238333565848, 51.18329695292881, 47.22930295126778, 53.15500463758196, 47.85507161276681, 49.68086017881121, 44.89343670436314, 36.04633017948696, 23.171573536736624, 13.409868683133807, 16.4809307711465, 1.0819527485540934, 1.3913611343928745, 2.7486650219985416, 48.500347341809956, 50.460211821964805, 52.29205574308123, 55.1187288420541, 48.86272716522217, 57.701058115277974, 44.023411069597515, 8.132770912987844, 34.0917706489563, 22.188436440059117, 35.913049834115164, 25.92574565751212, 38.90336690630232, 44.376330920628135, 3.289147151368005, 0.3839717576546328, 0.060537876561284065, 0.06132684315421751, 0.0660670277263437, 0.04277851505737219, 0.017626270252679075, 0.020031554757484367, 0.028306939007182206, 0.05790860764682293, 0.0411848127176719, 0.0168863142441426, 0.018903491985318915, 0.03745586923988802, 0.03838087531871029, 0.037384880906237025, 0.048354281578212976, 0.022325688440884863, 0.024499126011505723, 0.027475360415077636, 0.02329424289720399, 0.07105565111019782, 0.09944045370710747, 2.625005977494376, 49.60477045604161, 42.657047816685264, 34.145035539354595, 27.804729631968907, 38.41273375919887, 26.67947060721261, 8.313569988523211, 56.15343720572335, 61.82550185067313, 59.247053146362305, 64.98568848201207, 58.58814852578299, 57.31733342579433, 40.31253801073347, 1.4893474536282676, 0.5957465267607144, 0.9330067123685564, 21.96324532372611, 39.06468670708792, 35.05997085571289, 50.78503315789359, 55.73802178246634, 57.173630782536094, 53.27137654168265, 55.909023897988455, 54.20144156047276, 54.14123889378139, 56.66591548919678, 52.2752480506897, 53.658544063568115, 45.96639837537493, 50.16777951376778, 50.121303013392854, 45.009568895612446, 52.23925985608782, 46.29192842755999, 48.732184410095215, 54.36018010548183, 53.091862882886616, 54.57864883967808, 55.661921637398855, 51.105581351688926, 49.89350632258824, 50.04892710277012, 53.963879176548545, 50.10673611504691, 46.281825746808735, 47.34513289587838, 45.26558222089495, 42.75095272064209, 41.928827966962544, 43.66446713038853, 47.35719149453299, 52.79914569854736, 52.56849329812186, 54.702100958142964, 49.57228067943028, 48.346034799303325, 45.4001966203962, 45.453079359872, 46.622534138815745, 47.894249030521934, 51.96111304419381, 50.38534845624651, 52.94542612348284, 52.79656444277082, 51.43569721494402, 50.413981982639854, 45.77076142174857, 41.73160334995815, 42.50397205352783, 46.43739938735962, 50.95997142791748, 53.833246094839915, 50.65699175425938, 49.83080230440412, 54.402157647269114, 51.71382318224226, 47.71616322653634, 44.400531496320454, 44.30439622061593, 49.297580174037385, 53.41382850919451, 54.0364739554269, 53.252859592437744, 53.4554169518607, 51.774567808423726, 51.153926917484824, 51.35425043106079, 42.986062390463694, 40.664870738983154, 43.373893465314595, 51.222262450626914, 48.489893777029856, 49.728715896606445, 49.318938936506, 50.25834928240095, 50.666663646698, 48.549634388514924, 49.24540267671858, 40.881265435900005, 39.92123283658709, 41.004293714250835, 41.99433558327811, 43.822573389325825, 45.85141263689314, 45.076427936553955, 45.27946472167969, 42.72651938029698, 45.97474316188267, 45.924538952963694, 46.17365619114467, 47.20729800633022, 49.93945823396955, 51.327027388981406, 54.087869780404226, 53.44951793125698, 52.80393648147583, 48.72925921848842, 50.98029490879604, 48.17923634392874, 49.52685335704258, 50.059999057224815, 53.53389685494559, 45.4706027167184, 52.23326703480312, 49.99276828765869, 55.679927894047324, 51.67383977345058, 52.46053218841553, 47.026391233716694, 41.194389479500906, 27.06426531927926, 21.029727050236293, 12.861832124846321, 2.05014112165996, 1.8662366356168474, 7.467914291790553, 57.83998039790562, 56.838550431387766, 57.77983679090227, 61.45812974657331, 52.841884068080354, 64.12088094438825, 44.705557414463584, 12.699583871023995, 36.89952727726528, 23.4416343825204, 42.45631435939244, 28.78255135672433, 43.721324239458355, 49.62155382973807, 3.254965054137366, 0.6089276937501771, 0.08050243277102709, 0.05014246562495828, 0.040074298557426245, 0.016908426004062806, 0.029549786155777316, 0.024532669390152608, 0.04321821592748165, 0.08718724442379815, 0.1631540030773197, 0.12221068436545984, 0.12187551520764828, 0.2051043084689549, 0.12000198502625738, 0.21942648637507642, 0.1603879550737994, 0.09181891089039189, 0.0852611752759133, 0.18286818665053162, 0.17811583594552108, 0.22063550007130417, 0.3921155078070504, 5.090681076049805, 68.9190011705671, 49.85677467073713, 56.80539015361241, 27.64269416672843, 52.37437799998692, 31.1273912021092, 8.550386309623718, 61.47081020900181, 66.09383583068848, 65.62094838278634, 67.26016044616699, 63.38974979945591, 61.23994241441999, 47.869572503226145, 2.54323262827737, 1.4023225690637315, 1.8662607371807098, 35.77279002325875, 50.55901868002755, 40.92749874932425, 54.92741714205061, 58.42617212023054, 60.68363489423479, 52.875843388693674, 57.72819083077567, 54.842027255467, 56.86485283715384, 57.11510610580444, 54.1308582850865, 53.61032356534685, 48.44725268227713, 49.95800297600882, 48.652134214128765, 47.08660779680525, 52.21443394252232, 48.66107307161604, 48.069228989737375, 57.81779479980469, 58.902700424194336, 57.72811092649187, 58.5563257762364, 53.8535452570234, 51.90718807492937, 51.87004995346069, 57.29410212380545, 52.21862718037197, 48.72984634126936, 49.690813473292756, 46.41655479158674, 44.84282602582659, 43.23042011260986, 46.927296025412424, 49.10693897519793, 55.54134259905134, 56.31782463618687, 55.932185717991416, 52.255789620535715, 51.207136222294395, 50.127083914620535, 49.86416060583932, 48.8779993057251, 51.51920761380877, 56.44927760532924, 51.81344992773873, 53.452213832310264, 54.742251123700825, 53.6340377671378, 54.60147367204939, 48.139075756073, 45.62896258490426, 47.15257746832711, 52.47598498208182, 53.84672212600708, 58.6092015675136, 54.015983717782156, 53.53934076854161, 56.75798259462629, 53.46389028004238, 48.20811653137207, 46.48570326396397, 47.900776863098145, 51.36929675510952, 54.19259997776577, 56.767717020852224, 56.20725447790963, 56.082895619528635, 54.05952113015311, 53.35169424329485, 55.58010312489101, 46.7201042175293, 42.83549492699759, 46.167354175022666, 55.85932690756661, 52.06246641704014, 53.000858851841514, 53.044733251844136, 54.14955241339547, 52.890000343322754, 51.55317735671997, 52.08074712753296, 44.444537912096294, 41.79196582521711, 41.590818950108115, 44.246743542807444, 46.00467600141253, 47.64098719188145, 47.15276854378836, 47.625186988285606, 44.87627812794277, 49.783707414354595, 47.63540778841291, 47.84586872373308, 48.61738279887608, 51.07452985218593, 53.789409909929546, 55.1471608706883, 55.86703593390328, 55.49398715155465, 51.30206945964268, 54.40151146480015, 49.86412933894566, 52.27211441312517, 49.07221187864031, 55.40135029384068, 46.41280276434762, 52.55340528488159, 51.78643185751778, 55.55632291521345, 49.35277666364397, 52.655950273786274, 49.475318568093435, 44.480553899492534, 35.699288504464285, 37.751185349055696, 18.50908735820225, 4.813841828278132, 2.3269888375486647, 8.391794545309883, 61.90428747449602, 60.2739691053118, 61.416079248700825, 65.52227701459611, 57.66469471795218, 67.87450626918248, 53.340344360896516, 15.12484564099993, 42.32617112568447, 32.4675805909293, 47.98001759392874, 37.85743372780936, 50.72403144836426, 62.62185573577881, 8.31226806981223, 1.0522334575653076, 0.3205005334956305, 0.21382710683558667, 0.2761772690074784, 0.1256935910454818, 0.20518531197948114, 0.11341699944542986, 0.1624051175479378, 0.2650300514485155], [0.08360984495707921, 0.08889888972043991, 0.037078003266027997, 0.04981112679732697, 0.017534494998731782, 0.04036840956125941, 0.0370092744539891, 0.06734263284930161, 0.01685446550670479, 0.025315673356609683, 0.019455088369016136, 0.06248645271573748, 0.04653823349092688, 0.17879272890942438, 16.445750304630824, 43.26949678148542, 37.961618491581504, 32.7226767539978, 22.865897962025233, 48.91548483712332, 5.805265520300184, 24.41239673750741, 73.20352445329938, 44.87877600533621, 57.260431153433665, 55.198372568402974, 53.74353095463344, 54.43325778416225, 8.893553495407104, 1.9446153555597578, 0.31693931030375616, 0.710594929754734, 3.1437782432351793, 33.409593037196565, 40.18160615648542, 46.70529760633196, 51.285550117492676, 50.908686774117605, 54.96286685126168, 50.86766460963658, 54.43743017741612, 49.522319657461985, 50.53896965299334, 44.72946616581508, 49.071367672511506, 56.777861390795024, 52.01865455082485, 50.52376699447632, 48.020178181784495, 45.07394742965698, 51.744965008326936, 45.06484528950283, 56.10801683153425, 51.40448243277413, 50.270067419324604, 47.6242733001709, 48.57495709827968, 48.44946568352835, 48.23981073924473, 49.00310509545462, 49.82703985486712, 45.82764284951346, 45.33664492198399, 43.257681369781494, 41.870310238429475, 38.07147298540388, 41.00659009388515, 46.929550715855186, 50.63687324523926, 49.18126038142613, 47.28348847797939, 45.83317708969116, 43.34584706170218, 45.404667786189485, 47.287164075034006, 50.39495086669922, 49.429356234414236, 49.777120522090364, 47.226895400456016, 48.44207974842617, 45.63858583995274, 42.91054589407784, 40.455010822841096, 40.64357451030186, 45.09742539269583, 47.74977861131941, 46.613324301583425, 50.93982512610299, 48.268010003226145, 47.92920889173235, 50.00187390191214, 48.4214574950082, 46.29850489752633, 41.73384761810303, 41.25372362136841, 42.46644830703735, 45.12922729764666, 49.01979119437081, 50.13939264842442, 51.052757671901155, 50.503808294023784, 50.97419091633388, 49.727593762534006, 46.27521106175014, 40.27273872920445, 40.1112973349435, 40.71969549996512, 47.97663729531424, 47.995772634233745, 47.78200088228498, 48.600255489349365, 49.303531306130544, 45.67023835863386, 41.58258533477783, 36.93087060110909, 40.40791245869228, 39.84462547302246, 43.6403568812779, 44.09261860166277, 43.00105660302298, 45.86257144383022, 43.91941738128662, 41.61283084324428, 43.18588563374111, 41.84014116014753, 45.99323231833321, 46.19136714935303, 46.175209113529746, 48.40387855257307, 49.87817859649658, 49.24838692801339, 49.559971945626394, 46.54991504124233, 43.51077992575509, 43.26765898295811, 43.21227141789028, 46.567316804613384, 50.66540949685233, 45.913237707955496, 49.73104701723371, 46.83290127345494, 47.57276977811541, 48.297404357365195, 46.36835513796125, 38.270462444850374, 36.102683544158936, 15.55278171811785, 4.44406087057931, 0.9991293528250286, 0.9416791498661041, 0.1925086493470839, 35.930312633514404, 50.063799721854075, 52.128095626831055, 54.06173760550362, 48.00257839475359, 34.02970239094326, 63.95896012442452, 26.36227318218776, 19.525026900427683, 37.859799589429585, 22.615352869033813, 33.44680411475045, 18.774350472858973, 48.01389006205967, 31.313154765537806, 0.43029675473059925, 0.04364366416952439, 0.05514477506013853, 0.03361395646684936, 0.04704665978040014, 0.06695138277219874, 0.041078282719744105, 0.019294879465763057, 0.025650813676682965, 0.09801891605768885, 0.03519688706312861, 0.0600859315267631, 0.018059158631201302, 0.010786918856735741, 0.033098388596304824, 0.05751992921744074, 0.11068607919982501, 0.10526804492941924, 0.02603772621867912, 0.07437183495078768, 0.0507272169260042, 0.06586257833987474, 0.04506156487124307, 0.21678418958825724, 20.245885133743286, 57.683986391339985, 37.12107753753662, 39.27681868416922, 33.59805597577776, 46.7095742225647, 8.945995892797198, 27.609163897378103, 79.91126673562187, 50.98660734721592, 63.281663622174946, 61.589040756225586, 58.860080174037385, 62.279858452933176, 11.700010810579572, 1.2848229940448488, 0.30343141513211386, 1.4239484029156821, 3.9609191843441556, 36.57626233782087, 46.3026008605957, 49.497983591897146, 58.347157205854145, 54.305806977408274, 56.396446977342876, 51.84198270525251, 56.28564405441284, 50.538643087659565, 51.09071568080357, 45.90035227366856, 53.03345285143171, 54.891501903533936, 53.08132593972342, 51.44310746874128, 46.262395109449116, 47.31998041697911, 51.85293306623186, 48.300395556858604, 58.90777260916573, 53.664203371320454, 51.273724283490864, 49.69808823721749, 50.82759782246181, 48.898739678519114, 51.41085393088204, 49.59441416604178, 51.58752230235508, 49.0358693259103, 46.80709218978882, 45.2826817376273, 42.33983128411429, 39.84398276465279, 43.33884327752249, 49.472626141139436, 53.32744155611311, 50.62721872329712, 49.286331040518625, 46.47488839285714, 45.00929791586739, 48.12336935315813, 48.24015467507498, 51.75789908000401, 53.25396088191441, 52.950182165418354, 50.69814246041434, 51.64734629222325, 49.90187542779105, 46.01758575439453, 43.34722280502319, 42.772644996643066, 47.783897740500315, 50.982577392033164, 48.97317573002407, 51.3520131111145, 50.45887081963675, 51.23922300338745, 51.84545333044869, 51.08569213322231, 48.172413212912424, 44.449280057634624, 43.18265124729702, 44.322145393916536, 48.4607321875436, 52.456252098083496, 51.28166954857962, 54.40867158344814, 53.53001281193325, 53.21002047402518, 51.69886371067592, 48.733230113983154, 42.655342033931184, 44.05575493403843, 44.813289233616416, 50.332253796713694, 52.15249422618321, 48.96078361783709, 51.270733083997456, 51.565941197531565, 46.71340962818691, 44.34413296835763, 39.089418819972444, 41.97451932089669, 40.838089329855784, 45.19904279708862, 46.48196165902274, 43.820805072784424, 45.96183688299996, 44.21875272478376, 43.75032254627773, 45.047676290784565, 43.28536646706717, 48.139228616442, 48.36129304340908, 47.93971456800188, 51.432435035705566, 52.61727312632969, 52.05327047620501, 52.564640522003174, 50.937132699149, 45.90104709352766, 44.97565821238926, 46.133259364536826, 48.11798449925014, 51.07630164282662, 48.53342424120222, 51.668628624507356, 48.91518953868321, 50.79971122741699, 49.440178053719656, 49.21174907684326, 43.51503917149135, 40.868994917188374, 17.59233856201172, 2.8100477967943465, 0.4760116402591978, 1.7816428605999266, 0.43604777327605654, 46.16208744049072, 55.13419553211757, 56.080964020320344, 58.52054255349295, 52.57406227929251, 36.62609134401594, 68.8986290522984, 30.533275059291295, 22.605731351034983, 37.20184687205723, 26.35600243295942, 40.869012287684846, 18.287172317504883, 51.69048418317522, 33.227963651929585, 0.24693069979548454, 0.1775308166231428, 0.03985899600333401, 0.06714812400085585, 0.0473872063282345, 0.03315549749614937, 0.034324504767677615, 0.07000474285866533, 0.053566679025867155, 0.022814674702073847, 0.1348920153187854, 0.2359380525137697, 0.1390843710729054, 0.1062209252268076, 0.11789099472974028, 0.12189872110528605, 0.25764745473861694, 0.345928959016289, 0.11345864113952432, 0.11792801560035773, 0.11301966290920973, 0.14179259432213648, 0.12530928238161973, 0.3331941323620932, 37.21205030168806, 65.9580888748169, 56.213434900556294, 46.96965571812221, 35.61654935564314, 66.98235062190464, 9.625779850142342, 33.17229468481881, 85.72034290858677, 55.497527258736746, 66.75676345825195, 66.08109283447266, 61.71735313960484, 70.95735250200543, 15.126101527895246, 4.435647904872894, 1.2359611988067627, 1.2947426331894738, 7.245577582291194, 45.0060704776219, 53.950347559792654, 53.463629722595215, 61.77051380702427, 57.589702810559956, 57.28675092969622, 52.671496868133545, 56.84106567927769, 50.98498841694423, 52.13646125793457, 49.59733240944998, 56.68367855889456, 53.80104814256941, 54.199346678597585, 48.43824781690325, 49.54829549789429, 48.77816064017159, 50.77690029144287, 48.76559134892055, 62.69733401707241, 55.2652941431318, 55.368572166987825, 52.49666282108852, 53.51048837389265, 52.069379874638145, 52.38472386768886, 50.878142493111746, 54.572968687329976, 51.29315492085048, 50.52134207316807, 46.9821138381958, 46.18042721067156, 40.671231814793174, 45.453649112156455, 52.74674933297293, 56.67285673958914, 53.78880541665213, 52.279542037418906, 49.83617326191494, 48.13459416798183, 51.01117270333426, 51.07144832611084, 56.54460341589791, 56.575015681130544, 57.065131187438965, 52.23529243469238, 53.20582028797695, 52.839493887765066, 47.26358188901629, 47.16352088110787, 46.44797107151577, 52.603658131190706, 54.4376733643668, 51.98278794969831, 56.68381404876709, 52.7232574735369, 53.421884945460725, 55.858447960444856, 53.99110221862793, 51.58051156997681, 47.06982789720808, 45.839190755571636, 46.29785524095808, 50.24679095404488, 54.87940856388637, 54.32037387575422, 58.185333660670686, 55.97128323146275, 56.936700684683665, 56.657612391880576, 50.78247969491141, 45.28665263312203, 48.26869092668806, 47.15470014299665, 53.62174987792969, 54.292515073503765, 52.83920553752354, 53.78347267423357, 54.75668600627354, 50.94234037399292, 45.96677357809884, 40.956858362470356, 46.247901167188374, 43.38967282431466, 46.871171951293945, 48.52380098615374, 44.59426464353289, 49.69345726285662, 46.413316931043354, 45.01220921107701, 46.304462977818076, 44.88995565686907, 51.80108560834612, 51.17023433957781, 49.75000865118844, 52.712470395224436, 52.574246406555176, 52.78576694216047, 54.01707111086164, 52.08923782621111, 47.627236706869944, 46.69769280297415, 46.72881725856236, 49.4191632270813, 49.32030773162842, 49.54895210266113, 50.89534970692226, 47.56240653991699, 51.0405809538705, 51.402144363948274, 52.71999529429844, 45.19252191271101, 49.79977512359619, 28.376882519040787, 7.034298062324524, 1.0446708862270628, 2.3906890537057603, 0.7315256180507796, 48.758330481392996, 59.363477161952424, 60.323273522513254, 62.72797557285854, 58.58501488821847, 42.64686870574951, 75.66871752057756, 32.597894055502756, 27.853973252432688, 47.991631507873535, 33.260720934186665, 46.71366671153477, 30.025330475398473, 61.113735335213796, 47.73900542940412, 1.3132852039166858, 0.24349101579615048, 0.273887539016349, 0.24271805584430695, 0.2076855506747961, 0.18856588591422352, 0.111390432475933, 0.14665105433336326, 0.14303157212478773, 0.21252491671059812], [0.07036678200321538, 0.06116161309182644, 0.020970762574246953, 0.05647887329437903, 0.013998141811628426, 0.05943731990243707, 0.038487408709313185, 0.0186417403165251, 0.08502193739903824, 0.10045898905290024, 0.06421084768537964, 0.03380125588072198, 0.024264269774513583, 0.2932013597871576, 6.017474361828395, 42.350736481802805, 31.22585412434169, 30.53113154002598, 22.90784076281956, 45.79039703096662, 26.841540813446045, 13.546792490141732, 66.83921078273228, 50.5160162789481, 54.63785096577236, 57.2282714162554, 54.26353413718087, 49.56810828617641, 44.55930825642177, 0.2700879600431238, 1.3230273383004325, 0.5160611655030931, 0.0655311071979148, 14.05991608755929, 37.724455629076274, 40.148001194000244, 53.0216964994158, 47.153303555079866, 46.093779700142996, 49.66398300443377, 52.89907121658325, 51.20063965661185, 56.20448909487043, 55.66871697562081, 60.43424320220947, 55.604793548583984, 55.3556797845023, 47.793899672372, 48.315414088112966, 50.02245446613857, 49.17604228428432, 47.68289525168282, 55.003638880593435, 51.45926203046526, 50.00840868268694, 47.89907455444336, 50.81107153211321, 50.872354643685476, 50.701116289411274, 49.34626620156424, 49.934219292231965, 47.75537191118513, 46.51221064158848, 43.09123379843575, 43.268795013427734, 39.27651643753052, 40.177260058266775, 41.35959332329886, 44.63540492738996, 42.99413619722639, 44.127592359270366, 39.81440428325108, 45.02714783804757, 45.559810638427734, 51.05586699077061, 48.39347015108381, 48.71486949920654, 49.117715631212505, 46.81378330503191, 46.25474166870117, 43.98616177695138, 39.847508975437705, 39.209626129695344, 45.940815108163015, 47.45047800881522, 47.862224783216206, 50.12648984364101, 48.35690178189959, 46.997010775974815, 49.176643303462434, 50.65063762664795, 48.75756965364729, 47.430067675454275, 45.11586243765694, 42.06898702893938, 41.183737891060964, 40.666552203042166, 45.2421007837568, 50.10500601359776, 49.67196301051548, 51.70392894744873, 50.07289491380964, 50.02237803595406, 48.731378419058665, 44.67778893879482, 38.313718455178396, 40.1007638658796, 43.74247455596924, 46.084674085889546, 47.883104119982036, 47.91442659923008, 46.33950274331229, 43.94140148162842, 38.355755056653706, 39.17583009174892, 39.883313042776926, 41.356622968401226, 43.561064038957866, 43.56483343669346, 46.21473741531372, 46.1023850440979, 45.888036591666086, 45.84018782206944, 43.44808980396816, 43.21003062384469, 45.91537427902222, 45.66587488991873, 43.67205456324986, 47.990422521318706, 52.90565810884748, 50.869033404758994, 49.16561998639788, 46.216008935655864, 43.30913972854614, 43.62434475762503, 45.11056096213204, 47.427785192217144, 50.90361111504691, 43.73528317042759, 46.213934898376465, 49.3092531476702, 51.186531339372905, 44.38322005953108, 39.63567229679653, 38.861757619040354, 20.927699702126638, 1.9478853515216281, 0.24995047918387822, 0.5486685729452542, 2.1599524063723425, 15.779487541743688, 53.41986301967076, 47.44951568331037, 56.16844184058053, 46.356675216129844, 45.75398499625069, 49.56147623062134, 62.4791327885219, 23.044662952423096, 38.7077716418675, 33.386698722839355, 29.4619323185512, 26.801083190100535, 25.141156809670584, 45.41937017440796, 17.594916343688965, 0.0709287989884615, 0.10097185296139546, 0.014217910822480917, 0.008249288641049393, 0.026498217401759963, 0.02492168708704412, 0.015996678499504924, 0.05379397129373891, 0.0230821803478258, 0.028365325249199356, 0.0940960676276258, 0.0576203049027494, 0.024975958014173166, 0.07980607263743877, 0.036900987050362995, 0.07718858309090137, 0.08678756015641348, 0.030096458071576696, 0.10970311944505998, 0.03858515167874949, 0.03984895029238292, 0.05611418786325625, 0.04108690350715603, 0.31512865317719324, 8.510647824832372, 56.4936557497297, 33.31368357794625, 32.56599140167236, 38.31798117501395, 47.18676955359322, 32.42022861753191, 18.72449541091919, 72.32371575491769, 55.19522156034197, 60.08359541211809, 61.93778473990304, 61.49585846492222, 55.77550036566598, 54.28083515167236, 1.6677653597933906, 2.127305861030306, 1.2789285331964493, 0.13725855547402585, 18.06839438847133, 45.3130453654698, 45.772269180842805, 56.99421787261963, 50.39239740371704, 49.71083123343331, 51.26366329193115, 52.20554024832589, 53.41692393166678, 56.96073450360979, 59.28401061466762, 60.12207453591483, 52.61546312059675, 54.00158705030169, 47.47900036403111, 49.15787621906826, 50.12421778270176, 49.040340491703574, 49.72924395969936, 56.42002221516201, 53.11280475343977, 54.36851099559239, 50.32061208997454, 51.73809323992048, 51.1667845589774, 51.66671092169625, 50.349113600594656, 51.90428025381905, 50.648970058986116, 47.93112659454346, 43.710432938167024, 45.24546023777553, 40.211507729121614, 41.37069654464722, 42.73431525911604, 47.62901891980852, 46.22841841833932, 47.01772683007376, 42.570191860198975, 44.75621673039028, 46.304077352796284, 52.25677626473563, 50.3059618132455, 50.75851535797119, 53.338860920497346, 52.33052444458008, 50.81326021466936, 45.912233693259104, 41.50664152417864, 41.36152492250715, 47.171198640550884, 49.540371077401296, 48.576107025146484, 52.51701756886074, 50.456689085279194, 49.65161868504116, 51.751430307115825, 52.237557547433035, 49.68270492553711, 47.400207792009624, 46.214070388248985, 43.72448566981724, 42.31235810688564, 44.079879079546245, 48.67202690669468, 50.89613137926374, 52.20578343527657, 52.20326471328735, 52.25788450241089, 52.49524538857596, 50.53199713570731, 46.38540949140276, 42.10463128771101, 42.783192362104145, 46.107651778629844, 48.56998566218785, 50.62067699432373, 50.03321722575596, 48.255419867379324, 45.81407649176461, 40.91504062925066, 40.29413570676531, 41.353666509900776, 43.0042736189706, 45.48067760467529, 43.76190519332886, 48.29595913205828, 46.982200690678184, 47.70319093976702, 48.05897692271641, 45.703384740012034, 45.3087374823434, 48.454760210854666, 48.24504273278372, 45.29649823052542, 51.787925720214844, 56.33782849993025, 52.025192805698936, 50.41843925203596, 47.652191162109375, 46.8344715663365, 43.61055605752127, 46.61545392445156, 50.91273062569754, 51.593122550419395, 46.25228200639997, 49.565040656498496, 49.374302182878765, 49.50363942555019, 49.420188086373464, 47.353352614811485, 43.85646670205252, 26.727823121207102, 3.7133731075695584, 0.5502870689545358, 2.236072310379573, 1.8154150141136987, 21.544873441968644, 59.83443301064627, 53.23219912392752, 62.12064743041992, 51.29427358082363, 49.1558438709804, 50.03488826751709, 65.70330538068498, 24.525796549660818, 39.368851048605784, 35.514202390398296, 33.941606181008474, 29.472434520721436, 23.238979748317174, 53.58846453257969, 18.958474261420115, 0.08654709413115468, 0.06180611279393945, 0.062025279604962895, 0.022483797278255224, 0.07136156862335545, 0.0714779170230031, 0.07358605068709169, 0.03492279623502067, 0.039483379373060803, 0.03669983873675976, 0.2094101831316948, 0.18511124700307846, 0.12407569214701653, 0.25582010565059526, 0.09642494908933129, 0.20939613745680877, 0.22431725822389126, 0.15811634196766786, 0.2722494469157287, 0.1911003634865795, 0.22146982673023427, 0.1970763299614191, 0.27070857531258036, 0.5409397876688412, 15.86835673877171, 72.6426033292498, 44.79483481815883, 46.180955273764475, 36.91689429964338, 62.451291356767925, 33.9473488671439, 21.273021697998047, 78.90973949432373, 60.90204456874302, 65.18645668029785, 66.04955496106828, 65.54421247754777, 59.2184613091605, 61.358881677900044, 2.454135009220668, 5.054242551326752, 1.1374665754181998, 0.23702441422002657, 21.709276505878993, 55.071658270699636, 48.939702783312114, 58.33509513310024, 54.736167975834434, 54.540030751909526, 52.88360800061907, 54.0723614011492, 57.5196475982666, 58.82630498068673, 59.77614457266671, 57.60780981608799, 55.19606229237148, 55.74302448545183, 50.96752759388515, 49.40915434701102, 49.72896950585501, 50.69488375527518, 51.53252036230904, 60.280278069632395, 56.450649874550955, 56.40456942149571, 52.74774987357003, 55.864673546382356, 55.16663319723946, 55.39319658279419, 53.836487429482595, 55.55482905251639, 52.51892832347325, 52.295363085610525, 45.11878415516445, 47.911796706063406, 42.359567642211914, 44.16295174189976, 46.317101751055034, 48.85229444503784, 48.94509111131941, 48.410076345716206, 45.46270261492048, 49.44192899976458, 49.17733464922224, 57.15874079295567, 53.57203899111067, 54.77920511790684, 54.807685783931184, 55.560846192496165, 52.76177828652518, 48.00072322572981, 44.439427512032644, 44.2116516658238, 51.2402582849775, 53.68785156522478, 51.99220275878906, 55.29599475860596, 52.55133819580078, 51.10551186970302, 53.1089311327253, 54.352849755968364, 53.25026444026402, 52.31618683678763, 52.36556421007429, 47.1764097894941, 45.752185412815635, 45.72998244421822, 50.07212713786534, 54.36968871525356, 54.376852308000835, 56.36825466156006, 55.753839356558665, 53.20135954448155, 52.40443590709141, 50.37939385005406, 46.27206005368914, 45.56641142708914, 50.2939726965768, 52.332355294908794, 53.64259794780186, 52.9024133001055, 53.21121556418282, 49.01445150375366, 43.50806318010603, 42.756052698407856, 44.47187212535313, 45.41177579334804, 47.50554595674787, 45.731590952192036, 49.82390969140189, 47.948257378169465, 49.63521746226719, 50.032970564705984, 47.150652817317415, 46.80121053968157, 50.999944414411274, 48.743805272238596, 46.92943607057844, 52.43630034582955, 58.80582863943917, 54.65138258252825, 50.79325982502529, 50.69778462818691, 47.00780480248587, 45.506285190582275, 46.22020564760481, 51.78569187436785, 49.51610796792166, 45.46451262065342, 50.0166666167123, 49.92935902731759, 48.412834780556814, 52.49261896950858, 50.94985485076904, 48.4693410055978, 32.85837507247925, 7.072552238191877, 0.6752178509320531, 2.923318633011409, 4.666357627936772, 21.41108066695077, 67.7498972756522, 55.14345400674002, 69.0282963344029, 55.62027760914394, 55.665128231048584, 56.31829711369106, 73.32547228676933, 30.726153578077042, 50.17895916530064, 41.791024344308035, 43.23251846858433, 39.008281230926514, 39.29541553769793, 59.967129707336426, 32.6819429397583, 0.1688073668628931, 0.21299188451043197, 0.27913446032575195, 0.15889724077922956, 0.13846784058426106, 0.14166093138711794, 0.1993059553205967, 0.26108982573662487, 0.19753033774239676, 0.22346571034618787], [0.01228877978532442, 0.025436271081811616, 0.024041527083941867, 0.03330735702599798, 0.059759691889796934, 0.04928422399929591, 0.02802711625450424, 0.06941099757594721, 0.04158524337357708, 0.026019626297056675, 0.03868098117943321, 0.06380601333720343, 0.058848019024091106, 0.024953778400751095, 0.8553641757794789, 33.666360242026194, 42.459538323538645, 37.3891772542681, 21.384687934603008, 26.448811258588517, 26.03637487547738, 7.660230006490435, 51.37475456510271, 59.36907741001674, 55.295727252960205, 58.364638873508994, 53.24480663027082, 55.355693680899485, 54.98605298995972, 38.34061145782471, 0.30359578345503124, 1.6522265821695328, 0.16213846685630934, 4.82147833279201, 28.90669482094901, 36.085788999285015, 53.349932874952046, 53.733549867357524, 49.69063629422869, 49.96492338180542, 54.104274477277485, 53.349915504455566, 57.25659574781145, 58.699792180742534, 56.692384651729036, 55.29285764694214, 55.140841484069824, 53.06613370350429, 54.87603521347046, 53.449538775852744, 49.03493479319981, 47.183257239205496, 55.93737254823957, 54.47236571993147, 51.81559692110334, 50.237021786826, 49.0327912739345, 49.34955964769636, 52.20549855913435, 50.67599160330636, 49.442356313977925, 49.99734020233154, 46.83325910568237, 43.034651143210276, 42.24811853681292, 39.68638719831194, 41.04745592389788, 38.06877361025129, 40.370037828172954, 38.659905501774375, 37.843943800245015, 39.95028325489589, 44.757293701171875, 46.16608265468052, 50.51376158850533, 48.85822125843593, 48.22832189287458, 47.48138359614781, 48.304769447871614, 41.07197264262608, 38.764350822993684, 37.61088384900774, 40.9445287840707, 44.68887478964669, 46.35505975995745, 46.834332602364675, 47.40617976869856, 47.99629374912807, 46.6384733063834, 48.065018381391255, 48.911764076777864, 48.86413764953613, 47.24860504695347, 44.75116886411394, 41.20778560638428, 41.20241812297276, 39.403272424425396, 40.31842660903931, 46.11404412133353, 48.30591937473842, 49.14641169139317, 50.609250681740896, 49.725217478615896, 50.905129296439036, 47.94452619552612, 42.94760411126273, 39.2567766053336, 42.86790827342442, 41.396978105817524, 44.32896852493286, 43.96380247388567, 44.179995673043386, 39.59671374729702, 37.93232488632202, 39.14382321493966, 40.217667307172505, 43.8670140675136, 45.422257150922505, 46.727451937539236, 46.89523008891514, 48.71550178527832, 46.6106527192252, 45.652145249503, 44.3419303894043, 43.68303619112287, 44.411926542009624, 47.59584127153669, 48.04221091951643, 49.809554713112966, 50.03018086297171, 49.89535106931414, 46.33450698852539, 45.30886949811663, 46.01236418315342, 45.103852476392476, 45.71097217287336, 47.08457197461809, 46.53613328933716, 47.74022831235613, 47.513136863708496, 51.440383774893625, 45.745456082480295, 40.38767235619681, 41.50137826374599, 34.09388984952654, 10.400508335658483, 1.1011396561350142, 0.06824575617377247, 4.396636809621539, 0.9950237274169922, 44.14558124542236, 52.607827050345286, 50.211730343954905, 50.77622284208025, 51.67990207672119, 49.68335805620466, 63.79175867353167, 42.770723819732666, 19.303323779787334, 51.246876444135395, 15.871049165725708, 34.738182408469065, 29.44645173209054, 33.74654245376587, 52.17520441327776, 6.94409133706774, 0.34854039603046005, 0.004243466404399702, 0.08295117065842662, 0.03854062621082578, 0.042818701293851645, 0.022903223522007465, 0.031142450336899077, 0.01193478043257658, 0.08891117798962764, 0.030213206806885343, 0.07312573931579079, 0.013883795938454568, 0.049893463629164865, 0.049170487959470065, 0.019795436445357542, 0.028810179592775445, 0.027820962048800926, 0.0419018172792026, 0.06193407092775617, 0.03028187794344766, 0.04561954457312822, 0.034810956700571945, 0.06550475968314068, 0.01556329648675663, 1.7194808019059045, 44.32055425643921, 49.87173066820417, 31.523702553340367, 30.94627250943865, 33.42810303824288, 29.026684999465942, 10.99712061882019, 55.9592558997018, 65.85679803575788, 60.183051926749094, 64.99502686091832, 57.588938508714946, 62.11103112357003, 60.35611765725272, 46.77826411383492, 1.7924513263361794, 2.1778275157724107, 0.8631330760461944, 5.728634706565312, 33.66747195380074, 44.29928929465157, 56.166906288691926, 55.256813866751536, 50.91279315948486, 52.410897731781006, 56.96867629459926, 54.722535610198975, 57.217727524893625, 58.335803849356516, 57.68259327752249, 58.34107058388846, 57.72113493510655, 54.90096187591553, 56.61075374058315, 54.257822717939106, 48.9967440196446, 49.64630331311907, 57.246684142521445, 55.45261410304478, 53.51675912312099, 53.190002713884624, 51.169185161590576, 50.31960112707955, 53.03128501347133, 53.84797280175345, 52.03935323442732, 51.734803267887656, 48.294103963034495, 45.05145958491734, 44.340780462537495, 39.920673506600515, 42.19873421532767, 39.95530680247715, 41.7929698399135, 41.062939984457834, 41.97782318932669, 41.168028014046804, 46.993078095572336, 47.65033251898629, 50.5772750718253, 49.593743664877756, 52.03580617904663, 50.42930623463222, 50.46881716591971, 45.10010392325265, 41.80143274579729, 40.47910022735596, 43.60964584350586, 48.94699839183262, 49.649231978825156, 49.822460991995676, 50.713807174137656, 49.430325508117676, 48.9764518056597, 50.023392472948345, 51.06396164212908, 50.96932370322091, 50.043768065316335, 47.726846081869944, 44.570988178253174, 42.154199736458914, 40.497860363551546, 43.00644840512957, 50.34526777267456, 50.310009138924734, 52.838465554373606, 51.813901560647146, 52.02486971446446, 54.23159326825823, 49.7398225920541, 44.58188990184239, 40.408558641161235, 43.3011770929609, 46.17423289162772, 47.983613286699565, 46.28696741376604, 45.56387880870274, 42.710302284785676, 39.07409109388079, 40.53922993796212, 41.228501660483225, 45.21466582162039, 45.72828360966274, 45.60468210492815, 47.427625383649556, 48.186108112335205, 47.952304703848704, 46.22521529878889, 46.50342811856951, 45.951414585113525, 45.88595560618809, 51.26519536972046, 49.331529072352815, 51.154177052634104, 52.44657673154558, 52.65244490759713, 48.38480574744088, 49.00887557438442, 47.23598711831229, 47.05464955738613, 46.897008827754426, 46.91798196520124, 47.50066137313843, 49.63033982685634, 51.378256457192556, 54.057005882263184, 53.23215396063668, 48.04569544110979, 46.1890047618321, 37.50411088126046, 13.47969286782401, 1.6666694985968726, 0.15416981945080416, 4.786622694560459, 2.8245471673352376, 49.77291338784354, 56.32440805435181, 56.06679316929409, 55.29748862130301, 56.11534023284912, 52.948260988507954, 66.68988704681396, 45.13522011893136, 22.70252844265529, 56.76285675593785, 17.726791415895732, 40.3366447857448, 29.118220567703247, 33.878433159419465, 59.737672397068565, 8.23429799079895, 0.6080661171248981, 0.06401048307972294, 0.10468307988984243, 0.03513110648574574, 0.09203398613525288, 0.005645228998868593, 0.030074890836008956, 0.02223305992915162, 0.035891751027000804, 0.012656626341465329, 0.12310039305261203, 0.16975202331585543, 0.20914822790239537, 0.16032785044184752, 0.17018921699907097, 0.17593412872936043, 0.1219987507377352, 0.12864947957651957, 0.15380843169987202, 0.13863101468554564, 0.12771797313221864, 0.13090361362057074, 0.16321288634623798, 0.10281771248472588, 3.5333387681416104, 63.362318311418804, 57.12653241838728, 56.97168833868844, 34.55598327091762, 42.70993055616106, 34.324549198150635, 12.911991170474462, 63.10510989597866, 70.25407668522426, 66.06208256312779, 71.11489595685686, 61.68273721422468, 65.74880913325718, 63.71125684465681, 53.178590297698975, 2.032310958419527, 4.222585303442819, 0.875970470053809, 6.875395800386157, 43.37468555995396, 50.3619955607823, 59.93880190168108, 57.26084109715053, 52.01487125669207, 56.133652210235596, 59.237131118774414, 57.04765994208199, 59.6335050037929, 61.378510338919504, 60.48830713544573, 61.738162994384766, 59.71806458064488, 57.06989417757307, 58.63229043143136, 57.80219956806728, 51.978740624019075, 48.40763405391148, 59.55123833247593, 57.8840389251709, 57.00986174174717, 57.217366218566895, 55.47889566421509, 52.29019362585885, 56.886357511792866, 55.72784267153059, 52.80328682490757, 55.37860189165388, 51.08919749941145, 46.34790311540876, 46.20043107441494, 42.117860657828196, 45.74793658937727, 41.50073902947562, 44.10215153012957, 42.262240750449045, 43.224170207977295, 44.25166981560843, 49.334402152470176, 49.62210968562535, 55.33918128694807, 52.75559786387852, 55.33184398923601, 52.7459259714399, 53.788517066410606, 47.500984464372905, 44.59572376523699, 44.27291393280029, 46.82525825500488, 51.733337197984966, 55.28838300704956, 53.18685170582363, 55.250074114118306, 52.501304217747276, 52.03514610018049, 51.26937471117292, 55.06564460481916, 54.10801260811942, 51.77860123770577, 51.21256971359253, 47.65112461362566, 45.24557140895298, 43.88249117987496, 45.55166040148054, 52.026464326041086, 53.011767523629324, 55.74783263887678, 53.76155458177839, 55.780919960566926, 55.9740868295942, 52.318396363939556, 47.93786287307739, 44.39978109087263, 48.025733266557964, 48.80079092298235, 51.00846985408238, 50.67533499853951, 49.0466251373291, 46.71440669468471, 42.46396780014038, 42.251922675541465, 44.282210622514995, 48.254745892116, 49.25221538543701, 47.55089337485177, 50.07863065174648, 51.7461462020874, 50.670992374420166, 49.053007057734895, 48.86851848874773, 49.54207338605608, 47.457130908966064, 51.82981988361904, 50.03759459086827, 53.40047754560198, 54.112779072352815, 52.26441580908639, 50.14499637058803, 49.516969544546946, 47.65738146645682, 49.076822008405415, 48.09229353496006, 47.2926983152117, 47.12895359311785, 46.788634300231934, 50.74488994053432, 55.587669713156565, 56.73565803255354, 53.801947934286936, 48.42324318204607, 43.44723864964077, 17.019520384924753, 2.4023852603776112, 0.24202931565897806, 8.727777293750218, 5.09307907308851, 54.73624440601894, 61.24233259473528, 60.199824878147666, 60.06467546735491, 63.206963539123535, 57.2029903956822, 72.54543277195522, 50.67500843320574, 24.95122606413705, 62.56358119419643, 21.3903420312064, 49.50838157108852, 41.90928963252476, 45.994549001966206, 70.22119086129325, 16.441101959773473, 0.812896731708731, 0.23038948167647633, 0.2732824757695198, 0.17973191637013639, 0.30150844688926426, 0.1089657215135438, 0.150138100076999, 0.1239049591656242, 0.15281961618789605, 0.09425863783274378], [0.047352261774774106, 0.023234667522566657, 0.014502668221082007, 0.03095816701118435, 0.03948025471929993, 0.04170868924951979, 0.04490332371954407, 0.06598925404250622, 0.12855634385985987, 0.03278649318963289, 0.1300938499293157, 0.024809209729677865, 0.06532282408859048, 0.020278762028153454, 0.39187983902437346, 22.054188558033534, 49.09844132832119, 43.16618749073574, 39.59532758167812, 20.55253345625741, 44.77460861206055, 15.246473857334681, 17.559150491441997, 70.89932809557233, 51.08213465554373, 60.35078838893345, 52.25308329718453, 52.37288761138916, 52.00819403784615, 48.28097881589617, 24.270158427102224, 1.0676605211836951, 0.2560083312647683, 1.0346503896372659, 12.02434664113181, 32.61319746289934, 44.55455568858555, 55.30162279946463, 52.919912338256836, 58.86599309103829, 53.235374450683594, 51.746858392442974, 53.82919529506138, 57.39249903815133, 59.08719594138009, 55.632509912763325, 52.4300400188991, 53.865676811763215, 52.74979264395577, 56.08511904307774, 51.98943737574986, 53.498009409223286, 51.41469975880214, 53.29700149808611, 52.6925881249564, 54.90008987699236, 51.22295379638672, 50.519966329847065, 51.52900457382202, 48.18753249304635, 50.95866169248308, 48.57724305561611, 50.595093727111816, 46.13287721361433, 41.19472646713257, 40.16187327248709, 40.032348428453716, 38.91922616958618, 36.78703246797834, 37.819777965545654, 38.025211879185264, 37.009079524448936, 45.89277178900582, 49.1812082699367, 46.504300117492676, 49.33120598111834, 46.127436774117605, 44.81121867043631, 40.78630093165806, 36.53741495949881, 37.31334808894566, 37.511733055114746, 43.66998052597046, 46.44736310413906, 44.86009924752371, 46.3259676524571, 48.28718703133719, 37.9668539592198, 43.71809680121285, 47.10000739778791, 44.49294253758022, 50.495970726013184, 48.262222153799875, 45.64839322226388, 44.03513962881905, 39.116638387952534, 39.02540854045323, 39.80019869123186, 42.8933629989624, 46.96761294773647, 50.49901403699602, 48.079164913722444, 48.311193057468955, 48.3596636908395, 50.62484243937901, 45.81855460575649, 41.22316891806466, 42.585575171879356, 39.40379006522042, 37.65563372203282, 34.99706881386893, 37.739501953125, 38.20876938956124, 39.51552404676165, 40.250108446393696, 40.96575205666678, 43.67929458618164, 47.98775788715908, 46.86591216496059, 47.36548069545201, 46.480151653289795, 45.15338618414742, 43.831463609422954, 44.372849873134065, 47.61032131740025, 45.609983580453054, 49.674606800079346, 49.34466116768973, 49.1034266608102, 51.23846564974104, 49.99335193634033, 44.29457841600691, 46.454578808375764, 42.919853006090435, 47.6620089667184, 47.851416860307964, 45.40970870426723, 48.071157114846365, 48.49417386736189, 48.382950578417095, 43.91367816925049, 36.23607506070818, 43.18324531827654, 35.616556303841726, 14.852563108716692, 3.2514529568808417, 2.6428435231958116, 0.9288763340030397, 1.0964608043432236, 7.955111554690769, 51.77013485772269, 45.09358303887503, 56.25567994798933, 48.391715730939595, 58.11297859464373, 45.99809953144619, 62.75219004494803, 13.160997237477984, 31.176692145211355, 30.172281401497976, 17.638995715550013, 40.762517247881206, 37.81124905177525, 40.9166248185294, 37.260340281895225, 2.1367966660431454, 0.2602611444890499, 0.10946646000125579, 0.07482863151069198, 0.005135918493449155, 0.017466931570587412, 0.0862068495314036, 0.01430693970594023, 0.006716775741162044, 0.047618864968951256, 0.06248981824942997, 0.04644928772800735, 0.07001450697758368, 0.05389646740098085, 0.09930882469883986, 0.08313330981348242, 0.027551539541621293, 0.028398234197603803, 0.03332211855532868, 0.04346650206883039, 0.045174995570310524, 0.10490217206201383, 0.10266522530998502, 0.06079427458878074, 0.04007556402523603, 0.2550238040941102, 27.10823004586356, 60.9890707560948, 41.24099104745047, 47.6929076058524, 29.736556393759592, 44.679849079677034, 20.762801579066686, 21.01999088696071, 78.7758755002703, 56.356890882764546, 66.67378807067871, 58.545326777866904, 59.27333123343331, 56.69855465207781, 54.37333304541451, 31.769488130296978, 0.8009867050818035, 0.750884222132819, 0.6372920860137258, 14.153554354395185, 38.97146272659302, 48.7246595110212, 58.1501201902117, 57.825517722538535, 61.546267645699636, 53.07726124354771, 54.716164112091064, 56.978212697165354, 61.33227007729666, 58.397184235709055, 58.85961464473179, 53.83278751373291, 56.28223596300398, 54.73723799841744, 58.43635123116629, 54.16796166556222, 56.004043987819124, 54.240344524383545, 57.811079365866526, 53.8086598941258, 55.175759656088694, 51.53526142665318, 52.03680671964373, 51.85300602231707, 49.10114765167236, 51.68114580426897, 49.94012178693499, 51.346159253801616, 46.98491743632725, 45.540602343423025, 42.11240632193429, 42.73045206069946, 38.680406161717, 37.468153953552246, 37.858024324689595, 40.53710726329258, 40.847608361925396, 46.155966077532085, 50.29606063025338, 46.81931059701102, 50.59954057421003, 50.21236610412598, 47.67709697995867, 44.31626721790859, 40.12267501013619, 41.02769177300589, 39.265409742082866, 45.7382264818464, 47.885709694453645, 47.86201286315918, 49.442776679992676, 50.09689746584211, 43.959703036717, 45.73003108160836, 49.27448088782174, 47.57530239650181, 50.728495665958945, 48.09572941916329, 47.636773109436035, 47.85761117935181, 41.94722332273211, 41.61051361901419, 41.43730545043945, 46.10547351837158, 50.881279604775564, 51.596964904240195, 51.979112352643696, 50.485621384211946, 50.005684988839285, 52.78431824275425, 47.59243665422712, 43.31812374932425, 45.06333753040859, 41.237975529261995, 40.61245352881295, 38.172850676945274, 38.61851160866873, 41.70284823008946, 41.08430222102574, 42.42430748258318, 43.011583123888286, 44.90911878858294, 47.618325642177034, 47.850815841129844, 46.809968744005474, 49.24566323416573, 46.585548877716064, 45.512896401541575, 44.25921903337751, 48.32081978661673, 48.72832815987723, 49.09751374380929, 49.60252966199602, 51.86861515045166, 53.580217020852224, 50.81854779379708, 45.866483279636924, 48.28669023513794, 46.64040143149239, 47.98479100636074, 49.21819700513567, 46.00890050615583, 49.45606163569859, 52.28971767425537, 49.618121419634136, 49.43420607703072, 42.773159163338796, 49.03083883013044, 38.71525485174996, 16.381911993026733, 5.139959003244128, 4.4536120380674085, 1.0163780386958803, 0.8993042036890984, 9.969935417175293, 59.4761699948992, 49.39422614233834, 62.563282421657014, 50.73346710205078, 61.77184091295515, 49.291861806597026, 65.58074610573905, 16.25143003463745, 37.594482626233784, 33.18785864966256, 19.073437418256486, 52.130155767713276, 43.48292807170323, 43.859676769801546, 42.86837380273001, 1.8549679602895464, 0.20645520383758204, 0.03010258524279509, 0.06849207795624222, 0.022537489754280875, 0.024563666566142013, 0.05817882064729929, 0.04320496413856745, 0.02795626362785697, 0.03071281892646636, 0.03129554819315672, 0.17565591580101422, 0.27227742969989777, 0.2656627989241055, 0.28403299461518017, 0.22747472593826906, 0.24502795189619064, 0.09793401097080537, 0.14480382416929516, 0.2763733113450663, 0.266021689666169, 0.16015379263886384, 0.17699972726404667, 0.15049948782793113, 0.12325503118336201, 0.5111112254006522, 42.30125141143799, 69.4357248033796, 57.32306568963187, 58.23379039764404, 33.9720219203404, 58.28584630148751, 21.00900752203805, 22.856460571289062, 85.05477496555874, 60.02596705300467, 71.4819484438215, 62.36725984300886, 61.655625343322754, 62.199162074497764, 60.23019545418875, 34.53364133834839, 6.3710256304059705, 0.3487937067236219, 2.2662513766969954, 17.32696601322719, 46.32354620524815, 53.57276160376412, 60.800781522478374, 57.7757443019322, 61.338342802865164, 55.05200529098511, 56.22113003049578, 57.500091893332346, 64.62679318019322, 64.81619412558419, 62.10303374699184, 55.58806923457554, 61.05910859789167, 58.306989669799805, 63.14169216156006, 56.72786215373448, 57.719057423727854, 56.3725243295942, 60.90564373561314, 57.383570602961946, 59.642892020089285, 54.614452907017295, 55.536166191101074, 54.944144930158345, 52.87586075919015, 53.59270988191877, 53.66872317450387, 53.61238023212978, 50.76024545942034, 45.71138211659023, 45.95372486114502, 46.04609073911394, 41.71075528008597, 41.43825387954712, 40.61115421567644, 43.23316812515259, 40.779213769095286, 50.074819564819336, 55.88064398084368, 50.18543141228812, 55.22343472072056, 53.26916701453072, 50.27785982404436, 46.314367634909495, 41.2777088029044, 43.201814379010884, 43.76801265989031, 50.58823585510254, 51.50613457815987, 51.51553896495274, 52.75789771761213, 53.73557526724679, 43.33248220171247, 47.42765665054321, 49.77442809513637, 49.137910570417134, 54.53591047014509, 52.18833303451538, 49.61000592367989, 51.38816111428397, 44.858952794756206, 42.34318726403372, 44.20537049429757, 47.93600075585501, 52.38994543892996, 54.824580328805105, 52.275880336761475, 52.80047280447823, 51.366816248212544, 58.03441183907645, 51.75110721588135, 46.0824020249503, 47.11844444274902, 43.701320375714985, 42.09715155192784, 40.03116028649466, 41.31351287024361, 44.44812665666853, 43.229742663247244, 46.06064026696341, 44.61719717298235, 48.01041943686349, 51.27425582068307, 49.93053674697876, 49.742744309561594, 52.19739348547799, 50.78653049468994, 47.78414787564959, 46.967119625636506, 52.31405373982021, 49.33652482713972, 53.34811244692121, 52.21328401565552, 54.38242128917149, 54.57533802304949, 51.878036907741, 46.08812734058925, 49.259285177503315, 46.27366508756365, 48.311116627284456, 49.83467245101929, 46.08550786972046, 49.33394357136318, 52.26869589941842, 49.17258555548531, 52.202423981257844, 46.18208088193621, 51.52416167940412, 44.65953949519566, 23.158790588378906, 7.117156199046543, 5.289420400347028, 1.7668899893760681, 3.0067022272518704, 11.472427776881627, 63.81113025120327, 52.53501687731062, 68.32721614837646, 55.85070071901594, 70.19773374285016, 52.48758152553013, 74.18088585989815, 17.510709387915476, 41.35036611557007, 35.328935623168945, 28.2738824231284, 55.97972181865147, 44.4028765133449, 51.91150638035366, 56.51511526107788, 5.081073020185743, 0.5636744020240647, 0.21153128359998974, 0.26453396092568127, 0.07232350736324276, 0.0917755321466497, 0.21082388370164803, 0.09339324784065996, 0.1078382134437561, 0.1592166679246085, 0.14800854506237165], [0.026300093658002358, 0.04089555323922208, 0.03556264118690576, 0.05293889164126345, 0.006897216862333673, 0.11696138818349157, 0.03549635849360909, 0.05699683978621449, 0.03604901848094804, 0.05477528899375882, 0.03566291169928653, 0.037270839525652785, 0.0664422440209559, 0.06440723607582705, 0.17864061492894376, 5.782283919198172, 43.15593194961548, 30.703412124088832, 28.881655250276836, 27.009699378694805, 28.177938222885132, 47.27968086515154, 9.858636566570826, 33.85272135053362, 70.17126110621861, 49.349785464150564, 60.76099613734654, 49.89779336111886, 63.059161458696636, 44.70437274660383, 49.67677811213902, 2.404866418668202, 4.206950119563511, 0.2200600616633892, 2.1957512625626157, 25.32244747025626, 38.639832156045095, 56.61144856044224, 50.272801535470144, 55.79650477000645, 53.51227406093052, 60.45936788831438, 58.36711938040597, 57.34789855139596, 54.80308607646397, 53.600953919546946, 49.523646763392854, 51.623531341552734, 52.201027393341064, 53.154632908957346, 53.2811005456107, 53.80459172385079, 50.81570250647408, 53.13540376935686, 53.08651624407087, 51.91418491091047, 50.886004379817415, 52.15579114641462, 49.16285807745797, 48.54103251865932, 52.27670022419521, 51.17861039297921, 50.40871524810791, 45.89597143445696, 43.44068649836949, 39.36610998426165, 38.92992639541626, 38.061512742723735, 35.850922516414094, 37.171264375959126, 35.990188734872, 39.637572629111155, 42.7002169745309, 45.45860317775181, 44.833331312452046, 45.190638950892854, 45.17026335852486, 40.40307303837368, 37.473778520311626, 37.192734309605186, 36.090016978127615, 36.46557406016758, 43.37543943950108, 43.50813266209194, 47.50288132258824, 44.78937005996704, 50.18645279748099, 14.277703029768807, 25.004560436521256, 39.14090149743216, 28.62088414600917, 51.529890469142366, 45.54278407778059, 48.898552077157156, 42.65785380772182, 41.91270119803292, 35.940227712903706, 40.41549641745431, 37.22613082613264, 43.78517123631069, 45.29770721708025, 46.624608176095144, 45.92794009617397, 48.0393100466047, 45.99311419895717, 45.935652596609934, 39.79679754802159, 38.62994834354946, 35.606349400111604, 35.35333769662039, 35.17887190410069, 36.00103139877319, 36.194128785814556, 37.888988971710205, 40.60068328039986, 41.48920849391392, 43.72713988167899, 47.31810440335955, 48.045559951237266, 47.63429955073765, 46.035373142787385, 45.659249782562256, 45.50346769605364, 44.19323893955776, 43.98618262154715, 47.085516929626465, 47.13280289513724, 50.62937266486031, 50.200585433415, 49.07840967178345, 47.378720487867085, 50.02425404957363, 49.35243967601231, 52.23937102726528, 49.20063543319702, 50.943080357142854, 48.641913414001465, 48.1153233391898, 45.37607247488839, 43.72563559668404, 39.922886507851736, 41.41886493137905, 35.035527093069895, 22.538514477866038, 3.4848944076469968, 3.2448964629854475, 3.214180431195668, 0.9499373010226658, 0.8114375557218279, 13.770606994628906, 57.260406834738596, 49.70942769731794, 52.6261841910226, 48.06919772284371, 52.09812109810965, 52.80541297367641, 47.452833448137554, 21.66098131452288, 45.94138833454677, 29.20160068784441, 30.40917328425816, 35.843154430389404, 35.793985503060476, 42.41751561846052, 28.123004027775355, 0.23354673225964817, 0.09360478113272361, 0.008712741629486638, 0.0646706772968173, 0.05493346229195595, 0.008400866578865265, 0.024726901735578264, 0.04402007468576942, 0.055633289739489555, 0.06445058089281831, 0.03171288115637643, 0.012637090470109667, 0.04659645179552691, 0.03798861422442964, 0.04939438755224858, 0.03759957277881248, 0.07779832144400903, 0.08541043940931559, 0.08099692195121731, 0.10338099833045687, 0.03891308765326228, 0.013282198309233146, 0.04960506249751363, 0.061213744937309196, 0.15072154519813402, 0.13556057587265968, 7.4173730952399115, 55.744928291865754, 34.49109751837594, 33.439984457833425, 40.77135535648891, 30.797806876046316, 51.387765066964285, 14.210861359323774, 40.705879007067, 76.70817497798375, 54.875781604221885, 67.84794330596924, 56.408279759543284, 68.21354361942836, 49.56258794239589, 56.422780650002615, 3.771266366754259, 2.7336968651839664, 1.233381680079869, 3.6766644716262817, 30.056058883666992, 43.08895131519863, 59.76322092328753, 53.89002677372524, 57.34333011082241, 54.40506894247872, 61.18508638654436, 62.72988632747105, 59.2207681110927, 54.480943271092, 56.0237386567252, 51.85959986277989, 55.40447003500802, 54.452125617435996, 54.61464745657784, 52.763543128967285, 54.548674310956685, 52.20534917286464, 54.09771537780762, 53.62945195606777, 53.553240639822825, 54.53293316704886, 51.968749114445274, 51.45850120271955, 51.770631653921946, 54.023032665252686, 52.098194054194856, 51.64374712535313, 48.96093647820609, 46.08041831425258, 41.47162955147879, 40.95334257398333, 40.584591252463206, 37.39713641575405, 40.364840575626914, 38.707712582179475, 40.317283630371094, 44.92096546718052, 48.0713586126055, 48.00703566414969, 48.03748614447457, 49.343705790383474, 43.19176728384835, 39.695367744990754, 38.54118858064924, 39.78643083572388, 40.814423765454976, 48.00033412660871, 46.48668990816389, 50.54022380283901, 47.39264120374407, 52.6869010244097, 19.939203807285853, 31.32544960294451, 44.285316467285156, 33.44841957092285, 54.2567457471575, 50.45197473253523, 49.49568721226284, 47.866939135960166, 44.70328187942505, 39.39406606129238, 43.15378148215157, 39.80760894502912, 47.542513847351074, 50.22635977608817, 49.405294622693745, 49.29327923910958, 50.63449001312256, 49.582286085401265, 47.98011834280831, 43.45579188210623, 42.8055099759783, 37.44885880606515, 36.72828197479248, 36.69009814943586, 37.265443733760286, 39.530400139944895, 39.712786878858296, 41.44555991036551, 42.03585454395839, 44.58404731750488, 48.087183134896414, 48.918274538857595, 48.15831184387207, 47.22918135779244, 47.15768786839077, 46.830115045819966, 46.61875431878226, 47.62345341273716, 49.22648273195539, 50.26167399542672, 51.697116238730295, 51.381042684827534, 50.5750412259783, 48.84844166891915, 53.018851212092805, 52.25755098887852, 52.93989188330514, 50.01691675186157, 52.138677733285085, 50.74224962506975, 51.48999738693237, 47.02724586214338, 46.9048672403608, 42.06424488340105, 50.32361371176583, 41.885943685259136, 26.44963983127049, 5.369407628263746, 5.949177478040967, 2.9430543397154127, 1.506418526172638, 0.771151031766619, 15.695758274623326, 63.46768774305071, 51.9924042565482, 57.03438193457467, 51.3030561038426, 56.22802611759731, 55.594357354300364, 52.777133805411204, 25.009825434003556, 50.6254643031529, 31.655002662113734, 32.897250243595664, 41.24559422901699, 34.62842518942696, 47.17981440680367, 30.52001789637974, 0.27243512123823166, 0.02766422724484333, 0.039373850250350576, 0.07741166504898242, 0.04700410206403051, 0.02179092651100031, 0.0521137285977602, 0.07258738284664494, 0.024658805657444254, 0.0469117330919419, 0.008337984194180794, 0.10261597045298133, 0.11968227289617062, 0.19119761112545217, 0.20912917463907174, 0.11987048493964331, 0.23747162308011735, 0.20010871653045925, 0.20579321150268826, 0.1806391312607697, 0.21715745170201572, 0.19685102919382708, 0.19075854468558515, 0.11215755024126597, 0.24169531358139856, 0.3605033755302429, 14.324769258499146, 67.02646473475865, 45.85457754135132, 43.63291188648769, 41.21294811793736, 41.27172987801688, 58.17353214536394, 15.04717172895159, 44.655440058027, 83.48080648694719, 58.56572668892996, 73.62148639133999, 59.617030824933735, 71.45152923039028, 54.76754604067121, 62.308721269880024, 2.963186093739101, 7.1491943427494595, 1.0353282732622964, 5.90465863261904, 39.46011216299874, 47.5501012802124, 63.866868700299946, 55.76719379425049, 59.25838565826416, 55.9711651120867, 65.6405006136213, 63.98415429251534, 62.51053169795445, 57.74642637797764, 59.88842051369803, 54.488047804151265, 56.950756890433176, 59.773261070251465, 57.10794251305716, 57.913242203848704, 60.81393446241106, 52.51326901572091, 58.092714173453196, 58.44211823599679, 58.19725329535348, 57.435991287231445, 55.622296060834614, 52.88683543886457, 54.24364144461495, 56.54749386651175, 57.26013585499355, 54.660561152866904, 50.11698818206787, 48.83565698351179, 44.29744454792568, 43.12013135637556, 43.7657128061567, 40.49759980610439, 43.417156423841206, 40.44568634033203, 44.25091593606131, 46.56274836403983, 50.52465636389596, 49.030463627406526, 48.73059327261788, 51.956652300698416, 45.54680708476475, 42.09978491919381, 42.59155409676688, 42.49305643354143, 45.07303721564156, 51.80961104801723, 48.881289277757915, 55.85477236339024, 50.933964320591514, 57.178657804216655, 17.984289918627056, 30.633791174207413, 45.86033412388393, 32.27710614885603, 58.3057667868478, 52.094462871551514, 53.02274220330374, 49.56929642813546, 47.563764912741526, 41.55170406614031, 46.96453142166138, 40.714196000780376, 50.86499302727835, 50.87366437911987, 51.4145746912275, 49.53282185963222, 54.61533880233765, 50.892323766435894, 50.67992428370884, 44.82287079947335, 44.126209667750764, 39.35045916693551, 38.84678772517613, 39.08926943370274, 40.7069525037493, 41.337077685764854, 42.32393727983747, 43.7212165423802, 44.81811128343855, 49.62085206168038, 51.87600108555385, 50.74049867902483, 51.3898286819458, 48.02602161679949, 49.514294488089426, 47.352042879377095, 48.346945013318745, 50.26204572405134, 51.96353101730347, 51.83152219227382, 54.85035467147827, 52.835498673575266, 52.095185484204976, 48.18118183953421, 54.24037231717791, 52.34806864602225, 55.66960287094116, 50.98197637285505, 53.34600714274815, 51.32749291828701, 51.79829938071114, 47.42156308037894, 50.09486859185355, 45.029041222163606, 52.0232264654977, 45.16394049780709, 32.68014683042254, 7.3439653771264215, 9.198400497436523, 5.959775652204241, 3.098850105490003, 2.3513691978795186, 18.413789340427943, 72.14300700596401, 55.13658223833357, 62.10513210296631, 55.74760682242257, 62.188274247305735, 59.26944719042097, 57.99168389184134, 26.845586402075632, 59.8817571912493, 34.93616785321917, 47.467129366738455, 47.69006926672799, 44.469655650002615, 52.49968181337629, 45.33011014120919, 0.3003015230808939, 0.18775327237589018, 0.13391584769955703, 0.1434961107692548, 0.16269036009907722, 0.20460511025573525, 0.1378375765468393, 0.16676779916243895, 0.10054202138313226, 0.13423547840544156, 0.1538968990956034], [0.004764875613286027, 0.052047082888228555, 0.03229060283462916, 0.024759084651512758, 0.028916594239750078, 0.08795098308473825, 0.050703671760857105, 0.014208646274970045, 0.07001165034515516, 0.0510945554290499, 0.08537647873163223, 0.02810606380392398, 0.012844483850390782, 0.02404517081699201, 0.3529805392026901, 0.8776882493070194, 36.73069299970354, 45.7398419380188, 28.26697243962969, 26.118017945970806, 24.36412933894566, 49.50540426799229, 34.685702664511545, 8.950506142207555, 64.14818041665214, 53.17748206002371, 62.765454156058176, 51.5984240259443, 59.4272129876273, 46.31317254475185, 51.703720501491, 8.469796759741646, 4.451088973454066, 0.15369240221168312, 0.3241404396082674, 12.844493763787405, 36.74574627195086, 52.87267848423549, 54.15138326372419, 54.3228439603533, 55.97313492638724, 56.483295985630576, 55.11778041294643, 55.81260027204241, 50.704864842551096, 49.52979939324515, 47.47425127029419, 50.150443758283345, 49.63865334647042, 52.17641339983259, 52.28667436327253, 53.75848695210048, 54.30147130148751, 53.43839039121355, 55.025567395346506, 54.68873609815325, 52.159317357199534, 52.033176285879954, 49.964833055223735, 48.398233141217915, 51.539812496730256, 50.91126455579485, 49.2395418712071, 45.67227070672171, 42.14162002290998, 38.753306661333355, 38.64367798396519, 36.886676583971294, 35.53429658072335, 34.540162222726, 36.51888411385672, 37.06812184197562, 39.40613160814558, 42.82523243767874, 44.61686018535069, 44.85048641477312, 40.9299966267177, 35.51453242983137, 37.403031962258474, 36.06369720186506, 36.07560988834926, 37.284582546779085, 44.32857595171247, 40.76783609390259, 49.16740219933646, 44.97572422027588, 56.425559929439, 14.566519669124059, 11.124669568879263, 24.474048103604996, 25.40875973020281, 59.12917695726667, 41.47150100980486, 51.43565205165318, 45.401273591177805, 42.55245658329555, 36.43862894603184, 42.24017327172415, 35.013265064784456, 39.54734679630825, 39.63188552856445, 47.42665263584682, 45.84507587977818, 47.35877915791103, 44.31660073144095, 46.139665603637695, 42.55844593048096, 39.54586335590908, 35.170492376599995, 34.24471092224121, 34.673456464494976, 35.94821119308472, 35.896287305014475, 39.676795210157124, 39.66971846989223, 40.46374818256923, 41.58296053750174, 47.565856320517405, 47.61739458356585, 47.28713280814034, 49.13302598680769, 45.80025999886649, 42.98757709775652, 46.69016790390015, 45.86649717603411, 49.22321707861764, 49.29325492041451, 50.504308564322336, 48.44323314939226, 49.99291072572981, 52.495703969682964, 51.70960562569754, 50.99233961105347, 52.95737702505929, 52.100671086992534, 53.66382122039795, 49.17139046532767, 51.26322555541992, 44.59160000937325, 46.14527974809919, 36.553145681108745, 35.64526973451887, 39.77861063820975, 18.924752916608536, 1.7754186860152652, 3.3388875680310384, 0.24484933433788164, 1.6912103188889367, 0.6668349036148616, 27.115087917872838, 49.010449341365266, 50.49154472351074, 50.7638064111982, 55.20015825544085, 49.416338784354075, 58.24216297694615, 37.353126525878906, 43.44109991618565, 54.77279887880598, 30.132968493870326, 35.27148444311959, 29.618138245173864, 35.65297876085554, 48.342928954533164, 7.989017026765006, 0.16228213986115797, 0.10789044028414146, 0.04919730705608215, 0.04971364845654794, 0.07487195597163268, 0.07844611882631268, 0.029785831525389637, 0.07909702389900174, 0.03641701177028673, 0.055448236276528666, 0.017411205185843364, 0.07208692255829062, 0.028938873937087398, 0.05828901473432779, 0.03749064415959375, 0.05351729863988502, 0.03544083736570818, 0.02421572059392929, 0.07807643937745265, 0.007101341824246836, 0.060791031191391606, 0.02833984456291156, 0.057370196894875596, 0.002323103948063882, 0.0541184874517577, 0.03887335603524532, 1.216534252677645, 43.51974310193743, 55.83517149516514, 24.757326160158428, 43.1047272000994, 31.437451090131486, 50.54271125793457, 39.00024216515677, 11.640038302966527, 68.86707728249687, 58.71516159602574, 68.13787773677281, 55.38078710011074, 66.13150896344865, 51.1808511870248, 58.15106167112078, 12.068685701915197, 3.1715072010244643, 2.364579460450581, 0.4088223156120096, 15.24620635168893, 42.107115268707275, 55.37403692517962, 56.72683382034302, 56.79865387507847, 57.06988722937447, 59.923995290483745, 57.33947038650513, 58.39350169045584, 53.28624221256801, 51.298136779240195, 51.53171437127249, 53.85848542622158, 50.95194625854492, 55.10245268685477, 54.38430772508894, 55.102202551705496, 57.02359138216291, 55.11333703994751, 55.60149662835257, 54.95194428307669, 53.34100791386196, 54.029463223048616, 50.81414958408901, 50.84855011531285, 53.822959286826, 51.95831639426095, 50.940568583352224, 46.34051023210798, 44.33619465146746, 40.53364706039429, 40.51290668760027, 38.27445418494088, 38.125578607831685, 36.42123760495867, 38.52144527435303, 39.39715453556606, 42.25883960723877, 45.71118756702968, 46.45853580747332, 46.43764952250889, 45.22610255650112, 38.34996025902884, 40.27117885862078, 36.97010013035366, 39.32765170506069, 40.440235478537424, 45.014773096357075, 41.50906991958618, 51.994151728493826, 46.910943440028596, 58.88964475904192, 14.820832422801427, 13.732865248407636, 29.623561314174108, 27.494874715805054, 60.50298867906843, 46.13917922973633, 54.765121119362966, 47.06286927631923, 45.209256649017334, 38.15627922330584, 43.76400702340262, 38.938281604221885, 42.30764375414167, 44.85552385875157, 50.46316480636597, 48.23453705651419, 50.548339298793245, 47.813319887433735, 47.513136863708496, 44.261623110089985, 41.031579290117534, 35.90483358928135, 35.67322928564889, 35.803699084690635, 37.86371142523629, 36.85326269694737, 40.917521136147634, 41.56473193849836, 41.55220433643886, 42.95131097521101, 47.00919444220406, 46.74647610528128, 48.924583503178184, 49.031158447265625, 47.8026613507952, 46.767445768628804, 48.740914821624756, 48.194418157849995, 49.23082883017403, 51.01133598600115, 50.22187123979841, 51.52671166828701, 50.93151160648891, 54.22465549196516, 52.466267926352366, 54.30728346960885, 55.2045773097447, 53.80163179125105, 55.623400824410574, 52.8333169392177, 54.7614802633013, 48.92794643129621, 48.59812239238194, 43.68295281273978, 42.43149886812483, 43.442871706826345, 21.421443905149186, 3.634432234934398, 3.80996435880661, 1.1783743117536818, 0.7913772921477045, 0.6709669647472245, 34.874245507376536, 56.507701533181326, 54.537098612104145, 55.844186782836914, 57.53596544265747, 55.206356048583984, 60.436424936567036, 42.78873702457973, 43.164829117911204, 60.85511643545968, 30.668393203190394, 44.90072883878435, 31.757401738848003, 32.324489389147075, 54.16975430079869, 5.784939433847155, 0.10846522729843855, 0.08493508491665125, 0.06828654969909362, 0.018466647747637968, 0.03730604870777045, 0.03472376834335072, 0.018432904201160585, 0.014348513546532818, 0.0290104627742299, 0.08054164530975477, 0.17022478580474854, 0.10016149215932403, 0.12728637057755673, 0.1477998684027365, 0.19748239245797905, 0.37833405445728985, 0.13692453982574598, 0.13570218613105162, 0.12854543301676, 0.11042740129466568, 0.09692423551210336, 0.15149849493588718, 0.19988029450178146, 0.11271604562976531, 0.2094106173941067, 0.42647139142666546, 2.385941914149693, 61.080008779253276, 60.66936329432896, 42.390091078622, 42.210188320704866, 38.17169727597918, 61.318165234157014, 44.53728594098772, 12.91564244883401, 78.76515442984444, 61.76594189235142, 75.8668384552002, 58.40003994532994, 73.02752658299038, 53.53203821182251, 65.51193114689418, 11.576913918767657, 10.552569661821638, 2.2839508269514357, 0.8299224781138557, 22.067437035696848, 48.425452709198, 56.56764711652483, 58.88905416216169, 56.41366808755057, 58.123633657182964, 62.47379657200405, 59.27751404898507, 63.281489917210166, 55.986638750348774, 55.8050024168832, 56.15755748748779, 57.42292519978115, 55.30181040082659, 59.042192459106445, 57.147383962358745, 60.182572501046316, 58.200133323669434, 56.88092054639544, 60.2194813319615, 58.26345920562744, 57.085454668317524, 57.5312510899135, 54.01300294058663, 52.39096335002354, 57.93097748075213, 55.56164870943342, 54.51387425831386, 48.55794095993042, 47.202594075884136, 42.40992818559919, 43.76649100439889, 41.70679828098842, 40.77799783434187, 39.403880391802105, 41.95626640319824, 41.40168898446219, 43.364485604422434, 48.18443707057408, 49.26330123628889, 48.61876201629639, 48.72372497831072, 41.717724323272705, 44.79436581475394, 40.53376170567104, 41.9061073575701, 44.55916929244995, 49.691730635506765, 45.749975885663716, 56.38262006214687, 52.184511525290354, 64.46478203364781, 13.841520309448242, 11.7607467515128, 29.86189147404262, 27.02606064932687, 67.42671571459088, 45.82519360951015, 58.760248456682476, 50.519184657505576, 49.71896757398333, 40.11866937364851, 48.67456299918038, 39.93392719541277, 43.015192713056294, 43.13398953846523, 53.12086813790457, 49.8803915977478, 51.97930690220424, 48.57257386616298, 50.47848558425903, 44.95353167397635, 43.75247648784092, 37.19875144958496, 38.48950093133109, 37.423869609832764, 41.62512220655169, 38.745000089917866, 44.33095918382917, 42.60086120877947, 45.788083280835835, 45.0233610698155, 51.01742260796683, 50.04588726588658, 52.85109043121338, 51.70981059755598, 50.42181607655117, 47.841692856379915, 51.37424039840698, 49.917189257485525, 54.61264290128435, 54.3696539742606, 54.63334853308541, 52.15361636025565, 53.421884945460725, 57.52485179901123, 55.41227981022426, 55.35978616986956, 57.49687487738473, 53.491095951625276, 57.877914088112966, 51.697845799582346, 57.2850729397365, 48.43123013632638, 50.819127968379426, 47.51776783806937, 45.715443338666645, 43.590451444898335, 26.740192651748657, 5.468594031674521, 9.650135023253304, 2.1705950924328397, 5.595238847391946, 1.1771179905959537, 38.9289744922093, 59.32108620234898, 58.64904253823416, 58.03672906330654, 63.4294170652117, 56.816545486450195, 67.28855078560966, 44.99872970581055, 52.3949168750218, 63.95504134041922, 42.61595269611904, 54.33585098811558, 41.818723337990896, 46.71384736469814, 63.42444215502058, 17.719455855233328, 0.43532722336905344, 0.31359749819551197, 0.17371735482343606, 0.15856470433729036, 0.16076987529439585, 0.20530193857848644, 0.08593739649014813, 0.1956205466496093, 0.2639307975769043, 0.31306134696517673, 0.2583361949239458], [0.03264050977304578, 0.06435245794377156, 0.162559036431568, 0.021619479371500865, 0.04115266712116344, 0.03763848676213196, 0.0972040429977434, 0.0022502165645294425, 0.04456491794969354, 0.07749024618949209, 0.014438875751303775, 0.024185405345633626, 0.13822265874062264, 0.06528615605618272, 0.12470687899206366, 0.23777720811111586, 16.79128769465855, 46.46839182717459, 31.197522844587052, 18.982607092176163, 27.80441175188337, 39.16513334001814, 48.73768738337925, 9.83140310219356, 42.93403427941458, 63.37749317714146, 57.86321169989449, 60.24279948643276, 55.507081031799316, 50.97745656967163, 57.92435237339565, 19.979725701468332, 0.7416282445192337, 3.10031487260546, 0.35265571091856274, 3.731509642941611, 28.135887725012644, 51.78031744275774, 53.051549434661865, 51.818727084568565, 53.44307695116316, 58.595492771693635, 57.57421180180141, 56.668107645852224, 50.907460417066304, 47.75539970397949, 45.19615234647478, 44.76397786821638, 47.08546829223633, 48.630765029362266, 51.11395740509033, 50.98713193620954, 51.42283957345145, 56.758743422372, 51.692381041390554, 52.1360513142177, 52.77041837147304, 53.9621490750994, 44.78000388826643, 49.87705993652344, 54.704734325408936, 49.78624350684029, 49.73949950081961, 42.481543268476216, 43.53722129549299, 40.3722299848284, 37.033905438014436, 34.29839270455496, 37.047179971422466, 34.10186638150896, 37.36346544538225, 37.869429792676655, 39.13137551716396, 44.04350873402187, 45.10262264524187, 41.25239651543753, 38.3200934273856, 35.302070413317, 38.06340960093907, 35.90448617935181, 37.399474484579905, 35.80492544174194, 42.547502517700195, 41.178773403167725, 47.41654648099627, 44.42231409890311, 54.381594453539165, 26.19047028677804, 11.862246905054365, 14.450185111590795, 34.061076981680735, 54.954126017434255, 40.92319434029715, 51.42808893748692, 41.88793434415545, 45.54056065423148, 36.29125417981829, 38.35037020274571, 34.99922970363072, 38.74816499437605, 36.38685097013201, 41.93805864879063, 46.280804361615864, 45.566758837018696, 44.29750708171299, 46.194518157414024, 41.550859860011506, 37.7744722366333, 36.03608158656529, 34.684577056339805, 34.077822140284944, 35.996195452553884, 34.3641539301191, 36.6982935496739, 40.23967225211007, 41.434960433415, 41.045017106192454, 43.82793739863804, 50.397528648376465, 46.596370697021484, 48.48521416527884, 46.723470619746614, 46.157921995435444, 47.015027454921174, 48.05198008673531, 47.56869465964181, 50.07114396776472, 49.9803900718689, 49.87837662015642, 49.372655459812705, 51.23241376876831, 48.93382460730416, 50.975848061697825, 51.380664008004324, 51.54879304340908, 51.01379912240164, 52.809189319610596, 49.53265162876674, 47.48912736347744, 41.26343025479998, 42.091422762189595, 44.135839870997835, 40.31188488006592, 11.500159774507795, 0.2601416680429663, 0.03586721859340157, 0.426093583128282, 0.9826992516006742, 3.2563434030328477, 48.566615785871235, 51.89691516331264, 52.97762060165405, 48.34363767078945, 50.94122518811907, 47.43034907749721, 52.001627990177695, 24.46022466250828, 49.3571366582598, 36.07183354241507, 29.005492993763514, 31.168149335043772, 19.169788088117325, 37.465228761945454, 31.072979858943395, 0.27105647378734177, 0.2688596216695649, 0.020988475730908767, 0.06661778781563044, 0.03679026370601995, 0.032811582021947415, 0.018645168614706824, 0.05459214221420033, 0.05068838775956205, 0.03686159469985536, 0.1022801295455013, 0.049021335784345865, 0.02941049648714917, 0.045053883854831965, 0.08492099174431392, 0.06655772389577967, 0.01276849556182112, 0.027014450236622776, 0.08335629677666084, 0.02545452367381326, 0.11767645552754402, 0.09478393928813082, 0.11768904913749013, 0.09140001729662929, 0.13050563926143305, 0.06904830703777926, 0.21234271648739064, 0.18041220200913294, 21.006553070885793, 57.7193284034729, 31.071451255253383, 23.657742466245377, 38.77908795220511, 43.187553201402935, 57.550410747528076, 11.904870629310608, 48.35777030672346, 71.11866188049316, 62.40868500300816, 62.410380363464355, 62.66414942060198, 54.482989515577046, 62.12816538129534, 22.12668432508196, 1.4212475078446525, 2.8355769983359744, 0.14842409347849234, 5.3111865009580335, 34.18990353175572, 55.46064622061593, 55.27307265145438, 55.676832471575054, 56.51620265415737, 60.0868193762643, 60.11583505358015, 60.5202271597726, 51.787421975817, 51.45443650654384, 47.54320519311087, 48.32542296818325, 50.62826790128435, 51.34991128104073, 53.97119215556553, 55.11008528300694, 54.83270277295794, 56.799650941576274, 51.32855599267142, 55.60650975363595, 55.73944616317749, 57.19308921269008, 47.30652175630842, 53.63731384277344, 56.69803006308419, 53.07832431793213, 53.05515554973057, 44.695037841796875, 43.80634934561593, 42.63807576043265, 37.76056889125279, 36.78530584062849, 37.6827004296439, 37.03457246507917, 38.8796318599156, 39.21575444085257, 40.803077357155935, 44.34821850912911, 47.47478975568499, 44.41334050042288, 42.00191606794085, 37.59484045846121, 41.10549075262887, 36.71795695168631, 40.30047246388027, 38.90480170931135, 46.1212910924639, 45.34877300262451, 50.65446260997227, 47.95126594815935, 57.9136278288705, 30.764841147831508, 14.678430829729352, 17.881760563169205, 37.05650097983224, 57.91304070608956, 44.74547828946795, 53.335334709712434, 44.59904500416347, 45.33624887466431, 39.258471965789795, 40.86844948359898, 38.34850113732474, 40.56748826163155, 40.237132685525076, 45.85221862792969, 48.514803068978445, 48.939626353127615, 47.636866910117014, 46.24580628531319, 43.83891207831246, 40.486840520586284, 37.41226611818586, 37.76866701671055, 36.49539920261928, 38.17389290673392, 37.20243052073887, 40.73261220114571, 40.654545715876985, 42.385630335126606, 42.539508615221294, 45.741801330021445, 51.13686561584473, 48.62672812598092, 49.928688526153564, 46.081662041800364, 45.72407994951521, 48.13685233252389, 48.314771379743306, 48.99148770741054, 52.55362067903791, 51.6401583807809, 50.7380633354187, 51.63286624635969, 52.44473893301827, 50.27564682279314, 51.687475613185335, 52.740440368652344, 55.1135003226144, 52.55338096618652, 54.909740924835205, 51.4024327141898, 49.83753163473946, 43.915647983551025, 47.55310985020229, 51.012308733803884, 45.048933914729524, 14.844016824449811, 0.6852027922868729, 0.25621048041752403, 0.5937259580407823, 0.418471952102014, 5.466877392360142, 56.959511620657786, 57.23064422607422, 58.282052585056846, 53.176651750292095, 55.77901268005371, 50.88509069170271, 56.92096996307373, 27.32280605179923, 51.6343149457659, 41.91284711020333, 28.198060206004552, 44.548649719783235, 17.551342453275407, 41.86325434276036, 32.828084400721956, 0.4305494411715439, 0.18699315030659946, 0.012012307299301028, 0.007175523937413735, 0.0527337874685015, 0.08171162288635969, 0.04488791079659547, 0.05454104174194591, 0.06675919451351676, 0.06579194284443345, 0.052788239903748035, 0.052480520880115886, 0.08646997184093509, 0.16747669183782168, 0.26144936787230627, 0.24072622986776487, 0.23988671920129231, 0.19555120037070342, 0.20526151146207536, 0.1203553524932691, 0.1890448366424867, 0.25446270991648945, 0.24199099200112478, 0.1430381539144686, 0.20601049198635987, 0.12650767021945544, 0.3688228391110897, 0.46470811537333895, 34.73007386071341, 65.08884838649205, 48.24344464710781, 29.66443756648472, 44.32740865434919, 51.9698816708156, 60.220662525721956, 13.422991224697657, 55.14329767227173, 78.2509252003261, 68.5230302810669, 70.30609089987618, 63.75462750026158, 59.478066853114534, 70.13877132960728, 23.899367809295654, 5.253777878625052, 9.933362705366951, 0.6349044569901058, 8.566232545035225, 42.70217636653355, 56.32257372992379, 56.40814079557146, 56.18303305762154, 56.265073912484304, 62.1359543119158, 65.2279999596732, 64.23665877750942, 54.90903220857893, 55.88866220201765, 50.931000913892476, 52.48994391305106, 54.02351903915405, 55.70687648228237, 56.85559088843209, 59.19200256892613, 58.2359756061009, 59.82667882101876, 55.00915922437395, 57.44065005438668, 59.158908299037385, 60.68353067125593, 50.461420808519634, 54.91127300262451, 61.1912841796875, 56.42429883139474, 57.870719228472026, 46.79309851782662, 47.25314916883196, 44.56217091424124, 41.227747780936106, 39.46120997837612, 43.10063818522862, 39.499605723789756, 42.97207566670009, 42.45259359904698, 42.56524821690151, 46.94442680903843, 50.67905923298427, 46.048449652535574, 45.503161975315635, 39.11199351719448, 44.27597461427961, 39.83250781467983, 44.42514548982893, 40.534939425332205, 50.87588085447039, 47.46760531834194, 55.04911831447056, 50.91870955058506, 63.71046475001744, 26.930507285254343, 9.87158019202096, 15.89466609273638, 35.1118426322937, 62.823791231427876, 48.08816977909633, 57.6350919178554, 47.448796544756206, 50.82162931987217, 41.592166900634766, 42.2289206641061, 38.86828197751726, 44.53625413349697, 41.46614742279053, 47.153904574257986, 50.40201718466622, 50.021926403045654, 47.682933466775076, 49.53708110536848, 46.169403893607004, 42.8343380519322, 39.95752675192696, 42.074281556265696, 36.881465435028076, 40.454437596457346, 37.90657833644322, 41.78554221561977, 42.85617971420288, 45.78054101126534, 45.87498092651367, 48.92455571038382, 53.62252460207258, 51.7894994871957, 54.48755100795201, 48.955833026341026, 46.915112359183176, 51.54973799841744, 52.56450155803135, 52.93798460279192, 53.070823737553184, 53.51698841367449, 52.43035268783569, 53.606665338788716, 56.067467144557405, 53.485787527901785, 53.70349890845162, 55.35642671585083, 55.64364440100533, 54.17652532032558, 55.5222350529262, 53.718802315848215, 50.91059405463082, 48.594842842647004, 47.299570083618164, 50.16683455875942, 49.15396785736084, 19.671625205448695, 1.530324129121644, 0.5987808810813087, 2.5018074682780673, 2.9024783798626492, 5.298610261508396, 61.84888253893171, 60.287684849330354, 64.8922699519566, 58.133274282727925, 61.60976028442383, 56.5055684362139, 63.601343291146414, 33.02040358952114, 60.086444173540386, 43.65759883608137, 41.87430545261928, 44.32477181298392, 31.083676610674175, 50.27797099522182, 51.39595004490444, 0.8714577779173851, 0.4454515358167035, 0.19929317172084535, 0.19081718368189676, 0.18803479655512742, 0.1177214966820819, 0.10706760800842728, 0.34386173422847477, 0.15900073094027384, 0.3274864586336272, 0.2218812903655427, 0.16590344054358347], [0.08204690060977425, 0.10023300975028958, 0.05531562678515911, 0.007330541199605379, 0.026933955627360513, 0.03915933818955507, 0.030195195094815323, 0.03948889925543751, 0.041094065444277864, 0.12767760029860906, 0.06140290014445782, 0.05694024996565921, 0.08106845989823341, 0.05762555676379374, 0.04459548595228365, 0.05858921219727822, 1.6320760462965285, 39.59201329095023, 38.12959466661726, 28.700953449521744, 27.534039974212646, 23.156084265027726, 45.977439062935964, 29.15721559524536, 39.233267375401084, 66.21343517303467, 57.37411410467965, 57.43477535247803, 57.07572719029018, 51.436239174434114, 49.10133525303432, 31.751290798187256, 0.6502827746527535, 2.8347345292568207, 0.08512048103979655, 1.6375675116266524, 24.931289945329937, 51.74038961955479, 55.96039540427071, 58.38476085662842, 53.24444532394409, 59.82528223310198, 55.10190725326538, 55.81419488361904, 51.50883395331246, 46.13347823279244, 43.70680945260184, 43.506009987422395, 41.90871640614101, 46.48574147905622, 50.709992613111226, 51.87160634994507, 48.22691488265991, 53.15147842679705, 60.26933465685163, 52.33199051448277, 56.11041396004813, 45.718330315181184, 48.17928498131888, 55.49543585096087, 52.164462498256135, 51.917009353637695, 50.162901878356934, 44.66912453515189, 40.529099464416504, 39.54499135698591, 38.8053799356733, 32.9694732938494, 35.55575956617083, 36.53901999337332, 37.217792987823486, 38.97540235519409, 40.41010461534773, 42.75945036751883, 45.591720240456716, 39.95030757359096, 35.24757916586739, 35.92568513325283, 36.97380004610334, 36.23433106286185, 36.72472102301461, 35.97423219680786, 41.72817441395351, 43.3296924999782, 47.09367411477225, 46.558426584516255, 51.63347768783569, 36.01467071260725, 13.454962491989136, 13.539427399635315, 45.8910243170602, 51.01577935900007, 44.51243570872715, 48.23372759137835, 46.22670568738665, 43.832134110586985, 38.66684675216675, 36.316358021327424, 37.27334383555821, 36.71652562277657, 38.083166803632466, 37.95181458336966, 43.08529656273978, 46.68064887183053, 44.47307416370937, 40.86988428660801, 39.93552875518799, 41.32140254974365, 35.94808612551008, 34.87443658283779, 34.18519960130964, 32.99312843595232, 34.512129715510774, 37.725442273276194, 38.78148855481829, 40.69589097159249, 42.062111786433626, 43.88293586458479, 47.56531088692801, 46.72316837310791, 47.93530593599592, 45.91566262926374, 47.09800284249442, 47.80972766876221, 48.28048549379621, 48.57978957039969, 49.297667026519775, 48.4435110773359, 50.98907743181501, 48.535571234566824, 48.45579549244472, 48.19599539893014, 47.30781759534563, 46.79384197507586, 48.86881031308855, 50.12476321629116, 50.89617306845528, 50.88683468954903, 53.34707021713257, 52.60547161102295, 47.79054021835327, 33.802086353302, 29.36851031439645, 9.880409615380422, 0.39017921313643456, 0.16168900525995664, 1.1055610988821303, 0.6095136765922818, 5.092837188925062, 47.83557844161987, 48.57436302730015, 54.50690868922642, 49.155833448682515, 46.539458002362935, 54.81838948386056, 47.91270692007882, 40.58224276133946, 61.38926615033831, 32.12687219892229, 30.018257209232875, 23.030090842928203, 23.1926908493042, 43.41572509493147, 10.89976680278778, 0.16985822761697428, 0.07061388410095658, 0.021756385685876012, 0.10184932087681123, 0.02182511449791491, 0.044300957649414024, 0.006516318685109062, 0.04620160209015012, 0.017811133725834743, 0.0824959415144154, 0.08846764678933791, 0.05735160503536463, 0.037333658297679255, 0.01730332151055336, 0.07120881681995732, 0.07636131319616522, 0.054433198778757026, 0.10451077270720686, 0.022115279820614626, 0.06842970701732806, 0.009910598513670266, 0.08305901701429061, 0.15699909334736212, 0.033120105109576664, 0.08866628113069705, 0.035729014580803256, 0.0774884345009923, 0.07932912358748061, 2.2736972400120328, 50.462727069854736, 44.382841382707866, 26.682126556124004, 42.588097367967876, 28.305574893951416, 53.46747555051531, 32.114886556352886, 45.58286823545183, 70.67041274479458, 64.20921339307512, 62.36000592367989, 61.23675319126674, 56.425473076956614, 56.87121738706316, 35.18938452856881, 0.6068829149007797, 2.3541178618158614, 0.4927478964839663, 3.4269271067210605, 29.830711432865687, 54.77953168324062, 57.06813975742885, 60.31966045924595, 55.356482301439556, 61.262197494506836, 57.89344678606306, 58.62704454149519, 54.77932323728289, 49.419708660670686, 47.17704207556588, 46.285675048828125, 44.07415723800659, 48.162508555821006, 52.546085357666016, 53.35901069641113, 50.40862144742693, 58.00848463603428, 59.85510390145438, 51.62055056435721, 56.867680753980366, 48.99630280903408, 49.54546410696847, 57.10918971470424, 53.60199267523629, 53.01766307013375, 52.16108914784023, 46.11597572054182, 42.24938310895647, 42.08746228899275, 39.42339093344552, 36.881788526262554, 39.019155161721365, 38.696744850703645, 38.233164514814106, 41.468666144779746, 43.60933664866856, 45.65676927566528, 47.41294731412615, 42.91116080965315, 38.83146347318377, 38.33587278638567, 39.46807132448469, 36.72656576974051, 37.17493997301374, 39.28481258664812, 44.36369562149048, 44.89252649034773, 48.26725959777832, 49.62527111598423, 53.91753469194685, 45.539539269038606, 21.785081352506364, 18.763113498687744, 53.01723575592041, 50.08996663774763, 49.46122762135097, 49.977464880262104, 47.78268527984619, 45.220884459359304, 42.875742367335725, 38.908776078905376, 40.16408627373831, 39.320255347660606, 40.42486258915493, 40.457341943468364, 46.175063201359336, 49.06450285230364, 46.39033229010445, 43.38777249200003, 41.67851563862392, 41.69041790281023, 37.596737316676546, 37.66632352556501, 37.257699966430664, 35.446252482278005, 36.892200401851106, 38.42863471167428, 38.76229068211147, 43.08697802679879, 42.285729135785786, 45.448719365256174, 47.694432735443115, 47.91502414430891, 47.42286239351545, 46.194667543683735, 48.43162270954677, 49.853800841740195, 50.29088074820382, 48.922648429870605, 51.74019506999424, 50.56839874812535, 52.93658801487514, 50.6855662209647, 51.72249453408377, 52.179220472063335, 49.742584500994, 49.67923777444022, 49.489458152226035, 53.24339962005615, 53.92972183227539, 54.33093513761248, 53.46929250444685, 54.00550930840628, 54.27259111404419, 43.234981604984824, 34.499980790274485, 11.917318327086312, 0.6558238001806396, 0.6697604209184647, 0.7890064907925469, 0.12652124091982841, 5.6369684253420145, 55.09886394228254, 52.774785314287456, 57.91066094807216, 51.666356563568115, 51.872770173209055, 56.44510521207537, 53.77938713346209, 43.44025223595755, 67.86728709084647, 35.675629888262065, 34.26624338967459, 31.5843186378479, 23.727742092950002, 51.414863041469026, 9.049647382327489, 0.1335192168397563, 0.1503764965704509, 0.026377450042803372, 0.07966429953064237, 0.030158740800938437, 0.06718311605176755, 0.024526043495695506, 0.03107872572062271, 0.04067978249596698, 0.045724310380007537, 0.09752886449652058, 0.03425920255748289, 0.23920251162988798, 0.11257060843386821, 0.18119942476706846, 0.6375653999192374, 0.21988870442977973, 0.21416686289012432, 0.11057163748357977, 0.18024411531431334, 0.13103345808173927, 0.321869925728866, 0.34182390357766834, 0.1961345640676362, 0.23044940988932336, 0.16939169407955237, 0.2286578874502863, 0.4654986358114651, 5.5950290986469815, 62.49017347608294, 54.45191369737898, 43.935429504939485, 45.057334286826, 36.983148847307476, 56.7884122303554, 37.625120707920615, 47.702107020786826, 80.98328345162528, 69.1343605858939, 68.51708957127163, 63.97978387560163, 60.92181914193289, 59.86706175122942, 41.398152351379395, 1.4673310007367815, 12.267397233418055, 1.775433993765286, 5.615276149341038, 36.16852814810616, 58.07077176230294, 57.559148107256206, 60.99715845925467, 54.36532524653843, 65.83038098471505, 59.87387793404715, 63.138079098292756, 57.67373432431902, 53.13832548686436, 50.05172722680228, 50.47788109098162, 47.24962295804705, 53.79630252293178, 56.70376927512032, 58.19320944377354, 55.02196128027779, 61.01218741280692, 60.37400926862444, 54.6687148639134, 61.133225032261436, 54.58737230300903, 48.98978887285505, 61.432011468069895, 60.131239209856304, 58.17034639630999, 56.971816880362375, 50.50437804630825, 45.27592461449759, 46.12591164452689, 43.58682448523385, 41.20994302204677, 41.57981300354004, 41.943610259464805, 43.427418913160054, 44.847092219761436, 45.98219163077218, 48.04297522136143, 51.19726630619594, 43.70394679478237, 39.92232370376587, 42.70754384994507, 42.81282295499529, 39.10468053817749, 41.03328159877232, 41.67415911810738, 49.67318589346749, 47.980740206582205, 53.873326778411865, 53.49842282703945, 56.17365646362305, 41.62511873245239, 14.380101237978254, 14.95634661402021, 51.563658714294434, 54.51393331800188, 50.408426897866384, 53.6310396194458, 52.044032846178325, 49.76169204711914, 45.79790803364345, 41.203564575740266, 41.97516202926636, 42.58161817278181, 42.22556121008736, 42.49212537493025, 47.66985695702689, 51.278945854731965, 47.16135999134609, 44.2733655657087, 42.56021424702236, 45.254440784454346, 40.13971199308123, 39.44117137363979, 39.19849164145333, 36.287950311388286, 39.6496798651559, 40.82669428416661, 41.59804507664272, 45.620805399758474, 46.43888630185808, 47.64740037918091, 52.40743405478341, 52.39221749986921, 51.54679543631417, 49.25193745749337, 51.117191791534424, 52.93282903943743, 52.18855537687029, 53.221749033246724, 54.31225143160139, 52.223167828151155, 56.42414249692644, 53.19460242135184, 53.1269964490618, 54.54276139395577, 51.49874516895839, 51.35411841528756, 51.371662616729736, 53.83141871861049, 55.42516871861049, 54.306168283735005, 54.85946028573172, 52.20499134063721, 54.05485194069998, 49.32027299063546, 40.75601373400007, 14.784630571092878, 1.4448277396815163, 1.2901843977825982, 4.908412890774863, 1.8600236432892936, 6.6034528613090515, 58.43050084795271, 58.503088678632466, 63.63464600699288, 57.952266761234824, 55.27813441412789, 64.32149628230503, 58.01919181006295, 50.4388495853969, 72.07503277914864, 40.69854865755354, 43.508233410971506, 37.07302032198225, 37.95024081638881, 62.30911036900112, 23.065915754863195, 0.3551318480500153, 0.29564310876386507, 0.11680638364383153, 0.24361174074666841, 0.10098223454718079, 0.20644212168242249, 0.08452462551317044, 0.17262211787913526, 0.09466630167194776, 0.3936219641140529, 0.22394029130893095, 0.28734850670610157], [0.09172054366873843, 0.05849680929843869, 0.028111714304291775, 0.09979988049183573, 0.1308944805392197, 0.08833324257284403, 0.07284468332571642, 0.061204238661697934, 0.07853595686278173, 0.06612501532903739, 0.04360469251072832, 0.0192531393840909, 0.032920629384794405, 0.03538450538845999, 0.14642504788935184, 0.053685836560492, 0.16823879522936686, 30.037486348833355, 52.62300191606794, 24.9197906766619, 25.89739179611206, 21.586338554109844, 46.82385471888951, 37.52452121462141, 38.801919732775005, 66.90412780216762, 55.3522960117885, 59.64143289838518, 53.57812213897705, 53.11980158942086, 53.08993475777762, 24.82470805304391, 0.6960823684930801, 1.4342773343835558, 0.1979343103510993, 2.50160271355084, 23.133973360061646, 55.78076015199934, 58.82707623073033, 61.79344981057303, 58.15025915418352, 57.502252783094136, 57.84084892272949, 57.449401310511995, 51.89173528126308, 43.72847740990775, 43.39144808905465, 42.586176191057476, 43.427933079855784, 40.81039381027222, 46.22795288903372, 47.96975857870919, 52.310687337602886, 50.74177714756557, 50.20552560261318, 53.3958500453404, 50.07372522354126, 48.86110128675188, 56.04950952529907, 53.34345367976597, 51.3537049974714, 52.978746209825786, 46.35629653930664, 42.48395429338728, 40.664398261478965, 39.044290270124165, 37.27684572764805, 33.58077927998134, 36.02253607341221, 38.09150116784232, 40.34919670649937, 39.50635589872088, 41.41535609109061, 43.317091941833496, 44.11107996531895, 38.67914506367275, 35.978623458317344, 36.10196787970406, 34.81914281845093, 36.05900369371687, 37.18240928649902, 37.261549268450054, 40.3674704687936, 43.9183577810015, 46.356661319732666, 48.79300199236189, 48.96799584797451, 43.52886956078665, 14.796466827392578, 15.62440722329276, 50.316071442195344, 48.250448431287495, 47.08185870306832, 44.73465299606323, 45.80582550593785, 44.2029629434858, 37.33963312421526, 37.396549292973106, 36.221268449510845, 37.27245446613857, 36.27949087960379, 38.28314290727888, 41.08443076269967, 45.17562389373779, 46.60797071456909, 42.10001768384661, 39.37485081808907, 40.71447740282331, 37.36257955006191, 33.44384765625, 35.00121341432844, 34.68088756288801, 34.57289171218872, 35.301639625004356, 37.37868547439575, 39.68531717572893, 38.95366839000157, 41.5075934273856, 46.429575715746196, 47.14640746797834, 49.118917669568745, 47.17283146721976, 48.02367312567574, 47.91708081109183, 48.65588624136788, 50.087149143218994, 48.51587309156145, 48.57985210418701, 47.328957489558626, 47.835321358272004, 47.43398993355887, 43.82137482506888, 42.52256195885794, 46.75036709649222, 45.212560517447336, 49.51450293404715, 52.3707058770316, 48.20103631700788, 53.106370721544536, 43.997574193137034, 40.14424221856253, 33.20499985558646, 40.87587363379342, 13.83282550743648, 0.4570158081395285, 0.8509101633514676, 0.7296414077281952, 0.18822036231202738, 3.8841758966445923, 44.02427612032209, 54.55698783057076, 51.006434031895225, 52.861366816929404, 56.113207135881694, 54.82750899451119, 49.645723138536724, 52.73945025035313, 47.49758332116263, 23.98857225690569, 30.278425557272776, 21.987227031162806, 30.67088065828596, 32.72448328563145, 1.5650519856384821, 0.20497605177972997, 0.08779323726360287, 0.05334743418331657, 0.04861377372539469, 0.10275477157639605, 0.03146108698898128, 0.05417766249073403, 0.089420954563788, 0.038009411322751215, 0.0610938070874129, 0.02872583090460726, 0.1230707410722971, 0.14124180030609879, 0.05813936383596488, 0.0496763697426234, 0.06276001767920596, 0.06448383589408227, 0.08834015005933386, 0.07513770421168633, 0.07706192095897027, 0.04692875414288469, 0.09282692894339561, 0.030892199836671352, 0.05324472773021885, 0.04060532345569559, 0.01879385090433061, 0.08309020248374768, 0.04204315273091197, 0.43861977383494377, 35.834201676504954, 63.938025202069966, 24.94659856387547, 37.97356244495937, 30.357589857918875, 47.105076108660015, 44.034309319087434, 45.270029067993164, 74.28301743098667, 61.43921675000872, 66.8660169328962, 60.04549843924386, 58.676536560058594, 56.902209826878135, 30.375158378056117, 0.17213867524904863, 0.9660802462271282, 0.25127405673265457, 3.97145699603217, 27.726095131465367, 58.47852679661342, 61.77572495596749, 62.480696133204866, 61.79513822283064, 61.03913252694266, 61.4933362688337, 59.912753105163574, 54.90204232079642, 46.62421907697405, 46.95059680938721, 44.4421512058803, 45.62928567613874, 45.10004138946533, 49.119379724775044, 52.00693988800049, 53.70442301886422, 52.342854022979736, 52.678434644426616, 54.482850551605225, 50.737688132694785, 50.40880904878889, 58.706490244184224, 54.619657107761924, 53.01022154944283, 54.44040400641305, 48.12115287780762, 43.08990321840559, 42.71229294368199, 40.60061032431466, 38.41512393951416, 36.33375631059919, 37.63946526391165, 39.434633118765696, 40.62922995431082, 40.932202679770334, 41.780786173684255, 45.34322486604963, 47.67413704735892, 40.91921649660383, 38.73147194726126, 37.845253535679404, 37.3044022832598, 36.866269724709646, 40.950031757354736, 41.70779882158552, 44.23124211175101, 48.07866811752319, 46.660909039633616, 52.29718351364136, 51.18811900275094, 52.70187439237322, 26.267755099705287, 23.636109249932424, 58.197371414729524, 49.608192443847656, 50.01136861528669, 47.00758246013096, 49.68553979056222, 44.80851582118443, 41.857070446014404, 39.053611278533936, 38.314566135406494, 38.120141642434255, 40.57462058748518, 40.06792320523943, 43.87751626968384, 46.71970122201102, 48.663987840924946, 43.48778486251831, 42.22285836083548, 40.80083308901106, 39.33536767959595, 35.86524622780936, 36.88933079583304, 36.02695860181536, 36.92012173788888, 37.455866064344136, 38.79698303767613, 40.34464563642229, 40.88352012634277, 42.51258087158203, 47.947340215955464, 47.50039734159197, 51.461846760341096, 47.4554876599993, 48.912365095955984, 49.5871706690107, 49.95945862361363, 50.051056725638254, 50.41936683654785, 49.40109096254621, 50.52081053597586, 50.55504431043352, 51.37742267336164, 45.980989592415945, 45.96436602728707, 49.957655566079275, 48.72911330631801, 50.10517277036394, 54.83675009863717, 52.21709510258266, 55.72546986171177, 49.446257727486746, 46.660822187151226, 41.595672266823904, 45.35496037346976, 16.191778012684413, 0.2973697361137186, 0.8036613815597126, 0.441282046692712, 0.31127137158598217, 5.085995818887438, 48.148306437901084, 59.24171692984444, 55.81550809315273, 57.64451714924404, 58.35161794934954, 58.271230765751426, 55.91523558752877, 53.848139558519634, 54.839782987322124, 26.577345984322683, 38.160187585013254, 25.12218301636832, 32.77000093460083, 38.24698100771223, 0.27780404314398766, 0.10994215376142945, 0.042787682065474134, 0.04533290084717529, 0.02938445092045835, 0.1007047069392034, 0.044180670353983126, 0.08370850394879069, 0.06500812633229153, 0.056682596648378034, 0.1700450147369078, 0.07398321758955717, 0.07804877550474235, 0.2852016490484987, 0.2210991159081459, 0.08545711583324841, 0.2501791726265635, 0.26346933948142187, 0.19200067089072295, 0.1964428632387093, 0.13649212302906172, 0.2124228650437934, 0.22371678187378816, 0.12286287865468434, 0.17838689711477074, 0.1361451202205249, 0.12702054769865104, 0.2838569012071405, 0.1964393077152116, 0.5468985736370087, 50.81417390278408, 70.18154444013322, 45.158381938934326, 41.19288519450596, 38.88303647722517, 57.47231994356428, 49.35611179896763, 48.792658056531636, 80.21743910653251, 66.151700428554, 73.24872248513358, 62.46342985970633, 62.191755294799805, 63.76855863843645, 33.11837666375296, 1.7407012517963136, 5.526640585490635, 1.1983562452452523, 6.3383326189858575, 33.807380880628315, 62.958746092660085, 62.049886975969585, 65.96775381905692, 61.52204622541155, 63.781697681971956, 66.18985298701695, 61.65380491529192, 57.36720412118094, 51.2124376978193, 50.30568388530186, 48.61986330577305, 49.500665596553254, 49.29216752733503, 53.823751381465364, 54.90281009674072, 57.50205823353359, 59.601584979466026, 55.790154116494314, 58.62261159079415, 54.37485122680664, 53.408474922180176, 58.64988327026367, 61.04630306788853, 56.41919885362898, 59.61840656825474, 50.52725499016898, 46.97359882082258, 45.54116514750889, 42.22374078205654, 41.43064212799072, 40.313118185315815, 40.754697050367085, 43.248610496520996, 44.920340129307334, 43.83969375065395, 45.5889652797154, 45.753522941044395, 49.59518889018467, 42.44087198802403, 41.97002731050764, 40.07288769313267, 40.89016955239432, 40.70788703645979, 44.44302667890276, 43.42665808541434, 47.654025486537385, 50.97514976773943, 52.07345846721104, 56.093502044677734, 55.516040733882356, 52.52462584631783, 19.0325767993927, 16.730127913611277, 58.1810952595302, 52.60700021471296, 52.36128759384155, 50.29199593407767, 52.73988798686436, 49.16419907978603, 44.25367784500122, 42.13272980281285, 40.77703898293631, 40.94568565913609, 42.245200293404714, 41.44105052947998, 44.897153990609304, 48.34803588049752, 51.074331828526084, 44.75102295194353, 43.51147474561419, 43.90218932288033, 42.28153937203543, 37.28276211874825, 39.06321716308594, 39.45348705564226, 39.36034992762974, 39.46793930871146, 40.31337179456438, 43.07249450683594, 43.322751249585835, 45.35987622397286, 53.74906519481114, 50.299326283591135, 56.05211162567139, 49.27459553309849, 52.16098492486136, 51.91551896503994, 53.05123329162598, 52.45831571306501, 52.270262718200684, 52.214659758976524, 53.07632671083723, 52.53934907913208, 53.28564119338989, 47.853310244424, 49.448845931461875, 52.09234367098127, 48.8803061076573, 51.72873054231916, 57.16951397487095, 51.21131903784615, 56.804257597242085, 51.377012729644775, 52.69412020274571, 43.463556494031636, 49.890570708683555, 19.179548570087977, 0.742785282433033, 2.3168090752192905, 2.198402000325067, 0.7103392577597073, 7.710124152047293, 51.92195299693516, 65.32562214987618, 60.56311838967459, 62.06954342978341, 62.40651021684919, 66.0667587007795, 61.713406562805176, 63.272957529340474, 57.20893457957676, 35.33083595548357, 43.16489512579781, 35.65379170009068, 43.43853603090559, 54.80601474217006, 5.908512277262552, 0.5409090093203953, 0.18891649852905953, 0.19861211255192757, 0.17408887988754682, 0.17909146073673451, 0.10409266621406589, 0.13113366413329328, 0.1734486956681524, 0.1338953695126942, 0.430842893996409, 0.1838581013892378, 0.19978884155196802], [0.08618518390825816, 0.0460635032504797, 0.026601551499749933, 0.06851164690618004, 0.06594010096575532, 0.02920563319431884, 0.0325938570978386, 0.029370445957673446, 0.05520685422899468, 0.056689405747290166, 0.06450985092669725, 0.07275770870702607, 0.057394759862550666, 0.07364766166678496, 0.07401356846094131, 0.06398693112922565, 0.15667028884802545, 6.774749406746455, 44.925377573285786, 33.98990658351353, 23.978257656097412, 24.111254862376622, 42.79576512745449, 52.73483664648873, 26.370058638708933, 55.53846951893398, 60.5772579738072, 53.60055439812796, 54.090398924691335, 55.90766552516392, 54.96997833251953, 19.97169358389718, 0.2510847183210509, 0.4250772190945489, 0.22757409060639994, 2.5628873450415472, 24.877992050988333, 59.55271829877581, 62.18869808741978, 58.58584172385079, 55.662300314222065, 58.121337277548655, 55.19083377293178, 56.16164650235857, 52.928750446864534, 43.45776169640677, 40.345496790749685, 40.41712229592459, 41.14360162190029, 38.97541972569057, 40.58537639890398, 45.3078932762146, 50.114212376730784, 51.10089826583862, 51.269409452165874, 51.65600374766758, 54.67792470114571, 57.84825222832816, 51.18908827645438, 50.78533887863159, 52.62024348122733, 50.3779798916408, 44.86152015413557, 37.5164578301566, 38.419063568115234, 36.36286926269531, 35.021137373788015, 34.4200313431876, 35.401985509055, 38.80560575212751, 38.69073813302176, 41.53919383457729, 42.483169146946494, 43.89285789217268, 42.11148568562099, 35.867928232465474, 34.645733152117046, 36.33622292109898, 35.061165945870535, 34.8280782018389, 36.225958483559744, 39.64836665562221, 41.80388198580061, 44.588963168007986, 45.326427595955984, 48.67790160860334, 49.38552699770246, 47.978058201926096, 14.177852204867772, 22.887730939047678, 53.67540386744908, 47.2664931842259, 48.31472969055176, 44.206113951546804, 46.747636454445974, 43.584302289145334, 37.46291848591396, 35.507285458701, 37.401524203164236, 34.55981867653983, 38.060355867658345, 36.46427127293178, 40.131888321467805, 44.953760964529856, 47.27979898452759, 44.3363926751273, 38.91243430546352, 39.905512537275044, 39.01835264478411, 36.16462673459734, 34.4153482573373, 33.57966756820679, 34.67663179125105, 34.458819661821636, 38.9375833102635, 38.24953099659511, 39.30274241311209, 38.27663244519915, 42.897285257067, 47.544469765254426, 47.8526223727635, 46.02370364325387, 49.13119861057827, 49.09153481892177, 49.61173602512905, 45.9143077305385, 47.37280062266758, 48.752087524959016, 48.518412658146445, 48.181581360953196, 45.99713025774275, 44.154877935137065, 44.379308223724365, 42.46706322261265, 47.818267004830496, 49.40806000573294, 49.98117869240897, 45.10803181784493, 46.11274480819702, 44.10940544945853, 48.485016141619, 41.345227922712056, 39.60461037499564, 16.818715708596365, 0.1368817106953689, 0.3201240279844829, 0.1687788548214095, 0.24919996517045157, 1.9430715526853288, 30.603618621826172, 53.86319283076695, 50.94785029547555, 53.62963260923113, 50.193706716809956, 53.89117322649275, 46.27587114061628, 56.6095586504255, 38.689285959516255, 21.829805169786724, 32.928524085453574, 21.305141483034404, 41.186458110809326, 15.679304940359932, 0.10274732804724149, 0.050719776789524725, 0.06528157594480685, 0.06671060462083135, 0.0595364063712103, 0.024583868249984722, 0.006579145090654492, 0.05100434759099569, 0.03892402903043798, 0.049225279662225924, 0.10795791380639587, 0.04970108538067766, 0.02005528482342405, 0.04210342699661851, 0.04604622096355472, 0.010846260984960412, 0.05001129123515316, 0.041191347009901486, 0.06008546333760023, 0.007501597333300326, 0.027505816459389668, 0.0464723579186414, 0.12429606675037316, 0.04017042322084308, 0.011041904683224857, 0.06752114862735782, 0.04942030758996095, 0.039377609334353886, 0.09531576146504708, 0.12771259913487093, 7.215189635753632, 57.87839698791504, 34.934531552451, 27.904073238372803, 35.40310764312744, 45.54433700016567, 58.883217675345286, 30.12076050894601, 63.64556162697928, 66.57255281720842, 57.70121444974627, 58.41724368504116, 59.47295992715018, 60.222608021327424, 24.12448944364275, 0.121544213699443, 0.6485230890767915, 0.32249670209629194, 3.943680703639984, 29.431738921574183, 62.26848425183977, 65.4424352645874, 62.84578227996826, 58.724110875810894, 60.51051357814244, 57.137170110430034, 59.17821734292166, 53.99736254555838, 46.6028151512146, 45.77092123031616, 44.33887318202427, 42.96251147133963, 43.33235713413784, 42.983832018715994, 48.552507468632285, 52.549934659685405, 55.34067167554583, 52.287011350904194, 54.67584718976702, 56.881160259246826, 57.930272238595144, 52.419058391026084, 54.088769572121755, 55.068458625248496, 52.83514084134783, 47.81732899802071, 41.16031551361084, 41.14724595206124, 40.681317125047954, 36.86375100272042, 37.147689138139995, 36.70675645555769, 40.098307677677695, 40.80074623652867, 41.83811923435756, 43.84981380190168, 45.285259519304546, 46.421147550855366, 39.076307569231304, 39.49451616832188, 40.236086981637136, 36.849333490644185, 36.42800167628697, 38.680246353149414, 41.794522762298584, 45.51927832194737, 48.12219163349697, 47.504465511866975, 50.75573607853481, 50.65535197939192, 55.30877249581473, 27.67873099872044, 33.264681407383506, 59.69873469216483, 49.68091229030064, 53.115347794124055, 48.3528197152274, 47.448417867933, 44.82779707227434, 40.960287298474995, 39.749160698481965, 39.254296098436626, 36.200809478759766, 39.75299957820347, 38.77558953421456, 42.11871181215559, 45.7861065183367, 50.72167600904192, 45.872795718056814, 40.95814725330898, 40.424852166857036, 39.92169836589268, 37.63126638957432, 36.211846692221506, 35.04246834346226, 36.33855404172625, 36.689705576215474, 39.71720593316214, 38.87377800260271, 41.49920695168631, 39.5305495262146, 44.87147344861712, 47.60538462230137, 51.092556953430176, 47.424741881234304, 49.202146666390554, 49.03333323342459, 51.45612491880144, 47.33516223090035, 49.83540201187134, 49.95924322945731, 50.23944670813424, 50.95377710887364, 48.95357486179897, 46.30860757827759, 45.4578458241054, 44.31445026397705, 49.83746910095215, 51.2916819027492, 53.043180329459055, 48.10272625514439, 48.691127504621235, 47.13624225343977, 51.7341570854187, 46.78442716598511, 45.71146202087402, 19.389778477805002, 0.08056788425892591, 0.2494768074580601, 0.38600592421633856, 0.22748601676097938, 2.991474164383752, 35.0645740372794, 59.83109092712402, 55.44057982308524, 59.2465181350708, 54.44247109549386, 58.870036942618235, 49.289391721997944, 61.843852043151855, 43.17338235037667, 24.783439227512904, 43.42342022487095, 20.993323700768606, 47.85951151166643, 18.380224330084665, 0.1305968343679394, 0.048068482628358264, 0.043655752270881615, 0.023378019919618964, 0.057269699073263576, 0.02679011977410742, 0.04769028756501419, 0.030603330515857254, 0.06781597887831074, 0.014683519855939915, 0.025981631728687456, 0.039052248400236876, 0.054952875178839476, 0.20464753226510116, 0.12990973623735563, 0.15626025013625622, 0.16174362732895783, 0.13439468986221723, 0.13105268776416779, 0.0819296972560031, 0.15430962480604649, 0.2288593580680234, 0.20863703319004603, 0.21563198284379073, 0.17648732475936413, 0.18077855663640158, 0.18697807325848512, 0.1797431121979441, 0.1809246859380177, 0.3225811661354133, 15.53666363443647, 67.57822118486676, 51.19545977456229, 38.17392764772688, 41.10652256011963, 56.31015035084316, 66.22949245997837, 35.594130992889404, 67.71153627123151, 73.20839514051164, 63.90706402914864, 61.64170115334647, 63.72992665427071, 67.46205425262451, 26.806478466306412, 1.1624266760689872, 3.5049204187733785, 0.8315472166453088, 5.524844476154872, 35.03643383298601, 64.05087784358433, 69.1645644051688, 65.36979184831891, 59.89472252982003, 65.15392521449498, 60.3797276360648, 62.51162951333182, 59.17541721888951, 49.27126734597342, 47.93427412850516, 46.24702916826521, 48.80317415509905, 46.98677955354963, 48.649108273642405, 52.03282192775181, 57.02172231674194, 58.82113552093506, 56.90228625706264, 59.386468751089915, 58.69980607713972, 61.57246930258614, 55.021655559539795, 57.09805522646223, 58.78785364968436, 55.838065419878276, 50.51752751214163, 42.17059401103428, 42.79216248648507, 42.614663805280415, 40.22566468375069, 39.457388469151084, 38.555779797690256, 45.18155418123518, 45.32793882914952, 47.77452114650181, 45.733536447797505, 48.78954873766218, 49.23752341951643, 41.450555665152415, 41.917731693812776, 42.83192007882254, 41.2425856590271, 40.449386256081716, 42.39693505423409, 46.4968238558088, 49.18107278006417, 51.45497499193464, 51.88586057935442, 56.29829672404698, 55.73619788033621, 56.39203487123762, 19.883086681365967, 24.40022870472499, 63.01685387747628, 51.72243200029646, 57.25009223393032, 49.024925913129536, 52.520675795418875, 48.6272805077689, 44.12141193662371, 39.69705615724836, 42.37449584688459, 37.636963912418906, 43.78426449639456, 39.50489330291748, 43.195547103881836, 47.60152489798409, 51.21664483206612, 46.64527906690325, 41.69361754826137, 41.59697505405971, 44.75220761980329, 39.70154121943882, 38.84817041669573, 38.451282364981516, 39.66142232077462, 37.53240394592285, 43.26079068865095, 41.759003571101594, 44.851396628788535, 42.59642825807844, 47.7895188331604, 51.15030343191964, 53.917958532060894, 50.667004108428955, 52.78812238148281, 51.15246779578072, 53.60020351409912, 49.828318323407856, 52.85600280761719, 51.85178313936506, 52.84158876964024, 54.60505199432373, 51.62036643709455, 47.827330929892405, 48.910711424691335, 46.10709592274257, 51.636197907584055, 54.455648354121614, 53.97722666604178, 50.084397656576975, 50.759342193603516, 50.32321766444615, 53.09669882910592, 47.75353063855852, 48.91386938095093, 22.82099870273045, 0.1563709056270974, 1.8298458797591073, 1.1572130301168986, 0.5856383634465081, 4.880154567105429, 39.82369402476719, 63.647514070783345, 60.189242771693635, 63.673145975385395, 59.86146150316511, 64.89860670907157, 56.011513301304404, 68.22839886801583, 47.63164186477661, 34.726443426949636, 47.34681783403669, 38.18533658981323, 60.594051769801546, 34.09586661202567, 0.19997410875345978, 0.19940480430211338, 0.1469234318605491, 0.16141502639012678, 0.1483909131160804, 0.1932746475296361, 0.17580747338277952, 0.10342331855956997, 0.11820331082812377, 0.1652082678462778, 0.17420288734138012, 0.31735536083579063, 0.15135670825839043], [0.03677839952121888, 0.03857759619131684, 0.04973879835701414, 0.05674784457577126, 0.055147153325378895, 0.03682588679449899, 0.05891480722597667, 0.05203740358618753, 0.015582924808508583, 0.048459094882543595, 0.13130382714526995, 0.08833468106708356, 0.05625456997326442, 0.022659201973250935, 0.022153525446940745, 0.043305251614323685, 0.19739799627235957, 0.4567949857030596, 33.58455910001482, 46.11963742119925, 27.835044622421265, 26.79496530124119, 20.182837179728917, 62.13960211617606, 43.64791304724557, 32.68027884619576, 67.87825829642159, 52.12370783942086, 58.96901403154646, 52.13642999104091, 54.682326384953086, 24.41312803540911, 0.4177430969263826, 0.32165222455348286, 0.1916984242520162, 5.564838741506849, 41.99010413033621, 57.976800850459504, 58.913470132010325, 56.93386581965855, 58.10568298612322, 56.29553828920637, 54.3857981136867, 52.43322924205235, 49.55401039123535, 43.22983298982893, 43.21395288194929, 41.16290371758597, 39.54706539426531, 39.38571432658604, 39.523806299482075, 40.097074372427805, 45.67508820125035, 49.9323467527117, 56.45838321958269, 55.110793999263215, 54.41445943287441, 54.377324785505024, 50.833972794669016, 52.42501299721854, 50.299239431108745, 47.256866455078125, 38.93234436852591, 40.56943028313773, 38.55138158798218, 36.84750958851406, 34.85376221793038, 35.71539790289742, 34.621153899601524, 37.37661143711635, 39.3096593448094, 41.73311458315168, 39.20608254841396, 43.96875653948103, 39.83916766302926, 35.158649172101704, 34.85637126650129, 34.50882932118007, 35.1065411567688, 35.63652195249285, 37.815011501312256, 43.206316811697825, 42.53391184125628, 45.71826778139387, 47.68247141156878, 51.12870148250035, 48.790417262486045, 45.22470249448504, 15.041059051241193, 27.787513732910156, 56.10633189337594, 47.9949631690979, 48.73147916793823, 43.84789262499128, 46.837066718510215, 40.95640672956194, 38.033970083509175, 35.02731432233538, 36.834464345659526, 36.773271560668945, 38.44974333899361, 35.97957536152431, 38.49868644986834, 38.79013211386544, 45.73050355911255, 45.81575795582363, 41.92756339481899, 41.53371170588902, 39.27509553091866, 35.20596293040684, 33.52863999775478, 34.277985845293315, 34.79450798034668, 34.7615978377206, 34.759746142796104, 36.829954964774, 36.61191701889038, 37.49389008113316, 39.236967291150776, 46.61942481994629, 46.38508987426758, 48.47718899590628, 48.02314853668213, 47.19631290435791, 44.83899062020438, 47.047545024326865, 47.40300791604178, 46.50805561883109, 48.39886890138899, 44.69728210994175, 43.56105709075928, 42.628709588732036, 39.87592363357544, 43.432108947208945, 46.034282275608604, 49.788063934871126, 53.555057593754356, 54.67451660973685, 52.46636520113264, 52.91960661751883, 47.97208275113787, 41.66360827854702, 43.11081034796578, 22.68444401877267, 0.11478886833148343, 0.12998679067407334, 0.06939497736415692, 0.1691336879240615, 1.7067286861794335, 25.309667995997838, 50.36033146721976, 51.47736208779471, 51.15022005353655, 55.374721322740825, 51.18225819723946, 46.46121433803013, 54.848367486681255, 26.094305481229508, 26.355074848447526, 22.91155457496643, 26.280340024403163, 39.79628685542515, 5.073543778487614, 0.20887829310127667, 0.1604827328452042, 0.06712231252874647, 0.05398810694792441, 0.011521449977798122, 0.03664508096075483, 0.08229921385645866, 0.02918990475258657, 0.05021240222933037, 0.12870210675256594, 0.06521845183202199, 0.060899081107761176, 0.020487847505137324, 0.02821350303877677, 0.0695245707673686, 0.02694610649320696, 0.027039201497765522, 0.043958758868809254, 0.10727944664124932, 0.041121756458388906, 0.055481291109962125, 0.05649301057149257, 0.021855901328048537, 0.059122425370982716, 0.12178437438394342, 0.07288261343325887, 0.037199257473860464, 0.005201364468250955, 0.03704343190682786, 0.20228488690086774, 0.7340087305222238, 43.035557883126394, 53.88522209439959, 26.86304201398577, 43.54008742741176, 26.066886152539933, 70.9640644618443, 47.928489753178184, 38.07142782211304, 74.25436305999756, 57.72774962016514, 65.01426642281669, 57.49368565423148, 60.021659169878276, 27.07956177847726, 0.4953655760203089, 0.1712722403130361, 0.13613959694547312, 8.121220401355199, 46.91165215628487, 62.42114312308175, 62.52879156385149, 58.71967792510986, 59.89787701198033, 59.287304060799734, 57.42595114026751, 55.93603154591152, 52.075754846845356, 48.37651654652187, 46.297466141836985, 44.13430431910923, 44.123906339917866, 42.43257931300572, 42.68156453541347, 42.862613746098106, 47.85094090870449, 52.34350715364729, 59.642079080854145, 55.082883085523335, 55.865823473249165, 53.91375487191336, 52.927166257585796, 54.43799645560128, 51.998661109379356, 48.848994050707134, 42.46039642606463, 43.00885248184204, 41.320092814309255, 39.505591596875874, 35.666968958718435, 38.24897166660854, 37.41120304380144, 39.62564952032906, 41.42050123214722, 42.31575230189732, 42.10079935618809, 46.4789913041251, 44.395789350782124, 38.16294949395316, 37.31220163617815, 37.15473461151123, 36.6321883882795, 37.63132544926235, 39.9022399357387, 45.987413202013286, 45.70037964412144, 49.559801714760916, 49.16956308909825, 54.04982491901943, 52.54451159068516, 51.99574286597115, 26.824055671691895, 42.64358915601458, 60.067586762564524, 49.38422768456595, 52.872188636234824, 49.30154412133353, 48.2143177986145, 44.24579163960048, 38.41265385491507, 39.313730989183696, 39.793820244925364, 40.51053735188076, 40.41100788116455, 39.61292042051043, 40.39461013248989, 40.86787278311593, 48.88247047151838, 46.787512166159495, 45.02533783231463, 43.011934007917134, 40.44990389687674, 37.06611033848354, 35.66213648659842, 35.79525007520403, 36.368615422930034, 35.583298751286094, 37.61825936181204, 38.45780324935913, 37.387513160705566, 40.18486486162458, 41.26000826699393, 49.35905088697161, 48.05436331885201, 50.59870679037911, 49.72224364961897, 47.79436867577689, 46.73781517573765, 48.1258533341544, 52.09068999971662, 50.820302213941304, 49.37069954190935, 48.01611695970808, 46.5183493750436, 45.21183443069458, 44.066260610307964, 45.98675659724644, 48.025879178728374, 52.19089691979544, 56.15542091642107, 55.974976199013845, 53.74419798169817, 54.46419811248779, 49.38391154153006, 47.81058577128819, 49.54881313868931, 27.73706807409014, 0.048360208581600866, 0.4312044717371464, 0.35064418028507915, 0.4307161436549255, 1.8031659913914544, 28.13981866836548, 56.96160650253296, 56.058326789310996, 58.74747766767229, 58.187459809439524, 57.8695067678179, 49.14075585774013, 64.6472417286464, 28.064321279525757, 32.33429329735892, 28.324413197381155, 24.968045915876115, 48.01852103642055, 3.1272914707660675, 0.24387658653514727, 0.10446603689342737, 0.09561748563178948, 0.07586223711924893, 0.02961540049208062, 0.017494827841541598, 0.028267265064641833, 0.06069235862897975, 0.03680749849549361, 0.11986961641481944, 0.06355367973446846, 0.03909943372543369, 0.09137779527476855, 0.15572522527405194, 0.18778714484402112, 0.08104580361396074, 0.11385136363761765, 0.16760372716401303, 0.10759375763258763, 0.1579225795077426, 0.09668331486838204, 0.10116330161690712, 0.12760384354208196, 0.2478513361087867, 0.2635466924735478, 0.17969357914158277, 0.09346481292907681, 0.09299973824194499, 0.12992615678480693, 0.19919991386788233, 1.4954519889184406, 56.10220466341291, 64.61414051055908, 44.00995935712542, 44.816204002925325, 33.97815023149763, 74.30318805149624, 56.03782612936837, 41.009070600782124, 80.74753802163261, 62.94396727425711, 69.5596250806536, 62.60290799822126, 65.40647833687919, 30.068951266152517, 1.3739132306405475, 0.7409252279571125, 0.9323708436318806, 10.27162446294512, 51.65645885467529, 65.02520288739885, 66.7504961831229, 61.791740553719656, 63.332496643066406, 63.15425450461251, 62.25749914986746, 57.47077396937779, 57.468328203473774, 51.70947708402361, 49.10791172300066, 47.61605705533709, 48.14955711364746, 46.88722576413836, 47.254319940294536, 46.30292395183018, 52.959082807813374, 56.106338841574534, 63.35844121660505, 58.59396416800362, 60.75110190255301, 57.57565355300903, 55.34493439538138, 58.55014187949044, 55.76999044418335, 53.11308962958199, 46.01950345720564, 44.786347593579976, 43.772185053144185, 44.261897563934326, 38.60799551010132, 42.269588470458984, 39.777425970349995, 43.78754752022879, 43.662379196711946, 46.12770080566406, 43.85368742261614, 51.421911988939556, 44.63892766407558, 39.98830032348633, 39.587920801980154, 40.74130092348371, 40.10424838747297, 40.25104645320347, 43.78432355608259, 50.03475277764456, 48.91607195990426, 53.049558775765554, 54.385607038225444, 56.708275181906565, 54.749348708561485, 53.718260356358115, 20.44632155554635, 33.90258857182094, 64.83581583840507, 51.366764136723106, 56.31447213036673, 51.66272612980434, 51.292751925332205, 46.03940657206944, 42.38634599958147, 40.692295278821675, 42.109026023319785, 42.60054506574358, 44.133164814540315, 41.76318986075265, 43.83513225827898, 42.82484333855765, 49.487547397613525, 48.0374687739781, 45.9903244972229, 45.60857309613909, 43.00194944654192, 38.67220728737967, 36.78848811558315, 39.545432567596436, 39.50087724413191, 37.092041015625, 38.949412618364605, 42.460497174944194, 38.92510781969343, 42.19821310043335, 44.12074143545968, 51.7783511025565, 49.754663944244385, 52.41851643153599, 51.57088484082903, 50.26940734045846, 49.36662094933646, 50.845934118543354, 54.41402864456177, 53.82420996257237, 52.20010675702776, 48.37536661965506, 48.10276794433594, 48.88253647940499, 45.44918489456177, 47.239106859479634, 50.312666824885774, 54.593042033059255, 56.62511566707066, 58.149633816310335, 53.664759227207725, 55.732845374516074, 52.210647174290244, 47.64674724851336, 50.28369631086077, 33.143754959106445, 0.220575748277562, 0.9639416124139513, 0.44290325684206827, 0.5132608243397304, 3.1218618878296445, 33.816760948726106, 62.14659200395857, 61.82288932800293, 62.33808435712542, 62.74201093401228, 61.91503633771624, 58.013108662196565, 66.82152066911969, 34.50928790228707, 40.54245737620762, 37.584063802446636, 40.87645033427647, 59.61650971003941, 11.644757866859436, 0.45556499170405523, 0.18974999737526688, 0.19982351469142096, 0.1522056641323226, 0.1040293521114758, 0.08306297965879951, 0.15377347357571125, 0.10382039725248303, 0.12652563782674925, 0.22000852014337266, 0.15700317812817438, 0.16914682436202252, 0.23961069115570613], [0.03573691612109542, 0.03794452641159296, 0.07054565740483147, 0.02645541032377098, 0.028602568233119588, 0.025676579347678592, 0.11320480118904795, 0.02886216894590429, 0.04807199743975486, 0.06979398309652295, 0.10395910338099514, 0.06500296946614981, 0.0478573089598545, 0.0448735869223518, 0.04168546299583145, 0.032447754937623224, 0.08327240270695516, 0.04353682204548802, 9.775001100131444, 54.04408918108259, 25.53050606591361, 22.902558394840785, 25.65872812271118, 24.965746062142507, 67.14937141963414, 51.437184129442485, 61.490640367780415, 54.86827060154506, 56.700934410095215, 52.60571827207293, 52.053878443581716, 24.378916842596873, 0.12368936144879886, 0.07771712115832738, 0.1328040545008012, 16.35152404648917, 55.372793197631836, 56.15879774093628, 58.39763586861746, 55.78268827710833, 52.27829136167254, 52.3933014188494, 52.15702097756522, 51.36614922114781, 46.179127897535054, 42.84407247815813, 40.92719650268555, 42.392797401973176, 39.214302267347065, 38.76823834010533, 37.16633810315813, 38.32562071936471, 37.1501453263419, 41.72485664912632, 44.791732447487966, 47.809348991939, 53.339864935193745, 53.03665597098214, 50.49437958853585, 48.064914158412385, 44.97298663003104, 42.36939239501953, 38.4466097014291, 38.00486755371094, 38.62577247619629, 36.5394994190761, 34.768049240112305, 36.39105115618025, 37.131815978458945, 38.22558403015137, 39.41719314030239, 40.46099322182791, 39.14338895252773, 41.6090475491115, 35.91172967638288, 34.90587370736258, 35.06149251120431, 35.04125935690743, 35.35474470683506, 35.623921394348145, 36.990722383771626, 44.76013551439558, 45.100565978458945, 48.30949422291347, 47.72021402631487, 49.905328682490754, 50.80976179667881, 43.06892660685948, 18.73572196279253, 36.57745395387922, 54.79527282714844, 48.87451825823103, 48.479909215654644, 47.25942686625889, 49.927781786237446, 44.667905126299175, 38.68668385914394, 36.832286085401265, 36.84016881670271, 35.27650451660156, 37.742850984845845, 38.000604833875386, 36.26309313092913, 38.641530990600586, 41.534052167619976, 43.57415097100394, 39.96584374564034, 42.19089664731707, 39.90434176581246, 38.65515988213675, 35.981816155569895, 33.749728202819824, 33.86729172297886, 34.06494018009731, 36.021080425807405, 37.307059969220845, 39.36706188746861, 39.998330048152376, 35.31964935575213, 40.073853492736816, 46.240459646497456, 45.64999825613839, 48.72656331743513, 49.20253923961094, 49.8456575529916, 49.259573527744834, 46.76307535171509, 47.49256672177996, 46.995621136256624, 44.73615033285958, 42.49260132653372, 41.56148712975638, 38.71426820755005, 44.5333845274789, 47.28556598935808, 52.94872304371425, 54.76825475692749, 54.47007976259504, 49.1479229245867, 51.63986655644008, 47.03981515339443, 46.61374814169747, 37.860115732465474, 31.721232891082764, 0.4830024508493287, 0.19505885536117212, 0.22440506065530436, 0.0805279796144792, 1.816501321537154, 24.729429142815725, 49.004334926605225, 51.98183952059065, 50.579838957105366, 50.33830220358712, 53.41092416218349, 52.30770656040737, 43.259901319231304, 21.547452960695537, 27.111469643456594, 23.481543098177227, 35.580849511282786, 28.642041410718644, 0.3886607603303024, 0.0984943180478045, 0.013675645991627659, 0.06337513002966132, 0.05005312631172793, 0.05369009776040912, 0.08993858178811413, 0.06958826484956912, 0.01798336118060563, 0.041610288101115396, 0.018259401100554636, 0.09148449490645102, 0.03138348972424865, 0.030788855560656105, 0.02714106487110257, 0.025812835964773382, 0.0124003538429471, 0.053256262825535874, 0.043210066721907685, 0.08399423504514353, 0.02382622961886227, 0.0408079882950655, 0.054400534102959294, 0.11031259316951036, 0.13678819499909878, 0.04296449472063354, 0.04142909210973552, 0.06408725931708302, 0.02839811545397554, 0.04461874274004783, 0.06821377681834356, 0.05483959375747612, 10.388103195599147, 67.74210834503174, 27.009282486779348, 34.56226444244385, 35.309581415993826, 30.688560349600657, 76.52224118368966, 56.19579689843314, 69.28332996368408, 59.842117718287874, 64.57544599260602, 56.405955587114605, 58.05590609141758, 27.791634014674596, 0.18911674778376306, 0.06146881303616932, 0.5126567653247288, 19.927541255950928, 59.403505734034944, 60.493705885750906, 63.84063230242048, 59.7897560937064, 54.720468521118164, 54.11187580653599, 52.71374191556658, 52.837332998003276, 49.7873135294233, 45.44250072751726, 46.83473907198225, 44.070697035108296, 43.18178967067173, 42.14409705570766, 40.899949141911094, 39.85308837890625, 41.13278327669416, 45.83193336214338, 49.255647795540945, 51.977041789463584, 54.18536690303257, 56.31858546393258, 52.79091208321707, 49.90432814189366, 48.322796549115864, 44.856663363320486, 40.76145764759609, 41.45578071049282, 41.14278520856585, 40.219209807259695, 37.549472195761545, 38.892173358372276, 38.772070271628245, 40.2710086277553, 40.93112570898873, 42.310544627053396, 41.46585559844971, 44.42489882877895, 39.6568260874067, 39.01998199735369, 37.68520178113665, 36.61677728380476, 37.143461159297395, 38.41727440697806, 40.67824602127075, 47.776848793029785, 48.66320964268276, 50.98671851839338, 50.289171491350444, 51.41485609327044, 55.35064581462315, 45.902620860508506, 29.935549327305385, 53.01083299091884, 56.60988868985857, 53.66715635572161, 51.868688106536865, 51.92642068862915, 50.4292437008449, 47.65890312194824, 41.550446442195344, 41.89377430507115, 39.483020373753135, 40.37626688820975, 40.407759598323274, 40.75321708406721, 37.99450431551252, 40.819773878370015, 44.728507314409526, 46.91219064167568, 41.970315660749165, 42.72948278699602, 40.40269088745117, 39.58554799216134, 36.5770057950701, 35.77950198309762, 34.670378412519185, 36.136691502162385, 36.490007400512695, 38.12689529146467, 38.12221220561436, 39.09998355593, 38.747407640729634, 41.39048154013497, 48.19925062997, 48.298915590558735, 48.923127855573384, 50.97231142861502, 50.90232569830758, 51.37916667120797, 49.44917944499424, 49.90653419494629, 50.057042598724365, 48.06855501447405, 46.91547366550991, 42.63759633472988, 40.54400682449341, 47.588444914136616, 49.802547454833984, 55.078217370169504, 56.38465241023472, 55.9418054989406, 51.78804383959089, 52.699518953050884, 48.85008839198521, 50.45094639914376, 45.26900768280029, 37.077005113874165, 0.918567812868527, 0.17707298190465995, 1.2778298492942537, 0.8371095753141812, 2.112181369747434, 26.681588070733206, 55.63139125279018, 57.61322593688965, 57.161645139966694, 55.99336460658482, 58.42041901179722, 59.926454952784944, 51.079949447086875, 21.780613660812378, 36.164741379874094, 23.574998106275284, 40.23234190259661, 33.804497378213064, 0.4458597967667239, 0.06259010572518621, 0.05066830990836024, 0.024418130982667208, 0.05310384350429688, 0.02827160429608609, 0.12157727192555155, 0.008149644077223326, 0.009407644609122403, 0.06061312609485217, 0.043419252282806804, 0.015484365900712354, 0.05594498837100608, 0.05754240908260856, 0.14926378056406975, 0.0783302386158279, 0.18700978798525675, 0.09497928273464952, 0.14544213563203812, 0.1863436158746481, 0.17554669880441257, 0.15090692096522876, 0.1489945650100708, 0.175473579870803, 0.20895002782344818, 0.15878034276621683, 0.16166730571006024, 0.21893377495663507, 0.13160363105790956, 0.13613556644746236, 0.20761468447744846, 0.10073862690478563, 20.65402753012521, 78.02463626861572, 42.601827008383616, 37.02343797683716, 39.57169328417097, 34.940274238586426, 82.26687976292202, 61.743478366306846, 75.88969108036586, 64.77424785069057, 67.72803129468645, 60.09240572793143, 61.463806424822124, 31.550321102142334, 0.280537236481905, 0.664079942873546, 1.0351391519818987, 23.35241082736424, 64.66891316005162, 64.54403318677629, 69.89601516723633, 64.71833569662911, 56.88359212875366, 58.63151223318917, 56.93803473881313, 58.76703684670584, 53.86216449737549, 48.725719111306326, 50.39147676740374, 49.25115578515189, 46.737773486546104, 45.327501092638286, 43.396746090480256, 43.78276021139962, 44.85391535077776, 49.703219481876914, 51.263083117348806, 54.9528614452907, 58.371913637433735, 59.9679982321603, 56.86107301712036, 53.10664170128958, 52.42049319403512, 48.13271120616368, 43.840357303619385, 43.36899151120867, 44.54630817685808, 42.9830572945731, 40.452832562582834, 42.5649459702628, 42.723149503980366, 43.24150596346174, 43.73901782717024, 46.329476492745535, 44.85345676967076, 46.55866282326834, 42.357545716421946, 41.74392250605992, 38.458560603005544, 39.798107283455984, 39.653814043317524, 40.76168693814959, 42.57490273884365, 50.58922597340175, 53.734727587018696, 57.05288846152169, 54.66400398526873, 53.951678139822825, 56.08803381238665, 50.08598531995501, 23.57770790372576, 44.06759466443743, 60.71233095441546, 54.87882144110543, 55.989873136792866, 54.71886348724365, 54.058319091796875, 51.27250140053885, 43.09614964893886, 42.89481169836861, 41.622249126434326, 39.6267751285008, 43.67865187781197, 43.44376107624599, 38.72139358520508, 42.634427956172395, 44.21051216125488, 46.416773659842356, 44.259813104357036, 44.4108704158238, 42.74406705583845, 42.10766070229666, 39.45111424582345, 38.16782365526472, 37.3459073475429, 38.171704224177766, 39.03751230239868, 40.23354046685355, 41.050103187561035, 42.48952674865723, 39.93025507245745, 44.19733837672642, 51.728577681950156, 50.685910156794954, 51.880986418042866, 52.53655590329851, 54.013993058885845, 53.776385511670796, 51.30964299610683, 52.26489176068987, 53.55903196334839, 49.517501081739155, 48.897145066942485, 45.483731337956016, 42.157639094761436, 49.3818097114563, 50.761322430201936, 58.395537512642996, 56.30966050284249, 57.19319690976824, 52.70979881286621, 53.6579395702907, 50.23977327346802, 51.45905705860683, 46.31196008409773, 41.21163490840367, 1.8313225890908922, 0.27873863013727324, 1.4013146460056305, 0.5671819938080651, 2.523297595126288, 31.881590366363525, 60.56230545043945, 63.78476183755057, 59.68160738263811, 61.41691998073033, 63.012948989868164, 65.0815041405814, 52.79454946517944, 31.27230978012085, 42.61712694168091, 39.63412284851074, 51.25704165867397, 51.25582224982125, 0.9268077250037874, 0.2816014779465539, 0.12667195711817059, 0.28868817910552025, 0.15182748942502908, 0.1612791158258915, 0.1674277830336775, 0.13105185995144503, 0.09897752997598477, 0.11059538620923247, 0.09782538429966994, 0.19953966992241995, 0.11232729934688125, 0.1992591635457107], [0.049517195605273755, 0.09269592418734517, 0.09586660297853605, 0.054742397008729834, 0.0038142467799064305, 0.06944470719567367, 0.058084341431302686, 0.020934703527018428, 0.0618866141885519, 0.0556636406108737, 0.07606984847890479, 0.020764107948967388, 0.03113478628386344, 0.016248874698898623, 0.09017557371407747, 0.04640702856704593, 0.10615231176572186, 0.09063695717070784, 1.1332843026944568, 33.555397510528564, 47.19126851218087, 21.409869943346294, 25.07365506035941, 22.74533803122384, 52.72545657839094, 64.18563120705741, 60.14857496534075, 59.42458656855992, 58.35447365897042, 54.00115973608834, 53.95809827532087, 23.11038769994463, 0.326345542711871, 0.0863489279789584, 3.2901029629366736, 37.55477714538574, 59.57932989937918, 59.886822428022114, 56.209318092891145, 54.59609924043928, 52.120452608381, 51.06565352848598, 48.45752559389387, 48.73322663988386, 46.62307262420654, 42.74166645322527, 42.676315171378, 42.39612558909825, 40.14670535496303, 38.12888247626168, 36.33646263395037, 37.3761111668178, 38.644556931086946, 37.83375774111067, 40.441006728581016, 41.45596831185477, 42.02056155885969, 43.231201784951345, 42.44111170087542, 42.8076673916408, 40.23766769681658, 39.86858286176409, 38.23127807889666, 37.90216275623867, 38.921689305986675, 35.951431683131624, 35.05030591147286, 36.095794405256, 36.12543889454433, 39.375986848558696, 39.17150831222534, 39.78409276689802, 37.657784189496724, 34.396108695438926, 37.53040633882795, 35.1634920665196, 35.61317253112793, 35.35344191959926, 35.681254455021445, 37.261688232421875, 40.265231200626914, 46.46581057139805, 48.56511150087629, 46.82551186425345, 50.14981147221157, 49.52604736600603, 51.307947635650635, 35.3770032610212, 21.40313192776271, 44.82241569246565, 50.9114591053554, 50.566432407924104, 50.63740478243147, 49.03791209629604, 47.182065623147146, 47.66161291939871, 39.54587377820696, 38.24447965621948, 37.46205690928868, 37.23585483006069, 35.10985197339739, 34.890177726745605, 37.10232434953962, 37.39710167476109, 37.06570386886597, 39.95204809733799, 39.99752753121512, 40.475872789110454, 39.58185849870954, 39.30724484579903, 35.83508062362671, 34.260448592049734, 34.064033440181184, 35.35928188051496, 37.45685965674264, 36.30675213677542, 38.93870891843523, 37.715502875191824, 37.51363686152867, 37.717774936131065, 39.838365146092, 44.246632371629985, 46.79279627118792, 48.73459890910557, 48.1124050957816, 47.5671660559518, 45.449928351810996, 45.644714151109966, 44.06651769365583, 41.74288375037057, 39.3203387260437, 40.29453175408499, 40.026077679225374, 45.37333835874285, 50.10608993257795, 53.566240719386506, 56.285150732312886, 50.85172544206892, 51.08184977940151, 51.77839279174805, 46.84940324510847, 49.669854232243125, 40.58389295850481, 39.44737264088222, 2.84142911859921, 0.9225725808313915, 0.37183662024991854, 1.0972886170659746, 3.603183146033968, 33.04273509979248, 50.03170599256243, 50.51059320994786, 52.26105982916695, 55.28538485935756, 54.398940631321494, 44.1612285886492, 41.96399974822998, 25.913072143282207, 27.331116097314016, 20.80361877168928, 39.49428340366909, 9.444298114095416, 0.07990055185343538, 0.03991841870759215, 0.1356256745223488, 0.08440562404159989, 0.04509208198370678, 0.019014215329661965, 0.036527677439153194, 0.12294861833964076, 0.029230406507849693, 0.07878375106624194, 0.0531117179031883, 0.03948720970324107, 0.05915565323084593, 0.02381161567089813, 0.07131367762173925, 0.056228955276310444, 0.011157584725879133, 0.01517538310560797, 0.03420265344902873, 0.08206703274377755, 0.03691767222647156, 0.035871133740459166, 0.050043314695358276, 0.07786532677710056, 0.04976212639095528, 0.03157138964161277, 0.04980998346582055, 0.09673130765025105, 0.09435468446463346, 0.05054726943905864, 0.01717454913471426, 0.10501632879355124, 1.4038788569825036, 41.98872143881661, 51.86515842165266, 18.70992156437465, 39.57880129132952, 23.20063611439296, 64.60100146702358, 68.14255387442452, 64.43796198708671, 65.4277537209647, 62.67650331769671, 56.61517626898629, 61.04480920519148, 26.512430701936992, 0.25332437242780415, 0.21482429546969278, 4.613405406475067, 44.16370562144688, 62.34453228541783, 61.880545479910715, 58.109393324170796, 57.052586214882986, 55.90849583489554, 51.892853941236226, 51.39227097375052, 50.41203996113369, 47.75470488412039, 47.596014976501465, 45.430633204323904, 46.56521497453962, 42.50850575310843, 42.771005221775596, 40.37197290148054, 41.00331401824951, 41.81089966637747, 40.89120830808367, 41.152877467019216, 44.176691804613384, 45.405911513737266, 45.849585260663716, 44.87050070081438, 45.49786049979073, 42.67281675338745, 42.88077981131417, 41.184526511601035, 41.22339473451887, 40.6896584374564, 39.06289407185146, 36.926079818180625, 38.62832246507917, 40.86483294623238, 40.41365167072841, 41.87109538487026, 41.370627062661306, 41.49859203611101, 39.857774938855854, 41.188309805733816, 37.81752674920218, 39.37760577883039, 37.94455371584211, 38.58843285696847, 39.89559050968715, 44.43737779344831, 49.94211591993059, 51.283330168042866, 50.718799454825266, 53.36750486918858, 51.73124231610979, 56.95467914853777, 40.50193548202515, 31.79454333441598, 55.884045124053955, 53.02483361107962, 56.49476746150425, 53.79478781563895, 52.33015966415405, 50.117154938834055, 48.12810107639858, 42.15007250649588, 40.22540760040283, 39.17827238355364, 39.76894221987043, 38.01739515577044, 38.10212843758719, 40.959387506757466, 40.71135766165597, 39.537431716918945, 43.889064175742014, 43.714636598314556, 43.167959281376426, 40.18105377469744, 39.79018286296299, 37.39373527254377, 35.21882404599871, 36.2023936680385, 37.87628071648734, 38.55173594611031, 38.63439171654837, 40.16764375141689, 39.57675157274519, 39.85860177448818, 41.23847927365984, 41.55744327817644, 46.53599085126604, 47.66128287996565, 50.4216354233878, 49.383786473955425, 50.052616596221924, 49.833786555698936, 48.85880143301827, 44.915917600904194, 44.48459775107247, 43.82036733627319, 43.063239506312776, 42.75673362186977, 48.13020290647234, 51.28142983572823, 56.696612630571636, 55.80220924104963, 51.5218687738691, 50.17759037017822, 53.87056139537266, 50.041485582079204, 52.787337235042024, 46.22241517475673, 46.17510141645159, 3.6994228618485585, 0.7034927851387432, 3.871050749506269, 2.3582835240023474, 4.028760092599051, 38.00496135439192, 55.20075927461897, 58.12884828022548, 55.78185796737671, 62.9648883002145, 58.69576917375837, 52.88933331625802, 44.59326410293579, 29.596240997314453, 36.765836988176616, 20.876130172184535, 49.37758868081229, 7.645092487335205, 0.1542530349854912, 0.051697121667010446, 0.10368557234427758, 0.05083814722352794, 0.006359871834450002, 0.0336929074089442, 0.019395021056490283, 0.05968164000660181, 0.02182397116640849, 0.04912732295425875, 0.11699895188212395, 0.024783021670633128, 0.036430996377021074, 0.023898605556626405, 0.24069819280079432, 0.12923334538936615, 0.18044361818049634, 0.08643073216080666, 0.11121258166219507, 0.23601703398994037, 0.1459903105029038, 0.11218889855912753, 0.1356824543327093, 0.14746343716979027, 0.17652426420577935, 0.09668289417667048, 0.09483834422592606, 0.17072345476065362, 0.2159654420933553, 0.1379250261400427, 0.2667570859193802, 0.3685829091284956, 2.7577758474009375, 57.02389710290091, 63.458154814583914, 35.61934947967529, 41.65897035598755, 32.522165639059885, 67.36074951716832, 74.7537509373256, 71.03326157161167, 70.74658584594727, 68.06201035635812, 65.67302513122559, 64.74654538290841, 29.274000917162212, 0.46249196571963175, 0.5449708827904293, 6.542467653751373, 48.14320298603603, 69.10977785927909, 65.87758009774345, 63.66610745021275, 61.184752873011995, 58.51959759848458, 55.98320286614554, 55.35791015625, 54.72472081865583, 53.34073346001761, 51.39581108093262, 48.039865902491975, 49.6223007610866, 47.724539279937744, 45.37688888822283, 46.02558660507202, 44.70466457094465, 47.61131838389805, 44.556900705610005, 44.47894539151873, 46.533652782440186, 48.50012847355434, 47.51681593486241, 48.39500917707171, 48.70161928449358, 47.15855639321463, 46.752267428806846, 44.76113258089338, 43.94760274887085, 44.18612051010132, 42.20019333703177, 39.70687048775809, 42.05261707305908, 42.90492827551705, 43.38254049846104, 44.24689292907715, 43.8614033971514, 43.921432358878, 40.33706862585885, 44.738693373543875, 40.813701152801514, 42.55325910023281, 40.02445527485439, 41.76125478744507, 42.9701440674918, 46.32111086164202, 53.09812668391636, 56.30344533920288, 54.16553674425398, 55.948597363063264, 56.94692495891026, 58.7425513948713, 42.7396445274353, 27.336391517094203, 50.399439402988975, 57.06120892933437, 57.33927583694458, 56.842708928244456, 54.03487934385027, 51.77461297171456, 50.64731291362217, 45.723579679216655, 43.58104705810547, 43.55822569983346, 42.79984719412667, 41.10141216005598, 39.8179999760219, 43.12350818089077, 41.442631244659424, 40.83130093983242, 43.71335118157523, 44.98472908564976, 44.95113454546247, 42.509117194584434, 43.17919799259731, 40.05786221367972, 38.37975760868618, 39.78673308236258, 40.26654093606131, 40.726886885506765, 40.99381930487496, 42.58664172036307, 42.75456230981009, 43.10908719471523, 43.39391122545515, 45.124825613839285, 49.71778638022286, 48.76608467102051, 52.64488179343087, 53.49681084496634, 52.30743210656302, 53.685659408569336, 51.792341300419395, 47.012456621442524, 45.53866727011544, 46.12652656010219, 45.9058517728533, 44.683889457157676, 50.11593900408064, 52.41910008021763, 57.23469155175345, 59.16521726335798, 52.349524293627056, 49.92902203968593, 53.94159977776663, 50.989671502794536, 56.11251926422119, 46.76915502548218, 49.850278105054585, 4.849631130695343, 1.3483269235917499, 6.71224992615836, 2.8391055975641524, 5.297130729470934, 39.91280814579555, 60.6720244543893, 59.988849776131765, 59.729966844831196, 65.78017330169678, 63.305732182094026, 56.09833451679775, 52.25312498637608, 38.44443838936942, 42.46943950653076, 34.40825414657593, 59.09766687665667, 19.719956874847412, 0.6449179510985101, 0.13745302361037048, 0.28353286002363476, 0.17398895882070065, 0.07036939436303717, 0.10646192050938096, 0.10334832008395876, 0.23306909788932118, 0.14059964833515032, 0.12281737609633378, 0.2453712091914245, 0.1301595049777201, 0.17851527594029903, 0.16751487978867122], [0.04158169463542955, 0.02463311462530068, 0.02091502770781517, 0.09442557101803166, 0.010026131823126758, 0.08680174153830324, 0.07620507372277123, 0.04101054456883243, 0.03469572788370507, 0.01940781144159181, 0.03852969501167536, 0.013404536476757909, 0.10772675728159291, 0.08388845143573624, 0.0946485579812101, 0.009236256841437092, 0.05558455056910004, 0.08269246561186654, 0.0684161838144064, 12.887347647121974, 54.64998252051217, 30.24768672670637, 26.910140378134592, 23.66206771986825, 54.795012269701274, 61.65147726876395, 57.77169697625296, 58.269712584359304, 57.675839628492085, 53.835629326956614, 55.13264260973249, 20.110513380595616, 0.33845652426992145, 0.3542445956596306, 13.365307279995509, 52.847348826272146, 59.40028176988874, 59.92284883771624, 54.432205132075715, 52.884202071598594, 50.96023545946394, 49.87603507723127, 47.419666222163606, 47.07875633239746, 46.23806946618216, 44.24539906638009, 41.79625286374773, 41.72158752168928, 41.01727989741734, 39.93510144097464, 37.67668328966413, 37.566158294677734, 38.30822243009295, 39.79382371902466, 39.913794789995464, 39.493713651384624, 38.03176403045654, 40.06700951712472, 39.00945895058768, 39.26520824432373, 39.28186307634626, 39.09497390474592, 38.275204590388704, 37.331496783665244, 36.13521153586251, 35.92859295436314, 35.48627063206264, 35.32313387734549, 39.004258223942344, 39.33123697553362, 38.38882153374808, 37.24744095121111, 35.95694855281285, 34.04267815181187, 36.38841778891427, 33.007229804992676, 36.80357265472412, 34.92888266699654, 36.65973104749407, 36.2631139755249, 42.17257424763271, 49.3888829776219, 51.41961213520595, 49.0417857170105, 49.5299904687064, 49.81441845212664, 50.21140030452183, 38.17755808149065, 30.37975808552333, 45.263195514678955, 50.09115825380598, 51.018749713897705, 49.643211364746094, 50.32865462984358, 49.27628741945539, 49.56688887732369, 42.84343671798706, 39.607198578970774, 38.278824601854595, 37.2804205758231, 36.55809627260481, 35.344027110508506, 36.29413768223354, 35.23403712681362, 36.9670672416687, 38.14670807974679, 37.85891716820853, 40.80682591029576, 38.41013860702515, 38.76758868353707, 36.5587910924639, 34.86126627240862, 34.29073231560843, 34.165480613708496, 34.33531195776803, 35.57535696029663, 35.442649841308594, 37.1424606187003, 35.996032169886995, 37.724156856536865, 37.80795213154384, 36.74944271360125, 38.40546246937343, 40.48586777278355, 41.95647137505667, 41.98842961447579, 41.75881944383894, 38.71993446350098, 38.79709073475429, 37.801545892442974, 40.084237575531006, 38.74440949303763, 42.040124211992534, 47.903820174080984, 52.658573218754356, 53.813822405678884, 52.14487552642822, 50.851774079459055, 45.43300254004342, 53.61524288994925, 52.10420772007534, 49.56130599975586, 42.00597729001726, 42.081327029636924, 12.717632685388837, 0.7115416760955537, 1.9512817178453719, 2.22286747608866, 5.772724500724247, 31.564985275268555, 53.20190845217024, 48.123987742832725, 46.76411063330514, 59.45638847351074, 48.822594370160786, 38.27114336831229, 24.92062619754246, 24.403030565806798, 27.002728598458425, 26.220806121826172, 35.656095027923584, 0.6121362958635602, 0.10067932972950594, 0.0797570620530418, 0.07339318389339106, 0.015366204116227371, 0.035720685563449345, 0.05705889859902007, 0.1373078849698816, 0.09529839096856968, 0.023395314080906764, 0.04364070914951818, 0.07102002123636858, 0.02765168113234852, 0.005531305513743843, 0.05165713559836149, 0.05100359780980008, 0.04537022366587605, 0.06430593079754285, 0.060448845981487205, 0.0250019459053874, 0.10245343417461429, 0.08909250968801123, 0.0037801648140884936, 0.049303877766111066, 0.012429559686487275, 0.004717058402353099, 0.04842130048200488, 0.05457360463749085, 0.10057013987430505, 0.018109885909195458, 0.02634237826402698, 0.0346266835528825, 0.07191103949610676, 0.06784639081784657, 16.088899510247366, 65.8807623726981, 26.22403529712132, 37.982893875667024, 31.541788714272634, 61.799321038382395, 69.66598115648542, 64.48921189989362, 65.24333463396344, 62.7154757635934, 58.921745436532156, 58.53275053841727, 21.283176490238734, 0.12003653602940695, 0.6124422337327684, 17.15216670717512, 59.10259314945766, 62.526443072727744, 63.13812773568289, 57.91134187153408, 58.334893635341096, 54.27814619881766, 54.24554525102888, 50.920408385140554, 49.58243547167097, 48.548967361450195, 47.878379344940186, 44.1211895942688, 45.600954396384104, 42.74017606462751, 41.93009948730469, 41.94252634048462, 39.42214373179844, 40.184916973114014, 42.25388554164341, 41.101356574467246, 42.08709750856672, 40.72326339994158, 41.72607953207833, 42.377789293016704, 41.851487568446565, 42.59557362965175, 42.806600843157085, 40.761179719652446, 41.110034874507356, 39.23070001602173, 37.81485169274466, 37.90064804894583, 38.85469477517264, 42.06986945016043, 41.288270064762656, 40.821146147591726, 39.95530680247715, 39.52085678918021, 38.52878604616438, 37.20768683297293, 36.48599134172712, 40.74747439793178, 37.75659799575806, 39.810482025146484, 37.843617234911235, 45.45478514262608, 52.35720552716936, 55.13127728870937, 52.984620911734446, 53.99156774793352, 52.553349699292866, 55.223531995500835, 38.45556592941284, 38.238393034253804, 54.05096789768764, 52.44051790237427, 56.80663388116019, 52.369399615696494, 54.001927512032644, 52.136985846928184, 50.020665305001394, 45.794975893838064, 41.08583777291434, 39.926694120679585, 39.553277083805625, 38.82766628265381, 38.71360118048531, 38.86306735447475, 37.39192526681082, 39.183619022369385, 40.649428367614746, 39.410637514931814, 42.837565490177695, 40.36813749585833, 40.58246510369437, 37.434152943747385, 36.780105113983154, 35.54173810141427, 37.23875222887312, 36.91538306644985, 38.132985387529644, 37.62388392857143, 38.62650203704834, 38.04767540522984, 38.8207562991551, 37.75923483712332, 39.87839371817452, 39.604738916669575, 42.12632008961269, 44.358015469142366, 43.33872863224575, 42.20473745891026, 41.60892595563616, 39.85142081124442, 40.832523822784424, 41.03870119367327, 40.742176396506174, 44.75401415143694, 50.29301037107195, 54.48610578264509, 56.146676608494346, 52.96064615249634, 53.91576290130615, 46.898381096976145, 55.00780779974801, 55.702394894191194, 53.16346059526716, 46.94195672443935, 51.27401958193098, 16.956507171903336, 0.6469862886837551, 1.3473153093031474, 1.8423856411661421, 8.46704614162445, 36.34232343946184, 58.51015499659947, 55.17651006153652, 53.26925386701311, 65.3945621762957, 54.236929484776084, 48.39345278058733, 26.225044522966655, 33.866735867091585, 29.127560683659144, 32.29346220833914, 40.75019114358084, 0.38764043365206036, 0.13969776672976358, 0.059106717285301, 0.07739553627158914, 0.04245367320254445, 0.09707232577992336, 0.17289081774652004, 0.029380155793790306, 0.03905807362337198, 0.03304611765114324, 0.033942421698676686, 0.023287996982357333, 0.06255016715398856, 0.037581194657832384, 0.016559830334569727, 0.1906409952789545, 0.17848498613706656, 0.17208674017872128, 0.2746333847088473, 0.10606563570243971, 0.21107252607388155, 0.12724278148795876, 0.0950064512767962, 0.11426047954176154, 0.058465542404779365, 0.07308838596301419, 0.10398770363203116, 0.1703085305967501, 0.208871792735798, 0.24282415157982282, 0.20639915684504168, 0.18411640610013688, 0.17367126872496946, 0.1907179140086685, 28.6953375680106, 75.25985077449253, 49.73670979908535, 45.00111641202654, 35.23793854032244, 66.85409382411412, 74.76293645586286, 70.05112675258091, 69.49116447993687, 67.87126840863908, 65.06026349748883, 63.93698297228132, 26.44661041668483, 1.1018710626023156, 0.8436376250215939, 19.98073145321437, 64.86212171827043, 67.34510912214006, 67.47303935459682, 62.88363606589181, 62.424589429582866, 57.59603956767491, 58.887136459350586, 53.79008388519287, 52.58953939165388, 52.97673123223441, 51.82043981552124, 48.303296429770334, 49.778013365609304, 47.267285278865266, 47.70686306272234, 44.94103881290981, 43.30045100620815, 43.87627254213606, 46.196425437927246, 43.66326856613159, 45.3527751650129, 44.79688106264387, 44.76991162981306, 44.173332350594656, 44.83725357055664, 46.746583802359446, 47.026683058057515, 43.4877153805324, 44.1736033303397, 41.15100492749895, 41.97736113412039, 39.68020677566528, 41.3741636957441, 43.653742585863384, 43.65356193270002, 43.52456862585885, 43.56430884769985, 39.100473403930664, 40.92396559034075, 39.87315130233765, 39.30522986820766, 44.34213883536202, 40.47183241162981, 44.056984765189036, 40.256545952388215, 47.82859550203596, 57.87451989310128, 59.51136956896101, 55.233023234776084, 55.2771303994315, 56.822409766060964, 58.40577220916748, 45.766498701913015, 31.324323994772776, 52.699796880994526, 56.39263589041573, 57.147616727011545, 55.51780210222517, 56.76221752166748, 54.847346101488384, 54.160447188786094, 47.87403324672154, 42.465169838496614, 42.63824946539742, 40.83609867095947, 41.94289806910923, 40.11688021251133, 41.147919927324565, 37.417928900037495, 41.16682250159127, 42.18576192855835, 42.235271317618235, 45.03252921785627, 42.168384483882356, 42.701863697596956, 40.154390062604634, 39.25935786111014, 38.70634726115635, 38.755571774074006, 39.508377824510845, 39.626302650996614, 42.259701183864046, 41.86075299126761, 41.76063639777047, 42.26772287913731, 40.48693432126726, 41.4185140473502, 42.145403317042756, 43.890137672424316, 46.60417004993984, 45.98791694641113, 45.352625778743196, 44.085385526929585, 41.40109838758196, 42.709444182259695, 43.28911502020699, 43.52067068644932, 46.365193707602366, 52.304117815835134, 55.818127564021516, 58.49278450012207, 53.69496999468122, 54.373687403542654, 47.848040035792756, 56.48679092952183, 57.039568764822825, 56.212361403873985, 50.61428812571934, 50.822643756866455, 21.632775102342876, 1.0658464985234397, 6.104790202208927, 7.188809931278229, 10.29447969368526, 38.2929676600865, 64.9733554295131, 57.98294653211321, 55.93121991838728, 65.11308370317731, 63.398379462105886, 53.10820852007185, 30.910638672964915, 38.97870969772339, 41.8999582018171, 41.60010174342564, 58.34729616982596, 3.92831997360502, 0.5108676584703582, 0.19714805111289024, 0.22644217205899103, 0.14635536234293664, 0.10524612146296672, 0.249379179839577, 0.2299414857157639, 0.2235700554613556, 0.15381050801702909, 0.15087850391864777, 0.25086802137749536, 0.1704842440251793, 0.14123546278902463, 0.09203950941030468], [0.016253215626680424, 0.05720800666936806, 0.054949058419359584, 0.031605899932661226, 0.021043811958017092, 0.018244580199409808, 0.08250724590782609, 0.026970152077930312, 0.07608633687985794, 0.05487101332151464, 0.014764609879681041, 0.043206344957330396, 0.11328224239072629, 0.03418337966182402, 0.06786194962582418, 0.046876082862062116, 0.06840720001075949, 0.07599151161100183, 0.10937209613621235, 2.6071391190801347, 44.86577245167324, 39.136711733681814, 26.90377061707633, 28.922698259353638, 32.45632103511265, 59.059153011866975, 62.2743832724435, 57.195792061941965, 58.94580704825265, 54.96272093909127, 57.75203357424055, 24.197442054748535, 0.4421916093145098, 0.915815240570477, 26.320104564939225, 58.662793023245676, 60.2529855455671, 59.560312679835725, 54.39844036102295, 52.90009260177612, 51.424802439553396, 49.44079644339425, 47.490027155194966, 46.7905068397522, 44.070961066654746, 41.92277608598982, 41.279709884098594, 39.871785981314524, 41.15660864966256, 39.55833189828055, 37.27105093002319, 38.734477043151855, 37.77949578421456, 38.99686186654227, 38.64410529817854, 38.882560525621685, 37.612395082201274, 38.30194125856672, 37.89435298102242, 39.128710883004324, 37.87358134133475, 36.22724042619978, 38.22188758850098, 39.210442543029785, 36.12558133261544, 34.76578065327236, 36.4784699167524, 36.88085746765137, 36.53991283689226, 39.242762088775635, 38.36453063147408, 35.70338099343436, 34.28569834572928, 36.52717678887503, 34.89215101514544, 36.15595538275582, 35.273839882441926, 35.651411942073274, 36.46543162209647, 36.29380069460188, 43.6400511605399, 49.13485336303711, 53.39640590122768, 50.162314755576, 51.45689269474575, 51.23542928695679, 52.151584012167795, 41.92246341705322, 27.872073309762136, 51.546441078186035, 53.21931021554129, 52.953798702784944, 50.67577968324934, 51.95045798165457, 51.34545748574393, 50.9050007547651, 44.39758893421718, 41.32938950402396, 39.96724380765642, 37.92801005499703, 35.69691569464547, 36.789589405059814, 36.939312662397114, 35.10235834121704, 35.8529965536935, 37.647066593170166, 36.786751065935405, 37.14467709405081, 36.8264148575919, 36.710053375789094, 35.993819168635774, 34.93347542626517, 34.6450001171657, 34.00900718144008, 34.32208606175014, 34.82528502600533, 34.19697332382202, 35.58990996224539, 35.82109042576381, 35.94189528056553, 36.735754762377056, 35.40362875802176, 36.187885829380576, 35.75418969563076, 37.381527287619456, 34.90727029527937, 35.963747365134104, 36.54986613137381, 39.06079918997628, 38.413119384220664, 38.290754658835276, 40.64286579404558, 45.284477846963064, 52.872654165540425, 53.67360428401402, 55.0282632963998, 52.05959333692278, 57.37950938088553, 57.941976479121614, 52.438534191676546, 55.59963798522949, 50.97112328665597, 49.23724896567208, 40.842275619506836, 28.988396951130458, 0.045650808074112446, 2.5638357741492133, 2.5055364796093533, 6.374580936772483, 44.297903129032676, 54.756595679691856, 50.254555565970286, 44.00058971132551, 48.243038177490234, 48.64200374058315, 29.0944698878697, 16.20896785599845, 31.311758177621023, 28.954967430659703, 32.2191720690046, 11.848750029291425, 0.06934193628174917, 0.0854251364778195, 0.024552833754569292, 0.07629039271601609, 0.0600440591307623, 0.05212961649522185, 0.08423487070415701, 0.039817445911467075, 0.06720469346536057, 0.0276647174863943, 0.04670081726674523, 0.04361534211784601, 0.05551051561321531, 0.021940127879913365, 0.05710023495235613, 0.017862814345530102, 0.05239582274641309, 0.02313009849084275, 0.02487384358287922, 0.025342236306252222, 0.006268562225159258, 0.03952940779605082, 0.014229399268515408, 0.022547771256150942, 0.05331813843388643, 0.010161709057034125, 0.01746825810654887, 0.08206955010869674, 0.06398161141467945, 0.06673026856567178, 0.04775788322357195, 0.1118343775825841, 0.07000426788415227, 0.11228732006358248, 2.6558718298162733, 53.719479765210835, 42.788823877062114, 31.089811870029994, 37.97848871776036, 39.32421234675816, 71.37079811096191, 66.97883483341762, 64.04550688607353, 63.43366936274937, 62.06184482574463, 62.902430943080354, 27.482482603618077, 0.4049807217504297, 1.070941156574658, 30.699559347970144, 64.36177498953683, 63.91797964913504, 62.26322446550642, 56.95337288720267, 56.29529162815639, 54.74387352807181, 51.26401765005929, 50.85458809988839, 50.05566685540335, 47.79163108553205, 45.89364031382969, 44.344886847904746, 43.9464111328125, 45.040651662009104, 42.72428206035069, 40.49612331390381, 41.57862833568028, 42.07459422520229, 41.42253705433437, 41.00699656350272, 41.14962918417794, 41.75171838487898, 39.25296899250576, 40.80643333707537, 41.883525712149485, 39.94006940296718, 39.33368968963623, 40.20610203061785, 41.18484960283552, 39.437082358769004, 38.45979043415615, 38.40989542007446, 41.084875447409495, 39.78269270488194, 40.58457040786743, 41.3948415347508, 40.162759167807444, 37.58521720341274, 38.613015583583284, 39.49788951873779, 39.02191359656197, 39.92050327573504, 39.512296608516145, 40.14446803501674, 38.94056756155831, 45.74090848650251, 53.3784830229623, 53.941533769880024, 53.894362449645996, 55.437817914145334, 52.66568122591291, 55.02227742331368, 44.188673973083496, 36.93244784218924, 55.95882511138916, 55.5404497555324, 55.615469455718994, 53.19145836148943, 56.13457979474749, 55.11706474849156, 51.97745173318045, 47.15956040791103, 43.60164499282837, 44.15118496758597, 40.98986577987671, 37.99819033486502, 39.13291106905256, 38.85391657693045, 38.02345398494175, 37.941169943128315, 39.20416831970215, 38.09683738436018, 38.7221474647522, 38.54159157616751, 36.942091941833496, 37.15564829962594, 36.14234733581543, 36.05639811924526, 36.44981207166399, 37.85011032649449, 38.06037323815482, 35.879305907658164, 36.74913351876395, 38.3011109488351, 37.10128211975098, 38.47153288977486, 36.59215634209769, 38.18872036252703, 36.432511057172505, 38.92516687938145, 36.47484990528652, 38.055071762629915, 38.98012713023594, 40.22185707092285, 39.95324318749564, 41.08728994641985, 41.99720866339547, 47.92123930794852, 54.08503491537911, 57.18933023725237, 54.93037360055106, 54.674249104091096, 56.24399307795933, 58.30921309334891, 55.626892294202534, 59.18019757952009, 54.63368204661778, 53.3177627154759, 49.13627426964896, 35.76882260186331, 0.019574753108567426, 1.2985936722585132, 4.734419575759342, 9.713910801070076, 49.54471370152065, 61.2388584954398, 53.20805065972464, 48.56260667528425, 48.77996022360665, 56.93140615735735, 31.748150212424143, 17.73856166430882, 41.0848719733102, 30.00830044065203, 42.221465247017996, 11.179020983832222, 0.10211679259581224, 0.05560671830815928, 0.013072781198258911, 0.04988401842170528, 0.09842159944985594, 0.03360032130564962, 0.04989140088270817, 0.03014614719099232, 0.06411383753376347, 0.014452738221734762, 0.04125526161598308, 0.06702273751475982, 0.011668285804002412, 0.051246903504111936, 0.07019148926649775, 0.11937241309455462, 0.1105730759778193, 0.10556693281978369, 0.09628380023475204, 0.15895100789410727, 0.18078602052160672, 0.14125268400779792, 0.1470895100917135, 0.13872415040220532, 0.1778108344546386, 0.10835705524576561, 0.21730173538838113, 0.21260036980467184, 0.14750994395996841, 0.1200034778032984, 0.17725195230117866, 0.2034598517098597, 0.15979050498987946, 0.25269295488085064, 6.617100426128932, 68.98977552141461, 54.53927339826311, 42.28204659053257, 42.89101798193795, 44.43446997233799, 69.13410350254604, 74.51740796225411, 67.29325471605573, 68.67275006430489, 64.70932388305664, 66.58874211992536, 31.370894295828684, 0.7642504391925675, 1.332556032708713, 33.51637642724173, 68.25381537846157, 68.13361154283795, 65.38064493451799, 61.131647791181294, 60.98603439331055, 59.39166600363595, 55.93528461456299, 54.416137422834126, 53.69760683604649, 52.003007207598, 49.2313951083592, 46.76052188873291, 47.22769096919468, 49.047236578805105, 44.93852703911917, 44.4031092779977, 45.222128186907085, 46.10812078203474, 43.51512949807303, 43.048651763371055, 42.77632754189627, 45.075844287872314, 42.339914662497385, 42.82969665527344, 45.81249230248587, 44.51543385641915, 43.10036720548357, 42.67965725490025, 45.440315519060405, 42.109026023319785, 40.72423267364502, 41.10833951405117, 43.10318122591291, 40.451793806893484, 43.44188853672573, 43.95948069436209, 41.15824147633144, 39.99187517166138, 42.06945603234427, 41.942720890045166, 41.966799872262136, 42.496676445007324, 43.60013723373413, 42.61583457674299, 42.11975751604353, 50.81534120014736, 57.17621898651123, 59.414122581481934, 55.894797461373464, 58.201154708862305, 56.85738352366856, 58.39038889748709, 45.668525627681184, 30.974704538072857, 56.081686632973806, 59.06842885698591, 58.10614851542881, 56.88066693714687, 58.84845583779471, 58.55157320840018, 54.625583921160015, 49.1965776852199, 46.63689953940255, 45.585518973214285, 42.81234700339181, 40.25928701673235, 41.1208427974156, 40.977108887263704, 39.05343757356916, 38.02693850653512, 41.13085862568447, 39.84280504499163, 39.83053452627999, 40.38340268816267, 38.97438791819981, 40.40102331978934, 38.46839925221035, 39.31930691855294, 37.88048437663487, 40.33106190817696, 39.326001507895334, 38.96428176334926, 41.66368818283081, 40.00648723329817, 40.16237701688494, 41.51909964425223, 39.30363178253174, 39.4666816847665, 39.82388162612915, 41.60419423239571, 39.18423741204398, 40.19334166390555, 42.78441871915545, 43.75153848103115, 41.245806149074006, 43.95182030541556, 44.18077734538487, 48.81517716816494, 56.31763008662632, 59.554997307913645, 56.0870749609811, 54.189407280513215, 57.01585456303188, 60.87348052433559, 56.60922861099243, 61.644160815647666, 57.31907742364066, 58.22845070702689, 50.22820799691336, 41.92291852406093, 0.21940125844308309, 6.0691181506429395, 8.939730354717799, 9.06251631464277, 54.35842221123831, 64.57063783918107, 57.416473797389436, 52.75051873070853, 56.700934410095215, 62.569584437779014, 37.14058460508074, 23.57531946046012, 47.06874050412859, 43.167677879333496, 49.11817421231951, 28.90639952250889, 0.1578350213489362, 0.15301210300198623, 0.10243059468588658, 0.3110179794686181, 0.14899959973990917, 0.12335626860814435, 0.1550775228866509, 0.13087350023644312, 0.1252082756587437, 0.14011195807584695, 0.11999988156769957, 0.11111944594553538, 0.16018444885100636, 0.14153481886855193, 0.12367756851017475], [0.09439625151987587, 0.09809951244720391, 0.020255642643730556, 0.1333290370447295, 0.021264938038906882, 0.07420490855084998, 0.04400751839524933, 0.08199727934386049, 0.04571533675438591, 0.04798177942367537, 0.0419325379521719, 0.013821219742697264, 0.0814868581614324, 0.008707955413098847, 0.05038742015936545, 0.09349600518388407, 0.00798762942265187, 0.031309644758169136, 0.04669443564489484, 0.1574052779802254, 15.790463958467756, 57.5237192426409, 39.10530587605068, 31.57469538279942, 27.416000502450125, 41.92943246023995, 65.26237964630127, 59.56184128352574, 56.462791851588655, 53.07374545506069, 53.20697716304234, 28.410397154944285, 0.9704249330929348, 1.7029574428285872, 32.07274573189871, 59.88500199999128, 61.32614871433803, 58.69163499559675, 52.6841391154698, 53.67295462744576, 51.386170455387656, 49.567889417920796, 48.259314332689556, 46.42778308050973, 44.827765805380686, 43.24102306365967, 41.50400120871407, 41.88678789138794, 41.09491559437343, 40.08636719839913, 39.44609069824219, 38.31413882119315, 38.785532406398225, 39.57282584054129, 40.754756110055105, 39.76702104296003, 38.903339113507954, 39.503361225128174, 39.4497697693961, 38.96840551921299, 38.40716825212751, 38.90824106761387, 38.08740520477295, 37.25669247763497, 36.56726442064558, 35.56301695959908, 36.04205356325422, 36.21998650687081, 37.545817443302695, 39.61456714357649, 36.94021592821394, 36.818410532815115, 35.04652609143938, 37.25464970724923, 35.96383421761649, 36.7028237751552, 36.823159626552034, 36.47935233797346, 37.18479251861572, 37.82776491982596, 40.66920294080462, 49.94458947862898, 51.51653255735125, 52.23269380841936, 51.73527921949114, 51.687083039964946, 51.880006722041536, 44.490913663591655, 27.546232325690134, 46.910290309361045, 53.94275665283203, 52.071165561676025, 52.417661803109304, 51.34311246871948, 54.307040282658164, 50.49596030371529, 48.51970154898507, 42.65934419631958, 39.41928802217756, 39.94699675696236, 36.59830549785069, 35.884127957480295, 35.900949546269004, 36.56224087306431, 36.06294332231794, 36.96046992710659, 36.86787128448486, 37.406804834093364, 38.004992621285574, 37.232651710510254, 37.34509788240705, 36.68347304207938, 34.53016029085432, 34.61688423156738, 35.14796979086739, 35.73134401866368, 35.576183795928955, 34.5320918900626, 35.03750385556902, 35.52404451370239, 34.19888407843453, 34.534753050122944, 33.94830077035086, 37.63829796654837, 37.29048156738281, 36.2044711794172, 38.05607577732631, 36.81386988503592, 38.169310569763184, 39.051929814474924, 38.35125262396676, 39.87345354897635, 48.11634125028338, 53.58480283192226, 53.78180858067104, 52.144104276384624, 56.09782382420131, 52.55996091025216, 56.999171938214985, 53.207936014447895, 56.57138524736677, 53.4533429145813, 50.36871099472046, 42.18883303233555, 42.63075930731637, 3.4518318389143263, 2.0022780214037215, 1.3364558177334922, 14.951324803488594, 50.29735994338989, 47.05639008113316, 41.05508157185146, 44.91023744855608, 60.49687426430838, 56.6021067074367, 38.732138974326, 18.01183431489127, 32.37714631216866, 30.222683634076798, 35.37284823826381, 1.3168344306094306, 0.20536800074790204, 0.02952050058437245, 0.04511411740843739, 0.02488882902876607, 0.06235977701310601, 0.058977734563606124, 0.04069446260109544, 0.05750279620821987, 0.08425775769033603, 0.12907824585480349, 0.005376009628110166, 0.048182242416909764, 0.05816280722085919, 0.031704263761639595, 0.04920346815405147, 0.01901280228048563, 0.018351932921047722, 0.02107665135658213, 0.029681998704160963, 0.018552601171125258, 0.02489063562825322, 0.0236144079494157, 0.049808453369353495, 0.039080424566886256, 0.0349296087266079, 0.02014191847826753, 0.07001843569534165, 0.02117872846845005, 0.028582941607705185, 0.09919316840491124, 0.035759246708559136, 0.07204173212604863, 0.09200193892632212, 0.09848128339009625, 0.15389657339879445, 21.13727126802717, 68.5246353149414, 39.480525970458984, 45.76636668613979, 31.31318950653076, 46.11442974635533, 76.39825752803257, 63.782385553632466, 61.219174248831614, 58.33785356794085, 60.960916655404226, 32.62460987908499, 1.0374499708414078, 2.0323960738522664, 35.53499834878104, 65.0595269884382, 64.2430441720145, 61.765156745910645, 56.00033712387085, 56.65813003267561, 53.22989927019392, 53.491276604788645, 50.550587041037424, 47.874460560934885, 48.70218903677804, 45.383076259068076, 43.50490174974714, 44.76484291894095, 43.266651494162424, 43.98678364072527, 41.96361412320818, 40.42667259488787, 40.589625222342356, 43.44497006280081, 42.75526755196707, 41.40246023450579, 41.361535344805034, 42.4180645261492, 42.12247078759329, 41.41280262810843, 41.26990597588675, 42.724639892578125, 40.88979434967041, 39.18649557658604, 39.84223876680647, 39.02887569155012, 39.393478938511436, 38.21040569032942, 41.72901514598301, 42.36411871228899, 40.350221565791536, 40.332309109824045, 38.780960491725374, 39.213503224509104, 39.469301155635286, 39.75509793417794, 40.67191621235439, 40.10505437850952, 40.70400646754673, 41.068950176239014, 43.023999554770334, 52.91502775464739, 54.06049387795584, 54.16114548274449, 54.287053789411274, 53.41889027186802, 54.71814087459019, 47.414194515773225, 34.35613570894514, 49.38187224524361, 57.45914268493652, 56.345947469983784, 56.182042939322336, 53.54666069575718, 55.43673052106585, 54.22251197269985, 52.02202442714146, 44.66337142671858, 42.02358749934605, 41.37687349319458, 39.712793827056885, 39.45883369445801, 38.12491852896554, 38.52219220570156, 38.119988782065256, 39.064134325299946, 39.53036192485264, 39.59500796454293, 38.78579643794468, 38.35868372235979, 38.37025594711304, 36.77669702257429, 35.41133778435843, 37.139611857278005, 37.636251722063335, 37.27033526556832, 38.10226045336042, 37.93300233568464, 37.3585843358721, 38.09851884841919, 37.44916452680315, 36.715559823172434, 36.83421768460955, 38.248648575374055, 37.65427187510899, 36.24636534282139, 39.281727586473735, 39.379579067230225, 39.65708317075457, 39.54871906552996, 41.11165380477905, 41.661169460841585, 50.05619144439697, 54.8927560533796, 55.966332639966694, 53.619106088365825, 56.55448375429426, 52.57554571969168, 58.32631261008126, 56.95770161492484, 60.92804472787039, 55.17510305132185, 56.1324918610709, 49.82727261951992, 52.42124707358224, 5.370219698974064, 1.1120315002543586, 1.3140818583113807, 16.619521277291433, 55.885073457445415, 51.056916168757844, 45.470352581569124, 48.22712332861764, 62.76250811985561, 60.75282505580357, 37.258558068956646, 22.814759220395768, 34.710354873112266, 34.85051046098982, 44.58873735155378, 1.616288653441838, 0.15844426437148026, 0.030655479324715476, 0.0341446353122592, 0.09270916240555899, 0.04900773115722196, 0.05550645797380379, 0.04569978812443359, 0.04215780818568809, 0.026442859122263532, 0.08009085378476552, 0.015158433300842131, 0.04387527531278985, 0.015315716021827288, 0.025234462892902747, 0.05401914653235248, 0.15554683841764927, 0.17831685873014586, 0.1572150710437979, 0.25746240466833115, 0.0915977084743125, 0.12185103366417543, 0.09418802269335304, 0.2523123781595911, 0.1510601613138403, 0.15031050225453718, 0.07091809170586721, 0.15986332536808082, 0.10598963978035109, 0.09399377847356455, 0.19303007636751446, 0.12775945876325878, 0.13510895653494767, 0.14519476890563965, 0.21409552171826363, 0.2560284701841218, 33.79007291793823, 77.20360238211495, 52.97016518456595, 48.835472856249126, 40.58468852724348, 49.887603827885215, 78.24636718205043, 68.6011071886335, 68.12109783717564, 63.751417432512554, 64.53509085518974, 35.780453886304585, 1.846286403281348, 2.6807398668357303, 39.65977212360927, 69.83888707842145, 67.84378828321184, 65.8519481931414, 60.48100457872663, 59.11179256439209, 56.282798767089844, 56.56173767362322, 54.915810176304404, 52.9086458342416, 51.856983866010395, 48.25179985591343, 47.530489989689414, 47.69581890106201, 46.80437544413975, 48.650890486580984, 45.657995632716585, 43.32690627234322, 45.07964147840227, 47.350180762154714, 46.44593872342791, 46.52859796796526, 45.47565058299473, 44.60200841086251, 44.18946259362357, 44.13520411082676, 45.79389544895717, 45.75630916867937, 44.83387674604143, 43.59061125346592, 41.77196543557303, 40.96633570534842, 43.12750686917986, 39.82907540457589, 43.484154428754536, 45.497228213718955, 42.159000941685264, 42.879473549979075, 41.20730965478079, 43.1935008593968, 43.77523183822632, 41.65883139201573, 44.643680231911794, 44.0610807282584, 42.83236476353237, 43.53028004510062, 46.14432437079293, 57.594031538282124, 57.91469785145351, 58.0638860974993, 55.50274188177926, 56.70347050258091, 58.1062388420105, 48.21364729745047, 32.051157678876606, 51.14797925949097, 60.071686199733186, 59.143893241882324, 57.72464377539498, 54.916060311453684, 59.06210599626814, 56.946751253945486, 53.246769496372764, 47.65144075666155, 44.99998385565621, 44.23170416695731, 41.735834802900044, 39.903059823172434, 39.88662385940552, 41.973101888384136, 39.58028473172869, 40.52508340563093, 40.59339462007795, 41.08724478312901, 42.68827996935163, 40.061058385031565, 41.4401889528547, 40.4438659123012, 38.15622363771711, 39.53844962801252, 39.414556298937114, 38.90654223305838, 41.308020319257466, 41.47510365077427, 38.836306367601665, 40.082684653145925, 40.73103496006557, 37.498312609536306, 39.07934740611485, 41.46101270403181, 41.92038243157523, 39.578429562704905, 42.95348923546927, 41.48232282911028, 42.02689484187535, 42.63266658782959, 43.304279463631765, 43.943722179957796, 51.18603106907436, 57.39850575583321, 57.36849301201956, 54.71541370664324, 59.80606351579939, 54.69689328329903, 60.67469951084682, 58.183961391448975, 63.11055728367397, 57.77789824349539, 61.05851105281285, 50.98359530312674, 55.695741994040354, 7.087380128247397, 3.4586443305015564, 6.625664949417114, 16.679095132010325, 61.1484763281686, 56.53957986831665, 50.97092873709542, 53.609423773629324, 69.48607839856828, 63.24516473497663, 50.35908773967198, 28.25385250364031, 48.45282513754708, 41.947942461286274, 60.58462306431362, 7.401948094367981, 0.7931136361190251, 0.18351162783801556, 0.12929875616516384, 0.2916751445404121, 0.10370594196553741, 0.235660477408341, 0.15359355323016644, 0.10881033020892314, 0.21661474582340035, 0.1644274911710194, 0.11767348354416234, 0.20608080178499222, 0.19802370055445603, 0.20198587008884974, 0.14906247279473714], [0.13097789963441236, 0.040298584915165386, 0.006979145300907216, 0.006839328495386455, 0.05618773088125246, 0.02743311652115413, 0.00961653670362596, 0.056129061350865025, 0.05329088507486241, 0.07276042963245086, 0.03631308734683054, 0.05668284770633493, 0.0473939340029444, 0.07854798050331217, 0.07816679310053587, 0.022450834047049284, 0.022578254441863725, 0.08109039693538632, 0.2139271636094366, 0.04212700608851654, 5.136323358331408, 53.05092409678868, 47.14004986626761, 43.2423015322004, 21.483077900750295, 45.50013950892857, 56.17482376098633, 61.13141850062779, 58.22831869125366, 51.216801166534424, 58.999954359872, 35.12639216014317, 1.5402730809790748, 0.9714833391564233, 25.767250299453735, 60.27446242741176, 63.890388352530344, 59.36890370505196, 55.24730178288051, 54.25243091583252, 53.31071029390608, 53.16180344990322, 51.30118703842163, 50.82944604328701, 44.488186495644705, 43.17608172552926, 41.513402121407644, 42.13062102454049, 40.74376405988421, 40.61614997046334, 39.91144282477242, 40.29727629252842, 40.59295688356672, 42.276140621730256, 39.87681300299508, 38.051889487675254, 38.742338929857524, 39.23752662113735, 39.07147509711129, 38.1337879044669, 38.40558058874947, 37.518326895577566, 37.874633993421284, 36.981210299900596, 37.586704117911204, 37.211435386112754, 37.09916639328003, 37.909896101270405, 38.550023215157644, 39.39886726651873, 37.68519830703735, 37.91075072969709, 35.861386503492085, 36.68686376299177, 38.06503895350865, 37.4897836957659, 36.808283533368794, 38.673857484545024, 38.20988457543509, 38.31810276848929, 37.97050871167864, 44.03352069854736, 51.81275510787964, 51.44031776700701, 49.10727596282959, 51.122277872903005, 52.525049686431885, 54.18939685821533, 28.597901242119924, 40.486694608415874, 53.950125217437744, 52.8489990234375, 52.245471545628135, 52.54997982297625, 53.59505142484392, 53.3823219026838, 50.791189261845176, 43.67070313862392, 41.08758871895926, 41.203606264931814, 39.755421025412424, 36.69161285672869, 37.22799294335501, 36.71126583644322, 37.12205375943865, 36.18289702279227, 36.9755996295384, 36.19800935472761, 39.44611154283796, 37.7322758265904, 36.78827272142683, 35.80892413003104, 35.23809487479073, 34.726690087999614, 35.192469528743196, 36.58079603740147, 36.59782607214791, 36.70278556006295, 36.35751914978027, 37.540279729025706, 35.57855313164847, 38.942586013248985, 38.64287199292864, 35.551736559186665, 38.598935059138704, 35.297797271183555, 36.45265735898699, 37.17920616694859, 39.87802198954991, 37.56029054096767, 40.40845789228167, 40.44253533227103, 46.56249475479126, 50.967305251530235, 55.76104463849749, 54.06880044937134, 55.71195214135306, 54.181260517665315, 54.11813613346645, 52.43339947291783, 55.51752070018223, 49.37600449153355, 55.4525967325483, 45.325562545231406, 48.82013470785958, 6.903966358729771, 0.8640383503266743, 1.214482145650046, 21.770547458103724, 50.32330451692854, 50.90757506234305, 56.46559197562081, 57.11284794126238, 52.69992889676775, 56.35758222852434, 23.06417175701686, 28.62426791872297, 29.414622034345353, 34.31469317844936, 22.490822042737687, 0.1172447172658784, 0.04895530754168119, 0.0608395803719759, 0.04271780313657863, 0.023024494693215405, 0.037612400483340025, 0.09479166780199323, 0.017629990320918814, 0.015576753532513976, 0.06581192570073263, 0.04385301936417818, 0.03540087843845997, 0.04563259280153683, 0.030025425633149486, 0.0629398769565991, 0.032586603558489254, 0.12527870759367943, 0.07049298951668398, 0.008259319084962564, 0.0359545053382005, 0.00508492616271334, 0.045183229592761824, 0.037148771075797934, 0.019736005259411674, 0.07578307243862323, 0.056908864328371625, 0.06415098054068429, 0.08516113885811397, 0.0303194077153291, 0.043054380254553895, 0.06260031089186668, 0.03394850815779396, 0.08757650639329638, 0.016837834613397717, 0.1768166178039142, 0.07094720085816723, 5.854985526629856, 61.71089826311384, 44.99101373127529, 42.60490158626011, 32.2378523009164, 46.02417959485735, 68.638231413705, 65.3259973526001, 63.97858183724539, 53.873924323490684, 64.85304042271206, 40.334004470280235, 2.084002298968179, 1.0787045742784227, 28.73145604133606, 61.62820775168282, 66.16934190477643, 62.63284083775112, 56.819675649915425, 55.87730189732143, 57.67650318145752, 55.324485846928184, 55.30729947771345, 51.163119384220664, 48.262222153799875, 46.44382994515555, 45.1880715915135, 45.997050353458945, 43.79125091007778, 42.892473629542756, 43.78240932737078, 43.26637009211949, 44.052739415849956, 46.442249229976106, 44.27692304338728, 41.14303534371512, 41.657396589006694, 41.76270696095058, 41.85196352005005, 41.7653021131243, 39.98793206896101, 40.07190452303205, 40.842369420187815, 39.11815309524536, 39.19251619066511, 39.05476120540074, 39.269568238939556, 39.8289155960083, 41.11913701466152, 42.97528920854841, 41.36221626826695, 39.047601086752756, 39.31435980115618, 40.72483369282314, 41.26498665128435, 39.22712516784668, 40.059925828661235, 42.00027976717268, 39.60550669261387, 40.64495025362287, 42.03834547315325, 48.37578351157052, 55.356867926461355, 54.66067927224295, 52.71563529968262, 55.05190454210554, 54.63311576843262, 57.70055784497942, 35.175286633627756, 44.62210260118757, 58.60347625187465, 56.66370248794556, 56.277594566345215, 55.1003543308803, 56.310727051326204, 56.33420501436506, 53.05127150671822, 46.84244115012032, 42.121324334825786, 43.37394210270473, 42.84457969665527, 40.1065343448094, 39.40676042011806, 38.28938933781215, 39.11582544871739, 38.621516704559326, 38.95145538875035, 38.87783922467913, 41.14434507914952, 39.960340772356304, 38.98134306498936, 37.37606600352696, 37.55539900915963, 37.19700050354004, 38.30662781851632, 39.500967570713584, 37.74275023596627, 37.504649366651265, 38.60881887163435, 39.01707417624337, 38.22851616995675, 39.617617402757915, 40.97846031188965, 36.68739530018398, 40.33001273018973, 37.0668294770377, 40.06234380177089, 39.52229854038784, 41.28629330226353, 38.48036405018398, 41.885884625571116, 40.82571111406599, 49.7372065952846, 52.34675891058785, 57.76392194202968, 55.695509229387554, 58.58548041752407, 54.897418294634136, 58.109382901872905, 56.32753126961844, 60.045943123953684, 50.709620884486604, 60.59132807595389, 51.468190465654644, 56.63272047042847, 9.069354210581098, 0.9766975279365266, 1.943978726863861, 23.454945393971034, 56.9572743007115, 55.673994132450645, 60.11816964830671, 59.9111202784947, 56.21293115615845, 62.089248520987375, 28.526760373796733, 34.26733773095267, 33.30343845912388, 41.37053326198033, 23.465550082070486, 0.17225375478821142, 0.027561593734260117, 0.10902177529143435, 0.024260229098477533, 0.04347208301935877, 0.030452027384723936, 0.044716699448015006, 0.057201825215348175, 0.028349291466708695, 0.021084917609446814, 0.021091713137658577, 0.014033639371129019, 0.08706856186368636, 0.04865108975874526, 0.08801885694265366, 0.06178403326443263, 0.37491467222571373, 0.16310247512800352, 0.10964684853596346, 0.14292479785425322, 0.14879529284579412, 0.09017689685736384, 0.138049184477755, 0.17483271711638995, 0.16413705104163714, 0.224904950974243, 0.12141029802816254, 0.16637821149613174, 0.11737207828887872, 0.11895846602107797, 0.1599930612636464, 0.153371075168252, 0.21582856800939354, 0.17136819873537334, 0.5178647115826607, 0.34090758274708477, 10.964681216648646, 76.53129468645368, 59.144991057259695, 54.70256301334926, 36.67490243911743, 56.84593636648995, 69.44484778812954, 71.40811688559396, 66.20541000366211, 61.74561841147286, 70.46513516562325, 44.23045349121094, 2.3292281116758073, 1.6332527888672692, 32.412700244358604, 67.09231976100376, 68.67734282357353, 65.45275333949498, 63.07368319375174, 58.790271622794016, 60.9976031439645, 59.73687335423061, 58.70296055930001, 56.98237119402204, 50.86597967147827, 50.31846857070923, 46.85853317805699, 49.85291494641985, 47.10694169998169, 45.840260778154644, 49.1090338570731, 47.69631222316197, 48.042019844055176, 50.45627566746303, 45.59271730695452, 44.04684386934553, 46.46060637065342, 43.94065455027989, 45.810248034340994, 44.74024282182966, 42.66537175859724, 43.9573267527989, 44.58736160823277, 41.80380208151681, 44.190233843667166, 43.41099337169102, 43.291185583387104, 42.39327335357666, 43.49936056137085, 45.94807597569057, 43.334445067814414, 42.360304151262554, 42.66610826764788, 42.033196857997346, 44.816290855407715, 42.561214787619456, 43.726281779153005, 45.5414639200483, 44.07805517741612, 44.659688881465364, 44.349569933755056, 50.20536231994629, 59.62588977813721, 56.03855569022042, 55.86222778047834, 56.058507442474365, 59.58299160003662, 56.96725538798741, 29.37999221256801, 44.750630378723145, 60.32390580858503, 59.725290707179475, 58.32984924316406, 56.431424209049766, 58.08630793435233, 57.612760407584055, 56.30331679752895, 47.54014451163155, 45.748756476810996, 46.11764676230294, 45.23022631236485, 41.14410884039742, 42.26673970903669, 39.2058219909668, 40.53227826527187, 40.39525978905814, 41.638497488839285, 40.182832513536724, 42.90960093906948, 40.98978240149361, 41.19769334793091, 40.83594928468977, 40.959213801792686, 40.52769245420183, 40.190920216696604, 40.64709029878889, 41.61772237505232, 42.00864887237549, 40.77434655598232, 41.74707351412092, 41.23422350202288, 43.3992509160723, 43.77442932128906, 39.61005776269095, 43.62330252783639, 39.043974127088276, 41.71903058460781, 41.00542279652187, 42.872681685856406, 41.56212636402675, 43.53288561957223, 43.56268644332886, 51.87424666540963, 52.87006943566458, 61.58005673544747, 58.55775710514614, 59.76905741010393, 57.388997146061485, 59.41073186056954, 57.21510805402483, 63.612425667899, 53.745976720537456, 64.59838894435337, 54.615217208862305, 58.54163728441511, 11.650187015533447, 2.302264324256352, 6.556681062494006, 25.8889445236751, 60.43113735743931, 58.22693599973406, 65.17235878535679, 63.9977171761649, 63.30292510986328, 66.65798091888428, 33.560671193259104, 42.94890342439924, 46.266713414873394, 47.95283276694161, 42.05471542903355, 0.16663376135485514, 0.08657192851283721, 0.21868301555514336, 0.1408059365515198, 0.14317118749022484, 0.09401481305914265, 0.17247635498642921, 0.09853001577513558, 0.13748790031032904, 0.21648080301071915, 0.12894948704966477, 0.10560826917311975, 0.22453744283744267, 0.1410327979496547, 0.19303060562482902, 0.16446235430027756], [0.008187582666453506, 0.0796147325475301, 0.019229446637577245, 0.03799369984439441, 0.0425522473773786, 0.034170836942004304, 0.024246040931237594, 0.08432424055146319, 0.07300046818064791, 0.05615807890093752, 0.05419557920790144, 0.006395978379129831, 0.06903121474065951, 0.015473231141056334, 0.029623851645737886, 0.1074404019330229, 0.15863010154238769, 0.11079676861741714, 0.00393881944806448, 0.06484049425593444, 0.22364900979612554, 32.590792996542795, 50.01742744445801, 52.75834935052054, 31.750613348824636, 31.461432797568186, 57.76014559609549, 60.744605336870464, 69.50454671042306, 50.46868862424578, 54.80807835715157, 45.0627886227199, 4.35395793403898, 0.35008105050240246, 16.73890175138201, 51.65782070159912, 64.89039393833706, 63.552038873944966, 58.34945705958775, 54.72855969837734, 54.64438574654715, 54.075710432870046, 51.22459009715489, 52.60482890265328, 53.204006808144705, 47.35390499659947, 42.634000641959055, 41.00412695748465, 40.72983292170933, 41.54180983134678, 41.15344374520438, 41.07168776648385, 41.65177549634661, 44.117534841809956, 41.80471229553223, 38.59089599336897, 37.924935477120535, 40.02408354622977, 38.05245923995972, 38.56546558652605, 38.10507794788906, 38.49535826274327, 38.05825751168387, 38.73990706035069, 37.28138290132795, 38.06196437563215, 37.15482841219221, 38.464556898389546, 38.05594376155308, 40.52297462735857, 37.53787565231323, 37.27901356560843, 37.279687540871755, 38.130122729710166, 37.176760401044575, 38.866989612579346, 36.31531926563808, 40.530951159340994, 38.17850651059832, 40.38177333559309, 39.51219585963658, 43.559375626700266, 46.09264366967337, 48.63002504621233, 48.62127031598772, 52.14148480551583, 50.66951240812029, 55.74053355625698, 32.24643680027553, 34.91635853903634, 55.45111329214913, 52.179692949567524, 55.13539062227522, 51.813755648476736, 53.278936181749614, 50.5238538469587, 53.41482557569231, 45.018320151737754, 41.2750962802342, 38.87770026070731, 40.35230949946812, 38.00959927695138, 38.45154987062727, 36.099869523729595, 39.21425015585763, 37.0148743220738, 37.74512651988438, 37.89714615685599, 38.19183315549578, 38.44047791617257, 36.292657715933665, 36.41422687258039, 35.53377546582903, 35.74518135615757, 35.24592202050345, 35.81283943993704, 35.94889906474522, 35.85520955494472, 38.21350458690098, 38.47015367235456, 38.47621250152588, 39.9587287902832, 38.43604843957083, 39.42895644051688, 40.4454778943743, 37.57353033338274, 38.16279315948486, 39.53759152548653, 38.503744738442556, 38.237336908067974, 40.1538793700082, 41.10058879852295, 42.65657533918108, 45.689415386744905, 49.69737604686192, 51.743582316807334, 50.503457409994944, 50.97082451411656, 53.98526573181152, 52.00132574353899, 57.924991607666016, 51.66618633270264, 51.96661949157715, 48.44636678695679, 54.15758105686733, 11.25085927758898, 0.8194565911378179, 0.5031634090202195, 22.816937480654033, 52.666761670793804, 46.63649306978498, 56.82216657911028, 52.95543500355312, 58.99055344717843, 37.47634587969099, 22.01407139641898, 33.321177210126606, 25.99970054626465, 37.91606957571847, 2.4096250661781857, 0.07245207617857627, 0.00939813069999218, 0.07902879720287663, 0.029973700908677917, 0.04396670451387763, 0.03219469190974321, 0.05554396060428449, 0.032244238536804914, 0.05952469485678843, 0.010380503521966082, 0.027580229698547294, 0.05294847934107695, 0.055412898172757456, 0.09322229772806168, 0.054626652505248785, 0.052178654221019576, 0.06655632611364126, 0.04710844039384808, 0.03230784101677792, 0.058783402134265215, 0.007069415055281881, 0.058780016244522164, 0.11126775334456138, 0.0753201554928507, 0.026322431030816267, 0.06573010116283383, 0.08868039465908494, 0.014291360541912062, 0.04359056201896497, 0.06273557684783425, 0.04754776806969728, 0.027621233569724218, 0.033886276318558624, 0.04815835798425334, 0.036571789000715525, 0.05551981832832098, 0.28246826572077616, 38.12654788153512, 57.85766356331961, 43.90215458188738, 43.395484992435996, 38.74749796731131, 59.45228903634207, 72.56966808864048, 72.85548918587821, 58.472335951668875, 60.70149176461356, 51.21622099195208, 5.422334228243146, 0.4359202901167529, 18.407860789980205, 56.95470346723284, 66.93782656533378, 64.11876174381801, 61.31487873622349, 58.9268593106951, 57.47538409914289, 57.038359778267996, 54.35988828114101, 54.005512782505576, 56.20533677509853, 51.239893504551475, 45.51197576522827, 45.241458075387136, 44.262873785836355, 43.2681314604623, 43.88143505368914, 42.77951676504952, 44.78345019476754, 46.53767578942435, 43.66609648295811, 39.69762938363211, 40.97954075677054, 41.90074334825788, 39.57616792406355, 41.10215214320591, 41.4661682673863, 41.16498122896467, 41.599361760275706, 39.74987636293684, 38.88380077907017, 41.40548617499215, 39.98359291894095, 41.072132451193674, 40.5044298853193, 42.14433329445975, 40.35783679144723, 39.325667994362966, 40.982761246817454, 40.20688370295933, 40.51829501560756, 41.5992888041905, 40.400873933519634, 42.315894739968435, 40.58577939442226, 43.40484421593802, 41.8161038671221, 45.26028421946934, 50.52436453955514, 54.28427798407418, 53.92548343113491, 57.23481314522879, 52.74349757603237, 59.92229298182896, 40.398063387189595, 39.95664433070591, 58.16291182381766, 53.64568294797625, 58.78060667855399, 53.98409148624965, 56.60285363878523, 53.28583574295044, 56.39016580581665, 47.880873748234336, 44.00096491404942, 42.091311591012136, 43.059793199811665, 40.143672466278076, 41.61572476795742, 38.89021396636963, 39.96222720827375, 40.380508763449534, 39.63242053985596, 39.838326930999756, 40.52073730741228, 39.537584577287944, 38.12685360227312, 38.458473750523154, 37.62346703665597, 37.69180256979806, 37.29976783479963, 37.736083439418245, 38.42970126015799, 39.21168279647827, 41.342028277260916, 42.10208477292742, 41.07352556501116, 43.7353561265128, 40.00944021769932, 41.12346574238369, 41.97805942807879, 39.7762690952846, 40.21134097235543, 40.76077325003487, 40.212754930768696, 40.66321359361921, 41.07006188801357, 42.25874580655779, 43.330578395298545, 47.24803182056972, 49.954035554613384, 52.74299035753523, 50.75722994123186, 51.7938038962228, 55.00126954487392, 53.65051542009626, 61.459331784929546, 56.2649245262146, 54.8735477583749, 53.07062223979405, 60.27308668409075, 14.276109286717006, 1.1775879710912704, 1.1084119230508804, 25.94208608354841, 60.80479063306536, 50.754683426448274, 62.66271809169224, 54.50774942125593, 67.53124441419328, 44.26666055406843, 27.46274277142116, 36.683823926108225, 30.75154229572841, 47.303933552333284, 1.6392153203487396, 0.11646900246185915, 0.11055223138204642, 0.02058561422329928, 0.047292231781674285, 0.02586942069631602, 0.007380300717029188, 0.07802680454083852, 0.011261188541539013, 0.01809517866266625, 0.013442291861533054, 0.03341927459197385, 0.051102494288768084, 0.07496343606284686, 0.01982314103016896, 0.016875150646748285, 0.03991394716181925, 0.19443015195429325, 0.25546789169311523, 0.10198060383221932, 0.08503424602427653, 0.1258767955005169, 0.1507583489375455, 0.184487144063626, 0.21842221383537563, 0.11430993117392063, 0.1000452930373805, 0.12814342815961155, 0.08614362363836595, 0.1515019554644823, 0.11691072875899927, 0.16019279483173574, 0.1617612556687423, 0.2739571567092623, 0.17910385078617505, 0.08557506557554007, 0.16698391256587847, 0.35717459129435675, 52.964467661721365, 67.98371805463518, 59.97635691506522, 46.4459456716265, 44.312129565647666, 68.13978154318673, 76.83666106632778, 74.7323226928711, 61.62298270634243, 66.0663001196725, 54.95285449709211, 6.381570824554988, 0.7517916677253587, 20.693437712533132, 60.77219663347517, 69.81800774165562, 67.69827216012138, 64.16974067687988, 64.31367261069161, 60.13886138371059, 61.54528794969831, 56.936992509024485, 58.72599383762905, 58.95011493137905, 55.942013944898335, 50.202298164367676, 46.856782232012065, 46.40285989216396, 46.51040063585554, 48.96052653448922, 47.08351237433297, 48.719219071524485, 50.33566883632115, 47.09871850694929, 42.89506183351789, 44.67950861794608, 45.913314138139995, 42.29813861846924, 45.16021973746163, 43.75551632472447, 45.00194672175816, 45.2230418750218, 44.36078780038016, 42.70198876517159, 45.96960844312395, 43.93083674567086, 43.24393783296858, 43.57982070105416, 46.40089007786342, 42.542836802346365, 42.009357588631765, 43.53831911087036, 43.68657629830496, 41.79775020054409, 46.963141781943186, 42.535058294023784, 45.47230155127389, 42.87370307104928, 46.058448110307964, 44.668283803122385, 50.72292668478829, 52.95865201950073, 55.79663678577968, 55.01252562659127, 59.283413069588796, 54.10644578933716, 60.4120089667184, 32.68274893079485, 39.777432918548584, 61.48795141492571, 56.57735027585711, 61.2979598726545, 54.98782478060041, 57.847230843135286, 55.30087239401681, 56.958823748997276, 50.318225383758545, 46.19997249330793, 43.77915757043021, 44.816280433109824, 41.53846427372524, 42.19362728936331, 37.57174812044416, 42.254597731998985, 41.68834039143154, 42.59629276820591, 41.30990675517491, 41.72743443080357, 42.45380258560181, 39.230474199567524, 40.073790958949495, 40.20929820196969, 40.14408588409424, 39.41755444662911, 40.16346093586513, 40.46280322756086, 42.371403898511616, 43.37176036834717, 44.57381609507969, 43.036072049822124, 45.53003065926688, 41.492651326315745, 42.64567361559187, 44.56793097087315, 41.30605397905622, 42.04837172372, 44.09770815713065, 42.449675355638774, 42.88074854442051, 43.803097588675364, 45.16152599879673, 46.310355050223215, 47.802032538822715, 53.18186984743391, 55.14440243584769, 53.11974252973284, 54.69389166150774, 58.26130526406424, 55.62657962526594, 63.3866856438773, 57.485521520887104, 59.29029178619385, 56.34461688995361, 61.45013236999512, 17.651976687567576, 2.0602650812694003, 1.5780573849167143, 28.05978410584586, 63.8466147014073, 55.19619083404541, 67.90032577514648, 62.01990549904959, 70.11750984191895, 45.629612241472515, 32.41745628629412, 47.10167496544974, 38.37791633605957, 59.42018835885184, 9.202988914081029, 0.4320644198783806, 0.18987513280340604, 0.16359670646488667, 0.09668513334223203, 0.1484246498772076, 0.0947846517499004, 0.1375418302736112, 0.13984206398682936, 0.11029368239854064, 0.06727163773030043, 0.10747552290558815, 0.13952009912048066, 0.14315483479627542, 0.1237336697855166, 0.12112459407321044, 0.12860530694680555], [0.07317694835364819, 0.016131136998800293, 0.02378922571162028, 0.043951318732329776, 0.03529116611129471, 0.02337717175084565, 0.08247414018426623, 0.009126984713865178, 0.057189611585012505, 0.023960866233600036, 0.04469380567648581, 0.01688829217372196, 0.0201714296625661, 0.03353245084040931, 0.0494392590730318, 0.034842013248375485, 0.05022154888138175, 0.035570654685475996, 0.056662467907049825, 0.06628719198384456, 0.0515494453055518, 5.723136510167803, 59.12937150682722, 30.975211756569998, 32.706119196755544, 21.658556393214635, 46.84377173015049, 63.02610192980085, 56.99957493373326, 56.45645162037441, 56.61063214710781, 54.17990909303938, 18.40246203967503, 0.47830237448215485, 7.514706066676548, 46.5928236416408, 66.79065677097866, 66.44586631229946, 61.63732378823416, 58.76282623835972, 57.30540336881365, 57.44777543204171, 55.41611868994576, 56.28760692051479, 55.637394496372764, 55.389712061200825, 45.55635738372803, 41.44704335076468, 44.507248878479004, 42.573457513536724, 42.217247690473286, 44.38935879298619, 43.400105544498985, 42.228375230516704, 43.00339467184884, 41.043137618473594, 40.14364119938442, 40.40642554419381, 39.00543941770281, 39.87545115607125, 38.84653411592756, 37.62359210423061, 38.94689737047468, 38.94748101915632, 38.00661155155727, 39.324594497680664, 38.01308379854475, 37.8610189982823, 38.683258397238596, 40.55235161100115, 39.37063326154436, 38.595290728977744, 36.881173610687256, 38.44941677365984, 36.24197060721261, 37.27097797393799, 38.29511117935181, 38.16742065974644, 39.76677090781075, 41.69354806627546, 40.65904120036534, 46.19698476791382, 45.23914432525635, 47.8458583014352, 46.605194909232004, 49.06370380946568, 49.14290632520403, 57.14367362431118, 44.28172772271292, 30.878242697034562, 52.91307531084333, 53.6384915624346, 54.087894099099294, 50.19496086665562, 51.58719226292202, 52.18815585545131, 47.998062065669465, 45.308018343789236, 42.39650426592146, 40.171326296670095, 40.497492109026226, 38.96746751240322, 38.537693636757986, 35.98739555903843, 37.66497210093907, 37.58153813225882, 37.946655545915874, 38.89719690595354, 38.321434429713655, 38.5020980153765, 36.42595543180193, 34.40433188847133, 36.04020186832973, 35.322633607046946, 36.2825585092817, 36.73332984106881, 36.1562055179051, 37.57670218603951, 39.11280298233032, 39.6765068599156, 42.35616649900164, 40.41195631027222, 43.34017733165196, 42.62142787660871, 46.14028051921299, 43.51620299475533, 42.63846138545445, 40.555485248565674, 39.54924018042428, 36.96589994430542, 39.45643309184483, 39.31259495871407, 40.045331137520925, 40.91443613597325, 41.89556694030762, 39.15434973580496, 43.77390125819615, 44.362834044865195, 50.206439290727886, 52.91949544634138, 55.98995998927525, 54.47311612537929, 55.16386434010097, 45.004837172372, 58.6915933064052, 15.784630945750646, 0.5952406110508102, 2.919897730861391, 27.606520107814244, 56.050499643598286, 49.83307089124407, 57.72671433857509, 53.22446925299508, 53.8748380116054, 15.275129965373448, 25.062897511890956, 25.422904525484356, 35.267280782972065, 23.988042456763132, 0.3352650212390082, 0.14699072896369866, 0.06469598665301289, 0.07981256621756724, 0.07351845502853394, 0.06943836289324931, 0.04666107886337808, 0.059831548748271804, 0.02139080798120371, 0.012391741537222905, 0.04870933181207095, 0.07923735172620841, 0.021945632495252148, 0.015212480311415024, 0.036957352954362116, 0.06927425241363899, 0.022644518475447382, 0.03301797201856971, 0.045887626973646026, 0.028845588942723613, 0.03476188504802329, 0.0328210781195334, 0.023113043513149023, 0.022001501372350112, 0.04400799676243748, 0.0338460256212524, 0.02669039717875421, 0.05773079754518611, 0.013893199585644262, 0.0804280721183334, 0.01855591411835381, 0.02420588013982134, 0.07345114435468401, 0.07498225183891398, 0.09294764032321316, 0.05149029062262603, 0.12769767136446067, 0.02289726259186864, 7.559784242085048, 68.38874244689941, 37.088556494031636, 35.263000692640034, 31.42961699622018, 52.12656702314104, 71.35428919110979, 62.35297434670584, 60.88644586290632, 61.04779693058559, 60.4262249810355, 20.224112953458512, 0.43561532933797154, 8.072851385389056, 47.522044454302105, 68.96208695002964, 68.46219185420445, 64.55699157714844, 60.319104603358674, 58.19409186499459, 59.104080063956125, 57.77248559679304, 56.94628919873919, 59.5619455065046, 59.895973205566406, 47.09777355194092, 45.06814568383353, 48.53825323922293, 45.88691793169294, 46.822114195142476, 47.88766213825771, 45.49024180003575, 45.02233273642403, 46.14962237221854, 43.46187850407192, 41.99817098890032, 42.31529024669102, 41.013496603284565, 42.93550034931728, 41.149309567042756, 40.89446701322283, 41.15469789505005, 40.83166919435774, 40.38282946177891, 40.92643567493984, 40.01372030803135, 41.23900386265346, 42.42519685200283, 42.892935684749055, 41.58731010981968, 42.59621981212071, 41.863476685115266, 40.22204119818551, 39.342336722782676, 40.74507032121931, 41.05197920118059, 42.2415212222508, 44.09577655792236, 44.12617492675781, 43.739094257354736, 48.27175855636597, 48.66464444569179, 52.61377470833914, 51.43576669692993, 53.062225341796875, 54.95265647343227, 60.910750661577495, 53.92830787386213, 36.41275385447911, 57.53116076333182, 56.65342957632882, 56.64363956451416, 53.32989427021572, 53.47568484715053, 54.881288051605225, 53.1011699948992, 47.637047563280376, 44.70341042109898, 42.502009187425884, 42.43532385144915, 41.834818840026855, 41.12477200371878, 39.825959137507844, 40.97793224879673, 39.27203137534005, 41.05740227018084, 41.00635385513306, 40.21270629337856, 39.994626658303396, 39.85895265851702, 36.428137166159495, 38.34298079354422, 38.52201155253819, 39.18000248500279, 39.54372331074306, 39.83296292168753, 38.87771763120379, 40.20578588758196, 42.270137378147666, 44.7192314692906, 41.762425558907644, 46.61485290527344, 44.19725499834333, 48.69255883353097, 45.547633920397075, 44.387100628444124, 42.42253916604178, 40.69447006498064, 38.03399787630354, 41.53744636263166, 40.80687802178519, 40.90650476728167, 42.754360812050955, 42.42490502766201, 41.69819293703352, 45.33260107040405, 46.433897495269775, 51.23110055923462, 56.811066831861226, 58.50787598746163, 57.29982049124581, 58.01072890417916, 50.61389902659825, 62.73888424464634, 18.030568395342144, 0.9921065696648189, 3.17419485109193, 31.74452325275966, 63.940853118896484, 54.66832576479231, 64.49677153996059, 57.40117038999285, 64.28965268816266, 18.073532581329346, 30.42361511502947, 28.421210289001465, 41.328309059143066, 28.811600037983485, 0.377436026930809, 0.07294959841029984, 0.09581001994333097, 0.03408019144886306, 0.06800291527594839, 0.011095890625646072, 0.06350705759333712, 0.024551944873694862, 0.03976223351699965, 0.017759324184485843, 0.030793805473617146, 0.013910687977581151, 0.029256604744919708, 0.017884228910718645, 0.03025022428482771, 0.019974912350465144, 0.06150510787431683, 0.1350256595760584, 0.07717806579811232, 0.11691368717168059, 0.14096649150763238, 0.0734438229618328, 0.15024609571056707, 0.14819957981152193, 0.14735489870820725, 0.09517848704542432, 0.09328274162752287, 0.0864268441551498, 0.26650985489998547, 0.13397269536341938, 0.13832194198455128, 0.1321341097354889, 0.21419681342584745, 0.133104482665658, 0.1609322487243584, 0.2235070059874228, 0.2399264813533851, 0.15122923866978713, 13.65637947831835, 83.85413319723946, 43.920536041259766, 49.451069355010986, 35.390013762882774, 57.968886852264404, 77.41844068254743, 67.35036196027482, 66.65561853136334, 66.3836451939174, 65.00524071284703, 22.828162295477732, 0.598888849573476, 10.712913240705218, 52.67702416011265, 73.95661190577916, 71.12261540549142, 69.05178819383893, 64.87160600934709, 63.716474941798616, 61.90305069514683, 61.75224004473005, 61.050242696489605, 63.650703293936594, 63.51109313964844, 51.550137519836426, 48.60370526994978, 53.14103181021554, 48.375071321214946, 51.25779553822109, 53.08342776979719, 51.14488731111799, 49.537515367780415, 50.48426995958601, 46.903338636670796, 45.81978096280779, 46.66044351032802, 45.32947090693882, 46.732426847730366, 45.618738310677664, 43.514320032937185, 45.856384072984966, 44.92495720727103, 42.43436847414289, 44.65118776048933, 43.82289300646101, 44.2937342098781, 46.12280927385603, 47.84483691624233, 45.521633761269705, 45.9997010912214, 43.51923935753958, 44.106813771384104, 41.918134689331055, 45.72535146985735, 44.4705936568124, 44.794501304626465, 45.920672280447825, 48.054564816611155, 46.05647134780884, 53.5447290965489, 51.92088644845145, 55.1998872756958, 53.52161243983677, 55.52485452379499, 56.35130105699812, 64.1904046194894, 44.06916495731899, 34.14232226780483, 59.99725014822823, 59.77379608154297, 60.10926900591169, 54.01268332345145, 55.37956769125802, 56.84429311752319, 53.09324904850551, 48.14347049168178, 45.823922089168, 44.33189371653965, 44.208181040627615, 43.876279490334646, 44.0080486025129, 39.94662502833775, 42.74066243852888, 41.55331604821341, 42.157604353768484, 42.96694094794137, 42.79888834272112, 41.755685806274414, 41.08961064474923, 38.48153134754726, 41.29235907963344, 42.06506477083479, 41.26197460719517, 42.32725504466465, 40.84908138002668, 42.770800249917166, 43.78225646700178, 45.09324605124337, 49.66312837600708, 44.92164291654314, 48.91052034923008, 47.4586421421596, 51.169466563633506, 47.79376070840018, 47.130708013262065, 45.2616981778826, 42.2893248285566, 39.9585724558149, 43.52589225769043, 41.926298822675435, 43.61223752158028, 45.23046255111694, 44.909879616328645, 42.49149308885847, 47.33649628502982, 46.739104066576274, 53.78352131162371, 58.500865255083355, 62.037880488804404, 59.07333428519112, 60.05604580470494, 53.59622567040579, 64.17857183728898, 20.823424611772808, 1.3080797003848212, 7.495696663856506, 32.93295356205532, 66.99066761561802, 57.65755891799927, 67.96724387577602, 62.25462259565081, 66.21772915976388, 22.39240254674639, 41.31233515058245, 37.85142701012747, 49.1533077784947, 46.17551136016846, 0.3995985819825104, 0.2263108076793807, 0.14527012700481073, 0.20114812361342566, 0.13006318014647278, 0.10794187323855502, 0.19216164653854712, 0.08541137578764132, 0.16401958305920872, 0.15461046009191445, 0.1361374527748142, 0.14725847888205731, 0.14198520327253, 0.05334843841514417, 0.13974063657224178, 0.12710170048688138, 0.12755403907171317], [0.022018544475681016, 0.06324215752205678, 0.04926617836047496, 0.0680697306192347, 0.05069151919867311, 0.05936228750007493, 0.027627810270392468, 0.02098427220646824, 0.03521011510331716, 0.03905854520520993, 0.06857666413166694, 0.014461910318849342, 0.031164529866405895, 0.06202590385718005, 0.05140614549496344, 0.009905843679527087, 0.08207331597805023, 0.11060414609632321, 0.10759629535355739, 0.10647725540080241, 0.15545035073799746, 0.08995224748338972, 25.315862315041677, 53.350342818668906, 35.19524185998099, 33.50291429247175, 25.72754829270499, 65.02518899100167, 58.32880006517683, 68.00306183951241, 60.891045570373535, 60.84114360809326, 41.61076028006417, 2.3089081048965454, 0.4735759166734559, 24.614467723029, 61.77059718540737, 66.61883476802281, 65.84789739336286, 62.731435775756836, 58.15375757217407, 61.509546416146414, 59.2651948928833, 61.06850951058524, 61.12312235151018, 60.37255014692034, 52.65949732916695, 43.42478901999337, 43.725826672145296, 42.521571840558735, 43.754151003701345, 43.6641857283456, 43.80370208195278, 43.907244137355256, 43.771573611668174, 41.788349287850515, 40.273405756269185, 40.981243065425325, 39.91373225620815, 38.51848881585257, 39.452038356236045, 38.94255822045462, 41.48464352743966, 41.198898860386436, 39.39958987917219, 37.081153188432964, 40.53852816990444, 39.07996579578945, 40.346851689474924, 38.09233495167324, 38.882209641592844, 36.92176151275635, 36.74774040494646, 38.21320928846087, 36.95026649747576, 38.12572104590279, 40.740109307425364, 38.670821121760774, 38.343738147190635, 38.9956841468811, 47.960135323660715, 50.89080558504377, 49.18602337156023, 46.47877243586949, 46.35550791876656, 49.059618268694194, 51.45124380929129, 53.61995029449463, 57.16480657032558, 38.885141781398225, 44.003257819584434, 55.23501736777169, 53.01521383013044, 49.39642524719238, 50.831690311431885, 48.887685094560894, 47.00395550046648, 46.36590937205723, 42.444040366581504, 40.38404539653233, 40.69400453567505, 38.95647546223232, 38.858019488198416, 37.62784440176827, 38.3772736276899, 38.13034854616438, 38.82332713263375, 39.00067295346941, 38.12286533628191, 38.59870229448591, 38.272154331207275, 34.122620650700156, 35.53731904711042, 35.293440750667024, 34.87455817631313, 37.42975473403931, 37.2024861063276, 35.9658214024135, 37.07413898195539, 40.92900650841849, 42.49614143371582, 43.018837043217246, 45.52759878976004, 45.54478515897478, 46.60265186854771, 48.06645665849958, 46.40923833847046, 43.76480606624058, 41.118060043879915, 41.573035035814556, 40.394134180886404, 37.95798110961914, 42.9429349218096, 40.514188630240305, 41.31003182274954, 41.0242280960083, 42.87989739009312, 41.12757560185024, 48.079474108559744, 47.58336578096662, 56.20468364443098, 51.70873710087368, 60.431561197553364, 51.217975412096294, 58.45520864214216, 20.518966708864482, 0.5661056744200843, 1.052478164434433, 33.60316290174212, 46.58686556134905, 52.97218016215733, 55.095591340746196, 61.113158634730745, 24.94764600481306, 13.396034819739205, 38.4080993107387, 23.08153009414673, 45.242271014622276, 8.90061981337411, 0.22027886206550257, 0.07617387468261377, 0.007198683185768979, 0.05819866779659476, 0.022299876968775476, 0.041248367700193606, 0.057359272481075356, 0.12843859089272364, 0.023580213177150915, 0.04286407832322376, 0.05099827470257878, 0.06105227395892143, 0.02444687711873225, 0.04882781420435224, 0.014784921825464283, 0.04090127328942929, 0.012764364979895098, 0.042260484104709964, 0.06234315290514912, 0.05865632609597274, 0.04789174121937581, 0.02505906328691968, 0.03989527387810605, 0.08339930232614279, 0.11934014196906771, 0.020397366556738104, 0.02449556370265782, 0.01831354310603014, 0.008776353439316154, 0.03652135349277939, 0.03836344036140612, 0.03325023116277797, 0.06741564321730818, 0.06627028289117984, 0.08525097689458302, 0.06913109509540455, 0.02748916860270713, 0.07315809865083013, 0.23257919560585702, 31.473293372562953, 60.042496817452566, 34.69430800846645, 43.67316280092512, 31.09524883542742, 72.28600093296596, 65.35246998923165, 70.85014874594552, 68.41151169368199, 67.58498873029436, 45.98473467145647, 2.593762751136507, 0.35512840109212057, 25.57532368387495, 63.5782196862357, 71.96457031794957, 68.07303019932338, 65.73826871599469, 60.66369356427874, 64.74521132877895, 62.30159936632429, 64.142899785723, 64.48159667423793, 64.27603421892438, 55.9177508354187, 46.31921747752598, 44.2482339314052, 46.668711866651265, 47.111669949122835, 46.256544726235525, 48.19664852959769, 48.12413018090384, 45.64155966894967, 44.41784988130842, 42.9262627192906, 43.669438566480366, 42.242302894592285, 40.797956534794395, 43.16386331830706, 41.72734063012259, 43.176147733415874, 41.77918461390904, 41.08126933234078, 40.23045894077846, 43.30094085420881, 41.7102689061846, 41.72509636197771, 41.26289871760777, 42.36232607705252, 39.772652557918, 39.72867740903582, 40.23158802304949, 40.29966647284371, 39.52195807865688, 43.062614168439595, 41.25878190994263, 42.61541421072823, 42.352741037096294, 50.29172148023333, 52.33324466432844, 51.638855593545095, 50.08500214985439, 52.29532139641898, 52.1740961756025, 55.09118965693882, 55.17289005007063, 66.84394945417131, 45.143356459481375, 47.734624590192524, 56.755575043814524, 55.86311020169939, 53.673076220921104, 52.93956879207066, 53.217625277382986, 51.75938946860177, 48.65567084721157, 45.43325614929199, 43.183832441057476, 43.36557994570051, 40.867775508335654, 42.11025585447039, 40.390326568058555, 40.64900452750069, 40.280795165470664, 41.04916865485055, 40.479183605739046, 40.36288118362427, 39.663419927869526, 39.0295079776219, 36.13021925517491, 38.369790417807444, 37.2243903023856, 38.390430041721885, 38.43562112535749, 40.16749783924648, 37.872035367148264, 40.811748708997456, 41.98969766071865, 44.37180764334542, 45.93610422951834, 47.34638009752546, 46.43578045708792, 49.905544076647075, 48.29414912632534, 48.43977294649397, 46.722716740199495, 42.717076778411865, 41.42589998245239, 41.48196847098214, 41.108384677342, 44.28552838734218, 43.2749719619751, 43.353226048605784, 41.5007563999721, 45.69275747026716, 42.72223581586565, 50.33340719767979, 49.4143967628479, 60.721599851335796, 56.125821590423584, 61.9747838973999, 56.63183110100882, 64.18811866215297, 22.961055278778076, 0.5026374629565648, 2.902297075305666, 37.27394485473633, 53.85737371444702, 57.76172283717564, 59.469826289585654, 64.99236570085797, 32.06098590578352, 16.33249987874712, 47.312594481876914, 25.401292153767177, 54.33559043066842, 8.447769233158656, 0.3224960778440748, 0.04253508383408189, 0.035587546814765246, 0.05225537956825324, 0.03997305773996881, 0.058679518422910144, 0.024158029850306253, 0.030291143339127302, 0.055141114363712926, 0.09056516138038465, 0.04826334770768881, 0.0316890476138464, 0.019216523938147084, 0.03195587472457971, 0.11009545517819268, 0.03282382618635893, 0.004394298377779445, 0.2561314175171511, 0.10006881106112685, 0.14677357061633042, 0.22078766833458627, 0.06670285575091839, 0.09940469491162471, 0.1104260849367295, 0.14369539650423185, 0.09314006606915168, 0.09845251350530557, 0.18298367331070559, 0.07289547845721245, 0.087202083984656, 0.2244623697229794, 0.17868264338799886, 0.21487156221909182, 0.2968572521848338, 0.3478350724492754, 0.1612306141427585, 0.3264744100826127, 0.31983627485377447, 0.2543736318392413, 47.42315074375698, 68.41259561266217, 53.80303880146572, 50.37651382173811, 38.063364437648225, 76.80514403751918, 70.40495681762695, 75.47650950295585, 71.51624475206647, 72.08865819658551, 49.38845566340855, 3.0517691118376593, 0.9597038626670837, 30.039393629346574, 65.54300349099296, 73.68668828691754, 72.13438429151262, 68.93833800724575, 64.3274369921003, 67.80703926086426, 65.01612854003906, 67.35539245605469, 67.13894217354911, 67.75453172411237, 61.137470381600515, 48.4813996042524, 47.95421893256051, 49.93232243401663, 50.14236995152065, 49.69317933491298, 49.43303877966744, 51.79394286019461, 50.046804428100586, 49.09808349609375, 46.806247983660015, 46.68443216596331, 45.83679015295846, 43.126558440072195, 45.872917311532156, 43.56433316639492, 47.039106437138145, 46.24376351492745, 44.052680356161936, 44.43886818204607, 46.0110752923148, 45.26134034565517, 44.123399121420725, 44.12935025351388, 45.055864742824006, 42.32350301742554, 40.126270702907014, 43.238163879939485, 42.19083063943045, 43.64968831198556, 45.591206073760986, 44.57315949031285, 44.90732267924717, 45.53574555260794, 53.254919733319966, 56.487840107509065, 54.12091541290283, 53.2774110521589, 52.0073150907244, 54.162799154009136, 57.092691217150005, 57.179474217551096, 58.665072032383506, 39.408271653311594, 49.66068261010306, 59.387017658778596, 58.38259996686663, 54.763137408665244, 56.00984920774187, 53.81600761413574, 53.68533631733486, 50.60390056882586, 47.11186449868338, 44.43450123923165, 46.12581784384591, 42.46019492830549, 43.84530789511544, 40.528199672698975, 43.70898076466152, 41.65016351427351, 42.29554346629551, 43.728863034929546, 42.23748084477016, 42.39783484595162, 42.03099775314331, 37.10393633161272, 41.3491119657244, 39.39549044200352, 40.56019612721035, 41.77850021634783, 43.21861859730312, 40.569093295506065, 43.75888967514038, 46.05543259211949, 48.202384267534526, 48.21686083929879, 50.1003611428397, 49.17045593261719, 50.882016113826204, 50.93063613346645, 52.07332992553711, 48.18532991409302, 45.24199308667864, 45.04415702819824, 43.4197724206107, 42.982598713466096, 46.52130235944475, 43.777507373264854, 43.317682538713726, 44.72555433000837, 47.380269936152864, 44.15010799680437, 52.21477787835257, 52.07227727345058, 62.97099576677595, 59.11791392735073, 64.56183447156633, 59.07407079424177, 64.89608451298305, 26.055063792637416, 0.7772980162075588, 3.28859172974314, 41.58849825177874, 56.70846625736782, 61.77267469678606, 65.95214121682304, 70.50148814065116, 35.05824770246233, 21.764636278152466, 54.96379096167428, 33.41253907339913, 65.92951093401227, 18.184762818472727, 0.3542747768972601, 0.1638396762843643, 0.08042744786611625, 0.12163576164415904, 0.25189668046576635, 0.08418303062873227, 0.09193170376654182, 0.16974006752882684, 0.14105181050087723, 0.12052242138556071, 0.13623650531683648, 0.1179636794009379, 0.18582806496747903, 0.13507732323237828, 0.12885088234075479, 0.1314709096082619, 0.19696612230369023], [0.01964119016858084, 0.11119983877454485, 0.076588642783463, 0.046021834414984496, 0.03094637407256024, 0.018705710901745727, 0.03752426217709269, 0.04634554650900619, 0.040307076780923774, 0.042593705867018015, 0.031246133880423646, 0.04499990639409848, 0.05229845636391214, 0.028207716831405247, 0.06092956768614905, 0.01794561936653086, 0.03710507002792188, 0.017316542765391723, 0.10003507429999964, 0.09908147475549153, 0.07360940586243357, 0.07871973807258265, 4.261363199778965, 63.83121749332973, 31.558269841330393, 45.52301645278931, 38.63173055648804, 31.843639305659703, 71.0798978805542, 58.52450997488839, 65.805819102696, 58.43881089346749, 59.315534591674805, 12.885797330311366, 0.2822975463100842, 3.5477046029908315, 34.68650170734951, 65.24550942012242, 67.82070636749268, 65.29236112322126, 61.989680835178916, 63.84337684086391, 64.68408107757568, 65.04683262961251, 62.56301839011056, 61.53795065198626, 55.739956855773926, 46.42659493855068, 41.63177163260323, 42.70423303331648, 41.93235765184675, 42.9498553276062, 43.44369159426008, 43.52555527005877, 40.366386549813406, 41.2145288331168, 39.35151181902204, 39.18186807632446, 40.47808231626238, 41.71270077569144, 41.48621729442051, 40.716374261038645, 39.3343289239066, 41.05290331159319, 38.95423814228603, 39.07213517597744, 37.32001835959298, 38.83836998258318, 38.80237136568342, 38.3223237991333, 39.83651345116751, 38.225014277866904, 37.86045619419643, 35.699073110307964, 37.45951039450509, 37.76183693749564, 38.10115221568516, 39.11688157490322, 40.38941982814244, 45.15424428667341, 53.52007688794817, 51.2661646434239, 54.0309397152492, 53.06047786985125, 48.686357566288535, 48.295132296425955, 51.00763954435076, 52.91883536747524, 55.73517302104405, 53.43494061061314, 45.14474262510027, 53.39708335059029, 51.538784163338796, 48.546848160879954, 46.396613461630686, 47.863037722451345, 45.31071424484253, 43.75658982140677, 40.89572811126709, 41.39869431086949, 40.02812739780971, 41.33456938607352, 39.31979676655361, 38.76746709006173, 36.353027139391216, 38.37364319392613, 38.14829921722412, 38.701007570539204, 39.84723104749407, 39.166561194828574, 37.43606717245919, 35.816323961530415, 35.65798493794033, 38.71882275172642, 35.383260113852366, 36.31191464832851, 38.00637183870588, 35.9518381527492, 37.27394832883562, 36.93843718937465, 40.60197911943708, 42.22698559079851, 45.02878066471645, 45.886122362954275, 44.55518102645874, 47.45128747395107, 48.37958070210048, 45.31146812438965, 44.75314562661307, 42.03206082752773, 37.811467920030864, 41.255495412009104, 41.229846136910574, 42.64498921803066, 47.586513314928325, 47.06820201873779, 49.91250964573452, 43.750437191554475, 46.15593481063843, 45.96634973798479, 53.460878235953196, 54.60795981543404, 57.99977159500122, 54.06785896846226, 63.74367713928223, 18.619994504111155, 0.345915822578328, 0.8244127194796289, 29.352296692984446, 56.44782543182373, 52.593882015773225, 58.251619475228445, 55.868300506046836, 16.109990767070226, 18.196546963282994, 22.269645248140606, 30.819794450487407, 43.987593105861116, 0.3502197430602142, 0.0117071997873219, 0.1752441128981965, 0.04975540889427066, 0.04373746485050235, 0.0722354810152735, 0.08214015846273728, 0.07642905813242708, 0.03900425222569278, 0.0016753160016378388, 0.040599891782871315, 0.038819168228656054, 0.07170060543077332, 0.010588859573804905, 0.03340411951233234, 0.03931201874677624, 0.010754413636667388, 0.03360397521672504, 0.020982367219403386, 0.04363259047802005, 0.04155045488317098, 0.03761485338743244, 0.027241243781255822, 0.11935053712555341, 0.017287333529176455, 0.08502965234220028, 0.026182495057582855, 0.006666625642018127, 0.03757686221173831, 0.04865317625392761, 0.013143912872432597, 0.016073936496728232, 0.04567438377333539, 0.03539439503635679, 0.02682039770297706, 0.03110651172963636, 0.06311852844165904, 0.013019143853203526, 0.022023214492946863, 0.10468122070389134, 5.282942942210606, 74.11379405430385, 34.66855451038906, 49.98490640095302, 48.189151423318044, 41.3463465826852, 80.77821431841168, 63.32083061763218, 72.53863048553467, 62.02550574711391, 67.04612813677106, 14.938875368663243, 0.2107654618365424, 3.9688957163265774, 37.87353965214321, 67.56238624027797, 69.03532791137695, 66.33358342306954, 65.24004118783134, 65.70793982914516, 67.55867590223039, 67.08170291355678, 62.93715803963797, 65.37525313241142, 57.54465763909476, 49.98010866982596, 46.59008257729666, 46.13224145344326, 45.62251813071114, 46.815739222935264, 47.25209651674543, 46.45593023300171, 43.72938067572457, 44.690663950783865, 43.37398379189627, 41.95454324994768, 42.16115140914917, 44.3249385697501, 43.94531331743513, 42.69830969401768, 42.86602531160627, 42.429216384887695, 40.384778431483674, 40.779057434626985, 40.950483390263145, 43.01402194159371, 41.78569507598877, 41.154034342084614, 42.514050415584016, 40.593266078404014, 40.477734906332834, 40.00036934443882, 41.013632093157085, 41.509681361062185, 40.82705906459263, 42.70662668773106, 44.01305825369698, 48.124581813812256, 55.089664527348106, 55.014735153743196, 55.85683250427246, 55.43397208622524, 54.70985862186977, 51.510734285627095, 55.902944224221365, 56.10765552520752, 62.66106442042759, 63.0195289339338, 49.639455863407676, 55.649539947509766, 54.14520631517683, 53.58097090039934, 49.6823262487139, 51.69978434698922, 47.68057107925415, 47.89657667704991, 43.28422348839896, 44.12240205492292, 42.86562926428658, 42.00269774028233, 42.44777154922485, 39.95151308604649, 40.06434488296509, 39.18365028926304, 40.68921375274658, 40.15929201671055, 41.82321882247925, 40.22685629980904, 38.36577435902187, 38.33952406474522, 37.44831337247576, 38.89582463673183, 39.83966098512922, 39.83980342320034, 40.504624434879844, 38.333225522722515, 40.21842466081892, 40.24335479736328, 44.70172895703997, 44.572294439588276, 47.51199041094099, 46.91455997739519, 47.89593396868025, 49.49569763456072, 51.30720765250069, 47.42661789485386, 46.65695898873465, 43.266550745282856, 38.96162060328892, 42.91648660387312, 41.737214020320344, 42.48383617401123, 50.01503726414272, 48.87743650163923, 50.83449738366263, 46.38325902393886, 47.06100368499756, 48.119711126599995, 56.751392228262766, 57.40357446670532, 62.09762110028948, 57.34534856251308, 67.48722757611955, 20.052139827183314, 0.3755786323121616, 1.5961288894925798, 34.245398793901714, 59.31057357788086, 58.58821105957031, 64.64360087258476, 60.599582535879954, 20.237993717193604, 20.524207387651714, 28.055488382066997, 34.43121446881975, 49.934983594076975, 0.40168119594454765, 0.02537003588596625, 0.053944894445261786, 0.065010507990207, 0.02320597566930311, 0.06697728923921074, 0.08385742202933345, 0.05111526431781905, 0.1207345857151917, 0.04153299278446606, 0.06624500067638499, 0.02679607561523361, 0.011580641131981142, 0.017819802010697976, 0.0461745522916317, 0.01477100676856935, 0.02862473257950374, 0.021682800259441137, 0.05447792780718633, 0.13129713678998606, 0.18600045357431683, 0.13865597120353154, 0.10803042205848865, 0.25688700697251726, 0.16756285221448966, 0.17163940918232712, 0.1858635252075536, 0.1592883483639785, 0.10870489943772554, 0.1184589828231505, 0.10169844183006457, 0.12018514876919133, 0.11013240140995809, 0.1748711357691458, 0.2443355204803603, 0.0918238302692771, 0.1371395540024553, 0.1165003100676196, 0.18238935805857182, 0.24682294843452318, 9.459148151533944, 87.96584088461739, 42.33063186917986, 63.07611506325858, 52.609532833099365, 42.462505204336985, 80.03028242928642, 69.9406851359776, 75.24646854400635, 66.97492994580949, 71.57644394465855, 17.15773916244507, 0.26998892107180184, 6.032971450260707, 40.57920639855521, 70.93235288347516, 72.14381299700055, 70.56015178135463, 68.35020078931535, 70.18344824654716, 70.65273652757917, 69.34968526022774, 66.66605472564697, 69.01193332672119, 60.57030282701765, 53.66276856831142, 48.87986837114607, 49.34209380831037, 48.02786636352539, 50.22317055293492, 49.98746681213379, 51.97921657562256, 46.06215844835554, 47.36230189459664, 44.650927203042166, 45.32968282699585, 45.43707071031843, 48.19899354662214, 47.30362435749599, 46.913997173309326, 45.22829818725586, 47.17254311697823, 42.778422423771445, 43.62327126094273, 43.44591849190848, 46.363779749189106, 44.770860058920725, 42.72468158176967, 46.332863739558626, 44.048004218510215, 44.175149304526194, 41.07199001312256, 43.83455555779593, 44.97688109534127, 43.427401542663574, 45.41914088385445, 46.067195892333984, 53.02917276109968, 59.10073103223528, 56.403579303196494, 59.13329029083252, 57.685674803597585, 55.898115226200645, 53.65923888342721, 58.125391551426475, 59.206288065229145, 60.729263714381624, 54.99407121113369, 48.88491971152169, 57.56585659299578, 56.82946913582938, 53.71203824451992, 51.63222006389073, 52.97976064682007, 48.813255991254536, 46.84008571079799, 43.954543999263215, 45.1886100769043, 44.52305255617414, 44.77199608939034, 45.41133458273751, 42.30052532468523, 41.77607529503958, 42.504958697727744, 43.05090297971453, 41.98168638774327, 44.021875517708914, 42.89862625939505, 40.98260838644845, 39.91449308395386, 41.01251343318394, 42.00953129359654, 42.39118889399937, 41.05362939834595, 44.06144550868443, 40.723277296338765, 42.02850682394845, 42.292177064078196, 47.61978128978184, 46.88637113571167, 48.97463137762887, 48.74209254128592, 49.57115854535784, 52.525393622262136, 53.60228797367641, 50.00748457227434, 48.387008326394216, 44.39621319089617, 40.85577596936907, 45.045498030526296, 43.85107142584664, 44.460748059409006, 52.321158272879465, 50.36887080328805, 52.46800150190081, 46.656149523598806, 49.08780363627842, 50.47549785886492, 57.99847575596401, 59.89579255240304, 63.478443554469514, 58.550301688058035, 69.11610071999687, 22.21152182987758, 0.5273854807019234, 2.5477400549820493, 35.37557888031006, 68.1636277607509, 59.7681610924857, 67.74133014678955, 62.278691155569895, 24.13620236941746, 29.175749914986746, 34.55957896368844, 40.78785037994385, 62.87943935394287, 2.7444874175957272, 0.25001928263476914, 0.2814485361533505, 0.07937665496553693, 0.14096615224012307, 0.11967664105551583, 0.10843348543026618, 0.14185496526105063, 0.2251228964222329, 0.11800217947789601, 0.187748644767063, 0.095096316454666, 0.16493593103119306, 0.09885641147515603, 0.12741940415331296, 0.09947910306176969, 0.1278053955840213, 0.08359636246625866], [0.028844493108668497, 0.014197601421203996, 0.030016560573130846, 0.020046755638239638, 0.030524087803704397, 0.05770729987749031, 0.012812109248313521, 0.1313563050436122, 0.027779649444190518, 0.029637096649301902, 0.054124034475535154, 0.09705375427646296, 0.040185259389025826, 0.03240210310156856, 0.030154119977461438, 0.05625716197703566, 0.022156645011688982, 0.12698366253503732, 0.04258556344679423, 0.06693767636482205, 0.04726975191650646, 0.11247859229998929, 0.12978894343333586, 27.889700889587402, 56.3749075617109, 33.596447467803955, 54.94639614650181, 14.578652960913521, 45.927259172712056, 68.24137115478516, 64.38145228794643, 61.665248598371235, 58.706782068525044, 31.157292774745397, 0.5255916512438229, 0.06797245583896126, 10.31542330128806, 45.58457054410662, 69.57481384277344, 68.91122613634381, 65.37649685995919, 66.0195734841483, 65.7010750089373, 66.50444657461983, 65.39938422611782, 60.96547467367989, 56.522612367357524, 48.81924186434065, 43.75790997913906, 43.67826625279018, 43.759629658290315, 41.011558055877686, 44.432903153555735, 44.30908972876412, 43.799797194344656, 42.52589014598301, 41.39003338132586, 41.8411660194397, 43.61687544413975, 40.86803606578282, 40.53592954363142, 39.79555034637451, 39.41001912525722, 40.47880145481655, 39.67554800851004, 38.651400906699045, 40.14221681867327, 39.366089139665874, 40.002686568668906, 39.44636515208653, 39.3784430367606, 38.22666447503226, 38.890863622937886, 37.01753895623343, 39.6072541645595, 39.71230050495693, 39.86107880728585, 40.20309346062796, 41.567452158246724, 49.69192865916661, 52.8584555217198, 53.696317945207866, 53.65792914799282, 53.75413737978254, 52.924814292362754, 50.102928502219065, 52.52526160648891, 52.87508603504726, 54.5405900818961, 54.57153735842024, 52.757970673697336, 50.901106289454866, 51.18605191367013, 47.16209997449602, 47.65073551450457, 44.94820587975638, 43.48768411363874, 44.51747662680489, 41.69894681658064, 41.22483648572649, 41.326179436274934, 40.39363738468715, 40.829626423971995, 39.41821799959455, 38.3260098184858, 37.40997321265084, 37.443018845149446, 39.48008475984846, 38.9712438583374, 39.44025073732649, 37.674282687050955, 37.335801192692344, 37.42432819093977, 36.54308121544974, 37.637787273951936, 36.84069340569632, 38.14737163271223, 36.50258363996233, 36.131365707942415, 36.433761732918875, 39.231519903455464, 40.68398175920759, 42.28712224960327, 43.05504410607474, 44.79742302213396, 47.343844005039756, 51.14775344303676, 48.80446999413626, 45.92432355880737, 41.45690631866455, 39.88004044124058, 39.06283848626273, 43.308590820857454, 52.21540321622576, 56.62061323438372, 54.519286905016216, 55.41631323950631, 52.82566349846976, 49.00588090079171, 45.364965779440745, 51.82946899959019, 51.23283066068377, 59.90211541312081, 54.69360678536551, 68.39569064549038, 12.63913106918335, 0.6971563537205968, 3.3880297882216315, 32.92616169793265, 56.542713505881174, 51.525217805589946, 59.09091322762625, 42.131896018981934, 10.675676107406616, 35.54508018493652, 35.60060323987688, 39.80733101708548, 29.38780198778425, 0.0668146036831396, 0.08925759047269821, 0.027432846803484217, 0.03257759939879179, 0.02872281820912446, 0.13315104373863765, 0.07344347690897328, 0.004886306240223348, 0.025727128510230353, 0.04240692213975957, 0.034116588067263365, 0.04236033731805427, 0.07502604448901755, 0.0367959091173751, 0.01000276901426592, 0.028936807797955613, 0.02551275215643857, 0.0462680781659271, 0.026695141834872108, 0.019911024885784303, 0.035797034323747666, 0.006847465826597596, 0.03825909185356327, 0.006066139113889741, 0.03950816625729203, 0.01139197701455227, 0.029405142845852033, 0.0188562591626708, 0.03983050092522587, 0.05317698957930718, 0.06965263068143811, 0.008722912021247404, 0.053061519882508686, 0.01725942877653454, 0.04506996174209884, 0.061453423861946375, 0.04178392181971243, 0.008484499412588775, 0.13906929402479104, 0.15288132216249192, 0.08096818599317755, 33.05450882230486, 61.562095642089844, 34.4885162625994, 65.30759157453264, 20.03204389980861, 57.5720648084368, 72.06907122475761, 69.65912328447614, 66.16278280530656, 64.4229816709246, 35.73712491989136, 0.44629992172122, 0.05880165472626686, 10.350986787251063, 48.15960768290928, 72.55493095942906, 71.13843645368303, 67.32716887337821, 67.36209051949638, 68.64080224718366, 67.53886658804757, 67.03905487060547, 62.97469915662493, 60.821216174534385, 49.67647239140102, 45.63113389696394, 46.08994776862008, 45.57415172031948, 43.09819936752319, 46.76902648380825, 47.43275662830898, 45.6970340864999, 45.92638717378889, 44.28050136566162, 44.5118624823434, 44.99875749860491, 43.69601195199149, 42.31793056215559, 42.05185277121407, 42.65711382457188, 42.043382917131694, 41.74146631785801, 40.533070359911235, 42.25714424678257, 42.39123058319092, 41.87929425920759, 40.88723741258894, 41.18777479444231, 40.91422421591622, 40.42282676696777, 40.720508439200266, 40.729492459978374, 41.386927536555696, 42.7075959614345, 42.69590214320591, 44.34186438151768, 50.4469199180603, 54.34464740753174, 56.551304953438894, 56.325471128736226, 56.86237233025687, 57.12636913572039, 54.554684502737864, 54.04639250891549, 56.65088653564453, 58.39091696058001, 65.3105445589338, 59.897050176348, 52.05275283540998, 53.659204142434255, 51.44660588673183, 51.53919758115496, 47.5953687940325, 47.61889886856079, 47.104614053453716, 44.60887670516968, 43.838196413857595, 42.507480893816265, 42.83211810248238, 42.20922599520002, 41.021393230983186, 39.62010485785348, 39.61925022942679, 40.360536166599815, 40.35677719116211, 40.3100505556379, 41.191214152744834, 39.97845472608294, 38.42013706479754, 38.161146436418804, 38.774599415915354, 38.539725984845845, 38.3027264050075, 39.53771659306118, 39.03119986397879, 38.16515554700579, 39.51555183955601, 41.63730934688023, 43.08071422576904, 44.491076946258545, 44.42998143604824, 47.32748099735805, 48.94954490661621, 52.45651960372925, 49.18606506075178, 48.6899219921657, 43.95037508010864, 41.127648557935444, 41.16070808683123, 45.491971901484895, 53.619328430720735, 59.42771325792585, 57.254858698163716, 57.785086154937744, 53.89161443710327, 51.63821983337402, 46.18298414775303, 54.78393336704799, 54.95395231246948, 63.20013345990862, 55.916048526763916, 71.78535543169293, 13.960403987339564, 1.0387481983218874, 3.44344471182142, 37.921874795641216, 59.38395350319998, 54.590304442814414, 63.02116870880127, 54.46100888933454, 14.516794017383031, 41.79475205285208, 38.12700646264212, 45.804376806531636, 33.591430868421284, 0.09532437885978393, 0.04290210681834391, 0.015755727321707776, 0.013909247787004071, 0.12551704980432987, 0.021365052488233362, 0.06693051103502512, 0.018771447374352386, 0.05133870589945998, 0.013585335525151874, 0.035207631665148904, 0.020545965725822107, 0.060043638439050744, 0.017686590319499373, 0.014399050834721752, 0.03736847053681101, 0.0602516026369163, 0.07309951393732003, 0.12044029150690351, 0.13413741652454647, 0.09840398468077183, 0.1273261463003499, 0.09881799282240016, 0.13659830018877983, 0.14410637159432682, 0.17170150870723383, 0.17791805655828544, 0.07144861788089786, 0.11820945835539273, 0.31839845914925846, 0.16465807094105653, 0.07097737531044654, 0.1259159469710929, 0.15697165339120797, 0.12154542149177619, 0.205820855019348, 0.11043268708246094, 0.1566242841737611, 0.29093155158417566, 0.1950150898524693, 0.24136302141206606, 46.12608882359096, 72.69880730765206, 48.086873940059114, 67.03230122157505, 23.09138263974871, 57.84252691268921, 78.61166177477155, 74.16398784092495, 72.95566831316266, 72.54166684831891, 39.17882129124233, 0.6054260730743408, 0.41790247123156277, 13.527975899832589, 51.40119593484061, 77.71387808663505, 76.14803205217633, 70.53561769212995, 71.06894751957485, 70.29536288125175, 71.64963626861572, 70.43418094090053, 66.89041900634766, 64.79670442853654, 54.78572252818516, 49.48650516782488, 49.63262578419277, 49.60712589536394, 46.40218939099993, 49.97051320757185, 52.78001035962786, 49.71244668960571, 48.4912417275565, 47.200801440647666, 47.96388040270124, 47.70550468989781, 47.03822749001639, 45.74155119487217, 45.17597825186593, 44.97779130935669, 45.73808404377529, 43.62541478020804, 44.85071223122733, 46.09211213248116, 46.91512972967965, 45.93381479808262, 43.246612889426096, 43.64076335089547, 44.15085145405361, 42.10306446892874, 43.98793009349278, 43.83511141368321, 45.8983998298645, 45.63109915597098, 46.48974016734532, 46.52955681937081, 53.797556672777446, 57.263731547764365, 58.16539233071463, 57.63398368018014, 56.9817111151559, 57.873838969639365, 54.900840282440186, 56.23027385984148, 60.03852244785854, 61.032656805855886, 60.61686270577567, 58.18307549612862, 53.8616920198713, 56.58059508459908, 52.895565850394114, 51.521754128592356, 49.97352177756173, 48.9998950277056, 48.28384494781494, 45.993954930986675, 45.484811782836914, 44.41833972930908, 44.250224590301514, 44.613365241459434, 43.31797783715384, 41.861486026218955, 40.80517223903111, 42.182044642312185, 42.160196031842915, 41.76266874585833, 43.85951348713466, 42.40091984612601, 40.137606688908164, 42.819343839372905, 40.65496955599104, 41.317400387355256, 41.58102199009487, 43.19944851739066, 42.67728444508144, 40.84700386864798, 40.6711380141122, 44.62281826564244, 45.835674967084614, 46.91180501665388, 46.21132584980556, 49.72823994500296, 51.50467198235648, 55.242861883980886, 52.642898082733154, 51.75302144459316, 45.53291763578142, 42.99583503178188, 43.70343262808663, 47.72623116629464, 56.445984159197124, 60.328727858407156, 58.13284002031599, 58.86577769688198, 56.69703299658639, 52.696468693869456, 48.983281884874614, 56.43548890522548, 57.88358381816319, 66.31838076455253, 57.29260131290981, 72.72538416726249, 15.897353308541433, 0.7640041581221989, 7.178253012044089, 39.67480107716152, 68.20992360796247, 59.41244806562151, 69.4117465700422, 52.03516347067696, 18.27522141592843, 50.51911864961897, 48.377909660339355, 53.897867815835134, 45.12373127256121, 0.16673214893255914, 0.1304928692323821, 0.11085633720670428, 0.11933385873479502, 0.18261490309877054, 0.15095999597438745, 0.1599813633199249, 0.09199218159275395, 0.158497705789549, 0.10865390074572392, 0.1321164406836033, 0.06404797213950328, 0.19433160152818474, 0.11677344755402633, 0.09937399120203086, 0.10773838058646236, 0.09075738356581756, 0.14257402239101274], [0.061480700969696045, 0.04722029010632208, 0.045339682804686685, 0.09051226279033081, 0.012119900900870562, 0.05130730329879692, 0.0973208120891026, 0.04368601493271334, 0.03539395059591957, 0.04878598930580275, 0.015956500744713203, 0.07813444055084671, 0.018519086630216668, 0.03936083934136799, 0.07505343694772039, 0.018119059702647582, 0.00847475225704589, 0.1264518674995218, 0.023431239117469107, 0.04114451113023928, 0.003559799964672753, 0.025871843066332594, 0.06408145784267358, 3.774942832333701, 57.11979266575405, 31.271753924233572, 30.918590886252268, 25.142115661076136, 20.5276780128479, 71.29672336578369, 58.34495462690081, 58.44324384416853, 64.2325245993478, 47.643717833927695, 3.7818254573004584, 0.2468365462762969, 0.4640944483024733, 16.25486765589033, 47.241962569100515, 73.62100001743862, 69.03199972425188, 68.75425243377686, 67.18114553179059, 64.83421080453056, 62.08458627973284, 63.29215540204729, 53.856630257197786, 47.424804415021626, 44.33678524834769, 44.11507517950875, 41.89754022870745, 41.158210209437776, 41.62977055140904, 44.283273696899414, 42.74561650412423, 46.32557160513741, 43.44140911102295, 41.811184542519705, 42.4966972896031, 42.04519987106323, 40.5341716493879, 40.32591676712036, 39.03653260639736, 40.15915305273873, 40.97123418535505, 39.31043059485299, 39.063470772334504, 38.03088508333479, 40.455260957990376, 39.43494578770229, 40.14929355893816, 39.78086880275181, 39.41237456457955, 40.15206241607666, 37.96616608755929, 41.02413429532732, 40.514626366751536, 41.68380669185093, 46.61940744944981, 47.86518471581595, 51.355306557246614, 51.69123458862305, 52.879369599478586, 54.29849399839129, 53.99893283843994, 54.31876189368111, 54.43832302093506, 52.10318980898176, 52.841960498264854, 55.181366852351594, 51.05845866884504, 50.17793778010777, 48.86986991337368, 49.51675067629133, 46.465160914829795, 46.966956342969624, 44.938916138240266, 45.70894677298409, 44.95436198370797, 43.04475382396153, 42.13171189171927, 39.95796448843819, 41.177272592272075, 38.81449249812535, 37.18567146573748, 37.36447640827724, 37.74044690813337, 38.80589062826974, 37.754999910082134, 37.81794711521694, 38.26438624518258, 36.47025714601789, 37.51864998681204, 35.58419506890433, 38.350203445979524, 36.849468980516704, 36.933034964970176, 37.921951225825715, 36.78205060958862, 35.96925033841814, 38.010043961661204, 36.81505455289568, 39.305292401994976, 38.080995491572786, 41.50200012751988, 45.44863946097237, 47.75359664644514, 47.43870776040213, 49.25798239026751, 42.16588313238961, 41.530227184295654, 41.112932273319785, 47.67258065087454, 54.66221135003226, 56.617319788251606, 57.57004983084542, 60.362787927900044, 55.00997563770839, 55.93393666403634, 48.49667174475533, 56.04758140019008, 50.586036750248496, 60.74190943581717, 54.609436307634624, 62.37429141998291, 6.883858706269946, 0.9549913555383682, 2.7546246222087314, 31.866405078342982, 60.124096461704795, 53.52168887002127, 55.43650470461164, 11.297816940716334, 20.66846588679722, 42.20125988551548, 29.265131541660853, 55.71155261993408, 7.9240270512444635, 0.3604323464844908, 0.049208879470825195, 0.09729909896850586, 0.02213200061981167, 0.08269923739135265, 0.05159681722787874, 0.04218504797401173, 0.05107291355463011, 0.03516541660896369, 0.022260484618267844, 0.023255373018660715, 0.10135496740362474, 0.024797901943592087, 0.05195436107793024, 0.03336306814370411, 0.014176057086193135, 0.06688230790730033, 0.03225116977202041, 0.01971179343360875, 0.03352926511849676, 0.05445999073396836, 0.0817474088232432, 0.014669285887586219, 0.04602546797000936, 0.04827702358098967, 0.04306806630588003, 0.10272531637123652, 0.05041042249649763, 0.017363041073882153, 0.07986899997506823, 0.02037208603828081, 0.06998077700180666, 0.04945543195520129, 0.053736594372562, 0.023875623575544784, 0.034926294083041806, 0.043177137417452674, 0.08357152129922595, 0.011777068538192128, 0.021585834212601185, 0.10377620426671845, 3.6072745493480136, 67.44465596335274, 33.114093099321636, 40.84390149797712, 31.205582754952566, 24.63697988646371, 79.17315265110561, 67.30649798257011, 64.329820224217, 65.28789343152727, 55.07530607495989, 3.8366159115518843, 0.26037733682564324, 0.1931844837963581, 16.443549462727137, 55.52771718161446, 74.72522163391113, 70.6905208315168, 71.95174394335065, 66.72576754433769, 65.45792279924665, 64.14796502249581, 64.1528148651123, 56.84172575814383, 50.14982189450945, 46.79327917098999, 46.38829299381801, 45.10457508904593, 46.14626291819981, 43.81222057342529, 45.85902091435024, 45.25641754695347, 47.25756474903652, 46.7511557170323, 43.30976506641933, 44.18858364650181, 43.90439190183367, 42.54405968529837, 42.16173505783081, 41.87692492348807, 41.11392933981759, 43.29803303309849, 41.74177551269531, 42.32986756733486, 40.833124841962544, 41.61130918775286, 41.97864307676043, 43.30158356257847, 42.50719601767403, 41.07461643218994, 44.03608110972813, 41.60323190689087, 43.99092476708548, 42.471013273511616, 44.336312770843506, 47.779582909175325, 51.36568716594151, 55.0761468069894, 57.413319315229145, 56.587991441999165, 56.47008746010916, 56.187608446393696, 56.909046854291645, 55.11543539592198, 55.67622797829764, 56.249200752803254, 60.35368578774588, 58.19895560400826, 54.38312653132847, 54.733638831547324, 51.40785925728934, 48.687114919934956, 49.19087321417672, 46.62181500026158, 48.116365568978445, 47.4652498790196, 45.134893553597585, 43.34239728110177, 43.608388219560894, 43.15302412850516, 42.010292121342246, 41.37598759787423, 39.481641156332834, 38.80259370803833, 40.42538022994995, 39.825521400996614, 40.817894390651155, 39.78822347096035, 39.15191786629813, 40.04544578279768, 37.55070202691214, 39.85064261300223, 37.328092166355674, 40.73081956590925, 39.0943728855678, 38.31405544281006, 38.38653210231236, 41.23706531524658, 38.52480820247105, 43.28884056636265, 40.069142614092144, 45.99606370925903, 47.20917749404907, 51.32516527175903, 49.76713943481445, 50.77899864741734, 44.22606222970145, 42.53195244925362, 43.2034923689706, 49.84084939956665, 57.29988997323172, 58.67900317055838, 59.420751162937705, 61.72489888327462, 57.42761870792934, 57.04707976749965, 51.06977381025042, 57.91599021639143, 54.32324348177229, 62.83723599570138, 56.58463546207973, 65.93249865940639, 7.291344932147434, 1.1326781809329987, 3.6541345034326826, 35.67356627328055, 65.04019015175956, 60.77952698298863, 62.68274280003139, 20.597825288772583, 22.965667145592825, 47.73178972516741, 31.27595063618251, 61.103076798575266, 8.991179159709386, 0.49881611657994135, 0.16954215243458748, 0.08581711258739233, 0.013991110492497683, 0.04014719018180456, 0.01980517851188779, 0.031145686948938028, 0.06905343676252024, 0.02632299930389438, 0.007117923947849444, 0.02935710595920682, 0.15462818342660153, 0.04553544015756675, 0.015025369191010083, 0.021636977093294263, 0.05569635956947293, 0.025194027294803942, 0.08382000760840518, 0.12369432832513537, 0.21043842152825423, 0.18772602240954125, 0.1744990543063198, 0.09748283268085547, 0.12480623008949415, 0.11674478623483862, 0.16620597216699803, 0.2219836948705571, 0.151356219713177, 0.1213252775903259, 0.14430189824530057, 0.07709744226719652, 0.16269546268241747, 0.15759795478412084, 0.2355460221213954, 0.08685119995581252, 0.3042958416044712, 0.14240417150514467, 0.2587895920234067, 0.10295723285526037, 0.21233404480985232, 0.35004261827894617, 9.658230543136597, 82.28195040566581, 42.776966776166645, 47.9481566292899, 36.447157859802246, 27.986657789775304, 83.80514144897461, 67.95593915666852, 68.23489543369838, 73.07858194623674, 58.242642402648926, 4.5778540798595975, 0.3221248377646719, 1.8136478917939323, 19.043202332087926, 59.698331696646555, 79.94370092664445, 73.61076532091413, 73.79073061261857, 71.02102579389299, 68.39846297672817, 66.30378954751151, 67.86302784511021, 61.02964128766741, 53.27992977414812, 49.78307860238211, 48.99833863122122, 47.5806941986084, 48.90733460017613, 46.33667830058506, 49.78724752153669, 48.41068083899361, 52.13458177021572, 48.72618464061192, 46.2753917149135, 47.60307782036917, 46.27374846594674, 45.77346427100045, 45.00997883932931, 44.13515199933733, 45.03561074393136, 45.48178584235055, 43.37845148359026, 44.62129661015102, 44.68120050430298, 46.2666335105896, 44.51334939684187, 45.24247598648071, 44.36282709666661, 44.02398429598127, 47.54689121246338, 42.6264340536935, 47.269984654017854, 44.82094962256295, 46.833054133823936, 52.70797838483538, 54.07287209374564, 58.19378614425659, 57.76274422236851, 57.94225788116455, 58.71646090916225, 59.219628606523784, 61.23143087114607, 56.576269830976216, 58.38990947178432, 58.92092554909842, 62.18186106000628, 58.18885292325701, 55.23088318961007, 55.3380035672869, 53.84735093797956, 51.095978941236226, 50.62498835154942, 50.619704246520996, 49.92081274305071, 49.16911840438843, 46.948314326150076, 44.71866519110543, 43.287926878247944, 44.81589480808803, 42.481088161468506, 42.66289472579956, 41.570401668548584, 41.05548456736973, 41.349428108760286, 41.03311136790684, 42.38400445665632, 43.28878845487322, 41.46019976479666, 41.72351912089756, 41.154034342084614, 43.29410382679531, 42.037133012499126, 42.52687679018293, 43.67696346555437, 40.69874668121338, 41.61085408074515, 42.294980662209646, 40.974006516592844, 45.34291219711304, 42.08141735621861, 48.26699556623186, 48.96939243589129, 54.063943658556255, 52.52554995673043, 55.129773003714426, 46.98399680001395, 45.68860592160906, 47.369364738464355, 51.59306696483067, 60.46933160509382, 60.83969838278634, 61.42803709847586, 65.09564372471401, 57.83133683885847, 59.0522951398577, 50.94474792480469, 61.36617728642055, 55.78911883490426, 65.20882293156215, 58.350054604666575, 65.21545151301792, 8.601594533239092, 0.9609586639063699, 4.218937064920153, 38.2725955418178, 72.13605880737305, 62.87567343030657, 67.93581717354911, 17.65151810646057, 32.00843320574079, 57.48346832820347, 41.70574562890189, 70.65145805903843, 18.01712363106864, 0.6261275250996862, 0.3022804026092802, 0.23745368261422428, 0.11945196454014097, 0.13427429060850823, 0.16254545216049465, 0.08482998662761279, 0.25618589030844824, 0.09842026952121939, 0.0910120445436665, 0.07936160505882331, 0.3190469486372811, 0.12422089864100729, 0.1858866632516895, 0.07121912376689059, 0.08794788896505322, 0.15243886304753168, 0.1991097501346043], [0.018875083420425653, 0.04213545724217381, 0.05975332044597183, 0.07818351220339537, 0.04803549564842667, 0.06867465815906014, 0.035022876757596216, 0.04061426993991647, 0.008546604026508118, 0.06509862933307886, 0.05119574535638094, 0.027047754431675588, 0.04281920001709035, 0.03757293349398034, 0.06443048268556595, 0.0315416528444205, 0.00686555344977283, 0.0276597981075091, 0.018444625893607736, 0.07409777465675559, 0.0348602794110775, 0.04530477217797722, 0.03932703133406384, 0.2182088824255126, 36.639883518218994, 56.944625105176655, 26.197229146957397, 39.57742207390921, 15.618397031511579, 50.72357634135655, 49.73682791846139, 61.03620733533587, 61.52282442365374, 53.49911069869995, 10.862801517759051, 0.15058909516249383, 0.044159025086888244, 0.8655090885502952, 18.136910574776785, 69.88484941210065, 68.83552551269531, 67.242018699646, 66.81250190734863, 65.79513972146171, 62.5546875, 59.15079975128174, 51.58755356924874, 46.95722539084298, 45.41869272504534, 45.2404123714992, 46.96168960843767, 47.01211615971157, 44.426316261291504, 44.26205389840262, 43.27221005303519, 43.36867536817278, 42.764960289001465, 43.397732734680176, 42.319212504795615, 41.83417960575649, 43.0253336088998, 40.6028094291687, 42.59734542029244, 42.4299772126334, 40.52512509482247, 40.59799780164446, 41.13477046149117, 38.46831587382725, 40.26009995596749, 39.114015442984446, 38.58661937713623, 40.614937509809224, 37.57935292380196, 40.97844294139317, 39.268317563193186, 40.45203351974487, 42.06102786745344, 41.64874608176095, 46.24151577268328, 48.45990882601057, 49.61337232589722, 53.102246965680806, 54.862378529139924, 56.56059122085571, 55.40909406117031, 52.332407406398225, 55.292107241494314, 52.92777075086321, 55.19897706168038, 57.08853619439261, 52.74665205819266, 50.62595762525286, 49.55023751940046, 47.109654971531455, 48.54024737221854, 46.70230988093785, 48.08254868643624, 49.681680066244944, 47.65623501368931, 46.67139039720808, 41.90755953107561, 39.763387135096956, 39.63472734178816, 39.99119424819946, 40.07432944434029, 37.911653995513916, 38.708004406520296, 39.05727992738996, 37.83692611966814, 39.568934849330354, 36.5674798148019, 37.77071326119559, 35.162182331085205, 37.797654901232036, 38.143800258636475, 38.540900230407715, 37.236511434827534, 36.948376587459016, 37.332372256687705, 38.209280082157676, 39.374829973493306, 37.9746880531311, 39.54843071528843, 39.24820252827236, 43.46690552575247, 45.04726982116699, 48.219310079302105, 46.290733337402344, 46.53917660032, 42.434180872780935, 41.9458441053118, 42.796595437186106, 49.83180284500122, 55.722419602530344, 59.909598623003276, 58.967186655317036, 62.277523858206614, 57.46020228522164, 57.647445814950125, 51.33369418552944, 54.97910131726946, 53.79083776473999, 56.90748003550938, 58.334122385297505, 54.53327362877982, 2.009372349296297, 0.8917140566876957, 2.0454953823770796, 38.00647258758545, 50.39652463368007, 43.2092558997018, 32.05628544943673, 5.161234387329646, 35.071772371019634, 26.520513193947927, 34.95814847946167, 36.342240061078755, 0.3427397087216377, 0.10879698342510633, 0.10727732961199113, 0.03951169124671391, 0.06034368662429707, 0.04450957663357258, 0.05987821160150426, 0.030332598436091627, 0.02338403682889683, 0.12132865669471876, 0.032088535106075664, 0.017736235334138786, 0.06477917504629918, 0.012681805079669824, 0.05629487834604723, 0.04312764846586755, 0.0046986213336432615, 0.031558382125305276, 0.0015651318805924217, 0.013279515551403165, 0.0574504200901304, 0.08051852762166943, 0.04951880034059286, 0.028304133264880096, 0.014113357905963702, 0.04361993240724717, 0.04975453019142151, 0.03566240279802254, 0.036099033297172615, 0.05211823746295912, 0.011004290942634855, 0.00849448235905064, 0.03769973133291517, 0.042375573821898015, 0.016944383271038532, 0.043921388552657196, 0.01648528308474592, 0.057533601698066504, 0.019008420640602708, 0.026623831197087253, 0.025285310610862713, 0.085278993605503, 0.29129820476685253, 42.929622173309326, 62.413576534816194, 26.681263242449077, 44.592385155814036, 18.842163154057094, 62.31493295942034, 58.32770919799805, 65.16207545144218, 67.74847289494106, 60.53406797136579, 11.780667236873082, 0.2560560458472797, 0.7656352477414268, 1.160897963813373, 22.403721162251063, 73.36074134281704, 70.02304908207485, 68.97454507010323, 68.19481822422573, 69.23879895891461, 65.5930096762521, 61.10170800345284, 54.94726814542498, 47.07030037471226, 47.809571334293906, 47.96833072389875, 49.17364168167114, 48.357811995915, 47.196090562003, 47.48848465510777, 47.524497168404714, 46.77369567326137, 44.98272453035627, 45.88522604533604, 43.478852953229634, 43.264181409563335, 44.53609085083008, 42.151979787009104, 44.07517862319946, 44.458312715802876, 43.28950759342739, 43.343707016536165, 43.19840628760201, 42.39674397877285, 42.55953679765974, 43.05437707901001, 40.626676491328645, 42.24077081680298, 41.979942389896934, 43.376224585941856, 42.615330832345144, 42.915326254708425, 43.39634656906128, 45.74705069405692, 47.5243547303336, 51.25384201322283, 50.7007862499782, 56.10540778296334, 56.17141219547817, 59.38673973083496, 58.42354570116316, 55.747794423784526, 57.23179415294102, 56.50024611609322, 56.478366238730295, 59.23479652404785, 56.377297742026194, 53.55289322989327, 54.02351903915405, 51.006468772888184, 50.70535816465105, 49.482520375932964, 48.99063655308315, 51.107252393450054, 49.69029583249773, 46.7218690599714, 43.63148750577654, 41.11480481284005, 41.813345432281494, 41.4800785609654, 41.83228622164045, 39.67242479324341, 40.194762570517405, 40.23467649732317, 41.595158100128174, 41.320322104862754, 38.78105776650565, 38.69587285178048, 38.116514682769775, 38.46637732642037, 40.05030952181135, 39.918092250823975, 39.80643817356655, 39.22625316892351, 40.09199523925781, 39.543184825352256, 40.330061367579866, 40.177399022238596, 43.10809012821743, 41.149497168404714, 46.04675081798008, 47.30252654211861, 50.713421549115864, 50.200908524649485, 49.1868119921003, 44.13368245533535, 42.5577198437282, 45.09579604012625, 52.87661116463797, 57.01020915167672, 61.67312090737479, 60.496380942208425, 62.65700667245047, 60.01754583631243, 58.66461345127651, 52.63624518258231, 57.786381993974956, 56.996865136282786, 59.419938223702566, 60.29696069444929, 59.07849679674421, 1.9033437073230743, 0.18155680916139058, 4.41460485117776, 39.774646690913606, 57.49200071607317, 45.87681177684239, 40.01963322503226, 7.324204700333731, 36.77182633536202, 29.71972438267299, 39.36348009109497, 39.60720900126866, 0.7009662464261055, 0.10132183453866414, 0.0642659447288939, 0.04339382079030786, 0.03921791611771498, 0.03955828963911959, 0.0680759052879044, 0.012406268123803394, 0.06875146832317114, 0.015075295797682233, 0.021487390655758123, 0.04858711747718709, 0.11032614351383277, 0.014367197008271302, 0.03797606811193483, 0.011636304752235966, 0.09069027645247323, 0.03591572706188474, 0.040381179590310366, 0.19314659440091678, 0.15495162749929087, 0.16556015610694885, 0.1624901515564748, 0.1685762849769422, 0.17330601332443102, 0.11796617640980653, 0.1050447594108326, 0.2019544132053852, 0.12046836928597518, 0.21182035308863434, 0.14062332920730114, 0.08958196413836308, 0.11646894817905766, 0.18667687156370708, 0.12106781426284995, 0.16578693608088152, 0.11057612260005303, 0.13654232104974134, 0.2255349707390581, 0.17207189383251326, 0.09333869362516062, 0.20184915885329247, 0.5490325391292572, 57.08035816465105, 71.66627720424107, 40.03168140138899, 55.2173307282584, 23.250517232077463, 61.89918054853167, 62.78004537309919, 71.87318066188267, 72.27835791451591, 64.19494179316929, 13.279641202517919, 0.2798296058816569, 1.2435195360864912, 1.4088448647941862, 25.85728853089469, 78.2771338054112, 72.30627577645438, 71.52871676853725, 72.08286339896065, 70.39265850612095, 69.61935874394008, 64.76617404392788, 57.97440372194563, 51.20655952181135, 51.1683965410505, 50.28585025242397, 52.779329436165945, 51.16568326950073, 50.51739549636841, 50.533428464617046, 50.16187701906477, 48.86430440630232, 47.80727842875889, 47.690503529139924, 48.15148523875645, 45.420891829899375, 48.22233254568917, 45.17083658490862, 46.35129731042044, 48.147990294865195, 46.549546786717, 44.95367758614676, 47.32555634634835, 44.94610752378191, 46.944968768528526, 45.67951420375279, 43.50620801108224, 45.74711670194353, 44.80160583768572, 46.748744692121235, 44.61733613695417, 46.16976867403303, 47.87590231214251, 47.412203856876914, 49.44473607199532, 53.843220233917236, 52.80901561464582, 59.194427490234375, 56.967578479221885, 61.356394222804475, 59.0946444102696, 57.08248083932059, 58.650494711739675, 57.79262147630964, 59.41539410182408, 60.67451885768345, 58.59781347002302, 54.359360218048096, 55.74518537521362, 51.304681982312886, 53.59738254547119, 50.67578315734863, 50.31308371680123, 52.459990228925435, 52.237866742270334, 50.39670181274414, 45.566755362919395, 42.30465602874756, 42.57082067217146, 42.42121206011091, 44.699984959193635, 42.148352827344624, 44.538779803684776, 43.20004953656878, 43.23640945979527, 43.7550299508231, 39.881089619227815, 41.53783198765346, 40.108994007110596, 40.78188187735421, 43.16065672465733, 42.409535612378804, 42.59560489654541, 41.121475083487375, 42.57881110055106, 42.10589585985456, 43.39691284724644, 42.02862841742379, 45.17364018304007, 43.32818821498326, 50.19745526994978, 50.1426339830671, 53.381342206682476, 51.8685804094587, 51.75420263835362, 46.79922682898385, 45.459447383880615, 46.774974141802105, 56.29133810315813, 61.14489800589425, 62.03316961015974, 60.86653927394322, 62.37579917907715, 62.5597596849714, 60.70052596500942, 54.1760493687221, 60.34069960457938, 59.28632436479841, 64.15494796207973, 60.67297635759626, 59.68515791211809, 2.5729283605303084, 1.3054134377411433, 3.7469624366079057, 46.49584763390677, 60.406512941632954, 51.569783551352366, 40.49318422589983, 9.808543528829302, 51.34689228875296, 37.98874773297991, 47.140852383204866, 56.09588875089373, 2.23587971499988, 0.37952349920357975, 0.20496154470103128, 0.20955202409199306, 0.13777038800929273, 0.16202862560749054, 0.2783744196806635, 0.10616485109286648, 0.15732816926070622, 0.1452303919941187, 0.09456908795982599, 0.06633933740002768, 0.2466239205428532, 0.04811302845233253, 0.11001654155552387, 0.13795869504766806, 0.18190568472657884, 0.20982674935034343, 0.12908564188650676], [0.02108064792784197, 0.02756100340879389, 0.015668778148080622, 0.06278787832707167, 0.040958779132259746, 0.05969607923179865, 0.0625155618680375, 0.020732422059934055, 0.006215348540406142, 0.045974876399018934, 0.05172580334224871, 0.014422461989202669, 0.06451352180114814, 0.009208891524135001, 0.04675882522548948, 0.029856697722737278, 0.009924858775255936, 0.03922278799914888, 0.04872407637802618, 0.021526869519480636, 0.005184527894016355, 0.07269278647644178, 0.031108411627688577, 0.07330396332378898, 7.225598037242889, 61.36568396432059, 35.07645893096924, 44.478910650525776, 25.77278627668108, 24.99952299254281, 67.60935606275285, 62.87552751813616, 65.767242704119, 60.247440883091514, 22.21164689745222, 0.38235562294721603, 0.3910480907985142, 0.20040427281388215, 3.0239535186971938, 43.86137907845633, 76.15902410234723, 64.63872323717389, 69.74093832288469, 62.345379965645925, 61.83219991411482, 56.1036707333156, 51.126575333731516, 50.52645942143032, 55.2771303994315, 51.219907011304585, 49.52804844720023, 45.631113052368164, 45.21610757282802, 43.98493889399937, 44.47777809415545, 43.29052897862026, 43.89985820225307, 43.542609623500276, 44.24422134671892, 42.65535593032837, 43.08156190599714, 41.47453042439052, 41.91084255490984, 40.20293017796108, 42.50393383843558, 40.85007497242519, 40.48984214237758, 40.32842854091099, 38.673110553196494, 40.97970403943743, 39.41798870904105, 40.36464255196707, 40.79408291407994, 39.25240618841988, 39.350886481148855, 41.363293239048545, 42.19952630996704, 44.39343043736049, 45.33131217956543, 47.272131647382466, 49.70140600204468, 50.88418047768729, 51.83024024963379, 52.76787185668945, 52.77599082674299, 53.77163641793387, 54.56128876549857, 53.5184440612793, 54.70437996728079, 55.9282044001988, 51.99078185217721, 53.52880035127912, 49.284621783665244, 52.90736041750227, 49.28986767360142, 51.354014192308696, 52.110575744083945, 52.419103554316926, 52.692119121551514, 52.2979929787772, 45.90863452638899, 41.15592425210135, 40.10977567945208, 39.91145324707031, 39.890754563467844, 40.34708445412772, 37.42609650748116, 38.471612794058665, 37.715058190482004, 38.188984394073486, 37.33123622621809, 37.76850025994437, 38.55834020887102, 39.07064478737967, 38.68036447252546, 37.963696002960205, 37.81824936185564, 37.98321696690151, 37.41244329724993, 37.792509760175435, 37.60428306034633, 38.7998491695949, 39.18185417992728, 39.79032530103411, 43.372462136404856, 45.841813700539724, 47.61629676818848, 46.78997182846069, 47.274351596832275, 43.360017912728445, 40.493041787828716, 42.90581069673811, 49.062817914145334, 56.00911964688982, 59.84176336015974, 58.56789452689034, 59.77317769186837, 61.39921597072056, 57.936730589185444, 59.584589685712544, 52.9101049559457, 57.29430014746529, 58.19800022670201, 56.660843304225374, 35.439728123801096, 0.16771170922688075, 0.32513582333922386, 2.8315526885645728, 47.31021472385952, 46.405753816877095, 53.817150592803955, 12.595393896102905, 23.409950596945627, 37.139472893306184, 21.81097902570452, 49.00954260144915, 8.80511508669172, 0.1222128149654184, 0.060132275468536785, 0.034103885891714265, 0.01978406250210745, 0.07447774748184852, 0.06872037784861666, 0.06986730559063808, 0.03112711544547762, 0.03983405305604849, 0.06269637109445673, 0.04654002143070102, 0.0457392415430929, 0.05509777972474694, 0.0360847297789795, 0.03943546801539404, 0.03082597821152636, 0.10392585516508136, 0.03628458209069712, 0.046499648597091436, 0.029700532888195345, 0.03198292452309813, 0.08754432347736188, 0.02216968815108495, 0.06978062952735595, 0.02868644194677472, 0.03267388012526291, 0.064471819038902, 0.0326386404090694, 0.025316278949113827, 0.07603934154446636, 0.01905243211824979, 0.018821350232298886, 0.07430072448083333, 0.037599080840923955, 0.019838550560442463, 0.03631931629830173, 0.028133378231099675, 0.0391423001752368, 0.04880892378943307, 0.03697013994678855, 0.011505942059946912, 0.032603047854666195, 0.051390108319797685, 7.465866310255868, 72.70280947004045, 32.98398808070591, 45.096949441092356, 30.296310220445903, 38.09719174248831, 74.13083798544747, 66.14290400913784, 71.82769775390625, 67.45303549085344, 26.35889114652361, 0.24189360865524837, 0.9697422725813729, 0.4289416931569576, 3.004666187933513, 50.539806910923545, 76.82051345280239, 66.53656114850725, 74.77423422677177, 66.21401882171631, 64.27861894880022, 59.26695278712681, 55.19071912765503, 54.202396937779014, 58.15585592814854, 53.13877364567348, 52.32354845319475, 48.227251870291575, 47.04910142081124, 46.616589954921174, 46.699975286211284, 46.76010152271816, 45.75013222013201, 45.40201357432774, 45.7619754246303, 44.13672924041748, 44.82384007317679, 43.30953924996512, 43.43850128991263, 42.82493713923863, 44.769651072365896, 42.89613880429949, 43.31299250466483, 42.81648118155343, 41.200913837977815, 43.19407408578055, 43.655226026262554, 44.59330231802804, 43.84119803564889, 43.13605662754604, 43.48920924322945, 43.949655941554475, 44.9036922454834, 48.14613512584141, 49.4406817981175, 50.38774905885969, 51.0163699558803, 54.26928724561419, 56.71570975439889, 57.655074937003, 57.95642178399222, 57.16253450938633, 57.92346995217459, 56.07578066417149, 58.40101269313267, 58.91584641592843, 55.41188028880528, 55.322978087833945, 53.329984596797395, 54.42833151136126, 51.92460026059832, 53.9682982308524, 51.114773818424766, 53.31887442725045, 54.51159872327532, 52.0198426927839, 46.16195889881679, 42.56124952861241, 41.38217149462019, 42.02690526417324, 42.70798853465489, 41.55557073865618, 39.69103206907, 40.63608087812151, 39.89974553244454, 40.6376303264073, 39.230568000248496, 39.293893882206504, 39.35234907695225, 40.75928633553641, 40.65013360977173, 40.846142292022705, 40.232647623334614, 40.28597157342093, 40.431178501674104, 41.870619433266775, 40.41614259992327, 39.900367396218435, 42.1901010785784, 43.10941028594971, 45.92300687517439, 48.83552149363926, 49.8659462928772, 49.81287942613874, 49.38037143434797, 44.9260584967477, 43.14488778795515, 44.70672123772757, 50.27509444100516, 58.45147745949881, 60.19959558759417, 57.99969516481672, 57.95207915987287, 62.29693712506975, 59.626591546194895, 61.682466234479634, 55.66315841674805, 62.25412927355085, 60.5804819379534, 60.157746587480815, 36.58533321108137, 0.23092799420867646, 1.0196153564112527, 3.6141621683325087, 52.463085651397705, 53.536089011601035, 56.3734449659075, 24.765062979289464, 19.83670050757272, 45.14889417375837, 24.133749655314855, 56.62348631450108, 10.162003602300372, 0.14575188686805113, 0.07187122306121246, 0.05400270902152572, 0.060445276887289116, 0.04388167050534061, 0.07334124882306371, 0.026719046623579094, 0.029495862977845327, 0.02073059680073389, 0.05304815274264131, 0.025967043225786517, 0.008899174214872931, 0.04060098083157625, 0.022136049777535454, 0.061440477413790565, 0.03068445955536195, 0.03938011991392289, 0.06897989035184894, 0.06882768137646572, 0.09571215483759131, 0.09779115899332932, 0.16089183517864772, 0.1450116458748068, 0.17628132152770246, 0.15363103550459656, 0.09288011930350747, 0.12765595503151417, 0.14137340895831585, 0.10286523029208183, 0.15940449998847075, 0.12734491457896574, 0.13886211014219693, 0.1820502805390528, 0.13041823038033076, 0.07464442282382931, 0.20612341378416332, 0.14530634720410618, 0.10842220817825624, 0.12262596136757306, 0.152954278247697, 0.10346082797540085, 0.25621240745697704, 0.19233787565359048, 14.687133448464529, 85.3243442262922, 46.51291240964617, 63.2177471433367, 39.241330759865896, 34.568608147757395, 80.08283860342843, 74.13268620627267, 76.51720373971122, 72.94890076773507, 26.544969115938457, 0.3538568807499749, 0.9476017292056764, 0.4250306715922696, 3.463910413639886, 55.15538058962141, 80.34737042018345, 68.42086396898542, 77.22309902736119, 68.43562889099121, 68.29792949131557, 62.96956443786621, 57.64953374862671, 56.033011027744834, 61.77577359335763, 57.55464220046997, 56.08873210634504, 49.93205145427159, 50.77094568525042, 50.16007743562971, 49.95370898927961, 50.13936832972935, 49.41300017493111, 46.63396045139858, 49.41461215700422, 46.89840888977051, 49.647866657802034, 46.7646803855896, 46.749224117824006, 45.78017275674002, 48.037962096078054, 44.90280635016305, 48.140746797834126, 45.121122223990305, 43.44601576668875, 46.953296184539795, 46.213643074035645, 46.74411024366106, 46.254540170942036, 44.34829841341291, 46.238680907658164, 46.06255102157593, 46.61409902572632, 50.73374850409371, 50.31470264707293, 53.73345259257725, 54.457802295684814, 56.383377415793284, 58.6770715713501, 59.533360617501394, 60.593391690935405, 61.220786230904714, 59.83418982369559, 57.79315301350185, 59.976398604256765, 61.06363187517439, 57.40023238318307, 57.03306525094168, 53.954540797642295, 57.59508071626936, 53.42068638120379, 55.8381279536656, 55.102737562997, 55.62556866237095, 56.472567967006135, 55.662220409938264, 49.11728484289986, 43.80850676127842, 42.944241183144705, 43.56800528935024, 45.49534525190081, 44.586837019239155, 41.2400460924421, 42.5917694909232, 41.4541027205331, 42.52220065253121, 40.83312136786324, 41.60019554410662, 41.860252720969065, 43.771059444972444, 42.990120138440815, 43.866058690207346, 42.787496771131245, 42.449967179979595, 42.61644949231829, 43.57820177078247, 43.80208315168108, 42.89239372525896, 45.24470635822841, 45.14427709579468, 49.177143573760986, 51.43520736694336, 53.37157998766218, 53.163825375693186, 53.37783336639404, 47.046002524239675, 45.60200010027204, 46.416874408721924, 54.09433160509382, 60.133684975760325, 63.50752176557268, 60.21456895555769, 59.55353123801095, 61.61993939535958, 63.26101357596261, 64.64136355263847, 58.42060661315918, 63.79371806553432, 63.31985092163086, 63.34511457170759, 41.51718194144112, 0.264418392841305, 1.0702570847102573, 5.612817789827075, 57.73055669239589, 57.3907585144043, 62.31526647295271, 18.88225599697658, 34.36135728018624, 53.93033674785069, 30.834458623613628, 67.89089706965855, 18.57637197630746, 0.2018056104757956, 0.16119883156248502, 0.13246040365525655, 0.1541245747357607, 0.16541705307151588, 0.25538299339158194, 0.1563937993986266, 0.20455211667077883, 0.07117752278489725, 0.12395930982061795, 0.10115629913551466, 0.15469199285975524, 0.09579676136906658, 0.1403138900973967, 0.19829914505992616, 0.10064470408750431, 0.15944028592535428, 0.18171021235840662, 0.098563141854746], [0.007964551598498864, 0.01167981411396925, 0.005648358317557722, 0.04139878873580268, 0.013568440003187528, 0.020878748136705587, 0.004134826162563903, 0.04504121221335871, 0.06598328971969229, 0.0867235471627542, 0.03374364147228854, 0.04198631185239979, 0.07290657250476734, 0.03323803449581776, 0.007835400091218097, 0.035604683216661215, 0.039518351067921946, 0.0732630340914641, 0.016419609376628484, 0.006307164082370166, 0.030842201983822242, 0.05007234920880624, 0.05967830161431006, 0.026241135750231997, 0.4195637149470193, 27.732013259615215, 60.42342485700335, 32.071314402988975, 43.900313309260774, 12.493697455951146, 43.02668503352574, 74.33717169080461, 60.37441226414272, 65.68562916346959, 28.254210335867747, 0.6193172048245157, 1.1206569288458144, 0.22570273173706873, 0.1961153886680092, 26.431781223842076, 78.41940511975969, 66.84413705553327, 70.31164945874895, 66.39155919211251, 62.81168746948242, 55.30646569388253, 58.71779496329171, 59.85383932931082, 66.72924164363316, 63.64752796718052, 60.10305036817278, 49.15493713106428, 43.698249271937776, 43.00440910884312, 43.98149953569685, 42.03782435825893, 44.27716275623867, 43.899500370025635, 42.30351652417864, 40.630793298993794, 43.007612228393555, 40.67163828441075, 44.27804517745972, 42.77741493497576, 43.1723644392831, 39.644750118255615, 43.619022437504356, 41.33217225755964, 39.96792125701904, 40.123613016945974, 40.59600019454956, 39.89494432721819, 41.11627435684204, 40.3931371143886, 39.43518550055367, 40.684388228825156, 41.71098804473877, 44.427268164498464, 44.87692778451102, 44.947945322309224, 47.53966161182949, 49.917404651641846, 49.224314893995015, 52.30039358139038, 53.061950887952534, 54.3920966557094, 54.72406073978969, 51.067491327013286, 55.28709759031023, 56.513291358947754, 53.82046488353184, 51.52014562061855, 50.06015191759382, 47.94265365600586, 56.35732167107718, 53.20610863821847, 54.28639023644583, 57.40744808741978, 54.31496122905186, 53.84328971590315, 52.006832190922324, 46.12798220770699, 43.3961763381958, 41.73315627234322, 39.438405990600586, 40.85712044579642, 39.50450420379639, 39.06853600910732, 39.613611766270225, 39.39833572932652, 39.30195031847273, 39.04722588402884, 38.826300961630686, 37.278315271650044, 37.938432352883474, 38.533712318965364, 38.606730937957764, 38.6485139301845, 37.577271938323975, 39.48880474908011, 38.67755740029471, 38.16903959001814, 38.850463322230745, 40.233384132385254, 43.89736032485962, 46.12502227510725, 46.34452281679426, 45.70957905905587, 43.89630419867379, 43.901199204581125, 41.700520583561485, 41.16354990005493, 43.948936803000315, 53.325972012111116, 55.75952993120466, 61.63242530822754, 56.98316328866141, 60.59059156690325, 59.92669119153704, 60.23427404676165, 56.612299714769634, 62.44182096208845, 48.30967487607683, 58.19348389761788, 5.443693859236581, 0.23725337907671928, 0.683418408036232, 8.175338183130537, 48.091147082192556, 58.75543335505894, 41.03288902555193, 3.522913864680699, 35.488956110818044, 27.438384124210902, 30.75152145113264, 45.12790713991438, 1.7797401398420334, 0.17029090225696564, 0.05812474140631301, 0.00769980504576649, 0.054496631624975374, 0.043708810316664834, 0.057351258982505114, 0.06840876742665257, 0.017015147688133374, 0.04362529622656958, 0.029706931473421197, 0.03934128396213055, 0.047087605976100476, 0.060099875421396325, 0.04545491501422865, 0.20820804978055613, 0.028793884574302604, 0.03607286898685353, 0.022723476202892404, 0.08731561646397624, 0.03976963633405311, 0.007897766789288392, 0.04436925559171608, 0.043567902342017205, 0.019347192819363306, 0.02159755420871079, 0.03421334037557244, 0.03293560125998088, 0.028145737746464353, 0.06099557557276317, 0.0296811776767884, 0.06663601326623134, 0.08212683882032122, 0.04787041825641479, 0.027321341447532177, 0.07895219738462142, 0.023728647801492895, 0.029143197794577906, 0.05078586610034108, 0.032003002374299934, 0.03224281022059066, 0.06975050257252795, 0.014462997671216726, 0.027015579997428825, 0.33435543147580965, 38.371669905526296, 64.93271541595459, 33.812619822365896, 47.20100293840681, 16.889465740748815, 57.92490128108433, 73.70411436898368, 66.87671715872628, 68.11776965005058, 32.27375364303589, 0.3139566332101822, 2.6690647218908583, 1.8575948136193412, 0.3407007652734007, 31.168746880122594, 81.44693674360002, 66.93419960566929, 73.1536224910191, 69.60152966635567, 65.80563844953264, 58.89568274361746, 60.148005213056294, 59.972410338265554, 67.11076028006417, 66.20692471095494, 63.49672426496233, 50.0523282459804, 46.67131396702358, 46.32291391917637, 47.156888825552805, 44.68191269465855, 46.795186451503206, 45.569353989192415, 45.807472229003906, 44.280966894967214, 44.79488345554897, 43.238181250435964, 46.750012738364084, 44.57879100527082, 45.4602255821228, 43.281965323856895, 47.141845975603374, 43.52539198739188, 42.41815137863159, 42.65522738865444, 43.17148896626064, 43.525562218257356, 43.21214287621634, 43.64323343549456, 43.49913821901594, 43.81709820883614, 43.992189339229036, 47.239065170288086, 47.89228616441999, 48.78208637237549, 49.67015995298113, 53.47833905901228, 52.59742907115391, 56.850786209106445, 56.3563107081822, 56.6967898096357, 57.26362385068621, 53.70910957881382, 57.20990037918091, 58.83608109610421, 56.845991952078684, 54.966080393110005, 50.90944412776402, 52.32660913467407, 58.775673457554404, 52.89193541663033, 57.55728599003383, 58.37492915562221, 55.09467417853219, 55.03859526770455, 53.47346142360142, 46.7904269354684, 43.91887194769723, 43.02589293888637, 40.65072768075125, 40.85722814287458, 40.268465587071006, 40.740623474121094, 41.30426134381975, 41.81221635001046, 40.87219108854021, 40.96891696112496, 40.16006326675415, 40.02802664893014, 40.53035708836147, 40.265995502471924, 40.982375621795654, 41.515382358006065, 41.06058801923479, 42.263210024152485, 40.13645328794207, 41.074421882629395, 41.0254579271589, 43.675052710941856, 45.826670101710725, 48.57835476739066, 48.3271495955331, 49.60496153150286, 46.95742688860212, 47.25456312724522, 43.43305390221732, 44.163615294865195, 45.813843727111816, 54.01804038456508, 58.07314109802246, 61.97812598092215, 58.57859475272042, 61.17833273751395, 59.73981244223458, 61.37377861567906, 60.79406261444092, 63.35518251146589, 52.90551914487566, 62.40441880907331, 5.444611455713, 0.43730982126934187, 2.357365710394723, 8.873065863336835, 57.1706326348441, 58.11102615083967, 52.102866717747276, 8.478378653526306, 34.77084936414446, 32.50310673032488, 32.453607763562886, 53.458356039864675, 1.7444097442286355, 0.0908764936029911, 0.05109280820137688, 0.02804082435821848, 0.03441563880603228, 0.022081921342760324, 0.06794865961585726, 0.008414384692774286, 0.0654618219871606, 0.039121408082012615, 0.02397498145832547, 0.029220411687025, 0.02949890281472887, 0.08712655625173024, 0.05806083019290652, 0.018298786665712084, 0.037960176821798086, 0.029479388147592545, 0.023504244396463037, 0.0469286998600832, 0.2611218797309058, 0.06447630415537528, 0.08554637032960143, 0.11058856014694486, 0.10695702037108795, 0.10680425499698945, 0.0855299633528505, 0.18524643832019397, 0.15329106231885298, 0.18639655517680304, 0.1691152182008539, 0.23518799990415573, 0.2614420125527041, 0.17431807544614586, 0.08751638140529394, 0.16193874685892037, 0.13583317053105148, 0.2753338771206992, 0.1481795223163707, 0.09477619720356804, 0.11619332725448267, 0.13753276504576206, 0.25636855193546837, 0.1692271221961294, 1.1434123877968108, 52.64992618560791, 77.21330901554653, 46.0933176449367, 61.11574336460659, 18.61617820603507, 52.527099405016216, 86.14512102944511, 70.25866944449288, 78.76643289838518, 34.861999307359966, 0.6082228315728051, 4.133547612598964, 2.2039885691234042, 0.3336776835577828, 35.97976643698556, 82.49164703914097, 70.04075309208461, 78.11308683667863, 74.64829117911202, 69.26313155038017, 61.32696165357317, 64.3003181729998, 63.858718463352744, 70.90567180088588, 71.09498241969517, 66.68512058258057, 52.73117841993059, 49.096843242645264, 49.96303694588797, 50.46105602809361, 47.790029525756836, 50.099138259887695, 48.761384214673726, 49.09282718385969, 47.290867464882986, 47.24090991701399, 44.972583634512766, 48.85999652317592, 48.35257305417742, 50.84601749692644, 45.32694523675101, 51.377912521362305, 45.63081775392805, 45.70475353513445, 45.38438599450247, 47.275473730904714, 46.802509852818076, 46.87929092134748, 45.51328897476196, 45.59510748726981, 46.85344362258911, 47.089091777801514, 50.036006927490234, 50.57402331488473, 50.461754322052, 52.40205267497471, 56.1809902872358, 54.03906215940203, 57.1172148840768, 57.58308465140206, 59.095589365277974, 57.849263191223145, 54.709097794124055, 58.53769070761544, 60.294674737112864, 58.018083572387695, 56.28660985401699, 53.94395521708897, 53.377183709825786, 61.199357986450195, 55.62483215332031, 56.44336468832833, 61.94874899727957, 56.06656387874058, 55.64720187868391, 55.020026206970215, 48.864978381565635, 47.0384533064706, 46.37538324083601, 40.833837032318115, 44.75706441061837, 43.926768575395855, 43.84339019230434, 43.40422582626343, 43.459106172834126, 43.65071317127773, 42.70191580908639, 41.44879082271031, 41.20816428320748, 42.48225198473249, 42.377163955143516, 43.734306948525564, 43.888831411089214, 43.8045323916844, 44.92437355858939, 44.726954392024446, 43.015432425907676, 43.2245488848005, 45.42423391342163, 48.992748805454795, 52.745380537850515, 50.56656789779663, 51.71128708975655, 50.4443039212908, 50.36923558371407, 45.38527536392212, 45.25581305367606, 48.284240995134624, 56.750728675297324, 59.73244040352957, 64.14323329925537, 60.085457529340474, 63.334296226501465, 60.42103467668806, 62.99559933798653, 62.28760569436209, 65.98520074571881, 56.464369092668804, 68.12210532597133, 7.163527607917786, 0.2832748538681439, 3.5056432485580444, 11.40993046760559, 61.312738691057476, 69.59108652387346, 51.78209270749773, 6.650818296841212, 52.19879354749407, 38.2904280935015, 42.185508319309776, 62.9990109034947, 4.93104577916009, 0.5775263415915626, 0.2685725742152759, 0.13354629038700036, 0.095613102295569, 0.14040317173515046, 0.16154784283467702, 0.15474992617964745, 0.20974883995950222, 0.16795016000313417, 0.11844872337366853, 0.08679305629006454, 0.21723290479608945, 0.11213783879897424, 0.18707171109105858, 0.3390800708106586, 0.09863795712590218, 0.1284035106322595, 0.14487171838326113, 0.1590635497123003], [0.01751323988927262, 0.05997568994228329, 0.0845709830256445, 0.004732968776287245, 0.02624282699876598, 0.03571379164765988, 0.011825421791789787, 0.024358077240841727, 0.041265901045075486, 0.036327672457056384, 0.03475326086793627, 0.03346206979560001, 0.029028820539159433, 0.03089888340660504, 0.07235858762370688, 0.014006922054769737, 0.032752600365451405, 0.05381415431786861, 0.03163746538172875, 0.022758683688672524, 0.04975707809041653, 0.004757193748706153, 0.053216320861663134, 0.13629228089536938, 0.07955320299203907, 10.62291669845581, 62.66093935285296, 34.470780985695974, 39.270106724330354, 36.48219415119716, 8.362551314490181, 70.11088820866176, 65.19236959729875, 64.99923052106584, 39.83698245457241, 1.7854559017079217, 1.8224100044795444, 0.9458989862884793, 0.24086057980145725, 13.456102865082876, 80.96223040989467, 66.02376324789864, 74.38670539855957, 65.77927003587995, 66.44578293391636, 60.568642207554404, 63.400873865400044, 63.21364770616804, 64.74535029275077, 63.728849683489116, 64.73873560769218, 55.58031504494803, 50.46396732330322, 44.060781955718994, 45.707716941833496, 43.311463900974815, 43.7490371295384, 42.39042111805507, 43.62388965061733, 42.93395437513079, 43.66295937129429, 41.560007163456504, 43.717860562460764, 42.564695835113525, 41.75913906097412, 43.398795809064595, 41.62344421659197, 41.071590491703574, 40.287100655691965, 40.19585343769619, 41.46110997881208, 40.07811968667166, 39.308294023786274, 40.78385516575405, 42.06045464106968, 41.58025074005127, 41.24305118833269, 44.125198704855784, 46.72272021429879, 46.27789306640625, 47.219940253666465, 48.59308842250279, 48.287732464926584, 50.485871519361226, 50.62960542951311, 53.15669652393886, 55.211091245923726, 55.385553564344136, 54.567708900996614, 56.14534950256348, 55.19532230922154, 49.27829197474888, 53.32733038493565, 49.08827611378261, 47.075945786067415, 59.59132249014718, 55.705149854932515, 56.36703872680664, 55.863436767033164, 56.74417999812535, 53.308125564030235, 51.843202114105225, 45.09160280227661, 41.00384555544172, 40.30564539773123, 39.02476235798427, 38.46818733215332, 38.69406632014683, 40.03736850193569, 38.5098556791033, 39.736358642578125, 40.29966299874442, 39.83339023590088, 40.185108048575266, 40.4570883342198, 40.241728918892996, 39.337792600904194, 39.40192794799805, 37.647605078560964, 39.44278335571289, 38.137856074741904, 38.91726330348423, 39.20790992464338, 39.70851026262556, 42.70889180047171, 42.74527951649257, 44.319557189941406, 43.223551818302695, 41.44972882952009, 41.666272912706646, 41.794008595602854, 44.415313788822715, 43.52451998846871, 46.79596464974539, 55.78675297328404, 57.43321548189436, 62.929890223911826, 59.533867835998535, 57.86489316395351, 60.528245380946565, 58.298234939575195, 54.60572944368635, 55.24527290889195, 18.65151153291975, 0.30125391483306885, 0.3560394293495587, 1.7702728935650416, 12.645354918071202, 47.929459026881624, 60.86091818128313, 10.481646793229238, 22.75896692276001, 38.525798320770264, 20.91099796976362, 44.82780749457223, 28.62706283160618, 0.12209069223276206, 0.03897800309849637, 0.06374681115682636, 0.09112801974905388, 0.03085857842649732, 0.05112837361437934, 0.02727512812374958, 0.14492909530443804, 0.08718995177852255, 0.030634068152202026, 0.014169753495869892, 0.04158614582515188, 0.018657952214458158, 0.02074476970093591, 0.07377941959670611, 0.018419328411774974, 0.04360117769933172, 0.00866576240930174, 0.038791972545108626, 0.015943723930312053, 0.014706165962187307, 0.07159780737544809, 0.06915964784898929, 0.022302750564579452, 0.005124536068511328, 0.06800634187779256, 0.02459827185209308, 0.03513862804642745, 0.0399594090080687, 0.058737451742802343, 0.06937319639005832, 0.014832812827080488, 0.012457954680680164, 0.020545455128220574, 0.08963410955454622, 0.013420070687841092, 0.021945781772956252, 0.06203887066138642, 0.05746724097324269, 0.0012833260033013566, 0.05910246287073408, 0.028326518135145307, 0.010217755201405712, 0.0938183975272945, 0.0667080194024103, 11.862049749919347, 76.83245740618024, 35.45885304042271, 47.048455238342285, 32.37367916107178, 16.62610122135707, 87.30061340332031, 66.66728455679757, 73.00314535413469, 40.14345359802246, 3.2133266712938036, 3.0655237223420824, 0.8816841691732407, 0.9438343942165375, 15.9167092527662, 80.97262491498674, 67.88745076315743, 76.07098347800118, 69.09574249812535, 68.25815800258091, 62.99505043029785, 65.31055150713239, 66.39697183881486, 67.69961316244942, 64.71559115818569, 66.95491218566895, 58.04908990859985, 53.12071875163487, 46.39923988069807, 48.48741674423218, 47.290447098868235, 46.903036390032085, 44.4439195224217, 46.10086338860648, 45.10915395191738, 45.797626631600515, 43.25016689300537, 46.09781660352434, 45.73625666754586, 45.33488007954189, 45.281451906476704, 44.675794805799214, 42.247791971479145, 42.87072229385376, 42.86453839710781, 44.14952087402344, 42.29115220478603, 43.05716330664498, 43.883755752018516, 45.37874753134591, 45.0619409424918, 44.77899292537144, 46.760834557669504, 51.55605738503592, 48.96865592684065, 51.28700923919678, 52.12765441622053, 52.380231857299805, 52.90202072688511, 56.05306005477905, 57.61931255885533, 58.78462273733956, 58.141240392412456, 58.01255280630929, 59.48801667349679, 59.36547129494803, 54.370644092559814, 55.320268290383474, 50.22243056978498, 52.97871841703142, 62.810061591012136, 57.971614020211355, 58.05153567450387, 59.06572600773403, 58.28552668435233, 56.62351063319615, 53.7507084437779, 46.28554998125349, 43.85570934840611, 43.35278136389596, 41.56441926956177, 40.54372194835118, 39.370532512664795, 41.79654816218785, 40.660041740962434, 41.849646295819966, 41.06516688210623, 40.1102168900626, 41.22271033695766, 41.75289610454014, 41.71745681762695, 41.41998011725289, 40.84868533270699, 40.6225596836635, 42.51853200367519, 40.47454220908028, 40.952696391514365, 42.05817910603115, 42.86739410672869, 45.10580144609724, 45.91026387895857, 46.849913937704905, 47.32262420654297, 43.55201053619385, 43.483209473746165, 43.983330386025564, 45.71588454927717, 44.89333248138428, 48.09943975721087, 57.31192772729056, 60.7765531539917, 64.05233696528843, 59.729063579014365, 60.250553676060264, 62.33317198072161, 62.12014716012137, 58.13122109004429, 59.58540957314627, 17.177939312798635, 0.5434044982705797, 0.8495218264205115, 1.554279889379229, 14.518453768321447, 57.432732582092285, 63.36834934779576, 22.359763383865356, 19.92318820953369, 43.00608015060425, 22.64204784802028, 50.69305290494646, 30.734352452414377, 0.2878247840063912, 0.02411935505058084, 0.03516520965578301, 0.00432619933105473, 0.031038810898150717, 0.0290868726026799, 0.07691458386502095, 0.03452310857496091, 0.008193036391665893, 0.12301873814846788, 0.022867754800245166, 0.027116903935426047, 0.028852781413921287, 0.032766439087156735, 0.09137236699461937, 0.04802413697221449, 0.035596096356000216, 0.020421649628717984, 0.013807234287794148, 0.01855607357408319, 0.11998101829418115, 0.09132900860692773, 0.24586523696780205, 0.13624259856130394, 0.13800453687352793, 0.17063003405928612, 0.1019322242853897, 0.14534537653837884, 0.129990780459983, 0.29208343263183323, 0.17989365197718143, 0.13848574033805303, 0.17405895649322442, 0.09389228320547513, 0.20446283503302506, 0.0677179577095168, 0.09449582653386251, 0.15674146717148169, 0.11910919579012053, 0.10347696353814431, 0.3058529980480671, 0.15154796013874666, 0.10099324038518326, 0.2656657030539853, 0.22277526025261196, 19.697948455810547, 86.26857662200928, 49.45469978877476, 57.73922109603882, 51.46506725038801, 13.481596674237933, 86.02217960357666, 73.39348125457764, 77.1157146181379, 46.98796074731009, 3.123313627072743, 6.13648875270571, 2.828879152025495, 0.7342321585331644, 18.568306854793004, 84.56209209987095, 70.45378180912563, 78.97205788748605, 71.53714493342808, 72.72602340153286, 67.00225721086774, 68.41990511757987, 68.9818754196167, 71.40327399117606, 69.93633556365967, 70.41446195329938, 60.772689955575125, 56.33607407978603, 50.51695428575788, 51.36845254898071, 51.022102219717844, 50.08724641799927, 47.58299057824271, 49.30335412706648, 47.443026065826416, 47.16535867963518, 46.69427081516811, 49.23866639818464, 49.15079253060477, 48.69673122678484, 50.14983926500593, 48.32004506247384, 45.13698148727417, 45.55332102094378, 46.968620436532156, 47.426603998456685, 46.07672882080078, 45.34290177481515, 47.54369504111153, 47.801219599587576, 47.8119615146092, 46.350390570504324, 48.69899633952549, 53.93980366843087, 52.00254167829241, 53.35297966003418, 53.3287478174482, 54.585093293871196, 56.875594752175466, 56.89772476468767, 59.737304142543245, 60.93628529139927, 59.22058745792934, 59.22343621935163, 60.849446705409456, 62.802884101867676, 54.58434983662197, 58.1540459224156, 53.666603973933626, 55.3812699999128, 64.678758757455, 59.35331194741385, 60.612978662763325, 59.04884883335659, 60.23287051064627, 58.07501711164202, 56.20060157775879, 49.172269412449424, 44.95216982705252, 44.656662940979004, 42.56753070013863, 41.955067838941304, 42.351420879364014, 44.45028754643032, 42.536190850394114, 45.21566983631679, 43.83060203279768, 43.44949681418282, 43.10872936248779, 44.90939671652657, 46.08814123698643, 44.39328105109078, 43.87164504187447, 42.76852471487862, 45.308164255959646, 44.424937043871196, 44.805271012442454, 44.33644131251744, 45.76230893816267, 47.180085386548726, 48.395558084760395, 50.60003737040928, 50.59038632256644, 44.988026005881174, 47.08999504361834, 46.09532567432949, 49.87698350633894, 47.10557985305786, 51.06935691833496, 60.36519200461251, 62.69857079642159, 63.59166445050921, 61.33080400739397, 60.266027314322336, 65.07914175306047, 63.34181417737688, 61.23726735796247, 60.88928072793143, 23.354066235678538, 0.4246948781822409, 0.5510922457490648, 5.717416839940207, 14.766172681535993, 59.50394194466727, 73.5526019505092, 16.169842549732753, 35.413349287850515, 55.239936692374094, 32.178316661289756, 58.48956748417446, 42.45187446049282, 0.34362527834517614, 0.3035583554634026, 0.166568662705166, 0.1603567831750427, 0.13672621761049542, 0.12250938905136925, 0.10913684125989676, 0.15702850105507032, 0.12321726392422404, 0.19644670374691486, 0.11099004931747913, 0.17214540631643363, 0.10345614608377218, 0.14631333388388157, 0.24455132175769123, 0.17878149236951554, 0.10294806584715843, 0.1179033304963793, 0.17002060104693684, 0.1492473871580192], [0.03719638727073159, 0.06395368969866208, 0.013456374855845101, 0.04322057383667145, 0.0460233916528523, 0.07352056527244193, 0.04102621194241302, 0.03590062965771981, 0.04656861150371177, 0.021804838175220147, 0.032044443900563886, 0.03517551999539137, 0.05698080600372382, 0.027839896568496312, 0.046694371184068065, 0.005810770339199475, 0.07762496931744473, 0.014334841065907052, 0.03564558530758534, 0.045535548723169735, 0.010592623746820858, 0.1013795846541013, 0.058056446856686046, 0.03479650729734983, 0.1481390137757574, 1.1876634018761771, 35.875731059483115, 60.91600349971226, 25.740320818764822, 51.93340015411377, 18.89519006865365, 19.690640687942505, 81.44223976135254, 58.2764002255031, 57.11997331891741, 2.0790130581174577, 1.5494213615145003, 1.4944935717753, 0.2012432949351413, 0.43476572207042147, 54.61096838542393, 72.30394812992641, 69.51662267957414, 69.14011369432721, 67.70106533595494, 64.87080696650914, 67.50366701398576, 68.53188228607178, 66.41505105154855, 64.82403864179338, 63.654441424778526, 56.62766218185425, 48.60588353020804, 45.155970914023264, 45.22933346884591, 45.014901638031006, 43.44996581758772, 44.03893334524972, 43.629861627306255, 43.959518909454346, 41.075870582035606, 44.55066122327532, 44.7292924608503, 44.60235234669277, 42.23995092936924, 42.80358532496861, 41.99961621420724, 42.04208360399519, 40.812940325055806, 42.9652282169887, 41.144299915858674, 41.513155460357666, 39.33265788214547, 44.04946334021432, 41.44443430219378, 41.20289754867554, 41.821620736803325, 46.137740952628, 47.3544191632952, 45.94721439906529, 47.28691393988473, 49.8424266406468, 50.026341983250205, 50.46491922651018, 51.945100920540945, 53.98132610321045, 55.023489883967805, 56.645348821367534, 55.9985271181379, 55.73548568998064, 54.28995813642229, 54.587295872824534, 55.003722258976524, 57.50743613924299, 50.940113476344514, 45.84496818270002, 58.08223281587873, 56.93463706970215, 57.01159879139492, 55.439686979566304, 56.5176374571664, 53.98009279796055, 48.145332608904155, 40.841031891959055, 42.17449542454311, 41.34110764094761, 41.282388414655415, 39.40992532457624, 40.450824533190044, 41.093765667506624, 40.291224411555696, 38.652085304260254, 39.42457560130528, 41.32622112546648, 40.25063303538731, 40.13224267959595, 38.68515525545393, 39.95151308604649, 38.420658179691856, 36.82669278553554, 40.7189485686166, 41.10007463182722, 38.52906050000872, 40.67149584633963, 40.230563163757324, 42.076939242226736, 43.69718967165266, 42.153650828770225, 41.036304065159385, 42.664534500667024, 41.266504832676475, 40.34723036629813, 43.73836817060198, 43.89834349496024, 49.471768038613455, 58.71613434382847, 58.075586863926475, 62.55684838976179, 58.59140723092215, 59.28941631317139, 56.944590364183696, 58.141566957746235, 29.697111470358713, 0.06776115324880395, 0.19136603708778108, 0.41172161432249205, 0.7939871549606323, 20.17173569543021, 62.442105838230674, 32.99158246176583, 8.563709480421883, 34.68090145928519, 33.825095312935964, 28.967884131840297, 51.950735909598215, 7.876428416797093, 0.6334788277745247, 0.05175119072997144, 0.10337586860571589, 0.041432023381016085, 0.03812461978356753, 0.023108197076778327, 0.038667189955179176, 0.032024705316871405, 0.07259680769805398, 0.11199216411582061, 0.043649262083428245, 0.03744164714589715, 0.031448327137955596, 0.03041421262813466, 0.09616513124534062, 0.024670690198295882, 0.02640434038559241, 0.012822047241830399, 0.060373847505875995, 0.021827623381146362, 0.034894355439714024, 0.057249417661556175, 0.007690333545074931, 0.08686056373906986, 0.06384606047400407, 0.05560637564797487, 0.03589338629639574, 0.04269087208168847, 0.014037395910626011, 0.022433470335922072, 0.0404225329070219, 0.02786178610819791, 0.07321329747459718, 0.07314440581415381, 0.03530992760456034, 0.038231465300279, 0.027628887444734573, 0.01743717781001968, 0.045141289343259165, 0.026190384723512188, 0.0404136440982776, 0.05253710391532097, 0.041667234152555466, 0.042681464193654914, 0.0743612769458975, 0.8002754375338554, 42.43153708321707, 67.54938616071428, 27.286114352090017, 52.80693810326712, 17.856689725603374, 40.43974215643746, 83.61143956865583, 63.84598241533552, 60.49918801443917, 3.3895323361669267, 1.5693264305591583, 1.9853493869304657, 0.7945317743080003, 0.7843393098030771, 62.305816922869, 74.34627383095878, 72.29205281393868, 71.70941856929234, 70.69671862465995, 68.09690420968192, 71.05636433192662, 69.46246147155762, 67.57640075683594, 68.42119748251778, 65.91162627083915, 58.399636949811665, 51.46308701378958, 49.243120193481445, 47.325191565922324, 45.74149213518415, 47.08136885506766, 48.06279148374285, 44.89955459322248, 45.586418764931814, 44.19102941240583, 47.08846296582903, 47.700581891196116, 47.08463798250471, 44.96744196755545, 47.01097665514265, 46.196672098977224, 44.94505139759609, 44.0378737449646, 43.85431623458862, 43.320076193128315, 44.29033306666783, 41.76861292975289, 44.57002585274832, 43.857627051217214, 44.77354553767613, 44.93010582242693, 49.203338282448904, 49.38368225097656, 50.121073722839355, 51.272755009787424, 53.72976657322475, 55.15813207626343, 52.72411905016218, 53.89994532721383, 55.97041818073818, 57.24962670462472, 57.94844872610909, 58.16430493763515, 59.136458669389995, 56.09403705596924, 56.471400669642854, 58.90107454572405, 60.118121010916575, 52.41065107073103, 51.328861713409424, 62.03687300000872, 59.564558029174805, 58.09038652692522, 57.782574381147114, 58.2336688041687, 56.14298364094326, 50.727946758270264, 44.172894614083425, 42.99762071881975, 43.211479323250906, 42.06793785095215, 42.36362886428833, 42.72733579363142, 42.41738012858799, 41.42436443056379, 42.91861275264195, 41.55658517565046, 42.80633333751133, 42.781955582754954, 42.84913771493094, 41.550130299159456, 42.71775770187378, 40.003002711704795, 39.17203984941755, 41.80163424355643, 42.60367522920881, 40.608531270708355, 43.93825394766671, 43.47388846533639, 45.37015608378819, 45.239870412009104, 45.50804655892508, 42.29963248116629, 44.55681732722691, 43.98587690080915, 42.941413266318186, 45.083629744393484, 48.51076963969639, 50.98265034811837, 60.493671144757954, 60.037633078438894, 65.2600450515747, 59.91915239606585, 61.19106183733259, 57.52060644967215, 63.19078813280378, 26.230055911200388, 0.058702025429478714, 0.7090574236852782, 1.8143626877239771, 0.7174991592764854, 23.677800178527832, 65.5757920401437, 42.6414977482387, 13.871253388268606, 25.785213129861013, 40.64672899246216, 28.821772200720652, 61.484199387686594, 6.899252874510629, 0.5916298819439751, 0.017469438757481318, 0.037698733886437755, 0.03522467985749245, 0.030798090422259908, 0.05379230549026813, 0.04016074052612696, 0.029438937282455818, 0.02590666209081454, 0.018389905437028835, 0.060139121886874945, 0.0357183005128588, 0.05479328713512846, 0.024421861228932227, 0.011951878666877747, 0.06767900979944638, 0.03437791225899543, 0.013180866737716963, 0.11652878139700208, 0.0156793327602957, 0.1071408965757915, 0.1528427270906312, 0.10731257950620991, 0.16504478161888464, 0.13335533706205233, 0.20285218288855894, 0.13872738022889408, 0.15068463289311954, 0.11685071912195001, 0.15415732083576067, 0.16663281140582903, 0.08966059277632407, 0.16751365842563765, 0.13416746205517224, 0.27149879719529835, 0.12666506320238113, 0.11780817274536405, 0.1557075697928667, 0.1251999568194151, 0.10784827611808266, 0.16600490867027215, 0.17450860807938234, 0.1429284755140543, 0.1568022503384522, 0.3114490120538643, 1.5645330420562198, 58.358844075884136, 80.29716968536377, 40.48250484466553, 72.68825299399239, 27.49267734800066, 28.399226188659668, 96.02861390795026, 69.17238807678223, 67.37016432625907, 2.869534147637231, 3.03083136677742, 2.3554562585694447, 0.9286759218999318, 1.0771957295281547, 64.62543828146798, 73.73873724256242, 75.23929105486188, 77.55446556636265, 75.51304313114711, 69.64441394805908, 73.24490097590855, 73.84635094233921, 69.96875585828508, 70.36522701808384, 70.04881995064872, 60.927051135471885, 54.91695315497262, 51.525603430611746, 51.36191429410662, 50.060318674360005, 49.85416909626552, 51.13471514838082, 48.55308069501604, 48.724027224949424, 47.41531317574637, 50.38447993142264, 50.884635584695, 50.01116711752755, 48.10910470145089, 49.02320623397827, 48.88064309528896, 47.95022719247, 45.98933785302298, 48.01939650944301, 46.50861494881766, 46.895688670022146, 45.076024941035676, 48.84296301433018, 46.87652553830828, 48.15510525022234, 48.87172508239746, 52.946735858917236, 52.41628605978829, 52.37118877683367, 52.858340876443044, 57.8263167653765, 57.29066971370152, 55.26972014563424, 58.68922397068569, 58.06805501665388, 59.31764684404646, 60.21497195107596, 59.54435961587088, 60.72835350036621, 57.43408053261893, 59.14896542685372, 61.85878372192383, 62.64149134499686, 53.290814127240864, 52.70279155458723, 61.98858996800014, 59.90880652836391, 60.488842146737234, 59.27281011853899, 60.267535073416575, 58.749159131731304, 52.779405866350444, 45.525569915771484, 45.119604042598176, 45.823053564344136, 45.248583453042166, 43.22249221801758, 44.595727239336284, 44.56841039657593, 42.5068416595459, 44.06725767680577, 42.64637885774885, 43.80352142878941, 45.19014910289219, 43.96627950668335, 43.88647944586617, 46.66304908479963, 42.13958420072283, 42.40705510548183, 46.32287917818342, 45.8556684085301, 42.8831456729344, 47.158611978803364, 45.77794238499233, 48.333343914576936, 49.674992425101145, 47.391383579799104, 45.82757336752755, 47.821327686309814, 46.414473806108745, 44.68904502051217, 48.03192411150251, 49.45446702412197, 54.532783780779155, 61.705207688467844, 62.6957984651838, 66.17239216395787, 62.52915287017822, 61.45057010650635, 59.303444726126536, 62.21906171526228, 32.31165606634957, 0.18882914393075875, 0.49720739147492815, 0.9311397096940449, 7.5343998670578, 24.329756600516184, 73.35320254734584, 42.191254479544504, 12.25079711845943, 54.35603550502232, 49.43376834051949, 40.199581146240234, 66.04465648106166, 15.892328023910522, 1.091988770025117, 0.21281386406293937, 0.1757566375391824, 0.13164810224303178, 0.16711569763720036, 0.1329153206731592, 0.08843525352754764, 0.138657043288861, 0.159632501325437, 0.17957383128149168, 0.056850160871233256, 0.1724156261022602, 0.1511734223791531, 0.1360822200242962, 0.1523698696068355, 0.14638816272573812, 0.12235187393214021, 0.07102388888597488, 0.17000198204602512, 0.1449331800852503], [0.05759456128414188, 0.008887102228722401, 0.043551498757941384, 0.03624860955668347, 0.01805417818416442, 0.048302234549607546, 0.0329384036096079, 0.11851406629596438, 0.046555410604923964, 0.011336224336576248, 0.05451370017336948, 0.019201769194166576, 0.038950417257313213, 0.04241696785071066, 0.029720027199281112, 0.01976858002931944, 0.020170408467363034, 0.03350418307153242, 0.04524410775463496, 0.06321965051548821, 0.00885556052838053, 0.04291303801749434, 0.2008723941232477, 0.089370851538011, 0.1619200600045068, 0.08921113796532154, 5.442774959972926, 60.768785067967, 38.564079420907156, 29.06108205659049, 50.22562674113682, 6.3706764834267755, 52.140168121882844, 68.71829550606864, 63.99755736759731, 20.477178505488805, 2.1100626034396033, 0.5017566159367561, 0.7003296177302087, 0.11982028691896371, 11.057043620518275, 86.67408043997628, 68.97678933824811, 75.10633727482387, 66.09151513235909, 72.53384317670549, 67.9483447756086, 70.41330855233329, 67.42961311340332, 69.85012926374162, 62.410456793648855, 60.879219736371724, 50.64945990698678, 46.21336167199271, 45.02249254499163, 46.65110165732247, 45.95243944440569, 45.1702425139291, 44.75101947784424, 43.69058540889195, 45.04115540640694, 43.98359441757202, 45.58006116322109, 43.867319788251606, 45.49118675504412, 41.39980254854475, 39.785399028233115, 41.86109692709786, 41.80868666512625, 42.11530024664742, 41.471375942230225, 42.754343441554475, 42.25501809801374, 43.090372221810476, 41.70681912558419, 40.830085005079, 43.28333411897932, 46.65516635349819, 49.30628974097115, 48.462271213531494, 49.21992015838623, 48.177422864096506, 49.27927514484951, 49.141374247414724, 53.224305970328196, 55.58286503383091, 57.1374271937779, 55.653628962380544, 55.521484647478374, 55.48371423993792, 56.63995354516165, 54.686408451625276, 55.10619081769671, 56.13135583060128, 61.37354237692696, 55.112663064684185, 45.8647392817906, 54.281856536865234, 57.82534749167306, 55.629171303340364, 54.022817271096365, 51.346037660326274, 46.75859376362392, 41.019256659916465, 40.876971449170796, 40.813829694475444, 39.27170828410557, 39.192273003714426, 40.52408286503383, 40.36847448348999, 41.13949523653303, 38.87243700027466, 40.82392195292881, 40.50938395091465, 43.20835263388497, 40.491190092904226, 40.07237352643694, 39.33472844532558, 37.96824359893799, 37.784258774348665, 38.040529182979036, 39.12547302246094, 40.34770631790161, 40.48181002480643, 42.47223963056292, 41.16211857114519, 42.520678997039795, 43.446078300476074, 43.07228258677891, 43.10131563459124, 44.29199021203177, 45.312492983681814, 44.74220221383231, 47.30815805707659, 51.50378261293684, 53.49330200467791, 60.8916083744594, 61.4256260735648, 63.96590832301548, 55.98158393587385, 53.09911332811628, 51.01169729232788, 1.7980351809944426, 0.08954414259642363, 0.22112977212028845, 3.6991961768695285, 1.9020209440163203, 30.075340134756907, 69.12209701538086, 14.283214688301086, 19.855295624051774, 52.42012841360909, 33.533093793051584, 37.79409742355347, 37.00207921436855, 0.14696734664695604, 0.11052160231130463, 0.04742199142596551, 0.061370269395411015, 0.03658487454855016, 0.028285997720169168, 0.07829566047127758, 0.07726527111870901, 0.013793413377633052, 0.06591829285025597, 0.030207961731191193, 0.07979327546698706, 0.024763106667835797, 0.026606947549485734, 0.036734376169208965, 0.10896870028227568, 0.033860240929893086, 0.033883440042180676, 0.029059860123587505, 0.05265991196834615, 0.06604418823761599, 0.06750778827284064, 0.01807867669101272, 0.041117244200514894, 0.007721641999004143, 0.037047435263437886, 0.01758219940321786, 0.06373998509453875, 0.02228551747144333, 0.030964477386857783, 0.042425992366458685, 0.059184979514351914, 0.034830936164196045, 0.020063132080914717, 0.06387981759118182, 0.018990229116752744, 0.06977978135858263, 0.025418193212577274, 0.10324054836694684, 0.054380632670862336, 0.04869854310527444, 0.018486069116209234, 0.033951514067926576, 0.06844173065785851, 0.07486922826085772, 0.11817059186952454, 0.08593164929854018, 6.5386808855193, 73.486510685512, 39.1364928654262, 38.47756392615182, 41.60040051596505, 12.477334448269435, 74.04880755288261, 68.64218493870327, 72.85088947841099, 21.00461104937962, 1.2478467438902174, 2.861003931079592, 1.4488765852791923, 0.37020468924726757, 14.442215527806963, 89.34535012926374, 70.90904862540108, 77.19698074885777, 69.81459617614746, 73.150329044887, 68.77529157911027, 73.16664341517857, 69.12891319819859, 71.34250504629952, 64.49793188912528, 63.06974356515067, 51.34355367933001, 48.086199964795796, 47.4670147214617, 49.87184878758022, 45.98265021187918, 46.52912950515747, 47.00952795573643, 46.63966492244175, 45.832141808101106, 47.33020469120571, 48.23838288443429, 47.30393007823399, 46.954849106924875, 45.468407085963655, 42.67603029523577, 46.21952819824219, 43.016717842647004, 46.043770040784565, 45.29242311205183, 44.871146883283345, 42.91663251604353, 46.29231057848249, 44.92368916102818, 44.888819626399446, 45.77201557159424, 50.602670737675254, 51.225239753723145, 49.841228076389854, 50.91708367211478, 51.995718547276084, 51.60385056904384, 52.542979512895855, 57.72522047587803, 58.93505818503243, 59.60464913504464, 58.726855414254324, 59.71153327396938, 59.0174012865339, 58.999058042253765, 56.95326519012451, 58.79359286172049, 60.26499898093087, 65.33735765729631, 56.34817089353289, 50.28302928379604, 57.99971253531319, 62.14585549490792, 59.815408842904226, 57.27647106988089, 55.161842414310996, 50.35059009279524, 43.30600956508091, 42.64899138041905, 43.30915709904262, 41.17328085218157, 41.011401721409385, 41.796350138528005, 41.888128893715994, 41.11805656978062, 41.27026728221348, 41.7805985723223, 42.58808694566999, 45.366893904549734, 43.47900928769793, 41.820675781794954, 41.44911043984549, 40.521817752293174, 39.94857399804251, 42.02284404209682, 39.62781388419015, 41.695187841142925, 43.577527795519146, 46.17420162473406, 44.65107658931187, 45.22191626685006, 46.18907076971871, 45.68848432813372, 44.51828956604004, 46.02224799564907, 47.147901330675396, 46.269520487104145, 49.33281796319144, 52.688311508723665, 57.05576848983765, 61.476695333208355, 64.04442991529191, 63.27338136945452, 57.85886907577515, 51.37519924981253, 53.98745788846697, 1.507566173161779, 0.4245315412325518, 0.8060387511338506, 2.8187412960188727, 1.61474343921457, 35.24740546090262, 70.62881387983049, 26.513021298817225, 18.25324078968593, 53.135292598179404, 36.18144484928676, 41.27488088607788, 41.605073179517476, 0.6954533936721938, 0.12344586237200669, 0.04995958008138197, 0.05216090035225664, 0.02766597447251635, 0.03513389187199729, 0.00824155843084944, 0.015816278090434413, 0.07969439255871943, 0.045713966113648245, 0.030741490423679352, 0.12148196489683219, 0.013547609826283795, 0.019332801091617773, 0.0254506611132196, 0.07655988646937267, 0.10449198407254048, 0.04229546258492129, 0.01410330371332488, 0.02219426299312285, 0.01667810238099524, 0.18893688172101974, 0.12597782936479363, 0.11889272954847131, 0.18370274401136807, 0.1139653982328517, 0.11262896244547196, 0.12082454588796411, 0.2531643738704068, 0.19482904912105628, 0.08402752397315842, 0.13328768712069305, 0.11770105920732021, 0.09332208308790411, 0.11119321627276284, 0.07552305103412696, 0.07288484581347023, 0.12705971273992742, 0.12196497326450688, 0.24044333504778997, 0.16526496623243603, 0.19032876060477324, 0.14244093453245504, 0.24162765006933892, 0.14974236488342285, 0.3183653194989477, 0.5159294754266739, 14.655572993414742, 80.13585335867745, 53.926904337746755, 44.4756623676845, 69.86608927590507, 8.238794343812124, 66.22364902496338, 79.90603474208287, 75.26219926561627, 24.832351071493967, 3.1930199095181058, 5.4804845707757135, 1.5257852183920997, 0.26245137410504477, 16.007720232009888, 90.64058467320034, 70.80652100699288, 79.4535402570452, 74.00554806845528, 77.45048577444894, 71.03591578347343, 75.27037729535783, 70.8032831464495, 72.54566901070731, 69.07837200164795, 66.81433623177665, 55.2054180417742, 51.002299853733604, 51.093894481658936, 53.90151909419468, 49.28156110218593, 49.97727727890015, 50.30288028717041, 48.61934566497803, 49.622262545994346, 50.7824831690107, 53.10971280506679, 51.729126589638845, 49.74439798082624, 47.93365226473127, 44.582160881587434, 48.086550848824636, 46.61885159356253, 47.928027697971885, 46.808975151606965, 48.2718836239406, 47.00722810200283, 47.59259646279471, 48.02129684175764, 46.85803985595703, 49.55215869631086, 53.30562073843819, 54.60635825565883, 53.57592303412301, 53.802184173039024, 54.169615336826865, 54.46965939658028, 55.611825125558035, 60.72363567352295, 61.04520525251116, 63.90930829729353, 61.403447423662456, 62.06260912758963, 59.24184199741909, 62.096981866019114, 59.570054054260254, 61.42482703072684, 62.33105278015137, 63.732080595833914, 58.726195335388184, 52.84220368521554, 58.44241006033761, 62.30323914119175, 61.34286608014788, 58.77579157693045, 57.83516182218279, 51.594915185655864, 45.86879702976772, 44.552947180611746, 45.58211783000401, 44.37187712533133, 43.756183351789204, 43.35938215255737, 43.57315043040684, 43.953025817871094, 42.15460620607649, 43.96383374077933, 43.36507272720337, 47.64429106031145, 46.2808495249067, 44.491274969918386, 43.39760071890694, 42.459965637751985, 43.90988792691912, 45.56141219820295, 42.9471663747515, 45.31200660978045, 46.07880285808018, 50.17589153562273, 46.23736769812447, 48.263629164014546, 49.02889333452497, 49.48415320260184, 47.947374956948416, 51.27019459860665, 50.254433972494944, 50.432335649217876, 51.44028302601406, 55.88489627838135, 58.3001526423863, 64.30892004285539, 65.5919257572719, 66.10566166469029, 58.94912828717913, 55.7616491317749, 56.19203444889614, 2.6218894932951247, 0.30407928036791937, 0.3791375756263733, 7.697538358824594, 2.520246901682445, 35.78608887536185, 83.40910802568708, 19.653408765792847, 30.84486355100359, 76.18938078199113, 45.49091577529907, 51.388605798993794, 57.78260564804077, 1.4167019746133258, 0.36213631076472147, 0.12646580460880483, 0.23912708567721502, 0.11815688546214785, 0.056421140142317326, 0.29917727197919575, 0.15830946660467557, 0.1295639547918524, 0.22536886536649295, 0.07425467230911766, 0.21057597414723464, 0.10674932758722987, 0.10928870418242045, 0.1612929172281708, 0.2531100096447127, 0.23165199107357434, 0.1085167620331049, 0.18022211720900877, 0.09410237800329924, 0.08592167483376605], [0.02960493408941797, 0.03880856951166477, 0.035113138878451924, 0.028382152917661836, 0.06491665302642755, 0.04693178040906787, 0.03359261314783778, 0.10026023936058794, 0.05368901549705437, 0.03804582829720207, 0.0108751326500039, 0.01573807353686009, 0.03378595830872655, 0.025737153865130882, 0.12625982851854392, 0.09189148699598652, 0.023003202264330218, 0.06279918272048235, 0.03990891243198088, 0.040278663127017875, 0.016605631448328495, 0.026111784923289503, 0.059398806254778586, 0.025178670350994383, 0.09289881294327122, 0.055085138617349524, 0.4557656752211707, 37.86277689252581, 59.94143526894705, 26.82256702014378, 58.13136352811541, 27.925876685551234, 12.152156148638044, 72.62385014125279, 55.80767052514212, 46.48914957046509, 0.5135711591158594, 2.307827660015651, 1.542869427374431, 0.5422779672912189, 0.09213313367217779, 21.394059317452566, 78.5608218056815, 70.63223934173584, 73.5617596762521, 68.58135346003941, 71.41355037689209, 70.76192052023751, 68.71008273533413, 70.20119394574846, 66.9350333895002, 55.47109283719744, 50.721867084503174, 47.17778900691441, 48.9746869632176, 46.4951354435512, 46.087811197553364, 46.36669799259731, 45.138537883758545, 43.05595779418945, 45.71139601298741, 43.74523993900844, 44.370390210832866, 43.47417681557791, 44.04968220846993, 42.98303644997733, 43.41114970615932, 42.601337160382954, 42.31258044924055, 43.70874105181013, 42.5245943069458, 42.433159487588064, 41.276128087724956, 41.33306162697928, 43.84940038408552, 40.537152426583425, 44.42692422866821, 46.85725123541695, 49.287880488804404, 51.675170353480745, 51.61984532220023, 51.27040304456438, 52.51006242207119, 53.713226386478965, 57.163531575884136, 54.420320238385884, 54.50679404394967, 54.07225717817034, 51.4806763785226, 55.73678847721645, 57.59609515326363, 55.01699679238455, 57.27423027583531, 56.409599917275564, 54.78861992699759, 61.29825864519392, 60.50387110028948, 47.75019897733416, 51.09621865408761, 55.62285886492048, 55.64850466591971, 50.565164361681255, 47.557237080165315, 41.47513491766793, 41.37206186567034, 40.42033583777291, 39.12406948634556, 41.04326616014753, 42.1698887688773, 42.78856331961495, 39.76663889203753, 41.123163495744976, 41.108336039951865, 41.558662687029155, 45.63867269243513, 49.0419351032802, 47.613190923418315, 43.83559431348528, 40.35554388591221, 40.23541300637381, 40.80451910836356, 40.32581601824079, 40.75804260798863, 40.17903879710606, 43.29535797664097, 45.600937025887625, 44.36055850982666, 45.210045269557405, 44.77645335878645, 48.75475215911865, 53.0029467855181, 52.33332804271153, 55.99015801293509, 53.54015023367745, 56.26963540485927, 57.476818902151926, 58.17811100823538, 61.78266620635986, 64.4072926385062, 51.66215985161917, 52.98255729675293, 31.298400265829905, 0.08881886330034051, 0.6304114152278218, 1.8476521585668837, 5.712518794195993, 2.7385740663324083, 53.96795082092285, 47.65835074016026, 6.450310656002589, 34.79733937127249, 41.40024028505598, 26.552301202501567, 45.00690426145281, 16.97799621309553, 0.58156796757664, 0.042763794240142615, 0.07869042535977704, 0.03028808653886829, 0.016677968370329057, 0.06197315454483032, 0.03098936265866671, 0.05888304500175374, 0.05695270786860159, 0.10680439070399318, 0.027855207711192112, 0.039489167276769876, 0.044870031398854086, 0.03937481037740197, 0.05424453550949693, 0.023311998462304473, 0.07408298259334904, 0.05493021210921662, 0.06498722745371716, 0.049139770679175854, 0.03494534734636545, 0.035424135226224146, 0.03975285955571702, 0.018264983747420565, 0.0602973833946245, 0.03471295588782855, 0.030713243010853018, 0.02069456998391875, 0.07911942233996731, 0.02794168021396867, 0.025372190234650458, 0.011237502580375543, 0.007990140002220869, 0.026372393260576894, 0.021474087976717522, 0.04089216734947903, 0.01968355110979506, 0.12531335359173162, 0.03996081018288221, 0.012772896709585828, 0.02578987942875496, 0.06130519110177245, 0.03610356591109719, 0.022788138893832053, 0.02935860212892294, 0.03938375007627266, 0.07065868098288774, 0.35158517264894074, 44.45232336861746, 65.23956871032715, 29.267004081181117, 60.18766553061349, 14.903743539537702, 28.634349754878453, 78.11959729875836, 61.275864601135254, 51.51636927468436, 0.6176074594259262, 2.3013523731912886, 3.353199771472386, 1.6944684812000819, 0.2956206899668489, 27.320044142859324, 78.59759862082345, 71.86198711395264, 75.32627555302211, 70.3464251926967, 72.83202511923653, 74.09843158721924, 70.41873509543282, 71.32712868281773, 70.19479465484619, 58.19069766998291, 54.3451372555324, 48.20084524154663, 49.81570386886597, 48.68576349530901, 48.07739659718105, 48.493246282849995, 48.68654864174979, 45.47269065039498, 45.59268604006086, 46.71459777014596, 46.73942020961216, 46.922991616385325, 45.36581345966884, 44.604697363717214, 44.89666761670794, 45.17532164709908, 43.99741438456944, 44.477347305842805, 45.43141835076468, 45.515623569488525, 44.058304922921316, 42.369642530168804, 44.8295236996242, 43.13755049024309, 47.05762686048235, 51.564224992479595, 51.6125670841762, 53.98551934106009, 54.97088507243565, 54.70855236053467, 55.54961790357317, 54.82821076256888, 59.291806493486675, 57.57840156555176, 58.29492064884731, 56.733976568494526, 54.92859138761248, 57.74987963267735, 60.28029196602957, 57.51462057658604, 60.18922192709786, 59.129496574401855, 58.840451513017925, 66.2320077078683, 61.18220983232771, 49.80004262924194, 55.4648950440543, 58.29235676356724, 59.07832309177944, 52.593520709446494, 50.2839047568185, 44.849423340388704, 44.2394757270813, 42.715454374040874, 40.37818111692156, 42.569007192339214, 43.202526569366455, 43.55005461829049, 42.28984941755022, 42.32083143506731, 44.00992809023176, 43.60393442426409, 47.83997317722866, 50.48224803379604, 48.486103534698486, 45.83978482655117, 41.41552979605538, 41.687788009643555, 42.96271644319807, 43.41507543836321, 43.29026147297451, 44.442317962646484, 46.80837413242885, 48.49807875497, 47.60827507291521, 46.70189298902239, 47.70106479099819, 51.62964228221348, 54.77226734161377, 54.61638798032488, 59.30672427586147, 56.36712210518973, 59.06422519683838, 58.782135282244, 62.11804185594831, 61.786619731358115, 66.54422501155308, 53.21501275471279, 54.5566543170384, 32.42582886559622, 0.10794179859970297, 1.1392365204436439, 5.143038358007159, 1.737874529191426, 3.8041621787207465, 58.869349070957725, 56.55776677812849, 13.308740258216858, 23.932152884347097, 46.89189495359148, 31.467519419533865, 53.07699373790196, 21.96624173436846, 0.6370384767651558, 0.027953298429825475, 0.007883052757409002, 0.05121253909809249, 0.015798205310212712, 0.03746830678677984, 0.035286955801504, 0.016067756739045893, 0.03491777168320758, 0.04225818726367184, 0.05665416603109666, 0.09526972286403179, 0.04958900496629732, 0.03576852906761425, 0.06486959662288427, 0.0709437064028212, 0.025259550028879727, 0.014314086376024144, 0.0457126327923366, 0.03744052077776619, 0.0468059562678848, 0.0869596502078431, 0.15813838078507356, 0.10846744610794953, 0.1368322047804083, 0.1458959262818098, 0.10876611008175782, 0.10799550464642899, 0.1568029560148716, 0.22079971911651747, 0.15183412549751146, 0.07707604805805854, 0.11757439029003892, 0.09614165393369538, 0.14127219867493424, 0.17400075175932475, 0.12790033620383057, 0.24197579281670706, 0.11367232538759708, 0.2056770191660949, 0.13363319715218885, 0.20220597327819892, 0.1421165812228407, 0.1075689707483564, 0.10946879416171994, 0.14205787437302725, 0.3003333599439689, 1.1100221680743354, 57.02345241819109, 77.96297100612095, 40.531552178519114, 81.68241119384766, 38.18307842527117, 19.252895491463796, 87.6770042691912, 65.48977334158761, 55.72849232809884, 0.7718818411231041, 9.20030951499939, 6.341328161103385, 2.01742422580719, 0.2507758220391614, 27.467613458633423, 80.1997628893171, 73.14196341378349, 79.576050894601, 73.98824705396379, 76.51157569885254, 75.76529053279332, 72.64734894888741, 74.34285531725202, 71.96088777269635, 61.128937993730815, 56.81313739504133, 51.427279472351074, 53.37614148003714, 52.54607146126883, 52.39500720160348, 52.466420786721365, 50.866677965436665, 47.706394059317454, 49.20197296142578, 47.80022948128836, 49.73891585213797, 50.15542561667306, 49.82034526552473, 47.68158551624843, 48.28614132744925, 48.52256073270525, 46.84912531716483, 48.089687960488455, 48.703446660723, 48.76803364072527, 46.222957134246826, 44.46605995723179, 48.05202177592686, 46.449906144823345, 51.01802710124424, 54.71868978227888, 56.305609703063965, 56.72390168053763, 56.74380479540144, 56.93039172036307, 58.054328850337434, 58.79872758047921, 63.6658364704677, 59.19876316615513, 60.21544442858015, 57.9875670841762, 54.81718397140503, 58.35074247632708, 62.88675580705915, 60.56919111524309, 63.222013337271555, 59.90690272194998, 61.24620968954903, 64.32916709354946, 60.31399767739432, 53.58747441428048, 56.63128219332014, 59.25710718972342, 59.187138829912456, 54.15456553867885, 50.71802473068237, 44.75917666299002, 45.93906763621739, 43.08698844909668, 43.744135175432476, 44.22518675667899, 45.658589703696116, 46.64051955086844, 43.762554849897114, 41.85649721963065, 44.56291437149048, 45.19645111901419, 50.960850375039236, 53.06863158089774, 52.47858708245413, 49.09556130000523, 44.23754065377371, 45.80960532597133, 46.24166515895298, 46.735598700387136, 45.53228187561035, 46.50167717252459, 47.95847470419747, 53.763708523341585, 50.77838025774275, 50.190826688494, 50.081962312970845, 56.02002831867763, 57.92880964279175, 57.597547326769146, 62.48658125741141, 59.44853700910296, 58.530666078839985, 62.25715173993792, 63.4721554347447, 64.99556882040841, 67.56868130820138, 58.08806235449654, 56.69478178024292, 36.555400371551514, 0.14282639670584882, 0.8349446686250823, 7.375211426189967, 14.606011492865425, 4.127174377441406, 61.79779243469238, 59.116836956569124, 9.943910070828029, 54.632837840488975, 55.787086486816406, 40.76130131312779, 59.48061684199742, 32.917000498090474, 0.7665066495537758, 0.0916427903409515, 0.12326921256525175, 0.20694347763700144, 0.1336277010185378, 0.1834706307521888, 0.1297823887850557, 0.13505208172968455, 0.14444920819784912, 0.1762963171516146, 0.11557776028556482, 0.17209505901804992, 0.1225785453404699, 0.1555912417492696, 0.1314512863755226, 0.14461174447621616, 0.15695614208068165, 0.1590015044701951, 0.1146032347210816, 0.08892506081610918, 0.11032692382910422], [0.009344500988455755, 0.04716637032106519, 0.04791736609435507, 0.06083793831723077, 0.029891313186713626, 0.020262070066694702, 0.028318708197080662, 0.025197676116866723, 0.09841653079326664, 0.018520669313147664, 0.04479443241975137, 0.03616997413337231, 0.07965363974549941, 0.02272622087704284, 0.03129786199757031, 0.030282977170177867, 0.07952568839703288, 0.08491037267127208, 0.0391584187746048, 0.06259022786148957, 0.034275470434554985, 0.04290127222027097, 0.0851844126092536, 0.2642523688929421, 0.004998980372745011, 0.0760675889572927, 0.06722322425671987, 10.132084659167699, 69.18076760428292, 39.524268354688374, 36.3155311856951, 71.36548273903983, 8.801354374204363, 40.19933795928955, 74.63994639260429, 58.08437286104475, 4.243687851088388, 3.7301903537341525, 0.4953836521932057, 1.7601802008492606, 0.8253884528364454, 0.1058758765991245, 50.46743100030081, 82.75182233537946, 70.09483786991665, 78.40404960087368, 67.22806671687535, 71.10787827627999, 68.8851078578404, 66.12806960514614, 59.740340505327495, 58.91751398359026, 49.72360897064209, 47.812555585588726, 46.57553652354649, 48.796986784253804, 45.059807845524375, 46.418416908809114, 45.240589550563264, 45.31349352427891, 45.261051995413645, 44.847529956272666, 43.083510875701904, 45.08785424913679, 43.5283727645874, 44.25849642072405, 42.21663972309658, 44.09283399581909, 42.46246698924473, 44.64231491088867, 45.254218442099436, 44.42689643587385, 44.48038714272635, 43.430451801845, 42.35186556407383, 44.05161033357893, 44.91120672225952, 52.073951789310996, 53.51895127977644, 53.711812428065706, 51.40762996673584, 50.87531805038452, 50.748871258326936, 54.23302459716797, 56.361844948359895, 55.99195064817156, 53.014143807547434, 50.79665054593767, 51.45897715432303, 52.0231465612139, 54.24520478929792, 55.60368878500802, 56.751861231667654, 54.677841322762625, 58.92645631517683, 55.34644215447562, 58.99584797450474, 59.60000079018729, 53.36972829273769, 55.8676369530814, 51.36007996967861, 49.7667155947004, 45.28613499232701, 41.23904207774571, 39.98043148858206, 40.19272327423096, 37.73069511141096, 39.06711162839617, 39.34535224097115, 41.68705497469221, 42.18831886563982, 42.13519641331264, 43.03664180210659, 49.00331354141235, 53.218028272901265, 52.84037978308541, 54.00113194329398, 51.36882427760533, 43.438299792153494, 40.83599444798061, 40.21763604027884, 40.60948664801461, 40.333396502903526, 40.187585081372944, 42.05904068265642, 45.91766718455723, 44.27846554347447, 45.0804683140346, 48.68277924401419, 50.91806336811611, 53.7524802344186, 59.64323248182024, 57.56898675646101, 61.248585973467144, 60.35273388453892, 60.03489548819405, 64.10778359004429, 62.256165095738, 63.00758498055594, 49.002472809382844, 55.644651889801025, 13.22292913709368, 0.470455958374909, 2.4185500272682736, 3.4176953392369405, 1.1248154257025038, 6.68575427361897, 63.270254680088584, 17.98543116024562, 17.88789234842573, 45.211288997105186, 55.682304177965435, 35.18920040130615, 53.83844682148525, 8.70887645653316, 0.6698806030409676, 0.06901552022567817, 0.10009956226817199, 0.035059972267065725, 0.050245894717850854, 0.1002398222418768, 0.08385363580392939, 0.013748691134553934, 0.03864545647853187, 0.01315935717762581, 0.059925709052809646, 0.045927076999630244, 0.016170777014589736, 0.03502836271322199, 0.12311838780130659, 0.02270619900498007, 0.03212910471484065, 0.0756634467148355, 0.03574856656736561, 0.03837835456111601, 0.006658104090352676, 0.025708365320627178, 0.0825613047927618, 0.01602065623072641, 0.02297909221878009, 0.08444729966244527, 0.07317369817090885, 0.009243093081749976, 0.012015119826953326, 0.055679586183811934, 0.06963273603469133, 0.06296042978231396, 0.011677485042517739, 0.08254160013582025, 0.028700090678674833, 0.05096735725445407, 0.08989474164055926, 0.035540381845618994, 0.03512218375025051, 0.06944997941276856, 0.09713907326970782, 0.03410587399931891, 0.09519894487623658, 0.10872196459344455, 0.08659817424735852, 0.039462409248309474, 0.0745946251388107, 0.1661302340882165, 9.830954943384443, 80.61199256352016, 36.97365413393293, 44.98075124195644, 57.86962488719395, 11.153680035046168, 61.893212045942036, 71.55828135354179, 67.91936383928571, 3.4087575674057007, 3.8167753304753984, 3.3205388954707553, 4.18666181394032, 0.7407426748956952, 0.1582201849669218, 50.87422718320574, 82.10647365025112, 73.25059849875313, 81.25352668762207, 69.83357865469796, 74.09747273581368, 70.69694096701485, 69.04315158299038, 63.026199204581125, 61.50619738442557, 52.35403020041329, 49.432931082589285, 49.55198846544538, 51.20696251732962, 47.86698429925101, 49.431232248033794, 47.12634107044765, 46.32556118283953, 48.491804531642366, 47.48962068557739, 46.255627564021516, 46.31522921153477, 45.39991174425398, 47.9353927884783, 45.504148619515554, 47.77440997532436, 46.74222380774361, 45.99822112492153, 47.81143345151629, 46.032482692173545, 45.838617529187886, 45.604400702885215, 46.262822423662456, 45.104425702776226, 47.80700397491455, 54.30068962914603, 55.959867341177805, 54.79693692071097, 55.356051513126914, 53.68365485327584, 56.10192673546927, 56.69444479261126, 59.44859259469168, 59.24139731270926, 57.02848291397095, 54.72225073405674, 53.458870206560405, 54.581997871398926, 57.81277820042202, 59.1634315763201, 60.22103772844587, 57.92691625867571, 61.433880533490864, 57.60168150493077, 62.49692712511335, 61.716380391802105, 56.30348702839443, 56.51701559339251, 55.544201782771516, 53.72313451766968, 47.04345600945609, 43.14735092435564, 43.1163341658456, 42.98493330819266, 41.39700242451259, 41.554959297180176, 42.744911261967246, 44.354680333818706, 42.903281552451, 44.05232947213309, 44.302072048187256, 49.97260461534773, 53.79821327754429, 55.782504149845664, 56.40068885258266, 54.18145506722586, 47.14699459075928, 43.79680252075195, 44.11956718989781, 41.97783013752529, 43.54199470792498, 42.285263606480186, 45.60711050033569, 49.09420987537929, 47.25614731652396, 47.46353367396763, 50.2939726965768, 51.645459856305806, 55.32196365083967, 60.70258263179234, 59.91148853302002, 63.652864183698384, 62.496329580034526, 61.84432452065604, 65.55332851409912, 62.25641523088728, 64.33620561872209, 53.062961850847515, 59.79243809836251, 13.97893396445683, 0.3508630213992936, 6.344522161143167, 3.833224322114672, 1.5163008187498366, 8.297842741012573, 63.54912063053676, 28.014394998550415, 18.467941863196238, 50.0195813860212, 60.59231472015381, 38.70401961462838, 61.857421875, 9.710451466696602, 0.621489982519831, 0.12645379453897476, 0.020804231420957615, 0.012944772174315793, 0.05901272661451783, 0.01293821752603565, 0.08497529490185635, 0.047297507391444275, 0.08106250236076967, 0.014137719009470726, 0.04563112038054636, 0.01707436513554837, 0.05520370243383305, 0.08388744041855846, 0.05262325411396367, 0.03737092683357852, 0.03937713435984083, 0.037397596652486494, 0.02043110501420285, 0.0342538251674601, 0.06731642104153122, 0.09529877094818012, 0.3306299213852201, 0.09874914865940809, 0.18424801475235394, 0.19566252082586288, 0.12516851350665092, 0.05627126193472317, 0.07907552790961095, 0.2159912535654647, 0.15945590580148356, 0.1408599615097046, 0.0717648762677397, 0.15691092450703892, 0.11083282596830811, 0.13329702376254968, 0.18045043067208358, 0.19552494106548174, 0.1541319436260632, 0.18181130050548486, 0.2639104686677456, 0.12120875955692359, 0.23430617579392024, 0.20635965253625596, 0.4359637977821486, 0.10284118301102094, 0.23761213411177906, 0.5281176471284458, 19.006230967385427, 86.31393446241105, 54.23347623007638, 51.046584197453086, 97.36480113438198, 10.990536332130432, 50.89875432423183, 82.75519221169608, 70.3176874433245, 3.4432857717786516, 7.543448158672877, 7.629964521953037, 3.6609558973993575, 1.4038785312856947, 0.36897035262414385, 54.641224316188264, 83.79187733786446, 76.05132702418736, 82.86912877219063, 72.5374423435756, 76.63348184313092, 73.81946836199079, 69.0799422945295, 65.77075849260602, 67.24124050140381, 56.12244129180908, 53.930256843566895, 53.53472369057791, 55.24017987932478, 50.50185585021973, 52.3917623928615, 50.7292287009103, 50.53864656175886, 50.928589888981406, 51.423471859523225, 49.9046825000218, 51.336494309561594, 48.86160850524902, 51.38564239229475, 48.868546281542095, 50.74566119057791, 48.98755155290876, 50.751410824911936, 51.87973574229649, 50.857482024601524, 48.971577644348145, 49.93499401637486, 48.76801627022879, 49.51619134630476, 50.795948777879985, 59.28859642573765, 59.134693826947895, 58.16571889604841, 57.25501503263201, 55.07908589499337, 57.04660381589617, 59.62741143362862, 61.78393772670201, 62.05268710000174, 59.14870139530727, 59.09153161730085, 53.310220445905415, 53.35074928828648, 58.97214766911098, 63.62980311257498, 61.13929775782994, 60.08198343004499, 61.630278314862935, 58.02654300417219, 61.66370609828404, 61.83622292109898, 58.25718150820051, 58.87317752838135, 55.46611792700631, 56.41108683177403, 48.590840680258616, 46.11473199299404, 44.33020183018276, 45.14839390345982, 43.10432073048183, 44.252222197396414, 43.52449566977364, 46.99600676127842, 45.94260426930019, 46.428040163857595, 46.30385153634207, 54.310128756931846, 56.416864258902415, 57.41984714780535, 59.21871839250837, 55.10913685389927, 50.42106914520264, 48.1234701020377, 47.19483641215733, 46.02078192574637, 45.61721665518624, 45.43995073863438, 48.08480337687901, 52.625687394823345, 50.99368756158011, 51.158439772469656, 53.276570320129395, 56.267731598445344, 59.48510537828718, 64.56050041743687, 62.03345448630196, 66.29844638279506, 65.13902827671596, 63.380876949855256, 68.75309903281075, 62.491021156311035, 65.69402953556606, 55.79854754039219, 60.47352136884417, 17.56667365346636, 0.5423729621938297, 6.907077414648874, 13.657028266361781, 6.456897982529231, 6.583563642842429, 73.46151106698173, 24.582558121000016, 28.164913824626378, 69.77683271680559, 65.75306837899345, 47.657979011535645, 70.35695171356201, 18.78336923463004, 1.1794672416789191, 0.3212377753640924, 0.2180508787610701, 0.16016848970736774, 0.13572775333055428, 0.17877526341804437, 0.19207281273390564, 0.14585479348897934, 0.16307157464325428, 0.1414388468755143, 0.10541501561445848, 0.11136445815541915, 0.0908634385892323, 0.09632542835814611, 0.1313624390001808, 0.14547094622892992, 0.15424554395888532, 0.17748399770685605, 0.10945791046002082, 0.14913529317293847, 0.11106525135359593], [0.08168372152639286, 0.027771262751360024, 0.02534351364842483, 0.04584156462390508, 0.05350890176902924, 0.008183985582685896, 0.08974124344864062, 0.03606113372370601, 0.05317998191873942, 0.008067748293147554, 0.02255454133929951, 0.04519697331956454, 0.008884005564531046, 0.020754489715078046, 0.014679231514622058, 0.05606735198359404, 0.03759822927947555, 0.03958181784089122, 0.03909783577546477, 0.011493434115046901, 0.03368483284222228, 0.07633487747183867, 0.01997012528590858, 0.09034697165978806, 0.07856160548648664, 0.0080782435335485, 0.06816262206328766, 0.43007723508136614, 36.464306013924734, 63.1345911026001, 29.62591675349644, 46.33143241064889, 35.46898003986904, 10.329940693719045, 76.14535004752022, 58.60970878601074, 16.764108078820364, 3.9352677379335677, 1.1782328507729938, 3.832616789000375, 0.4055878206023148, 0.2833218356328351, 24.51145199366978, 90.85547855922154, 70.17322744641984, 74.29200145176479, 67.89767851148332, 69.8662977218628, 61.829163551330566, 67.14313193729946, 59.861954825265066, 52.09164885112217, 49.70164571489607, 53.16351965495518, 50.56729745864868, 49.02890375682286, 47.06048951830183, 48.21176780973162, 46.21795443126133, 45.1630858693804, 43.83572980335781, 43.52332489831107, 45.91995661599295, 47.32207529885428, 45.347748143332346, 43.972654478890554, 45.51104123251778, 44.27689872469221, 44.457770756312776, 44.027201311928884, 45.10870579310826, 44.51760516847883, 43.55406720297677, 42.87988349369594, 43.075562136513845, 42.998635155814036, 43.25162601470947, 52.5613158089774, 54.05863870893206, 55.13553306034633, 53.58656072616577, 53.04305873598371, 52.96991852351597, 56.42057112285069, 57.07599817003523, 56.99539906638009, 49.323323249816895, 52.339379923684255, 51.192687443324495, 55.5298433303833, 55.759731428963796, 55.14617075238909, 56.21435553686959, 56.3779821395874, 54.01084205082485, 56.9515038217817, 55.30275188173567, 56.58883217402867, 58.34040355682373, 54.399704933166504, 50.962865352630615, 47.044998509543284, 42.99657154083252, 41.68004076821463, 40.47272525514875, 40.91468974522182, 39.54071126665388, 40.79784536361694, 42.273507254464285, 43.179218837193076, 42.01137951442173, 44.81953566414969, 51.9203896522522, 55.33300086430141, 57.04005513872419, 56.00939410073416, 56.56753594534737, 54.70900746754238, 53.19284105300903, 46.25513424192156, 40.31035280227661, 40.85152019773211, 41.2582642691476, 40.02827678407942, 42.702839919498985, 46.50488029207502, 45.42995922906058, 45.272009304591585, 45.16814068385533, 51.28408752168928, 53.27644525255476, 59.527503286089214, 61.01696082523891, 62.20998041970389, 61.62058557782854, 63.85699531010219, 59.735608782087056, 67.22891439710344, 55.07613638469151, 58.927894592285156, 40.031858580453054, 0.15367963218263217, 0.08536229734974247, 4.26253570829119, 6.160903854029519, 0.45390819917832104, 18.182744366782053, 63.776535170418875, 10.049969979694911, 30.362668991088867, 39.20397029604231, 55.38508456093924, 47.28721271242414, 31.00276483808245, 0.4991128806556974, 0.03218975217480745, 0.05299291320677314, 0.020956835642989193, 0.031597611627408435, 0.05804148515952485, 0.06953459272959403, 0.038008312096021006, 0.02940406397517238, 0.06904481936778341, 0.05044951629159706, 0.09326217523110764, 0.032671912373708825, 0.026318644805412208, 0.020659542309918573, 0.0714656694659165, 0.07511907842542444, 0.018061058529253517, 0.059910889848002365, 0.0565595137886703, 0.031206544754760604, 0.040402149715061696, 0.038580289975340874, 0.013345950915079032, 0.06387697452945368, 0.01858104027009436, 0.03503966710663267, 0.0282100764369326, 0.048621492061231814, 0.016826243538941656, 0.06002499908208847, 0.03927259925486786, 0.04330506840986865, 0.02631998491207404, 0.027906486298888922, 0.08370876857744795, 0.020647050480225256, 0.052208676002919674, 0.04019409730764372, 0.08405471287135567, 0.08129572841737952, 0.04100746062717267, 0.04216689716226288, 0.03362966455253107, 0.030683614779263735, 0.0324596666198756, 0.03179241224591221, 0.07972316244351012, 0.10366924000637871, 0.3131574275238173, 42.23264837265015, 70.00311470031738, 30.381053924560547, 59.51291901724679, 19.567603724343435, 22.966223001480103, 85.20762838636125, 65.6257426398141, 20.147062642233713, 3.9830174957002913, 3.6140570768288205, 6.0419802239962985, 2.6349874990327016, 0.23599656937377794, 27.856090715953282, 93.92888219015938, 73.43118912833077, 76.854629107884, 72.26722690037319, 71.33498014722551, 65.4777946472168, 69.9644410269601, 61.24988528660366, 55.69316421236311, 55.35204587663923, 53.501490456717356, 52.19059814725603, 51.23412649972098, 48.50755262374878, 52.459962436131065, 47.5766156060355, 47.68139444078718, 47.04914658410208, 46.48006132670811, 47.61833953857422, 50.088959148951936, 46.320447308676584, 47.36611645562308, 49.33362742832729, 46.77248668670654, 46.341180733272004, 45.38254124777657, 46.13978719711304, 47.321026120867046, 46.91815914426531, 46.522094454084126, 44.87234892163958, 45.8931747845241, 47.093868664332796, 54.2442980493818, 56.97583293914795, 57.436442920139854, 55.312781606401714, 55.963126046316965, 56.029505661555696, 60.71624973842076, 59.54210145132882, 60.69678783416748, 53.78005416052682, 53.77888338906424, 52.372067723955425, 54.83354697908674, 57.748813084193635, 59.38898399897984, 59.258225849696565, 59.91969435555594, 58.01736095973423, 60.57322801862444, 56.838112694876536, 59.975008964538574, 61.02484008244106, 56.59988328388759, 53.876884256090435, 49.95530012675694, 46.960240909031455, 43.13896097455706, 43.53680787767683, 44.00050980704171, 43.36049039023263, 44.269467626299175, 44.36259433201381, 43.777569907052175, 43.03731230327061, 46.7205627986363, 53.0834937776838, 57.25126300539289, 57.70408405576433, 57.76212583269392, 58.38397571018764, 57.821915081569124, 54.57484817504883, 47.18777356828962, 42.642453125544954, 43.935943671635215, 43.56496892656599, 42.311590330941335, 45.46578066689627, 49.82663685934884, 47.71601384026663, 48.321938446589876, 46.88329308373587, 54.550380093710764, 56.454130922045024, 61.282972608293804, 63.484148025512695, 63.59993280683245, 62.68545954568045, 66.32034710475376, 61.13207857949393, 68.81152643476213, 56.71038048607962, 62.75351020268032, 40.97432265962873, 0.22779161536267825, 0.13585291590009416, 5.971389131886618, 3.883342547076089, 0.2881369101149695, 21.4697390965053, 70.54062039511544, 15.79866978100368, 25.632722752434866, 52.41893679755074, 57.40873350415911, 51.271657194410054, 38.99574668066842, 1.1334326033081328, 0.01848593001653041, 0.04281009407714009, 0.04330582158373935, 0.006890325066966138, 0.08775990083813667, 0.04134775950972523, 0.0474986082075962, 0.051623690607292314, 0.011400513833255639, 0.052738292941025326, 0.022749766042189937, 0.013991560021947538, 0.019617466887991344, 0.0692693805322051, 0.022931099436911087, 0.05228631737242852, 0.02370428669798587, 0.08413608957614217, 0.016119279599349414, 0.013342022197321057, 0.04810233134776354, 0.14390619019312517, 0.054025765641459396, 0.19689125274973257, 0.09677512744175536, 0.16050023904868535, 0.16260637103446893, 0.1758070391203676, 0.1371987493974822, 0.14249917997845582, 0.09398508643997566, 0.07898761012724467, 0.0631289439541953, 0.08351207484624215, 0.21144589675324305, 0.18274543966565812, 0.12209305353462696, 0.12282380860831056, 0.1764246959771429, 0.2473632251577718, 0.2348496009196554, 0.07880974574280636, 0.21674718228834017, 0.10060335416346788, 0.15838934374707087, 0.14790643911276544, 0.20608540225241864, 0.1320735708411251, 1.3472804597445895, 58.830529485430034, 80.71700068882534, 41.61236531393868, 66.56937749045235, 49.712696824754985, 17.194540296282085, 88.80673272269112, 69.820328439985, 19.608754430498394, 6.472291282245091, 8.641845447676522, 8.140312314033508, 2.9141118356159756, 0.33561761517609867, 28.590390239443096, 95.88602297646659, 75.94198322296143, 81.36830398014614, 74.61037485940116, 73.64073290143693, 66.01289626530239, 74.77488040924072, 64.54731968470982, 58.01887914112636, 57.60808079583304, 57.315655435834614, 56.21049233845302, 53.69623109272548, 51.0677101952689, 55.904917512621196, 53.3956172806876, 49.57542821339199, 49.88484539304461, 46.90000350134713, 52.0592702456883, 54.15535068511963, 49.914531571524485, 51.27315105710711, 53.17877095086234, 50.43628570011684, 48.615166323525564, 48.15545613425118, 49.31392233712332, 50.43945755277361, 49.621251583099365, 50.39751475197928, 48.33207239423479, 48.637977259499685, 48.460916314806255, 58.18042128426688, 59.9052768434797, 59.830312728881836, 57.1408873966762, 57.80032702854702, 60.197809900556294, 62.70365687779018, 61.190019607543945, 61.134065764290945, 54.944811957223074, 53.86475617544991, 51.04174477713448, 56.707521302359446, 59.632455825805664, 62.25802026476179, 60.33168084280831, 61.6442094530378, 58.88276604243687, 63.03794166019985, 60.933888162885395, 59.5079163142613, 62.09981673104422, 57.883934702192036, 54.54513072967529, 50.42529712404524, 47.527662072862896, 44.9811681338719, 45.34357575007847, 46.28783941268921, 45.57468673161098, 46.42623710632324, 47.39345414297921, 47.115904876164024, 45.96600580215454, 50.52763366699219, 55.91602768216814, 58.26312221799578, 60.726289885384695, 59.86494255065918, 61.240859576633994, 60.36690126146589, 59.02746227809361, 50.69974749428885, 44.885956968579976, 47.59189122063773, 47.67807667595999, 44.64363854272025, 48.45034810474941, 53.82287243434361, 51.56135886056082, 51.685821941920686, 50.64608655657087, 57.80713626316616, 58.49488285609654, 64.721497126988, 66.44743660518101, 65.57916191646031, 64.99229621887207, 67.80159882136753, 63.696769850594656, 70.6428006035941, 62.13040270124163, 62.42569419315883, 43.72737264633179, 0.40347616534147945, 0.24555137380957603, 9.09644263131278, 17.197708674839564, 2.1468051118510108, 20.56699960572379, 78.9483506338937, 13.219213587897164, 50.02998978751046, 52.036271708352224, 66.25588171822685, 57.04929624285017, 58.00165455681937, 2.1198408901691437, 0.252246153141771, 0.11131153242396456, 0.2175993544182607, 0.1692612525075674, 0.14306376182607242, 0.2143661214837006, 0.12497500889003277, 0.12790086546114512, 0.19766391414616788, 0.09563235233404807, 0.13920110623751367, 0.1278812965112073, 0.06037061767918723, 0.1772015235785927, 0.1984088641724416, 0.15537157282233238, 0.07056117550070796, 0.16198338089244707, 0.112314373254776, 0.13854853196867875, 0.12767859095973627], [0.09552450597818408, 0.023511000908911228, 0.02082180547794061, 0.026563545057017888, 0.03642376658639737, 0.07343549733715397, 0.06080173847398587, 0.04746501733149801, 0.03977293401424374, 0.022574388488594974, 0.05154119431972504, 0.0879220978489944, 0.04020556794213397, 0.1546213845057147, 0.0956554835928338, 0.10934885631182364, 0.08915540309888975, 0.06963501591235399, 0.01942357889908765, 0.016097907442599535, 0.06511779794735567, 0.09403295030019113, 0.09656994523746626, 0.1295577801231827, 0.13856420612760953, 0.159253363098417, 0.28530861330883844, 0.13049890819404805, 9.042024339948382, 66.1387837273734, 48.93980005809239, 44.06228971481323, 79.9007819039481, 14.682910680770874, 28.934796810150146, 71.02522945404053, 27.309451614107402, 1.782768685902868, 2.652266800403595, 4.958911529609135, 1.096964765872274, 0.14068989349263056, 21.282101256506785, 92.19196455819267, 65.92136069706508, 77.69484002249581, 60.31462301526751, 61.88598591940743, 58.06637007849557, 57.92653063365391, 50.54890557697841, 55.91071925844465, 51.638633251190186, 49.75675882611956, 50.48722989218575, 51.063503061022075, 48.003797803606304, 47.42844179698399, 48.55305290222168, 48.196485246930806, 48.31836012431553, 44.879797390529085, 46.439702715192524, 47.06055552618844, 48.34235920224871, 46.2594108581543, 46.792400223868235, 47.485455240522114, 46.34432131903512, 45.46830633708409, 45.812085832868306, 46.053184849875315, 45.23914432525635, 42.02733257838658, 42.62739290509905, 43.75730201176235, 43.56290183748518, 51.44486883708409, 61.03936876569475, 56.082669803074424, 57.90633569444929, 56.33383675983974, 54.37568848473685, 54.291330405644004, 56.7717330796378, 53.48464454923357, 54.04942887169974, 54.46361793790545, 53.002953733716694, 51.92903668539864, 53.75546448571341, 54.78018133980887, 54.57245799473354, 54.987011841365266, 55.85302141734532, 55.59391961778913, 57.86550807952881, 52.42574603216988, 51.23038142068045, 50.911000524248394, 48.669695786067415, 44.89191852297102, 43.644525800432476, 40.37121902193342, 41.531769684382844, 41.04538883481707, 40.47947195598057, 39.43277447564261, 41.82454592841012, 43.70465203693935, 44.14114482062203, 53.132909366062705, 58.00092847006661, 55.82940796443394, 57.7215553011213, 55.49507801873343, 56.81257111685616, 54.348976135253906, 56.438549586704795, 53.21849727630615, 44.60809850692749, 39.137809549059185, 41.5608548436846, 39.51558658054897, 43.6966164452689, 44.40890407562256, 46.18743794304984, 45.14006301334926, 47.88778025763375, 45.65226336887905, 52.590762274605886, 58.79363455091204, 63.2297397341047, 63.007341793605256, 64.05399758475167, 63.528498377118794, 65.10609381539481, 58.52173069545201, 55.83968782424927, 55.75762265069144, 4.383914223739079, 0.09802182697291885, 0.2957662492990494, 6.234367157731738, 2.004224385534014, 0.15107450554413454, 33.84966761725289, 24.053939172199794, 12.160903062139239, 47.986871991838726, 30.918076719556534, 19.225580385753087, 54.82545232772827, 17.07996276446751, 1.151914811560086, 0.06887933824743543, 0.13409974426031113, 0.0257165891650532, 0.04314236589042204, 0.03185342950746417, 0.06645026430487633, 0.022599066807223216, 0.0866588284926755, 0.035326361722712, 0.06843183083193642, 0.04711051331833005, 0.11047981812485627, 0.0423178983453129, 0.051710098649242094, 0.04563553425084267, 0.07908843364566565, 0.06647795531898737, 0.015034822880157402, 0.06210053592388119, 0.03424420014822057, 0.02047575601110501, 0.051509181037545204, 0.012750326938528036, 0.0020980003797116554, 0.022593541835833873, 0.005783918588089624, 0.05892074440738984, 0.037566083682967086, 0.06780132252190794, 0.036511345101254325, 0.03347260405176452, 0.04567052969442947, 0.009728169284893997, 0.05254865597401347, 0.07891607218022857, 0.08172900695353746, 0.011293908348307014, 0.028755886613258293, 0.014620275303189243, 0.04263803455978632, 0.023003550013527274, 0.06298627518117428, 0.0309937867069883, 0.10328607806669814, 0.04551654974264758, 0.12506426338638577, 0.05467465885781816, 0.07612414485109703, 0.1895070004143885, 10.253185680934362, 74.65166800362724, 46.2744710786002, 42.98293917519705, 58.684992517743794, 14.62795911516462, 49.468158449445454, 71.5847817829677, 34.85648243767874, 1.1732587005410875, 3.1089873101030077, 6.6213149428367615, 3.8533028789928983, 0.2930707282253674, 22.904509101595195, 94.95693070547921, 67.21907574789864, 80.43743991851807, 62.60171290806362, 66.53765201568604, 60.43497971126011, 60.11964961460659, 53.493843964168, 59.54861191340855, 53.83888455799648, 52.29496356419155, 53.33280903952462, 53.03971317836216, 48.98572417667934, 48.766390391758506, 49.76180669239589, 49.91506658281599, 49.23214898790632, 48.84888635362898, 49.657205036708284, 49.31611449377877, 50.508981227874756, 48.93116692134312, 48.51773868288313, 50.71206317629133, 49.489312240055625, 49.118538992745535, 49.37887062345232, 49.93873562131609, 46.0918550491333, 46.44083874566214, 46.017425945826936, 46.788832323891775, 45.707209723336355, 55.56957312992641, 61.551916531154085, 58.50761890411377, 58.691982405526296, 58.10157312665667, 58.7908205304827, 57.41554273877825, 61.31976331983294, 58.299193790980745, 60.32455893925258, 57.781202111925396, 53.97794233049665, 54.39266988209316, 56.14808014460972, 56.85888433456421, 58.75928265707833, 59.1670446395874, 59.393868582589285, 58.13676227842058, 61.75287233080183, 57.09923642022269, 54.59867007391793, 54.012794494628906, 52.95770706449236, 48.21513073784964, 46.04587881905692, 43.72127907616751, 43.74398578916277, 42.5481903893607, 44.719846384865896, 41.71345812933785, 44.21846784864153, 43.65535109383719, 46.85416970934187, 53.40257590157645, 58.66018744877407, 58.407780238560264, 59.29826136997768, 56.79543685913086, 59.1376120703561, 58.29580307006836, 58.40724522726876, 55.57317229679653, 46.67899867466518, 42.09987871987479, 41.9137920652117, 43.16104929787772, 47.442612648010254, 47.082713331495015, 47.712081159864155, 48.6973739351545, 50.92746428080967, 48.431879792894634, 55.16977378300258, 59.28844356536865, 64.78480911254883, 64.07432801382882, 65.2022429874965, 63.9368440083095, 65.40160070146833, 60.39650058746338, 57.37839419501168, 58.92847129276821, 3.47044324023383, 0.16826383317155497, 2.014819302729198, 8.806294543402535, 2.714409968682698, 0.1811877946768488, 34.774042061397004, 33.24462195805141, 12.53387107167925, 47.504833766392295, 34.434945651463096, 26.405980825424194, 63.383336612156455, 21.411450658525737, 0.9331418765442712, 0.050857258162328174, 0.13488140303109372, 0.04232278379744717, 0.056975900195539, 0.016109766538387964, 0.08638423215597868, 0.03514321155047842, 0.0736017112753221, 0.020823120139539242, 0.03890355084357517, 0.05905542682324137, 0.10140119599444525, 0.03854686873299735, 0.0708610744082502, 0.042395370081067085, 0.0584310863965324, 0.052787245849945715, 0.08168694456773144, 0.037582131036158116, 0.07575360366276332, 0.051108146485473425, 0.14961809798010758, 0.1375520218695913, 0.1344588521335806, 0.12293416554374353, 0.07952013119523015, 0.18775031396320888, 0.15795236719506128, 0.195207522383758, 0.13622971996665, 0.11541184490280491, 0.16164324485829898, 0.09185040170060736, 0.16285265210483754, 0.19272219788815292, 0.28082574957183426, 0.20791693111615522, 0.14277233103556292, 0.20711359993687697, 0.1361475900879928, 0.0971510833395379, 0.23039887260113442, 0.25810296886733597, 0.23143646121025085, 0.22963343081729753, 0.4278414621949196, 0.31166109495929306, 0.5947714447975159, 0.5952600442937442, 20.004292794636317, 83.99456323896135, 64.75381319863456, 57.56093379429409, 104.3325172151838, 20.141903604779923, 40.11986098970686, 85.94508934020996, 34.67339393070766, 4.00854126896177, 8.236610003880092, 12.954695667539324, 8.697032383510045, 0.36777984936322483, 25.644383566720144, 100.28970786503383, 69.4823055267334, 86.18305819375175, 65.337906564985, 69.03632845197404, 63.027158055986675, 63.42232295445034, 55.79767206736973, 61.91274343218122, 57.11629772186279, 55.66852937425886, 56.015150683266775, 56.08994109289986, 50.901217460632324, 53.92030354908535, 53.6490215573992, 53.12634679249355, 53.52651786804199, 53.25555549349104, 53.42857606070382, 52.32800572259085, 54.247737407684326, 52.11916719164167, 52.074156761169434, 53.44145107269287, 50.678135122571675, 52.683065618787495, 53.49013015202114, 52.2598751613072, 50.875258990696494, 49.67260224478585, 48.3104704448155, 47.40784386226109, 50.17922667094639, 57.60152517046247, 64.38082000187465, 61.033032008579795, 63.464192799159456, 61.05024964468819, 61.82828113010952, 60.950119154793875, 63.369787624904085, 59.39865589141846, 62.03532355172293, 59.88607202257429, 56.83111933299473, 54.674214363098145, 58.974704606192454, 59.08202648162842, 60.2995662689209, 63.30988025665283, 60.73967906406948, 61.53574112483433, 62.834602628435405, 57.95356260027204, 55.99762037822178, 56.32732629776001, 55.607152462005615, 48.52573605946132, 47.53810174124581, 44.64316259111677, 47.62080267497471, 45.31464345114571, 44.67497491836548, 42.777255126408164, 45.622639724186485, 45.00549030303955, 49.026141847882954, 57.11170843669346, 60.632836614336284, 61.197349957057405, 62.642373766217915, 60.60441153390067, 60.81376075744629, 60.66596562521798, 61.026653562273296, 58.46638829367501, 50.293785095214844, 44.42068822043282, 45.6433800969805, 45.9375181879316, 51.405156408037456, 50.1381002834865, 50.63017865589687, 51.85783849443708, 52.92238242285592, 52.51205655506679, 59.04340839385986, 62.76311261313302, 66.11566707066127, 65.59010532924107, 65.16313852582658, 65.56814902169364, 68.65070343017578, 62.62410000392369, 60.55772658756801, 58.63406917027065, 4.895957810538156, 0.1578213827950614, 1.6887075560433524, 18.939939941678727, 6.8235357488904675, 0.6718933007546833, 40.91094119208199, 33.36900513512747, 19.496011223111832, 71.77683694022042, 42.59180770601545, 34.2145904813494, 68.5871274130685, 34.69867842538016, 1.1107988463980811, 0.2431035451591015, 0.244315788682018, 0.1182946145002331, 0.14215848754559243, 0.2334273915205683, 0.13128511314945562, 0.16255280748009682, 0.1289552953094244, 0.13328905776143074, 0.23503543809056282, 0.1785114218613931, 0.2658740947289126, 0.14476533766303742, 0.160923427769116, 0.1904603149741888, 0.14493406218077454, 0.14747694001666137, 0.1555800052093608, 0.14444724044629506, 0.09741682479424135, 0.07119812310806342], [0.07292962233935084, 0.14169549596096787, 0.030277983152440617, 0.03630585755620684, 0.037786851836634536, 0.03200215420552662, 0.03674974498738136, 0.0652406331417816, 0.053067711514553854, 0.08137090331209557, 0.07492585879351411, 0.05198838621644037, 0.0047974525036157244, 0.03491608213101115, 0.059115463601691384, 0.048316558423851214, 0.021278133848682046, 0.07263008984071867, 0.03995482550401773, 0.03015187063387462, 0.01943983999080956, 0.100229786708951, 0.04473253306267517, 0.09323728656662361, 0.01464188494719565, 0.07802590208926372, 0.014527594204992056, 0.121337979765875, 0.25326417280094965, 41.791958877018516, 54.05930226189749, 59.66084616524832, 80.48456954956055, 41.87673732212612, 8.798337987491063, 72.49863665444511, 55.380269459315706, 0.573054307273456, 3.4471785000392368, 4.9701871531350275, 3.557086625269481, 0.3038171487195151, 12.38396976675306, 92.4412589754377, 70.09314250946045, 72.34993130820138, 67.13964394160679, 62.02739565713065, 55.04206589290074, 56.21984461375645, 54.30449376787458, 52.327227524348665, 54.760924407414024, 54.54859788077218, 49.82295083999634, 49.12698800223214, 49.28733505521502, 49.67026765005929, 46.86352893284389, 47.05064739499773, 44.84906203406197, 46.42213419505528, 48.78772136143276, 49.8555691582816, 48.63632358823504, 47.86643191746303, 51.256134918757844, 50.735304900578086, 55.512653487069265, 55.7901680128915, 52.10765402657645, 46.747681617736816, 44.30001885550362, 43.41548885617937, 44.735201903751914, 45.22572387967791, 44.79978888375418, 49.451204844883506, 60.46455124446324, 56.59291076660156, 59.50543580736433, 54.03380932126726, 58.67464665004185, 55.647187982286724, 60.715700830732075, 52.222045694078716, 57.38022157124111, 56.419282232012065, 54.818733419690815, 47.78238303320748, 52.48473971230643, 59.44924572535923, 57.108873571668354, 59.78319699423653, 55.90784270422799, 55.60797929763794, 50.843592575618196, 50.06809718268258, 49.0564672606332, 49.38612454278128, 45.49364294324602, 41.44939879008702, 40.293246337345664, 40.93124035426548, 41.38117790222168, 41.240000929151265, 41.846762793404714, 42.52971165520804, 43.429169859204976, 46.94776194436209, 53.92388881955828, 58.25514221191406, 56.629100458962576, 55.37480470112392, 56.88605179105486, 58.11990247453962, 56.389054094042095, 53.717471735818044, 54.75032493046352, 55.75220652988979, 53.462865420750205, 42.97305188860212, 41.58882481711251, 40.47147110530308, 41.41493919917515, 42.448612281254356, 48.24630383082798, 45.25670937129429, 48.88709797177996, 47.09162092208862, 51.89543867111206, 52.19659096854073, 62.83767373221261, 61.41935185023716, 67.02994578225272, 58.93949113573347, 67.08236299242292, 54.10963153839111, 62.344101497105186, 13.40658392224993, 0.054539796630186696, 2.3329944695745195, 0.9103250237447875, 3.742900780269078, 0.9554712155035564, 0.6244144141674042, 38.26294796807425, 27.247195754732402, 33.100981848580496, 41.20969983509609, 30.094478947775706, 49.044439928872244, 46.855847699301584, 2.4446932758603777, 0.40577319636940956, 0.031904397665389946, 0.17863184825650283, 0.017215076335040585, 0.07319577091506549, 0.07600614082600389, 0.08801688240574938, 0.03148293920925685, 0.03513593086972833, 0.05330796719395688, 0.1020893594250083, 0.0071847816995744196, 0.07952118292450905, 0.011925513340559388, 0.037535753167633495, 0.05222391929211361, 0.07150501092629773, 0.060449965564267974, 0.08884628290044409, 0.019056459223585467, 0.07424856549394981, 0.04060845828748175, 0.03129790610234652, 0.06663640003119196, 0.03570177818515471, 0.06412018183618784, 0.048247028940490315, 0.06305216093148504, 0.06674559667174305, 0.12262870264904839, 0.03797925044117229, 0.032349394501319954, 0.04645282289545451, 0.027595025154628923, 0.07219261795814548, 0.011934598076290317, 0.01021933025081775, 0.008969897919866656, 0.05604278901591897, 0.030891229531594684, 0.02116800082980522, 0.03766248654574156, 0.03952380309679678, 0.08698989929897444, 0.10009635279753379, 0.04310235268037234, 0.04539949566658054, 0.03594335700784411, 0.0543410367598491, 0.077754257379898, 0.49932349792548586, 50.04506390435355, 61.96017183576311, 58.31217997414725, 98.69738919394356, 27.5615531035832, 16.958584683282034, 81.08896555219377, 55.56959050042288, 1.2597622530800956, 2.5814818101269856, 9.887581893375941, 11.08005518572671, 0.11861166677304677, 13.3217933177948, 97.79634680066789, 70.72511591230119, 77.00621100834438, 71.23310565948486, 62.67893518720354, 56.00018078940255, 57.32925306047712, 54.77514736992972, 55.507636887686594, 57.04329994746617, 56.79483583995274, 51.22897093636649, 51.54576015472412, 51.960150718688965, 52.51388740539551, 50.36859287534441, 49.328270367213655, 47.942907265254426, 49.024606295994346, 51.31649391991751, 51.982659408024375, 51.722748143332346, 51.461273533957346, 52.508679730551584, 54.76664972305298, 56.86038167136056, 56.11509357179914, 53.71078062057495, 49.872324739183696, 48.0131014415196, 46.35503544126238, 46.22668136869158, 47.9474652835301, 46.880955014910015, 51.11809853145054, 59.971604347229004, 59.91156496320452, 62.1369618007115, 57.70179115022932, 60.769208908081055, 56.96020991461617, 63.057042258126394, 56.23577683312552, 61.44449738093785, 59.7648537499564, 56.9964725630624, 52.004160608564106, 56.91502577917916, 62.02324758257185, 59.534083230154856, 62.100907598223, 60.23910304478237, 58.75304317474365, 55.041558674403596, 54.260744435446604, 52.96672235216413, 52.69233798980713, 49.54952185494559, 43.84681912830898, 43.70888696398054, 43.22005340031215, 43.35227414539882, 42.90930911472866, 44.57375703539167, 43.83586181913103, 44.99621098382132, 46.672887734004426, 54.373447690691265, 59.01166902269636, 60.46736526489258, 57.39623022079468, 59.82692200796944, 58.749819210597444, 59.341472217014854, 57.493206228528706, 58.18603890282767, 56.68513420649937, 56.78700174604143, 44.56595073427473, 44.741806166512625, 42.91131019592285, 45.18481983457293, 47.53998122896467, 52.18894795009068, 48.511415822165354, 51.37698493685041, 49.71893630708967, 54.54157672609602, 55.17427968978882, 65.0724436896188, 62.67642688751221, 69.00650678362165, 59.385225023542134, 67.93618542807442, 55.26078128814697, 68.33624880654472, 14.095993740218026, 0.20113927551678248, 3.8442059499876837, 2.881001498017992, 4.983469503266471, 1.341272005013057, 0.9559053693498883, 42.60609320231846, 30.17101682935442, 28.900427545819962, 51.08465337753296, 30.337822232927593, 52.940319197518484, 52.82229709625244, 2.069145096199853, 0.40756043046712875, 0.01769636122376791, 0.11826884374022484, 0.05515926856813686, 0.06771405613315956, 0.07125946267374925, 0.0846470400158848, 0.06532664424074547, 0.05514471059931176, 0.02763887887288417, 0.13097232207655907, 0.031263460272124836, 0.06947028118052653, 0.011812313343398273, 0.024475996449057544, 0.022592934546992183, 0.05700080921607358, 0.01566954658898924, 0.0685053908133081, 0.011632072390057147, 0.04067337034004075, 0.04957236050228987, 0.26491054786103113, 0.19748666722859654, 0.11184666585177183, 0.19672022121293203, 0.10975058975496463, 0.12665648651974543, 0.08373237481074673, 0.12191402885530676, 0.15848610284073011, 0.12141040659376554, 0.17125279349940165, 0.11339714551078421, 0.10711372803364481, 0.08301029141460146, 0.13447348134858267, 0.134657459333539, 0.14607230467455729, 0.16719378344714642, 0.09475179029894726, 0.14455245408628667, 0.08910534078521387, 0.16495720988937787, 0.15290832785623415, 0.11972525130425181, 0.06835662879581962, 0.18103490716644696, 0.17882915266922542, 0.16762801871768065, 1.3677755828414644, 65.26210171835763, 71.19452231270927, 75.24841403961182, 92.58305781228202, 59.295836448669434, 13.25497944014413, 83.76500865391323, 66.06317343030656, 1.1865071782044, 11.395088246890477, 13.253278000014168, 11.429770180157252, 0.767567552626133, 13.979693923677717, 99.89964989253453, 75.9301643371582, 77.8797802243914, 74.7453088760376, 66.3151637486049, 59.105407169886995, 60.370806149074006, 60.272252900259836, 58.508515221732004, 60.814031737191335, 60.163312094552175, 53.17379256657192, 54.20752123423985, 54.491348198481965, 56.09119871684483, 53.522018909454346, 54.105900355747764, 50.72343737738473, 53.87377493722098, 54.548431124006, 57.175305298396516, 55.53335564477103, 55.350635392325266, 56.82057196753365, 58.45128985813686, 62.33983530317034, 61.891058104378835, 57.70335449491228, 53.322345052446636, 50.38196120943342, 49.42472873415266, 49.93649135317121, 52.4806159564427, 51.494312218257356, 53.9871313231332, 64.54190703800747, 62.58893517085484, 65.6570234298706, 59.54287270137242, 64.63375527518136, 60.08302565983364, 66.43961293356759, 57.888235637119834, 62.93763746534075, 60.63339247022356, 57.72588055474417, 51.570725032261436, 58.68353339603969, 62.82429150172642, 60.330562182835166, 64.81629834856305, 62.399541173662456, 60.980621746608186, 58.23064981188093, 54.12941305977957, 53.87127358572823, 55.05399594988142, 49.947354861668174, 45.1943736076355, 43.98128414154053, 44.49509647914341, 45.98623548235212, 45.880855628422324, 46.18672922679356, 46.144491127559114, 47.34958321707589, 49.08535092217581, 56.460297448294504, 61.58269010271345, 62.35575362614223, 58.330314772469656, 62.613886151994976, 60.434931073869976, 61.26038401467459, 58.40692561013358, 62.778211048671174, 58.43865803309849, 61.177860260009766, 49.67809132167271, 48.67460816247122, 46.70727089473179, 48.06082166944231, 49.72568300792149, 56.18166773659842, 51.80074862071446, 55.01056276048933, 52.19772352491106, 57.817801748003276, 56.471900939941406, 68.25819969177246, 64.75246524810791, 70.37321049826485, 59.8474817276001, 69.15397535051618, 58.817932401384624, 70.1241592679705, 15.239952972957067, 0.4388534612953663, 3.678794094494411, 4.691863596439362, 12.151038357189723, 4.482037118503025, 0.7902853935956955, 48.06505312238421, 34.55286700384957, 53.18206092289516, 58.3300507409232, 49.07604381016323, 61.70511041368757, 66.99926948547363, 6.255170064313071, 0.8461278485400336, 0.3112488442233631, 0.27237484018717495, 0.11371246751930032, 0.18251927037324223, 0.18926017651600496, 0.20758599601686, 0.1598341619329793, 0.1334676888904401, 0.08108499579663787, 0.14963553633008683, 0.1203991858554738, 0.1992279237934521, 0.09727273788303137, 0.1357326523533889, 0.1296735517680645, 0.14376128225454263, 0.09727235111807074, 0.16624884200947626, 0.19724487806005137, 0.17325622242476257, 0.1638197409255164], [0.09812818733709198, 0.036010504833289554, 0.002290429094240868, 0.027040551782452633, 0.06814977061003447, 0.08857206654335771, 0.05629730071606381, 0.06968648279351847, 0.010761067520694008, 0.010903707455976732, 0.043199905660003424, 0.005857128275757921, 0.034408086711274724, 0.035919174019779475, 0.11884577492518084, 0.011202335806696542, 0.03476545074954629, 0.011395898946960057, 0.012512095837986894, 0.05667325661384633, 0.003925899293140641, 0.08955041904534612, 0.06635958488498415, 0.14043058454990387, 0.04766283743083477, 0.09432523604482412, 0.041562044261289496, 0.1283172145485878, 0.2020730482680457, 13.483935611588613, 58.15418141228812, 32.09054354258946, 20.210814101355417, 58.33202402932303, 23.573162044797623, 23.850275312151226, 87.42025443485805, 1.265704048531396, 2.7892474957874844, 2.633876655782972, 2.3358482250145505, 0.18338722522769654, 4.585553552423205, 80.16905185154506, 73.90311772482735, 78.79303060259137, 69.6999647957938, 74.24936730521065, 72.317017691476, 68.34118897574288, 62.40938677106585, 61.20982197352818, 54.98402411597115, 55.156474930899485, 51.576214109148296, 51.84368848800659, 51.79744822638375, 50.73857055391584, 49.54507153374808, 50.98425885609218, 48.57936225618635, 48.15107529503958, 49.64090803691319, 49.90548154285976, 51.217819077628, 50.18696001597813, 50.7120805467878, 53.9401649747576, 58.396642276218955, 61.330824851989746, 60.112666675022666, 57.09374039513724, 47.91865457807268, 43.89463663101196, 42.23625101361956, 43.98051983969552, 43.14548185893467, 46.43968187059675, 60.29770415169852, 60.286691256931846, 58.918048994881765, 57.54511274610247, 56.51928070613316, 54.65239701952253, 59.11157717023577, 50.62787185396467, 61.34360258919852, 57.143739632197786, 56.88534654889788, 38.51969085420881, 47.31923001153128, 62.28315884726388, 56.35448680605207, 58.358371598379954, 52.66960348401751, 50.977571214948384, 45.880240712847026, 46.662024225507466, 43.71418843950544, 45.28805616923741, 42.02773904800415, 43.514577116285054, 41.835916655404226, 42.3349849155971, 42.553505761282786, 41.932062353406636, 41.23906292234148, 42.17559323992048, 43.72477054595947, 52.78201491492135, 59.785267557416645, 60.61980874197823, 59.63866056714739, 59.38361998966762, 57.83786467143467, 56.96191222327096, 56.33539663042341, 55.977943079812185, 54.95766959871565, 57.11500188282558, 54.59403215135847, 49.177306856427876, 39.76484625680106, 41.02438790457589, 40.620614188058035, 45.280295031411306, 44.48028639384678, 48.07774748120989, 49.3224720954895, 49.21403503417969, 48.834031105041504, 57.12419434956142, 55.640295369284495, 63.72450705936977, 62.766816002982004, 67.60103212084088, 59.001663616725374, 62.89613587515694, 24.041486263275146, 0.7732844544308526, 0.12229102291166782, 1.678022312266486, 2.696165084838867, 6.585624652249472, 1.2740256020001002, 4.778078147343226, 32.139059339250835, 24.34503742626735, 52.99531071526663, 24.290049382618495, 32.679931436266216, 45.308977195194785, 13.496504034314837, 0.7821599638887814, 0.02351797794524048, 0.11700306380433695, 0.05521212305341448, 0.12609294961605752, 0.10535778118563549, 0.025544343050569296, 0.049189161243183274, 0.1322939454444817, 0.13884670739727362, 0.03305626853502222, 0.06548973013247762, 0.01677155870545123, 0.06258883007935115, 0.05287898378446698, 0.14340241865387984, 0.03284199056880815, 0.06869154689567429, 0.03093500861099788, 0.047244466309036524, 0.037214175066245456, 0.08472974664930787, 0.017792219562189918, 0.0251556934589254, 0.012094692476759, 0.0751839599439076, 0.00839692768308201, 0.042157954070717096, 0.045201224341456375, 0.06299773563763925, 0.031637607874082666, 0.05993544603032725, 0.052579743055892844, 0.037518433561282497, 0.026972922197143947, 0.017770236723923256, 0.07631768339446612, 0.05609803194446223, 0.017280680493318608, 0.03023896399619324, 0.018274690190862333, 0.03266698281679835, 0.060967660642095974, 0.02984210243448615, 0.060405521520546505, 0.014676851553044148, 0.07227968078638826, 0.005885154740618808, 0.04153318616694637, 0.060334953878607066, 0.10625166964850255, 0.36814167137656895, 16.21536019870213, 70.97566100529262, 35.2729366166251, 40.45381573268345, 62.42714636666434, 19.867444549288066, 46.29833466666085, 86.52259581429618, 1.8026531274829591, 1.5621061665671212, 8.798682791846138, 11.609728523663112, 0.03799918240734509, 4.118557742663792, 84.66186823163713, 76.36423219953264, 80.97230529785156, 69.32346275874546, 76.18662929534912, 73.79129341670445, 68.45928055899483, 64.465101650783, 62.9523537499564, 57.767566272190635, 57.481936250414165, 53.327274799346924, 53.12310545785086, 53.3866263117109, 52.429581437792095, 52.85669067927769, 53.16874122619629, 50.321063722882954, 53.00917584555489, 51.5529967035566, 50.57677480152675, 53.35512317929949, 53.57919910975865, 54.22296013150896, 57.92476231711251, 59.99949441637312, 63.85623100825718, 60.7304379599435, 57.94800056729998, 49.58764662061419, 48.43732023239136, 46.24373572213309, 47.371386664254324, 44.714906215667725, 49.24204322269985, 62.74431773594448, 61.808805329459055, 61.846527099609375, 59.75875323159354, 60.38764163425991, 57.817398752485005, 60.463606289454866, 56.09774044581822, 65.17554106031145, 59.734774998256135, 60.4929415839059, 43.026890005384175, 50.86914457593645, 64.9819781439645, 59.21078354971749, 62.60868195125035, 56.28158630643572, 54.99714926310948, 49.11019768033709, 49.93569925853184, 46.62035240445818, 49.66555677141462, 46.207598141261506, 47.45861087526594, 44.32883998325893, 45.38929142270769, 44.600677830832346, 45.80434553963797, 43.38623694011143, 44.009563309805735, 45.74694299697876, 52.74466139929635, 60.59345422472273, 62.40157004765102, 60.607197761535645, 60.76951462881905, 59.043081828526084, 61.65392303466797, 56.44046034131731, 57.3144325528826, 58.58195768083845, 61.08679716927664, 56.51174191066197, 51.963211400168284, 43.067467485155376, 44.30079705374581, 43.373292446136475, 49.19363512311663, 48.07539551598685, 52.571046761104036, 51.660996028355186, 52.20809371130807, 51.16783026286534, 60.625721658979145, 57.34834671020508, 64.44440991537911, 64.78699779510498, 69.49518748692104, 60.50433662959507, 67.55892603737968, 26.04815033503941, 0.5687587463429996, 0.3214260824024677, 3.127236536570958, 4.59693991286414, 4.51524863924299, 0.8357819808380944, 5.742915425981794, 38.43256391797747, 27.586533614567347, 62.848839487348286, 32.482289927346365, 36.97814267022269, 55.815702642713276, 12.322169014385768, 0.5982365331479481, 0.020104208894606148, 0.12685878495020525, 0.051577726645129066, 0.08647717788283314, 0.03416462156123348, 0.08971860073506832, 0.027111828493486558, 0.15598492776708944, 0.0715329394276653, 0.053553339027400525, 0.08689907738672835, 0.054211738519370556, 0.03520036794777427, 0.02235287055373192, 0.0910497914467539, 0.06085729692131281, 0.03793790390981095, 0.019854921914104904, 0.03169239618416343, 0.058591146022081375, 0.05218292899163706, 0.04029459173658064, 0.18719175750655787, 0.14149384892412595, 0.14313032611140183, 0.08964393474161625, 0.19809105194040708, 0.13143635860511235, 0.16298419290355273, 0.12030603656811373, 0.13857062506888593, 0.08843842228608471, 0.08401026204228401, 0.1370249358671052, 0.12644140448953423, 0.14341153816453048, 0.13020488539976732, 0.07096417101898364, 0.07942951284348965, 0.09086370321788959, 0.11952990107238293, 0.14819215663841792, 0.09798617674303906, 0.3234712683728763, 0.12114698572882585, 0.27734508205737385, 0.07132110758019344, 0.17092221123831614, 0.28642768040299416, 0.3844924382865429, 0.5915854786123548, 29.98627117701939, 79.78046689714704, 49.37354135513306, 35.9930305480957, 74.62659890311105, 34.8745755468096, 32.18772104808262, 102.81110491071428, 1.1374798204217638, 6.484699896403721, 5.007842915398734, 7.790525232042585, 0.26023416593670845, 6.89502489566803, 86.2622537612915, 80.83201422010148, 84.31240163530622, 72.28840500967843, 81.3116761616298, 78.31788499014718, 72.07700606754848, 69.20890086037772, 67.96106692722866, 60.013863291059224, 61.15406962803432, 54.495225293295725, 56.38852603094918, 55.66255739756993, 56.55054759979248, 56.11711549758911, 56.2717650277274, 54.181486334119526, 56.877686159951345, 56.901490688323975, 55.03599664143154, 56.864567961011616, 57.51215396608625, 57.22229943956648, 61.589784213474815, 63.99664715358189, 68.09778663090297, 64.65812955583844, 62.77746064322335, 53.478832381112234, 51.542296477726524, 47.97600153514317, 49.953504017421174, 47.26998117991856, 52.57460076468331, 65.6379645211356, 66.35833985464913, 62.428438731602256, 63.42879867553711, 61.7157689503261, 61.099276133946006, 64.01742226736886, 58.90899549211775, 66.09497533525739, 64.90146241869245, 61.09223760877337, 43.79224797657558, 50.97798810686384, 66.08985451289585, 60.64925520760672, 65.14444092341832, 55.73914739063808, 58.577503885541645, 50.49145092282976, 51.7679739679609, 48.13279458454677, 51.82936477661133, 47.15106970923287, 50.19353996004377, 47.366835594177246, 47.83285127367292, 47.573402064187185, 47.929375648498535, 45.797609261104036, 45.68779993057251, 48.63351304190499, 57.59018223626273, 61.25210176195417, 64.50178119114467, 60.4760296685355, 64.17973218645368, 60.97279807499477, 62.28947475978306, 60.71886920928955, 58.53739888327462, 60.60120146615164, 65.05785942077637, 59.619011061532156, 56.69142927442278, 45.52446515219552, 47.884156772068565, 47.81007507869175, 51.572003500802175, 50.459166118076865, 56.73882293701172, 57.24340111868722, 57.02466835294451, 54.009945733206614, 63.300861494881765, 58.70234216962542, 68.04469544546944, 67.14442430223737, 70.41984680720738, 62.36033248901367, 69.48342418670654, 28.34396369116647, 0.8024383357592991, 0.2257189080119133, 4.441614670412881, 10.95301866531372, 14.78834785733904, 5.474470470632825, 5.969403684139252, 41.77516508102417, 37.54503577096121, 71.02817549024309, 39.00436244692121, 46.79124334880284, 62.63848277500698, 27.541894912719727, 0.8772009525980268, 0.2218401711434126, 0.26548876826252255, 0.1598945651203394, 0.1945583000779152, 0.10654497319566351, 0.22507476114800998, 0.12791086706732, 0.17831787653267384, 0.17019607020275934, 0.16540672576853208, 0.14555340180439608, 0.2119084812168564, 0.29893707058259417, 0.243407420281853, 0.2402181699872017, 0.12877184658178262, 0.17981783247419766, 0.15971582542572701, 0.10470732394605875, 0.14304169586726598, 0.08860377448477916, 0.18901036706353935], [0.031324165407568216, 0.03873702817197357, 0.03380971721240452, 0.01712483965924808, 0.04172608010204775, 0.10778190182255847, 0.07104351890406438, 0.01918947753230376, 0.06353119986930064, 0.08889941219240427, 0.09753419099641697, 0.03702507074922323, 0.03331501090100833, 0.04739371347906334, 0.0318245476643954, 0.029730429141116992, 0.033048648586762805, 0.02333624760753342, 0.03546957332374794, 0.041662124783865044, 0.01882501771407468, 0.041997853733067, 0.017416010910112942, 0.06372046364205224, 0.036209050965096266, 0.03349669883027673, 0.03274952320914183, 0.07438676272119794, 0.08011870764728103, 2.2126688233443668, 55.920599596840994, 50.41922092437744, 35.72065074103219, 30.60096788406372, 61.128639221191406, 9.61771559715271, 62.22987311226981, 13.538133297647748, 1.9007383499826704, 23.822133370808192, 18.54931221689497, 0.3293475444827761, 0.1949341134833438, 39.27997664042881, 89.90067795344761, 69.24667126791817, 78.64921678815568, 70.73674719674247, 70.78623226710728, 73.59393678392682, 70.63447666168213, 64.15696988786969, 58.2835499218532, 55.07950626100813, 53.42560223170689, 53.41661473682949, 55.251804215567454, 51.56768866947719, 51.35961444037301, 48.36934947967529, 47.389542307172505, 50.70734534944807, 51.7193991116115, 52.774587290627615, 50.55924449648176, 51.62548378535679, 56.04167890548706, 58.518075942993164, 61.666283879961284, 62.374930654253276, 61.93077400752476, 60.985096386500764, 58.880764961242676, 48.73500190462385, 42.711966378348215, 45.09001861299787, 43.927463395254954, 42.85818426949637, 52.957179001399446, 61.56798076629639, 59.776526723589214, 60.538021496364046, 60.28393282209124, 59.31181730542864, 54.65873377663748, 54.53237036296299, 62.518813950674875, 53.27824483598982, 58.73521409715925, 42.66979776109968, 52.541402271815706, 61.17828410012381, 57.10602133614676, 58.1309813771929, 54.96127918788365, 50.67953865868704, 45.63261733736311, 46.117163862500874, 46.19951738630022, 45.20869037083217, 42.61930520193917, 42.21801894051688, 43.22573355266026, 41.941254820142476, 42.101195403507774, 42.56627655029297, 43.39787517275129, 45.379595211574006, 49.11275461741856, 56.30026306424822, 60.75471496582031, 59.24640001569475, 58.46645777566092, 58.52644157409668, 58.087301526750835, 58.000907625470845, 57.56381382261004, 55.3058750970023, 56.030912671770366, 56.22759532928467, 57.188906397138325, 54.95994860785348, 44.252284731183735, 40.62768745422363, 40.41386706488473, 43.12882702691214, 48.52976254054478, 50.47885036468506, 47.769379479544504, 50.524260316576274, 51.236026832035606, 53.36998190198626, 58.509613037109375, 61.36084106990269, 62.88306631360735, 67.26918615613664, 59.00184426988874, 31.42239781788417, 1.3979515007563998, 0.08064674359879323, 0.4369886570743152, 3.676430404186249, 1.9874301552772522, 2.4654375570161, 0.7668301750506673, 11.96910411970956, 19.14717517580305, 32.692493779318674, 20.574373381478445, 19.986276115689957, 53.81861318860735, 28.55461743899754, 0.4602284271802221, 0.05643940969769444, 0.050443935341068676, 0.016762423927762678, 0.09071540938956396, 0.038919893359499316, 0.04660191400242703, 0.04325426649302244, 0.04393065055566175, 0.03788359057424324, 0.06136552643563066, 0.03611185760902507, 0.05745676439255476, 0.07603107020258904, 0.040780307458979745, 0.02128716345344271, 0.10524763459605829, 0.0375668775689389, 0.015503831374059831, 0.1427454881902252, 0.011523999573130692, 0.1199262198060751, 0.07017567940056324, 0.02349132508970797, 0.03513577819934913, 0.043057525264365334, 0.04951459342347724, 0.07656165066042117, 0.0443263212884111, 0.026236935618466566, 0.069918860681355, 0.03052492918712752, 0.03258519899100065, 0.07923218128936631, 0.08466947916895151, 0.04621796835479992, 0.04799568260620747, 0.05138250194223864, 0.03710889696542706, 0.015922005720702664, 0.04087232359285865, 0.03616254078224301, 0.044403799809515476, 0.06680340106998171, 0.05172320455312729, 0.01725607002819223, 0.06480773458523409, 0.02101260613250945, 0.049277604890189, 0.046898617010031424, 0.027759812472920333, 0.03002795996144414, 0.03790903563744255, 3.2723980844020844, 71.69397272382463, 53.55290712629046, 27.072254010609218, 38.41330003738403, 45.142369815281455, 12.17399867943355, 81.18439905984062, 10.49624148436955, 0.7796840710299355, 10.798113788877215, 15.40229068483625, 1.5885371140071323, 0.27787458364452633, 44.744533334459575, 89.37184361049107, 71.8969087600708, 84.579587663923, 73.21275860922677, 73.65172495160783, 75.89902945927211, 70.56533513750348, 64.86550549098423, 61.76386438097273, 58.59881401062012, 54.91470193862915, 55.63172476632254, 56.59434904370989, 55.19724348613194, 54.46434055055891, 51.07376207624163, 50.81918007986886, 52.637700830187114, 55.00816910607474, 55.71766356059483, 52.966750144958496, 54.16437292098999, 59.73353821890694, 60.32029969351632, 62.069091796875, 64.05019692012242, 63.130387442452566, 62.655818530491416, 58.99395111628941, 49.94998475483486, 45.93051092965262, 46.29252597263881, 45.95908887045724, 45.06238910130092, 56.089642320360454, 62.48107828412737, 62.0292786189488, 62.71079962594168, 62.780663762773784, 62.91342994144985, 57.729347705841064, 57.66934653690883, 66.18746280670166, 56.946028641292024, 60.86247457776751, 44.56698601586478, 53.65823834283011, 64.04269981384277, 60.322071484157014, 61.3719026020595, 57.445190702165874, 54.59045730318342, 49.82868310383388, 50.52657406670706, 48.34999179840088, 47.64162990025112, 45.36505263192313, 43.94546965190342, 45.01196602412632, 44.705929143088206, 42.64877598626273, 44.54897281101772, 45.02296849659511, 45.180539744240896, 50.845923696245464, 58.904944692339214, 62.25988933018276, 61.416093145098, 60.145218985421316, 59.97733661106655, 59.433237075805664, 60.521144321986604, 61.03087111881801, 57.28465952192034, 58.56075177873884, 59.07161113194057, 59.032423291887554, 58.25609411512102, 46.638594899858745, 44.371967451913015, 43.3037896156311, 47.49842405319214, 52.919620513916016, 53.723148414066856, 51.685488428388325, 53.275677476610454, 54.71583407265799, 54.89651850291661, 61.26485865456717, 65.85652010781425, 65.94115611485073, 70.35536752428327, 58.67047773088728, 36.60863052095686, 1.598806551524571, 0.2092715177152838, 1.4696570187807083, 6.167892873287201, 3.114527629954474, 2.166537127324513, 0.49196828688894, 14.252156240599495, 24.43366343634469, 39.20805583681379, 34.877955845424104, 23.117492233003887, 60.53087180001395, 32.464839526585166, 0.5210932354841913, 0.026180364457624297, 0.0440631073766521, 0.0668383999062436, 0.029601646587252617, 0.03681672317907214, 0.024941237377268926, 0.02341710353669311, 0.06788591548268284, 0.06164986653519528, 0.022123449382239153, 0.02087732999851661, 0.030962614808231592, 0.08151383671377387, 0.06605939420738391, 0.008691114173935992, 0.06614421787006514, 0.045904651417263916, 0.05256981948124511, 0.04645767102816275, 0.060860994937164445, 0.04996381074722324, 0.041826153839273114, 0.016687878374276415, 0.08459672664425202, 0.12621408168758663, 0.10936543292232923, 0.1551681887358427, 0.2166108103202922, 0.11866333042936665, 0.1564427489148719, 0.09145994550947632, 0.15394522435963154, 0.13538175475384506, 0.1497951413371733, 0.16221899539232254, 0.15786442905664444, 0.19046277127095632, 0.13852675099458012, 0.08487267326563597, 0.10398597336773362, 0.1417686284652778, 0.17819956716682228, 0.19083615552101815, 0.12110731857163565, 0.21261902951768466, 0.16116428055933543, 0.13679191337100097, 0.10770078974642924, 0.08168625246201243, 0.13166849900569233, 0.17044577108962194, 0.1839303925101246, 5.673049986362457, 94.67816897800991, 62.1972930090768, 52.38752399172102, 45.28124346051897, 85.10505213056291, 11.681223750114441, 76.47106770106724, 15.277308225631714, 3.8149288466998508, 41.8540028163365, 36.44001163755144, 0.5626847722700664, 0.2863897095833506, 46.00408887863159, 93.68051188332694, 72.69723006657192, 87.25130203792027, 75.98280388968331, 75.61200632367814, 77.66285746438163, 75.48627172197614, 69.01119681767055, 63.17573138645717, 59.845286096845356, 57.977693693978445, 58.53992802756173, 60.18163449423653, 57.38498108727591, 57.85615233012608, 53.14324828556606, 53.74828699656895, 55.765251772744314, 58.8364007132394, 59.2628116607666, 58.07452378954206, 57.40039913994925, 63.87032890319824, 63.53862190246582, 66.90904017857143, 67.42096955435616, 67.74999455043248, 66.95352254595075, 63.968687602451865, 54.01678276062012, 48.944292068481445, 50.650540351867676, 48.96972247532436, 48.14365809304373, 58.875199454171316, 67.50638375963483, 64.46367032187325, 65.42164625440324, 66.85467052459717, 64.82507392338344, 61.12563065120152, 60.34983648572649, 68.35746165684291, 60.07171399252755, 63.315626416887554, 47.040728841509136, 55.81258290154593, 65.73254340035575, 63.50577081952776, 62.44020898001534, 61.62533119746617, 57.40443951742989, 52.50303084509713, 52.57724108014788, 51.72725057601929, 49.921132360185894, 45.179587841033936, 46.45682307652065, 45.71484579358782, 46.05482462474278, 44.62495483670916, 46.6087315423148, 47.250185762132915, 48.33850990022932, 52.5022873878479, 61.14558587755476, 64.92129952566964, 62.50646005358015, 60.72736685616629, 62.45378576006208, 60.49970218113491, 61.83156067984444, 62.95315279279436, 59.36350495474679, 60.09775584084647, 62.32866954803467, 61.310577801295686, 61.493794849940706, 50.0288850239345, 47.27960443496704, 47.57035180500576, 51.32253885269165, 56.9815582547869, 57.09681844711304, 54.70304938725063, 58.053317887442454, 55.76285811832973, 57.93390267235892, 64.18639550890241, 68.23108087267194, 67.17127908979143, 74.01794365474156, 62.94853918892996, 38.86079181943621, 1.501889820609774, 0.3864723763295582, 0.8792929574847221, 9.604884011404854, 8.062709621020726, 7.444493651390076, 3.989694280283792, 14.203702977725438, 30.747873646872385, 49.907499994550435, 32.94632537024361, 33.80681112834385, 68.74874251229423, 52.553870814187185, 0.7133882141539029, 0.2602549291082791, 0.1240231871072735, 0.30568553560546463, 0.20921461576861994, 0.12266125875924315, 0.1624669592295374, 0.09495617861726455, 0.14933274686336517, 0.15337410143443517, 0.12558217559541973, 0.10286016163549253, 0.2007173081593854, 0.10974908340722322, 0.1331411371273654, 0.1758546722786767, 0.08445412572473288, 0.12588450365832873, 0.07822203263640404, 0.18766571421708378, 0.1251679299665349, 0.12543892328228268, 0.128230660621609, 0.09962887609643595], [0.03219757568357246, 0.13171010677303585, 0.028699748018490415, 0.041642369236797094, 0.07217887762401785, 0.059500335449618955, 0.027297541831753085, 0.04023045999929309, 0.03280672710388899, 0.13417597088430608, 0.0240492674721671, 0.16117030595030102, 0.045088943759245534, 0.06670788369540658, 0.025114067031868866, 0.08987597336194345, 0.07541175093501806, 0.0962226235174707, 0.049086098559200764, 0.075836296725486, 0.10370339745921747, 0.11537158063479833, 0.05751810395824058, 0.06154382508248091, 0.2318155180130686, 0.052442933432757854, 0.1469123853104455, 0.11310156208596059, 0.45094734377094675, 0.08706831080572945, 30.891423429761613, 59.25493240356445, 85.63503987448556, 72.33386707305908, 58.68574292319161, 45.57132380349295, 25.02710907799857, 34.12783179964338, 1.072089889219829, 15.895913294383458, 9.198759198188782, 6.4359700083732605, 0.6163247568266732, 0.8494904509612492, 52.88148185185024, 92.89985397883824, 63.97948510306222, 79.53289563315255, 73.29929842267717, 76.62579018729073, 71.50780269077846, 72.52740219661167, 62.98316206250872, 54.89530951636178, 56.18707690920149, 58.812575340270996, 60.567537443978445, 56.402981758117676, 55.22720759255545, 48.30057273592268, 52.51763595853533, 53.786064352308, 52.183997358594624, 49.911109583718435, 56.747153827122276, 54.54141344342913, 58.63169983455113, 60.746974672589985, 64.23068332672119, 58.97267573220389, 63.96911144256592, 62.9495883669172, 64.99376228877476, 55.15957382747105, 48.739945547921316, 41.861496448516846, 46.788516180855886, 42.5384316444397, 53.52316536222185, 59.987237794058665, 61.74991239820208, 58.08860431398664, 60.22635310036795, 55.84588214329311, 53.23893887656075, 60.63606057848249, 60.50857503073556, 54.98224190303257, 58.806217738560264, 34.20667995725359, 44.53162315913609, 62.85138947623116, 57.500776290893555, 57.770095416477744, 56.44290958132063, 55.83383396693638, 51.441943645477295, 49.10960360935756, 46.97383853367397, 47.683635234832764, 44.185258933476035, 43.56472226551601, 42.855078424726216, 42.49810082571847, 41.499675955091206, 43.53263895852225, 43.97185543605259, 44.42623288290841, 48.87611634390694, 54.14363602229527, 60.68134198869978, 60.01377991267613, 59.61003398895264, 61.57606846945626, 58.52529512132917, 57.24342196328299, 57.17565965652466, 57.10350956235613, 57.48012277058193, 55.19908128465925, 56.82567541939871, 54.56976209368025, 49.58667734691075, 39.6712019102914, 41.492995262145996, 42.94191006251744, 50.27039745875767, 51.652411528996055, 55.71181665148054, 52.720641476767405, 54.54800728389195, 56.416384833199636, 58.23074013846261, 61.68252182006836, 66.43501322610038, 63.454819679260254, 49.92040627343314, 4.481928987162454, 0.14470398452665123, 0.1318050745342459, 1.7731740921735764, 2.6453830897808075, 3.4966848492622375, 1.1777694927794593, 0.2444804555603436, 8.338706833975655, 28.447227818625315, 36.65369653701782, 36.27794143131801, 29.65426540374756, 43.90560436248779, 4.019505526338305, 0.6107334654246057, 0.08485661912709475, 0.1264922810452325, 0.06284128581838948, 0.09539605929915394, 0.053781852658305845, 0.10292662414056913, 0.06613165140151978, 0.15701700667185442, 0.04052162616114531, 0.0640826520643064, 0.030122239009610245, 0.16980422980019025, 0.018176285649782846, 0.06274920183100871, 0.030759797298482487, 0.12318355430449758, 0.03691820826913629, 0.05137189983257225, 0.03912705349336777, 0.04589947419507163, 0.03277772990986705, 0.05421876474948866, 0.04155644974006074, 0.030540647450834513, 0.06287719389157635, 0.07261326895760638, 0.09698740712233953, 0.04738100791083915, 0.03828731212498886, 0.053057061907436164, 0.10316047444939613, 0.052301089079784494, 0.07850038805710417, 0.046038729936948845, 0.04895052047712462, 0.048291177821478674, 0.019579903189358965, 0.05884900289986815, 0.06568439504397766, 0.04048791993409395, 0.025913761263447146, 0.05999891619597163, 0.10847922547587327, 0.06835240830800363, 0.03874036317159023, 0.047707576637289355, 0.04529228713363409, 0.10297246596642903, 0.05751849750855139, 0.12407927481191498, 0.09244644043168851, 0.286326632968017, 0.10589452274143696, 40.035186767578125, 68.81408337184361, 70.9170251573835, 68.1447981425694, 75.74730164664132, 29.3308093888419, 42.87503365107945, 35.73683656964983, 1.4260403535195758, 3.2521747010094777, 2.536933000598635, 7.933326346533639, 0.2957792228886059, 1.2549871035984583, 61.28991385868618, 92.00739261082241, 64.48905209132603, 83.64776475088937, 74.862900188991, 79.16152136666435, 74.67632716042655, 75.3649422781808, 62.17730304173061, 56.87950311388288, 58.09045253481184, 60.074583598545615, 61.260627201625276, 56.54858820778983, 55.13137456348964, 52.80310269764492, 54.20213290623256, 54.73695312227522, 54.83177866254534, 54.33464200156075, 56.767348766326904, 57.648800713675364, 60.15567602430071, 63.83334364209856, 65.54315635136196, 65.25253404889787, 67.59549440656389, 66.76540006910051, 65.96846948351178, 58.91301155090332, 49.22300863265991, 45.262062958308626, 50.84565619059971, 46.234293120247976, 55.41079289572579, 62.68070002964565, 63.11447606767927, 62.42116396767752, 63.58149228777204, 62.3601518358503, 59.049522808619905, 64.40723705291748, 64.23206601824079, 60.70411123548235, 63.390479360307964, 38.165211132594514, 50.141369410923545, 65.57050446101597, 61.11368669782366, 60.833952222551616, 59.82173865182059, 56.499863965170725, 53.020414556775776, 50.90976027079991, 50.20776639665876, 50.80541917255947, 46.860975469861714, 45.91542291641235, 44.98468392235892, 44.97450481142317, 43.846867765699116, 44.13636098589216, 45.83750581741333, 45.84526695523943, 50.13551555361067, 55.516513211386545, 62.37356185913086, 62.984600339617046, 60.51263277871268, 62.2588540485927, 61.58008452824184, 59.206475666591096, 60.322210448128835, 58.44121497017996, 60.82836587088448, 59.671198981148855, 61.234703472682405, 58.23424550465175, 53.55283069610596, 42.64539221354893, 46.54282093048096, 45.82827166148594, 53.711690834590364, 54.6658730506897, 58.759595326014924, 55.23709487915039, 57.59959009715489, 59.216800689697266, 61.89652633666992, 62.2510929107666, 68.46029499598912, 63.89616230555943, 54.26747029168265, 4.423164597579411, 0.24717790367347853, 0.24043787962624005, 3.8076970747538974, 3.6248111511979784, 3.1727116278239658, 0.3829482825739043, 0.4336404124540942, 10.861096603529793, 31.612219129289898, 47.03715051923479, 39.05129405430385, 30.703731741224015, 54.45234795979091, 5.024887715067182, 0.44552139778222355, 0.03135874015944345, 0.08259473621313061, 0.04434016001011644, 0.09553047030099801, 0.07733356566833598, 0.12305985737059798, 0.0852374265502606, 0.08865933971745626, 0.05706936839435782, 0.0960779394954443, 0.058585792380784235, 0.11099991521665029, 0.035641123939837725, 0.06362272067261593, 0.05335385312459298, 0.023145424900576472, 0.04667980642989278, 0.02443408334095563, 0.02857889753899404, 0.04076183095042195, 0.0350735429674387, 0.03679551217438919, 0.06912830631647791, 0.14330001414886542, 0.1969293864177806, 0.18276777703847202, 0.1151914567287479, 0.09951021389237472, 0.09693817262138639, 0.12725184671580791, 0.15967001074126788, 0.19410525581666402, 0.20128710115594523, 0.1727410243558032, 0.18080728580909117, 0.15880847482809, 0.10610332153737545, 0.1725152621843985, 0.1873912060899394, 0.08984955120831728, 0.17739907226392201, 0.17055038761879715, 0.13791335533772195, 0.2049468747739281, 0.2924425405051027, 0.22573531498866423, 0.20669034336294445, 0.21378699184528419, 0.31954863028866903, 0.3806462032454354, 0.49867726117372513, 0.6633055444274629, 0.323270991976772, 61.90703201293945, 74.37019647870744, 96.336092540196, 75.43645313807896, 85.37709494999477, 61.91250719342913, 33.6047123500279, 41.33063670567104, 1.833622225693294, 29.88206556865147, 22.489005088806152, 8.52525988646916, 0.5731287832771028, 1.8258359006472995, 60.35452651977539, 99.14185850960868, 66.23940059116909, 84.89427852630615, 78.7557326725551, 81.56042167118618, 75.16185338156563, 78.00461850847516, 65.99341351645333, 60.83555725642613, 61.480530738830566, 62.06538840702602, 64.14273997715541, 60.05303028651646, 60.501355852399556, 55.8719413621085, 57.63602992466518, 59.855875151497976, 58.73435946873256, 57.6127221924918, 62.60791070120675, 60.69368893759591, 64.4092103413173, 67.24245643615723, 68.75371047428676, 68.3859075818743, 70.44939054761613, 70.25871113368443, 69.34435599190849, 61.69760635920933, 54.545738697052, 47.133289269038606, 54.68867009026663, 49.39622374943325, 58.14886256626674, 66.9662446975708, 66.57424122946603, 63.1431999206543, 66.17763805389404, 65.09362179892403, 62.5407007762364, 65.8261912209647, 66.04624761853898, 63.09771006447928, 66.49514988490513, 40.41499267305647, 51.056325571877615, 66.5037795475551, 63.313535009111675, 62.9026254926409, 62.09289632524763, 59.151070731026785, 55.20691885266985, 52.48992306845528, 53.42704050881522, 52.986635889325825, 49.60473224094936, 48.255343437194824, 46.88215357916695, 46.587108748299734, 44.58423144476754, 46.203995500292095, 48.258946078164236, 47.50635889598301, 51.50867414474487, 56.54742438452584, 64.26084545680455, 63.776132174900596, 62.497913769313264, 64.29794883728027, 64.61487007141113, 62.00418867383684, 62.294776235307964, 60.62235178266253, 62.16918059757778, 61.8976936340332, 65.98793138776506, 62.36211122785296, 57.4213410105024, 46.91280208315168, 50.45025505338396, 49.40754236493792, 57.84578561782837, 59.81864670344761, 63.18014349256243, 57.52162783486502, 60.48017079489571, 63.20592130933489, 64.63669436318534, 65.10100078582764, 71.86800425393241, 68.72615391867501, 55.860848563058035, 4.184589947972979, 0.33055680245161057, 0.2414021050291402, 5.337468496390751, 11.351955567087446, 9.91987885747637, 4.828625423567636, 1.0495737088578088, 13.42972663470677, 44.66635915211269, 46.8924195425851, 45.60506772994995, 41.17828355516706, 63.020564215523855, 11.196701543671743, 1.03621330005782, 0.2277772847030844, 0.2556487891290869, 0.16396253183484077, 0.17114183945315226, 0.17210879256682737, 0.20398515995059693, 0.2685607677059514, 0.25671824174267904, 0.13251407577523164, 0.20330711347716196, 0.12143353106720106, 0.33832676123295513, 0.09815802252186195, 0.1285674718341657, 0.1314922156078475, 0.13434145200465406, 0.16919692738779954, 0.09257575563554253, 0.087476687106703, 0.07206669542938471, 0.057972430650677, 0.11404789452041898, 0.139891135639378], [0.01169204555584916, 0.06074548792093992, 0.09432292902576071, 0.04262948841122644, 0.051300816504018645, 0.09915397622223411, 0.04637932058955942, 0.05165715595441205, 0.06306709548724548, 0.0873888371778386, 0.06325799452939204, 0.05157331616750785, 0.026408179197460413, 0.019055784081241915, 0.1159986284162317, 0.022427277007539357, 0.05299859593755432, 0.039145842128034146, 0.04327169805765152, 0.06853802834770509, 0.11343211720564536, 0.11441899889281817, 0.014371190186856049, 0.05793956241437367, 0.1983589104243687, 0.020471888361498713, 0.12206972550068583, 0.04225803120061755, 0.2361079305410385, 0.16151703734483036, 5.997757111276899, 65.98237977709088, 54.51310648236956, 63.92511544908796, 19.887429305485316, 61.71966688973563, 18.565961837768555, 32.854574407849995, 0.2495982109435967, 3.039966945137296, 4.416310633931841, 12.805720210075378, 0.25189472628491266, 0.0509766803256103, 0.34393387607165743, 34.77482720783779, 80.95455265045166, 70.44593034471784, 77.44725486210415, 80.27913911002022, 76.44721453530448, 72.12698446001325, 65.50741481781006, 59.475676672799246, 61.13352380480085, 63.787624495370046, 66.88473537990025, 65.09055764334542, 58.565024920872276, 52.25686659131731, 49.88903863089425, 53.735540526253835, 53.606310980660574, 55.33467885426113, 55.99281917299543, 59.24824823651995, 61.67504555838448, 65.90405968257359, 66.58890192849296, 60.94299030303955, 64.11397443498883, 62.30373246329171, 62.95536231994629, 59.39420209612165, 51.22513553074428, 42.94808006286621, 44.88953529085432, 44.90896940231323, 50.55626024518694, 57.297020367213655, 64.34985188075474, 60.1064132962908, 62.585655621119905, 52.2936920438494, 58.16059112548828, 57.92558567864554, 57.73624031884329, 54.527374608176096, 58.61041750226702, 27.27203730174473, 42.65085349764143, 60.45885372161865, 54.62998213086809, 62.07564394814627, 56.51858588627407, 61.40946456364223, 56.26904828207833, 57.138191495622905, 50.60675627844674, 52.851566382816856, 45.61067492621285, 43.87676933833531, 42.645388739449636, 44.793848173958914, 41.672335215977256, 46.22461427961077, 43.6581130027771, 47.83170829500471, 52.2696339062282, 57.15730946404593, 59.27443599700928, 61.054960523332866, 57.08549983160836, 59.36450549534389, 59.110451562064036, 57.8990227154323, 56.078685011182515, 56.72376619066511, 53.92895058223179, 56.40926987784249, 55.878410134996685, 58.31502873556954, 53.53525175367083, 44.94838653291975, 42.28632320676531, 44.497955662863596, 49.170796394348145, 54.94047628130232, 54.83183077403477, 59.64984021868025, 55.861494745527, 56.99781009129116, 62.97724914550781, 65.37466253553117, 66.4936351776123, 64.81399849482945, 15.203768491744995, 0.7383908725210598, 0.05172929779759475, 1.837189257144928, 4.613294669560023, 4.081313661166599, 0.37997619062662125, 0.7998758075492722, 0.2553043376122202, 15.979375055858068, 40.86499970299857, 51.33462177004133, 105.91915920802525, 47.93165465763637, 42.868359906332834, 0.7286166570016316, 0.18133187480270863, 0.06939668727240392, 0.06983696828995432, 0.024457676003554037, 0.0391177541709372, 0.07722413832587854, 0.046598775777965784, 0.05459357053041458, 0.038974776664482694, 0.031557710375636816, 0.037016840119447024, 0.07002149588827576, 0.1357138297919716, 0.10140364550586257, 0.022981175321287343, 0.05581738646807415, 0.08118901521499668, 0.034667979194117446, 0.032023490739188025, 0.10148248448967934, 0.0696171840120639, 0.05089384816320879, 0.03441917058080435, 0.03470427403226495, 0.05992150213569403, 0.02685123372689954, 0.018301315904994096, 0.03259430493095091, 0.0033070882907070753, 0.009202498876090561, 0.028437360223116617, 0.07065570221415587, 0.07010770376239504, 0.04402662254869938, 0.022398844693920443, 0.018670505112303153, 0.04024477708818657, 0.04555593530780502, 0.004648036123918635, 0.017060585785657167, 0.00740737426427326, 0.038144633173942566, 0.04578549048996397, 0.04398502835205623, 0.013642687849434358, 0.09980579053184815, 0.01443757296406797, 0.07319217467946665, 0.05494666997609394, 0.02465340112602072, 0.07411529443093709, 0.02278764356326844, 0.16632208307938917, 0.07282823563686439, 7.203596566404615, 73.97447572435651, 63.6533088684082, 64.29358536856515, 36.82222161974226, 60.085749353681294, 15.316833053316389, 45.92684922899519, 0.20559951689626488, 0.8412617753658975, 2.5345784298011234, 10.473947320665632, 0.9623249620199203, 0.07336047850549221, 0.3858403345303876, 44.29566928318569, 84.4256294795445, 71.52572209494454, 79.49215834481376, 81.54730347224644, 76.69197872706822, 72.44025094168526, 69.13760539463588, 60.41350282941546, 60.98158754621233, 63.9983355658395, 68.23436737060547, 65.25398622240338, 57.44704587118966, 52.70627955027989, 53.43976960863386, 53.93132339205061, 56.17777674538748, 57.62230723244803, 59.23362922668457, 59.233504159109934, 63.95646572113037, 63.2909950528826, 68.14722306387765, 65.48631313868931, 67.28969029017857, 65.63899980272565, 65.84211649213518, 60.05794961111886, 52.33068077904837, 44.26109504699707, 47.223369189671104, 47.061531748090474, 52.51833077839443, 59.723018646240234, 66.24455615452358, 61.69867638179234, 66.18678883143834, 57.31011077335903, 62.938353129795615, 60.41436440604073, 63.39088930402483, 58.234273297446116, 61.852203777858186, 30.268555641174316, 44.186665943690706, 65.68813051496232, 58.10794115066528, 66.81581619807652, 60.357368332999094, 64.55970137459892, 58.491005761282786, 59.399802344185964, 53.80042280469622, 55.356114046914236, 47.86099147796631, 46.120936734335764, 46.030554567064556, 46.28047432218279, 44.01303046090262, 47.36696413585118, 45.84457213538033, 48.15070356641497, 53.89493220193045, 58.981034415108816, 63.52181421007429, 63.2962965284075, 58.92944404057094, 59.424405915396555, 61.27972779955183, 60.731966563633506, 59.33301625932966, 60.12026800428118, 57.400350502559114, 58.08722857066563, 59.84215245928083, 61.480461256844656, 57.623290402548655, 48.427182810647146, 45.417358670915874, 48.16992923191616, 54.56824391228812, 57.65412998199463, 58.905236516680034, 62.28110218048096, 59.30207593100411, 59.4780946459089, 65.93957887377057, 67.82538250514439, 67.88792324066162, 65.49521378108433, 18.786579302379064, 0.6446220012647765, 0.22010844121021883, 4.102283758776529, 4.770463790212359, 2.854922954525266, 0.8250074961355754, 0.2179431952536106, 0.6950490953666824, 18.19032311439514, 49.73884637015206, 53.648587294987266, 84.72885581425258, 50.101299149649485, 50.4762795312064, 0.9589959063700267, 0.18066511915198394, 0.03207167351086225, 0.04984752341572728, 0.02911274175026587, 0.027272139176992432, 0.04408010467886925, 0.0837485103734902, 0.030895008971648555, 0.019895170915073583, 0.05460151956815805, 0.030100973722125803, 0.044715274524475844, 0.10603751721126692, 0.057720477027552466, 0.03512351367888706, 0.013309624694686915, 0.028731337216283594, 0.05893687318478312, 0.055096870487821956, 0.08942820810313735, 0.07290788886270352, 0.02695596730336547, 0.01775701716542244, 0.04251025623774954, 0.14807106527898992, 0.10922973270394973, 0.15483299243663037, 0.09929837525955268, 0.15844867484910147, 0.10916621504085404, 0.13007847432579311, 0.08885102586022445, 0.13724202636097158, 0.16762565741581575, 0.11266094858625106, 0.09260743643556323, 0.13982028301273072, 0.08828625402280263, 0.1999014647943633, 0.08353107382676431, 0.12164201773703098, 0.09504850687725203, 0.1564381755888462, 0.07633303864193813, 0.15685349330306053, 0.1505462931735175, 0.07241688056715898, 0.1639912745782307, 0.23341175807373865, 0.10983026333685432, 0.13507181352802686, 0.09938553986804825, 0.3570932756577219, 0.19912625210625784, 12.527198195457458, 100.24274499075753, 65.69810812813895, 73.76845468793596, 28.496363742010935, 85.75457668304443, 24.715194020952495, 42.32352386202131, 0.1874967725681407, 4.8206206645284375, 15.988247905458723, 22.844699008124216, 0.3194530111338411, 0.11973618928875242, 0.656615677688803, 42.51464101246425, 88.91026088169643, 71.08487973894391, 81.80830560411725, 85.4620714187622, 81.10048566545758, 77.98273863111223, 71.60566111973354, 66.34763268062046, 63.940665517534526, 67.89312744140625, 74.98700196402413, 69.434647832598, 63.11020292554583, 59.01929119655064, 55.85088832037789, 57.93694598334176, 60.66891166142055, 60.74498053959438, 62.141443388802664, 62.765461104256765, 67.94015284946987, 67.52390711648124, 70.55690002441406, 68.45604269845145, 70.05122402736119, 68.38171781812395, 68.07271753038678, 64.35329123905727, 55.71589176995413, 48.47864811761038, 50.66037205287388, 51.0647155216762, 55.37259864807129, 62.247424261910574, 70.57720960889543, 65.6017644064767, 66.61479786464146, 62.00416782924107, 65.92915657588414, 63.12792778015137, 66.94155774797711, 59.33148765563965, 64.01880495888847, 32.49401501246861, 47.50600453785488, 64.42085552215576, 57.75818272999355, 68.11141204833984, 62.38942459651402, 65.84137303488595, 61.472081729343955, 61.83752223423549, 56.25383520126343, 58.37943853650774, 50.79127958842686, 47.18424040930611, 48.01782274246216, 48.27670567376273, 45.35742698396955, 50.24398735591343, 48.07327284131731, 49.86075251443045, 56.356599058423726, 61.099748611450195, 66.01691927228654, 65.3802488871983, 60.25238800048828, 61.6909430367606, 63.39111859457833, 62.37210273742676, 62.2643153326852, 61.55086040496826, 58.664266041346956, 59.97294534955706, 62.62708078111921, 64.85802922930036, 62.6486827305385, 52.829064641680034, 49.84593548093523, 52.47483852931431, 57.588740485055105, 60.75729969569615, 60.971901757376536, 66.26477541242326, 61.764677320207866, 60.98426260266985, 67.87675053732735, 71.97824437277657, 72.36299392155239, 67.85603100912911, 20.007416009902954, 0.8514067967023168, 0.282492638698646, 4.75797918013164, 16.470960106168473, 10.915101477078029, 4.295650388513293, 4.634953073092869, 0.7591627293399402, 24.995223794664653, 58.83892985752651, 60.45737375531878, 108.03411442892892, 58.1023964881897, 64.05945886884416, 1.683331930211612, 0.3319637312420777, 0.11057810392230749, 0.08458491334957735, 0.06380460198436465, 0.1993839189942394, 0.1683515813201666, 0.202610366578613, 0.12904944882861205, 0.11270154533641678, 0.29129793335284504, 0.08959940248834235, 0.18957982079258986, 0.27461373433470726, 0.2004493275391204, 0.14736555170800003, 0.11572923644312791, 0.14347944594919682, 0.17275775702936308, 0.13057759111481054, 0.17669050528534821, 0.19653969018587045, 0.1483633510236229, 0.09483904311699526, 0.12524038393582615], [0.05634495423042348, 0.009760106231884232, 0.08941891217338187, 0.11569761671125889, 0.05133311137823122, 0.009081087757035025, 0.04698279267176986, 0.02032615939554359, 0.17021247717951024, 0.042921278825295825, 0.036601664897586615, 0.03913393723113196, 0.005737377447076142, 0.06001019344798156, 0.0976698776440961, 0.029717859279896532, 0.04263473687959569, 0.046865043097308705, 0.018742210996736373, 0.02913837680327041, 0.022396632669759647, 0.08934832417539187, 0.046117070197526894, 0.14178739674389362, 0.023024667719645158, 0.07394328580370971, 0.11834390328398772, 0.15398049460990088, 0.08909131546637841, 0.1313849799335003, 0.4914911410638264, 16.219820942197526, 60.078168869018555, 43.168063504355295, 35.39825432641165, 53.03072220938546, 54.00952189309256, 22.027272973741802, 2.641617166144507, 0.7073676000748361, 2.8335316223757605, 2.21367392369679, 1.6955114709479469, 0.5097866164786475, 0.09550724404730968, 0.324572286435536, 18.90117941583906, 75.1721784046718, 74.23714542388916, 81.4077627999442, 76.00289113180978, 79.68431077684674, 68.94247913360596, 62.44658742632185, 64.62179742540631, 69.9609738758632, 67.05753013065883, 67.70379597800118, 63.55663858141218, 55.558323996407644, 54.66867664882115, 54.66105794906616, 54.27089922768729, 55.5591265133449, 60.50050817217146, 63.74732494354248, 62.50049155099051, 66.88891124725342, 63.937121936253135, 62.05540384565081, 64.87718541281563, 62.71258531297956, 63.63376358577183, 60.99196120670864, 53.82637432643345, 43.24361474173409, 46.351943492889404, 42.83199998310634, 47.91886649812971, 56.195161138262065, 62.32580689021519, 60.86282893589565, 58.92414256504604, 53.91084010260445, 54.55410780225481, 57.57272836140224, 61.285710198538645, 53.20339189256941, 59.683059556143625, 23.087460381644114, 39.4737480027335, 57.886769567217144, 52.96832391193935, 62.57857540675572, 58.99840491158621, 62.397484506879536, 59.61810084751674, 63.37445681435721, 55.51841354370117, 55.90409762518746, 48.78521653584072, 43.889543601444785, 43.73009634017944, 43.71385145187378, 43.49543482916695, 44.234413964407786, 43.26176691055298, 47.902541705540244, 50.194689886910574, 54.31935943875994, 59.54681927817208, 61.18640654427664, 58.6731458391462, 55.94328546524048, 56.5602959224156, 56.734660966055735, 57.09242371150425, 58.32767445700509, 58.37015574319022, 56.40862716947283, 56.37723868233817, 55.253742762974326, 54.207580293927876, 47.05085931505476, 42.449435642787385, 45.24191665649414, 47.25142254148211, 53.80057566506522, 58.82622160230364, 56.8854855128697, 58.35666234152657, 61.92349924360003, 62.065999848502024, 66.44713088444301, 67.41789845057896, 22.454957178660802, 1.3481336768184389, 0.08092549256980419, 0.7070566139050892, 2.7564756657396043, 3.9037884899548123, 1.3110606947115488, 1.066899259175573, 0.38113512843847275, 1.43778943164008, 37.23495503834316, 38.681104455675396, 36.17859608786446, 34.99174649374825, 45.95693145479475, 19.893981456756592, 0.3274482435413769, 0.00313187697819168, 0.08718705443399292, 0.06895593128034047, 0.047441607873354635, 0.019029261843700494, 0.03773351219881858, 0.03136635671502777, 0.08908172098121472, 0.008523859532683023, 0.1190124231257609, 0.02668652104746018, 0.10018663188176495, 0.08134796204311506, 0.08914503508380481, 0.07777269317635468, 0.03752629778214863, 0.07884401176124811, 0.04377233815778579, 0.046016935392149856, 0.07097215737615313, 0.0645310687167304, 0.006003110844176263, 0.1015194985749466, 0.0526105858651655, 0.029184669854917696, 0.00963237286279244, 0.07826111625347819, 0.08702237398496696, 0.06270809617957898, 0.011545566808698433, 0.05617073357903531, 0.010092448443174362, 0.05116208662678089, 0.035714025742241313, 0.046941089909523726, 0.05533291246475918, 0.05132501645545874, 0.05089891681979809, 0.06735195592045784, 0.07451164709138018, 0.02335991830165897, 0.014024038100615144, 0.04562058951705694, 0.06728388528738703, 0.049799398319529634, 0.06106070136385305, 0.028786257840692997, 0.08139716940266745, 0.015480754398075598, 0.06172131627265896, 0.04465131242094295, 0.10324018195803676, 0.06832819139318806, 0.1900405189288514, 0.6557477499757494, 21.911564622606548, 73.13054057529995, 44.76034048625401, 28.668267386300222, 74.383453641619, 44.12727621623448, 25.313376596995763, 2.810532867908478, 0.7649468875357083, 3.3829927785055975, 3.039608895778656, 3.2351160049438477, 2.648845681122371, 0.3940876562680517, 0.27878914028406143, 25.30884289741516, 80.74880954197475, 75.36442811148507, 82.07387965066093, 77.60399232591901, 79.61628791264125, 68.72179739815849, 62.80066762651716, 67.21967329297746, 70.94082273755754, 68.57493332454136, 68.8346917288644, 63.55798653193882, 56.97873728615897, 55.252832548958914, 56.30977514811924, 55.94261843817574, 58.05209847858974, 60.22815268380301, 64.85877963474819, 64.69952692304338, 68.30426624843052, 64.55137743268693, 65.51646832057408, 67.19258226667131, 64.89309678758893, 68.34874861580985, 64.57155500139508, 57.06269931793213, 47.07761335372925, 49.1048857825143, 46.70750365938459, 52.08889389038086, 58.87126677376883, 66.82311875479562, 62.71656663077218, 63.28165667397635, 58.19604778289795, 59.29746232713972, 61.14045115879604, 64.89452116830009, 59.69000775473458, 64.53721005575997, 25.75248190334865, 43.879545143672395, 61.4884933744158, 54.48236765180315, 67.5319183894566, 61.815322739737375, 65.81747123173305, 62.18547412327358, 65.17872333526611, 59.04803589412144, 58.995799337114605, 51.62772110530308, 47.40784733636038, 45.511524132319856, 47.012112685612266, 46.47972086497715, 47.2820189339774, 45.3964341708592, 49.78890119280134, 52.19710513523647, 57.54994869232178, 60.21960639953613, 62.732644762311665, 59.4846259525844, 56.49861676352364, 59.746197836739675, 62.6801233291626, 58.441638810294016, 60.58879893166678, 60.35082312992641, 59.961050033569336, 60.384181431361604, 58.82217080252511, 58.12011439459664, 50.13815239497593, 45.92907265254429, 48.52595145361764, 51.002386706215994, 58.30466202327183, 62.605395453316824, 61.301642417907715, 62.533356530325754, 66.11382579803467, 65.12663963862828, 67.62138339451381, 68.0103782926287, 25.77931932040623, 1.3099309610469, 0.11769461312464305, 1.5571527523653848, 3.1885183453559875, 2.875131355864661, 1.5993898745094026, 0.5335999386651176, 0.14252585997538908, 2.1382531821727753, 45.25849505833217, 48.844630581992014, 41.35597331183297, 35.84891101292202, 54.563852650778635, 23.369402647018433, 0.24946508237293788, 0.028270722200561847, 0.05864466207900217, 0.07021130248904228, 0.03519017295911908, 0.012565058888867497, 0.07723207040024654, 0.009621229621448686, 0.13744270987808704, 0.030783359427005053, 0.10244502034038305, 0.05083690211176872, 0.15902371970670565, 0.08622331079095602, 0.05670813670647996, 0.12157856114208698, 0.08708936574735812, 0.08291079103946686, 0.07896003446408681, 0.016295060881280472, 0.01957849522919527, 0.02827519374633474, 0.025228079574714814, 0.06557299316461597, 0.06438479013741016, 0.13023820146918297, 0.2930055074393749, 0.09576069044747523, 0.1292311605066061, 0.12226313512240138, 0.07642472229365792, 0.14949175475963525, 0.08259823066847664, 0.2785736918449402, 0.1342910232820681, 0.10569859575480223, 0.14793837097074303, 0.12637186822082314, 0.13301342326615537, 0.15984850616327353, 0.12119710232530322, 0.10062084679624864, 0.1333001178822347, 0.12586018496326037, 0.12156769101108823, 0.09631543353732143, 0.21579187283558504, 0.15044269444687025, 0.3091666916651385, 0.14826594053634576, 0.1879770667957408, 0.18912016760025704, 0.33964184352329796, 0.304145342537335, 0.4911653356892722, 0.8145001370991979, 41.87760237285069, 85.43467467171806, 61.66553347451346, 49.25225012642996, 69.92375237601144, 76.29545892987932, 30.215356758662633, 3.376303617443357, 1.0487463303974696, 9.330409322466169, 7.845208423478263, 5.548869175570352, 1.1445674172469547, 0.20953090808221272, 0.31960684859326904, 24.788360289164952, 84.33199555533272, 77.22220965794155, 84.02760192326137, 81.80003724779401, 82.73818302154541, 70.76957743508476, 67.05304159436906, 68.16228675842285, 75.41094630105155, 70.75946780613491, 72.66782529013497, 65.5992213657924, 60.752290044512065, 58.703120367867605, 61.13291236332485, 60.740978377205984, 61.07258810315813, 65.23223836081368, 67.49942166464669, 68.22511237008231, 70.39489582606724, 70.9754456111363, 69.5580825805664, 70.3925473349435, 68.11109243120465, 70.2461279460362, 69.23458140236991, 61.33905846732003, 50.39097997120449, 53.97528811863491, 50.28587804521833, 54.921813419886995, 60.9995972769601, 69.73904841286796, 65.92336177825928, 65.08110809326172, 60.43504919324602, 59.277152742658345, 63.847754205976216, 68.72859968457902, 63.0108436856951, 66.52932112557548, 28.948899916240148, 44.12107842309134, 63.58148533957345, 57.34584188461304, 68.6213264465332, 63.83216939653669, 67.82989883422852, 65.9689280646188, 69.3693208694458, 62.37913431440081, 63.36559786115374, 54.32279184886387, 49.62294694355556, 49.0398610660008, 48.67677252633231, 49.35624034064156, 49.54694059916905, 48.33479956218174, 51.58883898598807, 54.85090357916695, 59.729028838021414, 63.487622124808176, 64.90512411934989, 61.83277661459786, 58.620575768607004, 61.75745119367327, 63.90629277910505, 61.639616693769185, 64.23771490369523, 63.32644476209368, 62.504973139081685, 63.732038906642366, 63.03450925009591, 62.75389930180141, 55.613145283290315, 50.30936295645577, 52.45026275089809, 53.536193234579905, 62.489777428763254, 65.77362809862409, 62.554152488708496, 67.99543271745954, 67.95107541765485, 66.4799611227853, 70.40337262834821, 70.93273503439767, 26.911111388887676, 1.2897939958742686, 0.14773599111608096, 1.1324511702571596, 9.090945737702505, 11.536134072712489, 5.24104791028159, 3.2199289798736572, 0.41060813835689, 2.5692375642912726, 55.909590176173616, 51.17060259410313, 48.621496132441926, 49.798131874629426, 61.52291475023542, 37.2129396711077, 0.33467073312827517, 0.1396610037024532, 0.22458458745053836, 0.17208978001560482, 0.11192771685974938, 0.09827078825661115, 0.18394005484879017, 0.12999322318605014, 0.18143217584916524, 0.2351486991558756, 0.1597434010888849, 0.12072649757776942, 0.25448597009692875, 0.23436062144381659, 0.10509579202958516, 0.16551134229770728, 0.10617832001298666, 0.1941194236278534, 0.14389887558562414, 0.11346195239041533, 0.07506030372210912, 0.20332372401441845, 0.09621720880802188, 0.15337989612349442, 0.15867204857724054], [0.02284653701021203, 0.0672807843823518, 0.09272050751107079, 0.1385151209043605, 0.07416904797511441, 0.03625532026801791, 0.03926892498774188, 0.03588792748217072, 0.03171766143558281, 0.04396038735285401, 0.024129020781921487, 0.007865163181642336, 0.06878539507410356, 0.09837465161191565, 0.03323712865156787, 0.03886976997767176, 0.07782594460461821, 0.05594051343255809, 0.042065256009144444, 0.023406477678301077, 0.03266170720702835, 0.02307730507371681, 0.046006397743310244, 0.01725208024228258, 0.030522327005331005, 0.016946244153327177, 0.0745628425585372, 0.07469414586999587, 0.10246003632034574, 0.01878092311588781, 0.16776713196720394, 0.6005447464329856, 56.928588662828716, 69.5772318158831, 52.31220204489571, 26.71723232950483, 53.35297966003418, 28.627806288855417, 1.9311321590627943, 0.1839573167796646, 2.145268691437585, 2.355281033686229, 4.403737434319087, 2.360626586845943, 0.5804347598126957, 0.33842520309346064, 0.14089357613452844, 23.526077577045985, 82.67548247746059, 79.03735705784389, 82.68921906607491, 73.33635316576276, 76.90360695975167, 69.55062716347831, 73.53928920200893, 65.18439306531633, 73.25403090885708, 69.37779072352818, 70.83682210104806, 59.90515177590506, 53.67752306801932, 53.99656350272042, 55.42300435474941, 62.85546112060547, 62.769671712602886, 66.56802259172711, 68.84125082833427, 70.06987994057792, 66.94207886287144, 60.399147851126536, 63.721679142543245, 59.71765463692801, 63.538941519601, 65.63633169446672, 55.98710775375366, 45.16896057128906, 45.905639852796284, 44.55989190510341, 43.812307425907676, 50.65808262143816, 59.9453957421439, 63.03534998212542, 63.88363470349993, 61.10926764351981, 58.08197920663016, 51.30327844619751, 65.4802473613194, 54.4203063419887, 66.17818696158272, 26.368479660579137, 34.293928486960276, 62.41398647853306, 53.840493065970286, 61.42229093824114, 57.72189923695156, 62.3135780606951, 57.54580061776297, 61.73337568555559, 58.95672961643764, 59.79263959612165, 49.306421756744385, 44.066201550619944, 43.76464625767299, 44.457951409476145, 43.69856888907296, 44.75116539001465, 44.44077198845999, 47.1676481110709, 50.04692254747663, 53.738368443080354, 56.84837518419538, 59.21648802076067, 57.88614075524466, 56.72299146652222, 54.64584834235055, 56.582519735608784, 56.46244444165911, 56.15488937922886, 53.16527754919869, 55.64193514415196, 55.76108285358974, 57.580010073525564, 57.265524183000835, 52.21543448311942, 43.171416010175435, 45.16127238954817, 45.97176585878645, 52.9249393599374, 54.70113863263811, 62.59001908983503, 63.01264326913016, 60.83514731270926, 66.16446426936558, 65.84308923993791, 36.2089284488133, 1.4468040679182326, 0.13891707147870744, 0.250479410801615, 1.3094379646437508, 3.467216019119535, 1.1650073890175139, 1.280219595347132, 0.2303470325257097, 0.03841772655557309, 10.250527994973318, 48.98873274666922, 20.972937686102732, 12.019958853721619, 35.26545688084194, 49.80277674538748, 3.124870674950736, 0.389143985829183, 0.00749588237210576, 0.16066592372953892, 0.051692270141627104, 0.01718911049621446, 0.025455495675227473, 0.08154739705579621, 0.09621702560356685, 0.030556199473461935, 0.03337932923542602, 0.05432297076497759, 0.053353544391159496, 0.052862990714077435, 0.05696680782628911, 0.06288686980094228, 0.07451409660279751, 0.07930358352937869, 0.08504536721323218, 0.04261525613921029, 0.12149725907615253, 0.1319327341126544, 0.028109441211979305, 0.02168802497908473, 0.043889263312199285, 0.07875863169985158, 0.04595365182363561, 0.03646604949608445, 0.03536469555859055, 0.035581446784947596, 0.025143568038142154, 0.029503798444888422, 0.03507049295252987, 0.09294866491109133, 0.0315893470708813, 0.031658113202346225, 0.03394655058426516, 0.041857413947582245, 0.06299336587211915, 0.03540158411487937, 0.009818897050406252, 0.03464386405955468, 0.06418901242847953, 0.045809110293963125, 0.035763433269624195, 0.058571821344750266, 0.019572890529941236, 0.05970895104110241, 0.024078799012516226, 0.0764402471748846, 0.045390230270900896, 0.05276149544598801, 0.03469903574192098, 0.01779747990492199, 0.044551398139446974, 0.09841916350913898, 0.019321444111743143, 1.4842833025114877, 67.38578387669155, 78.12434986659459, 42.10889400754656, 37.82797336578369, 69.48048509870256, 32.23789051600865, 3.1717464796134403, 0.19810551830700465, 0.6247173664825303, 1.1304019945008414, 3.1258955342429022, 3.504376287971224, 2.416890493461064, 0.2733747022492545, 0.26681980969650404, 29.773305416107178, 86.84791047232491, 76.90166841234479, 84.28312192644391, 73.9430490221296, 79.15704672677177, 68.97908919198173, 72.49721922193254, 67.79790237971714, 76.49596309661865, 72.53433649880546, 71.59834466661725, 60.94050979614258, 54.64789111273629, 55.32953718730381, 58.51116248539516, 62.63694027491978, 65.91837297167096, 69.93369524819511, 68.47899954659599, 70.45563697814941, 68.26719760894775, 63.789576939174104, 64.5795384815761, 62.626226152692524, 66.70181015559605, 68.42034980228969, 58.073641368321006, 47.588229519980295, 48.255934034075054, 46.007316316877095, 48.14529439381191, 54.677962916237966, 63.80573150089809, 66.3311585017613, 65.35891096932548, 65.17566612788609, 62.14720344543457, 55.59473603112357, 69.11658709389823, 56.25318207059588, 68.50108786991665, 26.986033814293997, 38.60699496950422, 67.28623008728027, 56.72385651724679, 64.77286515917096, 59.85695212227957, 67.09512683323452, 60.232085364205496, 65.47243063790458, 61.58683817727225, 64.52971294948033, 51.27162592751639, 45.14112261363438, 44.79388986315046, 46.463465554373606, 44.56636415209089, 48.049798352377756, 45.26844140461513, 50.44522455760411, 53.16333900179182, 55.72182553155081, 59.08602169581822, 64.15990897587368, 58.869599206107004, 58.46866730281285, 56.860399041857036, 59.491087777274, 60.4910169328962, 61.66234425136021, 55.23797035217285, 57.136777537209646, 58.52544798169817, 61.05410589490618, 61.14789267948696, 55.732838426317485, 46.79035745348249, 49.62924895967756, 50.319528170994346, 56.34625666482108, 58.23558303288051, 65.82790742601667, 65.59150886535645, 63.79676832471575, 68.4086559840611, 68.98441846030099, 37.29100268227713, 1.7857020199298859, 0.15846983157098293, 0.5204692546810422, 1.2442676616566521, 1.9662948208195823, 0.5129929929971695, 0.9097388237714767, 0.7970266661473683, 0.03163591153653605, 15.847725800105504, 58.687257630484446, 33.54198748724801, 18.638780696051462, 41.89785984584263, 57.03355162484305, 3.8098922712462286, 0.29839483967849184, 0.051894317514130046, 0.07445492834917136, 0.019946666633976356, 0.07827954526458468, 0.05023154030953135, 0.11944158295435564, 0.054551599746836085, 0.0825063366709011, 0.04691247269511223, 0.02921988582238555, 0.04704179468431643, 0.07238175280924354, 0.08688267040997744, 0.06550807771938187, 0.07262723320829016, 0.06655059249273368, 0.08723719138652086, 0.005755547766706773, 0.1343423476708787, 0.0815765740615981, 0.009298161287525935, 0.034189432194190364, 0.07028288793350969, 0.03554889406742794, 0.10499338073922054, 0.10439590351389987, 0.15553965951715196, 0.17425923288932868, 0.1370581705123186, 0.1140396978173937, 0.15690268709191255, 0.11757823079824448, 0.19718385062047414, 0.08036693611315318, 0.1194287993546043, 0.1314472287361111, 0.12691370557461465, 0.12487510139388697, 0.15581466976021016, 0.18960618866341455, 0.1773831538323845, 0.14906699183796132, 0.13262326563043253, 0.1078458469627159, 0.18335791251489095, 0.33056459203362465, 0.11454200372099876, 0.1602777609867709, 0.0864430543567453, 0.12527416140905448, 0.18031038104423455, 0.1761216622378145, 0.13022811843880586, 0.1742275995867593, 0.2736494546490056, 2.018827110528946, 93.38680458068848, 84.90687561035156, 73.1259547642299, 37.43623045512608, 71.09050777980259, 42.14007404872349, 5.299657268183572, 0.36590351004685673, 5.106249383517674, 10.709850822176252, 16.363311665398733, 4.438745498657227, 1.2279727246080125, 0.37870173901319504, 0.30448537000588005, 30.680667196001323, 89.11560794285366, 79.29719884055001, 86.23708043779645, 78.47162778036935, 83.983460017613, 72.31236239842006, 78.48033387320382, 68.66754586356026, 79.51377419063023, 75.93551445007324, 74.7432313646589, 64.45717375619071, 58.83521951947893, 58.988844190325054, 60.45608139038086, 66.92732783726284, 69.98962129865373, 73.80766337258476, 74.31934261322021, 72.03826291220528, 71.47843265533447, 66.75688852582658, 68.9318414415632, 65.43349293300084, 68.51253155299595, 73.2413296018328, 62.46485424041748, 52.199182646615164, 52.616710322243826, 48.912726402282715, 50.63713032858712, 56.60660566602434, 65.97800936017717, 68.38415663582938, 70.17399174826485, 65.20699555533272, 64.07329968043736, 59.06646251678467, 70.32776233128139, 58.04518502099173, 68.980867930821, 30.588798114231654, 39.55292272567749, 69.33939497811454, 58.90055343082973, 65.44608306884766, 61.75897284916469, 67.73054654257638, 62.777175767081125, 65.79925305502755, 63.8870393208095, 65.80253260476249, 54.134853499276296, 46.5868308203561, 48.60596343449184, 49.256436416081016, 46.82903112683977, 49.429964201790945, 46.668239389147075, 51.371516704559326, 55.067676952907014, 57.010723318372456, 60.923750741141184, 66.45149435315813, 61.58246776035854, 60.92776679992676, 59.569873401096885, 62.81003379821777, 63.74549061911446, 64.89363179888043, 58.62362602778843, 57.98714671816145, 62.806219237191335, 66.56922463008335, 64.86478287833077, 59.24179336002895, 49.47127819061279, 54.500394753047395, 53.995556013924734, 59.839581625802175, 63.86088630131313, 69.77445643288749, 68.78828471047538, 67.0483307157244, 71.83855778830392, 71.00431537628174, 38.220713342939106, 2.413963999067034, 0.18924029543995857, 0.3126455135643482, 4.061840031828199, 8.776674372809273, 4.9033602476119995, 4.832347920962742, 1.9240621498652866, 0.14056147395500115, 16.089476210730417, 68.64317158290318, 29.8599077633449, 26.156219141823904, 49.20337997164045, 76.08777727399553, 7.197262414864131, 0.6070368066430092, 0.11488148836152894, 0.4002871864608356, 0.1543982143380812, 0.17742094823292323, 0.09991208304251943, 0.1515294768448387, 0.10097547633839504, 0.16176310128399304, 0.08106460581932749, 0.1807157921471766, 0.1397561885948692, 0.1408090985247067, 0.128982097442661, 0.1336951745407922, 0.19298048902835163, 0.15953893134636538, 0.17018119671515056, 0.09643387182482652, 0.17260868288576603, 0.2145962534206254, 0.10958393476903439, 0.15363083194409097, 0.13478810446602957, 0.13053425986851963], [0.02884320728480816, 0.04254349766831313, 0.025402671724025692, 0.050472803613437076, 0.051242299644010406, 0.026567321104396666, 0.048478124397141595, 0.057944312159504206, 0.17400917916425637, 0.028485405591449568, 0.0524967785791627, 0.02754463205513145, 0.03627020054097686, 0.06486043640013252, 0.06991465376423937, 0.010469896269829145, 0.0323626734316349, 0.06255586006279502, 0.04002014807026301, 0.05563572228753141, 0.00903499826589333, 0.012266872434078582, 0.1225513360862221, 0.017203264736703465, 0.06787562889180013, 0.07628226386649267, 0.08263463407222714, 0.036025693839682, 0.1240616464721305, 0.09241617776985679, 0.19474928054426396, 0.5552122018166951, 12.667583073888506, 71.54369708469936, 60.07365948813302, 38.69334718159267, 37.52461501530239, 49.502312319619314, 12.32009150300707, 0.03217463441459196, 0.1558484472334385, 2.096593520471028, 0.2416145679141794, 10.656176856585912, 2.3268846145698, 0.259770889367376, 0.2370570653251239, 0.09518480420644794, 27.164781434195383, 85.2968224116734, 81.42648819514683, 87.21136379241943, 80.6856643131801, 74.12692614964077, 71.94260011400495, 74.12875352587018, 77.36515494755336, 72.8648762021746, 74.0210633959089, 71.19547421591622, 63.98723234449114, 62.30793612343924, 62.791718346732004, 61.697258949279785, 69.65295328412736, 66.99666391100202, 72.9451070513044, 66.63495458875383, 63.23215075901577, 59.13716043744768, 64.14353901999337, 59.932388714381624, 65.94379643031529, 64.84062399183, 59.141725403921946, 45.46248027256557, 48.02487168993269, 43.97165393829346, 46.703998293195454, 48.51505667822701, 59.99336610521589, 60.011077063424246, 67.09965011051723, 59.754403659275596, 69.47984586443219, 56.85185623168945, 62.06264386858259, 58.07955081122262, 66.65140792301723, 22.099777426038468, 35.5541684286935, 66.08481012071881, 54.923091888427734, 66.27164023263114, 59.505672046116416, 62.784652028764995, 57.792357444763184, 61.91207640511649, 57.4769161769322, 61.201115880693706, 48.39168446404593, 45.42288596289498, 43.635857922690256, 45.052623408181326, 45.12256744929722, 45.15935468673706, 42.50377402986799, 46.41757270268032, 46.80546631131853, 51.26269749232701, 53.42651244572231, 57.99676302501133, 58.52036190032959, 58.98471696036202, 55.92801332473755, 56.365183557782856, 56.1383352960859, 57.750657830919536, 58.94728701455252, 55.69809743336269, 54.92407505852835, 57.18416077750069, 56.6192444392613, 54.193190574645996, 48.220355783190044, 48.10675621032715, 48.435843740190776, 52.74735730034964, 58.15567874908447, 59.496291978018625, 62.927771023341585, 67.14359746660504, 55.58134685243879, 42.37974521092006, 3.8746998565537587, 0.1869510811354433, 0.18351986525314196, 0.5327670233590263, 2.198674499988556, 1.591859330024038, 0.6820294739944595, 0.5104897958891732, 0.30792250271354404, 3.8044036286217824, 37.293563093457905, 44.407920905521934, 18.316047293799265, 34.81396641050066, 46.69369758878435, 11.757140636444092, 0.2340532722217696, 0.01876273668105049, 0.0643238237659846, 0.08198338973202876, 0.07908401638269424, 0.043823618441820145, 0.03223054909280368, 0.023656229455290095, 0.09464204404503107, 0.05039867026997464, 0.038481274752744606, 0.04834410694560834, 0.14076291743133748, 0.01521663973107934, 0.02292361858833049, 0.004045875734716121, 0.10195932497403451, 0.11109843850135803, 0.053126767809901915, 0.05969282904905932, 0.08300394032682691, 0.013625477656855114, 0.12663763681692736, 0.06793373863079719, 0.023166065935843756, 0.10434765967407397, 0.08441975114068814, 0.05723629479429551, 0.09144004407737936, 0.04457460742975984, 0.07568914283599172, 0.049275009493742666, 0.033869367225893905, 0.12529607809015683, 0.0832120877291475, 0.0686282938612359, 0.022013770981824825, 0.027605678154421703, 0.09340299838887793, 0.06676050408610276, 0.06322098044412476, 0.02765826292202941, 0.04549240407400897, 0.03779204941487738, 0.06826014111616782, 0.011689232180028089, 0.05292091385594436, 0.058410676063171456, 0.07066819404384919, 0.04091219091787934, 0.07314813775675637, 0.007066125856778983, 0.040370160181607516, 0.034314065506415706, 0.16952744179538318, 0.14401470151330742, 0.10046348774007388, 0.6159258868013109, 15.529458352497645, 85.62462452479771, 59.03712027413504, 32.82265090942383, 54.153717858450754, 56.41308443886893, 17.559027160917008, 0.09091953986457416, 0.593525057392461, 2.1318914549691335, 0.6508655005267688, 3.943533488682338, 4.743317178317478, 1.0974821895360947, 0.35701139005167143, 0.11063766572624445, 36.30152709143502, 84.7975526537214, 81.88250541687012, 91.1971492767334, 81.23688575199672, 74.42840153830392, 75.09738799503872, 74.70804568699428, 77.63216727120536, 74.15680340358189, 76.84001009804862, 72.53462137494768, 64.74138981955392, 60.60520362854004, 64.48259026663644, 64.06899179731096, 69.75812816619873, 68.05835560389927, 72.85896328517369, 69.46969454629081, 66.13904775891984, 61.42609855106899, 66.0877353123256, 61.68538447788784, 68.76918411254883, 69.80766882215227, 60.71438067299979, 48.28306327547346, 50.241305351257324, 48.14752129146031, 49.58305038724627, 52.398745332445415, 62.070724623543875, 63.58019297463553, 70.7704598563058, 62.62612887791225, 73.05191476004464, 59.65291827065604, 66.81191825866699, 62.616672379629954, 71.60973971230644, 25.651939732687815, 38.83699771336147, 71.97697285243443, 58.2279052734375, 67.31885882786342, 61.95234816414969, 64.40688269478935, 60.82832418169294, 63.97243268149239, 61.52966839926583, 64.31556252070835, 52.859661034175325, 49.119713238307405, 46.410426480429514, 47.07118974413191, 47.52759606497628, 47.53756325585501, 45.11772108078003, 48.92144291741507, 49.744877406529014, 53.19987262998308, 55.54580681664603, 61.56467342376709, 62.29316425323486, 61.59949779510498, 59.8138941356114, 59.870966638837544, 58.63106060028076, 60.74464007786342, 61.69707134791783, 59.1563583101545, 59.342924390520366, 62.09506416320801, 60.05113342830113, 58.788597106933594, 51.00543696539742, 52.09764167240688, 51.32592609950474, 56.6006441116333, 61.100811685834614, 62.8199280330113, 65.24138219015938, 71.49088382720947, 59.21370874132429, 44.50629350117275, 3.5954454583781104, 0.23499972000718117, 0.46153050873960766, 0.49129539728164673, 1.8070728331804276, 0.39149448541658266, 0.4269890050802912, 1.4337560023580278, 0.6284955580319677, 7.564093862261091, 42.98066364015852, 56.16810485294887, 22.87263250350952, 33.53576190131051, 58.27567761284964, 13.05078056880406, 0.29596997265304836, 0.0747586949063199, 0.018977099464141896, 0.10687351985169308, 0.07318685496492044, 0.013824190029741397, 0.026362632534333637, 0.028714597757373537, 0.02730505999975971, 0.026095779978537133, 0.012023307200122093, 0.03788637596049479, 0.033569780444460254, 0.02264589929421033, 0.08587533767734255, 0.05853720248809882, 0.05026951452185001, 0.05691894396607365, 0.029916351128901755, 0.021217108105442355, 0.03736838232725859, 0.029572113350565945, 0.06949840645704951, 0.0643945067588772, 0.04305775935894676, 0.06984167053763356, 0.1904752698859998, 0.21413592169327395, 0.1371942846370595, 0.14089301973581314, 0.14646616711148194, 0.16872978316886084, 0.1575725775744234, 0.15722763751234325, 0.25469295041901724, 0.14327090499656542, 0.10807232159589018, 0.08597097040287086, 0.19674008871827806, 0.19254910360489572, 0.32019538272704395, 0.12053090307329382, 0.11735249576824051, 0.1345079102154289, 0.06871854580406632, 0.09088561311364174, 0.2104499294821705, 0.14012208181832517, 0.20948004509721482, 0.11906559312982218, 0.19856031318860395, 0.11475789999323231, 0.15816136955150537, 0.24310585217816488, 0.37277687979596, 0.38334245713693754, 0.27474211316023556, 0.8771664830190795, 25.406195844922745, 102.67423929486955, 72.08771324157715, 59.023731095450266, 52.1216025352478, 66.96341678074428, 21.259441443852015, 0.20541442611387797, 4.362416497298649, 6.11122510262898, 2.933251734290804, 26.700902325766428, 8.092573847089495, 0.4380628322916371, 0.4157539036657129, 0.19988227582403592, 34.01635490145002, 87.66544246673584, 85.89208153315953, 93.74252455575126, 85.54916013990129, 78.68718869345528, 77.02777821677071, 77.21816580636161, 82.62516362326485, 77.92328984396798, 80.41123826163155, 74.7925774710519, 69.33521216256278, 68.6983333315168, 69.48549474988664, 67.81436961037772, 74.74815763745988, 72.4938632420131, 76.53087779453823, 72.77005413600376, 69.85796683175224, 64.1386057989938, 71.64415413992745, 65.9081243787493, 73.43260656084333, 73.34544835771833, 66.03385203225272, 51.57020391736712, 54.74268191201346, 51.128288064684185, 53.631206376211985, 55.85276780809675, 67.44910975864956, 68.49788475036621, 73.40237494877407, 64.6253479548863, 73.21346037728446, 62.83953584943499, 73.11269065311977, 65.85673550197056, 73.02109255109514, 26.582256623676844, 42.55555547986712, 71.77665628705705, 62.070794105529785, 71.57520716530937, 66.56374250139508, 65.6056067602975, 61.179402760096956, 66.0096514565604, 63.05533300127302, 66.28975418635777, 55.721151556287495, 50.81237779344831, 49.33047294616699, 50.254065717969624, 50.63621664047241, 49.84256560461861, 48.05503034591675, 51.614252022334504, 53.22781481061663, 55.27642515727452, 58.793384415762766, 64.0859454018729, 65.99523394448417, 66.2756632396153, 62.253719329833984, 64.04808466775077, 62.752461024693076, 62.81492533002581, 66.93121188027519, 62.658708981105256, 64.2891663142613, 67.63313974652971, 65.006192616054, 63.64110088348389, 56.02086557660784, 54.74461351122175, 54.532130650111604, 60.29407024383545, 66.01824637821743, 65.65427194322858, 69.03271538870675, 72.13428006853376, 62.41469519478934, 46.45848717008318, 4.798327369349344, 0.21113318710454873, 0.4074975981244019, 1.3471627746309554, 7.7048113856996805, 5.496236571243831, 3.658367693424225, 3.6723783016204834, 0.8790577501058578, 5.918757830347333, 53.63857841491699, 57.48465299606323, 29.48876278741019, 50.50100816999163, 64.8797492980957, 28.65209197998047, 0.3889983450727803, 0.23353926837444305, 0.187369723671249, 0.2099689431488514, 0.19618229222084793, 0.14191182649561337, 0.1627771175865616, 0.15555464157036372, 0.21814117820135184, 0.14402060476796968, 0.15783998822527273, 0.11873813212982245, 0.2508563777165753, 0.09732309875211545, 0.15551050965275082, 0.13310892028467997, 0.19436343839125975, 0.11803367707346167, 0.1376829926988908, 0.08978464933378355, 0.12029190946902547, 0.11051901709288359, 0.25473290256091524, 0.15178571880928107, 0.13303368432181223, 0.1112947454676032], [0.08719045389443636, 0.08660926829491343, 0.030998231111360446, 0.04791693861729332, 0.05005998630076647, 0.04817014413752726, 0.10201536518122468, 0.03948023775592446, 0.039181254870657406, 0.005180094939922648, 0.08768546554659094, 0.007508974705290581, 0.06553352278258119, 0.018886632086443048, 0.06178231657083545, 0.08226329221257142, 0.049838200344571044, 0.03360432805493474, 0.05216028967073985, 0.028299880546650717, 0.027696140443107913, 0.018636437565354363, 0.016815485366220986, 0.04586588331897344, 0.13927327522209712, 0.037087390798010995, 0.048991198651492596, 0.03062610893643328, 0.04272647142144186, 0.018736813250663023, 0.1031924198780741, 0.01708053471520543, 0.28874856872217997, 44.41605029787336, 78.98059027535575, 46.55272558757237, 33.28124243872506, 65.561110496521, 32.24525908061436, 1.5248980202845164, 0.6835812021579061, 0.06759580783545971, 0.6693851096289498, 0.8487144240311214, 4.867359459400177, 1.7928763606718607, 0.276255409100226, 0.19071397850556032, 0.14819886056440218, 37.21528468813215, 103.19012914385114, 73.97874191829136, 83.38613728114537, 78.88603918892997, 80.51070172446114, 75.5902167728969, 77.74929305485317, 76.69288199288505, 75.84626483917236, 70.88136005401611, 66.36906787327358, 61.8727912902832, 66.5977817262922, 71.47720977238247, 72.33691038404191, 72.63732269832066, 72.70816653115409, 62.27025604248047, 65.52431978498186, 61.23131275177002, 60.1981851032802, 62.23981598445347, 69.06305122375488, 64.82660947527204, 62.442904881068635, 45.371035030909944, 47.83963966369629, 45.420078890664236, 45.752873284476145, 43.73743711199079, 54.64617838178362, 55.8875470161438, 62.449019295828684, 58.629441670009065, 62.1773864201137, 64.53939873831612, 66.41081265040806, 59.673936571393696, 70.28297424316406, 23.79576669420515, 35.18555607114519, 69.81178215571812, 58.126979214804514, 64.82261426108224, 59.36712496621268, 65.73769201551164, 59.97672516959054, 62.36424432482038, 59.70864977155413, 60.81913866315569, 46.54274102619716, 43.590750217437744, 44.10505240304129, 44.03937455586025, 44.379898820604595, 47.909635816301616, 45.855414799281526, 47.26382507596697, 48.61600705555507, 49.941337721688406, 51.04325948442732, 53.696564606257844, 55.58938939230782, 57.769657679966514, 57.474133423396516, 58.553553444998606, 55.56785692487444, 55.200783593314036, 56.11293615613665, 57.18457766941616, 57.10070596422468, 59.633039474487305, 58.09567758015224, 58.8828980582101, 53.236705030713765, 50.9117648260934, 55.75905397960118, 56.77354308537075, 58.67196464538574, 62.26238373347691, 67.41888509477887, 57.43216977800642, 43.62051977430071, 6.881432916436877, 0.1888975402606385, 0.04437599005177617, 0.6548258651580129, 1.4653597750834055, 1.3325457189764296, 0.7650161523904119, 0.5172313398548535, 0.4967382252216339, 3.6193047038146426, 24.16604835646493, 63.55092021397182, 23.15151756150382, 32.421079771859304, 49.135433537619456, 39.70569624219622, 0.39093417833958355, 0.328008876315185, 0.05971178731748036, 0.16287076898983546, 0.03051119903102517, 0.057368921249040535, 0.03111984155007771, 0.017615430655756166, 0.12259994633495808, 0.0246720370903079, 0.026962842559441924, 0.011846178178010243, 0.07297104011688914, 0.04488569537975958, 0.03125531106655087, 0.04287546414083668, 0.026642289045932036, 0.0720663493765252, 0.020434155029111674, 0.017423861560278704, 0.07781754434108734, 0.03968283474179251, 0.02531136296290372, 0.08909382604594741, 0.056197342329791615, 0.042848692541675906, 0.038867978645222526, 0.08998080023697444, 0.08989108433680874, 0.004661246352562947, 0.012594023852476051, 0.028356285466413413, 0.033773113640823534, 0.03994595705132399, 0.030294641187148433, 0.023660992771121006, 0.010805592140448945, 0.0638586472986, 0.0671669262062226, 0.11965754708009106, 0.011589270401080804, 0.024555022030004432, 0.0757698817178607, 0.056240480193602185, 0.023754688279171075, 0.08415683917701244, 0.019977302490068332, 0.046170932307307205, 0.02585637416424496, 0.04931160288729838, 0.029917640345437185, 0.019980038682531034, 0.02367499773390591, 0.053650003126157184, 0.029791409083242928, 0.05927092954516411, 0.031133103517017195, 0.05430583097040653, 0.04913545858913234, 0.6934175172022411, 51.359294823237825, 94.46748570033482, 35.6372515133449, 40.268663610730854, 75.40815312521798, 36.22358219964163, 2.743491436753954, 1.5557778775691986, 1.2636328339576721, 2.084810244185584, 1.7383378871849604, 4.7283733401979715, 2.9114715201514105, 2.005871977124895, 0.6529812812805176, 0.24631876977426664, 46.748765536717, 98.99857275826591, 76.08341380528041, 85.81697150639125, 82.51249163491386, 80.48969732012067, 74.3782285962786, 79.29177924564907, 78.2387866973877, 78.94188186100551, 72.10484749930245, 67.63963631221226, 61.8380502973284, 71.04489980425153, 71.82547433035714, 75.0910234451294, 70.97848197392055, 71.70005934579032, 64.37477506910051, 66.7774760382516, 62.99978215353829, 63.94646726335798, 63.16457952771868, 68.91190705980573, 65.55432210649762, 63.13414641789028, 49.26291561126709, 51.84215988431658, 46.6627642086574, 49.41681126185826, 49.9902982030596, 58.23703868048531, 59.762491362435476, 67.3692193712507, 62.94685772487095, 65.6770133972168, 65.69211878095354, 72.9537992477417, 61.24555655888149, 72.10357597896031, 24.966739654541016, 39.05673449380057, 71.62865270887102, 59.40127536228725, 67.83522115434918, 62.8661960874285, 67.80544812338692, 63.487740244184224, 64.69537190028599, 62.33960601261684, 62.51560388292585, 50.213880811418804, 47.059270109449116, 46.80174207687378, 46.95833362851824, 46.76856442860195, 49.038266454424175, 48.13221093586513, 49.47276857921055, 51.04650081907, 52.23611579622541, 55.098780563899446, 58.41048308781215, 60.7896157673427, 61.082093238830566, 60.560950551714214, 60.273503576006206, 60.85538741520473, 60.42348739079067, 62.13476616995675, 57.781038829258506, 57.72727019446236, 61.671995299203054, 62.83820874350411, 62.09597437722342, 54.888389110565186, 53.50938708441598, 57.243529660361155, 60.37372439248221, 61.980453627450125, 64.34354291643415, 69.39102704184396, 60.00233622959682, 47.00498383385794, 7.700603382928031, 0.13833336851426534, 0.09902058980826821, 1.8968553926263536, 1.8940726390906741, 0.637742144720895, 0.6641802032079015, 0.6997062340378761, 1.2038483619689941, 6.308518767356873, 30.657481057303293, 71.31725529261998, 38.87005376815796, 23.32124294553484, 53.038789067949565, 45.06597784587315, 0.6030208021402359, 0.2184152520660843, 0.10132885737610714, 0.06936259767306702, 0.06208417644458158, 0.07686757495892899, 0.09365824290684291, 0.055843503280941925, 0.04769914923235774, 0.11487877422145434, 0.02242961964969124, 0.06176075951329299, 0.01909235372607197, 0.08004610440028564, 0.038444772961416414, 0.013590812999089914, 0.007974441246395665, 0.11077411233314446, 0.03200889884361199, 0.05989655918840851, 0.02409207115748099, 0.02201014930116279, 0.018346078860174333, 0.04038696749401944, 0.0475787296225982, 0.11825376669211046, 0.021413662736969333, 0.23544964300734655, 0.17325383398149694, 0.06061127369425126, 0.09864941758236714, 0.11978952214121819, 0.08756571768649987, 0.13645630995077745, 0.10752251145562955, 0.09316428298396723, 0.08103863149881363, 0.12473292116607938, 0.12018569159720625, 0.19444079138338566, 0.15092836267181806, 0.11650997240628515, 0.23589107074907847, 0.14933119980352266, 0.15296385916216032, 0.20659389639539377, 0.2288558839687279, 0.09679188725671597, 0.10353313266698803, 0.13827391527593136, 0.07343708510909762, 0.18443351265575203, 0.10643828713468143, 0.20278432938669408, 0.16955231688916683, 0.1700597253761121, 0.16711364846144403, 0.18534498874630245, 0.12723766533391817, 0.689159845667226, 71.23827511923653, 97.68717670440674, 65.50597654070172, 48.718385287693565, 81.32079219818115, 48.44926071166992, 3.180532042469297, 1.879973224231175, 2.83536833524704, 3.244458075080599, 4.164515733718872, 16.00600402695792, 7.190737187862396, 1.5907360017299652, 0.5309284648724965, 0.3062862290867737, 43.75888967514038, 104.48489815848214, 76.73391110556466, 88.05265167781285, 85.31943184988839, 83.67694023677281, 76.73509924752372, 81.03574235098702, 83.58289636884416, 82.6750794819423, 78.45063727242606, 71.85083525521415, 69.25017316000802, 74.4367949622018, 77.55735601697648, 77.85178593226841, 74.41201073782784, 74.74234894343785, 66.57037108285087, 66.35373319898332, 68.16098049708775, 65.71354007720947, 65.74097156524658, 71.19343144553048, 69.7551543372018, 69.04870319366455, 52.795167854854036, 55.851965291159495, 52.42626714706421, 52.166248185294016, 51.80979864937918, 61.2257194519043, 63.78144754682268, 68.01955686296735, 65.69102791377476, 67.63250746045793, 67.94287654331752, 73.27043560573033, 67.10689013344901, 73.0301877430507, 28.779702595302037, 42.89217138290405, 72.28629970550537, 62.15679890768868, 70.18144021715436, 66.06602913992745, 71.17157241276333, 67.21807520730155, 68.91704872676304, 63.94620323181152, 65.23426028660366, 53.142702851976665, 47.776108809879844, 49.08414888381958, 47.816345827920095, 49.25959437234061, 52.36973660332816, 50.81652586800711, 51.54632990700858, 53.29343012401036, 54.79034308024815, 58.226956844329834, 59.64872850690569, 63.6517733165196, 65.41910321371896, 64.9907328741891, 65.72369834354946, 66.10760021209717, 66.179659979684, 66.44531045641217, 61.23146561213902, 62.20344911302839, 66.34951564243862, 66.89081505366734, 67.85596152714321, 60.05195331573486, 58.10904591424124, 63.12697587694441, 62.933635302952354, 66.4075539452689, 69.52704497746059, 72.20875780923026, 62.67659364427839, 53.01287228720528, 9.15452001776014, 0.12794036976993084, 0.1787175608000585, 1.0315420478582382, 8.038459539413452, 4.736435856137957, 2.4106203956263403, 1.5577956778662545, 1.716565381203379, 4.858342868941171, 37.256748063223704, 79.46888882773263, 37.284044061388286, 50.36504234586443, 61.77882385253906, 62.65645776476179, 2.099356297935758, 1.0433938290391649, 0.24980787826435907, 0.3216610997915268, 0.2396660324718271, 0.20632723213306495, 0.17808959021099977, 0.15192343427666596, 0.23648934864572116, 0.13463224497224602, 0.1554807491068329, 0.2054489092635257, 0.07893091174108641, 0.1918256495680128, 0.13109425481941017, 0.07624059503099748, 0.09951695853046008, 0.17512116235281738, 0.16959298827818461, 0.09061873172010694, 0.13245193553822382, 0.11251146053629262, 0.08787773522947516, 0.10658832479800497, 0.1842898125095027, 0.18129029417676584, 0.09270437194832734], [0.09396849625876971, 0.02224508356968207, 0.05115126060055835, 0.05493934179789253, 0.019490677530744245, 0.013541693849089955, 0.0783981124737433, 0.047128290935818634, 0.08174843341112137, 0.0642244183857526, 0.11473103000649384, 0.0604836887546948, 0.12144585326313972, 0.051542293546455245, 0.009901461191475391, 0.04299439097355519, 0.02893414794068251, 0.06109593090202127, 0.056272300093301704, 0.03951684472018054, 0.09904205187090806, 0.08264487316565854, 0.07856467925012112, 0.14122672325798444, 0.0459262966843588, 0.0891894723421761, 0.029902488658470765, 0.03120837001396077, 0.041485804066594155, 0.07577651100499289, 0.07612894209367888, 0.24251267686486244, 0.3973572722503117, 5.443610915115901, 71.38933590480259, 64.75236797332764, 38.86029502323696, 40.99088716506958, 84.41180256434849, 21.238410983766826, 1.0224882193974085, 0.5532123148441315, 0.5277366904275758, 0.6282124732221875, 3.2746603744370595, 3.7483325345175604, 2.3674086800643375, 0.10426585549222571, 0.3029857804732663, 0.3379805183836392, 60.50560814993722, 104.75397409711564, 84.78405925205776, 84.91531072344098, 79.94611889975411, 83.90788446153913, 81.63200896126884, 78.2596938269479, 76.02206815992082, 74.78463568006242, 73.04777363368443, 73.59858512878418, 70.50241225106376, 69.96776226588658, 74.4992731639317, 73.1699229649135, 67.99088859558105, 70.63132912772042, 60.94371291569301, 58.895238058907644, 63.079116685049875, 66.29862703595842, 67.67594759804862, 65.56691224234444, 57.22094106674194, 47.38733278002058, 46.19298607962472, 45.49787439618792, 48.455402919224326, 43.567470278058735, 48.170217582157676, 50.20863492148263, 57.281386920383994, 54.82121740068708, 58.92975670950753, 53.30879953929356, 65.25055381229946, 59.60131399972098, 70.86334337506975, 26.619102920804703, 33.7109294618879, 70.01182774135044, 59.479449544634136, 66.53699193681989, 60.42229230063302, 63.19622162410191, 59.686908858163015, 64.60879734584263, 59.136903354099815, 55.85605430603027, 45.13416746684483, 49.073931557791575, 45.954655919756206, 46.98651204790388, 45.95262704576765, 46.43551295144217, 43.322296142578125, 47.19741766793387, 46.94955805369786, 49.78123385565621, 47.319987365177695, 51.07211882727486, 51.28550842830113, 57.67211191994803, 55.27801282065255, 55.89399494443621, 56.75785057885306, 59.83949824741909, 59.042852537972585, 59.86993135724749, 57.452034677777974, 60.4196172441755, 58.729120526994976, 59.075849533081055, 57.74027374812535, 55.073218141283306, 56.33985389981951, 61.769478525434224, 64.77174649919782, 64.59196880885533, 59.190439224243164, 68.50921726226807, 8.45923810345786, 0.032564099944595776, 0.11219655921948807, 3.491087858166013, 4.730329692363739, 0.5211739540100098, 0.18696951014654978, 0.5632695066077369, 0.3879883864096233, 5.684252653803144, 23.300087417875016, 66.99401664733887, 35.78243064880371, 23.168353046689713, 46.218204566410606, 50.50176204953875, 11.514684115137372, 0.6554721019097737, 0.24860915115901402, 0.10664040236068623, 0.05023537403238671, 0.11636727649186339, 0.10996433507118906, 0.04995327309838363, 0.07981164340994187, 0.03997460140713623, 0.06951262176569019, 0.053632490137325864, 0.058119713461824825, 0.034426271449774504, 0.06545667190636907, 0.01683888803901417, 0.006591007579118013, 0.003948095021769404, 0.01321507677701967, 0.03683035494759679, 0.0569878966946687, 0.02292769488745502, 0.08918802706258637, 0.07104460456009422, 0.09899758068578583, 0.08038616579558168, 0.07803010222102914, 0.15935550976012433, 0.032334504050335715, 0.030708900386733667, 0.016651988960802555, 0.09031402878463268, 0.04726477486214467, 0.05609086322199021, 0.039795804037047286, 0.1049813570986901, 0.015401513382260288, 0.0469056093133986, 0.12450036007378783, 0.035981548351368735, 0.11093532546822514, 0.03148739718432937, 0.11646187784416334, 0.04851107066497207, 0.05024560973314302, 0.09658922241734606, 0.053793170622416904, 0.0843779058860881, 0.07594881140227829, 0.07418084769908871, 0.05224385804363659, 0.044855174874620776, 0.027364562431882535, 0.056792166483189375, 0.029404379493956054, 0.045138707517513206, 0.1489994368915047, 0.08820206139768873, 0.0869559318359409, 0.26188167610338753, 0.4953797981142998, 8.061482395444598, 79.86267798287528, 69.64919430868966, 27.187319653374807, 65.50966603415353, 88.8864494051252, 28.19932304109846, 2.0452893248626163, 0.9877153081553323, 1.4411580051694597, 1.0906893483230045, 1.6780995024102074, 1.1323183945247104, 2.552401210580553, 1.749042998467173, 0.4756387174129486, 0.757637328335217, 75.1213731765747, 103.63784326825822, 86.73284830365861, 85.9376756123134, 84.84857327597481, 86.99153668539864, 80.9617509841919, 78.38481698717389, 77.51525688171387, 76.53274685995919, 75.00233663831438, 75.48612580980573, 69.9747382572719, 70.94521399906704, 73.61837359837124, 74.56648308890206, 68.26129858834403, 70.48383971623012, 64.94727884020124, 65.2105460848127, 66.72444738660539, 65.85282366616386, 69.06475353240967, 68.15003708430699, 61.233022008623394, 50.31276062556675, 49.323615074157715, 46.86046825136457, 51.328913824898855, 47.922927720206125, 53.235975469861714, 56.55930927821568, 61.6270751953125, 60.25472954341343, 61.95921298435756, 58.9230933870588, 70.14018876211983, 66.33870424543107, 74.18672929491315, 28.665116378239222, 37.443095275333945, 72.21440669468471, 61.89436544690813, 69.80398627689907, 64.07001318250383, 67.76069477626255, 63.116032464163645, 67.66961084093366, 62.63621071406773, 60.4979373386928, 48.38575070244925, 51.75631489072527, 48.922717911856516, 50.15328557150704, 49.72165305273873, 49.09524515696934, 44.94459629058838, 50.82648958478655, 49.51794229234968, 54.3616600717817, 51.19093302318028, 54.102481842041016, 56.586292607443674, 61.6218501499721, 60.17753505706787, 60.72196115766253, 58.59594440460205, 62.47586018698556, 62.231631006513325, 65.20101315634591, 60.77728966304234, 62.44815077100481, 60.399189540318076, 64.58757059914726, 60.31469249725342, 59.76888370513916, 59.53340230669294, 66.05837222508022, 67.58343928200858, 66.04376016344342, 59.860850061689106, 73.78656169346401, 10.053939138139997, 0.07796788734516927, 0.0630728155374527, 5.186794638633728, 4.254807140145983, 0.44767618072884424, 0.33304832875728607, 0.5031679687755448, 0.9366324778114046, 8.726177471024648, 28.129113231386455, 65.20552253723145, 60.198539461408345, 20.88556408882141, 44.650840350559776, 60.62143462044852, 12.242723311696734, 1.001384151833398, 0.1624133549630642, 0.1790956405124494, 0.0745607390999794, 0.07263452067439045, 0.07009827891098601, 0.049315409468753, 0.022147622192278504, 0.01750265304664416, 0.031479376900408945, 0.04002817174685853, 0.04204894741997123, 0.09664103535137006, 0.0336676523355501, 0.046611311712435315, 0.03803815067346607, 0.10401587640600544, 0.0237972968856671, 0.033939239369439225, 0.03625205312190311, 0.009933393897621759, 0.04868899272488696, 0.050161688522036584, 0.12354127796632902, 0.08983726293912955, 0.11448869800993375, 0.07466524027820144, 0.1832674095141036, 0.16097731702029705, 0.13227342654551777, 0.11038636349673782, 0.0967809831989663, 0.1860415863671473, 0.14858211071363517, 0.27049068414739197, 0.0850948052746909, 0.11051052861980029, 0.14469215087592602, 0.08503723836370877, 0.18815556221774646, 0.12193855111088071, 0.17686183537755693, 0.1501185582684619, 0.13010626712015697, 0.25141277643186705, 0.13788229200456822, 0.1331050390643733, 0.15733618954462664, 0.20955879587147916, 0.21857192580189022, 0.19371260117207253, 0.16823251199509415, 0.10913496850324528, 0.137843642649906, 0.26348424011043137, 0.28378161096147125, 0.1752567065081426, 0.1824990636003869, 0.38685531435268267, 0.6622602748019355, 12.615078142711095, 99.6382725579398, 78.99478544507707, 57.97986153193882, 58.109007699149, 103.33678477151054, 34.43260063443865, 2.2821073830127716, 1.2217297681740351, 4.582739097731454, 3.0604230931827, 6.454778781958988, 12.744695050375801, 6.791524529457092, 0.8112847496356282, 0.577232183090278, 0.6845864110759327, 69.45087882450649, 104.46510968889508, 89.75042315891811, 90.16082545689174, 85.09643636431012, 88.1345431464059, 83.04735006604875, 80.82057053702218, 79.5985700062343, 79.73915985652378, 79.43438407352993, 80.42415496281215, 77.42761925288609, 75.70230511256626, 76.49717903137207, 76.37566198621477, 72.45971284593854, 72.94029194968087, 69.21009595053536, 68.7221656526838, 69.86432443346295, 69.16561358315604, 72.72294534955705, 75.7643733705793, 64.16737828935895, 55.334050042288645, 53.39657613209316, 51.382491384233745, 55.10118464061192, 51.21200690950666, 56.32428298677717, 60.220322063991, 65.70270088740757, 64.16239643096924, 67.17725454057965, 63.70969349997384, 72.92171246664864, 68.84236948830741, 77.02114963531494, 32.16438899721418, 38.88012865611485, 76.50252914428711, 64.89356231689453, 72.59728717803955, 68.6824289049421, 71.45143195561, 67.0869974408831, 70.95197459629604, 65.76376860482353, 63.25851917266846, 52.03258221490042, 54.3358370917184, 52.01115049634661, 54.20687852587019, 53.46446003232683, 52.91729981558663, 48.559341021946494, 54.685842173440115, 53.796775000435964, 58.14507927213396, 55.17063883372715, 58.84874766213553, 59.41919476645333, 66.43429756164551, 64.30972603389195, 66.4838034766061, 65.0378486088344, 67.34453936985561, 67.37051173618862, 70.82066753932408, 65.12818908691406, 66.96092932564872, 67.26395416259766, 70.89761883871896, 67.18584251403809, 64.2804810660226, 61.75161470685686, 71.60232598440987, 71.19195147923061, 70.31152439117432, 64.22542354038784, 77.52581119537354, 10.801382047789437, 0.12621186966342585, 0.12920923025480338, 4.747911674635751, 10.701689294406346, 1.9876868043627058, 1.1340028984206063, 1.059631877711841, 1.3415744687829698, 7.042111311640058, 35.95973825454712, 82.41311155046735, 49.13638891492571, 36.34794453212193, 62.03644221169608, 71.01097175053188, 21.817392213003977, 1.451704284974507, 0.32788177313549177, 0.2094323169440031, 0.12790987640619278, 0.1330716008586543, 0.17144738377204963, 0.1753211673349142, 0.14356662412839277, 0.04923094882230673, 0.17972830656383718, 0.16457786810185226, 0.0897569108222212, 0.20638364553451538, 0.12326892758054392, 0.13830852056188242, 0.14494267957551138, 0.273127335522856, 0.13479383130158695, 0.12258463858493737, 0.14793599609817776, 0.13544365071824618, 0.2096786658678736, 0.17236548236438207, 0.1415821806128536, 0.14065424326275075, 0.12154960126749106, 0.25605957422937664], [0.02142671775072813, 0.10649003900055375, 0.1375563373523099, 0.020206233420010124, 0.03265960714114564, 0.14744483173957892, 0.010451812463413392, 0.08069531313542809, 0.04810156799586756, 0.059471165229167254, 0.04419080427448664, 0.06199400592595339, 0.02309776290452906, 0.057445188585136614, 0.05234459674518023, 0.017221215380621806, 0.0176880830965404, 0.048240274124379666, 0.1112610154918262, 0.13867153679685934, 0.05542143414329205, 0.05909481578107391, 0.046929456426629, 0.07039283774793148, 0.11723730766347476, 0.04517856466450861, 0.02581109043343791, 0.08579348599804298, 0.0345259753854147, 0.07773872571332113, 0.1295140010437795, 0.1294554706130709, 0.3388949121747698, 0.2537066047745091, 29.068447147096904, 75.67768069675991, 60.99902752467564, 22.8793739931924, 44.37073414666312, 78.99079023088727, 12.503276416233607, 1.254048228263855, 1.1110827454498835, 0.7530909265790666, 0.26270226921354023, 1.6254104439701353, 2.3860331092561995, 4.321774746690478, 0.031124099357319728, 0.10024229210934468, 1.2655263266393115, 28.706503323146276, 59.10724149431501, 70.47394548143659, 68.14605576651437, 73.02165535518101, 83.68165111541748, 81.36205754961286, 76.8536285672869, 77.24034445626395, 71.60529286520821, 68.29827690124512, 73.91977255684989, 81.85332298278809, 78.21230711255754, 70.0460684640067, 74.4113576071603, 63.839881896972656, 61.07552024296352, 50.62088891438076, 64.36757673536027, 66.2858145577567, 66.6788672038487, 64.87371826171875, 57.09811776024954, 47.47189930507115, 49.43090568270002, 45.764407294137136, 47.00010967254639, 43.237514223371235, 45.15067638669695, 46.53072759083339, 53.18464912687029, 51.909154415130615, 59.52026326315743, 55.34246778488159, 63.11516393933977, 53.39812905447823, 74.39638423919678, 26.81464954784938, 27.939286708831787, 73.67363262176514, 58.97469765799386, 68.99389580317906, 59.11054188864571, 65.40747887747628, 60.583400181361604, 65.24760777609688, 60.73799065181187, 53.95205681664603, 44.074150289808, 49.5781831741333, 46.19034229006086, 47.59476082665579, 45.913991587502615, 49.030550479888916, 47.28901924405779, 49.8229786327907, 50.00622694832938, 50.850881235940115, 48.36243602207729, 49.511136531829834, 49.10438551221575, 50.53636755262102, 53.192927905491416, 56.50322689328875, 54.783005782536094, 56.97253949301583, 60.22690200805664, 59.89977387019566, 58.0283008984157, 63.995966230119976, 64.9409351348877, 60.54777676718575, 60.40119756971087, 62.047503743852886, 61.64117309025356, 62.96397808619908, 62.40981061117989, 65.51118074144635, 73.41308907100132, 12.569284302847725, 0.08948650783193962, 1.4352090443883623, 23.94358614512852, 19.35928283418928, 1.8023817134754998, 0.14633900964898722, 0.4318641163408756, 0.3684574344328472, 10.883203165871755, 32.59280450003487, 72.18385546548026, 36.34268127168928, 14.572880744934082, 54.5767102922712, 53.7779974937439, 28.36409435953413, 0.11548968644014426, 0.004681546848067748, 0.06766688437866313, 0.050018914576087675, 0.05277238254036222, 0.04672500364748495, 0.0806120161765388, 0.036582567529486756, 0.10715532223028795, 0.01951112348719367, 0.05671157348634941, 0.05311430651428444, 0.06169987456606967, 0.005453844804183713, 0.04904778168669768, 0.06122431651289974, 0.05018334735983184, 0.06278926253850971, 0.0383595353923738, 0.048161329967635017, 0.043940390925854445, 0.03266954089381865, 0.03590466694108077, 0.032484986154096465, 0.09799929282494954, 0.08413967902639083, 0.12215439310031277, 0.0448735903150269, 0.015415957696469767, 0.1043690742392625, 0.033194788066404204, 0.06354864500463009, 0.03802123140277607, 0.07454705983400345, 0.024450201940323626, 0.01959516174559082, 0.053076708888901133, 0.03661047228212867, 0.015807994874194264, 0.057961228037519116, 0.027495998057669828, 0.07407622438456331, 0.03990977417145457, 0.03235829688076462, 0.02083161030896008, 0.04110538001571383, 0.032048447257173915, 0.12027031848473207, 0.029635895642318895, 0.013986103752228831, 0.05713847040065697, 0.04078909448747124, 0.07046303219561066, 0.05313527324636068, 0.05577049969828554, 0.06464358339352266, 0.042538873452161036, 0.07013105893773691, 0.08599868177303246, 0.15455131897968905, 0.2560251046504293, 0.3625810226159436, 36.60732078552246, 89.62971210479736, 58.91421358925955, 24.57857506615775, 82.53580978938511, 77.21253081730434, 20.97766419819423, 1.5014045323644365, 1.3039052443844932, 1.080954379269055, 0.8055454290338925, 0.652941383421421, 1.1391519478389194, 3.8879209756851196, 0.10993229464760848, 0.04901460132428578, 2.0315199494361877, 38.691436426980154, 67.70419202532086, 78.98232037680489, 74.24939509800502, 77.97337245941162, 86.88524314335415, 82.28225612640381, 79.26572350093296, 78.64625685555595, 75.00671400342668, 75.18062741415841, 78.81472287859235, 79.65007700238908, 79.9915531703404, 69.05492183140346, 74.41825716836112, 67.60023307800293, 64.3059184210641, 57.70740876879011, 66.63754626682827, 65.60590553283691, 68.89523833138603, 65.45398317064557, 60.515273094177246, 50.90523699351719, 51.481638704027446, 47.59730039324079, 49.503701959337505, 46.44192613874163, 51.54644455228533, 51.080345494406565, 57.25889907564436, 57.198828424726216, 63.227655274527415, 59.518005098615376, 67.9099976675851, 56.8470585005624, 74.43261909484863, 27.284867150442942, 31.296635423387798, 76.77397441864014, 60.307271821158274, 71.4651129586356, 63.54963479723249, 69.14222594669887, 63.09597301483154, 68.5778168269566, 63.73373426709856, 57.11456414631435, 46.97682278496878, 51.44414969852993, 48.28917421613421, 49.43467855453491, 48.986516271318706, 50.87500190734863, 51.23814255850655, 52.556254046303884, 53.776993479047505, 55.46196290424892, 53.11686944961548, 55.213818413870676, 55.0676908493042, 56.213622501918245, 57.50944764273507, 58.580220631190706, 60.57520130702427, 63.66960934230259, 63.18383993421282, 61.167576926095144, 59.33394731794085, 64.62867614201137, 66.07718794686454, 65.15214647565568, 63.79532309940883, 64.12550149645124, 65.48037242889404, 68.28172629220145, 66.59132684980119, 68.86138670785087, 79.29132761274064, 14.810295479638235, 0.04976108483970165, 2.2234587243625095, 31.10396535055978, 17.245269094194683, 1.5880493287529265, 0.30169604825122015, 0.21960028633475304, 0.6596507919686181, 16.433894940785, 38.54941177368164, 70.69970635005406, 66.8346527644566, 15.713368483952113, 43.5569611276899, 61.97173363821847, 33.75078780310494, 0.09981467934059245, 0.044598766669098816, 0.05825621435152633, 0.02937682079417365, 0.09240779786237649, 0.0235400574747473, 0.019364646436380487, 0.0346801996098033, 0.04847326608640807, 0.022853563240330135, 0.0270609010476619, 0.06319860235920974, 0.03437478421255946, 0.023108529558937465, 0.004494850906277341, 0.04453637876680919, 0.05699052262519087, 0.04726470361596771, 0.08831768376486641, 0.035154444697712145, 0.1382974468703781, 0.08002138536955629, 0.04873569629022053, 0.014948747320366758, 0.04929540964907833, 0.05793471088899033, 0.08782881963998079, 0.08130826774452414, 0.09082213616264717, 0.33140171425683157, 0.14118489835943493, 0.09271373573158469, 0.16590441763401031, 0.2773360439709255, 0.07534519343503884, 0.09842421859502792, 0.15186265110969543, 0.10365790847156729, 0.1499860675207206, 0.1901080874460084, 0.14351635825421127, 0.12613375671207905, 0.0899752498205219, 0.08122385120285408, 0.1358847256217684, 0.11762101921652045, 0.21710622230810778, 0.16693747362920217, 0.25882645004561966, 0.1307340341487101, 0.1656448237065758, 0.12188420045588698, 0.229035668607269, 0.17678298960838998, 0.09337557878877435, 0.17207562577511581, 0.10278166870453528, 0.2488306521305016, 0.1734030574027981, 0.3872956835797855, 0.4154765456914902, 0.9046386831573078, 53.54640013831002, 101.21515927995954, 78.09677246638707, 37.3276926449367, 63.23759814671108, 96.57376956939697, 24.966369662966045, 1.415298764194761, 1.9227341754095895, 3.55638615999903, 2.3541013598442078, 4.2201399718012125, 9.692262819835118, 10.724448118891035, 0.19681033066340856, 0.24652333451168879, 1.6628631885562624, 34.28703587395804, 64.26092883518764, 76.7484884262085, 75.156496320452, 79.41158703395298, 85.36579717908586, 86.5377220426287, 83.51220539637974, 83.46288708278111, 77.87759154183524, 74.92098712921143, 79.5791984285627, 88.58598150525773, 82.49366201673234, 70.37487111772809, 78.2848185130528, 73.21556568145752, 70.86697728293282, 64.62265205383301, 71.68993582044328, 68.61380154745919, 71.58123820168632, 68.6582978112357, 64.57379926953996, 58.2234480040414, 56.17601190294538, 51.63049691064017, 54.77910784312657, 50.645086015973774, 53.45839078085763, 54.17951651981899, 60.01314067840576, 59.867235456194194, 65.69067355564663, 62.30357960292271, 68.4533120564052, 60.38808631896973, 78.42565849849156, 30.332017013004847, 36.24684476852417, 78.24117687770298, 64.74342564174107, 74.57021427154541, 66.05773299080985, 72.3034895488194, 66.72365529196603, 72.82768249511719, 67.99942793164934, 60.41642802102225, 49.99292809622628, 53.170210770198274, 52.07229811804635, 52.64142506463187, 53.521855626787456, 54.95675243650164, 55.159431389399934, 57.51893540791103, 59.08766841888428, 59.08184582846505, 58.02187728881836, 60.91029208047049, 59.20093100411551, 60.640153067452566, 62.087025097438264, 64.01135648999895, 64.0717363357544, 69.80535507202148, 69.47048664093018, 65.39276954105922, 62.058940478733604, 68.53384167807442, 72.27701691218785, 68.43784536634172, 68.45049803597587, 70.73947783878872, 72.17666407993862, 69.97926153455461, 71.51966326577323, 72.78238024030412, 82.31079932621547, 17.050915820258005, 0.2472719486270632, 2.862458493028368, 28.641779116221837, 27.17999104091099, 7.647933432034083, 0.8172451640878404, 1.0464275862489427, 0.9465625392539161, 14.667813982282366, 48.776885645730154, 88.76552295684814, 51.28263882228306, 22.811731542859757, 72.92068413325718, 66.70768138340541, 49.302784374782014, 0.13501421947564396, 0.06434055643954448, 0.14905066628541264, 0.07398796733468771, 0.17693580926528998, 0.09544366531606231, 0.10567276392664228, 0.15241864270397595, 0.19602974397795542, 0.06578698275344712, 0.11711496779961245, 0.1507670341857842, 0.1486974616668054, 0.05983929761818477, 0.11591758419360433, 0.10264607026640858, 0.1508988599692072, 0.09102321323007345, 0.1563862133771181, 0.167336872911879, 0.22634881921112537, 0.1742027923464775, 0.11292818281799555, 0.07868504457707916, 0.19037514525864804, 0.12412479094096593, 0.19428035856357642, 0.16411451010831765], [0.16603842830019339, 0.043730832170695066, 0.15841149113007955, 0.09445910421865326, 0.04189998862732734, 0.032552110230816264, 0.060468957759439945, 0.03443607967346907, 0.09465876993324075, 0.014978779280292136, 0.0656102786638907, 0.04324152360537222, 0.10737676213362388, 0.0466842610122902, 0.05154090254966702, 0.06963103291179452, 0.07983903586864471, 0.05352620441200478, 0.16494608191507204, 0.08331135061702558, 0.06500706781766244, 0.08063554098563534, 0.029380742726581435, 0.022561364008912017, 0.08051001879253558, 0.03338152429621134, 0.05981593565749271, 0.014573403800438558, 0.0509333524719945, 0.028204861895314286, 0.04106435578848634, 0.07606961777699844, 0.12206017172762326, 0.031840360923005004, 0.20292911518897327, 56.028664929526194, 68.97621263776506, 60.44291455405099, 16.926143544060842, 56.20369700023106, 86.11265904562813, 16.221976620810374, 2.307747538600649, 0.3712192348071507, 0.43185296122516903, 0.23199370130896568, 0.33982768069420544, 3.176235233034406, 1.8485070041247775, 0.33302086165973116, 0.11045393879924502, 0.17107682222766535, 6.051021133150373, 17.371995551245554, 21.478043930871145, 35.87139885766165, 56.18632302965437, 84.56296757289341, 81.17137118748256, 81.41780989510673, 87.37972559247697, 83.93514224461147, 79.24445506504604, 73.97653933933803, 76.93128163473946, 74.75869805472237, 66.23471055712018, 59.440185274396626, 68.25565665108817, 63.90604959215437, 60.878601346697124, 65.77312088012695, 67.74679837908063, 62.07934733799526, 53.60943419592721, 51.747219698769705, 56.68509946550642, 54.3563585962568, 55.77591725758144, 51.5556127003261, 48.78085306712559, 43.62654733657837, 47.59765475136893, 47.506344999585835, 54.33413130896432, 53.71058259691511, 63.340306418282644, 62.17306464059012, 65.75454139709473, 34.114515577043804, 43.755891527448384, 67.52215617043632, 62.829731941223145, 67.27837167467389, 60.74125630514962, 65.21314471108573, 61.763364110674175, 62.02984142303467, 57.67799357005528, 51.23638466426304, 46.05240665163313, 49.44832829066685, 47.54228803089687, 49.87093162536621, 51.048196179526194, 51.723276206425254, 49.0689114843096, 50.19531869888306, 49.74008314950125, 51.02598973682949, 49.632073402404785, 49.88993842261178, 50.36398621967861, 51.78515338897705, 51.54965114593506, 53.913431780678884, 53.44239602770124, 59.59925733293806, 60.29088796888079, 67.68300696781704, 71.71932670048305, 70.05163397107805, 62.73490292685372, 58.14346381596157, 64.82930537632534, 61.85240527561733, 62.23919064658028, 57.375208445957725, 64.69450337546212, 60.0262519291469, 7.770509208951678, 0.5396411259259496, 7.095151254108973, 11.652313164302281, 12.635327798979622, 1.149181021111352, 1.097432357924325, 0.4612209339226995, 0.014201387646608055, 18.820509093148367, 31.02025692803519, 72.59190927233014, 34.85777827671596, 7.276905706950596, 43.84208740506853, 46.23461273738316, 51.78853716169085, 1.3639973912920271, 0.10983025655150414, 0.06683166205350842, 0.07005171783800636, 0.029666928441396782, 0.03389685467949935, 0.06254539026745728, 0.09186447451689414, 0.10158633427428347, 0.078158793172666, 0.08436892886779138, 0.06596635348562684, 0.09249384288809129, 0.0537668163222926, 0.05365825071930885, 0.04001671468306865, 0.10409613352801118, 0.07222366093524865, 0.023428263741412332, 0.05300373923299568, 0.04388865941603269, 0.06816804355808667, 0.042308694017784934, 0.06005091233445065, 0.06035085873944419, 0.14461672492325306, 0.06666658126882144, 0.02120741523270096, 0.043250137607433965, 0.08218480606696435, 0.004629709317149329, 0.1012546324304172, 0.03167179586099727, 0.02071033574507705, 0.08552956980253969, 0.07595751022121736, 0.03444950109613793, 0.13846919765429838, 0.12623517055596623, 0.03248518971460206, 0.03295010833867958, 0.06297083172414984, 0.0767360884430153, 0.025025136535987258, 0.02378786524890789, 0.09719575129981552, 0.017426943805600916, 0.20549556533140795, 0.048742271294551234, 0.092209842056036, 0.017336196532206874, 0.042489353966500075, 0.04996778696243252, 0.054969407684568844, 0.046967281361243556, 0.01944752100722066, 0.03334903943219355, 0.05498947196507028, 0.013721359744002777, 0.017264085223100016, 0.05368095450103283, 0.02443571012866284, 0.058605266335819445, 0.37212328772459713, 66.81696959904262, 76.62524822780064, 46.69545895712716, 21.949845722743444, 96.98785441262382, 80.89543737683977, 24.674161434173584, 3.352129966020584, 0.7279703659670693, 0.46447507930653437, 0.24916953966021538, 0.3697221151420048, 1.4774861186742783, 1.3368955084255763, 0.2972907003547464, 0.05226475013686078, 0.12756690409566673, 8.451149531773158, 21.575631380081177, 29.18221868787493, 44.033343519483296, 64.36161518096924, 88.06829902103969, 83.15545013972691, 85.06787926810128, 89.01717281341553, 84.26315975189209, 79.3222609928676, 76.31218324388776, 75.58759730202812, 76.20066465650285, 71.95378671373639, 62.949769020080566, 71.26096098763603, 67.5925692149571, 65.81882613045829, 69.37958335876465, 70.49982057298932, 66.01459162575858, 56.946528911590576, 53.953581946236746, 57.61508458001273, 57.17070211683001, 57.171247550419395, 55.0328699520656, 51.9298426764352, 47.9755985396249, 52.731452873774934, 52.7569249698094, 57.4777638571603, 58.170002460479736, 68.68773732866559, 64.33587210518974, 71.99098736899239, 35.4660096849714, 44.655447006225586, 72.24616691044399, 64.41425473349435, 69.52628067561558, 63.58985791887556, 66.76039041791643, 64.4465777533395, 65.9828244618007, 61.97187955038888, 54.35593475614275, 49.94254323414394, 51.319669246673584, 51.684981209891184, 52.50142233712332, 52.99067974090576, 53.89753082820347, 52.375851018088206, 52.87521457672119, 54.19034876142229, 56.446699823652, 54.89465985979353, 53.16882113048008, 53.588065011160715, 56.04683794294085, 57.9425288609096, 60.215930802481516, 58.267259870256694, 61.938111305236816, 61.413779394967214, 73.01808398110526, 75.66370786939348, 72.46829387119838, 66.77186884198869, 63.468257495335166, 69.24236338479179, 65.9056647164481, 64.44805771963937, 63.22840567997524, 69.08883598872593, 66.48255974905831, 9.621809823172432, 0.5310890333993095, 10.310218232018606, 12.668960554259163, 13.561355914388384, 0.6494927427598408, 0.5839441972119468, 0.36987923671092304, 0.1044755092422877, 29.608421189444407, 39.35902976989746, 70.02534198760986, 69.73565769195557, 8.180681347846985, 29.767534937177384, 51.619525705065044, 56.93904570170811, 1.6444386286394936, 0.3504858102117266, 0.028393570965688144, 0.13604776401604923, 0.03168450482189655, 0.020318079739809036, 0.027574696245470216, 0.015388919772314174, 0.03129233872251851, 0.04295265428455813, 0.058407643011638095, 0.07626608080629792, 0.06467351357319526, 0.04883918645126479, 0.032997643109411, 0.04190658738038369, 0.06655556615442038, 0.06113766759101834, 0.05652436567470431, 0.036511921856020174, 0.10157428349235229, 0.07895338482090405, 0.04435572221076914, 0.059772604411201816, 0.038085834721901586, 0.09504753657217536, 0.06260453816503286, 0.09103417157062463, 0.035800868046603034, 0.21164051416729177, 0.08581094470407281, 0.2460721901484898, 0.20273936965635844, 0.16499014597918304, 0.22726409509778023, 0.15525969596845762, 0.15016107527273043, 0.161244822666049, 0.21953077720744268, 0.13453980136130536, 0.17733151731746538, 0.18538772288177693, 0.12146762066653796, 0.10015059488692454, 0.10047306186918702, 0.21290721691080502, 0.09223732950964145, 0.34937428842697826, 0.12609882572931902, 0.31925759304847035, 0.19102062205118792, 0.14903913119009563, 0.2050717795001609, 0.30802135169506073, 0.2385167841400419, 0.14519563743046351, 0.1661875567265919, 0.2205588798969984, 0.14941833727061749, 0.1221535245754889, 0.19986364325242384, 0.23275721605334962, 0.1476153340190649, 0.6957238305892263, 90.3856761114938, 85.93387494768415, 78.37972395760673, 28.43075016566685, 74.58726515088762, 103.37807791573661, 31.72125026157924, 3.337763696908951, 0.8046291353447097, 1.0467413408415658, 1.2890737716640746, 0.9379996444497789, 8.385990193911962, 6.0025670017514905, 0.5009268490331513, 0.19499417740319455, 0.30189114063978195, 7.733013255255563, 20.083804505211965, 25.9520081111363, 44.84376055853707, 61.82655102866036, 92.35275282178605, 85.30802985600063, 84.3674452645438, 91.10910170418876, 90.91809572492326, 83.31690543038505, 78.19128881181989, 76.41628115517753, 81.20254080636161, 75.70247881753104, 68.81693213326591, 74.0936859675816, 72.78979396820068, 68.97282191685268, 72.79380307878766, 75.87478024618966, 71.60919775281633, 60.895332608904155, 60.12236636025565, 63.60263565608433, 62.440271513802664, 63.81654289790562, 62.21099485669817, 58.8450859614781, 51.10092953273228, 56.921907969883506, 55.7370594569615, 60.03181743621826, 62.67092391422817, 72.45908055986676, 70.44075393676758, 71.57169832502092, 42.256376470838276, 55.788069656917024, 75.49805586678642, 68.8667298725673, 75.49527658735002, 66.69318744114467, 70.58464418138776, 68.91602734157017, 68.12663555145264, 66.9812319619315, 58.74375343322754, 54.03693948473249, 55.86616740907942, 53.045313426426475, 57.059857504708425, 59.38718441554478, 58.81754330226353, 56.923040526253835, 57.3102844783238, 58.09837000710623, 61.17769350324358, 61.78170735495431, 60.14549691336495, 60.03666727883475, 62.995439529418945, 65.3399076461792, 67.7472152709961, 64.32260799407959, 67.36591897691999, 67.85438428606305, 80.57698059082031, 81.27997153145927, 74.8853428704398, 72.85043784550258, 70.82144573756626, 74.35386126382011, 69.92556585584367, 68.44152096339634, 69.38410663604736, 70.67611026763916, 66.75208732060024, 11.80993218081338, 0.6356992657695497, 13.581382359777178, 16.205259255000524, 17.93203772817339, 3.853200827326093, 2.180746844836644, 1.0852094995124, 0.1704529228487185, 26.362445150102886, 47.40988663264683, 85.17923109872001, 47.1178468976702, 13.36622096811022, 63.88683087485177, 56.27724715641567, 73.8173839024135, 3.6240566202572415, 0.6561594307422638, 0.159522252955607, 0.2533596562487738, 0.1233218533119985, 0.11210837680846453, 0.23901689159018652, 0.15586416210447038, 0.14819691995424883, 0.08794251496770553, 0.17313756022070134, 0.11437846321080412, 0.22099741707955087, 0.06528715350266014, 0.10849566637937512, 0.08731733994292361, 0.14163043802337988, 0.16559849333550247, 0.17207551720951283, 0.0933362983965448, 0.23477699767266, 0.11536613878394876, 0.1142747016357524, 0.10547237896493503, 0.09932248360876526, 0.2640801567052092, 0.15257242588060244, 0.2336093203297683, 0.12007453399045126], [0.11421283281275205, 0.08062223491391965, 0.1269518392426627, 0.13285654596984386, 0.07792646278228078, 0.1439282561519316, 0.05266805099589484, 0.021417769570169703, 0.02285000602049487, 0.19320926389523915, 0.12579778688294546, 0.057532292125480514, 0.04962642277990069, 0.042797018707330735, 0.016219675640708635, 0.04913850181869098, 0.07673973217606544, 0.04228970521528806, 0.031727856424238, 0.044437828340700695, 0.04518728044682315, 0.021931317102696215, 0.009210257075860031, 0.04724991155256118, 0.06664318538137845, 0.015485270048624702, 0.031159410319690193, 0.02172080161316054, 0.01729279912875167, 0.053927344137004445, 0.031713617366871664, 0.05689566342958382, 0.05681441564645086, 0.05787238744752748, 0.06226043948637588, 3.3437658548355103, 68.99602890014648, 69.3846138545445, 65.2169245311192, 13.784173352377755, 47.847987924303325, 95.37106418609619, 30.550444058009557, 6.297842860221863, 0.06348144289638315, 0.3551452559019838, 0.19013425175632748, 0.19779031164944172, 0.8779997240219797, 0.7308589166828564, 0.16523227441523755, 0.17848453830395425, 0.15441097079643182, 2.409897348710469, 4.326880804130009, 2.907648925270353, 9.769074286733355, 33.85284989220755, 80.31146212986538, 82.19370133536202, 65.6944603238787, 70.21990544455392, 72.74187919071743, 77.87420082092285, 83.43783187866211, 76.89692974090576, 67.12945788247245, 75.92828137534005, 70.47639124734062, 67.24798025403703, 64.67472880227226, 64.74216106959751, 69.43370287758964, 61.785077231270925, 61.17556735447475, 63.16435718536377, 64.06209223611015, 60.50109876905169, 61.21079472133091, 59.320627621241975, 56.60984352656773, 52.66851609093802, 50.1894439969744, 46.255429540361675, 49.946319580078125, 53.02480929238455, 61.45711530957903, 57.36651624952044, 67.14366694859096, 43.40215526308332, 27.361175741468156, 58.84664930616106, 63.25785909380232, 64.02833093915666, 61.36888708387102, 64.46410805838448, 60.99327441624233, 63.70675441196987, 55.25724812916347, 48.697728293282644, 50.03555876868111, 51.30000237056187, 51.33111292975289, 54.15085867473057, 58.14284542628697, 57.05018561226981, 55.5858736038208, 54.6862382207598, 53.937149456569124, 53.04869025094168, 53.150592531476704, 52.54798916407994, 49.99653768539429, 52.06970991407122, 51.82631451742989, 55.50630630765642, 55.00716161727905, 57.147564615522114, 56.96494858605521, 60.52741159711565, 64.00174018314907, 66.68775394984654, 65.45568547930036, 66.02962752750942, 62.538748332432334, 69.13647283826555, 62.72720432281494, 68.46387331826347, 42.49155214854649, 2.5420979005949835, 0.3495400409613337, 3.9497881702014377, 11.619211077690125, 0.48094952957970755, 1.5345838091203143, 0.9191923907824925, 0.7183332688042096, 1.2822392412594386, 23.888136046273367, 27.259169237954275, 71.64823273250035, 35.37335893086025, 6.429747028010232, 44.673359462193076, 51.09783411026001, 56.1071309362139, 7.004734780107226, 0.528205639549664, 0.09691334502505404, 0.07703910182629313, 0.03138822589867881, 0.03881134471989103, 0.05919161558683429, 0.02947517783780183, 0.0014209591983152287, 0.015375369427991765, 0.04790282848158053, 0.05824294899191175, 0.03172939330605524, 0.06935114400195223, 0.02158616160574768, 0.047341018449515104, 0.012211289389857223, 0.14387142205876963, 0.04297890341175454, 0.045353959181479046, 0.08271732034959964, 0.05958026008946555, 0.006931113503274641, 0.03955648812864508, 0.016708682257948176, 0.08286547847092152, 0.0883775305535112, 0.04502648461077895, 0.014948445372283459, 0.03909797826781869, 0.052257934252598455, 0.059684021664517264, 0.08517827865268503, 0.07266367732414178, 0.06398857996932097, 0.15404392406344414, 0.06714566091873816, 0.02287735776709659, 0.030295089020260742, 0.18136379308998585, 0.05662610860807555, 0.06961801182478666, 0.02824350955363895, 0.06255507296217339, 0.033074836645807536, 0.051050399762711356, 0.07657347752579621, 0.01861399332327502, 0.04641599201464227, 0.041416342436735115, 0.057468889813338, 0.06566789985767432, 0.024760757240333726, 0.04722846984597189, 0.07620344523872648, 0.06824242456683091, 0.014181693167691784, 0.02972928241693548, 0.04075178184679576, 0.1235364196555955, 0.05437791174543755, 0.010841278841585984, 0.016802019838775908, 0.07288327161222696, 0.17896939228687966, 5.634310739380973, 83.80159091949463, 73.7984778540475, 40.99582733426775, 20.374616146087646, 93.01926571982247, 94.27868924822126, 36.37042542866298, 8.235277686800275, 0.1384907207850899, 0.14079767199499266, 0.45897552583898815, 0.2616919848535742, 0.18237645232251712, 0.4700561655419213, 0.5533084496855736, 0.06561920139938593, 0.5936628271426473, 4.076909806047167, 5.263592643397195, 4.479467153549194, 16.606538568224224, 47.76577336447579, 87.0001802444458, 79.97040285382951, 70.85894516536167, 75.59426062447685, 82.29998098100934, 80.93192236764091, 86.5378749029977, 77.76031289781842, 70.00621359688895, 74.2064482825143, 70.57049070085797, 71.56652191707066, 66.82775320325578, 66.91079112461635, 70.89602075304303, 63.749388558524, 60.700178555079866, 66.30974415370396, 68.0730232511248, 62.15005220685686, 64.88242435455322, 64.95819446018764, 59.85966886792864, 54.92632974897112, 51.57961177825928, 51.948067801339285, 53.32012162889753, 57.61379221507481, 63.62691266196114, 62.17503098079136, 69.69759546007428, 44.0557792527335, 37.14315891265869, 65.51689910888672, 66.07981436593192, 67.6071743283953, 65.04300417218889, 66.99243940625871, 65.04221207754952, 67.35310649871826, 59.20767075674874, 51.597576345716206, 51.781759193965364, 54.38669443130493, 53.64365407398769, 55.98623922892979, 57.76813949857439, 59.69289125714983, 57.640244007110596, 58.98901094709124, 57.89455502373831, 58.66996356419155, 56.079053265707834, 58.81998906816755, 57.556122166769846, 59.25761440822056, 56.72725418635777, 60.94900049482073, 59.576793806893484, 65.3794915335519, 63.58438968658447, 65.04836818150112, 64.97311919076103, 66.24172128949846, 66.46017265319824, 67.41738428388322, 62.49374485015869, 70.5095966884068, 66.24880845206124, 72.15911987849644, 47.026245321546284, 2.9653474177633012, 0.49885064044169014, 6.792092544691903, 15.239928654261998, 0.4801943472453526, 0.7530378922820091, 0.9305743000337056, 0.8198080179946763, 2.423661078725542, 42.92573118209839, 29.118804216384888, 69.72385270254952, 68.16998536246163, 6.762295629296984, 27.341625247682842, 51.91978863307408, 66.45134149278913, 8.445974860872541, 0.643085635134152, 0.19417156225868634, 0.029336495458015373, 0.05184181247438703, 0.05966120931719031, 0.02426524007959025, 0.04057105065190366, 0.13649069810552256, 0.11781977569418293, 0.04106361957799111, 0.015751269346635257, 0.035284072027674744, 0.03343038899557931, 0.006639207314167703, 0.021910306265843765, 0.04471331016559686, 0.05672554452238338, 0.058975264696138244, 0.013387203299706536, 0.037223321718296835, 0.06783686418618474, 0.02093077989827309, 0.03847130707332066, 0.06067562595541988, 0.015220787276380827, 0.0876941711508802, 0.04574051040357777, 0.07290301019591944, 0.07853719179651567, 0.1776582726410457, 0.11256916993962866, 0.25416209176182747, 0.2464693502656051, 0.19960111805370875, 0.17916392827672617, 0.12360254967851297, 0.1818889927651201, 0.13578724728098937, 0.3078024020152432, 0.16505791805684566, 0.11566184434507575, 0.1400892407234226, 0.0992234107106924, 0.1453361213207245, 0.18127413147262164, 0.22458628378808498, 0.11026075987943582, 0.13784130848944187, 0.14103011095098086, 0.1265846025198698, 0.11707127014441149, 0.12975626518683775, 0.21853578702679702, 0.1879590041935444, 0.11467628580118928, 0.12263369666678564, 0.10557971641953502, 0.15004975481757096, 0.14682857266494206, 0.1243137629436595, 0.11367860862186976, 0.1214938528303589, 0.18974390413079942, 0.2532801048031875, 9.273899623325892, 111.38397298540387, 84.82115568433488, 92.44813769204276, 22.34480217524937, 67.30575452532086, 106.73453031267438, 50.08489792687552, 9.42750344957624, 0.181449668481946, 0.674991708781038, 0.7846608268363136, 0.9788318191255841, 2.5094674229621887, 3.762611516884395, 0.8405969196132251, 0.6768608827676091, 0.6487293637224606, 4.147329364504133, 7.682573676109314, 4.019369167940957, 14.067033648490906, 43.058024883270264, 89.10278851645333, 85.77860355377197, 69.56277956281389, 76.17915303366524, 78.64627075195312, 83.85702364785331, 92.93926416124616, 88.39324542454311, 73.34489250183105, 79.60630335126604, 75.34258297511509, 74.21042960030692, 68.9072378703526, 70.61324991498674, 75.05424662998745, 68.71685722896031, 67.57783903394426, 74.44910022190639, 73.17365414755685, 67.34811074393136, 70.49693012237549, 68.84319632393974, 63.62227821350098, 61.78813443865095, 56.62493848800659, 54.7806955065046, 56.642468793051584, 59.68383080618722, 68.48309203556606, 65.58364350455147, 72.91611221858433, 46.117327145167756, 38.757510321480886, 68.35718372889927, 67.29243482862199, 72.71073041643415, 67.7615771974836, 70.96178545270647, 69.78877667018345, 71.61363070351737, 61.976527895246235, 54.72886194501604, 56.42593513216291, 56.79016317640032, 57.77634532111031, 60.1355470929827, 63.13737733023507, 63.93926892961775, 63.59916155678885, 63.19932746887207, 64.18572153363908, 63.21293204171317, 61.882303374154226, 63.899184771946494, 64.58454813276018, 65.85815293448312, 63.28249740600586, 66.92256832122803, 65.63046046665737, 74.364089012146, 71.76551832471574, 73.68478448050362, 68.68394361223493, 72.60450635637555, 73.01347037724086, 71.62845121111188, 69.94448580060686, 77.01419448852539, 72.46757125854492, 75.05741500854492, 48.976243359701975, 4.259289162499564, 0.4667000227740833, 7.64827823638916, 20.327340602874756, 2.357230003390993, 3.8287913714136397, 2.3752568875040327, 1.1286990344524384, 2.5257757135799954, 34.20395973750523, 40.33152396338326, 82.25195503234863, 47.789539677756174, 11.877658009529114, 64.79154886518205, 61.32170186723982, 78.68574346814836, 14.339966705867223, 1.1997249318020684, 0.3346434288791248, 0.25175304817301886, 0.1251788679510355, 0.1897781022957393, 0.1346109796847616, 0.13093897886574268, 0.17007989143686636, 0.18124404522989476, 0.1024161826020905, 0.08842951990664005, 0.09278669860213995, 0.0850137814081141, 0.07804620385702167, 0.10225692364786353, 0.1298969526376043, 0.1556331209306206, 0.08051128765302044, 0.1586106140166521, 0.18935637921094894, 0.19434206453817232, 0.2336324719446046, 0.15513248422316142, 0.12674561887979507, 0.1313115760151829, 0.1930877382733992, 0.11835515339459692, 0.17578759230673313, 0.11321163403668574], [0.23700533381530217, 0.04175420877124582, 0.07207908547882523, 0.15408032068184443, 0.08630943045552288, 0.03753730362015111, 0.15348838030227593, 0.07511637785605021, 0.13230577909520694, 0.0557207189766424, 0.09012160303869418, 0.03482467667864902, 0.06373924549136843, 0.12348156688468796, 0.016253670245142918, 0.03034327857728515, 0.05444075765886477, 0.06461626557367188, 0.0523441624827683, 0.04554094307656799, 0.09965947124042682, 0.024663473978372555, 0.04344328599316733, 0.07437944132834673, 0.1320916334433215, 0.10715317127427884, 0.01404200994875282, 0.020195685593145232, 0.047771535348147154, 0.03906584624201059, 0.10755169524678163, 0.06750646512955427, 0.04958031971805862, 0.17790851635592325, 0.10090474584805113, 0.3703959004155227, 14.989180326461792, 78.76327146802629, 60.917782238551546, 71.26075254167829, 29.801765237535747, 31.00010715212141, 92.40343993050712, 52.154884406498496, 18.165910618645803, 1.6738957336970737, 1.0771353670528956, 0.1260292080364057, 0.29573237683091846, 0.3971241819007056, 0.3148300977689879, 0.2325942319418703, 0.300456310489348, 0.18929030347083295, 4.406517582280295, 1.7798745440585273, 0.39463849099619047, 0.19669409761471407, 11.665685841015407, 68.22424384525844, 77.0022713797433, 74.25576659611293, 71.38620921543666, 68.22803061349052, 62.232798303876606, 63.328292982918875, 76.11611202784947, 72.48676218305314, 72.4185517174857, 68.30646187918526, 69.53688362666539, 63.378792490277974, 66.307875088283, 63.722040448869976, 63.79717132023403, 61.522511754717144, 59.12553610120501, 60.97869709559849, 61.00300884246826, 59.98971135275704, 60.547213963099885, 58.42099571228027, 56.39162145342146, 47.90624509538923, 51.206132207598, 48.75444643838065, 65.30909933362688, 60.62273393358503, 68.22600868770054, 37.7446505682809, 14.26137910570417, 70.44407517569405, 61.29067121233259, 65.5737909589495, 62.73240852355957, 64.64884676252092, 62.20312949589321, 63.26999759674072, 48.98654753821236, 48.59511382239205, 53.546063150678364, 53.496661458696636, 55.74272918701172, 58.962003299168174, 59.43010343824114, 58.67416722433907, 56.50172955649239, 58.3570305960519, 57.676996503557476, 55.95196376528059, 56.2517785344805, 53.095566272735596, 53.826933656420024, 56.7641977582659, 58.28891045706612, 54.450916630881174, 51.31352009092058, 52.03788716452462, 58.58356966291155, 59.621387345450266, 52.34362179892403, 48.786036423274446, 42.8617764881679, 48.83535821097237, 60.123137610299246, 57.503632000514436, 55.95469440732683, 24.290158816746303, 1.1147687648023878, 0.3064563242452485, 9.993515866143362, 23.165125608444214, 0.030434768846524612, 0.24403498374990054, 0.27742115940366474, 0.3924087163593088, 7.124798348971775, 25.51631784439087, 20.833336217062815, 83.9507965360369, 29.035246917179652, 9.19938279901232, 51.98219040461949, 43.24005726405552, 46.97521080289568, 9.315158026559011, 0.26214445914540974, 0.038278182436312945, 0.07832187227904797, 0.02183886501006782, 0.08031468213136707, 0.030964243292276348, 0.14772151117878302, 0.041353374387004545, 0.08041859976947308, 0.0501839682193739, 0.08641468480761562, 0.0762152788894517, 0.335917663361345, 0.14264521428516932, 0.160039839467832, 0.07775935996323824, 0.17253536039165088, 0.043518834082143645, 0.10689294630927698, 0.008955667344188052, 0.09005022115473237, 0.0312556469413851, 0.0807578537080969, 0.07471423050654785, 0.08190522928323064, 0.03487913589924574, 0.01678979942309005, 0.028942928183823824, 0.027670951526878134, 0.05231608131102153, 0.14260828840945447, 0.04320756292768887, 0.06241329985537699, 0.11570243430989129, 0.05507798007290278, 0.019997753535530398, 0.05811283990208592, 0.031746051340763054, 0.11384122632443905, 0.09872830406363521, 0.027593372921858515, 0.02998452014955027, 0.03413642164585846, 0.029244611638465097, 0.023914201684030037, 0.025165907107293606, 0.025752675353682468, 0.08106649214667933, 0.046285496159855805, 0.05232188957078116, 0.04660754245040672, 0.08887752943805285, 0.05353247407557709, 0.11248779323484216, 0.035305676582668505, 0.07623813194887978, 0.05960463985268559, 0.0036927376973575777, 0.013356712480474795, 0.030095681148980345, 0.035071123990097215, 0.09892167297324964, 0.04054755976955805, 0.13672225496598653, 0.09684146781052862, 0.5994524136185646, 20.026936973844254, 93.86740452902657, 61.45515591757638, 42.40226779665266, 26.242852755955287, 76.53606809888566, 102.1045981815883, 53.00024741036551, 24.312406948634557, 1.4956947416067123, 1.4614003875425883, 0.3291951183761869, 0.09842752984591893, 0.51247888058424, 0.2974525716687952, 0.3736546055546829, 0.33469564893415993, 0.90183524787426, 10.79669896193913, 5.635016415800367, 0.5556214941399438, 0.4532978433583464, 22.1471745627267, 84.40335355486188, 83.40860080718994, 77.32794734409877, 70.61828735896519, 68.65548379080636, 64.23484529767717, 67.41612665993827, 75.35606942858014, 70.70285388401577, 71.59849057878766, 68.85653686523438, 71.46659292493547, 66.62032168252128, 68.43028572627476, 65.30597264426095, 67.68312508719308, 64.75561973026821, 68.46081611088344, 67.0142845426287, 68.90026187896729, 65.91946383884975, 67.79787458692277, 62.51422119140625, 60.480010986328125, 51.33277007511684, 56.65934944152832, 53.611466544015066, 68.86065714699882, 66.82093702043805, 75.96309879847935, 42.126837730407715, 17.969502414975846, 72.5268463407244, 66.06490353175572, 69.52782317570278, 66.24517454419816, 69.671372958592, 65.93059485299247, 67.54097884041923, 53.88804653712681, 53.04695667539324, 55.338920729500906, 55.62892811638968, 59.79824679238455, 62.45574515206473, 63.80043697357178, 62.82679285321917, 58.915596280779155, 59.611180441720144, 61.48772212437221, 60.068761008126394, 61.961485045296804, 56.694691453661235, 58.07712241581508, 60.651033946446006, 65.68136296953473, 62.47214984893799, 59.91781834193638, 56.94749123709542, 62.30423273359026, 64.3458080291748, 63.23998832702637, 60.37421076638358, 56.440505504608154, 61.40819304330008, 70.62755625588554, 65.8148934500558, 62.64884948730469, 30.820430210658483, 1.4203579212938036, 0.7632037582142013, 12.635309559958321, 27.22986694744655, 0.14507753162511758, 0.5536296953048024, 0.4163531857941832, 0.5265811724322182, 11.724764636584691, 50.397459166390554, 17.941947596413748, 82.0496026447841, 62.891550064086914, 8.153438329696655, 30.27584430149623, 45.06233351571219, 57.472545760018484, 12.891536542347499, 0.29156961877431187, 0.10454512014985085, 0.03568796321217503, 0.04770844516211322, 0.03069475293159485, 0.11138773869190897, 0.03752979902284486, 0.06699445617518254, 0.07679218293300696, 0.03989654613126602, 0.0806109644472599, 0.0393035031322922, 0.18957535603216716, 0.06904450724167482, 0.057964403581406386, 0.045140336001557965, 0.12607289212090628, 0.007236677754138197, 0.04429229275722589, 0.10403024777770042, 0.0735838861603822, 0.025045258491965275, 0.033063779917678664, 0.10275566724262067, 0.06561002082058362, 0.02039010962471366, 0.014616025977634957, 0.06840809567698411, 0.039203269939337454, 0.10269659398389713, 0.2929740234145096, 0.09993079025298357, 0.09428740771753447, 0.19039964037282125, 0.10571693655635629, 0.167144684653197, 0.16320661668266567, 0.2503501634512629, 0.2558733027960573, 0.14684036560356617, 0.1363716423511505, 0.08834143249051911, 0.13591777027717658, 0.23986877873539925, 0.1848316905753953, 0.181735223159194, 0.13227044099143573, 0.22126862752650464, 0.13514802658132144, 0.08164647673921925, 0.21206876475896153, 0.26091487226741655, 0.13331120514443942, 0.22358031491083757, 0.2630723150713103, 0.23864261167390005, 0.20912922892187322, 0.1067305321672133, 0.10683774748550993, 0.19326166036937917, 0.13740456263933862, 0.13204220895256313, 0.22367682973189013, 0.14635600016585418, 0.25821563282183235, 0.5706150010228157, 29.870684419359478, 114.19727775028774, 76.11664009094238, 97.93349729265485, 39.40154927117484, 48.68360260554722, 106.28958851950509, 76.00819955553327, 30.538315977369034, 2.7012911183493475, 1.315242316041674, 0.40555666227425846, 0.9241877113069806, 0.9838444015809468, 1.493238444839205, 1.4276778485093797, 1.1130538625376565, 0.8862183572990554, 8.820702501705714, 4.4430911626134595, 0.629505815250533, 0.3898426869085857, 17.78901253427778, 78.50273486546108, 88.46453394208635, 86.88055310930524, 83.19055938720703, 78.65219756535122, 69.64284365517753, 68.89808709280831, 79.0004551751273, 72.56299086979458, 77.0108801977975, 74.41233730316162, 79.85358279091972, 76.55565507071358, 75.8681308201381, 74.07876123700822, 77.9636241367885, 71.84321308135986, 75.15514142172677, 74.71460478646415, 73.70300265720913, 72.11936923435756, 75.53637518201555, 68.20399679456438, 65.91462789263043, 57.57045977456229, 61.40677561078753, 56.99720907211304, 73.50784860338483, 71.77516242436, 78.05945369175502, 48.21688863209316, 19.603180238178798, 80.89806379590715, 69.92350918906075, 73.9143807547433, 70.50043201446533, 70.97308322361538, 69.4434095110212, 71.0934955051967, 56.14139250346592, 56.900438036237446, 58.64073944091797, 59.725582531520296, 62.64641761779785, 67.41211754935128, 68.37381076812744, 67.24687549046108, 62.790439878191265, 64.45904282161167, 67.303968838283, 67.27341760907854, 68.33074583326066, 64.1740277154105, 65.5824692589896, 69.38195269448417, 75.16866956438336, 72.5310638972691, 69.52061789376395, 63.636744362967356, 72.60090024130685, 72.65938322884696, 71.08927100045341, 65.37962354932512, 65.86544159480503, 69.58871718815395, 74.76600755964006, 68.54638317653111, 64.62821756090436, 30.69579689843314, 1.3588240231786455, 0.5089024039251464, 17.55133203097752, 35.63296447481428, 0.5472482091614178, 1.1243709581238883, 1.0570691866534097, 0.6277543806603977, 10.166597230093819, 38.30735043116978, 32.55832059042794, 95.31441552298409, 43.950316020420615, 15.447658947535924, 75.61387538909912, 58.61075101579939, 72.61312907082694, 21.319529465266637, 0.4110103196331433, 0.16214598502431596, 0.18080484308302402, 0.06317428366414138, 0.18012412318161555, 0.23980567497866495, 0.1701165730399745, 0.12975948144282612, 0.11073148676327296, 0.0810354830963271, 0.1512700186244079, 0.2172389437577554, 0.32856028101273943, 0.16007892308490618, 0.20530649833381176, 0.14358923291521414, 0.1361745007868324, 0.11974064047847476, 0.11386452721697943, 0.2614952368395669, 0.19701378260340008, 0.05448128316285355, 0.11263392932180848, 0.1541346034833363, 0.2035703579229968, 0.08276058374238865, 0.09601248122219529, 0.1297229491174221, 0.1418449907962765, 0.20355794073215552], [0.08587843179702759, 0.04695975301521165, 0.0636779602084841, 0.1238231278423752, 0.04846911345209394, 0.08733083600444452, 0.1207858422505004, 0.04772546960573111, 0.09797242962356124, 0.04865505240325417, 0.10345127420233828, 0.09583002315568072, 0.11739957252783434, 0.04597752947094185, 0.06131657013403518, 0.022369353865672435, 0.03339588548988104, 0.08865240508956568, 0.02263375012470143, 0.05651652180988874, 0.12005705492837088, 0.07079955842345953, 0.08804914674588613, 0.0937758737376758, 0.04072658784155335, 0.10885238580937896, 0.025899535776781182, 0.08447786766503539, 0.141560182507549, 0.01823184748978487, 0.012642394917617952, 0.02062284543977252, 0.24831871102963174, 0.028669536246785095, 0.014940380983586823, 0.07287538703531027, 0.12340691446193627, 14.66011711529323, 78.27519525800432, 64.94353376116071, 78.26571096692766, 19.37223253931318, 24.378984587533132, 79.41583238329206, 57.074684960501536, 27.62413205419268, 11.21257209777832, 0.1047205010961209, 0.5665423795580864, 0.20683592983654567, 0.3674719030303614, 0.1400973288608449, 0.7473829271537917, 2.816644025700433, 4.556452325412205, 11.438333834920611, 6.954165356499808, 0.9731324506657464, 0.16432823506849153, 0.4852476960846356, 10.930548191070557, 22.434480837413243, 49.29154913766043, 67.7821786063058, 83.8079832621983, 89.8442029953003, 83.57778249468122, 78.7139253616333, 83.13698877607072, 81.02802985055106, 75.6592332295009, 72.33249132973808, 61.933761732918875, 56.39568962369646, 59.17109543936593, 59.39446612766811, 58.45243631090437, 54.28365959439959, 54.69102552958897, 53.85050194604056, 59.71610518864223, 60.329248973301475, 61.89341354370117, 56.09232432501656, 57.76692008972168, 52.69779927389962, 62.80437101636614, 56.10586983816964, 73.9351280757359, 30.5267368044172, 3.7580739089420865, 76.14428002493722, 55.96790293284825, 59.88193089621407, 55.721835953848704, 62.20846571241106, 57.56180231911795, 53.80822910581316, 48.88774068014962, 56.7189302444458, 55.98529774802071, 60.10758754185268, 59.01072406768799, 56.777656418936594, 59.77844442640032, 62.458065850394114, 60.2748932157244, 59.89420141492571, 58.21766015461513, 59.9475496837071, 55.82251187733242, 58.73547118050711, 56.07617323739188, 55.39090020315987, 53.098258699689595, 54.66132892881121, 56.93219130379813, 55.07761287689209, 40.75901188169207, 24.562861715044292, 12.998459764889308, 6.21846490246909, 3.949024736881256, 5.403863745076316, 4.984862182821546, 3.1641907479081834, 1.5962602538721902, 0.11459031541432653, 0.11202797040875469, 0.58137075815882, 1.3762125415461404, 3.327236307518823, 0.29561279181923183, 0.1672350519469806, 0.049402648716100624, 17.37770697048732, 21.622179099491664, 22.654796055385045, 85.89880738939557, 23.956026894705637, 10.79120033127921, 51.86476584843227, 40.09889827455793, 53.38525404248919, 6.078814796039036, 0.6148788258433342, 0.025151077724461044, 0.12281813605555467, 0.07534036905105625, 0.03469164310289281, 0.08243784534611873, 0.04174304347751396, 0.06544455327093601, 0.09642495587468147, 0.0977991996333003, 0.11003810539841652, 0.09217769306685243, 0.13712582045367785, 0.018745181283780506, 0.05330026921417032, 0.1414135918021202, 0.07035945382501398, 0.00603036759587537, 0.1796028861509902, 0.07528723975909607, 0.037606375092374425, 0.02301931577468557, 0.05278644517862371, 0.014235557821978415, 0.02917425094970635, 0.08502685677792345, 0.0391148398630321, 0.031099421038691486, 0.10982687744711127, 0.04340946102248771, 0.12885645989860806, 0.10808549874595233, 0.04203265240149839, 0.05611815729311534, 0.05284671265898006, 0.03463393709223185, 0.047484192731125016, 0.048763356770255735, 0.027820310655183027, 0.030702735896089246, 0.049171858600207737, 0.11903998521821839, 0.011786975997633167, 0.04618706787005067, 0.05308364012411662, 0.014768942325775112, 0.01771822022939367, 0.013388310159955705, 0.08887932755585227, 0.057729250485343594, 0.04346562675865633, 0.03420444478147796, 0.04883889468120677, 0.08543359102415186, 0.04652294270428164, 0.056289921647736, 0.09704949986189604, 0.056481041213763614, 0.06394055326070104, 0.039056472280727964, 0.05001222422080381, 0.020006784836628606, 0.046587532452706776, 0.11883873173168727, 0.07998102610664708, 0.07637360825070313, 0.026406396346698915, 0.10852635651826859, 22.408062049320765, 92.83952277047294, 64.38002095903668, 55.50065394810268, 8.67463833945138, 61.13321113586426, 105.70187514168876, 54.044391427721294, 41.81397077015468, 15.333275965281896, 0.09263991112155573, 0.35507178413016455, 0.3429301327892712, 0.40034106214131626, 0.536071488899844, 0.46158495438950403, 1.3751606494188309, 2.4040882204260146, 8.81221788270133, 7.299972857747759, 1.7307109364441462, 0.13112834441874707, 2.584798489298139, 23.04502773284912, 40.896770341055735, 70.50532354627336, 82.92140007019043, 87.57849270956856, 83.54180472237724, 81.3761762891497, 77.19022709982735, 77.02278941018241, 76.2089399610247, 78.68485409872872, 68.33100291660854, 64.71563284737724, 64.92744173322404, 69.78733144487653, 65.85779162815639, 65.8560962677002, 62.002611432756694, 63.13718278067452, 62.58434935978481, 67.15559005737305, 65.64760862077985, 67.95010266985211, 60.43473652430943, 62.17413466317313, 54.93743644441877, 68.67985112326485, 61.23416151319231, 72.96938405718122, 34.00432062149048, 4.900599641459329, 79.89500795091901, 61.230555398123606, 65.978759765625, 62.16421263558524, 67.1658455984933, 62.09588405064174, 60.65977478027344, 51.0446525982448, 57.792176791599815, 59.647033146449495, 62.78119877406529, 60.14576094491141, 60.31688812800816, 61.092536381312776, 65.92555740901402, 61.81534358433315, 64.09312983921596, 62.71310642787388, 61.33245073046003, 57.863774503980366, 64.11435658591134, 61.92112990788051, 64.5365777696882, 58.8456209727696, 60.34183216094971, 61.21625600542341, 64.8523872920445, 55.827716078077046, 36.989159039088655, 19.835022517613, 10.89634394645691, 7.519811255591256, 10.412166544369288, 8.782144342150007, 4.602651332105909, 2.54531752211707, 0.3754069358110428, 0.5569937090788568, 2.907286967550005, 2.2939442907060896, 3.384153344801494, 0.41043104071702274, 0.03315904962697199, 0.30004701816609924, 32.03956460952759, 44.56865010942732, 12.01529574394226, 87.85174451555524, 59.755466733660015, 8.873079759734017, 35.306861196245464, 41.833943367004395, 67.0188911982945, 12.23834594658443, 0.6663924444999013, 0.03421693661117128, 0.12864637188613415, 0.059753822561885626, 0.033952443660902124, 0.044244340687458, 0.05391901172697544, 0.013296027701081974, 0.0330641632899642, 0.08899193722754717, 0.037576088681817055, 0.037973679668669186, 0.04532848697687898, 0.030808360049767152, 0.04615126157711659, 0.027523334537233626, 0.049561836424150636, 0.055647657718509436, 0.08210303581186704, 0.005774566679195101, 0.049937425913023095, 0.022142777452245355, 0.05797994203333344, 0.015762957112331475, 0.0581866984388658, 0.12621013261377811, 0.026040301259074892, 0.09306949164186205, 0.036458327767572234, 0.019800691699076976, 0.026550590127174343, 0.11312721749501568, 0.08937976070280586, 0.12140149064362049, 0.1343492551573685, 0.1610564070620707, 0.16070154681801796, 0.11782128204192434, 0.1550891258354698, 0.211989606863686, 0.09946961714220898, 0.20642150778855595, 0.1374454511595624, 0.1559025671865259, 0.13041975029877254, 0.2092324612396104, 0.23502734995314054, 0.15042896089809282, 0.21590708808175155, 0.13368650286325387, 0.1626645214855671, 0.12336092335837227, 0.14305230815495762, 0.16371406588171208, 0.15324604830571584, 0.09259824228606053, 0.18094394276184694, 0.09766301765505757, 0.1616393636379923, 0.281898133456707, 0.10537946037948132, 0.17171163244971208, 0.13196443526872567, 0.3542415829641478, 0.22089822883052485, 0.1866874974220991, 0.185490914487413, 0.29019946658185547, 36.89314535685948, 109.11683137076241, 82.85935960497174, 101.51350797925676, 26.773351192474365, 40.9476763180324, 93.26985945020402, 77.96660491398403, 44.37542070661272, 17.285103116716655, 0.1626268085092306, 0.7237228995987347, 0.4347881408674376, 1.72194904088974, 1.9420851256166185, 3.549250142914908, 7.288843580654689, 7.625818184443882, 17.282544442585536, 12.47334270817893, 1.308353828532355, 0.19192204225276197, 2.113340198993683, 19.506478684289114, 36.288249083927695, 66.1448564529419, 85.81157275608608, 94.88512802124023, 90.55122389112199, 88.08300835745675, 84.03382750919887, 83.98935903821672, 85.81729112352643, 84.9429020200457, 77.48050199236188, 74.09071213858468, 70.7988224029541, 77.72323036193848, 76.14793477739606, 70.74941376277378, 67.08596910749162, 67.54196548461914, 67.20502649034772, 71.77191761561802, 71.147218976702, 71.94451781681606, 62.86921855381557, 64.0831105368478, 57.62143175942557, 72.62942259652274, 63.882140840802876, 78.04289613451276, 35.859729358128135, 4.599768263953073, 85.70761380876813, 65.36883994511196, 69.40279034205845, 64.18159430367606, 69.96299580165318, 62.98214067731585, 61.16196972983224, 56.21579033987862, 63.59854316711426, 63.30894224984305, 64.91997241973877, 65.46575341905866, 63.18310342516218, 65.01375225612095, 71.6417361668178, 66.97802189418248, 69.06417683192662, 66.34153216225761, 70.25143636975969, 63.78903497968401, 71.6667983191354, 72.91912078857422, 73.92073140825543, 69.44739777701241, 70.82569803510393, 73.5932628086635, 76.19003391265869, 61.2566945212228, 38.23948390143258, 17.64052258219038, 7.8906096901212415, 5.204478672572544, 8.918542691639491, 7.56600114277431, 4.350525958197458, 1.9081852989537376, 0.2517287294779505, 0.3780143287565027, 4.9511217304638455, 3.204032587153571, 3.670590877532959, 1.4995624997786112, 0.13023620657622814, 0.4039111877126353, 25.326380150658743, 33.40147406714303, 30.818345751081193, 99.45351995740617, 38.49150896072388, 16.57613672528948, 69.94902992248535, 52.105979510716026, 78.81155450003487, 19.278645515441895, 0.7664701172283718, 0.19512968084641866, 0.17998543062380382, 0.11511327592389924, 0.15166840010455676, 0.11940860615244933, 0.06425360217690468, 0.17138493140893324, 0.17135751859417983, 0.15202878362366132, 0.19076014602822916, 0.13240583586905683, 0.1943864542990923, 0.14898275850074633, 0.10247917100787163, 0.13841251283884048, 0.1574370198483978, 0.10841386898287705, 0.20232458119945868, 0.13654152037841932, 0.08305215023990188, 0.07453933132014104, 0.1046038812824658, 0.11519107674913746, 0.15398943770144666, 0.20130234105246408, 0.1162606922111341, 0.15964303218892642, 0.15087165071495942, 0.17750269813197, 0.194688918069005], [0.08124223271650927, 0.14860572373228415, 0.09105022570916585, 0.07813457625785045, 0.05111094883510044, 0.0986570714573775, 0.04622675199061632, 0.056055297808987756, 0.03190860118983047, 0.011883993782768292, 0.03630490082183054, 0.08079218758004052, 0.06112215628049203, 0.055974117879356654, 0.012950045239579464, 0.05909294980977263, 0.06541629907275949, 0.047189745852457624, 0.05773368810436555, 0.05397565583033221, 0.16850617873881543, 0.12887131981551647, 0.22050473280251026, 0.06627508691911187, 0.18606054463556834, 0.07944420991199357, 0.03427347554160016, 0.1691576944930213, 0.1326265904520239, 0.057062345556914806, 0.11466301365622453, 0.08286452852189541, 0.08960654067673854, 0.08467485995164939, 0.1192346162029675, 0.2918655957494463, 0.1286068404359477, 0.10611720436385699, 26.35399440356663, 79.1723188672747, 53.60923964636666, 71.39642306736538, 26.456376109804424, 17.095259223665508, 67.26723371233258, 57.52573422023228, 25.24431324005127, 26.698208161762782, 3.1688942440918515, 0.5319885537028313, 0.1557823714933225, 0.4181731252798012, 0.14223037154546805, 0.6980814955064228, 4.481809130736759, 8.396849359784808, 14.148363181522914, 13.003432069505964, 37.41322496959141, 48.493958473205566, 12.929916654314313, 4.210270924227578, 1.111406488077981, 3.713086928640093, 12.891314199992589, 25.186964545931133, 41.35863447189331, 55.74288552148001, 66.59141022818429, 70.80757018498012, 75.11953885214669, 76.1193151473999, 74.59905624389648, 63.71085384913853, 51.3366436958313, 48.00416258403233, 49.792298861912315, 53.939424991607666, 57.28273139681135, 56.118661471775596, 59.92837960379464, 60.930705887930735, 62.42959213256836, 57.698622771671836, 63.19203186035156, 57.931515966142925, 69.10781151907784, 64.9779759815761, 75.88076959337506, 22.130293914249965, 0.34199367303933415, 70.46447508675712, 56.533444608960835, 61.36487102508545, 53.90136275972639, 56.689056464603965, 49.59855876650129, 50.22128759111677, 48.67533424922398, 53.148129395076204, 54.50715882437569, 57.95165531975882, 60.50369044712612, 70.41602529798234, 61.484498160226, 58.16509008407593, 59.9493145261492, 63.61090401240757, 64.0591323035104, 64.5843118940081, 64.36643723079136, 61.17421245574951, 59.64068944113595, 61.42712688446045, 66.5587467466082, 59.3974677494594, 34.826539175851, 17.043161630630493, 7.430550353867667, 1.8033153776611601, 0.3619234950414726, 0.2982112823852471, 0.13878600565450533, 0.2723407234464373, 0.15239925017314299, 0.2027345249163253, 0.07177899658147778, 0.7711790959749902, 1.2338696824652808, 1.9697087747710091, 0.38134908410055296, 0.4461717600268977, 0.45905439874955584, 2.247622170618602, 25.6954128742218, 17.193597078323364, 28.531797817775182, 95.02314703805106, 14.928315843854632, 12.471782837595258, 63.17668328966413, 41.721514565604075, 61.793324742998394, 12.551097393035889, 0.41218885353633333, 0.07391975420926299, 0.3241650297173432, 0.09288634825497866, 0.09917237809193985, 0.022360276763460467, 0.042019404005259275, 0.08011018524744681, 0.08933618518390826, 0.050190950344715796, 0.18172697217336722, 0.10438974241593055, 0.22551715240946837, 0.06715064815112523, 0.2005135983760868, 0.12659666687250137, 0.1631479234035526, 0.08064381232751267, 0.22606107965111732, 0.02798663655162922, 0.05551708722487092, 0.057384242569761615, 0.0698868745405759, 0.1027333570112075, 0.10458868888339826, 0.01683973960046257, 0.07082745299807616, 0.09277113979416234, 0.07754623211388077, 0.08126548611159835, 0.01389076279675854, 0.05527495200346623, 0.018269185575523546, 0.08144347263234002, 0.05350411131179758, 0.02522661054639944, 0.07168059543307338, 0.03723600014512028, 0.021063540363684297, 0.0632071044029934, 0.08282344322651625, 0.07464519635375057, 0.044630043740783415, 0.08347207520689283, 0.0072139018780684894, 0.03679566823744348, 0.03883534789617572, 0.02790783149456339, 0.10011111093418938, 0.0625020522358162, 0.09878838155418634, 0.08307414834520646, 0.12127357322190489, 0.09312477188983134, 0.13136040339512484, 0.05900246037968567, 0.12714281970901148, 0.032924575065927844, 0.07566205571804728, 0.13689643490527356, 0.07770044276756899, 0.037193388145949156, 0.06028215028345585, 0.1247000257883753, 0.12443826054888112, 0.06674600379275424, 0.12464868782886437, 0.13851038472993032, 0.11330677143165044, 0.12360343177403722, 39.454286098480225, 91.76014791216168, 51.758128370557515, 46.61907393591744, 9.33603128365108, 44.583362919943674, 103.12381553649902, 49.92901161738804, 39.92088195255825, 40.26991081237793, 3.4589830551828658, 0.7910807452031544, 0.14458856571997913, 0.7899066082068852, 0.5581458615405219, 0.6086659963641847, 0.9751882489238466, 12.533653940473284, 16.930255140577042, 14.271872622626168, 34.79503951753889, 38.588988712855745, 10.999783515930176, 4.487376374857766, 3.2947141783578053, 11.99480550629752, 26.590295689446585, 44.56912606103079, 58.74696350097656, 66.09200150626046, 74.88947704860142, 71.3406846182687, 73.02332292284284, 80.95410796574184, 72.1015123639788, 62.50247178758894, 61.50259821755545, 60.095525469098774, 60.79065799713135, 62.11703436715262, 63.85111713409424, 61.97916126251221, 64.96894332340786, 65.29933711460659, 68.55489471980503, 62.29434544699532, 67.19142886570522, 59.174687658037456, 73.55956404549735, 68.91250460488456, 81.31793648856026, 23.72845949445452, 0.5145121514797211, 77.63699626922607, 61.557148524693076, 68.20435810089111, 58.51753398350307, 61.67135606493269, 55.73067058835711, 54.5708772795541, 53.487031255449565, 59.28842966897147, 59.70973369053432, 65.08630534580776, 66.28975418635777, 74.26730060577393, 66.18940830230713, 63.430500984191895, 64.0677411215646, 65.00266293116978, 66.20919677189418, 67.76260553087506, 68.7901051385062, 66.27516296931675, 63.03816400255476, 64.5934487751552, 70.01913724626813, 68.5512330191476, 50.536190373556956, 28.42120681490217, 12.321865030697413, 2.7090433537960052, 0.4584529453090259, 0.09844453393348626, 0.07383790931531362, 0.10776985782597746, 0.02259190147742629, 0.5182455054351262, 0.10021255870482751, 1.7340911264930452, 2.985969888312476, 1.2242458845887865, 0.41593072989157265, 0.2440529242157936, 0.2623366474040917, 4.684882393905094, 49.87907491411482, 32.47041198185512, 9.881918242999486, 108.28650774274553, 47.419607162475586, 5.549702090876443, 41.46761349269322, 43.17565093721662, 69.83000033242362, 22.397408723831177, 0.3931777679494449, 0.08493551917906318, 0.2529499296631132, 0.022942661673628857, 0.05740822199732065, 0.03154905905414905, 0.023805120394432118, 0.05136305173592908, 0.12482858103300844, 0.079334450087377, 0.07253333753240959, 0.0858847014605999, 0.09412798591490303, 0.12149392068386078, 0.1354096154017108, 0.07257511493350778, 0.14143008020307335, 0.018262217020882026, 0.04796090090115156, 0.0022461173648480326, 0.01422173691181732, 0.06475810653397016, 0.06456934487713234, 0.06267965877694742, 0.06121105793863535, 0.03420594434386917, 0.05225628201982804, 0.011531933343836238, 0.03404823923483491, 0.04218198778107762, 0.022195380879566073, 0.01343155574120049, 0.1005168002364891, 0.14068943208881787, 0.13011540020150797, 0.1189051331686122, 0.09265285078436136, 0.10856083288256611, 0.07820436358451843, 0.1515260434576443, 0.20133971476129123, 0.17853731475770473, 0.10511523884321962, 0.19704684082950863, 0.09545843702341829, 0.14737662539950439, 0.14780811938856328, 0.20102553947695664, 0.17543125285633973, 0.10023277904838324, 0.19380049859838827, 0.19176402501761913, 0.13630419597029686, 0.2293055626962866, 0.20391442946025304, 0.16669886000454426, 0.12797344156673976, 0.15665996154504164, 0.10757483329091753, 0.20217136799224786, 0.1785173522574561, 0.13910266437700816, 0.1350093340235097, 0.163326445966959, 0.1745270506611892, 0.1310807926846402, 0.23206429609230586, 0.27914165279694964, 0.1810270904430321, 0.1639269765998636, 53.17558520180838, 112.02005277361188, 67.11578382764543, 93.55404772077287, 35.7691387448992, 31.940594468797954, 81.57847309112549, 69.53434753417969, 39.94569396972656, 40.5550787789481, 5.276843726634979, 0.802950168294566, 0.5388133674860001, 1.0915459309305464, 1.0412658346550805, 3.404204760278974, 12.977753264563423, 23.318133626665386, 24.41219871384757, 19.60227002416338, 48.60920476913452, 57.71495451245989, 18.444929429462977, 6.153182234082903, 2.4364511924130574, 7.371636578014918, 17.203894308635167, 32.02004017148699, 48.00620188031878, 61.20482621874128, 75.39877305712018, 74.53083883013043, 79.0622455051967, 89.89089488983154, 87.36767046792167, 77.98681722368512, 76.96394511631557, 67.71407236371721, 69.08864143916539, 69.34969220842633, 71.49742903028215, 67.2451592854091, 72.42830698830741, 71.2671240397862, 73.16150869641984, 68.66705254146031, 74.0720909663609, 64.76111575535366, 80.09250354766846, 74.7111028943743, 83.01244926452637, 22.222524302346365, 0.6657077212418828, 83.35256358555385, 65.78136839185441, 72.60747323717389, 63.861678395952495, 64.98793969835553, 58.25636509486607, 58.68060820443289, 58.83025850568499, 63.83342007228306, 65.64539909362793, 71.39669404711042, 71.1802646092006, 82.57062721252441, 71.66037818363735, 66.75158705030168, 70.47880922045026, 72.87944657461983, 74.50453295026506, 74.86776392800468, 77.86842686789376, 75.20987933022636, 72.55717522757394, 75.5364933013916, 84.32944556644985, 77.91047736576625, 51.252407210213796, 25.706229482378276, 9.491732597351074, 1.4185238139969962, 0.2359941266477108, 0.23520366049238614, 0.21417100195373806, 0.21865640341171197, 0.1625095305166074, 0.3933582582644054, 0.13868539248194012, 2.10219007730484, 4.056492958750043, 2.9868486183030263, 1.8641067956175124, 0.43834336580974714, 0.503086544573307, 3.887022052492414, 44.35825170789446, 31.744780336107524, 37.342217854091096, 115.98605673653739, 28.55304888316563, 17.920637471335276, 86.0833237511771, 54.96058784212385, 84.15192604064941, 31.721462181636266, 0.37286280947072165, 0.29504787070410593, 0.28609066562993185, 0.11666497694594519, 0.12375136597880296, 0.17055250464805535, 0.04258525810603585, 0.25395361866269794, 0.21018197600330624, 0.14717377057032927, 0.13854819270116941, 0.12297835174415793, 0.21068291126617364, 0.11911360626774174, 0.10753433832100459, 0.15418016032448836, 0.15335864440671035, 0.11545787671847002, 0.24719798831003054, 0.13526268542877265, 0.10858578261520181, 0.1332913783511945, 0.14674128592014313, 0.13057907032115118, 0.2008729912340641, 0.07924370959933315, 0.13291665060179575, 0.14696482249668666, 0.10927300966743912, 0.08160833628582102, 0.09418142733297177, 0.13821111007460526], [0.09149151774389402, 0.19995234135006154, 0.0640152735369546, 0.011811742525813835, 0.055045138978000195, 0.03769190103879996, 0.047360624718878946, 0.07910741905548743, 0.007755705305109066, 0.1440612625862871, 0.11398821058017866, 0.12363427797598497, 0.009062416169659367, 0.09156864681946379, 0.04998494032770395, 0.1008041598168867, 0.13633151379014763, 0.07866571989974805, 0.08869954970266138, 0.13668232996548924, 0.09683151370180504, 0.1853927168995142, 0.226108224264213, 0.2056147160806826, 0.20598409697413445, 0.05941859233592238, 0.19424088139619144, 0.12775616108306817, 0.18575455248355865, 0.22391743824950286, 0.14760093550596917, 0.10812420238341604, 0.2945686892739364, 0.08974894482110228, 0.16357047430106572, 0.1799775596175875, 0.35256158454077585, 0.14712598813431604, 0.23940455221704074, 21.171525887080602, 92.9984211240496, 61.91758632659912, 75.47751004355294, 38.13484055655343, 9.45714967591422, 54.14078031267439, 77.63426562717983, 33.632456507001606, 30.7737626348223, 15.680041449410574, 0.679286346903869, 0.6172197173748697, 0.2228261503790106, 0.345977243568216, 0.9519955962896347, 1.6698971539735794, 5.804809979030064, 58.55768762316023, 61.19755145481655, 74.31736237662179, 64.88878195626395, 51.41413000651768, 26.256328787122452, 0.14699439305279935, 0.14769591683787958, 0.7822069185120719, 2.6159457436629703, 6.500250833375113, 12.456523724964686, 19.90339626584734, 32.022555419376914, 48.00547579356602, 52.875902448381694, 54.5887063571385, 60.27799211229597, 57.97953149250576, 45.96896226065499, 43.2297739301409, 48.09483310154506, 48.78862115315029, 57.09101322719029, 57.22400522232056, 64.28635924203056, 61.8587281363351, 67.34617914472307, 59.863684926714214, 64.52226448059082, 56.833144732883994, 75.26875141688755, 8.06019697870527, 0.04925823950075677, 59.496146065848215, 59.65597547803606, 55.33095114571707, 52.38101700374058, 51.74750804901123, 48.684505871364046, 50.59269659859793, 50.06044374193464, 53.20246083395821, 54.39653308050973, 55.51174674715315, 55.03490230015346, 55.69961908885411, 52.94889327457973, 52.57527821404593, 59.20931053161621, 67.89781052725655, 67.069230897086, 66.39105197361538, 67.92452635083879, 73.63512570517403, 72.95821135384696, 58.53809370313372, 28.030896970203944, 11.081486514636449, 3.292909166642598, 0.5265709129827363, 0.11600375814097268, 0.269364913127252, 0.20474985534591333, 0.17457551163222107, 0.22329995781183243, 0.10938044211694173, 0.21080367692879268, 0.931940923844065, 1.2481607156140464, 1.4294806889125278, 0.5193308900509561, 0.4194936087088925, 0.1717707599912371, 0.08108296697693211, 11.183388795171465, 39.23837430136544, 22.71714918954032, 43.61466939108712, 98.14103303636823, 9.721166457448687, 17.37948570932661, 62.59221472058977, 41.959278447287424, 64.1005505153111, 19.475734642573766, 0.22576978456761154, 0.15163743176630565, 0.32833888860685484, 0.24848364932196482, 0.29574203916958397, 0.19354260100850038, 0.04501193681997912, 0.09459502835358892, 0.029536534366863113, 0.1289032381027937, 0.15119977667927742, 0.08706465350197894, 0.15118649096361228, 0.13082898833921977, 0.1540541835129261, 0.2956575479890619, 0.16678260479654583, 0.08100094566387789, 0.1369940218116556, 0.17564587348273822, 0.2124154825827905, 0.17358426696487836, 0.0762677974998951, 0.08740480989217758, 0.039235642845077176, 0.058976893180183, 0.201967359653541, 0.08108271591897522, 0.07841540154601846, 0.07976734185857431, 0.06477217935025692, 0.051446657428251844, 0.25534407262291225, 0.14580994232424668, 0.07099756172725133, 0.03272900091750281, 0.025595173805153797, 0.05518120899796486, 0.03716114416186299, 0.05354740523866244, 0.06249189456658704, 0.05369808411757861, 0.0559088801299887, 0.08736411136175905, 0.05127433667491589, 0.10188035028321402, 0.07283069871898208, 0.06972369365394115, 0.04036943754181266, 0.06835567206144333, 0.09354948731405394, 0.013137936675255852, 0.06788599690688507, 0.04466502900634493, 0.16646070778369904, 0.24104918539524078, 0.07758309013609375, 0.13229512609541416, 0.05259081335472209, 0.20128491627318518, 0.048451780275042565, 0.08425536246172019, 0.11127132243875947, 0.14378253397132668, 0.23451872010316166, 0.3456912003457546, 0.12315996842724936, 0.2431674360164574, 0.13416192520942005, 0.10692490530865532, 0.06247698036687715, 0.30356535794479506, 35.00130026681082, 106.4427685056414, 60.275601931980674, 56.125032969883506, 9.605482425008502, 23.76079293659755, 94.88334928240094, 56.67036233629499, 33.55747849600655, 51.548789569309776, 26.66541961261204, 1.377296894788742, 0.9187921094042915, 0.25547546414392336, 0.4565190662230764, 0.40052011396203724, 0.3442566958921296, 7.852555274963379, 55.25090789794922, 66.01388985770089, 94.28656155722481, 77.99995626722063, 55.89673253468105, 19.125941480909074, 0.47841229715517586, 0.2790263018437794, 0.7353776342102459, 4.78963908127376, 14.440234422683716, 22.734097582953318, 33.82666213171822, 46.78553192956107, 57.778245653424946, 59.663069588797434, 64.5057486125401, 60.217181478227886, 58.52762276785714, 57.41774531773159, 53.70358228683472, 59.61318152291434, 57.80439519882202, 63.90936388288225, 63.37750012534005, 70.47672476087297, 66.40250955309186, 73.42319869995117, 65.10952622549874, 70.80413777487618, 59.25694043295724, 78.71876825605119, 10.790069511958531, 0.05337663493784411, 68.49004718235561, 66.04456615447998, 63.533772059849326, 60.15429333278111, 61.43618038722447, 57.683461802346365, 58.405021803719656, 58.545500482831685, 60.561054774693076, 61.86858763013567, 62.870601245335166, 63.59634058816092, 65.21661186218262, 58.329661641802105, 56.33865533556257, 63.100107192993164, 71.40932587214878, 71.01120798928397, 67.41760662623814, 69.2335183279855, 71.79758426121303, 72.61299010685512, 66.0683012008667, 39.32498012270246, 18.8080336025783, 5.695951248918261, 1.639713419335229, 0.6294301450252533, 0.33737930921571596, 0.06943769114358084, 0.275221511721611, 0.22475559184593813, 0.32741947365658625, 0.2621232345700264, 1.415392673441342, 2.2949061819485257, 1.0823503157922199, 0.19987808247762068, 0.8421990764992577, 0.17937052861920424, 0.45368471688457895, 21.486908095223562, 59.483479499816895, 25.27457959311349, 21.553873096193584, 117.2244758605957, 34.043581417628694, 2.2871459126472473, 47.569191455841064, 43.23616974694388, 70.13342121669224, 30.202193396432058, 0.2531985177525452, 0.17211617502783025, 0.419366858367409, 0.19570585207215377, 0.3150458719049181, 0.1315834242850542, 0.027399484932954823, 0.08083619057599988, 0.08622342614190918, 0.10568263661116362, 0.1955366932920047, 0.07434577242072139, 0.07717670194272484, 0.14093863085976668, 0.07846361145909343, 0.21515234000980854, 0.10933654768658535, 0.028893038896577697, 0.10278791122670684, 0.08655527726347957, 0.09534035835947309, 0.04692642676777073, 0.01540576440415212, 0.1014910883137158, 0.05093376977103097, 0.05653947325689452, 0.08346309818859611, 0.08418383130005427, 0.08087915541338069, 0.07165261943425451, 0.0426351338225816, 0.018350604688748717, 0.12190129953835692, 0.17527765966951847, 0.19669386691280774, 0.0930503365982856, 0.08792584336229733, 0.11007228320730583, 0.22858389999185288, 0.12866364738770894, 0.20668000248926027, 0.2176292778125831, 0.15164435282349586, 0.18452693335711956, 0.14972380016531261, 0.1520502253302506, 0.13186581698911531, 0.11779034084507398, 0.18122222354369505, 0.34270073367016657, 0.162166653200984, 0.10221224890223571, 0.19391567313245364, 0.11389322924826827, 0.18251819828791277, 0.26002509572676247, 0.24721880576440267, 0.18054910323449544, 0.14725132712296077, 0.24514721121106828, 0.2335272990167141, 0.2016427077885185, 0.1737299348626818, 0.2176949464316879, 0.23000738503677504, 0.3599105530551502, 0.29876464126365526, 0.26699356894407955, 0.32639944553375244, 0.2891338680471693, 0.2718083991536072, 0.3221730680337974, 48.34260933739798, 119.24231610979352, 77.25399766649518, 98.44648974282401, 53.76995842797415, 17.645004170281545, 72.36350808824811, 88.38997977120536, 46.414876801627024, 48.25455829075405, 24.3007687159947, 1.3025482829127992, 1.0524815299681254, 0.4919093357665198, 0.8616399190255574, 2.8059468397072385, 6.396443443638938, 12.671383738517761, 75.69704532623291, 74.40348529815674, 96.83286094665527, 81.13260023934501, 68.97778987884521, 31.890834944588796, 0.3633362320916993, 0.37587295366185053, 1.0303509746279036, 4.846266465527671, 10.086834515844073, 14.439729809761047, 25.56877326965332, 40.15171153204781, 52.229935373578755, 60.338365009852815, 69.28586605616978, 73.64044107709611, 78.53869874136788, 72.02225426265171, 64.87057767595563, 68.15622792925153, 61.85417706625802, 66.21176065717424, 66.46038804735456, 71.85361453465053, 70.52910028185163, 77.76442623138428, 65.49475519997733, 71.81683077130998, 62.84245409284319, 80.23234299251011, 8.937955958502632, 0.11706680538398878, 71.07274123600551, 71.47538934435163, 68.72276319776262, 67.40685081481934, 66.21406051090786, 63.23332500457764, 62.50224249703543, 63.79295376368931, 65.48591014317104, 66.81931114196777, 67.03062670571464, 67.2716875076294, 67.29884106772286, 62.12375327519008, 62.033405848911826, 68.19365787506104, 78.91920988900321, 78.10383878435407, 75.97215924944196, 76.43962015424455, 82.00990758623395, 84.35916996002197, 69.82228783198765, 34.029990741184776, 12.929975714002337, 3.4742725661822726, 1.039479604789189, 0.9807992449828556, 1.1753936431237628, 0.6210286329899515, 0.5236197199140276, 0.9379545897245407, 0.4105755958173956, 0.48589073015110834, 1.1350234150886536, 2.449012449809483, 2.3479040009634833, 2.1230183882372717, 1.0206467296395982, 0.3749503088848931, 0.642912472997393, 20.194725547518047, 61.85655335017613, 33.45762593405587, 55.78622491019112, 116.51784406389508, 24.399261168071202, 24.87897174698966, 82.49025739942277, 56.33354493549892, 84.06459413255963, 38.01168026242937, 0.21411464283508913, 0.24022471106478147, 0.3903569350285189, 0.2179824552897896, 0.42774049618414467, 0.26381009976778713, 0.1184990435306515, 0.22540933319500514, 0.18446228254054273, 0.17786719357328756, 0.3426512006138052, 0.11802402830549649, 0.17728131929678576, 0.24385272924389156, 0.12780455420059816, 0.30009858682751656, 0.17007883292223724, 0.14730866333203657, 0.18988636934331485, 0.16108680543090614, 0.2984372888292585, 0.20059412691209996, 0.09338014532944985, 0.1232400219887495, 0.13405295248542512, 0.15088969974645547, 0.20053684498582566, 0.11806175485253334, 0.20833760925701686, 0.12724093587270804, 0.09979077455188547, 0.13391180363084587, 0.19590017093079432], [0.15922865085303783, 0.04195859708956309, 0.09161611712936844, 0.1650358113859381, 0.09655412858618156, 0.0269506815155702, 0.1395753047295979, 0.05387287813105753, 0.07291142403015069, 0.15601282912705625, 0.15175925594355377, 0.08188525999763183, 0.15366982056626252, 0.1352934366358178, 0.1180560008755752, 0.17397852295211383, 0.021894959500059485, 0.106686203474445, 0.07077534150864397, 0.1620870339018958, 0.11314894418631281, 0.2288186459669045, 0.21493275250707353, 0.208276378256934, 0.22933118417859077, 0.15668227177645477, 0.28065101323383196, 0.4008545231606279, 0.3613400363496372, 0.22974096504705294, 0.18833891595048563, 0.22658131244991506, 0.17409210971423558, 0.16735933242099627, 0.1652917005121708, 0.2743894377989428, 0.28351546238575664, 0.36863852185862406, 0.1648049737725939, 0.045627541108323, 14.671843937465123, 82.8534049987793, 63.28481810433524, 59.05652659279959, 46.46578625270298, 15.297240870339529, 52.52443824495588, 84.90520109449113, 45.57169205801827, 34.43664796011788, 25.699937888554164, 8.169669321605138, 0.11883657399032797, 0.697770509336676, 0.0463365593126842, 1.3618028461933136, 2.0513527137892584, 29.082327910831996, 80.52033192770821, 66.96545260293144, 55.35194512775966, 56.526256697518484, 54.17753628322056, 13.22200242110661, 5.5663391181400845, 18.729755197252544, 29.305913993290492, 15.905446222850255, 1.3614875716822488, 0.2027826737612486, 1.085335218480655, 7.12074841771807, 12.503827929496765, 17.22305917739868, 30.76879119873047, 39.10624735695975, 42.5086099760873, 44.32226351329258, 49.192947251456125, 54.73043918609619, 55.31289972577776, 64.4521849496024, 59.86652673993792, 65.54038402012416, 64.9615295955113, 75.87441199166435, 78.30475289481026, 89.06194700513566, 38.91163873672485, 0.07808694309954133, 0.1747679713049105, 39.57131808144705, 65.27952085222516, 51.56058761051723, 56.284532342638286, 48.73754147120884, 52.703969274248394, 45.978321484157014, 47.031859466007774, 45.947210924965994, 50.06960494177682, 50.89348064150129, 52.894047669001985, 50.83942713056292, 54.124914101191926, 54.02027423041207, 56.84216002055577, 58.525844029017854, 70.82363442012242, 78.9248935154506, 73.78522069113595, 54.429762840270996, 23.381775651659282, 7.373500432286944, 1.3495835704462869, 0.21021135656961373, 1.0675510870558875, 0.8593050528849874, 0.9156909329550607, 0.7122721054724285, 0.7216268235019275, 0.19948787055909634, 0.42661491515380995, 1.0817082588161742, 0.921620243362018, 1.9989695932183946, 1.2493470119578498, 0.9435413756540844, 0.12340737586574894, 0.5362061102475438, 2.438831384692873, 20.40636420249939, 26.913718700408936, 27.27949619293213, 63.593241691589355, 80.16976751599992, 6.2089284999029974, 26.67931948389326, 67.81411252702985, 39.26028891972133, 66.82300063541958, 17.93473710332598, 0.14216542217348302, 0.021730499574914575, 0.102973483768957, 0.3791488664490836, 0.29222478504691807, 0.20872764475643635, 0.22804696166089602, 0.2283489911683968, 0.1443293924842562, 0.2513132760567324, 0.11456869728863239, 0.2329629207296031, 0.18368010808314594, 0.10034882889262267, 0.23793489964944975, 0.18805680823113236, 0.3894744323832648, 0.3183188262794699, 0.15921517514756747, 0.18824184473071778, 0.086519016352083, 0.1818475614168814, 0.24898421817592212, 0.16635558913861, 0.12217085435986519, 0.02099077426828444, 0.11369904609663145, 0.09330956411681005, 0.08023070663745914, 0.1312852624271597, 0.20151521105851444, 0.06594751735350915, 0.1267161297478846, 0.1228269027279956, 0.09507393836975098, 0.030771654697933366, 0.027876724056633453, 0.022350865482751812, 0.05026535510218569, 0.04182292740525944, 0.0047386044337015066, 0.057747489506644864, 0.07153453398495913, 0.0954535583566342, 0.10734297787504536, 0.09631526390356676, 0.09955647640994617, 0.08471112086304597, 0.13246243926031248, 0.034144910118941746, 0.04186855549258845, 0.07085745103125062, 0.04437895864248276, 0.08113899361342192, 0.054923413188329766, 0.17559689682509216, 0.1910563672759703, 0.16976955666073731, 0.14422925428620406, 0.10288210545799562, 0.2123730062906231, 0.2918819620140961, 0.21701140382460185, 0.21663996018469334, 0.11900673700230462, 0.15386369159179075, 0.1883833599942071, 0.1601224850331034, 0.1695593193705593, 0.1514821286712374, 0.20585969436381543, 0.17324845998414926, 0.050447450152465274, 0.09545281875346388, 25.129760026931763, 96.01773302895683, 67.87576389312744, 49.75255864007132, 14.736945084163121, 14.258158615657262, 94.8523394720895, 93.43622016906738, 31.305164337158203, 46.64140544618879, 46.985907554626465, 14.43876314163208, 0.11026478359209639, 0.535781455891473, 0.13556820260626928, 1.7451292084796088, 0.7910243453724044, 34.5255571092878, 88.07608100346157, 64.99133041926792, 62.56765978676932, 61.27610778808594, 62.05889878954206, 21.17653901236398, 9.166640281677246, 14.113713383674622, 15.911779505865914, 8.817025167601448, 1.6243938356637955, 0.7172323050243514, 1.796976340668542, 12.237859572683062, 20.88951587677002, 24.687097242900304, 41.36719465255737, 50.666542053222656, 52.36141613551548, 58.24914591653006, 59.282391684395925, 63.11908967154366, 61.88251876831055, 69.23097528730119, 64.13488156454903, 67.8814822605678, 66.89579691205705, 75.26522868020194, 79.37458787645612, 88.96404688698905, 51.77312953131539, 0.12353739674602236, 0.13964896649122238, 49.82340942110334, 73.8955441883632, 62.3983530317034, 65.8956732068743, 58.30173683166504, 60.471416064671104, 57.808265345437185, 59.561299324035645, 58.58081122807094, 61.52024664197649, 63.89626652853829, 63.71293830871582, 61.190012659345356, 64.62420845031738, 64.59474808829171, 65.3601963860648, 66.13748441423688, 73.2129601069859, 78.13945525033134, 75.90323311941964, 61.79118469783238, 33.35632814679827, 13.134735652378627, 3.1465770644801, 0.5867436698504856, 0.6254044239010129, 1.2164051681756973, 0.8590817334396499, 0.83122960797378, 0.616951126073088, 0.06115514665309872, 0.44312147370406557, 1.0627530302320207, 0.28388238698244095, 1.2404964183058058, 0.5355589506881577, 1.314132232751165, 0.4007658522043909, 0.2992387201104845, 2.9883839530604224, 33.7997830254691, 45.17002364567348, 26.463223559515818, 48.00766795022147, 110.77219799586705, 28.524667228971207, 10.919872283935547, 51.84951107842581, 43.030944279261995, 78.85070759909493, 27.552456174577983, 0.2073261985289199, 0.05925961836640324, 0.054493547683315616, 0.188797279926283, 0.27327854026641163, 0.17111583799123764, 0.1586405374109745, 0.04829449585771986, 0.07305543630250863, 0.12561294037316525, 0.11806817379380975, 0.15975784031408174, 0.17681573570838996, 0.04790844335885985, 0.11474929616919585, 0.1353873594530991, 0.15296119930488722, 0.21014182030090264, 0.1325574205922229, 0.09022026881575584, 0.07349197859210627, 0.06561826502106019, 0.16519701773566858, 0.09221358756933894, 0.04495755223823445, 0.03506245570523398, 0.03951594226860574, 0.08481860080999987, 0.03994927169489009, 0.19750783752117837, 0.08553043832736355, 0.08076252202902522, 0.056798157947404046, 0.14171970609043325, 0.1264147652047021, 0.196722039686782, 0.09648898243904114, 0.12591657122331007, 0.16130773643297808, 0.07507314839001213, 0.18810360000601836, 0.11186704904373203, 0.11417327422116484, 0.16959509173674242, 0.194258075473564, 0.14707627865884984, 0.21524847485125065, 0.23142717885119574, 0.2704089342483452, 0.1641102081962994, 0.1198757096592869, 0.11411205679178238, 0.09422639384865761, 0.1812907284391778, 0.10598594176449946, 0.17176968790590763, 0.2521039593432631, 0.17556968757084437, 0.22951276014958108, 0.21449452745062964, 0.2896816357970238, 0.5087118170091084, 0.3437798214810235, 0.22391392343810626, 0.28825616942984716, 0.291226578610284, 0.20750816805022104, 0.17311754343765123, 0.3041038161941937, 0.26710620575717514, 0.3417722534920488, 0.5212758971112115, 0.291381691715547, 0.17044921804751667, 31.214153357914515, 112.72904000963483, 82.19124167306083, 77.18465464455741, 64.37972218649728, 22.391877957752772, 74.76089368547711, 103.15313693455288, 61.73518221718924, 48.59030566896711, 43.269507203783306, 13.463649477277484, 0.133395058502044, 1.2848790138959885, 0.3973214456013271, 5.249764859676361, 5.368065323148455, 36.18057632446289, 92.20872361319405, 73.88985361371721, 71.09612192426408, 61.5569748197283, 71.48649256569999, 20.554583174841746, 7.701645612716675, 26.98031370980399, 32.411793504442485, 19.400298050471715, 1.896578767469951, 0.3444447586578982, 0.4515616350940296, 6.401499995163508, 12.079418063163757, 17.067216294152395, 35.67012344087873, 49.870438303266255, 55.59519461223057, 68.81459753853935, 70.48421491895402, 77.65745871407645, 73.81695311410087, 76.06476484026227, 68.71743392944336, 76.51106848035539, 68.8293068749564, 82.8132791519165, 86.17208698817662, 96.8443602153233, 44.91438899721418, 0.16736092019293988, 0.3265821614435741, 51.61857727595738, 82.27427959442139, 69.9598969050816, 75.5051360811506, 64.88673223767961, 69.04830714634487, 64.63337312425885, 67.5174869809832, 66.31080027988979, 69.7383258002145, 71.75272669110979, 73.27619566236223, 68.14670889718192, 71.40250968933105, 69.53516742161342, 70.6592469896589, 68.5745164326259, 79.44773156302315, 86.1866295678275, 79.1966028213501, 55.94797549928938, 23.480686732700892, 7.794937338147845, 2.1900324608598436, 0.7381761840411595, 1.838679428611483, 2.807546445301601, 1.4276320338249207, 0.837407967873982, 0.6439294070005417, 0.18894336851579802, 0.3866284393838474, 1.2745058962277003, 1.6710244991949625, 4.454271248408726, 2.264184287616185, 1.569883263536862, 0.464908418910844, 0.4314329209072249, 4.374482912676675, 34.22654485702515, 45.73490524291992, 38.37704086303711, 75.28052166530064, 96.65727996826172, 20.023794651031494, 36.654453890664236, 86.75784792218889, 54.52700982775007, 89.68438747950962, 32.16889837809971, 0.22133297978767327, 0.12774089404514857, 0.20116424560546875, 0.21876933878021582, 0.22841860886131013, 0.19826065855366842, 0.30916528031229973, 0.2468161088015352, 0.16078584800873483, 0.25127164114798817, 0.2608653934938567, 0.23385839696441377, 0.2423359863460064, 0.1334084663540125, 0.10191456880420446, 0.09401414809482438, 0.2082246331764119, 0.25487724053008215, 0.15172916970082692, 0.1576379747795207, 0.21312567804540905, 0.195144757894533, 0.19133421379540647, 0.19392585115773336, 0.11485248777483191, 0.1070142819413117, 0.11779807614428656, 0.1943640626434769, 0.10991414383585964, 0.2163848988711834, 0.24512555237327302, 0.17124926511730465, 0.09200238675943442, 0.17188383106674465], [0.18002542347780295, 0.10541838793350117, 0.11099630541035108, 0.11991221484329019, 0.11744009463914803, 0.07620527728327683, 0.1016080134681293, 0.2105388989938157, 0.1461974536733968, 0.17586011412952626, 0.2827760763466358, 0.23398379023586, 0.17376559866326197, 0.2585521319082805, 0.18715857714414597, 0.17518719738083227, 0.175056307975735, 0.07282947735594851, 0.10213199178022997, 0.3107795694044658, 0.2979098771299635, 0.322853394384895, 0.17437580520553247, 0.30997298125709805, 0.04509432114926832, 0.2713729425200394, 0.33387348162276403, 0.28715336003473824, 0.21824826459799493, 0.49238859862089157, 0.3127626287085669, 0.4114818743297032, 0.29864901889647755, 0.2905273347028664, 0.1652091228004013, 0.20384277616228375, 0.3722966398511614, 0.11916220294577734, 0.1462133721049343, 0.16116805321403913, 0.22831522726586886, 6.932494359357016, 61.5809600012643, 71.61310264042446, 57.678059577941895, 78.43707438877651, 24.829292127064296, 18.749453340257915, 78.90151977539062, 72.95043631962368, 39.94137566430228, 26.402260065078735, 26.759529488427297, 6.474994131496974, 0.17153500978435787, 0.1227819701390607, 0.45448123557227, 1.358766374843461, 23.440778017044067, 55.78596087864467, 68.5927346093314, 51.7081812449864, 27.899859155927384, 8.50659876210349, 1.7919582213674272, 10.897135172571454, 33.69743606022426, 50.897333417619976, 29.249515465327672, 15.251448767525808, 9.222230213029043, 0.6096406440649713, 0.0424289982765913, 0.21410533333463327, 1.9290622472763062, 2.431253505604608, 3.798214520726885, 5.797260761260986, 12.415220158440725, 24.33018912587847, 37.71872683933803, 50.84613561630249, 55.08193465641567, 65.5232845033918, 67.07763821738106, 62.32340976170131, 39.942515168871196, 21.802827051707677, 0.2920301540621689, 0.5715670670781816, 0.17412740710590566, 19.628039155687603, 65.80326911381313, 39.694040639059885, 51.60453149250576, 44.6132401738848, 48.20814779826573, 37.746366773332866, 45.69243785313198, 41.38804619652884, 41.332036767687114, 36.63406787599836, 37.85583911623274, 34.393100125449045, 33.069346700395855, 33.94338491984776, 42.49034316199166, 53.20723424639021, 52.29663808005196, 34.51211929321289, 11.115081054823738, 0.9773906107459749, 1.1298987929310118, 0.5575586301939828, 1.1828258271728243, 0.9465794754879815, 0.7707767518503326, 0.5684666505881718, 0.6693848382149423, 0.2640065492263862, 0.17649013389434132, 0.06568321439304523, 0.34857434992279324, 0.2972303650208882, 0.757510957973344, 1.471676230430603, 1.5200500232832772, 0.24713491169469698, 1.2470097030912126, 10.681415319442749, 38.877536978040425, 34.75021668842861, 43.354726859501426, 82.35246767316545, 59.18675667898995, 12.05316516331264, 29.262109075273784, 52.474796840122764, 48.03612082345145, 67.56107303074428, 11.906135201454163, 0.17958453856408596, 0.10490437730082444, 0.33599200365798815, 0.3250567061560494, 0.17321842802422388, 0.26339128081287655, 0.19292548697974, 0.11954890005290508, 0.2207195841308151, 0.10580490862152406, 0.17448669139828, 0.16489804163575172, 0.205403474558677, 0.1710602795439107, 0.10292780479150158, 0.2801784814468452, 0.5515177686299596, 0.3675561227968761, 0.40737768741590635, 0.2001415304839611, 0.1926827478621687, 0.0781203405931592, 0.21229888312518597, 0.07898135403437273, 0.1314882801047393, 0.2860919412757669, 0.24584811074393137, 0.18466981926134654, 0.1460742045726095, 0.21686071476766042, 0.16123962508780615, 0.20170830855412142, 0.1961312528167452, 0.11269727735114948, 0.11206163931638002, 0.10869930830917188, 0.08649271633476019, 0.09128185720848185, 0.17889625978256973, 0.08206355185913188, 0.05759674616690193, 0.13299131659524782, 0.19278030762714998, 0.08332638695303883, 0.15559657503451618, 0.19979771679001196, 0.14935393072664738, 0.1389156872672694, 0.13408924053822244, 0.10894626112920897, 0.12583862112036773, 0.15360982449991362, 0.06584282618548189, 0.08540178808782782, 0.17783949577382632, 0.21313116060835974, 0.16731921743069375, 0.08947324925767523, 0.21704906251813683, 0.04971434395494206, 0.15387940646282264, 0.26456066806401524, 0.14304407073983125, 0.12156792171299458, 0.4053095941032682, 0.2072159637297903, 0.2914237608867032, 0.2969348765909672, 0.2279842107423714, 0.09026078414171934, 0.1267523770885808, 0.3308784823332514, 0.09677287470549345, 0.12993343068020685, 0.1496021116950682, 0.25893838118229595, 13.10649469920567, 73.79574026380266, 73.55549934932164, 46.90101793834141, 44.764172417776926, 21.79672305924552, 44.68557439531599, 105.42252281733921, 53.21863971437727, 34.627209254673545, 41.397346360342844, 35.78841652188982, 8.570512635367256, 0.18432752548583917, 0.36299172629203114, 0.1391764889870371, 1.3552886928830827, 29.877198355538503, 69.69736616952079, 77.6472031729562, 62.345901080540244, 40.78938593183245, 10.417135374886648, 3.2001337792192186, 21.488196986062185, 37.443567752838135, 44.82435771397182, 15.092609473637172, 4.32546945129122, 5.920625158718654, 1.9599752170698983, 0.28117752926690237, 1.971412603344236, 7.315853834152222, 5.79886405808585, 8.735466344015938, 15.613272735050746, 28.395138910838536, 44.64941249574934, 55.818874495370046, 63.812235014779226, 64.28096743992397, 73.39273779732841, 72.71136270250592, 72.7813241141183, 49.684028557368684, 34.06449549538748, 0.7321298399141857, 0.5455702734845025, 0.20593765803745814, 26.4558584690094, 79.0937694822039, 51.90067761284964, 69.68406731741769, 59.60441984449114, 64.34423773629325, 54.10520206178938, 63.44295910426548, 56.94694927760533, 59.771315574645996, 52.8186423437936, 56.141507148742676, 53.59994643075125, 53.1783401625497, 51.35756124768938, 58.01501941680908, 63.726438658578054, 63.48303631373814, 45.72955860410418, 20.422633409500122, 4.200924728597913, 1.0491412920611245, 0.4101760472570147, 1.2012207486799784, 1.567839190363884, 0.6010133698582649, 0.5138763370258468, 1.0608101402010237, 0.3147415896611554, 0.10669554690165178, 0.11291559599339962, 0.33873122238687103, 0.15769647806882858, 0.3788528623325484, 0.7362759060093335, 1.85036239027977, 0.15349429712763854, 0.7206388765147754, 20.904461451939174, 63.69023159572056, 43.16573238372803, 33.236864294324604, 90.93053300040108, 96.30891118730817, 25.760838849203928, 9.756854142461505, 45.44787515912737, 53.625863211495535, 78.89817074366978, 21.574417182377406, 0.14508510407592567, 0.0816192471289209, 0.1862175983509847, 0.3213966339826584, 0.2779170870780945, 0.14817299480949128, 0.12872459340308393, 0.045087169390171766, 0.13325365180415766, 0.14876003616622516, 0.11037782752620322, 0.13187070244124957, 0.18328859337738582, 0.1186984514019319, 0.05246810708194971, 0.22822701771344456, 0.5216673846755708, 0.38799397753817694, 0.34434468831334797, 0.11729210615158081, 0.20294639069054807, 0.07167425791599921, 0.0977389050115432, 0.06277670285531453, 0.08590801592384066, 0.13111560153109686, 0.1451262097273554, 0.12431549999330725, 0.11406375866915498, 0.06716022906558854, 0.1753784492611885, 0.16713477804192475, 0.12742598594299384, 0.09555429366550275, 0.05860274897090026, 0.15636127042983258, 0.16320726807628358, 0.12020781183881418, 0.18436593056789466, 0.27753976732492447, 0.13495553976723126, 0.1931319244738136, 0.2671917554523264, 0.17402057855256967, 0.2145705640848194, 0.3526161387562752, 0.2756580811526094, 0.10366353352687188, 0.21578508748539857, 0.13092193406607422, 0.18411844170519284, 0.2805609037833554, 0.18831014606569493, 0.12323215098253318, 0.3508103670818465, 0.40437166871769087, 0.24590312636324338, 0.1667546627244779, 0.360148691705295, 0.13140897293175968, 0.2614820461188044, 0.2791911315705095, 0.3084936392094408, 0.1919414076421942, 0.5115794688463211, 0.30618336317794664, 0.355508027864354, 0.30477635296327726, 0.20464648732117244, 0.08205833392483847, 0.22482964715787343, 0.3356129197137696, 0.12512628148709024, 0.20860952538039002, 0.20301115007272788, 0.3256742815886225, 15.78994631767273, 92.39681134905133, 93.67129857199532, 70.57518768310547, 90.03033133915493, 35.20358664648873, 29.92609977722168, 94.94529247283936, 88.27402823311942, 51.876268591199604, 39.36821181433541, 40.8861083303179, 8.843620266233172, 0.23313771135040692, 0.40806311635034426, 1.0718135897602354, 2.9824740758963992, 28.589853491101945, 69.2761663709368, 99.97972093309674, 72.7157678604126, 42.79093265533447, 14.771126747131348, 11.062921796526227, 19.029530014310563, 34.6584518296378, 77.00484916142055, 33.008188656398225, 27.211931909833634, 13.58829060622624, 1.3517786583730151, 0.14092130107539041, 0.5405497114573206, 2.9935996617589677, 1.9347020132201058, 3.818312619413648, 9.34314797605787, 22.14591693878174, 38.18821314402989, 56.36426639556885, 64.94069194793701, 67.896393094744, 75.38113158089774, 68.50773729596818, 63.05251203264509, 39.24039970125471, 23.679969753537858, 0.30148298825536457, 0.8922111785837582, 0.3077724650502205, 25.190789529255458, 85.37701157161167, 54.6553430557251, 77.1350931440081, 66.08950710296631, 72.87877259935651, 59.67249134608677, 71.48945944649833, 63.55696514674595, 68.31650202614921, 58.57628795078823, 63.173348154340474, 59.2941688810076, 60.893651144845144, 57.623676027570454, 66.3037200655256, 66.17353861672538, 62.40068762642996, 36.81297704151699, 12.09325453213283, 1.4424903222492762, 0.9783468565770558, 0.5526877801333154, 2.167446472815105, 2.5227873367922644, 1.1672854210649217, 0.4771362170577049, 0.8332240666661943, 0.26444805839232033, 0.23766788254891122, 0.18864490810249532, 0.29386518416660173, 0.31819915984358105, 1.47726095361369, 2.8595098512513295, 2.0415681302547455, 0.3274791033140251, 1.2688648274966647, 19.69889862196786, 55.27826295580183, 50.03540938241141, 54.38918536049979, 103.39526775905064, 72.11920942578996, 21.253955841064453, 42.90622411455427, 68.50062928880963, 65.97265229906354, 90.72602667127336, 24.698546137128556, 0.24342899769544601, 0.1348574236035347, 0.2270648500749043, 0.3622868098318577, 0.21259718069008418, 0.2934330930667264, 0.26038086520774023, 0.15624152256974153, 0.20994431232767446, 0.24946516379714012, 0.16983198188245296, 0.1790325774678162, 0.2016956063785723, 0.2613234860556466, 0.14519542029925755, 0.17407961109919207, 0.4634091822164399, 0.3391744957438537, 0.2501026067350592, 0.1977992140288864, 0.22229116622890743, 0.22699782438576221, 0.17393418747399533, 0.2214199544063636, 0.2267122154257127, 0.21463453636637755, 0.31880074899111477, 0.26945051710520473, 0.19573186710476875, 0.37650751961129053, 0.28171267626541, 0.2782482121671949, 0.19255100350294793, 0.2839736635131495, 0.11600609230143683], [0.11075166639472757, 0.17496672778257302, 0.11154443278376545, 0.1800107942628009, 0.2940474386726107, 0.21152521749692305, 0.3081968751336847, 0.3702563936156886, 0.5707247608474323, 0.3245994821190834, 0.5103653797081539, 0.5660760902932712, 0.42767771812421934, 0.2159445703561817, 0.3011975421437195, 0.3294299729168415, 0.15254763221102102, 0.2849761311497007, 0.33771632398877827, 0.24198966207248823, 0.16810639947652817, 0.3785474401499544, 0.19169816640870913, 0.21483937251780713, 0.302410111363445, 0.2941067154918398, 0.40782785468867844, 0.4234604329935142, 0.4264918831842286, 0.407558584851878, 0.4066402284162385, 0.41259499745709555, 0.2723336938236441, 0.29926412446158274, 0.33289986529520577, 0.30512539137687, 0.2468626563038145, 0.4428977742791176, 0.4501503093966416, 0.29993793687650133, 0.2723535070461886, 0.34752671899540083, 1.5046382674149104, 46.972400256565635, 84.95497798919678, 59.60049411228725, 63.794037682669504, 37.281806741442, 20.975346973964147, 57.47195863723755, 97.65721607208252, 63.59535394396101, 47.68385410308838, 37.68107802527291, 18.646560941423687, 3.7628277795655385, 0.3294775246509484, 0.6757878746305193, 1.053899613874299, 14.318422079086304, 15.077914033617292, 6.35391959973744, 1.7868922246353967, 11.364716802324567, 9.621161035129003, 2.741757644074304, 8.936369163649422, 31.363143580300466, 37.62699324744088, 35.89833354949951, 3.651926713330405, 0.3342264826808657, 0.8347677066922188, 0.11282457730599812, 0.24803741755230085, 0.3542447585080351, 0.10884608221905571, 0.6184928662010601, 0.1968336451266493, 0.16110944135912827, 2.171532664980207, 4.90920455115182, 8.191357254981995, 11.286829233169556, 5.721230098179408, 2.0384683651583533, 0.22230831959417888, 0.19700717367231846, 0.4477871890578951, 2.1142300026757375, 1.1312364297253745, 2.091608622244426, 46.17543145588466, 47.32478509630476, 42.85525560379028, 36.65548917225429, 36.15149463926043, 31.837851456233434, 27.447781562805176, 20.392915964126587, 19.90632493155343, 16.91613118989127, 16.405581031526836, 14.879633290427071, 16.52709286553519, 17.081152643476212, 17.36799338885716, 19.528084107807704, 6.276700360434396, 0.8552726549761636, 1.2219274661370685, 0.9709630927869252, 0.7855296773569924, 0.8972463426845414, 0.7024311221071652, 0.7464446489300046, 0.5788413424577031, 0.3103934558374541, 0.06457647628017835, 0.37774972724063055, 0.6620073712297848, 0.7237587262477193, 0.5081641578248569, 0.22214221422161373, 0.9079920575022697, 0.38639765605330467, 0.028567182631897073, 6.307645031384059, 21.491011006491526, 22.453499794006348, 34.77756132398333, 66.97909191676548, 74.41989694322858, 32.801802839551655, 18.468610627310618, 50.093701294490266, 58.668219566345215, 59.62676525115967, 54.15203639439174, 6.282356194087437, 0.11213701777160168, 0.3916967974177429, 0.21233001431184156, 0.1208232973835298, 0.21484775921063765, 0.28601681387850214, 0.14081018418073654, 0.306035469685282, 0.28269894048571587, 0.2590514522578035, 0.1434883890407426, 0.21195779714201177, 0.08571403633270945, 0.16727824748626777, 0.3303632571228913, 0.45892422859157833, 0.36000457086733406, 0.4125769484255995, 0.4292567233954157, 0.4227667802146503, 0.2441089983497347, 0.26888912437217577, 0.31734013450997217, 0.23025673308542796, 0.27047583780118395, 0.2097318358719349, 0.19300336922918046, 0.30563950378979954, 0.27547878505928175, 0.30907902494072914, 0.30874401863132206, 0.22450190117316587, 0.16784421354532242, 0.10283399053982326, 0.11619521358183452, 0.10294774015034948, 0.09523896487163645, 0.13851913783167089, 0.0913714916844453, 0.12483007381004946, 0.13390197844377585, 0.15242955354707582, 0.21722621444080556, 0.3916527197829315, 0.4855961916702134, 0.24266233454857553, 0.4279743736343724, 0.5096954756549427, 0.4060280541224139, 0.27060527514134136, 0.22889713889786176, 0.2661159246095589, 0.17953674255737237, 0.23007019023810113, 0.18730174803308078, 0.2794573072876249, 0.18653009086847305, 0.4121911876967975, 0.32012419083288735, 0.2066739092447928, 0.5021069571375847, 0.3274414310497897, 0.39874170081956045, 0.3244465674672808, 0.4358621532363551, 0.4402693738894803, 0.5130649719919477, 0.43500842047589167, 0.3580587495650564, 0.25018685364297455, 0.24995737309966767, 0.3382109488759722, 0.34638805580990656, 0.35730989117707523, 0.19971333417509282, 0.4107328530933176, 0.2826508459235941, 0.3533318574939455, 4.263812005519867, 65.64137608664376, 86.14961651393345, 69.01020322527204, 49.432673999241416, 11.402475919042315, 34.33942181723458, 89.05479036058698, 88.74414334978376, 43.36531244005476, 48.49632780892508, 54.65914372035435, 33.46315322603498, 5.355975891862597, 0.52988286955016, 0.1356536437358175, 0.7635378688573837, 16.92895061629159, 17.61989685467311, 12.152897000312805, 5.605177811213902, 4.75652049268995, 2.8525775032384053, 10.488385677337646, 25.92509252684457, 54.87322119304112, 38.00410325186593, 31.714236055101665, 9.713239431381226, 0.6855562276073864, 1.3447302537305015, 0.40059665271214073, 0.42740565272314207, 0.8241273547921861, 0.9264814853668213, 0.36820887348481585, 0.204477314970323, 2.006984991686685, 5.601705883230482, 11.91878352846418, 14.57458826473781, 21.343994072505406, 12.245245507785253, 5.471633434295654, 0.5725477944527353, 0.3892628108816487, 0.1661194996642215, 3.653454448495592, 1.3864753565617969, 4.41744145325252, 69.19734600612095, 63.2784674508231, 58.30140331813267, 51.16872658048357, 53.967464447021484, 44.929004532950266, 45.89923013959612, 38.4253134727478, 39.23381628308977, 39.17559037889753, 38.63794224602835, 37.991822310856406, 39.26756368364607, 35.727758748190745, 33.15040438515799, 28.27944619315011, 11.28597547326769, 1.9941985692296709, 1.0887003179107393, 1.7404964970690864, 1.2924951080765044, 1.0741318996463503, 0.7887197690350669, 0.6789683582527297, 0.5995600021311215, 0.4303355669336659, 0.04136545570301158, 0.44947063443916185, 0.8648688771895, 0.6989234760403633, 0.6810527635472161, 0.15038391974355492, 1.0269759957279478, 0.5190786378724235, 0.04128753274147, 8.632520965167455, 50.982639925820486, 39.43630763462612, 31.55561215536935, 63.970035552978516, 98.16715131487165, 61.503425053187776, 18.261745384761266, 26.390178884778702, 48.873416968754356, 64.0128573008946, 67.54562718527657, 12.29289538519723, 0.1575417992259775, 0.37306577286549975, 0.21642547526529857, 0.3423708842269012, 0.32995342197162764, 0.33314476215413635, 0.21685999552054064, 0.14214714244008064, 0.24142601660319737, 0.16873046170387948, 0.09804455789604358, 0.14444107934832573, 0.16388673947325774, 0.14065395827804292, 0.27383645890014513, 0.2616762156997408, 0.32546268722840715, 0.6092155554464885, 0.411973947925227, 0.3298511803150177, 0.31722432215298924, 0.3631521591118404, 0.19353295224053518, 0.1287114569651229, 0.20963666455021926, 0.13536560562040123, 0.2713387443550995, 0.23434327808873995, 0.4920126902205603, 0.3095459113163607, 0.27783455007842606, 0.22757805325090885, 0.07450680235134703, 0.1032191812992096, 0.20963156196687902, 0.08134256090436663, 0.2189580122275012, 0.21943642012774944, 0.25604157948068207, 0.25940125063061714, 0.3111681528389454, 0.2349799339260374, 0.301141196595771, 0.3790021128952503, 0.5952963052051408, 0.35893908089825083, 0.5564014294317791, 0.5400600263050624, 0.7280685092721666, 0.33978333164538654, 0.4759049745542662, 0.42765250376292635, 0.23575889212744577, 0.44108855564679417, 0.43696458265185356, 0.28778431617787903, 0.16683627691652092, 0.3427191355398723, 0.2657705774264676, 0.1825599553329604, 0.5437224326389176, 0.4020257560270173, 0.5698359885386058, 0.5005805247596332, 0.608396862234388, 0.4877912795969418, 0.5852938847882407, 0.3992453095104013, 0.28313846832939554, 0.37723718902894426, 0.28001408598252703, 0.2832750981407506, 0.316509661929948, 0.47640785042728695, 0.46994179167917793, 0.4835788799183709, 0.3881016474749361, 0.5637319960764476, 5.431090261254992, 71.94480964115688, 104.01135063171387, 82.09824003492082, 82.33444404602051, 50.6296957560948, 29.274654047829763, 70.80836227961949, 111.67316395895821, 74.72046211787632, 60.174804415021626, 56.196797439030235, 31.052242960248673, 4.855875389916556, 0.379416752074446, 0.8637385464140347, 1.38288748051439, 17.253659043993267, 17.49924659729004, 12.317544988223485, 7.547407763344901, 22.371922731399536, 25.560605662209646, 6.623536195073809, 11.584858315331594, 45.34046295710972, 46.51101555143084, 42.085033893585205, 5.047038572175162, 0.36962807018842014, 0.6961300830755914, 0.3171835286276681, 0.5592990453754152, 1.1384256439549583, 1.745828696659633, 2.2114018627575467, 0.21288483882589, 1.442051391516413, 4.196167383875165, 9.102430241448538, 10.52691604409899, 16.52107572555542, 9.01478566442217, 3.6778217809540883, 0.3365669942327908, 0.46968286271606174, 0.6816443375178746, 6.742465036255973, 2.7064757772854398, 3.7545042719159807, 73.31473731994629, 79.15783882141113, 67.80100127628872, 61.87707832881382, 62.98006316593715, 59.0194023677281, 58.43408611842564, 50.58539056777954, 52.49939693723406, 54.23201016017369, 55.75223432268415, 53.598490783146445, 52.69300154277256, 44.758638177599224, 35.697582721710205, 25.250033344541276, 7.072421959468296, 0.8829562323434013, 1.327679482953889, 1.9596523429666246, 1.2283193745783396, 0.7351084457976478, 0.6062795072793961, 0.6421377488545009, 0.9716315312044961, 0.32852505147457123, 0.15467500234288828, 0.4022624290415219, 1.0044003214154924, 0.7977934650012425, 0.5846956883158002, 0.2801676520279476, 1.5420789612191064, 0.8294563516974449, 0.21820368484726974, 9.54875646318708, 34.435803753989084, 38.67692164012364, 47.05121367318289, 81.3149904523577, 87.52353245871407, 43.91103090558733, 25.82759714126587, 65.25320107596261, 72.95911461966378, 78.92059258052281, 76.55967112949916, 13.193117022514343, 0.2562782253537859, 0.4723920630557196, 0.2986477432506425, 0.2868603143308844, 0.28509121068886345, 0.46278438717126846, 0.22307102009654045, 0.42631163714187487, 0.26761526986956596, 0.37535208304013523, 0.27011398864643915, 0.3341970885438578, 0.3005422130227089, 0.16406617127358913, 0.4231637232005596, 0.5848823125873293, 0.40600137412548065, 0.645830607839993, 0.5231611930898258, 0.41662093571254183, 0.31357706072075026, 0.45198153970496996, 0.38398277706333567, 0.2593132039265973, 0.2842307740024158, 0.2605807887656348, 0.30694055397595676, 0.304317011897053, 0.6103310670171465, 0.3904000627143042, 0.4218525764133249, 0.33345072716474533, 0.1597172367785658, 0.21841280934001717, 0.3291441196841853, 0.16114330025655882], [0.07033262455037662, 0.06768167644206967, 0.10871339469615902, 0.1328868493437767, 0.06384485946702105, 0.14443675029490674, 0.18456239359719412, 0.12549703302127974, 0.07090697730226175, 0.12538898310491017, 0.11523269808718137, 0.06214138373200383, 0.1072815636705075, 0.11004938265042645, 0.06865040731749364, 0.14041609104190553, 0.06748116255870887, 0.09173262159207038, 0.09079797353063311, 0.09241378254124097, 0.06746960710734129, 0.11451290813939911, 0.1144990117422172, 0.22289595806172915, 0.08280605237398829, 0.07823127428335802, 0.0387987137905189, 0.1595078408718109, 0.05959332188857453, 0.11417839037520544, 0.23209206174526895, 0.13437037116714887, 0.01849795365706086, 0.08088515366294555, 0.06040066320981298, 0.08558204091553177, 0.05585006132189717, 0.09109470367963825, 0.06089160365185567, 0.10720777977257967, 0.04388655595747488, 0.08900649858904736, 0.1380487773567438, 0.42785652567233357, 19.64074567386082, 59.570234707423616, 69.38831029619489, 69.0385101863316, 54.54145165852138, 22.041568892342703, 31.149722712380544, 68.1241203035627, 68.9847172328404, 63.54775183541434, 35.7234091758728, 29.079270703451975, 15.960753883634295, 0.6993779859372548, 0.40136176879916874, 0.10238776555550949, 0.22709454276732036, 1.2508730100733894, 3.3259554505348206, 5.616846876485007, 3.2097073112215315, 4.091772871358054, 17.109991141727992, 2.36919458423342, 6.226290311132159, 7.453576683998108, 4.283238300255366, 3.854257822036743, 1.5269786800657, 0.1729966692094292, 0.4301006038274084, 0.26903590506740976, 0.3194865036223616, 0.09181036134915692, 0.7635269037314824, 0.2739972716995648, 0.73469627648592, 0.5213746918099267, 0.2655982295317309, 0.4269260913133621, 0.6881502398422786, 0.04723489896527358, 0.4005569719842502, 0.08251116784023386, 0.06959065329283476, 0.47294151357242037, 0.8382282352873257, 0.19164096590663704, 2.278983082090105, 21.0815623487745, 28.210132701056345, 31.222852502550396, 26.219142028263636, 18.360969134739467, 13.634583847863333, 10.347369381359645, 6.264575319630759, 3.6490558045251027, 2.657931319304875, 4.0516266141619, 4.006614446640015, 3.3136310832841054, 1.8226386436394282, 1.2262723701340812, 0.3859542469893183, 0.7899431405322892, 1.344391746180398, 0.3844613070998873, 0.07764046027192048, 0.2558916232415608, 0.1115943118929863, 0.0697226622807128, 0.15866044562842163, 0.09453170068029847, 0.15981877275875636, 0.0697919949889183, 0.20242724354778016, 0.05458762656365122, 0.19330393310104096, 0.19594100516821655, 0.07921945197241646, 1.4959454195840018, 12.77261117526463, 16.188924040113175, 16.91929088320051, 47.59966972896031, 66.09967926570347, 52.351452418736045, 28.11665163721357, 49.27215324129377, 76.72848456246513, 64.24216175079346, 59.02928270612444, 35.780770029340474, 2.3787846182073866, 0.06502670462110213, 0.12756759620138577, 0.08305426048380987, 0.1311672923288175, 0.06803013810089656, 0.0766702773315566, 0.047344421302633624, 0.08690229364271675, 0.09581555678908314, 0.016696115789402808, 0.018325497196721177, 0.10495811727430139, 0.024761900571840148, 0.07050656021705695, 0.06776621512004308, 0.11525218561291695, 0.11123206918793065, 0.025740945179547583, 0.08932480615164552, 0.15372084639966488, 0.09277762658894062, 0.19923039366092, 0.09766187093087605, 0.12458240852824279, 0.10298552098018782, 0.08501128439924546, 0.10001723561435938, 0.12659350489931448, 0.1620793935975858, 0.0975394971402628, 0.04082147417856114, 0.1291291088398014, 0.036197034109916, 0.06014045860086169, 0.027684450981074145, 0.04215613220419202, 0.1035028292930552, 0.08429821873349802, 0.12236962440822806, 0.1476374135485717, 0.0995664508747203, 0.10089866617428404, 0.301194502306836, 0.18388623345111096, 0.28947666393859045, 0.2136109662907464, 0.4318275297326701, 0.17936077128563607, 0.3176402641194207, 0.2782418882208211, 0.18415919451841287, 0.19185086392930575, 0.18842838757804461, 0.0746459359569209, 0.10944314553801503, 0.05233146369989429, 0.11534441209265164, 0.11992358709020273, 0.11488507102642741, 0.16894376597234181, 0.28780554075326237, 0.11534408639584269, 0.28729824083192007, 0.08385874517261982, 0.23445355359997067, 0.12554265771593365, 0.21473012837980474, 0.31789620752845493, 0.2606857717037201, 0.028555566112377813, 0.18883693351277284, 0.18235720906938824, 0.12326264434627124, 0.22517375940723078, 0.1610356710319008, 0.371347613632679, 0.08427874477846281, 0.39570384525826996, 0.1619652368660484, 0.12882348309670175, 1.2325141323464257, 32.78699970245361, 74.59041268484933, 70.63651248386928, 64.67702865600586, 25.50631938661848, 21.092842749186925, 61.18242522648403, 95.67835521697998, 70.89089298248291, 50.29558120455061, 36.049859864371165, 46.4852967943464, 24.76880979537964, 1.2294879747288567, 0.3631569359983717, 0.045992969535291195, 0.4294543127928461, 1.1086531558207102, 3.1762139541762213, 4.031060380595071, 1.9690843054226466, 5.240906340735299, 15.742794104984828, 10.922908646719796, 19.28976958138602, 25.88170450074332, 7.453813791275024, 2.2852614309106554, 4.621694607394082, 0.81993368268013, 0.4073480490062918, 1.1741360191787993, 0.5760673827358654, 0.599880650639534, 1.9117132467882973, 1.5819908252784183, 1.5216156478439058, 0.8177941260593278, 0.6357223902429853, 0.49262445739337374, 0.5613600547824587, 0.7925038774098668, 0.8320562807576997, 0.041956734510936906, 0.5777544379234314, 0.6479633248278073, 0.5775084282670702, 0.2932027711399964, 7.1161152720451355, 40.48321008682251, 46.6333246912275, 49.313804217747276, 43.6864720753261, 33.960487910679404, 28.33528365407671, 24.08487950052534, 20.161203963415964, 16.72183871269226, 14.727639709200178, 13.295646377972194, 10.89118925162724, 7.581569450242179, 3.7958612527166093, 2.794320983546121, 0.4575219952634403, 0.7994788374219621, 2.64647547687803, 0.5913472856794084, 0.3410033647503172, 0.2378574109503201, 0.30186625197529793, 0.22226671182683536, 0.15150515814977034, 0.15561581828764506, 0.6171850306647164, 0.4413910465581076, 0.1816841159015894, 0.16025254662547792, 0.16464656298714025, 0.49864811130932396, 0.2665526568889618, 1.6664919938359941, 23.42118409701756, 38.014039175851, 18.936667340142385, 35.59304012571062, 77.86156899588448, 80.1687183380127, 37.027405398232595, 30.154841423034668, 54.41404948915754, 60.733766147068565, 71.96760668073381, 49.90240696498326, 5.145117172173091, 0.04114620407511081, 0.117527055687138, 0.1963810079864093, 0.17531698755919933, 0.06156458825405155, 0.1439843438565731, 0.027149249699765017, 0.07955768132316214, 0.09555288909801415, 0.02540267681303833, 0.10477724019438028, 0.21349153055676393, 0.08613155928573438, 0.043937564827501774, 0.14613095724156924, 0.3042250568313258, 0.32098935012306484, 0.1680656195219074, 0.20417945166783674, 0.30100950651935166, 0.25632653704711367, 0.4397388680705002, 0.2626024974243981, 0.22764387114771775, 0.11372590929801975, 0.15386521151023252, 0.09942228932465826, 0.3328423798084259, 0.1773713608937604, 0.19608520743037972, 0.05248411372303963, 0.2415476915027414, 0.2343554917190756, 0.16989912970789842, 0.14543532314045088, 0.11570775402443749, 0.09114997714225735, 0.22028715376343044, 0.1898800182555403, 0.2771080562046596, 0.26057365057723864, 0.14869089344782488, 0.31116999845419613, 0.3842318265565804, 0.3266331058527742, 0.2923942288117749, 0.4576166101864406, 0.2743137947150639, 0.27960422368986265, 0.39790870408926693, 0.3154922936643873, 0.167929776811174, 0.30389097332954407, 0.19250475455607685, 0.19584846656237329, 0.11422421863036496, 0.2924335024186543, 0.27050838034067837, 0.13483898102172784, 0.30922697271619526, 0.32119130928601536, 0.17191258738083498, 0.30518024414777756, 0.3019489518233708, 0.3994431160390377, 0.22647303183163914, 0.3881982980029923, 0.31878487127167837, 0.37415357306599617, 0.1394387020596436, 0.27478567510843277, 0.24035251992089407, 0.18441488008413995, 0.2826089124594416, 0.25435447001031464, 0.4535336749894278, 0.3083587735891342, 0.3506375306418964, 0.241461843252182, 0.24072910685624394, 1.6944844403437205, 37.82714653015137, 89.9040756225586, 93.47904191698346, 84.89035279410226, 65.1507568359375, 29.44237313951765, 47.43851668494088, 85.01642090933663, 84.49012265886579, 73.02499743870327, 44.49176134381975, 46.840061392102925, 28.219960927963257, 1.0515109534774507, 0.7739062096391405, 0.18928418308496475, 1.7494154870510101, 2.790065211909158, 11.167607699121747, 12.161626543317523, 6.877845040389469, 15.19262879235404, 32.01451635360718, 5.002574009554727, 10.057674663407461, 9.560856751033239, 11.82272641999381, 10.201692581176758, 3.8479692680495123, 0.5639945619872638, 0.8738090374640056, 3.2728840240410397, 1.0783866941928864, 1.485042284641947, 3.0168409517833163, 4.071666955947876, 2.817584638084684, 2.8513009888785223, 2.4562531241348813, 1.3447892048529215, 1.453373698251588, 2.704188300030572, 2.5480333992413113, 0.06945044760193143, 1.22205741916384, 2.5972492269107272, 2.5802802060331618, 0.3736707546881267, 5.811129365648542, 40.10227509907314, 54.92350878034319, 60.43453502655029, 57.36814907618931, 48.190756457192556, 41.45441191537039, 37.47637019838606, 32.535155296325684, 25.60919267790658, 20.92440799304417, 13.995017307145254, 10.74387788772583, 5.269658420767103, 2.164599882704871, 1.659813906465258, 0.6154838619487626, 1.936872239623751, 2.209988555737904, 0.4888782926968166, 0.3280875863773482, 0.40061899008495466, 0.28419741722089903, 0.22744512824075563, 0.2384347085441862, 0.11075478087046317, 0.8678497629506248, 0.5167487657495907, 0.9583914130926132, 0.13598816150001117, 0.3993539022547858, 0.5074570157698223, 0.2957858182489872, 2.1470752230712344, 26.16672829219273, 37.59818949018206, 34.203810351235525, 64.11109788077218, 79.98888506208147, 66.05478000640869, 38.44644641876221, 60.151006834847585, 90.3906579698835, 78.3224013192313, 82.93513665880475, 53.92204059873308, 4.958898501736777, 0.2429126596876553, 0.2693004251590797, 0.19001278041728906, 0.2243288340313094, 0.22053878168974603, 0.2558084619896752, 0.17966369645936148, 0.21117640978523664, 0.2725087015756539, 0.13516333433134214, 0.128725651917713, 0.28286295597042355, 0.20823012931006296, 0.24569278050746235, 0.2518516800233296, 0.4244997315108776, 0.27520207847867695, 0.1950508350772517, 0.2823661326297692, 0.4567193697605814, 0.37547104379960466, 0.5518179525222097, 0.4794560468622616, 0.37238902917930056, 0.256280885211059, 0.19324519910982677, 0.2308461900268282, 0.3551286996475288, 0.28264283921037403, 0.1919866930693388, 0.23972699205790246, 0.29334947041102816, 0.2694650648960045, 0.3176196909376553, 0.25911121762224604, 0.1625291673200471, 0.1979269686021975], [0.031589618484888754, 0.04104643567864384, 0.06654732873929398, 0.017336512050990547, 0.03450859810358711, 0.07871591113507748, 0.07816724771899836, 0.027171697334519455, 0.021650680107995868, 0.029505206405052116, 0.08411257155239582, 0.00992058400463845, 0.020895872664238726, 0.014094263082370162, 0.006718542900801237, 0.018078037171757648, 0.029515262294028486, 0.023855350645525113, 0.022182290242718797, 0.03513919462316802, 0.07629039950136628, 0.029939166868903806, 0.07546856467212949, 0.046964733462248526, 0.013073028863540717, 0.12193015084734984, 0.11161426760788475, 0.07373431058866636, 0.08109048514493875, 0.03449340909719467, 0.08737836059715066, 0.0225542427838913, 0.039744164129453044, 0.04180953312399132, 0.03481427812948823, 0.025212571656863605, 0.04084208467975259, 0.11999243125319481, 0.0228615122780736, 0.03207933417122279, 0.060456140232937675, 0.08898846312825169, 0.04538069685388889, 0.03639873882223453, 0.2779540536659104, 1.9060267976352145, 40.5648444720677, 68.33014133998326, 65.64133439745221, 57.18613406590053, 27.956412281308854, 19.792992864336284, 46.71502161026001, 75.14072390965053, 83.59452765328544, 55.83300713130406, 43.2855783871242, 30.594735349927628, 7.855641143662589, 0.29021197876759935, 0.13987479651612894, 0.03631135368985789, 0.1052860396781138, 0.5205758118203708, 0.8577153267604964, 1.8118383203233992, 3.482794314622879, 4.3380396110670905, 7.860774993896484, 11.799455165863037, 3.862575250012534, 0.837458288030965, 4.175635891301291, 3.495811764683042, 0.3034495727292129, 0.06615959347358771, 0.056855212564447095, 0.11018052311348063, 0.024827031451942663, 0.09179909766784736, 0.2502241459275995, 0.26844438537955284, 0.12703159424875463, 0.27383629605174065, 0.15454776345619134, 0.1656654104590416, 0.08209676614829473, 0.3209587889058249, 0.15893082826265267, 0.15202555379697255, 0.32113710790872574, 0.14517779195947306, 0.21413560956716537, 0.19836630645607198, 0.5277903761182512, 2.0209656357765198, 1.9390874121870314, 1.1616511919668742, 1.0571829634053367, 0.588992172053882, 0.8010340939675058, 0.0901657146002565, 0.013193602840016996, 0.159407892663564, 0.1124042859300971, 0.19109493520643028, 0.24259923079184123, 0.2712083842073168, 0.7876094686133521, 0.16308906727603503, 0.3991887739726475, 0.0535072664996343, 0.1343607631112848, 0.0270420496485063, 0.12806414812803268, 0.011022605450956948, 0.2475959626691682, 0.10539881898356335, 0.2030983825347253, 0.15495960707111017, 0.2073110264859029, 0.10153355103518281, 0.0414469240100256, 0.23714076940502438, 4.392190831048148, 8.590515630585806, 16.587337221418107, 39.82948882239205, 69.58909239087785, 59.198193413870676, 38.98477894919259, 37.19176503590175, 46.159586088997976, 64.28528921944755, 55.617449692317415, 52.987209115709575, 16.260603393827164, 0.060933055356144905, 0.09326948983860867, 0.05996928457170725, 0.01965971926360258, 0.04516821361279913, 0.0275857241358608, 0.02977625061092632, 0.013625781301275959, 0.0824655160041792, 0.004136867704801261, 0.07676473619150263, 0.012699447838323457, 0.06034184779439654, 0.00813541010886963, 0.02956748234906367, 0.03297607587384326, 0.018421245273202658, 0.025166765454092195, 0.1392926677529301, 0.026539972750470042, 0.0724323783069849, 0.06816324631550483, 0.16080977315349237, 0.11215503287634679, 0.022678865918091366, 0.042547053191810846, 0.04330121433096273, 0.029385770671069622, 0.01647602447441646, 0.008122705388814211, 0.05132658047867673, 0.037648074461945465, 0.05985023560268538, 0.033197298645973206, 0.0617790799587965, 0.0818172504327127, 0.08070946059056691, 0.027913712696837525, 0.04849963056455765, 0.07073871418833733, 0.07832383324525186, 0.09042340184428863, 0.05383962991514376, 0.06529950283999954, 0.06124799059970038, 0.0954903078132442, 0.05839198920875788, 0.041644184317971976, 0.01626387032281075, 0.032808328446532996, 0.027089041591222798, 0.01960377405131502, 0.02694590123636382, 0.024052526136594157, 0.03889027191326022, 0.07007045897522143, 0.08721731709582464, 0.03149418592719095, 0.08207672900919404, 0.07790842053613492, 0.06270569416561297, 0.059734199329146316, 0.01218030324006187, 0.007062979998798775, 0.07086450779544455, 0.062262807573590956, 0.029676122590899467, 0.03001175315252372, 0.04462353658995458, 0.10246755448835236, 0.03186639291899545, 0.03479003407327192, 0.07936410206769194, 0.02708163538149425, 0.057939392780619006, 0.07153017100478921, 0.05636351216318352, 0.08073567918368749, 0.11563253163227014, 0.10895712447485753, 0.06913409422018699, 0.041494465566107204, 0.05532331797959549, 0.4097371979483536, 7.296980789729527, 58.074565478733604, 75.87195232936314, 69.81634712219238, 40.72503171648298, 18.954492943627493, 26.785649503980363, 73.3760621207101, 96.03138623918805, 73.01396369934082, 41.965684686388286, 50.30988754544939, 39.558397906167166, 9.342686789376394, 0.5674117729067802, 0.10018134609396968, 0.08921818115881511, 0.28866733450974735, 0.26749503346426146, 1.4078077375888824, 0.7825821212359837, 6.085488975048065, 2.142548905951636, 4.9065316660063605, 11.052733131817408, 9.58146858215332, 7.89885459627424, 4.380110953535352, 2.4361191987991333, 0.3203258514404297, 0.09086010698229074, 0.2956942974456719, 0.07101144455373287, 0.01868875091895461, 0.08830807570900236, 0.7461349655474935, 0.36383921653032303, 0.4080083178622382, 0.5764666327408382, 0.3342570167567049, 0.2795003264078072, 0.09114128510866847, 0.10519639163144998, 0.1461397646261113, 0.011564519139938056, 0.5482311078480312, 0.2186890680875097, 0.24836892262101173, 0.06357443612068892, 2.2281001210212708, 3.729387402534485, 3.2933766501290456, 2.3786245925085883, 2.5041707243238176, 1.7501827201672961, 1.5684189306838172, 0.30600034871271675, 0.5920255492840494, 0.5256790465542248, 0.4406890885106155, 0.2073490923004491, 0.0916640759844865, 0.997937085373061, 2.6563957674162726, 0.2205574142613581, 0.6128566829221589, 0.027738966180809906, 0.04429129191807338, 0.02241100573779217, 0.10731978554810796, 0.026909009287399904, 0.1644191723316908, 0.22872001411659376, 0.0894419891493661, 0.3615640343299934, 0.37106037618858473, 0.3740524442068168, 0.05908088545714106, 0.19446979197008268, 6.217541226318904, 24.261480127062114, 34.208785261426655, 33.20122698375157, 58.34681674412319, 80.01156398228237, 48.671026366097585, 28.943714823041642, 34.06903961726597, 64.37143298557827, 62.399284090314595, 65.56074224199567, 26.767455645969935, 0.5811278426221439, 0.05459080210753849, 0.02935773360409907, 0.0653718685997384, 0.017075393116101623, 0.11100950291646378, 0.054954893820519955, 0.06356821395456791, 0.036971442734024355, 0.010097298272220152, 0.01567826067496623, 0.04395813800926719, 0.025673497102356384, 0.06144234338509185, 0.009414036408998072, 0.07242551153259617, 0.03812571901029774, 0.03634660019140158, 0.1156051866710186, 0.016447632872898663, 0.06713149989289896, 0.02097076766325959, 0.023665104693334018, 0.07938506201441799, 0.03247894040708031, 0.04554943833500147, 0.01903129575241889, 0.014346174297056027, 0.0369731288935457, 0.05474498222715088, 0.05026361465986286, 0.013667909844246293, 0.05447652663237282, 0.1095695158998881, 0.07068627021674599, 0.07677450709577117, 0.019612542420093502, 0.027982254911746298, 0.019875086278521588, 0.1318639578031642, 0.1885843692081315, 0.17276538376297268, 0.13952050624149187, 0.12817810129906448, 0.15654110935117516, 0.15183275485677378, 0.20016238865043434, 0.12855413183569908, 0.10234105520482574, 0.2746518408613545, 0.1252220906317234, 0.10003363580576011, 0.13707225689930574, 0.11312510725110769, 0.13780531899205276, 0.11308972164988518, 0.17353234546525137, 0.11941167313073363, 0.18110907104398521, 0.24373903391616686, 0.19948279511715683, 0.20559370863650525, 0.1524774581193924, 0.11631379436169352, 0.23212525567838124, 0.2718162430184228, 0.14192558718579157, 0.24392408398645266, 0.14204267518860952, 0.3104369363614491, 0.12231478520802089, 0.15733553815100873, 0.18589707197887556, 0.13554657090987476, 0.20738835233662808, 0.16819186774747713, 0.14741273703319685, 0.18373025182102407, 0.27877809373395784, 0.15670112147927284, 0.16330687701702118, 0.1652400911386524, 0.17563028074800968, 0.3985683215515954, 7.806225555283683, 64.06118202209473, 94.26695374080113, 91.82697568620954, 72.36268125261579, 41.37888847078596, 26.590564932141984, 61.66822937556675, 95.31813975742885, 96.5503124509539, 63.77112947191511, 54.9662367275783, 48.158075605119976, 12.846184781619481, 0.3644709326326847, 0.26109709963202477, 0.2305735003735338, 0.2635654200400625, 4.121899391923632, 4.333509385585785, 4.108602276870182, 16.309725420815603, 12.705239704677037, 14.182898334094457, 30.695484229496547, 16.696324927466257, 13.775124192237854, 11.567876917975289, 4.20839751618249, 0.6535585245915821, 0.17202340572008065, 0.41836924904159134, 0.23262140048401697, 0.10983128792473248, 0.23935206074799809, 0.9510068893432617, 0.9317060964448112, 0.5167765042611531, 1.154584331171853, 0.3868058355791228, 0.33417757387672153, 0.20470250717231206, 0.5323626707707132, 0.6563144624233246, 0.29133994824119974, 1.3210075838225228, 0.3893471120723656, 0.3035401707249028, 0.4191639492554324, 2.5771999827453067, 5.389306400503431, 6.472687329564776, 4.256462548460279, 2.923177714858736, 1.9388531276157923, 1.53351172379085, 0.13767162045197828, 0.3266503949250494, 0.31056056544184685, 0.35110308708889143, 0.31559152262551443, 0.4511769057384559, 1.9285856442792075, 5.8360199843134195, 0.6570850067905017, 1.1600486551012312, 0.2928728945553303, 0.3942859513419015, 0.09234888745205742, 0.27486636649285046, 0.13392978480884007, 0.4144782306892531, 0.49677812308073044, 0.5491992416126388, 0.6451183632016182, 0.5847792295472962, 0.864932659481253, 0.16658515110611916, 0.2933787288410323, 9.686889256749835, 27.633989810943604, 47.76142726625715, 59.09253910609654, 87.89445509229387, 75.73905413491386, 53.83892624718802, 48.11023030962263, 58.93597534724644, 77.30814497811454, 74.32617269243512, 76.48504747663225, 26.90638140269688, 0.5678237250873021, 0.21946953263665947, 0.17689304798841476, 0.19987460837832519, 0.15320020647985594, 0.12381787598133087, 0.22127082597996506, 0.1437616486634527, 0.168274459029947, 0.11497903455580984, 0.16122988132493837, 0.15685202766742024, 0.2099324515355485, 0.22528104936437948, 0.1440202383590596, 0.18562473516379083, 0.29083454821790966, 0.11291767909590687, 0.363470337752785, 0.1405347939580679, 0.11187753919512033, 0.15695013026041643, 0.21851277111896447, 0.18969001487961837, 0.11187113382454429, 0.195443774706551, 0.24007071075694902, 0.11497645612273898, 0.11001284353967224, 0.1360782709504877, 0.14680426754057407, 0.09456348326057196, 0.2147283506180559, 0.17467486272965158, 0.1460240336933306, 0.1510385431881462, 0.14014816470444202, 0.14461368508636951, 0.10435972402670554], [0.013858440781145223, 0.02689941819491131, 0.01923513106469597, 0.023716286589790667, 0.0413021416004215, 0.01132138307938086, 0.019837405532598495, 0.030053791789604083, 0.05537719026740108, 0.04133144752787692, 0.0363857516619776, 0.05062553845345974, 0.04843382623844913, 0.03500765043177775, 0.030234227821763073, 0.14399638106780394, 0.020914793613233736, 0.04528882660503898, 0.05017154085050736, 0.004104358243889042, 0.00833861353541059, 0.020131240033411553, 0.03786848299205303, 0.026808597979002764, 0.06070860954267638, 0.05842248935784612, 0.04611459015203374, 0.0982311482408217, 0.03251611394807696, 0.022284184150131683, 0.03813194117641874, 0.042198544035532644, 0.052154050541243384, 0.06320679906223502, 0.016226077618609582, 0.03923204321680324, 0.03695320710539818, 0.06880619895777532, 0.07030982577375003, 0.056791830608355146, 0.0016814452932781673, 0.1538519665066685, 0.11571882771594183, 0.04934148556951966, 0.003706048858085913, 0.07918860577046871, 0.5378145639385495, 17.767601660319738, 47.10159853526524, 66.45264775412423, 72.44423225947789, 54.237547874450684, 28.182786328451975, 28.19340317589896, 43.34435667310442, 71.54506587982178, 64.73799215044293, 56.57907690320696, 52.90017598015921, 28.296853167670115, 3.9055676630565097, 0.1822229405598981, 0.1998934309397425, 0.2559290240917887, 0.5041408794266837, 1.1198156539882933, 0.9782605469226837, 1.1724732284035002, 0.9148099230868476, 2.5474936110632758, 4.236289322376251, 4.640787388597216, 1.7048043608665466, 1.0937075806515557, 0.10890515547777925, 0.12927673091845854, 0.15933112321155413, 0.07814881870789187, 0.054766451075140915, 0.03752332240609186, 0.05188353220000863, 0.017181117353694778, 0.07162990208183016, 0.1904227105634553, 0.07645668807838644, 0.1650398147425481, 0.010609132503824574, 0.05837708179439817, 0.13174213362591608, 0.0038980433102031903, 0.010601035036545779, 0.341096215482269, 0.13759301895541803, 0.33974679931998253, 0.65565025806427, 0.2549982097532068, 0.6382351954068456, 0.21684833828892025, 0.3123004377952644, 0.2903045580855438, 0.11516366393438407, 0.1318691282400063, 0.35342321544885635, 0.35468833042042597, 0.2046682954366718, 0.12946532294154167, 0.2818019986152649, 0.09229716272758585, 1.0117865822144916, 0.7219246189509119, 0.05862560881567853, 0.08466464121426855, 0.09413723434720721, 0.12075815802173955, 0.09439520657594715, 0.04702398314007691, 0.1542685462960175, 0.11592229322663375, 0.35580851031201227, 0.5464944924627031, 0.13463242139135087, 0.10001171233930758, 1.6202989582504546, 10.081401024545942, 16.95643421581813, 27.37102828707014, 48.085668427603586, 56.87931898662022, 35.24515771865845, 26.52167180606297, 45.82557576043265, 48.1850346156529, 53.67819356918335, 52.91926268168858, 36.04829651968819, 7.251957331384931, 0.10579583660832473, 0.023954849324322174, 0.036426171993038485, 0.03945362561249307, 0.06609073573989527, 0.08302257968378918, 0.03320456575602293, 0.01085297848164503, 0.09107739425131253, 0.021666618895583918, 0.049002815171011856, 0.031466786683137925, 0.02393220321807478, 0.09870819228568248, 0.03528709150850773, 0.027593679958954453, 0.03405992700053113, 0.07299805938133172, 0.023162430684481348, 0.024131868932662264, 0.02478471122282956, 0.022895983553358486, 0.031989764156086106, 0.061901060199098926, 0.02525739568019552, 0.03226526972970792, 0.02124920959717461, 0.10696179725761924, 0.06451797299087048, 0.039619629204805405, 0.04172116411583764, 0.0525398519821465, 0.010163229823644673, 0.023172795306891203, 0.02984401590323874, 0.06889513454266957, 0.02550488115022225, 0.0074754576198756695, 0.05371947832671659, 0.03268615482375026, 0.04547075880691409, 0.05089649784245661, 0.04091602124805961, 0.03643933557240026, 0.056543371440576654, 0.0035419555538932657, 0.06669721712491342, 0.03473385476640292, 0.07144434989563056, 0.056530655694327185, 0.06400797928550414, 0.07169141806662083, 0.014908793482131191, 0.031556509368653805, 0.03834790869482926, 0.06946925659264837, 0.07355006118970257, 0.023453464532004933, 0.02786522458440491, 0.02115535463339516, 0.05971482036901372, 0.007072366258528615, 0.04892744689381548, 0.028922405892184803, 0.0551330940797925, 0.040986802628529925, 0.01929309661500156, 0.05157958243840507, 0.03978265402838588, 0.057722756905215125, 0.025092175795829723, 0.07055425444351775, 0.030690294956522327, 0.032339104517762146, 0.03599487817181008, 0.0306735419269119, 0.015331892296671867, 0.07881827492799078, 0.014086111332289875, 0.03542301903611847, 0.015879553177260926, 0.10299128174249615, 0.06189580833805459, 0.05635870474257639, 0.03912512306123972, 0.06738148576446942, 1.6107791662216187, 32.803129945482524, 65.39698014940534, 74.46319811684745, 63.414388111659456, 36.21277775083269, 26.44980137688773, 44.97205557141985, 75.07280526842389, 85.36694363185337, 59.18622861589704, 56.76520872116089, 59.91193321772984, 30.312020097460064, 3.3304502836295535, 0.18574356021625654, 0.09841151641947882, 0.13176145830324718, 0.09975600641752992, 0.8625671778406415, 0.47544536207403454, 1.215037567274911, 5.017958624022348, 2.2386694167341505, 2.0700444536549703, 2.396075644663402, 0.8612959289125034, 1.4086746339287077, 0.2513299951595919, 0.0647558266563075, 0.25132744386792183, 0.043995257267462354, 0.04695881324421082, 0.06150911801627704, 0.2587663047015667, 0.05681124349523868, 0.11678726252700601, 0.17071595016334737, 0.13298611901700497, 0.2265804982078927, 0.09673056126173053, 0.1680635024926492, 0.23475479600684984, 0.10728062050683157, 0.08663903562618153, 0.16899466966944082, 0.5142052908028875, 0.5017772976841245, 0.5931744447776249, 1.0345246706690108, 0.7933840730360576, 0.12296575813421182, 0.1957324506448848, 0.13132661235119614, 0.04276305463697229, 0.44552104494401384, 0.7704711396779332, 0.6246434875896999, 0.9594566587890897, 0.18718399506594452, 0.3252861595579556, 0.442449045500585, 1.8105620230947221, 0.7036752296345574, 0.07233941222407989, 0.058388135129851956, 0.08829075270997626, 0.07734111776309353, 0.06244551669806242, 0.11166950714375291, 0.028870559031409875, 0.3006058596074581, 0.6872691214084625, 1.2360377375568663, 0.11616006546786853, 0.1999681240745953, 1.7955985346010752, 14.93863912991115, 27.012105192456925, 30.50482566016061, 53.854264395577566, 81.25989123753139, 52.075306688036235, 26.94256935800825, 40.029854025159565, 46.19418464388166, 57.25621012278965, 60.64150101797921, 50.536273751940044, 13.51210708277566, 0.22655000484415463, 0.04681173399356859, 0.06497341926608767, 0.14404291499938282, 0.053116108024758954, 0.08919571486434766, 0.039836879154401164, 0.030168481171131134, 0.034642252538885386, 0.04583445018423455, 0.08751661210720028, 0.014804970838927796, 0.03056873201525637, 0.04962885872061763, 0.04070175685254591, 0.05600203959537404, 0.045370210095175674, 0.07797296957245894, 0.061201395599969795, 0.040434702432581356, 0.019714968977496028, 0.0023236223912265685, 0.029981660124446665, 0.014839973067864776, 0.054696209130010436, 0.039482504062886746, 0.04607134372262018, 0.0359731311244624, 0.03073562788111823, 0.020872303750365973, 0.03777904189856989, 0.07131640533251421, 0.04852535382711461, 0.0411308454349637, 0.03364233619400433, 0.057384900748729706, 0.02731017445746277, 0.009931388826641654, 0.04851418174803257, 0.058340630893196375, 0.10351832024753094, 0.11264790714319263, 0.13926714126552853, 0.13951172599835054, 0.1663344595581293, 0.06676708587578364, 0.13929600614522183, 0.09679466925029244, 0.15534413286617824, 0.2745132025863443, 0.15589963591524533, 0.16025725565850735, 0.11098834619458232, 0.15913589511598858, 0.17210899612733296, 0.213586973292487, 0.12983830007059233, 0.15880961476692132, 0.21596019023231097, 0.10635193676820823, 0.12957671125020298, 0.10640743414738349, 0.06731531502945082, 0.08036896493285894, 0.17068989441863128, 0.11205078275608164, 0.08481547276356391, 0.13959989483867372, 0.17257994014237607, 0.13519040787858622, 0.11376185808330774, 0.15138230259929383, 0.23477944039872714, 0.16800935539816106, 0.20159514248371124, 0.08421889120446784, 0.14110702968069486, 0.16973423212766647, 0.15020382297890528, 0.12936172421489442, 0.12046729720064572, 0.2853356461439814, 0.10711871526603188, 0.11448656740997519, 0.12793370655604772, 0.20919918588229588, 1.4442448509590966, 29.746930054255895, 77.91539669036865, 93.58268124716622, 89.04473631722587, 70.47156919751848, 40.49459818431309, 42.70217636653355, 61.05091667175293, 91.98793070656913, 75.51032638549805, 66.41006224496024, 71.06880855560303, 41.650031498500276, 6.306107308183398, 0.2661956931863512, 0.3709229864180088, 0.23711930055703434, 0.7845724001526833, 2.8989417467798506, 6.2391809565680365, 5.082220775740487, 10.516120280538287, 12.34242388180324, 10.213750311306544, 11.553283095359802, 7.415885312216623, 3.5803428973470415, 0.3002703918942383, 0.16662506253591605, 0.3677759952843189, 0.13836285764617579, 0.11315689661673137, 0.14592496758060797, 0.24270177100385937, 0.14628180914691516, 0.19683443222727093, 0.21069308929145336, 0.17508412791149958, 0.2915349320641586, 0.2238569807793413, 0.2185592371970415, 0.6205000270690236, 0.16061786987951823, 0.13861204284642423, 0.7128895723393985, 1.450033351778984, 0.9524504861661366, 1.8583671493189675, 1.3455973672015327, 1.356863328388759, 0.9699782942022596, 0.5655485157455716, 0.397106621414423, 0.23065112477966718, 0.7488903062684196, 1.168807945081166, 1.0129866663898741, 1.649251558950969, 0.5105573779770306, 0.4833899757691792, 0.45235584676265717, 2.1480292975902557, 1.579849477325167, 0.18527518106358393, 0.18103395721742085, 0.13536233508161136, 0.320479118930442, 0.1795547373060669, 0.2207062305616481, 0.4637662544846535, 0.7901762851646968, 1.6601885663611549, 2.399248582976205, 0.25112651607819964, 0.40285614718283924, 3.8698560936110358, 23.83789883341108, 39.31875106266567, 44.63433143070766, 63.60754803248814, 73.99406964438302, 48.456184591565815, 37.239332403455464, 59.14021764482771, 63.85355595179966, 67.40009021759033, 75.28617749895368, 54.71142891475132, 11.66443863936833, 0.19817143119871616, 0.1118360874908311, 0.10809586676103727, 0.18522007044936928, 0.1864072081765958, 0.14828286319971085, 0.209439807970609, 0.08631852961012296, 0.1376593525388411, 0.2012032749397414, 0.1753355658480099, 0.1813168791787965, 0.13230834395757743, 0.22719033834125313, 0.13319190511746065, 0.18324318581393786, 0.10809101523565394, 0.1728928940636771, 0.13379470205732755, 0.19055506560419286, 0.1157607611800943, 0.07178801431187562, 0.12447300154183592, 0.11091923740293298, 0.19512497181338923, 0.08756406206105437, 0.08623768894800118, 0.24804669991135597, 0.12330674912248339, 0.09956513451678412, 0.13147099103246415, 0.1823736024754388, 0.11619226873985358, 0.13775786225284847, 0.15721599385142326, 0.16419833632452147, 0.09754958017063992, 0.13925127711679253, 0.1308783178350755, 0.11480877654893057], [0.01512552095976259, 0.06937811576894351, 0.019902463470186506, 0.04411352592121277, 0.026602033259613172, 0.10669731109270028, 0.026902291790715287, 0.018554119393229485, 0.050557586564017196, 0.04777816802795444, 0.08056190636541162, 0.085207713501794, 0.021257343535710658, 0.15933602223438875, 0.0696990764034646, 0.030013130578611578, 0.050105811163250885, 0.05478384532034397, 0.02508365169965795, 0.027403423828738074, 0.04578893744785871, 0.09104890935122967, 0.06317270946289812, 0.029427683779171536, 0.028132399444335272, 0.033781591935881546, 0.029728922793375592, 0.056330240198544095, 0.015317006934700268, 0.05887422404651131, 0.042213865356253724, 0.025929211505821774, 0.06815185371254172, 0.05002030557287591, 0.08128802025956766, 0.05202076251485518, 0.044704892938690524, 0.048031946910279136, 0.04086298355832696, 0.020784326596185565, 0.058963220699557235, 0.03688321961089969, 0.05960007331201008, 0.05033578025177121, 0.029387697710522583, 0.07008439608450447, 0.24166811789785111, 0.21669649572244712, 2.1437346594674245, 26.892999172210693, 56.43995312282017, 67.30276679992676, 64.20694828033447, 38.19830887658255, 26.387140784944805, 37.48645898274013, 56.06558070863996, 61.147246497017996, 69.38703182765416, 52.34092937197004, 39.17957169669015, 12.812612823077611, 0.8046024282063756, 0.15815400066120283, 0.6623369764004434, 0.0766899548470974, 1.3583468773535319, 0.929389415042741, 0.622746195111956, 0.6172345908624786, 0.859026582113334, 0.3689933685319764, 0.6864300178630012, 0.13079028470175608, 0.0975638972595334, 0.07661270363522427, 0.1050468221572893, 0.03542374846126352, 0.052886264465217075, 0.019824080801169788, 0.031564125924238136, 0.023185042863977805, 0.08678709196725062, 0.07709362211504153, 0.12817597069910594, 0.23281166170324596, 0.3411927574447223, 0.18656736958239759, 0.08450179280979292, 0.02688622408147369, 0.26784325763583183, 0.026718552989353026, 0.07333423955632107, 0.7675935540880475, 0.06201760537390198, 0.11122425924986601, 0.05790347792208195, 0.020263384728293334, 0.13762674214584486, 0.12196626248104231, 0.08435246082288878, 0.040572560392320156, 0.03274712119517582, 0.07453867992652313, 0.08921028301119804, 0.07140825183263846, 0.10585351887026004, 0.05079205094703606, 0.11698470264673233, 0.13572957180440426, 0.11518013876463686, 0.08115844042705637, 0.027510184528572217, 0.07285575701722077, 0.08213999561433281, 0.2363462591809886, 0.2362151662153857, 1.2022823031459535, 0.2699104281408446, 0.23089040336864336, 1.4227344223431178, 6.07092033965247, 11.649552992412023, 28.689942291804723, 40.74188804626465, 44.957540784563335, 42.815477166857036, 33.36324507849557, 42.80147654669625, 52.7663745198931, 48.38213069098336, 55.77470827102661, 43.29675456455776, 15.013886383601598, 0.8502721233027322, 0.3825558450605188, 0.02341632152508412, 0.10774650943598577, 0.049036528183413405, 0.014578998321667314, 0.03277683085096734, 0.02877667692622968, 0.031327795569917986, 0.031797087352190695, 0.04252452922186681, 0.013921739616697388, 0.02444130295355405, 0.028945913737905875, 0.08221983882997717, 0.03123006277850696, 0.027475465588005524, 0.06841267578835998, 0.0026017589843831956, 0.07051913347095251, 0.06049547490796872, 0.035641500526773076, 0.09108777583709785, 0.017524618921535354, 0.011897036073995488, 0.08363614497440201, 0.039642994558172565, 0.04713030957749911, 0.0035486060452447937, 0.08986605996532099, 0.04912569786288908, 0.07701592985540628, 0.07862690091133118, 0.049527465232781, 0.024874805406268154, 0.023393361596390605, 0.040371524036995, 0.026371026012514318, 0.004044326978536057, 0.07913185988685914, 0.02576594240963459, 0.045058338437229395, 0.07373792718031577, 0.06451864474053894, 0.01844550290011934, 0.019972116786188314, 0.06331392617097922, 0.032171221383448155, 0.1008010453411511, 0.1061712768194931, 0.021398773982322643, 0.020051145759810294, 0.09029498230665922, 0.11034607887268066, 0.02524285976375852, 0.020792670880577395, 0.06652827547597033, 0.0410795380095286, 0.08895575095500265, 0.06021140622241156, 0.05024414409750274, 0.016908892496888126, 0.0034482178494467264, 0.020091091116358126, 0.040919624269008636, 0.05721283105335065, 0.0978353994765452, 0.019825863651931286, 0.02148775876100574, 0.04575310740619898, 0.07051259917872292, 0.04600352754018136, 0.011749447073920496, 0.041095300378011804, 0.03696748348219054, 0.027302953148526803, 0.16873933694192342, 0.08961661013641528, 0.05750214481460197, 0.07431010862014123, 0.0675081614671009, 0.13246440701186657, 0.04922100489160844, 0.03522135164322598, 0.10521188258592572, 0.026875537154929977, 0.08260914151157651, 0.059367098313357146, 0.1124162349317755, 0.38597110179918154, 7.6865628106253485, 45.79593474524361, 73.77237347194126, 73.67328521183559, 57.06677443640572, 31.827898161751882, 23.39032541002546, 47.95615747996739, 71.43577766418457, 70.79449367523193, 63.46695123400007, 55.12513855525425, 44.404380798339844, 12.282552123069763, 1.745435580611229, 0.17736184783279896, 0.25184562749096323, 0.10792689118534327, 0.8524598830512592, 0.9547868179423469, 0.7843339358057294, 3.4290245941707065, 2.653242588043213, 1.9408639797142573, 1.0333342488322939, 0.11971106992236205, 0.11275105803672757, 0.003301220023006733, 0.0628451941800969, 0.02940732433593699, 0.070730042510799, 0.02770489693752357, 0.02671353691922767, 0.01700107996085925, 0.053495941750173054, 0.01567075607765998, 0.03628804940464241, 0.13350405836743967, 0.0933358437780823, 0.08157336459095989, 0.057777813236628256, 0.065986553473132, 0.1565718198461192, 0.34482547108616146, 0.2835810360099588, 0.1848967620836837, 0.10382387135177851, 0.23984907407845768, 0.228770307132176, 0.16073408935751232, 0.10628927405923605, 0.18594283238053322, 0.09196783575628485, 0.10206384650830712, 0.09480575418898038, 0.056996154465845654, 0.13924275471695832, 0.1377854107746056, 0.2498619710760457, 0.1770338032926832, 0.1902567408978939, 0.6375428725566182, 0.21993688041610376, 0.1040278457637344, 0.0702774596533605, 0.06662920755999428, 0.06958257194076266, 0.09086537241403546, 0.714766834463392, 1.5652050631386893, 0.12096669897437096, 0.17776739464274474, 1.0971816799470355, 9.138647726603917, 20.110025269644602, 35.157732009887695, 54.97896235329764, 60.9744656426566, 60.66515268598284, 35.972519465855186, 30.921467440468923, 46.92304025377546, 52.79323625564575, 62.89141804831368, 57.235563550676616, 24.48493766784668, 2.6793178745678494, 0.39329146327716963, 0.07051601899521691, 0.1349370021905218, 0.12751393765211105, 0.03524470681856785, 0.05375906405970454, 0.0421207499956446, 0.031120211351662874, 0.05507427866437605, 0.038646328396030834, 0.018706715133573328, 0.03299209608563355, 0.05321951336892588, 0.04419692126767976, 0.042571131006947587, 0.06730297247746161, 0.017074709492070333, 0.042285047072385035, 0.10608643280076129, 0.06360091934246676, 0.04383788124791213, 0.04661610556234207, 0.04485931733090963, 0.04338945781013795, 0.039533336513808796, 0.027552723585228835, 0.04746638457956059, 0.031865992583334446, 0.05202494229057005, 0.02782930972586785, 0.04522520376901541, 0.041749638837895224, 0.05774613922195775, 0.017435096403849975, 0.017148603651938692, 0.08163183395351682, 0.04010699376729982, 0.01956538762897253, 0.06699671569679465, 0.018115424451285174, 0.07893064032707896, 0.08572133058415991, 0.13816035565521034, 0.07706116778509957, 0.14822662621736526, 0.10762174041675669, 0.16475046026919568, 0.13116410321422986, 0.14178704390568392, 0.1344766840338707, 0.09744503149496657, 0.17743335185306414, 0.20976813749543258, 0.11771822614329201, 0.2322162879364831, 0.12907717376947403, 0.12346009803669793, 0.14120790069656713, 0.20770883799663611, 0.15790552113737377, 0.16960882528551988, 0.15828628784843854, 0.14541624273572648, 0.1363103570682662, 0.13273500677730354, 0.2463738668177809, 0.13407283356147154, 0.18406882722462925, 0.16965929472020694, 0.15618805401027203, 0.11197537715945925, 0.18935589066573552, 0.10694478638470173, 0.10811229409383875, 0.07462412784142153, 0.2106071189045906, 0.2043430193194321, 0.12358889755393777, 0.23409075449619973, 0.16936624901635305, 0.23680815153888293, 0.20935336260923318, 0.07379299029707909, 0.17457857861050538, 0.13893289491534233, 0.19794598115342005, 0.27006388562066214, 0.21505950284855707, 0.4163610568003995, 5.550550639629364, 47.01713970729283, 85.00746468135289, 95.17457607814244, 84.19902787889752, 57.685382979256765, 36.63427632195609, 50.01029511860439, 72.88149629320417, 77.4364573614938, 78.93653869628906, 66.23757321493966, 58.474017415727886, 21.2912346635546, 1.6929659332547868, 0.2601598799228668, 1.3866630664893558, 0.28754905451621326, 1.9190757317202431, 3.057684200150626, 3.6443879178592136, 7.368523785046168, 9.768869314874921, 8.516954183578491, 2.1337414128439764, 0.6773599588445255, 0.7151134301509176, 0.14610781919743332, 0.25400437308209284, 0.12007970442729336, 0.1850732761834349, 0.07080889506531612, 0.16241844397570404, 0.15002931734280928, 0.21796785321618828, 0.2925448907273156, 0.12899919652513095, 0.3980539377246584, 0.4281611336129052, 0.5423227506024497, 0.3336422097470079, 0.29682343399950434, 0.6404209466917175, 0.44595788578901974, 0.8989713958331517, 1.8000840310539519, 0.22913690603205136, 0.4472646085279328, 0.4548365707908358, 0.3447991982102394, 0.5403091300811086, 0.3311377912759781, 0.2138276089515005, 0.15162517742386886, 0.24585318618587085, 0.08995872070746762, 0.1709591235433306, 0.225934627865042, 0.36715532573206083, 0.36677016211407526, 0.2171549546931471, 0.8288686318056924, 0.4189091186438288, 0.4015139506331512, 0.08087275682815484, 0.20418918186000415, 0.26166039226310595, 0.7486734464764595, 1.666713033403669, 3.075397763933454, 0.4922367153423173, 1.003040211541312, 3.5446311107703616, 17.73289888245719, 38.85855449948992, 56.599702630724224, 61.32064574105399, 58.85808604104178, 58.25975234167916, 46.09127140045166, 53.008637360164094, 64.29223046983991, 63.09509754180908, 76.12750707353864, 64.56060464041573, 21.597332341330393, 2.0046686359814236, 0.47907047612326487, 0.13011020262326511, 0.20410101301968098, 0.19443330035677978, 0.09539917377488953, 0.16462912463716098, 0.15582897327840328, 0.09931210202297994, 0.12166253663599491, 0.16463839342551573, 0.10791520681232214, 0.12115473459873881, 0.15200295858085155, 0.22353440523147583, 0.09034280545477356, 0.12592240662447043, 0.18183304076748236, 0.14504977954285486, 0.16361822959567818, 0.23035156513963426, 0.13744516617485456, 0.16074619442224503, 0.16596596076020173, 0.12314387357660703, 0.19890270195901394, 0.17244451812335423, 0.21781774769936288, 0.11188654335481779, 0.17256923285978182, 0.16829873701291426, 0.1534265929034778, 0.26840570888348986, 0.16392300038465432, 0.11148283537477255, 0.09695793834647962, 0.24755671620368958, 0.13509831710585526, 0.1050364812836051, 0.16751707824213163, 0.14903776054935797, 0.17338772251137666], [0.05146521196833678, 0.028133844723924994, 0.12672748842409678, 0.049062041100114584, 0.013329242838413587, 0.05222243669309786, 0.07142054688717638, 0.04523586016148329, 0.05127031296225531, 0.08251838745283228, 0.02162165068356054, 0.04079842095130256, 0.10557795222848654, 0.0718863679628287, 0.019089364779314826, 0.0168574239193861, 0.14887100378317492, 0.06605092609035117, 0.07502534559794835, 0.09576725188110556, 0.07269522241715874, 0.07089090280766998, 0.0545461205765605, 0.06327966015253748, 0.03457384942365544, 0.01839313017470496, 0.0935958516118782, 0.0506191330828837, 0.05680092976295522, 0.07185516892267124, 0.02767755536894713, 0.05837938202811139, 0.061315321629600864, 0.05010316148400307, 0.05715412420353719, 0.018692956139732684, 0.06901978821094547, 0.04885998015691127, 0.015780291985720396, 0.1272899939545563, 0.12807476041572435, 0.05912583840212651, 0.09437376486935786, 0.06533129220562321, 0.09210236210908208, 0.10071556349950177, 0.039214777893253734, 0.14328043162822723, 0.07290963269770145, 0.3041302247771195, 9.006812606539045, 41.27565908432007, 59.65523896898542, 65.87608623504639, 58.88423906053816, 50.29408386775425, 34.96991525377546, 33.817077091761995, 63.78621401105608, 71.29651491982597, 53.620426246098106, 55.114577293395996, 28.757539578846522, 6.728373655251094, 0.23596869515521185, 0.1613407675176859, 0.2106399464287928, 0.4390365300433976, 0.5395168725933347, 1.0445560238191058, 0.6704967671207019, 0.048733572475612164, 0.41833076253533363, 0.14487646812839167, 0.30265774950385094, 0.46499429430280415, 0.05926432739943266, 0.05553388096658247, 0.06122145988047123, 0.043918352108448744, 0.04214723321742245, 0.13414999656379223, 0.07184591370501689, 0.0795645820243018, 0.08536917769483157, 0.034249373977737765, 0.17905860607113155, 0.08183122146874666, 0.045067298492150645, 0.10702880937606096, 0.034470494969614913, 0.06566489394754171, 0.2669024281203747, 0.08407054309334074, 0.09507097317171948, 0.040348457239036045, 0.12446158858282225, 0.13707054699105875, 0.11557253556592123, 0.05506105740953769, 0.06763327653918948, 0.028780486900359392, 0.05965325010142156, 0.0825187267203416, 0.11559107314263072, 0.00831598269620112, 0.14417186379432678, 0.155440946242639, 0.15954497030803136, 1.3543989977666309, 0.35252442796315464, 0.08113650338990347, 0.2412267987217222, 0.31902455698166576, 0.0794999176370246, 0.5371963371123586, 0.3215625493654183, 0.6526388110859054, 2.887214707476752, 8.821790763310023, 16.124389171600342, 25.806059462683542, 41.29120567866734, 44.52700955527169, 42.684962204524446, 43.21538768495832, 41.21830865315029, 53.556791169302805, 63.26643317086356, 69.58042103903634, 46.999550342559814, 18.6298348903656, 1.788151802761214, 0.2908353896013328, 0.22316596071634973, 0.028928678948432207, 0.09691926185041666, 0.04521979584491678, 0.05021612738658275, 0.02753357363066503, 0.040305353301976404, 0.017356518656015396, 0.09740903521222727, 0.05740826949477196, 0.029965192079544067, 0.13732233776577882, 0.03005024983680674, 0.06923396778958184, 0.06435970469777073, 0.06273360231092998, 0.016422827328954424, 0.048861327048923285, 0.06074090102421386, 0.08878685680351087, 0.03668665140867233, 0.06597261636384896, 0.07747820219291107, 0.0326546538355095, 0.028857799180384194, 0.04781968080039535, 0.07101858952747923, 0.028669325900929313, 0.06169154894139085, 0.012561389710754156, 0.03418295557743736, 0.06372303528977291, 0.044510244990565946, 0.04715187342039176, 0.09084961683090244, 0.06524126417934895, 0.08608398719557694, 0.05970120895653963, 0.07944983496729817, 0.0016856976934442563, 0.07892567345074245, 0.02859642749120082, 0.07949741384280579, 0.06414725538343191, 0.062354565864162784, 0.014012190031020768, 0.01077761359712375, 0.023941051314717958, 0.05161427593390856, 0.05049140225829823, 0.09506401140242815, 0.10556999979806797, 0.016797561863703386, 0.03240247968850391, 0.028130375713642155, 0.024267945737977113, 0.05202533244820578, 0.027090585258390223, 0.02885368386549609, 0.015809701389766166, 0.05522242321499756, 0.008564469005380358, 0.02863196237012744, 0.00807072366920433, 0.07554669119417667, 0.07226247992366552, 0.058796104309814315, 0.06203237029590777, 0.02299366715098066, 0.05536020653588431, 0.08079614343919925, 0.0653635294043592, 0.024419572869581834, 0.044423755524413924, 0.0742700139858893, 0.08323228771665267, 0.19006780960730144, 0.04957402630576065, 0.027390553715771863, 0.03822953147547586, 0.07297701801040343, 0.07811284956655332, 0.11288093642464705, 0.09251639060676098, 0.06793846801987716, 0.07672857027500868, 0.11149262663509164, 0.0811636040785483, 0.12299707931067262, 0.2371827842933791, 0.07179030776023865, 1.2079815630401884, 20.057781764439174, 59.94068486349923, 71.87618228367397, 73.10146236419678, 50.67756189618792, 44.419826643807546, 37.217806884220664, 44.52384465081351, 83.38458783285958, 75.79048470088414, 58.48358508518764, 54.8626321383885, 24.931508813585552, 6.592427372932434, 1.248503131525857, 0.19310922069208963, 0.06278369176600661, 0.29482783536825863, 0.6296461905751909, 0.2902359717658588, 0.2036243285983801, 0.5909769141248294, 0.5119795330933162, 0.30764302771006313, 0.1634847346161093, 0.29575045300381525, 0.042091240507683585, 0.06284579807626349, 0.046254443004727364, 0.053915897251239846, 0.1484281646886042, 0.11702531975294862, 0.12195011334759848, 0.06339252766753946, 0.10929052265627043, 0.2461094010089125, 0.10170830772923571, 0.01659258152358234, 0.026436603029391596, 0.08676532456385237, 0.20757265601839336, 0.17844409761684282, 0.17579627755497182, 0.012393582911629761, 0.021615784748324325, 0.03264283714815974, 0.07941364869475365, 0.12449064345232078, 0.054986303206533194, 0.09263081875230585, 0.023943117453849742, 0.021737379920003668, 0.15908169373869896, 0.14319903456739017, 0.200880373695067, 0.04143223372687187, 0.050665789150765965, 0.06220743233071906, 0.08894306913550411, 0.9674158202750343, 0.299093703606299, 0.0422416411872421, 0.25968216412833756, 0.24907717747347696, 0.25010583656174795, 0.5069006713373321, 0.31468369705336435, 0.4876671348299299, 2.175803852932794, 12.918869018554688, 25.09955620765686, 38.404305594308035, 55.184180872780935, 66.0487767628261, 53.92827313286917, 38.28717286246163, 30.788652624402726, 43.73691599709647, 67.75999300820487, 76.99870000566754, 57.728086607796804, 30.088229043143137, 4.0310907789639066, 0.3458149922745568, 0.23168369222964558, 0.04505696779649172, 0.12027596389608723, 0.0816404784896544, 0.01515159706052925, 0.02896973370973553, 0.05566852945568306, 0.018726334973637546, 0.10330304822751454, 0.061851092880325656, 0.08411415932433945, 0.10694575668977839, 0.07879309449344873, 0.06548409829182283, 0.040398689186466594, 0.12526605970093183, 0.038997694184737544, 0.02704357635229826, 0.04810955774571214, 0.03327971011666315, 0.0030447513854596764, 0.09263769231204476, 0.03860334998794964, 0.045205617855702124, 0.0012406334280967712, 0.05181638776723828, 0.01361648113067661, 0.023994065255724957, 0.019998995254614522, 0.030035898821162324, 0.04742268692435963, 0.02019554140445377, 0.03481674460428102, 0.06802410592458077, 0.06856506796819822, 0.08908957841673068, 0.057478620005505424, 0.07830518031758921, 0.0195509704561638, 0.10090234383408513, 0.0897524935592498, 0.12307673932186194, 0.16366503494126455, 0.16711683757603168, 0.2827626684946673, 0.136879240827901, 0.09368792881390878, 0.10028474804546152, 0.21188494962240967, 0.14794465420501574, 0.14823531146560395, 0.2637224873261792, 0.08465463960809366, 0.09523581646914993, 0.16946346951382502, 0.15354290737637452, 0.12041069380939007, 0.07323836934353624, 0.19320926389523915, 0.13658318242856435, 0.1288070354078497, 0.1746535703007664, 0.15769126691988536, 0.21729868198079721, 0.15574997823153222, 0.16037681352879318, 0.17891816289297172, 0.20437657966145448, 0.13938999681600503, 0.1483864483556577, 0.12346423710031168, 0.18038503346698626, 0.21095756867102214, 0.1297680309840611, 0.18097667529114655, 0.23674730051841053, 0.30284282671553747, 0.15284039293016705, 0.19409198367169925, 0.16931021559451306, 0.11384970801217215, 0.22207037093383925, 0.19957301313323633, 0.22658212669193745, 0.1547937731125525, 0.2036652849721057, 0.1344804566885744, 0.16893426648208074, 0.2513886477266039, 0.347889599523374, 0.18836028980357306, 0.551639090691294, 16.212945699691772, 64.05361543382917, 87.1286037990025, 92.40863718305314, 76.57980006081718, 73.13730812072754, 53.48476266860962, 48.883057594299316, 83.14380495888847, 89.12497411455426, 71.5432037625994, 72.97321946280343, 45.73163264138358, 12.151431798934937, 1.2430020038570677, 0.3262964167765209, 0.6914089449814388, 1.0140899100473948, 3.4118992388248444, 2.6883867936474934, 2.2518269164221625, 1.9152733300413405, 1.9351332357951572, 0.34777205011674334, 0.7837798712509019, 0.7468548097780773, 0.20516429096460342, 0.092768798848348, 0.11607596783765725, 0.1410941103739398, 0.2963917500206402, 0.23727948910423688, 0.28224975030337063, 0.2761569400983197, 0.20205569134226867, 0.28521983378699844, 0.7130080716950553, 0.12714264328990663, 0.2995956838130951, 0.6817140909177917, 0.4642136533345495, 0.5249051366533551, 0.42001124950391905, 0.17269098918352807, 0.2510610781610012, 0.1718778328171798, 0.20421286273215497, 0.2992165727274758, 0.2557731510273048, 0.3806214231465544, 0.2640508439924036, 0.10885579205517258, 0.2995458250599248, 0.1676492840051651, 0.27194855734705925, 0.10535126724945647, 0.4070570117660931, 0.2918779993695872, 0.6164054753524917, 3.274371155670711, 0.797526339335101, 0.5267021145139421, 0.6090055352875164, 0.6219393898333822, 1.692471091236387, 1.5011913095201765, 0.5292804933020047, 0.6435425877571106, 5.850168253694262, 22.99047221456255, 40.916895798274446, 59.12260396139962, 70.36629704066685, 63.942020416259766, 59.91232231685093, 58.62191677093506, 55.39249134063721, 66.17781175885881, 78.20224612099784, 89.12185437338692, 69.81681959969657, 32.15434537615095, 3.5167571093354906, 0.41187623888254166, 0.3416088622595583, 0.09822837981794562, 0.13622526877692767, 0.12158753137503352, 0.0842071593339954, 0.10813479431505714, 0.20121622138789722, 0.19885333175105707, 0.3784798037792955, 0.16843474257205213, 0.1413562148809433, 0.19598656200936862, 0.15218012407422066, 0.18505893195314066, 0.17345514175082954, 0.19824801066092082, 0.13419575696544989, 0.0891161769894617, 0.17197818814643792, 0.2645646849913256, 0.1302155383995601, 0.18385952631277697, 0.13424356654286385, 0.20001060036676271, 0.06166701311511653, 0.10415599388735634, 0.17377807013690472, 0.14833661674388818, 0.11934665590524673, 0.08118248770811728, 0.1459310201129743, 0.14376843401363917, 0.19454033247062139, 0.17495180001216276, 0.10354972963354417, 0.13793071226349898, 0.19781026057898998, 0.1971943136304617, 0.14836409741214343, 0.1407162206513541, 0.2732368510748659, 0.17856309908841336], [0.0026113343857494847, 0.06443494744598866, 0.06538062170147896, 0.06321748598877873, 0.04376462321462376, 0.04504152433946729, 0.035505457648209164, 0.02347657034572746, 0.04712897625618747, 0.06665035071117537, 0.020465535577386618, 0.057772893857743056, 0.05667202168011239, 0.13927280024758407, 0.031957679627729316, 0.02004018402658403, 0.057273946702480316, 0.008415511060905243, 0.05840218759008816, 0.09011298564395734, 0.03389074447165642, 0.07572955638170242, 0.1018781518297536, 0.019048688301284398, 0.041592904033937624, 0.0710501821179475, 0.05440010323322245, 0.07733547913708858, 0.023146629300234572, 0.11002975941768714, 0.03757016846377935, 0.03326948120125702, 0.12460364667432648, 0.10500808459307466, 0.023521496149312173, 0.03058189559461815, 0.019237804492669444, 0.05129138147458434, 0.03516730972166572, 0.01660972979984113, 0.0637963442131877, 0.052524842787534, 0.0237983774526843, 0.09269364430968251, 0.05543640262580343, 0.025839253029386913, 0.35212509653397966, 0.08450206422380038, 0.044134835313473425, 0.22116524593106338, 0.04128753274147, 1.627363647733416, 15.366123574120657, 42.513251372746055, 59.703612327575684, 62.36250727517264, 53.033463273729595, 40.01063183375767, 29.92058638163975, 33.25188282557896, 53.031406606946675, 59.156747409275596, 65.60781628744942, 55.206554072243826, 33.941366468157085, 15.844164848327637, 2.0182080694607327, 0.18981737590261868, 0.035340068130088706, 0.32380280058298794, 0.4985469824501446, 0.610722011753491, 0.33952187853200094, 0.5293231595839772, 0.2315535492130688, 0.5274234243801662, 0.4404577080692564, 0.1279684068369014, 0.07016102982951061, 0.1856564363198621, 0.14873236550816468, 0.18840348534286022, 0.35578875137226923, 0.05255696802799191, 0.0827756743612034, 0.5869008185608047, 0.12546765245497227, 0.12785381584295205, 0.2878291266305106, 0.11540721729397774, 0.16614813384200844, 0.14018616266548634, 0.22377540729939938, 0.16049525860164846, 0.09439865353384189, 0.11528026339198862, 0.058287033412073336, 0.016223560253690397, 0.07976803396429334, 0.17703197124813283, 0.17339358505393776, 0.08395558569048132, 0.14757791959813663, 0.17119524015911988, 0.11887649899082524, 0.13175423869064876, 0.41134719869920183, 0.1578264446663005, 0.12226062454283237, 1.1286007825817381, 0.5749701644693102, 0.17271304157163414, 0.2927477998392922, 0.20355184748768806, 0.3836814532322543, 0.38127086258360315, 4.048195506845202, 13.549504024641854, 22.033326591764176, 38.666440282549175, 42.29695047651018, 37.80570091520037, 37.802945954459055, 27.364290271486553, 49.88993147441319, 51.739649636404856, 53.02819653919765, 64.4835421698434, 42.84667110443115, 13.577586037772042, 1.1940480364220483, 0.3603979040469442, 0.12160920378352914, 0.25058227671044214, 0.08926742244511843, 0.10214725203279938, 0.010899779586387532, 0.044654644027884514, 0.08300808617579085, 0.04036307966868792, 0.02247021470351943, 0.024321841774508357, 0.09973254267658506, 0.021679153133715903, 0.05573874765208789, 0.0577129792155964, 0.0542912899649569, 0.08113259502819606, 0.016068112969930683, 0.04545782592945865, 0.10942873345421893, 0.03136897925287485, 0.05034414998122624, 0.0300266232474574, 0.07220978489411728, 0.02067337085359863, 0.062246739864349365, 0.05604616812031184, 0.06244966933237655, 0.08425113518855401, 0.0972169419484479, 0.09114860650151968, 0.01524463269327368, 0.08092012535780668, 0.08587393989520413, 0.06464779709598847, 0.02795641460189862, 0.12779095635882445, 0.156840302582298, 0.004565116600133479, 0.08850607222744397, 0.02209924773446151, 0.025212726023580347, 0.03743462430845414, 0.027752808295190334, 0.10199251890714679, 0.029571414459496737, 0.08108237665146589, 0.0694656196449484, 0.06381515998925481, 0.10667607294661657, 0.04402808818433966, 0.03754475393465587, 0.06334477915827717, 0.022333610337227583, 0.033136647793331316, 0.031520706468394825, 0.01405219136670764, 0.03185237438551017, 0.02648857711548252, 0.012747215007298758, 0.02850680658593774, 0.13438467468534196, 0.07377402524330787, 0.07160077257347958, 0.01147515098896942, 0.12813964193420752, 0.060165197987641604, 0.11423895641097001, 0.03739224640386445, 0.044104324986359904, 0.04998459427484444, 0.013695874816871114, 0.08239757429276194, 0.050169681664556265, 0.06906607108456747, 0.04446054230044995, 0.056103765565369806, 0.07659392857125827, 0.08964180414165769, 0.04557621332683733, 0.07160173609320607, 0.0338871889481587, 0.10581125970929861, 0.028050517230959873, 0.09104381355323962, 0.07727578841149807, 0.04178492265886494, 0.030664123860853057, 0.11718819529882499, 0.05138065293431282, 0.059853682560580115, 0.1759135691182954, 0.2032378621931587, 0.031426193325647285, 0.10132344266665833, 0.018962763715535402, 6.501710389341627, 32.71596826825823, 62.747041429792134, 73.11632456098283, 71.63088308061872, 58.33084283556257, 39.605398995535715, 37.60481807163784, 53.59676415579659, 65.78388363974435, 69.20922742571149, 68.8028759275164, 46.18897696903774, 23.002129554748535, 11.98045573915754, 2.683118539197104, 0.6543513249073709, 0.08353201020509005, 0.1508373168430158, 0.614418507686683, 0.46060335849012646, 0.3124965615570545, 0.586036636361054, 0.1173920136477266, 0.25873957042183193, 0.23011942473905428, 0.22912420385650226, 0.08325936126389674, 0.07290050640170063, 0.034322822000831366, 0.03943501339693155, 0.1547131902937378, 0.07008953937994582, 0.016960722394287586, 0.2219741139560938, 0.07699609627681119, 0.10699127960417952, 0.05781934636511973, 0.1512324684964759, 0.013781628072527903, 0.5397926835077149, 0.03736206855891006, 0.13061685115098953, 0.0977426233834454, 0.06421748375786202, 0.1600767924849476, 0.1585510250713144, 0.06279206488813673, 0.11098140478134155, 0.14289475232362747, 0.06612086269472327, 0.060384737992925305, 0.12593832505600794, 0.09972099401056767, 0.09864220475511891, 0.3223683504121644, 0.1251792072185448, 0.3513185355280127, 2.6841329761913846, 0.2939572477979319, 0.06349099666944572, 0.5171181602137429, 0.43485887135778156, 0.1704987103917769, 0.13060433896524565, 3.497584423848561, 16.476376226970128, 30.86547190802438, 47.25847148895264, 56.19469908305577, 57.16553613117763, 56.85660532542637, 33.95412336077009, 38.86501979827881, 50.18581703730992, 56.78694268635341, 71.05457864488874, 52.5147385597229, 28.527337074279785, 4.340385930878775, 0.45292057788797785, 0.2821266640509878, 0.1761938040809972, 0.05588631205526846, 0.08581403882375785, 0.11136373212294919, 0.12651951744088105, 0.05458021017589739, 0.019442910361768942, 0.05404932776998196, 0.04137652600184083, 0.08421654347330332, 0.04684336390346289, 0.038642141834965775, 0.014390872791409492, 0.047085563585694344, 0.06455883436969348, 0.05664874114362257, 0.0580086779913732, 0.04175061592832208, 0.04062403066615973, 0.03674765509952392, 0.031726054913763485, 0.06318137435508625, 0.013617414116327251, 0.08748650550842285, 0.018597966326134543, 0.0860297926036375, 0.01185744016298226, 0.08041844370641879, 0.07887217096452202, 0.08446476515382528, 0.014364569381411587, 0.09352561645209789, 0.029306894367826835, 0.005740495739571218, 0.049836032425186465, 0.1388931463339499, 0.022468537025685822, 0.06860828386353594, 0.025326406084267155, 0.0430673300953848, 0.06066322233527899, 0.0618961543909141, 0.010084138933702238, 0.1510120803224189, 0.12256276261593614, 0.14734651201537677, 0.1921795734337398, 0.2070704043975898, 0.11389009441648211, 0.08516170204217945, 0.13678510087941373, 0.12972518828298363, 0.2236727313803775, 0.1645458819610732, 0.14677727541753224, 0.08294127083250455, 0.20625029983265059, 0.24109850132039615, 0.0976059189332383, 0.23254605595554623, 0.21596352862460272, 0.1387919360505683, 0.10267851781100035, 0.18933702739221708, 0.22378642670810223, 0.32327574172190254, 0.14172608431960854, 0.17653460507946356, 0.23809666239789554, 0.08989822931055512, 0.11049886460282973, 0.17272241892559187, 0.2769431993365288, 0.09839291777461767, 0.13338730963213102, 0.1075476376073701, 0.16406918396907194, 0.1393477783671447, 0.09831128322652408, 0.15030975586601666, 0.24533318408897944, 0.13457368740013667, 0.17777949970747742, 0.17938332578965596, 0.21075062906103476, 0.2203591598996094, 0.25940556611333576, 0.14120302881513322, 0.1165787215743746, 0.3598079857017313, 0.4676211476325989, 0.08957281070096151, 0.27714708553893225, 0.07346592284739017, 3.6848876646586826, 27.531741857528687, 73.34027194976807, 89.58592455727714, 90.65270927974156, 80.29330648694719, 61.407991545540945, 47.94166006360735, 50.04495620727539, 74.23691613333565, 82.56550639016288, 90.25149944850376, 78.80478695460728, 48.997980798993794, 24.581204959324428, 4.898689321109226, 1.0622182360717227, 0.15412490043256963, 0.6238904222846031, 1.3836210582937514, 1.6825329959392548, 0.3634711248534066, 1.333391553589276, 0.9238477924040386, 1.4275953386511122, 0.897032197032656, 0.9930857228381293, 0.1570025538759572, 0.2305213888841016, 0.23472754604050092, 0.2497244184570653, 0.6535484822733062, 0.11263736949435302, 0.19557319847600801, 1.1557294811521257, 0.18249999997871263, 0.12669934279152326, 0.823934542281287, 0.569984994828701, 0.39152303817016737, 0.8591631033590862, 0.1968406340373414, 0.34011554239051683, 0.14186408477170126, 0.2819320873490402, 0.41582338565162247, 0.36832935416272705, 0.3153332450560161, 0.37660544578518185, 0.5723512907113347, 0.2424354324383395, 0.2529548965394497, 0.4253060482442379, 0.280391731432506, 0.2814259002251284, 0.5845776232225555, 0.4163919708558491, 1.1066446921655109, 6.767502869878497, 1.627656883427075, 0.6947471744247845, 1.0900914775473731, 1.1449158042669296, 0.5250391608902386, 0.7111894892794746, 6.941969965185438, 28.8521306174142, 50.61849873406546, 69.8087180001395, 67.22081279754639, 56.15521594456264, 55.66916513442993, 42.92265313012259, 65.300094468253, 67.72370951516288, 68.86540971483502, 86.63985361371721, 64.38580186026437, 30.622667108263286, 4.449239015579224, 0.4743255621620587, 0.36867760547569817, 0.27243664115667343, 0.16137994612966264, 0.22462268040648528, 0.10512123030743428, 0.2314219677022525, 0.23457767122558185, 0.26379612194640295, 0.19958837516605854, 0.34245314981256214, 0.2962079755961895, 0.2635994010737964, 0.08120293875357934, 0.143503248957651, 0.1489631895508085, 0.1294268907180854, 0.054416452534496784, 0.11638400916542326, 0.15920735842415265, 0.16100061791283743, 0.12821951907660278, 0.11817901927445616, 0.1924699049975191, 0.12880737467535905, 0.16445594892970153, 0.10448763466307096, 0.15268947317131928, 0.10780170147440263, 0.14777168205806188, 0.12864840749119008, 0.154731280037335, 0.15588409746331827, 0.14655782362180098, 0.09313978786979403, 0.1439701896160841, 0.28500557956951006, 0.19405557348259858, 0.07504884326564414, 0.15104618349245616, 0.08879273970212255, 0.16914891424987996, 0.13349103049508163, 0.15990295181316988, 0.25505284539290835], [0.06404229958674737, 0.11303888580628804, 0.06431861261704139, 0.11999589178178992, 0.07918091118335724, 0.08699369909507887, 0.02210151234508625, 0.08026865031570196, 0.02996010985225439, 0.07292468938976526, 0.027134176044325744, 0.07532082045716898, 0.1058444536424109, 0.04988554512549724, 0.049264651656683, 0.08772000297904015, 0.042527596200151105, 0.09265014342963696, 0.01734431690004255, 0.06590822339057922, 0.01930037559941411, 0.07929223842386689, 0.020792625079463636, 0.05086554986025606, 0.05967357901058026, 0.12858443520963192, 0.07084293716720172, 0.05100622374032225, 0.10481212367968899, 0.12921484852475779, 0.17205483546214445, 0.026302203901910355, 0.032134444785437415, 0.04076465704877462, 0.03767939903108137, 0.034824310269738944, 0.029368708908025707, 0.09101842955819198, 0.0436033999015178, 0.05769553408026695, 0.06464183277317456, 0.10432534944266081, 0.08657707180827856, 0.07185405612524066, 0.15354406088590622, 0.09154885395296983, 0.022199706540309956, 0.17406956878091606, 0.2308230655533927, 0.07629664880888802, 0.06295004141117845, 0.10379602427461318, 0.17706683437739099, 3.3669654556683133, 16.387185675757273, 28.685137612479075, 45.971411500658306, 50.81935378483364, 45.392602239336284, 34.43785694667271, 28.647657292229788, 25.01836998122079, 41.41706534794399, 58.87742287772042, 69.23738847460065, 62.23245784214565, 36.51308931623186, 21.55800380025591, 9.832480941499982, 2.2628578330789293, 0.5870809831789562, 0.31419260054826736, 0.009119005142045873, 0.15303928511483328, 0.972286724618503, 0.7071690878697804, 0.41503601361598286, 0.848212470965726, 0.3682612563882555, 0.053709680281047306, 0.11282066215894052, 0.13084642668919905, 0.5245373163904462, 0.1001154196315578, 0.3130016087421349, 0.01478171574750117, 0.34961872388209614, 0.4852847712380545, 0.22647974932832377, 0.14451953156718186, 0.034068602070744546, 0.19391947292855807, 0.09019972277539116, 0.22954215428658895, 0.028417782791491066, 0.23568343903337205, 0.320392157882452, 0.24541251840335981, 0.26160757509725435, 0.19834174348839692, 0.11620893355991159, 0.24919936805963516, 0.20707347137587412, 0.45934106622423443, 0.840207114815712, 0.15992541132228716, 0.3268169074186257, 0.11300233312483345, 0.3141576967069081, 0.2819277990077223, 0.21695226271237644, 0.1163536107965878, 0.14440955461135932, 1.1614737957715988, 3.6640404633113315, 17.787607261112758, 28.28820960862296, 37.03025763375418, 47.39235632760184, 51.02773373467581, 33.709630148751394, 36.486964089529856, 34.63689851760864, 53.85186726706368, 58.46703447614397, 56.23964350564139, 54.226941449301584, 22.26835114615304, 3.3587251092706407, 0.3760323008256299, 0.008423695041398917, 0.06877662161631243, 0.04139391685436879, 0.22865216061472893, 0.081699517821627, 0.05291914966489587, 0.035049556754529476, 0.03867574628176434, 0.058253194870693345, 0.07079647108912468, 0.07058722446007387, 0.06138595712504216, 0.06271631323865481, 0.03461732994765043, 0.1627759233649288, 0.0960522840863892, 0.05989932082593441, 0.054107546074582, 0.04110931891149708, 0.01688829217372196, 0.042702491993882825, 0.031108554120042493, 0.09847341238387994, 0.033650003639715056, 0.05101424741691776, 0.0713459351765258, 0.010709961111258184, 0.09714698498802525, 0.02785647487533944, 0.057724086833851676, 0.08749056993318455, 0.06844705037240471, 0.0734951812773943, 0.04497448507962482, 0.16306451787906034, 0.04612781819222229, 0.023413995846307704, 0.040349824487098625, 0.08535026692386184, 0.0517786205081003, 0.09845780607845102, 0.12508700788021088, 0.14808758082134382, 0.13363611485276902, 0.10503898507782392, 0.06025158228086574, 0.023852755249078785, 0.09556498059204646, 0.05423864582553506, 0.1815288263772215, 0.09939461188124758, 0.05867778815861259, 0.08402378524520568, 0.06896744601960693, 0.012786454687427198, 0.06313708637441907, 0.10967652087232896, 0.032029061511691125, 0.047553237061947584, 0.049147835067872486, 0.061581904467727454, 0.04944277727710349, 0.014540167458887612, 0.07332663317876202, 0.02353989123366773, 0.08551985318107264, 0.05480318356837545, 0.07395606940346104, 0.028155739352639233, 0.022656063748789684, 0.14326420107058116, 0.05379316044439163, 0.09100810904055834, 0.0749010176264814, 0.19366997560220106, 0.1528881210833788, 0.11728788566376482, 0.06559951031314475, 0.021598580492926494, 0.02657047798857093, 0.06608450000307389, 0.02864898002839514, 0.02196277228982321, 0.05853738569255386, 0.034168316184410026, 0.090283949327256, 0.05050528508477977, 0.12410539841013295, 0.07671554918800082, 0.06733979657292366, 0.1414346806704998, 0.07646094249295336, 0.0638993119022676, 0.1869667824357748, 0.17025990677731379, 0.009955747385642357, 0.14569327501314028, 0.10688528564891644, 0.3758208421724183, 10.415489520345416, 36.06605611528669, 57.43131167548043, 70.729875428336, 69.79924760546002, 48.25649683816092, 31.157629762377056, 40.30332817350115, 44.59188835961478, 64.37644263676235, 79.75745446341378, 77.9004511151995, 57.067559582846506, 29.892984662737163, 14.444504959242684, 3.919722012111119, 1.6963954120874405, 0.1630203995321478, 0.1673647878425462, 0.11007273104041815, 0.2016044519841671, 0.5777203483240945, 0.26493961630123003, 0.17090352438390255, 0.696684581892831, 0.2896407608475004, 0.0821303129196167, 0.29444367598210064, 0.31361546580280575, 0.5523252795849527, 0.03791472854624901, 0.5080188970480646, 0.16213094868830272, 0.35721712186932564, 0.6947471744247845, 0.2596536385161536, 0.1358500389116151, 0.08970109453158719, 0.09217818161206585, 0.0022903266778614905, 0.2377154342830181, 0.03144357060747487, 0.0937164815674935, 0.0931995939463377, 0.13288249314895698, 0.246094283248697, 0.12488943205348083, 0.14948492869734764, 0.18559635882931097, 0.20487420367343084, 0.37920561911804335, 0.5062621970261846, 0.11661415467304842, 0.18731936280216488, 0.033625830829675706, 0.4908171115177018, 0.7054065795881408, 0.2483291333275182, 0.042993583516883, 0.10659151391259261, 0.771521294755595, 5.1264325976371765, 21.52568425451006, 40.10949427740914, 51.37489005497524, 61.342699323381694, 73.55116367340088, 54.220469202314106, 40.07910633087158, 31.121110030582972, 43.68888657433646, 64.74687889644078, 62.93830449240548, 64.80079691750663, 35.816692216055735, 8.187546168054853, 0.637287471975599, 0.3767812134964125, 0.1672164329460689, 0.0679209753870964, 0.2907917733703341, 0.10577263071068696, 0.05180297991526978, 0.03266249091497489, 0.05248569810230817, 0.043499360127108436, 0.037605326755770614, 0.08077782299369574, 0.03902806541217225, 0.12033931192542825, 0.04525952746293374, 0.1269984274570431, 0.07153357725058283, 0.0935640147488032, 0.10583876751895462, 0.11185816023498774, 0.026138732941555123, 0.053087036191884956, 0.08872804138809443, 0.07959818307842527, 0.047030958480068615, 0.08378618263772555, 0.0700037996949894, 0.0634491378441453, 0.029889630419867377, 0.03013485636828201, 0.02081699636099594, 0.038575167035950084, 0.07034019700118474, 0.06494746530162436, 0.027350957804758633, 0.0910050692036748, 0.005125385933622185, 0.043221537356397936, 0.07840371038764715, 0.047853790755782805, 0.08424704362239156, 0.18087379581161908, 0.04328682938856738, 0.06145165967089789, 0.09155281659747873, 0.07256693180118289, 0.09931134206375905, 0.2541656472853252, 0.16815867381436483, 0.1593421154788562, 0.27920014251555714, 0.26452929260475294, 0.1512696115033967, 0.14501600206962653, 0.17046141810715199, 0.13820072848881992, 0.18836407602897712, 0.20952261638428482, 0.13501831782715662, 0.1599484679422208, 0.14963122084736824, 0.19496299193373748, 0.28089574724435806, 0.1525554217930351, 0.15749526529439858, 0.08920464438519307, 0.2640352376869747, 0.09896136048649039, 0.19055450920547756, 0.11616999922054154, 0.13857053007398332, 0.37802309542894363, 0.2630170008965901, 0.133158589048045, 0.16550296917557716, 0.24185381936175482, 0.2691810301371983, 0.3267369217106274, 0.1255291820104633, 0.1625723357179335, 0.21242819832903997, 0.21999627937163624, 0.12806697083371027, 0.12994377155389103, 0.16114724933036736, 0.16624862487827027, 0.23616598599723407, 0.1761246613625969, 0.2008926144668034, 0.24073879633631023, 0.14725777320563793, 0.21505748081420148, 0.20954264673803533, 0.1235826143196651, 0.2983964410211359, 0.35857028354491505, 0.16397403978875705, 0.2716889227075236, 0.28096930044037954, 0.2557978225605828, 6.480823235852378, 35.585195609501426, 67.28340217045375, 86.8978054864066, 92.44290569850376, 78.92270483289445, 57.17619814191546, 48.00197737557547, 44.924053941454204, 65.10250159672329, 81.30721541813442, 94.7470395224435, 81.40134961264474, 53.186375754220144, 32.42228528431484, 17.618027789252146, 5.268294402531215, 1.227268459541457, 0.5327808654734066, 0.2238387960408415, 0.24910187614815577, 1.3213446800197874, 0.6976790970989636, 0.37155421397515703, 0.9333650874240058, 0.8159005790948868, 0.3146044441631862, 0.5327277226107461, 0.8193063906260899, 2.9700335434504916, 0.11386174522340298, 0.6843640144382204, 0.25337561539241243, 1.7943327682358878, 1.928522024835859, 0.67711633763143, 0.3396972662636212, 0.23715287446975708, 0.3989423300538744, 0.17645873129367828, 0.407326444451298, 0.1043653151552592, 0.7440277614763805, 0.4300456153494971, 0.7355422739471708, 0.6650189267737525, 0.8052029588392803, 0.40922484972647255, 0.5487150390233312, 0.4784162055168833, 0.6037189875330243, 0.673201896250248, 0.40851819621665136, 0.4867919875042779, 0.15305695416671888, 1.0313543379306793, 1.099343329668045, 0.8141141320977892, 0.11759013230247156, 0.19164050450282438, 1.6689124639545168, 8.93230881009783, 34.10438162939889, 58.02250957489014, 72.18960857391357, 69.64353847503662, 72.91983645302909, 50.84501000813076, 53.74592808314732, 51.71054710660662, 67.45659991673061, 75.64139025551933, 77.60188007354736, 77.7671707698277, 35.31384066173008, 7.096593873841422, 0.5128917012895856, 0.3318710433585303, 0.20693876860397203, 0.17903810074286802, 0.3615191967359611, 0.18797864099698408, 0.12966573504464968, 0.20247322108064378, 0.1111172339213746, 0.14406951357211384, 0.2712623955948012, 0.08622759234692369, 0.14702111376183374, 0.2424552728022848, 0.10190679279289075, 0.24457957595586777, 0.2013738586434296, 0.1649466925965888, 0.17237388262791292, 0.2336694656738213, 0.10666267187999827, 0.22467707177358015, 0.13999622714306625, 0.17658345960080624, 0.11382089062993016, 0.1651897438402687, 0.11611552642924444, 0.13004466971116407, 0.2080330555992467, 0.1452331468462944, 0.15338442873741898, 0.1437075287103653, 0.1657366430652993, 0.232773202338389, 0.15286051827882016, 0.332846749573946, 0.11432504893413611, 0.13745717624468462, 0.08285827921437365, 0.12623074650764465, 0.1524308156222105, 0.26808953870620045, 0.26535713246890474, 0.18777893457029546, 0.1541857243116413, 0.20880190362887724, 0.19977707575474465], [0.03761899245104619, 0.039320476685783694, 0.03494613444698708, 0.02241811339211251, 0.049132679988230975, 0.03507505949320538, 0.030539344663598707, 0.05469677231407591, 0.0618576475286058, 0.030802599287458828, 0.03016605201576437, 0.052783130535057614, 0.013744844689166971, 0.047393998463771174, 0.06710901324238096, 0.07260064820625953, 0.0475491115690342, 0.08161265855388981, 0.06405625705208097, 0.06680058514965431, 0.050089034384914806, 0.053004109034580846, 0.010719686214412962, 0.0691476920619607, 0.022490509685927203, 0.04606382555461355, 0.07703890505113772, 0.17257633033607686, 0.09551820917321102, 0.08299231702195746, 0.05914764651762588, 0.016960023503218378, 0.0015212542015693284, 0.060753718550716124, 0.061386879932667525, 0.12326857474233423, 0.03645126082535301, 0.02159933197045965, 0.031292060523160865, 0.040260888902204375, 0.10250708593853883, 0.0170600667063679, 0.07518538486744676, 0.08553881144949368, 0.015941128533865725, 0.03029989983354296, 0.1199648284486362, 0.1091031316401703, 0.05306661228782364, 0.04453962555687342, 0.10016216390899249, 0.0594013100489974, 0.15879689902067184, 0.19191613899809973, 0.5507160659347261, 3.775176465511322, 14.842179025922503, 26.241609028407506, 22.3524660382952, 15.855563368116107, 39.07892009190151, 31.607886927468435, 27.117938416344778, 17.202902453286306, 32.69009665080479, 57.88002634048462, 64.09249755314418, 65.48999568394252, 67.54735728672573, 43.85402093614851, 26.524965252195084, 16.551468883241924, 12.034814970833914, 10.39025366306305, 8.925212962286812, 8.858605793544225, 5.101694405078888, 2.914977537734168, 1.7008018727813448, 1.2428379612309592, 0.7138001663344247, 1.0939825773239136, 0.4607960081526211, 0.9683287484305245, 1.0762530543974467, 0.08576525215591703, 0.31772228543247494, 0.5957710083041872, 0.4575710669159889, 0.22247112728655338, 0.31178792672497885, 0.26713673983301434, 0.3409604270543371, 0.01582639165488737, 0.02627350017428398, 0.11417723686567374, 0.14524005433278425, 0.17002590719078267, 0.16336456606430666, 0.18709252854543074, 0.22430807085973875, 0.38428591936826706, 0.830314291375024, 0.3142254145017692, 0.22794542568070547, 0.8653480857610703, 1.0206207824604852, 1.2219297460147311, 1.5908673661095756, 2.2936770021915436, 4.6100181596619745, 5.050354165690286, 10.302243437085833, 18.85128266470773, 38.014685358319966, 38.473669460841585, 45.60247605187552, 66.11645221710205, 42.675870486668174, 30.429246629987443, 41.97134052004133, 51.07677412033081, 56.98388590131487, 60.33951146262032, 52.51940427507673, 31.96205050604684, 2.7235090689999715, 0.4527444301971367, 0.15242774864392622, 0.19205248382474693, 0.023712015211848275, 0.05396745912730694, 0.11464391968079976, 0.11695416857089315, 0.052625574703727446, 0.020636399176770022, 0.03850327625072428, 0.17346728752766336, 0.07147071776645524, 0.055068545043468475, 0.02180488227999636, 0.05111919642825212, 0.039418708200433424, 0.07711021908159767, 0.03340555800657187, 0.0748189352452755, 0.029288957294608866, 0.0853781479277781, 0.06966219802520104, 0.0687886927542942, 0.03811713554231184, 0.03666161007380911, 0.030362735568944896, 0.10291090248418705, 0.015574914702613438, 0.044415898088897975, 0.0705046738897051, 0.04810524904834373, 0.049760921991297176, 0.021047681303960935, 0.06782938673027925, 0.1028572100081614, 0.058504531026950905, 0.04719060080658112, 0.03764977079949208, 0.029642100845064436, 0.03634951789198177, 0.04579121732552137, 0.042600328368800025, 0.053205718751996756, 0.12265026649194104, 0.09824938726212297, 0.012703838808062886, 0.03650447154151542, 0.07777945138514042, 0.1503019527133022, 0.07666401445333447, 0.1497892245118107, 0.057042511978319714, 0.05366662384143897, 0.09818248370928423, 0.011150947805227978, 0.02227397050176348, 0.0651589035987854, 0.10547178185411862, 0.0986717820965818, 0.010046151150683207, 0.02556496881879866, 0.05785030113267047, 0.018871629677180733, 0.0409494628464537, 0.04301457739035998, 0.01837263672080423, 0.05257863025846226, 0.03260397405496665, 0.12819663887577398, 0.02674531441048852, 0.13055745219545706, 0.07939513147409473, 0.09873321665717022, 0.06595564620303256, 0.02927770039864949, 0.0830598719684141, 0.07543384403522525, 0.09580883250704833, 0.14182657535587037, 0.05414190369525126, 0.00209249894500577, 0.06990740022489003, 0.05270917361070003, 0.02937705149607999, 0.03988246313695397, 0.01599388463156564, 0.10418242282633271, 0.04638152922104512, 0.10357077778982264, 0.1446712112852505, 0.04709299015147345, 0.04362062790564128, 0.01253695396839508, 0.08694529240684849, 0.07292230094649962, 0.0806667400257928, 0.056458605453372, 0.08236539137682744, 0.10426694793360573, 0.14504713325628213, 0.029305544083139727, 0.1203297988644668, 0.20970793786857808, 1.228777521422931, 11.559110028403145, 29.010473115103586, 47.28160204206194, 46.638191904340474, 44.61537674495152, 45.00322866439819, 30.0154709815979, 33.19803776059832, 36.11150080817086, 58.55702754429409, 75.93069240025112, 70.46788665226528, 62.6717438016619, 49.515468733651296, 22.653941426958355, 10.958104746682302, 5.268678724765778, 1.7935311198234558, 0.9326936091695512, 2.6707138334001814, 0.526458873280457, 1.4887089793171202, 1.3352503052779605, 0.9065025374293327, 0.20742115271942957, 0.27225332813603537, 2.159101034913744, 0.8404911767159189, 0.26077902955668314, 0.41769885644316673, 0.08898285842899765, 0.12581513023802213, 0.620995140501431, 0.22782391362956592, 0.21615590687308991, 0.21216061125908578, 0.2111537331449134, 0.2758907915226051, 0.02427494991570711, 0.05393806499029909, 0.24151656031608582, 0.3433084567742688, 0.23087569272943906, 0.13032138986246927, 0.1310751744146858, 0.47728440910577774, 0.49994889008147375, 0.6338488193494933, 0.40329982766083305, 0.7104196505887168, 0.31887009527002064, 0.8540325100932802, 0.6652014255523682, 0.2692984981196267, 1.8739324169499534, 5.057705359799521, 7.2646438734872, 12.831045525414602, 27.178380795887538, 51.84780529567173, 66.06216594151088, 68.91119834354946, 81.07018457140241, 62.71090384892055, 40.92021356310163, 30.363363810947963, 38.22351346697126, 53.98422350202288, 68.70113345554897, 65.00806168147496, 44.00588771275112, 8.18520723070417, 0.6425759739109448, 0.2688528634607792, 0.2192671120698963, 0.06671386158892087, 0.22452980253313268, 0.07851370091417006, 0.06256101014358656, 0.06841087088521038, 0.11526312359741755, 0.05227070088897433, 0.04043902809332524, 0.10818966065666505, 0.04139057167672685, 0.05674183275550604, 0.05906905180641583, 0.02351286348753742, 0.16698919156832354, 0.061565483920276165, 0.1172505933791399, 0.14002194362027304, 0.07814849301108293, 0.040585798610533984, 0.10548465366342238, 0.018526462305869375, 0.04719742686886873, 0.061360389925539494, 0.12062923636819635, 0.026126609217109423, 0.04061337088101676, 0.024026356737262437, 0.05288523309198873, 0.04320090989183102, 0.022518843611968414, 0.024056690645271113, 0.04029515492064612, 0.06747707099254642, 0.023777570176337446, 0.052421620647822104, 0.02783448525172259, 0.056463755534163544, 0.030918486283293793, 0.09014291582362992, 0.03507682368425386, 0.10641307277338845, 0.0722161088404911, 0.03668647498956748, 0.15070235622780664, 0.11919688965593066, 0.12434236998004572, 0.12813354868974003, 0.24981384937252316, 0.10621593799442053, 0.12329179421067238, 0.14569920540920325, 0.10576186914529119, 0.10275845602154732, 0.1575852661792721, 0.2643923913793904, 0.21076246271175997, 0.1492245476692915, 0.1431377628552062, 0.15114142266767366, 0.15280078005577835, 0.1594509660665478, 0.18259844183921814, 0.12741412515086786, 0.1591448382075344, 0.1910930760204792, 0.19857662517045224, 0.12213327709053244, 0.27699607078518185, 0.10573611874133348, 0.17204564809799194, 0.13678987776594503, 0.08337247983685561, 0.29018006048032213, 0.16189101870570863, 0.08397748201553311, 0.18036600734506333, 0.10122483795774834, 0.06988571424569402, 0.14260427148214408, 0.13650966994464397, 0.14311982238931314, 0.1465448907443455, 0.1733726318925619, 0.22125995584896632, 0.12830082114253724, 0.14423711172172002, 0.3172784692474774, 0.10819573354508195, 0.2253536797527756, 0.14938773534127645, 0.2803063988685608, 0.2365495211311749, 0.1543608677706548, 0.22321541234850883, 0.18372879975608417, 0.15313242083149298, 0.394845362752676, 0.2190472667238542, 0.1667747473610299, 0.28107984736561775, 0.6752429838691438, 8.736426063946315, 30.37106588908604, 60.17322022574288, 62.593305587768555, 65.53823702675956, 78.5333833694458, 54.76724031993321, 46.18438073566982, 33.967453479766846, 52.86710950306484, 81.03795882633754, 83.42802102225167, 83.62356417519706, 84.45264407566616, 59.348635809762136, 40.7812739099775, 26.11301350593567, 16.79084300994873, 14.312290293829781, 11.679815002850123, 11.469199470111302, 6.100934386253357, 4.314998081752232, 2.056105064494269, 1.8594241440296173, 0.6131692432931491, 5.090120443275996, 1.161479766879763, 1.1010419470923287, 1.5633945145777293, 0.1639196891337633, 0.29882804357579773, 0.8767299950122833, 1.1562320313283374, 0.5193100454551833, 0.9861082115343639, 0.7181936534387725, 0.7824086334024156, 0.11797897358025823, 0.4264095090329647, 0.46679431200027466, 0.6400243022612163, 0.6385013982653618, 0.8720102139881679, 1.1160926137651717, 1.5417285114526749, 1.773068783538682, 1.3518779958997453, 0.5529363953641483, 0.641445263155869, 1.0871298078979765, 0.9982256527457918, 1.431850676025663, 2.8334467240742276, 4.544591316155024, 8.55841669014522, 11.238306488309588, 23.250930649893625, 39.49018396650042, 67.81391102927071, 68.18189457484654, 72.40919944218227, 85.46344716208321, 64.4775458744594, 48.18304395675659, 55.5357597214835, 64.75348663330078, 68.12057672228131, 78.80809429713658, 74.18948078155518, 44.414945534297395, 6.502394352640424, 0.45354065032941954, 0.3650843825723444, 0.6107298827597073, 0.24483019965035574, 0.3009096533060074, 0.1498997714370489, 0.27551360747643877, 0.13823525235056877, 0.20517801094268048, 0.20538106933236122, 0.3346313238143921, 0.19990740876112664, 0.1493127979338169, 0.13834455077137264, 0.2245512713811227, 0.12809339298733644, 0.1629503747182233, 0.13516277793262685, 0.13437528376068386, 0.20998559439820902, 0.23193564585277013, 0.16518066504171916, 0.18957120339785302, 0.08626320865005255, 0.09147247805127076, 0.1773228592106274, 0.22688877023756504, 0.2622709652142865, 0.13661120592483453, 0.14267406559416226, 0.1716747201446976, 0.14114923455885478, 0.1634245485599552, 0.1487104216856616, 0.21682083047926426, 0.1898454672523907, 0.11025617298270975, 0.13665763129081043, 0.10755864344537258, 0.2409879815365587, 0.06948453720126833, 0.17422951305551188, 0.17366201350731508, 0.2604557211909975, 0.27873059628265245, 0.15042495754148277, 0.3584152247224535, 0.1831000963492053, 0.22110079867499216], [0.09705149475485086, 0.1339772144066436, 0.13203523361257144, 0.05563846356900675, 0.04221002145537308, 0.0888994461191552, 0.0379106675141624, 0.03840695141947695, 0.05447609915531107, 0.03720201911138637, 0.05082273090790425, 0.04184804337897471, 0.06518227234482765, 0.01858402582417641, 0.07734410331717559, 0.06518301873334817, 0.01694099568495793, 0.05594731235344495, 0.09220600154783044, 0.04982261439519269, 0.022849753266200423, 0.017175938435164944, 0.08404633296387536, 0.0573410741718752, 0.06867207972598927, 0.024971350761396543, 0.07173232694289514, 0.1382376950766359, 0.02607005162696753, 0.04380905368764486, 0.08861419678266559, 0.0722332214936614, 0.03456382067607982, 0.08171882214290754, 0.0774013309606484, 0.05553982832602092, 0.06323122632290636, 0.13606693941567624, 0.059442544622080665, 0.005542984797752329, 0.037666167598217726, 0.10377669959728207, 0.028147440869361162, 0.02942311384582094, 0.039999021882457395, 0.11136111976312739, 0.036888993943908384, 0.08889409247785807, 0.054066470957228115, 0.01659412688708731, 0.20090683656079428, 0.09318254236131907, 0.1325161928044898, 0.017320744593494704, 0.39966377562710215, 0.17037258430251054, 0.6345172577670642, 5.721719511917659, 14.170927456447057, 21.538463728768484, 17.55593694959368, 53.0243159702846, 53.805522782461985, 48.79245655877249, 24.60300666945321, 33.76681382315499, 32.61419800349644, 45.22378880637032, 52.152525493076865, 69.77932017190116, 67.87005247388566, 64.1922528403146, 59.9284907749721, 59.9493214743478, 48.35492154530117, 39.650888851710725, 30.8825193132673, 19.28421449661255, 14.382096239498683, 7.218135671956198, 5.374069435255868, 4.085095218249729, 5.147704073360988, 7.580626232283456, 6.236670919827052, 4.219633621828897, 2.3577641461576735, 1.960498720407486, 1.4773567084755217, 0.5954105162194797, 0.480181482221399, 0.5149134642311505, 0.7260231333119529, 0.35772409609385897, 0.5241972889219011, 0.4118330569139549, 0.8300853808011327, 0.5743793504578727, 0.42688280077917234, 0.9397452707801546, 0.9481008052825928, 1.8345676149640764, 3.6679688010896956, 5.681254071848733, 7.4947213104793, 7.767905371529715, 7.833268812724522, 9.066068581172399, 13.291554757526942, 22.615856613431657, 29.024921894073486, 35.928752762930735, 42.445259775434224, 41.932618209293906, 38.113471371786936, 41.90601355688912, 33.37339987073626, 41.650674206869944, 40.80395630427769, 53.348095076424734, 66.47193595341274, 61.96180466243199, 59.56696210588728, 34.793764523097444, 9.492509927068438, 0.27315879240632057, 0.13231301227850573, 0.17980477746043885, 0.08039071198020663, 0.05241184635087848, 0.034196431282907724, 0.19415120620812687, 0.09051155032856123, 0.09541300231856958, 0.038354286924004555, 0.05031377536111644, 0.03789200780114957, 0.045372065888451676, 0.07828397609825645, 0.056708991660603454, 0.11161576038492577, 0.0695915896711605, 0.04237929219380021, 0.021555178000458648, 0.13623510753469809, 0.09477971201496464, 0.02081654343887099, 0.09217910441969122, 0.14222311122076853, 0.02873541521174567, 0.11155973374843597, 0.20276550682527678, 0.12075530817466122, 0.06126011602048363, 0.11026670384619917, 0.01835412798183305, 0.023223351254793148, 0.061011236160993576, 0.061405288587723456, 0.07335692976734468, 0.05170477893469589, 0.08047409036329814, 0.12419858840959412, 0.07278780173510313, 0.10783003709678139, 0.018183079481657063, 0.039091793421123705, 0.054109948088548014, 0.06188051415873425, 0.06665547365056616, 0.07522820042712347, 0.10577759758702346, 0.0049941025541297025, 0.03405134353254523, 0.09696635896606104, 0.07881794244583164, 0.07634476372706038, 0.07903189132256166, 0.11207483682249274, 0.011955507132889969, 0.011468744770224606, 0.18550996775073664, 0.04503627587109804, 0.044418011725481064, 0.08804692115102496, 0.0470064667585705, 0.048451858306569714, 0.06125019583851099, 0.05595027415880135, 0.016122616295303618, 0.09230502016310181, 0.057033121053661616, 0.07853962095188242, 0.05178289867139288, 0.11454504355788231, 0.1220978032797575, 0.09164368600717612, 0.052772375755012035, 0.07161956799349614, 0.1525294610432216, 0.06960250729961054, 0.015852561054219092, 0.061098258277135234, 0.10753926448523998, 0.06546186269926173, 0.07209254082824502, 0.14096597582101822, 0.05331698153167963, 0.03865449795765536, 0.12992447401796067, 0.16646904019372805, 0.2112962526402303, 0.04842247774026223, 0.15737322398594447, 0.10173521164272513, 0.007138473380889211, 0.07718941090362412, 0.08560477862400667, 0.09311453958175012, 0.05453488064397659, 0.06480595682348524, 0.10768570591296468, 0.14709009363182954, 0.05804713735623019, 0.11459909565746784, 0.04074000587154712, 0.11555395727711064, 0.17132703880114214, 0.10615862214139529, 0.03424350464982646, 0.3228351010807923, 0.4905658907123974, 2.424699834414891, 14.181050113269261, 21.361656393323624, 21.978282962526592, 34.34190232413155, 61.19938577924456, 53.55591222218105, 34.85124002184187, 27.947721821921213, 46.66059289659773, 55.69627700533186, 68.87713827405656, 84.73424761635917, 80.7721346446446, 58.85813467843192, 46.95438010351998, 36.10588318961007, 28.302609750202723, 19.9169921534402, 19.87519179071699, 12.707027997289385, 8.112318890435354, 4.772166967391968, 2.7993708040033067, 1.821463746683938, 3.006136383329119, 0.8567316681146622, 2.4356434643268585, 1.8602427286761147, 1.2698348611593246, 0.9248546298061098, 0.7054114107574735, 0.22731954497950418, 0.11078199691006116, 0.13722865922110422, 0.10872395948639937, 0.024925720977729986, 0.10037448430167777, 0.020126037366156067, 0.1523244349019868, 0.07415028648184878, 0.15551232812660082, 0.07261077194873776, 0.06892416905611753, 0.43333290038364275, 0.6932790960584367, 1.7022089915616172, 1.6419165411165781, 2.380558363028935, 3.5061704431261336, 4.884640063558306, 8.526322960853577, 17.79116300174168, 26.107769353049143, 40.6330896786281, 54.04847696849278, 68.73471409933907, 67.58998448508126, 67.21530982426235, 56.2082793372018, 52.38848631722586, 61.95475918906075, 36.72945622035435, 39.23938873835972, 65.53640965053013, 70.88677964891706, 70.2199262891497, 46.65451322283064, 17.98110590662275, 1.2447612008878162, 0.5656511102403913, 0.1081437509773033, 0.12109965112592493, 0.06313693709671497, 0.05309398778315101, 0.3096949447478567, 0.11732994126422064, 0.05996734396155391, 0.10913915506431035, 0.02942839284826602, 0.13132866152695247, 0.09300991626722471, 0.08728666337473051, 0.11502164655498096, 0.08030050753482751, 0.0489208617114595, 0.036317090703440566, 0.011124150761004006, 0.09093300878469433, 0.14702097805483, 0.06019673629530838, 0.10158253447817904, 0.13834119880838053, 0.051203236382986815, 0.06543508092207567, 0.08641392484839473, 0.13501639078770364, 0.10625785788787262, 0.10818734685225145, 0.042655723967722485, 0.059901159655834944, 0.031063587604356662, 0.07390139305165835, 0.05756573033119951, 0.08866512762116534, 0.0518572898581624, 0.007825984569665576, 0.0666648985019752, 0.10417063667305879, 0.032350195172641955, 0.04421386428709541, 0.01584053741368864, 0.06992491321372134, 0.028570578699665408, 0.04259696962045772, 0.09695126156189612, 0.03880351781845093, 0.01869838441988187, 0.05371685918154461, 0.026961300588612045, 0.19601693323680333, 0.19882666532482418, 0.35584045574069023, 0.15973521795655998, 0.18427526471870287, 0.27696339253868374, 0.1833651049860886, 0.12520719000271388, 0.13799684228641645, 0.146246145346335, 0.16127170622348785, 0.1773119212261268, 0.11200312924172197, 0.04927496878164155, 0.21779045702091285, 0.09148640837520361, 0.20746398184980663, 0.1688384844788483, 0.29281136499983923, 0.1620724182575941, 0.17419699765741825, 0.11476224261735167, 0.17398141351129326, 0.21596974400537355, 0.16057202805365833, 0.09901117174220936, 0.15970229543745518, 0.3105534815362522, 0.27882401698401993, 0.21910502362464154, 0.32940104018364635, 0.26240623795560425, 0.08308714907616377, 0.25077221223286217, 0.21517014476869786, 0.4100122760449137, 0.17098197660275868, 0.32156029662915636, 0.1683845174099718, 0.06632818906967129, 0.15094908513128757, 0.16631471418908664, 0.20512767721499714, 0.1915415876678058, 0.2608964161149093, 0.17476130809102738, 0.3568827398121357, 0.19584127409117563, 0.26273904581155094, 0.1037909420473235, 0.21465683302709035, 0.22537615283259324, 0.46821364441088265, 0.17298680331025804, 0.3992265005196844, 0.3206343134599072, 0.8525258909378732, 8.705200859478541, 23.515994003840856, 28.3738374710083, 51.34170545850481, 94.5256838117327, 80.0584226335798, 71.82533536638532, 41.83034072603498, 52.10611152648926, 47.9088784626552, 63.115344592503135, 75.47352177756173, 89.67969049726213, 87.44649083273751, 78.05258192334855, 75.75335352761405, 75.30290181296212, 59.555038997105186, 55.11243030003139, 45.63282230922154, 32.24123954772949, 24.10835746356419, 19.62651402609689, 9.09053145136152, 10.408065370150975, 13.792222840445381, 11.335658567292349, 11.2918484381267, 6.26463394505637, 3.4008633281503404, 1.7980213931628635, 1.6416724856410707, 0.6573932788201741, 0.3848643297595637, 0.43390490540436333, 0.7412883256162915, 0.40974306049091475, 1.2664417518036706, 0.901203667478902, 1.5745205347027098, 0.9662893435784748, 0.8488182127475739, 1.2834952367203576, 1.8854299485683441, 3.3466437118394032, 8.756433401788984, 16.849996498652867, 16.95506020954677, 18.292873314448766, 21.8107636315482, 27.115240778241837, 35.238880021231516, 45.08653061730521, 59.594622884477886, 70.73735863821847, 74.65503787994385, 70.42573887961251, 60.89037159511021, 62.723931721278596, 49.90825039999825, 59.3814035143171, 58.5008305140904, 67.24707698822021, 80.27665165492466, 83.59536838531494, 82.83283138275146, 53.324353081839426, 17.062053782599314, 0.8152891919016838, 0.6124508646982056, 0.44845044346792357, 0.2594436454985823, 0.15684821430061544, 0.16969193225460394, 0.425998398235866, 0.2729594116764409, 0.16508548014930316, 0.26044304615684916, 0.10494381375610828, 0.16405697033873626, 0.2839694565960339, 0.17643460258841515, 0.19929147538329872, 0.23686851401414188, 0.22797655686736107, 0.17728254065981933, 0.1287079014416252, 0.1816178908837693, 0.19903433775263174, 0.1876168596957411, 0.1704696962343795, 0.27314169332385063, 0.2158994206360408, 0.22784302117569105, 0.33402957181845394, 0.24619907619697706, 0.14301443233021668, 0.19649245057787212, 0.1874340759324176, 0.14362728515905993, 0.16195427174014704, 0.1751059495976993, 0.132615096068808, 0.12089332219745431, 0.27777350906814846, 0.17380279595298426, 0.2529317449246134, 0.2038870844990015, 0.2702522740832397, 0.1239101838852678, 0.14092272599892958, 0.15612678229808807, 0.21467933324830873, 0.13454748237771647, 0.1717415829854352, 0.17288921640387603, 0.08245182316750288, 0.1417020641799484, 0.28114129549690653], [0.2243433953928096, 0.19899043653692516, 0.19069564448935644, 0.15837182397288935, 0.13005843040134224, 0.15078126985047544, 0.14708922510700567, 0.0737910700429763, 0.09186952960278306, 0.05409759535853352, 0.12538643181324005, 0.06661767246467726, 0.08251027217400925, 0.14145434461534023, 0.07592107289071594, 0.07346472862575736, 0.07083420442151171, 0.07748566607811622, 0.07140040796782289, 0.05826197511383465, 0.012491744028271308, 0.041818577995789905, 0.055456388874777725, 0.03290520628382053, 0.04509447381964751, 0.11715046875178814, 0.08125177970422165, 0.05696877557784319, 0.10489932900028569, 0.3447904315377985, 0.20111123844981194, 0.24958075902291707, 0.22739813290536404, 0.11872936545738152, 0.06909207933183227, 0.03084861413974847, 0.12924387625285558, 0.03951459198391863, 0.06404900351273161, 0.019955830249403204, 0.09289737444903169, 0.14478616868810995, 0.0852182579359838, 0.0825832961127162, 0.1874211701963629, 0.09511885060263531, 0.14799734923456395, 0.10341465366738183, 0.11100363358855247, 0.11056952723967177, 0.06598392754260983, 0.08847430321787085, 0.16628317588141986, 0.2892240860632488, 0.23422925706420625, 0.10848002614719526, 0.11434121163828032, 0.46130599507263725, 0.15226131757455214, 2.360283519540514, 19.947510378701345, 36.67448207310268, 55.009881837027415, 61.20727893284389, 49.83802843093872, 39.2848334312439, 43.87765175955636, 39.596102305821006, 39.72658600125994, 33.36301231384277, 58.934127126421245, 51.73444196156093, 58.63992650168282, 62.19238758087158, 64.53768253326416, 54.10089765276228, 36.245948450905935, 31.693568638392858, 27.876169272831508, 13.966263924326215, 15.268131392342703, 14.228178007262093, 21.605597223554337, 31.939816270555767, 27.132220438548497, 21.39334191594805, 23.848244701113018, 28.207190138953074, 30.151867594037736, 29.278885500771658, 24.5732319014413, 19.496207509722026, 17.761410815375193, 11.553180609430585, 6.868235681738172, 4.406272658279963, 3.721291882651193, 3.700841162885938, 2.6104390791484287, 2.6384828771863664, 5.508297341210501, 15.087014436721802, 22.12776129586356, 23.249646970203944, 26.329484633037023, 16.13070855821882, 20.391712188720703, 28.79806842122759, 30.679562432425364, 43.91599539348057, 57.012178965977256, 39.710136141095845, 45.54566410609654, 34.92950800486973, 40.85196140834263, 45.35444968087332, 44.19367667606899, 54.29730238233294, 68.34344019208635, 70.74660669054303, 58.92327404022217, 38.130904402051655, 13.203974451337542, 0.8092491988624845, 0.08452042538140501, 0.15080185660294124, 0.06079491919704846, 0.2174318376928568, 0.1354467584086316, 0.06798990097429071, 0.22340225375124387, 0.2028122850294624, 0.12771971018186637, 0.107497385303889, 0.13239060954323836, 0.03564723754035575, 0.06353682492460523, 0.11393284212265696, 0.07499314911131348, 0.11301415999020849, 0.13816822666142667, 0.1299417359488351, 0.06570719382060425, 0.11140590307435819, 0.018351139035075903, 0.14694583708686487, 0.06651533581316471, 0.10121711622923613, 0.12418299567486558, 0.13512577063270978, 0.09215623778956276, 0.08734542450734548, 0.08263385375695569, 0.06449789513966867, 0.05580752735425319, 0.11399327245141778, 0.14667759862329277, 0.19831355714372226, 0.28928257578185623, 0.20238883846572467, 0.12300934722380978, 0.17494014278054237, 0.17413374462297984, 0.2279909960925579, 0.2167025346841131, 0.19777926509933813, 0.2504483610391617, 0.140558121992009, 0.10631206605051245, 0.06051308289170265, 0.11985652068895952, 0.036854252950953584, 0.06850830851388828, 0.0572707915146436, 0.11689223189439092, 0.27156594502074377, 0.15175711177289486, 0.29726326039859224, 0.18849352693983487, 0.2581494078040123, 0.1983176554952349, 0.20578065860484326, 0.1899441262441022, 0.10963951357241188, 0.12515106158597128, 0.09880452390227999, 0.05116289069077798, 0.05589121447077819, 0.04101879894733429, 0.0447726819797286, 0.11238585013364043, 0.06458104960620403, 0.1044364527666143, 0.17726455948182515, 0.3019963135676724, 0.1433791449027402, 0.11704117033098425, 0.0763772384130529, 0.14652122344289506, 0.11824031812804085, 0.0704771185825978, 0.1160765920898744, 0.04926007493798222, 0.10783722956797906, 0.25257692539266174, 0.28216227356876644, 0.2928237686199801, 0.3401221920336996, 0.3252631707915238, 0.4416946502668517, 0.2939911202660629, 0.1360845813261611, 0.09136746797178473, 0.27141970715352465, 0.05458391497709921, 0.1384888615991388, 0.10271707895611014, 0.23031964685235704, 0.09487199956285101, 0.10719925737274544, 0.18947052237178597, 0.07741835540426628, 0.1925755121878215, 0.4145300979060786, 0.10373771776046072, 0.20965654562626565, 0.13182742547776016, 0.07376373186707497, 0.11822183483413287, 0.20569573316190923, 0.2244609176580395, 0.13366284913250379, 0.3324311061629227, 0.8956903261797768, 1.2015629474605833, 9.102769834654671, 24.38901604924883, 54.37923206601824, 62.85480798993792, 64.56128556387765, 41.0128504208156, 36.7605494090489, 30.428110599517822, 38.941856452396934, 48.80018642970494, 58.418681962149485, 84.8153817313058, 74.53552886417934, 76.79726478031704, 76.66984871455601, 64.00351892198834, 55.97343717302595, 45.62434550694057, 34.898307119097026, 29.667043140956334, 18.724914039884293, 17.560521023614065, 18.84128246988569, 24.87973952293396, 29.849127633231028, 23.343430280685425, 20.918502024241857, 14.993580273219518, 14.136262893676758, 14.055060165269033, 13.55347318308694, 12.137835911342076, 9.864136065755572, 8.692703655787877, 6.710957995482853, 5.460840276309422, 4.957953546728406, 6.805594197341374, 5.768962485449655, 1.1611593897853578, 4.015975407191685, 5.2307111620903015, 13.645365715026855, 23.395654678344727, 29.346109322139196, 33.712392057691304, 32.43890537534441, 29.429894174848283, 44.740819522312705, 56.96050868715559, 70.25905159541539, 81.92026887621198, 70.12974561963762, 65.33584295000348, 49.47397756576538, 38.348584515707834, 42.78796577453613, 28.312846183776855, 42.73926932471139, 69.37606757027763, 82.99794837406704, 72.97663797651018, 53.54231112343924, 24.232111828667776, 3.751243395464761, 0.11099406624478952, 0.14953230401234968, 0.30014426580497194, 0.016968790175659314, 0.10157199004398924, 0.36802751464503153, 0.3522777940545763, 0.04018319324989404, 0.13026769060109342, 0.31403265627367155, 0.21648804976471833, 0.1915039832570723, 0.12692771053739957, 0.13850254086511476, 0.10220709203609399, 0.02289850091827767, 0.06237712036818266, 0.19334271816270693, 0.16204177561615193, 0.12409351047660623, 0.08016638151769127, 0.09006392756210906, 0.15468686313501426, 0.055720016692898104, 0.1412499291556222, 0.18051213664667948, 0.1334828609334571, 0.1378860103764704, 0.0814234558492899, 0.17175275167184217, 0.16626856023711817, 0.2241142134049109, 0.2094350853668792, 0.22675584522741182, 0.32980381857071606, 0.242109762770789, 0.19239551041807446, 0.20506712474993297, 0.09620160250259296, 0.17071291032646382, 0.31221380244408337, 0.2532975567238671, 0.18032050478671277, 0.16676607568349155, 0.08915304858237505, 0.018786678789183497, 0.21609782427549362, 0.12081666131104742, 0.07022764161229134, 0.13645088167062827, 0.10280116301562105, 0.18269982854170458, 0.4703202513711793, 0.5750277042388916, 0.5097332022019795, 0.45819184503384996, 0.2782052473298141, 0.2613870512161936, 0.3742186852863857, 0.20221227008317197, 0.29688699916005135, 0.15356228633650712, 0.23505563129271778, 0.2653901906950133, 0.19146052987447806, 0.26515406050852364, 0.35577176085540224, 0.42668830550142695, 0.2809573582240513, 0.23352271211998804, 0.37207980720060213, 0.21240773371287755, 0.2658170163631439, 0.2714685888162681, 0.27317396444933756, 0.2940747972045626, 0.16317878317620071, 0.32338946419102804, 0.44327408980046, 0.4701724393027169, 0.5994113758206367, 1.0366097816399165, 0.5072024294308254, 0.5680186003446579, 0.7491610145994595, 0.7516957500151226, 0.5685311385563442, 0.39190144357936724, 0.516292681651456, 0.3500672626708235, 0.18423120065459184, 0.27751067174332483, 0.3310570998915604, 0.48032636301858084, 0.5362137641225542, 0.3171245503638472, 0.4748182328683989, 0.333920599094459, 0.28780920484236305, 0.5378856744085039, 0.3301572267498289, 0.4171100508953844, 0.25638236690844807, 0.2128816768527031, 0.41375352814793587, 0.5069020284073693, 0.5989605028714452, 0.26982295140624046, 0.5350117800491196, 0.9739957643406731, 0.34320100396871567, 5.129196243626731, 29.678761277879985, 68.40361159188407, 84.37207971300397, 88.33770152500698, 76.980516569955, 60.21627126421247, 65.24323041098458, 56.27905716214861, 57.81327152252197, 49.81827122824532, 80.22440814971924, 70.17912646702358, 77.14647429330009, 81.43616703578404, 83.1703679221017, 78.3768890925816, 69.22141456604004, 64.52869156428746, 63.30051408495222, 50.62389748437064, 55.416379247392925, 51.375376428876606, 59.04469381059919, 63.34727546146938, 56.31294700077602, 55.13819074630737, 51.71976389203753, 52.05972882679531, 52.13056571143014, 47.597463675907676, 40.75264038358416, 32.89626012529646, 33.43972737448556, 29.15945291519165, 27.6939023903438, 24.99478084700448, 24.58782138143267, 27.435604844774517, 31.13664272853306, 37.8924491746085, 42.17359563282558, 53.655215876443044, 55.64372777938843, 55.96780913216727, 59.07264641353062, 50.56319454738072, 55.0211900302342, 63.236159869602744, 63.93018763405936, 70.96605859483991, 80.75530610765729, 57.21437154497419, 65.52299267905099, 53.081777572631836, 59.78698376246861, 65.29306289127895, 60.21972451891218, 68.56871468680245, 85.56477274213518, 94.32194873264858, 89.93632916041783, 63.60369178227016, 24.66126036643982, 2.9881435888154164, 0.26559646534068243, 0.5865731132881982, 0.4002446016030652, 0.2518251085919993, 0.2895616708057267, 0.7203937896660396, 0.39422933437994545, 0.28322955487029894, 0.4383413573460919, 0.4989025890827179, 0.3260800183883735, 0.3062264365809304, 0.2958057943199362, 0.24282040606651986, 0.22876762013350213, 0.19476325836564812, 0.2273517075393881, 0.423755622868027, 0.37162103610379355, 0.40905421173998285, 0.45502897618072374, 0.583130552300385, 0.567890927195549, 0.40667700501424925, 0.4191073865762779, 0.4937670017991747, 0.28191162273287773, 0.44810116078172413, 0.4124638502086912, 0.24854477175644465, 0.3693325546170984, 0.41451823711395264, 0.5931677137102399, 0.6943369050111089, 0.6668712188090596, 0.5637482266340936, 0.4443666126046862, 0.40013603600008146, 0.3432484742786203, 0.46565714159182137, 0.429959522826331, 0.3635158267404352, 0.2832156041903155, 0.3681270693029676, 0.31197273252265795, 0.3803281603114945, 0.44256263226270676, 0.47815733083656853, 0.22591617171253475, 0.3355064982814448, 0.41466933329190525, 0.5365519459758485], [0.07567605389548199, 0.1994816687490259, 0.10451997364205973, 0.03693890358720507, 0.14996708211089882, 0.16147803515195847, 0.15160769836178847, 0.039134900750858445, 0.0627257584461144, 0.017763690557330847, 0.05727497807570866, 0.08797774450587374, 0.1569188090839556, 0.1102244718266385, 0.10035605529057127, 0.052005291916429996, 0.05876289680600166, 0.04259125974827579, 0.07014068734965154, 0.04827416355588606, 0.06160012313297816, 0.1343515757471323, 0.02956616599112749, 0.0920362388715148, 0.09270817174443177, 0.13791245967149734, 0.1661650836467743, 0.18842876755765506, 0.2595079706183502, 0.23618609777518682, 0.15456487610936165, 0.2809504100254604, 0.10948574396648578, 0.08119170221367053, 0.0767051608168653, 0.03446910736550178, 0.12523927113839559, 0.19484674531434262, 0.1586132738739252, 0.09913559470857893, 0.2237342745065689, 0.19794450194707938, 0.3265101010245936, 0.07225213226463113, 0.1008260425712381, 0.16632008818643435, 0.03198848511757595, 0.09753706798489604, 0.12125709839165211, 0.09491828922182322, 0.023399032452808957, 0.22075699855174336, 0.1526647609259401, 0.026634614814871123, 0.1523623378681285, 0.12033057239438806, 0.029850869106927087, 0.02435088816231915, 0.027115670698029653, 0.10030421521514654, 1.0459936495338167, 8.186605555670601, 38.25026750564575, 66.41871275220598, 76.29928738730294, 72.90453651973179, 70.89269256591797, 65.36678327832902, 55.92808975492205, 51.80675186429705, 41.4238189969744, 46.91491086142403, 37.69724300929478, 41.72754212788173, 47.64097329548427, 45.65405600411551, 39.86829451152256, 29.760253225054058, 23.812346833092825, 22.13029044015067, 10.885452645165579, 10.399822201047625, 11.026514104434423, 13.846789649554662, 21.250280244009836, 15.274429934365408, 29.873547077178955, 36.34300783702305, 31.96787657056536, 43.76414251327515, 37.370490074157715, 32.17137541089739, 27.560597726276942, 46.39954907553536, 32.132448128291536, 28.557339395795548, 11.526521239961896, 8.673603057861328, 12.523601634161812, 5.029448773179736, 16.243535143988474, 15.90162123952593, 16.199405397687638, 13.359334434781756, 18.89527518408639, 23.274408612932476, 24.558517353875295, 18.971618516104563, 26.865171636853898, 26.415267092841013, 34.267170974186485, 34.46593114307949, 44.33105993270874, 42.619986125401084, 59.60897091456822, 67.88207980564663, 86.54676859719413, 63.98824678148542, 48.61000033787319, 33.2048157283238, 17.789398159299576, 3.511098235845566, 0.06950180591749293, 0.14843979477882385, 0.1926199019487415, 0.09738023818603583, 0.14973916219813482, 0.1639121709657567, 0.05244533205404878, 0.10990520074431386, 0.0911309238789337, 0.14563384891620704, 0.16422494846795285, 0.1114803926487054, 0.0444108633590596, 0.08174509501882962, 0.021669136260503104, 0.13460666420204298, 0.022160770504602363, 0.06681152991950512, 0.12043030347142901, 0.07078171295246907, 0.10941234683351857, 0.06727665888943843, 0.10098947451582976, 0.13860525749623775, 0.09394068310835532, 0.20206299237906933, 0.12981284143669264, 0.063053687635277, 0.03973910225821393, 0.11815091435398374, 0.1554107650050095, 0.1775834709405899, 0.20213412999042443, 0.15310521157724516, 0.21694483953927243, 0.2742155428443636, 0.26137969589659144, 0.3013984156506402, 0.25571067152278765, 0.05905463293726955, 0.14049469253846578, 0.15981745640082018, 0.18065606749483518, 0.14919614419341087, 0.29117145442536896, 0.24363776934998377, 0.10344913003167935, 0.10013945334191833, 0.12674491320337566, 0.06509378459304571, 0.035337465948292186, 0.12662032060325146, 0.11228305207831518, 0.06618611740746669, 0.25413739308714867, 0.37513644461120876, 0.18698107238326753, 0.2026257286114352, 0.19716310101960385, 0.28789369602288517, 0.18264466364468845, 0.16790159046649933, 0.07021105143108539, 0.1350252388843468, 0.1226095679615225, 0.1894923983407872, 0.1428445814443486, 0.2328758511160101, 0.09454201441258192, 0.22008904867938586, 0.13407743402889796, 0.04332023366753544, 0.08091425602989537, 0.029586213308253458, 0.10129985000405993, 0.12542444334498473, 0.16185967038784707, 0.20149679561810835, 0.2880505190363952, 0.30714509157197817, 0.35737801609294756, 0.5102563798427582, 0.39768315904906815, 0.4920218640140125, 0.5512895094496864, 0.5128103856529508, 0.391052704836641, 0.3349505881113665, 0.1934085903423173, 0.22144002547221525, 0.28769360961658613, 0.23034654398049625, 0.22726770490407944, 0.1893364167107003, 0.3571387917867729, 0.35045223629900385, 0.48248475577150074, 0.40884584720645634, 0.3596550167671272, 0.3410972197140966, 0.18282970014427388, 0.2392009917114462, 0.18329263744609697, 0.20359858497977257, 0.20313324566398347, 0.3755390058670725, 0.21683079137333802, 0.11558587556438786, 0.2743883250015122, 0.3826099107308047, 0.21040457620152406, 0.17240983141320093, 0.1058916389676077, 0.15389601700007915, 3.6163206696510315, 19.797986882073538, 56.11991562162127, 80.17084448678153, 78.03235571725028, 66.6007833480835, 60.041329520089285, 53.049173150743755, 42.9286390032087, 37.49530751364571, 49.540086201259065, 52.6691449029105, 55.632947649274556, 67.75334358215332, 68.78535257066999, 68.76158278329032, 54.227299281529014, 53.213174956185476, 49.06067786897932, 45.07122720990862, 46.14372682571411, 53.01883731569563, 58.85850293295724, 63.59579862867083, 57.64679963248116, 55.190680912562776, 64.30473027910504, 74.0382810320173, 81.23981094360352, 82.76913029806954, 78.081604548863, 78.0231215613229, 75.51826817648751, 75.57465280805314, 65.05339867728097, 49.35099792480469, 32.706188678741455, 29.82513897759574, 33.783326217106406, 33.59900440488543, 42.385998589651926, 45.603757994515554, 50.126243182591026, 53.61232117244175, 51.68255628858294, 59.1944830758231, 56.3280280658177, 54.03927755355835, 47.32745667866298, 47.48235286985125, 46.82159308024815, 31.064079216548375, 39.550379684993196, 40.34291900907244, 58.4963767187936, 67.63951124463762, 96.92830835069928, 87.47451291765485, 70.32545552934918, 51.16843475614275, 31.079639707292827, 8.291493824550084, 0.22806452214717865, 0.16678280835705145, 0.3738253249653748, 0.03917220660618373, 0.1382808091917208, 0.22869289985724858, 0.3032702494944845, 0.23509091511368752, 0.13984779082238674, 0.2682079294962542, 0.329463139708553, 0.24596563300916127, 0.12996627177510942, 0.24641680451376097, 0.09644965454936028, 0.245823900614466, 0.09801052257950817, 0.08958939409681729, 0.24491992912122182, 0.1637717549289976, 0.238945156868015, 0.24564324745110103, 0.2941905009959425, 0.3681831977197102, 0.31883725417511805, 0.3518814481794834, 0.31198282912373543, 0.26241869585854666, 0.2661719173192978, 0.2124750850988286, 0.29416737652250696, 0.3967285417020321, 0.3058877933238234, 0.21748472271221025, 0.437606259648289, 0.40141450454081806, 0.44529208008732113, 0.42837658205202644, 0.4825327417680195, 0.41349161363073755, 0.40794784682137625, 0.41463882635746685, 0.48613359140498297, 0.23756952211260796, 0.3060731148081166, 0.23038893884846143, 0.18569968614195073, 0.17213081781353268, 0.2653464116156101, 0.15724267384835652, 0.12921954398708685, 0.16356473389480794, 0.1495313269219228, 0.08612077057893787, 0.25354115079556194, 0.3819154437099184, 0.25700876329626354, 0.16171139691557201, 0.1781207892511572, 0.4670941159129143, 0.25650572457483833, 0.2380130397421973, 0.21404303024922097, 0.17498899730188505, 0.21966499143413135, 0.2636759669653007, 0.3334563454346997, 0.2792384661734104, 0.17575582329716, 0.19020975913320268, 0.15998394175299577, 0.14215922036341258, 0.11233066488057375, 0.18159646274788038, 0.1340072870786701, 0.3331961679671492, 0.25452532512801035, 0.3491419037537915, 0.35654097529394285, 0.3485271781682968, 0.35740040774856296, 0.50596548723323, 0.49499569301094326, 0.43431191784994944, 0.6163040207965034, 0.5341153538652829, 0.3345773938511099, 0.46976260415145327, 0.3609403520822525, 0.2893599016325814, 0.33211857293333324, 0.34270895751459257, 0.2515127110694136, 0.39034993254712647, 0.38578493893146515, 0.36067974035229, 0.4949427672794887, 0.46514107499803814, 0.30221330906663624, 0.43886909474219593, 0.2607384803039687, 0.2603970957653863, 0.25377166271209717, 0.39723728011761394, 0.2030981925449201, 0.4087068018104349, 0.3380038599882807, 0.23512177488633565, 0.3243384632681097, 0.5138736771685737, 0.42821769629205975, 0.3076306240899222, 0.2434938656432288, 0.2594250264976706, 1.1963684090546198, 14.92300568308149, 59.41390718732561, 91.77555901663644, 103.36868395124162, 95.25881603785923, 93.1840353012085, 89.19030802590507, 76.24993433271135, 69.97746195111955, 58.95845276968819, 66.33778708321708, 56.53866965430123, 65.49896580832345, 73.20734596252441, 76.78723852975028, 72.07754107883999, 66.14518996647426, 62.55999592372349, 69.77283750261579, 51.82722473144531, 55.94313955307007, 52.523555823734824, 51.233695711408345, 56.0597824369158, 54.58701794488089, 73.28417219434465, 76.02989877973283, 62.41644614083426, 79.14706216539655, 69.7938905443464, 61.4911892754691, 53.99077565329415, 81.88325582231793, 64.57805851527623, 75.28664997645787, 54.72271278926304, 50.17074639456612, 46.0877035004752, 40.49924305507115, 52.97837448120117, 44.93214511871338, 38.5501309122358, 42.38680110658918, 50.192615849631174, 68.40625190734863, 56.51168285097395, 45.25567408970424, 49.11500930786133, 48.3485882622855, 55.43291596003941, 53.75559997558594, 61.8496537889753, 59.31237316131592, 77.07004410879952, 82.34579740251813, 114.76262487683977, 102.32292447771344, 83.42973722730363, 62.49334185464041, 29.395990439823695, 5.905656567641667, 0.22878870900188172, 0.2747384490711348, 0.3552974377359663, 0.15023248429809297, 0.21608607204897062, 0.24551687708922795, 0.31830625981092453, 0.2554255239665508, 0.15182363534612314, 0.4166570066341332, 0.4159707634576729, 0.20313752043460095, 0.2007569210337741, 0.28502997968878063, 0.15074734309954302, 0.4279756492802075, 0.18273106829396316, 0.24036315934998648, 0.3199381093893732, 0.23767754488757678, 0.24468312039971352, 0.22962593979069165, 0.31712275903139797, 0.3736725188791752, 0.3492827133408615, 0.4412470885685512, 0.3650122135877609, 0.36128255086285727, 0.3370354548096657, 0.2691175735422543, 0.2990276685782841, 0.43382244982889717, 0.28122573239462717, 0.30173505044409205, 0.3584095521696976, 0.553455284663609, 0.4585160219243595, 0.43995293229818344, 0.4241446405649185, 0.31533883618456976, 0.30145617255142754, 0.40077969431877136, 0.37842552097780363, 0.3037239451493536, 0.39037180851612774, 0.35725642261760576, 0.19759433716535568, 0.2940521884177412, 0.3518585408372538, 0.2380654497870377, 0.20379393521164144, 0.23886229417153768, 0.14278215622263296, 0.15729930438101292], [0.16372100050960267, 0.23190766306860106, 0.08923199613179479, 0.141847447093044, 0.21183456161192485, 0.1339611874095031, 0.081968407678817, 0.13062624207564763, 0.04240629110219223, 0.029760026838630438, 0.048149805050343275, 0.051145771252257485, 0.27274046199662344, 0.18704798950680665, 0.13428703349615845, 0.049501158430108, 0.03747523123664515, 0.01752953490774546, 0.0232313834130764, 0.05196511585797582, 0.024935347693307058, 0.04196240706369281, 0.1705050343381507, 0.11999164415257317, 0.12491596277270998, 0.18850890254335745, 0.3368504861635821, 0.13093291276267596, 0.1292519915316786, 0.1784023812838963, 0.2845782110733645, 0.19641121636543954, 0.18152729288807937, 0.20976367273500987, 0.13912496103772096, 0.07465184599693332, 0.17473617515393666, 0.2338042770113264, 0.22194268421403, 0.2541673571935722, 0.22435071000031062, 0.08769370296171733, 0.08617326204798051, 0.14180374943784305, 0.14447674314890588, 0.12028439130101885, 0.14323382984314645, 0.08095420817179338, 0.09477486048958131, 0.1784148256161383, 0.10686589990343366, 0.08828115143946239, 0.17459649193499768, 0.1595699946795191, 0.06852092247988496, 0.021405712002888322, 0.1290190097476755, 0.16808225720056466, 0.1209837980568409, 0.09749795044107096, 0.044158709568104575, 0.06409536781055586, 0.5053368381091526, 8.196714316095624, 33.94228710447039, 55.21781015396118, 71.40056419372559, 79.83894293648856, 73.88535118103027, 69.04725796835763, 70.30896745409284, 61.168751171657014, 62.449060985020225, 54.9607059614999, 49.16629048756191, 46.12481382914952, 38.654513699667795, 41.90782356262207, 34.628049986703054, 35.09078959056309, 24.08348117555891, 29.468404565538677, 34.52235746383667, 32.776580878666465, 25.779593774250575, 26.400799206324987, 32.47235400336129, 33.88251870019095, 41.7576938356672, 30.99464586802891, 42.382215295519146, 35.382641724177766, 27.301944085529872, 29.820584433419363, 30.369189875466482, 29.614184720175608, 76.425445829119, 45.44891391481672, 25.876833813531057, 22.72902192388262, 17.05301938738142, 18.393629142216273, 18.60069588252476, 25.369109834943497, 28.861604486192974, 22.896553414208547, 27.341769422803605, 38.63530887876238, 38.60248906271798, 53.67474726268223, 61.57777772630964, 74.42938123430524, 68.31641864776611, 81.60561970302037, 70.54388604845319, 38.94219691412789, 17.937323570251465, 12.334707038743154, 15.873451505388532, 2.3532115561621527, 0.031775594755475006, 0.46286993686641964, 0.31123207083770205, 0.05842693376221827, 0.059633321527923853, 0.1361987516283989, 0.21133005725485937, 0.12707370413201197, 0.09824321937880345, 0.041033027826675346, 0.1716542419578348, 0.054119203306202374, 0.1272026122148548, 0.009114591271749564, 0.12842010759881564, 0.058326463082007, 0.07950703546937023, 0.08194942226899521, 0.05056019892383899, 0.09620385523885489, 0.1116635903183903, 0.02518803922326437, 0.0856374500851546, 0.05043892775263105, 0.17228456027805805, 0.20511566714516707, 0.09950868718858276, 0.13611272695873464, 0.09712705641452755, 0.13056488893926144, 0.20482620410621166, 0.17517757575426782, 0.08727473472910267, 0.11726960593036242, 0.1607703095568078, 0.20365854033402034, 0.14366582594811916, 0.19420529901981354, 0.15330729287649902, 0.19108588354928152, 0.21157110003488405, 0.17269823593752726, 0.2402448771255357, 0.11875582832310881, 0.1534310169517994, 0.09889324914131846, 0.18871417295719894, 0.10171767151249306, 0.07906195720923798, 0.15576201544276305, 0.038391083878065856, 0.07028507281626974, 0.0722078171425632, 0.11742266985986914, 0.05565957957878709, 0.1395347961889846, 0.17824331910482474, 0.21935357100197247, 0.16847844022725308, 0.09662644006311893, 0.1583482109542404, 0.14128145389258862, 0.07392264476844243, 0.13039229677191802, 0.107892788015306, 0.019408802102719034, 0.07388656706150089, 0.0634541047204818, 0.21565043899629796, 0.3222445042005607, 0.12078367093844072, 0.1211074949907405, 0.10839054094893591, 0.031062627477305274, 0.03279859825436558, 0.02496332029945084, 0.054569027918790064, 0.04807963774406484, 0.12427018742476191, 0.18862638409648622, 0.18610051034816674, 0.2770815390561308, 0.3658685790640967, 0.2869661657937935, 0.2402813280267375, 0.24192845821380615, 0.30894749771271435, 0.19574698486498424, 0.2681781825210367, 0.20126253818827017, 0.13328471513731138, 0.09310070425271988, 0.2083628914718117, 0.18988651862101896, 0.24727243717227662, 0.23332941106387547, 0.19611050321587495, 0.20126514376274177, 0.22334054777664797, 0.27359321766666, 0.15960260507251534, 0.16062945925763675, 0.1452389279646533, 0.09298563828425747, 0.15355783514678478, 0.1556774564087391, 0.12436732649803162, 0.04925075525950108, 0.19972016023738043, 0.1764528958925179, 0.03193059590245996, 0.06689972590122904, 0.29571622769747463, 0.23943025512354715, 0.06822749001107045, 0.08542627641665083, 0.046984037783529074, 0.11662490266774382, 3.8191264271736145, 23.531306096485682, 60.36473342350551, 78.16853346143449, 82.87789739881242, 81.50544752393449, 70.86856842041016, 63.711159569876536, 53.69739491598946, 52.23936060496739, 43.79109804970877, 43.37589802060808, 53.00820309775216, 51.20879684175764, 40.37635721479143, 46.79154906954084, 44.252128396715435, 47.16852705819266, 36.11048984527588, 41.76636866160801, 38.55634607587542, 37.324604170663015, 39.10722705296108, 35.68614598682949, 52.68855469567435, 51.570214339665, 49.43726328441075, 45.73741354261126, 50.312729358673096, 44.4760479927063, 37.70507362910679, 62.92782660893032, 58.09043516431536, 54.24059465953282, 73.45227691105434, 45.21587480817522, 41.05044712339129, 34.29234429768154, 33.178148542131694, 22.96128283228193, 21.863351072583878, 25.487038135528564, 31.46085957118443, 30.910398960113525, 32.872598034994944, 30.235975537981304, 27.028572423117502, 37.77392332894461, 46.829239572797505, 56.93628379276821, 65.80652781895229, 76.79403386797223, 79.96599074772426, 67.93416350228446, 33.85744265147618, 22.39417086328779, 25.163312877927506, 6.136433167116983, 0.11415033973753452, 0.29885955474206377, 0.39856172619121416, 0.12165900825389794, 0.0056203628108570615, 0.09959769741232906, 0.3481733628681728, 0.11102023055510861, 0.08761877233960799, 0.05438400838258011, 0.25047962793282097, 0.034207657644791264, 0.08552905411592551, 0.1431935927165406, 0.09891594613769225, 0.024656417214178612, 0.13607075278248104, 0.10064971167594194, 0.05100785900971719, 0.13070054166018963, 0.1183785085699388, 0.10108898167631455, 0.12364696658083371, 0.1583006999322346, 0.10282706269728285, 0.23850212778363908, 0.2417381155703749, 0.2430265178637845, 0.17353903582053526, 0.2365631732557501, 0.31150961880173, 0.13170342998845236, 0.08768368099949189, 0.1640998808933156, 0.1460189311099904, 0.30840450684939114, 0.27057471392410143, 0.1994486783764192, 0.16534416483981268, 0.17410543614200183, 0.28974995070270126, 0.16132897457906178, 0.16646145417221955, 0.22214019218725817, 0.10491081659815141, 0.07834953615175826, 0.19045419458832058, 0.10416747469987188, 0.06678230541625194, 0.10242214692490441, 0.09844458143093757, 0.07575584282832486, 0.12557921718273843, 0.10036726468907935, 0.09556272107043437, 0.15832720351006302, 0.23214694165757724, 0.365099907453571, 0.2572923909340586, 0.23273428156971931, 0.24097981197493418, 0.16030684299767017, 0.20053194596299104, 0.28078734448977877, 0.19565368629992008, 0.10798177788300173, 0.17408615217677184, 0.20435350947082043, 0.36507355315344675, 0.3966867168034826, 0.2761702393846852, 0.15594710622514996, 0.28225745846118244, 0.08933965928320374, 0.1603159625083208, 0.12682093626686505, 0.12995204968111856, 0.16225936822593212, 0.32161680502550943, 0.40676877009017126, 0.2711157777479717, 0.3301808940512793, 0.7118358888796398, 0.29070095824343817, 0.3169559751238142, 0.4149240010551044, 0.5633959312524114, 0.3141193187662533, 0.41189928193177494, 0.44319399552685873, 0.2611666630421366, 0.22773336991667747, 0.33156874243702206, 0.2573390741433416, 0.27381537003176554, 0.3586350157856941, 0.24224025862557547, 0.2725949840886252, 0.20360235763447626, 0.3059227785893849, 0.2659001776150295, 0.46650471325431553, 0.2533816136419773, 0.18132065183350018, 0.1669817819659199, 0.35247302215014187, 0.4034406915307045, 0.2611550193812166, 0.4063787210200514, 0.5190962797829083, 0.21368361024984292, 0.25854673076953205, 0.2985341836299215, 0.5659689903259277, 0.40767833271196907, 0.26990293711423874, 0.16291403238262447, 0.2501465215214661, 1.4170365738017219, 15.421420812606812, 53.77589566367013, 81.15525136675153, 96.3984317779541, 103.83902141026088, 95.45116301945278, 90.23294775826591, 91.59116077423096, 80.91621943882534, 78.87076010022844, 75.65406376974923, 75.591064453125, 76.56575080326625, 69.2405846459525, 86.28896958487374, 73.53633621760777, 80.11143738882882, 64.05545670645577, 76.99733815874372, 76.16045543125698, 68.19940403529576, 65.1872626713344, 62.536830629621235, 77.91507012503487, 62.47371319362095, 77.73948219844273, 59.292174748011995, 69.07168088640485, 63.414971760341096, 49.49928985323225, 58.45491681780134, 63.09406920841762, 61.21299730028425, 136.77455275399345, 79.49684837886265, 58.65927028656006, 63.647951807294575, 49.82364913395473, 42.44162586757115, 46.87323209217617, 65.31151035853794, 67.85169533320835, 51.77740267344883, 56.29552786690848, 64.35324954986572, 59.069846289498464, 73.57777527400425, 76.13471930367606, 84.76970427376884, 85.1517231804984, 96.2155829838344, 93.66075815473283, 84.93249361855644, 49.69473573139736, 27.361217430659703, 22.10284505571638, 3.6463242939540317, 0.11588478381080286, 0.7106594720057079, 0.39605999471885817, 0.20074811364923204, 0.20145335580621446, 0.3227556310594082, 0.41763206145593096, 0.20766425824591092, 0.19473243930510112, 0.272937074303627, 0.28672078038964954, 0.08288515598646232, 0.3420143819281033, 0.23966809521828378, 0.2598215623625687, 0.13459044721509728, 0.33660005245889935, 0.16390374356082507, 0.17128430466566766, 0.241727313292878, 0.2336755453475884, 0.31624907734138624, 0.19292471344981874, 0.23554724348442896, 0.2753249747412545, 0.37997106090188026, 0.3356938825121948, 0.27372026656355175, 0.295680075351681, 0.21768703471337045, 0.6421767781887735, 0.26037649544222013, 0.16369497190628732, 0.2868034259549209, 0.32755355217627113, 0.3710449870143618, 0.420147037931851, 0.2701841491673674, 0.1465297865548304, 0.3236757516860962, 0.2793867667870862, 0.2746271421866757, 0.3292717385504927, 0.3163490119789328, 0.18695811075823648, 0.2733606972864696, 0.316317365105663, 0.15571777495954717, 0.3241410367190838, 0.27787659210818155, 0.24798289047820227, 0.21418937668204308, 0.18590000325015613, 0.4093076309987477, 0.250917201595647, 0.4128575905093125], [0.17332946349467548, 0.2007270519222532, 0.16284335617508205, 0.27422455378941124, 0.2138057601239, 0.06832951453647443, 0.13175058817224844, 0.03633274111364569, 0.11027979957205908, 0.13590349390038423, 0.1475583913602999, 0.14012571876602514, 0.06347064061888627, 0.1760734591100897, 0.061938793531485965, 0.14839647710323334, 0.055915244788463624, 0.05536005047283002, 0.06899838721645729, 0.09890647378883191, 0.04801304631733468, 0.10834197141230106, 0.16706779306488379, 0.24323132687381335, 0.2303186697619302, 0.16624774278274604, 0.2038563604333571, 0.23692347535065242, 0.4737142835344587, 0.3039672135242394, 0.40542122668453623, 0.3935472438377993, 0.3074491566845349, 0.18188406660088471, 0.3009586435343538, 0.25025728557791027, 0.13648004510572978, 0.24437699254070008, 0.34114639993224827, 0.22583774663507938, 0.26572948534573826, 0.3244757444730827, 0.43160567592297283, 0.22320138024432318, 0.1978583415704114, 0.09826624885733638, 0.043631097700979025, 0.12221239427370684, 0.23031858833772795, 0.08738627231546811, 0.1460947370422738, 0.1859373633882829, 0.17822773994079658, 0.09462525030331952, 0.1569489903215851, 0.245613337627479, 0.13944886651422295, 0.0870149236704622, 0.1969356560813529, 0.0518555833425905, 0.10049511425729309, 0.0725721972329276, 0.11229236836412124, 0.0688010828037347, 0.17923763075045177, 3.1899327380316596, 18.789311681474956, 38.408241748809814, 47.93715763092041, 69.8562992640904, 75.28084823063442, 80.50713729858398, 73.01275471278599, 73.07947826385498, 69.01827008383614, 72.93046719687325, 67.50029018947056, 58.08255590711321, 63.1825475692749, 44.115030016217915, 56.23541900089809, 49.8258239201137, 58.65502493722098, 63.83607428414481, 62.27937207903181, 65.65121473584855, 57.117465019226074, 67.69552762167794, 83.51003061022077, 65.01258495875767, 78.2442410332816, 72.17228671482631, 84.69125216347831, 54.31568384170532, 57.58672898156302, 43.265289647238596, 86.87250014713833, 54.30274282182966, 40.048228536333355, 47.35700041907174, 43.55259418487549, 42.78433881487165, 38.76830087389265, 37.32857506615775, 33.35382332120623, 35.559125968388145, 40.18336057662964, 56.05691630499703, 59.06019524165562, 67.05382674080985, 68.77163682665143, 72.54111099243164, 62.94803891863142, 45.19578756604876, 21.688374587467738, 11.450403724397932, 3.6240505405834744, 0.23348745544041904, 0.06741061527282, 0.370959925864424, 0.5640388024704797, 0.09296663251838513, 0.029345075533326184, 0.19217768710638794, 0.18093805307788507, 0.008157119836791285, 0.17542547173798084, 0.24866647379738943, 0.21949003796492303, 0.1413561198860407, 0.20604684789265904, 0.13116692591990742, 0.10651162319949695, 0.13104698807001114, 0.09667391715837376, 0.15124347433447838, 0.06385068129748106, 0.13708345272711345, 0.15215641606066907, 0.230502009923969, 0.08865482067423207, 0.06485827865877322, 0.18036142044833728, 0.15691647492349148, 0.21839155762323312, 0.13185699603387288, 0.09537237164165292, 0.1736393640083926, 0.16265485914690153, 0.19737500750592776, 0.1848578955978155, 0.2472431787422725, 0.3022341808038098, 0.24153802916407585, 0.4269639535674027, 0.2986755089036056, 0.3445708304643631, 0.2676187168274607, 0.31039736419916153, 0.15972814762166568, 0.22515974087374552, 0.23996350222400256, 0.1763368799750294, 0.14187342141355785, 0.12160757529948439, 0.16065058883811745, 0.04517938229920609, 0.06267561470823628, 0.1547649082328592, 0.027365339354478886, 0.14481141019080365, 0.08411396254918405, 0.14317885493593557, 0.06655139994940587, 0.2885905514870371, 0.31247289425560404, 0.2313747416649546, 0.14026015012391976, 0.14244640352470533, 0.23739413438098772, 0.038492982874491384, 0.10616518357502562, 0.03822899204013603, 0.03396602453930037, 0.09073730571461575, 0.14807776920497417, 0.20914042474968092, 0.047900260226534944, 0.21533558517694473, 0.10275431695793356, 0.05810524030987706, 0.06874874739774636, 0.03272628677742822, 0.03527506786797728, 0.04240376355924776, 0.0710898017776864, 0.09987021743186883, 0.09459421411156654, 0.14955918756978853, 0.22303086439413683, 0.22313260393483297, 0.2684246264398098, 0.3246118857392243, 0.2535199262201786, 0.352276654115745, 0.2819751336106232, 0.35035621002316475, 0.30473621083157404, 0.23055992967316083, 0.22017915812986238, 0.2382276196564947, 0.16757826853011334, 0.08947615338755505, 0.2032292312277215, 0.2911736528788294, 0.1273583360016346, 0.21834323235920497, 0.23886441120079585, 0.27603730080383165, 0.13668634689279965, 0.13431162360523427, 0.02250407699362508, 0.10644313866006476, 0.13736007788351604, 0.150661508419684, 0.11356767493167094, 0.09762666853410856, 0.20241911469825677, 0.18250755885882036, 0.11029137537947722, 0.12982390155749662, 0.17775921151041985, 0.0441662752335625, 0.09598132967948914, 0.24830937438777514, 0.052529253265155215, 0.1138434112071991, 0.12971332749085768, 0.10441499748932463, 0.16617731084781034, 1.405926404254777, 13.030536123684474, 41.50564098358154, 63.10013498578753, 74.21510573795864, 83.17377948760986, 89.02686555044991, 79.25513444628034, 79.12816306522915, 71.49699129377092, 61.38815443856375, 60.10100759778704, 49.053969383239746, 50.46212952477591, 48.26468529020037, 46.178415707179475, 39.320265769958496, 39.71050786972046, 43.86487749644688, 37.50568117414202, 40.23375586100987, 45.23019504547119, 53.141400064740864, 49.9427273614066, 55.901255811963765, 47.737317017146516, 60.52923897334507, 46.78671312332153, 38.51833595548357, 35.67623438153948, 39.616811411721365, 44.51295334952218, 118.67595454624721, 70.206467628479, 43.2894172668457, 50.95601095472063, 41.379183769226074, 43.160722732543945, 29.9692793573652, 37.1554468018668, 39.43632500512259, 33.44409779139927, 37.228013787950786, 51.701736790793284, 58.82121195111956, 73.36219351632255, 80.80844593048096, 86.26083632877895, 81.60004029955182, 68.93234171186174, 41.37567492893764, 20.009260756628855, 9.556316103254046, 1.0985556862183978, 0.22355909033545426, 0.23844342093382562, 0.4330621106284005, 0.1144926335130419, 0.06222616668258395, 0.058665560957576544, 0.23932738921472005, 0.010548932028801312, 0.08563852895583425, 0.3288366618965353, 0.31068028616053717, 0.11934662876384598, 0.06684786546975374, 0.16601800439613207, 0.11465816891619138, 0.13721181798194135, 0.007872585506577576, 0.17823747013296398, 0.11115369160792657, 0.14077036774584226, 0.13510028485740933, 0.27626151591539383, 0.1437560168227979, 0.03156873656968985, 0.0859661256628377, 0.07131122811032192, 0.09050350290324007, 0.06938431079366378, 0.06522080634853669, 0.13420589427862847, 0.14241833931633405, 0.24960290640592575, 0.2729502378829888, 0.3174039439431259, 0.23286808867539677, 0.33662328549793785, 0.2351701408624649, 0.2502550599830491, 0.25267409160733223, 0.13967338018119335, 0.14165649376809597, 0.10956256091594696, 0.15594766262386525, 0.16797381373388426, 0.18748568530593598, 0.10524135136178561, 0.15532791587923253, 0.08811003169310944, 0.12258058094552585, 0.023222165514848063, 0.06103016050266368, 0.1235500310680696, 0.1543206577854497, 0.07957277194197689, 0.14946409767227514, 0.14658324154359953, 0.2593175194093159, 0.29859601174082073, 0.2868677782160895, 0.28656246459909845, 0.2235505407942193, 0.31020949142319815, 0.25639308776174274, 0.19250168757779257, 0.1707386810864721, 0.1345135827681848, 0.20742260478436947, 0.21061481349170208, 0.28569657249110086, 0.2369082761662347, 0.3460601062646934, 0.22354471896375927, 0.17936013346271856, 0.17869174932794912, 0.2382892577775887, 0.15498070951019013, 0.18080644442566804, 0.162559036431568, 0.17876040350113595, 0.1842991355806589, 0.2902590148150921, 0.2992043862385409, 0.3422178881508963, 0.370948173637901, 0.541095036481108, 0.2969830525772912, 0.7625515503542764, 0.34167367592453957, 0.4826695887105805, 0.4749834154333387, 0.3960068518561976, 0.2361423729785851, 0.43554622733167236, 0.29685521657977787, 0.20882341318896838, 0.2740587741136551, 0.3467094099947384, 0.2961907950895173, 0.3647999135511262, 0.40503427173410145, 0.4993134013244084, 0.3425486061189856, 0.231273531381573, 0.20032212936452456, 0.28256706041949137, 0.2383535828973566, 0.24388586889420236, 0.2078489147658859, 0.19116076667393955, 0.26911409944295883, 0.341802570436682, 0.1799940208771399, 0.15421220074806893, 0.2638574886534895, 0.1610017442809684, 0.15830445901623794, 0.3006990360362189, 0.19971341559929506, 0.2637735403009823, 0.2844102872269494, 0.17695601603814534, 0.20540394953319005, 0.4895917315568243, 6.872025489807129, 30.016693864549907, 54.70341764177595, 76.08865969521659, 95.60457229614258, 103.19157436915806, 103.88506017412458, 99.13495894840786, 99.26874651227678, 93.25421210697719, 94.218017578125, 92.34971645900181, 80.98438126700265, 93.41803673335484, 72.66978468213762, 89.84775352478027, 81.04699843270438, 92.08711624145508, 90.81802082061768, 91.13748509543282, 96.92775249481201, 84.03191675458635, 102.55852399553571, 114.73219176701137, 89.36973135811942, 105.75598771231515, 98.62477357046944, 119.4088922228132, 84.48290348052979, 93.2653500693185, 69.0853271484375, 118.56645093645368, 77.35992990221295, 77.8546416418893, 90.14534487043107, 81.1827940259661, 79.14665916987828, 66.72817856924874, 68.03980391366142, 63.2893830708095, 55.911407130105154, 64.64804771968296, 78.80555820465088, 78.19261591775077, 89.80835723876953, 97.01927416665214, 100.84008162362235, 90.95737389155796, 72.3650575365339, 43.09274503162929, 21.334448984691075, 6.420106402465275, 0.63200722102608, 0.2181439601949283, 0.3625228857355458, 0.747223932828222, 0.1600607926292079, 0.15500368470592157, 0.1694864175681557, 0.33200949164373533, 0.17410445905157498, 0.2307350459907736, 0.337475769753967, 0.37973316652434214, 0.23990091415388243, 0.5077977489147867, 0.34830665428723606, 0.19251741601952485, 0.19651543934430393, 0.13650988707584993, 0.2216404511460236, 0.15398453867861203, 0.2787831148930958, 0.2930753422634942, 0.3090721038835389, 0.1848665401339531, 0.09735908824950457, 0.22133614176086017, 0.2834642194211483, 0.32117081752845217, 0.2650919338422162, 0.3370701958026205, 0.22158491984009743, 0.34040478829826626, 0.2749263218470982, 0.42993680547390667, 0.4552040924983365, 0.3127785607108048, 0.2966110525386674, 0.603320443204471, 0.32131762536508696, 0.32377074658870697, 0.24160892250282423, 0.26162060296961237, 0.22979788056441716, 0.2444655006485326, 0.26333862649542944, 0.3979548987533365, 0.16177900614483015, 0.3208084798284939, 0.2214474350746189, 0.31366478172796114, 0.18372961399810656, 0.25509076192975044, 0.21328463165887765, 0.37938518662537846, 0.15681656742734568, 0.32796151457088335, 0.2707453247691904, 0.4794336280652455, 0.46650563606194084], [0.2154682387730905, 0.07657055982521602, 0.18661527415471418, 0.08206688346607344, 0.14176678285002708, 0.13515988737344742, 0.14737062714993954, 0.1835166354264532, 0.07498643161462885, 0.1325308491608926, 0.17820992161120686, 0.1265756729990244, 0.15921883923666819, 0.19799015378313406, 0.14983427923704895, 0.09430517176432268, 0.1804813990103347, 0.032685513608157635, 0.03969726039628897, 0.07647226724241461, 0.0643784458349858, 0.1929796069328274, 0.19639767280646733, 0.059326426924339364, 0.20819768176547118, 0.2456192544528416, 0.19094482968960488, 0.184795293956995, 0.18929955868848733, 0.23482471225517138, 0.2610871930207525, 0.0829787463215845, 0.08128341979214124, 0.16873491289360182, 0.09942752761500222, 0.20025989413261414, 0.12462459983570234, 0.16345909956310475, 0.2196943312883377, 0.2064102848193475, 0.1911343445203134, 0.19410057392503532, 0.1312218601150172, 0.11719242935734135, 0.19257368014327117, 0.1190684022647994, 0.12691746465861797, 0.1015821544985686, 0.13380383513867855, 0.1488029467208045, 0.14406846862818512, 0.1625870056450367, 0.1145977114460298, 0.14329713716038636, 0.0754881879048688, 0.0728364594812904, 0.06488839204290084, 0.2882466699395861, 0.23559930069105967, 0.14187202363141946, 0.15072966047695704, 0.16139629882361206, 0.1476020754448005, 0.06324426098061459, 0.07693832580532346, 0.31429782775895937, 0.13339807119752678, 0.46813520576272694, 1.6894284316471644, 10.761739100728716, 20.48297851426261, 36.58448205675398, 42.56240292957851, 55.53532893317086, 74.53436851501465, 59.371050698416575, 80.20110389164516, 72.71902656555176, 69.06456593104771, 84.5921847479684, 69.33292620522636, 69.27374839782715, 68.13748168945312, 74.77721500396729, 81.9701360974993, 95.43575191497803, 97.12827750614711, 102.17622716086251, 96.30060808999198, 98.657395362854, 93.52517795562744, 84.36947413853237, 77.53046648842948, 82.5681814466204, 77.3143219266619, 79.65753241947719, 61.31740093231201, 64.6288151059832, 67.61268424987793, 59.99439443860735, 56.74728584289551, 48.792803968702046, 47.68825231279646, 44.13818836212158, 53.122758047921316, 63.789931297302246, 76.33668954031808, 72.31312670026506, 71.06964928763253, 62.14534132821219, 39.56435251235962, 20.837991510118755, 6.269707867077418, 0.9562072902917862, 0.3412422633596829, 0.3104895363960947, 0.3309975245169231, 0.27578176451580866, 0.030985922486122166, 0.09116111868726355, 0.07254807531301465, 0.11380916554480791, 0.2558671959808895, 0.09680621113095965, 0.03073717833363584, 0.20179977507463523, 0.04870466349114265, 0.18603482815836156, 0.14578258379229478, 0.1803853184516941, 0.14132588436560972, 0.1383339791957821, 0.06715339621795074, 0.12109078945858137, 0.13283931118037018, 0.017628293983372192, 0.07713799830526114, 0.023052441854295985, 0.0650120550500495, 0.09586646048618214, 0.08099456064935241, 0.07996423915028572, 0.10411986189761332, 0.028000719545941268, 0.049818034283816814, 0.04308231893394675, 0.0951576153082507, 0.1541052907705307, 0.020924905481349145, 0.19526842768703187, 0.045141791459172964, 0.07660816423594952, 0.050668781490198204, 0.08598285155104739, 0.13385178042309626, 0.14930973095553263, 0.2540870729301657, 0.15925982275179454, 0.18350868299603462, 0.3613718460713114, 0.2570582149284226, 0.16918061540595122, 0.2133587955364159, 0.19280865682022913, 0.07711014444274561, 0.125351609396083, 0.11548306393836226, 0.13110671272235258, 0.06991989205458335, 0.044223845537219725, 0.050095575462494574, 0.12145881328199591, 0.13402107491024903, 0.195561554815088, 0.21636803049061978, 0.3753404936620167, 0.15949038895113127, 0.1251326325748648, 0.2788269482553005, 0.10177860395716769, 0.11515995913318225, 0.15526303436074937, 0.15151153637894563, 0.17746733288679803, 0.08994564533765827, 0.21890617215207644, 0.15012018675250666, 0.16788972967437335, 0.18025172847722257, 0.21143185107835702, 0.04264240771798151, 0.054538459916199954, 0.15511945635080338, 0.02155286249970751, 0.10604069954050438, 0.029597951964076077, 0.043675171943115335, 0.15351192546742304, 0.19179098999926023, 0.09915184562227555, 0.21358839821602615, 0.2139304612896272, 0.19552384183875152, 0.21166833410305635, 0.2599884548357555, 0.24875517189502716, 0.2557579518428871, 0.1500518854175295, 0.2350488459425313, 0.2516784093209675, 0.138811355722802, 0.17649290231721743, 0.1950263806751796, 0.1169776865946395, 0.2576410493680409, 0.21979104966989585, 0.19995979166456632, 0.21924941587660993, 0.18802524278206484, 0.055607861639665704, 0.1251559741795063, 0.11071577189224106, 0.216726581965174, 0.16363140674574034, 0.1805320041520255, 0.10172069099332605, 0.14673912817878382, 0.052240611253572364, 0.07717728548284088, 0.2326374953346593, 0.11395888429667268, 0.10664224119058677, 0.10367892948644501, 0.25573938712477684, 0.15800624287554196, 0.09245460999331304, 0.07165849554751601, 0.145000409334898, 0.08659609793020145, 0.12732301146856376, 0.16303196176886559, 0.34690214108143536, 0.4485247294817652, 3.0876391870634894, 8.892968109675817, 29.348047869546072, 42.15442902701241, 61.45886625562395, 63.985168729509624, 73.66465554918561, 90.76331070491246, 86.32323115212577, 88.2541285923549, 85.08949511391776, 85.96100071498326, 80.25803743089948, 80.66907896314348, 77.73488943917411, 78.7823303767613, 82.77349376678467, 90.9206040246146, 97.19311809539795, 96.56131839752197, 105.63585335867745, 104.17997646331787, 96.8365226473127, 91.45227323259626, 84.29080663408551, 81.66014916556222, 73.7512092590332, 72.58277933938163, 70.56715556553432, 68.87248298100063, 64.1578036717006, 68.76343100411552, 66.61870275224958, 66.16369996752057, 63.954325675964355, 61.88413075038365, 54.44001143319266, 60.981462478637695, 66.96753706250871, 75.71078191484723, 80.85707637241909, 82.02690287998745, 75.5611663545881, 59.873600006103516, 37.88872494016375, 16.223788363592966, 4.453575560024806, 0.6886143577950341, 0.3122656153781073, 0.14298084484679358, 0.17600956825273378, 0.046553337680441995, 0.07777918675648314, 0.04495863789426429, 0.045375746940927844, 0.2282074759049075, 0.18683473952114582, 0.05754192732274532, 0.22571265191904136, 0.24491558649710246, 0.16199070907064847, 0.11191287051354136, 0.20064266930733407, 0.11960839400334017, 0.16090769932738372, 0.13578891647713526, 0.2584279328584671, 0.11754472473902361, 0.06561601228479828, 0.08628053164907865, 0.02453867781774274, 0.13371046872011252, 0.1967133680092437, 0.0732001813926867, 0.09471153281629086, 0.07897262128868274, 0.018546631759298698, 0.04607130640319415, 0.04672105796635151, 0.12376146257988044, 0.07203769484268767, 0.07312250948910202, 0.16060124577156135, 0.09478208010217973, 0.06465497599648577, 0.15724169675792965, 0.09527798063520874, 0.2836444926049028, 0.18167088446872576, 0.19489071438355104, 0.2530119206224169, 0.21245033214134829, 0.10749756850834404, 0.16450238786637783, 0.15858159985925468, 0.16179545383368218, 0.2047695464321545, 0.09142837327505861, 0.08228267117270402, 0.10326659732631274, 0.09774893375911883, 0.1242446880787611, 0.0871268208803875, 0.04403380144919668, 0.2440305325601782, 0.3180671440703528, 0.18880183968160832, 0.17733459786645003, 0.3204717364694391, 0.2557345830968448, 0.23830858245491982, 0.33958509085433825, 0.18847595288285188, 0.2442200066787856, 0.23961541375943593, 0.28696440160274506, 0.38615916456495014, 0.23061985788600786, 0.26742424869111603, 0.24462229652064188, 0.34524358436465263, 0.23116854844348772, 0.36167770251631737, 0.34033549630216187, 0.2296682803758553, 0.16944818890520505, 0.17773928972227232, 0.23366943853242056, 0.11165614678923573, 0.21221076856766427, 0.21699499684785092, 0.30796234628983904, 0.22037309700889246, 0.3452584578522614, 0.26947871702057974, 0.24516604734318598, 0.3185043920363699, 0.28514766480241505, 0.3088185760591711, 0.3158719204366207, 0.13815404527953692, 0.2639298476278782, 0.27354216469185694, 0.18911802342959813, 0.22872460101331982, 0.2571118191948959, 0.20813345164060593, 0.3127177639731339, 0.31256699349199024, 0.25304362177848816, 0.30482471893940655, 0.29891999864152496, 0.15879893462572778, 0.23563159895794733, 0.135487524792552, 0.23426861209528788, 0.2068989793104785, 0.3837703956024987, 0.262044008821249, 0.15243791309850557, 0.2585782419357981, 0.16640661497201237, 0.3615213137652193, 0.33671686904770987, 0.2200302875467709, 0.1502211256218808, 0.40464639397604124, 0.31786035373806953, 0.24042151336159023, 0.217148182913661, 0.34414272915039745, 0.3306791287447725, 0.22701420422111238, 0.26320663786360193, 0.5167895321335111, 0.17222746834158897, 1.006695723959378, 3.7934819289616177, 18.210759503500803, 31.401834624154226, 52.977269717625205, 61.84775693075997, 78.75263377598354, 105.94039985111782, 93.77147769927979, 111.05191162654332, 108.70536599840436, 105.29402978079659, 113.98619147709438, 105.56666319710868, 110.74682317461286, 108.87609713418144, 108.15616648537772, 113.44837311335972, 120.7596081324986, 126.02923311505998, 130.9106066567557, 124.2919750213623, 125.75466809953961, 121.56815610613141, 111.60511330195835, 103.57179369245256, 106.78231307438442, 102.93920189993722, 107.21924359457833, 90.64004271371024, 97.19290964944022, 102.16065624782017, 96.5426138469151, 91.57775769914899, 87.2425959450858, 86.99024432046073, 79.60487897055489, 87.2525944028582, 94.47559424809047, 108.32044274466378, 102.16936234065464, 99.88481548854283, 88.97410787854875, 62.499407632010325, 35.537312098911826, 13.115500433104378, 3.2066533608095984, 0.6953868972403663, 0.36986061771001133, 0.3707520770175116, 0.2970404294984681, 0.1540094002016953, 0.17587478405662946, 0.2186749545591218, 0.2292241927768503, 0.379811062344483, 0.2849134345139776, 0.1456790529191494, 0.35861479544213837, 0.27705540188721245, 0.21607376342373236, 0.13918981541480335, 0.47618995926209856, 0.22980124609810965, 0.2458581259208066, 0.2992967212838786, 0.2711776058588709, 0.24718186631798744, 0.16989575060350554, 0.13107037038675376, 0.10255245278988566, 0.19391625667256968, 0.26818944620234625, 0.16569800728133746, 0.1961408065898078, 0.19551770788218292, 0.11976961392377104, 0.13508988970092364, 0.11413482842700821, 0.2279101690011365, 0.21559543694768632, 0.1453434494989259, 0.2605163822216647, 0.14448601193726063, 0.09925239772668906, 0.15273192232208593, 0.3328106515109539, 0.29930223098823, 0.2176540307700634, 0.2769361154309341, 0.2694068465914045, 0.3090938441455364, 0.3541120099169867, 0.26340382014002117, 0.1935858101184879, 0.21677786564188345, 0.29306231439113617, 0.15537352700318607, 0.15488773664193495, 0.1384216866322926, 0.25460848637989586, 0.2164599448442459, 0.13739245757460594, 0.23235373198986053, 0.2445642410644463, 0.3708960350070681, 0.3298277301447732, 0.2969525456428528, 0.47176265397242134], [0.01713826277825449, 0.05288441884996636, 0.05738045634435756, 0.018247558968141675, 0.08958610998732702, 0.0305093262743737, 0.051290139755500216, 0.07614955598754541, 0.09289232614849295, 0.11838365186538015, 0.025077217491343617, 0.12192257839654173, 0.019062401494011283, 0.025801826734095812, 0.06455764014806066, 0.009786857474994446, 0.011270694817150278, 0.06785685382783413, 0.06145016010850668, 0.01163842432600047, 0.002456250330266942, 0.0776634897504534, 0.041363644014511786, 0.022560276656544635, 0.02839429021280791, 0.04044112815920796, 0.042751712924135585, 0.05543120504756059, 0.05652876936697534, 0.008606099673280758, 0.00192305920895056, 0.130478457148586, 0.05333051151995148, 0.025243266884769713, 0.055261591648949046, 0.05361111967691353, 0.07026748518858637, 0.12702582670109613, 0.07244218992335455, 0.08578150985496384, 0.11915988235601357, 0.09895406623503991, 0.10184577892401389, 0.1073092275432178, 0.08278619165399245, 0.04288082117480891, 0.06499914931399481, 0.046324505138077905, 0.027852524105193358, 0.1199196380163942, 0.018453341675922275, 0.04162202675693801, 0.061389879057449956, 0.07879032607057265, 0.033314444324267764, 0.03727617281089936, 0.0322348577901721, 0.06452597970409052, 0.01299222297633865, 0.08702964788036686, 0.041131072744194946, 0.06060935344014849, 0.08618016953447036, 0.021997455607301424, 0.04983248368703893, 0.07397188605474574, 0.02807131432928145, 0.05020368305434074, 0.08871770051441022, 0.01845643579560731, 0.06773940620145627, 0.7770167770130294, 1.61404264824731, 4.038796331201281, 9.719967024666921, 14.000390870230538, 35.642813546316965, 33.88750750677926, 32.098078863961355, 49.07898984636579, 42.154192788260325, 48.95253610610962, 53.447978905269075, 62.2319575718471, 76.92891924721854, 55.47433417184012, 52.19724757330758, 57.990419319697786, 59.78397519247872, 66.01113837105888, 86.1265971320016, 76.8083610534668, 84.91349029541016, 88.89019448416573, 83.70340592520577, 84.6024819782802, 82.37596648080009, 76.1792572566441, 58.13561235155378, 52.17283855165754, 65.72039100102016, 57.15462051119123, 62.57603236607143, 72.02299771990094, 63.269809995378765, 57.666789599827354, 47.16935041972569, 26.989662511008127, 15.808279139654976, 6.399136304855347, 0.4874331216726984, 0.04420251578890851, 0.35213109478354454, 0.2983835759971823, 0.11338948485042367, 0.12706964649260044, 0.027721159725583026, 0.08625372951584202, 0.04469661820413811, 0.1023389653169683, 0.10794341351304736, 0.0139775593000065, 0.06653912525091853, 0.13783247396349907, 0.03819671752197402, 0.11891076500926699, 0.10076954774558544, 0.022873040588040437, 0.021766214265621135, 0.03966609528288245, 0.05527591213051762, 0.09211407362350396, 0.036952508214328966, 0.008616391353176107, 0.06012521191899266, 0.01203156666763659, 0.04508324745776398, 0.014540311647579074, 0.08748414420655795, 0.06484078602599246, 0.07798115949013404, 0.03141455984275256, 0.019763767519699674, 0.02315228319327746, 0.04302352387458086, 0.06984138555292572, 0.034535261137144904, 0.04717955764915262, 0.008879547589458525, 0.05377182051805513, 0.05674858417894159, 0.021868727336238538, 0.039346067634012015, 0.08321701389338289, 0.05708315622593675, 0.05034388874524406, 0.01999912247993052, 0.04898781954709973, 0.06851921257163797, 0.0506617043699537, 0.06599828534360443, 0.04198598615559084, 0.10760664301259176, 0.060838935763708184, 0.10117529811603682, 0.02076761088600116, 0.05083080886730126, 0.05864085549754756, 0.07202019542455673, 0.02174130524508655, 0.034675253089517355, 0.01168140018957534, 0.11241681847189154, 0.016829342747639333, 0.04545565461739898, 0.03729679009744099, 0.060296548796551566, 0.1405659658568246, 0.03296544662277613, 0.021195284722905074, 0.08871094909097467, 0.018424751602911522, 0.07414642561759267, 0.0766255415177771, 0.11851878889969417, 0.09501409158110619, 0.09912561345845461, 0.14767735211976937, 0.040026444875236065, 0.056825971097818444, 0.015470980101131966, 0.06281981018504926, 0.06373588674302612, 0.07228833889322621, 0.06136182163442884, 0.054612284526228905, 0.03867446385057909, 0.04407953131677849, 0.023755426186003854, 0.10715964449835674, 0.06878037391496555, 0.052227010019123554, 0.06118146702647209, 0.1232307803417955, 0.10449718843613352, 0.0873144358130438, 0.013499236216635575, 0.09302094246127776, 0.10055381432175636, 0.09562602838767426, 0.06270612164267472, 0.057648864441684315, 0.02768465963059238, 0.11662289420408861, 0.16947383752890996, 0.12867919941033634, 0.1252046794231449, 0.07778413327676909, 0.03662640428436654, 0.08333683639232602, 0.04262351051771215, 0.05953521214957748, 0.08734973320471388, 0.06086925270834139, 0.042207578729305945, 0.05640536081045866, 0.05110189039260149, 0.07685190079999821, 0.03581979578094823, 0.04776969312557152, 0.10578079348696129, 0.05237407569906541, 0.02985476729060922, 0.007096312607505492, 0.035553782912237306, 0.029710799123027494, 0.030013252714914933, 0.07534783293626138, 0.012549518740602901, 0.10616341259862695, 0.03316904444779668, 0.08471601988588061, 0.019788800372875164, 0.12044782324561051, 0.023650304148239747, 0.30170674196311403, 0.4417533299752644, 4.175095668860844, 8.297852294785635, 15.928559405463082, 27.615789004734584, 27.79114590372358, 60.0583803994315, 54.864084311894004, 53.05059405735561, 75.66488211495536, 64.69548307146344, 72.97160053253174, 77.04280717032296, 83.53956045423234, 93.60338687896729, 93.33528368813651, 90.02773966108049, 94.81303351266044, 86.7241074698312, 91.66454069955009, 104.40147808619908, 96.82944938114711, 98.39844989776611, 108.64880071367536, 101.2772970199585, 105.29161180768693, 98.72761385781425, 95.77321202414376, 82.84552574157715, 74.88876833234514, 84.37339292253766, 74.81121948787144, 75.0701927457537, 82.66658183506557, 82.05971227373395, 76.8785239628383, 67.41196468898228, 47.471864564078196, 35.316355909620015, 17.979358434677124, 3.938776578222002, 0.661899239889213, 0.42260680879865375, 0.23776380025914737, 0.13536506279238633, 0.04742317546957305, 0.06013630596654756, 0.020085618731432726, 0.05107334103169186, 0.023068482422136834, 0.06809255653726203, 0.10890632255801133, 0.0313477682481919, 0.018774629703589847, 0.12258743414921419, 0.06716081939105477, 0.018067516486293504, 0.0661149255133101, 0.002523432930632095, 0.01791193688820515, 0.0500970682395356, 0.07555173270936523, 0.013259508098209543, 0.04874852399474808, 0.020808691092367684, 0.06334517949393817, 0.06174461037984916, 0.05875003856739827, 0.021897775420386876, 0.07907622680068016, 0.02439537800715438, 0.03164723967867238, 0.06653949165982859, 0.10434827714094094, 0.05305108740659697, 0.08513386853571449, 0.08931548986583948, 0.06048170743244035, 0.06957877893000841, 0.0711217268503138, 0.0353617575019598, 0.05563791056296655, 0.06685212666967086, 0.04443292592519096, 0.13416713635836328, 0.09215760164495025, 0.058106821296470504, 0.06503578341965165, 0.015373520420065947, 0.061909474033330164, 0.1369973194918462, 0.09423949635986771, 0.1961171528590577, 0.03389440516808203, 0.13264108396002225, 0.042821245800171576, 0.09108253754675388, 0.03766893941376891, 0.03870979516900011, 0.013073955912009945, 0.1233489132885422, 0.05107577357973371, 0.1375858671963215, 0.11488797515630722, 0.10148173131580863, 0.1054289662944419, 0.12822819075414113, 0.18288174378020422, 0.163353845211012, 0.10490074035312448, 0.16826695443264075, 0.10026595262544495, 0.1276101539177554, 0.11808216518589429, 0.2111863163965089, 0.19768565440816538, 0.18671102901654585, 0.22041623826537812, 0.09769164504749434, 0.13320330450577395, 0.15243114131901944, 0.14871244372001716, 0.18753695541194507, 0.17167556152812072, 0.14300444429474218, 0.15503883281988756, 0.17064376760806355, 0.17863289320043155, 0.15534314220505102, 0.21109544698681149, 0.14076143822499684, 0.18885621747800282, 0.1257304490676948, 0.20010536456746714, 0.20348826875644072, 0.1861102133989334, 0.15148336360497133, 0.22799520300967352, 0.25417283975652283, 0.21261604396360262, 0.17786089676831449, 0.182493391047631, 0.11054093377398592, 0.21715317693139824, 0.2270287655826126, 0.19932574140174047, 0.26212841857756886, 0.23486963127340588, 0.1937556474336556, 0.2289675979741982, 0.19765681666987284, 0.08335233413215194, 0.23627618008426257, 0.15722170711628028, 0.10757257376930543, 0.27001769095659256, 0.16510074718722276, 0.12191177611904484, 0.12832382347966942, 0.23174351187688963, 0.14190136348562582, 0.18128703720867634, 0.18731088111443178, 0.34980062554989544, 0.13648445558335098, 0.10422117396124772, 0.2077625101166112, 0.16208901522415026, 0.11818633388195719, 0.25713421085051125, 0.06834959917302642, 0.18271228644464696, 0.13856138342193194, 0.10578740920339312, 0.13688314918960842, 0.150979592065726, 0.1355025746992656, 1.2033575368779046, 3.0754238196781705, 7.4846281835011075, 16.74045467376709, 23.109784943716868, 51.5689115524292, 49.07361888885498, 51.62798513684954, 68.13810007912772, 65.65680803571428, 74.6541415623256, 81.83040087563651, 87.82354872567313, 102.15938472747803, 94.9764620917184, 87.80485112326485, 95.99839619227818, 83.00991317204067, 88.64825820922852, 105.68789536612374, 99.48199367523193, 111.00902039664132, 120.93614796229771, 116.58214269365583, 116.6657156263079, 116.43406963348389, 104.1664205278669, 89.2836640221732, 85.60504450116838, 101.55294595445905, 91.52930096217564, 95.08403410230363, 102.45657307761056, 95.75444493974958, 84.97047247205461, 65.9473261151995, 42.619002955300466, 27.61634486062186, 11.896866304533821, 2.056146753685815, 0.38255361946565763, 0.44589757759656223, 0.36452372265713556, 0.14181658732039587, 0.23920221307447978, 0.0865309653537614, 0.1940607303487403, 0.13964309037796088, 0.15632984068776878, 0.1968002612037318, 0.15239801523940905, 0.150233067838209, 0.13986991106399468, 0.3011832114841257, 0.3074813735272203, 0.264924661389419, 0.10236689381833587, 0.0746709874698094, 0.11972622839467865, 0.15094406397214957, 0.15411118045449257, 0.24088343286088534, 0.21348102683467524, 0.12909401500863688, 0.10996323584445886, 0.1637385202837842, 0.11786848093782153, 0.22774913907051086, 0.15858678386679717, 0.1004707073526723, 0.13359804903822287, 0.12500444373914174, 0.2202812097966671, 0.19021942147186824, 0.2043245088841234, 0.1580331807157823, 0.16039847236658844, 0.11899787533496108, 0.2921759576669761, 0.1900636162608862, 0.3150620481797627, 0.19673794454761914, 0.3078836905104773, 0.24587511643767357, 0.23894705676606723, 0.08949828719986336, 0.15616036978151115, 0.19755043594964913, 0.09185076132416725, 0.21127402383301938, 0.1539200914225408, 0.29309515548603876, 0.20738943799265794, 0.2236540988087654, 0.1383444286350693, 0.19797365181148052, 0.15992885828018188, 0.1081658440775105, 0.10079947792525802, 0.23560383330498422, 0.1320788905556713, 0.1683931890875101, 0.10894579294004611, 0.1433054017169135, 0.15991648180144175], [0.05199403162779553, 0.035381835353161604, 0.0435893915460578, 0.05164861659120236, 0.029606189379202466, 0.0551091451863093, 0.06199572940490075, 0.06084479830626931, 0.006810264296031424, 0.024750638586868132, 0.07586250174790621, 0.035476314569158215, 0.04275420993300421, 0.04989193014002272, 0.0510525371480201, 0.04023138280691845, 0.02840060058848134, 0.05208733019285968, 0.0454187932025109, 0.0581981453246304, 0.025314755637996962, 0.03891946588243757, 0.012130312172562947, 0.06672020589134522, 0.015176585808928524, 0.030416187165038924, 0.049083984922617674, 0.12715398839541844, 0.025189131664644395, 0.03696675405704549, 0.06355473146374736, 0.03662492847070098, 0.043320722212748866, 0.07462631950953177, 0.06228189476366554, 0.0456156396040959, 0.04145020133416567, 0.03438653304640736, 0.03820805584213563, 0.05889378621109894, 0.033948728681675026, 0.015252340851085526, 0.035781322845390866, 0.06324964176331248, 0.024842208583972285, 0.045915426553360054, 0.03272776937644396, 0.09406103486461298, 0.02144915351111974, 0.021504262428996817, 0.07616208174398967, 0.02313497885396438, 0.04558965510555676, 0.04047491241778646, 0.03585572760286076, 0.018473597642566477, 0.06648989074996539, 0.015405657534886683, 0.060864150125001154, 0.02309165439302368, 0.044724970789892335, 0.028846321760543754, 0.03598329897171684, 0.058769336103328636, 0.12328526670379297, 0.01884871724593852, 0.07807583548128605, 0.05344107880124024, 0.04619685913036976, 0.014629231965435403, 0.004201228023573224, 0.02933385595679283, 0.08290048409253359, 0.052335195642496855, 0.05903542361089161, 0.05516097169103367, 0.2564891683203833, 0.3105194733611175, 0.5937909345541681, 0.22766262585563318, 0.7516084632703236, 0.43841374346188133, 1.2118281509195055, 1.6884353820766722, 2.4511557519435883, 2.2992689992700304, 2.0697035576616014, 1.881162668977465, 0.8166692235640117, 0.32707355650407927, 0.6345447248646191, 0.9369099714926311, 1.8525910249778201, 2.5574946744101386, 4.171550784792219, 4.8738139016287665, 4.16122532742364, 1.77929610652583, 0.3876101438488279, 0.9250479851450238, 1.7729395904711314, 2.6889943267617906, 3.848855597632272, 2.852186015674046, 1.9059729490961348, 1.311889375959124, 1.0679366035120827, 0.13546491600573063, 0.13303240867597715, 0.12683667827929768, 0.046050366812518666, 0.07050459925085306, 0.03883171773382595, 0.12999030548546994, 0.042906985485127995, 0.04224616701581648, 0.049760504692260704, 0.10030437806355101, 0.07233428928468909, 0.0034251160645258744, 0.07408598171813147, 0.052211576740124395, 0.020961539587005973, 0.05244368999930365, 0.019536750058510473, 0.03125463253153222, 0.028466413396277597, 0.03127536516902702, 0.017488335957750678, 0.048619062905865054, 0.03965127268540008, 0.021997452214626328, 0.02943262690678239, 0.043040945261184654, 0.035573779339236875, 0.01995733829348215, 0.0108044971545626, 0.0658981471455523, 0.04881399923137256, 0.04178460035473108, 0.06638889081243958, 0.07829133820320879, 0.029957653555486883, 0.03350131965375372, 0.04310815076210669, 0.03409853903576732, 0.03794162228171315, 0.04545578353905252, 0.011848927941173315, 0.006988231308891305, 0.029282677453011274, 0.0304294050272022, 0.06345031170972756, 0.028806210162916353, 0.013508894314457263, 0.07516748511365481, 0.03646546595596841, 0.011763547879776784, 0.1165553799697331, 0.0933667714042323, 0.010933235603650766, 0.04197277507877775, 0.09307963574039084, 0.019942581853164092, 0.07750017315681491, 0.07368819056344883, 0.04573525854253343, 0.05685262395335095, 0.04018399392121604, 0.07559901981481484, 0.04015595685424549, 0.038354846715394936, 0.03239577915519476, 0.010007495010670806, 0.05961295190666403, 0.07487496866711549, 0.06849844261471714, 0.0776054071528571, 0.01614989509939083, 0.012481623678468168, 0.026746841114280478, 0.06494000820176941, 0.047227072063833475, 0.005689050910794842, 0.07612082681485585, 0.046056351491383145, 0.08591214820210423, 0.035124215962631364, 0.06485665696007864, 0.0713173213547894, 0.06947176038686718, 0.03290385599913342, 0.012293431991046029, 0.01963621311421905, 0.08190955155129943, 0.0027291021958392647, 0.035040610270308595, 0.014640098703759057, 0.04492926072063191, 0.041684238240122795, 0.015610559843480587, 0.07764492503234319, 0.012539756318022097, 0.08579638334257261, 0.07985773629375867, 0.0597165845600622, 0.09076129871287517, 0.13606873074812548, 0.036922333762049675, 0.01744792071570243, 0.04995498300663062, 0.016565981254513775, 0.08688569667616061, 0.028756443011973585, 0.014209004202192383, 0.10763955196099621, 0.005356028468148517, 0.010926045676959413, 0.0010540704367615814, 0.0607053865013378, 0.022184766895536865, 0.011981923349334725, 0.02866124115618212, 0.08744071118001427, 0.06061632878014019, 0.018837747031024525, 0.038396715718720636, 0.036075064047638855, 0.04279378888064197, 0.028404658227892857, 0.0740756747711982, 0.06758669511015926, 0.016492097272670696, 0.04066178096192224, 0.04678339158583965, 0.008547527682302254, 0.0728770223047052, 0.050777007825672626, 0.021103923375319158, 0.03174487068983061, 0.08872340699391705, 0.004195174643038107, 0.06469707909439291, 0.024789393114458238, 0.06061991823038884, 0.07551727670111827, 0.020610519851158773, 0.014468682098335453, 0.04757294511156423, 0.1268298522170101, 0.23700468242168427, 0.7525685088975089, 2.2105889235224043, 2.685934296676091, 3.5435628252370015, 4.466784954071045, 4.917563234056745, 5.672969647816249, 6.834981603281839, 8.916993243353707, 11.10891626562391, 9.663946305002485, 11.89593698297228, 9.122030241148812, 4.578761254038129, 3.2239059550421576, 4.79674448285784, 5.696617407458169, 8.713510036468506, 10.943783640861511, 12.751598954200745, 14.743556295122419, 13.281412124633789, 8.631453548158918, 3.5004464302744185, 4.3285006029265265, 8.99031150341034, 9.6779990366527, 12.610190085002355, 12.554866790771484, 9.443029199327741, 6.152059665748051, 4.315579559121813, 0.8386962616017887, 0.2569219379552773, 0.10620210945074048, 0.09939217594053064, 0.08070192206650972, 0.08191924103136573, 0.12293541404817786, 0.03456677230341094, 0.012879775304879462, 0.07035842923713581, 0.04085815578166928, 0.058972930535674095, 0.04198411679161446, 0.04735565784254244, 0.01760482515341469, 0.029970026641551937, 0.020912077776821594, 0.04171683845509376, 0.04255393353689994, 0.068840098567307, 0.04329083274517741, 0.046346153797847886, 0.008348847539829356, 0.04462547041475773, 0.04885873843782714, 0.012547053962147661, 0.048146215600094626, 0.01230703916267625, 0.0552906804451985, 0.015172870829701424, 0.005829331240550215, 0.06032829745007413, 0.07590122574142047, 0.023456195635454993, 0.04512969317979046, 0.018560653685459068, 0.03378833318129182, 0.07183285869125809, 0.15287493036261626, 0.04541232676378318, 0.02913768809022648, 0.05620529815288527, 0.048146195244044065, 0.052814974183482785, 0.07560393919370004, 0.06388924922794104, 0.031820045584546666, 0.06643926525222403, 0.10327101458928414, 0.044689123784857135, 0.0753145847203476, 0.10950671069856201, 0.060012093346033774, 0.015280425415507384, 0.08813186695000955, 0.04420494833695037, 0.025151067546435764, 0.0494630519034607, 0.07253058946558408, 0.09055009790297065, 0.05550615941839559, 0.03641804992886526, 0.038564500465456925, 0.031466284567224126, 0.01733315160631069, 0.03402958291449717, 0.018318359008324996, 0.05947885303092854, 0.06685494937534843, 0.24322679425988877, 0.1549569743552378, 0.16234232591731207, 0.1223444507590362, 0.136936183486666, 0.12660053452210768, 0.14750560133584908, 0.1385249053793294, 0.13197162773992333, 0.0932285131088325, 0.15825897002858774, 0.10080358984747104, 0.13918459069515976, 0.19074474328330585, 0.13158940896391869, 0.10443425431315388, 0.12081153158630643, 0.09383799361863307, 0.1280196498015097, 0.258505394416196, 0.13800524254994734, 0.19080965194318975, 0.28278107036437305, 0.1680109024580036, 0.09125454617398125, 0.16579115656869753, 0.11816965549119882, 0.31026472417371614, 0.17279678636363574, 0.18233124831957476, 0.20750831732792513, 0.21825302791382584, 0.08370785934052297, 0.24532767438462802, 0.16852383422000067, 0.12796916679612227, 0.28136067943913595, 0.142974602324622, 0.2301557127918516, 0.4564282510961805, 0.09714575005429131, 0.1413772494665214, 0.1517798698374203, 0.14721499835806234, 0.11660290456243924, 0.12026020831295423, 0.1456114844019924, 0.18591660021671227, 0.12331129530710833, 0.11206148325332574, 0.1388342494943312, 0.08061124264661755, 0.12981419850672993, 0.12215740579579558, 0.1452247058706624, 0.1883136744477919, 0.14371244130390032, 0.10601851823074476, 0.1592971421778202, 0.1073208237066865, 0.17243550717830658, 0.12083674594759941, 0.06601452947195087, 0.21631020573633059, 0.22220330951469286, 0.14477147161960602, 0.1340513647134815, 0.1610701134694474, 0.10338767511504036, 0.15419514237770013, 0.0974783543497324, 0.13085455553872244, 0.18815309235027858, 0.12116857671311923, 0.31661098077893257, 0.19180362432130746, 0.578297917331968, 0.7664712028844016, 1.0845062115362711, 1.3359352456671851, 1.8493562042713165, 1.9385237395763397, 2.553697918142591, 3.3307570900235857, 3.881151258945465, 4.981031554085868, 7.51103481224605, 4.858027160167694, 1.7734374723264148, 0.8652958114232335, 1.4161311366728373, 1.9626072815486362, 3.4624489034925188, 5.1572304878916055, 6.438734522887638, 8.032240901674543, 7.316781418664115, 4.068090370723179, 1.3340554322515215, 1.9563493430614471, 4.336636509214129, 5.465831254209791, 6.523446091583796, 6.578939616680145, 5.078319796494075, 3.0859386154583524, 1.8220078774860926, 0.23516891949943133, 0.21006393805146217, 0.22925543252910885, 0.13525965916258947, 0.13851005903312139, 0.1366444948528494, 0.24965260231069156, 0.1517743058502674, 0.1045286249635475, 0.19819015876523086, 0.1496456465018647, 0.22705514702413762, 0.08591239926006113, 0.16957947186061315, 0.07875171742801156, 0.11800086311995983, 0.11817329243889876, 0.08526040174599205, 0.12159152116094317, 0.15902625742767537, 0.09727635447468076, 0.13695301115512848, 0.11094988682972533, 0.1592100861349276, 0.167686793420996, 0.11122824225042548, 0.09627465358270065, 0.1887960857046502, 0.13790009676345757, 0.10087085302386965, 0.16979367179530008, 0.16165074945560523, 0.1582997499832085, 0.1420256303889411, 0.1899121401033231, 0.1799773017742804, 0.19256627054086753, 0.2517440915107727, 0.2777927523212773, 0.14348369357841356, 0.1853245377008404, 0.14977355035287993, 0.14133561455777713, 0.16568632290831634, 0.1983818584786994, 0.2671327500471047, 0.1644615807703563, 0.11004370331232037, 0.19905655298914227, 0.3153482542506286, 0.10510312699313674, 0.28941939558301655, 0.15417880325445107, 0.15655404222863062, 0.2840196410460131, 0.24848715056266102, 0.15035292426390306, 0.19863450420754297, 0.11552225612103939, 0.2419627106615475, 0.31145351752638817, 0.10887123551219702, 0.17415663839450904, 0.10856224423540489, 0.08220786947224822, 0.11376286910048553, 0.12499198583619935, 0.16798306895153864, 0.28004128166607445], [0.0342495096847415, 0.03185875940003565, 0.06427988862352711, 0.025596949870565107, 0.05380717558520181, 0.04705178611246603, 0.011548983232517327, 0.01642201647960714, 0.019923174055293202, 0.017857174023187587, 0.03004505904391408, 0.028448793538180844, 0.02136658428103796, 0.0392038500867784, 0.010623380891047418, 0.014793937859524573, 0.04314149058024798, 0.024796899408102036, 0.02366852111715291, 0.03337184499417033, 0.03000388553898249, 0.02209731051698327, 0.019430077568228756, 0.010446205219653035, 0.026021694132526006, 0.0327099306908037, 0.07041151781699487, 0.08942636248788663, 0.11267286366117851, 0.00885038500252579, 0.04892191004806331, 0.011605063303639846, 0.01166372180783323, 0.036936023206050904, 0.014902294812990087, 0.021025693376681635, 0.07525194915277617, 0.006111357959785632, 0.011297539358825555, 0.013325286131086094, 0.022793784305187206, 0.027918487887031267, 0.022449227615392635, 0.04597219618569527, 0.04859320054362927, 0.03264563610511167, 0.02842803715196039, 0.05352665563779218, 0.01814269138100956, 0.02791059822110193, 0.01622597753469433, 0.019597887760028243, 0.019878109152029668, 0.057493418854262145, 0.03804499709180423, 0.06427536279495273, 0.028638415238154784, 0.04639942558216197, 0.09913905523717403, 0.05630476460126894, 0.025877878635323474, 0.01848079520277679, 0.04291001853666135, 0.03027241237993751, 0.03797610543136086, 0.052718628996184895, 0.07436637274388756, 0.06716584055019276, 0.03696752080161657, 0.0337034993405853, 0.015510033184130276, 0.07442220939057213, 0.030058561890785183, 0.012713353565361882, 0.03310221214113491, 0.03451540041714907, 0.10375447757542133, 0.09857202387814011, 0.05478260360125985, 0.036759746593556235, 0.04058714210987091, 0.020830351626500487, 0.06229828816971608, 0.02847573986010892, 0.06928525825164147, 0.25074032108698574, 0.32428328480039326, 0.24981300798910006, 0.23827256581612996, 0.09017017936067921, 0.045808346942067146, 0.013682289697629, 0.0409092494685735, 0.0770197839343122, 0.08691571506538562, 0.08434701897203922, 0.05716194092695202, 0.08389473467000894, 0.03768346345584307, 0.02625093888491392, 0.04307750812066453, 0.0640031752575721, 0.1297516647194113, 0.07706911343016795, 0.04412519333085843, 0.086830877832004, 0.020600715020139302, 0.05887897379164185, 0.06921234287853752, 0.020877672658701028, 0.05842110514640808, 0.07896966287600142, 0.03486190110977207, 0.0693994624806302, 0.04595980613625475, 0.06201843997197492, 0.015914289081203084, 0.08430989632116896, 0.03400269935705832, 0.021951486556125537, 0.005576335642087672, 0.02556856844707259, 0.032150329290223975, 0.009496354581122952, 0.04172828194818326, 0.0008373410507504429, 0.024475222919136286, 0.08326216361352376, 0.05223523725622466, 0.0537809230653303, 0.037135074846446514, 0.04138861410319805, 0.012559199738981468, 0.040848194887595515, 0.04995990238551583, 0.03215707053563424, 0.06306204718670674, 0.005276318839085954, 0.025647444750315378, 0.024447014522073523, 0.0006742359161892507, 0.04760344526065247, 0.03534411898415003, 0.01549826399423182, 0.028332417997132455, 0.022610138802390014, 0.07057721606854882, 0.006377717729524842, 0.06479896791279316, 0.02865318355283567, 0.05859568542135613, 0.013835192475068783, 0.017240307659709027, 0.05554394703358412, 0.03824938201744642, 0.022900041192770004, 0.04243516276723572, 0.005689237507924969, 0.06098769778119666, 0.01376968331169337, 0.03392491888787065, 0.035563526675105095, 0.01897518429905176, 0.06661863598440375, 0.04570420878008008, 0.05644065480945366, 0.049871465523860285, 0.0037451142395314363, 0.034985686253224096, 0.025919119993756925, 0.025143861504537717, 0.03653896486918841, 0.04922883179304855, 0.053990539495966265, 0.03867088118568063, 0.07961931944425617, 0.04626122835491385, 0.05829942346151386, 0.024672143959573338, 0.03084671763437135, 0.004175557347480208, 0.04467306286096573, 0.04516096346612487, 0.05994527800274747, 0.04719673137047461, 0.007740238099358976, 0.054143640744898996, 0.027592629926013093, 0.05463878810405731, 0.024663568973275166, 0.03195563045197299, 0.013415359110305352, 0.028643738345376084, 0.021223564366144792, 0.046457698169563494, 0.07152291068008967, 0.01902273772949619, 0.029720325754689317, 0.05545967637694307, 0.014312795463151165, 0.008932873656574105, 0.005417136059674833, 0.06830243420388017, 0.041184592193790844, 0.029979203827679157, 0.01594795289981578, 0.03566373272665909, 0.05235909703852875, 0.010694144459973489, 0.04158311955896871, 0.04640357143112591, 0.040907481884849925, 0.03985344897955656, 0.07040554670883076, 0.035681737653378925, 0.02617614227347076, 0.049397468101233244, 0.0486281281337142, 0.02537595440766641, 0.03617120906710625, 0.01098480002422418, 0.01756715288917933, 0.002911554113130218, 0.055765193554439714, 0.01693605595002217, 0.02723853981920651, 0.04357287261102881, 0.040909483563154936, 0.008025355121519948, 0.03185900027996727, 0.030267815305186168, 0.02248655043409339, 0.013316806139690536, 0.05246954218351415, 0.053804040753415654, 0.03421864991209336, 0.020493475953117013, 0.010287225312952484, 0.017017670142065202, 0.018368533280278956, 0.029048168965216194, 0.04251552845484444, 0.06186220049858093, 0.06541894535933222, 0.04624424123072198, 0.020533752095486437, 0.03293628997302481, 0.07752181163855962, 0.021288822471563305, 0.05395470606163144, 0.021935485004048263, 0.025306540275258676, 0.15571896918118, 0.0215647673966097, 0.10427738380219255, 0.05469131349985089, 0.035615495672183375, 0.09465852566063404, 0.06413759983011655, 0.07513922413012811, 0.18211795762181282, 0.19352970884314605, 0.5791746931416648, 0.31919432644333157, 0.21701987194163458, 0.21154845053596155, 0.07859336771070957, 0.07506320106663875, 0.15406892129353114, 0.11230460235050746, 0.11761926859617233, 0.07183304868106331, 0.14321465444351944, 0.10601902713200875, 0.12557852507701942, 0.020410806639119983, 0.1251363916588681, 0.167987995115774, 0.1984858371849571, 0.30192794437919346, 0.2253221007330077, 0.12488168318356786, 0.06257122888096742, 0.039930737510855706, 0.025805816520005465, 0.0369149411230215, 0.02266570064239204, 0.028826043741511445, 0.052849056997469494, 0.03327448200434446, 0.04712505432377968, 0.042498972200389416, 0.05982605939997094, 0.03909622425479548, 0.0859780814498663, 0.08189839643559285, 0.07448150656585183, 0.013605871387491269, 0.04673348533521805, 0.03309813753834792, 0.05926774721592665, 0.03935058328456112, 0.06578142555164439, 0.06737743491040808, 0.11317696089723281, 0.08535015157290868, 0.02737500169314444, 0.03264753261048879, 0.025841621116601994, 0.036984104197472334, 0.029231224142547165, 0.055441142192908695, 0.09225907655698912, 0.009272553375922143, 0.04450848758486765, 0.014916615294558662, 0.025148475542664528, 0.061785166417913776, 0.07689333893358707, 0.03853656857141426, 0.034321607423147986, 0.048742797159190686, 0.04215453425422311, 0.02677464747934469, 0.04024292468758566, 0.006122457944521946, 0.0676979273557663, 0.02460295713639685, 0.013509704315635775, 0.0073255734751001, 0.016552188333922198, 0.028003823843651583, 0.03257355533008065, 0.017397424139614617, 0.04843384998717478, 0.058577772096863816, 0.04738205285476787, 0.06712208182684012, 0.03112370241433382, 0.0695963054895401, 0.031100106359060322, 0.016681908962449858, 0.08987272317920413, 0.01890136138536036, 0.03977257778335895, 0.003750953881535679, 0.02932211390829512, 0.061435524108154435, 0.03608289773442915, 0.07273873008255448, 0.045004513646875105, 0.07858462817966938, 0.12201765472335474, 0.17275840842298099, 0.18891879197742256, 0.12193970462041241, 0.11001048902315752, 0.12402858824602195, 0.08182104344346694, 0.12249765039554664, 0.11486467426376683, 0.08373848162591457, 0.10715358518064022, 0.16092300707740442, 0.11403197608888149, 0.07698075460003954, 0.07493604360414402, 0.09695766693247215, 0.1559226382523775, 0.15506556709962233, 0.14474404523415224, 0.17188613808580808, 0.07063999412847416, 0.06547675654292107, 0.14079155160912446, 0.17982989682682923, 0.1442029271274805, 0.09951281268149614, 0.15521114000252315, 0.10643648223153182, 0.1561113659824644, 0.07688694034836122, 0.12838274746068887, 0.09943946983133044, 0.10695309843868017, 0.15477899461984634, 0.07637103660298245, 0.09296796244702168, 0.08892786995108638, 0.16302164803658212, 0.10916725998478276, 0.0836310356057116, 0.1513451188802719, 0.11313779585595642, 0.061443449397172244, 0.1127615278320653, 0.1727153214492968, 0.1025632211406316, 0.12267976919455187, 0.13523979165724345, 0.0880062836887581, 0.07169614067035061, 0.0713759535657508, 0.1228873466274568, 0.15217757278255054, 0.15091815750513757, 0.11099084998880114, 0.17047790650810513, 0.09827549050429038, 0.1442948007690055, 0.22652834600635938, 0.11427866428026132, 0.19160341577870504, 0.09350977265941245, 0.13933593114571913, 0.0793416832706758, 0.11164275250796761, 0.19149713005338395, 0.1755107364484242, 0.2633352338203362, 0.09648452446396862, 0.1470601838082075, 0.15267316118947097, 0.10601918319506304, 0.158238057579313, 0.09893175600362675, 0.14508842889751705, 0.07401512909148421, 0.16048079223505088, 0.1496029666491917, 0.13567357909466538, 0.12936271487602166, 0.18744216406983988, 0.11868901976517268, 0.18978975952735969, 0.2338414064475468, 0.180153829444732, 0.3437696705971445, 0.44299496763518875, 0.3586050516792706, 0.32251477826918873, 0.29196705030543463, 0.1399259716272354, 0.08309805991926364, 0.1553269930716072, 0.182903239769595, 0.13781077441360268, 0.21708765758999757, 0.20332341188830988, 0.22262508688228472, 0.17454976801361355, 0.16339944276426518, 0.1257823027138199, 0.17409509526831762, 0.27692371181079317, 0.30007790508014814, 0.20473865951810563, 0.18439554183610848, 0.229227748300348, 0.25463334790297915, 0.21451078514967645, 0.09719301001834017, 0.08908840455114841, 0.17500981475625718, 0.18921379186213017, 0.10674031664218221, 0.11065731610038451, 0.1749437932989427, 0.15110729235623563, 0.19719733989664487, 0.16540597938001156, 0.13803877575056894, 0.09972863431487765, 0.10750182292291097, 0.19637412764132023, 0.08880650039230074, 0.13599884164120468, 0.19039825616138323, 0.15874785450952394, 0.14869854732283525, 0.26525095530918663, 0.17211552363421234, 0.08110886665859393, 0.16658711885767324, 0.10596263408660889, 0.19100146022226128, 0.15434048457869462, 0.146672658888357, 0.1975682271378381, 0.0950511870905757, 0.08890151565096208, 0.08726668730378151, 0.11937723069318704, 0.17034632499728883, 0.14398827935968125, 0.245419656591756, 0.08512610609510116, 0.12265421556574957, 0.1614769087838275, 0.15130598098039627, 0.1333010678312608, 0.11628913639911584, 0.14382657089403697, 0.1087713415867516, 0.0813697362318635, 0.10821079023714576, 0.1588585642831666, 0.13555103567029747, 0.12376165256968566, 0.1401094746376787, 0.12833720419023717, 0.09793365813259568, 0.12232706669185843, 0.09319555666297674, 0.1311345055167164, 0.16721508944673197, 0.1735369595033782, 0.17151845352990286, 0.1147350605045046, 0.16741354736898625, 0.1041835288384131, 0.10964935233018228, 0.148418733051845, 0.09139206486621074, 0.1326265904520239, 0.17897401989570685, 0.11189781382147755, 0.23104448510067804], [0.043168723583221436, 0.024252658344006965, 0.072209119929799, 0.05632945309792246, 0.0757413696763771, 0.03965526586398482, 0.03854604770562478, 0.028046513874349848, 0.0788162596789854, 0.030426022530134236, 0.06429439570222582, 0.016560176387429237, 0.02987573741536055, 0.07082204507397753, 0.05536565177940896, 0.02090418811089226, 0.029746317038578645, 0.033581156084047895, 0.02967739145138434, 0.06274259289992706, 0.026829676669357077, 0.045365891219781976, 0.01985398553577917, 0.04708512253793223, 0.008913827178600644, 0.0429666728180434, 0.03883311890863946, 0.02844929226141955, 0.008150156371162405, 0.025341094671083347, 0.05741823038884571, 0.059101614701960764, 0.024383412042100514, 0.006206996622495353, 0.006777659840216594, 0.03941219765692949, 0.07197670811521155, 0.04033778388319271, 0.019599748642316887, 0.022478850757969276, 0.041169481218925545, 0.012756265816278756, 0.025026481731661727, 0.057370827932442935, 0.02124566425170217, 0.046725817889507325, 0.05948975708867822, 0.04161316848226956, 0.008302065094799867, 0.0073543391190469265, 0.0456814575009048, 0.034557279598500044, 0.005480586293353034, 0.053830103283481937, 0.02086432248220912, 0.006656571449379304, 0.03016748372465372, 0.01899407641030848, 0.04129808056833489, 0.036890439223498106, 0.043007049044328075, 0.018320835661143064, 0.030231605283915997, 0.019629470172471235, 0.04656799064416971, 0.022384585280503546, 0.06367975832628352, 0.03823881044185587, 0.00549946483390938, 0.04155056005609887, 0.033395882097205946, 0.06940607819706202, 0.033320076164922545, 0.02264798409305513, 0.007782734747576926, 0.035098492700074396, 0.16370874616716588, 0.052716495003551245, 0.028982761582093577, 0.03684713851128306, 0.062237681421850405, 0.038069916290364096, 0.0523393923815872, 0.026611848268657923, 0.06635063500808817, 0.08285588398575783, 0.2428236087518079, 0.18723858999354498, 0.15070885659328528, 0.014163056355235832, 0.04309156058090074, 0.030032160093209574, 0.0374592449516058, 0.08218184765428305, 0.09513219738645212, 0.07096705479281289, 0.007232072197699121, 0.025630617081852894, 0.04045518061944416, 0.03569428037319865, 0.0589693139440247, 0.05123131076938339, 0.04729296120681933, 0.08716959572796311, 0.04611231366704617, 0.043797206466219256, 0.04896566877141595, 0.021225055446848273, 0.025273076624476483, 0.055899872577616146, 0.022613490765382136, 0.04016968022499766, 0.013105183789905692, 0.01811047793099923, 0.046047689991870096, 0.02220925861703498, 0.04218851189528193, 0.05966540266360555, 0.0666769424985562, 0.054238320128726106, 0.04432094389838832, 0.05264065514451691, 0.056375450986836634, 0.0489391855496381, 0.014594270448599542, 0.04890692120950137, 0.023277140422058955, 0.009871268927651857, 0.015172097299780165, 0.02191921373430107, 0.05008186905511788, 0.04484541414837752, 0.026762812132281915, 0.023902195006875054, 0.03293180485655155, 0.048868736651326926, 0.05602751858532429, 0.013687997025304606, 0.011083893278347594, 0.03826077801308461, 0.05916844361594745, 0.024136496541489447, 0.04820101069552558, 0.03959178552031517, 0.06857918149658612, 0.08453818942819323, 0.02883698172601206, 0.045991585323853154, 0.036022531866495094, 0.016242257286129252, 0.036663079102124484, 0.02432527855437781, 0.07669365964829922, 0.06891435743974787, 0.012630842858925462, 0.0032856436155270785, 0.022141968299235617, 0.002369367313804105, 0.04864150884428194, 0.01820224300692124, 0.01825909915247134, 0.04191341683534639, 0.021468138920941522, 0.010217907871784908, 0.013297536593329693, 0.016593455137418847, 0.011297503735737076, 0.02910964084523065, 0.04354666419593351, 0.05088991266010063, 0.046322988612311225, 0.027213747845962644, 0.020120444541264857, 0.007648769034338849, 0.009313021204434335, 0.07087444154811756, 0.04700577126017638, 0.012090292177163064, 0.04410055233165622, 0.0020736655694366035, 0.03596165370462196, 0.030152847724301473, 0.009696230641566217, 0.0030759128941489117, 0.048325620259025266, 0.07569560927471944, 0.029114044537501674, 0.05085084600640195, 0.00473910867003724, 0.018684535520151258, 0.014208299373941762, 0.03701174771413207, 0.08353731634893588, 0.06549025260444198, 0.07647521886974573, 0.03073061690000551, 0.03970190157581653, 0.0346331092795091, 0.0418147646289851, 0.07046889473817178, 0.03641876917598503, 0.03923853001158152, 0.05962155573070049, 0.04446833866781422, 0.005044302695231246, 0.02257010353995221, 0.03866547665425709, 0.07114787080458232, 0.017525794483455162, 0.03426781316686954, 0.020047110172786882, 0.0454852149954864, 0.06300766939031226, 0.03475542539464576, 0.008301613020843692, 0.025576040813965455, 0.03301121720245906, 0.045240474199610095, 0.042739265199218474, 0.0499747758731246, 0.025119807438126633, 0.04635656591770904, 0.04508589035166161, 0.029358683553125178, 0.06950679314988, 0.036390477658382485, 0.04502991460529821, 0.03472040620233331, 0.05782640312931367, 0.014472631172143986, 0.022219889564439654, 0.016041187004053166, 0.14760500671608107, 0.01545049512891897, 0.0451863033563963, 0.0679788069267358, 0.02062763928967927, 0.025650467623823454, 0.024864157495488013, 0.06376041578395025, 0.049049756223601956, 0.04343840393370815, 0.12356628876711641, 0.043223440647125244, 0.01596499769948423, 0.01905898846286748, 0.062044773916048665, 0.05060565398473825, 0.02275106034773801, 0.03373645239376596, 0.015443212751831328, 0.04487849612321172, 0.10556071743901287, 0.04899684406284775, 0.02667849397818957, 0.04917822325868266, 0.11545822955667973, 0.0742360804496067, 0.06926169273044382, 0.009547617053613067, 0.016523798428741947, 0.06430785105164562, 0.1712459267250129, 0.11685510245817048, 0.13035287388733455, 0.10348434599914721, 0.028062420431524515, 0.02869497113195913, 0.08129013050347567, 0.07639960292726755, 0.03637147528518524, 0.024282793780522685, 0.04151997509013329, 0.015223849165652479, 0.02025418040076537, 0.041032376433057446, 0.09865929026688848, 0.06624322969998632, 0.07633181049355439, 0.04096054332330823, 0.06754448344664914, 0.06570182660860674, 0.03903131898758667, 0.04877631339643683, 0.0654629347845912, 0.020931120862119963, 0.02273027682011681, 0.051408140387918265, 0.06680050372545208, 0.05044637467446072, 0.01822050068793552, 0.016918938207839216, 0.05309782489868147, 0.04032210633158684, 0.08478181064128876, 0.02694451532858823, 0.01990536251105368, 0.03180942990417991, 0.01219766864752663, 0.009272483826082732, 0.05093546610857759, 0.03594964363479188, 0.010888748303321856, 0.04407285113951989, 0.08782199357769319, 0.02496989700011909, 0.038733455685100386, 0.04552171339413949, 0.003406330822534593, 0.08600100236279623, 0.03465743475992765, 0.026113442245072553, 0.04444977734237909, 0.0444720638250666, 0.07872627236481224, 0.013694763715778078, 0.02167060528881848, 0.022299125491242324, 0.051464940554329326, 0.016772459460688487, 0.05910881395850863, 0.014815589911969644, 0.09196006653032132, 0.014499759002189552, 0.058547428010829856, 0.03272306712876473, 0.04243932218690004, 0.028773246931710413, 0.01931160705031029, 0.05787356809845992, 0.037467770744115114, 0.0988264541540827, 0.02818545579378094, 0.025071008895922984, 0.026509306360302225, 0.0220594669226557, 0.002957606072803693, 0.06244275506053652, 0.06888290055628334, 0.017183363304606507, 0.02223624904373927, 0.0478592156432569, 0.02878700422921351, 0.009362153925134667, 0.03079564430351768, 0.025437373701216917, 0.023143938908885633, 0.012816017610020936, 0.052211088194910965, 0.03283756312781146, 0.03948767110705376, 0.0693426283874682, 0.09083639218338899, 0.08534975802259785, 0.1535191179386207, 0.08169413703892912, 0.14005585680050509, 0.10127620984401021, 0.11168707441538572, 0.22016968578100204, 0.1581610031425953, 0.19993583937840803, 0.12462948528783661, 0.15046599533941063, 0.04845593630203179, 0.07083485581512962, 0.19203998520970345, 0.07700064246143613, 0.13238850608468056, 0.23636118695139885, 0.20527702277260168, 0.1213167959025928, 0.15097668793584618, 0.15656964853405952, 0.10412239283323288, 0.1260639083172594, 0.15839958962585243, 0.10433209408074617, 0.08049468390111413, 0.09546316641249827, 0.0904107607368912, 0.06230331611420427, 0.13259970689458506, 0.1297634169459343, 0.037209812086075544, 0.1678026057779789, 0.07977617638451712, 0.11495994058038507, 0.15748569795063563, 0.12680884477283272, 0.07697856293192931, 0.0908497321818556, 0.15122961864939757, 0.17381880937942437, 0.07915800384112767, 0.20727912176932606, 0.09124274645000696, 0.11951844740126814, 0.20656724353986128, 0.1362695364015443, 0.16730312258005142, 0.0989483529701829, 0.2212447023817471, 0.15779122869883264, 0.1447582808988435, 0.19179944454559258, 0.08802273816296033, 0.09501491939382893, 0.2643222308584622, 0.09194243140518665, 0.10132078959473542, 0.15323596527533873, 0.12350957681025777, 0.10002788182880197, 0.13317372037896089, 0.19128856195935182, 0.11207991226443223, 0.07932818042380468, 0.20567837623613222, 0.13986285429980072, 0.10746447635548455, 0.10437583923339844, 0.16896268352866173, 0.19143707970423357, 0.11127600433038813, 0.13208187610975333, 0.13994388495172772, 0.10998996333884341, 0.29473951725023134, 0.08890564792922565, 0.11437532837901797, 0.12007908017507621, 0.18984850708927425, 0.08929092011281423, 0.20199189547981533, 0.20804393930094583, 0.11517853742199284, 0.3012108957128865, 0.45127757319382256, 0.3586978752698217, 0.27177976497582024, 0.21608376502990723, 0.1244762177978243, 0.18551990150340966, 0.1172630919941834, 0.16860030511660234, 0.1465766190418175, 0.15811392638300145, 0.08693541293697697, 0.08977409132889339, 0.09987377974071673, 0.14942873242710317, 0.15083438557173523, 0.17069423704275064, 0.10934591146984271, 0.10574132310492651, 0.12942622575376714, 0.15600053407251835, 0.10822031686880759, 0.12355608360043593, 0.10416740684637002, 0.09115021462951388, 0.2185647197599922, 0.20202859065362386, 0.14418478310108185, 0.1892109013029507, 0.13569360944841588, 0.20442831117127622, 0.13314628042280674, 0.10517561488917895, 0.17863852504108632, 0.1081542411286916, 0.0955956910869905, 0.1834226990384715, 0.11877759572650705, 0.10134746280631848, 0.09627190551587514, 0.12780953464763506, 0.08269501690353666, 0.21136882874582494, 0.14981139903622015, 0.1446393472807748, 0.1689321765942233, 0.14499906583556108, 0.04891572180869324, 0.12121326502944742, 0.14998294625963482, 0.23139561340212822, 0.13040375044303282, 0.2128572360213314, 0.1329937321799142, 0.06573701543467385, 0.1007550610229373, 0.12118372161473547, 0.1483084982527154, 0.10035795518862349, 0.15095245066498006, 0.22156297601759434, 0.1495759609554495, 0.11244615832609789, 0.1254035716078111, 0.07226456302617278, 0.14343338699213096, 0.06813923974654504, 0.18261866218277387, 0.13347508492214338, 0.1603105885109731, 0.15202294822250093, 0.1273963339626789, 0.13860702168728622, 0.0928178501448461, 0.0963349821312087, 0.08986608710672174, 0.17070588070367063, 0.1450903695076704, 0.10529146795826298, 0.0787334173385586, 0.10723619681916066, 0.17038859772895062, 0.10903464031538793, 0.12049665062555245, 0.11439565728817667, 0.1558036503515073, 0.14478661652122224, 0.14024117828479835, 0.08371098060160875, 0.09550997854343482, 0.1306164711713791], [0.015076303422184927, 0.05442780103268368, 0.039353087078779936, 0.02857477543875575, 0.03228987001680902, 0.02384909285631563, 0.061321218098912916, 0.050205318323735676, 0.02082678083596485, 0.03054666266377483, 0.08391511786196913, 0.043167298659682274, 0.05979283832545791, 0.011067508353984781, 0.05144543267254319, 0.04570746574816959, 0.026196220124672567, 0.038176595565996, 0.015521410520055463, 0.05007459515971797, 0.005849274232917066, 0.014408104188208069, 0.04924428203542318, 0.04235631699806877, 0.01598163028912885, 0.008657011852067496, 0.06571336170392376, 0.03230530329580818, 0.021994812713403786, 0.044043582531490495, 0.08219365416360752, 0.03206287291167038, 0.05545044830068946, 0.06766262996409621, 0.033325165177562406, 0.027390017673107128, 0.02163559288185622, 0.06822538655251265, 0.012776250368915498, 0.03428380623725908, 0.025362855289131403, 0.067701591444867, 0.0459900043372597, 0.04299668442191822, 0.03857406780921987, 0.02876214270613023, 0.031768317467400005, 0.03697724760110889, 0.014001254591026475, 0.03007872455886432, 0.05749572587332555, 0.08038115820714406, 0.007076362829788455, 0.06008086287017379, 0.07884519241218056, 0.11205022635736636, 0.08189841679164342, 0.0358690099258508, 0.04832027679575341, 0.052150986955634186, 0.038068511722875495, 0.0424790979096932, 0.08621894102543592, 0.12475368433765002, 0.008282786218582519, 0.024412563602839197, 0.10680178512952157, 0.03932994564196893, 0.066605255273836, 0.031306523497083356, 0.031679775432816575, 0.02280901063100568, 0.024472839564883282, 0.021663411121283258, 0.03657641660954271, 0.020828655288953866, 0.04097140666895679, 0.03585990737857563, 0.03429531758385045, 0.016405539953016808, 0.05660902648898108, 0.022083427690501724, 0.0401672985670822, 0.030598380602896214, 0.01794769398735038, 0.08826022541948728, 0.03799055144190788, 0.1513232429112707, 0.080557299112635, 0.03310490253248385, 0.014792058317522918, 0.04547097593812006, 0.02720731363764831, 0.04501022691173213, 0.05543140860806618, 0.051347845766161165, 0.08356128899114472, 0.03192577491115246, 0.047214797365346124, 0.018514713472021476, 0.05669450493795531, 0.018421900059495653, 0.07250734964119536, 0.030496702130351747, 0.049242609446602206, 0.00704008834769151, 0.0459153044170567, 0.017247566288071017, 0.047425166969852786, 0.02277574545171644, 0.006172761986298221, 0.035504317709377835, 0.0644914965544428, 0.006469724109462861, 0.06777467645172562, 0.07799988027129855, 0.04064717210297074, 0.014218126257349337, 0.0600158456446869, 0.018027793349964277, 0.014911261653261525, 0.055392857640981674, 0.016732149391568134, 0.03882763634568878, 0.010512077399263424, 0.03902286444125431, 0.05404841174770679, 0.016546346147411635, 0.061809356191328595, 0.042447410324322324, 0.03793861297890544, 0.014256689098796673, 0.018798045947083404, 0.040519017193998606, 0.03279663389548659, 0.0399734139708536, 0.0448619907588831, 0.04024898400530219, 0.015505911083891988, 0.020885380816512873, 0.07673304860613175, 0.0717781823394554, 0.051517635583877563, 0.01545092260598072, 0.0464195441454649, 0.0684005639382771, 0.02416593987228615, 0.01338396075048617, 0.06858030786471707, 0.05504567502066493, 0.01615361516763057, 0.05983900584812675, 0.026546201701941233, 0.035582607079829486, 0.07880839545811925, 0.015557004770796214, 0.0729879763509546, 0.029792440456471274, 0.07290644358311381, 0.05085715298940029, 0.04298523075080343, 0.03994226921349764, 0.023260658806455985, 0.008082690482426966, 0.012019099434837699, 0.027235625511301414, 0.04362251762566822, 0.00528848751647664, 0.043051761109381914, 0.06793758592435292, 0.006172502870737974, 0.039923137918646844, 0.02477120328694582, 0.034609703214040825, 0.03424477351031133, 0.06886798635657344, 0.07185176267687764, 0.09186391811817884, 0.020904583357540623, 0.07905040854322058, 0.05206884350627661, 0.024408478822026933, 0.015161401891548718, 0.004414767234785748, 0.049697411113551686, 0.05642555061993854, 0.041359810291656425, 0.06766841108245508, 0.05438550794497132, 0.029723701466407095, 0.06170471930610282, 0.04877236771530338, 0.017985188136143342, 0.039240911669496975, 0.03941144448305879, 0.04876794705965689, 0.04712149540760687, 0.029533331681575094, 0.019703043724543283, 0.025089989216732125, 0.06348517483898572, 0.024745405385536805, 0.03424326716256993, 0.03336999598624451, 0.044520833529531956, 0.05082249002797263, 0.06933329853096179, 0.05491808329575828, 0.059906235097774437, 0.04624459746160677, 0.010447628446854651, 0.05091937804328544, 0.03668926716116922, 0.010367883618787994, 0.023098760351006473, 0.021126963031877364, 0.047174729872494936, 0.028554015659860203, 0.010517946727174734, 0.0180268773276891, 0.019263130812240497, 0.04049300555405872, 0.051358624294932397, 0.013507455820217729, 0.08084704035094806, 0.02362527808041445, 0.03620333091488906, 0.053054914344102144, 0.04289528075605631, 0.03687198307099087, 0.04119680243145142, 0.022306996497458646, 0.07955188663410288, 0.06531707011163235, 0.04745475109666586, 0.01113392336161009, 0.023708690390256897, 0.03407983182530318, 0.06130235482539449, 0.03900875091286642, 0.036144752986729145, 0.004113668592513672, 0.022731795042221035, 0.07467383053153753, 0.031606347765773535, 0.07011584618261882, 0.04064805080581989, 0.011290327379746097, 0.005547801548215959, 0.06932476934577737, 0.06511409993150405, 0.02306627548698868, 0.041871669968324046, 0.016822991659864783, 0.046866725864154954, 0.010467959900519677, 0.0697681987658143, 0.06671166313546044, 0.010272017646847027, 0.1774812021425792, 0.05743418274713414, 0.060015764220484664, 0.07347788541976895, 0.07771969959139824, 0.10786504271839346, 0.03425011358090809, 0.009135716611386409, 0.026986024708354046, 0.08656553671296154, 0.1304277027291911, 0.028527379767703157, 0.05902275536209345, 0.061374700229082785, 0.016656265427757586, 0.0809706219338945, 0.06107379708971296, 0.11149152062301125, 0.047256517090967724, 0.030839162146938697, 0.01927750388027302, 0.05059078728247966, 0.04714429757690855, 0.026678689057007432, 0.08536584608789001, 0.01992586614297969, 0.05061623573835407, 0.008950335755279022, 0.04515888714896781, 0.09138450598610298, 0.0356904873624444, 0.030382575932890177, 0.058789821075541634, 0.07041427945452076, 0.026230063755065203, 0.025680664128490856, 0.08775790594518185, 0.038644496351480484, 0.06335483504725353, 0.003578075881315661, 0.06291082887245075, 0.029798876361123154, 0.05345649511686393, 0.030288697220385075, 0.007876415836757846, 0.0431756683891373, 0.014638497361115046, 0.01994581167985286, 0.03558987079720412, 0.024776612907381992, 0.03643890130998833, 0.03611366590484977, 0.03284714404227478, 0.033453533825065405, 0.04255801831771221, 0.05070702372384923, 0.06077798296298299, 0.006185279261054737, 0.021393009827339222, 0.08213540871760674, 0.020239225488954356, 0.04320246034434863, 0.09819613583385944, 0.036971381665872674, 0.018035898450762033, 0.026630582620522807, 0.07603023560451609, 0.05916418241603034, 0.04407000807779176, 0.05164137322987829, 0.018037187667297463, 0.0006481166118257013, 0.01899944362230599, 0.008194125440370823, 0.04108693064855678, 0.040023618776883395, 0.029818696369017874, 0.04501920732270394, 0.013444772755194987, 0.04122566391846963, 0.04900122739906822, 0.04321905391822968, 0.00920474313066474, 0.02359901538251766, 0.029482994561216662, 0.020406458925987993, 0.023546873359009624, 0.043384083812790256, 0.017145348380186727, 0.014463469253054686, 0.011091331718489528, 0.01477706608628588, 0.03654453903436661, 0.1596761175564357, 0.1562655834215028, 0.12114706715302807, 0.21035165047006948, 0.1170194572103875, 0.09447661720748458, 0.15667833627334662, 0.06828688218125276, 0.11035247067255632, 0.21351158805191517, 0.20136349062834466, 0.1949070535068001, 0.17177670395800046, 0.08594404613333088, 0.11628342313425881, 0.19735477359167167, 0.04440794905115451, 0.09970949284200158, 0.05336212446647031, 0.08671380339988641, 0.13052894015397343, 0.19559404307178088, 0.2179945603545223, 0.12739257487867559, 0.1436291579157114, 0.07001627795398235, 0.154778655352337, 0.07815409771033696, 0.10460151319525071, 0.17118793912231922, 0.19990259116249426, 0.20087607178304875, 0.13435635263366358, 0.14302984864584037, 0.13921475836208888, 0.11431609227188996, 0.11604909785091877, 0.11555205737905842, 0.06431011735860791, 0.09212858748755284, 0.12966718710958958, 0.13905393199196883, 0.1265813862638814, 0.09661524423531123, 0.10705764711435352, 0.10616099701396056, 0.15022210271230765, 0.06791347757514034, 0.1385492105036974, 0.04538451022069369, 0.14047392936689512, 0.15667307084160192, 0.13813820827220166, 0.15672972851565906, 0.15479768147425993, 0.18037530327481882, 0.15991492117089884, 0.13798233520771774, 0.14165714516171388, 0.14353978128305503, 0.07993713167629071, 0.14683067612349987, 0.19822755961545876, 0.2040706825043474, 0.13140819940183843, 0.062229545786976814, 0.19548216621790612, 0.18557144302342618, 0.22117219412965433, 0.18409694571580204, 0.16361007360475405, 0.17086628638207912, 0.14109268545040063, 0.11795846825199467, 0.10916732105293445, 0.20509877162320272, 0.16096418058233602, 0.09569371225578444, 0.08664118658219065, 0.07470825261303357, 0.14671331670667442, 0.16339558868535928, 0.1992643746946539, 0.13289876441870416, 0.1546667106449604, 0.10953520916934524, 0.19800657433058533, 0.22239316361291067, 0.2970484090702874, 0.11602762900292873, 0.0731942577819739, 0.10038282349705696, 0.1325878325317587, 0.1917510921401637, 0.15358375518449716, 0.1917529377554144, 0.18729063362947532, 0.1419820412993431, 0.17314933958862508, 0.11568138615361281, 0.16666295193135738, 0.10034833356205906, 0.22807437447564943, 0.13397508380668505, 0.09199539784874235, 0.18467858593378747, 0.10923691160444703, 0.1435554147298847, 0.12357975090188639, 0.22922641837171145, 0.056934116009090624, 0.12311154816831861, 0.1513100793319089, 0.09261696985257523, 0.26480722054839134, 0.18316155805119447, 0.11632923781871796, 0.15636268178267138, 0.1280005829674857, 0.1808716652116605, 0.14395048495914253, 0.12796012870967388, 0.08954543859830924, 0.16665487736463547, 0.08318119402974844, 0.10852544049599341, 0.0792739586904645, 0.10951694979199342, 0.1334778940571206, 0.16271675511130265, 0.06918500470263617, 0.11977521862302508, 0.29053585710270063, 0.09425524515765053, 0.15420958160289697, 0.11332745317901884, 0.11266188496457678, 0.1350129438298089, 0.227849969374282, 0.10885235188262803, 0.14172166027128696, 0.14146670752338, 0.18297696938472136, 0.08685187849083117, 0.1321095467678138, 0.1820199635944196, 0.1606769702796425, 0.11744679856513228, 0.17765021164502415, 0.17258060510669435, 0.13006712922028132, 0.13237619745944226, 0.16642247912074837, 0.1367585023066827, 0.2554968515677111, 0.13252717150109156, 0.1983622895287616, 0.14738356002739497, 0.10397941193410329, 0.11427149895046439, 0.13878565281629562, 0.09870512530739818, 0.09933851739125592, 0.1498649354491915, 0.06248897008065667, 0.06324373850865023, 0.13128186975206646, 0.12515362644834177, 0.09058333254818406, 0.08514196345848696, 0.10862033361835138, 0.13079720575894627, 0.09872380537646157, 0.08018343988806009, 0.1066656167219792, 0.2161273948316063], [0.045067264565399716, 0.0635534558179123, 0.012088952918670006, 0.06159452521907432, 0.005455699325206557, 0.03332339420116373, 0.06264758442661592, 0.025970837932878306, 0.0728606628254056, 0.06745360046625137, 0.041846079020095725, 0.01812042695071016, 0.03193513530173472, 0.020109118095466068, 0.039348316977598836, 0.03999379037746361, 0.019282898233671273, 0.026562766438083987, 0.09262606900717531, 0.02014824072830379, 0.039605878692652495, 0.03789722573544298, 0.07958438846149615, 0.025302055158785412, 0.058489827173096795, 0.03649511793628335, 0.052928693259933164, 0.03145940422213503, 0.014975040552339383, 0.05626857154337423, 0.05862131368901048, 0.048719245208693404, 0.020857654179313352, 0.02047057369990008, 0.048303486446716955, 0.042656059842556715, 0.013616839057898946, 0.03894645122012921, 0.01255541860259005, 0.02241670203927372, 0.027531108852209787, 0.024307143009666885, 0.03890712333044835, 0.06617281133575098, 0.02096998056263796, 0.04783985025382467, 0.012987787053654236, 0.06422631149845463, 0.025988893749724542, 0.019589272061628953, 0.04105428972148469, 0.03275955534939255, 0.06542102167648928, 0.07609812303313188, 0.026467759661110382, 0.015497027364160334, 0.03786080536831703, 0.014664883891652738, 0.016260209626385143, 0.04290031887856977, 0.05060281092301011, 0.010834250066961561, 0.028937370982021093, 0.04967184391404901, 0.020093150470139723, 0.0874005826190114, 0.0053236890650753465, 0.04966538765334657, 0.056609806804252524, 0.045336442799972634, 0.01655193218695266, 0.03387287864461541, 0.017831605127347366, 0.05722589963780982, 0.018785012985712717, 0.10610869553472314, 0.0191653844501291, 0.033384038268455436, 0.03212975271578346, 0.00939402641129813, 0.0118894118848922, 0.01419508914529745, 0.10135897754558496, 0.061070105859211514, 0.02383761713281274, 0.08598658349364996, 0.08800375275313854, 0.09548755296106849, 0.03509315262947764, 0.00830409221816808, 0.07188071576612336, 0.038053003805024285, 0.06510435616863625, 0.03865409762199436, 0.04403902616884027, 0.04355056577229074, 0.029716648094888245, 0.05070405174046755, 0.07203173051987376, 0.10549426850463663, 0.009364923196179526, 0.04759531641112907, 0.04620368519265737, 0.010150655721580344, 0.08290167831416641, 0.05388505444196718, 0.07553521038166114, 0.07661300219063248, 0.06126956122794321, 0.03546863355274711, 0.03248510829039982, 0.027411289745941758, 0.025411345097901564, 0.03056281858256885, 0.022414520549188768, 0.046202531683125665, 0.02486481228178101, 0.014424740170527781, 0.02214086228715522, 0.022844989950369512, 0.037948224427444596, 0.04511558643675276, 0.0027714625009269056, 0.008833026380411215, 0.060839682152228694, 0.020692429205934917, 0.054648148494639566, 0.03801997611299157, 0.05418356913807137, 0.06815960258245468, 0.027501580704535757, 0.01995347742922604, 0.12279571725853852, 0.05208171531558037, 0.022266060479783585, 0.02616752657507147, 0.043956160079687834, 0.017411500348576477, 0.013750620718513216, 0.03461313660123518, 0.026215407398662398, 0.018764470338023136, 0.03242802992463112, 0.018362358611609255, 0.03880030156246253, 0.07559173913406474, 0.020622911596936837, 0.05600784106978348, 0.04214628666107144, 0.06193549585129533, 0.05148941531245198, 0.04958180231707437, 0.019629183491425853, 0.05511528932090316, 0.006450158552200134, 0.04412529171843614, 0.019607695983722806, 0.031174229524497474, 0.042827121913433075, 0.11726799101701804, 0.01088809606153518, 0.08573854501758303, 0.05871062246816499, 0.028321408766454885, 0.0787319652736187, 0.01755595875770918, 0.04705664442319955, 0.04368162141846759, 0.07729065511375666, 0.01545858326634126, 0.048514303884335926, 0.028402966979358877, 0.04657048426036324, 0.023429658130875657, 0.03431872704199382, 0.03649739781394601, 0.02331609002846692, 0.034163837853286944, 0.04908178307648216, 0.039084852007882934, 0.012338447700520712, 0.04664160151566778, 0.04173264492835317, 0.007491583852762622, 0.017732634009527307, 0.028617601176457744, 0.012993185647896357, 0.025607950619554946, 0.023740048886143734, 0.031143539385604005, 0.009788720053620636, 0.0533929537050426, 0.050034354640437026, 0.05574799608439207, 0.10974485613405704, 0.056421401378299506, 0.05435104515137417, 0.023202102930684174, 0.047163971699774265, 0.03428760264068842, 0.07187988795340061, 0.016014780117464916, 0.03921415024836149, 0.04955566514815603, 0.029631909249084334, 0.005846392579509744, 0.009444444955858802, 0.007258545241451689, 0.007570703580443348, 0.07854449961866651, 0.05488577485084534, 0.0378915430046618, 0.05029018948386822, 0.039128478416906934, 0.061818407848477364, 0.03339890157803893, 0.02310840572629656, 0.03766754163163049, 0.061821698743317804, 0.046577395139528174, 0.02062174621304231, 0.06852850850139346, 0.014316050734903132, 0.040102417048599036, 0.015712346881628036, 0.056651821692607233, 0.05000642274639436, 0.06930282552327428, 0.05250754692990865, 0.04426823190546461, 0.03799392036827547, 0.020557577156328728, 0.07109307231647627, 0.028578276679451977, 0.06808492980365242, 0.018400889222643206, 0.04135256353765726, 0.026196350742663656, 0.042396968031036, 0.07742526967610631, 0.03033794868471367, 0.06602482284818377, 0.028652939280228953, 0.026961811186213578, 0.008175753256572145, 0.023953192002539123, 0.02130894103486623, 0.06067802118403571, 0.03827482368797064, 0.03522128378972411, 0.03127967047372034, 0.0476285849830934, 0.07229453391794648, 0.010132307286507316, 0.029704115553093807, 0.04832063641931329, 0.027361088332587054, 0.0663860138239605, 0.02802043268457055, 0.052070465204971175, 0.014197693871600288, 0.00715054536703974, 0.02794633326785905, 0.10873727234346525, 0.03277364852172988, 0.004047072076770876, 0.0548446250946394, 0.022370218997821212, 0.0387531773054174, 0.05162933601864746, 0.04010085641805615, 0.03702732687816024, 0.05118334173624005, 0.008151996897400489, 0.021708381029644182, 0.007406212273053825, 0.03955724469519087, 0.023136242625436614, 0.08587881856198822, 0.03135140519589186, 0.04943142199356641, 0.027962613019293973, 0.003045318174242441, 0.008596904675609298, 0.031219962784754376, 0.05863709641354425, 0.015501269904364432, 0.038270362320223024, 0.044549508419420035, 0.01914100468690906, 0.022250342216076593, 0.07933373762560741, 0.017726527194359472, 0.045138422532805374, 0.05913706137133496, 0.013542914363954748, 0.01540936403242605, 0.05240885740412133, 0.027010222963456596, 0.01963717833028308, 0.018244056031107903, 0.046973998857928176, 0.014122943909439658, 0.01739911369181105, 0.046979274467698166, 0.05163576174527407, 0.06360554016594376, 0.017890829360112548, 0.047267458468143425, 0.07558660940932375, 0.042547986177461486, 0.010165462203856026, 0.01937945037414985, 0.040935257715838294, 0.035160510800778866, 0.04150494893214532, 0.02508186036720872, 0.011508556116106254, 0.017768986523151398, 0.037545632637505016, 0.04133505394150104, 0.03839615253465516, 0.029995054405714785, 0.06919244144644056, 0.029313737393489907, 0.035543207943971665, 0.034448927734047174, 0.016641276589195644, 0.04033847259623664, 0.03528104915416666, 0.029484307526477745, 0.02662925947723644, 0.005818548046850732, 0.025289999287841574, 0.028215827021215643, 0.04671036086178251, 0.03114265389740467, 0.021374423056840897, 0.017872391867318323, 0.03169700682961515, 0.04590358950995973, 0.043842739558645656, 0.025617390738001893, 0.021267170419118235, 0.05984419664101941, 0.036018664216888804, 0.033385178207286766, 0.030456414113619497, 0.06855575846774237, 0.054780293189521344, 0.0456870791635343, 0.018553143999140178, 0.11116732337645122, 0.12917250793959412, 0.11763011158577033, 0.11863589047321252, 0.057881846225687435, 0.14656933157571725, 0.14398617590112345, 0.10158602893352509, 0.11844192445278168, 0.14572919665702752, 0.12286452070942946, 0.21345174126327038, 0.11227771879306861, 0.09485154173203877, 0.1057181375633393, 0.12492475658655167, 0.15219737243439468, 0.12399084812828473, 0.15031160148126738, 0.17399433281804833, 0.1496822873928717, 0.13337702304124832, 0.18214853240975312, 0.11177873092570476, 0.12686616741120815, 0.17342268063553742, 0.21073198291872228, 0.07289779226162604, 0.0570772597566247, 0.11082441891942706, 0.09062762052885123, 0.14384907111525536, 0.09918451029807329, 0.1862274371087551, 0.172566220164299, 0.1132546802982688, 0.17019072334681237, 0.11049775180539914, 0.12147865364594118, 0.11427768718983446, 0.0976815213050161, 0.15650864823588304, 0.1230436810957534, 0.160486763343215, 0.057892132816570144, 0.1780468967876264, 0.20118312244968756, 0.123335261163967, 0.06898716424724885, 0.09271325397172145, 0.17219686641224793, 0.12693676219454833, 0.19992248580924102, 0.12432974922869887, 0.07781150537942137, 0.0756783609145454, 0.16084637333239826, 0.1239042127771037, 0.12521321539367947, 0.12491266509251935, 0.17751974293163844, 0.07641744839825801, 0.16226552932390145, 0.1685661476637636, 0.1915401356028659, 0.19210189474480494, 0.12314056232571602, 0.0992865687502282, 0.10592354368418455, 0.14459007206772054, 0.06625209815268006, 0.2025492712855339, 0.15762961522809096, 0.13228969781526498, 0.08965676583881889, 0.21320555518780435, 0.17705303297511168, 0.07296231415654932, 0.17439413922173636, 0.11088168727500097, 0.09320831990667752, 0.09843128214457206, 0.19080800988844462, 0.10764977069837706, 0.09763746402625527, 0.19166164765400545, 0.27870549048696247, 0.30258503769125256, 0.13682233888123715, 0.15519507229328156, 0.19706881179341249, 0.12317455693015031, 0.1746685794953789, 0.1256318443587848, 0.09662803462041275, 0.15959769247898034, 0.19106011278927326, 0.07912502703922135, 0.12758260539599828, 0.23906637036374637, 0.21919392528278486, 0.09701824653893709, 0.17029873255108083, 0.07195034702973706, 0.14045856733407291, 0.0975642500977431, 0.1445125833685909, 0.14515835871653898, 0.20899206985320362, 0.18270778097212315, 0.12890424233462128, 0.15854210912116937, 0.1345661420907293, 0.18627349606582097, 0.1314287997250046, 0.15583484939166478, 0.0789786602503487, 0.1612302070217473, 0.19774064288607665, 0.17065952319119657, 0.21005815693310328, 0.1474261584558657, 0.15746625113700116, 0.14592412619718484, 0.08770599801625524, 0.12612465077212878, 0.1328387004988534, 0.16663657048983233, 0.1417329239525965, 0.21107465667384012, 0.11275943115885768, 0.14554903203887598, 0.22846016234585217, 0.18023005606872694, 0.0886992850740041, 0.13701451356921876, 0.071836312434503, 0.18384150442268166, 0.08239714003035001, 0.1066043246537447, 0.14854792611939566, 0.08078224704201732, 0.0887629452294537, 0.1092475646042398, 0.11418148449489049, 0.17293465110872472, 0.07915555432971035, 0.17679228553814547, 0.16478123861764157, 0.16463472933641501, 0.11768767849675246, 0.144922798499465, 0.19926600317869866, 0.10513372892247778, 0.12243344741208212, 0.1953697329653161, 0.11445661687425204, 0.1556382370846612, 0.15603957697749138, 0.1672855620937688, 0.11729197044457708, 0.11389607909534659, 0.10387381831450121, 0.1145605548684086, 0.12283433947179999, 0.16049367082970484, 0.17027733155659266, 0.16192516258784703, 0.13971927628985473, 0.08456721037094082, 0.2743791240666594, 0.1464146798742669, 0.13301308399864606, 0.2084930209176881, 0.1603003019200904, 0.0763486178059663], [0.03424944522391472, 0.014748828851484826, 0.08599950280040503, 0.023420399520546198, 0.058772199521107335, 0.030515989488256828, 0.08215087931603193, 0.036680279964847226, 0.0034277171861114247, 0.04563016364617007, 0.043598266784101725, 0.05076108600146004, 0.060152217612734864, 0.03906485897355846, 0.011728461682131248, 0.012127687090209551, 0.04348199302330613, 0.03892095187412841, 0.020318330797765936, 0.02607311012356409, 0.026189368617321764, 0.025952106973688518, 0.09130298000361238, 0.04475896878700171, 0.04112097614311746, 0.02718832653148898, 0.025520053193239228, 0.061897959294063706, 0.05403901403769851, 0.02947203961334058, 0.018128452323643223, 0.017161940257730227, 0.018962680594995618, 0.02285091865009495, 0.026691784782867347, 0.11415629727499825, 0.014841352190290178, 0.023454794460641484, 0.001148762331078095, 0.0108682938651847, 0.034581672932420454, 0.05265088066724794, 0.014176093557450389, 0.0411234154765095, 0.012349418763603483, 0.07469707714127642, 0.03010805762772049, 0.02971992202635322, 0.04457170329988003, 0.05868188651012523, 0.013609044386872222, 0.035921945835330656, 0.035728939941951206, 0.02955575387126633, 0.030871589335479906, 0.0699732791898506, 0.029496209030704837, 0.050030286823000224, 0.011104050009245319, 0.03372622347835984, 0.02040597716612475, 0.02315127556877477, 0.049275270729724846, 0.01371919606546206, 0.01817170893108206, 0.1360175692077194, 0.02355923457071185, 0.008874597676497484, 0.012995400216563471, 0.03570012255970921, 0.05981698738677161, 0.00845952593122742, 0.03548343240150383, 0.06568115164658853, 0.004149798461834767, 0.022214546101167798, 0.04662079763199602, 0.02097877437647964, 0.06177679329578366, 0.03421203758833664, 0.011654561585081475, 0.02294065320997366, 0.037291283785764656, 0.011690511218538242, 0.06339529609041554, 0.09914701445294277, 0.08538952017469065, 0.047464321833103895, 0.09028837337557759, 0.060813436417707374, 0.014086427699242319, 0.050468162433909516, 0.022777831946898783, 0.023786974671695913, 0.01593434318367924, 0.07813887138451849, 0.029590338801166842, 0.014183192730082997, 0.04409535814608846, 0.09427410843116896, 0.07209440001419612, 0.03200495655515364, 0.022784094825120907, 0.013057855972354966, 0.030033408597643887, 0.03485901394326772, 0.05584521658186402, 0.04912416776642203, 0.032562776801309416, 0.064621836346175, 0.04328107541160924, 0.01842822739854455, 0.024314301554113626, 0.07744293194264174, 0.05818920223308461, 0.020601527565824132, 0.04772636866463082, 0.047383148688822985, 0.031918012470539124, 0.015266038776774491, 0.10065193727080311, 0.016500058184776987, 0.00744840273234461, 0.06866633931973151, 0.04443903274035879, 0.08089579309203795, 0.053546458682311435, 0.016685031919873188, 0.032853040511586835, 0.026802613300138285, 0.031082800323409692, 0.06622671415763241, 0.08690544883055346, 0.09517075853156191, 0.05282901307301862, 0.05684720245855195, 0.08996640172387872, 0.030645345404211963, 0.043533951842359135, 0.01878824790141412, 0.027299080409907868, 0.034894467397992096, 0.02611478235173438, 0.019514680707028935, 0.04562593637300389, 0.013949032839653748, 0.03834256862423249, 0.006651049446580666, 0.0314653414035482, 0.036918642531548224, 0.05747470485844782, 0.07290031641189541, 0.048400113226047585, 0.023102609340899756, 0.02079677941011531, 0.08075616415590048, 0.03866644695933376, 0.029927550349384546, 0.022233955595376234, 0.03630348268364157, 0.06811948759215218, 0.032291118521243334, 0.08828332275152206, 0.06025603347058807, 0.04328041723264115, 0.022653337734352266, 0.0744227793599878, 0.022097890664424216, 0.01860545396006533, 0.03001540367092405, 0.0743120831570455, 0.029964737461081574, 0.05673958341191922, 0.06384675257972308, 0.10376411277268614, 0.09625834160085235, 0.023212420055642724, 0.04752098289983613, 0.027046556817367673, 0.020208523475698063, 0.05666561970221145, 0.028668437020054886, 0.023803234067080275, 0.004980503016018442, 0.01648976480854409, 0.0715908727475575, 0.01828757726720401, 0.03771644365042448, 0.028868452180176973, 0.03865253359877637, 0.04147463198751211, 0.030905556798513447, 0.022104201040097644, 0.0632445120385715, 0.04729417578450271, 0.043560740404895375, 0.05486067923318062, 0.031493395433894227, 0.06781483893947941, 0.0584768196567893, 0.0300590538286737, 0.025381535358194793, 0.016386364553389803, 0.030606061619307314, 0.02943159214087895, 0.019789349986240268, 0.028118723571034412, 0.053420868635709794, 0.013542048383637198, 0.033693647012114525, 0.030886727451745952, 0.09227601957640477, 0.03030664107895323, 0.024219014881444827, 0.010747814035442258, 0.015884679509326816, 0.007502176632572497, 0.06135115506393569, 0.05218669825366565, 0.12022313315953527, 0.009896504493164164, 0.038257364981940815, 0.04616487977494087, 0.026813084791813577, 0.0313802497195346, 0.06013087768639837, 0.030886897085500613, 0.052123933764440675, 0.08572403115353414, 0.05619292167414512, 0.03319648779662592, 0.028198497236839364, 0.05893981124141386, 0.01578046501215015, 0.056412943439292054, 0.02727965055964887, 0.09212894711111273, 0.14071094164890902, 0.05254690535366535, 0.010518098549385155, 0.023150524091241614, 0.05679789331874677, 0.025224590208381414, 0.009651105518319776, 0.02601071882859937, 0.03344332865838494, 0.048364921007305384, 0.028933031750576835, 0.006558128740705017, 0.0348618332562702, 0.019777082073103105, 0.050252873450517654, 0.038237870670855045, 0.03716844519866364, 0.06325965694018773, 0.036670305500073094, 0.049580764158495834, 0.03863106814346143, 0.025865537779671804, 0.04979510319286159, 0.0784231639866318, 0.09193274192512035, 0.05079176935500332, 0.04013501047821982, 0.031242978692586933, 0.052516476450754065, 0.03448702747534428, 0.01705304386892489, 0.04446844044806702, 0.028331917577556202, 0.012132707401178777, 0.07556944247335196, 0.043484374681221585, 0.06666892221463577, 0.09112725978983299, 0.03423297039366194, 0.051056720316410065, 0.01557027013041079, 0.03472369709717376, 0.028874827016677176, 0.07347713903124843, 0.017230440064200332, 0.03207016716312085, 0.000969636719673872, 0.02159826327780528, 0.04514625282692058, 0.01510708685964346, 0.01999475441074797, 0.04662007838487625, 0.03508901695853897, 0.049252712833029885, 0.07014610205910035, 0.011952126332159554, 0.036923945282718966, 0.07541784417948552, 0.0021625816464490655, 0.04320601247517126, 0.06386665401182004, 0.020618675842082927, 0.010311517714788871, 0.01532724263545658, 0.041561555716076067, 0.017842119027461325, 0.02954166748427919, 0.05446174813966666, 0.019869269537074224, 0.03543270851618477, 0.05211889224925211, 0.055604516462023766, 0.09525735995599202, 0.013465905728350793, 0.0693693830232535, 0.0365469512263579, 0.04461342981085181, 0.009766852566307145, 0.02866120383675609, 0.06035971362143755, 0.048011570503669124, 0.03373340916420732, 0.05689376013885651, 0.07017246992992503, 0.02481596963480115, 0.01857912171232913, 0.015438890483762537, 0.05515648318188531, 0.00902708909208221, 0.010790566830629749, 0.011552827133397971, 0.059667560404964855, 0.019414148958665983, 0.02529691525601915, 0.02525221336899059, 0.01332104783172586, 0.011836399640222746, 0.039070209222180505, 0.033614380551236014, 0.062151683893586905, 0.03257881058380008, 0.05050899327865668, 0.029305262491106987, 0.008833531889000108, 0.039606326525764804, 0.07407543728394167, 0.0029674813018313474, 0.023704103493530835, 0.05660495188619409, 0.012048693739676049, 0.05687784170731902, 0.008751954168214329, 0.056010863943291564, 0.019370351219549775, 0.0708909910172224, 0.1258014238306454, 0.18878400778131826, 0.24460161477327347, 0.1041331272572279, 0.1482707309935774, 0.0783254685146468, 0.21049745407487663, 0.06615822283285004, 0.14143389356987818, 0.20833071534122738, 0.06372036864714963, 0.16878853073077543, 0.15570737980306149, 0.15166518384856836, 0.1262579693325928, 0.08468907526029007, 0.07631918974220753, 0.17895054258406162, 0.07475157028862409, 0.07824361004999705, 0.16167718517993176, 0.0938114154019526, 0.21396594867110252, 0.11570315355701105, 0.1641317991805928, 0.09104930290154048, 0.19372794963419437, 0.10156158810215336, 0.16939332256359713, 0.14830681548586913, 0.0699001873976418, 0.11114429389791829, 0.1052623927327139, 0.13711925223469734, 0.09141898235040051, 0.19499990423875196, 0.1440106574445963, 0.09278324485889503, 0.13475964670734747, 0.13338735034423216, 0.08965065902365105, 0.11203260480293206, 0.16181769621159348, 0.2886556637074266, 0.10120436655623571, 0.1441998737198966, 0.1620939006762845, 0.15971155065510953, 0.1363613014774663, 0.09755574805395943, 0.10434742218681745, 0.1530088053217956, 0.13787860077406677, 0.11310673252280269, 0.09884390607476234, 0.16333248492862495, 0.13071005472115108, 0.10330188793263265, 0.12863897585443088, 0.12677494516330107, 0.1381430123001337, 0.20937758630939893, 0.10799448005855083, 0.07427029897059713, 0.15950554742344789, 0.187202424077051, 0.08944555824356419, 0.1383139081299305, 0.11048925654696566, 0.18642908414559706, 0.14238632603415421, 0.12028064578771591, 0.08178294370216982, 0.1443060373089143, 0.082044817507267, 0.14517528137990407, 0.10733408228095088, 0.11693196690508298, 0.17948803731373378, 0.0894981718489102, 0.11472850585622446, 0.10568442115826265, 0.1797613919313465, 0.11831794253417424, 0.20664264235113347, 0.2689179213983672, 0.16630720959178039, 0.17968333326280117, 0.23228357146893228, 0.1636427247098514, 0.07826209334390503, 0.2308682288442339, 0.1430711578577757, 0.10858065967581101, 0.11590349780661718, 0.11406360939145088, 0.09569141880742141, 0.1057639183210475, 0.15113713432635578, 0.19036977126130036, 0.16888356634548732, 0.08979820646345615, 0.15729656309953757, 0.07304572646639176, 0.13101360414709362, 0.12560071317212923, 0.19163119500236853, 0.12414773899529662, 0.09512244683823415, 0.12260157481900283, 0.0763270811044744, 0.15873443308685506, 0.18235062727970736, 0.23766486985342844, 0.17280330029981478, 0.14348518635545457, 0.09944043335105691, 0.11803837253579072, 0.16921783983707428, 0.09673140943050385, 0.1794292354690177, 0.1887278657938753, 0.08407065165894372, 0.10175783400024686, 0.10548616679651396, 0.1570846973253148, 0.10916846099176578, 0.1324554639203208, 0.13494184693055494, 0.09311100441430296, 0.14841072633862495, 0.16137734055519104, 0.18298322547759327, 0.24425596903477395, 0.13842810557356902, 0.1708699097590787, 0.10954489186406136, 0.15571468083986215, 0.112257539161614, 0.10971781651356391, 0.1464434904711587, 0.1111565889524562, 0.10750552772411279, 0.2410767339169979, 0.20177852335785115, 0.06956511323473283, 0.0740395292107548, 0.09337338033531394, 0.16034478667591298, 0.13753893971443176, 0.11862272689385073, 0.14655699580907822, 0.2042942326515913, 0.2087178195693663, 0.11683442071080208, 0.14440370563949856, 0.14265839143523149, 0.11971752957573958, 0.11064789803432566, 0.10518044605851173, 0.1423548420092889, 0.17274707688816957, 0.16218418654586586, 0.1469048671424389, 0.14691737932818277, 0.17482689528592996, 0.32582887900727137, 0.10487748695803539, 0.13233454897999763, 0.11117195777062859, 0.11096820048987865, 0.11807752400636673, 0.11390591785311699, 0.15562572489891732, 0.15779877400824002, 0.18629377069217817], [0.030773096584847996, 0.08049252615975482, 0.04633915131645543, 0.012959690614869552, 0.017749517657128826, 0.00031424069935123304, 0.015356302593967744, 0.008468764185506319, 0.03570676202486668, 0.017290417470836213, 0.11830815805920533, 0.014901724843574422, 0.011884319479577243, 0.03004460781812668, 0.027862171176820993, 0.027125499277774776, 0.022861374874732325, 0.047560500779322216, 0.01939973178585725, 0.006724825286905148, 0.019604761319767152, 0.011008759943901427, 0.051163185853511095, 0.05549315529476319, 0.05674686409266932, 0.011888288061267563, 0.010596216589744602, 0.019117522286251187, 0.028795078795935427, 0.03720382062186088, 0.06712265858160597, 0.054727930642132244, 0.07025148533284664, 0.01787506359895425, 0.03673153989283102, 0.01433890379433121, 0.053783260618469546, 0.005295201620486165, 0.01871815862666283, 0.04329742132020848, 0.038696319463529756, 0.04949123485546027, 0.09007484519055911, 0.030604137972529446, 0.014411781848009144, 0.05215636095298188, 0.03415429425824966, 0.05938187680606331, 0.045439203535871844, 0.01590925774403981, 0.04349203873425722, 0.03499539948201605, 0.02992323486666594, 0.016686102308865105, 0.05696494185498782, 0.013437482744588383, 0.06302484989698444, 0.052039669893149815, 0.04249540310619133, 0.04701642086729407, 0.027493445069662163, 0.03283336299604603, 0.022738973942718337, 0.04088580947635429, 0.01780222456103989, 0.03359933742987258, 0.05215834566791143, 0.028097454890874878, 0.01041242859459349, 0.05237926309928298, 0.02396758203394711, 0.01810157046254192, 0.05440092086791992, 0.0022145845702782807, 0.046023310228650055, 0.020335507911763022, 0.03405126550101808, 0.06951607550893511, 0.0073244598295007434, 0.016879966549043144, 0.04397055520010846, 0.05456722980099065, 0.02038104270052697, 0.02127560121672494, 0.09628736932895013, 0.07001974526792765, 0.017350308364257216, 0.0990845960165773, 0.0833849852372493, 0.015623652176665408, 0.02039017917455307, 0.010558138900835599, 0.008797212453958179, 0.02747948930066611, 0.005100881489592471, 0.06200900833521571, 0.09686742856034211, 0.029755589219608476, 0.024384078702756336, 0.06075607306723084, 0.022748402186802456, 0.018765688308381608, 0.07036033592053823, 0.0343692948642586, 0.011001260435607816, 0.021207793515973856, 0.0655452139409525, 0.04631828636463199, 0.018949316847803335, 0.0831238306792719, 0.05215422696034823, 0.03448818098487599, 0.02788526681251824, 0.047017340282244344, 0.08442920313349792, 0.02563115651719272, 0.03210384285609637, 0.03484204038977623, 0.02143890254332551, 0.02473809247437332, 0.015830104937776923, 0.07321269357843058, 0.03347447680841599, 0.04805354807259781, 0.027374577608757784, 0.014683278976008296, 0.08839898583080087, 0.0565718631260097, 0.07540970854461193, 0.03327966940456203, 0.03109163824202759, 0.001168428926445943, 0.029825118702969382, 0.021865068336150477, 0.07491241701479469, 0.00914523221685418, 0.03270005461360727, 0.024593749416193793, 0.03468487810875688, 0.03268387833876269, 0.03900396724098495, 0.041586542768137794, 0.020501162058540752, 0.031018163077533245, 0.0542841076717845, 0.05253961788756507, 0.03301054884546569, 0.0264094158275319, 0.05186178515266095, 0.04976033505850604, 0.006341371153082166, 0.017542016559413502, 0.028213204483368566, 0.04506610766319292, 0.027903285309938446, 0.10470323916524649, 0.01265373663045466, 0.013286369603260286, 0.06984667812607118, 0.017426694443981563, 0.05217458979625787, 0.01945563798238124, 0.036254119261034896, 0.07052213938108512, 0.011053522899081665, 0.04529682653290885, 0.05417545385924833, 0.034405508278203864, 0.10302898793348245, 0.13829782684998854, 0.036226017733237574, 0.03314175716202174, 0.015071007456364376, 0.007106821418606809, 0.01654894832920815, 0.02855949822281088, 0.008975659530343754, 0.08579025617135422, 0.03302799737347024, 0.003832255523385746, 0.048667479772120714, 0.03374893743810909, 0.016179162011082684, 0.06826713681221008, 0.07931745278515986, 0.036819423748446364, 0.044573959428817034, 0.03285826523123043, 0.015229262178763747, 0.01729902468754777, 0.07843098749539681, 0.05648796566362892, 0.0444195994974247, 0.010187742749362119, 0.01784144727779286, 0.014755208776997668, 0.02339968384642686, 0.016409548398639475, 0.02475263347982296, 0.04198943650616067, 0.03818895847403577, 0.002753554901573807, 0.038786656223237514, 0.013603462588175066, 0.019154375219451528, 0.03656369407794305, 0.02556638526065009, 0.08597168964999062, 0.0671088978914278, 0.03461883290271674, 0.03213231757815395, 0.05944652083728995, 0.016557407964553152, 0.017371795871960263, 0.019814438818554794, 0.05092921340838075, 0.007516779554342585, 0.11090358360005276, 0.06808507908135653, 0.014363999411995922, 0.030074449788246835, 0.02529534953646362, 0.03423418836402042, 0.00977751744046275, 0.02647190890274942, 0.02424676187469491, 0.044332204187022786, 0.056957410116280825, 0.009682324914527791, 0.04955655402903046, 0.0772331017734749, 0.05570188962987491, 0.09484312111245734, 0.02294717393150287, 0.039336452792797766, 0.011064242904207535, 0.056700031605682204, 0.0708520838192531, 0.03968628169968724, 0.025094672804698348, 0.0144575643020549, 0.02712651708030275, 0.024752127971234064, 0.046711565261440616, 0.03381157300568052, 0.03944408541013088, 0.023607877049861208, 0.016208734263532927, 0.03616842707352979, 0.022863532616091625, 0.044382171505796056, 0.009549340532560433, 0.010720655671320856, 0.03928970851536308, 0.05438729249207037, 0.09943026211112738, 0.05783489838774715, 0.02601386044573571, 0.021094179612451365, 0.04572035791352391, 0.07229812336819512, 0.0800564724153706, 0.008697727345861495, 0.036534018348902464, 0.08579821538712297, 0.024871416123850004, 0.03498406794720462, 0.031083923298865557, 0.02669104009068438, 0.023546294907906225, 0.00813020404893905, 0.04259364479886634, 0.02861803543886968, 0.016398800403944085, 0.04841151600703597, 0.08576993404754571, 0.027545324160850475, 0.043634127359837294, 0.07002420324300017, 0.07748790524367775, 0.06853504279362303, 0.03715919676635947, 0.040350085723080804, 0.033338033594191074, 0.020972967813057557, 0.03738367311390383, 0.02975632543010371, 0.03476267893399511, 0.08360835218003818, 0.08369092310645751, 0.03853425815967577, 0.03137066541239619, 0.05864695552736521, 0.023491392943209836, 0.04414743910144482, 0.027162699960172176, 0.026108687410929372, 0.010651108376415712, 0.01008188195659646, 0.093439713918737, 0.03446829990882959, 0.02041302035961832, 0.06141298996018512, 0.035974172675716024, 0.07719561271369457, 0.09825759753584862, 0.019598551028008972, 0.03199741803109646, 0.00943619227369449, 0.044823928337012015, 0.006550781478706215, 0.01627858605102769, 0.016353849155296172, 0.031564122531563044, 0.01573272328823805, 0.04304799184735332, 0.05993969365954399, 0.05738704491938863, 0.11746889166533947, 0.052999311791999, 0.0020336156760874602, 0.016576825940449322, 0.02048935046020363, 0.03471274893464787, 0.04879569235656943, 0.0941662552899548, 0.04094497772998043, 0.02901267819106579, 0.026776096151609505, 0.05773158464580774, 0.0444598128753049, 0.0743059084883758, 0.0498807478829154, 0.040624095126986504, 0.05134746239387563, 0.03468925465962716, 0.059698671235569885, 0.031177978430475508, 0.06431291970823493, 0.021046426014176438, 0.03453676409221121, 0.01684990744771702, 0.027723415854520032, 0.027601620515010188, 0.029976174168820893, 0.023297767886625867, 0.060675653096820624, 0.04975367523729801, 0.05118486504735691, 0.018773963042934026, 0.016989219168733274, 0.05290436099416443, 0.15703914048416273, 0.19378368450062616, 0.13155910558998585, 0.07408033630677632, 0.05186754252229418, 0.04954700025596789, 0.11224056221544743, 0.10525093906159912, 0.2041685679661376, 0.11477050717387881, 0.25951641159398214, 0.12019861090396132, 0.04507974960974284, 0.08228528353252582, 0.13104943079607828, 0.11386235590491976, 0.1125424492305943, 0.20421732749257768, 0.07661408784666232, 0.09488980432174035, 0.14261789646531853, 0.07913431618362665, 0.13178808401737893, 0.18793878384998866, 0.19627557721521172, 0.06748238392174244, 0.07459465906556163, 0.12685821498078959, 0.11266210209578276, 0.13978114511285508, 0.1321756632200309, 0.2759534338755267, 0.24431907279150827, 0.105926325677761, 0.1112772256934217, 0.14259806967207364, 0.1151129909391914, 0.12231771647930145, 0.11017679117087807, 0.12719718393470558, 0.10013511071779899, 0.1761686032904046, 0.2362462431192398, 0.1312690590109144, 0.10412274567144257, 0.2006149443664721, 0.10770718833165509, 0.13191691067601952, 0.15496594458818436, 0.1350589349333729, 0.15028033458760806, 0.09022438752331904, 0.12524445514593804, 0.1001889660422291, 0.3413294686802796, 0.13864940298455103, 0.2192858803485121, 0.20081374155623571, 0.10761806954230581, 0.11842131055891514, 0.13396759278007916, 0.20421749034098216, 0.12872247637382575, 0.10546522720583848, 0.09372844413987227, 0.1025269737999354, 0.14891033167285578, 0.15794669464230537, 0.11884637203599725, 0.1380069117460932, 0.08024355130536215, 0.13237922372562544, 0.18239414851580346, 0.12010156682559422, 0.10782545020005532, 0.14747656003705092, 0.09139314373689038, 0.14963025732764176, 0.09008526748844556, 0.1081006775743195, 0.17131026541548117, 0.19004566222429276, 0.0940832704571741, 0.12946471226002487, 0.277786699788911, 0.20969818053500994, 0.09870678093284369, 0.19910111916916712, 0.15559700929692813, 0.1097311225852796, 0.12999382029686654, 0.17950658846114362, 0.12314695412559168, 0.17807809582778386, 0.09131223522126675, 0.14003715637539113, 0.12797796060996397, 0.19509107220385755, 0.17690089185323032, 0.15811543273074286, 0.07786850232098784, 0.1613815746137074, 0.1610769531024354, 0.12810842932334968, 0.09797192072229725, 0.15222735011151858, 0.1573267171957663, 0.17375721197043145, 0.1767873050911086, 0.16765292095286505, 0.12123624022517886, 0.15071450200464043, 0.17216410674154758, 0.1473671801920448, 0.21570827732128756, 0.12506507762840816, 0.2174089439213276, 0.14083979544895037, 0.18226506401385578, 0.11867544906479971, 0.12216683743255478, 0.19020335376262665, 0.15332760821495736, 0.16552492656878062, 0.10936206060328654, 0.1608820507036788, 0.223177468670266, 0.14565788262656756, 0.16011237486132554, 0.15016604214906693, 0.19202737802905695, 0.11330835920359407, 0.09151819774082728, 0.15978654234537057, 0.13834927337510244, 0.08201846320714269, 0.1166223513760737, 0.11219242015587431, 0.09383267390408687, 0.11404265623007502, 0.11533967591822147, 0.1598130187817982, 0.30235726705619265, 0.08286298146205288, 0.12731473334133625, 0.0980209516627448, 0.070629035787923, 0.11579086099352155, 0.10739354230463505, 0.22387075504021986, 0.1154462873403515, 0.14910399913787842, 0.14752018983875, 0.17381842939981393, 0.10736532203320946, 0.2622487906898771, 0.2795204110443592, 0.0654132863772767, 0.11340084352663585, 0.15087052434682846, 0.1534740767840828, 0.11607216804155282, 0.1295275038906506, 0.1519981138408184, 0.05555085791274905, 0.10579736331211669, 0.16761516726442746, 0.11604780863438334, 0.11822997725435666, 0.2971564047038555, 0.14912409734513077, 0.10217263602784701, 0.08121433814189263, 0.08519132688109364, 0.1194742883422545, 0.10400459915399551], [0.01898793057937707, 0.02344776992686093, 0.017001251290951456, 0.013412391367767538, 0.055218636989593506, 0.0445025368327541, 0.03001051821878978, 0.026312911184504628, 0.06014347129634448, 0.027634098593677794, 0.025435662096632377, 0.014554747480100818, 0.047660099542034526, 0.05457357071073992, 0.05668187400858317, 0.04320114737908755, 0.023467532259279063, 0.0496555862150022, 0.039147134737244675, 0.05933133951787438, 0.06300921645015478, 0.0792516145323004, 0.05129152735961335, 0.0781598516872951, 0.06794991490564176, 0.025961543699460368, 0.06185372559619801, 0.027776702905872037, 0.05818156871412482, 0.0038101085644614485, 0.008974802031713938, 0.05426389072090387, 0.0656979318175997, 0.049916903621384075, 0.07312596323234694, 0.03979565815201827, 0.03202326682263187, 0.027796940212803226, 0.06783123234552996, 0.020022112942699875, 0.04551666509360075, 0.014658393704199364, 0.01770404732919165, 0.020423564793808118, 0.024787586514971087, 0.0520963581012828, 0.026668290507846644, 0.04043822063665305, 0.03516885678150824, 0.029362971894443035, 0.028878067021391222, 0.033005639644605775, 0.039640846994838545, 0.006068285404970604, 0.06497920038444654, 0.011073509996224726, 0.053626210295728276, 0.052407167851924896, 0.06474281235464982, 0.027192988067067096, 0.027318096353805492, 0.024518147044415985, 0.021356767575655664, 0.011685294980582382, 0.019399426445098858, 0.08402690650629145, 0.026027115627325008, 0.06252804691238062, 0.023431296792945693, 0.07086761548582997, 0.030267883158688034, 0.05502453865483403, 0.01892703545412847, 0.040379042205001624, 0.023209537978151014, 0.05077261770410197, 0.042538778457258425, 0.07449871421392475, 0.020694383386788622, 0.0027388803095423748, 0.039288208952971866, 0.05414915044925042, 0.02875232430441039, 0.033003414049744606, 0.03510959692565458, 0.05175829499161669, 0.042591015475669076, 0.03553119787414159, 0.07516000087239913, 0.036251157455678494, 0.005381982856696206, 0.01545202692172357, 0.03732122753613761, 0.04086982997666512, 0.03935079702309199, 0.054343849287501404, 0.058120724479002614, 0.013894147838332822, 0.002084733747843919, 0.0440816347753363, 0.08695587076778923, 0.07741444025720869, 0.07355732151440211, 0.05529304853241358, 0.01464806470487799, 0.032976639057908735, 0.05421245437381523, 0.018634145813328878, 0.05044631360630904, 0.09066832584461995, 0.032866550143808126, 0.0018465439955304775, 0.053555795324168036, 0.00869413704744407, 0.013784883344279868, 0.0226323845729764, 0.054465877025255134, 0.0031378336674866398, 0.02885821308674557, 0.037538429988282065, 0.017209983929725628, 0.030034518002399375, 0.002272791212557682, 0.010723386774770916, 0.04629974200257233, 0.04770342739565032, 0.061655281244644096, 0.01183336489235184, 0.11948149438415255, 0.07478863865669284, 0.03414637575458203, 0.0312428429855832, 0.03828321038080113, 0.0374826883365001, 0.02719151564607663, 0.015585387890626277, 0.014440069972936596, 0.038733883162162135, 0.14116587223751204, 0.03248430761907782, 0.03626525402069092, 0.050061719957739115, 0.025828523694404533, 0.008521421047459756, 0.011658116260410419, 0.024652178066649606, 0.0657634986564517, 0.06944286836577312, 0.014849379259560789, 0.07164349313825369, 0.03891373226152999, 0.031291666972850046, 0.030890279582568576, 0.020645959735182778, 0.04773596314979451, 0.018787321701113666, 0.050992157709385665, 0.02289546617040677, 0.0035843264610905734, 0.036327058382864506, 0.036401697234915834, 0.029066910102431263, 0.0547517506139619, 0.050352940402392826, 0.037182368737246306, 0.04769053862297109, 0.04409906973264047, 0.0291285923283015, 0.006579638724880559, 0.029855981868292605, 0.0802654204890132, 0.07042733446827956, 0.010215433763473161, 0.022199816802250485, 0.0418177773244679, 0.04514075330059443, 0.014147580667798008, 0.03281769901514053, 0.01148533495143056, 0.03476204789642777, 0.058986474094646316, 0.03497963711353285, 0.06840553081461362, 0.04200360771002514, 0.05233464602913175, 0.015290106413885951, 0.005957437379817877, 0.018732163589447737, 0.0582435257466776, 0.009701956628954836, 0.04576496819832495, 0.07079152456883873, 0.06798533443361521, 0.0017166298785014078, 0.06994053308985063, 0.059707892526473315, 0.035009390874100585, 0.016329560994303653, 0.03269750332193715, 0.011337494893398668, 0.0477625752932259, 0.060271388718060086, 0.025349350745922754, 0.020950956137052605, 0.06603979811604534, 0.045501068966197114, 0.012553727354056068, 0.03228298627904483, 0.039003051218709776, 0.03692020316209112, 0.03809517814910837, 0.03728600139064448, 0.016611862096137235, 0.007902587780595889, 0.06077762333942311, 0.014226600311563482, 0.017794626665168574, 0.028338251701955284, 0.07274008715259177, 0.02269949677533337, 0.08908070317868676, 0.012400833906472793, 0.016547950882730738, 0.03689637301223619, 0.0353000583127141, 0.07278618003640856, 0.00867091418643083, 0.025821102217638066, 0.042694746516644955, 0.009032530942931771, 0.029486241351280893, 0.054828150264386616, 0.0739315946453384, 0.11325430031865835, 0.038403657131961415, 0.049747035772140534, 0.055588333401829004, 0.02767740609124303, 0.05181906458788684, 0.056217019845332415, 0.07237919473222323, 0.061934620541121276, 0.06259493689451899, 0.03783779624583466, 0.016805599110999277, 0.006866688723675907, 0.03850479956184115, 0.05149691312440804, 0.07403891852923802, 0.03722414613834449, 0.018258386690701758, 0.022162797627970576, 0.06278457386153084, 0.049247620427714925, 0.03271077207422682, 0.019832781316446405, 0.04662417334371379, 0.020700062724894712, 0.07323571627161332, 0.03909137612208724, 0.014093940778236305, 0.06570142627294574, 0.03576030522318823, 0.052365573655281744, 0.034381277792687924, 0.0611785493258919, 0.03245706104540399, 0.033446185290813446, 0.05089835024305752, 0.07299150473305158, 0.04587917921266385, 0.024499711247959306, 0.0714052187811051, 0.0193855504039675, 0.021832059303830777, 0.019742337687473212, 0.01677441194520465, 0.04334897980360048, 0.07353118434548378, 0.024779793540281907, 0.018253857469452277, 0.021318818808400204, 0.06091559665011508, 0.014486016971724374, 0.012316212956128376, 0.04131045365439994, 0.022075088495122533, 0.07665735123945133, 0.028870847408792803, 0.07306800955640418, 0.03756210068240762, 0.021854184634451355, 0.03328051418066025, 0.020683102742103592, 0.03560625741790448, 0.01853101697218205, 0.05229192207168255, 0.012589472578838468, 0.026543124545631663, 0.05156428486640964, 0.12386677121477467, 0.004307094753520297, 0.0711867847879018, 0.050355260992156606, 0.04177453089505434, 0.02677000799615468, 0.02632365409018738, 0.07869698000805718, 0.04007252758102758, 0.017599827743002346, 0.017179577079202448, 0.02768051378162844, 0.026910038964290704, 0.053709269767361026, 0.01758550386875868, 0.024484535812267234, 0.023732126989801015, 0.028334782691672444, 0.008188519044779241, 0.03397081160385694, 0.013634499628096819, 0.048320263225053034, 0.05463563970157078, 0.0711228803598455, 0.002964379336585158, 0.024737469918493713, 0.025768995817218508, 0.06076815777591296, 0.05644121799351914, 0.044523208402097225, 0.005162400018889457, 0.02772986363353474, 0.018396853635619794, 0.04586718949888434, 0.023543348369587744, 0.01158993536539908, 0.031724188942462206, 0.03778479926820312, 0.025026929564774036, 0.05147684205855642, 0.03620955986636026, 0.0437011462636292, 0.032335643989167044, 0.011803424534653979, 0.011812788317911327, 0.06019315363040992, 0.029060864355415106, 0.054454335144587925, 0.048410006266619475, 0.0836764160277588, 0.029816016155694212, 0.05080255466912474, 0.04189068591222167, 0.10764953999647073, 0.17159899563661643, 0.14183774404227734, 0.21903041191399097, 0.10177318246236869, 0.09977567714772054, 0.1512521052999156, 0.15918447822332382, 0.1834515096353633, 0.0870183841990573, 0.09826327008860451, 0.07781252996729952, 0.16429106492016995, 0.09788588926728282, 0.10723013750144414, 0.1400743808065142, 0.1508026301328625, 0.13062837267560617, 0.19684535664107117, 0.14320868333535536, 0.09882998253617968, 0.12889609991439752, 0.08890615004513945, 0.08958595392427274, 0.15617708888437065, 0.08978013029055935, 0.10547069619808878, 0.12858649795608862, 0.10535892790981702, 0.1122636663328324, 0.13765518633382662, 0.2372750107731138, 0.12064999953976699, 0.08539398493511335, 0.13742980414203235, 0.10487461675490652, 0.1905374779765095, 0.1857257690280676, 0.115418033142175, 0.17018464367304528, 0.09021204497132983, 0.19266612375421183, 0.11240913745548044, 0.18386110051402024, 0.07082167187971727, 0.07461698965302535, 0.08173370241586651, 0.09516123868525028, 0.1253348495811224, 0.10611496519829546, 0.1615701937781913, 0.15459674011383737, 0.1393709842647825, 0.11728579577590738, 0.16554362699389458, 0.1915565018675157, 0.13550034910440445, 0.20476239467305796, 0.11388325478349413, 0.1850320483957018, 0.0972504819344197, 0.12302165584904806, 0.16216435975262097, 0.20257394281881197, 0.173013144039682, 0.10866693540343217, 0.16540555868829998, 0.09504151796655995, 0.09988994244486094, 0.1939461257840906, 0.12237607049090521, 0.13770500437489577, 0.1144100015184709, 0.05119204055517912, 0.11711523921361991, 0.12949013018182345, 0.19175305989171776, 0.1335857268422842, 0.08656920080206224, 0.08646310506654636, 0.1595096593456609, 0.12072048575750419, 0.17784089355596475, 0.1265524263892855, 0.15519619866141252, 0.13999112455972604, 0.13546692446938582, 0.32706356846860474, 0.1141165622643062, 0.13900547102093697, 0.12234754487872124, 0.23379670456051826, 0.21004326987479413, 0.13073775252061232, 0.1288589569074767, 0.20287282392382622, 0.12763031997850963, 0.12318257721407072, 0.12559197364108904, 0.10279454051383904, 0.1648525662188019, 0.17777546920946666, 0.1036510756239295, 0.09498448031289236, 0.08364761900156736, 0.14236998691090516, 0.11654391272791795, 0.1858761188174997, 0.10932940271283899, 0.095629075009908, 0.08601758575865201, 0.14528472907841206, 0.2009958874966417, 0.11408083061022417, 0.101957669348589, 0.16573244971888407, 0.12558851311249392, 0.12630588747560978, 0.22209592456264154, 0.12799725814589433, 0.09765995746212346, 0.13602321461907455, 0.13039011188915797, 0.25911577737757135, 0.17321527962173733, 0.26799983637673513, 0.0901216369654451, 0.1952965326075043, 0.11727595701813698, 0.08552667245801006, 0.17265561036765575, 0.12643400845783098, 0.16160585757877144, 0.08057081553020648, 0.1509677448443004, 0.10939618412937437, 0.11583941695945603, 0.18862248930547917, 0.11946807296148368, 0.10740944716547217, 0.14088930136391095, 0.05734547786414623, 0.10315690535519804, 0.09717027909521546, 0.11881323238568646, 0.11841179749795369, 0.1460892544793231, 0.06869388105613844, 0.16339074394532613, 0.2328943344099181, 0.18694160878658295, 0.13791848506246293, 0.10895531278635774, 0.08384408203086682, 0.134756064042449, 0.1408968059612172, 0.0826675837327327, 0.0732233262221728, 0.06555111719561474, 0.1972889964069639, 0.08685286915195839, 0.2105410431644746, 0.1381879856011697, 0.12641872784921102, 0.14000914644982132, 0.10884036216884851, 0.07756650674023799, 0.08941294106521777, 0.11031694257897989, 0.17594539241067, 0.12233101576566696, 0.17599637753197125, 0.12339753710797854, 0.10292098551456418, 0.15384657893862042], [0.03475174434216959, 0.019975621419559633, 0.054822952686143775, 0.04906126078484314, 0.0426405553173806, 0.02798738972549992, 0.034681709350219796, 0.02652921966676201, 0.03625972396028893, 0.0619856667305742, 0.01260033083547439, 0.022766519071800367, 0.06041246971913746, 0.040972322691231966, 0.03149232334856476, 0.07211979757994413, 0.026687092713213394, 0.04732246730210526, 0.04434300646451967, 0.02607529330998659, 0.028009803433503424, 0.04824110193710242, 0.03700979692595346, 0.024064241043691124, 0.09060876404068299, 0.006110562801560653, 0.01968422455580107, 0.03828260648463454, 0.04427015894491758, 0.07434330255325351, 0.04568296724132129, 0.04750541052115815, 0.06393786626202719, 0.018101115844079425, 0.054289037228694985, 0.05233041875596557, 0.00808165910919862, 0.050773187673517635, 0.00830097180525107, 0.0392172036559454, 0.03639108155454908, 0.01885599623035107, 0.04256226255425385, 0.04291160630860499, 0.046946776032979996, 0.01828552978778524, 0.04342665509986026, 0.03082195110619068, 0.09374182485044003, 0.01392076931162072, 0.05934970746082919, 0.03777611741263952, 0.019215202491198267, 0.022183204568656426, 0.017253006442583034, 0.00821917356058423, 0.03376588724287493, 0.011539800109208694, 0.03809256239661148, 0.005019827088939824, 0.014002162979782691, 0.026623600495180914, 0.01821249906372811, 0.011371949205308087, 0.034099339707089324, 0.01640977061885808, 0.04950385560680713, 0.02165756723843515, 0.09935896843671799, 0.03128442021885088, 0.02360429777763784, 0.03895525860467127, 0.022103298588522842, 0.029916636113609587, 0.02219595424165683, 0.014003267295525541, 0.035273069582347355, 0.06156298012605735, 0.05533084971830249, 0.009359621293177562, 0.004448256754715527, 0.01853500845442925, 0.12690055556595325, 0.05555891212342041, 0.030943062821669236, 0.06209026290369885, 0.011482446088588663, 0.03344729130289384, 0.02265423340057688, 0.051392283024532456, 0.04171804624742695, 0.03269856522924133, 0.021406329469755292, 0.02012663278063493, 0.03722301298486335, 0.03930727917967098, 0.0319701375306717, 0.027962416244138564, 0.003583600428620619, 0.026249848139871444, 0.05593774500968201, 0.0272745903847473, 0.03968390343444688, 0.014446897731561745, 0.017384336895442436, 0.030949305343840803, 0.0373546725272068, 0.029982633822198426, 0.05730162414589098, 0.04944817502317684, 0.022923973122877733, 0.03137771878391504, 0.015338161960244179, 0.015875015474323715, 0.025503217043089013, 0.04595859155857137, 0.031087963974901607, 0.04071492382458278, 0.04067110064040337, 0.04173813766932913, 0.0018542733575616563, 0.02319995197467506, 0.06487241254321166, 0.02521436638198793, 0.043367191683501005, 0.070190261118114, 0.042559304141572545, 0.05767112039029598, 0.0333823996063854, 0.04934376883985741, 0.07131337906633105, 0.017361098767391274, 0.015019945999873536, 0.07612204817788941, 0.003345468987910343, 0.0393721335567534, 0.029698829765298536, 0.04036269290372729, 0.03670252234275852, 0.01094531946416412, 0.026187148111473237, 0.03648853275392737, 0.07674359304032155, 0.05786432645150593, 0.018031610109444176, 0.006954086154499757, 0.01615737934064652, 0.04023125049258981, 0.045156905826713355, 0.027148633929235593, 0.026207244622388055, 0.07152308031384434, 0.03309140647096293, 0.022545489682150737, 0.12730118978236402, 0.027858807339466045, 0.029249402095696757, 0.06649913239691939, 0.004978201085967677, 0.01365079719107598, 0.09004467752363, 0.07221378146537713, 0.016032114990853837, 0.018074944748410156, 0.024557286640629172, 0.010634300215835018, 0.05874685623816081, 0.0647867474971073, 0.11313799263111182, 0.028104308094563227, 0.024557244232190505, 0.029456290815557753, 0.020686444527070438, 0.04974792465301497, 0.06710129151386873, 0.023245568187641244, 0.013454377418383956, 0.053087914894734106, 0.0087934364065794, 0.0359525477646717, 0.026133484473185878, 0.008898065658286214, 0.02102487065297152, 0.0387403767422906, 0.012800548707933297, 0.031996715747352154, 0.047922285473240275, 0.03367115018357124, 0.015591062139719725, 0.13182728977075645, 0.014027101686224341, 0.028173113241791725, 0.05172337757955704, 0.05922743545046874, 0.03397839084001524, 0.04262307964797531, 0.0729838101459401, 0.019405685930645893, 0.020784708272133554, 0.013895538835121053, 0.041505183026726754, 0.037966982528035126, 0.030151724748845612, 0.01171013105860246, 0.02904617746493646, 0.03280238447976964, 0.02845818446283894, 0.030721154729170457, 0.035735053542469225, 0.020842787477054765, 0.044316638593694994, 0.08382310851344041, 0.03427469011928354, 0.03364797142733421, 0.022252408355208378, 0.01973606293488826, 0.003876968860692744, 0.01886069678169276, 0.03222786209412983, 0.020650706087638224, 0.0924278689282281, 0.06834839138069324, 0.05365845767248954, 0.10530739996050086, 0.04707642371899315, 0.034670798507119925, 0.0702662638255528, 0.03549077754308071, 0.0036570658391740707, 0.05938794969448021, 0.04541235729785902, 0.0313578071737928, 0.04896406064342175, 0.034418193490377495, 0.03657797045473542, 0.012374770528237735, 0.019000629362251078, 0.04145625386653202, 0.03387825942731329, 0.04767365327903202, 0.017062719778290818, 0.038830336915063005, 0.0620848685503006, 0.009841923984432859, 0.04702212056145072, 0.018103775701352527, 0.02391249856113323, 0.01043586349780006, 0.030378952555890595, 0.021180168659027134, 0.07919570324676377, 0.015989553881809115, 0.03187921044549771, 0.021606668630348783, 0.04538258657391582, 0.048830423171498945, 0.053272710514387915, 0.04831883151616369, 0.0191480393987149, 0.06452517903276853, 0.02819884498603642, 0.07788386435381003, 0.036571042612195015, 0.07031599365706954, 0.04565702345488327, 0.05171833945704358, 0.04580356327018567, 0.038435141156826697, 0.0514263488751437, 0.029044891641076123, 0.0025210890162270516, 0.01753637962974608, 0.01711842750332185, 0.02797846190099205, 0.05395711146827255, 0.022623784141615033, 0.03995728858613542, 0.0997797619285328, 0.044361347266073735, 0.03855142170297248, 0.022627502513517226, 0.05984784037406955, 0.02793628755690796, 0.03262988730732884, 0.05815470551273652, 0.01839545415714383, 0.009507853205182722, 0.017766618435936313, 0.049062997834490876, 0.040647290846599, 0.014903450018859335, 0.016288945584424903, 0.03527229944510119, 0.055717210950595994, 0.0113398010642933, 0.04927532501252634, 0.058233924476163726, 0.03555229013519628, 0.03691904625988432, 0.011047381308994122, 0.059164813453597684, 0.01285177470916616, 0.031000246360365833, 0.024332113098353148, 0.02101640762495143, 0.08230110018381051, 0.011051241325081458, 0.02606455040430384, 0.019036942860111594, 0.014326824174661721, 0.03728693098362003, 0.040500289627483914, 0.012350707980138915, 0.024067609970058714, 0.04301653496388878, 0.04326945889208998, 0.044493166264146566, 0.0412304509830262, 0.03687003228281226, 0.023811842980129377, 0.04887767635019762, 0.04623878580917205, 0.03694881019847734, 0.005021618845473442, 0.08372608479112387, 0.018269322978864824, 0.013603303132445684, 0.017289230034553578, 0.06735804237957511, 0.05172064308343189, 0.052114464808255434, 0.02915762344907437, 0.044547211578381915, 0.023050774354487658, 0.031943457533738444, 0.0554760799610189, 0.031610815918871334, 0.03541516160060253, 0.026929977715813687, 0.005933687805996409, 0.06730801399265017, 0.029716732911765575, 0.012880238405029689, 0.10064417483018977, 0.13882920119379247, 0.03813876384603126, 0.023994974492649947, 0.029917063590671335, 0.02307476396007197, 0.03377120017207094, 0.03699834325483867, 0.03733779736129301, 0.17880756168493203, 0.12054684864623205, 0.06365625387323753, 0.09198810359729187, 0.06385318509169988, 0.16550002433359623, 0.14996507364724362, 0.0761915844466005, 0.07725054690880434, 0.1936524693987199, 0.08112095136727605, 0.1286388130060264, 0.16543579420873097, 0.2795072746063982, 0.0796220132282802, 0.11921637718166624, 0.1259732696094683, 0.19073383244020597, 0.1596285793930292, 0.09048921974109751, 0.15817119473857538, 0.10249154070126158, 0.10625800716557673, 0.12198667281440326, 0.14230988227895328, 0.09590686046119247, 0.06651828065514565, 0.09105679392814636, 0.11027205070214612, 0.2839575686625072, 0.11543495580554008, 0.0785059452589069, 0.2802537445511137, 0.08745327764855963, 0.09524568915367126, 0.1552036896880184, 0.11303176118859223, 0.1035668829988156, 0.1019180632595505, 0.12655280636889593, 0.1218128999961274, 0.09166571803923164, 0.10484727857900517, 0.11832779486264501, 0.18165237403341702, 0.16365962023181574, 0.1604330912232399, 0.24511162883469037, 0.20722091703542642, 0.09481582364865712, 0.15398140384682588, 0.13834601640701294, 0.09618338383734226, 0.1693149653396436, 0.10278320219367743, 0.08030102322144167, 0.10648512640701872, 0.08617864961602859, 0.14905948724065507, 0.11439367596592222, 0.09095984484468188, 0.18043775563793524, 0.11480606240885598, 0.16685292816587857, 0.10963826506797757, 0.10318043694964477, 0.1527369977640254, 0.08165410347282887, 0.1771950910666159, 0.11889743858150073, 0.10788011976650783, 0.14888620296759264, 0.09543529897928238, 0.0799274489815746, 0.11834656314126082, 0.1096760458978159, 0.13747158832848072, 0.23062140494585037, 0.1444516916360174, 0.13814264589122363, 0.11322297914219753, 0.13016981871000358, 0.15226256607898644, 0.10709897668233939, 0.09793356313769307, 0.17338480481079646, 0.1170082613825798, 0.2186430769839457, 0.1439913191965648, 0.17907181036259445, 0.20526366920343467, 0.10504147530134235, 0.1169156413525343, 0.13589402155152389, 0.15619201665478094, 0.09877702287797417, 0.12763869310063974, 0.12205297925642558, 0.14514843853456633, 0.1017955673326339, 0.08490067640585558, 0.17466392474515097, 0.2943386116198131, 0.1100627158635429, 0.17257638461887836, 0.14265824215752737, 0.15530898475221225, 0.10809670135911022, 0.15638147720268794, 0.16857165736811502, 0.06747004136975322, 0.09084378142974206, 0.11010042883987937, 0.14067360865218298, 0.13977784743266447, 0.09737375817660775, 0.16820245289376803, 0.124457395236407, 0.23547217036996568, 0.16023558325001172, 0.1362934751170022, 0.10050217780683722, 0.13321877510419913, 0.12314101015882832, 0.12913503923586436, 0.17230438707130297, 0.09955115669539996, 0.13498730877680437, 0.09934140795043536, 0.1467966136655637, 0.13512376216905458, 0.08403189373867852, 0.0672827453485557, 0.19210117549768516, 0.061661788395472934, 0.11151017355067389, 0.06358811538666487, 0.11066686987344708, 0.24531318087662968, 0.14098889673394815, 0.12571701407432556, 0.12114497726517064, 0.17588169154311928, 0.0889469435704606, 0.06434529939932482, 0.14916156604886055, 0.08777682350150176, 0.1069751169000353, 0.11712112889758178, 0.10703376268169709, 0.17667732813528605, 0.10203929032598223, 0.18910826609602996, 0.12593870503561838, 0.1828466635197401, 0.11742694463048663, 0.19399887509644032, 0.16252407830740723, 0.10177996781255517, 0.13257033989897796, 0.20367720004703316, 0.12796745688787528, 0.08475030626037292, 0.13929395696946553, 0.15178869079266274, 0.10513169331742184, 0.08759881662470953, 0.12320239043661527, 0.30288275171603474, 0.08869003664169993, 0.06954537465104035, 0.11635462859911577, 0.07003621331283025, 0.18264498934149742, 0.17940951724137577, 0.09257204404899053], [0.060944556524710994, 0.03292982692697218, 0.02849820615457637, 0.01548526665594961, 0.011494144032310163, 0.026751000533944795, 0.020666283555328846, 0.03868679283186793, 0.022185123126421655, 0.025506207686183707, 0.006984062559370483, 0.0139736059853541, 0.02861705156309264, 0.03858015087566205, 0.046829382689403634, 0.051106857268937995, 0.05015657236799598, 0.021946331386321356, 0.035033726532544406, 0.059492416945951324, 0.0553043359624488, 0.041121773421764374, 0.019822939166000912, 0.03002554437677775, 0.05329909534858806, 0.009947280964947172, 0.03510770381295255, 0.010038715255047594, 0.061701469123363495, 0.005892168248205313, 0.012414233276753553, 0.043853324704936573, 0.032423863719616614, 0.0036527762256030527, 0.0392211696931294, 0.0737686851727111, 0.050127042523984394, 0.010433892353570886, 0.03756853997973459, 0.04783326507146869, 0.029409885805632387, 0.015914054986621653, 0.029623139183968306, 0.07741311032857214, 0.019940525892057588, 0.01578737249863999, 0.03016718177657042, 0.03932952834293246, 0.05104457793225135, 0.029369394228394543, 0.05435705018628921, 0.02360733931085893, 0.05299469775387219, 0.03478610874818904, 0.03907721170357295, 0.020157936993720274, 0.026889796568346874, 0.012570481231835271, 0.02683687592590494, 0.06843480281531811, 0.041149026780788384, 0.02286463014648429, 0.04715608712285757, 0.036282363281186135, 0.0232667757996491, 0.018097229534760118, 0.0065211528230325454, 0.05623192047434194, 0.012716125380913062, 0.04261460813826748, 0.033010029766176424, 0.022585401111947637, 0.02038660499134234, 0.03888955945149064, 0.06674654662076916, 0.025558906108407036, 0.041431399128798924, 0.03197690931015781, 0.04865247057750821, 0.019658833775403242, 0.0691624434132661, 0.012207145237230828, 0.05270147563091346, 0.057244966471833844, 0.03103273461705872, 0.04268375764201794, 0.02856578484975866, 0.016010620697800602, 0.02597736374342016, 0.05082345354769911, 0.0045690419252163595, 0.018225991732573936, 0.045943538259182654, 0.017595751443877816, 0.02814427889617426, 0.04082976248381393, 0.012837454227597585, 0.034809165368122716, 0.11496562670384135, 0.02211344607972673, 0.032756379805505276, 0.04391998737784369, 0.03239443565585783, 0.04020984949810164, 0.05254770941766245, 0.06229209314499583, 0.028537859741066183, 0.07194755825081042, 0.0568397996414985, 0.07593217372362103, 0.03449592646211386, 0.05046197080186435, 0.023716990569872514, 0.027358090904142176, 0.03381366289353796, 0.07284275628626347, 0.05289105831512383, 0.06410084358815636, 0.008612014802305825, 0.009005845008817102, 0.0062183213719565955, 0.04614579597754138, 0.012456361819723887, 0.07667215008820806, 0.004686817368825099, 0.07524589662040983, 0.031172156600015502, 0.12157777404146534, 0.01954992551223508, 0.01826435949520341, 0.028091449855959842, 0.08559092972427607, 0.05457714659028819, 0.09940124795372997, 0.05117331298866442, 0.014541580508063947, 0.026824155090642825, 0.019916895910033157, 0.04640706927914705, 0.06415028164961509, 0.02236952689210219, 0.03858617287395256, 0.05594088323414326, 0.03989606437140277, 0.03400887402572802, 0.06648955826780625, 0.02255252269761903, 0.0425793548513736, 0.035104124540729184, 0.02513854518266661, 0.03473854683605688, 0.040608889157218594, 0.04995816533586808, 0.02670271258934268, 0.043632183357008865, 0.01775591624235468, 0.052134315350225995, 0.0398914808673518, 0.020856020606255958, 0.04620307111846549, 0.033670057742191215, 0.032600672982100926, 0.05225749320483633, 0.01730274305944996, 0.0788820707904441, 0.017642680622105087, 0.03934710918526564, 0.07637453784367867, 0.015786161313631704, 0.0028298506513237953, 0.018170762374731045, 0.05718651067997728, 0.03633807100621717, 0.015881967065589767, 0.018823965984795774, 0.027482690289616585, 0.03675777205665197, 0.01901024081079023, 0.02567744787250246, 0.04112064705363341, 0.0031220015371218324, 0.03874239877664617, 0.01941037460762475, 0.02183416106605104, 0.034719530892159255, 0.022890553576871753, 0.034574514387973716, 0.07705151901713439, 0.03627120138012937, 0.11152128795427935, 0.04898411474589791, 0.06377184909901448, 0.019963429841612066, 0.016468265426478217, 0.07516141222523791, 0.07093833240547351, 0.030422653603766645, 0.012609386733467025, 0.010088406918969537, 0.06754469379250493, 0.0395204816678805, 0.0029462862003128976, 0.020517016029251472, 0.0469796578399837, 0.09052295650222472, 0.026393105542021136, 0.015874311494241868, 0.08172094595751592, 0.006881119467185012, 0.014468113825257336, 0.010369638479979975, 0.025560178361567, 0.005673775815271905, 0.030622512700834444, 0.033780933756913455, 0.04806858780128615, 0.02932467537799052, 0.05477196417216744, 0.01185855211224407, 0.008647088277419763, 0.06022403375910861, 0.05041840885366712, 0.039632914920470545, 0.03525272710248828, 0.05911226770175355, 0.026506636325003843, 0.051016028571341715, 0.011715938470193317, 0.01580896687560848, 0.04734048579952546, 0.021871349874085615, 0.05175910584096398, 0.032620224968663285, 0.029262572460408722, 0.07817562762647867, 0.051915341921682866, 0.03093326138332486, 0.038644981504018815, 0.009452040307223797, 0.021454035570578914, 0.07012834479766232, 0.07456903079790728, 0.06853825226426125, 0.036833004626844607, 0.04007661575451493, 0.036882191630346436, 0.006542991896692131, 0.02411561462629054, 0.04740560819794025, 0.05681631215182798, 0.038935190931494744, 0.03046978125348687, 0.023284395657745854, 0.02953634437705789, 0.06737922624285732, 0.05007651202114565, 0.022900884272530675, 0.03041884023696184, 0.029134146137429134, 0.022155254014900753, 0.04041211739448564, 0.039973447897604535, 0.03293321281671524, 0.05026388607387032, 0.01641020318493247, 0.12712927615003927, 0.0008283383753483317, 0.008708940985213433, 0.08371589998049395, 0.03101742686703801, 0.011956234013528695, 0.009779799862631729, 0.0037155025472332326, 0.05842120014131069, 0.0539525686763227, 0.040594782414180894, 0.020841165778360198, 0.03002091676795057, 0.035003457085362503, 0.0292176025520478, 0.022637141103457128, 0.04471207523186292, 0.042399539678756676, 0.05018946435302496, 0.017703336563759615, 0.08127803900944335, 0.022918940089376907, 0.03127339402479785, 0.05759002867021731, 0.018184635023187314, 0.033921071594314914, 0.046565144189766476, 0.04901799060670393, 0.016782048856839538, 0.027886193012818694, 0.01614929289956178, 0.06250303611159325, 0.05871608467506511, 0.07562036652650152, 0.10612838662096433, 0.017718165946592177, 0.07363902391599757, 0.027306035393849015, 0.037049694785049984, 0.08893114048987627, 0.02566436741368047, 0.02328902157023549, 0.00461936165811494, 0.03995834370808942, 0.08630462642759085, 0.05824723733322961, 0.06473579630255699, 0.018653314427605698, 0.01793287308620555, 0.052501585999769826, 0.14976217810596737, 0.10631631367972919, 0.02617320591317756, 0.005563488853762725, 0.03391226760244795, 0.04844047248895679, 0.019761055075962628, 0.03292974889544504, 0.060180614303265295, 0.048447905840086083, 0.02758264697955123, 0.017148922563397458, 0.042061554600617716, 0.012260169356263109, 0.021486617125836865, 0.0923817353323102, 0.07556744079504694, 0.05722942801990679, 0.03212201402389577, 0.045396703494978805, 0.026104926630588512, 0.03742256334849766, 0.017499528392883282, 0.07294822098421198, 0.04034835206610816, 0.0302639849750059, 0.03476916912144848, 0.035947631778461595, 0.04092919161277158, 0.051458273947771103, 0.0631244724084224, 0.029570461117795536, 0.03274190326088241, 0.025125483383557627, 0.034896302835217545, 0.02138142553823335, 0.008895840063425047, 0.10308962860809905, 0.08002333955041, 0.15237274659531458, 0.11628776575837817, 0.07222166604229383, 0.07347464880773, 0.0785248288884759, 0.09621757521693196, 0.13880998508206435, 0.08333541146878685, 0.12620961692716393, 0.09910344571939536, 0.13756722105400904, 0.24875718035868236, 0.09590101148933172, 0.12633442665849412, 0.14105105054165634, 0.06205394770950079, 0.14861709597919667, 0.15040962265006133, 0.17058609213147843, 0.14584228130323545, 0.037741837823497396, 0.14455507323145866, 0.16485878159957273, 0.12544352374970913, 0.17760595759110792, 0.11522102728486061, 0.2297577384327139, 0.11937731211738926, 0.14521193584161146, 0.13676524694476808, 0.08437899154211793, 0.11497986236853258, 0.10164896984185491, 0.14165371177451952, 0.14750797620841435, 0.10206079310072319, 0.1071786977616804, 0.1187943826828684, 0.13875828071364335, 0.12770544737577438, 0.10916770103254489, 0.15331652095275267, 0.09814402434442725, 0.16930381022393703, 0.08597100432962179, 0.08874390553683043, 0.1377041358500719, 0.13455177071903432, 0.13656445486204966, 0.10530997160822153, 0.12199431311871324, 0.20148654973932675, 0.17015116475522518, 0.10088267310389451, 0.19177821997020925, 0.05609065626880952, 0.13593953768057482, 0.1615358599062477, 0.1988473470721926, 0.111521966489298, 0.08123997998024736, 0.12369263198758874, 0.14223046654037066, 0.1665770901100976, 0.11497621185013226, 0.15352785746966088, 0.16832961035626276, 0.10732912897531476, 0.17253154702484608, 0.13160057765032562, 0.14987615841839994, 0.23801054273332867, 0.12685054753507885, 0.08330525737255812, 0.1067271191360695, 0.11459748074412346, 0.17746425233781338, 0.15374184027314186, 0.11124244398836579, 0.14691125894231455, 0.1675035482538598, 0.11252134679151432, 0.08982636566673007, 0.13405159541538783, 0.16165214723774365, 0.09747233574411698, 0.11717765086463519, 0.1790754608809948, 0.20744585139410837, 0.16040681834731782, 0.1735321826168469, 0.14196498292897428, 0.1307834857808692, 0.1601996344647237, 0.13646138539271696, 0.14079109020531178, 0.3604839965701103, 0.07975799164601735, 0.13527282274195127, 0.1236659927027566, 0.15950313183878148, 0.11696220242551394, 0.18751357309520245, 0.16727889887988567, 0.12576485079314026, 0.16485908015498094, 0.12893271366400377, 0.1971920880356005, 0.11069770929004465, 0.11893015754009996, 0.1551801445228713, 0.09317852543400866, 0.18458276321845396, 0.11454866693488189, 0.09401971886732749, 0.12581818364560604, 0.060350424477032254, 0.15682304065142358, 0.15981512224035604, 0.16878717366073812, 0.16522611331726822, 0.20646819099783897, 0.09644629580101796, 0.1502583771944046, 0.09555573894509248, 0.281672615557909, 0.17051358387938567, 0.07280606111245495, 0.11676253671092646, 0.1420342070715768, 0.13196201968405927, 0.21864219488842146, 0.1108550208487681, 0.16910148465207644, 0.0991871158725449, 0.08850700182041951, 0.07167425113064901, 0.17867344245314598, 0.2124791427382401, 0.19402210813547882, 0.20204180851578712, 0.09071360448641436, 0.10654222512883799, 0.1362493024872882, 0.1012391686173422, 0.12584999336728028, 0.10536471581352608, 0.1345653414194073, 0.0717561978048512, 0.1402685096753495, 0.112061747881983, 0.1093305019395692, 0.2242800745048693, 0.11008469361279692, 0.17604702338576317, 0.15719646561358655, 0.18024472599583014, 0.07368788522269044, 0.08073072587805134, 0.11497929239911692, 0.13868598959275655, 0.07700006570667028, 0.18865400047174521, 0.1268604677170515, 0.10660224833658763, 0.18363782178078378, 0.11699288577905723, 0.08578110951930285, 0.2129134051501751, 0.10715964449835674, 0.15001369746667997, 0.12359602217163358, 0.1148025883095605, 0.09826804018978562], [0.03972704129825745, 0.00886546798782157, 0.09040664202932801, 0.04137972529445376, 0.05084784348894443, 0.031015401440007345, 0.05419678021488445, 0.01556118285017354, 0.02369999496399292, 0.01800882490351796, 0.004585581640380302, 0.028483468373971324, 0.07093894308699028, 0.046069498107369454, 0.03463238663971424, 0.02101192929382835, 0.053832179600639005, 0.03936796735173889, 0.03664761528904949, 0.01291471392115844, 0.07052448032689945, 0.008812748361378908, 0.017458982532843947, 0.03607834815712912, 0.03403946916971888, 0.045741280540823936, 0.09886589060936656, 0.013589526327060801, 0.01380415289064071, 0.02132055246537285, 0.027895931686673845, 0.030075043506388153, 0.022574093325861862, 0.045757684124899764, 0.09160087044749941, 0.027451869532732025, 0.054217221082321236, 0.005201094326496656, 0.0746522599032947, 0.013435902606163706, 0.05676189364333238, 0.06015336433691638, 0.016440803417935967, 0.06800352595746517, 0.005571911169681698, 0.03633431192221386, 0.010443919404808964, 0.022715369405757104, 0.011354990918854517, 0.010918470681644976, 0.03662263841501304, 0.036859966215810606, 0.03247511686225023, 0.03881210467911192, 0.022733408259227872, 0.02539183891245297, 0.03158228691401226, 0.06652807191546474, 0.0691914168585624, 0.0266795575818313, 0.018000935237588625, 0.024092977001730884, 0.025517846258091073, 0.028860594744661024, 0.012959879756506, 0.04210029895018254, 0.04219061874651483, 0.03545252852407949, 0.03873338443892343, 0.03527880998860512, 0.09046184085309505, 0.03762527907799397, 0.07256677573812859, 0.033658831380307674, 0.030264639761298895, 0.012485822113896055, 0.008214244851842523, 0.008889957164813365, 0.013830044090614786, 0.007981127360835671, 0.01036994466890714, 0.07367659439998013, 0.06714361852833203, 0.00912965220465724, 0.021311950337673937, 0.052078716190797944, 0.05649132780464632, 0.05774362185703857, 0.055208927153476646, 0.009529847069643438, 0.05453556596434542, 0.013864186276415629, 0.05504881324512618, 0.048701867926865816, 0.049005149331476004, 0.033487823592232804, 0.04497734849740352, 0.0403084168875856, 0.02374565358539777, 0.026060467319829122, 0.02059445044557963, 0.06513516165848289, 0.03483753152457731, 0.04165975669664996, 0.02245866773383958, 0.027347838240010396, 0.031308318222207684, 0.019419539919389144, 0.08373007457703352, 0.04031603344316993, 0.013357366418599017, 0.04085863075618233, 0.049315453573529205, 0.007513794000260532, 0.09186537696846894, 0.011231526383198798, 0.015672386258042285, 0.03259791134457503, 0.03631597112065979, 0.021827014395967126, 0.035498441596116335, 0.011387707332947423, 0.023999870122809495, 0.02273003933286028, 0.024306642590090632, 0.06242429890802928, 0.1002624649554491, 0.05446645038734589, 0.012448106593053256, 0.05217320897749492, 0.01970595633611083, 0.072425796517304, 0.054957770808999024, 0.00846211114964847, 0.05241781745904258, 0.028278895154861466, 0.019928252889907787, 0.024699334554108124, 0.03371915653614061, 0.052866342677069564, 0.0460792656189629, 0.026234187551641037, 0.05423188083139913, 0.006679896938814116, 0.015397376014984079, 0.044514302629977465, 0.026390773077894534, 0.03138212247618607, 0.02903887303546071, 0.06528405259762492, 0.03103083132633141, 0.03644749495599951, 0.045645322118486674, 0.025511868364576782, 0.07817579726023333, 0.06367516464420728, 0.01838388174240078, 0.09551736778978791, 0.022944676922634244, 0.022614315185429792, 0.00785115737068866, 0.026531189114653637, 0.04688817774876952, 0.04755110985466412, 0.021182190693382705, 0.05410034003268395, 0.02573471962075148, 0.03011095497225012, 0.026853483070486357, 0.01625736486831946, 0.0400152320840529, 0.035323484734232934, 0.05973278797630753, 0.043972383851983717, 0.04491960516731654, 0.029966661107859442, 0.015350879402831197, 0.0011493021905023071, 0.013820156139055533, 0.04138832572581513, 0.032272095791995525, 0.02232385130732187, 0.04583352737660919, 0.01649252135705735, 0.03141510945611766, 0.01653668380874608, 0.02659678309490638, 0.006005497167019972, 0.01088699683480497, 0.03169263706409505, 0.07107893843203783, 0.06780869141221046, 0.0679411618039012, 0.011906730643074428, 0.05203608383557626, 0.011298861653943146, 0.030041004797177653, 0.013353167135002357, 0.012762822160896446, 0.02223862730897963, 0.03120438362072621, 0.040787713668708286, 0.1044158185166972, 0.051142700881298096, 0.013857108308002353, 0.07892998214811087, 0.00696745202211397, 0.023094587360641787, 0.0268146793491074, 0.02120628547189491, 0.054831495442028554, 0.028038486805079237, 0.022567028079980185, 0.028291541351271526, 0.02099061820523015, 0.01693202036299876, 0.02964062163872378, 0.07553936980132546, 0.009371837468019553, 0.05164748004504612, 0.032587244774081876, 0.02833950529540224, 0.004394979457304413, 0.04071253538131714, 0.012287792516872287, 0.011615024197713604, 0.029352040695292608, 0.02129071219159024, 0.06335049242313419, 0.04051444047529783, 0.05745732757662024, 0.020632034500262568, 0.017260892715837275, 0.054274706569101126, 0.04561600262033088, 0.048691384560827694, 0.033297535231603045, 0.020445308448480706, 0.048143311470214806, 0.020196136818932633, 0.0027986248938499814, 0.07571494073740073, 0.019300911642078842, 0.030259292905351946, 0.010027700935357382, 0.04837238149983542, 0.04327799825529967, 0.03253904503903218, 0.04982380861682551, 0.058969748206436634, 0.03554327919014862, 0.011973615536200148, 0.028260561138657585, 0.0379343653496887, 0.028655962153737034, 0.03479543521202036, 0.027999827272391746, 0.0156823929532298, 0.05791882638420377, 0.015065117772402508, 0.03460567271603005, 0.026295025001413057, 0.03454447564269815, 0.0883815542661718, 0.014364543936348386, 0.028659385362906114, 0.03946960511218224, 0.04033817743350353, 0.038853386749646494, 0.020956416647615175, 0.14247952960431576, 0.023809496945302402, 0.05275414012638586, 0.03311406954058579, 0.0266699444369546, 0.023335557198151946, 0.029782377782144716, 0.09392361116728612, 0.017158164210351448, 0.03719596657902002, 0.07195787876844406, 0.017170267578746592, 0.00875279979248132, 0.023338249285838435, 0.024883595827434744, 0.03677861325974975, 0.09312576255095856, 0.02347836846352688, 0.006061255782177406, 0.09050477176372494, 0.03332394381452884, 0.022170841660616652, 0.018415613432547877, 0.013239511671209974, 0.053160090664667745, 0.019397027823807936, 0.06396707719458, 0.043864493391343524, 0.0480902500317565, 0.015777817029239874, 0.044346623056169064, 0.035557687881269624, 0.036986367111759524, 0.05473165240670953, 0.022540923141475235, 0.04904038904766951, 0.01788203893894596, 0.06513851362147502, 0.02261390636808106, 0.04232002215992127, 0.029865423683077097, 0.040401606887046776, 0.044218013528734446, 0.036101523520691056, 0.06491227647555725, 0.019681613892316818, 0.0397412769629487, 0.061283824034035206, 0.03991647131208863, 0.010285960693311478, 0.009379946809661175, 0.05779628295983587, 0.023771285245727216, 0.017673104436003735, 0.03071045083925128, 0.10144821847123758, 0.04997852138642754, 0.05599241118345942, 0.043733933075730286, 0.03356027416884899, 0.09686478227376938, 0.012280762045910316, 0.03029332822188735, 0.05226576793938875, 0.04746991974700775, 0.030084241048565934, 0.016441880592278073, 0.018581781569602232, 0.040394573871578486, 0.0429084375500679, 0.06665214882897479, 0.048976810316422155, 0.03180763857173068, 0.03170310007408261, 0.025376061276931847, 0.04664793224739177, 0.04198729233550174, 0.020454188775537268, 0.045938303361513784, 0.05905551503279379, 0.05360518249550036, 0.01779573267724897, 0.1006850226383124, 0.12464104752455439, 0.20032098942569324, 0.09660824853926897, 0.10968600679188967, 0.1178509204515389, 0.1336282438465527, 0.08357417437114886, 0.11167760885187558, 0.05615168370838676, 0.1109897643327713, 0.1665338674294097, 0.15588461314993246, 0.12377351336181164, 0.17105643903570517, 0.09179296371127878, 0.12796003371477127, 0.2142604057277952, 0.11826824662940842, 0.08576629031449556, 0.1173160041549376, 0.08159364600266729, 0.10223020293882915, 0.0940669991874269, 0.11303954398525612, 0.1133083456328937, 0.21807662237967762, 0.1786788571625948, 0.10921575488256556, 0.2257221242679017, 0.09178421060953822, 0.11232075826930148, 0.08574285371495144, 0.1245037391781807, 0.1847642713359424, 0.12741755853806222, 0.1492927675800664, 0.07656312308141164, 0.1741214088563408, 0.10888832780931677, 0.18131474857883795, 0.1368665929351534, 0.16599287145904132, 0.15110578600849423, 0.09171115952943053, 0.16492919996380806, 0.10489556313093219, 0.08847646095923015, 0.1701877106513296, 0.13235797200884136, 0.12687253206968307, 0.15567064391715185, 0.11472400038370065, 0.1410401261278561, 0.1595871073326894, 0.1256512776017189, 0.08846147212066821, 0.16549926437437534, 0.11805909499526024, 0.16099472822887556, 0.1583861546324832, 0.089726193541927, 0.10627028186406408, 0.15981020964682102, 0.056696089317223856, 0.11609246980931077, 0.15775222650596074, 0.07484273825372968, 0.15956795907446317, 0.12570364693445818, 0.19257138669490814, 0.11696400732866355, 0.19690901679652079, 0.1340375090284007, 0.14483274333178997, 0.0828014247651611, 0.08901622878121478, 0.10632635599800519, 0.10174429722662483, 0.07024178228207997, 0.0801520576434476, 0.15539749286004476, 0.18274687815989765, 0.1520628867936986, 0.12025406078568526, 0.11920834332704544, 0.18509618352566445, 0.1568337750754186, 0.1731954121163913, 0.14107042950178894, 0.0889802732105766, 0.15547452015536173, 0.15963582614702837, 0.18215830331402166, 0.2542967402509281, 0.12478854746690818, 0.20448544381984643, 0.09346469079277345, 0.1437980859939541, 0.18212475654269966, 0.09635584708303213, 0.2190916564847742, 0.07855909490691763, 0.17684203572571278, 0.13163645858211176, 0.07536622802061693, 0.10238625242241792, 0.11318453334804092, 0.18907089238720282, 0.13736169279686042, 0.1768608447164297, 0.10727303448532309, 0.20201989183468477, 0.17838765707399162, 0.14961831511131354, 0.16069668850728444, 0.10862428947751011, 0.0795956114307046, 0.08910223988017865, 0.12216428614088468, 0.09217553532549314, 0.12494876315551144, 0.10508135280438832, 0.14347622969320842, 0.14324152443025792, 0.14705132214086397, 0.2562203327459948, 0.1839032918214798, 0.08936608822218009, 0.23008283813084873, 0.1683725073401417, 0.1776991475905691, 0.14644677458064898, 0.13380912771182402, 0.15242556376116617, 0.13249442540109158, 0.08178571212504591, 0.10423803555646113, 0.19289103097149304, 0.09070648665406875, 0.1771802447204079, 0.18177354681704724, 0.1601177624293736, 0.07382378221622535, 0.16471041313239507, 0.20982349238225392, 0.13372315732496126, 0.1552390277917896, 0.12481274402567319, 0.2239292176174266, 0.15551012967314037, 0.15366277737276895, 0.22832453676632472, 0.07366599568298884, 0.18580271489918232, 0.17806109174021653, 0.11491295881569386, 0.1435375828295946, 0.12801471006657394, 0.10260762447225195, 0.0518866568537695, 0.10208258764552218, 0.19194044412246772, 0.12384199111589364, 0.2025247761713607, 0.13817600267274038, 0.060107067892594, 0.0969380165583321, 0.1074174606640424, 0.12177491560578346, 0.13809012728078024, 0.08510432512100254, 0.14446538447269372, 0.1665752309241465, 0.1264969493661608, 0.07891285592424017], [0.03778575600257941, 0.0491331719261195, 0.0464009692493294, 0.01283307428405221, 0.033551979078246016, 0.0454521771254284, 0.055917585734277964, 0.06796939564602715, 0.034788174887320826, 0.018863960535132458, 0.0393752446398139, 0.03762371844745108, 0.028409496182575822, 0.06412345916032791, 0.036526476432170184, 0.04145190106438739, 0.022725464310497046, 0.02487281899500106, 0.029447408792163645, 0.018042324177388634, 0.061734859831631184, 0.04962844481425626, 0.018393459264189005, 0.011977638400691961, 0.04444803690005626, 0.03256147062139852, 0.0036167935135641266, 0.06267626610185419, 0.07493842526205949, 0.008468694635666907, 0.02696018439850637, 0.014377554845330971, 0.014436409276510988, 0.037696786490934234, 0.042371051385998726, 0.013239709294534155, 0.017061405116692185, 0.06804350524076394, 0.015425699763000011, 0.01442481141670474, 0.06869643913315875, 0.06202401752982821, 0.0309392155281135, 0.008224826605458344, 0.010205973288975656, 0.0203967914983098, 0.03239150099190218, 0.02315064113853233, 0.013808000184196447, 0.03345262798081551, 0.06888421012886933, 0.022178785609347478, 0.04394647738497172, 0.05999103161905493, 0.0022148369004883406, 0.04326201197026031, 0.088289979180055, 0.039827942848205566, 0.0070211152363169405, 0.05162036239302584, 0.050823962448963096, 0.09853226172604732, 0.02361631124014301, 0.04014801460185221, 0.01969326942759965, 0.0275024373549968, 0.07788788128112044, 0.025651541405490468, 0.019042474616851126, 0.016581960754202943, 0.01489917015922921, 0.044750877256904326, 0.027330730675852725, 0.04910728920783315, 0.04321222446326699, 0.07363704259374312, 0.027381870163870708, 0.02224924129300884, 0.0429945843560355, 0.054652335055704625, 0.03498700261116028, 0.022737844181912284, 0.06318781365241323, 0.04337645707918065, 0.03615503279226167, 0.028574975606586252, 0.0649390582527433, 0.030843752436339855, 0.03982859763449856, 0.020567911244662743, 0.021028485548283373, 0.034409375927810154, 0.059088057572288175, 0.020351641778168932, 0.03480220359883138, 0.027251146999852996, 0.02703107095190457, 0.00607572469328131, 0.07920908395733152, 0.04884565288999251, 0.020917078579909036, 0.031212668533303907, 0.05411422625184059, 0.057513496705463955, 0.04992662363552621, 0.015316223226753729, 0.055645167494990995, 0.0473234986753336, 0.0774026337478842, 0.02399411444951381, 0.03513062811855759, 0.06276573094406299, 0.022194480124328817, 0.07341322103249175, 0.03742196963035634, 0.030471297779253552, 0.04756416826109801, 0.05430822619902236, 0.012583026496161307, 0.038345845948372564, 0.04953396559825965, 0.01680306308636708, 0.009597119575898563, 0.03302258944937161, 0.036502703957791836, 0.03281072028247373, 0.058196136860975196, 0.036615150781082254, 0.030483450341437544, 0.05287795241123863, 0.014825121632644107, 0.06053248220788581, 0.026879157139254466, 0.020393529441207647, 0.038210725877434015, 0.02828139386006764, 0.0758168702679021, 0.06410090465630804, 0.013387472169207675, 0.011972134633521949, 0.07498391424970967, 0.04114109131374529, 0.030550411569752862, 0.017433571396395564, 0.029298314292516028, 0.08430938741990499, 0.06685055925377778, 0.09197050918425832, 0.03890889769952212, 0.009915404237939842, 0.052055394942207, 0.042452652007341385, 0.024234700914738432, 0.038178777056080956, 0.03623568346457822, 0.0548877018902983, 0.019159459143078754, 0.010852292313107421, 0.028183106366278868, 0.05970770253666809, 0.0173526255613459, 0.035397010788853676, 0.039219025522470474, 0.033026460491653, 0.031706190801092556, 0.022185428467180048, 0.04395938651370151, 0.020092587286074246, 0.04341919460733022, 0.021398534798728566, 0.06687970233282872, 0.021855360196371163, 0.02877853950485587, 0.014633830736524292, 0.016685881784984043, 0.027415539071496044, 0.08046041788267237, 0.013498615357093513, 0.05101331103859203, 0.0149189307953098, 0.027179383439943194, 0.033296690455504825, 0.027298600346382176, 0.03077863682327526, 0.01327198720537126, 0.01380350234519158, 0.04167318829734411, 0.040430264813559394, 0.008780555267419134, 0.017364253955227987, 0.012688025549453284, 0.036270485525684695, 0.02158629222373877, 0.021070697211793492, 0.007157499502812113, 0.02261792668806655, 0.03481641212212188, 0.06799593993595668, 0.022929230072934712, 0.026814375704686557, 0.01711311118145074, 0.0571898626429694, 0.014578228184421147, 0.030298298490898948, 0.01710829697549343, 0.041818384613309584, 0.05665560791801129, 0.061623607229973586, 0.027368905056001883, 0.021046853491238186, 0.028863261387284313, 0.03550655687493937, 0.02148325668115701, 0.03663473330172045, 0.01078899432572403, 0.06143255891012294, 0.025253736680107455, 0.01870852173306048, 0.014050789343725358, 0.029161918575742414, 0.04465730727783271, 0.02756308311862605, 0.052634256559291055, 0.014288286778277584, 0.04704265981646521, 0.029128443050597395, 0.055023045877793005, 0.023993680187101876, 0.011038736772856541, 0.025693788692089062, 0.0015655758969452499, 0.05308799971161144, 0.04775516569082226, 0.05206827353686094, 0.018292079347052743, 0.04652816063857504, 0.037878929038665125, 0.04488634677337749, 0.036607629220400534, 0.04545262156586562, 0.0202718104368874, 0.047859049402177334, 0.05471210381282227, 0.05058466350393636, 0.04127905105373689, 0.035026713873126676, 0.02183276498025017, 0.02635148759665234, 0.023907703014888933, 0.013590165846315878, 0.04588941830609526, 0.07202627509832382, 0.02816368330137006, 0.018408373463898897, 0.08709940806563411, 0.027066943402002965, 0.06148041598498821, 0.02005695062689483, 0.02404721320739814, 0.01793196045660547, 0.013576182935919081, 0.004349390809823359, 0.023392878140189817, 0.02048416475632361, 0.04362009186297655, 0.004209296653113727, 0.007539154246582517, 0.023805527515443306, 0.0399134721873062, 0.02374425919593445, 0.056444108552698574, 0.054662621646587334, 0.009524650339569365, 0.030015376529523304, 0.03270146257377096, 0.018963540638131753, 0.05046070194137948, 0.03774055199963706, 0.044574336015752385, 0.01865925669803151, 0.0034991694680814233, 0.04202163977814572, 0.014409396797418594, 0.016672708027596985, 0.06042629826281752, 0.061916306880967956, 0.02703111675301833, 0.015568568703851529, 0.045184746118528504, 0.07721710870308535, 0.053372309277100224, 0.05980320634054286, 0.016255466666604792, 0.061359847097524574, 0.0488032851634281, 0.040816714255405326, 0.05051348178780504, 0.05027097676481519, 0.014012151015257197, 0.017424560451347913, 0.022359968030026982, 0.054894880790795596, 0.02579799640391554, 0.018772901135629842, 0.028792452865413258, 0.036120278228606494, 0.0203736975589501, 0.06918780705226318, 0.026475915652034537, 0.026056957597445165, 0.03510927122884563, 0.0842217206954956, 0.07533077456589256, 0.029685907065868378, 0.01206727626933051, 0.03823105478659272, 0.005252030678093433, 0.01804853107647172, 0.12079678023500101, 0.029517806800348417, 0.048915335043732605, 0.033098408952355385, 0.061930189707449505, 0.018730679294094443, 0.016091225569003394, 0.0346236708573997, 0.024870562866064053, 0.039280147956950326, 0.012366020819172263, 0.03319844537015472, 0.039491576076086075, 0.03876129936959062, 0.01733685640751251, 0.019309389937136854, 0.029122007145945514, 0.039578024830136976, 0.01093703879243029, 0.016204649482720664, 0.01794835046998092, 0.044773906735437255, 0.012751848553307354, 0.050147758198103735, 0.025000965422285453, 0.020592294400557876, 0.08893954075340714, 0.01087273148420666, 0.014123990549705923, 0.02957757216479097, 0.006879455360051776, 0.015702011096956472, 0.006348582708077239, 0.028870131554348127, 0.20394284650683403, 0.09536794080798115, 0.17560494425041334, 0.1468999409782035, 0.12744453709040368, 0.10897976718842983, 0.11761275465999331, 0.20674952518727097, 0.16487725132278033, 0.15833150542208127, 0.08987988850900105, 0.12019372545182705, 0.11569905520549842, 0.13768197489636286, 0.11703791336289474, 0.09188727329352073, 0.07552375671054636, 0.09408821697746005, 0.09758996657494988, 0.09230805999998536, 0.07227770624948399, 0.1236104206847293, 0.11004617996513844, 0.13519844173320703, 0.1328835923756872, 0.13833104792450154, 0.07991719631744282, 0.14379614538380078, 0.1872784878526415, 0.15033909572022303, 0.11049668650541987, 0.1746651189667838, 0.09053413875933204, 0.12455187445240361, 0.14431260552789482, 0.16644151881337166, 0.10894813388586044, 0.09350905341229268, 0.04514334869704076, 0.08931908610143832, 0.13451038008289679, 0.21415654915784085, 0.10536915343254805, 0.11322435656828539, 0.12899361896727765, 0.06868750961231333, 0.10919343786580221, 0.13452723489276, 0.14855502359569073, 0.14161238899188383, 0.21603353986782686, 0.10506415194166557, 0.24559664566602024, 0.12152704676347119, 0.1425250864454678, 0.12310055590101651, 0.12264008846666132, 0.1686587676938091, 0.1646196251468999, 0.12019392901233264, 0.1564022810863597, 0.142658228586827, 0.12927446461149625, 0.14900637151939528, 0.11445656259145055, 0.10613892426980392, 0.1295131053775549, 0.12381020853562014, 0.05640291469171643, 0.12315314236496176, 0.16000638769141265, 0.12241439414875847, 0.14245009475520679, 0.17490085560296262, 0.19339630885847978, 0.16243987211159297, 0.08923173828848771, 0.0982904386307512, 0.10823134984821081, 0.1717256781245981, 0.12982589645045145, 0.10099231079220772, 0.08733515827251331, 0.08429871406406164, 0.14958850028259413, 0.10013718703495604, 0.14747449729059423, 0.276475797274283, 0.22379512552704128, 0.07571228766547781, 0.15724802070430347, 0.14068432950547763, 0.12843544249023708, 0.17707108200660773, 0.12366004873599325, 0.1308362079518182, 0.0904904818162322, 0.16864645906857081, 0.2207573921020542, 0.21294495702854224, 0.13600447348185948, 0.3585814115192209, 0.15293385434363568, 0.13396006104137215, 0.10367760634315865, 0.15144645129995687, 0.13880813946681364, 0.12671239780528204, 0.19510901266975061, 0.16452372100736412, 0.1990187857300043, 0.12261069432965346, 0.13479003150548252, 0.17425919217722757, 0.21780165284872055, 0.1941937232123954, 0.16750242188572884, 0.15627107955515385, 0.0831659541332296, 0.15604695943849428, 0.07306138705462217, 0.07268433193010942, 0.12913646415940352, 0.14641036439154828, 0.17153837531805038, 0.0958851541259459, 0.2289402937250478, 0.13709901832044125, 0.20633796655705997, 0.19534002670219966, 0.2552081213465759, 0.2133945543318987, 0.09346783240990979, 0.12005643067615372, 0.1328894549182483, 0.1673137348677431, 0.15944431642336504, 0.16874988137611321, 0.08160975442401, 0.1883138915789979, 0.08825760627431528, 0.11190841932381902, 0.19955020078590938, 0.15154521885727132, 0.11172585269170147, 0.21294765759791645, 0.19151004936013902, 0.19216730552060263, 0.14315753536564962, 0.10052882387701954, 0.13097131784473146, 0.08940536182905946, 0.1424717671637024, 0.0865490890241095, 0.1833424283457654, 0.13154318715844834, 0.11181811309818711, 0.10522111066217933, 0.10225501017911093, 0.14961401319929532, 0.10335465081568275, 0.109803617266672, 0.10132830097739186, 0.06756650190800428, 0.049594423068421226, 0.07648135282631431, 0.15401489633534635, 0.06409337970295123, 0.17961652470486505, 0.0693824855344636, 0.10802394204906055, 0.12177365353064877, 0.10451016881104026, 0.11373593804559537, 0.11851994240922586, 0.12944506188588484], [0.016066369134932756, 0.04696397011035255, 0.04043516044371894, 0.033997908899826665, 0.04016569722443819, 0.029840473950441395, 0.0427285070264978, 0.03684507915750146, 0.04662224969693592, 0.05586102644779852, 0.08793026062526874, 0.037379883495824676, 0.044373713566788604, 0.018102513626217842, 0.047170889364289384, 0.04899436741002968, 0.01723430771380663, 0.012026486984853233, 0.02072165031651301, 0.028907810603933673, 0.09985995119703667, 0.04163166195420282, 0.0467958664521575, 0.05632218938054783, 0.027705875724287968, 0.006525824112551553, 0.02450499533941703, 0.02912012760394386, 0.020700035583493964, 0.02940406397517238, 0.0123852555906134, 0.04579283902421594, 0.03311587444373539, 0.04613720911688038, 0.036730301566421986, 0.04687134329495685, 0.0748398205531495, 0.008637820337233799, 0.05493983034310596, 0.06185658901397671, 0.034272440775696716, 0.05582969170063734, 0.02702532206395907, 0.017335597725052918, 0.019269012014514635, 0.033556542226246426, 0.04168640276683228, 0.07282334339937993, 0.07538886394883905, 0.059250342792698314, 0.05695787152009351, 0.035874092153140476, 0.0033693555409887005, 0.02391529412541006, 0.014004651506963586, 0.0888822791831834, 0.010904034000954457, 0.02456598206689315, 0.032810930628329515, 0.01654337246769241, 0.04536021527435098, 0.028421823467527117, 0.040884852741978, 0.05860736979437726, 0.043302595149725676, 0.034131794037031274, 0.014303468999319842, 0.04712566839797156, 0.07059434907776968, 0.01909850973502866, 0.06954141879188162, 0.02287971058727375, 0.03777703682758978, 0.028287938330322504, 0.055384572728403976, 0.07115421510700669, 0.04693800596786397, 0.10763306516621794, 0.016719542210921645, 0.040486389837626896, 0.037681563557790856, 0.004628363273306084, 0.06721315479704312, 0.04258694765823228, 0.047354938595422676, 0.02529090004307883, 0.04598419607750007, 0.04667383532172867, 0.019259261466296654, 0.0005002080111548171, 0.015501470072194934, 0.021690503328240344, 0.01928179900694106, 0.03480339103511401, 0.042279455943831375, 0.022528860485181212, 0.02871870289423636, 0.004227886816287147, 0.015323062859741705, 0.0591196230213557, 0.03448979589822037, 0.015059828591932143, 0.028322548705286214, 0.035816267398851256, 0.05691888629059706, 0.10633555693285805, 0.019809300612126077, 0.024302951359589185, 0.016394859811823283, 0.040111112474863014, 0.06305898699377264, 0.026337341837851063, 0.13408177665301732, 0.007001323642076126, 0.010369737715726452, 0.04332850840208786, 0.02685979174982224, 0.11772670783102512, 0.05466773780062795, 0.047623855594013415, 0.02472014691946762, 0.032829318927334886, 0.032884412578174045, 0.08630755091352121, 0.04268745565786958, 0.034143000042864254, 0.020693192557830895, 0.07006350399128028, 0.07870858974222626, 0.058401020509856086, 0.05841334949114493, 0.022904885932803154, 0.01281322628658797, 0.012864476884715259, 0.011451391237122672, 0.08070186778370823, 0.03162316186353564, 0.03394336146967752, 0.010960803633289678, 0.052249323643211804, 0.1197370035307748, 0.03528084898633616, 0.0218954039404967, 0.044122621683137755, 0.033629165829292366, 0.02936540444248489, 0.02639187908997493, 0.050481024065188, 0.027960864095283405, 0.006936330165314887, 0.018463580769353678, 0.02633829178687717, 0.05087994498067668, 0.05549010867252946, 0.0411577052436769, 0.0499400857702962, 0.04787103911595685, 0.03324503019186003, 0.10852246172726154, 0.04997809390936579, 0.016658307818163718, 0.05168033471064908, 0.0018282161285502038, 0.033768608168299706, 0.04813802907509463, 0.061064826856766424, 0.03972309222444892, 0.041107429191470146, 0.05285623589796679, 0.030262085076953684, 0.002734502698461126, 0.06091018194066627, 0.03154136446703758, 0.02516927942633629, 0.059057299579892836, 0.03543491375499538, 0.06676245148160628, 0.029556859883346727, 0.088373520411551, 0.052153361828199456, 0.060232271174235005, 0.02182785577939025, 0.027752112796796218, 0.0394456799674247, 0.07843488228640386, 0.07604166213423014, 0.02753172462273921, 0.01204248599242419, 0.07010624491210495, 0.04156051755749753, 0.0370952210921262, 0.05013599579355546, 0.010520617610641887, 0.023972660868561695, 0.034628725943288634, 0.04722266158621226, 0.04410365323669144, 0.05607666487672499, 0.013245503983593412, 0.025837906137374893, 0.06813686487397977, 0.07360770952488695, 0.026443556316995194, 0.04536758077197841, 0.043274941455040655, 0.012298630417457648, 0.020403856744191477, 0.020368552567171197, 0.01985011958251042, 0.041070981682943444, 0.0075817772719476905, 0.031030661692576747, 0.05363224586471915, 0.011980235493475837, 0.0626500542940838, 0.02989404768283878, 0.04568034131079912, 0.021556463824318986, 0.029733906633087566, 0.021328693189259087, 0.03651333660153406, 0.006389808375388384, 0.04684513148718646, 0.05657269772408264, 0.02930147626570293, 0.06535086115556103, 0.05123285782922592, 0.03542921406083873, 0.02308826002159289, 0.03693142952397466, 0.044430062507412264, 0.05425152102751391, 0.009112355498863118, 0.037864499991493564, 0.06899182578282696, 0.04751568693401558, 0.037651592666017156, 0.04954693240246602, 0.008006741209620876, 0.037605011236986945, 0.038783572281577756, 0.058515903273863454, 0.09773963782936335, 0.028337052391309823, 0.020459812134504318, 0.023707840525146042, 0.020938043615647724, 0.022873193258419633, 0.031145096623471806, 0.014723224332556129, 0.037605048556412966, 0.06324087509087153, 0.010058228225846375, 0.06687922057296548, 0.026577974104189446, 0.061361699498125484, 0.0621852238795587, 0.017200411496950046, 0.03419780870899558, 0.011008182340966803, 0.06816711396511112, 0.03449060335489256, 0.03254648856818676, 0.02487388768765543, 0.031971348715679984, 0.04750606530745115, 0.008397298332835947, 0.05486630089581013, 0.026534313768414513, 0.008400945458561182, 0.04839731426909566, 0.02850533077227218, 0.027873034522469555, 0.024133777312402214, 0.018358175443219285, 0.04309446131810546, 0.05031278469998922, 0.024409973295405507, 0.028442673152312636, 0.04246809885704091, 0.0332450437625604, 0.040811045095324516, 0.03057868273130485, 0.062022809737495015, 0.08888133601950747, 0.028645651814128672, 0.07119464900876794, 0.02256963704712689, 0.03332034757893, 0.04519071722669261, 0.027094429159270864, 0.027466554726873125, 0.06446206849068403, 0.08135229109653405, 0.06284572343741145, 0.03317422506266406, 0.03509134094097784, 0.04998592420348099, 0.007969911176977413, 0.06500142240630728, 0.01769817969761789, 0.009125217978310372, 0.02085901633836329, 0.04103894125936287, 0.051063922965633016, 0.036228504564080916, 0.02499209188057908, 0.051000486726739576, 0.03331209320042815, 0.02041783626191318, 0.03325956441195948, 0.04327895159700087, 0.07451451050915889, 0.03002361733732479, 0.03822338055553181, 0.08275455835142306, 0.07677382856075253, 0.036656717836324654, 0.053340153502566476, 0.028800110133098702, 0.019876872521958182, 0.01928464715768184, 0.0058975575125909275, 0.01576410553285054, 0.0326840242237917, 0.03319002814324839, 0.030927330987261872, 0.035374917688646486, 0.03878150614244597, 0.014998870702194316, 0.028582388601664985, 0.07235049270093441, 0.008279684465378523, 0.007316950991350625, 0.015013245466564382, 0.01056363757899297, 0.040223026648163795, 0.08182216981159789, 0.00996736390516162, 0.021290603625987257, 0.05701061404709305, 0.025425543443166783, 0.0403006883737232, 0.048154554795473814, 0.044544066568570476, 0.020360025078324333, 0.019420700214271034, 0.01932132876078997, 0.051939490982996564, 0.022076223344941224, 0.018613458976947835, 0.015013767938528742, 0.10740982714508261, 0.09008662455848285, 0.20326216731752667, 0.13342229489769253, 0.2150477777634348, 0.1459860493029867, 0.09501711784728936, 0.17256043904594012, 0.3510225314114775, 0.08467302790709905, 0.12726503743657044, 0.11393215001693793, 0.19844507080103668, 0.10868533727313791, 0.2429184950888157, 0.18543781233685358, 0.08277460906122412, 0.09704621575240578, 0.1614349888903754, 0.11309602524020843, 0.17448750564030238, 0.11017912533134222, 0.11715350858867168, 0.15378787208880695, 0.14083370220448288, 0.10399041098675557, 0.07743065724415438, 0.1039776952405061, 0.10015404863016945, 0.11442849838307925, 0.0628893260977098, 0.13911130891314574, 0.0664735651974167, 0.12317618541419506, 0.08116443867662124, 0.0993401323046003, 0.17275778417076382, 0.06531442382505961, 0.09745788973356996, 0.21914082313222544, 0.11217116165374007, 0.15516193264297076, 0.11253985722682305, 0.06347582462642874, 0.14876139323626245, 0.07762828056833573, 0.14526391162403993, 0.15647691993841104, 0.11168705405933516, 0.1675697597009795, 0.1420108518962349, 0.14133085124194622, 0.052759653223412376, 0.13337745730366024, 0.16865294586334909, 0.18923694347696646, 0.08752816077321768, 0.12353457404034478, 0.19974599885089056, 0.08991476520895958, 0.13366572612098285, 0.13065944957946027, 0.11772015318274498, 0.09112382640263864, 0.11932324644710336, 0.11957055889070034, 0.14939230866730213, 0.1019065620909844, 0.1627741998859814, 0.10379384617720332, 0.15013482953820909, 0.07365687617233821, 0.18110057578555175, 0.08907786011695862, 0.1687539525862251, 0.14238255337945052, 0.08822834105896098, 0.14888243031288895, 0.13278783751385553, 0.17927934708339827, 0.1434840599873236, 0.14031256016876015, 0.1561864119555269, 0.17977224849164486, 0.15869559374238762, 0.15545252205005713, 0.13679663597473077, 0.1688788030296564, 0.11751252146703856, 0.10603363599096026, 0.1532660922301667, 0.09758111169295651, 0.13240648726267473, 0.1396441353218896, 0.14419800096324512, 0.1362289735781295, 0.1702219359576702, 0.11724021179335457, 0.1341012641787529, 0.13989034853875637, 0.11016446897493941, 0.13198031298816204, 0.08491861687174865, 0.19989685075623648, 0.10665701289794274, 0.26897176993744715, 0.12120585542704378, 0.13488137588969298, 0.1513242335723979, 0.11787405849567481, 0.11792960337230138, 0.13580199863229478, 0.21362436057201453, 0.1680294128933123, 0.10687639684017215, 0.14884178606527193, 0.19928736346108572, 0.18621130154601165, 0.21658848651817866, 0.1552110178662198, 0.1208957377821207, 0.18927728916917527, 0.0985285501394953, 0.17899042687245778, 0.13784489115434034, 0.09610436843442065, 0.19417707196303777, 0.1001811900309154, 0.16172575471656664, 0.1383529646056039, 0.09095083389963422, 0.1032194255718163, 0.12108453336570944, 0.08155404669897896, 0.12979563378861972, 0.13313371395426138, 0.17561293739293302, 0.14197543236826146, 0.14849649316498212, 0.1528954492615802, 0.1536865532398224, 0.10185371099838189, 0.1125702555956585, 0.1015979168670518, 0.1621645497424262, 0.1330076285770961, 0.2240015630211149, 0.09876334361199822, 0.09801610692271165, 0.07799331205231802, 0.10193063651344605, 0.11860714772982256, 0.09588247391262225, 0.1537397096731833, 0.13230003868894918, 0.1725656094827822, 0.15253552714628832, 0.10252181693379368, 0.17939229602260248, 0.12797479863677705, 0.1297630641077246, 0.172886922955513, 0.07456161441015345, 0.09776580892503262, 0.2614458937730108, 0.2674760887665408, 0.12837372294494084, 0.09823834749736957, 0.2020286585071257, 0.08114729209669999, 0.08867577383560793, 0.14547974004277162, 0.09315490563000951, 0.13419359922409058, 0.1682389173656702, 0.13416375725397042], [0.035875293160123486, 0.08135791615183864, 0.02985572741766061, 0.012657591557529355, 0.033149129444999356, 0.03171322720923594, 0.0464013661923153, 0.06519036726760012, 0.03329812894974436, 0.021086010050826838, 0.007782458244556827, 0.02142434287816286, 0.01575133720013712, 0.03592670236581138, 0.03279471703405891, 0.028004656745386974, 0.005898275487457535, 0.02029108252775456, 0.0015228112273949332, 0.03748824214562774, 0.007931489979715219, 0.05554859499846186, 0.045931063392864804, 0.009952113830617495, 0.024789189553952644, 0.059275319666734765, 0.055260054767131805, 0.05655512027442455, 0.10112582612782717, 0.046902610188616176, 0.026087500154972076, 0.04061645143000143, 0.055319976194628646, 0.015603036586461323, 0.028657661883958747, 0.05007129069417715, 0.06998651062271424, 0.019797986040690115, 0.039042368930365355, 0.03258364175313285, 0.0037591730610334446, 0.015389467689341732, 0.019906487182847092, 0.0365022696953799, 0.024066792335361242, 0.045464383970413885, 0.027190938891310776, 0.019628325144627264, 0.01914150849916041, 0.07221215298133236, 0.015986290128369416, 0.04617318504356912, 0.041139174452317614, 0.030111986345478466, 0.03487351762929133, 0.034347870121044774, 0.06354839394667319, 0.030516627311174358, 0.061316821191992076, 0.05614243188340749, 0.046335541510156224, 0.02821862937084266, 0.09098198544234037, 0.01600569622990276, 0.050189230258443525, 0.021400544958721315, 0.04286117419334395, 0.02186828968115151, 0.07837022468447685, 0.023687706694805195, 0.06109986640512943, 0.033333769001598866, 0.023336653032207062, 0.0044997986988164485, 0.0935761673109872, 0.022651712642982602, 0.014575434316481863, 0.055265717141862424, 0.05820954471294369, 0.00669575811895941, 0.04897513772760119, 0.05599766304450376, 0.04408160084858537, 0.0352039709687233, 0.0565341603276985, 0.007871212321333587, 0.029673411843499968, 0.053922479040920734, 0.06653734070381948, 0.022385016150240387, 0.016644876217469573, 0.034531725969697745, 0.09434498819921698, 0.03502104810572096, 0.04733423649200371, 0.055224380788526366, 0.03495071455836296, 0.007028753420204988, 0.0298476494582636, 0.0316090279790972, 0.06377955047147614, 0.03738308957378779, 0.030673657277865068, 0.05166651634499431, 0.049254992710692544, 0.01635612903295883, 0.03944558836519718, 0.040517914574593306, 0.0825936302010502, 0.01304016147540616, 0.05941408686339855, 0.023419843121830906, 0.05954748684806483, 0.0679075743204781, 0.05645985735048141, 0.009626420414341348, 0.02846452367625066, 0.006317455338181129, 0.046360216436109374, 0.01833843346685171, 0.06332742223250014, 0.011264337792194315, 0.015655170128281628, 0.06128082490925278, 0.04358639242127538, 0.043650907530848465, 0.036535833430077345, 0.021938952317993556, 0.03854426994387593, 0.0249143911392561, 0.045153893131230555, 0.037170355274741135, 0.038266063800879886, 0.05489328623350177, 0.011769328998135669, 0.04366203211247921, 0.056956772293363295, 0.021941461201225008, 0.04079638534624662, 0.06947195716202259, 0.026939144723915627, 0.08084291485803467, 0.02588796505837568, 0.053909722582570145, 0.024080351161371385, 0.01964615874125489, 0.0353996604681015, 0.016748111927881837, 0.009680466576745468, 0.03064411725582821, 0.039804594458213875, 0.034123023971915245, 0.020798063537638103, 0.02687947605071323, 0.033290817734918425, 0.01358806069142052, 0.014430295675992966, 0.004619404490637992, 0.02050799660251609, 0.03225702213655625, 0.007246049170914505, 0.053157166178737364, 0.014241495003391589, 0.07048162405512162, 0.029557558774415935, 0.007372177804687193, 0.03996529869203057, 0.012464104752455438, 0.034011598343827894, 0.010662288089016718, 0.008461191734698201, 0.04126396043492215, 0.07286254236740725, 0.02377785516104528, 0.05397139123774, 0.020261338945212107, 0.0302486229421837, 0.025366577053708688, 0.03339476251442518, 0.042995639477989504, 0.03791642488379564, 0.02160305203869939, 0.036049120261200836, 0.042130975518375635, 0.019889496665980135, 0.020557916423838054, 0.06430164245622498, 0.044186509147818596, 0.024317887611687183, 0.007893531882603253, 0.016801371837833097, 0.04895294963249138, 0.034405752550810575, 0.03066426974588207, 0.02945253512422953, 0.013824363056171154, 0.03708070383540221, 0.06090552040508815, 0.07822706736624241, 0.02495843654365412, 0.036681338479476314, 0.05083426261054618, 0.027430422737130096, 0.02508627254116748, 0.0876270979642868, 0.03126736184848206, 0.06432754892323699, 0.04237431513943842, 0.034170501067170074, 0.022537713670837026, 0.04997064020218594, 0.007347178030093866, 0.03116246372727411, 0.019237745120855312, 0.02988218349803771, 0.02316735515237919, 0.0957971481340272, 0.0478847692720592, 0.06059878186455794, 0.021834661485627294, 0.015706508087792566, 0.0361671141082687, 0.0416066240120147, 0.024361734544592242, 0.03973563833694373, 0.03115770380411829, 0.03423372696020773, 0.04496266839227506, 0.02121795797055321, 0.05409858601966074, 0.08052452587123428, 0.049374520046902556, 0.06143141897129161, 0.02977263062660183, 0.07039283774793148, 0.03645497241190501, 0.029435486931885992, 0.06535898321973425, 0.03742789324106915, 0.04396697932056018, 0.030005320640546933, 0.039888780297977586, 0.0389258271482374, 0.04224766657820769, 0.030289253619100367, 0.00998662072899086, 0.057453758482422145, 0.07635933865926095, 0.026917463833732263, 0.034800123888999224, 0.034024191953774006, 0.02630246344155499, 0.021195001434534788, 0.03653591485427959, 0.048842192361397405, 0.05398787285334297, 0.07818077770727021, 0.04842865580160703, 0.039599273154245954, 0.047284930744873624, 0.056399963064385314, 0.039869377589119334, 0.02683662317161049, 0.10033554996230773, 0.0544327577309949, 0.022192251136792556, 0.04976515944248863, 0.044129074551165104, 0.04616492048704198, 0.058652763787124834, 0.03202295808919838, 0.06820962418402944, 0.015685690633420433, 0.036035953289163966, 0.034159281490636725, 0.056477282129760296, 0.02011387292960925, 0.0175861705294145, 0.025721820670046976, 0.028835526268397058, 0.0645859893411398, 0.052272658462503126, 0.013037716204832708, 0.013730444479733706, 0.022426079393231442, 0.01898396114951798, 0.010325971358854855, 0.021425576115559255, 0.03572971007919737, 0.04980257047074182, 0.015154837065243294, 0.043794003780931234, 0.012702584366447158, 0.00505356554640457, 0.05921578500419855, 0.004471823124081961, 0.04367271564634783, 0.03510346636176109, 0.017642193773229207, 0.01265842021842088, 0.049687233088271957, 0.052143913228064775, 0.04288619177948151, 0.02927594638562628, 0.05424478656745382, 0.04964486536170755, 0.006978663541043976, 0.04975943260693124, 0.09550442134163209, 0.020239401908059205, 0.024914403013618927, 0.03372899190123592, 0.022970191535672972, 0.021504026638077836, 0.022893327088760476, 0.03442362516320177, 0.0511638338544539, 0.004127928430014955, 0.006592411722522229, 0.025263185280242136, 0.04741989475275789, 0.028117242668356215, 0.015767245453649333, 0.01510787904927773, 0.01287013925944588, 0.03217579810214894, 0.02643866916852338, 0.05045397087399449, 0.03674733279539006, 0.08863289042242936, 0.038074347124035866, 0.010239771966423308, 0.032557406196636815, 0.05516057814072285, 0.007738730903448803, 0.04736091309626188, 0.013120796880684793, 0.0991550347368632, 0.02762455160596541, 0.014820651783208762, 0.007837774115614593, 0.046459906801049194, 0.05265420888151441, 0.08756417741200753, 0.02065620561396437, 0.06901948287018708, 0.0036984607161554906, 0.05820606382829802, 0.08823599493397133, 0.013726460631005466, 0.05344900409025805, 0.029960679821670055, 0.08734798936971597, 0.12104607400085245, 0.1355638328407492, 0.17739437680159295, 0.1392078644462994, 0.12603238358029298, 0.13304103964141437, 0.15733688165034565, 0.09847922064363956, 0.10626776449914489, 0.07289631305528538, 0.09485276309507233, 0.07736851700714656, 0.09964241965540818, 0.06544097060603754, 0.1702288163027593, 0.11252574369843517, 0.09143493470868894, 0.10818229855171271, 0.1147765868476459, 0.12129825832588331, 0.10921497456729412, 0.1503470888627427, 0.09834894192005907, 0.07648617721029691, 0.142638944621597, 0.1333739696336644, 0.16533040414963449, 0.1788295190781355, 0.13663199623780592, 0.12348079335476671, 0.13786399870046548, 0.1257889794984034, 0.11739752335207802, 0.10544746315905026, 0.10670426607664142, 0.08033824086721454, 0.15735560921686037, 0.11558192649057933, 0.07829251885414124, 0.17366248848182814, 0.09324909986129828, 0.12364053406885692, 0.1397701935576541, 0.08140140346118382, 0.11692058108747005, 0.1109490997291037, 0.07673856509583336, 0.10239767895213195, 0.18220493224050316, 0.08094403014651366, 0.13758015393146447, 0.19643354016755307, 0.16215766939733708, 0.1765309138489621, 0.09059051144868135, 0.165195796372635, 0.18602844992918627, 0.1450948342680931, 0.1019847361104829, 0.1102147823465722, 0.15286173964185373, 0.15774409765643732, 0.14411345549992152, 0.19306618800120695, 0.1302737295627594, 0.1630006813045059, 0.13877951885972703, 0.166338232212833, 0.16002325607197626, 0.21172249476824487, 0.16724888049066067, 0.06915337140006678, 0.12052721184279237, 0.21873845186616692, 0.1692349524902446, 0.06839737482368946, 0.11708389089575835, 0.15345643487359795, 0.09673950435327631, 0.15311594600124018, 0.13784069780792507, 0.1625684273562261, 0.1194210776260921, 0.15404625822390827, 0.07776247443897383, 0.10585294211549418, 0.19879837041454657, 0.10316373141748564, 0.1069141708846603, 0.16357176351760114, 0.14967670983501843, 0.22786096164158412, 0.1351094450801611, 0.0939676955874477, 0.35466528737119263, 0.10674798408789293, 0.12630529036479338, 0.12271026255828993, 0.14365192955093725, 0.16363897919654846, 0.09142308070191316, 0.08520293661526271, 0.14945379751069204, 0.1295537089130708, 0.11700340307184628, 0.13041844751153672, 0.07207127554076058, 0.15303777876709188, 0.09564882037895066, 0.12776373353387627, 0.07916259752320391, 0.12711649255028792, 0.10582538680838686, 0.0896592221355864, 0.1133611085159438, 0.13987016890730175, 0.1026108135868396, 0.14506324167762483, 0.14391032925673894, 0.10430548872266497, 0.09144068868564707, 0.08599823393992015, 0.15284567193261214, 0.1378342652959483, 0.15291549318603107, 0.11051993990050894, 0.11745214542107922, 0.19364131428301334, 0.13806451936917646, 0.08910697605460882, 0.09647008523877178, 0.14791470366929257, 0.12292862869799137, 0.06306653230318002, 0.13829239856983933, 0.17119229531713895, 0.20801755785942078, 0.13340510082031998, 0.15740295739046165, 0.1411829170371805, 0.1532553578061717, 0.06927066974874053, 0.16380068766219275, 0.14148981842611516, 0.09475447729762111, 0.06968032169554915, 0.06693555933556386, 0.0944313724924411, 0.17801539919206075, 0.057623948635799546, 0.10974574501493148, 0.1288510180477585, 0.09823724827063934, 0.15016415582171508, 0.09019530551241976, 0.07805959813828979, 0.13071362381534918, 0.10871590527572803, 0.07239613775163889, 0.09359038261962788, 0.11170504880802971, 0.20569225906261376, 0.18729707971215248, 0.16846545306699617, 0.1597284326063735, 0.21108027494379453, 0.12187818863562175, 0.08905273396521807, 0.13890084092106136, 0.11001749150454998, 0.12160157704991953, 0.20494178576128824, 0.05465874721163085, 0.12743938022426196, 0.07742911696966205], [0.05431840083162699, 0.02255031236979578, 0.04877092243571367, 0.034445653802582195, 0.03767010310132589, 0.028117217223293016, 0.022127520592351044, 0.019369272348870124, 0.024223248939961195, 0.013343251193873584, 0.02911209035664797, 0.07314197665878705, 0.021219075856996433, 0.024519577056967785, 0.00594880005311487, 0.08732892253569194, 0.03692145166652543, 0.007427128115003663, 0.054674977769276926, 0.029600869664656262, 0.04100647335872054, 0.01331863394339702, 0.044613826753837724, 0.012073629053442605, 0.08076116495898791, 0.08043607883155346, 0.07558490628642694, 0.00353511210414581, 0.01905782307897295, 0.05443539723221745, 0.029022177681326866, 0.019411818190876926, 0.028495034003364186, 0.03699137130752206, 0.03171953758490937, 0.008359812665730715, 0.03123573533126286, 0.034894806665501425, 0.01639188952477915, 0.022796571387776306, 0.008301155857874878, 0.04572564030864409, 0.015301610975127135, 0.03875822899863124, 0.04374313401058316, 0.02684767820340182, 0.05735357278691871, 0.015188899523179446, 0.025161082723311017, 0.031521961758179326, 0.029268414646919285, 0.049940306294177256, 0.04371156516884055, 0.06565288387771163, 0.050382008842591725, 0.07191733630107981, 0.022914880753627846, 0.04064984553094421, 0.04099493147805333, 0.02587131380901805, 0.04101905679064138, 0.038026395054267983, 0.02352122643164226, 0.01744255011102983, 0.028276019862719944, 0.03536381007039121, 0.02424406130532069, 0.020403585330184017, 0.03409405391929405, 0.03689420170017651, 0.047886068666619916, 0.034563264277364524, 0.016264299496210048, 0.06651470477559737, 0.021346967833648835, 0.001024148314692346, 0.04327969459284629, 0.05563876212441495, 0.01623176713474095, 0.018193143852321163, 0.019728848411302482, 0.05850643092500312, 0.01612335250579885, 0.05680213076993823, 0.04083232056083424, 0.08340799435973167, 0.03452393638768366, 0.028308033144899776, 0.028066761359306316, 0.05971845731671367, 0.005850408234566982, 0.04240392640765224, 0.007697577754567776, 0.050850320141762495, 0.02115849794686905, 0.04080102652577417, 0.05653771245852113, 0.03178349968844226, 0.060502497745411735, 0.022951979655772448, 0.023347601194732955, 0.0032592666268880877, 0.0036306271462568213, 0.023704812562625324, 0.033515154982783964, 0.0800944771617651, 0.05212642738063421, 0.027551419101655483, 0.05991768876888922, 0.01844487525522709, 0.07369401917925902, 0.02487720233122153, 0.03417947808546679, 0.044836182679448805, 0.02138437207655183, 0.10363444473062243, 0.0031031259651561932, 0.07720569574407168, 0.011344512641829039, 0.03491130524447986, 0.0333439436342035, 0.08195174285875899, 0.06411442107387952, 0.019605617970228195, 0.027375189986612116, 0.032600147117461474, 0.01611241282496069, 0.03877832042053342, 0.07783668581396341, 0.0467518872049238, 0.042591483664831946, 0.042528529185801744, 0.056826513925833363, 0.04064730102462428, 0.0377999713112201, 0.017895404382475784, 0.006496932091457503, 0.051370054217321534, 0.05635475906144295, 0.03902475076860615, 0.023028665987242545, 0.0723579769421901, 0.01943763475199895, 0.01969414304143616, 0.036808326308216364, 0.04768321044476969, 0.03782199316525033, 0.043583281338214874, 0.015478264174557157, 0.040188920085451434, 0.04064525863421815, 0.014604833542502351, 0.011317702026904693, 0.048071566570018015, 0.03016481368935534, 0.03506327333993145, 0.040416144499821324, 0.023873971342774372, 0.03890787650431905, 0.021409443945490887, 0.06397584386702095, 0.039740554323153834, 0.025493117049336433, 0.011020926076785793, 0.02161176612467638, 0.04257942270487547, 0.10977966498051371, 0.04388556529634765, 0.04579026398382016, 0.015620279857622725, 0.018780689021306377, 0.05540363277707781, 0.01722154107743076, 0.05324463273531624, 0.026679089392668436, 0.012998396796839578, 0.019296275551563928, 0.013134913801747774, 0.03508403990417719, 0.08379889838397503, 0.006024823540688625, 0.05669293073671205, 0.08761397509702615, 0.03847415352772389, 0.039653657735990624, 0.005356810479757509, 0.010050292758803283, 0.0425989339793367, 0.02344943573033171, 0.012257408566905983, 0.022280864417552948, 0.02157733725783016, 0.018268854789701954, 0.012821774131485393, 0.07518855362598385, 0.04042840223493321, 0.028217245159404616, 0.003640654621579285, 0.03170610259154013, 0.013910373306966253, 0.04453473331938897, 0.09108843401606594, 0.051913818610566, 0.01455925973797483, 0.035623746658010144, 0.017746949402083243, 0.03091339048530374, 0.02013114164583385, 0.030502520568136657, 0.039705297643584866, 0.011557956009970179, 0.0540491072461009, 0.0461880551385028, 0.024662971862458756, 0.016553435142018964, 0.022986026846670678, 0.030610723154885427, 0.028194322550137128, 0.03156234137713909, 0.006056842335965484, 0.030130004842898676, 0.059340608306229115, 0.021712165558710694, 0.0498640253873808, 0.041652004434061904, 0.0329604424270136, 0.028408093311424767, 0.03482566394710115, 0.012380061405045646, 0.032196890363203626, 0.01368319639004767, 0.06615065038204193, 0.05017611417653305, 0.03930931817740202, 0.04180864763579198, 0.039009466767311096, 0.02857177970664842, 0.04466754637126412, 0.03221323287912777, 0.043331778940877745, 0.0223168335588915, 0.015381335447143232, 0.03005096229857632, 0.006074105115008673, 0.04169170551800302, 0.06842129996844701, 0.08205699721085173, 0.04876748226316912, 0.022642123246831552, 0.016890748470489467, 0.06329367190067257, 0.02962544620303171, 0.0081607644180102, 0.020756890032706515, 0.018459266982972622, 0.0546211733349732, 0.027360301231965423, 0.015923630812072327, 0.020528963334592323, 0.004312639656875814, 0.011096543715601521, 0.02061553592128413, 0.0245996187441051, 0.04173443626080241, 0.03882658800908497, 0.03530944245202201, 0.04467204166576266, 0.041927306447178125, 0.01700432166191084, 0.020181236189923117, 0.02449310401321522, 0.014894093020952173, 0.028501361342413083, 0.044694647059908936, 0.039433150818305354, 0.05114443114559565, 0.058282392232545784, 0.05723495129495859, 0.029161626805684397, 0.0720398865107979, 0.045471508588109694, 0.04785128017621381, 0.010091230472815889, 0.00274303400406747, 0.04617161762767604, 0.03246294394401567, 0.02010806297351207, 0.03825215383299759, 0.04162791644089988, 0.03795679771740522, 0.03062521666288376, 0.055789776878165345, 0.04749075077208025, 0.05839954808886562, 0.037644244131765196, 0.04483943964753832, 0.05267972858356578, 0.046257455700210164, 0.058460663737995286, 0.040256902508969815, 0.06947353814861604, 0.06953432810093675, 0.05879256235701697, 0.04723834931584341, 0.038270945860339065, 0.020427116924630742, 0.025393080631537095, 0.054841792210936546, 0.061910865030118396, 0.05063109226258738, 0.03858325856604746, 0.01585550928887512, 0.014581493634198393, 0.07019024076206343, 0.02750574012420007, 0.01599022393514003, 0.029416077437677553, 0.07039948060576405, 0.03573927403028522, 0.044317554615970166, 0.057051828264125755, 0.02869326461638723, 0.05408335630116718, 0.03364830730216844, 0.020689116258706366, 0.008107814937829971, 0.0066030282510577566, 0.06320395600050688, 0.03665859398565122, 0.07165640565965857, 0.00724461576568761, 0.05665265629068017, 0.05358476198411413, 0.03709072919030275, 0.008044088625216057, 0.02205395043295409, 0.01721365310783897, 0.02129722443143172, 0.04070344640474234, 0.04231226650465812, 0.033291469128536325, 0.027927076444029808, 0.0672443877639515, 0.11364964196192366, 0.05684119063828673, 0.026129601556541662, 0.03148963295721582, 0.0093333831921752, 0.03821056302902954, 0.015647480630182793, 0.05544831430805581, 0.012092094535806348, 0.045729697948055606, 0.10747167561203241, 0.17909326563988412, 0.14428698404559068, 0.10917118191719055, 0.17444846273532935, 0.24370252873216355, 0.10845274225409542, 0.13126988682363713, 0.123290179297328, 0.11713792942464352, 0.28655106521078516, 0.0701932195307953, 0.15648720652929374, 0.06697790670607771, 0.15741563242460999, 0.11498989111610822, 0.14074922459466116, 0.19640158116817474, 0.08770335172968251, 0.11469542048871517, 0.07890057444040265, 0.19183656041111263, 0.11232544694628034, 0.16064164574657167, 0.18729087790208204, 0.2390508454825197, 0.07504742512745516, 0.11008608460958515, 0.07780851303998913, 0.08998477645218372, 0.07604745003793921, 0.12646982153611525, 0.16249201074242592, 0.09109776387257235, 0.1414435559085437, 0.10084004074867282, 0.12448206676968507, 0.11547314375638962, 0.14520686039967196, 0.054861635967556915, 0.1339404649500336, 0.13993765600025654, 0.1174653632832425, 0.09776023815252952, 0.13134660199284554, 0.15296493124748978, 0.10626269584255559, 0.10004851607871906, 0.09015147893556527, 0.1307097833071436, 0.10480097534933261, 0.0799015967973641, 0.17009918897279672, 0.0890050193827067, 0.201116517452257, 0.13418848307004996, 0.07740053028932639, 0.15368978306651115, 0.09807684259223086, 0.07318533504647867, 0.1359081757920129, 0.0632471718958446, 0.09016633885247366, 0.09201863767313105, 0.08011361863464117, 0.1504242925771645, 0.09756701852061919, 0.11726656609347888, 0.13545823922114714, 0.14477923406021936, 0.23401842266321182, 0.07757241678025041, 0.19228824760232652, 0.14207989961973258, 0.09368939444954906, 0.1906291073454278, 0.17510618029960565, 0.1407730004617146, 0.22239770979753562, 0.0975316193486963, 0.07293714050735746, 0.09965556287871939, 0.17018112886164868, 0.1262718928711755, 0.2328776695898601, 0.08920007105916739, 0.12957458065024444, 0.19113502305533203, 0.17013337356703623, 0.11596295104495116, 0.14216185307928494, 0.12307122961751052, 0.13727337467883313, 0.15873440594545432, 0.14318391680717468, 0.1437056695244142, 0.16302721202373505, 0.14614977980298655, 0.09359291355524745, 0.10658336470701865, 0.0968117615474122, 0.12073272652924061, 0.12737528580640042, 0.17576648986765317, 0.19748358667961188, 0.1273594895111663, 0.10189732722938061, 0.2861236695732389, 0.10909249221107789, 0.14955806120165757, 0.11510198510118894, 0.11499958059617452, 0.10628619351025138, 0.12213006083454404, 0.2115714664437941, 0.11667883263102599, 0.19799194511558327, 0.24118223254169735, 0.14659370455358708, 0.1753760336765221, 0.13384430296719074, 0.1884572117456368, 0.09902504099799053, 0.1917565068496125, 0.1407786323023694, 0.11079412911619459, 0.09515049747590508, 0.11965412726359707, 0.16717829927802086, 0.09536066012723105, 0.20314700635416166, 0.23043803764241083, 0.16557041555643082, 0.14052019188446657, 0.1205411082399743, 0.08341338192777974, 0.10467171442828008, 0.10908572721694197, 0.11174535378813744, 0.07858299291027443, 0.194077055901289, 0.11145506972180945, 0.17230480776301452, 0.08964800595172814, 0.1431370164666857, 0.16099095557417187, 0.3030333322073732, 0.1764441563614777, 0.1667188225047929, 0.19257975981703826, 0.1332026802535568, 0.08087682125291654, 0.13114312291145325, 0.07105243485420942, 0.1908344320420708, 0.11164098153156893, 0.08098449797502585, 0.11114265184317317, 0.07242032073970352, 0.10311909059860877, 0.13539558329752513, 0.08638744841196708, 0.08464343020958559, 0.18916397382106098, 0.11340305555079665, 0.16584652502621922, 0.18462308176926204, 0.10858010327709572, 0.1309386667396341, 0.16593421889202936, 0.1588999277779034, 0.10477567956383739, 0.10474944061466626, 0.16554488906902926, 0.08320104117904391], [0.03417491493746638, 0.04761428485757538, 0.052530919068625996, 0.0460107369747545, 0.04815514172826495, 0.02141977464114981, 0.026560338979054774, 0.011054903717844613, 0.016945977828332355, 0.024874303290354352, 0.03372991131618619, 0.015570137816082154, 0.014570782958929027, 0.014347093712006296, 0.03460481436923146, 0.036969681935650964, 0.03818763193807431, 0.05460060015320778, 0.042139202755476744, 0.034140136625085554, 0.029484338060553585, 0.07704816705414227, 0.03650885148506079, 0.028289758500510027, 0.037874868006578515, 0.013691281982963639, 0.03393703413062862, 0.0176164688143347, 0.046073094342968295, 0.04583314061164856, 0.023971938228766834, 0.041681625880301, 0.08604113770914928, 0.05025965201535395, 0.01976258517242968, 0.03475494024210742, 0.02911023117069687, 0.009188191117053586, 0.01907457271590829, 0.10437757628304617, 0.011000093355375742, 0.060565845774752755, 0.03521019992019449, 0.07791462234620537, 0.03565005346068314, 0.03834861097857356, 0.03898599284834095, 0.02942092896306089, 0.031168400908687284, 0.024669143138453364, 0.024808568514085243, 0.049319908155926635, 0.0774514814838767, 0.05259015856842909, 0.046891309187880585, 0.0326219213062099, 0.018703519233635495, 0.04016379054103579, 0.009506398595736494, 0.06719864771834441, 0.011486944775762302, 0.05428349020491753, 0.047391267360321114, 0.051569512978728325, 0.04276990784066064, 0.022855315557015792, 0.07602453591035944, 0.011894774856045842, 0.056407481232391934, 0.04730910694758807, 0.030750647253756012, 0.03999998200950878, 0.03153935939605747, 0.049020080494561365, 0.01877142532196428, 0.036469737333910804, 0.04979581226195608, 0.04319704563489982, 0.09397356491535902, 0.027735052730089853, 0.005559767937354211, 0.010317906121989446, 0.05990821642002889, 0.015447998120050346, 0.06544038706592151, 0.052282724529504776, 0.007669134414754808, 0.031336789551590166, 0.05409100339082735, 0.0035308447550050914, 0.019432506723595516, 0.014332742696361882, 0.021149873766782026, 0.010519668509784554, 0.008978232874401977, 0.017014935645940046, 0.072764365135559, 0.06800387879567486, 0.031085826589592865, 0.013491853755632681, 0.011540569398286087, 0.03353733289986849, 0.01873345110964562, 0.026167738617264798, 0.027009671653753946, 0.05931341940803187, 0.03840450530073472, 0.024750407884961793, 0.029214484683637108, 0.018783716983827095, 0.04404219492737736, 0.025995377151827728, 0.02677442695546363, 0.05824308469891548, 0.0482473376739238, 0.06554437255752937, 0.03798276864524398, 0.03405426123312541, 0.03676566341891885, 0.05076815972902945, 0.023023670273167745, 0.047125190030783415, 0.0765804053683366, 0.05352279816621116, 0.03128236425774438, 0.03302014672330447, 0.03175626668546881, 0.0434357237203845, 0.03192882153338619, 0.05472850400422301, 0.008249509164930453, 0.029402086045593023, 0.03824988413336022, 0.026936820741476755, 0.07214228423046214, 0.04555301082187465, 0.04817381840465324, 0.012717608828097582, 0.03129088326490351, 0.03134496250588979, 0.018480455935267464, 0.025909069193793193, 0.019771494337224534, 0.027371413939233338, 0.046574606360601525, 0.020638114174029658, 0.033064421133271286, 0.04230006644502282, 0.04153020739821451, 0.0695304400952799, 0.05648428800382784, 0.034147641222391806, 0.035479140667510886, 0.018996217188292315, 0.0548244420705097, 0.011734186821351094, 0.03529811091721058, 0.033585705661347935, 0.038066957877682786, 0.039068953932396004, 0.10700003949127027, 0.030974858972643102, 0.03697897447273135, 0.05132842609392745, 0.02134294412098825, 0.05753674331520285, 0.06051623129418918, 0.042630842088588645, 0.04204485246113368, 0.0062125262588129514, 0.037670208274253776, 0.04083920769127352, 0.010979459105458642, 0.0793125062648739, 0.03943271655589342, 0.0210437831202788, 0.05258351571059652, 0.041094330072935135, 0.035272231591599326, 0.021318868002189056, 0.07172942281301532, 0.08505104655133826, 0.018005147243716886, 0.0447866869425135, 0.03444423905706831, 0.02673624748630183, 0.0639959963570748, 0.04138154037562864, 0.03423113834911159, 0.025697278058422462, 0.016753658951659287, 0.03513581212610006, 0.038836793175765445, 0.04621525760740042, 0.041729734013123174, 0.03173204298530306, 0.016252216483865465, 0.036712154147348235, 0.025420644420332143, 0.01982890348881483, 0.04559732594394258, 0.029462200855570178, 0.05134209857455321, 0.08708934539130755, 0.03109768738171884, 0.07714274805039167, 0.01129810932824122, 0.015038458131519812, 0.03957855408745153, 0.03795501656298127, 0.03908107935317925, 0.0067979213199578226, 0.04684896181736674, 0.02139955260125654, 0.012013808558029788, 0.037219186047358174, 0.017339180389951383, 0.02423678571358323, 0.0499464131093451, 0.025781745490218912, 0.015095214193154658, 0.027847580977582505, 0.029724057697291886, 0.031230646318622997, 0.039164081149335415, 0.04288326729355114, 0.09092696982302836, 0.02165745528015707, 0.02398811959262405, 0.02378811121785215, 0.028600156041128293, 0.033262064813503196, 0.01710054640924292, 0.014556479440735919, 0.014513743608923895, 0.012839551748973983, 0.018826595307993035, 0.05033480316134436, 0.09056369574474436, 0.013929385010020008, 0.059617348813584874, 0.031961550670010705, 0.050934780788208754, 0.031202904414385557, 0.016327108090211238, 0.03568689112684556, 0.02285618068916457, 0.04224628236676965, 0.06355519286756005, 0.023246411267401915, 0.021483768975096088, 0.03105548250355891, 0.023278375355792896, 0.020857370890943066, 0.11236185713538102, 0.04915136684264455, 0.04622280630948288, 0.013829398634178298, 0.021372662258467505, 0.041072633915713856, 0.05756619173501219, 0.06867148940052305, 0.024548143381252885, 0.01672451926528343, 0.046242171698915105, 0.02722043989758406, 0.03218412372682776, 0.01955608491386686, 0.0421661880931684, 0.07982897319431816, 0.06575629939990384, 0.05310766026377678, 0.0341320315242878, 0.07021221172596727, 0.01980640326759645, 0.06782511195966176, 0.040656722483358214, 0.02716163974920554, 0.01378798424931509, 0.046750289254954884, 0.06509356746183974, 0.023091642518660853, 0.041236768144049814, 0.01583553830693875, 0.03823619808203407, 0.06323300408465521, 0.021713636283363615, 0.048041188557233126, 0.02250809731361057, 0.03166149230673909, 0.020946247104023184, 0.013897863665728696, 0.025125851488805244, 0.044878706469067504, 0.024346844093608003, 0.03301874894116606, 0.015361225365528038, 0.056405968099300346, 0.046167152867253335, 0.010465271205508282, 0.03071316158665078, 0.05596281348594597, 0.027017954869994094, 0.012549030195389475, 0.00380013749236241, 0.03292353690734931, 0.03283440793997475, 0.026730210220973407, 0.0136029435088858, 0.05366378417238593, 0.009273966425098479, 0.01452110062486359, 0.015919389968205775, 0.034711934692625485, 0.022809348202177455, 0.016523292920153056, 0.017937037594882504, 0.045575324445962906, 0.046195403672754765, 0.04975153785198927, 0.03887839415775878, 0.01908625878526696, 0.05454046159450497, 0.03588001237117818, 0.047017750795930624, 0.07339823897928, 0.013607113954744168, 0.05642387803111758, 0.00868201332299837, 0.01388395284967763, 0.030205396868820702, 0.03448450332507491, 0.009580006922728248, 0.0382170057190316, 0.03844373480283788, 0.02488147370916392, 0.025543162399636846, 0.013879528801356043, 0.01561963016034237, 0.06160240979599101, 0.031058766613049165, 0.014785313679437553, 0.06916236198906388, 0.010256568252641176, 0.01916727247381849, 0.027705551723816564, 0.024406679007889967, 0.09102294181606599, 0.049040361906268766, 0.05536342957722289, 0.07857776819063084, 0.028789399457829337, 0.09094385177429233, 0.10192300977983645, 0.10907786978142602, 0.13908234903854982, 0.18455270411712782, 0.13778406727526868, 0.14339608113680566, 0.11016377008387021, 0.0843807150210653, 0.09723017338131155, 0.2819728808743613, 0.11808196162538868, 0.1810067208217723, 0.12649662366935185, 0.1527583444757121, 0.14947788550385407, 0.10017346151705299, 0.15397102226104054, 0.14081264047750405, 0.12683012363101753, 0.11387174682957785, 0.1447973916573184, 0.1025202495179006, 0.10413946477430207, 0.15687717417521135, 0.08194212123219456, 0.12643619334059103, 0.16807240487209388, 0.11799429490097932, 0.17694672010838985, 0.20049272663891315, 0.08169110398739576, 0.13681212014385633, 0.15443619872842515, 0.07774006242730788, 0.11546809545585088, 0.09919634394879852, 0.10437716916203499, 0.07738929374941758, 0.2117672645087753, 0.07566232034670455, 0.14293823284762247, 0.12332217900880746, 0.12807640247046947, 0.08444476194147553, 0.1893905909465892, 0.13376874130751404, 0.14395520756287233, 0.2314074741942542, 0.16570940666965076, 0.21921748401863234, 0.1051982304613505, 0.11766045567180429, 0.12315219241593565, 0.15811502560973167, 0.20132277852722577, 0.04659379193825381, 0.08080222989831652, 0.1017497390774744, 0.1122444841478552, 0.12506825317229542, 0.1130130539781281, 0.1589037954275097, 0.12536770424672536, 0.12739676822509083, 0.08684070980442421, 0.11646425271672861, 0.10302406176924706, 0.17261222483856337, 0.15415837935038976, 0.09637763484248094, 0.11735134225870882, 0.13080485963395663, 0.18468064868024417, 0.08287423157266208, 0.14410722654845032, 0.12647689187100955, 0.08884897668446813, 0.23730787900941713, 0.12487873834158693, 0.13596784616155283, 0.09947947625602994, 0.15866383830351488, 0.15991478546389512, 0.16183319395141943, 0.18977157478885992, 0.11718731320330075, 0.17220342106052808, 0.11450591922870704, 0.12117551134100982, 0.08135203325322696, 0.12205576125000205, 0.10130585503897496, 0.17583624326757022, 0.13476937689951488, 0.1618083459990365, 0.16011842739369186, 0.19149829713361605, 0.09032764698245696, 0.09690108389726707, 0.11604354743446622, 0.1436119909797396, 0.13131245811070713, 0.09188721901071922, 0.11491753214171954, 0.11386475791888577, 0.11387397242443902, 0.234706810010331, 0.07683936147285358, 0.2317409605852195, 0.1414597321833883, 0.11009945174945251, 0.07308293054146425, 0.218214500695467, 0.13762006536126137, 0.13250502411808285, 0.06380071397870779, 0.10289935381816966, 0.09978628265006201, 0.12547257861920766, 0.1124559902985181, 0.13894462000046456, 0.17066438150193008, 0.13914546636598452, 0.13446220409657272, 0.12399799988738128, 0.16478024795651436, 0.09892596131456749, 0.08027071306215865, 0.22726983550403798, 0.05906894324081285, 0.130133557798607, 0.1795195620507002, 0.1523913520255259, 0.1883709156619651, 0.13492485641368798, 0.07002948224544525, 0.09579041028129202, 0.08987880285297122, 0.09284943594996418, 0.1865748470383031, 0.11246891639062337, 0.16210787849766867, 0.1646857958819185, 0.15257842413016728, 0.12992697102682932, 0.1375324936317546, 0.18641159151281628, 0.16601581951337202, 0.16123832230057034, 0.16776842118373939, 0.13190024585596152, 0.14388678409159184, 0.14461968333593436, 0.22921040494527134, 0.11939755960234574, 0.13124320682670387, 0.1978191358170339, 0.05527581374293991, 0.244227334856987, 0.15144326218536922, 0.11448678454118115, 0.10408209463847534, 0.18301356956362724, 0.07241768123848097, 0.17122326365539006, 0.11908939613827638, 0.09321819937654904, 0.12978337944618293, 0.08023219941450016, 0.12802092544734478, 0.15474386007658072, 0.12644230015575886, 0.19695067884666578, 0.30027891429407255, 0.11704929918050766], [0.04264388353164707, 0.03820344180400882, 0.07475589934204306, 0.02950232263122286, 0.03744049702904054, 0.01822678222587066, 0.09362688101828098, 0.032256401277014186, 0.04064787099403994, 0.019761243369430304, 0.02669185433270676, 0.0854235283498253, 0.0073850038128771955, 0.04515835449897817, 0.06590926154915776, 0.02311833099728184, 0.01021610212046653, 0.04166550388825791, 0.06299320302371468, 0.020694944874516556, 0.006605821270828268, 0.020482429403013418, 0.1519316445503916, 0.03788926651967423, 0.03753713059372135, 0.0366474083358688, 0.02958788928974952, 0.017325333186558316, 0.027332398175661052, 0.02188118015016828, 0.05009307845362595, 0.01759100509142237, 0.027914550687585558, 0.03564602296267237, 0.022593199175649455, 0.02905769898955311, 0.03156389522233179, 0.02428558934479952, 0.05154098736654435, 0.030589101636516194, 0.023240989772602916, 0.03378546637083803, 0.00837489141018263, 0.03633179794996977, 0.03530741702499134, 0.04020337966669883, 0.06366630976221391, 0.058346602001360486, 0.062102184763976505, 0.06296317106378929, 0.02961687630574618, 0.04427334466683013, 0.04405578937647598, 0.05965236122054713, 0.04425137709560139, 0.04623958308781896, 0.026118953645761524, 0.021865926682949066, 0.004012223790466253, 0.05023286345281771, 0.03825941076502204, 0.013213806220197251, 0.06515441848231213, 0.048705437021063905, 0.03695014012711389, 0.026923828492207185, 0.021770904638937542, 0.06017783909503903, 0.020198701681303124, 0.030704734181719165, 0.062322952917643955, 0.030086578601705175, 0.0197122972458601, 0.020800664023097073, 0.02933270244726113, 0.08835339506289788, 0.052882298428033075, 0.02055479007373963, 0.035918166395276785, 0.062150543954755576, 0.035474723404539485, 0.048760310148022006, 0.030665877873876264, 0.040840846353343556, 0.025679083141897405, 0.022717978372903805, 0.07663874580924, 0.08040209779781954, 0.02517041766883007, 0.04712819933359112, 0.045887854282877276, 0.03951189141454441, 0.06987244888607945, 0.02796324066418622, 0.03877119580283761, 0.03975532603050981, 0.014241293139223541, 0.03909122005903295, 0.00757755763230047, 0.015247879483337914, 0.034974368289113045, 0.05095152024711881, 0.03445080388337374, 0.008986763755923935, 0.04055858935628619, 0.025965304479801228, 0.03724387454401169, 0.07754389795341662, 0.03902478130268199, 0.06512603536248207, 0.03210640432579177, 0.025459203869104385, 0.010109117504076233, 0.025230088038370013, 0.04335984654192414, 0.0278621168940195, 0.006629362619215888, 0.06374422593840531, 0.00785312257773642, 0.05753046686628035, 0.03620375160660062, 0.015458376313160573, 0.03580659827483552, 0.032476772487695725, 0.03689171147665807, 0.03859443064512951, 0.0021574544662144035, 0.021779759520930902, 0.006407115683292172, 0.007066715334076434, 0.028683015344930545, 0.03540934655549271, 0.027449640545195768, 0.011625068212327148, 0.0525259962970657, 0.021110844432509372, 0.04827900490324412, 0.03531967815277832, 0.023839464444401007, 0.04853310948237777, 0.011248398156437491, 0.03502036617802722, 0.04657171240874699, 0.027737921236881187, 0.07775679510086775, 0.007843447516539266, 0.04090682031320674, 0.057617841820631704, 0.023933290570442165, 0.10351192844765526, 0.05734794773161411, 0.0615607952432973, 0.04567827517166734, 0.025360741652548313, 0.04276803169133408, 0.02776766142674855, 0.05294577877170273, 0.012217631147775267, 0.03981341202078121, 0.03632338411573853, 0.0802695799086775, 0.026236901691715633, 0.012551550104814981, 0.02930278583828892, 0.014368340339777725, 0.06302827649882861, 0.025792905694938133, 0.02274958453407245, 0.030411006550171545, 0.031132740500782217, 0.015629879431799054, 0.04401565742279802, 0.052455639000982046, 0.0763553963708026, 0.03000901187104838, 0.016805298859253526, 0.03754290153405496, 0.02741522016003728, 0.024695872329175472, 0.06376076862215996, 0.05806753411889076, 0.0608586064938988, 0.04501840325870684, 0.03267908788153103, 0.0414836259691843, 0.05674939163561378, 0.044904056537364206, 0.043609506716685634, 0.022126034600660205, 0.0642146881935852, 0.035810184332409074, 0.03824103603671704, 0.017839949411739196, 0.012530859027590071, 0.05623211046414716, 0.03688911608021174, 0.041694976056792905, 0.02684006673683013, 0.024145495612174273, 0.062306763072099, 0.01724932878278196, 0.0178854825041656, 0.044692791266632934, 0.026216993474268487, 0.007295355766213366, 0.026661740948579142, 0.026409600728324482, 0.03605207528120705, 0.04622138477861881, 0.07021852888699089, 0.018995260453916023, 0.04274699032040579, 0.020782243493678312, 0.07159592783344643, 0.03752171088542257, 0.02055425912008754, 0.019301902303206067, 0.028519630897790194, 0.03450124617666006, 0.04122129076027444, 0.031831774062344005, 0.017048708030155728, 0.030566319823265076, 0.014107035655927445, 0.03536612048212971, 0.05466085745553885, 0.08040664398244449, 0.09924620270196881, 0.04899555823898741, 0.07192187570035458, 0.04769157338887453, 0.029502787427710633, 0.0703193795468126, 0.06545522662677936, 0.03277255608034985, 0.04007328414757337, 0.01830238799032356, 0.034897161182016134, 0.03050809134063976, 0.04387082751574261, 0.048571009055844376, 0.02579755026714078, 0.03823076980188489, 0.09777116935167994, 0.02418290324775236, 0.023517358782035962, 0.06630494245993239, 0.024968797773388878, 0.02622432165246989, 0.10043761519981281, 0.08534409225519214, 0.05840665235051087, 0.0486980613454112, 0.033986078641776524, 0.011455857693882925, 0.036625345769737444, 0.012488819542340934, 0.011487820934105133, 0.02017676973316286, 0.04987912618422082, 0.03759176284074783, 0.016252737259492278, 0.011726850161461957, 0.021451821850080575, 0.028718536653156792, 0.05569465644657612, 0.02163173710661275, 0.017766905116981695, 0.011536169098690152, 0.03776922688952514, 0.05725207073347909, 0.06520616356283426, 0.01902441371099225, 0.005973109418326723, 0.017497268871271184, 0.021094445937446187, 0.0260618091228285, 0.009825271886906453, 0.06112347263842821, 0.02528066943133516, 0.020999330594869595, 0.0187246267617281, 0.010960926617761808, 0.0381347774527967, 0.008434310721765672, 0.0578117806996618, 0.05997208013598408, 0.04007647665483611, 0.05665569952023881, 0.054579993044691424, 0.025166789202817848, 0.02331555398580219, 0.09832302188234669, 0.030662006831594875, 0.039074714694704325, 0.00874079396349511, 0.015819696210590855, 0.05344022384711674, 0.048929346791867695, 0.054494467098265886, 0.02713480538555554, 0.048551192440624745, 0.037551654635795524, 0.031280423647591045, 0.019769389182329178, 0.03607468067535332, 0.025218619100217308, 0.02727971502047564, 0.0717378705739975, 0.00797274660518659, 0.06684514454432897, 0.03749609958114369, 0.01189680622025792, 0.016764223741899644, 0.06808585261127778, 0.07261010698441948, 0.052980139785047085, 0.017702082970312664, 0.027971067565626333, 0.03538488536807043, 0.0029555910358405007, 0.03170071163081697, 0.05143675760232976, 0.030655051847653728, 0.04523745132610202, 0.02953582869044372, 0.03862272894808224, 0.03616352465802005, 0.024713169883138368, 0.01887360930309764, 0.0801332350820303, 0.025739932466032248, 0.08497691660055093, 0.006850829663952547, 0.016701869766360948, 0.01385855782843594, 0.08149473595299891, 0.05751188179211957, 0.03055435385821121, 0.06522914554391589, 0.049374218098819256, 0.051984413393906186, 0.01447882958953934, 0.017579963630331413, 0.01820893845121775, 0.04703883287896003, 0.01403318899351039, 0.03597034573821085, 0.04502783150279096, 0.020906354333939295, 0.010699045179145677, 0.004345665228486593, 0.11844881836857114, 0.14126443623432092, 0.15807315999908106, 0.1379452600542988, 0.08151185539151941, 0.13156437102173055, 0.16362017020583153, 0.2087189866495984, 0.12200381260897432, 0.07843855994620494, 0.20474771117525442, 0.21697225235402584, 0.08905942432050194, 0.17792176135948726, 0.16944307275116444, 0.10960898628192288, 0.13760931736656598, 0.10798114684543439, 0.12419466647718634, 0.12743995019367763, 0.19013582595757075, 0.09515045676380396, 0.155797597819141, 0.1366292278149298, 0.1030209269374609, 0.13139787209885462, 0.10866368522069283, 0.14891487785748073, 0.09576288890093565, 0.13898890119578156, 0.20245190151035786, 0.17522286118141242, 0.1396086886525154, 0.1895671050463404, 0.06959094506289278, 0.12276829087308475, 0.12137766049376555, 0.16509115270205907, 0.10760407136487109, 0.08765649210129466, 0.09751312926943813, 0.1574703087764127, 0.11875782321606364, 0.15904444216617517, 0.13671564603490488, 0.2026992818074567, 0.10734674374439887, 0.07996581335152898, 0.14156846063477652, 0.16078020259737968, 0.11990253893392426, 0.15368842599647387, 0.13167820205645903, 0.1791850035744054, 0.18763507157564163, 0.1060613270050713, 0.1391629454280649, 0.1380401871034077, 0.10241705112691436, 0.11775253287383489, 0.14900624938309193, 0.13733521636043275, 0.16091733452464851, 0.17249204271606036, 0.09510442494813885, 0.16552868565278395, 0.1359755000365632, 0.19887893966266088, 0.1393096311283963, 0.08726822079292365, 0.17737700630511555, 0.08256335396851812, 0.1285357028245926, 0.15682327135332993, 0.1043673236189144, 0.16009169311395713, 0.1997748908719846, 0.08417021310223, 0.0878650601953268, 0.12553292752376624, 0.1340199756835188, 0.10212039561676127, 0.20190960275275366, 0.15370665144707474, 0.09329104689615113, 0.11924107585634504, 0.2364756693797452, 0.12015325762331486, 0.10790892357804946, 0.13948199259383337, 0.16769912918763502, 0.11914986717913832, 0.09296741283365659, 0.16861105311129773, 0.15590104726808413, 0.16260007422949585, 0.12108069285750389, 0.06605247993554388, 0.08830285777470895, 0.20336358116141387, 0.11109073034354619, 0.13845097220369748, 0.1526067326111453, 0.07809376916182892, 0.09983003458806447, 0.08954456328813519, 0.12774520952786717, 0.16124012720371994, 0.0974406481587461, 0.15316596760281495, 0.10382841075105326, 0.12082804712866034, 0.1404132954776287, 0.14199451277298586, 0.13240667725247995, 0.08846341273082153, 0.13901480766279356, 0.13982406923813478, 0.0661603059353573, 0.14595828365002358, 0.09808322760675635, 0.1664711707936866, 0.10184458470238106, 0.08596225122788123, 0.1258932160479682, 0.13077633402177266, 0.13966937682458333, 0.11461912601121835, 0.12944320269993373, 0.07110759296587535, 0.1123596043991191, 0.08832767858569111, 0.12869009668273584, 0.062189267948269844, 0.16760625131428242, 0.13938190867858274, 0.13190376066735812, 0.10087447640086923, 0.11748658785862581, 0.13884476678712027, 0.19971025362610817, 0.13967799421932015, 0.1819741760513612, 0.11055041290819645, 0.14376193364816053, 0.1779530553945473, 0.1411650308540889, 0.12156689033976623, 0.07285630663058587, 0.1489429013537509, 0.12361226629998003, 0.10639720862465245, 0.11438268369862012, 0.10943723549800259, 0.23536903304713114, 0.11842626386455127, 0.134544008278421, 0.08300067657338721, 0.07620409663234438, 0.07656581686543566, 0.14228599784629686, 0.09228254029793398, 0.07255024662507431, 0.13897108286619186, 0.07923460365938288, 0.16611992035593304, 0.13081488838153227, 0.10253481087940079, 0.08365833985486201, 0.2137848205332245, 0.11710576686475958, 0.11643028525369507, 0.09020996186882257, 0.16865190091942037, 0.12452455663255282, 0.13281632241393837], [0.029152687106813704, 0.03810386000467198, 0.02498942014894315, 0.041754239305321655, 0.04244814992749265, 0.04223479137622884, 0.0505792182604117, 0.026985230822382227, 0.02950427002672638, 0.0345066982055349, 0.06113430205732584, 0.03038223327270576, 0.03386604240430253, 0.016890244658238122, 0.026288650164912854, 0.031181920718933855, 0.03820954861917666, 0.019759394361504486, 0.038131344065602334, 0.019034491652356725, 0.048197713015334945, 0.10338020444448505, 0.00942267500795424, 0.06806694184030805, 0.07117535825818777, 0.04852011553677065, 0.06435228152466671, 0.01973796452927802, 0.056102527238960774, 0.05046748389889087, 0.05886497561420713, 0.011773658051554645, 0.025250142140846168, 0.007753636621470962, 0.009594058534795684, 0.07983250157641512, 0.042199202214500735, 0.03224345143618328, 0.04987260207001652, 0.06060867490512984, 0.03433169384620019, 0.048761389018701654, 0.040481361893138716, 0.05397823087072798, 0.0610144388462816, 0.03959904245233961, 0.04983282634722335, 0.021018261721889888, 0.012401155362437879, 0.05967922442193542, 0.05212426624659981, 0.04043115030175873, 0.06913084403744765, 0.004020030335855803, 0.015237090776541402, 0.05508671281859279, 0.02807305137892919, 0.021092542646718875, 0.022936834754156213, 0.015111821337736078, 0.018552882763158, 0.017370304791256785, 0.01840118777805141, 0.04043831563155566, 0.01847340426008616, 0.041252411768904755, 0.01618567425092416, 0.01832175168341824, 0.04939135789339032, 0.03194517422733562, 0.05214898527732917, 0.021499731511409794, 0.03361996489443949, 0.07809223567268678, 0.02321676437609962, 0.01193896444913532, 0.04245941021612712, 0.026398365884753208, 0.019166627865550772, 0.010887912857080144, 0.022364939995376126, 0.030917692397321974, 0.0630125141303454, 0.07228373164044959, 0.08119666230465684, 0.03289605623909405, 0.026007502572610974, 0.040395228657871485, 0.03543913085013628, 0.02975034075123923, 0.03745981492102146, 0.02546706300095788, 0.06628777552396059, 0.07977490752403225, 0.11200496128627233, 0.03998273364933474, 0.010494624630415013, 0.07587276119738817, 0.11802033707499504, 0.0557074671877282, 0.02799426158890128, 0.043340026534029415, 0.026503011251666715, 0.022978727506207566, 0.03369539084711245, 0.05315841807584677, 0.034228006910000525, 0.02265063886131559, 0.05545844483588423, 0.019538125788260783, 0.015417245216667652, 0.030427739223731414, 0.010754769019383405, 0.04456925378846271, 0.05882422958633729, 0.04926489253661462, 0.0597470575677497, 0.08718412316271237, 0.0617579435929656, 0.04182583153513925, 0.050453587501708946, 0.05863783601671457, 0.015086174410368716, 0.05422767052160842, 0.02803603050831173, 0.038313863200268576, 0.020669632125645876, 0.10013313618089471, 0.020262539952195117, 0.01722694730519184, 0.0741836161219648, 0.05627519743783133, 0.04119766077825001, 0.04945099772885442, 0.0181566030452294, 0.0217828231065401, 0.03071765009579914, 0.037327127398124764, 0.013366957511087614, 0.03431080175297601, 0.060585618285196166, 0.015352809834959251, 0.01960236269847623, 0.013048423487426979, 0.060359801830989976, 0.044083544851413796, 0.06270834045218569, 0.048799275021467886, 0.0323013270805989, 0.029190539182829003, 0.06094354550753321, 0.015009985105799777, 0.011792975095366793, 0.022629393929881707, 0.08151772471943072, 0.017816782529864992, 0.014430743509105273, 0.07247661879020077, 0.03182880547163742, 0.057612399969782145, 0.03715986173067774, 0.025007667651932155, 0.07340604213199445, 0.04271855291777423, 0.07111836810197149, 0.04716210912114807, 0.05194380307304008, 0.04159770806186965, 0.03250662463584116, 0.06923676335385867, 0.02474634176386254, 0.02679854378636394, 0.051361070413674624, 0.05469389532559684, 0.09114088477300746, 0.03147651348263025, 0.023345082133476223, 0.06582003419420548, 0.013262096709305686, 0.0191207792543407, 0.05914637087179082, 0.041165287872510295, 0.06350935104170016, 0.013878125930204988, 0.03204319200345448, 0.03997277954061117, 0.04032321912901742, 0.050114794966897795, 0.02302701205813459, 0.03444554523697921, 0.025146177005288855, 0.03751787716256721, 0.018080946390650103, 0.040838033825691254, 0.043555145883666616, 0.019666036424626197, 0.040762068437678475, 0.020268304107178534, 0.05510488398639219, 0.020462590735405684, 0.006034689439859773, 0.04351778913821493, 0.009601296807107116, 0.04518871894106269, 0.02718650296862636, 0.00921265484898218, 0.06582743022590876, 0.053675648357186995, 0.006813768929402743, 0.032223790884017944, 0.04887499274419887, 0.043897700895156176, 0.008299678347871771, 0.031164903060666153, 0.017684997458543097, 0.02815713034942746, 0.025323988803263222, 0.014109098402384137, 0.04886188005496349, 0.024403829160811644, 0.03332702097083841, 0.03425357750217829, 0.04348378096308027, 0.03167521567749126, 0.006961298133579216, 0.040901113833699904, 0.028396777043651258, 0.02129978929380221, 0.08057494780847005, 0.016442040048007454, 0.01971876877360046, 0.051074905054909844, 0.05552196249897991, 0.05081869701721838, 0.04603370199246066, 0.049943597189017704, 0.014649084203743508, 0.054171324973659854, 0.03514639048704079, 0.03703846503049135, 0.057838650686400275, 0.039567626280976195, 0.06333957479468413, 0.026817257782178264, 0.020079240502257432, 0.03814740159681865, 0.028465680578457456, 0.03523786718557988, 0.05017014306836894, 0.04028185563428061, 0.06242824798183782, 0.03563456589888249, 0.01685751891428871, 0.015436025369646294, 0.022769482573494315, 0.010367402707093527, 0.04842522919976285, 0.038074425155563016, 0.017918508499860764, 0.013946350081823766, 0.04553896175431354, 0.043260539549269846, 0.04825493387345757, 0.07528848826353039, 0.01145987122851823, 0.029761855490505695, 0.023185833357274532, 0.023592236817681363, 0.023775597335770726, 0.030298566512231315, 0.09567246732435056, 0.04147014347836375, 0.0354413801937231, 0.007891401282644697, 0.0694170840350645, 0.004510169682492102, 0.029960751067847013, 0.022997373648520027, 0.020264080226687447, 0.03928277388747249, 0.04790280134017978, 0.02642513409123889, 0.07535577858132975, 0.02068665317658867, 0.12121413355427128, 0.013903375066417669, 0.06526199342416865, 0.04864678106137684, 0.028387766098603606, 0.01989419212830918, 0.014454027438270194, 0.07645774659301553, 0.02105892971823258, 0.05805293883063963, 0.06416335701942444, 0.016233916394412518, 0.024472839564883282, 0.03579527013269918, 0.05643538598503385, 0.08355165379387991, 0.010323087585025599, 0.06564455825303282, 0.0504680199415556, 0.07743785650070224, 0.015218219021335244, 0.012775331802134002, 0.042619093254740746, 0.02609915060124227, 0.039774304654981406, 0.01640556030906737, 0.031249289068260362, 0.042040669292743714, 0.052293794828334024, 0.031178545007216077, 0.03592160656782133, 0.020851537186120237, 0.04823054393221225, 0.02208162278735212, 0.012624920944550207, 0.02515699285348611, 0.022674820153042674, 0.06640567098345075, 0.016455173093293394, 0.08010861104620354, 0.018609805065872412, 0.008757658103214843, 0.07103087101131678, 0.027945888827421834, 0.05265125725418329, 0.022650272452405522, 0.022003891511953304, 0.02855327944936497, 0.03147138036521418, 0.039066338179899116, 0.03016709695969309, 0.0503969332203269, 0.005577248695772141, 0.059746860792594295, 0.036840974020638635, 0.032041712797113826, 0.06117732117750815, 0.014625576358022434, 0.056087151635438204, 0.01247905711976013, 0.019642184222383157, 0.04652025909828288, 0.06331045885703393, 0.08759976657373564, 0.060342682392469475, 0.03776818194559642, 0.006373978153403316, 0.01024301621198122, 0.13078390647258076, 0.23282091692090034, 0.12400002192173686, 0.12013995833694935, 0.08628831444574253, 0.1488826067319938, 0.15236080437898636, 0.09937774350068398, 0.0921002993626254, 0.14032615801053389, 0.15209399083895342, 0.120095555005329, 0.13673342365239347, 0.16812813973852567, 0.0669238410357918, 0.2017886878124305, 0.08240047163729157, 0.10778904679630484, 0.14423954087708676, 0.14502387307584286, 0.0744170593097806, 0.1529483207102333, 0.11851889746529715, 0.12597876574311936, 0.14634325727820396, 0.10762361995875835, 0.09277941792138986, 0.09858047842447247, 0.16185079514980316, 0.14599765225180558, 0.1777392490101712, 0.11080907724265542, 0.09811178036034107, 0.10670151122446571, 0.1724892064396824, 0.18998771533370018, 0.110333865242345, 0.14115524637912, 0.15554400214127131, 0.1646195844347988, 0.2229159748447793, 0.16495852624731405, 0.1648117048399789, 0.1711356376430818, 0.16737891494163445, 0.1414301616272756, 0.1766742475863014, 0.12017651780375413, 0.060669844837061, 0.14676099057708467, 0.18977388180792332, 0.08149553662432091, 0.22807364165782928, 0.12241543909268719, 0.11690608757947173, 0.10246521354253803, 0.11300630255469254, 0.12094442945505891, 0.23273512295314244, 0.14434878501508916, 0.06450768639998776, 0.10132918307291609, 0.11522045731544495, 0.08973328423287187, 0.09212965278753213, 0.09992775041610003, 0.12447670634303774, 0.11442939404930387, 0.07525355049542018, 0.08947177683668477, 0.10985345566379172, 0.14819260447153024, 0.11879267277462141, 0.17514151840337686, 0.21035538241267204, 0.11741882935166359, 0.12404803505965642, 0.10823856946080923, 0.11286714859306812, 0.07231817407799618, 0.0798227781695979, 0.08132164845509188, 0.1315564050206116, 0.11856376220073019, 0.1308118621153491, 0.15015760117343493, 0.11009793861636094, 0.20108957961201668, 0.08365396330399172, 0.08002739040447132, 0.09822869872940437, 0.08028819212423903, 0.10717130851532732, 0.18047761278493063, 0.28546785190701485, 0.12265162356197834, 0.1159995783652578, 0.12028509697743825, 0.16080541695867265, 0.14910173283091613, 0.10646829195320606, 0.15105428520057881, 0.13254707971853869, 0.09930596806641136, 0.0852581150829792, 0.17783557384141854, 0.1692467997116702, 0.09962183290294238, 0.32318074681929176, 0.10392626907144274, 0.17045115865767002, 0.1281628885439464, 0.11744173669389316, 0.08285797387361526, 0.16035344478275093, 0.08827032202056476, 0.2764550341027123, 0.20131141985101358, 0.1392678605126483, 0.10524619610181876, 0.17492554070694105, 0.10622007705803428, 0.12057894335261413, 0.2003470723118101, 0.1267181517822402, 0.17225188203155994, 0.10652404039033822, 0.19647567719221115, 0.1714744980313948, 0.10222780771021332, 0.11630824394524097, 0.12041754701307841, 0.08462804782071284, 0.23856756570083754, 0.11177594893212829, 0.12559101012136253, 0.11929773353040218, 0.10763961981449809, 0.07912643160670996, 0.09762411724243845, 0.08507985714823008, 0.13380029318588121, 0.0890537721237966, 0.10129932753209557, 0.13266903960279056, 0.1380565126559564, 0.1344396360218525, 0.17972462890403612, 0.09655298864735024, 0.07318342157772609, 0.13663811662367412, 0.101415777711996, 0.13625911410365785, 0.12448905568037714, 0.16708717202501638, 0.04766669150974069, 0.1238751443369048, 0.12286012380250863, 0.10073024699730532, 0.07968807539769582, 0.12521221116185188, 0.13841410061078413, 0.11116817154522453, 0.08737905948821988, 0.13700513621526106, 0.15429050368922098, 0.11481542619211332, 0.11337111012211867, 0.12235621655625956, 0.15458428221089499, 0.2074544145060437, 0.18768653167145594, 0.1363379191607237, 0.1841883308121136, 0.14138898812234402, 0.06612879476909127], [0.022006488604737178, 0.017238697835377285, 0.05151749309152365, 0.10227291671825306, 0.110638995654881, 0.019143647580806698, 0.0492649536047663, 0.0666953172268612, 0.034307422648583136, 0.04314367546300803, 0.01920492947101593, 0.053880291126136265, 0.05706799096826996, 0.023154705563294034, 0.03639243183923619, 0.01695952986899231, 0.028328828546883802, 0.03299388741808278, 0.0499850658566824, 0.06604201692555632, 0.03567034165774073, 0.023654940238754665, 0.01542389316351286, 0.07349819397287709, 0.02607419408325638, 0.017687547053875666, 0.013653275540231593, 0.010853535728529096, 0.01750669372268021, 0.04124910051801375, 0.050759939277278524, 0.04694304748305252, 0.007886097683305187, 0.0282354010601661, 0.05598381753744824, 0.03355405539540308, 0.0576252785644361, 0.003201937415204676, 0.02467519567081971, 0.018059564055874944, 0.06886924843170814, 0.04222186867679868, 0.022528907982632518, 0.023867886579994644, 0.059164453830037794, 0.05075230236564364, 0.05357748469603913, 0.029367982875555754, 0.04573481749477131, 0.006663096411752382, 0.01673206627102835, 0.04929635620542935, 0.0503206760622561, 0.021120813808270862, 0.020853818760120442, 0.027252509158902934, 0.04543695419228502, 0.029447673420820917, 0.021886710210570266, 0.08230198906468493, 0.0031034143425391187, 0.0458198175765574, 0.042387587284403186, 0.023862113943323493, 0.02744768127532942, 0.08215800393372774, 0.05883722353194441, 0.0662810919540269, 0.10910035643194403, 0.03705533001837986, 0.03179303989080446, 0.02631455663192485, 0.06417145872754709, 0.033338518746729405, 0.008143012245584811, 0.0691981954233987, 0.029959499170737605, 0.04381848532440407, 0.030419220216572285, 0.029592499935201237, 0.03603159370166915, 0.04298397206834384, 0.04694512380020959, 0.028269339685461352, 0.024602989366810237, 0.04650007946682828, 0.04810009557487709, 0.04815533511074526, 0.04542224694575582, 0.07015704004360096, 0.03804574687299984, 0.016744035628757307, 0.05474369301061545, 0.053002867315496714, 0.017147624865174294, 0.0722402986139059, 0.02392164182050952, 0.057211752182671, 0.022933459042438438, 0.004231349041219801, 0.020137906639969776, 0.10879845584609679, 0.025538129366136024, 0.0433409357709544, 0.08499338464545352, 0.08454817746366773, 0.04426205384411982, 0.07482637877443007, 0.005294410703105054, 0.006964498698445303, 0.019874942089830126, 0.07347167682434831, 0.03307757453460779, 0.06127251964062452, 0.05687277644340481, 0.015467621352789658, 0.03669231039072786, 0.01709520464230861, 0.06414006291223423, 0.013115924999250897, 0.05938389205506869, 0.014694602029131991, 0.06775617958711726, 0.04470240271517208, 0.017024687890495573, 0.019764905762193457, 0.05991726129182747, 0.010277613016244556, 0.002774310015541102, 0.031237947355423654, 0.053822785283305814, 0.048812370747327805, 0.030943140853196383, 0.060253780734326155, 0.00601845040052597, 0.021364764110850434, 0.14393620858235018, 0.04583265206643513, 0.03604922204145363, 0.05157894800816264, 0.01695215080066451, 0.05364118217091475, 0.08088727069220372, 0.014370766102469392, 0.05671015874083553, 0.044336818225149593, 0.028240988796044673, 0.01696999118264232, 0.013346425041423311, 0.03135885890307171, 0.0165746783771153, 0.05386838622923408, 0.05237436407644834, 0.02896860734160457, 0.015860086007575904, 0.04685083118134311, 0.03632145029093538, 0.003974611746213798, 0.06067967002413102, 0.06520886413220849, 0.03726576408371329, 0.06382384523749352, 0.034531597048044205, 0.016775635004575764, 0.04206232813053897, 0.006760185443064464, 0.015111120750329323, 0.030888834302978854, 0.05335261819085904, 0.04564075218513608, 0.029103924187698534, 0.10913857830954449, 0.027662033880395547, 0.052256377014730654, 0.044071361755153964, 0.03585563939330833, 0.033934862818568945, 0.012037113691414041, 0.0796270818848695, 0.07139812130481005, 0.07970854679920844, 0.008794505947402545, 0.029960021642701964, 0.04763610315110002, 0.06991818893168654, 0.0219598393222051, 0.01301529910415411, 0.025785594480112195, 0.0303730255525027, 0.0068922351430436325, 0.01667499469060983, 0.04660761708925877, 0.11147011962852307, 0.06581565085798502, 0.06874340732714959, 0.13225270408604825, 0.0869631582338895, 0.03859386406838894, 0.026351312873885036, 0.031033840629139116, 0.02320602486309196, 0.04378756109092917, 0.05395341345242091, 0.00623424701292866, 0.06018269062042236, 0.06217420447085585, 0.048217858720038614, 0.034170993005058596, 0.02055372986277299, 0.022595326382932917, 0.04614009967605982, 0.06717458686658315, 0.014012896555608936, 0.0483239985603307, 0.012641798654970313, 0.04148584817137037, 0.04753186660153525, 0.04484612321747201, 0.04936470164518271, 0.03975278152418988, 0.07138111721724272, 0.014534320183364409, 0.017923146286713224, 0.018266905697860887, 0.05657752210806523, 0.035306745275322876, 0.06997885674770389, 0.01203096192330122, 0.022304170399105976, 0.03786004880177123, 0.01234048924275807, 0.03217775567567774, 0.03447798599622079, 0.021295957267284393, 0.02844451876756336, 0.08848887815007142, 0.015097716291035925, 0.019489580000351583, 0.05760786735585757, 0.02402878419629165, 0.0489802504889667, 0.017501692919592773, 0.04532917229724782, 0.015670966423515762, 0.06521314568817616, 0.034575447373624356, 0.09186552624617304, 0.06675820385238954, 0.018038604109148895, 0.028977170453539917, 0.002939973704217534, 0.06958759988525084, 0.04109151415260775, 0.07653963898441621, 0.02064024647032576, 0.0177974256221205, 0.024539112080154673, 0.025993675725268464, 0.020888663229665587, 0.0673629210463592, 0.018231579468452504, 0.06743778381496668, 0.0053213625381301555, 0.05097002389707735, 0.03191660111770034, 0.052911801130643914, 0.027760945626401475, 0.03430323948019317, 0.05350835894101432, 0.07011769858321973, 0.022752780434010283, 0.01971738795483751, 0.012926185403817465, 0.052118284960410426, 0.0477039362969143, 0.016056399759171263, 0.007907328195869923, 0.002770526334643364, 0.025303463118949106, 0.0790052723937801, 0.06254153618855135, 0.04543096612074545, 0.03265021960916264, 0.04542821805391993, 0.06295504221426589, 0.0522225181173001, 0.03957810964701431, 0.05636513725455318, 0.03386174388495939, 0.05684841703623533, 0.090245089626738, 0.0170920969519232, 0.053649182098784616, 0.07495035390768733, 0.00845544199858393, 0.018582288774528673, 0.05085519202319639, 0.014219775097444654, 0.06738381313958339, 0.02996543635215078, 0.06060870883188077, 0.021469421352126768, 0.026839634170755744, 0.021369624117921506, 0.024455518262194734, 0.04380839890135186, 0.0729866735637188, 0.09517778815435511, 0.03314711080331888, 0.004050726411930684, 0.04578106304896729, 0.03216678376442619, 0.03621120531378048, 0.03988796266328011, 0.02707287040539086, 0.031258707134319205, 0.0671551264822483, 0.06883988143610102, 0.028016768595469848, 0.0004338929549183896, 0.0582460363262466, 0.013510280222232853, 0.020025943272880146, 0.04248445155099034, 0.012602716734233712, 0.04234811690236841, 0.051225258237017054, 0.04200619292844619, 0.049706201534718275, 0.1120336361761604, 0.04555888014978596, 0.018153795606589744, 0.03702128113114408, 0.0445403889087694, 0.06380490732512303, 0.048978401481040885, 0.04274242377973028, 0.03552011400461197, 0.030391807401818887, 0.015410682086699774, 0.056649389144565375, 0.008319539916036385, 0.013799835711584559, 0.06291303411126137, 0.031643558626196215, 0.04506296943873167, 0.05144590764705624, 0.03378901510898556, 0.028376897663942406, 0.05319055688700505, 0.0340396591595241, 0.01705129664125187, 0.14879491286618368, 0.11506267078220844, 0.14944600792867796, 0.15343706948416574, 0.3054002252008234, 0.08336228824087552, 0.08679627254605293, 0.20769182033836842, 0.16149056090840272, 0.16707570478320122, 0.08637256135365792, 0.07943980621972255, 0.2087721023708582, 0.08634387967841965, 0.15036908696804727, 0.10315279343298503, 0.16661298461258411, 0.124406491539308, 0.11475230886467866, 0.29539688197629793, 0.26568410492369104, 0.12298633131597723, 0.17472739491079534, 0.10447229298629931, 0.10475073661655188, 0.08123286214790174, 0.15033878359411443, 0.09196045329528195, 0.1559833399951458, 0.11980153221104826, 0.16091375185975007, 0.14558392230953487, 0.13010375654058798, 0.10418820394469158, 0.11736124886998109, 0.17220211827329227, 0.08319812347846371, 0.20122198893555573, 0.08820654651416199, 0.08248378216688122, 0.1462782807648182, 0.12639989171709332, 0.12440626083740167, 0.1730317630405937, 0.24186217891318457, 0.14324270508119039, 0.09916269539722375, 0.10776020905801229, 0.1452616046049765, 0.07345204002090863, 0.11356856381254536, 0.1645446198859385, 0.11305688055498259, 0.08788197607334171, 0.10436393094382115, 0.1582228448241949, 0.17143700218626431, 0.13838064883436474, 0.12013029599828379, 0.16891526750155858, 0.08309556291039501, 0.05926801184458392, 0.13686311883585794, 0.10114618896373681, 0.148149042523333, 0.17098816484212875, 0.09725285002163478, 0.14565352643174784, 0.21042263880372047, 0.13217136130801269, 0.16147582312779768, 0.18605001377207891, 0.17553183888750418, 0.11947932307209287, 0.06264619342982769, 0.16284807877881186, 0.18693558339561733, 0.17731143268091337, 0.13443956816835062, 0.08709131314286164, 0.10281434695103339, 0.06679551649306502, 0.09341549700392143, 0.1251332432563816, 0.09191915086869683, 0.13999968767166138, 0.18475383546735558, 0.11909261239426476, 0.09981451649218798, 0.1462791764310428, 0.11066786731992449, 0.12868431556437696, 0.13992551022342273, 0.13853596550013336, 0.16205341927707195, 0.16585541383496352, 0.10176041921866791, 0.12030466592737607, 0.18495571320610388, 0.0679533618635365, 0.1185097915253469, 0.17858494791601384, 0.10776613266872508, 0.16265895749841416, 0.21396206745079585, 0.16175566454018864, 0.13302216279719556, 0.14057786736105168, 0.11435722506472043, 0.13551674251045498, 0.16715168713458947, 0.1941403496478285, 0.1415560163025345, 0.2112859253372465, 0.22678409942558833, 0.17135625651904515, 0.11575055601341383, 0.11618384133492198, 0.10693727500204529, 0.08190356008708477, 0.17473074687378748, 0.12657362382326806, 0.1376509658460106, 0.23338610945003374, 0.1640100564275469, 0.10572033601679973, 0.20521970013422625, 0.08617581333965063, 0.1703980022243091, 0.14066477412624018, 0.18652141919093473, 0.17886534572712012, 0.09583081704165254, 0.13757221507174627, 0.10891464139733996, 0.15989635645278863, 0.20587581635585853, 0.16265677261565412, 0.13705027236470155, 0.12173417636326381, 0.21486785741789, 0.15592195971735887, 0.19240961037576199, 0.08721268270164728, 0.08999804859714848, 0.08344168362340756, 0.11129690999431269, 0.12636981904506683, 0.09584447595157794, 0.13515885600021907, 0.12305592186748981, 0.1160962696054152, 0.2072269967091935, 0.18111595138907433, 0.13371741691870348, 0.16331864281424455, 0.21006340879414762, 0.14105326256581716, 0.1972749235906771, 0.20498299997832092, 0.15534943901002407, 0.09150811471045017, 0.0747785691970161, 0.09850788196282727, 0.16158331664545195, 0.10955904610455036, 0.11712160387209483, 0.11606633264039244, 0.1431887751179082, 0.12123963290027209, 0.1481508067143815, 0.14669153573257582, 0.09477638040802308, 0.22601233369537763, 0.11684895493090153, 0.1501589718141726], [0.10211975779384375, 0.09234010042356593, 0.019239712872409394, 0.058060083804386, 0.028443355080006377, 0.07389331848493644, 0.01568462194076606, 0.02463400350617511, 0.0034300541031240884, 0.03415215687294092, 0.026791368278541734, 0.04485855397901364, 0.08743330157761063, 0.0016798367411995838, 0.05728661495127848, 0.041240513657352755, 0.009857349629913057, 0.032498136162757874, 0.02595006119060729, 0.04571339953690767, 0.04546194463702185, 0.04265132027545145, 0.025079171672197323, 0.04968297528102994, 0.05252185384077685, 0.06206937759582486, 0.04748075255858047, 0.05293548200279474, 0.0795835063659719, 0.08597130967038018, 0.028544142975338867, 0.048199399174856286, 0.020810121104919484, 0.016912086700488414, 0.032270541946802817, 0.04136543195428593, 0.04052431655249425, 0.018750414485111833, 0.03460140812343784, 0.02203279540741018, 0.05939064347850425, 0.027379571626495038, 0.0396514083924038, 0.01628264199410166, 0.03564072021150163, 0.025307956717110107, 0.011283850762993097, 0.06494144669600896, 0.0716018718002098, 0.024050388751285415, 0.0461841908815716, 0.06355171198291437, 0.03503690207643168, 0.023451520529176508, 0.04569628009838717, 0.05860029945948294, 0.03468912913064871, 0.026821167840223228, 0.050942604296973774, 0.017310251049431305, 0.027675119428230182, 0.03473913376884801, 0.06132636817970446, 0.03159706201404333, 0.056195578138743124, 0.005598256564033883, 0.04739464646471398, 0.03051943305347647, 0.03195407999945538, 0.012157432369089552, 0.025655188531215702, 0.04650936521855848, 0.015770161457891976, 0.02815485216810235, 0.05045493100104587, 0.06850068178027868, 0.05229012395388313, 0.06921382208487817, 0.03182219993323088, 0.03665463473381741, 0.03561391807826502, 0.03272085510460394, 0.0437721312046051, 0.04891023924574256, 0.012627330592035182, 0.04341670438381178, 0.02183746383525431, 0.012845653475129178, 0.022864743801099912, 0.03657286447872009, 0.01597607139098857, 0.047927391449255605, 0.03621834350217666, 0.06479442172816821, 0.04147549372698579, 0.06625824567994901, 0.01318125265450882, 0.02876397475068058, 0.042359709673162015, 0.03345311313335385, 0.05574618439589228, 0.029223010476146425, 0.03758963902613946, 0.030380733710314547, 0.06369206016617161, 0.052716661244630814, 0.05404834050152983, 0.04816069893006768, 0.03452162258327007, 0.028987277232642685, 0.03473056726423757, 0.03556055808439851, 0.03376309846394828, 0.034647992945143154, 0.017354466087583984, 0.013788940135522612, 0.03744299403790917, 0.01989883670051183, 0.022817806141184907, 0.043323114048689604, 0.0497946960718504, 0.01298467766693128, 0.027516367678929652, 0.039208548941782544, 0.021193712217999355, 0.06606128053473574, 0.0321800355533404, 0.015261948906949587, 0.03551947957436953, 0.04233581506248031, 0.044342395783002884, 0.029748169439179555, 0.0350109379339431, 0.06308680692953722, 0.08460938810770001, 0.040281428157218864, 0.09430161624082498, 0.015091175213456154, 0.03707411526037114, 0.02129012016978647, 0.037634639468576224, 0.021056086656504443, 0.07934361709547894, 0.03403976772512708, 0.023743507718401294, 0.012523708116662289, 0.01477761909232608, 0.011525525428753878, 0.02894227339753083, 0.030037048938018934, 0.02160085697791406, 0.0384047156465905, 0.028242713971329585, 0.022345647548458407, 0.039163480645843914, 0.03498450560229165, 0.053961973171681166, 0.021240241060565625, 0.027363476775852696, 0.04196250545127051, 0.008693817287816532, 0.03598717679934842, 0.11466027237474918, 0.04111153093565788, 0.023759558464267423, 0.03457716406722154, 0.07300890237092972, 0.05279612448066473, 0.04770681667806847, 0.007371325395070016, 0.029892171533512216, 0.03407060374904956, 0.009492783790587314, 0.025446747662499547, 0.043513036000409296, 0.028082620419029678, 0.017824276949145963, 0.020297723689249585, 0.044593117865068574, 0.038258915434458425, 0.02750651874313397, 0.03068602018590484, 0.028485768607684543, 0.009233373067607837, 0.004007242071176214, 0.012289739064207035, 0.02188645406360073, 0.08606297975139958, 0.08795120700129441, 0.013667726639791258, 0.06763199410800423, 0.0375691879806774, 0.04213701108736651, 0.066470009673919, 0.05405630650264876, 0.03460363032562392, 0.02582286131967391, 0.013811925509279328, 0.030918499853994166, 0.04124800807663372, 0.02258821194326239, 0.09757028905940907, 0.02456383959257177, 0.02048042942104595, 0.03475676889398268, 0.055314191683594666, 0.004150845950269806, 0.03919426917231508, 0.04071639285289815, 0.009679957675481481, 0.017039588519505093, 0.028963436904762472, 0.03658811455326421, 0.012371413476232971, 0.0200544315656381, 0.044262403289654424, 0.05635746980884245, 0.0167530262177544, 0.042452499336962185, 0.016410566201167445, 0.09914377105555364, 0.012638989519993109, 0.011899320192502012, 0.02740733727945813, 0.06484323553740978, 0.02465649863838085, 0.02002397721766361, 0.03960033506155014, 0.0036280788231774098, 0.018506822109754597, 0.06204638882939305, 0.032379419675895145, 0.0071949325834533995, 0.03777636507792132, 0.03184340075988855, 0.043737088263567, 0.015584875596687198, 0.09998830288116421, 0.06693471795214073, 0.021272632626018355, 0.05799194531781333, 0.025770301997129406, 0.038280933895813565, 0.03848098637536168, 0.02771130230809961, 0.01842516890194799, 0.01982534796531711, 0.031691320706158876, 0.018845112528651953, 0.05282443296164274, 0.05724683922848531, 0.02200244114335094, 0.04552199837884732, 0.05986915994435549, 0.020959319081157446, 0.010431609931401908, 0.032445644693715234, 0.031312002667358944, 0.01563092098305268, 0.018730808215747987, 0.018076651263982058, 0.04419206634962133, 0.02860598126426339, 0.05552618977214609, 0.054269899148494005, 0.047834954623665125, 0.009192681322539491, 0.014555468423558133, 0.02555525559000671, 0.053445641949240646, 0.04251205096287387, 0.051236722086157115, 0.014200836336905403, 0.02812475065833756, 0.10697956130440746, 0.019309603675667728, 0.021183982025831938, 0.01571491004766098, 0.08118884558124201, 0.024340257214914476, 0.04405549082106777, 0.041186057829431126, 0.01307255812987153, 0.05581788519131286, 0.029628214625907794, 0.06473253254911729, 0.01197714646280344, 0.022889417030715516, 0.05493054798405085, 0.0640336007678083, 0.03039198721359883, 0.02467455106255199, 0.019045958894171884, 0.011014317993872931, 0.024125439813360572, 0.05421533814764448, 0.011475472444934505, 0.03629447173859392, 0.02963969883109842, 0.0747857955949647, 0.04589953526322331, 0.047440922552985806, 0.0314055014002536, 0.02511925103941134, 0.041051304167402644, 0.026493890044678534, 0.0311908841665302, 0.035808647450591834, 0.044238213516239605, 0.03460733512682574, 0.03433678625151515, 0.0366620680849467, 0.06559352563428027, 0.03190401090042932, 0.057265899277159145, 0.01984124943347914, 0.03098443988710642, 0.05698105027633054, 0.03231291306604232, 0.018610174867457578, 0.011008359608240426, 0.04874892772308417, 0.061117420106061866, 0.018747464554118257, 0.021986919654799358, 0.027330598361524086, 0.019919805128925612, 0.03951396433902638, 0.025287168100476265, 0.041792420470821004, 0.08032467695219175, 0.059880301489361694, 0.03500638496396797, 0.04478001694328018, 0.030910778125481944, 0.025848377629050186, 0.009134482525821244, 0.021350937263507928, 0.049253197985568216, 0.04953898675739765, 0.02416235551105014, 0.10573843933109726, 0.028790037280746868, 0.012091360021648663, 0.026339022908359766, 0.07475132601601736, 0.036272076690303426, 0.015273302494149123, 0.03194982558488846, 0.04930780987654414, 0.011289174718383168, 0.014922550779634287, 0.21743520322654927, 0.15123645828238555, 0.17947996274701186, 0.10859007774186985, 0.13071663651083196, 0.14751575221972807, 0.25241195995892796, 0.07914920324193579, 0.09461699931749276, 0.07742098133478846, 0.05030494083517364, 0.1445947675300496, 0.17827744941626275, 0.09295603380139385, 0.26285542813794954, 0.1606172863394022, 0.06504040424312864, 0.1313614890511547, 0.06607404377843652, 0.12830274818199022, 0.06237540367458548, 0.09847900351243359, 0.09676603507250547, 0.13760715962520667, 0.1545026544481516, 0.23244058447224752, 0.1127288495855672, 0.059398039510207515, 0.12973029086632387, 0.1641649795430047, 0.14850439131259918, 0.10532189346849918, 0.11742283270827361, 0.103127104097179, 0.14207775544907364, 0.12810624444058963, 0.11461656114884786, 0.11762266127126557, 0.2032423269535814, 0.11014955477522952, 0.1188329913254295, 0.14495766162872314, 0.07942061046404497, 0.09062278935951845, 0.1450549771210977, 0.1276361689503704, 0.10223241496298995, 0.12951501884630748, 0.17536101091120923, 0.20005442015826702, 0.10645453804837805, 0.12631149217486382, 0.0869260084416185, 0.20570245065859386, 0.0882504680859191, 0.2386410374726568, 0.08249843852328402, 0.10067028485770736, 0.09928896397884403, 0.10913141976509776, 0.1671073380857706, 0.1639131209147828, 0.16982269952339785, 0.08281086997262069, 0.27800214822803226, 0.1110878601404173, 0.07701605877705983, 0.11219967369522367, 0.1584606170654297, 0.08080472012183496, 0.1595987645643098, 0.14162635324256762, 0.15087838178234442, 0.1125117251649499, 0.19517937675118446, 0.11683846477951322, 0.11342838526304279, 0.1852186590965305, 0.06509297713637352, 0.10883939864912204, 0.07269738694386822, 0.17773158156446048, 0.08236905546592814, 0.16280994511076383, 0.08523785402732235, 0.13360301591455936, 0.11709055410964148, 0.1390048060566187, 0.10814837858613048, 0.12874287313648633, 0.13683669668223175, 0.13810448508177484, 0.13902371004223824, 0.14668308118624346, 0.2791788365159716, 0.17560957185924053, 0.1098963390769703, 0.13135867991617747, 0.1740343663841486, 0.1311550922691822, 0.14098834033523286, 0.10946209702108588, 0.1853468750736543, 0.10526391265115567, 0.17734177676694735, 0.19779785695884908, 0.14851646923593112, 0.16978700858141693, 0.15079070148723467, 0.19228993036917277, 0.07516217896980898, 0.09428845944681338, 0.17950592349682534, 0.1062706211315734, 0.10450253529208046, 0.0928162420168519, 0.1092924496957234, 0.05971374149833407, 0.10156370513141155, 0.19058660391185964, 0.0750637235386031, 0.10129767869200025, 0.12422137361552034, 0.12927096337080002, 0.10660728985177619, 0.1916527317038604, 0.1331885667251689, 0.1097416670194694, 0.0978417709203703, 0.07761143932917289, 0.18578907634530747, 0.1108868441411427, 0.14961535669863224, 0.1763294975140265, 0.17451352067291737, 0.1580444308263915, 0.23132233162011417, 0.105442068805652, 0.09641758019902877, 0.07798307974423681, 0.10527213649558169, 0.12171102474842753, 0.09710334840097598, 0.1417835969477892, 0.14397785706179483, 0.14742528993104184, 0.20898930143032754, 0.15997571790856974, 0.09024986651326929, 0.10109411140105554, 0.07650318808321442, 0.15020142096493924, 0.13528840190597943, 0.20743620262614318, 0.14713024933423313, 0.1129023984872869, 0.16577742301992007, 0.08100627894912447, 0.11973747850528785, 0.10749656427651644, 0.08394751790910959, 0.1156101535473551, 0.1441620657486575, 0.10862617580486195, 0.09753099509647914, 0.2400714164333684, 0.1367431538445609, 0.10139639196651322, 0.16527727485767432, 0.09604129860443728, 0.09478171369326965, 0.07942739581423146, 0.10513798333704472, 0.2180900438023465, 0.1265407827283655, 0.1299646297203643], [0.057284362215016565, 0.021533271497381583, 0.01745658221521548, 0.0742964225688151, 0.01778272516094148, 0.05181601118030293, 0.05545228713058999, 0.05873967733766351, 0.07701700194073574, 0.07016778125294618, 0.013586404217806245, 0.04027532473472612, 0.02154641132801771, 0.10092955987368311, 0.036536712132926495, 0.010470161746655191, 0.022842313129720942, 0.08082323734249387, 0.07173526499952589, 0.0559312717856041, 0.037524435203522444, 0.0316434161338423, 0.037475221058619876, 0.02217809689630355, 0.0385462919782315, 0.013562938780523837, 0.026917389194880213, 0.04896536682333265, 0.031546144746243954, 0.024184044882921234, 0.018340801554066793, 0.026092731659965854, 0.022888599396018044, 0.057092574291995594, 0.010407068167946168, 0.03284600410344345, 0.014323528190808637, 0.042578605070177994, 0.07387788181326219, 0.028054971813357303, 0.06407628740583148, 0.045578238753868, 0.02083439739154918, 0.008792150582719063, 0.043240390451891084, 0.025817684097481624, 0.02586641308984586, 0.09995345332260643, 0.030358057069991316, 0.03956069165308561, 0.04815977951511741, 0.05467118475852268, 0.013750803922968251, 0.010872383735009601, 0.030725232724632536, 0.02666463829310877, 0.0457738298656685, 0.04960749504555549, 0.007759304085214223, 0.03498481433572514, 0.044492192566394806, 0.030250098755849258, 0.0542497704071658, 0.028323636057653596, 0.01486393722838589, 0.049836873808609586, 0.010157172202265688, 0.0296816289025758, 0.06707035710236856, 0.04946458199992776, 0.05594833354864802, 0.03825875258605395, 0.016152497281187346, 0.04752988867195589, 0.07816224691591092, 0.04796156586546983, 0.06325412009443555, 0.017074081847178083, 0.02662874379062227, 0.02952857854376946, 0.007616753207652697, 0.021966030954250267, 0.03633857312213097, 0.07660184028957572, 0.011441227630712092, 0.009128577574821455, 0.04576063575223088, 0.042366820720157454, 0.020362801982888153, 0.0015861574543773063, 0.031124974667493786, 0.03437659590105925, 0.12109925757561411, 0.03410559579996126, 0.05733955425343343, 0.03774962740551148, 0.017339253332465887, 0.015634311961808374, 0.016112970920013528, 0.05901937625770058, 0.1026688486869846, 0.07819666899740696, 0.011134926745268916, 0.03625057730823755, 0.016274306191397563, 0.06515956177775349, 0.02692839503288269, 0.03286142381174224, 0.03159109769122941, 0.030689416253673177, 0.021816873690113425, 0.08402190570320402, 0.05907049708600555, 0.05204357146950705, 0.060037334848727496, 0.03600148031754153, 0.03965303348377347, 0.023097776475229433, 0.008289634333258229, 0.023760130130020634, 0.004758659808430821, 0.026534764994201914, 0.06222335754760674, 0.02354094635562173, 0.0859422819422824, 0.023213276706103767, 0.03683950838499835, 0.010790096945129335, 0.015173488296568394, 0.027219741006514857, 0.030275757557579448, 0.013100107499797429, 0.027993851075214998, 0.06849318396832262, 0.014975490081789238, 0.03990843067211764, 0.04015447425522974, 0.001009437781509145, 0.057672660664788315, 0.03671807097271085, 0.03243416727387479, 0.07579881445105587, 0.027150259020605257, 0.05876902397722006, 0.02072392849783812, 0.04401572188362479, 0.03130339205797229, 0.06267253415925161, 0.0500657436703997, 0.0180425413085946, 0.010899677806134735, 0.023166902230254242, 0.02771642355115286, 0.024943400207640867, 0.022401222959160805, 0.009587274880946746, 0.017890369652637413, 0.03949726219954235, 0.03694637765043548, 0.03851800385330405, 0.03514249569603375, 0.018705863572124923, 0.019669128847973685, 0.07610009078468595, 0.01504838849151773, 0.043345960322767496, 0.027308771586311714, 0.013500782428309321, 0.04454813777868237, 0.010429720211374973, 0.023356919176876545, 0.07679018804005214, 0.029672841874084303, 0.0018065975787716784, 0.006823592420135225, 0.05118214412193213, 0.033774016092398336, 0.06476086817149605, 0.00554829348610448, 0.081645302873637, 0.006047554887897734, 0.022061568684875965, 0.10986658531640257, 0.058460568743092675, 0.07190438985292401, 0.06544228696397372, 0.03371021683726992, 0.030515802891126702, 0.06735198306185858, 0.02831489822295095, 0.03688990996618356, 0.03362128125237567, 0.04870924020984343, 0.018583747624818767, 0.025591628459681357, 0.07924061547964811, 0.05069810777370419, 0.0651233551491584, 0.029049322474747896, 0.03926757470305477, 0.049575624255729575, 0.018506028223782778, 0.042295862920582294, 0.06610202656260558, 0.07888705802283116, 0.013093808150318052, 0.11414470789687974, 0.03125252568029931, 0.039977865160575936, 0.014206797267044229, 0.025529764725693634, 0.016984157297494154, 0.020651918968984058, 0.04321823289085712, 0.07134108365114246, 0.057757966087332795, 0.009297302940727344, 0.0286056250333786, 0.043521466798016, 0.03415395159806524, 0.03374700700598104, 0.0262760260208909, 0.024954994674772024, 0.04393434178616319, 0.04364798304491809, 0.05327484789969666, 0.035992581330771954, 0.04404452569516642, 0.005940441349853894, 0.05066228112471955, 0.054862144868820906, 0.05814475818936314, 0.03536962511550103, 0.06152968441269227, 0.010273166915534862, 0.0365121084531503, 0.025599465539146746, 0.04170121857896447, 0.09428657311946154, 0.017775609024933407, 0.06689173275870935, 0.048832672515085766, 0.016611736567158784, 0.049197229024555, 0.0066932594137532365, 0.021797482855618, 0.0796815003933651, 0.02730457315088383, 0.018613341929657117, 0.025402631011924574, 0.07631561386265925, 0.03751692382086601, 0.07264475976782185, 0.04605535065223064, 0.07039063250912087, 0.0570862435602716, 0.056103226130029986, 0.01234674618379878, 0.045701545530131886, 0.014098379245427037, 0.02521309073615287, 0.02213407015161855, 0.01510806564640786, 0.04657371069437691, 0.04077281643237386, 0.027652184944599867, 0.04815690931198852, 0.02685117265874786, 0.03649851061137659, 0.018970704271591136, 0.011381330800109675, 0.026349786170093075, 0.04946986100237284, 0.06149270425417593, 0.08467080909758806, 0.020975854979561906, 0.03614771139941045, 0.01707214123702475, 0.041347070796681304, 0.06520804310483591, 0.07346637068050248, 0.029816765936889818, 0.0433226628229022, 0.07275379355996847, 0.020095440525827662, 0.06066588219255209, 0.11068432179412671, 0.005286913315233375, 0.026833082915150692, 0.029829532573265687, 0.05014765981052603, 0.04645029195983495, 0.05133163556456566, 0.025988822503547584, 0.0497444437683693, 0.05319292497422014, 0.036660371747400076, 0.016751514781000357, 0.017019922878327112, 0.0051946211024187505, 0.02769765187986195, 0.021822149299883416, 0.04473089100793004, 0.08844931277313403, 0.018614397051611116, 0.029385407654834644, 0.016060460791257874, 0.02915897373376148, 0.06938456185162067, 0.06251424551010132, 0.03526826894709042, 0.053810890564428907, 0.05434039215158139, 0.052463455724396875, 0.0326523468164461, 0.07991848553397826, 0.0184152249712497, 0.07143360868628536, 0.02638715478990759, 0.06960456326071705, 0.023419006827420423, 0.06831789801695518, 0.01631724728005273, 0.012690080662391015, 0.03761392379445689, 0.04666482437668102, 0.007583951128513685, 0.10326538274862937, 0.00719034144588347, 0.028249416200976287, 0.016561041519578015, 0.034894392759140046, 0.03019124941368188, 0.025310390961489508, 0.023707277341080562, 0.017907122682247843, 0.052099292765238454, 0.07930491345801524, 0.04248903166236622, 0.030236772328083004, 0.06274762762976543, 0.04680529469624162, 0.012243023624510636, 0.05359734541603497, 0.009371873091108032, 0.04340186143027885, 0.024285316234454513, 0.030833822076341937, 0.0692436776256987, 0.021641036429043328, 0.011175421715181853, 0.06502921520067112, 0.07072651412870203, 0.14535088624273027, 0.09078113229147025, 0.16930318597171987, 0.06289684426571641, 0.133053578968559, 0.23200442216226033, 0.15623587715838635, 0.18884732866925852, 0.18431744245546205, 0.09354038137410368, 0.1208944892776864, 0.14189782153282846, 0.13484115233378752, 0.1374734610851322, 0.09356687816658191, 0.1987625573362623, 0.1481644452682563, 0.1435427532664367, 0.15952382715685026, 0.11726109710122858, 0.22293133687760147, 0.12986998765596322, 0.08140411760125842, 0.10987320781818458, 0.10442164713250739, 0.13507336058786937, 0.1567745389682906, 0.1628649743007762, 0.1552598588168621, 0.1541946538324867, 0.0741801013105682, 0.10957810615322419, 0.10444084967353515, 0.1131438280322722, 0.10185988566705159, 0.10781534681362764, 0.12371142740760531, 0.19050783956689493, 0.14635145398122923, 0.1192159429192543, 0.17545971061502183, 0.1532599718442985, 0.09291683483336653, 0.11648327883865152, 0.11536579951643944, 0.0848901251863156, 0.15229955980820314, 0.09860580813671861, 0.12252234907022544, 0.09953164881361382, 0.2090796958655119, 0.07116745332522051, 0.11561955804271357, 0.10107066123081104, 0.2086992005684546, 0.12407604498522622, 0.11759784046028342, 0.125901032771383, 0.10662480962595769, 0.17023196470524582, 0.14168827634836945, 0.3238703826708453, 0.06561021759573903, 0.17806485082421983, 0.16943487604813917, 0.12058553871299539, 0.09038389753550291, 0.13124689805720532, 0.08933718263038568, 0.10055551744465317, 0.14616309266005242, 0.06121020976986204, 0.1447628406541688, 0.14257763219731195, 0.12808734045497008, 0.14152788424066134, 0.10377855878323317, 0.20702912232705525, 0.11073557154408523, 0.09972951641040188, 0.10266068591071026, 0.17863644872392925, 0.12675154927585805, 0.0963957720835294, 0.13579066709748336, 0.07134475452559334, 0.09599933121353388, 0.13118839476789745, 0.07461424158619982, 0.09704496046262127, 0.19526598496096476, 0.17738852782973222, 0.15926882012614182, 0.08966688279594694, 0.13693896548024245, 0.09690653253346682, 0.1798554097435304, 0.09619977045804262, 0.12549396604299545, 0.16186380945146084, 0.10513255505689553, 0.18395657039114408, 0.2653095264519964, 0.1732901627463954, 0.138223690113851, 0.10855056664773396, 0.1207728415195431, 0.10938183989908014, 0.20011520332523755, 0.20168545549469336, 0.37134302673595293, 0.2949723090444292, 0.16111609100231103, 0.11325821546571595, 0.14596110635570117, 0.07045619256262269, 0.06767345259764365, 0.10404312637235437, 0.11404356546700001, 0.15992474635796888, 0.10010518732347659, 0.12865410718534673, 0.0498609651944467, 0.1345321610569954, 0.06848287702138935, 0.10595512948930264, 0.13935045179511818, 0.1279866322875023, 0.18387222848832607, 0.1048674446397594, 0.14292699630771363, 0.14081128340746674, 0.22468420996197633, 0.10773190736238446, 0.1947569072778736, 0.06740085115390164, 0.14680752450866358, 0.14327215350099973, 0.21405303185539587, 0.14121828228235245, 0.19688414170273713, 0.07840653309332472, 0.13063169749719755, 0.08161162718066148, 0.1296283613358225, 0.11196623729275805, 0.1050626320232238, 0.22262330912053585, 0.1082190072962216, 0.1151514503040484, 0.17929990669446333, 0.12505559170884745, 0.07512097153812647, 0.07645736661340509, 0.08769940265587398, 0.1309722542230572, 0.11568359817777361, 0.1633647424834115, 0.17960321184779915, 0.1865093276969024, 0.37609643595559256, 0.12039708239691597, 0.2764381521514484, 0.1647109016776085, 0.12441194696085793, 0.10454240600977625, 0.1775957659951278, 0.17155267883624348, 0.0679599843653185, 0.0809069617784449, 0.12169655838182994, 0.16615733477686132, 0.12715744892401354, 0.20182611580405915, 0.17069468487586292], [0.01384990056976676, 0.06262980680912733, 0.06865307396011693, 0.04553442574771387, 0.04034508831266846, 0.035270399547048976, 0.02263389600973044, 0.03565140374537025, 0.014150308378572975, 0.03878197433160884, 0.00844489162721272, 0.012261412771684783, 0.07208346202969551, 0.03450868292046445, 0.04376559691237552, 0.04393336808841143, 0.08010914708886828, 0.004614083079754242, 0.009302545471915176, 0.0207648543374879, 0.0843840805547578, 0.027720004519713775, 0.10309281772268669, 0.015386865507545215, 0.032497922424227, 0.03969370826546635, 0.038218691878552945, 0.01726003606537623, 0.008662537671625614, 0.07458482709314142, 0.0045539466414733654, 0.03533262799360922, 0.13860922014074667, 0.03289493665631328, 0.032148473496947966, 0.010476393242632704, 0.044091809407940934, 0.017440273626042262, 0.016607392246701887, 0.03359652150954519, 0.050484097828822475, 0.04497677852798786, 0.03391099874196308, 0.08066138638449566, 0.015240717546216078, 0.042661596688308885, 0.08301951949085508, 0.04821616577516709, 0.012408358859829605, 0.04374359202172075, 0.05916603481663125, 0.057313023534204276, 0.005110692681877741, 0.10301707285855498, 0.033666668459773064, 0.012569674623331853, 0.050128732076180835, 0.025230388290115764, 0.03505942943905081, 0.04395665541025145, 0.013474096494194652, 0.0900640089863113, 0.09158320139561381, 0.011254804375182306, 0.03656133616875325, 0.016834838881290386, 0.040530782991221974, 0.05114029547465699, 0.034744897923831425, 0.07019531620400292, 0.020354089593248706, 0.047814316981072934, 0.039678875489958694, 0.054393928564552746, 0.08300624734589032, 0.017629824079839245, 0.05112649407237768, 0.07175469824245997, 0.0207505219815565, 0.05187458571578775, 0.03494582910622869, 0.04102974371718509, 0.016655834558020746, 0.04559209783162389, 0.009141938777507415, 0.05868890256221805, 0.017350299882569482, 0.03717259444030268, 0.02019902568177453, 0.03825037267857364, 0.04454727264653359, 0.016816749137693217, 0.07329920000795807, 0.06273934950253793, 0.04665855471310871, 0.02328359498642385, 0.010052670175874872, 0.0448932678305677, 0.013622459872359676, 0.0073201511321323255, 0.030692561263484613, 0.017282643155860047, 0.04044509080371686, 0.04674724941807134, 0.08361200948378869, 0.040739636069961956, 0.02054215914436749, 0.05068134795874357, 0.05313111721937146, 0.06535086794091122, 0.02200996270403266, 0.028889215351747613, 0.05726274408932243, 0.025382488699895994, 0.0346616756037942, 0.0408962487376162, 0.019605879206210375, 0.03916648316330143, 0.04416354413011244, 0.005371210265106389, 0.06589893424617392, 0.03727668849751353, 0.011592882751886333, 0.005602727261638003, 0.039412014452474456, 0.024907202060733522, 0.04144935995074255, 0.03986414608412555, 0.03780436821814094, 0.00781881669536233, 0.04849610557513578, 0.04231935041025281, 0.01431377764259066, 0.01464009191840887, 0.025632745985473906, 0.02161762018554977, 0.009788604702667465, 0.0777469766991479, 0.04043455994022744, 0.09743779831166778, 0.07914058584719896, 0.0934919204030718, 0.03142319420086486, 0.06705527326890401, 0.04319819575175643, 0.0554518325121275, 0.04878461866506508, 0.042597227463764806, 0.04747046257502266, 0.006107296927699021, 0.006083997307411794, 0.025312314608267376, 0.013066283377286578, 0.017549913010693023, 0.06381203194281884, 0.014276624457644565, 0.0438115914086146, 0.02571034325020654, 0.06448684858956508, 0.05172411039737718, 0.02277815085835755, 0.09620267458792243, 0.01395055530260184, 0.06763284227677754, 0.015564188760306154, 0.04904906751055803, 0.057484143280557225, 0.03704853788284319, 0.029898637972239937, 0.023591889068484306, 0.00874304585158825, 0.050622834491410425, 0.04746616744835462, 0.04479041549244097, 0.034452069351183515, 0.04391967525173511, 0.020357911441741244, 0.024392680830455253, 0.014236850431188941, 0.050135181551533084, 0.035913803415106874, 0.03799924347549677, 0.09349911287426949, 0.004851262875100864, 0.06476672392870698, 0.020120300352573395, 0.05112785453509007, 0.017954657452979257, 0.034966113910611184, 0.04895934482504215, 0.04260135295667818, 0.012561097940696138, 0.033312327295009575, 0.050916562122958045, 0.05851514331464257, 0.07227536530366965, 0.04081858701205679, 0.05210031396044152, 0.02049055994887437, 0.033468163040067465, 0.040391354222915, 0.008302797064451235, 0.02438563763696168, 0.028235390882140825, 0.05169632778103862, 0.02539852078604911, 0.01977009485874857, 0.01748549289602254, 0.03919184001694832, 0.04050662375188299, 0.04650921254817929, 0.015553551027551293, 0.07519662140735558, 0.05052447405510715, 0.029244031491024152, 0.056441377449248514, 0.018970207244689976, 0.0031378722591658254, 0.04620571740503822, 0.03675151935645512, 0.044129600415804555, 0.030991008106086935, 0.0222463727862175, 0.049627328624150584, 0.0026819066926171736, 0.026837956492922137, 0.06105350210730519, 0.05875998589077166, 0.022328643460891077, 0.04429919345836554, 0.043236797608967335, 0.03923298977315426, 0.04422375393499221, 0.061556785101337094, 0.041306925272302966, 0.053444223811051676, 0.030252493984465088, 0.04517484289993133, 0.022739978174545934, 0.036253182882709165, 0.025578637906749333, 0.04401327915755766, 0.07778836733528546, 0.04126587390367474, 0.0211870880198798, 0.02560538236450936, 0.023374420291345035, 0.07369878928044013, 0.03425606094034655, 0.008670777631258326, 0.09087552329791443, 0.053516806701996496, 0.040309695926095755, 0.04720727241198931, 0.050073658781392236, 0.03538460377603769, 0.034697570106280703, 0.03820570132562092, 0.03936789271288684, 0.002883431805197948, 0.09166429311569248, 0.0639864561547126, 0.025587106023782065, 0.06488380514617477, 0.009515142367620553, 0.03321370901539922, 0.033421561254986694, 0.00676953183886196, 0.028185940946319273, 0.022879396764827625, 0.06630266936761992, 0.017499314654352408, 0.04540752273585115, 0.01064772079033511, 0.039225033950060606, 0.037709156184324195, 0.024545875377953053, 0.04781416431069374, 0.01103459601290524, 0.06394480088991777, 0.0912573349529079, 0.04881453527403729, 0.03684253465118153, 0.006441199345447655, 0.018478189628305178, 0.06361580640077591, 0.04007434944755264, 0.049074692385537286, 0.025868323165923357, 0.00832140673550644, 0.008270994128127183, 0.05224338306912354, 0.014539728107463037, 0.03305937283273254, 0.06971134431660175, 0.014459179215399283, 0.03302568356905665, 0.05073067406192422, 0.021978968920718347, 0.031245455345404998, 0.035991030878254344, 0.0202974149558161, 0.02679819264449179, 0.015790863561310937, 0.027871226226644855, 0.02648345078341663, 0.03624950522290809, 0.025141629124326364, 0.016052985031689917, 0.05261045694351196, 0.018238293572462032, 0.050399857706257274, 0.0081818880613095, 0.007354093998271439, 0.07700936163642577, 0.0800010971724987, 0.06172206944652966, 0.057783126165824275, 0.08335370477288961, 0.024408845230937004, 0.025901683340115205, 0.018713636190763543, 0.044846547301858664, 0.03705275497798409, 0.003640935365443251, 0.038710558520896096, 0.004678653744381985, 0.0316113349981606, 0.06477734300174884, 0.04195700592494436, 0.056593046989291906, 0.05839257274887391, 0.0298308828579528, 0.020101564304370965, 0.009446169282974941, 0.03270406475556748, 0.009174362573373531, 0.031041664137904133, 0.018100377937246646, 0.010436184953765144, 0.024362455488049557, 0.05422002003927316, 0.0373328813750829, 0.0431373616946595, 0.041032071092299054, 0.03786098857277206, 0.017012447118759155, 0.059735373194728575, 0.023697116279176304, 0.068216775943126, 0.0678841784330351, 0.021636829511927705, 0.1076861944581781, 0.14969687589577266, 0.1490449801619564, 0.21855804297540868, 0.19357052950986794, 0.10906370197023664, 0.15602551773190498, 0.16181852402431623, 0.20148964385901177, 0.14679529730762753, 0.06239227884049926, 0.14274866373411246, 0.14070940815976687, 0.08346783436302628, 0.2013260219246149, 0.10186842842293636, 0.16050914142813, 0.09272736071475915, 0.090422906513725, 0.18149359683905328, 0.1258763883795057, 0.16350063947694643, 0.18206835671194962, 0.15060860982963017, 0.10675130890948431, 0.10968020531748023, 0.11457389486687523, 0.08744183076279503, 0.16430521916065896, 0.21141849750919, 0.1051970769518188, 0.08732657480452742, 0.2051123016114746, 0.15305943760488713, 0.12155933145965848, 0.07235048591558423, 0.11273277830332518, 0.10254195585314717, 0.0938545905851892, 0.12471275510532515, 0.10487364644982985, 0.1357640820954527, 0.11978868075779506, 0.18877773811774595, 0.08638476819864341, 0.1440670844167471, 0.1389048985604729, 0.17198543490043708, 0.09931401549173252, 0.16000437922775745, 0.11528265183525425, 0.15118801088205405, 0.08493778548602547, 0.17657169380358287, 0.11701257686529841, 0.09944200755230018, 0.1135006695985794, 0.2001177817583084, 0.17137347773781844, 0.09897976235619613, 0.10447543460343565, 0.25463410786220003, 0.1309992599167994, 0.12308174691029958, 0.18167642131447792, 0.08348614123782941, 0.16087916014449938, 0.1342585485960756, 0.08912554755806923, 0.12454308063856193, 0.10823217087558337, 0.0994013361632824, 0.10269011397446905, 0.24079226489577973, 0.21434100211731025, 0.14439166842826776, 0.1686689592897892, 0.10252187800194536, 0.11844807198005063, 0.12026959923761231, 0.09701802262238093, 0.13738236097352846, 0.13425777506615433, 0.09317682231111185, 0.2616369149514607, 0.1023420322952526, 0.12248378113976546, 0.1842066783990179, 0.09373019476022039, 0.10467155157987561, 0.16073532429124626, 0.0826918820717505, 0.09630375594965049, 0.12124112567731313, 0.16752520709165505, 0.06179771253040858, 0.09385568981191941, 0.0938490198126861, 0.09565129024641854, 0.11395663156041078, 0.10165994175310646, 0.12290508353284427, 0.12678502819367818, 0.18761755180146011, 0.28819442274315016, 0.17719688239906514, 0.07640140783041716, 0.11181333621165582, 0.14108188317290374, 0.13610971426325186, 0.10684320290705987, 0.14327831459896906, 0.09475913883319922, 0.07779063364224774, 0.219354317390493, 0.14172695284443243, 0.08567793148436717, 0.17097531338887556, 0.18566563725471497, 0.09456384966948203, 0.16183499885456903, 0.1625196814004864, 0.11882433321859155, 0.0908817183226347, 0.12028891034424305, 0.12042725006384508, 0.10247906244226865, 0.1428690901292222, 0.16869435007018702, 0.09916375391185284, 0.13780708318310125, 0.12223684867577893, 0.11908790336123534, 0.1836461949029139, 0.1466147798512663, 0.20597112338457788, 0.08196757308074407, 0.1312301518129451, 0.11949176740433488, 0.18555304115372045, 0.1580643661852394, 0.24840906475271496, 0.2369048020669392, 0.09104131654437099, 0.1353982567254986, 0.09230706933885813, 0.1235860205654587, 0.15936328577143805, 0.18876651514853748, 0.07648298131035906, 0.0811732392758131, 0.09039960562118463, 0.16563220295522893, 0.10172620748302766, 0.114172188565135, 0.13131882276918205, 0.128534590027162, 0.08656593026327235, 0.2203034521745784, 0.12457157910934516, 0.08058773819357157, 0.20957472787371703, 0.14324201297547134, 0.1436488354312522, 0.12788050941058568, 0.11741178615817002, 0.12043535177196775, 0.09443229530006647, 0.15469340421259403, 0.1055452400552375, 0.12106634862720966, 0.19336377988968576, 0.17503751255571842, 0.15816478936799935, 0.2174119973289115, 0.1456983775964805], [0.07175881016467299, 0.04960404469498566, 0.03226263701383557, 0.05336889963863151, 0.06297553397182908, 0.05322153201060636, 0.01831759904910411, 0.058577616033809524, 0.023484093602746725, 0.021849641842501502, 0.08283744818930115, 0.031636393296399286, 0.06368628583316292, 0.03769483570275562, 0.04947155394724437, 0.042820363704647334, 0.01293948553835175, 0.03205268131569028, 0.025997302494943142, 0.017707161804927245, 0.047029428383601565, 0.010231983232577997, 0.03229140689862626, 0.0074052741983905435, 0.018571008129843643, 0.025585178984329104, 0.05142413345830781, 0.019218607040654336, 0.046615576305027516, 0.016784508546282138, 0.09505926165729761, 0.038166163090084276, 0.03498710099873798, 0.007263367080927959, 0.016884022492117116, 0.04207912187225052, 0.051140214050454755, 0.01943490364854889, 0.016410571290180087, 0.05808097589761019, 0.04694042494520545, 0.023633488354140093, 0.07495907986802713, 0.059860976812030585, 0.014846159610897303, 0.0378058949219329, 0.008760152567577149, 0.061286348184304576, 0.03503403526597789, 0.018419579469731877, 0.034901446130658896, 0.048426226646240265, 0.05368274583348206, 0.01794389758392104, 0.04163122769179089, 0.027617143699899316, 0.06513361459864037, 0.025826157303526998, 0.0442403237601476, 0.041594552874032936, 0.0608817513233849, 0.04395946793790374, 0.02849664891670857, 0.0384107410375561, 0.01904660859145224, 0.02686016833675759, 0.04646371338250382, 0.006538009753317705, 0.01780677753101502, 0.08524628143225398, 0.017170666218070046, 0.016032537378902947, 0.026195039473740116, 0.03483300230332783, 0.03634324483573437, 0.04588911296533687, 0.048139759339392185, 0.05510761848251734, 0.03581730895010488, 0.027153673748086606, 0.10345903664295163, 0.015152859135663934, 0.01533627902556743, 0.024675609577181082, 0.04476751832823668, 0.022331876680254936, 0.02759918966330588, 0.06373801734298468, 0.022921569412574172, 0.01829370274208486, 0.024418258207983205, 0.021024371929732815, 0.019873350925211395, 0.01710980841224747, 0.011744966198291098, 0.026375180343165994, 0.06941077365939106, 0.032703586388379335, 0.04761385398783854, 0.023399787323017205, 0.015516290973339762, 0.029746418818831444, 0.034826861561409066, 0.04643402069008776, 0.03260379085051162, 0.08175987351153578, 0.004020831855346582, 0.03765718379457082, 0.024215360970369408, 0.06605068181774446, 0.013725028073947345, 0.019792294828221202, 0.022511985319267427, 0.05869749281555414, 0.08275643789342471, 0.033342827444097826, 0.06830883278910603, 0.04530915890687278, 0.04785082895042641, 0.018371530708723834, 0.03473416349983641, 0.062425208144954274, 0.08588219766638108, 0.027610597533306906, 0.019278511504775712, 0.023998068612334982, 0.050698976298528056, 0.011500040501622217, 0.05163151750873242, 0.05553702258371881, 0.028489283419081142, 0.07288398407399654, 0.026182320334815552, 0.031881626030164104, 0.03756447894764798, 0.02223144840848233, 0.03178718752626862, 0.024777360992240052, 0.016781828332958475, 0.02508732257410884, 0.049098488608641286, 0.020355690935892717, 0.034980712591537406, 0.08938961981662683, 0.022601604528192962, 0.036801069376191924, 0.016263707474406277, 0.04321705223992467, 0.04068937698113067, 0.06313179380127362, 0.002409950493269467, 0.023023917938449552, 0.023762730615479604, 0.02164016111886927, 0.03983864334544965, 0.06233358556138618, 0.002888792019803077, 0.032801254718963585, 0.025325184721233587, 0.04686798793928964, 0.02443340141326189, 0.07022055092134646, 0.017505641993401305, 0.03141851570191128, 0.03328691615856119, 0.010608784754627516, 0.059266546208943637, 0.0252721894399396, 0.03844470850058964, 0.002201155726132648, 0.01151407599848296, 0.05334391597924488, 0.07698395049997739, 0.07940440026244946, 0.023732976854911873, 0.002918145656752001, 0.051123898675931354, 0.06709215843251773, 0.006412845911524657, 0.01840198675303587, 0.0418250546125429, 0.08971767114209277, 0.045210197967078, 0.07305924288396325, 0.026502314056935053, 0.05360287208376186, 0.05563475198245474, 0.014582665803443109, 0.02239010007386761, 0.03767399789233293, 0.017922002955206802, 0.04827588703483343, 0.011048685792567474, 0.0372581814548799, 0.02977382145555956, 0.026820682687684894, 0.058292814530432224, 0.05972285422363451, 0.013402265928951758, 0.054217984434217215, 0.05969411148024457, 0.035490044725260565, 0.027325884239482026, 0.03491804988256522, 0.028046288261456147, 0.03953375720552035, 0.039506636160824976, 0.037863848597875664, 0.018547230566452657, 0.037574500909873416, 0.03794744071949806, 0.02504020001340125, 0.03813889955303498, 0.0254448138376964, 0.01317373279016465, 0.019824433639379482, 0.030260161430175816, 0.013376167775796992, 0.04216186243242451, 0.023519979623545493, 0.007093884300307504, 0.01443618705629238, 0.030743692269814864, 0.04814983219174402, 0.06442565151623317, 0.04960028221830726, 0.036141350133610625, 0.06386614511055605, 0.04214358948437231, 0.04871143866330385, 0.03461555218590157, 0.07274738818939243, 0.03921271514679704, 0.027619844269273535, 0.05939820235861199, 0.04442690731957555, 0.027417868142947555, 0.04816683288663626, 0.027002567392108694, 0.01846436786997531, 0.05928422883152962, 0.012972686256814216, 0.04117245998765741, 0.03622863009305937, 0.026009370240249803, 0.06142716455672469, 0.019286224751600196, 0.01798185652920178, 0.058513731961803775, 0.04136515036225319, 0.04518464094560061, 0.022681401942723563, 0.017943839908444455, 0.0392647961021534, 0.01449902618436941, 0.03465791651979089, 0.10587312174694878, 0.026331506436690688, 0.031951111408748796, 0.0245622178938772, 0.0370701186891113, 0.02399144950322807, 0.018555432358490567, 0.04569981187315924, 0.027317789316709553, 0.01627300340416176, 0.02727168455852994, 0.014750421712441104, 0.04173637687095574, 0.03724902123212814, 0.05003623418243868, 0.03483456971922091, 0.06581660759236131, 0.020774009471227015, 0.045677260761814456, 0.022303980409300754, 0.019423375338582054, 0.01629147312736937, 0.02529455056147916, 0.04937822824077947, 0.014907531406996506, 0.03771724432174649, 0.0481980387121439, 0.014146303325625402, 0.06938873484198536, 0.008614871434734335, 0.03257676480071885, 0.03373210976964661, 0.05882344927106585, 0.028409445292449424, 0.03816725213878921, 0.018993075571155975, 0.08085774763354234, 0.01904815904396985, 0.02183221875956016, 0.027657816785254648, 0.046720864583871195, 0.09213020240089723, 0.031268135378403325, 0.03844621145565595, 0.021837769176012704, 0.0663052410153406, 0.03879577234121306, 0.037249713337847164, 0.05872972322893994, 0.02421374266434993, 0.036300191788801124, 0.08185547909566335, 0.015428369798298393, 0.015000896129224981, 0.07765819717730794, 0.035086465666868856, 0.021977443913263933, 0.049692318708236725, 0.08170554999794279, 0.04624688073194452, 0.08560895839972155, 0.052737729756959846, 0.08663440123200417, 0.008881859697534569, 0.017717711328129684, 0.048709308063345294, 0.021071572521967546, 0.03686530967908246, 0.01912528811953962, 0.016576337395235896, 0.025291525991633534, 0.033106921174164326, 0.027117497653567364, 0.030799260895167078, 0.009785562321277601, 0.02915587622140135, 0.060274998524359295, 0.023774106255067245, 0.02471455918358905, 0.003760646330192685, 0.062344598184738836, 0.09138780366629362, 0.020564004579292874, 0.0065498361946083605, 0.01652988319152168, 0.04347354526232396, 0.04167091520503163, 0.01430431377541806, 0.07748944551817008, 0.018922121164255908, 0.005086174667147654, 0.019914286942886453, 0.041506960788475614, 0.044779535183416944, 0.02065620561396437, 0.01700046249399228, 0.0960767317031111, 0.20453417620488576, 0.06616297257798058, 0.07858722018344061, 0.12911878153681755, 0.2720898283379418, 0.09978285604821784, 0.14785370337111609, 0.08748307890657868, 0.17561935633420944, 0.21741217374801636, 0.12030534446239471, 0.10276382323354483, 0.13076650883470262, 0.12275932064013821, 0.13406448758074216, 0.059356323177261014, 0.10384458702589784, 0.14660176554960863, 0.12526744391236985, 0.12686725306723798, 0.13331082516482898, 0.06792805929269109, 0.12013770560068743, 0.1379531039191144, 0.08156199234404735, 0.10990293443735157, 0.17723394398178371, 0.16039190414760793, 0.16485013706343515, 0.1395615576101201, 0.15357957540878228, 0.08348069938697986, 0.09109506330319814, 0.17432520006384167, 0.12670048273035459, 0.1635371446609497, 0.14472617262176105, 0.13585990481078625, 0.13755956717899867, 0.10608257193650518, 0.09969705529510975, 0.19295718813581125, 0.11561282697532858, 0.1447625828108617, 0.18877924446548733, 0.07886332286787884, 0.1319154178989785, 0.0958608557869281, 0.10980726099972214, 0.1211355591991118, 0.13473919566188539, 0.14119154800261768, 0.12516402160482748, 0.09854162550930466, 0.11837339241589818, 0.14265991135367326, 0.12173608983201639, 0.1694095531212432, 0.1912108561290162, 0.23138578821505817, 0.09054335326488529, 0.07093046818460737, 0.12556789921862738, 0.09088779799640179, 0.16167635736720903, 0.14806250216705458, 0.09829899495733635, 0.07310292018311364, 0.1793993120746953, 0.11685890225427491, 0.12375983409583569, 0.15792618931404181, 0.13815925642848015, 0.14172594861260482, 0.09186216071248055, 0.08082753925451211, 0.17446417760636124, 0.09812883873070989, 0.13726836709039553, 0.19106127986950533, 0.10842756860490356, 0.1325645452099187, 0.09909548650362662, 0.1505843454173633, 0.05681257342387523, 0.09635065629013947, 0.18458962999284267, 0.1284607925585338, 0.1018476313246148, 0.09839426127395459, 0.06658364393349205, 0.08845430679087128, 0.08268857760620968, 0.11108302218573433, 0.11471055181963102, 0.11174438348306076, 0.14545220509171486, 0.12191994568066937, 0.11224846036306449, 0.08386580872216395, 0.131108694044607, 0.08660743625036307, 0.12523600059960568, 0.12826093685414108, 0.08355234589959894, 0.11621559677379471, 0.10718299967369863, 0.14032762364617415, 0.2570343847785677, 0.16525081199194702, 0.08642309185649667, 0.09226223853017602, 0.11562846042215824, 0.10509408212133817, 0.14602005747812136, 0.19778985024562903, 0.13762975484132767, 0.15348897741309234, 0.12637188179152353, 0.12681074467088493, 0.09989433935178177, 0.15556325896510056, 0.16683751185025486, 0.12918364948460034, 0.14119469640510424, 0.1513584724494389, 0.09751289856753179, 0.11295391965125288, 0.11047400307974645, 0.13796219628836426, 0.2748392250921045, 0.06016470265707799, 0.07199987330074821, 0.1124031867033669, 0.07316928769328765, 0.21231280666376862, 0.11960422779832568, 0.1561184363173587, 0.16493958154959337, 0.11643267369696073, 0.18719377954091343, 0.17072038778236934, 0.15893587656319141, 0.13901765750987188, 0.1197146118751594, 0.1830724799739463, 0.11197489539959601, 0.15443374243165764, 0.15293873979576997, 0.13736233061977796, 0.14829162987215178, 0.1345494772706713, 0.09665474175874676, 0.10491873510181904, 0.10090287987674985, 0.10921301360109023, 0.11730596183666162, 0.07987290833677564, 0.07802225157086339, 0.14678445431802953, 0.1965641174465418, 0.08628589207572596, 0.06252943790916886, 0.05896214182887759, 0.12573332605617388, 0.13022711420697825, 0.10245919493692261, 0.16981832975787775, 0.06873034552804061, 0.07099190274519579, 0.13247469360274927, 0.15478819555469922, 0.13208810506122454, 0.11062393217746701, 0.1403909581048148], [0.044071419430630546, 0.029784969785915952, 0.01757553279665964, 0.05482636232461248, 0.012107465898485055, 0.03838665643706918, 0.03858381835743785, 0.014454117344160165, 0.03151100341762815, 0.08311386299984795, 0.015782259737274477, 0.03858421190774866, 0.01653672960985984, 0.02290809031442872, 0.01700462360999414, 0.02186640674647476, 0.015295831553105797, 0.03976998917226281, 0.06332370386059795, 0.016601850311937075, 0.028697539387004714, 0.09903595862644059, 0.053757591638714075, 0.03169678630573409, 0.018669991122026528, 0.007918904003288065, 0.024556698011500493, 0.020363068307882974, 0.03939958029825773, 0.010651948063501289, 0.01865041538673852, 0.026861813784177815, 0.028108839012150253, 0.0545146908344967, 0.0340537150124354, 0.04552183553044285, 0.007942070036993494, 0.0192833867788847, 0.052124734435762675, 0.01314559139843498, 0.065763145818242, 0.04441875472132649, 0.016761662272204245, 0.006260502501390874, 0.007902732817456126, 0.03159293991380504, 0.082195526920259, 0.03388554350073848, 0.028979094100317786, 0.0714208861546857, 0.01720338348033173, 0.06075833937419312, 0.024929659873513237, 0.05286807633404221, 0.043032718024083545, 0.04950408630871347, 0.028341193151261126, 0.042798253641064675, 0.004481777232805533, 0.024981934211349914, 0.02706435987991946, 0.04498390993103385, 0.05170754057222179, 0.009670545546604055, 0.053292706941387484, 0.013156817760318518, 0.029268489285771335, 0.015218526058431183, 0.06435009664190666, 0.03143368774492826, 0.055442417838743756, 0.026852561959198544, 0.10896055786205189, 0.04874807955431087, 0.10436972563288041, 0.06448720142777477, 0.016981707786076834, 0.03408085980585643, 0.02160833273748202, 0.06782256066799164, 0.08602800127118826, 0.016434827220759222, 0.03214366268366575, 0.09161645639687777, 0.02241898191693638, 0.014737105462700129, 0.07758851163089275, 0.11022897051381213, 0.010158173041418195, 0.052353790894682915, 0.008080541222755398, 0.0210541748840894, 0.02772234207285302, 0.019880129490047693, 0.03288272302597761, 0.04696441115811467, 0.004788083207261349, 0.06014390555875642, 0.05490196130371519, 0.02590067741195006, 0.025705371284857392, 0.018051226556833302, 0.0743447681888938, 0.019399475638887713, 0.08805946726351976, 0.0793111084827355, 0.039695150152380974, 0.013082055075626289, 0.012710194136681301, 0.021904674425188984, 0.04331356366830213, 0.02957937028259039, 0.11775664479604789, 0.007063801026171339, 0.0949264248566968, 0.024224283705864633, 0.01807751300345574, 0.05638356965833476, 0.08131453740809645, 0.03115006010713322, 0.04263454010444028, 0.037901510684085746, 0.030491511337459087, 0.017971079696768096, 0.0238746346107551, 0.04117361010451402, 0.046031435685498376, 0.0346749782828348, 0.01601727882267109, 0.035135198051908186, 0.07997601173285927, 0.07183115556836128, 0.02528252183193607, 0.007105352814375822, 0.044760868685053926, 0.04308356065303087, 0.05743159752871309, 0.07091953698545694, 0.029280102412615503, 0.00839544423589749, 0.023579144484496543, 0.0062715308158658445, 0.036043186472462754, 0.012880097609013319, 0.031330411322414875, 0.02411928550074143, 0.03524543285103781, 0.050902065222284625, 0.04534036133970533, 0.011161257296667566, 0.06936212269855396, 0.043774899627481184, 0.05350549552323563, 0.032056582892047505, 0.05323241571230548, 0.010035320035448032, 0.0445863257295319, 0.04397441606436457, 0.03168799927724259, 0.03876889896179948, 0.017956111214256713, 0.028474291187844107, 0.0813405185139605, 0.019082465774512718, 0.06371354937021222, 0.014725555100345185, 0.018525186660034314, 0.02081013297928231, 0.054790790126259835, 0.022694363657917296, 0.02504941282261695, 0.03388855619622128, 0.02646535595080682, 0.020666626215513264, 0.05707454561655011, 0.060901327058672905, 0.060443946958652565, 0.057254452391394546, 0.013551276459890817, 0.011620230257644184, 0.021646052499168685, 0.02905303066862481, 0.02023115601124508, 0.08250043341623885, 0.023579302243888378, 0.02373892760702542, 0.013688882513503944, 0.024565970192530324, 0.03412379410916141, 0.01511847267725638, 0.04064215433650783, 0.009162917383946478, 0.03628609183111361, 0.026594957835706215, 0.04568731665079083, 0.0380323118796306, 0.012664655107073486, 0.047915154070194275, 0.0209467169895236, 0.04648242059296795, 0.07454023377171584, 0.05005992523261479, 0.013355602227550532, 0.04633820815277951, 0.02454756323381194, 0.029725492798856328, 0.033931789054934464, 0.00745088786685041, 0.04834152851253748, 0.019444576165239726, 0.054395390807517936, 0.03131694918764489, 0.09026484178113085, 0.034855743404477835, 0.02045621250623039, 0.08129692942436252, 0.03733699329729591, 0.062452274906848154, 0.018638205149077942, 0.07416009809821844, 0.018112903693690896, 0.058778781310788224, 0.08607691007533244, 0.057415916584432125, 0.01503108415220465, 0.04042082978412509, 0.023792029757584845, 0.0578840243230973, 0.02047703504961516, 0.06877413817814418, 0.02810840305340077, 0.05087721387722662, 0.06882176455110312, 0.0327685662944402, 0.01949223646494959, 0.03053691211555685, 0.10647753360016005, 0.01815910853578576, 0.04262160722698484, 0.039363522947366746, 0.0369813595233219, 0.03297283247645412, 0.04848471636484776, 0.021514827219237174, 0.04708717171368854, 0.010693302228381591, 0.017812833456056457, 0.054045802780560086, 0.08400598727166653, 0.022072503276701485, 0.018890248678092445, 0.00779934528483344, 0.02919544159833874, 0.04012106658358659, 0.06246402034802096, 0.06633217207023076, 0.01733901075619672, 0.025875693752563426, 0.04768532408135278, 0.10582259802946023, 0.022319018441651548, 0.0522042926666992, 0.02456976320328457, 0.030247981726591076, 0.030312181317380497, 0.014596300964642848, 0.02589193109555968, 0.030287180694618394, 0.02426606280330036, 0.048937618133745024, 0.032637005139674456, 0.050516128074377775, 0.02208075935154089, 0.025977474005360688, 0.025293025554024746, 0.014603301749697753, 0.03232706052118114, 0.0033334856353966253, 0.0049128785197223935, 0.010410321743360587, 0.05247288736115609, 0.04181820819420474, 0.027831436933151314, 0.021345853339880705, 0.06332043332180806, 0.0699815641024283, 0.0345121705904603, 0.010000227052452309, 0.06980182696133852, 0.04890801365088139, 0.04465034550854138, 0.021953081113419363, 0.015310226673526424, 0.058054255188575814, 0.02001780763800655, 0.0536468818650714, 0.0061448398461964515, 0.029310419357248714, 0.05528478058321135, 0.03325788164511323, 0.043861239815929105, 0.02385999521772776, 0.03439440744529877, 0.03906036367905991, 0.04192113856385861, 0.0330959424775626, 0.040236027379121096, 0.030271486179637055, 0.058183041135115285, 0.028218617496479834, 0.018429179043908204, 0.03591437677719763, 0.07539342370416437, 0.0195800355036876, 0.025687934631215673, 0.015569684893957205, 0.006506579163085137, 0.0033452724247971283, 0.04029864937599216, 0.051873194718999524, 0.019358354720420072, 0.03888116258063486, 0.015109853586181998, 0.036123823574078937, 0.027097949059680104, 0.024874257489240596, 0.0823381549811789, 0.0387523732414203, 0.029291271099022458, 0.028662856069526503, 0.07692184418972049, 0.0017254560287775739, 0.011342216648959687, 0.07684323590781007, 0.016558685306725756, 0.0700493904628924, 0.025301147618197968, 0.017962214636749456, 0.008574765774288347, 0.03753217728808522, 0.009911764745733567, 0.03029553685337305, 0.052607898866491656, 0.04119797290435859, 0.022057887632399797, 0.020881660748273134, 0.04316739704725998, 0.048154819424131086, 0.03699536109343171, 0.05095932000715818, 0.03033516669113721, 0.019786666380241513, 0.13760606039847645, 0.1845391605581556, 0.0904194459851299, 0.16036067796604975, 0.06805064342916012, 0.11721958432878767, 0.09511871489563159, 0.1235867262418781, 0.09233311151287385, 0.18939284368285111, 0.052855421655944416, 0.25413693168333595, 0.062327702662774494, 0.11561911020960126, 0.1405738911458424, 0.07812361113194909, 0.14616588822432927, 0.09321176007922206, 0.0724127482888954, 0.11580679299575941, 0.12867816803710802, 0.13921040216726915, 0.11508764087089471, 0.10301190242171288, 0.1794371743287359, 0.1734381512339626, 0.1417049275977271, 0.09809343277343682, 0.08710778797311441, 0.08360601801957403, 0.20725578016468457, 0.07943282409438066, 0.1643420500414712, 0.18419192704771245, 0.1314064216400896, 0.07528187933244876, 0.17970955185592175, 0.09800908408526864, 0.14710979828877108, 0.11154743190854788, 0.11705267828490053, 0.19563637008624418, 0.07526959106326103, 0.12735820029463085, 0.06711000390350819, 0.19342825428715774, 0.1613401568361691, 0.14652108773589134, 0.10391932765820197, 0.11700482799538545, 0.10519980466259377, 0.14366156474820205, 0.1343568954616785, 0.1577080131641456, 0.18068538020764077, 0.14584350266626903, 0.1948703990450927, 0.1277190859296492, 0.0861440511154277, 0.11977924912103585, 0.21657301591975348, 0.05499046941154769, 0.16977175511419773, 0.09185916158769812, 0.17965722323528358, 0.07999982831201383, 0.17485787719488144, 0.07927568216941186, 0.19456675462424755, 0.09698011965623923, 0.12791879235633782, 0.14093583529548986, 0.20389600044914655, 0.11336034177137272, 0.1807755846530199, 0.09749467990228108, 0.14749949452068123, 0.12834422024233, 0.13562832080892154, 0.15481317921408586, 0.1637974035527025, 0.08762031261410032, 0.15886106129203523, 0.15951876528561115, 0.0558028047505234, 0.12878803642732756, 0.25508061104587143, 0.20812103444976465, 0.09616178606769868, 0.07388418540358543, 0.16152770391532353, 0.12639758469802992, 0.13216800934502057, 0.11220673045941762, 0.1096873435058764, 0.11550099083355495, 0.13291224012417452, 0.14229882215814932, 0.15303499677351542, 0.13989926448890141, 0.12400230179939951, 0.09856483140694243, 0.1900230534374714, 0.1282453712608133, 0.23510063173515455, 0.137063897347876, 0.10423206444829702, 0.05137676153598087, 0.12142690856541906, 0.18835506508392946, 0.1230361493570464, 0.19205362376357826, 0.1305114882332938, 0.173088936401265, 0.15103102502013954, 0.11772053316235542, 0.10005674670849528, 0.1608000293906246, 0.17700003939015524, 0.14020491737340177, 0.1360587291419506, 0.19025507170174802, 0.2064234483987093, 0.11033600941300392, 0.0835711413196155, 0.1089768223464489, 0.09718668607196637, 0.09440258903695004, 0.10600335975842816, 0.09982746972569398, 0.18248432581978186, 0.15161733355905327, 0.10899725982121058, 0.11263252475431987, 0.14427987299859524, 0.13483340346387454, 0.136611477338842, 0.07770604746682302, 0.08028184103646449, 0.07166952174156904, 0.08791139056640011, 0.154378740383046, 0.1013856575425182, 0.08944222663662263, 0.12563962037009851, 0.08888436907104083, 0.19160291366279125, 0.13058516356561864, 0.1637628661202533, 0.08481830903994185, 0.2183910147952182, 0.16193623627935136, 0.10281095427594014, 0.16150786355137825, 0.15419857576489449, 0.11293502245098352, 0.12052428057151181, 0.12210426293313503, 0.13537669288260595, 0.13590789080730506, 0.09610985099737133, 0.08318637125194073, 0.1426848950130599, 0.27983856254390305, 0.1360887475311756, 0.10401156092328684, 0.12346845758812768, 0.09730055103344576, 0.11089208921683685, 0.08506781993699924, 0.11431063685034003, 0.17092948513371603, 0.07943333978099482, 0.1525823732039758, 0.1428298708051443, 0.17130301866148198]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.06404099001416139, 0.02710782683321408, 0.011559419949272913, 0.025232069360624467, 0.018912569087530886, 0.01626915780694357, 0.01637795750450875, 0.04398010897317103, 0.06697913485446147, 0.010612973012030125, 0.013770027668215334, 0.017271186092070172, 0.01623368399616863, 0.009023438573681881, 0.06979312814239945, 0.02015262745719935, 0.01891124085523188, 0.03608485870063305, 0.046671026186751466, 0.019439797582370893, 0.01565947543297495, 0.024074441121358956, 0.04384506354108453, 0.05182839444439326, 0.020105523556204777, 0.030662061114396368, 0.021925739544842924, 0.073558882144945, 0.06415520781385047, 0.032297669776848385, 0.05530566589108535, 0.0547054134575384, 0.044299804139882326, 0.009820144706671792, 0.055842529583190165, 0.013396502622137112, 0.03913699742406607, 0.08711319589721304, 0.04273620839895947, 0.054299639338361363, 0.06512563502682106, 0.03460989320384605, 0.02876651586432542, 0.03906461130827665, 0.03754163606624518, 0.06537781935185194, 0.02720256898153041, 0.03929329796561173, 0.025523552737597908, 0.02087428846529552, 0.05820463890475886, 0.03991278686693736, 0.029102482300783907, 0.03242118350629296, 0.07896140510482447, 0.0625544215685555, 0.02199106041475066, 0.028303354645946195, 0.015676091059244106, 0.031007143668830395, 0.021689599180327993, 0.00983281634814505, 0.04059997659974864, 0.0493293126512851, 0.07192157714494637, 0.05252822528460196, 0.013783181917720606, 0.03348158107006124, 0.04326988636915173, 0.027747359658990587, 0.0992898325036679, 0.01794295272390757, 0.04096490969615323, 0.04176177443670375, 0.02218968797075961, 0.045717952506882806, 0.07774709883545126, 0.09244661685079336, 0.06803059950470924, 0.015639085455664566, 0.01727118100305753, 0.08474641146936587, 0.04046033748558589, 0.037982307241431305, 0.039007292062576325, 0.01496337483903127, 0.02446882942292307, 0.04630190652928182, 0.012905970997443157, 0.04311544501355716, 0.02426096870164786, 0.013843171198719313, 0.05242053838446736, 0.04190308274701238, 0.04227804119831749, 0.013704275928570755, 0.03166708004261766, 0.05764142769787993, 0.030250753542142253, 0.038458418300641437, 0.03522918872269137, 0.042487484602523704, 0.019114411203190684, 0.06505835827972208, 0.020178094572786773, 0.026618117932230234, 0.043076775302844386, 0.05130658405167716, 0.019839142582246234, 0.04531490609848073, 0.017664498915629726, 0.0972185025789908, 0.02568897109345666, 0.03581298668203609, 0.045167199202946255, 0.08444970167641129, 0.008115670677008373, 0.04899670496316893, 0.0608638787109937, 0.00834968383423984, 0.04669545005474772, 0.03760209692908185, 0.03689725510776043, 0.016817800866972123, 0.029543065266417604, 0.026200773094647696, 0.012430400221741624, 0.029103829192795923, 0.057789653672703674, 0.01570021128281951, 0.04153072987017887, 0.04560698149725795, 0.05103296819808228, 0.01830170945530491, 0.01957701941552971, 0.026918334054893682, 0.014833969729287284, 0.011421003046312501, 0.026716892274894884, 0.036881733619208844, 0.044615679154438634, 0.021811576027955328, 0.017118566603000675, 0.04510820397574987, 0.028286957847220556, 0.03247280984318682, 0.025285356411976472, 0.04295234555112464, 0.01081332065431135, 0.04370621831289359, 0.07012613955885172, 0.055722188004957776, 0.01157806015440396, 0.013111835977594768, 0.0963769970195634, 0.06540104560554028, 0.027145290447931205, 0.041048474676374874, 0.03695229786847319, 0.03401884509782706, 0.00786431331653148, 0.020668794134897844, 0.040885476994195154, 0.03959521890750953, 0.027133217613611902, 0.039249634237161705, 0.05893541433449302, 0.03148573138085859, 0.05170681793242693, 0.01591716437334461, 0.034309950191527605, 0.039425910849656375, 0.027559244306758046, 0.05857929201530559, 0.01987743570602366, 0.0500953108338373, 0.033083104595009766, 0.03257958411372133, 0.013493637454562953, 0.020504936409581984, 0.011065587251713234, 0.044239227926092486, 0.025898609576480727, 0.01387233633015837, 0.016022725762533288, 0.009636198952128845, 0.05344755541799324, 0.05267992535872119, 0.03602921204375369, 0.011227313528901764, 0.08299574362380163, 0.0335668457805046, 0.04851251594456179, 0.04551251245928662, 0.036426341626793146, 0.012947189455319728, 0.05472850400422301, 0.057978659602148194, 0.040739279839077165, 0.04466096797425832, 0.03999432302745325, 0.03568230762279459, 0.04764502927927034, 0.026670650113373995, 0.06000289919653109, 0.031734251616788764, 0.021946017563875233, 0.03180357075429388, 0.05680020373048527, 0.023302232647048574, 0.01900426291727594, 0.03661695907690695, 0.02108563855290413, 0.03519461057814104, 0.027760005855400647, 0.032610813687954626, 0.043714462513370175, 0.04005945221121822, 0.0569887991462435, 0.028831818074520146, 0.03713583141299231, 0.06347683564360652, 0.0616686823112624, 0.028092834067397883, 0.09777101328862564, 0.02618215579007353, 0.054287147508668046, 0.028260411860953485, 0.023848288792318532, 0.07274421264550515, 0.03688042404662285, 0.05478896147438458, 0.05854607094079256, 0.026571433026609675, 0.03184599954900997, 0.042500936559268405, 0.024169018724933267, 0.02049773884937167, 0.05675236701167055, 0.004974123938674373, 0.02499494681667004, 0.019133564550429583, 0.014872904068657329, 0.03805622345368777, 0.036366413413946114, 0.03298656602523156, 0.020910756329872777, 0.07517659783895526, 0.03173160193754094, 0.013486869067751935, 0.04268295018534575, 0.02050403904701982, 0.037773847713002136, 0.013615924731961318, 0.05900238574083362, 0.04294159077107906, 0.029320312397820607, 0.03778895190251725, 0.04562951564522726, 0.0065280386812186664, 0.049338221816079955, 0.048305922387433906, 0.018128426878580024, 0.03979813141216125, 0.01051498407364956, 0.02433271869085729, 0.011467701522633433, 0.02671809328187789, 0.05447771746133055, 0.039291890005448034, 0.029178210201540163, 0.02314002376182803, 0.05536330744091954, 0.02684217698073813, 0.02879754187805312, 0.03475290463705148, 0.05444950397525515, 0.028133724283959185, 0.00821671896015427, 0.05772990866431168, 0.04868376461256828, 0.02042714915504413, 0.04728074757648366, 0.046824035833456686, 0.027657260386539356, 0.02096044714562595, 0.06394277207021203, 0.028680189246577874, 0.06901805116129772, 0.014952916918056352, 0.04305076705557959, 0.03359193800549422, 0.04682284500449896, 0.0536874446884862, 0.03274472596655999, 0.05197380110621452, 0.013798540557867714, 0.016411655249872377, 0.041415629974965534, 0.026850957223879438, 0.06638348288834095, 0.018660961517265866, 0.04453914040433509, 0.006139388665490384, 0.0323362173512578, 0.01333520800939628, 0.024374967673793435, 0.021687945251220038, 0.018866703512945344, 0.02393190805534167, 0.06263397979949202, 0.057924573575811725, 0.012651260825805366, 0.033463504897164445, 0.06624288364712681, 0.03581959900579282, 0.023244277274768268, 0.02758601420958127, 0.0915257159088339, 0.006256035196461848, 0.015367040410637856, 0.008654082277124482, 0.07345569053930895, 0.014770657323034746, 0.07661513279059104, 0.061742323716836314, 0.0294524503073522, 0.11043800679700715, 0.03893634444102645, 0.02397884232258158, 0.024933608947321773, 0.020696858343269144, 0.005266781605314463, 0.007588529543552015, 0.019488553716135875, 0.06637816317379475, 0.04247286217287183, 0.06355775772993054, 0.06106655712106398, 0.026441446073087196, 0.04250270753566708, 0.02105794584245554, 0.02356797070907695, 0.013573695256906961, 0.03606190046827708, 0.016089315492925898, 0.006975159331757043, 0.016791453352198005, 0.03172871477103659, 0.005039480855754975, 0.05554488001923476, 0.06557409917669636, 0.1303103297416653, 0.19118532964161464, 0.17234944179654121, 0.09981206698077065, 0.08387995617730276, 0.0884892852710826, 0.14947940542229585, 0.10708514813865934, 0.11044010347021477, 0.1596997305750847, 0.13132912293076515, 0.10093179903924465, 0.15248507128230163, 0.09502559953502246, 0.13828173199934618, 0.10195422239069428, 0.11925197312874453, 0.09357234037348203, 0.10020264530820505, 0.12922736071050167, 0.1310189510030406, 0.11265726414109979, 0.1624357330479792, 0.15024089813232422, 0.1786810013332537, 0.14121110338185514, 0.11049123108386993, 0.0960867265239358, 0.14181050764662878, 0.10671892921839442, 0.0831882915060435, 0.11069323095892157, 0.13628749043813773, 0.11986528736140047, 0.0859592521030988, 0.06864850063409124, 0.12493190834564821, 0.1427700918700014, 0.13622141469802174, 0.1816198043525219, 0.25761873913662775, 0.10956225557518856, 0.12688154301473073, 0.1264042750533138, 0.13586040692670004, 0.2705033863229411, 0.1257552427372762, 0.08539686192359243, 0.189564798027277, 0.12702419821705135, 0.23264436210904801, 0.09667944721877575, 0.11168594804725476, 0.1671339095171009, 0.09541724316243615, 0.13015651942363807, 0.10621386167726346, 0.10063984577677079, 0.11652680007474762, 0.15619447295154842, 0.22804156052214758, 0.17649668854262146, 0.17898330225476197, 0.23313459008932114, 0.20741644368640014, 0.11084351968020201, 0.05345721775665879, 0.16925629920193128, 0.1137285895113434, 0.12642446825546877, 0.1610071589904172, 0.11418782201196466, 0.19652139688176767, 0.07543484826705285, 0.09652114499892507, 0.13097035432500498, 0.10583313567829983, 0.15835306926497392, 0.1931658105126449, 0.16003187346671308, 0.12775046138891152, 0.13440171948501042, 0.11961595288344792, 0.11019443308136292, 0.11567954053836209, 0.1824324314615556, 0.12523049089525426, 0.1122356496219124, 0.09675133121865136, 0.09308209203715835, 0.16224665247968265, 0.14683343097567558, 0.20958877354860306, 0.1633911103542362, 0.11355179042688437, 0.14699570941073553, 0.22415325630988392, 0.16189145296812057, 0.05387261350240026, 0.1314816168908562, 0.15623145311006478, 0.10277284096394267, 0.14077257977000304, 0.13182134580399307, 0.17490085560296262, 0.05711974283414228, 0.07665807048657111, 0.08849818086517708, 0.10467078483530454, 0.10841386898287705, 0.09702189027198724, 0.19764898637575762, 0.1198500067527805, 0.09023078610854489, 0.09746031210358654, 0.22615340112575463, 0.11370926483401231, 0.12319329806736537, 0.12917590061468737, 0.11881924420595169, 0.10454256885818072, 0.0979970468740378, 0.14510877137737616, 0.14459666742810182, 0.2011771106294223, 0.06604760805410997, 0.1259916986205748, 0.09594536053815059, 0.1338379518794162, 0.12555723264813423, 0.11490322862352643, 0.06858568864741496, 0.056691665268902264, 0.10277900206191198, 0.12695973739027977, 0.17392012822840894, 0.15171821814562592, 0.1290554063660758, 0.1471547580191067, 0.07908764654504401, 0.10995938855090312, 0.18638630929802144, 0.22457746283284255, 0.09360348513083798, 0.10539652553520032, 0.06328416562506131, 0.15849613158830575, 0.14194033853709698, 0.17810103031141417, 0.12038718935634408, 0.13799548521637917, 0.17564048591469014, 0.09787388598280293, 0.12220919158841882, 0.2153408234672887, 0.18397841921874455, 0.129178289057953, 0.10519600486648933, 0.08412943993295942, 0.17096281477383204, 0.11386535502970219, 0.11474071948656014, 0.11922039410897664, 0.11909725357379232, 0.10616838626031365, 0.10380728795592274, 0.16457397331084522, 0.09479642433247396, 0.12350522061543805, 0.12393534396375928, 0.08958730420895986, 0.10257061038698469, 0.18740211693303926, 0.10832892318389245, 0.1338004967463868, 0.1573584590639387], [0.013566226282689189, 0.023251289934185997, 0.03025141850646053, 0.014090015453153422, 0.04230237685676132, 0.06343248659478766, 0.05382799303957394, 0.017213773547804782, 0.018106359223436033, 0.03711135665486966, 0.04675510346091219, 0.06486486723380429, 0.07093048854065792, 0.033240843630794964, 0.039849639005426846, 0.007380597576099847, 0.021458568184503486, 0.025853973846616488, 0.08671411552599498, 0.0028828149744575577, 0.03420266362705401, 0.024100252593468343, 0.052945663420749564, 0.02838292984025819, 0.0166765400541148, 0.037949062418192625, 0.012689283383744103, 0.0037049882230348885, 0.04706524485456092, 0.051924827841243575, 0.025637700987447585, 0.029561192329440798, 0.021358374007312313, 0.03197976594258632, 0.008762280623029386, 0.0260206678483103, 0.01657205753560577, 0.013624243571289947, 0.042461652774363756, 0.037668912272368155, 0.04585886726688061, 0.04303076723590493, 0.021986846712284853, 0.024220041165660535, 0.006004424233521734, 0.029979794153145382, 0.07749395099069391, 0.0275863025869642, 0.06868002537105765, 0.034690350493682284, 0.033219819223242145, 0.047255726597670994, 0.05475701604570661, 0.02665176139479237, 0.08122693175183875, 0.039450741838663816, 0.05255869829228946, 0.031737074322466335, 0.05327501753345132, 0.014892388201717819, 0.018252754850046973, 0.0059544764226302505, 0.030233793559351137, 0.07974011224827596, 0.029899859335273504, 0.02589545269230647, 0.01959317872699882, 0.03762198479047843, 0.037437949130045514, 0.024048661879662956, 0.028021560749039054, 0.028369676355006437, 0.006693100806192628, 0.017756196138049875, 0.02779829897917807, 0.06874808921877827, 0.047049743722059896, 0.03477639891207218, 0.08494853348072086, 0.030505563797695295, 0.016248620248266628, 0.04506615176796913, 0.03597011164362941, 0.049069318388189585, 0.019020278040053587, 0.044562292019171376, 0.08834900494132723, 0.07096005909677063, 0.04315532251660313, 0.017780204403347204, 0.010840311929184412, 0.015140932186373642, 0.031105175015649626, 0.024745914286800792, 0.05518616569627609, 0.06510948589337723, 0.01386329994004752, 0.002209345219723348, 0.03435881489089557, 0.02118227890293513, 0.11403850359576088, 0.01277148790125336, 0.024711855221539736, 0.021826619149318764, 0.0368287909243788, 0.03436205489560962, 0.052206691287990124, 0.04444546525233558, 0.08805291261523962, 0.02926322046135153, 0.06137703438954694, 0.05709847076130765, 0.02458210405893624, 0.04293153827477779, 0.04265771546800222, 0.026745249949661747, 0.09864489175379276, 0.06645599114043371, 0.075549541041255, 0.002541883782084499, 0.027686590062720434, 0.011891939427836664, 0.038667339232883284, 0.10833584424108267, 0.014453560945444872, 0.09957684603120599, 0.0044175526210373, 0.06592733772205454, 0.04505576678950872, 0.014858383419258254, 0.023171991242894104, 0.059960293982710154, 0.020365707809105515, 0.028638177750898258, 0.031175030195819478, 0.033449924018766196, 0.04352530391354646, 0.02428598459144788, 0.011112385811949415, 0.02783725706727377, 0.01637260047053652, 0.040703962091356516, 0.0382812663779727, 0.0384245458325105, 0.061121362394520214, 0.09104031909789358, 0.040887892578861544, 0.020488982354956012, 0.018937586673668454, 0.012555624707601964, 0.03516295691952109, 0.03131983296147414, 0.026538018569616333, 0.03415463352575898, 0.015312716897044863, 0.014536138657214386, 0.047661443041371446, 0.04139941298801984, 0.03579633543267846, 0.041911106423607895, 0.03396719501220754, 0.029844972637615035, 0.04522623514224376, 0.030080281796732118, 0.06255368875073535, 0.00874394575865673, 0.0272446194929736, 0.022819424447204386, 0.02285487450925367, 0.050650691746601036, 0.009777941524849405, 0.08815829588898591, 0.029751005715557506, 0.011827639753131993, 0.041673330789698024, 0.039438708020108085, 0.05296608393213578, 0.04218242882883974, 0.06364574336579867, 0.018615318162898933, 0.01173318428586104, 0.043612763684775145, 0.037103797774761915, 0.0476727135080312, 0.050854998640716076, 0.014784440065601041, 0.03418510653344648, 0.04264563075932009, 0.058439310240958414, 0.05027041018807462, 0.028592539485543966, 0.03159363880487425, 0.013382225397175975, 0.03556488713781748, 0.049048029351979494, 0.055590575960065634, 0.028192344620557766, 0.038835724483111074, 0.08509777047272239, 0.06044763818915401, 0.04225797352514096, 0.0030528764182236046, 0.04508246374981744, 0.0484669251766588, 0.02243602671660483, 0.02550703889158155, 0.006351175984101636, 0.0034950969857163727, 0.038131164253822396, 0.060477059467562606, 0.04642450423645122, 0.025179764488711953, 0.03201676306447812, 0.04059108779100435, 0.04345633422157594, 0.0656430111931903, 0.02765254456815975, 0.04638709660087313, 0.036508183128067424, 0.01033623080833682, 0.00797002313525549, 0.03352304295237575, 0.05364681401156953, 0.058849606796034744, 0.010621525945940187, 0.03907348654632058, 0.02200533848788057, 0.015954107212434922, 0.046782730014196465, 0.015620529219242079, 0.06010108321372952, 0.034790285131228824, 0.057499817439488, 0.015777886579079286, 0.10301131888159684, 0.0394854387268424, 0.07373164394604308, 0.041417502731617005, 0.015849521217335547, 0.04300117293106658, 0.055597992347819467, 0.018337313884070942, 0.01722181079510067, 0.01909051489617143, 0.02933850392167057, 0.014310695397268449, 0.01867598937159138, 0.030268595620457615, 0.043880659488162825, 0.03254282787176115, 0.01526731442260955, 0.02131424717871206, 0.02042913726264877, 0.03493924053119762, 0.04370261529194457, 0.07777502055146865, 0.03807873385293143, 0.018222502366240536, 0.0569363891014031, 0.035835605646882734, 0.05758158090923514, 0.035308204125612974, 0.057977723223822455, 0.024575639316546063, 0.025893944648227522, 0.00727361295970955, 0.00968099244138492, 0.011065684791122164, 0.017824192132268633, 0.029162966912346225, 0.07318181344973189, 0.03654508525505662, 0.012441976029159767, 0.02705973736010492, 0.024392463699249283, 0.01853633499039071, 0.07013952026941947, 0.01590931711585394, 0.015574232774919696, 0.02619704115204513, 0.015034933142097933, 0.03706852752449257, 0.028861246138278927, 0.033232575681592734, 0.08929676229932479, 0.04795872958909188, 0.046094193389373164, 0.008923190961857992, 0.0249379363044032, 0.016218184560005153, 0.020384662684851458, 0.024450020432206135, 0.03335132948788149, 0.024300271146265522, 0.08207045256027154, 0.007474459325229483, 0.025308027963287065, 0.013208583196891206, 0.046655368991196156, 0.033632826525717974, 0.012898781918920577, 0.04776486874158893, 0.027604453398713043, 0.06489134367023196, 0.053920253446059566, 0.06920417331691299, 0.029791856916355233, 0.03339105771322336, 0.030571344375078167, 0.034427509776183536, 0.04977372933977416, 0.06382416414895228, 0.024779985226424675, 0.034811197580503564, 0.04572463607681649, 0.05742403864860535, 0.0442077439012272, 0.022139478075717176, 0.031277746826942475, 0.07283135689795017, 0.013690915574053568, 0.013664347535398389, 0.040154704957136085, 0.07774710562080145, 0.02136574629028993, 0.04054036390568529, 0.05590380129537412, 0.06184633634984493, 0.012226306217988687, 0.01082140879173364, 0.05003860566232886, 0.0779640061248626, 0.030933810996689966, 0.029469769913703203, 0.02988458551200373, 0.06356582551130227, 0.004716084704601339, 0.08267751748540572, 0.018303724704310298, 0.0639870125534279, 0.031984091603330204, 0.013879530497693589, 0.02403987824384655, 0.04172222941581692, 0.016406450886279345, 0.036002124925809245, 0.006260206490488989, 0.0268749994159277, 0.02679190771388156, 0.0097980007163382, 0.01155917822117252, 0.04614676967529314, 0.1480033610548292, 0.09943139526460852, 0.08819731165255819, 0.10945355426520109, 0.12142656929790974, 0.1816484656717096, 0.20510609980140412, 0.11057153570332698, 0.09399639083338635, 0.11840007241283144, 0.1400335737104927, 0.13036246837249824, 0.0938036326052887, 0.10229564764137779, 0.11592435597309045, 0.0893347127629178, 0.14104486230228627, 0.14333224456225122, 0.15927579546613352, 0.09728183703763144, 0.08058721572160721, 0.14545741624065808, 0.1250506519739117, 0.12071222120097705, 0.06673761709992375, 0.10472548154315778, 0.20889646426907607, 0.1377488105956997, 0.15400766315204756, 0.10950845453355994, 0.10930294663246189, 0.10451673024467059, 0.16162811352738313, 0.16579248649733408, 0.14679182320833206, 0.07908732763358525, 0.052111306227743626, 0.08257929954145636, 0.11967894807457924, 0.10906607684280191, 0.12544170527585916, 0.151856232168419, 0.07321807436112847, 0.11470257224781172, 0.08975387777068786, 0.08731775384928499, 0.197869388120515, 0.16267673511590275, 0.1310496207858835, 0.08177023474127054, 0.0980738570381488, 0.10720783405538116, 0.1449646505394152, 0.09122250575040068, 0.14806459205491201, 0.11313255078026227, 0.1545924110604184, 0.10894019502614226, 0.1745197224829878, 0.16524914279580116, 0.11580234180603709, 0.11795214430562087, 0.09187611817781415, 0.2424017499600138, 0.18123506142624787, 0.12664638991866792, 0.1736623663455248, 0.14759301021695137, 0.06285386585763522, 0.06568565033376217, 0.07914472491081272, 0.06616670452058315, 0.12836195714771748, 0.16183984359460218, 0.11289457497852189, 0.21571648759501322, 0.14650936265076908, 0.16517432752464498, 0.21427514350840024, 0.21932420400636538, 0.247057992964983, 0.11523632146418095, 0.12974388870809758, 0.11483525298535824, 0.11850669740566186, 0.12066971776740891, 0.17571417481771537, 0.11147328160170998, 0.12233207428029605, 0.17847691157034465, 0.0789511049432414, 0.16814275538282736, 0.11949862060802323, 0.16339865566364356, 0.19413956254720688, 0.21416678146592208, 0.06913641480995075, 0.1072297507364835, 0.09244180603751115, 0.1257497194622244, 0.1937172966344016, 0.062242906141494, 0.12500342593661376, 0.2168308456561395, 0.2691717477781432, 0.12178398083363261, 0.09519802206861121, 0.12951466600809777, 0.2155655406947647, 0.13320793211460114, 0.17071595016334737, 0.17681090453905718, 0.10412167358611311, 0.10950136384261505, 0.11650303777839456, 0.07156864394034658, 0.2538080321890967, 0.24002429896167346, 0.14582024248582975, 0.05212979630700179, 0.0978030130001051, 0.06276217542056527, 0.15125963703862258, 0.20268735316182884, 0.07440839441759245, 0.13286988596831048, 0.17169844172894955, 0.21656153510723794, 0.12685417091207846, 0.16079040776406014, 0.10877868333565337, 0.16665634300027574, 0.10676012986472674, 0.11154490097292832, 0.12649135823760713, 0.12317554759127752, 0.13066745629268034, 0.053374215960502625, 0.08980708170150008, 0.17493322172335216, 0.16931957937777042, 0.11830161698162556, 0.08995306851076228, 0.16882209107279778, 0.13931562937796116, 0.28327740515981403, 0.18491455327187264, 0.18394427533660615, 0.1170978687171425, 0.15368383909974778, 0.1338292530604771, 0.18831908915724072, 0.12820537840681417, 0.11199987227363245, 0.10407377579914671, 0.1470018976501056, 0.12201545626989432, 0.10371546859719924, 0.12327588934983526, 0.0647282102810485, 0.08967591409704515, 0.199952612764069, 0.08452732608254467, 0.1499128264508077, 0.1061949169795428, 0.08069703661437545, 0.12290867976844311, 0.08088281950248138, 0.05280029747102942, 0.15788406586008413, 0.058083215063171725, 0.1356693993189505, 0.13531578757933208, 0.0721174498487796, 0.12441285619778292, 0.15289652134690965], [0.06396308062332016, 0.032528782196875126, 0.017664049386179874, 0.06448395124503545, 0.016758444319878305, 0.077034039955054, 0.06674416496285371, 0.05523102025368384, 0.04424138566745179, 0.04632491225908909, 0.049984943720379045, 0.027198222964735966, 0.010712815199180372, 0.01608389739080199, 0.02414668135211936, 0.03424018322091017, 0.0520075989354934, 0.031277804502419064, 0.017561212315091064, 0.014955905864813497, 0.011835313984192908, 0.016210888612217138, 0.041744906056140146, 0.021769517034824406, 0.021441172242962887, 0.02518954557100577, 0.02258249867840537, 0.04063071423609342, 0.005813853432690459, 0.014055599308838802, 0.023200040184227482, 0.06298518273979425, 0.04774489945599011, 0.0355904339812696, 0.027919442925070013, 0.04781168426520058, 0.02842292099791978, 0.026306950254365802, 0.017301380900400024, 0.04210589686408639, 0.023633457820064256, 0.04649508544909103, 0.017381056178627268, 0.0735968868913395, 0.08005224514220442, 0.0242542461159506, 0.07527857486690794, 0.035608703536646705, 0.031703418985541375, 0.015612824454105325, 0.015233706583135893, 0.05367289011233619, 0.012308629479126205, 0.022693842882290483, 0.02328195802069136, 0.06140485432531152, 0.03430578059383801, 0.05375473161361047, 0.038924398832023144, 0.03298864234238863, 0.03963497766692724, 0.036316266283392906, 0.0338848310389689, 0.061039802485278676, 0.15336395055055618, 0.02334313982698534, 0.03260936501568981, 0.005802841657506568, 0.007397950261033007, 0.025497454584443142, 0.03225463030061551, 0.059666400110082965, 0.014648017207426684, 0.05214513459109834, 0.03834229042487485, 0.033081343796636374, 0.02674014906265906, 0.043703008842255385, 0.0450172701052257, 0.02297132129647902, 0.04562925101656999, 0.005087220459245145, 0.004837735007250947, 0.016442611713760664, 0.018351975329486386, 0.029847337332155024, 0.03199607113908444, 0.06067906612796443, 0.040540832094848156, 0.0994249288258808, 0.04549647528412087, 0.016929718432947993, 0.028590151042278324, 0.08460932025419814, 0.03408930078148842, 0.03077107115781733, 0.05249282272000398, 0.035605857082243474, 0.03842753138659256, 0.05109190235712698, 0.02387812058441341, 0.003446140684120889, 0.04059827008417674, 0.06059093799974237, 0.05756967940500804, 0.0339766537903675, 0.036842772138438055, 0.02849351069224732, 0.006887462921440601, 0.02236859390645155, 0.005113901728431561, 0.0725208864148174, 0.07158711366355419, 0.016154023984979306, 0.01954707905783185, 0.03386263276583382, 0.02321907309150057, 0.058925392372267585, 0.08996032205011163, 0.02752738878397005, 0.019289493594052534, 0.050246807347450934, 0.026125252147072127, 0.06466400729758398, 0.024155614265639867, 0.05518046939479453, 0.049605198204517365, 0.07067313377878495, 0.010218311600121004, 0.031613435064043315, 0.0654447568314416, 0.0625977935269475, 0.03481226966583303, 0.010878543136641383, 0.0569582786411047, 0.056252524190183194, 0.03511857733662639, 0.054759496091199775, 0.04996135105778064, 0.025441604367058192, 0.02905611800295966, 0.050090886785515716, 0.005732139156732176, 0.01641783331121717, 0.06456325841801507, 0.052725641655602624, 0.025878250133246183, 0.02109553837882621, 0.023312268179974387, 0.040318513488663096, 0.025976322192166532, 0.02389341646007129, 0.07474851688104016, 0.07125018710004431, 0.03812751034274697, 0.06871994358620473, 0.014269026561773248, 0.02879612034718905, 0.050224548006164174, 0.04278215879042234, 0.022971034615433643, 0.06025156192481518, 0.04245553917384573, 0.1098102872659053, 0.03148237941786647, 0.03307890107056924, 0.00883202808576503, 0.02439566468819976, 0.06219473694052015, 0.010077579196409454, 0.015424515719392469, 0.044398653121399026, 0.008617734852513033, 0.03714751239333834, 0.037645509599574974, 0.032762605364301374, 0.046032758828784735, 0.08838449232280254, 0.03251144223447357, 0.025143873378900543, 0.02467645944229194, 0.053562285511621406, 0.044143965002149343, 0.043081304524093866, 0.054948342564914904, 0.048336052734936984, 0.06285461903150592, 0.06266563345811196, 0.03183800640649029, 0.027377866807260683, 0.01525228317560894, 0.03914349439686962, 0.04962195123412779, 0.02079107123427093, 0.042863504961133, 0.027096110229779567, 0.042690668521182876, 0.08985016867518425, 0.035114791111222336, 0.06809185086084263, 0.08343711708273206, 0.0170427979901433, 0.060679283259170394, 0.012042256138686622, 0.017064251571095417, 0.02481579830470894, 0.0029086107554446372, 0.05832698555397136, 0.04973943278725658, 0.026454043075708405, 0.006348774394220007, 0.035003477441413064, 0.03438477564070906, 0.013178040639364293, 0.04487788544169494, 0.020327971084043384, 0.0131235169579408, 0.042992216268820424, 0.012079047155566514, 0.010337574307673743, 0.03127003527645554, 0.07912019586988858, 0.031120737216302326, 0.017743790821571435, 0.023748961443613683, 0.005575311054209513, 0.03340086593691792, 0.04871334534670625, 0.019394369662872384, 0.013218198886274226, 0.023901801456564238, 0.07607681703354631, 0.040595321849520714, 0.016789989412895272, 0.028123276541009545, 0.0337299554209624, 0.031130938990307704, 0.024460067839494774, 0.03067431545683316, 0.032334202102252414, 0.04579707647540739, 0.023379931692034006, 0.031200695782899857, 0.01711198142064469, 0.05160843714007309, 0.05156482769442456, 0.05712112704558032, 0.01713491590427501, 0.025071706090654646, 0.06435659022203513, 0.04231667019692915, 0.039779766861881526, 0.10190110666943447, 0.028187004549961005, 0.014781181401173984, 0.035804555884429386, 0.042367156594991684, 0.04253953502380422, 0.03958230299342956, 0.04481136865381684, 0.04732426541990467, 0.06870372659925904, 0.0669868972950748, 0.03181632721264448, 0.0505348420701921, 0.11709940220628466, 0.06128589356584208, 0.040407333722604175, 0.027916029893926213, 0.04414116604519742, 0.018998999181868773, 0.02755866924832974, 0.024761641032195518, 0.11961733709488596, 0.030527083535811732, 0.03410948719829321, 0.011014940549752541, 0.033581064481820376, 0.02602781112571912, 0.04339865535231573, 0.0514808148810906, 0.03877254269484963, 0.04571422395695533, 0.028570331034383604, 0.023390140251389573, 0.0745236910879612, 0.030336109854813133, 0.0843490342210446, 0.037558803002216985, 0.08209686792854752, 0.036343631600694995, 0.014021135667072875, 0.052724033527608426, 0.04947509590004172, 0.027310267756027833, 0.05036885883393032, 0.013509702619298227, 0.09353079367429018, 0.023191836695852022, 0.044608978621129475, 0.03691141613359962, 0.04932859340416534, 0.04969023899840457, 0.08133794686623982, 0.010419332688408238, 0.014662982297262974, 0.024970914802647064, 0.08766425454190799, 0.04531672457233071, 0.025208347776372517, 0.02166253241843411, 0.06057999322989157, 0.04830976968098964, 0.05422961113176175, 0.033112420700490475, 0.02446831203997135, 0.01122411253995129, 0.039032662486923594, 0.017150601937568614, 0.036774670971291404, 0.01307360052929393, 0.08160214126110077, 0.027370450419506857, 0.06072013785264321, 0.027072697378961102, 0.020749770504023348, 0.017612721604694213, 0.02914143699620451, 0.06122921553573438, 0.03851662303454109, 0.013362572478529598, 0.027323838456400802, 0.018476111614810567, 0.00919210965678628, 0.03295052903039115, 0.046794455099318705, 0.08770850181047406, 0.030220233037003448, 0.02351592537680907, 0.0375499074081225, 0.03846999071538448, 0.028011906892061234, 0.046408355103007386, 0.03971720254048705, 0.036622767336666584, 0.03897706332749554, 0.019905364207391227, 0.03318026063165494, 0.04557115484827331, 0.02075872546993196, 0.053341744667185206, 0.038007243403366635, 0.16164547045316013, 0.16503635421395302, 0.10563401279172727, 0.1735261165137802, 0.1405926729951586, 0.12786009907722473, 0.12141374498605728, 0.15732876637152263, 0.15151070856622287, 0.08417969223644052, 0.14323507834758076, 0.177945985059653, 0.11190997316901173, 0.09598673081823758, 0.07488607628537075, 0.10469975828060082, 0.11400302978498594, 0.08124956768006086, 0.14174044212060316, 0.11695587847914014, 0.0945140587698136, 0.22357773647776671, 0.07396379791732345, 0.1563381730977978, 0.16540114821067878, 0.1091970137453505, 0.21356808287756784, 0.10540382657200098, 0.08729657677135297, 0.09972138077552829, 0.09225223013865096, 0.15605907807392733, 0.11770907949124064, 0.09514704373266016, 0.11850046845419065, 0.1040394419272031, 0.04285089438781142, 0.07507393549063376, 0.1429542327033622, 0.1837368607521057, 0.13374962019068853, 0.15674510411918163, 0.08183949959597417, 0.2259829802704709, 0.1794369707682303, 0.13664819965405123, 0.24489547471914971, 0.08672831726393529, 0.1342633254826069, 0.07898530989353146, 0.0992864737553256, 0.21095428456153187, 0.11383285998765912, 0.1348444228725774, 0.0560949853222285, 0.17168010771274567, 0.15357653557189874, 0.13146998680063657, 0.1528496210064207, 0.15018706316394465, 0.1030883936743651, 0.15956679199423107, 0.17190717267138617, 0.10382830218545028, 0.19832043748881134, 0.13286714468683514, 0.11326984555593558, 0.14994616966162408, 0.11992437419082437, 0.22118530342621462, 0.11978325247764587, 0.1398567474846329, 0.0818403884768486, 0.1726977473923138, 0.1567153978560652, 0.1328066736459732, 0.19235823170414992, 0.1379711665213108, 0.1421077059847968, 0.09618171464119639, 0.159338722803763, 0.13811455454145158, 0.1161778566560575, 0.13159865061087267, 0.12952854883457932, 0.18799158744513988, 0.12830680582140172, 0.08670966433627264, 0.11286122498235532, 0.1816298466707979, 0.18720345545027936, 0.13521349163992064, 0.07702736317047051, 0.19503119827381202, 0.09508218935557775, 0.09146816935390234, 0.13848542821194443, 0.2009293639234134, 0.14184462438736642, 0.10426702935780797, 0.06335141523075954, 0.06541927105614118, 0.15676669510347502, 0.09432595529194389, 0.10206492537898676, 0.09695324288415057, 0.13623233911182198, 0.18351305276155472, 0.054312928446701596, 0.1087128518681441, 0.08389771343874079, 0.19474060886672565, 0.15484752665672982, 0.19871624053588935, 0.1059611684509686, 0.16264807379671506, 0.13623658674103872, 0.1288303498710905, 0.20482019228594645, 0.13433873786457948, 0.1704907172492572, 0.16797812921660288, 0.07307396709386792, 0.23769543107066834, 0.12589868504021848, 0.18950890031244072, 0.07901070745927946, 0.1828662460403783, 0.08835651632398367, 0.09963367333901779, 0.1307900132877486, 0.1549495104700327, 0.07704541220196656, 0.0776143434590527, 0.17079125397971698, 0.08970076204942805, 0.27186702457921846, 0.20814775515879902, 0.26128556951880455, 0.13013373421771185, 0.1004391283329044, 0.1198911259749106, 0.08776812468256269, 0.16929948117051805, 0.21178416003073963, 0.10165027941444091, 0.09115820777203355, 0.10994066098438841, 0.09870783944747277, 0.1624670677951404, 0.10496051250291721, 0.15083453484943934, 0.13262216640370234, 0.1529316423194749, 0.07547238482428448, 0.1515468880534172, 0.06966747702764613, 0.08616896692131247, 0.13311098303113664, 0.12236125128609793, 0.19090067063059124, 0.10475263651460409, 0.09125679212489299, 0.15494275226124696, 0.15473260996597155, 0.10705599148890801, 0.12845906907958643, 0.1355119656239237, 0.1258387296859707, 0.08770700224808284, 0.0903059881446617, 0.09006746272955622, 0.09056411643645593, 0.1685514777366604, 0.16118920993592056, 0.13453715507473263], [0.06106156988867691, 0.06820078965808664, 0.05248354375362396, 0.06458157207816839, 0.03885368869772979, 0.041386452969163656, 0.008052750972897878, 0.004382377365670566, 0.04135067381763032, 0.06588372827640601, 0.032855656264083724, 0.030136189689593654, 0.017738678060205917, 0.12564958126417228, 0.047444305050053766, 0.05643102300486394, 0.07412099412509374, 0.00212226012705027, 0.034906684421002865, 0.04265533720276185, 0.016430070690278496, 0.02864951267838478, 0.04561911370339138, 0.018450761546513865, 0.0387231555235173, 0.009482773702724703, 0.04687012193192329, 0.05525364939655576, 0.05059834276991231, 0.05369691025199635, 0.016432060494220684, 0.024873353341328244, 0.01849170434953911, 0.015170531580224633, 0.03323351205991847, 0.03972130428467478, 0.04093186164806996, 0.01390057526129697, 0.009283055401673275, 0.029931265328611647, 0.0508285764870899, 0.0342846510133573, 0.0510868235225124, 0.03988661916394319, 0.043121239702616415, 0.04329139592924288, 0.05515623890927859, 0.021396909707358906, 0.021236351358571222, 0.0647191721946001, 0.03272282285615802, 0.0641953499455537, 0.07655318254338843, 0.030936270686132566, 0.07286983661885772, 0.037958463520876, 0.1016481691705329, 0.02339187221202467, 0.07751027654324259, 0.019534037614773427, 0.01541297383872526, 0.01055438066500106, 0.02700539688313646, 0.020665659303111688, 0.019712857037250484, 0.02926212123462132, 0.035763640222804885, 0.016602508490905166, 0.04614038805344275, 0.057490426514829905, 0.03670523987550821, 0.004201725474558771, 0.04995391431397625, 0.02816839063806193, 0.0536532092041203, 0.09845491551927157, 0.0659109918134553, 0.016921784662242447, 0.02559935188453112, 0.06962177769414016, 0.048771400802901814, 0.02512531035712787, 0.05929776560515165, 0.02582003522132124, 0.06949399597942829, 0.008990430389530957, 0.052623559454722066, 0.047166797798126936, 0.06189474982342549, 0.03193274007311889, 0.03645398514345288, 0.08845985042197363, 0.035308841948530505, 0.07570136325167758, 0.04417653807571956, 0.028780279947178702, 0.03741121145763567, 0.0295672652178577, 0.026459892047569156, 0.020537538320890496, 0.03963752556592226, 0.03311563017112868, 0.02381163093793605, 0.025686012680775354, 0.0568857839597123, 0.07358497860176222, 0.01869153291253107, 0.031838976711566956, 0.03164346023861851, 0.08214226192129509, 0.034012687392532825, 0.02827022347732314, 0.05165871658495494, 0.06193529229078974, 0.005621459917165339, 0.02702732034958899, 0.10282713733613491, 0.058181222661265304, 0.03136016508298261, 0.06581637010510479, 0.0338687192249511, 0.028698217922023365, 0.006393684506682413, 0.04470512703327196, 0.044204296943332465, 0.06417826443378415, 0.07400371613247053, 0.08523298214588847, 0.03661908967686551, 0.02645479455324156, 0.026825737773573825, 0.016967068393049494, 0.026525194257763878, 0.02485861216804811, 0.048577533170048676, 0.026801385151754533, 0.05792779661715031, 0.017998636700212955, 0.021069153544626067, 0.027688988684011356, 0.044764162972569466, 0.05345161984275494, 0.048300249834678004, 0.014409909091357673, 0.026775912947154472, 0.007454269515749599, 0.024022606134946858, 0.06316740331905228, 0.014907136160348142, 0.044522441657526154, 0.10142560968441622, 0.028397386028830494, 0.013440304602097188, 0.04384498890223248, 0.04689186219392078, 0.03137551693777953, 0.0030297294683155735, 0.028580726190869297, 0.042450124464396916, 0.044915469496377876, 0.028612827682601552, 0.04186669969931245, 0.01616271771490574, 0.01668122024940593, 0.009809945477172732, 0.059420919711036344, 0.02497380705816405, 0.017058153237615312, 0.036507776007056236, 0.034957384557596276, 0.018283758811386566, 0.0077024479396641254, 0.07392110449395009, 0.057786715616072924, 0.013569958225291754, 0.06333641960684742, 0.09968687048447983, 0.0399560434743762, 0.035780328791588545, 0.014327590919232793, 0.008497873337806335, 0.029827764989542108, 0.03011599648743868, 0.051014532401625595, 0.03613819155309882, 0.05405426411224263, 0.003388125940026449, 0.06918596143701247, 0.004233847746425974, 0.02549199407388057, 0.0163245415315032, 0.023070480707766752, 0.05277263359831912, 0.042931942003113885, 0.0426266962396247, 0.009523630840703845, 0.0301867710825588, 0.043119485689593215, 0.024235186067276766, 0.028264874925038645, 0.000688190730995432, 0.03967680935082691, 0.01240131481816726, 0.053340017795562744, 0.024013113430035964, 0.019178224029019475, 0.024129891003082906, 0.05722583178430796, 0.024925013604973043, 0.08977221857224192, 0.05891644249537161, 0.04916243374879871, 0.010371419634403927, 0.01840777974575758, 0.02735341919053878, 0.038067029123859744, 0.02343800580794258, 0.058809274674526284, 0.022810306632891297, 0.0112083688311811, 0.014936236830960428, 0.05697217503828662, 0.03657563629427126, 0.04028538740905268, 0.024672722410676733, 0.053614084874945026, 0.02214014304003545, 0.016322103894448707, 0.010750945474553322, 0.04603222278612001, 0.013848458682852132, 0.03956497320905328, 0.021498681478468434, 0.0021619991665439947, 0.027780192272205437, 0.06449925899505615, 0.04271936037444642, 0.06496196559497289, 0.042834215997053046, 0.05273599270731211, 0.0819343180794801, 0.009806331430029656, 0.04207497263061149, 0.027835211284192543, 0.02178371198741453, 0.0314265393785068, 0.026575716278914894, 0.044035450289292, 0.05734384259475129, 0.035030082799494267, 0.028837415988423994, 0.03619807566116963, 0.048667072651109526, 0.020342569764969603, 0.03507059473278267, 0.0455808477210147, 0.017007315697680627, 0.040547247643449476, 0.05753700794386012, 0.05007006933114358, 0.0781881669536233, 0.06701528720025506, 0.011775868379377892, 0.07440509673740182, 0.035372447821178606, 0.03341534248154078, 0.008309495901422841, 0.06852141781044857, 0.06932613998651505, 0.013985101216738778, 0.04676466741200004, 0.04960711845862014, 0.03034969073321138, 0.0607211013723697, 0.02581067822341408, 0.022608953062444925, 0.02486586570739746, 0.030785045586526394, 0.053554801270365715, 0.043213021741913896, 0.018952819784837108, 0.008772707161759692, 0.004085909724900765, 0.08435440143304211, 0.055657455764178715, 0.05091593787074089, 0.05184042826294899, 0.07114379280912024, 0.0076071765340332475, 0.054866165188806396, 0.025392819395554916, 0.046803065708705356, 0.0766380401328206, 0.035088399491672, 0.009831393969112208, 0.03070216592667358, 0.004647558180814875, 0.023832545083548342, 0.03630540972309453, 0.06989082361438445, 0.024454704020172358, 0.05581781733781099, 0.04437426996550389, 0.05168778502515384, 0.008580976066046526, 0.04058369854465127, 0.054775282208408625, 0.0492788601799735, 0.004899340897931584, 0.05438879544713667, 0.058192337064870765, 0.06512228984917913, 0.04764131769271834, 0.058399751649371216, 0.02178027860022017, 0.024616253030087267, 0.019065753457003405, 0.019505985280764953, 0.011946295171843042, 0.028186166559212973, 0.04730302727382098, 0.03187497638698135, 0.04214079731277057, 0.04646605093564306, 0.06033556456012385, 0.020582840711410557, 0.03636375355667301, 0.03449647268280387, 0.07397634402981826, 0.017721421218344142, 0.0037588435474650134, 0.0762515737275992, 0.010542575003845351, 0.032870964014104435, 0.02464245805250747, 0.028559786600193808, 0.060811997923467837, 0.017534423752554824, 0.05649571792621698, 0.04207766302196043, 0.054219687557114024, 0.05016856886712568, 0.019528385418068086, 0.02401797682978213, 0.0801082785640444, 0.09078431462070771, 0.04691609607211181, 0.039873452191906314, 0.016057061330814446, 0.021576516230457594, 0.005635347408575139, 0.016571652110932127, 0.16211678087711334, 0.10871083661913872, 0.09590901141720158, 0.12569382174738816, 0.09709527383425406, 0.13720549403556756, 0.17156418679015978, 0.1652914969516652, 0.1355431375226804, 0.15835620409676007, 0.09511868096888065, 0.1509469681020294, 0.1259079266871725, 0.27780325604336603, 0.12541400747639792, 0.1489343653832163, 0.1239068183515753, 0.1603717787989548, 0.12212708885116236, 0.1463595014065504, 0.12052086075501782, 0.10119409353605338, 0.12896090000867844, 0.0646382433229259, 0.1764547007956675, 0.13762951056872094, 0.14596320981425898, 0.15229898983878748, 0.1157215554267168, 0.12148493688021388, 0.10317374659436089, 0.23301953769155911, 0.1353660263121128, 0.20714781167251722, 0.13589748208011898, 0.19384393841028214, 0.11779551128191607, 0.05587477356727634, 0.08023027916039739, 0.09613163875682013, 0.17736327275633812, 0.12323099747300148, 0.10534233772861105, 0.11019241104700736, 0.13409128971397877, 0.15304252851222241, 0.1344055464225156, 0.16495752201548644, 0.12816542626491614, 0.13235134950705937, 0.0538731461523899, 0.10103747408304896, 0.1385679787823132, 0.1445967759937048, 0.12122518010437489, 0.13164631091058254, 0.1798568753791707, 0.072694686374494, 0.1775266504181283, 0.1330765134521893, 0.14162013786179678, 0.09861612186900207, 0.15318134320633753, 0.07891754460121904, 0.15159780532121658, 0.07426141016185284, 0.14797464545283998, 0.07451067678630352, 0.11520966860864844, 0.12587611696549825, 0.12788003443607263, 0.09316965698131494, 0.09716456583035843, 0.14955897043858254, 0.11549549469990389, 0.14679294957646302, 0.1809764988720417, 0.14975438852395329, 0.12957612771008695, 0.21154359222522803, 0.10829943405198199, 0.09325859256620918, 0.22426007129251957, 0.10394209250807762, 0.19118903444281646, 0.20268234557339124, 0.11117678893996136, 0.22294808312186173, 0.16379848920873233, 0.11714395481560912, 0.11179622355848551, 0.23018317988940648, 0.14163359999656677, 0.15439123899808951, 0.15243218626294816, 0.09338691032358579, 0.1074909120798111, 0.13335472638053553, 0.11195199484271662, 0.17881248784916742, 0.14590447582304478, 0.14819541360650743, 0.15295691096356936, 0.14993861078151635, 0.18645252074514115, 0.18037086565579685, 0.06073451600968838, 0.1223225612193346, 0.09461322666278907, 0.13786406655396732, 0.13153063426060335, 0.19316984101065568, 0.12927446461149625, 0.08514984803540365, 0.13940811370100292, 0.09225016060684409, 0.2102207610649722, 0.1857683403151376, 0.13991350015359266, 0.13781470991671085, 0.1267822054880006, 0.09790703920381409, 0.10737424476870469, 0.20175770590347902, 0.12486898100801877, 0.15771797405821936, 0.12144768530769007, 0.15789995715022087, 0.08298262075654098, 0.11106109193393163, 0.14225587089146885, 0.16359807710562432, 0.07098296643900019, 0.11806465898241315, 0.14035057170050486, 0.239937283630882, 0.20431773710463727, 0.20341676473617554, 0.1353627150612218, 0.10992037278733083, 0.1425503415188619, 0.1301447129143136, 0.09334379620850086, 0.13340677001646586, 0.10510687929178987, 0.06766433308699302, 0.1252226877425398, 0.15169862205428736, 0.11966163186090333, 0.09408365722213473, 0.14632243982383183, 0.11428467610052653, 0.10618446754025561, 0.06799575673150164, 0.0896629880049399, 0.15789550596049853, 0.11748339874403817, 0.1696644380156483, 0.08024892530270986, 0.08735171452696834, 0.2198422383517027, 0.12615950033068657, 0.13853899176631654, 0.12314141727983952, 0.17099991706865175, 0.29417750026498524, 0.11860804339604718, 0.08608392612742526, 0.26168639372502056, 0.15905957349709102, 0.19394349306821823, 0.1432281844317913, 0.15455899999610015, 0.11790623462625913, 0.14879446503307137, 0.123403630352446], [0.019196965166234543, 0.04476945215303983, 0.0047494414861180955, 0.03610090944649918, 0.024720409851787344, 0.018635938842115656, 0.03612837654405406, 0.031670214874403815, 0.02921617084315845, 0.007511442028252142, 0.03382414286690099, 0.03995920205488801, 0.04981123197025486, 0.022798635830570544, 0.07246378769299813, 0.07165851590356656, 0.05233922274783254, 0.01947084055947406, 0.0504709342494607, 0.008008804804246341, 0.032357927079179456, 0.04621036536991596, 0.018321809358894825, 0.027272821104686176, 0.05358208177079048, 0.016461658191734126, 0.027421019938109175, 0.01754926670608776, 0.0465882754485522, 0.030491487588733435, 0.02472809934988618, 0.044391056921865256, 0.024779645958915353, 0.05025302612089685, 0.0655808098880308, 0.048991700767406395, 0.044094991737178395, 0.07421540548758847, 0.015472177715439881, 0.028450620493718555, 0.05574901049424495, 0.037528424989432096, 0.016975402499416044, 0.014265464252925344, 0.016784350786890303, 0.030718427018395493, 0.019375706557184458, 0.09647082484194211, 0.02682707109488547, 0.014853136647226555, 0.013852061703801155, 0.02324500330723822, 0.033088719472289085, 0.055126739599342854, 0.07513953625623669, 0.03421731998345681, 0.04685135026063238, 0.014887007419019938, 0.010483879180225943, 0.0038149376133722918, 0.03922943424965654, 0.016445544681378772, 0.04975666418405516, 0.10794268069522721, 0.04287120972626975, 0.050435253485505066, 0.017143587581813335, 0.045163474045693874, 0.02303072534102414, 0.06992079450615815, 0.07462845010949032, 0.04661360516079834, 0.04923301835411361, 0.005774275333221469, 0.030133112533284084, 0.0366802901428725, 0.044069641668881686, 0.03527822644848909, 0.024123682407662272, 0.07756366367850985, 0.02714021670232926, 0.02855681800948722, 0.07942374529583113, 0.0244064873217472, 0.013081603001670113, 0.02108561310784093, 0.03662796491490943, 0.038592188086892874, 0.03331649350002408, 0.01513667098645653, 0.020257554416145598, 0.042550696924860985, 0.03304752900398203, 0.05203059448727539, 0.009009881444009287, 0.08240658523780958, 0.061960737353989055, 0.022907708638480732, 0.04643921487565551, 0.023739400885200927, 0.04421134352950113, 0.04956738344792809, 0.010726177250035107, 0.05378063468794737, 0.05381940617891295, 0.0460369453898498, 0.038091086582945924, 0.050835243093648126, 0.056476308432008536, 0.012753178481943905, 0.016073042526841164, 0.026380847806909254, 0.08795915264636278, 0.057850022933312824, 0.048984515081558905, 0.01501805119083396, 0.024362307906683003, 0.008604835901808525, 0.045525798174951754, 0.01149062837274479, 0.009182499056415898, 0.03208641129146729, 0.018028305643903356, 0.02481976603823049, 0.024899139368374432, 0.013953985297121108, 0.040856703716729365, 0.08534006175718137, 0.03797657022784863, 0.010154036522310759, 0.01527574352387871, 0.01604775691937123, 0.020322483432080065, 0.005313107735543911, 0.006957509787753224, 0.02642289492567735, 0.049458454828709364, 0.05532570303018604, 0.029764301609247923, 0.013542600541508623, 0.03658354122723852, 0.018144713415365134, 0.07734327550445284, 0.03962539675246392, 0.011282514897175133, 0.06109441776892968, 0.06828880922070571, 0.01156647501712931, 0.012010704260319471, 0.033239595126360655, 0.0688248790268387, 0.030245983440961157, 0.04735648565526519, 0.016146429481783083, 0.025073205653045858, 0.054684365301259925, 0.11736047534005982, 0.09620663723243134, 0.029138278415692703, 0.0026425387269617723, 0.044505135621875525, 0.008851232323130327, 0.00957601289597473, 0.06436562152313334, 0.053341999117817195, 0.04734294209629297, 0.03262425546667405, 0.0257378239184618, 0.04621546456058111, 0.053832569758274725, 0.008926887281372078, 0.021652283146977425, 0.017962029735956873, 0.03145853569731116, 0.020917499271620597, 0.008255705037819487, 0.02712189286415066, 0.09233300973262105, 0.02867002139932343, 0.003668819337950221, 0.030963320484650985, 0.027355142669486146, 0.007547905651985535, 0.035471988908414326, 0.01775563634665949, 0.04421004413494042, 0.05278117296152881, 0.038557525125465224, 0.02682624667483781, 0.01440134089040969, 0.041803589157227955, 0.02204619308135339, 0.05965374543198517, 0.033233797044626305, 0.034562748590750356, 0.02763746921638293, 0.019626806922523037, 0.013295613794720598, 0.00833167297033859, 0.03876915341243148, 0.0880004618582981, 0.027304683412824358, 0.03224800101348332, 0.054225489031523466, 0.09495769175035612, 0.059385154130203385, 0.04513415115486298, 0.019187801550807695, 0.015216215646692684, 0.01561810345655041, 0.02037196220563991, 0.021080021979287267, 0.062406446651688645, 0.02914241069395627, 0.022128273766221743, 0.06481281002717358, 0.017838509221162115, 0.04030079354665109, 0.01794617237257106, 0.015791308001748154, 0.007487336223545883, 0.042676449819867096, 0.008132768063140767, 0.06144965799259288, 0.042431454573358805, 0.04937795343409691, 0.04053427066121783, 0.05129007529467344, 0.022962502037574137, 0.053331899124064615, 0.0727317411718624, 0.04444772477394768, 0.05184413306415081, 0.025943986605852842, 0.02563452035454767, 0.022674199293500612, 0.050694955978542566, 0.030877238139510155, 0.019149739128936614, 0.04301901840205703, 0.06953444345188992, 0.009176685707643628, 0.02364035852120391, 0.04162782483867236, 0.035797556795712025, 0.02312833769246936, 0.045341009340648136, 0.029907268937677145, 0.028079410948391472, 0.009018530220990735, 0.06908722102109875, 0.04613403357299311, 0.05914257786103657, 0.05427534439201866, 0.03752034703003509, 0.019947107681738477, 0.005928746374723102, 0.06202323721455676, 0.05524049260254417, 0.06062695463853223, 0.01975707377174071, 0.04932702598827226, 0.03827564132266811, 0.033485821913927794, 0.07609817731593337, 0.02911968994885683, 0.03391051019674965, 0.05800796552960362, 0.028489680362067053, 0.04211023609553065, 0.040531980605529885, 0.09300126494573695, 0.02145898887621505, 0.08634314686059952, 0.02783446998468467, 0.02240927716983216, 0.08992736560425588, 0.034700263890304735, 0.028486270723598342, 0.0283594796700137, 0.059665165176349025, 0.0020587218958618386, 0.018694733901481544, 0.012608625077908593, 0.03161412038441215, 0.0428324280572789, 0.02640621144590633, 0.02500586783779519, 0.0571267588862351, 0.020659991839368428, 0.030175293662718365, 0.0647332314401865, 0.01828128724758114, 0.021886515131752406, 0.036009235972804685, 0.025749448919668794, 0.0628945440320032, 0.0846844951489142, 0.00933701844353761, 0.0477198547284518, 0.03315283424620118, 0.049834831418203454, 0.07718886807560921, 0.05406385859740632, 0.025437726539426615, 0.01576110301539302, 0.03485462721437216, 0.010557592680145587, 0.0601786058396101, 0.029595753510615656, 0.0337013890966773, 0.0144282702489623, 0.07886227792395012, 0.023152759864128063, 0.017290585408253328, 0.02014431031420827, 0.04416565776669553, 0.010164439312315412, 0.034995993200157366, 0.03907880286819168, 0.053813058483813486, 0.1064638543341841, 0.058027649830494604, 0.05557626565652234, 0.049964367145938535, 0.027336421888321638, 0.012692374110754048, 0.034257285696055205, 0.021350426665906395, 0.0557318164168724, 0.05026674609897392, 0.050550475517021756, 0.08911724907479115, 0.033637691621801684, 0.013833997405267187, 0.010037962929345667, 0.026253915957308242, 0.03868564950036151, 0.04505462685067739, 0.023878327537594096, 0.02347622938188059, 0.04222121389050569, 0.06527551662709032, 0.13451265996055944, 0.06515976533825908, 0.016394405193360786, 0.021553978689813187, 0.04404772838045444, 0.023931565395157253, 0.038857949897646904, 0.02681083544822676, 0.033998696000448296, 0.12741116673818656, 0.1979247158659356, 0.09973423901413168, 0.06816195709896938, 0.13739481887647084, 0.11096502494599138, 0.08310453314334154, 0.12384813864316259, 0.08274122513830662, 0.15526676630335196, 0.1475118709994214, 0.16166047964777264, 0.10879585027162518, 0.06999127393854515, 0.20763487767960342, 0.11627602710255555, 0.11591902268784386, 0.21884145348199777, 0.12947917862662248, 0.1397572471094983, 0.16795016000313417, 0.09267139514642102, 0.07345695261444364, 0.09478129978690829, 0.1663601217525346, 0.1140596331762416, 0.13624782328094753, 0.10570339299738407, 0.19907267498118536, 0.13045339206499712, 0.1265842496816601, 0.11691280507615634, 0.042433306973959715, 0.1420150859547513, 0.16648243447499617, 0.12477836944162846, 0.16339154461664812, 0.2024093980767897, 0.14156831135707243, 0.235590398311615, 0.07869945666087524, 0.09531084208616189, 0.09236188139766455, 0.09116573951074056, 0.14536932882453713, 0.12511657843632357, 0.17743941795613083, 0.1762515338403838, 0.08508875274232455, 0.13843921997717448, 0.15275370329618454, 0.11776192379849297, 0.22165258335215704, 0.17952246618058, 0.11826930514403752, 0.08303995018026658, 0.12792641908994742, 0.0717224542583738, 0.08181539803211178, 0.09480935720992939, 0.26917147636413574, 0.09829804500831024, 0.12324694304593972, 0.15663965977728367, 0.16910258387880667, 0.10080095034624849, 0.14448603907866137, 0.218131068029574, 0.16840651551527636, 0.10604662993656737, 0.13195071529064858, 0.0724875567747014, 0.1615092884749174, 0.06612919510475226, 0.15129226100231918, 0.10657286098492996, 0.1504892555198499, 0.15322905778884888, 0.09980018583259412, 0.17204172616558416, 0.11931951450450079, 0.19112016313842364, 0.10867009059126888, 0.08015370648354292, 0.15288115931408747, 0.09907227382063866, 0.12711772748402186, 0.17779564884092125, 0.1292308076683964, 0.14935673986162457, 0.12389404832252435, 0.2789630080972399, 0.09571579857064144, 0.10795988834330014, 0.08539245144597121, 0.1732326636889151, 0.10792409562106643, 0.1586160422968013, 0.11357055870550019, 0.1501347209726061, 0.12746278968240532, 0.17839216254651546, 0.13882655490721973, 0.10875762839402471, 0.17576555348932743, 0.10326032766274043, 0.10701444478971617, 0.09528672695159912, 0.1127526458086712, 0.11820567212998867, 0.12144133421991553, 0.1284691249685628, 0.14208900555968285, 0.14587939716875553, 0.130655581929854, 0.16791098139115743, 0.11385141792041914, 0.09603016384478126, 0.15774316127811158, 0.13584504489387783, 0.13864747594509805, 0.14409442937799863, 0.09452428429254464, 0.11070564136441265, 0.08965983960245337, 0.12549749442509242, 0.23309157096913882, 0.2459855005145073, 0.05728222482970782, 0.15551390232784407, 0.15297258512250014, 0.060932451459978304, 0.11535499723894255, 0.12422855251601764, 0.05393623973109892, 0.16776432283222675, 0.19366153462656907, 0.15537549475474016, 0.1484247041600091, 0.09492719160126788, 0.13106765624667915, 0.05920669263494866, 0.12844179357801164, 0.1783448008022138, 0.15998983143695764, 0.1617886142006942, 0.24866926936166628, 0.14438875072768756, 0.13352475368550845, 0.16672788773264202, 0.1736120461885418, 0.14018785900303296, 0.14910707968686307, 0.10856658007417407, 0.11517723463475704, 0.10376791256879057, 0.19586157585893357, 0.17315814697316714, 0.1516387074121407, 0.08320638803499085, 0.11910185404121876, 0.14232494575636728, 0.09519435119416032, 0.1072048485012991, 0.10277191137096711, 0.1566120705434254, 0.1246261333248445, 0.24428335470812662, 0.13220686226018838, 0.12253871533487525, 0.11500191475663867, 0.15087684829320225, 0.092355930645551, 0.10361982908632074, 0.09926199221185275, 0.21432904633028166], [0.03769536835274526, 0.040292132047138045, 0.044598240804459365, 0.057508163420217376, 0.054990835820457766, 0.07789415094469275, 0.010544154294101256, 0.02336845257585602, 0.01734515489079058, 0.03811327128538063, 0.019603504333645105, 0.005694215410455529, 0.04876109046329345, 0.03701125577624355, 0.04304774757474661, 0.0713670172595552, 0.022840364037879875, 0.055796884532485685, 0.025580834663872207, 0.00846395846123674, 0.03287170700994985, 0.02683227206580341, 0.03393432338322912, 0.03216535205553685, 0.016703623779384152, 0.06379486500684704, 0.02411466806993953, 0.058099791673677306, 0.024854707199015787, 0.013297585787118545, 0.020900527414466654, 0.0200241332807179, 0.03493349673226476, 0.01541703487081187, 0.053473047978643856, 0.047649321013263295, 0.026724617396082197, 0.03885040119556444, 0.01978520752995142, 0.04473711995940123, 0.018351016898772547, 0.0159326315790947, 0.022331325370552282, 0.00922546728647181, 0.02250821944991393, 0.02914145735225507, 0.016417709478576268, 0.010003359339732145, 0.06786129823220627, 0.04061870077358825, 0.038757699741316695, 0.04520648977320109, 0.030954804870166948, 0.014806658694786685, 0.04677865880408457, 0.021502642426639795, 0.045566364391041655, 0.03125737042033246, 0.02882047975435853, 0.02007237881688135, 0.05560799056131925, 0.05873935164085456, 0.08799018205276557, 0.05160875605153186, 0.02163741474838129, 0.005148970962701631, 0.042932654464883466, 0.09108377248048782, 0.046495621491755755, 0.01907907140308193, 0.03833220739449773, 0.009720200739268745, 0.013151252076828053, 0.05411856887595994, 0.0696464085153171, 0.06126005495233195, 0.016691896997924362, 0.06853176546948296, 0.02551265207252332, 0.08476804995111056, 0.06579925745193448, 0.04463406406076891, 0.037634191635463915, 0.03044668392145208, 0.030592168614800488, 0.017913779110780785, 0.029136273344712596, 0.050755077573869906, 0.03545160571645413, 0.046521046198904514, 0.01731383880334241, 0.04425283594589148, 0.03245425530310188, 0.03211656878037112, 0.05983324508581843, 0.1267410862658705, 0.05396726913750172, 0.09019441663154534, 0.027620767076898898, 0.026951972428443174, 0.07578738113599164, 0.04661810724064708, 0.0300821477680334, 0.05222962577162044, 0.015000426243724567, 0.019397311112178222, 0.034613984770008495, 0.024783975012334328, 0.0075942512900967684, 0.04394599562510848, 0.017726386398343102, 0.025489997484588196, 0.03191132890060544, 0.015220205432602336, 0.054715340424861224, 0.0402448110149375, 0.03225451155698725, 0.10508433835847036, 0.060263022381280146, 0.07766572891601495, 0.036565655044146946, 0.05837665431733642, 0.05013739357569388, 0.03187791783628719, 0.0619111160880753, 0.02854065191266792, 0.033124393450894525, 0.03965075021343572, 0.023147982977596775, 0.01806849696939545, 0.014412058351029242, 0.005098088045737573, 0.022361409916941608, 0.0305866894445249, 0.03544780931302479, 0.008976791835656124, 0.046985354141465256, 0.029706110446048633, 0.05628923632736717, 0.05500180773170931, 0.05658280450318541, 0.0547456268354186, 0.030642434488981962, 0.0528562325052917, 0.06189544192914452, 0.04931071400642395, 0.032564944720693996, 0.03284590232319065, 0.04265457045819078, 0.03322002956909793, 0.04512599855661392, 0.006380330089346639, 0.035814767836460044, 0.049478098417499235, 0.05406399091173496, 0.03158486195440803, 0.05083582324108907, 0.041600127039211135, 0.027835689651380693, 0.004091119177506438, 0.033043071028909514, 0.04352378738777978, 0.03494128292160375, 0.03557932636301432, 0.03300459130800196, 0.022684816670204912, 0.013224063973341669, 0.042396472700472386, 0.04268123009907348, 0.005892921422076012, 0.06796947028487921, 0.06689509150705167, 0.08319493436387607, 0.029855941156191484, 0.029160422406026294, 0.016461854966889535, 0.04938406364193984, 0.035272228198924234, 0.0417133032876466, 0.047084854516599856, 0.034505259711295366, 0.04474288072170956, 0.040336861075567346, 0.03987408662214875, 0.031153958290815353, 0.03366982364760978, 0.02861647480832679, 0.018612061194809418, 0.06352977494576148, 0.0728732632207019, 0.029503632203808854, 0.059370463847049644, 0.02909524572481002, 0.08991317743701593, 0.013119477130073522, 0.05742327868938446, 0.02986763570723789, 0.023854717911620225, 0.02433648795288588, 0.05176272243261337, 0.05067215380924089, 0.006926734831982425, 0.05398510443046689, 0.0515351383946836, 0.009954678692987986, 0.007998583522359175, 0.029775205666997602, 0.04507075562807066, 0.034315714346511025, 0.024806144447731118, 0.028221092452960353, 0.01790323298025344, 0.027750095851453285, 0.05202417215332389, 0.0497027240427477, 0.022516327943386774, 0.06123158362294946, 0.057696063337581496, 0.012380323489196599, 0.05331378563174179, 0.0547357846849731, 0.035322721382336955, 0.006743807728136224, 0.022583645402586887, 0.008746802391085242, 0.07434079197368451, 0.038281571718731096, 0.029250406327524354, 0.015254128790859665, 0.03315825234832508, 0.048692473609532626, 0.028367732352178012, 0.05705005728772708, 0.03948021061452372, 0.03338466252067259, 0.05072111350351146, 0.03501467326922076, 0.03834232435162578, 0.09817750326224736, 0.09764675995601074, 0.01189335502151932, 0.07762897267405476, 0.07889398586537157, 0.023231554743168608, 0.07605179944740874, 0.016600976698100567, 0.009639275260269642, 0.03238436958885618, 0.07260186956929308, 0.03873832756653428, 0.034292966460010836, 0.05077107064425945, 0.01128409503559981, 0.0327642474190465, 0.016492046382544295, 0.023642434838360975, 0.015578156403665031, 0.050940826535224915, 0.05091088617752705, 0.023357745293261747, 0.01972796461944069, 0.0735025094555957, 0.023735585822058574, 0.010847594306272055, 0.06269489188811608, 0.05590919225609728, 0.009496050088533332, 0.02725611217985196, 0.02162008496400501, 0.04933928372338414, 0.01730616796495659, 0.04593012022918888, 0.04696669103577733, 0.04236086318269372, 0.022528000442045074, 0.03484965694536056, 0.10951533487864903, 0.03425441549292632, 0.050863205521766625, 0.02397324949769037, 0.008082534419372678, 0.03020298128415431, 0.0174815472148891, 0.08900687178330761, 0.025409311189183166, 0.044496229849755764, 0.037937615532428026, 0.07110407815447875, 0.008330594947827714, 0.02574561010780079, 0.03390768409839698, 0.04331769933924079, 0.045586530451795886, 0.051424547364669185, 0.02278922624619944, 0.041448335362864394, 0.0734870999253222, 0.10318907470043216, 0.026055571689669575, 0.07656500262341329, 0.04029375035315752, 0.011317082015531403, 0.03643974269341145, 0.05918254357363496, 0.03470427742494004, 0.030274705828300545, 0.022351335368252227, 0.011381878717137235, 0.03320214677868145, 0.02494748668479068, 0.052200631970273595, 0.022272391211507574, 0.018368602830118368, 0.009796904882283082, 0.051264993247709105, 0.11128060479781457, 0.04810095392167568, 0.014595349319279194, 0.036178835800715854, 0.009931048710963555, 0.04754010062398655, 0.040260458032467535, 0.05604855656357748, 0.031571440531739166, 0.04666722978332213, 0.0180768056306988, 0.06866010358291012, 0.060559861095888276, 0.04525229427963495, 0.029363253486475775, 0.04201578741360988, 0.018951803678646684, 0.04783154498519642, 0.008174866920204034, 0.04253410335097994, 0.021626156156084368, 0.017376805156735436, 0.055171736649104526, 0.03518292620511992, 0.038888633251190186, 0.007855017386775996, 0.0740995184917535, 0.0022814304476404296, 0.033649250465844355, 0.035036196400012286, 0.015233626855271203, 0.03018941736913153, 0.046075693132089715, 0.07278240738170487, 0.019855764993865575, 0.004809050787506359, 0.05237611469679645, 0.10623573764626469, 0.11377424134739808, 0.11178489880902426, 0.12076254135796002, 0.17920170910656452, 0.1408436902399574, 0.1736315337142774, 0.14489273939813885, 0.062270576799554486, 0.10733855382672378, 0.11375353924397912, 0.062808594001191, 0.11253945689116206, 0.12014180395220007, 0.06456306842820984, 0.21244483600769723, 0.13149942164974554, 0.3189300777656691, 0.10769983301205294, 0.13591850309499673, 0.09881012181618384, 0.10742354712315969, 0.09006523713469505, 0.12976724388343946, 0.19219235703349113, 0.07760064383702618, 0.15860792701797827, 0.19631673714944295, 0.17469717296106474, 0.08897214436105319, 0.08487848831074578, 0.1353333887777158, 0.12969150580465794, 0.15612313177968773, 0.14615827506142004, 0.1416948852794511, 0.05934003833681345, 0.09334945519055639, 0.0811579315257924, 0.15405018015631608, 0.16498768968241556, 0.16256565893335, 0.1163255465882165, 0.1574343057083232, 0.24935771099158696, 0.1080585541203618, 0.1433544055159603, 0.11220148538372346, 0.14481782913208008, 0.14103920332023076, 0.1467558065695422, 0.0922136011400393, 0.07256010573889528, 0.06730722010667835, 0.10564335621893406, 0.17090348367180141, 0.13786572217941284, 0.10644381040973322, 0.07423849603427307, 0.10848775466105767, 0.19751994258591107, 0.19955359346100263, 0.256965771317482, 0.14786373211869172, 0.07132808970553534, 0.17682271104838165, 0.17434228557561124, 0.1767662569348301, 0.1823520114911454, 0.18055721851331846, 0.08331366442143917, 0.08979815218065466, 0.18035922199487686, 0.10200493609798805, 0.17527238066707337, 0.17135652793305262, 0.11524198044623647, 0.1748272752655404, 0.06646219973585435, 0.25426772609353065, 0.12798523450536387, 0.14821593250547135, 0.1521320973656007, 0.09660196530499629, 0.12674553745559283, 0.16312160981552942, 0.12625684296446188, 0.11773848719894886, 0.15047542697616986, 0.20044805189328535, 0.2333022425217288, 0.09684209884809596, 0.12285322988671915, 0.14495253190398216, 0.12587143507386955, 0.24607178302747862, 0.1585073545575142, 0.18692404830030032, 0.10690891223826579, 0.11249141661184174, 0.12808504700660706, 0.14025563108069555, 0.07070370178137507, 0.09578561303871018, 0.0588122263018574, 0.12667806393333844, 0.15990082121321134, 0.1464917885937861, 0.21121268426733358, 0.11678061288382326, 0.16048160647707327, 0.21350674331188202, 0.08712844257908207, 0.08877110122037785, 0.13639967941812106, 0.15618130937218666, 0.15393763833812305, 0.18830269575119019, 0.12782288821680204, 0.14062417059072427, 0.15842078705983503, 0.20452557238084929, 0.18751271814107895, 0.22298580966889858, 0.1585539292011942, 0.11796895840338298, 0.11628349098776068, 0.1933948296521391, 0.10892755391874484, 0.1345321067741939, 0.06636657379567623, 0.09388760809919663, 0.1006046976628048, 0.2681007481047085, 0.14918140641280583, 0.04245561042002269, 0.15524468677384512, 0.06841619738510676, 0.1870701504605157, 0.16365905026240007, 0.13166628698153154, 0.1253219438450677, 0.08184840197541884, 0.07835075751479183, 0.14555683519159043, 0.12864814964788301, 0.13291981257498264, 0.20045213667409761, 0.1684400351451976, 0.07547740598342248, 0.17979620077780314, 0.2010216853980507, 0.08362345636955329, 0.1055444325985653, 0.15675909551126616, 0.11402733490935393, 0.10504063391791922, 0.11144225219530718, 0.11580307462385722, 0.09244735645396368, 0.10305448727948324, 0.13202102508928093, 0.14104589367551462, 0.11834950798324176, 0.06614170050514595, 0.19214522599109582, 0.09010446324412312, 0.1891432377908911, 0.11712021966065679, 0.07136801470603261, 0.08666049768882138, 0.1777626448976142, 0.2392337785235473, 0.11524519670222487, 0.13238081149756908, 0.10824143966393811], [0.01901864616333374, 0.04536052740045956, 0.03881812667740243, 0.016634403029456735, 0.03540179446073515, 0.06535611301660538, 0.026918457887534584, 0.03226295592529433, 0.03780475498310157, 0.06703515470560108, 0.02708407471488629, 0.026076165227485553, 0.030258519375430684, 0.009547225199639797, 0.039010209763156514, 0.04880804508658392, 0.031770824654293914, 0.03749524801969528, 0.03443624252187354, 0.03849125600286892, 0.012680483632721007, 0.036180783196219375, 0.02348637008773429, 0.016726797446608543, 0.01363820951831128, 0.029498393913464885, 0.030382586110915457, 0.037558989599347115, 0.03233464654268963, 0.05380650044285825, 0.0168296837114862, 0.02606916444243065, 0.050153926081423245, 0.019397246651351452, 0.04544788199876036, 0.06588912262980427, 0.0325035440868565, 0.054029958987874646, 0.039173960619206936, 0.08759256731718779, 0.007005166694787996, 0.033086755113410096, 0.03755176320139851, 0.027654598832928708, 0.031038254499435425, 0.04515694314613938, 0.01125819026492536, 0.061170752958527634, 0.002950595533807895, 0.0019420257470171365, 0.045147759174661975, 0.051494399152163944, 0.06076253950595856, 0.03663229396832841, 0.039652015681245496, 0.027650715916284492, 0.01928641813408051, 0.035413007251918316, 0.017494956763195138, 0.04467873541372163, 0.04602925080273833, 0.02228084745417748, 0.04572549781629017, 0.013026315120181866, 0.010913175563993198, 0.03865939358781491, 0.01395093443404351, 0.020741310868678347, 0.044206390223864994, 0.04753976135647722, 0.06950578213270221, 0.018340073825259293, 0.017067820665293505, 0.03604817370484982, 0.05488018372229167, 0.057754994103951116, 0.06793105841747352, 0.05735310459775584, 0.022996924119070172, 0.057420089574796815, 0.06468866526016168, 0.016000457939558795, 0.03327407149065818, 0.022402968490496278, 0.008843446981960108, 0.05200909171253443, 0.010521504795178771, 0.025365399795451334, 0.0439437259254711, 0.08183486520179681, 0.06727355119905301, 0.01029149245005101, 0.025840588047036102, 0.12074044825775282, 0.03360904726598944, 0.0229408075766904, 0.0275795240221279, 0.033536281170589585, 0.03561872549887214, 0.06141362778310265, 0.040842858209673844, 0.011914582141408963, 0.029521609989127943, 0.0476679942969765, 0.060331215150654316, 0.02069174049289099, 0.007865923989031996, 0.008198822599037417, 0.029347860919577733, 0.037617411464452744, 0.04314983995365245, 0.01603423202011202, 0.04643944897023695, 0.043984991032630205, 0.017069729045033455, 0.06139351600514991, 0.042048513157559295, 0.023192348989791105, 0.05701486846165998, 0.04198812014822449, 0.0451822864290859, 0.03829780227637716, 0.08077756515038864, 0.010518331795797815, 0.018605608326782073, 0.02789801818185619, 0.034693417471966574, 0.008134800275521619, 0.061948428728750775, 0.0385193337819406, 0.06936625497681753, 0.010347284991959376, 0.049079611764422486, 0.05545903176867536, 0.020604348575164164, 0.07929416546331984, 0.005111676981739167, 0.030642271640577486, 0.030406959088785306, 0.03341036881985409, 0.03288758812206132, 0.012548746058850415, 0.022514697763004472, 0.016256341976778846, 0.04761178445603166, 0.027974031067320278, 0.06834750928516899, 0.004331860009447804, 0.012962288555822201, 0.009159362708617533, 0.01770822540856898, 0.04974598743553672, 0.05445427407643624, 0.04195379645430616, 0.018705008618001426, 0.030059213284403086, 0.023382486376379217, 0.06724926643073559, 0.016635799115257602, 0.04956221301108599, 0.049171614327601025, 0.015038851681830627, 0.03625253488176635, 0.018468703708744476, 0.04751534427383116, 0.04692510701715946, 0.032357587811670134, 0.02027881970363004, 0.031173971681190387, 0.012400580304009574, 0.03027887881866523, 0.03542768396437168, 0.029062961028622727, 0.008244367565826645, 0.10785227947469268, 0.03539589120607291, 0.0134549321207617, 0.04815377448020237, 0.06207004256014313, 0.025412897246756723, 0.019629219114514332, 0.019257185149139593, 0.04707433722381081, 0.05467376319159355, 0.07818276581487485, 0.06325182664607253, 0.009497201901727488, 0.02811677617553089, 0.01007826451677829, 0.023941171754683768, 0.017352062377280424, 0.07179010419973306, 0.05262275878340006, 0.016311484821406857, 0.023129457275250127, 0.06684204363929373, 0.042736018409154246, 0.06908692246569054, 0.07087043819150754, 0.04642714034499867, 0.047372726390936544, 0.018795737231682454, 0.013629791443236172, 0.020712666512866105, 0.03913855466193386, 0.03353472054004669, 0.03207495762035251, 0.02225889854266175, 0.046236668779913864, 0.02166445945788707, 0.05814430357090064, 0.0033731169574561393, 0.05249578452536038, 0.007948244705663195, 0.06348405525620494, 0.08837097590523106, 0.02060544101654419, 0.009351159113326242, 0.02306192268484405, 0.024575249158910344, 0.02313992367791278, 0.03240507847762533, 0.02041810767592064, 0.06143597194126674, 0.02552002774817603, 0.07951590392206397, 0.016358809246282493, 0.03711548554045813, 0.02081985299342445, 0.023192523712558404, 0.04628410516306758, 0.02642712728785617, 0.08643300525311913, 0.02638759583766971, 0.051810800031359704, 0.03889021763045873, 0.01683222652146859, 0.027457447090585316, 0.009312211203255823, 0.08729934519422905, 0.048922761609511714, 0.07014699093997478, 0.054695666301995516, 0.016789634878348027, 0.04113021439739636, 0.02172545636338847, 0.057579999922641685, 0.008199621574021876, 0.035027104030762396, 0.03661761386319995, 0.0061431125504896045, 0.042916603719017336, 0.014849762631846326, 0.019608420319855213, 0.06619906385562249, 0.02462907903827727, 0.020919567107089927, 0.012628488342410751, 0.009773661665219282, 0.015323931384565575, 0.04650399800656097, 0.046523478746946366, 0.019093988995466913, 0.034067418027137, 0.014765386802277394, 0.05231020859043513, 0.03843300037884286, 0.04208670789375901, 0.05824761052748986, 0.07263528741896152, 0.05119454434939793, 0.06935761044067995, 0.031774977288608036, 0.017692422327984656, 0.05785670650324651, 0.034287202305027416, 0.0582541719611202, 0.07604909887803452, 0.023677058784025054, 0.027654875335948806, 0.021673409334783043, 0.02119853320930685, 0.028182414260559847, 0.03419487065236483, 0.04142045096627303, 0.011650930574562932, 0.0240876725542226, 0.040397209980125935, 0.03350062415535961, 0.020483318283887844, 0.04496955552271434, 0.02710566739551723, 0.0555145359332008, 0.0814487991322364, 0.05851341305034501, 0.044095924722829034, 0.03810390750212329, 0.05675268253045423, 0.05171061772853136, 0.05650078319013119, 0.0076682633454246175, 0.013013724902910846, 0.020509027975744436, 0.02510556159541011, 0.014939846637259637, 0.09310132850493703, 0.03685547770666225, 0.0383625480878566, 0.042593424274985275, 0.040534691352929385, 0.0277456718031317, 0.008582235596674894, 0.0626268619671464, 0.025655909474673014, 0.08754595196140663, 0.03886518647362079, 0.020907158397936394, 0.054163939119981866, 0.00859974095198725, 0.02445532996872706, 0.04391933937690087, 0.04108376528269478, 0.08400434521692139, 0.08538126240351371, 0.03572912314640624, 0.03330692615626114, 0.04475226825369256, 0.02252447375628565, 0.05305566412529775, 0.049263114774865766, 0.0376676875166595, 0.056376987868653874, 0.03417387677888785, 0.02478101659965302, 0.030312035432351486, 0.039475199633411, 0.0246541390328535, 0.025429480642612492, 0.028957099387688295, 0.09295823904020445, 0.024688917345234325, 0.04674891182886703, 0.05556065595841833, 0.018352614848741462, 0.037445935487215004, 0.04801448820424931, 0.025246315203340988, 0.03978428929778082, 0.015346553742087312, 0.032135510085416694, 0.08527298857058797, 0.0628715484802212, 0.09507840313017368, 0.11489839745419365, 0.1706265871013914, 0.1256029794790915, 0.11231740630630936, 0.08206792841000216, 0.09396553106073822, 0.1215019952505827, 0.10670541958617312, 0.16499189659953117, 0.13481341382222517, 0.1610483189246484, 0.0811628984021289, 0.11219943620796714, 0.14041144986237797, 0.14146875669913633, 0.11968310070889336, 0.08191407737987381, 0.11537810814167772, 0.09655121088560138, 0.0920135961579425, 0.17025168293288775, 0.10601003654301167, 0.08087817153760365, 0.1821347310074738, 0.12111561026956354, 0.1391938594835145, 0.13204390529010976, 0.15325869619846344, 0.14895860265408242, 0.15464389829763345, 0.1041618903566684, 0.1592758090368339, 0.0710825143115861, 0.14387588681919233, 0.09996264068675892, 0.11214096684541021, 0.15679991617798805, 0.17244317462401731, 0.11811241427702562, 0.06724611802824906, 0.07202506052064044, 0.10816365919475045, 0.0779711307425584, 0.13318955738629612, 0.09097467083483934, 0.14448062436921255, 0.09823389630764723, 0.10122494652335133, 0.11781809292733669, 0.14164072461426258, 0.11852121805506093, 0.06541799541030612, 0.1492573887641941, 0.15368628182581492, 0.20103829593530723, 0.11550499419016497, 0.15120105232511247, 0.12922845993723187, 0.10013724810310773, 0.12694989863250936, 0.09859299739556653, 0.11861529015004635, 0.22622879993702683, 0.10448733610766274, 0.13360533650432313, 0.11662507908684866, 0.07954482986990895, 0.1638448467212064, 0.11194379135434117, 0.21844801173678466, 0.15694998098271234, 0.12584390012281282, 0.08747284659849745, 0.1594283301383257, 0.18005861741091522, 0.11232012044638395, 0.11450657062232494, 0.14512065931090287, 0.1483206847416503, 0.19021357250000748, 0.06807205799434866, 0.10479636809655599, 0.09091028464691979, 0.15330077894032001, 0.1511061117053032, 0.16529543245477335, 0.1494671782212598, 0.19286025262304715, 0.15139800389962538, 0.17976676592869417, 0.201028972864151, 0.19093424454331398, 0.23556046134659223, 0.18205973931721278, 0.17908573390117713, 0.05807740001806191, 0.13145094710801328, 0.1060667959973216, 0.11913795210421085, 0.17572222224303655, 0.19482784132872308, 0.10305282486868755, 0.1578046636922019, 0.10708078515848943, 0.07748584928257124, 0.09542143650885139, 0.0996777509738292, 0.13722917490771838, 0.21183076181582042, 0.09913680928626231, 0.11890860726790768, 0.17087436094880104, 0.10989175218024425, 0.12802118329065187, 0.17108264405812534, 0.14416533628744738, 0.25041625276207924, 0.13429096899926662, 0.10428412165492773, 0.19184405143771852, 0.22711679871593202, 0.16886720008083753, 0.1021264074370265, 0.09445345880729811, 0.1368183083832264, 0.11722330270068985, 0.09821556907679353, 0.18893703099872383, 0.24471061463866914, 0.1101301893857973, 0.11914230829903058, 0.11262924064482961, 0.11054078449628182, 0.1032878083309957, 0.18386271542736463, 0.13029829253043446, 0.12603821898145334, 0.1476692639823471, 0.11225595817502056, 0.13699548744729587, 0.10975589589881045, 0.11305630380021674, 0.10874037324850049, 0.18625417138848985, 0.10527257754334382, 0.21907767866339, 0.1235635339149407, 0.08672734017350844, 0.11010869339640651, 0.0887536085875971, 0.1244622671178409, 0.1881655366825206, 0.11636442664478507, 0.05487961036020091, 0.14201630731778486, 0.16171801941735403, 0.1715532216642584, 0.0741902861211981, 0.09550902859440871, 0.1276950929313898, 0.13643330761364528, 0.11112655020718064, 0.2240940744855574, 0.16543776196028503, 0.14831141595329556, 0.167416994326881, 0.08998189946370465, 0.1702595403684037, 0.23010775393673352, 0.13290099001356534, 0.11197962478867599, 0.1279494214270796, 0.08853429928421974, 0.25167279105101314, 0.1658629455736705], [0.058197297155857086, 0.07631625168557678, 0.08966722884880644, 0.0338500900460141, 0.026396837484623705, 0.020779140892305543, 0.03355179926646607, 0.010471149863276099, 0.04124064597168139, 0.037222870492509434, 0.07601411361247301, 0.08922734138156686, 0.046029912374381504, 0.039965403864958456, 0.04942586139908858, 0.014560715195589831, 0.055352708723928244, 0.029405251411455016, 0.06549557231898818, 0.04714737134054303, 0.015820551164714352, 0.04433001930426274, 0.022146862233057618, 0.025869707377361398, 0.03496313514187932, 0.054830375859247785, 0.032783765478857925, 0.029819524181740623, 0.04356523909206901, 0.048824927037847896, 0.009944437055050262, 0.017262292194313238, 0.03614116692915559, 0.07786392220961195, 0.011589077018600489, 0.050907622424087355, 0.03025508938091142, 0.11271985221121993, 0.04056667410103338, 0.02686506905592978, 0.0814734570948141, 0.02629036007315985, 0.023427122106243457, 0.018386299023404717, 0.03924326957868678, 0.0407784211316279, 0.02401082676702312, 0.0501919545765434, 0.02512277433249567, 0.04418894848121064, 0.01719870837405324, 0.08698025053100926, 0.03973695130220481, 0.0387469517466213, 0.009345798686678921, 0.0231226922811142, 0.034051614946552684, 0.0268873741983303, 0.027165753367756094, 0.03255591341959579, 0.013260927084567291, 0.015667125915310214, 0.005271795979102275, 0.041377642191946507, 0.035947367149804316, 0.04027404908889106, 0.02463247171337051, 0.04355525105659451, 0.025474581168964505, 0.07769270746835641, 0.018209309949140464, 0.010952933475242128, 0.046941310433404784, 0.11588596446173531, 0.01806105174390333, 0.018671453364991715, 0.029423822914915423, 0.04012144317052194, 0.02273694173033748, 0.04337244354454534, 0.026264531637674997, 0.042000191286206245, 0.028771689693842615, 0.03856746566348842, 0.025330950572554554, 0.017260042850726416, 0.04176810516842774, 0.005353712119228605, 0.05991606028484447, 0.06010239278631551, 0.06007392145693302, 0.04421153351930635, 0.11471674005900111, 0.03564918154318418, 0.04070974660239049, 0.03640587701063071, 0.036213631076472144, 0.005141379004011729, 0.02513746461564941, 0.019504202430003455, 0.0388595580256411, 0.025758373351501565, 0.017300042490075742, 0.024049199618665234, 0.02696135826408863, 0.041861139104834626, 0.07115797419101, 0.036278475275529284, 0.0384847929568163, 0.03714318673259445, 0.03828324091487697, 0.08795393471206937, 0.02372002531774342, 0.017509497768644775, 0.0245257449402873, 0.0194921058469585, 0.032310969063213894, 0.058364895305463245, 0.009398530187484409, 0.02516050766488271, 0.02657742109814925, 0.05570515338331461, 0.009869496254915637, 0.052087974801127396, 0.02244428448778178, 0.04957681169201221, 0.01823076861910522, 0.03562081877940467, 0.06636155942188841, 0.01592591917142272, 0.06662255791681153, 0.062215534038841724, 0.0570925675066454, 0.04987669024350388, 0.07237899117171764, 0.05355922871136239, 0.04634397570043802, 0.08975503128021955, 0.020189273437219005, 0.035901328548789024, 0.0877025510583605, 0.028189352281125526, 0.05436793388798833, 0.014769368106499314, 0.03080094705468842, 0.014330878421398146, 0.01735213871247002, 0.015086554389979159, 0.016024274518713355, 0.017123526693986993, 0.02027387996869428, 0.05204199387558869, 0.07691908933754478, 0.049081911998135705, 0.07001111430249043, 0.0605658729161535, 0.10161045619419642, 0.025917539007163475, 0.04811656701245478, 0.0508586016616651, 0.00797573131109987, 0.015517230744340589, 0.0054785841909636345, 0.009111229130732161, 0.041867293417453766, 0.03069258840488536, 0.08091029338538647, 0.05108173790254763, 0.04726574177454625, 0.031542422981666665, 0.01216396750948791, 0.008135122579655476, 0.05955229087599686, 0.04851208846750004, 0.030639102882040397, 0.015547434034358178, 0.043431360740214586, 0.059822870285383294, 0.04123895302680986, 0.0210881627031735, 0.050908721650817564, 0.08145356244806733, 0.016963570545028363, 0.0317803682493312, 0.08071129263511725, 0.030580586022032157, 0.026969539700075984, 0.02414849304061915, 0.02261421679785209, 0.022342631460300515, 0.043128645912344964, 0.021223275988761867, 0.006624641287739256, 0.006410794191262019, 0.01972360333560833, 0.019868938751252632, 0.048418969714215825, 0.05819062037127359, 0.026737987928624665, 0.06679474296314375, 0.017552121642178724, 0.034149887173303535, 0.030351879008646523, 0.006516498072804617, 0.02993913972750306, 0.03563097305595875, 0.04351068826924477, 0.038318178682987175, 0.009476728803877319, 0.04780626616307667, 0.03737245014469538, 0.01979536859185568, 0.021716185878696184, 0.030255903622933795, 0.00813660941951509, 0.02163138087572796, 0.03404881598960076, 0.03535410701962454, 0.06598603778651782, 0.03319078470979418, 0.015596444618755152, 0.05487588859562363, 0.015061740364347185, 0.03322509822568723, 0.009709553676657379, 0.057411607887063704, 0.040267005895397494, 0.02432874247564801, 0.04756211229999151, 0.05299663157867534, 0.0327049095316657, 0.01198582407752318, 0.029716536136610166, 0.025528344891167114, 0.0034877363650593907, 0.04712253017351031, 0.003930943352835519, 0.022100107777597647, 0.024846179710168923, 0.026653669774532318, 0.03422210704801338, 0.04197868172611509, 0.0268167132578258, 0.03817714178668601, 0.018470389868265817, 0.08164303656667471, 0.03157653632972922, 0.015613950822236282, 0.051127155644020865, 0.052445270985897095, 0.022306528308295777, 0.027280666665839295, 0.02261985542385706, 0.015253421418102724, 0.043294978594141345, 0.030950560633625303, 0.03292176253827555, 0.016160948434844613, 0.048934663113738806, 0.03862179935510669, 0.049831543916038105, 0.01010145090653428, 0.04704416277153151, 0.05986648651638201, 0.010193210045274879, 0.07573884552610771, 0.05521669637944017, 0.027399160932483416, 0.025743277643674185, 0.09812440111168794, 0.02128479875890272, 0.05547104523118053, 0.01710206632768469, 0.03531845000439456, 0.013968564470165541, 0.08571508127663817, 0.04875699211178081, 0.03169922224645104, 0.05968113789068801, 0.041588792111724615, 0.04597807569163186, 0.07311871647834778, 0.041233199049851725, 0.03383467033771532, 0.03308805450797081, 0.002465953805118001, 0.006528807970296059, 0.040881585595863204, 0.020406955952889154, 0.05146878445520997, 0.02056349567802889, 0.016170978878757784, 0.04126538535846131, 0.04004725893693311, 0.02650752181320318, 0.059495490709585805, 0.041430310080094, 0.014399632678500243, 0.00884794142828988, 0.06698401352124554, 0.004450236804716821, 0.04684327908658555, 0.04565410914697817, 0.009750114803734635, 0.028124647181747214, 0.022882629984191487, 0.05879410941685949, 0.017888466361910105, 0.06792301777750254, 0.011810730660467275, 0.04473816829600504, 0.019515316833608916, 0.043809491342731884, 0.07773793861269951, 0.08351640389966113, 0.005147913296241313, 0.07072253112814256, 0.020280770491808653, 0.07793065612869603, 0.030487185676715205, 0.056085299234837294, 0.010355002479627728, 0.026598255515896847, 0.044121709053537676, 0.027581535878458192, 0.04019091497840626, 0.04480712441727519, 0.025763871181490164, 0.07011025505406515, 0.028557445654379468, 0.054289318820727725, 0.02529822991761778, 0.061162481616650305, 0.08197052470807518, 0.06986996544791119, 0.030592022729771476, 0.029861196409910917, 0.044863816018083265, 0.037168770895472596, 0.07030981220304966, 0.024358165450394154, 0.014117563126741775, 0.02799821405538491, 0.05953489323811872, 0.007700810125762863, 0.019489432418985025, 0.017738912154787352, 0.04764394023056541, 0.021583108198163763, 0.061048385953264575, 0.0722656554675528, 0.09473225527576037, 0.09842997257198606, 0.13147210382989474, 0.16587419568427972, 0.1101272716852171, 0.12473264975207192, 0.12258033667291914, 0.10114923558597054, 0.07741397206804582, 0.09213894193193742, 0.11920435354113579, 0.22618351450988225, 0.127475803984063, 0.15826542968196528, 0.07252757677010127, 0.1619520325745855, 0.11219257621892861, 0.10934279699410711, 0.12518175851021493, 0.11180252036345856, 0.12345760102782931, 0.12387811632028647, 0.13881474839789526, 0.08669587650469371, 0.12050301528402738, 0.17702989493097576, 0.11558147865746703, 0.11557398763086114, 0.1232824439981154, 0.14395933305578573, 0.12826557803366864, 0.11496967077255249, 0.13251140234725817, 0.12318588846496173, 0.12836477985339506, 0.10362824970590216, 0.14577731836055005, 0.15978492743202619, 0.19466561717646463, 0.16172846885664122, 0.09579662566206285, 0.14650295728019305, 0.11238437771264996, 0.14450757578015327, 0.06444349020187344, 0.21482667034225805, 0.1981161848774978, 0.13959490082093648, 0.12284645810723305, 0.11188067402690649, 0.11229705704110009, 0.1345087651695524, 0.1780227002288614, 0.18064268678426743, 0.12281396985054016, 0.09410758915224246, 0.10924378516418592, 0.10682982219649212, 0.13532588418040956, 0.10662423965654202, 0.10281025538487093, 0.13272982276976109, 0.18510581872292928, 0.0713112416810223, 0.07089304019297872, 0.10346506203391723, 0.14305168390274048, 0.06040904311729329, 0.17543721039380344, 0.17249722672360285, 0.17035935286964687, 0.07618687541357108, 0.061154590254383426, 0.16184923451926025, 0.16284775308200292, 0.1799010887209858, 0.07085174455174378, 0.1428077777049371, 0.18520246925098555, 0.171882460426007, 0.21416569580989225, 0.11319591238030366, 0.1278882311390979, 0.1372389050998858, 0.10827506785946232, 0.13993851095438004, 0.0759334900815572, 0.15251518466642924, 0.157680193228381, 0.11049680185637303, 0.1626272699130433, 0.20875147490629128, 0.11746066782091345, 0.16253908750201973, 0.1624282013092722, 0.15259606604065212, 0.10389951443565743, 0.11461474267499787, 0.12512577937117644, 0.12764857257051127, 0.13953083354447568, 0.1122109509472336, 0.06847658021641628, 0.11784124454217297, 0.09727303643843957, 0.0959202004596591, 0.1815627259867532, 0.14834247928644928, 0.107222673616239, 0.2680859017585005, 0.06295333909136908, 0.13181517113532337, 0.1590949251715626, 0.08865191654435225, 0.1567162120980876, 0.11439860213015761, 0.14889197051525116, 0.18557788910610334, 0.1522867897791522, 0.0664091654387968, 0.16480107898158686, 0.19809778300779207, 0.08225791142987353, 0.1282199669097151, 0.15575780852564744, 0.11498626773910862, 0.1035660280446921, 0.13946904614567757, 0.10857523818101202, 0.13134094301079, 0.10165676620921918, 0.1441446952521801, 0.16985745408705302, 0.16283832144524368, 0.11004371688302074, 0.20867858667458805, 0.15318219816046102, 0.11323160332228456, 0.1526631053004946, 0.12957481135215076, 0.10972285802875247, 0.2756091723484652, 0.13434187269636563, 0.1892810482531786, 0.09177948122045823, 0.15721980721822806, 0.08735087314354521, 0.07324452365615539, 0.11134385783225298, 0.12667076289653778, 0.07870061695575714, 0.11024593388927834, 0.1295513611819063, 0.21446354554167815, 0.09634586583290781, 0.13571643536644323, 0.11814066847520215, 0.13808174058794975, 0.2675005703100136, 0.13649251657937253, 0.15305928832718305, 0.13309325969644956, 0.151210931794984, 0.10460778964417321, 0.15787859686783381, 0.1518598555454186, 0.09062036698950188, 0.1352740983877863, 0.16961003307785305, 0.16520848497748375, 0.10172690637409687, 0.0990827911134277, 0.09963110169129712, 0.1458918143595968, 0.17698036187461444, 0.16411004534789495, 0.27289774641394615], [0.03530835001064198, 0.023642417874985507, 0.06757540428744895, 0.01639449849192585, 0.05580237388078656, 0.048086382382150204, 0.02264459989964962, 0.028751082585326264, 0.06009785338704075, 0.023990343491147672, 0.01964774651319853, 0.026966219967497245, 0.04732777683862618, 0.045569299054997306, 0.028811831825545857, 0.01601332296351237, 0.01883721098835979, 0.028900886154068366, 0.054374376577990394, 0.030277922084288936, 0.04994422822658505, 0.031123726163059473, 0.03073852861832295, 0.04175244118752224, 0.041467809317899604, 0.020882003408457552, 0.05957766808569431, 0.03253234111304794, 0.015116572779204165, 0.019378705681966882, 0.028393604892439077, 0.05698316052023854, 0.013290407734790018, 0.07545127559985433, 0.029168639465102127, 0.08097080513834953, 0.051362084823527505, 0.05920096579939127, 0.04205664539975779, 0.03039167508749025, 0.013912772776425948, 0.010857874959973353, 0.05085401137226394, 0.04914119221003992, 0.016709359096629278, 0.012434766594586628, 0.0598867747134396, 0.023398491321131587, 0.009443886860805963, 0.038781041345958195, 0.020972078932183127, 0.03909311317173498, 0.03200448497331568, 0.049119736932750256, 0.04931415757164359, 0.0304736319397177, 0.04101794399321079, 0.04309081079970513, 0.023576053757486597, 0.00471343078450965, 0.03231155938868012, 0.06284479384443589, 0.0378144308924675, 0.004110675404912659, 0.017091330207352127, 0.05079219004671488, 0.017962827014603784, 0.02957633723105703, 0.07638037324483905, 0.04622025162513767, 0.01965157514704125, 0.04912680387496948, 0.035672309409294806, 0.033635672980121205, 0.025766283373481462, 0.07468030375561543, 0.06340237321066004, 0.0324050954410008, 0.041878645308315754, 0.029952903810356344, 0.0633881918287703, 0.05257028767040797, 0.010265650443865784, 0.06727199056851012, 0.006569585804494896, 0.0676501856318542, 0.038239590757127316, 0.023183505982160568, 0.04581552244988935, 0.007374932656862906, 0.048602360766381025, 0.005171412236190268, 0.005454598402138799, 0.05529298407158681, 0.05972144965614591, 0.060835007045950205, 0.043614860357982774, 0.005703669523687235, 0.049309095700404475, 0.011928071417579693, 0.01663552430857505, 0.010558452723281724, 0.055969463129128726, 0.07560665333377463, 0.03435535096962537, 0.029726405428456407, 0.020159497624263167, 0.0690968833597643, 0.025133695353620818, 0.014925583831167646, 0.08362529519945383, 0.04957912888910089, 0.026702649824853455, 0.024949461221694946, 0.038820440481816015, 0.03914201858320406, 0.033844746582742245, 0.0352028140665165, 0.018137760127761533, 0.03995783141415034, 0.02972485836861389, 0.03149510873481631, 0.03810978022270969, 0.023369695991277695, 0.04012741427868605, 0.04665537238387125, 0.0023789495005205807, 0.011164799249464912, 0.011727625387720764, 0.019147248905418173, 0.03579859495429056, 0.01748569984920323, 0.020069052298952426, 0.032666823361068964, 0.02910307262625013, 0.08221654114978653, 0.04543106111564806, 0.0763424024251955, 0.014545943488233855, 0.024581819074228406, 0.053240381713424406, 0.02933287886636598, 0.008955598642517413, 0.021144070596035038, 0.0945883651397058, 0.06873746336038623, 0.043178226466157606, 0.03018563792907766, 0.01808427969392921, 0.029744461245302643, 0.0541093034802803, 0.08873650271977697, 0.07558230749730553, 0.04746432861845408, 0.0754822167967047, 0.010435469099320471, 0.03113454201125673, 0.011882121026116823, 0.08527488846864019, 0.02605743257195822, 0.022061984287574887, 0.011131985295963074, 0.005847912922035903, 0.09379358350166253, 0.019188400357961655, 0.047554695912237675, 0.03351385219554816, 0.04691887128033808, 0.04729994333216122, 0.031286693311163356, 0.061214226697172434, 0.021058883917118822, 0.037514131649264267, 0.0427441744000784, 0.02729895996994206, 0.02702444845012256, 0.04366019328257867, 0.026354556271274174, 0.021595689933747053, 0.016283288298706924, 0.03963789536750742, 0.03787106481779899, 0.040183776790010076, 0.04380205799160259, 0.042300127513174496, 0.04200652880328042, 0.03771233172821147, 0.016216966589646678, 0.0464594521825867, 0.022129154165408442, 0.03043086387749229, 0.03733117825218609, 0.03717601425679667, 0.0071872032214222205, 0.09117557148316077, 0.049353716163230796, 0.06517567698444639, 0.05936533412230866, 0.041763765936983485, 0.022331805434077978, 0.020713195770180652, 0.04727768738354955, 0.04065417797703828, 0.023949141148477793, 0.03051198273897171, 0.021925407062683786, 0.0479159479561661, 0.07267095121954169, 0.03373418947947877, 0.03667090939623969, 0.06319499255291053, 0.038036671467125416, 0.02161942169602428, 0.01939226790065212, 0.13344592148704187, 0.0600797025752919, 0.041908823153270144, 0.0285427723346012, 0.06151724686580045, 0.027125319465994835, 0.032342531119606326, 0.016789159903834974, 0.02305261488072574, 0.0178646226413548, 0.026983987406960556, 0.03894765901246241, 0.00894631543529353, 0.03721775433846882, 0.005355920750714306, 0.02420875882463796, 0.032340566760727336, 0.024079575935112577, 0.04464041854121855, 0.053058486830975325, 0.05384825409523078, 0.045948332109089406, 0.043483160103538206, 0.034995935524680784, 0.014890281350484915, 0.05190540477633476, 0.07260749462459769, 0.026766235341451, 0.03991254259433065, 0.03301582445523568, 0.02424366945134742, 0.01492569748578327, 0.11107537509607417, 0.022648749141288654, 0.05269061567793999, 0.0342844983429781, 0.049729885799544196, 0.07130695333970444, 0.04058871291843908, 0.04987389807190214, 0.02835946949198842, 0.03472034852685673, 0.04459682945162058, 0.051413307432085276, 0.026977682120299766, 0.03544365328603557, 0.0423218643824969, 0.024962906393089464, 0.0599353713914752, 0.04373953438230923, 0.025049938687256405, 0.0512863297813705, 0.02192234686974968, 0.08285616218511548, 0.012642172697399343, 0.019166505729247416, 0.01857947794321392, 0.017966435124565448, 0.02707131316752306, 0.01747716048599354, 0.015034168093864406, 0.06104880664497614, 0.017195926380476782, 0.019901922338509133, 0.03366297044392143, 0.04539038633395519, 0.033655520129416666, 0.009419187337958386, 0.039856899330126386, 0.02002500689455441, 0.024347807613334486, 0.019182938151061535, 0.04170419395502124, 0.030795111653528044, 0.011928598978556693, 0.03213091979601553, 0.013841030420735478, 0.03385566081851721, 0.010386258347092994, 0.03229539329186082, 0.042576779810977836, 0.0351447789663715, 0.05303368976871882, 0.06597262314919915, 0.036607164423912764, 0.022057833349598304, 0.057209906567420275, 0.032195808099848885, 0.006425237657302725, 0.010498579641404961, 0.0328922666210149, 0.011380056850612164, 0.008946875226683915, 0.0645071639280234, 0.05547695866386805, 0.015177542543304818, 0.004296730131110442, 0.05891469866037369, 0.028540696017444134, 0.08330987819603511, 0.020033619200278605, 0.07693584236715521, 0.07398228799658162, 0.05662183044478297, 0.02558770652727357, 0.04250777279958129, 0.02996218277673636, 0.035517148806580474, 0.040066366483058245, 0.007319938241770225, 0.027086861797475388, 0.014746002753132155, 0.016123101447841952, 0.01634514015833182, 0.10084377947662558, 0.06151815610272544, 0.04788330702909401, 0.009319429119516696, 0.016398447565734386, 0.014242283800350768, 0.00927303683212293, 0.012624729258407439, 0.07286076460565839, 0.017946450571928705, 0.044476118071803024, 0.028021267282643487, 0.03170308650338224, 0.03748325152056558, 0.04295210467119302, 0.05519286283691015, 0.027753785385617187, 0.007251050822170717, 0.02701199733253036, 0.023705586092546582, 0.05059343356905239, 0.06036540653024401, 0.0029882822169124013, 0.045985373335757425, 0.1112900296492236, 0.09714068139770202, 0.18321874498256616, 0.09590238891541958, 0.141198726903115, 0.10252034451280322, 0.09390535857528448, 0.0937497162127069, 0.1666829822851079, 0.11819968745112419, 0.12145592272281647, 0.11233198802386012, 0.18953400610813073, 0.1044433331117034, 0.11724344162004334, 0.0865128959662148, 0.12781463723097528, 0.07289718158010926, 0.1802839588906084, 0.15993948413857392, 0.2108841918941055, 0.11534800832825047, 0.21179783929671558, 0.09324033997420754, 0.0982034368706601, 0.0944574825199587, 0.14224544859358243, 0.1480958860899721, 0.09013530944607087, 0.10606617853045464, 0.0866867977061442, 0.14135708340576716, 0.10130624858928577, 0.28850201623780386, 0.22627728804945946, 0.16208248771727085, 0.08231072181037494, 0.08334001872156348, 0.12695573403366975, 0.16575067516948494, 0.12740473422620976, 0.09228248601513249, 0.14848396740853786, 0.10763079885925565, 0.10598137522382395, 0.14457038098147937, 0.11292090213724545, 0.06571430486759969, 0.06577518981482301, 0.06447972397186927, 0.12021185590752534, 0.1395823479230915, 0.106745039245912, 0.13761393140469277, 0.12689272527183804, 0.1526749932340213, 0.08715174347162247, 0.12485131195613317, 0.09007956779428891, 0.07636647684765713, 0.08624662525419678, 0.17621994124991552, 0.06515532093388693, 0.16145104302891664, 0.2857170099658625, 0.10874823746936661, 0.1270430072077683, 0.07989515071468693, 0.10189891500132424, 0.1356672958603927, 0.12538751746926988, 0.0908651959949306, 0.15223523468843528, 0.17434600394751343, 0.14666035026311874, 0.18675047904253006, 0.15555648718561443, 0.11759632054184165, 0.11485525619770799, 0.12711495906114578, 0.13074691274336406, 0.15761581382581166, 0.10846707969903946, 0.1879796316581113, 0.10406785897378411, 0.15404578324939522, 0.19537030293473176, 0.07608407735824585, 0.0967315790642585, 0.1004859743905919, 0.143349520063826, 0.13069978170096874, 0.11469337131295886, 0.10131297965667077, 0.1478049981274775, 0.10212902658219848, 0.08293660929692642, 0.17129612474569253, 0.12156910236392703, 0.13828293979167938, 0.14855490145938738, 0.2098550306899207, 0.14096684434584209, 0.11144643875637225, 0.1567603847278016, 0.16637928358146123, 0.1510423022721495, 0.11754329981548445, 0.07179011098508324, 0.18514199821012362, 0.1725060883909464, 0.10991605051926204, 0.0776291015957083, 0.070233633076506, 0.10087028983980417, 0.12281920814088412, 0.13549798780253955, 0.12944564542600087, 0.06544107238629035, 0.08736010121979884, 0.09373971460653202, 0.17841287143528461, 0.11363008658268622, 0.09937927698982613, 0.11383872931557042, 0.1690308220152344, 0.07834633346647024, 0.08661042180444513, 0.10953460527317864, 0.12897186513457978, 0.12565450742840767, 0.1584671445723091, 0.15400165133178234, 0.128410295982446, 0.10911212901451758, 0.15325166657567024, 0.12473172694444656, 0.1431700475513935, 0.16021680140069552, 0.18028280538107666, 0.15790826241884912, 0.13022837628211292, 0.10124973340758256, 0.14409421224679264, 0.15910424824271882, 0.12703827103333815, 0.14193462527223996, 0.10227318813226052, 0.09462193226707832, 0.10940868274441787, 0.08435500532920871, 0.21072576753795147, 0.17352022682981832, 0.14200406654604844, 0.18726623351020472, 0.13083808070846967, 0.2684400698968342, 0.09725497383624315, 0.14274079272789614, 0.1482500628169094, 0.13350071997514792, 0.11687364003487996, 0.10320875221597296, 0.0831151454310332, 0.08364374456661088, 0.1631054063992841, 0.12334348500839301, 0.1280235717339175, 0.1829287526862962, 0.08483089586453778, 0.09291739801743201, 0.1404389983841351, 0.1830459763961179, 0.1231029172028814, 0.15701440109738282, 0.13434150628745556], [0.03519256479505982, 0.020848461726148213, 0.032209799491933415, 0.0020545052248053253, 0.041954542842826674, 0.06408278098595993, 0.031032795685210397, 0.05021846493972199, 0.028677125660968677, 0.03034859150648117, 0.013355719274841249, 0.02887607891378658, 0.039238221278148036, 0.03902152433459248, 0.07509944162198476, 0.041888277112905464, 0.06657474155404738, 0.07911122563694205, 0.010866676407333995, 0.060581085671271594, 0.017852702477414693, 0.029264974474374737, 0.013069240093630339, 0.04520493592800839, 0.02695611658106957, 0.014436424543548907, 0.013009274561357285, 0.047437943784253936, 0.03744994902185031, 0.027915607505877103, 0.05992014506565673, 0.03223598076562796, 0.007556719821877778, 0.0596746171691588, 0.02002397382498852, 0.0365074435248971, 0.017931339597063403, 0.05618704556088362, 0.004022097323156361, 0.05079852756378906, 0.027081267276246632, 0.005243635503575206, 0.025562746616612588, 0.030286580191126893, 0.013747312860297305, 0.015828261018863747, 0.02665666041762701, 0.024814154553626264, 0.04214239865541458, 0.021507865449945842, 0.010263667425273784, 0.029046482805694853, 0.05721310246735811, 0.050534346739628484, 0.019325355866125653, 0.04723496003342526, 0.029799385262387137, 0.05872377247682639, 0.0562302818122719, 0.06882475010518517, 0.052759503945708275, 0.029551058408937285, 0.018482106471700326, 0.043360715066748004, 0.027325974145372, 0.05723953140633447, 0.032654477416404655, 0.040218609385192394, 0.07157469647271292, 0.05675605145682182, 0.054579507892153094, 0.050012929897223196, 0.011932140931354036, 0.020575714397377202, 0.06163106432982853, 0.03329201874190143, 0.04141682080392327, 0.023259288165718317, 0.03117559337988496, 0.018481785863904015, 0.04988675631050553, 0.03858359444088169, 0.01766019530727395, 0.01931148661034448, 0.045344300235488584, 0.032259278265493255, 0.06066901023898806, 0.04358564603275486, 0.07753420168800013, 0.058716878561036925, 0.010891912821015077, 0.012405280007182487, 0.030839745687054734, 0.01699020474084786, 0.01771669861461435, 0.07526713476649352, 0.03455437207594514, 0.0366332507027047, 0.023308110456647615, 0.02784225787036121, 0.04718435149905937, 0.013884560986688095, 0.0747493039816618, 0.08698111227048294, 0.03136923031083175, 0.05019029216574771, 0.054269220613475354, 0.04844257255483951, 0.049574348609894514, 0.04497159452044538, 0.026051442804081098, 0.043914012877004485, 0.09643730521202087, 0.00817569303658924, 0.01760651809828622, 0.050718602923942466, 0.07643214546676193, 0.028312913508021405, 0.029737736963267838, 0.0013093329783129904, 0.03506583480962685, 0.0109324654664046, 0.01675121283291706, 0.040046522726437876, 0.05746407900005579, 0.016320190425696116, 0.03469644034547465, 0.022264577880767838, 0.04293823880808694, 0.037190317774989774, 0.009070852904447486, 0.05851398301976068, 0.017815578130206892, 0.025436566244544725, 0.05952322922114815, 0.050437404441514185, 0.07021517013864857, 0.0451471925979214, 0.017703255139557377, 0.02524055104835757, 0.04994896100834012, 0.011585714029414313, 0.016019845381379128, 0.06434448515730244, 0.03682026852454458, 0.02998950398926224, 0.01822058211213776, 0.04318328155204654, 0.03692131256684661, 0.0688079631488238, 0.061331694679600854, 0.03988639524738703, 0.049355134301419766, 0.03055201969774706, 0.036844135993825536, 0.038466832134872675, 0.05734758132270404, 0.009650097045648311, 0.004248856092869703, 0.009229847230017185, 0.03398212956796799, 0.009558516022350107, 0.015851405848349844, 0.02196381044840174, 0.04870695693950568, 0.02111470529676548, 0.030618516129574606, 0.02780774757931275, 0.012678878897401904, 0.02353117714769074, 0.013529537046062095, 0.029709116356181245, 0.03466466794322644, 0.019391362056402222, 0.03139256173744798, 0.02817363401741854, 0.01776707305439881, 0.03347473465172308, 0.004032383914039071, 0.05791506730020046, 0.07156428096017667, 0.057428089502666674, 0.013062157036204423, 0.020179550030401776, 0.056353323959878514, 0.05043344518968037, 0.01694896338241441, 0.041161905375442336, 0.04380052450246044, 0.06406298811946597, 0.10257293776209865, 0.04553422897255846, 0.015644956479913423, 0.08079176688832895, 0.0459885997697711, 0.030212026155952896, 0.03397026877584202, 0.052265472776655636, 0.021772606065496802, 0.03872527255277548, 0.03452507632651499, 0.10578202842069523, 0.06052427193416016, 0.037066532631537745, 0.04496044958276408, 0.05910440348088741, 0.03209400409832597, 0.028778736280011277, 0.03729770611971617, 0.04038183776927846, 0.030848325762365545, 0.011471989015782518, 0.04308862591694508, 0.008631577815062233, 0.034878413259450874, 0.02551800401748291, 0.026801308816564933, 0.022313413742397512, 0.010781432901109968, 0.013293901341967285, 0.02982043002599052, 0.022309189861906425, 0.03580046431826694, 0.047163629039589844, 0.014163676366609122, 0.03937672384615455, 0.0843046105333737, 0.019003104318731597, 0.03827454548861299, 0.047758571936615875, 0.032286928567503176, 0.06879159688417401, 0.01463357119687966, 0.06189336561198745, 0.07945662710283484, 0.01831830133284841, 0.027885394037834237, 0.039717921787606816, 0.013512020664555686, 0.03580148212079491, 0.031807943912489076, 0.045364262735737224, 0.04675394316603031, 0.0677744389644691, 0.09841837640851736, 0.06720765187804188, 0.011765254395348685, 0.027487027824723294, 0.05161129037982651, 0.060212159396282265, 0.009365997826015311, 0.036534228694758246, 0.05529914516955614, 0.02680121551799987, 0.04169531532430223, 0.018301186983340552, 0.031485721202833314, 0.05327978763463242, 0.05091737975765552, 0.038359467538871934, 0.04485157863902194, 0.09722209881458964, 0.0541886751140867, 0.010540877818129957, 0.0994201587246997, 0.029804789793810675, 0.07721268465476376, 0.03522953138287578, 0.05198449481810842, 0.06358365062624216, 0.06977267709693738, 0.010977987532636948, 0.018673115775787404, 0.05619972738038216, 0.022072382836735675, 0.03896977246872016, 0.01456442678214184, 0.0216930597089231, 0.019752822749848877, 0.07330731528678111, 0.011371561592178685, 0.03925816681502121, 0.04689401654260499, 0.02201558436666216, 0.03946371542822037, 0.03745117038488388, 0.026758403350998248, 0.042525217934910736, 0.053742358527545414, 0.05319235161212938, 0.06369948333927564, 0.03625960860933576, 0.08189966529607773, 0.019877758010157516, 0.023010432054953914, 0.04869596467220357, 0.04419816977211407, 0.022813314239361455, 0.049869762400963476, 0.05871223059615918, 0.03513110648574574, 0.03775138141853469, 0.07374104844140154, 0.06733067027692284, 0.05235070016767297, 0.028954741478498493, 0.04160711594990321, 0.07906446778880698, 0.025450277740934064, 0.08220696023532323, 0.02975309221073985, 0.023260389088786075, 0.0441907771330859, 0.04079889253314052, 0.03058768349832722, 0.03575330274179578, 0.024616215710661242, 0.03834774245374969, 0.06630131229758263, 0.02613621388029839, 0.030655306298285723, 0.0018898801187918121, 0.03532040757792337, 0.01079498154909483, 0.030162828974425793, 0.050489861983805895, 0.05226102837228349, 0.024288512134392346, 0.049218704657895226, 0.02124974563983934, 0.022109571644770246, 0.037078895539577515, 0.028594032262584994, 0.02046995623303311, 0.08152613176831178, 0.029375361943883554, 0.03972537210211158, 0.009058748687883573, 0.04279304927747164, 0.02502126549370587, 0.031456123505319865, 0.017383868706279566, 0.04517159950254219, 0.037644949808184586, 0.024170465700860535, 0.01294479931571654, 0.011018705570937266, 0.02821238854500864, 0.0082289911141353, 0.015688525213460838, 0.03732618423444884, 0.03900017083755561, 0.09627464001200028, 0.09280558223170893, 0.17454876378178596, 0.11478517710098199, 0.1488640420138836, 0.15888643850173267, 0.07968674546905927, 0.09960001800209284, 0.2145512801195894, 0.1072438642648714, 0.07394549782787051, 0.07817478624305554, 0.1240603436848947, 0.14512654899486474, 0.2694849324013506, 0.10202278156897851, 0.17634741083851882, 0.15458615496754646, 0.15518619705523762, 0.23356928676366806, 0.17090769058891706, 0.16651191003620625, 0.12945644770349773, 0.1537447308323213, 0.0931781115276473, 0.1343624730195318, 0.14268204516598157, 0.2128509934991598, 0.1012868085610015, 0.12200364976056985, 0.10195724865687744, 0.07871518510260753, 0.12662251905671187, 0.17465636586504324, 0.14360268147928373, 0.07410026488027402, 0.11353668623736926, 0.10660254010664565, 0.24386478002582276, 0.12873065950615065, 0.11993649282625743, 0.058783137505607944, 0.07612383272498846, 0.1437031996569463, 0.20891604678971426, 0.11069783142634801, 0.11969118884631566, 0.09704537436898265, 0.18045667319425515, 0.11533606611192226, 0.19112171019826615, 0.06738557054528169, 0.10858310240187816, 0.20405259276075022, 0.11510715553803103, 0.11535696499049664, 0.12677653293524468, 0.1589072152440037, 0.15521382700119699, 0.13038049026259355, 0.08503863614584718, 0.10313988091158015, 0.10745790135115385, 0.13696727396122046, 0.19387464890522615, 0.14025869805897984, 0.15725724878055708, 0.13994278572499752, 0.18336083021547112, 0.13937728106975555, 0.16692380793392658, 0.12936933737780365, 0.25714476885540144, 0.15644869288163527, 0.1512116781835045, 0.10265217029622623, 0.12401158415845462, 0.10569667550069944, 0.1385255024901458, 0.1168110112526587, 0.19596582597919873, 0.17565078607627324, 0.09319911218647446, 0.1360324698367289, 0.12619736258472714, 0.18773743536855492, 0.1529806461185217, 0.1579212767205068, 0.21519747615924903, 0.1099107986582177, 0.12810544376926764, 0.06833963827895266, 0.18411727462496075, 0.15492702381951468, 0.14471763665122644, 0.14059580782694475, 0.1306497465286936, 0.1921653649104493, 0.057883060803370814, 0.1208788694015571, 0.0971141846052238, 0.08454960238720689, 0.25282236507960726, 0.21660384855100087, 0.15728196102593625, 0.1890511605888605, 0.13205330978546823, 0.0970909312101347, 0.17027562164834567, 0.15194547309407166, 0.16706790163048676, 0.1391102775399174, 0.2813979445823601, 0.13733647843556746, 0.14195906610361167, 0.10955095796712808, 0.23401893834982598, 0.09881359591547932, 0.13710735073047026, 0.12886566083346093, 0.14115099874990328, 0.07008259796670505, 0.10237663079585348, 0.15639553644827434, 0.15555029894624436, 0.1277258712798357, 0.12821322227162973, 0.10282320861837693, 0.14244192519358226, 0.1043113444798759, 0.11475362522261483, 0.1423567554780415, 0.14469280226954392, 0.18649148222591194, 0.15383222113762582, 0.1181034983268806, 0.13348828921360628, 0.18294533608215197, 0.08959903607943229, 0.10764701584620134, 0.2010766060224601, 0.12104980594345502, 0.1622079759836197, 0.172427663313491, 0.10970057493874005, 0.09891709286187376, 0.11892590991088323, 0.10651131107338838, 0.2338846426989351, 0.14043460147721426, 0.17300257246409143, 0.18377287739089557, 0.09370171664548771, 0.16547407715448312, 0.13390519469976425, 0.07094218648437943, 0.13527378626167774, 0.11925418515290533, 0.16635890038950102, 0.08093799797019788, 0.07309909324560847, 0.06300739119095461, 0.17609914844589575, 0.06453684983508927, 0.0982118710609419, 0.09897090747420277, 0.1238622928836516, 0.10842610296926328, 0.09387802039938313, 0.11569251412791864, 0.09264481692974057, 0.08711630358759846, 0.11499023038361754, 0.0708022793488843, 0.09082039911299944, 0.12271373665758542], [0.030672639475337098, 0.044877695451889715, 0.042545869148203304, 0.02460272134547787, 0.015761886723339558, 0.062390806419508796, 0.04404250366081085, 0.08948668425104447, 0.03876804740035108, 0.0541350572769131, 0.02696999771121357, 0.012175298196130564, 0.019443332749818052, 0.090636271850339, 0.09384484003697123, 0.04259761083605034, 0.03699074026995471, 0.031205632125160525, 0.01647455714243863, 0.010316521062382629, 0.025194922961028557, 0.007889077300205827, 0.031720073627574105, 0.060482969507575035, 0.020480197022802064, 0.027128298234726702, 0.09109769601907049, 0.01718480179884604, 0.05753666189100061, 0.020505704850490605, 0.020758922245087366, 0.02896730794704386, 0.018348713272384236, 0.043215959798544645, 0.034209693249847205, 0.05640855671039649, 0.022752013689439212, 0.006053550592956266, 0.01862522816684629, 0.014050621406308242, 0.05026924650051764, 0.01270078370414142, 0.06614449606942278, 0.07632891993437495, 0.01257764401712588, 0.012143877783923276, 0.015458026867625969, 0.004581356063551668, 0.034999714964734654, 0.02390683109738997, 0.019175508192607334, 0.024399279583511607, 0.026796538715383837, 0.07065065391361713, 0.03560143303392189, 0.027960085476349508, 0.03839403889807207, 0.07590998562851123, 0.01863413054629096, 0.042377280337469916, 0.0682632623772536, 0.05028669163584709, 0.021556558819221597, 0.05829710965710027, 0.041597382365060706, 0.034129982348531485, 0.0031761028304962175, 0.02950889424287847, 0.0495030651135104, 0.03687084313215954, 0.016353813532207693, 0.015836556109466722, 0.05295079653816564, 0.02940443716943264, 0.09781395776995591, 0.05107814845229898, 0.005860001871561897, 0.023564578033983707, 0.02400694045770381, 0.05396927081580673, 0.031336270472300906, 0.02983785141259432, 0.015873695723712444, 0.010590101292889034, 0.03911856162760939, 0.012066499346734157, 0.020638972520828247, 0.03609715036249586, 0.04757262959278055, 0.000936563332548498, 0.03050427118848477, 0.048618540433900695, 0.041107992375535626, 0.004301300488545426, 0.05901433474251202, 0.045757327894014974, 0.007023170773339058, 0.07648183458617755, 0.04925046009676797, 0.08085059587444578, 0.025641706040395156, 0.03955719719773956, 0.04847517276981047, 0.037952522946787734, 0.09247127481337104, 0.01728429538863046, 0.06187453626521996, 0.056461227991219075, 0.012286654274378504, 0.02798633969255856, 0.017688468165163482, 0.033624782493071895, 0.026137323285053884, 0.026828855641984513, 0.07970443487699543, 0.07742139524114983, 0.009677237598225474, 0.040263453764574866, 0.009135904056685311, 0.056534713333738704, 0.11143800456609045, 0.03541417772482548, 0.028204113810456226, 0.02443137768256877, 0.019583202565887144, 0.06718266143330506, 0.028390039190916077, 0.03434114583900996, 0.028494494568024362, 0.019350320865799273, 0.04076925751620105, 0.022389808303809593, 0.04034364303307874, 0.028398139202701192, 0.03459143365866371, 0.010340182426651674, 0.06951079650649003, 0.01611744925113661, 0.02402414132042655, 0.024248861940577626, 0.047477678794945986, 0.014600789473791207, 0.03601746999525598, 0.01766077715105244, 0.02484572509170643, 0.03404248525787677, 0.020689910144678185, 0.01810418621503881, 0.06236993468233517, 0.01294165854674897, 0.0384235924908093, 0.04171267564275435, 0.06101987391178097, 0.018588488888261572, 0.015187997071604644, 0.05928486665444715, 0.02336122278523232, 0.029330375072147166, 0.09289537277072668, 0.013952062498512012, 0.0740038382687739, 0.014330980201650943, 0.0335959651108299, 0.03434339178992169, 0.0451440306247345, 0.03776973579078913, 0.03413702214934996, 0.012120384357071348, 0.050594247811074765, 0.02660323596293373, 0.02642996865324676, 0.03317314279930932, 0.06080562647964273, 0.012155622376927307, 0.12470256350934505, 0.012988401976014887, 0.02324195159599185, 0.041172958710896115, 0.05345162323543003, 0.06135283783078194, 0.02732314126166914, 0.05212478193321398, 0.031170453477118696, 0.08664117979684047, 0.0347210643813014, 0.09235265332141093, 0.0502443171239325, 0.009788207759681557, 0.027383705601096153, 0.013160000937724752, 0.019988813836659704, 0.039975167983876805, 0.01805093139410019, 0.04754186820771013, 0.03635755853195276, 0.0181268577663494, 0.020290163112804294, 0.09985328798315354, 0.03784541619409408, 0.030350396409630775, 0.03187221474945545, 0.04774332186207175, 0.035668964231652875, 0.031011353978621106, 0.029556805600545237, 0.01207458324331258, 0.043754553754947016, 0.04932098702660628, 0.001046033189465691, 0.02352964535488614, 0.09615500750286238, 0.06845736410468817, 0.039085340553096364, 0.01554593616830451, 0.03887850950871195, 0.02402266889943608, 0.03046324696125729, 0.057957034691103866, 0.0524546585178801, 0.08359542608793293, 0.02411419988077666, 0.0337471257496093, 0.015753157370324646, 0.045542846367295296, 0.009977980433697147, 0.038262450601905584, 0.04741669546014496, 0.03673477311219488, 0.04152041274522032, 0.026629532587581446, 0.037395089465592585, 0.09114348356212888, 0.07918842256601367, 0.0009653974661237694, 0.04891320105109896, 0.04470340694699969, 0.033660758419760635, 0.028877734539232085, 0.02711349768963243, 0.0339537091287119, 0.03969581850937434, 0.009682576820653464, 0.03905889465074454, 0.01592962397262454, 0.041939635428466966, 0.054093317195240936, 0.008845457141952855, 0.019960010025118078, 0.036621607041784694, 0.05904102831014565, 0.03841973501922829, 0.04357874193894012, 0.01169927534647286, 0.012596433499961026, 0.048606286091463904, 0.053187812212854624, 0.03961361738454018, 0.06192000489681959, 0.012741357553750277, 0.050727372989058495, 0.09628855676523276, 0.03673636427681361, 0.07519316087876048, 0.05578151232163821, 0.04151107271068862, 0.052809172709073336, 0.041589521536869664, 0.033868824397878985, 0.03807567026732223, 0.021933084686419795, 0.03506531233766249, 0.05817892921290227, 0.016086311279130832, 0.01572702868309404, 0.05559324260268893, 0.037136645655014684, 0.048836146614381244, 0.009683955943078866, 0.02460366620549134, 0.026597001922449896, 0.04457411888454642, 0.05946971316422735, 0.015954672092837945, 0.055489949216800075, 0.05447752068617514, 0.006938068063131401, 0.03171989042311907, 0.05416441409449492, 0.05986069182732275, 0.03516457183286548, 0.03009961325941341, 0.06976210552134685, 0.026143409744171158, 0.040282079550836764, 0.03221597076792802, 0.06416449695825577, 0.02960218602259244, 0.012369516122687076, 0.07065128495118447, 0.0375993590402816, 0.02665736439770886, 0.06174276476459844, 0.016911616814987998, 0.010625591218870665, 0.009286394642133797, 0.01318906174440469, 0.028840187803975174, 0.01689869411555784, 0.047782313876918385, 0.011389798917142408, 0.011388938025837498, 0.06579821929335594, 0.03912842074143035, 0.034517096754695685, 0.018988671878884946, 0.03690229323027389, 0.015872381062113812, 0.010849623125977814, 0.010328350472263992, 0.028638937710119144, 0.04563951725140214, 0.031086447449134927, 0.025199128181806633, 0.005323276430967131, 0.05595681184370603, 0.0186824049201927, 0.020765658401485, 0.047370483832699914, 0.030445442202367952, 0.01656362334532397, 0.03681908787361213, 0.04529792915231415, 0.07190609297582082, 0.015663943586072752, 0.013434013734305543, 0.032335362397134304, 0.05234893597662449, 0.057900967342512946, 0.013272923583696996, 0.06027034377413137, 0.05450547972161855, 0.03585495746561459, 0.01871091526533876, 0.025666433552812253, 0.023375690848167454, 0.035164493801338334, 0.04892671746867044, 0.023704958447654332, 0.0470644000784627, 0.02780497576376157, 0.06716864968516997, 0.08515062156532492, 0.10434955278677599, 0.12008077651262283, 0.2887892265404974, 0.15283868302192005, 0.05401907867885061, 0.22892734727689198, 0.14464568479784898, 0.1581687248711075, 0.11372826381453446, 0.12269316347581999, 0.1005137807556561, 0.08396123110183648, 0.18861894735268184, 0.1539798296455826, 0.15478169518922055, 0.168455695733428, 0.0895792974957398, 0.11901466229132243, 0.06684255254055772, 0.1629267209874732, 0.0744000416515129, 0.13150939611451967, 0.059107626522225995, 0.15426969980554922, 0.1395604041005884, 0.11407728865742683, 0.18985519744455814, 0.12380411529115268, 0.1572253576346806, 0.1578754484653473, 0.09613502464656319, 0.1396852545440197, 0.14650807343423367, 0.07670871634036303, 0.242233256144183, 0.08746304855282817, 0.13979234094066278, 0.08873127800013338, 0.15029227680393628, 0.10266571385519845, 0.23739245161414146, 0.20615531850074018, 0.15344707109034061, 0.1439369956829718, 0.15632689584578785, 0.17010353159691605, 0.10553841399294989, 0.2031343448907137, 0.16567864189190523, 0.07138301032994475, 0.09275728410908154, 0.10636486964566366, 0.10698118300310203, 0.13740043714642525, 0.14432338066399097, 0.1630820512239422, 0.1086468846936311, 0.18977048913283007, 0.09296652395278215, 0.14628950373402663, 0.21223723143339157, 0.12310210296085902, 0.13773016445338726, 0.189237472734281, 0.1230048688926867, 0.13614115757601603, 0.10982478755925383, 0.12612000959260122, 0.19920994261545794, 0.13079031184315681, 0.06816028111747333, 0.08859815621482474, 0.10354546164827687, 0.16899192838796548, 0.13356185598032816, 0.18115042096802167, 0.08295734532709632, 0.12042940780520439, 0.14834116292851313, 0.16060957818159036, 0.20558918959328107, 0.10020646546036005, 0.09772411973348685, 0.20469356408076628, 0.2110391285802637, 0.08279487011688096, 0.10945873148739338, 0.1805133172976119, 0.12269564691398825, 0.1257854646870068, 0.09004078951797315, 0.14222771168819495, 0.1770590040832758, 0.13755040695624693, 0.14732431034956658, 0.14862576765673502, 0.10300145976777587, 0.17455770687333175, 0.11869370165680136, 0.1954853417617934, 0.14820684013622148, 0.16384206472762994, 0.10958339194101946, 0.12681033754987375, 0.2833352977676051, 0.19054570182093553, 0.1823002528399229, 0.12672993115016393, 0.15407353533165796, 0.18512044793793134, 0.08073547562318188, 0.1424032486975193, 0.14217695726880006, 0.13246756898505346, 0.10885699306215559, 0.15894651599228382, 0.08576563892087766, 0.18823562934994698, 0.05808129480906895, 0.14558217168918677, 0.10075673700443336, 0.09048440214246511, 0.2411529469702925, 0.13260259745376451, 0.15046956443360873, 0.18309476306395872, 0.12661057684038365, 0.10360676728721176, 0.11740804064486708, 0.10361674853733607, 0.13228975209806645, 0.20706845021673612, 0.10380125577960696, 0.09841028148574488, 0.1113739169335791, 0.1277515741863421, 0.14186244271695614, 0.12249287350901536, 0.11790197342634201, 0.10000249104840414, 0.10833287904305117, 0.07889610967997994, 0.08751260875059025, 0.1086424131478582, 0.13452666492334434, 0.07416338899305888, 0.16321899316140584, 0.1486135675970997, 0.2281719206699303, 0.12508153888796056, 0.05899897949504001, 0.18310291905488285, 0.12000357279820101, 0.13295295222529344, 0.0952054588124156, 0.16971223402236188, 0.17295481716947897, 0.07169156055897474, 0.15870259622378008, 0.11258350059922252, 0.11370767706206866, 0.1323391358767237, 0.12001769989728928, 0.10716839760009732, 0.14430952497891017, 0.10974246090544121, 0.10695416373865944, 0.16139875512037957, 0.16444815934768744, 0.09909133386931249, 0.08868074071194444, 0.08140713029674121, 0.1924531858946596, 0.1159002815506288, 0.2774672997849328, 0.14792157044368132], [0.0034330496231892277, 0.04588518424757889, 0.03931207981492792, 0.025692784460261464, 0.08816060290804931, 0.0736086866153138, 0.03870136097871831, 0.04635932755523494, 0.020937992725521326, 0.04307808487543038, 0.056209796840058904, 0.013143632128568632, 0.03190317630235638, 0.023818282277456353, 0.017271418490314057, 0.03380326434437718, 0.04662913004202502, 0.009291839037489678, 0.018408269987308552, 0.04949097701215318, 0.03471003479457327, 0.026765838398465087, 0.009129563995104815, 0.01945502051551427, 0.025597574122782265, 0.024323524541354606, 0.018646578271208063, 0.0060621955531782335, 0.024685049695628028, 0.008930330846591719, 0.08953650907746383, 0.05134109095005052, 0.06713751171316419, 0.045789785616632016, 0.04859271199841585, 0.012813674967869051, 0.04438487207517028, 0.002976806281367317, 0.03185179763074432, 0.06398676828082119, 0.055461009698254723, 0.05825007360960756, 0.010913008474744856, 0.018161697146881903, 0.028666577834103788, 0.045102728198149374, 0.013429364073090255, 0.040620749949344566, 0.06489323678293399, 0.015408212219231894, 0.023956535483843515, 0.05007950775325298, 0.055830125963049274, 0.04051716818607279, 0.013077415592436279, 0.03762800678876894, 0.042898792174777815, 0.01914513866151018, 0.06071575451642275, 0.024830183247104287, 0.0730481691924589, 0.07184275851718017, 0.023480487189122608, 0.019172178282003318, 0.03911777791966285, 0.02226500366149204, 0.04813982719289405, 0.025037833622523716, 0.05977794448179858, 0.014897112501785159, 0.02623925281555525, 0.049398550364587984, 0.0523476264040385, 0.05964669545314141, 0.029323196171649864, 0.0038315417893630055, 0.06469777120011193, 0.026498929863529544, 0.06766391918063164, 0.060822657708610804, 0.010447265430619674, 0.028124879579991102, 0.07279228685157639, 0.05233996913635305, 0.04005314862089498, 0.027803527091496756, 0.026114393890436207, 0.024360080615484288, 0.0162737871121083, 0.0454078009352088, 0.023141808308927075, 0.016447919553944042, 0.04924222607431667, 0.03887642979887979, 0.029004115079130446, 0.04711686779877969, 0.01717215560243598, 0.10769225377589464, 0.04286948963999748, 0.04566623117508633, 0.02796381402627698, 0.03405541134998202, 0.05608501085745437, 0.011931848313127245, 0.017912744344877343, 0.01838162391712623, 0.02878656318145139, 0.026823904032685926, 0.02465022218945835, 0.028405119631705538, 0.04830815816032035, 0.03077916268791471, 0.024339157988184264, 0.014342489851904767, 0.008405734219455292, 0.07419089680271489, 0.013105037904876684, 0.011182323264490281, 0.011120922630652785, 0.024937773455998728, 0.013844023608336491, 0.03324201410370214, 0.04163617421207683, 0.011236746861998523, 0.007489119922476155, 0.032354242634028196, 0.034298781505120654, 0.03311093131612454, 0.04137145395257643, 0.05769511338855539, 0.037067431690437455, 0.05719172861427069, 0.1094513897384916, 0.07403072861156293, 0.031475207302719355, 0.020377516014767543, 0.013571544300897844, 0.013808889065070875, 0.017777698912790844, 0.06256121370409216, 0.021685823132949214, 0.055818814784288406, 0.10143730084278754, 0.05627453925886324, 0.04008444944130523, 0.024743970283972364, 0.023978923746783818, 0.007041537019956324, 0.0337187087030283, 0.04002726590260863, 0.048153581097722054, 0.015578068194112607, 0.026833803858608007, 0.0421063446971987, 0.024627092627010176, 0.02019400961164917, 0.022326239750587513, 0.018972380253087198, 0.03586930848125901, 0.04271136723192675, 0.03376214172957199, 0.031218025567276136, 0.06842172066015856, 0.0260585962595152, 0.008878071775792964, 0.07437148889792816, 0.028186024066859057, 0.030272100253828933, 0.017560389591380954, 0.046123078625117025, 0.0066636532345520595, 0.033618461939373186, 0.03769302740693092, 0.025362461738820587, 0.023564930872193406, 0.02018075612639742, 0.031603986463908634, 0.023829987006528035, 0.02235655839155827, 0.017093299655243754, 0.053897746439490996, 0.03272479400038719, 0.09786982834339142, 0.05960858214114394, 0.011285609865028943, 0.008272542036138475, 0.013966084424672382, 0.03092903071748359, 0.036893000693193505, 0.015026042637016093, 0.056327865325978825, 0.04836191509717277, 0.03299700867916856, 0.036676140901233466, 0.0791626043085541, 0.027992940141952465, 0.08027196156659297, 0.03166739895407643, 0.014369331000904952, 0.09194294030645064, 0.051907742329474, 0.02637773672384875, 0.038433081803045104, 0.029390625589128052, 0.03683131507464817, 0.08687287914965834, 0.05193002541948642, 0.015584541418190514, 0.04482887824997306, 0.005202893716549235, 0.01723630939211164, 0.07369538303464651, 0.094637565713908, 0.03303887428981917, 0.09568732045590878, 0.04018749176923718, 0.019915245373600295, 0.03814599024397986, 0.011556380960558141, 0.008282972815712648, 0.02051808811458094, 0.026223863641332303, 0.017324613939438547, 0.0948587002764855, 0.02125240719344999, 0.03188661665522626, 0.05606899403833917, 0.023775714383061444, 0.06330355815589428, 0.03420940147978919, 0.027127999679318497, 0.035906716116837094, 0.03178166425121682, 0.025992103220362748, 0.03204039304650255, 0.038408149033784866, 0.11984396779111453, 0.01901136208990855, 0.029037750060004846, 0.023651591668437635, 0.029775890987366438, 0.023947926570794413, 0.05779052219752755, 0.019334471984101192, 0.06694991713655846, 0.0320722502656281, 0.016885941049882343, 0.010858260028596436, 0.02257505345291325, 0.020804175441818576, 0.04403223064062851, 0.03365042772410171, 0.03280642854848078, 0.035630969663283656, 0.022980084576244866, 0.03391995879688433, 0.008169270702637732, 0.08271147816308907, 0.017570403071918657, 0.0391277422064117, 0.025381224928423762, 0.028100474371707866, 0.043338591432464976, 0.07830989613596882, 0.019453517560447966, 0.047909915779850314, 0.0036663320830224878, 0.06760183322642531, 0.07581410184502602, 0.07499538827687502, 0.05186957812735012, 0.020954640582203865, 0.0019837679491112275, 0.03882031495283757, 0.014663194339456303, 0.0749033246455448, 0.03358907798039062, 0.01786534019213702, 0.04796391359663435, 0.02972136052059276, 0.05761146359145641, 0.00831502172098096, 0.02276324344399784, 0.03422417997249535, 0.13242194429039955, 0.0265212434876178, 0.04117332511980619, 0.04200323112308979, 0.03611205777685557, 0.04754228889942169, 0.01677615238752748, 0.021604504103639295, 0.014570659126288124, 0.038725350584302626, 0.037314781453460455, 0.022794679971411824, 0.037459241558930705, 0.06785281654447317, 0.02187079856438296, 0.006885903139066483, 0.01666856387497059, 0.05378792554672275, 0.034716986385839324, 0.008006794644253594, 0.013648549543826707, 0.01945506631662803, 0.023717541879575168, 0.06548050884157419, 0.06565582193434238, 0.03389646452186363, 0.03049484294440065, 0.00464489365861352, 0.05027006413521511, 0.04904693351792438, 0.013231319209028567, 0.028413365528519665, 0.03730556355523212, 0.04029992162915213, 0.040397549247635264, 0.017099038365163972, 0.01266324969141611, 0.012676435323165995, 0.04859922932726996, 0.01259795087389648, 0.015624829434922763, 0.027101789567885653, 0.030255476145872047, 0.011506667244248092, 0.0199530720045524, 0.08399850303041083, 0.04290189647248813, 0.011457382701337337, 0.03232086549646088, 0.005691363867039659, 0.0671391130558082, 0.031150026180382286, 0.010874018156235772, 0.03902296282883201, 0.019450706729133214, 0.07284106673406703, 0.014964697982317634, 0.0874337697667735, 0.016039928321593573, 0.03860289876216224, 0.01755782642534801, 0.03849017373951418, 0.018228040908330252, 0.03368716361001134, 0.029859727381595542, 0.011354722049353378, 0.005148190647430185, 0.04100333513425929, 0.11241350043565035, 0.18615993644509995, 0.09077239276043006, 0.06889485634331192, 0.15623511719916547, 0.1751736266804593, 0.1597062987940652, 0.1212557413216148, 0.126266925994839, 0.09414458966680936, 0.10423538248453822, 0.09978783649525472, 0.25742340247545925, 0.09391132968344859, 0.17721451073884964, 0.15722659256841454, 0.10312863758632115, 0.0937166851279991, 0.1353295346988099, 0.09320493401693446, 0.24901768352304185, 0.09246660649244275, 0.06706880325717585, 0.19045548380485602, 0.19479120043771608, 0.09546016050236565, 0.0853985311197383, 0.09148562127458197, 0.10526729175554854, 0.2824866133076804, 0.1526269665254014, 0.11127405693488461, 0.12498833531779902, 0.09365520306995936, 0.29243347527725355, 0.2086905153202159, 0.18177833727427892, 0.13025740401021071, 0.14776501884417875, 0.13956367463937827, 0.11959729317043509, 0.197031098817076, 0.07663994003087282, 0.11887936240860394, 0.10488563616360937, 0.10283862493400063, 0.0867872548156551, 0.1367058479892356, 0.19804105748023304, 0.11980299784668855, 0.12117989467723028, 0.17483016582471983, 0.12300404107996396, 0.13104432821273804, 0.12856177214000905, 0.07190440342362438, 0.16038974640624865, 0.0648803785443306, 0.18971275937344345, 0.1721048570637192, 0.24835993881736482, 0.15899238495954446, 0.17517415593777383, 0.13511498192591326, 0.16237602196633816, 0.1001271650727306, 0.12628093095762388, 0.11253474107278244, 0.17077662476471492, 0.14987070299685, 0.11102206259965897, 0.13834444220576966, 0.10441478714346886, 0.1647182841386114, 0.15162367107612745, 0.10108761103557688, 0.25427396861570223, 0.09648157962198768, 0.16741936919944628, 0.2160159522401435, 0.13683034559445723, 0.19621587970427104, 0.09638349738504205, 0.10572512647403137, 0.12169745404805456, 0.10967922822705337, 0.1242079386221511, 0.11670412841652121, 0.08040447267038481, 0.13099037110805511, 0.1215492891413825, 0.1051253897270986, 0.274388569274119, 0.1827594039163419, 0.15482476859220437, 0.14158022643199988, 0.07963570606495653, 0.12489952865455832, 0.10965750153575625, 0.10149742583078997, 0.07155415721769844, 0.14305179246834346, 0.16931895512555326, 0.08217543549835682, 0.18657578341662884, 0.15685950512332575, 0.06880847883543798, 0.11351833865046501, 0.2763321649815355, 0.08540095348975488, 0.11439436807164124, 0.14173224541757787, 0.0985638950286167, 0.1272356840116637, 0.11552984214254788, 0.08568675922495977, 0.09815462306141853, 0.10306381713598967, 0.08333350478538445, 0.08793454896658659, 0.10479632738445487, 0.17667759954929352, 0.15398928842374257, 0.09864941079701696, 0.07306309017751898, 0.13309061340987682, 0.19886019852544579, 0.10744339427245514, 0.06231542117893696, 0.19420804030128888, 0.15003720191972597, 0.1507605066789048, 0.15133724787405559, 0.11308754355247531, 0.18147362076810428, 0.07433256134390831, 0.12256591101842267, 0.11101702108447041, 0.09497966949961015, 0.11796652924801622, 0.11144912575504609, 0.1343642236398799, 0.1363188794681004, 0.14539792229022297, 0.0938871738367847, 0.12362194220934596, 0.09596475306898355, 0.07710200202252183, 0.09500858187675476, 0.10198527215314762, 0.18853923305869102, 0.0720046026898282, 0.10839129412280661, 0.17190482494022163, 0.18405965343117714, 0.19149771359349999, 0.0967569834153567, 0.05289712441819055, 0.13834953121840954, 0.11844850624246256, 0.12371167168021202, 0.1071830200297492, 0.1462297790816852, 0.11209558642336301, 0.0805649326315948, 0.162559036431568, 0.07044049126229115, 0.11476281258676733, 0.07202022935130767, 0.22698308660515717, 0.1328259576112032, 0.1711563601025513, 0.09025832784495183, 0.09074700198003224, 0.0946074862565313, 0.11277672023113285], [0.034661204021956236, 0.06827774231455155, 0.016786834225058556, 0.032386588398367167, 0.022948597158704485, 0.02014309573652489, 0.020339699561840723, 0.05447226203978062, 0.008885456781302179, 0.011676999041810632, 0.03776018201772656, 0.041520942002534866, 0.015773448960057328, 0.027939900755882263, 0.04739346920645662, 0.026517596361892562, 0.01940322115219065, 0.028040306975266764, 0.02969884333599891, 0.018510048543768268, 0.07653587311506271, 0.035648611573768516, 0.04894303623586893, 0.035774028593940396, 0.041502041409590414, 0.033812831688140116, 0.030686556228569577, 0.025747705084670867, 0.03703827164801104, 0.07154297496059112, 0.07219619383769375, 0.021975866319345574, 0.05154981849981206, 0.03852511829297457, 0.004772938729729503, 0.05170745575534446, 0.019351739003988247, 0.021891867076711993, 0.024730299499684145, 0.022412914117532115, 0.046889063236968856, 0.030949519082371677, 0.030983764744762863, 0.008182066176751894, 0.00948241916817746, 0.027162533719092607, 0.08712080227477209, 0.02829937673439937, 0.029069610671805482, 0.022793650294521024, 0.05638262988733394, 0.059388648585549424, 0.018054687085428407, 0.02840588128726397, 0.019492484130231396, 0.024307626465867673, 0.019313863179247295, 0.029768260861081735, 0.05027707340195775, 0.024955179575564604, 0.05311950069985219, 0.007175999760095562, 0.02067743188568524, 0.04835161493558969, 0.01975070741692824, 0.022458067230348076, 0.05193195924428957, 0.04605485871434212, 0.008425849390083125, 0.10148182631071125, 0.022482938931456635, 0.0487895312586001, 0.0018449216607093278, 0.014940184208431413, 0.04825990414246917, 0.04250483813562563, 0.07440933079591819, 0.02229745968777154, 0.02302016903247152, 0.08565287318612848, 0.05613965667518122, 0.07878851438207285, 0.05315727474434035, 0.051531145216098855, 0.05313125292637518, 0.05893550254404545, 0.10725014749914408, 0.054461147636175156, 0.03757635331047433, 0.011334153108431824, 0.057375414829169, 0.0370416032549526, 0.12418199144303799, 0.033026436742927344, 0.03509719330551369, 0.04558436931776149, 0.04550929620329823, 0.021008651969688277, 0.062486344150134494, 0.03806034555392606, 0.0400710585527122, 0.07343687476324183, 0.03593680914491415, 0.019383002504972473, 0.050793299451470375, 0.022103664997432913, 0.03564849961549044, 0.034093222713896205, 0.041709062443780046, 0.015709425788372755, 0.03863342944532633, 0.05328109720721841, 0.06635155103036336, 0.016983958826001202, 0.026578922356878008, 0.04317751061171293, 0.012442389935521143, 0.0726753074143614, 0.051290360279381275, 0.06744081008114985, 0.020611055893823504, 0.0310156253565635, 0.016817085012527447, 0.0565074056919132, 0.029003762240920748, 0.08127925358712673, 0.025009328366390297, 0.06425969542137214, 0.011899539020045527, 0.021144447182970386, 0.03755211264693311, 0.02830015874600836, 0.024714666052854488, 0.014903153159788676, 0.04355089146909969, 0.04597062198445201, 0.009425912468161966, 0.01819988849040653, 0.04451514740607568, 0.06372730327504021, 0.08593122182147843, 0.009541855443135967, 0.03515123522707394, 0.025500667447756444, 0.051173421554267406, 0.03465628803574613, 0.00873109176089721, 0.017211597146732465, 0.016365114532943283, 0.04007097373583487, 0.02364189879569624, 0.03759925047467862, 0.05678041764934148, 0.03663875022903085, 0.05082597769796848, 0.07903806599123137, 0.015967805138123885, 0.03519961138122848, 0.0786928002323423, 0.029102434803332602, 0.01323886027759207, 0.02882331603073648, 0.03707260212727955, 0.028994510415941477, 0.06110562038208757, 0.04938346313844834, 0.009944453170256955, 0.0312666900988136, 0.0026036593065197977, 0.04216983521889363, 0.043705746731055636, 0.01389449049851724, 0.03271356424582856, 0.031769331877252886, 0.04189352897394981, 0.08198441431990691, 0.06453781335481576, 0.011859137348697653, 0.02550965634041599, 0.031077592567141567, 0.010188551054203084, 0.04083311105413096, 0.022524692583829165, 0.014310194977692195, 0.023456475531150187, 0.004396989193212773, 0.01450016612320074, 0.04803680182833757, 0.02061968855559826, 0.03681279785398926, 0.04005283988746149, 0.030381995785449232, 0.022000190103426576, 0.06309832845415388, 0.005566462109397564, 0.01848275786531823, 0.04134224980537381, 0.03202043054625392, 0.014678393523874027, 0.010274989630228706, 0.026644704630598426, 0.014062120878536786, 0.034494158878390274, 0.039252901383276494, 0.07437099356736455, 0.038516836773071966, 0.0382701723304178, 0.05685198273775833, 0.02725035141754363, 0.03359112037079675, 0.023649503476917744, 0.07743776829114982, 0.04556722952319043, 0.038179258815944195, 0.024785333778709173, 0.011686398448156459, 0.024552850717944757, 0.009906808895591115, 0.058879184137497625, 0.051449127295719724, 0.0023908404026380075, 0.04321166127920151, 0.03937664242195232, 0.017483891553378532, 0.027322952968201468, 0.0400712078304163, 0.03601390090105789, 0.01429773707474981, 0.003284378147717299, 0.07225201012832777, 0.0318309225008956, 0.06685064746333019, 0.03435968341571944, 0.06727344941880022, 0.014592647053567427, 0.04072983463161758, 0.006507248368247279, 0.03768228280491062, 0.039992789538311105, 0.06945379277957336, 0.03256639339295881, 0.013158157018811574, 0.027375978783571293, 0.03298392652400902, 0.03351630849231567, 0.02701563767290541, 0.038505668086665015, 0.03433320697929178, 0.03876195076320853, 0.0487330025061965, 0.06256216365311827, 0.04329790986542191, 0.010587272650030042, 0.03661776314090405, 0.019830150296911597, 0.01897636494998421, 0.07828285651547567, 0.11586896037416798, 0.02348650579473802, 0.030234872430030788, 0.049720488089535914, 0.05274680516283427, 0.03753639777590122, 0.03243971769032734, 0.011207329824433794, 0.05267920611160142, 0.0222914071554052, 0.037593133481485505, 0.05930864930685077, 0.032924334185996225, 0.0214706596785358, 0.03923800075426698, 0.01984028421741511, 0.03985477212284293, 0.06372930495334522, 0.09473222134900944, 0.06840344092675618, 0.03445105154865554, 0.03912297889058079, 0.02598946202280266, 0.024489143065043857, 0.06419034235711608, 0.012466879112512937, 0.013023375367213572, 0.06747571392250912, 0.036064292304217815, 0.03198324343455689, 0.04275187237986496, 0.02722002429488514, 0.056482011518840275, 0.02114609263039061, 0.030651615067784275, 0.021580528068755354, 0.04225847903372986, 0.040222558459000926, 0.034746190533041954, 0.04190851441983666, 0.01999759577613856, 0.02378887796242322, 0.05295489828235336, 0.033389500475355556, 0.03213097407881703, 0.011818618630059063, 0.029476545085864406, 0.027060914618362273, 0.017025508917868137, 0.06648822155381952, 0.01932782064458089, 0.021851936987202083, 0.028803845468376364, 0.02134361756699426, 0.0474537265087877, 0.05533634585195354, 0.01183300866146705, 0.04580412306157606, 0.01014319438088153, 0.06566436469022717, 0.04490363584565265, 0.03899099365142839, 0.03723357777510371, 0.02502117389147835, 0.0314910985928561, 0.024269299415339316, 0.07764489789094244, 0.03557049522974661, 0.017014333446111, 0.027330739157540456, 0.036150853016546795, 0.04200274597055145, 0.022524763830006123, 0.03263989230617881, 0.054128037832145176, 0.03380822782803859, 0.036231819207647016, 0.07295064335422856, 0.07877134744610105, 0.018575014879128764, 0.01696482244213777, 0.04151133055399571, 0.04975050987143602, 0.03386662933709366, 0.04345287708565593, 0.029813478434724466, 0.024570633424445987, 0.05674035015649029, 0.03891072974407247, 0.034305482038429806, 0.051341226657054255, 0.021146455646625588, 0.03209830940301929, 0.021787991847044656, 0.0611370840509023, 0.2174811807594129, 0.12909834406205586, 0.0759884174913168, 0.0931806628193174, 0.07846652915967361, 0.11088962613471917, 0.10335500365389244, 0.08432337881198951, 0.14530872207667145, 0.11488490817802292, 0.11939179205468722, 0.11821430309542588, 0.08702374462570463, 0.08524748243923698, 0.09885237419179507, 0.10274836620582001, 0.23898049497178622, 0.15476261478449616, 0.06394960491784982, 0.09704912666763578, 0.2137738282659224, 0.10522951771106039, 0.12190942838788033, 0.11248878389596939, 0.11712623148092202, 0.14605715977294104, 0.1619376747735909, 0.13207244447299413, 0.14431441043104443, 0.16242859485958303, 0.13979852918003285, 0.16696739702352456, 0.14021120060767445, 0.12269780465534755, 0.10475530994257756, 0.15678076791976178, 0.16736340363110813, 0.13238869607448578, 0.12184925590242658, 0.11110012126820427, 0.11358081815498215, 0.09698222990014724, 0.12789648212492466, 0.13879427021103247, 0.10183455595480544, 0.09778849235070602, 0.21098433009215764, 0.06779703418059008, 0.1253775701458965, 0.08858735393732786, 0.08956610677497727, 0.11272715324802057, 0.10072374663182668, 0.17338563262351922, 0.10389846270637852, 0.08838688755141837, 0.08042342415345566, 0.09217254977141108, 0.09273420713309731, 0.11171945410647563, 0.09994501913232462, 0.09676437944705997, 0.07632279276315655, 0.1510022822767496, 0.10570403760565178, 0.160815798544458, 0.13113052930150712, 0.16162613220512867, 0.11385084795100348, 0.1451338500316654, 0.10008533338883094, 0.13341270041252884, 0.13965808600187302, 0.1292520458144801, 0.2303105816245079, 0.11908008663782052, 0.23973163323743002, 0.10604238230735064, 0.11237700882234744, 0.17293489538133144, 0.13321093123938355, 0.2319859117269516, 0.24053998557584627, 0.2139466375644718, 0.17910405434668064, 0.20234246738255024, 0.15520396110202583, 0.1344874863113676, 0.057489178010395596, 0.14025453185396536, 0.08751190307417087, 0.09746214414813689, 0.21477442314582212, 0.09385153717760529, 0.08556618355214596, 0.10173968318849802, 0.11127297127885477, 0.08837533888540097, 0.16253365922187055, 0.1804086057735341, 0.11654570406036717, 0.10390508520816054, 0.12885696201452188, 0.10749380942434072, 0.17893070222011634, 0.13777851685881615, 0.1585055903664657, 0.11774688746247973, 0.10966225806623697, 0.0982403898877757, 0.22295120438294752, 0.16342726270002977, 0.13845360491956982, 0.11676792427897453, 0.08222912797438246, 0.13382356693702085, 0.046404724940657616, 0.16931670238929136, 0.15356483762817724, 0.13107809211526597, 0.12507094017096929, 0.10770676085459334, 0.07265110407024622, 0.14471095986664295, 0.09360042493790388, 0.14336896687746048, 0.09008903335779905, 0.1387072005974395, 0.07997962153915848, 0.1695143867816244, 0.08677593006619386, 0.14578480938715593, 0.11845541372895241, 0.16473633317010744, 0.12035737452762467, 0.11447934779737677, 0.1463136188685894, 0.12824116434369767, 0.1600306113915784, 0.14323711395263672, 0.13776899022715433, 0.11310156208596059, 0.12485573600445475, 0.09515116922557354, 0.10532231416021075, 0.17648458347788878, 0.11475893136646066, 0.22563088844929421, 0.09611141162791423, 0.10161367245018482, 0.08895218186080456, 0.12655995812799248, 0.10885885224810668, 0.08353950123169593, 0.18501157020883902, 0.19437969609030656, 0.10068817104079894, 0.09936235432646104, 0.18420176580548286, 0.2181672610874687, 0.062336401481713564, 0.10204281192272902, 0.14001169774149144, 0.15889116110546248, 0.08829730057290622, 0.10125176901263849, 0.11770502185182911, 0.09612635296902486, 0.16368530956762178, 0.13464627707643168, 0.1957916867520128, 0.10707298879112516, 0.18953966509018624, 0.1780269614287785, 0.10547853327755417, 0.29630791023373604], [0.020230830314436128, 0.023809357845623578, 0.026738354337534735, 0.03893836986805711, 0.02296203384841127, 0.024391700347353305, 0.04055603467194097, 0.036856726211096556, 0.07940585232738938, 0.029162373194204907, 0.011125165170856884, 0.07995774557015725, 0.03118539821090443, 0.04769082021500383, 0.07115340086498431, 0.01687514046872301, 0.028401767668713416, 0.1487563992185252, 0.024669053232563392, 0.005658797578819628, 0.027741186686658433, 0.03882997050615294, 0.015249553768496429, 0.031112957812313522, 0.057904034320797236, 0.012422357885433095, 0.03775833300980074, 0.02146667498163879, 0.03900662370558296, 0.06222661451569625, 0.037184394164276977, 0.04532482288777828, 0.030066409148275852, 0.046367775316217115, 0.07552166682268892, 0.08207543300730841, 0.05103699191074286, 0.01922278172735657, 0.0023314967901179834, 0.05825580723051514, 0.004330135682331664, 0.08694445780877556, 0.02720099817296224, 0.07317625624792916, 0.014538552545543228, 0.07230522084449019, 0.022007723538471118, 0.007548453569013093, 0.0620873248470681, 0.08544864771621567, 0.06010038432266031, 0.023063598666340113, 0.030633314978331327, 0.005306789302267134, 0.0248652448478554, 0.007683081702063126, 0.027270259634990777, 0.01734197765056576, 0.05129255873284169, 0.07380852874900613, 0.027238276886886785, 0.026568371137338023, 0.06743260659277439, 0.06512087849634034, 0.008323195523449352, 0.10806134968463864, 0.015279667152624046, 0.03343617011393819, 0.010850779180015837, 0.04305317585489579, 0.04746518696525267, 0.0368901406680899, 0.02834868078519191, 0.059909783835921965, 0.0351288130373827, 0.028776585324002162, 0.06257352232933044, 0.05399939098528453, 0.09454314756606307, 0.0928156381206853, 0.046361861883529594, 0.0439505044903074, 0.05213327719164746, 0.01339745766017586, 0.041052315184580426, 0.04952674937833633, 0.015109577083161898, 0.070637768533613, 0.031067014206200838, 0.02793113069076623, 0.14688706238354954, 0.05166739844051855, 0.09072476638747112, 0.013194991292298903, 0.05640049571437495, 0.025779994869870797, 0.02387435980407255, 0.035802421891795735, 0.05751562052007232, 0.030477903317660093, 0.03225649966459189, 0.0394560717312353, 0.0356487167466964, 0.014311519817316105, 0.04890219182042139, 0.09721515061599867, 0.02942190266081265, 0.037782617778118165, 0.10421493822442633, 0.04438966592507703, 0.03389344164835555, 0.06538767168032271, 0.010693421820178628, 0.03179004415869713, 0.027338328571724038, 0.06916578180555787, 0.02180111132163022, 0.022920909537268535, 0.05794912297278643, 0.038147530518472195, 0.03456991731322237, 0.04561044881120324, 0.049440762028098106, 0.029053213873079846, 0.021251899988523552, 0.024739149292664867, 0.045036303012498786, 0.027263754180499485, 0.04341680955673967, 0.0181083337603403, 0.011405713107836033, 0.02864088849829776, 0.01918032579123974, 0.007127949302749974, 0.03904939176780837, 0.02797542715312115, 0.02318097504654101, 0.03606559169877853, 0.03994140747402396, 0.0572256078677518, 0.0268249472802771, 0.06488270591944456, 0.02086612399268363, 0.027645559050142765, 0.03740660081218396, 0.04081273125484586, 0.07243623238589082, 0.03949134198150464, 0.07269640985344138, 0.03909425311056631, 0.02432002330065838, 0.052239505241491964, 0.04612062232834952, 0.03988308399649603, 0.026679421874827573, 0.002546035568229854, 0.06497914610164506, 0.024905870435759425, 0.017417498598141328, 0.09332671069673129, 0.03669863094442657, 0.025369798398709724, 0.07264047821185418, 0.05061955716727035, 0.02013498724305204, 0.018196516171363846, 0.039598187498216114, 0.036647309948291094, 0.09387325029820204, 0.029039256407746246, 0.012330583479654576, 0.04152626171708107, 0.03954309045470186, 0.020967573459659303, 0.021684674712430154, 0.018380439873518686, 0.023739151523581574, 0.07548693261508431, 0.09099035177912031, 0.03295036278931158, 0.04203632327594927, 0.007171205910188811, 0.027384940534830093, 0.059414507555110116, 0.03554411378822156, 0.008038101401845259, 0.0739240086238299, 0.10132539684751204, 0.04312906660405653, 0.014787088048511317, 0.025820846070668528, 0.018118988456470624, 0.02248654534508075, 0.11825310172779219, 0.05620304202394826, 0.026030420092865825, 0.010762741805852523, 0.0006534531837262746, 0.02413042534941009, 0.03275949088856578, 0.05323035635852388, 0.048905906799648485, 0.0509550893413169, 0.027398445078038743, 0.024326089403725097, 0.027863529943195835, 0.009920774842612445, 0.06509487024907555, 0.023576493108911172, 0.034090881768081865, 0.01529421833609896, 0.021004836906545928, 0.015623446919822266, 0.007040381814087076, 0.07110618161303656, 0.03036577201315335, 0.038971336491938145, 0.10741238522210292, 0.05870033587728228, 0.010201511921228042, 0.015566782460414937, 0.05930079187133482, 0.010342422440381987, 0.07608759216964245, 0.011495420526313995, 0.07705368354384388, 0.03653878166473337, 0.031668226766799173, 0.046659704829965315, 0.006736130952568991, 0.029143068872924362, 0.022866967699623535, 0.0026076781422099365, 0.06426437731300082, 0.015520099251131927, 0.04255336017480918, 0.04836493457800575, 0.027128627324210744, 0.024480618968872086, 0.041264533797012906, 0.021607481176033616, 0.029033773844795566, 0.07390670598085437, 0.030621647568685666, 0.005947459946453039, 0.08331196129854236, 0.053444407015506706, 0.028522708054099764, 0.034831424709409475, 0.010460657167381473, 0.04638299824936049, 0.06369149698210613, 0.03363275867221611, 0.01878988147447152, 0.0677408921931471, 0.08307929164064781, 0.011633160590593303, 0.0503287574143282, 0.05693982248859746, 0.02215926754953606, 0.04054252503971968, 0.008093209471553564, 0.0463300318058048, 0.04259124278490033, 0.020273177684949975, 0.04183325470824327, 0.07949238589831761, 0.027124842795144235, 0.030933010325367962, 0.026441061004464115, 0.0647282577784998, 0.06893720371382576, 0.01039172479483698, 0.04327103648600834, 0.11107002824012722, 0.02724398675906871, 0.0423956143536738, 0.02704772729027484, 0.02284861502370664, 0.030666152680558816, 0.01689210214785167, 0.0526756030906524, 0.02169380779378116, 0.05097609678549426, 0.012254664740924324, 0.050464511915509186, 0.031883743059422286, 0.01789669699168631, 0.02353440527804196, 0.02478093178277569, 0.008214119322864073, 0.04834173546571817, 0.03377108142844268, 0.044068277813494205, 0.12419335011925016, 0.07117391297859804, 0.019280285873849477, 0.07098825222679547, 0.029083218691604476, 0.0216742846449571, 0.06809442250856332, 0.015090717202318566, 0.041447714503322325, 0.042425096700234075, 0.05662964377552271, 0.039408818552536626, 0.07001364523810999, 0.05115655317370381, 0.016094207730410353, 0.028087019022288065, 0.046435496503753323, 0.04287894502548235, 0.050605511492384334, 0.01783487057712461, 0.04226282165784921, 0.02522745362616011, 0.026585147915674106, 0.05803104250558785, 0.0344918382886265, 0.005220570401953799, 0.01878670762692179, 0.018755433947912285, 0.09016293939203024, 0.044484742251890044, 0.08518882987222501, 0.06095093475388629, 0.009456734921384071, 0.03146055433899164, 0.06116378440388611, 0.029017689172178507, 0.017856195236423185, 0.02754074235313705, 0.04925001226365566, 0.012844970699266663, 0.055416857424591265, 0.030426283766116415, 0.014520193084276148, 0.01711828331463039, 0.07516133080103568, 0.03165959580136197, 0.007207046129873821, 0.05474169472498553, 0.02406494502377297, 0.07485045319689171, 0.054606391449591944, 0.023218906850421002, 0.011859369746941541, 0.038613334630749056, 0.03016467798235161, 0.0464507703270231, 0.057374648084597926, 0.01828473759815097, 0.07416003024471657, 0.1564815475472382, 0.19647716996925219, 0.12079748591142041, 0.12489450749542032, 0.0786521899114762, 0.11275938366140638, 0.1716622079589537, 0.10476682468184403, 0.13734612720353262, 0.18793456336217268, 0.20404322897749289, 0.1295864957251719, 0.10432551907641546, 0.1515573374927044, 0.08180319797247648, 0.1902319879404136, 0.23253224098256656, 0.16587142726140364, 0.08881076837756804, 0.10080566616462809, 0.09656990452536515, 0.09255445642130715, 0.16448560091001646, 0.13923290238848754, 0.08853533065744809, 0.09714716819248029, 0.08575779505606208, 0.11021629547966377, 0.1579378872577633, 0.058992350207907815, 0.07175809770290341, 0.13879971206188202, 0.13709908617394312, 0.10832884854504041, 0.19999084142701967, 0.13552986537771566, 0.11079349807862725, 0.19528395256825856, 0.15556165762245655, 0.12907927722803184, 0.285752320928233, 0.15529677112187656, 0.09289385963763509, 0.10559278500399419, 0.14549939041691168, 0.12331684572356087, 0.1398591087864978, 0.13973186989980085, 0.24039480622325624, 0.10733401442744903, 0.10070713609457016, 0.17177812888153962, 0.07295739477766411, 0.13449499090867384, 0.09210204319762332, 0.1271354236773082, 0.23234607811485017, 0.16053360940090247, 0.14154283915247234, 0.16797508937971933, 0.10667996773762362, 0.09689936720366989, 0.10334786546549626, 0.08229963454817023, 0.10996175663811819, 0.08375875625227179, 0.137136704155377, 0.08813692203589849, 0.18444863041596754, 0.1615664754062891, 0.11852750128933362, 0.1445833681417363, 0.14102741038160665, 0.129008003909673, 0.14023664567087377, 0.14904447804604257, 0.1347116878522294, 0.253169802150556, 0.280458716409547, 0.13087839925927774, 0.16229018728647912, 0.1343318982315915, 0.10436754075012036, 0.20184872459088052, 0.12549035623669624, 0.1601813140192202, 0.1828861813992262, 0.17981004289218358, 0.10396270640194416, 0.16957739554345608, 0.14783091816518987, 0.1301461649792535, 0.17011301751647676, 0.15638214216700622, 0.18304749631455966, 0.09842456464788743, 0.09334186238369771, 0.18350808588521822, 0.1759844081742423, 0.08812156678842646, 0.12576774135231972, 0.10326534203652825, 0.08168147557548114, 0.1486318337598017, 0.25085838618023054, 0.0953863901751382, 0.1606759253357138, 0.11972951250416891, 0.15462184590952738, 0.1418549381196499, 0.17218552130673612, 0.15113671363464423, 0.1235611183302743, 0.14107097232980387, 0.17456735564129694, 0.1442069440547909, 0.10834583227655717, 0.1915022869195257, 0.25718447672469275, 0.11343414602535111, 0.14602533648056643, 0.15508889513356344, 0.14785291627049446, 0.14264488858836039, 0.05552690223391567, 0.12693419733217784, 0.13561797993523733, 0.18221056408115796, 0.09259972827775137, 0.13082676274435862, 0.12596571072936058, 0.07926015728818518, 0.10914097353816032, 0.13791326034281934, 0.13059697007494314, 0.18144657436226094, 0.08575882642929043, 0.08441048235233341, 0.1397860034235886, 0.10744540273611035, 0.1900167159203972, 0.10019292868673801, 0.13384198237742695, 0.17842233021344456, 0.10492535081825086, 0.12405723599450928, 0.09823811679546322, 0.18014381426785672, 0.13708795819963726, 0.08499490456389529, 0.14312378503382206, 0.20860392068113598, 0.10125670196222407, 0.0958556921354362, 0.1352031779076372, 0.16453110346836702, 0.10352805043969836, 0.13639497038509163, 0.14737187565437385, 0.14846177931342805, 0.11719241578664098, 0.18906257354787417, 0.11015135967837912, 0.10602242659245219, 0.15597910593662942, 0.12678035987274988, 0.1243774773819106, 0.17930727558476584, 0.15162468887865543, 0.05743678153625556, 0.14051295870116778, 0.1326600829405444, 0.10947610198387078, 0.19043273931103094, 0.07317539450845548], [0.01813361936781023, 0.04909216466226748, 0.016518019006720612, 0.041909630609942336, 0.01893916426758681, 0.04348904639482498, 0.022902824882684008, 0.018757230369374156, 0.006783228492297764, 0.035395304273281775, 0.026146308785038333, 0.050761557583298, 0.08441517102931227, 0.05591271385284407, 0.04616186707945807, 0.019027575684179152, 0.03989408304914832, 0.03027757942410452, 0.054101714066096714, 0.11128848937473126, 0.02715442861829485, 0.028576237681720938, 0.03303116952468242, 0.027428314189559648, 0.04655283556452819, 0.004631928974829082, 0.02408977092376777, 0.026837656241176382, 0.04725726008681314, 0.09647949651948043, 0.03639655393947448, 0.030999717103051286, 0.062426911267851076, 0.02496608024063919, 0.0626970496294754, 0.05018563741551978, 0.021455029624381235, 0.029637110220002275, 0.04833858027788145, 0.006026463475011821, 0.10716818725424153, 0.07312515577567474, 0.045142632842596085, 0.09210961564843144, 0.02244722593708762, 0.08755264910204069, 0.02180432079226843, 0.07567450005028929, 0.012346891220659018, 0.04625882973362293, 0.030803223539675986, 0.040053735553686104, 0.06501058941440922, 0.05238501707624112, 0.02346761029080621, 0.02884753294555204, 0.039104556664824486, 0.04117711813056043, 0.020389453142083118, 0.023756125077073063, 0.03308088917817388, 0.03459989499034626, 0.03544708667322993, 0.025501992287380353, 0.04964438020916922, 0.03996692378340023, 0.04511995280959776, 0.047788054283176146, 0.03836483475086944, 0.030278013686516454, 0.06108214985579252, 0.029541372321546078, 0.07766038206006799, 0.032197246594088416, 0.03148895442219717, 0.05803462517048631, 0.00788733600971422, 0.007153373161729957, 0.04847911505826882, 0.024350464077932493, 0.10673863387533597, 0.02206934299985213, 0.007554717295403991, 0.03278596732499344, 0.025650462534810816, 0.04290505166032484, 0.03082412920360054, 0.010967125035157161, 0.03567951884386795, 0.0692006042227149, 0.03876268358102866, 0.02636106851111565, 0.031859929872942824, 0.08665059107754912, 0.03048864791968039, 0.01528308357644294, 0.039191653419818194, 0.06807025309119906, 0.058805298459317, 0.029672838481409208, 0.04487654533503311, 0.07097122778317758, 0.032449162897786925, 0.08883303111152989, 0.013928655584874963, 0.04445466957986355, 0.05208525726837771, 0.011927257175557315, 0.013656694508556808, 0.05537603336519428, 0.05424658129257815, 0.008979864751121827, 0.015336282418242522, 0.008648604803186442, 0.024446391966193914, 0.030327187119317905, 0.020282831541927795, 0.07640210672148637, 0.025859137498108403, 0.03111047437414527, 0.03838144189545086, 0.0490701665569629, 0.007199730674204017, 0.024177513983366743, 0.0744661038209285, 0.05844297433005912, 0.051606126728334596, 0.018211498224575604, 0.014888076111674309, 0.019493364529418092, 0.013301187111730022, 0.06510204914957285, 0.02631444636998432, 0.06679513651345458, 0.046666086451815705, 0.0641283785392131, 0.04567536086376224, 0.018539254387308444, 0.04606575259406652, 0.03431113762781024, 0.026215471859489168, 0.07370551356247493, 0.018473475506263118, 0.08123721834272146, 0.03572486873183932, 0.07671534562749521, 0.09390874446502753, 0.0501981801353395, 0.06432665325701237, 0.044126662359173806, 0.030951880384236574, 0.03318697812833956, 0.035184829495847225, 0.05163657598729644, 0.007979012027915035, 0.0197289654585932, 0.03830518813005515, 0.025916356659893478, 0.05692530183919838, 0.0959415878834469, 0.009939831498611187, 0.041059399090175114, 0.015053675975650549, 0.03482115508190223, 0.03144629153289965, 0.040649591080312214, 0.05495065297665341, 0.051381691092891354, 0.04688841523602605, 0.04898858968434589, 0.045855335492108545, 0.06331835021930081, 0.02991460050855364, 0.010816886355834348, 0.020473270876599208, 0.026890620988394533, 0.0325667496238436, 0.017738372719447528, 0.03659943930272545, 0.04585268581286073, 0.026072704698890448, 0.03258622018620372, 0.028925920703581402, 0.020312247731323754, 0.04676974285393953, 0.05023671753172364, 0.015079970903960722, 0.03751026060698288, 0.037346523321632824, 0.021983447251841426, 0.025381375902465413, 0.04094999210376825, 0.049133860639163425, 0.015011868040476526, 0.05486413976177573, 0.010369037128319698, 0.012059028676178838, 0.055482359802616496, 0.01708505884744227, 0.034398604184389114, 0.013517006200605204, 0.019482889645067707, 0.11078751339976277, 0.04784232351396765, 0.015391067335648196, 0.048003960733434985, 0.018538977884288346, 0.035759487588490756, 0.06313572930438177, 0.047066204981612306, 0.06624092268092291, 0.00827419596524643, 0.059261925385466645, 0.06268229149281979, 0.045456282262291224, 0.018431979697197676, 0.07841130997985601, 0.0284311448423458, 0.06884936735566173, 0.07488378962235791, 0.05851349447454725, 0.01868491041074906, 0.03180420518453632, 0.030293063593230078, 0.03303847734683326, 0.020757899353546754, 0.04987465803112302, 0.01520905370957085, 0.0418410205415317, 0.08226525317877531, 0.02268465212546289, 0.02505678340925702, 0.03242340910115412, 0.05100518558174372, 0.0374478964534189, 0.021815648934404765, 0.04852993733116558, 0.03288893162139824, 0.09334743315620081, 0.06794951456998076, 0.02010412747040391, 0.06881417852959462, 0.0010592762846499681, 0.03008425122659121, 0.028816004815910543, 0.05387577886826225, 0.04165900691545435, 0.024718854310257093, 0.009706215284365629, 0.027621381151090776, 0.017568667718608464, 0.02485513637241508, 0.018648374692669938, 0.033334552709545405, 0.023434338326166784, 0.049268760186220915, 0.10263795498758554, 0.013225663619648134, 0.027048373594880104, 0.07558263997946467, 0.021350581032623137, 0.0455499743776662, 0.0138573101721704, 0.028507301916501353, 0.03235831045146499, 0.024165300353031074, 0.021925802309332148, 0.0047382113074750775, 0.07964675940041031, 0.04676543415657111, 0.023099542362615466, 0.06282428173082215, 0.03170126124418207, 0.010727462225726672, 0.07172343134880066, 0.028453259994941096, 0.018876527003677826, 0.0764519926160574, 0.03745526534372142, 0.0054611780713977555, 0.041658776213548014, 0.05440333305991121, 0.021542287531441877, 0.028053445109565343, 0.0038443533786838608, 0.04794359486550093, 0.043109266952212365, 0.04461405745574406, 0.02829091709905437, 0.038536799273320606, 0.034921425594283004, 0.01155132841917553, 0.00797609517550362, 0.05683594895526767, 0.029525148549250195, 0.028584403850670372, 0.010631858337936657, 0.027542072281773602, 0.014513446749853236, 0.024719561683014035, 0.0443236105410116, 0.02271467730003808, 0.021542060222210627, 0.04948499572596379, 0.01975948766006955, 0.010708293611449855, 0.0068170462535428146, 0.03523122432774731, 0.048514734754072766, 0.01923041185364127, 0.08998835911708218, 0.028088676344071115, 0.029960761245872294, 0.023602552246302366, 0.0177640891966543, 0.040976112309311113, 0.04246644662427051, 0.09090182331523725, 0.03410903597250581, 0.03744633582287601, 0.02182658013355519, 0.0321061871945858, 0.12355471295969826, 0.03005235668803964, 0.04740739953038948, 0.0716951907213245, 0.042534483330590386, 0.010517718569774712, 0.015797655696847608, 0.04196076161627259, 0.02867540218202131, 0.05863384623080492, 0.017526949689324414, 0.018586097052320838, 0.021568007401323745, 0.09278276309903179, 0.000979051923163102, 0.018836973501103263, 0.0504993479033666, 0.01834329347392278, 0.036939656761075766, 0.03339908138981887, 0.02433679159730673, 0.03597546528492655, 0.034624556345599036, 0.035801767105502744, 0.06077499740890094, 0.02187638121124889, 0.01588104256162686, 0.021989677899650166, 0.01209475439307945, 0.02184857993519732, 0.08625039112355028, 0.1606014629027673, 0.10436422949922936, 0.13542083837091923, 0.11124566024435417, 0.10211411916783877, 0.1175611452864749, 0.07414055628968136, 0.13483971383954796, 0.14086851105093956, 0.139008456575019, 0.1695288395775216, 0.21434994520885603, 0.10845087628279414, 0.17352712074560778, 0.14205734511571272, 0.116136031757508, 0.1201436902795519, 0.12292298328663621, 0.14328098802694253, 0.0475165283174387, 0.09640069824776479, 0.1698618374232735, 0.09004225515361343, 0.11688931419381074, 0.0811907590499946, 0.17800512617187841, 0.1614255436829158, 0.20753575728407928, 0.18091023314212049, 0.14637665477182182, 0.08963402134499379, 0.12492472944515091, 0.13206901108579977, 0.18881748669913836, 0.11504916793533734, 0.1273861559373992, 0.1470308710954019, 0.17461002192326955, 0.13177998230925628, 0.1598505824804306, 0.27535005339554375, 0.07090705194111381, 0.18811012751289777, 0.1469672109399523, 0.15536040413592542, 0.10191589194749083, 0.1400539840438536, 0.12676825480801718, 0.16355760927711213, 0.08863918044205223, 0.11907719607864108, 0.38896650820970535, 0.18689436917858465, 0.08204389469964163, 0.13586039335599967, 0.15932398502315792, 0.0923860508150288, 0.1716564404112952, 0.1297812895583255, 0.08630518282630614, 0.09305909648537636, 0.1482438745775393, 0.12578498971249374, 0.14448811539581843, 0.19004625933510916, 0.08388347777404956, 0.2165708988904953, 0.10994235732193504, 0.18641722335347108, 0.17330625759703772, 0.10015516821295023, 0.1531425988567727, 0.1954638457724026, 0.11152784260255949, 0.19281348798956188, 0.05955264371420656, 0.08169995886938912, 0.1302672970507826, 0.10681612257446561, 0.2953265043241637, 0.11209507752209902, 0.1203823581870113, 0.15359455746199402, 0.14819242805242538, 0.12898270812417778, 0.0752540458259838, 0.08054892599050488, 0.14903800482196466, 0.16036351424242767, 0.1231127559606518, 0.06010065573666777, 0.15336688182183675, 0.17609115530337605, 0.11444490535983018, 0.15396587896559918, 0.1141710350556033, 0.14321682575557912, 0.22450152119355543, 0.1131675224751234, 0.16623577342501708, 0.18390823155641556, 0.08081187188093152, 0.19104251159088953, 0.12598620248692377, 0.18127166160515376, 0.11656771573637213, 0.07536006692264761, 0.10719819885811635, 0.11330413193042789, 0.162295968404838, 0.12859901014183248, 0.09356404189020395, 0.11596656085125037, 0.16758719805095876, 0.11068974328892571, 0.11220019616718803, 0.10954709031752177, 0.08374015082206045, 0.09999150556645223, 0.09320980589836836, 0.178813600646598, 0.08872019752327885, 0.10159427313400166, 0.14569674911243574, 0.11055198032408953, 0.09098623307155711, 0.10459537245333195, 0.06494142633995839, 0.0988212294344391, 0.0906986224332026, 0.11537759245506354, 0.1574144789150783, 0.12273441840495382, 0.13220105400042875, 0.153837866548981, 0.12181775830686092, 0.12296609740172114, 0.0937088548338839, 0.13622366743428366, 0.11327973181115729, 0.2173961738922766, 0.1079513184460146, 0.1295311272676502, 0.10512101996157851, 0.22755213321319648, 0.21409706877810614, 0.11280316274080958, 0.09311727407787528, 0.22378622314759664, 0.1238777091992753, 0.13311399572661944, 0.17135439733309404, 0.2121229525655508, 0.1731823163905314, 0.10193874500691891, 0.142359211774809, 0.14137342252901622, 0.17507116789264338, 0.20816066089485372, 0.14950261131993361, 0.13459523767232895, 0.14204913484198706, 0.052742700025971444, 0.14831779418247087, 0.18253989783780916, 0.13802259947572434, 0.10948531648942403, 0.1771463993936777, 0.14683474733361176, 0.07884546382618801, 0.13039263603942736, 0.11821084256683077, 0.07875122888279812, 0.10381545751754727, 0.0837681336062295], [0.0190895785178457, 0.03953414397048099, 0.03344062130366053, 0.01641433885587113, 0.025831526211862053, 0.004354822906732027, 0.024832965240680745, 0.032870757060923746, 0.037688118206071, 0.020504398670579706, 0.06805799874876227, 0.03692303265311888, 0.01951987319625914, 0.024365117041660205, 0.09712218453309365, 0.011225299976233925, 0.057359272481075356, 0.024586404274616922, 0.02394097837220345, 0.01183809937044446, 0.03532792913860508, 0.01954336916761739, 0.014448772184550762, 0.11986671228493963, 0.052879119491470714, 0.011685725850319224, 0.014738805192921842, 0.011512829190386193, 0.027986814667071615, 0.05693885896887098, 0.03786112427977579, 0.029183587591562952, 0.07351592409291438, 0.04137134199429836, 0.04497460043057799, 0.021137417560177188, 0.01440321364706116, 0.04020194795780948, 0.0482193718531302, 0.051172627668295584, 0.08358854574284383, 0.023180905496701598, 0.02396979575444545, 0.017697168680440103, 0.060128082122121534, 0.037945469575268884, 0.04478294142921056, 0.08741538825311831, 0.03137917424153004, 0.01877788158266672, 0.04704314157632845, 0.007271120191684791, 0.031162093925688947, 0.029439191733087813, 0.006748532452287951, 0.042396062186786106, 0.06717828488243477, 0.009100116423464246, 0.01703573783327426, 0.012617751373909414, 0.015893578496096388, 0.009644167497754097, 0.052557164803147316, 0.05264801385679415, 0.009629197318905165, 0.01489535000707422, 0.05567153875849076, 0.017286325904673765, 0.030954122942473208, 0.02478330665534096, 0.014268570246973207, 0.11399857859526362, 0.019457208790949414, 0.027783819041880112, 0.06362546195409127, 0.10028000508568116, 0.021807591331058314, 0.033545390503214936, 0.05157481233722397, 0.02322132752410003, 0.048651931142168384, 0.10917858473424401, 0.006078232728343989, 0.05404393341658371, 0.05449206169162478, 0.06805350684693881, 0.035050750976162295, 0.027595902161140527, 0.021973623761108944, 0.05621084856933781, 0.10800058687371866, 0.05134879571518727, 0.05602917421076979, 0.1200609632900783, 0.01897601380811206, 0.026637429038860967, 0.04727856269372361, 0.11189853306859732, 0.033995883472795994, 0.008046473675806607, 0.04351807073024767, 0.011896435570503985, 0.0313859222722905, 0.0631453034334949, 0.06657927416797195, 0.02522773521819285, 0.08134405368140765, 0.025908080229003514, 0.026051834658054367, 0.07923822703638247, 0.031512621723647626, 0.02688216304938708, 0.022428064108160988, 0.03946881461888552, 0.06781943262155567, 0.021922691226271645, 0.018500552446182286, 0.040781555963414054, 0.061351433263293335, 0.04835157422348857, 0.11695923044213227, 0.024562329852155278, 0.006304899895829814, 0.08555703690009457, 0.020616085534649234, 0.03702903339373214, 0.004465428355615586, 0.029387273626135926, 0.020694458025640676, 0.008373888874692577, 0.034959382843226194, 0.03874176095372864, 0.0483208365871438, 0.03380870619522674, 0.014723853673785925, 0.08340625052473374, 0.04138999152928591, 0.04161953314074448, 0.013083389245106705, 0.03428621842925038, 0.008193294234972979, 0.04805397554965956, 0.024587983564872826, 0.04238004536767091, 0.01478972246072122, 0.021082305249625018, 0.007053468634174871, 0.029725536903632537, 0.01709942682646215, 0.03578016594318407, 0.08097535810832467, 0.018330545497259924, 0.03995560921196427, 0.039198540550257475, 0.03566775643931968, 0.013290990426737283, 0.027912856046376482, 0.012114455657345908, 0.03332167072221637, 0.047946451497929435, 0.05835811674062695, 0.025876491031210338, 0.021861168456130793, 0.035670287374939234, 0.08325080493731157, 0.045248575907732756, 0.008082290994934738, 0.11042474822274276, 0.005536450929607132, 0.041507191490381956, 0.0365083459764719, 0.03372663738472121, 0.012444435718602367, 0.02389844779723457, 0.019249532970466783, 0.051112037883805375, 0.03197521297261119, 0.019538275065964887, 0.02137265038410468, 0.05921402759850025, 0.003938453887323183, 0.011760146722995808, 0.010139674480472292, 0.054550307137625556, 0.05245423782616854, 0.022756193465154086, 0.03746080897482378, 0.020302883948066404, 0.01563710413341011, 0.014732208136203033, 0.008664577517525425, 0.02653110260143876, 0.04307376939271178, 0.037021613613303216, 0.06712950499994413, 0.037454413782273016, 0.03487891198268958, 0.059915863509689055, 0.004580448098879839, 0.04297009602721248, 0.019006834564996616, 0.04339245693492038, 0.040023398253002336, 0.013385156668456537, 0.025802919175475836, 0.03831833474604147, 0.0036526273719833364, 0.041410863266459534, 0.055112263054719994, 0.0725432305729815, 0.03542861355734723, 0.10329572683466332, 0.025351162434422543, 0.016932759966169084, 0.042542184703052044, 0.011681071948260069, 0.024194847160418118, 0.02256781348426427, 0.07008164801767894, 0.016634423385507295, 0.028449560282751918, 0.01054163184016943, 0.015805754012295177, 0.010433939002853419, 0.007989104388148656, 0.039555745132799656, 0.06378546729683876, 0.018340343542929207, 0.05901567145649876, 0.03963985633371132, 0.06559472664126328, 0.02283163129218987, 0.012874213862232864, 0.04487011282305632, 0.04504209430888295, 0.04545967493738447, 0.09289469423570804, 0.052891390797282965, 0.12502864029790672, 0.029382103189293827, 0.029338222329637835, 0.015967236865045767, 0.04022480780258775, 0.01158421955603574, 0.019398880224408846, 0.06856681180319615, 0.028752565184342008, 0.03385334701410361, 0.004633271201912845, 0.02890254177951387, 0.05808949829744441, 0.07306458973991019, 0.023013926510299956, 0.05175130608092461, 0.07985938513385397, 0.04934327690196889, 0.032767504387136014, 0.016250428544091325, 0.00970581834137972, 0.009860073099844158, 0.019129447539203932, 0.043696226884744, 0.040690527097987275, 0.023681771209729568, 0.06382150429167918, 0.04703362173001681, 0.07124727618481431, 0.0488809027842113, 0.015188472046117698, 0.05639915560771312, 0.02510025375522673, 0.02495466558528798, 0.006393725642867918, 0.0408147159697754, 0.019057762010821273, 0.021414475282654166, 0.01278370916510799, 0.035009109282067845, 0.03766069521329232, 0.022509500184761624, 0.011157348934960152, 0.0444899364374578, 0.058865681290626526, 0.0655379875430039, 0.08871404999600989, 0.018660701977621232, 0.028821215964853764, 0.046607790115688524, 0.019636231773932065, 0.0870402737387589, 0.04949784039386681, 0.04675480829817908, 0.009338299178385308, 0.024175968619861772, 0.02670242081928466, 0.007543176262905555, 0.05437739945149847, 0.01033773715607822, 0.017639893539515988, 0.04240226060418146, 0.021025623826842223, 0.043587508611381054, 0.03585770892511521, 0.01135298075886177, 0.03714896785095334, 0.02801484494869198, 0.01980276801623404, 0.023050428301628147, 0.021875760351706828, 0.039427373092621565, 0.040128011389502456, 0.07419358380138874, 0.0763639323413372, 0.007140380064291614, 0.06745953764766455, 0.05310023709067276, 0.021062585325645547, 0.055382435343095233, 0.0349458732110049, 0.04086797757606421, 0.05025217455944844, 0.04420546402356454, 0.01616527239925095, 0.023319667604352747, 0.034820700463439734, 0.035909318298633607, 0.04631100907655699, 0.031562066570456536, 0.0328911131114832, 0.035650986446333785, 0.04877972982025572, 0.017298273210014616, 0.06220085732638836, 0.026732203417590687, 0.04006976933617677, 0.02034211005749447, 0.06742299175156014, 0.06048722392214196, 0.03167227762086051, 0.043482332290815454, 0.01023921387137047, 0.028607843842889582, 0.025259606008018767, 0.10441814589181117, 0.024466291701953326, 0.027150114831913794, 0.027153448135192906, 0.044189949320363145, 0.03158505872956344, 0.022637780622712204, 0.005099881922693125, 0.021251883025148084, 0.1427932841969388, 0.2534818196935313, 0.14854568695383413, 0.14433639496564865, 0.10329845454543829, 0.04430658949006881, 0.07069741854710238, 0.11890236474573612, 0.17869203431265696, 0.09072605560400657, 0.1515021047421864, 0.07020480890891381, 0.09252789177532707, 0.09296577756426164, 0.1775114376630102, 0.08334915180291448, 0.14271629761372293, 0.07381598584886108, 0.11661302830491747, 0.1500665553446327, 0.13695542673979486, 0.16379372589290142, 0.0826168293133378, 0.13703850656747818, 0.09395801967808179, 0.16199813224375248, 0.1188598070293665, 0.13934239079909666, 0.09411035078976836, 0.2385554877775056, 0.09683890294815813, 0.13984496811670916, 0.15917149106306688, 0.1452773737588099, 0.09663377502667052, 0.1901113037019968, 0.1140267513692379, 0.1698524464986154, 0.13604840183896677, 0.1099257603553789, 0.1242013161203691, 0.16837348443056854, 0.1371218849505697, 0.08066882312830005, 0.09198260067829064, 0.1145960558205843, 0.12419648495103632, 0.12299979345074721, 0.09162947748388563, 0.1755226786647524, 0.11997553573123046, 0.10303119995764323, 0.13190931108381065, 0.13763624163610594, 0.1463282752249922, 0.21966545283794403, 0.15253806486725807, 0.08104488080633537, 0.21595925385398523, 0.12546158635190555, 0.1319557364497866, 0.12374186648854188, 0.1821749952754804, 0.1775916947850159, 0.08600622029708964, 0.2316639604313033, 0.13651182768600328, 0.15364033143435205, 0.13074680417776108, 0.14391814598015376, 0.10557430849543639, 0.19794150282229694, 0.1503715839769159, 0.17253115347453526, 0.24010493606328964, 0.19417913470949444, 0.11952445922153336, 0.18157499389989035, 0.20205330289900303, 0.16701650938817433, 0.22845478834850447, 0.16082609870604106, 0.06221763749739953, 0.1069220079641257, 0.09273404428469283, 0.1459345892071724, 0.07219638382749897, 0.1500947145479066, 0.08148361476404326, 0.2137921487114259, 0.1593422376151596, 0.12104190779583794, 0.17568326076226576, 0.1562768199614116, 0.13894362933933735, 0.06925845611840487, 0.15638846611338003, 0.2104781429682459, 0.0953537594260914, 0.09872594276177031, 0.1534625416887658, 0.08495422638952732, 0.13914151729217597, 0.1343024769531829, 0.14912974275648594, 0.09726021212658711, 0.140895598168884, 0.15040685422718525, 0.1509166918694973, 0.10901173975850854, 0.1487758867442608, 0.09949276197169508, 0.08957086330545799, 0.17503995528178556, 0.23823171800800733, 0.07778983297092573, 0.0974768954994423, 0.16227772938353674, 0.11223600246012211, 0.19968847265200956, 0.16267148325485842, 0.14311872316258295, 0.07785733363458089, 0.16853745920317514, 0.13437137539897645, 0.19370736288172857, 0.07990175964576857, 0.10496787460786955, 0.1409060883202723, 0.13778262878102915, 0.12053159517901284, 0.12804347995136464, 0.1626722432140793, 0.09163812202002321, 0.18411169706710748, 0.2098662265177284, 0.19083429633506707, 0.19308685617787497, 0.16665993923587458, 0.11081697539027248, 0.09526953965957675, 0.07369731685944966, 0.10319462511688471, 0.10334496812096663, 0.17677281158311026, 0.12191557591514927, 0.06057366928351777, 0.10026429699999945, 0.10023869587374584, 0.1045333950647286, 0.21029514207371644, 0.12662253262741224, 0.07935725564935378, 0.10740843614829437, 0.16457313192742212, 0.04335039794178946, 0.1728702445647546, 0.069192020754729, 0.13158707480345452, 0.2373373545706272, 0.13074715701597078, 0.16639680335564272, 0.10806136325533901, 0.1803121723766838, 0.10570283659866878, 0.18387711394046033, 0.1460692784083741, 0.21231188385614327, 0.08729991516364471, 0.12086964132530348, 0.10501527027892214, 0.1843224907560008, 0.10946981874959809, 0.1198378066931452, 0.11323850402342421, 0.07126191218516656], [0.029030873107590845, 0.02353867156697171, 0.03807005878271801, 0.04720580677634903, 0.026634087253894125, 0.012581998515608055, 0.04432142905092665, 0.021740245034119914, 0.018611002680180327, 0.016327761180166687, 0.04504532752824681, 0.012214794023228543, 0.04144143805439983, 0.027086400393662707, 0.015489641510482346, 0.00592016163448404, 0.026828292457919036, 0.028402123899598206, 0.03617339734254139, 0.02413455762767366, 0.015403338641460453, 0.04731227570612516, 0.009635310071254415, 0.03168678469955921, 0.05736860233758177, 0.033850995890263996, 0.06757104130727903, 0.036725114166204414, 0.044570217308189185, 0.03502035939267703, 0.026456226262130907, 0.0649521675493036, 0.07921294482158762, 0.03237697355715292, 0.021138776326552033, 0.011184279989850308, 0.05840469138430698, 0.042984996656222005, 0.036829296432967694, 0.023751224357900873, 0.025551192861582552, 0.02753694255703262, 0.034432541113346815, 0.051658146615539274, 0.05494653426909021, 0.026463522209918926, 0.021005800426272408, 0.05586609849706292, 0.01330381304225219, 0.01759037235751748, 0.04192061948456934, 0.0186700301377901, 0.07633675022849015, 0.06490882273231234, 0.06978598316865307, 0.06732945569923945, 0.05288197273122413, 0.0336632350725787, 0.05569609494081565, 0.014541326057431954, 0.03562152784849916, 0.05644718910168324, 0.022977784342531647, 0.08007092521126781, 0.05875301733613014, 0.044507921008127074, 0.04019356805032917, 0.08065534742282969, 0.04598970578185149, 0.015297756896221211, 0.05521625533167805, 0.05092371727472969, 0.05367297153653843, 0.08483115370784487, 0.03822948058534946, 0.04000100659738694, 0.0915511202599321, 0.05329195037484169, 0.020404774462804198, 0.05877825205347367, 0.03480636641117079, 0.03488510022205966, 0.010118557622523179, 0.00762329767790756, 0.005136301017565919, 0.03998411786077278, 0.024789633994389857, 0.025253015736650144, 0.011501282220706344, 0.0700556126290134, 0.03161909404609885, 0.03412067963342581, 0.023913716531491706, 0.028541031892278364, 0.03682932018169335, 0.05762163483138595, 0.017610472261107395, 0.009385165592123355, 0.06721148560089724, 0.034559495015335936, 0.17907442950776645, 0.07190978420632226, 0.04181809962860175, 0.01681786702413644, 0.10550299446497645, 0.022885128689397658, 0.029499279401664222, 0.05862862829651151, 0.0717272786423564, 0.026545200862788727, 0.00713639791190092, 0.05963429183300052, 0.026445500319823623, 0.027068118963922774, 0.026891277471025075, 0.07494145831359283, 0.011110376500125443, 0.010667589992018682, 0.028632993743355786, 0.02753964821541948, 0.05513044779321977, 0.041085539651768546, 0.03924679456810866, 0.023486037605575154, 0.020795364664601426, 0.08598186088992016, 0.016176434300307716, 0.00965877974938069, 0.0368858217926962, 0.056185478144990544, 0.018902448737727742, 0.060851563300405226, 0.03359737307099359, 0.017679530162630335, 0.06561766112489359, 0.0431456974973636, 0.07135542788143669, 0.030149207383926426, 0.06394029541739396, 0.029844490877751793, 0.06232439819723368, 0.0219291915917503, 0.04565963920738016, 0.011656495409884622, 0.043490064197352955, 0.0018502786946815572, 0.033361829817295074, 0.029599041012781005, 0.03602009592577815, 0.006741931154725275, 0.028841270067329918, 0.020271116634830832, 0.022831914580560157, 0.04159825088988457, 0.015261044759037239, 0.044562719496233125, 0.03496354904824069, 0.023127570947898284, 0.03232372212888939, 0.009244191460311413, 0.024424217441784482, 0.049049756223601956, 0.03334953476275716, 0.04095017870089837, 0.03734465056498136, 0.03801267168351582, 0.08025996506746326, 0.09327471455825226, 0.044850421736815145, 0.020946900193978633, 0.0507507145937, 0.02513682679273188, 0.01074850105214864, 0.0070601878271970364, 0.037199284615261216, 0.030912711950285093, 0.028810009959020784, 0.026016915549657176, 0.044769228236483674, 0.03315507001908762, 0.012841499144477504, 0.03693365172616073, 0.03108934818633965, 0.048091739416122437, 0.035997673736086915, 0.03141818321975214, 0.054706197165484936, 0.017823846079409122, 0.0582321331437145, 0.01603472904701318, 0.03518895159608551, 0.04733739846519061, 0.057668277328567843, 0.013656366267241538, 0.06750458558755261, 0.0436750362361116, 0.027361916145309806, 0.019368968704449277, 0.036523579087640555, 0.0473483500203916, 0.041964344281171045, 0.0338848310389689, 0.052771252779556174, 0.04954800448779549, 0.0504505476648254, 0.018840427244348184, 0.05425171101731913, 0.049814163241535425, 0.11561958518411432, 0.04358961546261396, 0.027538235166243145, 0.01633860925877733, 0.05374772913221802, 0.07218032290360757, 0.01763980702630111, 0.03788186709529587, 0.034785498066672256, 0.011144600110128522, 0.038180341079298935, 0.036509587695556026, 0.07217448750244719, 0.05745595693588257, 0.05689344462007284, 0.01100283972586372, 0.01485644789811756, 0.04212067874946764, 0.03544144804722496, 0.03861309035814234, 0.041551320015319755, 0.06206981185823679, 0.02772351593843528, 0.04832911132169621, 0.024557469845084206, 0.03996367699333599, 0.05190057021432689, 0.02370870565729482, 0.024998670277584876, 0.04792693004544292, 0.04876836096601827, 0.036725602711417844, 0.003201145861696984, 0.007457630808598229, 0.039110839899097166, 0.10037654026278428, 0.0309228492634637, 0.06316289784652845, 0.0214013303630054, 0.027704052161425352, 0.056731461347745996, 0.09379754614617143, 0.03660908128534045, 0.0508383202499577, 0.03465391316318086, 0.06073598164532866, 0.09995574677096945, 0.13465417522404874, 0.03753860301471182, 0.035791829960154634, 0.030383960144328218, 0.06481251825711556, 0.045115372698221884, 0.049655447115323374, 0.04539626583989177, 0.018614376695560556, 0.01655937741244478, 0.0364200380364699, 0.004334247180460287, 0.07348987513354846, 0.11519456441913332, 0.04055827044482742, 0.07135763990559749, 0.030239944479295185, 0.01589805513088192, 0.0468396421388856, 0.0981725160298603, 0.07370528286056859, 0.06259118459586586, 0.030063406630818332, 0.04900552931108645, 0.037471102351056676, 0.06808632080044065, 0.04444452887400985, 0.013227181841752358, 0.03732767701148987, 0.02754311722570232, 0.01808978770194309, 0.04376554262957402, 0.02336483259153153, 0.04666931288582938, 0.03428111584591014, 0.04165113590923803, 0.004998802257302616, 0.03941967850551009, 0.060018980476473055, 0.02271395974925586, 0.042693263917629204, 0.04323584087459104, 0.01483189341213022, 0.047961270702736716, 0.007945030146012349, 0.02844945341348648, 0.07007949027631964, 0.016933562333828638, 0.027251504927075336, 0.021127212393496717, 0.053779535461217165, 0.041522227826395204, 0.07842545064964465, 0.04790875209229333, 0.019287629319088798, 0.021569914084726145, 0.06443046911486558, 0.04313336851607476, 0.05810672630156789, 0.06590601136641842, 0.051179887992995124, 0.012474497364434813, 0.035362361398126395, 0.04547352722979017, 0.04223177868074604, 0.04891395422496966, 0.06929792650043964, 0.02579769615216979, 0.0355938436197383, 0.0164663909734892, 0.02284934275251414, 0.03916317530508552, 0.03625188688082354, 0.0428813266833978, 0.06771883980504104, 0.012295947659627667, 0.02265694923698902, 0.010920719177063023, 0.005770595552998462, 0.017002219899690578, 0.02921355509066156, 0.0091201959710036, 0.11555794706302029, 0.08168334154678242, 0.03408985718020371, 0.05087702049474631, 0.03415780228429607, 0.024590409327564493, 0.02510316127778164, 0.02045766287483275, 0.026298224294025983, 0.04650806582399777, 0.03802240866103342, 0.030994784153465713, 0.01902061900390046, 0.029008671441780667, 0.01767242420464754, 0.12708986683615617, 0.11021847357707364, 0.09387956067387547, 0.14227645764393465, 0.10812617013497011, 0.13777892397982733, 0.09852417358862502, 0.06733399509851422, 0.10163664764591626, 0.09672917705029249, 0.1416319850832224, 0.0812667210453323, 0.07635421571987015, 0.09303258612219777, 0.07976730793182339, 0.0950766864365765, 0.12319245668394224, 0.07568376883864403, 0.16857878198581083, 0.10229731683752366, 0.13796310552528926, 0.1425333238605942, 0.09151577537081071, 0.1195845367120845, 0.08810389773654086, 0.11958706086235386, 0.19915480485984258, 0.0847865061036178, 0.10505121227885995, 0.11205865376229797, 0.10591575410217047, 0.19435353177998746, 0.17310568264552526, 0.14986823312938213, 0.14452958745615824, 0.076680007523724, 0.13667528677199567, 0.08440764607595545, 0.14732143336108752, 0.11160915823919432, 0.19049477098243578, 0.09195124557507889, 0.14026415348052979, 0.16162899562290736, 0.17056546466691153, 0.19148977473378181, 0.09386293656591858, 0.16167574668569223, 0.07594888604113034, 0.14853514251964434, 0.13989988874111856, 0.10982976800629071, 0.2103628870099783, 0.15499651937612466, 0.13889527693390846, 0.21875787153840065, 0.09777399205735751, 0.10034119537366287, 0.1814624113695962, 0.11341946252754756, 0.11134512669273786, 0.13237505752061093, 0.13655445325587476, 0.14032185609851563, 0.12650760236595357, 0.08088254808847394, 0.1284153578536851, 0.22533527788306984, 0.138394083827734, 0.19043444921927793, 0.13830746204725333, 0.09643725771456957, 0.1035976545619113, 0.16043834308428423, 0.04421737231314182, 0.1138006838570748, 0.14454043044575624, 0.100941162822502, 0.21729921123811177, 0.2341581465942519, 0.1487038263252803, 0.11623961691345487, 0.15079211284007343, 0.258638930107866, 0.07724452151783875, 0.1905308419040271, 0.14917162193783692, 0.15215125919452735, 0.10496068213667188, 0.13747266041381018, 0.10304182581603527, 0.14194993302226067, 0.19148307080779756, 0.11392497111644063, 0.17148778374705995, 0.18709421131227696, 0.050841268484613726, 0.08642360754311085, 0.19169899422143186, 0.16123403395925248, 0.3116977358503001, 0.17644924537411757, 0.15883187071553298, 0.1568406011377062, 0.1707739241953407, 0.09055712752576385, 0.10593393205532006, 0.14571920862155302, 0.12177764331655842, 0.08244866797966616, 0.07727651444396802, 0.15320374843265328, 0.11274543976677315, 0.09805717864739043, 0.06988827232271433, 0.22680478117295674, 0.1531214149934905, 0.09256580831216914, 0.12803419759230955, 0.09473449444132191, 0.12990768706159933, 0.10233298742345401, 0.17797689911510262, 0.1067530188177313, 0.12185880967548915, 0.16478220213736805, 0.08260250543909413, 0.0866078230153237, 0.09535270091146231, 0.17689293942281178, 0.08735298338745322, 0.17208610235580377, 0.14161842795354979, 0.07870066445320845, 0.07308364978858403, 0.40617507909025463, 0.14402273536792823, 0.10261637757399253, 0.12563856185546943, 0.1519563975078719, 0.1694852097758225, 0.15033391171268054, 0.15520200692117214, 0.1795813494494983, 0.12322574561195714, 0.1000503549086196, 0.10607499948569707, 0.09407330277775015, 0.13884965223925455, 0.09104656162006514, 0.17394212633371353, 0.06998302973806858, 0.10137383746249334, 0.2102154820625271, 0.14235235857112066, 0.09348842594772577, 0.16312399825879506, 0.0862666963200484, 0.08726391888090543, 0.127964172778385, 0.14150428479271276, 0.20516813147280896, 0.1482281189944063, 0.08898777780788285, 0.20307011476584844, 0.08274290111980268, 0.12800576697502816, 0.12963639519044332, 0.10213706722216946, 0.11193042421447379, 0.1959933609302555, 0.08160376295979534, 0.09699064373437848, 0.1445279454014131, 0.1345608088054827, 0.09447734323995453], [0.05008747036169682, 0.053595452303332944, 0.05137846126620259, 0.04809816853542413, 0.04849908434386764, 0.0425456723730479, 0.028624691867402623, 0.03935840679332614, 0.026492448157763908, 0.04013656432341252, 0.054458012804389, 0.041903605218976736, 0.03406982682645321, 0.027801276051572392, 0.033980321272143295, 0.016932468196111064, 0.06701585716967072, 0.01301070287757154, 0.009188514269356216, 0.03303667922903385, 0.05640134049047317, 0.02061124418729118, 0.04196016111278108, 0.03518816110278879, 0.023521989783538238, 0.024068914453632066, 0.037198941955076795, 0.04592946544289589, 0.07411669899842568, 0.02426630537956953, 0.0148127247978534, 0.035424939290221245, 0.044483612491084, 0.0670550697083984, 0.029017970764211247, 0.016687411881451095, 0.011455000195253109, 0.022291944894407476, 0.0740825551162873, 0.0406234437333686, 0.030123148246535232, 0.11788483363177095, 0.14461367151566915, 0.07111116884542362, 0.04736329475417733, 0.07333095544683081, 0.023144841360460435, 0.02930657545636807, 0.06702733798218624, 0.015143210367698754, 0.02786789631604084, 0.025830586440861225, 0.05222348842237677, 0.03893059046406831, 0.037985710094549825, 0.05352911871990987, 0.05967471216406141, 0.015254106738471558, 0.039508318927671225, 0.022986371203192642, 0.03363948295425091, 0.020820658753759096, 0.03485402331820556, 0.019948995705427866, 0.05231597274541855, 0.03168066092101591, 0.01185590582567134, 0.08114715638969626, 0.009968634461984038, 0.019103264569171836, 0.03223357875166195, 0.03532353901703443, 0.02895688564915742, 0.02938915995348777, 0.019026635913178325, 0.04364432913384267, 0.08826781144099576, 0.02816217016827847, 0.045194249001464674, 0.08329290124986853, 0.031793891452252865, 0.04527534072154334, 0.08917836472392082, 0.019104521555293883, 0.06348806539816515, 0.031201136830661978, 0.025873076303728988, 0.009892300120554864, 0.055315409653953145, 0.04458745209766286, 0.013137273407275123, 0.049039649444499185, 0.019516953799341406, 0.000556104771801204, 0.030278933101466725, 0.06090144919497626, 0.025200753273176293, 0.04042322501274092, 0.060257777305586, 0.0472051723461066, 0.10254214584295239, 0.06740901393017598, 0.048541804908641746, 0.023875740622835498, 0.033626427940492115, 0.06661389980997358, 0.04362622581954513, 0.05539880839309522, 0.011806695073443865, 0.0734013466696654, 0.03787405715723123, 0.06342918891459703, 0.07453093784196035, 0.02757844515144825, 0.03592778802184122, 0.008962632506154478, 0.042845004703849554, 0.03246506775862404, 0.018746643526745693, 0.0496768718585372, 0.08225183854145662, 0.04004128443609391, 0.016586037053327476, 0.025234875102926577, 0.06071237541202988, 0.03707437649635332, 0.05131041777453252, 0.025926410852532302, 0.05092961374404175, 0.040820412271256955, 0.03426075640267559, 0.028680525121412108, 0.04561573459899851, 0.017870016994753053, 0.011516595907908465, 0.016754781927115152, 0.01677454765220838, 0.0866266048646399, 0.03786785873983588, 0.05662453440683229, 0.0325052539951035, 0.03164669685065746, 0.10129073727875948, 0.014372915362140961, 0.04169838230258652, 0.048421717781041346, 0.005515329406729766, 0.025981054973921607, 0.051318604299532514, 0.0002339706427717049, 0.06809856157217707, 0.03847027909276741, 0.012133083988114126, 0.07084801260914121, 0.0170021079414125, 0.010135973920114338, 0.01899288049233811, 0.04180251028654831, 0.07039329236639397, 0.05110094044357538, 0.01721720863133669, 0.025782732758671045, 0.03122636815533042, 0.056521712602781396, 0.01889618585950562, 0.016394763120583127, 0.04372412485203572, 0.025594576694337384, 0.08401098128940378, 0.024382959119975567, 0.015452773310244083, 0.013454678518298482, 0.026345709870968546, 0.024907415799264396, 0.04950474448768156, 0.04522755489285503, 0.02843729067327721, 0.04859010303126914, 0.04457606628004994, 0.018352765822783113, 0.039919361871268065, 0.07132025262606995, 0.032022927555122545, 0.026893659128940532, 0.011545605824462004, 0.05017570027017167, 0.0578758886882237, 0.07924245430954865, 0.03015474762235369, 0.05162780252950532, 0.01985652495308646, 0.03332620333614094, 0.054821229207196405, 0.06659056499068226, 0.015525591992107885, 0.036222000805927176, 0.012809427338652313, 0.013615417527034879, 0.013295194799346583, 0.03455210237630776, 0.0341923261460449, 0.017304205302415148, 0.03399457050753491, 0.04701115543554936, 0.015028858557343483, 0.0674231138878635, 0.038196432537266185, 0.04311661548646433, 0.02935302796374474, 0.044405407937509675, 0.013896078270460879, 0.0369561078426029, 0.017262114078870842, 0.050553505175880024, 0.03332723470936928, 0.03283320354031665, 0.04029306842546378, 0.016573831904679537, 0.03350214746647647, 0.10146586038172245, 0.0722570719995669, 0.02517415809312037, 0.021636726035337363, 0.04028734837525657, 0.05375901656225324, 0.041412790305912495, 0.02935358096978494, 0.025557844201102853, 0.05953905265778303, 0.0766936664336494, 0.04424971807748079, 0.07935164416474955, 0.038417950472129245, 0.04044947074726224, 0.022927691494779925, 0.056798490429563184, 0.003060217743040994, 0.046356721980763335, 0.040402597548174005, 0.030896104805703675, 0.0229514249533947, 0.011059474499363984, 0.07259391035352435, 0.01900332823528775, 0.020757212336840372, 0.006673372400525425, 0.030711315971400057, 0.028254366113937328, 0.02178745580437992, 0.08650379002626453, 0.04223986342549324, 0.027611350707177604, 0.08225779607892036, 0.08671687716352088, 0.09036605206451245, 0.07835670148155519, 0.05888611876538821, 0.03860862220504454, 0.030647794915629283, 0.029855472967028618, 0.06221159853573356, 0.032230623731655736, 0.018080266159293906, 0.0074416487644027385, 0.11411774291523866, 0.050545125268399715, 0.022627202261771475, 0.03680271143093705, 0.09745926037430763, 0.038968778414917846, 0.0029573868211757925, 0.06220442642058645, 0.05347279692068696, 0.02944937315104263, 0.05166618386283517, 0.08512649964541197, 0.06218310006495033, 0.03538824411641274, 0.06896617037377187, 0.030447108005838733, 0.035763752181082964, 0.03998221457004547, 0.02065108945992376, 0.008838771027512848, 0.04901208395936659, 0.11001597837145839, 0.03860561629491193, 0.0486540820981775, 0.06404216387974364, 0.03114192107958453, 0.06425500674439327, 0.05227983057765024, 0.04366465465032628, 0.019564970329936062, 0.07042300541486059, 0.037327894142695835, 0.05461490027872579, 0.04352677633453693, 0.008976512788129705, 0.03826895436005933, 0.032009828436587534, 0.05351842161534088, 0.017407519044354558, 0.05950514626290117, 0.018038178328424692, 0.093964540399611, 0.03816284844651818, 0.025489622593990395, 0.07169657493276255, 0.008312478910998573, 0.01097757023360048, 0.04254704301378556, 0.054865754675120115, 0.04592047824657389, 0.02568886592052877, 0.03716186001630766, 0.04294719207765801, 0.022089753333213072, 0.0655250343094979, 0.08481148976300444, 0.04457387121926461, 0.030091725289821625, 0.07695511276168482, 0.01983486781162875, 0.05836283934435674, 0.05228604256574597, 0.008264269846092378, 0.015380897792056203, 0.03920607568163957, 0.03167948705543365, 0.03823750086926988, 0.03292049367779067, 0.028668277564325502, 0.011917615192942321, 0.04158271922330771, 0.07240091463817017, 0.020651515240647962, 0.005093106326447534, 0.038549158788685284, 0.014792241521977952, 0.055658748373389244, 0.05484082529853497, 0.04680591555578368, 0.0757845855717148, 0.016820302964853387, 0.05326636621196355, 0.0353412725297468, 0.034535315419946394, 0.02675837790593505, 0.01588105782866478, 0.04648353339039853, 0.050816739443689585, 0.12866279243358544, 0.14353569650224277, 0.1339849361351558, 0.10190758667886257, 0.1084080675084676, 0.09073700037385736, 0.13594795151480607, 0.08473748873387064, 0.11811221071652003, 0.14797803812793323, 0.1046757720676916, 0.1830003381307636, 0.046195254395050664, 0.10910959129354783, 0.10735969697790486, 0.12964997946151666, 0.1911235558135169, 0.09335073762174163, 0.0708724670112133, 0.07218427876276629, 0.0775507850838559, 0.20640363517616475, 0.10467147694102355, 0.10019417719117232, 0.14092538585620268, 0.07264118388827358, 0.07747297747326748, 0.1422557080430644, 0.16296017276389257, 0.15472100701715263, 0.16582192134644302, 0.12798292748630047, 0.14053791521915368, 0.17361670093876974, 0.12158641857760293, 0.14144213098500455, 0.0706674340846283, 0.11094099802098104, 0.10982500469045979, 0.10530879095728908, 0.10695668788892881, 0.26039761145200047, 0.2986856869288853, 0.1729451005480119, 0.1709811623607363, 0.1248383383665766, 0.10850898602179118, 0.17043825292161532, 0.23728928714990616, 0.15848277801913874, 0.1855905641402517, 0.08481659234634467, 0.11501309701374599, 0.18415603254522595, 0.0643847697813596, 0.1330715058637517, 0.12873391647424015, 0.1292831227183342, 0.16535230726003647, 0.15415988569813116, 0.19837857436920914, 0.15130319898681982, 0.11198985031140701, 0.13360779280109064, 0.13531293773225375, 0.11924862116575241, 0.09458462641175304, 0.20595421429191316, 0.06503467740757124, 0.14964552436556133, 0.1382134035229683, 0.11131822956459862, 0.08053715340793133, 0.16094883212021419, 0.1541902840669666, 0.1685353693153177, 0.20412549456315382, 0.12210632567959172, 0.14026211787547382, 0.1504248489758798, 0.12065529211291245, 0.14946788389767918, 0.17839366889425687, 0.18792614952794143, 0.2136386912316084, 0.12912264918642385, 0.1082438552486045, 0.10472514906099864, 0.24712959198015078, 0.18176726358277456, 0.08390463449593101, 0.15386127600712435, 0.1660758155797209, 0.09066191368869372, 0.13183145597577095, 0.1702870481780597, 0.09947556789432253, 0.13290899672678538, 0.2080831043422222, 0.23971705830522946, 0.15787168938134397, 0.1494360063225031, 0.11735183080392224, 0.13489573369068758, 0.13636659405061177, 0.21193220280110836, 0.10511199544583048, 0.06281799849654947, 0.10069679522088595, 0.2160374889416354, 0.07735508201377732, 0.1353009140917233, 0.16439950838685036, 0.08161807326333863, 0.16396686088825974, 0.131005393873368, 0.13307185870196137, 0.11611746703939778, 0.16298873908817768, 0.11965244449675083, 0.2777457705565861, 0.1079374152634825, 0.09624424164316484, 0.16179960646799632, 0.13934081659785338, 0.12379315016525132, 0.12682202192289488, 0.11616999922054154, 0.18544930672006948, 0.19894345477223396, 0.08754135149398021, 0.06340850716722862, 0.14841489254363946, 0.20697094473455632, 0.10654725985867636, 0.10919052695057221, 0.12776606769434043, 0.18606000180755342, 0.14096635580062866, 0.11282651791615145, 0.107113734818995, 0.09200387275112526, 0.22844170619334492, 0.1748952373330082, 0.11068232690117188, 0.1331844005201544, 0.12232949584722519, 0.10603957317237343, 0.12362336713288512, 0.1230085872645889, 0.1441202001380069, 0.10929478385618754, 0.09289708267897367, 0.18772478747580731, 0.09697695089770214, 0.08718620626521961, 0.17864820095045225, 0.0984290429790105, 0.2312988271670682, 0.1862761287816933, 0.06259227703724589, 0.11454527425978865, 0.08466173708438873, 0.11927800173205988, 0.129409737352814, 0.21259015106729098, 0.1326171995273658, 0.15333136729896069, 0.19688286605690206, 0.19367499676133904, 0.20185568636017187, 0.05036288772576621, 0.17187796852418355, 0.0784215083611863, 0.09782993048429489, 0.12607104650565557], [0.023204823856108954, 0.03195970844743507, 0.015238882108990635, 0.02408662421761879, 0.04703442579401391, 0.053794894101364274, 0.005626837307188127, 0.016001183972028748, 0.031650391473834, 0.010853699425102344, 0.018639533381376947, 0.02702155789094312, 0.02921480020242078, 0.022793104073831012, 0.021269770904577205, 0.002575944543683103, 0.01051381360074239, 0.009297151966685695, 0.04174788482487202, 0.025175347225740552, 0.07586484947907073, 0.0781188342454178, 0.008506182847278458, 0.06695739459246397, 0.010523409782243627, 0.038068399764597416, 0.03359893709421158, 0.01940755359828472, 0.019410147298393503, 0.012056262797809072, 0.040875149691211324, 0.013816056091205349, 0.023608487731377994, 0.044245714720870764, 0.03695849967854364, 0.03618544473179749, 0.017705345027414814, 0.05093863147443958, 0.03017027589625546, 0.02914011724559324, 0.046334571205079556, 0.016270419882078255, 0.06919298427445547, 0.03861167900530355, 0.024602729827165604, 0.03054279162149344, 0.02700422641022929, 0.025947438652760217, 0.020798628418041126, 0.04049620823934674, 0.020904362833659564, 0.009395464057368892, 0.030047654440360408, 0.01979643219549741, 0.024146715278870294, 0.04743026616051793, 0.04589755394096885, 0.026837990419673066, 0.032435656658240726, 0.061290521174669266, 0.013228106345715267, 0.01609635359740683, 0.05081936537421175, 0.045969658464725525, 0.013801213137672415, 0.036423529099140844, 0.01309072844950216, 0.016577097354456782, 0.010645864148890334, 0.03858114492946437, 0.042596905159630945, 0.02552298446451979, 0.05949160270392895, 0.04382527745994074, 0.0649136064041938, 0.08152673566447836, 0.07207780304763999, 0.024814454805372015, 0.0021538287567506942, 0.0763503344995635, 0.10279589079852615, 0.014499687756012593, 0.06781930369990212, 0.01602770960224526, 0.03962201425539596, 0.035842679374452145, 0.014424802935017007, 0.023712663212791085, 0.025272313272580504, 0.05218261008017829, 0.07684195347662483, 0.03861279519540923, 0.14719112749610627, 0.06960868196828024, 0.04372504426698599, 0.017957424179517796, 0.016663831093215516, 0.018235318196405257, 0.06298780867031642, 0.026129080780914853, 0.05858163974647011, 0.022149684938735197, 0.07995351151164089, 0.07338018316243376, 0.028604804006006037, 0.05928730938051428, 0.061414211323218684, 0.04041907577110188, 0.03469195183632629, 0.05971988902560302, 0.012968644732609391, 0.021778030952970897, 0.008971166780351527, 0.010712861000294132, 0.0733627923099058, 0.04983443108254245, 0.026402406560789262, 0.07589318510144949, 0.029451754808958088, 0.04565953064177718, 0.024268749801974212, 0.0566363748429077, 0.058269072590129714, 0.035518010546054156, 0.006184473500720092, 0.010879860342746335, 0.02317828974420471, 0.041058316826820374, 0.03216526723865952, 0.01900497537904552, 0.04812540153839758, 0.00448695699950414, 0.027789208306265727, 0.07696900237351656, 0.031243219572518553, 0.04701888055673667, 0.04165932582691312, 0.0306056680689965, 0.004572216620934861, 0.03725689223834446, 0.0198382825391101, 0.019196578401273916, 0.01164107654975461, 0.020860368319387947, 0.053431365572448285, 0.053979333490133286, 0.025171940979946936, 0.047934929973312786, 0.015041307978598135, 0.0430819898444627, 0.035412047124866924, 0.07004487820501838, 0.0006707722599717922, 0.020105788184862052, 0.10536605252751283, 0.019484172076252953, 0.06388831963496548, 0.015856238714020168, 0.017927529622933695, 0.015943813836202025, 0.08351952516074691, 0.010742543514684906, 0.05908817292324134, 0.020401593829904283, 0.025635707790830305, 0.017713300850508467, 0.015552424659420337, 0.037029230168887546, 0.042824316171130965, 0.046849979619894705, 0.02765499577591462, 0.02022944271032299, 0.028231518143521886, 0.035638128207730393, 0.0497234600729176, 0.052655396317797046, 0.023655525475208248, 0.02882168415401663, 0.03762620867096952, 0.08136070493076529, 0.01969644836416202, 0.01937383888954563, 0.04650875792971679, 0.023731309355103543, 0.02393712429329753, 0.02433497821246939, 0.037857826599585157, 0.016070667654275894, 0.052860500490559, 0.038024624077869315, 0.03257030175466623, 0.02203188108147255, 0.026549872576392124, 0.053391053806990385, 0.03589003772607871, 0.0700279555416533, 0.08084923880440847, 0.05973320866801909, 0.02719850286043116, 0.06502127634095294, 0.025944127401869212, 0.026607670189280595, 0.03277864932481732, 0.032789604272693396, 0.013111668888346424, 0.0031102208969449358, 0.005121731598462377, 0.019317018367084007, 0.012195123293037926, 0.04291502951777407, 0.03732001295845423, 0.04656468957130398, 0.011908162351963776, 0.0568774990471346, 0.03725001189325537, 0.049940570922834535, 0.043003513876880915, 0.019222135422751307, 0.01181176457820194, 0.008965737652033567, 0.029609900965754474, 0.013931784479479705, 0.04966004079739962, 0.025195540427895527, 0.013767570523279054, 0.028309797335948263, 0.017372689841847335, 0.03327452950179577, 0.06774860035095896, 0.015809411316045692, 0.01011542703158089, 0.037361902317830493, 0.01959977239104254, 0.019979830033012798, 0.05425789247133902, 0.06758824217000178, 0.06446056214294263, 0.05683809991127678, 0.02894247356536133, 0.043851160178227086, 0.02087589998596481, 0.05429143584998591, 0.054154212320489545, 0.005430002355881567, 0.016022076065252935, 0.03956482732402427, 0.028796405331896882, 0.024539973819628358, 0.015439126274681516, 0.01032468892766961, 0.030125234741717577, 0.101854660947408, 0.07225754697407995, 0.05866364070347377, 0.04602109141913908, 0.06318157791559185, 0.07329739510480847, 0.048366773407906294, 0.03924768005630799, 0.020596346950956752, 0.05898313570235457, 0.04043981519394687, 0.040786387132746835, 0.05130233642246042, 0.027090451247724037, 0.041125461259590726, 0.07606079682175602, 0.044555574522486756, 0.08488817779081208, 0.0417930277596627, 0.017581218920115913, 0.024190972725461637, 0.014639869698190262, 0.019280543717156564, 0.023976204517696584, 0.052090576982923915, 0.028013582873557295, 0.07968020439147949, 0.05280755101037877, 0.03512137968625341, 0.05348992653723274, 0.06886345374264888, 0.0548597394621798, 0.08894739818892308, 0.04088191807802234, 0.03486012334802321, 0.022282676106052737, 0.04542965654815946, 0.0319012594409287, 0.02085371019451746, 0.03202265274843999, 0.03109904784443123, 0.012159184685775211, 0.04994462177689586, 0.022421590884083083, 0.021474111725443175, 0.07424574278827224, 0.08023762090929917, 0.06335313870970692, 0.0669644038592066, 0.04434665359024491, 0.005115909768002374, 0.010148991614447107, 0.0178584225276219, 0.033031566467668326, 0.027573059279737726, 0.04510190038542662, 0.01570023163887007, 0.017699592746794224, 0.07849130925855466, 0.03167106643585222, 0.01847213539960129, 0.04629916185513139, 0.044836053757795265, 0.032560327289892096, 0.04887209879234433, 0.039051780211074014, 0.045410562572734695, 0.03569474516968642, 0.029994426760822535, 0.015066074506778802, 0.013512238643930426, 0.06529167254588433, 0.07476409604506833, 0.022840248686926704, 0.034659331265304766, 0.015841850378949727, 0.05336035688274673, 0.016148505798940147, 0.04861400442730103, 0.04680374424372401, 0.014279431896284223, 0.0368267824607236, 0.029416277605508055, 0.06076013070664235, 0.04262978357395955, 0.02092101238667965, 0.01550371093409402, 0.05078017658420971, 0.011071331050646092, 0.05456854955160192, 0.006176571960427931, 0.03448418441361614, 0.06169425629611526, 0.01617356070450374, 0.03260458812915853, 0.0223073696917189, 0.08486850706062146, 0.061448484127010615, 0.0290809998820935, 0.05291128544402974, 0.02018896470378552, 0.1072931055511747, 0.08450110748942409, 0.1602145079523325, 0.21245843384947094, 0.07696579968822853, 0.15387256682983466, 0.09937103957469974, 0.0886966727141823, 0.13748367982251303, 0.07337753009051085, 0.17321686739368097, 0.0841085206983345, 0.10308493314577, 0.13089262135326862, 0.06813842550452266, 0.06743275587047849, 0.083161129749247, 0.07699806402836527, 0.2002334584082876, 0.1493358409830502, 0.15946288114147528, 0.13945069855877332, 0.107891078107059, 0.16409346195203917, 0.12276438251137733, 0.09963528825236218, 0.18574972131422587, 0.16585253684648446, 0.07211782304303986, 0.08626609920923199, 0.1554085122687476, 0.12379386941237108, 0.08122572395950556, 0.1846890218023743, 0.13630154968372413, 0.2031830908464534, 0.08662967862827436, 0.1430033314973116, 0.07112991676798888, 0.14301896494414124, 0.08896335054721151, 0.12462640473885195, 0.20000103302299976, 0.1632525399327278, 0.15249489646937164, 0.13285764519657406, 0.12228912301361561, 0.07904348748603038, 0.0741332620382309, 0.12919245686914238, 0.14140284380742482, 0.11960668409509317, 0.09775495915008442, 0.10380323031651122, 0.08910926950297185, 0.1654171480664185, 0.15066404614065373, 0.09613524856311934, 0.13524623773992062, 0.14423643318670137, 0.13926030163254055, 0.1935747635683843, 0.1466309018433094, 0.1685772349259683, 0.08165579302502529, 0.06752448023429938, 0.07561524358711072, 0.06816172639706305, 0.1173463753823723, 0.14232007387493337, 0.12719601685447351, 0.0928791964958821, 0.19806848386568682, 0.1201803447412593, 0.20690317265689373, 0.16930424448634895, 0.2243792356124946, 0.17417083334709915, 0.20134753148470605, 0.29056845392499653, 0.12401900733155863, 0.1392161561442273, 0.14297316383038247, 0.11696756285216127, 0.16015780956617423, 0.13117559759744576, 0.1488136811447995, 0.12422587908804417, 0.08909432137651102, 0.17385884294552462, 0.2390913133110319, 0.2352489594902311, 0.15497822607202189, 0.12348855579538004, 0.18098491270627293, 0.165457371622324, 0.06462970056704112, 0.1244965059948819, 0.14191954822412559, 0.09384203768734421, 0.12132401551519122, 0.08405738629932914, 0.14889598744256155, 0.1863853322075946, 0.15325948329908506, 0.12919226687933716, 0.17155892135841505, 0.2098273193197591, 0.2035967665059226, 0.11355763939874512, 0.12087333255580493, 0.17642475025994436, 0.11417080435369696, 0.13659669884613582, 0.14789574540087155, 0.1261544113180467, 0.07058646450085299, 0.16547425357358797, 0.13468791198517593, 0.16849080313529285, 0.10931454279593059, 0.07670839742890426, 0.10335130563804082, 0.1340990521545921, 0.12931791799409048, 0.12983551807701588, 0.08324743261826889, 0.09190502376960856, 0.16344471462070942, 0.12681842568729604, 0.14185606448778085, 0.07516831292637757, 0.07238043645130736, 0.25545855505125864, 0.18628602182226522, 0.10670128730790955, 0.1626992081957204, 0.1809491810521909, 0.16628122170056614, 0.09751177898475102, 0.07915445510298014, 0.10313587755497013, 0.08435855406735625, 0.12328852367188249, 0.09839828498661518, 0.1622128885771547, 0.1364851612597704, 0.09255669558686869, 0.1332396739827735, 0.17500169947743416, 0.07768009350235973, 0.11658752895891666, 0.12282486712293965, 0.151427208046828, 0.19014673680067062, 0.0859393710270524, 0.1370090717183692, 0.1014092569904668, 0.16662861805941376, 0.11224096933645861, 0.09345461454774652, 0.06524465685444218, 0.11693363610122885, 0.06577153929642268, 0.16631913823740824, 0.04132304387167096, 0.09915040034268584, 0.13469374738633633, 0.13752028000141892, 0.14902729753937038, 0.08520348622862782, 0.17797457852533885, 0.1013283756162439, 0.14790968251015457, 0.11268490087240934, 0.12440750934183598], [0.015686738970024244, 0.03495849396235176, 0.04295778061662402, 0.04737519286572933, 0.0786991852468678, 0.041410527391625304, 0.04967693631936397, 0.040690974931099584, 0.042737830097654035, 0.002466788827275325, 0.03844763637919511, 0.05945692956447601, 0.03327346759449158, 0.040388752041118484, 0.03457450081727334, 0.03978149373350399, 0.039931093741740496, 0.0305292073504201, 0.03977308329194784, 0.022355603353519524, 0.020090353209525347, 0.026991320674174597, 0.0015023741767176294, 0.021215194636689763, 0.03316786718953933, 0.024872420355677605, 0.005975734500680119, 0.05407856923661061, 0.02621659653128258, 0.03490431972646287, 0.026065999076568654, 0.026563480596191118, 0.017766806729403988, 0.018550312811774865, 0.010108282906003296, 0.05295938000615154, 0.02747467000569616, 0.028979399441076175, 0.011107612318093223, 0.03267643820228321, 0.03728334153337138, 0.03536663956141897, 0.030920325113194327, 0.03100603087139981, 0.04671360765184675, 0.04218915311087455, 0.01390426479546087, 0.036495891466204605, 0.022710497524323206, 0.04894466811258878, 0.021278118581644127, 0.02903789933770895, 0.03779185263972197, 0.030739749981356517, 0.006782234014411057, 0.029576028497623544, 0.05212562331663711, 0.017863774472581487, 0.012571366720034607, 0.01641795544752053, 0.029937188939324448, 0.022800498409196734, 0.053373839373567274, 0.10243060147123677, 0.0378761300817132, 0.14652771023767336, 0.027193924445392828, 0.024364438506641557, 0.03379290311464241, 0.04408816906756588, 0.035886909679642746, 0.04364386773002999, 0.09923554970217602, 0.024161030671426227, 0.0937570986737098, 0.030085174034216573, 0.0821289558495794, 0.04359735754717674, 0.035992170817085674, 0.013166441931389272, 0.06642187439969607, 0.02241458331367799, 0.03504920391631978, 0.05847761354276112, 0.039908047299832106, 0.01175390844166811, 0.021189868317118714, 0.09422526748052665, 0.022539766239268438, 0.014249179412477782, 0.08721467759460211, 0.024516901932656765, 0.06395900262785809, 0.029850753755973916, 0.08420128322073392, 0.08925973464335714, 0.06807619705796242, 0.004368413114986781, 0.05827670610908951, 0.01324237508898867, 0.017738645829792534, 0.014403956642906581, 0.08489604201167822, 0.06530400152717318, 0.033020774368196726, 0.024619827213297998, 0.008233449089207819, 0.0773165887221694, 0.04604410732697163, 0.09324340016714164, 0.024536872914593135, 0.020224450388923287, 0.009480690600217452, 0.016876684135890434, 0.017341385628761988, 0.06245452764311007, 0.0323474606765168, 0.01121402102788644, 0.028237058381949152, 0.037479875808847804, 0.049053922428616455, 0.03537961993632572, 0.07284074782260827, 0.04920055723882147, 0.06612289151442902, 0.0356167373912675, 0.02934819000906178, 0.028208391973748803, 0.037996244350714345, 0.009131259484482663, 0.014443985119994198, 0.06102807740015643, 0.04036692696224366, 0.016737494551177536, 0.01696476137398609, 0.035274759134543796, 0.017883334940831577, 0.040170796415103335, 0.04583884709115539, 0.0438290127952184, 0.10252960651580777, 0.004090718417761049, 0.021562138073412434, 0.025875938025170138, 0.042904383303331475, 0.015086756254147207, 0.005082875290619475, 0.02316284628718027, 0.06900923699140549, 0.047832630641226254, 0.06589185712592942, 0.04667083958962134, 0.01658944838813373, 0.04792426001014454, 0.015131476800888777, 0.047099897637963295, 0.12527232936450414, 0.038484623323061636, 0.02108994385759745, 0.017382267363635556, 0.025627483946404288, 0.042970889913184304, 0.015299149589346988, 0.03766262564542038, 0.034908048276390345, 0.06191717540579183, 0.015563762979581952, 0.019621828171823705, 0.0428466874706958, 0.042478602579129596, 0.027720567703779255, 0.02235389853428517, 0.020118207072040865, 0.04356793626876814, 0.042491640629512925, 0.03225821635818907, 0.07178133074194193, 0.04881383977564318, 0.012541812279128602, 0.06022625256861959, 0.10435761378279754, 0.05231333324419601, 0.024637384306905524, 0.004919998472489948, 0.009356773142436785, 0.037051207918141565, 0.03206197724544576, 0.029922295095665113, 0.04950746541310634, 0.05485187524131366, 0.03482350281306675, 0.016732985685978616, 0.022846489512760724, 0.026522167991580706, 0.045592884932245524, 0.01255118624041123, 0.03341285225802234, 0.02735482545436493, 0.017393737998125807, 0.03416442817875317, 0.023092580593324134, 0.010241041675076952, 0.01681499512467001, 0.015134776177416955, 0.052017617505043745, 0.03347797465643712, 0.04109935462474823, 0.029169809938009297, 0.015707821053053652, 0.02019672205538622, 0.02045285375788808, 0.019822394641648446, 0.08411426110459225, 0.023777931496234875, 0.04148392113191741, 0.0030567756621167064, 0.021659747032182555, 0.010931401862762868, 0.05577456412304725, 0.016880181983911564, 0.03505105631692069, 0.03263524773397616, 0.038517813863498826, 0.02648567977095289, 0.05582636687904596, 0.021183905690642338, 0.06934397188680512, 0.04583008720406464, 0.052583128945635896, 0.06003808123724801, 0.04113911338416593, 0.04556682240217924, 0.02459989863980029, 0.022486267145723104, 0.008546187575640423, 0.08629856032452413, 0.036311754025518894, 0.06203109465007271, 0.04056423476764134, 0.031771068926900625, 0.08838916064373084, 0.08736590947955847, 0.02583384171261319, 0.022810260831777538, 0.04459718568250537, 0.04142361633213503, 0.07463746105453797, 0.05181518676025527, 0.03439184258292828, 0.07034487210746322, 0.023711910038920384, 0.04509760865143367, 0.0460684226293649, 0.02384393259749881, 0.09545532254768269, 0.05715246857809169, 0.035108891249235184, 0.04930298888523664, 0.08892195312572376, 0.0842275493113058, 0.04679354925506881, 0.022402958312470998, 0.04827657574787736, 0.03716099488415888, 0.05314030119084886, 0.01816446048074535, 0.09669258365673677, 0.06347205197172505, 0.10389040171035699, 0.15693873087210314, 0.08660941757261753, 0.06603401699768645, 0.016302674044189707, 0.01782777310082955, 0.017678110328103815, 0.12598207699401037, 0.015141307076971446, 0.042201892605849674, 0.018365847977942655, 0.01524290582165122, 0.05908434598573616, 0.04307036653959325, 0.01795716803254826, 0.036720150682543, 0.026679255633748004, 0.03484198271429964, 0.032666338208530626, 0.0467879818752408, 0.02280050689088447, 0.08385251622114863, 0.03717204821961267, 0.04906218019979341, 0.03600840476740684, 0.035372030522142134, 0.04799028146745903, 0.026322687177785804, 0.09825043899140187, 0.05875104958457606, 0.025554463400372436, 0.1043915676751307, 0.053786548120634894, 0.02131913093450878, 0.028213726955332925, 0.010737348480948379, 0.010643460438586771, 0.015372991162751402, 0.040041243723992787, 0.028503268025815487, 0.03712786541187337, 0.032760101570082564, 0.048755383983786614, 0.017820667142846754, 0.019521101344642893, 0.029254969475524764, 0.022474525097225393, 0.05455223756975361, 0.017288263122152005, 0.012755245469244463, 0.05632210795634559, 0.027881333005747626, 0.013539430086633988, 0.019282932160422206, 0.01594730998788561, 0.020419493583696227, 0.018274798756465316, 0.04730690510145255, 0.02945692863847528, 0.013294672327382224, 0.017291114665567875, 0.002749191709361704, 0.027794183664289967, 0.025791843787633946, 0.023741036154595867, 0.06886170990765095, 0.058649832515844276, 0.05817356200090476, 0.07697613377656255, 0.04407276292996747, 0.03961376326956919, 0.03094776506934847, 0.06035942185137953, 0.03749685614768948, 0.045782898486192734, 0.06570046953856945, 0.06721907162240573, 0.011714105577474194, 0.035888572090438435, 0.016937854067821587, 0.04720281443691679, 0.04351420647331646, 0.06391856872609683, 0.02408508224678891, 0.12079226119177681, 0.08557397991951023, 0.1400345100888184, 0.16912047006189823, 0.21775662526488304, 0.154223410146577, 0.12232979440263339, 0.13236527304564202, 0.11047589619244848, 0.12006892929119722, 0.07044081695910011, 0.14455467968114785, 0.146096636940326, 0.11880856406475816, 0.10966487042605877, 0.095820645801723, 0.11834672598966531, 0.17394661823553698, 0.17787125121269906, 0.09341472347400018, 0.12539084229086125, 0.17080783737557276, 0.10423450038901397, 0.17647671247167246, 0.11969352300677981, 0.19563837854989938, 0.1281611786356994, 0.12343245452003819, 0.11896896974316665, 0.12260960867362362, 0.12402949748294693, 0.12239577514784676, 0.11553075137947287, 0.0921360920848591, 0.11649695810462747, 0.1836040714489562, 0.15965335949191026, 0.1492087242326566, 0.3234664372035435, 0.09899312271071331, 0.14328979541148457, 0.08282812511814491, 0.1454707155270236, 0.1540075410157442, 0.14150912953274591, 0.10573514843625681, 0.10500975378922053, 0.15755089159522737, 0.19565942670617784, 0.12069369719496795, 0.11880028593753066, 0.09221120591142348, 0.1517498650188957, 0.13395026299570287, 0.1068075933892812, 0.1310878630195345, 0.16070766720388616, 0.06843266543000937, 0.09670274132596594, 0.161645646872265, 0.07991210051945277, 0.1995180110846247, 0.09689532992030893, 0.14266060345939227, 0.1978430745324918, 0.2783844619989395, 0.0796692528362785, 0.11128808225372008, 0.17642484525484697, 0.1864246872386762, 0.16014077833720616, 0.21665647572704724, 0.21871254539915494, 0.1349274077053581, 0.20342612851943287, 0.14945120550692081, 0.0864988367206284, 0.14478652152631963, 0.14535476746303694, 0.15571481654686586, 0.34224896505475044, 0.08854780213109084, 0.32235567537801607, 0.264455359429121, 0.127871607031141, 0.05443373482142176, 0.22516389350805963, 0.16540374021445, 0.14575203614575521, 0.1620642894080707, 0.25700216793588226, 0.1712221372872591, 0.2544399382812636, 0.2682439461350441, 0.19610933613564285, 0.15762183921677725, 0.1548274555908782, 0.11576082903359618, 0.14193518167095526, 0.25411304725067957, 0.1419079452753067, 0.16875799665493624, 0.1646490871374096, 0.09843741610114064, 0.1669040082820824, 0.23671158243502888, 0.1457849858062608, 0.11119496010776077, 0.13352571720523493, 0.3277625138206141, 0.13271935975977353, 0.13121314772537776, 0.10844409771795784, 0.15746359127972806, 0.11507134245974676, 0.18904461951128074, 0.1497588668550764, 0.1186456885188818, 0.11287441570311785, 0.07451930775174073, 0.13683715808604444, 0.13572125296507562, 0.10170422294842345, 0.21409117909414427, 0.126771959609219, 0.0621891865240676, 0.08504182526043483, 0.11675176157483033, 0.11685656809381076, 0.1316138090831893, 0.1257190089672804, 0.17064697029335157, 0.12392501666077546, 0.11567751850400652, 0.09332586252795798, 0.133631310824837, 0.06623341808361666, 0.0976230383717588, 0.18183992111257144, 0.16870125755667686, 0.10706828654344593, 0.1394558282835143, 0.11660084181598254, 0.18886995102678025, 0.1250209185693945, 0.22501190166388238, 0.06925262750259467, 0.08423041951443468, 0.1115688057616353, 0.12626562320760318, 0.1432896325630801, 0.06835776873465095, 0.08148541288184268, 0.14249282889068127, 0.13722312237535203, 0.07092279395354645, 0.14332430570253304, 0.14471599459648132, 0.09243162122688123, 0.1150666605681181, 0.12335788352148873, 0.1370154092354434, 0.10293019323476724, 0.11515489726194314, 0.10465084947645664, 0.2022115644067526, 0.07425942883959838, 0.1001083900087646, 0.15405050585312502, 0.13873434199818543, 0.0783111582111035, 0.0639267722144723, 0.10362130829266139, 0.16328890940972737, 0.10451127482312066, 0.07912830436336142], [0.02185101417957672, 0.006793845444917679, 0.04221491030018244, 0.02828235737979412, 0.015108203049749136, 0.057898422836193016, 0.037629387607531886, 0.04182198763425861, 0.05846832439835582, 0.06160713918507099, 0.009789844725414045, 0.030723512638360262, 0.032440481042223315, 0.07263980646218572, 0.007716254430956074, 0.05917638247566564, 0.03643289966774838, 0.10123979965490953, 0.023047396946432333, 0.05941309620227132, 0.043218450022063086, 0.04929169127717614, 0.030653511573161398, 0.026694526064342687, 0.030396628393126384, 0.012149658054113388, 0.06017078911619527, 0.02526018106644707, 0.011665265475000654, 0.015071894640901258, 0.04446866436462317, 0.017367175048483268, 0.014561342840482081, 0.054351350492132564, 0.0218161595320063, 0.04687354174841728, 0.02569878101348877, 0.03998734429478645, 0.008855385805613228, 0.032811303822589774, 0.024941956624388695, 0.08165098899709326, 0.05876708336706672, 0.07116887824875967, 0.03919505627293672, 0.019013139851657406, 0.03375722235068679, 0.0914145175899778, 0.04887890789125647, 0.035732885623084645, 0.0546293564672981, 0.03618502404008593, 0.020670539666233317, 0.0535159008577466, 0.02853948822511094, 0.03960429092070886, 0.07606612332165241, 0.048906656580844095, 0.031011971445488076, 0.04111450970438974, 0.04967334347644022, 0.03833311663142272, 0.010193551857290524, 0.04965976599071707, 0.020541870766984563, 0.0885766398693834, 0.02469168576811041, 0.03717823645898274, 0.050485790773694, 0.028804547752120664, 0.011406238124306713, 0.026399120754961456, 0.027034626475402286, 0.08238475676625967, 0.0852965201650347, 0.054821785605911694, 0.020874088297465017, 0.0581422679658447, 0.07114163506776094, 0.07651659593518291, 0.02774544958291309, 0.07108110974409751, 0.06404808749045644, 0.04728314959044967, 0.056227384467742274, 0.03638576862535306, 0.023326977122841135, 0.034524170482265096, 0.03867670301614063, 0.04126977887270706, 0.042949560164873085, 0.07019450874733073, 0.1319512581186635, 0.029319162280963998, 0.026467557796942334, 0.022419952222013047, 0.02942809768553291, 0.03935101415429797, 0.031581068943653784, 0.03685290266626647, 0.03604267078584858, 0.07241863118750708, 0.037952075113675425, 0.04329655618805971, 0.0570466849686844, 0.05282780188801033, 0.02990922990388104, 0.04848948307335377, 0.016430657623069625, 0.018992415695850338, 0.033292500501764674, 0.1125903877296618, 0.032793570309877396, 0.01980626247158008, 0.01584025751799345, 0.03159399164308395, 0.054797076753207614, 0.018335564960060374, 0.009712294109963944, 0.017176030037392463, 0.026481740875169635, 0.079151211705591, 0.03568781393447092, 0.03601369055520211, 0.018450103367545774, 0.037889585431132994, 0.07403789394135986, 0.0392792047932744, 0.036060831775622706, 0.022754266425701122, 0.041231777518987656, 0.04862412138442908, 0.05168683846880283, 0.031388012160147936, 0.03326317421825869, 0.06710396494184222, 0.02663683023170701, 0.05111610230856708, 0.053843439889273474, 0.04022105550393462, 0.051479603696082316, 0.0502571685771857, 0.09697162439780575, 0.044919730696294985, 0.018520151930195943, 0.028322708161015595, 0.0378739723403539, 0.061168602002518516, 0.08479044160672597, 0.043631379293011766, 0.02054364004704569, 0.02845457465653973, 0.0320079387165606, 0.01724239924390401, 0.049674079686935456, 0.030332869850099087, 0.02575202226372702, 0.0382346781635923, 0.011240058112889528, 0.044241378882101605, 0.03295973675059421, 0.04447441155623112, 0.044753649072455506, 0.057359272481075356, 0.03588774427771568, 0.04707771972087877, 0.03366411716810294, 0.03926726257694619, 0.059742016052561145, 0.020494995871558785, 0.03825502064345138, 0.03851567647819008, 0.07360909373632499, 0.002177832569161962, 0.09173600748181343, 0.03377097964818988, 0.035318232873188596, 0.008923264752541269, 0.03391158567475421, 0.03566206353051322, 0.048139664344489574, 0.01197902430846755, 0.022614344023168087, 0.049609835991369824, 0.03482235948156033, 0.03779765750680651, 0.019901917249496495, 0.042245186532714536, 0.03836968966892787, 0.03611675323918462, 0.04628210348476257, 0.042435332400990386, 0.004636738515858139, 0.009485313968200768, 0.03685487720317074, 0.008659466452497457, 0.11161182488181762, 0.0372214794957212, 0.05528771524716701, 0.015625445205452185, 0.052008694769548516, 0.056880559240068705, 0.043442397112292905, 0.013690107269212604, 0.06882958127451794, 0.046222582392926724, 0.04793722342167582, 0.028412378260067532, 0.01606544802364494, 0.05748458432831934, 0.009171083552895911, 0.04456025302144034, 0.023243089838485633, 0.04310538912458079, 0.05214036448991724, 0.017646602554512874, 0.008394512098415621, 0.025792327243834734, 0.15452638960310391, 0.040060252882540226, 0.01770473095322294, 0.030509380557175194, 0.043931559792586734, 0.013953839412092097, 0.02033975554097976, 0.025088101193042736, 0.044455840052770715, 0.02519122324883938, 0.020848590647801757, 0.10234960474606071, 0.01965605347816433, 0.03117526089772582, 0.016235926554405263, 0.09571364082928215, 0.029691521943147694, 0.04090483559827719, 0.05071126456771578, 0.05560844178710665, 0.03639421977901033, 0.13125829744551862, 0.03154811928314822, 0.0397967472007232, 0.024932703103071878, 0.044041000705744536, 0.03150140893246446, 0.09631901620221989, 0.11412808378892285, 0.015799094191087142, 0.0545720236508974, 0.05668819795495697, 0.06462265058819737, 0.0975894033908844, 0.033342128553028615, 0.06967006224606719, 0.15819525559033665, 0.08086919451930694, 0.06220382930977004, 0.07629683201334306, 0.07346888804542166, 0.07325240144772188, 0.06061417782413108, 0.015562358412093349, 0.010760730797691005, 0.09202084969729185, 0.03887847897463611, 0.02814710669086448, 0.02456338158143418, 0.03290559983413134, 0.0909175585423197, 0.10459007988018648, 0.061028817003326755, 0.030058497429958413, 0.04039794619062117, 0.04517781149063792, 0.029657785182020495, 0.04328548588923045, 0.04231744372685041, 0.020427619040544544, 0.028734417765268257, 0.06460538187197276, 0.03592306202543633, 0.04651408442961318, 0.028806736027555804, 0.04327396097193871, 0.023328434276793684, 0.025057684164494276, 0.0051034315090094295, 0.07366915765617575, 0.007172201660328678, 0.004394945106469095, 0.0730689052226288, 0.08934667533529655, 0.06688726799828665, 0.006495459246382649, 0.04868095208491598, 0.02558496524579823, 0.04591388288619263, 0.060871973633766174, 0.08372932140316282, 0.03734465395765645, 0.030665385935987746, 0.027529013875339712, 0.010608721990138292, 0.016642184129783084, 0.033375298737415245, 0.004325725628794836, 0.006128608440381608, 0.0034043518327442662, 0.06004300061613321, 0.029588062316179276, 0.02388367778621614, 0.04885217361152172, 0.020600240045626248, 0.05024423909240535, 0.055546335476849756, 0.015368215972557664, 0.04920162253880075, 0.06038528082094022, 0.0701271980734808, 0.023923126115862812, 0.028311704019350663, 0.02485552483371326, 0.05598949687555432, 0.09623700845986605, 0.010162633560997034, 0.04364848516083189, 0.03721564070188573, 0.05277673873518195, 0.04574755698974643, 0.04523721383884549, 0.044236344152263234, 0.037018356645213704, 0.0214282885592963, 0.023225371592811177, 0.06497384674314942, 0.013612774633137243, 0.05221740535593458, 0.023381448217800686, 0.013032667056125189, 0.023767449826534306, 0.007149458862841129, 0.007163087238690683, 0.03978508996910282, 0.0322276279995484, 0.04650293270658169, 0.046191491918372254, 0.0631211611575314, 0.008185861732012458, 0.03897051207189049, 0.01493447772892458, 0.04715713545946138, 0.018096537429041097, 0.11496540957263537, 0.11499800639493124, 0.1852663601083415, 0.17139786428638867, 0.12709723572645867, 0.09825851355812379, 0.10625268745103053, 0.08944211807101965, 0.16068442059414728, 0.21452926844358444, 0.10340657910065991, 0.07970016010637794, 0.09165779275021382, 0.1512965764850378, 0.13705336648438657, 0.11492662451096944, 0.16240183343844755, 0.19497029297053814, 0.08984316619379179, 0.15767551133675234, 0.19018256344965526, 0.06346604015145983, 0.16854075688336576, 0.12075350327151162, 0.1927433546100344, 0.157899088625397, 0.1263606452516147, 0.13890926832599299, 0.1852007864841393, 0.13276995133076394, 0.1191692054271698, 0.13527769462338515, 0.14837717956730298, 0.1493165570178202, 0.12058500945568085, 0.1476406298045601, 0.12355217523872852, 0.12759922950395516, 0.2196208323751177, 0.07731869896607739, 0.07089057032551084, 0.15449790470302105, 0.23360657904829296, 0.14760750372494968, 0.10388998101864542, 0.13594776152500085, 0.10812410060316324, 0.12905744197113173, 0.05741862393915653, 0.16174681644354547, 0.06388762752924647, 0.10449424359415259, 0.06315009389072657, 0.20540308100836618, 0.14451617960418972, 0.16481825948825904, 0.15724340666617664, 0.15938406251370907, 0.105610352275627, 0.1380669485245432, 0.07662748212793044, 0.16478501127234527, 0.1173223823841129, 0.2038561161607504, 0.11137675999530725, 0.16672202519008092, 0.10173858396176781, 0.116704630532435, 0.12230586925787584, 0.12223452808601515, 0.16304052488080092, 0.11157878701175962, 0.12527623772621155, 0.2382936275431088, 0.16607740335166454, 0.15897695507322038, 0.16752235724457673, 0.1473224511636155, 0.14976477010973863, 0.21424812424395764, 0.16444369458726474, 0.15008516077484402, 0.12340356249894414, 0.21370148286223412, 0.15408574896199362, 0.13082771269338472, 0.1114769864029118, 0.1748489069619349, 0.11593724813844476, 0.11996986317847456, 0.0974278034908431, 0.231397024754967, 0.23292720264622144, 0.23626896047166415, 0.20470039014305386, 0.14051635137626103, 0.11847385631075927, 0.13109046859400614, 0.08926515613815614, 0.12102330236562661, 0.29255677866084234, 0.1702535149774381, 0.11132769512810878, 0.18117326045674936, 0.11582686406161104, 0.13418248482048512, 0.1556223729359252, 0.11115542865757432, 0.09508380426892213, 0.14092720433005265, 0.09759232787681477, 0.1647353425089802, 0.158887687006167, 0.06334442632006747, 0.15221635784421647, 0.16918798429625376, 0.1420751227332013, 0.12510699752186025, 0.09794538321771792, 0.10633281565138272, 0.12452458377395358, 0.247634123478617, 0.1709923174764429, 0.1277375692235572, 0.1039690642750689, 0.12711555617196219, 0.20928649976849556, 0.15287889300712518, 0.11970372817346028, 0.10566299302237374, 0.10383613926491567, 0.1420538438750165, 0.1078115605882236, 0.08139485559825387, 0.07809511266116585, 0.16665379170860561, 0.15868819771068438, 0.1753410076988595, 0.10405322297343186, 0.11493179494781153, 0.2112497187086514, 0.21565615226115498, 0.20996274133878096, 0.14656671243054525, 0.12147064693272114, 0.11123337197516646, 0.13069047220051289, 0.13128547955836567, 0.10183150254722152, 0.13946196224008287, 0.123582356476358, 0.12716217152774334, 0.14882486340190682, 0.12255903067333357, 0.16914826285626205, 0.12601689941116742, 0.12909029663673469, 0.09536456170358829, 0.12409612962177821, 0.06093737083886351, 0.10939911540065493, 0.12811658531427383, 0.07753605408860104, 0.16224665247968265, 0.1267397699079343, 0.1658933303718056, 0.18264572215931757, 0.17257063064192021, 0.08462364412844181, 0.20225686340459756, 0.08331218521509852, 0.06608396396040916, 0.12518576186682495, 0.07359046795006309, 0.16692933120897838, 0.18722358079893248], [0.058394716919532845, 0.023041737964376807, 0.008838651435715812, 0.01270464711290385, 0.03675236073987825, 0.03728064096399716, 0.0477354169291045, 0.020878678586866175, 0.03370755697999682, 0.04351395880803466, 0.023167146502860954, 0.05554760433733463, 0.07931464365018265, 0.0383239903354219, 0.05214688181877136, 0.01157238336080419, 0.038928778775568516, 0.049407232220151594, 0.038190373219549656, 0.03347393058772598, 0.08146443257906608, 0.007418844050594738, 0.057581926962094646, 0.06611143784331423, 0.009660966328478285, 0.03034194525597351, 0.021255849062332084, 0.01722385997085699, 0.028416105113657456, 0.028602771793625185, 0.014264300565368362, 0.005970738362520933, 0.019595752071057047, 0.019759463911343898, 0.056679136119782925, 0.019809059732194458, 0.027745724389595643, 0.09086934184389454, 0.05766043346375227, 0.028686282491045337, 0.06453034268426043, 0.024685000501839176, 0.040875037732933245, 0.05092122365853616, 0.06086025533399411, 0.006546429948814745, 0.025432542531884143, 0.031038491986691952, 0.036101238535983224, 0.03810506101165499, 0.05790705380163022, 0.01824376086837479, 0.03393306809344462, 0.032487883498626094, 0.012439133815600403, 0.021555242461285422, 0.06678097548761538, 0.0426725312801344, 0.017453398189640472, 0.03512300817029817, 0.00957090946446572, 0.057595674081572464, 0.016964449247877513, 0.002746313660671668, 0.046771764888295105, 0.03237455797248653, 0.03641600414578404, 0.01610321697912046, 0.03872315213084221, 0.015077093915481652, 0.046823028208953996, 0.03276378262255873, 0.034878413259450874, 0.05198809444638235, 0.09736775992704289, 0.08114877130304064, 0.052860656553613286, 0.07663576704050813, 0.023648850386962295, 0.09998142253607512, 0.06421389430761337, 0.01839009881950915, 0.04724731615611485, 0.06803601421415806, 0.09490547848067113, 0.03819571329014642, 0.02205729391425848, 0.05508500969569598, 0.010778154728801122, 0.08472144138067961, 0.026693533706877912, 0.04678037210500666, 0.14836605159299715, 0.061090943669634204, 0.06559716936733041, 0.06765014491975307, 0.028533910667257648, 0.04207058929439102, 0.038428871493254385, 0.06827859726867505, 0.035122065006622245, 0.047146706376224756, 0.06867541811828103, 0.02373523298384888, 0.04602312363151993, 0.09398123236106974, 0.028240549444620098, 0.062291265332273076, 0.010019731541563357, 0.07593367328601223, 0.029989917895623615, 0.01486829511954316, 0.07440157514065504, 0.024609164035479938, 0.02496322021553559, 0.035685574768909385, 0.02324492866838617, 0.01871807041711041, 0.026151882950216532, 0.002832323487382382, 0.08854468765535525, 0.024869714697290744, 0.023795357971851314, 0.04063699407769101, 0.015084361025531377, 0.04823527332129223, 0.041668743892971954, 0.04285688924470118, 0.04200934472360781, 0.02734868640878371, 0.03360913547554186, 0.025751513362463032, 0.06995544728956052, 0.01793413855401533, 0.006985943797709686, 0.007204080083673554, 0.03694347691323076, 0.010223655911561633, 0.06013832800090313, 0.025780632692788328, 0.061424206144043376, 0.060046481500778875, 0.05173024096127067, 0.02025416004471481, 0.0361405562476388, 0.024343193575207676, 0.025133904003139054, 0.0868721938292895, 0.03571749305618661, 0.009306503875580217, 0.014358255613063062, 0.07091517400528703, 0.04034284914710692, 0.02207107326414968, 0.02387801880416061, 0.01630615153616028, 0.02800881616505129, 0.03271368298945682, 0.020032474172434638, 0.040543149291936836, 0.0320323863332825, 0.014965956664777227, 0.05459233559668064, 0.024088488492582525, 0.033973135586295805, 0.07074938754418067, 0.03289821398045335, 0.013209774874017706, 0.04192112838583333, 0.0645429634356073, 0.028654299742941345, 0.015398548184228795, 0.05816297006926366, 0.019293105096689293, 0.016122731646256785, 0.019263057869725993, 0.17366628827793257, 0.019325018294953873, 0.020627971771838408, 0.04315260159117835, 0.012825841948922192, 0.02394906820596329, 0.05076164240017533, 0.023390111413651278, 0.03011026625920619, 0.01767931642409946, 0.004172544651997409, 0.07924336354647364, 0.025788200054583803, 0.018257794668897986, 0.020842782388042127, 0.04049349070659705, 0.04814631059499724, 0.040396375382053, 0.013214952096209993, 0.02444271939540548, 0.04597297989364181, 0.019963716522657445, 0.08530709174062524, 0.02977205387183598, 0.01955871593340167, 0.029574196453073194, 0.02901457469644291, 0.02331245138442942, 0.03661776314090405, 0.031149876902678182, 0.053771773020603826, 0.02957627277023026, 0.02066891796753875, 0.04345454967447689, 0.02852207362385733, 0.07509940090988364, 0.04457556416413613, 0.023934812185221484, 0.04755345758582864, 0.044120114496243854, 0.03582259813057525, 0.01847849496906357, 0.01409655568256442, 0.016902195356254066, 0.030613196415028403, 0.01241461664903909, 0.027614417685461894, 0.04987147570188556, 0.01524814241565764, 0.027826222391532998, 0.041117393478218994, 0.00940048012749425, 0.030632090222622668, 0.029516931490174363, 0.04338465038953083, 0.012679442929636155, 0.026943015766197016, 0.00629128169800554, 0.10189238749444485, 0.010513877213400389, 0.02132300197679017, 0.05797736360026257, 0.02734531748241612, 0.04598169228328126, 0.07195073379469769, 0.028320345162813152, 0.04491278589037912, 0.04559846588277391, 0.03324532535459314, 0.06006205387945686, 0.03373439982533455, 0.09392620317105736, 0.0388968095981649, 0.07114520416195903, 0.020487486185239892, 0.09489315628473248, 0.05790000382278647, 0.09377250141863312, 0.12351273878344468, 0.0710263858948435, 0.07995278547917094, 0.09219917548554284, 0.07357220178736107, 0.03380343397813184, 0.06658097729086876, 0.02176119989183332, 0.06070414478225367, 0.02379249794674771, 0.030129706287490468, 0.06825977470725775, 0.06006929384810584, 0.03947325902325766, 0.14637309924832412, 0.08264560598347868, 0.04857202007302216, 0.04021965432912111, 0.045511586258986166, 0.03411940059491566, 0.03372345505548375, 0.04907540823998196, 0.02180597302503884, 0.06845289934426546, 0.006934996419918856, 0.05462492563362632, 0.05437490922798004, 0.04774276546335646, 0.05575869318896106, 0.05614800944126078, 0.04935952103031533, 0.07321544843060629, 0.05637058249807783, 0.032153898384422064, 0.05288959267948355, 0.04545392435310142, 0.049364613435630283, 0.01757292722218803, 0.016807397228798697, 0.06747542893780129, 0.06576903550220387, 0.052558732219040394, 0.028476771233337264, 0.01815203989722899, 0.008000206069222518, 0.05056324554607272, 0.024002275529450605, 0.04669991820784552, 0.044078187817441564, 0.03966701469783272, 0.022961750560040985, 0.013411550832513188, 0.025088189402595162, 0.02746016631967255, 0.026205673813819885, 0.04283345943050725, 0.018933764825175916, 0.03309530804732016, 0.04326578123228891, 0.13654818359230245, 0.07858971040695906, 0.01871400259967361, 0.010029877336429698, 0.04859615217096039, 0.033789954879986386, 0.08663572437529053, 0.009053527360915073, 0.062206312747938294, 0.08435925295842545, 0.05225505726411939, 0.04668398281293256, 0.09197918086179666, 0.03999835013278893, 0.050967825443616936, 0.03694168218810644, 0.03294823218935302, 0.026502008716176664, 0.023708072923389927, 0.0241464353831751, 0.03271427670759814, 0.03734532231464982, 0.024193761504388282, 0.03653707854183657, 0.02446337739404823, 0.040818807535937855, 0.029783768778932945, 0.0636613971686789, 0.042489394678601196, 0.04090554466737168, 0.031367978413722346, 0.056433187531573434, 0.012159809786161142, 0.026794009476101825, 0.016637218949784125, 0.07279195436941725, 0.00356609804189897, 0.03378227725625038, 0.030210214467453103, 0.21621109891150678, 0.0779904689905899, 0.10843785519578628, 0.10474958989237036, 0.10204978047737054, 0.1676859791789736, 0.18441139241414412, 0.06100447116685765, 0.1475096046924591, 0.16466549411416054, 0.1779237969645432, 0.15237365583223955, 0.1529119648039341, 0.08967629407665559, 0.17783205903002194, 0.1056895237416029, 0.18685272069914, 0.10388688011361019, 0.15754057786294393, 0.17753811765994343, 0.1615126540086099, 0.13471247495285102, 0.15732123463281564, 0.16787176206707954, 0.10817199160477944, 0.0928698123565742, 0.12387262018663542, 0.12547876685857773, 0.25338172220758026, 0.07729353888758592, 0.10561350067811352, 0.07901142670639924, 0.08542110597980873, 0.150867850918855, 0.13874096449996742, 0.2611451399113451, 0.11692201958170959, 0.17377399892679282, 0.13909818604588509, 0.11395078258855001, 0.10332805902830192, 0.06818483729979821, 0.13103649791862282, 0.10419339473758425, 0.12261684185692243, 0.06676857865282468, 0.09215207836989846, 0.12700107374361583, 0.1144239114863532, 0.12618988512882165, 0.10586551536938973, 0.11684518227619783, 0.15267742238938808, 0.08670103337083544, 0.09733237432582037, 0.06579412094184331, 0.12856612833482878, 0.09542009979486465, 0.19788336594189915, 0.1691954346107585, 0.06517437419721059, 0.17877964675426483, 0.07856417034885713, 0.1549319364130497, 0.10240625563476767, 0.12222981905298573, 0.23231174424290657, 0.07789099575685603, 0.14712176764650003, 0.16788459994963237, 0.15771150083414145, 0.14756054910165922, 0.11999863306326525, 0.1046903266438416, 0.16273019010467188, 0.21225502262158052, 0.1868653278797865, 0.13491735181638173, 0.1883329584130219, 0.21761497429439, 0.1898460779339075, 0.22380518141601766, 0.12622929444270475, 0.12013234517404012, 0.24572266318968364, 0.11589112132787704, 0.10175408848694392, 0.1856146114213126, 0.09646384271660022, 0.16816144223724092, 0.13608437776565552, 0.15551467585776532, 0.24802620815379278, 0.17883946640150888, 0.20089299444641384, 0.20796935473169598, 0.1387971064874104, 0.07338876663041966, 0.17048853236649716, 0.18935522570141725, 0.12891986221075058, 0.2517422730369227, 0.16056267784110137, 0.09842168765940837, 0.09251297079026699, 0.15066187482859406, 0.15865607586290154, 0.1755529548972845, 0.09917906844722373, 0.2751974101577486, 0.13130728767386504, 0.09869424160569906, 0.12377520969935826, 0.14619216110025132, 0.18731628225318023, 0.2202188524284533, 0.11429038936538355, 0.110078220388719, 0.16752394501652035, 0.13784660106258734, 0.286284862352269, 0.12826602586678096, 0.11562991248709814, 0.10332368247743164, 0.11734771888170924, 0.1321654173412493, 0.15730876315917286, 0.11164003836789302, 0.15173144957848958, 0.07249456604144403, 0.10910458370511021, 0.10030380809413535, 0.17497975565493107, 0.13698790142578737, 0.16968384411718163, 0.08699686785361596, 0.12155729585460254, 0.16079956798681191, 0.14468885319573538, 0.11063165390597922, 0.1523361328457083, 0.12643076506044182, 0.14188517364008085, 0.09234909779791321, 0.08887944290680544, 0.17315191802169594, 0.15015655622950622, 0.29265266922967775, 0.103709965678198, 0.20503600713397774, 0.12758829151945456, 0.12367570932422366, 0.060261061415076256, 0.08521385424371276, 0.10117531847208738, 0.10008301958441734, 0.08179787825793028, 0.15598390996456146, 0.15121541012610706, 0.06346179252224309, 0.11153918092272111, 0.19063188933900424, 0.24250841566494533, 0.0603020042181015, 0.1210812356855188, 0.1147763832871403, 0.1532987840473652, 0.08810472554926362, 0.1891098538679736, 0.18875065099980148, 0.08370771684816905, 0.0911937765777111, 0.15730466480766023, 0.12413065348352705, 0.10646348792527403, 0.09104194079658814], [0.018717826144503694, 0.014053997966194791, 0.019006218794467192, 0.06887371997748103, 0.04194108749340687, 0.024933174684909836, 0.0215477463456669, 0.04073633499709623, 0.05869687534868717, 0.009422852275227862, 0.025321296715576733, 0.030536851047405174, 0.02007164430272366, 0.025769002602568696, 0.017909159983641336, 0.059095745374049456, 0.04117426149813192, 0.02578182691442115, 0.038078296197844405, 0.026764247233846357, 0.057735051959753036, 0.060566069691308906, 0.01941535505466163, 0.03726944852886455, 0.010228616850716727, 0.03398704216150301, 0.02061269964490618, 0.04085312783718109, 0.0849951963339533, 0.04537436951483999, 0.04065620340406895, 0.029415843343096118, 0.0940054492758853, 0.02142061772091048, 0.04749280673318675, 0.05022327575300421, 0.03176397145060556, 0.022174424325515116, 0.0989058291805642, 0.030964487564883063, 0.011284833790601363, 0.055579336027481725, 0.03627911309844681, 0.01696820154653064, 0.023452248257984008, 0.04926285014620849, 0.028661441324012618, 0.04146545819405999, 0.027548365694071566, 0.034059943963906596, 0.004859423955037657, 0.04777172873062747, 0.02308563918008336, 0.032653147487768104, 0.04357956296631268, 0.012422053392843475, 0.006923612722727869, 0.01715789279634399, 0.027434665277334194, 0.0894528321389641, 0.031398095190525055, 0.039113367442041636, 0.047681687133652825, 0.012274147177647268, 0.028364192095718214, 0.020905171986669302, 0.013520847556979528, 0.03349522640928626, 0.010125601664185524, 0.058648427948355675, 0.0531006238556334, 0.03119516232982278, 0.028892217869205133, 0.09139047709426709, 0.0706415819004178, 0.12057100449289594, 0.07251705269196204, 0.08812311384826899, 0.03885256572227393, 0.0581401577219367, 0.050337059290281365, 0.03964070450248463, 0.0586547926068306, 0.058583587141973634, 0.11982916215700762, 0.02945035702681967, 0.05100054779489126, 0.054100608054016314, 0.006379238072051001, 0.007642411161214113, 0.037807896600237915, 0.06603337238941874, 0.08363486932856695, 0.04834426300866263, 0.10068581652428422, 0.09353436276848827, 0.023043566616252065, 0.029725713322737386, 0.036283523576068025, 0.009960183308326771, 0.05248640038605247, 0.02461491122708789, 0.022699230450338552, 0.029524069678570544, 0.06278190721890756, 0.07498352069939886, 0.016137701825105717, 0.101025905060981, 0.032690527981945446, 0.03620292718655296, 0.027119908149221113, 0.058566840897713385, 0.05973415183169501, 0.0334982696388449, 0.0409763192624918, 0.08114801134381976, 0.0726634601929358, 0.06790664472750255, 0.0400878285456981, 0.04665140973936234, 0.026069946454039643, 0.04434072319418192, 0.030860641172954013, 0.021889648267201016, 0.06621043610253505, 0.05407528512712036, 0.036841462565852065, 0.022272192740014622, 0.070475306894098, 0.041550085081585815, 0.03298909356817603, 0.05298632123906698, 0.036602397715406756, 0.04957768700218626, 0.040254157834819386, 0.011796701100787945, 0.025403748898367797, 0.04156162356957793, 0.0756928137104426, 0.013214251508803239, 0.09470218938908406, 0.011817624576256743, 0.033769113676888604, 0.029175879433751106, 0.06292403994926385, 0.025641271777983223, 0.08752033047910247, 0.02632059220091573, 0.0638430817052722, 0.059391383081674576, 0.0771565901647721, 0.01168078017820205, 0.05998791714331933, 0.029917911759444644, 0.012051882854263698, 0.03355243369670851, 0.027283502942217246, 0.04823299344362957, 0.041340987730239115, 0.019346705970487425, 0.033154659505401335, 0.024521093582734466, 0.03816733695566654, 0.022190880496054888, 0.0623439671471715, 0.016732846586299793, 0.02210766665770539, 0.041393689545137544, 0.05287441724379148, 0.021945815699707185, 0.005031278639632676, 0.023494103690609336, 0.04236883257648774, 0.05304744367354682, 0.02922244729208095, 0.06943795577223812, 0.021499982569366693, 0.012084080189067339, 0.01919174044659095, 0.03324823626982314, 0.015618653069915516, 0.0022394853211673243, 0.022652374214625785, 0.04759691096842289, 0.03728918032720685, 0.03344147286510893, 0.025261327790628587, 0.05989623349159956, 0.02451965508849493, 0.06731308264923946, 0.03860286144273622, 0.1228861388351236, 0.023360167663278322, 0.05381519586912223, 0.05156301939859986, 0.01847020157479814, 0.04302010405808687, 0.03969246654638222, 0.03727777076086827, 0.030757683661899397, 0.013411414277340685, 0.04922101506963372, 0.052201887260058095, 0.03350130269037826, 0.056084905684526475, 0.06857400427439383, 0.05232415248506835, 0.08649047038384847, 0.10711687643613134, 0.026823914210711206, 0.04079026496037841, 0.06804604296173368, 0.012908230519055255, 0.007815475758564259, 0.0365223543319319, 0.05064020159521273, 0.03333770111203194, 0.06571076291480235, 0.04593272580366049, 0.01718394854106009, 0.0530048316743757, 0.03931543517059513, 0.021140457397060733, 0.034551447590014765, 0.036572240226502926, 0.0788600319730384, 0.06194029309387718, 0.04738798325083085, 0.007883917889557779, 0.046800466919583936, 0.03159490766535912, 0.022312424777607833, 0.023360281317893947, 0.030380021248544966, 0.03570955419646842, 0.04049680535016315, 0.10084132317985807, 0.060979541790272505, 0.012041587781693255, 0.10533140652946063, 0.07005399771566902, 0.06399957223662309, 0.02618689026816615, 0.0062653094979136115, 0.0717226035360779, 0.011862535960972309, 0.03148289510448064, 0.03053732941459332, 0.00821917356058423, 0.028671914512025456, 0.0874710213392973, 0.051120719739368985, 0.09057680504130465, 0.12896978881742271, 0.07837482515190329, 0.1193742858512061, 0.10877211511667285, 0.06143044188086476, 0.032297662991498194, 0.06588796233492238, 0.07638939097523689, 0.08188770950904914, 0.02973554190248251, 0.14241562517625944, 0.05404682397576315, 0.021183505354981338, 0.052019938094807525, 0.06840472335794143, 0.14139886759221554, 0.07264053249465567, 0.10678119837705578, 0.12478374343897615, 0.032302735040762594, 0.047378246273313246, 0.008193322224542499, 0.1262681202164718, 0.06642245115446192, 0.07220810891262122, 0.07414509568895612, 0.05308764687340174, 0.03840448833735926, 0.03543241335345166, 0.04554362328989165, 0.10146258984293256, 0.0347869840583631, 0.037504119865064106, 0.07482546275215489, 0.05032556829974055, 0.04133329992847783, 0.004039455521186548, 0.02855289607707943, 0.10103064123541117, 0.06161080327417169, 0.08422076396111931, 0.05073785296242152, 0.0321744647808373, 0.09547752421349287, 0.09696282379861389, 0.06791777948715857, 0.041755640480135164, 0.06723242519157273, 0.015683023990797143, 0.026446022791787982, 0.007236083187828106, 0.020103518485224674, 0.036058341552104266, 0.06089888433260577, 0.008272493690518396, 0.03433920522885663, 0.06058206954704864, 0.03123667510226369, 0.010677511870328869, 0.02569372423126229, 0.04362010882635202, 0.03406587435996958, 0.015189206560275384, 0.044155340641736984, 0.04978869782228555, 0.03673182148486376, 0.042630356936050315, 0.031952587222414355, 0.019995938454355513, 0.03314404043235949, 0.04988187085837126, 0.05902008871947016, 0.07658799817519528, 0.03307700456519212, 0.030716927456004278, 0.018692552411396588, 0.04182081716135144, 0.025332636732075895, 0.025548112312597886, 0.03430464404768177, 0.054539715205984454, 0.029758642627192394, 0.06718375387468509, 0.04604580705719335, 0.04033194508935724, 0.03204855921545199, 0.029154956806451082, 0.08365450613200665, 0.04375739681667515, 0.0437600804226739, 0.0444308971054852, 0.02406511126485254, 0.06020849530718156, 0.04370732771764908, 0.03665959482480373, 0.05591744324192405, 0.027730935718864202, 0.038706083582448106, 0.11154368639524494, 0.1967680443610464, 0.09004720167389937, 0.22656886811767304, 0.1277605987020901, 0.08914677213345255, 0.061885698166276724, 0.12190328086061136, 0.1816915933574949, 0.22044076052095207, 0.10201754327863455, 0.095946249419025, 0.13453292101621628, 0.12705728358456067, 0.18124048970639706, 0.11257444894207375, 0.1496229970029422, 0.11818569605903965, 0.1818364741546767, 0.10965610375361783, 0.10865352076611348, 0.13983525149524212, 0.12496820996914591, 0.12073976972273417, 0.1326001818690981, 0.05226540831582887, 0.1882549404565777, 0.11881613651556627, 0.11408730383430209, 0.2103515283337661, 0.17495551838406495, 0.1235438563993999, 0.16830459955547536, 0.23430823854037694, 0.0981792878093464, 0.07621563172766141, 0.08635405091834919, 0.15816208879862512, 0.0828009769320488, 0.2446133941411972, 0.1317879483103752, 0.1402899378112384, 0.1776348224708012, 0.23540974514825003, 0.1129188190347382, 0.11118395426975829, 0.10000475057001625, 0.08215491659939289, 0.11989972979894706, 0.1665690562554768, 0.14458624513021537, 0.13542307753648075, 0.10849795304238796, 0.07226577081850596, 0.1757355079587017, 0.13886293795491966, 0.11535507866314479, 0.18261494381087168, 0.1545806045510939, 0.0579213233930724, 0.19961844783808502, 0.278294569679669, 0.08187182500426259, 0.11643939119364534, 0.2042195395167385, 0.15895429200359754, 0.17953101572181496, 0.13994246002818855, 0.06771335045674018, 0.128110478499106, 0.20306843199900218, 0.17918363293366774, 0.20836158868457588, 0.1901529793228422, 0.18001885525882244, 0.21118038600044592, 0.19007106657539094, 0.1823899144572871, 0.18726873051907333, 0.15822255983948708, 0.20746461967272417, 0.12942381016910076, 0.12447472502078329, 0.15974964361105645, 0.1719412487000227, 0.2684846632182598, 0.13153348410768168, 0.11944089084863663, 0.16872435488871165, 0.10153942036309413, 0.13090027522827896, 0.1125671479052731, 0.19957758645926202, 0.20718419472021715, 0.1876597838210208, 0.23834332344787462, 0.2663234206182616, 0.10755437546010528, 0.09484346716531686, 0.10525443351694516, 0.1560443945761238, 0.2280123292335442, 0.23688545024820737, 0.11310956201383046, 0.0861003195334758, 0.16277889534831047, 0.18569741983498844, 0.16381972735481604, 0.2385915315576962, 0.18634088816387312, 0.1928288500223841, 0.11544521525502205, 0.1449170580932072, 0.24520732941372053, 0.0567386368555682, 0.131808426497238, 0.1910304743796587, 0.16990944344018186, 0.21629997342824936, 0.12272299187523977, 0.2647628443581717, 0.17073627907250608, 0.1532312155302082, 0.1487571998898472, 0.1605811882764101, 0.09939864237925836, 0.11334049462207726, 0.10690685627715928, 0.13283722129251274, 0.09499429192926202, 0.1373641626643283, 0.16320405182029518, 0.1310066966606038, 0.14092876496059553, 0.15736244884984835, 0.1356341697807823, 0.1202155878501279, 0.18574711573975428, 0.11327488707112414, 0.1700578254780599, 0.08201011722641331, 0.18212626289044107, 0.17398472476218427, 0.18214850526835236, 0.12056557621274676, 0.10032362131667988, 0.08431911082672221, 0.19667522077049526, 0.11986131114619118, 0.14689012936183385, 0.17932660026209696, 0.13034497573971748, 0.0637036156175392, 0.13976830723030226, 0.12640784414751188, 0.12724067802940095, 0.17824056425264903, 0.13788960661206925, 0.10638387541153602, 0.08421325936381306, 0.14747284166514874, 0.15581192847873482, 0.0693034226340907, 0.13736530260315963, 0.07513856595116002, 0.15165774710476398, 0.08544440008699894, 0.13977415620216302, 0.11213362509650843, 0.09202301422400133, 0.14937805943191051, 0.17325740307569504, 0.08997674938291311, 0.1758383602968284, 0.11431352740951947, 0.11039048220430102, 0.17959293882761682], [0.009280606738424726, 0.028096046930711185, 0.005164559032501919, 0.024148778025326983, 0.057197034758116515, 0.05696971195616892, 0.07729172719908611, 0.017843895092872635, 0.08526352979242802, 0.05158652724432094, 0.014219345924045359, 0.010333641349071903, 0.023305591395390884, 0.04322427185252309, 0.034736857283860445, 0.04896449151315859, 0.01217795126805348, 0.0022100710401511087, 0.04744780968342509, 0.10755688603967428, 0.0433736174101276, 0.019681439169549515, 0.038770995635007105, 0.014336218491994908, 0.020273550879210234, 0.013226788291441543, 0.04111128327037607, 0.053188561994050226, 0.04491222609898873, 0.03049990820831486, 0.040315158132995875, 0.02328410219135029, 0.030118116909371953, 0.013040382847455996, 0.032116375397890806, 0.03234213756929551, 0.022198503836989403, 0.06190744521362441, 0.020981826087726013, 0.01664175495638379, 0.024057257222011685, 0.013766864846859659, 0.018499112255605202, 0.03965415645922933, 0.05040441746158259, 0.027713499065222483, 0.02373520584244813, 0.019500964121626954, 0.032771382214767594, 0.06758976208844356, 0.03519546213958945, 0.023864076605864933, 0.1191732766372817, 0.026131457349817668, 0.04208863154053688, 0.037600746644394736, 0.026388009744031087, 0.016051107186025808, 0.1115118223907692, 0.09759421420416661, 0.023753568696390306, 0.018038298768390502, 0.1484240527663912, 0.03320880320721439, 0.05624017485284379, 0.042670797623161755, 0.050662891806236336, 0.02309293343153383, 0.03917445255709546, 0.007337263785302639, 0.04519469004922679, 0.031877066274838786, 0.0455121223016509, 0.05989256940249886, 0.2722150044781821, 0.16318149731627532, 0.13109707752508776, 0.10150683032614843, 0.08012967277318239, 0.09967150845165763, 0.12653809572969163, 0.09537843774471964, 0.07906604199005024, 0.055306486918457916, 0.06289926663573299, 0.04999254331258791, 0.07284443226775952, 0.06212516674505813, 0.023912540969571898, 0.06589665436851126, 0.0649292194949729, 0.14009576823030198, 0.2125422464949744, 0.0791093868070415, 0.06481263360806874, 0.12234738203031675, 0.007208958750457636, 0.06183237888451133, 0.05059820706290858, 0.04661404960123556, 0.06888468510338239, 0.10423315688967705, 0.03597583508651171, 0.02836201060563326, 0.04363104681085263, 0.08197374774941377, 0.027836736291646957, 0.10831459252429859, 0.04975836391427687, 0.039543080276676586, 0.030020326442484344, 0.05431821423449686, 0.02572748134844005, 0.011583228894908513, 0.009860333487657564, 0.06544672458299569, 0.0452889182072665, 0.0590993416096483, 0.051544407183038335, 0.048777161565210135, 0.015242790470698049, 0.07674823421984911, 0.027931831278172985, 0.05445518670603633, 0.017882624175399542, 0.04167846729978919, 0.021859897899308374, 0.012749028392136097, 0.04015071517122643, 0.031190541506345783, 0.04325480932103736, 0.03327080434454339, 0.10288396464394671, 0.037362991366535425, 0.03181541797571948, 0.024475799673902135, 0.04384966740118606, 0.018660705370296325, 0.019675690281604017, 0.08324523416480847, 0.04129191268501537, 0.03371932616989527, 0.08194281333791358, 0.0595033752865025, 0.034312565944024494, 0.021582957224122117, 0.020092276856303215, 0.00548342808282801, 0.07383848607007946, 0.027626342938414643, 0.03344213104407702, 0.0050894634415661645, 0.011068085956919407, 0.008952321318377341, 0.0394141009476568, 0.025384461540462713, 0.02705018867605499, 0.01616427834544863, 0.054176397022924254, 0.04017027055046388, 0.0681260083136814, 0.028493951740009443, 0.05772469073001828, 0.010769316810183227, 0.028466264118573496, 0.016985717928037047, 0.024452983933900083, 0.004046483023557812, 0.03595725340502603, 0.05366196569853595, 0.01416409112113927, 0.0468767410410302, 0.017578772801373686, 0.026817944798884646, 0.04956290511680501, 0.023032224903415357, 0.012546458547668797, 0.052296488612358055, 0.042377226054668427, 0.02858425796564136, 0.02356038468756846, 0.04483565681480935, 0.0176716913868274, 0.017253264285890118, 0.0871048838432346, 0.02801262783551855, 0.05576950225180813, 0.03726856643334031, 0.015761983414579715, 0.06484362230237041, 0.024667241544063603, 0.03572682969804321, 0.021805864459435855, 0.04342241086331861, 0.031712121197155545, 0.04464896468977843, 0.07108861434140376, 0.07319548593035766, 0.04039660947663443, 0.04561084575418915, 0.031312694773077965, 0.021352852428598062, 0.007201625483243593, 0.06457209294395787, 0.006194791473847414, 0.06490072780953986, 0.02649665337854198, 0.02486604721551495, 0.01972511307602482, 0.039855755998619964, 0.016057146147691777, 0.02631919950778995, 0.05564729809494955, 0.03802811853321535, 0.029315345521484102, 0.0253820340814335, 0.013049623646241213, 0.029282887798867056, 0.037215535528957844, 0.03603346985099571, 0.06174395220088107, 0.06854321235524756, 0.03372882566015635, 0.07858203617589814, 0.035014252577509196, 0.04287974230412926, 0.024124842702544162, 0.02383040091288941, 0.11379060761204787, 0.013517383635709328, 0.027961452724412084, 0.021390580671972463, 0.014324970077723265, 0.019314270300258483, 0.11169352728341307, 0.02482886180015547, 0.025665753321456056, 0.044368139401610406, 0.027155816222407987, 0.0550157176995916, 0.0058405385186363545, 0.04722105685089316, 0.02478841263135629, 0.013355591201356478, 0.039052689447999, 0.06818728681121554, 0.051320276888353486, 0.08141378672527415, 0.08587801110531602, 0.1566473679350955, 0.11192353029868432, 0.13120151763515814, 0.1678887525839465, 0.20973471286041395, 0.13892967865935393, 0.17458060064486094, 0.17586721160582133, 0.07486209007246153, 0.16490147502294608, 0.17772510834038258, 0.17759097553789616, 0.023629895511216352, 0.020356880068512898, 0.06987645902803966, 0.06452298736465828, 0.032812467510146756, 0.08924350408571106, 0.19881632445114, 0.3065840516771589, 0.13048931370888436, 0.17876845092645713, 0.16876251569816045, 0.05890982677893979, 0.07313247716852597, 0.04392859459455524, 0.10918375517108611, 0.10517068193959338, 0.08313259735171284, 0.04921378867168512, 0.030831070616841316, 0.10973281892282621, 0.036770708326782496, 0.10129267788891282, 0.007951109819779438, 0.06255477440676518, 0.008686301664316227, 0.04643823439255357, 0.07280091103166342, 0.07352327262716633, 0.07493405549653939, 0.012298990889186305, 0.045016659423708916, 0.043584835183407576, 0.028485497193677083, 0.023897630162537098, 0.005036166212188878, 0.026310617736141597, 0.022451366697038923, 0.03315956870626126, 0.017187444692743675, 0.0555863758283002, 0.03416232472019536, 0.023770611799721206, 0.021601208119786212, 0.07568092577691589, 0.036819929257035255, 0.09610990528017282, 0.017686970299109817, 0.07790468180818216, 0.04555063934198447, 0.017790592774482708, 0.044889559636690786, 0.02571475881684039, 0.02394626585633627, 0.05054820581738438, 0.09439040254801512, 0.03148028613733394, 0.03819636807643941, 0.03184413018503359, 0.013769293154057647, 0.0675432485129152, 0.01614732345167015, 0.01851210620121232, 0.04332520393654704, 0.07199677239571299, 0.06781423504331283, 0.03560843890798943, 0.05546623102522322, 0.012872801661225302, 0.01303304364306054, 0.06949676440230437, 0.07132684120110103, 0.023356678296944926, 0.006561512934110526, 0.032472188983644755, 0.053206726376499446, 0.046097524996314726, 0.038177274101014645, 0.023470607719251087, 0.016931077199322835, 0.09786809807909386, 0.08634564386946814, 0.024111187185293863, 0.03721835823463542, 0.01743142892207418, 0.013532115479132958, 0.042819135556263585, 0.08380076435527631, 0.05031207902356982, 0.011896403340090598, 0.03722744381853512, 0.029993371638868536, 0.20506935034479412, 0.09740354586392641, 0.16523610135274275, 0.12555622841630662, 0.08003969224435942, 0.13600508416337626, 0.19751568138599396, 0.11869633437267371, 0.21320997923612595, 0.1121504120528698, 0.14693286349730833, 0.06787271797657013, 0.09538820186363799, 0.16271470593554632, 0.10027338258389916, 0.13677811196872167, 0.1317068226635456, 0.133259812902127, 0.13050498786781514, 0.15682074720306055, 0.20136951601931027, 0.14549111228968414, 0.12415896196450506, 0.14130319415458611, 0.08232201941843544, 0.10107667305107627, 0.07940720939742667, 0.16983770871801035, 0.09638460339712245, 0.20398908188300474, 0.11010180626596723, 0.08865389786660671, 0.1276224489722933, 0.1717258816851037, 0.09411109717828886, 0.11937245380665575, 0.06878698963139739, 0.11771950178912707, 0.07365644869527646, 0.11579333086098943, 0.11688844566898686, 0.09929676713155848, 0.13755135690527304, 0.16602743603289127, 0.22300092742911407, 0.20485814953488962, 0.1908317179019962, 0.17233918234705925, 0.15494923905602523, 0.1176817888127906, 0.07414889548506055, 0.13120206046317304, 0.26206306208457264, 0.09090577238904578, 0.1438145065414054, 0.10398836859634944, 0.09063712001911231, 0.11340255343488284, 0.2917504347860813, 0.2299583948084286, 0.11161876629505839, 0.13027682368244442, 0.2211672815361193, 0.134004410090191, 0.102637826065932, 0.23712969571352005, 0.08598832054329769, 0.10735131028507437, 0.1352759168616363, 0.21294992390487874, 0.15162790513464383, 0.18972607223050936, 0.16611173722360814, 0.25467205154044287, 0.33937257368649754, 0.21540778130292892, 0.3388462747846331, 0.32724443876317566, 0.13257124913590296, 0.3401095712823527, 0.29099354254347937, 0.20861397657011235, 0.3857988624700478, 0.23241311737469264, 0.3266856516046183, 0.1475929016513484, 0.11293213867715426, 0.13407652479197296, 0.11448993294366769, 0.11254511587321758, 0.1447495413678033, 0.24195017133440289, 0.3906503607119833, 0.5401480187262807, 0.4726355214204107, 0.2851928009518555, 0.07451643754861184, 0.1540097123278039, 0.17655816381531103, 0.23370122111269406, 0.25467368002448765, 0.22216153889894485, 0.20134255103766918, 0.16314906334238394, 0.1965190762920039, 0.1727655330406768, 0.17143271384494646, 0.24044585919805936, 0.16820763690131052, 0.11288311452205692, 0.18495909231049673, 0.12361751816102437, 0.2077267648918288, 0.12010311388543674, 0.12082787070955549, 0.15636376743870123, 0.16394337000591414, 0.1979983640568597, 0.11968969606927463, 0.1742233655282429, 0.1659886645419257, 0.1446693113871983, 0.15619034745863505, 0.11809427025062696, 0.06107471989733832, 0.20814060339970247, 0.0836941393624459, 0.0890482963461961, 0.13581533863076142, 0.10497480245040995, 0.16836276357727392, 0.07939502969384193, 0.15430974694234983, 0.09834058236862932, 0.0988515056669712, 0.19192331789859704, 0.14654894838375704, 0.08547101223043033, 0.10449032844709498, 0.17323946260980197, 0.19674295213605675, 0.1125890374449747, 0.17284623799579485, 0.10538387764245272, 0.18555137195757457, 0.1508796845695802, 0.0942413080483675, 0.20389047717409475, 0.15666587837040424, 0.12824921176901885, 0.15104178658553533, 0.08257477371288197, 0.09714161099067756, 0.07077602004366261, 0.14881281261997564, 0.16895887016185693, 0.08921235254300491, 0.1251169177038329, 0.1234636807015964, 0.16701022615390165, 0.15242766721972398, 0.09836253976183278, 0.14500927100224154, 0.12997043798012392, 0.17663137774382318, 0.19011252506503037, 0.09917247987219266, 0.07069402587200914, 0.14762385641889914, 0.17047720083168574, 0.18854937037186964, 0.1935073443289314, 0.11195930266486746, 0.07584029329674584, 0.1761313381471804, 0.1388751244438546], [0.022490548701690774, 0.04726381812776838, 0.035080721867935996, 0.036498734527932744, 0.08809668490929262, 0.06149908248335123, 0.015286279476380773, 0.066743812124644, 0.021290145614849668, 0.01818152902913945, 0.04291821523968663, 0.043163651533957036, 0.0024178433398317012, 0.014698403521573969, 0.023557785898447037, 0.012953543087600597, 0.06070953235030174, 0.06296790045286928, 0.015177091317517417, 0.027965473044397574, 0.07274139672517776, 0.014714087858530027, 0.04704834933259657, 0.0329257523241852, 0.07853939703532628, 0.026851315151101778, 0.034202419354447296, 0.04705743491649628, 0.014973831063668643, 0.06008688147578921, 0.03533410041459969, 0.014821303176826664, 0.04193348790119801, 0.08645307631897074, 0.012964599815729474, 0.014788696176505514, 0.026427490304091146, 0.03225798565628273, 0.049375358037650585, 0.03545576174344335, 0.026519989894170846, 0.003073193453019485, 0.07085451297461987, 0.010194582382350095, 0.02672331969785903, 0.017306301975622773, 0.025138726690784097, 0.03435491670721343, 0.10204684242073979, 0.03561515301199896, 0.02722990037208157, 0.014951424141015326, 0.0456066049103226, 0.029508833174726794, 0.028465320954897573, 0.016464972835300223, 0.030773910826870372, 0.07231815372194562, 0.06722746510058641, 0.02502607800332563, 0.04309881751292518, 0.04689349407064063, 0.0799463801085949, 0.08140515575983695, 0.02046809026173183, 0.034702733757772615, 0.027849221335990087, 0.011418020036736769, 0.09123191024575915, 0.09054791980556079, 0.051709165663591454, 0.0008516716043232009, 0.02836968483669417, 0.12429591747266905, 0.2695427978677409, 0.15740975631134851, 0.10204467110868011, 0.1308802313038281, 0.10357647748397929, 0.11063611188105174, 0.10385401187730686, 0.08839975257537194, 0.04580153105780482, 0.06365817412734032, 0.09028769484055893, 0.02954587440139481, 0.04258791796330895, 0.1542295441031456, 0.01760944428055414, 0.022831268275954893, 0.04323063651099801, 0.1344654339232615, 0.2749178537300655, 0.16734363112066472, 0.1382953298411199, 0.11919781246355601, 0.045448241622320244, 0.0443650283185499, 0.040664054054234705, 0.09115784136312348, 0.13729073160461017, 0.07927836238273553, 0.05861195669110332, 0.048817612430346866, 0.0370927105125572, 0.08345390403909342, 0.08974858519754239, 0.052768223120697906, 0.02292025475097554, 0.10539112439645187, 0.08342480845749378, 0.02648052290481116, 0.022914073296955655, 0.09019689328436341, 0.02254503167101315, 0.09385043116552488, 0.030943246026124274, 0.03408931435218879, 0.058825905567833355, 0.028060786858467118, 0.030501034576445818, 0.05576525801526649, 0.021716579429007003, 0.017697687759729366, 0.05656750014583979, 0.013373160169326832, 0.043272305346493206, 0.04241415871573346, 0.07633315399289131, 0.03373875941282936, 0.016830365639179945, 0.017626100618924414, 0.020011454853894453, 0.04058427869209221, 0.016519793375794376, 0.06122979229050023, 0.03870841435023716, 0.0826529748737812, 0.06463778191911322, 0.028277851907270293, 0.03128187571253095, 0.03681995979111109, 0.029663532373628447, 0.015307217370718718, 0.05823187530040741, 0.006692876889636474, 0.04304092829780919, 0.04220424372968929, 0.025225497748968855, 0.030720774749560014, 0.01929352239572576, 0.028429701259093623, 0.03407926185588751, 0.03578961454331875, 0.03474066047263997, 0.021286250823842626, 0.01773946007181491, 0.0105395258371053, 0.06593955135239021, 0.05755505019000598, 0.019929228283997093, 0.024839345166193585, 0.0634439131245017, 0.03272419010422059, 0.007926741930922227, 0.05632658628746867, 0.02930749487131834, 0.04545879962721041, 0.02047900789018188, 0.028443056524598172, 0.07290277949401311, 0.03858023908521448, 0.044560151241187534, 0.01232955973994519, 0.02811991948900478, 0.03142295332093324, 0.03401310808424439, 0.03469228431848543, 0.09485127031803131, 0.043743473278092485, 0.03541817768876042, 0.022280111243682246, 0.0384973933521126, 0.0412556517736188, 0.02787610319709139, 0.0018362964204113397, 0.040688277754400454, 0.007266317860090307, 0.014722438928272043, 0.03044966608285904, 0.031305678720985136, 0.002060350591948788, 0.05315650121441909, 0.05599688272923231, 0.02855043299496174, 0.018128101181771075, 0.07780682348779269, 0.02110505992147539, 0.014847552304023078, 0.025191128253936768, 0.01851883896493486, 0.03542842356754201, 0.04804979916661978, 0.040752989639128955, 0.06616461463272572, 0.0581102886104158, 0.05002812568896583, 0.02395429292560688, 0.03698517967547689, 0.06777760772300617, 0.02823312457517854, 0.021446532669610212, 0.03519529250583478, 0.02547293572154428, 0.04757797644872751, 0.06789084164691822, 0.02973596259419407, 0.016802506687651788, 0.08168940086449895, 0.029403782383139645, 0.029400549163775783, 0.015248992280768496, 0.05168720827038799, 0.0294538073773895, 0.038237293916089196, 0.02927917960499014, 0.008194631797128489, 0.01933189694370542, 0.027437189427603568, 0.005982679306595985, 0.030812957124518495, 0.0637019599920937, 0.032036226841488054, 0.027322016589875733, 0.012485545610875955, 0.16220106849712984, 0.05900756974837609, 0.011436122502865536, 0.013133208134344645, 0.10598364831613642, 0.023594460716204982, 0.04742803717298167, 0.05735089257359505, 0.042441931154046736, 0.049842407261686664, 0.05503381762121405, 0.11086526672754969, 0.022668409693453993, 0.03266868933237024, 0.06146031777773585, 0.15637319907546043, 0.23999984455960138, 0.15020513933684143, 0.2604609323399407, 0.2080742155334779, 0.21250485921544687, 0.1839899814554623, 0.11509400552936963, 0.10644340328872204, 0.11289173870214395, 0.057015926976289065, 0.058959291981799264, 0.023121516719194393, 0.07458592631987163, 0.035195808192448955, 0.05453024285712412, 0.09909649073545422, 0.23178862088492938, 0.29092707325305256, 0.18306968440966948, 0.37031857456479755, 0.25197194357003483, 0.06773480573402983, 0.006847216040893857, 0.024536783008703163, 0.18679450239453996, 0.17129938171378203, 0.062313039521021504, 0.0938018751995904, 0.015699863533622453, 0.04610456479713321, 0.027230811305344105, 0.06036637004997049, 0.12130516581237316, 0.035989293828606606, 0.08476594649255276, 0.07108925216432128, 0.041056600133223195, 0.0444008278261338, 0.09081862135125057, 0.01765500790705638, 0.023294902772509625, 0.035872948821634054, 0.01443074011643018, 0.0368762340928827, 0.024861485763852085, 0.013103900510551674, 0.02781295363924333, 0.014815469472003835, 0.029109148907342126, 0.033193251184586964, 0.06327713600226811, 0.08272760694048234, 0.012842970717299198, 0.06681916343846492, 0.017307095861594592, 0.014617031905800104, 0.03921867607693587, 0.01811801645505641, 0.028692016111952916, 0.029922267954264368, 0.02710577765745776, 0.016401019213455062, 0.013203519629314542, 0.036819552670099905, 0.022640208081741418, 0.0851459057469453, 0.016595555203301565, 0.06054396302040134, 0.03250101315123694, 0.045446989725210836, 0.012021280924922653, 0.05593002667384488, 0.04636764978723867, 0.036805188083755117, 0.025518655411100814, 0.04278858790972403, 0.05599102018667119, 0.028096564313662902, 0.026026633867461766, 0.011021430737205913, 0.0264269356017134, 0.01539109617338649, 0.025116462260484695, 0.055597405415028334, 0.06077519418405635, 0.03501955532867994, 0.05229449711207833, 0.057348707690835, 0.03868353586377842, 0.04826140370486038, 0.03598449997869985, 0.05095562877665673, 0.010305674680109535, 0.02132125474911715, 0.015989670929099833, 0.024429221637547016, 0.0265363290174199, 0.002814015976452668, 0.046355785602437596, 0.02443908414404307, 0.012907702958078256, 0.08957158933792796, 0.19415793727551187, 0.19329093237008366, 0.1682396773248911, 0.14125025485243115, 0.14366583951881953, 0.1056703958394272, 0.29282572280083385, 0.07418814195053917, 0.0875315602336611, 0.12468291313520499, 0.09893643789525543, 0.1421536292348589, 0.1356612161866256, 0.08342236573142664, 0.06425804658127682, 0.24741102116448538, 0.11195776239037514, 0.1898785119077989, 0.15043105078595026, 0.15522465642009461, 0.09587363938667945, 0.12631766684353352, 0.12495366217834608, 0.1415832391274827, 0.08212645884071078, 0.10031539747225386, 0.1573106087744236, 0.1702860575169325, 0.19416738248297147, 0.09456812444009952, 0.07307805866003036, 0.12521569883184774, 0.11852736558232989, 0.17760939097830228, 0.09044161372418914, 0.1410815031932933, 0.07859873492270708, 0.10087154512958867, 0.08443079769079175, 0.11629662742572171, 0.07338846128966127, 0.23084814420768193, 0.11301648736532245, 0.06606307186718498, 0.10362012764172894, 0.159129869725023, 0.14810663408466748, 0.1447223185428551, 0.10984244304043905, 0.13202916750950472, 0.06246028162006821, 0.11146736477634736, 0.13027193823031016, 0.24272456978048595, 0.16220743315560476, 0.1201975659600326, 0.18893126345106534, 0.19006297843796865, 0.17894550785422325, 0.1761472158666168, 0.156025409166302, 0.26514171117118424, 0.2027968687138387, 0.15650110292647565, 0.1361780020275286, 0.09143656319273369, 0.12799218270395482, 0.2492031678557396, 0.23484539400253976, 0.31717476195522715, 0.16497088915535382, 0.1219042172389371, 0.2531300942812647, 0.3951897599867412, 0.27502831923110144, 0.2727232814899513, 0.33957116731575554, 0.1971793044358492, 0.306934012898377, 0.3320697998361928, 0.2097521647810936, 0.2340560406446457, 0.22920655086636543, 0.1652437552277531, 0.13811426955674375, 0.06840217885162149, 0.34022864060742514, 0.13565154027725967, 0.14550076105764934, 0.1885027957281896, 0.22595912297921522, 0.4628603288105556, 0.3661023750901222, 0.4033804376210485, 0.3615218294518334, 0.17369144835642406, 0.13634771720639297, 0.18955444358289242, 0.2604689390531608, 0.3394758738577366, 0.20454862900078297, 0.1905403956770897, 0.20069685711392335, 0.1937781340841736, 0.09519721461193902, 0.20362363649266108, 0.19193805567920208, 0.08720631125782217, 0.20836317645651953, 0.19658502989581653, 0.07880667197917189, 0.11607884482613631, 0.33349711181862013, 0.06714692977922303, 0.15119003291640962, 0.0723696273884603, 0.2500181698373386, 0.16414608912808554, 0.12909017450043134, 0.10723583041025059, 0.1597508785447904, 0.13482642812388285, 0.059283828495868614, 0.19535498161401066, 0.07877904881856271, 0.20988282348428453, 0.15042692529303686, 0.21166557925088064, 0.09799004439264536, 0.1113937980096255, 0.14084108466548578, 0.06744849109756094, 0.10338169722152607, 0.10016657438661371, 0.12216892732041222, 0.11343182543558733, 0.187242810481361, 0.11289892438799143, 0.10868060788405792, 0.19923584908246994, 0.16785679358456815, 0.0876950261050037, 0.08299898702119078, 0.11436817661992141, 0.08504458689796073, 0.11525137137089457, 0.17081861251166888, 0.11213669886014291, 0.11523113745663847, 0.10878016254199402, 0.16297761111387185, 0.13310384484274046, 0.08541551485125508, 0.06813693272748164, 0.13915698789060116, 0.058745478812072954, 0.06393838873399155, 0.18586355234895433, 0.18677968318973268, 0.1941420188439744, 0.08543397100376231, 0.1907672977873257, 0.09896900757615056, 0.0735714825402413, 0.09742067887314729, 0.1833222351436104, 0.13371686051998818, 0.07342945159013782, 0.06822181745831456, 0.12633606871323927, 0.07893564791551658, 0.08319694282753126, 0.09938219469040632, 0.13248074613511562, 0.08153032511472702], [0.020290161416466748, 0.01893296415385391, 0.035242749245039055, 0.010520409809292426, 0.058542433993092606, 0.023996798055512563, 0.011588315363042057, 0.04150985134765506, 0.05377111144896064, 0.016243275088657225, 0.0152002429323537, 0.038730853503303866, 0.016848294230710183, 0.016914692274960022, 0.01076772394922695, 0.03302386509520667, 0.04357649598802839, 0.013173578423447907, 0.040818800750587664, 0.04378375450947455, 0.040163834645812, 0.03846893220075539, 0.004803213265924049, 0.08605673044387784, 0.022091470026810254, 0.016039115775908743, 0.03544816554390958, 0.02725173732531922, 0.0323496218105512, 0.023911809848089303, 0.018534547050616572, 0.0827214526278632, 0.03804849154715027, 0.04529277567884751, 0.033908335492014885, 0.015504345364336456, 0.05656100656571133, 0.04479691246524453, 0.02211085577229304, 0.021470076138419763, 0.025856004362659793, 0.01785723169866417, 0.04276481204267059, 0.015205888343708856, 0.04547965779368367, 0.02642023846107934, 0.04801904795957463, 0.023749884251239042, 0.015811290858047347, 0.046415198128670454, 0.07726203450667006, 0.04143449664115906, 0.01472701395063528, 0.054428930793489726, 0.023410750752581016, 0.021803900100556866, 0.025801051507837007, 0.06544760667851993, 0.03905012119295342, 0.05530793559072273, 0.061386805293815475, 0.049679165306900225, 0.126166611377682, 0.12189017156405108, 0.039315560699573586, 0.0555362761951983, 0.026553229628396884, 0.05675868756536927, 0.15312445483037404, 0.02256229699456266, 0.025188733025320938, 0.10194802058062383, 0.33126245172960417, 0.4130236958818776, 0.6971804552844593, 0.7168012995805059, 0.42319743282028605, 0.13227148593536445, 0.0906727702489921, 0.07922960285629545, 0.06383282225579023, 0.024577708848352944, 0.058683766052126884, 0.05048435227945447, 0.1297766212373972, 0.33805860419358524, 0.5379403914724077, 0.8845967128872871, 0.4651940550122942, 0.5193184592894146, 0.1369245941085475, 0.07692957948893309, 0.6338522934487888, 0.39180916281683104, 0.690241484769753, 0.6569292694330215, 0.37666385407958713, 0.10126109208379473, 0.03705757596929159, 0.11664194746741227, 0.18333721719682217, 0.1158111220491784, 0.14297004256929668, 0.05907984729856253, 0.07129757598574672, 0.045384303267513, 0.11606515198945999, 0.06316886216934238, 0.04519006583307471, 0.12860973099512713, 0.0739809444972447, 0.029937565526259795, 0.0483640117703804, 0.038520819773631435, 0.039599778662834845, 0.012973123911901243, 0.029231939996991838, 0.053878727102918286, 0.049301740380802324, 0.03938663045742682, 0.062383322178253105, 0.04255654589672174, 0.03379032468157155, 0.0263642576257033, 0.0423714652923601, 0.05977155268192291, 0.0381193136397217, 0.05836891901812383, 0.016356885599504625, 0.05843067927552121, 0.1307653688958713, 0.06595049612224102, 0.08151034225842782, 0.03312384723020451, 0.02171740384905466, 0.05506767312596951, 0.03141413915104099, 0.015407048531674912, 0.029172602109611034, 0.04333091041605387, 0.012068878460143293, 0.04561263369396329, 0.013653479100737189, 0.03642860793375543, 0.021706496398629885, 0.0755484893119761, 0.018960568654750074, 0.049643959517457655, 0.04672852185155664, 0.02332020364701748, 0.038403619812535386, 0.048801069746592214, 0.01614898755880339, 0.03835068051038044, 0.05236279166170529, 0.08108998981437512, 0.030146768050534383, 0.0382763978892139, 0.025266630541799322, 0.04351249995774456, 0.028308048411937695, 0.022112397743122916, 0.07968928997537919, 0.054591500998607705, 0.05547269067860075, 0.011924509956900562, 0.04572886334998267, 0.02344110162396516, 0.025285710946523716, 0.03557890567130276, 0.03926573248047914, 0.07497163955122232, 0.03710610818650041, 0.04949537052639893, 0.033719129394739866, 0.02112385873416705, 0.03988736894513879, 0.051861968357115984, 0.016994655930570195, 0.026491752659369792, 0.011845059443398245, 0.05066023534163833, 0.05184143928012677, 0.052884154221309085, 0.008739911019802094, 0.02993250704769577, 0.03397180226498416, 0.03683503005387528, 0.052375772036612034, 0.06071185972541571, 0.015225840665932213, 0.04453567648306489, 0.01913716926771615, 0.005475924333690533, 0.02679782623558172, 0.005108845794373857, 0.029348393569567373, 0.0442872648127377, 0.025174122470031892, 0.037208651791193655, 0.0159469384899629, 0.05981603065239532, 0.025859147676133683, 0.02984219742938876, 0.013324152129436178, 0.0448896546315934, 0.021916316389771442, 0.06363888337676014, 0.015522312971630266, 0.15930881298014096, 0.05662898898922971, 0.02168675102958722, 0.03625439067504235, 0.05645908721323524, 0.06945639835404498, 0.025213063594752123, 0.06260534562170506, 0.009488269836375756, 0.03221038642472454, 0.021402858763134906, 0.06424693896302155, 0.03203167047883783, 0.042406107897737196, 0.013493930920958519, 0.039473523651914935, 0.014422063349879213, 0.0033804794864928617, 0.024099804760356034, 0.03501940265830074, 0.03441299930480974, 0.0641130232917411, 0.02633332321420312, 0.029290697736931697, 0.06535916642418929, 0.02033070388383099, 0.022380602279944078, 0.04347951976316316, 0.02431727184115776, 0.014032748793917043, 0.20476939715445042, 0.06552814199988331, 0.07719512416848115, 0.019945855784629072, 0.0564037832165403, 0.052222144923039844, 0.17317350900598935, 0.17987075820565224, 0.12484166318816797, 0.12727753605161393, 0.4224486829979079, 0.41718270842518124, 0.7533981672355107, 0.32820950554949896, 0.15178474171885423, 0.172205456665584, 0.06038633933556931, 0.058614175500614304, 0.09249646203326327, 0.05731355957686901, 0.08598840196749993, 0.059386986174753735, 0.7030241074306625, 0.7942115057791982, 1.0180736162832804, 0.40825649883065906, 0.4169179712023054, 0.14935353717633656, 0.10363705709044423, 0.6703652941754886, 0.29109266293900354, 0.9755189397505352, 0.5663131975701877, 0.255559683910438, 0.080475868125047, 0.0474696415476501, 0.13561061104493483, 0.23803431860038213, 0.12810849717685155, 0.08351512825382607, 0.017853289410205822, 0.006962796423717269, 0.09452868119946548, 0.074615557944136, 0.13140678804899963, 0.03774556637342487, 0.07429106892751795, 0.05394968150981835, 0.07265972825033323, 0.06849465638931308, 0.029884005364562784, 0.04638445709965058, 0.038057322680417977, 0.0675928494227784, 0.06748935247638396, 0.055775860124932866, 0.07019273098558187, 0.021987219906545112, 0.023834658720131432, 0.007765097077935934, 0.05488007854936378, 0.06545472451086555, 0.05904819363994258, 0.0055857528599777394, 0.047012010389672856, 0.015425240055524876, 0.04322914373395698, 0.09160086366214923, 0.10815590353948729, 0.039052058410431655, 0.0158056420540171, 0.010832552033077394, 0.02387785256308104, 0.013922335879345025, 0.01790271559730172, 0.04684929090685078, 0.013057816956591393, 0.05497379441346441, 0.005365451623219997, 0.010746197425760329, 0.009364819719589182, 0.01443272313502218, 0.014103444509341248, 0.054448988288640976, 0.051665294981960735, 0.03798007146854486, 0.01497988698871008, 0.013380129572137125, 0.07837936455117804, 0.0293026467386101, 0.010809369035996497, 0.034112174196967056, 0.048483474645763636, 0.03577015415898391, 0.04891934857836791, 0.04481884950239744, 0.03930541660104479, 0.016537043432305967, 0.021770126020003642, 0.027499970880204012, 0.03172125767118164, 0.04769631974132998, 0.021113032707944512, 0.04555538908711501, 0.01394375553354621, 0.036333209302808554, 0.025031960901937315, 0.042666085197457244, 0.02900414900588138, 0.050253083796373436, 0.01281732294176306, 0.009979697127294327, 0.006708228320349008, 0.10877438820898533, 0.16764158941805363, 0.10241095109709672, 0.0939791424732123, 0.14215231287692273, 0.09028863121888467, 0.1353059352508613, 0.13682841855500424, 0.15742342200662407, 0.13318730465003423, 0.14530604864869798, 0.11377602589449712, 0.1666316171841962, 0.11410723919314997, 0.07563350974981274, 0.159523962863854, 0.0703019547675337, 0.11503624862858228, 0.07574258425406047, 0.23579846428973333, 0.10588852449187211, 0.12854566371866635, 0.0902309828837003, 0.19395162191774162, 0.07312584109604359, 0.16995118691452912, 0.11608766578137875, 0.07606859997447048, 0.07486098406038114, 0.09377507985170398, 0.11187346119965826, 0.22056148547147, 0.10770260143492903, 0.3835372509700911, 0.24743311426469258, 0.06375498071845088, 0.11638357490301132, 0.1366587576589414, 0.17381876866732324, 0.09818660241684743, 0.10220232193491288, 0.11326719248401267, 0.111906926546778, 0.15169073747737066, 0.1665555126965046, 0.11198275962046214, 0.09139217343181372, 0.08244286650525672, 0.09871772570269448, 0.07853605185768434, 0.11384936874466282, 0.11256952277783837, 0.1148428525775671, 0.1690147950180939, 0.1680222475635154, 0.11264154927006789, 0.1372475903481245, 0.2235634329595736, 0.1625903168959277, 0.21155317313969135, 0.11396455684942858, 0.12363583860652787, 0.2303145985518183, 0.23667404587779725, 0.18220334446855954, 0.11644275672733784, 0.09321905433067254, 0.1768689735659531, 0.3286588042974472, 0.2181206050195864, 0.19712651441139833, 0.2903650834092072, 0.4911264149206025, 0.4928572220461709, 0.7905169097440583, 0.975065569792475, 0.4049480435039316, 0.15425935893186501, 0.17349866298692568, 0.11829997492688042, 0.14747723857206957, 0.31108759716153145, 0.2291925459035805, 0.3030849280101912, 0.27240629707063946, 1.830322917018618, 2.03169104882649, 2.249043945755277, 1.6196383365562983, 2.3648827927453175, 1.0156307816505432, 0.10099834975387369, 0.6529636393700327, 0.4692608139344624, 1.191411737884794, 0.7760814300605229, 0.49872177307094845, 0.2679207463349615, 0.17647226128195012, 0.1495644258601325, 0.26319002732634544, 0.26863570511341095, 0.295307668192046, 0.14001061208546162, 0.08221240887152297, 0.16054123613451207, 0.2654999776610306, 0.3144152414585863, 0.14534948846059187, 0.19814154851649488, 0.18245072476565838, 0.23965129469122204, 0.23529917108161108, 0.18577138015202113, 0.06570669849004064, 0.09486152976751328, 0.13329125621489116, 0.16388166403131826, 0.15288947815341608, 0.1875043043068477, 0.10462171996810607, 0.12482043861278466, 0.1284409521945885, 0.13402833523494856, 0.17826013320258685, 0.19279216841927596, 0.10546861988093172, 0.11442790127226285, 0.09637591814888374, 0.14318517888230936, 0.13514726662210055, 0.1476666855492762, 0.1943484427673476, 0.0846396100574306, 0.049523499195597, 0.1324948596635035, 0.14321593008935452, 0.08629885209458214, 0.15010429546236992, 0.11928288718419415, 0.1167561449110508, 0.09681174119136163, 0.2030290633972202, 0.1061006820361529, 0.12640434290681565, 0.10479586598064218, 0.08550774133098976, 0.15818716745291436, 0.09929925056972674, 0.050607567453490834, 0.1037097621176924, 0.17843904931630405, 0.1131098877106394, 0.10049587421651397, 0.11760862916707993, 0.1711055649710553, 0.13254048435815743, 0.1745294119630541, 0.08713138063571282, 0.06954950014395372, 0.09688813066376106, 0.07276283843176705, 0.19451549808893884, 0.13203101312475546, 0.17040725744196347, 0.09975650174809353, 0.09944341890513897, 0.10644970009369509, 0.06900051103106566, 0.10191167145967484, 0.09995957370847464, 0.2033559408571039, 0.2080561529312815, 0.1274875154984849, 0.17348655792219297, 0.19145215675234795], [0.05966749255146299, 0.03498872948278274, 0.03165834729692765, 0.02887885072933776, 0.025657078251242638, 0.11696928633110863, 0.04433870794517653, 0.030586655517773967, 0.013879918958991766, 0.06507413421890565, 0.07130717047091041, 0.03984576117779527, 0.021261575897889476, 0.05143124111262815, 0.024943629213209664, 0.022642628755420446, 0.024274625915235708, 0.01957033245292093, 0.024328764528036118, 0.032886190339922905, 0.025748860290540115, 0.06860650610178709, 0.006482855458411255, 0.02989936400470989, 0.019766352738120725, 0.019198359555697868, 0.09334425761231355, 0.0062773433164693415, 0.03202958059098039, 0.03817941148632339, 0.020184596634602973, 0.020631968343098248, 0.009539691764595253, 0.02734426236046212, 0.03775557476494994, 0.01919423067010939, 0.06835903759513583, 0.07697749763195004, 0.055600421503186226, 0.0568413025965648, 0.013406567840969988, 0.045617078098335435, 0.038862462155520916, 0.019313093042001128, 0.025134253448673656, 0.01642759912647307, 0.03509017386074577, 0.053586210656378946, 0.04500969086906739, 0.03218872758692928, 0.020057074459535734, 0.00877414395966168, 0.060598958283662796, 0.0268135003945125, 0.04179685130449278, 0.035998776355492215, 0.03926659421995282, 0.05976589369986739, 0.0423346683382988, 0.21829530064548763, 0.04900607213910137, 0.03329406452498265, 0.06386968027800322, 0.19560762734285422, 0.023919579074052826, 0.02649743708648852, 0.044440813894782744, 0.1708185039460659, 0.3726207896002701, 0.20831714464085443, 0.1326495385063546, 2.5198695276464735, 8.445313913481575, 17.31699534824916, 20.668187958853586, 23.424923964909144, 41.21087408065796, 54.713103430611746, 70.84953035627092, 78.61719948904855, 67.7003288269043, 67.06866114480155, 72.1558472769601, 77.90457834516252, 82.92176832471574, 89.0612382888794, 88.90058204105922, 90.35671601976667, 93.49389716557094, 95.1613050188337, 92.02473531450543, 61.16513116019112, 42.06627375738961, 41.05286509650094, 31.02874067851475, 24.7696088382176, 7.142418112073626, 3.7173070907592773, 1.386327598776136, 0.1599600301789386, 0.3454471177288464, 0.489810545529638, 0.4538644743817193, 0.013290161765845758, 0.023059566471991793, 0.21803814944412026, 0.15915675328246184, 0.042748211683439355, 0.015453629960705127, 0.07456139049359731, 0.047515805677643845, 0.014801532362720795, 0.07472197937646083, 0.03124408470466733, 0.01129622639356447, 0.0322719566923167, 0.08936126383819751, 0.014450042741373181, 0.09342648927122355, 0.042938693426549435, 0.061986162061137814, 0.09807438629546336, 0.08135453704744577, 0.007614482659846544, 0.021549748023971915, 0.029100782570562193, 0.010931976921191173, 0.05286079226061702, 0.060717993681984286, 0.039629244046019654, 0.014996519578354699, 0.05944734186466251, 0.012786156980187764, 0.01621351115006421, 0.05280147133661168, 0.0204713930309351, 0.021435355501515523, 0.015330408001318574, 0.03553949635741966, 0.06282211041876248, 0.02557203745735543, 0.040139064724956236, 0.02508893918379077, 0.1020118910819292, 0.03819369125579085, 0.05481690015377743, 0.050535842909344604, 0.02221032222067671, 0.031238429115286896, 0.02664015844597348, 0.029911642095872333, 0.062115056573280265, 0.06219016361449446, 0.09142243609364543, 0.02446906012482941, 0.021960740077442358, 0.014996422887114542, 0.016221063244821768, 0.005404466538623507, 0.0726695398667029, 0.01792916828500373, 0.01762690637925906, 0.08091971823679549, 0.049172642308154275, 0.053511137541915686, 0.09621414182973759, 0.02429284797316151, 0.013880436341943485, 0.05144734274862068, 0.0454781310898917, 0.024614176712930202, 0.04325880928497229, 0.03127980278804898, 0.058900435854281695, 0.020911545126831958, 0.06129816826432943, 0.021113039493294697, 0.015572974092460104, 0.05997586636138814, 0.05917879806033202, 0.0426002401592476, 0.05712411938501256, 0.038474709926439185, 0.07880683482757636, 0.06484858917870692, 0.1438797273273979, 0.06856414516057287, 0.04696715243959001, 0.049770163638251166, 0.06998776591249875, 0.02017734309525362, 0.025834242048274194, 0.07738135488969938, 0.015280768075691802, 0.06657499939735446, 0.036844261522803984, 0.027194082204784666, 0.05208322505599686, 0.05968047971171992, 0.030011946535004035, 0.02880329924768635, 0.023728749581745694, 0.03763648169115186, 0.031044826111091033, 0.01472759579441377, 0.0869377606681415, 0.005773003928230277, 0.022015134837212305, 0.010987907714609588, 0.02574536413885653, 0.04555080897573914, 0.0253086369484663, 0.05355989706835576, 0.07307817401098353, 0.03555758270834174, 0.03703645995951124, 0.05539318673046572, 0.034227501401411634, 0.04839733801782131, 0.010555797106852489, 0.052195095124521425, 0.02407294834431793, 0.05206538637035659, 0.07461477762886456, 0.043903444694089036, 0.028870063700846264, 0.01209005044906267, 0.015324148515771543, 0.04551034793257713, 0.01581121113018266, 0.0287165756869529, 0.024174480931833386, 0.04762979956077678, 0.045828027850283046, 0.06548793880002839, 0.12328547026429858, 0.046649157003100426, 0.06142208232943501, 0.0885819595839296, 0.21678553308759416, 0.024616186872922947, 0.05357542194958244, 0.03923551731609872, 0.06616836014602866, 0.29346292146614616, 0.32969894419823376, 0.1657209281942674, 1.203622436949185, 7.457571029663086, 17.388895307268413, 18.404732363564626, 24.206469501767838, 44.79551574162075, 60.89462389264788, 82.70772211892265, 89.15052958897182, 75.7282496861049, 77.16180896759033, 81.20425006321499, 89.14768777574811, 97.3863752910069, 105.08209582737514, 105.30026926313127, 104.01910482134137, 107.78148487636021, 110.27751404898507, 104.42373316628593, 68.9245388848441, 47.71193872179304, 46.008636474609375, 33.33840874263218, 29.226499557495117, 8.46996351650783, 3.772378512791225, 1.2201528527906962, 0.15975667323384965, 0.26409598014184404, 0.4302463802908148, 0.24447144461529596, 0.043633021347756894, 0.05166670633479953, 0.23696768869246754, 0.16743292632911885, 0.2721081759248461, 0.022041930185098733, 0.11589521967938968, 0.10097567989890065, 0.06354188679584435, 0.01336482775929783, 0.09162940284503357, 0.05480556183361581, 0.05394275705995304, 0.06776797931109156, 0.06068307626992464, 0.06706026728664126, 0.03190007878999625, 0.015227679495832749, 0.11411249105419431, 0.07214028255215713, 0.014130068527135466, 0.03963314222970179, 0.055314262929771624, 0.044081203905599456, 0.006846293233268495, 0.08715023033853088, 0.024306615448689887, 0.0596586037427187, 0.043250042612531354, 0.021907977194392254, 0.027773128722661307, 0.02863337711564132, 0.036491647229662964, 0.047096715308725834, 0.013081388414970465, 0.039079169277101755, 0.0158889542799443, 0.09110290716801371, 0.019862906574936848, 0.047934122516640594, 0.07911301018404109, 0.02457247903969671, 0.053893315605819225, 0.039179982617497444, 0.06406566833278962, 0.037769671329962354, 0.04594537030373301, 0.030324632434972694, 0.03905299478875739, 0.05158944494490113, 0.023721552021535378, 0.02585850137152842, 0.03588927098150764, 0.0506760112808219, 0.006641014337739242, 0.044999631587415934, 0.02945692863847528, 0.04934949906808989, 0.07561341154256038, 0.041783066865588935, 0.039432458712586334, 0.028172958875074983, 0.050150713218109946, 0.031650866448347054, 0.026850075128355196, 0.022258489725313017, 0.0425839756748506, 0.03233085692461048, 0.03766278170847467, 0.012891533468583865, 0.05807815319193261, 0.02720975297104035, 0.020626916649884412, 0.15820562360542162, 0.1310942412487098, 0.11388127346123968, 0.118997508926051, 0.10859511925705842, 0.13336733356118202, 0.1693826967052051, 0.18749146642429487, 0.10047622384237391, 0.44494738429784775, 0.15873612942440168, 0.1535841351641076, 0.15512518318636076, 0.28831848608595984, 0.11831232426421982, 0.1744012502687318, 0.1445959210395813, 0.09723010552780968, 0.18481882555144175, 0.09817057541970696, 0.16074837930500507, 0.15911619045904704, 0.08891020089920078, 0.11708262882062367, 0.11294881028256246, 0.05983245798519679, 0.14366651805383818, 0.16465499039207185, 0.12952060997486115, 0.19139515981078148, 0.1383865928011281, 0.07638655469885894, 0.0823775575097118, 0.07035177959395306, 0.15872661636344024, 0.13290609259690556, 0.20132268353232316, 0.19226919433900289, 0.11295070339526449, 0.21386967812265667, 0.12066195532679558, 0.10803025921008416, 0.12915990075894765, 0.08241660041468483, 0.1286281192941325, 0.11178035940974951, 0.12354718122099127, 0.15368727248694214, 0.17136214620300702, 0.14220773561724595, 0.1099499094166926, 0.07713081261941365, 0.1761256791651249, 0.14013384761554853, 0.11980945750006608, 0.08293990697711706, 0.09965279445584331, 0.17671828450901167, 0.16561255258108887, 0.2668991711522852, 0.19743942762059824, 0.1444357189216784, 0.28998817077704836, 0.39659842582685606, 0.10789109167775937, 0.1433961625610079, 0.13303681915359838, 0.42685888920511517, 0.5746723690203258, 0.3539506814309529, 0.17317862516002996, 4.316928812435695, 15.256010259900775, 27.088288715907506, 29.68887438092913, 37.28540938241141, 61.4495278767177, 79.58380508422852, 105.47508593967983, 113.96389470781598, 98.59666115897042, 96.70798792157854, 102.81183447156633, 116.99953487941197, 120.83505167279924, 129.6884046282087, 132.10181971958704, 127.68265424455915, 132.94972229003906, 137.51146480015345, 130.4716750553676, 89.7344423021589, 64.75680092402867, 63.98877484457833, 48.74957227706909, 38.73971251079014, 12.487363304410662, 6.87084299325943, 3.207296286310468, 0.347948143524783, 0.48832221967833384, 0.6665880254336766, 0.7344507553747722, 0.07992103682564837, 0.17350866459310055, 0.31833953516823904, 0.3329593321042401, 0.44664961152843063, 0.07460222473101956, 0.2154068992074047, 0.16123411538345472, 0.1967158243060112, 0.16705203748175076, 0.11917979057346072, 0.15075587907007762, 0.16016938537359238, 0.2650847685124193, 0.18721260210233076, 0.1549096940351384, 0.1403444241732359, 0.10340893361717463, 0.17607974234436238, 0.1907536592334509, 0.08731309231370687, 0.08416734289910112, 0.145311761913555, 0.10501465959740536, 0.12409161057855402, 0.1449788047799042, 0.10104459870074477, 0.18086121577237332, 0.14347811602056026, 0.07324072386005095, 0.08160144915538174, 0.11240058112889528, 0.1759569953594889, 0.11365029335554157, 0.05320356779598764, 0.1557543072849512, 0.08659459836781025, 0.16687556409410068, 0.06782028079032898, 0.10639216710946389, 0.2662761945809637, 0.12449817519102778, 0.1564889842910426, 0.12852990813553333, 0.16390108370355197, 0.14046879964215414, 0.07600019685924053, 0.06620291793452841, 0.2211937986846481, 0.2367056113268648, 0.26181059277483393, 0.14006509844745907, 0.1692224403045007, 0.09017513945166554, 0.14041333618972981, 0.14758252006556305, 0.16978242168469088, 0.17600641985024723, 0.10015090701303311, 0.18084605730005673, 0.18867498077452183, 0.10532573397670474, 0.19906107203236648, 0.22059930701340946, 0.12998451079641068, 0.10469230118074588, 0.1429153119346925, 0.11641564246799264, 0.10996649281254836, 0.09666368485029254, 0.10708885293986116, 0.08209156178470169, 0.16403547434934548], [0.02823373186402023, 0.04493758634531072, 0.03400036858926926, 0.04060468224010297, 0.03901949890756181, 0.01507497688622347, 0.034840065852871964, 0.04949368775955268, 0.04600856566269483, 0.016575842064672282, 0.049463608302176, 0.04556190641596913, 0.03952628992764013, 0.011816079212751771, 0.04984743181349976, 0.012691291847399302, 0.04509411080341254, 0.00717644504870155, 0.022096330033881322, 0.03063047191660319, 0.011180873744056692, 0.013956402578125042, 0.023586572746613195, 0.09069687181285449, 0.04154993919655681, 0.025460823871461407, 0.04051261182342257, 0.03823778585397771, 0.051784408411809375, 0.036511680976088555, 0.06699556218726294, 0.0330706907968436, 0.04340739149068083, 0.05139187590352126, 0.014811491560457008, 0.05885704353983913, 0.01787059035684381, 0.017396922023700814, 0.018531749790002192, 0.0391048484348825, 0.05384910904935428, 0.04049363319895097, 0.054220138782901425, 0.06546425114252738, 0.025642443947227936, 0.020479284393201982, 0.05323897036058562, 0.02846458474440234, 0.04235977752666388, 0.023742603570488945, 0.045062413040016375, 0.0067358196746291855, 0.036635567899793386, 0.02586529859607773, 0.036561889174793444, 0.015446634264662862, 0.04728916819606509, 0.05209390180451529, 0.013625173164265496, 0.14789085994873727, 0.0739615655371121, 0.24781920069030353, 0.27302897508655277, 0.6463297381997108, 0.029732580097126107, 0.07501908950507641, 0.4284118115901947, 1.2862302213907242, 5.663956965718951, 25.06841090747288, 61.0058992930821, 76.90233543940953, 97.62876319885254, 105.10191903795514, 102.70637471335274, 108.767746925354, 107.15481989724296, 109.91184425354004, 101.3023522240775, 108.22998414720807, 112.39815984453473, 104.90722356523786, 111.41325269426618, 106.42483520507812, 101.31022453308105, 101.78387628282819, 104.61785193852016, 104.75787898472377, 104.6597843170166, 104.28572804587228, 113.67397417340959, 116.3889410836356, 115.63593006134033, 125.63643755231584, 120.98948233468192, 117.1968915121896, 113.76679515838623, 108.13400868007115, 88.59664004189628, 75.01065363202775, 53.51655067716326, 15.58959674835205, 8.275922911507742, 0.5914085709622928, 0.036184355683092556, 0.39169725882155554, 0.6068534936223711, 0.6670059487223625, 0.029875089414417744, 0.07255068088748626, 0.021375659686912383, 0.046850763327841244, 0.0870197955518961, 0.02466014406776854, 0.01843713825967695, 0.05764180767749037, 0.020977654793698872, 0.0932308676253472, 0.06040158601743834, 0.007149997450012181, 0.036459019873291254, 0.05150331510230899, 0.040476903918066194, 0.05449625503804002, 0.05744383151509932, 0.020792950776272585, 0.0077480870531871915, 0.011017043160141578, 0.04405736018504415, 0.029127550777047873, 0.05265957948618701, 0.026018391363322735, 0.05872852222195693, 0.028794522397220135, 0.01775855235090213, 0.021710028173401952, 0.07359887499894414, 0.04121057329965489, 0.03631648341459887, 0.04901050975812333, 0.024155169825202653, 0.02207553293555975, 0.043464038986712694, 0.059349117135362964, 0.04063006623515061, 0.015417994997863258, 0.050824892041938644, 0.029399765455829244, 0.0890533650027854, 0.03878112616283553, 0.014943210474614586, 0.020908182985814552, 0.022201187442988157, 0.029900595545768738, 0.02077670834426369, 0.01924738540713276, 0.02923407738230058, 0.03526531392708421, 0.07359542125569922, 0.03157324543488877, 0.03472320515928524, 0.07366641637470041, 0.05737004761717149, 0.03816318092867732, 0.03334045935688274, 0.025604797128055776, 0.02263968052076442, 0.05419692609991346, 0.02806090560209538, 0.020699557216305817, 0.029990548933190957, 0.04686809989756771, 0.018284985263432776, 0.03901401634461113, 0.04758600012532302, 0.06275882345757314, 0.025284767782847797, 0.06985696471695389, 0.033603625771190436, 0.08426351166729416, 0.014308424001293523, 0.017534934350156357, 0.024068290201414908, 0.04269126223932419, 0.04946864303201437, 0.018824897274108868, 0.026906870205753615, 0.05602090286889246, 0.02979227082271661, 0.03303931873025639, 0.02515141699197037, 0.04514489236420818, 0.11008605068283421, 0.025474309754957045, 0.032985616076205454, 0.04126668814569712, 0.06190310937485524, 0.04404541796871594, 0.009869215511051672, 0.04972911566229803, 0.03427153493144682, 0.021999959401520233, 0.02615270228125155, 0.06929325817951135, 0.08968968835792371, 0.018192180332594683, 0.08408315027398722, 0.05811175424605608, 0.012336916755884886, 0.06859092693775892, 0.02431019302457571, 0.09751638623752765, 0.025693271309137344, 0.005218820205690073, 0.04396786141608443, 0.03943935941372599, 0.05747407382088048, 0.01682842502902661, 0.040182467217424085, 0.08007185480424336, 0.0372853398190013, 0.02756851988046297, 0.05012845387682319, 0.011596210117984031, 0.03269257376502667, 0.03736912193042891, 0.02861485310963222, 0.07021654077938624, 0.04218263238934534, 0.031616016889789274, 0.007497021462768316, 0.02989409857296518, 0.0811090295069984, 0.042011787449674945, 0.04533585247450641, 0.11749312893620559, 0.07757401812289443, 0.06086153776517936, 0.2896768589104925, 0.5742178048406328, 0.12188050922538553, 0.10829170553811959, 0.18037775957158633, 1.170671473656382, 5.108038544654846, 27.35366473879133, 67.5796594619751, 92.7318673815046, 117.30956350054059, 120.04115050179618, 122.05976894923619, 126.87506512233189, 123.77527918134416, 124.45828710283551, 120.24477440970284, 125.50003051757812, 129.28557586669922, 126.99504661560059, 130.38302993774414, 126.34348624093192, 121.67759023393903, 120.77986907958984, 133.89262063162667, 127.79018456595284, 124.12835884094238, 123.61695752825055, 128.3724297114781, 138.59225709097726, 135.8431328364781, 145.34465544564384, 141.604731968471, 142.52329771859306, 129.46176828656877, 130.0771702357701, 111.90414987291608, 88.04489748818534, 63.32112939017159, 18.767402274268015, 7.948932869093759, 0.2517534281526293, 0.08647559689623968, 0.3882103759263243, 0.6548939357910837, 0.445306302181312, 0.03224985680675932, 0.07815464732370206, 0.030137349984475544, 0.024013902226995145, 0.05148185643234423, 0.039653355787907324, 0.022723184432834387, 0.08686653484723397, 0.026326717675796578, 0.0978264631703496, 0.006955589109566063, 0.004849455003360552, 0.011306946398690343, 0.04901896430445569, 0.0349762478311147, 0.05842394820813622, 0.05541503216539111, 0.023638210957869887, 0.023795783752575517, 0.03189735107922128, 0.04334849804373724, 0.037155074666121175, 0.07192926494670765, 0.03465045941993594, 0.027721049463642494, 0.04286876021485243, 0.07156237427677427, 0.03550574941826718, 0.06466913023697478, 0.05627902098266142, 0.040626978900815756, 0.035903910374534984, 0.025333218575854386, 0.044270915511463366, 0.01708304020576179, 0.0903573464602232, 0.04462173168680497, 0.03918315137603453, 0.038963631726801395, 0.05682591681501695, 0.054076031515640874, 0.02389302969511066, 0.056220799285386286, 0.012621039724243539, 0.02422483162289219, 0.02648508774914912, 0.03429568738543561, 0.04780584547136511, 0.038668628449418714, 0.03904509324846523, 0.02902340582971062, 0.01546466294010835, 0.09453134784208876, 0.03949301117765052, 0.05578936297180397, 0.029938529045986276, 0.03098891143287931, 0.035173528495111635, 0.031687408951776366, 0.0036249427191380945, 0.06874548364430666, 0.034909710687186034, 0.03455758833193353, 0.08818564763558762, 0.026948308339342475, 0.05988689684974296, 0.022428445784108977, 0.03089317014174802, 0.06690626019345862, 0.14463011920452118, 0.09433339882109847, 0.11867706397814409, 0.07830496997173343, 0.11564648231225354, 0.11063007970473596, 0.08638485640819583, 0.138284744694829, 0.11120713302599532, 0.1490887999534607, 0.13595990730183466, 0.10928322161946978, 0.1106530006176659, 0.16791296271341188, 0.14497729843216284, 0.2128054637994085, 0.08566925302147865, 0.10018999063010726, 0.1493282685322421, 0.11200382813279118, 0.15103984597538198, 0.10465511067637376, 0.12291067466139793, 0.2574831135571003, 0.1030013986996242, 0.09172773613993611, 0.15760955773293972, 0.17075918641473564, 0.12419438149247851, 0.22338117845356464, 0.11451486232025282, 0.1312322145594018, 0.1353570967912674, 0.11611954335655485, 0.1454442526612963, 0.10092295772795166, 0.070898617750832, 0.16361399553716183, 0.09788107166865043, 0.14987653839801038, 0.11438774556985923, 0.2660648173519543, 0.23225634864398412, 0.13983173668384552, 0.16860848824892724, 0.1509677041321993, 0.07528685299413544, 0.10961081832647324, 0.07306155668837683, 0.17290353349276952, 0.07742168701120786, 0.10198083453412567, 0.07636300953371183, 0.1462296298039811, 0.13118614203163556, 0.2088171299546957, 0.10930407300059285, 0.30733277435813633, 0.21506984372224125, 0.1596217940428427, 0.33220898093921797, 0.4197900742292404, 0.757527731359005, 0.1388491636940411, 0.4109223543533257, 1.0847967330898558, 3.822342140333993, 9.836777533803668, 38.28144754682268, 89.56305803571428, 112.50701032366071, 137.10185459681918, 143.45506504603793, 137.57412365504672, 145.91576957702637, 139.40873990740096, 140.17142977033342, 126.67174693516323, 134.00654329572404, 139.87140655517578, 137.19257027762276, 142.3379475729806, 133.55199214390345, 128.221709387643, 128.75505311148507, 133.95073536464145, 131.47278540475028, 129.19117764064242, 129.29177365984236, 141.73660877772738, 150.41147640773227, 151.35769598824638, 159.54642595563615, 157.45879799979073, 152.77383613586426, 155.78303146362305, 151.6667240687779, 133.06517355782645, 111.07753658294678, 81.12117045266288, 27.431819813592092, 13.625544241496495, 1.461402016026633, 0.09938021336815187, 0.44147282359855516, 0.7951928302645683, 0.8164754882454872, 0.21673044961478027, 0.19185454158910684, 0.09244918171316385, 0.12397703315530505, 0.27592914232185906, 0.13683288331542695, 0.1493521529648985, 0.1041104845436556, 0.15819661266037396, 0.1683415932846921, 0.09093726998461144, 0.16189795333359921, 0.10924900988382952, 0.1507003749055522, 0.12160529542182173, 0.13452867338699953, 0.08605643188846962, 0.1149808666003602, 0.08917512132653169, 0.09718351731342928, 0.13977022069905484, 0.10223290350820337, 0.19049648089068277, 0.10887372573571545, 0.12789465008037432, 0.08887404855340719, 0.12990487792662211, 0.09290733534310545, 0.13461446735475743, 0.15710780822804996, 0.11039876033152853, 0.1478191659386669, 0.11004799165363822, 0.11965239021394934, 0.08692410854356629, 0.20643397926219872, 0.1392521999244179, 0.0821168507848467, 0.0834838885015675, 0.11555072745042187, 0.1374812913792474, 0.13502551029835427, 0.09797020402870008, 0.07338470899100814, 0.13697078877261706, 0.11712720857134887, 0.08269998377987317, 0.13124060125223228, 0.1367976130651576, 0.12430040937449251, 0.1834788274552141, 0.09864149907869951, 0.10123285824166876, 0.12136392694498811, 0.09094403497874737, 0.13163485723946775, 0.10602552071213722, 0.10184179592345442, 0.0654638847336173, 0.13128906222326414, 0.15829867789787905, 0.08092743996530771, 0.08978998261903014, 0.15430871556912149, 0.06223368485059057, 0.08076493082834141, 0.12632804842931883, 0.12518908668841633], [0.04297933088881629, 0.07472867651709489, 0.020634690964860574, 0.02967355094317879, 0.04621726607105561, 0.1208998089922326, 0.03298553804467831, 0.04171185461538179, 0.030539846779512506, 0.08681779567684446, 0.02853095225457634, 0.011778605420009365, 0.06077250040003231, 0.008672873456297176, 0.009043704718351364, 0.05354464699381164, 0.042202404899788756, 0.010628334196683551, 0.029000325461051295, 0.018298267586422817, 0.06364108183022056, 0.027464776965124265, 0.0194772713751133, 0.04557386898834791, 0.0471639038462724, 0.01191109701591943, 0.024552677691515003, 0.009192929835990071, 0.03434344607272318, 0.023992960939982107, 0.028730875812470913, 0.009608595299401453, 0.04108236750055637, 0.028104184261922325, 0.040403364292745075, 0.031533652916550636, 0.031871641387364695, 0.009911020901719374, 0.030116193262594085, 0.04043942842898624, 0.0225074289566172, 0.07664571436388151, 0.021598142837839465, 0.024155936569773724, 0.026520151046237776, 0.02276081428863108, 0.06815223369215216, 0.03865971589194877, 0.057249383734805245, 0.019893863038825135, 0.04449840455449053, 0.04782209638506174, 0.03137770521321467, 0.036013395392469, 0.04833954379760793, 0.019526563551543013, 0.036243975162506104, 0.025175265801538314, 0.2915624263031142, 0.10247794964483806, 0.5395924885358129, 3.7310037272317067, 10.60592314175197, 23.782441786357335, 37.94313975742885, 55.69920914513724, 62.357983997889924, 69.46521990639823, 79.58849511827741, 99.13859980446952, 92.73780809129987, 93.59119973863874, 89.39650971548897, 73.59791810171944, 87.55973257337297, 86.04673453739711, 76.27236311776298, 92.33069923945835, 81.76376765114921, 87.11813981192452, 79.95080893380302, 76.38794640132359, 72.1340994153704, 92.98660223824638, 96.93190056937081, 67.15609727587018, 74.27078860146659, 57.46028218950544, 80.62292207990373, 85.65347344534737, 91.97484724862235, 71.58654662540981, 80.98192855290004, 90.55438532148088, 90.81731905255998, 73.3154182434082, 78.82834134783063, 93.73397827148438, 103.57213415418352, 101.52242251804897, 111.17452648707798, 106.89820207868303, 93.91916860852922, 83.24401187896729, 43.910106795174734, 38.96964577266148, 19.215184143611364, 18.296701771872385, 1.9816017023154666, 0.13500991756362574, 0.2983996979892254, 0.02974549261853099, 0.09587223481919084, 0.03857811187793102, 0.16239694798631327, 0.10497309932751314, 0.040269865920501094, 0.01385695648579193, 0.02935561996751598, 0.03812696751473205, 0.10260270509336676, 0.022769402845629623, 0.023375648439728787, 0.019147488089012246, 0.02726604084351233, 0.034356684290937016, 0.0260490815022162, 0.020820925078753914, 0.06908870701278959, 0.024121070047840476, 0.07286564327244248, 0.016516962188429067, 0.018377676539655243, 0.026160368030624728, 0.037289377102362256, 0.05532527894579938, 0.03066160310325878, 0.037520954318876774, 0.029205375351011753, 0.020960287689896565, 0.026061013540519134, 0.006095873790660075, 0.004653295618481934, 0.03682861111259886, 0.03560884263632553, 0.024185532570949624, 0.004080676523569439, 0.015440381564466017, 0.01776538689487747, 0.014553539687767625, 0.03223796548055751, 0.04301370886553611, 0.050930611190519164, 0.010846127822463001, 0.006630614516325295, 0.10344646338905607, 0.03498077365968909, 0.034323324116745164, 0.05405758214848382, 0.038185715076646636, 0.03551367809996009, 0.045755102299153805, 0.15863618121615478, 0.07311913717005934, 0.033035705531282086, 0.011123071890324354, 0.06332324924213545, 0.026910746337047646, 0.040550389260585816, 0.10224841481872968, 0.11269361326204878, 0.05502404671694551, 0.03066504666847842, 0.04187108303553291, 0.056260066106915474, 0.06704595019774777, 0.010247002605215778, 0.07678232381918601, 0.05641379500074046, 0.02948718790763191, 0.023560517001897097, 0.028279918046402078, 0.03922623834971871, 0.01939090065258954, 0.015650237178696052, 0.05312409098925335, 0.045658475519823175, 0.08249630792332546, 0.04520424382228937, 0.026383533109245554, 0.04536471735419972, 0.05355503536494715, 0.07770117558538914, 0.061211756829704554, 0.015832693548873067, 0.019551769431148256, 0.06778188249362366, 0.04178098037040659, 0.008320503435762865, 0.02840619341337255, 0.0463316365411239, 0.030774596147239208, 0.034977791498282125, 0.06020145889903818, 0.018366667308977673, 0.07516725441174847, 0.028892954079700366, 0.025993319494383674, 0.0491933613749487, 0.03970064967870712, 0.01261511187268687, 0.017859080706589987, 0.024973518680781126, 0.001699953608164963, 0.039610523264855146, 0.06916842809213058, 0.0804007135863815, 0.03942187695897051, 0.021746714865522723, 0.02104888909629413, 0.0709212604644043, 0.011570573368641947, 0.09813506768218108, 0.029600750921028, 0.026675172549273287, 0.08823186944105796, 0.035639444565666575, 0.040191600298775096, 0.035062666051089764, 0.018470515397244265, 0.08322551593716655, 0.03174735073532377, 0.10407626602266516, 0.043676030289913924, 0.24646959453821182, 0.08631784428975411, 0.13980421530348913, 3.811120799609593, 9.632253834179469, 25.93728140422276, 43.466436522347585, 68.88174492972237, 73.2222706930978, 85.75675146920341, 94.58102621350969, 115.9575274331229, 104.78178078787667, 107.51327051435197, 98.18495259966168, 107.37950379507882, 111.55944279261998, 112.53813130514962, 109.71753093174526, 128.50218037196566, 110.34079129355294, 127.9065113067627, 106.60795497894287, 112.4476101739066, 117.99869973318917, 121.20434842790876, 136.18751335144043, 101.13104438781738, 117.09725434439522, 98.48297473362514, 122.40665081569126, 124.26156970432827, 142.22491427830286, 103.19432585580009, 130.10178075517928, 117.87019974844796, 112.45138999394008, 108.54288932255336, 117.8050673348563, 106.16163744245256, 120.92981120518276, 116.71351923261369, 131.4364185333252, 122.54932512555803, 115.75499439239502, 99.05961963108608, 55.80110100337437, 47.45265974317278, 23.71377100263323, 20.417597702571324, 2.7014383333069936, 0.15624035548950943, 0.2862066408353192, 0.056352272230599604, 0.055793179731283865, 0.044908100606075356, 0.07276971199150596, 0.05720103811472654, 0.054814905260822604, 0.017327060058180774, 0.10514443620507206, 0.0073660964345825565, 0.013876585655712655, 0.024849104196099297, 0.06493664945342711, 0.08514052496424743, 0.016958946328876272, 0.03187853869582925, 0.048369243275374174, 0.022085152865786637, 0.06294689979404211, 0.054824201190578084, 0.02710689215122589, 0.014808777420382415, 0.024138981675995246, 0.03493310996730413, 0.044609165218259604, 0.03980258599455867, 0.04265860774155174, 0.005010765677850161, 0.041388413935367546, 0.05414554403562631, 0.04707347548433712, 0.015051297710410185, 0.018578361753108244, 0.06107281321393592, 0.05075136259464281, 0.012906652925136899, 0.011228728274415647, 0.01846997596190444, 0.048926737824721, 0.03761399504063385, 0.03417979021157537, 0.013358267173836274, 0.04921371403283306, 0.011221638431639543, 0.10513554739632777, 0.06864560328956161, 0.07584039507699863, 0.017293759255803058, 0.02038044898238565, 0.03603596346718924, 0.03457381549690451, 0.06786767646138157, 0.04438510616975171, 0.05772234299885375, 0.07289111547704254, 0.009786585212818213, 0.07291931539241757, 0.06609369415257658, 0.03147856265838657, 0.013709076563827693, 0.012039279066292303, 0.05951557534613779, 0.007180176143135343, 0.04558844731322356, 0.054845473263412714, 0.02776164960648332, 0.07697148581168481, 0.18404277147991316, 0.10474489443004131, 0.1316042553101267, 0.08028142713010311, 0.1603203322738409, 0.09541976052735533, 0.17812438548675605, 0.1509940041495221, 0.15902314973728998, 0.0848141699763281, 0.09433934278786182, 0.14067598352474825, 0.12100670539907046, 0.06143640620367868, 0.09296449513307639, 0.16739130499107496, 0.1018558144569397, 0.11277589920376029, 0.12465833659682955, 0.1335029319993087, 0.11712150887719222, 0.11337166652083397, 0.13355789333581924, 0.15459318459033966, 0.18639891647866794, 0.12585371173918247, 0.22137536108493805, 0.11610481914665018, 0.1302635379667793, 0.1480544140296323, 0.1058392764202186, 0.2235364815486329, 0.12207200537834849, 0.11035975813865662, 0.11071609758905002, 0.14086693684969628, 0.08436672362898077, 0.11894689021365983, 0.11121133315776076, 0.20218937631164277, 0.11973566003143787, 0.10790838075003453, 0.13623886661870138, 0.13330211277518952, 0.0980787832023842, 0.11776119098067284, 0.1272330241543906, 0.15190725800182137, 0.14950666895934514, 0.2194320096501282, 0.17762195744684764, 0.15637545181172235, 0.09876341825085026, 0.16684687563351222, 0.20725272675710066, 0.1926104567412819, 0.18060909930084432, 0.43463511765003204, 0.15669173055461474, 1.443846958024161, 7.90500635760171, 18.519566978727067, 36.84608520780291, 57.70829119001116, 82.92287308829171, 90.12654304504395, 103.36867005484444, 112.13942977360317, 131.64908899579729, 117.38201931544712, 117.1560638972691, 109.0909423828125, 95.9403439930507, 108.75097397395542, 110.45851462227958, 99.37850720541817, 118.77920477730888, 107.12456744057792, 114.10181644984654, 107.93410900660923, 99.42848559788295, 100.72385215759277, 121.46639278956822, 129.53867094857353, 93.6033799307687, 98.85483537401471, 80.55658067975725, 109.35326467241559, 112.64155524117606, 119.48611450195312, 97.98485837663922, 108.68068599700928, 119.30088942391532, 115.97423090253557, 97.64943408966064, 104.52646923065186, 117.37382044110979, 126.05965232849121, 127.73143059866769, 140.84591920035226, 142.94159317016602, 131.2424109322684, 120.5825263432094, 71.44027314867292, 60.938612937927246, 32.24850388935634, 30.220595700400217, 4.808119986738477, 0.18307370133697987, 0.7104134080665452, 0.12499217582600457, 0.18974053859710693, 0.13210502772458962, 0.26253787374922205, 0.2501593865454197, 0.11202502556677375, 0.1437335844550814, 0.19321056668247494, 0.1243014136063201, 0.24464908508317812, 0.13976025980498108, 0.1622915986393179, 0.22872753228460038, 0.11602321852530752, 0.12178681711001055, 0.12782429956964084, 0.1461692808994225, 0.19229948414223536, 0.21943510376981326, 0.13938414784414427, 0.11519730570060865, 0.13726578865732464, 0.12104265418435846, 0.21807621525866644, 0.12047321402600833, 0.19039889398430074, 0.0995752379032118, 0.13665425218641758, 0.11899292202932493, 0.145932065056903, 0.07823466695845127, 0.09107119244124208, 0.0972195543082697, 0.10361881806914296, 0.09405844964619194, 0.15102227191839898, 0.10088580793568067, 0.18586082463817938, 0.10001895230795656, 0.08480328627462898, 0.16916519909032754, 0.09854303686214344, 0.1275186873972416, 0.22007782571017742, 0.2589906555201326, 0.1504563330007451, 0.095413599429386, 0.09584022153701101, 0.12441239479397025, 0.15174024339233125, 0.12758146545716695, 0.21733053241457256, 0.15650037010865553, 0.15601514971682004, 0.09501648002437182, 0.15917202032038144, 0.08198423111545187, 0.13153902095343384, 0.11944399853902203, 0.19233061532889092, 0.15240549269531453, 0.10350821686110326, 0.09258722966270787, 0.1790317360843931, 0.11127814171569687], [0.10092004002737147, 0.04091588214838079, 0.028374485471951108, 0.052270429474966865, 0.025356550002470613, 0.02373200485349766, 0.06050701000328575, 0.029371487508927072, 0.0368047979261194, 0.03302642995757716, 0.0470429142670972, 0.0345138771060322, 0.020759870497775928, 0.0343009663878807, 0.04981088591739535, 0.053203771356493235, 0.06135313638619014, 0.01431299393464412, 0.017448309177000607, 0.007893629422012185, 0.023927412760843123, 0.03245822134028588, 0.06037692126951047, 0.010675020798641657, 0.033355709431426864, 0.041083012108824084, 0.005416715367963272, 0.021392526371138434, 0.07255311004285302, 0.08445358968206815, 0.052368722057768276, 0.05335385312459298, 0.023917221164863025, 0.06067009589501789, 0.021701076600168432, 0.05687365175357886, 0.055162644279854636, 0.03600943274796009, 0.06481950716780764, 0.05292229467470731, 0.008749273954890668, 0.004270510689821094, 0.05561864695378712, 0.061367032783372064, 0.046255718650562425, 0.028858973045966456, 0.0032651552506389892, 0.02486090561641114, 0.027916895026074987, 0.06834040502352373, 0.039149981191647906, 0.04589694325945207, 0.06799175337489162, 0.02916591175432716, 0.016397643501737287, 0.0886128329272781, 0.16614220344594546, 0.7580890155264309, 10.989865830966405, 37.991763251168386, 65.4794066292899, 77.30553245544434, 89.37702696663993, 77.9471082687378, 94.24071734292167, 88.83153779166085, 77.98822770799909, 88.32915524074009, 102.19077668871198, 63.412338393075125, 77.85820606776646, 49.58342906406948, 66.64514064788818, 26.2328907762255, 31.498966966356548, 40.04307992117745, 24.962749651500157, 31.38861220223563, 30.11651168550764, 26.52315698351179, 29.734878403799875, 31.859557628631592, 19.733886275972637, 32.260836941855295, 22.134945733206614, 27.5771552835192, 29.814563819340297, 37.50329099382673, 21.462966339928762, 27.22520818029131, 23.77821728161403, 34.51391192844936, 15.816406794956752, 43.54301609311785, 46.40461778640747, 48.54162311553955, 42.01205348968506, 56.380222933632986, 62.198203223092214, 86.32797677176339, 79.58003916059221, 96.54996504102434, 93.84744930267334, 90.32269069126674, 109.57887268066406, 101.27804742540631, 102.01484830038888, 105.13927255358014, 93.608063016619, 48.69293751035418, 8.848857470921107, 0.3883162816720349, 0.3102651312947273, 0.2501889978136335, 0.024850968471063033, 0.0519883217556136, 0.034088245659534416, 0.03666038531810045, 0.1220605517072337, 0.04665074138236897, 0.04803691717929073, 0.04785731574520469, 0.024837787928325788, 0.01760043842451913, 0.045586435456893275, 0.025372783952791775, 0.04935173823365143, 0.02785840361112995, 0.010668584045821002, 0.05192238511517644, 0.038691084565860887, 0.03321404489023345, 0.019894677280847515, 0.051183572438146384, 0.029686239548027515, 0.027084503888285587, 0.05619654844381979, 0.04449696945292609, 0.027705851975562315, 0.011013893061317503, 0.04946675331198743, 0.03211826851059284, 0.014483280779261674, 0.027114249167165587, 0.01208509290258267, 0.03735940530896187, 0.028564702586403916, 0.022293646320966736, 0.017024109439392174, 0.018565846174689274, 0.017643947786252414, 0.004917504856296415, 0.025266981683671474, 0.013209316014711345, 0.08296884649566241, 0.01687133727994348, 0.03412164654582739, 0.043688098035220585, 0.07756105131868805, 0.02485652736920331, 0.07651857047208718, 0.05250409997201391, 0.09003819072885172, 0.011710778211376496, 0.09104012232273817, 0.053982827945479324, 0.06041607952543667, 0.029133291183305637, 0.03437680624691503, 0.010503308182316167, 0.04132306083504643, 0.08149968925863504, 0.04737629209245954, 0.06348880500133548, 0.020828831708058715, 0.0701718321070075, 0.04923728294670582, 0.05333740543574095, 0.02951161516830325, 0.04341645332585488, 0.024881105603916303, 0.01745173068983214, 0.055524201664541445, 0.022568152751773596, 0.0787377328212772, 0.00426855990164248, 0.048503922298550606, 0.04407419463885682, 0.060031058399805, 0.005049061346133905, 0.04252958091508065, 0.04996510674910886, 0.051594561098941734, 0.03962002614779132, 0.03338093397074512, 0.03285865878154125, 0.017248480614008646, 0.01299084470208202, 0.05829244812152215, 0.047357408462890556, 0.04954180267772504, 0.028003683047635213, 0.021138615174485103, 0.04289042244532278, 0.04648141636114035, 0.06154311940606151, 0.019610449139560972, 0.08434663899242878, 0.05017035680689982, 0.06974983760820967, 0.020495321568367735, 0.08733929055077688, 0.04331426255937133, 0.030285942368209362, 0.04503221483901143, 0.010505716133463596, 0.015014171666864837, 0.02171202645903187, 0.04376436197864158, 0.0464068419699158, 0.029561735157455717, 0.046940994914621115, 0.05252783512696624, 0.0501284979815994, 0.05729496093200786, 0.01592747132027788, 0.018113402416929603, 0.028891288276229585, 0.04607013253761189, 0.11725238471158914, 0.009961714252962597, 0.013936842958043729, 0.12801656925252505, 0.7515432153429303, 10.958519901548113, 42.18747813361031, 71.84114946637834, 90.36003725869315, 102.73263195582798, 92.55926718030656, 100.38728141784668, 98.48748411451066, 90.1106664112636, 101.40191990988595, 104.75602381569999, 91.50794219970703, 108.42597198486328, 86.56912095206124, 104.5435756955828, 52.86177676064627, 70.12852273668561, 63.67748165130615, 40.87797198976789, 46.51059171131679, 43.589551653180806, 48.53372301374163, 54.42314468111311, 51.34023938860212, 35.69810036250523, 62.19303376334054, 53.34170968191964, 49.736921719142366, 43.87744331359863, 46.36773327418736, 39.68561942236764, 50.44419275011335, 46.68798269544329, 53.58088404791695, 35.523346219744, 68.52526760101318, 72.70427553994315, 76.72044549669538, 67.45016588483537, 92.57347624642509, 108.16222531454903, 116.46905381338937, 119.61622646876744, 125.27725737435478, 118.98858179364885, 109.88218239375523, 128.2956382206508, 116.95034163338798, 119.97229385375977, 120.60281508309501, 106.16125529153007, 55.055423804691856, 9.741476041930062, 0.11024770486567702, 0.20314023457467556, 0.23117698941911968, 0.04608404589816928, 0.05109305586665869, 0.02967542709250535, 0.013432281773670443, 0.05132635995479567, 0.06622397287615708, 0.027350915396319966, 0.005606136051937938, 0.023207845033279488, 0.004695804141062711, 0.04171779518947005, 0.033069089454199584, 0.06955196322607142, 0.037536017796290774, 0.01729821044552539, 0.052737519411104064, 0.019834077318332026, 0.05807048574622188, 0.07404305759285178, 0.023194142018577883, 0.018510769487225583, 0.06470315876816, 0.08081626878785235, 0.0355290842375585, 0.06426419410854578, 0.035084202752581665, 0.009090056293644011, 0.031641444989613125, 0.015695583673992326, 0.020389534566285353, 0.049268573589090786, 0.06595997525645153, 0.03054168900208814, 0.005548394418188504, 0.0365823470056057, 0.0353328892295914, 0.021649877740336314, 0.0662722574280841, 0.027381325639518242, 0.053090588322707584, 0.06257447227835655, 0.03961630777588912, 0.037100187968462706, 0.1296850461512804, 0.02394829467604203, 0.01824896183929273, 0.04969031024458153, 0.024722615090597953, 0.05437399320570486, 0.013361170455547315, 0.05276291697685208, 0.011472237529233098, 0.024675353430211544, 0.08609810750931501, 0.02493300335481763, 0.012297621096617408, 0.01126219192519784, 0.07650029752403498, 0.010789768703814064, 0.03451561076300485, 0.08528978909764971, 0.015029421741408961, 0.28147611181650845, 0.16437571894909653, 0.08285327162593603, 0.1511233193533761, 0.12035683169960976, 0.11080034449696541, 0.14633634979171412, 0.1418468499822276, 0.2283453813620976, 0.19698774042938436, 0.11402557071830545, 0.1085643544793129, 0.18487925588020257, 0.10612386079238993, 0.09869897778012923, 0.12765717639454774, 0.15817652802382196, 0.15249298300061906, 0.08349388332239219, 0.08422229745026145, 0.09835966277335371, 0.08939538736428533, 0.08800159501177923, 0.07315438027892794, 0.18955259796764168, 0.08698795868882112, 0.1293377447873354, 0.1491863461477416, 0.19683061886046613, 0.13438255765608378, 0.10772462668163435, 0.11977251805365086, 0.09632921458355018, 0.15298551799995558, 0.11430955119431019, 0.1776553142283644, 0.15609586824263844, 0.18145596528691904, 0.12234491216284887, 0.1668470791940178, 0.11219370937240974, 0.11377175112387963, 0.12210772346173014, 0.14039250516465732, 0.13008568036769116, 0.18634668285293238, 0.13083428091236524, 0.16108661544110092, 0.18087249302438327, 0.12755877524614334, 0.1615875642746687, 0.10032129394156591, 0.17379149155957357, 0.23841991648077965, 0.08290957646178347, 0.22755932568439416, 0.15073327028325625, 2.0902076917035237, 21.716493947165354, 63.582478931971956, 97.75133637019566, 109.00950254712785, 121.56600216456822, 106.89793109893799, 121.0677468436105, 113.06638894762311, 103.45682185036796, 109.43353721073696, 126.9551361628941, 83.65124579838344, 104.38576126098633, 70.20579365321568, 95.97613416399274, 43.017395292009624, 52.011035851069856, 59.06484358651297, 36.53388180051531, 42.6516421181815, 41.09434584208897, 32.93963425500052, 45.98215341567993, 44.315277099609375, 28.277509382792882, 45.04645340783255, 31.472737516675675, 42.900217396872385, 38.87014756883894, 51.264521394457134, 29.331945419311523, 39.49981416974749, 35.64035735811506, 51.028286116463796, 21.185578618730815, 64.83275168282645, 68.25239099775041, 65.77709524972099, 60.50589302607945, 87.25475529261998, 88.06080886295864, 118.6804152897426, 104.255190713065, 121.52396556309291, 116.1369994027274, 115.5513357434954, 143.17559460231234, 132.15101296561105, 136.15259170532227, 137.25650760105677, 125.59565162658691, 73.16908918108258, 15.793401309422084, 0.6752908613000597, 0.5074496875916208, 0.4588374303919928, 0.15950607668076242, 0.1274049784988165, 0.10778547091675655, 0.16230966124151433, 0.1594975542809282, 0.14120121034128325, 0.14822959820074694, 0.0874854741351945, 0.17886217018323286, 0.0695958508710776, 0.18448744261903421, 0.18218218774667808, 0.1535873921321971, 0.09276317379304341, 0.10183252034974949, 0.14567426246191773, 0.11227459753198282, 0.13989361907754624, 0.19784832639353617, 0.133228776710374, 0.12383630499243736, 0.07268878311983176, 0.1557184127824647, 0.1305462835090501, 0.12702949079019682, 0.15600654589278357, 0.11269332149199077, 0.10202532607529845, 0.12932406552135944, 0.19312144789312566, 0.1426556230123554, 0.12734063980834825, 0.20554857248706476, 0.11187855021229812, 0.09928990714251995, 0.1351100014788764, 0.0970399257327829, 0.10599117326949324, 0.1065109446644783, 0.1030567264450448, 0.1759089415094682, 0.15515497087367944, 0.0960991708561778, 0.1936653751347746, 0.08474997377821378, 0.07048526100282158, 0.14575602593166487, 0.2667026131280831, 0.17618634019579205, 0.13573820276984147, 0.2590268892901284, 0.12251746361809117, 0.14057277834841184, 0.11317031803940024, 0.13410388332392487, 0.15663951049957955, 0.11547880273844514, 0.16575439354138716, 0.14127807478819573, 0.1445820246423994, 0.21995692434055464, 0.1328461915254593], [0.07006260153970548, 0.032243397153381786, 0.06476765352168254, 0.050600178207137754, 0.018518194356667142, 0.04006216635129281, 0.040264800656586885, 0.15494434003319058, 0.02285846565583987, 0.034487373528203795, 0.06320275499352387, 0.06420707503067595, 0.0422211562150291, 0.05954731721431017, 0.02462387806735933, 0.008327626357121127, 0.05425968041111316, 0.04012048304347055, 0.08400768360921315, 0.07886659340666873, 0.05945369295243706, 0.05976644331323249, 0.04210286720522812, 0.05250035445871098, 0.020965646420206343, 0.08534464186855725, 0.04602575974006738, 0.03764808463997074, 0.03690624569675752, 0.069285495738898, 0.05836282577365637, 0.031927108232464106, 0.06707398047936813, 0.04123286656769259, 0.01960324988301311, 0.008860692797627832, 0.046149181867284436, 0.01604329385528607, 0.021220884152821133, 0.031262761381055625, 0.023434628399887254, 0.02397776854091457, 0.052902376279234886, 0.03063103849334376, 0.0032978375259387705, 0.12815835593002184, 0.05830535385757685, 0.05232793192512222, 0.019903216644057205, 0.07721940215144839, 0.10781645282570805, 0.00479575022888769, 0.1440502024654831, 0.04529494020555701, 0.30120753017919405, 3.660753531115396, 18.490309851510183, 53.49924618857247, 84.43580859048026, 75.64053562709263, 77.06558336530412, 77.14435509272984, 73.8611089161464, 73.11165537152971, 69.85067817143032, 82.16606834956578, 75.00703362056187, 67.67662157331193, 55.11121783937727, 38.95404706682478, 26.827564511980327, 27.809060096740723, 36.23830543245588, 53.98002331597464, 50.74987179892403, 63.02705383300781, 66.75867421286446, 83.40034634726388, 73.66216809409005, 97.22869982038225, 69.9527541569301, 87.37989234924316, 100.99873679024833, 82.54468263898576, 98.73330443246024, 92.02032320840019, 89.58028956821987, 99.13324274335588, 107.45371750422886, 101.58706855773926, 138.43172591073173, 96.22456005641392, 121.4561789376395, 69.02813652583531, 52.623311110905235, 87.17583765302385, 69.82798535483224, 34.69335610525948, 37.69898700714111, 40.231490748269216, 36.717088426862446, 39.22419997623989, 45.48868540355137, 64.58252620697021, 63.97129317692348, 84.67140116010393, 90.13498510633195, 87.0728931427002, 89.65372507912772, 98.63816969735282, 96.18087673187256, 59.219322885785786, 20.15816412653242, 3.8923296076910834, 0.2941329612263611, 0.4068034568003246, 0.030800495828901018, 0.08062809067113058, 0.04970968920471413, 0.04559558889429484, 0.10642337972032172, 0.013136285290654217, 0.046795432189745564, 0.010725771825361465, 0.009235901458721076, 0.05061137064227036, 0.061147859186998436, 0.03608937095850706, 0.06063943289752517, 0.03658894915133715, 0.02253612589889339, 0.03156055683004005, 0.00562191114295274, 0.015456232142501643, 0.09665404965302773, 0.010604199554239, 0.1169365673725094, 0.042628674169204066, 0.056072841331894906, 0.042588827200233936, 0.02344614653182881, 0.048673861393971105, 0.05072323392544474, 0.05094751689050879, 0.04629821190610528, 0.012401480211078056, 0.05853670037218502, 0.006040177091823092, 0.047148480745298524, 0.04203174316457339, 0.031860058794596365, 0.03806998414386596, 0.021478476401950632, 0.04216873938483851, 0.05302843451499939, 0.043547620930309804, 0.060605445078441074, 0.10033835231193475, 0.03034114119197641, 0.060742631288511414, 0.048808665946125984, 0.06965657975524664, 0.04458919253998569, 0.04058099797527705, 0.08946823488388743, 0.051925801538995335, 0.022425314344997917, 0.04403481925172465, 0.04665643768385053, 0.011113652127927967, 0.038620649238250086, 0.0593156653589436, 0.062314905492322784, 0.04419028858787247, 0.04813366948759981, 0.08664280149553504, 0.024846233992970417, 0.13504943544311182, 0.0328348829144878, 0.03273892109947545, 0.006111643792662237, 0.04127664225442069, 0.025558534610484327, 0.022628932526069026, 0.042811142413743904, 0.009121271449008157, 0.007931678273182894, 0.05392492176698787, 0.03164947545155883, 0.0063384492116581115, 0.06963514483400754, 0.04422982343073402, 0.009287146967835724, 0.0253111984181617, 0.023702902486547828, 0.01567940061379756, 0.03219797262655837, 0.06843284184911422, 0.015621167042159607, 0.019503479790208594, 0.041573579356606515, 0.037152194284967015, 0.055731392332485745, 0.04370380951357739, 0.06794115501855101, 0.03878271393477917, 0.017169042823037932, 0.07798938333456006, 0.06932445721966879, 0.024816135875880718, 0.011335257424174674, 0.060223117736833434, 0.0355760727875999, 0.09189990761556796, 0.03834451941241111, 0.05854346536632095, 0.034635385764496665, 0.026160191611519883, 0.018720294315634028, 0.03810774461765375, 0.024628101947850416, 0.028424844644697647, 0.0019420866031266215, 0.007082704587706498, 0.022248851135373116, 0.03819934345249619, 0.060679452892925055, 0.025004127395472357, 0.004392798391303846, 0.05174792358385665, 0.14369538293353148, 2.9226809186594824, 18.03810371671404, 57.07266303471157, 99.25618416922433, 89.87737369537354, 93.98880345480782, 87.002334186009, 91.68440559932164, 90.03435434613908, 107.31208542415074, 127.30425534929547, 104.34676797049386, 100.3369139262608, 99.3936334337507, 51.21830545152937, 44.59507410866873, 22.49987380845206, 37.65296213967459, 22.22242876461574, 23.401541539600917, 39.49360248020717, 29.291614600590297, 45.948781217847554, 39.247580664498464, 36.96852288927351, 41.25912931987217, 41.64287485395159, 35.77668448856899, 39.76001378468105, 29.281793321881974, 47.134873458317344, 27.707109178815568, 52.21989175251552, 42.502078669411794, 45.90674114227295, 57.75721345629011, 54.687488896506174, 33.57496016366141, 45.68493379865374, 37.213366985321045, 51.85300949641636, 40.69156919206892, 36.24664674486433, 36.529143129076274, 59.581080845424104, 55.9687853540693, 70.75788361685616, 87.77070767538888, 101.25161647796631, 93.72042233603341, 113.12272494179862, 109.74176624843052, 108.39863777160645, 103.22471032823834, 114.02574062347412, 115.68311527797154, 76.10798263549805, 24.986177240099224, 4.499610415526798, 0.4771843116198267, 0.22299065440893173, 0.007525793892065329, 0.14738769909100874, 0.08779031277767249, 0.06610713593129601, 0.053213158888476234, 0.02922453378726329, 0.02321535811227347, 0.058130244325314245, 0.030420217663049698, 0.011017949004391474, 0.0507052323914, 0.0451498558478696, 0.051795186940580606, 0.015607158686699612, 0.07936957105994225, 0.04334423005846994, 0.01951475704221853, 0.013997325873268502, 0.08436069145266499, 0.02313492457116289, 0.05165241638730679, 0.042796798183449676, 0.02910547803289124, 0.11779982676463467, 0.04933361456330333, 0.034321529391620836, 0.024618015524798205, 0.010454031272924371, 0.03125371990193214, 0.040153531091553826, 0.06185929636870112, 0.03879617267687406, 0.021765668044931123, 0.06321825951869998, 0.011494373886047729, 0.05135690760133522, 0.034945540728845766, 0.04430095086406384, 0.03996178727330906, 0.014455186036814536, 0.035809214027332406, 0.005454069144824254, 0.04906650925321238, 0.03761089752827372, 0.0521405884064734, 0.03032637626997062, 0.04768785840964743, 0.07456894937370505, 0.04468316285471831, 0.03450670838356018, 0.06028065072106464, 0.040080771781504154, 0.10529714051101889, 0.03575679719714182, 0.05250813386269978, 0.059061248653701375, 0.04880688479170203, 0.07267559239906923, 0.09661993969764028, 0.03821539759103741, 0.09781673976353236, 0.23338754794427327, 0.13058091593640192, 0.09452313756836311, 0.10553278215229511, 0.16397025356335299, 0.15874222266886914, 0.1984158937952348, 0.11847309635153838, 0.08692444102572543, 0.11755003088286944, 0.11752009391784668, 0.1208671714578356, 0.1717370232301099, 0.1857626541916813, 0.2309497616120747, 0.10933439673057624, 0.1534838748297521, 0.09499499760568142, 0.08812743611633778, 0.09129366371780634, 0.1422010316912617, 0.08218405289309365, 0.1081366738570588, 0.08894798851438931, 0.19258145615458488, 0.2533938544137137, 0.10585630086383649, 0.24698376123394283, 0.1850148407476289, 0.15934269901897224, 0.11947432905435562, 0.218034173228911, 0.1781048301075186, 0.0912207415593522, 0.10575110757989542, 0.2157066081251417, 0.18979304363684996, 0.15737952079091752, 0.14175764976867608, 0.12196642532944679, 0.11737823938684804, 0.13598871789872646, 0.09678017574229411, 0.14386688944484505, 0.16719493695667811, 0.1958053931593895, 0.10829922370612621, 0.07050856868071215, 0.15453154646924563, 0.15252559339361532, 0.1376299448311329, 0.4099712653883866, 0.14473109878599644, 0.7537164273006576, 9.054515463965279, 35.143891198294504, 83.04558522360665, 117.91286168779645, 100.60528114863804, 100.71558380126953, 97.43428312029157, 93.76156956808907, 92.61768763405937, 92.92478411538261, 103.63428579057965, 100.80755710601807, 86.30799375261579, 75.30233206067766, 54.42393330165318, 39.76520756312779, 39.46035187585013, 52.47517204284668, 77.57212093898228, 72.01070635659354, 92.88515159061977, 100.55124500819615, 122.04695647103446, 109.77227578844342, 146.73988151550293, 107.01165921347481, 125.19457381112235, 149.03403772626604, 116.45996556963239, 141.97508484976632, 131.75049100603377, 133.00701713562012, 142.9090061187744, 152.18162727355957, 136.9978539603097, 181.98802348545618, 133.01420157296317, 173.04634502955844, 97.8489099230085, 78.02410820552281, 114.79724080221993, 103.79048129490444, 47.32154723576137, 50.56770740236555, 54.58576032093593, 46.97853899002075, 55.73204285757882, 67.53132084437779, 89.05271979740688, 83.51473454066685, 103.98916503361293, 110.7618521281651, 110.14351803915841, 110.94125461578369, 126.41742897033691, 130.65334265572685, 96.3451668875558, 38.00677136012486, 8.227436644690377, 1.152147576212883, 0.3559449501335621, 0.16794963074581964, 0.30499313133103506, 0.20368725593600953, 0.17852898234767572, 0.21836904383131436, 0.18114761183304445, 0.13016702314572676, 0.15938993862697057, 0.09314862239573683, 0.11542412638664246, 0.19196556348885807, 0.10590290264891726, 0.14424020584140504, 0.1571197233029774, 0.14767489582300186, 0.1764998912279095, 0.06855722410338265, 0.073845746394779, 0.2394015666629587, 0.10004063150180237, 0.19112791200833662, 0.0970906326547265, 0.11995902018887655, 0.16437964088150434, 0.13362255772309645, 0.11435422593993799, 0.13513623364269733, 0.08650371538741247, 0.19657053638781818, 0.09660301024892501, 0.17172403606985295, 0.28048018525753704, 0.1271548569202423, 0.060148309251027446, 0.1268650817551783, 0.11251352328274931, 0.0877943772024342, 0.07732443258698497, 0.10953662730753422, 0.12053489285920348, 0.16776965611747333, 0.1890789262418236, 0.11520345322787762, 0.10145284608006477, 0.15651035814413003, 0.1926236610327448, 0.2055476632501398, 0.17979626863130502, 0.1990390196442604, 0.10514940308140856, 0.13027253534112657, 0.180493490504367, 0.19762225209602288, 0.06943216108317886, 0.12337564756827694, 0.1364740197147642, 0.1554305917982544, 0.09463890921324492, 0.18031814348484787, 0.0825196902400681], [0.0239870661670076, 0.030807725619524717, 0.038445885758847, 0.03014774853363633, 0.06877339178962366, 0.015148949077618974, 0.022559667671365396, 0.05432257042931659, 0.02577082277275622, 0.014493887977940696, 0.048576596791722944, 0.03819226293957659, 0.029734598738806586, 0.006028323509131691, 0.08769825593169246, 0.05924195609986782, 0.05703804721789701, 0.027769903984985182, 0.01983451158074396, 0.05447233667863267, 0.056847897956946065, 0.02259085144448493, 0.05762016919574567, 0.014434002173532332, 0.03727365544598017, 0.10127514454403094, 0.008690668885330004, 0.0517447378619441, 0.02552304383633392, 0.07484518097979681, 0.05407656077295542, 0.03693448971690876, 0.04152821929060987, 0.05091292856793318, 0.07171628637505428, 0.06461759550230843, 0.026074918419388787, 0.04762489375259195, 0.08580875303596258, 0.08299901416259152, 0.05870863436056035, 0.05929109560591834, 0.0386346474156848, 0.05903953553310462, 0.024916677802268947, 0.02680685244766729, 0.03805774337212954, 0.0008292715730411665, 0.02978585866679038, 0.043591047171503305, 0.10627110967678682, 0.28850378042885233, 3.7582662871905734, 18.291964837482997, 39.681950773511616, 71.91697515760148, 74.95023209708077, 75.75482654571533, 64.31865446908134, 73.39916488102504, 76.07238701411656, 75.66980838775635, 48.09988791601998, 32.49182980401175, 39.66921819959368, 20.93077428000314, 26.98152964455741, 31.225996562412806, 26.238918338503154, 59.099244117736816, 72.27100672040666, 107.0683843067714, 92.87600081307548, 72.94637857164655, 89.25161893027169, 47.0979437828064, 43.48939337049212, 33.14935173307146, 35.67674854823521, 50.32530212402344, 50.61933251789638, 49.3824211529323, 53.39130244936262, 70.95371164594377, 80.20416109902519, 62.36495304107666, 65.70236042567662, 45.0429619380406, 45.97183881487165, 55.34420830862862, 50.279586451394216, 49.95483807155064, 63.75154250008719, 49.51925550188337, 65.2960158756801, 86.45572635105678, 74.87909643990653, 89.48483521597726, 143.0999982016427, 95.58232416425432, 84.1369457244873, 59.58126149858747, 45.51722860336304, 39.384251730782644, 28.87985392979213, 29.07652963910784, 50.83970505850655, 56.89848559243338, 75.22244167327881, 78.98362663814, 73.08597482953752, 80.22772244044712, 84.54790387834821, 82.46853733062744, 62.238877977643696, 19.45062906401498, 2.5360073702675954, 0.12221360206604004, 0.3278122368667807, 0.1403389008981841, 0.12220426542418343, 0.1117150504142046, 0.06306068333131926, 0.06920501470033612, 0.05896408243903092, 0.0460761002531009, 0.05563552890505109, 0.07149052420364958, 0.049498454468058686, 0.06142250302114657, 0.02835661285955991, 0.06212017272732087, 0.02728349106785442, 0.019850083959421942, 0.019309364492073655, 0.022134794487750957, 0.013941910766464258, 0.035178261276866706, 0.04450128832831979, 0.02724812412634492, 0.015690591352592622, 0.033585854939052036, 0.06980687526187726, 0.03362017184762018, 0.0527282133033233, 0.028235786128789186, 0.049639918841421604, 0.003991779106269989, 0.06902284161852938, 0.0384444811913584, 0.014572733747107642, 0.04837396587910397, 0.07084658090025187, 0.11852473286645752, 0.04308581678196788, 0.016240102937445045, 0.0396861018879073, 0.06280017338160958, 0.02375878323800862, 0.056045058715556345, 0.03505992816228952, 0.08743399368332964, 0.1090902801869171, 0.06791204586625099, 0.029274338257632086, 0.07646330379481826, 0.03317253890314272, 0.07540548127144575, 0.013400358397380581, 0.05757411702403, 0.08299437976841416, 0.04865204310044646, 0.0789964310824871, 0.09699013483311449, 0.028148058336228132, 0.017986928578466177, 0.06227407804025071, 0.01064054697885045, 0.023920037085190415, 0.040438967025173564, 0.04792861620496426, 0.06167191213795117, 0.0196041845650013, 0.03592026306848441, 0.039665817083524804, 0.0770964448207191, 0.03837337411407914, 0.0111114138105352, 0.034766227672142644, 0.0519863641820848, 0.02394507672371609, 0.0839031281481896, 0.02896121809525149, 0.04135213606059551, 0.0071497048317853895, 0.015802134027970687, 0.04972274421847292, 0.04201140068471432, 0.09517615967031036, 0.04668738566605108, 0.04046333661036832, 0.051296307638819726, 0.03969844104722142, 0.008731137562010969, 0.008014306026910032, 0.01240477619493114, 0.02722802252641746, 0.05729297282440322, 0.01384557321268533, 0.07038379287613289, 0.021939712277214442, 0.013415666995570064, 0.050620144100061486, 0.02806363670554544, 0.0687387390062213, 0.031596973804490905, 0.01905433371263955, 0.05218337343207427, 0.07163875017847333, 0.0455908391491643, 0.01790193358569273, 0.052661682944744825, 0.05150953048307981, 0.06518222484737635, 0.07156091542648417, 0.08348987318043198, 0.10836472269147635, 0.5217668850507055, 2.250054691519056, 16.6519433089665, 43.31723437990461, 79.5472297668457, 92.61196231842041, 89.65536485399518, 81.45292609078544, 96.13552583966936, 97.80604648590088, 105.82676206316266, 82.80205086299351, 64.34006186894008, 60.22219807761056, 31.290058953421457, 46.63902568817139, 36.10198525020054, 23.96537917000907, 38.77362666811262, 44.25045040675572, 80.88265269143241, 81.02414580753872, 69.2076084954398, 72.58980396815709, 56.52121925354004, 53.06132902417864, 40.62675986971174, 43.63456208365304, 53.65559107916695, 51.39993831089565, 50.56342731203352, 58.629003933497835, 66.86742741721017, 73.32151876177106, 62.26907484872, 62.2808381489345, 44.25327484948294, 48.54092134748186, 51.47297082628523, 50.26579080309187, 54.255901541028706, 69.48272241864885, 51.758180482046946, 66.00145258222307, 72.96566677093506, 70.28700419834682, 65.28416919708252, 97.54290430886405, 65.74492509024483, 39.88390016555786, 32.941062109810964, 27.745357275009155, 45.74043948309762, 43.88725764410836, 54.55061980656215, 85.05238478524345, 95.14594949994768, 100.49794537680489, 95.64454528263637, 85.08424922398159, 95.34298651559013, 101.48801503862653, 103.629880632673, 73.68913405282157, 23.73068639210292, 2.5289599427155087, 0.4385939895042351, 0.2935108260384628, 0.11004476861229964, 0.21653622575104237, 0.03059254859441093, 0.038912222521113496, 0.03518283121021731, 0.03702431418267744, 0.049010034783610275, 0.04240102227777243, 0.022526353298287307, 0.11617207553769861, 0.06543856859207153, 0.016751124623364637, 0.056153583606438975, 0.11050085271043436, 0.03560743128348674, 0.03199730268014329, 0.026069266222683445, 0.03423015447333455, 0.06950179234679256, 0.025060937739908695, 0.01691350314233984, 0.04322671118591513, 0.050091107309396775, 0.07956414776188986, 0.06850282595093761, 0.04367808285834534, 0.055471167367483885, 0.025402654760650227, 0.06612753269395658, 0.05782270511346204, 0.06119806399302823, 0.016186259487377744, 0.03601197725428002, 0.02193270979582199, 0.08767169807106256, 0.019454771153894917, 0.02908690652943083, 0.033364187726484876, 0.0393416062662644, 0.01571630613346185, 0.08329146954097918, 0.03625899114246879, 0.06511259358376265, 0.036027325716401847, 0.032819833007774184, 0.044196198627884896, 0.07810637634247541, 0.07856211438775063, 0.028293193584041934, 0.028063212621158788, 0.11566423278834138, 0.014041442523843475, 0.021479234664833972, 0.03887322372091668, 0.048874687403440475, 0.10521938039788178, 0.11683602205344609, 0.11409398061888558, 0.16865320370665618, 0.15669835305639676, 0.12488282312239919, 0.23103905682052883, 0.09876359466995512, 0.07417349237948656, 0.12439824055348124, 0.12544317091149942, 0.1486704559730632, 0.10327872274709599, 0.10744965036532708, 0.09792500002575771, 0.12022221035190991, 0.1275728480624301, 0.2092484610953501, 0.13666098325380258, 0.0932797696441412, 0.09130514453032187, 0.15132603847554751, 0.09289217008543865, 0.1082281403775726, 0.1777638934020485, 0.09255932151739087, 0.11324871597545487, 0.25126743423087256, 0.09914808653827224, 0.13151299235011848, 0.06087483026619468, 0.1514728870242834, 0.11451613796608788, 0.12587917037308216, 0.10779235804719584, 0.12154859703566347, 0.13739411320005143, 0.19813233401094163, 0.1502291051937001, 0.20579631919307367, 0.19932016384388718, 0.3188263161906174, 0.08589487948587962, 0.16789114102721214, 0.13137556186744145, 0.1339742559939623, 0.1195709795824119, 0.12218051669853074, 0.1726310881120818, 0.20928679832390376, 0.22860949433275632, 0.16428144329360553, 0.4625188899891717, 1.1677874284131187, 11.182848572731018, 37.80831343787057, 71.46531445639474, 108.02169104984829, 106.97380542755127, 100.81384522574288, 84.19329561505998, 94.53445938655308, 95.33420399257115, 96.73785822732108, 69.24975626809257, 45.91950845718384, 54.746545110430034, 27.54775745528085, 40.19870219911848, 48.96605035236904, 38.21311548777989, 94.23860509055001, 116.56051295144218, 155.99585478646415, 143.0336012159075, 112.06974628993443, 143.49045916966028, 79.75168745858329, 70.82109832763672, 51.07169846126011, 53.269222600119456, 79.47630255562919, 80.30902331215995, 78.85099247523716, 83.53273037501744, 110.45039217812675, 128.11604118347168, 99.64712456294468, 100.28040422712053, 68.24664483751569, 73.35801070077079, 84.98671736036027, 79.92961692810059, 76.23573221479143, 101.88196400233677, 76.54499653407505, 95.83117389678955, 131.76270593915666, 114.15242018018449, 141.50251007080078, 208.79457664489746, 139.66315514700753, 129.1075074332101, 87.54384899139404, 66.23348767416817, 51.19471979141235, 43.164794376918245, 42.28190762656075, 68.18673052106584, 72.72567599160331, 95.67797306605748, 101.4710475376674, 94.67700862884521, 100.15978349958147, 113.22125039781842, 117.4243894304548, 92.72832380022321, 36.13062572479248, 5.566507611955915, 1.2118800452777316, 0.39704862024102894, 0.35440915397235323, 0.5644557486687387, 0.4014296223010336, 0.15368640396211827, 0.12236064060458116, 0.18314582960946219, 0.09654336023543562, 0.2235741266714675, 0.1031916599188532, 0.2926841803959438, 0.12453598316226687, 0.15351527743041515, 0.16197565916393483, 0.14292422788483755, 0.10616684598582131, 0.13324086820440634, 0.10848419913755995, 0.1386525785284383, 0.10890006646513939, 0.16073436077151979, 0.07732484649334635, 0.1081799508205482, 0.11811392062476703, 0.16489353616322788, 0.1369173066424472, 0.19477053226104804, 0.16741449731801236, 0.09163356226469789, 0.07700602324413401, 0.14420401278351033, 0.1370909030416182, 0.07312164774962834, 0.10747289018971579, 0.15975447478038923, 0.305950327111142, 0.08205023221671581, 0.15785178116389684, 0.1046059847410236, 0.10308992037815706, 0.16373450335647377, 0.22251140512526035, 0.09635896155876772, 0.18463988229632378, 0.16165088516260895, 0.24311847292951175, 0.1267627858157669, 0.14433833557580197, 0.11794929445854255, 0.12030180250959736, 0.07427003434193985, 0.2450602501630783, 0.19190434605947562, 0.1441609122391258, 0.18132008186408452, 0.16482513983334812, 0.18179785194141523, 0.1897040062717029], [0.09652809998286621, 0.010164491898779358, 0.049833898432552814, 0.050729856427226744, 0.030493088931377445, 0.028414172985191857, 0.006214874838146248, 0.022266465904457227, 0.022071611003151963, 0.05299391743860074, 0.04212210028033171, 0.028546239648546492, 0.006031806514199291, 0.07444926936711584, 0.01218084097906415, 0.06096584216824599, 0.055923665408045053, 0.0530533299648336, 0.0986881415758814, 0.07663957362196275, 0.037299741724772115, 0.019665366371295283, 0.020575517622221793, 0.018276250821405222, 0.013910183317161031, 0.08480863991592612, 0.038088039960712194, 0.06253485940396786, 0.032214664588017125, 0.014882681758276053, 0.01095500131071146, 0.02874039565878255, 0.02718803645776851, 0.02480883483908006, 0.10566558502614498, 0.0757249016314745, 0.11188390385359526, 0.04726541607773729, 0.1012627137824893, 0.05765979564083474, 0.02976213368986334, 0.06039550634367125, 0.05939668244017022, 0.028083163247044598, 0.021487109063725387, 0.0484538701629, 0.06635349842586688, 0.02601653726638428, 0.10160001354025942, 0.7566199600696564, 6.260732097285135, 32.00383697237287, 51.41532162257603, 75.19981833866665, 78.24784020015171, 66.08502551487514, 75.62660448891776, 72.36266735621861, 63.89803831917899, 22.899245841162546, 31.939802374158585, 28.905136687414988, 26.469796555382864, 40.82829236984253, 79.59426212310791, 122.57728467668805, 85.12562574659074, 97.53128692081997, 96.28298051016671, 47.48524679456438, 32.51427943365914, 10.41344153881073, 3.5272048115730286, 1.4815664482968194, 0.6134691557713917, 0.6453087872692517, 0.5328388937882015, 0.8243577852845192, 1.099737965634891, 1.650748461484909, 0.9276913404464722, 0.9580025311027254, 0.985787074480738, 1.4541143327951431, 1.7289207982165473, 0.5553659849933216, 1.3477825756583894, 0.776828252843448, 1.6856866095747267, 1.3648484370538165, 1.2143791168928146, 0.7433625257440976, 1.3106574820620673, 0.4449748785368034, 0.6595164420349258, 0.37346214588199345, 1.270133308001927, 4.095052421092987, 10.706778849874224, 36.62180430548531, 64.16427939278739, 83.1606751850673, 131.44554846627372, 110.11673968178886, 75.23549039023263, 54.57236419405256, 37.91075420379639, 30.925056185041154, 33.34218508856637, 45.00171743120466, 66.32062503269741, 70.5756949016026, 80.67061451503209, 67.31081976209367, 78.70912415640694, 86.6248802457537, 73.45487553732735, 50.6970967565264, 35.706757817949565, 15.37524482182094, 5.595244058540889, 1.125468339238848, 0.2715898023119995, 0.022174744933311428, 0.021892084207917963, 0.0879148578803454, 0.047106347113315544, 0.0485699912533164, 0.0553924912320716, 0.0639003636315465, 0.024007736040013175, 0.01937975232223315, 0.039998122823557684, 0.058417162857949734, 0.050952351452516656, 0.06038693644638572, 0.05174481589347124, 0.06156583675848586, 0.04300353084025638, 0.13442184483366354, 0.027277470765901462, 0.02458433135013495, 0.07793073076754808, 0.061597843255315504, 0.016046761169231365, 0.03993278329393693, 0.04353311045893601, 0.05997628026774951, 0.033655001050127406, 0.012939854491768139, 0.023928946249985268, 0.03742739451783044, 0.016177961004099677, 0.016823926341852972, 0.005813106196001172, 0.03562566691211291, 0.05629840333546911, 0.030397215325917517, 0.03916781987728817, 0.02309251273982227, 0.0779995002916881, 0.04689517683748688, 0.04759478036846433, 0.029943611273275952, 0.038057037695710144, 0.0217769249408905, 0.01320516168405967, 0.034917642761554034, 0.02098342912670757, 0.014450268354266882, 0.06420370271163327, 0.029323857743293047, 0.04553347919136286, 0.05845290808273213, 0.033526381344667504, 0.049504344152020555, 0.04302021601636495, 0.025153992032366138, 0.03248176311275788, 0.08318856970540114, 0.06194261368364096, 0.054104750510305166, 0.030824522753911357, 0.022143700259870717, 0.006872720051822918, 0.02683988183603755, 0.014107952526371394, 0.042462660398866446, 0.01316664888456996, 0.024629723646544983, 0.015219443777043904, 0.08841958615396704, 0.02502914667794747, 0.017652670353917137, 0.07003841855164085, 0.061685007863811085, 0.04247023963502475, 0.03897271052535091, 0.04110390759472336, 0.03380784784842815, 0.027286912580685954, 0.014278503999646221, 0.030288144214344875, 0.02824771816709212, 0.016116584118987833, 0.04090974140646202, 0.009813290654814668, 0.02139869086178286, 0.010398047044873238, 0.021385040433545197, 0.0905239675194025, 0.08881240364696298, 0.033325521408447197, 0.03141200855108244, 0.08817663669053998, 0.008962585856871945, 0.06059976574033499, 0.03518286852964333, 0.04658580558108432, 0.010403466843334692, 0.052138040507478375, 0.051492573892963786, 0.09449286812118121, 0.09362228733620473, 0.13624757900834084, 0.3469687732202666, 3.175575588430677, 32.2436158316476, 60.02449403490339, 88.53348786490304, 90.36079461233956, 79.79426601954869, 83.32763344900948, 85.2684668132237, 95.7112340927124, 52.08369663783482, 51.05887903485979, 55.891573497227256, 37.486254010881694, 34.6392365864345, 57.836992672511506, 49.059173583984375, 49.913183620997835, 68.58311830248151, 80.224428994315, 53.81547955104283, 41.75212485449654, 16.78806894166129, 6.558674326964787, 1.9742863348552158, 0.41450140944549013, 0.2893999351986817, 0.6083846486040524, 0.8683456906250545, 1.023112688745771, 1.1096521764993668, 0.5410035156777927, 0.8198968789407185, 1.0198951299701418, 0.7270196026989392, 0.5322592077510697, 0.29295081751687185, 0.7875465005636215, 0.8280990102461406, 1.589401513338089, 1.2119091408593314, 1.3287006510155541, 0.8246989526918956, 0.9044218776481492, 0.19646739906498364, 0.20673603591110024, 0.4716289554323469, 1.4464631719248635, 6.048324797834669, 15.513220412390572, 41.70944554465157, 61.96390996660505, 72.50753034864152, 95.47879600524902, 69.29859515598842, 45.557264123644146, 24.008174862180436, 31.048497881208146, 35.01168782370431, 57.72070067269461, 75.18528965541294, 91.5440172467913, 93.00961467197963, 94.37576253073556, 83.23997497558594, 93.56230218069894, 105.28369780949184, 87.39453220367432, 59.53761291503906, 40.38948583602905, 19.237750155585154, 5.996302332196917, 0.7962835345949445, 0.41368361189961433, 0.023047512297385504, 0.023394376006243483, 0.08809554497046129, 0.03958640134494219, 0.014590876077168753, 0.04408166870208723, 0.031235616587634598, 0.007860002922825515, 0.0484263114631176, 0.07493037783673831, 0.05670591111161879, 0.07504840221788202, 0.050518482590892484, 0.04764292921338763, 0.005408210779673287, 0.014334539117823755, 0.11876254581979342, 0.11026538748826299, 0.01327163097448647, 0.03489653692979898, 0.06216576349522386, 0.031226239233676876, 0.08853839085038219, 0.020384021469258835, 0.042594082453953366, 0.00987325533891895, 0.09726648857550961, 0.017172218366925205, 0.039278719640736065, 0.05368486625541534, 0.0565978204831481, 0.034809687840087075, 0.06947733794472047, 0.048130538048488755, 0.07073097888912473, 0.03995783141415034, 0.010826367186382413, 0.03890115222228425, 0.03346831910312176, 0.05071113903873733, 0.013543528438146626, 0.027824634619589363, 0.030828220769762993, 0.013312868092076054, 0.044767531898937056, 0.03393825888633728, 0.01382002976190831, 0.029407996085605452, 0.036156766449234316, 0.04629963682964444, 0.05663917040718453, 0.029189962428063154, 0.0383073221226888, 0.24934340747339384, 0.11525802101407732, 0.06921037512698344, 0.18151545923735413, 0.1910950302013329, 0.08365009565438543, 0.15050397972975457, 0.0915918934292027, 0.14254594461194106, 0.09686726571193763, 0.13663931084530695, 0.1191707117749112, 0.04035466244178159, 0.14716162479349545, 0.09788764667298112, 0.15675438647823675, 0.1362646645201104, 0.1356548379574503, 0.24039464337485178, 0.19834057640816483, 0.1547479855694941, 0.15861912284578594, 0.17113675044051238, 0.11263093698237624, 0.09578446631452867, 0.11914741088237081, 0.1487507673778704, 0.16910741504813942, 0.05855175027889865, 0.10498493297823838, 0.054194524085947444, 0.20559396647981235, 0.12242903693446092, 0.09363321853535515, 0.2920128921312945, 0.1806664897927216, 0.1938952220869916, 0.15034194556730135, 0.22615251903023037, 0.16581096979124205, 0.1803540786994355, 0.15167825243302754, 0.2154870749052082, 0.11511554223086153, 0.12429608032107353, 0.11365099224661078, 0.17320427378373487, 0.26814083595361027, 0.2471442754779543, 3.8608903118542264, 19.955598081861222, 62.37046296255929, 87.78752926417759, 109.32527732849121, 103.15657629285539, 86.53262901306152, 92.50293118613106, 95.0640093939645, 85.96535028730119, 33.9687944820949, 46.031179904937744, 39.01115778514317, 36.49467658996582, 55.89932073865618, 97.57159342084611, 160.0391366141183, 115.87521212441581, 137.97039331708635, 150.57713535853793, 73.41055297851562, 54.62303393227713, 17.844839572906494, 7.358122331755502, 2.5829669875758032, 0.6136005201510021, 0.9934096825974328, 0.9724837711879185, 1.3091508086238588, 1.3177679862294878, 1.9995195865631104, 1.1197160993303572, 1.5433428819690431, 1.3060354100806373, 1.7715750294072288, 1.8946903773716517, 0.9116826908929008, 1.485483712383679, 1.1163873693772723, 2.479925419603075, 1.9198513243879591, 2.3603028442178453, 1.439185042466436, 2.1791971794196536, 0.7673358193465641, 0.8654280986104692, 0.8633113407662937, 2.0880259573459625, 6.829941987991333, 16.01367310115269, 59.759322983878, 98.81005423409599, 126.94579778398786, 187.50733893258231, 157.42918477739607, 108.10353388105119, 80.86260019029889, 57.13565192903791, 45.43622650418963, 45.31524099622454, 60.417907987322124, 87.30025904519218, 95.42009762355259, 101.90449006216866, 85.37196717943463, 98.7906687600272, 115.76671600341797, 107.23370974404472, 75.9799690246582, 56.54888698032924, 30.03386286326817, 13.455686841692243, 3.4064123332500458, 0.453828294894525, 0.10260764482830252, 0.09588419060621943, 0.30238248141748564, 0.2039375403629882, 0.1548403613269329, 0.1411351074597665, 0.17666282105658734, 0.15705465179468903, 0.10182287158178431, 0.16254230375800813, 0.1299268217491252, 0.10695024180625166, 0.13871440663933754, 0.11292523797601461, 0.147683160379529, 0.08176391758024693, 0.29259903782180374, 0.16571220223392757, 0.13113313487597875, 0.1463640204497746, 0.0876114373760564, 0.20162526943853923, 0.16711966028170927, 0.1478608822716134, 0.13720980951828615, 0.11908181011676788, 0.10170093883893319, 0.09401613620242902, 0.12592231162956782, 0.1339200274752719, 0.09841727039643697, 0.12959167973271438, 0.15128741626228603, 0.14752613380551338, 0.1382374508040292, 0.10572548609759126, 0.0871430921501347, 0.17207821777888707, 0.14323691039213113, 0.1277087586266654, 0.13103856066507952, 0.11371341068297625, 0.13822016173175403, 0.05347346527768033, 0.1352539323270321, 0.14017693458923272, 0.12562571040221623, 0.23522132954427175, 0.11783481203019619, 0.1677596816526992, 0.18496331279831274, 0.10145924466529063, 0.11966658516653947], [0.011095555598980613, 0.06198800089103835, 0.009655627106050295, 0.05130625156951802, 0.014338247311700667, 0.012493811015571867, 0.04376516264996358, 0.044766480169658146, 0.027280661576826657, 0.04828919649922422, 0.03549626010603138, 0.08161825646779367, 0.0880666325933167, 0.044424878499869785, 0.031202965482537235, 0.042334139080984254, 0.01694853590535266, 0.022229623149282167, 0.020877497935933725, 0.0590544090207134, 0.04868557969374316, 0.04022445157170296, 0.03807614863451038, 0.0496179309141423, 0.018582424481532404, 0.0615773650684527, 0.024739145899989774, 0.05967955690409456, 0.0035460818949754214, 0.03861834900453687, 0.02983827210430588, 0.015384668750422341, 0.04743784539667623, 0.021029783246506537, 0.0048469397588633, 0.07813791465014219, 0.03908697242981621, 0.13690453661339624, 0.07226599473506212, 0.03950811875984073, 0.030519511085003614, 0.07814577887100832, 0.026411722846595303, 0.06570949405431747, 0.08701930022133247, 0.04138764040544629, 0.014356652574081506, 1.717767853822027, 13.643586976187569, 37.65632506779262, 53.60931955065046, 54.57623781476702, 35.23430115836007, 49.53818586894444, 59.743606158665244, 76.21497794560024, 65.30632700238908, 44.02002034868513, 16.602842126573833, 81.21858419690813, 63.72735582079206, 48.708001204899375, 78.86005292619977, 62.08604540143694, 60.11128398350307, 56.91674893242972, 55.81233971459525, 20.354846784046718, 3.2831766945975165, 0.40983843537313597, 0.3911426514387131, 0.16481858518506798, 0.25028426413025173, 0.024048918026632497, 0.5405015626123973, 0.23351307692272322, 0.2425373483981405, 0.31280784628220965, 0.5730429621679443, 0.7694728789584977, 0.4709694193942206, 0.25906638002821375, 0.5408307878034455, 0.47154492565563744, 0.5356633365154266, 0.22726562858692237, 0.7961384366665567, 0.2847835629114083, 0.515922310096877, 0.453409095960004, 0.7795613918985639, 0.34547691898686544, 0.7190304228237697, 0.10903196688741446, 0.361090498311179, 0.11450595994080816, 0.052501640282571316, 0.15819351854068892, 0.14210111062441552, 1.0770719647407532, 0.5576623646276337, 0.9160642900637218, 4.853668034076691, 28.570341212408884, 69.21763474600655, 97.33921786717006, 100.73493453434536, 93.61788776942662, 56.26172488076346, 30.0084776197161, 22.52781251498631, 30.197062151772634, 47.534103052956716, 49.22820588520595, 70.98538848331997, 69.64692919594901, 72.10830770220075, 79.98177010672433, 84.31047698429653, 86.36957563672746, 74.40923145839146, 52.65225730623518, 15.838239771979195, 0.49873713510377066, 0.026911195866497498, 0.042813934585345645, 0.08173366170376539, 0.02461779160824205, 0.039541675709187984, 0.024685126030817628, 0.027026550212342824, 0.08386511661644493, 0.02594821048634393, 0.018510937424642698, 0.010238491231575608, 0.004459120948532862, 0.00481160801635789, 0.05475823062338999, 0.040447218011000326, 0.03408337038542543, 0.028352884309632436, 0.011535951119315411, 0.006942369551065245, 0.04686179291456938, 0.033502473163285425, 0.06858665895249162, 0.01373896433506161, 0.016573110961222222, 0.04430194491786616, 0.04922637549628105, 0.02479114882381899, 0.03347635295774255, 0.016472625013973032, 0.02335429155001683, 0.024883991074083105, 0.030674301886132786, 0.02467754340198423, 0.05388086448822703, 0.023214129963889718, 0.022987339811931764, 0.04141507696892534, 0.01154198159929365, 0.04050738710377898, 0.04248621913471392, 0.009185311584068196, 0.022079251307461942, 0.030769320537469218, 0.041869424017412324, 0.014260485502226012, 0.022280825401789377, 0.009482401356633221, 0.0036339210096879727, 0.01890364465569811, 0.027690154067905884, 0.014787140634975262, 0.06744667940906116, 0.040565337387046645, 0.019004371482878923, 0.050936785859188864, 0.07013793928282601, 0.05011846244867359, 0.03450923253382955, 0.028511033859103918, 0.021676978428981135, 0.026652546799076453, 0.034965313239289184, 0.034071689405079396, 0.04510034654023392, 0.014283820321517331, 0.05533089043040361, 0.0115353794535622, 0.03303706260131938, 0.03196562188012259, 0.01986732383790825, 0.04798514835004296, 0.039257450960576534, 0.03886677424556442, 0.0871827050245234, 0.04793603937806828, 0.0069073601126936925, 0.011612021680256086, 0.028720080320324217, 0.03882868807496769, 0.027139134438974515, 0.030713053021047796, 0.048328405645276816, 0.025780267980215803, 0.02964494051411748, 0.018701229177947556, 0.0489709138471101, 0.06462869633521352, 0.06656262970396451, 0.02627490134909749, 0.06186167124126639, 0.06683696141200406, 0.020534064221595014, 0.0752066501549312, 0.06112769991159439, 0.013800712718096162, 0.02110155698444162, 0.08247272204607725, 0.07913601930652346, 0.05526042117604187, 0.5759131110140255, 8.787300774029323, 37.544299261910574, 64.60073048727853, 71.12513760157994, 49.324532236371724, 61.662108012608115, 75.44078881399972, 98.79817281450543, 101.38763441358293, 81.25474957057408, 34.70435857772827, 44.45541531699044, 42.766930103302, 31.501492636544363, 35.18067148753575, 41.448387827192036, 57.17049714497158, 71.91361222948346, 58.90056037902832, 27.341415064675466, 5.457020504134042, 0.47624945321253365, 0.4172560716313975, 0.3954145179263183, 0.23599925637245178, 0.03894766919048769, 0.43533267879060333, 0.29393776027219637, 0.3192863900746618, 0.49418818205595016, 0.4474248242165361, 0.6318631544709206, 0.3151562288403511, 0.26193975870098385, 0.17492856697312423, 0.26811440022928373, 0.37345259210893084, 0.1397997234016657, 0.35796497602547916, 0.31275608763098717, 0.4924721398523876, 0.49336416912930353, 1.0530940571001597, 0.7150878086686134, 0.6305910370179585, 0.1422865813864129, 0.31491638028195923, 0.10516125708818436, 0.0743558079536472, 0.3261324555746147, 0.4437756628862449, 1.0728070735931396, 0.2842208945325443, 0.6243826587285314, 6.100319904940469, 34.85760804585048, 63.29417037963867, 85.40998077392578, 73.71199362618583, 52.15244558879307, 27.054315498897008, 27.780131271907262, 39.58821957451956, 53.039483887808665, 82.50817680358887, 83.12510735648019, 101.46253599439348, 85.74657930646623, 83.78346306937081, 92.85432243347168, 102.92764009748186, 100.772718838283, 91.40407357897077, 64.06356525421143, 19.982305220195226, 0.4669856588755335, 0.03295685636944004, 0.11009381990879774, 0.03716868607859526, 0.08040316988314901, 0.05248619343287178, 0.04342844643230949, 0.015583467636523502, 0.12007510395986692, 0.01240510358807764, 0.02667138971654432, 0.0715950932353735, 0.026857674720564058, 0.041241426286952834, 0.016023109134818827, 0.028688765929213593, 0.02770084947613733, 0.034202514349349906, 0.049179132495607646, 0.019975784267964106, 0.029116999557507888, 0.027450052755219594, 0.07849742964442287, 0.05105280516935246, 0.02966849585728986, 0.010471158344963831, 0.082235987963421, 0.05998141677784068, 0.05839227419346571, 0.06189852247812918, 0.020487168970118676, 0.04455447190308145, 0.0541599595120975, 0.004341005389246025, 0.0724265021937234, 0.020587827943797623, 0.008622116492395955, 0.026638972706028392, 0.014776670839637518, 0.029306137801281044, 0.07231535815766879, 0.06275315769016743, 0.023178327063630735, 0.06102764992309468, 0.08025268438671317, 0.020531268657318184, 0.01961380958424083, 0.08181344385125808, 0.0525752443687192, 0.07746404116707188, 0.0466008758438485, 0.04380072806296604, 0.02463117571148489, 0.08550630283675023, 0.16063924373260566, 0.1377924403973988, 0.20166211389005184, 0.07004420645534992, 0.15663640280919416, 0.08358615729957819, 0.175594671230231, 0.08514729674373354, 0.10381173914564507, 0.16299271530338696, 0.16545107481735094, 0.1817994261426585, 0.21434592828154564, 0.10318729693868331, 0.1536261093403612, 0.1373037594769682, 0.06884917058050632, 0.13324892920042786, 0.162498090416193, 0.08606876765510865, 0.21492972624089035, 0.09728431369044951, 0.15466839341180666, 0.1027285394125751, 0.08524242056799786, 0.11216273424880845, 0.15607051817434175, 0.14165558453117097, 0.1325450712548835, 0.09653025093887534, 0.05848714017442294, 0.10839852730610541, 0.10460897029510566, 0.16140121141714708, 0.1536030527204275, 0.13439040152089937, 0.22471903237913335, 0.23074731390391076, 0.09956309212637798, 0.25911108191524235, 0.15996718193803514, 0.15074054417865618, 0.10228470965687718, 0.23434990059052194, 0.11233296511428696, 0.09120700122522456, 2.798207849264145, 27.947091272899083, 73.74779769352504, 92.67587879725865, 83.6447422845023, 56.21659285681588, 70.56451525006975, 81.18699768611363, 102.19200651986259, 89.01636682237897, 62.24868188585554, 28.219462394714355, 99.25057697296143, 79.47955431256975, 73.4927362714495, 111.7046115057809, 101.33345236097063, 91.18284293583461, 84.57266725812639, 85.89034448351178, 35.90008796964373, 4.994676947593689, 0.7908453749758857, 0.715057193168572, 0.40835925617388313, 0.25815174196447643, 0.16163909222398484, 0.8510033669216293, 0.7690284113798822, 0.6318349816969463, 0.9209018647670746, 0.8913480277572359, 1.1958706357649393, 0.7776479231459754, 0.5974644688623292, 0.8912389193262372, 0.7987325031842504, 1.1206677854061127, 0.5852043181657791, 1.1152159465210778, 0.5453425028494426, 1.2134518580777305, 1.1645486993449075, 1.9925996150289262, 1.2097505309752055, 1.2338940011603492, 0.34156114767704693, 0.6568335688539914, 0.22887463867664337, 0.13066428074879305, 0.20322320583675588, 0.2713954427412578, 1.4634698650666644, 0.6348108191575322, 1.3195448794535227, 7.923300095966884, 48.76774181638445, 108.28909247262138, 143.70560319083077, 139.8464903150286, 129.1101199558803, 76.96246515001569, 45.82495389665876, 31.93513665880476, 41.40853296007429, 61.87943376813616, 69.08990601130894, 98.05973216465541, 87.29510348183769, 88.07872131892613, 104.51369844164167, 112.06890555790493, 115.93702329908098, 110.82390648978097, 86.33678708757672, 38.22360379355294, 1.0240252912044525, 0.338177320680448, 0.1887685236121927, 0.14670946262776852, 0.17391151083367212, 0.2279739784342902, 0.07759789577020065, 0.09773951569305998, 0.28719865903258324, 0.1012645186856389, 0.12837874410407885, 0.13223865841116222, 0.13094864120440824, 0.09072315825947694, 0.07362491038760968, 0.12690522388688155, 0.12770706228911877, 0.10640640277415514, 0.13575726960386547, 0.13866966404020786, 0.07629951901201691, 0.1767611407807895, 0.105996113004429, 0.1390632957752262, 0.08403756629143443, 0.11285095196217299, 0.12404559233358928, 0.10923686410699572, 0.15417189576796123, 0.08061553777328559, 0.13632277425910744, 0.154896435460874, 0.11618974458958421, 0.07106308106865201, 0.17322663829794951, 0.10109915291624409, 0.10802160110324621, 0.0866211290870394, 0.05640183921371188, 0.1556624879262277, 0.11780552645879132, 0.1342728114021676, 0.11638197356036731, 0.1468088680080005, 0.1936025292213474, 0.1533982708517994, 0.17480695992708206, 0.189079631918243, 0.10725254951311008, 0.11924910971096583, 0.07243264972099236, 0.11254984526229755, 0.1558037724878107], [0.013500999559515288, 0.039419010148516724, 0.00962480210832187, 0.04838868669633355, 0.056659662164747715, 0.008394686821182924, 0.06954291835427284, 0.015798239236963645, 0.09307563238378082, 0.037735293353242536, 0.037353074577237876, 0.025161776525367583, 0.028127357929146717, 0.03594462926100407, 0.006451769648785037, 0.016659790417179465, 0.06749702670744487, 0.11927482618817262, 0.04164660329531346, 0.14907394003655228, 0.05724804023546832, 0.031046424061059952, 0.042196918944162984, 0.01863823059414114, 0.06503171220953975, 0.060478701522307735, 0.049103852427963696, 0.03479639533907175, 0.06011506782046386, 0.11056857050529548, 0.009888150030747056, 0.006907574699393341, 0.04518672065543277, 0.04379187996632286, 0.025520485759313618, 0.038103917680148564, 0.031569401534008126, 0.03847715604518141, 0.024051520208429013, 0.008767010012109364, 0.04247927093612296, 0.018833533328558718, 0.03895385064450758, 0.06120678995336805, 0.06159993992852313, 0.48237103330237524, 13.328767572130475, 37.94029794420515, 55.09180457251412, 61.23061793191092, 53.38703972952706, 46.23264987128121, 29.290475096021378, 57.17472512381417, 35.20119299207415, 17.089844839913503, 15.031727620533534, 16.820284264428274, 42.6115266936166, 73.16599028451103, 56.433661528996055, 70.6365055356707, 63.07749775477818, 42.30730676651001, 23.701563017708914, 3.050365141459874, 0.16007132349269731, 0.3469689632100718, 0.1687881914632661, 0.017900907301477025, 0.25747000426054, 0.04527884196223957, 0.05677813098632863, 0.0991799912548491, 0.1742744863565479, 0.30059779861143654, 0.22439417695360525, 0.3345913988138948, 0.3971461664353098, 0.5708430973546845, 0.2563426047563553, 0.28919599471347673, 0.1871414373495749, 0.48243242715086254, 0.30547383267964634, 0.19632235541939735, 0.2853774981839316, 0.39673261291214396, 0.41740450795207706, 0.322624782366412, 0.24187952226826123, 0.329094260931015, 0.2766858988574573, 0.3620227782854012, 0.3729583743427481, 0.17024221058402741, 0.14033043278115137, 0.2050729330096926, 0.2477401920727321, 0.5669996035950524, 0.3305446702454771, 0.04067308535533292, 0.25071198546460693, 0.6513255472694124, 0.36852170526981354, 5.455871445792062, 29.25215925489153, 77.26253700256348, 91.55655874524797, 78.22605064937046, 71.9882984161377, 33.809437547411235, 20.07804618562971, 23.665915284837993, 23.981615373066493, 42.061392647879465, 55.200043610164094, 70.55174446105957, 69.72135829925537, 60.06285503932408, 68.53025640760148, 75.20681517464774, 75.43925326211112, 40.695210048130576, 2.840102881193161, 0.2189176936766931, 0.04382378129022462, 0.014468497197542871, 0.013421976523074721, 0.03425108388598476, 0.07538009049104792, 0.11901779712310859, 0.10398581730467932, 0.020776224888062904, 0.08466054286275591, 0.07981822519962277, 0.050592582007603984, 0.021649770871070877, 0.02400845698347049, 0.017501791307170476, 0.12770497240126133, 0.006385553536737072, 0.038511839362659624, 0.020483377655701976, 0.0714997047824519, 0.05437782353588513, 0.016644021263346076, 0.029395670496991703, 0.03229355446196028, 0.004418215889018029, 0.027701862189652662, 0.03878010496763246, 0.03519796932648335, 0.059283007468496046, 0.03584783963326897, 0.05663064800735031, 0.055646663664707115, 0.08626732735761575, 0.021598641561078172, 0.015152150066569448, 0.01717337018011936, 0.05181778894205179, 0.04281227895990014, 0.05484742744426642, 0.045547653787902424, 0.01349782062295292, 0.054454576024519544, 0.019328271870368292, 0.006141714768351189, 0.01781245686912111, 0.04496041565601315, 0.029251692151384692, 0.031043014422591244, 0.012576041826313096, 0.019165501497419815, 0.018765705271757076, 0.013343088345469108, 0.04573287009926779, 0.023016711896551505, 0.02787102945148945, 0.024068658306662525, 0.05031725624576211, 0.06207499586577926, 0.03758861104558621, 0.024861750392509357, 0.05740314655538116, 0.03070504291515265, 0.01953387985538159, 0.043633961118757725, 0.038433098766420565, 0.04667430351089154, 0.023326459739889418, 0.038522767169134955, 0.022488078834222894, 0.061281259171664715, 0.08851785159536771, 0.05476571825732078, 0.012822462844529321, 0.04885386994906834, 0.024716058745980263, 0.0315140398618366, 0.08719196024217776, 0.0631630742656333, 0.00350474299713304, 0.04424719392721142, 0.05647055106237531, 0.061305557510682514, 0.02766651051518108, 0.032252995031220574, 0.01481190207414329, 0.03471048602036067, 0.002919005275803751, 0.017408387569178427, 0.05321277890886579, 0.08260729589632579, 0.04373496784163373, 0.021736041509679387, 0.07680926844477654, 0.07992646510579757, 0.06290174328855105, 0.11751932038792542, 0.5356715332184518, 8.688475676945277, 35.820162841251914, 66.9525706427438, 76.63914462498256, 67.17528820037842, 61.90239061628069, 40.068833419254844, 78.19408893585205, 55.772061007363455, 42.37484325681414, 36.35773801803589, 25.198321376528057, 30.854031699044363, 70.12190805162702, 62.41724518367222, 48.183047430855886, 64.18597861698696, 43.778229985918315, 27.49597774233137, 2.9113438470023016, 0.21323176021022455, 0.6475246112261499, 0.21116852520831994, 0.08923116153372185, 0.11461259850433894, 0.02433536497743002, 0.04119970316865614, 0.3208827115595341, 0.2981185402188982, 0.6716912601675306, 0.611279441842011, 0.6150884117398943, 1.014243096113205, 1.6204318425485065, 0.9620739583458219, 1.015638598373958, 1.105288599218641, 1.6678430927651269, 1.1656383723020554, 1.0012993620974677, 1.153110335980143, 1.6571645800556456, 1.543865082519395, 1.479024276137352, 0.9659486647163118, 1.0669242292642593, 0.6954280978866986, 0.7578729156936918, 0.5870201864412853, 0.3301228657364845, 0.3250590131751129, 0.20639385070119584, 0.2849948587162154, 0.2771419286727905, 0.12153752334415913, 0.09470714269472019, 0.32292469484465464, 1.1188515914337975, 0.23223143283809933, 5.2180072494915555, 30.960252285003662, 69.62154742649624, 78.4170149394444, 55.38436542238508, 40.731166975838796, 24.264938592910767, 26.005521399634226, 35.96434491021292, 47.64145272118704, 76.40194702148438, 83.7836993081229, 89.24321160997663, 83.95736258370536, 77.91554260253906, 77.29176807403564, 88.82490226200649, 88.8385763168335, 46.65495443344116, 1.808218200291906, 0.34879449382424355, 0.051148912869393826, 0.02736286779067346, 0.05507219216919371, 0.07227159943431616, 0.03755326954913991, 0.06793806768421616, 0.021835448586248925, 0.05403454588460071, 0.02864870861438768, 0.037970945172544034, 0.018736543532993113, 0.06163899640419653, 0.03406450032655682, 0.04012236258547221, 0.029882475268095732, 0.05496708370212998, 0.04665663106633084, 0.05969704953687532, 0.013773113306212639, 0.02610753050872258, 0.03618827761550035, 0.07452647986688785, 0.027087609882333448, 0.04046538917879973, 0.08498288092336484, 0.025941248717052594, 0.009956561627664735, 0.07353233785501548, 0.057878256775438786, 0.024100035462262373, 0.01874210582380848, 0.10836363025009632, 0.013654738631365555, 0.027720744122884104, 0.03082688744845135, 0.049167217420680184, 0.036707685994250436, 0.024905985786712596, 0.04491213110408612, 0.03084158112428018, 0.06353140342980623, 0.02784207127323108, 0.04241297806480101, 0.10027397290936538, 0.06089291322444167, 0.051941848892186365, 0.018342100948627506, 0.02234816660971514, 0.020394779641979506, 0.047328445195619545, 0.06790258030274085, 0.2990381180175713, 0.1783619270260845, 0.1004886274625148, 0.08980382473341056, 0.18803878634103707, 0.18661502988210746, 0.1565926508711917, 0.22334958586309636, 0.10726953324462686, 0.10049161301659686, 0.10198306691433702, 0.08109110261180572, 0.19309189090771334, 0.10708790299083505, 0.08943882039082901, 0.1313749918980258, 0.18145145981439523, 0.14971926755138806, 0.3582508292581354, 0.11807767328407083, 0.07738253554063183, 0.15989993911768707, 0.08868066607309238, 0.14097647954310688, 0.16402448208204337, 0.2186113622571741, 0.22480614270482743, 0.11503687288079943, 0.22242417266326292, 0.09839088895491191, 0.1476497628859111, 0.15537666183497223, 0.16876396776310035, 0.12542343911315712, 0.13548723980784416, 0.08288476922150169, 0.12016274354287557, 0.16153660629476818, 0.11468502533222948, 0.1429046725056001, 0.14644146843680314, 0.10806684581828968, 0.15073534660041332, 0.3072643508868558, 1.7306446028607232, 27.397962978907994, 77.74606214250836, 90.31881359645298, 87.87072699410575, 74.17982973371232, 73.02462223597935, 53.573383467538015, 90.62707042694092, 54.255463804517476, 26.833663293293544, 23.57547058377947, 26.07250029700143, 66.36236980983189, 106.20735658918107, 81.01575238364083, 110.49049718039376, 93.90156187329973, 63.28107302529471, 40.53632211685181, 5.542794712952205, 0.4212349738393511, 1.083305367401668, 0.2623494581452438, 0.1987534106842109, 0.4494741085384573, 0.11356726102530956, 0.19937752719436372, 0.4042499395353453, 0.43348090244191034, 0.6906350350805691, 0.4934390251125608, 0.5154322992478098, 0.7118071732776505, 1.0289814195462634, 0.5399850074734006, 0.5707610217588288, 0.39415320275085314, 0.6223973195467676, 0.5310471270765577, 0.5693919009396008, 0.4153367674776486, 0.6431595683097839, 0.6608967993940625, 0.6642607588853154, 0.4531686502907957, 0.8285017886332103, 0.5758915064590318, 0.644998832472733, 0.7065748540418488, 0.5038843931896346, 0.5982784937535013, 0.5381428120391709, 0.4522124316011156, 0.7145050827945981, 0.40952522360852783, 0.1958227636558669, 0.2911014567528452, 1.2920322929109846, 1.0967347153595515, 8.515396918569293, 46.97022199630737, 112.97346373966762, 138.17389215741838, 114.11994429997036, 104.92346150534493, 52.89376974105835, 29.603494916643413, 31.70101363318307, 31.56309883935111, 60.86254405975342, 77.41410500662667, 87.89173834664481, 87.90018040793282, 78.5783382143293, 85.17609051295689, 98.86133193969727, 105.76436723981584, 71.4563512802124, 6.508217811584473, 0.43285154764141354, 0.12839661671647004, 0.06422008933233363, 0.12735820029463085, 0.15889934423778737, 0.15387251254703316, 0.2679752734090601, 0.21236721160156385, 0.21020812674292497, 0.16873815629099095, 0.21912014138485703, 0.13173510400312288, 0.14385535434952804, 0.17711373471787997, 0.08664215010191713, 0.2273681280868394, 0.1063469834625721, 0.1546267992151635, 0.16173579703484262, 0.14629073866776057, 0.15002444546137536, 0.08875909793589797, 0.25744522416165894, 0.16346597990819386, 0.09534151865435497, 0.25760372994201525, 0.08493417567972626, 0.08054627970393215, 0.17631085137171404, 0.18154729610042913, 0.2366751315338271, 0.1388310468090432, 0.2217087253396, 0.13829610337104115, 0.08737194844122444, 0.12093092660818781, 0.11935250487710748, 0.0822107871728284, 0.16464786577437604, 0.20010670806680406, 0.12245673473392214, 0.14966639610273497, 0.10068006254732609, 0.1511589695832559, 0.2302598814879145, 0.13914845192006656, 0.10103812547666685, 0.06782066076993942, 0.042524678499570916, 0.1490633820316621, 0.09760393761098385], [0.04053926807163017, 0.027786947088316083, 0.01694810333927827, 0.09793862500893218, 0.08350490273109504, 0.020058365372408713, 0.06224540315036263, 0.004337833238033844, 0.049456208877797635, 0.031937849441809316, 0.024233209834034954, 0.01674041394809527, 0.04191137444494026, 0.050454764759966304, 0.0367418909445405, 0.034061192468340905, 0.09859101607331208, 0.024475906543167572, 0.052605035448712964, 0.09967446686433894, 0.0212588040823383, 0.03163791660751615, 0.02644399566841977, 0.03829966824767845, 0.005436920020396688, 0.010310525357324098, 0.03784601669758558, 0.07131994049996138, 0.027836877087663327, 0.024447160407102535, 0.03661991748958826, 0.07203172373452357, 0.044935988395341804, 0.016473776827167188, 0.0541743648105434, 0.08569678797253541, 0.07694023248872586, 0.018774324362831454, 0.04873428833005684, 0.0851883345416614, 0.026210145359592776, 0.05047525651752949, 0.0813924807256886, 0.22293498739600182, 8.504809600966317, 40.894814423152376, 55.333647046770366, 55.39460359300886, 35.942465032849995, 47.87485313415527, 39.315092836107524, 29.10078058923994, 28.48150154522487, 18.093239409582957, 21.352102620261057, 36.48121445519583, 54.665219920022146, 64.64372594015938, 62.345671789986746, 34.40004137584141, 35.711809158325195, 39.42626748766218, 6.928770559174674, 0.20085650283311093, 0.5569812783173153, 0.2848671855671065, 0.03691867306562407, 0.08388900783445154, 0.08219898066350392, 0.014268548194585102, 0.2392519632620471, 0.04775054147467017, 0.10155723869268383, 0.08853428571351937, 0.09342062672866241, 0.2625225931406021, 0.14349809209150927, 0.1675688504640545, 0.12623897035207066, 0.4497369187218802, 0.21003508674246923, 0.2032537670539958, 0.3662235885858536, 0.6560851718698228, 0.23615925492984907, 0.32647644568766865, 0.5521856642195156, 0.3876752560692174, 0.21190892904996872, 0.4680075868964195, 0.28467619153005735, 0.17710058470921858, 0.2175687932010208, 0.1586078048816749, 0.11600046046078205, 0.0852103733590671, 0.07879320305905171, 0.12022470736077853, 0.1299163315977369, 0.21658999286592007, 0.27581484988331795, 0.42755802454692976, 0.28544290895972935, 0.26280698073761805, 0.1065652681780713, 0.1342251646731581, 0.21420681503202232, 1.459832917366709, 14.500802738325936, 44.90363318579537, 82.53102248055595, 107.93463012150356, 88.2004954474313, 62.421844891139436, 49.9032199042184, 23.823646341051372, 16.36470651626587, 34.6810473714556, 53.00107772009713, 59.608943121773855, 62.988116128104075, 69.59923676082066, 66.94706072126115, 75.03166498456682, 58.714584895542686, 14.439836638314382, 1.4561374528067452, 0.30696156142013414, 0.10062984417059592, 0.04950413041348968, 0.11768944268780095, 0.1103548998279231, 0.05536667975996222, 0.0694905761629343, 0.050297789076077085, 0.0432458017686648, 0.02643659115502877, 0.024538204539567232, 0.023595668508538177, 0.03380111338836806, 0.009898244087318224, 0.038626464283359904, 0.009378934096145843, 0.03290206466668418, 0.04212093998544982, 0.07761184645018407, 0.020704574982768724, 0.10720102834914412, 0.07557411079428025, 0.03299993655777403, 0.01325396022626332, 0.02272256526962987, 0.05330033367499709, 0.03914034938705819, 0.028690842246370654, 0.0860405338129827, 0.012295940026108707, 0.03371666291994708, 0.02857107063755393, 0.028763109618531804, 0.019745589566550086, 0.05082142812066844, 0.05074570361258728, 0.030075267422944307, 0.031156272095228945, 0.02462109607378287, 0.042102093675306866, 0.02341157347629113, 0.0656465260045869, 0.035193843833569965, 0.0120984201785177, 0.04758473126483815, 0.015187474599640285, 0.016694370258067335, 0.03974292241036892, 0.0699207673647574, 0.03939054899715951, 0.03318440987329398, 0.026006382989830205, 0.0361982893997005, 0.0356241673497217, 0.03182900563946792, 0.05241998537842717, 0.034890128166547844, 0.06486572897327797, 0.04594140087387391, 0.04462273931130767, 0.015474745970485466, 0.06578909978270531, 0.03532238890017782, 0.013920903322286904, 0.03292815773082631, 0.03241577897486942, 0.0503326216712594, 0.08597005438059568, 0.03829116959656988, 0.026226126555619494, 0.01936164391892297, 0.018891609140804837, 0.05758329081748213, 0.027815379401934997, 0.04782884780849729, 0.03933704990361418, 0.05407995005537357, 0.054795468625213416, 0.027048417699656317, 0.034666140364216905, 0.06337502824940852, 0.014565637967150127, 0.026215967190052782, 0.045664857141673565, 0.09120560344308615, 0.04390457445489509, 0.031978178170642683, 0.04404263936781457, 0.04279830453119107, 0.02134220621415547, 0.052950637082436254, 0.11464135481842927, 0.0713742436575038, 3.2264266312122345, 30.764806406838552, 61.61271326882498, 69.07630838666643, 50.25632388251168, 65.94795840127128, 68.84104238237653, 60.81385803222656, 43.37334108352661, 41.888851506369456, 31.011922563825333, 16.192068099975586, 32.48424237115042, 30.507775170462473, 43.39293500355312, 33.81765031814575, 36.44807849611555, 41.4222799709865, 11.350842118263245, 1.3518961263554437, 0.3482957163027355, 0.1528568270483187, 0.05245140154979058, 0.12947626092604228, 0.03369889887315886, 0.09873447873230491, 0.5360237200345311, 0.7573791050485202, 0.8570924858961786, 0.7538609281182289, 0.9567999499184745, 1.4408038641725267, 1.2032448457820075, 0.8850567053471292, 0.6697878880160195, 0.8745389782956668, 1.0060143662350518, 2.034736313990184, 1.7743632112230574, 3.2176280404840196, 2.8105552324226926, 2.092291282755988, 2.8605069177491322, 3.3624267620699744, 2.9166157926831926, 3.1042449474334717, 3.404238849878311, 2.551935464143753, 1.9502768346241541, 1.3319448083639145, 0.45315744089228766, 0.757173264665263, 0.5280244435582842, 1.3036554349320275, 1.2647428086825778, 0.9472352117300034, 0.936797063265528, 0.6953890142696244, 0.1329987533390522, 0.5825129225850105, 0.04225159529596567, 0.08765241410583258, 0.11583801917731762, 1.9027492020811354, 15.107803446905953, 47.24233429772513, 78.9423473903111, 79.96202332632882, 54.33753245217459, 46.02917534964425, 34.435939243861604, 20.369570016860962, 31.86075966698783, 70.96496772766113, 87.09649617331368, 84.05583940233502, 84.94707788739885, 85.52188846043178, 77.79433127811977, 88.60328946794782, 67.53416960580009, 15.899566309792654, 0.6970474081380027, 0.25477236615759985, 0.14216812274285726, 0.037569330473031314, 0.12295525441212313, 0.11631618280495916, 0.013338995082969112, 0.04195374217150467, 0.04898643533566168, 0.047950644844344685, 0.0624102328770927, 0.028763893326478343, 0.016833296910460507, 0.05947993190160819, 0.040475804691335986, 0.021895587144951736, 0.041508344999913654, 0.004866470541206321, 0.04177209834701248, 0.011018207695867335, 0.021106934374464408, 0.04177934510101165, 0.02983151050284505, 0.020360496660162295, 0.028595114525939738, 0.026596649084240198, 0.013794815400615335, 0.032025845255702734, 0.010746616421134343, 0.0488993250099676, 0.019981672255588428, 0.08724978499646698, 0.04272911770801459, 0.03292689226301653, 0.03199939596067582, 0.026739808098812188, 0.02872217699353184, 0.044141878506967, 0.04927432417337384, 0.05736495860453163, 0.01593684358522296, 0.04960685043728777, 0.05758970297340836, 0.026333782921678255, 0.049308827679072104, 0.026656395788969736, 0.031061623245477676, 0.03728743309953383, 0.06253606719630105, 0.03933529928326607, 0.10819108558020421, 0.16232114205402987, 0.0871677433273622, 0.19629300199449062, 0.24618998382772717, 0.17052776526127542, 0.14251498984439032, 0.11987436615994998, 0.1359431203454733, 0.1812813782266208, 0.11386821844748088, 0.04936294084680932, 0.18999645486474037, 0.12947879864701203, 0.2052941761378731, 0.09970712475478649, 0.13905948240842136, 0.13863015973142215, 0.12533563668174402, 0.22258835099637508, 0.10710592488093035, 0.08586746667112623, 0.19034970019544872, 0.16054176539182663, 0.10691261703946761, 0.10973446097757135, 0.1279605765427862, 0.15892922692000866, 0.16172111353703908, 0.1210118622652122, 0.19749900299523557, 0.1535601285951478, 0.14232525788247585, 0.1347986760416201, 0.19020821207336017, 0.2452719530888966, 0.13609850486474379, 0.12000125220843724, 0.1227872898536069, 0.16816832258233003, 0.08013020881584712, 0.08806319242077214, 0.2472001596220902, 0.3555622292416436, 14.63903454371861, 64.02795573643276, 92.23553671155656, 81.5902989251273, 61.27378708975655, 75.79702990395683, 64.8609266281128, 52.076824869428364, 50.98696517944336, 35.953269481658936, 37.957487787519185, 55.470123563494, 78.70073768070766, 100.53838389260429, 105.09365762983049, 52.26227228982108, 55.34510115214756, 61.9554887499128, 11.783581137657166, 2.166550589459283, 1.024930945464543, 0.2250410650989839, 0.11419040044503552, 0.40243179138217655, 0.10691936846290316, 0.1916053021060569, 0.48473890338625225, 0.4667995774320194, 0.4294912793806621, 0.6406894294278962, 0.6020630363907132, 0.8682813112224851, 0.6125672470246042, 0.31948696502617424, 0.22974788610424313, 0.36432048784834997, 0.49463921785354614, 0.9709424653223583, 0.5978034649576459, 1.5807593656437737, 1.56355063191482, 0.676578015089035, 0.9450232961348125, 1.3972369219575609, 1.24245266190597, 1.5134776788098472, 1.5827769488096237, 1.7126054508345467, 1.1460782161780765, 0.4181847689407212, 0.2600263442311968, 0.3836056472999709, 0.20528781147939817, 0.3260985831064837, 0.4379110304372651, 0.43415620763387, 0.5190698440585817, 0.6572275534272194, 0.36098155272858484, 1.4282745250633784, 0.14379184347178253, 0.11077606651399817, 0.4450409678476197, 3.172222431216921, 19.617276396070206, 70.38171509334019, 125.98220770699638, 144.40417507716586, 126.11974034990583, 90.76645823887416, 70.32511506761823, 32.98582240513393, 22.4886246749333, 50.54866239002773, 69.39623819078717, 76.05969265529087, 85.76832021985734, 91.55877522059849, 86.529953956604, 100.00339344569615, 88.59407615661621, 30.919035570962087, 2.432284878832953, 0.4398939811757633, 0.34857315570116043, 0.1432469527104071, 0.2706027781324727, 0.19053389531161102, 0.12238727988941328, 0.15649096561329706, 0.08229802642017603, 0.12380195754979338, 0.13269216407622608, 0.13120567026947225, 0.10031483428818838, 0.14243646977203234, 0.135540138397898, 0.11639040096529893, 0.061983393638261726, 0.11906557955912181, 0.14926976524293423, 0.136896122779165, 0.1248169509427888, 0.2018706684133836, 0.1479633410594293, 0.12634355973984512, 0.09105721461985793, 0.19134756736457348, 0.11782063064830643, 0.09131787384727172, 0.11133642787379877, 0.1357144404734884, 0.11073992095355477, 0.12297071143984795, 0.15416093064205988, 0.11416704526969365, 0.1424088262553726, 0.10836978456271545, 0.08092798279332263, 0.13376874130751404, 0.16870865358838014, 0.12083390967122146, 0.11011956352740526, 0.11489588687462465, 0.12787650605397566, 0.09012660384178162, 0.11371436063200235, 0.12099610668207918, 0.15266728507620947, 0.08178165448563439, 0.1629591549613646, 0.1648797211902482], [0.05442207758980138, 0.04068079351314476, 0.020787887208695923, 0.0038041480584070086, 0.04048477831695761, 0.057312141438680034, 0.04961637028359941, 0.10549510988805975, 0.05000610722761069, 0.02485697859499071, 0.0038878920022398233, 0.010354111902415752, 0.009830756994363452, 0.03095554108066218, 0.025502133083396723, 0.041027619902576716, 0.02832979885196047, 0.011571267170698514, 0.04197640524112752, 0.01466070581227541, 0.041832046915910075, 0.006052542968453574, 0.014836811094677873, 0.02910066382693393, 0.0404830751940608, 0.015906231477856636, 0.014826858682291848, 0.0039728628222032315, 0.04635650145688227, 0.08919960287000452, 0.008177444505106126, 0.023148286622017622, 0.025716143028278435, 0.02591212429771466, 0.05178747199741857, 0.0568878908109452, 0.010790871323219367, 0.09604237747511693, 0.024711237754672766, 0.019473980480272855, 0.05496954678424767, 0.045909160282462835, 1.8543454451220376, 23.13370759146554, 57.12065076828003, 63.89110401698521, 56.04038654054914, 52.264818804604666, 57.562361649104524, 39.98336015428816, 24.432202577590942, 17.720770801816666, 22.730654750551494, 43.31110954284668, 39.680456910814556, 52.70056465693882, 55.520661285945344, 50.49720055716378, 52.70493507385254, 30.140410014561244, 8.60917501790183, 0.16449966015560286, 0.3787182681262493, 0.06816173996776342, 0.0711606815457344, 0.27736402675509453, 0.029513942543417215, 0.07649615846042122, 0.3732693876538958, 0.10843488321240459, 0.239584852542196, 0.23211695040975297, 0.4864654764533043, 0.40010547478284153, 0.5705793372222355, 1.6854868488652366, 1.2785143554210663, 0.9053542933293751, 1.6762095923934663, 4.357936646257128, 2.2643608152866364, 3.899380726473672, 6.258929474013192, 7.624361668314252, 5.267411981310163, 2.527862995862961, 7.9943845101765225, 8.906882745879036, 8.805423413004194, 6.294210689408438, 4.019538964544024, 2.065978671823229, 0.9212415665388107, 1.3129583128861018, 1.257227246250425, 0.3995284214615822, 0.26810840197971886, 0.3521067218056747, 0.3477749542466232, 0.5753213741949627, 0.21737433863537653, 0.13847181679947035, 0.17775537100221428, 0.15032481934343064, 0.1345134742025818, 0.17188794298895768, 0.056848776659795215, 0.15148096159100533, 0.41730500757694244, 0.0995655959205968, 10.335968255996704, 41.47879661832537, 74.35953794206891, 72.14559173583984, 73.22275706699916, 88.39649023328508, 59.5081456048148, 20.3561269896371, 17.181066002164567, 14.620547124317714, 29.82067128590175, 53.23150430406843, 69.06391974857875, 72.37422915867397, 63.27714034489223, 69.64314242771694, 36.239173957279746, 15.810530355998448, 3.3647915380341664, 0.27990856021642685, 0.16263030974992684, 0.0724567309288042, 0.1291300995009286, 0.060515797031777244, 0.005849647003092936, 0.01107899340734418, 0.051117371169051955, 0.0034429515695332414, 0.04244021446044956, 0.0038284663293909815, 0.05003015450867159, 0.010408885793627372, 0.03044156776741147, 0.03512770363262721, 0.0531484639671232, 0.06943039010678019, 0.012058654633749808, 0.0035731509893334335, 0.09714176026838166, 0.016862368743334497, 0.013898411582756256, 0.07437701895833015, 0.02698820280576391, 0.09274040215781756, 0.029255359633160487, 0.05751022616667407, 0.06997657687004123, 0.04087917340387191, 0.05742965691855975, 0.029189765652907745, 0.028693261223712137, 0.014686753075303776, 0.015231385993372117, 0.04018882169787373, 0.009987098248010235, 0.05313230465565409, 0.06702920395348753, 0.037246853312743564, 0.06844009538846356, 0.04205043001898697, 0.01120701600198767, 0.0763083603233099, 0.05070474384618657, 0.020859282663358108, 0.01978957899180906, 0.019411327949325954, 0.04924699617549777, 0.047654800183538876, 0.029462740290910006, 0.027858887067330734, 0.058784487790295055, 0.023861313272001486, 0.057594669849744866, 0.1280108152755669, 0.04378541013492005, 0.043686150639717064, 0.0294625910132059, 0.017708873409511786, 0.022715252358466387, 0.07538864681763308, 0.02010916728925492, 0.040317197130726914, 0.06154993868299893, 0.02873262982549412, 0.07543619176638977, 0.027017422220004455, 0.03324412774028523, 0.022344884196562425, 0.04697235680318304, 0.017161081910931637, 0.09974971639790706, 0.020770014596304724, 0.043835329956242015, 0.04319230267511947, 0.0240349096711725, 0.027319556900433133, 0.015768778942791477, 0.020920355904049108, 0.05890677337135587, 0.0073040520406461185, 0.03743088897317648, 0.078279083860772, 0.04590915349711265, 0.014666125610736864, 0.03868131026891725, 0.07279738264956645, 0.053355301796857796, 0.06828139961830207, 0.40932899128113476, 15.291499921253749, 66.20060185023716, 83.60432461329869, 73.3897431237357, 63.750896317618235, 71.25894601004464, 62.257130895342144, 50.77528483527047, 31.229686055864605, 28.9263755934579, 30.795649460383824, 30.239303725106375, 46.06631694521223, 36.00007254736764, 48.43323816571917, 53.99247101375035, 41.21734632764544, 12.636092100824628, 0.7515148797205516, 0.5711030576910291, 0.326530999903168, 0.18922131003013679, 0.5282110135470117, 0.206660053559712, 0.2878241597541741, 1.9372837032590593, 0.7552276062113898, 0.6455050195966447, 1.3659669884613581, 2.72127457175936, 2.9183181013379778, 3.2140408158302307, 6.278901636600494, 4.23564053433282, 6.336134382656642, 7.159967090402331, 7.17687292609896, 5.773938698428018, 8.889620815004621, 8.033766899790082, 8.002487846783229, 11.587307555334908, 7.64877416406359, 12.747357947485787, 13.98476871422359, 11.968155690601893, 8.724079115050179, 7.65143358707428, 5.678278071539743, 8.625141109739031, 7.941652025495257, 5.56545843396868, 3.747824013233185, 3.1578440027577535, 2.6337062077862874, 1.7859467267990112, 2.329966357776097, 1.2341325197901045, 0.11538236934159483, 0.43164299534899847, 1.200850865670613, 0.7376424212540899, 0.23693962448409625, 0.10646502141441617, 0.4979714761887278, 0.30879105467881474, 0.26102924613015993, 10.848616770335607, 42.54217324938093, 66.1681468146188, 43.52204990386963, 47.8875926562718, 52.7545382635934, 30.133392333984375, 16.899363449641637, 28.616407769066946, 31.702847957611084, 48.24239894321987, 79.26979514530727, 82.73106111798967, 85.14150932856968, 77.63037463596889, 84.89860030582973, 38.72038262231009, 15.904624598366873, 1.592000465307917, 0.233265683054924, 0.021760816519547786, 0.04253366569589291, 0.05339515894385321, 0.021006290667823384, 0.07794948547546353, 0.029266857409051487, 0.05038552026131323, 0.009492852492257953, 0.023170917461227094, 0.024761983692379932, 0.018595455746565546, 0.03511096417371716, 0.03680261982870953, 0.018819105977724706, 0.0558143500238657, 0.04810653826487916, 0.01297621039806732, 0.03053709871268698, 0.013973227702081203, 0.03078573090689523, 0.0593336872490389, 0.009329348453320563, 0.043110990431159735, 0.07751146397952523, 0.045655449253640006, 0.03042214470250266, 0.021146760987383977, 0.022359749202483466, 0.01647534085038517, 0.04059042961203626, 0.04457760316186717, 0.058853291241186004, 0.06765111522482974, 0.03772013827360102, 0.03369160462170839, 0.06936018208840064, 0.024488713891644562, 0.011448662678178931, 0.033580107747444084, 0.01312779342489583, 0.028976929573608295, 0.04934989261840071, 0.047657999476151805, 0.03597341610917023, 0.02255580511077174, 0.036099738973592005, 0.13664524124136992, 0.2483086958527565, 0.14589292715702737, 0.07852790265211038, 0.17760856316557952, 0.13418320406760487, 0.07531296302165304, 0.2184822234724249, 0.16380667234105722, 0.13362877310386725, 0.10137599520385265, 0.13549535508666719, 0.0809433583968452, 0.1331088524311781, 0.09603743095483099, 0.11708451514797551, 0.16066034617168562, 0.13853155502251216, 0.18343134357460908, 0.163430763940726, 0.09925923057432685, 0.12803472684962408, 0.09622816036322288, 0.11629544677478926, 0.24952647622142518, 0.10559891896056277, 0.140813766845635, 0.07723926965679441, 0.08304171437131506, 0.20727738471967833, 0.1224807005907808, 0.09635784876133714, 0.09218085504003934, 0.1190456577709743, 0.12321908239807401, 0.15682853678507463, 0.11129287271095173, 0.21358113789132663, 0.14559291968388216, 0.22579292261174747, 0.19090433471969195, 0.2745893613568374, 4.368298581668308, 38.144682679857524, 93.29207284109933, 95.86108589172363, 82.79534585135323, 79.07974106924874, 87.45568329947335, 62.01313100542341, 40.63260677882603, 30.302633081163677, 43.54637554713658, 66.82776709965297, 61.21328912462507, 81.32742772783551, 95.15319647107805, 84.8382899420602, 74.94978046417236, 53.55785771778652, 17.338091816220963, 0.7986225805112294, 0.7116791201489312, 0.3514781269643988, 0.17320431449583598, 0.44510917418769425, 0.231183259082692, 0.21834114247134753, 1.2531924056155341, 0.7627383374742099, 0.7959203826529639, 1.4557947111981255, 1.7225323638745715, 1.8127191130604063, 2.54678532906941, 5.507912150451115, 4.398723440510886, 5.202639571258, 6.754086766924177, 11.678508741515023, 7.552722266742161, 12.289267557007925, 17.761858974184307, 19.388242925916398, 16.97914092881339, 9.41005391733987, 17.439149890627178, 17.877018417630875, 21.359973192214966, 13.390883599008832, 9.105041895593915, 5.837056568690708, 5.734900678907122, 5.076557559626443, 4.133176318236759, 1.7062126738684518, 2.05592462846211, 1.4036540176187242, 0.6680649518966675, 1.0906629668814796, 0.5403375742690903, 0.2076005573783602, 0.24527018889784813, 0.6473225163561958, 0.4422140009701252, 0.21995876995580538, 0.22647821583918162, 0.5457429470760482, 0.5316044485994748, 0.9512306430510112, 17.247959784099034, 65.61269392286027, 110.25685705457414, 103.79294790540422, 103.27377155848912, 121.69872665405273, 86.42313235146659, 31.023220334734233, 26.472256217684063, 24.616322892052786, 41.75822189876011, 71.45432935442243, 89.69337844848633, 94.11471176147461, 84.36085837227958, 100.60311331067766, 63.8207882472447, 38.13841887882778, 8.123271856989179, 0.3817788953227656, 0.5794717829142297, 0.1280565621065242, 0.20447157456406526, 0.16374787049634115, 0.15589511687202112, 0.1332965080759355, 0.15936078876256943, 0.0986369461087244, 0.13400244233863695, 0.08559464809617826, 0.1437504935477461, 0.16276413042630467, 0.17736296063022955, 0.1518793295004538, 0.2363261202616351, 0.15879027651888983, 0.15647032457802976, 0.07328100169875792, 0.16888786825750554, 0.08559441060892173, 0.1211778319307736, 0.10284150870782988, 0.17597946843930654, 0.1998181135526725, 0.140139832294413, 0.13307803337063107, 0.15823661908507347, 0.12084407412580081, 0.2034105493554047, 0.1430115553417376, 0.1262651210916894, 0.163739714505417, 0.134234148476805, 0.18684776739350387, 0.09847196031894002, 0.1658749013606991, 0.20249430994902337, 0.10210048061396394, 0.12424931568758828, 0.1312443603362356, 0.14707603438624314, 0.08128998801112175, 0.13750856848699705, 0.0964019942496504, 0.05602482140862516, 0.13084352255931922], [0.03973206924274564, 0.014663348706173045, 0.03205485941310014, 0.01768649702093431, 0.03984635828861168, 0.02955929921673877, 0.050501122272440364, 0.01995755372835057, 0.024658690306491086, 0.045904705700065405, 0.04379822426874723, 0.08337285303111587, 0.07085515079753739, 0.022253339644521475, 0.0663203519902059, 0.06688283716461488, 0.030927364914012805, 0.0530450959423823, 0.017890887035589133, 0.06356630727116551, 0.015509464911052158, 0.03686526896698134, 0.00996651319188199, 0.04839980788528919, 0.09035728539207152, 0.013610536315744477, 0.020191195387659327, 0.03688723314553499, 0.019626031696264232, 0.02672815595620445, 0.041293547954410315, 0.01756089849264494, 0.03707824075328452, 0.04213376429730228, 0.03960080325071301, 0.013714551493259413, 0.022893187989081656, 0.057783540072185655, 0.09469070179121834, 0.03090416919440031, 0.06636858225933143, 3.9564697316714694, 44.65892110552107, 73.74261433737618, 56.48991414478847, 55.73169544764927, 70.8344875063215, 58.12916789736067, 36.28635222571236, 24.842172350202286, 37.90929855619158, 62.116311754499165, 27.592608077185496, 52.49869864327567, 57.289964471544536, 40.34941904885428, 47.95370823996407, 31.473414966038295, 8.001580238342285, 0.5549424705760819, 0.4758939008627619, 0.06910902235124793, 0.07599254298423018, 0.025641185264768343, 0.07744707779160567, 0.10687227134725877, 0.04402496353057878, 0.27548060353313175, 2.131814156259809, 0.6944120324083737, 0.9455680783305849, 1.0787888211863381, 2.854857380901064, 1.452818276626723, 2.689513704606465, 3.4945489295891354, 4.139863525118146, 5.612965439047132, 5.717444198472159, 1.7089923875672477, 1.7218609941857201, 8.80015754699707, 8.107462099620275, 7.634331464767456, 7.990778395107814, 11.087172746658325, 13.419233117784772, 10.208831855228969, 7.901350736618042, 7.5148597955703735, 12.188558629580907, 5.661664494446345, 8.184579287256513, 7.263513922691345, 1.1275632211140223, 2.7290600282805304, 3.5888401099613736, 8.100599016462054, 6.175800357546125, 5.688343405723572, 2.834083352770124, 3.177881521838052, 0.7491002721445901, 0.2830414649631296, 0.026112522830122283, 0.2059409421469484, 0.09819879569113255, 0.12276522389480046, 0.17175503154950483, 0.04281017550134233, 0.08825403718011719, 0.6444686523505619, 15.190262930733816, 58.76601546151297, 64.15569141932896, 69.23818751743862, 123.79850006103516, 109.32292883736747, 74.4374828338623, 76.7373296192714, 52.56320571899414, 14.568234137126378, 37.13575908115932, 57.03253023965018, 58.53237533569336, 63.11747074127197, 72.13818495614188, 74.66500854492188, 62.91283934456961, 34.05454567500523, 8.177996737616402, 0.5867793879338673, 0.07151938908334289, 0.026817615709400604, 0.07167637494525739, 0.04653507491041507, 0.04518939747608133, 0.04869796295783349, 0.007215421796510262, 0.01779542564015303, 0.027719066445050494, 0.007441174638058458, 0.010583783283696642, 0.05275295947545341, 0.011189075536094606, 0.034581639005669525, 0.04854143171438149, 0.06695031068686928, 0.045426124773387394, 0.02622216221477304, 0.040525358103747876, 0.04969399468973279, 0.0305852339869099, 0.03825239471292921, 0.05454487207212618, 0.030769978716437305, 0.011267839032890541, 0.0372467854592417, 0.010144565869787974, 0.02072876475618354, 0.014263708543564593, 0.05018309290919985, 0.12562398692326887, 0.05754561176789658, 0.047690457198768854, 0.027934362213792543, 0.030223890340753963, 0.016306351703990783, 0.015448435775137373, 0.059863914868661335, 0.07672297236110483, 0.036578241868742874, 0.06767062310661588, 0.03247771904404674, 0.03714408239881907, 0.018567517067172697, 0.02247425537955548, 0.022039976004245024, 0.014286259654909372, 0.013499706950304764, 0.03529085737786122, 0.024727463223306195, 0.00809965470606195, 0.02010125557093748, 0.04163511569744774, 0.01739137160724827, 0.00752453351326819, 0.031063696169959645, 0.024581050633319786, 0.04693606875038572, 0.04184716467612556, 0.05178843890982015, 0.06703510720814977, 0.05112445168197155, 0.02962246404162475, 0.07744993442403418, 0.02804684466017144, 0.020024867794875587, 0.02084827173634299, 0.08338102937809058, 0.057773233125252385, 0.00921898812521249, 0.019242725567892194, 0.05081493454053998, 0.03770338524399059, 0.020608750571097647, 0.06028580080185618, 0.017204840634284273, 0.02038755833304354, 0.0780345941228526, 0.11518506492887225, 0.02857402226488505, 0.04988307186535426, 0.04481922269665769, 0.01656068189601813, 0.05528793916372316, 0.09787803183176688, 1.4447311162948608, 41.163355350494385, 84.42199557168144, 75.63274669647217, 67.36357743399483, 88.44590582166398, 98.33406094142369, 75.32206494467599, 31.799594674791607, 20.737814119883947, 35.02310718808855, 29.36694696971348, 55.87437670571463, 50.39249815259661, 37.94309459413801, 47.6235020501273, 40.24759667260306, 13.267471432685852, 0.08848385699093342, 1.030340226633208, 0.15858302478279385, 0.12075515889695712, 0.11032559390046767, 0.1988683816577707, 0.3590867572597095, 0.5003800040909222, 1.0156368613243103, 2.012939380747931, 1.128065554159028, 0.29189650980489595, 1.9593005904129572, 2.2068533982549394, 3.6336629390716553, 4.181557493550437, 3.8175704649516513, 5.003093821661813, 5.3583608610289435, 7.586730224745614, 8.41784507887704, 10.737693990979876, 15.91674746785845, 13.219365579741341, 12.297250168664114, 11.749917984008789, 16.09585813113621, 15.135358265468053, 15.77956223487854, 13.691322837557111, 11.862794075693403, 15.564696141651698, 12.928706799234662, 16.347931827817643, 10.370932459831238, 7.003410279750824, 5.488593118531363, 4.505934579031808, 4.376094460487366, 5.265952859606061, 5.341006866523197, 3.7994209017072404, 3.0409891988549913, 1.0394550689629145, 1.096477740577289, 0.6014740137117249, 0.5159642707024301, 0.29425175913742607, 0.18034833829317773, 0.10367508219288928, 0.05233273934572935, 0.028437504411808083, 0.5737831624490874, 16.179269518171036, 55.46514170510428, 55.2649884223938, 68.89084012167794, 99.06654003688267, 60.0327137538365, 37.29062747955322, 25.064926385879517, 51.519343103681294, 35.6361015864781, 57.57705014092581, 75.79902403695243, 70.28719179970878, 72.07788848876953, 84.03245871407645, 86.31291307721818, 66.98482418060303, 29.38395963396345, 4.168271669319697, 0.3521044962108135, 0.12072366130139146, 0.04794526066897171, 0.07710715210331337, 0.11284205636807851, 0.08276002055832318, 0.0544044458573418, 0.07218339666724205, 0.029053118878177235, 0.06546895339020661, 0.023815854818427136, 0.05987193515258176, 0.050188802781381776, 0.01494457941901471, 0.026064764142834713, 0.008822066343522497, 0.004425609800299364, 0.04795810194419963, 0.03753331722691655, 0.04118826985359192, 0.033525672275573015, 0.08567205537110567, 0.02758819400332868, 0.025404870177486112, 0.03252060924257551, 0.030594132973679473, 0.03137780699346747, 0.012997491800758456, 0.09026202586080347, 0.04921258766470211, 0.021335943335933343, 0.031471170019358397, 0.032400878345859904, 0.01979543814169509, 0.07506909075060061, 0.012906021887569554, 0.021371395094320178, 0.0338887970761529, 0.08395124985171215, 0.061228503073964796, 0.036460516043007374, 0.03243046586534806, 0.03256521952737655, 0.03346882461171065, 0.002112001525737079, 0.2081774885633162, 0.06479133439383336, 0.14608401618897915, 0.11878242689583983, 0.15794429262833937, 0.1350695743624653, 0.1212115144090993, 0.0755648012938244, 0.17023129974092754, 0.11714326270989009, 0.06763394828885794, 0.1566475307835, 0.13899603938417776, 0.18270643747278623, 0.18693215000842298, 0.13232848287693091, 0.12336407176085881, 0.14598645642399788, 0.11953800278050558, 0.1503441711621625, 0.1018388375107731, 0.09024158838604178, 0.1352684394057308, 0.18496070722384111, 0.1996659045772893, 0.1430381132023675, 0.1961396395095757, 0.10155741511178867, 0.16154466729078973, 0.25148763241512434, 0.17120757592575891, 0.07244562331054892, 0.22621123945074423, 0.1528166849166155, 0.18838379425661905, 0.15724454660500797, 0.13707281329802104, 0.19880761206150055, 0.2458995436983449, 0.16180732819650853, 0.28283698164990967, 10.939273391451154, 69.46080780029297, 105.79709325517926, 80.84119973863874, 82.41958727155412, 103.18989290509904, 84.02605942317417, 56.204937253679546, 42.784887722560335, 59.61206981113979, 103.89332853044782, 45.24489048549107, 74.91351781572614, 88.09932272774833, 57.79647077832903, 68.95461068834577, 49.663416726248606, 15.627294199807302, 0.6177913695573807, 1.477006584405899, 0.2901064530014992, 0.35705753043293953, 0.4208993704191276, 0.23410790786147118, 0.3146382894899164, 1.2993467918464114, 1.4677025122301919, 7.350242206028529, 4.264031742300306, 6.09403178521565, 8.077242646898542, 8.702534488269261, 5.922308794089726, 10.062450681413923, 10.64441442489624, 11.372682912009102, 16.679954971585953, 17.259300981249126, 18.283395971570695, 20.552700213023595, 20.80370041302272, 22.91657985959734, 26.395026990345546, 23.00344797543117, 34.477590220315115, 34.30026524407523, 30.71272271020072, 25.455868516649517, 23.834598439080374, 30.804994787488663, 17.58528961454119, 18.058163166046143, 24.759004150118145, 16.880917719432286, 15.67827660696847, 16.84589011328561, 18.43608958380563, 13.298333593777247, 13.499219042914254, 9.879849416869027, 6.502114253384726, 2.6098634643214087, 1.3479078603642327, 0.30260536660041126, 0.210462536662817, 0.2674224302172661, 0.1765595751681498, 0.30893794393965174, 0.18467397189566068, 0.16045428865722247, 1.3498820172888892, 26.577582223074778, 93.06763907841274, 88.54200635637555, 86.4853048324585, 146.78327996390206, 139.4887692587716, 98.55086558205741, 92.14225019727434, 70.94321986607143, 23.800347294126237, 48.27193920952933, 75.10784503391811, 79.22199153900146, 83.26631559644426, 94.05819511413574, 102.12778432028634, 89.09044851575578, 58.830675397600444, 15.80497874532427, 0.6642021334597042, 0.24112737977078982, 0.16827413333313807, 0.26178559554474695, 0.185252043019448, 0.1328303680888244, 0.15764841064810753, 0.21311799702899797, 0.11778723315468856, 0.13109980523586273, 0.07729714190853493, 0.10324755763368947, 0.11122477493648018, 0.07297367283276149, 0.135873068390148, 0.12176488685820784, 0.16181293289576257, 0.07660295987235648, 0.13842258229851723, 0.13291304079549654, 0.156890297042472, 0.1280904481453555, 0.15030671602913312, 0.1377521897000926, 0.18817648823772157, 0.12191625445016793, 0.12827346261058534, 0.06742062366434506, 0.20296889091176645, 0.07054743516658034, 0.10938918164798192, 0.22023810925228254, 0.10466900707355567, 0.13860516250133514, 0.22087700425514153, 0.09571759668844086, 0.09896885151309626, 0.11635723417358738, 0.14651977137795516, 0.20709906571677753, 0.0858239522203803, 0.11376868414559535, 0.10957900181944881, 0.19170698736395153, 0.07516767510346004], [0.02122580522804388, 0.041995902944888384, 0.05477953323030046, 0.054012758125151904, 0.05331829449694071, 0.0045472668882991585, 0.08615028006689888, 0.051116509429578266, 0.032406187882380824, 0.09733912574925593, 0.0548027560913137, 0.025114231576610888, 0.015966227544205527, 0.030266627868903533, 0.07698019820132426, 0.0401288425949003, 0.025940531166270375, 0.04759930619703872, 0.05012133604447756, 0.06852293772889034, 0.08843112803463425, 0.06626452891422169, 0.03451758869258421, 0.07056158940706934, 0.031076496733086448, 0.01888292219622859, 0.03910012583115271, 0.03259290036346231, 0.03393924954746451, 0.05621400375717452, 0.02806063079541283, 0.037227247043379715, 0.02509862187850688, 0.050523273048124144, 0.124912434390613, 0.11015505769423076, 0.079531150603933, 0.06548626960388251, 0.13108231260308198, 0.6789009390132767, 14.40667722906385, 52.32126944405692, 74.33797768184117, 61.73450824192592, 60.542113985334126, 95.38941437857491, 53.48901149204799, 17.22401281765529, 24.311241388320923, 40.00915534155709, 61.017829350062776, 49.96651799338204, 34.8954062461853, 31.85342584337507, 33.67018175125122, 33.36133084978376, 10.812753643308367, 0.3553033545613289, 0.14686311009739125, 0.31986585898058756, 0.1726650827165161, 0.10940045211464167, 0.13837432488799095, 0.12584634284887994, 0.09013242567224161, 1.3575871352638518, 0.27421945120607105, 1.213849425315857, 1.9845742285251617, 0.913972448025431, 0.5282712674566677, 2.556678261075701, 4.556278620447431, 7.106196284294128, 7.058449566364288, 8.35410143647875, 3.8380845870290483, 7.201608078820365, 10.9372010912214, 5.91382200377328, 5.716341171945844, 8.572381700788226, 6.061031316007886, 5.028883797781808, 12.602362070764814, 6.1921442576817105, 8.683935029166085, 15.988949673516409, 8.765446952411107, 8.305002859660558, 7.504020605768476, 8.868958609444753, 20.11128636768886, 13.905354278428213, 10.259870716503688, 12.932254723140172, 6.5361330679484775, 8.098412070955549, 7.06781747511455, 7.174134033066886, 6.395590552261897, 4.476788188729968, 6.373850507395608, 3.7609765189034596, 1.684088089636394, 0.41555370869381086, 0.057707761281303, 0.11636591942182609, 0.035627882328948805, 0.057691089675894806, 0.10595820325293712, 0.041231255047023296, 0.26009077791656765, 0.8310322357075555, 22.412191016333445, 42.796095166887554, 45.10500240325928, 61.97987692696707, 89.00260938916887, 168.7085290636335, 72.5487540108817, 29.95802674974714, 24.53451132774353, 31.195577348981583, 37.40187161309378, 62.11564472743443, 63.76747471945626, 65.84653554643903, 71.47253363473075, 79.69231510162354, 73.641615322658, 17.038989237376622, 0.7438598104885646, 0.12230962834187917, 0.015124548958348376, 0.0788128941452929, 0.060495332415614805, 0.04910603052537356, 0.012899664014444819, 0.021987771216247762, 0.07579876695360456, 0.018687575357034802, 0.016642638748245578, 0.013492623044710075, 0.03325487234230552, 0.017460451561159322, 0.03897103454385485, 0.013454653921404054, 0.027458953438326716, 0.03176206137452807, 0.01976396599119263, 0.0769676792302302, 0.016035836755431125, 0.04742550623736211, 0.059950719853597026, 0.04327957584921803, 0.024388843714924793, 0.01703010090360684, 0.04581283205854041, 0.04216667324570673, 0.021310751027028476, 0.0659646639334304, 0.08459292684814759, 0.0370517439608063, 0.031342852261981795, 0.03021149689863835, 0.08942121919244528, 0.04550973725106035, 0.04088472042764936, 0.05386007756793073, 0.015113193674811294, 0.025837017256500464, 0.03984254152913179, 0.061079306794064384, 0.017417259414547255, 0.05434886026861412, 0.027567639481276274, 0.02991602203941771, 0.05704855093998568, 0.054620270883398395, 0.0308353962775852, 0.03876198808263455, 0.023335452025224055, 0.04630236454041941, 0.034971749143941064, 0.08675501083156892, 0.08240298221686057, 0.013853945486646677, 0.020778766001707742, 0.01037884789652058, 0.026697713482592787, 0.0047730761330707795, 0.04909770829336984, 0.0214698081170874, 0.029010123506720577, 0.033914167500500164, 0.0557135400761451, 0.06984261370130948, 0.04028699892972197, 0.03049746887492282, 0.02909084881788918, 0.02067721475447927, 0.024360981370721544, 0.005869437749164977, 0.03771760394530637, 0.039051179707582505, 0.021188004042154977, 0.07022297329136304, 0.07895961377237525, 0.07543440721929073, 0.11468987007226263, 0.09468729554542474, 0.03344666365800159, 0.07036115694791079, 0.10799034099493708, 0.2899044666971479, 9.255295821598597, 52.44562482833862, 88.27295126233781, 81.23445388248989, 78.81854438781738, 96.05515602656773, 64.36976541791643, 40.406870228903635, 39.92780583245413, 36.446271964481895, 40.79370076315743, 54.09133693150112, 36.25361926215035, 35.76327446528843, 44.88305956976754, 46.55134984425136, 16.85139134952, 1.298775085381099, 0.3005464199398245, 0.11128125619143248, 0.2641316439424242, 0.28595115883009775, 0.4974877621446337, 0.21966870980603354, 0.6620561171855245, 1.5459720151765006, 0.18008993858737604, 0.5437565222382545, 1.4751558665718352, 2.780152520963124, 2.854816343103136, 2.690755695104599, 1.2735702778611864, 1.5456037606511797, 2.8175066879817416, 3.1314035015446797, 1.4408806200538362, 2.2701703778335025, 1.5209401526621409, 3.4341026416846683, 9.168605753353663, 20.95978127207075, 16.895534992218018, 15.352452993392944, 13.703841754368373, 8.192508918898445, 7.792329158101763, 8.348815594400678, 12.523711936814443, 6.915819985525949, 8.487422602517263, 8.28317596231188, 11.12282655920301, 2.9087397924491336, 0.49786752462387085, 1.3216709196567535, 1.27980509187494, 3.03855276959283, 3.2358303666114807, 3.8782942465373447, 2.041615899120058, 3.8958571212632314, 0.9951679025377546, 3.0338266917637418, 2.06490387235369, 0.7217149787715503, 0.5440122485160828, 0.4878546819090843, 0.6224367288606507, 0.37314033029334887, 0.1420779318681785, 0.01763591562796916, 0.2518249186021941, 1.279084107705525, 25.419517278671265, 47.36977468218122, 49.14359072276524, 63.22737039838518, 65.5529533113752, 150.39795521327426, 64.85068498338971, 19.891855307987758, 37.03702865328108, 54.35141495295933, 58.19667312077114, 77.1513866697039, 76.70618084498814, 76.44295528956822, 86.08523450578961, 92.47918919154576, 81.9321711403983, 13.953378490039281, 0.6598525611417634, 0.20963726166103566, 0.02059505264540868, 0.11803223857922213, 0.08021420466580562, 0.05416185262479952, 0.021499037709353224, 0.03380830246689064, 0.04636423336341977, 0.03262758707361562, 0.027597405116206834, 0.0680927261710167, 0.015235087401898844, 0.01457649961646114, 0.09129162132740021, 0.0529608049296907, 0.05036115746146866, 0.020082482203309025, 0.031943647523543665, 0.06314245358641658, 0.04076863665665899, 0.07047306772853647, 0.009900231346754091, 0.05783598404377699, 0.03492862145815577, 0.03891758294776082, 0.033242529790316305, 0.02252483507618308, 0.04539682563128216, 0.10209413631153957, 0.06935725760247026, 0.009124746396472412, 0.013941548598398055, 0.017742776411718557, 0.03902258624189666, 0.045041202035333426, 0.02896428168086069, 0.012607020342589488, 0.030393398566437618, 0.03823823029441493, 0.027028105753873075, 0.061022703402808735, 0.02677466274638261, 0.04052897130272218, 0.1461256510977234, 0.12471228013081209, 0.10354673050876174, 0.11761850863695145, 0.13238991743751935, 0.11527788851942335, 0.2005752364971808, 0.1205540546881301, 0.13446098273353918, 0.2628780369247709, 0.12972322053142957, 0.12338567631585257, 0.10998547822237015, 0.12948405050805636, 0.1583121536033494, 0.12724648628916058, 0.1499652907784496, 0.21777962760201522, 0.1526628474571875, 0.18690518502678188, 0.228314358741045, 0.18504008225032262, 0.08570599569273846, 0.10471418393509728, 0.13317215974841798, 0.13359114155173302, 0.3061121441423893, 0.11604892143181392, 0.13112335040100984, 0.16272371688059398, 0.1752515767834016, 0.12422399276069232, 0.24690876954368182, 0.23089352462972912, 0.22878743335604668, 0.25988491039190975, 0.20973099448851176, 0.1763775377933468, 0.2760022341140679, 1.1633944298539842, 30.031813144683838, 84.50175394330705, 107.81690679277692, 82.8076719556536, 89.43464142935616, 116.01561437334333, 70.08211571829659, 28.36147141456604, 42.67173283440726, 65.38698863983154, 102.3548583984375, 94.30759375435966, 51.933448791503906, 54.802696977342876, 50.1795254434858, 59.616120610918315, 20.112943513052805, 2.2924825634275163, 0.7968306509511811, 0.25242561208350317, 0.603785266833646, 0.3274901227227279, 0.39385418593883514, 0.1794347587440695, 0.9504362685339791, 4.049607293946402, 3.800058833190373, 4.620088704994746, 5.991259242807116, 6.470941594668797, 6.166118477072034, 11.776768428938729, 17.330797944750103, 21.535205023629324, 20.768299341201782, 23.707774707249232, 16.483475548880442, 21.965147393090383, 24.170252016612462, 21.471517835344585, 19.514978068215505, 25.129610640662058, 17.74051410811288, 13.652776837348938, 31.948234013148717, 26.328249590737478, 28.383881092071533, 36.14376129422869, 26.194901500429424, 22.160469940730504, 23.047549928937638, 23.76653562273298, 41.8706819670541, 33.760327679770334, 27.65586621420724, 30.262159824371338, 24.912300518580846, 23.26217109816415, 27.590249163763865, 27.205037559781754, 20.997089624404907, 24.78161879948207, 18.444271087646484, 14.294514196259634, 11.637348481587, 3.0582352791513716, 0.8962885226522173, 0.29221352136560846, 0.4240298052983624, 0.21315752847918443, 0.21336328743823937, 0.10475440070565258, 0.5942611864634922, 1.57395838201046, 37.6392741884504, 68.6848885672433, 62.93426064082554, 81.55192402430943, 107.57498441423688, 177.93380519321985, 84.59674971444267, 47.752665587833945, 34.68395171846662, 45.137766633714946, 51.49096666063581, 81.53417137690953, 83.2627511705671, 84.2096586227417, 88.09256213051933, 99.11558042253766, 102.59169469560895, 39.35441269193377, 1.3705399887902396, 0.5959342909710748, 0.21913384779223374, 0.2592205974672522, 0.1803921852260828, 0.10780972854367324, 0.21447630200002873, 0.11913251025336129, 0.21825654272522244, 0.1231461398835693, 0.14745572901197843, 0.16124826962394373, 0.07519957982003689, 0.07791627797165088, 0.1957063406173672, 0.12516085963164056, 0.15754763462713786, 0.09989645638103996, 0.08099063193159443, 0.2368747836777142, 0.1292132336114134, 0.10823231336793729, 0.18073067920548574, 0.11728716641664505, 0.1826087012887001, 0.10178157594054937, 0.1426841757659401, 0.17443668336740561, 0.10473960864224605, 0.17991281380610807, 0.2120606901922396, 0.0781207409288202, 0.10311056819877454, 0.08135681013975825, 0.21603058145514556, 0.0727167794747012, 0.13593843845384462, 0.12657646009964602, 0.08507304465664284, 0.10629781002977065, 0.1179513300635985, 0.2354195974767208, 0.07023070859057562, 0.1596707571297884], [0.04828929827947702, 0.02006541026223983, 0.041867364663630724, 0.06050312878297908, 0.014780523222205895, 0.08045155621532883, 0.042698492029947896, 0.04867190721311739, 0.0038839285095621434, 0.01061064563691616, 0.010408358232650374, 0.084919648244977, 0.148674269339868, 0.0030380239227919704, 0.056217623741499016, 0.018753807160205076, 0.03731585353878992, 0.03806835226714611, 0.04007711447775364, 0.025660667701491287, 0.03356706291171057, 0.0368796505167016, 0.0326068137240197, 0.06205307239932673, 0.0355757708395166, 0.023165857286325524, 0.018104308351342167, 0.07974260925714459, 0.06978741487754242, 0.09248462838253804, 0.019381993184132234, 0.046003313801650486, 0.03660605162648218, 0.06527420026915413, 0.09064568991639785, 0.1626005084919078, 0.08480996984456267, 0.150728276265519, 6.419187937464033, 30.192524978092738, 62.689364433288574, 78.53665597098214, 54.53802272251674, 54.92711836951119, 62.331573895045686, 74.8517552784511, 70.30156762259347, 35.66513116019112, 48.636622360774446, 35.65686280386788, 30.708081313541957, 32.6903954233442, 41.50135741915022, 39.634529318128315, 14.817017861774989, 2.51663253562791, 0.22238506190478802, 0.06730747116463524, 0.09836660418659449, 0.317997689225844, 0.13529977415289196, 0.011316254202808653, 0.31225329318216866, 1.0174880134207862, 1.17306230536529, 2.741560923201697, 0.9020055330225399, 18.19140182222639, 49.57332985741751, 73.60804857526506, 80.12304088047573, 76.71326800755092, 63.70776884896414, 45.26410225459507, 25.523841006415232, 11.393307771001544, 6.080801112311227, 3.276594579219818, 1.845223980290549, 6.006770661899021, 8.243892584528242, 20.700220891407557, 11.799991914204188, 6.051515758037567, 7.176096030644008, 10.792983412742615, 6.764032244682312, 8.816880992480687, 9.761540702411107, 8.51023440701621, 12.263913580349513, 13.085564988000051, 17.048176492963517, 4.436985867364066, 1.8789364227226801, 2.555008739233017, 5.021530866622925, 13.306356157575335, 24.085473571504863, 36.67711196626936, 40.37172276633126, 41.466008458818706, 39.64897462299892, 34.64704636165074, 22.868081433432444, 8.546790616852896, 2.508507703031812, 0.96562731053148, 0.13148665162069456, 0.20666523756725447, 0.4900608978101185, 0.13067387523395674, 0.03695245732420257, 0.10155703513217823, 0.3709797662283693, 3.178509682416916, 23.396148000444683, 51.9485958644322, 49.6956980569022, 37.336770466395784, 77.92410973140171, 89.42066165379116, 36.01748125893729, 18.11844399997166, 20.18470103400094, 23.938736302512034, 44.575501033238, 56.262047971997944, 61.922255516052246, 62.52004378182547, 73.66706657409668, 76.45626108986991, 41.55710629054478, 2.0690545524869646, 0.2800102047622204, 0.01801390034545745, 0.11275760589965753, 0.04213872778096369, 0.031228525896689723, 0.005550939348592822, 0.04152556961136205, 0.02591279604738312, 0.061999725976160595, 0.06357364902006728, 0.00655977800488472, 0.058528327250054905, 0.02251802767360849, 0.040344301212046824, 0.010375479818321764, 0.02584890858270228, 0.037736843805760145, 0.035432348892624886, 0.017473135076995407, 0.028309062821790576, 0.016486691044909612, 0.0035868221977060394, 0.03787262884101697, 0.037720026315322945, 0.03471759367468102, 0.033499535106654675, 0.039300666855914254, 0.05019250079723341, 0.016815514203959277, 0.04153660598344036, 0.04903734242543578, 0.03852925057123814, 0.044837322618280134, 0.060737691553575654, 0.040154498003955395, 0.019459919538348913, 0.004967195672049586, 0.03380026521959475, 0.011516494127655668, 0.05751893177096333, 0.01691304343486471, 0.016795134404674172, 0.008383859946791614, 0.015340043198583382, 0.03516074828803539, 0.029800070582755973, 0.026767814631706903, 0.06441136835409061, 0.05439054606748479, 0.0451914737932384, 0.027811406579400812, 0.013321655968736325, 0.03142341472474592, 0.020879687907706414, 0.08658899366855621, 0.006292892794590443, 0.07293180722211089, 0.04483516826959593, 0.010144172319477158, 0.0594033185126526, 0.034388578829488585, 0.021698993497661183, 0.04764265101402998, 0.05369079665147832, 0.02862950607335993, 0.0376446410747511, 0.056547137309930155, 0.049396643681185584, 0.0374029163670327, 0.1262189128569194, 0.09231589707945075, 0.08425935224762984, 0.04905196485508766, 0.013838221285758274, 0.03680869950247662, 0.04477887361177376, 0.1297031223241772, 0.10816111468843051, 0.11304616648703814, 0.1321423471506153, 3.0848640331200192, 28.121864523206437, 72.65678460257394, 95.27499839237758, 79.11324528285435, 82.58181381225586, 85.34256935119629, 119.94668279375348, 80.69582952771867, 19.636121647698538, 21.647027594702585, 42.196330138615195, 40.39798348290579, 38.1534617287772, 46.49039677211216, 51.69401734215872, 19.88668758528573, 2.5871862811701636, 0.2620731586856501, 0.11945404085729804, 0.027205659708540355, 0.52438244755779, 0.8155581089002746, 0.39965566034827915, 0.8652713298797607, 0.6985673808625766, 0.5184624195098877, 1.1790519782475062, 2.1647429721696034, 24.15310559953962, 60.29527228219168, 84.18472848619733, 91.85202394212995, 88.77410398210797, 75.10784503391811, 53.24800280162266, 32.52439948490688, 15.09379414149693, 8.47358787059784, 4.1196529524666925, 1.4988002606800623, 1.9316560966627938, 3.418023858751569, 2.893454189811434, 6.447992563247681, 7.675392712865557, 6.324492675917489, 0.8577938739742551, 1.6294653692415781, 3.5681700876780917, 3.774707462106432, 1.6324112968785423, 1.5264758041926791, 0.9623106313603265, 3.7545589889798845, 2.433716207742691, 0.7416712907808167, 3.86353714125497, 9.3767694405147, 20.109828983034404, 32.175676345825195, 45.947735513959614, 52.943560532161165, 54.60168906620571, 54.32493884222848, 47.04532854897635, 31.36236538205828, 12.078824860709053, 2.454198411532811, 0.9289655749286924, 0.08194121199526957, 1.0275025389024188, 1.8117373543126243, 0.253502257168293, 0.10260356004749026, 0.06053647877914565, 0.2840304976063115, 3.9720397761889865, 29.29507827758789, 51.21192005702427, 48.022929668426514, 45.45550428118025, 63.09119265420096, 45.70482996531895, 30.516964163099015, 25.858448880059377, 35.1431998525347, 47.49315731866019, 66.16464492252895, 70.76886177062988, 68.38258634294782, 76.27562877110073, 82.61558900560651, 86.09525380815778, 42.922691345214844, 0.2679297572800091, 0.07735121436417103, 0.05434550152027181, 0.12571007944643497, 0.02679636568895408, 0.05665280217570918, 0.02070615257668708, 0.007279513669865472, 0.03790121891402772, 0.032585351661379845, 0.04071865576718535, 0.07177459288920675, 0.016968157441754426, 0.017024324874260595, 0.027745578504566635, 0.049062773917934725, 0.04982681791963322, 0.016170405516667024, 0.028879210352897644, 0.014095408958382905, 0.024731544611443366, 0.03307458898052573, 0.011426194687373936, 0.02695094614422747, 0.0362927245109209, 0.059055277545537264, 0.03922261497271912, 0.04031997233895319, 0.0913800819377814, 0.04098693494285856, 0.07430598312722785, 0.06099081904228244, 0.023501927199374353, 0.04693750385195017, 0.050950722968471904, 0.04166467268286007, 0.021924053385321583, 0.036708449346146414, 0.04494239715859294, 0.027411289745941758, 0.04286305034267051, 0.018245375781719173, 0.0028260302871266113, 0.11436842089252812, 0.07140412633972508, 0.13161921022193773, 0.10612567248088972, 0.20546417630144528, 0.1403004822454282, 0.10830939494605575, 0.19088636711239815, 0.13731745231364453, 0.07318854451711689, 0.15549024859709398, 0.21356485305087908, 0.21844364197126456, 0.12213669690702643, 0.13524527422019414, 0.1757075251745326, 0.1688993897821222, 0.15506142803600856, 0.11164835042187146, 0.16214788492236817, 0.137734303517001, 0.11717537098697253, 0.09657048806548119, 0.10197755042463541, 0.08936419510947806, 0.14737183494227274, 0.1683739594050816, 0.3035730118198054, 0.2697158785802977, 0.23160883624638828, 0.16388774370508535, 0.05743995029479265, 0.12074916064739227, 0.07901192882231303, 0.20415571651288442, 0.41674228491527693, 0.2685221997754914, 0.26110803761652535, 13.948341914585658, 60.701158251081196, 96.17117009844098, 105.61072172437395, 78.66699722834996, 81.60720389229911, 87.60796696799142, 85.20989349910191, 92.03997966221401, 57.64585815157209, 75.187089238848, 65.33985900878906, 47.42387683050973, 51.57027687345232, 67.1474745614188, 64.51963111332485, 27.540215185710363, 3.5210793231214796, 0.6704080147402627, 0.265455818602017, 0.3267219667988164, 0.6085837579199246, 0.42253065002816065, 0.3663241203342165, 1.3563858568668365, 3.9420617733682906, 5.016030064650944, 4.934234133788517, 3.639235394341605, 24.728583199637278, 56.331335408346995, 84.14754172733852, 89.07617691584996, 88.96269198826381, 74.49137306213379, 51.82061004638672, 33.28706502914429, 16.484993730272564, 15.051302433013916, 10.287030356270925, 13.768151674951826, 18.774527651923044, 23.40783487047468, 41.84965671811785, 25.82947141783578, 18.501473869596207, 29.89947428022112, 28.548878226961406, 25.68821975163051, 26.540246077946254, 27.73941309111459, 21.144021442958287, 28.208826439721243, 27.15513907160078, 33.44829102924892, 17.864101716450282, 13.135414838790894, 11.937723449298314, 11.020179084369115, 19.27462077140808, 30.865256513868058, 44.5784192766462, 49.045923369271414, 52.85131972176688, 48.10192026410784, 44.89511122022356, 35.46184423991612, 19.541419437953405, 10.274696435247149, 4.016711481979915, 0.4876696861216, 0.7395853655678886, 1.3762573791401727, 0.2626311316021851, 0.22379759539450916, 0.35297559946775436, 0.487823306449822, 5.457919427326747, 42.642720631190706, 76.81325258527482, 71.38999598366874, 46.00951542173113, 106.30078901563371, 126.007540839059, 53.101062297821045, 26.228581156049454, 30.80423743384225, 35.07143190928868, 62.39553206307547, 72.18334824698312, 80.94848687308175, 82.43070438929966, 88.73079586029053, 100.49245629991803, 73.30644117082868, 8.667162077767507, 0.6611698961683682, 0.13382773314203533, 0.25351300516298836, 0.1426202306257827, 0.1761516670563391, 0.06840776998017516, 0.14559320466859, 0.156016167519348, 0.10581605016653027, 0.12133664983723845, 0.13783719656722887, 0.13019514163689955, 0.08774278818496636, 0.1427516085760934, 0.1379579079470464, 0.11807684547134809, 0.17353195191494056, 0.12125217222741672, 0.1512147994445903, 0.09695304610899516, 0.09350173201944147, 0.08296579987342868, 0.10902239275830132, 0.17093407203044209, 0.13126831262239388, 0.12590739742985793, 0.12280764590416636, 0.21393941795187338, 0.19363906154675142, 0.1951013316533395, 0.17343019880354404, 0.10899538706455912, 0.14063954619424685, 0.17898326154266084, 0.0928279874580247, 0.1435417626053095, 0.10353615214782101, 0.0863779014242547, 0.11708702572754451, 0.19971376843750477, 0.14568655751645565, 0.16667440560247215], [0.02174938659715865, 0.047944585526628156, 0.08818728969033275, 0.07363327672438962, 0.03518686170822807, 0.01685416355862149, 0.017163750249892473, 0.03778418180133615, 0.03818263113498688, 0.12531758765024797, 0.057025691095207415, 0.0635856387338468, 0.019210573186033537, 0.04148917977831193, 0.06016356271824666, 0.015339266275987029, 0.02998185689960207, 0.08745492648865495, 0.008295600352409695, 0.02676501397841743, 0.06997452769428492, 0.026870190298983028, 0.023467120049255233, 0.0426504415726023, 0.0841335654258728, 0.043170365637966564, 0.034179125247257094, 0.03738294708143387, 0.09272237348237208, 0.09512218899492707, 0.03489028762227722, 0.06242581882647105, 0.02313230372965336, 0.03864083904772997, 0.23876276665500232, 0.23830475551741465, 1.5626268471990312, 24.24499900000436, 72.1233297075544, 73.32239423479352, 72.72966425759452, 55.91775778361729, 56.93769080298287, 31.834815093449183, 32.22034978866577, 23.9321893623897, 23.380120243344987, 65.58873653411865, 61.48360879080636, 32.88549736567906, 38.62111370904105, 37.85431398664202, 25.13144322804042, 4.6931068897247314, 0.07773671046431575, 0.12750876721526894, 0.016860760615340302, 0.15800845489970275, 0.09586825181863137, 0.2567157175924097, 0.15320848460708344, 0.41333875326173647, 1.0870302532400404, 1.5387443687234605, 2.0742515879017964, 19.962403842381068, 75.89322076525006, 114.2445046561105, 115.59351825714111, 114.17051328931535, 112.36635099138532, 113.04348073686872, 118.15528433663505, 126.36380277361188, 119.7838865007673, 108.1788523537772, 101.81763063158307, 83.0805138179234, 52.27490758895874, 18.817146165030344, 6.486634535448892, 16.983721528734478, 18.37619263785226, 16.132158994674683, 7.453270094735282, 3.003249841076987, 4.425009344305311, 4.157617909567697, 7.120618138994489, 3.3379248082637787, 1.9301292300224304, 2.6730957627296448, 2.524449041911534, 8.896813069071088, 33.65153278623308, 69.60425336020333, 106.58884743281773, 121.76601300920758, 130.05000277927942, 132.83870397295271, 135.98794719151087, 129.6915452139718, 131.4195760999407, 125.59340041024345, 119.97622653416225, 87.36489118848527, 45.96262550354004, 19.133431638990128, 3.2209996538502828, 3.904210593019213, 11.103752885546003, 4.570333523409707, 0.1711353390876736, 0.09390471396701676, 0.12153961323201656, 0.10204068810812064, 0.18735396808811597, 7.316469618252345, 29.201083047049387, 49.537154061453684, 46.2680926322937, 58.00101184844971, 73.53579425811768, 67.04070159367153, 30.421607085636683, 20.379281861441477, 18.226651770727976, 17.858303444726126, 46.5387909752982, 51.68110064097813, 61.73841312953404, 71.27711554936, 78.54115840366909, 59.46307264055525, 10.03260816846575, 0.6037535656775747, 0.054225746874830554, 0.029347755746649842, 0.06165279780647584, 0.028340022678353956, 0.07778124271758965, 0.06470865490181105, 0.052326405221330266, 0.04561748182667153, 0.04368582494290812, 0.06978879908898047, 0.03324927782107677, 0.04377217191670622, 0.07345448953232595, 0.007002847377277378, 0.0494152626820973, 0.023573875660076737, 0.022333237142967324, 0.023906449421441982, 0.05253600808126586, 0.010466995532624424, 0.13847770648343222, 0.01820660598709115, 0.026263206798051084, 0.04421444443453636, 0.04639600237299289, 0.03143835945853165, 0.021512684744915793, 0.07193815375545196, 0.02991744696295687, 0.0749221539923123, 0.03984871280512639, 0.06226525029965809, 0.03892833094245621, 0.10028013400733471, 0.03910534376544612, 0.030073079147509167, 0.023418989864044955, 0.06268451708768095, 0.028207542108637945, 0.01594569337820368, 0.03638913415904556, 0.034207915488098345, 0.05401934330750789, 0.02828091549287949, 0.09184934318597827, 0.05205440088840468, 0.04971492749505809, 0.07420992970998798, 0.036024652288428376, 0.05865274343107428, 0.04444754156949265, 0.04820452889959727, 0.06119435240647622, 0.031364891079387495, 0.04375250457919069, 0.027098259489451135, 0.00475954232803945, 0.0053708790552004105, 0.05241039089326348, 0.0633549029007554, 0.12028027937880584, 0.02816731176738228, 0.02221436289671276, 0.02119144082202443, 0.02603771604065384, 0.0552546366650079, 0.07135565179799284, 0.05865053140691348, 0.08376910391130618, 0.036035108513065746, 0.051555413021040816, 0.036992989613541534, 0.02958577565316643, 0.038678545238716264, 0.11832608495439802, 0.13089462981692382, 0.9694748755012239, 19.347978115081787, 76.28465448107038, 90.51041712079729, 89.72587517329625, 82.29953629629952, 83.96629796709333, 64.26216561453683, 52.98822355270386, 39.93965598515102, 39.479181494031636, 29.827577795301163, 43.99125133241926, 38.31581333705357, 39.480279309409006, 47.47656502042498, 32.266520568302695, 6.074895143508911, 0.14665460985686096, 0.1404375463191952, 0.03302811272442341, 0.09952259037111487, 0.29584322231156485, 0.41423406664814266, 0.12286320435149328, 0.4864377922245434, 1.324626835329192, 0.32484177340354237, 4.100972720554896, 27.501623153686523, 86.14928300040108, 122.00248800005231, 120.53351375034877, 118.68860026768276, 115.0811858858381, 116.23008441925049, 122.03446360996791, 130.11991555350167, 122.77069473266602, 117.58084896632603, 114.85031114305768, 96.01676028115409, 63.377472332545686, 27.00954130717686, 9.329101324081421, 1.592808953353337, 2.2216437246118272, 3.8258648770196095, 1.2705884150096347, 2.257910064288548, 2.7056819455964223, 4.343275078705378, 5.000245928764343, 2.227161245686667, 0.7309220475809914, 1.0538584675107683, 2.330364142145429, 14.48171864237104, 44.68730449676514, 83.13131209782192, 113.81498786381313, 131.30522264753068, 135.21983773367745, 138.73054013933455, 141.55435752868652, 136.60412733895438, 134.3536891937256, 130.18017033168246, 126.92831611633301, 100.77885409763881, 58.80499485560826, 24.435996294021606, 5.40537063564573, 2.4512000467096056, 10.715576137815203, 4.2943684458732605, 0.3914666926222188, 0.16695294422762735, 0.06453353179884808, 0.14977505670062133, 0.06530804559588432, 10.306976897375923, 36.20081990105765, 58.055350235530305, 46.16185120173863, 53.19835444859096, 43.49967670440674, 27.306576796940394, 26.469051361083984, 24.417029448917933, 37.893970830099924, 38.13168260029384, 76.9890489578247, 67.76614216395787, 73.55280344826835, 81.1075519834246, 91.82073620387486, 68.59847382136753, 8.576257058552333, 0.4350601519857134, 0.10548691997038466, 0.030765941433076347, 0.04919430114594953, 0.03185906134811895, 0.06571453556950603, 0.07000650704971381, 0.03177944544170584, 0.023027951829135418, 0.0857381107551711, 0.060994137078523636, 0.04632412176579237, 0.07076991322849478, 0.053474717174789736, 0.03160012899232762, 0.010676573795665587, 0.03321472681792719, 0.025540923234075308, 0.046762167010456324, 0.01014174401227917, 0.031997675874403546, 0.08504245629800217, 0.06833362645868744, 0.0464532266237906, 0.062253375936831744, 0.03898490719231112, 0.010403443942777812, 0.08591342384793929, 0.04845239095655935, 0.07809680899871246, 0.03541742451488972, 0.0178928615724934, 0.06108661461621523, 0.039073479760970385, 0.02938060023422752, 0.028652019865278686, 0.050196320949388404, 0.009873500459694436, 0.02860500756651163, 0.014382762601599097, 0.04976674721443227, 0.08149829826184682, 0.16785120245601448, 0.20412793728922093, 0.16750612668693066, 0.15909614653459617, 0.15413020657641546, 0.1649525687098503, 0.13627819450838224, 0.1636280683534486, 0.16063878232879297, 0.12943518241601332, 0.15503130108118057, 0.1707421009029661, 0.07515487114765815, 0.20546930602618627, 0.17682268390698092, 0.12432296387851238, 0.131028681195208, 0.23491180901016506, 0.1722304131835699, 0.2108397614210844, 0.20129653279270443, 0.118464750370809, 0.22278296841042383, 0.17182133799152716, 0.06992114734436784, 0.14681224711239338, 0.09707854794604437, 0.24170334743601934, 0.1591852381825447, 0.10785277480525629, 0.11058801731892995, 0.18599951719599112, 0.21647928309227737, 0.3299459580864225, 0.47841837682894295, 5.521485890660967, 46.981241839272634, 115.15740762438092, 104.49606391361782, 103.6956592287336, 78.22069358825684, 83.37480476924351, 46.082794598170686, 46.61735078266689, 44.2773642539978, 33.32951504843575, 104.58274269104004, 99.63493047441754, 56.30067648206438, 64.19076592581612, 67.23092242649624, 39.118431023189, 7.771256140300205, 0.5092896574309894, 0.17192155761378153, 0.2664958770786013, 0.5208765928234372, 0.1589695590415171, 0.5541584640741348, 1.1839692401034492, 2.1427178340298787, 6.409499543053763, 4.8168894818850925, 5.41714175258364, 24.470666067940847, 86.90764413561139, 127.32981082371303, 129.15740939549036, 127.0174754006522, 124.87160764421735, 124.04813494001115, 129.1190970284598, 136.84553555079867, 123.49284880501884, 116.53637490953717, 110.93558488573346, 93.80168151855469, 60.465246064322336, 24.734006268637522, 14.050853031022207, 34.223737784794395, 40.58402844837734, 36.114662238529746, 21.939039536884852, 13.628192373684474, 10.187283754348755, 10.898926070758275, 12.109643595559255, 10.221374222210475, 9.066010390009199, 10.81836952481951, 7.516465697969709, 11.4623407295772, 41.36390815462385, 79.2244998386928, 115.88283429827008, 132.96115902491977, 141.13418606349398, 147.89921624319894, 152.01645469665527, 147.250921521868, 146.82136998857771, 136.13784762791224, 132.25570842197962, 97.1255885532924, 53.85765164239066, 27.02113263947623, 11.36949108328138, 9.782430461474828, 14.585139104298182, 6.92205946786063, 0.327800131802048, 0.22010997469936097, 0.2318959922662803, 0.2791929229029587, 0.425689447671175, 13.477461627551488, 49.87612887791225, 87.72331401279995, 72.04922022138322, 83.12580217633928, 104.17955957140241, 95.2760545185634, 44.74095153808594, 31.793931892939977, 29.452649525233678, 28.3260303906032, 62.125615392412456, 66.3406844820295, 84.50167056492397, 86.18875571659633, 97.99154254368374, 93.10467992510114, 24.347191367830547, 0.5552821180650166, 0.14383579897029058, 0.07967232659991298, 0.18744676453726633, 0.08706656018538134, 0.13526539956884726, 0.18925842589565686, 0.2133852584021432, 0.26228217461279457, 0.13803853147796222, 0.1597597130707332, 0.11423474949385438, 0.11163328694445745, 0.15947228563683374, 0.08593739649014813, 0.08827584529561655, 0.13034216660474027, 0.09783080579446894, 0.12839667099927152, 0.2240555744085993, 0.13836468969072613, 0.22462531312235764, 0.11964271430458341, 0.17810493867312158, 0.11715943898473467, 0.10298507314707551, 0.09654775035700627, 0.20194001469228948, 0.18778349432562078, 0.20356807804533414, 0.0970430402085185, 0.11901992772306715, 0.1892415303736925, 0.1526324219469513, 0.2329820825585297, 0.12956586826060498, 0.13715168620858872, 0.06858275059078421, 0.19428276057754243, 0.07331130507269076, 0.10362249572894403], [0.04571886852915798, 0.03684403760624783, 0.0593873050862125, 0.019995880778878927, 0.1123696467173951, 0.0835367056674191, 0.02630746254830488, 0.01144028701154249, 0.0230557242674487, 0.026567024245326008, 0.029524534475058317, 0.038072776315467696, 0.030620941892266273, 0.02115002813349877, 0.02789620479701885, 0.12181356496044568, 0.06954848234142576, 0.01669272481064711, 0.056131303909101656, 0.028546643376882588, 0.0124290821674679, 0.02713238980088915, 0.04592360629300986, 0.013344933112551059, 0.020027042499610355, 0.019194513958479677, 0.05270865453141076, 0.07479944093418972, 0.01698323618620634, 0.05700095849377768, 0.0333176368315305, 0.045230313137705834, 0.05472128778429968, 0.07927704602479935, 0.5659850037523678, 18.492984907967703, 69.7949605669294, 87.95332717895508, 73.55233791896275, 71.90992273603166, 61.25829260689871, 54.6072997365679, 27.78625784601484, 31.334916523524694, 33.02306822368077, 63.978574889046804, 43.87749195098877, 37.6375857761928, 35.235972200121196, 32.28241457257952, 30.67491408756801, 7.523796916007996, 0.5670576319098473, 0.5288437338812011, 0.1194355304219893, 0.20003919383244856, 0.07670666037925652, 0.05328290211036801, 0.45960346928664614, 0.6726076081395149, 2.3689772358962466, 1.4829405631337846, 6.672962640013013, 35.4869897706168, 88.14627865382603, 114.59555544172014, 108.39587933676583, 94.59387343270438, 90.63579736437116, 92.27443272726876, 93.40295219421387, 89.21423762185233, 93.85436276027134, 94.34136894771031, 93.31113174983433, 97.97537408556256, 104.92385755266461, 108.44202927180699, 122.29500716073173, 119.69765935625348, 79.25829587663922, 6.78436484507152, 1.6690966997827803, 1.5789728100810732, 1.8256578530584062, 11.048429591315132, 51.94810949053083, 63.31732872554234, 64.2779380253383, 35.8502311706543, 13.721452832221985, 14.44882413319179, 64.51141139439174, 101.69293825966972, 118.24641690935407, 112.83215822492326, 101.71334511893136, 101.35396344321114, 103.3062196459089, 100.8321954182216, 96.50439180646623, 91.64421027047294, 92.805803162711, 92.15735558101109, 96.88135937282017, 108.51690305982316, 113.67018045697893, 94.49229771750313, 65.735426902771, 26.080836398260935, 2.5890264681407382, 0.9602085841553551, 0.5495096306715692, 0.28249852838260786, 0.10096444335899182, 0.055650575419089625, 0.07567874089415584, 0.20332905729966505, 1.4602480722325188, 14.336354511124746, 37.3975567817688, 40.842744622911724, 58.647319384983604, 66.52359580993652, 70.22478307996477, 75.08757019042969, 27.491324186325073, 25.112827266965592, 8.608895352908544, 32.402173723493306, 50.72763408933367, 64.13348497663225, 65.51063183375767, 72.9990667615618, 74.51497609274728, 28.597103936331614, 0.7277636027761868, 0.2004620704267706, 0.04239403675975544, 0.06376070076865809, 0.10084985236504249, 0.01092343925431903, 0.1371485920889037, 0.05120356207979577, 0.03837358445993491, 0.03205955148275409, 0.07162171216415507, 0.016352363163605332, 0.0575138766850744, 0.021783944385658418, 0.006990473867127938, 0.04675809240766934, 0.06262988823332957, 0.05269590485841036, 0.03637769066595605, 0.04400169995746442, 0.03111990601090448, 0.10035963117011956, 0.0326603263882654, 0.07229284436575004, 0.08948318979569844, 0.008697805377388639, 0.09497211740485259, 0.04313026421836444, 0.09417859105659382, 0.09980907464133841, 0.03992683593449848, 0.10562092385121755, 0.13246471913797514, 0.052794882761580605, 0.09286907953875405, 0.02196180198474654, 0.0828356161447508, 0.13576267074261392, 0.06909620482474566, 0.04774968312787158, 0.030672673402088027, 0.0216107517148235, 0.011093967827036977, 0.03361410913722856, 0.051136132662317584, 0.03791171245809112, 0.0053978707541578585, 0.06615296418645553, 0.04349328384601644, 0.042113557524446926, 0.023525981265785437, 0.045989400441093106, 0.005956053168379835, 0.09703895542770624, 0.07106525916606188, 0.03439187650967922, 0.0663583092391491, 0.05456972002450909, 0.07036345039627381, 0.03793663165665098, 0.0168201469017991, 0.016357391108093516, 0.06455334502139262, 0.022328655335253904, 0.041901155707559416, 0.036760794930160046, 0.04126205375151975, 0.017812461958133748, 0.055768952638443024, 0.0473444857634604, 0.014655591354572346, 0.04792394109868577, 0.07709180364119154, 0.06357370330286877, 0.3118721464914935, 11.539497869355337, 64.37038380759103, 100.20929636274064, 94.80164541516984, 90.25833647591728, 87.89063358306885, 85.10722691672188, 53.42010620662144, 29.02544822011675, 27.152505704334803, 29.270776953016007, 23.544413873127528, 41.23689161028181, 39.508002621786936, 43.337241717747276, 39.16249997275216, 11.198557581220355, 0.4917578867503575, 0.573832776929651, 0.06069347821176052, 0.1635159607976675, 0.3069585215832506, 0.15595253450529917, 0.7583598324230739, 0.17397438388850006, 1.0735821234328407, 1.18219983790602, 11.372574346406118, 43.701910972595215, 97.68894849504743, 118.52373341151646, 113.43834686279297, 97.9900347845895, 95.4524484361921, 96.62069075448173, 97.06058815547398, 95.86352470942906, 100.02401569911412, 99.4766435623169, 100.77182252066476, 102.94082777840751, 106.56256239754813, 112.90120247432164, 129.69457462855746, 127.75512395586286, 95.41950702667236, 13.442621622766767, 0.9192008588995252, 1.2116547716515405, 2.2711843805653706, 16.98704276766096, 62.1175137928554, 75.23222473689488, 77.16218417031425, 47.92746836798531, 20.127899510519846, 21.555624042238506, 81.43206759861538, 113.5959667478289, 120.62399319240025, 112.46542535509381, 103.63506398882184, 103.66139766148159, 104.00720950535366, 102.77386256626674, 100.56532205854143, 96.39306776864188, 98.23402772630963, 97.23887893131801, 100.95164884839738, 110.64179420471191, 118.10263088771275, 104.40673787253243, 77.37362480163574, 33.59471736635481, 4.335889143603189, 2.2471978962421417, 0.2222075435732092, 0.2479080616363457, 0.1597629836095231, 0.030178455635905266, 0.017516786931082606, 0.41126387459891184, 1.6417953819036484, 16.754613365445817, 45.547352518354145, 45.51621069226946, 55.98004838398525, 53.78059612001692, 38.95137895856585, 47.17054550988333, 23.388016871043614, 17.028544357844762, 15.444527047021047, 41.93053374971662, 59.79840660095215, 75.40029471261161, 76.76801981244768, 83.16598360879081, 83.48091765812465, 29.252287796565465, 0.439966014453343, 0.07658599649689027, 0.028338653733953834, 0.13660094647535256, 0.045248803216964006, 0.044603909964540174, 0.0560251030006579, 0.006999281675754381, 0.029011673959238187, 0.07605439823653017, 0.054509598429181745, 0.018372438249311278, 0.021898311463051608, 0.08681414515844413, 0.028011123184114695, 0.09710611682385206, 0.029102729966065714, 0.047991482474442036, 0.021603694950629557, 0.05674607359937259, 0.0250077202383961, 0.06857317646167108, 0.03780454463724579, 0.10815920800502811, 0.1197642127850226, 0.006735242919863335, 0.04217062571219035, 0.04891792365482875, 0.05281849578022957, 0.05442338376971228, 0.08469668163784913, 0.14197624661028385, 0.1198007043983255, 0.0730453057746802, 0.04982202746240156, 0.02516409881146891, 0.04440692785595145, 0.10179826111665793, 0.08715548898492541, 0.03746252906109605, 0.09636992668466908, 0.11361221397029501, 0.21003271186990397, 0.15940669844193117, 0.21163619868457317, 0.13904121624571936, 0.08243100571313075, 0.1727181984377759, 0.07756268658808299, 0.14730461926332541, 0.08027204977614538, 0.10897427784012896, 0.10364678728261165, 0.17855919072670595, 0.18398939791534627, 0.24006058701447078, 0.24920528488499777, 0.11010637959199292, 0.23854389839938708, 0.10163138221417155, 0.13056976082069532, 0.1107289083302021, 0.07683100870677403, 0.10631524837974991, 0.11221414684717144, 0.1273016104740756, 0.12814033403992653, 0.20552086111690315, 0.14008435527128832, 0.18473498576453753, 0.09310352017304727, 0.14435224554368428, 0.11944739121411528, 0.1160485821643046, 0.539545262498515, 38.27792133603777, 104.35308388301304, 128.88201059613908, 100.35653563908168, 100.50621373312813, 85.30629280635289, 74.25087506430489, 41.58986357280186, 52.599954741341726, 53.21770518166678, 88.6426579611642, 69.26124858856201, 57.592958041599815, 50.46104907989502, 53.591674600328716, 47.59790488651821, 12.346075160162789, 1.6905039910759245, 0.6993581184319088, 0.2514148663197245, 0.2588124450828348, 0.2702373191714287, 0.1330086870917252, 1.8030200792210442, 4.831349985940116, 8.549923385892596, 5.987217562539237, 11.502655914851598, 41.78179713657924, 100.53757790156773, 127.87285423278809, 122.94622012547084, 104.11970778873989, 99.91966070447648, 101.15771852220807, 101.46059744698661, 99.60762405395508, 105.99039213997978, 104.9443894795009, 104.58680043901715, 107.51035227094377, 116.87042345319475, 121.13985524858747, 138.20187950134277, 138.46028300694056, 95.35243606567383, 11.893830810274396, 7.919743486813136, 10.129595467022487, 5.551834319319044, 18.3557962008885, 71.51354885101318, 79.0364190510341, 84.9853902544294, 57.14090476717268, 21.130540200642177, 19.407772575105938, 82.00201443263462, 123.0892140524728, 132.16336686270577, 115.23715209960938, 106.54346874782017, 108.35680266789028, 109.68442971365792, 105.70296600886753, 106.41883196149553, 98.79544912065778, 104.24444184984479, 105.12853063855852, 110.35016441345215, 121.21286691938127, 132.02757126944405, 104.97025762285504, 74.72705595833915, 31.87120280947004, 7.037905045918055, 6.104652975286756, 0.9763196110725403, 0.6276928782463074, 0.2627595104277134, 0.1693574552025114, 0.17929822392761707, 0.3871383991624628, 2.4768037242548804, 20.533462388174875, 60.45269761766706, 63.11428846631731, 90.24101461683, 101.37341145106724, 100.2551405770438, 109.47982610974992, 40.756892681121826, 40.88721309389387, 15.167693444660731, 45.28968552180699, 63.72403458186558, 86.37648909432548, 84.69042532784599, 89.78589371272496, 100.6754857472011, 52.54668985094343, 1.9752586483955383, 0.5028326639107296, 0.13382522256246634, 0.32621653963412556, 0.19340907888753073, 0.17217778600752354, 0.17811199543731554, 0.17178799478071077, 0.05993927975318261, 0.19591093249619007, 0.1261374886546816, 0.11130470636167697, 0.09869167674332857, 0.2147562519780227, 0.16968193064842904, 0.15442470434520925, 0.2106832776750837, 0.16333685469414505, 0.16194161027669907, 0.13974200721297944, 0.21291001247508184, 0.2088329398206302, 0.06535751758409397, 0.20475330230380806, 0.284675377288035, 0.10970795739974294, 0.1477116724210126, 0.1704815841679062, 0.15288603119552135, 0.18375139497220516, 0.1533387904720647, 0.2655628100037575, 0.17679977656475135, 0.16408873934830936, 0.1354876604995557, 0.09023559013647692, 0.19943886676004954, 0.18394160190863268, 0.15827387065759727, 0.07462883008910076], [0.06244454639298575, 0.13247492430465563, 0.09757744760385581, 0.04714767328862633, 0.09924852329173259, 0.04183545994705387, 0.05790409538894892, 0.007341011843111898, 0.0347366265819541, 0.03901986192379679, 0.12716563205633843, 0.024948779294001203, 0.015984702356425778, 0.049464161308216195, 0.028304952595915114, 0.0892005121069295, 0.07106237539223262, 0.08975598122924566, 0.04804804176092148, 0.006315029151405075, 0.0915503738714116, 0.23560679171766552, 0.3115999453834125, 0.05888769296663148, 0.13917728965835913, 0.11353011123303856, 0.12370754618729864, 0.09875232420329537, 0.04102342655616147, 0.2075084801763296, 0.05253825063950249, 0.050335189926304987, 0.08195034507662058, 0.24000999544348034, 32.85799292155674, 97.19732870374406, 85.55196026393345, 75.45761040278843, 66.98846503666469, 65.52912099020821, 43.188060419900076, 27.30970696040562, 54.57980918884277, 77.2125586100987, 75.14222472054618, 51.70036104747227, 35.56114789417812, 26.550934144428798, 29.595841475895472, 17.515449796404155, 1.5228167091097151, 0.5473014063068798, 0.32474846126777784, 0.02357421492758606, 0.09894956754786627, 0.12668640991406782, 0.37002639738576754, 0.25542639249137467, 1.2670242062636783, 1.2024286495787757, 13.85125126157488, 65.67979962485177, 110.34272289276123, 123.34788158961705, 106.34057440076555, 92.79602009909493, 89.91587366376604, 92.39742279052734, 89.97875486101422, 86.17485931941441, 89.04836327689034, 87.21813828604562, 101.359299659729, 106.89912618909563, 108.87339428492955, 103.75979110172817, 98.8576910836356, 86.27417687007359, 85.42631598881313, 84.600175176348, 109.41191441672188, 81.5297384262085, 17.07848106111799, 22.214848279953003, 50.353296416146414, 102.69793960026333, 102.82268060956682, 112.97019808632987, 102.77018696921212, 113.41277749197823, 84.66598156520298, 95.23396233149937, 103.50049127851213, 94.09866837092808, 99.25930391039167, 99.3614285332816, 102.0631799697876, 101.7275333404541, 106.65011664799282, 106.96473802839006, 103.22268840244838, 97.53803362165178, 94.54722322736467, 97.92313058035714, 97.77277156284877, 96.94271891457694, 96.21723665509904, 99.19737461635044, 102.36348806108747, 109.01203169141496, 97.53899942125592, 32.68738685335432, 4.044341862201691, 0.5233809841530663, 0.38731202270303455, 0.5517868484769548, 0.331697908363172, 0.07181930834693567, 0.11976373781050954, 0.14270468109420367, 4.259220114776066, 29.061267920902797, 36.688649450029644, 46.91090522493635, 64.75939260210309, 57.800358295440674, 73.80967140197754, 68.58471638815743, 124.05989129202706, 48.1413825580052, 25.560708148138865, 44.21712684631348, 59.111549377441406, 67.01231125422886, 71.86960233960832, 78.19203921726772, 52.473855359213694, 3.0979527022157396, 0.12857726987983498, 0.08687667216041259, 0.10889236509267773, 0.08769471397889511, 0.12803360048149312, 0.09214399701782636, 0.029890831426850388, 0.014186455635353923, 0.00892427152887519, 0.044847300475729365, 0.09190228927348341, 0.15728828497231007, 0.11428372615150043, 0.09051797605518784, 0.37196722467030796, 0.08988516072609595, 0.09813673009297677, 0.0925443869616304, 0.13788359479180404, 0.1047666889748403, 0.08682983288807528, 0.07671366964599916, 0.06464499474636146, 0.06829240545630455, 0.031031180771866014, 0.07834406715950795, 0.06704989248620612, 0.22809920885733195, 0.21149058506957122, 0.42056553118995255, 0.2094994919108493, 0.14813350407140596, 0.0944372961031539, 0.17597266951841967, 0.3154132036226136, 0.2862078621983528, 0.2765741305691855, 0.043097355269959996, 0.09324639250657388, 0.10870272134031568, 0.08931995462626219, 0.11502684413322381, 0.18975283365164483, 0.08810150929327522, 0.11737027338572911, 0.019862236521605934, 0.016563455407906855, 0.19667181452470167, 0.06477980608386652, 0.044692526637975655, 0.06093171864215817, 0.02789154156510319, 0.056385313493332694, 0.11323975931320872, 0.08216803946665355, 0.1577145949538265, 0.06537885072508029, 0.005888052509232823, 0.055008939134755304, 0.15219954374645436, 0.394149050116539, 0.1298481523990631, 0.056367298388587575, 0.1154471015823739, 0.18979897403291293, 0.11304516904056072, 0.06869728051658187, 0.11959343909152917, 0.11271878012589046, 0.06835797229515654, 0.12318497922803674, 0.3425126437629972, 27.143387930733816, 107.05868462153843, 100.9092926297869, 93.94764927455357, 84.86151776994977, 86.93045507158551, 70.63196836199079, 45.24384478160313, 32.50937400545393, 35.10209083557129, 40.69446659088135, 50.36428151811872, 45.0065290587289, 31.865717206682476, 40.152281284332275, 22.65844907079424, 2.516657505716596, 1.0248614634786333, 0.2863276371998446, 0.03954838642052241, 0.39763522733535084, 0.20782224833965302, 0.7144804384027208, 0.08956778275647334, 0.48730007452624186, 2.537026149885995, 20.67114094325474, 75.01937362125942, 120.91091210501534, 127.40514319283622, 112.04225226811, 97.40127917698452, 95.68634564535958, 97.48456028529576, 94.95550632476807, 90.72048200879777, 95.45788192749023, 92.03565093449184, 105.33127907344273, 111.52352060590471, 114.25149454389299, 107.77216039385114, 107.08503219059536, 91.86801869528634, 90.277145249503, 87.78459017617362, 111.96761471884591, 89.5226195199149, 23.245048999786377, 32.07981552396502, 60.60858045305525, 117.46209035600934, 113.00036021641323, 121.04911177498954, 108.72738483973912, 125.68392154148647, 98.49971294403076, 104.61314105987549, 104.93828201293945, 94.30404322487968, 101.18505273546491, 100.25215979984829, 106.96782302856445, 107.19988591330392, 112.5582046508789, 111.06110409327916, 108.7842766898019, 103.0616569519043, 99.06109959738595, 101.35683304922921, 104.35996259961809, 103.03693526131767, 102.78495189121791, 103.43644278390067, 107.87047740391323, 117.53977121625627, 112.64784336090088, 44.2742896761213, 7.000969724995749, 0.780098520219326, 0.13290609259690556, 0.41365353922758785, 0.2772519870528153, 0.04705253250098654, 0.131848595770342, 0.33814274253589766, 5.487803195204053, 36.239483152117046, 42.81454610824585, 44.00891365323748, 57.99789558138166, 49.4619710786002, 37.36449030467442, 36.0137848172869, 54.2644339288984, 43.97365154538836, 46.18968221119472, 60.80627754756382, 72.4011812210083, 75.81476865495954, 79.7617415019444, 89.06873539515904, 55.114361899239675, 2.3881347221987586, 0.07045687788299151, 0.07221172550427062, 0.14976103816713604, 0.08010249744568552, 0.24611474786485943, 0.056303712871990035, 0.049267939158848355, 0.04106533966426339, 0.06071221934897559, 0.032566590168114216, 0.15175248416406767, 0.1553737712757928, 0.12271426591489996, 0.1345907321998051, 0.22526232179786476, 0.16739012434014253, 0.10181740937488419, 0.04187936455543552, 0.06183670115258012, 0.08583802503666707, 0.20388454677803175, 0.09562616409467799, 0.03258624732760446, 0.009768274945339986, 0.05974057077297142, 0.09691887508545603, 0.040028086929981194, 0.14694445287542685, 0.18541335793478148, 0.2591042151408536, 0.26413897212062565, 0.1682919380920274, 0.10098688929740872, 0.24101615431053297, 0.22226445909057344, 0.2246137373149395, 0.18928859356258596, 0.04905407509899565, 0.1766575149127415, 0.23140956408211164, 0.22507507327411855, 0.26511763674872263, 0.30909522835697445, 0.21191236243716308, 0.18640524042504175, 0.11628832215709345, 0.10436510480940342, 0.24571139950837406, 0.1870824455150536, 0.14889936654695443, 0.12320771015116147, 0.17354504764080048, 0.2666128565158163, 0.38626127051455633, 0.1800583459969078, 0.20343991635101183, 0.1251154520681926, 0.08907208578394991, 0.28099690324493815, 0.37413956810321125, 0.6195918758000646, 0.31853096346770016, 0.26156743296555107, 0.1795545473162617, 0.40688072836824823, 0.2102434512759958, 0.1717130709439516, 0.3953549696930817, 0.2591176229928221, 0.25843113554375513, 0.29561838294778553, 0.5936762892774173, 65.92687061854771, 134.80882399422782, 110.12896156311035, 99.54912717001778, 98.08583654676164, 86.23500987461635, 63.49350030081612, 39.5208602632795, 81.76737376621791, 110.5521902356829, 114.78177411215646, 77.57601193019322, 56.28757217952183, 44.49934530258179, 54.8607873916626, 28.888457536697388, 4.002751248223441, 1.1487398105008262, 0.5004632196256092, 0.16132839103894575, 0.3078272363969258, 0.25918783779655186, 0.8693657730306897, 1.5749817213841846, 6.012538535254342, 6.649763473442622, 18.46049860545567, 73.83170413970947, 126.10867881774902, 138.4471092224121, 120.51287760053361, 101.49793706621442, 99.08128411429269, 103.06592314583915, 100.5688725880214, 96.47335420336042, 102.91950375693185, 97.61681924547467, 111.95439229692731, 116.68247468130929, 118.20500564575195, 113.90306322915214, 111.52263818468366, 94.63825852530343, 92.33626474652971, 90.5527594430106, 116.16257572174072, 95.69564928327287, 25.84542795589992, 29.500064032418386, 71.25614588601249, 125.67887714930943, 112.51541764395577, 120.22797366550991, 109.92513615744454, 129.39616339547294, 119.19166374206543, 115.515059198652, 112.08540752955845, 96.93064989362443, 99.86322743552071, 100.55141871316093, 111.04237174987793, 110.75697449275425, 118.04315430777413, 118.74809074401855, 114.5175758089338, 108.52790900639125, 106.19922719682965, 106.00660228729248, 108.75732462746757, 108.15769508906773, 105.7637071609497, 108.77470902034214, 115.64784622192383, 121.26811899457658, 108.48372541155133, 34.83268485750471, 6.053867288998195, 1.7253608235291071, 0.8746083517159734, 0.9869368927819389, 0.5388275352971894, 0.2651052331285817, 0.22146742471626826, 0.352573635322707, 8.580096806798663, 48.71934066499983, 56.261137757982524, 64.80668898991176, 95.38861533573696, 87.2468204498291, 113.61751311165946, 91.27442714146206, 145.18206759861536, 66.55345916748047, 40.65623760223389, 57.726370402744834, 79.75527272905622, 87.38778550284249, 89.49738366263253, 98.56359468187604, 84.94536168234688, 8.641639607293264, 0.6495434971792358, 0.16609888577035495, 0.3336109428533486, 0.1420124260974782, 0.42157690120594843, 0.172031059595091, 0.1012832937496049, 0.13879425664033207, 0.12164028068738324, 0.15905485089336122, 0.28708309094820705, 0.27040309884718483, 0.32089829072356224, 0.20724078454077244, 0.443960251552718, 0.3063841552606651, 0.18065582322222845, 0.18564798177352973, 0.20318267015474184, 0.29322632987584385, 0.3130693808197975, 0.15871567837893963, 0.18464776687324047, 0.1916639275316681, 0.20578734896012715, 0.15816940340612615, 0.25268652236887384, 0.20998054609767028, 0.29103547600763185, 0.35879186594060486, 0.4692646680133683, 0.20380779089672224, 0.2520185724965164, 0.2798168222819056, 0.3432937189936638, 0.37189529995833126, 0.3286627126591546, 0.08593127610427992], [0.08623457447226558, 0.020123994975749935, 0.03775901493749448, 0.07143075883920703, 0.08633197138884238, 0.09722840919026307, 0.11410646566322871, 0.13699555530079774, 0.09490441318069186, 0.08487901756806032, 0.0079138149906482, 0.008895949477196803, 0.08220292973731246, 0.01738595180878682, 0.013908892404288054, 0.12926828994282655, 0.03585069287302239, 0.042925784297819645, 0.05672646393733365, 0.0639738557594163, 0.08908226380922965, 0.1527986494558198, 0.17766220814415387, 0.18061824595289572, 0.036060977660651715, 0.14272016526332923, 0.13144638735268796, 0.1059303426050714, 0.11388605034777097, 0.05250748246908188, 0.08396123788718667, 0.04835992698956813, 0.3570765565548624, 43.86872679846627, 102.41206986563546, 92.39297594342912, 89.70119517190116, 79.51034178052629, 77.86653695787702, 37.380068165915354, 37.407826219286235, 66.98790918077741, 71.98794405800956, 53.45304414204189, 47.519973891122, 34.51888683864048, 26.072083405085973, 31.64389249256679, 5.986405057566507, 0.04330453236720391, 0.4892215228506497, 0.03750037095908608, 0.17856229841709137, 0.17637375156794274, 0.08712971822491714, 0.5629108601382801, 1.2477459950106484, 0.9513808978455407, 15.832582201276507, 81.60865606580461, 123.68727329799107, 116.50149495261056, 99.99081025804792, 89.5203127179827, 88.11253125326974, 91.50153596060616, 83.36447279793876, 76.62544972555978, 74.25810813903809, 84.63684776851109, 78.45180456978935, 74.86745820726667, 84.29281466347831, 91.80119092123849, 89.35948276519775, 87.07643672398159, 83.6351398740496, 83.789320400783, 89.25596850258964, 99.69489342825753, 90.41302422114781, 97.73340306963239, 50.461403438023154, 71.66103131430489, 70.6960585457938, 101.21556922367641, 75.77773475646973, 76.73207678113664, 67.26787989480155, 87.61217062813895, 80.45683234078544, 63.13740512302944, 84.96266964503697, 97.97009345463344, 102.8337629863194, 98.11656842912946, 97.66655445098877, 98.62022944859096, 98.62302957262311, 97.81703158787319, 96.98235838753837, 88.96428312574113, 91.35719408307756, 87.13155678340367, 87.26294721875871, 91.02282592228481, 101.17324079786027, 102.06441674913678, 93.56795106615338, 91.27326679229736, 102.03018992287772, 124.59577805655343, 99.30430739266532, 41.41560622623989, 4.968340235097068, 0.4712847481880869, 0.19014315413577215, 0.3988137612385409, 0.09011674472796065, 0.15640811648752007, 0.06278339321059839, 0.5488516145518848, 13.008718780108861, 35.65396540505545, 40.944403716496055, 44.17662579672677, 53.566695826394216, 55.04475137165615, 144.63523047310966, 87.96746676308769, 15.535072496959142, 19.89299307550703, 37.21178279604231, 61.27164009639195, 59.75581414358956, 75.32015419006348, 79.31732777186802, 63.06578309195382, 3.8005478126662116, 0.15174105763435364, 0.10975390100585562, 0.33929294081670897, 0.13117721251079015, 0.0663567961060575, 0.05339262800823365, 0.0641671907422798, 0.04325972191457238, 0.024870099765913825, 0.11200661691171782, 0.0931529039517045, 0.17472477576562337, 0.15043220429548196, 0.07167188304343394, 0.07669787335076503, 0.02306374455136912, 0.04830710303836635, 0.08965209073254041, 0.10130957341087715, 0.013899791553350431, 0.06532614891018186, 0.007787313162615257, 0.057341121669326506, 0.048086874320038726, 0.18767171246664865, 0.17802333805177892, 0.22347210214606353, 0.13953263844762528, 0.10736724228731223, 0.08518929127603769, 0.022813293883310895, 0.2606381656868117, 0.19646336856697286, 0.21724290640226432, 0.1502399481832981, 0.1769817325153521, 0.01995655119286052, 0.051290923463446755, 0.04030995376940284, 0.04594270366110972, 0.033482887249972136, 0.09241216762789659, 0.043950545202408514, 0.08221894994910274, 0.08185332813965422, 0.04759324687932219, 0.09388758774314608, 0.04425947880372405, 0.00875601774480726, 0.0669470876455307, 0.02474973104628069, 0.030632066473897015, 0.02353183871933392, 0.08085135583366666, 0.11266131499516112, 0.02073037458051528, 0.09631197300872632, 0.09703535240675722, 0.0667154968583158, 0.0870754150673747, 0.16956512763031892, 0.11015688973878111, 0.14350409034107411, 0.08280145869191204, 0.034124761021562984, 0.05399263956184898, 0.032913280850542445, 0.07637321470039231, 0.09805235426340785, 0.10997956139700753, 39.935174397059846, 117.53611646379743, 102.53762381417411, 105.13728536878313, 93.11132935115269, 101.21677126203264, 63.040408270699636, 35.5281891141619, 20.917727300098964, 55.570399965558735, 49.39575822012765, 48.72271401541573, 39.03571619306292, 31.56176131112235, 41.76349210739136, 8.19443964958191, 0.19330567015068872, 0.6248880858932222, 0.022106852415683012, 0.4179939648934773, 0.6262909163321767, 0.8083092378718513, 0.4702116314853941, 0.8476363675934928, 2.0024773478507996, 22.404457671301707, 91.12262984684536, 128.94892174857003, 120.20201519557408, 105.38813618251255, 96.66844572339738, 94.19328893933977, 96.67250347137451, 88.104950768607, 82.11168479919434, 78.3926476069859, 90.51343958718437, 82.06196349007743, 79.81596524374825, 86.51270157950265, 94.95451968056815, 94.52034759521484, 91.51614107404436, 87.05887167794364, 91.58264228275844, 94.48392513820103, 105.23786054338727, 96.776962688991, 102.83278329031808, 59.286025592258994, 76.94444152287075, 84.40388856615338, 106.46091720036098, 78.78741645812988, 81.68987355913434, 73.42619337354387, 92.53123814719063, 90.32509476797921, 68.87787478310722, 90.89076845986503, 101.0630910055978, 104.55340044839042, 100.2167865208217, 99.70381491524833, 100.46169662475586, 102.53481674194336, 100.22035789489746, 102.28871154785156, 93.8464001246861, 96.00273186819894, 91.86995724269322, 92.8423993246896, 95.81035709381104, 106.75921726226807, 105.82253061022077, 100.21167264665876, 94.11359310150146, 103.88415690830776, 129.1703052520752, 113.24296351841518, 53.28883389064244, 8.577557240213666, 0.09369282105139323, 0.3042124089385782, 0.25366790113704546, 0.08148770633020572, 0.13113530618803843, 0.1325561585170882, 0.3576478287577629, 17.02067378589085, 44.19352034160069, 43.64518240519932, 40.943649836948936, 51.77154881613595, 57.613927704947336, 154.0258181435721, 97.97968196868896, 28.724518265042985, 36.41401842662266, 53.38080372129168, 73.98560673849923, 71.34571511404855, 83.96772234780448, 91.78753076280866, 69.63820920671735, 3.7097101041248868, 0.06696139794907399, 0.11891011361564909, 0.2779874104474272, 0.13783725085003035, 0.03974825908829059, 0.049870434150631936, 0.07476128691009112, 0.021103689280737723, 0.03170403984508344, 0.08735932768987757, 0.08228760412228958, 0.10604282335511275, 0.160469881391951, 0.07714582859937634, 0.03804736178634422, 0.03858613894720163, 0.04544535445581589, 0.12050651652472359, 0.12629575016243116, 0.0739978128778083, 0.023731529878984605, 0.012833452567325106, 0.057269570151610036, 0.04600370056661112, 0.21460928129298346, 0.1399108674377203, 0.07690990875874247, 0.08273929131350347, 0.048755295774234195, 0.06527013584439244, 0.03818443264546139, 0.20638303485299858, 0.14392723834940366, 0.1810240913182497, 0.09599458146840334, 0.12693189031311444, 0.039582364061581235, 0.1985810220773731, 0.1654971744865179, 0.08446437160351447, 0.15029284677335195, 0.21986661132957253, 0.13505972203399452, 0.33387426872338566, 0.2119219433516264, 0.20404744946530887, 0.2800278195313045, 0.0911038164049387, 0.11977538147142955, 0.1831361944121974, 0.0799480357340404, 0.1221477027450289, 0.17718648724257946, 0.16671669190483435, 0.265382319688797, 0.14381198239113602, 0.18417215453726904, 0.16541009130222456, 0.248417288597141, 0.2328242553131921, 0.34443615483386175, 0.17725020168083055, 0.32287437468767166, 0.3286054443035807, 0.20898001907127245, 0.2093565110117197, 0.1558582724205085, 0.12307222027863775, 0.14988497937364237, 1.5650587167058672, 78.96238599504743, 133.761563709804, 110.27620083945138, 116.45836053575788, 109.16025066375732, 97.2828540802002, 52.12687274387905, 51.88382475716727, 102.39064162118095, 106.87598868778774, 73.65884685516357, 72.92647893088204, 53.9526925768171, 44.304153033665244, 54.2927165712629, 9.77426198550633, 0.712298758327961, 1.0933479028088706, 0.19658583056713852, 0.6975490355065891, 0.369961502296584, 0.5462040251919201, 1.6783146794353212, 5.880939219679151, 5.2983987757137845, 20.186729907989502, 90.37864453451974, 132.71798597063338, 127.0943363734654, 111.600159236363, 100.82032094682965, 96.40999358040946, 103.39700480869838, 95.2703778403146, 86.89758314405168, 80.52960082462856, 95.818986756461, 85.88475118364606, 83.32809897831508, 93.22994204929897, 101.53646482740129, 100.37431607927594, 98.76820523398263, 96.00326687949044, 96.4415592466082, 100.37849194662911, 109.50074018750871, 99.24576881953648, 102.57515103476388, 69.8632961000715, 96.01789283752441, 99.52143165043422, 110.55106462751115, 88.19781344277519, 86.78667599814278, 81.39598560333252, 98.38597093309674, 97.02743135179792, 75.67704841068813, 93.87139974321637, 105.71629960196358, 109.66694109780448, 102.93101692199707, 105.23535224369594, 106.13487992967877, 106.9403498513358, 105.62942627498082, 106.61805765969413, 97.9028626850673, 99.26901054382324, 98.15859808240617, 99.30899047851562, 103.7481667654855, 113.34856224060059, 111.61705030713762, 103.32395144871303, 98.02798584529332, 114.12601702553886, 139.58505739484514, 113.9573564529419, 49.9195099558149, 7.5387303318296155, 1.1539820092064994, 0.4262212834187916, 0.6602906233498028, 0.38848360840763363, 0.2445510503436838, 0.24856531779680932, 1.008537539413997, 24.721834761755808, 60.088014466421946, 58.327438218253, 65.65798228127616, 83.27944769178117, 66.63363443102155, 155.96756172180176, 103.27038083757672, 24.945889847619192, 32.902534348624094, 49.97424439021519, 80.15855312347412, 76.6770053591047, 95.09134360722133, 93.78902190072196, 93.65514401027134, 12.927884306226458, 0.7766441798635891, 0.25411942547985483, 0.47694183034556253, 0.27395482254879816, 0.22241517528891563, 0.10739787135805402, 0.1567572634667158, 0.12266944189156805, 0.18560360558331013, 0.2230092462684427, 0.3702189656240599, 0.18370663880237512, 0.28025225177407265, 0.22885487973690033, 0.20305574339415344, 0.1116861312517098, 0.10065967935536589, 0.1553661852542843, 0.203396842948028, 0.18009190633893013, 0.19867684479270661, 0.07230005719299827, 0.14539045840501785, 0.17954327006425175, 0.27894145782504765, 0.18483251838811807, 0.2370846409882818, 0.15693873087210314, 0.13903467516813958, 0.12820293568074703, 0.17150634846517018, 0.2630904998098101, 0.19947100217853272, 0.3282205792410033, 0.19386802640344414, 0.2603219955095223, 0.21638363679604872], [0.05307029334029981, 0.09369533163096223, 0.05487646535038948, 0.08512253700090305, 0.03395167691633105, 0.08773520894880805, 0.048183399319116554, 0.0570364933727043, 0.14322328540895665, 0.030960921863360063, 0.013340868687789356, 0.03439945574583752, 0.0736509118495243, 0.035313310101628304, 0.07677090407482215, 0.11763301571565014, 0.08439754947487797, 0.034704114576535564, 0.0635150032384055, 0.03346884157508612, 0.1036869158436145, 0.1323974220348256, 0.14982353124235356, 0.09802235623023339, 0.03692471881264022, 0.10734172937061105, 0.05628963666302817, 0.03886093545172896, 0.020204983219238262, 0.09387168288230896, 0.10233524015971593, 0.8372947882328714, 49.709886278424946, 106.09353814806256, 89.33867291041783, 88.95502117701939, 63.21112551007952, 45.504457814352854, 27.857343128749303, 20.310741356440953, 59.49244267599923, 63.031000409807476, 44.85759789603097, 30.756989683423722, 30.437032086508616, 32.13845484597342, 15.27207623209272, 1.4593857356480189, 0.5545856154390744, 0.041061461836631806, 0.07671800548476831, 0.15779174438544682, 0.09090923970299107, 0.15651129452245577, 1.1873472588402885, 1.3981347594942366, 9.914705923625402, 64.83311993735177, 123.0896726335798, 109.57447447095598, 89.89049884251186, 86.22476128169468, 89.48124994550432, 93.77929442269462, 89.43216092245919, 84.78396892547607, 85.33844906943185, 81.25546523502895, 73.59263052259172, 82.86848953792027, 80.01477405003139, 77.53945745740617, 76.21234457833427, 79.55336502620152, 79.3838289805821, 80.74565505981445, 85.09383078983852, 97.83256775992257, 91.3226545878819, 96.578202520098, 92.7283376966204, 105.38240391867501, 77.38776438576835, 35.71721485682896, 84.64648491995675, 91.56586933135986, 83.34795692988804, 88.94353580474854, 75.63568578447614, 96.2013669695173, 66.9500345502581, 84.15264170510429, 103.73566000802177, 85.33084079197475, 96.41413470676967, 94.94759927477155, 100.79206262316022, 94.0253301348005, 95.95333017621721, 99.04119300842285, 101.82963017054966, 100.0257874897548, 103.30134201049805, 97.76325947897774, 90.05921500069755, 84.67873150961739, 88.5013871874128, 92.08646311078752, 95.61837141854423, 93.15622166224888, 95.53306143624442, 85.66084548405239, 97.68092332567487, 114.32105990818569, 105.4658031463623, 46.71841580527169, 6.539437804903303, 0.4282067854489599, 0.12861848409686769, 0.035769740252622535, 0.030540762801787684, 0.2106672235365425, 0.09135849095348801, 5.040741332939692, 27.528860092163086, 36.00520726612636, 41.078417096819194, 35.192125592912944, 42.3821701322283, 49.46036951882498, 49.0694534437997, 40.516238348824636, 21.32733576638358, 31.643159457615443, 49.16896554401943, 66.76099491119385, 69.51500374930245, 75.79107529776437, 64.16148621695382, 2.537213316985539, 0.47618094831705093, 0.23647227670465196, 0.1653551028243133, 0.03163003881594964, 0.01845115000781204, 0.032896402291953564, 0.01607324948002185, 0.03507928676637156, 0.07030177834842886, 0.07150024761046682, 0.028912936935999563, 0.028488387752856528, 0.10261529191796269, 0.05870806439114468, 0.06395876514060156, 0.032553457122828276, 0.08325649106076785, 0.09283492887126547, 0.13565008821231977, 0.01604420648488615, 0.04841490189677902, 0.023164118540340235, 0.04762289207428694, 0.16305332205125264, 0.20487098741744245, 0.15525361629469053, 0.14064238247062477, 0.3043825312384537, 0.07905960269272327, 0.11674467766923563, 0.16560599793280872, 0.11954466599438872, 0.13475803179400309, 0.15873106755316257, 0.057713569541062625, 0.04833382374740072, 0.10822212855730738, 0.06729823630303144, 0.0556550028600863, 0.03445922450295516, 0.1301475084785904, 0.06667677286480155, 0.08391522642757211, 0.0633582209369966, 0.023801631028098718, 0.06061831010239465, 0.06531416598175253, 0.02802940970286727, 0.04921764614326613, 0.026674957114404867, 0.0687831151964409, 0.11228620048080172, 0.08332570163266999, 0.03477549306782229, 0.009330166088018035, 0.006942336472483086, 0.08407876693776675, 0.11316831636109523, 0.14010940678417683, 0.15467074114297116, 0.048601912933268716, 0.08530825203550713, 0.07499506936541625, 0.045291191299578974, 0.051573835246797116, 0.05001977292288627, 0.01843926716329796, 0.4541760305208819, 48.08162457602364, 120.72029522487095, 102.92712593078613, 108.02038478851318, 88.92187132154191, 74.63397094181606, 54.63841029575893, 30.525628566741943, 35.5599319594247, 56.26954855237688, 40.575027057102744, 36.847676345280235, 38.728626659938264, 40.18128306525094, 24.660834789276123, 2.0677732612405504, 0.601844710963113, 0.010218909559106188, 0.10247632794614349, 0.4845388712627547, 0.34207881561347414, 0.561374439724854, 0.5528253327522958, 0.746128071631704, 14.864884001868111, 76.25948115757534, 131.4064440046038, 116.07976014273507, 94.1577627999442, 92.6420897075108, 95.34627996172223, 97.36298070635114, 93.74109322684151, 90.57284668513707, 90.82835279192243, 86.24598108019147, 79.59929261888776, 87.13792133331299, 83.99354880196708, 81.06611292702812, 79.35052626473563, 83.67236137390137, 81.15209688459123, 85.98742471422467, 89.21496023450578, 102.80280181339809, 94.92933940887451, 100.10874898093087, 93.66583728790283, 106.16413184574672, 81.26109327588762, 42.034715039389475, 90.2170433316912, 99.51310770852226, 91.55120168413434, 96.79964855739048, 82.90694781712124, 103.27680097307477, 74.77269867488316, 87.91239534105573, 103.52763789040702, 90.16311836242676, 97.38870293753487, 94.48370279584611, 103.0757201058524, 97.34367861066545, 99.56460775647844, 104.43534360613141, 105.76962702614921, 105.6473526273455, 109.39110456194196, 102.1030695778983, 97.51907893589565, 90.51881749289376, 93.13368170601981, 92.5786873953683, 98.12469087328229, 99.98452908652169, 102.34095505305699, 91.35142013004848, 100.59499086652482, 121.80522864205497, 118.85514858790806, 58.684367179870605, 10.379683715956551, 0.13293693879885332, 0.13970685909901345, 0.17369243901755127, 0.040028636543346305, 0.0781499043639217, 0.17361664665596827, 5.302660192762103, 33.9488878931318, 41.289187226976665, 40.55273028782436, 39.60360983439854, 50.298357009887695, 44.80575738634382, 29.302523272378103, 32.45814841134207, 37.380349567958284, 54.40062209538051, 61.50040258680071, 82.97493594033378, 77.63785089765275, 86.05198737553188, 73.74470574515206, 4.4920768312045505, 0.4075933801276343, 0.22293272108903953, 0.203773470595479, 0.0456732234784535, 0.05236902739852667, 0.029631061080311025, 0.13655880945069448, 0.027925120566838553, 0.04877986891993454, 0.07800625171512365, 0.0675129247829318, 0.058969429294977865, 0.11703815763550145, 0.035728906015200276, 0.004759242500378085, 0.032872514466622045, 0.05607878869133336, 0.08505329250225, 0.12548456154763699, 0.043853253458759615, 0.038288489383246214, 0.03259608608537486, 0.07650983094104699, 0.08576735561447484, 0.15330315381288528, 0.1835334495242153, 0.10271139961800405, 0.21535864179687841, 0.07962216929133449, 0.15244990959763527, 0.12944721962724412, 0.09240133820899896, 0.18102141789027623, 0.21167374881250517, 0.062352713463561873, 0.02376516316352146, 0.13641639852098056, 0.19829945718603476, 0.24110572093299457, 0.16704185945647104, 0.19112086881484303, 0.21293746600193636, 0.1421916000545025, 0.20058998784848622, 0.21705709637275764, 0.18488963746598788, 0.10476442266787801, 0.07427309453487396, 0.14685431628354959, 0.11404553321855408, 0.24911962662424358, 0.28097953274846077, 0.17201400122472219, 0.17562376681183064, 0.1717620204601969, 0.18085984513163567, 0.23525932750531606, 0.34261504826801165, 0.32931182639939444, 0.20437534472772054, 0.1878457431282316, 0.14883932976850442, 0.24333701548831804, 0.11027653581861939, 0.15473415702581406, 0.14812251180410385, 0.17431361068572315, 3.183144565139498, 91.9479090826852, 135.63503428867884, 114.45279080527169, 119.09901646205357, 85.55900573730469, 61.542863028390066, 41.867558751787456, 38.261957849775044, 93.78226825169155, 93.7135922568185, 68.03038215637207, 48.803306170872276, 51.0049158505031, 49.74707651138306, 31.530039310455322, 2.424149189676557, 0.8009414332253593, 0.18237732084734098, 0.30314998594777925, 0.501800964985575, 0.19178845227829047, 0.5778918819768089, 3.087484372513635, 5.732191315719059, 14.604889358792986, 74.03445257459367, 140.9052290235247, 124.8538202558245, 100.44486808776855, 94.93796907152448, 101.15443897247314, 103.3687742778233, 100.44085202898297, 93.91313062395368, 96.77716418675014, 90.55692141396659, 83.30250181470598, 93.31409863063267, 89.07401602608817, 86.1379643848964, 84.33858939579555, 85.96669128962925, 85.55025100708008, 89.9702433177403, 93.3631181716919, 107.00203595842633, 98.97696386064801, 103.85638495853969, 97.1912351335798, 106.39661162240165, 78.34502465384347, 49.47940410886492, 97.10450077056885, 110.4454311643328, 99.4003940309797, 100.88088839394706, 90.6831910269601, 110.90377603258405, 85.98721626826695, 90.43526540483747, 104.9674505506243, 93.41730717250279, 100.18310860225132, 98.20035675593785, 106.35027408599854, 101.147782598223, 103.85699640001569, 110.0159352166312, 112.23537744794572, 109.93571131569999, 117.5933974129813, 106.07197093963623, 98.87242126464844, 95.19902678898403, 96.59325926644462, 98.84111268179757, 104.48967157091413, 105.63995974404472, 103.73058087485177, 90.98758465903146, 106.2601420538766, 129.14566693987166, 122.92966951642717, 53.309834820883616, 8.235837016786848, 0.463308433336871, 0.2069693569626127, 0.39150159646357807, 0.1365116105547973, 0.23000192961522511, 0.2449738048017025, 8.31551374707903, 46.42298534938267, 56.407637051173616, 58.69798564910889, 54.21688045774187, 56.584295000348774, 66.60678659166608, 69.00419998168945, 52.16216264452253, 34.22971323558262, 45.1040609223502, 66.81297438485282, 84.71948964255196, 86.74252019609723, 91.77261298043388, 96.54917294638497, 13.344340222222463, 0.6848520711064339, 0.37654364481568336, 0.3507863198007856, 0.2773933937507016, 0.18521346151828766, 0.13266769610345364, 0.1387008630803653, 0.07713206790919815, 0.1484402154705354, 0.18579268615160668, 0.21360977206911358, 0.19545132001595839, 0.31949304469994133, 0.20578025148383208, 0.2011899213705744, 0.09994037795279707, 0.1642903456730502, 0.230223077748503, 0.2843567915260792, 0.14791888344500745, 0.1871062892356089, 0.1293301180537258, 0.22054800976599964, 0.24636550726635115, 0.3065042288175651, 0.21855918291424, 0.11018672492355108, 0.4169386529496738, 0.07851728357906852, 0.17495086363383702, 0.26730080960052355, 0.20339573015059742, 0.2111332006752491, 0.3458831443318299, 0.27527565881609917, 0.1607454073216234], [0.025026091574026004, 0.051507369349045415, 0.04906318103894591, 0.048483756237796376, 0.10751472187361547, 0.030969210168612853, 0.03990085143595934, 0.01743790214615209, 0.013811456471947687, 0.042186388080673556, 0.07348676065781287, 0.11501923097031456, 0.02978118695318699, 0.021965742576867342, 0.09419629403523036, 0.029367782707725252, 0.10524566684450422, 0.017198399640619755, 0.03340334598241108, 0.034688426846904416, 0.05971731737788234, 0.14684022989656242, 0.13212207252425806, 0.10599061687077795, 0.12451318438564028, 0.1262733449361154, 0.0776359751554472, 0.09772563286657844, 0.06133069723312344, 0.08629129999982459, 1.0030847234385354, 57.65869494846889, 117.94657434735979, 91.89882700783866, 97.72336292266846, 60.928836822509766, 49.30163444791521, 33.185395513262065, 28.232967955725535, 63.891333307538716, 39.439031328473774, 37.55674001148769, 37.438815185001914, 33.15698432922363, 29.902378627232142, 5.151366642543247, 0.09439742538545813, 0.22132510878145695, 0.020568481214078407, 0.05254885274916887, 0.10380647371390037, 0.02696337690576911, 0.2928918663944517, 2.9504769699914113, 6.189079233578273, 51.617965834481375, 113.16761725289481, 113.21364906855992, 92.88846588134766, 87.93354565756661, 93.11520644596645, 94.21032592228481, 95.58251871381486, 90.57722405024937, 94.7173707144601, 98.66605281829834, 96.01717022487095, 86.08130182538713, 72.78668117523193, 69.7088932309832, 74.09402642931256, 70.64100796835763, 76.73768397739956, 72.2441658292498, 78.5784980228969, 86.02146393912179, 97.29154627663749, 98.16435813903809, 100.3748163495745, 95.43297958374023, 93.49351501464844, 85.84658472878593, 108.04538440704346, 56.26716879435948, 67.81079823630196, 81.33878803253174, 73.72387504577637, 81.89090578896659, 76.27947807312012, 84.33563641139439, 49.827133655548096, 87.73555673871721, 87.46775926862443, 105.47159794398716, 93.86218643188477, 94.24726949419293, 92.11620140075684, 92.97922325134277, 89.3398471559797, 94.67174884251186, 92.06482642037528, 95.90274034227643, 94.43566295078823, 93.1585145677839, 85.9375227519444, 84.07983153206962, 86.36874185289655, 83.52724824632917, 80.22062832968575, 78.41961356571743, 79.71386841365269, 95.52528640202114, 91.27870723179409, 87.80533749716622, 91.98796544756208, 119.73633302961076, 106.57723699297223, 47.01848765781948, 2.0570593561444963, 0.3994856466140066, 0.05510909090350781, 0.11899136139878205, 0.13238991743751935, 0.16680268943309784, 1.6651217873607362, 14.26255943093981, 29.384362629481725, 35.92798498698643, 41.508180550166536, 64.13233852386475, 72.07658917563302, 47.58363676071167, 30.179715973990305, 24.78843150820051, 20.40877001626151, 41.698661940438406, 50.40754795074463, 66.85637283325195, 75.7985863004412, 73.85666901724679, 20.72425992148263, 0.7260716078536851, 0.049102790520659516, 0.17803813011518546, 0.08291176134454352, 0.00820342730730772, 0.025538546665172492, 0.029892595617898872, 0.017635077637221133, 0.13336923345923424, 0.05353912032608475, 0.04000945435836911, 0.06173650188637631, 0.07889714783855847, 0.0576654885496412, 0.13113882099943502, 0.04916518520829933, 0.03369614402098315, 0.10491342217262302, 0.03345542015241725, 0.04496381850913167, 0.05043517206130283, 0.08242255116679839, 0.1412197072058916, 0.1267359565411295, 0.08145826469574656, 0.2762802706233093, 0.08130333479493856, 0.08226919546723366, 0.056439908420933146, 0.1114496753684112, 0.18681591695972852, 0.12856669830424444, 0.16378373785742692, 0.15835108794271946, 0.09184103113199983, 0.06016397662460804, 0.03638337678941233, 0.04792631257857595, 0.06968969904950686, 0.06728722367967878, 0.0456956151340689, 0.033350773089166195, 0.07444495388439723, 0.05209313505994422, 0.01571657754746931, 0.04859110387042165, 0.04686045620058264, 0.07329377172780888, 0.03900619283584612, 0.1028310524831925, 0.04170689791707056, 0.08490993162350995, 0.0406352400646678, 0.022520003906850303, 0.07888013018029076, 0.07570156002683298, 0.13755154689507826, 0.1668077241629362, 0.08738787365811211, 0.16261337351586136, 0.09310043283871242, 0.016693561105057597, 0.10476306559784071, 0.038026269525289536, 0.1274270580283233, 0.8851190220032419, 58.16484342302595, 128.11120523725236, 105.4874050957816, 109.45406218937465, 83.3238605771746, 83.58116626739502, 47.72858313151768, 17.72035912105015, 25.735540458134242, 41.733055523463655, 40.64226824896676, 47.14263807024275, 41.741827624184744, 37.87367861611502, 8.487949797085353, 0.16908370703458786, 0.37449045213205473, 0.004008339601568878, 0.14488315848367556, 0.42150961767349926, 0.16788389427321299, 0.6525687862719808, 1.7388465170349394, 9.181409546307155, 61.484241076878135, 120.40530558994838, 116.1927934374128, 97.25244876316616, 90.41737379346574, 96.57630566188267, 97.9288489477975, 101.98442213875907, 95.9096815926688, 100.40580531529018, 103.58439077649797, 100.43843405587333, 91.34782791137695, 77.65023258754185, 73.84138992854527, 79.72356115068708, 75.90030097961426, 80.20844118935722, 77.44830404009137, 82.16672148023332, 92.90780271802629, 102.4407103402274, 99.97879682268415, 103.59152657645089, 98.11442838396344, 96.77084827423096, 89.3399235861642, 110.23948655809674, 64.24975613185337, 74.01246847425188, 90.39471571786063, 80.7540693283081, 89.99828624725342, 86.49492808750698, 89.16810853140694, 56.755387442452566, 89.67992673601422, 92.72730936322893, 107.3714577811105, 99.62937886374337, 98.3531129019601, 92.32552977970668, 96.91944244929722, 91.73794841766357, 96.81644930158342, 94.95104558127267, 99.34273093087333, 98.02142674582345, 99.65745653424943, 91.53246934073312, 89.95895249502999, 90.2252699988229, 87.03483091081891, 83.44168812888009, 81.42284733908517, 83.52008465358189, 98.58865683419364, 97.2090642111642, 92.07771532876151, 96.25967625209263, 125.44423648289272, 118.28841182163784, 59.34869834354946, 5.066276397023882, 0.4442649952002934, 0.043161351300243816, 0.11094662307628564, 0.08780674011047397, 0.1989289205521345, 1.4381539949348994, 18.119970866612025, 38.25670153754098, 38.645981311798096, 43.04123803547451, 51.83942576817104, 49.15556246893746, 31.643826484680176, 28.910441637039185, 35.20110266549246, 38.69523361751011, 58.786394527980256, 66.04487882341657, 77.46292304992676, 85.4138856615339, 85.38664177485875, 24.690637350082397, 0.7274316091622625, 0.026211110575656806, 0.17622238397598267, 0.09484937720532928, 0.02784749785704272, 0.02926245371678046, 0.07981054418321167, 0.027517195491652404, 0.08551458774932794, 0.028975653927773237, 0.0624950768958245, 0.07399420307150908, 0.0408279711513647, 0.030816438009164164, 0.04178682594959225, 0.051546432610069, 0.009834161543819522, 0.08412894460239581, 0.0249558598069208, 0.03829639431621347, 0.026084663878594126, 0.08995408631329026, 0.01939249181720827, 0.1108114385445203, 0.0765818642186267, 0.3306022100150585, 0.06418557225593499, 0.07447581365704536, 0.019841978858624185, 0.056968992709049156, 0.18462813006980078, 0.22226436409567082, 0.07551068812608719, 0.1965933215937444, 0.04391767357343009, 0.20442012803895132, 0.10700124049825327, 0.16197579487093858, 0.17355289150561604, 0.20228393695184163, 0.12827277050486632, 0.12291090536330428, 0.20842830224760941, 0.14442676225943224, 0.1513388899288007, 0.11285047020230975, 0.16439117597682135, 0.16403915200914654, 0.08986120165458747, 0.23087954680834497, 0.16123981507761137, 0.180143678560853, 0.09820192373756852, 0.2518904650849955, 0.09766085991369826, 0.12720391500209058, 0.2954104798180716, 0.2124697653842824, 0.1677024947213275, 0.27619352670652525, 0.22303391780172074, 0.1427824276366404, 0.281684367784432, 0.10235913816307272, 0.19229416442768915, 1.3738048821687698, 102.81460680280412, 143.05937903267997, 115.89590385981968, 125.26042883736747, 78.58839920588902, 72.7206802368164, 52.37020560673305, 43.680934361049104, 98.2597291128976, 66.71542167663574, 58.60549817766462, 62.57241235460554, 55.23525013242449, 50.231563976832796, 10.981767705508641, 0.6605740338563919, 0.5481143998248237, 0.10945928788610867, 0.1865017009632928, 0.34626410103269983, 0.18528987813208783, 3.2011104353836606, 8.676679372787476, 12.371900745800563, 59.99202510288784, 125.76200539725167, 125.11100087847028, 100.82130064283098, 92.64920466286796, 98.08529458727155, 102.46816267286027, 106.05033424922398, 99.84885161263603, 104.7160508292062, 112.42394460950578, 105.99549906594413, 96.32960987091064, 81.88967595781598, 78.88398947034563, 83.31910106113979, 78.97057792118618, 85.28643485477993, 81.95547539847237, 87.50449439457485, 97.99072960444859, 111.00902039664132, 107.45493343898228, 109.0940134865897, 101.06015191759381, 99.99422182355607, 90.33177893502372, 114.31386852264404, 67.616776738848, 85.53004564557756, 100.4549777167184, 88.84508677891323, 97.93078749520438, 94.91399083818708, 96.79358278002057, 64.06879029955182, 90.83817059653146, 96.4194083895002, 111.77710206168038, 104.93334184374127, 105.0790525163923, 97.58934606824602, 101.43133858272007, 94.80461924416679, 98.95682798113141, 97.86802441733224, 103.22961575644356, 101.86765766143799, 103.84448269435337, 96.4567688533238, 95.40722955976213, 95.27684661320278, 92.54209123338971, 87.66869422367641, 85.7463013785226, 89.85207530430385, 106.07994747161865, 100.83426598140171, 94.82176739828927, 98.97103009905133, 131.64076505388533, 115.83982494899205, 54.61410549708775, 3.8378044877733504, 0.425953207803624, 0.16052898179207528, 0.17164736161274569, 0.19673917948135308, 0.2914900401873248, 2.496626283441271, 26.655782461166382, 51.912027495247976, 53.24287503106253, 63.740126609802246, 94.08738449641636, 102.54465539114815, 70.51325838906425, 42.984346185411724, 36.31631980623518, 31.11886923653739, 54.475211007254465, 69.1319009235927, 87.03205857958112, 90.719544001988, 105.14063440050397, 41.25995962960379, 1.0303198162998473, 0.1813788837088006, 0.3553292474576405, 0.24617991436805042, 0.15535777142005308, 0.11211510109049933, 0.1785980843539749, 0.11300792425338711, 0.4113597651677472, 0.10677630613957133, 0.19122473895549774, 0.24273694625922612, 0.1750289901558842, 0.12253102074776377, 0.19594739696809224, 0.11340264164443527, 0.147806762318526, 0.23837187620145933, 0.10277928704661982, 0.17885442131331988, 0.16373892740479537, 0.1431302446871996, 0.16186215382601532, 0.16232340836099216, 0.14447354046361788, 0.3559451401233673, 0.1520145751003708, 0.11429964458303792, 0.1415762095046895, 0.1846896189131907, 0.32838150060602594, 0.1911717996533428, 0.19570756198040076, 0.37431039607950617, 0.1473158693739346], [0.016554278221779635, 0.008873340690375438, 0.0687827623582312, 0.08858829710100379, 0.09238898208630936, 0.056572036152439456, 0.10763366906238453, 0.05178969080692955, 0.015834864860932742, 0.009948978150662566, 0.03182201672877584, 0.007365291522416685, 0.06329944623368126, 0.04845383284347398, 0.07123013639024325, 0.036868603966597996, 0.05648252381277936, 0.048998978055481396, 0.06637133711150714, 0.04695086759914245, 0.12773891272289412, 0.12193662407142775, 0.0952135401644877, 0.0636185680383018, 0.18267565912434033, 0.03725238676582064, 0.013216756151190825, 0.11813032760151795, 0.01803673304883497, 1.3499422711985452, 56.12576253073556, 112.37293788364956, 100.760267666408, 81.78278487069267, 67.54942090170724, 58.34894984109061, 22.379946163722447, 33.36469725200108, 71.95623942783901, 58.22843681062971, 39.955661160605295, 30.293256487165177, 28.647829260144913, 18.29197699683053, 0.581197704587664, 0.315677777997085, 0.05604441410728863, 0.07233323755541018, 0.11569000354834966, 0.03810039947607687, 0.1372285506555012, 1.8180626034736633, 2.702143141201564, 25.504144600459508, 98.68300642286027, 112.84554045540946, 92.29977280752999, 85.26868220738002, 92.51540320260185, 89.48273686000279, 90.19728960309709, 96.1787714276995, 107.86211177280971, 103.28578499385289, 101.36872141701835, 93.41855090005058, 93.80719144003731, 90.88618959699357, 80.60022926330566, 68.79759529658726, 72.90451567513603, 74.22762639181954, 75.95570591517857, 81.2920058114188, 97.5920558656965, 96.08959824698312, 94.21150711604527, 93.29777036394391, 93.65756893157959, 87.63254969460624, 93.54873234885079, 92.29061508178711, 97.61984866006034, 84.71226351601737, 43.11644186292376, 91.76553971426827, 79.65227958134243, 77.77648830413818, 89.37544972555978, 63.161306926182334, 70.19807420458112, 100.73499706813267, 98.46841130937848, 99.8289519718715, 95.03267996651786, 90.98142855507987, 84.64786761147636, 90.08195645468575, 91.45956884111676, 95.4678178514753, 92.56831373487199, 91.22777693612235, 94.06388568878174, 100.85905020577567, 91.74618898119245, 91.59659426552909, 81.78156893593925, 77.13515567779541, 74.49773066384452, 78.59464563642229, 74.21948310307094, 74.26481315067836, 81.23788629259381, 90.52976785387311, 92.3443524496896, 89.87779058728898, 91.81130749838692, 113.75938143048967, 92.28270803179059, 14.232516288757324, 0.31527342540877207, 0.043134413460003476, 0.08607273708496775, 0.0973937613889575, 0.1412505262664386, 0.22644382768443652, 9.961118153163365, 28.49470485959734, 22.911672694342478, 34.170316559927805, 43.02700465066092, 49.386683872767854, 69.78124482291085, 35.79040370668684, 23.85278708594186, 17.534449645451136, 40.45859261921474, 66.47408989497593, 69.72766031537736, 68.94040162222726, 85.90797206333706, 34.06097970690046, 1.3493780557598387, 0.12776240360523972, 0.02750986222443836, 0.015716341756550328, 0.050158285668918064, 0.03241145331412554, 0.02812442496152861, 0.00865400763827243, 0.05520119863961424, 0.052535105629691055, 0.08839659738753523, 0.03760475678635495, 0.030616375351590768, 0.09659703235541071, 0.051529126574418375, 0.056126849326704226, 0.056478218508086035, 0.1053349824090089, 0.14579339964049204, 0.03113639441185764, 0.018552317882754972, 0.059206360152789524, 0.13413819005446775, 0.17266227358153888, 0.16684815127934727, 0.08504547577883516, 0.06949607229658536, 0.10244099662772246, 0.06710120330431632, 0.138214448466897, 0.047970400391412635, 0.16986741498112679, 0.06275016535073519, 0.037539790450994454, 0.05913393332489899, 0.036340249103627036, 0.04160328222704785, 0.03739864159641521, 0.08928226200597626, 0.017303842286180173, 0.12042875641158649, 0.039932868110814264, 0.03350298206454941, 0.056354562286287546, 0.046134532296231816, 0.03393806889653206, 0.05816718377172947, 0.02157590724527836, 0.09297123977116176, 0.030109268812728778, 0.03827703910480652, 0.09121802741927759, 0.028951386122831275, 0.03808481691937361, 0.05838810120310102, 0.185194408254964, 0.031003116563494717, 0.09475155281169073, 0.05153913835861853, 0.047787005946572335, 0.016489235551229546, 0.14484433270990849, 0.1078769713640213, 0.7870442760842187, 57.01034116744995, 125.65294647216797, 115.31276239667619, 95.48014395577567, 89.6826365334647, 72.85496807098389, 44.56776074000767, 38.460387979234966, 31.885099206651958, 58.748311451503206, 39.40893520627703, 40.3158974647522, 35.33832263946533, 25.02286720275879, 0.9525553605386189, 0.21963101040039743, 0.125132931130273, 0.08551034690546137, 0.3359976219279425, 0.21007535101047584, 0.8365321148719106, 0.9046671273452895, 1.2772909296410424, 29.51145212990897, 104.31589017595563, 118.83652741568429, 96.42543942587716, 88.04848970685686, 97.25070476531982, 94.70794895717076, 95.28107806614467, 101.43901634216309, 112.2428537096296, 109.25191129956926, 106.08528368813651, 98.71009050096784, 98.50182519640241, 97.25446374075753, 85.70099912370954, 72.39129393441337, 76.85793645041329, 79.41563783373151, 79.26290948050362, 85.48080376216343, 100.24185562133789, 100.95066915239606, 97.1210583278111, 95.1478602545602, 95.7362128666469, 91.24787112644741, 96.74426446642194, 94.36041396004813, 101.06870515005929, 89.08808612823486, 51.651143482753206, 97.84281635284424, 87.75059958866665, 84.82259396144322, 96.63212054116386, 69.81254645756313, 73.3536124910627, 104.43916511535645, 97.73664787837437, 103.6547690800258, 96.97495855603898, 97.11907114301408, 90.11794117518834, 97.56597232818604, 95.5928715297154, 101.20515387398856, 98.0559662410191, 94.07339082445417, 97.63237626211983, 101.75258159637451, 96.0657798222133, 95.2870465687343, 86.40048817225865, 78.57476684025356, 77.05616160801479, 81.74124853951591, 76.48075348990304, 76.15346554347447, 82.68971238817487, 94.52889387948173, 99.52939428601945, 92.82706465039934, 93.50537558964321, 119.65962491716657, 105.82062680380685, 24.462039879390172, 0.07092630197959286, 0.028533364446567636, 0.11653122412306921, 0.09451226743736438, 0.15971324699265615, 0.17142383860690252, 11.14992540223258, 35.72585494177682, 29.60114642551967, 33.23054838180542, 39.89744567871094, 42.47643286841256, 37.02959060668945, 32.986861160823274, 32.87826429094587, 33.81026438304356, 52.79854120526995, 76.19741984776088, 81.51787090301514, 77.71125166756767, 101.90464987073625, 42.942611830575125, 0.9245035286460603, 0.062230203965944905, 0.03946963903893318, 0.003528623825072178, 0.09441416484436818, 0.0769239476482783, 0.010068673424289694, 0.05183730360918811, 0.055253564579678435, 0.052151058201811144, 0.08076875776584659, 0.08710478884833199, 0.060425911497856886, 0.01971123873123101, 0.03228364785068801, 0.02335011855965214, 0.09330089922462191, 0.049519780823694806, 0.08834352237837655, 0.05185318811397467, 0.030065812037459443, 0.042143996605383496, 0.06416545369263206, 0.1104844185922827, 0.06817638953881604, 0.05553852893146021, 0.01748201879672706, 0.1069163829088211, 0.07642813532480172, 0.01983457773790828, 0.04766665758298976, 0.1377721657710416, 0.1000203840168459, 0.07930290499436003, 0.13482435180672578, 0.1378304519291435, 0.15015519915946893, 0.1713053663926465, 0.15601106493600778, 0.21976967581680842, 0.20416763158781187, 0.14694739771740778, 0.10535795760474034, 0.13522057554551534, 0.09191967334066119, 0.11387101401175771, 0.12318002592240061, 0.1696800036089761, 0.1517272155199732, 0.22436901687511376, 0.1383505625916379, 0.26188892285738674, 0.12404264749160834, 0.1300978668566261, 0.1789824744420392, 0.28856452288372175, 0.16236608821366513, 0.15358275095266954, 0.4987629737172808, 0.11291272579027073, 0.14235381063606056, 0.27898748964071274, 0.12061904477221624, 2.4154213837214877, 105.2940923145839, 135.86918858119418, 123.73973219735282, 106.04877090454102, 87.33769593920026, 77.32346575600761, 34.192321504865376, 52.06977939605713, 105.73544188908168, 90.11899035317558, 60.669161796569824, 52.79651233128139, 46.44634519304548, 33.32854577473232, 1.2612249574490955, 0.6356927518333707, 0.23702856685434068, 0.34697618282267023, 0.3975170265351023, 0.20193147872175488, 1.5700546886239732, 6.3526537248066495, 6.85729661158153, 30.511245795658656, 106.06172929491315, 128.75698471069336, 100.3965711593628, 91.53498458862305, 102.5733722959246, 100.9955267224993, 98.78940418788365, 104.23607621874127, 116.34550789424351, 113.79624162401471, 110.9808315549578, 103.70134285518101, 102.21909059797014, 101.06707927158901, 92.80416338784354, 79.008376121521, 81.2974670955113, 82.61966064998082, 84.98903805868966, 90.39041478293282, 106.33092335292271, 104.79806736537388, 102.07454722268241, 97.71822125571114, 101.33881637028286, 95.06755992344448, 102.67125156947544, 98.27700928279332, 104.94229112352643, 88.89953981127057, 56.84546388898577, 107.58362102508545, 96.1333510535104, 93.34550448826381, 107.5117905480521, 81.25167151859829, 76.99321092878068, 106.17240715026855, 99.86734076908657, 106.10726778847831, 100.75067220415387, 100.60012558528355, 92.62840870448521, 102.74427713666643, 100.32934733799526, 107.3751472745623, 100.37790829794747, 98.3321223940168, 103.21284280504499, 107.39670753479004, 100.29143101828438, 99.83101558685303, 89.58769634791783, 86.04012680053711, 82.6465015411377, 86.10633618491036, 79.90076800755092, 80.5556287765503, 87.97136470249721, 99.180038860866, 102.6410824911935, 97.57492855616978, 97.13003540039062, 125.45660427638462, 102.99630914415631, 21.13328126498631, 0.20997507710541996, 0.15351850725710392, 0.2593185507825443, 0.24835185067994253, 0.34343577708516804, 0.42781817487307955, 16.346354586737498, 46.32646444865635, 37.50954784665789, 50.906696115221294, 63.840472493852886, 69.24354457855225, 99.58978107997349, 48.85557052067348, 35.31510870797293, 26.94146112033299, 53.08022117614746, 81.95833805629185, 88.51876463208879, 83.90081119537354, 109.70294666290283, 63.1508846282959, 2.133541000740869, 0.3971340613705771, 0.15264369919896126, 0.09923739531742674, 0.14636414258607797, 0.15513006863849504, 0.18735950493386813, 0.1583839561790228, 0.23341884197933332, 0.16280746167259558, 0.19105769720460686, 0.1647367945739201, 0.15144064304019722, 0.21155455735112938, 0.08419645883675132, 0.19164978686187947, 0.18841694747763021, 0.14593395138425486, 0.2196490458611931, 0.13951317806329044, 0.136567087577922, 0.1324955653399229, 0.19603353020335945, 0.18406533955463342, 0.1618081967213324, 0.1281094742672784, 0.11725923791527748, 0.18124452020440782, 0.1281034353056124, 0.17044605607432978, 0.3432458144213472, 0.21058475439037594, 0.1777084842324257, 0.14028955783162797], [0.06811952151890312, 0.06821862834372691, 0.053949176001229456, 0.05919164951358523, 0.03783347737044096, 0.11485240635062967, 0.05857755496565785, 0.021558323010270084, 0.02914336064298238, 0.08289679964738232, 0.03231655340641737, 0.10333668320838894, 0.04954397398978472, 0.03729741774233324, 0.030649436970374415, 0.036064835132232735, 0.038115839540426216, 0.11572660372725554, 0.0872371167476688, 0.03752643009647727, 0.11485256919903414, 0.03164660864110504, 0.039527066850236485, 0.05071370390110782, 0.08793663885444403, 0.07360859840576138, 0.10825349723121949, 0.1693687324545213, 1.1232727084841048, 54.324751240866526, 109.38025842394147, 94.17224284580776, 87.20739637102399, 72.58460671561105, 41.28474037987845, 31.55824899673462, 60.297238622392925, 61.069280760628835, 43.81026118142264, 37.814118657793315, 28.48611167498997, 29.002468790326798, 10.231986727033343, 0.10745927199189152, 0.01941143990760403, 0.09752842344875846, 0.02689791693618255, 0.15857366099953651, 0.12494516691991261, 0.9103589504957199, 1.5203169861010142, 1.0015070480959756, 52.40500913347517, 109.49186733790806, 95.22899436950684, 82.81994942256382, 93.07505975450788, 93.89085469927106, 84.60696356637138, 95.2324754170009, 104.7794531413487, 103.0807922908238, 96.472138268607, 93.93106392451695, 97.0403619493757, 95.42827565329415, 88.86363846915108, 91.29508413587297, 82.64736311776298, 69.26330525534493, 69.56646905626569, 70.89675031389508, 75.6856711251395, 88.21407222747803, 86.16122695377895, 93.86329814365932, 91.73778860909599, 89.86378996712821, 82.72482163565499, 84.51300307682583, 75.62712560381208, 82.97988305773053, 83.70209966387067, 105.21084594726562, 63.3172036579677, 53.41489158357893, 81.30861200605119, 66.48711776733398, 80.78423840659005, 36.463183879852295, 85.57192243848527, 88.54238850729806, 96.32220309121269, 95.39953095572335, 95.60361344473702, 90.54542909349713, 87.07852118355888, 85.03340230669293, 85.66762692587716, 89.29412800925118, 92.5824533190046, 89.92701162610734, 85.34820434025356, 86.88359642028809, 90.04530470711845, 90.0106748853411, 89.03770474025181, 79.57104124341691, 72.5874832698277, 71.74273518153599, 72.11018371582031, 76.04997907366071, 73.3240965434483, 74.06785256522042, 80.31099660055978, 90.72632544381278, 89.33460126604352, 84.80956608908517, 90.19342640468052, 116.34232561928886, 26.22285062926156, 0.2577987680477755, 0.16285323564495358, 0.08391084309135165, 0.035123988653400114, 0.05407599758888994, 0.11992482202393667, 2.626678539173944, 22.848456246512278, 28.403763362339564, 42.53330387387957, 52.24261236190796, 70.20295183999198, 64.08664716993059, 39.386909416743684, 31.07799298422677, 24.641187020710536, 38.898801939828054, 44.97912188938686, 73.03646196637834, 71.99575383322579, 85.62392275674003, 47.96859475544521, 2.3497811002390723, 0.4996148337210928, 0.05415682468031134, 0.11378300801983901, 0.02210920862853527, 0.0740956576274974, 0.06266751978546381, 0.009025478419581694, 0.05778330258492913, 0.04285136257697429, 0.10364777794373886, 0.02714641172704952, 0.09190578372882945, 0.08222876835082259, 0.08380899498505251, 0.07346699493271963, 0.15463928425950663, 0.094533139174538, 0.039407145963715653, 0.0969445915626628, 0.05928403205637421, 0.016139174246096184, 0.1181756808821644, 0.12493789302451269, 0.13637964906437056, 0.10120110958814621, 0.13790579645761422, 0.06401827266173703, 0.08570427899914128, 0.11875740252435207, 0.032867608658437214, 0.05325940104999712, 0.03532344402213182, 0.07963466112102781, 0.06363220659217664, 0.041657202012304745, 0.11243866729949202, 0.04333152788292084, 0.07184818679732935, 0.04169624152460268, 0.009482667681628039, 0.02220842401896204, 0.06816281883844308, 0.0369042474111276, 0.04074718137936933, 0.025805022634033645, 0.06607680541596242, 0.006671639591721552, 0.14259835465678147, 0.04954160590256963, 0.0980134674214891, 0.09347452955054385, 0.03758227352851203, 0.07673334037618977, 0.09471046073096138, 0.053184670595718284, 0.07199446537664958, 0.07287310037229743, 0.1542948463133403, 0.08727993909269571, 0.13626333459147386, 0.8452941732747214, 57.50693586894444, 126.26684761047363, 107.53888157435826, 102.03016213008335, 86.65834971836635, 65.46327291216168, 53.709609849112375, 25.14548032624381, 30.041721275874547, 53.15437582560948, 37.32719932283674, 37.83966718401228, 36.68747520446777, 15.02263069152832, 0.14061488823166915, 0.058913348375686576, 0.19297336441065582, 0.09663769017372813, 0.3235411303383963, 0.3018846538450037, 1.1275006873267037, 0.4880826696753502, 1.5498828738927841, 60.29414667401995, 119.40432030814034, 100.00679806300572, 88.54910741533551, 97.03125980922154, 96.57325540270124, 90.5541421345302, 98.9984963280814, 107.6891780580793, 104.42468506949288, 98.87891088213239, 98.57765088762555, 100.48380579267229, 96.34061581747872, 95.0796845299857, 95.09814589364188, 86.903336252485, 73.86187321799142, 71.77483585902623, 74.9018726348877, 80.43066542489188, 92.07190663473946, 91.88000433785575, 97.09747614179338, 93.78067016601562, 93.51684706551688, 87.94424588339669, 89.95789636884416, 80.8330911908831, 86.46817752293178, 87.35290554591587, 108.29465797969273, 67.47745840890067, 59.825733866010395, 87.87267943790981, 73.60778454371861, 88.72008173806327, 44.40412024089268, 90.12618868691581, 90.68642888750348, 99.39435604640416, 98.65802070072719, 100.10825565883091, 95.32945837293352, 92.81331416538784, 90.52491801125663, 92.49751853942871, 91.3855983189174, 97.60094955989292, 93.59058829716274, 87.96945394788469, 90.4501623426165, 93.13250746045793, 92.76032720293317, 91.80957739693778, 81.74146393367222, 76.12298379625592, 75.92222949436733, 74.10443483080182, 79.0870783669608, 77.82669598715646, 76.5498741694859, 80.73698370797294, 94.92979104178292, 94.64879894256592, 89.03965718405587, 90.69145243508476, 122.98788152422223, 37.877722467694966, 0.02793245722672769, 0.1075201297977141, 0.2126705574670008, 0.0610620787899409, 0.04028269362502864, 0.08102824312767812, 2.34921156508582, 26.681192023413523, 37.79334006990705, 37.854053429194856, 46.394622802734375, 59.6690867287772, 29.53535393306187, 27.77295551981245, 29.914221831730433, 42.611387729644775, 55.45188454219273, 62.69882787976946, 81.58128016335624, 79.37513678414481, 97.6463212966919, 60.93337399618966, 3.4761483626706258, 0.535510313298021, 0.02049556075196181, 0.03787451856104391, 0.045018623782587905, 0.06967737685356822, 0.05432467728054949, 0.021612824639305472, 0.04367867996916175, 0.04772429234747376, 0.0465985179346587, 0.013726594641671648, 0.04511708599914398, 0.03501682761790497, 0.074260324505823, 0.04438020036156688, 0.05163570746247258, 0.053246162831783295, 0.03945903692926679, 0.04792710307187267, 0.06433273971612964, 0.0702157604641148, 0.05005202708499772, 0.0832557175308466, 0.11659682488867215, 0.08204495999962091, 0.0726341474801302, 0.09480854296790701, 0.0993941572627851, 0.11144576700670378, 0.09123837668448687, 0.046217086259275675, 0.17229752029691422, 0.09680385661444493, 0.1424031537026167, 0.13765376141028746, 0.238734919577837, 0.12038104182907514, 0.1457824752266918, 0.1283158574785505, 0.19932617566415242, 0.12829383223184518, 0.20827396267226764, 0.156919623325978, 0.28020043884004864, 0.1303175493542637, 0.15228797043008463, 0.1675443146377802, 0.23757839735065187, 0.10808301530778408, 0.27934610896876877, 0.21780680971486227, 0.09637937867747885, 0.18847139312752656, 0.20058825079883846, 0.22437528653868608, 0.1502972301095724, 0.16870268248021603, 0.3995120551969324, 0.1919037625193596, 0.2972776453409876, 2.1350661303315843, 104.14238670894078, 136.7850306374686, 120.40049743652344, 113.18303530556815, 94.51915250505719, 61.31767191205706, 48.90715047291347, 82.69391604832241, 94.19733279091972, 67.04988711220878, 58.95129612513951, 49.144084044865195, 47.05184595925467, 21.076863629477366, 0.35913395615560667, 0.14433045099888528, 0.3885771105332034, 0.2132150682487658, 0.33782415677394184, 0.2102636716195515, 2.9993679693767, 5.274021889482226, 2.605716041156224, 61.861583845955984, 123.15069171360561, 106.18585886274064, 89.40406935555595, 104.45347840445382, 103.55805015563965, 93.66941561017717, 99.17773900713239, 111.44690976824079, 107.87520217895508, 103.96538829803467, 102.92982183183942, 106.46834482465471, 101.43051869528634, 102.28213855198452, 98.90682874407086, 91.18923527853829, 76.90605967385429, 76.91155569893974, 79.20544787815639, 83.74591500418526, 97.22514234270368, 96.9607286453247, 101.51113864353725, 101.4998756136213, 100.9054502759661, 95.76087202344621, 94.69695690699986, 84.84594685690743, 88.42151069641113, 93.05069242204938, 115.82348278590611, 73.79901286533901, 67.27113165174211, 97.91293757302421, 81.81346811567033, 98.4762349809919, 50.100774560655864, 92.19675186702183, 94.8069885798863, 105.55264173235211, 105.20453003474644, 104.24648462023053, 99.85764108385358, 97.54339763096401, 91.99599061693463, 95.00337941305978, 94.96945830753872, 99.34362724849156, 97.57802050454276, 91.86161940438407, 96.1589412689209, 98.29424776349748, 99.74524702344621, 98.8244856425694, 87.00673934391567, 79.77103124346051, 79.88762201581682, 78.89448819841657, 83.54917676108224, 80.23314898354667, 80.34042222159249, 87.63701043810163, 99.74024432046073, 98.83959102630615, 91.37355709075928, 98.87911932809013, 125.1113760811942, 33.4920334134783, 0.2318369597196579, 0.30001965963414734, 0.22167880194527761, 0.21251612289675645, 0.17516023239919118, 0.30067626440099304, 4.143500472818102, 38.0438608442034, 48.126527309417725, 65.29962199074882, 72.16810389927456, 99.24630383082798, 90.47623198372978, 54.475586209978374, 43.664376803806846, 35.927099091666086, 52.881606919424875, 64.5325756072998, 92.63735103607178, 86.4371885572161, 109.37248338971818, 82.43419238499233, 9.26506585734231, 0.7634669212358338, 0.19430644144969328, 0.2339476921728679, 0.09553953552884714, 0.18808559168662342, 0.18392822119806493, 0.10403942157115255, 0.10682644987744944, 0.1376868060656956, 0.21838216669857502, 0.08395884265857083, 0.12162765993603639, 0.17757570849997656, 0.15939753821917943, 0.15534866548010282, 0.17693760059773922, 0.13561244308948517, 0.1845193744770118, 0.19011720695665904, 0.1816821074379342, 0.18647974357008934, 0.1785968222788402, 0.1514809344496046, 0.15634915179439954, 0.20072359139365809, 0.19522213802805968, 0.2046272304973432, 0.17878113953130587, 0.17698744578020914, 0.3068030284983771, 0.19676077046564647, 0.2599690487342221], [0.09766328906906502, 0.04415218545390027, 0.015651696028986146, 0.044093288614281585, 0.11342772029872451, 0.029342246042298417, 0.04573721611606223, 0.0038208540146505193, 0.05070214166439005, 0.03328326903283596, 0.11393252999654838, 0.08245540583240134, 0.12675091145294054, 0.11256980097719602, 0.03057172435468861, 0.03413281183955925, 0.013150822055259985, 0.07659523814384427, 0.11186829076281615, 0.032881922354655604, 0.03674001818788903, 0.06745873697634254, 0.03836326394230127, 0.03879975873444762, 0.15618171649319784, 0.04402780659230692, 0.043939305269824605, 2.362109375851495, 62.29968861171177, 102.93754128047398, 100.9163658959525, 85.16170079367501, 72.42349883488247, 49.04221650532314, 36.53289515631539, 29.099684510912212, 82.84123870304653, 80.90044702802385, 42.00653314590454, 36.605542046683176, 27.587518521717616, 5.691983827522822, 0.9200723149946758, 0.07385671830603055, 0.022267371748707125, 0.037291901252631626, 0.07572236391050474, 0.05461234220170549, 1.9118383143629347, 1.3917425253561564, 3.3053814002445767, 81.48656926836286, 107.41776057652065, 90.3918878010341, 93.76944187709263, 96.52572277614048, 87.33028221130371, 92.568466595241, 100.82380894252232, 97.76777580806187, 94.42307976314, 94.5070001057216, 94.3203923361642, 95.631913457598, 89.3229421888079, 88.29989637647355, 92.04261302947998, 92.72722598484584, 90.23378154209682, 69.06469099862235, 66.87555680956159, 71.27323150634766, 83.35372393471854, 90.7581342969622, 92.94204344068254, 93.30603872026715, 85.78635774339948, 80.57916927337646, 77.66958332061768, 83.94367463248116, 86.63851261138916, 86.50768498011998, 78.24975790296281, 86.1172240121024, 90.13344955444336, 44.661627428872244, 56.642374992370605, 77.91060938153947, 42.50369759968349, 67.87302630288261, 95.15036855425153, 91.48703507014683, 95.86253806522915, 89.31290899004254, 95.60881764548165, 87.724502154759, 86.67889554159981, 89.76478508540562, 94.07866450718471, 86.51762090410504, 90.99726349966866, 93.11791624341691, 92.3644883292062, 88.96056583949498, 93.00251361301967, 88.80834470476422, 83.65016882760185, 73.54490334647042, 72.09837872641427, 74.98878765106201, 76.69862815311977, 71.43090697697231, 74.99346378871373, 72.91241577693394, 73.67256259918213, 67.9447386605399, 73.22220121111188, 81.45448248726981, 87.85653182438442, 80.1201365334647, 111.67621421813965, 18.94978380203247, 0.4058041647076607, 0.13723039627075195, 0.15331939794123173, 0.14940950274467468, 0.005106730037368834, 0.2352717582668577, 0.14046273353908742, 12.644722631999425, 26.139948197773524, 32.419947215488975, 35.67361838476998, 66.06907939910889, 68.2128210067749, 44.1832891191755, 20.264068569455826, 12.235068133899144, 27.966520173209055, 55.19151817049299, 58.53609957013811, 68.12847682407924, 73.51340716225761, 64.3193006515503, 12.101894617080688, 0.2057081096406494, 0.07334787132484571, 0.006023714560017521, 0.01670416660739907, 0.05706258982952152, 0.06007716485432216, 0.045737460388668945, 0.0477506771816739, 0.06902898236044816, 0.05742036098880427, 0.06574429611542396, 0.012349829277289765, 0.06837964470365218, 0.061382150543587546, 0.07536868431738444, 0.027120634181691066, 0.029602450651249716, 0.0642879292634981, 0.06695071102253028, 0.10443061736545392, 0.09628137786473547, 0.11882246046194009, 0.0348363305175943, 0.12277882173657417, 0.09606020259005682, 0.008598042069934309, 0.0431546846936856, 0.10295659503234283, 0.030330209992825985, 0.09240508372230188, 0.05462688659983022, 0.13545978628098965, 0.02119566809519061, 0.037713553091245036, 0.024954387385930334, 0.06153758256030934, 0.06109050940722227, 0.09727190328495842, 0.05294827917324645, 0.04370041344580906, 0.029213131006274904, 0.05830253115189927, 0.04006153192105038, 0.06541937283639397, 0.07801141536661557, 0.0589378367045096, 0.03080942534974643, 0.009617836946355445, 0.06443945291851248, 0.10518189133810145, 0.03437202596770866, 0.10034132429531642, 0.08784059900790453, 0.013620096874157233, 0.06300309606428657, 0.21059295109340123, 0.09167822343962533, 0.10431603994220495, 1.5700868240424564, 68.64811870029995, 124.67458452497209, 111.1967329297747, 101.27089772905622, 89.88325881958008, 83.42314338684082, 49.10653945377895, 25.477800505501882, 55.220947265625, 77.758791242327, 44.597724846431184, 40.26851075036185, 38.32906355176653, 8.010605948311941, 0.8108855539134571, 0.14701563119888306, 0.04283983087433236, 0.025296245202688233, 0.20291006192564964, 0.6153053258146558, 1.595238325851304, 0.9128947172846112, 4.484621848378863, 89.45873083387102, 110.97451564243862, 95.13764640263149, 98.24315071105957, 102.42996147700718, 91.1217404774257, 97.19213145119804, 103.54605061667306, 102.06816182817731, 97.55937848772321, 99.23502690451485, 97.12254524230957, 99.00152574266706, 91.36560835157121, 95.71384661538261, 98.06590216500419, 98.45941339220319, 93.91875171661377, 73.08113888331822, 69.7693703515189, 72.85470403943742, 87.02615261077881, 95.7000891821725, 96.011292048863, 95.47694778442383, 90.7370673588344, 85.03424998692104, 82.66523388453892, 86.22993768964494, 88.79979147229875, 89.07761519295829, 81.20696680886405, 87.8231109891619, 93.31444604056222, 50.16261005401611, 62.8014041355678, 87.82949638366699, 49.78333568572998, 70.60501629965646, 98.84630298614502, 96.84804970877511, 98.45310442788261, 90.63248307364327, 97.88609668186733, 90.95761707850865, 92.73070008414132, 92.83830683571952, 95.61000578744071, 90.97391755240304, 94.66528006962368, 98.63356304168701, 97.34342152731759, 91.88497924804688, 96.23780332292829, 92.96422903878349, 86.79153973715646, 76.57674285343715, 76.20531300136021, 78.71860149928501, 80.957978112357, 76.03219863346645, 75.97661999293736, 75.21993337358747, 77.95189557756696, 70.16555663517543, 74.42351695469448, 84.47148759024483, 93.08512074606759, 83.61148820604596, 115.85176890236991, 29.020685229982647, 0.4527663875903402, 0.1707875356078148, 0.13045871177954332, 0.10182591820401804, 0.00972238477386002, 0.22781245995845112, 0.020818217724029506, 14.285889744758606, 34.56435237612043, 35.51624516078404, 35.34627137865339, 56.23091309411185, 30.38979823248727, 28.204713106155396, 25.390937600816997, 24.547704219818115, 44.24985980987549, 70.6570166179112, 73.84343269893101, 75.60249423980713, 86.48744487762451, 79.13352012634277, 17.383984667914255, 0.28474719343440874, 0.032384942950946946, 0.06881631591490336, 0.058232594547527175, 0.03283628748197641, 0.06623845281345503, 0.030184871184506586, 0.04827548669917243, 0.07846831370677267, 0.01862358780843871, 0.046439238624381166, 0.017363387126741663, 0.05377062629642231, 0.09159786453736679, 0.032222087761121135, 0.03372063234980617, 0.009187683063958372, 0.04253679034965379, 0.03941626886704138, 0.06885035123143878, 0.053539931175432036, 0.04683867183380893, 0.04492447026340025, 0.02647629054263234, 0.06351417542568275, 0.02967030754578965, 0.07754022707896573, 0.08664676414004394, 0.04493450240365096, 0.054088194255850146, 0.016884383812014545, 0.2328873590699264, 0.12839033348219736, 0.10611424595117569, 0.12956449761986732, 0.17500872910022736, 0.13127389018024715, 0.15856615640223026, 0.047937922312745025, 0.16269520483911037, 0.09793513733893633, 0.13322275131940842, 0.11330143136105367, 0.18071139524025576, 0.14241335886929715, 0.1618799857263054, 0.14334748445877007, 0.1081207622108715, 0.16102324027035916, 0.20333631762436458, 0.16796789690852165, 0.17686042402471813, 0.20289159220244202, 0.13395216289375508, 0.1496291309595108, 0.2438551719699587, 0.14443789023373807, 0.23469836903469904, 4.700697796685355, 106.8310546875, 129.2075753893171, 127.23488453456334, 108.16376086643764, 94.26249299730573, 70.1286894934518, 52.76273366383144, 45.89277178900582, 129.7241600581578, 112.06105409349713, 62.14577906472342, 62.76512064252581, 48.76410443442208, 11.523950406483241, 1.6461349661861147, 0.29490141570568085, 0.23625956954700605, 0.207344722534929, 0.12594950731311524, 0.46724165656736916, 4.192031902926309, 3.537102520465851, 4.254831024578639, 93.40040220533098, 114.13272203717912, 96.9409818649292, 100.65810830252511, 108.79984065464565, 94.15003640311105, 102.44810322352818, 106.8970764705113, 109.08838544573102, 101.59473242078508, 104.71408448900495, 100.7917013168335, 104.6535587310791, 96.82015269143241, 98.82947444915771, 99.25906767163957, 102.58939484187535, 99.45154666900635, 76.76694284166608, 74.65780326298305, 77.64591080801827, 93.08285563332694, 101.53911209106445, 98.39694213867188, 101.18595600128174, 93.85483523777553, 91.05698326655796, 85.4007396697998, 90.30559117453438, 90.39067186628068, 94.55806241716657, 81.71724946158272, 93.77024786812919, 95.69367599487305, 56.155466079711914, 70.77079336983817, 92.50063828059605, 58.875123023986816, 73.65487943376813, 101.64118807656425, 101.79377051762172, 101.96045085362026, 95.85886246817452, 101.05381516047886, 94.79022257668632, 96.75326238359723, 95.24683039528983, 100.6813291822161, 96.40456703730992, 100.79455007825578, 101.46234839303153, 102.65940489087785, 96.91041673932756, 99.41663197108677, 96.72979136875698, 89.28934070042202, 81.18474646977016, 80.54689489092145, 81.80605438777378, 82.44640731811523, 77.70695073263985, 81.10266045161656, 79.0639339174543, 81.96029050009591, 73.38047422681535, 79.13169969831193, 88.77115099770683, 96.30724361964634, 90.00301102229527, 124.1713820866176, 25.253999028887065, 0.6389159560203552, 0.40124204808047836, 0.23044699430465698, 0.36421702482870644, 0.10136907414666244, 0.3783883372587817, 0.27213102898427416, 19.361351660319738, 42.609775747571675, 52.03571237836565, 52.41514655521938, 98.59703636169434, 92.83023997715541, 63.81906509399414, 28.774251733507427, 20.593043191092356, 38.674159731183735, 70.5091381072998, 80.04931354522705, 86.27885995592389, 91.14177908216203, 98.90038776397705, 28.37489012309483, 0.4372014727975641, 0.10596492753497191, 0.17364876850375108, 0.11761075976703848, 0.11896806050624166, 0.11112325252699, 0.13235170234526905, 0.12042396595435483, 0.14721256920269557, 0.12377998658588954, 0.10200755524316005, 0.14636397973767348, 0.147805744515998, 0.22496182577950613, 0.09619590280843632, 0.12718069553375244, 0.11468180907624108, 0.15548513244305337, 0.1494017131626606, 0.24078683661563055, 0.15139504548694405, 0.16805214381643704, 0.0742287454860551, 0.1516358032822609, 0.17535217638526643, 0.10116003107811723, 0.18770976471049444, 0.24160029153738702, 0.13617836843643868, 0.1970257791025298, 0.16549086411084446], [0.15173918487770216, 0.0947717053017446, 0.13009968533047608, 0.02796750356044088, 0.009899126182842468, 0.025908456815938865, 0.041646705075566254, 0.0977336395797985, 0.10186620961342539, 0.07092690587575946, 0.14440397705350602, 0.03701832950381296, 0.04567902834553804, 0.06851838475891522, 0.025384544661002498, 0.012094963042597686, 0.029294670559465885, 0.036906917446425984, 0.10451779554464988, 0.04725223553500005, 0.03181125855605517, 0.03428384355668511, 0.04025897204077669, 0.010127555845039231, 0.03323974779673985, 0.025185184287173406, 0.41544522451502935, 60.05248137882778, 108.3329495021275, 110.45684705461774, 88.20545646122524, 63.276112011500764, 45.885597773960654, 19.02325405393328, 33.02377346583775, 76.36471162523542, 56.55013765607561, 29.51987682070051, 33.31237384251186, 23.98743622643607, 2.914695050035204, 0.998077026435307, 0.2886768882828099, 0.09364606320325818, 0.08371815271675587, 0.14912356808781624, 0.25257111713290215, 2.5619241510118758, 2.236234073128019, 7.243780604430607, 94.40508392878941, 98.54127011980329, 91.52991935185024, 98.61836038316999, 96.2251228604998, 90.49579811096191, 94.86434595925468, 94.15212086268834, 93.83851391928536, 93.4155353818621, 95.21175588880266, 90.96143163953508, 86.75310925074986, 80.54920864105225, 80.66792556217739, 86.27826935904366, 91.18624755314418, 88.27947562081474, 81.67549078805106, 64.96196038382394, 69.03474426269531, 73.02985422951835, 83.10370690482003, 87.27646146501813, 88.63330568586076, 84.53218705313546, 83.20207950047084, 75.77316978999546, 88.20562321799142, 89.90763310023716, 99.97434997558594, 84.67279079982212, 80.9141627720424, 73.72661958421979, 98.19246360233852, 59.82507378714425, 35.604000908987864, 56.31044912338257, 39.30178703580584, 84.2305657523019, 78.95874513898576, 89.1045811516898, 85.82971450260708, 93.55076122283936, 88.3200878415789, 88.7621044431414, 85.89538192749023, 88.54071399143764, 86.83740479605538, 86.22871480669293, 83.43882547106061, 91.21248395102364, 87.63523864746094, 86.98082256317139, 86.67910398755754, 87.84542165483747, 79.5436931337629, 72.57959706442696, 70.43462562561035, 79.32071154458183, 81.68327971867153, 80.41004317147392, 73.32589612688336, 69.6475475856236, 66.95615591321672, 75.57431929452079, 66.25242151532854, 67.31115327562604, 75.19639982495988, 89.01517868041992, 81.10767010280064, 101.23757416861397, 5.787525900772639, 0.41309339499899317, 0.1328679317874568, 0.01756801293231547, 0.2337406575679779, 0.08156146308673279, 0.02409460548577564, 0.20598124712705612, 5.243894066129412, 22.673495394842966, 29.894085952213832, 34.441119125911165, 52.312181200299946, 63.06386538914272, 57.59808928625924, 28.183585371289933, 20.329332998820714, 21.06833471570696, 56.51450729370117, 71.84877164023263, 70.89300523485456, 73.70412131718227, 86.91469655718122, 14.130622693470546, 0.5820448419877461, 0.01469305666562702, 0.07496870827994176, 0.05323453952691384, 0.05924932499017034, 0.05651949718594551, 0.06026999093592167, 0.013562149983564658, 0.024143088509195616, 0.03822816762008837, 0.08043844013341836, 0.08671305701136589, 0.01331734303052404, 0.03529707954398223, 0.02628017356619239, 0.05545250426179596, 0.03710659333903875, 0.04922487593388983, 0.052603535886321745, 0.003822571556416473, 0.1380897473011698, 0.03223048123930182, 0.05673062335699797, 0.11894345682646547, 0.06922978122851678, 0.0412327071119632, 0.0128654225928975, 0.032939750501619916, 0.03482370976624744, 0.0684140667851482, 0.046824337781539986, 0.08651194601718869, 0.061649479770234654, 0.05123465933970042, 0.015331568296200462, 0.06726061832159758, 0.06710708620292799, 0.06970774129565273, 0.09320915450475045, 0.06967844215354749, 0.09997990261763334, 0.04132501840857523, 0.04586732181321297, 0.038628934150827784, 0.08449475640164954, 0.06229041037814958, 0.0382417077863855, 0.03206601792148181, 0.11875250350151743, 0.044584771884339194, 0.029519017985356704, 0.04197058001799243, 0.07476472708263568, 0.013317672968176859, 0.0787258381024003, 0.06973292851554495, 0.2817527912557125, 72.00902489253453, 127.6291948046003, 116.34317329951695, 103.51437377929688, 73.13778059823173, 63.278557777404785, 34.379353114536826, 39.235619340624126, 32.964706829616, 60.34960719517299, 32.26665258407593, 40.61243268421718, 33.26783241544451, 4.683662116527557, 1.1551087030342646, 0.24663461425474711, 0.05337617353403142, 0.08505259361118078, 0.6662707424589566, 1.9968668946198054, 3.5403210563319067, 1.1698067486286163, 9.669004593576703, 104.54724434443882, 105.64310032980782, 94.38066101074219, 104.62625925881522, 99.04402092524937, 94.70029899052211, 100.41952105930874, 97.19032491956438, 96.1594762802124, 96.61660521371024, 100.7541949408395, 95.4000242778233, 91.12073993682861, 86.08574867248535, 83.95337431771415, 89.50538103921073, 94.98174967084611, 91.44601290566581, 86.11862754821777, 68.24270520891461, 71.52463122776577, 76.29443059648786, 87.37725898197719, 89.624758039202, 91.83427129473004, 88.19399888174874, 86.75675705501011, 77.92311613900321, 92.64520944867814, 93.59615380423409, 102.51593153817313, 89.08085305350167, 85.20471014295305, 78.29706818716866, 104.94881548200334, 65.31529712677002, 39.439013957977295, 62.67744132450649, 41.4776223727635, 86.54191875457764, 81.7123509815761, 92.0119992664882, 85.96910231454032, 98.22999777112688, 91.23159844534737, 92.26621300833565, 87.93337890080043, 91.63141863686698, 90.43565450395856, 89.89994839259556, 86.5390213557652, 93.59220722743443, 89.6674199785505, 91.69914967673165, 88.55278996058873, 91.73788588387626, 83.04681505475725, 76.4581857408796, 74.40793909345354, 82.07606833321708, 83.60727064950126, 85.54952144622803, 78.73949473244804, 73.94802393232072, 70.1959480558123, 78.44796916416713, 70.50124495370048, 72.19652203151158, 75.48714024680001, 96.19219534737724, 82.7026777267456, 110.76295689174107, 10.542592917169843, 0.3656956883413451, 0.19443491527012416, 0.19824407515781267, 0.31714439072779244, 0.11606520627226148, 0.024984288727864623, 0.217928036781294, 5.1191330807549615, 27.746825081961497, 32.68139403206961, 32.81124544143677, 48.03197622299194, 40.54636921201433, 24.364879744393484, 29.003339052200317, 32.406811646052766, 41.00391503742763, 65.51270934513637, 84.01558153969901, 81.50592000143868, 81.79427719116211, 104.1590484891619, 21.910454647881643, 0.5133549507175172, 0.04035930362130914, 0.09548869289989982, 0.08513038765106883, 0.10125769940870148, 0.06642954184540681, 0.11587293658937727, 0.06518594321927854, 0.04991770429270608, 0.07602147571742535, 0.05967226265264409, 0.06124331549342189, 0.0665979270956346, 0.033393592041518004, 0.05221184815413185, 0.017958382610231638, 0.040506220023546896, 0.012850737398756402, 0.05046005733311176, 0.024192004098689983, 0.07311769189046961, 0.04386086662166885, 0.0570118964782783, 0.034003540740481446, 0.04311480040528944, 0.04293838130044086, 0.030838100239634514, 0.01692506537905761, 0.03403578811724271, 0.0448414107917675, 0.14696710237434932, 0.1426643625433956, 0.17408479510673455, 0.13936764587249073, 0.07420415537697927, 0.09622852677213294, 0.26265235617756844, 0.20593304399933132, 0.15333785409373896, 0.0873696617782116, 0.2037299493593829, 0.09145147739244358, 0.163467513397336, 0.14923376217484474, 0.12906430874552044, 0.12350793475551264, 0.15419975641582692, 0.13467814108090742, 0.1383097962077175, 0.17537276313773223, 0.0750219054254038, 0.10862527335328714, 0.11309655449752297, 0.23808757002864564, 0.19892358726688794, 0.145741003166352, 0.8307311832904816, 112.75025285993303, 136.49884823390414, 135.47697666713168, 115.80602196284703, 87.55480630057198, 64.68314307076591, 28.6474940095629, 49.37381928307669, 110.77594307490757, 78.40431363242013, 44.7917810848781, 55.24860804421561, 41.346443857465474, 6.351448646613529, 1.6694230479853494, 0.6960327540125165, 0.17414055711456708, 0.35169949222888264, 0.3636851619396891, 1.3544845474617822, 6.049239354474204, 6.4097683514867505, 9.740583198411123, 110.19988182612828, 105.05727686200822, 97.91635608673096, 108.24413067953927, 104.79772690364292, 94.77206693376813, 104.32526329585484, 103.45169407980782, 101.23438494546073, 100.02375166756767, 104.19620050702775, 98.68607752663749, 95.44001116071428, 88.6476606641497, 87.81947013310024, 95.04421397617885, 100.71044213431222, 95.61304909842355, 90.72996629987443, 71.92329107012067, 74.40851579393659, 79.43036106654576, 92.60030324118478, 95.69940825871059, 96.24580764770508, 93.51435961042131, 92.71586568014962, 83.86293656485421, 97.98166915348598, 98.04136112758091, 104.76296506609235, 92.11301217760358, 90.08864062173026, 83.10433224269322, 111.28172329493931, 66.47773769923619, 48.009363310677664, 72.84724167415074, 48.8956755229405, 85.65094430106026, 87.45960208347866, 97.39886120387486, 94.69504615238735, 101.12232439858573, 96.80964006696428, 98.12813717978341, 93.79403155190604, 96.7692779813494, 94.88207081386021, 92.82093633924211, 93.09391716548375, 97.27164663587297, 93.94185447692871, 94.83380862644741, 94.25184140886579, 97.49597617558071, 89.09822354997907, 80.30074105943952, 78.88476072038922, 84.79520416259766, 88.70840876443046, 89.91806234632219, 81.80333069392613, 76.8779958997454, 74.4820624760219, 83.79304463522774, 72.93949290684291, 73.99639729091099, 84.71980231148856, 98.8859702519008, 86.93216432843889, 115.46446936471122, 9.302231771605355, 0.8901069057839257, 0.3186408318579197, 0.1738906798085996, 0.4694666000349181, 0.2816267194492476, 0.11994383457515921, 0.31131189369729584, 8.880827001162938, 37.74423367636544, 47.77363872528076, 48.01238577706473, 74.28925691332135, 95.28023733411516, 81.15609209878104, 42.063192231314524, 28.958762884140015, 32.25618164879935, 70.22472749437604, 90.95752675192696, 91.07629231044224, 88.07130759102958, 117.01002665928432, 31.17531292779105, 0.5940389526741845, 0.08827693773699657, 0.10043559995080743, 0.1688881939543145, 0.1568306131022317, 0.21050822921097279, 0.19019435638827936, 0.13756652894829, 0.1434097604027816, 0.09309831580945424, 0.10892300773411989, 0.13325727518115724, 0.1406958917421954, 0.1418690923601389, 0.14607576520315238, 0.09481780497091157, 0.10268925902034555, 0.14862480413700851, 0.1615016617413078, 0.09553036173539502, 0.1619750756238188, 0.16110640152224473, 0.16098062827118806, 0.1555020958185196, 0.08832797714109931, 0.14850283068205627, 0.09927310661545821, 0.09340177702584437, 0.08564352975892169, 0.17187434514718397], [0.10826868284493685, 0.0456976235977241, 0.07961857305573565, 0.011779384887112039, 0.09210502196635519, 0.05259239434131554, 0.009307033981063535, 0.09332894307694264, 0.035317299887537956, 0.1180240690175976, 0.06355329975485802, 0.07680354160921914, 0.021481892825769525, 0.04213304505018251, 0.08797298797539302, 0.02621055587327906, 0.05242253327742219, 0.02334338240325451, 0.03899580446471061, 0.0901672752307994, 0.08404456877282687, 0.036233593576720784, 0.029014120077980415, 0.03530068595760635, 0.18416612914630345, 0.45899561047554016, 48.68471084322248, 103.11759689876011, 99.0513026373727, 86.12082317897251, 76.68883119310651, 62.33424200330462, 32.519309929439, 60.538639886038645, 51.9495165007455, 72.03651196616036, 38.31927006585257, 37.736958912440706, 19.8940144606999, 1.1981088242360523, 0.33789312307323727, 0.2876470078315054, 0.2343792404447283, 0.10727095138281584, 0.38812965740050587, 1.4668249764612742, 16.19331530162266, 0.11292065786463873, 12.284780757767813, 90.46213408878872, 97.5713085447039, 94.78542831965855, 96.15689849853516, 93.58812168666294, 91.61003902980259, 98.9093370437622, 88.57193224770683, 94.48068032945905, 93.62434264591762, 90.96737234933036, 87.35792214529855, 86.32057694026402, 86.6750601359776, 85.92563438415527, 74.17118617466518, 74.37826333727155, 80.61971896035331, 87.09869180406842, 74.74518380846295, 64.20502362932477, 68.03632286616734, 76.03358827318463, 83.59997504098075, 89.5155393055507, 89.31315912519182, 85.04303250994, 74.69501781463623, 79.20721966879708, 88.714293888637, 88.09475081307548, 86.28589848109654, 89.10001618521554, 82.13588537488664, 74.62900992802211, 81.36283574785504, 96.91374492645264, 37.18100922448294, 24.200924839292252, 54.24074057170323, 86.06786400931222, 84.59221948896135, 86.8211807523455, 86.77312006269182, 85.40101759774345, 87.95511981419155, 84.31483350481305, 84.19109998430524, 87.68611335754395, 88.71537780761719, 87.2206882749285, 83.23058101109096, 84.20829677581787, 90.26720932551792, 91.11527170453752, 88.50145666939872, 86.79440934317452, 77.39997931889125, 69.38894258226667, 70.87159783499581, 82.00213255201066, 82.0256313596453, 80.09048162187848, 79.67853682381767, 78.03505856650216, 71.00816467830113, 71.80524812425885, 69.546708379473, 75.56049932752336, 66.71515764508928, 78.9896993637085, 85.55289827074323, 94.2713588987078, 63.752584729875835, 0.4042803379041808, 0.3379725659532206, 0.02768400145162429, 0.04321478254028729, 0.029523347038775682, 0.06752541661262512, 0.03811863171202796, 0.40580818163497107, 2.223818293639592, 16.97711205482483, 43.52081312452044, 39.40161180496216, 49.17645917619978, 88.65902096884591, 70.75982216426304, 37.21891164779663, 18.193324736186437, 23.43871440206255, 28.016656637191772, 60.14186300550188, 69.91407353537423, 70.93633420126778, 72.88337230682373, 7.071803135531289, 0.37508118471929003, 0.026416816948247806, 0.06791737236614738, 0.044684672595134804, 0.018229094333946705, 0.07693626305886678, 0.02529507133710597, 0.06390251458755561, 0.009010746576158064, 0.0034660064931293683, 0.045474979294730086, 0.009829105609761817, 0.031017701673720564, 0.07188755539911133, 0.04700051261378186, 0.015705826160098826, 0.0820253910496831, 0.035465800669044256, 0.12289951954569135, 0.056220948563090394, 0.05220476085586207, 0.09893571864813566, 0.03657294251024723, 0.024750467256775925, 0.01635605439410678, 0.0254049024078995, 0.06839738160903965, 0.05079587449186614, 0.06572391970881394, 0.04310070044760193, 0.004274235422989088, 0.08807329580719982, 0.04449373623356223, 0.03732160073039787, 0.036270054655947855, 0.022006159515253136, 0.09643229762358324, 0.014461898444486516, 0.04023966093414596, 0.08216552210173436, 0.07121153096003191, 0.06460021143513066, 0.03020147154373782, 0.1062003927571433, 0.03146985026874712, 0.09459052288106509, 0.029319114783512693, 0.0498227093900953, 0.07515086100569793, 0.038824840781411955, 0.04425685965855207, 0.027331653483478085, 0.09647295544190065, 0.10124749424202101, 0.3051959318774087, 62.626483236040386, 124.78336552211216, 107.46211092812675, 112.40359333583287, 97.61779199327741, 92.05845492226737, 51.752399580819265, 33.64873266220093, 22.494851997920446, 64.62836347307477, 44.30039753232683, 45.17385557719639, 28.78057633127485, 1.6160759734255927, 0.4459953137806484, 0.08978861876364265, 0.1740494705736637, 0.051231877346123965, 1.4670860767364502, 3.614392761673246, 12.598082848957606, 0.5582149092640195, 16.013532400131226, 104.80147198268345, 104.86818163735526, 99.89019339425224, 100.69376645769391, 96.65500095912388, 98.66521903446743, 101.00339208330426, 93.2691090447562, 95.35428428649902, 98.7324914932251, 97.55683544703892, 89.57869843074253, 90.47386959620884, 91.63412148611886, 90.52190944126674, 78.3219427381243, 78.9802359172276, 84.24251665387834, 90.11874716622489, 78.73615959712437, 67.79799270629883, 70.67898682185582, 80.30199868338448, 87.06108120509556, 93.54679380144391, 91.55997031075614, 92.91720363071987, 78.08079160962785, 84.93257004874093, 91.02743952614921, 91.18612943376813, 89.07801818847656, 91.25814751216343, 84.76290198734829, 78.22665514264787, 83.67165960584367, 101.10769844055176, 42.47387593133109, 27.848416430609568, 57.474776131766184, 88.35471766335624, 88.1100160053798, 91.48258127485002, 90.62921742030552, 87.88530431474958, 89.00970349993024, 87.81760801587785, 87.65236595698765, 90.96453748430524, 91.8250788279942, 88.86067853655133, 88.713376726423, 88.21680981772286, 95.26643821171352, 92.10682133265904, 91.17364352090019, 90.22786167689732, 81.31586592538017, 71.60149914877755, 72.62678228105817, 86.15892710004533, 87.53681741441999, 84.70261246817452, 83.67463343484062, 81.68628828866142, 76.23151465824672, 73.89056927817208, 72.74890381949288, 78.07977022443498, 71.42016506195068, 81.78692599705288, 88.73612512860979, 95.51498917170933, 74.85447897229875, 1.2853567025491168, 0.3650614209473133, 0.2518555612436363, 0.07647782444421734, 0.22200255814407552, 0.11382182700825588, 0.053658722301146815, 0.46469807305506294, 1.813160540802138, 21.88938249860491, 46.74831737790789, 37.90860373633248, 48.16949149540493, 58.637056895664756, 37.60923365184239, 25.69818867955889, 24.852843046188354, 46.29315825871059, 57.82713317871094, 73.37266445159912, 84.93055507114956, 75.46828283582414, 93.15463052477155, 13.995192749159676, 0.436749487050942, 0.05351602977940014, 0.037807520013302565, 0.0586825039769922, 0.057012744647051604, 0.03695528342255524, 0.013592954625242522, 0.009799952352685588, 0.04724264783518655, 0.028052622385855232, 0.06760982636894498, 0.020240345071735125, 0.05272954662463494, 0.09683169012090989, 0.012145731880861734, 0.09777200394975287, 0.09558880395655121, 0.025099383534065316, 0.012951668634611582, 0.06858217383601836, 0.05058909433760813, 0.050806035553770404, 0.053892250305839946, 0.028537381373878037, 0.03199891420081258, 0.0918530954846314, 0.06722494095031704, 0.06893187721392938, 0.04939002457207867, 0.15145603221442017, 0.12639687902161054, 0.18756382539868355, 0.10595461380268846, 0.26162996675286976, 0.12675837533814566, 0.09219769627920218, 0.11662885174155235, 0.12230304655219827, 0.190097448016916, 0.15342747499900206, 0.15098989222730907, 0.11386372654565743, 0.10097002091684512, 0.2958232733820166, 0.12783473543822765, 0.19496919374380792, 0.19778843889279024, 0.18314935799155915, 0.21222085159804138, 0.160827333639775, 0.11893303452857903, 0.11821954138576984, 0.14460368348019464, 0.282050152442285, 0.5525989191872733, 94.65433665684291, 136.15521812438965, 122.52948107038225, 111.2951055254255, 97.37051950182233, 84.18315124511719, 48.56962782996041, 85.38300091879708, 74.87713009970528, 98.4047519138881, 66.79306779588971, 63.83810315813337, 38.55204166684832, 2.543859051806586, 0.6931260728410312, 0.7258575707674026, 0.41251156479120255, 0.3490906336477825, 0.7040655772600855, 3.0579124050480977, 28.606023686272756, 2.3244062789848874, 15.10331664766584, 113.95366695949009, 106.66979394640241, 102.75885445731026, 102.76940182277134, 100.81909806387765, 99.44172191619873, 105.30750233786446, 95.57614026750836, 99.07623277391706, 103.04088878631592, 102.30639471326555, 95.64723423549107, 96.00266238621303, 94.69989599500383, 96.95705304827008, 84.38487134660993, 84.67285333360944, 87.525283404759, 95.28542069026402, 82.88280977521623, 71.83382606506348, 75.87965788160051, 85.12288815634591, 91.69716249193463, 97.5606916972569, 96.7918735231672, 97.3351948601859, 81.35504681723458, 88.18892669677734, 95.79990005493164, 93.19980771200997, 91.60404968261719, 95.66741875239781, 88.98609352111816, 82.21273939950126, 87.19741180964878, 102.74249839782715, 45.910725934164866, 38.744412967136924, 60.7106078011649, 89.80823911939348, 94.17558492933, 95.05257265908378, 95.41045352390834, 92.17478166307721, 91.41426658630371, 91.03378323146275, 90.97893415178571, 93.91658387865338, 96.02385439191545, 92.8561567578997, 94.83964511326381, 93.51992511749268, 99.18515968322754, 96.3284912109375, 94.46498434884208, 94.62812805175781, 84.20754637037004, 77.1257130759103, 77.28748103550502, 91.61451366969517, 89.68122604915074, 86.05421079908098, 87.38661125728062, 85.95298944200788, 80.39884962354387, 78.00821072714669, 77.51140063149589, 83.63672406332833, 72.92638165610177, 88.03298132760185, 93.12546198708671, 101.99970122746059, 75.20827429635185, 0.9649936131068638, 2.0159436081136977, 0.2484529252563204, 0.13058620850954736, 0.31629771473152296, 0.32092350508485523, 0.19912850484251976, 0.9703719530786786, 4.083832383155823, 28.008768694741384, 67.30066844395229, 49.94778912408011, 69.94234575544084, 121.10764339991978, 96.67777715410504, 52.63715192249843, 25.674849680491857, 35.66033342906407, 45.22417443139212, 75.75214454105922, 92.50211824689592, 84.70199407849992, 107.33050509861538, 20.983240127563477, 0.6576216465660504, 0.19011875401650155, 0.10614447468625647, 0.10776086723698036, 0.19185614293175085, 0.17500442718820913, 0.2307576004947935, 0.15344415338976042, 0.13118276292724268, 0.11031129038227455, 0.26257424322622164, 0.12196623533964157, 0.12451824625687939, 0.1457748892051833, 0.19500512895839556, 0.1986153016665152, 0.1350553794098752, 0.20811586401292256, 0.1869286759091275, 0.18977266044488975, 0.14127546921372414, 0.12447347651634898, 0.09124738762953452, 0.10826699329274041, 0.08681655395776033, 0.23735825344920158, 0.10459095519036055, 0.15291416325739451, 0.12058510445058346], [0.138772204252226, 0.061444426487599096, 0.0290407865042133, 0.09116907111768212, 0.009551981730120522, 0.00519539208783369, 0.07957815272467476, 0.030720276026321307, 0.059657552013439794, 0.05531377777723329, 0.09923996696514742, 0.03569240761654718, 0.032025604375771115, 0.07013508943574769, 0.12122663216931479, 0.05241956129404051, 0.03760282974690199, 0.06079687337790217, 0.08573146789733853, 0.1277920284441539, 0.03611489405323352, 0.07183819876185485, 0.043455543728279214, 0.026846826641953418, 0.268099309610469, 58.66276523045131, 108.64917591639927, 99.69282286507743, 94.91184384482247, 76.630660874503, 54.67404760633196, 25.746384859085083, 24.929848194122314, 55.06554733003889, 80.01197392599923, 35.95998838969639, 27.466536487851823, 24.478984798703873, 1.4115529251950127, 0.31637172933135715, 0.0725157634754266, 0.3171526145722185, 0.10072140568601233, 0.11504074053040572, 1.5913955377680915, 7.387842382703509, 0.7128003856965474, 17.408629928316387, 91.17876434326172, 91.35261522020612, 101.13300377982003, 97.05637754712785, 94.9557773045131, 94.79915796007428, 89.84409182412284, 86.0109999520438, 94.90055997031075, 97.16084371294293, 90.59589385986328, 87.09511348179409, 86.30165004730225, 85.097763470241, 85.0567204611642, 84.01624161856515, 75.68257222856793, 67.84500421796525, 71.73873996734619, 73.95761244637626, 68.48767784663609, 60.94006511143276, 67.07917376926967, 78.39822006225586, 84.59624249594552, 86.11340250287736, 83.36001205444336, 80.09098884037563, 74.05248314993722, 78.46566622597831, 83.87180246625627, 85.98434666224888, 79.60275976998466, 80.83278547014508, 83.95176928383964, 77.2896419252668, 75.54903479984829, 83.85468210492814, 74.83628858838762, 13.782382454190936, 67.18347317831856, 80.43176324026925, 78.35546779632568, 80.8677418572562, 82.17141151428223, 84.49520874023438, 85.6972679410662, 83.20877061571393, 83.74632494790214, 81.97332532065255, 87.8497017451695, 87.23164558410645, 80.95929827008928, 78.90496608189174, 84.31884261540004, 84.62826674325126, 88.96688870021275, 83.46350547245571, 75.71098341260637, 62.298764501299175, 69.993574823652, 78.51561682564872, 81.72152260371617, 85.57141521998814, 81.77390507289341, 74.21065194266183, 71.6109903880528, 70.13995252336774, 75.35551357269287, 70.88698114667619, 73.49351446969169, 71.82582174028668, 81.71039853777204, 81.81298868996757, 93.6048251560756, 28.235827139445714, 0.531249004815306, 0.16244197557015078, 0.12424817574875695, 0.11030728024031435, 0.07661393178360802, 0.06499828757452113, 0.12487002595194749, 0.40422966490898815, 1.272204196878842, 19.126016174043926, 37.39326279503958, 46.84902456828526, 51.58014331545149, 90.0646276473999, 91.21549252101353, 54.5691819190979, 20.47581318446568, 18.15727400779724, 31.048105307987758, 59.84322248186384, 64.94340869358608, 69.11209160940987, 64.14028031485421, 2.7423534521034787, 0.2230779275830303, 0.05035845689209444, 0.11964738262551171, 0.023942087776958942, 0.10150758350001914, 0.07984379239912544, 0.0839932511693665, 0.023311219843370572, 0.024882303218224218, 0.02902188930394394, 0.07615675524409328, 0.03585682004424078, 0.038625246313001425, 0.06341244267033679, 0.045407570233302455, 0.05449383266802345, 0.1151713856628963, 0.01677251035081489, 0.07782886230519839, 0.034669309122754, 0.026279086213825003, 0.04111096096624221, 0.07528424741966383, 0.03690230001562408, 0.03304840431415609, 0.06967448629438877, 0.10954384013478245, 0.2130637685103076, 0.07225167764616863, 0.05842920006918056, 0.03214051428117922, 0.060535447405917306, 0.05223045697701829, 0.09156330674886703, 0.04408564152462142, 0.02924746148554342, 0.05147208892075079, 0.08451963149543319, 0.07267808940793787, 0.039753049545522244, 0.07849859672465495, 0.05620415821405394, 0.06129689940384456, 0.007741233849498842, 0.04190991898732526, 0.03821850188874772, 0.01648158676523183, 0.12141138368419238, 0.11010637959199292, 0.05226538795977831, 0.029160744710160152, 0.07224413233676127, 0.039566727222076485, 75.39470141274589, 129.8306759425572, 109.96280929020473, 116.63385118756975, 75.42823341914585, 68.21116038731166, 50.006748063223704, 29.486671379634313, 28.725411108561925, 57.008079528808594, 42.795403821127756, 32.57453073774065, 33.789791515895296, 1.6465631489242827, 0.2423064022191933, 0.035558997453855615, 0.2499880971653121, 0.057904461797858985, 0.31217689013906885, 3.9434318712779453, 3.371655923979623, 0.6478268035820552, 21.32872714315142, 102.30547755105155, 99.05764634268624, 105.59765216282436, 100.28713703155518, 99.21835122789655, 98.4591841016497, 95.0301855632237, 89.94353444235665, 96.2937571661813, 97.93936852046421, 94.40991987500871, 89.6680383682251, 90.47978251320976, 88.65153775896344, 89.47752571105957, 87.30568558829171, 80.12754331316266, 70.33958121708461, 75.56643308912004, 75.29363986424038, 71.6605588368007, 65.02320875440324, 73.36211708613804, 82.01682104383195, 89.61396053859166, 87.29581914629254, 86.10870552062988, 84.29231439317975, 75.93058817727226, 81.33872549874442, 89.88997077941895, 89.05015591212681, 82.1189317703247, 84.1648496900286, 88.77033111027309, 80.9415317262922, 80.7814382825579, 85.5583803994315, 78.7777237210955, 18.328891038894653, 65.90642207009452, 83.46500628335136, 83.5562778200422, 84.43234143938336, 88.54450075966972, 88.29633889879499, 90.47918496813092, 86.88002504621232, 85.16369492667062, 86.09910311017717, 91.8350008555821, 90.38453660692487, 85.01004941122872, 82.06420775822231, 86.6679243360247, 89.36230373382568, 90.44330447060722, 86.99804714747837, 79.7648126057216, 66.76451764787946, 74.03179141453334, 83.15670081547329, 85.10571915762765, 87.51434694017682, 85.23283645084926, 77.9221989767892, 75.29889270237514, 73.56845773969377, 79.39061042240688, 73.02571310315813, 77.2825825554984, 74.53841236659459, 84.92994362967355, 85.86847155434745, 99.16601739610944, 36.994964259011404, 0.7723112723657063, 0.8061710383210863, 0.5580809393099376, 0.3061058201960155, 0.09280953130551747, 0.08097878471016884, 0.038809689094445536, 0.3506028710731438, 0.6137122341564724, 24.36360822405134, 37.732157707214355, 43.88778918130057, 59.90657615661621, 70.56138161250523, 47.981633050101145, 24.880144255501882, 17.513735328401836, 26.47473325048174, 49.44369731630598, 68.70605972834996, 77.05265276772636, 76.32296684810093, 83.78251811436245, 7.773384026118687, 0.4373566401856286, 0.03735303047246166, 0.09714693070522376, 0.05281106921445046, 0.03498540466119136, 0.0057463387742505544, 0.05674848239868879, 0.019682602857106497, 0.01912246541386204, 0.02824654769418495, 0.04293965355360082, 0.016978298147608126, 0.032731460606945414, 0.023684644805533544, 0.11757353533591543, 0.03843181972791042, 0.048096991277166774, 0.057139121794274876, 0.11442813197416918, 0.06308727511870009, 0.06353857554495335, 0.08539998318467822, 0.13855630797999247, 0.054765870927699974, 0.02272383582645229, 0.10214178982589926, 0.09079489298164845, 0.09860180478010859, 0.19858759029635362, 0.12204843307180063, 0.10193368313567978, 0.18667009978422097, 0.15311006988797868, 0.3319014960101673, 0.14735006753887447, 0.10514291628663029, 0.16168150066265038, 0.11659877906952586, 0.1990049300449235, 0.15251975799245493, 0.10364139292921339, 0.1429463481264455, 0.22563455253839493, 0.1805758782263313, 0.1655784494110516, 0.15631198164607796, 0.11386417437876974, 0.28168740762131556, 0.17856768598513945, 0.17213851240064415, 0.18825751888964856, 0.11069528013467789, 0.3805174444402967, 100.96500328608921, 144.45008877345492, 127.36938776288713, 126.01739338466099, 98.88180133274624, 76.65384006500244, 37.67479337964739, 35.23737921033587, 85.70539038521903, 119.02845055716378, 54.72227505275181, 43.95676047461373, 40.34390565327236, 3.1948789869035994, 0.5645262077450752, 0.3331605855907713, 0.5665087785039629, 0.2374420389533043, 0.28175914234348703, 3.342717328241893, 15.611921310424805, 3.332670884472983, 19.787095580782207, 111.86587224687848, 99.11344037737165, 107.21533870697021, 102.57597092219761, 101.62558242252895, 99.57459926605225, 95.29959501538957, 90.16042246137346, 98.70084244864327, 104.02013315473283, 99.07555185045514, 93.7114313670567, 91.82141017913818, 92.52749306815011, 92.75691563742501, 92.22082042694092, 84.08607796260289, 75.2812442779541, 80.2760124206543, 81.44085012163434, 77.38473497118268, 70.10188334328788, 75.79583481379917, 85.5862704685756, 95.15355777740479, 90.07166617257255, 91.18428121294293, 90.02239649636405, 83.02714470454625, 85.9871050970895, 95.81726360321045, 95.05014078957694, 84.9703265598842, 86.94031456538609, 93.94949749537876, 85.5363129207066, 85.9704919542585, 91.37309156145368, 82.70504011426652, 24.867248398917063, 70.80935587201799, 85.17605577196393, 88.90707165854317, 87.91229111807687, 92.21217686789376, 91.57213660648891, 95.05640111650739, 88.62560708182198, 91.39461013248989, 89.93578025272915, 96.16049071720668, 93.76796885899135, 86.78930241721017, 85.71876566750663, 93.52980545588902, 91.74295806884766, 95.02780927930559, 91.64689922332764, 84.97956071581159, 68.27479199000767, 78.99520233699253, 87.31685829162598, 91.11247852870396, 93.86656379699707, 90.63228157588414, 82.0546053477696, 77.80447564806256, 78.44703810555595, 85.52022089276994, 78.80981050218854, 81.62401158469063, 77.76708044324602, 90.61645357949394, 89.47403076716832, 104.19766657693046, 36.65100411006382, 1.9115480099405562, 3.1024631687573025, 0.5111412980726787, 0.2834142249609743, 0.20065101528806345, 0.19421544990369252, 0.2940801169191088, 0.6068241809095655, 2.324020436831883, 31.00358819961548, 56.84777069091797, 54.593434606279644, 67.00447368621826, 122.4492015838623, 122.28543254307338, 74.95693710872105, 31.01158905029297, 25.424613782337733, 44.88601950236729, 72.29597854614258, 88.02526882716587, 83.34348923819405, 98.66366263798305, 10.400577817644391, 0.593300598008292, 0.10483558063528367, 0.25441879513008253, 0.1470078687582697, 0.17704197285430773, 0.23739983407514437, 0.13677592708596162, 0.1272464727184602, 0.10756472311913967, 0.08519847864019019, 0.10884298809937068, 0.13664737184132847, 0.2303522436746529, 0.2021035687731845, 0.1678567121603659, 0.1982005810631173, 0.2530565139438425, 0.20232581613319262, 0.208314946187394, 0.17385143334312098, 0.14993282966315746, 0.13782088458538055, 0.19357658204223427, 0.14287431484886579, 0.10440400522202253, 0.1378326096705028, 0.15890474537653582, 0.22974031365343503], [0.14605836756527424, 0.05382523140204804, 0.0733360308887703, 0.06560062989592552, 0.12626133486628532, 0.06296455527522735, 0.0858302286693028, 0.03802758588322571, 0.08925108332186937, 0.048644375654735734, 0.15412756028984273, 0.042600087488868406, 0.024788534767659645, 0.04646553524902888, 0.06581398166183915, 0.07032461783715657, 0.11846799376819815, 0.01759346986987761, 0.038981365239513774, 0.09587652994585888, 0.09426577602113996, 0.07570734793054205, 0.052056701122117896, 0.7808081050004277, 71.5810158593314, 102.0052250453404, 94.0081124986921, 91.12899439675468, 61.905385289873394, 60.73515578678676, 81.82458523341587, 68.72389575413295, 71.55478640965053, 63.953297342572895, 52.48198127746582, 35.54114055633545, 25.014284440449305, 1.662104749253818, 0.359916659870318, 0.1720341672854764, 0.11550826472895485, 0.20999547386808054, 0.4004585844065462, 0.2981849823679243, 6.124568249498095, 0.5854025046740259, 13.114911573273794, 98.50603580474854, 91.56004674094063, 98.7686846596854, 89.47883197239467, 96.56750229426792, 92.70162882123674, 95.01401710510254, 94.17065865652901, 92.98507363455636, 90.13378306797573, 89.91325419289726, 86.65705040522984, 83.49916362762451, 76.62977150508335, 83.73141411372593, 87.37885011945451, 86.22565065111432, 77.80519131251744, 66.11193588801792, 64.49711894989014, 65.97441019330705, 65.10553795950753, 63.95586122785296, 70.58074624197823, 80.56994206564767, 88.62003462655204, 80.23039749690464, 87.09065968649728, 81.78683567047119, 72.17668492453438, 73.09826619284493, 85.06434263501848, 79.16591957637242, 88.4646520614624, 81.79099764142717, 87.82506343296596, 75.81346239362443, 79.5539139338902, 76.69742611476353, 94.93813582829067, 32.60643686567034, 51.76853677204677, 92.8190255846296, 81.9216307231358, 88.06464426858085, 80.14029325757707, 87.98944391523088, 81.99626132420131, 88.38174615587506, 80.03248500823975, 83.49243082318986, 81.96837820325578, 90.6047111238752, 85.20470319475446, 81.16430486951555, 77.21419143676758, 84.9807905469622, 85.52344485691616, 84.18133081708635, 67.85185514177594, 63.973377636500764, 64.49579184395927, 80.00248268672398, 81.39164297921317, 82.75616495949882, 78.39559364318848, 76.64940711430141, 70.78008311135429, 69.56932476588658, 67.74365084511894, 74.54545783996582, 71.66044766562325, 71.76077270507812, 77.93629687173026, 83.98088918413434, 83.9052233014788, 71.26745755331856, 12.21092140674591, 1.2174267704997743, 0.3506338394113949, 0.19086522396121705, 0.14248748203473433, 0.04059527435206941, 0.10373794167701687, 0.09732897486537695, 0.20447709783911705, 1.3422509410551615, 18.986348697117396, 37.158879211970735, 48.921884128025596, 59.931874547685894, 99.2422877720424, 119.00862039838518, 105.78314822060722, 46.10774210521153, 25.93876658167158, 44.438586780003135, 53.640398842947825, 71.21920926230294, 75.68825585501534, 53.0284675189427, 1.496425713811602, 0.04442906845360994, 0.05397122160398534, 0.049881358564432175, 0.1390268855861255, 0.0593025628477335, 0.0949765821652753, 0.0939244254093085, 0.053334762541843314, 0.08228816730635506, 0.06762801110744476, 0.04791164265147277, 0.09779479594102927, 0.017623581557667682, 0.06552221160382032, 0.08242391502218586, 0.04956380756837981, 0.0866545605074082, 0.0869943912007979, 0.04628429176019771, 0.07860795621361051, 0.04659879274134125, 0.03306021082348057, 0.09295715338417462, 0.12323713142957006, 0.04654406210673707, 0.07722312730870076, 0.05867582040705851, 0.11868812409894806, 0.10243831641439881, 0.08647588188094751, 0.10511893685907125, 0.15265026741794177, 0.04295172129890748, 0.06386147678962775, 0.04106236428820661, 0.11051637080631085, 0.02228320366702974, 0.03947994937854154, 0.03762118072648134, 0.024755091472928013, 0.027456680346014242, 0.05755185429006815, 0.0815703451101269, 0.02355656453541347, 0.034560407644936016, 0.05561118306858199, 0.06179390594895397, 0.049371486995369196, 0.012139469002639609, 0.1102255235559174, 2.2280994696276526, 90.06687886374337, 120.4288877759661, 105.40243557521275, 110.75713430132184, 75.49148981911796, 92.60859939030239, 88.53133392333984, 42.81882619857788, 31.701447895595006, 58.93410628182547, 57.265558923993794, 43.45352329526629, 37.53208432878767, 2.154748639890126, 0.3403855450451374, 0.09467217778520924, 0.17424944841435977, 0.026444014328132783, 0.9409156079803194, 0.63803923449346, 1.1098127450261797, 1.1998314346585954, 16.914741550173076, 105.76674352373395, 98.00382695879254, 105.01572663443429, 92.25485270363944, 99.1412331717355, 97.11266490391323, 96.83750234331403, 96.33340358734131, 96.14293261936733, 91.99190507616315, 93.31763526371547, 88.85407079969133, 86.92244379861015, 82.46645981924874, 86.0835599899292, 90.01307201385498, 91.03101090022496, 80.99227442060197, 71.89390019008091, 68.00584806714738, 70.44506876809257, 67.43706158229283, 67.17612893240792, 73.5088005065918, 84.92995057787213, 93.21674047197614, 84.52184813363212, 89.2951146534511, 85.3931244441441, 76.28166675567627, 77.34786088126046, 88.20434474945068, 83.417160987854, 89.54193551199776, 84.40199170793805, 91.72542081560407, 77.91764790671212, 83.24084350040981, 80.99087088448661, 100.36403969355992, 38.54865442003523, 50.7266127041408, 96.44830594744, 85.43104771205357, 92.47532599312919, 83.24805573054722, 90.27349744524274, 85.24138273511613, 89.91053744724819, 82.38378320421491, 86.59711524418422, 85.90702710832868, 92.89944403512138, 89.5519687107631, 84.13682065691266, 81.37188230242047, 88.77716813768659, 88.54807908194405, 86.37001337323869, 69.76831422533307, 67.93040452684674, 67.63070092882428, 82.74060099465507, 86.59596879141671, 85.9821788242885, 81.0542106628418, 79.52287633078438, 75.54039124080113, 74.68761103493827, 71.38689013889858, 78.05784865788051, 75.43136010851178, 74.64794376918248, 81.32348115103585, 87.11928626469204, 84.67194311959403, 79.75068691798619, 16.734672035489762, 1.1197624568428313, 0.9919097402266094, 1.2990941596882684, 0.5015692859888077, 0.05396646507350462, 0.14147797120468958, 0.11772879771888256, 0.3534373018358435, 0.9870051805462156, 23.652333293642315, 33.11672299248831, 46.22498600823538, 72.47538798195976, 91.45046670096261, 83.78267097473145, 70.15241064344133, 28.493539299283707, 41.0877137865339, 61.859124183654785, 61.91156223842076, 82.35421861921037, 83.03705978393555, 75.45738806043352, 1.5099272578954697, 0.04626553365960717, 0.04912809309150491, 0.03575596259906888, 0.12311555152492863, 0.060808645960475714, 0.06111319961824587, 0.02900614050616111, 0.03291444453809943, 0.017798658859516894, 0.07837688111300979, 0.049134515425456424, 0.09548121544399432, 0.0455896822469575, 0.05262913361990026, 0.10108761103557688, 0.04280455383871283, 0.08356538055730717, 0.07038179119782788, 0.0968675846233964, 0.07355816968317543, 0.0401611238984125, 0.014349702679153, 0.03390458658603685, 0.11695897259882518, 0.047273633136813126, 0.03954314134482827, 0.01389652440723564, 0.3647213934787682, 0.14299171497779234, 0.1892653876649482, 0.22561928550047533, 0.2093139397246497, 0.20090370172900812, 0.15926687951598847, 0.13104392109172686, 0.3573928624391556, 0.19846069067716599, 0.22045678751809256, 0.08035493282867329, 0.12369759886392526, 0.09634826784687382, 0.10334921575018338, 0.16102877711611135, 0.3133725774075304, 0.12794739939272404, 0.23261236239756855, 0.23326356602566584, 0.20017097890377045, 0.11402284300753049, 0.17894581998033182, 3.3458023284162794, 115.51703943525041, 133.6694028036935, 119.18364552089146, 118.79140581403459, 84.78146062578473, 83.93879699707031, 98.05131789616176, 84.76666096278599, 101.24367468697685, 88.35516234806606, 71.91416808537075, 55.77576787131173, 50.84774759837559, 4.188894357000079, 0.8473809670124735, 0.5387734696269035, 0.5836616009473801, 0.4387503782553332, 0.7856543106692178, 0.7458365729876927, 12.770922763007027, 4.950321819101061, 16.118596111025127, 113.94286251068115, 99.76974637167794, 109.63999598366874, 95.68551186152867, 103.81641892024449, 98.93303040095738, 103.04854570116315, 100.28762340545654, 100.02284840175084, 96.45174530574253, 98.01651436941964, 92.90285560062954, 93.00495937892369, 85.37667110988072, 89.53889914921352, 94.99802235194615, 96.22893742152623, 85.22511005401611, 74.25020803724016, 69.76686900002616, 74.59439400264195, 71.48787525721959, 72.01805755070278, 78.65295491899762, 88.99646023341587, 96.99142578669957, 88.11472688402448, 92.28417410169328, 90.4876687186105, 79.20976270948137, 79.3218024117606, 91.95617049080985, 88.27305548531669, 93.20267036982945, 88.3679609298706, 96.72219698769706, 82.22665664127895, 84.09843185969761, 85.99667276654924, 102.85199505942208, 44.942501408713206, 54.962665353502544, 98.83544989994594, 89.41888291495187, 96.64912973131452, 88.49680137634277, 93.61708872658866, 88.963317326137, 93.21159880501884, 85.88722474234444, 90.45411586761475, 90.10193947383335, 98.69613851819719, 92.66293430328369, 90.10869312286377, 85.79254164014543, 92.28195762634277, 91.7111075265067, 88.77487523215157, 73.69752052852085, 70.9317067010062, 72.66978468213762, 87.96293653760637, 90.2009721483503, 89.24281556265694, 85.96387032100132, 83.53384208679199, 80.6168076651437, 78.852965763637, 74.46348299298967, 84.94598702022007, 79.70516232081822, 79.14530427115304, 86.50405802045549, 92.40922777993339, 91.06999029432023, 81.44543593270438, 16.38972176824297, 6.376871236733027, 3.2915190926619937, 1.3637398736817496, 0.4357002004981041, 0.18122340419462749, 0.2859803358358996, 0.3107129644070353, 0.34913357134376255, 2.795695641211101, 33.825918674468994, 52.22633968080793, 57.92482485089983, 69.6630768094744, 121.26661818368095, 145.27453422546387, 144.0177023751395, 62.895767620631624, 36.13651779719761, 59.22552762712751, 70.9426223209926, 95.72844478062221, 92.97670105525425, 92.13545485905239, 3.231392204761505, 0.10508347661899668, 0.21350466699472495, 0.17103720935327665, 0.27467607813222067, 0.1075039060254182, 0.2284990559731211, 0.18721370132906096, 0.14763719641736575, 0.12343837134540081, 0.17707298190465995, 0.150326759953584, 0.1577119350965534, 0.15102983079850674, 0.11624220891722611, 0.18142294777291162, 0.15826369263231754, 0.15758985307599815, 0.16698345116206578, 0.16087082773447037, 0.10720823439104216, 0.20836789906024933, 0.09518926218152046, 0.18220033177307673, 0.18469341870929512, 0.1724929248115846, 0.18554400306727203, 0.17346594402832644], [0.16351083107292652, 0.10060141355331455, 0.08277072105556726, 0.12376129973147597, 0.09205263227756534, 0.06912249127136809, 0.02940055255645088, 0.11083015254033463, 0.05869699069964034, 0.05895566860479968, 0.05539712901892407, 0.07161404471844435, 0.05466323572077921, 0.056838880226548226, 0.02472724948477532, 0.026843101484701037, 0.06262443281177964, 0.08061664378536598, 0.02768431188139532, 0.04713992441871336, 0.06230934829052005, 0.10909537598490715, 1.0100778681891305, 85.5787455695016, 105.68783283233643, 106.6871644428798, 99.65298189435686, 61.338224683489116, 69.35958644321987, 20.292068072727748, 30.022624152047293, 103.1817843573434, 62.621987751552034, 45.20609869275774, 36.24505908148629, 32.03522893360683, 5.806369849613734, 0.16649467524673256, 0.11077500799936907, 0.04908039886504412, 0.0594707445374557, 0.1541196892836264, 0.06391972902097873, 1.9868050345352717, 0.5488226275358881, 4.390323502676828, 99.16370364597866, 92.80345467158726, 103.32622350965227, 87.00291783469063, 91.908095904759, 83.52200930459159, 89.04942635127476, 89.53113106318882, 90.63328211648124, 87.36163248334611, 89.67108167920793, 83.42138549259731, 82.72207709721157, 75.02065208980015, 79.69320447104317, 80.00920159476144, 81.75330366407121, 78.11339950561523, 77.50190939222063, 64.62755748203823, 66.68878923143659, 60.24788556780134, 62.75669942583357, 62.05786350795201, 74.07705198015485, 80.4136631829398, 85.11209065573556, 78.67571026938302, 84.82023157392229, 77.66597720554897, 74.35705048697335, 67.52996594565255, 78.62295259748186, 75.77478872026715, 81.61086559295654, 81.61800139290946, 85.08872386387416, 77.10012980869838, 82.34016936165946, 68.00746699741909, 94.06235013689313, 51.725371088300435, 43.40614005497524, 88.60083675384521, 75.37013953072685, 81.82557187761579, 77.0248669215611, 83.5889413016183, 80.11933054242814, 84.81152548108781, 79.37355259486607, 81.57202516283307, 81.60322952270508, 83.6447422845023, 84.26896149771554, 78.94382040841239, 74.40925230298723, 72.71676840100969, 77.02875096457345, 71.21827125549316, 64.26497268676758, 63.66343934195382, 63.6899745123727, 77.62768568311418, 79.52425207410539, 83.79250267573765, 77.27455043792725, 70.55563545227051, 70.33284146445138, 68.66749722617013, 69.26231166294643, 66.8580265045166, 70.33668381827218, 72.75858266013009, 74.45328303745815, 78.32198442731584, 79.2071293422154, 83.04500157492501, 51.982541288648335, 6.3324935265949795, 1.1915110754115241, 0.7392992952040264, 0.23335807238306316, 0.045008540752210786, 0.09851702861487865, 0.16957392144416059, 0.07658647147140332, 0.35841028498751776, 4.746284927640643, 20.883361509868077, 49.7162959916251, 62.539040156773154, 81.9244794845581, 101.43607030596051, 92.86671801975795, 100.84470912388393, 28.578331640788488, 17.345239775521414, 32.423275402614046, 53.260561670575825, 67.64932210104806, 79.16120869772774, 24.611391408102854, 0.680182121694088, 0.05621239223650523, 0.08535253323082413, 0.02369203744456172, 0.06441691877054316, 0.06833522780133144, 0.03825851509879742, 0.01928888800154839, 0.10047420180801835, 0.05643595934712461, 0.07167452933000666, 0.05562703703929271, 0.07965427078306675, 0.12684748055679457, 0.06308283749967813, 0.05764868123722928, 0.06712507416627236, 0.029530298630041734, 0.06136340940637248, 0.07541302658085312, 0.046408724904592545, 0.05136997279311929, 0.024934419796669056, 0.03705353190058044, 0.10034807571875197, 0.10452761394636971, 0.011331583157048693, 0.05361124859856708, 0.03184460176687155, 0.059079786230410845, 0.07763961210314717, 0.04618428587647421, 0.09903720713087491, 0.047632727439382246, 0.11468836372452122, 0.0483956348949245, 0.06388591762099947, 0.03172046717788492, 0.03866905253380537, 0.087336820683309, 0.05145609585036125, 0.06935938820242882, 0.019536999420129826, 0.0636175705918244, 0.07032573741993733, 0.07929573287921292, 0.04903017709563885, 0.12925933328058037, 0.07584377418139152, 2.5598151556083133, 109.9180906840733, 121.86068916320801, 120.76358250209263, 123.32188143048967, 78.92637348175049, 95.28014005933488, 40.63836683545794, 63.05461038861956, 64.75398690359933, 58.876158305576865, 56.47203990391323, 41.724471024104524, 43.30188928331648, 5.421371468475886, 0.19795983683850082, 0.08570571749338082, 0.09260307345539331, 0.07230910885014705, 0.4731328604476792, 0.48665144933121546, 0.9690280194793428, 1.2468586883374622, 7.719960195677621, 106.04872921534947, 97.38168525695801, 106.5778067452567, 91.27804020472935, 94.86089270455497, 88.27482727595738, 91.12811197553361, 93.98353672027588, 94.78122465951103, 89.70288358415876, 92.53162029811314, 87.11147648947579, 85.19082069396973, 79.2112704685756, 84.91059289659772, 82.7809144428798, 86.95791435241699, 81.72039699554443, 80.90923649924142, 67.77355589185441, 68.32214396340507, 64.84263896942139, 66.04683126722063, 66.40669236864362, 77.59894098554338, 85.63194792611259, 90.26959950583321, 83.89572511400495, 87.98729692186627, 81.34774426051548, 76.85881887163434, 70.26361656188965, 84.19523416246686, 79.9905526297433, 87.15752220153809, 82.90019416809082, 88.40973349979946, 82.31089660099575, 85.03140122549874, 71.77865736825126, 95.98657730647496, 55.92466081891741, 45.43082080568586, 91.52211652483258, 78.07035541534424, 83.25489970615932, 81.9819758278983, 84.73196165902274, 83.31641905648368, 86.27737998962402, 82.9904373713902, 83.91924476623535, 84.95484597342355, 89.3828842980521, 85.45012746538434, 85.42882428850446, 76.3398996080671, 75.28860936846051, 79.69217613765171, 70.93787670135498, 66.25788279942104, 66.1522215434483, 66.81384290967668, 81.03524902888707, 83.08424500056675, 86.64810807364327, 82.7403369631086, 73.96022496904645, 71.58196776253837, 70.80080958775112, 73.95247772761753, 68.89413356781006, 74.24045276641846, 75.78658676147461, 78.38089125497001, 81.87178434644426, 83.65363597869873, 83.67671789441789, 58.46269185202462, 9.477542638778687, 0.13614107615181378, 0.814683124423027, 0.41282781639269417, 0.2586558392005307, 0.07542949462575571, 0.14974783387567314, 0.22510515951684543, 0.5223055332899094, 5.614750257560185, 25.53349552835737, 45.08452953611101, 52.72637374060494, 92.11344296591622, 112.66406740461076, 86.52893257141113, 66.999450138637, 19.77786316190447, 32.89756638663155, 42.27068281173706, 66.68713556017194, 75.2473509652274, 93.60802132742745, 43.82992805753435, 0.40906441690666334, 0.03963999882606523, 0.03252444975078106, 0.04692116812137621, 0.07199230763529028, 0.004688302936431552, 0.14873269120497362, 0.029183363675006797, 0.07166233605572156, 0.08225735503115825, 0.12466903030872345, 0.0460756015298622, 0.021727454649018388, 0.07863344198891095, 0.06560483681304113, 0.03963788179680705, 0.043131624681076834, 0.05342039366119674, 0.05205628043040633, 0.02750697505793401, 0.10264474033777203, 0.019288574179102267, 0.03687902965715953, 0.09897166064807347, 0.05618103713329349, 0.10302505921572447, 0.0517005550542048, 0.22573063309703553, 0.18029622680374555, 0.13961874454149178, 0.13673720987779753, 0.13359068014792033, 0.16585458602224076, 0.11656287099633898, 0.13981264270842075, 0.1622899565845728, 0.15525434911251068, 0.18948790643896374, 0.253415404685906, 0.16965704198394502, 0.19468211914811814, 0.11945625288145882, 0.17082276514598302, 0.11841580085456371, 0.17846766992339066, 0.1549583857080766, 0.08118005855275051, 0.1764548093612705, 0.29033167234488894, 3.8869464908327376, 130.11845643179757, 136.1928495679583, 133.53991617475236, 132.6740733555385, 84.10246876307896, 93.2346042905535, 33.00211593082973, 41.16421692711966, 135.6217771257673, 88.52058506011963, 66.79666696275983, 58.69064140319824, 58.39698273794991, 9.927494083132062, 0.394334507307836, 0.45419597945043017, 0.26275698627744404, 0.18486130184360913, 0.5352607209767614, 0.3630957321396896, 7.309434567178998, 5.059994791235242, 7.124810074056898, 112.01939269474575, 100.32511588505336, 113.0529511315482, 92.75311497279576, 98.94903210231236, 90.86148875100272, 96.65388229915074, 99.050600869315, 100.06116771697998, 93.55895314897809, 96.20525101252964, 90.18465082986015, 90.92970616476876, 84.15927028656006, 88.049149785723, 88.38550513131278, 91.20248549325126, 85.49431800842285, 86.24686350141252, 72.00874696459088, 74.2863039289202, 68.59409645625523, 69.47397463662284, 69.84439005170549, 80.68551840100969, 89.5130865914481, 92.60839094434465, 86.25299181256975, 93.09790543147496, 85.41130787985665, 80.20971270969936, 75.4268159866333, 89.40777969360352, 84.2116527557373, 90.0340347290039, 87.43976497650146, 93.2701860155378, 86.69154821123395, 89.31919016156877, 75.6748388835362, 100.10502474648612, 60.56377846854073, 49.19409370422363, 93.02995899745396, 83.12428052084786, 88.63946178981236, 86.15055452074323, 89.48337609427315, 86.85395540509904, 90.41624123709542, 86.21700709206718, 86.1814045224871, 88.90515395573208, 91.69274343763078, 89.35265268598283, 86.24094363621303, 79.72526345934186, 79.84154156276158, 84.79824747358049, 75.97548048836845, 70.66326304844448, 69.819105557033, 68.79073742457798, 83.97672721317836, 88.24934823172433, 92.23583548409599, 86.9175522668021, 77.609682900565, 75.83859402792794, 75.2445855821882, 78.2989580971854, 72.02000304630825, 79.45196996416364, 80.46860258919853, 82.98407976967948, 84.89359760284424, 86.8674418585641, 86.5117357798985, 60.08698613303048, 9.019519993237086, 5.07952834878649, 3.317461060626166, 0.6726788271750722, 0.1757931291524853, 0.18349697148161276, 0.33709028043917244, 0.36212746266807827, 0.8162520059517452, 9.838880232402257, 41.067588329315186, 65.81447655814034, 72.50343091147286, 85.97969136919293, 110.26461819240025, 101.05427374158586, 130.73531750270297, 39.61458451407296, 27.6399861063276, 48.75081253051758, 73.7245420728411, 87.57246167319161, 103.16107872554234, 54.64328098297119, 1.0115673882620675, 0.11204280318426234, 0.189809382760099, 0.10974320729396173, 0.21531597551490578, 0.15607825347355433, 0.23638547850506647, 0.11415671796670981, 0.14705101001475537, 0.1506472049014909, 0.18372809407966478, 0.13267878336565836, 0.15912106234048093, 0.17428374157420226, 0.10946648035730634, 0.10313852384154286, 0.19739663920232228, 0.12832157074340753, 0.13319191868816102, 0.13547749604497636, 0.18657747975417546, 0.13722389590527329, 0.11872032737093312, 0.12910682574978896, 0.18279352065707954, 0.1537139524838754, 0.1474865209311247], [0.07131809488471065, 0.051781768910586834, 0.11685392180723803, 0.034621207775282006, 0.08716464242232697, 0.10830035007425717, 0.023042906740946428, 0.047591665892728736, 0.11909040037010397, 0.046754465637994666, 0.056387841036277156, 0.07608388736844063, 0.029613113829067776, 0.03797087731904217, 0.029800538771918843, 0.048940386556621106, 0.03799432070393648, 0.13256312028637954, 0.03282377529623253, 0.07286634894886188, 0.21045315930885927, 0.06387489821229662, 55.40350423540388, 109.40615436008999, 100.75049155099052, 84.90019839150565, 65.65218748365129, 103.78315789358956, 26.448139020374843, 46.36076423100063, 40.465360164642334, 49.54015915734427, 52.784533636910574, 36.893134934561594, 20.480433736528667, 0.48225003693784985, 0.07229779088603598, 0.04240049980580807, 0.12271011328058583, 0.04479694639199546, 0.06423171263720308, 0.17317215193595203, 1.6370171925851276, 0.9529852803264345, 0.7092178836464882, 79.65523256574357, 98.8448508126395, 96.0773207800729, 88.49701677049909, 89.95843138013566, 82.50013078962053, 77.4366797038487, 79.52692713056291, 75.6486372266497, 80.21218626839774, 83.52945082528251, 77.87076841081891, 77.06089333125523, 72.2426928111485, 70.5260569708688, 71.36461421421596, 75.73043836866105, 79.71613352639335, 81.50653839111328, 72.62851933070591, 61.13492039271763, 64.05207293374198, 63.426651682172505, 62.3120425088065, 61.55707209450858, 73.02757522038051, 83.56716564723423, 82.56130273001534, 83.28668771471295, 87.07129505702427, 79.2609222957066, 72.24145603179932, 68.72778674534389, 73.4827378136771, 74.812484060015, 82.80314173017229, 81.42341014317104, 81.05683708190918, 76.78204127720424, 81.17307349613735, 72.33694512503487, 84.81244264330182, 67.15436717442104, 42.364431381225586, 85.40149702344621, 77.47494343348912, 78.49160385131836, 75.31202479771206, 82.31456524985177, 79.65179320744106, 84.15918690817696, 82.10738386426652, 80.99246202196393, 79.23968165261405, 81.1414383479527, 82.23629379272461, 83.09895433698381, 77.204179082598, 71.12502643040249, 67.64547279902867, 67.87442983899797, 62.120897565569194, 62.85660062517439, 64.9799701145717, 78.02624130249023, 76.74207523890904, 80.53144209725517, 76.03811155046735, 72.4213865825108, 67.50249971662248, 67.8791754586356, 66.10691234043666, 70.8946728025164, 68.83419145856584, 70.60585008348737, 72.6709589276995, 77.55753667013985, 80.20378589630127, 81.6428689956665, 69.38325895581926, 44.646330969674246, 2.6843461990356445, 1.0776314032929284, 0.6384695885436875, 0.08987401239573956, 0.10443403039659772, 0.04873414583770292, 0.15589878096112184, 0.10462713467755488, 0.4193565174937248, 1.4745273802961623, 12.622886180877686, 47.24141018731253, 36.20844554901123, 55.345747334616526, 95.93789822714669, 127.89464378356934, 96.86324541909354, 31.143490178244456, 22.462280579975673, 42.30451359067644, 73.53740624019078, 73.19015611921037, 71.6244421005249, 1.993022369486945, 0.18414247541555337, 0.06608253903687, 0.14572591254753725, 0.08330730654831443, 0.01012547274253198, 0.07264072926981108, 0.05724445078521967, 0.037806492032749314, 0.07450037662472044, 0.026145606501294032, 0.03625610736863954, 0.02012741139956883, 0.008902693267113395, 0.015342131390103271, 0.02456187184101769, 0.03902126649128539, 0.0832731355247753, 0.0507851027484451, 0.06618919117110116, 0.007996861739749355, 0.06160771593983684, 0.0869555857830814, 0.11615078310881342, 0.012012316629157534, 0.19987224707646029, 0.07335887037749801, 0.1382050168301378, 0.06416575224804026, 0.07300292447741542, 0.022619852031181966, 0.04983839372705136, 0.03641960038138287, 0.06044155851538692, 0.09768298694065639, 0.056480349108044586, 0.06134165557367461, 0.0382650527837021, 0.08213909316275801, 0.030816577108842984, 0.05743792826043708, 0.046310198227209706, 0.07379424558686358, 0.05515629319208009, 0.019052325248984352, 0.05085798758747322, 0.031194280234298537, 0.1381379911409957, 0.06548981155667986, 71.94935376303536, 127.01621082850865, 109.453172819955, 105.8798463003976, 78.3783551624843, 104.63691779545375, 43.0374755859375, 56.84654433386666, 9.123446805136544, 56.50736107145037, 49.441439151763916, 36.223036766052246, 28.218944753919327, 0.08787117379584483, 0.3058363603694098, 0.04354527659182038, 0.07693040730165583, 0.05605357772271548, 0.08628728985786438, 0.5034170725515911, 1.4195118695497513, 0.11977265376065459, 1.6239660871880395, 87.77862862178257, 101.72619233812604, 102.524172101702, 92.49185575757707, 94.86898735591343, 85.96144539969308, 79.86457484109062, 82.14974008287702, 80.75460433959961, 83.51132297515869, 87.46782875061035, 80.79883657182965, 79.7244644165039, 74.11346748897007, 74.01164858681815, 76.40596308026994, 79.39659976959229, 82.5695571899414, 85.23050880432129, 75.43393789018903, 64.89295782361711, 66.69699505397251, 65.92270169939313, 66.90592043740409, 65.70655713762555, 76.35643632071358, 86.25839056287492, 87.01719638279506, 85.06222343444824, 88.94389016287667, 83.01184477124895, 75.5081307547433, 73.1695477621896, 78.34206472124372, 77.97390052250454, 86.00999246324811, 86.01463385990688, 84.92668492453438, 80.96031270708356, 83.10974488939557, 77.5376787185669, 88.49878856113979, 73.28724329812187, 44.45294870649065, 87.03173896244594, 81.8739035470145, 81.44194098881313, 77.4063994543893, 84.27026775905064, 81.49742930276054, 85.88730117252895, 84.87852001190186, 84.82551220485142, 81.375168800354, 82.92581912449428, 85.12515326908657, 85.41146768842424, 82.32601588112968, 74.10789503370012, 69.1428165435791, 70.24935191018241, 64.46111338479179, 64.24876253945487, 67.84649808066231, 80.45404611315045, 79.73134313310895, 82.35624749319894, 78.49805177961076, 75.31351171221051, 71.80254527500698, 72.80234241485596, 68.80144459860665, 73.54965591430664, 73.49962193625313, 74.23970930916923, 76.82755197797502, 79.32154532841274, 83.92053018297467, 84.04274204799107, 70.95479556492397, 51.64650208609444, 5.809303726468768, 0.27100718500358717, 0.8095021567174366, 0.3504484365028994, 0.582743515925748, 0.06504320659275566, 0.20347609583820614, 0.08425464999995061, 0.4781946231211935, 1.3049873177494322, 16.141832624162944, 47.699980872017996, 36.79525566101074, 65.68344742911202, 94.49425016130719, 115.50731890542167, 54.50794397081648, 20.91580091203962, 31.453192234039307, 49.40710115432739, 81.91336931501115, 79.6977902821132, 95.47282750265938, 7.424067684582301, 0.48963884902851923, 0.1303608806005546, 0.1903777779745204, 0.009796908274958176, 0.04209413785221321, 0.07068289789770331, 0.06969558873346873, 0.06272738693015915, 0.07204339453684432, 0.008413730754650064, 0.08161630907229014, 0.03774075895281775, 0.022097040799313357, 0.045588789973407984, 0.09102431245680366, 0.03616669002388205, 0.028320397749277096, 0.01313684762655092, 0.03497402562892862, 0.022162807805995857, 0.08662625202643019, 0.06346342779163804, 0.05728695421878781, 0.046909415894853215, 0.16223495453596115, 0.017460290409092392, 0.23883292717593058, 0.09083356269236122, 0.19285672424095018, 0.11257389254335846, 0.1843442174472979, 0.22892124046172413, 0.12353394978812762, 0.11603738633649689, 0.21609498799911567, 0.13606437455330575, 0.1270819551178387, 0.1199158246495894, 0.10937168222985097, 0.08314318928335394, 0.08157030439802579, 0.18753213781331265, 0.1096857353778822, 0.1811401615185397, 0.1707014837967498, 0.14051445147820882, 0.2251045216939279, 0.2073863438729729, 89.27442986624581, 141.5775923047747, 124.935670035226, 113.32044288090297, 81.88219969613212, 126.23569188799176, 37.235507420131135, 64.85685498373849, 60.033269609723774, 74.55291325705392, 67.3815107345581, 60.2090242930821, 34.730608872004915, 2.0144280322960446, 1.0352108052798679, 0.2118144498339721, 0.23847061661737307, 0.2382961788347789, 0.34728885175926344, 0.5394867999213082, 6.237124289785113, 6.77823132276535, 1.7167817524501254, 91.990480695452, 105.88963631221226, 105.90042686462402, 95.33942208971295, 99.43798378535679, 92.56675733838762, 84.51516396658761, 88.56227425166539, 84.5911077771868, 88.60303933279855, 92.16225406101772, 85.25878797258649, 86.51828098297119, 78.19173349652971, 80.19720595223563, 81.1347541809082, 83.09406280517578, 88.91288035256522, 90.2347959790911, 79.12713473183769, 67.97904886518205, 69.32082939147949, 69.2374301637922, 68.95074054173061, 68.90873868124825, 80.67871611458915, 92.3879246030535, 90.97896889277867, 87.7423312323434, 96.88959298815045, 86.76105798993791, 78.96265002659389, 75.53965473175049, 81.05330739702497, 82.82055391584123, 92.50862870897565, 90.56785787854875, 86.4682400567191, 83.97359357561383, 87.05898979731968, 81.76408726828438, 91.35111440931047, 76.84811864580426, 49.364192553928916, 90.1505560193743, 86.26203836713518, 85.2277364730835, 83.40559918539864, 87.43271255493164, 83.94579383305141, 89.10886124202183, 88.6846945626395, 87.90065288543701, 85.78355067116874, 87.1492816380092, 89.27331815447126, 91.14453751700265, 85.74056911468506, 78.03252247401646, 73.04397991725376, 73.05066408429826, 68.18801593780518, 68.84097290039062, 73.07359313964844, 84.14606870923723, 83.30139010293144, 85.76854951041085, 83.80843489510673, 78.92110674721854, 75.7429312297276, 76.07495784759521, 73.91841070992606, 80.32602555411202, 77.17583738054547, 79.2093597139631, 82.64969771248954, 84.45693111419678, 88.43594210488456, 87.41889953613281, 72.06007330758231, 53.55045788628714, 4.378627947398594, 4.4362011551856995, 2.712933042219707, 0.8031733791743005, 0.33163521172744886, 0.16116041290972913, 0.3718307577073574, 0.15812664212925093, 0.6609617216246468, 5.718740471771785, 23.200233118874685, 66.88156005314418, 46.61935533796038, 63.446363721575054, 103.06789643423897, 132.49397604806083, 126.83058275495256, 41.04961333956037, 35.64546775817871, 56.90788650512695, 94.92095988137382, 90.0595624106271, 110.50066934313092, 11.78004537309919, 0.7927470643605504, 0.26105918309518267, 0.2987564988434315, 0.13721303934497492, 0.0905133280903101, 0.2848001191658633, 0.16583527491561004, 0.1689310637967927, 0.13681730415139878, 0.1116235296108893, 0.14231666762913975, 0.21686275037271635, 0.05798993006880794, 0.16957283578813076, 0.15494823482419762, 0.15528900868126325, 0.17152785802526133, 0.13526337753449166, 0.10548367657299552, 0.10535809331174407, 0.17518518891717705, 0.15614187291690282, 0.19317872981939996, 0.12514813031469071, 0.30284013971686363, 0.15743222939116613], [0.07984291708895139, 0.014234036207199097, 0.19141734790589127, 0.049752928848777495, 0.0672079436480999, 0.06674186472914048, 0.0339390018821827, 0.03098884018670235, 0.10550334730318614, 0.03935253407273974, 0.041620666294225624, 0.12846946423607214, 0.062158082478812764, 0.10067504817353827, 0.03937053560678448, 0.07101041996585471, 0.06098533647933176, 0.07747354744268314, 0.06823165621608496, 0.3648795464209148, 0.2839317029075963, 12.683446679796491, 109.12874058314732, 89.64294147491455, 105.04270648956299, 68.06536633627755, 103.88431671687535, 182.95949281964982, 86.94312163761684, 43.94265563147408, 109.64135783059257, 43.56393017087664, 46.22782782145909, 24.87552891458784, 0.18992334950183118, 0.31646078026720453, 0.22932420883859905, 0.20433894810932024, 0.09416829768036093, 0.07035101963473217, 0.26629161089658737, 1.2357410277639116, 0.5170368445771081, 1.4429378296647752, 53.12171581813267, 107.95676013401577, 95.10049438476562, 89.35263878958565, 84.5851114818028, 85.99947983877999, 77.17381545475551, 75.25850977216447, 66.19464029584611, 66.86503723689488, 72.06254686628068, 71.75544343675885, 70.26784106663295, 69.42105715615409, 64.20471790858677, 65.58883380889893, 69.46116910661969, 73.23832103184291, 71.0446149281093, 72.35679612840924, 70.60224396841866, 60.41144616263253, 64.18488774980817, 61.72603838784354, 63.0622673034668, 62.594806398664204, 67.28855078560966, 79.67003222874233, 83.3546758379255, 82.19946139199394, 81.8925108228411, 76.47921793801444, 70.41016101837158, 65.51355702536446, 71.03574207850865, 73.57296017238072, 76.44906275612968, 78.74556050981793, 78.91125420161656, 79.66786439078194, 78.19882065909249, 71.30333805084229, 80.87009729657854, 76.63863740648542, 43.460089342934744, 77.73859977722168, 78.10616643088204, 73.88783168792725, 69.16304969787598, 71.72760200500488, 76.58289895738874, 79.63419342041016, 81.72659478868756, 76.8304146357945, 78.12547547476632, 78.08291775839669, 82.55302742549351, 82.23973315102714, 81.46894863673619, 71.22942311423165, 63.79162665775844, 63.06412942068917, 62.10171358925955, 60.676339285714285, 64.75083242143903, 73.75140380859375, 77.30073819841657, 78.98129899161202, 74.06524004255022, 67.554826600211, 68.83515725816999, 69.38639259338379, 67.84970814841134, 66.85159247262138, 68.90405559539795, 69.49470111301967, 72.8972270148141, 76.6965228489467, 80.59971509660993, 79.16519696371896, 70.1610472542899, 72.70388644082206, 38.035675866263254, 0.94224770792893, 1.4497416360037667, 0.46441520537648884, 0.5673349627426693, 0.022324185485818555, 0.15674931103629725, 0.003406139348434018, 0.0786106703536851, 0.18201206544680254, 0.21491122937628201, 10.845947793551854, 38.65986728668213, 58.38503878457205, 101.59993662152971, 88.35330717904228, 89.11291898999895, 40.64257049560547, 34.52857610157558, 56.12146506990705, 66.13826261247907, 65.47946221487862, 81.96101311274937, 21.790919576372417, 1.8983538150787354, 0.14758976681956223, 0.11633406898805074, 0.083995307130473, 0.05592367558607033, 0.06772353526737009, 0.08088513330689498, 0.042251466374312124, 0.10702819190919399, 0.00868545688821801, 0.09633912119482245, 0.04670903093314596, 0.06778556693877492, 0.05875018784510238, 0.03984403430617281, 0.12204421258398465, 0.12044531266604151, 0.025825017364695668, 0.025566149469731108, 0.05750140521143164, 0.0321141192689538, 0.04904219055814402, 0.029339657431202273, 0.0535191646111863, 0.09779849395688091, 0.059995129970567565, 0.017913010669872165, 0.062211530682231696, 0.13305746018886566, 0.04408445408833878, 0.018869534700310657, 0.05975211265363863, 0.02586510351725987, 0.025129203451797366, 0.12444174821887698, 0.08413310402206012, 0.054921781311609914, 0.05416538439957159, 0.07472779442157064, 0.16077523572104319, 0.01793114112557045, 0.06728752902043716, 0.08479722017156226, 0.10499542991497687, 0.03155934903770685, 0.2549316861799785, 0.320305413965668, 19.11359974316188, 132.4511056627546, 98.4787849698748, 121.36540767124721, 73.47868701389858, 105.16795471736363, 175.9923951285226, 76.04766532352993, 17.76882628032139, 99.31330530984062, 49.01553889683315, 44.52718326023647, 35.41573599406651, 0.3396415449678898, 0.37297308498195236, 0.21669041604868003, 0.054453751604471884, 0.11196799469845635, 0.06345645245164633, 0.2544061472373349, 1.2658798162426268, 0.47657970977681025, 0.5321788149220603, 63.61307185036795, 110.78371116093227, 98.75928374699184, 92.37079034532819, 88.3034816469465, 88.94493934086391, 80.30013656616211, 77.18115970066616, 70.54039110456193, 70.81790215628487, 75.03364522116524, 75.66470146179199, 72.441223689488, 73.61221054622105, 67.01262392316545, 69.92265456063407, 72.60162285396031, 76.96732194083077, 74.56664984566825, 75.36098875318254, 73.36846773965019, 63.58971895490374, 66.64058262961251, 63.48764296940395, 65.43715463365827, 65.87931019919259, 70.51770523616246, 84.0741548538208, 85.27380997794015, 82.6972303390503, 84.90140042986188, 79.07211889539445, 71.65627874646867, 69.00528390066964, 73.31881591251918, 76.45183508736747, 81.10983099256242, 82.89640739985875, 83.21031311580113, 81.9166488647461, 81.46315383911133, 74.80901690891811, 84.51293359483991, 81.34094197409493, 47.07179076331002, 79.12823949541364, 79.29356493268693, 76.1617408479963, 73.22270842960903, 75.27043982914516, 78.4728089741298, 80.27255916595459, 83.83284391675676, 80.42022228240967, 80.88861424582345, 81.8380161012922, 84.37758268628801, 84.06636592320034, 84.31195000239781, 74.15300968715123, 64.58267906733921, 65.26416533333915, 64.58831405639648, 64.15891538347516, 68.09727941240583, 78.26662118094308, 80.74172237941197, 82.06032371520996, 78.2331795011248, 72.35073035103935, 70.99665846143449, 72.9150560923985, 72.6550545011248, 69.85179683140346, 71.35072476523263, 72.4990188053676, 76.43033041272844, 80.44622938973563, 83.7232916695731, 79.79900469098772, 73.38895797729492, 75.78072248186383, 45.02882235390799, 2.4969984463282993, 0.6852564236947468, 0.29104112141898697, 1.2520612605980463, 0.2120564425630229, 0.2358686248106616, 0.021196850442460606, 0.025276696608800973, 0.11656044184097222, 0.18483568036130496, 14.008607115064349, 39.969661780766074, 48.89955261775425, 102.27202892303467, 94.05671514783586, 83.40252113342285, 25.13072235243661, 35.452273096357075, 61.933761732918875, 74.31551415579659, 70.82742813655308, 93.25792939322335, 38.598087378910606, 1.8195417012487138, 0.1636839932096856, 0.08772021332489592, 0.06807531496243817, 0.21425877724375042, 0.013675099770937647, 0.07867836100714547, 0.020115535340404937, 0.054560668367360315, 0.028371803562289903, 0.10789571928658656, 0.049495122861117125, 0.043206626549363136, 0.01470776051948113, 0.051897401455789804, 0.06665467297924416, 0.0417722442320415, 0.011838665099016257, 0.06398938064064298, 0.03770239458286336, 0.03719182073005608, 0.05248069051387055, 0.0411857185619218, 0.061898495336728435, 0.08564450684934855, 0.08174194661634308, 0.17416087245302542, 0.13321464961128576, 0.16960079143089907, 0.159108183745827, 0.14892544943307126, 0.1836436843233449, 0.15731971471437387, 0.18061087706259318, 0.187522326196943, 0.1760184842028788, 0.13763640448451042, 0.21571310849062034, 0.14579540810414723, 0.2535965735358851, 0.08293090960276978, 0.20151480393750326, 0.22918082081845828, 0.1707002760044166, 0.2740505231278283, 0.6685834612165178, 0.7052448711224965, 25.31768795422145, 145.50432504926408, 112.54543386186872, 134.02221843174524, 91.19974790300641, 118.4871997833252, 183.43014989580428, 111.7362813949585, 61.866155760628835, 161.78282873971122, 63.880355153764995, 71.45967946733747, 44.07005432673863, 0.7860811363373483, 0.7162890327828271, 0.6019151700394494, 0.4641826035720961, 0.42868759536317413, 0.35949091985821724, 0.5246769860386848, 4.334720109190259, 6.616176315716334, 3.134908433471407, 66.30490125928605, 114.6610769544329, 103.35387734004429, 96.80702754429409, 93.81194400787354, 92.53076566968645, 83.33528341565813, 80.53590978894914, 75.0027048928397, 74.33181462969098, 80.64365550449916, 79.69653960636684, 78.09221444811139, 77.52886840275356, 71.14580849238804, 73.17892783028739, 76.74691118512834, 81.72229385375977, 80.34767614092145, 80.64195319584438, 80.15372412545341, 67.80641392299107, 71.3558247429984, 68.27602182115827, 68.89173643929618, 69.01871476854596, 73.2477844783238, 88.27093628474644, 89.93287590571812, 86.24048505510602, 89.72900881086076, 83.24986921037946, 76.44543579646519, 72.27042307172502, 78.1983551297869, 83.353987966265, 87.85965156555176, 87.07385894230434, 88.48141806466239, 86.4825325012207, 84.7209974016462, 77.48934704916817, 88.96030180794853, 84.49700832366943, 51.53722429275513, 80.92004094805036, 86.22702639443534, 79.96667167118618, 77.78798062460763, 79.48374407632011, 84.57347324916294, 86.26080158778599, 91.21328299386161, 82.45271628243583, 83.51163564409528, 84.45554842267717, 88.73493003845215, 88.5068415233067, 88.6430331638881, 76.29467378343854, 69.41860444205147, 69.58611161368233, 68.65658160618374, 65.88662665230888, 71.66085760934013, 81.53096825735909, 85.72082928248814, 85.87325191497803, 82.77343123299735, 76.29791859218052, 75.61359051295689, 76.38465295519147, 76.95882429395402, 72.63927514212472, 77.26383631569999, 75.85971655164445, 80.71157414572579, 84.41365078517369, 89.212646484375, 81.49620641980852, 74.86029461451939, 77.41106169564384, 46.113741874694824, 2.2724161658968245, 3.8283953240939548, 2.6563421360083987, 4.2891707590648105, 0.24979894874351366, 0.40518363086240633, 0.19260110652872495, 0.22711568591850145, 0.42382271641067093, 0.91800685439791, 18.746283224650792, 61.315010751996724, 72.58760833740234, 102.69898877825055, 91.27049446105957, 111.49877112252372, 61.28064496176583, 48.68242835998535, 71.62688786642892, 83.93046610695976, 84.15538624354771, 106.37805298396519, 51.56708765029907, 2.739839072738375, 0.3476644344627857, 0.17432859273893492, 0.22143381009144442, 0.32532575886164394, 0.17508248585675443, 0.20790676666157587, 0.1608409314815487, 0.21043588380728448, 0.08674975218517439, 0.1732736336333411, 0.16325172569070542, 0.134047198508467, 0.1800731923431158, 0.21438277273305825, 0.15711402360882076, 0.16054342101727212, 0.07118455919304065, 0.1394624507852963, 0.1308294361723321, 0.06987117324024439, 0.14463476038404874, 0.1195053652461086, 0.1301770926054035, 0.18987482067729744, 0.18996910990348884], [0.045693722021366866, 0.07910484062241656, 0.0486786789926035, 0.07139848092836992, 0.07917101814278535, 0.09210640617779323, 0.04313465773261019, 0.06337206305137702, 0.10088114640010254, 0.08115643874875136, 0.1493070846689599, 0.13767368319843495, 0.02703777657422636, 0.11571592358606202, 0.0895206584994282, 0.1438753575618778, 0.05156191338651946, 0.04516387777402997, 0.0915716120174953, 0.11937929343964372, 0.09670380662594523, 52.74684313365391, 106.20766925811768, 99.87466417040143, 88.05864102499825, 81.41827542441231, 48.64902489525931, 30.158819266727992, 46.704845973423545, 102.35695675441197, 22.195737259728567, 41.762925829206196, 29.083481311798096, 0.31114187996302334, 0.015520233261798109, 0.08567310710038457, 0.19355220906436443, 0.032315640776817284, 0.05277673873518195, 0.19461920538118907, 0.19217884061591967, 0.49102040060928887, 2.573954305478505, 22.201526846204484, 114.99743924822126, 90.50394139971051, 96.47256210872105, 81.54476043156215, 86.87284060886928, 81.30126776014055, 84.03990023476737, 72.7664897101266, 71.22003609793526, 65.14612933567592, 66.36416939326695, 64.63539505004883, 64.64177349635533, 61.651456424168174, 62.99104131971087, 61.148531913757324, 62.55180399758475, 66.66202477046421, 71.32186889648438, 69.84885079520089, 65.68941593170166, 60.031511715480256, 62.962296622140066, 61.751941272190635, 67.09104824066162, 63.469320569719585, 64.81407492501395, 76.91185447147915, 83.23983601161412, 81.27823448181152, 79.94175543103898, 73.261472429548, 65.87986605507987, 65.5071507862636, 67.4509162902832, 73.21124390193394, 77.77487632206508, 79.78447600773403, 78.68954413277763, 74.42743573869977, 77.78939805712018, 75.62531907217843, 74.35672392163957, 81.87434823172433, 42.15510647637503, 72.9282785143171, 82.33907849448067, 72.25704778943742, 71.75044768197196, 68.07011195591518, 74.04936340876988, 72.00498104095459, 77.72846930367606, 78.09850256783622, 81.80170481545585, 77.09303569793701, 80.00237846374512, 78.98359189714704, 81.37596784319196, 67.94997760227749, 64.11652442387172, 61.88620131356375, 59.863059588841026, 61.335236958095, 63.36160959516253, 70.0029548917498, 73.69872951507568, 71.4674267087664, 71.97065693991524, 71.21876457759312, 69.67372144971574, 69.8154855455671, 69.48454979487828, 69.37580353873116, 67.13486358097622, 67.74739592415946, 73.46377617972237, 74.34316798618862, 78.8990809576852, 73.37523528507778, 74.97662135532924, 74.37473365238735, 75.05498313903809, 30.721772738865443, 0.31008268679891315, 0.3624322605984551, 3.2503199662481035, 0.5173040245260511, 0.11205353082290717, 0.056146662549248764, 0.04971083592889564, 0.09072371465819222, 0.09489886276423931, 0.17383693983512266, 10.004461884498596, 32.88758182525635, 49.50634922300066, 82.62968690054757, 46.407581193106516, 53.0177811895098, 25.034953594207764, 18.979945932115825, 53.36205400739397, 71.3368353162493, 63.44707938602993, 66.13567093440464, 6.581369749137333, 0.22094842685120447, 0.060927762782999446, 0.08140880627823727, 0.013316212421549218, 0.05651878472417593, 0.06718909394528184, 0.0989278137151684, 0.0492579239819731, 0.03922386686982853, 0.061407493826534064, 0.13072423610304082, 0.08202224943254675, 0.07974102148520094, 0.05388256761112383, 0.028885259492588893, 0.01005436820975904, 0.059083938864724975, 0.05987368577292987, 0.07155527680047921, 0.03200399303542716, 0.009970732831529208, 0.023364819020831158, 0.08649061287620238, 0.010996802460535296, 0.042018084254648, 0.04366771823593548, 0.1245245159204517, 0.0648678799292871, 0.10676744447222777, 0.06932527824704136, 0.1591044110911233, 0.030503110893602883, 0.08843357076070138, 0.0827191456087998, 0.11164517487798419, 0.008058539724775722, 0.1058377225750259, 0.08616075664758682, 0.0716768770611712, 0.07081697641738824, 0.0899204784738166, 0.057093490314270766, 0.08227631329957928, 0.05958612941737686, 0.057097588665783405, 0.013205160835890897, 75.9209371294294, 117.88290105547223, 113.11100333077567, 93.8586984361921, 93.9900541305542, 65.11510562896729, 61.2960421698434, 37.991367203848704, 74.20533657073975, 32.63532747541155, 35.48870250156948, 37.84203651973179, 0.378539786274944, 0.0903430904394814, 0.28114691376686096, 0.21454695106617042, 0.06455771478691272, 0.10694266257009336, 0.18953794161123888, 0.29474054862345966, 0.27465265510337694, 1.8779588980334145, 29.84955494744437, 120.427734375, 93.43906893048967, 101.14229352133614, 85.51259871891567, 92.04109832218715, 84.40410396030971, 87.23719024658203, 76.73701000213623, 75.6352549961635, 67.22953278677804, 67.9175364630563, 67.95353507995605, 66.65538229261125, 64.69904749734062, 67.05520943232945, 65.57782091413225, 67.17731012616838, 70.93238762446812, 75.64697660718645, 75.20566872188023, 68.80090958731515, 63.28420666285923, 66.37705830165318, 65.10178593226841, 69.1827061516898, 65.44319956643241, 66.72423199244908, 79.39828123365129, 86.0625833783831, 85.01090403965541, 84.77170535496303, 74.40178993770054, 69.83364118848527, 68.21472481318882, 72.71440601348877, 75.19013254983085, 80.21565341949463, 82.13132735661098, 82.57350376674107, 80.25217315128872, 79.7220881325858, 80.58235154833112, 77.91923904418945, 85.68321868351528, 45.54778330666678, 74.43904617854527, 85.3694658279419, 76.0871102469308, 74.01551178523472, 71.66557543618339, 76.82112489427838, 75.10058416639055, 78.84633718218122, 80.23885345458984, 84.2009664263044, 79.80215222494942, 82.44426727294922, 80.39924567086356, 83.93554524012974, 71.85014043535504, 67.24273436410087, 65.9004396711077, 63.70229366847447, 63.35723917824881, 65.82906777518136, 72.96944659096854, 77.16372667040143, 74.68045439038957, 75.00811753954206, 73.94524465288434, 73.19291455405099, 72.61087785448346, 72.06375585283551, 71.24239540100098, 70.8814364842006, 70.66951642717633, 77.05451488494873, 77.27271611349923, 82.61896583012172, 77.45155579703194, 76.3048598425729, 79.91705458504813, 80.70800277165004, 39.964245659964426, 1.316899135708809, 0.740690997668675, 0.20959702453442983, 0.3537209566150393, 0.18004941647606237, 0.01661880859839065, 0.06925659014710359, 0.03195183744121875, 0.04876516167340534, 0.2945286014250347, 9.446621417999268, 39.18141644341605, 51.20937006814139, 86.22107178824288, 61.55893421173096, 46.00219202041626, 37.47554683685303, 34.48973567145211, 62.946260179792134, 79.70845576695034, 70.49470669882638, 89.80502905164445, 17.38062173979623, 0.5250495289053235, 0.07391644974372216, 0.08472141423927886, 0.051449503882655075, 0.08713018641408, 0.03460172024954643, 0.11105918525052921, 0.060612427203782966, 0.04067761796925749, 0.03984949990574803, 0.011728549043514898, 0.03487073563571487, 0.02272605463596327, 0.036443715515945635, 0.03522825573704072, 0.011043146402308983, 0.0692474909925035, 0.05745706294796296, 0.04723083454051188, 0.06239320843347481, 0.01984792621806264, 0.03231753049684422, 0.09143509755709342, 0.07889242523482867, 0.06150041241198778, 0.12294393644801208, 0.2183975423020976, 0.13682284099715097, 0.14534708644662583, 0.14008020263697418, 0.15110236619200024, 0.11871200853160449, 0.2111393753439188, 0.1786151020122426, 0.14706573422466004, 0.252510130405426, 0.1328951274710042, 0.1362326783793313, 0.119323232876403, 0.23961411097220012, 0.26193590462207794, 0.19281944552702562, 0.1652796497302396, 0.13780940377286502, 0.1701970880052873, 0.22233969505344117, 88.96322699955532, 133.2636002131871, 127.09728240966797, 113.14784267970494, 104.45916203090123, 65.81756850651333, 41.39988592692784, 68.38276699611119, 146.10200909205844, 28.811429807118007, 62.44391931806292, 47.58848660332816, 0.9868455891098294, 0.3452833465167454, 0.6493437907525471, 0.4650457543986184, 0.1591981846307005, 0.4281929704759802, 0.7620019369891712, 0.48776516956942423, 2.6211260599749426, 8.57973723752158, 30.167810235704692, 123.69049726213727, 97.3303450175694, 105.91041837419782, 89.12496021815709, 92.75531755174909, 88.78874383653913, 91.44774300711495, 79.58921773093087, 77.70296941484723, 70.98838315691266, 71.61333193097795, 73.44779532296317, 69.63246304648263, 68.44657230377197, 70.98617362976074, 69.29472500937325, 70.9071239743914, 74.71801635197231, 79.60406603131975, 80.44862651824951, 73.67489719390869, 67.76263332366943, 69.11796283721924, 68.09155409676688, 73.71461309705461, 72.88360854557583, 71.0046558380127, 84.88849067687988, 91.20878750937325, 86.75596496037075, 86.0259038380214, 79.19012015206474, 72.62009116581508, 71.99000767299107, 75.62336662837437, 80.93705708639962, 83.99170058114188, 87.78937748500279, 84.74584415980748, 81.78341020856584, 83.03923457009452, 84.06221784864152, 81.50763620649064, 90.98081016540527, 51.78337812423706, 78.9873161315918, 89.41674286978585, 79.47403049468994, 78.64572184426444, 75.41016810280937, 82.1705846786499, 78.56729752676827, 83.17671162741524, 85.37777587345668, 89.25743457249233, 83.81132534572056, 86.87273638589042, 86.67172500065395, 90.11177812303815, 74.52673939296177, 69.68993854522705, 67.0353445325579, 65.88145719255719, 67.76553767068046, 70.46336337498256, 78.41561140332902, 80.74886512756348, 79.05378259931291, 77.98003578186035, 79.6805031640189, 78.02118301391602, 76.3010105405535, 76.02160957881382, 75.31727068764823, 73.71594715118408, 75.48921775817871, 80.9636617388044, 81.05995682307652, 86.97824478149414, 79.39641216823033, 79.94839790889195, 82.48981966291154, 81.53308745792934, 38.87560190473284, 0.9782224403960365, 3.2048290244170596, 10.492266246250697, 1.9937679980482375, 0.4925046009676797, 0.12140894095812525, 0.15183635109237262, 0.19588654594761984, 0.17888644816620008, 0.37409258633852005, 14.82485716683524, 52.076491355895996, 61.182008334568565, 87.9775972366333, 59.719134603227886, 74.69914504459926, 37.48633738926479, 31.107578413827078, 70.48151901790074, 94.87130110604423, 80.61423683166504, 105.1268561226981, 18.25677047457014, 0.7293729249920163, 0.24897762281554087, 0.16591740479426725, 0.1252120483134474, 0.14747745570327553, 0.2058999314904213, 0.16687997457172188, 0.27236924905862125, 0.12387200950511865, 0.10249862460685627, 0.16505981795489788, 0.1352815894143922, 0.12968694604933262, 0.11009179108909198, 0.152268808601158, 0.10410340742341109, 0.20047389050679548, 0.1121558335476688, 0.13419055938720703, 0.13094375575227396, 0.1056562890963895, 0.11793501808175019, 0.16697507803993566, 0.11380984407982656, 0.13640951817589148], [0.13571068138948508, 0.06453841725098235, 0.08508936342384134, 0.029806024727544615, 0.1201947025422539, 0.06772625619279486, 0.05576211300545505, 0.08500964912985053, 0.1023910768064005, 0.0661214937322906, 0.13159725282873425, 0.14288838766515255, 0.08842769464743988, 0.058477009646594524, 0.08658224903047085, 0.06528646139694111, 0.13388359014477047, 0.05492644623986312, 0.17270968960864203, 0.3769168662173407, 5.932620355061122, 97.27822657993862, 88.21159172058105, 80.84297847747803, 76.24624483925956, 39.57106099809919, 16.627841745104107, 24.11122359548296, 78.17121546609062, 91.460312298366, 61.64630780901228, 42.673341342381065, 1.7324287699801582, 0.0739473570138216, 0.051719421720398326, 0.1103125728134598, 0.14498793786125524, 0.04398698592558503, 0.06865290432636227, 0.05298368852319462, 0.4406883828341961, 0.4610105880669185, 2.7493832920278822, 100.55401733943394, 96.16665376935686, 97.45525278363908, 90.14598410470145, 88.96999454498291, 84.5483763558524, 85.1151339667184, 80.46086924416679, 82.23877429962158, 72.45769092014858, 70.37196677071708, 63.03599616459438, 63.271317754473, 59.247782707214355, 60.30328355516706, 59.49609048025948, 62.43205874306815, 62.63427216666085, 65.46946375710624, 62.353467668805806, 64.45895249502999, 60.184038570949006, 62.74943855830601, 61.51728670937674, 60.73454434531075, 62.88802037920271, 65.61812741415841, 61.998546736580984, 68.11351040431431, 77.33227607182094, 80.96717057909284, 71.73109694889614, 65.24688516344342, 61.20445796421596, 66.60987854003906, 67.14236763545445, 73.0146654673985, 72.27785764421735, 77.41663415091378, 72.25109318324498, 77.28563976287842, 73.65286445617676, 75.94007246834892, 71.54038974217006, 86.3285048348563, 41.16046837397984, 64.5767730985369, 80.05022375924247, 70.19878986903599, 69.91227395193917, 63.986113684517996, 69.70931707109723, 66.27746977124895, 69.86691611153739, 74.77493599482945, 79.55957671574184, 78.32983589172363, 78.07612936837333, 72.73658466339111, 71.42173535483224, 60.71011447906494, 64.65530163901192, 61.23644747052874, 59.90620790209089, 56.55895839418684, 60.149033546447754, 65.15620422363281, 72.2327082497733, 70.32788045065743, 72.4507566179548, 70.53861931392125, 71.70655591147286, 69.94178989955357, 69.03664112091064, 66.27230725969586, 66.89581775665283, 66.97702830178397, 71.16569423675537, 73.52967984335763, 79.08709226335797, 78.95239448547363, 73.69093363625663, 76.94227368491036, 75.15816388811383, 76.79700074877057, 28.792053018297466, 0.22155575640499592, 1.4310653124536787, 0.39950711546199663, 0.2500412943107741, 0.042701121353145154, 0.007968801772221923, 0.1616592040019376, 0.04199065108384405, 0.16000478634876864, 0.670623354613781, 1.8124564928667886, 29.388910225459508, 25.965263536998204, 44.22624288286482, 39.86969109943935, 20.533622196742467, 24.65520327431815, 30.30482176371983, 51.10666874476841, 68.75828238895961, 69.90125410897392, 56.52080236162458, 2.813114340816225, 0.19122157698231085, 0.03935301583260298, 0.09608562729720559, 0.03960761913497533, 0.10756126259054456, 0.0465362114565713, 0.12335264523114477, 0.10030141965086971, 0.09128155865307365, 0.03174381556787661, 0.05966464948973485, 0.03926146788788693, 0.1251669121640069, 0.042559660372457335, 0.1447000897356442, 0.05326613551005721, 0.13648612477949687, 0.023255186421530585, 0.04242178884201816, 0.03589359324957643, 0.08000433378453765, 0.07489455118775368, 0.11686092428863049, 0.02761272813326546, 0.10610125879091875, 0.07110234110483102, 0.131510427487748, 0.0210251318889537, 0.10983056189226252, 0.06546377616801433, 0.07140683369444949, 0.08098273378397737, 0.06622890582574265, 0.038231865635940006, 0.11285317077168397, 0.0953177631433521, 0.07755117863416672, 0.0724978433655841, 0.0862043389518346, 0.07061583828181028, 0.2941182234457561, 0.056855850387364626, 0.2779865419226033, 0.5964840671845845, 11.46441910948072, 119.61742155892509, 98.3969282422747, 90.56039551326207, 93.88468469892229, 52.31410585130964, 33.34278958184378, 24.73416781425476, 52.4545567376273, 87.39950711386544, 34.41681432723999, 51.94138363429478, 2.681075985942568, 0.16151729518813746, 0.026644361970414008, 0.08877154905349016, 0.09356237947940826, 0.10289957773472581, 0.17767408250698022, 0.10729272557156426, 0.39856357180646484, 0.9352343699761799, 5.171256729534694, 110.44397899082729, 98.89824771881104, 102.1763174874442, 92.69468757084438, 93.10536084856305, 89.69185679299491, 88.87835475376674, 84.5075626373291, 87.25391456059047, 75.49134390694755, 72.88159356798444, 66.32783031463623, 67.05213138035366, 63.18292277199881, 64.20466927119664, 60.315838950020925, 65.06516892569405, 66.8730971472604, 69.05023179735456, 65.68640736171177, 66.8162122453962, 62.622501918247764, 64.91145392826625, 63.056674003601074, 63.972411836896626, 66.86633655003139, 69.41069044385637, 64.35973916734967, 72.11052417755127, 80.31810460771833, 81.7618430001395, 74.87874902997697, 65.9692268371582, 62.33129596710205, 69.51892253330776, 71.65309647151402, 76.13078662327358, 76.82525907244, 81.89894485473633, 75.99255221230644, 80.34483432769775, 77.68193026951381, 78.06627682277134, 73.40474428449357, 88.66381522587368, 44.066476004464285, 66.83617441994804, 82.95172895703996, 73.37362330300468, 73.68824468340192, 68.33618627275739, 72.22382845197404, 68.62560653686523, 72.42042773110526, 76.37524509429932, 81.17796502794538, 82.09697546277727, 80.16834313528878, 75.3441115788051, 73.33550548553467, 63.436907223292756, 67.28572286878313, 64.20086860656738, 62.7950256892613, 59.228015082223074, 61.95118086678641, 68.20910372052873, 75.74453626360211, 73.02026571546281, 77.12045328957694, 73.5836534500122, 74.70820549556187, 73.77100467681885, 72.83348424094063, 69.83464867728097, 69.95916734422956, 71.92308957236153, 75.07828739711216, 77.27384866986955, 82.97673552376884, 78.04282665252686, 74.12870488848004, 80.84746701376778, 77.56110804421562, 80.70056125095913, 37.497378076825825, 0.4109395348599979, 0.6552810807313237, 0.4717345897640501, 0.17135234815733774, 0.07788039703986474, 0.04271753850792136, 0.12523327288883074, 0.07162505734179701, 0.08634069734918219, 0.632882585482938, 1.441824815102986, 33.46538707188198, 27.06452587672642, 48.858968189784456, 38.63242885044643, 22.63775733539036, 31.947212627955846, 43.60498360225132, 60.51002025604248, 78.26851109095982, 76.41669804709298, 79.87553215026855, 6.110344418457576, 0.3615447096526623, 0.09244204352476768, 0.09225356685263769, 0.06093480597649302, 0.07752090240163462, 0.011246812929000174, 0.045284623080598455, 0.041402483358979225, 0.05556090362370014, 0.05079549111958061, 0.07724219414272479, 0.010417224989006562, 0.05865192240370171, 0.03523106487201793, 0.05572762646313224, 0.018010088674990193, 0.09492955968848296, 0.023317209611247693, 0.1202044870172228, 0.04247043301750507, 0.045009809612695656, 0.017759785588298525, 0.07342782989144325, 0.022881530757461275, 0.23111160578472273, 0.2523746133915016, 0.20653841937226908, 0.1046532786318234, 0.1789877534444843, 0.2150912040046283, 0.11259630455502442, 0.12289695468332086, 0.1659011470952204, 0.12519675413412706, 0.19373975614351885, 0.17964258044958115, 0.1692185319427933, 0.13308699003287724, 0.19521985815039702, 0.23112715780735016, 0.3594955067549433, 0.0882788308496986, 0.44725744319813593, 0.8162774103028434, 13.545362898281642, 139.06077412196566, 111.90109961373466, 107.88413061414445, 102.31690038953508, 62.30406597682408, 25.640532527651104, 39.33528777531215, 102.32990741729736, 104.72848115648542, 88.42624241965157, 69.58995396750313, 3.9464317560195923, 0.2814245974378926, 0.14525658344583853, 0.5919663810304233, 0.3279952513320105, 0.2939801551401615, 0.29976311911429676, 0.29689332310642513, 1.3609880613429206, 3.051632536309106, 4.4538812807628085, 114.3356511252267, 102.24891921452114, 108.76512050628662, 94.39662102290562, 97.966278893607, 92.74546500614711, 91.25928006853376, 86.82475212642125, 91.11493819100517, 79.17106124332973, 77.49663570949009, 70.81413623264858, 70.62541621071952, 66.96732861655099, 68.9518939426967, 67.30185658591134, 68.4726836340768, 69.99581909179688, 73.35637787410191, 69.67290851048061, 71.08122498648507, 68.20934690747941, 69.32078075408936, 67.71513543810163, 67.38675662449428, 68.26138196672711, 71.42699514116559, 67.45810072762626, 76.29991967337472, 83.08070141928536, 87.36336953299386, 79.85771696908134, 70.33345985412598, 66.83628559112549, 75.29642609187535, 75.34222861698696, 80.90731879643032, 79.82759652818952, 84.59504045758928, 79.75500174931118, 84.43925489698137, 82.15146323612758, 81.85767950330461, 76.58013357434953, 94.98521682194301, 49.95506041390555, 70.48020580836705, 86.5441699709211, 77.65399851117814, 76.46369566236223, 73.32681328909737, 76.86956078665597, 73.4459262575422, 77.46308980669293, 81.98904909406389, 85.14875629970005, 85.35694517408098, 83.61380195617676, 79.8873371396746, 79.48484189169747, 67.83231680733817, 70.3420478275844, 68.88462148393903, 65.46268926348004, 61.92612566266741, 65.0614377430507, 73.46788951328823, 79.8387622833252, 79.21509892599923, 79.32269872937883, 76.55819811139787, 77.98633084978376, 77.34247602735246, 77.5920970099313, 72.9361160823277, 75.82557310376848, 74.27094146183559, 78.16462162562779, 79.23515142713273, 86.90996483394078, 79.96470533098493, 75.98606954302106, 83.96652030944824, 80.49879251207624, 85.46810245513916, 37.96087850843157, 0.5794972415481294, 5.087284709726061, 2.3736692241259982, 0.6360143231494086, 0.31123790623886244, 0.1422509854393346, 0.3407280423811504, 0.16738096411739076, 0.21671902308506624, 1.05656598508358, 3.622587727648871, 45.2733815738133, 36.772746971675325, 62.538602420261924, 57.9736533164978, 28.21745957647051, 35.76570980889456, 45.099134649549214, 71.58261394500732, 89.94102614266532, 90.05068261282784, 90.22249071938651, 5.976165149893079, 0.2979984123791967, 0.20486630552581378, 0.18865474686026573, 0.2270420105861766, 0.22841755034668104, 0.09889987164310046, 0.18379803746938705, 0.14573413639196328, 0.20752773700015886, 0.1550283155270985, 0.13452490073229584, 0.12845716918153421, 0.1229487947587456, 0.1541585014866931, 0.175426204555801, 0.11290488871080534, 0.22538878715464047, 0.10037518997809716, 0.15407315535204752, 0.10274071233080966, 0.21401397537972244, 0.11223414327417101, 0.2027980357940708, 0.08452908348824296], [0.08671088569930621, 0.010200025929537202, 0.12988760242504732, 0.030420132846172367, 0.12810175253876618, 0.05419964702533824, 0.05576142429241112, 0.032176741265824864, 0.04499927535653114, 0.06468815635889769, 0.06636592918740851, 0.09547915269753762, 0.15543334665043013, 0.038448457406567674, 0.08986112023038523, 0.03513000047366534, 0.13744326627680234, 0.06372980706925903, 0.10810419917106628, 0.18960052968135901, 33.85686942509243, 102.01300702776227, 90.75395148141044, 70.40288625444684, 44.74733345849173, 38.202873843056814, 32.05033779144287, 58.92320455823626, 74.42494133540562, 96.80558926718575, 52.52226345879691, 4.990025562899453, 0.10039645526558161, 0.04894372834158795, 0.09160937249128308, 0.17701017670333385, 0.09829598904720374, 0.04524329351261258, 0.050851236164037666, 0.04220596042328647, 0.5502264350652695, 0.15595210024288722, 64.18736130850655, 105.16672488621303, 92.70469992501395, 94.76361792428153, 87.71417713165283, 93.22488376072475, 89.58912767682756, 92.26060581207275, 86.08858353751046, 85.05009882790702, 80.53788307734898, 71.27271039145333, 64.67367962428501, 62.861012731279644, 57.16919783183506, 58.57140336717878, 60.58531788417271, 60.37671906607491, 59.76925195966448, 59.73874241965157, 59.58556243351528, 60.03911999293736, 57.410043239593506, 60.19635772705078, 59.655044419424875, 60.498430660792756, 61.5812657220023, 65.23365579332624, 64.88209084102085, 63.05841800144741, 64.45435278756278, 66.08754771096366, 59.01489298684256, 59.08610507420131, 60.817373820713584, 66.2326191493443, 67.2888981955392, 74.77401883261544, 77.81896264212472, 81.71038464137486, 73.5267754963466, 75.11571039472307, 72.16223267146519, 75.61652265276227, 68.12459972926548, 81.28168078831264, 42.6968366759164, 59.45445687430245, 82.33326980045864, 68.78045409066337, 69.9321596963065, 62.8362979888916, 69.1214508329119, 63.53896236419678, 68.20786694117955, 65.57427038465227, 73.52766486576625, 75.39353411538261, 76.7640871320452, 66.94638674599784, 61.53544235229492, 63.07324545724051, 62.84492070334298, 59.002094405038015, 59.09847286769322, 60.80192102704729, 57.853320939200266, 61.50525937761579, 67.46456255231584, 68.07014669690813, 71.13920075552804, 74.45257432120187, 72.21599783216203, 70.38124956403459, 69.90884849003383, 67.14003998892647, 68.14299855913434, 67.73677212851388, 74.89398642948696, 77.5358999797276, 83.31683594839913, 66.93477630615234, 72.65217794690813, 76.54446152278355, 74.7468513761248, 65.05678244999477, 75.33912972041539, 22.30559696469988, 0.19258598876850946, 0.738874260868345, 0.1490830595472029, 0.0340711363990392, 0.04144875944725104, 0.020118127344176173, 0.043392914946057966, 0.044441271905920336, 0.32306078182799475, 0.29260240335549625, 3.357309413807733, 23.792572259902954, 42.720488343920024, 60.599103110177175, 55.005792822156636, 36.29254307065691, 24.144394295556204, 47.471280915396555, 56.42779377528599, 67.23085294451032, 76.98972293308803, 35.533771991729736, 0.3139652913170201, 0.03126296154888613, 0.04411191440054348, 0.05537303763308695, 0.07249206224722521, 0.06456255952694587, 0.05368610118914928, 0.07423194138599293, 0.07284141278692655, 0.021379277974899327, 0.14673930459788867, 0.07158507127314806, 0.04798184049182704, 0.039152328922812424, 0.08312708086201123, 0.05037262470328382, 0.05905923340469599, 0.08478864348892655, 0.07311406851347003, 0.015501627831586769, 0.02900332797850881, 0.027550811812813793, 0.08568038778113467, 0.04827105247282556, 0.016841295141992823, 0.04698824809331979, 0.12856569407241686, 0.030016713243510042, 0.08901690731623343, 0.007689571041347725, 0.05787926100726638, 0.03966201050207019, 0.008385613111646047, 0.07687149689133678, 0.1590515939252717, 0.06336264498531818, 0.08239137248269149, 0.06617191566952638, 0.07167902123183012, 0.022047831743423427, 0.048002929360206635, 0.13865857677800314, 0.17201518187565462, 0.218515919521451, 49.17231804983956, 116.63329533168248, 100.88739190782819, 82.16377544403076, 58.663466998508994, 54.339036737169536, 39.209851946149556, 75.51745523725236, 81.48524216243199, 86.18460069383893, 53.63312407902309, 8.065664342471532, 0.4621777225817953, 0.02926384810624378, 0.12922033108770847, 0.0383660086164517, 0.18785004504024982, 0.16476917426501, 0.09370331120278154, 0.10214318082268749, 0.053804525905953984, 0.7895878595965249, 69.30871868133545, 107.42987823486328, 97.48849991389683, 98.16605349949428, 90.80220672062465, 96.04156535012382, 92.16014875684465, 95.774719783238, 91.19492585318429, 88.90518869672502, 83.48016030447823, 76.27958924429757, 68.08445303780692, 65.15766334533691, 60.21053900037493, 62.18925394330706, 62.68545954568045, 63.78798580169678, 62.7939487184797, 63.56641469682966, 62.46261692047119, 63.52745614733015, 61.30814593178885, 63.74305874960763, 61.47386046818325, 64.25160435267857, 64.397308077131, 68.02301011766706, 68.587815284729, 66.50111838749477, 67.67677443368095, 67.1431805746896, 60.99996553148542, 61.90327303750174, 63.524614334106445, 69.60339873177665, 70.51414775848389, 77.9322669165475, 79.4249484198434, 82.57620661599296, 78.47496291569301, 78.24160071781704, 76.89116968427385, 78.19099698747907, 72.39857564653668, 85.52081148965019, 45.754905632564, 63.33801351274763, 85.28462137494768, 71.65235301426479, 74.13488183702741, 66.27348150525773, 71.7226757322039, 67.35479491097587, 72.63717678615025, 68.25603185381208, 75.42894908360073, 79.36660439627511, 78.5012548991612, 70.96820558820451, 63.797150475638254, 64.94256101335797, 64.86287907191685, 62.12413542611258, 62.40578760419573, 61.645258631025044, 60.82971382141113, 65.51806640625, 70.91628864833287, 70.97882243565151, 74.26442405155727, 76.50222342354911, 74.58663286481584, 72.97330978938511, 72.61335836138043, 70.40588092803955, 70.816575050354, 70.66166496276855, 77.2648993900844, 81.83814116886684, 81.78011676243374, 67.95304870605469, 76.6444183077131, 76.12452629634312, 78.69247627258301, 69.75933020455497, 83.19778551374162, 31.657003743307932, 0.26186216143625124, 0.9883151331118175, 0.27538300305604935, 0.07458194331931216, 0.029756834331367697, 0.13869863748550415, 0.06282637840402977, 0.2567722259887627, 0.4318513055997235, 0.393320694565773, 3.623986921140126, 24.929507732391357, 36.93212822505406, 57.442070960998535, 29.984426430293492, 36.33047328676496, 33.666360242026194, 59.14574146270752, 62.5267140524728, 79.05050304957798, 84.275221824646, 54.64397580283028, 0.2233647850475141, 0.05340359991948519, 0.044285938276776245, 0.03129294261868511, 0.07411484659782477, 0.10069307006363358, 0.037730353618306775, 0.004731637151313147, 0.049536859550114186, 0.0318999532610178, 0.10504122424338545, 0.011067796731367707, 0.10288933185594422, 0.048374742801700316, 0.0659174718228834, 0.07329219074121543, 0.029546362946608236, 0.009136597010573106, 0.13620305354041712, 0.01968935936955469, 0.010540231513524694, 0.026216107986069152, 0.12557810438530786, 0.10799726205212729, 0.15815385138349874, 0.18514020687767438, 0.14259654975363187, 0.1767924212451492, 0.1343724067722048, 0.13029529340565205, 0.25537797223244396, 0.12103044055402279, 0.08781507930585317, 0.1615379633648055, 0.1941004925008331, 0.26518874721867697, 0.20700379940015928, 0.2417283175247056, 0.206018756542887, 0.1552863623946905, 0.3369221123201506, 0.24579344796282904, 0.20752392363335403, 0.3138664966183049, 56.66104827608381, 134.4073153904506, 113.01607009342739, 100.86481721060616, 63.37127453940255, 60.2879558290754, 44.96322093691145, 91.53447042192731, 91.28175054277692, 111.9491047177996, 76.41972746167863, 9.568167993000575, 0.5644091740250587, 0.17981509119272232, 0.572450302541256, 0.4657391086220741, 0.4120616146496364, 0.16855172200926713, 0.35825978592038155, 0.5336830456342015, 1.1982451826334, 1.0816987050431115, 71.87998989650181, 110.3027846472604, 104.68854291098458, 100.02492591312954, 95.86753382001604, 99.68631935119629, 96.69547421591622, 98.26038919176374, 94.97787257603237, 91.43331159864152, 87.44813755580357, 79.06051540374756, 71.96683543069022, 70.50899914332798, 63.913650921412874, 65.09147480555943, 68.2312684740339, 69.7064266204834, 67.63486984797886, 67.98691422598702, 67.01625088282994, 65.98160852704729, 66.38620907919747, 66.85055719103131, 64.81308828081403, 65.88984366825649, 67.82373578207833, 72.74519348144531, 72.96176883152553, 69.01335770743233, 73.38114820207868, 71.32624626159668, 66.61840397971017, 65.5862351826259, 67.3142591203962, 71.42748151506696, 73.10906369345528, 81.60648127964565, 83.24128818511963, 85.9113905770438, 81.52481215340751, 80.15504428318569, 80.80861268724713, 82.62321812765938, 80.04075336456299, 89.84270913260323, 51.486422538757324, 67.86092254093715, 88.89540563310895, 75.66449996403286, 77.92328289576939, 68.79476737976074, 76.57174709865025, 70.28539916447231, 77.1838903427124, 72.26316915239606, 80.85315758841378, 82.54471043178013, 84.45610427856445, 74.21201378958565, 67.73864119393485, 69.55881908961705, 68.6137251172747, 65.27462237221854, 64.83503069196428, 66.96395874023438, 63.78907666887556, 71.00613580431256, 74.53631401062012, 73.84360640389579, 78.6004890714373, 80.08828599112374, 77.9733099256243, 75.50242628370012, 77.0934317452567, 74.4791511808123, 75.04445661817277, 75.78194536481584, 82.76233495984758, 83.83325386047363, 85.21249907357353, 69.75486251286098, 76.50250135149274, 80.74091638837541, 84.28077343532017, 74.2584069115775, 86.95021574837821, 29.54272597176688, 0.479837709239551, 1.8441487465585982, 0.4176907411643437, 0.22507082564490183, 0.21490038638668402, 0.20640358089336328, 0.09033865282045943, 0.5393700376152992, 0.655032356934888, 0.4493358502430575, 6.151019173009055, 39.85169179098946, 59.347107206072124, 77.8293571472168, 77.83989756447929, 48.87355245862688, 35.043896198272705, 65.04494271959577, 76.32957458496094, 88.46126134055001, 99.12496743883405, 59.64870071411133, 0.445259618972029, 0.14773976377078465, 0.2516071360026087, 0.1689601865197931, 0.10969971319926636, 0.2218634177531515, 0.11823666760964052, 0.27781845522778376, 0.12091370538941451, 0.09809256424861294, 0.2176498645650489, 0.1485682821699551, 0.137025655114225, 0.16698608387793812, 0.1145684394453253, 0.16915381327271461, 0.15858025635991777, 0.1154288218489715, 0.1806995751602309, 0.11407776363193989, 0.15895597477044376, 0.15628456883132458, 0.17692544125020504, 0.20781850282635006], [0.04115044152630227, 0.06207846996507474, 0.07049189028995377, 0.07013974418597561, 0.09315549595547573, 0.040976549964398146, 0.09123591360236917, 0.1206284628382751, 0.03610370161810091, 0.05608211690559983, 0.03135749165500913, 0.0579058595799974, 0.01742914904441152, 0.05336944246664643, 0.024377066043338606, 0.07607140910944768, 0.05028253560885787, 0.047437326317386966, 0.14064827215458664, 0.48256151165281025, 53.31723117828369, 92.76283550262451, 89.5791083744594, 66.20338112967355, 51.90376608712332, 27.42810426439558, 52.89355434690203, 26.165441138403757, 45.88234601702009, 42.141953536442344, 13.760460019111633, 0.07509532969977174, 0.033166482978101285, 0.01908948182660554, 0.018461409457294003, 0.15086646670741694, 0.04707778078903045, 0.43086230009794235, 0.12553857293512138, 0.28845313457506044, 0.38798865782363073, 39.53716768537249, 107.46423707689557, 89.26443140847343, 101.10160487038749, 90.96350220271519, 95.63195514678955, 90.02429335457938, 93.18593910762242, 89.17200647081647, 92.24991253444126, 98.20205211639404, 82.91770362854004, 79.25734397343227, 66.41776779719761, 61.10557815006801, 58.608194078717915, 58.72686236245291, 56.95628070831299, 58.616247040884836, 57.981793131147114, 57.65236166545323, 56.51015772138323, 59.10197475978306, 58.671770095825195, 59.042053495134624, 58.824144090924946, 56.877564566476, 60.345063073294504, 67.29597840990338, 64.7101993560791, 66.25246320452008, 60.97520909990583, 60.85938262939453, 55.41474642072405, 61.18337712969099, 64.8864334651402, 65.15202140808105, 66.92384678976876, 75.99046080453056, 72.34759671347481, 76.66260869162423, 74.34007603781563, 81.27683789389474, 71.15425750187465, 73.38781152452741, 70.64435005187988, 81.89720780508858, 44.930289949689595, 57.118649687085835, 80.54833316802979, 65.93848105839321, 69.33217579977853, 68.1785385949271, 70.88804422106061, 66.31298896244594, 67.04577377864292, 63.64137881142752, 65.72185707092285, 67.44365542275565, 67.69535391671317, 62.29642990657261, 60.33076368059431, 60.8099809374128, 60.275956290108816, 57.8403000150408, 54.877782685416086, 58.222259862082346, 56.35507392883301, 57.6143341745649, 62.522962025233674, 68.6583672932216, 68.36342321123395, 71.81669875553676, 72.05511229378837, 72.70844445909772, 70.8622247150966, 65.94275420052665, 64.1199985231672, 70.39015715462821, 73.88211332048688, 78.27222837720598, 68.93949835641044, 72.34312207358224, 73.80630152566093, 69.47695541381836, 68.51242733001709, 77.97467177254813, 72.54345253535679, 82.1042571749006, 17.166926418031963, 0.8370555639266968, 0.504957455609526, 0.28248677615608486, 0.10547839757055044, 0.09960750902869872, 0.02555667542453323, 0.008673149959317275, 0.14864638155060156, 0.11742185561784677, 0.07128778472542763, 7.3750976494380405, 26.67847875186375, 38.328629289354595, 54.423544202532085, 38.57348033360073, 22.83531720297677, 24.16470214298793, 56.26735292162214, 66.62778404780796, 60.46468326023647, 71.91584260123116, 12.71751890863691, 0.5698693724615234, 0.10156655497848988, 0.1119539625942707, 0.035536341169582944, 0.022858648860294904, 0.04687350442899125, 0.05314152594655752, 0.03669204915474568, 0.08611969170825821, 0.038404769929392, 0.04098329120980842, 0.03435907612687775, 0.08829025737941265, 0.025593621656298637, 0.06210481747984886, 0.005847843372196491, 0.06815295293927193, 0.060236159179891856, 0.06835265258061034, 0.07819283527455159, 0.07323971284287316, 0.06522601749747992, 0.06135308210338865, 0.03103670065424272, 0.0589877904525825, 0.057088306306728294, 0.0844875435744013, 0.06400926171668939, 0.05058096209540963, 0.04800816425787551, 0.0996508402749896, 0.02508723097188132, 0.05126510520598718, 0.05123127005728228, 0.05372326794479575, 0.0390845670231751, 0.03743395934413586, 0.033027417226029296, 0.09192648583224841, 0.05269429333774107, 0.09113703747945172, 0.08004697971045971, 0.588654913008213, 74.48553657531738, 107.40785244532994, 98.07584503718785, 78.51506096976144, 53.65939521789551, 40.76096779959542, 48.49264178957258, 20.565783670970372, 54.868392195020405, 51.5774369921003, 18.41809027535575, 0.26769397993172916, 0.06082089351756232, 0.053876613466335196, 0.02929125413564699, 0.2140095377607005, 0.2683756362114634, 0.06414005612688405, 0.1860641815832683, 0.38195086323789185, 0.4194928216082709, 47.06456811087472, 112.36630235399518, 94.48332064492362, 103.99462631770542, 95.54162856510708, 97.77272987365723, 93.11509527478898, 95.108199937003, 92.27719811030796, 93.53284876687187, 101.52311733790806, 87.07614489964077, 82.4033145904541, 70.07935728345598, 63.50026089804513, 62.07722813742501, 63.145437240600586, 62.0760816846575, 63.064073835100444, 61.812654631478445, 61.64265305655343, 60.125965527125764, 62.246798924037385, 60.86104324885777, 62.47332409449986, 63.12304319654192, 61.04998561314174, 63.29223878043038, 70.5328175680978, 68.43487848554338, 70.24818461281913, 62.45836462293352, 64.02597549983433, 59.96489238739014, 65.68036937713623, 67.23860018593925, 68.74788093566895, 69.09690979548863, 76.52581950596401, 74.4537833077567, 77.83078847612653, 77.47074672154018, 83.96906335013253, 72.38513088226318, 78.63085269927979, 73.44175733838762, 85.44990512302944, 48.75115646634783, 57.62250525610787, 81.9588383265904, 69.25004114423479, 72.62874167306083, 69.54080935886928, 73.78583908081055, 71.41129221235002, 69.70293167659214, 66.85287094116211, 67.50022765568325, 70.3742596762521, 69.71090820857457, 63.8254782812936, 61.876230648585725, 64.63095515114921, 62.85172298976353, 61.41785798754011, 58.458050455365864, 60.51566219329834, 59.809697423662456, 61.33109583173479, 66.55949715205601, 71.43445750645229, 72.61264964512416, 76.53037057604108, 76.74172782897949, 74.93527957371303, 74.33661583491734, 68.84517656053815, 67.06318596431187, 74.57134682791573, 75.31141335623605, 80.3198972429548, 69.85657719203404, 75.22312954493931, 74.45299121311733, 76.78945500510079, 72.74324798583984, 82.96943991524833, 75.27344839913505, 88.12865107400077, 24.252954687391007, 0.4412196757537978, 0.42074501727308544, 0.32392382408891407, 0.2036554597850357, 0.11726296985788004, 0.051652423172656975, 0.059692645844604285, 0.3900832140019962, 0.05615746143407055, 0.16334263581250394, 7.53873120035444, 29.537466185433523, 38.34380415507725, 47.13683979851859, 39.32265942437308, 35.268524510519846, 40.966648374285015, 66.21629088265556, 72.85484995160783, 66.63393320356096, 86.61885615757534, 24.298788479396276, 0.8689850877438272, 0.09581234731844493, 0.218247938901186, 0.02583305800466665, 0.047700896460030756, 0.0673583952177848, 0.070049885793456, 0.04875296500644513, 0.058159875949578624, 0.023234687878617218, 0.01895457549419786, 0.07917002069630794, 0.048663266069654904, 0.025294538687116334, 0.12592676281929016, 0.008918365729706628, 0.06515131757727691, 0.03467486632455673, 0.05554158912439432, 0.03140823250370366, 0.09183623388941799, 0.054107868378715854, 0.06766165287366935, 0.10791917624218123, 0.1784606267298971, 0.11991498326616627, 0.20573914583240235, 0.20116983673402242, 0.21838735070611748, 0.2905685624905995, 0.20247079192527703, 0.21111207109476837, 0.1970693003386259, 0.12882885709404945, 0.09374022350779601, 0.2124405883784805, 0.18554884780730518, 0.113815245218575, 0.12682650025401795, 0.1700116986674922, 0.17078927265746252, 0.2403303725378854, 0.7565506409321512, 87.95056179591587, 124.61385726928711, 115.78671291896275, 93.29510225568498, 70.49048914228166, 40.59024361201695, 68.45987810407365, 38.377381324768066, 60.08734049115862, 65.59071677071708, 26.19751054900033, 0.657330582184451, 0.1476741630051817, 0.5360605237739426, 0.1289411410689354, 0.5484337455460003, 0.6192594479237283, 0.6146920387234006, 0.41877829709223335, 0.6683252922126225, 0.9257064355271203, 47.52719306945801, 114.54957226344517, 97.24493776048932, 108.3717621394566, 101.34568813868931, 101.09345463344029, 96.40508815220424, 99.32350526537213, 97.64936460767473, 95.36715929848808, 103.58788572038922, 91.01265375954765, 87.63027763366699, 73.86125482831682, 68.88880429949079, 66.18132059914726, 68.0519493647984, 64.75697462899345, 67.76549598148891, 65.80215045383999, 64.34088870457241, 64.07311902727399, 65.54256575448173, 64.72382477351597, 66.03100327083042, 66.54007693699428, 65.52618885040283, 65.72045353480748, 74.78071689605713, 71.97179644448417, 72.39285727909633, 65.0603607722691, 66.93936211722237, 62.15995338984898, 70.31041267939976, 71.74934986659459, 71.76287106105259, 72.99778134482247, 81.11974607195172, 78.3151821408953, 82.15155356270927, 83.45864868164062, 87.52831281934465, 78.1197987965175, 83.05477769034249, 78.18965598515102, 89.03523118155343, 55.68487501144409, 64.40458284105573, 85.71822370801652, 74.25330693381173, 76.6251301084246, 74.93374402182442, 77.31460680280412, 73.82128184182304, 72.95291682652065, 70.38279901232038, 72.82731424059186, 74.84767668587821, 73.24305275508335, 67.64047704424176, 64.13868917737688, 66.81975582667759, 66.31922149658203, 64.98300647735596, 61.02235957554409, 64.38582270486015, 62.250307764325825, 64.78251620701381, 70.91185569763184, 76.3907048361642, 76.79803603036063, 80.77458735874721, 78.1267192023141, 79.00533975873674, 79.0355783190046, 72.76635074615479, 72.00738511766706, 78.52604607173375, 79.20879690987724, 84.00257451193673, 71.2261574608939, 77.28404862540108, 78.6538164956229, 83.22153445652553, 76.55531460898263, 88.70925644465855, 76.06510530199323, 91.31913185119629, 22.25602330480303, 1.1624823702233178, 1.7207106330565043, 0.462209695151874, 0.4252914733120373, 0.4956268391438893, 0.22505262733570167, 0.10041924047150783, 0.3614987592611994, 0.22101941518485546, 0.29878923137273106, 12.82466013090951, 42.73840079988752, 54.838111945560996, 77.12577560969761, 54.27655853543963, 32.89158746174404, 37.44068077632359, 76.2930131639753, 88.09434781755719, 78.75259903499058, 97.57992431095668, 23.11639962877546, 1.0998160243034363, 0.3712430920984064, 0.35582579938428743, 0.15761936934930937, 0.20790095840181622, 0.16764989468668187, 0.14803206308611802, 0.10717217704015118, 0.19121791289321013, 0.12315148673951626, 0.15099872675325188, 0.19988356504057134, 0.12471366434225015, 0.13012308121791907, 0.16374283576650278, 0.10161108044641358, 0.18004064980362142, 0.1725881639868021, 0.1405627496008362, 0.17957885244062968, 0.15283089343990597, 0.20639851902212414, 0.10187283890055758], [0.04839355179241725, 0.07005264064563171, 0.055947275034018924, 0.09007289779505559, 0.03819636468376432, 0.051814060392124314, 0.04306462274066039, 0.11666349773960454, 0.11016554784561906, 0.07552269141056708, 0.03210499297295298, 0.04630694804447038, 0.10493731339062963, 0.025239304240260805, 0.033496973636959276, 0.08476915596319096, 0.05036524563495602, 0.12046694436243602, 0.030311723306242908, 3.151575859103884, 78.06949383871896, 87.31649003710065, 83.85800334385463, 80.86266272408622, 55.689474718911306, 42.490819113595144, 51.41305998393467, 104.82947322300502, 67.0475664138794, 42.773468358176096, 2.1506550652640204, 0.23976043026362145, 0.36597187923533575, 0.14639070044670785, 0.1852631438523531, 0.03080994782171079, 0.14277389166610582, 0.1259136399520295, 0.6334406669650758, 0.631817068372454, 20.13414420400347, 104.24066202981132, 91.55243846348354, 98.81943430219377, 90.7919442313058, 96.32683059147426, 89.57523127964565, 92.3601734978812, 88.68217236655099, 90.97129113333565, 86.94108581542969, 82.79535974775041, 88.827271597726, 82.0128675188337, 69.87152971540178, 61.16633319854736, 57.33060448510306, 56.042471000126426, 58.71612739562988, 56.133530616760254, 54.37857893535069, 58.27455200467791, 57.54722152437483, 58.68879318237305, 56.28079073769705, 59.127231461661204, 54.968873568943565, 58.36079651968819, 66.51415320805141, 70.63190582820347, 68.51940332140241, 66.37402193886894, 62.186856814793174, 58.85841260637556, 59.90795189993722, 62.439639227730886, 63.76600864955357, 67.84744998386928, 69.26272160666329, 74.43132672991071, 76.46052033560616, 76.70378371647426, 71.9270361491612, 74.78162016187395, 67.64240169525146, 74.00397777557373, 65.98879296439034, 81.90527466365269, 48.94349997384207, 52.381267138889854, 81.59009047916958, 65.98017024993896, 70.64785889216832, 67.91447925567627, 73.02741541181291, 70.4240574155535, 73.82495049067906, 65.45289925166539, 65.5762506212507, 58.370454515729634, 61.4242433820452, 59.114780289786204, 63.13132544926235, 59.71479892730713, 62.70464352199009, 58.719782148088726, 57.337375504629954, 53.96627630506243, 55.40270171846662, 56.56699398585728, 62.24612494877407, 64.49963419778007, 70.63662365504673, 68.59631987980434, 71.71620001111711, 73.58019324711391, 71.13741506849016, 67.34336512429374, 66.68882397242955, 72.54811477661133, 77.7385025024414, 70.74941376277378, 72.49466923304966, 74.9821034840175, 66.9280435017177, 70.37059102739606, 77.58313383374895, 72.27441133771623, 77.39134965624127, 74.30186094556535, 76.04720674242292, 9.788568326405116, 0.8313134749020848, 0.2058788426220417, 0.0857686312603099, 0.14441718134496892, 0.0778278037905693, 0.017190993430891206, 0.04705668513530067, 0.12294192798435688, 0.11915264917271477, 0.09612296029393162, 12.471275619098119, 26.89585488183158, 46.380594389779226, 38.42878409794399, 29.859226839882986, 19.320115838732036, 45.6945709500994, 56.28847197123936, 71.79574298858643, 77.06363786969865, 47.88062708718436, 0.6019176670483181, 0.05972287457968507, 0.09677076446158545, 0.03691543984626021, 0.04325342171692422, 0.02807280032097229, 0.02644996508024633, 0.03467831328245146, 0.08032873459160328, 0.07848033734730311, 0.07381952101630823, 0.05698359478265047, 0.18403344840875693, 0.04140933316999248, 0.029889284367007867, 0.08637697183127914, 0.09235612063535623, 0.07221465677555118, 0.03022411764998521, 0.045385511059846194, 0.13777253217995167, 0.03135057059781892, 0.06958761345595121, 0.05810481283281531, 0.026096244775024906, 0.09548606018402747, 0.08234403787979058, 0.04499560448208025, 0.03206076266776238, 0.025618439074605703, 0.05899016532514777, 0.09214303349809987, 0.07790916013930525, 0.05212937222261514, 0.044180130918643305, 0.05081414065456816, 0.025787309477371827, 0.07868868152477912, 0.15245007244603975, 0.018678206484764814, 0.1802052759698459, 0.19483929499983788, 5.798297779900687, 102.30298314775739, 98.48873479025704, 97.28187438419887, 86.72837366376604, 63.431814193725586, 41.42930459976196, 36.56807735988072, 76.38076196398053, 66.12130900791713, 47.04803139822823, 2.1271343273775916, 0.26844161695667673, 0.33371948131493157, 0.3624302249933992, 0.26111227167504175, 0.25013471501214163, 0.04902612963425262, 0.2813350036740303, 0.5360771343111992, 0.621269268648965, 25.6708961554936, 113.01839773995536, 94.90592397962297, 101.85508837018693, 95.52206243787492, 100.25741958618164, 91.94474765232631, 95.93049839564732, 92.36216068267822, 93.24353272574288, 92.52692331586564, 84.96637998308454, 88.69800731113979, 85.75309671674455, 73.60392829350063, 62.99245180402483, 60.38539041791643, 58.82952199663435, 61.60961437225342, 60.20211083548409, 58.837109429495676, 62.44219616481236, 61.94766507829939, 62.493835176740376, 59.962259020124165, 62.29813916342599, 59.211054529462544, 60.78155585697719, 69.5025247846331, 73.83749893733433, 71.85574068341936, 67.23181874411446, 64.13546521323067, 61.68937969207764, 64.01701927185059, 66.21158000401088, 68.0180560520717, 71.81680992671421, 73.64984198978969, 77.96377699715751, 78.88172435760498, 80.25619615827287, 76.59992204393659, 76.70114340100969, 71.75999450683594, 76.45797729492188, 69.29785169873918, 84.30629416874477, 52.687206745147705, 56.99949850354876, 84.81992585318429, 68.4555424281529, 74.12826715196881, 71.02358967917306, 75.03069918496269, 72.46477808271135, 76.81496184212821, 69.0603414263044, 67.21892983572823, 61.15122086661202, 64.16482830047607, 61.59605843680245, 64.8860582624163, 61.429114069257466, 66.21875054495675, 59.97348730904715, 60.735767228262766, 56.200417450496126, 58.09999588557652, 59.82366330283028, 66.13603918892997, 68.71780913216728, 74.157803944179, 73.90347208295549, 76.11054652077812, 74.68770830971854, 74.92265469687325, 70.50225244249616, 70.68763038090297, 75.12445817674909, 79.73786054338727, 73.02897180829729, 74.81414467947823, 74.37035628727504, 74.0763224193028, 74.9054787499564, 79.46904863630022, 74.75156225476945, 82.16731902531215, 74.57711383274624, 81.52153260367257, 15.677399396896362, 0.6755687349608966, 0.28144530632666176, 0.26164161041378975, 0.17869834468833037, 0.08852311024176222, 0.2965073181050164, 0.023569127611283745, 0.12787425331771374, 0.14179756119847298, 0.0859283244769488, 13.747240202767507, 27.888776779174805, 33.38422169004168, 23.0682555607387, 30.774165630340576, 28.447543961661204, 55.04304558890206, 65.64572565896171, 82.00599575042725, 84.09267180306571, 65.34924602508545, 1.1254695334604807, 0.015131522602002536, 0.046197144115077596, 0.06268877150224787, 0.05687104957178235, 0.03549970706392612, 0.02803389821201563, 0.03926074864076717, 0.04494610195979476, 0.06644242722541094, 0.07329365637685571, 0.1285976530717952, 0.1350597898874964, 0.008395989608418728, 0.024595077648492794, 0.07120201789907046, 0.07863393053412437, 0.010083273801553463, 0.07977158948779106, 0.0705068859138659, 0.043622694044773064, 0.036991978596363745, 0.09748374191778046, 0.12486785463988781, 0.1382257935724088, 0.11635215873164789, 0.19950619100459985, 0.13252311386168003, 0.17997632468385355, 0.12888740109545843, 0.21791836087192806, 0.18851939269474574, 0.1844264558915581, 0.18033852667680808, 0.15743027521031244, 0.14194028425429547, 0.146582603720682, 0.16449143631117685, 0.22379014508000442, 0.10107984859496355, 0.3503664694726467, 0.3603016063570976, 7.103940725326538, 120.14373370579311, 112.40344742366246, 111.34430571964809, 105.30113083975655, 78.36138766152519, 54.532790728977744, 72.16494941711426, 149.8206432887486, 89.85783536093575, 64.91570622580392, 3.5695493050983975, 0.42415300011634827, 0.8178756045443671, 0.47158433496952057, 0.3767628116267068, 0.36162409824984415, 0.5836645322186607, 0.5900880875332015, 1.2062984704971313, 1.0797773110015052, 29.49681227547782, 117.8363481249128, 95.7553482055664, 107.53490720476422, 98.97526850019182, 105.14807592119489, 96.9631118774414, 100.27434539794922, 94.36808477129254, 98.45083236694336, 91.29015786307198, 88.84263406481061, 93.58439745221818, 89.12838568006242, 76.7406369618007, 67.51462432316372, 64.98060934884208, 62.96843882969448, 67.64533383505685, 64.37717914581299, 63.261791774204795, 65.54223918914795, 65.37570476531982, 66.59459250313895, 62.944606508527485, 65.16629300798688, 61.25349834987095, 63.2620974949428, 73.37929303305489, 77.9178216116769, 74.95515836988176, 70.79088061196464, 69.53063024793352, 64.84595326014927, 66.3102583203997, 69.6158846446446, 72.20299080439976, 75.44050393785749, 75.8386982509068, 82.53895037514823, 83.02838148389543, 83.32786273956299, 77.02954305921281, 81.31059224264962, 76.02476406097412, 78.68982206072126, 76.1908676964896, 88.40468910762242, 55.44459935597011, 62.45650945390974, 88.12999902452741, 73.77128260476249, 76.91828850337437, 75.5097427368164, 76.38254070281982, 76.66731262207031, 80.29846899850028, 73.94306986672538, 72.11694431304932, 65.72809655325753, 67.1512474332537, 63.66467612130301, 68.26641246250698, 63.852888924734934, 67.2715346472604, 63.504110200064524, 63.45868982587542, 59.13996750967843, 60.80511025020054, 62.853390557425364, 69.79250090462821, 72.22927583966936, 76.30476951599121, 78.05595874786377, 81.70070580073765, 77.28252696990967, 78.49815600258964, 76.30531842367989, 73.09617478506905, 79.59861864362443, 85.21867602212089, 74.66774613516671, 77.26770646231515, 79.56555216653007, 78.52466338021415, 78.03043801443917, 83.4074821472168, 77.37113039834159, 85.74041625431606, 79.57017271859306, 81.60750266483852, 14.820172343935285, 2.2571101529257636, 1.3607671303408486, 0.42509214686495916, 0.38025471568107605, 0.24009383523038455, 0.4721044184906142, 0.14487588458827563, 0.4021862159882273, 0.16478155074375017, 0.3446810245513916, 21.918915816715785, 41.996048314230784, 64.21278476715088, 50.745028904506135, 40.76797158377511, 29.286327021462576, 64.4515665599278, 75.67868818555559, 89.86057989937919, 98.11503982543945, 74.09536743164062, 1.0746247874838966, 0.15730986238590308, 0.11112186153020177, 0.10341215665851321, 0.1269775964319706, 0.1234838060502495, 0.09568994638643094, 0.1124500734731555, 0.15723440929182939, 0.1633804573544434, 0.1675745772996119, 0.2633677492184298, 0.1908762026578188, 0.16299585013517312, 0.09276258346757718, 0.21600569279066154, 0.2297332026064396, 0.1539110533360924, 0.15426059386559896, 0.13007814862898417, 0.13246581836470536, 0.14116330737514154, 0.19318828359246254], [0.0539526670639004, 0.08183083470378603, 0.07721252180635929, 0.03646669410435217, 0.08895620557346515, 0.043936184008738825, 0.10553266680134193, 0.022967092326975296, 0.013844336582613843, 0.06578861123749188, 0.025337696906977465, 0.10209581229303565, 0.04207836191302963, 0.11675195156463555, 0.022031809835295593, 0.08306698980075972, 0.07032942865043879, 0.29980931377836634, 0.4874281276549612, 13.710994924817767, 94.07038225446428, 77.71926294054303, 71.27633735111782, 43.880608218056814, 41.97468260356358, 46.91665833336966, 94.860399382455, 41.35816894258772, 40.69785731179373, 13.527429597718374, 0.6819369218179158, 0.3192364498972893, 0.2349751027567046, 0.344877012606178, 0.13877357489296369, 0.3898921385407448, 0.07303444242903165, 0.6918199200715337, 1.3309821571622575, 11.960664663996015, 79.83932508741105, 88.60360213688442, 100.95051629202706, 87.93082891191754, 94.84093747820172, 89.86897332327706, 92.34153842926025, 88.2668924331665, 89.55688803536552, 88.52910355159214, 82.05910083225795, 84.08164501190186, 83.99233286721366, 82.77816990443638, 72.64463915143693, 58.31477860042027, 55.8705586705889, 56.58098765781948, 56.401644229888916, 56.99168178013393, 57.75459051132202, 58.19363675798689, 59.176035608564106, 56.65297099522182, 57.056984424591064, 56.46188511167254, 55.06839261736189, 61.02026121956961, 63.02768611907959, 65.17916107177734, 70.40719413757324, 64.28787394932338, 58.05554825919015, 59.378672872270855, 59.5019964490618, 68.22054045540946, 74.67149121420724, 67.11294896262032, 70.48031003134591, 75.16117245810372, 73.30646896362305, 71.94731099264962, 73.08888612474713, 69.23219817025321, 66.31635883876255, 68.90595245361328, 67.28993347712925, 79.30803803035191, 52.451739243098665, 51.79547841208321, 78.55591637747628, 62.38276127406529, 67.71635137285504, 66.62211431775773, 74.1434211730957, 66.67923545837402, 68.40637002672467, 63.587321826389854, 62.71603856767927, 56.161066327776226, 60.69960185459682, 54.5205271584647, 61.85567787715367, 57.763553687504356, 61.823382650102886, 61.70515905107771, 59.39828068869454, 51.84707920891898, 54.598298345293315, 54.80545541218349, 59.818459102085654, 64.39290291922433, 70.46268245152065, 68.37344251360211, 68.44861507415771, 68.92631762368339, 70.23273181915283, 63.64426231384277, 70.36043970925468, 70.28107043675014, 72.72613457271031, 72.2150250843593, 75.91507979801723, 69.86945220402309, 74.0478070122855, 73.4025764465332, 76.16610431671143, 71.24609184265137, 72.78773730141776, 73.27129718235561, 78.32187325613839, 64.50717299325126, 2.343464319195066, 0.27945185186607496, 0.065952314596091, 0.17446439473756722, 0.06464546293552433, 0.47795431315898895, 0.5262425020337105, 0.13652805824364933, 0.08404898603579827, 0.1682650273931878, 1.6486371862036842, 19.03153804370335, 48.41524927956717, 84.96705395834786, 48.36941201346261, 29.632086753845215, 21.459447077342443, 49.81037112644741, 53.696050439562114, 63.38968031747, 67.63320228031704, 9.886334691728864, 0.5144943467208317, 0.10247795643018824, 0.10324087406375579, 0.04067675283710871, 0.06828121641384703, 0.13719105481037072, 0.12372501167867865, 0.11819003868315901, 0.03779871262876051, 0.035889430437237024, 0.04577709701178329, 0.012097567768900521, 0.02475017379038036, 0.05978935744081225, 0.0399848099664918, 0.019004391838929484, 0.040330462490341494, 0.051218805368989706, 0.057488574114228995, 0.07752826450658695, 0.06428343057632446, 0.02292923176927226, 0.09961492541645255, 0.14633146433957986, 0.04864791760753308, 0.06891203006463391, 0.07144380028226546, 0.0281534713493394, 0.022232289791905453, 0.007751623916971896, 0.010450852336362004, 0.04748936316796711, 0.028112906829587052, 0.07002492249011993, 0.08409373542027813, 0.037545296762670786, 0.03262300017688956, 0.09102858044207096, 0.06205989846161433, 0.25200052346502033, 0.49641111705984386, 22.458243676594325, 114.02581705365861, 86.57688208988735, 84.95700686318534, 58.42646394457136, 64.24774810246059, 49.13853243419102, 63.70023700169155, 43.936881678445, 49.02701384680611, 15.102093764713832, 0.7064847445913723, 0.24294829634683474, 0.2759500683418342, 0.2270455661096743, 0.7072800961988313, 0.08814722898283175, 0.3601239930306162, 0.7764707463128226, 1.1135388250861848, 15.924767426082067, 99.3374433517456, 92.46119335719517, 104.05859838213239, 91.81651864733014, 98.00234004429409, 93.80822672162736, 96.39541625976562, 90.89549323490688, 92.26781804221017, 91.50039645603725, 87.59111758640834, 86.67189175742013, 87.95837157113212, 85.87863676888603, 75.93256146567208, 61.700733048575266, 59.44386087145124, 60.35727800641741, 60.13620717184884, 59.682732990809846, 60.811801365443635, 59.62852314540318, 61.93157999856131, 59.29482895987374, 60.20924663543701, 58.73472772325788, 58.32718113490513, 64.12309047154018, 67.73981543949672, 67.09062440054757, 72.49920640672956, 67.62556621006557, 60.29429953438895, 60.59708118438721, 63.88355132511684, 71.22107137952531, 76.01851068224225, 71.66253907339913, 74.72575664520264, 77.78505543300084, 74.01992389133999, 75.38919149126325, 73.82194192068917, 71.61402675083706, 69.68787493024553, 71.65240859985352, 70.69416863577706, 82.34524849482945, 53.48774344580514, 56.008136476789204, 80.63322625841413, 64.65093122209821, 69.20642730167934, 70.31279591151646, 75.20061043330601, 68.26090948922294, 71.7282829284668, 66.55817699432373, 67.46049090794155, 59.37173857007708, 63.93965802873884, 57.20997333526611, 64.56270994458879, 60.61516734531948, 63.794482367379324, 63.61230060032436, 61.773946217128206, 54.641946928841726, 56.945705550057546, 58.507667541503906, 62.5435425894601, 67.04562091827393, 74.96990244729179, 71.26538699013847, 71.40173843928746, 72.42294992719377, 74.07040255410331, 66.29782104492188, 73.52161993299211, 76.16959926060268, 76.77174404689244, 72.83470712389264, 77.63544682094029, 73.93648297446114, 78.04989297049386, 75.45842334202358, 77.14498737880162, 76.52146298544747, 72.8878538949149, 78.89056941441127, 81.26827076503209, 73.72742557525635, 3.867416407380785, 0.44238778735910145, 0.14080786359097275, 0.4236798169357436, 0.07389033293085438, 0.5122638121247292, 0.3417939123298441, 0.24400800519755908, 0.16006403602659702, 0.2930103386087077, 1.165085556251662, 23.54431312424796, 49.20458548409598, 39.46817902156285, 28.164958987917217, 36.05841657093593, 37.3731164932251, 59.82674135480608, 58.99584797450474, 68.39840044294084, 82.8122091293335, 19.584414890834264, 0.8157190574066979, 0.24363095685839653, 0.15668239391275815, 0.10448771608727318, 0.10341440939477511, 0.10765612178615161, 0.10979550198784896, 0.15188607413853916, 0.00548616681979703, 0.04913446453533002, 0.07650966809264251, 0.05165253173825996, 0.035562512265252214, 0.031731181245829375, 0.14119198226502963, 0.024490640931097523, 0.08505108726343938, 0.017116547961320196, 0.048043990906860144, 0.037985469214618206, 0.11299139514033284, 0.06979717221111059, 0.22124021047992365, 0.1957488033388342, 0.18417044462902205, 0.142805117847664, 0.1731740246926035, 0.12216269836894103, 0.16451332585087844, 0.12821968192500727, 0.09584434024457421, 0.20165201728897436, 0.09751407243311405, 0.14625848111297401, 0.17194025803889545, 0.1385693358523505, 0.06931227073073387, 0.210344064448561, 0.13606052047439984, 0.427060495529856, 0.6410078523414475, 26.162951946258545, 134.28385979788644, 97.98325334276471, 102.13451712472099, 66.98952116285051, 63.610890116010395, 61.967849595206125, 133.1343220302037, 56.94733837672642, 67.07314968109131, 20.89294307572501, 0.7886931704623359, 0.8294817017657417, 0.26425052327769144, 0.5441316163965634, 0.6301711052656174, 0.7465216762253216, 0.4368450790643692, 1.8927737602165766, 2.09684539266995, 15.115052155085973, 101.6572870526995, 96.01677417755127, 106.91293225969586, 94.28912544250488, 100.97530051640102, 96.90326009477887, 98.81228460584367, 93.80322401864188, 96.34527111053467, 93.48721994672502, 92.30981990269252, 91.90369769505092, 90.84796755654472, 91.87586321149553, 80.24761513301304, 65.21281814575195, 62.45544637952532, 64.35616779327393, 63.78160040719168, 64.04338768550328, 64.20762920379639, 64.32619326455253, 65.68310001918248, 64.02022933959961, 64.64390659332275, 63.846107482910156, 63.27688326154436, 67.71439892905099, 70.70263154166085, 72.97824301038469, 76.67741530282157, 70.63563006264823, 65.42154897962297, 65.82038252694267, 67.1019847052438, 78.00403485979352, 78.91825798579625, 75.10821328844342, 79.19865253993443, 81.75169168199811, 80.50679683685303, 77.53995772770473, 79.61851828438895, 74.12448733193534, 73.71382795061383, 74.626786504473, 76.69994136265346, 85.03734193529401, 57.576348372868125, 59.882069860185894, 85.614563533238, 69.87184238433838, 73.04333373478481, 74.67069217136928, 79.0808527810233, 71.67957605634416, 74.75201388767788, 70.59835992540631, 70.64754622323173, 62.06214359828404, 66.70842484065464, 61.08669294629778, 69.01364953177315, 63.058570861816406, 67.82714734758649, 67.14887114933559, 66.76300294058663, 57.414048876081196, 60.0630704334804, 60.99613012586321, 66.95228576660156, 70.73649706159318, 76.83661242893764, 75.11773232051304, 75.4934561593192, 76.2387477329799, 78.27896118164062, 69.6817605154855, 77.11284501211983, 78.81270095280239, 78.24760396139962, 75.01789365495954, 81.462632724217, 78.94639819008964, 80.41219016483852, 80.04431084224156, 83.44081960405622, 80.5289615903582, 77.10267979758126, 83.40976810455322, 85.12522275107247, 74.74852589198521, 3.373694351741246, 0.8709913258041654, 0.8414344489574432, 0.4235948643514088, 0.4212234930268356, 0.9917225731270654, 1.701174035668373, 0.300624777163778, 0.5299070796796254, 0.391211780586413, 3.0602585077285767, 34.20702736718314, 72.65941102164132, 113.20489433833531, 66.27418327331543, 40.20267309461321, 35.897666522434776, 68.51365716116769, 73.63743250710624, 79.53784275054932, 96.17298357827323, 19.39783491407122, 0.8308273181319237, 0.4062807948461601, 0.2365285408283983, 0.17047825934631483, 0.25949798258287565, 0.21856761031917163, 0.2680584618023464, 0.3763826148850577, 0.13184529809015139, 0.13694991703544343, 0.1273955875741584, 0.2073585239372083, 0.09158567804843187, 0.2227684749024255, 0.3607436583510467, 0.08200567282204117, 0.15160183581922734, 0.1368839227195297, 0.15211221628955432, 0.13980817794799805, 0.22421660433922494, 0.15640890358814172], [0.08207798429897853, 0.039683543810887, 0.0601000382698008, 0.047572748336408816, 0.039736795239150524, 0.1015940560027957, 0.053455894613372426, 0.05061164544895291, 0.05018975951575807, 0.11032359222216265, 0.026568603535581912, 0.09626119823328086, 0.06409460785133497, 0.10621584299951792, 0.07180699293634721, 0.09119004463510853, 0.0313140823771911, 0.22580510910068238, 0.2598116286098957, 32.57051467895508, 90.16846152714321, 79.26044287000383, 67.35265486580985, 60.30667427607945, 24.937711817877634, 56.79769154957363, 101.09895065852574, 48.61248779296875, 34.45972292763846, 1.016593975680215, 0.08212261833250523, 0.07760568535221474, 0.026169879395248632, 0.1777211728372744, 0.3157467171549797, 0.10517433245799371, 0.5964657195976802, 1.0516275529350554, 3.544215955904552, 98.09432029724121, 103.68354851858956, 96.65379197256905, 90.33013916015625, 91.96368844168526, 89.56568445478166, 91.136123248509, 88.36295127868652, 90.94002423967633, 88.92998681749616, 83.06369222913469, 82.98954800197056, 85.47980322156633, 84.29665701729911, 83.61568491799491, 69.41024575914655, 60.870423316955566, 56.927403994968955, 56.27933161599295, 55.8759400503976, 57.521905762808665, 54.986574104854036, 57.74624572481428, 57.84407288687569, 57.74559954234532, 54.855141980307444, 53.61203977039882, 56.77550595147269, 61.49742875780378, 64.84621729169572, 65.40909780774797, 65.85413687569755, 61.64318111964634, 58.76418808528355, 60.31742313929966, 59.69887365613665, 67.86054733821324, 69.82326057979039, 82.41871874673026, 69.422043800354, 72.43846525464738, 70.02040876661027, 73.76322964259556, 67.46716812678746, 70.14008453914097, 66.07661819458008, 74.53875977652413, 65.06265367780412, 80.64459351130894, 46.92453064237322, 53.5173636163984, 80.16891983577183, 62.438249588012695, 67.29202488490513, 65.58114910125732, 71.05828203473772, 66.65422194344657, 65.7576263972691, 58.129800183432444, 58.07492331096104, 55.8759435244969, 57.01437112263271, 56.72385304314749, 57.158730370657786, 58.942506653921946, 62.53139019012451, 62.22407831464495, 58.022526945386616, 54.211735316685264, 51.140447412218364, 54.882170472826274, 60.416879653930664, 63.35024929046631, 66.14550958360944, 68.0189801624843, 67.62512847355434, 68.04737745012555, 64.95004422324044, 67.39207199641636, 69.56148024967739, 73.72424330030168, 75.04021821703229, 76.39756270817348, 70.38787119729179, 74.43620436532157, 72.76477350507463, 74.79792758396694, 72.85170936584473, 73.36225605010986, 68.63420145852226, 74.153947693961, 68.2009048461914, 88.87385926927838, 36.69766126360212, 0.4541124382189342, 0.43298329200063435, 0.07086834151829992, 0.19689582607575826, 0.0627651677599975, 0.21600817622882978, 0.27781297266483307, 0.20158237245466026, 0.08557425811886787, 0.13915252313017845, 5.509320029190608, 24.490251302719116, 56.45846659796578, 61.57169805254255, 27.749083246503556, 19.514993701662334, 26.442672525133403, 49.100452831813264, 57.72280945096697, 69.50806249891008, 42.07736655644008, 0.42097639771444456, 0.11818727026028292, 0.03936597924413426, 0.16248662317437784, 0.06189581512340477, 0.005492464472938861, 0.0742914489071284, 0.05824212796453919, 0.004882311365301055, 0.049537137749471834, 0.04109388902517302, 0.06436911597847939, 0.058341587627572675, 0.025714731675439646, 0.05236286630055734, 0.09535139133887631, 0.07192861355308976, 0.0507234544493258, 0.14633833111396857, 0.06685463724923985, 0.0852132842742971, 0.07172021509281226, 0.08440107785697494, 0.10027214765016522, 0.02595187966445727, 0.13256682508758136, 0.05013566670407142, 0.08243749250790902, 0.07468439532177788, 0.06369599566927978, 0.033269301389477084, 0.07332847879401275, 0.059223011402147155, 0.10867493533130203, 0.10548050102910825, 0.14074808465582983, 0.0368963153367596, 0.09611265334699835, 0.042567969033760686, 0.13723653022732052, 0.34454265769038883, 43.76388890402657, 109.52555915287563, 87.39949321746826, 81.68648978642055, 71.1373108455113, 31.59172194344657, 34.56138896942139, 88.26075717381069, 52.67105565752302, 39.92674970626831, 0.7690842683826173, 0.07554660976997443, 0.1555022858083248, 0.1765731322978224, 0.27165176612990244, 1.1971733144351413, 0.5488251245447567, 1.4595491268805094, 0.9681680713381086, 6.301672620432718, 105.9865289415632, 105.28282928466797, 100.2991852079119, 92.432268006461, 96.07950251443046, 91.71772915976388, 93.73689651489258, 90.65245914459229, 93.94989354269845, 91.5544742856707, 88.64604868207658, 86.73104177202497, 89.17474406106132, 85.63597093309674, 86.38832187652588, 71.0630693435669, 62.78716727665493, 59.437746456691194, 60.90125247410366, 59.597881589617046, 60.50916562761579, 58.828180994306294, 60.023236410958425, 61.26349680764334, 60.840476581028526, 56.19606440407889, 56.23716299874442, 61.07130963461739, 63.298519951956614, 68.08921950204032, 68.39644799913678, 68.04485525403703, 64.11174406324113, 61.08966677529471, 64.24937398093087, 63.86027485983712, 71.01573126656669, 73.59448569161552, 82.70695781707764, 70.45801326206752, 77.54929610661098, 73.15604741232735, 76.33449390956334, 71.87807219369071, 72.18835094996861, 69.16350133078438, 76.00652503967285, 68.39742074693952, 84.11434323447091, 48.76100901194981, 57.30619546345302, 82.97785418374198, 66.33775234222412, 71.32959529331752, 68.36272839137486, 73.43904754093715, 70.7774497440883, 67.32347243172782, 59.456124441964285, 59.59811782836914, 59.18339375087193, 60.70901666368757, 58.92993041447231, 58.59116404397147, 61.820895195007324, 65.67348371233258, 64.63843141283307, 62.08475998469761, 57.53630243028913, 53.73467200142996, 56.522011348179404, 63.496967451913015, 66.00662204197475, 67.3146412713187, 70.70124885014125, 71.38509750366211, 71.73777416774205, 68.83997930799211, 70.65211118970598, 74.63686139242989, 74.72761181422642, 76.62453951154436, 77.85031291416713, 73.64524228232247, 76.84095505305699, 75.55125822339738, 79.01738098689488, 75.78570434025356, 77.03421224866594, 72.59325722285679, 76.97884205409459, 72.04763603210449, 92.33932890210832, 46.37129075186593, 0.059033259084182124, 0.36895957748804775, 0.29966361873916214, 0.6060410972152437, 0.6955395947609628, 0.20314719634396688, 0.4191186231161867, 0.4972012032355581, 0.09145819488912821, 0.11455299598830086, 4.481793931552342, 29.84662628173828, 54.554597650255474, 38.82176726205008, 26.22555695261274, 29.155787740434917, 33.47467333929879, 60.05537182944161, 67.0338715144566, 77.42666734967912, 58.09428794043404, 0.7816524739776338, 0.09653396252542734, 0.0608845129609108, 0.1111089965062482, 0.022596808981948664, 0.03487391796495233, 0.015145946560161454, 0.0229962082646255, 0.027767276358125464, 0.1331714540719986, 0.0256427628586867, 0.060086067233766825, 0.059971917287579606, 0.04307045474914568, 0.027793091222909943, 0.0814247586365257, 0.038883038729961426, 0.017319346811356287, 0.033986027751650126, 0.1202967134969575, 0.007444352726452053, 0.07022475783846208, 0.14415757384683403, 0.217893105798534, 0.1965140551328659, 0.18128895067742892, 0.10427525320223399, 0.18629618627684458, 0.1336892984275307, 0.13316973059305123, 0.1557271116014038, 0.16824034228920937, 0.1261496480022158, 0.1680340405021395, 0.21460618717329843, 0.2297993190586567, 0.21589810427810463, 0.23452992950166973, 0.12085962614842824, 0.24888469065938676, 0.6341666451522282, 54.04832410812378, 126.09118325369698, 103.73284598759243, 93.22026320866176, 76.67645645141602, 39.01711933953421, 71.45045920780727, 130.34250804356165, 67.52588040488106, 56.74669177191598, 1.3579431218760354, 0.2419362206544195, 0.21965615690818854, 0.34229697819267, 1.8263776430061884, 2.325592032500676, 0.7040236709373338, 3.937255791255406, 2.179789513349533, 5.33276413168226, 108.29774297986711, 107.68757997240338, 104.67660590580532, 97.81364781515938, 97.70045471191406, 96.22829818725586, 95.09038475581578, 97.58300236293248, 98.62774045126778, 93.50763375418526, 92.70447758265904, 90.2860528400966, 92.65859862736293, 92.26216915675572, 88.6823947089059, 75.953524180821, 67.55155399867466, 63.759977613176616, 65.01412745884487, 63.532632555280415, 65.30838366917202, 63.91308116912842, 63.92533779144287, 64.52966431209019, 63.93150084359305, 61.98130825587681, 59.53811318533761, 64.6666897365025, 66.87616130283901, 72.58888680594308, 71.72984627314976, 72.52692971910749, 67.6392263684954, 66.37539768218994, 66.40011937277657, 67.28452777862549, 75.30051163264683, 79.46692248753139, 81.89005810873849, 71.88366549355644, 79.88377271379743, 79.55584553309849, 80.52902412414551, 74.900712285723, 75.83181953430176, 74.34077780587333, 80.16957296643938, 72.01653589521135, 86.94804096221924, 52.422688824789866, 61.46411214556013, 87.31173746926444, 68.4419448035104, 73.8140835080828, 71.13811683654785, 76.0913416998727, 75.69941466195243, 71.3306861604963, 62.77563326699393, 63.699305943080354, 63.22459806714739, 62.73356192452567, 62.82051168169294, 62.48891585213797, 64.81381784166608, 67.3973456791469, 67.91142899649483, 64.28398295811245, 60.447854723249165, 57.22628423145839, 61.37106187002999, 66.06292329515729, 69.52002034868512, 70.43390996115548, 75.36619295392717, 74.25915036882672, 74.0191317967006, 72.38529763902936, 75.58088534218925, 77.1847310747419, 80.09226036071777, 80.42154244014195, 80.86244732992989, 79.0860847745623, 80.13961233411516, 79.77226107461112, 81.70559038434709, 77.47344957079206, 81.44740922110421, 76.48156642913818, 81.69147164481026, 73.70238426753453, 96.89752783094133, 45.058505058288574, 0.6687340959906578, 1.0316885028566634, 0.4230668826826981, 0.4929689903344427, 1.202928594180516, 0.6177166221397263, 0.8807930084211486, 0.4836847313812801, 0.38707722244518145, 0.215775533712336, 9.220620836530413, 40.10449504852295, 78.63425731658936, 86.13338552202497, 37.19496120725359, 29.98929364340646, 40.18419436046055, 71.63939462389264, 76.04943016597203, 93.70000158037458, 61.10001959119524, 0.7597373127937317, 0.1882723516651562, 0.15408720102693352, 0.210206091137869, 0.15708814428320952, 0.10165591804044587, 0.11069819783525807, 0.13961522973009519, 0.0672637192266328, 0.21898227663976805, 0.12247660223926816, 0.15018178416149958, 0.19464085064828396, 0.11703583704573767, 0.14156177027949265, 0.16501830518245697, 0.105526010372809, 0.1391717663833073, 0.2086287143507174, 0.09850708807685546, 0.15678896462278707, 0.09110677481762], [0.11840510714266982, 0.025094342018876756, 0.022708419510828595, 0.04087110901517527, 0.06266334679509912, 0.02961821641240801, 0.05533287175265806, 0.061727585936231275, 0.0742101196997932, 0.08292299788445234, 0.19368218923253672, 0.04962028203798192, 0.05384592332744172, 0.1300971204681056, 0.07323161792010069, 0.048974733999265094, 0.09360858771417822, 0.06592853872903756, 0.45535157886998995, 52.087191581726074, 80.12327017102922, 76.2955631528582, 76.92996842520577, 70.89344297136579, 61.271911076136995, 95.3875731059483, 80.91919326782227, 51.105359009334016, 8.95549842289516, 0.275897739721196, 0.12027364330632345, 0.10566375298159462, 0.050498170645109246, 0.04811828709872706, 0.27616369830710547, 0.6892543520246233, 0.42381609390888897, 0.32899489626288414, 80.4721600668771, 99.50254644666398, 89.74749101911272, 86.78198596409389, 84.05683299473354, 84.34471770695278, 84.6688928604126, 82.85753917694092, 84.53179100581578, 92.66923631940568, 81.60912159511021, 79.71737725394112, 76.28962939126151, 78.47909014565604, 83.04330621446881, 74.99973106384277, 58.931549344744, 58.341230392456055, 56.707288537706646, 55.79561540058681, 56.65268611907959, 56.83239432743618, 55.63720689501081, 56.628867694309776, 57.427851472582134, 54.531668594905305, 51.82445934840611, 55.88555288314819, 57.862520354134695, 63.86803599766323, 69.8687504359654, 68.93457208360944, 61.689539500645225, 58.97387777056013, 55.75313411440168, 60.36836733136858, 60.127243995666504, 67.0646172932216, 65.4022468839373, 69.80835669381278, 76.14480113983154, 70.25689765385219, 72.3206377029419, 68.75673988887242, 67.55186666761125, 68.36591761452812, 67.35432938167027, 69.70613479614258, 65.82701805659703, 76.95152173723493, 48.210326058524, 51.923696994781494, 77.23097828456334, 61.24007443019322, 64.21124226706368, 62.1090578351702, 68.67142295837402, 62.152171407427105, 63.281899860927034, 52.52536582946777, 57.101282664707725, 51.84219115121024, 55.978509357997346, 54.74574954169137, 53.554116112845286, 55.095754623413086, 59.638347898210796, 57.54282678876604, 59.82155105045864, 55.69521740504673, 52.27338593346732, 50.90704352515084, 58.546174458095, 59.339630944388254, 65.85360881260463, 65.28969996316093, 67.54841341291154, 66.50339739663261, 66.85048076084682, 61.24698093959263, 71.13820021493095, 65.52386815207345, 70.5377299445016, 73.26129872458321, 69.78847094944545, 68.77349199567522, 75.37485735757011, 74.1136759349278, 74.47242532457624, 70.91337040492466, 72.2020319529942, 66.51060267857143, 74.39104802267892, 71.04551819392613, 80.96840041024345, 9.31937210900443, 0.630213988678796, 0.703925256218229, 0.03458351515499609, 0.16405030712485313, 0.14146392552980355, 0.040955725724675825, 0.31904819714171545, 0.07693114011947598, 0.07671546776379858, 0.07040433891649757, 14.594183921813965, 31.049203123365128, 50.84761905670166, 52.89112247739519, 31.935911382947648, 34.82591036387852, 44.621762139456614, 59.01727621895926, 60.0755216053554, 68.01080908094133, 6.499028818947928, 0.5787503644824028, 0.06777094450912305, 0.06171267173652138, 0.021492477972060442, 0.08969690118517194, 0.04310494807681867, 0.021749140628214394, 0.07077489367553166, 0.05851737569485392, 0.023325984765376364, 0.062173179882977686, 0.12009438792509691, 0.12238550212766443, 0.027748765922816734, 0.018075187324679325, 0.031826742725180726, 0.06396049540489912, 0.0020443392859306186, 0.019765609742275307, 0.027662566530385187, 0.10604620245950562, 0.02310346090234816, 0.01303768397441932, 0.0094903690540897, 0.03576075644897563, 0.04056275895397578, 0.03882610285654664, 0.07650909133787666, 0.0670750050672463, 0.036699954087712934, 0.048209668802363534, 0.09218444449028798, 0.027315707910539846, 0.0967494584619999, 0.05585457357977118, 0.02484868180805019, 0.029675630653010945, 0.06370400238249983, 0.051114578997450213, 1.1369593569210596, 76.82279246194022, 90.53722327096122, 90.37826238359723, 87.70082964215959, 86.98274026598249, 52.769716603415354, 73.68971770150321, 87.97119794573102, 51.93399422509329, 11.016280276434761, 0.432651515517916, 0.06612422144306557, 0.5768051402909415, 0.3134439321500914, 0.4108912231666701, 0.7978956252336502, 1.0440191669123513, 0.5299690163561276, 1.2687213037695204, 93.33457497188023, 101.07504190717424, 95.36003739493233, 89.21443217141288, 89.16608660561698, 87.27198682512555, 89.29379449571881, 86.76438617706299, 88.46201174599784, 89.39953913007463, 84.68015589032854, 81.80141993931362, 81.31972912379673, 83.54145731244768, 86.80977875845772, 76.61926582881382, 62.78953661237444, 61.21654782976423, 62.309568950108115, 60.204216139657156, 59.58036518096924, 60.50428104400635, 59.27923025403704, 58.300548689705984, 59.81629821232387, 58.32917526790074, 55.29180152075631, 57.811319078717915, 61.33745343344552, 66.88063594273159, 75.3988286427089, 70.23182160513741, 65.0105630329677, 62.361381667000906, 59.288179533822195, 64.02173015049526, 64.49658393859863, 69.90550640651158, 70.29322283608573, 73.12628827776227, 77.52036380767822, 71.80642931801933, 73.9996143068586, 72.1910537992205, 71.41318212236676, 70.55860233306885, 71.58314200810024, 71.91599546160016, 69.47939423152378, 79.40178312574113, 47.70960760116577, 55.65503249849592, 79.54920305524553, 62.57824189322335, 65.98315797533307, 65.1806549344744, 71.9260356085641, 64.24111257280622, 64.44045639038086, 54.04813303266253, 60.131385122026714, 55.02579321180071, 59.97767012459891, 58.219136646815706, 56.82178790228707, 57.4794487953186, 62.818086760384695, 60.78710051945278, 61.58855438232422, 57.26236970084054, 53.85737024034773, 56.11092812674386, 60.74036693572998, 62.24350547790527, 69.07446711403983, 68.01460279737199, 70.51781640733991, 69.61981037684849, 68.71169471740723, 65.0439143862043, 74.03714847564697, 69.99362346104213, 74.18989072527204, 74.79154913766044, 73.4945011138916, 71.14934512547084, 76.95857415880475, 76.21164281027657, 78.04235417502267, 72.29982089996338, 74.54017720903668, 69.7051203591483, 80.13643700735909, 72.87951605660575, 89.1769049508231, 14.12690019607544, 0.9043579867907933, 0.3119284648980413, 0.7332682045442718, 0.6091501989534923, 1.2554555641753333, 0.32691106093781336, 0.8186528799789292, 0.03575202709596072, 0.08229370415210724, 0.0792193366214633, 15.167736870901924, 36.08552496773856, 39.47175734383719, 27.480592693601334, 34.668724741254536, 43.246053559439524, 52.5994371005467, 67.65156636919293, 67.04708003997803, 83.60112844194684, 13.571178061621529, 0.674974826829774, 0.13802580216101237, 0.02606124254608793, 0.01646569208241999, 0.1063564218846815, 0.025185506591307263, 0.0392335190304688, 0.060080944294376035, 0.0202608911120998, 0.041164802719971964, 0.034526358757700236, 0.036907121006931574, 0.07103183453104325, 0.033934099466672966, 0.02888040796720556, 0.05999331149671759, 0.07699776547295706, 0.03163364522957376, 0.06775597602661167, 0.07021456624248198, 0.1322512248797076, 0.1212348153016397, 0.12646573675530298, 0.13143650788281644, 0.0989024161494204, 0.16624528648597853, 0.11939450619476182, 0.20983839301126345, 0.1810167631400483, 0.10717673001012631, 0.13090691130076135, 0.2761306400809969, 0.08800376632383891, 0.17987360805273056, 0.24017642651285442, 0.10759648534336261, 0.2231164276599884, 0.1775241805506604, 0.1433689533067601, 1.924734605210168, 93.8862897327968, 108.24084418160575, 100.65512752532959, 100.96145275660923, 86.09103625161308, 76.34250518253872, 134.53254972185408, 92.39337199074882, 67.40297372000558, 15.128910337175641, 0.4881701192685536, 0.5147486616458211, 0.3884589640157563, 1.210669864501272, 1.200268519776208, 1.1508783357484, 4.302990726062229, 3.784642083304269, 0.9476430927004132, 94.54206766401018, 102.87578569139752, 99.31160300118583, 92.16189275469098, 94.48513412475586, 91.56516756330217, 92.33509050096784, 91.25108119419643, 90.73700482504708, 94.3577458517892, 89.7845457621983, 88.30928339276994, 84.157317842756, 86.41334233965192, 91.22653320857457, 81.87379932403564, 66.35756860460553, 64.13633373805455, 64.96860980987549, 62.558404786246165, 64.64285046713692, 64.02919251578194, 61.9134521484375, 62.18411922454834, 64.2812453678676, 61.83868258340018, 59.9369467326573, 62.02863938467843, 65.63266999380929, 70.68569878169468, 78.18415996006557, 74.1587141581944, 66.92484733036586, 64.1565043585641, 64.13201195853097, 65.71448503221784, 68.29632445744106, 72.61317076001848, 73.21462072644914, 79.3095805304391, 77.48705414363316, 78.38507407052177, 76.44533157348633, 75.4725420815604, 75.21627862112862, 74.74913038526262, 77.36583587101528, 75.75135244641984, 72.61490086146763, 82.420302936009, 50.85854857308524, 59.28753335135323, 83.15081569126674, 66.7222934450422, 67.91233226231166, 69.11173725128174, 75.98383222307477, 69.35705035073417, 70.25110980442592, 57.396414348057334, 63.195102964128765, 57.9343820980617, 64.18228912353516, 62.02855600629534, 59.71103995186942, 61.191888672964915, 66.09502397264752, 62.918279784066335, 65.47038786751884, 63.308483668736045, 57.62050417491368, 59.54635374886649, 64.3048345020839, 66.62682519640241, 72.91299942561558, 71.58357974461147, 74.29683739798409, 73.80012457711356, 72.96239416939872, 68.79981177193778, 76.70337377275739, 72.92323412214006, 78.1892043522426, 78.23577117919922, 75.7857390812465, 75.73145280565534, 79.39760725838798, 80.1272862298148, 81.42123535701207, 75.43370165143693, 79.03716945648193, 74.51010540553501, 82.8063656943185, 76.05580166407994, 92.08158547537667, 12.358018245015826, 2.161232177700315, 3.2659816401345387, 0.758993421282087, 0.41906100192240303, 2.004055891718183, 0.904115939778941, 1.287040337920189, 0.1536111408578498, 0.1942821363253253, 0.39717284643224304, 26.18157138143267, 44.7815637588501, 72.78466619764055, 73.38465009416852, 43.819286891392295, 50.98842082704817, 60.8577150617327, 80.8314653124128, 77.32885755811418, 96.130113192967, 12.842946921076093, 0.7703294615660394, 0.11986201682261058, 0.15400892522718224, 0.1083920540820275, 0.12199211466525282, 0.12896731894995483, 0.13558835509632314, 0.17668498201029642, 0.18441122956573963, 0.12386386708489486, 0.10635765003306524, 0.14081603315259728, 0.1813742153878723, 0.11488496246082441, 0.10098853813750402, 0.13515483907290868, 0.11564097260790211, 0.14284798769014223, 0.1343489158898592, 0.17682690439479692, 0.23310785580958637], [0.03647366605166878, 0.09657493925520352, 0.042267255884196074, 0.1325462790472167, 0.022352003725245595, 0.05864697588341577, 0.1324456658746515, 0.02950201729046447, 0.09713048301637173, 0.004326056414616427, 0.09446390824658529, 0.01483719955597605, 0.09768790631954159, 0.11391317817781653, 0.10927506562854562, 0.1269757372460195, 0.2285506517759391, 0.4404704102448055, 8.674087694713048, 85.50287124088833, 79.90714645385742, 70.79470212118966, 47.907808440072195, 32.75128943579537, 24.820632934570312, 48.12279960087368, 56.008709703172954, 34.2945989881243, 0.09359511200870786, 0.2806173036141055, 0.05270751119990434, 0.25028735824993675, 0.39471245131322313, 0.12395202235451766, 1.4155516134841102, 2.0030064965997423, 0.7138476095029286, 45.31677654811314, 105.14128753117153, 86.088625226702, 90.71021951947893, 80.60799734933036, 84.5961035319737, 79.68603393009731, 82.93650545392717, 85.1876940046038, 90.38109030042375, 80.1292039326259, 79.4732106072562, 74.70636422293526, 72.88337925502232, 70.90746443612235, 67.64994743892125, 60.09759603227888, 58.94388934544155, 61.09163311549595, 58.25740385055542, 58.186483587537495, 57.93477814538138, 57.25979191916329, 56.45423514502389, 56.639689513615195, 55.87618671144758, 51.13513551439558, 54.503448486328125, 55.28352621623448, 57.33469697407314, 67.35655975341797, 73.80905996050153, 70.32578904288155, 63.021696771894185, 55.07125527518136, 53.96649169921875, 59.121186528887065, 60.77959646497454, 64.67770957946777, 71.17287172589982, 68.81784234728131, 69.62459073747907, 72.09131935664585, 68.92122459411621, 70.00129427228654, 66.30516529083252, 70.10151508876255, 67.32443823133195, 70.99306624276298, 67.0012914112636, 76.276337487357, 43.528400557381765, 55.47430290494646, 73.8057804107666, 64.87783159528459, 62.368454933166504, 56.94897467749459, 62.30031394958496, 55.15491853441511, 54.45049973896572, 50.842588560921804, 51.58183520180838, 50.28345659800938, 50.67281975064959, 50.30441583905901, 51.10774571555001, 54.069071429116384, 60.005553245544434, 64.23139899117606, 60.69696848733084, 54.033406325748985, 51.96578918184553, 49.42432573863438, 51.31475339617048, 53.93466894967215, 56.718145098005024, 58.028620515550884, 62.20201083592006, 61.66812515258789, 61.74650778089251, 62.75168282645089, 70.50600446973527, 71.29552827562604, 70.72301755632672, 67.4108668736049, 64.05563735961914, 67.13343225206647, 71.58873530796596, 72.15113639831543, 71.84832000732422, 71.08587333134243, 68.14785534994942, 64.74150099073137, 68.16804681505475, 72.9243527821132, 74.59790284293038, 62.07629707881382, 0.8252942721758569, 1.0813991725444794, 1.2689867466688156, 0.44974679819175173, 0.08220465321625982, 0.24369302924190248, 0.20109857698636396, 0.2967434211501053, 0.22595619170793466, 0.37553322474871365, 3.03545452441488, 21.26006851877485, 30.811074461255753, 82.2809498650687, 31.098306042807444, 24.642024278640747, 51.31555591310774, 56.280526706150596, 58.31891972678048, 68.43130711146763, 34.06802518027169, 0.5419290374432291, 0.08528710209897586, 0.018674498290887902, 0.012233074604799705, 0.07956256677529641, 0.12693518799330505, 0.046409322015408955, 0.01956998979273651, 0.06498025889907565, 0.05413457890972495, 0.049379700661769936, 0.03404721125428166, 0.08861054626426526, 0.10514058212616614, 0.08050506548689944, 0.04152288939803839, 0.08102812099137477, 0.03744353347324899, 0.06331601605883666, 0.0933141577988863, 0.07672319627766098, 0.07792942798031227, 0.06011232653898852, 0.11233857659889118, 0.11432468252522604, 0.08849202655255795, 0.06971500840570245, 0.10210704883294446, 0.026838107466963784, 0.039678207132965326, 0.07210472053182976, 0.08407849552375929, 0.04424901918641158, 0.0992342062028391, 0.005155706695014877, 0.1418776690427746, 0.07391937422965254, 0.30967979984624044, 0.5586482488683292, 16.939468451908656, 103.88473360879081, 89.60585893903459, 81.23042392730713, 60.688199860709055, 44.88650587626866, 28.747629710606166, 61.4497641154698, 61.60572338104248, 36.357786655426025, 0.09342137990253312, 0.24717578664422035, 0.2045888796980892, 0.5062001517840794, 0.5804212433951241, 0.4223372946892466, 2.8351034351757596, 0.5313747780663627, 0.5302335364477975, 56.89722796848842, 107.78482001168388, 91.89261531829834, 91.55928243909563, 84.61646175384521, 86.98474829537528, 85.22768783569336, 86.44100311824253, 87.38763959067208, 91.85369845799038, 83.93843569074357, 82.91817610604423, 77.79824311392647, 73.9696397781372, 74.96312795366559, 69.90431826455253, 61.342914717538015, 61.77644756862095, 62.834380286080496, 59.19858251299177, 60.28283500671387, 60.50555951254708, 59.772086824689595, 58.47087682996477, 59.691710063389365, 59.25861494881766, 54.3965539251055, 57.21609122412545, 59.037870679582866, 61.57383114950997, 72.03661618913922, 77.29183755602155, 73.00578566959926, 63.17245878492083, 58.12655537469046, 56.10882977076939, 61.464904240199495, 63.13044997623989, 67.95078359331403, 73.57137598310197, 70.75597286224365, 74.14308071136475, 73.38676929473877, 72.29014900752476, 73.73879977634975, 70.06623908451625, 72.74877875191825, 69.64806870051792, 75.69977596827916, 69.23459529876709, 78.84029919760567, 45.15892737252371, 57.129068510872976, 77.22845608847481, 69.91074534824916, 66.55257674625942, 59.38429396493094, 64.02544048854283, 59.892429624285015, 56.804823875427246, 53.99815116609846, 55.0978182383946, 53.51487616130284, 53.80743701117379, 52.719158036368235, 54.399020535605295, 58.063601221357075, 63.794920103890554, 66.97691713060651, 62.753385135105674, 56.82200329644339, 54.60012919562203, 52.46029594966343, 53.247929845537456, 56.905683926173616, 58.43639292035784, 60.57381861550467, 64.7258744921003, 64.57781532832554, 63.37424142020089, 65.67330305916923, 73.93861607142857, 74.57664830344063, 73.73750741141183, 70.86005687713623, 65.36932631901333, 70.96266092572893, 74.97101415906633, 75.60415485927037, 75.07163797106061, 74.9097102028983, 71.66935525621686, 69.27110113416398, 70.95075171334403, 79.45709773472377, 76.06869752066476, 74.02020181928361, 2.038576062236513, 1.2892791777849197, 0.7961904938731874, 1.235752752849034, 0.28534462994762827, 0.8677499911614827, 0.019815846778718487, 1.343318140932492, 0.7952566125563213, 0.5734640881419182, 2.385621645620891, 24.877736704690115, 33.95728479112898, 57.10501732145037, 24.494706835065568, 36.9184159551348, 59.37285723005022, 65.87835829598563, 66.43404047829765, 76.61858490535191, 54.33565991265433, 0.9853346816131047, 0.041221073629068475, 0.03438283163788063, 0.038362514161105664, 0.07285562131021704, 0.07123862486332655, 0.021428541313590746, 0.02170597731934062, 0.03311140629063759, 0.02011098406676735, 0.05022181351003902, 0.03611958612288747, 0.00488249584200925, 0.06660453602671623, 0.07651229402316467, 0.051167263848973174, 0.047946095267044644, 0.07517574967018195, 0.07142433311258044, 0.07435476979506866, 0.004622476982019309, 0.1001460487022996, 0.18852768439267362, 0.19711952550070627, 0.312842532992363, 0.13942466995545796, 0.1580219848879746, 0.2304359477545534, 0.18523908300059183, 0.16698103557739938, 0.09122742512928587, 0.20777563298387186, 0.09973082598298788, 0.28148919397166794, 0.11798128059932164, 0.29412897144045147, 0.22855396302683012, 0.3879844237651144, 0.7762277222105435, 21.99027555329459, 121.88685607910156, 102.4220335824149, 95.04721559797014, 67.75471932547433, 49.01767546789986, 36.54866756711687, 69.72080939156669, 68.13072804042271, 55.20091560908726, 0.2741418539413384, 0.4820471278258732, 0.4980461693235806, 1.2467235241617476, 1.0290339652981078, 0.7693157845309803, 6.906206284250532, 7.365944266319275, 0.8995698637195996, 58.769371441432405, 111.7840016228812, 93.62411335536412, 94.80972617013114, 91.42300047193254, 90.40977941240583, 86.92429201943534, 88.84019524710519, 89.51720687321254, 96.62588105882917, 90.79442473820278, 86.52877276284354, 81.44566522325788, 77.66747106824602, 78.65342739650181, 74.20478766305106, 66.70336655208042, 65.21758460998535, 68.43441990443638, 62.92331722804478, 63.255274363926475, 64.55128015790666, 63.79478808811733, 62.17104271480015, 63.926908084324424, 63.08653041294643, 56.807113306862966, 63.217038427080425, 62.99975436074393, 64.54805619376046, 73.83239201136998, 80.90152399880546, 76.18476022992814, 68.51855564117432, 64.57848930358887, 60.950341497148784, 67.46486827305385, 66.59735093797956, 73.83618572780064, 75.77578231266567, 74.97343213217599, 76.45778274536133, 75.00289249420166, 77.1236355645316, 75.06060423169816, 72.42019149235317, 75.77327401297433, 75.18476854051862, 78.15809031895229, 72.77107552119664, 81.13736670357841, 48.67686980111258, 62.93691485268729, 80.19772706712995, 74.29324517931256, 70.95701204027448, 61.71951402936663, 67.4679810660226, 63.890096528189524, 61.27834510803223, 56.54612854548863, 58.502400806971956, 55.93092461994716, 56.86317137309483, 57.82607010432652, 57.21131781169346, 61.57385894230434, 64.93315315246582, 69.75237505776542, 66.03566551208496, 59.938892228262766, 58.399789810180664, 56.40525034495762, 57.34607464926583, 59.60910293034145, 65.04557500566754, 65.98460320064, 68.89000633784703, 67.73702226366315, 67.29463045937675, 69.25429344177246, 77.46306896209717, 79.18501322610038, 77.90081242152623, 75.90617915562221, 70.68790136064801, 76.13981233324323, 79.21421650477818, 78.42914649418422, 77.43394211360386, 77.65975161961147, 75.69338362557548, 73.69212872641427, 74.93766280582973, 82.78051839556012, 80.18399742671421, 73.95802239009312, 1.2924014159611292, 3.5728863946029117, 4.756811448505946, 2.4267195888928006, 0.5379102102347783, 1.7806095331907272, 1.1687772210155214, 0.8785599768161774, 0.8391674363187381, 0.6716833891613143, 5.316264765603202, 37.961104324885774, 45.45837736129761, 115.2361307144165, 40.54617813655308, 35.82019410814558, 65.16969067709786, 77.73710591452462, 75.69931043897355, 91.27060563223702, 56.96410437992641, 1.1360327494995934, 0.1044243002044303, 0.12218437077743666, 0.13204537092575006, 0.20962282243583882, 0.2772423247141497, 0.1291260825736182, 0.2095526619149106, 0.19366975847099507, 0.10620573282774005, 0.17473958139973028, 0.17255767062306404, 0.11863219924271107, 0.16627565771341324, 0.13664325991911547, 0.1414673589169979, 0.1264079391424145, 0.18149141195629323, 0.18578568367021425, 0.16686020206127847, 0.16509780234524182], [0.09985713527670928, 0.061093393181051524, 0.0887764480763248, 0.017835968107517277, 0.03240322268434933, 0.02920821841273989, 0.07753201680524008, 0.053204293828457594, 0.0887959763141615, 0.024500656107972776, 0.08995504304766655, 0.0300543855077454, 0.11938552239111491, 0.05822669129286494, 0.08181073649653367, 0.06140929872968367, 0.04410647933504411, 0.3801622177873339, 26.216383593423025, 81.3868487221854, 73.86709131513322, 67.60638918195451, 55.80789634159633, 34.99775321143014, 35.47927727018084, 33.995614528656006, 41.091382435389924, 7.382663369178772, 0.01838512346148491, 0.3894653400140149, 0.6888517907687596, 0.39418978935905863, 0.03345210550885115, 0.36374150748763767, 0.43879890707986696, 1.6278402507305145, 8.871918542044503, 105.60825511387416, 86.27512182508195, 90.3671452658517, 76.63177953447614, 79.75993497031075, 78.97489275251115, 85.28579562050956, 89.3941959653582, 94.09455503736223, 79.2270359311785, 83.2771964754377, 78.58659267425537, 75.6025915145874, 67.48624788011823, 64.77622808728898, 57.66317653656006, 60.448410579136436, 57.72146150044033, 59.2973997933524, 58.238146918160574, 59.7160496030535, 55.907773222242085, 57.13561371394566, 56.599765164511545, 55.433273792266846, 50.17101042611258, 54.07618291037423, 53.01496369498116, 55.52613994053432, 62.111635616847444, 73.20216260637555, 70.2696475982666, 68.68804999760219, 62.54414708273751, 55.03004550933838, 52.805485929761616, 56.47054951531546, 57.59139469691685, 63.79227978842599, 66.53210040501186, 72.51729951586042, 64.37918022700718, 74.19293403625488, 66.80749920436314, 69.98570946284703, 65.88018567221505, 69.22024726867676, 64.93425096784318, 69.06444086347307, 64.79794815608433, 72.5684243610927, 42.1574375970023, 52.868023191179546, 71.34116404397147, 65.77628925868443, 61.43530491420201, 53.65898527417864, 53.84128516060965, 52.88319110870361, 54.562608923230854, 55.92217683792114, 56.490209443228586, 53.53178807667324, 50.94070059912545, 48.689866406576975, 48.971998010362896, 50.831064973558696, 57.24035780770438, 61.87707832881382, 61.27924837384905, 56.990476267678396, 52.26197699138096, 50.1855981690543, 50.60521377835955, 50.69044733047485, 52.315745626177105, 50.28676394053868, 52.03200551441738, 55.413575649261475, 55.9221316746303, 59.783808435712544, 68.51636001041958, 71.04500402723039, 71.32968561989921, 62.07524790082659, 59.94909218379429, 68.26989351000104, 73.72816903250558, 72.47647884913853, 73.73418617248535, 70.10700416564941, 65.70892647334507, 62.65742356436593, 64.36561039515904, 70.87901851109096, 71.81899166107178, 77.73595251355852, 49.597137859889436, 0.0861952058704836, 2.3730955634798323, 1.8075419451509203, 0.6949611572282655, 0.2297217489353248, 0.8944920333368438, 0.33670332548873766, 0.496751144528389, 0.029584774814013923, 0.05347507340567453, 10.31113018308367, 22.90236210823059, 41.36192791802542, 51.54942880358015, 19.102508681161062, 30.65152645111084, 48.902641092027935, 59.18463053022112, 60.73022951398577, 73.15425477709088, 7.5947519200188776, 0.5915485120245388, 0.08402243496051856, 0.09230303884084735, 0.022723806988713995, 0.10214988474867173, 0.033279740650738986, 0.06693500293684856, 0.07968874714736428, 0.05340046508769904, 0.04441301431506872, 0.05071905414972987, 0.06629450659134559, 0.08506305662116834, 0.07824627669262034, 0.06092907235558544, 0.05300662639950003, 0.025594329029055576, 0.10537418816238642, 0.07549057634813444, 0.04127686956365194, 0.10681666540248053, 0.05521650638963495, 0.055283138528466225, 0.048885988404176066, 0.02375065947749785, 0.03690965872790132, 0.04331350938550063, 0.03442352677562407, 0.020328317136902894, 0.09973075812948601, 0.07488235112811838, 0.056110723941986046, 0.048184766567179134, 0.03798162531373756, 0.0599791979683297, 0.04458187114713447, 0.09785821860922234, 0.40670648057545933, 46.660127367292134, 95.59383732931954, 81.9915018081665, 78.50231102534703, 61.44947229112898, 46.652967248644146, 47.3006956917899, 35.17670406614031, 44.030512128557476, 8.113870075770787, 0.20542687044611999, 0.5433321392961911, 2.1170894035271237, 0.9417820700577327, 0.1317880975880793, 0.8245136312076023, 1.053580322435924, 1.5191706418991089, 12.9982157094138, 113.14043590000698, 91.32576738085065, 95.0191170828683, 78.25831808362688, 84.80052648271833, 81.32556561061314, 89.67181124005998, 91.39396395002092, 97.13901247297014, 83.49684987749372, 85.59822137015206, 80.53367246900285, 76.68049335479736, 69.70907388414655, 68.62795502798897, 61.4933362688337, 63.30357824053083, 61.250774656023296, 60.5409049987793, 60.20666190556118, 62.398450306483674, 56.79050711223057, 59.8389493397304, 59.543567521231516, 58.2430419240679, 53.11097737721035, 56.48871210643223, 55.908947467803955, 59.666515895298545, 66.383805002485, 75.76303931644985, 71.15739808763776, 73.8307591847011, 64.41433811187744, 59.361093929835725, 56.188807010650635, 60.980809347970144, 61.95877524784633, 65.78517600468227, 69.29898425510952, 75.08784811837333, 68.13252067565918, 78.26488413129533, 67.47967488425118, 73.48853955950055, 69.18314388820103, 72.91865525926862, 69.52538435799735, 71.84165668487549, 67.52674198150635, 75.59648404802594, 42.00294440133231, 55.22570330756051, 72.75160666874477, 68.30938012259347, 62.60600689479283, 56.63498558316912, 58.08078759057181, 56.140048027038574, 56.72328676496233, 59.19444833483015, 59.63284492492676, 56.97505474090576, 52.95492083685738, 51.77926479067121, 51.92989478792463, 54.82871798106602, 60.202062198093955, 63.603719575064524, 64.56160518101284, 58.49423667362758, 55.1650698525565, 52.27647788184029, 52.28796672821045, 54.82460117340088, 54.2429153578622, 53.063382216862266, 53.9280229977199, 57.289707388196675, 60.04082924979073, 62.33243547167097, 70.21650082724435, 73.12874794006348, 73.87729127066476, 64.82458060128349, 63.68105302538191, 70.7497055871146, 74.422335760934, 76.03678444453648, 75.11739880698067, 72.2179502759661, 69.23333767482212, 65.88151277814592, 68.51477582114083, 73.50924519130162, 76.28334127153668, 81.28027030399868, 62.21470519474575, 0.3709859816091401, 1.131400146654674, 1.3327654557568687, 0.767533463026796, 0.9437138863972255, 0.9563117304018566, 0.778682281928403, 1.9789451020104545, 0.041862950793334415, 0.07851768391472952, 10.59512564114162, 28.48747525896345, 38.703338691166465, 36.60556289127895, 27.6351067338671, 46.07055187225342, 56.16986274719238, 69.15817901066372, 66.22105734688895, 86.5646254675729, 17.476390498025076, 0.7592767232230732, 0.1457110254892281, 0.12044467484312397, 0.06435806942837578, 0.10234615100281579, 0.03862675605341792, 0.019635829741933515, 0.07300053603414978, 0.033494279852935245, 0.0480295584670135, 0.05636792603347983, 0.01579612390404301, 0.0354307848694069, 0.032231556717306376, 0.03941764968580433, 0.006654998096304813, 0.09778734562652451, 0.11885368664349828, 0.08334691263735294, 0.028441694365548234, 0.16846024191805295, 0.1267723124474287, 0.08852220779018742, 0.08327606001070567, 0.1331071425229311, 0.16055783310106822, 0.12260580887751919, 0.10827771414603506, 0.19463193469813891, 0.11625723168253899, 0.3071035380874361, 0.12601171540362494, 0.13622235107634748, 0.14459761737712792, 0.16106829499559744, 0.12389389904482023, 0.19017391891351768, 0.5113721085446221, 57.86816923958914, 113.76974814278739, 97.00444671085903, 93.03323854718889, 75.58495698656354, 48.87334401266915, 49.57771764482771, 47.728544916425435, 65.08959879193986, 11.176515289715358, 0.25671362770455225, 0.6734642450298581, 3.6663264206477573, 3.4771250188350677, 0.7526453733444214, 1.3670793516295296, 8.125379766736712, 5.3766867348126, 12.0627258845738, 115.70300102233887, 92.71842956542969, 97.83989116123745, 84.08074869428361, 87.84437247685024, 84.06259999956403, 94.9838480268206, 92.064117704119, 101.23988097054618, 88.67397349221366, 91.23031997680664, 84.58800193241665, 82.39359406062535, 73.88207163129533, 72.83986963544572, 64.44486154828752, 67.6140947341919, 63.98078441619873, 64.56998470851353, 63.59502043042864, 67.33280386243547, 61.52875123705183, 63.785574776785715, 64.58458982195172, 60.96768420083182, 56.344686371939524, 60.49047497340611, 59.508381843566895, 61.77752453940255, 67.82141508374895, 78.9161457334246, 73.69127409798759, 76.53941713060651, 67.13940075465611, 60.89802850995745, 59.30486215863909, 62.247861998421804, 64.96284975324357, 68.21850463322231, 73.83435140337262, 78.68865476335797, 72.1604608808245, 77.93793664659772, 70.88625158582414, 76.07199096679688, 70.19733074733189, 76.97673674992153, 71.73102746691022, 73.10356072017125, 72.03489998408726, 76.70023318699428, 45.90332957676479, 60.36815888541085, 74.15735925946916, 71.8983678817749, 64.92656626020158, 60.17746557508196, 60.28312683105469, 60.49287905011858, 60.37955393110003, 62.956036295209614, 61.93139934539795, 59.45806993756975, 57.52934033530099, 55.51570374625069, 55.18468461717878, 57.78787933077131, 66.1614487511771, 67.89057745252336, 68.24606813703264, 62.56831986563546, 58.264824526650564, 57.5226457459586, 57.046214716775076, 56.757555280412944, 56.21022483280727, 55.26369605745588, 57.25822510038103, 61.179618154253276, 63.67204121180943, 66.18159852709088, 73.1934426171439, 75.42049312591553, 77.68556417737688, 68.78452573503766, 67.3636816569737, 75.94514465332031, 78.92097473144531, 80.62643092019218, 78.89275809696743, 76.63423919677734, 72.07308033534459, 69.79701028551374, 72.95072119576591, 77.47058691297258, 79.98805822644914, 82.61731215885708, 60.45326042175293, 0.27177037405116217, 5.951188113008227, 6.558143658297403, 2.1873621812888553, 0.9334665962627956, 2.0897816802774156, 2.0358747329030717, 2.1555322664124623, 0.16968881099351815, 0.15397047943302564, 16.576709951673234, 39.1075953074864, 56.15089763913836, 74.626939364842, 26.88095794405256, 46.655041285923545, 64.58674376351493, 82.75292709895542, 75.97545964377267, 101.84667410169328, 15.650075605937413, 0.8911653118474143, 0.39607025416834013, 0.17870418008949074, 0.21331230231693812, 0.2480821737221309, 0.10170300837074008, 0.13253117485770158, 0.17851406814796583, 0.22952969638364656, 0.17184599595410482, 0.16104755896542752, 0.15718433340745314, 0.23248710483312607, 0.15754717322332518, 0.16148452194673674, 0.1468270527465003, 0.17882300514195645, 0.26042453572154045, 0.1729615753782647, 0.0980852564264621], [0.03985986113548279, 0.07641808622117553, 0.03708913802568402, 0.08286968538803713, 0.04505751062450664, 0.05793644793863807, 0.11303400713950396, 0.06483001767524652, 0.08938065636903048, 0.030654593836516142, 0.0689711304647582, 0.009815578165996288, 0.056654664754335365, 0.05633769390572395, 0.030624792578497102, 0.05051720355238233, 0.10355879486139331, 3.012161122901099, 72.35200187138149, 74.59539454323905, 80.77168301173619, 53.952619620731895, 55.714255469185964, 29.084936959402903, 50.56839179992676, 59.44408321380615, 24.8877021585192, 0.6008742430380413, 0.06546371509986264, 0.6622691771813801, 0.8292949689286095, 0.7198215403727123, 0.5670751109719276, 0.35571764090231484, 1.231803027646882, 0.05592184014884489, 62.44236292157854, 103.61693613869804, 85.99345575060163, 81.18706021990094, 74.56994329180036, 85.01466996329171, 79.35306930541992, 94.84196581159318, 84.96496255057198, 79.69744982038225, 83.19973100934709, 82.41426495143345, 76.28018678937639, 69.94548634120396, 62.02303218841553, 60.43279797690255, 57.70942374638149, 60.41379465375628, 58.8287090573992, 56.70472117832729, 57.66272837775094, 59.13051101139614, 56.61322035108294, 56.82794748033796, 55.84985303878784, 53.3660318510873, 50.253534180777415, 54.950506005968364, 52.40151071548462, 63.243948800223215, 68.63668196541923, 66.3457566670009, 64.04809856414795, 65.52479921068463, 59.55967344556536, 56.18561083929879, 51.77893475123814, 56.074311120169504, 57.855985573359895, 62.55823108128139, 63.12220941271101, 70.32845715114048, 65.68728978293282, 70.44048295702252, 71.43226882389614, 69.43985898154122, 70.49221229553223, 68.46738910675049, 70.02707903725761, 74.3934382029942, 67.6434439250401, 72.28563962663922, 41.66278491701399, 51.146134512765066, 70.85779871259416, 66.1946611404419, 60.21269294193813, 51.29294300079346, 57.746308258601594, 54.86236463274275, 60.44795199802944, 62.874784060886924, 60.477558272225515, 57.64698723384312, 52.50856508527483, 46.802707876477925, 47.908666542598176, 51.23316070011684, 55.12016017096383, 60.019762311662944, 62.520759446280344, 56.474075726100374, 53.79877608163016, 50.9863919530596, 49.619090693337576, 48.52133437565395, 52.3327374458313, 50.767495904650005, 52.29362603596279, 51.53765855516706, 51.78899226869856, 53.49028648648943, 59.806000982012065, 65.06729507446289, 63.965310777936665, 55.021579129355295, 60.21466623033796, 68.95984963008335, 71.32744135175432, 69.69709518977574, 71.14907414572579, 67.87820271083287, 65.1452191216605, 61.302010672433035, 61.57500539507185, 66.60117244720459, 75.33068071092877, 69.02794197627476, 81.54599026271275, 41.744572162628174, 0.21110647996621473, 1.2445095458200999, 1.2394070710454668, 0.16351178102195263, 0.12443649635783263, 2.4396306446620395, 2.618452523435865, 0.09072220831045083, 0.024865697769980346, 0.7452321339930806, 22.578014986855642, 25.698886973517283, 62.57314886365618, 33.318696703229634, 15.947378601346697, 47.379008838108604, 45.073391573769705, 61.56814752306257, 66.41514832632882, 45.96286869049072, 0.5393850196685109, 0.1599991816495146, 0.1153891139796802, 0.03157434126894389, 0.05858836402850492, 0.03122029865958861, 0.04059018873210464, 0.04328468521790845, 0.017529589190546955, 0.03304727455335004, 0.06537832146776573, 0.058401095148708136, 0.04504916464377727, 0.0391874838221286, 0.05090400922511305, 0.07531272553439651, 0.07907191131796155, 0.04340200052995767, 0.03698531198980553, 0.019623862080542103, 0.04045096691697836, 0.0713851409299033, 0.0774204588628241, 0.06991856891129698, 0.026581198841865574, 0.057126039639115334, 0.030830975621938705, 0.10916052891739778, 0.026491615256028514, 0.014321806408198816, 0.07605903941605772, 0.034139709148023806, 0.028176548325323632, 0.11427718507392065, 0.019557531889794127, 0.1717173457145691, 0.3220586398882525, 11.293117352894374, 97.78741141727993, 83.86999593462262, 91.82309164319719, 65.52327060699463, 65.45797143663678, 32.661699363163535, 30.710402011871338, 50.626760142190115, 29.706019060952322, 0.43888556957244873, 0.1809597254863807, 1.4393712324755532, 2.5369644846235, 1.8917213252612521, 0.898534853543554, 1.2285067588090897, 0.4848708105938775, 0.18825764102595194, 72.81086785452706, 106.47034590584892, 89.04356207166398, 83.5545129776001, 77.37796742575509, 87.25991085597447, 83.31835760389055, 96.82935905456543, 89.9484120777675, 83.99477168491909, 85.65050656454903, 84.61571134839738, 81.51991367340088, 72.72438362666539, 65.35110119410923, 61.75617272513253, 61.833492279052734, 62.430022920881, 59.452018056597026, 60.51291070665632, 61.24859292166573, 61.5828012738909, 59.593379156930105, 59.31540257590157, 57.00649186543056, 56.371586322784424, 53.93154573440552, 56.52547155107771, 55.84087944030762, 64.67931461334229, 73.61854035513741, 68.49719687870571, 66.60632801055908, 66.95144503457206, 60.963737624032156, 58.302633149283274, 54.997173581804546, 59.526287351335796, 59.078198024204795, 64.53957939147949, 66.94880471910749, 73.89931011199951, 69.02557264055524, 72.69696603502545, 75.7890533719744, 73.11754049573625, 73.27522291455949, 72.30435807364327, 73.5096412386213, 75.2002352305821, 70.35014942714146, 74.25229249681745, 45.250907625470845, 54.67275871549334, 74.45328998565674, 70.50963142939976, 63.106701033455984, 52.160613196236746, 61.1237268447876, 59.13765375954764, 64.62000479016984, 67.1156587600708, 64.61901814596993, 61.83002512795584, 54.57054376602173, 48.84155600411551, 50.73670843669346, 53.86348812920706, 57.9846453666687, 63.47225270952497, 66.1929657799857, 59.26923179626465, 55.75151171003069, 54.245916979653494, 51.593786103384836, 51.79148667199271, 54.9538619858878, 53.76402814047677, 55.7219888142177, 52.778283732278005, 53.06560216631208, 54.822857175554546, 62.803363527570454, 67.99781594957624, 64.64157199859619, 55.91431842531477, 62.39449678148542, 72.00159726824079, 73.49760001046317, 72.55469472067696, 73.709561756679, 68.73570074353898, 67.20030866350446, 63.41377667018345, 64.33611529214042, 71.60842650277274, 77.06026104518345, 72.68864209311349, 82.64794676644462, 54.68881947653634, 0.34310280638081686, 0.8404484561511448, 0.1589791670973812, 0.7444381394556591, 1.2361025512218475, 1.473279852952276, 2.2014359746660506, 0.8614459122930254, 0.07921078708022833, 0.4009459353983402, 25.237120117459977, 29.270401750292095, 49.309148924691335, 25.79881075450352, 25.05906731741769, 61.37480000087193, 54.23410504204886, 70.100556237357, 72.74165684836251, 69.71225615910122, 2.1218597761222293, 0.1654753392296178, 0.013010506950584906, 0.053528742132974524, 0.10175178825323071, 0.08994504144149167, 0.03911606122606567, 0.03961885567488415, 0.04332697830562081, 0.007653125229158572, 0.02648285197626267, 0.0593537176027894, 0.013858447566495409, 0.05077925038390926, 0.06837209939424481, 0.044034846393125396, 0.05211780998589737, 0.011019150011374481, 0.020466968982613513, 0.007961081740047251, 0.1534631795116833, 0.2102522315191371, 0.16114036898527825, 0.19734093147729123, 0.08651189851973738, 0.14978266986353056, 0.18212382016437395, 0.1466770286538771, 0.13663020490535668, 0.11997755776558604, 0.14718397573700973, 0.11529870597379548, 0.20288761598723276, 0.2385358102619648, 0.09720573254993983, 0.20951758165444645, 0.3277724747146879, 12.879274708884102, 116.49114908490861, 94.54968288966587, 107.06179741450718, 76.6919161932809, 73.11729730878557, 39.320495060511995, 68.88735212598527, 79.44666154044015, 41.06598676953997, 1.5846830351012093, 0.26456984185746735, 5.504597859723227, 4.658877023628779, 3.465879576546805, 2.442331973995481, 2.28082218340465, 3.4506193782602037, 0.2813833967915603, 76.48253222874233, 108.2551018851144, 93.85437665666852, 86.28120844704765, 80.26790387289864, 91.33378560202462, 88.10080964224679, 98.16339928763253, 92.2771703175136, 89.02774102347237, 88.8018411908831, 90.07725252423967, 84.12063830239433, 75.10487120492118, 68.23835563659668, 66.1646727153233, 64.3568834577288, 66.94555296216691, 63.95472172328404, 62.6720495223999, 65.32373223985944, 64.77184377397809, 62.893009185791016, 63.19571440560477, 62.44842869894845, 60.830804688589915, 57.11387627465384, 60.70147092001778, 59.237680026463096, 68.14001778193882, 74.74132755824498, 70.629807472229, 67.50689097813198, 71.52857085636684, 65.7887543269566, 60.59887381962368, 59.64496258326939, 63.32469381604876, 62.49077796936035, 68.85844761984688, 69.49149799346924, 75.12055328914097, 73.55147634233747, 75.09184333256313, 78.67945534842355, 77.7045327595302, 77.38614545549665, 75.3843138558524, 78.31044346945626, 81.04055050441197, 74.33405194963727, 77.00139590672084, 47.91587182453701, 56.358509813036235, 77.35127244676862, 73.41764014107841, 65.22657557896206, 54.94323819024222, 64.33694907597133, 61.549463817051475, 67.72973360334123, 70.4275871004377, 66.83675112043107, 64.23872239249093, 57.392950671059744, 53.45474992479597, 55.79536179133824, 58.35300758906773, 59.84600870949881, 65.98338726588658, 68.3271119253976, 62.835109846932546, 60.11624499729702, 57.57938126155308, 56.03147547585623, 55.052568095070974, 57.7712071282523, 57.89650051934378, 58.869203158787315, 57.00846862792969, 56.33700513839722, 58.74935368129185, 65.27952085222516, 72.52582495553153, 71.2486070905413, 59.25874696459089, 65.16309683663505, 75.35981450762067, 77.95268767220634, 75.03553513118199, 75.87323079790387, 73.49438299451555, 71.73352187020438, 67.92811162131173, 69.13599341256278, 75.31571429116386, 80.96071570260185, 75.7467874799456, 87.09763567788261, 51.2545542035784, 0.4747161269187927, 3.4753273895808627, 3.9126847897257124, 0.9813362104552132, 0.6535065216677529, 5.59787916285651, 6.939786493778229, 0.6188505355800901, 0.10785968907709632, 1.8481400523866927, 37.53793123790196, 38.79374170303345, 87.3015444619315, 45.56392397199358, 24.333600691386632, 66.74784197126115, 63.253328868321006, 80.78742068154472, 85.52439676012311, 73.56351062229702, 1.4041114045040948, 0.20855702034064702, 0.2392987007541316, 0.16514785108821733, 0.2134613628898348, 0.1710572261363268, 0.12901556278978074, 0.10650943153138671, 0.1295912726117032, 0.14421048600758823, 0.16982820922774927, 0.09328986624521868, 0.12360780153955732, 0.11153337944831167, 0.15469881892204285, 0.1405294199607202, 0.18037257556404385, 0.102833217009902, 0.12267881924552576, 0.1391887026173728], [0.033595937969429154, 0.0694101019097226, 0.060318153351545334, 0.12934982271066733, 0.049682123719581535, 0.10204726311245135, 0.059584460221230984, 0.14125239902309009, 0.027443949332726852, 0.0752337576289262, 0.058031076432338784, 0.11404387759310858, 0.07327490845429045, 0.10122156063360827, 0.10385447328111955, 0.03380219225904771, 0.17926169160221303, 50.001585551670615, 83.91775090353829, 76.52884892054966, 60.535534041268484, 47.42593002319336, 16.93374834741865, 42.81841972896031, 102.94379465920585, 45.39649323054722, 8.735602702413287, 0.12904096714087895, 0.15885191463998385, 1.0835802555084229, 0.9684268917356218, 0.2480736513222967, 0.10386667334075485, 0.5417729201061385, 1.0443306416273117, 12.732993415423802, 112.19792665754045, 85.09381689344133, 90.58215727124895, 72.48997919900077, 79.86356735229492, 76.05432169778007, 90.01790796007428, 89.71884359632219, 78.76658575875419, 82.83975873674665, 82.48205157688686, 78.24742330823625, 75.15701743534633, 62.16686684744698, 61.05797604152134, 57.50045319965908, 56.74293974467686, 56.337345600128174, 56.77266066414969, 55.73930719920567, 58.17029428482056, 56.49950960704258, 56.544704164777485, 57.09876046861921, 53.907240935734336, 50.465683528355186, 54.742549896240234, 50.92484828404018, 54.79186473573957, 65.81081485748291, 67.01382596152169, 64.87631688799176, 63.45190143585205, 60.86553873334612, 58.22960410799299, 54.55174194063459, 51.18254654748099, 52.21694919041225, 57.02232333592006, 58.862789971487864, 62.91683455875942, 65.97623756953648, 67.09978907448905, 63.35698904309954, 71.22610882350376, 67.50800963810512, 68.18308271680559, 67.96876553126744, 66.07895973750523, 68.03954683031354, 65.33742019108364, 73.31004728589738, 46.00537429537092, 54.304802962711875, 70.76644379752022, 62.18534210750035, 56.83024385997227, 52.54654393877302, 60.22317777361189, 63.9485239301409, 67.34260082244873, 66.58119637625558, 61.47042110988072, 57.372731413160054, 54.180781091962544, 47.971110003335134, 47.989408084324424, 48.239386899130686, 53.9457026890346, 57.8910288129534, 62.08705983843122, 59.99169853755406, 53.29068211146763, 51.046917710985454, 48.60809653145926, 46.81701421737671, 47.97707155772618, 50.2053518976484, 50.48389475686209, 50.7811838558742, 52.19276251111712, 50.72408355985369, 49.86498744147164, 51.412806374686106, 53.309490885053364, 52.84099817276001, 54.46644238063267, 63.81493786403111, 68.91206686837333, 68.537093435015, 65.2725031716483, 63.12718432290213, 61.30692999703543, 57.87928288323538, 56.390513215746196, 61.44894422803606, 68.61175877707345, 75.26267174312046, 67.26350252968925, 82.71442018236432, 32.43279096058437, 0.9543890335730144, 0.9905892567975181, 2.2120489137513295, 0.5203134630407605, 1.1615730247327258, 1.2594674974679947, 0.9076343881232398, 0.10263886422451053, 0.28118165475981577, 6.582689906869616, 27.681227139064244, 41.810371603284565, 55.328647817884175, 22.560503789356776, 24.019679341997417, 51.06592798233032, 54.81452281134469, 59.76765387398856, 72.71997152056012, 13.036396929195949, 0.5738838570458549, 0.08322778224412884, 0.1009072699983205, 0.08585822502417223, 0.10228413968746151, 0.01875379528584225, 0.013994900958745607, 0.0753792016101735, 0.06466683000326157, 0.028222765041781322, 0.08915234290595565, 0.02891689618783338, 0.029275301777358567, 0.09569796667035137, 0.041030429037553925, 0.032604886684566736, 0.04432805155270866, 0.04941794289542096, 0.10683537261294467, 0.08062536296035562, 0.006150536995846778, 0.08628351720316069, 0.039095745887607336, 0.04026180153180446, 0.02333511445405228, 0.03007916560662644, 0.06601537764072418, 0.051714702509343624, 0.038745404686778784, 0.04645188990980387, 0.10561879325125899, 0.022106772687818323, 0.0837287785751479, 0.023549156629347374, 0.04009239847904869, 0.1752992777952126, 72.33951595851353, 95.71787657056535, 87.91414628710065, 75.66602856772286, 63.406620025634766, 32.309106077466694, 38.86308472497122, 66.57772922515869, 51.37856217793056, 9.077327268464224, 0.11582016013562679, 0.25076849386096, 2.3811496113027846, 2.0716614297458102, 1.8786461183003016, 1.4511544001953942, 0.619866492492812, 1.1152997591665812, 18.474968229021343, 117.63961683000836, 85.50391347067696, 96.09442724500383, 74.43455069405692, 81.81548309326172, 77.69649369376046, 93.97085625784737, 92.57569966997418, 83.30954728807721, 86.49462931496757, 86.32685811179024, 79.12784344809396, 76.86481516701835, 61.989708627973286, 62.012318066188264, 60.5365971156529, 60.999666758946006, 58.87608882359096, 60.3519070489066, 58.39420345851353, 59.72831317356655, 59.06951972416469, 60.771814482552664, 59.75912148611886, 56.70142425809588, 53.82992485591343, 56.51199551991054, 54.96104294913155, 59.27932058061872, 68.85498046875, 67.88510922023228, 64.95868083408901, 65.58773599352155, 63.989004135131836, 62.30900614602225, 58.64253902435303, 54.54795517240252, 54.18107986450195, 60.31797899518694, 62.793705531529014, 65.56216662270683, 68.58992058890206, 69.84575189862932, 67.19767529623849, 73.11100918906075, 70.99437945229667, 70.58400494711739, 70.04055159432548, 70.52517454964774, 69.78395462036133, 68.91748646327427, 75.29477936880929, 49.41382353646414, 57.31848682676043, 72.09408473968506, 65.96330002376011, 57.60402652195522, 54.29745871680123, 64.22062928336007, 66.20324911390031, 70.7593218939645, 69.45606218065534, 64.10896478380475, 60.089855739048545, 54.493585518428254, 50.635865756443565, 50.75464173725673, 51.14404310498919, 56.01212126868111, 60.446937561035156, 64.66557107652936, 62.82752936226981, 55.476234504154746, 51.724495615277974, 51.59576286588396, 50.324047974177766, 51.62963533401489, 51.659248556409565, 50.83358716964722, 52.17622579847063, 55.28783062526158, 53.56231846128191, 52.21802963529314, 53.6521760395595, 54.566287994384766, 54.338779653821675, 57.20716626303536, 65.28554494040353, 72.2437002999442, 70.34037331172398, 66.63523946489606, 65.79589012690953, 62.47118404933384, 61.44219057900565, 59.00153854915074, 64.66086714608329, 71.75987638745988, 77.37682792118618, 70.7874482018607, 87.01901681082589, 47.4118321282523, 0.43507624683635576, 0.7989873066544533, 0.8992331475019455, 1.2094621807336807, 3.6759305681501115, 0.44314288826925413, 1.442746862769127, 0.29308286043150084, 0.48266209768397467, 5.662400134972163, 34.07636649268014, 38.84150014604841, 34.6264762197222, 28.43736137662615, 36.38927241734096, 58.80913598196847, 64.86559581756592, 65.505615234375, 81.03269209180559, 25.421174424035208, 0.5973133455429758, 0.09806550427206925, 0.08867178404969828, 0.06307094956615142, 0.10773664353681461, 0.01569707305835826, 0.04353672365791031, 0.052192869529660256, 0.05991376683648143, 0.014393778617626854, 0.12019595104668822, 0.016626752547121475, 0.04538699705153704, 0.023713450313412716, 0.05215870529147131, 0.03251297911629081, 0.0314880858973733, 0.05319159843825868, 0.061907757339732986, 0.09260730751390968, 0.10124028141477279, 0.20692754563476357, 0.2334240802696773, 0.14341320736067636, 0.1580699301723923, 0.18822923755007132, 0.2548584043979645, 0.17389652878046036, 0.18278518824705056, 0.1449379976838827, 0.3027234316936561, 0.17591450549662113, 0.32154227473906105, 0.18200257952724183, 0.10271668540579931, 0.39836180263331955, 81.43855026790074, 113.28572968074253, 101.87568283081055, 83.53323064531598, 70.23988151550293, 28.94795843533107, 55.87500899178641, 135.89988572256905, 64.79088878631592, 15.511156797409058, 0.49147317345653263, 0.4177803892110075, 4.166196763515472, 4.0176642537117, 3.3349939712456296, 2.3787427118846347, 2.4281203023024966, 2.9048724685396468, 17.08972324643816, 119.86723709106445, 88.8615470613752, 98.6461045401437, 79.97951194218227, 86.97219984872001, 81.67351055145264, 95.28077929360526, 94.0432356425694, 90.5750492640904, 88.77582018715995, 91.5013553074428, 84.43023613521031, 85.58608981541225, 65.87070832933698, 66.3566722869873, 63.902297564915244, 62.682110513959614, 62.80610111781529, 62.558481216430664, 61.03834738050188, 65.19686508178711, 61.25518676212856, 63.437011446271626, 63.80812168121338, 60.8279698235648, 56.08215911047799, 59.8434031350272, 57.55654600688389, 62.10834911891392, 71.45109149387905, 70.70616122654506, 67.11584636143276, 68.27444458007812, 66.66215678623745, 67.05226339612688, 60.82273088182722, 58.578983851841514, 57.23493473870413, 63.75582259041922, 66.911374773298, 69.97086116245815, 72.35462829044887, 71.71174621582031, 71.0863597052438, 75.17224788665771, 74.99232428414481, 77.35373905726841, 72.85039615631104, 73.7241599219186, 73.16303035191127, 72.2383154460362, 79.42326695578438, 51.825056893484934, 58.289480209350586, 75.84862722669328, 68.7268487385341, 61.688427788870676, 57.98707376207624, 65.85299737112862, 69.06883907318115, 74.30190958295549, 73.6475282396589, 68.03500270843506, 63.26045772007534, 59.46962479182652, 54.71436105455671, 53.576034205300466, 54.1952611378261, 59.540822982788086, 65.54433059692383, 67.35533687046596, 65.13030133928571, 58.387081554957796, 56.41574559892927, 53.55977542059762, 53.772953101566856, 55.744705949510845, 55.64149393354143, 54.542671067374094, 55.430751596178325, 58.3305857522147, 56.79272011348179, 55.17686441966465, 56.68331377846854, 58.49109608786446, 57.44513511657715, 61.2504689352853, 70.75958592551095, 74.78337805611747, 74.96594892229352, 72.45703778948102, 69.08057458060128, 67.52479648590088, 65.53517981937954, 63.6746050970895, 67.38525581359863, 75.66404138292584, 81.93135820116315, 72.83579799107143, 91.11799539838518, 45.08187185014997, 0.9559164430413927, 2.3719176266874586, 5.574376881122589, 1.471048178417342, 2.5893814776624953, 5.01271664244788, 1.9171152540615626, 0.4221562072634697, 0.5903926140495709, 10.604150482586451, 46.09248733520508, 54.98144286019461, 80.31740978785923, 31.319602693830216, 37.32535457611084, 64.01340620858329, 78.33245536259243, 74.16030529567173, 98.34563664027623, 25.36298152378627, 0.8441420208130563, 0.16401165777019092, 0.33515650991882595, 0.17385265470615455, 0.3681982069143227, 0.13729446354721273, 0.1417283641972712, 0.16238971480301448, 0.09357187896966934, 0.051834918558597565, 0.19652230611869267, 0.07291141724480049, 0.15890337473579816, 0.15214625160608972, 0.1106441185942718, 0.14210917162043707, 0.14336355216801167, 0.15396927164069243, 0.1720514834991523], [0.07933958659746818, 0.027774716494604945, 0.03417007698278342, 0.06382768574569907, 0.0831666530242988, 0.04367645098162549, 0.08931604626455478, 0.03406914829143456, 0.026048888119735887, 0.01951476722024381, 0.11703340789037091, 0.017666503986609832, 0.03708107363698738, 0.07869383839092084, 0.17244464025965758, 0.12048402987420559, 7.888703278132847, 81.0103188923427, 67.80746310097831, 80.96698992592948, 50.21693107060024, 43.05390460150582, 29.786204746791295, 45.54044600895473, 57.70963566643851, 31.128277097429546, 1.5232230701616831, 0.08431691915861197, 0.6770454442926815, 0.9057146768484796, 0.9694362261465618, 0.49521754682064056, 0.2729242635624749, 0.7828669430954116, 0.3366182643387999, 76.89294842311314, 95.87922763824463, 90.40351213727678, 84.96098818097795, 75.51967866080147, 74.94066442762102, 79.36374173845563, 88.7378899710519, 76.91436971936906, 83.29776314326695, 79.14800017220634, 77.62796361105782, 66.80696419307164, 60.84468024117606, 59.37248202732631, 56.25935207094465, 55.162314891815186, 57.59515019825527, 57.42581565039498, 57.24977956499372, 55.48540265219552, 56.116104534694124, 56.50407109941755, 57.03740440096174, 53.988267353602815, 49.4990153993879, 53.23739637647356, 55.93758794239589, 52.38440425055367, 61.09724031175886, 66.58282920292446, 62.889680998665945, 62.93685926709856, 60.73032678876604, 61.085289410182405, 57.55267933436802, 55.20194394247872, 52.089369841984336, 49.745023318699424, 53.708578041621614, 56.38411392484392, 61.73295184544155, 62.798972266060964, 66.41737174987793, 65.1153974533081, 59.408327783857075, 70.24368218013218, 64.98793275015694, 66.1007353918893, 63.82442215510777, 67.1856827054705, 60.97541059766497, 71.20843955448696, 46.69233921595982, 61.54179300580706, 69.3343505859375, 59.72161511012486, 53.53704786300659, 55.4997888973781, 64.38189697265625, 64.75725255693708, 66.33290944780622, 63.38873536246163, 57.57938820975167, 51.813019139426096, 50.02290609904698, 47.2947758265904, 48.761665616716655, 47.9064952305385, 54.17375298908779, 57.70460169655936, 62.5157914842878, 60.45475428444998, 53.182456970214844, 51.19278819220406, 49.608338356018066, 46.05367469787598, 45.412206581660676, 47.35020508084978, 49.5133877481733, 49.22163636343819, 51.17025171007429, 49.964558601379395, 50.790313788822715, 49.797419684273855, 53.360598359789165, 51.58395092827933, 50.553477491651265, 51.52498156683785, 57.02148955208914, 56.53803736822945, 57.36198602403913, 55.07305833271572, 55.759957245418, 53.66872664860317, 53.95555870873587, 52.723007338387625, 62.826695578438894, 62.88486589704241, 75.60731628962925, 66.30098942347935, 83.80505807059151, 21.09980137007577, 1.155299452798707, 1.4366680575268609, 4.534347065857478, 0.10384588302778346, 1.4396472062383379, 0.6569685158985001, 0.47829852040324894, 0.10605440594788108, 0.08693412372044154, 18.543522630419048, 29.97705439158848, 59.538335527692524, 34.22646495274135, 25.728517566408428, 38.366163458142964, 57.17039292199271, 59.96180043901716, 56.52818134852818, 44.65908438818795, 0.5406063284192766, 0.08594448718109302, 0.02172222314402461, 0.07926628445940358, 0.0509877200903637, 0.034386811245765, 0.04959632296647344, 0.03992927526789052, 0.05920418205537966, 0.08460212778300047, 0.05028253900153296, 0.021391293133742044, 0.05578681168013385, 0.05285920788134847, 0.06614058092236519, 0.08474095604781594, 0.045702213887125254, 0.0480939684036587, 0.06728581911219017, 0.09612822572567634, 0.022370921281565512, 0.020395800837182572, 0.02708846653279449, 0.06203752037669931, 0.04466654553211161, 0.08383227552154235, 0.009492089988530746, 0.055934311622487645, 0.02134681855594473, 0.1474146640726498, 0.04654863204008766, 0.13697372004389763, 0.04358461805220161, 0.20374968115772518, 0.24670575186610222, 14.592617103031703, 99.85454913548061, 76.94395514896938, 90.31645120893205, 62.12413542611258, 54.616321972438264, 39.70640843255179, 37.700008392333984, 58.293329511369976, 38.25746236528669, 1.420156097837857, 0.09646508443568434, 1.7852517983743121, 2.5661716716630116, 1.5451724295105254, 1.1415563502482005, 0.33173091230647905, 0.31945216975041796, 1.6052479658808028, 88.69306019374302, 96.53487355368478, 96.51042284284318, 84.65432248796735, 80.65760053907121, 77.18830939701625, 83.67508506774902, 91.89245550973075, 83.17410605294364, 85.10371112823486, 83.60518618992397, 79.11562156677246, 70.82592732565743, 60.847980635506765, 61.84533895765032, 60.071616717747276, 59.42516326904297, 61.28631469181606, 59.697122710091726, 58.57199396405901, 58.368620191301616, 58.47137015206473, 59.02222333635603, 59.0724310193743, 56.299735001155305, 52.62870291301182, 55.45214509963989, 57.11523812157767, 56.08315617697579, 64.7037375313895, 70.4167548588344, 63.48225811549595, 64.34139592306954, 61.68657956804548, 62.13760798318045, 60.612686838422505, 59.16042995452881, 54.567906924656455, 53.170950753348215, 56.62553603308541, 60.83280576978411, 65.28097302573067, 67.49428694588798, 69.54482541765485, 68.57079914637974, 63.47167600904192, 70.6352618081229, 66.9328863961356, 68.61326653616769, 66.75324072156633, 69.1807884488787, 63.89582879202706, 72.16119738987514, 49.74753509249006, 65.09177357809884, 72.34095423562187, 63.89439051491873, 56.1799167905535, 59.74190385001046, 67.06438105446952, 67.48387159620012, 68.52602495465959, 67.2639958517892, 61.534184728349956, 52.4919866834368, 53.42986842564174, 50.0556321144104, 51.60317659378052, 51.86080884933472, 54.81833389827183, 61.767067500523154, 65.1489850452968, 62.39845725468227, 57.18702343532017, 52.31441157204764, 50.873633112226216, 49.362073353358674, 49.33326959609985, 49.202935286930625, 51.76415940693447, 50.4637519291469, 53.87042590550014, 51.665234429495676, 52.32940231050764, 52.82669530596052, 54.03606401171003, 54.46629646846226, 54.192905698503765, 53.03212227140154, 58.32511057172503, 58.65772083827427, 59.053441592625205, 56.781592573438374, 57.213582924434114, 56.54675735746111, 56.72860213688442, 56.3370954649789, 64.21547372000558, 65.80257429395402, 78.22224998474121, 70.79281221117292, 87.14240986960274, 36.439233439309255, 1.1532877321754182, 0.364642683416605, 0.8928576324667249, 1.0601544039590018, 3.5138067305088043, 1.3808457957846778, 2.470901446683066, 0.17032459830599173, 0.09924863185733557, 20.036947590964182, 39.61445944649832, 51.193177291325156, 21.304873977388652, 35.1169877733503, 45.56613349914551, 65.64114679609025, 70.43470205579484, 64.03600175040108, 70.00204467773438, 4.325771697929927, 0.6925143599510193, 0.03226716623508504, 0.10862177211259093, 0.04884952732494899, 0.06927040512008326, 0.008020919198835534, 0.02895184074129377, 0.032956191405121765, 0.043713733088225126, 0.05403220833146146, 0.054308192272271426, 0.04812727090237396, 0.09160867360021387, 0.16253325210085937, 0.06156563998333045, 0.050692598069352765, 0.020906089705282023, 0.050288866340581856, 0.17781383357942104, 0.20449592040053435, 0.1347497265253748, 0.12551183865538665, 0.14384053514472075, 0.19383260687547071, 0.13258167143378938, 0.15137882849999837, 0.19165889280182974, 0.09800693312925951, 0.19711077239896568, 0.10033518355339766, 0.2130876122308629, 0.18896133612309182, 0.35101365617343355, 0.34806107889328686, 15.44294285774231, 115.61580113002232, 88.4699535369873, 105.19384370531354, 70.34664058685303, 62.91351331983294, 41.62058503287179, 65.93805027008057, 73.32579885210309, 51.6450012751988, 2.474162323134286, 0.13728170708886214, 3.0296536471162523, 4.951409212180546, 4.840251931122371, 2.506671207291739, 1.3608730903693607, 3.1720795588833943, 1.2036404588392802, 87.56553431919643, 101.06321607317243, 97.9913410459246, 89.90961333683559, 85.05330194745744, 80.03073406219482, 87.43519306182861, 94.3030287878854, 88.25719969613212, 88.64322771344865, 87.95451532091413, 84.75070095062256, 74.95568643297467, 64.82926368713379, 63.95414502280099, 61.97595814296177, 61.61289392198835, 64.1402108328683, 64.07577323913574, 63.836192403520855, 61.36858136313302, 62.562247140066965, 62.53307860238211, 62.1738497870309, 60.870319093976704, 56.81914758682251, 59.52811472756522, 62.879571369716096, 59.63579790932791, 68.29566437857491, 70.91570499965123, 64.85827936444963, 66.35617201668876, 64.33780370439801, 65.63096073695591, 65.29660647256034, 62.45710005078997, 56.84577655792236, 57.12548671449934, 61.11978721618652, 64.24498271942139, 67.3189561026437, 72.29414422171456, 71.32393945966447, 72.13254301888603, 67.17797020503453, 75.83776024409703, 71.1771240234375, 71.1760470526559, 72.0117416381836, 72.16848605019706, 66.97648634229387, 76.46461977277482, 51.92924860545567, 67.8020087650844, 76.59767777579171, 66.75408145359584, 58.790799685886924, 62.22689928327288, 70.99755477905273, 68.94481372833252, 72.26443372453961, 71.5268338067191, 64.59942422594342, 55.19228247233799, 57.55400991439819, 53.65939174379621, 56.55695383889334, 54.84408392224993, 59.03859329223633, 63.65047400338309, 68.12508610316685, 65.53538131713867, 59.01561559949602, 56.65152924401419, 55.588242939540315, 50.98781633377075, 51.81960603169033, 53.442816393715994, 54.781696047101704, 54.90115989957537, 58.391848019191194, 54.97418546676636, 55.80978625161307, 55.56272220611572, 58.523099490574424, 57.44813673836844, 56.80541794640677, 56.15214136668614, 62.85286944253104, 63.45638302394322, 63.89328575134277, 61.25456837245396, 63.30232061658587, 58.74598380497524, 59.66857951028006, 59.63444301060268, 68.72536182403564, 70.53620828901018, 82.02900123596191, 73.45428494044712, 92.53666469029018, 31.137917722974503, 1.6758831356252943, 5.250739344528743, 7.579610058239528, 1.4020219509090697, 4.772685476711818, 3.3234347743647437, 2.0836320902620042, 0.6468581812722343, 0.302979510809694, 31.322531359536306, 45.86709124701363, 79.00112915039062, 49.07503284726824, 34.77437904902867, 54.24563905170986, 73.06600570678711, 81.60791260855538, 74.3696197782244, 79.21400111062187, 3.5439184861523763, 0.6510811118142945, 0.16721816999571665, 0.21934576784925802, 0.11610705831221171, 0.09964157827198505, 0.13277448394468852, 0.12249352490263325, 0.14178150705993176, 0.17898058811468737, 0.1281679097030844, 0.0881712966199432, 0.11896842691515173, 0.1700697676943881, 0.2231322918087244, 0.16608755423554353, 0.16815350337752275, 0.10500787424721889, 0.11161865094410521], [0.08057584347469465, 0.031691710863794596, 0.05419754695945552, 0.030078073165246418, 0.05912493595055171, 0.07780389221651213, 0.05555384007415601, 0.07066149011786495, 0.03383811729561005, 0.028132468994174684, 0.04621098283678293, 0.07637221046856471, 0.08163608836808375, 0.046961798798292875, 0.04746480020029204, 0.24081243095653398, 42.75852278300694, 84.58983625684465, 71.73079817635673, 59.697671617780415, 44.13393953868321, 37.00255864007132, 24.50996334212167, 59.9004339490618, 48.88790396281651, 15.11494619505746, 0.09433997382542916, 0.03467550075479916, 1.0047394803592136, 2.312717237642833, 0.29618794524243897, 0.4815004457320486, 0.28429526197058813, 0.40165538447243826, 47.48418719427926, 103.3902233668736, 84.28777721949986, 91.6095665522984, 77.23348658425468, 76.82275772094727, 67.60170609610421, 79.45156002044678, 71.5849415915353, 82.35411439623151, 78.36684894561768, 75.51870591299874, 63.04208973475865, 63.288479804992676, 58.75949110303606, 56.34440496989659, 54.16618987492153, 55.369044644492014, 55.15770476205008, 56.90763289587838, 54.92913334710257, 54.29146589551653, 56.077166829790386, 57.43957655770438, 53.17092296055385, 50.632162366594585, 51.39802060808454, 52.376733439309255, 52.93322508675711, 58.03220926012312, 63.178330012730186, 66.25532586233956, 62.50488976069859, 61.06435448782784, 55.36361115319388, 59.00416496821812, 56.60761662891933, 57.5968907220023, 52.297798429216655, 51.12914964130947, 47.3160651070731, 54.18513413837978, 59.18130234309605, 60.31906986236572, 61.65726511819022, 62.86667551313128, 56.9854805128915, 60.373953683035715, 58.40226336887905, 60.92523765563965, 59.09632587432861, 61.2504689352853, 62.01998887743269, 68.9396025793893, 47.56301103319441, 63.14021914345877, 66.05598899296352, 55.726491246904644, 52.52270119530814, 59.949592454092844, 60.74355615888323, 61.89804104396275, 62.88632501874651, 60.75752203805106, 57.429918561662944, 49.02101060322353, 47.32099832807268, 48.75089590890067, 47.33559649331229, 47.699550083705354, 51.342469760349815, 57.42167452403477, 59.510646956307546, 60.44095516204834, 54.374323163713726, 53.966144289289204, 48.43409626824515, 47.62292882374355, 45.64344263076782, 45.390055724552695, 46.38829299381801, 49.4457539830889, 49.25804144995553, 50.10928610392979, 49.66867651258196, 51.74705294200352, 47.755503926958355, 51.001400062016074, 48.19107607432774, 53.88401310784476, 48.67053999219622, 50.768750054495676, 47.201718602861675, 51.13707058770316, 48.03778491701399, 53.79821327754429, 51.5018892288208, 56.614436285836355, 52.27752011162894, 60.62183066776821, 59.86786774226597, 73.66273089817592, 66.85557379041398, 80.65064539228166, 15.105911799839564, 0.6672223742519106, 2.240201494523457, 5.648946251188006, 0.2871109651667731, 0.9014530969517571, 1.5785434331212724, 1.077207128916468, 0.43856918226395336, 4.1689230629376, 24.957642725535802, 29.33937999180385, 69.17111655644008, 15.685824087687902, 22.67144741330828, 40.99767208099365, 57.70259714126587, 61.457136154174805, 60.32985346657889, 20.740339790071758, 0.799343076135431, 0.3803863243332931, 0.10809841126735721, 0.022066277717905383, 0.024733237556314895, 0.08924264234623738, 0.044783389262322865, 0.014807951303997209, 0.015573847706296613, 0.10653923957475595, 0.11032282547759158, 0.029027707741728852, 0.041738286947033236, 0.021064274877841984, 0.018686749240649596, 0.01518674347815769, 0.02595035804967795, 0.03415519670982446, 0.027719843367646848, 0.10587339994630643, 0.03653041193527835, 0.05140130754028048, 0.02215701650961169, 0.05364816090358155, 0.10958426725119352, 0.01915433450735041, 0.06785693525203637, 0.03466020318280373, 0.06747715920209885, 0.06780398916453123, 0.05370394666013973, 0.03816731320694089, 0.027607878304219673, 0.08061040126319442, 61.2466960634504, 95.90070452008928, 81.8177273614066, 68.68200506482805, 52.94608620234898, 50.298346587589805, 29.18404953820365, 45.34067487716675, 52.91422176361084, 18.00052091053554, 0.07538346959544079, 0.7952645378453391, 4.646708122321537, 4.458395004272461, 2.095549987895148, 0.8567899135606629, 0.09945808883224215, 0.5019549652934074, 59.65843514033726, 107.00796277182442, 89.36568055834088, 93.41613292694092, 82.10477134159633, 77.89510100228446, 71.26656123570034, 83.50896753583635, 77.87898118155343, 85.95046029772077, 81.95414134434291, 77.86101313999721, 66.38015719822475, 65.91659423283168, 61.54676096779959, 59.556616238185335, 57.21068899972098, 58.44125665937151, 57.167672702244346, 60.36314923422677, 57.37709488187517, 57.86641481944493, 59.41677679334368, 60.29400076184954, 55.06518602371216, 53.818797315870015, 54.823155948093955, 56.77221597943987, 57.554808957236155, 60.18669973100935, 66.37391771589006, 66.86284855433873, 63.75728171212332, 61.60425731113979, 58.69160025460379, 61.986449922834126, 60.9096736907959, 60.15177113669259, 55.4951822417123, 53.554046630859375, 50.66656984601702, 57.33774375915527, 60.44652761731829, 64.16633605957031, 63.281232833862305, 65.76028060913086, 60.44231700897217, 63.39102131979806, 61.47341578347342, 63.49299308231899, 61.46723188672747, 63.88444069453648, 66.18314797537667, 71.35215609414237, 49.804340090070454, 65.19285597120012, 68.1617795399257, 58.55492918831961, 53.56905473981585, 63.122591563633506, 65.43088735852922, 65.41623360770089, 66.05275113242013, 64.69119603293282, 60.974180766514365, 54.38473156520298, 50.49709980828421, 51.5165672983442, 50.542481967381065, 50.73731292997088, 53.621197496141704, 60.265895298549104, 62.948685101100374, 63.64357444218227, 58.27909960065569, 56.597465310777935, 50.39580202102661, 50.33492537907192, 48.96844400678362, 49.15675755909511, 49.39402117047991, 51.53361470358712, 53.32520423616682, 51.44835335867745, 52.35949495860508, 52.471221991947715, 50.45912790298462, 54.82385771615164, 51.47688961029053, 54.7235917363848, 52.035903453826904, 53.46504715510777, 50.126920631953645, 53.948040757860454, 51.44505991254534, 55.724306038447786, 54.59080818721226, 59.17126914433071, 55.06422022410801, 62.84197466714041, 61.242867606026785, 76.41815022059849, 69.0927061353411, 83.64838314056396, 30.834180695669993, 0.8378483642424855, 1.1065150648355484, 0.7220266706177166, 1.450253848518644, 3.6843552589416504, 2.4550400120871405, 2.4767659434250424, 0.49654145006622585, 2.892433456012181, 32.05512510027204, 32.26586743763515, 43.01401499339512, 15.779612609318324, 41.760118756975444, 50.14519439424787, 64.90236568450928, 65.3291379383632, 69.28144700186593, 41.92085143498012, 1.3506855113165719, 0.3167351526873452, 0.05892639660409518, 0.03500956729320543, 0.05403067484231932, 0.0629519277385303, 0.006354591983836144, 0.04190364932375295, 0.08743979515773909, 0.0936302872640746, 0.0773718146873372, 0.020884018657462936, 0.031064842894141163, 0.0716308316748057, 0.08476934595299618, 0.020802796319393174, 0.09236329275050334, 0.04856467832412038, 0.15053836788449967, 0.2266468182206154, 0.0924701891573412, 0.13154172152280807, 0.13157471189541475, 0.1927961582051856, 0.2218244969844818, 0.07924302427896432, 0.2121520210057497, 0.10677541047334671, 0.13683719879814557, 0.19595791426088127, 0.2017598229327372, 0.11119026464543172, 0.174638710383858, 0.19775365718773433, 70.49435928889683, 109.09441648210797, 94.453366960798, 82.52710369655064, 62.49309171949114, 50.807653018406455, 35.38322537285941, 80.6608453478132, 69.67183153969901, 26.15496325492859, 0.3365267978182861, 0.7698187689696039, 5.5671142765453885, 9.919151902198792, 2.709466108254024, 3.7990139978272572, 4.505911563123975, 0.8473837354353496, 54.673992020743235, 109.7412451335362, 89.25570447104317, 98.1143102645874, 86.52656323569161, 82.90821933746338, 75.4215978894915, 85.8726474217006, 80.32319068908691, 90.96334934234619, 87.9257984161377, 83.30689307621547, 68.66612843104771, 69.5223410470145, 66.30374091012138, 63.922905921936035, 60.413878032139365, 62.267421177455354, 61.321819986615864, 66.17615808759416, 59.411482266017366, 60.62226145608084, 62.25435161590576, 63.76076970781599, 58.31812763214111, 57.015524523598806, 57.86062002182007, 60.855234554835725, 60.219641140529085, 62.996870858328684, 68.48800441196987, 70.20102718898228, 66.69475078582764, 64.6031415121896, 60.05097361973354, 64.89024107796806, 63.453457832336426, 63.44252136775425, 58.463296345302034, 57.3121292250497, 53.38917630059378, 59.283635411943706, 63.86207444327218, 67.80041762760708, 68.2736177444458, 69.00292151314872, 63.9509071622576, 67.10363837650844, 67.07940305982316, 66.89696420942033, 66.07307461329869, 68.55467237745012, 70.529586655753, 73.06821523393903, 54.87825863701956, 69.5962142944336, 72.92725712912423, 61.978577613830566, 57.01304054260254, 67.33344309670585, 68.81349277496338, 67.97250366210938, 71.18466976710728, 67.22143118722099, 64.74810177939278, 56.28064135142735, 52.74984475544521, 54.325710092272075, 54.07309096200125, 55.06839609146118, 57.63250371388027, 64.75396605900356, 65.1158699308123, 65.56400094713483, 60.56001254490444, 59.3664996283395, 53.65459748676845, 54.86959423337664, 52.22842761448452, 52.72140230451311, 52.76743759427752, 54.68670375006539, 56.724704197474885, 53.79777554103306, 54.93954522269112, 57.64497920445034, 53.99475697108677, 58.432828494480674, 53.8919027873448, 60.784807613917756, 54.636311939784456, 56.65218932288033, 52.3630176952907, 57.90953186580113, 54.50095755713326, 59.08327715737479, 58.19570732116699, 62.71851907457624, 58.28902857644217, 66.93151760101318, 65.74544620513916, 81.08808313097272, 73.78842381068638, 89.71185370853969, 29.116943836212158, 1.3218097750629698, 7.577190348080226, 11.232260687010628, 1.136049902864865, 6.54392113004412, 4.32450886283602, 3.108283587864467, 0.5978887432387897, 6.789224675723484, 42.266159534454346, 40.996268544878276, 94.67522294180733, 21.714407750538417, 37.76356356484549, 56.79137563705444, 78.0739198412214, 75.11215986524309, 86.48420701708112, 48.56107112339565, 1.4236457220145633, 0.3916362720940794, 0.18254106491804123, 0.16361095570027828, 0.17713729345372745, 0.10973765687750918, 0.2372960996414934, 0.1574878692626953, 0.14055920764803886, 0.20060810473348412, 0.20742347330919333, 0.130000022106937, 0.11674295419028827, 0.1611174616430487, 0.2439072291765894, 0.09164975211024284, 0.16642797525439942, 0.15332333344433988], [0.048606757673301866, 0.03524175858391183, 0.03700727277568408, 0.09192133575145688, 0.046785630751401186, 0.07958965389324085, 0.03291990335232445, 0.08460595472050564, 0.07185200694948435, 0.04596658809376614, 0.03459915538717594, 0.035071235948375294, 0.018818088175196732, 0.0892796360754541, 0.09011066505419356, 3.855286589690617, 71.6867674418858, 73.29939569745744, 74.10074533735002, 52.86218670436314, 42.52437196459089, 17.553904601505824, 50.52243294034685, 53.58217988695417, 31.230023043496267, 5.245434829166957, 0.23106370121240616, 0.3526076434978417, 2.903214454650879, 2.6573587443147386, 1.7667902175869261, 0.16774550027080945, 1.6255165125642503, 21.935435158865793, 106.15231990814209, 86.80536665235246, 93.44644791739327, 82.43339334215436, 76.90338461739677, 62.245840072631836, 72.32687718527657, 67.62667097364152, 72.75883279527936, 75.75156784057617, 74.8779638835362, 65.29882989610944, 57.75901998792376, 57.73902307237898, 54.704741273607524, 55.05092484610421, 56.68989372253418, 54.06569460460118, 54.50888892582485, 55.90682479313442, 56.81234530040196, 55.7600336756025, 55.0568516595023, 54.632257665906636, 50.580617155347554, 48.17345544270107, 52.40834774289812, 52.89927618844168, 55.42894506454468, 60.1469977242606, 63.99136652265276, 61.96500083378383, 61.61205318995884, 56.77028438023159, 56.68339368275234, 54.875208377838135, 56.87560517447335, 53.34671933310372, 51.26338883808681, 49.90576294490269, 49.962772914341514, 49.85527385984148, 54.24301610674177, 57.577685901096885, 59.34488378252302, 57.30379833493914, 57.490597179957796, 56.69176973615374, 55.66521508353097, 57.077221052987234, 59.916310582842144, 61.17699868338448, 64.55667890821184, 66.66706221444267, 47.454285621643066, 65.4911629813058, 65.11733600071499, 53.1030946459089, 54.44614669254848, 61.57123947143555, 61.12087113516671, 62.18002673557827, 63.03434944152832, 63.0307502746582, 61.910096168518066, 54.01697383608137, 50.479944705963135, 45.42462648664202, 47.181652205330984, 46.16644396100725, 48.642257349831716, 53.21273027147566, 56.502837794167654, 56.68279961177281, 56.85336399078369, 51.820950508117676, 48.42857592446463, 45.65835346494402, 46.89037329810006, 45.492058753967285, 45.93892867224557, 45.624703339168, 49.52988971982683, 49.11948047365461, 48.588558197021484, 49.42274502345494, 49.70897953850882, 49.4210079738072, 50.022947788238525, 51.430830001831055, 51.13039684295654, 49.45843097141811, 50.63234649385725, 48.63756731578282, 53.22719989504133, 50.58715888432094, 53.21731260844639, 54.53153657913208, 57.993643283843994, 52.054288387298584, 58.03679854529244, 57.71180350439889, 73.61503846304757, 67.05728694370815, 76.1803342274257, 9.451901180403572, 1.5412719930921281, 3.0264123124735693, 1.8520959658282143, 1.086798031415258, 1.3662858456373215, 0.5144625912819589, 0.3484220595232078, 0.09745189148400511, 17.02143635068621, 25.9692257472447, 53.48507186344692, 61.478814533778596, 12.368916494505745, 24.29443195887974, 47.25659894943237, 59.52635683332171, 56.617764472961426, 53.64641598292759, 19.64697473389762, 2.21395662852696, 0.08692447495247636, 0.04832925381405013, 0.10595249677343027, 0.047438785167677064, 0.033254129346460104, 0.04599101535443749, 0.03912877697231514, 0.07945906304355178, 0.0492107352641012, 0.06848750463021652, 0.09156450775585004, 0.14824211038649082, 0.07587433539863143, 0.04953990617234792, 0.07690729639892067, 0.07684590933578354, 0.020051181382898773, 0.0269066004880837, 0.0335671477285879, 0.03146730576242719, 0.07320995229695525, 0.07250001467764378, 0.042101099621504545, 0.08602910049791847, 0.004880372027400881, 0.021627402964181135, 0.03941508482343384, 0.05981225121234145, 0.037327371670731475, 0.13703444892806665, 0.12338934040495328, 7.238374037402017, 90.79618263244629, 81.69079766954694, 82.2702635356358, 63.91641630445208, 50.0215824672154, 26.252601078578405, 38.61960594994681, 38.855813435145784, 42.279645987919395, 5.031624862125941, 0.17365228331514768, 2.626335688999721, 5.344892646585192, 3.7816582662718634, 2.264911025762558, 0.9057683082563537, 0.8773292771407536, 30.77129602432251, 110.44021306719098, 87.59880229404995, 98.50252001626151, 85.45604038238525, 80.19029249463762, 64.40128939492362, 75.25140871320451, 72.16931288582938, 78.02183614458356, 78.05768190111432, 76.09309264591762, 67.10365922110421, 60.751039368765696, 59.52934455871582, 59.40174783979143, 58.47622694287981, 60.96529402051653, 56.93993159702846, 57.432124614715576, 58.31118638174874, 59.69451713562012, 58.80052716391427, 56.81299148287092, 57.15201841081892, 54.19350324358259, 51.536407879420686, 56.11233166285923, 55.674442291259766, 57.248365606580464, 62.88681139264788, 66.0704481942313, 63.70579556056431, 63.6759808404105, 58.71228504180908, 60.67508166176932, 56.09362711225237, 60.10766397203718, 55.36818306786673, 53.96916675567627, 52.861377239227295, 53.205542360033306, 52.332108633858816, 58.624202728271484, 60.60088184901646, 62.258847100394114, 60.71861212594168, 61.27061176300049, 58.41452693939209, 60.05896404811314, 60.20794037410191, 62.944168772016255, 65.30427033560616, 66.8766268321446, 69.87998567308698, 49.66768639428275, 69.38373143332345, 68.03034046718052, 55.82812949589321, 58.67392403738839, 64.96872098105294, 63.64925112043108, 66.34544399806431, 66.44886098589215, 66.60153375353131, 62.221743719918386, 58.967485427856445, 53.53689500263759, 48.90564271381923, 50.72278077261788, 48.711277280535015, 50.54265219824654, 58.155029092516216, 59.59875706263951, 59.34302166530064, 58.704405784606934, 54.23288563319615, 51.95448098863874, 48.78784990310669, 49.71349934169224, 47.73135198865618, 47.22157308033535, 49.521940980638774, 51.69209269114903, 50.80033309119088, 51.9327609198434, 52.48451042175293, 52.39992305210659, 51.29837996619088, 53.10204546792166, 52.69851493835449, 53.60078368868147, 52.060034547533306, 53.77466583251953, 50.47448689596993, 56.95132664271763, 53.039397035326274, 55.68626812526158, 56.22521904536656, 61.69314561571394, 55.960225173405235, 62.095335142953054, 59.13119193485805, 77.77553640093122, 69.12995542798723, 82.28420162200928, 21.163045610700333, 1.7261053664343697, 1.2865360506943293, 1.34635591506958, 3.882668137550354, 2.3016333409718106, 0.9331222261701311, 0.5333378070167133, 0.16500480233558587, 16.28659313065665, 36.09857021059309, 51.217523779187886, 38.24955184119088, 16.041722978864396, 36.86706876754761, 56.461676665714805, 69.10530321938651, 63.67364624568394, 69.65390518733433, 38.471671853746685, 5.7208674890654425, 0.07259733017001833, 0.025159389778439487, 0.07854250472571168, 0.14231176860630512, 0.025950766867026687, 0.012112354743294418, 0.07232383306005172, 0.05538864733119096, 0.03581064234354666, 0.03196683306513088, 0.10505831654050521, 0.09820932655462197, 0.0842350267672113, 0.025138803025973693, 0.03822783513792923, 0.08258088731339999, 0.1138333146061216, 0.19801159548972333, 0.11110555633370366, 0.28363654017448425, 0.13909393841666834, 0.25913407068167416, 0.10128628608903714, 0.14075841195881367, 0.19319926228906426, 0.15421315069709504, 0.10367819666862488, 0.1923262184219701, 0.09146627624120031, 0.24817480732287678, 0.2971788506422724, 9.193306599344526, 109.02378804343087, 95.36465794699532, 96.29369463239397, 72.65261568341936, 61.0497076851981, 26.57900139263698, 66.69117246355329, 73.50158132825578, 51.339280537196565, 8.914302553449359, 0.4808207707745688, 4.7117041775158475, 9.067243695259094, 8.73269053867885, 5.902116026197161, 5.981538278715951, 3.390812324626105, 27.013451405933925, 115.31554167611259, 94.49739074707031, 102.78504916599819, 88.53992189679826, 83.75504493713379, 67.04445362091064, 78.89596121651786, 76.30914688110352, 81.35033593858991, 82.69566004616874, 82.03069659641811, 71.78574453081403, 64.88673223767961, 65.00340638841901, 62.42828587123326, 61.97105271475655, 65.31397696903774, 60.44692366463797, 61.340607915605815, 63.11672728402274, 62.332859311785015, 61.50566932133266, 59.33777577536446, 61.499221393040244, 58.235826219831196, 54.520805086408345, 59.05404608590262, 59.47185516357422, 62.23727989196777, 66.30580452510289, 68.49438980647496, 65.90177372523716, 64.02934537615094, 61.53383731842041, 62.5995728628976, 60.55251543862479, 63.95089326586042, 59.160853794642854, 58.41379737854004, 55.72130789075579, 56.28088106427874, 55.970473766326904, 61.584753717694966, 63.76581409999302, 64.85186617715019, 63.57416888645717, 65.18340642111642, 61.31351688929966, 63.132249559674946, 63.45967647007534, 65.90598433358329, 69.5742301940918, 72.2689014162336, 73.69254561832973, 53.91777787889753, 72.2761344909668, 70.38888563428605, 57.62183822904314, 61.135934829711914, 67.95054040636334, 67.38241400037492, 69.27963352203369, 69.8798189163208, 68.56277397700718, 68.13823904309953, 62.32775933401925, 55.34389911379133, 51.56627818516323, 54.060445240565706, 50.99427815846035, 54.30425405502319, 59.9004339490618, 62.003785678318565, 60.912397384643555, 62.65234443119594, 56.74576766150338, 55.474483558109824, 52.46013961519514, 53.39374821526663, 50.74842309951782, 51.63802180971418, 52.038905075618196, 55.57571186338152, 53.00352348600115, 53.840850898197715, 55.62310552597046, 55.55358532496861, 55.86153643471854, 55.84899493626186, 56.060084683554514, 56.02760532924107, 54.64325666427612, 56.21508509772164, 53.569773878370015, 61.12701334272112, 55.287427629743306, 58.06084973471505, 59.37030724116734, 63.5226479939052, 57.05080400194441, 64.15063313075474, 63.542415618896484, 82.57726969037736, 72.71089022500175, 85.60559340885708, 20.71206930705479, 2.5334356682641164, 8.112398794719152, 7.031450169427054, 5.977968641689845, 5.547210727419172, 1.1471232686723982, 1.1740054147584098, 0.14411398475723608, 27.55396740777152, 42.51470702035086, 69.81117071424211, 80.56762831551688, 17.664273262023926, 40.44987610408238, 67.16540091378349, 79.5846527644566, 73.71856662205288, 85.1072199685233, 40.01415804454258, 4.37339769090925, 0.13040965369769505, 0.14297730289399624, 0.11838123628071376, 0.18282295550618852, 0.13723606882350786, 0.13796417761061872, 0.1443660876580647, 0.15696874926132814, 0.110061155233, 0.11171810382178851, 0.22733557197664464, 0.21740194143993513, 0.15154179904077733, 0.11636096611618996, 0.14289596011596067, 0.11892069876194], [0.05246455495112708, 0.03890450079260128, 0.05763972457498312, 0.03633722962279405, 0.05703679871346269, 0.06225486871387277, 0.002004283879484449, 0.12526500118630274, 0.07225059877548899, 0.019404182975579585, 0.03348003401021872, 0.23796206819159643, 0.04349522784884487, 0.17159089392849378, 0.6317620256117412, 17.00097737993513, 78.90635572160993, 63.10789612361363, 67.8041627066476, 46.24108845846993, 36.44894354684012, 29.99036714008876, 76.69457735334123, 43.0277133669172, 23.91216812814985, 0.037664220202714205, 0.22144131468875067, 1.0608374987329756, 3.269522398710251, 1.2477543545620782, 1.5116769011531557, 0.7215960994362831, 2.7740339807101657, 90.79684965951103, 86.9430799484253, 85.68908296312604, 82.96676485879081, 77.56809098379952, 67.22290420532227, 66.66659668513707, 62.28002520969936, 67.92159421103341, 69.69203690120152, 67.87905039106096, 62.85024997166225, 58.12552009310041, 57.583366053445, 54.32478250776018, 57.18065193721226, 54.274123191833496, 55.143867424556184, 54.75808606828962, 55.23052535738264, 56.232445171901155, 56.136174406324116, 51.908296312604634, 54.84056118556431, 51.52753502982003, 49.30452142442976, 50.96877826963152, 52.79459115437099, 50.71994243349348, 57.6515383039202, 60.57075445992606, 61.616701534816194, 61.58760942731585, 58.39646162305559, 57.50937468664986, 55.20437928608486, 54.8818439074925, 54.665758405412944, 52.14739424841744, 49.692904881068635, 48.32881716319493, 48.47982931137085, 48.218427658081055, 51.00425577163696, 54.22206728799002, 54.01849201747349, 57.300862721034456, 55.3147097315107, 52.001575878688264, 54.359745843069895, 53.75931378773281, 55.67897251674107, 58.30088220323835, 63.44270896911621, 62.10884244101388, 45.024608271462576, 66.36123030526298, 62.222111974443706, 53.33289589200701, 52.766089643750874, 60.432804925101145, 57.746822425297324, 61.30547782352993, 59.128141675676616, 64.39190237862724, 58.79362760271345, 60.137978962489534, 55.14142165865217, 48.91110747201102, 47.09620673315865, 45.97447565623692, 46.06432628631592, 53.2818717956543, 55.19319616045271, 56.71651227133614, 55.02411869594029, 54.021385942186626, 48.40655708312988, 46.91998304639544, 44.96505873543875, 46.05210787909371, 44.344476904187886, 45.1713090624128, 48.99829346793038, 47.39483683449881, 47.952176162174766, 48.29752942493984, 48.92098781040737, 48.59746926171439, 48.54035159519741, 49.72625276020595, 49.95665155138288, 50.90492779867989, 50.0357984815325, 50.6952520098005, 54.685988085610525, 54.63765641621181, 58.186712878090994, 62.48694951193673, 62.257200377328054, 64.31203283582414, 58.67174230303083, 62.999281883239746, 60.54984038216727, 72.40384932926723, 67.48305865696499, 70.00945145743233, 3.4689039971147264, 0.6560869632022721, 3.184111450399671, 3.3755471323217665, 1.9349102420466286, 1.4275331305606025, 0.2823016718029976, 0.05061439351577844, 1.4691962663616454, 30.353914260864258, 37.71678829193115, 75.75402750287736, 47.358612401144846, 27.275184835706437, 39.73713336672102, 48.80195822034563, 53.49414621080671, 59.38850457327706, 59.78209917885916, 36.30982324055263, 4.447610965796879, 0.12822395669562475, 0.09809571943644967, 0.05917997192591429, 0.048677678153451, 0.031052110184516226, 0.11327157582023314, 0.02931420218997768, 0.05653411622292229, 0.018440439332542673, 0.043466152623295784, 0.033231961607400856, 0.034031784760632684, 0.016357206207300936, 0.03550855855324438, 0.08727499935775995, 0.08024294062384538, 0.09516068228653499, 0.08125630553279604, 0.016707287868484855, 0.05837429980082171, 0.06898411762501512, 0.0397090431568878, 0.11075685718762023, 0.04396623293203967, 0.04452089120500854, 0.05173114002017038, 0.13209216270063603, 0.05663559452763625, 0.2089816882674183, 0.3567018152347633, 28.12587537084307, 94.95836203438895, 72.56149700709751, 78.89175060817173, 57.523757457733154, 50.63886390413557, 37.36207233156477, 50.52327367237636, 47.0984787940979, 28.99285422052656, 0.07043077464082412, 0.3267427028289863, 4.928184424127851, 4.809596478939056, 2.250556047473635, 1.4993325578314918, 0.7734759641545159, 4.346550720078604, 99.78051607949394, 88.52258614131382, 90.52442468915666, 85.83571774618966, 77.24229690006801, 70.31251798357282, 67.99341773986816, 65.92730140686035, 70.75807121821812, 71.09736565181187, 70.86596284593854, 66.00740024021694, 60.6484283719744, 59.7601706641061, 57.58869184766497, 60.02624498094831, 58.03790330886841, 57.48093223571777, 57.058012757982524, 57.12763718196324, 58.727953229631694, 59.17551449366978, 57.481738226754324, 57.88861083984375, 55.21474599838257, 52.56360871451241, 54.085198198046, 55.363024030412944, 54.43522759846279, 59.222289766584126, 61.67771366664341, 64.04409640175956, 62.46313803536551, 60.65353529793875, 59.75068637302944, 58.36806433541434, 58.0537417275565, 58.08055830001831, 54.77066925593785, 51.978886536189485, 50.49624865395682, 51.40295730318342, 51.009171622140066, 53.607248987470356, 56.934838567461284, 57.54981320244925, 59.1905642918178, 58.50704915182931, 56.10295854296003, 57.739509446280344, 55.220495632716585, 59.166488783700125, 62.2061311176845, 66.99473231179374, 64.74011829921177, 46.603496074676514, 69.4740858078003, 63.54019219534737, 57.467025416237966, 56.47095945903233, 64.60980483463833, 61.51443794795445, 65.01805319104875, 62.52941690172468, 67.72736426762172, 62.78832067762102, 63.022099767412456, 58.785331453595845, 51.89090149743216, 48.8286566734314, 49.187902859279085, 48.54562875202724, 55.64572886058262, 58.78447682516915, 59.545262881687705, 55.73292875289917, 56.7334554536002, 51.94164419174194, 50.74556391579764, 46.64481701169695, 49.77649518421718, 47.80808789389474, 46.956718172345845, 50.22023146493094, 50.14247070040022, 50.55025005340576, 50.79244688579014, 51.90130295072283, 52.95823860168457, 50.9009291103908, 53.178461756025044, 52.14961767196655, 53.62883356639317, 53.15020343235561, 54.53007050922939, 56.164040156773154, 58.29579612186977, 61.25312314714704, 65.53281048366001, 63.921919277736116, 68.44532857622418, 62.65979984828404, 67.76113946097237, 61.01249313354492, 76.30551297324044, 68.86611148289272, 82.1909429005214, 12.155329738344465, 1.4432275912591388, 1.161052669797625, 1.9253799191543033, 3.5840250083378384, 2.2728977629116605, 0.8689755882535661, 0.045490164908447435, 0.7083153235060828, 33.215887682778494, 43.40473651885986, 65.31181607927594, 34.04799699783325, 39.14981256212507, 56.372013636997764, 55.78216716221401, 60.344145911080496, 65.67059326171875, 71.70350565229143, 52.82064689908709, 8.012909276144844, 0.1539362676973854, 0.030879728363028595, 0.0763724208144205, 0.04811320147876229, 0.012503749009088745, 0.07866904472133943, 0.01803479074234409, 0.03079153916665486, 0.09924915432929993, 0.07414793875068426, 0.00946818944066763, 0.03404710947402886, 0.06644861546478101, 0.055649991878973584, 0.08145521807351283, 0.12161132081278733, 0.11840052024594375, 0.11187190735446555, 0.10292796763990607, 0.17476383224129677, 0.11829749148871217, 0.14474233532590525, 0.29275442234107424, 0.19400001503527164, 0.16756008379161358, 0.10492907597550324, 0.3096934248294149, 0.1995287997914212, 0.3085223005286285, 0.6023410186171532, 34.494467394692556, 112.4616733278547, 83.53717027391706, 90.26681327819824, 66.64170823778424, 53.20448623384748, 40.25395427431379, 102.20001084463937, 65.0202557700021, 41.41288948059082, 0.23141895500676973, 0.8706840851477214, 5.3150345001901895, 8.516914231436592, 6.216218028749738, 5.497435569763184, 3.7563034210886275, 3.3100314821515764, 103.88583142416817, 92.97278921944755, 94.53921890258789, 89.65363475254604, 81.94667897905622, 73.08793422154018, 72.22702462332589, 69.21013069152832, 74.34692001342773, 74.7210944039481, 75.52483422415597, 70.2239076069423, 63.28324086325509, 63.02820723397391, 61.266338620867046, 63.460204533168245, 61.16486712864467, 61.877071380615234, 61.293485232761924, 62.344421114240376, 62.86314582824707, 62.570161138262065, 58.45989867619106, 60.75436060769217, 58.91557543618338, 55.57525675637381, 57.27774953842163, 58.02208226067679, 56.11342600413731, 62.15750067574637, 64.447418485369, 67.15283857073102, 64.85456902640206, 62.905898094177246, 64.28658158438546, 61.60184628622872, 61.943822724478586, 61.926591191973, 58.117828437260215, 55.425648144313264, 54.62346819468907, 54.66466406413487, 54.19020284925188, 57.20612055914742, 59.42767851693289, 61.1374842779977, 63.791327885219026, 61.06629998343331, 58.77887657710484, 60.990654945373535, 58.80213219778878, 62.06164332798549, 64.328444480896, 68.98081929343087, 68.42831938607353, 52.60334546225411, 72.12057127271379, 68.2632371357509, 60.611700194222585, 59.227236883980886, 67.22722598484584, 63.117790358407156, 67.72771167755127, 65.08636093139648, 70.88509818485805, 66.11375631604875, 66.97857080187116, 61.46746117728097, 53.79914781025478, 52.02523449489048, 51.907076903751914, 52.36372988564627, 60.76995236533028, 62.649919509887695, 61.91355637141636, 59.02478722163609, 61.20937728881836, 54.07553672790527, 53.15177025113787, 49.798774582999094, 52.80709443773542, 50.485510213034495, 49.87674379348755, 54.470364638737266, 53.947940008980886, 52.76249047688076, 52.736771719796316, 53.95055947984968, 54.97529023034232, 53.83453845977783, 55.984922545296804, 56.298199449266704, 57.81468200683594, 55.92899649483817, 56.95146213259016, 59.477330344063894, 60.44408185141427, 64.99799374171666, 67.07257992880685, 67.21182182856968, 69.9797340120588, 64.5766132899693, 70.61891964503697, 65.9248834337507, 81.47220039367676, 72.67812252044678, 84.66645404270717, 11.199605022157941, 1.3233853876590729, 12.439768144062587, 6.422572578702654, 6.203730378832136, 4.830968269280024, 0.7866941520145961, 0.20026142762175628, 3.0192246181624274, 46.119203158787315, 51.80653299604143, 98.02039841243199, 64.38930375235421, 38.872357095990864, 57.17933872767857, 66.27725437709263, 73.44018704550606, 80.00954205649239, 86.83440317426408, 56.94332579204014, 7.075628553118024, 0.21297488042286464, 0.10360317105161292, 0.12307656290275709, 0.10357820096292666, 0.06914605679256575, 0.16816334213529313, 0.07207029166498355, 0.21374714826898916, 0.1787843286458935, 0.18985389465732233, 0.15874062132622513, 0.14284886978566647, 0.15046866876738413, 0.1505690376673426, 0.15681331045925617], [0.024035179388842413, 0.034907546160476546, 0.03909942015473332, 0.070076301161732, 0.020438979413094263, 0.032115099752055745, 0.029296356718987226, 0.05672062514349818, 0.05545122522328581, 0.06915678443121058, 0.10616366365658385, 0.048684036026575735, 0.0031804622059488402, 0.023712649642090713, 0.6457290990012032, 53.82241037913731, 69.93286146436418, 67.84131472451347, 53.87170089994158, 36.14607504435948, 19.209071465900966, 40.06604719161987, 51.79617670604161, 30.443424429212296, 9.378212060247149, 0.29427816772035187, 0.9412283854825156, 1.4313735302005495, 3.1365184613636563, 2.4027465667043413, 0.35671487024852205, 1.2662340658051627, 33.54838330405099, 102.12829153878349, 78.54051916939872, 86.30323423658098, 70.18078013828823, 66.26209340776715, 62.34456007821219, 63.604810442243306, 61.848833901541575, 59.93101297106062, 59.3740245274135, 59.44815485818045, 58.22770724977766, 58.303800446646555, 56.26842294420515, 55.47198568071638, 54.29061821528843, 56.007802963256836, 54.14323650087629, 54.127530097961426, 54.94215079716274, 55.05021612984793, 56.38143539428711, 56.038854462759836, 55.94457088197981, 48.920341627938406, 49.26303025654384, 51.10292713982718, 50.255198274339946, 54.934299332754954, 59.440998213631765, 60.39260959625244, 60.19756671360561, 56.75440427235195, 58.68994658333914, 57.156482628413606, 54.27883059637887, 53.02189104897635, 53.45479161398751, 48.808513845716206, 47.08430446897234, 47.60934509549822, 46.41917078835623, 47.38210426058088, 46.90656607491629, 50.73097964695522, 53.051316670009065, 54.75096763883318, 57.29587044034685, 55.506077017102925, 54.2479111126491, 51.64747135979788, 56.292119775499614, 60.76218427930559, 65.26215035574776, 58.07904359272548, 42.48000771658761, 68.12562806265694, 60.81414985656738, 54.18480062484741, 52.86415304456438, 60.963077545166016, 57.827070644923616, 60.738372802734375, 60.28567681993757, 60.75127560751778, 59.83136885506766, 58.73804896218436, 58.443549564906526, 52.9313907623291, 46.337261949266704, 46.51133516856602, 46.16858400617327, 51.86386258261544, 51.283618518284385, 54.59099926267351, 54.521326201302664, 51.57217720576695, 49.90193796157837, 47.81591851370675, 46.704845973423545, 44.68945149012974, 45.54020282200405, 44.10407270703997, 44.44041763033186, 48.18709128243582, 47.66425323486328, 48.462246894836426, 48.4962374823434, 49.282464368002756, 48.825721059526714, 48.88503435679844, 48.21084369931902, 48.75474868501936, 52.760805538722444, 56.9172248840332, 60.72857584272112, 63.08459186553955, 66.84808363233293, 64.82371207645961, 70.34398637499127, 67.1876698902675, 66.0254794529506, 67.33021218436105, 62.83863953181675, 65.91446808406285, 67.58102825709751, 73.12776129586356, 58.54549353463309, 0.13539604470133781, 1.5701054973261697, 4.394988783768245, 1.8797647782734461, 1.8356773725577762, 0.574604081256049, 0.15768544508942536, 0.13088808873934404, 14.344379680497305, 29.259513923100062, 34.68840898786272, 64.75886453901018, 12.183403066226415, 15.233223642621722, 27.783388239996775, 46.82988575526646, 50.985836097172324, 55.079700810568674, 56.77349444798061, 41.57516813278198, 2.8253423018114905, 0.2687517888844013, 0.022530329513496587, 0.04157123501811709, 0.049581178064857206, 0.09744782027389322, 0.03895903465205005, 0.004399342437474323, 0.052774374040641954, 0.023720987141132355, 0.02486988602738295, 0.037260532578719516, 0.053646657948515246, 0.04432387177699378, 0.0176426992818181, 0.10530685034713574, 0.021471329731866717, 0.006520784293700541, 0.00906367230761264, 0.050649063262556276, 0.046097528388989825, 0.023779934870877435, 0.012436361151880451, 0.03694102740181344, 0.07839288096874952, 0.08265055928911481, 0.04275275108271411, 0.04092083206134183, 0.02510433683970145, 1.8342514719281877, 74.57846178327287, 80.23925645010812, 77.3819556917463, 60.015690667288645, 46.25227853230068, 25.11173118863787, 38.10729789733887, 41.189115796770366, 37.30529512677874, 9.325329320771353, 0.4881133937409946, 1.2479391332183565, 3.5704167442662373, 6.1166455660547525, 2.9244518407753537, 1.0220424490315574, 0.6655769539730889, 43.83023725237165, 102.3448738370623, 84.12715571267265, 88.68238081250871, 69.9671994618007, 67.56472083500454, 64.71506309509277, 66.15594577789307, 63.62639849526541, 62.652455602373394, 61.31393378121512, 61.29887703486851, 60.1370062146868, 60.22182287488665, 59.10137721470424, 59.7099004473005, 57.73818928854806, 59.00112860543387, 58.927602767944336, 57.76998771939959, 55.95174837112427, 57.84111295427595, 57.34737743650164, 59.428623471941265, 58.22807897840227, 51.52381774357387, 52.70252404894148, 54.04827894483294, 53.91978938238961, 56.84170491354806, 62.75653961726597, 62.858483586992534, 62.141179357256206, 58.31811373574393, 60.889510018484934, 59.35568823133196, 57.99354600906372, 56.39554718562535, 55.72251687731062, 52.07237802233015, 50.83327797480992, 50.019817624773296, 50.038494382585796, 50.829546792166575, 48.917749949863975, 54.05786745888846, 57.38415425164359, 57.95602573667254, 62.36683600289481, 58.852096693856375, 57.93298898424421, 54.905495575496126, 58.786651611328125, 64.77025263650077, 69.07937254224504, 61.27448885781424, 47.10815068653652, 71.74805750165666, 64.70641258784703, 57.24807030814034, 57.01846013750349, 64.72608988625663, 61.19546004704067, 63.833225522722515, 63.46185820443289, 63.21494007110596, 63.18387467520577, 61.26488644736153, 62.17613574436733, 55.863943985530305, 49.03237438201904, 49.86592892238072, 49.38597515651158, 54.709021363939556, 55.613360677446636, 56.873611041477744, 56.54233135495867, 53.461461884634836, 52.95028638839722, 50.90434414999825, 49.175969328199116, 46.6490797315325, 48.64329610552107, 46.107592718941824, 46.65281786237444, 50.29381288800921, 50.38997595650809, 51.447397981371196, 50.99751949310303, 50.642848696027485, 51.49196025303432, 52.69534655979702, 50.82912990025112, 50.37413753782, 56.660999638693674, 61.43983513968331, 65.18170411246163, 65.4806295122419, 69.82919434138707, 67.872560773577, 72.14281940460205, 70.8593898500715, 69.67854349953788, 70.34324291774205, 68.8776524407523, 65.87800393785749, 71.52226189204625, 73.1989803314209, 72.02782671792167, 10.306036284991674, 2.916347635643823, 1.3507696496588844, 1.637676402926445, 2.835213303565979, 1.4068791759865624, 0.7223758718797139, 0.16633152828684875, 15.638468640191213, 36.92116049357823, 37.230483872549875, 49.323632444654194, 17.640731028148107, 31.470333439963206, 38.49905470439366, 55.28255346843174, 59.03731482369559, 63.99793951851981, 65.4855488368443, 58.03398105076381, 5.125662650380816, 0.3291496293885367, 0.014118159389389413, 0.025118552148342133, 0.03819464799016714, 0.04957656741940549, 0.04246589022555521, 0.0543477678272341, 0.03166308007868273, 0.023250055000452057, 0.011960675873394524, 0.047674555730606825, 0.03320434523214187, 0.06640190511409726, 0.07759830289121185, 0.1762695557304791, 0.08410262422902243, 0.12840724257486208, 0.14054946388517106, 0.15750190136688097, 0.10616665599601609, 0.1864972904856716, 0.16564593650400639, 0.12072965955095631, 0.12989403493702412, 0.18122960600469792, 0.14429786774728978, 0.13271458287324223, 0.08812640474310943, 1.8498792733464922, 85.57616083962577, 93.7643210547311, 90.36724948883057, 73.04107557024274, 54.55779382160732, 28.017453942980083, 56.08762386866978, 72.45116656167167, 48.58488954816546, 14.376401322228567, 0.6362685837915966, 1.9317470746380943, 4.9326664464814325, 13.233985458101545, 5.453859942299979, 5.232694438525608, 1.6656070756060737, 42.62961285454886, 107.89704731532505, 88.57508672986711, 94.10169083731515, 75.96704537527901, 72.75221116202218, 68.44819818224225, 71.08098179953438, 65.86606693267822, 65.90350382668632, 64.93625204903739, 65.50840841020856, 63.880660874503, 64.82788099561418, 62.67140333993094, 62.6247044972011, 61.615812165396555, 63.63952364240374, 62.78028161185128, 61.32334859030587, 60.535742487226216, 61.31260667528425, 61.71071066175188, 61.70393616812569, 62.297222001211985, 55.355085713522776, 55.88580649239676, 57.38749633516584, 57.401448317936485, 60.931664739336284, 67.16697120666504, 65.6328923361642, 65.15817056383405, 59.46159962245396, 64.3835506439209, 62.68217304774693, 62.00438322339739, 59.636228697640554, 60.65336854117257, 55.270807538713726, 53.876522949763704, 54.797791549137656, 53.80551583426339, 54.64003964832851, 50.94705125263759, 57.128286838531494, 59.296566009521484, 60.53422777993338, 64.47126470293317, 64.11728177751813, 62.51217147282192, 59.3647278376988, 62.17916515895298, 68.71485614776611, 71.76664393288749, 65.51604448046002, 51.887020928519114, 75.16820403507778, 67.63854544503349, 61.02996785300118, 61.20702879769461, 67.53979069846017, 64.28000858851841, 67.49282087598527, 66.20907170431954, 65.3093981061663, 66.57498468671525, 64.1262241091047, 66.03376865386963, 58.00135578427996, 52.021652698516846, 52.51224415642874, 51.70854949951172, 57.93756437301636, 58.26604046140398, 60.11686338697161, 60.207884788513184, 56.306554658072336, 55.346577644348145, 54.734899929591585, 53.73128475461687, 50.70645598002842, 51.60933269773211, 50.17712484087263, 48.89735351290022, 52.7112648827689, 53.255930696214946, 54.629356792994905, 52.95000498635428, 54.203282833099365, 54.61792353221348, 55.36301360811506, 54.32010637010847, 53.4472667149135, 60.60691288539341, 63.73446382795061, 68.20598397936139, 67.83395658220563, 74.73862470899309, 71.26294817243303, 76.63060528891427, 73.78637409210205, 74.11994321005685, 74.4795263835362, 71.88166441236223, 70.0966444015503, 75.30119950430733, 78.75378022875104, 72.21020998273576, 10.821583935192653, 3.870594773973737, 13.228915878704615, 4.886478730610438, 6.015208380562918, 1.706317113978522, 0.6344507070524352, 0.1877788124339921, 23.927381208964757, 44.47837216513497, 47.84730352674212, 82.89870725359235, 19.181104966572352, 25.942134720938547, 46.139356408800396, 65.75046975272042, 71.35852759225028, 74.22389520917619, 82.3166913986206, 62.56924397604806, 4.90672013589314, 0.37852312145488604, 0.09798013778137309, 0.15558813405888422, 0.11938336464975562, 0.20561656169593334, 0.09432638955435582, 0.09960918501019478, 0.181116412792887, 0.12610182485410146, 0.06271504437816994, 0.11677842800106321, 0.14616518254790986, 0.19650106797260897, 0.1668870449066162], [0.09158554912677833, 0.08914209702717406, 0.10474167138870273, 0.06404392807079212, 0.01565704627760819, 0.034112530427851846, 0.10226045881531068, 0.009584810102491506, 0.13223559143287794, 0.055116548003362756, 0.23113785151924404, 0.03349685150065592, 0.15663047241313116, 0.1782309833381857, 14.722308703831263, 87.68634959629604, 65.47124249594552, 67.48116179874965, 52.22556843076433, 46.36215387071882, 27.475987774985178, 64.69818592071533, 33.71944795336042, 29.087087426866802, 0.8819071629217693, 0.036963320669851134, 0.3990451959627015, 4.924181393214634, 3.1860343643597195, 1.4535385008369173, 0.19696323174451077, 0.9338815339973995, 80.66274915422711, 87.55914197649274, 81.41528075081962, 75.5813786642892, 67.06661837441581, 68.82404708862305, 67.71656676701137, 67.49922016688755, 60.522269930158345, 57.16322932924543, 57.65872621536255, 55.580019746507915, 55.580200399671284, 55.990710394723074, 55.58200345720564, 56.46349014554705, 54.674787589481895, 56.03749261583601, 54.11274780545916, 53.81899186543056, 54.12821796962193, 54.37585176740374, 53.88034445898873, 56.05707958766392, 53.22266966956002, 48.784045764378135, 50.433989320482524, 51.35073464257376, 52.84058822904314, 55.083841936928884, 59.0153237751552, 57.610015869140625, 59.019318989345, 58.30601692199707, 54.42012568882534, 55.2615247453962, 54.25505386080061, 52.36105135508946, 51.27473177228655, 47.18085663659232, 48.25084795270647, 47.427013942173545, 47.85247646059309, 45.49860395703997, 48.55246230534145, 50.01360593523298, 52.018838678087505, 57.58443260192871, 58.91135787963867, 55.48517336164202, 57.06412022454398, 51.1313487461635, 56.25529432296753, 60.702923093523296, 65.65715544564384, 50.68091440200806, 43.880524839673726, 65.6637214933123, 59.34387629372733, 55.01712185995919, 52.6137330191476, 61.77131979806082, 58.315410886492046, 59.37750557490757, 59.81851468767439, 62.32206875937325, 59.592934472220286, 62.92782660893032, 61.47223458971296, 55.10112905502319, 47.04618665150234, 45.876106534685405, 45.83367735998971, 50.2492401940482, 54.13339785167149, 50.75688600540161, 50.83307300295149, 48.704811981746126, 51.18054894038609, 48.783309255327495, 46.61131279809134, 45.53519664491926, 44.76843513761248, 43.510039942605154, 43.86070162909371, 46.27492618560791, 48.81919322695051, 46.71631050109863, 48.220063958849224, 48.4963139125279, 48.5320589201791, 48.0848832811628, 48.58068241391863, 50.6273854800633, 58.159180641174316, 63.40675898960659, 65.08335930960519, 65.58137144361223, 67.01316588265556, 70.31097548348563, 68.99483380998883, 69.12415368216378, 71.3030948638916, 66.93938991001674, 68.56997231074742, 69.70284135001046, 71.27189745221818, 70.46173054831368, 70.0331448146275, 49.57901348386492, 1.3205504140683582, 0.5656422621437481, 4.016739274774279, 1.1451167591980524, 1.898055693932942, 0.159242520108819, 0.08131100224064929, 2.784240884440286, 28.63916311945234, 28.42733860015869, 43.55640527180263, 34.85786165509905, 19.230124507631572, 23.856931686401367, 30.4840818132673, 42.77981901168823, 55.0186574118478, 51.271862166268484, 52.17101117542812, 31.3901720728193, 2.2175017297267914, 0.060974378138780594, 0.08649072822715555, 0.0241471376669194, 0.20523375937981264, 0.03456338302099279, 0.030651007778942585, 0.029823714135480777, 0.13241981369044098, 0.10337598395666905, 0.07157598568924836, 0.03225068122680698, 0.05294956838978188, 0.025256903742306998, 0.023612652240054946, 0.031464170930641036, 0.07865463942289352, 0.02745345900101321, 0.08436476266277687, 0.0487723609299532, 0.10754026871706758, 0.01633735736166792, 0.06765866731958729, 0.04535172680126769, 0.14056357741355896, 0.04512574410598193, 0.40396422200969284, 0.36863610627395765, 22.346798045294626, 100.63981369563511, 74.12265995570591, 76.17487294333321, 65.01839365277971, 60.08661093030657, 37.7974534034729, 45.72910002299717, 36.6592446735927, 38.30519996370588, 0.7489677135433469, 0.24072983967406408, 3.1638129396098, 8.698708636420113, 4.24192214012146, 2.8915849072592597, 0.8561216379914964, 1.3531923996550697, 83.40726675306047, 93.45133250100272, 85.3391022000994, 79.66827433449882, 70.21374934060233, 73.14646584647042, 70.54959746769497, 71.53250353676933, 64.7052036012922, 61.43299116407122, 59.367903164454866, 59.4511912209647, 58.42966706412179, 59.28072411673409, 58.31187425340925, 58.64230278560093, 58.58955206189837, 59.584256172180176, 56.59451232637678, 55.43206133161272, 57.24760477883475, 57.67056247166225, 56.04075132097517, 58.47190516335623, 56.959365708487375, 52.2935357093811, 51.9668869972229, 55.24151045935494, 56.87370484215872, 57.81618629183088, 60.861126627240864, 58.54774475097656, 60.282480648585725, 58.973488671439036, 56.69798142569405, 57.78410645893642, 55.97000823702131, 54.65173346655709, 54.136448110852925, 49.473022188459126, 53.73873322350638, 50.381158692496165, 50.29107877186367, 48.04534455708095, 50.803897517068044, 52.60192108154297, 54.492783001491, 61.319478443690706, 62.80417646680559, 60.22292069026402, 58.999718121119905, 54.19582046781267, 57.59165872846331, 63.31031799316406, 68.61533015114921, 51.94172409602574, 47.36972951889038, 67.59636293138776, 60.826302255902974, 56.29548617771694, 53.213859353746685, 64.46190547943115, 61.69570255279541, 61.26057161603655, 62.84172453199114, 67.02794470105852, 62.0996013368879, 66.64408452170235, 65.92641203744071, 58.91844504220145, 49.07894120897566, 49.53452416828701, 47.47494956425258, 54.27466862542288, 54.09505074364798, 53.321848256247385, 54.591179915836875, 52.95389597756522, 52.139851978846956, 51.11993285587856, 48.50399167197091, 49.005120073046, 46.171974727085654, 48.06105790819441, 45.5297075680324, 49.85868195125035, 49.530490739004954, 50.037601539066856, 50.59934949874878, 51.590329374585835, 51.33599751336234, 51.51195369447981, 51.20527410507202, 53.13281903948103, 61.30747195652553, 68.66157041277204, 66.95244557516915, 69.25135435376848, 68.65264892578125, 73.28349821908134, 71.87583487374442, 73.04383400508335, 74.06942285810197, 71.87272902897426, 69.86722878047398, 73.78276102883476, 70.95368385314941, 75.63314969199044, 67.34618609292167, 68.48807389395577, 4.250576989991324, 2.38228868160929, 2.660074404307774, 2.116318370614733, 3.3144068930830275, 0.8155157140323094, 0.19988013165337698, 1.3465417793818881, 38.4250042779105, 38.045306069510325, 40.568923064640586, 26.54879583631243, 24.375531332833425, 30.191896166120255, 45.963341167994905, 54.66724531991141, 62.96746608189174, 58.543263162885395, 61.97123336791992, 44.747920581272666, 3.0658776462078094, 0.09292966593056917, 0.04996228404343128, 0.030042389008615698, 0.08946860129279749, 0.027479653845408132, 0.056337741403175254, 0.0691467353275844, 0.06647537688591651, 0.029516955238900015, 0.049282588729900975, 0.03315824556297489, 0.05083778759996806, 0.002456457707532016, 0.1190327520349196, 0.1003572495122041, 0.21228519028850965, 0.12369192631116935, 0.1614163698894637, 0.15899760967918805, 0.20761254030678952, 0.11820503430707113, 0.21029001234897546, 0.19408287773174898, 0.35696929373911446, 0.1195115399147783, 0.45284186782581465, 0.5170335876090186, 25.64341950416565, 118.18794087001255, 84.0758363178798, 89.86012131827218, 72.3064216886248, 66.16643755776542, 39.00678389413016, 86.70683424813407, 51.327284472329275, 50.735555035727366, 1.3407145206417357, 0.22204517014324665, 3.0773797375815253, 13.641762205532618, 8.8318977866854, 6.237986300672803, 3.1218870750495364, 1.3753158982310976, 87.19620282309396, 95.78284222739083, 90.57882908412388, 85.19264112200055, 72.98594161442348, 74.83681665148053, 74.86288629259381, 72.49266120365688, 68.28686101096017, 62.79327474321638, 63.77679225376674, 62.232582909720286, 62.0426539012364, 62.53096635001046, 63.77276924678257, 63.230768067496165, 62.39383670261928, 62.57392011369978, 60.27401079450335, 60.858597482953755, 60.910083634512766, 60.65266677311489, 58.823928696768625, 60.86146708897182, 60.650915827069966, 56.80359751837594, 55.46801825932094, 59.34407779148647, 59.801637513296946, 62.422755105154856, 64.16061074393136, 63.20054340362549, 63.175397872924805, 62.91342994144985, 60.16520200456892, 61.02160917009626, 59.43384851728167, 59.36327566419329, 57.92135075160435, 52.21025112697056, 57.036094665527344, 53.38920061928885, 53.85725906917027, 51.503890310014995, 53.13049486705235, 56.541598320007324, 57.547169412885395, 63.568346296037944, 63.53079128265381, 61.93344906398228, 62.23257596152169, 57.84159932817732, 61.129090854099815, 67.41814163752964, 70.66536140441895, 55.15959814616612, 53.730343273707796, 68.44539111001151, 65.01196656908307, 58.9734400340489, 57.62919637135097, 68.07262025560651, 65.74591173444475, 65.74049908774239, 67.89594841003418, 68.79051508222307, 64.5145102909633, 68.69230229513985, 69.5285735811506, 61.29290158408028, 53.11405542918614, 52.198223795209614, 50.93164014816284, 57.52598435538155, 58.78217697143555, 57.08090707233974, 56.808381353105815, 54.35736608505249, 55.46578788757324, 53.25710841587612, 51.30527605329241, 51.56165415900094, 49.047535351344514, 49.72887223107474, 49.311309814453125, 51.94224173682076, 52.53016356059483, 52.34426103319441, 53.395457472120015, 53.95267173222133, 54.257527419498985, 54.54425525665283, 53.71098211833409, 56.5487619127546, 64.52940028054374, 72.60342243739537, 70.37776851654053, 73.7887156350272, 71.7334315436227, 76.12860488891602, 75.18788828168596, 72.13058362688336, 75.73693493434361, 74.21500151497978, 73.77642427171979, 77.57532405853271, 73.96425492422921, 79.44962842123849, 72.77511937277657, 67.10193606785366, 6.359969309398106, 3.8518754584448676, 13.751264078276497, 4.330730106149401, 6.225409626960754, 0.4175371208361217, 0.29578679533941404, 3.663510663168771, 49.0912812096732, 46.68013817923409, 60.54890932355608, 45.08191006524222, 25.453549555369786, 35.23522874287197, 50.90581716809954, 62.9026254926409, 74.74298817770821, 71.18083436148507, 76.45448235103062, 49.20529767445156, 2.885566681623459, 0.2654284600700651, 0.1696668536003147, 0.10492559509085757, 0.26252777714814457, 0.15388121136597224, 0.20385536977222987, 0.11500015056559018, 0.13381076976656914, 0.20343741934214318, 0.10013146019939866, 0.15096161088773183, 0.2487267819898469, 0.08948054350912571], [0.11821757363421576, 0.017534966580569744, 0.11604588159493037, 0.003137708986676963, 0.05487833471436586, 0.11618260640118803, 0.050200303949947865, 0.057319605323885164, 0.06441573133426053, 0.008221650213402296, 0.03178003237449697, 0.03839543328753539, 0.18095264158078603, 0.031650008101548464, 47.436053548540386, 80.02169445582798, 59.74417591094971, 56.59025655473982, 30.615847451346262, 14.657886743545532, 27.452730417251587, 57.16213846206665, 42.50044584274292, 14.261154157774788, 0.1812710373529366, 0.38811396967087475, 1.9141260087490082, 6.348630717822483, 1.9842550456523895, 0.725941600544112, 0.6702266559004784, 6.327292799949646, 93.99403544834682, 80.75321469988141, 87.44395474025181, 77.53558731079102, 83.76624543326241, 76.75283799852643, 80.50000844682965, 75.02134690965924, 72.07406003134591, 67.18470995766776, 62.26648317064558, 57.655721119471956, 57.43123524529593, 56.44030400684902, 56.29787288393293, 54.80528865541731, 54.04886954171317, 54.39365305219378, 54.79327869415283, 54.19560507365635, 54.68764870507376, 52.04216725485665, 52.74008253642491, 54.069568225315635, 48.147767952510286, 48.900386401585166, 51.32579060963222, 50.398866176605225, 53.65312099456787, 55.526185103825156, 61.5549806867327, 54.20054871695382, 54.80332926341465, 55.371719700949534, 57.31713192803519, 54.41448375156948, 52.82256460189819, 51.16879258837019, 50.657297474997385, 48.17449072429112, 49.06565277917044, 47.9751330103193, 48.336213520595, 47.86576836449759, 49.28275271824428, 47.94106946672712, 53.26555395126343, 57.72705480030605, 60.734745843069895, 60.790671893528526, 61.484234128679546, 54.62509059906006, 53.459495544433594, 59.37929821014404, 64.52049963814872, 49.00382770810808, 52.21919345855713, 65.80999497004917, 59.29095186505999, 54.41510214124407, 52.78265067509243, 60.31674221583775, 59.310469354902, 56.496150153023855, 60.15941415514265, 66.5419043132237, 61.018961906433105, 64.01151629856655, 61.107954433986116, 56.3437796320234, 44.68247549874442, 44.33174780436924, 44.241977078574045, 49.95043291364397, 50.19376230239868, 50.21990142549787, 48.944135734013145, 50.49283708844866, 48.79969310760498, 49.920302050454275, 44.56513779503958, 47.03974567140852, 44.54099975313459, 45.050650119781494, 43.55654770987374, 43.3854934828622, 48.639186246054514, 46.82749557495117, 48.345141955784385, 50.49870484215872, 46.03856584003994, 47.810266154153005, 48.32579469680786, 50.7553574017116, 61.99343286241804, 64.09428324018205, 65.71249089922223, 66.84955665043422, 69.93837833404541, 66.43938364301408, 69.54403332301548, 70.33703122820172, 68.94235406603131, 68.18625804356166, 67.76551682608468, 69.37109960828508, 67.7117030279977, 70.25983674185616, 65.70942674364362, 73.62681565965924, 29.034329754965647, 2.5970485976764133, 0.8819406011274883, 1.986362304006304, 1.6175991488354546, 0.8591792796339307, 0.2479793078133038, 0.12479481713048049, 13.268672602517263, 24.599199056625366, 33.56500686917986, 47.80638905933925, 32.10422454561506, 21.480652979442052, 16.144910676138743, 13.761936511312213, 30.74191904067993, 54.194687911442344, 48.6915339742388, 57.47002008983067, 21.626954248973302, 0.2188835497945547, 0.02267272856884769, 0.034988624309854846, 0.0629506656633956, 0.015270359348505735, 0.02183775560531233, 0.0587933019601873, 0.039915565467838726, 0.041351671264107735, 0.08946459115083728, 0.01722799224912056, 0.02780504192092589, 0.053670040265257866, 0.10845110698470048, 0.02157839577245925, 0.06545528090958085, 0.008915831401411976, 0.06834322094385113, 0.15885120896356447, 0.06924838665872812, 0.06911775509693793, 0.05882883005376373, 0.07578789003725563, 0.029566817384745394, 0.11670077645352908, 0.18164336308836937, 0.0470761489123106, 63.661723136901855, 90.11018003736223, 68.43015371050153, 66.95860862731934, 43.268409388405935, 27.58122866494315, 23.158217361995153, 42.30852964946202, 50.056493691035676, 15.488366706030709, 0.393663083336183, 1.5951018588883537, 4.5735587903431485, 9.611989412988935, 3.8342335479600087, 1.1993685109274728, 0.3281490073672363, 9.998103414263044, 100.54990400586809, 82.55827331542969, 91.22041184561593, 79.17985766274589, 86.26581123897007, 80.8920327595302, 83.26794842311314, 79.58080346243722, 77.16685335976737, 70.56450830187116, 65.46084799085344, 61.33658490862165, 60.05633068084717, 58.12310906818935, 58.12244551522391, 56.05312258856637, 58.377777917044504, 57.652274812970845, 56.370901925223215, 55.73606586456299, 56.427470684051514, 54.842795031411306, 54.916480677468435, 56.453463894980295, 51.49083464486258, 52.70755801882063, 55.06118386132376, 53.56119632720947, 55.98138243811471, 56.87936067581177, 60.961027826581685, 55.963400500161306, 57.867870467049734, 57.57825217928205, 60.3171660559518, 57.4346468108041, 55.8643330846514, 52.384143693106516, 52.07952771868025, 51.02087933676583, 52.82403761999947, 52.94381414140974, 52.52498367854527, 51.72776126861572, 51.938413279397146, 50.81909670148577, 55.866566930498394, 60.030483382088796, 65.4094660622733, 67.2142675944737, 66.73714869362968, 58.18944352013724, 56.03341054916382, 62.92169829777309, 66.0978032520839, 55.28577743257795, 58.981625011989046, 65.88614027840751, 62.64971801212856, 56.28082895278931, 56.300207478659495, 63.010426793779644, 61.837556975228445, 61.4725125176566, 63.42275374276297, 67.0610876083374, 63.89427934374128, 65.24209785461426, 62.752058029174805, 58.160080432891846, 46.0892460005624, 47.53175456183297, 47.887630871364046, 51.4700734274728, 51.6406169618879, 51.869716439928325, 51.334180559430806, 53.05678142820086, 52.87107345036098, 52.3268210547311, 47.446232659476145, 48.28076342173985, 46.45229632513863, 47.47620023999895, 46.54067046301705, 44.797836439950125, 51.78267983027867, 49.33899143763951, 50.90402453286307, 52.02221202850342, 50.38315977369036, 51.45458241871425, 52.72941010338919, 54.14432736805507, 63.47811004093715, 66.86052090781075, 68.89508547101701, 70.88081114632743, 71.16881397792271, 68.37940406799316, 71.03431074959892, 71.98374039786202, 71.00147356305803, 70.55784497942243, 69.84072140284947, 70.90947246551514, 70.99055794307164, 71.7845355442592, 70.40044743674142, 72.95658547537667, 50.145649501255576, 0.953703441790172, 2.551763496228627, 2.774282378809793, 2.3213258385658264, 2.9809050858020782, 0.9023697163377489, 0.8640565350651741, 9.689799683434622, 35.49924291883196, 38.51199919836861, 33.094325474330354, 24.243850810187205, 38.43600327627999, 34.21976341520037, 22.90211718423026, 39.291222299848286, 64.89088726043701, 59.14185741969517, 70.13577665601457, 28.14389204978943, 0.20291626373572008, 0.03742295689880848, 0.05101299551980836, 0.025921350677630732, 0.06256648592118706, 0.06075087548898799, 0.016471042331042032, 0.07292760709034544, 0.03591452944757683, 0.032634613303733725, 0.04460833740553685, 0.0066170120096233275, 0.05748489645442792, 0.1351389477827719, 0.10133056049900395, 0.1977196354418993, 0.08382261318287679, 0.10817690419831447, 0.22978531409587177, 0.09566141398889677, 0.11423331099961485, 0.1285909762872117, 0.15709445465888294, 0.24331636088235037, 0.16077485574143274, 0.23356212143387112, 0.11737914862377302, 69.6705322265625, 101.38717583247593, 78.93848419189453, 78.0738503592355, 47.19194943564278, 26.76304875101362, 39.21787364142281, 75.37258529663086, 62.63814231327602, 23.15515841756548, 0.4736600550157683, 1.7384367904492786, 6.100211773599897, 17.606530257633754, 6.774768948554993, 4.737952300480433, 1.9126946798392703, 10.187021459851946, 103.22084018162319, 86.8814285823277, 95.96305070604596, 84.08108915601457, 90.79744720458984, 84.19834000723702, 85.71899495806012, 83.39630944388253, 78.55518681662423, 74.51947852543422, 70.35737555367606, 65.23733139038086, 62.45983764103481, 61.41976874215262, 62.00684983389718, 60.62350518362862, 60.90652615683419, 61.135462352207725, 62.59647396632603, 58.458168574741904, 59.83198724474226, 57.57740102495466, 57.84817579814366, 60.67400469098772, 53.88159166063581, 55.981733322143555, 57.403654370989116, 57.082744870867046, 59.3117686680385, 60.02158273969378, 64.12534168788365, 58.79436411176409, 59.032937458583284, 59.98681395394461, 63.956674167088096, 61.6302991594587, 58.520049231392996, 55.69488041741507, 56.50263629640852, 54.1677462714059, 56.76697356360299, 57.77325337273734, 55.08868135724749, 53.615058762686594, 55.181721210479736, 52.696204662323, 60.49829169682094, 63.056382179260254, 68.38174561091832, 68.9359130859375, 69.75347287314278, 60.37321022578648, 57.8949475969587, 67.68927424294608, 68.7192474092756, 57.06664589473179, 59.51236316135952, 69.74038246699742, 66.83636202130998, 58.80644702911377, 58.40833609444754, 66.3116340637207, 64.64683873312813, 61.345596722194124, 66.0487767628261, 69.89322893960136, 67.14275673457554, 69.93369524819511, 66.71482413155692, 61.98862470899309, 49.69333914348057, 50.69376856940133, 49.36751726695469, 56.69184964043753, 54.817378520965576, 55.541328702654155, 56.13865491322109, 57.58949089050293, 54.9086709022522, 56.09148359298706, 50.24811805997576, 51.53362512588501, 48.33982310976301, 48.90764379501343, 49.866630690438406, 49.796724864414756, 54.41128410611834, 52.60433905465262, 53.56502478463309, 55.73021895544869, 51.04477071762085, 54.1961088180542, 53.96336153575352, 57.63406358446394, 67.48936067308698, 68.84824766431535, 71.22717189788818, 72.34911142076764, 73.62773977007184, 68.84232779911586, 73.41920348576137, 76.34341539655412, 73.63044261932373, 73.5399979182652, 73.66891479492188, 74.07100704738072, 74.40142168317522, 77.18289675031389, 72.79294845036098, 77.36586366380963, 51.09485680716378, 3.4062416681221555, 8.372235366276332, 9.677427547318594, 5.102315400327955, 5.286023599760873, 1.1697183762277876, 1.2325002359492438, 19.9120763029371, 41.18833759852818, 50.40903833934239, 65.44247000558036, 42.0382308278765, 33.92782095500401, 26.46491370882307, 27.54497470174517, 51.496181283678325, 76.20167909349713, 71.09735175541469, 83.9734754562378, 32.62616974966866, 0.2789300041539328, 0.1221094469406775, 0.12343363517097064, 0.12265021220913955, 0.12522918810801847, 0.13334408695144312, 0.11810794951660292, 0.10926111494856221, 0.09583096631935664, 0.12282938616616385, 0.18874704119350227, 0.08137751224317721, 0.19328702400837625], [0.0776309539963092, 0.027859623277825967, 0.0435376837849617, 0.030147860491914407, 0.10151165471013103, 0.1576559016747134, 0.007560349136058773, 0.06915704227451767, 0.09864395537546702, 0.026663593349180052, 0.046371846526329, 0.12721456800188335, 0.1832499440227236, 4.393122323921748, 79.31394399915422, 67.38954285212925, 65.14243984222412, 35.21874761581421, 33.59464093617031, 34.901916708265034, 77.83262974875313, 63.3468724659511, 34.7606007712228, 2.5490990792001997, 0.06452452763915062, 0.9315766862460545, 3.6652759398732866, 4.944614742483411, 6.539215896810804, 5.8268362028258185, 0.7329143892441476, 37.974663734436035, 96.44953577859062, 85.45371273585728, 81.9604572568621, 86.63655321938651, 82.91024126325334, 82.05038779122489, 82.02114282335553, 79.43450219290597, 71.80910437447685, 70.88254124777657, 67.50311115809849, 61.56207479749407, 55.12654903956822, 55.223806449345176, 55.37798350197928, 53.06553963252476, 55.17407819202968, 52.14623042515346, 53.08043657030378, 51.96711976187569, 53.102837562561035, 53.091122899736675, 55.089956351688926, 50.64304671968733, 47.852010931287495, 52.82919665745327, 48.93055200576782, 53.63832480566842, 54.16240310668945, 59.40579169137137, 56.41282735552107, 52.704056126730784, 54.19178009033203, 57.11606495720999, 56.10066911152431, 52.72702687127249, 50.81443098613194, 48.2583589553833, 50.28653464998518, 47.49798631668091, 51.05230951309204, 48.7155191557748, 51.18007298878261, 50.78323357445853, 50.0042918750218, 45.83842297962734, 49.009667669023784, 56.42221784591675, 60.96160452706473, 57.90389340264456, 65.17022568838937, 60.760092871529714, 54.66593905857631, 58.255625111716135, 65.54062720707485, 44.83603416170393, 59.55621324266706, 64.79368891034807, 57.30734191622053, 56.842073168073384, 55.659597464970176, 58.79933902195522, 60.937584604535786, 61.25241443089077, 63.02646323612758, 61.77994251251221, 56.16741003308977, 59.31314441135952, 58.03381429399763, 49.84067222050258, 42.738282680511475, 45.787249497004915, 43.78698124204363, 44.78263030733381, 49.86231933321272, 47.85932738440377, 47.31633261271885, 48.36906112943377, 48.72183159419468, 49.03658846446446, 45.16373552594866, 47.01735510144915, 47.05204398291451, 43.95445367268154, 42.6137501171657, 41.779174191611155, 43.8408853667123, 48.67674820763724, 45.72978094645909, 48.606265681130544, 46.100852966308594, 48.483675139290945, 46.478897503444124, 51.84219115121024, 63.81449317932129, 66.2212518964495, 66.25285230364118, 66.14352934701103, 64.01849923815045, 64.9885858808245, 64.35555635179792, 67.80327333722795, 68.26156261989048, 67.309659412929, 67.64137336186, 67.08717809404645, 68.26490470341274, 66.96222169058663, 72.79385866437639, 70.17397090366909, 68.31730106898716, 10.47824478149414, 1.7966065662247794, 1.452745537672724, 1.6228872707911899, 1.771427488752774, 1.8833824012960707, 0.07062487636825868, 3.5321616998740604, 30.855535984039307, 24.730153492518834, 49.474787030901226, 52.39877659933907, 15.394555602754865, 10.659607529640198, 18.564021553312028, 26.998747280665807, 36.83553784234183, 52.07079035895211, 48.510582038334434, 42.037879943847656, 1.9031630541597093, 0.11060649382748775, 0.09840144017445189, 0.04976426377626402, 0.04126310548079865, 0.011408175341784954, 0.01748719601891935, 0.10487900687647717, 0.007859628880396485, 0.1322865222713777, 0.033507077023386955, 0.06522629569683756, 0.031180821492203643, 0.03421531151980162, 0.06466139493776218, 0.0691522111051849, 0.05508550502625959, 0.09021328669041395, 0.054227375358875306, 0.01114888336243374, 0.08508111922336475, 0.03359896423561232, 0.13476924119251116, 0.06733301800808736, 0.25626308045216967, 0.2568386681377888, 6.982338564736502, 95.10890170506069, 77.80497591836112, 75.02562699999127, 52.42699670791626, 39.73964166641235, 39.98453787394932, 57.25314596721104, 51.350342069353374, 44.11480072566441, 2.1784667500427792, 0.20105235518089362, 3.37197054709707, 5.249980253832681, 8.050288847514562, 16.89062782696315, 2.465279919760568, 0.5798850378819874, 39.61978524071829, 97.54628808157784, 88.89100742340088, 87.51719570159912, 87.49330084664481, 86.71446337018693, 83.50508349282401, 85.0741604396275, 80.55717127663749, 75.20969867706299, 72.98941571371896, 71.72240475245884, 64.62850938524518, 59.559068952287944, 58.05138628823416, 58.84097262791225, 56.086908204214915, 57.59188454491751, 55.98604815346854, 54.52671800340925, 54.038329124450684, 56.25599261692592, 57.39994750704084, 58.45240156991141, 53.14266463688442, 51.048411573682515, 55.42499153954642, 52.307060377938406, 55.393846239362446, 57.916104861668174, 59.17195701599121, 57.56304257256644, 54.31925868988037, 55.30066742215838, 59.04832077026367, 58.302084241594585, 54.83424179894583, 52.58992501667568, 49.687089238848, 51.331050395965576, 50.74211413519723, 54.58588886260986, 53.979154791150776, 54.99232373918806, 51.95431423187256, 52.11834730420794, 48.587165083204, 52.22698933737618, 60.16816888536726, 64.08528532300676, 62.58746215275356, 64.6756876536778, 65.25661958966936, 55.76129477364676, 61.54540606907436, 65.33348751068115, 59.50048868996756, 72.35655294145856, 63.72253377096993, 60.54107870374407, 58.195804595947266, 59.09223338535854, 63.67668955666678, 67.47646481650216, 64.49805000850132, 64.20078522818429, 61.876703126089915, 62.409574372427805, 58.985467365809846, 61.151054109845845, 50.76499455315726, 48.37548473903111, 46.466164929526194, 46.18972390038626, 48.62165594100952, 51.104938643319265, 50.55747617994036, 50.43873494012015, 50.187505449567524, 51.75008583068848, 50.49246883392334, 50.18722404752459, 48.15797485624041, 47.758310999189106, 46.25829914637974, 45.36018541881016, 42.81360462733677, 47.00470590591431, 51.01650544575283, 48.97693123136248, 50.83994477135794, 50.50926610401699, 51.1187481880188, 48.67345823560442, 53.99544831684658, 65.96121556418282, 67.2035882132394, 71.29848820822579, 68.00946113041469, 66.38566711970738, 66.36646229880196, 67.07814543587821, 69.55505316598075, 71.35146127428327, 67.86471625736782, 69.51169640677315, 67.67477335248674, 70.4072983605521, 69.01685265132359, 75.8259413582938, 69.36420004708427, 78.29187788282121, 23.051925557000295, 5.683514841965266, 0.15672778790550573, 2.96339128272874, 3.6692906958716254, 3.232729515859059, 0.1379962723170008, 0.6424704481448446, 33.38525349753243, 35.48755257470267, 43.03734009606497, 33.01047461373465, 15.946666410991124, 10.204814059393746, 29.559676102229528, 40.729468141283306, 49.478810037885395, 59.99142755780901, 59.080727168491904, 53.45099442345755, 2.815666501011167, 0.10440775073532547, 0.10343933877136026, 0.024222667096182704, 0.012484587180162115, 0.03457587145801101, 0.08679040321814162, 0.014744306415585535, 0.041800501822893105, 0.04083096349079694, 0.039162683367197, 0.01407950240120824, 0.058593839806105406, 0.1414075664111546, 0.13662168250552245, 0.17972899866955622, 0.12125956825911999, 0.13053576621626103, 0.2662252773131643, 0.12109982754502978, 0.14382760226726532, 0.14231377706996032, 0.19114887874041284, 0.12608484790793487, 0.28734125995210236, 0.3736663306398051, 6.731834292411804, 110.23780509403774, 85.35671588352749, 85.97873946598598, 53.533653667994905, 48.80523429598127, 46.07858051572527, 104.44532121930803, 80.13424137660435, 56.86528015136719, 3.9563520465578352, 0.25325714317815645, 3.39092675277165, 9.6737345797675, 12.096415962491717, 14.316808359963552, 11.015334452901568, 1.1113250638757433, 49.80778292247227, 100.66869040897915, 97.1089198248727, 86.91650308881486, 94.82985510144914, 89.08673817770821, 88.94810771942139, 87.59878839765275, 85.25860037122453, 77.42685495104108, 76.72660160064697, 73.96523462023053, 69.64123862130302, 61.98313563210623, 62.54004764556885, 61.119669096810476, 59.719391686575754, 59.81576320103237, 59.24634443010603, 57.24608659744263, 58.919556753976, 58.13137742451259, 60.03404780796596, 61.22116838182722, 56.55035652433123, 55.28615958350045, 58.27301645278931, 55.53758362361363, 60.912689208984375, 59.68332358769008, 63.80976840427944, 59.83505140032087, 57.50281558718, 57.29010343551636, 62.760882241385325, 62.152539661952424, 58.97093173435756, 56.0678562436785, 53.98768023082188, 54.922053132738384, 52.84689024516514, 57.40179920196533, 56.76534768513271, 57.928472655160085, 56.49421855381557, 55.463825021471294, 51.62731810978481, 54.31597914014544, 62.62202944074358, 65.3655673435756, 65.99708216530937, 70.44562462397984, 69.97801085880825, 58.37722206115723, 66.49275970458984, 69.32429654257638, 53.392028536115376, 60.131524085998535, 67.70818029131208, 64.60120296478271, 60.74552944728306, 60.814657075064524, 66.43818855285645, 68.0256017957415, 68.10415812901088, 68.39665644509452, 65.6433493750436, 65.34990610395158, 64.76848084586007, 65.51118768964494, 55.00222144808088, 49.50143684659685, 51.1923817225865, 48.642993858882356, 51.89134965624128, 55.818315165383474, 53.926473549434114, 52.59495898655483, 54.2670499256679, 55.044601985386436, 54.443051270076204, 51.508434431893484, 52.017285755702424, 52.112093925476074, 50.105815478733604, 47.042392935071675, 47.30191510064261, 49.5272980417524, 54.81148297446114, 52.14983306612287, 53.69054399217878, 52.55216155733381, 52.8211784362793, 51.54982485089983, 56.201897416796, 70.0453736441476, 71.35929884229387, 73.2834495816912, 70.60285540989467, 70.28309931073869, 69.14033603668213, 69.83865083966936, 72.1895807811192, 73.30017389569963, 69.84619658333915, 73.17270919254848, 70.05773448944092, 73.89984512329102, 71.50309876033238, 81.81167548043388, 73.7396821975708, 83.32349232264927, 22.81249237060547, 7.292686803000314, 11.332769853728157, 5.998380712100437, 7.800427283559527, 7.607962182589939, 0.16599677982074873, 4.3305937477520535, 49.080970082964214, 40.56193317685808, 68.66942882537842, 66.16647229875836, 21.574066298348562, 15.384718690599714, 31.244690690721782, 45.01362664358956, 58.81171376364571, 69.20380088261196, 74.31278351375035, 61.679832867213655, 3.225986723388944, 0.293736099664654, 0.182243568024465, 0.12375011747436863, 0.1791892647743225, 0.106358878181449, 0.25164833664894104, 0.13068783948464052, 0.10809863518391337, 0.1689530076192958, 0.11082693628434624, 0.13136819297713892, 0.1752130767064435], [0.08728494668113333, 0.03035768387573106, 0.0999954342842102, 0.03210727285061564, 0.019809025805443525, 0.10124556720256805, 0.04780053932751928, 0.0845792204407709, 0.1361174631331648, 0.10883542921926294, 0.19856913414384636, 0.24196224925773485, 0.17926414789898054, 33.28542525427682, 84.30016585758754, 58.5431033543178, 57.97893047332764, 22.19885352679661, 35.502873352595735, 46.71877711159842, 44.22581556865147, 48.68721219471523, 16.002104350498744, 0.016738882155290673, 0.659564808011055, 1.925769669669015, 4.141707403319223, 3.4883854431765418, 14.155710033008031, 0.36624028054731234, 6.589788794517517, 56.635343415396555, 68.56319781712124, 93.35760825020927, 84.5336253302438, 85.77501828329903, 85.58030891418457, 80.23676204681396, 77.52609607151577, 76.00346088409424, 73.02102306910923, 69.92472512381417, 68.05991200038365, 62.332491057259695, 61.17616489955357, 56.14620065689087, 54.36232015064785, 51.51265198843819, 52.58872297831944, 53.254669598170686, 52.323433807918, 50.09301689692906, 55.07717514038086, 53.695887156895225, 54.139783246176584, 47.82912356512887, 46.9416892187936, 49.151219844818115, 50.016353947775706, 52.216796330043245, 53.28971283776419, 60.515564918518066, 53.99372863769531, 52.62792124067034, 56.19281612123762, 53.77824762889317, 52.59801966803414, 52.32103667940412, 48.270427976335796, 50.46560362407139, 50.56385810034615, 48.990966592516216, 50.88677562986101, 51.56461409160069, 53.81231812068394, 50.46315090996878, 53.05948427745274, 47.51796586172921, 49.141443729400635, 52.94810465403965, 61.57114914485386, 57.982067584991455, 65.7417219706944, 56.42329829079764, 61.7057774407523, 54.561629227229524, 68.63364560263497, 42.164997237069265, 57.634900842394146, 67.17559392111642, 56.77721520832607, 59.11229978288923, 54.36868470055716, 60.01442609514509, 56.14856651851109, 58.351590156555176, 58.44488361903599, 60.40866688319615, 52.185147285461426, 50.86565310614449, 46.89050531387329, 44.3027286529541, 44.20706932885306, 44.905901772635325, 43.269284861428396, 44.79119048799787, 49.67515570776803, 48.94321509769985, 45.09923192432949, 45.3905942099435, 48.13001183101109, 49.39663369315011, 48.00135203770229, 45.761020047324045, 47.8613840511867, 45.650526319231304, 43.87649141039167, 42.98785155160086, 41.214171000889365, 47.68936749867031, 46.655367851257324, 47.365505014147075, 46.992699418749126, 47.29912192480904, 47.33939715794155, 51.92729268755232, 63.822275161743164, 61.72567013331822, 61.49411446707589, 64.52660710471017, 65.61853040967668, 66.42535523005894, 68.38992364065987, 65.5740133013044, 65.99909714290074, 67.20809759412492, 67.63621779850551, 67.01554216657365, 67.83172621045793, 67.7923229762486, 69.18610382080078, 64.81520053318569, 70.95306546347481, 46.571013246263774, 1.1010850476367133, 0.508740804025105, 2.2464233892304555, 1.5314039226089204, 1.6457275194781167, 0.4139359455023493, 0.02776132051699928, 14.221387880189077, 27.70461651257106, 31.56428698131016, 57.93031392778669, 57.25312859671456, 66.30888952527727, 13.927380067961556, 18.427115985325404, 22.02691514151437, 44.26387780053275, 49.44270372390747, 58.929249491010395, 10.627709218433925, 0.2953888752630779, 0.18826747978372232, 0.12958858561302933, 0.19259356121931756, 0.06962036634130137, 0.02276488719508052, 0.050249002408236265, 0.06143205679420914, 0.1578360934342657, 0.23318371602467128, 0.06512341621731009, 0.020180552565891827, 0.020108563393088322, 0.09794640102024589, 0.05740486324897834, 0.04916191466950944, 0.07791466984365668, 0.05918787685888154, 0.06563359312713146, 0.22034997253545693, 0.058603861768330844, 0.04324152021269713, 0.11922966289733138, 0.1885194062654461, 0.29290663131645744, 41.77458143234253, 95.28926999228341, 66.65770299094063, 66.34096935817173, 36.41950055531093, 42.316262994493755, 39.63458490371704, 44.281644344329834, 53.36330815723964, 18.60651499884469, 0.12017924551452909, 0.45573375693389345, 3.6235233460153853, 4.749861947127751, 3.530134128672736, 5.328698566981724, 0.457486982856478, 11.35090378352574, 71.53767994471959, 73.85283361162458, 93.6833884375436, 87.5642419542585, 88.50525733402797, 88.10520090375627, 85.84252003261021, 79.28943770272392, 77.75701250348772, 75.57583400181362, 72.83159433092389, 69.55023111615861, 67.22151456560407, 61.345478602818076, 58.640051569257466, 55.69652714048113, 54.81252173015049, 55.72546638761248, 53.78301756722586, 53.906358514513286, 53.58483062471662, 57.056511947086875, 56.08989940370832, 57.06271321432931, 52.86464636666434, 49.33116429192679, 51.02461746760777, 51.26387173788888, 54.79364694867815, 56.19016538347517, 61.140513692583355, 56.98301042829241, 54.506526538303916, 58.91968182155064, 56.501267501286094, 53.36436775752476, 54.27584287098476, 51.197061334337505, 54.825188296181814, 53.678978715624126, 53.5888432094029, 53.5762426512582, 53.44602646146502, 55.832628454480854, 55.5741137777056, 55.808997631073, 51.284587791987825, 50.03005232129778, 58.330252238682334, 61.98922225407192, 60.31756905147007, 65.90713773454938, 61.747133118765696, 63.14554841177804, 60.32432964869908, 65.52523694719586, 61.983351026262554, 74.13102558680943, 68.22652980259487, 61.611427852085654, 61.62505326952253, 60.389559337071006, 64.66925362178257, 62.72549506596157, 63.17245878492083, 60.31515802655901, 60.07224900381905, 54.55261046545846, 55.210479804447715, 49.978562695639475, 46.7973438671657, 46.81268201555525, 47.004490511757986, 44.7827901159014, 48.79258510044643, 51.99916137967791, 51.82663760866438, 48.36529173169817, 47.94751392092024, 51.5679144859314, 52.293966497693745, 51.29822015762329, 47.61772462299892, 50.55683694566999, 47.77676888874599, 47.63527577263968, 45.2962064061846, 45.65453542981829, 50.22444554737636, 48.84804562159947, 49.48947204862322, 48.315414088112966, 50.60345588411604, 49.80265515191214, 54.79756920678275, 62.86809294564383, 63.878812653677805, 65.8770033972604, 66.48174680982316, 70.27472673143659, 69.9249335697719, 68.68805694580078, 68.69805540357316, 69.20917878832135, 69.97199371882847, 68.63652910505022, 69.52161843436105, 69.08296476091657, 70.02218750544957, 67.75908279418945, 70.63485186440604, 69.43207005092076, 64.61388342721122, 2.704463405268533, 3.320521524974278, 2.0832822918891907, 2.511723199060985, 3.595222464629582, 0.9889519789389202, 0.048032299748488834, 11.510168654578072, 38.342949526650564, 38.15074150902884, 43.51683875492641, 29.52089125769479, 38.167090620313374, 16.61316541263035, 30.000542776925222, 32.130287238529746, 53.67886059624808, 56.704339027404785, 71.49299607958112, 14.64618250301906, 0.2775916616831507, 0.1652914969516652, 0.09368476684072188, 0.18222543756876672, 0.05540184144462858, 0.050666857843420336, 0.04439918577138867, 0.044446879997849464, 0.05341996618413499, 0.21813272365501948, 0.03720214803303991, 0.012093847700660782, 0.14069407326834543, 0.12547751835414342, 0.21519856181527885, 0.11602616336728845, 0.1421092123325382, 0.1790260635316372, 0.15579805922295364, 0.31666249515754835, 0.20665170757898263, 0.2018707769789866, 0.2545366430921214, 0.3437799300466265, 0.3066496524427618, 47.02823250634329, 106.56438282557896, 74.47669846670968, 78.48890795026506, 34.81885099411011, 51.53654336929321, 56.58188050133841, 60.05185604095459, 68.9161593573434, 26.468198469706945, 0.2126096657344273, 1.4041322490998676, 8.200754693576268, 9.301960791860308, 13.136597769601003, 25.188833611352102, 0.6595157363585064, 10.760608281408038, 77.27777440207345, 78.70446191515241, 94.40484769003731, 92.52940382276262, 92.28228419167655, 93.11242021833147, 88.46204648699079, 82.33509022848946, 82.77581446511405, 77.98547622135708, 76.88601412091936, 74.65350927625383, 70.61939907073975, 64.8736070905413, 60.77826935904366, 60.869401931762695, 59.625785555158345, 59.972007342747276, 57.76894548961094, 57.98690005711147, 56.30866343634469, 61.817782402038574, 57.66558756147112, 60.777407782418386, 57.05315944126674, 54.27163226263863, 56.393188272203716, 55.68893275942121, 59.315458161490305, 57.87575319835118, 63.702557700020925, 59.06447533198765, 57.61983714784895, 62.787257603236604, 60.51842062813895, 57.84381927762713, 59.06642082759312, 53.95358542033604, 56.574647426605225, 55.677836486271445, 57.05353464399065, 57.13138573510306, 54.78912019729614, 60.70286750793457, 57.96904666083199, 58.550885336739675, 53.56883587156023, 53.09608391353062, 59.27643707820347, 66.52672249930245, 61.234779902866904, 69.81500611986432, 64.82568536485944, 66.7996129989624, 63.711597306387766, 71.7466470173427, 49.193958214351106, 55.33804873057774, 71.07280376979283, 65.80560370853969, 64.41908373151506, 62.74217769077846, 65.59660884312221, 64.63282421657017, 65.72030067443848, 63.9562155859811, 66.92085211617606, 59.09995978219168, 58.91019058227539, 54.07347658702305, 49.99718386786324, 49.04866443361555, 49.99477284295218, 48.03801073346819, 51.51529925210135, 57.087195192064556, 54.15801184517996, 50.74287496294294, 49.819466318402974, 54.182521615709575, 55.84020546504429, 54.28769997188023, 50.92493513652256, 56.086136954171316, 51.91340323856899, 50.67391756602696, 47.92920541763306, 49.33595854895455, 53.203930377960205, 50.98817069189889, 52.73433985028948, 50.76145792007446, 52.530768053872244, 53.72855063847133, 58.539643151419504, 67.77493163517543, 67.04443972451347, 68.30216789245605, 69.62138761792863, 73.23030975886753, 73.64121232713971, 73.17729500361851, 72.30819347926548, 73.97674778529576, 73.92988218579973, 72.42756353105817, 71.51766913277763, 72.93940952845982, 75.61140877859933, 72.92876488821847, 74.19342041015625, 75.12583392007011, 68.19404697418213, 4.827650938715253, 5.550364775317056, 10.652060048920767, 4.674491797174726, 5.696596562862396, 1.5942346368517195, 0.11296037251928023, 19.320894036974224, 47.128331729343955, 49.46644571849278, 79.52899769374302, 80.46335669926235, 87.2009275981358, 23.65083074569702, 30.867521626608713, 38.40353781836373, 65.02813502720424, 66.46628706795829, 82.20341491699219, 16.89033079147339, 0.48125552173171726, 0.23913300250257763, 0.18524795823863574, 0.28615062098417965, 0.15047674333410604, 0.12736387284738676, 0.11558567200388227, 0.11478048163865294, 0.25741412011640413, 0.34353720449975556, 0.19015800048198017, 0.10989821861897196], [0.08499574594731842, 0.058916150725313594, 0.07462932541966438, 0.03648583557722824, 0.030399746261537075, 0.01163590102389987, 0.08615457519356694, 0.06066037927355085, 0.12399217805692128, 0.10781113311116185, 0.03579466623653259, 0.18776468533490384, 0.07337651228798286, 59.56301552908761, 75.17365142277309, 60.48365184238979, 42.27022075653076, 26.423394748142787, 77.00589139120919, 87.02451283591134, 40.99916941779, 43.90058428900582, 7.025935905320304, 0.05551309743896127, 0.23396750539541245, 3.0356577592236653, 2.597868485110147, 5.629206418991089, 3.131008974143437, 0.498668087380273, 60.89717388153076, 69.76442323412213, 72.908219064985, 82.1373792375837, 79.3658400944301, 83.83278833116803, 81.08906282697404, 79.27670860290527, 78.42337948935372, 72.36057594844273, 68.66009739467076, 68.46783379146031, 68.74258640834263, 60.29920496259417, 58.90534768785749, 56.68886538914272, 55.63015794754028, 50.2868195261274, 50.90864508492606, 50.34467717579433, 52.368211473737446, 51.390707629067556, 52.34761701311384, 53.621419838496614, 51.85607017789568, 45.18371507099697, 47.87908111299787, 49.35433653422764, 50.48224455969674, 50.14001798629761, 56.03573819569179, 55.09705741064889, 54.64565379279, 53.67886059624808, 55.068132059914724, 51.14507143838065, 49.07026638303484, 54.46828017915998, 54.09967129571097, 54.455262729099815, 52.547791140420095, 51.14339344842093, 52.78194890703474, 54.466960021427695, 56.15287440163748, 52.524354866572786, 54.22506890978132, 49.923275879451204, 50.1855252129691, 49.02330003465925, 58.49097796848842, 61.96930176871163, 67.23776640210832, 59.64465686253139, 64.02258477892194, 55.538122109004426, 62.34881237574986, 29.829224518367223, 39.6968720299857, 56.14972686767578, 56.52681255340576, 61.095426831926616, 57.5857458114624, 56.224461691720144, 47.25062002454485, 56.391857692173545, 56.98441049030849, 55.43775885445731, 44.2545394216265, 44.09043339320591, 42.75690385273525, 44.41948618207659, 43.43585055215018, 44.12097767421177, 43.62086371013096, 44.278788634708945, 46.65993281773159, 49.882441316332134, 44.153651578085764, 45.13123532703945, 48.685707909720286, 51.95279605048043, 47.437356335776194, 45.91065992627825, 46.57709986822945, 45.22811753409249, 43.765865666525706, 44.80129664284842, 39.61641189030239, 44.66799545288086, 45.01001705442156, 46.8382305417742, 45.45841210229056, 48.423434257507324, 46.08735261644636, 50.868349007197786, 56.38133117130825, 59.764659200395855, 64.46405247279576, 62.88186427525112, 60.96405724116734, 59.5961514881679, 59.692613329206196, 61.544732093811035, 60.740457262311665, 62.50912816183907, 63.2365072795323, 63.27759892599923, 60.89293548039028, 61.8309006009783, 62.273049218314036, 66.78561237880162, 62.23122106279646, 72.45164598737443, 16.47847284589495, 2.3266559754099165, 1.604537078312465, 1.5530448470796858, 0.9235864749976567, 0.10362703512821879, 0.04162538889795542, 2.822427749633789, 44.85301208496094, 31.831188133784703, 37.20958716528756, 74.54688222067696, 107.59988675798688, 65.32755374908447, 21.537553514753068, 18.296095541545323, 35.618442739759175, 49.19847106933594, 61.317491258893696, 29.199710777827672, 0.43596914463809555, 0.19937220747981751, 0.07954346601452146, 0.11727975681424141, 0.019056974910199642, 0.023307048549343432, 0.12582696388874734, 0.07172453057553087, 0.05370936815493873, 0.2265381711934294, 0.03516713669523597, 0.02873799025214144, 0.05404931080660649, 0.0657123439013958, 0.09195290798587458, 0.05081972160509654, 0.08573285889412675, 0.10201337028826986, 0.11260737824652876, 0.05299973587638565, 0.03409636093835745, 0.1024373664653727, 0.02263774160694863, 0.1243385159011398, 0.30270953529647415, 72.41288893563407, 83.80271652766636, 69.99811894553048, 51.495743547167095, 29.75055353982108, 80.42591285705566, 68.1484181540353, 35.46505430766514, 56.928835323878694, 6.978427163192204, 0.13509018825633184, 2.9193768330982754, 3.520648751940046, 4.1750921947615485, 0.3849056932543005, 0.05517272052488156, 0.823136530816555, 70.85336576189313, 81.81698390415737, 80.42856012071881, 82.01821763174874, 80.32202339172363, 87.09664903368268, 82.35456602913993, 81.07763998849052, 79.60762350899833, 74.29920673370361, 71.1394578388759, 70.52632795061383, 70.1662653514317, 62.000742367335725, 62.40121568952288, 60.19092423575265, 58.76638371603829, 51.68238605771746, 54.29330369404384, 53.468073095594136, 53.832422733306885, 54.46974624906267, 54.35588959285191, 54.859481130327495, 54.61244140352522, 47.89532947540283, 51.44850274494716, 52.27580738067627, 55.34612601143973, 53.78021396909441, 59.60134179251534, 58.98571055276053, 57.88228450502668, 54.34851408004761, 57.6302490234375, 53.00289814812796, 51.82915980475289, 54.362188134874614, 57.52510888235909, 58.647534779139924, 56.190401622227256, 56.43643733433315, 57.84971135003226, 55.88626159940447, 60.022437368120464, 55.060749598911826, 57.77653292247227, 53.08782945360456, 53.47756780896868, 51.66738142286028, 59.11537783486502, 61.89540767669678, 69.115232195173, 63.89209760938372, 67.38939693995884, 60.04774965558733, 66.97662530626569, 43.066539900643484, 50.94889252526419, 57.57303408214024, 60.27877031053816, 65.40251786368233, 60.957512038094656, 59.5656349999564, 49.70823608125959, 59.5897660936628, 59.974863052368164, 56.49015038354056, 45.4679901940482, 46.99522508893694, 45.633402483803884, 47.59659515108381, 45.61296088354928, 49.01148114885603, 46.05276100976126, 47.88636629922049, 51.83602115086147, 53.09166138512747, 47.76858391080584, 46.27904299327305, 51.60404511860439, 53.89831597464425, 49.3326928956168, 48.699357645852224, 49.549441950661794, 48.10367121015276, 46.659929343632285, 47.26976925986153, 42.56916005270821, 46.494805404118125, 47.645166533333914, 48.95229639325823, 47.50435086659023, 51.53809629167829, 49.276648725782124, 54.642315183367046, 60.38599491119385, 61.80633177076067, 64.94468021392822, 65.94244153159005, 64.7025146484375, 62.576247760227744, 61.68737861088344, 62.422317368643625, 63.24551214490618, 64.79853180476597, 63.618144035339355, 64.86515808105469, 61.05577346256801, 63.73392881665911, 62.680679185049875, 69.66183308192662, 64.70553016662598, 74.56281444004604, 32.49300752367292, 3.4843652588980536, 0.8026269684944833, 2.391712393079485, 1.299550895180021, 0.9888642579317093, 0.02708940630379532, 1.516671787415232, 47.659375599452424, 42.59947156906128, 44.17232486179897, 75.3101418358939, 106.25679997035435, 49.92382826123919, 31.11199746813093, 28.006319454738072, 42.66529185431344, 56.87281199863979, 68.08165291377476, 38.70095893314907, 0.4422614169972283, 0.2847725435027054, 0.13813245429524354, 0.21777219085821084, 0.03894308229376163, 0.04656317983088749, 0.10048110929450818, 0.04574725504166313, 0.0829075544274279, 0.21123650084648812, 0.02702474870186831, 0.07110914002571787, 0.2489489343549524, 0.23466973485691206, 0.20759123430720397, 0.12576603144407272, 0.1900478471070528, 0.21355772843318327, 0.29788694264633314, 0.17090659136218683, 0.19268331783158438, 0.3457765871925013, 0.10438713005610875, 0.22700087779334613, 0.35281152970024515, 85.65197263445172, 93.26508603777204, 78.9496499470302, 59.45683315822056, 40.17284795216152, 86.50532954079765, 95.96927629198346, 53.8436336517334, 68.0701675415039, 11.151434029851641, 0.22901286983064242, 2.0134203263691495, 9.393532838140215, 7.847394500459943, 16.711072478975566, 5.822729817458561, 0.5263902055365699, 72.88390731811523, 79.73463657924107, 82.54268155779157, 83.86809907640729, 82.15837669372559, 89.20605959211076, 86.40476131439209, 82.86525167737688, 86.98447731563023, 77.91364574432373, 76.03745147160122, 74.65749059404645, 76.34873076847622, 65.35042027064732, 66.68558611188615, 63.44318839481899, 62.40352249145508, 54.29818480355399, 56.76239122663225, 57.41890219279698, 58.17174645832607, 58.05618749346052, 58.72248499734061, 58.8785971232823, 58.46861171722412, 50.580780438014436, 55.600916453770225, 55.4683552469526, 58.287027495247976, 55.78898681913103, 62.08176531110491, 61.19484165736607, 61.63073689596993, 57.4385586466108, 60.866150174822124, 58.451901299612864, 55.61586202893938, 59.34814248766218, 60.475341796875, 61.75154522487095, 59.12747464861189, 58.292676380702424, 62.23941993713379, 59.10497638157436, 64.36130251203264, 59.104886054992676, 61.99624688284737, 56.77974435261318, 56.04615354537964, 53.88676112038748, 61.79843861716134, 64.82958330426897, 72.47314371381486, 64.27136502947126, 69.69126565115792, 60.699150221688406, 73.96032224382672, 33.70165361676897, 41.859867095947266, 60.9586306980678, 64.5595485142299, 67.6990225655692, 63.21641308920724, 58.312485694885254, 48.55930975505284, 61.624087469918386, 63.01681913648333, 63.49016516549246, 49.12644256864275, 50.07373911993844, 48.71269818714687, 51.582762786320274, 47.25598750795637, 52.81059285572597, 49.9094489642552, 50.76191997528076, 55.002926690237864, 58.16811602456229, 50.03539548601423, 49.56982101712908, 53.69548416137695, 60.05452414921352, 50.22183302470616, 51.43605504717146, 53.17525168827602, 51.97914361953735, 50.06358085359846, 52.14119298117501, 45.17763887132917, 50.18370825903756, 49.01087318147932, 50.48360640662057, 47.66348545891898, 56.39591196605137, 52.90538018090384, 57.59506681987217, 64.68382399422782, 66.56485421316964, 68.68913391658238, 68.7713519505092, 67.13315432412284, 65.51714924403599, 64.99955013820103, 67.36168752397809, 66.0181907926287, 71.30750002179826, 67.65863963535854, 71.24147823878697, 66.38445118495396, 69.28065490722656, 67.16783973148891, 76.04537241799491, 68.4321756362915, 82.01199899400983, 31.231916427612305, 5.856695652008057, 7.106650522777012, 7.9705895355769565, 3.6119413503578732, 1.7847014793327876, 0.15624772437981196, 4.657828714166369, 58.831036703927175, 50.66318259920393, 56.08589724131993, 88.31276444026402, 121.69892120361328, 80.38817024230957, 32.65094355174473, 28.9309891973223, 53.12548174176897, 66.82402202061245, 79.44370855603898, 46.20038938522339, 0.4924900531768799, 0.26905338412949015, 0.19230797940066882, 0.26842945760914255, 0.06577682508421795, 0.16740292151059422, 0.2223590604428734, 0.15732966203774723, 0.15818119634475025, 0.4536517672240734, 0.10847140196710825, 0.15644259963716778], [0.04725780291482806, 0.11876268152679716, 0.10464272741228342, 0.1863879920648677, 0.028669220728001425, 0.05207405126254473, 0.11982442598257746, 0.09672929918659584, 0.10053284758968012, 0.09707435459962913, 0.12168116920760699, 0.27762746119073456, 4.520957018647875, 84.24591432298932, 67.79129464285714, 66.91440418788365, 39.20233399527413, 41.8304032598223, 43.9136642728533, 57.994612557547434, 54.87980808530535, 27.807060752596172, 2.185101194041116, 0.047748923168650696, 0.5784232563206128, 1.327872621161597, 3.3679447174072266, 1.1338480838707514, 0.4749169190015112, 39.964391572134836, 104.72295733860561, 91.4106674194336, 91.68712929316929, 80.21671649387905, 84.48291042872837, 77.71498979840959, 84.46931975228446, 76.95940794263566, 75.99198940822056, 67.17239080156598, 71.89199638366699, 66.27154295785087, 67.27374417441231, 63.169241768973215, 61.04590702056885, 55.16550758906773, 55.73039266041347, 52.227593830653596, 53.600147928510395, 51.86311565126692, 53.8533923966544, 52.71317911148071, 54.433500971112935, 52.65133319582258, 49.68362208775112, 44.324632849012104, 47.76097910744803, 48.74779006413051, 53.52086550848824, 51.220928396497456, 55.705757822309224, 52.84395463126046, 54.027337074279785, 52.304392269679475, 54.49212292262486, 47.99207271848406, 52.45394877025059, 54.83862263815743, 59.19957610539028, 53.79322794505528, 56.35644619805472, 53.24757548740932, 56.57187509536743, 54.72272321156093, 59.10522651672363, 53.501445293426514, 56.28206920623779, 50.53328602654593, 50.08437333788191, 47.6643921988351, 53.39695133481707, 57.989536898476736, 66.23762880052838, 61.81432219914028, 64.08240182059151, 56.34256717136928, 44.6484432220459, 15.259079626628331, 19.581300360815867, 43.75151068823678, 52.45498752593994, 59.58465916769845, 57.77977773121425, 54.68449074881417, 56.221991607121055, 54.62822423662458, 57.18649884632656, 50.16650799342564, 42.65454299109322, 43.797063078199116, 43.230541706085205, 43.77540554319109, 44.38405384336199, 41.74059084483555, 41.86055496760777, 44.02582556860787, 45.036837100982666, 46.66843393870762, 45.718399797167095, 42.414465359279085, 47.63407373428345, 50.06197929382324, 50.48610428401402, 47.39534752709525, 44.73897477558681, 43.80601930618286, 44.64253725324358, 43.9012895311628, 41.31028890609741, 39.75070667266846, 46.060730593545095, 46.15719243458339, 47.634087630680625, 44.77126652853829, 47.327057157244, 48.28416803904942, 54.43772200175694, 55.54770367486136, 57.73556981767927, 56.54700401851109, 57.75220380510603, 53.320715699877056, 54.899492331913535, 54.49941158294678, 54.67682341166905, 54.84134285790579, 56.238903522491455, 54.14201361792428, 55.69625268663679, 55.75453765051705, 60.38815580095564, 60.52636936732701, 68.37616620744977, 62.659480231148855, 62.157667432512554, 2.498818657227925, 2.300782186644418, 4.446031987667084, 1.7242979662758964, 0.6029385636959756, 0.24463741428085736, 0.05312286962621978, 25.193813732692174, 68.40659236907959, 28.72287154197693, 92.11097635541643, 90.4603692463466, 100.25886481148856, 22.022829600742885, 16.63347499711173, 39.278708594185964, 57.96238681248256, 59.28306565965925, 58.02432305472237, 1.7718421007905687, 0.1331990704472576, 0.05927627640111106, 0.08101541881582566, 0.129394565309797, 0.06351186840661935, 0.06702774510319744, 0.007689843303523958, 0.11574492417275906, 0.07551227589803082, 0.06562872803104774, 0.13097975882036345, 0.024758618158687438, 0.07632906242672886, 0.03252536238038114, 0.040713142670158825, 0.018922820055325116, 0.0477083060624344, 0.0885274392951812, 0.018818532615633946, 0.06242993753403425, 0.06882096387978111, 0.2327261120080948, 0.3095626032778195, 6.705325177737644, 94.8096011025565, 75.96036120823452, 74.89713396344865, 52.742642947605674, 52.33018050874983, 53.88591691425869, 58.1867858341762, 57.865918023245676, 37.333376271384104, 1.0078778948102678, 0.05414895028141992, 2.5760348566940854, 2.451590448617935, 1.5423674200262343, 0.5987758870635713, 0.9454258573906762, 56.56263746534075, 105.00187192644391, 89.62466771262032, 92.1684101649693, 83.31597437177385, 86.56856509617397, 81.23428017752511, 86.36338479178292, 78.70651163373674, 78.03311307089669, 70.24940749577114, 73.26127787998745, 67.34574835641044, 69.88245228358677, 65.92751680101667, 64.02183437347412, 58.81529903411865, 57.29134021486555, 54.7334303855896, 56.68005507332938, 55.32737282344273, 54.931256021772114, 56.34238304410662, 54.78796679633004, 56.10424048560006, 53.27471515110561, 46.463712215423584, 51.69747059685843, 52.83850029536656, 56.347020966666086, 54.21537964684622, 56.428089073726106, 55.37905352456229, 55.20306955065046, 55.610716887882774, 56.25985581534249, 51.26796075275966, 56.26998281478882, 58.20051547459194, 61.49118232727051, 57.349621704646516, 58.58420194898333, 56.19497701099941, 60.87949071611677, 56.06168624332973, 62.092875480651855, 58.10202475956508, 60.675964082990376, 54.49972077778408, 55.46483598436628, 49.43060343606131, 56.27220623833792, 58.32458945683071, 69.54410280500139, 61.87953799111502, 67.85644790104458, 58.30327238355364, 50.242601190294536, 22.604583161217825, 24.860967227390834, 48.80627999986921, 54.09720121111189, 63.217983382088796, 59.24007020677839, 55.897705282483784, 57.6549985068185, 57.265663146972656, 59.607185227530344, 52.55473933901106, 45.67236450740269, 46.78398942947388, 45.6745844568525, 45.68568420410156, 46.57221181052071, 45.38677270071847, 45.57110840933663, 47.42810828345162, 48.38468415396554, 50.168887751443044, 48.21468257904053, 45.1746198790414, 49.90471724101475, 51.942648206438335, 53.01671116692679, 51.028157574789866, 46.547663824898855, 46.27948072978428, 47.57691090447562, 47.39671632221767, 43.71333033697945, 41.836764335632324, 49.042178290230886, 49.18915353502546, 50.52334662846157, 46.75263568333217, 48.98288236345564, 50.11718620572771, 57.8034849848066, 57.646382740565706, 59.871696199689595, 59.87949207850865, 60.28458595275879, 54.12320137023926, 57.58826800755092, 55.50211654390608, 58.585348401750835, 56.24100882666451, 58.95585414341518, 55.58830547332764, 58.49127674102783, 57.423533167157856, 63.4564733505249, 62.840821266174316, 69.60794980185372, 63.52589280264718, 72.95505687168666, 10.390941534723554, 3.268478866134371, 1.09072702058724, 1.2502084800175257, 1.6713911252362388, 0.5241300868136543, 0.06765671992408377, 22.57989273752485, 75.9384604862758, 34.684879302978516, 89.24703311920166, 93.67104843684605, 92.12590108598981, 25.49286593709673, 22.592753853116715, 47.28956120354788, 63.81921100616455, 65.79838453020368, 66.70800100054059, 2.5913356585162024, 0.15093668151114667, 0.10596826592726366, 0.06020996094282184, 0.12074301312012331, 0.0475648773301925, 0.07999961118080787, 0.05092886057017105, 0.08197910817606108, 0.0673994669424636, 0.06992178516728537, 0.10879219296787467, 0.16343585295336588, 0.20868846614445957, 0.11002528787191425, 0.2958106797720705, 0.22568240282791002, 0.12488454660134655, 0.3076284799192633, 0.13351297431758472, 0.19514805557472364, 0.16613278537988663, 0.44916162959166933, 0.3439899502055985, 7.351621423448835, 109.06068992614746, 81.71253858293805, 84.43765681130546, 54.05655772345406, 58.7996586390904, 52.57019213267735, 71.49883951459611, 74.56396089281354, 46.58112982341221, 2.8242199506078447, 0.10039541710700307, 2.815714921270098, 7.909609539168222, 12.027572342327662, 6.209154316357203, 0.9084016755223274, 57.15597193581717, 111.01053510393415, 95.23640809740338, 94.30382783072335, 85.55827617645264, 88.9490109852382, 82.93804100581578, 90.87535735539028, 82.31199441637311, 82.17785944257463, 72.52494253431047, 76.93323407854352, 73.12285586765834, 75.019533429827, 69.22832802363804, 68.07847063882011, 61.64714854104178, 62.6715909412929, 58.89564105442592, 60.61813422611782, 58.060839312417166, 59.18482507978167, 58.341452734810964, 59.45936925070626, 58.68002455575125, 55.88533401489258, 50.18802309036255, 54.347447531563894, 56.30956670216152, 62.37632724217006, 58.56034878322056, 59.67518029894148, 59.1771890095302, 59.056693349565776, 57.57765463420323, 59.9290257862636, 53.88448211124965, 58.47597680773054, 61.450174059186665, 64.14791638510567, 60.485979488917756, 62.294776235307964, 59.37759590148926, 64.08663327353341, 59.410856928144185, 65.70863464900425, 60.87565531049456, 64.24640015193394, 56.08033173424857, 57.885887145996094, 51.809861183166504, 60.17483220781599, 61.68855285644531, 73.58521679469517, 65.17952932630266, 69.94200529370988, 62.04628086090088, 60.74543217250279, 21.32219409942627, 28.691279820033483, 56.59677743911743, 61.80663054330008, 66.63330786568778, 62.54916368212019, 56.29030976976667, 59.27961935315813, 58.39739268166678, 63.50609738486153, 56.579611914498464, 46.93944842474801, 49.32498386928013, 48.73768390927996, 50.73888322285244, 48.83302361624581, 48.6183624948774, 48.086342402866904, 50.238004956926616, 51.45456852231707, 54.429384163447786, 51.04732765470232, 48.137255328042166, 53.58957624435425, 54.33081701823643, 56.44643579210554, 53.63694906234741, 51.161107880728586, 49.73871782847813, 51.97886221749442, 50.986086232321604, 46.3522492136274, 44.21543148585728, 51.64691897800991, 51.61916439873831, 52.96962322507586, 49.98168591090611, 52.615612506866455, 53.48937974657331, 61.929182870047434, 62.075991358075825, 64.76872403281075, 63.82261562347412, 64.20303644452775, 57.81988273348127, 60.723392486572266, 58.38091850280762, 62.7517523084368, 61.78110980987549, 64.17482675824846, 59.39443833487374, 63.25806059156145, 59.81040613991873, 68.55772958483014, 66.03652014051164, 75.98146288735526, 67.12731088910783, 77.09828158787319, 11.290748017174856, 5.3467703972543985, 11.017807143075125, 6.408221508775439, 3.797481051513127, 0.9031749474150794, 0.15474846054400715, 32.4289208139692, 88.30339132036481, 44.37130389894758, 98.91764014107841, 89.92338466644287, 112.24041489192417, 31.05160025187901, 26.927635942186626, 54.808863503592356, 72.10704313005719, 71.90404456002372, 77.53209236689976, 3.02314926471029, 0.2648607976734638, 0.13868421183100768, 0.14929424678640707, 0.18146611617079803, 0.21046028392655508, 0.14617271428661688, 0.07894419745675155, 0.13262786609785898, 0.17186973110905715, 0.1563932429999113, 0.2168435885437897], [0.06225912991378989, 0.008397818260293986, 0.026636635152889148, 0.05816081232790436, 0.059788353208984645, 0.05150831251272133, 0.06046101211437157, 0.06409254510487829, 0.12423894767250333, 0.14442916427339825, 0.22704161703586578, 0.6822256520390511, 20.604525089263916, 84.29277297428676, 57.89855023792812, 56.79908466339111, 30.385389600481304, 31.089652061462402, 49.072576659066335, 35.70903335298811, 34.92790991919381, 15.39147755077907, 0.37199219475899425, 0.09679019091916935, 3.7837418573243276, 1.505275764635631, 1.7915846471275603, 0.6157506076352937, 20.08567704473223, 103.18190247671944, 80.03946099962506, 84.42562253134591, 77.33609063284737, 88.41263784681047, 79.9019422531128, 80.88355595724923, 79.69036960601807, 78.88143948146275, 78.73200457436698, 73.28312301635742, 64.67834186553955, 66.79923779623849, 65.19535037449428, 63.87342085157122, 60.800413267953054, 62.61387920379639, 58.29073783329555, 56.94233219964163, 55.39909560339791, 52.43137754712786, 51.54070881434849, 52.39540324892317, 50.901509284973145, 53.82260492869786, 46.5929730279105, 47.25579295839582, 48.28489065170288, 50.30530520847866, 51.35829775674002, 56.40806783948626, 54.22977631432669, 50.36267648424421, 51.80733551297869, 51.758795397622244, 47.319695540836875, 52.302856717790874, 56.93430355616978, 61.53358023507254, 59.564043862479075, 57.74272993632725, 57.1856963293893, 56.54269960948399, 57.69368607657296, 58.575634820120676, 57.50793988364083, 56.073109081813264, 57.03317642211914, 51.00092758451189, 50.27081782477242, 49.57198190689087, 50.172806535448345, 51.026014055524556, 57.555743489946636, 60.615730149405344, 60.231869970049175, 47.020867415836875, 33.464869431086946, 15.688080515180316, 13.944026214735848, 36.06825869424002, 46.546187332698274, 58.17531783240182, 56.059459345681326, 53.248666354588096, 51.4889030456543, 53.3377492087228, 53.53406708581107, 46.431823457990376, 44.68177720478603, 42.934364318847656, 42.75230067116873, 43.516241209847585, 43.40803343909127, 39.74612780979702, 42.24893147604806, 42.830335889543804, 41.58149446759905, 45.34734862191336, 46.82738092967442, 45.162085328783306, 43.5663411957877, 45.44063861029488, 45.94858666828701, 49.112459318978445, 44.29889324733189, 45.91936254501343, 44.4766629082816, 44.25350414003645, 40.44891030447823, 39.90359830856323, 45.84041016442435, 46.16454015459333, 44.369514737810405, 44.88218409674508, 44.24482236589704, 48.45769582475935, 50.69349758965628, 51.619793210710796, 50.96886512211391, 52.16584518977574, 49.53628901072911, 48.38409008298601, 50.58505705424717, 50.06484889984131, 51.19066204343523, 51.65861974443708, 50.60802085059029, 54.63238968167986, 55.03657681601388, 55.29863159997122, 60.74883678981236, 60.51097215924944, 66.18239756992885, 65.55777536119733, 71.98305947440011, 40.32449933460781, 0.7860208281448909, 0.7801931894251278, 1.3393854605300086, 0.40498452154653414, 1.5398127628224236, 0.07853440980293921, 3.629954989467348, 61.59828880855015, 40.18620586395264, 50.898681368146626, 98.40954617091587, 52.15798330307007, 34.187516825539724, 29.136914696012223, 19.841293266841344, 52.383181367601665, 56.10204138074602, 67.58421748025077, 9.667343974113464, 0.29224381116884096, 0.3481014110147953, 0.03384186959426318, 0.12193072081676551, 0.021365027043170164, 0.07144202930586678, 0.08518804277160338, 0.07658754355673279, 0.047837108972349336, 0.11487486585974693, 0.02120389702862927, 0.1262897112007652, 0.08156701350318533, 0.028038695454597473, 0.023793709131755998, 0.08606575495962586, 0.08524157239922456, 0.08806841035506555, 0.07249798585793801, 0.07990306921835456, 0.2743782555418355, 0.5153369243655885, 1.023733901126044, 25.349019118717738, 98.02378218514579, 65.4349034173148, 67.50282628195626, 42.088608741760254, 30.625752108437673, 45.56212091445923, 33.737113748277935, 44.11745146342686, 14.648353815078735, 0.334162347550903, 0.261048679373094, 3.527480351073401, 2.4759367193494524, 0.6909716970154217, 0.5344561412930489, 29.508829184940883, 106.95605972834996, 79.7967882156372, 89.6255362374442, 79.43622534615653, 90.94660418374198, 83.3196291242327, 83.23662594386509, 83.06029456002372, 82.11290073394775, 80.2234354019165, 76.62039143698556, 66.40419796534947, 69.20621190752301, 66.0542380469186, 69.34646824428013, 63.67102677481515, 65.50004277910504, 60.6535769871303, 58.94188131604876, 57.98813336236136, 56.91835396630423, 53.84150750296456, 54.76740707669939, 53.77634729657854, 55.70596626826695, 49.388761384146555, 49.79750306265694, 51.43360580716814, 52.908642360142295, 54.6774765423366, 59.07603018624442, 55.24721493039812, 53.02594184875488, 53.67021008900234, 53.2030097416469, 48.44041912896292, 53.048745836530415, 59.27243491581508, 63.20617839268276, 61.83764730181013, 61.62902763911656, 60.9265022277832, 60.428483145577566, 61.02620192936489, 62.05042198726109, 59.46328108651297, 58.80751705169678, 57.456811564309255, 54.75124209267752, 53.210225445883616, 51.921768869672505, 52.27653694152832, 52.48792893545968, 59.82413578033447, 62.63272271837507, 62.49134077344622, 47.634337765829905, 39.7752685546875, 18.86181960787092, 18.64041873386928, 42.08532919202532, 48.56729670933315, 60.6716423034668, 57.86083541597639, 56.47953353609358, 52.2780898639134, 55.87683984211513, 54.00524180276053, 49.194722516196116, 45.69570350646973, 46.52862923485892, 45.57757370812552, 47.06552348818098, 44.93204089573452, 43.530672618321006, 45.88889816829136, 45.78516156332833, 46.51088700975691, 47.49316079275948, 48.97618082591465, 46.29346745354788, 45.290825026375906, 47.77012988499233, 48.521987506321494, 50.23427724838257, 46.9809569631304, 47.97074522290911, 47.52047068732125, 49.44677536828177, 43.156727518354145, 42.03824472427368, 47.47964654650007, 49.572655882154194, 46.03922939300537, 48.111408029283794, 47.33523866108486, 51.50658621106829, 52.00526189804077, 54.439545903887065, 53.85714094979422, 53.78533131735665, 52.9495290347508, 52.226968492780415, 51.808061599731445, 52.43093981061663, 53.03840691702706, 53.25986337661743, 52.03378077915737, 57.45408092226301, 58.61268956320626, 58.90385382516043, 62.21323217664446, 66.16902923583984, 67.36819798605782, 70.94626317705426, 71.22985390254429, 47.6450240952628, 1.826540274279458, 1.487399352448327, 1.524367243051529, 1.3822966665029526, 3.8770865627697537, 0.07774411328136921, 3.1104043083531514, 64.73799909864152, 50.653086866651265, 52.850340025765554, 94.63071278163365, 55.37933840070452, 30.52131720951625, 36.26792212894985, 27.621906893593923, 58.69933359963553, 61.266227449689595, 77.56468636648995, 13.025453516415187, 0.31673238426446915, 0.3361837576542582, 0.0465987655999405, 0.08315422226275716, 0.04217988432251981, 0.05892822864864554, 0.06138575356453657, 0.06515093759766646, 0.05819589937371867, 0.11742318554648332, 0.02129162142851523, 0.15364103711077146, 0.16480700937764986, 0.17039516594793114, 0.12889748412583554, 0.14870681187936238, 0.30960434675216675, 0.20749210034097942, 0.14466543016689165, 0.2670033127069473, 0.32151217492563383, 0.5730303142751966, 1.215685703924724, 29.668880939483643, 108.86096395765031, 73.24162142617362, 75.68917301722935, 42.813788754599436, 40.52718523570469, 56.54594094412667, 51.77794115883963, 54.89840146473476, 24.757308789661952, 0.671287396124431, 0.4473082519003323, 10.47462911265237, 7.116167817796979, 9.461184842245919, 1.942509399993079, 29.98566320964268, 109.07377338409424, 85.5978809084211, 92.50388308933803, 84.71650886535645, 95.24154281616211, 87.84524100167411, 85.17490237099784, 85.53689656938825, 84.57894842965263, 82.84166949135917, 81.77524607522147, 70.73496845790318, 72.08034815107072, 71.43306786673409, 72.10818263462612, 68.05561801365444, 69.57295172555106, 65.14692837851388, 63.21685082571847, 61.40351690564837, 59.68088476998465, 58.385240282331196, 57.892533097948345, 54.927559580121724, 58.75421742030552, 52.75408663068499, 54.435703550066265, 53.39228561946324, 57.69136190414429, 58.497022901262554, 63.9127129146031, 57.31782327379499, 55.224115644182476, 55.60352897644043, 55.54717908586775, 52.11317089625767, 56.52702794756208, 64.01506682804653, 65.8374195098877, 65.91064657483781, 64.11066709245954, 63.000824383326936, 62.26883166176932, 63.58260399954659, 64.42035525185722, 63.39811543055943, 60.48515265328543, 62.77180480957031, 57.359724385397776, 56.03338623046875, 55.75082731246948, 56.31918995720999, 56.36171988078526, 63.148918288094656, 64.74497509002686, 65.38069357190813, 51.37594270706177, 44.43117652620588, 20.186583995819092, 20.290952886853898, 48.989799295152935, 53.5862306867327, 64.34796891893659, 61.40907546452114, 61.92348534720284, 54.20113583973476, 57.77327421733311, 59.47983169555664, 53.945417812892366, 50.835772378104075, 48.28119421005249, 48.52527747835432, 50.29713412693569, 48.94573729378836, 45.68914440699986, 47.92689861570086, 48.83755384172712, 48.451595306396484, 51.67209924970354, 51.752260616847444, 50.659138747623985, 49.1326334135873, 49.992549419403076, 50.89973749433245, 53.88403742653983, 48.996316705431255, 51.9557455607823, 50.10563135147095, 53.37458855765206, 46.455815587724956, 44.76355055400303, 50.41205038343157, 51.251298972538535, 48.35187823431832, 52.57851260049002, 50.450790064675466, 54.691768986838206, 56.613460063934326, 57.63738829748971, 57.13160807745797, 59.291875975472585, 57.26525320325579, 55.32490621294294, 56.04931844983782, 55.91928291320801, 57.748514311654226, 57.21345090866089, 55.29426465715681, 61.53204468318394, 60.32508700234549, 61.867656571524485, 65.66091442108154, 69.04806395939418, 71.27839401790074, 73.34694916861397, 77.57208619798932, 50.44455753053938, 3.1380774634225026, 7.2510892408234735, 4.9658419234412055, 2.81988188624382, 6.892014154366084, 0.18078847681837423, 5.4695611340659, 76.37351499285016, 56.02307162966047, 66.83183179582868, 98.69488784245083, 63.365861892700195, 46.63330037253243, 40.83035945892334, 32.72657469340733, 68.6649819782802, 67.37215151105607, 88.08640602656773, 15.135307891028267, 0.48879008314439226, 0.45216015726327896, 0.16129363647529057, 0.14977424245859894, 0.19986961436058792, 0.10983001906424761, 0.21535366134984152, 0.1385906282812357, 0.13808178130005086, 0.2454750793320792, 0.12655761039682797], [0.0757825296106083, 0.04330613710252302, 0.03522374347916671, 0.02902836592069694, 0.12064857461622783, 0.032878628067140064, 0.19119258996631416, 0.03180367931989687, 0.08966499646859509, 0.1342381246920143, 0.1813283735620124, 0.4547677401985441, 26.517358711787633, 77.34057222093854, 60.32149478367397, 44.88683244160244, 34.82708460944039, 35.814906529017854, 46.32111433574131, 49.297375202178955, 29.590758868626185, 5.081478621278491, 0.326618069516761, 0.7979444254721914, 3.235499458653586, 0.713774707700525, 1.8436990678310394, 4.7120884997504096, 90.62036541530064, 89.21739210401262, 84.84599549429757, 81.92980875287736, 76.61907822745187, 79.9279146194458, 81.32082693917411, 81.87181908743722, 77.22658702305385, 80.29732254573277, 74.41853509630475, 73.09488242013114, 70.20672471182687, 68.8025563103812, 65.17675699506486, 68.54742540631975, 66.92339515686035, 65.0614377430507, 60.786711420331685, 60.569698333740234, 56.91045386450631, 54.39985431943621, 52.643756185259136, 51.6546870640346, 52.33387000220162, 51.035265581948416, 46.005752972194124, 47.06274420874459, 49.35654606137957, 48.46856280735561, 52.597297055380686, 53.35992438452584, 51.19958700452532, 50.110165051051546, 52.97165904726301, 47.74925054822649, 48.03387655530657, 52.02141298566546, 59.24066080365862, 60.27763775416783, 60.14890153067452, 58.158294745853965, 59.6309689113072, 60.28103542327881, 58.229451247623985, 58.71389702388218, 57.89843211855207, 58.2718630518232, 55.25486142294747, 53.36470474515642, 53.0360757963998, 50.2263354573931, 48.019483361925396, 51.149400166102815, 54.57391711643764, 60.60341099330357, 59.08638995034354, 41.51064716066633, 40.605401107243125, 25.16449233463832, 22.82062350000654, 39.36757605416434, 44.2628355707441, 58.31608486175537, 52.836982113974436, 53.73707260404314, 46.31668833323887, 46.74260595866612, 45.49690859658377, 42.80887290409633, 42.60992513384138, 42.722857679639546, 44.35193926947457, 43.35084976468767, 41.233191694532124, 41.80576147351946, 43.5013164792742, 41.76823077883039, 42.20769739151001, 45.15344524383545, 46.363237789699006, 45.21053859165737, 43.020862443106516, 43.19958053316389, 45.52345418930054, 46.53161001205444, 45.71650641305106, 45.09985726220267, 43.16201509748186, 43.05323757444109, 41.10557760511126, 38.36239058630807, 42.909093720572336, 47.290950843266074, 45.99621309552874, 45.287211963108604, 44.58927583694458, 47.427983215876985, 47.462300368717735, 48.897537640162874, 46.564940520695274, 47.494682448250906, 46.312814712524414, 48.18333925519671, 47.09461906978062, 48.42472662244524, 48.7912232535226, 49.581806659698486, 53.10649578911917, 61.0349566595895, 60.907047271728516, 63.463164465767996, 66.59764971051897, 69.14283738817487, 65.01922743661063, 70.661776133946, 64.75899655478341, 51.46446623120989, 8.282059039388384, 0.9330770628792899, 0.14341894776693412, 1.3149237845625197, 0.805458413703101, 0.04563039095540132, 0.15804715853716644, 36.69832829066685, 61.92377717154366, 34.00678375789097, 38.302399839673726, 36.17411797387259, 39.830169745853965, 21.260435036250524, 26.855520589011057, 45.41071619306292, 52.4186623437064, 65.78918511526925, 26.454823187419347, 0.30783573165535927, 0.10832867212593555, 0.17985007645828383, 0.07347827218472958, 0.025711308466270566, 0.07732496184429952, 0.09408990652965647, 0.05023507208430341, 0.04395073179953864, 0.05544680456763931, 0.04505045046763761, 0.11498052733285086, 0.02320966520346701, 0.02156235690095595, 0.026632767503282855, 0.07569356009896312, 0.004774832690600306, 0.12084544476653848, 0.027550905111378858, 0.17934159588600906, 0.02007987323616232, 0.1552915871143341, 0.46556192955800463, 35.03106982367379, 88.88401753561837, 63.20571286337716, 56.408529894692556, 35.474910327366416, 28.986665112631663, 41.26566757474627, 52.320581572396414, 39.841130529131206, 4.017796269484928, 0.3539954647421837, 2.6505340933799744, 4.775142967700958, 2.2541584713118414, 1.362708826150213, 8.91384049824306, 100.04036481039864, 88.1018796648298, 89.72078909192766, 80.15197317940849, 82.02383177621024, 81.59223052433559, 84.1492440359933, 82.15804318019322, 80.27667944771903, 82.02953624725342, 76.55630820138114, 77.15523597172329, 73.7024815423148, 71.96690491267613, 69.03599493844169, 72.11230291639055, 70.13117694854736, 66.19127736772809, 67.00297287532261, 64.54713208334786, 59.54883425576346, 57.07098157065255, 54.250266551971436, 52.91797726494925, 55.10588162285941, 54.02022211892264, 49.23865597588675, 49.535799162728445, 51.923912388937815, 53.44690888268607, 55.84718493052891, 55.77524675641741, 52.771165302821565, 52.80982855388096, 54.603512968335835, 50.47184310640608, 51.05681194577898, 57.25036668777466, 61.56794602530343, 63.947294098990305, 62.39296122959682, 61.19352149963379, 62.88615826198033, 61.456399645124165, 63.59699371882847, 62.52278137207031, 59.89922496250698, 59.57022081102644, 57.93202665873936, 56.39292771475655, 55.284141131809776, 52.78802858080183, 51.51041119439261, 53.17790242603847, 58.62062440599714, 61.45783792223249, 63.12723296029227, 46.177470752171104, 47.108164582933696, 30.74393401827131, 27.72896647453308, 45.57502371924264, 47.49940027509417, 61.59243842533657, 57.346679142543245, 56.733528409685405, 48.91023199898856, 49.59517151968819, 49.14382348741804, 45.958411421094624, 45.00172437940325, 45.523117201668875, 46.59414379937308, 46.64158609935215, 43.741929122379844, 44.75856522151402, 45.83702291761126, 44.26986019951956, 45.00612606321062, 47.5820004599435, 48.442246505192344, 48.99550724029541, 45.110505376543315, 45.17934465408325, 47.637228216443745, 49.574472836085725, 48.89384814671108, 47.47789560045515, 46.27697243009295, 46.991473061697825, 44.408042498997276, 42.43801975250244, 44.10554919924055, 48.63353736060006, 47.90124239240374, 48.797483580453054, 47.84717151096889, 49.77730812345232, 48.57865006583077, 52.18931967871529, 49.47395672116961, 50.06233017785208, 47.82778951099941, 51.1070682661874, 51.30766970770699, 51.956290994371685, 52.15250812258039, 53.169550691332134, 57.638406208583284, 62.93166896275112, 65.810133934021, 67.61950738089425, 68.58812795366559, 70.63214206695557, 67.73611899784633, 71.5086225782122, 65.64730290004185, 59.220142773219514, 17.53320070675441, 0.7982487348573548, 0.3849089230809893, 0.7874469459056854, 1.4681310206651688, 0.15122640239340918, 0.0423544985242188, 36.32204859597342, 70.44576358795166, 43.43487433024815, 37.99211413519723, 40.905525071280344, 29.285389014652797, 26.878725835255214, 33.22216885430472, 52.16582434517996, 59.82979161398751, 72.9895268848964, 34.2354177066258, 0.3130282073148659, 0.14069205123398984, 0.22138434488858494, 0.14445015814687523, 0.04909772186407021, 0.0801229892032487, 0.06785044845725809, 0.04934557035033192, 0.03529291333896773, 0.033087236873273335, 0.0793979609651225, 0.40551798577819553, 0.19291749383722032, 0.11354191774236304, 0.12755004928580352, 0.21856087925178663, 0.13819992781749793, 0.27448929101228714, 0.25723664249692646, 0.19798032859606401, 0.23638800265533583, 0.25095908077699797, 0.6291454860142299, 42.884583950042725, 98.8521533693586, 75.14783191680908, 62.17293957301548, 46.90198026384626, 45.479100363595144, 56.72061518260411, 69.66286141531808, 53.37111793245588, 7.061446411269052, 0.4163972091461931, 3.101211190223694, 8.763260875429426, 9.56043725354331, 5.645198132310595, 8.300331933157784, 102.11213697705949, 94.46173259190151, 93.2496679850987, 85.93087332589286, 83.5450564793178, 84.91877787453788, 88.90493856157575, 85.63356685638428, 83.86875915527344, 86.5336503982544, 78.59407588413784, 79.62417411804199, 76.9470054081508, 74.18734073638916, 71.03112152644566, 75.13076714106968, 71.38531289781842, 72.4167868750436, 68.36510467529297, 67.34675584520612, 63.53383459363665, 61.01102706364223, 58.9176390511649, 56.30477244513375, 57.635303837912424, 56.38676813670567, 52.04489442280361, 53.68119171687535, 55.178615365709575, 56.47883871623448, 57.952113900865825, 57.7808130128043, 55.016020570482524, 54.64141191755022, 56.629229000636506, 55.83263540267944, 53.56887756075178, 59.145720618111746, 65.18260737827846, 65.68009144919259, 66.34812600272042, 63.00923865182059, 66.95472458430699, 65.0610625403268, 66.27693475995744, 64.7566202708653, 63.88553850991385, 64.61328588213239, 61.17419855935233, 57.87706640788487, 58.18871743338448, 56.471015044621055, 54.55370480673653, 57.23094994681222, 62.11164951324463, 65.06746877942766, 68.48662866864885, 49.84316314969744, 51.873353821890696, 32.127782412937705, 28.979993104934692, 50.28355387278965, 53.07276228496006, 66.21085739135742, 57.95765856334141, 59.869021143232075, 52.292688029153005, 54.254056794302805, 53.119944027491975, 46.99799394607544, 46.78884274618966, 49.304337297167095, 49.756498268672395, 49.841221128191265, 46.348024708884104, 47.53470754623413, 50.392710072653635, 48.918649741581504, 49.62877648217337, 51.384429931640625, 53.179156575884136, 51.1514116695949, 49.269881180354524, 48.61094529288155, 52.64644513811384, 54.986820765904014, 50.93488148280552, 51.87856149673462, 50.138798577444895, 49.880436761038645, 46.33702918461391, 45.24516841343471, 47.73149790082659, 51.60070998328072, 51.60082115445818, 50.30922399248396, 50.23741088594709, 53.72945043018886, 53.94380930491856, 54.2741961479187, 52.715531076703755, 53.60033900397164, 52.59791544505528, 55.73836571829659, 53.52338423047747, 55.12765032904488, 56.74702875954764, 56.62672070094517, 59.9073543548584, 67.70618615831647, 69.7676055090768, 70.41656725747245, 70.52424349103654, 74.35174901144845, 71.49477481842041, 76.34688254765102, 69.6350199835641, 68.48331437792096, 17.141584600721085, 2.2732836050646643, 3.345155711684908, 4.547320655414036, 3.595066564423697, 0.34712928746427807, 0.35244210809469223, 46.531269550323486, 75.9733612877982, 49.42905398777553, 49.93374334062849, 53.045921393803184, 55.684009960719514, 31.71342658996582, 39.40930693490164, 60.19121606009347, 67.76646872929165, 80.98419366564069, 40.383666719709126, 0.5264121357883725, 0.17125370273632662, 0.32509988812463625, 0.1746654582342931, 0.12739775888621807, 0.2703602968582085, 0.15236274498913968, 0.10068886314651795, 0.1644985337874719, 0.17345178978783743, 0.16159683306302342], [0.09050055806125913, 0.10650462750345469, 0.06110710637377841, 0.06105951392757041, 0.08469379107866969, 0.023376257424908023, 0.07211103090750319, 0.03484388939770205, 0.05622111141149487, 0.02811961923725903, 0.15520776089813026, 0.10225218068808317, 44.33072294507708, 66.72456550598145, 54.13676425388881, 41.03491789954049, 47.784113134656636, 23.461355107171194, 31.838935375213623, 30.382982049669536, 22.086944103240967, 0.18368268651621683, 0.07811529229262046, 3.0842940637043545, 2.6167751848697662, 0.9921301284006664, 0.2136769470359598, 66.97798715318952, 90.82246766771588, 80.21885653904506, 81.0084011895316, 65.98423494611467, 70.93231119428361, 78.03934560503278, 80.5571573802403, 81.48926516941616, 80.66105379377092, 81.56290912628174, 76.84399141584123, 77.13896329062325, 72.12922177995954, 71.98539406912667, 72.38324097224644, 70.93725136348179, 68.79434353964669, 68.99427100590297, 68.91611766815186, 64.64044639042446, 60.91542679922921, 57.368718828473774, 51.461881501334055, 52.08965124402727, 52.836106640951975, 49.6426659311567, 44.92319931302752, 46.55874272755214, 46.97690268925258, 50.67583874293736, 53.934380599430625, 54.750748770577566, 51.196922370365684, 52.026266302381245, 50.05129296439034, 44.47360570090157, 49.03682122911726, 54.076401778629844, 61.18341187068394, 61.62229483468192, 58.93479415348598, 63.26505742754255, 59.630225454057964, 59.89948204585484, 58.92927033560616, 57.50881535666329, 55.96245901925223, 56.33526808874947, 55.766214098249165, 55.558702673230854, 52.8100265775408, 49.89242240360805, 46.34524890354702, 49.9568634714399, 54.269954272678916, 58.690266200474326, 57.58722230366298, 47.47842018944876, 46.34040253502982, 39.987654141017366, 39.684170722961426, 46.216224329812185, 46.13555921827044, 55.29385471343994, 53.750433989933555, 49.04412725993565, 46.764075892312185, 43.65162685939244, 43.10683945247105, 44.91146033150809, 44.05672768184117, 45.6858857018607, 43.00183827536446, 43.13090106419155, 42.15165669577462, 42.40236854553223, 42.680692536490305, 41.375890323093955, 43.27561814444405, 42.43348257882254, 46.575970785958425, 46.58982201984951, 44.79268782479422, 42.31405694144112, 43.971907547542024, 45.81771387372698, 43.58833571842739, 45.45859622955322, 41.98926339830671, 43.286853381565635, 42.353401115962434, 38.525909491947715, 39.96816444396973, 45.67129101072039, 45.56284352711269, 45.954749720437185, 45.58559192929949, 44.16946915217808, 43.59637825829642, 45.39232778549194, 44.83107662200928, 46.416009357997346, 45.44743047441755, 48.041213853018625, 47.16608476638794, 47.28221695763724, 51.18533277511597, 57.44914075306484, 59.13536780221121, 64.27473490578788, 64.6192752293178, 69.48231247493199, 65.84112984793526, 67.8855539049421, 65.02367428370884, 66.90209197998047, 62.538588523864746, 56.5452287537711, 58.21681942258562, 9.55875665800912, 0.6088956126144954, 1.340431381549154, 0.7062982831682477, 0.4380004070699215, 0.45153484653149334, 10.07817792892456, 64.64200973510742, 55.025949546269004, 29.334495408194407, 22.240000758852275, 45.812985624585835, 25.96412229537964, 15.559116738183157, 26.805453607014247, 56.94314513887678, 58.857293946402415, 49.55998236792428, 0.3910359585923808, 0.04616328861032214, 0.05709535628557205, 0.06931036404733147, 0.06746095578585352, 0.09474761052323238, 0.07590405523244824, 0.054416944472385306, 0.07616113858031374, 0.06885742835168328, 0.1017830144347889, 0.08278512635401317, 0.04025674983859062, 0.029754422139376402, 0.017235615590055074, 0.055863279184060435, 0.005230383290576616, 0.08106841240078211, 0.05233467656320759, 0.02749994713147836, 0.057224522211721966, 0.22597711772790977, 0.04981188675654786, 52.706380299159456, 75.78612123216901, 60.30577795846121, 50.344440937042236, 49.726058210645405, 24.118883984429495, 31.364821570260183, 41.234675134931294, 29.340304102216447, 0.08333511291337864, 0.5945607189621244, 6.004883357456752, 2.6199932864734103, 0.02952597296929785, 0.3750522791274956, 75.94189289637974, 92.25312955038888, 84.75527286529541, 82.10004656655448, 71.11851596832275, 75.39138712201799, 80.60808767591203, 82.99204240526471, 83.73401968819755, 80.11438342503139, 80.86974988664899, 78.6881753376552, 79.68968868255615, 75.04823643820626, 73.99576500483921, 73.97681726728166, 75.33084746769497, 71.74953051975795, 72.55531311035156, 72.2746684210641, 67.4545293535505, 63.82522119794573, 59.77548449380057, 54.853384086063926, 54.51342609950474, 54.854732036590576, 51.019573075430735, 48.07208122525896, 49.81215681348528, 50.82972049713135, 52.625405992780415, 55.598182337624685, 57.26618078776768, 52.57447917120797, 53.20500040054321, 53.73182324000767, 46.51683119365147, 51.947852407182964, 58.596632276262554, 63.683005469185964, 63.94785690307617, 61.11690371377127, 65.22483852931431, 61.79896668025425, 61.69900989532471, 60.21884904588972, 61.763218198503765, 58.66167436327253, 58.50178936549595, 57.78693437576294, 57.54933030264718, 56.48498092378889, 52.1527339390346, 49.26902655192784, 52.61535194941929, 57.81222234453474, 61.51413917541504, 58.36734867095947, 51.64311483928135, 50.05701133183071, 44.75672394888741, 43.8847701890128, 51.74917909077236, 51.1152914592198, 57.799451555524556, 55.74171127591814, 52.24047579084124, 49.48598405293056, 46.37639767783028, 46.37085996355329, 47.62400232042585, 45.938675062997, 47.7859822000776, 45.759706837790354, 45.26249027252197, 44.83732305254255, 45.10515178952898, 45.82376575469971, 44.856371538979666, 44.78744193485805, 46.50294869286673, 50.88408667700631, 50.55463784081595, 47.52240228652954, 45.74647746767317, 46.66427891595023, 47.96343224389212, 46.72773681368147, 47.862728527614046, 42.99334410258702, 45.69819096156529, 46.187566484723774, 41.14846188681466, 40.987930706569124, 48.17871870313372, 46.98058870860508, 48.479867526463096, 47.199036598205566, 47.64733784539359, 46.83483634676252, 48.304394245147705, 47.67560659136091, 49.75470215933663, 47.62965815407889, 50.08501257215227, 50.62257732663836, 50.05596562794277, 55.265645027160645, 59.65469006129673, 61.087811606270925, 68.31129782540458, 67.94002083369664, 70.86633110046387, 67.78680610656738, 70.61018575940813, 67.4639858518328, 68.6338609967913, 62.97074563162667, 62.100865909031455, 67.32149914332798, 19.877359628677368, 0.18069709172206266, 0.506203408752169, 1.2873025238513947, 1.1855490867580687, 0.44750038587621277, 8.357821328299385, 70.35617351531982, 64.94390201568604, 36.13349880490984, 27.34569341795785, 40.05359601974487, 23.86317811693464, 26.483430658067974, 35.573672022138325, 64.45476273127964, 64.40361704145158, 58.613648414611816, 0.5518234350851604, 0.1277555911136525, 0.044799911590026956, 0.11575191308345113, 0.08387910122317926, 0.0569048609717616, 0.040112534005727084, 0.040377827627318244, 0.005562568166559296, 0.030023854824581316, 0.03907650602715356, 0.2915565094777516, 0.24053420445748738, 0.17589148958878859, 0.09792604496968643, 0.15066623102341378, 0.11040403254862342, 0.1615467436079468, 0.13997327908873558, 0.2181141317955085, 0.12488329809691225, 0.4011919450547014, 0.15447370814425604, 59.64540031978062, 85.93941961015973, 70.21835599626813, 57.59980549131121, 62.77771077837263, 35.084800243377686, 45.67581081390381, 50.00809601375035, 36.40726130349295, 0.26860994792410303, 1.2077679059335162, 10.401205761092049, 9.057956559317452, 5.391108589512961, 0.529461960707392, 78.51458849225725, 94.91618646894182, 87.64523015703473, 85.67140674591064, 72.71580954960415, 77.43738147190639, 83.89251504625592, 87.53982598440987, 88.58100659506661, 83.59384672982353, 85.6567599432809, 81.47524370465959, 83.82037884848458, 77.16183676038469, 76.46181964874268, 77.38566602979387, 78.2283296585083, 74.925767489842, 77.25330979483468, 73.96498448508126, 71.7849246433803, 67.7156982421875, 63.5065073285784, 55.96723937988281, 59.2455940246582, 57.55001122610909, 53.53311170850481, 52.828025885990684, 52.900950704302105, 54.25942775181362, 57.76002747671944, 58.15226718357631, 58.96810381753104, 54.495808941977366, 55.666646412440706, 56.25419650759016, 49.62463535581316, 54.508360862731934, 61.670049803597585, 67.05208274296352, 67.47663852146694, 65.39757074628557, 69.90862614767892, 63.85891301291329, 65.9342565536499, 64.33826923370361, 65.47612707955497, 61.22259971073696, 62.2371826171875, 60.79735606057303, 61.06233951023647, 59.347537994384766, 55.815278802599224, 50.38652270180838, 57.02743026188442, 59.71595927647182, 64.96415601457868, 63.60314982278006, 54.81304284504482, 54.434494563511436, 46.42155749457223, 47.760162694113596, 55.381332533700125, 55.252301011766704, 61.25003119877407, 58.50938374655587, 54.8358850479126, 51.984382561274934, 47.38054438999721, 48.05604130881173, 50.10777487073626, 48.15904140472412, 50.63836015973772, 49.77656119210379, 48.998359475817, 47.60563128335135, 47.71038927350725, 49.283732414245605, 46.76774454116821, 49.67597906930106, 48.5787855557033, 54.237488814762656, 54.80547973087856, 51.14463022777012, 47.79874604088919, 48.84226819447109, 50.993753569466726, 48.90583378928048, 51.487436975751606, 46.298185280391145, 48.18402017865862, 49.03831509181431, 43.72685847963606, 44.518261773245676, 50.20783587864467, 49.533117158072336, 50.26346663066319, 50.4535346031189, 51.47651440756661, 49.31521470206124, 49.828856808798655, 51.90967205592564, 52.786010129111155, 50.870534215654644, 53.1552026612418, 53.81692477634975, 52.41295092446463, 58.7483183997018, 63.32893221718924, 63.60460894448416, 70.39645222255162, 70.62978662763322, 74.95697184971401, 72.24623639242989, 73.44796207972935, 71.44320528847831, 71.62787451062883, 67.25263554709298, 63.01113551003592, 70.112243107387, 17.262161902018956, 0.8149088865944317, 5.316530968461718, 3.492546762738909, 1.5104615092277527, 0.6703989495124135, 13.732212117740087, 79.41779177529472, 70.37093148912702, 44.64562920161656, 34.17173399244036, 63.264237540108816, 34.147849559783936, 26.63210126331874, 43.03125, 74.25283445630754, 72.6081611088344, 67.30485820770264, 0.6278377047606877, 0.1672030250941004, 0.10666861584676163, 0.2080037293157407, 0.2727118549602372, 0.21056086995771953, 0.1126009321638516, 0.08570635531629835, 0.1654508983982461, 0.192501375451684, 0.1854777101959501], [0.05405485104503376, 0.07269478136939661, 0.054981404183698554, 0.007040941605477461, 0.05102508022849049, 0.10721782209085566, 0.029398415171142136, 0.03278487827628851, 0.16159025127334253, 0.12446210426943642, 0.034078291550810845, 0.37753783432500704, 54.95781898498535, 64.54700701577323, 53.018277985709055, 42.14274215698242, 19.134862967899867, 35.9084848676409, 45.15157617841448, 34.947364875248496, 14.792132888521467, 0.42404793575406075, 0.8792546881096703, 4.206858924457005, 0.2524072916379997, 1.0512604926313673, 23.141946417944773, 99.73015553610665, 80.93957928248814, 86.59836591993059, 73.78171185084751, 70.48101874760219, 65.8275044304984, 70.60604463304792, 75.83136095319475, 77.64510481698173, 78.13199288504464, 76.81434345245361, 75.36137090410504, 78.03353691101074, 75.12593119485038, 73.66130651746477, 73.4220244543893, 71.65365927559989, 71.2533735547747, 71.83561870029995, 71.04119641440255, 65.02946213313511, 60.82570471082415, 60.72045339856829, 53.16411025183541, 51.76346458707537, 52.00455665588379, 47.82083783830915, 43.549391065325054, 48.26177746909005, 48.009363310677664, 51.09858104160854, 54.88666943141392, 50.288073675973074, 51.78340939113072, 49.63563435418265, 45.52449294498989, 45.76462616239275, 50.08035380499703, 57.23025860105242, 59.51287037985665, 59.69426005227225, 61.7943183353969, 62.44478784288679, 58.151023456028526, 60.624380656651084, 58.94905880519322, 58.518652643476216, 54.68168020248413, 55.843585763658794, 53.18478461674282, 53.53255932671683, 52.887172426496235, 52.184838090624126, 50.242934703826904, 51.97039931161063, 55.16623020172119, 58.13531010491507, 55.97641795022147, 50.93998146057129, 51.48377874919346, 49.772722312382285, 45.76216650009155, 48.469320161002024, 49.540756702423096, 52.109144415174214, 54.627393926892964, 54.38618721280779, 48.53793709618704, 46.01080083847046, 46.91635608673096, 46.09735107421875, 44.65659693309239, 41.7994247164045, 41.73806864874703, 41.05302837916783, 41.33449295588902, 41.621981620788574, 44.621445996420725, 44.0434809412275, 42.809140409742085, 44.196990966796875, 47.57982219968523, 46.02941158839634, 46.26491035733904, 44.72916739327567, 44.639323711395264, 45.43008082253592, 43.07554824011666, 43.248179708208355, 43.098974091666086, 42.115039689200266, 42.47882999692644, 40.95861625671387, 38.99475308826992, 43.442743165152415, 46.39232989719936, 45.970973764147075, 45.835855620247976, 46.25126756940569, 44.86041191646031, 45.65709236689976, 44.11982079914638, 44.76074348177229, 46.50582872118269, 47.33644764763968, 46.604284695216585, 50.944994585854666, 57.76398794991629, 63.09532683236258, 64.7198851449149, 67.73200566428048, 62.87102508544922, 64.97516196114677, 64.91099534715924, 67.72751017979213, 67.18377889905656, 67.15666702815464, 66.3829573222569, 70.50666454860142, 66.37593964168003, 68.00313826969692, 12.82891503402165, 1.2674953809806278, 1.0070720123393195, 0.3765603367771421, 0.05015062840123262, 0.11505114925759179, 43.66058308737618, 63.80168764931815, 46.58595882143293, 31.489361081804546, 42.125594002859934, 28.440072911126272, 14.519865989685059, 20.787413835525513, 50.449914591653005, 48.544131415230886, 59.69665718078613, 3.943866567952292, 0.23380916246346065, 0.13456394363726887, 0.037162687829030414, 0.03757125072713409, 0.05923303336437259, 0.11169677746615239, 0.07417233208460466, 0.07710595788168055, 0.023725229681336453, 0.05776249870125737, 0.011154410030160631, 0.05105643533170223, 0.06512136025620358, 0.09684918953904084, 0.012395482809681977, 0.06714631231235606, 0.008932899949806077, 0.0461751019049968, 0.10557037977767841, 0.07745322531887464, 0.06488141670290913, 0.5258269129054887, 64.2018483025687, 72.22685786655971, 61.031788281032014, 52.464054925101145, 30.981541565486364, 30.805925846099854, 44.772267069135395, 44.32780817576817, 15.207305124827794, 0.5313804234777177, 3.8865130969456265, 4.401391114507403, 1.022331667797906, 0.7516883675541196, 29.191671712057932, 106.10487760816301, 83.36001205444336, 89.60444845472063, 76.0107148034232, 70.85836151668003, 68.8572803224836, 71.75713879721505, 76.47812012263707, 81.07224818638393, 82.06315858023507, 79.08773844582694, 77.25489398411342, 81.33593232291085, 77.11322716304234, 77.23400769914899, 73.29837431226457, 73.7828791482108, 73.8116933277675, 73.49944128308977, 71.46362604413713, 68.49445234026227, 63.03478022984096, 62.737994875226704, 55.61902693339756, 55.01240055901663, 53.46253538131714, 51.20008727482387, 46.64584534508841, 50.99915926797049, 49.87075097220284, 53.87796470097133, 56.45631613050188, 51.13106039592198, 52.47060012817383, 52.49876465116228, 47.850610869271414, 48.54574687140328, 54.122426646096365, 60.352685247148784, 62.96110153198242, 63.19342150006975, 63.35731560843331, 65.02493190765381, 61.97752843584333, 63.4045147214617, 63.592435700552805, 61.038555826459614, 57.87182746614729, 58.42424052102225, 55.598234449114116, 56.261113439287456, 55.525045599256245, 54.87388474600655, 51.61862938744681, 54.75669295447213, 58.674667494637625, 62.041021074567524, 58.86233833857945, 53.722453594207764, 55.947013173784526, 53.53116621289934, 51.0219841003418, 53.34208141054426, 52.57340914862496, 55.85843406404768, 57.864670821598594, 57.54402187892369, 51.76140792029244, 49.039690835135325, 49.26263768332345, 49.63625969205584, 47.34531702314104, 44.82062653132847, 43.49367693492344, 44.70828110831124, 44.6966289792742, 46.680398736681255, 47.5803085735866, 46.40439544405256, 45.221252713884624, 48.08222906930106, 49.82200935908726, 50.264870166778564, 48.304901463644846, 48.49357632228306, 47.87019436700003, 48.15371561050415, 45.96831955228533, 45.66666003635952, 45.9683403968811, 46.29658024651663, 45.09969745363508, 44.15912675857544, 41.429332392556326, 47.410293102264404, 48.1064852305821, 47.90954548971993, 48.78570638384138, 48.750732626233784, 46.904794284275596, 48.35510219846453, 48.282656805855886, 48.217079707554404, 49.82059192657471, 49.74328626905169, 49.74468980516706, 54.42116444451468, 62.65869508470808, 65.673018183027, 67.14339596884591, 69.5078193119594, 66.73534216199602, 67.78114332471574, 67.53377355848039, 70.06618349892753, 68.78891699654716, 68.34649739946637, 67.34341376168388, 71.75369249071393, 67.64222799028668, 76.75120517185756, 25.209261315209524, 0.6407641768455505, 1.2027036462511336, 1.829948148557118, 0.1227609355534826, 0.07911429261522633, 44.95419522694179, 71.08556761060441, 53.89899342400687, 37.89276531764439, 44.21850258963448, 26.742640154702322, 22.434638908931188, 26.104210138320923, 58.26535606384277, 54.142878668648855, 69.01754052298409, 5.691352409975869, 0.27907518350652283, 0.15543314308992454, 0.021295495863471712, 0.04595529387838074, 0.01500080113432237, 0.09869638577635799, 0.06425007379480771, 0.02907921533499445, 0.0428525126938309, 0.05020919615136726, 0.10491545099232878, 0.14195992105773517, 0.13554232328065804, 0.12474712968936988, 0.12721866635339601, 0.29994963482022285, 0.05764024704694748, 0.22103859058448247, 0.2839244290121964, 0.29357192133154186, 0.11901812281991754, 0.6941356786659786, 72.54072189331055, 82.68170806339809, 69.79738548823765, 60.083359173366, 30.02176604952131, 46.46217318943569, 60.69816357748849, 54.23712750843593, 21.467442716870988, 0.5886276087590626, 5.6491542628833225, 7.408554094178336, 7.010381928512028, 2.8757247754505704, 28.643073218209402, 109.62559236798967, 90.32383714403424, 93.75943647112165, 80.02985858917236, 75.82435716901506, 71.64054107666016, 74.46753379276821, 82.69033077784947, 83.83721433367047, 85.01379449026925, 80.55840805598667, 78.14414528438023, 83.98349475860596, 80.5752226965768, 81.25900186811174, 77.54009669167655, 77.29891082218715, 75.88547352382115, 78.24499143872941, 77.71617099217006, 72.7106956754412, 66.58271803174699, 66.41903236934117, 58.440916197640554, 56.6439973967416, 57.62018803187779, 55.6269200869969, 49.685376507895334, 55.04260090419224, 53.59702123914446, 56.42038352148873, 58.13189506530762, 53.11756426947457, 55.911452293395996, 53.36504520688738, 50.66316870280674, 52.078867639814106, 55.973430224827354, 63.96176719665527, 65.49796526772636, 65.43752983638218, 66.87023448944092, 67.93806144169399, 63.4962865284511, 67.77356284005302, 66.17687375204903, 63.520445414951865, 60.75079618181501, 62.01679270608084, 60.17534637451172, 59.354138783046174, 58.295928137642996, 58.17516149793352, 55.276303563799175, 57.10004241125924, 61.9358948298863, 65.13245528084892, 62.99714878627232, 61.944413321358816, 57.732745374952046, 55.91953999655587, 52.88348988124302, 56.85587576457432, 56.81191451208932, 58.59660448346819, 61.27510724748884, 60.471881593976704, 55.59753615515572, 52.03258568899972, 54.18294545582363, 51.94341598238264, 49.83583974838257, 48.01166663851057, 45.831266335078645, 45.79374258858817, 48.21443591799055, 46.976423263549805, 51.13119241169521, 50.45820379257202, 47.607128620147705, 50.60428966794695, 53.34475646700178, 52.066885471343994, 50.82289389201573, 51.21133640834263, 50.53309147698538, 53.23614570072719, 49.29405396325247, 48.3649616922651, 48.604466097695486, 49.71369736535208, 48.860597542354036, 47.011341435568674, 45.00571959359305, 49.942470278058735, 50.1688460622515, 51.701608249119346, 53.16822011130196, 53.08446305138724, 50.98698602403913, 52.20420272009713, 50.49381331035069, 52.86556352887835, 54.715931347438264, 54.188695090157644, 51.98573398590088, 56.336935656411306, 64.86609608786446, 69.01466396876744, 70.6252008165632, 73.17379311152867, 68.0083841596331, 71.13386453901018, 70.49474838801792, 73.3087271281651, 71.8022881916591, 71.93866743360246, 71.5434261049543, 76.6162086214338, 71.18965162549699, 76.70952987670898, 20.882161208561488, 2.2630719244480133, 6.579453783375876, 2.4248008004256656, 0.15788570791482925, 0.40538789704442024, 56.46840599605015, 75.88647406441825, 62.099462372916086, 45.84434631892613, 57.99546023777553, 39.82548318590437, 24.373280116489955, 33.129417351314, 67.12856156485421, 62.049880027770996, 79.86451925550188, 6.495756217411586, 0.5155763115201677, 0.26937905379704064, 0.13726383447647095, 0.22017062215932778, 0.16365240061921732, 0.22883878488625797, 0.1759967032287802, 0.11898039627288069, 0.15232135435300215, 0.14910516621811049], [0.058921144743050845, 0.0798458687162825, 0.021691816293501427, 0.03408548741468361, 0.054860438353249004, 0.05327091578926359, 0.03636339054043804, 0.11066561458366257, 0.0607472046145371, 0.09737836542938437, 0.10083011378135, 1.9043726921081543, 64.70467553819928, 65.19315474373954, 53.33317034585135, 37.248507499694824, 46.00906726292202, 97.66605418069022, 35.94361843381609, 48.01080853598458, 5.880874948842185, 0.0896709200793079, 1.9007654913834162, 1.2917061618396213, 0.7380939455968993, 0.6408960297703743, 78.26471737452916, 85.89443697248186, 83.40699577331543, 76.81944343021938, 73.2162674495152, 63.10891056060791, 62.84278760637556, 62.415695735386436, 70.44728524344308, 73.36812727791923, 78.76698180607387, 76.44173240661621, 77.78890473502022, 76.12499877384731, 73.82297025408063, 71.53081512451172, 75.19746984754289, 71.02288791111538, 69.02070195334298, 65.56448037283761, 67.38836860656738, 66.36891501290458, 62.23776626586914, 56.570454188755576, 53.17419556209019, 52.84404843194144, 49.962946619306294, 46.75129468100411, 44.72598859242031, 46.108766964503694, 47.50986078807286, 54.745860712868826, 54.54379667554583, 49.09054470062256, 51.54847690037319, 49.753746782030376, 47.023552894592285, 45.72466707229614, 54.723539624895366, 59.96642793927874, 60.55687195914132, 58.23943928309849, 62.03913116455078, 62.97999368395124, 60.10942881447928, 60.42367499215262, 60.334515707833425, 57.04285178865705, 54.146821771349224, 51.72739996228899, 52.284489154815674, 53.75219188417707, 52.42683342524937, 51.13270364488874, 49.1297881262643, 51.86727067402431, 53.93991831370762, 57.66367333275931, 51.692877837589805, 46.45150423049927, 49.115367140088765, 45.157284123556956, 44.08131735665457, 47.430529730660574, 48.21953936985561, 48.441124371119905, 53.23835522787911, 53.774103028433665, 52.6698431968689, 52.5075923374721, 52.66789770126343, 55.31977496828352, 55.798585755484446, 46.42193617139544, 42.64549643652779, 40.8221640586853, 43.11219998768398, 43.55386223111834, 45.99789803368704, 43.317929199763704, 44.57245772225516, 45.940293993268696, 48.137237957545686, 49.359929834093364, 46.80221108027867, 43.3652776990618, 45.57798712594168, 44.61010306222098, 44.665848459516255, 43.16862630844116, 43.2177848134722, 43.033327511378694, 42.50971473966326, 40.10208054951259, 38.43159464427403, 39.54463005065918, 45.851676668439595, 44.52369179044451, 45.819346700395855, 44.183285645076204, 44.48564692905971, 45.70821026393345, 47.1276091166905, 45.77890818459647, 45.578171253204346, 46.670539242880686, 49.61060346875872, 57.5335578918457, 64.19676916939872, 64.30038070678711, 65.98055240086147, 62.62140410287039, 65.71334552764893, 64.83207770756313, 67.70072487422398, 65.49572794778007, 67.74730559757778, 65.88058171953473, 69.58792509351457, 62.909566743033274, 72.54830237797329, 64.66156196594238, 73.32305431365967, 1.847509286233357, 1.8911174833774567, 1.9167311489582062, 0.3312778951866286, 0.4218889187489237, 15.566566944122314, 64.66509165082658, 58.14594084875924, 36.867572511945454, 45.81449338368007, 43.176568099430625, 24.92870695250375, 23.49796516554696, 43.4180770601545, 50.579397746494834, 61.44085652487618, 10.895570090838842, 0.3354390247591904, 0.3528775375868593, 0.07129577108259712, 0.05894839470939977, 0.037234951808516464, 0.08222312293946743, 0.03941516285496099, 0.07491502937461648, 0.1384278205888612, 0.025777984709878052, 0.08797222123082195, 0.08673002717218228, 0.05514987425080367, 0.01612190213719649, 0.09025654329785279, 0.005106742759900433, 0.009390911935562534, 0.08677086819495473, 0.034990273149950166, 0.15710499909307274, 0.08485542490546193, 2.5269625527518134, 73.88719245365688, 71.61549282073975, 64.22590296609062, 38.965963227408274, 44.74332087380545, 104.49838461194719, 40.49502897262573, 57.289749077388215, 4.777649096080235, 0.14992734710020678, 3.66414338350296, 1.3260085497583662, 0.3076795871768679, 1.4476742212261473, 85.64519119262695, 88.12767137799943, 86.93825789860317, 79.6264739717756, 74.13914108276367, 65.387864112854, 64.41840280805314, 65.82821314675468, 72.28458350045341, 75.9443108694894, 80.94779205322266, 76.84874398367745, 78.12124402182442, 76.26986871446881, 76.71620709555489, 74.8670482635498, 75.90444905417306, 71.70497172219413, 71.2965566090175, 71.00929723467145, 70.16569559914726, 70.5040589741298, 63.802535329546245, 59.74006952558245, 55.6659620148795, 55.387773513793945, 53.25276231765747, 49.37226636069161, 48.66061449050903, 47.929222788129536, 49.61613770893642, 56.86901133401053, 53.34684092657906, 51.50189617701939, 52.74548823492867, 50.458721433367046, 49.49330398014614, 47.59578916004726, 57.7066444669451, 62.23512595040457, 64.09019769941057, 60.93301963806152, 64.81596483503068, 65.07459763118199, 64.86021791185651, 62.40368924822126, 63.681872912815635, 59.53718907492501, 57.24636105128697, 54.79839604241507, 55.140164034707205, 56.8360664503915, 55.25039720535278, 54.32773896626064, 53.70655264173235, 52.182461806706016, 58.514782496861045, 61.15280505589077, 53.58029692513602, 50.20061322620937, 52.108011858803884, 46.175962993076865, 46.71659885134016, 50.083421434674946, 49.342969281332834, 50.76143707547869, 57.08167484828404, 56.456788608006065, 56.286384037562776, 55.26150042670113, 56.1962902205331, 57.957370213099885, 56.45743826457432, 50.34243638174874, 46.37663044248308, 43.58747066770281, 44.5345344543457, 46.70787191390991, 47.23950638089861, 45.59029238564627, 47.8697566304888, 48.85006059919085, 50.68167175565447, 52.03161294119698, 49.439535345349995, 47.70364952087402, 48.232351848057334, 48.488785539354595, 46.462597029549734, 46.271910667419434, 45.358069692339214, 46.1252098764692, 45.546383244650706, 44.04573563167027, 41.705203669411794, 42.813357966286794, 46.20140034811837, 46.40034811837332, 48.74792207990374, 48.09951966149466, 47.83920887538365, 47.992652893066406, 49.83365453992571, 47.86855459213257, 50.46143470491682, 47.51588487625122, 53.72853326797485, 59.7534031186785, 66.88370704650879, 66.3828044618879, 68.6599931716919, 63.72143595559256, 68.91384560721261, 65.46485710144043, 69.43247999463762, 66.3663580758231, 70.53107357025146, 65.5901609148298, 72.56307424817766, 63.79405157906668, 76.41962323869977, 65.14087649754116, 80.8006431034633, 4.948867040021079, 2.3763258244310106, 2.328021079301834, 0.7328937074967793, 0.35804436462266104, 13.453923736299787, 73.71459225245884, 62.8696562903268, 45.7359162058149, 46.595238140651155, 35.76290273666382, 25.289346252168926, 32.1670640536717, 51.08586931228638, 55.727074895586284, 69.20149408067975, 14.121140139443533, 0.5050502249172756, 0.36363923868962694, 0.15471477806568146, 0.12419432720967702, 0.08058458300573484, 0.0644060622102448, 0.06822898957346167, 0.12385282053479127, 0.04245076567998954, 0.04185322399384209, 0.15451019975755895, 0.1831130970801626, 0.1109799255750009, 0.14420474560133048, 0.1398963060762201, 0.16741429375750677, 0.091087999753654, 0.21775049130831445, 0.13618165254592896, 0.34494293906858986, 0.16964808532169887, 2.5783431785447255, 82.29551328931535, 83.07793603624616, 70.36834675925118, 51.433112485068186, 55.03530876977103, 102.2192712511335, 52.35030596596854, 66.05926159449986, 6.841558073248182, 0.16716601779418333, 6.171316598142896, 6.092128847326551, 4.097390489918845, 0.9979898482561111, 88.27023451668876, 89.64847918919155, 89.68078136444092, 80.53511074611119, 77.95050593784877, 68.12984561920166, 67.61581788744245, 70.58802100590297, 77.26278713771275, 77.92467253548759, 86.47711985451835, 79.06261375972203, 80.61911446707589, 78.834518296378, 81.30627046312604, 77.21376064845494, 80.02664852142334, 75.2095319202968, 76.27860954829625, 73.63324969155448, 73.61466326032365, 73.71779537200928, 67.81321620941162, 61.95344597952706, 58.308671133858816, 58.4988294328962, 56.548699378967285, 52.66154704775129, 50.38869401386806, 50.27877351215908, 53.61284923553467, 59.94840431213379, 56.310344900403706, 51.662041732243125, 54.68770081656319, 52.66420473371233, 52.743441990443635, 50.744222913469585, 59.88233389173235, 67.092757497515, 66.97293581281389, 64.1176986694336, 66.51514680044991, 69.80394458770752, 67.50135326385498, 66.98347623007638, 66.48421342032296, 62.95471613747733, 60.92524460383824, 57.927631923130576, 59.6234370640346, 59.11542647225516, 58.05585050582886, 55.66101142338344, 55.00664397648403, 54.428665024893625, 60.6093100139073, 65.29837131500244, 60.85167012895857, 54.53796018872942, 52.27966710499355, 48.54465600422451, 49.03272179194859, 53.15346908569336, 52.65941742488316, 53.759480544498985, 59.973654065813335, 60.30077525547573, 59.83124378749302, 58.9399288722447, 58.96980612618582, 59.8700008392334, 60.854796818324495, 53.40375362123762, 49.02274765287127, 46.66650928769793, 48.70880372183663, 49.07373700823103, 51.80314922332764, 47.83338975906372, 50.303637640816824, 51.402196475437705, 53.427287169865195, 54.3990135874067, 52.925536905016216, 50.010409763881135, 50.550500188555034, 51.957774434770855, 49.76604509353638, 48.74392339161464, 48.640815598624094, 48.721859386989046, 48.64558553695679, 47.47941378184727, 44.81454685756138, 46.27996015548706, 47.77259996959141, 48.91618660518101, 51.36405781337193, 50.461181095668245, 50.052616596221924, 51.7399970463344, 54.013676915849956, 51.52693748474121, 52.36227771214077, 52.959777627672466, 57.33378676005772, 63.003575869968955, 70.53033011300224, 67.86053344181606, 71.97574302128383, 67.07797867911202, 71.39865343911308, 71.39641611916679, 72.97648511614118, 70.14094611576625, 74.26623058319092, 68.9939444405692, 77.44257177625383, 66.22436468941825, 81.43464538029262, 70.22863933018276, 85.31142057691301, 2.8387564505849565, 5.0464088916778564, 7.2256041169166565, 0.5267734421151025, 0.4729604039873396, 19.927728857312882, 82.23418154035295, 70.44447122301374, 52.90081868852888, 59.68317072732108, 58.833412987845286, 34.15489155905587, 35.858332770211355, 59.8954381942749, 63.45502812521798, 78.91885553087506, 17.14780671255929, 0.8262522550565856, 0.43131252165351597, 0.3100111963493483, 0.1840666966246707, 0.17818094816591057, 0.19367996363767556, 0.15428838665996278, 0.17215623573533126, 0.24934169756514685, 0.0951563600184662], [0.023731022674058164, 0.060410664815987856, 0.05893474258482456, 0.04200114123523235, 0.04884499471102442, 0.043993387903485975, 0.019464486079024415, 0.050858476132686646, 0.05195054431845035, 0.14886693257306302, 0.05476992856711149, 2.42120315347399, 60.51877498626709, 68.91217109135219, 56.10218381881714, 51.341569968632285, 52.53635787963867, 36.18136147090367, 46.5279517854963, 53.50323445456368, 0.45046371115105494, 0.10350932965853385, 2.911575525999069, 2.000571152993611, 1.7380336863654, 26.328129734311783, 99.3405214037214, 79.15055016108921, 85.81481756482805, 73.54395839146206, 70.75544479915074, 64.4770872933524, 68.93915094648088, 58.196447304316926, 58.55873680114746, 64.2089979989188, 75.18445587158203, 76.72043854849679, 76.92081069946289, 74.69453144073486, 75.8631420135498, 72.65767397199357, 70.65090220315116, 68.36389568873814, 68.62071500505719, 69.2832396371024, 69.54216425759452, 64.17561885288784, 59.03016512734549, 54.441157885960166, 52.51818486622402, 50.636904512132915, 50.46305363518851, 46.05217041288103, 47.64793191637312, 46.01502881731306, 48.955044405800955, 55.681352274758474, 48.38552836009434, 49.60820286614554, 49.06142132622855, 49.93236412320818, 45.84456171308245, 47.6289633342198, 56.78972543988909, 60.10293224879673, 62.5834321975708, 60.27164145878383, 61.974158559526714, 61.25035081590925, 58.521265166146414, 60.189492906842915, 61.03853498186384, 56.11773041316441, 53.90897103718349, 50.10449532100132, 52.137569495609824, 53.813429832458496, 55.42798621313912, 52.34707505362374, 52.528565474918906, 52.01667431422642, 55.25367675508772, 54.84718976702009, 45.006018366132466, 47.1274527822222, 49.00771175112043, 47.864976269858225, 52.00950377328055, 48.2741938999721, 45.680455684661865, 45.71690593447004, 51.919555868421284, 56.88727467400687, 55.38854823793684, 53.914359365190776, 57.317507130759104, 55.233290740421836, 54.95376123700823, 49.65777478899275, 45.47000169754028, 42.6504157611302, 43.5037761415754, 45.124217646462576, 46.76803289140974, 46.64174938201904, 45.4291740826198, 47.88975354603359, 48.47907543182373, 47.535002844674246, 48.30203880582537, 47.53719847542899, 45.98991802760533, 45.701036248888286, 45.792610032217844, 42.785342829568044, 44.16626255852835, 42.01442977360317, 42.62069831575666, 40.836067404065815, 40.5414012500218, 37.12556954792568, 44.54390410014561, 46.19386502674648, 45.083542891911094, 43.95703840255737, 45.4140339578901, 44.96700423104422, 45.493125302451, 44.88673864092146, 47.50766863141741, 46.751471860068186, 57.57143599646432, 58.91620077405657, 64.09472792489188, 64.77753434862409, 65.92687061854771, 64.53987121582031, 63.31929506574358, 63.01102433885847, 66.07618740626744, 62.60163647787911, 66.85637283325195, 62.940069334847585, 66.46445274353027, 62.06356797899519, 67.81440435137067, 63.78655447278704, 74.00627762930733, 42.954479353768484, 0.26954681479505127, 1.6317403614521027, 0.4979919950876917, 0.10338231468839304, 1.1663135417870112, 52.59712335041591, 60.76617949349539, 48.124512331826345, 40.84749371664864, 39.05536569867815, 21.13319788660322, 18.97952904020037, 36.195490632738384, 53.06913879939488, 54.94241482870919, 15.042370523725237, 0.3591061362198421, 0.12834093613283976, 0.09023649937340192, 0.07046510851276772, 0.04099769650825432, 0.05728818236717156, 0.019910851859354546, 0.095425243090306, 0.08117266930639744, 0.04457300269444074, 0.04274519220260637, 0.06587051719959293, 0.04344157947759543, 0.05853376231555428, 0.04110365992944155, 0.09871480121676411, 0.027828773683203117, 0.0688151420493211, 0.04078802579481687, 0.1413978905017887, 0.143194990498679, 3.002068430185318, 72.0628386906215, 72.98448249271938, 64.64495577130998, 54.3195400919233, 57.267452308109824, 40.963744027274, 51.30045747756958, 60.537660190037315, 0.21174308152071067, 0.6424995980092457, 4.11536591393607, 1.1884260752371378, 0.563973283129079, 31.927396365574428, 104.46076011657715, 79.51390620640346, 90.46930462973458, 76.46416119166783, 74.6782031740461, 67.02971649169922, 71.69129071916852, 60.44262967790876, 61.6798745564052, 63.309025628226145, 76.18573992592948, 78.76360498155866, 79.4374690737043, 76.88051114763532, 78.0833763395037, 75.23401042393276, 73.7457549231393, 71.71501881735665, 71.81731019701276, 73.42251082829067, 70.69209807259696, 67.47100353240967, 63.21214689527239, 55.347769260406494, 55.806722096034456, 52.399936948503765, 53.00881106512887, 48.245567321777344, 50.506997517177034, 49.376824378967285, 50.642476967402864, 56.502452169145855, 51.10779435294015, 50.82977955681937, 50.527494703020366, 51.319950648716514, 48.55516862869263, 52.305559567042756, 60.6791741507394, 61.96738406590053, 65.9315745489938, 63.70335674285889, 64.20397445133754, 62.542076519557405, 62.96745218549456, 64.4757740838187, 63.231942313058035, 59.19515010288784, 57.142145020621165, 52.65997328077044, 55.36616114207676, 57.6945024899074, 60.37197344643729, 56.900514466421946, 57.24525628771101, 55.12174783434187, 59.27212919507708, 56.15654305049351, 49.287178720746724, 50.022141797201975, 51.06928743634905, 49.91034180777413, 55.592026233673096, 50.07672684533255, 47.1019355228969, 48.63270010266985, 55.71511009761265, 59.87398215702602, 58.62161105019705, 56.3214168548584, 59.75534166608538, 56.9880166053772, 58.323352677481516, 52.246663161686485, 48.25498213086809, 44.58931057793753, 45.430608885628835, 47.87811531339373, 49.337994371141704, 49.140404973711284, 48.8011348588126, 50.60069397517613, 50.74239901133946, 50.8827908379691, 51.03026635306222, 50.047155312129426, 47.56622110094343, 48.01077379499163, 47.85101039069039, 46.471251010894775, 46.652616364615305, 45.149043560028076, 46.01853765760149, 43.58812032427107, 43.05777474812099, 41.06860276630947, 45.193143776484895, 47.86673069000244, 47.21864094052996, 46.91172858646938, 48.12737498964582, 46.7595282963344, 49.227855001177105, 46.987012318202424, 50.20181179046631, 50.17257377079555, 60.40019008091518, 62.19664682660784, 66.81319672720772, 66.46833678654262, 66.74260302952358, 65.96339729854039, 65.4510440826416, 64.57627977643693, 66.94259302956718, 65.45574106488908, 68.3148136138916, 64.97662108285087, 67.87133094242641, 65.07390975952148, 66.3333819253104, 68.60212162562779, 75.32476084572929, 55.95315538133894, 0.7469342255166599, 1.5893521159887314, 1.1388120289359773, 0.203325271074261, 0.9232550242117473, 53.42140899385725, 68.2460194996425, 53.987846987588064, 48.60455642427717, 32.02890607288906, 19.009083202907018, 26.657231160572596, 44.83945962360927, 58.632443291800364, 63.44348021915981, 21.94909358024597, 0.4613042580229895, 0.22841380483337811, 0.0723937696644238, 0.16587050445377827, 0.08743832952209882, 0.08653796104980366, 0.018151410555999194, 0.051822966164244075, 0.10180780131902013, 0.10880636077906404, 0.11771619053823607, 0.14546144673866884, 0.1706594146255936, 0.127230310014316, 0.10283610756908144, 0.16255632229149342, 0.10189088793205363, 0.1515303725110633, 0.11183416723672833, 0.2848837689629623, 0.2717774850981576, 3.6954233050346375, 80.24588503156389, 81.65137359074184, 72.68550845554897, 63.70079285757882, 63.9693546295166, 47.569997446877615, 64.92799758911133, 67.06697968074253, 0.6036853864789009, 0.6473655083349773, 7.022855682032449, 6.644789431776319, 3.251380217926843, 33.2423221043178, 106.8245928628104, 83.80246639251709, 93.54800278799874, 80.9903428213937, 78.28172656467983, 68.63670975821358, 76.67196096692766, 65.14262744358608, 67.56210136413574, 67.84207207815987, 81.99428803580147, 84.92650427137102, 82.80954796927315, 79.58003221239362, 81.31631061008999, 79.85325622558594, 78.97164794376918, 77.11665957314628, 74.91980593545097, 74.82813835144043, 74.38935266222272, 70.75917598179409, 66.15487575531006, 59.53677218300955, 58.54452773502895, 54.677094391414094, 55.322481291634695, 51.801234994615825, 53.38279438018799, 52.12929766518729, 53.927692958286826, 59.29824052538191, 50.50252982548305, 51.221810817718506, 50.97645255497524, 53.70104272024972, 50.94067975452968, 54.206096853528706, 62.991854258946006, 64.970367704119, 66.5046967097691, 66.8767032623291, 66.61163643428257, 66.87650871276855, 65.37906769343785, 66.58000823429653, 66.64447362082345, 61.42177677154541, 58.33433083125523, 54.03650869641985, 59.17975984300886, 60.20603656768799, 62.091520581926616, 59.46785300118582, 58.741286822727744, 55.58826378413609, 61.72782407488142, 60.731778962271555, 52.3833064351763, 53.2804856300354, 53.04451090948922, 50.742173194885254, 56.89270469120571, 51.44414275033133, 51.352648871285574, 52.087921142578125, 60.12495803833008, 62.808303696768625, 62.02918829236712, 60.239999362400596, 63.6037334714617, 58.36282539367676, 60.58884062085833, 56.981738907950266, 52.513678959437776, 47.6409455026899, 48.521167618887766, 51.461204051971436, 52.410904679979595, 53.73187187739781, 51.75394902910505, 54.17060545512608, 55.94590493610927, 53.86841092790876, 53.79466274806431, 54.005686487470356, 51.90022945404053, 52.011730670928955, 51.67447900772095, 49.40414122172764, 49.021913869040354, 49.44068874631609, 49.40144879477364, 47.214472021375386, 47.79524414879935, 43.92969029290335, 48.825627258845735, 51.002577781677246, 49.121436391557964, 50.37800421033587, 51.74161945070539, 49.75232240131923, 52.90707206726074, 50.00012295586722, 52.80449233736311, 52.721061842782156, 62.67745522090367, 65.60574572426933, 68.9087039402553, 69.3005337033953, 71.30615207127163, 70.71948787144252, 68.87437983921596, 68.69533170972551, 72.02038519723075, 68.3840663092477, 71.72611509050641, 68.37554086957658, 70.512514931815, 67.99027715410504, 71.03888266427177, 70.68773460388184, 79.34136159079415, 54.61296599251883, 1.0367603621312549, 10.651565858295985, 1.610897611294474, 0.31386397246803555, 1.9755118233816964, 65.24941430773053, 72.79633917127336, 62.15784113747733, 57.50954839161464, 54.102026735033306, 29.304889133998326, 28.376646280288696, 52.58636406489781, 65.57664666857038, 74.65373161860875, 28.772730078016007, 0.7076005818588393, 0.3133713831858975, 0.21247767710259982, 0.21938415936061315, 0.12626638316682406, 0.22010568635804312, 0.13229884446731635, 0.1702408670846905, 0.15693843231669494, 0.18715939138616833], [0.08591551373579673, 0.03307607497221657, 0.0578427558232631, 0.07935922340090786, 0.04278067619140659, 0.10829399898648262, 0.009702745425914015, 0.011799632372068507, 0.06896473187953234, 0.03812611595328365, 0.05018419213593006, 3.08428407566888, 62.56359509059361, 56.454561710357666, 46.7719065121242, 31.532888071877615, 40.02186359677996, 57.42944261005947, 54.72819144385201, 36.33117505482265, 0.17717677062111242, 0.4442447748567377, 2.0213892587593625, 0.9694400259426662, 0.889250106045178, 75.51177855900356, 85.76210853031704, 83.6883978162493, 75.88969802856445, 71.87304864610944, 67.07270499638149, 65.99702657972063, 62.562288829258506, 62.624134744916645, 53.792960439409526, 56.400897298540386, 58.20868655613491, 70.54537296295166, 73.58083248138428, 76.24101284572056, 69.0801090512957, 73.23151179722377, 67.67878941127232, 69.57619653429303, 69.06784548078264, 67.69091401781354, 61.59247316632952, 57.29186827795846, 51.247011934007915, 51.45107705252511, 50.62843813214983, 52.76060404096331, 46.21042258398873, 45.3118884904044, 46.93986184256417, 43.842903818402974, 52.419728892190115, 56.18753201620919, 49.11281367710659, 50.477422509874614, 49.439587456839426, 51.08680384499686, 44.056658199855256, 50.61692844118391, 60.1032657623291, 58.615156173706055, 59.758364132472444, 60.730820110866, 63.57871995653425, 61.716679164341514, 60.50866535731724, 61.46124253954206, 59.55753340039934, 58.01298359462193, 54.86915302276611, 49.771968432835166, 52.23234292439052, 54.11119488307408, 57.38919169562203, 59.10583101000105, 54.32937526702881, 53.31870767048427, 54.204526560647146, 48.608641965048655, 42.82401997702462, 46.58700452532087, 46.3360355922154, 53.68671900885445, 54.125702721732004, 53.71423734937395, 43.36402007511684, 45.921700613839285, 44.08292586462838, 49.72979286738804, 55.48905740465437, 56.55864919934954, 55.304954460689, 55.856631006513325, 52.844680718013215, 49.29154913766043, 45.44320944377354, 46.942258971078054, 45.53841366086687, 47.08455807822091, 47.60380738122122, 47.98212289810181, 47.19669158118111, 47.31800365447998, 46.45614562715803, 49.38597863061087, 47.644027028764995, 49.50256245476859, 47.936174460819785, 43.72462115968977, 43.043037618909565, 45.535603114536826, 45.351983070373535, 45.524583271571565, 41.92125790459769, 41.76213026046753, 41.117924554007395, 37.420284339359824, 40.69116619655064, 45.15564087459019, 44.57274954659598, 44.5299972806658, 42.21377011707851, 47.16270794187273, 45.53226797921317, 47.63524450574602, 45.28870235170637, 53.67201314653669, 58.144763129098074, 63.889394760131836, 61.208557401384624, 63.625641141619, 62.142971992492676, 63.36456952776228, 59.35897472926548, 61.318012373788015, 56.56800494875227, 62.54056876046317, 58.956284931727815, 65.14252322060722, 60.845451491219656, 62.979180744716096, 58.676974296569824, 70.4477229799543, 63.27352033342634, 80.58443600790841, 12.768337164606367, 0.8002775545631136, 2.6752755429063524, 0.20588668648685726, 0.07477989234030247, 23.94663119316101, 71.49899237496513, 51.628332546779085, 41.08805077416556, 38.987488746643066, 41.88756608963013, 19.029236452920095, 32.516311781747, 47.83024569920131, 55.86711583818708, 22.547479391098022, 0.09673164013241019, 0.05697526237262147, 0.011629574533019747, 0.12218338011630944, 0.07760420614587409, 0.061016189466629706, 0.0653106647410563, 0.02344518810111497, 0.03246709318565471, 0.015068045651007975, 0.02290725232368069, 0.059428424308342595, 0.10308519098907709, 0.10850243815886122, 0.07727211075169699, 0.08415725986872401, 0.0340003991233451, 0.04883359532271113, 0.04005822745550956, 0.16655783328626836, 0.13446813449263573, 4.594777286052704, 72.37365245819092, 63.72199875967843, 55.76865986415318, 43.67139795848301, 32.83872904096331, 46.27563142776489, 68.07667105538505, 35.075333322797505, 0.17135183247072355, 1.0713998462472643, 1.7680872508457728, 0.3733465777976172, 1.8444114753178187, 83.41435391562325, 87.22436387198312, 87.02597195761544, 77.74369975498745, 73.30576024736676, 69.62123475755963, 70.18120397840227, 65.06142384665353, 66.34691701616559, 57.393183435712544, 58.21752119064331, 60.617043358939036, 71.14364760262626, 76.81810242789132, 78.21077156066895, 72.53811631883893, 73.5456190109253, 69.88018022264752, 73.69705499921525, 69.62208938598633, 67.20456096104213, 66.08690847669328, 58.25522211619786, 54.508037771497456, 52.85674279076712, 52.56611354010445, 53.650963578905376, 48.609868322099956, 48.92801938738142, 48.8879908152989, 49.062421866825645, 54.34249694006783, 55.17377594539097, 50.831697259630474, 50.8757175718035, 50.98982783726284, 51.3882132257734, 47.071898460388184, 51.00714274815151, 62.64382593972342, 61.45719868796212, 62.45111070360456, 61.32883071899414, 63.68519415174212, 64.11086164202008, 62.41871820177351, 65.37947068895612, 61.58676174708775, 63.07587882450649, 57.06276185171944, 52.21055684770857, 52.3909946169172, 57.154234886169434, 58.9220928464617, 61.98259367261614, 58.639398438589915, 56.03669704709734, 58.94564029148647, 51.45182745797293, 46.37590435573033, 50.1491687638419, 50.35534960883004, 56.199792112622944, 55.31080136980329, 55.84989125388009, 45.75030592509678, 47.70795392990112, 45.97230087007795, 51.76283230100359, 58.493097169058665, 59.88748945508684, 56.86062833241054, 58.1150734765189, 54.3269989831107, 50.73717744009835, 48.37702029091971, 49.11003787176949, 47.81120763506208, 49.32738447189331, 50.29736341748919, 49.20546095711844, 50.25624745232718, 49.97415058953421, 49.060966219220845, 51.468791484832764, 50.48940120424543, 50.44032260349819, 51.4052015713283, 46.174858229500906, 46.36035081318447, 48.152176584516255, 48.29479530879429, 47.4730909211295, 46.28032841001238, 44.02115290505545, 43.193480014801025, 39.43695381709507, 42.75392654963902, 47.72040510177612, 47.24415472575596, 48.32207046236311, 44.35193232127598, 49.15024014881679, 47.67386954171317, 49.93266289574759, 48.95350537981306, 56.21906641551426, 61.21908392224993, 66.88798018864223, 63.02490683964321, 66.42061655861991, 64.77608217511857, 64.61160441807338, 62.491896629333496, 63.662897382463726, 58.560161181858604, 65.16001183646065, 59.2204623903547, 67.06130300249372, 62.87343611036028, 65.98193509238106, 60.6362064906529, 72.1629135949271, 64.97479370662144, 84.23941775730678, 19.34356427192688, 1.1274347880056925, 1.2197760215827396, 0.263678925377982, 0.1269942612520286, 22.4606442792075, 80.36173234667096, 57.377886976514546, 50.59885617664882, 38.22155407496861, 32.602636201041086, 21.46026870182582, 40.36870377404349, 53.910739353724885, 62.954174177987234, 33.24881867000035, 0.0950192484472479, 0.019726071506738663, 0.03916911927184888, 0.10911023590181555, 0.03195573901757598, 0.05445767692955477, 0.09224066111658301, 0.024633866102833833, 0.06173452056412186, 0.022735440471608723, 0.17287385437105382, 0.1411101102296795, 0.14500196996544087, 0.20351667223232134, 0.1287387612142733, 0.21621071893189633, 0.10838098039052316, 0.09613560140132904, 0.16412524453231267, 0.22373084111937455, 0.23684462958148547, 5.5354348335947305, 84.27473545074463, 71.0524594443185, 61.53564385005406, 42.68973214285714, 49.34980283464704, 79.2131256375994, 74.0511907849993, 42.6474940436227, 0.22634632220225676, 1.4869419655629565, 5.99693809236799, 4.7112655724797925, 1.5493429771491458, 83.90108912331718, 91.40701961517334, 90.47204221997941, 82.52048901149205, 77.04582268851144, 73.06988974979946, 73.86263751983643, 70.7602460043771, 72.78298473358154, 60.76736068725586, 63.10677746364048, 63.74343395233154, 74.17217281886509, 80.47994204929897, 80.27301774706159, 73.98381410326276, 77.5437444959368, 73.26827471596854, 76.98356682913644, 73.15925053187779, 72.4744986125401, 67.9584127153669, 61.48431750706264, 57.67073270252773, 56.0501001221793, 55.55629859651838, 55.17310891832624, 51.245511123112266, 51.573143005371094, 52.62725073950631, 50.30359942572457, 56.8806426184518, 57.91249179840088, 51.01988921846662, 52.31207697732108, 53.45441293716431, 54.573396001543315, 50.68735885620117, 53.77217490332467, 66.03193432944161, 63.079776763916016, 64.51302337646484, 63.69085693359375, 68.69458825247628, 66.18329388754708, 65.67886161804199, 66.70964077540806, 64.21266664777482, 64.04426315852574, 60.54954855782645, 53.806926318577354, 57.8798839024135, 60.53541592189244, 63.23390865325928, 65.09093979426792, 60.17647893088204, 59.012975284031455, 61.83504867553711, 55.376427105494905, 48.5860846383231, 51.43737520490374, 50.04777717590332, 56.86732986995152, 56.303817067827495, 57.93381929397583, 46.74213695526123, 51.1109071459089, 50.12221670150757, 55.57005950382778, 62.94616290501186, 62.85429382324219, 60.614145960126606, 61.24283981323242, 57.37905774797712, 53.90557336807251, 51.20045552934919, 52.78885889053345, 50.74156175340925, 52.23455592564174, 53.46308776310512, 52.72999375207083, 53.20396164485386, 53.67534480776106, 51.74401657921927, 54.75019638878958, 54.5221391405378, 55.24455029623849, 55.53530461447579, 50.87148264476231, 48.42582791192191, 50.598873547145296, 49.43777050290789, 51.24435077394758, 47.82919304711478, 46.288933753967285, 45.87106214250837, 42.35912643160139, 46.114547865731375, 49.209522179194856, 49.88365725108555, 51.37949323654175, 47.50002213886806, 54.69444751739502, 52.470718247549875, 52.91462823322841, 50.568405696323936, 59.37454564230782, 64.43153490339006, 67.50327096666608, 65.01597567967006, 69.24148096357072, 68.11115496499198, 69.66904531206403, 64.62256172725132, 67.33467987605503, 62.107709884643555, 70.32774148668561, 63.09452084132603, 72.03489998408726, 66.28268092019218, 69.38341181618827, 64.4542624609811, 76.98265661512102, 69.00704179491315, 90.23512254442487, 16.890124082565308, 5.830804927008493, 10.361017380441938, 0.256167434155941, 0.25092124566435814, 30.15081146785191, 87.38613877977643, 63.79870687212263, 57.57632058007376, 54.021462372371126, 52.387562206813264, 30.10383469717843, 47.91342258453369, 64.03701618739537, 71.6012212208339, 42.92703396933419, 0.22201083627130302, 0.14292251797659056, 0.12232904801411287, 0.1599151383021048, 0.19056248877729687, 0.13156342107270444, 0.2190399928284543, 0.1340353919991425, 0.1229403130710125, 0.09988722151943616], [0.07964783148573977, 0.06068327983043023, 0.1374657257859196, 0.0443368148324745, 0.03800356574356556, 0.09663862655205385, 0.021963637421971986, 0.06209379807114601, 0.10446094788078751, 0.054931660781481435, 0.05671123082616499, 3.365676781960896, 56.2055139541626, 50.26855271203177, 53.27698721204485, 19.880781616483414, 61.26409435272217, 43.98508480616978, 69.81743798937116, 18.51990396635873, 0.25827832945755547, 1.6147166235106332, 2.016467979976109, 1.3291561922856738, 16.907466786248342, 102.12095424107143, 76.30429703848702, 85.11600943974086, 69.81470039912632, 72.43690190996442, 64.78278023856026, 69.43408502851213, 61.758861677987234, 63.05720901489258, 54.488999707358225, 56.07593699863979, 52.10344689232962, 57.65204552241734, 60.96193109239851, 69.27245603288922, 66.98919459751674, 71.01290334974016, 65.9515436717442, 67.3475409916469, 60.59796360560826, 56.01065867287772, 51.095079149518696, 50.415903159550254, 50.19214684622628, 51.23896592003958, 50.48509332111904, 51.65797356196812, 42.73536096300398, 45.14695562635149, 45.263126032693044, 47.630530153002056, 50.84715005329677, 51.53134959084647, 48.645324979509624, 49.10314525876726, 47.16031081335885, 49.51561117172241, 44.56803866795131, 51.747376033238, 57.90065901620047, 58.877950940813335, 59.56857408796038, 64.58570848192487, 63.303981236049104, 60.58217035021101, 60.670176233564106, 57.52515057155064, 59.876796177455354, 61.18875503540039, 61.92347839900425, 57.262779644557405, 45.24691241128104, 51.89544561931065, 58.795149258204866, 59.83831010546003, 57.12379482814244, 55.21266848700387, 54.21820061547415, 44.854467732565745, 42.23897123336792, 50.061715262276785, 49.225162574223106, 57.33334902354649, 54.94600009918213, 54.566597189222065, 48.00150837217058, 42.98461021695818, 40.28174359457833, 39.088758741106304, 49.67567682266235, 57.0212185723441, 53.36279051644461, 52.99050951004028, 46.9582849911281, 45.74375377382551, 44.34705468586513, 42.88912112372262, 43.44695029939924, 47.747496128082275, 47.56600570678711, 50.43275254113333, 48.52410323279244, 48.44041565486363, 49.63377571105957, 48.17275367464338, 48.722390924181255, 48.2865651675633, 48.36671611240932, 43.69518859045846, 43.456601347242085, 44.296068804604666, 47.14942298616682, 46.17469842093331, 44.16455677577427, 41.266480513981406, 40.890913009643555, 38.85923542295183, 37.8255797113691, 46.51776572636196, 43.926897117069785, 45.15464380809239, 44.160526820591514, 43.46027347019741, 44.75617504119873, 46.65473209108625, 48.09507976259504, 57.087351526532856, 61.0247289112636, 61.72680268968855, 61.44039099557059, 62.05269404820034, 60.68609455653599, 59.68103068215506, 54.9335732460022, 54.744669096810476, 55.61662285668509, 58.88797719138009, 58.433036940438406, 59.920583724975586, 57.923959800175254, 60.69222981589181, 55.73973798751831, 63.48904650551932, 66.39365059988839, 72.14557783944267, 52.602278913770405, 0.6314744896122387, 2.320989502327783, 0.23888232452528818, 0.3499357897256102, 4.82003527879715, 59.96851239885603, 60.13228143964495, 46.78103297097342, 38.98671402250017, 52.74272632598877, 22.767125844955444, 41.384784017290386, 49.88521017347063, 51.26289551598685, 31.04804277420044, 0.09992246462830476, 0.04987854603677988, 0.12195054761001042, 0.07907028961926699, 0.012049932914253856, 0.044570101957236014, 0.09250363414841038, 0.11637813305216176, 0.10512833456907954, 0.047513651328959634, 0.022412345844454, 0.09257046306239707, 0.1091190975691591, 0.030412061672125543, 0.10120291449129581, 0.028499624292765344, 0.10798280925623008, 0.021017062411244427, 0.04484697138624532, 0.01860751840285957, 0.05787301848509482, 4.234077189649854, 67.04858779907227, 55.24686404636928, 63.09639685494559, 27.158170223236084, 47.11184365408761, 48.26470960889544, 81.50211933680943, 17.597313472202845, 0.20783999881574086, 1.8051204979419708, 0.7459124603441784, 1.4711396992206573, 22.41958737373352, 107.19131878444126, 77.38100378853935, 90.40836197989327, 74.47646222795758, 76.6377202442714, 68.22484833853585, 70.91002832140241, 65.04716614314488, 65.10193879263741, 57.41578245162964, 58.380161149161204, 53.94235365731375, 58.34304387228829, 60.33336230686733, 70.35345676967076, 69.52797603607178, 71.71223258972168, 69.0759470803397, 67.50981616973877, 62.47073936462402, 59.17986406598772, 53.085738045828684, 54.51297099249703, 53.24893733433315, 53.01119777134487, 52.12843608856201, 53.30673592431204, 46.164352553231375, 48.64860452924456, 48.91839613233294, 49.73647356033325, 54.334662846156526, 54.55929115840367, 49.334968430655344, 51.12876401628767, 47.96642344338553, 50.95036901746477, 48.533101149967735, 54.08206803458077, 61.794714382716585, 61.1590792792184, 61.970489910670686, 65.6184470312936, 63.65687329428536, 63.52450316292899, 63.89656530107771, 61.04615020751953, 61.155487060546875, 63.075239590236116, 64.92985275813511, 61.59212575639997, 49.00259787695748, 55.999861172267366, 61.07804938725063, 62.4536190032959, 60.268702370779856, 58.6941293988909, 56.64767299379621, 46.982065200805664, 44.39036628178188, 51.84863907950265, 53.551395893096924, 58.05836227961949, 56.94076190676008, 55.65275348935808, 48.92832858221871, 44.68561955860683, 43.887108257838655, 42.83997304098946, 51.06270054408482, 59.07608577183315, 55.80505452837263, 55.71591261454991, 50.153591292245046, 48.332871437072754, 46.110038484845845, 46.196133613586426, 45.294476304735454, 49.04709414073399, 52.42207390921456, 53.84815345491682, 51.26848186765398, 50.48324857439314, 53.389377798352925, 50.51362957273211, 52.12241894858224, 50.3244822365897, 49.90179899760655, 47.34967701775687, 46.19148874282837, 47.15290750776018, 48.86571489061628, 47.3857798576355, 47.08416550500052, 45.17202125276838, 44.63364008494786, 41.383317947387695, 40.105433055332725, 49.01522970199585, 47.079659598214285, 47.26862628119332, 45.56684568950108, 47.001103264944895, 49.2189439364842, 50.569461822509766, 51.699464729854036, 59.92028495243618, 62.047510692051475, 64.77382401057652, 63.61486448560442, 63.816890307835166, 64.18566594805036, 61.92484024592808, 57.680196149008616, 57.54517180579049, 57.773871762411936, 61.0223456791469, 59.824566568647114, 62.21221079145159, 61.85269709995815, 61.86413383483887, 58.956604548863, 63.70128617967878, 69.69988141741071, 73.33941037314278, 62.944578715733115, 1.525582526411329, 1.6736218226807458, 0.4234116056135723, 0.5117336862853595, 4.367542965071542, 63.41715349469866, 69.38482230050224, 54.95867361341204, 44.860015869140625, 37.00752660206386, 25.212249040603638, 51.02023662839617, 54.96657371520996, 58.11757830211094, 40.84490898677281, 0.2503346928528377, 0.02108549775688776, 0.10274481746767249, 0.027469606438119496, 0.060415998101234436, 0.02334282091552658, 0.08601355526064124, 0.06350184644439391, 0.02110930415801704, 0.030690668150782585, 0.11960429565182754, 0.1507297419011593, 0.3187304527631828, 0.1444181991474969, 0.19130859231310232, 0.174159474670887, 0.18553884620113031, 0.19320435130170413, 0.20478102724467004, 0.12020041580711092, 0.13359861900763853, 5.5211158990859985, 79.4026655469622, 62.89291191101074, 67.61384459904262, 26.525717394692556, 82.85384273529053, 58.1536602973938, 87.98225947788784, 23.413254465375626, 0.3601890509682042, 4.1826900499207635, 6.922501112733569, 4.55537622315543, 20.387274026870728, 109.54083824157715, 82.24323504311698, 94.41309520176479, 77.10616084507534, 82.69923836844308, 71.36708082471574, 75.3665612084525, 69.18019090379987, 69.4110586983817, 61.35207939147949, 63.376666341509136, 56.96560519082205, 63.6308661869594, 64.98362486703056, 76.08407388414655, 72.96357536315918, 76.22462204524449, 69.67333235059465, 70.32134914398193, 66.23075703212193, 62.34743663242885, 54.919225215911865, 57.42462056023734, 55.548454080309185, 54.05961145673479, 55.24737821306501, 58.060780252729145, 49.07293449129377, 50.46917847224644, 53.23537792478289, 52.605089460100444, 55.926595892224995, 53.35791982923235, 49.89918647493635, 51.56617048808506, 48.439957073756624, 53.59713588442121, 49.791836806706016, 55.97635541643415, 64.02139663696289, 65.6153759275164, 65.33701024736676, 68.79946436200822, 67.1053545815604, 66.25558989388603, 66.45655264173234, 62.834387234279085, 65.1789665222168, 67.42357512882778, 66.65198462350028, 62.01345757075718, 51.8412218775068, 57.05093254361834, 65.46828256334577, 65.89332471575055, 63.49596691131592, 61.10869094303676, 62.31416170937674, 51.29355444226946, 48.83082103729248, 54.279094627925325, 54.8298088482448, 60.56236103602818, 59.19345474243164, 58.864332471575054, 49.94190399987357, 48.90961708341326, 49.177296434129985, 45.34752580097744, 53.6002973147801, 62.36656502314976, 58.87002304622105, 59.39872537340437, 54.16936520167759, 51.15638310568673, 48.95344632012503, 48.87132556097848, 49.44139746257237, 53.597101143428254, 56.46248613085066, 58.72019904000418, 54.207726206098286, 53.790893350328716, 54.825539180210654, 53.77786200387137, 53.92458363941738, 53.284133434295654, 54.28369433539254, 50.29119689123971, 50.9502717426845, 49.077575887952534, 52.50602204459054, 51.54106317247663, 52.13292115075247, 47.54959058761597, 47.92090579441616, 44.36339337485177, 43.604538917541504, 52.576775550842285, 48.02458333969116, 50.08958101272583, 48.41080938066755, 49.591145038604736, 51.45414468220302, 53.288618496486116, 53.727831499917166, 64.42494801112584, 66.55320208413261, 68.97309984479631, 66.16504096984863, 68.45673057011196, 67.068008014134, 65.15166704995292, 61.45418316977364, 61.10885769980294, 61.41603061131069, 65.05035536629813, 64.34759371621269, 65.17582593645368, 63.80146530696324, 65.78949778420585, 62.861367089407786, 68.87871551513672, 73.94021415710449, 77.6499685559954, 63.00321456364223, 0.9083659031561443, 7.391383358410426, 1.020226689321654, 0.35593004950455254, 6.261060399668557, 73.58418846130371, 72.17435032980782, 63.54165826525007, 52.468873500823975, 67.6168462208339, 35.00568805422102, 56.537929671151296, 64.452956199646, 66.10636343274797, 54.37322882243565, 0.7171032205224037, 0.12610362975725106, 0.22122559483562196, 0.12956908451659338, 0.18623571523598262, 0.17253603892666952, 0.2166477633374078, 0.15221390154744896, 0.19263947089867933, 0.16530280134507588], [0.08049657701381616, 0.0748204890904682, 0.02225845240588699, 0.1529989122812237, 0.04239193669387272, 0.03456013623092856, 0.02006520839807178, 0.016662141541019082, 0.09198104683309793, 0.03922500002330967, 0.12628401150660856, 2.7232982345989774, 56.6576714515686, 52.786729267665315, 47.65671443939209, 40.20107848303658, 49.04505484444754, 40.83224936894008, 75.96186896732875, 5.287550466401236, 0.1212547370897872, 1.7464647825275148, 0.9432796239852905, 0.14741530189556734, 56.45220627103533, 91.27720642089844, 75.59708854130336, 80.79967730385917, 67.48251669747489, 69.12280573163713, 64.27483218056815, 62.96525655473982, 61.35358715057373, 61.86715630122593, 55.184642927987234, 52.480588163648335, 53.769103799547466, 54.36522102355957, 54.62545190538679, 54.71064029421125, 56.999838965279714, 60.54948602403913, 57.25995520183018, 54.584749358040945, 52.92313630240304, 50.790101868765696, 50.48331805637905, 51.05783680507115, 53.46921607426235, 50.951980999537874, 51.28901032039097, 47.750119073050364, 45.847570283072336, 44.44758817127773, 46.36073643820626, 47.29689155306135, 52.7266377721514, 51.323879855019705, 48.429333278111045, 49.35883896691458, 47.13217755726406, 48.3429845401219, 45.122379847935264, 49.565606934683665, 61.48378944396973, 58.839020184108186, 57.249095167432515, 61.68409906114851, 61.528216225760325, 59.910592215401785, 60.19186919076102, 60.49680478232247, 59.202855655125205, 57.66957582746233, 64.96105711800712, 63.25328023093087, 51.918364252362935, 45.086287430354524, 54.30172143663679, 58.13361474445888, 57.59456654957363, 51.5607647895813, 46.311477184295654, 42.749326842171804, 45.65891279493059, 48.94330889838082, 51.96950299399239, 52.275442600250244, 53.69548763547625, 50.891340596335276, 47.72174957820347, 40.73343556267874, 39.0836900302342, 42.893752098083496, 52.02828127997262, 52.87174047742571, 50.227534021650044, 47.19572925567627, 44.28705699103219, 45.18471908569336, 42.90476499285017, 43.80762781415667, 40.74423653738839, 40.522470882960725, 45.76525844846453, 48.8447903905596, 50.71478687013899, 50.934547969273154, 51.483163833618164, 47.417925698416575, 48.0448442867824, 46.9914140020098, 46.76865128108433, 45.9508170400347, 44.03622007369995, 45.593957560403005, 45.59460374287197, 46.5146598815918, 43.20572968891689, 43.3352302142552, 40.998557976314, 40.49281597137451, 37.23385027476719, 42.596355301993235, 45.632363728114534, 44.354319027491975, 43.435746329171316, 43.72186619894845, 44.93534476416451, 47.132927962711875, 49.78230387823922, 56.26802689688546, 59.90757669721331, 60.53740310668945, 62.345602308000835, 59.53076893942696, 55.11244419642857, 50.61745997837612, 53.912233216421946, 54.79029096875872, 58.519090379987446, 58.7121947152274, 61.47572258540562, 59.67286654881069, 58.54744597843715, 56.32030166898455, 58.60915987832205, 56.26950338908604, 66.76845727648053, 64.76866149902344, 78.46410982949394, 19.483075414385112, 1.7923834728343147, 0.7266067819935935, 0.1331644651613065, 0.1428688322859151, 41.292824608939036, 61.602158955165315, 55.357597487313406, 40.33917393003191, 50.18605327606201, 24.199578625815256, 17.688538108553203, 48.31086649213518, 47.564140115465435, 31.371891362326487, 0.3835395851305553, 0.04569836659356952, 0.07833201637757675, 0.050862615196300406, 0.05459369945206812, 0.03550313366577029, 0.025041394235034074, 0.10422594406242881, 0.03974070020818284, 0.054945893053497584, 0.03322680134858404, 0.05715152541441577, 0.013911626052244433, 0.1572909312588828, 0.06305769777723721, 0.027965814008244445, 0.04213270917534828, 0.013873492384196391, 0.03708330601719873, 0.04597789587985192, 0.04622215830854007, 4.970039503914969, 69.4852237701416, 60.891052518572124, 52.508947236197336, 34.62236983435494, 43.758455412728445, 49.57630021231515, 81.23849078587124, 4.743159541061946, 0.17986623916242803, 2.69768174631255, 1.792673560125487, 0.3713770620524883, 62.84703990391323, 92.88568660191127, 79.90917532784599, 82.57481697627476, 69.77002348218645, 71.89943790435791, 65.00816590445382, 67.7229313169207, 63.92808927808489, 65.3070843560355, 58.19459560939244, 55.29618583406721, 57.60759442193167, 56.4957332611084, 55.71063893181937, 57.96268558502197, 59.58809852600098, 63.53550216129848, 58.6980551310948, 56.26153727940151, 52.862252712249756, 52.674026012420654, 54.256429604121614, 54.102874415261404, 54.65044110161917, 53.14383888244629, 53.48907402583531, 49.8913072177342, 47.78127479553223, 47.15782683236258, 48.61542340687343, 50.440517153058735, 55.34578554970877, 52.00311837877546, 49.519026211329866, 50.12614243371146, 47.44530160086495, 50.65947573525565, 46.45476640973772, 52.30842569896153, 63.454409735543386, 62.02851431710379, 60.60771887642996, 63.07569122314453, 62.676982743399485, 61.4204774584089, 61.24532726832798, 63.677731786455425, 60.47218036651611, 60.12756361280169, 63.547425270080566, 63.23210906982422, 55.724907057625906, 48.17271545955113, 57.84665066855294, 59.746712003435405, 61.36362729753767, 52.81634943825858, 49.98985351834978, 44.355159759521484, 49.36094427108765, 51.578222138541086, 52.39750507899693, 52.815946442740305, 52.85694081442696, 51.3412538255964, 49.017335006168906, 42.77785961968558, 41.8781304359436, 45.3853691646031, 53.5816205569676, 56.42889159066336, 51.15918322971889, 50.41342265265328, 48.53484514781407, 48.10119765145438, 46.014681407383506, 45.506594385419575, 43.45738301958357, 43.94699478149414, 48.26371949059622, 52.44720901761736, 52.43189518792288, 53.17151355743408, 51.90196997778756, 51.192916733878, 49.553885323660715, 50.15172222682408, 50.0374174118042, 49.93477167401995, 46.11011144093105, 48.64692653928484, 48.705343518938335, 48.12698936462402, 46.87486144474575, 46.36341149466378, 44.21849911553519, 43.25701781681606, 40.72957236426217, 44.5347706930978, 48.34333195005144, 46.2050655228751, 46.34429700034005, 44.69236625943865, 48.44841997964041, 48.85652242388044, 52.11898306437901, 59.13904339926583, 62.675780705043245, 64.08964879172188, 64.45865372249058, 62.54836463928223, 57.36091947555542, 52.75282900674002, 56.84825359072004, 57.80890110560826, 61.88711847577776, 60.16150556291853, 65.4483551297869, 62.02745819091797, 62.07210731506348, 59.420931816101074, 62.26996421813965, 56.86654124941145, 69.50932012285504, 67.28762667519706, 81.5358806337629, 26.311011110033306, 1.2875570016247886, 0.868351933147226, 0.4845086900251252, 0.07002747378179006, 41.63953971862793, 69.97933796473912, 62.36963612692696, 48.38706738608224, 44.143997056143625, 21.033093452453613, 21.8887745312282, 57.32656063352312, 53.14641319002424, 42.273507254464285, 0.6263314113020897, 0.0499401841578739, 0.028343065907912593, 0.031160848813929727, 0.04291030691404428, 0.09674681896077734, 0.04428345823128309, 0.057313512079417706, 0.05995280295610428, 0.11897971773786203, 0.21462125065071241, 0.2202797984438283, 0.1048682995938829, 0.34995438158512115, 0.15680622655366147, 0.14042485771434648, 0.16245299497885363, 0.14513954972582205, 0.1494232498641525, 0.1564109120517969, 0.36626017519405907, 7.033116434301649, 81.2561183656965, 68.99134581429618, 63.467708587646484, 52.05986084256853, 66.39904240199498, 55.24212190083095, 90.74773284367153, 6.761795358998435, 0.21617342664727143, 4.358884641102382, 5.856028624943324, 0.8082686343363353, 65.4384400503976, 94.79808098929269, 83.02801322937012, 85.4181101662772, 73.01890386853898, 74.13888399941581, 69.69954095567975, 71.59138257162911, 69.13784858158657, 69.97364044189453, 61.930134773254395, 58.702536719185964, 60.358389718191965, 61.069725445338655, 59.26992661612374, 60.5229925428118, 62.80115400041853, 67.00855227879116, 63.22976057870047, 59.668781008039204, 55.94678388323103, 54.68128762926374, 55.87781606401716, 56.179020472935264, 59.042928968157085, 55.700536251068115, 56.198298249925884, 51.503831250326975, 51.723859855106895, 50.83946534565517, 52.84463555472237, 53.539504051208496, 54.44449996948242, 52.35403020041329, 50.44324084690639, 51.642354011535645, 50.31106179101126, 51.801228046417236, 48.153211866106304, 54.24588918685913, 68.23613221304757, 64.65020860944475, 62.35839394160679, 65.47821153913225, 65.8351057597569, 63.77618776048933, 64.09549917493547, 64.5641621180943, 65.20311151232038, 61.884464263916016, 66.62930570329938, 68.22056824820382, 55.970609256199424, 50.09131806237357, 61.39246926988874, 63.176794460841585, 63.66849763052804, 55.38832936968122, 53.76942341668265, 48.08492497035435, 50.71482508523123, 52.546213899339946, 53.58023091724941, 53.97261306217739, 55.470033236912315, 51.73038073948452, 49.943283217293875, 43.826995917728965, 44.68056474413191, 47.6010593686785, 56.69178363255092, 58.754974773951936, 54.90294558661324, 54.21585559844971, 50.87566893441336, 50.56309379850115, 48.252883774893625, 48.18123395102364, 46.401223591395784, 44.91096353530884, 52.69384227480207, 54.11489132472447, 55.6125442641122, 56.20944316046578, 56.1405656678336, 54.10315581730434, 52.3368855203901, 52.999163491385325, 53.1425256729126, 53.56490319115775, 50.669602734701975, 50.74056121281215, 51.558892250061035, 50.31120770318167, 49.399916716984336, 48.957917485918315, 47.105367933000835, 47.06210844857352, 43.64349399294172, 48.43679911749703, 49.95573091506958, 49.0535420690264, 48.738093852996826, 47.29749952043806, 51.212197984967915, 53.02588626316616, 55.67254890714373, 60.68430886949812, 65.00856889997209, 65.65145792279924, 68.99817589351109, 66.62037726811, 62.35706683567592, 56.19148554120745, 59.9072014944894, 61.61643750326974, 66.62856224605015, 62.63200010572161, 68.82803535461426, 64.07363319396973, 63.84313365391323, 62.373360361371724, 65.23947143554688, 62.1150541305542, 71.81230054582868, 71.30154541560582, 86.9627433504377, 24.88653486115592, 2.8844367308276038, 3.725116865975516, 0.32670978030988146, 0.3319298859153475, 51.98151642935616, 75.09027303968156, 70.31755542755127, 55.36216592788696, 67.68980230603898, 37.08373097011021, 26.99379668916975, 65.45351764133999, 60.478079387119834, 59.50509534563337, 1.6201899583850587, 0.16009915699916227, 0.19979606116456644, 0.09040234690265996, 0.21594595456761972, 0.14979054086974689, 0.17375589561249527, 0.22134051152638026, 0.17466168557958944, 0.2203313128224441], [0.054780221943344386, 0.08042932062276772, 0.045657657885125706, 0.07399799608226333, 0.04028836617778454, 0.07446430570312909, 0.026242302830464075, 0.18218034213142736, 0.05925632747156279, 0.08824923993753535, 0.1420509261744363, 4.655063331127167, 50.99231876645769, 47.782052993774414, 37.34034878867013, 48.92492396490914, 43.852773734501426, 53.69627973011562, 65.4691024507795, 0.7372240094201905, 0.11387751437723637, 0.9806811256068093, 2.2541196048259735, 2.9498681340898787, 84.18115711212158, 79.12763500213623, 83.48075090135846, 70.79502173832485, 70.22457463400704, 63.75215394156319, 64.1754173551287, 63.14065687997, 65.22040557861328, 60.03617395673479, 59.94279016767229, 54.6238295010158, 53.983893462589805, 51.50836842400687, 50.831742422921316, 52.77508061272757, 52.68994780949184, 50.0478640283857, 52.277791091373985, 50.40335471289498, 51.81620488848005, 52.64054959160941, 50.85710334777832, 49.98831449236189, 52.341506072453086, 53.549492086683, 50.764390059879844, 46.584718567984446, 45.80356386729649, 47.01466614859444, 43.04986769812447, 48.215752601623535, 54.442745549338206, 47.76916061128889, 50.13651956830706, 47.46619135992867, 46.58536127635411, 47.20461252757481, 47.833778858184814, 49.30417748859951, 56.90883493423462, 60.37740693773542, 58.11002561024257, 59.3850930077689, 61.34425571986607, 59.35447924477713, 58.40432003566197, 61.50037479400635, 56.83761589867728, 59.382153919764924, 52.8943429674421, 50.959676129477366, 58.6374876839774, 47.99298293249947, 49.6616518838065, 51.93849318368094, 57.74868106842041, 50.56965637207031, 44.86162090301514, 43.176561151232036, 45.42401157106672, 47.54125622340611, 42.83586318152291, 42.60993208203997, 42.742517607552664, 42.9510087285723, 43.879913398197715, 39.89554534639631, 40.199779169900076, 43.064500604357036, 54.38818481990269, 50.33668327331543, 50.739515508924214, 45.45067875725882, 47.41172443117414, 46.139974798474995, 48.69188833236694, 45.96069737843105, 45.454406465802876, 43.88651418685913, 41.51855073656355, 44.05390323911394, 49.820779527936665, 50.29593903677804, 50.30202913284302, 49.405523913247244, 47.112184115818565, 46.021018164498464, 46.309364931924, 46.50744070325579, 44.51512118748256, 45.34658432006836, 47.38705137797764, 44.59130818503243, 46.119797229766846, 43.6271379334586, 42.10382529667446, 41.70515155792236, 38.40523665291922, 38.17036322184971, 44.92420332772391, 44.17234223229544, 44.272083623068674, 44.254522051130024, 45.2144330569676, 44.979709012167795, 49.73202323913574, 54.30706460135323, 60.84030287606375, 59.082040378025596, 58.43305083683559, 52.56056540352957, 48.92447928019932, 49.16882310594831, 54.27029126031058, 56.66815628324236, 61.78318037305559, 60.69985893794468, 60.184656960623606, 59.896633284432546, 61.150060517447336, 56.73077344894409, 57.82072693961007, 56.14642647334507, 63.49715505327497, 64.33045945848737, 72.61878490447998, 52.60585028784615, 0.6544021336095673, 2.4645325541496277, 0.24523539362209185, 0.4052755587867328, 15.484758853912354, 64.77180903298515, 52.94843816757202, 47.139462743486675, 34.01914112908499, 37.35762548446655, 31.960032054356166, 39.96520103727068, 50.41683421816145, 41.80070318494524, 0.8698209886040006, 0.044873732807380814, 0.014643888321838208, 0.06689143420330115, 0.03526975154610617, 0.04649044426956347, 0.008656758249604275, 0.03728813199060304, 0.028382353085492338, 0.03887461132502981, 0.020869650678443055, 0.05713598696248872, 0.056222448125481606, 0.061536802245037894, 0.027532299681167518, 0.24147622819457734, 0.05944199500871556, 0.07805956421153885, 0.05591646954417229, 0.08899650376822267, 0.15094364328043802, 7.974119220461164, 62.12446893964495, 54.6219812801906, 41.88318525041853, 34.77591460091727, 44.5321546963283, 64.15287045070103, 67.49820572989327, 1.0577999417270934, 0.21503390850765364, 2.085429285253797, 0.9041314103773662, 4.248857745102473, 91.6327040536063, 80.68801280430385, 87.81122956957135, 74.72845949445451, 73.30260576520647, 66.0968930380685, 69.97508566720145, 66.11982209341866, 68.10166372571672, 62.88805512019566, 62.561587061200825, 56.68750354221889, 57.51164327348982, 53.62515102113996, 54.7544903755188, 56.58376693725586, 55.70427785600935, 52.67423793247768, 54.5660274369376, 52.19985662187849, 55.00516748428345, 53.462445054735454, 53.58926010131836, 53.52223430361067, 54.566802161080496, 54.35184921537127, 52.41302388054984, 48.84052767072405, 48.953560965401785, 48.43217509133475, 46.4688504082816, 50.88960354668753, 54.9459479876927, 48.98138850075858, 49.41279867717198, 48.360004152570454, 46.11013575962612, 47.96751431056431, 49.992205483572825, 51.634766578674316, 59.42924880981445, 62.962852478027344, 59.07571751730782, 63.494806562151226, 62.76717036111014, 61.790093830653596, 59.6551764351981, 63.515359333583284, 60.75413826533726, 63.280829838344026, 53.41834136417934, 53.33616154534476, 60.535131045750205, 50.46171958105904, 51.98259687423706, 55.93794924872262, 62.149197578430176, 54.60229008538382, 48.55605104991368, 44.92903927394322, 44.6599702835083, 49.00223657063076, 43.576575892312185, 43.774370261601035, 42.0188627243042, 43.078185081481934, 45.428826672690256, 41.7074270929609, 42.704031535557334, 45.19064242499215, 57.0557268006461, 53.083128997257774, 55.13761404582432, 48.329894133976524, 49.647088459559846, 49.65140676498413, 51.10223926816668, 48.94689416885376, 49.16687413624355, 47.12740414483206, 43.39338663646153, 46.80316645758492, 52.75792898450579, 53.783073152814595, 54.281769684382844, 49.94097988946097, 49.42798049109322, 48.22017513002668, 49.65111494064331, 50.23472888129098, 47.34540040152413, 47.56646776199341, 48.777854919433594, 48.87825638907296, 48.99919325964791, 46.021806785038535, 45.32683406557356, 43.73282698222569, 41.214650426592144, 41.13970715659005, 46.79540531975882, 45.65794699532645, 46.430329595293315, 46.922536509377615, 49.47794846126011, 47.41148124422346, 52.717358452933176, 57.517497130802695, 62.928069795881, 61.66863931928362, 61.30309459141323, 53.6159724508013, 51.64465733936855, 51.999355929238455, 57.24903958184378, 60.0907381602696, 64.61783000401088, 65.08586066109794, 63.7212553024292, 62.8256186076573, 62.97853456224714, 58.56155776977539, 59.819626399448936, 59.62047018323626, 66.9349639075143, 67.6326881136213, 73.07778290339878, 60.58833340236119, 1.724715183888163, 1.9609334170818329, 0.7766167127660343, 0.4036739447287151, 15.862205845969063, 72.41528606414795, 61.55145795004708, 54.89720637457711, 39.09103775024414, 26.203955003193446, 31.83931405203683, 47.91155004501343, 55.40223618916103, 53.054200172424316, 1.0470495585884367, 0.07825853103505713, 0.02735717997087964, 0.017414341713967066, 0.04722147075725453, 0.02361222306665565, 0.025351584822471653, 0.010157735386331166, 0.020915841949837546, 0.029084653793168918, 0.07677526026964188, 0.1989433869187321, 0.17955382806914194, 0.18380772694945335, 0.07586406916379929, 0.23721198844058172, 0.17521124466189317, 0.36513502842613627, 0.174636091238686, 0.27139579557946747, 0.3966534957289696, 11.582178047725133, 75.1523551940918, 61.94118935721261, 50.303543840135845, 66.14679500034877, 64.70388344355992, 66.36284923553467, 78.53478690556118, 1.1316899082490375, 0.29461748951247757, 4.713156351021357, 5.135767936706543, 4.414643066270011, 93.53161893572126, 82.47799382890973, 90.87769195011684, 76.69926738739014, 78.26068047114781, 69.97744805472237, 73.42895875658307, 69.9882733481271, 71.89328180040631, 65.28753212520054, 65.81540761675153, 60.46971375601632, 61.91705131530762, 56.48637751170567, 59.20305020468575, 59.90832710266113, 59.70193781171526, 54.95478957039969, 57.20976488930838, 53.583545207977295, 56.90501689910889, 56.94199521200997, 55.665993281773154, 55.274458817073274, 57.170504093170166, 58.09872089113508, 56.11019509179251, 50.67799268450056, 51.62618555341448, 52.33643388748169, 49.55870737348284, 54.358356203351704, 57.9408335004534, 47.798989227839876, 50.42235108784267, 48.61626761300223, 47.292357853480745, 50.583413805280415, 51.926622186388286, 56.36343955993652, 62.73424979618618, 65.35851492200578, 61.406379563467844, 64.1312893458775, 65.42810807909284, 63.58675902230399, 63.188912119184224, 67.32895456041608, 63.47478185381208, 64.50848620278495, 57.57894352504185, 56.091334206717356, 63.329244886125835, 53.587842668805806, 55.364437988826204, 58.87762437547956, 64.78537191663469, 56.456045150756836, 52.23269380841936, 48.85636261531285, 48.20717505046299, 51.21208681379046, 44.858761719294954, 43.30136122022356, 42.4563421521868, 44.313064098358154, 46.543588706425254, 42.77379839760916, 45.31379924501692, 49.85206726619175, 62.41657815660749, 55.48263726915632, 55.88105045046125, 50.94421638761248, 54.386704853602815, 52.612121037074495, 54.37517431804112, 50.882300989968435, 50.57070902415684, 51.36889723369053, 47.60329321452549, 49.45586013793945, 56.99372455051967, 56.87758193697248, 56.0971429007394, 54.17042480196272, 51.640047209603445, 50.92254148210798, 52.048055853162495, 53.29171739305769, 50.578661237444194, 50.053568499428884, 52.171518393925254, 51.225524629865376, 51.47052158628191, 49.50232969011579, 46.37773520605904, 47.640785694122314, 44.713714599609375, 45.09801598957607, 48.851842812129426, 49.649565492357524, 49.159158161708284, 48.9636184828622, 52.33505467006138, 50.664353370666504, 55.771244594029014, 60.300059591020855, 67.49770545959473, 65.04945904867989, 65.8802273614066, 57.42597893306187, 55.123022828783306, 54.55476440702166, 60.1944191796439, 62.71037578582764, 66.16843863895961, 66.99678897857666, 65.2287712097168, 66.2576882498605, 65.45529638017926, 61.24832889011928, 62.41757869720459, 63.27571596418108, 68.96491486685616, 70.30388832092285, 77.25998701368059, 62.50144345419747, 1.25651972421578, 6.138290073190417, 1.1091067429099764, 0.44674243511898176, 21.575318711144583, 81.1670355115618, 66.32727445874895, 64.59029429299491, 45.86079270499093, 55.683996064322336, 44.01797063010079, 55.738105160849436, 63.391681398664204, 62.43330247061593, 2.0867177418300082, 0.17119973206094333, 0.09084641414561442, 0.08238209690898657, 0.12003535537847451, 0.10858210495540074, 0.07882354035973549, 0.15681611959423336, 0.13629572785326413, 0.08496148671422686], [0.00770475495872753, 0.13717783694820745, 0.031068279674010615, 0.16238887341959135, 0.050813353553946526, 0.30108080697911127, 0.06880820742143051, 0.19670770902718815, 0.02515416336245835, 0.14618149452975818, 0.1725893582084349, 6.772702293736594, 49.167982373918804, 51.65430838721139, 41.90307099478585, 52.56205579212734, 34.414674282073975, 71.15790530613491, 41.98755761555263, 0.17436389013060502, 0.5523935673492295, 11.730208550180707, 3.82904280935015, 14.916363205228533, 106.85152408054897, 68.50900186811174, 88.310165813991, 64.18028109414237, 71.98216315678188, 58.81314509255545, 68.3754574911935, 56.128420216696604, 66.06304836273193, 61.28812122344971, 63.11509445735386, 55.543635504586355, 55.630811078207834, 52.28598649161202, 53.53271566118513, 48.617355006081716, 53.41454764774868, 50.189117431640625, 54.687377725328716, 51.26177338191441, 52.56659991400582, 49.207267488752095, 52.13507161821638, 50.068611349378315, 51.91882978166853, 48.57777459280831, 49.74660055977957, 43.601485184260774, 46.35331228801182, 46.69858564649309, 45.443789618355886, 48.80073881149292, 52.135898453848704, 48.368786675589426, 48.21402597427368, 45.64928953988211, 45.96524844850813, 44.00003038133894, 48.32417924063546, 45.475157260894775, 53.489654200417654, 58.370926993233816, 58.95283167702811, 58.919848578316824, 61.29372841971261, 59.23993124280657, 59.743821552821565, 56.46770422799246, 60.064731052943635, 60.85791655949184, 52.751599175589426, 57.36248629433768, 58.45875917162214, 50.03647593089512, 46.21327134541103, 53.60156536102295, 55.587221554347444, 50.33864961351667, 43.29715756007603, 39.52435520717076, 42.966836724962505, 43.39796549933297, 46.55714464187622, 46.606754779815674, 50.44850410733904, 48.420245034354075, 46.28114482334682, 42.747106892721995, 40.036798749651226, 38.28809002467564, 51.88512059620449, 53.615194252559114, 51.92017425809588, 51.5443184035165, 49.61007193156651, 49.58439833777291, 47.31254584448678, 49.937495367867605, 49.33408600943429, 49.32280560902187, 48.065831320626394, 42.70789473397391, 44.46381221498762, 47.23177998406546, 49.78315155846732, 49.07107932226998, 48.185430662972585, 45.37394632611956, 46.08403137751988, 43.328660692487446, 47.57182134900774, 42.84864091873169, 46.023033142089844, 47.407541615622385, 46.25045463017055, 44.654255390167236, 43.23174721854073, 42.34246117728097, 39.04700354167393, 36.81111145019531, 42.351215907505576, 46.41726698194231, 43.84669753483364, 44.41229132243565, 45.000657830919536, 45.593366963522776, 47.703100613185335, 52.705077511923655, 52.680234227861675, 54.718342372349326, 49.37383665357317, 46.57563727242606, 46.744144984654014, 48.86803558894566, 55.896333013262065, 59.49328340802874, 60.12051119123186, 61.99679579053606, 61.39935493469238, 61.50165326254708, 58.03681244168963, 56.373490129198345, 55.65728024074009, 59.28560175214495, 61.5479074205671, 70.29967771257672, 65.53629847935268, 77.65930693490165, 11.298270310674395, 1.205085467014994, 2.723888180085591, 0.2080890890210867, 2.8565110521657124, 57.19925226484026, 61.862243924822124, 51.515097754342214, 36.15484019688198, 30.467614582606725, 20.58695830617632, 30.8211076600211, 45.951543126787456, 42.75627851486206, 1.0347805597952433, 0.06093242431857756, 0.061450397595763206, 0.1236555025513683, 0.06754396097468478, 0.08683260131095137, 0.05569131126893418, 0.10207407881638833, 0.10057439428887197, 0.10399484182042734, 0.011638549854978919, 0.08396976028702088, 0.01835442484090371, 0.12214407936802932, 0.05068252860967602, 0.19971545120435102, 0.036731383829776726, 0.23770240641066007, 0.04124412007097687, 0.2100104559212923, 0.44121522456407547, 11.853139553751264, 61.57424109322684, 61.78091526031494, 51.87271458762032, 47.6627767426627, 40.63453490393502, 81.55589144570487, 41.038166182381765, 0.28504965720432146, 0.5285994069916862, 14.810939925057546, 8.550252556800842, 17.944580963679723, 110.92939404078892, 72.03853389195034, 90.26927294049943, 65.03387423924038, 74.90569414411272, 59.72497803824288, 70.56030464172363, 58.23712205886841, 70.57065050942558, 63.02168982369559, 66.00289780752999, 57.69636113303048, 58.5869117464338, 52.784158434186665, 57.18366398130144, 53.22971861703055, 57.54595695223127, 52.60499913351876, 57.13817759922573, 53.0682772227696, 54.72635364532471, 50.96221917016165, 54.30544567108154, 51.27616657529558, 54.6188302721296, 50.87520340510777, 51.24698066711426, 47.084314891270225, 49.694930280957905, 47.43405941554478, 47.72124235970633, 52.189253670828684, 53.25434650693621, 48.8026738848005, 50.06872599465506, 46.03955595833914, 47.88868004935128, 46.56273794174194, 50.65606416974749, 46.1215238571167, 56.37437949861799, 62.32558454786028, 61.084031786237446, 60.91262667519705, 62.503180503845215, 61.29358945574079, 62.53876222882952, 59.37828377314976, 60.83514036451067, 63.94709954942976, 53.31640781675066, 59.03870446341378, 61.68097931998116, 52.594045298440115, 49.706043924604145, 55.45895433425903, 57.102046966552734, 53.31337145396641, 46.076843466077534, 40.77222040721348, 43.52043097359793, 44.34568241664341, 47.32401384626116, 49.51164027622768, 52.14146396092006, 51.1579464503697, 47.00276388440813, 44.825448581150596, 40.81080722808838, 41.75006471361433, 56.44316666466849, 57.00580051967076, 54.60257843562535, 53.62114885875157, 52.56823968887329, 51.68660708836147, 49.97305972235543, 52.59956216812134, 52.31948375701904, 53.36669192995344, 50.80842079435076, 46.751110553741455, 45.80003765651158, 50.42366429737636, 51.9129307610648, 50.19430773598807, 49.74282768794468, 47.36485883167812, 48.77339417593819, 48.91291400364467, 48.90048367636544, 47.38661016736712, 48.470862661089214, 50.25050476619175, 48.65144286836897, 46.92960630144392, 44.98260988507952, 44.89419405800955, 41.63675001689366, 38.97615623474121, 45.04033204487392, 46.51331540516445, 46.645327704293386, 46.618733474186485, 47.21550382886614, 48.72645909445626, 48.93989385877337, 55.04980271203177, 55.070987769535606, 55.15366438456944, 51.668295110974995, 49.35826226643154, 49.13142442703247, 51.686217989240376, 57.21504899433681, 61.84692314692906, 61.75509575435093, 65.70885699135917, 64.86927141462053, 64.69498974936349, 61.566375732421875, 58.7181910106114, 57.51801477159773, 61.88191427503313, 63.54489612579346, 72.74365098135812, 68.59709112984794, 80.19132777622768, 17.37866755894252, 1.1477887758186884, 0.8776477000543049, 0.16938602152679647, 2.503464613642011, 57.60018416813442, 69.91975021362305, 56.89252403804234, 45.278432914188926, 28.6712429523468, 20.82504527909415, 40.156293869018555, 51.04093531199864, 49.47154917035784, 1.6702930927276611, 0.07425423804670572, 0.044601670798978636, 0.05413126087348376, 0.04574552817004068, 0.04708471202424594, 0.027873882691242864, 0.14169344678521156, 0.12191659371767725, 0.07384763272213084, 0.08770319566662822, 0.2069897401545729, 0.11717562883027963, 0.25142754135387285, 0.17007455815161976, 0.38048604183963364, 0.3034677303263119, 0.4070149154535362, 0.18442095975790704, 0.3340025118419102, 0.6675721726247242, 15.890637874603271, 73.66437067304338, 69.4351828438895, 53.48313679013933, 69.32433823176792, 50.756726196834016, 84.81103215898786, 50.56574106216431, 0.38044763675757814, 0.767827567245279, 20.221580335072108, 8.258880717413765, 18.144416366304668, 116.49021107809884, 73.98821926116943, 94.01991053989956, 67.0039039339338, 79.01495606558663, 62.773152760096956, 75.67164966038295, 59.74384934561593, 73.29593549455915, 66.80465044294084, 68.68729959215436, 61.166444369724815, 63.7814336504255, 54.55578926631382, 61.5718161719186, 55.60066979272025, 61.61521462031773, 56.046844891139436, 62.43838855198452, 56.640419074467246, 58.04016842160906, 54.85497522354126, 57.30640390941075, 53.295914105006624, 57.68061304092407, 53.62198959078108, 53.89540120533535, 49.936362811497276, 53.63947473253523, 51.264497075762065, 50.735193729400635, 55.90467085157122, 53.79011515208653, 48.027157647269114, 50.1558564049857, 46.63271672385079, 47.745710441044395, 47.073673725128174, 53.91746520996094, 50.30727154867989, 59.43299388885498, 63.83519186292376, 64.71676540374756, 63.9316189629691, 66.26598439897809, 63.60456725529262, 67.05331257411412, 60.53057997567313, 64.8149642944336, 66.74263777051652, 55.65822866984776, 60.036278179713655, 64.90702792576381, 55.65660973957607, 51.26648773465838, 59.407528741019114, 62.11055864606585, 56.6728914805821, 50.60247271401541, 45.02078676223755, 44.17381872449602, 44.448852743421284, 47.101226806640625, 49.76346036366054, 52.82998527799334, 50.658384868076865, 47.69158744812012, 47.917087759290425, 42.78388718196324, 44.7695711680821, 60.186387062072754, 59.79055513654436, 56.92997830254691, 56.77769463402884, 55.86882162094116, 55.18265574319022, 52.96949815750122, 55.49509538922991, 56.500249590192524, 54.79888589041573, 52.30701868874686, 48.19086415427071, 48.973300797598704, 52.92745460782732, 54.23268413543701, 53.124550683157786, 52.95041840417044, 50.89023583275931, 50.95838723863874, 51.00306068147932, 53.08708599635533, 49.518769127982004, 51.50607204437256, 52.18046767371041, 50.42126716886248, 49.78898457118443, 47.566592829568044, 48.60742603029524, 44.20654821395874, 42.81631095068795, 47.875367300851, 50.928179945264546, 49.149357727595735, 49.04865748541695, 48.89648151397705, 50.870812143598286, 52.52646017074585, 58.10705525534493, 59.112626348223, 58.9765875680106, 55.60882350376674, 52.227979455675396, 52.752259254455566, 54.51982191630772, 60.92473043714251, 66.0816764831543, 65.33893489837646, 69.31692450387138, 66.40250955309186, 68.28604807172502, 64.62356921604702, 62.52146121433803, 62.112441607883994, 67.1527829851423, 66.69932964869908, 76.7128997530256, 73.20043250492641, 84.80741214752197, 15.69938349723816, 2.6605314654963355, 6.938965737819672, 0.23160959620560917, 4.0848211986677985, 67.81642627716064, 73.23457595280239, 65.72928469521659, 52.62171649932861, 45.63189125061035, 31.671435151781353, 48.78705433436802, 60.30290835244315, 60.80069119589669, 2.6040660611220767, 0.16837106884590217, 0.16928767466119357, 0.23615616081016405, 0.14178722032478877, 0.20052019373646804, 0.1482545682894332, 0.14982872882059642, 0.27908131746309145, 0.2549262307584286], [0.07419975847005844, 0.05726159057979073, 0.05574505802776132, 0.12036603263446263, 0.007724511353964252, 0.10897188939686332, 0.0986336280724832, 0.10424661223909684, 0.04123703955805727, 0.26900102836745127, 0.29549695232084816, 12.990997399602618, 53.12835134778704, 38.48099633625576, 25.769664798464092, 36.06193930762154, 38.7614221572876, 85.10645566667829, 22.37673088482448, 0.10446855425834656, 0.6950780280998775, 1.0949789924280984, 8.889808416366577, 37.94497408185686, 91.72437858581543, 70.5216657093593, 84.66710717337472, 65.03802231379917, 68.20764459882463, 58.8762903213501, 62.461984634399414, 58.16612536566598, 65.03584057944161, 60.71082319532122, 67.16087763650077, 61.59957422528948, 57.680265630994526, 51.27665989739554, 54.798107692173545, 49.53472914014544, 52.13741316114153, 50.51514775412423, 52.501168727874756, 49.263940470559255, 51.993766103472026, 49.49062892368862, 50.551761286599294, 47.02670737675258, 51.38586820874895, 49.44833523886544, 47.36541468756539, 42.878639766148154, 44.89306150163923, 45.218216351100374, 45.84879316602434, 50.804481165749685, 51.89272539956229, 47.4235189982823, 49.891557352883474, 47.16745008741106, 47.53822333472115, 44.39773137228829, 48.372437953948975, 46.516174588884624, 50.406686374119346, 55.951651096343994, 59.727604457310264, 58.144172532217844, 60.337190764290945, 58.91626330784389, 59.01943710872105, 55.15218094417027, 58.43440573556082, 57.45727709361485, 52.61718627384731, 59.0148651940482, 57.30418048586164, 49.881694384983604, 50.73928621837071, 52.08731664930071, 53.4165278843471, 49.193093163626536, 45.52500711168562, 36.97158704485212, 47.10400261197771, 52.2022294316973, 57.54232651846749, 56.95608268465315, 59.562695911952424, 53.71854523250035, 51.504397528512136, 48.094120911189485, 44.882114614759175, 36.290632316044395, 46.54328645978655, 54.75184658595494, 55.305673599243164, 52.73722335270473, 52.27037736347744, 46.970763955797466, 48.223013469151084, 49.309312207358225, 53.533747468675884, 53.56222813470023, 51.28482403073992, 49.3844222341265, 45.805429458618164, 45.462285723005024, 46.84286151613508, 47.23074470247541, 45.26710040228707, 44.564814703805105, 47.08331087657383, 49.44968318939209, 47.098044531685964, 45.5424679347447, 47.65771497998919, 47.712637015751426, 45.20903083256313, 46.61359180722918, 43.52690322058541, 41.632410866873606, 41.0421370778765, 38.02436419895717, 40.21125411987305, 45.91632270812988, 44.36701338631766, 45.54711627960205, 44.59769705363682, 45.626363958631245, 46.584218297685894, 46.414921964917866, 45.930781909397666, 45.315657888139995, 45.95501027788435, 47.79424013410296, 45.163655621664866, 49.118983677455354, 52.77511535372053, 59.78951290675572, 59.576418604169575, 61.93484565189907, 60.7415064402989, 60.37350899832589, 56.752229486192974, 54.198679651532856, 52.42382138116019, 61.99781717572893, 65.00137751443046, 69.73588003431047, 62.67269570486886, 72.99428640093122, 43.40092543193272, 0.17804305627942085, 0.9356903455087117, 0.12697873637080193, 0.044782513952148814, 31.025308268410818, 69.28112043653215, 52.935062885284424, 38.32935190200806, 23.155618735722133, 18.49139724458967, 29.716406617845806, 44.35338796888079, 29.072728974478586, 1.5696908852883746, 0.08353762168969427, 0.04521544982812234, 0.03592821889157806, 0.019104436738416553, 0.07781048079154321, 0.055978144984692335, 0.03433933075783508, 0.024514199666944996, 0.0510303456602352, 0.06417973685477461, 0.0628333469586713, 0.01871407893486321, 0.13136300896959646, 0.03492145612835884, 0.1146117706916162, 0.0262831540312618, 0.17375254364950315, 0.03350916012589421, 0.2819986380636692, 0.2984401929591383, 21.713481903076172, 62.84857545580183, 43.95246648788452, 31.295332636151993, 35.2668708392552, 46.17120695114136, 93.92766625540597, 23.75058603286743, 0.15511313240442956, 0.634808593562671, 0.457316697708198, 9.380192296845571, 42.22100666591099, 94.92956869942802, 73.98399475642613, 87.08273874010358, 67.8432115827288, 70.69469669886998, 61.12141309465681, 68.44213240487235, 62.92440114702497, 68.08716283525739, 64.85648672921317, 68.76580033983502, 62.150337082999094, 59.98889146532331, 54.59289959498814, 58.644526209150044, 53.00097002301897, 55.98589529309954, 52.13138907296317, 53.75681938443865, 52.177393095833914, 54.11185148784092, 50.96053423200335, 53.2206130027771, 50.06613084248134, 53.3797093800136, 51.35170044217791, 50.479618140629356, 45.99418074744088, 48.324040276663645, 48.44298301424299, 49.041268076215474, 54.01198155539376, 53.28055511202131, 47.16485493523734, 49.20901843479702, 46.56090014321463, 47.217807156699045, 44.23743643079485, 49.29277549471174, 48.90646260125296, 53.662900584084646, 57.131913798195974, 60.454080309186665, 59.15309265681675, 62.65372017451695, 61.85932568141392, 60.28867149353027, 57.61324678148542, 60.32546220506941, 59.70381382533482, 56.500968728746685, 59.8826813016619, 60.913724490574424, 54.09193795067923, 54.17433663776943, 54.97759703227452, 57.969272477286204, 53.70650747844151, 48.76914882659912, 39.30426059450422, 49.925266538347515, 53.05072954722813, 58.64301150185721, 59.83696910313198, 61.05176435198103, 58.70967946733747, 52.99139193126133, 50.74128035136631, 46.45208787918091, 39.567795344761436, 47.12352010181972, 54.44017818995884, 58.45784895760672, 54.055644035339355, 54.759889125823975, 50.89423452104841, 52.65340723310198, 53.97222743715559, 55.58235086713518, 56.351023129054475, 54.7673271724156, 51.99620492117745, 48.2663493837629, 48.20790113721575, 50.17834424972534, 49.93723133632115, 47.54159321103777, 46.4268832887922, 49.859446253095356, 51.38099752153669, 50.761200836726594, 49.887398856026785, 49.59520973478045, 49.300599166325156, 48.151120458330425, 49.93271848133632, 46.75354242324829, 43.29179007666451, 44.663472175598145, 41.07623883656093, 42.329777240753174, 47.43729380198887, 46.68827451978411, 47.79890237535749, 46.61258431843349, 46.82896859305245, 49.546089444841655, 48.29209245954241, 48.200404030936106, 47.39595896857125, 48.535991600581575, 49.77610608509609, 48.0035719871521, 51.530310835157124, 55.96473455429077, 61.32949774605887, 63.42200333731515, 64.3840022768293, 62.8395219530378, 61.02810573577881, 58.40566798618862, 55.16463559014456, 55.02368443352835, 65.38302816663469, 67.94209139687675, 72.04166058131626, 64.33786623818534, 75.87127140590123, 50.83964252471924, 0.4193746750908238, 0.7270488068461418, 0.310292299836874, 0.02722402086614498, 30.153590747288295, 75.73085526057652, 61.327461923871724, 48.36475324630737, 27.1501658984593, 25.183684996196202, 39.88732215336391, 52.328137738364084, 36.28364242826189, 2.2902893211160387, 0.1854309727038656, 0.06111084510173116, 0.08445983898958989, 0.0642652865499258, 0.09891021930213485, 0.027342618609379445, 0.10443220513739757, 0.04970531265384384, 0.024963537430656806, 0.15280615405312606, 0.3264404833316803, 0.10685881599783897, 0.24214694648981094, 0.12904539118920053, 0.236234789448125, 0.24841346165963582, 0.35342929512262344, 0.2023318958069597, 0.5586390207920755, 0.5824909380504063, 24.026342664446148, 73.70298876081193, 52.52090161187308, 36.04997450964791, 50.239074979509624, 53.84036105019705, 100.11213970184326, 27.647007261003765, 0.21038955343621119, 1.3398667318480355, 4.24065192256655, 14.02451935836247, 42.71540226255144, 98.73024722508022, 74.00199059077671, 91.43812670026506, 72.50864206041608, 74.02734456743512, 65.39966910226005, 72.06725774492536, 62.868183272225515, 73.02841595241001, 66.89948640550885, 73.00511169433594, 64.93449415479387, 63.552990777151926, 58.50386687687465, 60.34922504425049, 53.84963689531599, 58.209892068590435, 54.876535483769004, 58.55028779166085, 53.519361223493306, 56.57462658200945, 53.51039457321167, 55.629859175000874, 50.79994746616909, 55.937997886112754, 53.62536988939558, 53.41341509137835, 48.13346855981009, 51.44062696184431, 51.39261838368007, 51.24030692236764, 56.74669872011457, 52.27026619229998, 47.044397490365164, 50.292405877794536, 47.7305668422154, 49.325758593423025, 46.04525695528303, 52.69640963418143, 51.01365321023123, 55.868977955409456, 59.91606044769287, 63.32672963823591, 60.89566612243652, 63.61341231209891, 64.90945284707206, 62.77787753513881, 59.61294528416225, 63.61486448560442, 62.200433594839915, 57.96126815250942, 62.84164115360805, 63.34255763462612, 56.73185389382498, 56.82133626937866, 57.31398091997419, 61.2256360735212, 55.263845443725586, 50.882610184805735, 41.864487648010254, 51.33470862252371, 54.78182111467634, 62.736021586826865, 63.17537702832903, 62.783470835004536, 59.76153251102993, 52.93233919143677, 51.619817529405864, 46.77639504841396, 41.63680212838309, 51.84945549283709, 58.29818630218506, 61.60862077985491, 55.555923393794465, 58.73405374799456, 54.24947098323277, 54.75357321330479, 54.77675935200283, 57.6520003591265, 58.577107838221956, 56.76965209415981, 55.238376821790425, 51.4594600541251, 51.56709459849766, 53.00943292890276, 52.62121622903006, 51.42522280556815, 49.57331943511963, 52.830155508858816, 53.169766085488455, 54.02187579018729, 53.42293759754726, 52.65441124779837, 53.41255004065377, 49.68106515066964, 52.180714334760395, 48.87957654680525, 46.77349417550223, 46.9082475389753, 43.885763781411306, 46.54628460747855, 51.04358952386038, 51.64895132609776, 52.62835202898298, 50.12337357657296, 51.28796114240374, 52.74127067838396, 51.628454140254426, 49.839960030147004, 49.78305080958775, 51.51035213470459, 53.15503590447562, 50.556579862322124, 54.468915939331055, 58.89737115587507, 64.90039239610944, 65.29793357849121, 68.29057829720634, 65.78320271628243, 65.31790964944022, 62.698716708592, 59.05012730189732, 57.09065886906215, 69.59758308955601, 71.3128640311105, 74.73173209599086, 67.17916529519218, 78.88152285984584, 50.64910554885864, 0.37998115750295774, 4.853632424558912, 0.23319693388683455, 0.0758108448769365, 38.886840615953716, 81.213456426348, 67.1761497770037, 54.34411934443882, 36.726294789995464, 28.81241124016898, 44.20664896283831, 62.96084444863455, 48.21857704435076, 2.795442683356149, 0.23182482751352446, 0.2408434807189873, 0.159236806843962, 0.16162462585738727, 0.17489640441324028, 0.13009817898273468, 0.189775143883058, 0.13519728822367533, 0.13293483534029552], [0.026261861602376615, 0.05014382269499557, 0.08928397869957344, 0.10149324605507509, 0.04394956471930657, 0.022837417499561394, 0.027747807492102896, 0.07471389123903853, 0.025603601210085408, 0.10538089208837066, 0.06263038356389318, 29.83786460331508, 57.854554244450156, 37.29478250231062, 41.53662994929722, 39.116322244916645, 45.74935054779053, 80.86986105782645, 11.541447707584926, 0.6680758084569658, 1.043219472680773, 1.381176920873778, 2.5241947812693457, 56.76670258385794, 72.34927122933524, 81.7552352632795, 77.05346570696149, 68.99644579206193, 62.12537220546177, 59.414963313511436, 58.69381672995431, 61.13770662035261, 62.420239857264924, 63.90936388288225, 68.45396518707275, 65.31242752075195, 63.04072788783482, 52.49696854182652, 51.627519607543945, 51.25281367983137, 51.280609948294504, 50.862345763615195, 50.41544457844326, 49.77543905803135, 47.81289257322039, 50.80681923457554, 49.063776765550884, 50.69970233099801, 50.04061705725533, 49.47537415368216, 46.44876316615513, 44.97748906271798, 45.33178465706961, 45.85040862219674, 45.42157275336129, 54.662492752075195, 48.83108159473964, 48.123525687626426, 46.670685155051096, 47.35717759813581, 46.26227004187447, 45.097831862313406, 46.39663083212716, 45.51753085000174, 47.90265982491629, 52.14760616847447, 58.04131140027727, 55.62273727144514, 58.978470529828755, 59.9589238848005, 55.61478853225708, 53.36412804467337, 58.122452463422505, 55.88481289999825, 57.391349111284526, 59.26085226876395, 56.643292154584614, 54.87086575371878, 53.532712187085835, 55.090418406895225, 53.99070617130825, 50.64816754204886, 42.11005435671125, 40.02930859157017, 53.87076984133039, 58.08215291159493, 56.77909469604492, 56.68263632910592, 54.41384104319981, 57.0093788419451, 53.43468700136457, 55.09426423481533, 50.017844336373464, 39.82503502709525, 40.94926398141043, 50.43707084655762, 51.555762086595806, 52.98821313040597, 47.9127972466605, 51.94235290799822, 53.82472760336739, 53.31922183718, 51.96456977299282, 50.042600767953054, 52.97452170508248, 49.99870204925537, 47.629123142787385, 46.873982497623985, 47.01444033214024, 45.62475892475673, 46.48057549340384, 48.40203033174787, 50.6149377822876, 50.467903477805, 46.03163848604475, 50.41265835080828, 47.1743357522147, 48.66573183877127, 45.89941774095808, 45.234381335122244, 44.76030921936035, 38.252379758017405, 41.541622229984824, 39.873682839529856, 36.29351929255894, 42.03189754486084, 45.100222042628694, 42.64693471363613, 43.38918992451259, 43.57177121298653, 44.24903644834246, 44.5802674974714, 44.784211022513254, 43.67531326838902, 43.455965587071006, 46.248988560267854, 49.742779050554546, 49.849228927067344, 56.68946640832083, 58.12656579698835, 59.083902495247976, 58.969104358128135, 57.68833943775722, 54.6215226990836, 53.04136337552752, 50.04749924795968, 57.054952076503206, 65.14797755650112, 69.17942660195487, 72.44124453408378, 66.99088300977434, 68.82629135676792, 68.0023809160505, 6.070581614971161, 0.7744619569608143, 1.0429841024535043, 0.3786806230034147, 6.055463203362056, 63.69326795850481, 59.44936384473528, 48.88654211589268, 27.683348076684133, 17.56993235860552, 24.83436778613499, 40.43937390191214, 14.85592429978507, 1.648097615156855, 0.033815559398915083, 0.1067649746047599, 0.08549456418092762, 0.11634176357516221, 0.00273099954938516, 0.058679674485964436, 0.034373627310352664, 0.07642752464328494, 0.12205046867685658, 0.022914061422592828, 0.036914927552321126, 0.10709795887981143, 0.07878045338605132, 0.008106046505937619, 0.041642874745385985, 0.022786586744976894, 0.01005656157420682, 0.013095463775763554, 0.09900895971804857, 0.05531976245609777, 40.42979233605521, 67.06320680890764, 50.99637304033552, 38.73922266278948, 36.42756393977574, 56.36003146852766, 86.13278797694615, 11.19712712083544, 0.6358238990817751, 0.7141042585883821, 1.1649569060121263, 3.4358392570699965, 64.05642250605992, 78.97303758348737, 84.31975282941545, 80.31274059840611, 69.4687773840768, 63.707574299403596, 62.2171231678554, 62.180471420288086, 63.823949677603586, 65.19977637699672, 67.2194162096296, 72.14850997924805, 69.84868403843471, 64.13704940250942, 53.704336166381836, 54.785218783787315, 52.868433134896414, 53.36953374317714, 51.96484422683716, 54.91726234980992, 51.36908483505249, 51.42683826174055, 51.93802418027605, 53.067780426570344, 51.95500210353306, 51.0242075238909, 51.47050421578543, 49.32699884687151, 47.427006993974956, 47.91136244365147, 48.11068541663033, 48.442764145987375, 54.80282551901681, 50.846430914742605, 49.172269412449424, 47.3661789894104, 46.963381494794575, 46.36006246294294, 45.908356598445344, 48.71969502312796, 47.39903007234846, 47.85500907897949, 56.698248931339805, 60.433471952165874, 59.64587279728481, 62.813257762363975, 61.57966068812779, 58.66421045575823, 56.367281913757324, 60.37211241040911, 56.998414584568565, 59.50941712515694, 60.64659404754639, 58.658804757254465, 58.938705989292686, 55.80934156690325, 56.826748916081016, 57.01949889319283, 54.29047230311802, 44.07871525628226, 41.199739592415945, 55.86363131659371, 59.99299785069057, 59.31370026724679, 59.606129101344514, 57.631798471723286, 57.924974237169536, 55.923173904418945, 55.235031264168875, 51.81600686482021, 42.62715319224766, 43.07836920874459, 49.620049544743125, 52.934805801936555, 55.19076429094587, 51.25212580817086, 57.30058479309082, 57.193117005484446, 54.486220427921836, 54.817402839660645, 51.10571684156145, 55.58517530986241, 52.026412214551655, 49.852901050022666, 50.030879156930105, 49.660765988486155, 48.06571667534964, 49.715510845184326, 51.05291748046875, 54.056074823652, 53.2276098387582, 50.51683269228254, 52.284770556858604, 51.020740372794016, 51.13468735558646, 47.40662445340838, 47.090335505349294, 49.784443923405235, 42.01964439664568, 45.124155112675254, 43.30515146255493, 39.84631388528006, 45.03691700526646, 46.670605250767295, 43.83577496664864, 46.38336672101702, 46.79136841637747, 46.85830388750349, 47.10542351858956, 47.45381661823818, 47.08439826965332, 46.58159187861851, 49.2092616217477, 52.00214215687343, 54.50874301365444, 59.24737971169608, 60.13743700299944, 62.447587966918945, 60.55963734218052, 61.80918748038155, 56.651275634765625, 54.433038915906636, 51.881344250270296, 62.17444733210972, 67.15844576699394, 74.51763030460903, 72.81090954371861, 70.09312166486467, 68.90421540396554, 73.99776608603341, 9.315886718886238, 0.7972503112895148, 0.9431662814957755, 0.39221932366490364, 5.631535368306296, 70.23584461212158, 67.18216691698346, 58.00008078983852, 31.817611353737966, 16.148087739944458, 31.32803085872105, 49.789238180433, 24.87534999847412, 1.562201052904129, 0.092964590127979, 0.03254540291215692, 0.06640748267195054, 0.04605122176664216, 0.058116755049143515, 0.05508441258487957, 0.009625325428455003, 0.08371950978679316, 0.08011752699634858, 0.07434970113847937, 0.13828512467443943, 0.22949430399707385, 0.283095584916217, 0.13338547758758068, 0.1309727020561695, 0.12859944440424442, 0.27236376649567057, 0.18629165366292, 0.3505388173673834, 0.16314473428896495, 47.100052561078755, 78.67044353485107, 47.680626664842876, 54.38582590648106, 60.99974318913051, 61.079974038260325, 93.69293526240757, 13.542333483695984, 0.7732429280877113, 2.60969323345593, 2.5699949179376875, 4.341449005263192, 67.88483129228864, 82.87817532675606, 86.1078439440046, 86.02058846609933, 74.4117397580828, 68.07489926474435, 64.48517499651227, 65.43085261753627, 69.43813582829067, 69.19052287510463, 70.29147189004081, 75.86262089865548, 72.24260248456682, 66.59910883222307, 56.89407001222883, 59.06922789982387, 57.62573964255196, 58.030249868120464, 55.90696723120553, 58.570625168936594, 55.05589280809675, 52.70477179118565, 54.73132855551583, 54.49286985397339, 54.45176083700997, 53.02927350997925, 53.75357110159737, 52.53912673677717, 51.87748452595302, 51.74762964248657, 52.7261757169451, 50.3317882674081, 57.809432642800466, 49.88352176121303, 49.42590992791312, 47.82650409426008, 48.51598078863961, 47.500914982386995, 48.384656361171174, 51.703178542000906, 49.19704321452549, 51.08125918252127, 59.024759428841726, 62.52342755453927, 61.41374465397426, 64.71049812861851, 64.63085092817033, 60.9468673978533, 58.68905026572091, 63.725340843200684, 60.27513640267508, 61.049144881112234, 63.350812094552175, 59.86868762969971, 62.82194995880127, 59.437225341796875, 59.543129784720286, 59.71184594290597, 57.61778048106602, 47.127897466932026, 42.68409020560128, 56.12586327961513, 62.898866517203196, 62.339091845921104, 62.77610574449812, 59.31463132585798, 61.900917598179404, 58.423107964651926, 57.09823587962559, 52.300181661333355, 42.42279624938965, 47.92962230954851, 53.013073784964426, 57.53713274002075, 57.66792563029698, 52.30420814241682, 60.094309534345356, 58.71075643811907, 57.21000460215977, 57.51414809908186, 53.32088245664324, 59.36500576564244, 55.359397070748464, 51.613713536943706, 53.06095034735543, 52.04144811630249, 51.896428789411274, 51.49712971278599, 53.53138508115496, 55.52517066683088, 58.62185423714774, 52.87008680616106, 54.146703651973176, 54.62537200110299, 55.262368951525005, 49.09824330466134, 48.954144614083425, 51.25698607308524, 44.309850556509836, 48.08689131055559, 46.34372724805559, 43.60998283113752, 47.15671164648873, 50.85541493552071, 45.6605977330889, 48.93283796310425, 49.41339274815151, 49.31754582268851, 49.524814060756135, 50.57271705354963, 48.57102789197649, 50.02931581224714, 50.83766923631941, 55.90004335130964, 56.385802337101524, 62.634431975228445, 62.751001902988975, 64.60726874215263, 64.20309897831508, 65.69366822923932, 60.67103781018938, 58.42952115195138, 54.417832783290315, 63.20685931614467, 71.00734479086739, 77.46731431143624, 75.23491368974958, 74.32714544023786, 73.77661187308175, 74.54531192779541, 8.853969608034406, 1.7125817835330963, 2.548415115901402, 0.5611707706536565, 8.472489186695643, 78.8419667652675, 71.92616067613874, 65.69656562805176, 42.04703419549124, 27.09681589262826, 39.17835923603603, 60.864350591387065, 39.90604754856655, 2.1265951905931746, 0.2315397070986884, 0.12660585423665388, 0.2166325912943908, 0.21198094875684806, 0.10486922240150826, 0.1362041120550462, 0.12336180545389652, 0.15989517580185617, 0.18949121768985475], [0.06047347680266414, 0.0823723870728697, 0.11749113404325076, 0.030044278728642633, 0.12418774541999612, 0.044506353592233996, 0.06549063258405242, 0.01923579942168934, 0.07252221634345395, 0.06687791778572968, 0.12128175635422979, 42.89966154098511, 47.8394763810294, 23.350644247872488, 35.62010683332171, 41.3166777747018, 54.647408212934224, 76.15379210880825, 2.783620757716043, 0.09182390490812914, 0.4242102956133229, 1.1772406697273254, 14.241944994245257, 77.51440225328717, 74.7505269731794, 84.58925260816301, 74.01267692020961, 69.20993614196777, 60.07771723611014, 59.88912228175572, 53.63496535164969, 62.02224704197475, 59.99531160082136, 64.46742234911237, 66.19007532937187, 69.01864528656006, 64.75049195970807, 59.04158796582903, 50.156495639256065, 51.75966739654541, 48.10171529224941, 50.26185464859009, 49.63192401613508, 50.72780432019915, 48.53083256312779, 50.526337827954976, 48.48276839937483, 51.17802674429757, 47.77779027393886, 50.16590002604893, 43.28838893345424, 44.93899604252407, 43.625359194619314, 45.32260261263166, 46.19839525222778, 53.06459467751639, 48.43156712395804, 46.15572983877999, 46.389140674046104, 45.26170860018049, 43.95325510842459, 44.29468611308506, 44.915969712393625, 45.93834154946463, 45.003065381731304, 52.884719712393625, 56.633053983960835, 57.29654788970947, 57.471774509974885, 57.889395986284526, 55.031362192971365, 54.29296670641218, 55.89109059742519, 56.98838138580322, 57.12832505362374, 61.51552881513323, 58.342543601989746, 62.25856222425188, 57.399099826812744, 53.61176184245518, 54.80813046864101, 48.63280085154942, 39.5089510508946, 41.591256686619346, 52.55008404595511, 56.948689801352366, 50.54833582469395, 52.544379574911936, 52.67974437986101, 50.90567473002842, 53.0346896307809, 55.03261981691633, 45.95236301422119, 39.875166279929026, 30.355877126966202, 35.15590810775757, 55.92890616825649, 48.51842655454363, 49.514370918273926, 53.145575932094026, 55.01815019335066, 52.33224759783064, 52.843308448791504, 53.61925547463553, 51.10527910505022, 53.063948495047434, 47.519112314496724, 45.559261730739046, 44.44417660576956, 49.422342027936665, 52.489464487348286, 54.286195686885286, 52.69731984819685, 48.42761359895979, 52.20208004542759, 48.72937386376517, 46.079570634024485, 44.54238939285278, 42.06152466365269, 41.64198548453194, 45.06557485035488, 42.868505818503245, 41.01480286461966, 42.858455249241416, 36.04211262294224, 38.4623577935355, 45.760749067579, 43.510686125074116, 45.576729501996724, 43.83534417833601, 44.4595946584429, 43.44327817644392, 45.954808780125205, 46.013548851013184, 47.20100293840681, 48.007032190050396, 50.56277070726667, 52.111930642809185, 56.455392020089285, 55.681397438049316, 59.52855246407645, 55.47338226863316, 54.99300813674927, 50.824634415762766, 49.373145307813374, 56.40747029440743, 63.46930667332241, 64.21163136618478, 68.39207063402448, 69.58148411342076, 77.92878586905343, 59.633984429495676, 79.66719736371721, 25.742446967533656, 0.3178987316787243, 1.2628533329282488, 0.03152901852237327, 0.37204232492617195, 42.40820155824934, 66.53551197052002, 46.83088282176426, 34.15419326509748, 33.4638341494969, 23.765170301709855, 39.968918323516846, 18.325437784194946, 0.554304267678942, 0.08120311517268419, 0.062415091187826226, 0.007818263689322131, 0.1684450970164367, 0.10744373353996448, 0.023316346175436462, 0.021750506179939424, 0.04166574476818953, 0.04558363310726626, 0.04349866462871432, 0.09892106229173285, 0.05456210007624967, 0.04011035930099232, 0.04244351553331528, 0.07774980619017567, 0.08603253388511282, 0.03363448893651366, 0.12841824841286453, 0.04100702975743583, 0.6845398907150541, 53.47024440765381, 54.90397392000471, 36.81444311141968, 32.90435477665493, 42.18313550949097, 66.1602258682251, 76.3561097553798, 2.8783720391137257, 0.1559805172894682, 0.2792252211698464, 1.5022278938974654, 18.591223750795635, 84.50608267102922, 77.40689277648926, 87.27184786115373, 76.67747783660889, 71.45570509774345, 62.64118562425886, 63.46169144766671, 57.43761716570173, 63.922989300319124, 63.2299690246582, 68.71876798357282, 69.45145552498954, 71.89038440159389, 68.8709682737078, 64.06149469103131, 54.05435514450073, 52.99159342902047, 52.1428918157305, 53.96462263379778, 54.038217953273225, 52.75760589327131, 51.77655846732003, 53.456942081451416, 50.884666851588655, 54.839921951293945, 50.52219670159476, 52.33578770501273, 46.52189643042428, 47.42582927431379, 47.57974924360003, 47.64680630820138, 49.12566784449986, 54.89153664452689, 48.52749047960554, 47.00346565246582, 45.141480445861816, 45.822528975350515, 42.95983641488211, 46.30693653651646, 46.42223146983555, 48.67812395095825, 46.804774965558735, 53.831814765930176, 58.859718867710654, 60.355026790073936, 59.841749463762554, 60.097873960222515, 57.242285932813374, 56.87639379501343, 57.64190115247454, 56.54480143955776, 59.166926520211355, 63.002547536577495, 61.80972943987165, 63.51644325256348, 59.91929830823626, 55.86796351841518, 59.261123248508994, 50.41697665623256, 43.19811793736049, 42.66418014253889, 53.30079174041748, 55.999131611415315, 51.062714440482004, 54.429762840270996, 52.33749348776681, 51.49007034301758, 54.474224363054546, 55.69197259630476, 46.999981130872456, 41.585732868739534, 33.198079449789866, 39.20795161383492, 57.8187849181039, 49.66561235700335, 54.393086774008616, 54.0908088684082, 58.540525572640554, 55.250748089381624, 56.19204487119402, 57.07626914978027, 51.54160165786743, 54.31610768181937, 50.94117307662964, 48.25181375231062, 47.83422006879534, 53.23870958600725, 54.96851921081543, 56.5545254434858, 54.96772016797747, 53.155470166887554, 53.95616667611258, 51.53731114523751, 49.32545634678432, 46.833509240831646, 44.2254890033177, 42.57481936046055, 47.956591742379324, 45.88873488562447, 43.37219115665981, 44.50229828698294, 40.49869762148176, 40.35848992211478, 48.64064884185791, 45.42146158218384, 48.04310376303536, 46.07254600524902, 47.65352521623884, 45.88404485157558, 49.339172090802876, 46.52012463978359, 49.68676267351423, 50.9061541557312, 53.40844018118722, 54.58898775918143, 59.320328848702566, 58.38090460641043, 60.053697313581196, 57.47094072614397, 57.96660784312657, 52.30687625067574, 52.650082520076204, 59.9571590423584, 65.97573035103935, 67.63145133427211, 70.75750841413225, 70.64193207877022, 78.99173518589565, 62.18412617274693, 80.3606206348964, 30.762041023799352, 0.12928988092711993, 0.4281614321683134, 0.08915325892823082, 0.24419034112777027, 44.78460012163435, 74.58610480172294, 54.37551130567278, 41.38219233921596, 23.493203912462505, 34.10671969822475, 50.27651187351772, 33.5170955657959, 0.43333007767796516, 0.03978298311786992, 0.060404490147318156, 0.01588372786396316, 0.04257511400750705, 0.02377228269220463, 0.043303358501621654, 0.024760713135557513, 0.0664258845416563, 0.02572661282361618, 0.22560495484088147, 0.1573319961982114, 0.19840216024645738, 0.14613592411790574, 0.13025802826242788, 0.10370413027703762, 0.15533867744462831, 0.11028207944972174, 0.21315233090094157, 0.21875403103019508, 0.7925579973629543, 59.894917079380576, 65.1293146950858, 32.028207778930664, 50.46222332545689, 64.91066878182548, 67.9415841783796, 88.93666403634208, 3.4209542615073065, 0.15561743320098945, 1.143743512885911, 3.443562831197466, 17.429698603493826, 85.26042774745396, 81.7477034160069, 90.78255721500942, 80.45933369227818, 75.45097487313407, 65.86945765359062, 66.7800121307373, 59.23582485743931, 66.86214678628104, 66.76261384146554, 71.0835109438215, 72.90131255558559, 76.40365627833775, 70.87178543635777, 65.0989510672433, 57.91868264334542, 56.5516106741769, 52.8224047933306, 56.84268808364868, 57.21206821714129, 55.26454373768398, 56.97147641863142, 56.49253708975655, 54.06256791523525, 57.003681319100515, 51.68872628893171, 55.19057321548462, 49.1785922731672, 50.790247780936106, 50.415100642613, 50.37146595546177, 50.059641224997385, 56.875910895211355, 48.894067014966694, 45.925053119659424, 45.85501527786255, 44.82740102495466, 44.886922768184114, 46.156129360198975, 48.16084793635777, 50.68195315769741, 48.584417070661274, 57.06000689097813, 62.205165318080354, 63.27802971431187, 62.12988158634731, 63.5204176221575, 59.697421482631135, 58.2534225327628, 60.57217189243862, 61.52053846631731, 63.36764063153948, 67.03105054582868, 63.399810791015625, 66.33371543884277, 61.01841994694301, 59.804243087768555, 62.99400820050921, 54.41514730453491, 43.65066105978829, 43.66152804238455, 54.556887081691194, 60.97616100311279, 52.60513114929199, 56.78063372203282, 55.180828366960796, 53.0256986618042, 56.6771159853254, 59.25794792175293, 46.9541369165693, 44.10501071384975, 38.294732502528596, 43.072654315403526, 58.700146538870676, 54.434442452022004, 56.658244677952354, 56.98081827163696, 62.23054708753313, 58.73659678867885, 58.55133696964809, 60.92230551583426, 54.375240325927734, 57.30288117272513, 54.166158608027864, 52.14081083025251, 49.751895087105886, 54.08380161012922, 58.819315092904226, 58.2934684753418, 58.7550025667463, 56.149514947618755, 57.716417108263286, 53.885315895080566, 51.80239534378052, 48.655410289764404, 44.357518672943115, 44.50198561804635, 50.303491728646414, 49.87596559524536, 46.33142893654959, 49.952030999319895, 42.48951980045864, 43.205774852207725, 50.85999379839216, 49.231353419167654, 51.42592804772513, 48.57666982923235, 50.18948916026524, 49.547579833439414, 50.886167662484304, 50.054367542266846, 52.524073464529856, 54.083169324057444, 54.84929854529244, 58.26585980824062, 64.48107555934361, 61.31916577475411, 63.723902566092356, 61.035950251988, 60.18398298536028, 55.41825178691319, 56.570273535592214, 61.96417399815151, 69.48330606733049, 68.13621711730957, 75.26060812813895, 76.04719284602574, 77.46659864698137, 66.7733210154942, 83.25490665435791, 30.331443786621094, 0.5593235269188881, 3.795916838305337, 0.15655446292034217, 0.628396709050451, 54.34534222739083, 78.47365665435791, 60.10962336403983, 51.0667895589556, 53.8659964288984, 41.13856765202114, 56.8686500276838, 48.449743611471995, 1.4303025305271149, 0.19803603632109507, 0.12761106315468038, 0.12251066469720431, 0.18375577830842563, 0.14725074358284473, 0.2665557238672461, 0.11555391656500952, 0.25335205665656496, 0.11654372273811273], [0.11636110182319369, 0.014468978957406111, 0.042120929807424545, 0.051653396870408735, 0.03432552596288068, 0.12052581406065396, 0.012539867428131402, 0.030048824913267578, 0.18454638017075403, 0.12872152642479964, 2.8486350519316535, 53.63760566711426, 47.86502490724836, 34.00916351590838, 43.548765727451865, 39.28900235039847, 64.47263349805559, 53.50803565979004, 0.21387632776583942, 0.03193507084090795, 0.6565862564103944, 0.3253452463873795, 54.660776547023225, 92.50131225585938, 75.03349236079625, 83.73162950788225, 73.03709425245012, 67.07071781158447, 58.38640757969448, 58.581950732639854, 55.58077710015433, 60.06131253923689, 60.70393753051758, 65.93336023603166, 66.45507962363106, 70.37303679330009, 65.89711843218122, 63.973599978855674, 58.36190128326416, 54.11362675258091, 51.00064965656826, 51.978278568812776, 49.535198143550325, 49.49681282043457, 49.05823557717459, 49.72562394823347, 51.31636537824358, 50.9773245538984, 49.245718819754465, 47.92542559759957, 44.08717816216605, 43.05740301949637, 44.75111675262451, 45.39829976218087, 48.450111865997314, 52.14833572932652, 46.69934300013951, 47.111909661974224, 45.54345457894461, 46.56354740687779, 45.498103686741416, 43.938045501708984, 42.881617069244385, 45.809202330453054, 43.49629293169294, 49.213201250348774, 55.325430801936555, 55.66155685697283, 59.07692650386265, 58.326111112322124, 53.393373012542725, 53.19476917811802, 53.435673645564485, 53.81694562094552, 56.69590738841465, 58.261617933000835, 63.30125754220145, 53.706135749816895, 58.788812501089915, 53.11744267599923, 49.00465106964111, 42.04287917273385, 39.90945563997541, 45.124294076647075, 51.17559487479073, 49.880110195704866, 51.02580213546753, 52.74664510999407, 53.90528154373169, 55.74607821873256, 52.42554800851004, 51.1298896244594, 46.85371112823486, 36.77762113298689, 31.030998843056814, 29.74107619694301, 42.11415031978062, 53.12854242324829, 50.59639998844692, 54.81042684827532, 51.385173388889854, 54.57701601300921, 54.4581948689052, 51.07638502120972, 53.2962406703404, 50.98410252162388, 48.21390438079834, 47.91175154277256, 47.53347076688494, 52.41195733206612, 52.10641029902867, 53.743402412959504, 48.217229093824116, 53.340010847364155, 50.877190589904785, 48.20646286010742, 43.82761778150286, 42.19126490184239, 40.581554889678955, 42.211775984082905, 45.51178468976702, 42.86747053691319, 40.02157524653843, 40.62650973456246, 38.89772496904646, 37.49512686048235, 42.242928232465474, 43.16556910106114, 42.92637389046805, 43.6981589453561, 46.10522338322231, 44.57560873031616, 45.284710611615864, 43.1254015650068, 46.79266425541469, 50.22229855401175, 50.81396198272705, 54.8248929977417, 55.145215375082834, 56.222627367292134, 53.63149125235421, 51.83196687698364, 49.227403368268696, 47.515971728733604, 52.595066683632986, 60.40575558798653, 67.36680834633964, 65.08907072884696, 66.64737796783447, 58.50763974870954, 72.48442758832658, 75.31345612662179, 65.92536980765206, 51.59878880637032, 0.735404232782977, 0.5310902276209423, 0.32249252232057707, 0.363336584929909, 18.569145849772863, 72.53112643105644, 52.182110922677175, 39.204018933432444, 21.15140390396118, 19.169404200145177, 35.27550745010376, 28.250235966273717, 0.7022064998745918, 0.17877587409956114, 0.04275298856997064, 0.018479987746104598, 0.04505022994375654, 0.01929500329840396, 0.10052333452871867, 0.05055881810507604, 0.06098166560488088, 0.06493704978908811, 0.059671360201069286, 0.03723412399579372, 0.07266985199281148, 0.015694501410637583, 0.20611809406961712, 0.020484692317300608, 0.03169293901217835, 0.02255498747607427, 0.27353993909699575, 0.3044410752398627, 5.732427988733564, 66.86009011949811, 54.32120418548584, 37.63265602929251, 38.41748285293579, 46.71556009565081, 69.54084409986223, 57.55893966129848, 0.1401442563427346, 0.17920491179185255, 0.24009188104953083, 0.12277004149343286, 62.10587556021554, 94.57161835261753, 76.00965172903878, 86.1350461414882, 74.66096469334194, 68.93790027073452, 60.36997931344168, 61.09332152775356, 59.50631128038679, 62.63605785369873, 66.00760868617466, 69.32911164419991, 68.24889605385917, 74.29088973999023, 69.11597565242222, 66.09511429922921, 59.72663170950753, 56.95910167694092, 53.75434235164097, 54.136653082711355, 53.99942963463919, 52.20167357581002, 51.22806419645037, 51.27843516213553, 53.21939011982509, 51.843792710985454, 51.85546915871756, 50.307976790836875, 46.663969721112935, 45.67456013815743, 47.32433693749564, 48.595127718789236, 52.47486284800938, 52.980007307870046, 46.32741635186331, 45.843349252428325, 45.735301290239605, 47.99463312966483, 43.91715226854597, 43.424709115709575, 45.85650219236101, 46.5083509172712, 46.41703074319022, 50.53525931494576, 57.88967044012887, 58.12367187227522, 60.345611980983186, 60.02249295370919, 55.783827781677246, 56.56748035975865, 54.65405069078718, 55.49670042310442, 58.47981916155134, 60.42719772883824, 62.086142676217214, 55.966530663626536, 59.4144560950143, 55.57215438570295, 50.182617391858784, 45.54579612186977, 42.19748701368059, 45.98919194085257, 53.75679506574358, 51.286654881068635, 54.5408228465489, 55.69499853679112, 57.34078359603882, 56.30675962993077, 54.776387623378206, 53.875185421534944, 48.57508216585432, 38.28883000782558, 36.91748489652361, 34.43952798843384, 43.165781021118164, 57.01989146641323, 51.8123972756522, 56.18651410511562, 51.83780336380005, 57.65121521268572, 56.752941676548545, 54.0687518119812, 55.85620716639927, 51.668962138039724, 52.79545273099627, 49.880221366882324, 50.091856547764365, 54.94707012176514, 54.92398125784737, 54.52984816687447, 52.1654943057469, 58.55738190242222, 54.703111921037944, 50.716131346566335, 46.27418967655727, 44.70453255517142, 41.633873462677, 42.199828556605745, 46.20431511742728, 46.54784795216152, 41.88329642159598, 43.09265470504761, 42.44851153237479, 40.86556945528303, 44.076981680733816, 46.16910512106759, 45.271324907030376, 46.700756958552766, 47.30289479664394, 47.38083968843733, 46.404475348336355, 46.29884188515799, 49.3283155305045, 52.631906032562256, 54.34687430518014, 57.96859155382429, 58.54632731846401, 59.03328486851284, 56.43260540281023, 52.790991987500874, 51.005919865199495, 50.720960344587056, 57.855839661189485, 63.90105383736746, 69.86543614523751, 67.86524432046073, 66.40037645612443, 64.43575940813336, 72.71666417803083, 77.32001944950649, 68.90254783630371, 57.39418050221035, 1.7345516617809023, 0.5225627794861794, 0.3294611583862986, 0.6461910999247006, 18.06801744869777, 78.07993698120117, 61.81362043108259, 47.8981990814209, 24.74685001373291, 30.874650478363037, 45.63808209555489, 45.743826729910715, 1.1530698410102298, 0.15016362656440052, 0.03301879643861737, 0.02102541008831135, 0.041236822426851304, 0.08240711449512414, 0.03825910542426365, 0.018259077100083232, 0.04138576425611973, 0.06342645441847188, 0.17310838321489946, 0.14981426245399884, 0.19030032998749188, 0.14064057756747517, 0.3058859205671719, 0.2846781999937126, 0.23534973551120075, 0.21206545350807054, 0.34151568583079744, 0.41189260514719145, 6.176375320979527, 78.95228331429618, 60.324954986572266, 44.47670112337385, 59.94494410923549, 57.06590591158186, 74.36159460885185, 65.80296339307512, 0.3136354690151555, 0.32425345640097347, 1.6398180765765054, 0.9868921637535095, 64.88174343109131, 98.97065489632743, 82.4231378010341, 90.28549698420933, 77.75829097202846, 71.96060289655412, 63.577163560049875, 64.87487166268485, 62.78386688232422, 67.25487981523786, 70.14642129625592, 71.63583019801548, 72.16823591504777, 75.5225830078125, 72.25212151663644, 68.72060925619942, 61.565757342747276, 59.520096506391255, 56.41521406173706, 58.7291761125837, 55.982264859335764, 55.346869468688965, 54.46345812933785, 53.63288089207241, 56.591437748500276, 55.620579855782644, 52.976703439440044, 51.793227195739746, 50.11768300192696, 49.41226713997977, 49.63499859401158, 50.55259507043021, 55.21989461353847, 54.070151873997276, 47.148502349853516, 46.1917701448713, 45.92824581691197, 47.41578565325056, 45.026894228799, 46.611986773354666, 47.66075134277344, 49.81740617752075, 47.818062032972065, 53.95704909733364, 60.85023185185024, 60.30889769962856, 62.038568360464915, 62.25105816977364, 57.423050267355784, 59.022049631391255, 57.13415111814226, 57.92578717640468, 59.982103075299946, 63.05522877829415, 67.32316671098981, 60.67166314806257, 60.41159207480294, 60.9321928024292, 54.826508453914094, 48.466697216033936, 45.32237679617745, 46.252910818372456, 53.72000435420445, 52.12208890914917, 55.1422415460859, 58.43822724478585, 61.021456309727256, 60.370736667088096, 56.3557722227914, 54.990451199667795, 48.66892801012312, 38.944687843322754, 36.49950211388724, 36.65613188062395, 49.27827113015311, 56.35862445831299, 55.32587201254708, 58.96278149741036, 53.67812408719744, 61.346722330365864, 58.93632275717599, 56.18059423991612, 58.160240241459434, 55.71286235536848, 54.75165898459298, 52.4738484110151, 53.28879567555019, 58.977053097316194, 57.50541768755232, 58.947419030325754, 55.88914162772042, 59.57988575526646, 58.624647412981304, 52.51522840772356, 49.48796428952898, 46.67068862915039, 42.78226130349295, 43.276205267224995, 47.00043623788016, 48.8398745400565, 45.885222571236746, 46.21397658756801, 46.687440735953196, 44.37089395523071, 46.885422706604004, 47.75996119635445, 47.78950841086251, 49.69285971777779, 50.399946621486116, 50.15304238455636, 49.61475501741682, 48.243760790143696, 51.04201923097883, 57.068664346422466, 58.349839210510254, 62.00577981131417, 62.05296502794538, 62.845949036734446, 59.00145517076765, 58.17982721328735, 55.3159430367606, 54.0098032951355, 57.924255098615376, 66.72212668827602, 72.40088939666748, 71.32358510153634, 70.22415774209159, 67.39870057787213, 77.64244365692139, 74.91794381822858, 71.17772156851632, 59.63495717729841, 1.3420378267765045, 1.7035142758062907, 0.8338107551847185, 0.6165338541780199, 24.760741199765885, 85.4344870703561, 65.9239593233381, 56.909929275512695, 36.91567836488996, 32.65997273581368, 48.856525897979736, 61.835722650800435, 2.819823912211827, 0.2943763653082507, 0.20232078140335424, 0.13435652905276843, 0.20710818522742816, 0.08702823652752809, 0.08587342420858995, 0.11439989134669304, 0.11921329663268157, 0.20429862955851213], [0.03290859217356358, 0.05571630510634609, 0.1123945489525795, 0.05477380978741816, 0.036805656272917986, 0.03228960878082684, 0.11180151613163096, 0.06319263125104563, 0.06679461404149022, 0.499843744294984, 8.429463335445949, 62.907954760960166, 40.03547511781965, 47.076856000082834, 45.895016057150706, 37.78152118410383, 76.93611063276018, 36.17489964621407, 0.5202793734414237, 0.4352690593472549, 1.3395384294646127, 6.304875305720738, 84.10895143236432, 75.79636982509068, 78.38565771920341, 75.03000436510358, 71.2796516418457, 59.88970593043736, 58.94682148524693, 57.894436904362266, 58.376200675964355, 59.769092151096885, 62.9050851549421, 66.96277059827531, 66.32760102408272, 66.8221321105957, 68.85327121189663, 65.5262861251831, 61.78164482116699, 57.90265662329537, 54.50600889750889, 53.02273872920445, 52.71479456765311, 50.14888736179897, 49.8667870249067, 48.127093587602886, 50.01578766959054, 47.79129409790039, 49.37266935620989, 48.4312926701137, 42.198671681540354, 41.49436753136771, 43.90432936804635, 43.321309498378206, 49.04477344240461, 47.784213883536204, 46.53216239384243, 46.57218401772635, 44.95220456804548, 44.16025584084647, 45.069542271750315, 43.742394651685444, 42.77946465356009, 45.74623775482178, 44.57014397212437, 46.64055776596069, 50.413898604256765, 55.8741717338562, 59.057534081595286, 57.90014484950474, 55.09512233734131, 52.15997396196638, 52.1490409714835, 52.199801036289756, 54.71656015941075, 56.770169734954834, 58.568978445870535, 57.00194079535348, 47.66324574606759, 56.868886266435894, 42.51670115334647, 45.00650126593453, 39.38209431512015, 49.5671146937779, 58.83047389984131, 56.84416110174996, 56.592202050345286, 55.422903605869834, 56.15850591659546, 54.23368467603411, 55.70142214638846, 56.079129695892334, 55.76079102924892, 40.35134022576468, 42.85269866670881, 43.5736437525068, 34.88464001246861, 45.77869626453945, 53.462573596409385, 52.18315315246582, 54.83313356127058, 52.4358035496303, 51.354545729500906, 51.021442140851704, 51.50994566508702, 51.2416409764971, 49.81567260197231, 48.899743693215505, 49.79539428438459, 51.681267397744314, 53.198517731257844, 45.73221976416451, 50.901363372802734, 55.412950311388286, 47.570376123700825, 44.98855406897408, 39.929643630981445, 41.432306221553254, 41.19145039149693, 41.760462692805696, 42.31751019614083, 46.68530763898577, 40.42936154774257, 41.64726611546108, 40.72652210508074, 37.12264435631888, 38.38664674758911, 46.11596877234322, 43.06853403363909, 43.3269236428397, 43.21312952041626, 43.27832794189453, 44.28665052141462, 44.971923555646626, 45.73611422947475, 49.94404057094029, 49.33856759752546, 52.7529992376055, 51.36481516701834, 49.77515418188912, 49.604846886226106, 48.6039970942906, 49.49743468420846, 53.140274456569124, 58.94832924434117, 64.3010755266462, 65.18546308789934, 63.74902030399868, 64.70038155147007, 68.46768093109131, 59.488093103681294, 70.45374706813267, 71.52853611537388, 66.50472450256348, 7.843269007546561, 0.6939715817570686, 1.2822137283427375, 0.2569652556308678, 2.9053160675934384, 54.75883994783674, 61.703567913600374, 42.530163288116455, 27.425700187683105, 19.26080080441066, 35.22641147886004, 37.31040900094168, 0.7314017446977752, 0.17601536294179304, 0.058177782488720756, 0.017739609349519014, 0.11676275384213243, 0.050468291355563064, 0.07979517536503927, 0.04159036970564297, 0.01949721691198647, 0.10046480409801006, 0.028126031393185258, 0.03821400998692427, 0.06714124365576676, 0.03835937932931951, 0.015650372885699784, 0.037142660867955, 0.1001995579738702, 0.08173558874321835, 0.22734568214842252, 0.491383715399674, 13.496376361165728, 73.64424174172538, 47.13076359885079, 44.03521605900356, 40.947054454258506, 46.82947581154959, 81.05134105682373, 39.29211514336722, 0.5094508773514203, 1.0298165061644144, 1.768687944327082, 9.868080036980764, 91.1998312813895, 77.24534021105084, 83.31129128592355, 75.21757098606655, 73.42053059169224, 64.67342948913574, 62.719359806605745, 60.52547999790737, 61.398507254464285, 63.33701992034912, 65.50264835357666, 67.63758659362793, 68.70949908665249, 69.8798953465053, 71.73348018101284, 70.73894282749721, 67.06005927494594, 60.73662185668945, 56.86151075363159, 55.68785926273891, 54.887280872889924, 52.1059239251273, 52.91298498426165, 50.893793310437886, 50.841706139700754, 51.42775889805385, 52.18622425624302, 49.02810818808419, 45.047519956316265, 45.15721116747175, 46.53135640280587, 48.13544879640852, 50.07819638933454, 48.663900988442556, 46.878728117261616, 46.51381567546299, 44.571630886622835, 46.84901762008667, 45.30861588886806, 42.76830584662301, 45.31389651979719, 46.52428661073957, 45.44394595282418, 49.13240759713309, 52.06640257154192, 57.35294989177159, 61.0202751159668, 60.61395141056606, 57.209441798073904, 54.137483392442974, 53.28189958844866, 55.13503279004778, 56.52392210279192, 60.89615249633789, 61.21638107299805, 59.191460609436035, 49.82703290666853, 58.516755785260884, 46.63745192119053, 50.41846704483032, 42.12014661516462, 51.904044015066965, 58.42576217651367, 58.61872754778181, 57.64497225625174, 57.90460559300014, 58.65483733585903, 55.77678230830601, 59.34408473968506, 58.614391871861045, 58.981222016470774, 42.37691381999424, 43.77537080219814, 45.5994987487793, 38.3974164554051, 46.739243030548096, 55.98628439222063, 53.46088865825108, 55.42983095986502, 54.623165948050364, 53.63143219266619, 53.908606256757466, 53.21950823920113, 52.07883289882115, 52.73968996320452, 52.80206741605486, 52.97462592806135, 55.49037061418806, 56.12942770549229, 49.97615514482771, 55.2697514125279, 56.308489731379915, 51.228505407060894, 45.99199206488473, 41.760487011500764, 42.01842846189226, 42.20253487995693, 42.46589592524937, 43.37136779512678, 47.95197466441563, 44.076467514038086, 44.63397707257952, 44.21242986406599, 39.718564305986675, 41.152234758649556, 47.92635318211147, 44.27146870749337, 45.525559493473594, 45.22773885726929, 46.71766539982387, 46.5816023009164, 48.464063848767964, 48.10900395257132, 52.88475097928728, 51.73390695026943, 55.56685985837664, 53.74082463128226, 52.964519773210796, 52.27566841670445, 49.787702628544395, 49.77098873683384, 56.513138498578755, 60.85656860896519, 67.2207919529506, 67.12751933506557, 65.5906194959368, 64.7422513961792, 69.98247855050224, 62.90898309435163, 72.9505752835955, 71.8832208088466, 70.82077176230294, 9.935468009540013, 0.586543854858194, 0.7288565869842256, 0.17829714050250395, 2.030547853027071, 58.07283190318516, 68.07260635920933, 53.39568676267351, 29.597467354365758, 23.080793585096085, 47.609956536974224, 51.533541747501914, 2.9626921202455248, 0.16707463269787176, 0.056253070410873206, 0.0686698066336768, 0.04686402868745582, 0.08098006714135408, 0.025576493736090403, 0.02135022819441344, 0.0509582547071789, 0.06396072610680546, 0.13618481451911585, 0.207747148083789, 0.28114835226110046, 0.10817710775882006, 0.19753126055002213, 0.10216326545923948, 0.19989018754235335, 0.20024316145905427, 0.33478402133498875, 0.6322118129049028, 14.448522755077907, 87.06890487670898, 50.13109997340611, 60.61427797589983, 60.12800134931292, 52.86518832615444, 87.56619439806256, 45.86752898352486, 0.7866995260119438, 1.3015660899026054, 3.950834308351789, 10.702126162392751, 96.24211120605469, 79.9783307484218, 85.29707949502128, 79.40582002912248, 77.70412281581334, 67.37527125222343, 66.54795619419643, 65.75692462921143, 62.91873836517334, 66.4377577645438, 70.08728517804826, 73.40507779802594, 71.27152919769287, 73.36570930480957, 73.29198891775948, 72.74703475407192, 68.94586290631975, 64.95608220781598, 59.63446385519845, 57.547537667410715, 58.06231233051845, 55.931449208940776, 55.657582487378804, 53.34018802642822, 54.26068884985787, 53.89433465685163, 54.268804345812114, 53.35039145605904, 47.250185762132915, 48.21573175702776, 50.61937768118722, 49.64836345400129, 51.65243237359183, 49.35555246898106, 47.852420875004356, 47.66213403429304, 45.235927309308735, 45.56936093739101, 46.04371792929513, 43.29870006016323, 46.618153299604145, 50.05879354476929, 50.91059405463082, 51.85339164733887, 54.54769808905465, 60.961396081107004, 63.206379890441895, 63.13482734135219, 59.433306557791575, 56.306940283094136, 56.98891639709473, 55.793628215789795, 60.55033370426723, 63.12184115818569, 63.23669488089425, 60.9511752809797, 55.388440540858674, 60.92977482931954, 49.68034601211548, 52.49103478022984, 43.22507347379412, 51.636548791612896, 62.609383719308035, 62.158695765904014, 62.3650016784668, 60.257571356637136, 64.32623495374406, 58.07794230324881, 60.78518976484026, 61.83475685119629, 59.25124291011265, 44.61545317513602, 47.94372020448957, 47.82792847497122, 41.750335693359375, 49.7319016456604, 58.15535913194929, 57.65118394579206, 58.37597138541085, 58.27958597455706, 55.84408255985805, 57.14857905251639, 56.51488249642508, 56.54774052756173, 56.24813420431954, 55.32958582469395, 55.66418327604021, 57.87367568697248, 58.59324850354876, 54.02460643223354, 56.09029197692871, 60.458964892796104, 53.91551276615688, 48.49288845062256, 43.838804381234304, 44.017949785505024, 42.69311244147164, 43.93720129558018, 43.835375445229666, 51.98840209415981, 48.06717232295445, 47.963977677481516, 48.29500722885132, 42.696718556540354, 42.45286110469273, 50.66829647336687, 46.605698653629844, 48.326781341007774, 47.759895188467844, 49.301172392708914, 48.86926542009626, 52.24183068956648, 51.865488461085725, 57.09159687587193, 54.85415881020682, 59.51987416403634, 58.074867725372314, 55.83476502554757, 54.185471126011436, 53.16051108496529, 54.66291659218924, 58.397663661411826, 63.88743536812918, 69.1499662399292, 70.44546481541225, 66.50084045955113, 67.89251599993024, 70.73314802987235, 66.24101257324219, 79.6894177028111, 68.74141216278076, 71.72910976409912, 10.050594449043274, 1.2559141452823366, 2.6907059720584323, 0.29706767946481705, 4.072989284992218, 68.4481634412493, 70.78433540889195, 59.90357453482491, 40.881574630737305, 29.30243989399501, 50.20368085588728, 67.68898936680385, 3.5052667430468967, 0.33901091452155796, 0.20294701494276524, 0.10620025026478938, 0.1864201139126505, 0.17712630118642533, 0.1936491174357278, 0.10973566198455435, 0.07689877399908644, 0.1523755014474903], [0.04552038346550294, 0.0700535566679069, 0.013994942519015499, 0.03735480484153543, 0.06177525980664151, 0.05298419063910842, 0.07550903928599187, 0.035035334660538604, 0.06156437112284558, 0.2791935200137751, 15.165923391069684, 60.64384950910296, 35.753064087459016, 41.753969601222444, 45.82345308576311, 44.02870907102312, 80.31951509203229, 16.781129428318568, 0.5708716501082692, 0.514448477753571, 1.4121065012046268, 28.831346818378993, 89.31981549944196, 73.5545266015189, 79.84012413024902, 68.36267280578613, 65.01475974491665, 57.863506998334614, 58.53215994153704, 59.367861475263325, 59.645045961652485, 60.83801691872733, 65.87933104378837, 65.93162318638393, 67.21321841648647, 65.96105575561523, 66.30365753173828, 65.92396627153668, 65.38696084703717, 62.81433473314558, 59.44390256064278, 56.18742779323033, 52.16691868645804, 48.67969076974051, 49.290642397744314, 49.803054673331125, 49.01260328292847, 49.57019621985299, 49.110659735543386, 45.277797154017854, 42.929938316345215, 42.678100858415874, 44.23011302947998, 42.81679732458932, 49.549365520477295, 49.58777168818882, 47.086305550166536, 44.96307155064174, 44.38148995808193, 43.86403676441738, 45.35659320013863, 44.73961748395647, 42.40982048852103, 42.724254267556326, 43.53207268033709, 43.65063674109322, 47.398415156773154, 52.857142312186106, 59.65177876608712, 57.007693903786794, 56.55527237483433, 53.19712461744036, 49.986862318856375, 50.358854975019185, 52.30323192051479, 55.266801902226035, 54.073702403477256, 56.34777137211391, 49.98408303941999, 50.82951552527291, 47.787531648363384, 42.08159800938198, 39.09817355019705, 48.74257544108799, 56.85842227935791, 53.43377331324986, 51.13186291285923, 51.40788010188511, 49.04331432070051, 53.909186431339805, 51.32064894267491, 54.80585493360247, 52.77041489737374, 42.732272488730295, 37.036083698272705, 38.59437704086304, 48.13293354851859, 39.0233553477696, 48.619953632354736, 52.984620911734446, 52.72662387575422, 53.52210576193673, 50.11199242728097, 55.21351269313267, 53.687879358019146, 53.25231763294765, 51.79309170586722, 50.443636894226074, 49.93224947793143, 56.27969987051827, 49.579961912972585, 48.50102826527187, 53.53202778952462, 53.11934995651245, 45.14718839100429, 39.55466324942452, 39.24064983640398, 41.8881254196167, 40.30456147875105, 41.528504031045095, 40.93365485327584, 44.389185088021414, 42.83347994940621, 40.16544812066214, 42.68400682721819, 37.79609155654907, 38.141236373356406, 43.24428176879883, 42.74777739388602, 43.08492830821446, 44.20564494814192, 43.60345499856131, 42.360641138894216, 43.571045126233784, 44.47555119650704, 46.78007064546858, 46.96445151737758, 48.65978765487671, 45.86122349330357, 47.49687113080706, 45.05704941068377, 50.22271892002651, 50.62034000669207, 58.925858770098, 63.6556921005249, 66.89005770002092, 60.546192577907014, 62.43672098432268, 66.20470823560441, 69.18153190612793, 66.81846346173967, 64.41487312316895, 57.893227917807444, 81.60750266483852, 25.612281152180262, 0.30545103390301975, 0.05602877387510879, 0.13428437363888535, 0.046008029620030096, 29.421184607914515, 69.08124160766602, 47.80039276395525, 34.01316567829677, 27.6151636668614, 31.967626435416086, 44.52391760689871, 4.78148797580174, 0.340632043246712, 0.019614918988996317, 0.12746494742376463, 0.02251924734030451, 0.08026724574821335, 0.06784153929246323, 0.09721921504076038, 0.02057319363978292, 0.052777335845998356, 0.10733084566891193, 0.05134360492229462, 0.03371081055541124, 0.047326708145971806, 0.02988559313650642, 0.05399249706949506, 0.13921787962317467, 0.033630455045827796, 0.1859033687838486, 0.3171292186847755, 21.48862256322588, 68.31147153036935, 45.5622181892395, 39.638302189963206, 46.043262822287424, 54.957297870091026, 85.39554241725376, 16.59396059172494, 0.7866686933806964, 0.12329498332526002, 2.12217635342053, 39.30233941759382, 92.95700291224888, 77.11350509098598, 81.3739320210048, 71.71604020254952, 68.506806237357, 60.005956241062705, 60.16318702697754, 60.60960878644671, 63.168401036943706, 65.88785648345947, 67.84265572684151, 68.14930752345494, 71.02131067003522, 69.33901977539062, 70.31275422232491, 67.54304245540074, 68.91271305084229, 66.45842170715332, 60.37682328905378, 57.016948904309956, 53.73067331314087, 52.40581859861101, 50.48810536520821, 51.35347918101719, 51.12694706235613, 49.3688200541905, 50.42343848092215, 47.26263345990862, 45.62914323806763, 45.78522409711565, 44.82948201043265, 47.22434541157314, 49.63466855457851, 51.55737754276821, 46.597597054072786, 43.65513569968087, 44.13226154872349, 44.86621366228376, 45.153337546757285, 45.5496141569955, 41.92317908150809, 43.85197121756417, 44.05802699497768, 43.48966087613787, 48.21330336162022, 55.468344824654714, 59.789999280657085, 57.92904240744454, 58.90227658408028, 56.634304659707205, 52.463658877781455, 52.94834089279175, 54.56387349537441, 57.98777553013393, 56.94265876497541, 58.3245130266462, 54.23712056023734, 53.47620248794556, 52.11486973081316, 45.096271991729736, 43.65921081815447, 49.68387222290039, 58.45398575919015, 56.31588608877999, 52.515659196036204, 52.76302201407296, 51.58923503330776, 54.79003735951015, 50.9614965575082, 56.301142011369976, 53.47196408680507, 44.19760935647147, 40.68361003058297, 41.82477521896362, 51.15461826324463, 42.68147768293108, 51.163181918007986, 55.59652866636004, 55.84392275129046, 54.96759510040283, 54.05352136066982, 55.88169315883091, 54.994453362056184, 56.43761852809361, 53.66351897375924, 53.40058524268014, 52.50181143624442, 58.884315490722656, 51.137824467250276, 53.02585499627249, 55.283369881766184, 54.51182801382882, 46.639571121760774, 42.13256304604666, 40.883718150002615, 43.35319825581142, 41.42656353541783, 41.68101004191807, 39.09409843172346, 48.508671283721924, 45.76277446746826, 43.52051087788173, 44.4330039024353, 41.65867158344814, 40.14984246662685, 45.06123570033482, 44.862433842250276, 45.82686465127127, 46.477400166647776, 46.167208262852256, 44.48421560014997, 48.18639298847744, 47.087799412863596, 49.90731239318848, 48.413494859422954, 51.02033390317644, 48.297574588230674, 50.23737614495413, 48.16901901790074, 53.8565468788147, 54.16219466073172, 62.44032709939139, 65.45229475838798, 69.73869405473981, 62.417960848127095, 65.13839599064418, 67.08410699026925, 69.60076536451066, 65.90356636047363, 67.68693964821952, 61.50488417489188, 84.03939996446881, 30.445248331342423, 0.19864841417542525, 0.12295374806438174, 0.15635295159050397, 0.06507041584700346, 31.647908551352366, 77.41007505144391, 58.04972219467163, 38.930068833487375, 23.27096230643136, 40.709248883383616, 57.070165157318115, 9.887701749801636, 0.65000902648483, 0.14026674548430101, 0.10168445043798004, 0.04304176289588213, 0.079299810874675, 0.048608945948737006, 0.1414158988211836, 0.057937370746263435, 0.09453652506428105, 0.1774250737258366, 0.1692724483353751, 0.11760516863848482, 0.1765243456299816, 0.12394039226429802, 0.16832513202513966, 0.218861510977149, 0.14984563791326114, 0.19422063391123498, 0.39143032314521925, 24.43193507194519, 82.10921124049595, 46.01867314747402, 55.39373854228428, 64.76785550798688, 60.34502138410296, 93.63625185830253, 19.650495733533585, 0.710057258605957, 1.6707852206059863, 3.1528825547013963, 44.43632861546108, 95.27197592599052, 82.15156745910645, 84.12634972163609, 74.77575588226318, 72.68698147365025, 62.8418357031686, 63.341765539986746, 66.06900991712297, 66.78736332484654, 67.34088461739677, 72.53296770368303, 70.94895212990897, 71.02274894714355, 70.76118401118687, 70.58904239109584, 70.91789368220738, 71.54874147687639, 71.10839939117432, 65.2648115158081, 62.3361805507115, 56.923811776297434, 54.62657403945923, 53.135605267116, 54.3874900000436, 51.77575247628348, 54.46396882193429, 52.84671654020037, 50.59154667173113, 48.192153045109336, 49.63249724251883, 49.38419989177159, 50.22583866119385, 53.68047257832119, 53.79696260179792, 46.91510541098458, 44.31958498273577, 45.093159198760986, 43.38919687271118, 46.2013829776219, 47.07373625891549, 43.38633074079241, 46.13036543982369, 46.92068134035383, 45.92304856436593, 50.63855470929827, 57.96164335523333, 64.57700933728898, 62.413639068603516, 63.70809541429792, 58.943903241838726, 54.592802320207866, 55.143516540527344, 59.678008215767996, 62.22729533059256, 59.41471317836216, 59.604072434561594, 56.816159861428396, 57.190157072884695, 56.298637185777935, 49.49988392421177, 43.443076678684776, 51.70016302381243, 59.27199717930385, 56.045232909066335, 53.704634938921245, 54.94166094916207, 56.140544823237825, 55.10520764759609, 54.494391509464805, 56.85621970040457, 55.84762266704014, 43.30099991389683, 43.20277670451573, 46.44160999570574, 52.676589897700715, 43.49074132101876, 52.67434910365513, 60.0845890045166, 57.334297452654155, 57.450200353349956, 55.506504331316265, 62.27613421848842, 58.176773480006624, 57.6410847391401, 57.35279355730329, 56.88793475287301, 56.2727620942252, 64.61511325836182, 55.78647157124111, 55.23230062212263, 57.818194321223665, 57.32010923113142, 49.326137270246235, 43.815566131046836, 42.78057289123535, 43.6931597164699, 41.49228654588972, 42.54499421800886, 39.92034346716744, 49.18901457105364, 50.45632083075387, 46.4062089238848, 47.523691177368164, 44.271767480032786, 43.16011129106794, 48.964452266693115, 48.301701818193706, 48.68084764480591, 48.76013353892735, 49.34517880848476, 48.083549227033345, 51.476323332105366, 49.61256633486067, 54.31565604891096, 52.32358666828701, 55.92433772768293, 52.43101971490042, 52.532748290470664, 49.85998821258545, 56.724172660282676, 56.7545918737139, 65.5795510155814, 69.02984578268868, 72.93633842468262, 63.83348955426897, 67.57294750213623, 69.09648595537458, 72.47240720476422, 67.30244023459298, 71.98877784184047, 66.67061969212124, 84.16805975777763, 31.019979000091553, 0.42845610635621206, 1.2006603330373764, 0.256852320262364, 0.17003144403653486, 39.26084130150931, 81.14243194035122, 63.66614219120571, 51.6035726411002, 43.91857317515782, 44.472090993608745, 68.46490165165493, 10.95848342350551, 0.732889039175851, 0.3118644111922809, 0.30156004269208225, 0.21585296812866414, 0.20361311919987202, 0.23089512597237313, 0.23191998526453972, 0.08542962159429278, 0.29394058297787395], [0.07430536566036088, 0.07953073669757162, 0.03005977307579347, 0.12076768465340137, 0.14266995367194923, 0.13567078353038856, 0.1502192257238286, 0.05433031929922955, 0.17517260887793132, 0.17668355708675726, 25.638703414372035, 53.52437782287598, 30.44906289236886, 45.47029004778181, 42.71525635038103, 46.76465259279524, 79.28904860360282, 8.766626409121923, 0.2931467784302575, 0.5921262981636184, 2.24831851039614, 44.679334912981304, 84.26759270259312, 74.02337714603969, 76.80563041142055, 69.27594402858189, 62.20821557726179, 58.33777713775635, 58.531472069876536, 61.24364580426897, 64.07020078386579, 64.8184870311192, 64.43446704319545, 67.06725066048759, 68.43326650347028, 67.6379062107631, 68.22252069200788, 68.97519125257219, 65.44909858703613, 62.15400573185512, 59.919423375810894, 55.917403425489155, 53.227641105651855, 48.993933473314556, 48.135257720947266, 51.16580138887678, 48.52701105390276, 48.26107917513166, 48.30773285457066, 46.91950362069266, 43.198666845049175, 42.187207153865266, 44.11076382228306, 45.05033050264631, 47.10971403121948, 49.056481157030376, 46.260043144226074, 43.445459910801475, 43.61452695301601, 44.21742214475359, 45.51054791041783, 44.38067701884678, 42.03904724121094, 42.603240966796875, 44.43004396983555, 42.136784076690674, 44.466688769204275, 47.98477363586426, 54.87743527548653, 55.70679657799857, 57.09797532217843, 55.351747104099815, 50.33656515393938, 50.22626944950649, 50.13216304779053, 52.49328599657331, 54.362556389399934, 57.15454060690743, 54.72568661825997, 46.29881061826433, 43.460999556950156, 38.47695248467581, 37.01127862930298, 44.625528063092915, 53.83085938862392, 53.174268518175396, 52.14247839791434, 52.47261510576521, 50.55458920342581, 49.15806382043021, 48.849640233176096, 53.280273709978374, 49.40254313605172, 40.43357910428728, 35.85963555744716, 38.820923055921284, 50.0208911214556, 42.37214388166155, 46.18461350032261, 52.28284590584891, 51.65578140531267, 51.717943464006694, 53.375151361737935, 54.17882169995989, 50.20983348573957, 51.14640549251011, 52.29019709995815, 51.52629130227225, 53.35712773459298, 50.3228702545166, 47.32321827752249, 52.74012769971575, 52.41448647635323, 45.43303033283779, 39.57471922465733, 41.9942695753915, 43.189335414341514, 41.72598225729806, 40.95648315974644, 42.37491968699864, 39.01486117499215, 43.96121426991054, 45.30701780319214, 38.43834481920515, 40.64274072647095, 41.72129569734846, 35.752807004111155, 41.33436441421509, 45.12746592930385, 42.869381291525706, 43.97773708615984, 41.33733824321202, 45.11030387878418, 43.4722660609654, 43.01209034238543, 43.46598488943917, 43.300791467939106, 44.679765701293945, 46.60153668267386, 46.37429237365723, 48.55472394398281, 51.5669903755188, 56.45203604016985, 60.050230162484304, 65.61124174935478, 62.446636063711985, 59.625604901994976, 64.92633696964809, 64.83972072601318, 68.13345868246896, 65.15319565364292, 70.54401806422642, 67.16075256892613, 60.86313465663365, 48.482698917388916, 0.7812395447066852, 0.5119078255125454, 0.39096221540655407, 0.34253519826701706, 16.306682109832764, 68.29969433375767, 46.86886167526245, 46.367705481392996, 33.95191035951887, 23.783855744770594, 50.51153121675764, 10.922108735357012, 0.1583229015980448, 0.10260020808449813, 0.035697513592562506, 0.0023331551721119986, 0.07522910287869827, 0.10812123040003435, 0.10106498867805515, 0.02870943071320653, 0.053957203070500066, 0.061017030850052834, 0.10268253473831074, 0.038735097739845514, 0.05398294668910759, 0.08064199385366269, 0.06275940021233899, 0.12625321958746227, 0.049504551105201244, 0.18590862064489297, 0.0762401811246361, 39.07893746239798, 58.440478461129324, 39.46543100902012, 42.23841190338135, 45.31379577091762, 56.71383721487862, 84.65217549460274, 8.815862212862287, 0.30026477362428394, 0.09287747980228492, 3.3233312027794972, 56.87319762366158, 84.57400826045445, 78.17266069139752, 78.74526173727853, 73.07751887185233, 65.7398806980678, 61.472192900521414, 60.737969807216096, 63.72646645137242, 67.17013958522251, 67.34629031590053, 68.35634299686977, 69.67111587524414, 70.58995260511125, 69.47390515463692, 70.18358026232038, 70.78096553257534, 68.96909768240792, 66.28792681012834, 62.915243421282085, 58.85303470066616, 55.824394839150564, 52.02192367826189, 51.16235160827637, 52.98697635105678, 51.296611649649485, 50.20762395858765, 50.99726240975516, 48.33310420172555, 44.64848838533674, 44.751589230128694, 46.40532650266375, 46.340607506888254, 49.000895568302695, 50.37356778553554, 45.72533062526158, 43.469396454947336, 44.470221928187776, 44.57040105547224, 44.43143360955374, 45.48654535838536, 42.02387932368687, 44.37408665248326, 44.1456298828125, 45.3178048815046, 45.98334503173828, 49.400027888161794, 56.763190269470215, 58.01065942219326, 58.807489258902415, 57.84712314605713, 51.9283036504473, 50.73877899987357, 51.99184145246233, 53.928026471819194, 57.77037681852068, 59.08801582881382, 57.14898204803467, 50.94611324582781, 47.7489378792899, 42.70564351763044, 41.38028505870274, 45.29665456499372, 55.03311313901629, 55.084800788334434, 52.69983162198748, 54.435429096221924, 52.65164239065987, 52.0576617377145, 49.91258955001831, 55.120524951389854, 50.20886421203613, 42.56375435420445, 37.04356343405587, 44.841123717171804, 52.63365003040859, 44.403025899614605, 50.18697738647461, 53.67122105189732, 53.72655650547573, 53.933800424848286, 54.79704809188843, 54.606299195970806, 52.86646679469517, 53.98685686928885, 54.65475593294416, 55.4169351032802, 55.920043740953716, 51.18225472314017, 50.15409503664289, 55.11516441617693, 54.36216729027884, 46.901646750313894, 40.841407094682964, 43.13709190913609, 42.96327577318464, 42.32363503319876, 40.98004102706909, 41.21559885569981, 38.76240880148751, 45.77005965369088, 47.14712313243321, 41.788432666233604, 43.82334811346871, 43.155678340366904, 39.325522082192556, 43.56043522698538, 46.79652050563267, 45.560616629464285, 46.09999833788191, 44.32735306876046, 47.31989009039742, 45.357034410749165, 45.781968866075786, 47.01429441996983, 46.62277732576643, 47.240392276218955, 49.37902348382132, 49.00028412682669, 51.54204286847796, 54.97727394104004, 59.5772384916033, 64.97847625187465, 66.71196147373745, 63.64889676230294, 63.633714948381694, 67.88499804905483, 67.6939503805978, 71.17094707489014, 67.57695661272321, 72.00637068067277, 68.80903203146798, 64.1123138155256, 56.86092363085066, 1.2532482083354677, 0.5787391822252954, 0.3114928996988705, 0.37240561257515636, 18.214918000357493, 75.02318818228585, 54.60137987136841, 52.301373277391704, 26.169022934777395, 32.18318040030343, 61.026980127607075, 19.656535455158778, 0.16487935478133814, 0.0453657792615039, 0.08673380661223616, 0.026666902903733507, 0.052787211923194785, 0.10138165418590818, 0.046312552743724415, 0.003467292316989707, 0.09285374464733259, 0.2613464748220784, 0.15289261298520224, 0.13918602918939932, 0.2474733106791973, 0.22871751710772514, 0.18633147009781428, 0.22973860374518804, 0.15379848437649862, 0.23930950303162846, 0.19928022527268954, 43.8136762210301, 70.14193970816476, 40.19504744665963, 58.88378742762974, 60.77450343540737, 58.52685151781355, 94.50367191859654, 9.448369758469717, 0.2989090606570244, 0.6285375186375209, 4.604548624583653, 64.56364795139858, 84.8064741407122, 81.86632306235177, 80.57108157021659, 78.01425565992082, 67.0058285849435, 65.44705581665039, 62.176622118268696, 68.74116897583008, 69.50277491978237, 71.19373021806989, 71.46664851052421, 72.96807084764752, 73.28165694645473, 73.97512190682548, 73.43118912833077, 74.92632334572929, 70.78502328055245, 67.70697825295585, 64.66643960135323, 61.44122477940151, 57.69901187079293, 53.74234281267439, 51.24769285746983, 57.405085699898855, 53.08276421683175, 51.61168813705444, 53.14487068993704, 52.2861567224775, 47.42792763028826, 47.28479126521519, 49.97716610772269, 49.51624345779419, 52.423800536564414, 51.732246330806184, 45.695856366838726, 44.296798365456716, 44.305108410971506, 44.44925226484026, 46.03607143674578, 46.78532348360334, 44.62669883455549, 47.09535905293056, 48.346337045942036, 47.75783157348633, 48.52433252334595, 52.527186257498606, 57.92998736245291, 59.63687488010952, 62.48990944453648, 60.38412584577288, 54.46101931163243, 54.684153761182515, 55.50648348672049, 57.43885047095162, 58.44357735770089, 63.59871687207903, 60.20090184892927, 53.902130535670686, 50.998658997671946, 47.61534139088222, 42.93876600265503, 46.28737040928432, 56.23205259868077, 58.308170863560264, 55.889902455466135, 57.128269468035015, 53.900390011923655, 54.38242128917149, 50.96720450265067, 56.66483851841518, 51.18300860268729, 40.8638254574367, 40.988576889038086, 46.264990261622835, 54.0021151133946, 44.837104184286936, 50.26183032989502, 55.62166724886213, 57.19154323850359, 55.43189804894583, 57.28374235970633, 58.212261404309956, 55.88169315883091, 56.553861890520366, 57.35886975697109, 57.2677823475429, 59.41176019396101, 55.369395528520855, 52.11764901024954, 59.31258160727364, 58.38530281611851, 49.90604087284633, 43.515126023973735, 46.85187332970755, 46.399201665605815, 43.17179121289934, 42.12188366481236, 42.82818194798061, 38.97064283915928, 45.7715048789978, 49.966702120644705, 43.970649923597065, 47.15331050327846, 46.58849491391863, 40.63656030382429, 47.270363330841064, 49.32596009118216, 49.01829038347517, 48.230646065303254, 46.4117431640625, 51.6027284349714, 49.13624995095389, 49.87349898474557, 49.79577643530709, 49.08622986929757, 52.13524532318115, 53.01290702819824, 51.53795732770647, 54.647658348083496, 59.083687101091655, 62.1694724219186, 67.72359834398542, 70.61700889042446, 66.55414703914097, 66.12820856911796, 70.22925771985734, 70.39611176082066, 74.7156400680542, 70.05366284506661, 74.22165094103131, 72.36282021658761, 70.74295193808419, 55.647465910230366, 1.4769388394696372, 1.0181131341627665, 0.9244934320449829, 0.4579304190618651, 23.851374864578247, 79.3310296194894, 61.7086956841605, 60.69852488381522, 51.9169259752546, 36.52978583744594, 71.09163338797433, 24.086460215704783, 0.6134434257234845, 0.18203284218907356, 0.15536680950650147, 0.11524275397615773, 0.1808081136218139, 0.16001693212560245, 0.13935179529445513, 0.20785751858992235, 0.16478385776281357], [0.018486846038805585, 0.049222548558775864, 0.12823752739599772, 0.05508215645594256, 0.058561025852603574, 0.07540407670395714, 0.056930322998336384, 0.10173726760383163, 0.0899221340992621, 0.21607543261987822, 39.346641131809776, 52.71392256872994, 24.030059950692312, 31.696500778198242, 42.86242267063686, 53.94417061124529, 74.2338033403669, 2.988060644694737, 0.05894837435334921, 1.465122776372092, 3.7896152564457486, 49.72555794034685, 84.42691489628383, 78.41218594142369, 79.82251044682094, 72.43877792358398, 63.81603567940848, 58.71885803767613, 62.14970479692732, 63.67616149357387, 62.86255523136684, 68.62637083871024, 70.56556442805699, 69.45545768737793, 67.54113170078823, 67.27555070604596, 67.23450074877057, 66.96530669076103, 65.78642668042863, 62.862610816955566, 60.70327745165144, 53.86893204280308, 51.38534014565604, 48.63102906090872, 49.53501749038696, 48.37896926062447, 49.49767092296055, 48.24097803660801, 46.67784179959978, 45.12360273088728, 44.95770754132952, 41.93834005083357, 44.03701564243862, 43.776694434029714, 48.56529910223824, 49.63006884711129, 44.85463796343122, 43.65072359357561, 44.13080242701939, 44.06189366749355, 45.367470605032786, 43.03272649220058, 41.826140539986746, 43.98712757655552, 44.42379753930228, 42.78407825742449, 43.559382574898855, 43.73603704997471, 49.08834906986782, 52.15397419248308, 53.828861781529014, 55.29914229256766, 52.10222053527832, 49.78711550576346, 49.71355492728097, 52.0618827683585, 54.2860289301191, 57.87952954428536, 56.345860617501394, 49.2151015826634, 43.222412313733784, 40.069434438432964, 45.91537080492292, 47.74677351542881, 52.16428531919207, 49.76263352802822, 42.69446734019688, 45.96745102746146, 46.01136711665562, 44.160210677555625, 44.216035979134695, 41.20420381001064, 44.33460003989083, 37.31303889410836, 33.50063875743321, 39.206266675676616, 51.92772694996425, 45.78672143391201, 45.4430878502982, 53.91923700060163, 50.550767694200786, 55.2497683933803, 50.60969189235142, 47.89241123199463, 48.937458515167236, 50.795243535723, 53.02110937663487, 51.3561646597726, 52.797089031764436, 53.63438170296805, 50.14059121268136, 55.56480319159371, 48.87428549357823, 41.02425936290196, 40.39709063938686, 41.07186147144863, 40.836195945739746, 40.30134098870413, 41.25900425229754, 40.009700775146484, 38.77280330657959, 41.85294669015067, 46.97118779591152, 38.341552938733784, 39.005863257816856, 39.688926764896934, 38.10951437268938, 39.02519314629691, 44.55233921323504, 44.20432826450893, 44.368333544049946, 44.24610430853707, 42.413221631731304, 44.30306911468506, 44.1538530758449, 42.89046212605068, 44.356677940913606, 43.914164543151855, 45.527508463178364, 46.569960594177246, 51.02340153285435, 54.84086343220302, 59.22313744681222, 60.55810179029192, 64.86869471413749, 62.91101196834019, 65.41727583748954, 63.37950815473284, 69.11528083256313, 66.69734246390206, 72.81172248295375, 64.78179359436035, 73.03681632450649, 60.09117589678083, 59.15505204881941, 9.332036937986102, 1.7801689739738191, 0.8217049304928098, 0.5630902647972107, 9.127052051680428, 64.93649523598808, 53.908380440303254, 46.26998601640974, 43.31333644049508, 36.68301446097237, 46.113641125815256, 21.453992741448538, 0.47179603789533886, 0.0663300414702722, 0.01123432703648827, 0.04210939471210752, 0.07607835730803864, 0.05541986333472388, 0.08207595547927277, 0.058894111907907894, 0.13405029262815202, 0.018127161410770247, 0.035068226645567586, 0.11480351111718587, 0.09311569309128181, 0.03494638889761908, 0.15704885710562977, 0.06224207154342106, 0.06865658877151352, 0.1311678487275328, 0.44089921723519054, 50.08360208783831, 62.29101031167166, 31.147662571498326, 33.55626603535244, 51.017617157527376, 60.050952775137766, 81.55218805585588, 2.5950622814042226, 0.030615910555102994, 1.4158840413604463, 6.434553010123117, 61.51756463732038, 81.57443618774414, 83.60088525499616, 81.2435073852539, 75.69087532588414, 63.37813935961042, 61.936068534851074, 64.69725486210415, 67.04931041172573, 67.28461115700858, 71.7639410836356, 69.99621513911656, 71.04134927477155, 69.78402410234723, 70.5511052267892, 69.2637221472604, 69.12535572052002, 68.8761238370623, 65.09367043631417, 64.72206687927246, 57.89102533885411, 53.54785231181553, 52.004587922777446, 52.23742553165981, 48.74546589170183, 50.86546550478254, 49.24010467529297, 49.05620322908674, 47.31704132897513, 45.77495813369751, 46.51520878928048, 46.03879860469273, 47.99003689629691, 50.1311034475054, 49.973073618752615, 45.92448336737496, 44.89811979021345, 44.821863310677664, 43.23306737627302, 44.579701219286235, 43.73363644736153, 43.00082036427089, 46.74757392065865, 45.86635821206229, 45.20723819732666, 47.38198961530413, 47.908485889434814, 52.09217691421509, 54.283544949122835, 56.66198975699288, 56.18728535515921, 53.12024280003139, 51.65577793121338, 51.50860813685826, 53.11815486635481, 58.03277553830828, 61.35842309679304, 57.43589401245117, 51.75992100579398, 48.45866509846279, 44.52222919464111, 47.58065250941685, 48.46258735656738, 53.568366868155344, 51.79461683545794, 42.436265332358225, 48.11750854764666, 46.35581711360386, 42.4578012738909, 45.03007302965437, 41.13502754483904, 44.34481389181954, 38.48452949523926, 36.58763653891427, 43.15327773775373, 54.422832012176514, 48.07538161958967, 48.0333137512207, 56.19622073854719, 52.594722747802734, 56.71935755865914, 49.668516704014365, 48.264716557094026, 51.28269093377249, 55.19415848595755, 54.483013834272114, 54.254185335976736, 55.334633690970286, 57.04443597793579, 54.13071584701538, 57.81172554833548, 49.271298612867085, 42.10567351749965, 42.03697667803083, 43.24319437571934, 41.570453780038015, 40.408582959856304, 40.99215521131243, 39.34475816999163, 38.90687574659075, 41.554281847817556, 49.01010887963431, 42.15214654377529, 42.899341923849924, 43.75972693307059, 40.03698287691389, 42.55664982114519, 46.94285304205758, 46.92168882914952, 46.23409857068743, 45.62483882904053, 45.15821865626744, 45.91827515193394, 45.83555337360927, 46.96626499720982, 46.31363459995815, 46.25873340879168, 48.61368983132498, 49.970481940678184, 53.25390182222639, 58.07350240434919, 61.46086038861956, 63.9607458114624, 66.49920068468366, 65.29814897264752, 68.71178504398891, 66.58729689461845, 70.5185946055821, 68.61001477922711, 73.78884070260185, 67.97176715305874, 75.43802343096051, 63.68832084110805, 64.56222357068742, 12.325386030333382, 1.6263395484004701, 0.29843832020248684, 0.5387851404292243, 9.046583226748876, 70.97398648943219, 60.73146629333496, 54.33044876371111, 38.77575281688145, 40.83061306817191, 58.1878593308585, 31.493536949157715, 0.39944634586572647, 0.0047229099187201685, 0.09148516665611948, 0.03965019381472042, 0.12759078852832317, 0.07946212323648588, 0.05773509945720434, 0.06893195863813162, 0.062413944463644705, 0.15065103183899606, 0.15787367070359842, 0.2228856986122472, 0.253431852374758, 0.22382171052907193, 0.2837417402437755, 0.1296323375510318, 0.1776377401713814, 0.118621790515525, 0.36299940730844227, 57.17983552387783, 69.32562364850725, 32.4317661012922, 45.33503293991089, 59.1252373286656, 66.53754084450858, 89.29705320085797, 4.096221889768328, 0.10250211227685213, 2.6274777991431097, 9.431533404758998, 67.19959994724819, 84.85563264574323, 86.25076838902065, 85.46982560838971, 78.52282905578613, 67.51973124912807, 64.64224597385952, 67.97504670279366, 69.90598583221436, 67.98081370762416, 75.02509198869977, 72.1368717466082, 74.54635415758405, 73.66825471605573, 72.9093724659511, 71.55192375183105, 74.6389389038086, 71.24106829507011, 68.57865755898612, 66.052091053554, 60.98224067687988, 57.08207089560372, 54.90309844698225, 54.47860867636544, 51.81173372268677, 52.53827905654907, 51.3002108165196, 50.65015125274658, 49.95272581917899, 49.79504687445504, 48.05896650041853, 48.707111835479736, 49.55688694545201, 51.96893671580723, 51.679182938167024, 45.54810292380196, 44.51566662107195, 47.10640321459089, 43.7770140511649, 45.19232388905117, 44.482499395098, 43.03996304103306, 48.48600278581892, 48.69833626065935, 48.7554817199707, 49.78153610229492, 50.399064200265066, 54.184776306152344, 56.01006460189819, 59.693725040980745, 58.22113077981131, 56.01895482199532, 54.83646869659424, 54.822891916547505, 56.72033378056118, 60.26879964556013, 64.09759058271135, 60.30874483925955, 53.982993670872276, 52.601521560123985, 49.34107937131609, 48.10868780953543, 47.91400970731463, 54.03011982781546, 52.18953854697091, 42.639976092747276, 49.74661793027605, 50.49251399721418, 44.54140969685146, 44.54080867767334, 41.40904017857143, 43.418646812438965, 38.71515757696969, 37.27106830051967, 48.9065876688276, 56.36355767931257, 49.16231959206717, 51.30786425726754, 60.76135744367327, 55.70674794060843, 57.588365282331196, 52.750028882707866, 51.256419794900076, 53.00401333400181, 58.249767780303955, 57.162148884364534, 56.769923073904856, 57.72679076875959, 57.80409990038191, 55.8404278073992, 62.01274190630232, 53.79474612644741, 45.3824439729963, 45.440475327628, 45.68004921504429, 41.90160492488316, 40.85626234327044, 41.21553284781319, 40.965467180524556, 39.47779532841274, 42.7085165977478, 51.17679691314697, 44.00696120943342, 45.35097558157784, 46.43076385770525, 41.99658332552229, 45.16815805435181, 50.34857858930315, 50.42250394821167, 49.47804921013968, 47.77192946842739, 46.65271711349487, 50.19924095698765, 51.085164070129395, 48.76730407987322, 49.66843332563128, 49.73792225973946, 52.5845262663705, 52.33929654530117, 56.508156640189036, 61.564367703029085, 64.95066261291504, 66.46820477076939, 68.0899907520839, 67.74067701612199, 71.85956219264439, 70.9744450705392, 73.6877305167062, 71.56003229958671, 76.11564649854387, 72.24841812678746, 78.05830723898751, 66.8987568446568, 69.56245994567871, 11.714420505932399, 2.374119988509587, 2.368881481034415, 0.8968965443117278, 13.704659904752459, 76.6908461706979, 66.56740420205253, 61.9229850769043, 63.601350239345, 51.846408707754954, 63.91695826394217, 41.63762896401541, 0.6571906954050064, 0.2280898993568761, 0.1181515386062009, 0.17411857257996285, 0.22065202918435844, 0.23152982762881688, 0.18133707238095148, 0.1619474728192602, 0.2084113388721432], [0.054961441683449914, 0.13133655967456953, 0.061006649264267514, 0.029980194488806382, 0.06406557333788701, 0.09266754785286528, 0.04122649173119238, 0.09713704445000206, 0.09447814391127654, 1.5839966833591461, 50.14900548117501, 46.71327413831438, 36.57973991121565, 42.05151925768171, 41.85423558098929, 61.675184522356304, 61.985254832676475, 0.501133395092828, 0.05586346917386566, 1.8728812847818648, 3.19933842761176, 52.22169828414917, 79.81065682002476, 76.57974447522844, 78.43887397221157, 71.99340534210205, 66.17792293003627, 58.82511683872768, 65.44255338396344, 65.95448970794678, 71.12190668923515, 67.89345400674003, 69.28966672079903, 65.42909472329276, 69.02801145826066, 65.08671528952462, 64.92462076459611, 62.049511773245676, 58.34234210423061, 55.15150349480765, 54.407226358141216, 49.06081335885184, 47.81668628965105, 48.79093490328108, 48.67787381580898, 48.91999421800886, 47.540370328085764, 48.14590930938721, 48.50277573721749, 46.8463773046221, 43.27452380316598, 43.286801270076204, 44.75399678094046, 44.41958345685686, 47.940795012882774, 47.38442495891026, 45.695571490696494, 44.34154823848179, 42.89463799340384, 42.89486380985805, 43.42955548422677, 42.321623529706685, 43.362255232674734, 42.80470051084246, 43.93303237642561, 42.41460084915161, 43.91625247682844, 41.68463700158255, 46.17842960357666, 48.96297924859183, 50.55674661908831, 52.98855011803763, 52.29775674002511, 50.81424685886928, 48.2727313041687, 49.826480524880544, 55.53828886577061, 55.508974415915354, 54.317726612091064, 46.48594645091465, 38.20415578569685, 46.664122581481934, 41.1962377003261, 44.85105616705758, 48.41808067049299, 43.70080968311855, 42.21958923339844, 40.11708171027047, 45.27725172042847, 42.060336521693635, 41.94100815909249, 41.11173718316214, 39.656926836286274, 38.12520687920706, 39.808022362845286, 34.22607237952096, 49.04019110543387, 43.26883670261928, 46.30164200919015, 50.63503197261265, 52.66531297138759, 52.509829657418386, 40.591021810259136, 51.997375692640034, 51.92342948913574, 52.63952473231724, 50.092405455453054, 52.41248886925833, 52.88232953207833, 53.89230578286307, 50.3699060848781, 49.000339712415425, 40.50338765553066, 39.07534524372646, 38.424517904009136, 41.00179236275809, 40.59148039136614, 39.20975467136928, 40.41860573632376, 40.84166070393154, 40.51061725616455, 40.13979884556362, 44.12795713969639, 40.157700879233225, 40.25935649871826, 39.05758564812796, 36.93320172173636, 38.931489740099224, 43.94782509122576, 44.78987727846418, 44.27641929898943, 42.83242382322039, 45.094580105372835, 44.16546351569039, 43.57089573996407, 43.87601893288748, 44.387232644217356, 42.87531157902309, 42.6068366595677, 47.34754392078945, 50.500771931239534, 55.51881306512015, 57.55901261738369, 59.71231147221157, 62.86944089617048, 62.15976578848702, 62.84442738124302, 65.16875267028809, 66.67523329598563, 67.15060125078473, 67.55873148781913, 67.73047011239188, 73.12524604797363, 66.25300516401018, 75.82712255205426, 24.87071555001395, 0.677078611084393, 0.18571781659764902, 0.17161124997905322, 1.7981629627091544, 56.52795205797468, 62.076943261282786, 47.530097416469026, 37.933759689331055, 19.571486030306133, 41.48874296460833, 28.425269774028234, 0.2280141477073942, 0.022142399168972458, 0.0696432940395815, 0.032482777522610765, 0.14477216372532503, 0.06224152193005596, 0.10724212721522365, 0.07740848950509514, 0.10770439955272845, 0.004031853808555752, 0.0709304071164557, 0.048011947090604475, 0.039067512045481374, 0.02326182079767542, 0.0620678983894842, 0.059053859407348294, 0.05634755641222, 0.11832711632762637, 2.436087931905474, 62.191755294799805, 54.783950737544465, 36.18760790143694, 37.44260890143258, 51.33917284011841, 68.28871617998395, 66.8505780356271, 0.2798830472997257, 0.051781490711229186, 2.5335629071508134, 7.351275750568934, 59.939121518816265, 80.22832693372453, 78.67152050563267, 78.55637495858329, 75.17567334856305, 70.18313557761056, 63.77516637529646, 66.52800096784318, 69.88944217136928, 72.26471860068185, 72.14244420187813, 71.98462281908307, 66.38229724339077, 71.1615183694022, 67.65514469146729, 67.18502262660435, 65.48361028943742, 60.10414123535156, 58.0627326965332, 55.62817423684256, 52.34687008176531, 50.90419823782784, 51.55140209197998, 50.834768363407676, 49.36472061702183, 49.528586932591026, 50.92528602055141, 50.09801265171596, 48.15538317816598, 44.99097204208374, 45.28086825779506, 45.977567604609895, 45.09582730701992, 48.53484862191336, 48.787467752184185, 44.619823592049734, 44.07387236186436, 43.54190438134329, 43.787422452654155, 43.32176807948521, 41.797166551862446, 42.63978501728603, 43.649653570992605, 46.85891532897949, 44.61137458256313, 45.775166579655235, 43.69933666501726, 47.86291265487671, 51.430572918483186, 52.80656290054321, 53.14103528431484, 55.00331578935896, 54.11574247905186, 51.225788661411826, 53.06959390640259, 58.572897229875835, 57.23795025689261, 56.06260340554373, 49.578169277736116, 44.0550149508885, 49.82741853169033, 42.08113595417568, 45.93815047400338, 46.85334982190813, 43.954047203063965, 42.25908974238804, 42.201697622026714, 47.64912005833217, 42.871104444776265, 40.81012977872576, 42.05521222523281, 40.90489625930786, 38.73119401931763, 40.117300578526084, 40.04797145298549, 50.74596343721662, 44.07549129213606, 48.83861691611153, 53.67424699238369, 55.82151828493391, 52.23929459708077, 43.49448292595999, 53.497425760541645, 53.63212701252529, 54.92048283985683, 52.65828834261213, 54.7816230910165, 55.446391991206575, 55.9358925819397, 52.31739582334246, 50.07540668760027, 42.68918670926775, 41.736922195979524, 40.657960755484446, 41.56220279421125, 41.2782438141959, 38.80187109538487, 41.730988434382844, 41.29558651787894, 41.117521558489116, 41.02102845055716, 47.00091913768223, 45.27447591509138, 41.92764677320208, 42.42523506709507, 41.045496531895225, 41.09070151192801, 44.517146587371826, 46.703157561165945, 47.67742701939174, 45.7869541985648, 46.59490810121809, 45.864461353846956, 47.67366109575544, 46.52940048490252, 47.45481021063668, 45.91701405388968, 47.457387992313926, 50.61262403215681, 53.555057593754356, 57.897883210863384, 60.80711133139474, 63.092297417776926, 66.30139936719621, 65.29559898376465, 65.15032604762486, 66.16647229875836, 67.14513996669224, 70.63163484845842, 70.06381416320801, 69.47109808240617, 73.62011064801897, 69.10382325308663, 78.2884246281215, 29.669902324676514, 0.7727100881082671, 0.3694560208490917, 0.11784055243645396, 1.4037946100745882, 60.866365568978445, 68.67584201267788, 55.77096666608538, 40.8075589452471, 24.878791093826294, 49.84682485035488, 41.4268136705671, 0.03565165141065206, 0.05304220538320286, 0.06413800695112773, 0.04731796522225652, 0.0848658268472978, 0.08438502371843372, 0.0099633062657501, 0.04706889198028615, 0.08469740767031908, 0.13309537672570773, 0.27666125446558, 0.1559514081371682, 0.12106938846409321, 0.13793282929275716, 0.1524170006492308, 0.11287372359739882, 0.19992970542183944, 0.2764687676514898, 3.0504732728004456, 71.01592581612724, 62.41431304386684, 45.74294430868966, 55.18844011851719, 57.47360536030361, 72.6072369984218, 73.29861749921525, 0.680302520947797, 0.1268706186009305, 3.281796608652387, 14.161057540348597, 63.729544503348215, 85.2547093800136, 84.14343534197126, 81.91263280596051, 78.5638095310756, 74.52861540658134, 64.43796198708671, 69.68604755401611, 75.13503333500454, 76.36257852826799, 73.42192717960903, 74.07471738542829, 70.9348611831665, 73.73271315438407, 69.84818376813615, 70.93618828909737, 69.41169793265206, 62.49038192204067, 59.89845371246338, 59.39525127410889, 54.98905461175101, 51.17422260556902, 53.94258989606585, 54.786730016980854, 51.47531236921038, 49.789411885397776, 52.7114212172372, 53.14583996364048, 51.92834186553955, 49.22199419566563, 48.97221687861851, 50.822959899902344, 46.21084295000349, 50.32219280515398, 50.059922627040315, 46.48067971638271, 43.62137787682669, 43.07201508113316, 43.711412634168354, 44.20125368663243, 42.27562992913382, 45.225557122911724, 45.1034494808742, 47.75850902284895, 46.752336910792756, 48.23692028863089, 45.23685836791992, 51.29524980272566, 54.45761469432286, 54.42058079583304, 58.500281606401714, 59.45082991463797, 54.48562288284302, 53.364260060446604, 54.66196468898228, 60.262851987566265, 60.484304973057334, 59.76151861463274, 51.94598681586129, 47.32213088444301, 51.91706493922642, 48.83590017046247, 53.08901412146432, 51.20376982007708, 43.364228521074565, 44.64023045131138, 44.94505834579468, 49.92179938725063, 44.91044589451381, 42.597734519413535, 41.14516149248396, 40.66710805892944, 40.87090914590018, 41.096082891736714, 42.579419067927766, 55.93412773949759, 47.02175331115723, 50.753210408346995, 57.510020869118826, 57.822484833853586, 55.73355061667306, 46.21429967880249, 54.113928999219624, 56.49240854808262, 55.95713669913155, 56.53388581957136, 56.94110584259033, 57.522489411490305, 58.52809524536133, 55.6786459514073, 54.9805326461792, 45.44368192127773, 44.12416342326573, 41.43775013514927, 43.00253656932286, 40.89776393345424, 40.04656791687012, 43.3396075793675, 41.0845627784729, 41.274609906332834, 40.87001977648054, 48.412431785038535, 45.97043875285557, 44.759273937770296, 44.59439665930611, 44.20886196408953, 45.067912919180735, 48.360063212258474, 49.628102506910054, 50.24804162979126, 49.29610368183681, 49.22604846954346, 49.37680006027222, 50.07851253237043, 48.034147535051616, 50.07314157485962, 48.6953832762582, 49.23840584073748, 54.11533600943429, 57.2225912639073, 60.98290770394461, 64.16239643096924, 66.02749443054199, 69.32122543879917, 69.06767872401646, 68.58087403433663, 69.98315947396415, 69.97238281794957, 71.83775874546596, 73.58208315713065, 73.18520900181362, 77.80343341827393, 73.99625832693917, 81.14239719935826, 31.03433745247977, 1.2879418666873659, 0.9798359423875809, 0.24204036220908165, 4.086108352456774, 70.21523625510079, 74.13375622885567, 63.289473397391184, 53.21885858263288, 31.57574108668736, 57.65665912628174, 50.8678765296936, 0.18547711308513368, 0.07575133735580103, 0.18612337697829517, 0.14662079167153153, 0.24688906488674028, 0.1953271616782461, 0.2573833146265575, 0.10210745595395565, 0.1469370297023228], [0.10650172337357487, 0.08168032885129962, 0.07018422894179821, 0.05765413665877921, 0.026415305511493768, 0.06588043738156557, 0.041429285492215834, 0.06440488155931234, 0.17551635471837862, 2.1476501865046362, 54.75411517279488, 42.165803228105815, 42.83823946544102, 38.157196385519846, 42.58712114606585, 72.28036594390869, 47.31944193158831, 0.04120484985677259, 0.05550569122923272, 2.9092415826661244, 1.5230556620018822, 63.65691498347691, 77.87066418784005, 78.5776503426688, 77.7280524117606, 71.78388936179024, 66.15739795139858, 66.05800397055489, 67.25037043435233, 68.83196803501674, 69.73702648707798, 66.99811608450753, 68.80236870901925, 66.68741348811558, 68.50652830941337, 63.74360070909773, 60.85836124420166, 52.31797252382551, 50.3553079196385, 48.981423241751536, 50.22354228155953, 49.97105169296265, 50.68474980763027, 48.37099272864205, 47.79242665427071, 47.553679602486746, 47.42409569876534, 47.39370427812849, 48.01892750603812, 43.60033873149327, 41.24880082266671, 43.31057105745588, 43.62267371586391, 45.35196222577776, 45.86311340332031, 48.86227900641305, 50.01660408292498, 49.289888518197195, 45.29125928878784, 46.04046269825527, 45.57294273376465, 42.899890831538606, 41.66190249579293, 45.026852539607454, 44.45712457384382, 43.474520751408164, 41.593709400721956, 43.664710317339214, 40.819839886256624, 42.58542578560965, 45.86877271107265, 48.37689869744437, 50.7847969191415, 49.3861870765686, 47.118513924734934, 44.94548566000802, 52.63587692805699, 57.96675722939627, 59.091712270464214, 51.415418897356304, 42.5647166797093, 42.60936232975551, 39.50900663648333, 44.14397273744856, 42.30950934546334, 43.99311692374093, 39.8511255128043, 40.048905985695974, 50.093538011823384, 46.0741024017334, 38.09057705742972, 44.155708244868684, 42.97762727737427, 39.79028013774327, 39.540030343191965, 45.929006644657676, 51.26351043156215, 43.284563950129915, 50.05646242414202, 55.37720877783639, 51.86855261666434, 47.46881430489676, 52.54645013809204, 54.99329648699079, 51.39810051236834, 51.99099724633353, 49.77945164271763, 52.587520939963206, 49.8739332471575, 48.724037647247314, 45.857600007738384, 39.31212942940848, 39.819598061697825, 39.19630295889718, 39.766354015895296, 41.83316516876221, 42.801250730242046, 40.89746863501412, 39.65841375078474, 38.83467354093279, 38.48232691628592, 41.548810141427175, 44.401559829711914, 41.678303718566895, 40.03507907049996, 40.213060651506694, 37.98916115079607, 38.015359333583284, 42.90242344992501, 45.88521214893886, 44.027645996638704, 42.98319278444563, 44.916775703430176, 43.04950639179775, 43.004791259765625, 43.62005077089582, 45.019814014434814, 43.53478247778756, 44.130781582423616, 44.04867124557495, 48.164454051426475, 51.45558990750994, 53.15182931082589, 54.61288608823504, 58.45693874359131, 58.58732863834926, 63.32831382751465, 62.732102802821565, 66.99960994720459, 66.0081923348563, 69.74463476453508, 64.33148779187883, 71.26658902849469, 64.72874409811837, 73.27043560573033, 42.18786375863211, 0.0550241552825485, 0.28128177938716753, 0.014491642027028968, 0.12080706682588373, 35.725768089294434, 67.65556158338273, 51.376196316310335, 37.68213415145874, 25.24203770501273, 40.78220844268799, 46.09278958184378, 0.26209788450172966, 0.08997678330966405, 0.13492888691169874, 0.1414334321660655, 0.08053905330598354, 0.08963184324758393, 0.01612304037969027, 0.050762300579143424, 0.047306331739361794, 0.05266703997871705, 0.06954124915812697, 0.035312207482222996, 0.05304001710776772, 0.023759889250089015, 0.09899089711585216, 0.07758936658501625, 0.1836534823690142, 0.1363260583685977, 4.098524349076407, 64.4368085861206, 45.87928186144148, 50.126354353768484, 40.17551258632115, 49.9405734198434, 79.92804663521903, 50.67564419337681, 0.06686700694262981, 0.08121685550681182, 5.901311772210257, 3.4892839321068356, 68.39751802171979, 81.42452880314418, 82.13713605063302, 77.4050931930542, 73.81411130087716, 69.76634093693325, 67.6573681150164, 71.20067146846226, 72.08591365814209, 71.66791697910854, 69.8127201625279, 72.71028573172433, 69.66873959132603, 71.29422201429094, 65.66861302512032, 63.113503319876536, 54.88992466245379, 52.62852225984846, 51.382147448403494, 52.867818219321116, 52.58112512316023, 53.322456223624094, 51.390276840754915, 51.14706557137625, 51.194292477199006, 50.07107448577881, 50.03221321105957, 49.475471428462434, 44.93154757363455, 44.60093144008091, 46.122343744550435, 46.20971734183175, 47.16857916968209, 47.7969707761492, 50.14720937183925, 50.867869581495015, 50.02794701712472, 47.741784708840505, 47.063282694135395, 45.18224900109427, 43.344224657331196, 43.14051737104143, 43.73603010177612, 45.22632837295532, 44.847418785095215, 43.109055927821565, 45.23916169575283, 43.38999591554914, 45.74379546301705, 48.08742979594639, 51.40314143044608, 51.4834417615618, 52.7314042363848, 50.561262948172434, 47.4732472555978, 55.45724160330636, 59.68846525464739, 61.44770050048828, 54.72048241751534, 47.276040009089876, 44.27623169762747, 46.44964906147548, 49.786007268088206, 44.10018171582903, 43.44265978676932, 42.27129077911377, 41.564457484654014, 51.722755091530935, 46.29415879930769, 39.81353575842721, 43.903787408556255, 42.390806743076865, 40.53120824268886, 42.43548018591744, 49.52017266409737, 54.29599264689854, 45.7203939301627, 51.97278254372733, 56.92900555474417, 53.8765993799482, 50.1518611907959, 54.7931501524789, 56.408998898097444, 54.18698583330427, 56.34793812888009, 52.14584827423096, 54.902476583208355, 52.72950390407017, 51.09132364818028, 46.49937037059239, 40.60513360159737, 41.291219575064524, 41.389706815992085, 44.64415965761457, 43.87614747456142, 44.27758312225342, 41.56154618944441, 38.657532691955566, 39.75804049628121, 40.42268432889666, 40.766092096056255, 47.225498812539236, 43.49867268971035, 43.21791335514614, 41.84930583408901, 40.48384237289429, 40.91220923832485, 45.21949481964111, 46.82749210085188, 45.91527700424194, 45.38246134349278, 48.57100009918213, 45.522328581128804, 45.875668798174175, 47.17053508758545, 47.423011779785156, 46.02201870509556, 46.84500503540039, 46.87527486256191, 50.52079316547939, 52.89017404828753, 56.06279795510428, 56.525186674935476, 59.379986081804546, 61.529821259634836, 64.11520426613944, 65.26208087376186, 69.91475445883614, 67.70535932268415, 72.55164446149553, 67.57606029510498, 72.6791022164481, 66.36925547463554, 75.51552363804409, 45.94205188751221, 0.09214825821774346, 0.734722875058651, 0.0661206930609686, 0.19372343059097016, 38.1613826751709, 74.52912957327706, 59.343688692365376, 43.28352519444057, 31.25539091655186, 50.71983821051461, 58.385066577366416, 1.549844658800534, 0.3660247235425881, 0.05700899913374867, 0.08332648194794144, 0.06275322554366929, 0.13556525776428835, 0.030307879405362264, 0.019748741361711706, 0.02870528486424259, 0.206898124356355, 0.1454942606921707, 0.1170051944042955, 0.16654720742787632, 0.11172572377004794, 0.11766721388059002, 0.1674406887697322, 0.34687627532652443, 0.3539450360195977, 4.768003693648747, 76.34038598196847, 53.20986066545759, 55.62964725494385, 52.42511722019741, 58.7656888961792, 86.2676386151995, 56.36513492039272, 0.3531786985695362, 0.14916106393294676, 7.012176300798144, 10.726073128836495, 74.72641672406877, 85.99165616716657, 85.39301327296666, 81.46542590005058, 77.23397990635463, 71.7553322655814, 69.88276495252336, 73.7393000466483, 73.0612461907523, 75.87129225049699, 71.61677128928048, 75.56109687260219, 72.30970123835972, 75.50512218475342, 67.8999297278268, 66.85952036721366, 57.32617153440203, 56.56562171663557, 52.30221400942121, 56.49751199994768, 53.97881085532052, 56.16529083251953, 53.44263574055263, 53.87791953768049, 53.55376522881644, 51.76557336534773, 51.910165378025596, 53.48350504466465, 48.430542264665874, 47.96426602772304, 49.29305689675467, 50.00803000586373, 50.02399001802717, 50.18547657557896, 52.9240916797093, 52.365765707833425, 49.95632151194981, 47.081083978925435, 46.133276735033306, 44.648113182612825, 43.94502149309431, 43.19085359573364, 46.91833979742867, 46.96099131447928, 48.118971143450054, 46.47986330304827, 47.02932684762137, 46.54134791237967, 47.8569267817906, 52.11939648219517, 54.043116433279856, 55.03274835859026, 55.63162054334368, 52.933270250047954, 50.13335813794817, 56.47378390175955, 62.171612467084614, 63.15194770268032, 57.02495322908674, 45.956969669886995, 48.65838411876133, 48.56240517752511, 48.67653628758022, 48.956434045519146, 43.33517115456717, 43.19542898450579, 44.514169284275596, 52.80130311420986, 47.94736453465053, 40.00351340430123, 44.963627406529014, 43.1459230695452, 40.49402495792934, 43.156032698495046, 47.368214811597554, 58.071515219552175, 49.137420722416465, 55.489825180598665, 59.334211349487305, 57.17157064165388, 53.681869166237966, 56.64615133830479, 59.206586837768555, 57.66389914921352, 58.363172803606304, 54.38926179068429, 57.81922960281372, 54.51148755209786, 54.25428261075701, 52.04898343767439, 43.46233361107962, 44.86303833552769, 42.97941991261074, 45.41214404787336, 45.60082238061087, 45.959724630628315, 42.538369110652376, 39.0016804422651, 39.879178864615305, 39.477962085178916, 42.014554841177805, 48.96137074061802, 45.815789222717285, 45.79743555613926, 44.784801619393484, 43.8735488482884, 42.91269636154175, 47.981785910470144, 49.934459005083355, 49.002174036843435, 47.21042469569615, 51.224409443991526, 47.81485196522304, 48.27530561174665, 50.33952856063843, 50.14193568910871, 47.5029890196664, 49.37848152433123, 49.139307158333914, 52.58273363113403, 58.38173839024135, 58.12274776186262, 60.65278489249093, 63.10263633728027, 64.87589999607631, 67.39298221043178, 69.16569696153913, 71.34454086848667, 70.65734318324498, 73.74389280591691, 70.15432834625244, 75.39042827061245, 69.33792196001325, 78.14667442866734, 48.298074858529226, 0.21976294474942343, 1.7792785188981464, 0.14358503956879887, 0.776327765413693, 48.27946063450405, 78.71865708487374, 67.31355735233852, 53.71628359385899, 41.25315039498465, 56.11384637015206, 69.27208083016532, 1.7520972745759147, 0.3430172838270664, 0.3011370982442583, 0.1897162063313382, 0.16123544531209127, 0.26892286113330294, 0.14829699029879911, 0.1117012422265751, 0.15945140032895974], [0.03592090089140194, 0.05973924084433487, 0.09637601314378635, 0.07920277358165809, 0.01335259122840528, 0.2397792392543384, 0.03747052898896592, 0.06642004235514573, 0.1481750982680491, 6.280806311539241, 53.66498156956264, 41.103534834725515, 25.279486758368357, 32.78657586233956, 47.11952141353062, 72.17857483455113, 35.96411214556013, 0.2890798295182841, 0.2766653528170926, 4.254474929400852, 2.3815421845231737, 72.87750107901437, 76.69845444815499, 75.41433702196393, 73.50267219543457, 70.49998038155692, 66.50626700265067, 64.753007207598, 69.44827325003487, 68.5471544265747, 71.12148979731968, 69.03427178519112, 69.25222982679094, 68.47510160718645, 66.26846490587506, 55.82734782355172, 51.701625619615825, 50.90931906018938, 50.88953059060233, 50.89330693653652, 49.60195990971157, 48.7143622807094, 47.64458635875157, 49.95396607262747, 48.58909668241228, 48.48509604590279, 47.20901073728289, 49.56172636577061, 46.96507338115147, 43.15651559829712, 42.33400869369507, 41.924283845084055, 41.301183291843955, 44.77885743549892, 46.5261105128697, 47.589164052690776, 49.82237761361258, 49.16786078044346, 47.65643998554775, 48.76173857280186, 44.88741609028408, 42.73891149248396, 49.975689615522114, 46.45461354936872, 44.85992554255894, 43.470174653189524, 40.54241221291678, 39.50711325236729, 40.988455295562744, 41.266730649130686, 44.17907156263079, 45.50743859154837, 45.941930294036865, 44.62085539954049, 44.87791095461164, 44.20183733531407, 47.57699775695801, 54.99370295660836, 56.095336369105745, 60.663804735456196, 54.06815774100167, 44.502617904118125, 52.083324909210205, 51.99692405973162, 44.51781708853585, 47.23598364421299, 43.61836583273751, 38.61563852855137, 49.161155768803184, 45.43841518674578, 49.80885989325387, 41.862893036433626, 41.78207506452288, 50.04229504721505, 52.82489224842617, 51.06580638885498, 50.1434781891959, 45.84699705668858, 49.444360869271414, 50.4325510433742, 51.681979588099885, 54.00253547940935, 57.58011082240513, 53.46172244208199, 51.156390053885325, 51.480627741132466, 47.80815390178135, 45.68012564522879, 44.34973669052124, 44.15789345332554, 39.35087605885097, 38.939104965754915, 40.61953026907784, 43.31604276384626, 40.79061228888375, 41.993331568581716, 43.749203886304585, 39.838326930999756, 39.02155576433454, 39.378995418548584, 39.464044843401226, 39.67402982711792, 44.72934457233974, 41.44674110412598, 39.41565064021519, 39.14666155406407, 38.62386519568307, 36.8505528994969, 42.87700693947928, 42.04171187537057, 43.675723212105886, 44.26623671395438, 44.49041339329311, 42.15033653804234, 44.17756380353655, 43.02173096793038, 43.61278642926897, 44.8571914264134, 44.35657024383545, 43.14259488242013, 47.564887046813965, 45.22172519138881, 48.058799743652344, 46.52799347468785, 48.70528098515102, 50.533616065979004, 56.8861733845302, 61.16900825500488, 62.99209744589669, 65.11735684531075, 66.18868568965367, 64.2156126839774, 70.13661738804409, 66.13335718427385, 74.58051150185722, 49.38875443594796, 0.09883076285145112, 0.4441244298858302, 0.06417960793312107, 0.1262047586164304, 26.201762846538, 71.44871520996094, 50.955396039145334, 45.401221479688374, 25.615091698510305, 27.784569433757238, 55.457651547023225, 2.4675600145544325, 0.10349907020905189, 0.03480311622843146, 0.045213892590254545, 0.10788277283843074, 0.06074024284524577, 0.04411097802221775, 0.013396903805966889, 0.06658479744302374, 0.06295482508305993, 0.027663258636104207, 0.07972895713256938, 0.12483414502016135, 0.049685149985764704, 0.24329565199358122, 0.07200488767453603, 0.21207538726074354, 0.26595500324453625, 9.913763574191503, 63.093332699366975, 50.083358900887625, 27.689934968948364, 34.50829430988857, 56.94257538659232, 77.81089578356061, 39.508763449532644, 0.4178937045591218, 0.35171591277633396, 4.060808224337442, 4.4423681156975885, 77.50206920078823, 77.62185614449638, 78.10591629573277, 73.73438767024449, 72.23144367762974, 69.68868786948067, 68.73488085610526, 70.75153991154262, 73.00041471208844, 74.15824168069022, 73.01172637939453, 72.38725008283342, 69.82459463391984, 67.82932908194405, 57.126702649252756, 54.03690126964024, 54.045781067439485, 52.50563989366804, 52.12093550818307, 51.64910766056606, 51.70452996662685, 50.190361159188406, 51.60459055219378, 51.40609788894653, 50.83565425872803, 49.847578729902, 51.43036447252546, 49.78828975132534, 46.25497790745327, 45.076719760894775, 44.548205035073416, 44.69530882154192, 45.45149169649397, 48.56104333060128, 51.51246438707624, 52.081678186144146, 47.69007968902588, 48.89228480202811, 48.679489271981375, 46.50424453190395, 45.64698273794991, 51.599059786115376, 47.85217421395438, 45.96495662416731, 45.79507664271763, 44.76208101000105, 43.180737018585205, 46.400924818856375, 42.86419446127755, 46.31465251105172, 47.62272385188511, 47.837895665849956, 47.33635037285941, 48.23507554190499, 46.38972084862845, 49.78029237474714, 54.923150948115754, 58.25024025780814, 61.63293947492327, 53.162255082811626, 48.82214273725237, 54.42297445024763, 53.300416537693565, 49.80081387928554, 47.43529619489397, 46.52643707820347, 40.79980822971889, 51.13550724302019, 47.370188099997385, 47.58646467753819, 44.62525708334786, 44.41869756153652, 49.390157972063335, 52.23692178726196, 51.502914088112966, 51.79278251102993, 50.154293060302734, 50.75685126440865, 52.26931081499372, 53.00215121677944, 56.04032400676182, 59.62347180502755, 54.48575489861624, 52.61598423549107, 53.97165421077183, 50.04039471490042, 48.20633084433419, 47.13975804192679, 45.28455775124686, 41.47233131953648, 42.216146400996614, 42.62566975184849, 43.5607339995248, 42.23703963415963, 42.46954720360892, 45.22100952693394, 40.52923148018973, 40.98242425918579, 39.88283361707415, 39.777415548052105, 40.43424613135201, 45.34361743927002, 41.59405333655221, 42.17990459714617, 42.54550838470459, 41.44989211218697, 39.556237016405376, 44.72805220740182, 44.483006613595144, 47.01189729145595, 46.2601751599993, 46.5709159714835, 43.615037645612446, 47.352984360286165, 45.694088050297324, 46.39937537057059, 46.957326139722554, 47.42992523738316, 47.011247634887695, 50.10957098007202, 48.10358783176967, 51.849420751844136, 48.458265577043804, 51.572750432150706, 51.642020498003276, 57.64479507718767, 61.9416618347168, 66.7216750553676, 66.03523472377232, 68.92409420013428, 65.5006959097726, 72.72757284981864, 66.31647000994, 78.38314247131348, 52.86680030822754, 0.17068659673844064, 1.0544323452881403, 0.16103318759373256, 0.08272998181304761, 26.483607837132045, 77.81687818254743, 57.95730767931257, 51.00293908800398, 27.263425009591238, 35.6805214200701, 64.76248455047607, 5.434850973742349, 0.23314930072852544, 0.08396311742918831, 0.01775565161369741, 0.07354906374322516, 0.08052548260561057, 0.055500310446534834, 0.016379341715946794, 0.09788318191255842, 0.16988561329032692, 0.16602250986865588, 0.2426702326961926, 0.23282262682914734, 0.15061733578997, 0.4819344367299761, 0.2501674204000405, 0.2660099102982453, 0.26736966733421597, 10.55261308806283, 74.68210806165422, 52.658698286329, 30.03208065032959, 44.418419633592876, 63.827548844473704, 84.07939379555839, 44.011981282915386, 0.41005762932556017, 0.4759373271039554, 7.406303746359689, 6.484919198921748, 83.2954216003418, 80.60790007455009, 81.88659790584019, 78.60567937578473, 75.69187586648124, 71.9215053830828, 70.06948389325822, 73.48882443564278, 75.8011223929269, 77.32660634177071, 74.28344127110073, 74.05467183249337, 74.64678342001778, 70.82645538875035, 60.236184801374165, 57.08168179648263, 56.256850719451904, 55.96766669409615, 56.84249700818743, 55.37978655951363, 53.17069367000035, 52.620052405766074, 56.51093939372471, 54.24535417556763, 52.77571637289864, 50.976935454777305, 52.80870294570923, 51.722247873033794, 48.28452239717756, 48.52766418457031, 47.199773107256206, 48.215554577963694, 48.91756582260132, 52.061646529606406, 52.940663133348735, 52.018091746738975, 49.49060460499355, 49.295162200927734, 49.633042676108225, 48.05664580208914, 44.983697278159006, 53.235673223223, 49.49417250497, 49.04564196722848, 48.29982233047485, 46.9458372933524, 45.51353563581194, 45.69022832598005, 46.13275562013899, 50.25038317271641, 50.605707100459504, 52.00466087886265, 48.07636478969029, 50.66880716596331, 50.36384725570679, 52.836467947278706, 58.941339356558665, 60.505830492292134, 66.13365595681327, 57.379512854984824, 53.14570099966866, 56.093255383627756, 54.24879353387015, 50.23635475976126, 47.49942806788853, 45.791248185294016, 41.267098903656006, 54.96865817478725, 50.7603496823992, 46.52789619990757, 43.98381328582764, 46.36295986175537, 52.35532603945051, 55.33942794799805, 57.15692036492484, 54.37896803447178, 51.13320391518729, 53.49950327192034, 55.779832567487446, 56.021744523729595, 57.36068671090262, 61.948881013052805, 56.28755480902535, 54.763429233006065, 57.67226825441633, 53.66769484111241, 50.94488341467721, 49.247122355869834, 47.49784735270909, 42.8352586882455, 44.64025477000645, 46.07045112337385, 46.56237663541521, 42.609021868024556, 43.25719152178083, 44.55491352081299, 40.72682435171944, 39.60461384909493, 40.51601253237043, 41.13453769683838, 41.53660215650286, 48.56747736249651, 45.772293499537874, 44.24386351449149, 45.17354985645839, 45.10662480763027, 42.50966262817383, 48.54179334640503, 45.535276549203054, 49.93296166828701, 49.063255650656565, 47.62485000065395, 46.75083262579781, 51.816277844565256, 47.49665921075003, 47.969685622623985, 50.67793362481253, 50.18428495952061, 48.81629235403878, 53.94300331388201, 50.51966060910906, 55.778706959315706, 51.390071868896484, 55.55447816848755, 56.18834842954363, 61.03153814588274, 65.29849638257707, 69.24349594116211, 69.2322815486363, 72.63449478149414, 69.0544215611049, 75.8213277544294, 72.29113565172467, 81.04943030221122, 57.55569832665579, 0.18796991503664426, 2.3662754723003934, 0.3180543604706015, 0.2435703772519316, 33.80848911830357, 84.42912442343575, 63.904965673174175, 60.579759325299946, 39.044342381613596, 38.387265137263704, 77.3424551827567, 5.926195442676544, 0.31646422722509926, 0.16016296643231595, 0.10061049235186406, 0.23812733218073845, 0.19417859188147954, 0.2351504090641226, 0.06761198411030428, 0.15373962824898108], [0.05562605316351567, 0.07792969939431973, 0.10556982337896313, 0.06106331372367484, 0.056780139449983835, 0.08300586736627988, 0.022818952865366424, 0.2039208755429302, 0.25754135900310104, 12.742127690996442, 64.19250297546387, 33.963576384953086, 52.59064762932913, 51.695118631635395, 50.068816321236746, 77.73229776109967, 25.55375473839896, 0.31524793963347164, 0.22367856678153786, 2.7299298558916365, 10.24447090285165, 76.62749249594552, 77.44469097682408, 74.49371460505894, 67.48369789123535, 65.64130660465786, 64.07368183135986, 67.56668717520577, 72.55239486694336, 71.7389692578997, 69.72292859213692, 68.82725715637207, 68.51508849007743, 61.34531879425049, 52.390007972717285, 50.21245643070766, 50.03478404453823, 51.22807114464896, 50.1118152482169, 47.81988246100289, 49.551877294267925, 50.437633650643484, 49.024529865809846, 47.46025759833199, 47.02351120540074, 47.83541863305228, 47.967844349997385, 47.71225486482893, 47.40415784290859, 44.61005442483084, 41.541726452963694, 41.14319862638201, 43.90860251017979, 42.293392998831614, 45.18636580875942, 48.41825784955706, 48.902797426496235, 47.1447468485151, 47.13648196629116, 49.712557860783164, 47.30609096799578, 42.321759019579204, 45.444988182612825, 45.26866027287075, 47.67004803248814, 42.690843854631694, 41.84095062528338, 40.389892305646626, 39.71414525168282, 40.61678920473371, 38.024603911808555, 42.06353964124407, 42.37204660688128, 43.45825849260603, 45.75009053094046, 45.78494964327131, 43.87361485617501, 45.97697353363037, 50.40253135136196, 51.21019690377371, 51.580852031707764, 53.871475083487375, 54.782185895102366, 53.25902959278652, 43.92087997709002, 49.5694214957101, 43.85512569972447, 40.187574659075054, 41.29432541983468, 36.85660130637032, 52.435299805232454, 53.750673702784944, 36.2106168610709, 38.34402649743216, 46.34331035614014, 49.6805544580732, 50.5403037071228, 49.715979848589214, 50.19248383385794, 51.77476583208357, 52.45820106778826, 52.7851311819894, 53.56073774610247, 50.08040244238717, 43.52169554574149, 44.10833542687552, 44.31520414352417, 42.4117625100272, 42.48558017185756, 40.0285199710301, 39.41715839930943, 40.87769406182425, 42.726724352155415, 42.28444024494716, 44.129718508039204, 44.80002859660557, 45.267413071223665, 41.01716872623989, 39.26421117782593, 40.35903882980347, 41.67539937155587, 43.76109920229231, 44.87343284061977, 40.321879863739014, 39.18555062157767, 37.86457647596087, 40.242340360369, 38.0035126549857, 40.90986769539969, 43.67918688910348, 44.48277037484305, 42.99544940676008, 42.93429136276245, 43.10490437916347, 42.961066246032715, 44.033274037497385, 46.00844887324742, 42.22263254438128, 44.9354316166469, 43.35887493406023, 43.94860328946795, 44.833081177302766, 46.816854408809114, 44.68312168121338, 47.01791443143572, 46.19026585987636, 49.43958398274013, 49.17801904678345, 53.76456315176827, 53.32221303667341, 58.71951811654227, 56.74975940159389, 69.31602818625313, 63.69353199005127, 78.42800004141671, 51.600018637520925, 0.23766370277319634, 0.4578944838472775, 0.11777105687984399, 0.0797870804422668, 13.506414771080017, 73.06538731711251, 52.0854024205889, 47.10481207711356, 29.589560304369243, 24.31200395311628, 57.99326113292149, 6.153354636260441, 0.4298522328691823, 0.18703482592744486, 0.007668454183398613, 0.06424329522997141, 0.0252382016208555, 0.040132968087813685, 0.030517570474850278, 0.05514161308695163, 0.1156657255653824, 0.08739513398281165, 0.06355328618415765, 0.10983865002968482, 0.09704454655625991, 0.14033284836581775, 0.11745203685547624, 0.2433199164058481, 0.2904412964625018, 21.280782835824148, 71.59496784210205, 41.736699853624614, 51.304098333631245, 52.58061443056379, 58.43134157998221, 82.29858439309257, 28.007877588272095, 0.5189806031329292, 0.2063056140073708, 4.37414505652019, 12.906704459871564, 81.86612156459263, 80.34413950783866, 76.77010427202497, 68.14931447165353, 66.67767211369106, 66.79176848275321, 69.9047212600708, 73.59370054517473, 72.70824296133858, 72.98410034179688, 71.80377510615757, 68.8806540625436, 62.839063371930806, 54.14105476651873, 52.58193111419678, 52.52574450629098, 51.793303625924246, 54.039326190948486, 52.350663798195974, 51.91748530524117, 52.792242663247244, 51.82736716951643, 50.377215589795796, 50.47786372048514, 50.15556110654558, 50.662553787231445, 50.5700489452907, 49.915122168404714, 46.66742297581264, 43.92774827139718, 43.60475778579712, 46.95437315532139, 43.79954358509609, 46.48061718259539, 50.16423940658569, 51.06592450823103, 47.23066132409232, 46.44550098691668, 49.04572187151228, 46.593841552734375, 44.05767958504813, 46.7512321472168, 46.19663735798427, 47.94683994565691, 43.87953472137451, 44.18349756513323, 43.13686956678118, 40.68534708023071, 43.05914354324341, 42.56582144328526, 41.839053767068044, 45.480337142944336, 46.33052914483206, 46.48913219996861, 45.78409154074532, 45.725233350481304, 49.36671475001744, 53.19557864325387, 54.67032337188721, 55.37436349051339, 56.57848283222744, 56.77662461144583, 55.09053652627127, 45.08425508226667, 49.2465352330889, 45.19628088814871, 40.79587207521711, 45.52626820972988, 42.66211305345808, 51.760949339185444, 52.93724461964199, 39.45418534960066, 41.63455786023821, 48.060755661555696, 51.02309581211635, 52.43207236698696, 51.470980167388916, 52.625604016440256, 52.45009599413191, 54.953934941973, 53.645352908543174, 55.253784452165874, 52.64098385402134, 47.252982412065776, 44.066166809626985, 44.7255334854126, 44.60280397960118, 44.61711032049996, 40.46575273786272, 40.7946457181658, 41.182125908987864, 44.15790040152413, 43.56671987261091, 45.75995349884033, 44.22772632326399, 45.73827511923653, 43.407970905303955, 40.16996444974627, 41.239236627306255, 42.37651082447597, 43.96111352103097, 46.81808076586042, 43.12251806259155, 41.06113345282418, 41.345356464385986, 40.94196489879063, 39.94052798407418, 42.85504715783255, 44.17345394407, 45.86875534057617, 45.82016658782959, 45.701428822108674, 44.8546518598284, 45.13461562565395, 45.52788366590227, 47.50738375527518, 45.44326155526297, 46.72065312521798, 45.43097366605486, 46.162851742335725, 46.07743753705706, 48.608683654240195, 47.7536244392395, 49.8311253956386, 49.238798413957866, 52.279045241219656, 50.72748122896467, 56.658599036080496, 54.67387042726789, 61.28952475956508, 59.118150166102815, 72.37237398965019, 65.93970394134521, 80.74640546526227, 53.215575558798655, 0.21816651469894818, 1.3698054339204515, 0.09796750345932585, 0.020447493331240754, 13.061964562961034, 79.86828517913818, 59.29991504124233, 54.86250707081386, 32.940391608646934, 32.86899886812483, 68.56003638676235, 11.573638711656843, 0.7664480784109661, 0.05951491716716971, 0.09061445016413927, 0.06018840388527938, 0.055152333940246275, 0.04958250799349376, 0.01166660473349371, 0.06728138149316822, 0.20098329388669559, 0.21563036793044635, 0.19458392156021936, 0.25308905648333685, 0.19633671322039195, 0.26620969814913614, 0.16608539649418422, 0.3364671410194465, 0.3573311971766608, 21.687413999012538, 85.51292528424943, 45.494296073913574, 65.20213876451764, 68.44698919568742, 64.03382696424211, 88.67940698351178, 31.732707841055735, 0.5823746100068092, 0.8853156343102455, 7.598774058478219, 14.905645608901978, 87.01558440072196, 84.24273204803467, 79.37719345092773, 73.076386315482, 70.0078672681536, 69.86192035675049, 71.12006541660854, 76.0245486668178, 77.46422931126186, 76.48930672236851, 73.85026277814592, 73.72110271453857, 67.43287181854248, 57.851903506687705, 56.243791580200195, 54.29776096343994, 53.59117433003017, 56.54389122554234, 51.9365233693804, 55.686052731105256, 55.93390539714268, 54.524473735264365, 52.21580621174404, 53.043659755161826, 52.049959659576416, 51.67224168777466, 51.575870173318044, 52.2722499029977, 49.81054483141218, 46.23708629608154, 45.46374831880842, 50.85863195146833, 47.13601991108486, 49.970037255968364, 53.050597531454905, 51.456117970602854, 45.33957358769008, 47.558241094861714, 50.56887469972883, 47.203855173928396, 46.5458607673645, 47.78049659729004, 45.90161337171282, 50.95837334224156, 46.70185477393014, 44.820758547101704, 46.13534729821341, 42.47620357785906, 46.74796996797834, 43.37616900035313, 45.77308906827654, 47.50282226290022, 48.6126059123448, 50.06303889410836, 48.44539751325335, 48.426564420972554, 51.0175997870309, 55.98834105900356, 56.183248451777864, 58.06701973506382, 59.928970200674875, 58.52922085353306, 58.219532694135395, 44.191005093710764, 48.51697090693882, 47.604015827178955, 43.36921385356358, 50.71328605924334, 49.108592646462576, 53.64951835359846, 52.2739383152553, 39.94147988728115, 43.74443742207119, 52.00961147035871, 54.56546810695103, 56.121124608176096, 54.40965127944946, 54.888062545231406, 55.289508615221294, 57.47787850243704, 56.65155356270926, 58.76555688040597, 56.45893212727138, 48.92068208966936, 46.872825622558594, 47.95897497449602, 47.4836938721793, 48.385490145002095, 43.58857543127877, 42.808925015585764, 44.160408701215474, 46.86216708592006, 45.23101493290493, 46.66680111203875, 45.924806458609446, 47.47680820737566, 42.52907936913626, 40.65235703332083, 41.5510960987636, 43.57987628664289, 45.44552319390433, 49.19141864776611, 44.991121428353445, 44.35028559820992, 42.704427582877024, 45.669873578207834, 43.45973151070731, 46.4216547693525, 47.631138120378765, 49.04315798623221, 46.15534768785749, 47.7280307497297, 47.575382300785606, 48.40632431847708, 49.13149390901838, 50.610775811331614, 47.31508193697248, 51.1932988848005, 48.46221910204206, 50.12869937079293, 50.33938959666661, 53.154236861637656, 49.97844110216413, 53.36381884983608, 51.41700308663504, 55.69452953338623, 53.966939858027864, 59.17741135188511, 57.37906469617571, 63.500003814697266, 60.79386806488037, 74.55936118534633, 69.61175046648297, 84.84472397395542, 55.088507652282715, 0.9546881318092346, 1.1960978635719843, 0.4035101463752133, 0.15728152676352433, 19.000345843178884, 89.61550998687744, 65.25439616612026, 63.67074884687151, 46.27352612359183, 36.245785168239046, 79.90029553004673, 13.443361605916705, 1.2975286436932427, 0.4668183592813355, 0.16390576559518064, 0.18351606545703752, 0.15666591908250535, 0.15314491944653646, 0.15190144974206174, 0.18588863100324357], [0.10767374334058591, 0.05045342804597957, 0.055092076637915204, 0.10418645332434348, 0.027403486593227302, 0.02925487787329725, 0.09585961406784398, 0.1576150402958904, 0.15023755974003247, 24.891516719545635, 61.04300962175642, 27.858569485800608, 28.294991050447734, 44.73278045654297, 51.03256273269653, 78.22479997362409, 19.524033308029175, 0.7006477149469512, 0.4699206213865961, 1.7348654163735253, 26.34817181314741, 80.49624947139195, 77.13781683785575, 70.17292172568185, 64.43038845062256, 62.757331711905344, 62.85714258466448, 66.15446581159318, 70.24077088492257, 68.67606435503278, 66.79176153455461, 63.27847439902169, 53.94820056642805, 51.41145147596087, 49.19285692487444, 50.02585908344814, 49.81234441484724, 51.1713946887425, 49.38662828717913, 48.003026553562705, 47.6694643838065, 47.64066062654768, 47.381308691842214, 47.615299701690674, 45.16684831891741, 46.76457963671003, 46.6889762878418, 47.18342399597168, 44.22725731985909, 44.46484749657767, 40.36330154963902, 41.540423665727886, 41.67913750239781, 43.41266441345215, 42.98011473246983, 47.83270883560181, 49.316951751708984, 46.97736474445888, 47.825017179761616, 47.03246743338448, 46.25400863374983, 43.05887256349836, 45.582044873918804, 45.233749049050466, 43.56178665161133, 43.396402154650005, 41.9014207976205, 41.07920919145857, 41.15449639729091, 40.70056363514492, 42.20015859603882, 40.31014435631888, 41.29089648383004, 41.96394068854195, 42.686376162937705, 42.54645333971296, 43.16268907274519, 43.89548431124006, 45.58663763318743, 47.91583360944475, 48.391715730939595, 50.734749044690815, 52.88229479108538, 54.15903670447213, 51.62681436538696, 50.89234461103167, 38.508254119328086, 40.30806337084089, 38.1178765296936, 41.77951465334211, 37.57958568845476, 52.184101581573486, 52.47839253289359, 42.01743139539446, 44.28631353378296, 45.78665542602539, 49.676225730351035, 48.39077425003052, 48.687260832105366, 48.73620741707938, 50.99445881162371, 47.88027967725481, 46.06469106674194, 43.16815383093697, 41.547694955553325, 43.11334644045149, 40.82046175003052, 42.222639492579866, 39.856409617832725, 38.923471518925254, 38.27418320519583, 40.735916069575715, 40.951994623456685, 43.067422321864534, 46.59151043210711, 43.874733516148154, 41.866169112069265, 39.175583430698936, 40.52961015701294, 39.86472313744681, 41.99546119144985, 43.52310603005545, 44.587858404432026, 41.130591120038716, 40.22366707665579, 39.13348082133702, 40.354602405003135, 37.346942629132954, 40.947526931762695, 42.29176017216274, 42.65024553026472, 43.02355834415981, 43.77530826841082, 41.04407215118408, 43.27541317258562, 42.07131120136806, 44.42668104171753, 44.47763218198504, 45.22771801267351, 45.10151093346732, 45.30041354043143, 43.15731464113508, 47.25059223175049, 42.884893144880024, 46.07160799843924, 45.684006214141846, 49.06850848879133, 46.494899204799104, 49.12183591297695, 49.9745431627546, 55.98760107585362, 62.048413957868306, 72.73135266985211, 64.96462154388428, 80.28129999978202, 42.3332895551409, 0.010747326338397605, 0.7202832698822021, 0.48060103399412973, 0.07822590028601033, 2.06979193006243, 57.37301628930228, 60.41159207480294, 46.205326080322266, 35.08733286176409, 20.34277081489563, 54.011696679251536, 16.104265451431274, 0.49449363137994495, 0.005647388860649828, 0.04373072699776717, 0.12185895895319325, 0.04967665133465614, 0.055177741684019566, 0.027718795031043034, 0.08051676343062095, 0.13119413517415524, 0.050410561596176455, 0.010435195988975465, 0.05127669797678079, 0.021647287432902625, 0.028765698229627948, 0.0272656540785517, 0.16457260267010757, 0.10952672069626194, 33.02921390533447, 68.17894159044538, 37.69568313871111, 32.56078372682844, 47.26205675942557, 58.88906805855887, 82.53617804391044, 21.986593008041382, 0.7313530530248369, 0.7040770852140018, 1.712244144507817, 34.90317780630929, 83.86783504486084, 78.40951088496617, 72.52472714015416, 68.61987427302769, 65.5046146937779, 64.9915041242327, 67.58310576847622, 71.98179490225655, 71.10223633902413, 69.8243236541748, 64.99316474369594, 56.98733220781599, 53.27248477935791, 51.998240743364605, 51.99167816979544, 53.55327190671648, 52.917939049857004, 51.249079023088726, 50.107653277260916, 51.02424226488386, 50.80742372785296, 50.46399859019688, 49.26112297603062, 49.66584859575544, 48.45398896081107, 48.69579321997506, 47.96187237330845, 47.59086288724627, 46.844313689640586, 43.8022255897522, 42.22639846801758, 44.59575850622994, 45.66914054325649, 44.72346292223249, 49.63110065460205, 52.072673320770264, 47.012036255427766, 49.35633066722325, 45.91042716162545, 47.52443463461739, 43.284907885960166, 46.60385043280465, 44.407563073294504, 44.99992479596819, 45.0559515953064, 44.74701036725725, 42.791985307421, 43.08509853907994, 41.38455472673689, 44.43481738226754, 43.36234903335571, 44.1911301612854, 45.27955852236067, 47.519310338156565, 45.00700848443167, 43.78622388839722, 44.98268978936331, 46.98151976721627, 50.40013074874878, 50.27410432270595, 53.49863474709647, 54.986865929194856, 56.91502925327846, 52.88933331625802, 51.173941203526084, 41.18759414127895, 41.25196920122419, 39.45361907141549, 45.52593469619751, 41.07718031747, 50.87246928896223, 51.42670972006661, 45.081461906433105, 48.05871983936855, 50.65489339828491, 52.528402192252024, 51.49411766869681, 48.99355132239205, 51.3925211088998, 52.659705775124685, 50.3521534374782, 47.678875718797954, 43.79059083121163, 43.40573011125837, 42.98801483426775, 43.0858975819179, 43.4691914830889, 42.13488721847534, 40.265755789620535, 41.877206325531006, 41.03176689147949, 42.57334286825997, 43.60401432854788, 44.997201102120535, 44.43764877319336, 44.085392475128174, 40.749868052346365, 41.12196493148804, 41.19279834202358, 41.27748646054949, 43.69490024021694, 46.019979408809114, 43.829681396484375, 42.69894892828805, 41.9436936378479, 42.90112066268921, 40.19427967071533, 43.97109113420759, 45.4583044052124, 44.421240602220806, 44.66363198416573, 45.635674544743125, 44.797006130218506, 47.249456201280864, 44.639813559395925, 47.41155767440796, 46.59150348390852, 47.30132450376238, 47.942042214529856, 48.99086931773594, 45.75169903891427, 50.45435101645333, 46.48181922095162, 48.33304166793823, 48.25848054885864, 51.609947613307405, 49.256318296704976, 52.13910852159773, 51.69158547265189, 59.67634759630476, 64.72536727360317, 75.42291804722377, 66.00252955300468, 81.96064485822404, 42.56725624629429, 0.21069507061370782, 1.4594691140311105, 0.6167876262749944, 0.10620507464877196, 2.1225565501621793, 61.51035935538155, 66.89052322932652, 52.860605989183696, 38.099706990378245, 27.286970717566355, 60.74824619293213, 24.874549218586512, 0.624482267669269, 0.019801509333774447, 0.09819118252822331, 0.05997577136648553, 0.1234631243028811, 0.030966876008148705, 0.016780744373266186, 0.0620981203392148, 0.16352261044085026, 0.11252117037240948, 0.10667888886694397, 0.13111615792981215, 0.14027818558471544, 0.11515731284660952, 0.17190067230590753, 0.3039509286837918, 0.2324532595063959, 36.91935396194458, 80.49186515808105, 36.916039671216694, 37.0775158064706, 60.31565134865897, 65.91237667628697, 91.95204326084682, 25.535557406289236, 1.0711117131369454, 2.6984618987355913, 3.6716144340378896, 36.843597752707346, 88.08175768171037, 81.78404249463762, 75.32561547415597, 71.73564107077462, 69.68615177699498, 69.81097616468156, 72.27233382633754, 76.3147679737636, 74.24835286821637, 70.80905709947858, 68.60833331516811, 60.95942974090576, 53.73113189424787, 56.49290534428188, 55.03720562798636, 56.33427449635097, 56.22538580213274, 55.58162478038243, 52.44726112910679, 52.91328723090035, 52.59658486502511, 53.32627078465053, 51.775759424482075, 51.68754856927054, 49.5147773878915, 50.945369788578574, 50.25249195098877, 49.47752462114607, 50.589559486934114, 46.7014239856175, 46.95709337506975, 46.97415467670986, 48.14593710218157, 46.84272255216326, 50.37718084880284, 53.42497341973441, 46.39553649084908, 48.86472129821777, 47.948128836495535, 45.988545758383616, 44.05440698351179, 46.34131274904524, 46.130146571568076, 45.2354930468968, 44.75026559829712, 44.785256726401194, 45.56036649431501, 45.932043007441926, 45.27181822913033, 47.97510174342564, 45.64561741692679, 46.66341039112636, 47.184295994894846, 49.54900768824986, 47.61652953284127, 46.911638259887695, 47.59493800571987, 49.900836672101704, 53.11518103735787, 53.95103543145316, 58.41981451851981, 56.81539555958339, 58.76621001107352, 53.543353353227886, 51.10796110970633, 42.36662353788103, 43.968641894204275, 43.76819331305367, 47.228045327322825, 46.55584185464041, 53.21997029440743, 50.77524662017822, 44.98917940684727, 49.25461251395089, 51.52208764212472, 55.488272258213584, 52.74156597682408, 50.901123659951345, 52.636338983263286, 54.853394508361816, 52.55752556664603, 51.36126463753836, 46.43859795161656, 46.6289438520159, 46.64087738309588, 43.81999213354928, 48.064160278865266, 43.90953704289028, 42.79896477290562, 44.800254413059776, 43.62559543337141, 43.4740378516061, 44.76693432671683, 46.33833197184971, 45.4120328766959, 44.762042794908794, 42.8346437726702, 42.311965533665244, 41.869657107761924, 42.07392372403826, 45.18755742481777, 47.858962603977744, 46.509598118918284, 46.70323051725115, 45.35779871259417, 46.59845168249947, 44.004126344408306, 46.80493477412632, 47.17321014404297, 46.96339539119175, 47.87774011066982, 48.23228236607143, 46.75726318359375, 50.05132075718471, 47.00386864798409, 49.19616774150303, 49.13940095901489, 50.275535651615684, 49.733159269605366, 51.67017459869385, 48.15007128034319, 54.915810176304404, 48.6560252053397, 52.59387854167393, 50.904920850481304, 55.293729645865305, 51.806053570338655, 54.834707328251426, 54.397964409419465, 62.78960609436035, 66.83456243787492, 80.06239700317383, 69.924558367048, 86.99921444484166, 46.91818693705967, 0.41997987404465675, 2.810190451996667, 1.633921770112855, 0.2307717411645821, 5.046276007379804, 71.44501876831055, 73.42436599731445, 60.699462890625, 52.47890669958932, 30.98115246636527, 68.6516136441912, 30.010096549987793, 0.9282160380056926, 0.1786895373037883, 0.2886406273714134, 0.19383946007915906, 0.2515558658965996, 0.08279254952711718, 0.09030705344464098, 0.16308636670666082], [0.035039456760776896, 0.0372227347855057, 0.017663369154823676, 0.11210750828364066, 0.04073449955987079, 0.10864087965871606, 0.09929695033601352, 0.150265705372606, 0.05454277539891856, 30.22863824026925, 54.370428698403494, 35.383051667894634, 39.914576462336946, 42.73761912754604, 53.184541429792134, 77.98547622135708, 12.580879977771215, 0.3975989392825535, 0.53018669039011, 7.8369921786444525, 60.49175344194685, 72.40035438537598, 76.81501047951835, 67.78986331394741, 62.76145894186837, 60.252082279750276, 61.9744781766619, 64.89188085283551, 66.97487436022077, 67.3785160609654, 60.06677382332938, 51.061067717415945, 49.45118400028774, 51.754817553928916, 50.148189067840576, 52.04891395568848, 52.309068407331196, 50.544642857142854, 50.574127537863596, 50.53633281162807, 48.3112382207598, 48.55673892157418, 48.65351690564837, 49.31565938677107, 46.44172464098249, 47.69522483008248, 48.30344581604004, 45.13935429709298, 47.39420107432774, 42.29118347167969, 40.1268995148795, 40.884652682713096, 42.31998028073992, 44.27562720435006, 45.99601854596819, 43.26069688796997, 47.86151259286063, 45.52411774226597, 46.25124672480992, 47.29212508882795, 47.077814851488384, 45.61605283192226, 42.59763029643467, 43.32586056845528, 41.79776757104056, 43.477480684007915, 44.56144482748849, 39.837135314941406, 40.94677652631487, 39.471034731183735, 39.3222599029541, 38.61388063430786, 39.895625250680105, 42.26538481031145, 45.1348831312997, 42.06957415172032, 44.35725464139666, 43.14471755708967, 43.96856198992048, 42.390976973942344, 46.92508997235979, 49.212634972163606, 53.26776695251465, 52.04502643857683, 49.68435512270246, 46.88367176055908, 40.85195098604475, 41.788752283368794, 42.37422834123884, 43.26644304820469, 35.902127265930176, 31.19695656640189, 50.746435914720806, 48.95155988420759, 47.17207758767264, 50.47431666510445, 44.96454804284232, 47.28653178896223, 47.11557831083025, 47.877934660230366, 46.750193391527446, 46.155090604509624, 43.532329763684956, 43.24775586809431, 40.29570599964687, 40.07518754686628, 40.05017403193882, 39.516371726989746, 38.25268200465611, 40.72022008895874, 40.233151367732454, 41.35311760221209, 42.898803438459126, 43.97945329121181, 41.45440149307251, 45.28252192905971, 41.612094334193635, 39.92633628845215, 41.5157401902335, 40.7173296383449, 44.975050245012554, 40.90072039195469, 43.4957857131958, 41.92988061904907, 41.312185764312744, 39.98000417436872, 39.031203338078086, 36.69893625804356, 41.099313804081504, 44.41436535971505, 43.502084255218506, 43.43326234817505, 43.348966802869526, 43.97454786300659, 44.1464011328561, 41.94255065917969, 43.645144190107075, 43.748877320970806, 45.335286549159456, 44.40852887289864, 44.58613177708217, 44.20271975653512, 44.46848487854004, 44.66624798093523, 45.19669083186558, 47.15003095354353, 48.47024079731533, 47.547624247414724, 48.89346252168928, 53.88479825428554, 66.2658245904105, 64.13691738673619, 74.11381489889962, 67.45436954498291, 81.32806696210588, 25.1541725226811, 0.6819373017975262, 0.6557459043604987, 0.9166086379970823, 0.29344663662569864, 0.6826533462320055, 37.97054692677089, 66.10762800489152, 45.58936480113438, 39.20644038064139, 22.314685208456858, 48.4655750819615, 28.961238179888042, 0.20896484702825546, 0.23370640512023652, 0.10931844437228781, 0.14027530859623635, 0.01934280609046774, 0.06971971743873187, 0.05361637153795787, 0.06567843750651393, 0.07358965370804071, 0.09982265212706157, 0.03723754381228771, 0.14243815253887857, 0.06844225312982287, 0.0787932098444019, 0.10776218359491654, 0.23657679823892458, 0.12525846010872296, 40.61485065732683, 58.984188897269114, 43.62417452675955, 32.78731237139021, 48.08213526862008, 60.714206968035015, 82.97382422855922, 12.224373119218008, 0.4743394042764391, 0.33476282390100615, 11.666077545710973, 68.78518581390381, 75.44069848741803, 80.82574694497245, 69.16767024993896, 66.01252801077706, 62.58446747916085, 64.17622334616524, 66.68699659620012, 71.21315043313163, 70.23079327174595, 63.97321087973458, 53.800155299050466, 53.40941640308925, 54.17233555657523, 53.251806940351216, 53.200515338352744, 55.13771479470389, 52.26745564596993, 53.2704941204616, 51.84939643314907, 53.19242763519287, 51.21547058650425, 50.523075648716514, 50.966638224465505, 48.59971700395857, 49.471861839294434, 50.053631033216206, 47.666869231632774, 48.87601906912667, 43.51267678397042, 41.82330567496163, 42.44503743307931, 45.87097529002598, 46.515344279153005, 48.901466846466064, 44.36950084141323, 49.607983997889924, 47.085377965654644, 47.84345422472273, 48.9736829485212, 47.99854496547154, 46.660690171378, 44.094011715480256, 45.055572918483186, 43.588214124952046, 45.08615888868059, 48.11917611530849, 41.69525384902954, 43.93374456678118, 41.33148438589913, 41.022894041878835, 41.5051337650844, 43.00357185091291, 43.74909271512713, 46.3303484916687, 43.85054683685303, 47.86493458066668, 46.202136857169016, 47.87778179986136, 45.31725249971662, 48.219549792153494, 52.107410839625764, 55.588750158037456, 54.01750884737287, 51.87530279159546, 49.265500341142925, 43.02966233662197, 42.27919782911028, 42.534613609313965, 43.26814188276018, 41.15570190974644, 32.788768018995015, 46.94842897142683, 50.6365327835083, 50.5317747933524, 52.84546933855329, 48.77172313417707, 49.902320112500874, 48.88332857404436, 49.14493519919259, 47.01999889101301, 47.913537229810444, 44.758770193372456, 45.45180089133126, 43.021710123334614, 41.72235529763358, 40.655893666403635, 41.21246174403599, 40.20791898454939, 43.25960949489048, 43.046466554914204, 43.98128761563982, 43.968787806374685, 44.0277224268232, 42.14362110410418, 46.32882336207798, 42.06165667942592, 41.33693872179304, 43.075631618499756, 40.999346596854075, 44.26144593102591, 42.5368926184518, 46.365339619772776, 43.69266292027065, 42.21260976791382, 41.83093479701451, 41.83877236502511, 39.32292693001883, 43.230121340070454, 44.75628621237618, 45.23718840735299, 46.400573934827534, 45.770580768585205, 46.279046467372346, 46.07883759907314, 45.704447814396445, 46.536765575408936, 46.40287726266043, 47.29165608542306, 46.09635400772095, 46.54635756356375, 47.22425855909075, 46.06085218702044, 48.2363018989563, 48.16811922618321, 49.355986731392996, 50.89135796683175, 50.567050797598704, 51.22176218032837, 56.26053326470511, 69.08620262145996, 66.55102729797363, 75.64667088644845, 68.41590990339006, 83.21806730542863, 26.390738214765275, 0.4551934530692441, 1.169634563582284, 1.3225633289132799, 0.23053259828260966, 0.9992967609848294, 41.1458180972508, 73.18413897923061, 54.64628607886178, 40.37197984967913, 30.60839203425816, 59.482492855616975, 38.40995795386178, 0.07500064013791935, 0.11381568626633712, 0.12991025192396982, 0.03456439743084567, 0.01023869394391243, 0.05414952364351068, 0.06150458540235247, 0.01930217880622617, 0.17048983515373298, 0.19665611322437013, 0.1345133384955781, 0.2291632874735764, 0.11000931515757527, 0.2054339407810143, 0.2074761547680412, 0.24880161083170346, 0.1959674951753446, 47.20679426193237, 68.96032210758754, 45.084411416734966, 51.35028648376465, 61.05168097359793, 64.89843300410679, 92.77199322836739, 15.017099925449916, 0.42433492892554825, 1.9128264784812927, 17.149717467171804, 78.00199903760637, 76.68400914328438, 83.27903774806431, 72.89360700334821, 69.42952701023647, 64.61145850590297, 68.18195016043526, 68.0411240713937, 72.96958555494035, 74.55196830204555, 67.41691875457764, 56.21322298049927, 56.38553830555507, 57.69469009126936, 57.468422004154746, 55.43649428231375, 58.93750395093645, 55.56747129985264, 55.806395530700684, 55.18904113769531, 54.34467172622681, 53.37101718357631, 53.727463245391846, 53.458731242588584, 51.064635617392405, 51.896668502262656, 52.32122080666678, 50.29002264567784, 50.874901158469065, 47.0021003314427, 44.71417318071638, 46.10057503836495, 48.08601583753313, 50.53113208498274, 51.358009406498496, 44.59256928307669, 52.109470980507986, 47.85057265417916, 46.61039563587734, 50.76600204195295, 49.1217177936009, 47.75415250233242, 46.094620432172505, 44.44190107073103, 42.538035597120015, 45.14100449425833, 48.95175443376814, 44.3147976739066, 45.47664417539324, 42.53977264676775, 44.55723074504307, 43.66863604954311, 44.87729603903634, 46.31743179048811, 50.37942164284842, 46.50119774682181, 50.31686006273542, 48.46886852809361, 48.37673888887678, 45.87423399516514, 50.20299298422677, 53.532541956220356, 58.66494001661028, 57.713999135153635, 53.53675256456648, 52.80535043988909, 44.24601745605469, 44.76935229982649, 46.69637264524187, 45.859934602464946, 43.25725058146885, 38.69721385410854, 52.06267833709717, 51.61689928599766, 53.396176610674175, 54.06842524664742, 49.64522981643677, 52.65786450249808, 50.66147681644985, 51.10595308031355, 50.35998753138951, 50.30172688620431, 46.46722105571202, 48.940116201128276, 46.382557255881174, 45.11364596230643, 43.74243981497628, 44.52095420019967, 43.4719603402274, 44.83954995019095, 45.013887201036724, 44.3875036239624, 44.39667872020176, 44.8608843939645, 42.484423296792166, 46.528531960078645, 45.286381653376985, 43.40653610229492, 43.23983839579991, 43.16224091393607, 46.67348527908325, 42.48064347675869, 48.29099811826433, 47.472806044987266, 45.587381090436665, 45.40179123197283, 43.80178437914167, 42.64803947721209, 45.22383744376046, 48.186861991882324, 47.92482457842146, 48.94930519376482, 48.76557397842407, 49.713735580444336, 50.33429309300014, 47.9963493347168, 49.538918903895784, 49.085559368133545, 50.65455641065325, 49.898109504154746, 50.5133238519941, 49.47758715493338, 48.98332357406616, 51.3493241582598, 50.836807659694124, 52.399936948503765, 54.60575723648071, 54.18612773077828, 54.323045458112446, 58.050246783665244, 72.95759296417236, 69.26411124638149, 80.89497184753418, 72.33035128457206, 85.57356221335274, 29.621956280299596, 0.7683692553213665, 5.644910216331482, 2.8437813009534563, 0.28652663795011385, 2.6065724066325595, 49.17614303316389, 80.31893839154924, 61.53921522412981, 54.87651811327253, 32.64296007156372, 66.1642210824149, 46.236763204847065, 0.23859560276780808, 0.2578937086675848, 0.277324128895998, 0.16897974189903053, 0.1535048551325287, 0.26503091997333933, 0.15759870117264135, 0.23017389753035136], [0.0839657840718116, 0.08490338376057999, 0.08571147825568914, 0.026220554086778845, 0.04692739028749721, 0.05683555540495685, 0.025764999245958667, 0.08743395297122852, 0.06539911856608731, 37.4583535194397, 51.178693771362305, 20.44599151611328, 42.46896008082798, 49.619629178728374, 54.513908999306814, 71.52730628422329, 5.233477847916739, 0.18040507739143713, 0.5488199133958135, 2.7965209569249834, 37.112489564078196, 81.79719543457031, 70.01137610844204, 66.99325234549386, 62.143201283046174, 63.730948039463584, 61.72359957013811, 63.037698473249165, 63.056639262608115, 60.50123773302351, 52.318566594805034, 52.2588746207101, 52.902941363198416, 56.31257874625069, 58.3057667868478, 58.73789610181536, 60.75427722930908, 60.43418761662075, 59.300700187683105, 57.51619781766619, 55.86568798337664, 54.25163882119315, 49.96436405181885, 50.00863797324044, 46.1076135635376, 47.222163677215576, 47.40632220676967, 47.20249680110386, 45.24565826143537, 43.351433413369314, 38.0955867086138, 39.80746303285871, 42.72832938602993, 42.88813100542341, 44.60328687940325, 45.12684753962925, 46.71650505065918, 43.58547306060791, 44.72939320972988, 47.49897643498012, 43.99181066240583, 46.14942782265799, 48.01241704395839, 48.22387157167707, 45.393109457833425, 42.76046827861241, 43.517425877707346, 45.68339129856655, 43.40966279166085, 41.92908157621111, 43.3892628805978, 41.23088141850063, 41.117872442517964, 42.02786064147949, 42.6917610168457, 45.128445625305176, 46.0418975012643, 50.14913749694824, 49.44897447313581, 46.666971342904226, 47.7860621043614, 51.42617818287441, 51.418385778154644, 50.98469659260341, 49.02652052470616, 40.79155376979283, 41.09838621956961, 42.209562982831685, 44.45700992856707, 45.95213024956839, 45.24968474251883, 31.643319266183035, 28.602936949048722, 48.82892765317644, 48.27487482343401, 51.96173143386841, 47.8637638092041, 47.88567842755999, 41.98976019450596, 43.799512318202424, 41.631309577396934, 41.213684626988, 43.36279719216483, 43.08825649533953, 39.13547842843192, 36.63010392870222, 36.0971805708749, 35.86702149254935, 39.756654330662315, 41.56378698348999, 41.74352298464094, 40.02747426714216, 41.48775979450771, 43.231517927987234, 43.63423899241856, 42.609379700251985, 44.748820372990195, 40.482588223048616, 39.25026961735317, 42.937640394483296, 39.203007970537456, 43.61149059023176, 41.918478625161306, 41.67082050868443, 38.883008684430806, 38.7392817224775, 37.169280665261404, 39.30249922616141, 41.566114630017964, 43.92099462236677, 42.62592683519636, 42.901169300079346, 44.43842697143555, 43.66251816068377, 43.56973539079939, 44.671094349452424, 43.54741082872663, 43.689588342394146, 44.048622608184814, 45.244560446058, 44.9904648235866, 45.3732966695513, 45.14999198913574, 45.19914354596819, 45.33959790638515, 46.10886076518467, 45.685104029519216, 48.39663852964129, 48.24440349851336, 55.28799390792847, 65.45076615469796, 67.69350569588798, 71.02915518624442, 67.85441902705601, 75.72091933659145, 26.153651782444545, 0.6202986921582903, 0.277960404753685, 0.7524546778627804, 0.40858129997338566, 0.8467943327767509, 22.073641777038574, 69.82208633422852, 46.00787912096296, 36.34472404207502, 24.201623133250646, 43.35790566035679, 38.492648465292795, 0.08142357798559324, 0.09066857690257685, 0.10286795121750661, 0.09146252394254718, 0.039948325138539076, 0.018671097134106925, 0.05098321122516479, 0.013275176319958908, 0.041162370171930106, 0.12429940514266491, 0.017743337899446487, 0.03874763706699014, 0.04158337400960071, 0.0394363942156945, 0.03987011379961457, 0.04467049121324505, 0.18051288303519997, 47.451874596732004, 58.46752779824393, 22.278316599982126, 36.76259217943464, 57.05858251026699, 60.6910833631243, 76.01130540030343, 5.437397054263523, 0.26460268295236994, 0.1542946020407336, 2.5886777554239546, 43.72219623838152, 84.04974583217076, 74.31721646445138, 70.37100097111293, 64.0798031943185, 65.00467790876115, 65.12561130523682, 65.27136366707938, 64.93371595655168, 62.61119025094168, 53.96656118120466, 54.547027587890625, 54.72734376362392, 58.18562201091221, 60.829560961042134, 62.704740796770366, 64.0825685773577, 63.507181303841726, 60.34932926722935, 59.83990819113595, 56.45619453702654, 55.33606154578072, 54.151247773851665, 51.85118906838553, 48.50219208853585, 49.508770670209614, 48.748554365975515, 48.43789693287441, 47.400423186165945, 45.62149327141898, 42.40021112986973, 42.01384959902082, 44.040527956826345, 46.66314288548061, 46.229120186397004, 47.23627546855381, 48.34361335209438, 46.490862301417756, 44.67312322344099, 50.155244963509695, 45.57104934964861, 46.40741096224104, 51.08854784284319, 49.23167303630284, 46.31540986469814, 44.265024253300254, 45.31828083310808, 46.24658795765468, 46.219927719661165, 44.96603148324149, 46.122249943869456, 42.88707487923758, 43.328685011182515, 43.42381279809134, 45.14577790669033, 47.77675151824951, 49.69092117037092, 51.86707265036446, 51.03103412900652, 48.90384660448347, 51.4118857383728, 54.87769930703299, 53.77660437992641, 53.80946935926165, 49.91201632363455, 40.63360731942313, 43.47101885931832, 44.256801060267854, 45.62772927965437, 48.0206367628915, 47.061333724430625, 36.470430850982666, 28.236386469432286, 48.5552659034729, 50.37992191314697, 53.13661275591169, 50.99698100771223, 48.74601132529122, 44.259100914001465, 44.357879979269846, 44.002093996320454, 43.67177663530622, 44.40788616452898, 44.46369756971087, 42.28506210872105, 39.21530280794416, 39.05163104193551, 39.68136017663138, 42.37371070044381, 40.84796619415283, 43.81510407584054, 40.730816091809956, 40.13397625514439, 42.09838138307844, 43.945497444697786, 42.607305662972585, 45.302230494362966, 41.35238456726074, 39.74446024213518, 43.51547343390328, 39.838316508701865, 44.63830580030169, 44.49231372560774, 43.43993956702096, 40.290133544376914, 41.86251088551113, 39.3965083530971, 40.58017567225865, 42.729288237435476, 45.415816170828684, 45.45356225967407, 44.9956134387425, 45.235232489449636, 45.919685636247905, 45.901971203940256, 47.78903940745762, 46.47619465419224, 46.08394105093819, 45.96755872453962, 47.59493105752127, 47.88609184537615, 47.05193975993565, 48.20450694220406, 46.39299692426409, 48.73713847569057, 48.65296799795968, 48.65015745162964, 51.33247825077602, 51.71633843013218, 58.2046149117606, 68.5359330858503, 70.26591641562325, 74.67351313999721, 70.85447747366769, 76.92953068869454, 27.837473017828806, 0.4711892104574612, 1.2941818918500627, 0.7846166949187006, 0.4062034147126334, 0.8077841060502189, 23.999946457999094, 76.41494015284947, 52.93393380301339, 42.74724585669381, 32.68399265834263, 49.65874753679548, 50.78208017349243, 0.10901431140622922, 0.04676678104858313, 0.0968533286026546, 0.05954171930040632, 0.06980033418429749, 0.04923010065353342, 0.05606162175536156, 0.043927634467503855, 0.09262153639325074, 0.20691873825022153, 0.11209976619907788, 0.1322983287807022, 0.27561126223632265, 0.1865369440721614, 0.14585213363170624, 0.10859107518834726, 0.192381193329181, 52.545654569353374, 67.27500874655587, 27.75283353669303, 56.12797900608608, 66.77352946145194, 65.57882145472935, 84.39338983808244, 7.648723789623805, 0.41045945776360376, 1.4887600051505225, 5.13941878080368, 49.972114767347065, 88.22571046011788, 78.4399995803833, 73.12851170131138, 69.05717999594552, 68.38297544206891, 68.12755966186523, 67.5058695929391, 67.68959386008126, 65.93083109174455, 58.026219912937705, 57.105871949877056, 57.122516359601704, 60.79731437138149, 64.04465225764683, 65.083956854684, 66.16515908922467, 64.25791331699916, 62.49482876913888, 62.37077563149588, 60.66214411599295, 59.541858264378135, 55.95186996459961, 53.60210384641375, 49.18170159203665, 51.51683132989066, 52.444613865443635, 50.75663587025234, 49.96300915309361, 48.55752406801496, 45.1656289100647, 44.51970699855259, 46.916988372802734, 47.775528635297505, 49.32211078916277, 48.890182971954346, 51.08474717821394, 46.69853353500366, 44.5552122933524, 51.19246857506888, 46.648447445460725, 47.10037217821394, 53.24595308303833, 51.40675796781267, 47.90911817550659, 44.97634260995047, 47.22576631818499, 48.78609548296247, 47.36139862877982, 45.17356027875628, 48.345899309430806, 46.30015509469168, 46.50794097355434, 45.554630756378174, 46.95015907287598, 49.550994873046875, 51.38440908704485, 53.99046298435756, 54.75655051640102, 52.55684116908482, 53.46849346160889, 57.11877475466047, 54.97206974029541, 55.14473247528076, 53.69388607570103, 45.79447214944022, 46.18134784698486, 45.474445070539204, 49.93345499038696, 49.15185213088989, 50.010573046548025, 39.893488679613384, 34.19498266492571, 53.21700688770839, 53.29514285496303, 56.353732926504954, 53.32570103236607, 51.58021627153669, 45.80618681226458, 48.602562291281565, 44.283833026885986, 46.78222458703177, 47.04903541292463, 47.101303236825125, 44.07255220413208, 41.35169669560024, 42.19649689538138, 41.33220699855259, 44.73115457807268, 44.14581053597586, 45.12453031539917, 43.31446204866682, 42.50985370363508, 44.067900385175435, 45.409941468920024, 43.34550312587193, 47.81180170604161, 42.4655693599156, 42.15911558696202, 46.28141232899257, 41.380514349256245, 46.49253681727818, 47.9442343711853, 45.03965112141201, 41.939003603799, 44.35316910062517, 42.54394851412092, 43.69952426637922, 46.210151604243684, 48.05001722063337, 48.13159602028983, 48.53468533924648, 48.79253993715559, 47.55570500237601, 49.037186009543284, 49.92448834010533, 49.00895200456892, 48.29088347298758, 49.1749826839992, 50.496985163007466, 50.42707586288452, 50.55248737335205, 51.82010630198887, 49.76975195748465, 51.77474846158709, 51.229252338409424, 51.462996687207905, 54.32181562696184, 53.450191906520296, 60.02841281890869, 70.8503224509103, 72.30197484152657, 77.29499898638043, 72.90835108075822, 80.00276061466762, 30.229350430624827, 0.685495485152517, 4.852631883961814, 2.3927567941801886, 0.548415289393493, 1.4507926596062524, 31.254991395132883, 83.58288247244698, 60.8271985735212, 56.11595514842442, 37.304280689784456, 57.92532164709908, 58.58947563171387, 0.16745408305100032, 0.15415658801794052, 0.2278959197657449, 0.14843051241976873, 0.19440550756241592, 0.11814594747764723, 0.15260297352714197, 0.14087720986987862], [0.06512362656316587, 0.07889275093163763, 0.05825364948915584, 0.10715782602450677, 0.12949479850275175, 0.020251520543492267, 0.05653305431561811, 0.010390646772326102, 0.06999916530081204, 47.100059509277344, 48.10036039352417, 47.05536869594029, 44.48348951339722, 46.59292091642107, 59.49370724814278, 65.37439155578613, 2.8730848942484175, 0.014099205361812242, 0.2907146375094141, 0.3890389214668955, 35.4892201423645, 81.49954155513218, 69.31688281467983, 70.2391311100551, 61.994301387241904, 63.77864047459194, 58.83054338182722, 60.437161445617676, 54.25688123703003, 52.72140577861241, 51.15962444032942, 55.29156180790493, 58.6647732598441, 66.36239065442766, 66.48606164114815, 68.63802991594586, 65.30115059443882, 63.47918701171875, 62.95044299534389, 62.156555720738, 57.92547450746809, 57.476301261356895, 54.522354534694124, 53.41641671316964, 47.34499740600586, 46.033118452344624, 44.978395802634104, 45.39850473403931, 44.88575547082083, 42.67596428734915, 39.95155824933733, 40.89924042565482, 43.50560351780483, 43.4672703061785, 42.477249281747, 44.2599972316197, 46.2089113507952, 43.04715442657471, 44.840668610164094, 48.37382064546858, 46.71476452691214, 48.79669148581368, 50.59212337221418, 48.30806636810303, 45.00455577032906, 47.52987854821341, 49.66893359592983, 52.20255599703108, 51.443281173706055, 49.691946029663086, 48.44714151109968, 48.00394718987601, 45.20358344486782, 42.904563495091026, 46.5796776499067, 47.99285786492484, 50.77442325864519, 50.24819796425955, 50.75202226638794, 50.04726995740618, 50.8805639403207, 53.011854376111714, 52.207913058144705, 49.157897063664024, 41.5424872807094, 36.24945034299578, 41.54965434755598, 42.48917586462838, 40.86809165137154, 44.85005215236119, 43.07807738440377, 36.63538803373064, 24.730657236916677, 33.607637541634695, 47.55958904538836, 46.370463916233604, 51.21676295144217, 48.94741528374808, 45.47150250843593, 40.156036785670686, 43.791365555354524, 41.13687923976353, 41.19483069011143, 38.61121947424752, 37.0208671433585, 36.80091496876308, 38.868275029318674, 39.009465898786274, 38.81325224467686, 41.35635198865618, 43.39381742477417, 38.52558292661394, 39.77263171332223, 39.44276251111712, 39.12357269014631, 37.979530947549, 38.969871589115684, 40.284053870609824, 40.16453095844814, 39.85123668398176, 39.52260078702654, 43.760633672986714, 41.20778908048357, 41.743373598371235, 38.89303493499756, 39.581695216042654, 37.55743483134678, 38.558694566999165, 40.99285350527082, 44.745672839028494, 42.42946652003697, 43.52413088934762, 42.735975878579275, 44.81322322572981, 42.50923531396048, 44.495673179626465, 43.04486846923828, 43.666700976235525, 43.826113496507915, 45.8167723928179, 44.13550983156477, 48.146086488451274, 44.73756429127285, 46.470229625701904, 45.18373244149344, 47.488088607788086, 46.45751789637974, 47.752443245479036, 46.67126532963344, 56.1701545715332, 63.81495870862688, 70.78357110704694, 66.71797861371721, 68.73381778172084, 64.74833801814488, 60.563292094639365, 0.5758771757994379, 0.16635562985071115, 0.349633163107293, 0.1856755167245865, 0.1808557060680219, 13.348853077207293, 69.85763331821987, 50.44041987827846, 33.063096795763286, 23.31588762147086, 39.5935731615339, 47.314543451581685, 0.33918863641364233, 0.12360276680971895, 0.12025072239339352, 0.14381632501525538, 0.12179981784096786, 0.05485482347596969, 0.07590089325926133, 0.06091763225517102, 0.0693555816209742, 0.038022680075040886, 0.1208513073090996, 0.057312311072434695, 0.07372612067099128, 0.03584729341257896, 0.09492576667772872, 0.03327846500490393, 0.2238046657294035, 55.55835178920201, 52.16297558375767, 45.40538692474365, 39.73331185749599, 56.22776556015015, 65.62885543278286, 73.53691986628941, 3.9383414472852434, 0.21211752428540162, 0.2761301243943827, 0.41251569028411594, 43.1784336907523, 85.45048877171108, 72.73238100324357, 74.09756306239537, 66.65099103110177, 65.8000659942627, 61.52430438995361, 62.31229959215437, 55.798960958208355, 54.91632086890084, 54.30540745598929, 57.729365076337544, 61.2893580027989, 69.14442157745361, 69.32864611489433, 69.90484632764543, 64.54759761265346, 65.66342966897147, 63.850728034973145, 64.1918637411935, 61.13170337677002, 60.04440757206508, 58.81119959694998, 54.88310500553676, 49.997743197849815, 48.54343659537179, 48.94437197276524, 47.904612268720356, 47.516617911202566, 45.93664618900844, 42.01580899102347, 44.29693038122994, 45.61023024150303, 44.204623562949045, 45.553428718021934, 46.58163356781006, 48.346910272325786, 44.534562247140066, 44.44681692123413, 49.93748147147042, 47.55261652810233, 50.243323802948, 51.535782541547505, 49.869177205221995, 46.77800703048706, 47.88304158619472, 52.716104303087505, 55.080190658569336, 55.059148039136616, 50.89311238697597, 52.30209936414446, 49.72691631317139, 47.90405988693237, 46.46239900588989, 48.22590739386422, 51.60077599116734, 53.63385363987514, 53.15669304983956, 54.712672642299104, 52.45853805541992, 54.754024846213206, 55.024546010153635, 54.32832261494228, 51.2231205531529, 43.731281008039204, 36.35173824855259, 41.01457357406616, 43.20013986315046, 42.30910982404436, 46.5373283794948, 43.33364255087716, 39.48118257522583, 27.069787400109426, 30.68111882890974, 49.179328782217844, 49.58529118129185, 54.10555641991751, 51.49755702699934, 48.196492195129395, 43.51532752173287, 45.80359513419015, 43.315188135419575, 42.28055272783552, 39.99614136559622, 39.31896645682198, 39.25782230922154, 40.78213896070208, 41.28151988983154, 41.131713254111155, 43.72564949308123, 45.12734086172921, 39.7642765045166, 38.74010508401053, 40.38006407873971, 39.99032572337559, 38.910259519304546, 38.30867406300136, 43.26321560995919, 41.934581075395855, 39.89557661328997, 41.35519858769008, 46.30976792744228, 43.45759146554129, 43.83945056370327, 39.77459805352347, 41.450701577322825, 40.508998325892854, 39.91763366971697, 42.8968996320452, 45.95640686580113, 44.540040901729036, 44.47073956898281, 45.75912666320801, 47.105600697653635, 45.63871438162667, 47.07492092677525, 44.261372974940706, 46.942894731249126, 46.37984051023211, 47.5791551726205, 48.21953589575631, 49.959371771131245, 46.32462665012905, 50.27684538705008, 48.3070831980024, 49.877098151615684, 48.453523431505474, 51.43406091417585, 49.4444511958531, 57.377741064344136, 63.972939899989534, 73.43857506343296, 67.47574915204729, 71.36629567827497, 66.83521556854248, 68.75416210719517, 1.0952456295490265, 0.31144529368196217, 0.1460256621773754, 0.15957593864628247, 0.46597328462771004, 15.34352629525321, 76.40017523084367, 56.534525053841726, 37.01919610159737, 26.934033496039255, 47.667661326272146, 57.234535217285156, 0.7251693191272872, 0.22021305773939404, 0.06471916540924992, 0.14639968425035477, 0.06102748028934002, 0.02249655034393072, 0.03345187141426972, 0.055213374950523884, 0.17698853143623897, 0.11477942312402384, 0.21704294213226863, 0.1999886158321585, 0.16930333524942398, 0.08195037221802132, 0.20193757196622236, 0.12589582162243979, 0.43920841653432163, 64.92189012254987, 60.48936326163155, 61.57164246695382, 56.9628050667899, 62.744880540030344, 73.58560589381626, 80.29004083360944, 4.9023827229227335, 0.28115486619727953, 0.4283852401588644, 0.43091039466006414, 49.851469721112935, 87.2728831427438, 77.22318240574428, 75.58599921635219, 69.67792510986328, 68.70777593340192, 64.63598564692906, 64.42767865317208, 59.45599242619106, 55.76386213302612, 56.68317828859602, 59.354861395699636, 63.52940164293562, 72.1889762878418, 73.47965976170131, 72.04319613320487, 69.68784713745117, 67.38234451838902, 67.83392184121269, 66.95598220825195, 64.13449941362653, 62.180804933820454, 59.84769712175642, 57.62387752532959, 52.84642471585955, 50.9940801348005, 52.622261932918, 49.37209265572684, 49.066128730773926, 47.243831634521484, 44.56227513722011, 46.62071023668562, 48.439932755061555, 47.58168431690761, 48.052713121686665, 49.34590489523751, 50.22350754056658, 45.56919070652553, 45.37175069536482, 49.59917368207659, 49.39022397994995, 49.77877766745431, 53.217864990234375, 50.541908740997314, 46.04371098109654, 50.07901627676827, 55.237560408455984, 57.46635838917324, 55.82716717038836, 52.76676361901419, 51.89848893029349, 53.42468506949288, 49.52157967431204, 47.49511671066284, 52.18594980239868, 52.34059585843767, 55.725059917994905, 54.40469026565552, 55.375141688755576, 54.777134554726736, 54.703695569719585, 55.97929450443813, 56.26099531991141, 53.66711466653006, 48.38250241960798, 44.09391791479928, 45.13705096926008, 45.10463762283325, 46.305543422698975, 49.719137804848806, 45.39969982419695, 41.74857432501656, 31.719794613974436, 37.35363374437605, 52.81465755190168, 52.18081508363996, 56.97527360916138, 52.755267824445454, 49.26569141660418, 45.75134815488543, 47.54369156701224, 45.40185376576015, 45.7819584437779, 43.14559303011213, 41.16373402731759, 39.73208202634539, 42.765113149370464, 42.97635923113142, 43.67802653993879, 45.00968354088919, 46.16982078552246, 40.80006878716605, 40.83824219022478, 42.50480931145804, 40.89154876981463, 40.32545471191406, 39.5210930279323, 45.27611916405814, 44.9265136037554, 39.87556232724871, 41.43156623840332, 47.93212366104126, 44.7549660546439, 45.81410428455898, 43.51583474023001, 45.24277475902012, 44.246201583317344, 44.185575076511924, 45.83904831750052, 48.81407240458897, 46.94589982713972, 47.62952266420637, 48.63800157819475, 50.263609068734304, 46.53014046805245, 50.75298111779349, 47.65661021641323, 49.688471930367605, 50.52934292384556, 50.19737536566598, 51.126203605106895, 53.813068526131765, 49.79559925624302, 53.65756436756679, 49.92324113845825, 52.73214421953474, 52.17047963823591, 54.481495652879985, 50.97957577024187, 61.499290875026155, 67.28717504228864, 76.5229776927403, 71.48912593296596, 73.32338782719204, 69.22349207741874, 67.36987945011684, 0.96853925713471, 1.9336350304739816, 2.1533985180514197, 0.24613019132188388, 0.9277077338525227, 20.197664635522024, 84.37710326058524, 66.05641283307756, 47.86694955825806, 34.970533643450054, 54.437308583940776, 67.82290199824742, 0.8858921719448907, 0.28955271414348055, 0.1889903095683881, 0.2256602147328002, 0.21331089096409933, 0.08897044123815638, 0.15755332075059414, 0.1765717209449836], [0.030301850621721575, 0.03285508968734315, 0.06564137592379536, 0.03126858321151563, 0.08427549459572349, 0.04735115237001862, 0.08695422871304409, 0.08582709383751665, 0.22556748613715172, 48.656713077000205, 43.60148171016148, 31.786406993865967, 34.6092655318124, 54.066559655325754, 57.096610001155305, 68.53245203835624, 3.9545059970446994, 0.18646009319594928, 0.5260128315005983, 0.630898223391601, 34.85955006735665, 79.57896218981061, 71.121246610369, 68.47040462493896, 64.011780330113, 62.091089793613975, 55.51297310420445, 52.10743168422154, 50.74740866252354, 56.29193912233625, 58.313882282802034, 66.65299211229596, 65.84511116572789, 66.69644614628383, 65.74222224099296, 67.37526430402482, 70.69875444684709, 67.98451709747314, 62.462311199733186, 64.1993955884661, 60.90644972664969, 59.89413888113839, 54.121148177555625, 52.97828415461949, 50.17839983531407, 48.76193312236241, 44.688350200653076, 48.39606877735683, 45.34108134678432, 43.406119210379465, 40.37167412894112, 41.08384016581944, 41.64175271987915, 42.26847675868443, 42.17226505279541, 43.772852080208914, 43.51405252729143, 44.34917388643537, 46.58642087663923, 47.1097730909075, 45.421875, 45.37796238490513, 49.95188856124878, 50.58676978519985, 51.011666025434224, 51.8206968988691, 56.61503035681588, 55.467368602752686, 56.37330600193569, 56.758225781576975, 53.74130058288574, 52.02301107134138, 51.447894777570454, 50.73040642057146, 49.91346154894148, 51.19773530960083, 51.47626774651663, 53.38907207761492, 52.51163966315133, 51.07819850104195, 49.81287942613874, 53.41682318278721, 48.64250748498099, 42.14776570456368, 38.37745080675398, 29.782348496573313, 41.753000327519004, 39.21594204221453, 41.19479594911848, 39.23077644620623, 43.02634457179478, 36.25961903163365, 29.704354967389786, 27.528106212615967, 39.10300602231707, 45.167803696223665, 50.036368233816965, 50.31239584514073, 47.116773400987896, 44.12659529277256, 40.58467810494559, 39.492223262786865, 38.803601196834016, 35.007862840379985, 37.79497984477452, 37.63303818021502, 37.76554380144392, 37.32659135546003, 39.938304560525076, 45.658947535923545, 46.041762011391775, 43.96112741742815, 38.68691662379673, 37.44688204356602, 37.354127066476, 38.47155720846993, 37.827254227229524, 42.516999925885884, 42.598860127585276, 44.40689952032906, 49.57797820227486, 41.39946208681379, 41.431201457977295, 40.68610790797642, 37.78330339704241, 37.9129706791469, 35.822660718645366, 37.58353573935372, 40.94455657686506, 42.264186246054514, 43.12410225187029, 41.82268033708845, 41.62613664354597, 43.44637707301548, 44.55153669629778, 43.8150589125497, 44.42888362067086, 46.074064186641145, 44.86807925360543, 50.28793123790196, 46.84164210728237, 48.561324732644216, 45.69790261132376, 47.89478056771414, 45.37572853905814, 46.944558824811665, 47.559700216565815, 49.61388649259295, 47.090019362313406, 52.38324737548828, 54.221685137067524, 70.80470057896206, 65.84575039999825, 72.56994601658413, 65.51799692426408, 82.28466715131486, 29.068671226501465, 0.3122306029711451, 0.1071019893778222, 0.0914467005059123, 0.100758725112038, 6.77918496302196, 67.00550201960972, 47.37924855095999, 41.61956017357962, 37.92572757175991, 36.4809330531529, 50.76722839900425, 2.134011741195406, 0.1791918703487941, 0.14195860469979898, 0.05645367589646152, 0.09450639810945306, 0.03222348215058446, 0.04730450987283673, 0.006129516829137823, 0.03219063766300678, 0.05408036056905985, 0.07429332844913006, 0.016125666310212443, 0.07699446100741625, 0.019992398197895715, 0.150087888485619, 0.02098066240016903, 0.6859987410051482, 58.41511058807373, 50.250720160348074, 37.763000760759624, 35.63096339362008, 60.162103107997346, 63.04298605237688, 75.08766746520996, 4.236955046653748, 0.26060546029891285, 0.1115770363914115, 0.6052934601902962, 42.00116913659232, 83.20130825042725, 74.61006913866315, 72.12537247794015, 66.9777717590332, 64.3954598563058, 57.215153217315674, 52.22454357147217, 53.604716369083945, 57.830989428928916, 62.03415625435965, 68.79628903525216, 68.58744008200509, 69.25201443263462, 70.30266543797084, 69.64178058079311, 73.17294543130058, 69.44189480372837, 65.04303891318185, 65.90300355638776, 63.63595226832798, 61.89754772186279, 57.09343467439924, 56.52021523884365, 51.41544669015067, 49.63527304785592, 47.89962346213204, 49.54316772733416, 47.61545951025826, 45.99750893456595, 43.70076104572841, 44.9026917048863, 43.61567340578352, 44.55834245681763, 44.06253637586321, 44.70940671648298, 45.874237469264436, 45.15842710222517, 46.25556155613491, 47.53586789539882, 46.12947954450335, 46.36585031236921, 52.09521675109863, 49.768633297511506, 53.21901839120047, 54.5359764780317, 56.9276054927281, 58.810532569885254, 58.048242228371755, 57.99592924118042, 54.9209692137582, 53.25572919845581, 54.86619656426566, 53.65993022918701, 50.99874585015433, 54.13224792480469, 54.269971643175396, 56.20554869515555, 54.44085216522217, 53.805067675454275, 52.53375577926636, 55.126778330121724, 50.41278689248221, 43.722345624651226, 38.34017024721418, 33.995155947549, 42.31040218898228, 40.83014753886631, 43.64700630732945, 42.48246043069022, 42.68829386574881, 36.868500096457346, 33.54579162597656, 28.64019318989345, 38.63038260596139, 46.64395890917097, 52.82797724860055, 52.225029945373535, 50.63881526674543, 44.165998526981895, 43.432574476514546, 41.69650452477591, 41.158064297267366, 38.835920742579866, 40.26083299091884, 39.25205530439104, 39.93953786577497, 39.603185994284495, 42.35190030506679, 49.06584732873099, 47.5079083442688, 47.54980598177229, 39.94484281539917, 36.74543707711356, 38.25895970208304, 39.836857386997764, 38.33467074802944, 42.37930400030953, 44.704324109213694, 45.603962966373985, 49.385130950382774, 44.142537934439524, 42.538025174822124, 43.01346261160714, 40.01817757742745, 41.26189122881208, 39.00279215403965, 41.177651269095286, 43.78072786331177, 44.2981150490897, 44.54455028261457, 44.74338340759277, 44.6060904775347, 45.52814074925014, 47.82276943751744, 46.419584206172395, 46.560500621795654, 49.08611174992153, 48.180636405944824, 52.9377692086356, 50.98361267362322, 52.05823148999895, 48.61010456085205, 50.88790471213204, 48.119057995932444, 49.78901931217739, 50.267083168029785, 52.25777333123343, 48.275486264910015, 54.51911320005144, 56.67911359242031, 73.70569161006382, 66.95183413369315, 76.10106917790004, 68.59889766148159, 85.00149617876325, 34.86709233692714, 0.22277318393545492, 0.12955381747867378, 0.046693869068154266, 0.32817956858447617, 8.249522362436567, 74.0917752129691, 55.98867457253592, 43.35019663402012, 34.69613538469587, 43.86812925338745, 60.70971843174526, 3.073161095380783, 0.41262672575456755, 0.15843694976397923, 0.1005807046645454, 0.11638320849410125, 0.06842948988612209, 0.02816237712145916, 0.053065221291035414, 0.11544623305755002, 0.14143877902201243, 0.10694855225405522, 0.1516578828117677, 0.13113974380706037, 0.11278951061623436, 0.20114274961607798, 0.15226217252867563, 1.109250700899533, 67.30548354557583, 55.777866227286204, 42.1321496282305, 47.270912238529746, 69.2175235748291, 69.48673152923584, 83.54031085968018, 5.337487169674464, 0.4235176199248859, 0.6542646352733884, 0.8595778782452855, 49.73154728753226, 87.04192502158028, 78.44185474940709, 73.16098758152553, 72.1065776007516, 68.01210839407784, 60.08790329524449, 54.584054538181846, 56.50922666277204, 62.992472648620605, 64.3983016695295, 71.40626866476876, 72.87064320700509, 72.59325722285679, 72.89013290405273, 72.03711645943778, 74.64173207964215, 70.45199612208775, 66.21545709882463, 68.84446784428188, 66.15023435865129, 64.68610995156425, 60.470082010541645, 59.479894229343955, 53.86471101215908, 53.54920373644148, 48.746796471732004, 53.211364950452534, 47.70680400303432, 48.239240986960276, 46.39477913720267, 46.39117302213396, 46.535580907549175, 46.81529106412615, 47.16305882590157, 47.15328965868269, 46.57010998044695, 46.53358677455357, 47.64409303665161, 48.068773882729666, 45.126343795231406, 47.11848265784127, 53.59244237627302, 53.65992328098842, 55.38997956684658, 56.058500494275776, 60.52176965985979, 59.86893081665039, 61.30861146109444, 60.787559100559776, 58.961329323904856, 55.00203384671892, 56.162883281707764, 55.67845140184675, 53.76479244232178, 58.44304929460798, 57.35796301705496, 57.93389572416033, 57.48927354812622, 56.74841839926583, 54.64832884924752, 57.807587896074565, 53.80375794001988, 44.056922231401714, 45.15116970879691, 37.60190330232893, 44.27943481717791, 42.54940285001482, 46.36850799833025, 44.30131469454084, 44.358109269823345, 37.14032752173287, 34.72745091574532, 31.53894690104893, 41.09350858415876, 51.05117000852312, 54.71692841393607, 54.17332567487444, 51.071684564862935, 47.04539108276367, 45.092367104121614, 44.41552223478045, 42.817936829158235, 38.68197645459856, 43.34484999520438, 42.285888944353374, 42.07920088086809, 42.50878368105207, 42.59244346618652, 48.69866977419172, 47.67002023969378, 48.93877519880022, 39.91800192424229, 36.4888505254473, 38.859631470271516, 40.890305042266846, 40.732195309230256, 45.25874171938215, 46.210168974740164, 48.35159683227539, 50.815542697906494, 45.880727086748394, 46.0678768157959, 46.33604948861258, 43.157453605106895, 44.38014548165457, 41.53233943666731, 42.96131290708269, 47.07346875326974, 46.89255155835833, 47.63934741701399, 47.67619718824114, 46.58780009405953, 48.431650502341135, 50.988538946424214, 49.005964279174805, 49.98874528067452, 52.04237222671509, 49.823145389556885, 56.411427293504985, 53.35694360733032, 55.1701455116272, 50.40183653150286, 52.97003664289202, 50.71158375058855, 53.69054051807949, 53.45392656326294, 56.507031032017295, 52.4517114503043, 58.052529266902376, 59.34555080958775, 78.08317484174455, 70.15655871800014, 78.86431912013462, 70.60039574759347, 86.63197435651506, 31.384735107421875, 0.6093793266585895, 0.4831426090427807, 0.12569794724030153, 0.7098292165568897, 11.495735509055, 81.3598758152553, 62.413930892944336, 58.64394950866699, 52.94686092649187, 50.65641852787563, 71.38445826939174, 3.933294883796147, 0.510725274682045, 0.38673754781484604, 0.1759801876864263, 0.1747128064078944, 0.15957889705896378, 0.1021292165720037, 0.16833182238042355], [0.027108037179069858, 0.03376725109826241, 0.07516366496149983, 0.09947379691792385, 0.023082775762304664, 0.03814537277711289, 0.03998129854777029, 0.04184853192418814, 1.017262522663389, 52.13931696755545, 49.961609091077534, 28.300096239362443, 27.653350966317312, 55.270831857408794, 62.29738180977957, 63.846552167619976, 1.1872317450387138, 0.08128799311816692, 0.6864643788763455, 0.2187341499541487, 42.39979076385498, 81.33239568982805, 69.18760463169643, 73.47431659698486, 63.40371567862374, 57.087441853114534, 49.08625418799264, 53.71556098120553, 57.60994291305542, 62.431871141706196, 66.1578426361084, 69.09917490822929, 64.56004878452846, 68.85011672973633, 61.915897914341514, 63.154129437037874, 61.15184620448521, 70.64822714669364, 65.46375233786446, 61.14423097882952, 58.70248113359724, 56.709678718021934, 53.57404702050345, 52.36561632156372, 49.34590489523751, 49.19343709945679, 45.345020975385395, 45.92759616034371, 45.15350430352347, 45.38358000346592, 40.81278051648821, 41.42161989212036, 41.22228649684361, 43.04445505142212, 42.612013067517964, 42.56630086898804, 45.2044415473938, 47.26013558251517, 46.31721639633179, 43.76474353245327, 49.22565589632307, 53.77933154787336, 52.30828673498971, 50.05692447934832, 50.40852417264666, 52.44999524525234, 53.10549177442278, 53.25806726728167, 53.44758980614798, 52.27737072535923, 53.753849029541016, 54.20657280513218, 53.64576285226004, 54.669461795261924, 51.99575328826904, 55.76472718375069, 54.5315956388201, 54.014663560049875, 49.26090063367571, 49.46529926572527, 48.188922132764546, 42.39410366330828, 35.21027776173183, 38.53611292157854, 30.782367978777202, 30.870967933109828, 37.63214186259678, 37.93201221738543, 38.713434423719136, 38.66908407211304, 42.21276610238211, 37.39869281223842, 34.30632059914725, 29.87507915496826, 33.26665122168404, 42.87712853295462, 48.408547742026194, 51.915345260075156, 50.71662466866629, 47.94694069453648, 45.3307181085859, 42.10696588243757, 40.06680801936558, 42.434823581150596, 42.020728315625874, 42.542965344020296, 43.7232106753758, 43.59561743055071, 51.125460147857666, 52.115404742104666, 52.87509993144444, 49.870490414755686, 45.09743234089443, 41.56838321685791, 37.21508666447231, 38.431222915649414, 39.147457122802734, 43.48810795375279, 46.533027444567, 42.230306829724995, 46.17089775630406, 41.96148450034005, 40.975111280168804, 40.18579592023577, 40.53136110305786, 37.138281277247835, 37.76459189823696, 39.44443007877895, 42.77094268798828, 41.140151841299875, 41.76833152770996, 43.73940692629133, 43.20777245930263, 44.54731913975307, 46.576922689165386, 45.484297616141184, 45.02088403701782, 49.1531514440264, 50.88667140688215, 49.93440341949463, 51.6183306149074, 48.70350572041103, 50.41223451069423, 48.52786568232945, 46.559274264744346, 45.96221555982317, 46.506443636757986, 46.96859264373779, 48.4796382359096, 50.63110971450806, 51.07586390631539, 53.721383571624756, 65.41250937325614, 65.6973021371024, 68.43582344055176, 69.12446635110038, 74.84612028939384, 3.641861379146576, 0.45875068647520884, 0.40127564913460184, 0.250850325184209, 7.518702149391174, 61.14929621560233, 49.79349742616926, 37.05069923400879, 29.588139397757395, 24.36389136314392, 55.3045653615679, 2.7711098747594014, 0.35209062695503235, 0.1783653332718781, 0.035478909965604544, 0.050726402683981826, 0.041144467025463066, 0.04209405303533588, 0.060453032542552264, 0.02883473238242524, 0.07403821963816881, 0.02234130322800151, 0.05178091395646334, 0.11763849827860083, 0.016717649098219614, 0.05487445688673428, 0.07110745047352143, 1.918469718524388, 62.4948913029262, 55.73781681060791, 31.479869842529297, 30.677867071969168, 62.48896448952811, 67.58367552076066, 68.6423030580793, 1.499872237443924, 0.3497447414057595, 0.41479505226016045, 0.3018912763467857, 47.90493883405413, 84.46856934683663, 73.3767569405692, 76.34237316676548, 66.24254117693219, 61.0841429574149, 52.068653787885395, 57.113282203674316, 58.781454358782085, 67.27762821742466, 69.03252778734479, 70.9446303503854, 66.81671946389335, 70.84789752960205, 65.82674707685197, 66.81404440743583, 65.45217663901192, 74.94163022722516, 64.63520744868687, 63.7141820362636, 60.82068811144148, 59.8079742704119, 57.27959428514753, 55.276501587459016, 51.28902769088745, 49.53908566066197, 47.798714773995535, 46.157220227377756, 47.51349122183663, 47.08804954801287, 43.29494455882481, 43.04678269795009, 44.62027522495815, 45.91620111465454, 43.877617018563406, 44.14695004054478, 45.51436594554356, 47.47186803817749, 46.85193586349487, 43.347111633845735, 49.44749450683594, 56.738819462912424, 53.11165482657296, 53.7879125731332, 52.362645966666086, 55.416678019932334, 54.359652042388916, 56.31704991204398, 55.62188611711775, 55.84065709795271, 55.7187613759722, 56.65460729598999, 54.86532456534249, 54.42401320593697, 55.231703077043804, 57.75308970042637, 56.907243796757285, 55.646708556583945, 51.70629480906895, 51.86606863566807, 49.498952865600586, 43.57320254189627, 38.45400605882917, 39.87954364504133, 30.38203362056187, 32.56429604121617, 41.26537922450474, 40.05542687007359, 41.218795027051655, 41.17776591437203, 44.175020762852256, 37.02007852281843, 36.670479910714285, 32.98718425205776, 35.00648014886038, 41.625205584934776, 49.73021323340279, 53.74020276750837, 53.95480482918875, 49.967911107199534, 47.131378514426096, 44.26513889857701, 40.87324374062674, 44.43426847457886, 45.04269790649414, 46.37922559465681, 45.12597206660679, 47.25259331294468, 51.93776362282889, 54.271812915802, 54.022310052599224, 52.40319912774222, 46.527958733694895, 42.99965306690761, 36.5823142187936, 40.12894923346383, 40.02899244853428, 44.45647839137486, 47.51796586172921, 41.5359594481332, 45.867970194135395, 43.68196269444057, 42.40411254337856, 41.08571965353829, 42.22998373849051, 39.29944201878139, 39.9602678162711, 43.370214394160676, 45.251168182918, 43.56147050857544, 44.94706984928676, 46.24524000712803, 45.272850036621094, 47.39905091694423, 48.049530846732004, 48.359754017421174, 47.8970422063555, 52.30055338995797, 53.49576166697911, 52.33621154512678, 53.57040616444179, 51.59838581085205, 53.226362637111116, 51.60471909386771, 49.168350628444124, 48.92854050227574, 50.486771311078755, 49.719162123543875, 52.792621340070454, 50.5087171963283, 54.50520290647234, 56.89637334006173, 67.33183806283134, 66.70017038072858, 71.66496399470738, 71.89308030264718, 81.1295360837664, 5.589292926447732, 0.5195906332560948, 0.39445221956287113, 0.5003452630979675, 11.169184940201895, 66.57116317749023, 60.576952253069194, 38.21529722213745, 30.489341599600657, 30.558413641793386, 65.4434288569859, 3.9609786782945906, 0.4670378246477672, 0.1113472097952451, 0.048141201226306815, 0.015917652918558036, 0.1095399521291256, 0.04576322775600212, 0.04736163912873183, 0.08771780452557973, 0.08954909590205976, 0.13261080772749015, 0.23804911066378864, 0.3020773577902998, 0.21138971405369894, 0.18409908988646098, 0.20664452867848532, 2.5387067454201833, 72.25674901689801, 64.27098287854875, 36.84336151395525, 39.14120374407087, 72.71088327680314, 72.66007110050747, 77.5708841596331, 2.127358623913356, 0.4341604145509856, 1.0936966155256544, 0.510107699249472, 51.801999296460835, 87.29058715275356, 77.26585824148995, 79.16575976780483, 69.96373925890241, 63.738410404750276, 53.46508537020002, 59.41845825740269, 64.00273377554757, 68.52151557377407, 72.47192777906145, 73.8933971949986, 69.75427886417934, 71.95041683741978, 67.18694727761405, 68.84607287815639, 66.93670095716203, 75.48265865870884, 65.24574565887451, 65.06411279950822, 64.14561653137207, 62.83776405879429, 59.295363971165244, 57.5122720854623, 53.273009368351524, 53.402874674115864, 50.61876623971121, 49.46587944030762, 48.05963700158255, 48.458567823682515, 45.72933626174927, 47.15440831865583, 45.66329363414219, 49.198203563690186, 46.219465664454866, 46.691376890454976, 47.06975146702358, 50.406926086970735, 48.292002132960725, 44.6956319127764, 49.78454467228481, 56.519586426871165, 54.26897457667759, 53.81822408948626, 53.668705804007395, 57.73431914193289, 56.27049003328596, 58.756621497017996, 58.58229119437081, 57.90478277206421, 58.86005932944161, 59.44694587162563, 58.15955931799752, 57.42243535178048, 56.327896050044465, 62.84586565835135, 60.12902968270438, 59.20331423623221, 54.67354733603341, 52.97516788755144, 51.70272690909249, 43.95510332924979, 38.13318688528878, 42.95129360471453, 35.09536845343453, 35.8017257962908, 40.624275888715474, 41.87823118482317, 44.658712659563335, 42.494522503444124, 45.26720462526594, 38.71044669832502, 37.137683732169016, 35.073387827192036, 37.68567425864083, 44.900301524571006, 53.72856453486851, 54.84777341570173, 55.511246476854595, 52.80905382973807, 50.01605517523629, 46.024269921439036, 42.4237551007952, 47.43551158905029, 46.283368246895925, 45.43292610985892, 47.27709266117641, 48.38792201450893, 54.05475466591971, 54.10187387466431, 55.560366766793386, 53.455236298697336, 47.38699231828962, 44.15937689372471, 37.351580551692415, 40.934123856680735, 40.85901035581316, 45.0893098967416, 49.24813331876482, 43.63103239876883, 49.76713943481445, 45.42280605861119, 46.38478067943028, 44.92427975790841, 45.763385908944265, 41.737884521484375, 43.34469713483538, 46.491359097617014, 47.462831905909944, 46.47614254270281, 46.67580597741263, 48.67254107339041, 48.67500768389021, 50.107969420296804, 50.682627132960725, 50.29024846213204, 49.861443860190256, 54.206986222948345, 56.10901389803205, 56.18609026500157, 56.6909567969186, 53.94061313356672, 56.486426149095806, 54.66436529159546, 52.073969159807476, 52.14745330810547, 52.72733954020909, 53.13419825690133, 54.539617334093364, 55.00331578935896, 57.21864816120693, 59.293244770595, 70.07329845428467, 69.23431737082345, 73.89607919965471, 76.69390337807792, 81.8167198726109, 4.8715744103704175, 0.6843885502644947, 0.6717683960284505, 0.8198675119451114, 14.589097840445381, 73.7965532030378, 66.76526805332729, 49.24527413504464, 49.92553404399327, 36.35722385134016, 79.24470520019531, 6.005966407912118, 0.5513248475534576, 0.2421485206910542, 0.12277185996728283, 0.12094783570085253, 0.23077000411493437, 0.12883724378687994, 0.18405301735869475], [0.060334221060786924, 0.07069341519049235, 0.005284255578382207, 0.048964871492769034, 0.032647719207618914, 0.05256476439535618, 0.07286733960998909, 0.12351003821407046, 1.4748798928090503, 57.565929549080984, 39.684761319841655, 40.8881893157959, 37.49714183807373, 54.30419152123587, 62.89157090868269, 60.8188259942191, 1.7779319797243391, 0.10303949165557112, 0.3133605809084007, 0.23500935520444596, 48.78568206514631, 80.51264722006661, 68.49721077510289, 70.90424742017473, 63.43828296661377, 56.391781261989046, 53.86379732404436, 60.30957167489188, 64.3105320249285, 69.31306825365338, 66.27194595336914, 67.86510535648891, 67.21897847311837, 64.67251232692173, 63.34273828778948, 63.90513937813895, 59.61156259264265, 58.100662912641255, 66.30752073015485, 59.57280554090227, 55.21326950618199, 53.94607441765921, 52.15824038641793, 52.767340319497244, 51.91589069366455, 49.323872157505576, 45.9867878641401, 44.66787385940552, 45.64050006866455, 45.62137862614223, 40.34190457207816, 41.319147859300884, 39.523573534829275, 41.74728543417794, 41.603812081473215, 42.67119434901646, 43.85214144842965, 44.88641554968697, 47.74442849840437, 43.09973839351109, 50.14367968695504, 56.01347269330706, 49.96744210379464, 50.958800656454905, 51.010078362056184, 52.93627187183925, 55.86050115312849, 53.90388148171561, 54.01070656095232, 53.589030810764854, 53.49418442589896, 54.6485025542123, 56.1125922203064, 54.70310149874006, 53.97594819750105, 53.04800932747977, 50.07454858507429, 49.09365054539272, 43.86808409009661, 43.55400814328875, 37.22977863039289, 42.24861533301217, 39.22827162061419, 37.6449647630964, 30.666878495897564, 33.092998368399485, 35.45037623814174, 40.10094799314226, 39.078583104269846, 39.39446210861206, 40.09650809424264, 37.20583861214774, 37.16110610961914, 36.22731338228498, 36.20975181034633, 39.83887583868844, 46.11798027583531, 48.82886859348842, 52.02090924126761, 50.960711411067415, 49.76988397325788, 47.43293033327375, 46.32329259599958, 47.79631069728306, 50.98987300055367, 53.40274265834263, 53.22695670809065, 53.18768201555525, 52.35212639399937, 49.68181208201817, 47.72294814246041, 48.7996757371085, 47.83526577268328, 44.27740594318935, 39.63035692487444, 42.48457963126046, 41.04338427952358, 40.42701653071812, 44.412270477839876, 41.3903807912554, 40.061933858054026, 39.43869434084211, 40.16101516996111, 39.48865188871111, 38.81079953057425, 37.30387422016689, 38.28939281191145, 40.949944904872346, 42.738564082554404, 43.407814570835654, 46.928317410605295, 45.91759770257132, 46.52917119434902, 46.1431952885219, 46.956280435834614, 48.700653484889436, 50.817592416490825, 51.96604626519339, 54.553037779671804, 58.953422273908345, 55.32410022190639, 53.26762798854283, 52.341318471091135, 48.25357164655413, 46.90393965584891, 45.37416172027588, 50.608159814562114, 47.01192855834961, 48.9686142376491, 49.94181019919259, 52.935914039611816, 51.78645965031215, 57.112191336495535, 57.468310832977295, 68.94464697156633, 63.93003477369036, 81.16366563524518, 25.092027834483556, 0.7419237600905555, 0.3807435594499111, 1.0753449031284876, 10.470887507711138, 60.965057781764436, 53.26619665963309, 36.70346300942557, 26.935308490480693, 29.054719243730815, 57.44446114131382, 3.275764052356992, 0.32504894371543613, 0.08111413209033863, 0.10688620845654181, 0.10031883085944823, 0.09710170634623085, 0.008778096426145306, 0.04094898108659046, 0.05343640369496175, 0.03223962110600301, 0.056602298814271174, 0.03044442439983998, 0.05470957626987781, 0.021633044982861196, 0.09073870349675417, 0.11110335788024323, 2.528916516474315, 64.70823996407645, 47.910090923309326, 41.88787528446743, 39.112434727805, 61.994384765625, 66.770249911717, 66.74775859287807, 2.188761591911316, 0.1514708785606282, 0.26079558581113815, 0.3934487205530916, 52.94283791950771, 84.92310660226005, 72.57255159105573, 73.50331142970494, 64.53029659816197, 58.82992499215262, 54.499067647116526, 61.99186256953648, 67.52803434644426, 73.37488787514823, 70.10546166556222, 70.57921069008964, 68.34653908865792, 67.00552286420549, 64.63630526406425, 65.90248244149345, 63.09288106645857, 62.46478475843157, 69.2860814503261, 59.89108862195696, 58.15219422749111, 57.24694469996861, 54.67477369308472, 54.24047654015677, 52.814820834568565, 49.95316008159092, 47.00038760049002, 49.132171358381, 48.57504742486136, 46.901855196271626, 43.70543023518154, 43.4090895652771, 42.16385773250035, 44.02362993785313, 44.295884677342, 45.28719111851284, 45.241475445883616, 47.0008670261928, 48.02617795126778, 42.794312953948975, 50.8761031968253, 55.95662948063442, 49.941132749829976, 53.59380769729614, 52.382375376565115, 54.686578682490754, 56.61958490099226, 56.55520984104702, 57.00728048597063, 57.0024619102478, 55.30236625671387, 58.963385990687776, 58.191413334437776, 58.4216696875436, 54.51969684873308, 54.39791577202933, 54.25196886062622, 50.77754994801113, 44.78666026251656, 44.02675315311977, 35.62556116921561, 44.05680758612496, 41.056637968335835, 37.799979073660715, 33.31627525602068, 35.284293447222026, 37.91334935597011, 42.86820009776524, 42.50262410300118, 42.40012775148664, 40.77536446707589, 37.4349102973938, 37.64673655373709, 36.78601108278547, 37.5327478817531, 40.32553809029715, 46.017835889543804, 51.31961366108486, 53.83398955208914, 54.346978528159006, 51.209519454411094, 49.57867997033255, 47.867189271109446, 49.60453074319022, 52.9842700277056, 54.636843476976665, 55.025789737701416, 54.510858740125386, 52.83574186052595, 51.11706672395979, 51.28624841145107, 50.35399123600551, 49.92715644836426, 45.85854843684605, 40.635973181043354, 42.21742834363665, 41.665922028677805, 40.19189991269793, 45.18320437840053, 40.57829965863909, 42.414107527051655, 41.979480334690635, 41.67930425916399, 41.16192749568394, 40.4392523084368, 38.01904535293579, 40.22630044392177, 43.32334532056536, 45.67374719892229, 45.10272339412144, 47.22354636873518, 48.6733192716326, 48.55501924242292, 51.350428921835764, 50.86407586506435, 52.0757965360369, 54.50251742771694, 54.119810649326865, 55.5768826348441, 59.817347390311106, 59.18797261374337, 55.69665568215506, 54.16076333182198, 51.21188531603132, 49.642822265625, 49.25776699611119, 51.61706951686314, 50.36989218848092, 51.10213157108852, 52.608803272247314, 54.99654129573277, 54.73988873617989, 61.1492406300136, 61.32866396222796, 69.99408899034772, 70.29995564052037, 85.34211771828788, 31.50359446661813, 0.7698547041841916, 0.2955628516418593, 1.8507716826030185, 13.738759057862417, 69.89867632729667, 59.1295382635934, 42.51859106336321, 29.579200540270122, 35.37863261359078, 67.68183967045375, 6.458658482347216, 0.6714168063231877, 0.07385519160223858, 0.09055300881820065, 0.13513167388737202, 0.06878568684416157, 0.02077309344895184, 0.048920312098094394, 0.18801164494029113, 0.27666242154581205, 0.10291548259556293, 0.1163307713078601, 0.15227579751185008, 0.22264593147805758, 0.14587661517517908, 0.15453101721193108, 2.9355822035244534, 77.76104940686906, 51.10370533806937, 49.762793336595806, 50.9125326020377, 68.17309815543038, 73.81651537758964, 73.60360867636544, 3.1147488866533553, 0.4063408859074116, 0.7229308592421668, 0.5176771645035062, 53.12868486131941, 88.42529051644462, 75.112229347229, 76.95519038609096, 67.9520342690604, 60.34156812940325, 57.466441767556326, 65.36698477608817, 71.24117946624756, 76.17593601771763, 70.01610088348389, 73.0489478792463, 70.61808586120605, 68.73382472991943, 66.80540084838867, 67.58141735621861, 67.09910815102714, 67.22013882228306, 67.89907509940011, 63.34863036019461, 60.12281799316406, 59.74478040422712, 57.246830054691856, 57.60808079583304, 55.18673780986241, 51.79753507886614, 49.526203700474326, 50.81175592967442, 51.269093309129985, 49.466119153159006, 45.95935637610299, 45.6326972416469, 45.58857618059431, 46.41609968457903, 46.73051609311785, 48.060463837214876, 47.82999208995274, 49.28442028590611, 48.669918128422324, 42.85844135284424, 52.65086766651699, 57.62090022223336, 51.59720114299229, 55.76885788781302, 54.726155621664866, 57.489860670907156, 59.3703350339617, 58.2694068636213, 59.99107319968087, 58.1125408581325, 58.0631217956543, 61.09074374607631, 60.568788119724815, 61.9346649987357, 57.06032303401402, 57.32115493501936, 55.952873979296, 52.33810492924282, 48.33086688177926, 46.71290588378906, 39.42197697503226, 42.13488027027675, 40.41963406971523, 41.14401156561715, 35.308945655822754, 36.49021932056972, 38.25365127835955, 44.607657296316965, 46.32033266339983, 44.24014622824532, 42.14101900373186, 37.63878781454903, 38.54712234224592, 37.943313462393625, 38.864262444632395, 43.335914611816406, 47.098277296338765, 54.278709002903526, 55.768065793173655, 55.36936773572649, 54.16722515651158, 51.91014800752912, 49.96921736853463, 51.374636445726665, 54.20536034447806, 56.79320648738316, 57.83080530166626, 56.16333144051688, 54.82680722645351, 53.962552070617676, 52.16799565723964, 52.78422791617257, 51.41185794557844, 45.5208659853254, 41.12102345057896, 44.27787494659424, 43.54985659463065, 41.38329362869263, 46.07029478890555, 41.64949301310948, 42.997853483472554, 44.360527242933, 44.30515010016305, 44.79394892283848, 44.849732535226, 41.37210702896118, 42.68171044758388, 46.179694175720215, 47.29815265110561, 48.890342780521934, 50.84611129760742, 51.07051379340035, 49.69805697032383, 52.84266921452114, 52.70015123912266, 56.96242986406599, 55.93790061133248, 59.373037883213584, 57.496034145355225, 61.283695220947266, 60.863836424691335, 59.64324637821743, 57.103815283094136, 53.233025959559846, 52.647167750767295, 53.26342780249459, 55.630098887852256, 52.209903717041016, 54.71797064372471, 55.67493561335972, 56.64088460377285, 56.01141602652413, 65.76010690416608, 64.50185067313058, 73.02930532182965, 71.24013028826032, 87.77616895948137, 31.384947027478898, 0.8619581790907043, 0.49462722135441645, 2.447629758289882, 18.34337455885751, 74.35090133122036, 68.7956428527832, 51.158755915505544, 43.623934813908164, 41.34897994995117, 82.47851494380406, 9.28799751826695, 0.8051056840590068, 0.23385003741298402, 0.23907652124762535, 0.23184808769396373, 0.21979024899857386, 0.12459082236247403, 0.125355029212577], [0.1546144498778241, 0.01967234001494944, 0.06797288331602301, 0.04755341687372752, 0.09771268641842262, 0.05679820205218025, 0.0671671772641795, 0.18178284274680273, 1.5905665308237076, 52.17077146257673, 45.489321163722444, 36.28946154458182, 30.743392058781215, 54.87983240400042, 67.75884655543736, 45.36521938868931, 0.22994322276541165, 0.08883636271847145, 0.13329122907349042, 0.47493765503168106, 56.328806264059885, 77.78008052280971, 71.50732326507568, 72.85485689980644, 60.67131573813302, 53.16759477342878, 54.20220933641706, 63.625509125845774, 65.59260668073381, 69.1397454398019, 67.37370790754045, 65.90933336530412, 65.37627451760429, 64.06416279929024, 60.59443392072405, 60.80319949558803, 62.90241009848458, 56.5570650100708, 56.67588268007551, 63.56474018096924, 54.067650522504536, 54.04982491901943, 52.42637137004307, 49.41701275961739, 50.53860834666661, 47.876465116228374, 45.415541716984336, 45.479614530290874, 47.688582352229524, 43.71835388456072, 41.98263481685093, 37.8935991014753, 40.44807652064732, 42.142314842769075, 42.06953593662807, 41.697418212890625, 43.38711241313389, 42.23702573776245, 51.43118783405849, 48.595822538648335, 50.23311342511858, 62.60317202976772, 55.38249635696411, 51.40918983731951, 49.80020591190883, 53.52603496823992, 54.53578887666975, 56.917610509055, 54.33304738998413, 49.07700266156878, 44.75524050848824, 44.245510237557546, 48.103785855429514, 50.10461344037737, 50.34161302021572, 47.11286851337978, 44.791301659175325, 42.02473395211356, 44.10727235249111, 38.96120023727417, 46.50288963317871, 38.158224718911306, 37.722520555768696, 37.37067420142037, 31.131039006369456, 38.439901215689524, 35.34229006086077, 40.07279389245169, 35.1630300113133, 35.81066117967878, 39.688954557691304, 39.25498744419643, 40.12544386727469, 37.64561094556536, 37.580169337136404, 42.443098885672434, 44.98772375924246, 50.57348482949393, 51.529845305851524, 53.32758052008492, 51.43501281738281, 49.374774660382954, 50.94651276724679, 50.122067315237864, 49.96665000915527, 52.37297446387154, 49.66072429929461, 50.56823199135916, 49.10568135125296, 48.750294889722554, 52.79594605309622, 50.79884270259312, 47.137517247881206, 47.30205059051514, 44.19393375941685, 41.807627064841135, 40.42439011165074, 41.93113476889474, 48.18013960974557, 44.121401514325825, 39.55970416750227, 39.407437869480674, 39.3284090587071, 37.607225622449604, 39.02748605183193, 36.72251844406128, 37.08390120097569, 41.305737836020334, 43.48856653485979, 45.90560858590262, 48.039754731314524, 49.899044036865234, 49.564630712781636, 50.504461424691335, 50.144173009055, 53.38135610307966, 53.97772693634033, 59.6216652733939, 66.98396260397774, 59.964016914367676, 57.380165985652376, 53.36990199770246, 52.67323391778128, 49.74636779512678, 47.75466319492885, 48.06389624731881, 46.26742907932827, 48.06538316181728, 48.964452266693115, 54.381851536887034, 58.65541403634207, 59.2497490474156, 59.69758823939732, 60.80705574580601, 63.099662508283345, 67.34765911102295, 74.34936577933175, 51.76772730691092, 0.46861240587064196, 0.2685781382024288, 1.2275314054318835, 9.468677605901446, 63.709776878356934, 53.83787359510149, 38.389488560812815, 29.298125062670024, 37.30715376990182, 52.53811229978289, 5.263843647071293, 0.5332834699324199, 0.08381573283778769, 0.05037548812106252, 0.06476462047014918, 0.09229516104928084, 0.15696492232382298, 0.051377012593937774, 0.13427454845181533, 0.019058477865265946, 0.08015633919941527, 0.06040337734988757, 0.09734017069318465, 0.06320982532841818, 0.1370424556412867, 0.2231496080224003, 2.896718974624361, 60.440420150756836, 54.16279567990984, 33.62479611805507, 35.028426034109934, 61.071226256234304, 71.85390635899135, 46.429582663944785, 0.10976039458598409, 0.03636805207601615, 0.2314301644052778, 0.5975848681160382, 62.842586108616416, 78.75892189570835, 72.59516102927071, 74.25195898328508, 63.70133481706892, 56.9013169833592, 58.08527265276228, 66.74682058606828, 67.18892056601388, 70.15695476531982, 68.69217722756522, 68.44655145917619, 67.13417570931571, 66.14703123910087, 64.27086475917271, 63.02320453098842, 64.47990826198033, 61.50603757585798, 60.76744406563895, 66.93062128339494, 56.888671261923655, 57.577713693891255, 54.03788791384016, 52.743014676230295, 52.41637986046927, 50.210090569087434, 47.88816588265555, 48.73444604873657, 48.31194346291678, 47.49003757749285, 43.20540312358311, 41.52705880573818, 43.49664381572178, 43.94553913388933, 43.99189404078892, 42.81628663199288, 45.68638597215925, 42.22486291612898, 51.1201308795384, 48.753810678209575, 50.95897783551897, 63.45183890206473, 54.638566630227224, 53.804459708077566, 51.26355906895229, 52.49151420593262, 55.86999239240374, 58.64843804495675, 55.825058392116, 51.31062616620745, 46.17998252596174, 47.36346571786063, 49.213559082576204, 49.81830596923828, 53.18921409334455, 48.42905535016741, 47.96424865722656, 42.58022158486502, 44.52330616542271, 37.75229011263166, 48.1227023260934, 42.64383234296526, 35.86243568147932, 37.404577936444966, 33.34144163131714, 39.80206080845424, 36.706360408238, 41.56791421345302, 38.04552493776594, 38.7149213382176, 40.76127699443272, 38.35215588978359, 39.067709173474995, 36.84274312428066, 38.48689883095877, 45.5676759992327, 45.50322103500366, 52.26783432279314, 52.333307198115754, 55.084647927965435, 53.604622568402974, 53.378090449741904, 53.735050678253174, 50.71183735983712, 52.06894908632551, 53.303675242832725, 52.604283469063894, 53.022203717912944, 50.987760748182026, 50.16600424902779, 54.253771918160574, 51.36233466012137, 49.16509192330496, 48.6664058140346, 43.43225138528006, 44.31643744877407, 40.94691549028669, 43.32237952096121, 50.48569086619786, 45.091338770730154, 41.165147985730854, 41.455947467258994, 40.484912395477295, 39.38735062735421, 40.51508494785854, 40.094604287828716, 39.28862714767456, 43.93540518624442, 44.83383158275059, 48.05953625270298, 49.704970427921836, 52.45304203033447, 52.42223024368286, 52.141199929373606, 53.14133753095354, 56.16157007217407, 56.52804238455636, 62.4085807800293, 67.84739439828056, 63.0194525037493, 58.30535684313093, 57.60965803691319, 54.283940996442524, 53.25286306653704, 50.38219397408621, 51.11714315414429, 48.405177865709575, 51.0349702835083, 51.469211850847515, 57.996002197265625, 59.7670076915196, 64.79380702972412, 63.48302936553955, 65.17479065486363, 65.92832279205322, 71.42275674002511, 76.22239862169538, 61.38087272644043, 0.6126421030078615, 0.15255299263766833, 1.183248907327652, 12.69966811793191, 73.30910233088902, 64.27187919616699, 42.22900751658848, 35.41137947354998, 46.83774764197213, 59.91715131487165, 9.715330839157104, 0.8537579476833344, 0.3265032613916056, 0.1600321584514209, 0.08015302116317408, 0.13027174824050494, 0.11638240782277924, 0.003502727112001074, 0.3726174240665776, 0.0795876250735351, 0.2713048718869686, 0.17567040930901254, 0.17093595835779393, 0.08257058715181691, 0.21420214671109403, 0.29530522546597887, 3.2491025115762437, 72.85574626922607, 56.40310682569231, 46.34413371767317, 44.15087577274868, 67.3931211744036, 78.97894355228969, 55.402951853615896, 0.4466400034725666, 0.2713519622172628, 0.7738077949200357, 1.3277372398546763, 60.49941035679409, 82.90194511413574, 75.57118565695626, 77.76877580370221, 66.22866562434605, 59.33762986319405, 61.68311241694859, 69.82871491568429, 69.5181165422712, 75.05364213671002, 72.9464966910226, 69.9790461403983, 69.57744026184082, 69.32579735347203, 66.0739083971296, 65.93937042781285, 67.35101509094238, 65.23984663827079, 60.2167854309082, 65.8179715020316, 59.54699298313686, 58.23941149030413, 57.36994865962437, 55.13453599384853, 55.524666922433035, 51.968280111040386, 49.838434900556294, 50.9873160634722, 51.84908376421247, 47.85673223223005, 46.594296659742085, 44.5911796433585, 46.18738235746111, 46.7509229523795, 45.83470916748047, 46.78439242499215, 49.78276940754482, 44.79675946916853, 53.698857511792866, 50.617053508758545, 52.13165657860892, 65.34117916652134, 57.76933111463274, 54.488930225372314, 53.53356334141323, 56.39900391442435, 58.23580190113613, 59.99561037336077, 57.23069633756365, 54.22000714710781, 49.24265813827515, 51.527823380061555, 52.6646146774292, 55.4109388078962, 55.52572304861886, 50.41954401561192, 50.22692952837263, 44.12676899773734, 45.48426634924752, 38.50868838174002, 46.1431223324367, 41.1462071963719, 38.707712582179475, 39.07662371226719, 33.61969266619001, 41.64375727517264, 37.38570315497262, 45.95664310455322, 42.01677826472691, 40.68373509815761, 41.658529145377024, 38.51525442940848, 40.33931636810303, 39.73363842282976, 39.6824232510158, 47.24371004104614, 46.329907281058176, 55.51182665143694, 54.4510486466544, 58.19572121756417, 56.72549976621355, 54.879401615687776, 55.23141820090157, 54.66466753823416, 52.94655173165457, 55.886591638837544, 54.34507819584438, 53.00888054711478, 54.40980066571917, 53.26877791540963, 56.046587807791575, 52.908857754298616, 50.116168294634136, 49.30901343481881, 46.31994703837803, 44.2526912008013, 41.45493997846331, 43.345430169786724, 49.72104855946132, 46.56783444540841, 43.068360328674316, 43.17308357783726, 43.837664876665386, 42.587496348789756, 44.6744954926627, 42.67186485018049, 42.402820178440635, 44.77946192877633, 47.284881591796875, 50.404490743364605, 52.9201659475054, 55.520001207079204, 54.98433678490775, 54.887788091387065, 55.15005479540144, 60.31773580823626, 59.533284187316895, 63.21291814531599, 66.31197452545166, 66.98321914672852, 65.11250700269426, 60.24436977931431, 58.85244410378592, 56.27718114852905, 54.1492223739624, 54.55108186176845, 52.3727034841265, 55.0848320552281, 54.59999023165022, 60.11469554901123, 62.48269721439907, 68.12607969556535, 65.80784797668457, 66.94834613800049, 65.6971492767334, 74.25965063912528, 77.80221053532192, 63.874636786324636, 0.9774150380066463, 0.30480110592075754, 2.5431637976850783, 17.288410459245952, 78.37183080400739, 69.16652379717145, 52.55678905759539, 46.740201881953645, 52.504562922886436, 75.2786317552839, 14.726545367922101, 1.179395154118538, 0.5791829441274915, 0.2706918833511216, 0.2197632704462324, 0.2600432533238615, 0.30211828702262467, 0.13066444359719753], [0.11605067205216203, 0.043731205364955325, 0.05849911631750209, 0.1007462739944458, 0.11713795656604425, 0.011811466870962508, 0.0843103373689311, 0.05620624470923628, 2.7833960269178664, 58.033303601401194, 37.25548696517944, 37.50718198503767, 34.75347191946847, 48.299599988119944, 69.91712379455566, 19.630566562925065, 0.14225543662905693, 0.29557568952441216, 0.3508236120854105, 1.3949043899774551, 58.777834347316194, 78.00234644753593, 71.24517468043736, 68.95233862740653, 55.047270093645366, 56.69949960708618, 60.5827123097011, 63.51759665352957, 64.21168000357491, 65.91485718318394, 64.2442878995623, 62.576463154384065, 62.111885751996724, 61.04908929552351, 60.50460066114153, 60.99264907836914, 57.81001629148211, 59.92352281297956, 55.18164825439453, 61.399535587855745, 58.77667399815151, 58.8630678994315, 56.390367303575786, 52.542687688555034, 51.94299909046718, 51.222495215279714, 47.33981057575771, 45.68010827473232, 44.712008816855295, 45.31400074277605, 40.20199564525059, 39.24821295057024, 37.450727871486116, 41.88153852735247, 40.35864625658308, 43.70356811795916, 43.42104394095284, 45.16182477133614, 51.80089800698416, 55.27537597928728, 55.7551942552839, 59.91224588666643, 51.75301102229527, 50.58724921090262, 48.76877709797451, 50.48775100708008, 52.64987754821777, 56.17206185204642, 53.84162562234061, 50.029593740190776, 46.18765333720616, 44.7616536957877, 42.27436883108956, 40.82401922770909, 40.70222078050886, 40.204358032771516, 41.586531911577495, 41.986324310302734, 41.644570214407786, 41.173874923161094, 35.76989262444632, 30.804650851658412, 40.69806228365217, 37.67785406112671, 45.06130518232073, 36.25100326538086, 39.2194230897086, 39.52975048337664, 33.096402985709055, 34.388965947287424, 40.57745892660958, 38.88788284574236, 38.68974454062325, 37.31004422051566, 40.87670046942574, 41.63296324866158, 42.42733342306954, 41.37413937704903, 49.00601986476353, 50.28212601797921, 53.61454807009016, 51.33701889855521, 50.66523231778826, 49.75930186680385, 52.725244658333914, 53.428565638405935, 49.86113119125366, 48.85385084152222, 47.24508578436715, 52.519845485687256, 51.6372401373727, 49.28022009985787, 47.472712244306294, 45.79094246455601, 39.50213139397757, 39.302401951381135, 45.00200925554548, 48.2782620702471, 54.211943762642996, 46.58396816253662, 38.854416847229004, 37.59859595979963, 38.097400188446045, 37.17464467457363, 36.736807414463584, 36.857393401009695, 39.350070067814414, 42.12325593403408, 42.262626375470845, 47.272645814078196, 48.24541793550764, 50.196961947849815, 49.60783461162022, 50.261892863682334, 55.07934992653983, 55.91865757533482, 61.855281829833984, 64.75580733163017, 51.5486193384443, 53.1426750591823, 55.19423491614205, 55.72805806568691, 51.721493993486675, 51.76470831462315, 49.65633651188442, 49.19448280334473, 46.286738123212544, 48.786508900778635, 49.095787116459434, 54.93084955215454, 56.877300534929546, 65.16648060934884, 62.02319894518171, 66.51513290405273, 64.50266361236572, 72.26699760981968, 71.66199016571045, 70.13250405447823, 0.4308097000632967, 0.048169312932129414, 0.4417302597846304, 8.899056468691144, 67.68263871329171, 53.133750098092214, 41.76105328968593, 25.608310256685527, 25.41408552442278, 55.52329117911202, 8.912621089390345, 0.5741131475993565, 0.04263298286657248, 0.13400498005960668, 0.06558019920651402, 0.04249716051188963, 0.11042145054255213, 0.04504494076328618, 0.011608585748555405, 0.013472628314048052, 0.1042543611090098, 0.10578504790152822, 0.039103281018989425, 0.057850715039031844, 0.14516635185905866, 0.18368966185620852, 4.031603208609989, 68.36144297463554, 41.812435218266074, 36.00532191140311, 42.00099195752825, 54.71668175288609, 73.93302277156285, 20.36814389910017, 0.1409219524690083, 0.20674169489315578, 0.20954690793795244, 1.8558898993900843, 65.21658406938825, 80.01956135886056, 72.48430252075195, 72.13507216317313, 58.308163915361675, 58.1793269429888, 63.171548570905415, 66.2997248513358, 67.85736506325858, 69.05724252973283, 64.98501450674874, 65.42333466666085, 64.70859432220459, 64.71195030212402, 62.306192125592915, 64.77939646584647, 60.38782228742327, 60.47838510785784, 58.874108586992534, 64.35812718527657, 62.41103349413191, 61.33736310686384, 58.74703298296247, 56.484657832554404, 53.53716598238264, 51.30801016943795, 48.51761361530849, 47.41324608666556, 46.69286380495344, 46.531946999686106, 42.01498910358974, 42.47268431527274, 39.44691405977522, 42.971742153167725, 43.46337236676897, 45.037538869040354, 44.718970911843435, 47.04721845899309, 55.85493912015642, 58.80537005833217, 56.03448404584612, 58.811922209603445, 52.73805366243635, 52.28650065830776, 51.577148641858784, 50.361863545009065, 54.0891239302499, 56.35057497024536, 54.537532874516074, 51.003870146615164, 48.495191778455464, 50.345264298575266, 46.59801047188895, 43.689237458365305, 41.96958957399641, 40.36445495060512, 42.475616455078125, 41.45342527117048, 41.88562406812395, 42.263439314705984, 40.36960703986031, 35.06148208890642, 41.0365264075143, 39.505831309727256, 46.160569259098594, 36.95362942559378, 40.568287304469514, 40.23623636790684, 36.28213119506836, 39.06181015287127, 42.19814361844744, 39.82103286470686, 38.666509764535085, 38.579170908246724, 41.29407181058611, 42.27573067801339, 42.1004832131522, 39.24329015186855, 50.18651533126831, 52.62263018744332, 53.807812213897705, 53.943058899470735, 53.721758774348665, 52.79673119953701, 55.212032726832796, 54.635224546704976, 51.04669884272984, 50.93987028939383, 49.44290174756731, 53.01369912283761, 52.88223920549665, 53.673062324523926, 49.687089238848, 46.97216054371425, 42.07238122395107, 41.297882897513254, 44.97259405681065, 53.06757198061262, 55.80727447782244, 46.24716465813773, 40.34816142490932, 40.50746624810355, 39.70778070177351, 39.79442473820278, 39.64649064200265, 40.33187484741211, 40.60431718826294, 44.61200686863491, 44.10882527487618, 48.11180407660348, 48.72190107618059, 52.536034788404194, 53.04533774512154, 53.48422418321882, 58.14902932303292, 58.599599157060894, 63.720942633492605, 67.41805825914655, 56.22145659582955, 57.7704428264073, 57.50923572267805, 58.88319683074951, 54.801856245313374, 55.39617735998971, 50.75205700738089, 51.20815413338797, 48.42501149858747, 52.97362191336495, 51.439146995544434, 58.882564544677734, 57.76286581584385, 68.53990745544434, 64.03918402535575, 70.60411998203823, 65.32491343361991, 78.5276163646153, 71.99562181745256, 81.18328039986747, 1.6952654612915856, 0.06588872229414326, 0.5655497099672044, 12.71211234160832, 76.09613595690045, 60.84008053370884, 50.398887021201, 27.159681456429617, 33.52952936717442, 67.73862729753766, 15.224418537957327, 0.8137741589120456, 0.14912303883050168, 0.12472925707697868, 0.06867810511695487, 0.07016724521028143, 0.05999050236174038, 0.05482507650075214, 0.3409669409905161, 0.23492779529520444, 0.28133049820150646, 0.27735045605472153, 0.23583841643163136, 0.13978216291538306, 0.3106375113129616, 0.27176727993147715, 5.529780736991337, 80.48809923444475, 46.89721032551357, 48.79670885631016, 51.113926138196675, 62.62554522923061, 80.30591746738979, 25.110075780323573, 0.2735025111053671, 0.376183342720781, 0.8136394289987428, 2.161339874778475, 63.43192536490304, 82.83637496403286, 75.59855461120605, 73.88751901899064, 61.25274099622454, 61.62528256007603, 64.34218106951032, 70.6265001296997, 69.73695005689348, 71.40191909245083, 68.7962612424578, 68.7773551940918, 68.11635221753801, 68.52400997706822, 65.28821304866246, 67.26152924128941, 62.449422291346956, 63.264494623456685, 58.88818563733782, 61.46094376700265, 66.08430290222168, 64.74792112622941, 61.170029640197754, 58.162335123334614, 56.056311811719624, 56.947856017521445, 53.369919368198936, 50.102997984204976, 49.618086678641184, 48.43679564339774, 44.21647024154663, 44.71075814110892, 42.99284035818917, 45.73901162828718, 43.87922205243792, 47.6368773324149, 47.868300982883994, 51.64537647792271, 58.23373828615461, 60.52658476148333, 60.080079623631065, 64.91250310625348, 53.7692358153207, 55.77167190824236, 53.6318872996739, 53.76126970563616, 56.007424286433626, 59.87454496111189, 57.916716303144185, 50.668171405792236, 47.445537839617046, 48.834889207567485, 46.39336517878941, 44.19027205875942, 42.77165487834385, 42.334502015795024, 43.01245512281145, 43.44326775414603, 42.75355134691511, 41.443121092660085, 40.56704010282244, 37.2312342779977, 43.37239612851824, 37.89235884802682, 46.332881110055105, 39.99586343765259, 40.79682745252337, 44.484733240945, 39.59804432732718, 41.441790512629915, 42.005268573760986, 40.51670387813023, 38.77326883588518, 39.50387191772461, 41.64387886864798, 43.01920182364327, 44.27011728286743, 42.937348570142476, 52.2563385282244, 55.49247244426182, 57.71222039631435, 56.54259538650513, 56.04465968268258, 54.03345496313912, 56.03381354468209, 58.26042284284319, 52.26474584851946, 52.948365211486816, 51.168823855263845, 54.001611368996755, 55.185313429151265, 52.98555197034563, 51.18110827037266, 49.02163246699742, 44.0245748928615, 41.790124552590505, 45.71476936340332, 52.63725961957659, 58.32492297036307, 49.136117935180664, 42.645635400499614, 42.11896194730486, 42.88972561700003, 41.848958424159456, 42.078207288469585, 43.6060015133449, 44.290673528398784, 46.771586894989014, 46.94900567190987, 51.58277668271746, 52.35872023446219, 55.688915388924734, 54.880989279065815, 55.80481481552124, 61.300725255693706, 62.856795174734934, 64.01278781890869, 67.473206111363, 59.84985106331961, 59.87348188672747, 59.49766772133963, 60.41251618521554, 57.16818686894008, 58.02956894465855, 53.258407729012625, 55.299500124795095, 49.84377806527274, 55.48409291676113, 53.835174219948904, 61.0832952771868, 61.80036326817104, 71.25527736118862, 65.53449889591762, 73.75066035134452, 67.34583868299211, 81.67497662135533, 74.01687363215855, 83.1521497453962, 3.56254334960665, 0.11204627049820763, 0.8812388873526028, 16.54603886604309, 83.00639738355363, 69.37499754769462, 58.71848978315081, 39.25722476414272, 38.96149206161499, 79.04489585331508, 19.207574129104614, 1.088943070599011, 0.44637833322797504, 0.3451196295874459, 0.19215083069034986, 0.15181917058570044, 0.24444655595081194, 0.1236261355557612], [0.0514312173639025, 0.07217076234519482, 0.09507067461631127, 0.026304035946460705, 0.029863822340433086, 0.10401717240789107, 0.11466761412365095, 0.13695979650531495, 2.887917126928057, 55.03128228868757, 45.828848361968994, 32.85920538221087, 46.07621118000576, 46.285372802189414, 69.02810873304094, 13.29780466215951, 0.17459717047001633, 0.23537793542657579, 0.1974905484489032, 1.2587480332170213, 61.502327237810405, 76.10638454982212, 68.84656620025635, 65.95237745557512, 54.90310192108154, 58.106878076280864, 57.52355943407331, 61.44433062417166, 58.686604499816895, 62.748979977199006, 60.252186502729145, 62.32393087659563, 59.718411990574424, 57.804655756269185, 58.73221942356655, 63.49602944510323, 61.24534116472517, 62.67463425227574, 57.70014442716326, 57.73003557750157, 61.7104674748012, 58.4527976172311, 57.2647077696664, 57.9902595111302, 58.050764424460276, 58.46462345123291, 48.54422869001116, 45.50102540424892, 44.43439701625279, 43.91761432375227, 42.26983860560826, 37.24536691393171, 38.204169682094026, 40.52230760029384, 39.27032559258597, 40.95773383549282, 39.657149178641184, 48.17019326346261, 52.724730491638184, 54.84032842091152, 45.74567495073591, 45.383712019239155, 50.15672492980957, 45.58902086530413, 42.29337215423584, 42.719595500401084, 44.97725282396589, 45.332389150347026, 48.01373372759138, 49.20983484813145, 50.51189947128296, 55.22190611703055, 54.19561202185494, 53.45868607929775, 50.810567787715364, 48.721122877938406, 47.239954539707725, 43.444431577410015, 40.12232065200806, 35.05016347340175, 33.8623446055821, 41.61224719456264, 39.137149470193044, 41.25690589632307, 40.8254714012146, 35.50231402260916, 39.29231316702706, 33.73404611860003, 33.25634356907436, 33.64600896835327, 37.96879250662667, 39.767715862819124, 38.85820361546108, 43.317474092756, 35.264227049691335, 35.22987515585763, 41.875045435769216, 37.52103321892874, 41.24699081693377, 41.80612972804478, 46.410631452287944, 49.22436005728585, 50.191990511757986, 51.65996422086443, 50.593308040073936, 47.32691471917288, 44.83803176879883, 43.08944116319929, 50.5808881350926, 53.46469974517822, 53.95196301596505, 52.721430097307476, 46.80974292755127, 43.35620335170201, 42.31183351789202, 43.554039410182405, 55.36189494814192, 55.81863130841936, 51.26745353426252, 46.74262680326189, 40.21802166530064, 38.76982600348336, 37.43522296633039, 38.84638820375715, 36.23799276351929, 36.57095391409737, 38.38832473754883, 42.23582717350551, 41.088054248264854, 47.75034141540527, 47.276588916778564, 50.78682231903076, 49.96416255405971, 56.62589733941214, 53.79087945393154, 62.03637967790876, 54.530355385371614, 46.396311214991975, 53.376547949654714, 58.43214757101876, 56.408220699855256, 58.22655037471226, 56.17245789936611, 55.78463724681309, 54.581035545894075, 54.92469344820295, 50.95757777350289, 50.162644795009065, 48.59059401920864, 56.48484543391636, 59.84311825888497, 66.5193087714059, 65.36468492235456, 69.6550099509103, 64.72663184574672, 76.40964562552315, 63.58662700653076, 79.01269095284599, 6.253622787339347, 0.1561062362577234, 0.4550092715237822, 11.674411041396004, 68.12137576511928, 53.75538110733032, 45.1739285332816, 31.862399441855295, 32.63345840999058, 59.51209912981306, 14.018749747957502, 0.7166151638541902, 0.008192775155683714, 0.12118224240839481, 0.16549630596169404, 0.11069250492645161, 0.06118017780993666, 0.0421056899109057, 0.0644324640078204, 0.06429763909961496, 0.03462344015549336, 0.053604317363351583, 0.06469338786389146, 0.038874696141907146, 0.1843354372041566, 0.18879897626382963, 3.493789621761867, 64.92519746507917, 47.72433083398001, 33.56626449312483, 53.19547094617571, 51.551558426448274, 75.40459564753941, 12.979843803814479, 0.3582997652036803, 0.182282027389322, 0.34852997373257366, 1.7884765224797385, 67.66092559269497, 76.57628427233014, 71.70390169961112, 67.88627651759556, 57.4794487953186, 59.17016438075474, 59.830458641052246, 64.53916944776262, 62.42753546578543, 64.59259414672852, 63.47989572797503, 63.272547585623606, 62.00589793069022, 59.67337376730782, 60.843763078962056, 63.4068979535784, 62.49947016579764, 62.42545795440674, 60.54853412083217, 63.94095039367676, 62.78814002445766, 60.11147853306362, 59.32094029017857, 60.497374534606934, 61.9597202028547, 58.75852530343192, 48.969732897622244, 46.8045699937003, 45.41005264009748, 46.1862393787929, 44.094261850629536, 39.555292061397004, 40.56149196624756, 41.79408502578735, 40.55649273736136, 42.17132357188633, 42.910490308489116, 48.946150711604524, 54.25200360161917, 56.47158132280622, 48.09808833258492, 47.75704642704555, 51.23709685461861, 46.578037875039236, 45.4143396786281, 43.655802726745605, 46.52880988802229, 46.604364599500386, 48.12444632393973, 50.346841539655415, 51.38549995422363, 53.52557291303362, 54.97610664367676, 55.72200618471418, 52.371039390563965, 49.53409685407366, 48.075812407902305, 44.92507880074637, 41.50629758834839, 36.33133486339024, 34.766635281699045, 41.63305704934256, 38.91357033593314, 42.114462988717214, 40.67541463034493, 37.03239073072161, 39.246114594595774, 36.91431999206543, 36.73849582672119, 35.711096967969624, 40.31910753250122, 38.857651233673096, 38.62313216073172, 43.96039438247681, 34.35343285969326, 35.005948611668174, 42.04879903793335, 37.277123655591694, 40.31679030827114, 43.02173791612898, 47.868585859026226, 51.73050928115845, 51.87587601797921, 54.933003493717735, 51.75132955823626, 48.039240564618794, 47.81556415557861, 43.72760541098458, 51.89495924540928, 54.40127522604806, 55.06260129383632, 54.35434709276472, 48.23870250156948, 45.87489059993199, 42.58155216489519, 45.02119670595442, 57.54813868658883, 58.26752042770386, 51.92487818854195, 50.22246878487723, 43.52842140197754, 40.69217715944563, 39.92324086597988, 42.10914414269583, 38.20638963154384, 38.7220710345677, 41.702306270599365, 45.34422540664673, 42.496443680354524, 49.99538081032889, 49.45542240142822, 52.30475010190691, 51.39426163264683, 58.092783655439106, 55.76897600718907, 63.61940165928432, 56.5901141166687, 49.47617667061942, 55.20199605396816, 60.86996473584856, 58.96288572038923, 60.56551551818848, 59.13004548209054, 58.44445283072335, 58.26535606384277, 58.76282623835972, 52.91589975357056, 52.56827095576695, 50.6283860206604, 59.10150228227888, 60.86684499468122, 71.24366692134312, 68.21009731292725, 73.01571464538574, 67.2638360432216, 80.84286730630058, 65.76810428074428, 88.62451621464321, 9.870496273040771, 0.4772696984665734, 0.36069151972021374, 13.930959258760724, 79.66746139526367, 60.62857736860003, 55.68431568145752, 29.085822854723247, 41.02876526968819, 66.45918600899833, 19.731054885046824, 0.9431808292865753, 0.2886837550571987, 0.0989738523161837, 0.15639156023306505, 0.0649618027465684, 0.06110965766544853, 0.12785144097038678, 0.1508131745670523, 0.20301338923828943, 0.22464583202132157, 0.11830332688987255, 0.3195232259375708, 0.15599887844707283, 0.34949181069220814, 0.5671941531555993, 4.873885989189148, 74.2743947165353, 57.52397632598877, 40.39930016653878, 59.712651933942524, 58.38219697134835, 81.86732360294887, 16.808642557689122, 0.4660407581499645, 0.26051328810197966, 0.644885272852012, 2.5851780346461704, 67.42099734715053, 78.8654099873134, 74.51570565359933, 70.3605717250279, 61.14473124912807, 61.50799696786063, 61.82869802202497, 66.76316274915422, 63.21291119711739, 67.82233224596295, 67.40563488006592, 67.3569141115461, 63.54525743212019, 61.42504242488316, 63.351034436907085, 69.28970146179199, 64.8021240234375, 64.92211941310337, 60.50380856650216, 62.17660127367292, 65.60798304421562, 62.77134622846331, 59.832223483494346, 63.95354747772217, 62.99062442779541, 63.31274291447231, 53.169964109148296, 49.953952176230295, 47.740902287619456, 48.5166026524135, 47.07361813953945, 42.18066195079258, 42.67565509251186, 43.33913162776402, 42.252308300563264, 44.22432170595442, 44.53309965133667, 52.770737988608225, 56.750301361083984, 59.07536315917969, 52.32113742828369, 49.81446361541748, 51.49744585582188, 48.962256635938374, 48.06577920913696, 46.28802701405117, 47.88470220565796, 49.26460402352469, 49.80712979180472, 52.073830195835654, 53.11186327253069, 57.412520272391184, 57.535274096897666, 55.72265931538173, 53.13495908464704, 52.14282580784389, 50.387495449611116, 46.250885418483186, 42.87940059389387, 39.03500052860805, 35.11101579666138, 41.86688825062343, 38.88565942219326, 41.42276634488787, 43.886225836617605, 40.02041489737374, 40.844804763793945, 41.15001828329903, 40.40137767791748, 40.12133053370884, 41.54309524808611, 39.7550492967878, 40.361189297267366, 42.824832916259766, 34.23549066271101, 35.17266368865967, 41.23518582752773, 39.02779524666922, 42.1711950302124, 43.76639025551932, 51.47065707615444, 54.80216544015067, 53.94881895610264, 56.20011172975813, 55.89456122262137, 49.81072895867484, 47.99218736376081, 43.73929922921317, 54.44450691768101, 56.94900941848755, 58.3304328918457, 58.40919072287423, 50.28819179534912, 48.47576461519514, 46.40237351826259, 46.93255928584507, 60.129988534109934, 61.25073296683175, 56.18339783804757, 50.7251501083374, 45.25632722037179, 43.97188670294625, 42.67610672542027, 45.27242272240775, 41.12095396859305, 40.796612058367046, 42.48965529033116, 47.91856772559029, 45.494990893772666, 53.768520150865825, 52.692087854657856, 55.64224433898926, 54.16139561789376, 60.725998061043875, 59.06821346282959, 64.62625816890171, 56.54757377079555, 54.97970928464617, 58.03661094393049, 60.73678166525704, 61.35032149723598, 63.171590260096956, 61.81369686126709, 59.64945806775774, 60.2323910849435, 60.57082394191197, 55.786485467638286, 55.3261673109872, 53.96635968344552, 62.73452077593122, 64.82468482426235, 73.93758773803711, 70.27177374703544, 75.9126479285104, 69.66551562717983, 85.21662630353654, 69.3255055291312, 89.6514252253941, 12.354604073933192, 0.4321401443864618, 1.1646270837102617, 18.089320625577653, 85.14906202043805, 68.94462612697056, 65.22155897957938, 47.60564170564924, 47.19706678390503, 78.2322484425136, 25.78158790724618, 1.1837855471032006, 0.4825526092733656, 0.18794109086905206, 0.24410001454608782, 0.2074390524732215, 0.17035484739712306, 0.11016951049012796], [0.06473163688289267, 0.11347402352839708, 0.13837843681020395, 0.11218880356422492, 0.08252199047378131, 0.04203551581927708, 0.18195747051920208, 0.19071085724447454, 4.4080626879419595, 55.71651363372803, 45.5264766556876, 34.22993557793753, 35.41337708064488, 54.18148980821882, 66.58650479997907, 12.166729995182582, 0.6327011180775506, 0.5546981979693685, 0.3416635793234621, 1.7420577790055956, 57.55819272994995, 76.71818733215332, 66.09935964856828, 63.353862353733604, 58.486614499773296, 59.02905341557094, 55.386658327920095, 59.78987421308245, 58.338854108537944, 59.936446462358745, 58.932654108319966, 58.22389963694981, 57.02233723231724, 58.08080843516758, 61.6716548374721, 62.227469035557334, 61.72678879329136, 58.853055545261924, 55.62676722662789, 52.45579351697649, 60.77264826638358, 60.035534722464426, 56.35097796576363, 59.696907315935405, 61.33466025761196, 58.26828472954886, 47.64097676958357, 43.72845656531197, 45.04129784447806, 44.39129039219448, 42.387687001909526, 39.262991768973215, 39.300282750810894, 39.62536811828613, 38.00622592653547, 38.634360449654714, 40.288042136601035, 44.848155294145855, 49.11439091818673, 54.36829212733677, 51.3435571534293, 49.474957261766704, 44.9749390738351, 42.576452187129426, 42.41926309040615, 41.06201239994594, 43.31578915459769, 45.1676994732448, 48.48211874280657, 47.87515538079398, 50.58938578196934, 48.87622404098511, 51.492123535701204, 51.74805695669991, 54.011943340301514, 55.343086174556184, 52.1879300389971, 53.83602884837559, 53.226758684430806, 45.5371629851205, 42.10639265605381, 39.34612001691546, 39.194329670497346, 37.51561362402779, 38.28847564969744, 37.69554417473929, 38.864939893995015, 34.453528608594624, 31.669930866786412, 34.72464731761387, 34.84787014552525, 39.5874274798802, 42.205025809151785, 39.282276494162424, 35.66180297306606, 38.03536319732666, 40.042305197034565, 40.020008427756174, 37.136721406664165, 40.75127853666033, 37.36340291159493, 42.9555459022522, 45.1651668548584, 46.05220167977469, 46.33588968004499, 46.56803246906826, 47.02536984852382, 45.15091609954834, 43.604462487357004, 46.95848996298653, 48.17873954772949, 43.111380100250244, 43.43103545052664, 42.277460779462544, 39.69496127537319, 43.47360358919416, 46.7074202810015, 54.27685035978045, 53.17791632243565, 48.85853740147182, 41.34513412203108, 38.09602097102574, 38.661844049181255, 38.106144496372764, 36.77988624572754, 35.75638880048479, 39.17512137549264, 41.15750496728079, 41.19795043127877, 46.090006828308105, 47.74467168535505, 48.830275603703086, 50.216858114515034, 52.876350607190815, 53.954856940678184, 54.64932244164603, 43.253206729888916, 53.44138853890555, 55.39417280469622, 57.24614218303135, 55.547401428222656, 60.38514723096575, 59.35891219547817, 61.803837367466514, 58.1093863759722, 61.83687605176653, 54.65720864704677, 53.680830410548616, 46.94330814906529, 53.08937542779105, 56.309743881225586, 68.86147008623395, 63.86465917314802, 74.67523629324776, 64.5355772290911, 74.46955571855817, 58.68932124546596, 78.42568629128593, 14.573056186948504, 0.5525851856384958, 0.49094777022089275, 10.085344995771136, 71.47844655173165, 53.61906787327358, 45.46849741254534, 34.30584464754377, 37.727054255349294, 58.2455050604684, 16.446802956717356, 0.5924213251897267, 0.024680679930107932, 0.05377320472949317, 0.15283125984881604, 0.08224263082125358, 0.08002255244978837, 0.11182448454201221, 0.0744765464748655, 0.027602570464036295, 0.09267545278583254, 0.08553521521389484, 0.06284198470945869, 0.13649578711816243, 0.27377962480698315, 0.3108261711895466, 5.963811252798353, 64.11380767822266, 47.38264969417027, 36.86305618286133, 42.3194556917463, 58.26931306294033, 73.78921590532575, 13.559553725378853, 0.7962233349680901, 0.4051748641899654, 0.38070070317813326, 2.023149324314935, 61.99236283983503, 78.79402419498989, 68.98327200753349, 67.56016281672886, 60.687505040849956, 60.811287198747905, 58.11249222074236, 61.419747897556846, 58.276084082467214, 59.430992807660786, 60.80141380855015, 59.84341008322579, 58.87451158251081, 60.13606125967843, 61.5998660496303, 63.989747592381065, 62.95371559688023, 61.3423866544451, 58.645186288016184, 58.827861377171104, 61.34171267918178, 63.07547582898821, 57.98111915588379, 62.754913738795686, 61.83109515053885, 60.61160291944231, 48.49944755009243, 46.34758349827358, 46.96702929905483, 47.71802534375872, 44.062539849962505, 42.25009182521275, 40.971845626831055, 41.85241862705776, 41.72881712232317, 41.79039553233555, 42.978294304439, 46.01548045022147, 51.28656802858625, 59.217321804591585, 55.875915731702534, 52.17142806734358, 46.84815951756069, 45.45230116162981, 44.10849870954241, 43.17180510929653, 45.56450414657593, 49.40511744362967, 49.480891023363384, 49.888566153390066, 51.333381516592844, 49.82710238865444, 52.24062170301165, 52.89610086168562, 55.295511858803884, 57.1440418788365, 54.67958184650966, 55.51078789574759, 53.12245580128261, 46.5326418195452, 42.6271253994533, 38.63345718383789, 40.2736246245248, 38.435819149017334, 39.13770880017962, 39.52884374346052, 38.73619324820382, 36.48983369554792, 35.86280741010393, 38.23021847861153, 38.24117578778948, 38.84084701538086, 43.332603795187815, 38.38182817186628, 37.01628133228847, 37.25372907093593, 40.99649783543178, 39.71380131585257, 37.45017201559884, 42.503777503967285, 38.70119169780186, 46.11938033785139, 45.72296476364136, 46.49552454267229, 46.83890799113682, 47.20101683480399, 47.55208151681082, 46.5562344278608, 44.11302546092442, 48.0034955569676, 47.04862894330706, 46.092073917388916, 44.295467785426546, 42.62531886781965, 41.01426437922886, 46.350991589682444, 48.34801851000105, 56.06850937434605, 53.649299485342844, 50.2108861378261, 43.94473661695208, 40.81493445805141, 39.86961119515555, 40.08034658432007, 39.16812106541225, 38.671345710754395, 42.2275310243879, 43.11376333236694, 43.35515417371477, 48.83388866697039, 49.62178659439087, 52.583574363163535, 52.90471315383911, 55.156749384743826, 57.648328236171174, 59.06214768545968, 48.04400702885219, 55.51376519884382, 56.015209742954795, 60.73894950321743, 59.42057745797293, 62.41846111842564, 62.05521624428885, 64.05884047916958, 62.00115925925118, 63.47870758601597, 58.018913882119314, 56.58146013532366, 50.05685152326311, 56.22581659044538, 57.79883663994925, 71.01307010650635, 66.18857451847622, 76.3780938557216, 66.80478940691266, 75.93999603816441, 61.55529335566929, 81.6200441632952, 24.597118071147374, 0.5155390735183443, 0.520988578242915, 12.724871839795794, 79.92870671408517, 59.58128234318325, 53.66238989148821, 37.22450147356306, 44.54788194383894, 62.978416442871094, 23.890263932091848, 0.6118992428694452, 0.12141989251332623, 0.0648241008498839, 0.18970395198890141, 0.04199511245159166, 0.09625340186591659, 0.07740284409373999, 0.2226531918027571, 0.13607360262955936, 0.2631872317620686, 0.16933533496090344, 0.19692736438342504, 0.23668924506221498, 0.2957129164465836, 0.5893680261714118, 8.169229848044258, 73.80978257315499, 58.949691091264995, 44.114522797720774, 48.330359663282124, 65.80435303279332, 78.21799073900495, 15.58231156212943, 0.7805050984025002, 0.8650639695780618, 0.5321684469069753, 3.3845194280147552, 62.767073086329866, 82.22102165222168, 71.06362519945417, 69.6981999533517, 64.180559022086, 63.37241404397147, 60.01170934949602, 66.02317265101841, 60.54279490879604, 63.484141077314106, 64.00893156869071, 62.793337277003694, 61.92012241908482, 64.1989995411464, 65.08178206852504, 67.32363224029541, 66.18733773912702, 62.22352245875767, 57.73176915305001, 56.96227352959769, 63.10005855560303, 63.36899553026472, 58.61015347072056, 64.67501367841447, 66.07554122379848, 63.43202263968331, 50.44699287414551, 48.04183224269322, 49.08788006646292, 49.89121341705322, 46.983215127672466, 44.47446380342756, 43.623121874673025, 46.15623705727713, 42.74532467978341, 43.71454627173287, 45.93752861022949, 49.60083430153983, 54.83716699055263, 61.47422177450997, 54.62225920813424, 52.08464854104178, 48.339062282017295, 45.62459911618914, 45.52050467899868, 45.698712076459614, 49.03164482116699, 51.683317116328645, 53.20205783843994, 52.711688722882954, 55.45934690747942, 53.57698610850743, 57.56631170000349, 57.46372502190726, 59.68912533351353, 60.86268302372524, 57.37272446496146, 57.54977151325771, 56.08188465663365, 47.70648091179984, 43.84590196609497, 39.649485315595356, 40.89831631524222, 39.837364605494905, 41.09192786897932, 40.327771936144146, 40.63744272504534, 40.5174160684858, 37.043921266283306, 42.05801234926496, 39.265041487557546, 39.90215308325631, 43.38131761550903, 38.77868843078613, 38.7424327305385, 36.53063351767403, 42.00849601200649, 39.0933723449707, 39.02621453148978, 41.517991406576975, 37.84542376654488, 47.485952036721365, 48.883880955832346, 50.286718777247835, 50.69047164916992, 48.95787579672677, 50.7877151625497, 48.19474472318377, 46.20884881700788, 51.011905738285606, 49.81745481491089, 46.84243767602103, 47.466813223702566, 45.66054562159947, 43.63940150397164, 49.09639508383614, 50.73548207964216, 58.34447520119803, 57.770303862435476, 52.7988087109157, 46.49021264484951, 43.22246789932251, 42.779117243630544, 42.55217170715332, 42.17617688860212, 40.6207913671221, 44.91150549479893, 45.936621870313374, 47.59925978524344, 53.459530285426546, 51.67747368131365, 54.541958877018516, 56.24711629322597, 57.912464005606516, 59.84205518450056, 60.55626746586391, 50.42587729862758, 57.73643486840384, 60.05228682926723, 63.994639124189106, 59.765458243233816, 64.75045721871513, 64.05452564784459, 66.3835757119315, 62.603519439697266, 66.47868960244315, 59.41782597133091, 60.17585359300886, 51.87689740317208, 59.33079283578055, 59.96733815329415, 73.46730586460659, 67.65032264164516, 80.85969584328788, 70.25894737243652, 77.42634773254395, 63.06519249507359, 82.56549944196428, 28.680079323904856, 0.7339009791612625, 1.2922524639538355, 16.24767279624939, 88.21220316205705, 67.32780115944999, 63.445550782339915, 50.11017199925014, 52.180481570107595, 71.88210909707206, 31.20895263126918, 0.9300068276269096, 0.24769307460103715, 0.1655462189976658, 0.26056233261312756, 0.160357122442552, 0.19311728168811115, 0.20988540191735539], [0.14478703721293382, 0.013170019507275095, 0.09395218427692141, 0.0628279729613236, 0.25102595718843596, 0.07186275494417974, 0.19541900817837032, 0.3373514621385506, 3.5356308051518033, 55.94333062853132, 42.114994525909424, 30.183388096945627, 40.24307686941964, 51.872262954711914, 71.86134093148368, 15.243843964168004, 0.38928156558956417, 0.3401299001915114, 0.36296637622373445, 0.2766715681978634, 52.776164531707764, 79.3252626146589, 69.40411049979073, 70.27639429909843, 62.786222321646555, 62.577887535095215, 58.63274901253836, 57.919228076934814, 53.20602873393467, 57.394632135118755, 52.653111934661865, 55.566849436078755, 56.38488170078823, 58.89680140359061, 57.605555125645225, 62.87727151598249, 62.52299676622663, 55.05187674931118, 54.34918110711234, 47.39076171602522, 55.89747599193028, 57.55136612483433, 56.08482027053833, 59.216036387852256, 58.3368877683367, 59.03301388876778, 47.93058810915266, 43.59119142804827, 45.661160537174766, 43.00501012802124, 43.24578257969448, 40.4360283442906, 36.55146769114903, 37.56394876752581, 37.977536814553396, 40.78327151707241, 38.899899755205425, 38.315792492457796, 44.460918290274485, 48.04666818891253, 48.95242493493216, 46.458198819841655, 43.901001180921284, 44.91087668282645, 43.4432885987418, 42.874182496752056, 47.32543127877371, 45.49263545445034, 49.2436899457659, 50.96240677152361, 49.7485008920942, 50.73098659515381, 50.02748843601772, 50.63286760875157, 51.210499150412424, 51.12648500714983, 50.59482969556536, 51.38880034855434, 53.29377058574131, 46.78247472218105, 38.83287395749773, 40.241666385105674, 38.70359230041504, 42.06286219188145, 42.050452709198, 39.52034957068307, 38.92055674961635, 36.73634188515799, 32.995900767190115, 33.10021754673549, 33.63166788646153, 39.330486570085796, 45.64110803604126, 39.3436256136213, 42.37185205732073, 36.46883623940604, 37.23288794926235, 37.645513670785085, 38.091438634055, 43.55437639781407, 46.28125946862357, 48.89584922790527, 48.081985882350374, 48.67651196888515, 48.58634866986956, 47.78243167059762, 46.54307801382882, 46.467099462236675, 43.50595440183367, 41.23476546151297, 39.88871874128069, 41.08169664655413, 40.8231645992824, 38.28945187159947, 39.821150984082905, 42.6810746874128, 43.48496389389038, 47.60885872159685, 49.528083188193186, 48.327160017830984, 39.76826824460711, 38.58955499104091, 38.806609766823904, 36.43137502670288, 37.026196411677766, 37.083734444209504, 39.320119857788086, 42.627180985042024, 41.517039503370015, 45.80892440250942, 46.663122040884836, 49.41481712886265, 48.943555559430806, 51.43023245675223, 56.07098640714373, 50.95451361792428, 54.57882601874215, 54.856361389160156, 52.878629616328645, 56.61045496804373, 54.09286206109183, 57.03395462036133, 57.1987624168396, 60.87049279894148, 62.46051161629813, 63.1695613861084, 58.78829138619559, 57.694627557482036, 50.50637912750244, 51.43680892671858, 53.858360358646934, 64.19177341461182, 62.07098865509033, 70.73261301858085, 63.50069168635777, 74.11704581124442, 67.07337897164481, 77.12668582371303, 25.441638605935232, 0.39606406592897003, 0.2206037582031318, 10.695237892014639, 70.57522937229702, 53.155025482177734, 48.68050718307495, 23.686539275305613, 31.915007727486746, 52.40094791139875, 18.955199922834122, 0.4193646056311471, 0.1463003195822239, 0.1451838444918394, 0.05561589210161141, 0.02374156710824796, 0.07910220790654421, 0.03625820064917207, 0.07553018922252314, 0.04620581579261592, 0.1373993107782943, 0.04813494513343487, 0.24693284396614346, 0.10586796488080706, 0.29776646196842194, 0.2721521449940545, 4.86191554580416, 65.09150954655239, 48.83517408370972, 33.49185970851353, 47.13711772646223, 54.92379713058472, 77.83605521065849, 17.37818465914045, 0.4366595947316715, 0.26565131811159, 0.33005216238754137, 1.0087622702121735, 56.95503698076521, 81.14464841570172, 70.08968230656215, 73.93530178070068, 65.21843229021344, 64.55272538321358, 59.9032757622855, 60.654070309230256, 53.851450375148225, 60.42657239096505, 56.14990404673985, 58.30465507507324, 59.559506688799175, 62.35380813053676, 59.40417276109968, 64.7322529384068, 64.04087243761334, 55.238352503095356, 56.34812920434134, 52.50746726989746, 54.35183184487479, 58.810817446027485, 56.973143986293245, 60.02827385493687, 59.68540109906878, 62.505674907139365, 50.902110304151265, 45.58461570739746, 46.70331736973354, 45.04014096941267, 44.41971547263009, 42.229542527879985, 38.7780978339059, 39.08191476549421, 40.83163097926548, 43.520451818193706, 40.495494501931326, 41.7711455481393, 44.25081518718174, 50.2013566834586, 50.28043760572161, 48.85173511505127, 46.58235618046352, 46.66073186056954, 45.70797402518136, 44.641529764447895, 50.18481649671282, 48.6750111579895, 50.26595755985805, 52.565849508558, 51.84132957458496, 53.291095529283794, 52.32771042415074, 53.4129912512643, 51.65075090953282, 54.159728050231934, 52.879032611846924, 53.98039157049996, 55.19674321583339, 47.55721276147025, 40.246582235608784, 39.88352148873465, 40.81390265056065, 43.08234705243792, 43.254860401153564, 39.741271018981934, 39.59692914145333, 39.242400782448904, 33.90541301454817, 35.28220203944615, 35.28629800251552, 41.368490491594585, 45.35610335213797, 39.48629297528948, 42.57987764903477, 36.2598865372794, 36.720739705221995, 37.524844305855886, 39.553235394614084, 46.38577427182879, 50.0563964162554, 49.89697347368513, 51.39198957170759, 48.94881534576416, 49.98254748753139, 49.10063001087734, 47.31787163870675, 48.27297796521868, 45.19410262789045, 42.51677410943167, 41.870567321777344, 42.379429067884175, 42.562920570373535, 39.349118164607454, 41.29678160803658, 43.35384096418108, 44.58884852273123, 48.581578731536865, 51.26736320768084, 48.73510265350342, 42.26606573377337, 39.917466912950786, 40.61944341659546, 38.791612080165315, 39.29990407398769, 40.397702080862864, 42.03130694798061, 42.4164525440761, 44.05868707384382, 48.968079226357595, 51.1671701839992, 52.39480570384434, 51.85196379252842, 53.99045256205967, 59.40235233306885, 55.11002969741821, 57.650850432259695, 56.73786408560616, 56.176331520080566, 59.701451437813894, 57.236042976379395, 58.61428764888218, 59.33412102290562, 64.57536956242153, 65.02274322509766, 65.52746037074498, 62.0059882572719, 60.60728808811733, 53.643879890441895, 53.7503992489406, 55.264710494450156, 65.07198510851178, 65.09811033521379, 73.23123386928013, 67.14811379568917, 76.27563571929932, 71.07415866851807, 78.27516051701137, 35.678106921059744, 0.5441690172467912, 0.434850918927363, 13.840595330510821, 78.46675709315709, 59.72171238490513, 56.346899373190745, 26.663932698113577, 38.7837884085519, 58.72254058292934, 28.660395077296666, 0.5080888675791877, 0.18405619290258202, 0.08915285859256983, 0.16245831469339983, 0.06177567371300288, 0.08608903549611568, 0.026663031861452118, 0.27803865341203554, 0.1543081048876047, 0.25120031354682787, 0.13264601012425764, 0.3211286940744945, 0.34019419816987856, 0.3969099819660187, 0.5743695252708026, 6.202825375965663, 75.4246689932687, 56.22758838108608, 41.17152643203735, 56.36892168862479, 63.28192070552281, 85.38854558127267, 17.6442711353302, 0.8173540553876332, 0.9002356422798974, 0.5473698026367596, 2.5963956841400693, 56.90839719772339, 83.90639754704067, 72.99993528638566, 78.7046981539045, 66.8145238331386, 66.35500471932548, 62.323583466666086, 65.15309143066406, 55.2377028465271, 63.40019989013672, 55.80671862193516, 60.5726443699428, 60.525750977652415, 63.826416288103374, 61.397958346775596, 69.57612010410854, 63.8013402393886, 56.70127139772688, 54.478685106549946, 49.43016569955008, 57.690340518951416, 60.99492113930838, 59.55970818655831, 63.59802205221993, 62.737161091395784, 65.70163781302315, 52.44558661324637, 47.539675508226665, 48.43400594166347, 47.76513065610613, 45.70009824207851, 45.64202519825527, 40.54942989349365, 42.42525591169085, 43.588478156498496, 46.227261543273926, 43.03550577163696, 44.78419712611607, 48.31332615443638, 52.949581146240234, 53.674570083618164, 51.67861665998186, 49.51068489892142, 49.49090337753296, 49.42783457892281, 45.48304346629551, 53.49261065891811, 51.781314509255544, 52.47818061283657, 57.30158185958862, 56.54429769515991, 56.03919492449079, 55.64052465983799, 55.16436113630022, 55.58496338980538, 56.97547510692051, 54.53934982844761, 55.86529541015625, 55.68299204962594, 49.38635383333479, 40.07815095356533, 40.271689551217214, 41.13912698200771, 43.11916903087071, 44.49184472220284, 41.88515159061977, 40.841820512499126, 41.86331687654768, 36.33373546600342, 36.99906369618007, 34.67942149298531, 41.98033496311733, 47.64636857169015, 41.181920937129426, 42.696485791887554, 37.067579882485525, 37.29908691133772, 38.070712157658164, 39.97949695587158, 47.1472864151001, 50.74368095397949, 51.72574976512364, 53.1625851222447, 51.80120720182146, 53.25663941247122, 52.47727734701974, 51.36908483505249, 50.445405210767476, 47.94364724840437, 44.92696871076311, 43.127750056130544, 43.916950770786826, 44.35062605994088, 42.67337260927473, 41.66183648790632, 46.00509984152657, 46.985136304582866, 52.44242170878819, 54.19486856460571, 52.01919303621565, 45.32374906539917, 43.44238533292498, 42.94702046258109, 42.557945660182405, 41.288252694266184, 42.42971665518624, 43.17034598759243, 45.05527414594378, 45.02124534334455, 52.452041489737375, 51.86493955339704, 55.84210927145821, 53.71328892026629, 56.352360657283235, 61.0464767728533, 56.579629284994944, 59.146200043814524, 58.75681604657854, 57.38930286679949, 61.56178297315325, 60.66185923985073, 61.92090061732701, 60.817992210388184, 65.61110278538295, 68.01431097303117, 67.72063146318708, 63.44138881138393, 62.59662682669503, 54.68544265202114, 55.59107085636684, 58.913831438337056, 68.81406252724784, 66.95647553035191, 76.80918094090053, 68.7974910736084, 80.14133548736572, 73.78020409175328, 82.37971155984062, 41.04320362636021, 0.6717348492571286, 0.9957822752850396, 17.075580188206263, 86.1765616280692, 67.8676483971732, 66.98491450718471, 35.44857318060738, 44.68368101119995, 70.06633635929653, 37.40716961451939, 0.6948852698717798, 0.2062798568180629, 0.22660485761506216, 0.3967918354485716, 0.15890209908996308, 0.2569160482713154, 0.1634157547461135], [0.08800783074860062, 0.16177710624677794, 0.08634715021720954, 0.08880934345402888, 0.19969197389270577, 0.06498116135065045, 0.16214859059878758, 0.16786938719451427, 3.333720930985042, 54.69314125605992, 45.49083587101528, 33.40807138170515, 35.84636102403913, 49.849215030670166, 70.55730301993233, 16.84574941226414, 0.5073851996234485, 0.4955913381917136, 0.10175395277994019, 0.32201575647507397, 47.763007981436594, 77.37602193014962, 64.07270213535854, 72.1848143168858, 65.54175976344517, 65.54033538273403, 57.963251863207134, 53.68551697049822, 51.737863949366975, 53.48456117085048, 53.145680155072895, 57.004657541002544, 53.632328510284424, 59.25078432900565, 58.21724326269967, 61.775162151881624, 58.24186767850603, 58.6740699495588, 56.09793846947806, 44.767747265951975, 57.25635256086077, 58.08137123925345, 57.76658310209002, 55.48237671170916, 59.18927887507847, 56.11361360549927, 49.37991285324097, 44.291927678244456, 42.256612709590364, 43.89874301637922, 43.389054434640066, 40.498100076402935, 38.38261331830706, 37.68207161767142, 36.93849624906267, 39.80707393373762, 36.193381854466026, 40.00489609582083, 39.9999281338283, 42.69858067376273, 43.71385145187378, 44.64856481552124, 43.67990950175694, 42.75685868944441, 45.484374046325684, 46.205263546534944, 46.407271998269216, 45.53387648718697, 46.05366080147879, 47.57109873635428, 48.034265654427664, 50.06670754296439, 47.42047916139875, 51.31326648167202, 50.17501606260027, 52.435754912240164, 50.95938777923584, 54.41397305897304, 51.09343590055193, 51.720962456294465, 45.429003851754324, 38.937673636845176, 44.347617489951, 42.19628497532436, 42.20468534742083, 42.21701839991978, 38.516519001552034, 39.94618729182652, 32.3676689692906, 33.967307567596436, 35.56074489865984, 43.8929899079459, 43.97445753642491, 38.67087670734951, 41.487606934138704, 38.59992865153721, 37.58158329554966, 38.67703628540039, 40.65495565959385, 43.92324931280953, 47.83557496752058, 48.94392033985683, 49.10283953802926, 49.453615869794575, 48.008070945739746, 47.45119367327009, 45.39294270106724, 46.04647983823504, 46.89232574190412, 44.04661805289132, 43.06602225984846, 42.94461638586861, 41.85717119489397, 39.330785342625205, 39.41474737439837, 42.81856216703142, 45.428024155753, 47.369604451315745, 46.95126036235264, 43.71506043842861, 38.59820202418736, 37.02381317956107, 36.14970200402396, 34.865000929151265, 35.841952392033164, 38.22043194089617, 40.359507833208355, 42.11223956516811, 42.551772185734336, 52.016969612666536, 51.372878551483154, 51.681482791900635, 51.70611763000488, 54.66465711593628, 54.16670751571655, 54.058079378945486, 53.854775088174, 56.96646329334804, 58.64926488058907, 57.449109486171174, 58.057785579136436, 55.7889347076416, 54.62242943899972, 57.749275139399934, 60.108421325683594, 62.898435728890554, 61.317206382751465, 59.96513557434082, 54.4634233883449, 54.406111172267366, 48.65137338638306, 54.30321529933384, 56.6938020842416, 64.41957705361503, 64.76649366106305, 72.52620710645402, 63.57538482121059, 78.11893027169364, 36.79518270492554, 0.98877914249897, 0.27743022463151384, 10.714405366352626, 68.88808863503593, 53.52516296931675, 48.858419282095774, 32.105332783290315, 27.385577814919607, 51.26073462622506, 22.6970636844635, 0.24831450411251613, 0.07651627702372414, 0.06954587676695415, 0.05948759934731892, 0.028749274289501563, 0.06570785199957234, 0.07278527758483376, 0.10395668101097856, 0.13104485747005257, 0.12228925872061934, 0.01983056589961052, 0.23847107802118572, 0.0790951307862997, 0.2143349088728428, 0.2601005216794354, 4.363938587052481, 64.86964661734444, 49.93436173030308, 29.034171683447703, 39.65351527077811, 56.47963775907244, 76.43338067190987, 19.287085839680262, 0.4456841919038977, 0.4404592551290989, 0.05472747602366975, 1.1239745851073946, 50.67061717169625, 80.72853469848633, 66.7684086390904, 74.95029463086809, 68.34426702771867, 68.65055056980678, 60.63255868639265, 56.51214490618025, 54.3467492376055, 56.14870548248291, 56.36017043249947, 59.70614842006138, 56.543665409088135, 60.51805237361363, 60.5838657106672, 64.89137363433838, 59.626306670052664, 58.69143349783761, 60.8288939339774, 49.41382006236485, 58.424136298043386, 60.08313683101109, 59.86534554617745, 58.1661878994533, 59.08301312582833, 58.67530672890799, 51.32504367828369, 47.099003383091514, 44.311941964285715, 47.31819125584194, 44.06857436043875, 41.967098644801546, 39.80737965447562, 38.01682192938668, 39.733700956617085, 41.96945061002459, 39.84976019178118, 42.31541878836495, 41.63044452667236, 45.20976039341518, 44.910737718854634, 46.000910077776226, 46.220434938158306, 44.03043917247227, 47.440958976745605, 47.77849204199654, 50.308147021702354, 47.5605583190918, 49.70817354747227, 52.5199670791626, 52.03087990624564, 51.32687105451311, 50.878371783665244, 53.74359696252005, 53.34152208055769, 54.11784083502633, 53.02244343076433, 57.6508469581604, 54.61012765339443, 52.71915456226894, 46.355337687901084, 42.16679334640503, 43.616142409188406, 43.2589876311166, 42.07715811048235, 42.435938767024446, 38.78949982779366, 41.19372592653547, 35.03629486901419, 35.42582477842058, 35.970831053597585, 45.14916515350342, 43.905048506600515, 39.53141805103847, 41.521541936056956, 39.45475162778582, 38.847642353602815, 39.3903591973441, 41.395904609135215, 45.28165340423584, 49.28563969475882, 52.03081737245832, 52.02025611060006, 50.148856094905305, 48.63326638085501, 50.35283783503941, 48.26491805485317, 47.78607252665928, 47.905758721487864, 46.393886293683735, 44.36503314971924, 43.93642309733799, 43.174938746861045, 41.065229415893555, 40.24538714545113, 45.43521901539394, 46.89239869798933, 48.53303861618042, 48.50769853591919, 44.988522802080425, 40.73616967882429, 39.03766516276768, 39.112368719918386, 37.94522074290684, 36.95868076596941, 39.9870913369315, 41.96607378550938, 43.77927221570696, 44.932930265154155, 54.02717726571219, 53.990334442683626, 53.91233743940081, 55.5887953213283, 55.3448440687997, 57.5565425327846, 57.638562543051584, 56.85349600655692, 58.588530676705496, 59.69133486066546, 60.9922182900565, 60.225352559770855, 57.03415264402117, 56.26513992037092, 59.16871220724923, 61.95289012363979, 65.09811033521379, 63.74537249973842, 62.373909269060405, 58.84633663722447, 57.12801933288574, 51.40826572690691, 57.30520534515381, 58.927165031433105, 66.4318517957415, 65.4606603894915, 75.15448134286063, 67.75853388650077, 81.7881419318063, 42.658541679382324, 1.0201925997223174, 0.3590908556112221, 11.685349243027822, 78.05543763296944, 59.249693461826865, 58.783677782331196, 37.12774085998535, 35.01124661309378, 59.41570677076067, 33.012176922389436, 0.18355958669313363, 0.1290227688316788, 0.0504242951449539, 0.037776819696383815, 0.05002317577600479, 0.11145331910146133, 0.08755238447338343, 0.30341776300753864, 0.18917928157108171, 0.26869794034532135, 0.27576442116073197, 0.3226261394364493, 0.12142787208514554, 0.3564243758363383, 0.5576986798218319, 5.656222317899976, 73.03952612195695, 59.36015592302595, 42.50300972802298, 48.25248077937535, 63.77084459577288, 82.86745425633022, 21.633739164897374, 0.6114324107766151, 0.9764383818422044, 0.30907188675233294, 1.8867016860416956, 51.1046780858721, 82.86953871590751, 69.5102789742606, 77.59425789969308, 69.03510556902204, 69.57907308850969, 63.00887039729527, 59.7112067086356, 54.52969183240618, 59.05897235870361, 59.851511682782856, 61.97825799669538, 57.32958309991019, 62.58748994554792, 60.815935543605256, 67.60065691811698, 62.2107377733503, 59.26468072618757, 56.19180168424334, 50.14009094238281, 62.23512595040457, 62.97950036185128, 61.25613866533552, 58.56346157618931, 64.62701552254813, 62.489777428763254, 53.88906792231968, 49.81969213485718, 45.99244717189244, 49.3861905506679, 47.90703024183001, 44.342632157461985, 43.7891525541033, 40.47044972011021, 42.36164515359061, 45.7786545753479, 41.855399404253276, 46.67396123068673, 44.36563416889736, 50.77368327549526, 47.104023456573486, 48.10304934637887, 47.989856243133545, 46.56588200160435, 49.705974442618235, 50.08779532568795, 52.58449847357613, 50.12741395405361, 51.764489446367534, 55.91862978254046, 54.09476934160505, 56.70940426417759, 54.78580590656826, 58.243125302451, 55.863832814352854, 57.6310967036656, 56.65957873208182, 60.88499368940081, 55.375141688755576, 54.04485348292759, 47.28232118061611, 43.038569927215576, 44.52076312473842, 44.216480663844514, 44.737140451158794, 44.16201720918928, 40.339785371507915, 43.942203998565674, 36.626497813633506, 38.63668809618269, 36.728723185403005, 47.231199809483115, 45.49897568566458, 41.167267186301096, 43.96240241186959, 41.01435470581055, 39.334370613098145, 39.69190059389387, 43.108927386147634, 46.4546274457659, 51.72407177516392, 54.54951851708548, 53.79170976366316, 53.935547896793906, 51.66181591578892, 53.12963329042707, 50.28312655857631, 50.62281356539045, 52.81641544614519, 47.79279143469674, 46.55880873543875, 47.83210781642369, 45.70671987533569, 43.40559114728655, 42.35935224805559, 47.310847009931294, 48.64876086371285, 50.64577041353498, 52.099024363926475, 47.63377148764474, 43.53994151524135, 40.56223542349679, 40.93431840624128, 41.40083088193621, 41.845946380070274, 42.613187313079834, 45.74289219720023, 46.831598486219136, 48.729714325496126, 58.450066975184846, 57.70860038484846, 57.33550991330828, 58.51291343144008, 59.432792391095845, 57.68911068780081, 60.48423549107143, 58.46489443097796, 61.50106961386544, 62.18017264774868, 63.914887700762065, 61.511519704546245, 60.714061055864605, 58.652085849217, 62.015493392944336, 65.15035384041923, 67.8315177645002, 66.19669001443046, 64.71615396227155, 59.683650153023855, 60.4101676940918, 53.260672841753276, 60.46530859810965, 61.66966765267508, 71.139999798366, 70.33717019217355, 79.60845034463065, 70.68707452501569, 85.10344014848981, 46.468659332820344, 1.84451048714774, 0.8396500104240009, 15.139153718948364, 85.58939715794155, 66.87092930930001, 67.35902636391776, 46.086609159197124, 39.86942706789289, 67.75659533909389, 44.46857173102242, 0.2829785511962005, 0.21228814870119095, 0.13909111571099075, 0.14276578995798314, 0.16535878048411437, 0.15747573705656187, 0.2176984612430845], [0.1792596559971571, 0.027797130202608447, 0.10361425831381764, 0.053829126193055084, 0.0589253855869174, 0.06495954322495631, 0.11130788869091443, 0.12614797880606993, 2.754385777882167, 57.02385541370937, 44.278729575020925, 29.733645098549978, 34.24569756644112, 44.96404777254377, 74.32901450565883, 23.97429891995021, 0.08600007276982069, 0.2619095231805529, 0.14946027073476995, 1.8155715657132012, 47.225943497249055, 75.39958599635533, 68.42508847372872, 78.66812978472028, 64.67405482700893, 65.61705044337681, 56.2919773374285, 54.17127595629011, 50.44251128605434, 53.83350665228707, 52.36859709875924, 54.177178450993125, 54.9516316141401, 60.396778515407014, 56.606324263981406, 65.46490573883057, 57.50055047443935, 66.03893116542271, 51.29037911551339, 47.028062275477815, 60.64805316925049, 57.764453479221885, 58.8933550970895, 55.92441415786743, 55.57497535433088, 54.16963618142264, 49.628661836896626, 42.76480048043387, 43.43013913290841, 43.63391242708479, 43.29717493057251, 41.08455235617501, 37.24649599620274, 36.561806610652376, 37.4164628301348, 36.82850626536778, 37.87070478711809, 38.763854026794434, 38.10152047021048, 39.46425676345825, 40.12080594471523, 43.15572350365775, 42.072662625994, 43.83006007330758, 43.470087800707134, 44.45914997373308, 45.114750725882395, 47.62183100836617, 46.743616921561106, 48.296007769448416, 47.15539843695504, 49.999143259865896, 45.96663114002773, 48.300465038844514, 48.2279988016401, 51.052691664014546, 49.4343068259103, 51.85550389971052, 51.46996225629534, 51.71056795120239, 44.78803947993687, 44.90067672729492, 42.61975336074829, 42.87626348223005, 40.26461281095232, 42.823922702244346, 39.623096057346885, 40.55588476998465, 40.94299670628139, 35.48402983801705, 38.0862135887146, 41.73652614865984, 41.9857371875218, 39.726401873997276, 42.66600751876831, 40.13486909866333, 39.74520369938442, 38.87753350394112, 42.01401635578701, 45.662817682538716, 49.21992015838623, 50.57932479040963, 50.34676510947091, 46.286428928375244, 46.67362771715437, 46.10800266265869, 45.69094051633562, 45.47745711462838, 43.01375791004726, 42.15987294060843, 41.840023040771484, 41.139498710632324, 40.929451193128315, 39.077099663870676, 38.719666957855225, 40.94950022016253, 38.509178229740684, 41.51378774642944, 39.71469415937151, 37.86641427448818, 33.97017022541591, 37.324611118861604, 37.23148788724627, 37.256261689322336, 34.273483412606375, 40.064702715192524, 41.10160323551723, 41.9592923436846, 46.81955030986241, 56.16137204851423, 53.46923344475882, 56.166718687329976, 52.10643114362444, 55.38298967906407, 59.45738206590925, 53.364937509809224, 55.52149159567696, 57.194892270224436, 56.86632585525513, 58.11541393824986, 58.209377901894705, 59.539072036743164, 58.75089618137905, 60.43481295449393, 60.01651750292097, 61.800050599234446, 59.95925045013428, 61.78080408913748, 58.72588266645159, 59.12040833064488, 54.150073528289795, 54.81351184844971, 50.90694972446987, 55.945939677102224, 56.875636441367014, 69.76363113948277, 62.73157473972866, 79.06510121481759, 39.52061707632882, 0.40948657425386564, 0.353452419596059, 10.14919112409864, 72.21511541094098, 51.5378600529262, 49.70255592891148, 28.155563286372594, 31.60134867259434, 52.10521868297032, 25.42831369808742, 0.32403637947780745, 0.05908057333103248, 0.11621448397636414, 0.13857373275927135, 0.13817596196063928, 0.05056133546999522, 0.07173975690134934, 0.19332024508288928, 0.025652927313266054, 0.09829312562942505, 0.0098671298640381, 0.03460501114438687, 0.0153418413163828, 0.15518412073808058, 0.15987380194876874, 3.2288176800523485, 64.05868067060197, 51.31537873404366, 34.20020423616682, 42.38849646704537, 51.35928092684065, 79.95160102844238, 27.65083224432809, 0.18211749621800014, 0.3362516654389245, 0.3837242823626314, 2.5765418580600192, 49.96449259349278, 78.91112913404191, 70.30290862492153, 81.01678766523088, 68.49031816210065, 69.33571938105992, 57.3594707761492, 57.27988610948835, 51.62035948889596, 56.77812194824219, 52.96539872033255, 58.49154772077288, 56.22589649472918, 63.69814559391567, 59.228633471897666, 68.54050500052315, 57.51852546419416, 66.74024759020124, 56.68739237104143, 49.73795005253383, 62.919016293116975, 61.21844468797956, 62.300737789699006, 55.32271058218819, 58.3626377923148, 57.44495446341378, 52.51694808687483, 45.29243006025042, 45.42013100215367, 45.42075981412615, 45.107976232256206, 44.755261353084016, 40.848542894635884, 38.91661712101528, 40.06860760280064, 38.38969700677054, 39.89003195081438, 40.18662970406668, 38.33294759477888, 41.690807001931326, 43.602885246276855, 44.23183618273054, 43.59907068525042, 45.331718649183, 47.3412766456604, 46.90676409857613, 47.50294385637556, 50.06805549349104, 49.54366799763271, 52.226565497262136, 49.278090476989746, 52.503003052302766, 49.921733379364014, 50.968114716666086, 50.4756646156311, 52.71054574421474, 52.49246958323887, 54.20916100910732, 52.17831025804792, 53.4888482093811, 45.672962052481516, 45.100354058401926, 42.2937126159668, 43.822719301496235, 42.76773262023926, 42.891031878335134, 41.25896603720528, 41.567855153764995, 43.61152185712542, 38.93575940813337, 38.75045789991106, 44.84871809823172, 43.637056486947195, 41.867009844098774, 43.6621082169669, 40.26292092459542, 40.216809204646516, 40.61563580376761, 42.11448383331299, 47.74098914010184, 51.359756878444124, 51.57312216077532, 52.51854269845145, 49.05785690035139, 50.155449935368125, 49.34346260343279, 48.488410336630686, 46.81443643569946, 45.603553022657124, 43.18494415283203, 42.919040066855295, 42.20669685091291, 42.57984290804182, 41.97932052612305, 39.82619537625994, 41.845442635672434, 42.163437366485596, 44.00801386151995, 42.38477570669991, 40.75812946047102, 36.388681820460725, 39.89978722163609, 39.638976165226524, 39.66025154931204, 36.895483425685335, 43.31850242614746, 42.2900960786002, 44.3582968711853, 48.64633246830532, 57.47555433000837, 56.66815628324236, 59.42304406847273, 54.94375235693795, 56.35059928894043, 59.53136648450579, 55.81739105497088, 55.60633257457188, 60.27337156023298, 58.16561119897025, 60.62596484592983, 59.94738987513951, 60.921659333365305, 61.47619506290981, 64.38020856039864, 61.7158453805106, 64.4028318950108, 62.162350518362864, 64.1500494820731, 60.08828544616699, 61.796861376081196, 57.613583769117085, 59.21597385406494, 56.550690037863596, 58.96490069798061, 58.95841108049665, 72.1195707321167, 65.81321893419538, 82.84672777993339, 43.62793002809797, 0.7475590748446328, 0.24620838569743292, 10.987380112920489, 81.45969363621303, 58.0657308442252, 57.79593229293823, 31.893780980791362, 37.42106601170131, 59.86429636819022, 35.68285254069737, 0.355803733425481, 0.046888316848448346, 0.09372088525976453, 0.09271153727812426, 0.11317588881190334, 0.03960849783782448, 0.01859139301814139, 0.2820605475987707, 0.15627890984926904, 0.17834718924547943, 0.09308808350137301, 0.13511310916926178, 0.09993570284651858, 0.3635766234781061, 0.23500444261091097, 4.31348728282111, 75.07404899597168, 57.56167030334473, 38.78721039635794, 50.942378589085166, 59.69709491729736, 84.7403689793178, 31.05833305631365, 0.28747512134058134, 0.8033530552472387, 0.5403831718223435, 3.4087158782141547, 50.57908855165754, 82.54223687308175, 68.47200271061489, 81.70860590253557, 70.10892186846051, 70.13251100267682, 59.04272052219936, 59.103899410792756, 54.88582175118582, 58.27250576019287, 54.585708209446494, 58.69508130209786, 59.202883447919575, 65.86413533346993, 63.69788156236921, 69.50831263405937, 59.764367376055034, 62.39899921417236, 55.558702673230854, 53.71542201723371, 63.295810154506135, 63.86802904946463, 63.48886585235596, 58.96401827675955, 59.79634298597063, 58.82251821245466, 55.18364586148943, 47.912620067596436, 47.36539036887032, 48.86358526774815, 48.04517780031477, 46.3583983693804, 42.99164179393223, 41.400879519326345, 41.47688586371285, 40.60608550480434, 41.97371332986014, 42.8304887499128, 42.784279755183626, 43.87464318956648, 46.4563992364066, 48.82492896488735, 46.599476541791645, 48.79433952059065, 49.729369027274, 50.5636704989842, 50.67614793777466, 53.533483437129426, 51.55448709215437, 54.98211683545794, 51.45168849400112, 56.77159758976528, 53.69740186418806, 54.14729077475411, 52.66761629922049, 56.12571389334542, 56.07183756147112, 57.8862692969186, 54.64817598887852, 55.866910866328645, 47.726092202322825, 46.35844700677054, 44.79924692426409, 45.106739452907014, 43.767057282584055, 45.26405361720494, 44.188399519239155, 42.557646887642996, 46.91131516865322, 41.0503567968096, 38.72351973397391, 45.64510325023106, 45.362280300685335, 41.23609256744385, 46.4192784854344, 42.45816258021763, 40.50839383261544, 40.83148159299578, 44.42228283200945, 50.80410943712507, 54.38103859765189, 55.24328224999564, 55.92141253607613, 50.66499955313546, 53.6477187701634, 52.69398818697248, 52.83406039646694, 50.32243251800537, 48.381192684173584, 47.25422961371285, 45.83617523738316, 43.425695759909495, 46.497574261256624, 42.99494218826294, 41.95956332342965, 45.793082509722026, 45.14549650464739, 45.87169790267944, 44.42898089545113, 42.7082873071943, 38.251907280513215, 43.067794050489155, 42.90913540976388, 43.97826862335205, 39.05084242139544, 47.1552768434797, 44.277975695473806, 47.28807776314871, 51.760563714163645, 60.6568078994751, 58.372469493321006, 61.73953178950718, 56.314208098820274, 57.723525115421836, 60.676783970424104, 59.3485107421875, 57.0267458643232, 62.51473535810198, 61.370554651532856, 63.81593145642962, 63.43303707667759, 63.47366319383894, 64.01173169272286, 67.41721057891846, 64.6576987675258, 67.93130779266357, 62.6868074962071, 66.04041807992118, 62.7423791885376, 66.12938976287842, 60.0757508959089, 60.53939029148647, 58.04673099517822, 61.530641147068565, 62.81375108446394, 77.07838194710868, 68.90805775778634, 87.7391003199986, 48.87878097806658, 1.2050755875451225, 0.5868103834135192, 13.401959027562823, 89.74526759556362, 66.40304456438336, 69.29387732914516, 40.277185576302664, 46.40999569211687, 68.31338923318046, 47.57102925436837, 0.412651885833059, 0.15649695029216154, 0.22177925226943834, 0.15413408779672214, 0.2707033370222364, 0.0783822483250073, 0.12848737756056444], [0.12227534875273705, 0.05324185074173978, 0.17186309503657476, 0.06955819896289281, 0.14470374025404453, 0.05643888722573008, 0.11203886768115418, 0.09752872878951685, 1.682644818510328, 53.03514126368931, 41.5430257661002, 20.04762523514884, 32.791787011282786, 48.037705012730186, 65.76829188210624, 35.79651812144688, 0.42516665001000675, 0.6732553105269159, 0.11998823790677957, 3.3156603915350775, 56.34048271179199, 68.14136573246547, 69.64691529955182, 67.56990419115338, 65.82004206521171, 64.43060384477887, 56.34341485159737, 48.70852926799229, 52.191011565072195, 57.10894652775356, 57.98858846936907, 58.151186738695415, 59.083318846566335, 56.230482305799214, 65.64696938650948, 58.42277445111956, 65.04844461168561, 63.04864188602993, 40.610598359789165, 60.450057302202495, 58.67197854178292, 60.209017344883506, 53.77182054519653, 55.66720226832798, 55.558119024549214, 54.15607329777309, 47.97450072424752, 45.952599252973286, 40.820048332214355, 44.731019088200156, 41.473279748644146, 42.31769779750279, 37.37977286747524, 37.000821590423584, 37.23381553377424, 38.39824676513672, 35.977803570883616, 37.241545404706685, 38.11652510506766, 36.55357299532209, 40.698930808476035, 40.48200110026768, 38.40844324656895, 41.770134585244314, 44.51283870424543, 43.93743406023298, 45.37135812214443, 45.003975595746724, 44.284458364759175, 47.09920488085066, 46.33157484872, 48.73607540130615, 46.106289931706016, 47.33496420724051, 47.20532124383109, 47.970741748809814, 51.01691538946969, 51.40209225245884, 48.994249616350444, 51.01507411684309, 48.94590752465384, 46.035081318446565, 43.40175574166434, 43.311481271471294, 41.922206333705354, 39.77036312648228, 37.48366928100586, 46.942397935049875, 43.18057026181902, 39.60004540852138, 43.95120538984026, 43.07933848244803, 41.95673540660313, 39.37402745655605, 41.05150324957711, 41.490028381347656, 39.59655046463013, 40.31703002112252, 43.244191442217144, 47.27790560041155, 49.08381537028721, 48.00469412122454, 47.01506219591413, 46.73407357079642, 44.78577436719622, 45.865163121904644, 45.824905259268625, 46.53744649887085, 45.64119488852364, 41.807960578373496, 43.94478872844151, 42.05579239981515, 41.11923081534249, 42.03704616001674, 38.09381839207241, 37.0739027432033, 39.20072896139962, 40.02109234673636, 36.96349239349365, 34.23051922661917, 33.792407512664795, 35.704263414655415, 35.42777374812535, 34.835040296827046, 36.0991747038705, 39.80243253707886, 39.63153117043631, 40.63583769117083, 47.52331597464425, 55.83848925999233, 52.42383875165667, 54.09687117167881, 52.591283389500205, 61.46089512961251, 63.188585553850444, 53.19828496660505, 53.45866870880127, 58.99086611611502, 55.042190960475374, 57.61857257570539, 55.33893462589809, 59.134040696280344, 57.381149155753, 59.219107491629465, 57.69975185394287, 61.68812206813267, 59.721441405160085, 61.97640282767159, 60.33665575299944, 63.406765937805176, 59.7331143787929, 64.054365839277, 56.9444340297154, 63.14674350193569, 53.19557516915457, 66.98383753640312, 60.231494767325266, 81.49886757986886, 32.53486694608416, 0.6593890945826257, 0.18495162842529161, 10.449191757610865, 72.06265803745815, 52.12143925258091, 46.55760669708252, 33.54398162024361, 32.40641559873308, 48.2266161101205, 30.244070189339773, 0.2971940498266901, 0.0470905576034316, 0.10995855395283018, 0.03072039476994957, 0.04447388908426676, 0.031703866818653684, 0.09023686578231198, 0.06535819611911263, 0.056312316696026495, 0.039125974622688124, 0.03667536397863712, 0.1201957067740815, 0.06434055643954448, 0.13704282205019677, 0.12506461622459547, 3.0038886410849432, 62.46331174033028, 44.967976978846956, 29.211522715432302, 41.74820259639195, 52.219961234501426, 73.30799061911446, 39.65848323277065, 0.33231982641986435, 0.8595065506441253, 0.1367975587823561, 4.650122727666583, 61.28141621180943, 69.63292857578823, 73.02223900386265, 71.89003004346574, 67.85605185372489, 67.23514693123954, 57.81185409000942, 51.63073314939226, 54.355069705418174, 59.24373190743582, 60.56725256783621, 60.92190252031599, 60.59153652191162, 58.889526639665874, 66.27655955723354, 59.782891273498535, 62.13152136121477, 68.36734894343785, 44.267317158835276, 60.67096138000488, 60.88611234937395, 62.07568563733782, 58.074697494506836, 58.278366565704346, 56.42369086401803, 57.61362198420933, 49.53776202883039, 48.51948268072945, 42.60723270688738, 46.77679456983294, 44.647025789533345, 43.267766680036274, 39.44595520836966, 40.49992050443377, 37.426905972617014, 41.71115132740566, 39.504750864846365, 39.178404399326865, 38.730506147657124, 39.646473271506174, 42.03517014639718, 44.424523626055034, 39.46550049100603, 42.05279425212315, 44.8977689061846, 47.03023011343819, 48.45842885971069, 48.452752181461875, 49.15805687223162, 49.39054707118443, 48.33000530515398, 50.31078386306763, 49.24856410707746, 50.07719932283674, 50.14083787373134, 50.509005546569824, 52.77346863065447, 53.35850347791399, 52.54931974411011, 52.520359652382986, 50.63684892654419, 45.82841409955706, 45.436928272247314, 44.69819232395717, 43.851154804229736, 42.47460896628243, 39.63574525288173, 47.84865495136806, 47.99121809005737, 43.91836472920009, 45.9111567224775, 44.68541806084769, 43.66249731608799, 40.49672433308193, 43.09258869716099, 42.46638229915074, 41.37723132542202, 41.731401852199006, 43.74706384113857, 49.25710344314575, 50.1356440952846, 49.60958555766514, 49.464666979653494, 48.51935066495623, 47.79837431226458, 47.98994309561593, 47.490787982940674, 48.85170384815761, 46.20965828214373, 46.270823274339946, 44.16951084136963, 46.349251065935405, 41.4218213898795, 42.86489970343453, 40.66286965778896, 38.32834093911307, 42.56166989462716, 41.53907918930054, 38.32563461576189, 37.075493880680625, 36.155764307294575, 37.98227201189314, 38.7200664792742, 38.039295877729145, 37.45346893583025, 42.2577417918614, 41.974884101322715, 42.683642046792166, 49.893478529793875, 57.56542233058384, 55.365751198359895, 56.22463539668492, 56.728727204459055, 62.75101579938616, 63.43966565813337, 56.577503136226106, 55.957946164267405, 60.6302101952689, 58.234203815460205, 59.76867525918143, 57.53018454142979, 61.707194873264854, 60.280785288129536, 61.6062444959368, 61.10106182098389, 65.93777234213692, 61.74326297215053, 64.62705721173967, 61.96857220785958, 68.30634375980922, 59.83801828111921, 68.66345337459019, 59.85780675070626, 65.32619885035923, 58.25944314684187, 71.12690939222063, 63.09881482805525, 87.03009918757847, 34.97302457264492, 0.7709647874747003, 0.15518938616982528, 12.02725533076695, 80.62434646061489, 60.03035136631557, 57.44769900185721, 37.631964683532715, 35.619168826511924, 55.658826214926584, 38.803927762167795, 0.2723984532058239, 0.21889587199049337, 0.10412498483700411, 0.03057746815362147, 0.17637434867875917, 0.08615930458264691, 0.053631163601364405, 0.2884332670697144, 0.0971607728196042, 0.2166429864508765, 0.13361271896532603, 0.3421735391020775, 0.18761084787547588, 0.312665191079889, 0.1797121845717941, 4.124126723834446, 73.21810177394322, 53.141073499407085, 26.470333303724015, 44.047156538282124, 61.93980666569301, 77.95072133200509, 44.00018671580723, 0.8848499964390482, 1.9160413231168474, 0.1701181743826185, 4.515667702470507, 60.56264591217041, 70.7491010938372, 71.90898472922188, 75.05637972695487, 69.09937640598842, 69.37355927058628, 59.99532549721854, 55.44825063432966, 56.74838713237217, 62.945162364414756, 61.524040358407156, 62.53096635001046, 61.460770062037874, 63.375797816685264, 68.32812636239188, 64.33611529214042, 59.3930139541626, 64.69600418635777, 47.701026575905935, 63.42141274043492, 63.52353736332485, 64.57466779436383, 58.907869883946006, 61.63659422738211, 61.303143228803364, 60.92655781337193, 51.7752035685948, 51.607084955487935, 44.54999419621059, 48.22499370574951, 47.10069874354771, 45.69136435644967, 42.14159917831421, 43.15212433678763, 40.75182397024972, 43.85878045218331, 40.56439978735787, 41.59068693433489, 42.030626024518696, 41.460477692740305, 44.63317108154297, 46.62917314256941, 43.098473821367534, 45.26033633095877, 48.420602866581504, 49.2358523777553, 52.20314311981201, 52.19152225766863, 51.00085462842669, 52.85589163643973, 51.60459402629307, 55.36676910945347, 53.75533594403948, 52.57693188531058, 53.78377839497158, 53.32179267065865, 55.904865401131765, 55.03746271133423, 53.72167192186628, 55.88125194822039, 52.857972621917725, 48.69211067472185, 46.973800318581716, 46.3805388041905, 45.88912398474557, 43.44088799612862, 39.29237917491368, 50.27979489735195, 51.51415627343314, 47.30521896907261, 48.18694537026541, 46.91019303458077, 44.529083592551096, 41.400896889822825, 44.693981715611045, 41.659970896584646, 41.79623201915196, 43.396822520664756, 46.17504930496216, 50.27899238041469, 54.1881913457598, 52.08360978535244, 53.3064614704677, 51.98436519077846, 49.60247755050659, 51.852429321834016, 52.67075341088431, 52.65274715423584, 51.25344944000244, 49.403731278010774, 49.93159287316458, 49.5552784374782, 45.092634609767366, 44.990958145686555, 42.95662634713309, 40.81980514526367, 45.840597765786306, 44.879352705819265, 40.31867674418858, 39.94206006186349, 38.58971132550921, 39.66144663946969, 41.61263976778303, 39.50664077486311, 40.49301746913365, 45.23099061420986, 44.49008682795933, 44.05853073937552, 52.83373383113316, 60.42550931658064, 57.37423917225429, 58.962837082999094, 58.487316267830984, 64.16531467437744, 66.08619976043701, 58.526712553841726, 56.64180176598685, 64.01387173788888, 59.36781978607178, 63.737277848379954, 59.95963954925537, 64.14815262385777, 61.79922376360212, 62.80224486759731, 64.40965502602714, 67.6439094543457, 64.10087013244629, 66.53420570918492, 66.03315721239362, 71.12551975250244, 64.73437213897705, 71.38989870888847, 63.20587267194475, 68.92496272495815, 60.6241374697004, 74.13700798579625, 68.04153401511056, 90.71783474513462, 39.52842685154506, 1.3594472983053751, 0.5681169607809612, 13.148919531277247, 89.18445764269147, 66.43178926195417, 65.61696706499372, 48.693149430411204, 45.9435909135001, 62.69285242898123, 53.00675439834595, 0.32334658077784945, 0.4019570340003286, 0.1747699933392661, 0.27740631305745667, 0.20714314335158893, 0.1401051455842597, 0.1591918199722256], [0.11855472411428179, 0.022641841654798815, 0.13980431029839174, 0.03292767936363816, 0.15074718025113854, 0.05400374039475407, 0.2118543205516679, 0.2427506526666028, 3.0128181619303565, 52.82700450079781, 39.889090469905305, 30.880983761378697, 30.105627332414898, 50.75136913572039, 61.39387975420271, 48.80434840066092, 0.09717139867799622, 1.2050273844173975, 0.688474633863994, 11.762601052011762, 71.84478337424142, 68.05586120060512, 68.81128324781145, 66.70281764439174, 69.8115598133632, 58.81200558798653, 49.57331248692104, 54.07254205431257, 60.1003475189209, 62.16777011326381, 61.96914890834263, 60.58784008026123, 57.29531111036028, 59.64952060154506, 59.52217401776995, 66.70840399605888, 72.78183133261544, 40.08652353286743, 50.715273244040354, 60.246766907828196, 57.7596036366054, 57.12394074031285, 55.63592495237078, 53.842560155051096, 51.79577718462263, 51.77492911475045, 50.19393253326416, 41.55346890858242, 42.58406393868582, 40.86638239451817, 40.986579281943186, 41.993699823107036, 39.39398615700858, 37.50921433312552, 38.554904324667795, 37.79017863954817, 38.580595288957866, 36.08693545205252, 37.71826131003243, 38.98752696173531, 39.97272941044399, 38.87261070523943, 37.92425455365862, 38.763280800410676, 43.05670125143868, 45.050796031951904, 45.33497735432216, 45.57218885421753, 45.92559855324881, 44.9099942616054, 46.65298114504133, 46.03910779953003, 47.05656031199864, 46.30569975716727, 47.91096639633179, 48.02154350280762, 48.74699796949114, 50.382204396384104, 51.191787651606965, 47.54411540712629, 45.082059451511924, 47.020645073481965, 46.807370117732454, 43.60105092184884, 41.537755557468955, 40.85714476449149, 39.595174721309114, 47.31598520278931, 48.55874695096697, 48.32118109294346, 46.397607054029194, 41.97487367902483, 43.1769745690482, 40.01749665396554, 41.884057249341694, 41.49235602787563, 43.80494580950056, 42.404845578329905, 44.75748477663313, 44.46435417447771, 47.425419330596924, 47.886077948978965, 47.88335425513131, 46.76241179874965, 46.262092862810405, 46.24420472553798, 43.26973649433681, 45.77897419248308, 42.529357297079905, 43.55321952274868, 41.570214067186626, 42.87177842003958, 42.05358287266323, 41.11021205357143, 37.069483688899446, 34.26402691432408, 35.92711993626186, 38.57241725921631, 35.51856585911342, 35.648858479091096, 33.70829609462193, 35.09556647709438, 35.29590736116682, 35.584903785160606, 34.14394814627511, 38.507027762276785, 39.811527729034424, 41.25400502341134, 47.3446569442749, 56.578618322099956, 51.440845830099924, 51.18225819723946, 47.84250579561506, 59.929484367370605, 60.73722634996687, 52.915614877428325, 52.428330762045725, 53.838099411555696, 57.4361788885934, 57.36542190824236, 58.531367846897666, 59.53593145098005, 58.88456562587193, 61.45682348523821, 59.80241571153913, 64.00922339303153, 59.032089778355186, 64.20926897866386, 59.470444679260254, 65.4089241027832, 61.53992394038609, 66.85205105372837, 61.39246926988874, 71.34219237736293, 60.05900573730469, 69.2058436529977, 57.8406092098781, 85.22882039206368, 18.73130464553833, 0.488233955843108, 0.0841456094224538, 11.181038566998073, 74.30092988695417, 48.01576260157994, 50.59903335571289, 29.57331541606358, 34.389806679316926, 55.20033196040562, 29.175364289964946, 0.291847682424954, 0.0873791476977723, 0.05013113069747176, 0.08166393544524908, 0.04456711979582906, 0.18293727508613042, 0.03816373393471752, 0.1355154397232192, 0.039174876641482115, 0.12179991283587047, 0.04043214435556105, 0.2057385758629867, 0.03201412695593067, 0.11950083263218403, 0.2700545218374048, 3.751437076500484, 62.85995660509382, 44.88967425482613, 34.807855469839915, 36.29587125778198, 56.60650144304548, 64.52394594464982, 53.04055738449097, 0.3093064970203808, 1.4769902995654514, 0.7194320069892066, 14.324667641094752, 75.15467589242118, 69.42167554582868, 72.33021926879883, 68.72941262381417, 70.98355415889195, 62.19942610604422, 52.64818218776158, 56.406924860818044, 66.15057482038225, 63.35184737614223, 63.65937464577811, 62.04792063576834, 61.36487102508545, 62.80876922607422, 62.6860362461635, 62.57859625135149, 76.03642313820976, 44.906620911189485, 51.67150517872402, 61.95711462838309, 58.80693340301514, 57.909907068525044, 56.77840335028512, 56.325495447431294, 54.754170758383616, 55.9579496383667, 52.287525517599924, 45.206032684871126, 43.437400000435964, 42.97375365665981, 43.445459910801475, 44.44611862727574, 41.906774384634836, 39.208510943821494, 38.70368610109602, 40.501066957201274, 39.36259766987392, 38.9973795073373, 40.48388753618513, 40.351892607552664, 43.03278207778931, 41.68443202972412, 40.40126650674002, 40.84220961162022, 44.86107199532645, 46.56528793062483, 48.51082522528512, 49.93974658421108, 48.19145475115095, 47.16823870795113, 49.231766836983816, 50.317530563899446, 50.10429034914289, 49.74629831314087, 51.720010553087505, 50.663592542920796, 51.311505113329204, 50.58758967263358, 52.281814098358154, 48.52958883558001, 48.59597192491804, 48.06533452442714, 48.44574492318289, 46.550793988364084, 42.957720688411165, 41.809023652757915, 41.683758054460796, 50.608000005994526, 51.814235074179514, 51.13133484976632, 48.32866777692522, 44.99503673825945, 44.12540715081351, 41.86953551428658, 43.11889805112566, 44.49739980697632, 45.89041287558419, 45.057132789066856, 47.22842053004673, 46.34901482718331, 50.299103941236226, 49.463228702545166, 49.72638130187988, 48.96820429393223, 48.74434723172869, 49.34947974341256, 46.40253332683018, 48.11764056341988, 45.33518232618059, 46.18171610151018, 44.75313173021589, 45.38273579733712, 43.793210302080425, 43.39843102863857, 38.18130316053118, 36.92601033619472, 36.88530431474958, 41.29625007084438, 38.94508736474173, 38.28660658427647, 34.14181504930769, 38.05697556904384, 37.47851719175066, 38.26050567626953, 37.570532185690745, 42.32377052307129, 42.72468505586897, 42.968080452510286, 52.172644002096995, 56.58863762446812, 53.33211074556623, 53.799665451049805, 49.65362671443394, 59.60638618469238, 60.77813039507185, 53.59785154887608, 54.374632358551025, 57.49762180873326, 58.84441893441336, 59.451503889901296, 59.195309911455425, 62.027291434151785, 61.213386399405344, 66.08427510942731, 62.246541840689524, 64.29526683262416, 62.66189125605992, 65.98888329097203, 61.281909533909385, 67.67314052581787, 64.80799525124687, 71.22170366559709, 63.84964411599295, 72.33833476475307, 64.75384099142892, 73.65528242928642, 60.838753427777974, 91.20349298204694, 18.687760284968785, 0.4040516716028963, 0.012348650322694863, 13.158154555729457, 84.24108532496861, 55.89844873973301, 59.808891432625906, 31.622603212084087, 36.44060570853097, 63.07964474814278, 37.038157735552105, 0.2852851631385939, 0.08808647295726196, 0.0660682830161282, 0.07706857060215302, 0.05844891829682248, 0.10753213308219399, 0.030507718146379505, 0.17932850016014917, 0.15426294159676346, 0.2594648429325649, 0.11555711925029755, 0.3912820496729442, 0.14489203372171947, 0.221530216346894, 0.4639475590416363, 5.253601133823395, 73.18517426082066, 51.843500886644634, 41.06071308680943, 39.81762824739729, 68.70828315189907, 71.96534156799316, 56.70199053628104, 0.5613337819065366, 2.7317531066281453, 0.9131552747317723, 15.074368715286255, 74.53946154458183, 69.74049363817487, 75.0037818636213, 72.36524513789585, 74.63422107696533, 65.71569401877267, 54.8263521194458, 58.379160608564106, 66.75509589059013, 65.48237351008824, 66.1978781563895, 63.826124463762554, 63.50917543683733, 63.08597455705915, 65.71249089922223, 60.338066237313406, 70.69796235220772, 52.22271966934204, 52.58878551210676, 63.9998641695295, 60.22442150115967, 62.44761575971331, 59.74621868133545, 59.60182816641671, 58.79936681474958, 56.55082205363682, 54.44990914208548, 46.35375697272164, 47.430283069610596, 47.092496395111084, 43.895942892347065, 46.503640038626536, 45.717138699122835, 42.356677191598074, 42.16519178662981, 43.72120612008231, 43.05122259684971, 41.619160652160645, 42.797331946236746, 43.65051167351859, 46.24374961853027, 43.8251233782087, 43.03429331098284, 43.82022142410278, 48.299203940800254, 50.26888969966343, 51.025402614048545, 53.440374101911274, 50.30237306867327, 52.072718484061106, 53.536141123090474, 55.315602575029644, 53.42921529497419, 52.3625556400844, 53.96098525183541, 55.62465150015694, 53.211236408778596, 54.83721910204206, 56.14707612991333, 51.62698112215315, 50.3965037890843, 50.77190453665597, 49.94330753598894, 48.83704662322998, 44.70995909827096, 43.604667459215435, 43.82914291109358, 52.0036255972726, 52.943716866629465, 52.682534081595286, 49.97185073580061, 44.75907244001116, 45.39024680001395, 43.41424512863159, 44.085597446986604, 46.20450619288853, 48.02442005702427, 47.257001944950645, 48.710033552987234, 48.66523156847273, 53.154288973127095, 54.267161096845356, 53.15348993028913, 52.892307145254954, 53.860076563698904, 54.15381860733032, 49.002535343170166, 52.49230630057198, 47.75510093144008, 49.10798467908587, 49.32429599761963, 49.63618326187134, 47.28706680025373, 45.19960560117449, 40.9153185571943, 39.922320229666575, 39.170344488961355, 44.796516282217844, 40.7843519619533, 41.20417601721627, 36.48765890938895, 41.15356533867972, 39.88390016555786, 40.12618385042463, 38.56707756859915, 43.79442971093314, 44.74032620021275, 44.97437626974923, 55.11759975978306, 61.353573254176546, 55.601715496608186, 55.54828037534441, 52.294626576559885, 62.958016531808035, 62.17371082305908, 55.520355565207346, 55.50721304757254, 58.86463819231306, 61.323501450674875, 60.98784787314278, 61.10877432141985, 64.57941341400146, 62.32854448046003, 67.21425369807652, 65.71696553911481, 66.98820100511823, 65.88725893838065, 70.23592104230607, 64.33098752158028, 70.44456154959542, 67.12867273603166, 73.7536689213344, 65.92509882790702, 78.10133743286133, 67.00521714346749, 77.42173412867955, 63.88136264256069, 95.39528560638428, 23.37129603113447, 0.981130695768765, 0.21002710717064993, 15.256906577519008, 91.95311328342983, 60.90015465872628, 70.01674706595284, 43.178687300000874, 49.14547368458339, 73.3317951474871, 46.2239750453404, 0.3894856960645744, 0.2633540428110531, 0.1610661915370396, 0.29408274963498116, 0.19230028481355735, 0.22691792010196618, 0.19301733347986424], [0.057609197284494124, 0.04067353318844523, 0.07298415619879961, 0.07779240461864642, 0.06763040633606059, 0.056401028364364586, 0.08651100963886295, 0.2014299463480711, 2.0000317990779877, 54.908695220947266, 41.00459943498884, 42.37619120734078, 35.95931441443307, 48.30113901410784, 54.91578238351004, 60.241201400756836, 0.8068318228636469, 0.7196478896907398, 0.07342455256730318, 21.380812576838903, 76.05478027888707, 60.893248149326865, 69.0570410319737, 62.97443512507847, 62.451694352286204, 51.221428666796, 58.848462785993306, 62.82593127659389, 60.580488886152, 60.801281792776926, 62.94258458273751, 58.602635519845144, 61.107037271772114, 59.288318497794016, 72.60163675035749, 72.81427942003522, 37.509398460388184, 44.00529016767229, 59.895764759608674, 58.17017616544451, 56.48150682449341, 52.70730093547276, 53.08215624945504, 54.50198589052473, 51.54722275052752, 51.20178958347866, 45.43676151548113, 41.568473543439595, 40.92591108594622, 40.12759780883789, 40.87762457983834, 41.54077802385603, 39.40462384905134, 38.9325840813773, 39.48767219270979, 37.26528739929199, 38.422753061567036, 35.84746578761509, 36.903192452022004, 38.01618269511631, 37.87581171308245, 36.577301093510215, 36.94053554534912, 37.1880373273577, 42.7951397895813, 44.22038207735334, 43.25465195519583, 45.73768104825701, 44.011415004730225, 44.520276750837056, 44.971690790993826, 43.22452456610543, 46.72267852510725, 47.20161785398211, 50.07485777991158, 48.27423211506435, 49.767320087977815, 50.13059970310756, 47.716823305402485, 51.65494762148176, 49.864177976335796, 46.69403805051531, 48.20503153119768, 47.74345922470093, 38.752921036311555, 40.30634369168963, 38.936148507254465, 49.81255286080496, 49.23677996226719, 49.49276202065604, 49.66220426559448, 44.43014471871512, 40.935152190072195, 41.39120762688773, 42.5066887991769, 45.646148954119, 45.490335600716726, 42.40289660862514, 45.578984192439485, 45.41896023069109, 43.5592714037214, 43.08503947939192, 45.145586831229075, 47.32469129562378, 44.50635256086077, 43.21027728489467, 43.703154700142996, 43.536564690726145, 42.8738420350211, 43.61790030343192, 42.08997058868408, 42.675342423575266, 42.88586936678205, 40.62260832105364, 35.18538236618042, 34.84639365332467, 34.1316567829677, 35.90401370184762, 34.327655042920796, 35.383301803043906, 33.34912633895874, 36.04389830998012, 37.02219424928938, 36.433084283556255, 34.490840435028076, 39.09683949606759, 40.11658491407122, 39.53367968967983, 45.19459594999041, 53.700313159397666, 52.9108692577907, 52.566620758601594, 55.25802632740566, 51.79170901434762, 58.121080194200786, 54.55972194671631, 51.80236407688686, 59.53076893942696, 56.3593088558742, 56.21223633629935, 55.78090606416975, 54.85658025741577, 55.23098046439034, 59.43511308942522, 58.243226051330566, 62.32413237435477, 60.1672169821603, 66.74522250039237, 60.32944352286202, 67.11685385022844, 60.76831259046282, 70.28703893933977, 64.77513722011021, 71.17861093793596, 64.37496267046247, 73.6343058177403, 58.52492686680385, 81.25817503247941, 6.578922246183668, 0.2560532231416021, 0.4202091374567577, 16.123119388307842, 72.76880346025739, 49.00740603038243, 43.43953309740339, 36.487186431884766, 45.72067533220564, 50.438130446842735, 39.9884740284511, 0.042907039767929485, 0.09442693487341915, 0.06604160301919494, 0.18061150131481035, 0.07908554987183639, 0.07074847152190548, 0.06363304797559977, 0.07898322000567402, 0.0404614401049912, 0.02186948390278433, 0.035845556362931214, 0.12446437057639871, 0.04688490042462945, 0.043552994927657504, 0.09341229431863342, 3.0670280073370253, 65.4136071886335, 45.32796662194388, 39.147662094661165, 41.267852783203125, 55.78487001146589, 60.74861444745745, 68.75359235491071, 1.0867571021829332, 1.0855790568249566, 0.04000561385016356, 25.48868833269392, 78.75249481201172, 63.89347335270473, 69.34653772626604, 65.40165628705705, 64.78396143232072, 53.15576893942696, 60.93163694654192, 65.63148185185024, 61.48548480442592, 65.20787797655377, 64.92205687931606, 60.587826183864046, 61.55350766863142, 61.24624443054199, 66.49612958090646, 72.61808313642229, 43.342181886945454, 46.573973178863525, 61.35490730830601, 59.89416667393276, 58.50749383653913, 54.7318114553179, 55.38447311946324, 54.82859986168997, 53.76834992000035, 51.41209071023123, 47.67817047664097, 43.838839122227256, 43.67800569534302, 43.566584382738384, 42.970779827662874, 43.32673256737845, 41.657775265829905, 40.87046793528965, 41.252802985055105, 39.308036940438406, 40.2593217577253, 38.000750746045796, 39.26879698889596, 41.18013872419085, 39.41309717723301, 38.751232624053955, 40.492475509643555, 39.15728882380894, 43.670988014766145, 46.61097233636038, 45.82390819277082, 47.166501658303396, 47.53452341897147, 47.35102496828352, 48.185746806008474, 47.45639092581612, 49.217179094042095, 51.5926570211138, 53.1859484400068, 51.759396416800364, 50.9192202431815, 52.5520920753479, 51.43902540206909, 54.35396146774292, 51.2192781993321, 49.14624840872628, 49.042115756443565, 48.993110111781526, 41.09097249167306, 40.22974675042288, 42.619972229003906, 51.470122064862935, 51.42691469192505, 52.06516579219273, 52.366203444344656, 46.44323934827532, 43.70739310128348, 42.439471926007954, 43.74277680260794, 47.39696993146624, 47.67186498641968, 45.294229643685476, 48.40767921720232, 47.22772223608834, 46.02440888541085, 46.837820598057334, 47.52177347455706, 48.27798414230347, 46.77352196829659, 46.918173040662495, 45.29675531387329, 48.54603174754551, 45.3405567577907, 46.43110431943621, 45.35401889256069, 44.821102482931956, 44.59206901277815, 41.32725293295724, 37.841466767447336, 35.70975249154227, 36.66872896466936, 37.12333917617798, 36.12614761080061, 35.56280503954206, 35.04533794948033, 38.1818277495248, 39.3945072719029, 38.968252658843994, 37.4941645349775, 42.918300083705354, 41.4192852973938, 41.06805385862078, 47.27045018332345, 54.861805302756174, 55.14225544248308, 53.87245825358799, 56.66787140710013, 53.78824608666556, 56.41236877441406, 56.159763540540425, 54.264930725097656, 62.372596059526714, 57.45641899108887, 58.71186120169503, 56.57994542803083, 56.87747771399361, 56.177255630493164, 61.751941272190635, 60.282737731933594, 64.69462149483817, 62.29204559326172, 69.37582438332694, 64.89506312779018, 70.06954642704555, 63.57539871760777, 73.48693452562604, 66.56287397657121, 74.41393538883754, 66.9002159663609, 74.97120176042829, 63.54318686894008, 83.98723983764648, 6.427508405276707, 0.2271627491073949, 0.6400615402630397, 18.61493968963623, 82.48159994397844, 55.71220922470093, 52.812489713941304, 40.01862921033587, 56.585399763924734, 55.79271452767508, 52.31370980398995, 0.030875738577118943, 0.08531883718179804, 0.028663096949458122, 0.1576714536973408, 0.048801405621426444, 0.08668895544750349, 0.03211407516417759, 0.12268664953964097, 0.18823866918683052, 0.13094884476491384, 0.09284009252275739, 0.26547541469335556, 0.21640036946960858, 0.25781502574682236, 0.3149873821863106, 4.414057680538722, 80.03027548108781, 51.66643646785191, 53.38334676197597, 49.091767583574565, 64.52870546068463, 65.36030755724225, 71.7226618358067, 1.151264937860625, 2.269780193056379, 0.14109225118798868, 25.97667247908456, 82.24945368085588, 66.75792380741665, 71.45277295793805, 66.71857615879604, 67.8628055027553, 57.53264767783028, 64.77470643179757, 70.9942752293178, 64.30937167576381, 66.75032247815813, 68.66347421918596, 64.56682327815464, 64.01349653516496, 63.25920009613037, 63.50419357844761, 71.23796245029995, 50.9883166040693, 48.21942472457886, 62.72138868059431, 63.33475480760847, 61.90894276755196, 56.72856044769287, 56.063385077885215, 57.89574316569737, 55.04764182226998, 55.40739870071411, 50.015829358782085, 46.39451510565621, 44.67202888216291, 47.26941837583269, 45.00171743120466, 46.61651005063738, 44.15981463023594, 43.784000464848106, 45.078116348811555, 41.38966860089983, 42.91946390696934, 40.71353939601353, 42.638708046504426, 42.93414545059204, 40.52004943575178, 40.33715547834124, 42.561513560158865, 42.02852419444493, 47.77987125941685, 50.908009324754985, 49.421442236219136, 50.57913024084908, 50.291856970105854, 50.32332536152431, 51.307499476841514, 49.31928287233625, 52.744772570473806, 56.563446930476594, 58.03389419828142, 52.970307622637065, 54.07622112546648, 54.30802692685808, 52.470054694584434, 56.70257765906197, 54.134603364127024, 54.29523181915283, 52.33320297513689, 49.26145648956299, 41.82234334945679, 41.32718345097133, 45.31130831582205, 54.23440728868757, 53.88590996606009, 53.57830279214041, 54.55852338245937, 48.40525082179478, 45.06098209108625, 44.355125018528526, 46.042620113917756, 50.8987786429269, 51.11214739935738, 46.818056447165354, 52.28451694761004, 49.211082049778526, 49.05037716456822, 50.12032331739153, 51.865658691951204, 52.958617278507774, 50.396927629198345, 49.1604574748448, 48.758709158216206, 51.98648091724941, 50.47239201409476, 49.26592418125698, 48.07181371961321, 49.214153153555735, 48.62342425755092, 44.785670144217356, 40.07866164616176, 39.64455904279436, 38.40340232849121, 40.76394510269165, 38.41967153549194, 40.22377129963466, 38.40700149536133, 42.915489537375315, 41.00189658573696, 42.85398408344814, 39.366801330021445, 46.006089959825786, 43.82102741513933, 43.451035840170725, 49.41917017527989, 58.40957287379673, 57.24857752663748, 59.28395502907889, 58.130092007773264, 58.27442693710327, 61.870220456804546, 55.02738087517874, 55.887619972229004, 64.49723706926618, 60.360925810677664, 60.97462545122419, 59.13794558388846, 58.33607482910156, 59.311435154506135, 64.30004024505615, 64.10635920933315, 67.1105796269008, 63.94789859226772, 71.01171520778111, 66.15641825539726, 71.82202107565743, 65.73532267979213, 75.54670020512172, 68.32553468431745, 78.32814053126744, 71.47605637141636, 81.15597397940499, 65.06515502929688, 90.85415145329067, 8.786716256822858, 0.783110781439713, 0.8074985785143716, 20.165683814457484, 92.32933739253453, 61.37566157749721, 63.096521922520225, 50.91295644215175, 66.14914349147251, 61.95154217311314, 62.75749846867153, 0.0982886269422514, 0.11680467373558454, 0.14476906960564, 0.23817330971360207, 0.17518896157188074, 0.1896658997450556, 0.12739922452185834], [0.05193326881687556, 0.0868514645844698, 0.06441558205655643, 0.044677581904189925, 0.039890144153365066, 0.01471286649549646, 0.07848598275865827, 0.10535858864230768, 2.1627729407378604, 58.451824869428364, 43.55202095849173, 38.032330308641704, 33.25103514535086, 46.27229629244123, 49.565742424556184, 67.4969620023455, 2.47957301565579, 0.17387795049164975, 0.23434075393847056, 29.685358592442103, 75.12566716330392, 60.648914745875764, 67.37654972076416, 61.06575802394322, 56.99840068817139, 57.95976734161377, 63.79754652295794, 63.6169558933803, 66.08121790204729, 62.583856037684846, 63.0440491267613, 59.196407726832796, 62.57754012516567, 66.54977662222726, 65.87232031141008, 32.659660066877095, 43.12280641283308, 52.822119917188374, 55.21486759185791, 54.654953956604004, 57.28863736561367, 55.864673546382356, 51.928397451128276, 50.80138226917812, 48.771535532815115, 47.45181901114327, 41.126095635550364, 40.629059723445344, 40.46643018722534, 39.39709547587803, 41.99561752591814, 40.86298125130789, 41.49989482334682, 39.18097870690482, 39.91434717178345, 38.43493325369698, 38.31195708683559, 37.14941576548985, 35.94090516226632, 37.26957096372332, 37.812857559749055, 36.2528132711138, 37.30813346590315, 35.61802584784371, 38.87657117843628, 43.73895876748221, 42.64712578909737, 45.883850302015034, 43.139294488089426, 44.26134170804705, 45.626791272844585, 45.24490090778896, 45.26130560466221, 46.60609817504883, 48.694796153477256, 49.72109372275216, 49.196119104112896, 49.87433276857649, 48.878252914973665, 50.10510676247733, 49.09742341722761, 50.688613006046836, 47.567381450108115, 46.8006477355957, 44.66133213043213, 40.13405268532889, 38.492130824497764, 46.45915767124721, 46.78116498674665, 46.523550101688926, 45.683637959616526, 42.88295807157244, 43.65517391477312, 43.717019830431255, 42.68124839237758, 45.22655766350882, 47.62823377336775, 45.98092358452933, 48.83738708496094, 46.79374470029558, 47.21545171737671, 45.08506107330322, 45.33044365474156, 45.23353018079485, 42.45401103155953, 43.309810229710166, 42.070213385990684, 40.96121488298689, 42.11638069152832, 40.72280134473528, 43.031778063092915, 40.64754887989589, 41.03988586153303, 38.67275619506836, 35.50314780644008, 33.51304129191807, 33.02387768881661, 37.88643203462873, 34.88815927505493, 33.933125904628206, 33.36264058521816, 34.219443798065186, 37.156350067683626, 34.96311296735491, 37.580898897988455, 40.56652593612671, 40.71934461593628, 39.50913517815726, 42.526852471487864, 47.15788589205061, 51.87264163153512, 51.76133843830654, 57.13775723321097, 47.233867917742046, 44.765523842402864, 58.17555407115391, 51.62704365594046, 57.63453606196812, 55.35400179454258, 58.17377880641392, 55.485829966408865, 58.05160168239048, 54.47300148010254, 56.91152388708932, 54.95148917606899, 57.00439350945609, 55.88668196541922, 59.869973046439036, 60.01535715375628, 62.891626494271414, 61.36250168936593, 64.12554318564278, 64.62780066898891, 67.33290808541435, 67.99651663643974, 67.89660848890031, 66.88801492963518, 60.28739997318813, 0.7643837577530316, 0.1425862903041499, 0.7068483307957649, 21.478834288460867, 71.45194612230573, 48.44464710780552, 43.3991744858878, 29.406895637512207, 27.414676870618546, 53.89132956096104, 39.046569279261995, 0.037843268630760055, 0.17085574194788933, 0.028004972264170647, 0.012144992277691407, 0.04204112730388131, 0.08028357808611222, 0.02556223432267351, 0.03610369822542582, 0.034990252793899605, 0.022961874392681887, 0.047797051657523425, 0.02585685083509556, 0.06428508620176997, 0.17420185596815177, 0.09087000680821282, 3.1434149827275957, 68.92543520246232, 44.44943291800362, 38.29877635410854, 41.87652540206909, 50.47539016178676, 55.55712890625, 73.12000710623605, 2.7781620791980197, 0.4067543851477759, 0.09784308727830648, 31.921646731240408, 80.28127220698765, 63.59249823434012, 70.64382198878697, 61.72517681121826, 61.01729433877127, 58.86602088383266, 65.53599275861467, 64.82451806749616, 69.71782166617257, 64.82722091674805, 64.17903736659459, 60.1607551574707, 64.22843905857631, 63.113287925720215, 64.70008972712925, 37.68813739504133, 46.57595688956124, 56.89241981506348, 56.7886449950082, 57.292517934526714, 58.77326938084194, 57.367356981549946, 53.92966277258736, 53.15703351157052, 51.638511657714844, 50.68816484723772, 42.85551963533674, 43.22043555123465, 42.180912085941856, 43.24175957271031, 44.99935851778303, 43.62901394707816, 44.019322054726736, 41.82205152511597, 41.181121894291465, 40.68483291353498, 40.39320312227522, 39.15829283850533, 38.74718182427542, 37.884048802512034, 39.16534178597586, 37.685841015407014, 40.12629154750279, 38.12737471716744, 39.74771547317505, 44.32182230268206, 46.20930739811489, 47.10445771898542, 45.89354998724801, 47.44392933164324, 46.80769668306623, 46.53153010777065, 47.86992686135428, 49.91157858712332, 51.479724475315635, 51.02669497898647, 51.04074076243809, 50.99006755011422, 50.31113474709647, 52.543201855250764, 50.25273861203875, 52.16660254342215, 48.897402150290354, 45.92954165594918, 46.75993129185268, 40.968896116529194, 41.68902131489345, 48.19580084936959, 50.38263865879604, 49.49424546105521, 46.07050323486328, 44.567628724234446, 43.72487824303763, 44.18619346618652, 43.75152805873326, 46.62550449371338, 50.72034542901175, 48.5111517906189, 51.4011264528547, 49.34721463067191, 50.03335966382708, 47.54237140927996, 49.093105111803325, 47.709711824144634, 45.46480097089495, 46.90774379457746, 43.429340090070454, 44.091354029519216, 44.73525401524135, 42.84308583395821, 46.57816989081246, 44.266424315316335, 43.6648770741054, 38.754501751491, 35.271557399204795, 37.503096444266184, 36.381212506975444, 38.88128205708095, 37.91348484584263, 35.58498368944441, 36.078819956098286, 37.47860404423305, 39.29133694512503, 37.017698764801025, 39.62328018460955, 42.55130318232945, 42.5128344808306, 42.28567007609776, 43.88304008756365, 49.67504801068987, 54.788331576756065, 55.11721066066197, 59.58442987714495, 50.32600041798183, 46.049967833927695, 59.954463141305105, 54.96789387294224, 58.24409805025373, 56.74537508828299, 61.83622292109898, 57.402580874306814, 61.21265683855329, 56.93658256530762, 58.38507352556501, 57.20543963568551, 58.60613741193499, 57.246531282152446, 61.1873653956822, 62.30159936632429, 65.92119394029889, 63.16209207262312, 65.35759081159318, 66.3891829081944, 68.91491562979562, 71.79121276310512, 71.8118975503104, 70.78262615203857, 59.929123061043875, 0.8221501037478447, 0.3445845640131405, 0.6004201674035617, 25.056717089244298, 80.23545578547886, 57.67505100795201, 52.48550401415144, 37.66384301866804, 37.42173998696463, 61.413709912981304, 43.47617094857352, 0.12719440194112913, 0.09157009209905352, 0.02973447660250323, 0.03760877371366535, 0.06350266747176647, 0.03532388846256903, 0.041882333146142106, 0.09436486927526337, 0.16326467213886126, 0.20680155525250093, 0.2239943298378161, 0.13334206491708755, 0.1477387731096574, 0.3462050956274782, 0.14290303045085498, 4.522760510444641, 82.60601438794816, 52.20025266919817, 51.51481287819998, 46.08331571306501, 61.861396244594026, 58.294976234436035, 80.0086943762643, 3.287556448153087, 0.7654415667057037, 0.36056314089468544, 34.0799343926566, 82.14397307804653, 66.0064344406128, 73.87324741908482, 64.69057764325822, 62.628942898341585, 61.90000738416399, 67.59489686148507, 66.4807254246303, 70.65852437700543, 66.70652798243931, 67.68602248600551, 60.75786944798061, 67.21984699794224, 64.85522215706962, 67.6369959967477, 47.52330902644566, 48.183738776615684, 55.575288023267476, 59.5168308530535, 60.52024800436837, 61.903141021728516, 59.27534621102469, 57.211595739637104, 55.66114691325596, 54.31280033929007, 54.34249694006783, 46.2485681942531, 44.77303831917899, 45.10636077608381, 44.47514820098877, 46.32036393029349, 45.33591883523123, 47.635067326681956, 45.66850478308541, 43.5033175604684, 43.95075028283255, 43.09263038635254, 42.68065432139805, 41.300808089120046, 41.512081963675364, 39.93584142412458, 41.743064403533936, 42.539519037519185, 40.90641791479928, 43.00222042628697, 48.72487490517752, 47.083526270730154, 48.81890140260969, 47.218682629721506, 50.89816720145089, 50.142922333308626, 49.68115547725132, 51.04796688897269, 51.24994059971401, 53.67241614205496, 55.021964754377095, 53.07506908689226, 54.69466291155134, 53.2448969568525, 54.23971571241106, 52.76467915943691, 55.175495624542236, 53.43276582445417, 48.034644331250874, 47.81330599103655, 42.09004701886858, 42.37960624694824, 51.557492188044954, 49.6478944505964, 50.32917921883719, 49.35933576311384, 46.06889820098877, 44.677775042397634, 46.84258706229073, 46.25811154501778, 49.685710021427695, 52.797113350459504, 51.613800389426096, 54.08780377251761, 50.71709714617048, 51.00034046173096, 48.53890636989048, 51.918867996760774, 51.53569221496582, 47.749733448028564, 51.26625149590628, 46.85039683750698, 46.21839911597115, 48.912587438310894, 47.31270217895508, 49.732565198625835, 45.67905214854649, 46.56179298673357, 44.26683078493391, 38.334761074611116, 38.906305994306294, 37.436518805367605, 44.6070875440325, 40.93940101351057, 38.78283303124564, 38.06142936434065, 40.05465562002999, 43.793974603925435, 39.64587572642735, 42.286489963531494, 46.18932785306658, 44.4310062953404, 43.85682453427996, 46.17768962042672, 53.095701762608115, 56.58336394173758, 56.597698075430735, 60.23155730111258, 53.44367797034127, 55.42638465336391, 60.24986580439976, 56.58691099711827, 62.26694175175258, 60.43823841639927, 62.88442816053118, 59.200646127973286, 63.07753249577114, 58.60971573420933, 60.31274005344936, 59.91474028996059, 61.302663803100586, 59.52203505379813, 64.39746788569859, 63.692566190447124, 69.07823998587472, 65.93161623818534, 69.67155361175537, 69.64968763078961, 72.68435505458287, 74.97323063441685, 77.54931695120675, 74.39177063533238, 70.43607085091728, 1.2735562728984016, 1.2361367493867874, 1.205052137374878, 26.85773011616298, 91.82322365897042, 62.06590257372175, 62.78301920209612, 44.711998394557405, 42.93802254540579, 69.36889008113316, 57.091947759900776, 0.21825481924627507, 0.19044869845466955, 0.08719184489122458, 0.11555633214967591, 0.15940531423049314, 0.15514043665358, 0.10771656568561282], [0.036203344485589435, 0.08356621515538011, 0.023450999753549695, 0.02503537223674357, 0.015014990997899855, 0.07496829437358038, 0.047000800991164784, 0.10733062175235578, 2.0973378462450842, 53.43892887660435, 47.69365801130022, 37.30833148956299, 22.247549976621354, 49.05009576252529, 43.44796821049282, 72.98587213243756, 5.8732731853212625, 0.20920044795743056, 0.34541872782366617, 29.472434520721436, 73.41955089569092, 60.17291450500488, 66.02607699802944, 58.47616440909249, 60.01022243499756, 64.36950138636998, 62.77305548531668, 63.46337291172573, 55.68063313620431, 51.837834630693706, 58.53440420968192, 58.27528156552996, 60.38696071079799, 48.812800884246826, 32.20828424181257, 49.184258529118125, 57.99358422415597, 55.55051074709211, 56.72178247996739, 56.154712200164795, 56.738357407706125, 53.13831159046718, 51.6648279598781, 50.211712973458425, 47.08865751538958, 44.82569524220058, 40.318947723933626, 40.16203308105469, 39.50813463756016, 40.04698133468628, 39.84530987058367, 42.25986794063023, 41.48164537974766, 39.91394417626517, 38.321795736040386, 38.980557918548584, 37.93407930646624, 37.167130197797505, 36.602384090423584, 35.03162915366036, 37.30055298124041, 38.02093873705183, 37.66843925203596, 36.80188076836722, 36.795592648642405, 39.051089082445415, 40.173049449920654, 41.58745602199009, 42.488811084202354, 42.76291404451643, 43.381883893694194, 45.07973527908325, 46.75506755283901, 47.704962730407715, 47.91188703264509, 47.036834376198904, 48.475236552102224, 48.87637342725481, 48.91308423451015, 49.07508148465838, 48.4246814591544, 47.30350276402065, 47.33909143720354, 46.609131063733784, 43.7577988079616, 45.63935361589704, 40.93282454354422, 46.10761703763689, 39.009302616119385, 36.87663296290806, 45.422614983149934, 43.46051318304879, 44.282210622514995, 41.66024187632969, 44.368510723114014, 46.30305944170271, 46.76484019415719, 44.6286165373666, 47.578283173697336, 48.51731136866978, 49.263304710388184, 48.00782428468977, 46.0065415927342, 45.54951688221523, 44.3519218989781, 43.933758463178364, 42.40711069107056, 40.99168273380825, 40.403681005750386, 39.56288644245693, 41.23616552352905, 42.348669392721995, 37.43250969478062, 33.32838944026402, 33.861625467027935, 33.38296406609671, 32.87925440924508, 35.44684655325753, 34.37504870550973, 33.91021421977452, 32.0428580556597, 33.19370208467756, 37.797877243586946, 37.43339211600167, 39.24889734813145, 40.77944653374808, 42.29041569573538, 40.95448555265154, 38.54099750518799, 42.61628968375069, 49.56466197967529, 53.76914201463972, 53.96482065745762, 53.27539260046822, 41.0029422896249, 50.63419124058315, 52.72531066622053, 54.62335007531302, 56.09235559191023, 53.83902699606759, 57.96880694798061, 57.5420173236302, 58.978109223502024, 59.08135945456368, 62.35664994376046, 59.561118670872276, 58.959210123334614, 58.390340260096956, 58.60194764818464, 58.46223327091762, 62.23433385576521, 61.35482392992292, 65.57155363900321, 65.45649147033691, 68.36985029493059, 60.67968831743513, 66.2829588481358, 23.310711213520594, 0.5381311955196517, 0.40663634719593184, 0.18221310180212769, 25.666742869785853, 68.14153248923165, 42.98928982870919, 42.020394802093506, 27.32454136439732, 40.23494052886963, 51.71087367194039, 30.51764508656093, 0.3358868307300976, 0.01640586564982576, 0.14226929231413774, 0.05315901518666318, 0.0630356182477304, 0.07126497916345086, 0.052144659616585286, 0.01747750653885305, 0.08353053778409958, 0.03907609890614237, 0.0449871974331992, 0.012720077847396689, 0.02952059218659997, 0.03772435876141701, 0.09317636769264936, 2.498209169932774, 66.40799862997872, 52.31420660018921, 42.260541915893555, 31.003727163587296, 55.77459362574986, 47.27865947995867, 82.11065646580288, 6.884748944214412, 0.3494861109980515, 0.06319883306111608, 30.750948224748882, 77.84376771109444, 62.529555865696494, 69.04938411712646, 61.27082020895821, 64.34457819802421, 67.3407734462193, 65.88607079642159, 63.47132165091378, 58.49669633592878, 54.04432541983468, 59.5078398840768, 59.112800053187776, 61.615159034729004, 50.187710421425955, 37.44524226869856, 49.97871903010777, 60.29714134761265, 57.59542465209961, 59.7982884815761, 58.3263612474714, 58.15168006079537, 54.98959657124111, 53.34053543635777, 52.10691751752581, 50.607277393341064, 46.24836322239467, 43.40518467766898, 43.64006853103638, 41.9157931464059, 41.76316901615688, 42.93637582233974, 43.421853406088694, 44.74338340759277, 41.338425636291504, 41.47589227131435, 41.873138155256, 39.03184952054705, 39.13265745980399, 38.04807840074812, 36.4285158429827, 39.71695927211216, 39.4466986656189, 40.381478037152974, 38.98458439963204, 40.5587682723999, 40.889790875571116, 40.009572233472554, 43.845992292676655, 43.39565174920218, 45.21072619301932, 45.05473913465227, 46.552277428763254, 49.418405873434885, 49.086914266858784, 50.080530984061106, 47.817822320120676, 50.861789907727925, 49.19411454881941, 51.343247958592, 50.003576210566926, 49.54512364523751, 50.39162615367344, 47.75159209115164, 49.419587067195344, 46.21834005628313, 46.887559277670725, 41.33109876087734, 46.65265457970755, 42.17234148297991, 39.21960374287197, 46.70279972893851, 44.12897505078997, 46.361789090292795, 43.76286057063511, 44.82499694824219, 48.24254832948957, 47.55336693355015, 47.56246559960501, 50.198987347739084, 48.76875972747803, 48.44984088625227, 50.626193864004954, 47.61987509046282, 48.033709798540386, 47.20771837234497, 46.56510727746146, 45.805988788604736, 44.036240918295725, 44.826667990003315, 42.98089293071202, 43.97081320626395, 44.56499188286917, 40.587103026253835, 35.848994391305105, 36.69315535681588, 36.39091566630772, 35.97821698869978, 38.03664166586739, 36.99922350474766, 37.269258294786724, 36.377502168927876, 37.51886190686907, 40.57760483877999, 39.55976670128958, 41.87746688297817, 42.1978691646031, 44.33218206678118, 42.43004322052002, 40.05661848613194, 43.48067685535976, 52.23952736173357, 55.613162653786794, 56.121593611580984, 55.87823295593262, 46.07572480610439, 51.48822212219238, 55.772585596357075, 57.97510896410261, 57.96972411019461, 57.25641509464809, 60.899181910923545, 60.10730266571045, 61.950354031154085, 61.68514129093715, 64.2505134854998, 63.320566586085725, 62.98711558750698, 60.02952453068325, 62.247639656066895, 61.147031102861675, 65.38963590349469, 62.54352174486433, 69.32123933519635, 65.94734695979527, 73.18950298854283, 65.03588226863316, 68.96783311026437, 24.177273171288626, 0.6148039698600769, 0.4780227094888687, 0.16956526333732264, 28.622105291911534, 77.32363251277378, 48.77494362422398, 50.23538548605782, 32.6066244670323, 40.0422739301409, 60.985388210841585, 43.909345967429026, 0.3153457029589585, 0.07121552753129176, 0.1941107248089143, 0.029218019851084267, 0.03335708685751472, 0.024407457626823868, 0.05666337714397481, 0.16408354177006654, 0.18665294641894953, 0.1640455030969211, 0.08717798920614378, 0.19133325027568, 0.19995805461491856, 0.12571816758385726, 0.17245365120470524, 4.413080590111869, 78.89926161084855, 59.78137656620571, 52.36682183401925, 30.490258761814662, 67.40453706468854, 53.711701256888254, 89.69831861768449, 7.168424350874765, 0.7649898252316883, 0.3163184236202921, 35.36328056880406, 79.88039588928223, 65.40297644478935, 70.66265855516706, 63.171298435756135, 65.67722184317452, 70.05813748495919, 66.66076019832066, 67.25084291185651, 60.41246059962681, 56.232823848724365, 61.07148333958217, 60.669307708740234, 63.080006054469514, 53.41415854862758, 44.40774025235857, 51.927737372262136, 61.98922225407192, 59.51202269962856, 60.3602865764073, 61.77791363852364, 61.60738400050572, 58.32809829711914, 57.05379172733852, 55.39923109327044, 51.888049261910574, 49.89649404798235, 46.17534807750157, 45.846392563411165, 43.88571514402117, 43.74839094706944, 44.87150124141148, 46.901559897831504, 47.97211054393223, 44.015076705387656, 42.84243270329067, 44.71260983603341, 41.2449688911438, 42.184994152614046, 41.02358191353934, 39.74475901467459, 41.349730355399, 41.536206109183176, 41.52517931801932, 42.814980370657786, 42.16171421323504, 43.888230391911094, 43.79702833720616, 46.01321881158011, 45.85502222606114, 48.89985833849226, 48.45615332467215, 48.78211069107056, 51.38353361402239, 53.68806348528181, 52.67337982995169, 52.19418689182827, 52.403539589473176, 52.317392349243164, 54.676562854221885, 52.82548631940569, 51.706624848502024, 53.03827837535313, 50.77456569671631, 51.67207145690918, 48.477432182856965, 48.63285296303885, 42.19885580880301, 51.2401054246085, 45.206428732190815, 44.09698207037789, 49.44453457423619, 46.342872619628906, 47.74658243996756, 46.660829135349815, 47.2580372265407, 51.01961129052298, 49.78855030877249, 51.595481463841026, 52.2195964540754, 52.34957293101719, 51.29322440283639, 56.0558671270098, 50.35656206948416, 50.325986521584646, 50.72865547452654, 49.08967270169939, 48.88876553944179, 48.58653974533081, 44.884841782706125, 44.7658816746303, 45.23904357637678, 48.0182500566755, 43.40610531398228, 38.47825179781233, 39.53841488701956, 39.09996965953282, 37.314605712890625, 42.250876971653526, 39.07499783379691, 40.4058175768171, 37.558424949645996, 38.72795615877424, 43.54354068211147, 42.28412757601057, 44.72486993244716, 44.76087897164481, 45.55047573362078, 45.00545903614589, 41.56117793491909, 46.46610586983817, 53.48218488693237, 57.40022543498448, 58.91499873570034, 56.15590034212385, 48.19142001015799, 54.36556495938982, 56.66752052307129, 61.558072635105674, 60.799565587724956, 59.6365761075701, 63.79622636522566, 61.33976718357631, 64.55704716273716, 64.02735124315534, 66.49267632620675, 64.14109325408936, 64.00088555472237, 62.14687688010079, 62.05755083901541, 63.91308811732701, 67.15614591326032, 65.96480778285435, 73.36267989022392, 71.39447062356132, 75.5708451952253, 68.47785309382847, 74.0362035206386, 30.98459529876709, 0.642791856612478, 0.7784394206745284, 0.37894579448870247, 34.844368253435405, 85.75477818080357, 56.54162611280169, 61.86462715693882, 40.58370188304356, 57.54597084862845, 67.87627111162458, 52.8760518346514, 0.49031537558351246, 0.12853958404489926, 0.2223654386720487, 0.15718312561511993, 0.18913829805595533, 0.12184954088713441, 0.1014936463907361], [0.04770090324538095, 0.05514948070049286, 0.12183454526322228, 0.02927263852741037, 0.06365119200199842, 0.11462597921490669, 0.02763969311490655, 0.045907195923583846, 0.6679270735808781, 49.41312524250576, 50.335700103214805, 42.32334668295724, 27.021705865859985, 49.860200132642476, 45.253179686410085, 75.05492755344936, 14.425569381032672, 0.3520569716181074, 0.3241127282381058, 18.20301399912153, 74.73595660073417, 59.71409021105085, 68.45561191013881, 60.79677241189139, 67.03656741550991, 62.887818881443565, 66.81684453146798, 58.47816549028669, 58.8676050731114, 59.809329169137136, 65.06168787819999, 61.37947613852364, 59.34363310677664, 44.23054381779262, 55.82366875239781, 61.71162782396589, 58.55797249930245, 59.48177719116211, 56.94073758806501, 55.66430834361485, 55.338052204677034, 53.44776003701346, 51.122826780591694, 48.3857923916408, 41.49672991888863, 41.6669260433742, 40.74545594624111, 37.73915106909615, 40.27926656178066, 41.584749698638916, 41.22481911523001, 40.52947814123971, 43.61638559613909, 40.783448696136475, 38.86056252888271, 39.66080740519932, 36.889473233904155, 37.57937376839774, 36.503288882119314, 36.35136651992798, 37.22952849524361, 37.84814051219395, 37.36326047352382, 36.46429211752755, 37.123398235866, 36.42589637211391, 36.41689498083932, 38.1646865436009, 40.34515980311802, 40.54822438103812, 42.23223148073469, 42.886428696768625, 46.153648853302, 45.58430303846087, 42.837634972163606, 46.06059510367257, 45.954398836408345, 46.663240160260884, 47.27083580834525, 48.614791120801655, 45.3294118472508, 48.891228675842285, 47.58241735185896, 45.87671102796282, 46.49893610818045, 47.75776556559971, 43.5402055467878, 38.48993171964373, 25.521994522639684, 28.15342150415693, 38.8522698538644, 41.77538047518049, 47.13185794012887, 45.2023675101144, 45.560453346797395, 45.713212966918945, 46.77895893369402, 46.84251758030483, 46.1768593106951, 44.51587159293038, 47.56196185520717, 45.19817427226475, 47.82661526543753, 43.248051166534424, 43.571764264787944, 42.59989193507603, 42.0962552343096, 40.24811083929879, 38.57588441031319, 40.502303736550466, 37.83216660363333, 35.538281372615266, 34.05117579868862, 33.413511821201865, 34.11103800364903, 34.928566523960654, 33.63746615818569, 35.494667530059814, 33.77442210061209, 35.1214485168457, 34.59509468078613, 36.15284258978707, 38.94284657069615, 36.851536069597515, 39.78035116195679, 39.93506669998169, 42.053297996520996, 39.99912909099034, 40.665179933820454, 41.28477512087141, 43.474975858415874, 51.5742894581386, 54.309281076703755, 55.54499735151018, 56.40945747920445, 50.876169204711914, 53.857172216687886, 51.66155883244106, 53.303821155003135, 53.97214753287179, 53.668379238673616, 56.249655859810964, 57.61193009785244, 58.992207118443076, 58.561731474740164, 60.73161915370396, 64.06049415043422, 63.05160876682827, 64.09324101039341, 64.27240031106132, 63.429146085466655, 60.5452823638916, 63.13367394038609, 64.33102921077183, 68.24638775416783, 60.400579180036274, 55.40966728755406, 7.0562139834676465, 0.4924015722104481, 0.29082295883979115, 0.07578005295779024, 29.490326132093156, 65.57118538447789, 50.66500302723476, 46.00750044413975, 33.652529852730886, 40.48215396063668, 49.387927600315635, 41.80203376497541, 0.22494312535439218, 0.05963442754000425, 0.09683416677372796, 0.008001456269994378, 0.12692670630557196, 0.029662670634154762, 0.06244557098086391, 0.020577563405303017, 0.026877241974164332, 0.028095510888046453, 0.043838135698544126, 0.069956811144948, 0.03255692104409848, 0.007467069230707628, 0.08341070849980627, 0.7309608597840581, 57.589049679892405, 54.05986854008266, 45.722026756831575, 30.31891965866089, 56.37637710571289, 49.44256475993565, 82.28077616010393, 15.717070136751447, 0.44056499802640503, 0.14758811119411672, 17.909025294440134, 80.44026783534459, 63.46876471383231, 73.71108341217041, 63.184875215802876, 70.87912273406982, 63.49423680986677, 69.20451654706682, 59.74899101257324, 62.08047294616699, 62.32239532470703, 65.85175364358085, 61.61635412488665, 62.00042969839913, 48.1380752154759, 57.24735116958618, 61.95120171138218, 60.05070263998849, 61.90578828539167, 57.828845909663606, 56.903762749263215, 56.67149836676461, 54.89081750597273, 53.205191476004465, 49.7993095942906, 43.86227887017386, 43.56722709110805, 41.841565540858674, 40.44297306878226, 42.44500616618565, 42.68706750869751, 43.8485666002546, 43.630754470825195, 45.264275959559846, 42.29721450805664, 40.925000871930806, 42.742708683013916, 40.120920589991975, 39.89775834764753, 38.594272817884175, 38.52743114743914, 37.6029177393232, 39.18262890407017, 38.804723330906455, 38.6517448425293, 38.61141054970877, 37.05452421733311, 39.42458602360317, 40.69945887156895, 41.29295662471226, 41.425052302224294, 44.59107542037964, 45.715947083064485, 47.51086480276925, 48.08792311804635, 46.20822695323399, 47.521735259464805, 48.2479818207877, 48.086182594299316, 46.59580094473702, 51.15905816214425, 46.762071337018696, 52.21482651574271, 48.953210081372944, 48.38472931725638, 48.116810253688264, 49.720183508736746, 45.48690319061279, 41.034994329724995, 29.531407356262207, 31.87247780391148, 42.73431178501674, 44.25689486094883, 48.83375665119716, 46.79327917098999, 47.52562625067574, 46.70837218420846, 50.085519790649414, 50.30685813086373, 48.61989457266671, 47.82912009102957, 50.21139683042254, 47.57086597170149, 50.85306991849627, 45.232060636792866, 44.60198061806815, 45.81145702089582, 44.96233851569039, 42.1734219278608, 40.84827191489083, 42.912487915584016, 40.57313019888741, 37.502908842904226, 35.57080589021955, 36.40368298121861, 35.90812356131417, 36.446351868765696, 37.12545837674822, 37.76706198283604, 36.339561530521934, 37.0596068246024, 36.612872396196636, 38.50879260471889, 40.423469475337434, 40.22894423348563, 42.01649686268398, 42.06809071132115, 44.62691075461251, 42.45755461284092, 43.88805668694632, 44.56060756955828, 45.53121880122593, 53.597736903599326, 55.767662797655376, 56.859558309827534, 58.671999386378694, 54.7278162411281, 54.034351280757356, 54.1805031640189, 54.78073372159685, 55.26088203702654, 55.678472246442524, 59.193294933864046, 60.30422156197684, 61.86796924046108, 60.66556262969971, 62.58300140925816, 63.52423218318394, 64.11797659737724, 66.22146034240723, 65.78441170283726, 65.43112359728131, 64.69338471548897, 66.26783261980329, 66.40679659162248, 69.57311848231724, 63.50308881487165, 58.441930634634836, 7.4246304886681695, 0.4489499538072518, 0.11806893375303064, 0.10275312952165093, 35.05023642948696, 76.54837335859025, 56.47603164400373, 54.19932235990252, 42.272718633924214, 46.725186824798584, 58.403493200029644, 52.3995999608721, 0.5501888170838356, 0.09083126924399819, 0.0525859889707395, 0.08111498704446213, 0.0461828372042094, 0.012719318736344576, 0.1220245079270431, 0.07991046525005784, 0.13732513333005564, 0.16196831741503306, 0.15687336080840655, 0.12911576884133474, 0.17525152250060014, 0.17512858552592142, 0.1662463042885065, 1.3716777563095093, 72.80079991476876, 60.810342243739534, 53.76299633298601, 34.89975234440395, 68.01007257189069, 53.73217759813581, 90.32962499346051, 16.677887882505143, 0.814553117113454, 0.3530824008796896, 21.715099096298218, 81.5495685849871, 64.91763087681362, 75.98494393484933, 65.37068121773856, 72.72043704986572, 65.51893493107387, 71.42496626717704, 63.06361525399344, 62.0657844543457, 59.90642329624721, 67.98630278451103, 64.58274160112653, 63.829007966177805, 52.02822569438389, 59.12056119101388, 64.44800908224923, 63.23752866472517, 64.06544821602958, 60.57623658861433, 58.86973122188023, 60.212595667157856, 57.78169890812465, 55.86169624328613, 53.12363352094378, 46.14497750146048, 46.554997648511616, 44.44508334568569, 41.957975660051616, 46.28911440713065, 44.97403233391898, 46.24888433728899, 44.84546981539045, 47.62698309762137, 44.42260939734322, 43.810028416769846, 44.81779861450195, 41.481297969818115, 42.67025981630598, 41.04183483123779, 40.40171813964844, 39.31519358498709, 42.421198163713726, 41.20774391719273, 42.447361605507986, 41.258368492126465, 40.651589257376536, 41.386062485831125, 43.64836468015398, 44.75984369005476, 45.885684626443044, 47.08185870306832, 47.61214174543108, 50.65557779584612, 50.964150769369944, 47.9480767250061, 49.8966121673584, 50.04106869016375, 51.1387277330671, 49.76832757677351, 53.853527886526926, 49.27685022354126, 54.63273361751011, 51.392378670828684, 50.74378865105765, 50.09727266856602, 54.22737571171352, 47.65312222072056, 45.644602979932515, 35.414742401668, 37.45486899784633, 44.96180350439889, 46.491025584084646, 49.02398790631975, 49.52188886914934, 49.73827314376831, 50.349627767290386, 53.10495676313128, 52.90819072723389, 51.337463583265034, 51.54425934382847, 53.9062751361302, 50.0092111996242, 53.17709296090262, 47.698316778455464, 49.03168303625924, 48.66645792552403, 47.32583427429199, 45.48223747525896, 43.661514145987375, 45.89144120897566, 41.95647484915597, 38.9754753112793, 38.018003123147146, 39.642134121486116, 39.114244733537944, 39.81943130493164, 38.122757639203755, 41.18116010938372, 38.725232464926584, 39.455390862056184, 39.30267293112618, 41.13331828798567, 43.320597308022634, 42.92165953772408, 44.88293102809361, 43.286554609026226, 46.96480934960501, 44.10698052815029, 45.35182326180594, 46.89142942428589, 48.09202602931431, 57.17003856386457, 57.015899726322715, 60.31713826315743, 60.229563168116975, 57.4323330606733, 56.82884727205549, 55.756573472704204, 58.37860475267683, 59.52471705845424, 58.540817396981375, 61.996316364833284, 62.291441099984304, 65.45440006256104, 64.06020927429199, 66.06520925249372, 67.80209214346749, 67.79906967708042, 68.87615162985665, 68.50156034742082, 69.17491027287075, 68.4047372000558, 69.94209562029157, 69.17354147774833, 75.20912892477853, 66.73894827706474, 65.84427738189697, 11.058029396193367, 0.576570910002504, 0.468228137918881, 0.29615236286606106, 38.58854750224522, 86.05658708299909, 63.728377205984934, 66.36010469709123, 49.554552350725444, 62.353175844464985, 69.5145034790039, 66.03715937478202, 1.0144806376525333, 0.20230715642017977, 0.1316545618964093, 0.15845484951777117, 0.10657130035438708, 0.08188309547092233, 0.17349696664937905], [0.003010169636192066, 0.07778261335832731, 0.025410123734868, 0.02400032983028463, 0.03981582082009741, 0.11287411036235945, 0.05595630633511713, 0.04861939538802419, 0.03125748237861054, 36.02542304992676, 46.47190761566162, 37.611564772469656, 32.01851504189627, 49.83747952325003, 40.889704023088726, 70.06258433205741, 23.340963670185634, 0.12474692612886429, 0.412735535630158, 5.886636308261326, 72.14273602621896, 60.026752199445454, 68.35127081189836, 60.34352057320731, 64.05989660535539, 64.99176815577916, 68.29512241908482, 64.54314381735665, 66.31314877101353, 61.82658576965332, 58.88652501787458, 56.34042712620327, 57.121734687260215, 58.93155629294259, 55.341210160936626, 54.63111121313912, 58.96372645241873, 56.09130641392299, 56.07342522484915, 52.451235498700825, 52.57017476218087, 46.488145555768696, 45.01335913794381, 41.10632106236049, 39.31517274039132, 39.5907313483102, 40.79199150630406, 38.53267356327602, 40.819044317517964, 40.85769019808088, 40.0290584564209, 39.25684608731951, 44.43733263015747, 40.97451720918928, 41.46174921308245, 38.11479500361851, 38.65806770324707, 35.911198139190674, 36.978646414620535, 35.5148937361581, 37.66729627336775, 35.63148103441511, 35.945490973336355, 36.72440487997872, 37.83322620391846, 38.357752663748606, 38.43257434027535, 38.99740035193307, 40.27857174192156, 41.52075678961617, 42.556076594761436, 40.157759938921245, 41.444319656917024, 40.890673296792166, 43.28751346043178, 42.44556202207293, 44.5273118019104, 44.0506306375776, 45.17888259887695, 46.92782061440604, 45.40733936854771, 43.23072583334786, 47.70562628337315, 46.27354349408831, 44.873425892421174, 45.03208800724575, 45.399418422154014, 37.40500177655901, 19.498340606689453, 20.012931142534526, 35.27456596919468, 42.18393802642822, 43.28028038569859, 43.241870743887766, 44.66001544679914, 47.0104763848441, 47.02543585641043, 46.2545679637364, 44.32145752225603, 45.27305848257882, 45.37054865700858, 43.85373953410557, 43.34774739401681, 42.63993787765503, 40.5978136743818, 42.676044191632954, 41.99292162486485, 39.76149722508022, 38.523380347660606, 36.39917707443237, 34.84490326472691, 33.74184199741909, 35.31215572357178, 35.51057890483311, 33.8247583253043, 36.037769998822895, 37.02581426075527, 35.76975366047451, 34.73174490247454, 34.51219572339739, 35.514647075108115, 36.55715479169573, 39.96579163415091, 37.81372261047363, 39.397303921835764, 38.966692788260325, 40.05200488226754, 38.48828847067696, 41.54689938681466, 39.985527992248535, 41.12374019622803, 44.44255072729928, 49.8468839100429, 51.766111850738525, 56.07690279824393, 56.49829714638846, 53.874949182782856, 53.90918295724051, 52.77047395706177, 50.5905704498291, 49.80715411049979, 51.21844441550118, 52.51872682571411, 53.65927015032087, 55.50179345267159, 56.99823045730591, 56.249638489314485, 59.47647571563721, 61.36123711722237, 59.026704924447195, 54.056946822575156, 57.875492640904014, 57.623634338378906, 61.96854441506522, 64.10695675441197, 66.74631336757115, 45.463004861559185, 0.8928055209772927, 0.25525884862457004, 0.09941646749419825, 0.09935964697173663, 37.05305814743042, 67.16228117261613, 46.90226861408779, 41.90408543178013, 34.267334256853374, 33.614686489105225, 50.85640157972063, 35.386081082480295, 0.18834127725235053, 0.05807672826839345, 0.08317218987005097, 0.0513261937137161, 0.025930426083505154, 0.03964001918211579, 0.041931218201560636, 0.03391367556261165, 0.04632268327155283, 0.013839257747999259, 0.041534899467868466, 0.07399938029370137, 0.11374513219509806, 0.022706728262294616, 0.01142827354903732, 0.17162575705775193, 44.668266432625906, 53.62798588616507, 34.272069454193115, 32.19673980985369, 58.45748765127999, 46.678606101444785, 79.00450597490583, 24.965313536780222, 0.08735024889132806, 0.4069146551191807, 5.521323910781315, 72.19216551099504, 62.463381222316194, 71.27032715933663, 63.40707860674177, 67.77013737814767, 65.20257650102887, 70.79499394553048, 66.0300235748291, 67.79628344944545, 62.30858925410679, 63.35504354749407, 59.66618932996477, 59.01270430428641, 60.68159907204764, 59.724665369306294, 56.99850491115025, 60.01675374167306, 57.56972326551165, 57.97349003383091, 56.085768699645996, 54.371286800929475, 48.49380908693586, 46.387445313589915, 42.81816611971174, 42.03000068664551, 42.19470426014492, 43.418330669403076, 41.390752519880024, 43.41505806786673, 42.208944593157085, 42.050852230616975, 42.53813634599958, 45.064199107033865, 43.62007508959089, 43.910812037331716, 41.23248297827584, 40.9422150339399, 37.947180134909495, 39.84172807421003, 38.1368624823434, 40.33674553462437, 39.05075209481375, 38.87561927522932, 38.61941140038626, 40.732650416237966, 40.98388685498919, 39.19495848246983, 40.86399916240147, 41.85977676936558, 44.68847874232701, 45.16087286812918, 42.54220799037388, 44.567489760262625, 43.999530111040386, 45.25834914616176, 44.64191191537039, 46.27717740195138, 45.02749177387783, 48.320600918361116, 48.739420958927695, 47.09021043777466, 45.7369966506958, 49.77750614711216, 47.29694019045149, 49.00864975793021, 47.66856459208897, 48.793839250292095, 42.112190927777974, 21.266924653734478, 22.91182902881077, 38.28339999062674, 46.58959967749459, 44.57225622449602, 47.19255740301949, 48.59336287634713, 49.60459327697754, 49.31861931937081, 47.38928174972534, 45.322244780404226, 47.320734296526226, 45.80321993146624, 45.93781001227242, 47.65620722089495, 44.70589787619454, 43.44041551862444, 43.87213488987514, 45.29480634416853, 41.98955174854824, 41.884185791015625, 37.57834890910557, 36.89307240077427, 35.3271221433367, 37.88613326208932, 37.444234779902864, 37.629734311785015, 37.621108123234336, 39.714662892477854, 36.57029036113194, 36.93529312951224, 38.41034705298287, 36.765037945338655, 40.24542188644409, 41.710762228284565, 40.06313937050955, 43.020449025290354, 42.58113874707903, 42.861001764025005, 40.34357908793858, 42.13894844055176, 42.41789429528372, 43.34078529902867, 46.594571113586426, 52.58215345655169, 54.98736619949341, 57.430443150656565, 59.66623796735491, 56.58513920647757, 54.48591123308454, 55.47116231918335, 54.003035749707905, 54.24578148978097, 52.458927154541016, 55.03234536307198, 56.47832107543945, 58.783768108912874, 58.87760353088379, 58.92388548169817, 61.945295742579866, 63.61252294267927, 62.43822874341692, 56.95630850110735, 60.824613843645366, 61.30813203539167, 65.5210610798427, 66.96033178056989, 69.89925997597831, 49.4177041053772, 0.6554941407271794, 0.24684938415884972, 0.13405953427510603, 0.14459495751985482, 42.41650812966483, 74.49020576477051, 54.271934509277344, 52.29910469055176, 37.37947756903512, 41.07852826799665, 59.93730803898403, 42.44785145350865, 0.610515085714204, 0.09038795517491442, 0.09658889672053711, 0.05518130738554256, 0.031608240878475566, 0.013553382462954946, 0.05165484893534865, 0.10286038555204868, 0.18580746464431286, 0.14843585927571568, 0.18066376208194665, 0.2276324581887041, 0.18855904628123554, 0.1789317335933447, 0.23900657785790308, 0.3569557230387415, 59.51414884839739, 58.01557527269636, 48.36433288029262, 41.09522131511143, 66.02413845062256, 48.9935930115836, 85.9794064930507, 26.37182174410139, 0.19710501842200756, 0.7265438682266644, 7.667946849550519, 79.54878616333008, 63.10359518868582, 73.94836439405168, 65.97722421373639, 71.17231587001255, 67.67547512054443, 72.99775355202812, 64.53010204860142, 67.75777653285435, 66.12859766823905, 64.64756829398019, 59.796773774283274, 59.98488235473633, 62.61492143358503, 62.29212202344622, 58.54984310695103, 64.78739384242466, 60.83031136648995, 60.044581277029856, 58.006455762045725, 59.02335589272635, 51.825991426195415, 49.10466691425869, 45.6453012738909, 44.57987492425101, 45.87103087561471, 46.327468463352744, 45.49774238041469, 45.66623272214617, 43.06639051437378, 45.10726751599993, 43.68993575232369, 48.257083960941856, 45.192372526441304, 44.8553466796875, 41.843274797712056, 45.39024332591465, 40.00490651811872, 41.75629377365112, 39.70169060570853, 43.0194137437003, 40.90425355093819, 41.07747561591012, 40.527883529663086, 41.978504112788606, 44.4837327003479, 41.1084645816258, 44.39455951963152, 44.067083971840994, 48.316623074667795, 49.138400418417795, 44.63551957266671, 47.58533559526716, 48.618855816977366, 47.06976536342076, 46.94400644302368, 48.614652156829834, 47.56955623626709, 50.443473611559185, 51.348431314740864, 47.79751968383789, 48.4329810823713, 51.96122768947056, 50.01962654931204, 51.2148244040353, 52.15657976695469, 51.1372720854623, 45.57988051005772, 27.86486976487296, 30.535911900656565, 43.04726559775216, 48.730384826660156, 47.5183549608503, 49.31697954450335, 50.37393604006086, 51.6670618057251, 52.59380211148943, 50.49625212805611, 46.93532814298357, 48.089705330984934, 47.68415634972708, 48.11915527071272, 49.35642099380493, 47.290926524571006, 45.749725750514436, 47.261462688446045, 46.710282938820974, 45.07804339272635, 44.26684468133109, 40.59938744136265, 37.52784940174648, 38.217555386679514, 40.06897585732596, 40.108528477805, 38.703863280160085, 40.51553658076695, 43.02626119341169, 39.528676986694336, 39.77325357709612, 40.81595931734358, 39.94415841783796, 42.26337678091866, 44.95366021565029, 41.75319835117885, 45.347352096012656, 43.78302424294608, 45.72599765232631, 42.258655479976106, 45.612401553562705, 45.32467317581177, 45.800600460597444, 50.41170644760132, 54.88667637961251, 56.95848328726632, 60.57011522565569, 62.15501322065081, 58.55013493129185, 58.989122118268696, 58.415173121861045, 57.391717365809846, 55.581735951559885, 55.89322369439261, 57.37527445384434, 59.36139270237514, 60.97433362688337, 62.627254486083984, 61.85389219011579, 63.967075620378765, 68.53780909946987, 65.24403640202114, 58.797386578151155, 63.51160035814558, 64.37525449480329, 67.87806374686105, 70.9234105518886, 73.75068814413888, 55.93628862925938, 1.7511270237820489, 0.5183808324592454, 0.3993479311466217, 0.17782874777913094, 48.83649771554129, 84.05950805119106, 60.208913121904644, 61.14920588902065, 47.320914949689595, 49.92154230390276, 73.21983187539237, 57.15868868146624, 1.0124808592455727, 0.2462564802595547, 0.19013814654733452, 0.17295438290706702, 0.109898802159088, 0.05830900437597718, 0.20587375360940183], [0.05493396780054484, 0.04650590129728828, 0.0868513153067657, 0.09253380181533949, 0.058026625242616446, 0.11566537272717271, 0.035719603300094604, 0.15944070661706583, 0.07379934138485364, 36.254557268960134, 48.83967304229736, 47.98892865862165, 32.11377484457833, 42.593232086726594, 45.69659982408796, 65.68799155099052, 31.59378903252738, 0.06325156201741525, 0.9207381478377751, 0.39797560764210566, 39.82466329847063, 65.61338874271938, 65.49645056043352, 65.80372074672154, 67.19798101697648, 61.98374707358224, 63.768662861415315, 59.96159199305943, 60.38584899902344, 61.143105370657786, 61.85741492680141, 56.14288289206368, 59.03919083731515, 55.27753339494978, 54.953483309064595, 54.69481577192034, 53.26267739704677, 54.37854766845703, 52.04061780657087, 49.168406214032856, 45.0529464994158, 41.7959679876055, 40.63189458847046, 41.2806270463126, 38.89961487906319, 39.709149496895925, 39.425499711717876, 39.38040937696184, 41.31761230741228, 41.151331492832725, 43.6261373928615, 46.00732673917498, 46.92372465133667, 46.459115982055664, 44.53885623386928, 40.37900447845459, 39.36051321029663, 39.26770612171718, 40.45184939248221, 36.050870827266145, 37.460166999271934, 37.25536189760481, 36.841624464307515, 38.84108672823225, 38.693409715379985, 38.852676323481965, 39.593031202043804, 39.09275048119681, 37.8475638117109, 39.384835379464285, 40.80346993037632, 40.54314177376883, 39.35832452774048, 41.69568811144148, 41.045069217681885, 41.393959113529746, 40.84672246660505, 45.18231848308018, 45.76211091450283, 43.56832143238613, 42.307303292410715, 44.54930632455008, 42.30206782477242, 43.5537371635437, 43.5701835496085, 47.32218647003174, 48.57744107927595, 29.015897921153478, 19.225696768079484, 18.01670847620283, 24.070925780705043, 44.392874581473215, 45.5370830808367, 43.47099454062325, 45.16908911296299, 44.733360631125315, 45.54234981536865, 42.04389360972813, 41.50868429456438, 39.749848570142476, 41.9572217805045, 42.496676445007324, 42.29961163657052, 38.184113706861226, 37.81238160814558, 38.17925344194685, 38.73742307935442, 39.37423242841448, 38.481757164001465, 36.78594160079956, 36.99266440527779, 34.94885873794556, 35.520608629499165, 36.512894766671316, 36.375622681209016, 34.790505817958284, 33.76206125531878, 35.301896708352224, 34.80558688299996, 35.38881172452654, 37.13083628245762, 39.18963616234915, 38.01482432229178, 38.60312482288906, 39.92174352918352, 40.294069698878694, 40.522213799612864, 40.9750383240836, 39.27170828410557, 40.556669916425435, 41.2207544190543, 40.61936003821236, 44.18464749200003, 50.402048451559885, 52.74135753086635, 53.89315693719046, 54.57334041595459, 53.329359258924214, 53.4456547328404, 52.44798721585955, 50.869756017412456, 49.38560342788696, 49.82870742252895, 48.486648968287874, 50.41396113804409, 49.9610983984811, 51.04290165219988, 51.89608137948172, 53.257045882088796, 53.508751324244905, 51.51755394254412, 50.62805250712803, 58.06451838357108, 61.388689449855256, 63.61195319039481, 66.67747061593192, 54.674061502729145, 0.1484115541513477, 0.2301214060613087, 0.18177218974700995, 0.3226675029311861, 43.40200935091291, 60.89539514269148, 49.27596780232021, 44.88420254843575, 25.302322013037546, 40.79035520553589, 44.0327980858939, 30.3119923046657, 1.0855435558727808, 0.013162821947064782, 0.08420686756393739, 0.02863616928724306, 0.05527765257284045, 0.02573105553165078, 0.05344746720844081, 0.07431174388953618, 0.10287012931491647, 0.0558117885541703, 0.05688960750454238, 0.014748202902930123, 0.05422515994203942, 0.05364398791321686, 0.12386674407337393, 0.0752853670024446, 46.40557663781302, 55.410334314618794, 48.2916373525347, 41.02195256096976, 53.14645140511649, 46.99000351769583, 72.96602807726178, 34.14714779172625, 0.006652744087789739, 1.0850326461451394, 0.23819651561123983, 37.96528366633824, 68.75991521562848, 68.27644566127232, 67.1927490234375, 67.3120287486485, 63.21575995853969, 66.08761024475098, 64.10067558288574, 63.00113705226353, 62.774806431361604, 62.004980768476216, 57.749646868024556, 58.90612588609968, 56.60883951187134, 55.57931450435093, 56.57353918892996, 55.03746965953282, 56.43264709200178, 53.76029348373413, 49.72823647090367, 46.68580790928432, 43.182786737169536, 44.109231744493755, 42.86038684844971, 41.68131228855678, 41.933768136160715, 43.21925435747419, 42.95684174128941, 43.27047995158604, 43.65554564339774, 45.233627455575125, 49.487186091286794, 50.1232658794948, 50.18402787617275, 45.00263111931937, 42.427670410701204, 42.23141854149954, 41.116656507764546, 42.46333203996931, 39.82880095073155, 40.69981322969709, 38.35497685841152, 38.44624144690377, 40.44103799547468, 40.90101221629551, 41.54604475838797, 40.31331968307495, 40.809355054582866, 38.76621641431536, 41.669170311519075, 43.301441124507356, 42.7185845375061, 42.240201064518516, 43.25384943825858, 41.93254177910941, 43.32898725782122, 43.269250120435444, 46.53520223072597, 45.44000979832241, 45.930371965680806, 44.3150234903608, 47.08713238579886, 44.94132021495274, 45.60624892371041, 44.9222091947283, 48.4447409084865, 48.99278007234846, 29.44995709827968, 20.211130244391306, 20.450445311410085, 24.699614422661917, 44.82912070410592, 49.053753989083425, 45.61316238130842, 47.546595914023264, 46.01754406520298, 46.82806532723563, 44.14684929166521, 43.448735986437114, 42.836321762629915, 43.68704877580915, 43.117511885506765, 44.39411136082241, 40.50347450801304, 41.5105881009783, 40.433693749564036, 40.98691974367414, 40.840740067618235, 41.044853823525564, 39.00833681651524, 39.70274673189436, 37.3413736479623, 37.933433123997276, 39.15995345796858, 38.410548550742014, 36.71543822969709, 35.319003173283164, 37.242625849587576, 38.6369833946228, 38.551114082336426, 38.99131025586809, 41.79587418692452, 40.47626883643014, 41.01274619783674, 43.0348665373666, 41.479342051914756, 41.48718656812395, 41.61963312966483, 41.454012393951416, 41.087317739214214, 44.70719371523176, 42.966697760990684, 46.156257901872905, 53.94025877543858, 54.18798289980207, 56.06174530301775, 56.04404476710728, 55.92985807146345, 56.34933819089617, 53.94022750854492, 53.787669386182515, 52.95195395605904, 50.15368856702532, 51.13125147138323, 51.94304425375802, 53.72690738950457, 53.23144177028111, 53.709213801792686, 54.255033016204834, 55.586981841496055, 53.52903311593192, 53.85745014463152, 61.68111828395298, 64.95223290579659, 66.9844559260777, 68.3862897327968, 59.31966182163784, 0.4514023150716509, 0.26853072217532564, 0.24222942920667784, 0.5819994615656989, 48.3011668069022, 69.6101940699986, 56.70070859364101, 52.73715387071882, 30.155101980481827, 45.437359060559956, 53.909797872815815, 41.165995665958945, 1.3222940862178802, 0.025184556642281156, 0.05674019070076091, 0.0807620741959129, 0.059499717982751985, 0.04481359764135309, 0.0561355481456433, 0.11489243991672993, 0.16060937462108477, 0.17707534320652485, 0.18225612092231, 0.13803124401186193, 0.17482682743242808, 0.0951930076948234, 0.3536099482859884, 0.25282423783625874, 58.37794467381069, 61.958038738795686, 64.01894392286027, 43.9222001348223, 58.81904411315918, 55.122737952641074, 78.8419667652675, 37.23997858592442, 0.2072189628545727, 1.8780177405902316, 0.6996301295501846, 45.814580236162456, 72.70420605795724, 71.38962078094482, 70.49398408617292, 70.70183944702148, 64.51421151842389, 67.78464521680559, 65.98115689413888, 67.23076261792863, 65.92585618155343, 63.911740166800364, 59.48357677459717, 63.690405300685335, 61.00265448434012, 57.90716600418091, 58.268944808415, 59.078302247183665, 59.90200424194336, 56.3782114301409, 53.62910802023751, 50.34678247996739, 45.485430172511506, 47.124277455466135, 46.120252336774556, 43.92517743791853, 43.905861445835654, 44.186210836683, 44.25124250139509, 45.805061204092844, 46.595418793814524, 49.18191351209368, 50.339716162000386, 52.428518363407676, 51.925385407039094, 47.697201592581614, 44.90171200888497, 44.67977959769112, 42.614431040627615, 45.993965353284565, 42.741242613111226, 42.34110975265503, 41.359888621738975, 40.237507888248985, 43.581401416233604, 42.79585892813546, 43.31369079862322, 43.47845343181065, 42.16488606589181, 41.161878858293804, 44.75892652784075, 45.745292799813406, 45.52998897007534, 44.99792718887329, 45.724840777260916, 44.30278771264212, 44.15843888691494, 43.86244910103934, 48.816882950919016, 48.499589988163535, 47.81218385696411, 46.28539364678519, 49.12441022055489, 46.73678684234619, 47.94780227116176, 48.23805979319981, 51.398802280426025, 50.90450743266514, 29.88564041682652, 23.017957551138743, 21.068418094090053, 25.449528285435267, 47.42535332271031, 49.9009165763855, 49.42660822187151, 50.344962051936555, 48.71877438681466, 50.87384850638253, 46.58299888883318, 44.64428472518921, 45.551424162728445, 45.82946327754429, 44.834880760737825, 46.64869063241141, 43.664376803806846, 43.863449641636436, 42.8100471496582, 43.708709784916465, 44.82024438040597, 43.31650481905256, 41.42322492599487, 41.726041316986084, 39.82270390646798, 40.865565981183735, 41.43738882882254, 40.47926351002285, 39.513797419411794, 38.5377596446446, 39.368243081229075, 40.98624576841082, 41.0771872656686, 41.26154381888253, 43.971848487854004, 42.67163903372628, 43.57114240101406, 45.31814534323556, 45.12484993253435, 44.64022697721209, 45.26589141573225, 43.28762115750994, 44.17978375298636, 47.078176157815115, 44.80431910923549, 49.07113838195801, 56.10893399374825, 58.499211583818706, 59.33910982949393, 59.367395945957725, 58.65480954306466, 59.01144668034145, 57.50186020987374, 55.61574043546404, 56.232069969177246, 54.45194843837193, 53.488309723990305, 54.40565259116036, 55.3816625731332, 56.22652530670166, 57.51769862856184, 57.55260985238211, 58.261388642447336, 56.46777023587908, 57.2075240952628, 65.12568773542131, 69.88644054957798, 70.01999882289341, 72.63228525434221, 62.347610337393625, 0.7163764823760305, 0.36323024492178646, 0.5848323181271553, 0.6725045793822834, 56.9604218346732, 78.06556115831647, 62.5874274117606, 63.89154870169503, 36.03855514526367, 59.607372828892295, 66.22057792118618, 54.5526556287493, 1.737519736800875, 0.07804065344056912, 0.17296586371958256, 0.11186803970485926, 0.2172903088586671, 0.14032702653535775, 0.1737596139843975], [0.06174942797848156, 0.13678530443991932, 0.06779103593102523, 0.06093262109373297, 0.08097835723310709, 0.09700933058879205, 0.02954202371516398, 0.05158014562247055, 0.22631232759782247, 33.836653641292024, 50.997456959315706, 35.669730867658345, 20.178287846701487, 38.47170659473964, 51.310014724731445, 63.29947880336216, 42.48952327455793, 0.029402557627430985, 0.5698362056698117, 0.1295577394110816, 7.549255984170096, 50.6579714502607, 62.44922079358782, 63.79302324567522, 64.16818428039551, 63.35324396405901, 60.99254485539028, 58.20821755273001, 58.977185113089426, 56.459491457257954, 55.204744066510884, 53.693969454084126, 52.07199239730835, 53.89746134621756, 50.5619786126273, 52.819392749241416, 51.11919982092721, 48.13196080071585, 43.41980716160366, 42.1025641986302, 41.09707995823452, 39.43350403649466, 39.40336969920567, 37.67837865012032, 41.02741037096296, 40.696967942374094, 39.36611693246024, 40.24097156524658, 39.73638643537249, 43.84493269239153, 47.564261708940776, 49.35426357814244, 52.29215996606009, 53.18329075404576, 50.16200903483799, 44.75087703977312, 40.10945953641619, 39.42146975653512, 40.28746543611799, 40.03121587208339, 37.11021750313895, 36.737839221954346, 34.869569369724815, 36.70584624154227, 37.595219135284424, 39.16280916758946, 40.78201041902815, 42.49466494151524, 38.262298311506, 36.574490547180176, 40.262625626155305, 38.62483099528721, 39.17324536187308, 39.749640124184744, 41.08751923697335, 42.52797113146101, 43.541744572775706, 44.2981984274728, 45.56339243480137, 45.05791793550764, 43.95706272125244, 42.73560414995466, 42.33132321493966, 43.05457510266985, 44.70067630495344, 51.503000940595356, 42.61585889543806, 24.10925899233137, 20.00837138720921, 22.1968263898577, 19.69714593887329, 30.205236707414898, 52.731744698115754, 46.45783403941563, 44.79974372046334, 42.89085817337036, 42.40068013327462, 43.65524339675903, 41.5745393208095, 42.30647645677839, 40.26197944368635, 40.89931685583932, 39.8183091708592, 37.3861026763916, 37.40758303233555, 37.93562528065273, 38.538756711142405, 37.24350132261004, 37.61253752027239, 38.059584617614746, 37.00982298169817, 37.80830996377127, 36.26195362636021, 35.93351227896554, 33.66975096293858, 36.23389680044991, 33.14034686769758, 36.03141587121146, 34.36391421726772, 38.16205317633492, 38.365385259900776, 39.44450650896345, 38.47826222011021, 41.40489557811192, 39.838257449013845, 40.169054235730854, 39.58564874104091, 39.11824689592634, 38.120680127825054, 36.9538448197501, 40.87567908423287, 41.63208777563912, 40.57995680400303, 45.79109879902431, 48.8242758342198, 54.75918735776629, 53.059393950871055, 56.03336191177368, 54.70848287854876, 53.55912923812866, 54.42397151674543, 52.13928917476109, 54.29403672899519, 51.1553304536002, 51.81821639197213, 50.646107401166645, 51.098945822034565, 47.73175845827375, 48.575499057769775, 46.14167710712978, 48.49510840007237, 48.611230169023784, 56.79313005719866, 59.98722389766148, 65.26164313725063, 61.4888060433524, 70.29457773481096, 2.1246837845870425, 0.1467624833541257, 0.11289758088865451, 1.1541560398680824, 51.418594224112375, 56.60458026613508, 46.70951516287667, 41.99689252035958, 18.638124091284617, 29.91379451751709, 43.214025838034495, 25.25703886577061, 1.8003399201801844, 0.09793950710445642, 0.21580829338303634, 0.04119859715657575, 0.048445941481207094, 0.04889805954215782, 0.01776678128434079, 0.12473560816475324, 0.05436872098860996, 0.05978655509118523, 0.14158351054149015, 0.05368129037586706, 0.14119443856179714, 0.0504816754588059, 0.04936268300350223, 0.14890383130737714, 41.22836964470999, 55.78981018066406, 42.04287917273385, 25.203129529953003, 45.80172954286848, 55.99331944329398, 68.2594781603132, 47.000304222106934, 0.015434507147542067, 0.4534505137375423, 0.11551940627396107, 6.591022099767413, 51.491897719247, 63.42683233533587, 64.35563278198242, 64.01030731201172, 64.78004264831543, 63.68301241738455, 61.18040330069405, 61.236940792628694, 59.49149077279227, 57.60402652195522, 55.227450779506135, 55.07323898587908, 56.77316093444824, 54.37437874930245, 55.43946811131069, 53.030298369271414, 51.962037154606406, 45.75576720918928, 44.7028615134103, 43.19052355630057, 42.411182335444856, 41.828885078430176, 41.549727303641184, 44.1776819229126, 42.3022450038365, 43.31264509473528, 42.2644259589059, 41.2457331929888, 45.34971795763288, 51.6569104875837, 51.80500091825213, 53.254273550851, 54.86743681771414, 52.887193271092, 46.73512969698225, 44.64040068217686, 41.86336898803711, 42.2482123374939, 41.801616873059956, 38.00163664136614, 39.229101930345806, 37.36482034410749, 38.36849110467093, 39.52226727349417, 40.63231495448521, 42.30123404094151, 43.581265926361084, 40.432748794555664, 38.58404506955828, 42.686761787959504, 41.86696120670864, 39.98740747996739, 43.17254856654576, 44.51646218981062, 45.10877874919346, 45.157506465911865, 46.206517696380615, 47.139323779514854, 47.11770445959908, 45.47031784057617, 44.464854444776265, 43.38597985676357, 45.85663768223354, 46.22671958378383, 55.09069980893816, 43.641277517591206, 23.832960401262554, 20.64043164253235, 22.71332594326564, 20.13144482885088, 30.440558297293528, 55.17702770233154, 49.536459241594585, 45.700744424547466, 44.051565170288086, 45.53998395374843, 45.19976888384138, 44.66797113418579, 44.22977604184832, 42.924511773245676, 43.81046615328108, 43.15828044073922, 40.7765873500279, 41.52890007836478, 41.227101598467144, 40.24131897517613, 41.28889887673514, 39.293536049979075, 38.68465845925467, 37.34533412115914, 39.433389391217915, 39.872421741485596, 39.19796357836042, 37.14935670580183, 37.884528228214805, 35.482994556427, 38.627766609191895, 36.64782878330776, 40.56357642582485, 39.86921167373657, 41.75229508536202, 41.441140856061665, 42.44437040601458, 43.377350194113596, 41.510615893772666, 42.261914185115266, 41.043867179325645, 40.8487582887922, 40.320681299482075, 43.55746834618704, 43.7336607660566, 43.10444927215576, 46.03604711805071, 51.88538462775094, 56.170849391392295, 54.45065259933472, 57.06242833818708, 58.192761284964426, 56.76597997120449, 56.39262546811785, 54.3144713810512, 55.86045598983765, 54.229685987745015, 55.75547218322754, 52.484017099652974, 52.37455170495169, 48.49959346226284, 50.575256620134624, 48.48434911455427, 50.389826570238384, 51.276586941310335, 59.45468616485596, 60.918914794921875, 69.56790038517543, 64.66971220288957, 74.86991786956787, 2.497228605406625, 0.2996868517782007, 0.018991228259567703, 1.3023914056164878, 60.57688971928188, 64.44188771929059, 52.524354866572786, 49.919047900608604, 31.70093720299857, 40.98624576841082, 55.76906285967146, 34.406364236559185, 1.9126642814704349, 0.13854636065661907, 0.2139351296105555, 0.010758014961278864, 0.05527897910880191, 0.044557406567037106, 0.021313197145770704, 0.2417349943092891, 0.2473754659295082, 0.12350830116442271, 0.15883602334984712, 0.15731383860111237, 0.3486141392162868, 0.18025707533316954, 0.133042735978961, 0.3478891924023628, 55.889676639011924, 65.72811739785331, 46.744586195264546, 25.86388237135751, 52.31519671848842, 66.10698182242257, 75.42060429709298, 52.072058405194966, 0.0902567400730082, 1.2144116865737098, 0.20625457460326807, 9.68514004775456, 56.35190902437483, 66.06074850899833, 66.55508504595075, 68.6272463117327, 68.58168697357178, 64.83502374376569, 63.528831890651155, 62.321429525102886, 62.32375717163086, 59.683351380484446, 57.6040369442531, 58.34846346718924, 58.60339287349156, 57.85498850686209, 57.96671206610543, 56.0667063168117, 54.979935101100374, 47.74605785097395, 46.860801764896934, 44.24318953922817, 46.586288860866, 43.56101540156773, 43.079783167157856, 47.45054401670183, 45.93130997249058, 44.662353515625, 43.43398148672921, 43.05191394260952, 48.965480600084575, 53.48055900846209, 55.034766810280935, 56.77478333881923, 57.34250327519008, 54.59109306335449, 47.98107372011457, 46.083781242370605, 43.927650996616904, 43.988878522600444, 45.42698540006365, 41.08034174782889, 42.54115881238665, 39.718487875802175, 41.78544841493879, 42.95613302503313, 43.42706455503191, 44.66989231109619, 46.108999729156494, 43.577083110809326, 39.06529467446463, 44.480022362300325, 44.5093263898577, 43.36360318320138, 45.5315523147583, 48.11529554639544, 47.537789072309224, 48.88636493682861, 49.54985884257725, 49.91418416159493, 50.17982074192592, 48.500062465667725, 46.47246694564819, 46.51215853009905, 48.144012451171875, 50.425842557634624, 57.85894203186035, 45.498378140585764, 24.77435098375593, 20.721897533961705, 23.51302538599287, 19.625364099230083, 31.75429241997855, 56.48684998920986, 51.93164920806885, 49.07868412562779, 45.67565447943551, 47.6490922655378, 47.4832352910723, 46.911877972739084, 48.42806870596749, 45.07320744650704, 45.978957244328086, 47.10905047825405, 42.626573017665315, 43.08486924852644, 43.221776553562705, 43.83188744953701, 44.76892498561314, 42.86058487210955, 43.057100772857666, 41.610253061567036, 42.067993436540874, 42.19078547613961, 42.3080050604684, 38.34562458310808, 42.37898785727364, 37.058679240090505, 42.17813628060477, 38.96323605946132, 45.05808816637312, 41.69388852800642, 44.48115839276995, 45.129216875348774, 45.45558418546404, 45.68814039230347, 44.37849528448922, 44.82011931283133, 44.20770856312343, 43.71445941925049, 41.763248920440674, 45.917833941323416, 45.96340717588152, 45.16490282331194, 48.678169114249094, 54.81674970899309, 59.22754260471889, 58.17947285515921, 60.199783188956125, 60.14612225123814, 59.89746012006487, 59.83435658046177, 54.9896764755249, 58.356933321271626, 56.73417806625366, 58.50623621259417, 54.5717180115836, 55.83469901766096, 51.69782148088728, 53.0722724369594, 52.368954930986675, 54.891303879874094, 54.28998940331595, 62.68161719185965, 64.36182362692696, 73.28816740853446, 69.98307609558105, 78.95864786420549, 3.1494117123740057, 0.40120432153344154, 0.3323813559753554, 1.6442122693572725, 68.33082921164376, 71.95043768201555, 62.493258476257324, 60.24660015106201, 30.625196252550396, 49.284100668770925, 68.8160149710519, 47.00130476270403, 2.4335891859872, 0.3196583901132856, 0.3510771941925798, 0.10685181351644651, 0.12448992420520101, 0.15376214204089983, 0.10623879783919879], [0.05751752720347472, 0.07310247913535152, 0.04534933157265186, 0.05871198632355247, 0.046121864047433646, 0.06068954949400254, 0.02387981692196003, 0.10106378088572196, 0.04726568749174476, 25.981548377445765, 45.39169202532087, 45.60696111406599, 34.79736368996756, 32.995987619672505, 45.4572309085301, 56.25660753250122, 55.44374472754342, 1.39164622766631, 0.09418571567428963, 0.32904774057013647, 0.5967564582824707, 26.18214634486607, 65.07810647147042, 59.826623235430034, 61.38589627402169, 55.52395820617676, 57.177653789520264, 53.013459409986226, 50.548561641148154, 47.53616666793823, 50.076799801417756, 51.27621521268572, 52.45992422103882, 48.13680716923305, 49.3213985988072, 47.64746986116682, 43.98953512736729, 43.494229316711426, 40.445199966430664, 40.090178285326274, 41.34123270852225, 39.97072485515049, 38.16200106484549, 39.32244750431606, 38.49609129769461, 40.91547836576189, 39.46139063153948, 39.801282610212056, 42.477485520499094, 47.55508313860212, 50.631443228040425, 50.79589319229126, 53.530766691480366, 54.58996050698416, 55.11699874060494, 49.085211958204, 41.64611618859427, 39.68217658996582, 40.69328192302159, 41.420372690473286, 38.032323360443115, 38.9204421043396, 34.4436308997018, 37.7977625983102, 35.58059590203421, 37.83001266207014, 38.26302787235805, 39.18467167445591, 36.469683919634136, 37.26416873931885, 40.332600934164866, 40.193053313664024, 38.246230602264404, 43.56804003034319, 42.38641548156738, 42.429153851100374, 41.62537234170096, 47.00975724628994, 45.453822817121235, 43.65891899381365, 41.1595755304609, 45.0386505808149, 44.48000846590315, 46.515969617026194, 48.53896542957851, 50.13439341953823, 44.87714665276663, 30.129483972276958, 26.83004675592695, 39.73829024178641, 31.95413998195103, 29.566016333443777, 47.20509195327759, 46.381581033979145, 44.40943561281477, 42.08953980037144, 41.411683968135286, 43.89039822987148, 42.85668693270002, 40.10540526253836, 43.566448892865864, 42.03893607003348, 39.82825551714216, 37.414499964032856, 40.82919910975865, 39.405579226357595, 36.78551428658621, 38.820061479296, 35.54405879974365, 36.55268710000174, 38.54658038275582, 37.86757114955357, 35.474413531167166, 35.89721141542707, 34.89622960771833, 33.57023538861956, 36.04754958833967, 36.87832137516567, 35.68530525479998, 39.47030169623238, 39.07005419049944, 39.13243859154837, 38.503126348767964, 41.09014218194144, 45.91535690852574, 45.40811061859131, 46.53684547969273, 40.866080147879465, 37.71404722758702, 38.016835825783865, 38.48063850402832, 41.53274590628487, 40.033873558044434, 38.99814033508301, 43.775245734623496, 51.13847064971924, 54.16604743685041, 54.56470727920532, 55.64215401240757, 56.77579082761492, 55.60655491692679, 56.49596949986049, 56.35625859669277, 56.86222989218575, 58.79173769269671, 55.97363519668579, 52.357841287340435, 50.08780574798584, 49.544307231903076, 48.99268627166748, 48.00135898590088, 48.51348638534546, 54.55152307237898, 54.36967134475708, 65.6159109388079, 57.19811276027134, 74.63421412876674, 4.291495365755899, 0.2532633314175265, 0.03432358196005225, 2.0355507731437683, 55.242337294987266, 57.70537642070225, 50.2114246232169, 37.8310409954616, 23.768468958990915, 33.09557267597744, 47.63942732129778, 24.591173887252808, 2.1427395471504758, 0.019551106163167527, 0.06885907719177858, 0.02188970085366496, 0.08717132599226066, 0.02628171384068472, 0.05059161509520241, 0.059187788649329116, 0.050541922583111694, 0.028500621739242758, 0.08058619791907923, 0.03083803577880774, 0.06785753914820296, 0.04124913105208959, 0.10634627100080252, 0.024099063460848162, 34.14068596703665, 53.737117767333984, 47.825194358825684, 29.502454212733678, 36.83933850697109, 51.54637507029942, 61.503647395542686, 60.11509159633091, 1.3910595391477858, 0.037178029505802054, 0.3410881273448467, 0.4661314647112574, 28.01566651889256, 66.34328310830253, 63.43535082680838, 63.595006534031455, 58.2439660344805, 58.67764132363455, 55.71789632524763, 52.96946341650826, 49.775432109832764, 50.565438815525596, 52.92935494014195, 53.254756450653076, 51.28233310154506, 50.80688871656145, 50.18019594464983, 47.149409089769634, 45.18874904087612, 43.050461769104004, 42.58591563361031, 44.51814365386963, 40.398792948041645, 40.93900844029018, 42.48207480566842, 40.64112874439785, 43.81339829308646, 40.94082539422171, 42.89949478421892, 47.060065678187776, 49.072371687207905, 53.196065017155235, 53.64436626434326, 55.66032702582223, 56.560410567692344, 57.38152435847691, 51.96359702519008, 43.85394450596401, 42.495477880750386, 42.996370043073384, 43.76912784576416, 40.83720690863473, 39.99595723833357, 35.98640544073922, 38.41351890563965, 35.96816989353725, 39.728468963078086, 40.40803405216762, 41.584371021815706, 39.16913897650582, 39.482294287000386, 43.93177822657994, 42.80373123713902, 40.94084971291678, 44.707266671316965, 43.02715751102993, 43.87633507592337, 44.19583756583077, 49.41426822117397, 47.66489594323294, 45.819499560764854, 42.68686948503767, 47.06560339246477, 46.36743450164795, 48.13220051356724, 50.46091706412179, 52.60030215127127, 47.19982521874564, 30.254082543509348, 27.934862443378993, 41.77788530077253, 32.42529385430472, 29.05121214049203, 49.472726890019004, 47.771960735321045, 46.946400097438264, 45.50306470053536, 44.14104754584176, 46.30484512874058, 43.533160073416575, 41.691244738442556, 45.021075112479075, 42.73020192555019, 39.857319831848145, 41.073153836386545, 42.96754196711949, 40.233495303562705, 39.35287366594587, 41.29196650641305, 38.55716943740845, 37.2841135433742, 40.73575973510742, 40.622792448316304, 37.05938795634678, 36.75982679639544, 36.70682941164289, 36.36941793986729, 37.84593793324062, 41.30075250353132, 38.67293337413243, 41.040316649845664, 40.89976154054914, 41.458170890808105, 41.2471923146929, 42.93085895265852, 49.61396639687674, 48.06506701878139, 48.29831804547991, 43.466961111341206, 41.22931807381766, 41.57716226577759, 41.44558422906058, 42.37478419712612, 42.76461635317121, 42.36512967518398, 47.55934933253697, 52.013307912009104, 55.720626967293875, 54.72717005865914, 59.44400678362165, 58.83744989122663, 58.32768835340227, 59.69216864449637, 60.70526463644845, 59.472237314496724, 59.92850467136928, 58.51461574009487, 56.26487241472517, 53.62871544701712, 52.846893719264436, 51.86208036967686, 51.99708734239851, 51.264875752585276, 57.38264649254935, 56.862566879817415, 67.97113486698696, 60.371570450919016, 77.8678571156093, 4.9111800108637125, 0.31040583231619423, 0.06179621296801737, 2.376697770186833, 64.64666502816337, 61.65421485900879, 58.01280641555786, 44.300140448978965, 31.90026365007673, 48.51140192576817, 59.99948746817452, 36.61130905151367, 2.675169800009046, 0.06051131191530398, 0.05771792573588235, 0.012289655095498477, 0.06752532161772251, 0.01613321840497, 0.05769174785486289, 0.23117506237966673, 0.13877455198339053, 0.15199702818478855, 0.1423628894346101, 0.24244172924331256, 0.15017421171069145, 0.13002117882881845, 0.18089364974626473, 0.18979700628135884, 46.093189103262766, 65.81214891161237, 54.15634427751814, 44.13438422339303, 47.31243119921003, 59.689660344805034, 66.99451691763741, 68.05940478188651, 1.569395695413862, 0.2232148288083928, 0.4273363878684384, 0.7570676846163613, 33.364092758723665, 69.67254720415387, 65.24054145812988, 66.20374243600028, 60.745112555367605, 61.243812561035156, 59.555657386779785, 55.31521347590855, 51.653356484004426, 55.14690031324114, 56.05652025767735, 56.21711049761091, 54.20283120019095, 53.54348189490182, 52.74943481172834, 48.08209705352783, 49.24710498537336, 45.405946254730225, 43.95841414587838, 46.725186824798584, 44.194392340523855, 43.1627550806318, 44.95660277775356, 44.0010552406311, 46.950843470437185, 43.54023681368147, 42.97310400009155, 48.3305333682469, 50.811109747205464, 54.35270731789725, 54.10315234320504, 58.8418550491333, 57.74471017292568, 59.11684390476772, 53.64757980619158, 47.90347276415144, 44.27786799839565, 46.01674502236502, 45.673389366694856, 42.49183007649013, 44.723883288247244, 38.33237436839512, 42.87342514310564, 37.933648518153596, 43.46698890413557, 43.78770732879639, 44.31387703759329, 40.377507141658235, 43.40769297736031, 45.65831524985177, 44.313494886670796, 41.94618804114205, 48.95979002543858, 47.174158573150635, 47.53547184807913, 46.145505564553396, 51.214143480573384, 50.71415458406721, 49.75350706917899, 43.869494574410574, 50.617206369127544, 48.90711573192051, 49.71195684160505, 53.03260169710432, 55.398800304957796, 48.56596612930298, 31.175726345607213, 28.420581477028982, 40.883846691676546, 31.80064732687814, 30.830866404942103, 52.22047540119716, 50.47502538136074, 51.018346718379426, 48.03186852591378, 46.27912637165615, 50.20707852499825, 47.034819398607524, 44.482482024601524, 48.709828581128804, 46.30764525277274, 42.86703280040196, 42.625603743961875, 45.336436476026265, 44.45912912913731, 42.1576703616551, 44.4672064099993, 40.49100596564156, 40.04910748345511, 42.777404512677876, 42.40850727898734, 40.33812822614397, 40.420297622680664, 40.28572491237095, 38.57437317711966, 42.137753350394114, 42.74311167853219, 41.41723905290876, 42.30602134977068, 42.539227213178364, 43.69514690126692, 42.51188952582223, 45.76532098225185, 51.02056319372994, 48.987648827689036, 50.49422672816685, 44.89802598953247, 42.348453998565674, 44.11615909848894, 43.441919803619385, 45.85810375213623, 44.158727237156455, 43.49367693492344, 48.39872646331787, 57.60786887577602, 59.91797120230538, 59.8387200491769, 61.80868026188442, 60.90641498565674, 61.89597742898123, 63.12865039280483, 61.195369720458984, 62.562247140066965, 62.515048027038574, 61.465779713221956, 58.673013823372976, 56.36469370978219, 55.238265650612966, 55.54908289228167, 54.59125634602138, 54.49598959514073, 62.847818102155415, 61.40687983376639, 73.6689008985247, 64.05184364318848, 81.86996391841343, 5.903083997113364, 0.6391182137387139, 0.2347537646336215, 2.7931337101118903, 71.00024373190743, 71.85035582951137, 65.97332627432687, 53.00938081741333, 34.632177216666086, 51.367306096213206, 71.48035035814557, 47.49532515662057, 3.2600192172186713, 0.1344911911125694, 0.19001814084393637, 0.15526052378118038, 0.19437373855284282, 0.15066936585519994, 0.08379074917840106], [0.03523194696754217, 0.055641445730413706, 0.03000256578837122, 0.023856192028948238, 0.06232395714947155, 0.07907604359622512, 0.20955146769327776, 0.14723041467368603, 0.22757824324071407, 18.558589799063547, 39.98283903939383, 40.605866636548726, 42.69177143914359, 34.076192787715364, 43.849018233163015, 54.20465162822178, 67.34841646466936, 7.85529807635716, 0.49019812473228996, 0.556288195507867, 0.32294741219707895, 10.73051302773612, 65.23019559042794, 57.91897446768624, 56.18830326625279, 52.72820806503296, 50.10138947623116, 49.03038372312273, 49.88520669937134, 47.27736711502075, 43.92652538844517, 46.59287575313023, 44.6928700038365, 45.115101609911235, 41.92107030323574, 41.302840437207905, 40.9816460609436, 40.47219719205584, 39.526231220790315, 38.7379025050572, 37.09033523287092, 38.31598009381975, 41.19100570678711, 39.19262388774327, 40.51728752681187, 39.9294490814209, 40.90435082571847, 45.63950647626604, 47.077790532793315, 48.615159375326975, 53.80762113843645, 51.133064951215474, 54.26891551698957, 55.36624452045986, 54.142972469329834, 46.94537871224539, 41.953935282570974, 40.86069181987217, 42.42635372706822, 44.26363808768136, 40.993624755314414, 40.08691610608782, 39.06629521506173, 38.19346250806536, 35.7008171081543, 38.81411729540144, 38.068613801683696, 36.47434616088867, 37.46548931939261, 37.308807441166465, 38.47582687650408, 41.91593558447701, 40.25181770324707, 40.249361515045166, 38.84541893005371, 42.643391132354736, 44.14041525976998, 45.074350425175254, 46.80020652498518, 42.89876174926758, 44.48302398409162, 46.89054352896554, 47.71403012956892, 45.940161977495464, 49.64001519339425, 46.141350541796, 46.77301474979946, 34.722069535936626, 31.479025636400493, 37.53424869264875, 37.4090074130467, 36.30787774494716, 45.534762382507324, 47.92543254579817, 44.197300161634175, 45.19312988008772, 44.135798181806294, 42.2106225831168, 40.66504791804722, 42.39471857888358, 39.856555530003135, 41.766980103084016, 39.60109111240932, 43.40271806716919, 41.05941377367292, 39.47869164603097, 40.44842740467617, 38.337606361934114, 38.38402727672032, 38.92614310128348, 37.50962427684239, 36.1177785055978, 34.4550051007952, 35.73926496505737, 34.59970828465053, 35.753751959119526, 36.65501322065081, 37.48996434892927, 38.29507643835885, 41.19251693998064, 37.799822739192415, 37.86575072152274, 39.06946359361921, 45.59777559552874, 49.48005029133388, 50.83660268783569, 51.78269025257656, 50.91550990513393, 44.52494594029018, 39.14466742106846, 39.10737991333008, 39.87357861655099, 38.33316993713379, 40.95462451662336, 42.32654980250767, 46.92332165581839, 50.22370556422642, 52.096231188092915, 55.22444568361555, 54.57316323689052, 55.44874743052891, 56.60619224820818, 57.43611635480608, 57.92263616834368, 56.359701429094585, 57.38927159990583, 57.08901562009539, 55.20828764779227, 58.302153723580496, 54.578541142599924, 51.936283656529014, 50.51961197171892, 54.20369972501482, 51.8821884563991, 63.77540956224714, 58.7493119921003, 76.81109864371163, 5.774917960166931, 0.2461788287120206, 0.0968147199600935, 2.2113210899489264, 59.2155430657523, 55.03197710854666, 55.24667297090803, 34.31646496909005, 33.54409973961966, 29.16516433443342, 40.221130984170095, 36.71474340983799, 0.5795527185712541, 0.04243568523920008, 0.0955700831753867, 0.03156913351267576, 0.0618209998522486, 0.012918367832233863, 0.017886844663215534, 0.02254422421434096, 0.053918285694505484, 0.03568588010966778, 0.06731840236378567, 0.04497629676812461, 0.14975850044616631, 0.10005830055368797, 0.09960589411535434, 0.14991957108889306, 29.05768265042986, 50.69992119925362, 41.84428228650774, 36.40464530672346, 40.44962249483381, 50.42426184245518, 59.178856577192036, 75.37608024052211, 9.368574908801488, 0.5375921673008374, 0.6964500801903861, 0.37241912899272783, 12.579167246818542, 68.4078916822161, 61.635003089904785, 58.71760736192976, 56.63796636036464, 53.34901571273804, 50.575833320617676, 52.6028208732605, 49.87260614122663, 46.325773102896555, 49.28523669924055, 46.057325976235525, 47.35561077935355, 45.44164262499128, 42.981379304613384, 42.589434896196636, 42.44659035546439, 42.08500262669155, 41.30566487993513, 42.00827019555228, 41.3850793157305, 43.395881039755686, 42.28307492392403, 40.881126471928184, 41.78834581375122, 43.59528391701834, 47.37578139986311, 48.56737661361694, 51.925916944231304, 56.14246947424752, 53.44218063354492, 54.50454977580479, 55.59312057495117, 54.621588706970215, 49.830830097198486, 44.651465688432964, 44.38728475570679, 44.7455130304609, 46.558193819863455, 43.311748777117046, 40.325197628566194, 40.17726353236607, 39.19528504780361, 38.494962215423584, 41.79652731759207, 39.04112883976528, 38.51776967729841, 40.53038835525513, 39.20273004259382, 41.039125033787315, 43.64775323867798, 40.68732731682913, 43.401804379054475, 39.74135787146432, 45.12975883483887, 46.41984476361956, 46.442353452954976, 47.448820863451274, 46.43051719665527, 45.85029397691999, 48.33636290686471, 48.04119300842285, 49.93456322806222, 51.73979207447597, 48.0693610055106, 49.70500864301409, 35.73912600108555, 34.08705282211304, 37.33833728517805, 36.15971088409424, 36.54742383956909, 47.74710355486189, 48.60947227478027, 46.505721024104524, 46.12885768072945, 46.91174595696585, 45.23429100854056, 42.342141560145784, 43.06971870149885, 44.05552911758423, 43.968197209494456, 42.92584582737514, 44.28185279028756, 43.52257101876395, 42.59965222222464, 42.05166516985212, 40.78302485602242, 40.73742730276925, 40.478606905256, 39.5933438709804, 38.822663579668315, 36.473988328661235, 38.47918633052281, 37.272252968379426, 38.24520574297224, 39.16458443232945, 40.04125254494803, 42.501786845070974, 44.42763294492449, 41.04839393070766, 40.948562213352744, 40.83297198159354, 48.5268269266401, 52.2127594266619, 52.43110656738281, 55.35359879902431, 54.109075682503835, 47.86012295314244, 41.372478757585796, 42.22443560191563, 41.80083867481777, 41.018735545022146, 43.1419243812561, 43.37024218695504, 47.51326193128313, 53.23975876399449, 53.77242503847395, 56.0813843863351, 60.0322482245309, 58.78674193790981, 59.66643251691546, 59.266897201538086, 60.614604541233604, 60.79666818891253, 61.055731773376465, 59.77774960654122, 58.278092111860005, 60.75263050624302, 55.74824605669294, 55.402865001133506, 52.944908482687815, 57.047635623386924, 54.525220666612896, 66.0387852532523, 61.33648763384138, 81.35497733524868, 6.6018673692430765, 0.24066109050597462, 0.03203788585960865, 2.446502847330911, 66.46791294642857, 62.699286460876465, 63.31486906324114, 44.22692033222744, 30.39614541190011, 38.341688428606304, 49.54184756960188, 45.67721782411848, 0.9441901636975152, 0.09077870313610349, 0.01213292368421597, 0.08095145331961767, 0.06595743753548179, 0.00397801459933232, 0.0662877212411591, 0.11164021478699786, 0.07371404274765934, 0.10689772998115846, 0.16145955185805047, 0.1610170520309891, 0.2276555419500385, 0.35601660343153135, 0.14232425365064824, 0.25260067411831444, 41.599577154432026, 60.61456285204206, 54.054459367479595, 54.137681416102815, 47.45754085268293, 60.2807297025408, 64.33315535954067, 82.94605922698975, 10.108698759760175, 0.7123885420816285, 1.0748905560800006, 0.5925385217581476, 16.41536930629185, 73.0171251296997, 64.15705326625279, 61.0743807383946, 59.661784172058105, 54.91851997375488, 53.0821076120649, 54.72026007516043, 50.930260930742534, 48.25542334147862, 52.381791727883474, 48.433432715279714, 49.52110024860927, 47.845698492867605, 46.64333357129778, 45.391632965632844, 46.787897791181294, 44.776192801339285, 44.03032800129482, 43.36110530580793, 43.70335619790213, 46.846352985927034, 43.89198589324951, 44.21135636738369, 44.02988679068429, 45.29833950315203, 50.717673846653526, 53.59541967936924, 54.89074107578823, 56.84430006572178, 55.3320837020874, 56.288784640175955, 59.37861728668213, 56.37509516307286, 51.48026296070644, 47.44459635870797, 46.12357357570103, 47.15118088041033, 49.14156532287598, 44.962901319776265, 44.345956870487754, 43.37149633680071, 41.19504608426775, 39.980914388384136, 44.5566714150565, 41.97899396078927, 40.87171513693673, 42.04750667299543, 41.11408567428589, 44.41954524176461, 47.07816573551723, 43.26406676428658, 44.53726509639195, 41.824955872126985, 47.68421540941511, 50.09210320881435, 49.08448239735195, 52.585519858769004, 48.619060788835796, 49.02547134671892, 50.22973312650408, 51.71628284454346, 53.503856318337576, 54.7082188470023, 49.15050418036324, 51.20704242161342, 36.38183784484863, 32.40104464122227, 38.17893729891096, 37.192442485264365, 37.528596333095, 49.55392353875296, 53.14593376432146, 50.1876027243478, 47.155697209494456, 48.12765291758946, 47.986733027866904, 44.745057923453196, 46.38673659733364, 45.683054310934885, 47.70526845114571, 45.82665620531355, 48.568321568625315, 45.44049269812447, 46.17593172618321, 45.88148096629551, 43.25242853164673, 43.083948612213135, 41.99585029057094, 40.95946046284267, 41.12180512292044, 37.65884378978184, 41.2891629082816, 39.506029333387104, 41.04185220173427, 41.40703214917864, 42.32146372113909, 44.07336514336722, 44.63619007383074, 43.2128689629691, 43.26624155044556, 43.770076274871826, 50.21645164489746, 54.131028515951975, 54.99665246691023, 57.78935234887259, 55.83892352240426, 50.72627919060843, 42.918842043195454, 45.75819213049752, 45.52465622765677, 43.951886313302175, 47.106337206704275, 45.216812814985005, 50.87665210451399, 54.533753054482595, 56.29860591888428, 60.77888774871826, 61.19404261452811, 60.33540507725307, 63.31630039215088, 60.782097816467285, 63.750354358128135, 65.2467461994716, 63.21347400120327, 62.416529519217356, 61.41507870810372, 64.64527538844517, 58.310067721775596, 58.80074255807059, 56.13958249773298, 60.67584596361433, 58.24339975629534, 71.15356963021415, 65.18397617340088, 87.71394784109933, 7.114270959581647, 0.44446665580783573, 0.21398850317512239, 2.969322438750948, 75.2659443446568, 66.61429759434291, 71.66852147238595, 52.12128291811262, 44.72227130617414, 45.70084864752633, 63.01682608468192, 54.65387698582241, 1.5409776717424393, 0.21127725365970815, 0.2707930664931025, 0.1659459439771516, 0.18256530218890735, 0.12614455898957594, 0.25918113387056757], [0.12872253065662725, 0.05384766037708946, 0.059470554547650475, 0.09682923382414238, 0.03559112608698862, 0.0187607468771083, 0.029958437263433422, 0.08399830625525542, 0.3384135865739414, 14.337876166616168, 38.28526905604771, 37.418220724378315, 26.8956846509661, 42.04157985959734, 40.96415744509016, 43.82995237622942, 68.42655454363141, 21.209223338535853, 0.44374360889196396, 0.594245932996273, 0.18736008847398417, 3.814723006316594, 62.89197390420096, 63.279183115277974, 60.60197966439383, 56.65264790398734, 56.03992795944214, 53.47502129418509, 52.26999173845564, 50.109247888837544, 46.120849881853374, 45.64963347571236, 44.36124638148716, 41.64957986559187, 40.31471627099173, 39.50352103369576, 40.893258026668, 38.467874663216726, 38.07610048566546, 40.37652049745832, 39.77008172443935, 40.92571653638567, 37.23360013961792, 40.94578640801566, 40.617046288081575, 40.47226667404175, 41.6607004574367, 44.18311888831002, 48.066175256456646, 50.88485792704991, 52.75141157422747, 48.921696526663645, 57.07850994382586, 51.75240305491856, 52.98284217289516, 48.62727008547102, 45.06410183225359, 42.35495751244681, 40.12766381672451, 49.053462164742605, 45.39895984104702, 41.644500732421875, 41.588699749537874, 39.60476323536464, 39.14303806849888, 37.26195921216692, 39.04832369940621, 38.062422956739155, 37.14070272445679, 37.42493963241577, 35.72435760498047, 38.60541425432478, 40.63505949292864, 39.093191691807334, 38.27879680906023, 40.04361145836966, 41.862757546561106, 43.124870027814595, 42.45315292903355, 42.23743915557861, 43.700417109898154, 45.54077952248709, 47.17323793683733, 47.845236437661306, 51.26729025159563, 47.71601036616734, 48.65850223813738, 39.1751526423863, 30.295532022203716, 36.70830937794277, 36.72753504344395, 39.5082562310355, 46.939069747924805, 49.11614881243025, 46.295440741947715, 47.596536091395784, 45.435007095336914, 45.14904703412737, 41.0480499948774, 41.67163692201887, 42.67627695628575, 43.578066280909944, 40.50257819039481, 40.141938890729634, 38.335233552115305, 41.022317341395784, 39.70479645047869, 40.23914418901716, 37.72611277444022, 36.75407716206142, 34.06566626685006, 36.33897788184029, 35.84389788763863, 36.640811102730886, 36.40732731137957, 36.25193779809134, 38.68392195020403, 38.06246812002999, 42.70131826400757, 43.91439035960606, 38.887757778167725, 38.111036028180806, 42.82168885639736, 48.13529941013881, 53.08666215624128, 50.11907958984375, 52.40792737688337, 53.077952589307515, 48.503616469247, 46.27096571241106, 39.48929807118007, 37.81016860689436, 40.03891795022147, 39.51975549970354, 39.67240047454834, 41.140158789498464, 45.18409374782017, 48.79644135066441, 52.80967569351196, 55.58132948194231, 59.28020995003836, 56.07240383965628, 56.93510259900774, 55.90639747892107, 58.05456856318882, 57.59782525471279, 61.402287074497764, 58.5073687689645, 60.44440146854946, 58.02763387135097, 60.41992991311209, 52.35693107332502, 57.59482363292149, 50.80636065346854, 62.35105664389474, 57.34220102855137, 75.659163747515, 4.760087089879172, 0.16793059105319635, 0.20043627252536161, 5.449205083506448, 68.63429178510393, 53.1685015133449, 53.02080018179757, 33.30320569447109, 45.40975734165737, 44.17591708047049, 52.663555077144075, 41.84510564804077, 1.5237554758787155, 0.10160879378340074, 0.0250393213105521, 0.04931788272889597, 0.05135305691510439, 0.04681033281875508, 0.05915468292576926, 0.06801311365727868, 0.05642184242606163, 0.00894382012276245, 0.0637173695223672, 0.08331654140991823, 0.03879764509786453, 0.07462040946951934, 0.11301553063094616, 0.372249250965459, 24.685209069933208, 50.76739515577044, 38.797184535435264, 30.197930676596506, 45.76549468721662, 47.26095199584961, 50.407176222120015, 75.68932587759835, 24.708016531808035, 0.39802858765636173, 0.4960366742951529, 0.2333883350448949, 4.942357012203761, 65.92284066336495, 66.5608103615897, 62.245471818106516, 59.33642087663923, 57.69885901042393, 54.45078114100865, 54.63727426528931, 51.3417124067034, 48.31088038853237, 48.11737305777413, 46.96431950160435, 44.865400723048616, 43.68221630368914, 42.98637158530099, 44.206311975206646, 40.89000974382673, 40.50733770642962, 42.69281019483294, 43.23270954404558, 41.552308559417725, 40.10712841578892, 43.48869160243443, 41.26440300260271, 43.86304317201887, 43.278494698660715, 46.39859369822911, 49.92324113845825, 52.50724492754255, 53.905635901859824, 48.88784837722778, 55.878479616982595, 55.40021078927176, 55.01294946670532, 51.247741494859966, 47.95164462498256, 44.366262980869834, 41.86639492852347, 50.022930417742046, 47.28945003237043, 45.22721079417637, 43.71305935723441, 41.783770424979075, 39.509656293051584, 38.24320813587734, 39.53730664934431, 40.497353145054404, 38.5794939994812, 38.64166995457241, 37.88087000165667, 41.247699533190044, 41.7726081439427, 40.98617628642491, 40.59939786366054, 42.776271956307546, 42.56434842518398, 44.988317830221995, 45.06884397779192, 45.27166884286063, 44.90211500440325, 48.88420752116612, 48.045139585222515, 49.3362330027989, 51.37198918206351, 50.08939341136387, 50.1048253604344, 39.353769983564106, 30.655219418661936, 38.60749176570347, 35.561373710632324, 41.80563293184553, 47.736038548605784, 48.9257264818464, 48.50883804048811, 49.24008730479649, 47.22723586218697, 47.704146317073274, 43.054151262555806, 43.68212250300816, 45.59737260001046, 45.836043221609934, 43.97872373035976, 41.98518827983311, 41.24844993863787, 43.049982343401226, 41.054105349949424, 41.93085336685181, 40.743479183741975, 38.19681848798479, 37.28404753548758, 38.07681615012032, 39.03993027550833, 39.160783767700195, 38.39906317847115, 38.02104990822928, 41.72747611999512, 40.817672048296245, 46.31641040529524, 47.99341024671282, 42.5092214175633, 41.83644124439785, 45.67056144986834, 51.54973799841744, 55.68703242710659, 51.07512044906616, 55.15047516141619, 55.02540063858032, 53.48136847359793, 49.94364104952131, 42.44856711796352, 39.25130142484392, 41.148972579411094, 41.58248805999756, 43.09276587622506, 43.891037464141846, 47.32307236535208, 49.80710199901036, 55.24534586497715, 56.98507751737322, 60.72357313973563, 59.19467067718506, 58.67106137956892, 58.81278378622872, 60.58278179168701, 60.5096242087228, 64.04308891296387, 62.278760637555806, 65.2442101069859, 61.238948822021484, 63.07888739449637, 56.004533835819785, 61.49648380279541, 52.605235372270855, 66.38609095982143, 60.45607444218227, 80.24931049346924, 4.752936525004251, 0.09407691258404936, 0.2631000264414719, 6.314092091151646, 75.74023532867432, 61.59561375209263, 62.747590337480815, 43.008727414267405, 37.11275359562465, 43.819425855364116, 62.546023096357075, 51.551638330732075, 3.440003616469247, 0.11562901682087354, 0.12737434942807468, 0.06125342566519976, 0.0818988714101059, 0.07384896943611757, 0.09424002561718225, 0.2657496514064925, 0.1138398963958025, 0.15096475929021835, 0.15054366045764514, 0.09345104545354843, 0.18305050901004247, 0.16111724451184273, 0.13205442258289882, 0.43429226747580935, 39.27419226510184, 62.61898612976074, 51.94097021647862, 39.52448722294399, 57.259222166878835, 54.831504208701, 57.224046911512104, 81.05721923283168, 25.93895765713283, 0.8308689530406679, 1.055830670254571, 0.3159086698932307, 7.139872031552451, 70.29972634996686, 69.12153421129499, 66.40713010515485, 61.890842710222515, 59.74368953704834, 58.61466979980469, 58.23763969966343, 55.86700814110892, 51.11479466302054, 51.11552422387259, 49.72804886954171, 47.22689192635672, 45.417257922036306, 44.81696135657174, 47.26971020017351, 42.54156528200422, 44.52675594602312, 47.81851019178118, 45.66777522223336, 45.20191240310669, 42.455154010227744, 45.271189417157856, 44.95098515919277, 45.06023168563843, 44.960278374808176, 47.828487804957796, 52.39223139626639, 53.929200717381065, 56.069551604134695, 51.117226532527376, 56.76596260070801, 57.6790566444397, 55.381999560764854, 52.68297529220581, 49.228303159986226, 45.401992729731965, 43.50858082090105, 52.471711839948384, 48.80280590057373, 47.77178703035627, 46.81409249986921, 44.185147762298584, 42.280691691807334, 41.48074211393084, 43.578222615378245, 41.507450989314485, 40.69752379826137, 40.13228089468819, 40.14541646412441, 43.010655539376394, 44.501099722726, 43.548922061920166, 43.055169173649375, 45.45087330681937, 46.06923866271973, 47.72767986570086, 47.60261923926217, 48.73138536725725, 48.65527827399117, 52.0404406275068, 50.3573819569179, 50.965224266052246, 54.615276268550325, 53.16143866947719, 52.20241008486067, 40.77221693311419, 31.23342071260725, 39.85527358736311, 37.850951058524, 40.700723443712505, 49.188264165605815, 53.36775847843715, 52.15260192326137, 52.73653548104422, 49.23035635266985, 49.2971841267177, 47.38111414228167, 46.92669153213501, 47.94252511433193, 47.87707655770438, 47.175513471875874, 45.149411814553396, 44.40784794943673, 46.40325941358294, 44.45297997338431, 45.151405947549, 42.554603576660156, 41.611882414136616, 38.349366188049316, 40.54504905428205, 41.0566622870309, 41.11106320789882, 40.88899878093174, 40.63472597939627, 42.94996302468436, 43.71997628893171, 48.421711104256765, 49.95470258167812, 44.20932054519653, 44.28476408549717, 47.976050172533306, 53.056135245731895, 56.43564176559448, 53.88025413240705, 58.05594778060913, 57.8320038659232, 55.71517263139997, 50.76013428824288, 44.58540569032942, 42.249153818402974, 44.21581016268049, 44.28653587613787, 43.78706809452602, 46.47926575796944, 49.78644153050014, 53.57492944172451, 58.2807046345302, 59.891102518354145, 64.63030896868024, 61.590479033333914, 61.64023508344378, 60.28569071633475, 63.31410476139614, 62.80403750283377, 66.92525032588414, 64.92132037026542, 67.55015046255929, 64.29107012067522, 66.41099330357143, 57.23832198551723, 64.38259874071393, 55.79707104819161, 70.83414704459054, 62.52601228441511, 84.65517711639404, 5.962908855506352, 0.3189232652740819, 0.37019179708191324, 7.178043697561536, 83.4337602342878, 65.26053142547607, 67.64451394762311, 49.093098163604736, 58.283914702279226, 60.80080931527274, 69.98148495810372, 64.3326689856393, 4.846696385315486, 0.222446225051369, 0.1604667737015656, 0.1972728201321193, 0.21117204001971654, 0.15855065866240434, 0.2999356569988387], [0.056493485546005626, 0.03005841261308108, 0.03363425823460732, 0.07151871054832425, 0.07140644692948886, 0.055626497603952885, 0.03940991438659174, 0.18789911669279846, 0.9188723393848964, 22.230288914271764, 39.19441999707903, 39.074052878788535, 19.900113242013113, 39.09373017719814, 39.86023112705776, 42.93781409944807, 67.59483432769775, 30.513976437704905, 0.04822486798678126, 0.05823991594037839, 0.12088013147669179, 0.4519800197865282, 47.128588812691824, 66.78387532915387, 58.27884946550642, 60.91619804927281, 53.239876883370535, 54.24127210889544, 53.94007812227522, 52.62311308724539, 47.046732085091726, 45.37877879823957, 44.05656092507498, 42.376236370631624, 39.153821672712056, 39.90006167548043, 39.90798609597342, 39.965822901044575, 39.90278884342739, 38.30892767224993, 37.44746221814837, 40.00867591585432, 38.68043048041207, 41.865526403699604, 43.39377920968192, 40.368460587092805, 40.39761175428118, 46.13879360471453, 47.237536566598074, 50.251140526362825, 48.82504708426339, 53.03558247429984, 62.97345542907715, 50.61219324384417, 52.288772719247, 49.31927245003836, 46.50513737542288, 44.06049707957676, 45.19555827549526, 51.75036375863211, 46.26529598236084, 45.36175223759243, 43.68815701348441, 38.1137284551348, 37.916396141052246, 37.15240349088396, 38.439824785505024, 39.556553159441265, 36.87493412835257, 37.57016045706612, 37.613211495535715, 37.662543705531526, 37.16629293986729, 38.49432645525251, 37.95903723580496, 36.49952295848301, 40.02750553403582, 40.228635038648335, 42.15107652119228, 43.399584429604666, 43.24704367773873, 41.476427282605854, 45.86991916384016, 48.74731411252703, 50.3909660748073, 50.017774854387554, 50.613245895930696, 34.43046406337193, 27.25180241039821, 35.18103626796177, 32.42967469351632, 42.1403797694615, 51.12460551943098, 49.498942443302695, 48.95892150061471, 46.596200466156006, 46.76308577401297, 46.90315798350743, 43.04134920665196, 41.3989166532244, 41.38093818937029, 40.596156529017854, 39.80509717123849, 38.32290049961635, 38.075836454119, 37.345570359911235, 36.5269718170166, 38.11327682222639, 37.09963539668492, 38.33466727393014, 36.384780406951904, 38.68641287939889, 37.13710355758667, 36.259900433676584, 35.96975408281599, 36.323056084769114, 41.0812554359436, 40.961614404405864, 46.02153927939278, 45.184500217437744, 40.1909236907959, 42.411536693573, 43.567324365888325, 49.09863935198103, 50.66820962088448, 52.667345319475444, 48.70790045601981, 50.961732796260286, 53.34521157400948, 50.5837334224156, 51.761060510362896, 40.255792072841096, 38.08190223148891, 37.1843513080052, 39.17211627960205, 38.187764985220774, 40.13978147506714, 43.164186409541536, 46.324272292000906, 48.06558813367571, 55.4877997807094, 54.2195520401001, 58.485155378069194, 57.84290558951241, 60.29579339708601, 57.323604175022666, 60.630821636744905, 60.68749114445278, 61.379469190325054, 59.4883918762207, 62.70777715955462, 57.27835750579834, 59.85245663779122, 52.25960070746285, 63.90453488486153, 60.027009282793315, 74.01646368844169, 2.208110587937491, 0.04210385786635535, 0.3348146639764309, 10.044784886496407, 69.05859742845807, 51.91882630756923, 40.02491385596139, 32.27183246612549, 49.84316662379673, 47.56761074066162, 52.18660293306623, 47.87247337613787, 4.02064459664481, 0.18914897819714888, 0.0319836403775428, 0.039642251562327147, 0.07066827546805143, 0.06588145518409354, 0.08820763217019183, 0.05410231796226331, 0.04475393744983843, 0.048777181921260696, 0.11461690041635718, 0.07552266426916633, 0.0174964580219239, 0.055505348569048304, 0.21120796166360378, 1.2083129052604948, 34.2712391444615, 52.941048758370535, 44.1467798096793, 29.425589765821183, 49.59647083282471, 47.16137041364397, 51.1408052444458, 72.13760825565883, 34.768177781786235, 0.06696148615862642, 0.061669252280678065, 0.2915629691311291, 0.6269712969660759, 48.22580317088536, 69.27884837559291, 60.50737994057791, 63.49595996311733, 56.14088528496878, 55.287931374141145, 56.38858509063721, 53.2968555859157, 48.89808654785156, 48.93040609359741, 47.777140617370605, 44.319307054792134, 42.08407504217965, 43.1699013028826, 43.15987852641514, 41.54683337892805, 41.444715704236714, 39.55715070452009, 40.465471335819785, 42.70362506593977, 41.167503425053184, 43.172864709581646, 45.63592120579311, 41.76740741729736, 44.534148829323904, 48.74148109980992, 49.48144340515137, 53.581231457846506, 50.74356630870274, 51.47225863592965, 64.07660007476807, 55.13360146113804, 54.81726040158953, 50.96940360750471, 48.69507755552019, 47.24786158970424, 46.860958099365234, 51.99237993785313, 47.900467668260845, 49.8733218056815, 45.63254090717861, 41.26529932022095, 39.0525621005467, 40.83030039923531, 38.889387130737305, 42.216730049678254, 39.52966363089425, 39.49494000843593, 38.41610710961478, 40.71085739135742, 39.76836551938738, 41.361750738961355, 39.145126002175466, 40.09877668108259, 41.68857315608433, 42.70655720574515, 44.919912815093994, 46.254092012132915, 44.95436545780727, 46.670084135872976, 48.25165741784232, 50.46605178288051, 52.87140001569475, 49.78209890638079, 53.458613123212544, 35.57111161095755, 26.630447592054093, 36.01905502591814, 32.135731152125764, 42.884695121220176, 52.37515272412981, 52.960479395730154, 50.36760623114449, 50.083411012377056, 49.221459184374126, 47.94678088596889, 45.0566394669669, 44.389247621808735, 42.96170548030308, 44.9463472366333, 40.30862270082746, 41.54802846908569, 41.264482906886506, 39.48600809914725, 38.42313868658883, 39.267845085689, 38.514041968754356, 41.70945596694946, 38.514729840414866, 40.32022271837507, 39.203504766736714, 41.2366657938276, 37.70904105050223, 38.231670652117046, 42.44175440924508, 43.70348126547677, 47.441094466618125, 48.12902518681118, 43.136873040880474, 46.14681877408709, 46.53201995577131, 51.947046416146414, 53.41051421846662, 56.191249302455354, 50.92532076154436, 53.30164984294346, 56.33150911331177, 52.75743218830654, 54.50659949438912, 44.3645988873073, 41.09631218229021, 40.15476526532854, 40.003843443734304, 40.537941047123496, 43.470424788338796, 44.65001698902675, 49.97171177182879, 49.87684106826782, 57.87041698183332, 55.518674101148335, 61.07077462332589, 60.59722709655762, 61.84080178397042, 59.13465213775635, 64.7996643611363, 61.858575275966096, 63.018556186131065, 61.348778997148784, 65.92277812957764, 60.289185660226, 63.375346183776855, 54.16399424416678, 68.80822604043144, 62.13514832087925, 77.36951146806989, 2.1170292581830705, 0.08018512944025652, 0.2949700563081673, 12.01854750088283, 74.50171892983573, 57.94581535884312, 50.097877161843435, 38.60965960366385, 44.15227583476475, 44.2867408479963, 61.370485169546946, 58.84324468885149, 6.418204767363412, 0.2010479989860739, 0.15590525418519974, 0.057374010261680396, 0.02880611177533865, 0.07021441017942769, 0.03277627445225205, 0.12617854002330983, 0.1764819100499153, 0.15733059841607297, 0.16439511147992952, 0.22076290180640562, 0.21068762029920304, 0.20500217537794793, 0.34427645483187264, 1.5586186051368713, 46.07685041427612, 63.05474935259138, 54.05658204214913, 31.081043243408203, 52.88879483086722, 53.14600672040667, 54.06407567432949, 80.8182567868914, 38.2862765448434, 0.17608001375836985, 0.14910547834421906, 0.525651253759861, 1.3590380059821265, 53.16418668201992, 72.03907585144043, 64.29709420885358, 66.14407130650112, 60.44180979047503, 59.35978766850063, 59.94679927825928, 57.33384581974575, 52.67588465554373, 52.25448683329991, 48.263712542397634, 47.563702378954204, 45.12967198235648, 45.84539549691336, 45.957949365888325, 45.23996421269008, 44.156517710004536, 42.283557823726106, 42.76925080163138, 45.289279052189414, 43.73219469615391, 46.62493126732962, 49.37603228432791, 43.52108063016619, 45.332698345184326, 51.1144437789917, 52.6487797328404, 54.364821502140586, 53.60906594140189, 52.16212790352957, 64.90395682198661, 56.476351261138916, 55.84659433364868, 52.424384185246055, 49.28747749328613, 50.47501495906285, 50.484096254621235, 56.42647361755371, 50.7166976247515, 51.37747131075178, 47.18398332595825, 43.40772077015468, 42.016792161124094, 41.382803780691965, 41.59811108452933, 43.256041594914024, 40.677502564021516, 41.44827665601458, 40.45066819872175, 44.26084838594709, 43.35510901042393, 43.37324033464704, 40.81053277424404, 42.468591826302664, 44.401226316179546, 45.12338733673096, 47.85267448425293, 49.122082574026926, 48.12288645335606, 48.3896347454616, 50.98778854097639, 53.56349270684378, 55.778432505471365, 53.29415621076311, 54.93335090364729, 35.98118386949812, 27.68842547280448, 35.82612786974226, 32.583358424050466, 43.34695529937744, 54.31750079563686, 54.76993274688721, 51.47008037567139, 51.29062230246407, 51.900774887629915, 51.000243186950684, 48.18038627079555, 47.346623284476145, 45.96882677078247, 47.88235371453421, 43.465449878147666, 43.10255936213902, 43.05829586301531, 42.00122124808175, 39.765718255724224, 42.58105884279524, 41.00276163646153, 43.76115478788103, 41.270270756312776, 42.93238408224923, 41.919069222041536, 43.20558377674648, 40.009023325783865, 40.40004709788731, 46.24114751815796, 44.756452969142366, 49.860901900700156, 51.897123609270366, 44.60104261125837, 49.00650971276419, 46.96550416946411, 53.20492049625942, 54.1970294543675, 58.162925720214844, 52.683965410505024, 54.48542138508388, 59.06012575966971, 56.044419969831196, 58.325881821768625, 46.59101711000715, 40.564035006931846, 42.72049181801932, 42.263105801173616, 43.750576155526296, 46.733736583164756, 48.06161723818098, 53.05499921526228, 53.89352866581508, 61.1586971282959, 59.109284264700754, 63.36804362705776, 63.29169682094029, 65.00559507097516, 60.808792795453755, 67.45416804722377, 66.2730437687465, 67.01505579267229, 64.66374370029995, 69.06100150517055, 63.153427668980186, 66.83595207759312, 55.8315931728908, 71.24615437643868, 64.24963106427873, 85.085312298366, 2.9319606721401215, 0.26765999889799524, 0.36408731607454164, 12.783553719520569, 85.47584969656808, 62.56244168962751, 53.506041526794434, 48.06516776766096, 60.33606515611921, 68.58108942849296, 70.29598821912492, 71.25939069475446, 8.69042638369969, 0.2648960000702313, 0.2747687388743673, 0.21169675114963735, 0.25080882598246845, 0.2222979108669928, 0.1444157971335309], [0.047205671069345305, 0.03986721645508494, 0.10985758794205529, 0.07592172428433384, 0.06598303187638521, 0.03272270071985466, 0.12707189922886236, 0.09971445293298789, 1.3759505727461405, 33.11387423106602, 41.93252093451363, 40.99396174294608, 27.554693494524273, 28.671100514275686, 36.69169623511178, 40.05752175194876, 60.989522389003206, 46.68958078111921, 2.240889366183962, 0.14358404890767165, 0.7104837042944772, 0.7451504926596368, 22.036838906151907, 76.15177018301827, 57.57393387385777, 58.41873059953962, 52.94487721579415, 50.61726195471627, 49.64042166301182, 49.13746588570731, 45.07918984549386, 45.36485113416399, 43.91556807926723, 44.22390133993966, 41.16154881886074, 41.37955549785069, 38.09552417482649, 40.141174588884624, 40.95035832268851, 40.1309746333531, 38.15393420628139, 42.268817220415386, 38.22563961574009, 43.526093755449565, 38.65093190329415, 39.072357518332346, 41.848013469151084, 47.95588650022234, 48.951382705143516, 50.3214111328125, 47.629811014447895, 54.62039361681257, 56.132846219199045, 49.79119062423706, 51.53491749082293, 47.80476665496826, 48.718565940856934, 44.87338072913033, 49.94653844833374, 51.23670080729893, 46.91117967878069, 45.342113154275076, 43.04939522062029, 41.529841559273855, 37.855019228799, 39.1679230417524, 37.858830315726145, 37.421475955418174, 36.1698066166469, 37.56151689801897, 37.522714682987754, 38.81396096093314, 37.373439584459575, 36.90416519982474, 37.62748656954084, 38.81031663077218, 38.870804173605784, 39.3247959954398, 39.0386518069676, 40.13244417735508, 39.89458996909005, 43.71497706004551, 44.2757522719247, 45.795198236192974, 50.34022685459682, 49.60957860946655, 51.580751282828196, 36.145678997039795, 27.46059925215585, 35.56743253980364, 30.169366632189067, 41.488544940948486, 51.016675676618306, 49.53399610519409, 50.56942708151681, 47.5992945262364, 44.617311818259104, 45.308456080300466, 41.348802770887104, 41.63851138523647, 41.965702056884766, 38.02176904678345, 38.544356959206716, 37.03025763375418, 38.21935149601528, 37.08764975411551, 34.832062993730815, 37.46159832818167, 36.80738026755196, 38.95476620537894, 37.2800349508013, 37.69321305411202, 35.94211067472185, 36.61237907409668, 34.410807609558105, 38.792581353868755, 37.619152205330984, 44.042320592062815, 47.052433082035606, 47.068469524383545, 40.72992672239031, 42.92974029268537, 44.0316481590271, 49.89428799492972, 54.23846503666469, 50.84015669141497, 50.49697126661028, 45.13661323274885, 50.57440199170794, 53.15206554957798, 49.91898536682129, 50.30778224127633, 42.87210151127407, 38.359833649226594, 38.39647497449602, 38.441068513052805, 39.69300535746983, 41.573643003191265, 41.47292539051601, 42.93077210017613, 47.69414438520159, 48.495594773973735, 54.38818481990269, 55.513483796800884, 58.91366468157087, 56.765719413757324, 61.702754974365234, 61.13839449201311, 59.7724620274135, 57.827397210257395, 60.27710274287632, 58.247339384896414, 60.11795425415039, 55.33518954685756, 63.53404998779297, 64.6854498726981, 62.05968393598284, 0.301933969770159, 0.16634896663682802, 0.6470158185277666, 18.247786453792028, 67.96957847050258, 55.81366334642683, 39.68627602713448, 58.24684606279646, 92.76356506347656, 34.82299212047032, 49.69197729655674, 49.42235592433384, 8.675078681537084, 0.3542090132832527, 0.17524898477963038, 0.07018648167806012, 0.17658630944788456, 0.061208954480077536, 0.0268647823748844, 0.034831947181373835, 0.026803573427189673, 0.04816071589344314, 0.03798052608700735, 0.07759353957538094, 0.059375403581985405, 0.05883654499692576, 0.01670182735792228, 1.6333664570535933, 47.29240301677159, 49.37193979535784, 56.12900733947754, 32.309887749808176, 31.981706959860666, 42.82427706037249, 45.814142499651226, 67.73390252249581, 50.987323011670796, 2.4891897567680905, 0.29104239706482204, 0.623843847640923, 0.9031415634921619, 22.383422000067576, 77.5737885066441, 59.486224038260325, 60.97808565412249, 55.04992430550711, 53.18304409299578, 50.125145367213655, 51.03699568339756, 48.80711725779942, 46.670768533434185, 46.676549434661865, 48.29364538192749, 44.450826031821116, 45.049055508204866, 39.831663608551025, 42.729243074144634, 43.17566135951451, 42.093462058476035, 40.70248481205532, 44.41898591177804, 40.37390450068882, 44.27646446228027, 41.59422009331839, 42.18119348798479, 45.63224560873849, 50.77836636134556, 49.845893791743684, 53.44676644461495, 48.758775166102815, 51.19088438579014, 58.966352871486116, 53.4865448815482, 52.91460044043404, 48.51408740452358, 49.16498075212751, 45.43061235972813, 50.04612003053938, 52.40633623940604, 49.82956205095564, 49.388177735464915, 45.065074580056326, 44.27539096559797, 39.34418146950858, 40.60025596618652, 40.83337845121111, 39.512845516204834, 39.31508241380964, 39.25890622820173, 38.89736713681902, 40.600728443690706, 39.63130187988281, 39.61319487435477, 41.39685651234218, 39.09130872998919, 39.355003288814, 41.531762736184255, 42.262994629996165, 41.771809101104736, 42.32505593981062, 44.97961173738752, 45.02583462851388, 48.81735890252249, 51.96840865271432, 50.92103372301374, 52.58816712243216, 37.26646511895316, 27.773228236607142, 36.01153360094343, 30.078390393938335, 41.272028650556294, 53.39310898099627, 51.29128238133022, 53.053418500082834, 48.33394145965576, 47.371945994240896, 48.43738971437727, 43.05767747334072, 43.36004223142351, 43.03661748341152, 41.31096288136074, 39.57528897694179, 39.38839633124215, 40.95363092422485, 39.346950326647075, 36.103402682713096, 38.90981483459473, 38.31239482334682, 41.56216805321829, 37.89542300360543, 38.37571723120553, 37.98903955732073, 40.40689107349941, 38.69250297546387, 40.276799951280864, 40.917006969451904, 45.79542752674648, 48.78468499864851, 49.28318698065621, 43.671887806483674, 44.41899285997663, 46.48072140557425, 50.74825981685093, 55.64572191238403, 51.72391891479492, 53.33992746898106, 47.98015308380127, 52.921566009521484, 55.198956217084614, 52.13447059903826, 53.12179919651577, 44.53119584492275, 41.42064714431763, 40.978001730782644, 42.02412945883614, 40.9589011328561, 43.43414824349539, 43.04388182503836, 44.96589251926967, 50.16006701333182, 53.1675044468471, 58.589378356933594, 56.890213762010845, 61.93984835488455, 58.379237038748606, 63.520410673958914, 64.28935391562325, 64.20744855063302, 60.997686522347585, 63.17625250135149, 60.64999866485596, 62.51469366891043, 56.254245144980295, 67.3010505948748, 65.79124178205217, 67.02784742627824, 0.2305215245911053, 0.1014929407143167, 0.6379899457097054, 22.11351227760315, 74.69846412113735, 61.750614166259766, 42.11120080947876, 64.91818673270089, 87.74647235870361, 35.9628267288208, 59.32462283543178, 58.8941193989345, 13.105851122311183, 0.35388046662722317, 0.2589098284287112, 0.018109885909195458, 0.10687322129628488, 0.031375547471855364, 0.04317028421376433, 0.1040847273543477, 0.14484501124492713, 0.1968250141612121, 0.15656997423086846, 0.16621521381395205, 0.16609914361366204, 0.29596294303025517, 0.17383453782115663, 2.118843389408929, 59.653877122061594, 59.89516026633126, 55.931046213422505, 37.732758726392476, 39.8492807660784, 49.76916830880301, 50.95801898411342, 70.63322598593575, 59.183657782418386, 2.8592903316020966, 0.30932837298938204, 1.6842201054096222, 0.9884178361722401, 25.922775302614482, 80.63025937761579, 62.966917174203054, 64.29021549224854, 57.93465307780674, 56.83138336454119, 52.75498989650181, 54.3778007371085, 52.29626635142735, 50.61590358189174, 48.828733103615896, 50.93919978822981, 45.97085217067173, 47.393023354666575, 43.213775702885215, 45.10726056780134, 45.994941575186594, 45.36431959697178, 41.637681075504844, 47.154582023620605, 42.98214360645839, 48.610347747802734, 43.64071123940604, 43.46865994589669, 45.91670485905239, 53.310665130615234, 52.41560861042568, 55.09077276502337, 50.27386113575527, 50.27562945229666, 60.27926363263811, 54.8874545778547, 53.56546252114432, 51.26604304994856, 51.59397370474679, 49.34769058227539, 54.12020322254726, 56.99722991670881, 54.79271241596767, 53.14703505379813, 46.745948042188374, 47.5115943636213, 43.834732736860005, 44.1426352092198, 42.24217782701765, 42.64101832253592, 40.214672633579795, 42.37596539088658, 43.015957014901296, 44.64304447174072, 42.27085999080113, 40.6174909727914, 43.07584353855678, 43.090010915483745, 43.56267949513027, 43.70319291523525, 43.14364753450666, 43.50035415376936, 46.44421557017735, 46.59210450308663, 49.657403060368125, 50.71351187569754, 53.29445845740182, 53.549106461661204, 54.96520839418684, 37.95298188073294, 29.44725772312709, 36.500304630824495, 30.112707546779088, 42.314668382917134, 55.206022535051616, 54.305772236415315, 54.928195340292795, 51.38858495439802, 49.467522689274375, 49.903393609183176, 46.4563992364066, 47.38822562353951, 48.27312387738909, 43.26511941637312, 43.23797280447823, 42.567464692252024, 43.25654533931187, 41.220278467450825, 38.455680574689595, 42.399151529584614, 41.063857146671836, 44.62044545582363, 41.52653421674456, 42.14824513026646, 41.412069593157085, 41.7743729863848, 40.096706117902485, 43.6521931375776, 42.375826426914756, 49.39249604088919, 52.584185804639546, 50.36277723312378, 46.15508018221174, 46.3677020072937, 47.966496399470735, 53.33131170272827, 60.24217414855957, 54.229213510240825, 54.80969033922468, 48.69462244851248, 53.94780799320766, 57.49827493940081, 55.33005135399954, 56.186138902391704, 48.87843009403774, 44.43757234300886, 43.57845538003104, 44.35362420763288, 43.84409543446132, 45.692604609898154, 46.49940511158535, 47.87672567367554, 51.677143641880576, 55.42481088638306, 60.97191565377371, 61.36018793923514, 64.80509785243443, 61.564152308872764, 67.26651804787772, 69.24087647029332, 66.907365662711, 63.771706172398154, 66.49987465994698, 64.32901423318046, 68.76054750170026, 61.519357272556846, 69.1941567829677, 71.39649949754987, 73.60686043330601, 0.4668812187654631, 0.22543133130030973, 0.7335832619241306, 22.794779675347463, 83.3393064226423, 66.3210836138044, 54.16084671020508, 70.64866488320487, 101.80078819819859, 54.78139380046299, 68.84462765284947, 71.08515071868896, 15.62525142942156, 0.48139774267162594, 0.4040222503244877, 0.22617983685008117, 0.23641761392354965, 0.24797683794583592, 0.2239218351564237], [0.024890655984303782, 0.04107914785189288, 0.035427761995898824, 0.11584529307271753, 0.12553230327154907, 0.04344917906980429, 0.025612244049885442, 0.038981775753200054, 0.8454674439770835, 39.87044150488717, 46.50114563533238, 34.48772416796003, 33.08832917894636, 49.11524554661342, 38.075308391026084, 40.265526499067036, 51.80994456154959, 55.88023056302752, 12.970854571887426, 0.47632175790412085, 0.41465532832912033, 0.31567465673599926, 3.124481575829642, 65.71007292611259, 63.41586807795933, 57.15188986914498, 54.75824587685721, 47.472257137298584, 49.0749112537929, 45.81879431860787, 44.876111371176584, 41.62389932359968, 46.464372294289724, 43.28598485674177, 42.915197713034495, 41.08558068956648, 43.69839865820748, 42.842154775347026, 45.083605425698416, 42.54239559173584, 41.36942502430507, 37.3160057749067, 39.49009363991873, 38.96250997270857, 42.021575995853965, 44.09717314583914, 44.891588483537944, 47.741253171648296, 49.567434310913086, 47.00500120435442, 53.88958903721401, 52.2695574760437, 43.46553325653076, 52.219044072287424, 50.53765991755894, 49.306199414389475, 47.56507117407662, 44.39221797670637, 47.38391774041312, 47.46290833609444, 42.7131302016122, 46.61365781511579, 40.572219984872, 43.792070797511506, 42.55221339634487, 36.98114429201399, 34.74928215571812, 36.24375629425049, 35.75905690874372, 36.4621069090707, 36.67001438140869, 35.19932392665318, 35.78010647637503, 36.874930654253276, 40.47197137560163, 39.11369929994856, 41.30197538648333, 40.902704102652415, 40.193998268672395, 39.43237148012434, 38.02663973399571, 41.38010093144008, 43.50927216666085, 45.04653331211635, 46.560990469796316, 48.59344972882952, 48.98242725644793, 38.12446689605713, 29.00708760534014, 35.67544228690011, 30.526656900133403, 43.864512716020855, 52.471249784742085, 48.46844121388027, 50.09382288796561, 46.744131088256836, 44.59704392296927, 44.497361591884065, 41.51393018450056, 40.22123520714896, 39.521857329777305, 37.71387699672154, 37.37048660005842, 37.410973753247944, 39.89074066707066, 37.92195469992501, 34.32500777925764, 36.60693516050066, 34.80713980538504, 34.95830481392996, 37.52866581508091, 34.686522551945274, 33.87667873927525, 35.1398959841047, 38.737304959978374, 42.91931799479893, 42.21943637302944, 46.724808147975374, 45.98046152932303, 47.14559800284249, 43.23359196526663, 44.20511341094971, 44.65201112202236, 46.63262987136841, 56.16303266797747, 49.46337114061628, 51.54297392708914, 50.49391753332955, 44.56269897733416, 50.17179904665266, 55.803223678043906, 51.05516522271292, 49.76104586465018, 39.97230209623064, 39.989707333701, 39.0668580191476, 38.24914189747402, 37.06128828866141, 39.57333305903843, 40.08786800929478, 40.82888991492135, 43.15307623999459, 49.76788289206368, 53.555332047598704, 56.385350704193115, 54.32258687700544, 53.96474075317383, 56.464737347194124, 53.354004519326345, 52.857347284044536, 53.47559799466814, 55.88414239883423, 53.550676754542756, 56.45169905253819, 60.5240695135934, 68.92343412126813, 44.24765723092215, 0.20733466664595263, 0.32219263698373524, 0.24255287327936717, 35.19174691608974, 64.97194494519914, 56.97764989307949, 45.1817695753915, 48.53102363858904, 57.66442026410784, 43.121705123356406, 44.957540784563335, 57.87291485922677, 12.940199988228933, 0.2727687161948, 0.10180306514458996, 0.08739658604775156, 0.15645135273890837, 0.027470281580463052, 0.06702021336449043, 0.060334743532751284, 0.07080496634755816, 0.035475076242749176, 0.06835916651678936, 0.07093940449080297, 0.06261924880423717, 0.03114257925855262, 0.0028473360746699783, 0.9012682640126773, 51.34696524483817, 53.746386664254324, 45.757768290383474, 26.0032354422978, 50.461122035980225, 45.62881667273385, 44.50141586576189, 59.41751330239432, 61.405615261622835, 15.330385514668055, 0.5148412681051663, 0.5568431828703199, 0.4636525862983295, 3.7505993843078613, 66.31781796046666, 64.21279171534947, 58.388735226222444, 58.09711933135986, 48.91533545085362, 49.80710547310965, 46.72698988233294, 46.84074926376343, 44.1698374067034, 48.26338250296456, 45.4550005367824, 44.73908247266497, 43.2489127431597, 45.27624075753348, 45.48037535803658, 45.30563858577183, 45.40152025222778, 42.742750372205464, 40.4504771232605, 41.23572778701782, 38.96380928584507, 44.96822016579764, 46.16261550358364, 47.19716058458601, 50.42577307564871, 52.672295910971506, 51.50304610388619, 51.07332781382969, 51.33641440527779, 48.38385384423392, 52.5615450995309, 54.60900551932198, 51.00549602508545, 48.81480196544102, 46.09558970587594, 51.486405168260845, 52.46194267272949, 47.074257373809814, 48.88366903577532, 43.96150262015206, 45.74027272633144, 44.3928850037711, 38.47475685392107, 36.64099175589425, 40.08451550347464, 37.59910317829677, 37.175190108163015, 40.12554114205496, 37.15581505639212, 38.730933461870464, 39.12061275754656, 44.12396192550659, 41.15903009687151, 43.602669852120535, 41.93413291658674, 42.15433522633144, 40.54318346296038, 40.6884320804051, 42.2507449558803, 46.12443862642561, 47.676836422511506, 47.96716342653547, 50.99516405378069, 50.31902095249721, 39.092156410217285, 28.095294611794607, 34.29323714120047, 29.228201866149902, 44.72531461715698, 54.448901653289795, 49.6641080720084, 51.961050510406494, 49.50780834470476, 47.1643511908395, 46.13637563160488, 42.97935390472412, 42.489644868033274, 42.72573075975691, 38.382661955697195, 41.08755397796631, 40.00900248118809, 41.74393292835781, 38.772560119628906, 36.7637733731951, 37.71416187286377, 36.70565169198172, 37.70704344340733, 37.30476706368582, 37.89375196184431, 34.609064034053254, 38.47550031117031, 39.94556542805263, 43.94843305860247, 44.90084000996181, 50.13661684308733, 47.50450372695923, 50.61125871113369, 47.37391580854143, 46.69692155293056, 46.528250558035715, 49.74617671966553, 57.80816459655762, 51.676132678985596, 53.35952486310686, 54.200104032244, 42.98400224958147, 51.669837611062185, 59.306494985307964, 53.369954109191895, 53.95425592150007, 41.91020679473877, 42.32727241516113, 40.492475509643555, 40.879198346819194, 38.031440939222065, 43.27593081338065, 42.973138741084504, 43.37599182128906, 44.473060267312185, 53.37281329291207, 56.071198327200754, 58.87547738211495, 57.27159343447004, 56.258170877184185, 58.38581003461565, 56.33149869101388, 55.4994866507394, 56.5421576499939, 58.2515777860369, 56.31343337467739, 60.894234793526785, 64.58666038513184, 72.70875712803432, 47.04886170795986, 0.21721784131867544, 0.26647294259497095, 0.2784831481320517, 41.319012369428364, 70.83354255131313, 63.4187376839774, 48.151926449366975, 60.81200981140137, 71.50564874921525, 50.43296793528965, 56.14913279669625, 68.6717425755092, 16.63943134035383, 0.25684396071093424, 0.11803393491676875, 0.11232651903160981, 0.11052214513931956, 0.08185857321534838, 0.10935868149889366, 0.2063214781561068, 0.13373007838215145, 0.1614587376160281, 0.17040963231452874, 0.25017887407115524, 0.2737008333206177, 0.18888869216399534, 0.13557215168007783, 1.6477003736155373, 61.42481313432966, 66.34701429094586, 50.17833035332816, 43.738680839538574, 62.679442405700684, 55.076341356549946, 54.775529520852224, 61.95252881731306, 69.12947600228446, 17.36961579322815, 0.6184195301362446, 0.8973303724612508, 0.686480446585587, 4.436893369470324, 71.00393322535923, 66.91482107979911, 62.80082048688616, 59.33860955919538, 52.136360509055, 53.67265932900565, 51.3496333530971, 48.33013384682791, 46.340520654405864, 51.126273087092805, 47.80272388458252, 46.56559017726353, 45.71720470700945, 47.29895864214216, 48.15944440024239, 48.715668542044504, 49.962404659816194, 43.97366544178554, 42.707825251988, 43.505641732897075, 43.47518083027431, 47.932780265808105, 49.24220650536673, 49.14482055391584, 53.23276540211269, 52.52063758032662, 52.67449154172625, 51.3470972606114, 49.86151681627546, 53.194831711905344, 52.91866166251046, 54.86087771824428, 52.68492078781128, 52.055771827697754, 50.07028933933803, 53.37197950908116, 56.4989606993539, 50.10601002829415, 52.44820261001587, 46.65859876360212, 50.41847399302891, 48.45964479446411, 42.10904686791556, 38.7739462852478, 40.30187252589634, 40.06083951677595, 40.30171619142805, 43.507066113608225, 38.578535148075645, 41.28539003644671, 41.816972391945974, 46.186142104012625, 43.8547921861921, 47.11664833341326, 44.7354450907026, 44.89244311196463, 43.11849505560738, 43.65355151040213, 44.2756793158395, 48.500646114349365, 49.64736638750349, 50.064289569854736, 54.137149878910606, 52.66067852292742, 40.92181164877755, 29.525484016963414, 35.66328641346523, 30.148758275168284, 47.49970252173287, 57.759061677115305, 53.1139303616115, 55.402229240962434, 51.38519770758492, 49.64675842012678, 49.52657542909895, 44.07307679312569, 44.034396171569824, 44.93699148723057, 41.39090538024902, 42.25455951690674, 42.614997318812776, 44.10634476797921, 42.976116044180735, 38.25434609821865, 40.8139408656529, 39.38034336907523, 38.2976507459368, 41.86492191042219, 39.72511298315865, 37.44601351874215, 39.98463862282889, 43.37017617906843, 45.129859583718435, 47.11505372183663, 53.560633523123606, 52.38152422223772, 53.15977110181536, 47.634928362710134, 50.44031912939889, 48.30984858104161, 50.920828751155305, 61.771813120160786, 53.72018848146711, 56.78338173457554, 55.102063587733674, 46.89048099517822, 55.70382274900164, 59.73812402997698, 58.28752776554653, 55.29325022016253, 43.33233281544277, 44.16796139308384, 43.41346345629011, 43.964962823050364, 41.581796714237754, 45.81507355826241, 45.8183148929051, 45.64936249596732, 47.21026141302926, 56.05736098970686, 59.25124291011265, 62.10937050410679, 59.689180919102256, 59.47542653764997, 62.339557375226704, 59.87172399248396, 58.2910088130406, 60.43935012817383, 62.40570422581264, 59.60958930424282, 62.09876755305699, 67.12765135083879, 74.67632716042655, 53.59624998910086, 0.307216364890337, 0.5867461668593543, 0.3317190786557538, 44.205505984170095, 78.44149344308036, 67.05984388078961, 59.02961621965681, 63.728272983006065, 68.82787554604667, 56.854791845594136, 61.94239139556885, 79.46372631617955, 23.304014887128556, 0.3571521724973406, 0.2629833184182644, 0.24539262375661305, 0.24092721194028854, 0.17971523797937802, 0.24825745288814816], [0.058576632158032486, 0.0434548482298851, 0.09219243084745747, 0.10440203068511826, 0.046599111652800014, 0.11359919288328715, 0.018299187001373087, 0.0920508409451161, 0.9788811079093388, 46.7051864351545, 44.45887204578945, 45.34956509726388, 41.49832105636597, 89.74307196480888, 40.90926667622158, 31.89203003474644, 54.07002680642264, 54.59114170074463, 28.988952807017736, 0.11065386914248977, 0.07409829712871994, 0.017582704911806753, 0.32357565420014517, 34.2580931527274, 77.84168325151715, 55.49907670702253, 61.96780095781599, 52.23065798623221, 54.726291111537385, 48.17863185065133, 51.15409367425101, 43.22458709989275, 48.56984322411673, 45.792533602033345, 48.2881806237357, 42.71956075940813, 46.77510615757534, 45.04651246752058, 44.600771631513325, 42.50518798828125, 42.98341860089983, 38.465824944632395, 39.69770928791591, 39.43016542707171, 44.23708207266671, 42.24974094118391, 47.16233621324812, 48.0441494669233, 53.9021965435573, 46.118699414389475, 58.67663383483887, 45.41538885661534, 42.76879569462368, 57.38290010179792, 49.99091311863491, 49.2496862411499, 46.10950347355434, 45.03421415601458, 47.121953283037456, 45.57014608383179, 41.84863880702427, 46.52924762453352, 40.50916855675833, 40.297432626996724, 43.46564095360892, 38.751069341387065, 36.30235045296805, 35.944177763802664, 36.24879373822893, 35.96036359242031, 39.02061080932617, 34.290833064488, 36.70656190599714, 34.719179085322786, 39.946604183741975, 41.3071413721357, 40.55320276532854, 38.3644437789917, 38.902359417506624, 39.83112859725952, 39.98288420268467, 39.93708515167236, 42.58445998600551, 43.69348628180367, 45.68322801589966, 47.435786042894634, 50.508029324667795, 40.59545128686087, 31.291490282331193, 35.065984521593364, 33.916078499385286, 45.80633272443499, 49.31342554092407, 46.955696787152974, 47.77724831444876, 43.83891902651106, 43.68980721064976, 42.42578744888306, 41.198752948216026, 39.45120457240513, 38.4580533845084, 38.897645064762656, 38.346152646201, 40.14637531552996, 41.11282805034092, 37.20281614576067, 35.01361247471401, 35.382957867213655, 35.48169524329049, 37.00960758754185, 36.06441286631993, 34.70543554850987, 35.50307832445417, 34.70566831316267, 40.433408873421804, 42.28751482282366, 38.770225524902344, 43.80564757755825, 43.77145201819283, 47.04307385853359, 48.01315702710833, 44.14342382975987, 46.945972783224924, 47.369792052677695, 49.965579986572266, 52.338195255824495, 52.88751288822719, 55.5306910106114, 41.09075709751674, 35.97488532747541, 63.18666785103934, 52.82825517654419, 52.800219195229666, 47.58425862448556, 39.65158019747053, 36.292932169778005, 37.63708897999355, 37.05431924547468, 39.637503147125244, 39.952829769679475, 42.94879225322178, 41.12914936883109, 44.10309648513794, 48.36816828591483, 52.59441007886614, 51.01311125074114, 50.584125995635986, 50.39791079929897, 50.04664461953299, 48.44822890417916, 51.17494869232178, 52.24529436656407, 51.43876484462193, 61.88711152757917, 59.24449620928083, 74.71153368268693, 19.48155549594334, 0.33962015754410196, 0.31405930912920405, 0.14573109655507974, 52.660546507154194, 55.99978126798357, 55.763243743351524, 42.61766195297241, 38.64291368212019, 20.697419030325754, 29.689041137695312, 42.791398184640066, 54.29421043395996, 14.420846343040466, 0.2117013516170638, 0.035112450165407996, 0.031148238240608146, 0.0718750296426671, 0.05895678818758045, 0.21754736506513186, 0.021275538452235714, 0.08148348584238972, 0.03437083853142602, 0.038478302769362926, 0.0697855149794902, 0.05672723746725491, 0.0880303784672703, 0.035437753424048424, 1.6827726002250398, 58.849706513541086, 51.385183811187744, 47.9991911479405, 36.27961594717843, 92.38916833060128, 47.36167655672346, 39.25548424039568, 59.04443672725132, 60.733835629054475, 31.162865230015345, 0.15030607820621558, 0.0770044761842915, 0.0793997115854706, 0.4517987695123468, 37.027422768729075, 78.30124405452183, 56.006705147879465, 63.23226193019322, 52.321373667035786, 56.23988669259207, 50.117120197841096, 53.650612694876536, 44.67958157403128, 51.582512651171, 46.458869321005686, 50.24065222058977, 46.914914335523335, 48.424730096544536, 46.531165327344624, 47.238926206316265, 44.61503280912127, 44.771603516169954, 40.30973441260201, 41.61628062384469, 41.784506934029714, 48.982767718178884, 44.53910289491926, 47.748489720480784, 51.04616035733904, 56.56109149115426, 47.428431374686106, 55.43968003136771, 47.41857188088553, 45.01404006140572, 58.06215252195086, 53.667059080941335, 50.88766499928066, 48.51074879510062, 46.26088040215628, 49.05909367970058, 49.668919699532644, 46.605375562395366, 47.89954355784825, 43.187706061771934, 42.147425242832725, 45.88019902365548, 39.752443722316194, 38.34427315848214, 36.67034442084176, 36.90763235092163, 38.87446240016392, 38.95193134035383, 37.077560969761436, 40.07090745653425, 37.88218321119036, 40.15307337897164, 42.583466393607004, 42.073089940207346, 40.32425267355782, 41.3100700378418, 40.2683926309858, 42.08289384841919, 40.645353249141145, 45.3872903415135, 44.98879378182547, 46.99355057307652, 48.54623324530465, 52.057984828948975, 40.90679311752319, 31.444854395730154, 35.77497523171561, 33.39669023241316, 44.96157768794468, 50.52360718590872, 46.83857447760445, 49.70120450428554, 46.2956874029977, 46.460797446114675, 43.973290239061626, 44.072117941720144, 40.655549730573384, 40.57271678107125, 39.645788873944966, 40.43680306843349, 41.51419769014631, 44.392565386635916, 39.456078733716694, 36.798166956220356, 38.16451631273542, 39.440264633723665, 37.94129153660366, 38.61118125915527, 37.58728081839425, 38.8204471043178, 35.99784564971924, 43.38347503117153, 44.03163773672921, 41.87967641013009, 46.23633589063372, 48.48131969996861, 49.4752699307033, 51.3345661844526, 48.00088998249599, 49.957450594220845, 49.41158274241856, 51.50576979773385, 54.88054459435599, 55.928805419376914, 57.15621164866856, 46.82742609296526, 43.50591271264212, 59.42041070120675, 56.143796580178396, 54.38266795022147, 48.9726094518389, 42.46896355492728, 38.338825770786826, 39.6243119921003, 39.4709027154105, 42.85368878500802, 42.07680375235421, 44.12074143545968, 45.87673882075718, 46.23063141959054, 50.444967474256245, 55.69283069883074, 54.23405640465872, 53.65272147314889, 51.53418445587158, 52.47905261175973, 51.26545245306832, 52.4848439352853, 55.478996413094656, 56.59775366101946, 68.06316375732422, 61.994808605739046, 79.01506723676408, 21.335020474025182, 0.62589188345841, 0.12469994436417307, 0.2660570820527417, 58.79764366149902, 64.4526365825108, 60.301963397434776, 45.716777392796104, 52.990040506635395, 27.150044304983957, 38.45158461162022, 51.93463693346296, 64.59018312181745, 20.65086783681597, 0.1154729537665844, 0.05034720678148525, 0.02802143691639815, 0.1027014794360314, 0.07301835436373949, 0.23808898138148443, 0.08548154309391975, 0.1659486581172262, 0.22428593704743044, 0.12849129949297222, 0.23748573660850525, 0.146164314023086, 0.15649589177753243, 0.17420362015920027, 3.022268580538886, 72.1855160849435, 58.8284797668457, 64.36889689309257, 53.64296620232718, 100.71663992745536, 55.31428241729736, 48.395273208618164, 62.59541089194161, 68.95533330099923, 35.44335855756487, 0.16078408381768636, 0.18152216316333838, 0.3213482680065291, 0.8612028339079448, 39.28619180406843, 81.82323033469063, 60.43131801060268, 65.95501777103969, 54.988658564431326, 60.14986733027867, 52.24991144452776, 55.967961992536274, 47.3225234576634, 51.18111869267055, 48.9752254486084, 53.2517409324646, 48.7813846043178, 50.09602199281965, 51.02642052514212, 51.065865448543, 48.099325111934114, 47.146400519779746, 43.671384062085835, 44.02975477491106, 45.136960642678396, 52.1970808165414, 46.98489311763218, 50.33782277788435, 53.686576570783345, 58.52965859004429, 49.55096708025251, 51.1879939351763, 52.858358246939524, 48.198396001543315, 57.59909330095564, 56.82519946779524, 52.624968256269185, 54.20235872268677, 48.87142630985805, 50.50913756234305, 53.43926933833531, 49.09902845110212, 52.49624245507376, 45.98720128195626, 44.94845254080636, 48.742877687726704, 41.92285599027361, 40.929826395852224, 37.62502690723964, 40.04841613769531, 41.65883139201573, 43.11852979660034, 37.570139612470356, 42.370500632694785, 38.63931451525007, 43.00868225097656, 45.71620764051165, 45.234443868909565, 43.83143581662859, 43.29650442940848, 44.66060951777867, 44.96297080176217, 42.44621862683977, 47.316009521484375, 47.667626585279194, 48.63474982125418, 52.15789645058768, 54.987981115068706, 43.4984781401498, 32.919710295540945, 35.60970538003104, 35.35915681294033, 47.81430653163365, 51.67924894605364, 50.89206320898873, 51.62445892606463, 48.9163498878479, 48.59204271861485, 45.61941576004028, 46.93472712380545, 44.65029491697039, 43.636309555598665, 43.92036233629499, 42.73710148675101, 45.6845759664263, 47.04330314908709, 41.55122464043753, 39.91975287028721, 40.493889468056814, 40.10304634911673, 40.24265302930559, 41.60725143977574, 39.26306472505842, 39.14370162146432, 38.44690152576992, 46.7015768459865, 47.96127135413033, 43.8122101511274, 49.36128125871931, 51.882973602839876, 53.204666887010845, 53.126315525599885, 51.28141246523176, 54.52651997974941, 53.19040223530361, 55.909531116485596, 59.08393723624093, 58.079300676073345, 59.65117427280971, 46.754393577575684, 43.10829857417515, 62.90755871364048, 56.00064284460885, 58.23233822413853, 50.0970572744097, 46.16950464248657, 40.52904735292707, 42.20539058957781, 41.683473178318565, 46.209759031023296, 44.369539056505474, 48.24368783405849, 47.39372859682356, 49.14841972078596, 53.15764147894723, 58.35215990883963, 56.61287294115339, 58.33483110155378, 54.88089200428554, 55.59956155504499, 53.413668700626914, 55.72760990687779, 58.76245103563581, 58.82641615186419, 70.77750532967704, 65.76325443812779, 82.65907083238874, 25.343726328441075, 0.6458902103560311, 0.41657096839376856, 0.4147309171301978, 64.42615004948208, 69.83601747240338, 71.06650175367082, 55.27953795024327, 54.55253403527396, 29.484698091234478, 43.30669048854283, 59.09714576176235, 77.70847933632987, 27.757233483450754, 0.34697848984173363, 0.1361328794487885, 0.13464794627257756, 0.15199332338358673, 0.1762035885559661, 0.3574355830039297], [0.06372734398714133, 0.0658518032037786, 0.012032198553372706, 0.01470288185269705, 0.03273132489994168, 0.028273901137124215, 0.09395373133676392, 0.048192230452384265, 3.5959544139248982, 51.02461051940918, 52.448414530072895, 41.21465390069144, 33.64602633884975, 72.4970316205706, 32.32843944004604, 26.348863158907207, 50.27922861916678, 60.20486232212612, 40.815528529030935, 0.11097026323633534, 0.006298178582385714, 0.15178844652005605, 0.37760001527411596, 3.6994819215365817, 70.29387596675328, 62.71758106776646, 64.11064624786377, 58.70959608895438, 60.702346393040244, 56.86141347885132, 53.46144798823765, 50.63866588047573, 54.38571473530361, 53.446512835366384, 50.63618884767805, 49.12003285544259, 49.01841197695051, 45.50589609146118, 46.15807138170515, 43.01859385626656, 39.33196653638567, 39.763275963919504, 39.17965160097395, 39.317684514181956, 42.64667068208967, 43.678217615400044, 47.941382135663716, 52.15102468218122, 51.928560733795166, 55.67859731401716, 54.97532844543457, 30.225984028407506, 53.06815562929426, 54.03699854442051, 53.215651988983154, 47.5772374698094, 46.40923139027187, 44.740753514426096, 48.12177126748221, 40.74247516904558, 41.42255442483084, 45.509543895721436, 42.33016633987427, 41.902810437338694, 39.95138801847185, 43.408502442496165, 36.085344314575195, 34.03315911974226, 37.32906838825771, 36.83467626571655, 38.78888143811907, 36.20342200142996, 38.84879922866821, 37.0995728628976, 40.41484676088606, 41.955189432416645, 40.691676889147075, 40.022221429007395, 41.315899576459614, 40.47485835211617, 40.01413719994681, 38.81289093835013, 38.05197286605835, 42.65246547971453, 46.2683219228472, 47.322148254939485, 47.95969063895089, 40.99034520557949, 33.708935328892295, 35.01933084215437, 36.29481513159615, 46.6193379674639, 50.03165735517229, 45.35905633653913, 46.074279580797466, 42.74159697123936, 42.43508761269705, 40.67869765417916, 39.17603158950806, 37.99388939993722, 39.4739008631025, 37.77865852628435, 40.39165019989014, 38.50750718797956, 40.78151362282889, 36.38868529456002, 35.75721563611712, 33.993099280766074, 36.14920520782471, 34.002979619162424, 35.1765581539699, 34.54745088304792, 35.64595760617937, 36.67287356512887, 42.07191916874477, 38.80996574674334, 39.67666319438389, 44.250259331294465, 42.785137857709614, 43.95603091376168, 49.34283379146031, 43.70248767307827, 46.21041563579014, 44.83465494428362, 49.052381719861714, 48.13374301365444, 52.139928409031455, 52.06854261670794, 58.536016191755024, 38.027720178876606, 31.092691898345947, 55.99163103103638, 50.61388513020107, 50.92902067729405, 46.07457487923758, 41.302538190569194, 36.14180537632534, 39.93233953203474, 39.05266284942627, 40.43945728029524, 40.44817726952689, 41.829322814941406, 43.78548043114798, 47.5738536970956, 48.23537084034511, 48.24971539633614, 46.81420714514596, 46.805897099631174, 46.1302056312561, 45.85009247916085, 47.66312762669155, 54.40003844669887, 58.713410649980815, 64.12732192448208, 61.07454054696219, 71.4276065826416, 4.752789744309016, 0.10673467123082706, 0.2840875488306795, 1.0348538415772575, 60.93537507738386, 54.47632966722761, 59.24542031969343, 33.32128143310547, 46.81975875582014, 40.23140736988613, 33.65445450374058, 50.923806054251536, 53.53356334141323, 32.19509308678763, 0.3421286200838429, 0.014737387054732867, 0.03436299127393535, 0.06673862133175135, 0.06319731992802449, 0.17384046821721963, 0.054581492607082636, 0.064602952716606, 0.022917667836216942, 0.026232481036069136, 0.03247885559020298, 0.04111750204382198, 0.12438100576400757, 0.056451969380889616, 4.294508712632315, 59.77581800733294, 60.47120067051479, 45.16479165213448, 45.047606808798655, 83.41085202353341, 37.127845082964214, 35.95810890197754, 57.93546601704189, 64.80814811161586, 47.01012202671596, 0.3307861472879137, 0.19309706134455545, 0.08060873885239873, 0.5054043659142086, 4.210397294589451, 75.99320534297398, 62.44698347364153, 68.12659386226109, 59.14182267870222, 63.575628008161274, 57.00788497924805, 55.469435691833496, 55.60176413399832, 56.79516587938581, 55.243820735386436, 51.974599497658865, 50.99343395233154, 51.25610712596348, 47.56167350496565, 47.276040009089876, 43.89816631589617, 42.1542900630406, 41.72873026984078, 41.3854649407523, 42.03147023064749, 45.381328787122456, 46.18936259405953, 50.23519788469587, 53.791126114981516, 53.24086005347115, 52.96302243641445, 55.59564624513899, 34.29243809836251, 53.74935701915196, 53.7504027230399, 55.12789699009487, 50.07243633270264, 49.83798326764788, 47.59029313496181, 50.333049365452354, 44.192547593797954, 44.0272673198155, 48.476421219961985, 45.89964703151158, 44.0968257359096, 42.59820352281843, 43.9818434715271, 39.2825995853969, 36.222032751355854, 40.56724507468087, 38.215241636548726, 39.749108586992534, 39.086583954947336, 41.54550279889788, 38.38340193884713, 41.994957447052, 43.187407289232524, 41.92497866494315, 42.27435493469238, 41.50779839924404, 40.434145382472444, 43.25301912852696, 40.326674120766775, 40.49522352218628, 44.02483892440796, 46.171828814915244, 48.990890162331716, 50.81950317110334, 41.545318671635215, 33.52166748046875, 35.67232949393136, 33.725795132773264, 46.87622676576887, 53.31418439320156, 47.389250482831685, 47.66993686131069, 43.98141963141305, 43.547306605747764, 42.9716066632952, 41.91547352927071, 39.984874861580984, 41.49840790884835, 40.57832745143345, 41.395202841077534, 41.64696386882237, 42.59613643373762, 39.25117635726929, 37.21918610164097, 36.85856417247227, 36.82673794882638, 36.148107392447336, 37.98330381938389, 37.26892825535366, 37.25760269165039, 38.40611560004098, 42.97633491243635, 42.96533243996756, 43.47199855531965, 47.801518372126985, 47.78594051088606, 45.25977005277361, 52.80725424630301, 47.399238518306184, 48.777316434042795, 47.97000871385847, 50.66754606791905, 51.870626653943745, 54.96361378261021, 53.02697018214634, 65.16288144247872, 40.13698135103498, 31.184415067945206, 58.34664303915841, 53.05273757662092, 54.02896990094866, 48.54194968087332, 43.5887838772365, 39.12680012839181, 44.381392683301655, 41.5518673488072, 44.02697549547468, 42.541943958827424, 45.23084122794015, 45.75141068867275, 49.014771120888845, 50.04177393232073, 51.046677998134065, 49.739169461386545, 49.958058561597554, 49.27216018949236, 50.05365187781197, 49.6972405569894, 57.351146834237234, 61.35062026977539, 65.87024974822998, 64.16930294036865, 73.46866771153041, 4.389872304030827, 0.1538025148745094, 0.03875718066202743, 1.4741895241396767, 69.00834805624825, 60.84925215584891, 64.07690579550606, 39.0195894241333, 55.47311128888811, 38.627182960510254, 39.8884060723441, 54.84372956412179, 63.50960622514997, 39.11162873676845, 0.22487801313400269, 0.009958060341887176, 0.020230660680681467, 0.04133307940459677, 0.05388638437060373, 0.08729588466563395, 0.12648441003901617, 0.1326172538101673, 0.14164440227406366, 0.09613498393446207, 0.12748780048319272, 0.14810693264007568, 0.218242809176445, 0.20085547145988258, 6.18090945482254, 71.25953660692487, 70.1775770187378, 56.07166733060564, 40.97931146621704, 81.96956634521484, 45.17628744670323, 42.6517949785505, 63.311589513506206, 71.47898156302315, 51.45930371965681, 0.3412681833973953, 0.2054771227496011, 0.6813125610351562, 0.6045302440013204, 5.59909987449646, 81.35000937325614, 67.35218933650425, 68.5268656866891, 61.930100032261436, 67.60408932822091, 59.5743966783796, 59.2100887298584, 56.806244782039094, 58.57909502301897, 57.42496449606759, 54.656197684151785, 53.261367661612375, 53.97828279222761, 50.71621125085013, 50.00978095190865, 47.12097011293684, 45.712782178606304, 44.28977721078055, 43.98590816770281, 43.38181093760899, 46.70504747118269, 47.86077260971069, 52.5079015323094, 54.46298565183367, 55.739894321986604, 52.23557383673531, 57.94555827549526, 41.06860971450806, 55.15384503773281, 56.42622000830514, 55.98204946517944, 53.81499317714146, 51.03696094240461, 50.40505354745047, 54.3024787902832, 47.964224338531494, 48.31051213400704, 52.04325812203543, 48.428047861371724, 49.020190715789795, 46.03231940950666, 48.55243798664638, 41.19529969351632, 37.74630076544625, 42.01659761156355, 40.34116111482893, 42.081914152417866, 40.9486768586295, 43.64748920713152, 41.232180731637136, 45.366414478846956, 46.39036703109741, 44.036299977983745, 45.0730858530317, 44.47007949011666, 43.30543286459786, 44.52344165529524, 42.63895123345511, 43.48831639971052, 45.78509555544172, 48.803358282361714, 50.14454473767962, 51.488267285483225, 42.56014823913574, 33.68719094140189, 34.11866365160261, 34.95083897454398, 49.77175651277815, 56.646526541028706, 49.294401373182026, 49.73645618983677, 46.368921416146414, 45.6207845551627, 45.41109486988613, 44.27642624718802, 43.77622543062483, 43.31483030319214, 42.67978927067348, 43.396266664777485, 45.02864170074463, 45.39092077527727, 41.54093435832432, 40.281319754464285, 39.28294699532645, 39.23345497676304, 39.12511171613421, 39.87752171925136, 40.689095633370535, 38.21517562866211, 40.07650075639997, 46.05952508108956, 46.02589579990932, 45.914453642708914, 51.08374316351754, 51.820075035095215, 50.03301225389753, 55.95945392336164, 49.445090430123464, 51.313770226069856, 49.62227644239153, 54.19080039433071, 55.45756816864014, 56.647930077144075, 56.336119243076865, 60.311767305646626, 38.95092732565743, 34.577046734946116, 58.446988923209055, 55.07904767990112, 56.35232244219099, 51.9412134034293, 45.370795318058555, 41.54599959509713, 45.91647556849888, 43.42541088376726, 47.022736481257844, 43.936245918273926, 47.13980320521763, 48.48342500414167, 51.76258563995361, 55.130096094948904, 54.332098960876465, 52.621511527470176, 53.63530233928135, 52.72441782270159, 53.544854164123535, 51.9175443649292, 60.42228535243443, 65.51011766706193, 71.12092004503522, 65.43330533163888, 78.64709063938686, 6.426302458558764, 0.37056005160723415, 0.4660566087280001, 1.5917287256036485, 75.01425974709647, 66.30005141666958, 74.26818997519356, 44.81608935764858, 62.524344716753276, 51.82047455651419, 47.23187378474644, 66.29638276781354, 73.77968992505754, 46.97802482332502, 0.6211494665060724, 0.06414080930075475, 0.11364338586905173, 0.14580353695367063, 0.1518072962228741, 0.32850629676665577], [0.04602524405345321, 0.07507625608039753, 0.08751108204679829, 0.04814855654590896, 0.09665785623448235, 0.034990568312683275, 0.14417038458798612, 0.16189738336418355, 2.1238901700292314, 49.29176800591605, 56.77883413859776, 48.16517318998064, 21.666930709566387, 27.007887635912212, 33.603135108947754, 24.76325123650687, 54.04376956394741, 52.9778151512146, 52.7188766343253, 2.041297150509698, 0.18418985073055538, 0.5073886194399425, 0.11975229771009513, 0.4007184904600893, 22.34641589437212, 63.89754499707903, 40.07028906685965, 63.24073873247419, 57.930918421064106, 62.21250261579241, 57.44879681723458, 56.36291149684361, 53.81793226514544, 53.627871240888325, 51.61644765308925, 55.023156370435444, 48.67619582584926, 47.39241886138916, 43.81038972309658, 41.169942242758616, 38.36475644792829, 42.16328798021589, 39.411863871983115, 44.49046203068325, 41.749168395996094, 45.26294885362898, 47.76020438330514, 53.2439728464399, 53.199059690747944, 59.41878482273647, 32.245074953351704, 42.146699156079976, 57.55051497050694, 52.10109840120588, 49.2427727835519, 48.91584266935076, 48.80155175072806, 46.22868939808437, 47.1095472744533, 42.271936961582725, 40.80323369162423, 42.25152315412249, 40.61477770124163, 38.97693790708269, 38.87716177531651, 40.51591873168945, 38.74055324281965, 35.0545825277056, 35.60150303159441, 35.515411376953125, 35.821510791778564, 38.007077080862864, 36.57706485475813, 35.60777030672346, 38.43649312428066, 39.454862798963276, 39.00280952453613, 41.30850321905953, 41.10076250348772, 40.828142983572825, 37.355381216321675, 38.20532308306013, 38.11912373134068, 43.72428069795881, 47.362030914851594, 45.27658469336373, 46.12917034966605, 42.01933172770909, 35.62202453613281, 36.426174300057546, 36.45479393005371, 46.5716107913426, 50.13313232149397, 48.00555222375052, 45.28712511062622, 43.86282082966396, 40.23653514044625, 41.2744778905596, 39.80338791438511, 39.54303196498326, 39.805138860430034, 38.503751686641145, 40.02358675003052, 39.14161021368844, 38.06773138046265, 33.792237281799316, 35.70729977743966, 34.16346563611712, 34.77890927450997, 34.339307171957834, 36.07798269816807, 31.762574672698975, 34.573940890175955, 37.632127966199604, 37.841480663844514, 38.23259823662894, 42.437293665749685, 43.590809277125764, 44.235442297799246, 42.85331358228411, 47.97661297661917, 44.83287967954363, 45.05904006958008, 47.144385542188374, 44.79490082604544, 51.68136814662388, 48.704058102199006, 55.368957792009624, 52.53255374091012, 43.854000091552734, 34.49424157823835, 46.47618770599365, 53.67658158711025, 52.55645554406302, 49.98103972843715, 47.999347482408794, 41.03123188018799, 39.79591165270124, 39.873328481401714, 39.61240972791399, 38.73412615912301, 41.545089381081716, 41.86202451160976, 42.834265095846995, 44.49795913696289, 45.61542054585048, 45.02890920639038, 46.36584683826992, 45.43074090140206, 47.405953952244346, 47.35369655064174, 54.93770742416382, 62.094147000994, 63.49715505327497, 70.26998805999756, 46.4609294618879, 0.1936403371925865, 0.1434704621455499, 0.6532760368926185, 8.478472454207283, 67.97160734449113, 54.895146233694895, 57.71882118497576, 29.99809353692191, 46.81558288846697, 40.876662254333496, 39.762598514556885, 45.55938679831368, 54.22372790745327, 36.43800013405936, 0.4103789020861898, 0.021182777626173835, 0.06878473689513546, 0.059336584593568525, 0.08443445499454226, 0.09307703695126943, 0.04364634099017296, 0.11778584894325052, 0.07833639971379723, 0.07887582148292235, 0.04664852596553309, 0.030600714763360362, 0.1573198368506772, 0.1142334331359182, 3.2293262013367245, 56.72937338692801, 63.132548332214355, 54.42392635345459, 29.20008945465088, 36.70790638242449, 38.636802741459434, 29.89759131840297, 58.36630644117083, 59.754869188581196, 59.82012666974749, 1.9988212926047189, 0.45029326315437046, 0.6087013887507575, 0.04993043700233102, 0.5003348950828824, 26.338908127376012, 69.37248229980469, 51.15032775061471, 68.05608354296002, 57.933360712868826, 65.87764957972935, 57.49263647624424, 58.547772543770925, 55.840535504477366, 57.079031058720176, 53.582336221422466, 56.60380901609148, 49.213982922690256, 51.63081652777535, 44.62768200465611, 43.70792463847569, 40.46917472566877, 45.18933963775635, 40.201509271349224, 46.85759169714791, 44.083297593253, 50.820920603615896, 50.99617501667568, 56.336942604609895, 52.52809647151402, 57.61035285677229, 36.40086201259068, 44.5549760546003, 58.66644082750593, 53.11091136932373, 52.57302699770246, 51.34718411309378, 49.811191013881135, 48.29673385620117, 50.583087239946636, 46.743453638894216, 44.23207589558193, 46.485168252672466, 45.13893045697893, 41.94573640823364, 43.15947553089687, 42.65340001242501, 38.976743357522146, 39.14419494356428, 36.185777051108225, 36.57204130717686, 37.66716078349522, 40.35880953924996, 39.33730970110212, 37.521165234701975, 41.03449753352574, 42.58501236779349, 40.11042186192104, 41.41960144042969, 42.701384271894185, 41.87165124075753, 38.85683134623936, 40.0830112184797, 38.713038376399446, 46.29437071936471, 47.27421610695975, 47.9652214050293, 47.02944496699742, 43.88132735661098, 35.4095208304269, 36.60045249121529, 35.57610041754586, 47.16562965938023, 52.592398575374055, 49.377800600869314, 46.546850885663716, 45.39963034221104, 39.795348848615376, 42.47276074545724, 41.22638940811157, 40.684860706329346, 41.101912430354524, 41.83699015208653, 42.96943187713623, 40.728953974587576, 40.4124287877764, 36.2179228918893, 37.43225608553205, 36.86148588997977, 34.003101212637766, 36.86142683029175, 37.131412982940674, 35.63470152446202, 36.6418012210301, 41.31754282542637, 41.69868973323277, 41.26898533957345, 44.945829595838276, 47.489440032414024, 48.016954217638286, 46.23812157767159, 50.76967069080898, 48.67751250948225, 47.12352705001831, 49.02392884663173, 47.67717688424246, 54.34100655147007, 51.735404287065776, 57.7637482370649, 52.4935257094247, 43.9444135257176, 35.966175760541645, 46.957652705056326, 54.76694502149309, 54.35720975058419, 53.925782203674316, 50.334029061453684, 43.28215639931815, 43.34795583997454, 41.49854339872088, 41.110163416181294, 41.92031642368862, 44.82289511816842, 45.86960302080427, 45.349255902426584, 47.539300305502756, 48.83035550798689, 48.99642787660871, 50.44922324589321, 47.17182745252337, 49.65092733928135, 52.00034604753767, 57.10220677512032, 66.06412533351353, 66.00907475607735, 72.90362630571637, 47.112493310655864, 0.30449410953692024, 0.1375497691333294, 0.776574969291687, 10.680616276604788, 76.88009425571987, 59.01658834729876, 67.79005786350795, 32.57384634017944, 52.066440786634175, 40.4504771232605, 46.5188809122358, 60.653820174080984, 60.291457721165244, 47.561003003801616, 0.4545341884451253, 0.044957691337913275, 0.051291615569165776, 0.06864805958632912, 0.15907877603811876, 0.05796424073300191, 0.09974993352911302, 0.1275207908557994, 0.21506964016173566, 0.14628763097737515, 0.11054144267524992, 0.16985012590885162, 0.2500336675771645, 0.32053169182368685, 5.410041127886091, 69.96041801997593, 69.27649988446916, 63.309359141758506, 28.817535536629812, 41.51676157542637, 49.849729197365896, 37.470082078661235, 67.19274207523891, 64.69765785762242, 66.53849274771554, 2.4383938653128485, 1.6139787031071526, 0.8025100976228714, 0.21990942688924925, 0.7140969304101807, 26.94548065321786, 70.61553587232316, 36.30466072899954, 69.03525148119245, 60.30557646070208, 68.73966121673584, 60.21351282937186, 61.33993394034249, 58.348699705941335, 59.34602328709194, 55.68538222994123, 60.69147246224539, 52.20134701047625, 54.003463063921245, 47.08355406352452, 46.07059703554426, 43.457046031951904, 48.39877162660871, 43.14613846370152, 49.37884977885655, 47.42911229814802, 52.38733639035906, 51.422134331294465, 57.62907130377633, 54.06277983529227, 57.76622526986258, 42.89053855623518, 47.12487152644566, 61.17309379577637, 56.73321226664952, 55.28204277583531, 54.718384061540874, 53.091425146375386, 50.856213978358674, 54.98988839558193, 51.50314685276577, 49.27902848379952, 50.55245263235909, 47.54635272707258, 46.22751515252249, 48.00893252236502, 47.32339545658657, 40.957799843379426, 41.63363374982561, 39.355166571480886, 38.848226002284456, 39.619469097682405, 43.04193632943289, 41.04746287209647, 40.06693656103951, 43.16861241204398, 44.36709329060146, 43.08861085346767, 45.355755942208425, 46.10271508353097, 46.049401555742534, 40.609493596213206, 43.87123509815761, 41.15294000080654, 47.790182386125835, 51.39367798396519, 48.70896005630493, 48.62694352013724, 43.237333570207866, 37.02206570761544, 37.12341908046177, 35.321309975215364, 49.23088788986206, 55.521203245435444, 53.203791413988384, 49.791503293173655, 46.72646876743862, 44.50111014502389, 44.87124068396432, 43.47442347662789, 43.85200943265642, 43.73255947657994, 44.74049295697893, 46.78611210414341, 42.69278587613787, 42.69041306631905, 38.557645389011924, 41.72775752203805, 38.605685234069824, 38.208870138440815, 38.78605352129255, 40.28841386522566, 36.38590948922293, 38.27078206198556, 44.79644332613264, 46.238072940281455, 45.29184641156878, 49.23494911193848, 50.302668367113384, 53.881265095302034, 51.6018077986581, 53.89780528204781, 51.008699144635884, 49.77996233531407, 49.33709110532488, 51.71524061475481, 56.36535031454903, 53.344735622406006, 59.88295922960554, 55.01935223170689, 46.14799301964896, 35.64722565242222, 47.75776209150042, 56.17214870452881, 58.12534291403634, 56.21737452915737, 53.864631107875276, 46.0159147126334, 44.96063968113491, 44.37713691166469, 44.63178491592407, 44.1531652041844, 47.304003034319194, 48.205573490687776, 47.316231863839285, 49.60648318699428, 53.38205092293875, 52.135634422302246, 54.40696580069405, 51.72581924710955, 52.935253960745676, 53.85462917600359, 61.092459951128276, 69.23226070404053, 71.02250576019287, 74.27471433367047, 54.1855023929051, 0.5181020359907831, 0.6104798018932343, 1.776014385478837, 11.314536912100655, 83.18373625619071, 65.85015555790493, 74.58486802237374, 40.521168095724924, 62.40109757014683, 54.0108003616333, 48.92298541750227, 62.104152406964985, 70.71273422241211, 59.03951045445034, 0.8306066042610577, 0.15020876271384104, 0.12200272695294448, 0.11960311500089509, 0.1760494118290288, 0.1978925940181528], [0.022750369938356534, 0.020605658147750155, 0.10606834305716412, 0.025935811955215674, 0.05980923851685865, 0.030596426422042505, 0.23867461138537951, 0.07272123744977371, 4.873820415564945, 51.0674044745309, 56.46850674492972, 43.78759615761893, 33.890832219805034, 20.40039222581046, 34.0944561277117, 33.39979955128261, 61.65974562508719, 48.033272062029155, 61.75056552886963, 10.182228071349007, 0.5600612301911626, 0.5776512463177953, 0.05010181459199105, 0.056007254136992354, 0.7648341964398111, 42.1253091267177, 25.240611587251934, 51.712721892765586, 64.87731048039028, 58.358586992536274, 59.27511692047119, 58.221752643585205, 55.629807063511436, 55.5545129094805, 52.78422791617257, 53.65953418186733, 50.313010760716026, 45.888936383383616, 45.72571625028338, 40.39670501436506, 37.51610347202846, 39.74925102506365, 41.180239473070415, 43.13790832247053, 48.319965158190044, 50.0906023979187, 52.362010206495015, 51.47309936795916, 57.53124066761562, 39.272097383226665, 33.66739552361624, 53.91504028865269, 53.19057246616909, 53.30042348589216, 46.90239020756313, 50.228082929338726, 46.425132342747276, 48.229027135031565, 47.16663367407662, 43.17114850452968, 39.226982729775564, 41.33362095696585, 40.833913462502615, 40.772616454533164, 39.14693600790841, 39.17942231042044, 40.44834055219378, 41.43183721814837, 36.825080803462434, 36.6114375931876, 37.72180836541312, 35.875696318490164, 34.39578907830374, 36.297827175685335, 39.15445743288313, 38.668875626155305, 38.755675997052876, 37.27524764197213, 39.60551016671317, 38.151439802987234, 38.919469356536865, 38.29899869646345, 41.43847622190203, 42.40883037022182, 44.88481398991176, 45.748721735818044, 50.131277152470176, 47.25875636509487, 36.17076894215175, 35.93321003232683, 37.44487401417324, 46.430294854300364, 49.21931219100952, 46.57489728927612, 44.61760711669922, 45.190993309020996, 41.74878624507359, 38.700715746198384, 39.123652594430105, 39.82711948667254, 38.741421767643516, 37.49080160685948, 39.047986711774556, 39.573180198669434, 37.50189093181065, 34.79074205671038, 34.30075509207589, 35.704305103846956, 35.662963322230745, 33.13203682218279, 32.91001408440726, 34.79992757524763, 39.39184263774327, 36.763109820229666, 39.335030691964285, 36.91903781890869, 40.090393679482595, 43.63158130645752, 44.48594222749983, 44.13321345193045, 47.673386641911094, 47.7347982951573, 44.16329915182931, 45.31348657608032, 44.14011301313128, 49.08532312938145, 50.87574189049857, 52.00813150405884, 50.00431619371687, 42.10837984085083, 40.307792391095845, 43.355105536324636, 51.28921181815011, 52.87020492553711, 51.918440682547434, 49.72658627373831, 42.967059067317415, 39.66673769269671, 39.9625746182033, 40.94617550713675, 40.60747514452253, 43.24491058077131, 42.64827919006348, 43.07463802610125, 41.71827670506069, 43.592157227652415, 44.197230679648264, 45.67411545344761, 44.54244497844151, 44.45559597015381, 48.87586620875767, 58.95325551714216, 64.40222045353481, 65.10824080875942, 66.95956747872489, 16.712472540991648, 0.991932539003236, 0.3637335007744176, 0.8311356444443975, 19.052481651306152, 62.90789917537144, 55.18873194285801, 56.149421146937776, 33.621857030051096, 55.031824248177664, 45.595670291355674, 41.89423288617815, 46.24072715214321, 58.22430610656738, 46.25891753605434, 1.0942706018686295, 0.024622079949559908, 0.10041246190667152, 0.010401885008572467, 0.15171340054699353, 0.03596228474218931, 0.03782846299665315, 0.036988640204072, 0.051382661397968016, 0.039932145471019406, 0.16751798747905663, 0.09587165127907481, 0.17444349585899285, 0.15264274924993515, 7.004856373582568, 58.82365076882498, 63.56267656598772, 47.58135775157383, 32.74692596708025, 30.434680121285574, 41.51022679465157, 39.81976481846401, 66.66515145983014, 56.93725306647164, 67.03670637948173, 11.988206454685756, 0.7591183260083199, 0.8431256839207241, 0.08923849649727345, 0.03747204212205751, 0.9623183395181383, 48.00513880593436, 32.9886850629534, 57.516031060900005, 63.965095383780344, 60.6611852645874, 59.96670586722237, 60.05155726841518, 56.617170401981895, 58.776806013924734, 52.66069936752319, 57.01174817766462, 52.20159714562552, 47.73599338531494, 46.2183643749782, 41.84184694290161, 38.979255131312776, 42.598491873059956, 41.61455052239554, 45.06414352144514, 49.28570570264544, 53.116410868508474, 54.04564905166626, 54.305042675563264, 57.24474906921387, 42.695672852652415, 36.37462214061192, 56.818595205034526, 53.1223064150129, 54.90450545719692, 49.655579158238, 51.74835572923933, 48.16341182163784, 50.742002964019775, 51.42739759172712, 48.2668149130685, 42.93567058018276, 45.195881366729736, 43.69105788639614, 42.42077432359968, 42.115321091243196, 43.0162627356393, 42.879841804504395, 43.78214529582432, 39.548031193869456, 38.259796960013254, 39.79303857258388, 38.86185141972133, 37.43116174425398, 38.3491473197937, 41.183651038578574, 40.47266272136143, 39.7403747013637, 38.9810790334429, 41.6938259942191, 39.60757030759539, 38.640148299080984, 42.08653817858015, 43.07041352135794, 44.84609167916434, 47.551518712724956, 46.689386231558665, 49.52672481536865, 47.35531895501273, 35.07028545652117, 35.750569684164866, 37.56907653808594, 46.069262981414795, 52.28981842313494, 48.44398702893938, 45.72571277618408, 45.77617059435163, 42.76767703465053, 42.140147004808696, 41.376088346753804, 41.70130920410156, 42.042945180620464, 39.64258228029524, 40.718903405325754, 41.888309546879356, 37.68659836905343, 36.42298855100359, 35.42113127027239, 37.95858907699585, 36.62930835996355, 36.24347141810826, 34.920249530247276, 37.42078460965838, 40.67765542439052, 38.77258791242327, 43.75387307575771, 40.03453711100987, 43.51033524104527, 48.37431744166783, 47.98494734082903, 48.47438539777483, 49.0122697693961, 50.85428237915039, 45.46095861707415, 48.720983913966585, 46.66097157342093, 52.23046691077096, 51.85841172082083, 54.25984811782837, 53.424698965890066, 43.956103869846885, 41.56936638695853, 44.73440286091396, 51.20473561968122, 56.079602173396516, 54.45500564575195, 52.97170768465315, 44.98670237404959, 42.05728626251221, 42.46321044649397, 44.548000063214985, 44.24799421855381, 44.692147391183035, 45.15993138722011, 45.48058032989502, 44.76947736740112, 47.625134876796174, 48.19769770758492, 47.367116996220176, 47.401451519557405, 47.773221833365305, 51.21163170678275, 61.72986684526716, 67.08749076298305, 67.47691644941057, 69.16769804273332, 17.22096429552351, 1.2384058790547507, 0.4428259852741446, 0.9118362026555198, 22.39582106045314, 71.91549519130162, 60.75938415527344, 64.53188078744071, 40.24814905439104, 56.554726941244944, 46.511536666325156, 33.96746390206473, 59.38560022626604, 63.71107619149344, 57.559481620788574, 1.7348117849656512, 0.10137987642415933, 0.09811024008584873, 0.044172368478029966, 0.1765041931399277, 0.015481429540419152, 0.19111900962889194, 0.11489172066961016, 0.21047730158482278, 0.16246709493654116, 0.29293355558599743, 0.21575322348092282, 0.43951842561364174, 0.3205149184380259, 9.54931926727295, 73.59839752742222, 70.30454839978898, 57.24020494733538, 46.611257212502615, 33.70319611685616, 51.047810554504395, 48.08189902986799, 72.33445072174072, 61.756395067487446, 74.87687996455601, 13.644314799989973, 1.9226542711257935, 1.8507260850497653, 0.2514484945152487, 0.14770920255354472, 1.2388149542467934, 52.30424983160836, 28.78923726081848, 53.29281520843506, 69.82658181871686, 61.48454679761614, 62.96707698277065, 62.11321285792759, 59.31851536887032, 59.735143252781455, 55.3788937159947, 59.45738206590925, 55.798655237470356, 50.55019794191633, 51.07112176077706, 42.90411533628191, 41.58999906267439, 44.78837299346924, 44.25619656699044, 47.881193365369526, 53.200081075940815, 56.0663172176906, 55.11441053662981, 55.53359188352312, 58.136678900037495, 47.926554679870605, 39.4697527885437, 58.910760334559846, 56.589978626796174, 57.601629393441335, 51.55767631530762, 55.01300852639334, 52.30643504006522, 54.33780343191964, 55.576667240687776, 54.356855392456055, 46.519572257995605, 49.26008422034127, 48.50582947049822, 47.976960386548726, 46.85709490094866, 46.23060015269688, 45.24685335159302, 45.111644881112234, 41.97798299789429, 40.475205762045725, 42.603102002825054, 41.569425446646555, 40.37220914023263, 39.27836118425642, 44.477965695517405, 43.948644978659495, 42.28037207467215, 40.83171088354928, 44.56031574521746, 41.207174164908274, 40.84119517462594, 44.476534366607666, 46.33978067125593, 46.65353005273001, 49.324292523520334, 48.61472858701433, 53.38955497741699, 49.73601150512695, 35.658651965005056, 36.11105612346104, 37.782167366572786, 48.72628191539219, 55.31368487221854, 51.55098172596523, 47.797762870788574, 48.148959568568635, 47.08786889484951, 43.533493586948936, 43.41697229657854, 45.20640441349575, 44.614094802311485, 40.970362186431885, 44.23843002319336, 45.26091650554112, 40.33124950953892, 39.04397760118757, 37.68832499640328, 39.75707817077637, 39.38730198996407, 37.937987668173655, 36.824361664908274, 38.80700928824288, 42.47066238948277, 41.471365519932334, 47.40231309618269, 43.07173020499093, 47.39366953713553, 51.83887686048235, 52.88009916033064, 54.4774101121085, 53.491481576647075, 53.43118858337402, 48.574460302080425, 51.464487075805664, 49.225833075387136, 53.76818663733346, 53.84319938932146, 55.606499331338064, 55.83091572352818, 43.907174655369346, 43.64398036684309, 46.45713227135794, 52.77774177278791, 58.10932036808559, 55.80848693847656, 56.00842135293143, 48.91535629544939, 44.77388947350638, 44.31166751044137, 46.607098715645925, 45.714397634778706, 48.233758858272004, 48.103330748421804, 49.71939141409737, 46.82472671781267, 49.88897957120623, 50.36802659715925, 50.65518174852644, 51.06272138868059, 50.28755603517805, 54.82498679842268, 66.04579598563058, 70.28740719386509, 72.63765621185303, 72.27115263257707, 23.088968140738352, 1.1271464377641678, 0.46268369257450104, 1.6763015474591936, 25.529024362564087, 76.59023625510079, 67.45659991673061, 70.42447430746896, 46.42229747772217, 71.39021137782505, 60.13697147369385, 50.54316289084298, 61.25966140202114, 74.71616813114711, 67.48339911869594, 2.652037726981299, 0.24538347710456165, 0.222254837464009, 0.10347073458667312, 0.36421482637524605, 0.166555309135999], [0.08215568334396396, 0.02447548585145601, 0.1439480558037758, 0.15815299642937525, 0.08476949523070029, 0.02539310946927539, 0.046215702047837634, 0.03993641006361161, 5.59469428232738, 57.85758365903582, 48.231386048453196, 49.45472410746983, 31.46859986441476, 16.02195187977382, 36.57437937600272, 28.471129621778214, 56.19848237718855, 55.23818922042847, 56.96922867638724, 29.688707624162944, 0.25749052315950394, 0.2857585905918053, 0.14835457078048161, 0.678819514811039, 0.09799350492124047, 11.974623594965253, 30.833656106676372, 43.58891589300973, 62.26441955566406, 58.82218469892229, 62.428035736083984, 58.68457562582833, 58.245908055986675, 53.786689690181184, 51.09179959978376, 51.23606504712786, 48.28485591070992, 43.26123884746006, 40.68749059949602, 39.604120526994976, 39.53915139607021, 39.914242948804585, 43.2892609323774, 45.71257373264858, 50.61658797945295, 51.41775696618216, 52.37077188491821, 53.43746975490025, 46.529285839625764, 36.95721122196743, 50.57955755506243, 51.339582783835276, 53.2980888911656, 52.269397667476106, 49.409359318869456, 47.0106257711138, 45.48908839906965, 49.21757166726248, 44.474303994859966, 39.28211668559483, 41.85790770394461, 40.74633836746216, 37.90484128679548, 36.16218096869332, 40.55659001214163, 37.38644313812256, 41.10801989691598, 41.83518362045288, 43.37351131439209, 34.78759799684797, 35.670588970184326, 37.87343890326363, 37.22322300502232, 37.56137098584856, 36.395421573093955, 37.708891664232524, 39.91345085416521, 37.326403754098074, 39.638993535723, 37.972631386348176, 40.08856282915388, 36.87437827246529, 38.34004865373884, 40.488171100616455, 42.31642975125994, 44.58893537521362, 49.57791914258684, 47.143638610839844, 38.124376569475444, 32.70383671351841, 39.18149982179914, 49.09195865903582, 49.00488036019461, 46.892593247549875, 45.49203096117292, 43.6589606830052, 42.24219867161342, 38.19392803737095, 39.74222639628819, 40.326958996909006, 39.62461771283831, 37.36303465706961, 36.60493755340576, 37.105027198791504, 36.378777163369314, 35.29895067214966, 36.38859149387905, 34.543612003326416, 34.8678879056658, 34.8125524520874, 37.516926833561485, 39.35594824382237, 37.31595366341727, 36.71844679968697, 38.88161209651402, 36.70945235661098, 40.05915457861764, 44.179933139256065, 42.80945307867867, 45.23493719100952, 48.01062788282122, 47.245144844055176, 45.62380007335118, 46.26452473231724, 45.52737297330584, 50.16903018951416, 49.97518587112427, 52.48883220127651, 52.909920828683035, 47.444610255105154, 46.667440346309114, 46.09121234076363, 44.65004130772182, 50.31605407169887, 54.19400003978184, 52.164830752781455, 48.96152012688773, 40.68557637078421, 41.23310831614903, 41.136813231876914, 40.66238675798689, 42.02598115376064, 42.34296144757952, 42.93938091823033, 42.5407384463719, 41.91836745398385, 42.6497209412711, 45.948652676173616, 44.15620156696865, 45.804237842559814, 48.153204917907715, 58.332704952784944, 62.90127059391567, 66.09314795902797, 61.17723492213658, 3.371078137840543, 0.4998368503791945, 0.4605188401682036, 0.266348906393562, 25.879090241023473, 63.025177819388254, 53.9201089995248, 55.00693927492414, 33.92862694604056, 58.073068141937256, 41.887222153799875, 59.50829151698521, 36.59928866795131, 56.543040071214946, 54.10870395387922, 5.800050897257669, 0.21394804891731056, 0.1316300124994346, 0.038408556154796054, 0.06393070093223027, 0.045293549208768775, 0.09029213924493108, 0.015544037966589843, 0.12964334338903427, 0.05426955988098468, 0.18307847822351114, 0.04108838610617178, 0.13936504029801913, 0.023272962342681627, 9.830055151666913, 66.68997042519706, 54.49341181346348, 48.91451556341988, 42.98285927091326, 27.050297703061783, 43.56566374642508, 35.82536704199654, 60.69880975995745, 60.527654784066335, 61.74902997698103, 34.89216491154262, 0.2413807176053524, 0.3909447634858744, 0.18042209504970483, 0.7984169029763767, 0.14753408623593195, 14.283853922571454, 35.649261474609375, 47.23914507457188, 61.65593801225935, 61.07152502877371, 62.85949107578823, 61.98196833474295, 60.18127318790981, 54.740010329655235, 53.70087248938424, 53.140944957733154, 49.9533303124564, 46.07663154602051, 42.61372232437134, 42.058484826769146, 40.44631862640381, 42.61905854088919, 43.83008786610195, 48.30213608060564, 52.16122463771275, 53.47503171648298, 55.58646420070103, 54.31263010842459, 50.216145924159456, 40.65934344700405, 52.88378517968314, 55.15584264482771, 53.88884905406407, 54.09661061423165, 52.28845657621111, 47.6916743006025, 47.39272805622646, 48.3865566934858, 48.14174386433193, 43.42609528132847, 46.9187045778547, 45.019556931086946, 41.51398924418858, 40.297870363507954, 43.92495162146432, 40.65560531616211, 43.76417030606951, 45.05940137590681, 44.186450549534385, 38.18588202340262, 37.13663802828108, 40.101899896349224, 39.22401237487793, 37.44356427873884, 38.55977848597935, 40.37569713592529, 41.06777940477644, 40.14955759048462, 39.0520270892552, 39.63545342854091, 42.470804827553884, 39.36396646499634, 41.133624008723665, 40.96199655532837, 43.547306605747764, 45.14700426374163, 51.63198035103934, 48.72991234915597, 37.45518166678292, 32.638214451926096, 39.59044994626726, 49.8064523424421, 51.32155220849173, 48.610406807490754, 47.8041204724993, 46.093265533447266, 43.55121496745518, 40.03506864820208, 41.552986008780344, 39.79097843170166, 42.049539021083284, 38.933925083705354, 38.78734588623047, 40.61717135565621, 37.82551717758179, 36.11745888846261, 36.51650782993862, 37.173050062997, 36.252851486206055, 37.55646208354405, 38.31706748689924, 41.527183873312815, 40.52420793260847, 39.088442598070415, 41.1090794972011, 40.179309776851106, 43.73995583398001, 46.20816094534737, 45.61149481364659, 48.35214226586478, 51.56611142839704, 50.77052879333496, 48.40741171155657, 49.493710449763704, 46.779358455113, 53.348748207092285, 53.636455740247456, 54.98595571517944, 54.5962347303118, 49.59119020189558, 49.89944008418492, 48.265032700129915, 45.471745695386616, 52.55333232879639, 56.42916604450771, 55.46915428979056, 52.038613251277376, 44.65942832401821, 42.47481393814087, 43.52835886819022, 43.36967938286917, 44.89569139480591, 45.628799302237375, 45.35689197267805, 44.23653663907732, 44.753065722329275, 45.86210591452462, 47.58456781932286, 46.48740209851946, 50.36541060038975, 50.99598741531372, 61.85940905979702, 66.73183332170758, 67.14183262416294, 62.57147434779576, 3.557325686727251, 0.5003203472920826, 0.2403287983366421, 0.37372319187436787, 30.650598866598948, 70.04356711251395, 60.947221755981445, 62.57294041769845, 38.249454566410606, 58.281333446502686, 49.19469819750105, 59.79195867265974, 45.09764773505074, 65.57664666857038, 63.60319151197161, 7.187698653766087, 0.41894964075514246, 0.12329566186027867, 0.02571588009595871, 0.07186327063079391, 0.058274799425687106, 0.1797014365770987, 0.07864604916955743, 0.2651139998010227, 0.2556176579424313, 0.253941540739366, 0.11742216774395534, 0.21046753068055424, 0.07822522853634187, 12.478542566299438, 82.15438842773438, 59.784058570861816, 68.09070641653878, 43.44094010761806, 24.310722010476248, 54.93068626948765, 40.64686100823538, 68.99147088187081, 66.17524092538017, 69.96034158979143, 37.49113859449114, 0.5728324534637588, 0.8847890368529728, 0.31495500249522074, 1.3058127420289176, 0.18857909020568642, 16.140606267111643, 34.61329896109444, 44.191554001399446, 64.98129722050258, 62.44852597372872, 65.474410874503, 62.447004318237305, 63.194734709603445, 57.15345321382795, 56.80221830095564, 55.47114494868687, 53.484140804835725, 47.064481258392334, 46.50602674484253, 44.205530302865164, 43.134045124053955, 43.752288886478965, 47.630109786987305, 48.81032732554844, 55.762062549591064, 56.67543452126639, 58.72953741891043, 56.10642916815621, 54.57702643530709, 42.80587823050362, 54.12164844785418, 57.281320912497385, 57.23560871396746, 56.175157274518696, 54.36748266220093, 50.44012457983834, 49.627984387534006, 53.91453307015555, 53.18345403671265, 45.5201016834804, 51.573066575186594, 50.23315511431013, 43.946355547223774, 42.84977000100272, 47.8247948374067, 44.961383138384136, 48.67649459838867, 47.62825114386422, 48.655111517224995, 39.386895520346506, 39.857483114515034, 42.59971128191267, 41.4546342577253, 40.79815108435494, 40.659426825387136, 41.83081667763846, 44.33102866581508, 41.2546512058803, 43.51515729086739, 43.86867468697684, 44.43552262442452, 40.22234344482422, 42.2953245980399, 43.76513957977295, 46.820338930402485, 47.52565404347011, 53.63732426507132, 51.09180307388306, 40.25954410008022, 32.52922848292759, 39.15938023158482, 51.585337093898225, 52.68706430707659, 51.666380882263184, 49.85464852196829, 48.86171620232718, 47.52348273141043, 41.83819566454206, 44.27655826296125, 43.47028929846627, 45.864829608372276, 41.104101112910676, 41.190675667354036, 43.51074865886143, 41.52941424506051, 38.61906051635742, 39.46517392567226, 39.38737147194998, 39.2968225479126, 39.233948298863, 41.893138544900076, 44.38435609000069, 43.07749720982143, 42.984328814915244, 45.87947293690273, 44.21340956006731, 46.87543814522879, 49.8241320337568, 50.503603322165354, 52.81094721385411, 55.27747433526175, 53.50827884674072, 49.63134036745344, 51.22015714645386, 51.19849961144583, 55.3246282849993, 56.087387629917686, 57.278704915727886, 59.04518018450056, 50.7826429775783, 51.68020779745919, 48.51534502846854, 45.620103631700786, 54.75358016150338, 59.44072028568813, 58.76502186911446, 55.259704317365376, 47.461855684007915, 44.8110797064645, 46.31894302368164, 47.16107511520386, 49.07450825827462, 48.47826944078718, 49.04418979372297, 48.36022996902466, 48.868014744349885, 47.5712377003261, 50.589493479047505, 51.07923378263201, 51.972164154052734, 53.05919245311192, 65.65463324955532, 70.40301132202148, 71.71660995483398, 65.05407265254429, 6.827270839895521, 0.6151142503534044, 0.6962626416768346, 0.4737522272127015, 34.339487825121196, 77.05794034685407, 67.3192618233817, 69.52120849064418, 46.49049752099173, 70.47125652858189, 60.10130637032645, 78.45657103402274, 50.98164980752127, 72.44892229352678, 77.79597800118583, 10.392707245690481, 0.7562941004123006, 0.3201189525425434, 0.1356281986726182, 0.1762495253767286, 0.20208395911114557], [0.009372949417281364, 0.02044752556165414, 0.19695221233580792, 0.11307877688003437, 0.05956292351973908, 0.017948935706434504, 0.16904265566595963, 0.04196985059284738, 12.00374870640891, 64.10426780155727, 51.1796213558742, 46.258997440338135, 21.97611165046692, 25.78788471221924, 36.712276799338206, 32.900467259543284, 56.236457756587434, 57.969529560634065, 49.727968965257915, 51.633745193481445, 1.4017657360860278, 0.04818361645032253, 0.030422070063650608, 0.1384129063891513, 0.14872389739113195, 1.031283010329519, 20.40368046079363, 48.297199385506765, 61.69936425345284, 58.700598171779085, 58.467242922101704, 55.367380550929475, 54.334662846156526, 51.82225329535348, 49.342257090977256, 47.16328811645508, 46.434651374816895, 40.015926361083984, 38.2613707269941, 37.026213782174246, 40.65236050742013, 40.19574574061802, 45.33403239931379, 49.05054044723511, 51.20526368277413, 51.443486145564485, 51.37465034212385, 47.73211976460048, 45.15343829563686, 49.59199619293213, 53.98010669435774, 52.55717815671648, 53.60842670713152, 52.22147594179426, 47.33635037285941, 48.350023065294536, 47.00484834398542, 49.0711453301566, 46.547278199877056, 42.09145055498396, 42.5275160244533, 41.79291425432478, 41.32567221777779, 37.66693149294172, 41.250794955662315, 37.99131856645857, 37.64478063583374, 38.882630007607595, 42.558161054338726, 43.590972559792654, 37.7544892174857, 36.599632603781565, 37.456515720912385, 36.524995054517476, 37.2692756652832, 35.58668599809919, 38.10301433290754, 37.6657919883728, 38.53816958836147, 38.828381947108674, 38.865822315216064, 38.88591997964041, 40.816410950251985, 38.834687437329976, 40.52569832120623, 44.53241177967617, 48.26848595482962, 46.914011069706504, 40.09585843767439, 37.00144692829677, 44.15326942716326, 48.46984822409493, 48.45636524472918, 46.849750655038015, 43.55781923021589, 43.30927174431937, 43.317168372017996, 38.390054838997976, 38.1327144077846, 38.652411869594026, 38.45423187528338, 37.75975942611694, 37.17087180273873, 37.37869937079293, 34.93544176646641, 34.283971718379426, 34.90377535138811, 33.56588929040091, 34.424836022513254, 35.56849908828735, 40.65039416721889, 39.33157048906599, 37.85483162743704, 36.89476081303188, 38.108503409794395, 37.05325269699097, 39.61892713819231, 45.75571509769985, 44.076088837214876, 43.51374333245413, 44.73937429700579, 48.863897936684744, 45.70949568067278, 48.57196937288557, 44.07452549253191, 51.11191463470459, 51.17412880488804, 52.06179591587612, 51.9658135005406, 50.20163461140224, 50.03837973730904, 52.76423447472708, 48.489299706050325, 45.94380978175572, 54.25447368621826, 52.81826366697039, 49.94799757003784, 42.913808073316304, 39.89075108936855, 40.605196135384695, 41.94343655450003, 41.60784203665597, 42.805419649396626, 45.454413414001465, 42.72201347351074, 43.88698666436331, 45.129550388881135, 45.83605711800711, 43.92238426208496, 46.49263061795916, 45.936159815107075, 60.78339712960379, 58.85784980228969, 71.60370867592948, 47.83879893166678, 0.4950030211891447, 0.09562504451189723, 0.0721029427700809, 0.2383277714252472, 38.06627573285784, 63.27015045710972, 57.46855749402727, 59.38116727556501, 36.33426005499703, 41.594105448041645, 41.50877462114607, 20.875683750425065, 36.09447424752371, 55.303307737622944, 59.435794012887136, 9.353787405150277, 0.3235578222998551, 0.109540148904281, 0.06264518919800009, 0.0574782807379961, 0.02227835892699659, 0.04440736211836338, 0.048013969124960046, 0.15111741609871387, 0.03127349580505064, 0.09789349564484187, 0.010717935594064849, 0.16455373939658913, 0.11021185107529163, 15.420649562563215, 75.54023143223354, 53.62892736707415, 66.71749223981584, 35.038236890520366, 24.16377976962498, 43.036666120801655, 39.13549927302769, 63.95691040584019, 64.21696758270264, 55.444575037275044, 58.198024545397075, 1.7328293770551682, 0.22780741165791238, 0.0862125288695097, 0.026198450808546374, 0.13203956266599043, 1.1996234229632785, 24.133555105754308, 50.28857742037092, 61.99203627450125, 59.400094168526785, 61.4081791469029, 57.80428750174386, 56.8212285723005, 54.554795673915315, 51.99906063079834, 48.97862311771938, 48.57516554423741, 43.118609700884136, 41.87660183225359, 40.1740847315107, 42.06137180328369, 42.385275976998464, 47.234031200408936, 52.92759704589844, 54.75420202527727, 54.493655000414165, 50.614830085209434, 48.81469774246216, 46.87299932752337, 50.14533683231899, 56.33626168114798, 53.67806850160871, 53.750135217394146, 53.96515417098999, 49.004310607910156, 50.877260071890696, 49.53761959075928, 50.59396811894008, 50.420363903045654, 46.24413524355207, 47.3695592880249, 44.54174321038382, 44.319571086338584, 41.10339934485299, 42.45237125669207, 39.829666001456125, 41.89361449650356, 43.30136469432286, 46.08377429417202, 44.84963526044573, 38.29716437203543, 38.626213686806814, 39.51402670996529, 38.22652898515974, 38.79568372453962, 38.07768814904349, 40.03226852416992, 39.15115703855242, 39.164177962711875, 40.937434673309326, 42.33102791649954, 39.853435788835796, 40.82459940229143, 38.35755116598946, 42.49545703615461, 46.83192157745361, 50.143599782671245, 48.5009309904916, 39.54651648657662, 37.446312291281565, 42.51879603522164, 51.01656103134155, 50.51421669551304, 48.13810995646885, 45.416552679879324, 44.37706742967878, 44.6657338142395, 42.52458735874721, 41.40373175484793, 40.48778200149536, 40.005549226488384, 40.10803862980434, 38.848236424582346, 39.79435178211757, 37.48762280600411, 37.48504849842617, 36.53662633895874, 35.98490810394287, 36.832088061741416, 38.46622446605137, 42.67329270499093, 42.71624299458095, 40.050219195229666, 40.090400627681184, 40.69144759859358, 41.697855949401855, 43.71319137300764, 48.821135248456685, 46.90088244846889, 47.957613127572195, 47.97233288628714, 51.76811293193272, 48.845266342163086, 49.566774232046946, 46.020708969661165, 51.685787200927734, 53.246547154017854, 54.267845494406565, 54.654352937425884, 53.265842301504954, 51.817337444850374, 54.75776645115444, 50.3739777292524, 46.96052578517369, 56.10335111618042, 55.06063495363508, 52.61175625664847, 45.84760502406529, 43.78985432216099, 44.87086548124041, 44.14359753472464, 43.96645321164812, 45.542780603681294, 47.158361843654085, 46.08834968294416, 46.49787303379604, 46.60076195853097, 47.88001217160906, 47.496002605983186, 48.25567347662789, 50.01193141937256, 63.91698605673653, 61.54229327610561, 73.47988210405622, 48.72611515862601, 0.8200242806758199, 0.39167796128562515, 0.09641184657812119, 0.7320427703005927, 44.24104949406215, 69.66324356624058, 62.05104732513428, 66.66342830657959, 35.9497641154698, 50.58853462764195, 53.22804757526943, 28.300085817064556, 44.49184124810355, 60.76827090127127, 68.66786548069545, 12.050795827593122, 0.464550749531814, 0.14149413390883378, 0.05486761046839612, 0.07543687708675861, 0.005319505472600992, 0.09853153569357735, 0.09365839218454701, 0.2672126271895, 0.1629697536783559, 0.18334545461194857, 0.06980437825300864, 0.3304172142275742, 0.2760776329253401, 19.09895294053214, 87.36876828329903, 62.311618668692454, 62.75284317561558, 28.170024224690028, 34.55594505582537, 51.90999514716012, 45.547658239092144, 69.6351797921317, 70.49029459272111, 61.82691233498709, 64.18882737840924, 2.196482126201902, 0.5643464773893356, 0.1286846955439874, 0.8791447111538478, 0.27065632811614443, 1.6253836282661982, 24.221328224454606, 50.94506754193987, 66.11607701437813, 62.65994576045445, 65.5638758795602, 60.922687666756765, 59.71603570665632, 55.5475994518825, 53.608506611415315, 51.56324182237898, 50.05328709738595, 44.06357513155256, 43.08650554929461, 42.286566393715994, 45.08627700805664, 44.63130896432059, 48.717805113111226, 54.6937700680324, 57.47820159367153, 56.149824142456055, 52.89865779876709, 50.9385848726545, 49.554493291037424, 52.00703716278076, 59.25805214473179, 56.68731941495623, 58.338854108537944, 56.33104010990688, 51.94035530090332, 53.210611070905415, 50.35114942278181, 55.57035827636719, 55.43345097133091, 52.90491465159825, 51.30340003967285, 51.17363895688738, 48.452845982142854, 44.38255303246634, 48.239522389003206, 44.67159809385027, 44.4844970021929, 45.551108019692556, 48.706663676670615, 49.72216027123587, 41.218965257917134, 41.333506311689106, 41.92359249932425, 40.72407981327602, 40.77421454020909, 39.43651260648455, 42.16833584649222, 40.68815067836216, 43.44573436464582, 43.45506579535348, 44.20188249860491, 42.86932570593697, 44.59708908626011, 40.94703360966274, 45.12318583897182, 50.084036350250244, 53.328407355717246, 49.88950068610055, 41.47042751312256, 36.80472952978951, 45.817074639456614, 52.93239825112479, 51.96750886099679, 51.033327034541536, 47.120633125305176, 47.42977932521275, 48.07842493057251, 44.888013635362896, 41.49930770056588, 43.24947554724557, 42.198046343667166, 42.82959590639387, 42.885320459093364, 42.793774468558176, 39.4956556728908, 39.30684185028076, 40.32927622113909, 38.41183744158064, 40.28168453489031, 41.090955121176584, 47.04249368395124, 46.05921588625227, 44.338247844151084, 43.97928653444563, 44.06590277808053, 44.24705968584333, 46.58513198580061, 52.870055539267405, 48.960533482687815, 51.20957156590053, 52.0919372013637, 53.992710726601736, 50.390101024082725, 52.98147337777274, 49.12280171258109, 54.860870770045686, 55.45364243643624, 56.77914333343506, 55.84744896207537, 52.849586146218435, 55.46772990907942, 57.292184420994346, 52.0205340385437, 47.898049695151194, 59.30125604357038, 57.230762345450266, 55.03995711462838, 47.79795047215053, 46.089569091796875, 46.52315058026995, 47.48301294871739, 47.31464767456055, 48.81845671789986, 51.29546867098127, 47.282446248190745, 49.67330748694283, 50.834417479378835, 52.53952973229544, 51.18996374947684, 50.82331773212978, 50.61243295669556, 66.40924235752651, 65.95695631844657, 76.99647658211845, 53.10164247240339, 2.1530055105686188, 1.0992673337459564, 0.18548245994108065, 0.9552298741681235, 49.072010380881174, 75.02181243896484, 70.92728764670235, 72.93756825583321, 48.22671685900007, 53.8023544039045, 58.126155853271484, 30.739428111485072, 53.42194053104946, 72.00778811318534, 79.3875949042184, 17.179455757141113, 0.7691233519996915, 0.32453605266554014, 0.24901526793837547, 0.2385158341910158, 0.16037103241043432], [0.08123658051980392, 0.010008012393622525, 0.19165554083883762, 0.015190224362803357, 0.12977895539786133, 0.056403929101569314, 0.33497357687779833, 0.13700181139366968, 21.48939902441842, 63.41866820199149, 44.93321166719709, 26.404335839407786, 36.632542746407644, 48.86791399547032, 42.588104316166465, 34.45452567509243, 44.444093227386475, 65.63690839494977, 46.21035657610212, 64.11918558393205, 8.166528735842023, 0.42143432742783, 0.09718762245029211, 0.09436934082103626, 0.08011303509452514, 0.08586536321256842, 10.222493750708443, 45.623688902173726, 62.511233466012136, 57.56284802300589, 55.21336678096226, 56.18373482567923, 50.68452746527535, 48.7892221723284, 46.69749477931431, 43.66328246252877, 43.43606942040579, 40.1559499331883, 41.25778831754412, 38.2431560243879, 41.81552021844046, 44.69818190165928, 49.94483266557966, 51.58315535954067, 51.73268059321812, 48.16275521687099, 46.452650683266775, 47.99670021874564, 49.17918981824602, 50.44106606074742, 50.56460850579398, 53.37209415435791, 51.8851831299918, 50.79812008993966, 46.50339685167585, 50.220620564052034, 44.7286810193743, 47.437717642102925, 45.43485770906721, 44.08428076335362, 44.21370485850743, 43.26214906147548, 38.84761456080845, 38.106814997536794, 38.63400609152657, 38.53493520191738, 37.90031106131417, 39.337174211229595, 37.35918535505022, 40.382318769182476, 39.34794391904558, 38.455499921526226, 37.703232356480186, 35.616066455841064, 36.11242491858346, 35.65289885657174, 34.880273069654194, 37.85849332809448, 39.631996699741904, 38.02925573076521, 39.18693331309727, 39.87416573933193, 41.60723754337856, 39.621470178876606, 42.140987736838206, 44.88913924353463, 48.52572563716343, 49.27531467165266, 42.66819967542376, 40.03652082170759, 41.8257132257734, 48.311450140816824, 46.15763364519392, 46.19639764513288, 39.43852758407593, 39.63227810178484, 42.25240557534354, 38.3894989831107, 40.10838951383318, 38.11007022857666, 37.51936565126692, 37.31525536945888, 37.18310758045742, 35.02508742468697, 35.138478551592144, 36.21172162464687, 35.64290039879935, 34.74835804530552, 36.07995251246861, 39.49685423714774, 38.47905084065029, 38.67664023808071, 37.898601804460796, 36.846356187547954, 37.69695118495396, 37.21286671502249, 38.43210881096976, 42.39084495816912, 44.201809542519705, 44.705199582236155, 44.39007445744106, 46.91613721847534, 44.76907784598214, 48.681118624550955, 47.280191557747976, 45.22468512398856, 50.16432973316738, 53.45832824707031, 49.40227215630667, 49.80414554050991, 52.18952465057373, 51.176602363586426, 53.506910051618306, 49.08326646259853, 48.68850455965315, 51.97074324744088, 53.46508189610073, 45.001703534807476, 39.19485773359026, 40.376881803785054, 41.00011437279837, 44.20775720051357, 43.33455971309117, 46.32135057449341, 44.19777263913836, 44.97839232853481, 44.407552650996614, 46.70840345110212, 42.4993827683585, 48.35534885951451, 47.71916137422834, 58.70430156162807, 55.78945582253592, 76.47534779139927, 27.699570383344376, 1.8041296196835381, 0.2224843722901174, 0.16060666048101016, 0.29267511516809464, 43.888754980904714, 61.91590486254011, 55.707644258226665, 55.865410055433, 33.60362148284912, 25.541124650410243, 41.834064960479736, 24.828447920935496, 36.77829858234951, 55.99021012442452, 57.80836609431675, 12.133556689534869, 0.3558640959007399, 0.10301287272678954, 0.012642236310057342, 0.03841532454160707, 0.10913570810641561, 0.07241248366023813, 0.012498504781563367, 0.1551807416336877, 0.0723587301160608, 0.12830287031829357, 0.061136609076389244, 0.2554600206868989, 0.13070332365376608, 26.029579537255422, 74.5534691129412, 49.47660051073347, 37.98577390398298, 19.15005694116865, 40.36348220280239, 47.075879778180806, 39.71031679425921, 56.12048189980643, 69.10336467197963, 52.44297409057617, 69.309677532741, 9.884094766208104, 0.3112080235566412, 0.31520858460239, 0.04649811510794929, 0.1613561295505081, 0.03094154629590256, 12.444166353770665, 48.12036773136684, 66.53173909868512, 60.84515271868025, 58.75348091125488, 57.632698263440815, 53.40056439808437, 51.598413603646414, 48.60742603029524, 46.677372796194895, 46.08529247556414, 41.330862522125244, 43.3461458342416, 41.42602505002703, 42.71071917670113, 46.77101019450596, 54.691425051007954, 53.930385385240825, 53.5996789251055, 51.294322218213765, 47.49877493722098, 51.38334253856114, 52.16035958698818, 54.084114279065815, 51.84043673106602, 54.286890506744385, 53.82231657845633, 53.940314361027305, 48.69762059620449, 53.894438879830496, 47.87295627593994, 49.768007959638325, 47.59893321990967, 46.505165168217246, 46.82675906590053, 45.05452026639666, 44.04246303013393, 41.21520628247942, 42.95109905515398, 40.761565344674246, 40.20182541438511, 41.44250965118408, 41.81251859664917, 42.877302237919395, 41.201678139822825, 39.08663954053606, 38.80464342662266, 36.68787472588675, 38.08628307070051, 35.985804421561106, 37.36170060294015, 39.60898426600865, 40.720609188079834, 41.128068923950195, 40.948711599622456, 42.68508379799979, 43.61064291000366, 42.88896131515503, 44.932975428445, 46.190936361040386, 51.58210965565273, 50.73953982761928, 41.46545607703072, 40.76593576158796, 43.62338938031878, 49.85146277291434, 48.26189906256539, 46.64510188783918, 41.38472148350307, 43.28748566763741, 43.561974252973286, 42.09461545944214, 41.637153012411936, 39.25970179694039, 38.86471060344151, 39.136096818106516, 38.3057975087847, 36.26035206658499, 37.46153926849365, 38.34935229165213, 37.41349594933646, 36.83457204273769, 37.31137132644653, 40.44354282106672, 40.97195332390921, 43.29246405192784, 40.58025557654244, 40.010499817984446, 41.842375005994526, 39.94067389624459, 41.597440583365305, 45.83096061434065, 47.81754786627633, 47.43287822178432, 49.59428562436785, 49.44032743998936, 48.49032456534249, 51.84748567853655, 50.036204951150076, 47.7771440914699, 52.01667084012713, 54.528573172433035, 51.74816117967878, 51.385312352861675, 54.5638040133885, 53.525611128125874, 56.41361250196184, 50.4101048878261, 49.72488743918282, 54.41693993977138, 54.92805985042027, 48.8827622958592, 41.99938692365374, 43.34369312013899, 44.237311363220215, 47.02721806934902, 46.019673688071116, 46.63492625100272, 46.75550181525094, 47.82736219678606, 48.008883884974885, 50.38110658100673, 46.813863209315706, 51.369731017521445, 50.79480232511248, 63.156832286289756, 60.16127627236502, 78.31345203944615, 29.67495366505214, 1.9536573503698622, 0.3355164591755186, 0.3134731634386948, 0.7598006608230727, 49.505102021353586, 70.461028780256, 62.02239990234375, 63.327994210379465, 37.35142074312483, 36.90959174292428, 50.61508022035871, 23.222682748522075, 46.37621355056763, 62.15003136226109, 67.95363235473633, 18.179873023714336, 0.4397908438529287, 0.15131804533302784, 0.05500113258936575, 0.023350352654233575, 0.05130268247531993, 0.1678548122623137, 0.09147635927157742, 0.3407976600740637, 0.15302849640803678, 0.2274906307991062, 0.0994786009458559, 0.4192135365945952, 0.2525857463479042, 32.80672563825335, 81.79263741629464, 58.84695502689907, 37.6838573047093, 49.42888028281075, 68.10094806126186, 57.391501971653526, 49.25459861755371, 54.26013994216919, 76.71182973044259, 56.888438497270855, 78.45601517813546, 10.918852635792323, 0.8918163797685078, 0.5307849954281534, 0.47440676923309055, 0.31625276857188767, 0.3737218619457313, 14.073672652244568, 48.81711571557181, 70.13426889692033, 61.648329734802246, 59.7844546181815, 60.96521759033203, 54.53402403422764, 53.19731569290161, 51.14144795281546, 47.80059078761509, 47.38030120304653, 44.38562066214425, 47.51417909349714, 43.39282383237566, 45.506187915802, 49.67943579810006, 56.31774125780378, 55.969421114240376, 57.21838412966047, 53.173299244471956, 48.069288049425396, 52.61833620071411, 54.95214925493513, 56.33151953560965, 52.93095997401646, 57.131152970450266, 55.3123334475926, 55.04428931644985, 51.39526564734322, 56.18148013523647, 48.70201185771397, 52.83293826239449, 51.456170082092285, 50.10120187486921, 52.341120447431294, 50.25387464250837, 46.414338316236226, 46.32164934703282, 46.95087126323155, 45.461146218436106, 44.386193888528005, 44.999629497528076, 44.54676328386579, 48.998529706682476, 45.126531396593364, 42.29344858442034, 42.42480080468314, 41.29268217086792, 39.33528082711356, 38.431504317692344, 38.80064473833357, 42.210730280194966, 43.7796300479344, 42.96178191048758, 44.93086665017264, 44.85159812654768, 47.0332282611302, 44.82960360390799, 48.605452741895405, 48.7959862436567, 53.16752181734358, 52.60643393652779, 43.0955034664699, 41.7148060798645, 43.68948759351458, 50.51799998964582, 49.89647320338658, 49.94380433218819, 43.51665115356445, 44.926214831215994, 47.56754125867571, 44.164306640625, 43.55194452830723, 41.56189707347325, 40.58501161847796, 41.17991290773664, 41.85509715761457, 39.88293784005301, 39.98748738425118, 41.727052279881065, 40.79984991891043, 39.43599149159023, 39.9893217086792, 43.98267378125872, 44.69595152991158, 46.86391108376639, 44.12727274213518, 43.81340871538435, 46.24161999566214, 43.68103510992867, 45.328571115221294, 50.08362293243408, 50.596636227199006, 51.184908935001914, 52.90013081686837, 52.15881708690098, 50.41647638593401, 53.54786968231201, 51.70801101412092, 49.104475838797434, 54.753191062382285, 58.020098549979075, 52.980469363076345, 53.0723488671439, 55.45473330361502, 55.14035858426775, 58.53282002040318, 50.280305589948384, 50.89629813602993, 57.24512774603707, 58.45005307878767, 50.92258664539882, 44.1046633039202, 45.518409797123496, 47.16549416950771, 51.36517994744437, 49.967070375170024, 51.68168428965977, 50.90886742728097, 51.27908481870379, 51.438024861471995, 53.38533394677298, 47.90861790520804, 54.707993030548096, 52.096418789454866, 66.11456230708531, 63.13580008915493, 81.32097979954311, 34.07704046794346, 2.523581385612488, 0.6233674074922289, 0.313845977719341, 0.8040814761604581, 55.57297427313668, 76.26251057216099, 69.14096137455532, 67.77666173662458, 46.144174984523225, 36.529358523232595, 60.08464459010533, 31.835812159946986, 50.95699412482125, 72.8738602229527, 79.56831754956926, 25.328421183994838, 0.7116796086941446, 0.2683209462889603, 0.1495741153401988, 0.12081001166786466, 0.2626035287976265], [0.08014790500913348, 0.0350055639365954, 0.10017036739736795, 0.059271859138139656, 0.1407273079135588, 0.052994582402919016, 0.1864994346563305, 0.052409749677670855, 35.22268377031599, 61.78011621747698, 42.32110588891165, 27.265641484941753, 83.2787389755249, 91.15714154924665, 46.07700674874442, 44.34138148171561, 33.41746187210083, 67.5812019620623, 49.68620681762695, 61.683230536324636, 24.07491057259696, 0.21772729898137705, 0.22360714418547495, 0.013649169555199998, 0.23105365889413015, 0.02954686845519713, 2.5201834993703023, 40.13805137361799, 60.868394442967, 57.464649132319856, 56.044204575674875, 50.33028745651245, 46.43661076681954, 45.49638748168945, 43.67165156773159, 42.59845018386841, 42.35574265888759, 42.6341152872358, 42.52446576527187, 40.23331465039934, 43.36263738359724, 47.9546914100647, 52.86927039282662, 51.579281738826204, 51.95114237921578, 47.20844445909773, 52.6576178414481, 51.59961911610195, 51.3869833946228, 51.25639547620501, 49.99197619301932, 51.44510507583618, 49.884508405412944, 47.13075317655291, 45.12203938620431, 48.24938883100237, 46.39305598395211, 47.9388564654759, 46.16096183231899, 45.664606843675884, 43.686878544943674, 41.89353459221976, 39.99739898954119, 40.56900296892439, 42.013578619275776, 39.21107482910156, 37.519980566842214, 39.37688316617693, 38.45258167811802, 39.46989175251552, 40.76887137549264, 36.959969656808035, 38.39844478879656, 39.45574174608503, 35.68717432022095, 36.5330445425851, 36.19406277792794, 38.39886168071202, 36.713697705950054, 38.79858112335205, 38.865506172180176, 40.28115994589669, 42.624068192073274, 44.332459994724815, 45.28887953077044, 46.37726272855486, 49.84148515973772, 48.28438343320574, 41.517261845724924, 39.3194146156311, 44.31265415464129, 50.152576855250764, 48.277560302189414, 48.138231549944194, 42.454143047332764, 38.91171516690935, 42.232766492026194, 40.2006060055324, 40.16426345280239, 37.821115493774414, 38.85331208365304, 38.749450411115376, 34.865410872868125, 35.818766253335134, 35.43251936776297, 35.52538899012974, 34.74009663718087, 37.88925647735596, 39.68335083552769, 39.58076415743147, 37.32651492527553, 37.49984468732561, 37.429598399571006, 40.20411831992013, 39.69523572921753, 37.779954365321565, 38.21768045425415, 43.462191173008506, 43.55016578946795, 41.27414090292794, 45.081625189099995, 45.74704374585833, 44.429026058741975, 48.98865284238543, 49.28236014502389, 45.72309330531529, 47.35405090876988, 49.66871125357491, 50.19086837768555, 50.327511651175364, 52.850795132773264, 52.48470844541277, 54.692557607378276, 50.47918387821743, 48.22193649836949, 52.82710524967739, 52.61292355401175, 47.11549840654646, 41.34629099709647, 41.42569153649466, 40.507799761635916, 40.7412314414978, 41.4655498777117, 43.98723527363369, 42.99123879841396, 45.283484254564556, 43.71732555116926, 44.47711801528931, 45.469067164829795, 45.33732237134661, 48.03703798566546, 59.1205472946167, 58.44990716661726, 72.54741995675224, 11.41086152621678, 1.3876054159232547, 0.30785603342311724, 0.8840363515274865, 2.277853782687868, 51.361122199467246, 62.64327008383614, 55.49822555269514, 62.591874258858816, 37.52173498698643, 25.36318302154541, 55.87992136819022, 35.9649771962847, 40.86937359401158, 51.42892966951643, 57.84764773505074, 12.447827185903277, 0.28269562923482483, 0.15319572814873286, 0.06962344010493585, 0.04387188942304679, 0.07894841115921736, 0.09723733192575829, 0.04263479794774737, 0.1529577930590936, 0.05219377198123506, 0.1826139260083437, 0.02179005628983889, 0.13700006077332155, 0.05969833875341075, 41.75811767578125, 69.89780085427421, 52.414625440325054, 31.05306284768241, 46.44535507474627, 84.4734330858503, 51.5998067174639, 46.00393949236189, 39.720871107918875, 72.18906661442348, 55.0353296143668, 67.69921016693115, 26.943733181272233, 0.33126098609396387, 0.3505817822047642, 0.026184452631111656, 0.25646365540368216, 0.07790694811514445, 3.0942317247390747, 41.966952732631135, 62.91372176579067, 61.372319493974956, 59.32511615753174, 51.64326422555106, 49.14191273280552, 47.49677038192749, 44.369695390973774, 43.90958915437971, 44.51607656478882, 44.46868985039847, 44.2035813331604, 42.060371262686594, 45.70567069734846, 51.36438437870571, 55.40130860464913, 52.539130210876465, 53.77232081549508, 48.25231054850987, 52.82852963038853, 54.81541565486363, 53.39465495518276, 54.05686691829136, 53.89814574377877, 54.07280608585903, 51.47792141778128, 49.39222158704485, 49.21350349698748, 52.02305623463222, 48.45353037970406, 51.1635536466326, 50.34920392717634, 48.85101250239781, 47.897372245788574, 46.471480301448274, 43.27383940560477, 42.84577826091221, 44.233392579214915, 43.0538455418178, 41.551228114536826, 42.108984334128245, 42.19045891080584, 41.17583431516375, 42.884747232709614, 40.761648723057334, 39.78805324009487, 40.48045860018049, 38.55869804109846, 37.746307713644846, 38.9370413507734, 40.34330463409424, 40.7490724836077, 40.62474141802107, 40.344829763684956, 41.284479822431294, 46.12289612633841, 45.68577800478254, 46.7129545211792, 47.20870154244559, 50.574801513126914, 49.360232080732075, 42.513185364859446, 41.01243005480085, 44.24906424113682, 51.446744850703645, 49.390672138759065, 49.5787980897086, 45.16816847664969, 42.14549016952515, 44.60859530312674, 42.63393810817173, 42.07455601011004, 40.67726979936872, 43.17639786856515, 41.030516215733115, 37.72049168178013, 37.902795042310444, 37.7817747933524, 37.31952503749302, 39.148058141980854, 39.75557041168213, 42.35366514750889, 43.46212863922119, 41.176407541547505, 39.45657205581665, 39.0031430380685, 41.606528827122276, 42.74444225856236, 41.92506204332624, 43.560549872262136, 46.98183591025216, 46.64118310383388, 46.84547403880528, 47.943737574986045, 49.748268127441406, 46.31457608086722, 51.89339590072632, 50.46208783558437, 47.69348430633545, 49.766875403267996, 51.959174496786936, 52.34515387671334, 52.21362100328718, 54.230860233306885, 53.75390461512974, 58.004954951150076, 53.0800335747855, 50.667313303266255, 55.14174474988665, 53.36761951446533, 49.75692558288574, 44.033941064562114, 42.86369071687971, 44.017314025333945, 43.15061657769339, 43.703463894980295, 47.031320980616975, 47.97740854535784, 47.67104509898594, 48.30809416089739, 48.833732332502095, 48.47199174336025, 48.35217005865914, 50.57615293775286, 61.6862599509103, 59.36631897517613, 77.65958486284528, 13.302811707769122, 1.2635964644806725, 0.2778512148984841, 1.1207881846598216, 2.797337804521833, 59.953149931771414, 68.82790333884103, 61.06892640250069, 68.82058688572475, 45.63542440959385, 33.3683693749564, 57.879960332598, 33.66014855248587, 46.22769580568586, 58.89361218043736, 66.38731384277344, 18.605097566332134, 0.5404918459909303, 0.26598282318030086, 0.050843979232013226, 0.10862711218318769, 0.06639754213392735, 0.1521170881709882, 0.14542163030377456, 0.2826476975211075, 0.18851829346801552, 0.21420589222439698, 0.10431182623973914, 0.22987061951841625, 0.16095382613795145, 49.705578395298545, 79.24231501988002, 55.9667078426906, 40.14842503411429, 103.76571096692766, 99.27848788670131, 57.058304582323345, 60.56736373901367, 44.63557168415615, 79.43031937735421, 60.37701783861433, 74.37182235717773, 31.965420382363455, 0.970643475651741, 0.9684407881328038, 0.0934066828340292, 0.7957713220800672, 0.25762199610471725, 3.611626292978014, 45.274086815970286, 67.3602214540754, 64.23865985870361, 61.95399488721575, 53.6462527002607, 52.004664352961946, 48.570979254586355, 47.9488445009504, 46.93244464056832, 47.20952837807791, 46.82958698272705, 46.84643636431013, 43.700427532196045, 46.35887779508318, 52.66339526857649, 58.83632428305489, 56.68950809751238, 54.68168020248413, 47.77858931677682, 56.03052009854998, 55.54509462629046, 54.84405265535627, 54.35311031341553, 55.66224125453404, 58.53509208134243, 53.935068471091135, 52.80432905469622, 50.15231629780361, 53.91775703430176, 49.44039344787598, 54.87850877216884, 53.0820311818804, 51.30988965715681, 51.925607749394004, 50.00125551223755, 48.65460777282715, 47.72615473611014, 47.25122104372297, 46.741626262664795, 44.807841845921104, 45.2160450390407, 45.80013493129185, 46.05882331303188, 46.791500432150706, 44.09180218832833, 44.160554613385884, 43.52864721843174, 40.23172351292202, 41.40382208142962, 39.53584752764021, 41.97780581883022, 42.41343355178833, 43.00617395128523, 44.16931629180908, 43.87027277265276, 49.50337191990444, 48.69701957702637, 48.70536436353411, 49.20828192574637, 53.95488820757185, 52.651343618120464, 43.16515220914568, 42.097564969744, 45.321480478559224, 53.297081402369905, 52.89312703268868, 52.90567200524466, 45.90552520751953, 44.21435798917498, 46.71230486461094, 43.22312102999006, 45.05642407281058, 42.240107263837544, 44.08289459773472, 42.506907667432515, 38.77550615583147, 40.25140428543091, 39.64087649754116, 40.57278626305716, 40.91007266725813, 43.060950074877056, 46.208352020808626, 45.90618528638567, 44.56854588644845, 43.49606016704014, 42.88688727787563, 46.70574229104178, 46.961502007075715, 48.34841455732073, 46.242669173649375, 50.49292394093105, 50.73988028935024, 49.487939970833914, 52.92972319466727, 51.20420060838972, 47.6916048186166, 54.59186431339809, 53.44112798145839, 50.573835713522776, 53.2860233443124, 55.92682865687779, 55.72445889881679, 53.89326116016933, 56.930603640420095, 56.54863337108067, 60.8517951965332, 54.113029207502095, 52.389577184404644, 57.47440440314156, 58.074329239981516, 52.779183523995535, 46.779879570007324, 45.71918494360787, 47.08525289808001, 45.78350094386509, 46.248012338365825, 49.56659010478428, 50.486222403390066, 50.782743726457866, 48.987381322043284, 50.60413680757795, 50.83922215870449, 51.078570229666575, 53.73310170854841, 64.11714976174491, 61.9206782749721, 81.15482752663749, 17.492192438670568, 1.3737611302307673, 0.5609743211950574, 1.4269640296697617, 3.600090980529785, 63.839485849652974, 73.8797995703561, 66.50664915357316, 74.18275492531913, 50.63734572274344, 38.871749128614155, 73.86363806043352, 50.097884110042024, 53.79391234261649, 68.33776351383754, 76.5036130632673, 30.164673124040874, 0.4822409174271992, 0.3694077091557639, 0.16295057827872889, 0.25141364495669094, 0.22712130418845586], [0.01746933867356607, 0.017332544317469, 0.04270217986777425, 0.1389578650040286, 0.048935653774866035, 0.03273885663864868, 0.12158290376620633, 0.1394620979470866, 37.80676398958479, 69.9417690549578, 32.844641957964214, 36.16000965663365, 85.13343552180699, 78.41749436514718, 51.78201975141253, 40.49864203589303, 25.034797259739467, 50.93398169108799, 56.83746998650687, 50.110835552215576, 49.39014407566616, 1.142922431230545, 0.22983889122094425, 0.2754174454935959, 0.09731226254786764, 0.08184780486460243, 0.1854010357388428, 26.119341577802384, 63.30803203582764, 57.40713194438389, 59.09622165134975, 48.65797764914376, 45.457355976104736, 43.552993706294465, 44.62966571535383, 42.559679235730854, 42.1403762953622, 43.094152041843955, 41.704543590545654, 44.557894298008506, 48.98569985798427, 52.15481145041329, 52.76224381583077, 53.591073581150596, 48.83130046299526, 49.28123453685215, 54.09013489314488, 52.77825941358294, 53.29483366012573, 49.96606288637434, 51.36025367464338, 50.12954357692173, 48.879454953329905, 46.69334670475551, 49.39059223447527, 47.60640253339495, 47.48840822492327, 46.16022879736764, 42.427302156175884, 46.68400832584926, 45.85184689930507, 43.2184032031468, 40.474160058157786, 37.82309225627354, 40.55584308079311, 39.89469419206892, 39.21760960987636, 39.288408279418945, 37.7240491594587, 36.68787472588675, 33.03899349485125, 40.55587782178606, 38.18212652206421, 39.28407607759748, 36.02748319080898, 37.02244438443865, 37.4544277872358, 34.505535875047954, 37.077123233250205, 40.83855833326067, 40.118759700230186, 41.76252630778721, 43.03150708334786, 42.776459557669504, 46.04224491119385, 44.1045104435512, 50.37070860181536, 47.80876881735665, 41.49698352813721, 39.333547251565115, 43.26623460224697, 51.16556167602539, 50.39767803464617, 47.762038707733154, 45.072345869881765, 42.800743511744905, 42.57813365118844, 39.64492382322039, 40.04266650336129, 39.8610440662929, 38.416909626552034, 36.90849045344761, 35.84546818052019, 34.564946447099956, 34.601869174412315, 36.4590288570949, 37.199140548706055, 38.69627932139805, 39.025818484170095, 36.442061356135774, 37.70680373055594, 36.26012625013079, 35.7608391216823, 39.449029786246165, 40.82795538221087, 37.70397233963013, 39.43933704921177, 44.37134211403983, 42.60195207595825, 41.61456094469343, 41.94975594111851, 45.99435445240566, 45.57898766653878, 50.03714643205915, 48.38904414858137, 44.79606812340872, 46.665640762874055, 47.58209426062447, 49.78090034212385, 46.976999964032856, 50.90406622205462, 51.87775897979736, 52.27953161512102, 53.384840624673025, 50.09948219571795, 51.610145636967246, 49.522430828639436, 47.10225861413138, 41.08742891039167, 42.04242059162685, 39.95212452752249, 40.20057821273804, 41.02123689651489, 42.81612682342529, 44.39325325829642, 45.24806581224714, 44.557508672986714, 44.29163932800293, 46.0971565246582, 48.74033464704241, 51.63491249084473, 55.60773263658796, 60.189604078020366, 59.711144174848286, 4.188549552645002, 0.680639345731054, 0.2825163331414972, 1.1705985175711768, 3.659627054418836, 60.9872225352696, 61.18760858263288, 59.697129658290315, 57.989648069654194, 24.373978410448345, 29.647973809923442, 52.6049678666251, 31.23604713167463, 37.85933058602469, 52.43516084126064, 55.974170207977295, 13.155799984931946, 0.22100501667175973, 0.0961014778752412, 0.011212155904753931, 0.09983847556369645, 0.015814537648111582, 0.06036497226783207, 0.02085109444202057, 0.03283891680517367, 0.04300458935488548, 0.193803036319358, 0.04863125278747507, 0.1229432714836938, 0.0885586654767394, 46.86920213699341, 77.04398836408342, 41.735133034842356, 36.45992170061384, 83.13612025124687, 82.82154750823975, 60.865594318934846, 50.24243095942906, 26.176902191979543, 57.83288628714425, 62.04448822566441, 57.4072049004691, 53.6531001499721, 1.577630722096988, 0.37459972341145786, 0.2258673036204917, 0.24582099648458616, 0.1355136348200696, 0.5068185957414764, 28.569908687046595, 67.35007708413261, 59.807029315403526, 59.39479964120047, 49.83755595343453, 46.234883717128206, 45.67457056045532, 44.92172629492623, 44.65179225376674, 43.75115633010864, 45.34099102020264, 43.36392627443586, 45.45726217542376, 51.758923939296174, 54.77111046654837, 53.51124920163836, 55.55026061194283, 48.92455571038382, 51.42878723144531, 54.3726555960519, 54.920510632651194, 53.99224867139544, 51.5616124698094, 51.36506877626692, 52.86372225625174, 50.36978449140276, 47.76858043670654, 50.67683233533587, 50.80759048461914, 49.303652899605886, 50.18039049421038, 46.11178248269217, 49.117253576006206, 48.80271209989275, 46.67620202473232, 43.85172455651419, 42.25557047980172, 43.789274147578645, 44.94126115526472, 40.48100403376988, 40.462702478681294, 42.31065232413155, 39.1185039792742, 36.56668424606323, 43.778077125549316, 40.03173003877912, 43.12703786577497, 37.53375884464809, 39.264395305088584, 38.593671798706055, 36.73936087744576, 38.62482404708862, 41.14085708345686, 41.104375566755024, 43.46162836892264, 43.577708448682515, 44.28026165281023, 47.66940879821777, 46.73119701657976, 52.385547229221885, 48.93384197780064, 42.0998717716762, 40.643741267068044, 44.61260093961443, 52.32130071095058, 50.34020601000105, 49.66670322418213, 47.46070575714111, 44.27729477201189, 43.67511177062988, 40.35021809169224, 42.63460166113717, 40.21723304476057, 40.44096156529018, 38.91161789212908, 36.60208879198347, 36.49086897713797, 36.485557079315186, 37.26386649268014, 38.522883551461355, 39.98169258662632, 41.54804583958217, 42.29049907411848, 40.77160201753889, 38.110570498875205, 38.084966387067524, 41.54371016366141, 43.48917102813721, 41.40194606781006, 40.87508501325335, 47.59971489225115, 45.200057234082905, 44.685390268053325, 46.40000070844378, 48.99687950951712, 46.56151505878994, 51.05000271115984, 50.1162759917123, 47.556740283966064, 48.4380532673427, 48.847486291612896, 51.759368624006, 49.85592699050903, 53.47751917157854, 53.484957218170166, 55.968073163713726, 54.8157456942967, 51.55205522264753, 52.55707393373762, 53.4036910874503, 50.4573769569397, 43.55786439350673, 44.8998464175633, 42.862999371119905, 43.33405944279262, 43.80597414289202, 45.41101843970162, 47.90904174532209, 46.100828647613525, 48.185910088675364, 47.94223328999111, 49.10411105837141, 50.89173664365496, 55.13373000281197, 60.70758533477783, 64.96816512516567, 63.919508252825054, 5.821277643953051, 0.6364663903202329, 0.32467789362583843, 0.838055995958192, 4.104426409517016, 66.03466497148786, 67.16443511417934, 66.9733110155378, 64.28139128003801, 32.92354222706386, 26.77381672177996, 60.69140992845808, 33.660839898245676, 37.178466183798655, 59.19000843593052, 65.07500062670026, 20.814134870256694, 0.3834958060511521, 0.17517411522567272, 0.02802913319984717, 0.03261697817859905, 0.03825591291700091, 0.13079880710159028, 0.11685745018933501, 0.2000484490501029, 0.18323925031082972, 0.2144615642194237, 0.1921991016715765, 0.2312521439577852, 0.3296745983617646, 52.45692259924752, 90.45826394217355, 43.75451578412737, 46.660377502441406, 94.76138060433524, 81.86840752192906, 63.8223237991333, 51.161493505750386, 38.256065777369905, 62.003785678318565, 68.77859197344098, 60.18100915636335, 60.91868550436837, 1.8238272198608942, 0.6420302146247455, 0.502859099635056, 0.57117367961577, 0.23161727722202027, 0.9637875578233174, 30.86992917742048, 69.62655707768032, 61.7967015675136, 62.66729000636509, 52.08236953190395, 48.551951612745015, 48.85867983954293, 47.4145245552063, 46.934584685734336, 47.10442297799246, 46.931378092084614, 46.30238199234009, 49.85100071770804, 52.80492312567574, 56.00588526044573, 55.963271958487375, 57.795067242213655, 51.53700542449951, 52.12267255783081, 57.538240977696006, 55.94054440089634, 58.41888345990862, 53.00934955051967, 53.05638190678188, 53.76763078144619, 52.77860682351248, 50.14318983895438, 54.46220397949219, 53.66960906982422, 51.15470164162772, 53.62068680354527, 48.58394111905779, 52.12932545798165, 54.005109786987305, 49.410780225481304, 47.61864178521292, 45.73273045676095, 47.99926062992641, 48.531697613852366, 46.36994627543858, 45.95909234455654, 47.16403504780361, 45.06477233341762, 41.36996350969587, 47.838058948516846, 44.03285019738333, 45.36302375793457, 39.72074604034424, 40.55261564254761, 40.282872676849365, 37.760325704302105, 41.207670961107524, 43.570718560900005, 45.32486425127302, 45.943087169102256, 46.59003741400582, 45.62129872185843, 50.874539852142334, 47.924247877938406, 54.84540407998221, 52.173140798296245, 42.25956916809082, 40.15804828916277, 44.0465589932033, 54.703994342258994, 53.61799785069057, 52.63985824584961, 50.54747772216797, 46.15145322254726, 45.87634972163609, 44.25606802531651, 45.83219739368984, 41.92768498829433, 44.31781319209507, 40.141004358019146, 40.626693861825125, 39.5172506741115, 37.19176851000105, 40.77561807632446, 41.919840472085134, 42.79781832013811, 45.20034211022513, 43.367160660879954, 44.14338214056832, 41.655089787074495, 43.76445518221174, 46.411197730473106, 47.29921919958932, 45.092103072575156, 45.068263803209575, 51.75218071256365, 48.897659233638215, 49.317500659397666, 49.01530613218035, 51.391263484954834, 47.80564212799072, 54.71263790130615, 53.21378639766148, 50.582218715122764, 50.65822158540998, 51.397103445870535, 55.04382378714425, 51.03177063805716, 54.68326786586216, 55.09081792831421, 56.1141242980957, 57.94024290357317, 53.87448712757656, 55.540001596723286, 54.065409728458945, 54.03652606691633, 46.28109271185738, 47.75508008684431, 46.502316406794954, 46.69349261692592, 46.18845932824271, 48.64446340288435, 50.50258193697248, 48.65589666366577, 50.351635796683176, 51.26329503740583, 52.39508015768868, 54.77826016289847, 57.13794830867222, 62.23249953133719, 67.75594915662492, 64.9941930770874, 8.717359338487897, 0.9929373136588505, 0.4269358350762299, 1.926973010812487, 4.546215891838074, 73.39257104056222, 72.52970205034528, 74.60105732509068, 71.78302083696637, 39.48788063866751, 41.66134316580636, 70.55420412336076, 42.38955954142979, 49.24508305958339, 68.75148010253906, 77.51474966321672, 30.6218124798366, 0.461444796196052, 0.2041921809847866, 0.11837956708456789, 0.18585828691720963, 0.18892772149826798], [0.0018742000226796205, 0.04015576007909008, 0.14458521375698702, 0.037172509623425345, 0.1998266495232071, 0.049581887133951695, 0.19254220968910626, 0.11574240002248969, 36.99188273293631, 70.21893269675118, 37.12435013907296, 44.34996598107474, 77.11850084577287, 89.80397292545864, 50.12713950020926, 32.350267205919536, 25.71353725024632, 44.318810258592876, 60.679445130484446, 49.56887953622, 57.68394122804914, 11.592941675867353, 0.2316363033439432, 0.5858688482216426, 0.16505586888108933, 0.3813815994986466, 0.121641909171428, 13.88454008102417, 62.811715262276785, 57.45858335494995, 58.03112881524222, 51.41397367204939, 49.180992875780376, 47.82774087360927, 45.89569698061262, 41.84872565950666, 41.143476554325645, 43.06873900549752, 42.48920018332345, 48.02867930276053, 51.737311567579, 52.07847506659371, 53.56454883302961, 49.673363072531565, 45.555395058223176, 52.1069244657244, 53.133371421269004, 51.66758639471871, 51.229210649217876, 51.00275496074131, 49.280129773276194, 49.858122621263774, 44.46188408987862, 45.24976464680263, 48.92290898731777, 48.19376155308315, 45.60673182351248, 46.9134065764291, 42.60693046024868, 43.40987818581717, 42.87661436625889, 43.99199478966849, 41.540243012564524, 37.750997747693745, 40.18558052607945, 40.20865201950073, 38.0005909374782, 37.964116368974956, 38.92622300556728, 32.11338574545724, 27.18337481362479, 31.26963472366333, 37.66270003999983, 38.040247780936106, 39.6245447567531, 38.53996569769723, 37.282887186322895, 37.12032018389021, 37.23534066336495, 39.28232165745327, 42.58957386016846, 44.94052464621407, 42.7562437738691, 43.82336548396519, 45.14195639746529, 44.577179023197715, 50.287337166922434, 46.66213192258562, 40.495348589760916, 39.61597762789045, 40.52346794945853, 49.97513028553554, 48.192486558641704, 45.77200167519705, 44.54702384131295, 44.30574417114258, 42.3721855708531, 42.060937540871755, 42.919425691877095, 37.454792567661826, 38.019872188568115, 37.602250712258474, 36.54832015718733, 35.67344467980521, 36.521409784044536, 36.21863508224487, 37.69082287379673, 37.017646653311594, 37.33235836029053, 34.31931720461164, 32.8100711958749, 36.51439905166626, 34.23186022894723, 38.83292259488787, 37.75700099127633, 39.437068462371826, 39.35868583406721, 41.01895093917847, 41.3842316355024, 43.752462591443745, 46.41054112570626, 46.25746883664812, 44.39166906901768, 50.641295773642405, 47.269602503095356, 46.8352358681815, 46.110382420676096, 44.57075888769967, 47.22850390842983, 50.12805666242327, 49.43365369524275, 51.610496520996094, 55.78045790536063, 52.73328719820295, 53.12307071685791, 51.91133267538888, 49.12946156093052, 45.53240694318499, 41.11869232995169, 42.89955384390694, 41.26273543494088, 40.681747913360596, 42.213617256709504, 44.794192109789165, 42.88759599413191, 43.5411296572004, 45.49002293178013, 44.77089479991368, 47.698935168130056, 48.42488643101284, 55.24601984024048, 54.90555116108486, 64.95198277064732, 41.98924255371094, 1.3914038006748473, 0.18481768561261042, 0.05950952959912164, 1.2041325867176056, 5.95711145230702, 64.96512876238141, 54.71157830102103, 63.46810463496617, 38.49158191680908, 17.390832117625646, 35.35336201531546, 55.51297310420445, 32.91161911828177, 38.27134139197213, 48.7945271219526, 62.51462418692452, 22.745199067252024, 0.3832646155995982, 0.22682147313441547, 0.032664913284991465, 0.15033201181462832, 0.023392854391464164, 0.1042432738468051, 0.025308251879843216, 0.16241965176803724, 0.06828853102134806, 0.11810124559061867, 0.04856653751007148, 0.17743736878037453, 0.16773131888891968, 42.93319354738508, 79.03682204655239, 42.08349486759731, 42.43009533200945, 78.7464290346418, 87.8726030077253, 56.22609799248831, 39.610481602805, 29.95535169328962, 48.40276684079851, 66.43225479125977, 55.361387729644775, 64.48065866742814, 13.364603774888174, 0.2445968378867422, 0.46337422409227913, 0.181504684101258, 0.7888420139040265, 0.06889799796044827, 16.06342567716326, 67.79620701926095, 59.328096934727256, 59.18326868329729, 53.26546709878104, 50.077202796936035, 49.843048504420686, 46.78768934522356, 44.89576087679182, 43.45542015348162, 45.48769875935146, 44.231325490134104, 49.23922572817121, 55.18521268027169, 55.656950201307026, 55.097776549203054, 52.869343348911826, 46.02271352495466, 53.487562792641775, 57.21228013719831, 53.6998267854963, 53.86497156960623, 51.893135343279155, 49.59059960501534, 50.33101354326521, 46.27538129261562, 48.42417424065726, 49.98748418263027, 50.30446100234985, 48.860965796879356, 49.79087448120117, 47.50363520213536, 46.439890316554475, 46.23890325001308, 46.829392433166504, 44.5616706439427, 41.211377825055806, 41.11579493113926, 41.67018822261265, 42.429233755384175, 40.64725705555507, 42.59621286392212, 37.098391669137136, 30.943256991250173, 34.27240296772548, 40.244928564344136, 41.80057464327131, 40.27387128557478, 41.45413398742676, 38.960081577301025, 39.146032742091585, 39.95211410522461, 40.518458298274446, 45.07526758738926, 46.19885730743408, 43.47527115685599, 47.91843223571777, 45.55693061011178, 47.54568222590855, 51.27863665989467, 48.127934319632395, 40.63886363165719, 39.761851583208355, 41.58010482788086, 52.163639136723106, 51.608370372227256, 46.99727480752127, 45.94463314328875, 46.182713168007986, 42.549791949135916, 44.43805524281093, 44.56545393807547, 41.298386641911094, 41.43575600215367, 38.67215517589024, 37.8856086730957, 37.77131428037371, 39.978829928806846, 37.684958594185964, 40.488994462149485, 41.61391476222447, 41.45071199962071, 38.27692426953997, 37.51312616893223, 39.945746081215994, 38.30426543099539, 41.02555520193917, 42.59405197416033, 42.4044634274074, 43.74476398740496, 44.85180309840611, 46.284420898982454, 46.68349763325283, 49.11314371653965, 47.56698887688773, 47.173352582114084, 53.51602608816964, 48.72734498977661, 48.907973834446494, 49.413139138902935, 46.90108394622803, 50.60890327181135, 52.5659294128418, 51.01179109300886, 53.03618696757725, 57.10711915152413, 53.92101226534162, 53.779084886823384, 54.86326095036098, 52.74786104474749, 45.3782958984375, 43.52050392968314, 45.47345495223999, 43.77481147221157, 43.29197767802647, 45.84014960697719, 47.00361156463623, 46.95100327900478, 45.6354660987854, 49.38766009466988, 47.529816014426096, 50.63455949510847, 49.23887831824166, 59.55977766854422, 58.4614759172712, 69.41234411512102, 43.540028367723735, 2.1700672464711324, 0.44319589542491095, 0.31144808924623896, 0.7911994074072156, 7.484396287373134, 72.68262495313371, 60.74454975128174, 70.11541148594448, 44.75803368432181, 18.770975385393413, 29.10658754621233, 63.14377662113735, 37.18797131947109, 33.18263707842146, 53.74730730056763, 70.38788509368896, 28.28362727165222, 0.5481886586972645, 0.18074339495173522, 0.048960464407822916, 0.12122668645211629, 0.0029751112160738558, 0.2018045519611665, 0.13140503742865153, 0.4049026630818844, 0.16153822120811256, 0.23046156923685754, 0.11159856630755322, 0.3563563052032675, 0.17829591913947038, 53.61519772665841, 87.36394623347691, 50.74377475466047, 58.4130539212908, 83.8564122063773, 90.214277948652, 61.68311241694859, 42.415733405521934, 37.92701646259853, 57.7124844278608, 71.93153163364956, 60.65606444222586, 71.16725758143834, 15.77753336088998, 0.3609251528978348, 1.0456667585032327, 0.4918254688382149, 1.737866712468011, 0.16779096211705888, 16.824310745511735, 70.26112910679409, 63.216892514910015, 61.319582666669575, 57.400666645595, 53.94205141067505, 51.95780570166451, 49.73690087454659, 47.66467360087803, 44.860213892800466, 48.46481078011649, 46.639015265873496, 51.88055910382952, 57.311625480651855, 57.303245953151155, 56.19939259120396, 53.56616428920201, 47.543250356401714, 55.324343408857075, 57.51008340290615, 55.585894448416575, 56.30883714130947, 55.141518933432444, 53.78910418919155, 53.789597511291504, 47.91565295628139, 50.29337167739868, 52.983196531023296, 53.45037950788225, 50.97735234669277, 53.578942026410786, 49.92119141987392, 49.82670634133475, 48.74958617346627, 51.930044174194336, 47.82774782180786, 43.74279417310442, 43.80585254941668, 46.609044211251394, 44.17588581357683, 44.545922551836284, 45.91760465076992, 41.947417872292654, 37.73028516769409, 40.97011552538191, 43.86296674183437, 44.36170843669346, 44.148798261369976, 43.56129680361067, 40.57539183752877, 41.327732358660015, 41.48725257601057, 43.75006546292986, 47.8102696282523, 49.3428372655596, 44.22376932416643, 50.947377817971365, 48.928933075496126, 50.81020300728934, 53.025615283421104, 50.50407927376883, 41.348312922886436, 39.32989249910627, 41.70074987411499, 54.02836888177054, 53.15790203639439, 49.0061935697283, 47.77075522286551, 48.95092412403652, 45.45785972050258, 48.39389746529715, 47.6313430922372, 43.149001121520996, 42.47108622959682, 41.00466544287545, 40.27202306474958, 40.95223086220877, 41.33747373308454, 39.563199111393516, 43.81991570336478, 44.25535930906023, 43.82934440885271, 43.84090621130807, 41.93163503919329, 42.08899089268276, 40.48563500813076, 45.9352912902832, 46.18776103428432, 46.487697396959575, 46.84172548566546, 49.1372400692531, 49.73896101542881, 52.02094745635986, 52.20788179125105, 50.58290311268398, 48.58084569658552, 54.71665048599243, 51.905054977961946, 52.13458524431501, 53.579668113163535, 48.643216201237266, 53.59097283227103, 55.72495916911534, 55.89089257376534, 56.953001158578054, 59.66836411612374, 57.7575226511274, 57.20287922450474, 57.751790387289866, 55.7628789629255, 50.248757294246126, 46.180937903267996, 47.4982260295323, 47.1730329649789, 46.6955840247018, 49.698453017643516, 49.94812611171177, 49.28428479603359, 49.13660083498274, 51.30888564246041, 50.26255294254848, 53.566410950251985, 52.929264613560264, 61.94698415483747, 61.791810035705566, 71.81216158185686, 49.09502976281302, 3.661340653896332, 0.708995595574379, 0.4498422544981752, 2.361774125269481, 8.176467265401568, 79.88275132860456, 66.53111376081193, 76.45321083068848, 52.85735075814383, 30.92854765483311, 45.38465002604893, 72.85791410718645, 47.36547374725342, 52.31998402731759, 62.344650404793875, 80.72889600481305, 36.44229064668928, 0.6519443712064198, 0.3053598930793149, 0.0775437011782612, 0.2373965499656541, 0.13342445263905184], [0.05257944789315973, 0.07905741102461304, 0.07356464290725333, 0.015344399393403103, 0.26598624299679485, 0.05784739021744047, 0.23138016994510377, 0.19023973681032658, 35.281479426792686, 63.66618388039725, 54.529980182647705, 32.59275238854544, 59.438767841884065, 75.07920455932617, 35.93539524078369, 33.18902942112514, 15.924659729003906, 51.21955612727574, 52.85390445164272, 52.504229409354075, 55.21511425290789, 31.078045095716202, 0.2809699789753982, 0.2922542334667274, 0.011324704508297145, 0.09047043110643115, 0.07343283747988087, 5.618289496217455, 56.279446261269705, 59.10268347603934, 56.278716700417654, 52.49711792809622, 52.14917993545532, 54.0244014603751, 51.551690442221506, 50.477123737335205, 41.43960877827236, 41.671553543635774, 42.717358180454795, 50.85217360087803, 53.656775747026714, 54.67548935753958, 48.31463936397007, 42.12287030901228, 43.35914938790457, 53.888376576559885, 51.75688464300973, 51.58346455437796, 49.110058716365266, 48.067787238529746, 50.12587145396641, 46.317615917750764, 45.00580644607544, 44.728111267089844, 48.23013884680611, 48.24039786202567, 46.083996636526926, 46.62566777638027, 48.248183318546836, 44.96168538502285, 45.85994502476284, 43.145544392721995, 44.354628222329275, 38.770843914576936, 38.41660737991333, 39.3949693271092, 38.86853558676583, 38.00701802117484, 34.853501660483225, 38.25552381787981, 34.454369340624126, 31.749883787972585, 37.2745806149074, 38.712110791887554, 40.19356748035976, 39.04673951012747, 40.029277324676514, 36.08196749005999, 37.19016695022583, 38.99609061649868, 42.56168031692505, 44.84184980392456, 44.38639538628714, 43.6908529145377, 42.61898905890328, 47.392943450382774, 51.961641107286724, 45.373779569353374, 36.89452804837908, 37.507650988442556, 38.87165880203247, 50.56907967158726, 50.82922370093209, 45.47331598826817, 47.180523123059956, 44.62694549560547, 43.433696610586985, 41.68123238427298, 39.19255093165806, 39.59316669191633, 39.56737845284598, 36.55170740400042, 35.85032149723598, 37.08989749635969, 34.99798945018223, 37.85739551271711, 39.213760307856965, 35.149164881025044, 37.332243715013774, 29.230512142181396, 34.712696416037424, 36.41333402906145, 35.38253402709961, 37.736993653433665, 38.8680978502546, 38.56654255730765, 40.98970249720982, 42.29036358424595, 40.94066905975342, 42.26933486121041, 44.890553201947895, 45.711590562547954, 45.18961756569998, 48.50328295571463, 44.894770758492605, 45.958095278058735, 47.686414514269146, 47.0007905960083, 47.812958581107004, 47.87196268354143, 49.5894010407584, 51.004884583609446, 52.970856530325754, 54.33183145523071, 53.8280279976981, 50.29831532069615, 50.16667127609253, 46.35247850418091, 45.062114647456575, 44.68878793716431, 44.131406920296804, 41.65030942644392, 41.55205495016915, 44.21919046129499, 47.992197786058696, 47.20207296098982, 48.16217851638794, 48.0511463029044, 51.05637420926775, 48.86679186139788, 58.59916142054966, 55.7778697013855, 66.23005526406425, 25.759951216833933, 1.2286795952490397, 0.10613528053675379, 0.2057944464364222, 0.5317429240260805, 11.706240739141192, 66.76680360521588, 50.98051725115095, 64.83319636753627, 35.34985317502703, 35.207175391060964, 23.765126875468663, 50.18228735242571, 30.127795560019358, 35.901105880737305, 51.321038041796, 59.41909749167306, 18.82268909045628, 0.5033285373023578, 0.20033593076680387, 0.013758016750216484, 0.15819142865283148, 0.0473166183302445, 0.11053153606397764, 0.021993533674893633, 0.06365163983511073, 0.04859078156628779, 0.13017150147684983, 0.046293896423386674, 0.19435347749718598, 0.14396268501877785, 40.72633450371878, 73.86836283547538, 55.74177728380476, 30.152861186436244, 76.11448614937919, 83.64732006617955, 39.053402832576204, 38.96172482626778, 25.179893016815186, 55.77084507261004, 62.00077016013009, 57.53690692356655, 62.62276594979422, 33.484987940107075, 0.2932523584791592, 0.4535499598298754, 0.13373729799474987, 0.16642379547868455, 0.05975156982562371, 6.026000235761915, 57.978360721043174, 62.5433132989066, 58.93519714900425, 54.67817831039429, 55.1892009462629, 55.31566858291626, 54.261439255305696, 51.894042083195274, 44.32219403130667, 44.39666134970528, 45.84031983784267, 52.52010951723371, 54.44233213152204, 54.25117676598685, 50.330933638981406, 44.00592940194266, 43.25753198351179, 54.81424140930176, 52.26620149612427, 53.50634029933384, 50.342029912131174, 51.46674524034773, 50.39940466199602, 48.59065307889666, 48.13538973672049, 45.70349938528878, 50.25697006498064, 49.220062596457346, 48.21911205564226, 48.62084647587368, 50.14467675345284, 46.219267640795024, 48.072272300720215, 46.65731334686279, 47.07315608433315, 42.61211381639753, 42.36458771569388, 41.15121684755598, 42.052808148520334, 41.092789445604595, 39.02661752700806, 41.376790114811485, 37.775142737797324, 35.309890610831125, 40.31603642872402, 41.58313076836722, 42.69697216578892, 41.97004120690482, 40.83891616548811, 40.00068201337542, 39.043525968279155, 40.044636317661826, 44.46066468102591, 46.333447388240266, 43.68714952468872, 45.02403504507882, 44.66372231074742, 47.153543267931255, 52.8700590133667, 45.25405863353184, 35.64411980765206, 37.76135056359427, 38.300398758479524, 51.6146411214556, 52.78861917768206, 49.144042355673655, 46.681093556540354, 46.365791252681184, 45.417049476078574, 42.18092598233904, 41.38357503073556, 40.239832060677664, 39.0007598059518, 36.34570721217564, 37.62392561776297, 37.92673506055559, 36.41905239650181, 40.92391695295061, 42.78108358383179, 38.18846327917916, 40.38109588623047, 34.56693363189697, 37.557104791913716, 39.51774747031075, 39.887864112854004, 42.321074622017996, 43.25992216382708, 43.3121656690325, 44.74652051925659, 44.28231137139456, 45.32909223011562, 44.774452277592246, 49.54016957964216, 47.75490985597883, 47.13195521490914, 50.870106901441304, 46.65401642663138, 47.63922929763794, 49.88268450328282, 48.8767660004752, 48.96841621398926, 49.72177464621407, 50.985690185001914, 52.23913131441389, 56.15126241956438, 57.22252525602068, 56.272723879132954, 52.64840453011649, 55.775611536843435, 49.10258592878069, 47.08920989717756, 47.858500548771445, 47.696704796382356, 42.94146885190691, 44.87190771102905, 47.21789400918143, 50.25495161328997, 49.71555948257446, 51.47734819139753, 51.478689193725586, 54.46793624332973, 50.933220863342285, 63.94379915509905, 58.495445660182405, 71.9190457207816, 26.66494713510786, 1.9470244262899672, 0.444234379700252, 0.27220314368605614, 0.6739975735545158, 14.16953260557992, 75.90750626155308, 55.88527842930385, 70.85489436558315, 39.6933388710022, 35.526875904628206, 25.81781928879874, 58.756621497017996, 36.34863935198103, 37.490207535879954, 57.42618390492031, 68.42108631134033, 24.742342369897024, 0.5738257744482586, 0.24267704518777983, 0.03474942375240581, 0.19234350749424525, 0.04394421786335962, 0.3101961107126304, 0.16135921009949275, 0.2672572476523263, 0.19642998464405537, 0.3288036308118275, 0.1788660106914384, 0.41482197652970043, 0.2626838944852352, 49.30130788258144, 80.89225510188511, 73.58523069109235, 44.25677326747349, 71.35131536211286, 83.26373086656842, 48.5295923096793, 44.298222746167866, 28.217718396868023, 62.751509121486116, 65.63149574824742, 63.51028714861189, 67.94725390842983, 38.32753494807652, 0.7550433703831264, 0.6635731043560165, 0.31881725096276825, 0.7911081037351063, 0.21086151525378227, 7.125507065228053, 60.21665341513497, 64.4073760168893, 60.46494034358433, 56.41192061560494, 55.679344245365684, 58.68215070452009, 55.13700260434832, 54.900711740766255, 44.84723465783255, 46.221369470868794, 48.81731721333095, 55.00813089098249, 56.849799564906526, 56.339548179081504, 50.88024432318551, 43.572799546378, 43.91159718377249, 57.87701082229614, 53.60033205577305, 55.90842982700893, 52.044710295540945, 52.840925216674805, 53.28341082164219, 51.213671003069194, 49.91647359303066, 48.641312394823345, 51.23415081841605, 52.425072056906565, 50.022503103528706, 50.95615339279175, 54.592819690704346, 51.29665681294033, 52.427232946668354, 49.97343839917864, 51.646932874407085, 46.5558522769383, 43.63438490458897, 45.496293681008474, 46.586903776441304, 46.125001430511475, 42.74497032165527, 47.50732816968645, 43.23050349099295, 38.941755703517366, 45.17251457486834, 44.990204266139436, 47.319250856127056, 45.39610760552542, 43.7980740410941, 41.93213530949184, 40.79202624729702, 42.371119022369385, 46.355560030256, 47.945606640407014, 47.377056394304546, 45.89868470600673, 46.36661114011492, 48.22735956736973, 55.25478499276297, 47.789060252053396, 35.93841075897217, 38.82612378256661, 39.41073131561279, 54.82784945624215, 55.557372093200684, 51.47442994798933, 50.387530190604075, 50.68178640093122, 48.70026438576834, 45.28200428826468, 43.79095908573696, 43.77465861184256, 44.299841676439556, 39.81235456466675, 38.58504908425467, 41.34260150364467, 39.682565689086914, 44.002729756491526, 47.813875743321006, 42.086902959006174, 45.82194185256958, 39.7809556552342, 40.65260369437081, 41.63965783800398, 42.78025674819946, 45.95874840872628, 46.90849072592599, 46.60973555701119, 48.52055270331246, 47.29601608003889, 49.465396540505544, 49.841874258858816, 52.86645289829799, 51.26943029676165, 49.25023167473929, 53.688035692487446, 49.771412576947895, 50.9577236856733, 51.27053853443691, 54.55567809513637, 51.7478380884443, 52.90304211207798, 52.5950527872358, 54.194038254874094, 56.9272198677063, 57.0431991985866, 59.218273707798545, 55.517944540296284, 57.26364122118269, 51.908879961286274, 49.47722932270595, 48.93093415669033, 49.0304080418178, 45.61555256162371, 46.9976395879473, 51.01100942066738, 52.962299823760986, 52.209549358912874, 54.77325745991298, 52.80083411080496, 58.051448822021484, 52.66788727896554, 66.31298896244594, 60.70543834141323, 71.14914362771171, 32.445235184260774, 3.8346213442938666, 0.9708733090332576, 0.7410796625273568, 3.659874583993639, 15.23820550101144, 83.03528104509626, 61.635746547154014, 77.94570473262242, 48.17592205320086, 47.187276772090364, 33.83275917598179, 66.94090461730957, 42.43292324883597, 51.3288756098066, 68.29335757664272, 77.5183001926967, 33.6007136617388, 0.8357192842023713, 0.3103109731205872, 0.16910442949405738, 0.297433789819479, 0.16428932787052222], [0.1238170617393085, 0.04962477054713028, 0.17393614165484905, 0.09614860213228635, 0.10979841290307896, 0.042259927705994675, 0.17240668301071438, 0.16158368305436202, 21.382836239678518, 66.4765704018729, 46.026573249271934, 40.37024974822998, 18.529278823307582, 22.23865975652422, 46.28729050500052, 30.13141209738595, 8.21009133543287, 61.59302207401821, 51.49172401428223, 57.84808199746268, 51.29976960590908, 47.66164418629238, 1.3150837016957146, 0.19765153766742774, 0.3422173453228814, 0.06880919808255774, 0.07575459432389055, 0.6130019436989511, 43.051611695970806, 63.70692811693464, 53.50919600895473, 54.97538750512259, 55.006084646497456, 57.237286703927175, 50.9239068031311, 55.298471791403635, 50.2971202305385, 42.221312386649, 42.716527870723176, 52.010667596544536, 52.848856585366384, 52.17529126576015, 43.60351753234863, 47.05231843675886, 44.567274366106304, 53.12339380809239, 53.63235630307879, 50.20180136816842, 48.6409649848938, 50.025039196014404, 49.4132398877825, 53.116487298692974, 48.84723963056292, 46.90774032047817, 44.86566822869437, 50.86984634399414, 45.51951456069946, 47.770605836595806, 45.776094164167134, 45.22460869380406, 44.85039608819144, 44.221302713666645, 46.30351802280971, 40.48479080200195, 39.794907638004844, 38.912583691733225, 41.06525373458862, 36.83743470055716, 37.25441346849714, 35.99192578451974, 33.04262740271432, 31.923022474561417, 32.814160210745676, 34.23692546572004, 35.95620856966291, 40.17060715811593, 37.628612177712576, 36.77251420702253, 38.775843143463135, 37.87067699432373, 43.19617591585432, 44.70138502120972, 45.66399540219988, 41.917686530521934, 47.625211306980674, 52.587149211338584, 51.97575984682356, 40.74204785483224, 34.99627324513027, 39.215056146894185, 34.56999431337629, 49.331021853855674, 51.20961325509207, 48.22821419579642, 43.1575300352914, 44.954744134630474, 43.988148961748394, 42.75037949425833, 43.02099098478045, 39.802894592285156, 37.984078543526785, 38.803927762167795, 39.996342863355366, 36.250468254089355, 33.12176043646676, 36.02683353424072, 36.66975729806082, 33.85470853533064, 28.945328542164393, 36.254095213753835, 37.0459223474775, 30.324478217533656, 36.83985614776611, 37.53755603517805, 38.71495607921055, 38.73407057353428, 43.53216995511736, 43.014129638671875, 45.14218916211809, 41.74582631247384, 45.92554644175938, 45.4823625428336, 47.732891014644075, 46.568167958940776, 45.03908484322684, 48.824043069567, 50.02678666796003, 49.951336179460796, 48.393251282828196, 46.818751267024446, 49.516597815922324, 51.093765939985005, 55.64669466018677, 55.60056904384068, 51.39396980830601, 51.92852251870291, 49.39405591147286, 48.35913562774658, 47.2078469140189, 47.83413321631295, 48.23078155517578, 41.59510946273804, 42.81042235238211, 45.87968833105904, 46.273522649492534, 48.940442766462056, 51.99576718466622, 53.94194718769619, 56.95195892878941, 53.14320312227522, 60.02780832563128, 56.73818717684065, 65.82909556797573, 12.600950717926025, 1.7351565893207277, 0.26560523201312336, 0.04179500908191715, 0.2674647979438305, 21.204373495919363, 68.39300864083427, 51.1478785106114, 64.07153483799526, 44.395970003945486, 41.55496277127947, 17.488120794296265, 49.74125739506313, 28.187174115862163, 31.58697979790824, 48.15262474332537, 59.112779208592, 12.294868673597064, 0.5665913426450321, 0.25168587320617264, 0.09455524584544556, 0.1842009922755616, 0.03696920356846281, 0.06230389286897012, 0.09804216945277792, 0.12628410650151117, 0.032078156912965436, 0.16816062799521855, 0.03749218104141099, 0.22017531762165682, 0.15765343180724553, 25.249302046639578, 73.9830220086234, 49.454077925000874, 36.32218408584595, 29.999462332044327, 36.93057877676827, 47.29797894614083, 33.17540747778756, 15.032111508505684, 64.20249448503766, 56.95752790996006, 63.34819957188198, 54.61553335189819, 54.038544518607004, 1.419400915503502, 0.06355322511600596, 0.5291356667876244, 0.20024260506033897, 0.12821296442832264, 0.521085147346769, 45.832242556980674, 66.30722195761544, 56.108072417122976, 57.94356414249965, 56.696904454912456, 60.35716683523995, 53.56208569662911, 57.63100985118321, 51.902876717703684, 44.44959272657122, 45.59361015047346, 53.2683401788984, 55.30541998999459, 54.90411983217512, 45.96223293031965, 47.622366019657676, 43.0344044821603, 55.40949010848999, 55.00167601449149, 53.444876534598215, 49.47350856236049, 52.27890280314854, 51.278296198163716, 53.847951957157676, 50.45320803778512, 49.06647266660418, 46.5039700780596, 52.28450652531215, 48.44903836931501, 49.96655968257359, 49.72964000701904, 48.9999714578901, 47.67380700792585, 48.67772095543997, 49.007722173418315, 44.17482968739101, 42.89643062864031, 41.20978668757847, 43.987971782684326, 40.03875814165388, 39.74450887952532, 40.249083587101524, 35.569718497140066, 35.252693040030344, 37.059141295296804, 38.53480666024344, 39.353870732443674, 43.618018422807964, 41.78378084727696, 40.49891996383667, 40.27020263671875, 39.013975279671804, 44.74115998404366, 44.536413942064556, 46.350967270987375, 44.37782825742449, 50.02920464106968, 55.94673524584089, 53.52540963036673, 41.79638140542166, 33.56414181845528, 39.23068611962454, 34.55720615386963, 50.93230717522757, 51.11041382380894, 49.26328386579241, 45.2719988822937, 47.24180276053292, 44.98878335952759, 44.14219747270857, 44.7253806250436, 40.266339438302175, 39.821595668792725, 39.127786772591726, 41.11233820234026, 38.936294419424875, 35.700455801827566, 39.87589236668178, 40.59324870790754, 36.264719009399414, 33.7665011542184, 40.150651931762695, 39.5300110408238, 34.045110021318706, 40.13015822001866, 40.47816569464547, 43.32485655375889, 40.13823202678135, 47.39073739733015, 45.86119222640991, 48.817386695316856, 45.398511682237896, 48.038253920418875, 47.0834880556379, 50.07881130490984, 48.19556113651821, 46.69730370385306, 52.316416127341135, 53.07509340558733, 51.39773225784302, 51.06168958118984, 50.36947529656546, 51.37565435682024, 52.7771372795105, 56.78211368833269, 56.725666522979736, 54.95336518968855, 52.714947428022114, 52.38891363143921, 51.49399607522147, 50.80310542242867, 50.79645947047642, 51.1737014906747, 46.25726733888899, 46.39133283070156, 47.319865771702354, 50.51641927446638, 52.82466295787266, 56.14020783560616, 56.54236609595162, 61.173503739493235, 56.967064312526155, 63.11073793683733, 58.28171559742519, 65.5919257572719, 13.419696041515895, 3.0043092242309024, 0.4572390190192631, 0.16308434467230523, 0.6835054776498249, 25.346022708075388, 77.4246106828962, 55.81451102665493, 73.51888929094586, 49.65921654020037, 48.73218093599592, 20.619752066476003, 56.3467048236302, 31.027524743761333, 33.63774756022862, 57.05076231275286, 65.28203610011509, 17.052348886217388, 0.8457708305546215, 0.33733023756316727, 0.11125260844294514, 0.22345606157822268, 0.06320520450494119, 0.28070426466209547, 0.17458036994295462, 0.27560355407851084, 0.18160520227892057, 0.21334742328950337, 0.11015555981014456, 0.19408591756863253, 0.37129227231655804, 29.087302821023123, 88.6700199672154, 58.75184113638741, 53.735856669289724, 28.208234105791362, 36.45129203796387, 62.85095173971993, 36.06761251177107, 18.732876675469534, 72.71264117104667, 61.08200986044747, 68.59526375361851, 59.32273292541504, 58.19142375673567, 1.9710417432444436, 0.535654217004776, 0.8271782653672355, 0.6490085944533348, 0.4232398819710527, 1.021657909665789, 48.59880331584385, 68.45295075007847, 58.79061208452497, 58.479437010628835, 59.56416893005371, 61.184745924813406, 56.16319247654506, 60.14036914280483, 55.13562338692801, 46.71585886819022, 48.796813079289024, 55.710183824811665, 56.67668172291347, 57.38671466282436, 45.884277616228374, 46.5649231501988, 43.35352482114519, 56.49267257962908, 58.05771262305123, 54.17183528627668, 50.15573133741106, 54.94181033543178, 52.2946891103472, 58.12989745821272, 53.41239023208618, 50.71775375093733, 49.394590922764365, 54.878724166325156, 51.281012943812776, 53.951507908957346, 51.63326576777867, 53.37802791595459, 51.197797843388145, 50.97106422696795, 52.55180025100708, 49.001444475991384, 45.96768726621355, 44.55448273250035, 47.35397447858538, 41.87406573976789, 43.82905953271048, 44.63402223587036, 42.83426856994629, 41.97888626371111, 40.97497926439558, 43.41635043280465, 44.18319879259382, 48.060703550066265, 44.68212808881487, 42.31786108016968, 42.693650926862446, 40.55662822723389, 47.473295892987935, 46.10347243717739, 48.61140039988926, 45.627048356192454, 52.966242926461355, 56.96609156472342, 56.15206493650164, 42.44734076091221, 36.46559490476336, 39.736452443259104, 34.42755971636091, 51.56325919287545, 51.941626821245464, 53.05411679404122, 47.32165493283953, 50.46048627580915, 47.66579226085118, 46.894299030303955, 47.70954506737845, 42.974125385284424, 42.89218527930123, 42.957515716552734, 44.315885066986084, 41.990114552634104, 41.07820865086147, 45.011111395699636, 45.68214757101876, 42.29344858442034, 39.07047455651419, 42.63344826017107, 42.32819652557373, 37.17783737182617, 44.40473863056728, 44.157552991594585, 47.6611647605896, 44.26965175356184, 51.609047821589876, 50.52544845853533, 52.87455102375576, 49.58692053386143, 50.13641881942749, 49.10686601911272, 53.39345291682652, 50.03698314939226, 49.938534123556956, 54.1236321585519, 55.32734503064837, 53.752313477652415, 53.636469636644634, 51.144074371882844, 53.73626661300659, 56.33154385430472, 58.722241810389924, 56.93486288615635, 56.50516891479492, 56.03370932170323, 56.70501300266811, 52.768104621342246, 52.2913088117327, 52.27339288166591, 53.37316765104021, 46.13907848085676, 47.69967515127999, 51.20268242699759, 51.94151565006801, 54.84888512747628, 57.409355367933, 58.31393092019217, 63.69984095437186, 58.913581303187776, 67.72352886199951, 60.69852488381522, 72.68097823006767, 17.784006357192993, 4.739661991596222, 1.0038929943527495, 0.5018565505743027, 1.2563423280205046, 29.538671697889054, 83.77707767486572, 61.33748122623989, 79.27135154179165, 54.27343532017299, 54.117747034345356, 26.706613745008195, 66.92333262307304, 37.50037275041853, 42.41340923309326, 63.66470391409737, 78.02545615604946, 24.41782328060695, 0.909700337265219, 0.44687464088201523, 0.20130510947534017, 0.37800431357962744, 0.18183541564004763], [0.00975206813641957, 0.04543973279318639, 0.02573633792677096, 0.03653720746349011, 0.16459175092833384, 0.06766904890537262, 0.3112652919122151, 0.1376808485282319, 7.143731755869729, 63.261604172842844, 44.612569672720774, 53.991890839168, 29.641595363616943, 21.20917991229466, 46.46829802649361, 47.291628292628694, 7.771904928343637, 46.78485100609915, 51.07506833757673, 57.33550296510969, 51.07335908072335, 52.736830779484336, 5.294557724680219, 0.1719395387917757, 0.2622655640755381, 0.2249543076114995, 0.28142875007220675, 0.022105946571433117, 19.032879046031407, 66.41452993665422, 56.58500371660505, 56.82062060492379, 54.918186460222515, 58.78185040610177, 55.87818431854248, 54.65102127620152, 52.76809767314366, 43.529084954942974, 39.48989561625889, 48.51862110410418, 53.5967606816973, 52.80482585089547, 52.29004076548985, 51.81307472501482, 44.11992154802595, 49.985722814287456, 54.05529315131051, 50.00356231416975, 53.03784758704049, 52.28853300639561, 53.76570265633719, 52.43893371309553, 49.76347426005772, 47.64192519869123, 44.692953382219585, 49.52848965781075, 46.08374302727835, 47.80252933502197, 48.785094942365376, 47.2256759916033, 45.27688346590315, 46.42001152038574, 45.36875949587141, 41.538391317640034, 39.74421010698591, 39.99497754233224, 39.973292214529856, 38.010446957179475, 30.117046696799143, 38.39830929892403, 30.608524050031388, 20.86706451007298, 21.45423592839922, 27.83441059929984, 33.124167987278526, 35.829341411590576, 38.93187883922032, 35.5696177482605, 39.747833592551096, 39.15267869404384, 39.64470842906407, 47.10736901419503, 43.9989082472665, 41.76326629093715, 48.787460803985596, 48.0469183240618, 50.68409667696272, 39.21752970559256, 37.06418568747384, 36.00749322346279, 32.78768062591553, 45.38186032431466, 54.31485005787441, 49.44363825661795, 44.140557697841096, 42.89533281326294, 45.85812112263271, 44.88871540342058, 41.19849239076887, 39.101501737322124, 38.95805617741176, 37.60340411322457, 36.93549115317208, 32.56990671157837, 29.31095838546753, 30.86286285945347, 31.58028868266514, 28.754821096147808, 31.75684240886143, 35.989945547921316, 27.980076108660015, 35.393574714660645, 38.530797549656455, 37.49987595421927, 38.193570205143516, 39.990777356284006, 42.57771328517369, 43.19320903505598, 44.5471384865897, 43.79249811172485, 48.795989717756, 44.50300005504063, 48.70886972972325, 45.42129829951695, 44.13138607570103, 51.72576366152082, 48.45524311065674, 50.035621302468435, 53.62484877450125, 50.82251868929182, 51.41102416174752, 49.31553431919643, 58.157172611781526, 57.280778953007285, 49.70909765788487, 52.65943826947893, 50.5068724496024, 51.08356251035418, 50.10223020826067, 47.2825539452689, 50.2284893989563, 48.68126801082066, 44.89407941273281, 43.710564953940256, 46.72552381243025, 52.2862366267613, 56.43866075788225, 58.62436948503767, 54.90854583467756, 56.21723556518555, 62.415723528180806, 54.463753427777974, 44.88642597198486, 4.556976480143411, 1.8253506124019623, 0.07473627610930375, 0.09296982163297278, 1.472398083124842, 43.66377925872803, 60.09576865604946, 55.3844244820731, 57.30824518203735, 56.97415842328753, 60.026349203927175, 18.623805591038295, 45.56858621324812, 33.38897425787789, 33.30349057061331, 47.22474840709141, 60.12373515537807, 7.473149759428842, 0.4221448078751564, 0.08952272803123508, 0.0859800831281713, 0.14382344963295118, 0.0728674346048917, 0.08720018408660378, 0.002391344426931547, 0.13233122415840626, 0.03153209228600774, 0.22130054581378186, 0.0552469522559217, 0.1652815496282918, 0.1638052745589188, 8.259471314293997, 73.12683023725236, 53.108899865831646, 54.581584453582764, 25.576440606798442, 28.199288300105504, 55.10561759131295, 43.89785017286028, 9.669061916215078, 53.74574048178536, 54.457948207855225, 63.19998754773821, 56.53312151772635, 59.59219796316964, 5.701225800173623, 0.1725531244384391, 0.3141908092158181, 0.3503682336636952, 0.27432524838617867, 0.011537532105908861, 21.508357184273855, 69.07823998587472, 59.002177783421104, 60.5570387159075, 58.2053861618042, 59.27051026480538, 55.557868889399934, 58.43521172659737, 52.985340050288606, 44.759489331926616, 41.015855516706196, 50.92999689919608, 55.04247236251831, 54.35313810620989, 55.05674396242414, 51.08986800057547, 43.87750932148525, 51.76015029634748, 54.674429757254465, 53.64663485118321, 54.24956130981445, 54.27089575358799, 55.7780190876552, 53.99136972427368, 53.12649965286255, 49.540166105542866, 47.08523205348423, 51.10824598584856, 48.87079749788557, 48.54993316105434, 51.07540532520839, 50.45244026184082, 48.28830221721104, 47.86380549839565, 48.77495404652187, 44.55646644319807, 42.54429244995117, 43.077337401253835, 43.51703677858625, 42.83515793936593, 35.51804821831839, 41.28644963673183, 37.012657846723286, 26.2747415133885, 26.142227206911357, 32.536607469831196, 37.04109334945679, 40.04739475250244, 44.05934715270996, 36.72453342165266, 40.657085282461985, 40.72480937412807, 39.40716688973563, 48.274450983319966, 44.75309698922293, 43.95093788419451, 50.50644513538906, 48.28368166514805, 52.496812207358225, 39.44563559123448, 35.56442049571446, 36.15584421157837, 32.61106436593192, 45.35063164574759, 53.68997423989432, 49.570776394435335, 45.49483455930437, 44.231342860630576, 45.694852352142334, 46.50864968981062, 41.91919081551688, 40.584434917994905, 39.74238273075649, 39.20750345502581, 38.634885038648335, 37.66554880142212, 33.61121933800833, 35.69669335229056, 36.13501698630196, 33.47150148664202, 36.92376954214913, 38.74037953785488, 32.38520622253418, 38.21504708698818, 42.3134628704616, 40.98358113425118, 42.10758079801287, 42.539355754852295, 47.18097823006766, 47.20622450964791, 48.54714345932007, 48.00214760644095, 50.310797759464805, 46.113905157361714, 50.18510832105364, 47.98693799972534, 46.7256315095084, 53.389839853559224, 50.38226693017142, 52.75176245825631, 56.20453078406197, 51.92432580675398, 54.450513635362896, 50.675220353262766, 57.77901690346854, 59.77478967394148, 52.52856894901821, 56.452699593135286, 52.546682902744834, 53.2582757132394, 53.02948890413557, 49.826685496738975, 53.138117040906636, 50.55056619644165, 47.15186875207083, 46.10698127746582, 51.23053775514875, 55.07342658724104, 59.77657536097935, 60.60490485600063, 58.52061203547886, 59.80445153372628, 66.71523407527378, 58.51908343178885, 49.63515840257917, 5.941386376108442, 2.1593125207083563, 0.21837892330118588, 0.16006124046232018, 1.5179920537131173, 51.287408760615754, 65.94997337886265, 63.19977215358189, 66.61467279706682, 64.76864760262626, 67.16417108263288, 22.232592242104666, 54.49414832251412, 41.17740460804531, 31.709921223776682, 54.05346230098179, 67.71306487492153, 11.268274937357221, 0.47466434112616945, 0.18953648954629898, 0.10499262756534986, 0.16818661588643277, 0.08257683645933867, 0.15742229563849314, 0.08416686792458807, 0.26909241346376284, 0.17599952593445778, 0.36293437651225496, 0.19216563632445677, 0.4348970593086311, 0.2907831152634961, 10.50533320222582, 86.0229161126273, 58.91657597678048, 71.44577612195695, 38.34289394106184, 34.107160908835276, 60.712080819266184, 52.72658566066197, 17.18774495806013, 60.68551090785435, 60.59733826773507, 66.94776943751744, 62.78240776062012, 65.5614092690604, 6.526942772524698, 0.30170769191214014, 0.8119122588208744, 0.5036465259534972, 0.8127010422093528, 0.13822450435587338, 23.39471319743565, 68.64467239379883, 61.98338576725551, 61.76315566471645, 60.11301408495222, 61.64637034279959, 59.45343548910958, 59.80895396641323, 57.22498491832188, 48.17324352264404, 44.21013348443167, 52.7842070715768, 57.68418788909912, 56.5587534223284, 54.743338516780305, 49.68911116463797, 43.59817784173148, 51.77957051140921, 57.123006207602366, 54.16340364728655, 56.97086150305611, 55.42129857199532, 57.25321544919695, 57.61945152282715, 54.50356660570417, 51.30281639099121, 47.85709353855678, 55.29229136875698, 50.709005968911306, 52.13343184334891, 54.12634195600237, 55.066058022635325, 51.430899483816965, 51.94923857280186, 52.54096106120518, 48.14980377469744, 47.647824219294954, 47.16478197915213, 46.18515198571341, 47.08607973371233, 41.719919954027446, 46.292491231645855, 41.118053095681326, 33.87953444889614, 33.72882454735892, 38.21327529634748, 41.509879384722026, 45.69393171582903, 46.84501893179757, 40.555888244083945, 44.3535338810512, 42.48963097163609, 43.024934087480815, 51.29078558513096, 48.80283716746739, 46.69249207632882, 52.45162459782192, 49.82508046286446, 55.31526558739798, 40.02266263961792, 36.40132406779698, 35.99455220358712, 33.391096932547434, 45.7842652457101, 57.79835374014718, 52.465468883514404, 49.76358890533447, 47.09339966092791, 49.477924142565044, 49.32845796857561, 45.26081575666155, 42.95743233816964, 43.247582163129536, 42.11095414842878, 41.465073926108225, 43.062298025403706, 40.02682113647461, 39.83928230830601, 42.866490840911865, 38.10601942879813, 41.32099608012608, 43.46060698372977, 36.40209879193987, 44.88902112415859, 45.34838737760271, 45.50537845066616, 46.64411871773856, 46.161326612745015, 51.677477155412944, 50.52472931998116, 52.07132189614432, 51.42673403876168, 53.35501200812203, 47.90445246015276, 52.6792962210519, 51.73219769341605, 49.15377330780029, 54.82011611121041, 51.66537686756679, 52.97585228511265, 57.70892000198364, 55.488796847207205, 56.06906175613403, 52.3028358731951, 59.34427234104702, 59.47627421787807, 56.36408574240548, 58.197149072374614, 56.05962610244751, 54.55898543766567, 56.19340671811785, 52.24218504769461, 57.002705097198486, 52.80084105900356, 49.81964349746704, 49.4525215285165, 53.63338811056954, 57.034937790461946, 62.197682108197895, 62.00300748007638, 61.194160733904155, 60.28754588535854, 66.18854672568185, 61.820596422467915, 59.03357669285366, 8.985653604779925, 4.142614143235343, 0.28353182865040644, 0.6827912788305963, 2.3509614254747118, 52.47196544919695, 71.60504967825753, 66.57505416870117, 70.85066291264125, 68.69053745269775, 72.81648199898856, 29.515930243900844, 62.23359734671456, 49.37935699735369, 48.70896700450352, 61.07852186475481, 80.58281707763672, 17.306203058787755, 0.8140903562307358, 0.36425239007387844, 0.21710459382406302, 0.2824033163487911, 0.1787559115993125], [0.059517712731446536, 0.038724359923175404, 0.04367280385590025, 0.03143449520160045, 0.05316831111641867, 0.0782487533454384, 0.04229087568819523, 0.12602059064166887, 1.3161222402538573, 52.90137801851545, 54.89902332850865, 45.69539778573172, 49.28626503263201, 27.693614040102275, 33.253303732190815, 27.34219673701695, 16.6221980707986, 40.88315534591675, 55.845055307660786, 51.68632568631853, 54.02085093089512, 55.05345746449062, 18.115869692393712, 0.3097103067806789, 0.29522461550576345, 0.3074587375989982, 0.257586983697755, 0.33776181297642843, 4.100303087915693, 49.003365652901785, 55.997443199157715, 56.08164494378226, 57.71316882542202, 59.19796412331717, 56.91506052017212, 56.74189056668963, 49.67142799922398, 41.196633747645784, 40.544552258082796, 46.58103254863194, 49.941261291503906, 51.49508694240025, 52.1314446585519, 52.544035639081685, 49.36428982870919, 42.91242190769741, 52.312959398542134, 52.87624985831124, 52.909226008823936, 52.8978066444397, 51.7396878514971, 50.30429424558367, 53.18744230270386, 46.00861215591431, 46.01500449861799, 49.31886945452009, 48.2948682648795, 44.307884216308594, 49.28887408120291, 45.096869536808555, 49.461839062826975, 46.613730771201, 46.199083123888286, 44.66328110013689, 39.754083497183665, 40.35635335104806, 37.25177662713187, 38.606876850128174, 32.38984761919294, 28.566533599581035, 34.664924076625276, 24.21906658581325, 21.962038074220928, 18.25290380205427, 27.536860942840576, 30.742169175829204, 34.024022238595144, 36.706881523132324, 38.1865942137582, 37.45310762950352, 40.423486845833914, 44.26564611707415, 43.06478548049927, 42.9948205947876, 47.20588057381766, 45.03943920135498, 44.344921588897705, 43.98579004832676, 31.695218835558208, 32.95553868157523, 29.08350736754281, 46.54435648236956, 50.185643332345144, 50.0530230658395, 47.9107996395656, 43.61601734161377, 45.55849742889404, 44.77622754233224, 41.610544885907856, 37.357986790793284, 38.70357492991856, 39.13620104108538, 37.33857699802944, 27.281844684055873, 25.30851459503174, 21.60419716153826, 19.195451259613037, 26.055030788694108, 32.16487537111555, 28.238601207733154, 33.76501423971993, 40.20103331974575, 37.38276406696865, 39.78910936628069, 37.95515666689192, 43.64538042885916, 45.39558301653181, 44.60983903067452, 46.406851632254465, 43.364989348820274, 47.515982151031494, 47.56793730599539, 48.71633904320853, 45.34377029963902, 43.13595935276577, 50.05428416388375, 49.895698479243684, 48.151565143040244, 52.2520341191973, 50.283804007938926, 51.835937772478374, 50.337253025599885, 59.29193850925991, 53.04162393297468, 44.65360573359898, 53.14030919756208, 51.76149477277483, 53.00385699953352, 50.3982686315264, 50.59942592893328, 50.79215158735003, 49.86557803835188, 47.43389613287789, 44.574966021946494, 44.16927112851824, 50.083633354731965, 52.46152230671474, 58.32088606698172, 57.106549399239675, 60.310857091631206, 57.54565123149327, 52.36744369779314, 31.824545655931743, 3.739232565675463, 0.7016269224030631, 0.4071597691093172, 0.44539467458214077, 6.264817638056619, 55.81284693309239, 58.90631348746163, 56.10813842500959, 49.01027911049979, 61.688837732587544, 57.22660732269287, 17.06660485267639, 49.064683505467, 22.803431919642858, 32.08417551858084, 45.45420149394444, 59.865324701581685, 5.896535319941385, 0.4060581267944404, 0.10239628116999354, 0.1672545259020158, 0.06168137091611113, 0.05424930561067803, 0.01166192877904645, 0.01792293254818235, 0.019349406539861645, 0.031464639119803905, 0.059696689913315434, 0.014774216239207556, 0.08081713052732603, 0.07559290621429682, 1.4526615078960146, 61.13577502114432, 59.960389954703196, 51.462558950696675, 52.51331417901175, 32.58946936471121, 44.07652309962681, 30.359233106885636, 18.0423994404929, 47.005022048950195, 58.17100300107683, 58.19050659452166, 60.20222895486014, 59.50319848741804, 19.954314402171544, 0.3355567098728248, 0.2494728990963527, 0.3468613475561142, 0.5293159399713788, 0.35210528331143515, 5.38077140705926, 53.70414856501988, 58.59588187081473, 58.802945137023926, 59.83796269553048, 59.745245933532715, 57.84014368057251, 57.683590344020296, 52.197744369506836, 43.70477363041469, 42.9020482472011, 46.43706587382725, 53.30407476425171, 53.393758637564524, 54.26419769014631, 51.31346103123256, 44.9752447945731, 44.55195011411394, 53.861896991729736, 54.30926718030657, 54.890188694000244, 52.276516096932546, 53.12116343634469, 52.99163859231131, 54.16352871486119, 48.25844233376639, 47.56322990145002, 50.40978179659162, 49.25007881437029, 45.709130900246755, 50.32114362716675, 49.12889180864607, 50.72639383588518, 50.020554133823936, 48.41532918385097, 48.42001921789986, 43.12426553453718, 42.276387282780235, 41.483990396772114, 43.04540000643049, 37.39742476599557, 33.1134295463562, 38.49157149451119, 30.335376467023575, 26.57020149912153, 24.4751980304718, 33.012427057538716, 36.44113377162388, 37.72527551651001, 39.67460305350167, 40.173160621098106, 41.29809134347098, 41.62738731929234, 45.758789675576345, 46.054341724940706, 44.73771367754255, 49.197859627859934, 46.78401722226824, 46.761939321245464, 43.68636785234724, 31.535552706037247, 33.23295940671648, 28.345289060047694, 46.754042693546836, 53.42416048049927, 51.48476191929409, 49.55023751940046, 45.013126373291016, 46.86488035746983, 46.24750164576939, 45.712792600904194, 39.35104281561715, 39.60204996381487, 41.68041597093855, 41.35034874507359, 32.289793559483115, 29.515499455588206, 26.955791779926844, 24.26498375620161, 30.64413356781006, 36.826112610953196, 32.979805265154155, 36.89365257535662, 41.32600225721087, 41.715288979666575, 42.99575512749808, 42.52151278087071, 48.36570862361363, 48.686392307281494, 48.07325199672154, 51.03845133100237, 48.925108092171804, 51.39343479701451, 49.29087863649641, 51.15921797071184, 45.992242200034006, 46.450191020965576, 51.3851386478969, 52.417415142059326, 50.72137376240322, 54.41796132496425, 53.50932455062866, 54.17457635062081, 52.706269127982004, 56.53295823505947, 52.90793711798531, 49.64130755833217, 55.85313606262207, 55.21039990016392, 55.446676867348806, 52.364212785448345, 51.49733468464443, 52.40280655452183, 51.91642223085676, 53.01345246178763, 48.11728967939104, 46.79922682898385, 52.04471376964024, 57.21092176437378, 59.40932832445417, 60.56347969600132, 60.67702715737479, 61.31722027914864, 58.01256670270647, 36.72563123703003, 5.154543272086552, 0.6209399891751153, 0.7468700632452965, 0.3926815688610077, 7.07749023607799, 63.533959661211284, 64.60085555485317, 67.31437029157365, 53.8337150982448, 65.65443175179618, 66.50015258789062, 20.845592839377268, 58.73137174333845, 29.3770809173584, 28.702200651168823, 53.18705667768206, 67.2620017187936, 9.829010316303798, 0.5085602594273431, 0.3837513694805758, 0.2375492746276515, 0.02290303522853979, 0.034903651369469504, 0.2442209023450102, 0.09969358119581427, 0.20699386564748629, 0.1268349140882492, 0.2746281192771026, 0.14892285742930003, 0.1277147704469306, 0.19261835488889897, 1.9359609399523054, 74.51640742165702, 71.59268188476562, 60.46061161586216, 61.280214173453196, 41.12189892360142, 47.882221698760986, 33.31248501368931, 25.81542216028486, 52.82657718658447, 66.02944687434605, 62.280747822352815, 65.78058324541364, 66.8742436000279, 22.014034918376378, 0.35247986178312984, 0.7090960187571389, 0.5903636813163757, 0.8757634897317205, 0.40122174631272045, 7.11251653943743, 59.049606187003, 60.73959568568638, 58.499975885663716, 61.84970242636544, 60.740207127162385, 62.57731778281075, 59.743307386125835, 53.720657484872, 45.43280799048287, 45.360042980739046, 49.99336583273751, 56.5056483404977, 54.520836353302, 55.97343717302595, 52.221538475581575, 45.3324099949428, 45.783313342503135, 55.007873807634624, 54.985167094639365, 56.11149093082973, 54.358338832855225, 56.29656662259783, 55.939491748809814, 56.76765101296561, 49.84361825670515, 48.24725920813424, 54.80528518131801, 52.16642536435808, 48.55524853297642, 54.45093052727835, 52.701725006103516, 55.42638465336391, 51.57515103476388, 52.97664090565273, 52.41924946648734, 47.86857196262905, 48.047317845480784, 46.842128481183735, 47.237745012555806, 42.29542187282017, 37.87922327859061, 43.029565061841694, 36.93507773535592, 34.30850580760411, 30.323595796312603, 38.4642824445452, 39.378206798008506, 41.843351227896555, 42.28390175955636, 43.95207391466413, 42.39852966581072, 43.94260004588536, 47.7054317338126, 47.6655455998012, 46.097121783665244, 53.92438561575753, 49.75818320683071, 48.683915274483816, 45.67033563341413, 31.36477988106864, 32.67820133481707, 28.015192304338726, 47.906394481658936, 57.02194465909685, 54.43216691698347, 52.45104442323957, 47.39505917685372, 49.4129376411438, 50.22143350328718, 47.13554048538208, 41.29268217086792, 41.76605946677071, 44.4337716783796, 44.38888284138271, 37.09378848757063, 36.86140945979527, 33.089218548366, 31.91275998524257, 36.634884289332796, 42.769393239702495, 36.180013520377024, 39.85484627314976, 45.126326424734934, 43.638008390154155, 47.95548350470406, 45.42937905447823, 52.48312425613403, 52.76629114151001, 52.37345388957432, 54.4730292728969, 50.657151562826975, 55.61302716391427, 52.292027950286865, 53.846364293779644, 48.86829962049212, 46.68497065135411, 52.0380608694894, 56.42935364586966, 52.210424831935335, 56.99054574966431, 55.690228598458425, 56.60031754629952, 56.165808473314556, 57.90212508610317, 54.470493180411204, 49.63448790141514, 58.32652800423758, 57.61197178704398, 57.11710023880005, 55.43621982846941, 54.58404758998326, 55.25830772944859, 53.96820790427071, 53.22958312715803, 49.22060455594744, 51.283448287418906, 54.27359165464129, 58.84761510576521, 61.21394920349121, 63.228822571890696, 62.03198841639927, 61.88095542362758, 52.168124198913574, 36.99685764312744, 7.511469074657985, 1.5184256647314345, 0.9847704661743981, 0.7920278172407831, 8.716433491025652, 68.19144139971051, 68.9213079724993, 69.38655240195138, 63.0144567489624, 69.82999338422502, 70.75006689344133, 27.834304639271327, 67.68306255340576, 33.69367013658796, 49.9733897617885, 61.21465791974749, 82.26400320870536, 14.02283181462969, 0.9196331671306065, 0.4676691879119192, 0.42135602448667797, 0.2490343212016991, 0.20630588542137826], [0.050519530927496295, 0.09727718228740351, 0.1380595253514392, 0.07629165479115077, 0.15145277524633066, 0.19355306401848793, 0.05420100409537554, 0.10697606684906141, 0.13228418811091355, 31.542712824685232, 64.30732195717948, 37.175249167851035, 32.85912895202637, 32.5578168460301, 34.96406487056187, 17.161668368748256, 30.768864154815674, 58.38155773707798, 56.07990094593593, 52.173866885049, 52.119247095925466, 56.41443586349487, 30.96689476285662, 0.032598447387239764, 0.0822253960317799, 0.12953495420515537, 0.4468848460486957, 0.1830395981669426, 0.29977579414844513, 29.52686323438372, 57.15552030290876, 56.91583871841431, 58.87400436401367, 56.952983788081575, 55.77377373831612, 55.71906362261091, 45.28931031908308, 41.59435905729021, 42.18403877530779, 44.5406037058149, 49.03045667920794, 52.06610032490322, 49.8002302306039, 52.356806005750386, 48.88933876582554, 39.93222836085728, 46.7446209362575, 44.86451482772827, 48.64336906160627, 47.837294646671836, 52.16684225627354, 53.71394899913243, 53.61898102079119, 47.98220975058419, 46.58838374274117, 49.05681814466204, 49.12976380756923, 45.74179785592215, 48.501907212393625, 45.23031663894653, 48.31864152635847, 49.14848920277187, 46.10155473436628, 43.03962952750069, 42.749910490853445, 39.32952771868025, 36.718158449445454, 39.939426694597515, 33.4981096131461, 28.435280391148158, 32.768159661974224, 32.98674651554653, 32.309439590999055, 27.428766080311366, 31.586413519723074, 36.30859688350132, 37.38666895457676, 37.48758806501116, 39.579159123556956, 35.24298988069807, 38.06385081154959, 41.410065037863596, 42.612304891858784, 44.99185446330479, 49.49854292188372, 43.20772034781319, 39.16984074456351, 42.43325676236834, 34.30105039051601, 24.09174953188215, 33.04735912595476, 45.53921965190342, 43.79090002604893, 46.44244725363595, 46.98460824148995, 41.78750508172171, 42.2716520854405, 41.99081632069179, 42.81740181786673, 38.27247742244175, 36.597040925707134, 34.30769634246826, 33.52395691190447, 22.547578402927943, 15.506221839359828, 10.785329971994672, 15.792317390441895, 27.907905169895717, 31.56987680707659, 33.29104287283761, 40.02268695831299, 38.28661700657436, 38.63599675042288, 39.22929995400565, 42.828904560634065, 45.22230189187186, 47.687453269958496, 40.196100098746165, 49.90952886853899, 45.15125308718, 44.9073817389352, 44.49031611851284, 48.96102333068848, 44.96721267700195, 47.38763502665928, 50.85554347719465, 49.88980988093785, 50.786558287484304, 49.36478662490845, 51.38580220086234, 53.07464872087751, 51.8598222051348, 70.97600146702358, 51.977799143110005, 45.53316082273211, 52.54097148350307, 53.4504976272583, 52.14986433301653, 49.36885479518345, 50.79026862553188, 50.663470949445454, 50.47374691282, 47.97639063426426, 44.01122392926897, 44.52802051816668, 48.64970234462193, 52.05920076370239, 55.89566251209804, 60.74892711639404, 60.0566919871739, 55.20092603138515, 35.85757541656494, 16.507408618927002, 1.7746819598334176, 0.28134311895285335, 0.824261867574283, 0.23417915403842926, 13.553283844675336, 64.46737371172223, 50.5786577633449, 44.74562767573765, 50.75717088154384, 69.11878272465297, 42.02000917707171, 17.430032117026194, 51.35870770045689, 27.04389320101057, 56.15654305049351, 48.2496771812439, 54.17571585518973, 2.1830469157014574, 0.19808020895080908, 0.01790480887783425, 0.012028256264914359, 0.04199271043762565, 0.13553148029106005, 0.07318082278860466, 0.024618799232744744, 0.057645118928381374, 0.1295338278370244, 0.10994366010917084, 0.1418050250836781, 0.015917839515688162, 0.17368629149028234, 0.0686193032722388, 35.21897343226841, 74.74948474339077, 42.38965681621006, 39.684709208352224, 34.65681900296892, 41.28645658493042, 22.437308754239762, 38.50120517185756, 62.40418951851981, 61.52688911982945, 57.01156752450125, 58.54481955936977, 61.47301278795515, 35.39655549185616, 0.01784988316441221, 0.04610359788473163, 0.7613722022090639, 0.8533563635178975, 0.18353978704128945, 0.7450514265469143, 37.09892668042864, 59.960688727242605, 60.11755125863211, 61.14136832101004, 59.587744167872835, 57.528054918561665, 56.61371367318289, 48.393636907849995, 42.887394496372764, 44.67753185544695, 45.6267078944615, 53.697766644614084, 53.44810049874442, 53.07189376013619, 51.269204480307444, 44.37733840942383, 40.277220317295615, 45.52374601364136, 46.78093222209385, 48.82138190950666, 49.11251490456717, 52.90603331157139, 55.990387303488596, 53.885246413094656, 48.24040133612496, 46.27783053261893, 50.9966926574707, 52.71913371767317, 48.856088161468506, 49.584523405347554, 48.11492034367153, 50.38785328183855, 50.37866428920201, 47.53356804166521, 46.10007129396711, 47.73336001804897, 43.17556061063494, 41.41010325295584, 42.34553575515747, 38.55974721908569, 32.499945299965994, 36.34080525806972, 35.92796761648995, 39.75431626183646, 32.67584242139544, 35.49482386452811, 38.01651273454939, 40.39496449061802, 39.401969637189595, 42.444839409419465, 39.098913533346995, 39.68044301441738, 42.936525208609446, 45.25353751863752, 47.12288086754935, 51.38418327059065, 45.2663882119315, 41.38234519958496, 43.2007235118321, 33.18774400438581, 25.10971794809614, 33.30824661254883, 46.687353883470806, 46.398624965122764, 48.45231097085135, 51.45198379244123, 43.13536875588553, 43.970107964106965, 43.933980805533274, 44.311486857278005, 39.84967681339809, 37.52172456468855, 39.70576572418213, 36.97307048525129, 26.274006741387502, 19.166782992226736, 14.715334449495588, 20.388599395751953, 32.83708231789725, 36.66288552965437, 36.946236542293, 41.98265566144671, 41.29098333631243, 41.88891404015677, 42.85116311482021, 46.60832507269723, 48.16347435542515, 48.82353932516915, 42.20567546572004, 52.65133319582258, 50.037181173052105, 48.11121695382254, 46.20280041013445, 50.84844241823469, 46.003824847085134, 48.86821276800973, 54.369591440473286, 51.28411531448364, 51.98886067526681, 49.94785165786743, 53.93904978888375, 54.57219396318708, 52.572922774723594, 64.60633768354143, 50.69380331039429, 47.20908716746739, 53.96065868650164, 54.87087965011597, 55.06355667114258, 52.47202798298427, 53.47633102961949, 51.334840638296946, 53.247502531324116, 51.01409094674246, 46.94193240574428, 45.191069739205496, 51.72976234980992, 54.60619149889265, 57.278378350394114, 62.90589114597866, 61.80333014896938, 55.90391002382551, 39.81082943507603, 17.957346541540964, 2.3639484771660397, 0.305983873882464, 0.7774014249444008, 0.5905973687767982, 16.931698628834315, 71.48546423230852, 58.77491610390799, 49.845535959516255, 53.09412799562727, 77.81154891422817, 50.08934824807303, 18.74772150175912, 60.162652015686035, 24.029841082436697, 51.19600520815168, 55.341519355773926, 60.98350524902344, 4.184253828866141, 0.22761579336864607, 0.18658657212342533, 0.04888650069811514, 0.04049971287271806, 0.07419696969113179, 0.19793336040207318, 0.18591252900660038, 0.265026794480426, 0.19757654597716673, 0.2009904592164925, 0.48362360894680023, 0.2810834843133177, 0.3606061600148678, 0.17325498749102863, 45.702682971954346, 84.43448148454938, 52.51566614423479, 45.1897600037711, 46.61258084433419, 49.62692478724888, 23.70072054862976, 41.11454772949219, 68.59395749228341, 68.0601829801287, 64.00013514927456, 63.22436877659389, 67.21510832650321, 37.11184338160923, 0.18641798331269196, 0.3133254327944347, 1.8438656074660165, 1.9710745300565446, 0.31184706783720423, 1.624256500176021, 41.61518280846732, 61.55302129473005, 62.34674876076834, 62.879057203020366, 63.095500537327354, 59.8178893498012, 60.96715613773891, 50.04637016568865, 45.78027697971889, 47.56269489015852, 47.84505925859724, 54.389817646571565, 55.966099875313894, 54.252708843776155, 55.99618904931204, 46.93895162854876, 40.1283586365836, 44.68650197982788, 46.33794287272862, 50.61031723022461, 51.72475617272513, 54.64585181644985, 56.77315051215035, 56.09181710651943, 49.62617785590035, 48.53167676925659, 52.263856479099815, 55.38090521948678, 50.39758423396519, 52.88874271937779, 51.65308550425938, 55.85437631607056, 55.10817452839443, 52.72948653357369, 48.064476421901155, 52.1651816368103, 47.33023943219866, 46.96798815046038, 45.52237721851894, 41.96085221426827, 38.15226663861956, 42.10206740243094, 41.78457294191633, 43.59663186754499, 38.57120132446289, 41.566173689705984, 44.702076366969514, 47.06167418616158, 44.260136195591514, 45.89227499280657, 40.53716284888131, 43.88151148387364, 45.97170679909842, 47.41508041109358, 49.450923442840576, 53.66152484076363, 46.62044620513916, 44.058596747262136, 45.20313876015799, 34.89639983858381, 24.5167030947549, 33.646971293858115, 48.347886494227815, 49.067903995513916, 52.76580129350935, 51.10341698782784, 47.04332051958357, 47.433395862579346, 47.81846850258963, 47.3315179007394, 41.929505416325156, 40.61131402424404, 41.796110425676616, 42.95378105981009, 32.353018692561555, 25.993040697915212, 20.10984287943159, 27.205589941569738, 37.70805093220302, 40.84870965140206, 40.59707716533116, 46.83420058659145, 46.36885888235909, 46.00949457713536, 47.25869730540684, 50.23608030591692, 51.42974608285086, 52.71015664509365, 44.83463062558855, 58.671408789498464, 50.7310664994376, 52.12246411187308, 48.224250248500276, 53.56907211031233, 49.61727721350533, 52.28040361404419, 56.022630419049946, 53.567786693573, 54.97611359187535, 54.30454240526472, 56.06216219493321, 56.55591855730329, 52.935577051980154, 66.04967308044434, 54.378488608769004, 47.71014608655657, 55.29070717947823, 59.254522459847585, 57.15305369240897, 56.77352224077497, 55.078199999673025, 55.27414962223598, 55.08272327695574, 53.98632880619594, 48.319683756147114, 48.577649525233674, 55.25087663105556, 57.542211873190745, 60.22480365208217, 67.66270433153424, 63.08456407274519, 58.242228984832764, 40.949969223567415, 21.227988685880387, 4.129268825054169, 0.7563119594539914, 1.3108616939612796, 1.1590250985963004, 17.561191524778092, 78.94127736772809, 61.366503851754324, 56.12595360619681, 62.086073194231304, 80.08136558532715, 54.80527823311942, 30.974582944597515, 66.86802496228898, 37.918435437338694, 69.43452276502336, 62.20426205226353, 74.57680116380963, 6.544932961463928, 0.5198990681341716, 0.4999661520123482, 0.12104778390909944, 0.0931503458746842, 0.2773338726588658], [0.06015933544508048, 0.014427086205354758, 0.04321385294731174, 0.1897272528814418, 0.02166856968376253, 0.12284860227789197, 0.11197599462632622, 0.07237242973808732, 0.38521021977066994, 12.373741149902344, 65.9613128389631, 44.28607382093157, 44.919620990753174, 28.387770346232823, 48.1761930329459, 22.375601802553447, 22.830649750573293, 62.20661054338728, 52.67308800561087, 49.58650016784668, 48.41240746634347, 55.48535748890468, 35.89822237832205, 0.7020014194505555, 0.21581030184669153, 0.8744951177920613, 0.40697542471545084, 0.08008085896394082, 0.17114611422376974, 26.99443244934082, 69.39962196350098, 54.09929609298706, 57.788619313921245, 53.7685409954616, 56.37756177357265, 44.71248129435948, 44.98814412525722, 43.19220849445888, 46.262238774980815, 44.43239940915789, 52.693654673440115, 51.68332406452724, 56.40008783340454, 36.17540339061192, 43.46422004699707, 49.85732010432652, 44.60553114754813, 47.50791529246739, 48.65230791909354, 50.24785055433001, 53.00622980935233, 52.16335426058088, 50.94509186063494, 47.5437228339059, 46.41180222375052, 50.054350171770366, 51.26818656921387, 47.015482561928884, 48.45883880342756, 43.93307406561715, 45.32320015771048, 44.598558630262104, 44.12225614275251, 47.4434985433306, 47.12986033303397, 40.844092573438374, 40.647232736860005, 38.68481131962368, 38.91824299948556, 37.44980376107352, 30.970049245016916, 25.046367747443064, 31.628502232687815, 37.20781537464687, 39.19137668609619, 40.68155336380005, 35.72650807244437, 39.58966132572719, 38.46944843019758, 36.908973353249685, 37.5711783681597, 40.721981457301546, 46.70324093954903, 51.365426608494346, 53.53682899475098, 47.5957544190543, 38.20762988499233, 40.11757503237043, 37.618123871939524, 30.203433649880544, 43.483261585235596, 40.6223338672093, 41.203376974378315, 44.513877459934776, 47.93561513083321, 45.345840862819124, 43.471324580056326, 41.91097109658377, 40.28719793047224, 36.286039556775776, 37.613965375082834, 37.57774441582816, 36.5986042703901, 25.433834041867936, 21.67524422918047, 19.93437828336443, 21.168862989970616, 28.776808670588903, 33.47618804659162, 37.91541991915022, 37.08842100415911, 38.526527881622314, 39.91488913127354, 36.810486112322124, 42.02621044431414, 43.42288868767874, 45.41116087777274, 47.56249686649868, 43.77042021070208, 45.80407108579363, 47.74487318311419, 46.86446693965367, 49.79194450378418, 44.27431746891567, 46.51932559694563, 51.13115767070225, 49.32495607648577, 49.118889876774375, 49.56816039766584, 52.99234383446829, 49.33325569970267, 47.57842213766915, 50.97450358527047, 47.16355562210083, 44.46924223218645, 47.9660621370588, 49.86254514966692, 53.74646309443882, 52.36151688439505, 53.26118006025042, 51.13875205176217, 50.82328299113682, 47.53829976490566, 48.03341102600098, 42.42345632825579, 43.86625323976789, 49.06417976106916, 54.78004584993635, 53.55120481763567, 58.76979528154646, 57.69796616690499, 56.24597678865705, 27.53728825705392, 0.5875851618392127, 0.09447553155145474, 0.10314059337334973, 0.3427540122398308, 22.491153819220408, 67.87446457999093, 40.71096856253487, 44.75154059273856, 61.57008607046944, 62.31377261025565, 19.575991937092372, 35.384149483272004, 46.99232421602522, 42.600847312382285, 56.89410822732108, 45.06645379747663, 51.92102888652256, 0.939215362071991, 0.029112219278301512, 0.034996200153338056, 0.060302906669676304, 0.05472824955359101, 0.012182863861588495, 0.033658665139228106, 0.07242913490959577, 0.060357759440583844, 0.2475295476615429, 0.05700416796441589, 0.1797182099627597, 0.08496379373329026, 0.16845195022012505, 0.3197432884148189, 14.068132332393102, 76.76556015014648, 50.50437804630825, 46.16776759283883, 35.83452476773943, 52.91157102584839, 21.309755086898804, 28.191379513059342, 69.6638411113194, 59.120533398219514, 56.43961613518851, 55.83495610100882, 59.710129737854004, 40.07101167951311, 0.7416486548525947, 0.1115477711760572, 1.3103820511272974, 0.8647157454064914, 0.1514310756964343, 0.2321388806615557, 30.03447777884347, 71.51732172284807, 55.4429144178118, 60.797877175467356, 56.19471297945295, 56.378249645233154, 45.82602391924177, 46.062780312129426, 44.571606567927766, 48.02707426888602, 45.63862752914429, 56.20740386417934, 52.362128325871055, 58.533605166843955, 36.826095240456716, 42.758366448538645, 48.47712993621826, 46.466123240334646, 49.72649942125593, 49.94580888748169, 53.88675764628819, 53.80299711227417, 53.568144525800435, 52.64590665272304, 49.19511161531721, 47.000877448490684, 52.906165327344624, 52.3949933052063, 49.83821255820138, 49.19385051727295, 48.183141231536865, 47.92006853648594, 47.690771034785676, 47.29952144622803, 50.2148813520159, 48.960008893694194, 44.72961207798549, 43.52756677355085, 43.879614625658306, 41.777596950531006, 41.88479723249163, 35.019671303885325, 31.769220624651226, 35.02731432233538, 40.77430486679077, 43.195418562207905, 42.994716371808735, 38.66353593553816, 41.54509285518101, 40.84317888532366, 39.8015570640564, 39.466334274836946, 42.97192975452968, 47.208183901650564, 51.44966656821114, 55.10505131312779, 48.47311040333339, 39.162764004298616, 40.25298500061035, 35.87114177431379, 28.24568315914699, 43.70343610218593, 42.18361840929304, 43.5531222479684, 46.36918197359358, 49.43131215231759, 47.19225863048008, 44.28930820737566, 43.82639837265015, 42.46957847050258, 38.60225977216448, 40.04885040010725, 41.703487464359824, 38.614637987954275, 30.49988201686314, 27.209750175476074, 24.297787938799175, 25.533589329038346, 33.15407998221261, 36.408011708940776, 40.60768706457955, 40.92351048333304, 43.09972102301461, 41.32332372665405, 40.91856336593628, 45.1929110118321, 47.256935937064036, 49.60601765768868, 50.051237378801616, 47.41065788269043, 48.56825903483799, 48.88847371510097, 49.49069493157523, 51.89632109233311, 46.35469150543213, 46.76447541373116, 52.86543151310512, 52.52512959071568, 50.98275457109724, 51.49891887392317, 54.80405535016741, 51.774095330919536, 49.75091886520386, 49.67139325823103, 47.42369270324707, 47.062045914786204, 50.14999212537493, 53.238059929439, 55.62042352131435, 56.346875054495676, 55.26020458766392, 53.1784165927342, 54.85638918195452, 51.44365290233067, 51.36136538641793, 45.09059878758022, 48.013702460697715, 51.108652455466135, 56.81162963594709, 55.95096322468349, 61.9359712600708, 59.661193575177876, 57.85625307900565, 30.605630125318253, 0.7824310521994318, 0.2960059621504375, 0.04343568300828338, 0.2969709746539593, 26.936482736042567, 75.67312267848423, 49.78412430627005, 44.92598206656319, 68.52622645241874, 68.80532169342041, 23.055179050990514, 36.68128088542393, 54.009466307503835, 37.03520475115095, 56.47949532100132, 54.40395375660488, 57.803728171757285, 1.85650720340865, 0.09298731426575355, 0.0627074312152607, 0.014383293555251189, 0.03575043932401708, 0.10039410753441708, 0.15752394018428667, 0.19156627277178423, 0.1429247028593506, 0.38796485481517656, 0.15601861024541513, 0.29948198848537033, 0.13030467075960978, 0.5129244338188852, 0.49303461824144634, 19.451016426086426, 92.56606946672711, 58.844370297023225, 61.007546016148154, 41.76587186540876, 66.69006075177873, 30.1092369215829, 34.2138227054051, 72.14235387529645, 64.94568075452531, 60.30076135907854, 60.504552023751394, 65.67153126852853, 42.94995955058506, 1.0876505970954895, 0.24625439037169727, 2.9676883092948367, 1.7754652606589454, 0.28061396522181375, 0.48522321454116274, 34.89960643223354, 71.6089198248727, 57.58719103676932, 62.03482328142439, 57.66714743205479, 58.81317983354841, 48.66260862350464, 48.78912489754813, 46.60262754985264, 50.69485248838152, 48.56174162455967, 56.63572209221976, 55.969737257276265, 59.074279240199495, 43.96281582968575, 48.6572585105896, 46.90629856927054, 48.05011796951294, 50.03405448368618, 52.728048256465364, 55.05499301637922, 57.268921852111816, 55.882398400987896, 55.159973348890034, 51.26396206447056, 48.806512764522004, 54.62049783979143, 54.40260580607823, 51.97691324778965, 53.245126247406006, 51.67477430616106, 52.94367517743792, 53.57555825369698, 49.52156925201416, 53.86659744807652, 53.592848845890586, 47.06464106695992, 46.91442101342337, 48.99373197555542, 45.88232864652361, 43.15165185928345, 40.13992738723755, 36.25128814152309, 40.87671783992222, 43.80678708212716, 46.575953415461946, 48.6112961769104, 42.25060599190848, 48.387383529118125, 43.61619452067784, 41.93150649751936, 43.80726650782994, 45.70774473462786, 50.97772060121809, 56.34211901256016, 56.999606200626914, 51.39957700456892, 42.355186803000315, 42.69463757106236, 39.09654419762747, 29.222841330936976, 45.350558689662385, 44.22488798413958, 46.05492189952305, 48.68207400185721, 52.401548930576865, 49.781178270067485, 47.90798909323556, 46.06185967581612, 44.93814141409737, 41.9525317464556, 42.55761562074934, 42.846921239580425, 44.839581217084614, 36.38684402193342, 32.58718340737479, 29.627976894378662, 32.65974344526018, 38.97399187088013, 39.821081502096995, 44.6024044581822, 46.20054224559239, 46.7465386390686, 47.426242692129954, 43.6920097896031, 49.873224530901226, 50.432154996054514, 54.57391364233834, 52.62327289581299, 50.21539899281093, 52.6530876159668, 52.55597264426095, 52.06881359645298, 54.33210243497576, 47.97511911392212, 49.246139185769216, 53.44470977783203, 55.052112988063264, 53.35241685594831, 56.657664503370015, 56.124327727726524, 53.78896869931902, 49.95569617407662, 59.20649651118687, 52.45882987976074, 47.00613376072475, 52.10617058617728, 55.560425826481406, 59.012391635349815, 58.16510050637381, 57.130138533455984, 55.67360503332955, 56.187667506081716, 52.51434598650251, 53.16741064616612, 47.13039534432547, 48.35584912981306, 53.35243075234549, 60.68374606541225, 57.22471741267613, 64.00809778485979, 61.23789964403425, 58.50886957986014, 34.75038691929409, 1.914093004805701, 0.5486141272953579, 0.332925378211907, 0.9154894351959229, 29.593920298985072, 79.79714952196393, 53.82187189374651, 54.45972694669451, 72.64217254093715, 73.96336555480957, 31.339992182595388, 47.74077374594552, 63.73184435708182, 55.931397097451345, 71.10143034798759, 59.07862186431885, 72.89704636165074, 3.234460485833032, 0.17134436858551844, 0.13014980192695344, 0.15362932559634956, 0.122870980362807, 0.11111932380923203], [0.04896204539441636, 0.018497024064085314, 0.05376383076821055, 0.15243515824632986, 0.09104493313602038, 0.1357604315770524, 0.04060473313022937, 0.09367407312882797, 0.1708058967654194, 3.6042692363262177, 62.90138176509312, 46.880312306540354, 39.07613386426653, 17.46356064932687, 42.340936047690256, 27.5282712323325, 21.269056013652257, 54.958861214774, 57.74325452532087, 45.075399603162495, 44.97523437227522, 54.701347078595845, 40.59022971561977, 1.443100460938045, 0.04493613088769572, 0.19993596151471138, 0.5968607355441365, 0.2166806451444115, 0.05313158201585923, 19.827056407928467, 63.97268281664167, 54.70357745034354, 57.449342250823975, 50.68120275224958, 48.19575221197945, 43.025757449013845, 47.96174035753523, 47.20498078210013, 51.69582387379238, 50.112378052302766, 54.53483697346279, 51.148868628910606, 57.80999892098563, 37.58083636420113, 28.006178753716604, 48.436837332589285, 48.02920389175415, 52.57040752683367, 54.07171521868025, 53.680427415030344, 50.694855962480815, 50.69920553479876, 47.433618204934255, 45.89381054469517, 45.450974055698936, 49.67042398452759, 50.23382214137486, 48.56391988481794, 46.7913475717817, 47.596445764814106, 42.63606078284127, 46.824316774095806, 44.914475849696565, 45.15918792997088, 45.84983886991228, 46.56576040812901, 38.00837639399937, 39.64803661618914, 32.15071494238717, 37.849971362522666, 36.51652520043509, 35.924052306583945, 34.46206447056362, 34.40690967014858, 33.74797378267561, 36.499842575618196, 39.84568854740688, 37.80994279044015, 37.27705764770508, 41.26873867852347, 39.14501135689871, 44.62051493780953, 45.990713596343994, 52.57878705433437, 52.082439013889854, 49.193016733442036, 42.06590550286429, 42.288240909576416, 40.37321662902832, 43.505110195704866, 42.25561216899327, 42.97496264321463, 42.08781664712088, 49.20158386230469, 57.0445818901062, 48.822886194501606, 44.5335373878479, 41.86012765339443, 40.9129353250776, 40.45740100315639, 36.823211738041465, 35.47499370574951, 34.64681707109724, 38.02863734109061, 34.06792443139212, 35.40307290213448, 29.0817095211574, 28.439254760742188, 33.966793400900706, 36.96090071541922, 38.943162713732036, 40.26323011943272, 39.5375394139971, 41.80861370904105, 43.165173053741455, 46.5995842388698, 42.53023624420166, 47.35160166876656, 43.84668711253575, 47.03048372268677, 46.36705582482474, 46.15569857188633, 48.7262020111084, 43.239459718976704, 43.95100736618042, 47.79447637285505, 49.49551698139736, 49.40936974116734, 49.17265851157052, 52.03829710824149, 53.06836754935128, 51.78560502188546, 30.006337574550084, 38.488719258989605, 52.3325845854623, 51.62449366705758, 53.15555007117135, 51.43030193873814, 52.61643934249878, 54.56228583199637, 51.692759718213765, 52.264363697596956, 51.55834681647164, 50.25162690026419, 48.604413986206055, 44.461818081992014, 43.872530937194824, 49.88210085460118, 54.495610918317524, 56.34110457556588, 53.94042553220476, 57.100983892168315, 22.873407227652415, 0.5381696820259094, 0.8485095607382911, 0.13489715861422674, 0.4933435416647366, 35.994628633771626, 58.50784819466727, 49.06412417548043, 57.96386677878243, 64.92309216090611, 31.935261726379395, 22.96833872795105, 52.97669301714216, 30.88480874470302, 47.840143408094136, 41.804642813546316, 58.45934282030378, 34.677684443337576, 0.12710856726127012, 0.030686406950865473, 0.0341535682257797, 0.01582968594240291, 0.04179877834394574, 0.04027373357010739, 0.026874417572149208, 0.029490129356937747, 0.016527284402400255, 0.03373248974925705, 0.04897739724921329, 0.09816769843122788, 0.05847618861922196, 0.11605281622282096, 0.1738407396312271, 4.900743816580091, 72.84748486110142, 54.29027080535889, 37.703114237104145, 23.188563619341167, 50.875345843178884, 26.50831389427185, 24.145891632352555, 58.68731321607317, 66.6131511415754, 46.82082183020455, 53.08708252225603, 59.00470692770821, 46.7784378187997, 1.5729456820658274, 0.046755317199443064, 0.3957344607583114, 0.9956990054675511, 0.24662842601537704, 0.05342400686017104, 23.775807993752615, 67.46078968048096, 58.16083083833967, 60.84942586081368, 52.52305555343628, 49.26990897314889, 45.11047758374895, 49.52183328356062, 47.59685223443167, 52.623682839529856, 50.48242173876081, 56.58627871104649, 52.914148807525635, 58.91992500850132, 38.57592609950474, 30.379858834402903, 49.031672613961355, 49.554680892399375, 55.92914240700858, 54.593257427215576, 55.13592215946743, 53.30883080618722, 51.84119755881173, 48.69959388460432, 48.80254186902727, 49.1045001574925, 51.88645117623465, 53.161070414951865, 49.70411927359444, 48.18676471710205, 50.999541418892996, 46.34253215789795, 47.74877807072231, 47.44637162344796, 48.50459963934762, 49.73492063794817, 48.98250021253313, 42.95126928601946, 44.18012074061802, 36.278413908822195, 41.686964648110525, 40.712736879076274, 39.2320271219526, 37.41777603966849, 38.08426114491054, 37.089136668613975, 39.490413257053916, 42.11840261731829, 41.509775161743164, 40.70928015027727, 43.88402325766427, 40.93573236465454, 46.4979772567749, 48.07823385511126, 53.04804059437343, 53.3219906943185, 50.342905385153635, 42.16703653335571, 43.047248227255686, 42.318090370723176, 42.264915806906565, 43.53679050718035, 43.16217490604946, 41.95144435337612, 50.155852930886404, 57.726491996220176, 50.98166717801775, 45.555850165230886, 44.942543097904746, 42.56058597564697, 43.51189511162894, 38.041446345193044, 36.98331560407366, 36.832567487444194, 39.431812150137766, 36.58291523797171, 38.61047601699829, 33.11266524451119, 32.16496569769723, 38.21043348312378, 41.3218993459429, 41.11319283076695, 44.49571834291731, 42.00531373705183, 46.13697665078299, 46.07596451895577, 48.9453238759722, 45.36929450716291, 51.56397138323103, 46.9909519468035, 49.99147939682007, 48.597295556749614, 48.04996163504464, 50.76478958129883, 47.38698884419033, 46.16608960287911, 51.172047819410054, 50.90369449343, 52.88961819240025, 53.51741572788784, 53.62770101002285, 55.32687950134277, 53.04820040294102, 31.483382156917028, 40.116862842014854, 55.07786996023995, 53.5832325390407, 55.186977522713796, 54.30291305269514, 54.450204440525596, 58.15145771844046, 55.53886904035296, 55.071880613054546, 56.15081773485456, 53.0875688961574, 50.85030453545706, 46.7178703716823, 45.858013425554546, 52.17884874343872, 56.631921427590505, 59.43515477861677, 58.78608880724226, 58.31018584115164, 23.19413260051182, 0.4847101335014616, 1.0350721670048577, 0.05973987188190222, 0.5488359811050552, 40.609184401375906, 65.88134602137974, 52.08516270773751, 59.79566901070731, 74.0365092413766, 33.12743364061628, 27.114153385162354, 56.093373503003804, 40.62483869280134, 45.94181564876011, 42.394555296216694, 66.42452144622803, 40.80759368624006, 0.2077819433595453, 0.019547925530267612, 0.11171975944723402, 0.03674630142216172, 0.057462742286069055, 0.044495843084795136, 0.13772575397576603, 0.09929768993918385, 0.1426409530852522, 0.2254654208996466, 0.18443444903407777, 0.3943703610982214, 0.12190367441092219, 0.35803073963948656, 0.304043318011931, 6.85386507000242, 87.31095232282365, 61.964736802237375, 54.41321223122733, 26.80286192893982, 61.38599354880196, 35.03425209862845, 32.299305643354145, 66.13273879459926, 69.83134133475167, 54.75618921007429, 59.54249055044991, 62.994967051914756, 50.41019174030849, 1.5671945278133665, 0.08176936621644668, 0.6022411382624081, 2.564420074224472, 0.5725792241947991, 0.09299101228160517, 28.787406410489762, 67.86406312670026, 59.66729409354073, 62.42469365256173, 56.13517386572701, 51.788356508527485, 47.24689926419939, 52.65445988518851, 49.7912357875279, 55.84767477852957, 54.148555346897666, 59.86812482561384, 55.10476991108486, 61.816059248788015, 40.65865904944283, 33.14188241958618, 51.35409757069179, 52.01626784460885, 57.87194211142403, 57.62405123029436, 58.21417563302176, 54.81546776635306, 52.16155120304653, 50.176450865609304, 52.67186164855957, 50.65500456946236, 53.639790875571116, 56.9203793661935, 52.498243536267964, 50.79446881158011, 53.55153833116804, 50.6641275542123, 53.296456064496724, 51.62508078983852, 52.05407994134085, 54.21622732707432, 53.91382435389927, 44.24874809810093, 48.148702485220774, 41.867301668439595, 46.27590240750994, 42.680762018476216, 42.6645518711635, 42.57361037390572, 42.476825441632954, 44.037585394723074, 43.885121073041645, 45.88471187864031, 45.27332946232387, 45.326128823416575, 48.334337506975444, 44.22247348512922, 50.515231132507324, 51.00205666678292, 55.23472554343087, 57.0129154750279, 53.331544467381065, 45.14662558691842, 45.60297979627337, 43.39244515555245, 44.969179017203196, 46.54749359403338, 45.09385401862008, 45.24949366705758, 52.586843490600586, 62.078041076660156, 52.722802366529194, 47.841710226876394, 46.87365940638951, 46.19534846714565, 46.46475791931152, 41.978392941611155, 39.87493004117693, 41.96668175288609, 44.44582680293492, 42.449050017765586, 43.83040400913784, 36.84961141858782, 38.97465542384556, 43.368070874895366, 44.98967620304653, 44.96436391557966, 48.41021530968802, 48.397083214351106, 50.181648118155344, 50.752154282161165, 52.189510754176546, 49.34833329064505, 54.411231994628906, 51.20080641337803, 54.800793170928955, 52.32481302533831, 50.12729236057827, 55.7489721434457, 48.524947438921245, 48.17729432242257, 54.038450717926025, 52.856034074510845, 54.08547960008894, 56.5174046925136, 56.872669560568674, 58.348123005458284, 53.30689573287964, 40.454805850982666, 45.266478538513184, 55.36573382786342, 57.44523933955601, 55.40326452255249, 57.802244731358115, 55.92001247406006, 61.61296340397426, 56.889706543513704, 57.071492263248985, 58.1233036177499, 55.56010273524693, 54.31586102076939, 48.93596117837088, 49.345911843436106, 55.02942711966378, 60.030379159109934, 62.47622149331229, 61.62256581442696, 60.786350114004954, 26.704746416636876, 1.4964206112282616, 1.3836721926927567, 0.22840031555720738, 1.2053175802741731, 43.228672640664236, 69.69668524605888, 56.96436493737357, 67.78547205243791, 77.7122244153704, 43.9885311126709, 34.17020191465105, 64.1389045715332, 48.66504396711077, 56.610243047986714, 56.40269340787615, 73.20278099605015, 56.66389356340681, 0.5977021732500621, 0.2968149387410709, 0.22581618279218674, 0.11294471871640001, 0.20230056105979852, 0.10170549859425851], [0.04222052178478666, 0.02587879805027374, 0.05721017119607755, 0.027219696901738644, 0.04750529517020498, 0.08816569192068917, 0.04157931637018919, 0.01969726599885949, 0.16260270694536821, 0.47012548467942644, 53.41007995605469, 44.3941148349217, 48.08306632723127, 20.628567593438284, 30.95718812942505, 26.670158284051077, 26.318767036710465, 61.07815361022949, 53.627176421029226, 55.06548827035086, 36.63489818572998, 52.47247961589268, 43.11421843937465, 2.1159872455256323, 0.3389321230351925, 0.4052665749830859, 0.3531345123691218, 0.42660101875662804, 0.12069243511983327, 19.38517008508955, 62.74497086661202, 53.40900298527309, 57.40306377410889, 50.92708212988717, 49.794623034340994, 51.3020555632455, 49.77166966029576, 52.24877541405814, 54.83899089268276, 53.647301878247944, 52.94406080245972, 52.70874963487898, 53.716005665915354, 47.969911439078196, 42.52507025854928, 50.59942592893328, 52.98621204921177, 54.605715547289165, 51.874826839991975, 51.561859130859375, 49.58120911461966, 46.33362109320504, 47.674116202763145, 44.86983714784895, 45.625085490090505, 46.463034766060964, 49.94237300327846, 47.353877203805105, 47.24269560405186, 49.59431341716221, 43.41362673895699, 43.69305549349104, 45.20512594495501, 45.43161637442452, 45.826242787497385, 45.08727754865374, 43.00002826963152, 39.72160414287022, 39.25428567613874, 31.602623667035783, 36.441383906773154, 35.93240751538958, 33.048734869275776, 27.764100040708268, 30.36529541015625, 29.476700714656285, 31.123972688402446, 37.599808420453755, 40.45632750647408, 39.826028619493755, 39.812660285404746, 39.94294595718384, 44.020874977111816, 47.65269490650722, 46.00174386160714, 45.382725375039236, 39.949512004852295, 39.00339317321777, 42.639041560036794, 41.89341647284371, 41.46805470330374, 41.409255572727744, 43.963024275643484, 48.6152149609157, 54.431545053209575, 50.908249037606375, 43.103792667388916, 44.023049763270784, 40.76732192720686, 32.04112795421055, 31.961199351719447, 41.19246482849121, 41.9253226007734, 38.08168683733259, 33.34732328142439, 30.514619146074565, 22.9229895727975, 20.78603982925415, 23.74902789933341, 35.73778847285679, 37.295275824410574, 40.41295337677002, 35.96906621115548, 42.50022350038801, 40.99854755401611, 47.9595308303833, 38.54994331087385, 43.99327325820923, 46.1043062210083, 47.69565561839512, 46.5388674054827, 47.65312916891915, 47.89533294950213, 43.93792043413435, 44.3750559261867, 46.86981357846941, 46.43745844704764, 49.16647808892386, 47.74109683718, 51.01840925216675, 47.633358069828574, 50.85947963169643, 29.764397825513566, 40.36207171848842, 55.692542348589214, 50.54759236744472, 52.79590783800398, 53.47045980181013, 55.80802140917097, 53.679510252816335, 54.66601896286011, 54.0559150150844, 55.87714556285313, 54.85113981791905, 51.94350978306362, 50.16151571273804, 46.93796498434884, 48.45207820619856, 49.83593007496425, 55.50558022090367, 52.26721593311855, 60.082636560712544, 16.994654519217356, 0.29842545517853325, 0.5856197444455964, 0.04993831140122243, 1.399888202548027, 52.886734689985005, 47.199241570064, 52.31786135264805, 56.90179293496268, 62.93431622641427, 23.650299208504812, 30.109160491398402, 47.42055559158325, 27.98529420580183, 42.49222264971052, 40.66859497342791, 59.08001150403704, 20.854939903531754, 0.40504491116319385, 0.017469174128824046, 0.06745523573564631, 0.03138606137196932, 0.07555409401123013, 0.02763620374857315, 0.024833287544814602, 0.03852395460541759, 0.029833145772239993, 0.03097564268058964, 0.04083659193877663, 0.019962449358510118, 0.08066549152135849, 0.027883000505555953, 0.094203303301973, 0.7382200988275665, 62.496586663382395, 52.19963775362287, 49.10760947636196, 21.819051095417567, 42.546825068337576, 28.998860938208445, 32.33994565691267, 68.59085164751325, 59.66649505070278, 58.755752972194124, 41.92103903634207, 58.36303383963448, 47.774920667920796, 2.5631079503468106, 0.3431395286960261, 0.5911421509725707, 0.6348970745291028, 0.23235457337328366, 0.17751021629997663, 22.71382795061384, 66.40669236864362, 56.34306049346924, 59.095109939575195, 52.187016350882395, 51.27158076422555, 51.750408921922954, 51.93384831292288, 53.8882862499782, 56.28192329406738, 56.624691826956614, 55.615445137023926, 54.58248771939959, 55.75816808428083, 47.59177657536098, 43.87572363444737, 51.17716516767229, 54.80378437042236, 55.14463520050049, 54.35664694649832, 51.95596095493862, 51.06569521767752, 47.4886931010655, 47.647355215890066, 46.314350264413015, 48.16255719321114, 47.82366228103638, 52.32933630262102, 49.562622683388845, 50.4739796774728, 50.650477818080354, 46.9217027255467, 46.362886905670166, 47.71269260134016, 48.83374275479998, 48.68003817967006, 48.467854091099326, 46.718370641980854, 44.00157635552542, 43.119981970105854, 35.26273666109358, 38.494277817862375, 39.389706066676546, 35.948919909340994, 32.377879347120015, 35.03653110776629, 33.658609526497976, 35.892497062683105, 40.00293322971889, 43.700444902692524, 43.687323229653494, 43.048884528023855, 43.82485587256295, 45.30883823122297, 51.99101461683001, 48.22766876220703, 47.02367448806763, 41.43735408782959, 40.09983280726841, 43.45374911172049, 43.898975781032014, 43.86508246830532, 43.48239653451102, 46.367344175066265, 50.46792779650007, 55.685434341430664, 52.15529087611607, 46.27415146146502, 44.78649697984968, 43.6642621585301, 36.42741802760533, 35.80113867350987, 43.90319333757673, 44.3495317186628, 41.74281774248396, 37.45314237049648, 33.294284207480295, 29.462213720594132, 24.728256634303502, 28.733309473310197, 39.45004422324044, 40.63646650314331, 44.48178025654384, 40.795361382620676, 46.009511947631836, 44.020597049168174, 51.50344909940447, 42.64876208986555, 48.50242485318865, 50.76523079190935, 50.96066624777657, 49.16821166447231, 49.42774772644043, 49.69364139011928, 45.75242165156773, 46.520857674734934, 48.52112592969622, 48.594561440604075, 50.68212686266218, 50.53025313786098, 52.38070780890328, 51.17657457079206, 52.89909553527832, 31.404707704271587, 42.816734790802, 56.43704530170986, 52.285124914986746, 55.73718799863543, 55.00002234322684, 57.028531551361084, 55.2918883732387, 56.973668575286865, 57.07080439158848, 58.587398120335166, 59.4408939906529, 55.06716973440987, 52.10411739349365, 48.693416936056956, 53.07558672768729, 53.233025959559846, 59.615689822605674, 54.667877605983186, 62.50268023354666, 18.719266891479492, 0.18259179219603539, 0.891270131937095, 0.05474421548257981, 1.8121077801500047, 57.92568642752511, 52.154755864824565, 56.734796455928254, 62.56486661093575, 69.20733056749616, 27.43399112565177, 35.23064293180193, 52.65633589880807, 37.15283080509731, 40.11637299401419, 45.1197395324707, 67.98536477770124, 26.50056665284293, 0.356549931956189, 0.021454425728214637, 0.0891752163214343, 0.03193611917751176, 0.06516119704714843, 0.01961533459169524, 0.10939524096569844, 0.153652517923287, 0.10512096567877702, 0.1787435079791716, 0.0871186445334128, 0.1464437483144658, 0.1517838053405285, 0.11875168925949506, 0.21937556910727704, 1.1991281466824668, 77.59375762939453, 58.568165506635395, 64.63770185198102, 30.783250399998256, 47.72841984885079, 37.070161138262065, 35.207706928253174, 75.06183406284877, 65.83929552350725, 65.13761084420341, 46.5332602092198, 63.731413568769185, 54.44882869720459, 3.183791833264487, 0.6548292306917054, 0.7545238839728492, 1.5983287543058395, 0.8576386794447899, 0.28044221443789347, 27.15145305224827, 66.26408754076276, 57.96509313583374, 60.94288608006069, 54.71417345319475, 52.61522340774536, 55.45025518962315, 53.57145881652832, 56.03092656816755, 58.67908654894148, 58.99292278289795, 58.20296124049595, 57.51001392092024, 58.26484884534563, 50.57745572498867, 45.3566244670323, 53.41354363305228, 56.535303252083914, 59.54644407544817, 56.543373584747314, 56.20061547415597, 53.62753772735596, 49.197963850838796, 49.828856808798655, 48.20034497124808, 49.46446548189436, 50.33887195587158, 55.47485876083374, 52.64365891047886, 53.763357639312744, 54.92290776116507, 51.31565318788801, 50.01504421234131, 52.16770035879952, 51.97744825908116, 50.31098188672747, 50.88187020165579, 48.843713419778005, 46.51374966757638, 47.561312198638916, 41.704852785382954, 45.74191944939749, 45.93109457833426, 42.46721608298165, 39.16513334001814, 40.11261749267578, 40.5049648966108, 40.92361123221261, 45.219751902988975, 48.785463196890696, 46.86657919202532, 45.57346732275826, 45.29335764476231, 47.21996457236153, 52.704389640263145, 48.877387864249094, 51.236488887241904, 45.44163220269339, 42.87308815547398, 46.055703571864534, 45.72895411082676, 46.01056112561907, 46.18241439546858, 48.84192773274013, 52.88876008987427, 59.24848447527204, 54.958885533469065, 49.1182575907026, 49.89434010641915, 47.89505154745919, 39.37931850978306, 39.25715528215681, 48.367952891758506, 46.78092874799456, 45.60737453188215, 42.1556727545602, 38.628433636256624, 34.348937375204905, 30.447648933955602, 34.847901412418906, 43.831480979919434, 45.62957055228097, 48.33244412285941, 43.571389062064036, 47.427701813834055, 47.50334685189383, 55.425658566611155, 45.10351201466152, 50.47284017290388, 54.04330056054251, 54.0491544178554, 52.29337590081351, 52.79445913859776, 53.004763739449636, 46.71676560810634, 50.07045957020351, 51.97261231286185, 51.52499198913574, 52.921308926173616, 53.3377492087228, 53.09968655450003, 54.129760469709126, 54.920708656311035, 38.20550373622349, 45.55778176443917, 60.551827566964285, 53.936774253845215, 59.043915612357004, 57.90214940479824, 60.683669635227744, 57.636915819985525, 59.14288575308663, 58.56618527003697, 61.00514888763428, 60.27286434173584, 58.112005846840994, 53.877328940800254, 52.8724422454834, 55.098926476069856, 56.12055485589163, 60.916719164167134, 57.27968461172921, 64.00041307721818, 23.292946406773158, 0.4281760885247162, 1.4641517656190055, 0.15483824429767473, 2.3052987328597476, 61.43412372044155, 57.42720181601388, 62.921503748212544, 67.91262408665249, 72.89239106859479, 34.623102869306294, 41.465143408094136, 62.90238230569022, 43.87019634246826, 52.218502112797324, 53.91694756916591, 75.14471912384033, 40.089896883283345, 0.5336948250021253, 0.2366744258574077, 0.16524138035518782, 0.20780821623546736, 0.22314354191933358, 0.1312506299998079], [0.0229078748795603, 0.0653409341882382, 0.03129540230812771, 0.050172372055905204, 0.03983427697260465, 0.07893208560666867, 0.038923889930759153, 0.0439421720802784, 0.1801998069775956, 0.05007299042439886, 43.21322679519653, 54.591721875326975, 40.67339965275356, 27.270993334906443, 27.6781838280814, 25.853569507598877, 13.789024063519069, 59.986765316554475, 55.80711119515555, 57.127602440970286, 46.84744037900652, 50.378098011016846, 53.283532415117534, 5.735899482454572, 0.7570713758468628, 0.5299968091504914, 0.6632535957864353, 0.34072299408061163, 0.18262970873287745, 14.264070664133344, 60.45289216722761, 55.621139185769216, 54.605423722948345, 50.05472190039498, 49.58376605170113, 54.62774133682251, 53.96978514535086, 54.82461854389736, 52.64795984540667, 53.48260872704642, 51.17584153584072, 56.940011501312256, 48.76329844338553, 44.966451849256245, 46.85166488374983, 53.84473494121006, 51.8776512827192, 51.3976662499564, 53.932768617357524, 49.21766546794346, 48.97287348338536, 45.640058858054026, 44.9229040145874, 46.17299958637783, 46.303313050951274, 46.70168454306466, 47.92007895878383, 49.60321405955723, 46.732089860098704, 48.614481925964355, 45.83769689287458, 44.17390557697841, 41.57661683218819, 47.32019928523472, 47.44916132518223, 45.22251033782959, 44.87017413548061, 42.504420212336946, 41.53979137965611, 41.48958369663784, 34.36394201006208, 35.82193463189261, 31.46063722882952, 28.76856289591108, 31.127992221287318, 33.65731021336147, 33.03318132672991, 39.739530495234895, 38.82893780299595, 35.683509145464214, 38.60325336456299, 40.7079530443464, 43.94622353145054, 46.579761028289795, 43.02193941388811, 44.58278969355992, 45.74648094177246, 44.49455451965332, 43.007671288081575, 41.73213836124965, 39.057401520865305, 39.687599658966064, 41.32740926742554, 44.402563844408306, 46.53941631317139, 48.920289516448975, 43.79621539797102, 44.119077341897146, 38.15835326058524, 24.862817185265676, 15.486256190708705, 23.94398045539856, 23.236332484654017, 25.168862751552037, 26.809837920325144, 19.824383088520594, 18.86729826245989, 21.16096636227199, 29.85600287573678, 35.71141311100551, 39.62174115862165, 38.771486622946604, 41.990072863442556, 43.909095832279746, 42.788396562848774, 45.795712402888704, 45.17500550406319, 46.40078585488455, 47.04917785099575, 49.30800247192383, 45.255479540143696, 46.117368834359304, 45.85857275554112, 42.42151083265032, 43.87077304295131, 44.321613856724326, 47.126695428575786, 47.8510868208749, 48.58755418232509, 52.77307605743408, 63.04153387887137, 55.90987505231585, 36.90433890478951, 47.98414134979248, 51.479203360421316, 49.77513681139265, 52.141575132097515, 51.54319626944405, 53.04759243556431, 54.28276327678135, 53.489466599055696, 55.68767513547625, 53.85727643966675, 55.17224734170096, 54.201792444501606, 53.7816036088126, 50.110894611903596, 51.71603965759277, 52.70756844111851, 57.22019760949271, 52.799635546548025, 54.41344846997942, 9.743456278528486, 0.2672644944063255, 0.67957746556827, 0.14903351292014122, 3.94755562714168, 51.167865003858296, 52.811562129429404, 56.63280732291085, 49.341176646096365, 69.21650913783482, 17.392544848578318, 36.27550261361258, 42.27693619046892, 28.192477328436716, 45.648778847285676, 46.114624295915874, 54.57890592302595, 7.7271793740136285, 0.399292779820306, 0.07824820373207331, 0.12330931398485388, 0.024788967333734035, 0.015652464469894767, 0.032416141991104395, 0.09636908530124597, 0.06569663581571408, 0.0836571863453303, 0.020338496858520166, 0.03546844695561698, 0.021623214706778526, 0.10560219628470284, 0.0907046003267169, 0.1511192074311631, 0.08529008765305791, 51.55511243002755, 62.16911806379046, 44.07451159613473, 27.583502462932042, 33.97536052976336, 23.257738147463115, 17.781291348593577, 68.15460899897984, 61.504488127572195, 62.99197237832205, 49.20866755076817, 55.3463796206883, 57.24491582598005, 6.233955042702811, 0.4665926513927323, 0.840400687285832, 0.8043268887060029, 0.8758319946272033, 0.16150711716285773, 17.262163639068604, 65.27493504115513, 58.93535000937325, 56.547299316951204, 51.754028933388845, 50.33922283990042, 55.97656733649117, 56.17520591190883, 55.79119634628296, 54.556355544498985, 54.85441241945539, 53.74905129841396, 57.821241106305806, 51.39575549534389, 46.566865171704976, 47.41382278714861, 56.20542710168021, 53.535147530691965, 53.90940877369472, 54.27110072544643, 51.397454329899375, 49.44326652799334, 48.995277949741904, 46.73746081760952, 47.75680324009487, 48.26752015522548, 48.95829963684082, 49.428164618355886, 49.962164946964805, 47.852945463997976, 51.23361928122384, 48.410976137433735, 46.326370647975374, 44.14968763078962, 49.565495763506206, 50.412102494921, 48.53555733816964, 46.61552340643746, 46.11800806862967, 44.14661652701241, 43.59299448558262, 40.20529951368059, 39.00687074661255, 35.48547158922468, 33.39301116125924, 35.735380922045024, 38.6070088659014, 36.27268164498465, 43.552952017102925, 43.409607206072124, 40.602896281651084, 41.152748925345286, 41.931478704724995, 47.03380148751395, 47.64600726536342, 45.613662651606965, 45.758358887263704, 45.9085441998073, 45.99565723964146, 44.39975329807827, 40.85043280465262, 40.84343596867153, 41.99242830276489, 41.035869802747456, 46.18456138883318, 49.33889068875994, 50.25950615746634, 45.18556676592146, 45.133865220206125, 42.782462801252095, 28.33216564995902, 18.75297086579459, 30.604514939444407, 27.815483706338064, 29.831173488071986, 31.198481695992605, 24.497845683779033, 23.41589825493949, 25.55881823812212, 34.838212149483816, 39.107504980904714, 42.5940728187561, 42.023309571402415, 43.98362915856497, 47.06853553227016, 45.7992525100708, 48.53931631360735, 48.56946802139282, 48.494052273886545, 47.87618718828474, 50.30956098011562, 48.32011801855904, 49.202730315072195, 47.71386684690203, 45.679795605795725, 46.05851411819458, 47.59553555079869, 48.23174735477993, 48.713104656764436, 50.42904567718506, 54.31082010269165, 61.945073400224956, 55.74199615206037, 39.9669554574149, 50.02083900996617, 53.36605616978237, 51.21493557521275, 52.4680848802839, 54.68579701014927, 55.226363386426655, 57.87799399239676, 56.095207827431814, 57.900252546582905, 56.90694155011858, 58.162977831704275, 55.215975829533164, 55.360546997615266, 52.49130228587559, 55.14684125355312, 54.745492458343506, 60.98313699449812, 56.69494506290981, 56.285810811179026, 9.98465257031577, 0.23556898374642643, 0.906042816383498, 0.20652985626033374, 4.885311433247157, 58.5688533782959, 58.630317143031526, 60.455775669642854, 56.9950829233442, 73.88298184531075, 20.881242309297832, 41.29051085880825, 48.03585679190499, 33.47515623910086, 45.80457135609218, 49.364380155290874, 62.776592118399485, 9.039943354470388, 0.47776839456387926, 0.046830526020910056, 0.08272101836545126, 0.029824976210615466, 0.04570566084501999, 0.08509114118559019, 0.15645520681781427, 0.18538115466279642, 0.19744907638856343, 0.13192793008472237, 0.15269662493041583, 0.13265689382595675, 0.24259741231799126, 0.1258955637791327, 0.3159279131463596, 0.2950646983725684, 61.70812593187605, 73.67598806108747, 55.05320732934134, 36.5046055657523, 42.39261327471052, 38.76486151559012, 20.944503920418875, 71.8921422958374, 68.6139474596296, 69.16937950679234, 57.48059524808611, 61.599080903189524, 63.44916384560721, 7.72695095198495, 1.7023484983614512, 1.1706935124737876, 1.8126659159149443, 1.483011456472533, 0.2507862171956471, 21.872251714978898, 67.26796327318463, 60.86037622179304, 59.38336290631975, 54.98097733088902, 53.61803953988211, 59.234456062316895, 57.768038749694824, 60.15454346793038, 58.46749305725098, 58.893292563302175, 56.242735454014365, 59.20605877467564, 52.08226530892508, 48.00079965591431, 48.5426583971296, 58.497154917035786, 56.156626428876606, 55.77641405378069, 58.50377655029297, 53.21172973087856, 52.3525641305106, 50.20933321544102, 46.9147093636649, 50.1553179195949, 50.5721229825701, 51.7127913747515, 51.405764375414165, 55.13462632043021, 51.264583928244456, 53.27509382792881, 51.46383741923741, 49.78338432312012, 47.791450432368684, 53.3920841217041, 52.546637739454, 52.12880434308733, 52.18564755575997, 48.8596317427499, 48.306075709206716, 50.10043409892491, 42.26039947782244, 44.7060854775565, 41.20518698011126, 40.49440710885184, 41.46711669649397, 44.902281761169434, 42.549010276794434, 49.73260341371809, 47.31077057974679, 46.02618415015084, 43.24585206168038, 44.20833737509591, 49.89416640145438, 49.50002636228289, 48.152291229793, 48.563047885894775, 50.999704701559885, 48.586164542606895, 45.67968096051897, 46.44837754113333, 44.56368562153408, 44.136517320360454, 45.021874155317036, 49.68968786512102, 51.39835064751761, 52.2923058782305, 47.97269766671317, 48.24723488943917, 46.70615918295724, 33.03282349450247, 23.89181511742728, 37.58098227637154, 35.8749806540353, 35.045431750161306, 35.93434953689575, 29.861189705984934, 29.997357027871267, 31.715966156550817, 41.278400148664204, 42.96777125767299, 44.92614187513079, 47.65958057131086, 47.02224315915789, 50.44014195033482, 47.457200390951975, 51.48860774721418, 51.63505492891584, 52.71571172986712, 52.003893102918354, 54.47301537649972, 51.35803025109427, 51.86530780792236, 50.922346932547434, 45.650526319231304, 48.64094761439732, 49.459386348724365, 51.32806961877005, 51.6946496282305, 52.88483435767037, 58.00619173049927, 62.7585198538644, 53.121934686388286, 41.34259455544608, 52.28174809047154, 56.78734220777239, 53.03977918624878, 55.723242964063374, 56.63195964268276, 57.272948333195274, 59.039705004010884, 59.431590352739605, 61.57023893083845, 59.0987924848284, 60.219307626996724, 57.48753997257778, 58.59638908931187, 56.47555569240025, 58.987927028111045, 57.40356404440743, 63.30600316183907, 59.97839968545096, 62.56407451629639, 13.525392038481575, 0.2653071922915322, 1.5353841547455107, 0.3056167321545737, 5.649156868457794, 62.654685974121094, 63.36629268101284, 67.21185656956264, 62.1182016645159, 79.78023760659354, 28.55358910560608, 45.73939377920968, 57.96071924482073, 41.75967059816633, 59.79723930358887, 56.77013151986258, 75.79655047825405, 16.242343527930124, 0.7536135613918304, 0.22539124345140799, 0.1713157615491322, 0.15776978699224337, 0.2010449320077896, 0.147022687963077], [0.017123872746846507, 0.023518140793644955, 0.03895697869094355, 0.023523563984781504, 0.00823082315868565, 0.06031860797000783, 0.017043086367526224, 0.08720076084136963, 0.118895701531853, 0.2026633330221687, 30.272047110966273, 54.88045426777431, 42.885261399405344, 37.41970763887678, 37.96020105906895, 31.01934323992048, 11.66109221322196, 40.15438658850533, 60.87730203356062, 49.89113003867013, 60.00941644396101, 44.777881213596885, 54.52625594820295, 14.591583558491298, 0.0903212483972311, 0.4713983620916094, 0.22633851904954227, 0.7908690965601376, 0.16014248824545316, 11.666058438164846, 57.588097776685444, 56.178481987544465, 56.25821256637573, 51.048960481371196, 51.38868917737688, 56.12406369618007, 56.6226247378758, 57.532359327588765, 56.542404311043875, 55.47917706625802, 51.789231981549946, 49.875145707811626, 45.70536150251116, 45.87250736781529, 50.90642860957554, 52.95150579724993, 53.31033509118216, 52.79897894178118, 50.42491497312273, 50.74535199574062, 49.382448945726665, 48.25646557126726, 49.33220999581473, 48.23106643131801, 47.33180972508022, 43.91524151393345, 44.41749552318028, 48.109188079833984, 44.67507914134434, 49.01609475272042, 48.82775688171387, 50.26705884933472, 45.085165296282085, 45.40531744275774, 45.93454783303397, 46.44250978742327, 45.1368842124939, 45.77881438391549, 39.0562550680978, 41.430103642599924, 40.50630589893886, 38.206792627062114, 35.21117407935006, 34.791683537619456, 40.18462514877319, 41.005262987954275, 40.6753694670541, 35.3300438608442, 41.82128374917166, 39.13904632840838, 37.83070400782994, 40.6213298525129, 44.71271058491298, 47.768323353358674, 49.053333623068674, 51.71177346365792, 52.35918576376778, 52.978186879839214, 47.910698890686035, 47.93064022064209, 51.54352630887713, 47.3478114264352, 47.309019633701865, 44.44042110443115, 42.25002581732613, 46.48241676603045, 42.62900141307286, 40.91532897949219, 38.70317888259888, 36.12929514476231, 29.673313890184673, 27.381692034857615, 22.2437128339495, 26.221954311643326, 24.227685826165335, 19.587211540767125, 19.831591844558716, 25.702682426997594, 33.829761028289795, 37.66184541157314, 39.17409304210118, 39.89760896137783, 42.911827836717876, 41.67418691090175, 42.272683892931255, 46.03924328940255, 43.40140833173479, 44.48170730045864, 45.29160669871739, 47.54215254102434, 44.82139778137207, 45.56389965329851, 46.60502120426723, 43.254113469805034, 44.417742184230256, 45.372223172869, 46.685356276375906, 49.37691470554897, 49.42394011361258, 53.4764769417899, 47.631669657570974, 57.92468588692801, 59.19931207384382, 48.984602042606895, 51.89956590107509, 48.53486599240984, 49.02516910008022, 47.73444741112845, 54.27446017946516, 52.149874755314414, 54.24259226662772, 52.22134045192173, 55.37384237561907, 53.16021926062447, 57.88769020353045, 50.77612556729998, 55.700630051749094, 52.84589317866734, 53.558945110866, 52.94530800410679, 51.37601913724627, 50.90911408833095, 4.917917592184884, 0.29552262808595386, 0.6316384236727441, 0.690365303839956, 11.54131395476205, 58.56888811928885, 53.03447771072388, 50.8648818561009, 57.84333985192435, 54.25994191850935, 17.158696276800974, 58.30798326219831, 34.13231686183384, 33.14521060671125, 29.284913063049316, 47.7437857900347, 47.131986481802805, 2.7454139164515903, 0.2583655076367514, 0.0974764001688787, 0.05595983471721411, 0.0796006733019437, 0.06922623249036924, 0.037669105654848475, 0.01678049161897174, 0.08314473634319645, 0.07277016660996846, 0.028908333075898032, 0.0623501893132925, 0.06351620424538851, 0.06829939436699663, 0.043662697076797485, 0.0971112669046436, 0.24776388651558331, 34.5281001499721, 67.63978917258126, 43.79696580341884, 38.075162478855674, 51.653029918670654, 30.52622958592006, 13.19957103048052, 57.57889836175101, 65.53608308519635, 57.83973373685564, 64.60753277369908, 51.420119353703086, 61.43278966631208, 15.526284762791224, 0.5028853182281766, 0.7379486305373055, 0.1729768831282854, 2.4517003170081546, 0.23054101211684092, 15.160967588424683, 60.80884838104248, 58.428173201424734, 58.193299770355225, 52.713206904275076, 52.407948221479145, 58.602156094142366, 57.79355948311942, 58.64480413709368, 56.48181949343, 59.21048477717808, 53.2648070199149, 50.41305092402867, 47.52683523723057, 46.045896189553396, 52.60286603655134, 55.25957924979073, 54.79080513545445, 54.95943791525704, 50.61899553026472, 52.71829298564366, 50.74076965876988, 48.55553340911865, 51.44442415237427, 48.92573343004499, 49.621070929935996, 45.86184535707746, 47.30481597355434, 52.096495219639365, 46.33901636941092, 50.679917335510254, 50.014662061418804, 51.10839537211827, 47.18681819098336, 48.79558324813843, 49.35965538024902, 48.80247586114066, 49.712189606257844, 48.77103526251656, 43.01971251623971, 43.90375961576189, 42.94507149287632, 42.20092984608242, 40.43065391268049, 39.71789033072335, 43.26332330703735, 43.87302425929478, 44.84803717476981, 41.78327015468052, 44.14857939311436, 43.09487118039812, 40.39586428233555, 41.31733785356794, 44.622276306152344, 48.89079441343035, 51.370401518685476, 53.51487963540213, 54.574903760637554, 54.09676000050136, 48.94502510343279, 48.39677054541451, 51.040737288338796, 48.205865315028596, 47.69825424466814, 45.38003989628383, 43.75313656670706, 47.09385476793562, 43.35147510256086, 43.63277987071446, 41.23230232511248, 38.515396867479595, 32.592575209481375, 32.83053364072527, 26.469013145991735, 31.660741874149867, 28.69646838733128, 24.17262830053057, 25.093323673520768, 30.518089771270752, 37.82291160311018, 40.65347916739327, 41.40167856216431, 43.731176785060335, 45.68598297664097, 45.031949043273926, 47.111218316214426, 47.88230160304478, 47.101087842668804, 47.77362830298287, 50.167994907924104, 48.80351461683001, 46.757919788360596, 46.73735659463065, 48.62660305840628, 44.6118609564645, 47.79211745943342, 48.914963722229004, 50.1874429157802, 50.368537289755686, 51.5805150440761, 56.00140367235456, 48.29238428388323, 58.768051283700125, 60.275449071611675, 52.85746192932129, 53.93496772221157, 49.506891182490754, 51.75593621390206, 50.4779748916626, 57.37541689191546, 54.075957093920024, 56.233320644923616, 54.903275626046316, 57.26572568075997, 55.21306453432356, 60.75636863708496, 56.102326256888254, 56.96545580455235, 54.89516707829067, 56.7073267527989, 57.07798535483224, 55.67986536026001, 52.00292035511562, 5.383997976779938, 0.29973934324724333, 1.1386158508913857, 0.642574128295694, 14.349834884916033, 63.52807453700474, 59.49544429779053, 55.1514652797154, 60.93454129355294, 57.17589242117745, 20.886828660964966, 64.34728799547467, 38.27444723674229, 42.88218682152884, 31.39306252343314, 50.093065534319194, 57.374190534864155, 3.263237318822316, 0.5531163428510938, 0.04929960299549358, 0.046742299505110295, 0.07886828974421535, 0.035220537401203594, 0.0320998089654105, 0.16414724263761724, 0.22303864040545054, 0.13367370569280215, 0.07375435451311724, 0.1640089029180152, 0.22239000163972378, 0.23518045459474834, 0.23988202373896325, 0.26223806983658243, 0.30863767862319946, 43.69937488010952, 76.19268117632184, 58.215579169137136, 50.69023193631853, 53.182456970214844, 46.4789913041251, 19.239414249147686, 54.65682649612427, 70.3342033113752, 60.010416984558105, 68.82422079358781, 56.038586957114084, 66.4496739251273, 17.639080830982753, 1.6373136852468764, 1.7741565023149763, 0.3904004155525139, 3.0060738495418002, 0.2834566741117409, 19.166607550212316, 62.792371477399556, 60.673080580575125, 60.327199254717144, 54.15799100058419, 53.18493052891323, 60.91230705806187, 58.832426343645366, 59.31664630344936, 56.85129690170288, 59.237714767456055, 53.679072516305105, 53.88145964486258, 48.15651226043701, 49.014222213200156, 53.65798473358154, 58.37324769156319, 55.58713122776577, 57.44826528004238, 53.624431882585796, 55.343516962868826, 52.774354525974815, 51.04613256454468, 51.99190398624965, 51.5583051272801, 51.430982862200054, 46.409526688711985, 47.32444116047451, 55.04473052706037, 48.407616683415, 54.220260756356375, 54.244193826402935, 54.113911628723145, 49.91855110440935, 53.67554977961949, 51.5381692477635, 54.935320717947825, 50.8955512046814, 51.4633024079459, 44.378133978162495, 49.71205759048462, 49.54719420841762, 47.64856767654419, 44.87908172607422, 44.98811285836356, 48.47838756016323, 47.50527497700283, 46.88932064601353, 46.33158527101789, 48.963851247514995, 47.25783225468227, 44.25898279462542, 43.14006226403372, 48.68782016209194, 51.93179859433855, 53.244389738355366, 56.58044569832938, 56.40764399937221, 57.06760127203805, 52.02696459633963, 51.40538569859096, 54.892908913748606, 50.70039367675781, 51.356981073107036, 47.77038696834019, 46.17990262167794, 50.691777910505024, 47.17523554393223, 47.06740297589983, 43.760032653808594, 43.403520584106445, 37.608785493033274, 38.51418440682547, 33.15108183452061, 36.92196995871407, 35.31506354468209, 30.853430679866246, 30.74157510484968, 36.348875590733115, 41.91143315179007, 45.06707566125052, 45.290463720049175, 48.202561446598594, 50.77066428320748, 49.52176380157471, 50.7349922316415, 51.936644962855745, 50.16664000919887, 50.10348435810634, 53.54245008741106, 50.428288323538645, 48.44915648869106, 49.41034943716866, 52.10703911100115, 47.91782774244036, 50.77226931708199, 50.41737617765154, 52.15315430504935, 53.749954564230784, 54.93666519437517, 58.009929861341206, 56.663778918130056, 60.01746940612793, 57.61483791896275, 56.62014423097883, 56.99593755177089, 53.510193075452534, 53.875977516174316, 54.037592615400044, 61.05134746006557, 57.77921492712838, 56.445247650146484, 56.8284581729344, 59.359634808131624, 56.11966896057129, 63.02802658081055, 58.50845268794468, 58.308601651872905, 56.42445516586304, 59.51834556034633, 60.22987583705357, 59.22014972141811, 56.829288482666016, 8.135401674679347, 0.3501220340175288, 1.5701219992978233, 0.8370279882635389, 14.934155804770333, 70.04888248443604, 64.02905355181012, 60.08465848650251, 70.03246389116559, 64.33353751046317, 27.979801654815674, 68.48042392730713, 49.47736481257847, 45.98289687292916, 44.620261328560964, 58.96426841190883, 69.53516047341483, 6.260689539568765, 0.730300455221108, 0.30098385789564674, 0.21338533982634544, 0.18343891602541718, 0.19400928382362637, 0.12520588721547807], [0.08415974330689226, 0.0374990546011499, 0.04726073418610862, 0.07288033355559621, 0.02324048426401402, 0.06299780349114112, 0.05114390188828111, 0.15525903100413935, 0.16607331857085228, 0.6236295934234346, 15.098020383289882, 57.851792335510254, 41.00976194654192, 36.79580109460013, 20.96446783202035, 36.03665828704834, 12.884621347699847, 20.89589606012617, 61.04863766261509, 54.68090895244053, 52.083846024104524, 50.01732669557844, 51.586976868765696, 27.35577004296439, 0.1687300138707672, 0.2773953207901546, 0.3040381611457893, 1.2063233320202147, 0.36284331711275236, 6.878670138972146, 55.58010312489101, 56.71603284563337, 57.75970091138567, 53.21588822773525, 54.03675535746983, 56.386326926095144, 56.290250710078645, 62.25484493800572, 58.4553337097168, 58.09749105998448, 51.4502397945949, 46.77383116313389, 46.85422529493059, 50.41675778797695, 46.6858218056815, 52.603154386792866, 48.92948545728411, 52.77579280308315, 53.66238294328962, 53.06837797164917, 51.669920989445274, 51.89958674567086, 53.5060658454895, 52.424985204424175, 49.709361689431326, 46.013534954616, 47.0978638785226, 48.22372565950666, 43.95713220323835, 49.22981439317976, 49.588108675820486, 47.77876649584089, 47.63271883555821, 47.24931376320975, 48.02119261877877, 49.28419099535261, 48.52043458393642, 49.70232663835798, 47.50702939714704, 43.28779138837542, 39.536778586251394, 41.70922320229666, 39.178508622305735, 35.74664395196097, 38.1851281438555, 40.60330622536795, 39.45096833365304, 39.34371246610369, 38.91601610183716, 37.70219012669155, 39.30668204171317, 41.2209871837071, 49.46822793143136, 54.48879126140049, 55.22630085263933, 55.918233735220774, 52.20746142523629, 53.440735408238, 48.638397625514436, 41.40518045425415, 47.3282070841108, 52.56112820761544, 56.25028467178345, 53.04601519448416, 48.048175948006765, 44.49909169333321, 41.38839360645839, 41.054251262119834, 40.283299991062705, 38.949534211839946, 40.4096599306379, 38.016168798719136, 40.17982046944754, 31.37329489844186, 26.025926521846227, 24.232381071363175, 33.04937757764544, 34.9445230620248, 38.36424575533186, 38.78123494556972, 38.6557365826198, 43.30848659787859, 47.433548722948345, 43.69552557809012, 44.75091872896467, 45.43746328353882, 44.82323905399868, 45.60951457704817, 43.76346853801182, 44.96408598763602, 42.15076037815639, 43.79993615831648, 44.668933459690635, 41.76495122909546, 43.85284669058663, 46.58971432277134, 48.27621235166277, 49.81924745014736, 52.15768453053066, 49.9989903994969, 47.731775828770225, 37.178250789642334, 55.194102900368826, 51.87607404163906, 50.94904885973249, 44.58921677725655, 44.65178877966744, 45.72321489879063, 48.66491889953613, 50.99114452089582, 52.43954862867083, 49.83146585736956, 52.33969954081944, 52.00614084516253, 55.32073034558977, 61.6871006829398, 66.68105588640485, 55.14118194580078, 55.4017949785505, 52.55053915296282, 54.87119926725115, 38.422065189906526, 0.5769921988248825, 0.44149787511144367, 0.4550450438899653, 0.5904793579663549, 22.599665573665074, 58.80920546395438, 50.101907117026194, 57.42974485669817, 62.35904707227434, 44.63644715717861, 20.184247664042882, 45.11319432939802, 32.21952642713274, 29.74527985709054, 24.042123760495866, 53.0504481451852, 39.054955754961284, 1.2486898643629891, 0.1684656430568014, 0.08543656979288373, 0.025397167108686905, 0.07373036151485783, 0.041481281630694866, 0.06692974429045405, 0.12308767730636255, 0.02479462631578956, 0.03649231558665633, 0.0518354512085872, 0.060611117631196976, 0.052003700751811266, 0.08384455700537988, 0.09517055497105632, 0.19103256426751614, 0.4657231494784355, 17.352372101375035, 68.70346110207694, 47.68686614717756, 41.482267243521555, 26.172865288598196, 43.51970141274588, 12.064104233469282, 26.891039780208043, 72.28981549399239, 60.757348333086284, 57.11277845927647, 56.14398765563965, 58.04591110774449, 30.730027198791504, 0.12449411755161625, 0.14799303375184536, 0.6395620299237115, 1.8342447408608027, 0.324789254793099, 9.924558469227382, 59.681489263262065, 59.57240949358259, 60.40993840353829, 54.28270769119263, 56.21873985018049, 57.9929449898856, 58.40006078992571, 61.68255656106131, 55.433256421770366, 52.475852966308594, 49.42134496143886, 47.630408559526714, 48.667990003313335, 49.348861353737966, 45.46112537384033, 52.95207207543509, 52.038244996752056, 54.39011641911098, 54.76995359148298, 54.49440540586199, 52.76681573050362, 52.621761662619456, 55.33171197346279, 53.381783417293, 51.77787167685372, 48.20644896371024, 48.97715009961809, 49.7383565221514, 45.016308648245676, 51.18838998249599, 52.49442550114223, 50.53663158416748, 50.709620884486604, 50.01261234283447, 49.469006129673545, 52.411728041512625, 50.71010031018938, 52.65743024008614, 50.06717307226998, 46.499721254621235, 44.354860986982075, 44.640258244105745, 43.20213747024536, 40.660128593444824, 42.098496028355186, 45.17947666985648, 43.96814857210432, 43.033991064344136, 45.08347340992519, 40.78730494635445, 41.85658059801374, 42.54172509057181, 48.90846020834786, 55.557347774505615, 55.97856494358608, 57.55913073675973, 54.85433598927089, 55.273114340645925, 48.94411488941738, 40.670067991529194, 50.700035844530376, 52.527922766549246, 58.81530598231724, 53.00474984305245, 48.83885662896292, 45.60356344495501, 43.82983773095267, 40.6845132963998, 43.42549773624965, 41.22710507256644, 44.920694487435476, 41.02794885635376, 43.47486816133772, 34.62684447424752, 30.713424478258403, 28.460363388061523, 38.064420563834055, 38.149331024714876, 41.50599534170968, 42.823134081704275, 41.81540904726301, 46.34276144845145, 48.09721633366176, 46.788179193224224, 47.213304724012104, 48.5401223046439, 48.466276850019185, 47.252339703696116, 46.81704895836966, 49.74260881968907, 44.36379289627075, 48.15698821204049, 47.34190545763288, 43.022773197719026, 44.855332783290315, 49.27356719970703, 50.15260464804513, 53.88765743800572, 52.98556934084211, 52.05352061135428, 49.66982296534947, 43.03438711166382, 60.0012731552124, 53.30712849753243, 54.04481874193464, 46.50584956577846, 46.71353816986084, 46.53619582312447, 50.75261633736746, 51.25018726076399, 55.97075169427054, 52.12962770462036, 54.13801145553589, 51.92193910053798, 53.44475494112287, 56.1002140045166, 63.30102130344936, 57.637815611703054, 59.29664938790457, 56.53101621355329, 58.801624979291645, 39.66108185904366, 0.8888651866997991, 0.48431338050535744, 0.5041527673602104, 0.2852649970778397, 27.994420664651052, 63.15329565320696, 55.57576397487095, 60.279298373631065, 68.26482827322823, 49.033798762730186, 25.443773439952306, 52.988529273441856, 37.20711013248989, 37.35462038857596, 29.56301818575178, 60.23522594996861, 47.642467158181326, 1.0636123269796371, 0.2965112807495253, 0.021150326688906977, 0.04036347661167383, 0.06012907956859895, 0.02926101182986583, 0.0718658829906157, 0.20837814493903092, 0.1312937983976943, 0.18076069759471075, 0.13828300764518126, 0.08694109906043325, 0.18296928836831025, 0.1575161913143737, 0.24649212190083095, 0.3773605738367353, 0.5589114118899617, 22.737203427723475, 79.85434709276471, 55.077967235020225, 52.50641114371163, 31.21195772715977, 52.01916871752058, 20.981351954596384, 32.05275923865182, 70.95187037331718, 69.5724514552525, 61.69928087506975, 61.2289434160505, 62.257346289498464, 34.22730915887015, 0.5881367836679731, 1.056994384952954, 0.9851750901767186, 3.5360902547836304, 0.4740220127361161, 14.01142634664263, 64.117233140128, 60.48782770974295, 61.08976405007498, 56.18306085041591, 58.062552043369834, 60.374905586242676, 58.750541823250906, 63.77663244519915, 55.38216979163033, 52.70984050205776, 51.44088404519217, 51.1554867880685, 48.457786151341026, 52.19230740410941, 47.599926812308176, 56.27708387374878, 51.02977303096226, 57.32020650591169, 58.6872923714774, 57.82624380929129, 54.122801848820274, 55.94521706444876, 56.7363771711077, 54.6029223714556, 56.37649175098964, 49.53041083472115, 51.56165763310024, 51.87858234133039, 48.95138617924282, 53.61334603173392, 54.34192718778338, 53.33304875237601, 51.35053661891392, 52.707050800323486, 52.52729048047747, 55.885400022779194, 53.71898296901158, 57.723479952131, 52.59963165010725, 48.75682619639805, 47.36687380926949, 48.73295218603951, 47.32128667831421, 46.32033266339983, 47.255605357033865, 49.68396602358137, 48.07116058894566, 49.009890011378694, 46.92027487073626, 46.84239598682949, 45.70915174484253, 45.77601425988333, 53.4017664364406, 59.404561860220774, 58.40438256944929, 60.26412350790841, 57.48317650386265, 58.302230153764995, 52.00501523699079, 42.038331576756065, 51.939688273838584, 54.7769330569676, 61.06903062547956, 55.78881311416626, 52.61331612723214, 48.79474599020821, 45.215704577309744, 42.68856484549386, 45.48283849443708, 42.58757625307356, 48.3544316973005, 45.65151296343122, 51.66342094966343, 41.254189150674, 36.08033813749041, 33.95327568054199, 43.97381135395595, 42.69656222207205, 46.409293924059185, 48.03099305289132, 45.97922822407314, 48.30805247170584, 52.6965868132455, 50.9285238810948, 50.561332430158345, 51.80973611559187, 50.74622746876308, 51.70847306932722, 49.95273971557617, 51.45702818461827, 47.18035289219448, 48.711784499032156, 49.34156574521746, 44.53020920072283, 48.061356680733816, 50.12690673555647, 51.935668740953716, 55.73483255931309, 57.66713700975691, 53.06112405232021, 51.42193283353533, 46.372232232775005, 56.939872537340435, 55.13338259288243, 57.23900638307844, 50.992037364414756, 48.28306327547346, 50.13332339695522, 53.473628180367605, 55.92846495764596, 58.97100121634347, 54.3501330103193, 57.45088127681187, 53.668549469539094, 54.622043813977925, 57.59515714645386, 66.42729377746582, 61.199580328805105, 63.25386387961251, 58.042162554604666, 62.303266933986116, 47.09389993122646, 2.326666831970215, 0.68379893047469, 1.0361020203147615, 1.7185602741582053, 28.96514654159546, 69.34893485477993, 59.773559842790874, 64.20086860656738, 73.48641341073173, 54.11098991121565, 30.201588903154644, 54.02785471507481, 47.050821099962505, 40.20612634931292, 38.175279072352815, 66.44652639116559, 63.055687359401155, 2.388736827032907, 0.5000592470169067, 0.1737887638487986, 0.1291922533086368, 0.2000889711614166, 0.1359964803393398, 0.1631001816796405], [0.0754950682499579, 0.03066798811778426, 0.15844092597918852, 0.053808827817972214, 0.037508218216576746, 0.026068804818870764, 0.04015939024143985, 0.17446974159351417, 0.031807306089571545, 0.3428117148578167, 6.609831307615552, 59.79858030591692, 40.8831900869097, 33.21462658473423, 29.64377362387521, 40.64673246656145, 37.68361759185791, 19.028201171330043, 46.15798800332205, 59.38298075539725, 53.916621003832134, 55.73827191761562, 51.26379878180367, 45.576104164123535, 0.6374332755804062, 0.2511337899735996, 0.5725631022027561, 1.637642639023917, 0.20560852784131253, 4.257424005440303, 51.6464603969029, 57.941146169389995, 57.4294877733503, 53.60998657771519, 55.703433649880544, 56.18088606425694, 57.795977456229075, 52.38777412687029, 42.76875747953142, 24.88697259766715, 25.369997467313492, 47.309130804879324, 52.85779891695295, 46.442805085863384, 41.360208238874165, 48.13196080071585, 52.88386508396694, 52.3937599999564, 53.349852970668245, 52.185918535505024, 48.70591674532209, 51.54538147790091, 54.89247465133667, 52.54116950716291, 50.8638847896031, 48.66867440087454, 44.66750907897949, 47.39333602360317, 44.12492077691214, 47.01653868811471, 48.43452705655779, 48.03724295752389, 47.02954918997628, 48.86245618547712, 48.727595124925884, 47.015989780426025, 48.204381874629426, 48.624650614602224, 48.32066345214844, 45.87008592060634, 45.74528237751552, 40.18246078491211, 40.60759326389858, 39.41920811789376, 39.66079350880214, 39.69694151197161, 42.202590465545654, 41.05628708430699, 39.55279070990426, 36.74631602423531, 40.577174050467356, 45.078418595450266, 51.22325604302542, 51.9019387108939, 55.726758752550396, 54.2669734954834, 54.109426566532676, 47.397807189396445, 48.03442546299526, 44.37534775052752, 48.74893651689802, 49.53745283399309, 52.39420468466622, 56.004398345947266, 55.36068248748779, 56.18152182442801, 47.512407302856445, 39.573103768484934, 39.42052132742745, 39.02967126028878, 35.633704457964214, 36.94140407017299, 38.9458794593811, 36.80232892717634, 38.05833741596767, 35.57923058101109, 39.20967476708548, 37.863888604300364, 41.155990259987966, 42.67005137034825, 47.13330316543579, 44.89760562351772, 47.07212775094168, 46.42652893066406, 45.18188074656895, 47.44040659495762, 47.866407598767964, 46.11094175066267, 46.77599205289568, 45.795431000845774, 43.57476241247994, 45.99307598386492, 44.90902498790196, 42.5903068951198, 42.605478286743164, 46.59751714978899, 48.8779993057251, 49.21445540019444, 52.46040712084089, 47.956935678209575, 48.33087730407715, 43.273245334625244, 40.58498729978289, 52.99600553512573, 45.676443099975586, 42.49370609010969, 40.49425424848284, 44.734250000544954, 47.956591742379324, 51.11916855403355, 50.94339997427804, 51.02129970278059, 47.9980377469744, 42.79688378742763, 42.16334703990391, 43.783864974975586, 49.14632831301008, 53.94788442339216, 56.94208901269095, 51.79571117673601, 54.32094710213797, 21.16746292795454, 0.13056140126926558, 0.015591774601489305, 0.00024230339736927168, 0.4669093372566359, 48.08053370884487, 55.1818254334586, 52.57839100701468, 55.095084122249055, 55.94721119744437, 54.63461657932827, 13.558679989406041, 14.539677909442357, 30.53755862372262, 32.96672875540597, 32.811721393040244, 52.87396042687552, 28.453154632023402, 0.11934578738042287, 0.01949936617165804, 0.03253107903791325, 0.04293828969821334, 0.1101471052638122, 0.021518781382058347, 0.03164322614403708, 0.016986206473250474, 0.01821614958212844, 0.09012062594826732, 0.0470621405568506, 0.06532118881919555, 0.011954417236016264, 0.05460576380469969, 0.15455904070820126, 0.1680875497737101, 0.356294504233769, 8.178182601928711, 71.00252968924386, 46.965858527592246, 35.405699321201865, 34.2202011517116, 43.93358128411429, 37.79129729952131, 19.178129400525773, 52.23825931549072, 68.5231831414359, 56.678314549582346, 60.68860285622733, 54.45059353964669, 49.45692321232387, 0.595314761357648, 0.09256128926894494, 0.9189191311597824, 1.7329321886811937, 0.1490349785557815, 5.358488099915641, 57.80828966413225, 60.26558262961251, 60.38407026018415, 55.44265733446394, 57.82150166375296, 56.525853702000205, 59.29826831817627, 53.21056938171387, 44.94896323340279, 26.17602150780814, 25.64896069254194, 49.06266505377633, 51.845408167157856, 47.678927830287385, 41.13988780975342, 47.87989057813372, 54.50487634113857, 54.99971662248884, 53.92560155051095, 54.850253922598704, 50.946999141148154, 51.83135543550764, 57.66859613146101, 55.37432874952044, 53.26571723393032, 49.21337148121425, 46.77602331978934, 49.074883460998535, 46.781071186065674, 49.21471248354231, 51.0647155216762, 52.45295517785208, 48.839228357587544, 51.38818890707833, 51.71336807523455, 51.109062399183, 49.961556979588096, 49.97642959867205, 50.015666076115195, 48.64036396571568, 48.867816720690044, 43.49238109588623, 43.92815126691546, 42.92418868201119, 43.58805431638445, 43.88421433312552, 45.02516412734985, 44.98780713762556, 43.449541977473665, 40.974736077444895, 43.922474588666645, 46.72342545645577, 54.78727545057024, 55.32861655099051, 58.77307483128139, 56.94434717723301, 57.141606535230366, 48.257188183920725, 49.65406097684588, 43.91864613124302, 49.494672775268555, 50.92824942725045, 55.864621434892925, 56.305679185049875, 57.0324364389692, 56.11088296345302, 48.34724725995745, 41.2386599268232, 42.75504520961216, 42.46416582380022, 40.480041708265034, 40.7174824987139, 44.3792074748448, 40.70186989648001, 40.86423192705427, 39.36804158346993, 43.0589142526899, 42.92389338357108, 45.45816544124058, 45.68107407433646, 49.55223512649536, 46.86927856717791, 47.60844530378069, 48.019868986947195, 46.897547313145225, 51.26764113562447, 51.273484570639475, 48.9882116317749, 49.97701672145298, 49.309972286224365, 46.13897773197719, 48.913070338112966, 47.38856955936977, 45.07569490160261, 45.36698770523071, 48.684120246342246, 52.42979335784912, 50.89082990373884, 52.420107569013325, 50.10358510698591, 50.30785519736153, 46.67557668685913, 47.28194597789219, 55.092537607465474, 49.559502942221506, 43.397569452013286, 44.155975750514436, 46.54154941013881, 51.52603074482509, 53.18683780942644, 54.94268233435494, 54.821700300489155, 50.206953457423616, 42.60007953643799, 42.52043581008911, 46.20989799499512, 53.08715200424194, 56.6266199520656, 59.370981216430664, 54.287620067596436, 57.81986883708409, 23.124848638262065, 0.10506904417915003, 0.5114285083753722, 0.2388895441378866, 0.7264487104756492, 54.69397851399013, 60.81037698473249, 59.65240410396031, 59.57895469665527, 61.381769044058665, 58.882634026663645, 23.416157075337, 20.95549075944083, 38.869209562029155, 41.920945235661094, 33.807624067579, 60.67854186466762, 36.31120940617153, 0.30382431404931204, 0.058481216563710144, 0.023355755489319563, 0.019425636556531702, 0.06247700750827789, 0.09333843578185354, 0.035944639439029355, 0.15382901845233782, 0.07241829191999775, 0.1936800314911774, 0.13564000518194266, 0.08446542333279337, 0.13778614359242575, 0.20569804018097265, 0.291069647031171, 0.316248887351581, 0.40198224836162155, 10.939996872629438, 86.19722557067871, 56.04340205873762, 48.88446807861328, 42.78880998066494, 58.81819643293108, 46.553691387176514, 31.7928375516619, 57.23769317354475, 72.36873313358852, 63.5533173424857, 67.78829302106584, 59.33924879346575, 55.58878142493111, 0.5873522886208126, 0.6922747013824326, 2.160309370074953, 3.9320685267448425, 0.25774076687438147, 7.55741924898965, 64.50480365753174, 61.41790662493025, 64.4507258278983, 58.57207039424351, 61.155334200177876, 58.85092939649309, 60.72611618041992, 53.74783536366054, 47.878507886614116, 31.412298611232213, 28.46144904409136, 50.87912566321236, 52.949365752083914, 49.473251479012625, 42.200009209769114, 47.67180592673165, 55.66231073651995, 55.422313008989605, 56.89583485467093, 56.02510397774832, 53.12575966971261, 53.86442266191755, 58.360192026410786, 56.098897320883616, 55.615667479378835, 51.824525356292725, 49.30658851351057, 50.061784744262695, 48.99133832114083, 51.922814573560444, 54.50703028270176, 56.55672107424055, 52.360954080309185, 55.6628110068185, 55.49108280454363, 53.35335833685738, 53.34893233435494, 54.067501136234824, 54.43630109514509, 54.29700013569423, 53.43588209152222, 48.9601582799639, 46.79046515056065, 48.01514073780605, 49.2854277747018, 47.909343991960796, 48.319659437452046, 49.77974346705845, 48.5175267628261, 44.59131860733032, 48.53339992250715, 51.03930595942906, 56.713462012154714, 57.32282597678048, 62.29752772194998, 60.240027155194966, 59.56703158787319, 50.734745570591514, 51.17722075326102, 44.718310832977295, 52.82626451764788, 51.02277272088187, 56.21424436569214, 59.28350339617048, 57.74058294296265, 60.661727224077495, 52.727801595415386, 45.09392697470528, 45.64913320541382, 45.3958991595677, 44.08121313367571, 46.59224346705845, 50.53268848146711, 47.21108824866158, 48.02837358202253, 44.43031842367989, 47.773273944854736, 46.26213455200195, 49.27926124845232, 49.34390033994402, 52.694985253470286, 51.32251800809588, 51.72451993397304, 51.40558024815151, 50.09462887900216, 55.047304834638325, 53.854775088174, 51.23933070046561, 54.178404808044434, 51.39770793914795, 47.42935201099941, 50.45330878666469, 48.662827491760254, 47.00977461678641, 44.94486379623413, 50.27437877655029, 54.05267368044172, 54.2127810205732, 54.934813499450684, 51.99580887385777, 51.328469140189036, 47.44206026622227, 44.48913492475237, 58.605081285749165, 51.31161975860596, 45.98072208677019, 45.44493954522269, 49.78978361402239, 52.56970228467669, 57.133251326424734, 55.8198298726763, 57.47968850816999, 51.53614732197353, 45.11179426738194, 43.719816480364116, 50.02035958426339, 59.16495323181152, 60.18401772635323, 63.01292814527239, 58.77371406555176, 62.06927245003836, 28.73809504508972, 0.16358603989439352, 1.0576499040637697, 0.5628966923270906, 0.6751979291439056, 57.29610667909895, 65.63038403647286, 63.93720531463623, 66.12928553989956, 67.61802046639579, 65.6914587020874, 23.038452999932424, 20.35181736946106, 44.27896581377302, 44.95540073939732, 47.81094707761492, 64.97735064370292, 53.2771053314209, 0.5535235181450844, 0.12406605694975172, 0.1337456168340785, 0.1415131871721574, 0.22112082902874264, 0.16760824620723724, 0.08900119244520154], [0.018657984444871545, 0.04762287171823638, 0.030558221507817507, 0.04834718410191791, 0.0391479252305414, 0.039336133881339004, 0.07136180611061198, 0.036651744174637964, 0.06525520807398216, 0.19301731990916388, 1.2618676658187593, 43.14770180838448, 45.86402709143502, 30.095093863351003, 27.788420472826274, 46.66213192258562, 76.86349500928605, 15.480939081736974, 25.670472315379552, 66.00928320203508, 48.0350021634783, 61.39804867335728, 44.718626976013184, 60.714714186532156, 12.34155101435525, 0.06788973563483783, 0.5207361632159778, 0.7374306097626686, 0.015104213263839483, 1.6301298992974418, 44.90175717217581, 58.51540783473423, 56.91966370173863, 55.114945547921316, 54.82943364552089, 56.36256061281477, 53.16739674976894, 50.733091899326865, 51.542563983372276, 42.32363850729806, 47.071571895054404, 57.76288666043963, 50.70545196533203, 51.485446316855295, 25.331191778182983, 39.546707562037874, 52.555225712912424, 51.773522104535786, 52.847150802612305, 52.7045772416251, 52.40996667316982, 54.14023835318429, 50.922774246760774, 50.02578960146223, 54.40666355405535, 49.192346232278005, 43.63086911610195, 47.24387679781233, 45.977345262254985, 45.151194027491975, 51.783183574676514, 46.312317916325156, 49.10793604169573, 46.40711913790022, 49.971683979034424, 49.31165722438267, 48.18097339357649, 48.273050921303884, 47.642328194209504, 46.96196058818272, 46.52355357578823, 43.58661951337542, 40.896700859069824, 40.97165107727051, 40.347501346043174, 41.48400429316929, 40.10142394474575, 37.56358398709978, 36.856354645320344, 37.48244639805385, 39.16057184764317, 46.053751128060476, 50.33635670798165, 54.95809343882969, 52.65343502589634, 53.35064853940691, 49.23494216373989, 49.95326083047049, 49.551064355032786, 41.36581196103777, 49.771555015019004, 48.15401438304356, 51.77627011707851, 54.01828704561506, 52.730125767844065, 54.45985548836844, 51.725951262882774, 42.796432154519216, 40.4570813860212, 40.71580798285348, 36.332144328526084, 38.672436577933176, 40.93456506729126, 41.73211056845528, 39.98503814424787, 42.78652054922921, 38.35585927963257, 41.01466737474714, 43.479634625571116, 44.98640360151018, 47.19561461039952, 46.9696626663208, 46.49709136145455, 48.98683588845389, 43.53986855915615, 43.69056803839547, 44.209139892033164, 44.39443792615618, 46.90296343394688, 45.52629600252424, 42.25571639197213, 46.99939053399222, 44.1134215082441, 44.10527127129691, 44.830673626491, 44.62724426814488, 46.627679279872346, 49.58070537022182, 52.19942235946655, 49.6601927621024, 49.045315401894705, 44.772541522979736, 38.273200035095215, 51.46448360170637, 48.8732328414917, 41.09045485087803, 40.92474378858294, 47.7872884614127, 53.516891138894216, 51.96942656380789, 52.423922130039756, 53.94842638288225, 51.93359817777361, 52.101195675986155, 50.12991530554635, 50.110581942967, 53.39578403745379, 55.673997606549946, 54.73828370230538, 59.085187911987305, 49.780973298209055, 3.480932197400502, 0.1192930516387735, 0.43484581634402275, 0.18365046967353138, 5.872628739901951, 55.18609857559204, 42.27783250808716, 58.558431080409456, 51.69420146942139, 65.00646359579903, 39.47462347575596, 7.021470384938376, 38.621968337467735, 27.83734621320452, 23.344675745282853, 43.713219165802, 44.59820079803467, 20.911946398871287, 0.1261539092021329, 0.10068417446953909, 0.08668642451188394, 0.030001008550503423, 0.032004111779055426, 0.06656936755669968, 0.04381200870765107, 0.08402289636433125, 0.028670343703457286, 0.030217257660946677, 0.06458465941250324, 0.0470349821927292, 0.04459507204592228, 0.0838530319077628, 0.028045692846977284, 0.019963104144803116, 0.17372176530105726, 1.3104108210120882, 50.46320302145821, 53.79265819277082, 36.37954146521432, 38.18067782265799, 53.202412196568076, 75.68863800593785, 21.19173993383135, 28.92630958557129, 76.10792704990932, 55.66063274656023, 67.07143347603935, 49.182340826307026, 67.09821878160749, 13.041984149387904, 0.08485283290169068, 0.8271857563938413, 1.6939520346266883, 0.05671996696453009, 2.3029682636260986, 50.29809645244053, 59.437364305768696, 61.517738342285156, 56.499547822134836, 55.90431301934378, 58.014842237745015, 56.16602039337158, 52.8731301171439, 55.44659696306501, 43.787182739802766, 49.4907922063555, 56.82369518280029, 50.97246081488473, 50.80271632330758, 26.007656233651296, 39.47072901044573, 55.2839743750436, 52.65445988518851, 55.38195092337472, 56.09718458993094, 53.987760135105674, 56.85291583197457, 52.203514848436626, 52.64374228886196, 56.244159834725515, 52.70257616043091, 45.751629556928364, 49.398672989436555, 45.85802732195173, 47.871920994349885, 53.132259709494456, 50.637144224984304, 51.61845915658133, 50.05974544797625, 55.40374394825527, 51.90508277075631, 49.74022906167166, 50.579015595572336, 50.46430778503418, 50.20619262967791, 49.77479634966169, 46.83083765847342, 44.67579827989851, 44.95789861679077, 45.574533871241975, 46.01301383972168, 44.35205044065203, 42.22187519073486, 41.33559077126639, 40.59960630961827, 43.052796363830566, 47.77357619149344, 51.58659471784319, 55.47192662102835, 53.92924240657261, 57.09962551934378, 50.278196811676025, 52.69630193710327, 51.77814960479736, 41.15066793986729, 51.48721810749599, 50.36851991925921, 53.188512325286865, 54.486244746616904, 52.897907393319265, 56.79722254616873, 52.251266343253, 43.552093914576936, 43.83133506774902, 42.45614760262625, 40.29974985122681, 42.49921253749302, 44.19361066818237, 45.402927262442454, 44.77147497449602, 47.36767980030605, 41.60364185060774, 44.410727977752686, 44.584467683519634, 46.07958453042166, 48.64817026683262, 48.10698202678135, 49.95080464226859, 50.97050142288208, 46.95578016553606, 46.985796383449006, 47.97642190115792, 48.204364504132954, 49.16177068437849, 48.15693957465035, 45.91669791085379, 49.36693361827305, 44.26154667990548, 45.37988008771624, 46.958132130759104, 48.05866425377982, 48.91779163905552, 53.78771454947335, 52.57317985807146, 52.49912943158831, 50.35882370812552, 46.9888779095241, 45.029496329171316, 51.39514752796718, 51.440307344709126, 43.8892309325082, 44.97151361192976, 49.54767710821969, 54.899492331913535, 54.9329583304269, 55.9612535067967, 55.611328329358784, 55.88858577183315, 54.59960113252912, 53.908074719565256, 54.58248771939959, 56.96601513453892, 58.16350589479719, 58.192389556339805, 60.79354844774519, 54.03998279571533, 3.7253800289971486, 0.2623986383633954, 1.3564105012587138, 0.17790760711899825, 7.733392800603594, 63.24294825962612, 48.09083093915667, 62.955480439322336, 56.99840416227068, 73.56094673701695, 50.57252597808838, 12.615222317831856, 37.07040779931204, 36.73686647415161, 29.484948226383754, 42.08548205239432, 54.94880369731358, 23.772835901805333, 0.15137025181736263, 0.10709614719131164, 0.12291524798742362, 0.03342184963236962, 0.03511993779933878, 0.051613420979785066, 0.016604491509497166, 0.13524500280618668, 0.16825733280607633, 0.14299140285168374, 0.1530346575060061, 0.18555282402251447, 0.07656779140233994, 0.2082634860915797, 0.13909062716577733, 0.15484079558934483, 0.26163287088274956, 2.0643037217003957, 66.0073516028268, 59.86966732570103, 46.74236624581473, 40.214092458997456, 64.58930764879499, 77.5533538545881, 25.570675339017594, 35.91205971581595, 79.21611336299351, 57.36443526404244, 74.04993316105434, 53.63590683255877, 74.53215203966413, 14.550436326435634, 0.1373271146523101, 2.388173154422215, 2.9025899853025163, 0.18818517348596028, 4.060438667024885, 59.348969323294504, 60.75399930136544, 63.85423687526158, 59.16369560786656, 57.62092454092843, 58.39416176932198, 56.726041725703645, 53.17387594495501, 54.27571085521153, 44.11515508379255, 50.12722635269165, 57.34750597817557, 55.0236496925354, 50.16342646735055, 27.47218884740557, 40.69948666436331, 54.368476254599436, 55.372946058000835, 56.01223243985857, 57.69837611062186, 54.25179515566145, 57.16377476283482, 51.82536261422293, 53.651734828948975, 58.50565256391253, 53.95944969994681, 47.46828624180385, 52.45248964854649, 49.560472215924946, 49.155395712171284, 55.88579607009888, 52.72042955671038, 54.84440006528582, 53.43384279523577, 58.62862178257534, 56.687145709991455, 52.54747152328491, 53.621048109872, 53.86074359076363, 53.85995497022356, 53.71949018750872, 50.59708091190883, 47.10023668834141, 51.56882469994681, 48.94922181538173, 50.41144936425345, 48.51139497756958, 45.73661797387259, 45.21009043284825, 45.18142563956124, 47.008888721466064, 51.643375396728516, 54.85068471091134, 60.68075139181954, 56.639175346919465, 58.23608677727835, 53.67005722863333, 56.075193541390554, 53.826044287000386, 42.322558062417166, 55.479382038116455, 52.035319805145264, 56.41584982190813, 57.33665289197649, 56.1793783051627, 57.17245306287493, 53.93161521639143, 47.20026295525687, 46.84982361112322, 45.613242285592214, 42.960809162684846, 46.60090439660208, 48.0828856740679, 48.33022764750889, 48.886486530303955, 51.214633328574045, 47.248358385903494, 47.82779993329729, 48.767960684640066, 50.97605650765555, 53.49373279299055, 54.02208423614502, 54.15208503178188, 55.986749921526226, 50.27822460447039, 49.7283650125776, 52.25577572413853, 50.15484544209072, 52.320814337049214, 50.40400436946324, 47.65373713629586, 52.11275747844151, 48.48953594480242, 47.89163998195103, 49.822023255484446, 49.443846702575684, 50.46691335950579, 54.95566504342215, 55.49664831161499, 56.01385484422956, 52.475846018110005, 46.169831207820344, 41.944631644657676, 55.038918358939036, 52.8917304447719, 46.878641264779226, 45.538305963788716, 51.433282715933665, 57.9052483013698, 56.618004185812815, 56.43060779571533, 56.586205754961284, 56.08742584500994, 55.37620823723929, 56.26174225125994, 56.39127056939261, 58.07889420645577, 60.829602650233674, 60.55399540492466, 63.639356885637554, 56.800071307591026, 6.963888491903033, 0.295354459966932, 2.336212136915752, 0.2966866413397448, 8.012807658740453, 68.22886439732143, 52.91134173529488, 66.58039038521903, 60.68354456765311, 73.953506061009, 51.45863669259207, 12.98652275971004, 52.81212493351528, 40.80066285814558, 35.85097115380423, 58.463664599827354, 61.94528184618269, 39.431252820151194, 0.2994431491409029, 0.2086068248110158, 0.33459384153996197, 0.23463887508426393, 0.16368430533579417, 0.24780793700899395, 0.09892772550561599], [0.0507781749059047, 0.02767417287187917, 0.07879940486912217, 0.02232078432903758, 0.03831163760540741, 0.03472988194386874, 0.06246038340032101, 0.08139233823333468, 0.05001482979527541, 0.027746414798977118, 0.32097881925957544, 26.006490673337662, 51.798636368342805, 29.701533998761857, 28.95209608759199, 29.357636383601598, 42.28696938923427, 29.804158891950333, 14.01488481249128, 60.004858425685335, 43.57666621889387, 60.46614238194057, 48.47876623698643, 54.85676785877773, 42.59529570170811, 0.3100787784372057, 0.31944104177611216, 0.7366980633565358, 0.0962605264836124, 0.7635222896933556, 34.98567724227905, 63.103914805821006, 55.84243583679199, 58.41299833570208, 54.82206160681588, 53.640767097473145, 51.03945187159947, 52.547440256391255, 49.045905998774934, 42.72179460525513, 47.18405975614275, 54.442505836486816, 52.2392007963998, 42.66838032858712, 24.434629235948833, 32.69961568287441, 45.29191936765398, 55.901512895311626, 49.5170772416251, 52.30190828868321, 45.85441425868443, 53.18755347388131, 44.98178652354649, 47.97842993055071, 54.16954238074166, 50.59654590061733, 47.0831823348999, 46.81313712256295, 48.43732370649065, 43.245918069567, 48.36861297062465, 51.821377822331016, 46.80013356889997, 45.94199630192348, 49.29330355780465, 50.07929767881121, 47.6388714654105, 47.18999351773943, 46.59646449770246, 51.029998847416465, 48.526945046016145, 45.44580112184797, 45.31814534323556, 40.720668247767854, 40.30018063953945, 38.540351322719026, 36.87016766411917, 37.55535731996809, 36.74807391847883, 36.59252112252371, 42.665444714682444, 46.06144973209926, 50.04596717017037, 49.64118249075753, 54.40430811473301, 55.208044460841585, 48.17145783560616, 50.83715854372297, 50.52415609359741, 43.14752115522112, 49.50511939185006, 50.790459700993125, 50.41644859313965, 50.390059334891184, 52.733450480869834, 54.91535159519741, 52.59875617708479, 44.9880815914699, 41.236054352351594, 39.039961542402, 38.64137813023159, 39.139292989458355, 37.1618287222726, 41.18813610076904, 39.79198244639805, 40.38137034007481, 40.930562904902864, 42.032477719443186, 44.342392444610596, 47.34428868974958, 47.32978432519095, 46.63308497837612, 44.616464138031006, 46.79527677808489, 44.18571056638445, 45.051678453172954, 45.02398293358939, 47.6158902985709, 46.63760130746024, 41.74536773136684, 43.722953592027935, 46.189845493861604, 41.59054102216448, 43.280113628932405, 44.96930061067854, 44.926259994506836, 44.845935344696045, 46.153874669756206, 49.21959011895316, 51.55254507064819, 51.99625008446829, 48.49598387309483, 40.55318886893136, 52.48076186861311, 46.147339888981406, 43.56074442182268, 40.137693541390554, 49.41421958378383, 51.33228022711617, 54.624923842293875, 52.15681947980608, 52.80581249509539, 52.773548534938264, 55.63759252003261, 55.25263105119978, 58.16901581627982, 57.182611329214915, 58.02333293642317, 53.74428483418056, 59.24014663696289, 30.971678597586497, 0.01848780786219452, 0.02717406881440963, 0.6101135558315686, 0.3875535268868719, 21.896090984344482, 61.592313357761924, 45.4980411529541, 63.806815419878276, 49.425093514578684, 59.39222880772182, 24.914273806980678, 18.54462913104466, 46.83678879056658, 29.57340226854597, 32.64499241965157, 36.192353521074565, 46.6460850579398, 7.791580489703587, 0.16750137694180012, 0.07505869559411492, 0.10060504371566431, 0.014724735769310167, 0.04419353198526161, 0.043829114575471194, 0.0899400067116533, 0.016284457075276544, 0.06035900794501815, 0.0770441840535828, 0.005973810429817864, 0.07545782346278429, 0.019002695501382862, 0.03777049235733492, 0.061011772203658304, 0.08770901071173803, 0.008628509140440395, 0.5166029621447835, 33.62256574630737, 62.01845332554409, 33.270041942596436, 38.057388986860005, 39.75141886302403, 51.912395749773296, 31.623569011688232, 18.150259801319667, 64.82359395708356, 48.15104055404663, 66.9402723312378, 52.89068126678467, 62.0029935836792, 47.85358122416905, 0.6239054586206163, 0.365363776151623, 2.0895152602876936, 0.02748844426657472, 0.979915629540171, 39.256835665021626, 64.26993370056152, 58.43692793164934, 60.32159205845424, 53.89628710065569, 57.482304504939485, 54.134276798793245, 52.43914910725185, 50.376166411808555, 47.413833209446494, 49.0905898639134, 55.993944781167166, 53.872152532849995, 43.048137596675325, 29.452097143445695, 35.29647363935198, 46.711297375815256, 55.43665756498064, 50.52092865535191, 53.09664324351719, 47.27820437295096, 52.4869179725647, 49.79609257834298, 51.88970293317522, 57.24507563454764, 51.91984074456351, 47.37181397846767, 47.34952763148716, 50.20182568686349, 45.74355922426496, 51.95134040287563, 54.009313447134836, 50.01414442062378, 51.29470436913626, 51.99575328826904, 51.9796438898359, 50.82702112197876, 51.63015644890921, 49.370675223214285, 52.129321983882356, 50.58003350666591, 50.13103396551949, 48.80126340048653, 44.78905391693115, 43.22972876685006, 41.123635973249165, 39.75201988220215, 39.931443214416504, 40.04285063062395, 40.53941059112549, 44.59980583190918, 46.12269115447998, 53.17289277485439, 52.62349871226719, 55.627611432756694, 54.61421666826521, 49.92408881868635, 54.215518610818044, 49.72024604252407, 43.544555119105745, 51.52668734959194, 51.37430988039289, 50.27186352866036, 52.723222732543945, 54.78709479740688, 55.85314301082066, 54.06532635007586, 48.15233291898455, 44.707909379686626, 41.434599127088276, 41.9844274520874, 41.71931546075003, 39.41163805552891, 44.60740368706839, 43.00115040370396, 44.17965521131243, 43.47558035169329, 44.890414237976074, 45.53817394801548, 50.82725388663155, 49.7317487852914, 49.29897328785488, 47.506928648267476, 49.391710894448416, 47.28049380438668, 48.48835127694266, 47.83814580099923, 48.746007851191926, 49.2476921081543, 44.37514625276838, 47.72335113797869, 48.95135143824986, 42.948743615831646, 44.60042769568307, 45.894352504185264, 47.632381847926546, 46.69482667105538, 49.916213035583496, 51.09401260103498, 53.031990255628315, 52.2362825529916, 50.930879320417134, 43.71304893493652, 54.48962157113211, 48.08584908076695, 45.57538849966866, 41.56068113871983, 51.49520853587559, 54.05574825831822, 56.40819985525948, 55.18130431856428, 55.8737131527492, 54.89546932492937, 58.91034344264439, 56.09301219667707, 59.30397973741804, 57.6912750516619, 60.586721420288086, 56.95392179489136, 60.8029146194458, 32.815925053187776, 0.1846061319644962, 0.11869256171797003, 1.3184903817517417, 0.36802211350628306, 26.22698654447283, 66.34838308606828, 49.91101925713675, 67.50063759940011, 56.5932651247297, 71.4832547051566, 30.257417678833008, 16.53129826273237, 44.67360264914376, 40.067120688302175, 32.288310119083945, 37.941750117710654, 53.842514991760254, 6.891875624656677, 0.1708960197865963, 0.052935390400567224, 0.05720780310886247, 0.02371118400645043, 0.052735968958586454, 0.007981099371266152, 0.0529680313276393, 0.1188679358788899, 0.2848082073032856, 0.11994084902107716, 0.09085750819316932, 0.12654095914747032, 0.16328282973596028, 0.17088292406073638, 0.24023958455239022, 0.166736328708274, 0.135271139975105, 0.7304371393152645, 47.97306592123849, 73.0462589263916, 44.35597617285592, 40.18740790230887, 43.682334423065186, 56.98699174608503, 38.4479854447501, 22.860471418925695, 70.18251023973737, 54.108724798474995, 69.20034762791225, 58.27078260694231, 65.11559895106724, 53.606679235185894, 0.8377567891563688, 1.1166415214538574, 3.4212858208588193, 0.1852952114173344, 2.0077794747693196, 46.984226090567454, 65.21490955352783, 60.815831320626394, 61.38607692718506, 58.006830964769634, 60.00940949576241, 54.73823159081595, 53.68601724079677, 53.45606313432966, 48.896870613098145, 53.0093287059239, 58.3301271711077, 53.557089941842214, 47.47789560045515, 31.96523972920009, 35.377034527914866, 48.180337633405415, 55.504336493355886, 52.372213636125835, 54.370199407849995, 50.79661233084542, 52.18095404761178, 50.67469229016985, 52.89557974679129, 59.67753573826381, 54.44893986838204, 49.81664882387434, 50.09680366516113, 51.97694451468331, 49.10028954914638, 54.2514442716326, 57.013103076389854, 52.66450350625174, 52.51560708454677, 54.568594796316965, 54.74133743558611, 55.02500111716134, 54.72506822858538, 52.96974829265049, 58.19289330073765, 55.90459442138672, 52.26413788114275, 53.928248814174104, 49.65509625843593, 47.81948641368321, 45.91534996032715, 43.32173681259155, 44.109506198338096, 42.99114499773298, 44.165355818612234, 49.50331286021641, 50.13600887571062, 57.54947274071829, 55.08003085000174, 61.04538590567452, 58.707699230739046, 51.077576637268066, 55.062934807368684, 52.23164463043213, 45.874487604413716, 53.51904855455671, 56.78143623897007, 52.641835008348735, 53.402850355420796, 56.020417417798726, 60.0192620413644, 56.72909893308367, 52.764873708997456, 48.726156847817556, 45.29946858542306, 44.76824753625052, 47.44278635297503, 42.993976388658794, 48.77776459285191, 48.57369947433472, 48.5964617729187, 48.50684043339321, 48.00744560786656, 50.34207854952131, 55.67750644683838, 52.06252895082746, 52.10700784410749, 49.94458600452968, 52.93862731116158, 51.820530142102925, 51.37735666547503, 49.52297626222883, 53.875744751521516, 52.307675293513704, 46.573525020054404, 50.8224526814052, 50.70134210586548, 44.94222000667027, 47.88207231249128, 48.66023928778512, 49.71719578334263, 47.82319327763149, 50.91712188720703, 54.00427600315639, 56.13254049846104, 56.514920711517334, 48.21973739351545, 44.38884810038975, 58.97863033839634, 50.79932907649449, 48.74554927008492, 43.30722202573504, 53.8760643686567, 56.086015360695974, 59.918422835213796, 58.28367498942784, 58.03162213734218, 56.74098382677351, 60.925105639866416, 59.89644568307059, 61.58167566571917, 61.59407820020403, 62.856135095868794, 59.22849450792585, 64.0021779196603, 36.260397229875835, 0.40511925145983696, 0.17940004489251546, 3.0609622299671173, 0.4718600373182978, 26.87856776373727, 70.21366596221924, 56.90256071090698, 73.89316790444511, 60.07258251735142, 69.23494270869664, 35.92688022341047, 27.43572470120021, 61.541584559849326, 39.54354960577828, 49.95153072902134, 47.68144307817732, 69.14733982086182, 15.447671106883458, 0.4931648426822254, 0.2824953799801213, 0.20813186386866228, 0.21081951393612794, 0.18199996038206986, 0.10925969002502305, 0.27398826075451715], [0.02102354072433497, 0.06327712921691792, 0.08194773271679878, 0.06011371075042656, 0.03109356188880546, 0.07023310381919146, 0.004526130098383874, 0.00468999715355624, 0.061618572500135214, 0.02995584186698709, 0.21398667113057204, 16.076382330485753, 47.66844994681222, 34.359456947871614, 35.61798415865217, 31.048647267477854, 48.66959503718785, 36.767799854278564, 14.554546185902186, 60.949382645743235, 51.38359614780971, 53.365555899483816, 55.37707328796387, 41.045576436179026, 58.74125902993338, 5.877678343227931, 0.1423648436154638, 1.0621726385184695, 0.43169431973780903, 0.22695058477776392, 23.720206771578106, 61.84069061279297, 59.31172003064837, 57.83679117475237, 55.443049907684326, 57.323545115334646, 53.565827301570344, 57.41808230536324, 55.0139673777989, 57.873811176845, 56.657938957214355, 48.872621400015696, 55.96690934044974, 55.532890115465435, 69.59358092716762, 44.29586730684553, 30.761950697217667, 43.84253208977835, 46.256965092250276, 48.24081127984183, 54.1084121295384, 54.30676930291312, 35.6724510874067, 52.24322032928467, 54.69600738797869, 52.250814710344585, 45.201617104666575, 46.001389503479004, 47.93180751800537, 43.07577058247158, 46.984844480242046, 50.32299879619053, 48.421794482639854, 47.39625079291207, 49.68338932309832, 48.31178365434919, 46.654415948050364, 46.202522482190815, 46.9030259677342, 49.3709705216544, 49.228198937007356, 48.20385033743722, 45.19336264474051, 43.98830877031599, 41.86199671881539, 36.73216601780483, 35.44858707700457, 36.66154452732631, 38.90384633200509, 37.57449960708618, 45.92790535518101, 46.200743743351524, 49.85905020577567, 50.52920395987374, 54.21928800855364, 52.87519720622471, 48.95043427603585, 53.06208290372576, 50.79702574866158, 47.89278990881783, 50.89883770261492, 51.77503681182861, 48.380181721278596, 46.86034318378994, 51.674597127096995, 52.39142887932913, 51.103979791913716, 46.92128930773054, 42.20075266701834, 37.511868544987266, 36.197644574301584, 35.9945695740836, 37.89558628627232, 42.270943369184224, 40.594777311597554, 40.9017904145377, 43.088579586574006, 42.090752261025564, 45.98123277936663, 46.24221406664167, 46.743109703063965, 46.62403494971139, 46.71367365973336, 45.49640137808663, 44.5494452885219, 44.656364168439595, 42.57508339200701, 46.61639887945992, 44.68342045375279, 40.84177882330758, 46.236144815172466, 46.82673822130476, 42.83473409925188, 44.301102774483816, 44.4189372743879, 43.754672118595664, 46.22393683024815, 47.81156546728951, 50.81942674091884, 49.323229449135916, 54.65144164221627, 47.97188820157732, 37.80073642730713, 51.287631102970664, 49.12451096943447, 43.64325775418963, 38.201015199933735, 46.36363731111799, 52.21135936464582, 52.476867403302876, 53.72811985015869, 51.07094458171299, 50.90127999441964, 53.62603344236101, 53.3415081841605, 54.01425014223371, 56.24277366910662, 55.714787006378174, 57.36753068651472, 56.607130255017964, 14.094056929860797, 0.2480241996901376, 0.4953862577676773, 1.2401829894099916, 1.7432349558387483, 41.23039157049996, 53.48236901419503, 52.47535964420864, 57.33883810043335, 48.027817726135254, 42.3132301058088, 31.150351524353027, 27.202593530927384, 45.717055320739746, 25.861348015921457, 29.309686865125382, 36.201202051980154, 33.80036320005144, 0.9838892391749791, 0.0592495489067265, 0.03834204954494323, 0.05317103543451854, 0.045405602481748374, 0.04051248968711921, 0.057629383701298914, 0.0481313692538866, 0.020635839385379637, 0.0306001956840711, 0.03708213893696666, 0.08782596979290247, 0.07658298380140748, 0.03789147175848484, 0.061358836080346785, 0.04814185601259981, 0.0496322412176856, 0.07413824927061796, 0.3000549434551171, 18.687808922358922, 60.857833181108745, 35.900275571005686, 36.381813526153564, 40.59854670933315, 51.76249531337193, 36.68243081229073, 15.90836272920881, 66.22190502711705, 52.9365359033857, 59.80227674756731, 59.34946264539446, 45.825367314474924, 64.62080383300781, 7.4975118807383945, 0.1733671221882105, 1.8657035785061973, 0.5435311400464603, 0.33431325373905046, 28.177629028047832, 65.86089052472795, 59.54538794926235, 60.44428334917341, 57.759395190647666, 60.890899658203125, 55.3323129926409, 59.40905039651053, 55.61319392068045, 61.87553582872663, 58.538149288722444, 50.32055650438581, 57.1645633833749, 54.12645312717983, 67.80635833740234, 52.67745494842529, 32.26578753335135, 46.46379906790597, 45.917799200330464, 49.74630526133946, 49.31373126166207, 56.201421465192524, 39.03403125490461, 54.35860981260027, 54.83742754799979, 53.642535414014546, 46.841902664729524, 49.26637928826468, 48.83498648234776, 45.01447779791695, 47.92508513586861, 51.19873932429722, 51.26961442402431, 50.61057778767177, 52.255567278180806, 53.38406242643084, 49.31021547317505, 49.89333609172276, 48.69331618717739, 51.734382901872905, 52.6922789301191, 50.27571630477905, 47.73232821055821, 46.60295411518642, 44.67788968767439, 38.61770561763218, 40.29046705790928, 40.2281173978533, 39.850218772888184, 41.3797778402056, 49.88188893454415, 49.25383084160941, 52.15946674346924, 51.22409330095564, 55.65342051642281, 52.63522727148873, 50.389201232365195, 53.76025179454258, 53.1067077091762, 47.700828552246094, 51.994700636182515, 53.61592033931187, 50.72086654390608, 48.15910741261074, 52.11573478153774, 54.36887230191912, 53.381957122257774, 49.06819234575544, 44.67453718185425, 40.419654914310996, 40.84431144169399, 38.79810864584786, 40.58993789127895, 44.61125993728638, 43.926184926714214, 43.49740811756679, 46.368890149252756, 45.37416866847447, 48.65957226072039, 50.77330459867205, 50.056528432028635, 49.46344757080078, 50.94802747453962, 47.54680783408028, 47.842061110905235, 47.94153847013201, 45.91464819226946, 49.19268669400896, 45.8528995513916, 43.58592816761562, 47.101671491350444, 47.12232501166207, 45.585647514888215, 44.59068284715925, 47.10013593946184, 46.218076024736675, 47.993858405521934, 48.230364663260325, 52.6786778313773, 51.00990465709141, 55.132309096200125, 47.38880927222115, 41.28910037449428, 55.887380259377615, 52.082279205322266, 45.94164194379534, 40.44434533800398, 48.05150066103254, 54.57227039337158, 54.98026861463274, 56.57651996612549, 54.28261736461094, 53.01625605991909, 56.18226180757795, 56.77705192565918, 56.78111662183489, 57.58040959494454, 59.736783027648926, 58.98951121738979, 59.87929058074951, 15.403207847050258, 0.29231223464012146, 0.4653075603502137, 1.3557111216442925, 3.417631068399974, 50.276265212467735, 55.95336382729666, 57.16346556799752, 62.40883091517857, 52.50724492754255, 44.842402185712544, 29.450492109571183, 27.759420428957256, 48.24284362792969, 33.85587930679321, 25.959515639713832, 42.90371928896223, 42.095563888549805, 0.9828212793384279, 0.10581220287297453, 0.07565419828253132, 0.11138621198811702, 0.04886586984087314, 0.0360000893207533, 0.03412130727831807, 0.058225171374423165, 0.18163530209234782, 0.15928241796791553, 0.2156965658068657, 0.10513260933969702, 0.20639615772025927, 0.1760224061352866, 0.18471013781215462, 0.2741021732134478, 0.23244378715753555, 0.21974651063127176, 0.36902428258742603, 29.71216126850673, 73.6340834753854, 47.77904094968523, 49.14186062131609, 44.21908276421683, 65.33078466142926, 45.23480864933559, 23.132988452911377, 71.78286797659737, 62.01316574641636, 61.74906471797398, 65.78396006992885, 48.30526276997158, 69.50770814078194, 8.895286202430725, 0.30936476960778236, 3.6177001042025427, 0.9834410803658622, 0.4617038880075727, 36.73641831534249, 63.1999180657523, 59.30860723767962, 63.65467766353062, 61.69589710235596, 62.78321375165667, 56.53917339869908, 61.13707433428083, 57.52330582482474, 61.53025899614607, 58.08149283272879, 53.834653105054585, 57.25740868704659, 59.69489928654262, 67.85640621185303, 44.43255574362618, 36.09123986107962, 48.061690194266184, 48.02452775410244, 51.14909791946411, 50.42347322191511, 54.200941290174214, 42.39150503703526, 54.256252425057546, 58.847003664289204, 55.261691502162385, 49.406024183545796, 51.18029533113752, 53.56658812931606, 48.50336285999843, 49.48038727896554, 55.59041077750069, 55.389479296548025, 54.20166737692696, 55.54996183940342, 55.98217453275408, 51.83395058768136, 52.397022179194856, 51.950221742902485, 56.779921531677246, 55.797050203595845, 54.19907569885254, 50.63494512013027, 49.58404745374407, 48.15774556568691, 43.030808789389475, 42.16579627990723, 43.91917419433594, 44.38933447429112, 45.54940571103777, 53.52140746797834, 53.09657028743199, 54.234459400177, 55.50691080093384, 59.24660151345389, 57.240920611790244, 53.25294297082083, 55.890732765197754, 53.26282330921718, 50.63482352665493, 53.42884704044887, 56.27778911590576, 51.237597124917166, 48.99312400817871, 55.96914666039603, 55.27863121032715, 57.46085888998849, 53.15092257090977, 47.929049083164756, 43.842149938855854, 42.81532430648804, 43.381894315992085, 44.06564916883196, 49.32942724227905, 46.99303988048008, 48.12053448813302, 49.4725010735648, 48.771757875170024, 53.11665752955845, 54.15329054423741, 51.91512291772025, 53.83434738431658, 52.33571127482823, 50.45627566746303, 51.826001848493306, 52.57996129989624, 49.081126417432515, 51.77373055049351, 48.36289807728359, 45.73223713466099, 49.17854363577706, 51.01857948303223, 47.98073673248291, 47.058908803122385, 47.66234595435006, 49.497820309230256, 51.52157000132969, 52.04131957462856, 54.63022531781878, 53.968784604753765, 58.37581852504185, 50.0872220993042, 40.01609311785017, 57.19619505746024, 53.1124712399074, 49.17305108479091, 43.65032754625593, 54.59621735981533, 57.2743900844029, 57.09296914509365, 58.28269876752581, 54.41655084065029, 53.65531662532261, 57.9094797543117, 59.74666336604527, 59.73738752092634, 59.811969484601704, 60.56320871625628, 59.399580001831055, 62.6371556690761, 18.74932653563363, 0.2607267823602472, 1.504219964146614, 3.263296595641545, 4.04106969492776, 49.443461077553884, 64.272796358381, 61.653096199035645, 67.06244945526123, 59.05763830457415, 53.67657463891165, 43.18039655685425, 37.63209669930594, 60.15819822038923, 37.431186062949045, 44.47641972133091, 49.26576784678868, 59.72522817339216, 4.2260437692914685, 0.39586582513792173, 0.14811926840671472, 0.23998336972934858, 0.128105457339968, 0.1883912988539253, 0.09580747543701104, 0.15969496725925378], [0.12870260886847973, 0.10018360561558179, 0.009222365533267813, 0.14304165515516484, 0.011377844826451369, 0.05670952431059309, 0.04514960139723761, 0.01517884193786553, 0.04510885876204286, 0.16815220059028693, 0.20565511605569295, 5.603911936283112, 49.48027958188738, 36.19028295789446, 39.21805082048689, 20.73275235721043, 49.608661447252544, 31.53407621383667, 19.605639900479996, 60.51786477225167, 49.854547773088726, 49.01996142523629, 56.41689205169678, 44.79319851739066, 57.96372086661202, 17.008670772824967, 0.23465893257941517, 1.1633169140134538, 0.4194848691778523, 0.1986481970442193, 12.613363674708776, 53.21811512538365, 52.338730267116, 58.91331727164132, 50.59427383967808, 57.34544236319405, 52.83952862875802, 57.29712111609322, 52.14670637675694, 63.7771327154977, 54.05511597224644, 58.6085067476545, 51.07758705956595, 67.05922549111503, 61.4440735408238, 53.78474766867501, 52.31776755196707, 38.57465805326189, 38.868917737688335, 46.34501961299351, 44.930894442967, 32.820924282073975, 44.525394099099294, 55.0269535609654, 53.23151125226702, 49.1719081061227, 46.20642736979893, 45.60222591672625, 48.226119313921245, 42.50826951435634, 42.87682281221662, 50.47445910317557, 48.188918658665244, 49.27502979551043, 48.37016936710903, 48.34225845336914, 48.0326258795602, 46.78790473937988, 48.63370064326695, 50.80531842367989, 50.56902756009783, 48.95751101630074, 46.556925773620605, 44.51177910396031, 42.00766222817557, 39.172248295375276, 37.57107761928013, 38.7361341885158, 41.601341996874126, 45.72080387387957, 48.97250175476074, 46.01963199887957, 48.39989028658186, 50.17178167615618, 48.780050550188335, 51.441617080143516, 51.73790911265782, 50.49590819222586, 51.817406926836284, 44.23278113773891, 50.04944474356515, 53.647128173283164, 48.94703313282558, 47.85258763177054, 51.87386104038784, 53.2992388180324, 51.41178151539394, 48.636587619781494, 42.25456646510533, 41.05288594109671, 38.380869320460725, 39.189337389809744, 37.86324937002999, 37.11209699085781, 40.36059175218855, 43.95863996233259, 45.860358442579, 48.30093056815011, 46.20523227964129, 46.92445421218872, 50.30913714000157, 46.7760580607823, 48.62061023712158, 45.97059856142317, 45.30211932318551, 44.117507049015586, 45.60929570879255, 47.5550206048148, 44.007683822086875, 39.67182724816458, 46.74367945534842, 43.28729806627546, 43.52610765184675, 45.03675372259957, 48.452418667929514, 46.81652089527675, 47.83879893166678, 45.605515888759065, 50.64923409053257, 51.93415750776018, 52.47187859671456, 43.34679896490914, 40.773655210222515, 52.84147065026419, 48.00484350749424, 47.587541648319785, 41.018169266836985, 41.255717754364014, 49.119490895952495, 51.00449548448835, 52.63496323994228, 55.147796630859375, 50.114632742745535, 52.47943128858294, 52.732234546116416, 54.49420738220215, 55.653173855372835, 55.75587865284511, 55.527984687260215, 48.702849115644185, 4.508467197418213, 0.2702896206506661, 1.0324154581342424, 0.6042899340391159, 9.764300874301366, 45.73437023162842, 52.234128611428396, 53.70926938738142, 52.99348333903721, 56.54080275126866, 67.07477555956159, 28.02204670224871, 33.30038125174386, 33.11523607798985, 23.074145896094187, 33.547518253326416, 39.39552170889718, 27.366826363972255, 0.13073098074112618, 0.023463744337537458, 0.04450026374044163, 0.0612809674016067, 0.06567440700850316, 0.0280804999970964, 0.01390999078284949, 0.09370741633964436, 0.11952178579355989, 0.04007789818570018, 0.05573873068871243, 0.0661069934389421, 0.029082268742578368, 0.049803795226450474, 0.07393286350582327, 0.09417397023311683, 0.07824061771056481, 0.1665384407554354, 0.24422766055379594, 9.03187997000558, 63.56635911124093, 41.14522055217198, 39.78016356059483, 34.02289663042341, 57.86062002182007, 32.72303458622524, 21.820558854511805, 66.09564236232212, 54.39394835063389, 53.30453681945801, 64.62962804521833, 48.08340678896223, 64.32961177825928, 18.283090250832693, 0.23717453330755234, 0.95136559009552, 1.1188105536358697, 0.22019423517797673, 16.76978302001953, 56.752479621342246, 54.79692302431379, 60.9158992767334, 54.788633823394775, 59.68869454520089, 54.5076139313834, 58.27900579997471, 53.9182642527989, 66.42518152509416, 56.06905133383614, 60.8713196345738, 52.01119218553816, 69.155031476702, 58.47592122214181, 57.12117535727364, 57.70168692725045, 40.58441059929984, 40.50627810614449, 46.06083829062325, 47.88822146824428, 37.7260502406529, 43.895050048828125, 55.34398249217442, 54.287171908787315, 51.57264273507254, 48.406824588775635, 46.447119917188374, 51.253536292484824, 44.894822869982036, 44.33568743297032, 53.54399258749825, 51.53099870681763, 50.58957685743059, 51.26659543173653, 51.675000122615266, 50.904253823416575, 50.778241293770925, 53.752466338021414, 53.413877146584646, 51.671543393816265, 50.83815908432007, 50.64075034005301, 46.971371923174175, 44.362080165318076, 41.69041442871094, 41.87632737840925, 42.34840883527483, 43.99246031897408, 48.321062973567415, 51.68054131099156, 49.20567635127476, 50.43719244003296, 52.997978823525564, 51.23796885354178, 53.58943033218384, 53.66454383305141, 53.0659704208374, 53.52639627456665, 45.670568398066926, 51.09175443649292, 54.56930003847395, 51.891662325177876, 49.22218874522618, 53.46278204236712, 54.909216335841585, 52.801924977983745, 52.306862354278564, 45.10009697505406, 42.83238213402884, 40.852934156145366, 40.80392851148333, 38.833801542009624, 40.220832211630686, 42.546439443315776, 45.17222622462681, 47.37446471623012, 50.9104585647583, 48.464192390441895, 48.91379989896502, 51.15337800979614, 48.15993077414376, 51.25454030718122, 49.412333147866384, 49.72081579480852, 47.3386675970895, 47.47636352266584, 50.95200531823294, 47.0020239012582, 41.84563718523298, 48.399105140141074, 44.913371086120605, 46.51940550122942, 47.13978236062186, 50.06013107299805, 48.512805461883545, 51.569206850869314, 47.077217306409565, 51.363213607243125, 52.66139071328299, 55.44605500357491, 44.85125766481672, 39.60219587598528, 55.21252952303205, 48.80741603033883, 50.680723326546804, 41.5527914592198, 43.130366052900044, 51.32136113303048, 52.42519365038191, 55.521314416612896, 56.33537231172834, 52.56124980109078, 55.06037787028721, 55.44518300465175, 57.77525097983224, 56.40824154445103, 58.31188120160784, 55.63708530153547, 52.615612506866455, 4.897590202944619, 0.26738679355808664, 2.6983526817389896, 0.5831589964883668, 14.694517646517072, 52.23426757540022, 54.535889625549316, 61.25514507293701, 59.284997258867534, 60.33314691271101, 63.41690335954939, 32.5089293207441, 37.687692710331504, 38.68507535117013, 26.867155347551616, 30.696408339909144, 46.30741943631853, 38.17792286191668, 0.037730967692498646, 0.023228348665205494, 0.03691741099048938, 0.02325759352450924, 0.015623769223956125, 0.06420617936445133, 0.01488698027761919, 0.050333181462649784, 0.22925985657743045, 0.13769672624766827, 0.1064691740487303, 0.20714409330061503, 0.091926689392754, 0.17497633583843708, 0.1130208774868931, 0.27155503417764393, 0.20401466265320778, 0.2944575995206833, 0.3765914679637977, 13.62238107408796, 79.43393938882011, 48.38172422136579, 56.818397181374685, 31.417878014700754, 67.37216540745327, 38.171745913369314, 28.539298398154124, 71.39078113010952, 60.92732906341553, 57.63075624193464, 68.9422081538609, 51.57333060673305, 69.41817365373883, 20.493494612830027, 0.22958275782210485, 3.0787893533706665, 1.4694819024630954, 0.20305938034185342, 22.859865188598633, 61.40591403416225, 53.560126304626465, 60.671683992658345, 56.14799329212734, 59.79154872894287, 57.12179722104754, 61.08121081760952, 58.74763052804129, 66.83865492684501, 57.33874429975237, 61.49294022151402, 57.1358117376055, 67.52456719534737, 59.182275090898784, 55.48172010694231, 50.683964661189485, 40.69600561686924, 40.075437682015554, 48.70040682383946, 49.09537717274257, 43.411590916769846, 47.49440452030727, 56.56116097314017, 56.30751698357718, 52.4368040902274, 50.374186175210134, 47.99341719491141, 53.94163451875959, 47.67763199125017, 47.103790691920686, 57.63079445702689, 52.893689836774556, 54.667405128479004, 54.75960424968174, 53.00198793411255, 54.23958369663784, 52.134296894073486, 53.3956172806876, 55.89912618909563, 56.58432626724243, 55.52750178745815, 56.10678700038365, 50.351128578186035, 49.02904966899327, 45.1525593485151, 45.05687917981829, 45.289529187338694, 47.22401884623936, 52.30221748352051, 54.928014687129426, 50.905025073460166, 54.927688121795654, 56.04094239643642, 54.499349049159456, 56.37388965061733, 55.9122930254255, 52.85513080869402, 56.60330179759434, 47.06312983376639, 52.92107268742153, 56.5319368498666, 52.78195585523333, 51.91046762466431, 54.04219232286726, 58.49098491668701, 56.812994956970215, 55.086551734379356, 48.32799727576119, 46.340006487710134, 45.13033206122262, 45.7350754737854, 41.843316486903596, 42.466705390385215, 45.994333607809885, 48.87302439553397, 50.10504770278931, 53.34693472726004, 51.2218907220023, 52.99376821517944, 56.53686312266758, 52.34483773367745, 54.27505077634539, 52.69002423967634, 51.354337283543174, 51.03969158445086, 50.651586055755615, 53.814183712005615, 48.75920942851475, 43.49603584834507, 51.294475078582764, 46.69060911451067, 49.732881341661724, 51.24227326256888, 52.15756293705532, 51.64364637647356, 51.82390349251883, 49.299320697784424, 53.94466393334525, 56.59306362697056, 57.007103306906565, 51.38207449231829, 47.68814461571829, 55.62133720942906, 53.49509116581508, 50.938560553959434, 47.567906039101736, 46.18371370860508, 54.25995234080723, 55.492131982530864, 57.973740168980186, 58.534515380859375, 51.905902658190044, 58.12886217662266, 56.322340965270996, 59.72439438956124, 61.84034320286342, 59.83400222233364, 56.509872845241, 53.70807777132307, 6.464193591049739, 0.4227533180798803, 3.637101863111768, 0.7931004453982625, 14.307088698659625, 56.89720712389265, 59.56922721862793, 64.6167321886335, 63.293906348092214, 66.92469446999687, 77.79202447618756, 38.74830743244716, 41.637896469661165, 46.14301463535854, 33.63909551075527, 50.391501086098806, 52.20711748940604, 53.0104022026062, 0.5157654870833669, 0.11795051582157612, 0.13011640443333558, 0.14109829014965466, 0.13346259987780026, 0.1451767605862447, 0.04951103789997952, 0.1504453814455441], [0.037749600264110734, 0.012483739011388804, 0.07423951383680105, 0.039424601277070384, 0.04896404368004628, 0.06993731683386223, 0.11045330097632748, 0.020642207436529652, 0.07906876291547503, 0.03158435983849423, 0.24839834389942034, 3.020548467125211, 52.31393562044416, 44.96693474905831, 30.756972312927246, 16.875499861580984, 41.1239139011928, 31.348281383514404, 15.798473494393484, 56.51103319440569, 61.20297104971749, 47.110804898398264, 50.3786677633013, 51.915946279253276, 54.55140495300293, 36.172707489558626, 0.12826276889869145, 0.3624692271862711, 0.17612145867730888, 0.43395340708749636, 7.662522912025452, 45.20379883902413, 46.04723719188145, 55.3782753263201, 59.09439427512032, 58.351145471845356, 54.188549177987234, 52.69777842930385, 54.67321729660034, 58.81567423684256, 53.11863776615688, 54.66459805624825, 57.785867827279226, 51.959181444985525, 50.474584170750205, 52.9722010067531, 59.15988104684012, 60.90710980551583, 52.095432145254954, 48.941769872392925, 43.20087289810181, 41.87251629148211, 51.54163987295968, 54.28301688602993, 51.136118684496196, 50.73994629723685, 46.47446455274309, 46.26481308255877, 47.922413553510395, 43.25678505216326, 41.16143069948469, 47.33829239436558, 47.62520783288138, 49.402445861271445, 49.193530900137766, 46.059393065316335, 50.04312883104597, 49.63870198386056, 48.64971971511841, 47.270029817308696, 48.25041716439383, 50.08151068006243, 44.947893210819785, 45.21876873288836, 41.40126861844744, 39.206565448216026, 38.84984145845686, 40.46258783340454, 43.84868124553135, 47.891344683510916, 49.96879005432129, 48.82789584568569, 48.240234579358784, 50.08771889550345, 53.25381844384329, 51.568883759634836, 48.756537846156526, 50.31420585087368, 52.418193340301514, 45.4939660344805, 48.98438664845058, 54.45718738010952, 51.002122674669536, 51.72118132455008, 53.4048410143171, 51.54667384283883, 49.83376918520246, 48.620853424072266, 45.11652946472168, 42.23669222423008, 38.948214054107666, 40.24691227504185, 37.22363642283848, 38.84679467337472, 40.998967920030864, 44.604172774723594, 47.74040896551949, 48.465384006500244, 48.012434414454866, 49.53126546314785, 48.96232959202358, 47.18537991387503, 47.37743159702846, 45.28634343828474, 46.880235876355854, 44.83595425742013, 46.55865240097046, 45.74300684247698, 41.93087421144758, 40.991130352020264, 45.857815401894705, 40.057928221566335, 44.695680550166536, 50.25511142185756, 49.020044803619385, 49.11565201623099, 48.85262448447091, 48.70642396381923, 53.39120170048305, 48.82502623966762, 57.4553142275129, 19.462698084967478, 19.461701018469675, 54.96541684014456, 53.626148087637766, 50.82363734926496, 45.392671721322195, 41.14142683574131, 39.47558232716152, 51.45583309446062, 51.96921811785017, 54.04924821853638, 55.2947336605617, 50.776149885995046, 49.03186021532331, 51.6835081917899, 49.929768971034456, 54.825094495500835, 52.90106534957886, 39.14392743791853, 0.8070705586246082, 2.1284299492836, 2.4407473504543304, 0.27321768924593925, 34.29016951152256, 56.88299458367484, 52.20832995006016, 47.62700046811785, 56.49737303597586, 55.54914542606899, 58.47413553510393, 28.118105547768728, 20.189215626035416, 30.607353278568812, 40.63673053468977, 35.344437054225374, 45.26034327915737, 27.679239954267228, 0.08381693384477071, 0.047974234114267995, 0.019875842845067382, 0.03368648507499269, 0.06265637145510741, 0.025260712020099163, 0.0319018599444202, 0.0009268506338620292, 0.04108268301934004, 0.049501463770866394, 0.10410032008907624, 0.02877156755753926, 0.007785568479448557, 0.023270192223467996, 0.027958007462854897, 0.07610157677637679, 0.049793379713914225, 0.0835409736526864, 0.19624612879540237, 4.013766748564584, 64.06421838487897, 51.08821085521153, 34.42683015550886, 25.694447074617656, 49.108179228646414, 37.34818288258144, 21.262892961502075, 63.32262325286865, 66.36301599230084, 49.701367786952424, 55.680883271353586, 56.697786876133506, 58.98785754612514, 38.031955105917795, 0.23647653790456907, 1.7958530123744691, 0.7189002526657922, 0.5174611189535686, 10.616751040731158, 51.81827197756086, 48.08331298828125, 59.37334360395159, 58.273391655513215, 60.62383869716099, 57.19255072729928, 54.86460542678833, 57.5010472706386, 57.78901883534023, 56.56097337177822, 57.25355243682861, 58.942874908447266, 54.118268149239675, 55.27592141287667, 55.61881501334054, 58.774714606148855, 62.00316728864397, 53.58340276990618, 50.75159842627389, 45.50098371505737, 43.72069542748587, 52.846129417419434, 54.72611740657261, 52.7196478843689, 53.29831123352051, 47.73778602055141, 47.62798363821847, 49.07391766139439, 45.371945244925364, 43.06656421933855, 50.456216607775005, 49.135509967803955, 50.537680762154714, 52.76313665934971, 49.7126864024571, 50.990140506199424, 51.96359007699149, 52.93040759222848, 49.638392789023264, 52.78750399180821, 52.237901483263286, 48.45437111173357, 50.11587994439261, 45.00946814673287, 42.15340764181954, 42.84230416161673, 42.654376234327046, 46.47580208097185, 50.20210708890642, 51.34813601630074, 50.974868365696494, 51.17935037612915, 51.85403088160923, 53.792529651096885, 52.16237803867885, 52.59495898655483, 52.83855588095528, 54.047667503356934, 45.16753966467721, 49.34715209688459, 53.66194520677839, 52.432343346732004, 51.96746022360665, 55.79595586231777, 53.40176296234131, 53.80932344709124, 50.60213572638375, 49.442714146205354, 44.05431318283081, 40.66614920752389, 41.86917073386056, 40.29718944004604, 41.34110069274902, 44.75578594207764, 45.0962233543396, 50.225869928087505, 52.328832558223176, 49.87535067967006, 49.93151296888079, 51.72291490009853, 50.380470820835654, 49.464812891823904, 48.113655771527974, 49.29820898600987, 48.25639608928135, 48.04782853807722, 49.27895900181362, 42.247215270996094, 44.47458192280361, 48.52326944896153, 43.091657638549805, 46.463198048727854, 50.009450912475586, 50.5922658102853, 51.40231459481375, 49.465285369328086, 50.98533582687378, 54.241973876953125, 50.59521532058716, 59.40998840332031, 20.10851056235177, 21.758963074002946, 56.67948184694563, 54.896945817129954, 54.277503490448, 47.36369153431484, 43.86605174200875, 42.02148914337158, 53.55413695744106, 53.98605782645089, 56.25189317975725, 56.02669164112636, 53.14875820704869, 51.45262997491019, 55.41093185969761, 52.12603896004813, 57.34457383837019, 54.17607021331787, 43.09547567367554, 0.93217433989048, 3.471600115299225, 3.5278342749391283, 0.5992826712982995, 38.579591274261475, 54.728160176958355, 57.9892589705331, 53.60531044006348, 60.845006806509836, 60.46765014103481, 64.10376753125871, 33.17824234281267, 23.0867395060403, 34.81108638218471, 47.03719915662493, 44.62873465674264, 49.94209507533482, 34.663089752197266, 0.1630168440086501, 0.03234537757400956, 0.03289883144732032, 0.05561995652637311, 0.03476647533742445, 0.07910599413194827, 0.02069353012900267, 0.027211191465279887, 0.07646440302154847, 0.15756761069808686, 0.21092012710869312, 0.1279165396200759, 0.11054251476057939, 0.09164239000529051, 0.15042835021657602, 0.10302284040621348, 0.12914126818733557, 0.1311329584568739, 0.29418572410941124, 6.26825395652226, 81.16659777505058, 60.00460134233747, 42.59482669830322, 25.71361368043082, 59.309976032802034, 40.00600780759539, 23.347781590053014, 68.67405632564, 73.78060013907296, 53.95284196308681, 61.92765426635742, 60.77926295144217, 64.09733349936349, 41.16920573370797, 0.48184503295591896, 3.4908407628536224, 1.6093585853065764, 0.5889450002993856, 15.138050692422048, 58.67299992697579, 52.48474318640572, 59.7766170501709, 59.22880022866385, 61.61338724408831, 58.65648405892508, 57.79282297406878, 57.42295299257551, 61.65741103036063, 58.340195110866, 59.303375244140625, 61.853336334228516, 55.45316301073347, 57.37389523642403, 58.97455174582345, 62.546544211251394, 59.66921179635184, 52.98010458265032, 54.47996704918997, 50.81943021501814, 47.94104167393276, 55.26812205995832, 57.32314211981637, 54.08429145812988, 55.08972358703613, 47.988880021231516, 51.11348492758614, 51.11855363845825, 46.355441910879954, 46.1558792250497, 53.55153138296944, 52.85690259933472, 54.73907927104405, 55.921030385153635, 52.07063055038452, 54.47730588912964, 56.772160393851145, 54.54258074079241, 52.50507014138358, 54.867638315473286, 54.894288131168906, 50.49412945338658, 53.34272411891392, 49.24359267098563, 45.75317553111485, 45.02293028150286, 47.67357076917376, 50.90921483721052, 55.26853895187378, 55.41212347575596, 55.07692500523159, 54.662183557237896, 54.97993162700108, 56.914153780256, 55.41821704592024, 53.5653200830732, 53.51747478757586, 55.40590483801705, 47.0975581577846, 50.346205779484336, 55.70041465759277, 55.89119829450335, 57.29109355381557, 59.52547441210066, 53.89782960074288, 57.70151669638497, 54.30692563738142, 51.848229135785786, 48.4056989806039, 43.99604211534773, 46.04548624583653, 43.16492986679077, 45.361338819776265, 45.93395723615374, 47.43286085128784, 51.96232550484793, 55.32474640437535, 52.632402828761506, 53.33694321768624, 53.98946244376046, 53.836247716631206, 53.966342312949045, 51.262558528355186, 51.99247373853411, 51.84763853890555, 51.598458766937256, 50.59061908721924, 43.67511871882847, 46.22776876177107, 50.669748646872385, 44.30597693579537, 47.27815226146153, 52.16786016736712, 51.3648499080113, 54.40257453918457, 51.02948120662144, 52.510583536965505, 56.97986289433071, 53.28285149165562, 61.993127141680034, 24.62246683665684, 24.89901556287493, 58.85735648018973, 58.2068452835083, 56.2779107093811, 48.75719445092337, 45.38884673799787, 43.63257489885603, 56.770454611097065, 56.89269774300711, 58.43891511644636, 58.918424197605674, 54.000607354300364, 53.90149130140032, 57.92540502548218, 53.33786037990025, 58.47132151467459, 57.41401413508824, 48.107482297079905, 1.7711236136300224, 2.4824408846242085, 5.5571575079645426, 0.626332659806524, 44.65995291301182, 66.71690164293561, 60.193495069231304, 58.54006699153355, 64.52409185682023, 64.65658705575126, 71.5938561303275, 37.113594327654155, 28.227407659803117, 45.738198689052034, 55.77528149741036, 53.68867840085711, 57.52021735055106, 49.84192984444754, 0.5294798197490829, 0.24664753356150218, 0.1276493053883314, 0.10624877230397292, 0.18756139624331677, 0.12482854032090732, 0.14979971466319902, 0.22653025947511196], [0.01892967495535101, 0.0581081783665078, 0.041331746083285124, 0.019696911464312246, 0.010956597564342831, 0.022291111992672086, 0.05782144982367754, 0.06732581196618931, 0.019431644984121834, 0.045151368980961185, 0.05598219583875366, 0.6153872385621071, 37.89996017728533, 48.003704002925325, 35.840006896427695, 31.989068576267787, 31.36517592838832, 29.081158876419067, 9.806045651435852, 39.633858816964285, 63.23675741468157, 51.02500656672886, 48.990622656685964, 52.20527969087873, 51.541622502463206, 51.63982139314924, 1.5110646997179304, 1.17783246082919, 1.2432243462119783, 0.41645151908908573, 2.0104940491063252, 37.20213174819946, 55.212779658181326, 45.8203889301845, 49.40644107546125, 54.57934365953718, 56.529122829437256, 54.8680864742824, 53.60389995574951, 49.252312660217285, 52.45551906313215, 52.330854484013145, 52.84944370814732, 53.13681077957153, 55.74991709845406, 51.59433501107352, 52.499014786311555, 49.795661790030344, 54.39602238791329, 52.82126528876168, 59.84168692997524, 56.125342164720806, 51.143827710832866, 52.55042103358677, 52.499674865177695, 51.119842529296875, 46.592656884874614, 45.77830369131905, 45.649824551173616, 44.634918553488596, 40.35490117754255, 42.76404660088675, 49.56726060594831, 49.54320594242641, 49.81507853099278, 49.90659325463431, 48.81153283800398, 51.113161836351665, 48.22348942075457, 48.93978616169521, 49.70905596869332, 46.948192732674734, 45.425224031720845, 42.15679488863264, 39.523052419934956, 40.06813859939575, 42.80550650187901, 46.28806522914341, 46.66943447930472, 48.14040633610317, 48.330488204956055, 49.69929027557373, 49.48099177224295, 48.132450648716514, 52.80653510774885, 51.606397083827424, 50.87729481288365, 51.324077878679546, 51.61790330069405, 42.9520822252546, 45.9424409866333, 54.80437496730259, 48.40606723512922, 52.67769813537598, 52.309151785714285, 52.06458561761038, 49.98344380514962, 51.061505453927175, 48.51883997235979, 46.243200710841585, 43.52117790494646, 40.54289511271885, 38.38700805391584, 38.94302722385952, 39.61297600609915, 44.26042454583304, 47.4441898890904, 47.88110998698643, 47.21946430206299, 48.83907202311924, 49.156132221221924, 46.04371098109654, 47.497083050864084, 46.22565303530012, 44.66559485026768, 47.010945388248985, 48.3257669040135, 48.28827442441668, 38.63853631700788, 42.534047331128804, 44.532220704214915, 41.430798462459016, 48.52100086212158, 51.49806424549648, 50.470828669411794, 51.444917474474224, 50.41585452216012, 50.221350124904085, 51.91467475891113, 51.986484391348704, 29.10303701673235, 26.050483192716325, 43.01175682885306, 43.03477968488421, 44.06650727135794, 53.184423310416086, 54.164383343287874, 47.717028277260916, 40.32418319157192, 41.27619756971087, 50.44760431562151, 49.62773772648403, 54.373284408024375, 55.13301433835711, 49.5866356577192, 48.61939777646746, 53.1840237889971, 46.74671234403338, 46.91880532673427, 21.375905411584036, 0.11272054431693894, 6.407643505505153, 1.049886812056814, 2.172240946974073, 52.61311115537371, 51.473714283534456, 52.67616605758667, 54.05575173241751, 53.6998302595956, 54.86796835490635, 56.721376010349815, 22.846998861857823, 28.76218444960458, 33.097507749285015, 40.67701619012015, 24.211974212101527, 50.66855355671474, 16.183714628219604, 0.22405425805066312, 0.03783852227830461, 0.014226385724863835, 0.01301888600989644, 0.08380877106849637, 0.053874794992485216, 0.03949250227638653, 0.06110622427825417, 0.02707843099986868, 0.01598230203879731, 0.06880355267120258, 0.1317529630448137, 0.014688138983079364, 0.04703766919140305, 0.020526381508846368, 0.08262728553797517, 0.09354820488286869, 0.012900657220078366, 0.09603143270526614, 0.9576471958841596, 44.342340333121165, 59.142316000802175, 32.800899573734824, 33.95036785943167, 41.61790302821568, 35.761777128492085, 13.761498774800982, 42.12161615916661, 72.33959933689663, 52.8001184463501, 54.82468107768467, 57.48132133483887, 56.89050211225237, 59.17932905469622, 2.142122460263116, 1.356556739125933, 1.001190579363278, 0.7646755820938519, 2.8695452213287354, 43.20223821912493, 58.96531758989607, 47.68519857951573, 54.0587603024074, 57.177844864981516, 58.18265860421317, 55.42096158436367, 54.744992188044954, 52.445753370012554, 55.99240575517927, 54.298827511923655, 55.87435238701956, 52.86126259395054, 57.52852392196655, 53.415138244628906, 56.424812998090474, 50.46409586497715, 54.19593858718872, 53.16243226187569, 61.42254107339041, 56.74411399023873, 53.03510652269636, 52.21822765895298, 55.3490755217416, 51.331967558179585, 48.33233642578125, 47.7054317338126, 47.39184216090611, 44.2812066078186, 40.62526600701468, 45.517982482910156, 52.35889046532767, 51.98241969517299, 53.24859339850289, 52.46463162558419, 52.458086422511506, 53.3759434563773, 51.17195749282837, 52.157225949423655, 52.10801533290318, 50.237865992954795, 48.69346904754639, 45.56842640468052, 43.55433818272182, 42.23372881753104, 43.961085728236604, 48.97054583685738, 49.796398299080984, 49.985292025974815, 49.522903306143625, 52.52802698952811, 51.86954273496355, 52.43725919723511, 55.45797116415841, 52.73356860024588, 53.45305109024048, 52.403351988111226, 52.94855628694807, 44.332692759377615, 47.39048031398228, 56.181236948285786, 51.36593730109078, 52.739832401275635, 54.13898767743792, 53.956566197531565, 51.24469123567854, 52.363399846213206, 51.66669007710048, 50.70215157100132, 46.939934798649375, 42.82529844556536, 41.33505228587559, 40.33308730806623, 42.711511271340505, 47.05722386496407, 49.764019693647114, 49.550119400024414, 49.910810811179026, 50.473562785557334, 52.766200814928325, 48.81321430206299, 49.34917402267456, 50.46158409118652, 49.083259514399934, 50.29025193623134, 50.86081715992519, 49.687777110508506, 40.33154828207833, 43.00006995882307, 46.221859318869456, 43.17581074578421, 50.66133437837873, 53.277907848358154, 51.15629972730364, 53.75189658573696, 51.9940961429051, 51.668878759656636, 53.20697716304234, 53.61376987184797, 28.874203307288035, 34.859358991895405, 49.347450869424, 42.82092802865164, 46.883022103990825, 55.03267887660435, 56.85163388933454, 49.88824653625488, 42.57659115110125, 43.879906449999126, 53.54125847135271, 52.483707904815674, 57.96587480817522, 57.2809213910784, 51.68626315253121, 51.460672514779226, 55.269306727818076, 49.13467270987374, 52.55022300992693, 23.017071655818395, 0.41147831880620545, 8.80715525150299, 1.0592057577201297, 4.025036292416709, 59.5714784349714, 53.18252992630005, 58.312847001211985, 59.64931215558733, 58.97559397561209, 57.67697218486241, 62.264558519635884, 24.69399333000183, 26.07604561533247, 39.866265637534006, 46.08472619737898, 24.614373922348022, 58.215106691632954, 20.141340800694056, 0.244923756058727, 0.021095305980582322, 0.023811875210542763, 0.04415674181655049, 0.030027559625783136, 0.06794106680899858, 0.032630589591073136, 0.03590404608153871, 0.05757757755262511, 0.1893151785646166, 0.09786218125373125, 0.15707198157906532, 0.168095841471638, 0.09928022444780384, 0.1769230935190405, 0.258946387895516, 0.13039336885724748, 0.11576354317367077, 0.1461963408759662, 1.3786790434803282, 63.3793830871582, 66.04624761853898, 53.12944916316441, 44.89406204223633, 44.78112949643816, 41.84278842381069, 15.634299721036639, 49.54553011485508, 76.80963257380894, 59.68303176334926, 61.156987871442524, 61.55283369336809, 61.90334946768624, 61.67513588496617, 2.954420941216605, 1.4970357439347675, 3.738806119986943, 0.6626747239913259, 5.300400725432804, 50.74649844850813, 59.11604486192976, 52.92884424754551, 55.81170742852347, 60.68979099818638, 59.96621254512242, 56.234769344329834, 56.66746146338326, 55.54500429970877, 56.82778072357178, 57.120490959712434, 57.486834730420796, 54.92969615118844, 59.3017771584647, 56.02578837530953, 59.2690372467041, 56.09878267560686, 57.33001388822283, 56.096819809504915, 62.319518770490376, 58.00798436573574, 55.01551335198538, 55.68591724123274, 56.612153802599224, 55.562475545065745, 50.47462238584246, 50.563604491097585, 50.848755087171284, 47.3009215082441, 42.92040538787842, 46.30464710508074, 53.51549455097744, 53.85498006003243, 57.05544887270246, 55.23799467086792, 54.953458990369526, 55.992624623434885, 54.03381974356515, 54.20857736042568, 55.39913729258946, 53.906091008867534, 52.501047134399414, 49.58240073067801, 44.99281331471035, 45.46185146059309, 48.16858128138951, 52.11236490522112, 54.6676378931318, 52.370782307216096, 55.19709062576294, 56.074884346553254, 55.041662897382466, 54.14226375307356, 59.346697262355256, 57.40117038999285, 55.6930113519941, 55.44695132119315, 57.25833627155849, 44.81920215061733, 49.472421169281006, 57.43215240750994, 53.91036762510027, 57.42238324029105, 58.065348693302695, 56.2477833202907, 54.41016892024449, 55.448372227805, 54.80046313149588, 52.41112354823521, 50.64485672542027, 45.3095816884722, 43.29949215480259, 44.9806261743818, 45.821128913334434, 48.917312213352744, 53.314354624067036, 53.24879142216274, 52.47663116455078, 55.08189991542271, 57.676273890904014, 50.621031352451865, 51.52545057024275, 52.44042757579258, 50.800847257886616, 53.902457101004465, 53.351586546216694, 52.80184159960066, 41.87784555980137, 44.446743965148926, 48.24551521028791, 46.47041722706386, 54.337449073791504, 56.70281737191336, 53.65326343263899, 55.67181934629168, 54.743578229631694, 54.46287100655692, 55.819704805101665, 55.17886897495815, 33.43388393947056, 31.290635653904506, 44.09557506016323, 46.841218267168315, 50.07969372613089, 57.69648272650582, 59.233254023960654, 51.89913511276245, 45.188033376421245, 46.544241837092805, 57.37318999426705, 54.779524735042024, 58.5673178264073, 59.8981271471296, 53.574429171425955, 53.816917828151155, 57.527162075042725, 52.60723992756435, 53.357023511614116, 29.086661849703106, 0.2436324224940368, 11.201798915863037, 2.199274867773056, 4.737750802721296, 62.4893535886492, 56.15459408078875, 63.60883344922747, 64.43200043269566, 65.10090351104736, 61.484421730041504, 68.87617247445243, 29.89547211783273, 39.112837723323274, 44.76012509209769, 56.60556691033499, 34.79893050874983, 66.93734019143241, 30.81593472617013, 0.27913874866706984, 0.13463459270341055, 0.10830623975821904, 0.07242528083068983, 0.17784314629222664, 0.1244876714689391, 0.13286191996719154, 0.11278305096285683], [0.022128350101411343, 0.05296927983207362, 0.10324147795992238, 0.027101348520123532, 0.1312096193432808, 0.05830521136522293, 0.07611561566591263, 0.06205955919410501, 0.05472390014412148, 0.06792743504047394, 0.08151588588953018, 0.2348902044551713, 17.03862793104989, 50.292798451014924, 41.013135296957834, 33.3361679485866, 23.106489760535105, 36.80982255935669, 9.951972586768013, 38.9542624609811, 58.89631502968924, 58.36415944780622, 46.23776027134487, 52.45853458132063, 51.62889882496425, 51.9073999949864, 26.286054917744227, 1.5953488456351417, 0.16799961163529328, 0.13834304442363127, 8.695807763508387, 27.348554338727677, 45.855560711451936, 55.51319892065865, 53.50315107618059, 55.62186179842268, 55.2805940764291, 53.44829852240426, 53.35269478389195, 51.18977614811489, 52.02215991701399, 51.149049282073975, 51.920660631997244, 50.82513468606131, 53.31477151598249, 55.15524162564959, 51.89524064745222, 53.42314256940569, 54.29912281036377, 51.40209225245884, 51.17263494219099, 54.02166734422956, 51.00537095751081, 53.2020891053336, 53.0033324105399, 48.60881567001343, 50.63051216942923, 44.538435867854524, 43.99432938439505, 45.05242885862078, 41.10964924948556, 41.091559614454, 44.689851011548726, 48.586612701416016, 46.79905659811837, 50.80184432438442, 51.58172403063093, 51.1564039502825, 49.677719593048096, 48.25877237319946, 49.59507771900722, 45.04866293498448, 45.81071008954729, 38.91284077508109, 41.73775945390974, 40.38579286847796, 44.70658574785505, 47.525365693228586, 47.841008458818706, 50.710444246019634, 48.617903913770405, 50.26140648978097, 50.573481355394634, 50.08556147984096, 51.07522814614432, 51.56995030811855, 48.56858560017177, 51.400191920144216, 49.40035097939627, 42.29812124797276, 45.83528586796352, 54.20117058072771, 50.83972937720162, 51.38719184058053, 52.066930634634836, 50.525795868464876, 49.72711781093052, 49.15051807676043, 50.625113419124055, 47.69004842213222, 47.33687496185303, 41.62199551718575, 39.44990873336792, 41.43654114859444, 40.12267501013619, 43.31624773570469, 46.30105488640921, 48.609729358128135, 48.63124792916434, 46.28358016695295, 46.47618075779506, 47.82971068790981, 47.122776644570486, 46.97476264408657, 46.71607773644583, 46.91036673954555, 49.44415937151228, 44.066854681287495, 40.16543422426496, 44.308502605983186, 43.7169885635376, 42.267573492867605, 48.25494391577584, 49.27647154671805, 46.47751828602382, 48.08995546613421, 44.40869215556553, 48.3903260912214, 47.253145694732666, 25.536351237978252, 32.02676255362374, 58.61487824576241, 51.74290486744472, 49.9367310660226, 44.66179418563843, 42.56459856033325, 49.376608984810964, 51.289833681924, 44.42789350237165, 41.710734435490195, 43.960418701171875, 53.74375329698835, 50.99652590070452, 55.98847654887608, 50.75808456965855, 52.3575564111982, 51.629353931971956, 45.93604516983032, 43.722369943346294, 8.278831601142883, 4.345773824623652, 8.931006022862025, 0.3198404817708901, 25.40658494404384, 49.81361593518938, 46.89217635563442, 59.022014890398296, 51.50781256811959, 55.494035788944785, 57.400249753679546, 49.840536730630056, 26.29065462521144, 36.69328042439052, 32.732574462890625, 49.79658590044294, 33.17311109815325, 50.337193965911865, 6.440452464989253, 0.052390330005437136, 0.14719153461711748, 0.06446264524544988, 0.062075525123093805, 0.04720363546428936, 0.01626913745089301, 0.011656369880906172, 0.05329049152455159, 0.06721403689256736, 0.03546964796259999, 0.010737646188187813, 0.023015948544655527, 0.09702765781964574, 0.05299058922433427, 0.01753329229541123, 0.04086553824267217, 0.02464729600719043, 0.06015955936163664, 0.12377592894647803, 0.20829349091010435, 21.63565513065883, 61.09320340837751, 44.10568816321236, 38.209022998809814, 33.7751898765564, 40.39191770553589, 13.36137546811785, 42.68035207475935, 68.47351741790771, 64.36746556418282, 51.24528183255877, 57.24408551624843, 56.95213263375418, 57.200311865125386, 33.0723865372794, 1.9120686905724662, 0.2695295257227761, 0.17446135490068368, 10.832128695079259, 33.86131279809134, 51.431198256356375, 56.51522295815604, 57.69861234937395, 58.187195777893066, 57.87095199312483, 54.96280084337507, 56.45372445242745, 53.14720181056431, 52.8644448689052, 52.74692651203701, 55.63594232286726, 52.60018055779593, 54.82433019365583, 57.440570150102886, 53.64465114048549, 54.36575256075178, 57.764668873378206, 54.83946337018694, 54.31637518746512, 55.67334794998169, 54.380941322871614, 53.186066559382844, 52.86825942993164, 48.43159144265311, 51.77926131657192, 44.60452018465315, 48.01421662739345, 46.70320272445679, 42.28963054929461, 41.97855969837734, 47.3817846434457, 51.9281507900783, 50.054013184138704, 52.365241118839805, 53.169526372637065, 53.15726627622332, 53.3123778615679, 49.418044567108154, 51.985473428453716, 50.91337333406721, 51.74292571204049, 43.09779984610421, 43.24672406060355, 43.502831186567036, 47.264377457754954, 51.385861260550364, 48.865339687892366, 51.66027341570173, 51.341278144291465, 53.64277512686593, 52.35535730634417, 54.18033640725272, 52.832194805145264, 53.33853088106428, 49.992632797786165, 53.91059691565377, 51.768074716840474, 43.558979579380576, 46.93747166224888, 55.965662138802664, 53.05311277934483, 51.13921410696847, 54.5838599886213, 54.89369058609009, 53.06931945255825, 54.601650851113455, 51.33974606650216, 51.69599757875715, 49.46956198556082, 43.89988946914673, 42.18961817877633, 43.60944087164742, 41.743818283081055, 44.534485816955566, 48.40626525878906, 51.61725017002651, 48.90248475755964, 52.05214139393398, 50.36355195726667, 50.20733560834612, 49.35610832486834, 50.056347778865266, 47.52866261345999, 49.19299936294556, 50.652982643672395, 46.197273118155344, 41.83402674538748, 47.07076937811715, 46.69177641187395, 44.459914275578086, 49.50152022497994, 52.021635328020366, 48.93640933718, 49.19490664345877, 47.21056713376726, 51.58057757786342, 48.91005481992449, 26.012973342623027, 42.062935147966655, 64.63961260659354, 50.8277576310294, 51.74354757581438, 44.87131364004952, 46.6179587500436, 51.87929800578526, 53.48356410435268, 45.88039009911673, 44.63836138589041, 46.36485324587141, 54.45955671582903, 53.36319351196289, 58.177572522844585, 54.12133230481829, 56.04515995298113, 52.68857206617083, 50.108469690595356, 46.47165053231375, 8.121659006391253, 5.85035411800657, 10.508430361747742, 0.315410489482539, 35.75544037137713, 53.67183944157192, 51.75209386008126, 63.03695501599993, 57.42742763246809, 61.268610681806294, 62.65481104169573, 56.10841287885393, 33.3699883052281, 34.94506849561419, 42.114497729710166, 55.895457540239605, 34.94344956534249, 57.038908685956685, 6.277346108640943, 0.14494516301367963, 0.05085307499393821, 0.03799933507772429, 0.051425687303500514, 0.04169457232845681, 0.031205204648098776, 0.04225538830671992, 0.05644662931029286, 0.1843769092644964, 0.06811332649418286, 0.16735636043761457, 0.11456617313836302, 0.2829364820250443, 0.086928172968328, 0.1769276668450662, 0.1514782610216311, 0.18065205056752476, 0.18803840636142663, 0.24043467694095202, 0.48043590571199146, 31.861461435045513, 72.88484532492501, 58.687771797180176, 47.27053703580584, 34.899960790361675, 51.160051754542756, 15.424460649490356, 50.215638705662315, 71.15946865081787, 70.08670847756522, 56.62004000799996, 63.25762980324881, 60.280132157461985, 62.34606088910784, 36.05833666665213, 2.8276564862046922, 1.2086146090711867, 0.33703331063900677, 14.0522426707404, 43.146273953574045, 55.4717355455671, 59.85849462236677, 58.7238746370588, 62.19411768232073, 58.908120019095286, 55.73777512141636, 59.815923009599956, 55.50676836286272, 56.47200863701956, 53.916923250470845, 56.36793157032558, 54.590596267155235, 57.12503160749163, 59.884515626089915, 56.63051789147513, 56.0744639805385, 57.35342584337507, 54.556803703308105, 57.01226234436035, 56.805577754974365, 55.63773495810372, 57.65762839998518, 56.976833479745046, 50.75694159099034, 54.796916076115195, 45.96747882025582, 49.93751621246338, 48.46475519452776, 46.669045380183626, 43.1151772907802, 48.44544267654419, 53.46670082637242, 52.956817695072715, 54.33033759253365, 55.41506603785923, 55.20927429199219, 55.963699272700715, 53.04520920344761, 57.20586347579956, 52.82610123498099, 55.11300005231585, 45.513254233769004, 47.63290991101946, 44.9978472845895, 50.414173058101106, 55.08328608104161, 52.45710672651018, 55.80337306431362, 53.350436619349885, 57.997624601636616, 55.70733158929007, 57.18551220212664, 55.76824992043631, 56.318370069776265, 51.403165749141145, 55.77596936907087, 53.94718265533447, 45.712156840733115, 49.006530557359966, 57.584752219063894, 55.59772375651768, 55.05326638902937, 56.66375459943499, 56.174563203539165, 56.76805400848389, 54.86240979603359, 55.39417280469622, 54.03779411315918, 54.329423904418945, 47.97506700243269, 45.67642572947911, 46.49011884416853, 45.15673174176897, 46.922460079193115, 50.32399238858904, 54.3296914100647, 50.71596111570086, 54.572385038648335, 52.856068815503804, 51.561490876334055, 53.28473097937447, 54.086497511182515, 51.195887088775635, 53.66626698630196, 55.12645871298653, 49.26354442323957, 44.770790576934814, 48.878176484789165, 48.209982122693745, 45.0534155028207, 53.27815450940813, 55.12546512058803, 49.72668007441929, 51.49518769127982, 48.31301695959908, 51.57826035363333, 51.690359115600586, 32.04308039801461, 39.40085097721645, 57.19029256275722, 56.934084687914165, 51.98567492621285, 49.30543163844517, 52.07052632740566, 53.01574536732265, 55.729072502681184, 48.39105217797415, 46.558992862701416, 51.17284338814871, 57.14460815702166, 55.3677522795541, 60.952571868896484, 56.03682906287057, 56.770350388118196, 55.09453174046108, 51.46580375943865, 52.131361280168804, 12.754259245736257, 4.3759528909410745, 15.907207591193062, 0.6792548628790038, 38.82457086018154, 55.834025042397634, 55.43602180480957, 69.39070047651018, 62.324431146894185, 63.42590822492327, 68.21016679491315, 63.93710803985596, 35.81892258780343, 50.65192304338728, 42.41203348977225, 67.05884334019252, 48.47616761071341, 67.50628648485456, 13.507339750017438, 0.36822670538510593, 0.2869720011949539, 0.13240905212504522, 0.1406885092811925, 0.09236152177410466, 0.1554228700697422, 0.15050259551831655, 0.15711061736302717], [0.040562283979462724, 0.02020685258321464, 0.025222040613048842, 0.0683010160656912, 0.07955543537225042, 0.08643776856895004, 0.07976632405604635, 0.044744353142700026, 0.08453398929642779, 0.11416344903409481, 0.019927438647885407, 0.2754050147320543, 4.774389956678663, 47.88757528577532, 33.72544772284371, 42.22242757252285, 25.133930683135986, 43.36598294121878, 15.430717502321516, 19.037714992250713, 62.31833757672991, 51.280231271471294, 58.36282539367676, 48.76023428780692, 55.95032051631382, 50.75041375841413, 52.454191957201274, 4.122030973434448, 0.5102860182523727, 0.4346338691455977, 33.66236155373709, 27.258609907967703, 34.69905015400478, 50.82465526035854, 50.73631933757237, 54.19375337873186, 54.62544495718819, 53.42435850415911, 51.82432038443429, 49.359999316079275, 49.86800295966012, 53.355265617370605, 53.87588371549334, 51.385399205344065, 54.01365259715489, 50.79227318082537, 48.619668756212505, 49.836548464638845, 54.24599340983799, 56.89473703929356, 57.03898164204189, 52.661557470049175, 50.80943523134504, 52.80557625634329, 50.08365419932774, 50.03996740068708, 46.86230952399117, 49.905766419001985, 45.27035215922764, 45.034631047930034, 42.027666091918945, 39.27265671321324, 40.95809861591884, 49.935195514133994, 49.58981793267386, 50.49731172834124, 50.04549469266619, 48.5229880469186, 49.34363978249686, 50.37086146218436, 45.45143263680594, 45.27605315617153, 41.02054555075509, 39.378773076193674, 40.43912724086216, 42.48075812203543, 46.77281672613961, 48.0370067187718, 47.87816742488316, 47.05621290206909, 49.4916398865836, 51.173944677625386, 50.43112666266305, 50.26533222198486, 50.58983394077846, 46.746514320373535, 48.20174503326416, 51.62445545196533, 49.95841986792428, 42.7876808983939, 44.904776164463584, 51.84892742974417, 50.8301408631461, 50.11613007954189, 50.399140630449565, 52.317527839115684, 51.67030314036778, 48.779974120003835, 50.080176625932964, 51.78653608049665, 48.91638810294015, 47.72105475834438, 43.291675431387766, 39.99229901177542, 41.520211356026785, 41.68959106717791, 43.4125462940761, 47.31610679626465, 46.982641901288716, 47.74152762549264, 47.20156921659197, 48.8084374155317, 47.43599101475307, 46.6987315586635, 46.110594340733115, 49.49253967830113, 46.8838906288147, 38.43498189108712, 38.4419127191816, 42.86059876850673, 43.07224089758736, 44.45625604901995, 51.508521284375874, 52.045842851911274, 51.78100184031895, 49.35410029547555, 47.04789938245501, 39.98379441670009, 25.481104373931885, 38.68989740099226, 61.523012025015696, 49.99941771371024, 48.17043645041329, 48.933921882084434, 59.45430401393345, 59.979879651750835, 48.126225062779014, 52.046947615487234, 48.29316595622471, 45.89558233533587, 43.82275056838989, 47.346664973667686, 52.634605407714844, 53.380887099674766, 54.732971804482595, 51.7916464805603, 52.10618795667376, 50.022457940237864, 24.211128268923076, 11.203894666263036, 16.808892692838395, 6.158975728920527, 2.4634036890098026, 58.85613359723772, 59.08943326132638, 58.83073098318917, 51.688496998378206, 53.69140556880406, 44.52806568145752, 62.88284397125244, 41.73218352454049, 35.3504889351981, 31.692342281341553, 26.731340646743774, 29.239360673086985, 30.76360089438302, 39.778676646096365, 0.9201151984078544, 0.07843049216483321, 0.05928838146584375, 0.02915395257462348, 0.022787421343049834, 0.03685372369363904, 0.015382273521806513, 0.0155193342028984, 0.03234256843903235, 0.05599122713985188, 0.02667361531140549, 0.09024183265864849, 0.009253661264665425, 0.08929347140448433, 0.0828875240736774, 0.05729794648608991, 0.04005472282213824, 0.01372135550315891, 0.046264953512166224, 0.02298498529541705, 0.24085536865251406, 6.695068333830152, 58.00692476545061, 39.18103429249355, 42.523652826036724, 38.956624848502024, 45.67285088130406, 16.042541129248484, 21.56866581099374, 68.64531857626778, 61.65270015171596, 62.841703687395366, 53.64961562837873, 61.823750904628206, 53.449472767966135, 59.41317067827497, 7.100446215697697, 0.24241933758769715, 0.11493566259741783, 40.39057322910854, 36.15917239870344, 41.41898305075509, 53.015550817762104, 54.05242701939174, 58.89654432024275, 58.156081744602744, 55.41466999053955, 53.520090784345356, 52.53247383662632, 52.6208792413984, 54.99391140256609, 54.89345782143729, 56.92687245777675, 56.3341772215707, 51.85857152938843, 50.66836595535278, 52.687797342027935, 55.26631900242397, 59.342590876988, 59.145359311785015, 56.518582412174766, 52.85946648461478, 51.99324151447841, 51.097177505493164, 50.577049255371094, 47.9796701839992, 53.14064271109444, 48.04109573364258, 49.483114446912495, 44.4795047215053, 41.87415954044887, 44.49202190126692, 53.28120476858956, 52.09789180755615, 53.49747092383248, 52.364264896937776, 49.827588762555806, 52.76385579790388, 52.70937844685146, 51.51700503485543, 47.041312490190776, 44.45685011999947, 41.64918729237148, 44.13309185845511, 46.51055697032383, 48.609069279261995, 49.87460374832153, 50.5699725151062, 52.00160714558193, 53.27694204875401, 53.696488176073345, 53.70527069909232, 53.20513589041573, 54.047719614846365, 50.77510070800781, 48.602854115622385, 55.60111100333077, 53.953651428222656, 43.89050245285034, 47.40705871582031, 53.85342713764736, 52.225106375558035, 51.692742347717285, 53.06270129340035, 52.196716036115376, 52.67457839420864, 53.29236010142735, 51.59922306878226, 55.46297039304461, 52.128456933157786, 48.9473249571664, 44.9469621522086, 44.05658524377005, 41.40505886077881, 44.44026129586356, 44.3219438961574, 50.71261555807931, 48.358194146837505, 49.453581128801616, 50.36916610172817, 51.31129319327218, 50.18526118142264, 47.871559688023154, 48.84153515951974, 50.82001038960048, 48.685551575251985, 41.194121973855154, 40.21907431738717, 44.74315411703927, 46.4635454586574, 46.31166131155831, 51.73999009813581, 51.7220915385655, 53.755770206451416, 51.8641995702471, 48.387640612465994, 39.60300881522042, 26.977661234991892, 47.23086282185146, 65.46489879063198, 50.156127384730745, 51.32358455657959, 51.42892966951643, 58.868869645254954, 59.65396744864327, 53.86173718316214, 55.149846349443706, 52.30177627290998, 47.38105508259365, 45.98753132138933, 50.2149612562997, 56.417885644095286, 56.868552752903526, 57.96300172805786, 52.163451535361155, 58.590983390808105, 52.97073146275112, 28.691099166870117, 16.890466281345912, 23.777251482009888, 6.983597925731114, 2.9412043818405698, 65.00246838160923, 59.13911982945034, 63.90424306052071, 55.68975612095424, 60.746391023908345, 47.66443736212594, 68.12433569771903, 51.97350515638079, 39.29262931006295, 36.19446577344622, 36.33033084869385, 35.138197149549214, 35.35039513451712, 45.56053672518049, 0.9231339735644204, 0.061014377778129916, 0.05359250406867691, 0.11239757521876267, 0.03419247203107391, 0.029736875223794153, 0.07442211439566952, 0.015086830892999257, 0.022064182741035308, 0.13908153479652746, 0.08073340609137501, 0.14903359434434346, 0.12065389433077403, 0.15729809658867971, 0.2640363233430045, 0.14779757495437348, 0.18585161013262613, 0.17669555358588696, 0.24286334376249993, 0.12965776904353074, 0.33061629640204565, 11.05227107661111, 73.53864996773856, 47.310572556086946, 55.95060886655535, 39.812479632241384, 62.065235546657014, 21.780631031308854, 26.50848933628627, 72.79196180616105, 65.39381177084786, 66.0727549961635, 57.93480246407645, 66.25033705575126, 59.454477718898225, 62.980320249285015, 10.659323522022792, 1.046144989984376, 0.48235887395484106, 46.353204590933665, 45.186018398829866, 49.23033550807408, 58.207515784672324, 56.89729050227574, 60.61000483376639, 61.1136589050293, 57.67401920046125, 56.467759813581196, 55.152177470070974, 54.293564251491, 56.08024835586548, 57.94486345563616, 56.98231560843331, 57.585172585078645, 55.15241370882307, 52.08044835499355, 54.709605012621196, 57.861558028629844, 63.4550142288208, 61.17078699384417, 57.75502477373396, 53.867691789354595, 56.029755796704976, 54.926058769226074, 55.57583345685686, 50.43229396002633, 56.236964975084575, 48.463744231632774, 52.00782578332083, 46.57005092075893, 44.490621839250835, 46.213618755340576, 54.89779349735805, 55.12588548660278, 55.54263843808855, 52.40916415623256, 52.39704997198922, 54.89140115465437, 56.397853987557546, 54.776474475860596, 52.20115940911429, 47.974361760275706, 43.89866311209542, 48.52030256816319, 50.646482603890554, 51.46324334825788, 53.58013711656843, 54.52541869027274, 53.55916745322091, 56.97877550125122, 57.78328309740339, 58.35626629420689, 56.4558401788984, 55.469803946358816, 53.61590644291469, 51.42951679229736, 57.86518151419503, 55.76459864207676, 44.514426367623464, 47.72516461781093, 55.07354818071638, 53.85328469957624, 53.41702120644705, 54.668297971997944, 56.76602166039603, 56.73297255379813, 53.834653105054585, 55.93758794239589, 58.177582945142476, 54.041862283434185, 52.729215553828645, 49.183084283556255, 45.39372089930943, 45.617755140577046, 48.21994931357247, 47.565453324999126, 53.05788966587612, 50.945824895586284, 50.9737913949149, 52.08815738133022, 54.53658791950771, 53.331332547324045, 50.43238081250872, 51.62019273212978, 54.690643378666465, 51.56959247589111, 43.55912896565029, 40.95802913393293, 46.570551191057476, 46.826588835035054, 49.11160816465105, 56.28568226950509, 54.69933557510376, 53.87042590550014, 50.01408188683646, 49.976846490587505, 42.29082563945225, 32.03368990761893, 44.38563455854143, 58.72855772290911, 52.60957452229091, 51.97900812966483, 53.40658153806414, 59.19114794049944, 60.288845198495046, 57.912891319819856, 55.925223623003276, 55.12182773862566, 48.90140778677804, 48.25557967594692, 53.391083581107004, 57.42366518293108, 57.16835709980556, 61.502507890973774, 53.72543784550258, 59.77390725272042, 50.94376475470406, 35.08050625664847, 15.848340715680804, 24.41365957260132, 11.297115172658648, 3.7000964028494696, 70.76128128596714, 65.0446092060634, 70.2560430254255, 61.055078642708914, 64.00092724391392, 54.58527742113386, 72.45792021070207, 53.73475885391235, 45.642664432525635, 46.59626994814192, 40.52737978526524, 42.26484285082136, 43.599195752825054, 61.10378551483154, 3.002335718699864, 0.2361741012760571, 0.2396750705582755, 0.21427287720143795, 0.0997201729831951, 0.14418060332536697, 0.1213034830455269, 0.08883289540452616, 0.07183000205882958], [0.08375815235610519, 0.024387637618929148, 0.04606722501505699, 0.03091995870428426, 0.03337520034983754, 0.03497334370123489, 0.07228766714355775, 0.10993571446410247, 0.04403369966894388, 0.01839816151186824, 0.016446582839957306, 0.13818714421774658, 0.6400592061025756, 38.36155680247715, 46.66220835277012, 44.51254687990461, 20.838307653154644, 36.953445298331125, 44.29237583705357, 8.346193517957415, 57.34990310668945, 43.725691182272776, 48.186219283512656, 49.799188000815256, 55.28500270843506, 48.967332295009065, 54.33888040270124, 3.6867276344980513, 0.18816416604178293, 0.21996802517345973, 19.932887894766672, 42.59327725001744, 27.66818015916007, 49.585972104753765, 46.59611708777291, 57.44589247022356, 53.98438678468977, 56.918298380715505, 50.18167243685041, 53.95235211508614, 53.26688800539289, 54.519286905016216, 55.373460224696565, 54.95411906923567, 52.14529241834368, 52.4796918460301, 48.33368785040719, 55.287281717572895, 52.9220141683306, 54.66157906396048, 52.37768881661551, 52.0179249899728, 51.9083206312997, 50.4531455039978, 48.29251977375576, 50.309845856257844, 50.43383993421282, 51.73823915209089, 46.61212226322719, 46.91166605268206, 42.79377099445888, 38.78652947289603, 39.1482526915414, 44.357793126787456, 51.010088784354075, 48.07387038639614, 51.71659551348005, 48.28654432296753, 49.8753993170602, 49.386753354753765, 46.23866353716169, 45.55025339126587, 40.0753230367388, 40.89392505373274, 40.529238428388325, 43.71415369851248, 48.851960931505474, 48.574880668095176, 46.71582760129656, 47.594590595790315, 51.34341124125889, 51.40994719096592, 50.94496331896101, 49.79444932937622, 49.22099365506853, 43.20388494219099, 46.912819453648154, 51.286526339394705, 51.49245704923357, 42.813427448272705, 45.23106357029506, 52.31723254067557, 48.46089199611119, 44.80070604596819, 53.464734486171174, 52.019113131931846, 49.60221004486084, 50.226762771606445, 50.5811174256461, 50.403848034994944, 49.82394790649414, 47.70740849631173, 44.297312532152446, 42.23610162734985, 40.98244857788086, 39.458864961351665, 42.08226156234741, 45.48901196888515, 48.34153584071568, 46.694993427821565, 48.526114736284526, 48.12298720223563, 46.49322121483939, 47.755444867270334, 49.211116790771484, 46.87817226137434, 44.137865270887104, 36.989683628082275, 39.81548820223127, 43.795638697487966, 42.33179916654314, 44.43619659968785, 48.863359451293945, 50.481421198163716, 47.72753395353045, 49.54693712506975, 41.39293425423758, 31.6038430758885, 50.00818634033203, 62.30229418618338, 49.30200965063912, 47.3340505191258, 46.80654328210013, 44.937415327344624, 47.2078469140189, 55.71814298629761, 58.258703163691926, 50.044952733176096, 52.584432465689524, 47.02759674617222, 48.00946058545794, 47.50178003311157, 52.867741789136616, 52.04832335880825, 56.12427561623709, 45.61870009558541, 47.09346914291382, 38.07233803612845, 25.913591521126882, 34.55241189684187, 21.313088485172816, 3.688305309840611, 5.540444050516401, 56.06273194721767, 46.55283328465053, 53.66167075293404, 48.39804553985596, 48.052685328892295, 47.8565411567688, 60.84711905888149, 29.171285697392054, 46.007462229047505, 23.726077999387467, 26.701426914760045, 25.383885179247173, 40.1511869430542, 23.6516523701804, 0.046199128830007145, 0.0831368856930307, 0.030035260998244797, 0.03456647714067783, 0.03812043661517756, 0.03883725797225322, 0.0588696575058358, 0.019551589619368315, 0.026683817085410868, 0.04560651330809508, 0.02238871586242957, 0.03921678974958403, 0.03129059149484549, 0.020711647014000585, 0.0772176311750497, 0.059740055086357255, 0.036735088630978546, 0.058530892112425396, 0.018927976921466843, 0.032804359016673904, 0.18510849215090275, 0.8989305751664298, 46.35552181516375, 55.912299973624094, 40.50319658006941, 32.351681164332796, 43.32586751665388, 44.46422563280378, 12.096364719527108, 61.790350914001465, 49.68756866455078, 51.28388949802944, 54.48034920011248, 60.39565290723528, 53.18520845685686, 58.60872909000942, 7.535236256463187, 0.21478621608444623, 0.07574840608452048, 23.164901529039653, 52.01194953918457, 32.85865300042288, 54.817315987178254, 47.91131033216204, 61.30233723776681, 56.48422704424177, 59.60020228794643, 51.40280096871512, 57.98565632956368, 53.727317333221436, 57.3924469266619, 56.40801920209612, 57.46956498282296, 51.898134572165354, 52.88520956039429, 51.675910336630686, 59.13917541503906, 54.56817443030221, 57.445465156010215, 53.14378677095686, 54.467071192605154, 52.626451696668354, 52.086052077157156, 48.631821155548096, 51.68163912636893, 52.303766931806294, 52.29795823778425, 48.05685772214617, 48.99503823689052, 44.38624947411673, 41.21888187953404, 41.15232508523123, 45.04525484357561, 54.27589498247419, 50.26124668121338, 52.47498444148472, 51.9452086176191, 52.129731927599224, 52.55457258224487, 46.96272141592843, 47.308797291346956, 43.47989170891898, 43.89202410834176, 45.77180017743792, 48.52237313134329, 50.93253993988037, 50.33418539592198, 53.49626193727766, 51.46182244164603, 52.714804989951, 52.745905126844136, 54.37948914936611, 52.383841446467805, 52.589139870234895, 46.64610937663487, 49.6751765523638, 53.8271073613848, 54.11158398219517, 46.587477002825054, 47.496096406664165, 53.335852350507466, 51.82367420196533, 47.76715953009469, 56.01932307652065, 54.45902170453753, 52.63164894921439, 52.2126795223781, 54.15865107945034, 54.212645530700684, 51.46945851189749, 50.6505959374564, 44.86683552605765, 44.59309734616961, 43.70472846712385, 42.692782402038574, 43.677821568080354, 47.69664226259504, 49.71669898714338, 49.28131444113595, 51.672127042497905, 49.2087995665414, 49.36138548169817, 49.5851730619158, 47.93808174133301, 47.26661477770124, 44.25306987762451, 38.095760413578574, 41.30160365785871, 44.53395427976336, 45.05261993408203, 45.18381234577724, 49.389782769339426, 52.78470386777605, 50.6665038381304, 49.9119086265564, 40.150582449776785, 34.85503373827253, 57.169183935437886, 61.998032569885254, 49.155506883348735, 49.34637042454311, 48.18770619801113, 47.279969215393066, 49.4031719480242, 55.04273986816406, 60.11773885999407, 52.08551706586565, 53.27024745941162, 50.38218355178833, 50.51789229256766, 49.60733086722237, 56.16430418831961, 53.26618276323591, 57.68573733738491, 46.79253918784005, 51.77749647412981, 39.962168148585725, 34.249678884233745, 44.38025317873274, 21.356582471302577, 5.284100685800825, 7.279278951031821, 64.00312287466866, 52.441577502659385, 59.62130396706717, 53.986860343388145, 52.020843233381, 56.156803607940674, 68.28580488477434, 35.46333115441458, 49.31358534949166, 29.896059240613663, 35.85978146961757, 25.56100865772792, 45.90081432887486, 31.883410794394358, 0.20786977293235914, 0.028950649912336042, 0.028547237095023905, 0.03355718004916396, 0.040970504217381985, 0.040742421456213505, 0.02030741486565343, 0.016836216307378242, 0.032736749787415774, 0.16657018262360776, 0.09736643678375653, 0.12503314577043056, 0.09555770669664655, 0.15151045072291577, 0.09947915055922099, 0.19965432876987116, 0.15515265028391564, 0.14480949672205107, 0.1317352939929281, 0.1422647868416139, 0.2304568737745285, 1.7601085475512912, 64.85159519740513, 62.83730547768729, 61.319144930158345, 29.414635930742534, 53.90800176348005, 56.06196764537266, 14.179569278444562, 67.39763750348772, 57.00304208483015, 54.95616878782, 58.61287021636963, 65.99616500309536, 57.232023443494526, 64.86474118913922, 7.498388222285679, 0.3192314830209528, 0.26892983647329466, 31.640470504760742, 59.85407556806292, 39.50975704193115, 60.294487135750906, 52.078798157828196, 63.220748765128, 59.00872993469238, 62.72336891719273, 52.42277567727225, 59.74505138397217, 57.689815929957796, 59.97600255693708, 59.32562337602888, 61.37150655473982, 54.94580207552229, 55.67689153126308, 51.3158894266401, 61.242721693856375, 56.96490689686367, 61.20989145551409, 55.77143219539097, 55.73460674285889, 53.76625156402588, 55.87215328216553, 50.70580284936087, 54.654457160404746, 52.36492150170462, 56.04630987984793, 48.16820955276489, 51.57731539862496, 45.145989826747346, 42.74699224744524, 43.43785858154297, 48.23911244528634, 54.36208391189575, 52.922142710004536, 56.828944546835764, 55.59434693200247, 54.69485051291329, 56.08873210634504, 50.222559111458914, 50.35427958624703, 46.68273680550711, 47.916024684906006, 49.2832738331386, 51.58233894620623, 55.513570649283274, 54.852011816842214, 54.03228766577584, 55.1885096005031, 58.03919914790562, 57.28369719641549, 57.53895664215088, 54.820130007607595, 55.205567428043906, 50.042413166591096, 51.65935625348772, 56.19868734904698, 54.77061367034912, 46.153909410749165, 47.88542134421212, 55.25490311213902, 51.71141563143049, 48.24735300881522, 57.53335986818586, 57.14130776269095, 54.99978263037545, 53.639592851911274, 56.37532097952706, 55.3040303502764, 54.420070103236604, 53.326013701302664, 50.118165901729036, 47.105958529881065, 45.76044682094029, 44.45256308146885, 44.38612788064139, 50.89937271390642, 51.20581259046282, 51.52433885846819, 55.00307607650757, 52.7235666683742, 52.9582142829895, 54.53666434969221, 52.10929380144392, 48.615638801029746, 46.75433104378836, 40.86554166248867, 44.735511098589214, 47.03849152156285, 48.48792396272932, 48.88184860774449, 52.79320151465279, 54.300790378025596, 53.90005302429199, 52.79554305757795, 44.01692145211356, 37.531333923339844, 52.81607845851353, 57.71238020488194, 51.46833290372576, 52.055215971810476, 51.95037112917219, 47.70465006147112, 52.66297837666103, 55.042312553950715, 62.2809910093035, 54.654352937425884, 57.272590500967844, 51.081526688167024, 51.627665519714355, 49.861297948019846, 59.16738510131836, 55.456862926483154, 61.137102127075195, 50.849595819200786, 52.81107922962734, 43.574293409075054, 43.203443731580464, 49.53305809838431, 33.20428419113159, 5.6988838229860574, 7.44899000440325, 71.69270120348249, 54.30992725917271, 64.82055759429932, 58.135383061000276, 57.94608633858817, 58.874692235674175, 71.69602939060756, 39.30223519461495, 54.52862875802176, 37.987858363560264, 40.572814055851524, 36.61485958099365, 57.39845364434378, 44.388285296303884, 0.3352098970540932, 0.1280430999717542, 0.20934992922203882, 0.13124875724315643, 0.148898878001741, 0.15015537557857378, 0.23797278904489108, 0.11218545838658299, 0.058603861768330844], [0.0046321639175792885, 0.04033511724056942, 0.0527918225686465, 0.030505523085594177, 0.07128713333180972, 0.12466653329985482, 0.012504985639160233, 0.028167069191113114, 0.030935402161308696, 0.05261052479701383, 0.18595085266445363, 0.02748011694555836, 0.16421235485800675, 19.305922406060354, 45.38225984573364, 39.9161502293178, 34.58516917909895, 28.046348026820592, 43.08770758765084, 10.89091306073325, 38.85556329999651, 64.93691212790353, 53.07506561279297, 53.605866295950754, 54.224711077553884, 52.68461854117257, 56.456232752118794, 20.730087723050797, 0.397862862263407, 0.21375568423952374, 1.41505785712174, 19.959839957101003, 35.75757346834455, 42.25269739968436, 54.17841870444161, 52.729371888296946, 53.39902537209647, 53.42339617865426, 55.26320273535592, 52.68642854690552, 54.634484563555034, 54.54690599441528, 52.00563015256609, 52.40542949948992, 53.41858802522932, 48.162654467991416, 52.2614871433803, 51.75754124777657, 54.83366162436349, 56.71330220358712, 55.76247596740723, 54.46508400780814, 51.352562018803184, 51.99364103589739, 48.324783733912874, 48.988392284938264, 48.610646520342144, 49.2001872743879, 47.03232846941267, 45.7134769984654, 45.148227146693635, 38.578535148075645, 40.56119319370815, 41.552676813943044, 48.444744382585796, 51.713340282440186, 49.61316735403878, 50.48958533150809, 49.86049543108259, 46.21034267970494, 43.88351951326643, 41.315409728458945, 39.75682456152779, 42.675297260284424, 43.757135254996165, 45.852920395987375, 48.019431250435964, 46.13468721934727, 48.98093686785017, 48.519562585013254, 50.396302291325156, 49.212454319000244, 50.199345179966514, 50.37480456488473, 46.11177206039429, 41.39004727772304, 47.097547735486714, 50.04575177601406, 49.553746359688894, 46.05293124062674, 49.243599619184224, 54.07808671678816, 47.44938366753714, 41.96639340264456, 51.14490120751517, 50.22050244467599, 52.70439658846174, 51.36072267804827, 51.0325106212071, 52.91349567685808, 49.85897030149187, 49.832723481314524, 47.59287439073835, 43.60824925558907, 41.77669021061489, 42.96643720354353, 41.85063294001988, 42.946391650608604, 47.78795896257673, 48.23097610473633, 47.32314532143729, 45.75647592544556, 48.057222502572195, 45.90553215571812, 47.67647164208548, 45.19883435113089, 39.16013758523123, 36.632886682237896, 40.039122922079905, 42.9061198915754, 42.88289901188442, 42.97000857761928, 47.01707022530692, 46.96399293627058, 49.80288444246565, 34.63082231794085, 38.458800315856934, 56.65345389502389, 58.00936358315604, 47.37554516111101, 49.30525098528181, 43.094152041843955, 43.23164994376046, 43.76903404508318, 49.88564443588257, 46.978542464120046, 48.75232376371111, 49.69866146360125, 50.5041834967477, 50.80306025913784, 51.35611949648176, 51.389307567051475, 50.9246745790754, 54.84832579748971, 47.58290025166103, 49.9620954649789, 46.580945696149556, 31.746322836194718, 33.96712344033377, 17.328913245882305, 4.258396318980625, 3.26446476152965, 15.290766886302404, 47.85048927579607, 50.9270578111921, 52.86007097789219, 53.7003687449864, 46.34722219194685, 62.53908879416329, 33.24325663702828, 33.27010795048305, 47.059843335832866, 24.557386534554617, 50.02082511356899, 20.559016125542776, 43.6966164452689, 13.492726819855825, 0.20427142030426435, 0.028243046453488723, 0.0634333211928606, 0.008633405618768717, 0.015538161853328347, 0.05763089004904032, 0.04228632611089519, 0.022532919820930277, 0.03263462008908391, 0.047444322013429234, 0.020452770637348294, 0.012662856141105294, 0.0810685141810349, 0.024513609341478775, 0.0880592976297651, 0.07835963275283575, 0.022529393135170852, 0.09148198432688202, 0.04045944181936128, 0.09906529169529676, 0.02598694635422102, 0.134134743096573, 23.985400404248917, 57.3769976070949, 36.10108198438372, 32.19014596939087, 40.71839618682861, 45.640555654253276, 14.575197969164167, 41.7895131111145, 71.80937535422188, 55.96952881131853, 58.2574177469526, 61.270361627851216, 57.27749592917306, 58.61700439453125, 25.287227051598684, 0.4495235058878149, 0.20199986148093427, 2.1534284821578433, 25.923192194529943, 42.99565437861851, 47.20287895202637, 54.82239512034825, 55.965113231113975, 55.070275579180034, 57.72997999191284, 55.51854903357369, 55.9464955329895, 58.37945243290493, 57.4629294531686, 53.312270164489746, 55.29397630691528, 53.950194699423655, 50.73448848724365, 56.13800873075213, 53.77382857458932, 56.39293813705444, 56.69309336798531, 55.55892848968506, 54.5088472366333, 52.43773167473929, 53.05328301021031, 51.13398906162807, 50.59382915496826, 49.996106897081646, 52.107480321611675, 47.994813782828196, 46.35260009765625, 47.141745226723806, 42.18297222682408, 44.437464645930696, 42.03607341221401, 50.77428429467337, 53.76833602360317, 52.29065220696585, 53.57264001028878, 52.82443019321987, 48.46831962040493, 47.33096204485212, 45.61976316996983, 44.997329643794465, 45.62327201025826, 46.38111203057425, 47.34468821116856, 52.91406542914254, 51.23145144326346, 51.501729420253206, 50.46118804386684, 53.49938862664359, 51.974144390651155, 52.505351543426514, 53.04262794767107, 50.32816130774361, 43.7682523727417, 48.999439920697895, 50.44252518245152, 53.405806813921245, 46.36881719316755, 51.66888223375593, 54.80781432560512, 49.84898574011666, 45.000084604535786, 52.63507441111973, 52.215708936963765, 54.29568692616054, 52.32179750714983, 53.10664517538888, 53.89606128420149, 53.452800955091206, 51.45818853378296, 50.279895646231516, 45.91337667192732, 43.896130493709016, 43.26907294137137, 42.425217696598594, 47.133768694741384, 51.020222731998985, 49.907764026096885, 50.76816987991333, 47.63002988270351, 50.67523772375924, 49.415550163814, 48.973036766052246, 47.036056177956716, 40.689918994903564, 37.396139349256245, 43.341341154915945, 45.74432005201067, 44.57293714795794, 44.26986714771816, 48.65137686048235, 48.480656147003174, 51.09491239275251, 36.14563383374895, 42.222493580409456, 59.9266425541469, 56.73454284667969, 48.285915510995046, 51.92987046922956, 44.815099239349365, 46.16904258728027, 45.613329138074604, 51.27552734102522, 48.67767579214913, 50.08184766769409, 51.401915073394775, 52.199234758104595, 52.754298550742014, 54.57713760648455, 53.55969204221453, 53.36960669926235, 57.82381541388375, 49.98637247085571, 51.24574041366577, 50.223924432482036, 34.68487582887922, 39.90996633257185, 13.008731807981219, 5.4934538177081516, 2.6834118834563663, 21.772553750446864, 54.91695315497262, 57.62597588130406, 57.439326422555105, 61.10095064980643, 51.55753040313721, 68.00165135519845, 36.1598915372576, 35.27267605917794, 50.74824244635445, 29.596178463527135, 51.7663619858878, 19.580885205950054, 53.37388331549508, 14.606393643787928, 0.20271404672946247, 0.041968140684600384, 0.004377932961298419, 0.02498242784557598, 0.03451705604259457, 0.07164621406367847, 0.03666742511891893, 0.033204406300293546, 0.01597617656391646, 0.09125149276639734, 0.11404489539563656, 0.09348118597907679, 0.11283185120139803, 0.11500369251838752, 0.3497726699071271, 0.19310630299150944, 0.08640713949820825, 0.15024956980986254, 0.15046017350895063, 0.39040823227592875, 0.10758218861051969, 0.2555600367486477, 35.66048628943307, 65.78933102743966, 56.00686843054635, 46.25701372964041, 43.32210854121617, 58.622549057006836, 15.502004282815115, 48.78746427808489, 75.62256063733781, 63.90743923187256, 64.45617321559361, 66.07670852116176, 60.53859124864851, 67.4308568409511, 27.829334940229142, 1.036646259682519, 0.2151498972837414, 2.6658142677375247, 37.87499877384731, 49.81891393661499, 52.16389274597168, 60.70534801483154, 59.91708183288574, 56.90894610541207, 59.22615991319929, 59.30097116742815, 57.568194661821636, 60.320563725062776, 58.84157712118966, 56.12332023893084, 58.322477204459055, 55.72806848798479, 51.018906048366, 56.2537761415754, 57.45889949798584, 59.39021383013044, 59.40652820042202, 57.071787561689106, 57.697524956294465, 55.07003239222935, 55.38218716212681, 52.49599231992449, 53.16623640060425, 50.88066816329956, 53.68809822627476, 49.89731740951538, 47.973093714032856, 48.54247774396624, 44.44504165649414, 46.935811042785645, 45.660010610307964, 52.396508012499126, 57.50048794065203, 56.158478123801096, 56.14614159720284, 56.495583874838694, 53.529675824301584, 50.62911210741316, 48.53190605981009, 49.197421891348704, 49.12642867224557, 48.856987953186035, 49.94516617911202, 56.9608838898795, 53.61083425794329, 55.670547825949534, 54.24317591530936, 58.217385700770784, 53.843209811619346, 55.69122566495623, 55.98844528198242, 54.59506743294852, 46.65929705756051, 51.717634269169395, 54.38416181291853, 56.057691029139924, 48.07256759916033, 52.682207516261506, 59.00036430358887, 52.1251391683306, 47.5810763495309, 55.45245776857649, 55.31267738342285, 58.76967021397182, 55.88612610953194, 57.3298019681658, 57.81172207423619, 55.763914244515554, 52.723292214529856, 52.64715385437012, 48.676001276288716, 46.990135533469065, 48.058577401297434, 46.10243368148804, 47.50073432922363, 52.995467049734934, 52.16559158052717, 52.562545640128, 50.315696239471436, 53.110616070883616, 52.4921430179051, 50.38763788768223, 50.26749658584595, 42.62347412109375, 39.05929490498134, 44.362715925489155, 48.12229585647583, 46.87502472741263, 46.13207469667707, 51.63909878049578, 49.51627125058855, 51.74413817269461, 42.53737204415457, 43.7809293610709, 51.769440037863596, 55.142463888440815, 50.87949391773769, 54.23051629747663, 45.87274013246809, 47.30380848475865, 46.66640159061977, 54.51149450029646, 52.39365577697754, 51.69835649217878, 52.05038349969046, 54.79765953336443, 54.44847781317574, 57.12309306008475, 56.14211859021868, 55.178726536887034, 60.87393910544259, 54.20920269829886, 51.26969085420881, 51.27552386692592, 39.90893452508109, 48.135341099330354, 23.42501950263977, 11.060981512069702, 4.154697929109846, 21.81333793912615, 62.417849676949636, 60.80405412401472, 62.37642451695034, 63.49218014308384, 57.450808320726665, 70.64951256343296, 43.61362716129848, 42.50155060631888, 59.21729401179722, 38.98342752456665, 63.81747395651681, 32.412985120500835, 65.02640492575509, 25.598198890686035, 0.24911227130464145, 0.15793802296476706, 0.1337460239550897, 0.0883916372965489, 0.0908706174897296, 0.14659610656755312, 0.19208364215280327, 0.0950528902134725, 0.10347865309034075], [0.024208443305854286, 0.03563748359946268, 0.03794141872120755, 0.056741378137043545, 0.04495698905416897, 0.03288748973448362, 0.04872579646429845, 0.06529541127383709, 0.02483706019951829, 0.026099318538659384, 0.05896356675241675, 0.03847904237253325, 0.18917550891637802, 5.590521454811096, 51.56351627622332, 34.61208997453962, 40.176454067230225, 25.43772677012852, 46.67341232299805, 18.973115852900914, 23.661086286817277, 61.055182865687776, 49.84521286828177, 63.10034343174526, 48.33580010277884, 56.89388241086687, 45.21413081032889, 50.28942510059902, 0.7722323994551386, 0.8461303455489022, 0.5728261023759842, 1.1195673644542694, 37.14434705461775, 44.254942417144775, 51.128732749394004, 54.0226400920323, 58.71709319523403, 55.3949544770377, 58.07631989887783, 57.49137537819998, 57.81316729954311, 51.894087246486116, 51.95391123635428, 51.88746561322893, 48.71435880661011, 49.39309011186872, 54.57949651990618, 49.147832598005024, 54.698814460209434, 53.30078131811959, 54.12927756990705, 53.321195125579834, 51.81617362158639, 49.628592354910715, 51.813095569610596, 50.715770040239605, 46.862577029636924, 46.323490619659424, 46.934171267918174, 45.92040477480207, 47.2919340133667, 44.35114370073591, 38.96165187018258, 40.88008771623884, 41.23829167229788, 49.82689394269671, 51.06844323022025, 48.86472824641636, 48.20243985312325, 41.830281666346956, 40.81122064590454, 39.42190401894705, 42.259718554360525, 45.00090796606881, 45.22310093470982, 47.333939347948345, 47.44498545782906, 48.77055583681379, 48.69953482491629, 49.317097663879395, 49.84187773295811, 47.72731161117554, 49.228619303022114, 46.926455293382915, 40.58508110046387, 40.693778719220845, 44.7016282081604, 51.268064975738525, 52.62661497933524, 46.79043735776629, 51.26144681658064, 49.870806557791575, 45.510811941964285, 39.5912628855024, 45.23077869415283, 53.367244311741416, 49.128867489951, 50.92174243927002, 49.7267495564052, 49.59380619866507, 48.8014475277492, 49.141513211386545, 48.79231759480068, 46.548014708927695, 42.628587995256694, 40.83651556287493, 39.50405257088797, 38.75915357044765, 44.152536392211914, 47.953815937042236, 48.525763852255686, 48.61821658270699, 46.37373999186924, 47.55890812192644, 47.8881311416626, 44.03376041139875, 37.85026666096279, 37.76860448292324, 41.270579951150076, 45.75888000215803, 42.007412093026296, 43.534428119659424, 46.38540601730347, 47.69883441925049, 47.999024391174316, 41.36325849805559, 53.78354563031878, 49.86120067323957, 47.486535685403005, 49.49151829310826, 45.52883904320853, 45.27111298697335, 49.59751306261335, 47.78401933397566, 47.357795987810405, 49.44942263194493, 49.688489300864084, 51.877133641924175, 49.908375467572895, 51.38979741505214, 51.23304605484009, 55.11118309838431, 52.31934131894793, 48.128611768995015, 53.339100633348735, 48.67993743079049, 34.46363128934588, 31.2816481590271, 13.051455412592206, 0.47176618235451834, 0.6490459953035627, 5.516746784959521, 56.419435092381065, 46.520180225372314, 54.00139944893973, 46.95815644945417, 50.42827442714146, 43.94038009643555, 60.66563211168562, 24.87957102911813, 48.69854818071638, 28.28236617360796, 38.60287121364048, 42.470506055014475, 22.506080286843435, 35.65165860312325, 1.65507002387728, 0.06045802656028952, 0.06824456873748984, 0.045144505599247556, 0.032260944068964036, 0.1008646037163479, 0.019549626956826875, 0.037121083454361985, 0.026568598446569273, 0.07426236689622913, 0.04362457019409963, 0.020494904269331267, 0.06266371998935938, 0.0492479325538235, 0.021893364942765663, 0.020237033820844123, 0.03145171642037375, 0.04951949244631188, 0.003233425468871636, 0.027472368075645397, 0.07809439341404609, 0.011593669004339193, 0.3261346811694758, 8.004464609282357, 62.5137209211077, 41.30578299931118, 35.938740798405235, 35.61789035797119, 48.287485803876606, 18.982765163694108, 27.747226340430124, 67.39826978955949, 56.53186041968209, 67.15995352608817, 53.708261898585725, 62.19587557656424, 49.85208811078753, 52.23855113983154, 1.149963127715247, 2.0775313547679355, 1.2334764578512736, 1.8314834833145142, 42.9746082850865, 48.791525500161306, 55.26856674466814, 58.55790996551514, 62.12416321890694, 57.36524472917829, 60.29175649370466, 58.21761499132429, 59.65152168273926, 54.117316246032715, 53.33879491261074, 54.13796976634434, 50.97886010578701, 55.69084351403372, 55.80873359952654, 50.76641893386841, 56.044124671391074, 54.69237348011562, 55.39211613791329, 55.03355434962681, 54.60303006853376, 52.322864055633545, 53.24748168672834, 52.050498144967214, 47.84318324497768, 48.085623264312744, 48.654784951891216, 46.826237951006206, 49.840064253125874, 45.51014838899885, 41.71132503237043, 43.500548703329905, 42.208291462489534, 52.259090014866416, 54.449193477630615, 50.778696400778635, 50.20616136278425, 44.09091281890869, 44.259462220328196, 44.18600933892386, 45.94015155519758, 46.988864013126914, 47.29481751578194, 50.96234771183559, 49.93882247379848, 51.96990251541138, 53.033393791743684, 50.967760358537944, 53.11069597516741, 51.51954460144043, 50.32306480407715, 50.09325313568115, 43.72859900338309, 41.28586251395089, 47.892185415540425, 52.835727964128765, 54.46753672191075, 47.50955854143415, 51.7454513822283, 52.602362292153494, 49.24609749657767, 41.06048379625593, 46.61754533222744, 54.5744833946228, 51.8136305809021, 51.53515372957502, 53.05308151245117, 50.8246100970677, 53.105050563812256, 50.83250672476632, 50.284446716308594, 48.1624390738351, 45.33011014120919, 43.444494111197336, 39.51938377107893, 42.80266121455601, 46.73471280506679, 49.27284458705357, 48.658728054591585, 49.635029860905235, 48.883151394980295, 48.57790313448225, 50.80737509046282, 44.06541640417916, 38.99111918040684, 38.690682547433035, 43.27902276175362, 48.09137289864676, 43.044458525521414, 43.65409346989223, 46.50616223471505, 49.198332105364116, 48.96935422079903, 43.61324153627668, 57.94015952519008, 49.99623891285488, 49.57371200834002, 52.24632964815412, 48.06160681588309, 48.521250997270855, 50.68796682357788, 51.62246131896973, 48.74394771030971, 50.71827139173235, 51.902630056653706, 54.795286723545615, 52.26770230701992, 54.96530566896711, 53.42370537349156, 56.942818573543, 57.12341267721993, 51.656587396349224, 54.99095841816494, 53.038806438446045, 36.601578099387034, 38.20668840408325, 14.626157794679914, 0.887947101678167, 1.1500523686408997, 9.031854782785688, 62.64135932922363, 50.53882721492222, 61.52380411965506, 52.56976481846401, 54.647519384111675, 50.59959268569946, 67.0883731842041, 28.85237554141453, 51.76073047092983, 31.24430853979928, 48.49734572001866, 42.62632983071463, 25.22956395149231, 45.752564089638845, 2.4505647208009447, 0.12040886176483971, 0.017512569835941707, 0.035387989665780745, 0.049134793624814065, 0.053194617919091663, 0.00873195774121476, 0.005014371243305504, 0.021537598854463016, 0.04656350552769644, 0.06422530048127685, 0.11246601226074354, 0.09639902905161891, 0.1872116792947054, 0.1068953008257917, 0.11010907337601696, 0.14030015654861927, 0.0881169798917004, 0.13689081663531916, 0.15748221028063977, 0.1593478965972151, 0.2698191244687353, 0.4098544216581753, 12.092043808528356, 76.39006560189384, 49.45616238457816, 54.585048130580354, 37.787020683288574, 63.28564493996756, 25.449759313038417, 31.575883524758474, 73.23251233782086, 59.74891458238874, 73.0909844807216, 57.6576874596732, 68.70493412017822, 54.39251702172415, 60.55161912100655, 1.1233209116118295, 5.321168891021183, 0.7163876646331379, 3.7456500955990384, 53.204281261989046, 51.42850930350167, 58.69871520996094, 61.787245069231304, 66.12627002171108, 58.76079041617257, 63.12433556147984, 60.1883464540754, 61.34754916599819, 55.71285540716988, 55.623400824410574, 55.92256941114153, 55.81781142098563, 56.4098813193185, 59.465900557381765, 53.103660924094065, 57.1422700881958, 57.41759245736258, 58.2803989137922, 57.628272260938374, 57.03718900680542, 54.36889662061419, 56.98030063084194, 55.53680542537144, 49.9305089541844, 49.27144105093819, 50.9533428464617, 49.578349930899485, 52.195232595716206, 47.61839859826224, 44.43365355900356, 45.30117089407784, 43.395227909088135, 53.287065574101035, 56.46270499910627, 53.02260323933193, 51.97937985828945, 47.60291106360299, 48.63529872894287, 46.1631053515843, 49.69589955466134, 51.605076926095144, 50.75499956948416, 55.442997796194895, 54.33800492967878, 56.09759105954851, 56.31777252469744, 55.265488692692344, 56.193250383649556, 54.12920461382185, 53.58426087243216, 52.7914331981114, 45.68346078055245, 44.00836821964809, 48.38806792667934, 55.3780460357666, 58.28203868865967, 50.01171602521624, 55.58628354753767, 53.9746801512582, 51.37655414853777, 43.65675115585327, 48.5129201071603, 58.06577600751604, 55.116512366703574, 55.02108580725533, 55.46977962766375, 53.408405440194265, 55.12423528943743, 53.58727639062064, 55.43994058881487, 51.47810901914324, 48.237903458731516, 47.01538528714861, 42.698219367435996, 44.612013816833496, 47.69102464403425, 51.067668506077354, 51.748644079480854, 52.40054144178118, 50.852809361049104, 51.99542324883597, 51.35635226113455, 48.236812591552734, 42.383855070386616, 42.057661465236116, 44.590248584747314, 50.68098388399397, 45.09113032477242, 45.58263199669974, 49.46582038061959, 52.530948707035606, 51.65904011045183, 46.65978690556118, 54.34830215999058, 51.60611915588379, 52.07908650806972, 54.32321221487862, 48.87190226146153, 50.27680022375924, 54.3942505972726, 52.0678061076573, 51.9822564125061, 53.37597124917166, 53.42143331255232, 57.54143020084926, 52.738856179373606, 55.341654845646445, 54.427129473005024, 59.28431633540562, 59.119935853140696, 57.76531852994646, 54.37873526981899, 54.11569731576102, 39.54535266331264, 45.29477507727486, 18.409867082323345, 0.708761636699949, 1.510832586458751, 8.91947375025068, 66.90265478406633, 53.88565288271223, 64.44467394692558, 56.3317905153547, 60.35053130558559, 55.21835558755057, 70.73532281603131, 35.0048577444894, 57.74425854001726, 42.30970042092459, 50.91512428011213, 51.4799815586635, 36.75277784892491, 62.13962990897042, 8.188721282141548, 0.2941700635211808, 0.14313640578516892, 0.11747201292642526, 0.1297552338136094, 0.21681660999144825, 0.14111635275185108, 0.19519192964902946, 0.08224889369947569, 0.1406472543520587], [0.03013387249250497, 0.03908366796427539, 0.02236788483735706, 0.10664566779243094, 0.028075772304353968, 0.04983464821374842, 0.058819242353950224, 0.0514411579019257, 0.037040018875684054, 0.041518913182829104, 0.01338172921844359, 0.03612294147855469, 0.045707618418548784, 0.1905931042773383, 28.92865112849644, 41.52613122122628, 37.22486972808838, 26.97736246245248, 32.290259088788716, 38.63164370400565, 14.178003328187124, 63.430653844560894, 52.76044423239571, 55.28179611478533, 52.25048119681222, 54.65952934537615, 46.77030495234898, 59.612646511622835, 19.415676151003154, 1.8940761131899697, 0.3946525773831776, 0.2539927837039743, 14.116794041224889, 33.145227977207725, 46.28458418164934, 55.35222652980259, 54.00704138619559, 58.185288497379844, 54.69114712306431, 54.45298024586269, 52.736188071114675, 50.00984001159668, 48.250983442579, 45.48706647327968, 50.76745768955776, 53.749016557421, 50.713609150477815, 48.18130343300955, 46.71179417201451, 50.66936649594988, 54.688440799713135, 54.63389049257551, 52.77015086582729, 53.70874827248709, 52.72583178111485, 52.02917412349156, 50.18775905881609, 47.14862046922956, 45.11553239822388, 43.82039860316685, 45.132902894701274, 45.53803150994437, 41.81571476800101, 41.20549270084926, 39.66966635840279, 41.558673109327046, 50.250678471156526, 49.12574080058506, 43.286478178841726, 39.64753287179129, 39.061945642743794, 42.815286091395784, 43.65374953406197, 45.5410852432251, 46.35925647190639, 48.66281359536307, 48.03587416240147, 48.44071442740304, 49.49701084409441, 50.02326740537371, 49.711074420383994, 49.7797087260655, 47.47690200805664, 43.390544823237825, 38.67642831802368, 40.639961447034565, 42.71848726272583, 50.22511952263968, 48.572549547467915, 49.92653805868966, 51.07010384968349, 48.107232161930625, 43.7747072492327, 39.47691638129098, 39.65230975832258, 46.366350582667756, 53.03579786845616, 51.568539823804585, 51.76613964353289, 48.693114689418245, 50.002870968409944, 49.80321795599801, 48.97666719981602, 48.91311550140381, 44.76366867337908, 42.52903767994472, 40.02091864177159, 37.30724062238421, 41.51667124884469, 46.99822671072823, 46.83242532185146, 46.484591552189414, 48.04577187129429, 48.62556082861764, 45.95542369570051, 38.577781268528526, 38.496591567993164, 39.85759081159319, 43.03051349094936, 42.40378597804478, 43.48776054382324, 43.60841253825596, 43.30900771277291, 46.71600130626133, 46.95727750233242, 43.54713290078299, 46.85855054855347, 50.4450751713344, 50.58617918831961, 47.187492166246685, 47.25400379725865, 46.31485053471157, 50.63816908427647, 49.26453801563808, 53.003374099731445, 51.03967768805367, 50.54140499659947, 52.71496479851859, 51.58307892935616, 52.42451272691999, 50.1355641910008, 46.57393843787057, 49.026784556252615, 60.16551467350551, 53.68127509525844, 45.02438245500837, 34.795755181993755, 23.590548174721853, 1.4625324010849, 0.10186580927776438, 0.7141378053597042, 29.30651501246861, 58.74203722817557, 44.5037122453962, 58.63354805537632, 44.93385437556675, 50.7877915927342, 41.526367459978374, 54.625646454947336, 38.820214339665, 51.4121219771249, 27.94211288860866, 31.571742398398264, 23.808639969144547, 23.477596521377563, 20.219231843948364, 0.2501195972519261, 0.10922776495239564, 0.08189904104386057, 0.04254892594846232, 0.03753507463261485, 0.05257503741553851, 0.0301557450688311, 0.020753244603318826, 0.028463153035512993, 0.09551010067973818, 0.01253889627488596, 0.03025918433974896, 0.0676501856318542, 0.020443859776215892, 0.05555513268336654, 0.04072048441906061, 0.027395199984312057, 0.03180081929479327, 0.03473583948133247, 0.06060659858797278, 0.018000360179160322, 0.07770318404904433, 0.03584973613864609, 0.815087694142546, 37.7408881187439, 47.919453620910645, 37.0177196093968, 37.52278763907296, 44.89920718329293, 35.448628766196116, 19.033822263990128, 70.61637660435268, 61.21322659083775, 60.944331305367605, 57.78202894755772, 59.556164605276926, 50.9139917237418, 65.1266257422311, 24.022569792611257, 1.0591290018388202, 1.4934306059564864, 0.05224699626809784, 18.440909896578106, 37.7079119682312, 51.029957158224924, 56.59839289528983, 57.59632444381714, 58.514928409031455, 57.84364557266235, 55.78496381214687, 53.55076360702515, 51.62125928061349, 49.27964687347412, 49.03820044653756, 56.094693660736084, 57.18559558050973, 52.37868588311331, 49.53835957390921, 48.194407735552105, 53.298599583762034, 56.301235812050955, 56.44540398461478, 56.60757146562849, 56.33223172596523, 54.80113363265991, 54.22599649429321, 50.94222225461687, 49.06857449667794, 47.05599055971418, 44.96114689963204, 48.118199893406455, 47.9047303880964, 42.59733847209385, 44.22245611463274, 41.60740777424404, 43.12451914378575, 51.61015953336443, 52.55283900669643, 47.017164025987896, 42.843078885759624, 43.04685912813459, 44.03914526530674, 45.6096396446228, 47.49074976784842, 49.75262117385864, 52.68280853543963, 50.17501258850098, 52.67266763959612, 53.31121056420462, 52.20510598591396, 52.8951906476702, 52.085315568106516, 51.0368914604187, 45.270011697496685, 42.32142203194754, 43.22584124973842, 46.40831075395857, 52.2116824558803, 49.55525759288243, 49.526443413325715, 52.830996240888325, 50.44818101610456, 45.66596521650042, 43.399230071476524, 41.00549922670637, 50.76908009392874, 53.55457469395229, 54.95346941266741, 54.82764795848301, 49.8557984488351, 52.082004751477925, 52.00390005111694, 50.63924605505807, 54.30379894801548, 47.93315894263131, 45.34709848676409, 42.97169004167829, 39.49710437229702, 43.24697766985212, 49.303197792598176, 48.70425612585885, 48.81461088997977, 49.33737250736782, 49.8089154788426, 45.84007665089199, 40.3647016116551, 41.058969088963096, 41.08112689426967, 44.81699957166399, 44.42458268574306, 45.32929720197405, 43.886295318603516, 44.57480273927961, 46.47190414156233, 47.87669093268258, 47.398957116263254, 48.50475249971662, 52.20416450500488, 52.91455527714321, 47.79149212156023, 49.700544425419395, 49.230137484414236, 53.167320319584434, 51.10024513517107, 53.035530362810405, 55.06991079875401, 53.34211267743792, 55.70742538997105, 54.00660364968436, 54.60094560895647, 52.22637789590018, 48.713035174778526, 49.69843217304775, 59.812045914786204, 56.985115732465474, 48.682987689971924, 38.29950244086129, 26.465632847377233, 1.1428150598491942, 0.44821526323046, 0.46003186915602, 35.45235994883946, 62.28797394888741, 50.714946678706575, 63.6564633505685, 50.00594902038574, 52.88113791601998, 44.83724314825875, 58.76816245487758, 44.842152050563264, 53.95525298799787, 37.164906774248394, 39.978941099984304, 25.871084179197037, 33.00214719772339, 30.909044061388286, 0.5159751272627285, 0.059272870155317445, 0.050623265361147265, 0.022140607836523225, 0.027366474204297577, 0.07761760721249239, 0.036086572001555135, 0.03001696090879185, 0.0999931272651468, 0.04511884001216718, 0.14694765556071485, 0.10800803718822342, 0.16889031098357268, 0.1556569239390748, 0.17539039147751673, 0.20732200518250465, 0.10435322366122689, 0.16586233489215374, 0.08167929747807127, 0.1371885985136032, 0.07446823442088706, 0.13662685294236454, 0.16359173958855017, 1.5245712378195353, 55.03846672603062, 54.74909509931292, 54.633438859667095, 40.84389802387783, 47.93243285587856, 47.1425963810512, 19.818501438413346, 75.4121344430106, 64.20403003692627, 66.2690555027553, 65.05102239336286, 64.89475045885358, 56.36975547245571, 68.83409418378557, 25.143529619489396, 7.521125333649771, 3.0626106900828223, 0.33044042012521196, 23.331314359392437, 46.47973476137434, 52.469481468200684, 57.434017998831614, 58.86126136779785, 62.17979049682617, 58.85245105198452, 58.45761966705322, 56.35721397399902, 54.15164382117135, 50.51423406600952, 51.434363160814556, 57.980566774095806, 58.92307254246303, 53.551600864955354, 50.49612011228289, 49.38287278584072, 54.74322039740426, 58.12256710869925, 57.33128193446568, 57.46880415507725, 57.09178447723389, 57.64675794328962, 55.46132714407784, 54.80214459555489, 51.714316504342214, 48.08511257171631, 46.818984031677246, 49.41103730882917, 49.52251073292324, 46.72838647024972, 47.12053237642561, 42.722333090645925, 44.93259327752249, 53.898896149226594, 54.44429152352469, 49.22284534999302, 45.241089820861816, 45.611835275377544, 47.39435393469674, 48.23523882457188, 50.24971614565168, 52.498511041913716, 57.48197446550642, 52.85673236846924, 56.273887702396934, 55.80416168485369, 55.754336152757915, 55.63071380342756, 54.796718052455354, 52.167147977011545, 46.23110389709473, 45.009711333683555, 46.04659448351179, 49.88706186839512, 55.16924571990967, 51.898975304194856, 53.184489318302695, 55.389618260519846, 51.688736711229595, 48.55436611175537, 46.37027631487165, 43.259369782039094, 52.127727372305735, 57.53173746381487, 56.949408939906526, 58.290237562997, 53.209846769060405, 53.376197065625874, 54.69989837918963, 53.277959959847585, 56.724464484623496, 48.77082681655884, 48.484345640454976, 46.6540025302342, 41.78848130362374, 45.25383629117693, 52.02171870640346, 50.79859604154314, 51.594522612435476, 54.038544518607004, 53.139134952000205, 47.57175881522042, 43.10250377655029, 42.755535057612825, 44.35657024383545, 46.825268677302766, 47.25325686591012, 47.90316356931414, 46.07532181058611, 46.3847633089338, 48.32467603683472, 50.685173647744314, 46.319846289498464, 48.103699002947124, 54.377237933022634, 55.44521427154541, 50.50144938060215, 51.72018773215157, 51.43520736694336, 54.319123200007844, 54.109537737710134, 55.97157505580357, 57.091867855616975, 54.27975818089077, 57.57588284356253, 54.506700243268696, 58.02657427106585, 53.53228834697178, 51.62637315477644, 49.442877428872244, 58.69266332898821, 55.69968857084002, 53.28931679044451, 43.11736249923706, 33.37157596860613, 2.1520735834326064, 0.3231308880661215, 2.0056500690323964, 36.35959666115897, 70.44913346426827, 53.73596089226859, 69.24475356510708, 54.06711898531233, 59.50404616764614, 51.609322275434224, 61.795916421072825, 48.89827414921352, 60.575778007507324, 40.81873164858137, 37.00943040847778, 34.91443041392735, 42.31545352935791, 45.641180992126465, 1.6411951226847512, 0.30056137485163553, 0.203947284125856, 0.10296222687299762, 0.09608718114239828, 0.18180436587759427, 0.1430830865034035, 0.10814677724348647, 0.26326548042041914, 0.14276649563440255], [0.04313803683700306, 0.050304431933909655, 0.027952984607379352, 0.04272708210295864, 0.033698420505970716, 0.04572605760768056, 0.0862792017204421, 0.002195165110086756, 0.02721950351925833, 0.015132387734151312, 0.041638386236237626, 0.06970730024789061, 0.03525206892352019, 0.26463324416960987, 17.904613188334874, 49.91449335643223, 33.630121912275044, 23.688088723591395, 25.795043093817576, 53.81415591921125, 19.51599771635873, 35.11823150089809, 62.56397724151611, 49.51781375067574, 55.81804418563843, 52.15264013835362, 53.21514824458531, 45.46752119064331, 55.78920221328735, 2.4825631294931685, 2.5213175756590704, 0.16481599318129675, 3.6974730236189703, 28.766857113157, 48.70333548954555, 60.160192353384836, 54.280647550310405, 58.41966165815081, 55.707001549857004, 56.64959764480591, 51.68722200393677, 51.59390074866158, 48.743437017713276, 51.76078258241926, 52.344514642442974, 51.80677618299212, 49.585082735334126, 52.032550948006765, 45.88061244147164, 44.49200800486973, 50.84856401171003, 51.98783581597464, 54.51593439919608, 52.25682142802647, 54.41606099264962, 51.87015765053885, 53.52438824517386, 49.78217881066458, 45.08332749775478, 46.76269320079258, 46.45623942783901, 45.12318583897182, 43.34580189841134, 39.983228138514924, 41.70547464915684, 38.66682243347168, 43.68229968207223, 44.32721063068935, 43.326951435634065, 40.32715007237026, 41.2514202935355, 44.692901270730154, 42.29887860161917, 46.940587929316926, 48.112370354788645, 49.285240173339844, 50.56374345506941, 49.02750369480678, 48.573129722050254, 50.657516343253, 49.27583926064627, 47.50919723510742, 42.70486879348755, 38.00562490735735, 37.91124405179705, 39.796637739454, 44.04500607081822, 49.16958393369402, 46.65205703462873, 46.87237398965018, 49.074067047664094, 48.08826010567801, 41.50420618057251, 38.847162927900044, 38.77744817733765, 42.71580525806972, 47.777838911329, 48.30137872695923, 51.97621495383126, 53.051830836704795, 51.6105694770813, 50.30974163327898, 46.68963984080723, 48.42402138028826, 49.49032320295061, 44.684327193668906, 44.57017871311733, 36.8997391973223, 35.946821553366526, 41.128343377794536, 45.65603276661464, 45.80708312988281, 48.70769548416138, 44.82171739850725, 38.35885395322527, 36.868646008627756, 37.5372051511492, 40.87609945024763, 43.3701171193804, 40.834288665226524, 44.750852721078054, 42.81235047749111, 44.762351989746094, 44.13904299054827, 50.93472862243652, 47.04225049700056, 48.83657414572579, 51.20711537769863, 48.7863039289202, 50.978359835488455, 45.59280068533761, 43.79351602281843, 51.33658116204398, 47.62661484309605, 53.10838222503662, 51.09895971843174, 50.8734142439706, 51.88900463921683, 51.27264731270926, 51.685908794403076, 51.7210110936846, 51.62389612197876, 58.42004380907331, 48.13641807011196, 45.80862562997, 38.77752808162144, 31.046208449772426, 8.525800108909607, 0.11547516579074518, 0.7911056610090392, 4.378621433462415, 56.39382750647408, 47.598398208618164, 56.716446263449534, 48.23507554190499, 50.282216344560894, 54.111184460776194, 55.74400765555245, 47.273149558476035, 35.73414414269583, 50.416591031210764, 30.325155666896276, 18.32028569493975, 21.79049747330802, 33.49214111055647, 13.159230657986232, 0.0940970243620021, 0.032029343103723865, 0.04133807002965893, 0.014304115303925105, 0.01990624630291547, 0.02628163411282003, 0.014124738634563982, 0.0397980533806341, 0.017941739842561737, 0.017511401059372083, 0.045512088374899964, 0.047194298822432756, 0.03296878840774298, 0.03612579132563301, 0.035271610732057264, 0.013301413572792496, 0.12257345632783004, 0.015386373569656695, 0.021675124332042675, 0.035400410249297104, 0.08666889795235225, 0.03628290950187615, 0.03213001734444073, 0.31787666571991785, 21.672852311815532, 60.27327428545271, 34.41290249143328, 27.19614212853568, 37.33819832120623, 58.40142958504813, 23.674708230154856, 42.30675785882132, 65.78994941711426, 55.1541542325701, 62.51128905160086, 55.68247440883091, 60.44964041028704, 48.45778962544033, 63.412116050720215, 2.9611520086015974, 1.5286305057150977, 0.3105726976479803, 4.728799785886492, 36.421876839229036, 51.32902847017561, 61.21793746948242, 54.68330608095442, 60.34024102347237, 55.427211488996235, 55.64099018914359, 52.67686782564436, 53.65695292609078, 49.53025450025286, 54.10273197719029, 54.816200801304404, 52.8460008757455, 51.819328103746685, 52.95543152945382, 46.81510693686349, 45.549846921648296, 53.00174127306257, 52.73367282322475, 56.638077531542095, 54.21849243981497, 55.51336915152413, 53.69568565913609, 54.57337515694754, 50.44754178183419, 48.26694345474243, 48.18158483505249, 46.28377819061279, 46.72583300726754, 45.99181488582066, 42.062052726745605, 44.00700289862496, 39.77908311571394, 45.926817962101524, 47.45117630277361, 46.24829374040876, 44.11493274143764, 44.86673477717808, 46.798316614968435, 46.19194732393537, 49.41369846888951, 51.26884664808001, 50.71475212914603, 53.07354048320225, 52.515686988830566, 52.0921630178179, 53.622225829533164, 50.397476536887034, 51.63486385345459, 47.291089807237896, 41.40550701958792, 39.31839670453753, 42.93822404316494, 44.88145453589303, 50.95328378677368, 50.73592676435198, 49.65983145577567, 51.92978709084647, 51.09125764029366, 45.52635506221226, 41.28106478282383, 41.25016614368984, 45.270088127681184, 51.05977187837873, 51.84242738996233, 53.56092187336513, 54.09461995533535, 52.399047579084126, 53.12086466380528, 49.53062970297677, 51.247988155909944, 49.70659283229283, 47.70085287094116, 47.003924233572825, 38.68976885931832, 38.66085045678275, 43.097435065678184, 46.32580784388951, 49.00582531520298, 50.96545008250645, 47.93079655511038, 39.68158599308559, 39.88524464198521, 39.05897528784615, 42.32625797816685, 44.31784793308803, 41.73301730837141, 45.53331020900181, 44.58706978389195, 46.83287695475987, 47.76849358422415, 51.47579526901245, 48.7322677884783, 49.00217056274414, 52.864601203373496, 49.60758795057024, 53.58096742630005, 47.822356019701274, 47.37955774579729, 52.916076932634624, 50.488220010484966, 53.55732618059431, 52.48841878346035, 53.74482331957136, 51.727941921779085, 52.584345613207134, 52.307411261967246, 53.96234015056065, 51.36741379329136, 59.141287667410715, 51.63269601549421, 47.804700647081646, 41.11182056154524, 33.98942368371146, 9.703056846346174, 0.27807879554373877, 1.2241879105567932, 6.934486321040562, 61.932038579668315, 52.06031594957624, 60.105635098048616, 50.76122168132237, 55.8794002532959, 58.5534005846296, 57.71368299211775, 52.93101903370449, 40.403309277125764, 55.214964866638184, 37.45282622746059, 22.15796685218811, 27.5945657321385, 45.066943645477295, 20.298109531402588, 0.07298688390957457, 0.038387847266026905, 0.053011610239212, 0.0403824179167194, 0.008427378638381404, 0.02193395999659385, 0.021900397958233953, 0.049937541263976266, 0.02203608290957553, 0.020442234684846232, 0.12242496572434902, 0.07470311610294239, 0.1555598120072058, 0.1794758779661996, 0.07920233253389597, 0.11869436662111964, 0.23695080674120358, 0.10555057334048407, 0.14310010416167124, 0.13658960136984075, 0.19957720647965158, 0.19601652611579212, 0.17471191074166978, 0.5013376612748418, 33.12589808872768, 71.05165345328194, 50.44763905661446, 32.15756586619786, 38.95801101412092, 68.43307890210832, 25.113471712384904, 44.89973177228655, 76.0041070665632, 59.89555631365095, 67.36448069981166, 61.595127378191265, 65.35357475280762, 53.5162136895316, 69.60984666006905, 4.20662659406662, 7.635480523109436, 0.20635218865105084, 6.568574207169669, 46.370637621198384, 52.95385776247297, 61.81164714268276, 54.512401240212576, 62.299459321158274, 55.555287633623394, 57.41528912952968, 51.3912912777492, 54.6631041935512, 49.520363739558626, 55.40440402712141, 54.375292437417166, 54.84778036390032, 52.86254801068987, 55.33843782969883, 45.44199003492083, 45.532886368887766, 54.16947637285505, 55.83370195116316, 55.591803891318186, 56.46254171643938, 57.1519524029323, 55.233051027570454, 56.87368399756295, 55.15904229027884, 50.388697487967356, 51.32993173599243, 49.328426701681956, 49.48712355749947, 46.881118297576904, 44.77259710856846, 44.41645676749093, 41.97940737860543, 47.647945812770296, 50.39531217302595, 49.76509666442871, 46.101721491132466, 48.98870842797415, 50.38004698072161, 47.54794039045061, 53.664314542497905, 54.8328834261213, 54.277027538844514, 58.66232749394008, 55.57938398633684, 54.23962538582938, 56.07943194253104, 54.01068224225725, 52.5537804876055, 49.053086962018696, 43.0467722756522, 42.22456761768886, 44.95316341945103, 48.026970045907156, 52.96538829803467, 52.742688110896516, 51.108867849622456, 53.2920126914978, 53.437157085963655, 47.9945775440761, 43.39219849450247, 43.14044788905552, 46.20272397994995, 52.44881752559117, 53.0748085294451, 55.92911114011492, 57.690476008823936, 57.51907089778355, 56.35840559005737, 53.46497419902256, 51.852849687848774, 52.64877278464181, 49.54809052603585, 50.25539282390049, 40.79065745217459, 39.846480642046245, 43.19947631018502, 50.34633084705898, 52.297499656677246, 53.252981185913086, 48.92098433630807, 40.74272877829415, 41.52728462219238, 41.649017061506, 46.330129623413086, 45.98016970498221, 43.44096095221383, 49.94510017122541, 46.54931402206421, 48.81138345173427, 49.456221444266184, 53.79885598591396, 46.58955104010445, 51.22141129629952, 55.685271058763774, 53.608645575387136, 55.145413398742676, 50.183767318725586, 49.10825913293021, 56.42657784053257, 51.28485877173287, 57.10359294073922, 54.10452461242676, 52.76994936806815, 53.50017029898507, 54.91828720910208, 53.50762224197388, 55.71598209653582, 49.918835980551584, 59.676910400390625, 56.562675680433, 53.838467666081016, 43.01829160962786, 40.87791640417916, 13.359076482909066, 0.3479342742690018, 1.54002403148583, 6.356943368911743, 66.54030622754777, 56.693086419786724, 65.63929162706647, 55.76877450942993, 61.040681975228445, 62.11702047075544, 64.85158130100795, 57.61651938302176, 44.82796730313982, 61.39179529462542, 40.95201894215175, 30.21016298021589, 37.37559700012207, 52.66034153529576, 35.11111307144165, 0.26900914364627426, 0.1899091816906418, 0.12770319463951246, 0.1246643348463944, 0.08292528454746519, 0.08015258690076214, 0.0764273889362812, 0.1109493032896093, 0.10873573885432311, 0.21405100982104028], [0.017263527128047178, 0.00631716229586995, 0.05783026399356978, 0.11142740584909916, 0.0403411528095603, 0.0317438189605517, 0.033834310714155436, 0.09238968097737857, 0.03537739094878946, 0.0590375881376011, 0.07802827017647879, 0.041763653978705406, 0.11306652253759758, 0.2288647320653711, 4.71398492370333, 45.44189623423985, 40.134942054748535, 37.05266210011074, 21.876333781651088, 42.458885192871094, 32.654893602643696, 23.75803450175694, 71.28268800462995, 47.679966585976736, 61.94475378308977, 49.10074118205479, 56.13145310538155, 46.34189639772688, 59.561737060546875, 20.117032527923584, 1.8935367592743464, 0.17768210279090063, 0.4275820446865899, 16.485516582216533, 42.41783176149641, 56.37714835575649, 56.05729150772095, 53.52359962463379, 49.79021092823574, 52.90582833971296, 52.16020672661917, 52.622772625514436, 55.351816586085725, 53.49575471878052, 49.83248029436384, 51.2912198475429, 55.92890616825649, 54.358484745025635, 49.159804344177246, 40.91031238010952, 51.05626998628889, 47.77177313395909, 54.59642233167376, 55.19456148147583, 52.75555270058768, 53.47528185163225, 51.33635534558977, 50.48579856327602, 49.170702593667166, 45.047700609479634, 44.51070213317871, 43.51928104673113, 46.64680767059326, 41.243336064474924, 41.61846930640084, 38.24742916652134, 40.13921519688198, 38.96873555864607, 40.804244654519216, 39.5626015663147, 45.30295310701643, 44.348923751286094, 42.764341899326865, 47.60467938014439, 50.19581549508231, 46.95113182067871, 48.83726896558489, 48.410013811928884, 49.15739679336548, 50.523197242191856, 47.357358251299175, 39.220656394958496, 36.01133557728359, 36.35753304617745, 37.94251094545637, 39.0239702633449, 43.61705609730312, 45.925414425986155, 44.28069938932146, 45.36024100439889, 47.442261763981406, 44.82949938092913, 43.02713666643415, 38.72619826453072, 38.61395011629377, 38.49780750274658, 44.17420782361712, 49.613011019570486, 50.95844282422747, 48.49518830435616, 51.51959671292986, 50.1433288029262, 49.73344414574759, 49.15608705793108, 50.29601199286324, 48.45802239009312, 46.18409238542829, 39.223390511104036, 37.09730775015694, 40.38124527250017, 42.26077468054635, 45.51309789930071, 42.36759975978306, 39.12973574229649, 38.502629552568706, 37.317735876355854, 38.566771847861155, 41.51315893445696, 39.8895594733102, 40.08290352140154, 39.75515699386597, 42.56447696685791, 42.7547151701791, 44.43005786623274, 47.026519775390625, 49.17154679979597, 46.652084827423096, 49.62472915649414, 51.59343869345528, 48.75503008706229, 47.61894055775234, 42.86678613935198, 46.3946019581386, 51.32854904447283, 50.51149647576468, 49.48021704810006, 49.834206921713694, 52.76466873713902, 48.631383419036865, 51.088252544403076, 51.618129117148264, 49.49677460534232, 43.65053251811436, 45.21252925055367, 47.71451997756958, 32.19265079498291, 15.366398027965001, 0.16013511935515062, 0.09732291554766041, 1.7079065144062042, 15.747685636792864, 55.68722350256783, 46.768724237169536, 53.10278197697231, 48.95633329663958, 59.437190600803916, 50.63553919110979, 56.843059812273296, 26.972238165991648, 44.66860689435686, 46.27043764931815, 21.949942997523717, 45.209815979003906, 36.49463490077427, 36.18269552503313, 4.587443896702357, 0.2011759571198906, 0.013176842176887606, 0.062424896018845696, 0.023345341673120856, 0.027828008634969592, 0.02412289361070309, 0.07426862298910107, 0.0625107917668564, 0.06934121703462941, 0.0781980057113937, 0.06187870247023446, 0.03433259969045009, 0.04736644994201405, 0.09422239727739777, 0.05352135288662144, 0.04640802262084825, 0.057195087362612994, 0.04441400158352085, 0.016225512738206556, 0.04012175529663052, 0.034480415151587555, 0.024771204983283366, 0.11399499593036515, 0.26991846199546543, 5.487507896763938, 56.692026819501606, 44.386433601379395, 38.06103679112026, 34.23445190702166, 46.527152742658345, 32.87910849707467, 25.488622324807302, 75.07199927738735, 53.722908701215474, 69.01370511736188, 54.121363571711946, 61.402064732142854, 52.47926105771746, 63.73023932320731, 25.004732404436382, 0.6833808443375996, 1.9345561010496957, 0.3423788366573197, 20.905880621501378, 44.83833054133824, 57.700193064553396, 58.86857087271554, 56.5758181980678, 52.05603238514492, 54.730817862919395, 52.39464936937605, 52.81915998458862, 54.771294593811035, 53.772070680345806, 52.64343309402466, 52.64446142741612, 56.3709123475211, 55.11682503564017, 50.83364275523594, 43.085275718144004, 49.24512822287423, 50.30015311922346, 55.007404804229736, 57.01911326817104, 54.52517550332205, 54.51347473689488, 53.879705224718364, 51.65504837036133, 50.425981521606445, 46.473710673195974, 47.14012629645211, 46.00827169418335, 47.9894254548209, 43.378163133348735, 42.52270787102835, 40.84093114307949, 42.663429737091064, 41.09880658558437, 42.18392413003104, 42.26763602665493, 46.736661774771555, 48.09870672225952, 47.428841318402974, 50.439085824149, 52.13499518803188, 50.323902062007356, 51.79908105305263, 53.3979275567191, 51.695570264543804, 51.83086558750698, 51.04640701838902, 41.65528086253575, 38.23944221224104, 39.55367660522461, 40.78159005301339, 41.131411007472444, 45.0687814440046, 48.84384890965053, 48.65016439982823, 47.32764775412423, 49.8431145123073, 46.50898667744228, 44.54677023206438, 41.116215297154014, 41.58055298668997, 41.298310211726594, 47.33125039509365, 50.46614210946219, 52.532758712768555, 52.55471849441528, 55.19830656051636, 53.031149523598806, 52.93495518820626, 52.32471922465733, 53.54192897251674, 51.30081530979702, 48.43449578966413, 39.94818837302071, 39.72897270747593, 42.515172549656455, 44.49828570229666, 47.86728654588972, 44.83298390252249, 40.54843977519444, 38.787411894117085, 38.55576590129307, 39.88905920301165, 43.62732206072126, 42.30418702534267, 41.44340249470302, 44.13924101420811, 43.90686198643276, 44.72320931298392, 46.960352080208914, 48.29146017347063, 52.785864216940745, 47.35740688868931, 50.603865827832905, 54.04763971056257, 50.943226269313264, 51.27922030857631, 46.18355042593819, 48.77128539766584, 53.59324141911098, 53.595395360674175, 52.44187280109951, 51.36681972231184, 53.597987038748606, 51.7211674281529, 51.73621722630092, 54.613785879952566, 52.91598660605294, 47.18982328687395, 47.98874453135899, 48.84796919141497, 35.65532030378069, 18.43448976108006, 0.18027938556458267, 0.932080864906311, 1.511387573821204, 20.037060499191284, 58.772477286202566, 51.27375207628523, 58.50023296901158, 53.88686186926705, 62.849582944597515, 53.39470706667219, 61.72218908582415, 32.02306958607265, 47.28690004348755, 51.996858051845, 30.86973810195923, 53.2711819921221, 40.45015055792672, 45.94892018181937, 8.409555009433202, 0.45386710709759165, 0.022997404182595865, 0.0683159234800509, 0.021421299648604224, 0.06084617573235716, 0.029994983159537827, 0.0539497561486704, 0.02143023256212473, 0.05414576795218246, 0.012508691288530827, 0.13447871963892663, 0.16409301411892685, 0.1311931580837284, 0.16823089708174976, 0.177111007007105, 0.1652784419379064, 0.21054242737591267, 0.19497155504567282, 0.11105140245386533, 0.19004231026130064, 0.19161193817853928, 0.10219367061342512, 0.30438703671097755, 0.39105414333088057, 10.367106607982091, 69.8394637789045, 53.964782442365376, 51.888907364436555, 35.9300833429609, 58.04950680051531, 39.63595369883946, 29.881065028054373, 81.53675610678536, 58.6749176297869, 73.7083180291312, 58.65418420519148, 66.36191122872489, 55.861508641924175, 71.40912437438965, 26.487311226981028, 6.440730827195304, 2.772108461175646, 0.7439936718770436, 28.54152355875288, 48.97678184509277, 58.93286255427769, 58.323429107666016, 57.1919219153268, 51.929262501852854, 56.541574001312256, 53.2628823689052, 52.994782652173726, 56.02667427062988, 54.776766300201416, 52.61155823298863, 53.633805002485005, 58.35639830998012, 56.558166299547466, 49.21944420678275, 43.15249606541225, 51.36399875368391, 49.92313691547939, 58.816348212105886, 57.97929177965437, 57.28558015823364, 58.95959922245571, 55.99997581754412, 55.85532127107893, 53.94861398424421, 49.82976007461548, 51.25498499189104, 47.930824347904746, 51.25713198525565, 44.7503593989781, 44.42387049538748, 42.60494327545166, 45.80968523025513, 44.88234043121338, 45.02576167242867, 44.29870912006923, 51.53314222608294, 50.94743340356009, 49.25195830208914, 54.4296030317034, 56.24182871409825, 54.08941922869001, 54.717063903808594, 54.75078003747122, 54.28523336138044, 54.96115064620972, 51.93796164648873, 40.991557666233604, 39.822092464991975, 41.4933739389692, 44.64147070475987, 43.99270698002407, 47.31425857543945, 50.75325557163784, 50.745567389896934, 47.26793146133423, 52.109939983912874, 50.422260761260986, 48.46842384338379, 43.58091156823294, 44.17759159633091, 42.71072959899902, 49.00737476348877, 52.17750079291207, 55.11854471479143, 53.63861663000924, 57.35109124864851, 54.95073182242257, 55.71658311571394, 53.64160088130406, 56.194191864558626, 53.52555206843785, 50.601343631744385, 44.717803614480154, 41.449284144810264, 44.25043303625924, 45.544736521584646, 49.85210200718471, 45.8284592628479, 42.92263923372541, 40.86142485482352, 39.48425715310233, 42.47008568899972, 46.65356131962368, 43.58637285232544, 43.68437371935163, 45.98467561176845, 45.41114003317696, 47.61509472983224, 49.17638274601528, 50.911653654915945, 51.54032318932669, 49.83597176415579, 53.276768343789236, 55.84740727288382, 53.477119650159565, 53.16491971697126, 48.661892959049766, 51.13971437726702, 55.905886786324636, 56.34217112404959, 55.875453676496235, 53.65768248694283, 57.600368295397075, 54.16744749886649, 55.083817618233816, 56.71799223763602, 55.50415931429182, 52.30849518094744, 49.432493346078054, 50.79580633980887, 41.961175305502756, 25.749956233160837, 0.6447111879076276, 0.7196117373449462, 6.166848472186497, 22.060796294893535, 68.51413658687046, 55.889384814671104, 64.16561344691685, 58.565205574035645, 68.19615227835519, 59.96961716243199, 68.54307583400181, 35.468003817967, 53.263212408338276, 58.56374645233154, 34.71055637087141, 58.27218266895839, 47.211067404065815, 58.132801805223735, 17.870933532714844, 0.5018027563180242, 0.16684660421950476, 0.15513567333774908, 0.17458537753139222, 0.11971945661519255, 0.13896526103573187, 0.2661342721964632, 0.12168912163802556, 0.21092453758631433, 0.1604091389370816], [0.0573830958455801, 0.01798317288713796, 0.07438269151108605, 0.022496777653161968, 0.0375515155361167, 0.03964689613452979, 0.08403478429785796, 0.016942580064226474, 0.04438172706535884, 0.025982905678184967, 0.08350214787891932, 0.03674289856904319, 0.09298369767410414, 0.025750371727294157, 0.6931944148881095, 31.899183205195836, 50.98500231334141, 33.74222067424229, 20.541471924100602, 29.47655827658517, 49.90118408203125, 23.18094665663583, 45.4722946030753, 62.96715341295515, 48.82830578940255, 58.65879780905587, 48.16918577466692, 51.20197718484061, 47.95139101573399, 39.15462418964931, 1.770009079149791, 0.7420248889497348, 0.25151241251400536, 5.62161203793117, 30.703509398869105, 52.2162196295602, 53.55079139981951, 55.004305907658164, 56.147208145686555, 53.137439591544016, 54.52297987256731, 53.03174706867763, 53.78570999417986, 52.05674457550049, 55.06090593338013, 54.605500153132844, 54.140992232731406, 52.58562408174787, 52.86400713239397, 54.00151409421648, 48.09270000457764, 51.302990095955984, 49.32340662819998, 50.580419131687705, 55.521401269095286, 54.859567982809885, 55.20560564313616, 52.80501345225743, 50.8869423866272, 46.22396809714181, 42.42788927895682, 43.79107025691441, 44.995863573891775, 43.270716190338135, 39.29030513763428, 36.93027653012957, 38.12707594462803, 38.3848089490618, 37.32741471699306, 36.605274541037424, 45.38704368046352, 47.83409152712141, 45.1115163394383, 48.32933132989066, 48.98337915965489, 49.57673794882638, 49.50102342878069, 49.87494421005249, 49.42609058107649, 46.5777564729963, 37.633086817605154, 37.7122163772583, 35.7084184374128, 36.398715019226074, 36.440494537353516, 37.89104911259243, 43.44432388033186, 46.6161070551191, 42.921464988163535, 43.85814469201224, 45.62275089536394, 43.58719621385847, 40.07004935400826, 37.37661838531494, 37.496596404484336, 35.547140325818745, 39.239906379154746, 44.67176832471575, 51.53557062149048, 51.60760259628296, 50.06337240764073, 50.26380361829485, 49.8704765183585, 48.717350006103516, 50.86285993031093, 48.00439534868513, 49.19129358019148, 43.040282658168245, 39.06541974203927, 39.73913097381592, 38.53499773570469, 39.73539284297398, 38.864929471697124, 37.67061056409563, 38.938736711229595, 38.07348101479666, 39.1182746887207, 41.59976128169468, 40.19724655151367, 40.0112259047372, 43.10292066846575, 44.21102285385132, 44.92622177941458, 46.52455759048462, 47.492101192474365, 47.83833687646048, 52.01989133017403, 52.04139600481306, 50.68566002164568, 48.4310633795602, 49.633171217782156, 46.411663259778706, 46.85379103251866, 46.11685119356428, 45.836738041469026, 46.54273407799857, 48.44087076187134, 51.204349994659424, 49.070818764822825, 48.98500503812517, 52.195159639631, 48.65603215353829, 54.90963670185634, 51.01116575513567, 41.129065990448, 21.798015424183436, 1.1792422937495368, 0.022206262884927646, 0.837004266679287, 0.8743956716997283, 23.599195207868302, 54.70333773749215, 49.94482224328177, 53.464803968157085, 51.57171515056065, 50.88513585499355, 52.41187047958374, 44.825914110456196, 27.268210581370763, 56.885919775281636, 26.459619181496755, 25.451041255678447, 47.27807930537632, 35.26682220186506, 27.561280386788503, 0.6800742074847221, 0.16118401235767774, 0.07991182232009512, 0.08595765754580498, 0.05217011485780988, 0.059991947641330104, 0.028415092400142124, 0.01900259541746761, 0.06878720676260335, 0.04773028041901333, 0.03596292256510683, 0.021772891050204635, 0.06697192202721323, 0.06632780230471066, 0.004999849321653268, 0.041352122489895136, 0.023822584189474583, 0.034731337401483736, 0.02449467821445848, 0.04851056176370808, 0.042441914190671275, 0.08946380405021565, 0.04082182362409575, 0.05147085737969194, 0.028802159308855022, 1.00058956018516, 41.014952250889365, 60.80595793042864, 32.3972543988909, 30.520080430167063, 38.70381811686924, 50.78159032549177, 27.522082124437603, 50.95184898376465, 70.18626921517509, 53.82167387008667, 63.4721554347447, 52.65337249210903, 57.519220284053254, 53.298867089407786, 45.33505031040737, 3.2053970396518707, 4.111256054469517, 0.42055817587035044, 8.132258483341761, 35.021599428994314, 53.5068370955331, 54.27093396868025, 56.70378317151751, 56.86253908702305, 56.174271379198345, 56.00235557556152, 55.55911956514631, 55.38796806335449, 53.6455648286002, 56.43196269444057, 55.128699507032124, 54.77134323120117, 54.334662846156526, 55.40411220278059, 56.097584111349924, 49.35481595993042, 52.26140029089791, 50.14211981637137, 53.01045431409563, 56.267286913735525, 56.35690825326102, 57.15387010574341, 54.003386633736746, 52.28599343981062, 48.19623858588082, 43.18515954698835, 46.00988367625645, 46.918016706194194, 44.42493009567261, 41.16975811549595, 38.374497822352815, 41.66649178096226, 40.01489455359322, 40.98406055995396, 41.30286823000227, 48.86021539143154, 50.58774253300258, 48.075214862823486, 50.956862109048025, 51.72047955649239, 52.58316789354597, 52.041236196245464, 52.70266648701259, 52.07550471169608, 49.28620249884469, 40.76684944970267, 39.57615402766636, 39.714944294520784, 39.11023562295096, 39.0723922593253, 40.5085779598781, 45.803303309849326, 49.53218262536185, 45.879570211683, 47.86604281834194, 49.217769690922324, 46.184384209769114, 42.21634095055716, 39.12970794950213, 39.70860406330654, 37.91774409157889, 42.72112757819039, 47.85271964754377, 53.431730542864116, 52.66249895095825, 52.083404813494, 52.43933323451451, 52.81105491093227, 51.353208201272146, 53.61345025471279, 50.921721594674246, 52.07676580974034, 43.39218807220459, 39.132244041987825, 42.12402023587908, 39.015059198652, 40.62420640672956, 39.98334278379168, 39.35175848007202, 40.05950198854719, 39.83814975193569, 40.94779096330915, 44.31854970114571, 42.100795882088796, 42.70806149074009, 44.93769325528826, 44.93733194896153, 47.42850085667202, 47.83328553608486, 49.523132596697124, 50.06198624202183, 54.10653611591884, 51.28104073660714, 51.11543042319161, 49.90705183574131, 51.28928477423531, 49.68892356327602, 48.715480940682546, 47.69639560154506, 48.673023973192485, 49.5193110874721, 51.67395789282662, 53.29377405984061, 53.044729777744834, 52.03551435470581, 54.60249505724226, 51.379892757960725, 56.7944050516401, 52.31230974197388, 44.27243103299822, 24.063314029148646, 1.1092394100768226, 0.6601539935384477, 0.9300885775259563, 0.897168826844011, 28.310831206185476, 57.00846862792969, 54.638705594199045, 58.841326986040386, 56.17725910459246, 56.3015832219805, 56.566705635615754, 50.31766605377197, 30.334782396044048, 59.6800787789481, 33.97510344641549, 27.303993804114207, 43.57286555426461, 40.49177374158587, 37.180953638894216, 1.124206155538559, 0.21575471625796386, 0.008696718025021255, 0.03322983779279249, 0.03660455206409097, 0.04112842985029731, 0.047809628304094076, 0.057645607473594804, 0.04171995971617954, 0.14378546524260724, 0.041688635147043636, 0.12323531295572009, 0.13283472428364412, 0.13538464531302452, 0.14663861000112124, 0.16353205564830983, 0.10098448049809251, 0.14323469836797031, 0.11024553355361734, 0.16635740761245998, 0.15201233593480928, 0.13394864808235848, 0.11453945242932864, 0.1887332262205226, 0.10597672725894622, 1.5962520028863634, 54.07895524161202, 67.58869212014335, 48.38739047731672, 30.925226415906632, 45.056472710200715, 58.76011644090925, 31.274317809513636, 55.24996641704014, 75.56785052163261, 58.01354987280709, 69.9026437486921, 56.0328095299857, 64.22165761675153, 57.35343279157366, 49.81235136304583, 4.55730174268995, 3.357796221971512, 0.594499976507255, 10.247521162033081, 42.24919203349522, 53.39666298457554, 56.47931119373867, 57.476978710719514, 59.732760020664756, 54.53841182163784, 55.87513753346035, 55.36932257243565, 58.58257607051304, 54.900180203574045, 57.996071679251536, 56.2652302469526, 55.712240491594585, 55.8076114654541, 57.43700572422573, 56.160767555236816, 51.797899859292166, 52.7520021711077, 52.75372185025896, 54.221351623535156, 58.78007166726248, 57.87763268607003, 60.09074510846819, 57.709618295942036, 53.63419757570539, 49.44816500799996, 45.73289026532854, 48.19680833816528, 48.25022608893258, 46.97347722734724, 43.50060428891863, 39.81036043167114, 42.464502811431885, 41.039281368255615, 43.9935233933585, 42.16104023797171, 51.461117199489046, 53.63392659596035, 50.86997488566807, 54.71343347004482, 54.54645088740757, 56.892735958099365, 54.90746886389596, 54.8268906048366, 53.64106934411185, 51.63426978247506, 41.9339348929269, 42.048493317195344, 40.951661109924316, 42.165441921779085, 39.28627518245152, 43.38990558896746, 49.51763309751238, 49.955821241651265, 47.39042125429426, 47.72579690388271, 50.524527822222026, 47.17959901264736, 43.661830289023264, 40.06323664528983, 42.445363998413086, 38.745212009974885, 42.67390067236764, 49.344814028058735, 54.736237457820344, 53.5609427179609, 52.35495431082589, 54.63493619646345, 55.907394545418875, 52.99163164411272, 55.63394124167306, 53.471036502293174, 55.67568254470825, 46.12048857552664, 43.56242935998099, 43.85887425286429, 42.42404692513602, 43.88373490742275, 42.273132051740376, 41.94759157725743, 43.16492986679077, 42.28126491819109, 42.25079359327044, 45.52307898657662, 43.58013684409005, 44.84060607637678, 47.569337368011475, 48.17447682789394, 48.46690913609096, 49.74297360011509, 51.62033864430019, 50.56654357910156, 54.33832107271467, 57.47202117102486, 55.02790546417236, 50.98444298335484, 53.72313799176897, 51.49767862047468, 52.43197161810738, 49.462558201381135, 50.874213286808555, 51.45821632657732, 52.55924871989659, 58.05971370424543, 54.79802431379046, 53.21114955629621, 57.93251650674002, 53.02268314361572, 56.902202878679546, 53.931920937129426, 49.10272141865322, 29.527926308768137, 3.433277977364404, 0.5570051084671701, 2.160631158522197, 3.7336896402495245, 32.17890725816999, 63.488323892865864, 59.550675528390066, 63.12817791530064, 61.34334550585066, 59.708621978759766, 62.84794316973005, 54.58374186924526, 35.412373065948486, 67.80141816820417, 40.1099910736084, 38.7408207484654, 54.6568786076137, 45.062458583286826, 54.28962114879063, 3.587392713342394, 0.4130722518478121, 0.17610320608530725, 0.17969459694411072, 0.13657235300966672, 0.13986296286540373, 0.09195628030491726, 0.08779684706990208, 0.10935732442885637, 0.17501163323010716, 0.17516551140163625], [0.04699495541197913, 0.035216724034398794, 0.07482936432851212, 0.01847151284372168, 0.02924622655180948, 0.020007509172761014, 0.07651129657668726, 0.04418232937210372, 0.04122784201587949, 0.015481120806985667, 0.04104609301845942, 0.09402594781879868, 0.07243480067700148, 0.0905776871368289, 0.1146442453776087, 13.077917626925878, 46.93658229282924, 33.09393637520926, 28.7451457296099, 25.30410248892648, 38.9394975389753, 41.1007798739842, 23.34484597614833, 61.492585863385884, 52.54354231698172, 55.41443722588675, 51.497612612588064, 54.54617990766253, 48.701185022081646, 40.29055738449097, 3.5500839267458235, 2.608178743294307, 0.1504372525960207, 1.4000115330730165, 20.975286177226476, 50.730760778699604, 60.49873638153076, 58.28331020900181, 58.88928345271519, 59.32367788042341, 57.46165445872715, 54.32661683218819, 54.31305047443935, 56.021751471928184, 54.66031101771763, 54.627452986580984, 53.47052928379604, 56.106502124241416, 54.481863907405305, 56.464473315647666, 54.07917063576834, 53.97220311846052, 54.0273231778826, 51.93200356619698, 53.56245047705514, 51.836135796138215, 53.8360983303615, 52.37848785945347, 51.35757861818586, 50.69675282069615, 46.19176319667271, 43.02322135652815, 42.80648619788033, 44.692491327013286, 41.16515493392944, 40.392925194331575, 38.6575813293457, 37.159421171460835, 37.68981885910034, 37.13952153069632, 41.885078634534565, 48.52138648714338, 46.543418475559776, 48.871155330113, 48.46496711458479, 50.761777537209646, 50.043469292776926, 49.4450626373291, 45.39116048812866, 38.04330498831612, 36.25740950448172, 35.50806713104248, 36.7422513280596, 36.530953134809224, 38.14152124949864, 37.761895997183665, 43.42459447043282, 42.63117619923183, 41.74525656018938, 44.96928324018206, 43.23712512425014, 43.30656542096819, 38.931903157915386, 37.84759507860456, 36.364380495888845, 36.257121154240195, 37.0212527683803, 37.43017510005406, 42.83637734821865, 47.84275940486363, 49.939777851104736, 51.78468785967146, 51.01383038929531, 50.66978338786534, 51.07755926677159, 48.40819338389805, 50.60704810278756, 46.551985604422434, 41.646258626665386, 37.91156019483294, 34.08893925803048, 35.37356390271868, 36.72070843832833, 37.13106557301113, 38.432987758091514, 37.23616402489798, 40.043392590114046, 41.81469338280814, 40.386407784053254, 41.54847662789481, 44.62295722961426, 45.388360364096506, 48.680990082877024, 48.87238168716431, 47.62191786084856, 49.36166340964181, 49.1365521975926, 50.461764744349885, 47.4896901675633, 43.14187921796526, 47.51902893611363, 48.87263182231358, 48.37144783564976, 48.836542878832134, 47.50732816968645, 46.6247158731733, 46.91323634556362, 46.97507183892386, 47.69693408693586, 48.5931579044887, 52.76096534729004, 52.1322089603969, 49.60180357524327, 47.61601536614554, 37.7992981501988, 9.55804533617837, 0.6055046202880996, 0.6519033876912934, 3.201719705547605, 0.5880415716341564, 38.849341188158306, 53.813600063323975, 51.047431877681184, 49.54265008653913, 55.33077049255371, 53.42644991193499, 54.88718012401036, 46.56566660744803, 48.29508365903582, 43.47276980536324, 17.868074348994664, 35.73836864743914, 18.651669604437693, 40.31408745901925, 13.726774283817836, 0.02982450123610241, 0.03515668386327369, 0.07678688357451133, 0.012841005510251437, 0.04542804163481508, 0.031029782989727597, 0.02485565884437944, 0.04292098366256271, 0.05956442986748048, 0.0403876901338143, 0.042065591883978674, 0.04741450718470982, 0.05052166152745485, 0.06888607610017061, 0.017941269957061325, 0.07743975639875446, 0.08263637790722506, 0.018069691191028272, 0.0017551462827084053, 0.06495792152626173, 0.026491416784535562, 0.036519725008734634, 0.08319080887096268, 0.04463426083592432, 0.02706503332592547, 0.11336378872926746, 16.4601799760546, 58.839242526463096, 34.3211167880467, 32.01971360615322, 36.30947930472237, 44.85239716938564, 46.41554382869175, 25.388674225125992, 68.8089417048863, 57.62215437207903, 60.7222877229963, 56.45654194695609, 61.287614004952566, 53.33817652293614, 47.7902101789202, 5.778664341994694, 1.2930236054318291, 0.35650729281561716, 2.058944055012294, 26.045810529163905, 51.722883633204866, 61.133808680943076, 62.39121723175049, 60.73107719421387, 59.37122440338135, 59.26153319222586, 58.32634735107422, 55.750045640128, 58.7090402330671, 54.99269199371338, 57.12662621906826, 55.45668922151838, 57.05501461029053, 56.19963230405535, 58.78203105926514, 55.8821621622358, 54.91882569449288, 55.17102793284825, 54.501311915261404, 54.926503453935894, 52.560551507132395, 56.697821617126465, 53.333406584603445, 52.7009676524571, 52.564744744982036, 46.47133091517857, 45.31139864240374, 46.76152242933001, 46.69644212722778, 44.436606543404714, 41.76392984390259, 41.07973378045218, 39.104531151907786, 38.39968156814575, 39.009372098105295, 45.13597052437918, 51.219504015786306, 48.089927673339844, 50.91584341866629, 51.50178153174264, 50.83114487784249, 54.60621234348842, 51.90220969063895, 48.633165631975444, 41.65029900414603, 38.41084732328142, 38.48280981608799, 37.33472074781145, 39.51028857912336, 38.542203017643516, 40.66606930324009, 45.7979462487357, 46.12368474687849, 45.122442381722585, 47.14256164005825, 44.917897837502615, 46.187830516270225, 41.52818093981062, 40.10673584256853, 39.66079698290144, 39.017612661634175, 39.229348591395784, 40.25191150392805, 45.958369731903076, 51.25320972715105, 51.934418065207346, 54.019197259630474, 53.2541241645813, 50.70054653712681, 51.779146671295166, 50.898243631635395, 51.65558338165283, 47.93157475335257, 42.17204965863909, 40.77510738372803, 36.498067310878206, 37.913884367261616, 37.42571783065796, 38.93031896863665, 39.11660712105887, 39.320547172001426, 41.305352210998535, 42.9796769959586, 41.68292774472918, 43.890505926949636, 46.1858537537711, 47.84376689365932, 49.4400634084429, 48.4266790662493, 49.52332019805908, 50.73627070018223, 49.482951164245605, 52.21603202819824, 48.876786845070974, 44.53062956673758, 50.958550521305625, 51.32812867845808, 52.16138097218105, 50.61006014687674, 50.0699280330113, 48.48994241441999, 49.34941373552595, 49.01104688644409, 49.40727833339146, 50.821459089006694, 53.07077510016305, 55.459520612444194, 53.02039371218, 50.7147000176566, 40.30524240221296, 10.852526000567845, 1.4517277351447513, 0.360225610435009, 1.7678184424127852, 1.7926508699144637, 43.46136433737618, 58.169873918805806, 54.56582941327776, 55.42257009233747, 60.29915632520403, 58.653829847063335, 60.42839281899588, 50.83763796942574, 51.988673073904856, 51.00082336153303, 23.0035400390625, 38.55095427376883, 17.959281614848546, 48.71256964547293, 17.116583245141165, 0.0957104517146945, 0.03483115668807711, 0.07798972938741956, 0.029274660561765944, 0.0467801006909992, 0.04385174711101821, 0.016300920031166503, 0.017302419058978558, 0.05686758225783706, 0.06719566216426236, 0.05168885711048331, 0.1021296169076647, 0.10807323083281517, 0.16639293570603642, 0.08581927711410181, 0.13573352087821278, 0.10430610618953194, 0.16217119938560895, 0.12315714572157178, 0.23869781728301728, 0.11784216734979834, 0.171497500368527, 0.19368733252797807, 0.20394382359726088, 0.17049598268100194, 0.5004856384226254, 27.27738915170942, 66.8259744644165, 50.62701722553798, 43.826853479657856, 38.67197452272688, 51.689407212393625, 52.05090808868408, 30.949520792279923, 72.76314762660435, 62.630659103393555, 66.30140631539481, 61.10816287994385, 64.98322187151227, 58.30544022151402, 53.97371782575335, 6.613400510379246, 7.130141079425812, 0.1697393482817071, 3.3441256412437985, 34.082341943468364, 56.72551366261074, 62.73841176714216, 64.65043095179966, 63.85112408229283, 62.983940260750906, 62.26849120003836, 60.6575722013201, 56.755324908665244, 59.80288124084473, 58.7679887499128, 58.4939865384783, 58.970306396484375, 60.80260195050921, 58.181070940835134, 61.3144896371024, 58.763840675354004, 58.80420970916748, 58.277706486838206, 55.99366685322353, 57.27673857552664, 55.7219158581325, 57.395017760140554, 56.97563144138881, 55.7920822416033, 55.14621591567993, 48.46559245245797, 46.86489077976772, 47.99724217823574, 49.32902772086007, 46.735921791621614, 44.92343555177961, 44.47275454657418, 42.58480739593506, 43.015442848205566, 42.41148805618286, 47.54233666828701, 54.26370436804635, 53.33521659033639, 55.31239945547921, 54.24218232291085, 54.40645510809762, 57.14813436780657, 53.12513780593872, 51.65275546482631, 42.53065313611712, 41.41704797744751, 40.067541054316926, 39.88644668034145, 41.68965012686593, 42.6315826688494, 43.29754318509783, 49.33516992841448, 49.4572046143668, 47.54618944440569, 50.12552056993757, 47.58479710987636, 48.06708894457136, 43.66243130820138, 43.96372256960188, 41.699725014822825, 41.67143195016043, 41.04971061434065, 41.1913948059082, 45.942736285073416, 50.50301272528512, 54.19020979745047, 55.724406787327354, 54.5168446132115, 55.493830817086355, 54.7320442199707, 51.377596378326416, 53.60780831745693, 50.727158137730186, 46.14682919638497, 41.44300644738333, 38.342727184295654, 39.397571427481516, 39.97752366747175, 42.19144555500576, 42.38755151203701, 40.630998270852224, 44.40206010001046, 44.05077307564871, 44.65595769882202, 45.8751858983721, 49.37228373118809, 49.15045901707241, 52.957488196236746, 53.2920161655971, 51.91599839074271, 52.035896505628315, 51.889223507472444, 53.164148466927664, 51.48464379991804, 44.723858969552175, 51.879930291857036, 54.425371578761506, 52.911275727408274, 53.88194949286324, 53.42681469236101, 49.75998626436506, 51.905294690813335, 50.59266880580357, 51.91845110484532, 51.80238144738333, 57.36456380571638, 55.53812558310372, 56.18033020836966, 51.37994834354946, 43.588888100215364, 15.840595211301531, 1.8081069205488478, 1.6861023072685515, 8.298896261623927, 2.473119007689612, 49.23663057599749, 64.01303100585938, 59.7353447505406, 59.30436883653913, 63.93764999934605, 61.30183001926967, 67.01277678353446, 54.682368074144634, 59.6536408833095, 53.914967332567485, 29.11927843093872, 50.018643379211426, 28.431979996817454, 59.14901406424386, 28.732079642159597, 0.14299605760191167, 0.10064656327345542, 0.21753813698887825, 0.0688564105491553, 0.12092556618154049, 0.07560982209231172, 0.08314841400299754, 0.0996590709047658, 0.1471598877438477, 0.1626185303820031, 0.14010931178927422], [0.06463552239750113, 0.1064930177692856, 0.009869122212486607, 0.042773409081356864, 0.0055897833579885104, 0.02714785361396415, 0.07907827597643648, 0.05191936224166836, 0.06620861762868506, 0.048423064673053365, 0.07277820046458926, 0.10158749456916537, 0.011663714174314268, 0.09596207285565989, 0.15902297331818513, 2.911703199148178, 37.55854306902204, 38.30331005368914, 30.171138422829763, 26.1010000705719, 24.663153750555857, 62.43688774108887, 31.307762963431223, 44.97514751979283, 62.993507930210654, 50.43844311577933, 55.90067563738142, 49.04260213034493, 54.581765106746126, 47.29973684038435, 17.861628157751902, 7.470193300928388, 0.590027236512729, 0.19026334982897553, 11.355630295617239, 45.664752755846294, 61.45876898084368, 58.38551821027483, 58.510780334472656, 55.77677188600813, 54.684504645211355, 54.407004015786306, 54.98607383455549, 52.8586049079895, 56.57967792238508, 54.364873613630024, 56.24420847211565, 53.93136855534145, 52.42882061004639, 52.53751475470406, 52.02681868416922, 54.17830753326416, 54.86010299410139, 54.443412576402935, 56.27667393003191, 55.06867054530552, 54.11961609976632, 53.435100419180735, 52.12962423052107, 52.86130428314209, 47.18718991960798, 46.48498412540981, 41.74105290004185, 44.91787699290684, 42.17624289648873, 38.27205010822841, 38.61348806108747, 36.81289366313389, 36.72899069104876, 37.364983626774375, 39.28770998546055, 46.52406774248396, 46.449530942099436, 48.71869795663016, 48.98184013366699, 50.75172349384853, 49.514516830444336, 45.39299133845738, 40.072769573756624, 37.28805317197527, 38.2661371912275, 35.88185242244175, 35.98807300840105, 35.4281975882394, 36.309232643672395, 38.686669962746755, 43.550329072134836, 40.73828887939453, 37.990957260131836, 42.52648769106184, 44.19099814551217, 42.88232231140137, 39.38354648862566, 36.11553076335362, 36.6726199558803, 36.0517532484872, 36.19398634774344, 38.46588747841971, 37.39608376366751, 41.384954248155864, 48.24858978816441, 50.34240164075579, 50.955239704677034, 50.378910950251985, 50.82609006336757, 49.50107206617083, 49.533294337136404, 49.06554855619158, 40.903819288526265, 37.28218541826521, 35.53435564041138, 35.15325042179653, 34.87294272014073, 34.74480404172625, 37.91777883257185, 37.947788102286204, 40.52015365873064, 41.077680587768555, 39.09548112324306, 40.857248987470356, 46.47019835880825, 45.96100657326834, 46.136611870356965, 50.79596267427717, 49.163806506565635, 50.12715687070574, 49.59632839475359, 50.17877503803798, 50.53617647715977, 49.78269992555891, 51.16509962081909, 48.270959513528005, 50.30292197636196, 48.151137828826904, 50.01455089024135, 48.35084990092686, 48.59429740905762, 51.38633721215384, 51.442833014896934, 50.12577417918614, 51.499912466321675, 51.073098523276194, 54.85711874280657, 55.86295734133039, 34.84439952032906, 8.037068162645612, 2.7766022086143494, 0.273566401962723, 0.8561404198408127, 3.099410955395017, 38.40644563947405, 48.943777901785715, 50.738143239702495, 54.87550367627825, 54.30596678597586, 48.58965948649815, 52.73594488416399, 47.22883742196219, 56.82213878631592, 25.766468627112253, 24.577796867915563, 24.294263465063914, 21.415004662105016, 35.514080796922954, 3.4479879651750838, 0.09925475902855396, 0.013932722554142987, 0.07035839531038489, 0.043002356974674125, 0.05829258382852588, 0.056554336566478014, 0.030420872449342693, 0.10366258357784577, 0.020515920195196356, 0.008282697160861321, 0.043212702830455134, 0.04212516047326582, 0.08381044026464224, 0.050499456468969584, 0.04771847390968885, 0.06547770649194717, 0.027057840854727795, 0.09572979674807616, 0.015576270076313188, 0.05059171687545521, 0.05856400462133544, 0.04555650527722069, 0.06773903300719601, 0.029649133860532726, 0.10395422471421105, 0.24143011495471, 3.7125610368592397, 50.14292928150722, 42.18360798699515, 31.294464111328125, 40.90316268375942, 29.134340388434275, 67.86688409532819, 34.77536221912929, 51.916418756757466, 66.4503617967878, 56.94383995873587, 60.54147475106375, 53.88670206069946, 59.13404764447893, 51.157126562935964, 19.161721229553223, 2.176516477550779, 1.2499303349426814, 0.1591198816895485, 14.8411819594247, 49.53130367824009, 62.78816086905343, 60.469241278512136, 62.174614088875906, 58.76683534894671, 57.34951400756836, 58.16585438592093, 57.913061550685335, 56.77617992673601, 59.08451393672398, 57.50480277197701, 58.07097326006208, 54.68920857565743, 53.22598743438721, 54.53781427655901, 53.2212279183524, 55.175759656088694, 57.73629937853132, 55.357298714774, 58.49004690987723, 57.31053808757237, 54.97013814108712, 55.33661045346941, 54.208445344652446, 53.504335744040354, 49.9882276398795, 47.462672097342356, 44.98049415860857, 46.122343744550435, 43.99274519511631, 41.187795639038086, 40.93856028148106, 39.835787364414756, 38.21820156914847, 40.29163088117327, 42.39530570166451, 49.61879192079817, 50.662623269217356, 52.01086214610508, 52.83772209712437, 52.35908848898751, 52.517993790762766, 48.33371564320156, 42.40465450286865, 40.29247161320278, 40.288386072431294, 38.87592847006661, 38.7587297303336, 38.815340178353445, 38.7509651184082, 41.756422315325054, 46.16060400009155, 43.25123691558838, 41.79606178828648, 47.46050773348127, 46.53265919004168, 45.987343720027376, 41.92512457711356, 38.90532629830496, 39.19916909081595, 38.50076743534633, 37.92075266156878, 40.05516283852713, 38.60043587003435, 44.61198949813843, 50.711774826049805, 50.96846907479422, 52.132452147347585, 53.72282879693167, 51.95573166438511, 52.535847187042236, 52.41355889184134, 48.59472819737026, 43.36909226008824, 40.568864004952566, 37.24261890138899, 37.82574994223458, 36.65945659364973, 37.690996578761506, 39.97259739467076, 38.82403932298933, 42.80136884961809, 43.735696588243755, 41.37318747384207, 43.24548033305577, 47.21512515204293, 47.15068061011178, 48.18793548856463, 51.454248905181885, 51.34106275013515, 52.02102388654436, 53.53595004762922, 50.949813161577495, 53.366368838718955, 50.62951510293143, 53.58294071469988, 50.85908358437674, 52.357466084616526, 51.42811325618199, 51.12075621741158, 51.76949562345232, 51.64348656790597, 54.15272774015154, 53.29341970171247, 52.49781622205462, 55.237167835235596, 52.61969804763794, 55.791227613176616, 54.01336424691336, 40.34611865452358, 10.876715285437447, 4.171087861061096, 1.189252802303859, 0.7062030168516296, 4.834105380943843, 42.6210491997855, 53.4803192956107, 55.47032853535244, 60.536986214774, 59.06756033216204, 52.969039576394216, 60.56051976340157, 51.27094152995518, 63.267246110098704, 28.53759261540004, 28.886942829404557, 32.74615124293736, 23.922555685043335, 45.59549311229161, 4.259887141840799, 0.18645081083689416, 0.044490635328527005, 0.028941370945956026, 0.043882271008832116, 0.05314950891105192, 0.055350052259330235, 0.04830643807404807, 0.05296862504578062, 0.030913499050906727, 0.028086913849360177, 0.04126099862956575, 0.14231767186096736, 0.15872857054429396, 0.17301773093640804, 0.13200038405401365, 0.23196487714137348, 0.20193309363509926, 0.1876369307615927, 0.19755713987563336, 0.1152428218296596, 0.17939240458820546, 0.14962102925138815, 0.21266196721366473, 0.20727502341781343, 0.3578566275537014, 0.41180168145469254, 7.101681692259652, 65.30206775665283, 54.57560205459595, 45.21196297236851, 40.87278168542044, 39.130246434892925, 72.12055042811802, 39.29645429338728, 54.99162197113037, 76.09234224046979, 60.33780915396554, 68.29171085357666, 57.75957236971174, 63.39161191667829, 56.84772900172642, 23.723882368632726, 10.969630071095057, 1.2911764702626636, 0.6127787328192166, 19.025097063609532, 56.0597859110151, 65.03321416037423, 64.46926362173897, 64.10505989619664, 61.74616731916155, 58.17564787183489, 59.426900318690706, 59.283197675432476, 57.68212080001831, 61.62208638872419, 60.827254159109934, 60.69327204568045, 57.43620320728847, 54.43131923675537, 57.17299502236502, 55.239703927721294, 57.94236557824271, 59.455832617623464, 55.43575429916382, 60.226929800851, 58.720984186444966, 57.1185176713126, 59.22559710911342, 57.8858767236982, 58.049228872571675, 51.95391123635428, 50.841233662196565, 47.58740963254656, 49.675728934151785, 47.41700158800398, 42.8576249395098, 43.45440571648734, 43.66192061560494, 41.25316081728254, 42.84606661115374, 45.232015473502024, 51.5045781816755, 51.70589528764997, 52.46078927176339, 53.60964959008353, 55.34992320196969, 53.98338624409267, 50.66060134342739, 45.06288937159947, 42.22792707170759, 42.83206251689366, 41.610645634787424, 41.39623812266758, 41.80302388327462, 41.72163615907942, 44.47140659604754, 48.733118942805696, 47.05408327920096, 42.14092867715018, 49.71073743275234, 50.49693305151803, 47.51599604742867, 43.09984261648995, 42.11344160352434, 41.16239649908883, 40.411157267434255, 40.702866962977815, 41.843934876578196, 40.51581103461129, 44.058106899261475, 49.898665360042024, 54.46278067997524, 54.78991576603481, 56.11462804249355, 54.98654978615897, 55.75108092171805, 54.144653933388845, 51.515528542654856, 45.92963893072945, 42.31641238076346, 39.769022124154226, 39.34719351359776, 38.68260179247175, 39.08990519387381, 42.62484639031546, 39.70383412497384, 45.24577638081142, 46.54741021565029, 44.33033037185669, 46.056221212659565, 50.27770001547677, 49.20455421720232, 48.862560408455984, 53.34479815619332, 54.00060040610177, 55.443150656563894, 54.01476083483015, 53.98649903706142, 53.209415980747764, 51.78944042750767, 54.33932508741106, 52.89683737073626, 54.28404521942139, 52.91571562630789, 53.60556057521275, 55.18154055731637, 52.50354848589216, 57.46854707172939, 56.03925398417881, 54.14306279591152, 56.55339636121477, 56.01703364508492, 57.140557357243125, 55.71656574521746, 42.9031217438834, 13.215037720543997, 5.974867573806217, 3.6375617470060075, 2.5766662742410387, 4.723162191254752, 44.93886750085013, 58.26812492098127, 59.45654133387974, 64.57391738891602, 60.825162751334055, 59.37726238795689, 63.742801666259766, 58.39239692687988, 68.01024627685547, 36.620581422533306, 39.961799894060405, 41.12353869846889, 32.875540597098215, 58.52268954685756, 10.238807252475194, 0.2806712607187884, 0.1524866454835449, 0.2509278138833386, 0.12071399896272592, 0.17125041862683638, 0.24745773151516914, 0.10909552526261125, 0.27172626927495, 0.12777171310569557, 0.07053573043750865, 0.10605020581611566], [0.033997494993465285, 0.009361125944581414, 0.023867340359304632, 0.01941383513621986, 0.025115334196016192, 0.04426705125453217, 0.01446235306294901, 0.017686698885102357, 0.042980413152171035, 0.05593325310785856, 0.03542077987055693, 0.04898928179006491, 0.062240524483578544, 0.04566740504066859, 0.0473071833008102, 0.1152622007897922, 20.648071186883108, 45.404890128544395, 23.298369475773402, 21.60368299484253, 27.18625831604004, 46.21900708334786, 45.90589346204485, 31.224749360765728, 63.785282952444895, 52.656394958496094, 57.313383374895366, 53.82211855479649, 52.26518358503069, 52.39839097431728, 23.409743888037546, 0.3198180901152747, 4.898256795746939, 0.09755366495145218, 5.701258369854518, 40.301994119371685, 59.36762523651123, 57.454049655369346, 57.14659186771938, 54.026875019073486, 56.52342183249337, 56.030930042266846, 56.01526880264282, 57.470068727220806, 56.817514760153635, 55.19894926888602, 55.474108355385916, 52.50243330001831, 52.8085744040353, 50.75240094321114, 51.1196688243321, 52.14288486753191, 53.41806691033499, 50.92282983234951, 53.47344405310494, 55.91025372913906, 52.51525272641863, 52.52083560398647, 51.341750621795654, 50.29254831586565, 49.43495648247855, 49.36930295399257, 42.05087307521275, 44.44739014761788, 41.70435946328299, 39.30462884902954, 36.87223475319998, 36.224999632154194, 36.807144028799875, 39.12744631086077, 38.12660346712385, 41.00217451368059, 44.06044496808733, 48.97028180531093, 50.05610459191458, 48.51389980316162, 45.73310913358416, 39.4863555090768, 37.115376540592735, 35.997741426740376, 34.57102959496634, 34.488933154514854, 35.06583513532366, 35.60209362847464, 37.13863910947527, 38.77507536751883, 44.91862045015608, 36.328013624463765, 25.556594814573014, 44.55681037902832, 42.45287152699062, 42.2791040284293, 39.189528465270996, 36.49270677566528, 36.251051902770996, 36.09614528928484, 35.853865078517366, 35.59164353779384, 36.743387358529226, 37.40089191709246, 42.01504468917847, 49.03364937646048, 47.66037614004952, 47.04608242852347, 50.60347672871181, 51.369887351989746, 50.22698858806065, 46.54774372918265, 42.35649653843471, 36.72299786976406, 34.860043389456614, 35.03489480699812, 35.503397941589355, 34.49561037336077, 37.47784321648734, 39.15098680768694, 40.72200230189732, 42.001363686152864, 39.49862255368914, 41.97055189950125, 44.42502042225429, 46.264170374189106, 47.313650608062744, 48.91590520313808, 48.26260083062308, 50.75641352789742, 49.83569383621216, 48.879444531032014, 49.60127551215035, 49.57845762797764, 49.87250886644636, 49.32902077266148, 49.85982492991856, 52.35844578061785, 49.92421736036028, 50.60169104167393, 50.17606176648821, 49.837535108838765, 50.934429849897114, 53.05530841009957, 53.12391144888741, 55.4747371673584, 50.512048857552664, 40.375693661826, 32.5712650844029, 8.846114669527326, 0.2548057772219181, 0.6302325533969062, 0.6959035066621644, 6.704595616885594, 43.9174336705889, 56.58905799048287, 47.72069345201765, 52.63662733350481, 42.72345869881766, 53.95760842732021, 46.00910547801426, 49.16771139417376, 50.13663073948452, 25.948045900889806, 28.399874108178274, 19.958785567964824, 27.817264182227, 28.507183824266704, 0.20877812776182378, 0.11681296543351241, 0.02662149873296065, 0.051261848237897666, 0.08731356050286974, 0.02050647498773677, 0.021734129737264345, 0.04166312223034246, 0.05418175744957157, 0.008014579985423811, 0.05274459653134857, 0.028608142398297787, 0.03408741445413657, 0.01951741350681654, 0.06252685947609798, 0.01405195557578866, 0.04038726944210274, 0.0761550385504961, 0.022732670352395092, 0.0633207658039672, 0.04352346169097083, 0.03688360298318522, 0.04028660198673606, 0.03898614891139524, 0.03748167731932231, 0.054733844074819765, 0.025420052398528372, 0.36707729420491625, 28.281495911734446, 54.42911318370274, 22.823531321116857, 32.82637166976929, 34.29031194959368, 50.93744536808559, 51.564242362976074, 35.421753134046284, 71.1071834564209, 57.737424986703054, 62.70895140511649, 57.31225776672363, 57.542270932878765, 54.908170631953645, 25.92595410346985, 1.436259959425245, 3.3136406370571683, 0.2577105313539505, 6.229945932115827, 43.94721712384905, 61.6037848336356, 60.789824213300435, 59.63360227857317, 57.270721435546875, 57.00808647700718, 57.27933372770037, 58.26009627750942, 58.60681138719831, 59.90591607775007, 58.28932040078299, 57.73210614068167, 54.62561171395438, 55.48345715659005, 52.70430278778076, 52.914148807525635, 53.23783758708409, 56.80175971984863, 52.31672532217843, 55.718500818525044, 55.77221039363316, 53.068972042628694, 54.34073904582432, 54.201643058231895, 52.31845889772688, 52.00812455586025, 49.995429447719026, 45.761989321027485, 45.98797948019845, 45.07461098262242, 40.99708495821272, 39.993844985961914, 38.87767941611153, 40.6957311630249, 40.73492595127651, 40.24199642453875, 44.44639308112008, 47.24891424179077, 54.27477979660034, 50.1872935295105, 50.80433177947998, 47.64718498502459, 42.378220081329346, 40.72254426138741, 38.04419783183506, 37.891389574323384, 37.81726966585432, 38.31093570164272, 39.16579689298357, 39.249425411224365, 41.71750545501709, 47.16719995226179, 38.85094274793352, 30.70684106009347, 47.59780066353934, 46.06153311048235, 45.76837124143328, 39.950311047690256, 38.771632535117014, 38.926424503326416, 38.76759910583496, 37.35837588991438, 38.26995522635323, 38.90525334221976, 38.1955817086356, 43.966960430145264, 51.25958817345755, 51.5089555467878, 51.1943028994969, 52.34012338093349, 53.076580320085796, 51.34184442247663, 49.255418504987446, 45.00300979614258, 38.948460715157644, 36.907965864454, 36.761275495801655, 37.345500877925325, 36.63001707621983, 40.57460669108799, 41.09415129252842, 41.19003643308367, 42.19743490219116, 41.21201358522688, 43.88525308881487, 47.8051939691816, 49.203776018960134, 48.421412331717356, 50.82091365541731, 51.82645000730242, 52.36530365262713, 51.14274031775338, 50.180550302777974, 50.893105438777376, 50.80244186946324, 52.4220426423209, 52.338650362832205, 51.50693709509713, 52.767795426504954, 52.01770612171718, 53.07764686856951, 51.349365847451345, 51.84402200153896, 53.97810908726284, 54.642933573041645, 55.38882963997977, 57.61152015413557, 52.20402206693377, 43.462441308157786, 35.17083283833095, 10.394117730004446, 1.0413512757846286, 1.0993617858205522, 0.23102624607937677, 7.13861267055784, 46.89520229612078, 61.8163024357387, 51.977712290627615, 56.143084389822825, 46.654099805014475, 56.93518597739083, 51.82848235539028, 53.79326268604824, 56.91033574513027, 29.540144715990337, 36.506839411599294, 24.90973663330078, 33.62240246364048, 37.38099227632795, 0.4394855573773384, 0.09936716513974325, 0.06735372011150632, 0.03525744970621807, 0.03624592934335981, 0.04171713701050196, 0.03718467236363462, 0.009955275803804398, 0.026415812716420208, 0.061501504853367805, 0.010814533535657185, 0.012476904467413468, 0.1274615004658699, 0.06986154482832976, 0.1056200892531446, 0.06728301676256315, 0.08781646351729121, 0.20150151822183812, 0.1477610290582691, 0.10347246485097067, 0.16442826470094069, 0.16613539095435823, 0.1291887927800417, 0.18059282803109714, 0.07959888196949448, 0.19856783135661057, 0.1436258466648204, 0.7674767917820385, 42.43349647521973, 65.08559662955147, 38.62033551079886, 33.476747376578196, 41.83361332757132, 57.50438935416085, 55.777334690093994, 40.69912535803658, 74.7104845046997, 62.13961601257324, 67.45263944353376, 62.616714068821494, 62.63448061261858, 60.51264667510986, 28.32336401939392, 4.239896740232195, 13.198266506195068, 0.6669040599039623, 9.350666795458112, 48.06062364578247, 64.30155495234898, 64.9939637865339, 62.785562242780415, 58.70325238364083, 60.96599578857422, 60.340150696890696, 61.30515125819615, 61.12789576394217, 62.30874906267439, 60.69199357713972, 61.693784849984304, 57.31687137058803, 57.94708340508597, 55.10930361066546, 55.09308304105486, 55.769736834934776, 59.18290737697056, 52.257776805332725, 57.669825962611604, 57.49760096413748, 54.479435511997764, 55.54819699696132, 58.6464022227696, 54.67406497682844, 55.48785884039742, 52.14560508728027, 46.854037693568635, 48.29567078181675, 47.02212503978184, 43.25857073920113, 43.242614201136995, 42.88299281256539, 44.139404296875, 44.76529802594866, 42.4063846043178, 48.57416500364031, 47.80076796667916, 55.04518910816738, 53.942252908434185, 52.70796448843819, 49.8471166746957, 45.29793998173305, 42.439986092703684, 41.13240459987095, 40.07807799748012, 38.6117718560355, 39.65145512989589, 41.50820139476231, 42.76404660088675, 43.825033051627024, 49.58881739207676, 39.60011141640799, 28.993861709322246, 50.45166901179722, 47.52326038905552, 48.491008962903706, 43.56163379124233, 41.52990409306118, 40.40050915309361, 40.35406044551304, 39.16083240509033, 40.63346835545131, 40.31294100625174, 40.908491952078684, 44.20041642870222, 52.84050137656075, 51.442294529506135, 51.44512939453125, 55.63860348292759, 55.893546785627095, 53.00428431374686, 49.77735676084246, 46.33350992202759, 41.66992766516549, 39.09804848262242, 39.36463001796177, 38.521691935403005, 37.625558444431846, 43.09966891152518, 42.797040121895925, 44.982349327632356, 45.88182837622506, 43.15386138643537, 46.931659494127544, 48.23364073889596, 52.24376923697335, 49.30849231992449, 51.79752813066755, 53.73178155081612, 54.322837012154714, 52.78362342289516, 52.00812802995954, 52.71124403817313, 53.07960278647286, 55.0446332522801, 55.19008336748396, 52.29682568141392, 56.86268499919346, 54.318876538957866, 55.72089447293963, 56.04467705317906, 54.22199433190482, 54.592750208718435, 56.32255635942732, 57.41578939982823, 58.19955662318638, 54.92021533421108, 46.98681429454258, 39.535826683044434, 12.441907320703779, 2.20382941194943, 1.9136489714894975, 1.63859714780535, 10.498761074883596, 50.26926490238735, 68.71682248796735, 55.7294477054051, 59.93070725032261, 49.61039154870169, 63.4708491734096, 55.20272561482021, 59.322420256478445, 60.49649906158447, 40.997150966099326, 43.91965709413801, 32.34306539808001, 43.28415748051235, 51.98938526426043, 1.2999469424997057, 0.35676201486161774, 0.16613875648805074, 0.13190827971058233, 0.13114674628845283, 0.15088252084595816, 0.1300703997590712, 0.06742084079555102, 0.1108111399891121, 0.11737737086202417, 0.136521096474358, 0.1624569711940629], [0.02261178764248533, 0.04622998181730509, 0.03320830448397568, 0.08226428965904883, 0.04547188856772014, 0.05591863746355687, 0.057773192413151264, 0.019092538626864552, 0.048833676746913364, 0.04319293371268681, 0.024869638362101147, 0.02050529433680432, 0.021805141819640994, 0.05576980080721634, 0.04135489430544632, 0.09190773790968315, 6.691695417676653, 41.39757217679705, 28.550670862197876, 25.44448389325823, 24.700969321387156, 33.226014682224815, 52.04867771693638, 52.002444403512136, 53.62545326777867, 57.23185321262905, 54.684733935764854, 51.94062975474766, 51.22349228177752, 47.3686386517116, 25.1352664743151, 0.7208002050008092, 1.6807085509811128, 0.1921261591570718, 5.133173218795231, 39.20225061689104, 57.126494203295024, 56.05736098970686, 56.943430015019004, 58.23516614096505, 54.104357855660574, 55.144847120557515, 57.736910820007324, 54.53986052104405, 54.281547342027935, 56.57623508998326, 54.876698766435894, 51.78858232498169, 49.16489737374442, 49.03964567184448, 47.794323512486045, 50.45506320680891, 51.12736395427159, 53.49026564189366, 53.2202273777553, 53.77564205442156, 54.47347048350743, 54.04283503123692, 52.78677790505545, 50.75281088692801, 51.9772641318185, 49.774153641292024, 44.98525020054409, 42.60081951958792, 42.248837675367085, 39.15011133466448, 37.88168641499111, 35.32207775115967, 35.958310399736675, 37.281778948647634, 39.3120391028268, 39.7767276763916, 45.278578826359336, 48.43292897088187, 50.83655405044556, 49.570699964250835, 43.348303249904085, 39.05297204426357, 35.86800466264997, 34.27872930254255, 35.76232603618077, 34.83020435060774, 35.67532764162336, 34.559790883745464, 37.94566542761666, 39.4154178755624, 44.63800702776228, 31.36287954875401, 17.2007954120636, 43.133437156677246, 42.637120383126394, 42.72675214494978, 38.691644872937886, 35.47913483210972, 35.65473665509905, 36.34116309029715, 35.689418588365825, 35.7090403011867, 35.01228884288243, 36.705252170562744, 37.435712814331055, 42.94677380153111, 48.2818786076137, 45.837630884987966, 48.76209293093, 48.05483232225691, 46.32870871680123, 43.662035260881694, 42.33866398675101, 37.877729415893555, 35.33474779129028, 36.3787910597665, 37.67557852608817, 36.05428239277431, 37.06397376741682, 38.760775974818635, 39.89867550986153, 40.6373176574707, 39.27157974243164, 42.5392758505685, 43.04574046816145, 45.86713293620518, 48.50758736474173, 48.454697677067344, 49.151751382010325, 48.72844975335257, 48.78058903557913, 50.67961161477225, 47.65056528363909, 49.70264972959246, 46.97548873083932, 49.66576869147164, 49.91385064806257, 49.72327198301043, 47.44506883621216, 46.98661627088274, 47.31897292818342, 46.11719165529524, 49.88118716648647, 50.89121552876064, 50.24009983880179, 48.27789381572178, 48.158256258283345, 49.90380007880074, 32.91922044754028, 9.078980071204048, 1.1649432267461504, 0.6152303069829941, 0.16170083891068185, 3.6322227077824727, 40.60397325243269, 47.07926007679531, 53.10908399309431, 50.25058467047555, 53.93691669191633, 50.63597692762102, 53.06339611325945, 54.75854812349592, 42.5883857182094, 25.61601059777396, 26.962225811822073, 23.313903910773142, 36.22163322993687, 11.42451821054731, 0.06053240078368357, 0.02075712412728795, 0.02449919386500759, 0.042924851312169006, 0.02471341415574508, 0.04564165463671088, 0.07405672328812735, 0.0277181351557374, 0.06108996657920735, 0.0842681121347206, 0.028800456185958216, 0.02326947128001068, 0.031723571475595236, 0.04042562024135675, 0.01588396535121969, 0.02098591935022601, 0.022260016429104974, 0.049245788383164575, 0.05689349551019924, 0.021320666119988476, 0.06052361375519207, 0.008897356589191725, 0.04659279788445149, 0.015392168258715953, 0.06880676892719098, 0.07155036420694419, 0.03960279475099274, 0.11611978762916156, 8.586798344339643, 55.09046009608677, 28.727730069841655, 27.291035413742065, 34.93457671574184, 36.72833061218262, 59.358495303562705, 55.57776505606515, 60.517079625810894, 60.331764221191406, 58.658262797764365, 54.95344509397234, 57.46490274156843, 54.79688480922154, 28.575192792075022, 0.8979716694780758, 1.9087396349225725, 0.10529192936207567, 6.15979083946773, 43.15859310967581, 61.99394702911377, 59.71191542489188, 60.00956930433001, 60.04306656973702, 58.35407066345215, 57.55834559031895, 59.18240710667202, 57.04728821345738, 59.1084018434797, 58.03227874210903, 56.467165742601665, 55.254145758492605, 51.27673632758004, 51.820168835776194, 51.98122807911464, 53.25886631011963, 53.29870728084019, 55.0641542162214, 55.664075578962056, 55.397865772247314, 55.76821517944336, 56.02504144396101, 54.214344365256174, 53.37587397439139, 54.45921972819737, 50.7628892489842, 45.76178782326834, 44.9724794115339, 44.83890724182129, 42.01308877127511, 38.6763345173427, 37.37793506894793, 38.87252037865775, 39.60637869153704, 41.66212831224714, 42.92657191412789, 47.8047388621739, 50.1932099206107, 53.45869302749634, 52.73953710283552, 46.99729217801775, 41.22357191358294, 38.06378480366298, 37.017184598105295, 39.675888470241, 36.43063504355294, 39.57235336303711, 37.250258445739746, 40.55093765258789, 42.78628431047712, 46.542098317827495, 34.57011590685163, 19.343166487557546, 46.47675051007952, 45.76271193368094, 43.58964892796108, 40.86265121187483, 37.45378507886614, 38.80808973312378, 39.0036016191755, 37.05066449301583, 37.8959892817906, 37.250248023441856, 37.979457991463796, 37.84353385652815, 44.582014969417024, 50.497231824057444, 47.69143458775112, 50.86819962092808, 50.33358090264456, 48.99895354679653, 46.8084887777056, 43.96137407847813, 39.462158407483784, 37.34562247140067, 37.30677509307861, 39.34491450445992, 38.39170503616333, 38.93030159814017, 39.59704378673008, 40.71473796027047, 43.18466969898769, 41.08279793603079, 44.224696908678325, 45.34400306429182, 47.90510559082031, 50.724802698407856, 52.25604670388358, 50.79090438570295, 51.48837150846209, 50.90998261315482, 50.70911019189017, 49.67621183395386, 50.38392407553536, 49.322062151772634, 51.39030115944998, 51.59374441419329, 49.92035068784441, 50.159198488507954, 47.93632732118879, 49.84202364512852, 47.746321882520405, 49.14894430977957, 52.355673449380056, 52.073309080941335, 49.19024092810494, 51.14705514907837, 51.12713813781738, 34.28973872320992, 10.388520087514605, 2.6667503203664507, 0.7056418412498066, 0.31690945476293564, 3.6041741328580037, 43.7790880884443, 53.02281863348824, 57.174739020211355, 56.308569635663716, 56.27648285457066, 57.470829554966514, 58.63550049918038, 60.49783311571394, 47.37927981785366, 32.0520018850054, 37.332038743155344, 25.708412953785487, 46.32083988189697, 14.93677180153983, 0.13364036248198577, 0.027740384318998883, 0.044006371671067815, 0.019124149877045835, 0.06791563531649963, 0.05485982767173222, 0.09611687383481435, 0.017391261345307742, 0.03910953711186137, 0.029981897611703192, 0.019827900953324776, 0.05069771083071828, 0.09900318538503987, 0.16310392719294342, 0.11092061482902084, 0.3059232399931976, 0.09931326231786183, 0.15622350067964622, 0.1034083432917084, 0.09821534516023737, 0.13896653668156692, 0.13202432276947157, 0.15149732785565512, 0.14947717982743466, 0.261319062007325, 0.12949375355882303, 0.12207363386239324, 0.32110733379210743, 15.186005422047206, 69.28549780164445, 44.73055703299386, 39.6381528036935, 37.43396534238543, 45.454243183135986, 62.73265865870884, 63.6287191935948, 64.72940417698452, 66.05314023154122, 63.295372417994905, 60.814393043518066, 63.234533991132466, 60.73780305044991, 32.84142146791731, 3.287210775273187, 10.431927221161978, 1.0269306153059006, 7.7923100505556375, 48.46466486794608, 62.55827277047293, 62.09992095402309, 63.017812728881836, 63.36582020350865, 58.55426216125488, 61.45656640189034, 61.68131978171212, 60.1104154586792, 60.47427872249058, 62.186551094055176, 59.12394496372768, 59.22638920375279, 52.15874760491507, 54.23429264341082, 53.68239722933088, 54.69833850860596, 55.70996495655605, 58.68646553584507, 57.01725115094866, 59.035452706473215, 57.82209573473249, 59.192113740103586, 58.534508432660786, 56.745618275233674, 57.04325825827462, 52.66264486312866, 48.51334394727434, 47.38740226200649, 46.50361224583217, 43.280207429613384, 43.92272124971662, 39.4097238268171, 42.18327794756208, 41.58932856151036, 44.22347749982561, 45.98101391111101, 51.509963035583496, 52.062511580330984, 54.15238380432129, 53.97768177304949, 47.81371940885271, 44.434601988111226, 41.56573595319475, 39.21285356794085, 41.359864303043906, 40.14451667240688, 42.12319687434605, 40.2152111189706, 44.49038907459804, 44.0919828414917, 48.14427995681763, 35.817213330950054, 16.670970950807842, 49.8736310005188, 46.89684901918684, 46.776613916669575, 43.944201605660574, 40.406053815569194, 41.794196196964805, 41.24369042260306, 38.12139926637922, 39.81709671020508, 38.29539605549404, 40.08890676498413, 41.932284695761545, 45.46969597680228, 53.19149310248238, 50.7997807094029, 52.20012412752424, 52.08556917735508, 50.197760990687776, 47.14644568307059, 47.28688267299107, 42.21590321404593, 39.71056692940848, 39.391352789742605, 42.09752328055245, 40.347570828029085, 41.68063136509487, 42.34659188134329, 42.83360849108015, 45.77614974975586, 41.717321327754426, 46.23129844665527, 46.75450127465384, 50.31063100269863, 52.55382912499564, 54.864456040518625, 53.90118210656302, 52.09238536017281, 53.71747520991734, 52.9966447693961, 50.42498445510864, 51.37504291534424, 50.974062374659944, 53.73386601039341, 53.130474022456575, 52.102310861860005, 52.295592376164024, 50.7914845602853, 51.111824308122905, 50.153306416102815, 51.255829198019846, 52.17449222292219, 54.457117898123606, 51.48863901410784, 52.84894691194807, 51.67110218320574, 37.872316769191194, 12.757644755499703, 4.45701231275286, 1.2067567259073257, 1.2092467865773608, 6.165478374276843, 50.39886270250593, 55.24868447440011, 60.05360698699951, 60.58451189313616, 60.16128322056362, 62.07638045719692, 61.92642443520682, 64.34184755597795, 51.909522669655935, 39.06514528819493, 38.83768211092268, 34.73931496483939, 57.41890566689627, 25.655634437288555, 0.13685492213283265, 0.07908182471458401, 0.14621221859540257, 0.1449707844959838, 0.12115058196442467, 0.13761136654232228, 0.16015422690127576, 0.09963967837393284, 0.1484707902584757, 0.23319487114037785, 0.08503431387777839, 0.057492882811597416], [0.05274415887626154, 0.04278330551460385, 0.012710520681659026, 0.04825882866446461, 0.03680821434993829, 0.03292374046785491, 0.006236826718252684, 0.03172927795510207, 0.0730260285948004, 0.08374013725136008, 0.04807315094928656, 0.04146789074210184, 0.015162409516051412, 0.05256085264097367, 0.1045788297695773, 0.11884428214813982, 1.0144387313297816, 31.711936201368058, 41.04449251719883, 26.030177082334244, 23.620875324521744, 26.525246654238018, 42.797623770577566, 47.217292990003315, 57.639052391052246, 58.50684765407017, 51.73271186011178, 57.48900951657976, 50.0540896143232, 52.49202142442976, 24.758582047053746, 0.31948020681738853, 0.8234186928187097, 0.2571065809045519, 7.593506455421448, 46.22095257895333, 57.07722800118582, 58.0132337297712, 57.18312897000994, 58.729711123875205, 57.330326557159424, 56.2982828276498, 56.03912544250488, 58.32552746364048, 56.10433776038033, 52.958148275102886, 53.06634562356131, 51.388261863163535, 48.94376400538853, 47.56217724936349, 47.65641566685268, 45.26791334152222, 45.605217116219656, 49.98786285945347, 51.58615698133196, 54.29140336172921, 53.63090065547398, 53.624018464769634, 53.02801588603428, 53.29243653161185, 52.225405148097444, 50.5077930859157, 47.35999161856515, 42.49032926559448, 40.27228362219674, 39.03568492616926, 37.556802545275005, 37.43362488065447, 35.814145701272146, 37.09013373511178, 39.98339489528111, 43.07740340914045, 48.44906268801008, 52.1292907169887, 53.112690108163015, 45.643692765917095, 38.255843435014995, 35.56484086172921, 36.277455057416645, 36.15088667188372, 34.83721508298601, 33.64961855752127, 34.0300498008728, 34.416466917310444, 35.901988301958355, 40.78221191678728, 47.87146936144148, 33.75805561883109, 11.283126711845398, 38.38515288489205, 45.83880860464913, 42.35190030506679, 38.3978715624128, 35.21266794204712, 35.128316811152864, 34.44410685130528, 35.562857151031494, 35.47242634637015, 36.22911296572004, 35.172257219042095, 36.56287663323538, 38.39005831309727, 43.629399572099956, 50.067332880837576, 47.17028842653547, 44.824729442596436, 40.92149550574166, 39.686314242226736, 38.41418593270438, 36.62332943507603, 35.361244746616904, 34.48050151552473, 37.04916715621948, 35.2803955078125, 36.910439423152376, 38.78745010920933, 40.149519375392366, 40.6547645841326, 41.717276164463584, 40.87248291288103, 42.97209651129586, 46.3329610143389, 48.42527205603463, 48.686367988586426, 48.21876117161342, 48.11477095740182, 49.090728827885215, 47.80382864815848, 46.92317574364798, 42.743024826049805, 45.796733788081575, 46.880965437207905, 48.770250116075786, 50.16018860680716, 48.57315056664603, 42.20457417624337, 43.91271236964634, 50.34202643803188, 50.082441738673616, 47.643384320395334, 50.04550511496407, 50.8555017880031, 54.00245904922485, 50.06817708696638, 29.636019434247697, 5.57017582654953, 0.9626984276941845, 0.24059994093009404, 0.20181566636477197, 3.639740441526685, 32.520320892333984, 50.2320989881243, 51.504397528512136, 53.22402456828526, 52.390873023441856, 54.92860875810896, 49.63466508047921, 55.62460633686611, 39.65145165579659, 26.049470492771693, 22.15746831893921, 22.311589785984584, 32.36217294420515, 2.1006163103239874, 0.28848795699221746, 0.06955125754965202, 0.03885417724294322, 0.041498916755829535, 0.06892695783504418, 0.036268168328596015, 0.03487758544672813, 0.07620476838201284, 0.023203107162511775, 0.028388052779648985, 0.0703820829678859, 0.015802069567143917, 0.016347891617832438, 0.11075605651629822, 0.045635503716766834, 0.038482781100486, 0.035217063301908116, 0.08248329362166779, 0.02731426602362522, 0.03262750904208847, 0.003532674891175702, 0.028450951279540147, 0.04935156859989677, 0.02429309394210577, 0.04227623290249279, 0.028910551885409013, 0.07131865128342595, 0.11755388496177537, 1.7233175103153502, 41.79644741330828, 48.48987293243408, 27.29518869944981, 39.234090736934114, 29.915205001831055, 47.677479130881174, 54.44272123064314, 65.56798921312604, 63.28033651624407, 57.43256235122681, 63.03988715580532, 55.01309885297503, 56.35770034790039, 26.398964881896973, 0.3806077981633799, 0.135976911389402, 0.6094617822340557, 9.910424096243721, 50.067999907902305, 62.8272305897304, 60.908548082624165, 60.47293077196394, 59.295072146824424, 59.63092722211565, 58.84710093906948, 58.42324692862374, 60.75952311924526, 57.31676367350987, 55.82017380850655, 54.143590859004426, 53.194453035082134, 49.62470136369978, 49.53288786751883, 50.496530055999756, 46.35349988937378, 48.295639514923096, 52.62470075062343, 53.52173750741141, 56.64467484610421, 54.804805755615234, 55.340713364737375, 54.681975500924246, 55.856321811676025, 53.69524792262486, 54.19062668936593, 47.16084929874965, 44.658997535705566, 42.66550030027117, 40.71964686257498, 39.74732289995466, 39.16251734324864, 38.861903531210764, 38.560039043426514, 41.28467437199184, 47.932616983141216, 50.05269650050572, 54.45309836523873, 57.44819927215576, 48.40737697056362, 40.8144793510437, 38.74497924532209, 39.44465242113386, 38.264837878090994, 37.3926374571664, 37.35892479760306, 36.555400371551514, 36.552322319575715, 40.306361062186106, 43.121406350817, 50.63980885914394, 36.95476198196411, 14.447568246296473, 42.59239135469709, 48.396860871996196, 43.370530537196565, 40.92280524117606, 37.71130616324288, 38.901820932115825, 37.86294712339129, 38.283146381378174, 37.69795519965035, 37.81344468252999, 37.724893365587505, 39.03082118715559, 39.81514426640102, 45.48222357886178, 51.24184594835554, 48.88236624853951, 47.37827927725655, 43.573018414633616, 41.90510334287371, 40.78779826845442, 40.34435728618077, 37.87687478746687, 36.71808896745954, 39.02269179480416, 36.81893859590803, 39.365713936941965, 39.842714718409944, 40.59164367403303, 42.81087745938982, 43.3323050226484, 44.65435266494751, 45.20939908708845, 48.60839877809797, 49.627279145377024, 51.23254925864083, 50.20876693725586, 49.87737260546003, 51.42975997924805, 49.883969920022146, 48.535605975559776, 45.56960759844099, 47.35522862843105, 47.95423630305699, 51.55255896704537, 52.19451345716204, 51.72954000745501, 43.77788257598877, 46.31337056841169, 49.33096974236624, 52.497385433741975, 49.515322821480886, 51.621592794145855, 52.404626982552664, 53.38709531511579, 51.76133843830654, 32.164382049015586, 5.938227985586439, 1.7861575612000056, 0.5110315382480621, 0.06821957150740282, 3.650077623980386, 35.653350489480154, 56.121482440403526, 56.02214404514858, 58.521327699933735, 57.38310507365635, 60.88916260855538, 54.550869941711426, 64.00828538622174, 42.94522435324532, 36.002087524959016, 26.799245391573223, 27.39747313090733, 42.89825453077044, 2.59665624158723, 0.2890016622841358, 0.15983296771134647, 0.07311446884913103, 0.01948371745779046, 0.045195748563855886, 0.09081596149397747, 0.04017015180683561, 0.03313659690320492, 0.02814701508863696, 0.02741323035609509, 0.03290184414280312, 0.017568691467334117, 0.18969800802213804, 0.32680795075637953, 0.09741718441780124, 0.12145491849098887, 0.15688379667699337, 0.12850816787353583, 0.18096865500722611, 0.13694484159350395, 0.22654806423400128, 0.21455412996666773, 0.11129300163260528, 0.16652676995311463, 0.2545983897788184, 0.14646877268595354, 0.2776084622102124, 0.2362058295735291, 2.9618407487869263, 56.52311263765608, 58.54454857962472, 39.33905369894845, 37.18652956826346, 39.62595871516636, 52.125281606401714, 59.06542028699602, 70.28831045968192, 68.15100983210972, 61.74701499938965, 68.04147148132324, 60.25065789903913, 61.782367433820454, 30.27246400288173, 1.2032381147146225, 3.8607339773859297, 1.1596583617585046, 11.940057175500051, 55.33234773363386, 64.403610093253, 64.57973303113664, 63.4669303894043, 63.56337138584682, 61.371374538966585, 62.62566334860665, 61.25442246028355, 63.84685788835798, 58.897801944187705, 58.33157239641462, 58.10432461329869, 56.78041137967791, 50.337364196777344, 52.24902902330671, 52.476214272635325, 49.85964775085449, 49.01762335641043, 57.202316420418875, 55.5977897644043, 59.69824137006487, 56.32111113412039, 56.801040581294465, 56.434116636003765, 59.21941321236746, 57.350837639399934, 57.26459312438965, 51.50066287176949, 46.683150223323274, 44.717119216918945, 42.342923232487266, 42.11552606310163, 42.38746813365391, 42.46163667951311, 42.32341963904244, 45.44397374561855, 50.29267685753958, 52.55129998070853, 56.72483273914882, 56.57392133985247, 50.211059842790874, 44.57786342075893, 40.67153058733259, 43.2994886807033, 40.07780701773507, 39.97530024392264, 38.723655223846436, 38.111102036067415, 37.12433624267578, 42.61571298326765, 46.066796370915, 56.64046423775809, 36.55316652570452, 10.770029170172554, 44.405777386256624, 54.45997708184378, 46.72574962888445, 44.0107410294669, 39.691897119794575, 41.28930187225342, 39.44536461148943, 41.39193371364048, 39.427743979862754, 39.41849940163748, 39.99974748066494, 40.512746879032676, 41.95585298538208, 46.19543184552874, 53.10197251183646, 52.48208550044468, 47.69145890644619, 44.994449615478516, 43.913573946271626, 42.87945965358189, 41.65238693782261, 40.09251635415213, 38.02445452553885, 40.196450982775005, 37.321498325892854, 41.681802136557444, 42.8112804549081, 43.71465049471174, 45.76310450690133, 46.9105578150068, 46.10191604069301, 47.198220184871126, 51.13378061567034, 52.6589241027832, 53.74376024518694, 53.432863099234446, 50.98509611402239, 52.28702177320208, 52.42726421356201, 50.55262981142317, 46.50534929547991, 49.96952656337193, 51.08926698139736, 53.46404314041138, 55.01305716378348, 54.62418038504464, 47.38831942422049, 49.43695408957345, 50.772686208997456, 52.740235396793906, 49.40356452124459, 54.05523061752319, 53.33266660145351, 55.56931604657854, 53.72084161213466, 34.27865982055664, 7.684030192238944, 3.5275778429848805, 1.4862792811223438, 0.3124372847378254, 5.662665469305856, 42.25902720860073, 60.63351058959961, 60.897562980651855, 64.00460978916713, 62.788536071777344, 65.12830025809151, 60.79358318873814, 67.86262484959194, 51.5269444329398, 36.421824727739605, 32.87707267488752, 36.58130325589861, 54.09829207829067, 6.400859458105905, 0.6483046008007867, 0.31635862003479687, 0.3736079494868006, 0.14955252435590538, 0.16103500606758253, 0.2190221202160631, 0.15100104734301567, 0.1671033754412617, 0.19754322990775108, 0.10444657650909253, 0.16157639558826173, 0.050896952460919104], [0.08538804096835, 0.013498698477633297, 0.025767053510727625, 0.10294204045619283, 0.03002029251573341, 0.037038468423166444, 0.016404817313221947, 0.028425082131954174, 0.02127869364007243, 0.018460635927372744, 0.028696199280342886, 0.045583161525428295, 0.046631874716175456, 0.1884574560182435, 0.027824673635352935, 0.1612747460603714, 0.08582929907632725, 13.030977334295, 46.872971534729004, 28.478124720709665, 21.56506143297468, 27.989146981920513, 43.93289341245379, 46.443534646715435, 37.23014341081892, 60.31113501957485, 53.26497377668108, 55.50453451701573, 50.10658325467791, 52.21977015904018, 24.04023211342948, 0.14595989856336797, 0.4599813318678311, 0.09872084017843008, 11.321580648422241, 49.08617080960955, 58.609076499938965, 59.201014382498606, 59.089113644191194, 60.331993511744905, 57.53828614098685, 56.94070632117135, 58.80700288500105, 55.544073241097585, 54.247598443712505, 53.5079140663147, 53.2126191002982, 51.66853134972708, 51.87156466075352, 48.69404922212873, 46.72505480902535, 44.792931011744905, 45.35811832972935, 46.718791007995605, 50.312135287693565, 53.437157085963655, 52.47998367037092, 53.71719033377511, 52.259194237845286, 53.79661866596767, 52.26549972806658, 49.95168706348964, 46.88289703641619, 40.611112526484895, 38.63223777498518, 38.316358770642964, 36.47656263623919, 37.79467412403652, 36.53648042678833, 39.25947250638689, 40.30483593259539, 43.57038157326834, 45.411074025290354, 52.19548967906407, 49.0065791947501, 39.91079316820417, 35.572626318250386, 36.512481348855154, 35.9645915712629, 37.48982885905674, 34.28181082861764, 34.92739922659737, 34.65350471224104, 35.543127741132466, 37.23114742551531, 42.8185031073434, 47.438061577933176, 37.38208661760603, 8.97044747216361, 38.9870023727417, 48.908415045057026, 40.91273035321917, 40.58342742919922, 35.499427046094624, 35.63016087668282, 35.09215491158621, 35.699562958308626, 35.1873903955732, 37.228253500802175, 34.76016303471157, 34.04243843896048, 34.77361127308437, 38.66136462347848, 44.5223890032087, 52.343847615378245, 51.01633868898664, 46.87639004843575, 43.919066497257774, 38.21111788068499, 35.282827377319336, 35.71995939527239, 36.03030415943691, 35.825353145599365, 35.74921478543963, 35.70061213629586, 37.80857399531773, 38.50898715427944, 39.17917912346976, 43.21130561828613, 42.43844706671578, 43.224931035723, 47.05562925338745, 47.08465882710048, 48.51421594619751, 48.59826135635376, 49.89612231935774, 49.01125880650112, 46.46741213117327, 44.76581914084298, 42.9851348059518, 42.81781523568289, 44.632337297712056, 49.055553572518484, 48.83960703441075, 50.86003201348441, 52.603984696524485, 52.417783396584646, 48.089722701481406, 49.94949838093349, 50.58068316323416, 50.78043345042637, 54.707836696079795, 53.85462917600359, 50.92079748426165, 21.65330355507987, 5.078997680119105, 0.8725892486316817, 0.23349057670150483, 0.09249208548239299, 0.36559244245290756, 21.965133496693202, 57.0126097542899, 50.03383561543056, 54.441508769989014, 50.24034649985177, 51.83874831880842, 57.13838951928275, 52.61307641438076, 31.93500116893223, 25.487519298280986, 18.016619886670792, 40.48941135406494, 18.542515141623362, 0.17995062177734716, 0.05824713555297681, 0.025479617595140423, 0.01964648104538875, 0.03869549843615719, 0.051525231783411334, 0.020029831278537, 0.049155655183962414, 0.025553615231599127, 0.0310574943598892, 0.03926952549123338, 0.038932106989834986, 0.012999953186538602, 0.01091245886137975, 0.019295544430081333, 0.006049332649646593, 0.099197307468525, 0.03476253644164119, 0.0457719231822661, 0.013423534609111292, 0.03382018022239208, 0.05581850605085492, 0.040592465217092207, 0.05091565627870815, 0.016145121605534638, 0.07288378729884114, 0.032153952667223554, 0.014905775697635753, 0.12915190761642797, 0.1680601912417582, 15.73220157623291, 58.4574042728969, 25.501763105392456, 31.768470219203405, 35.416152885981965, 46.03139182499477, 52.98831040518624, 41.63383872168404, 66.1014302117484, 57.43928473336356, 60.70864840916225, 55.20551184245518, 56.99267537253243, 26.449344532830374, 0.14321004040539265, 0.336214970265116, 0.5060475628290857, 13.508500967706953, 51.216012545994346, 60.482533182416645, 64.55364949362618, 62.28205408368792, 62.33841092245919, 59.526843207223074, 58.01548842021397, 60.646969250270296, 60.44467939649309, 59.04987021854946, 57.330149378095356, 54.19148479189192, 54.824417046138215, 51.45064973831177, 50.720665046146934, 48.68132012231009, 45.96169444492885, 48.16455132620675, 48.94268356050764, 53.01022849764143, 55.11881569453648, 54.63621466500418, 54.49204649244036, 54.16606133324759, 56.11487122944423, 54.297771385737825, 54.20093086787632, 49.477538517543245, 43.04737329483032, 42.212126868111746, 41.34103121076311, 39.766388756888254, 41.026590483529226, 38.544878074101035, 41.018829345703125, 43.91510602406093, 46.444736685071675, 48.000087465558735, 54.97395617621285, 53.516015665871755, 44.692241191864014, 37.424668652670725, 39.87029559271676, 37.71371371405465, 39.841585636138916, 36.79143762588501, 37.484249455588206, 35.65032107489449, 36.23724235807146, 40.547519138881135, 45.26019736698696, 49.27554048810686, 41.71633120945522, 13.86419141292572, 40.88539266586304, 51.06943334851946, 44.61758974620274, 41.711345876966206, 37.310179710388184, 38.08869062151228, 36.685081550053184, 37.38222210747855, 36.39718988963536, 38.19379949569702, 36.05504322052002, 36.785378796713694, 35.41122661318098, 41.04517691476004, 46.81522158214024, 54.667877605983186, 52.05298212596348, 48.06386498042515, 45.16161285127912, 41.58306128638131, 37.787680762154714, 38.40864127022879, 39.09385177067348, 37.1565272467477, 37.81575148446219, 37.965255873543875, 39.567969049726216, 40.994079862322124, 41.88126754760742, 42.84115423474993, 45.53728110449654, 45.7586715562003, 48.4053133555821, 49.83163261413574, 50.05895682743618, 50.852347305842805, 50.93134137562343, 50.29749543326241, 47.82774434770857, 46.74808808735439, 43.94392715181623, 45.35935858317784, 46.697644165584016, 50.17810106277466, 51.23123604910714, 54.07995925630842, 52.404088497161865, 53.68079219545637, 51.93015881947109, 52.829794202532085, 52.719887597220286, 53.820930412837434, 55.86028923307146, 54.21426098687308, 52.976901463099885, 24.21527808053153, 5.687262526580265, 2.2433006082262312, 0.7811181683625493, 0.08529679157904216, 0.7845577437962804, 24.704898527690343, 61.2029641015189, 53.84038536889212, 60.30670206887381, 56.83200870241438, 56.63587147848946, 60.371653829302105, 59.90787546975272, 37.320633275168284, 34.79577602658953, 20.02754667827061, 47.30383627755301, 23.878321715763636, 0.149242868114795, 0.045933533260332685, 0.015872588015294502, 0.02855061280674168, 0.0891618084694658, 0.009914467011445334, 0.024699594093752757, 0.026866019004955888, 0.022252561025587574, 0.025455670397994772, 0.051794827317020724, 0.07512977892266852, 0.03729227783956698, 0.23614584707788058, 0.09090538562408515, 0.09244492051324674, 0.36242949217557907, 0.18282619890357765, 0.10229830749865089, 0.13678770645388535, 0.10485593668584313, 0.10716535097786359, 0.15183230702366146, 0.11418008671275207, 0.13789366425148078, 0.1357119841767209, 0.21542390329497202, 0.14329763927630015, 0.2581368956182684, 0.2952882620905127, 25.458890983036586, 67.57629653385708, 41.972149985177175, 32.98553058079311, 39.58504772186279, 57.22266074589321, 58.502588408333914, 50.23546886444092, 71.79343618665422, 65.14578192574638, 66.79205335889543, 60.07550770895821, 63.27786990574428, 29.91999578475952, 1.3550759043012346, 2.0371929364545003, 0.9328010891165052, 16.863107749394008, 55.72532742364066, 63.12983853476388, 65.63417775290353, 66.67305850982666, 65.0825116293771, 60.912842069353374, 60.86198125566755, 63.68760517665318, 62.460636683872764, 62.187655857631135, 60.392415046691895, 57.81365714754377, 57.30512196677071, 53.643709659576416, 54.24838706425258, 52.7519986970084, 49.175906794411794, 50.297825472695486, 53.489553451538086, 55.75978354045323, 59.47998455592564, 55.03043808255877, 57.67996685845511, 55.98258795057024, 58.26320559637887, 57.15706280299595, 55.9976863861084, 52.36365345546177, 43.9235063961574, 44.45901100976126, 43.76561205727713, 41.758343492235454, 44.25354582922799, 42.3046247618539, 44.35418701171875, 47.88212442398071, 48.84253570011684, 51.08304834365845, 57.43801668712071, 56.125984873090474, 44.55409710747855, 39.96568046297346, 41.24026148659842, 39.847665309906006, 42.84366600854056, 38.96503564289638, 38.796062401362825, 39.81371988568987, 39.464190755571636, 42.89026410239083, 48.05223022188459, 51.294971874782014, 39.97384112221854, 8.37628356048039, 42.391793387276785, 55.143784046173096, 46.37011650630406, 45.52853332247053, 40.32298810141427, 40.491061551230295, 38.32652051108224, 39.200391973767964, 39.21381936754499, 41.91511917114258, 39.332466806684224, 38.34564890180315, 38.40262413024902, 43.15198884691511, 47.36051968165806, 55.912713391440256, 51.78829050064087, 49.614553519657676, 49.19357606342861, 42.79731110164097, 38.9069174357823, 41.28867653438023, 40.20466375350952, 38.60526139395577, 39.406100341251914, 39.628209931509836, 41.3806220463344, 44.117927415030344, 43.32281378337315, 46.374959400721956, 48.26011684962681, 48.01651995522635, 49.31776121684483, 51.8584429877145, 52.31466865539551, 54.19152648108346, 52.773600646427695, 52.66953747613089, 50.73163972582136, 48.66081598826817, 47.14726904460362, 46.99266120365688, 48.25869246891567, 52.05164112363543, 53.1796429497855, 56.257236344473704, 53.11638307571411, 55.26618698665074, 53.92403820582798, 54.937453814915244, 54.614532811301096, 56.056499413081575, 59.72014904022217, 56.40544836861746, 54.70686742237636, 27.9393926688603, 6.572090429919107, 4.250838415963309, 1.5639624212469374, 0.2401383471276079, 1.5635488948651721, 30.214179039001465, 66.31234972817558, 57.713339056287495, 64.77989673614502, 60.58615861620222, 61.242568833487375, 64.92269611358643, 64.00358145577567, 45.08805922099522, 38.51949977874756, 30.710540975843156, 58.40567493438721, 38.03458499908447, 0.25374229571649004, 0.14626057100083145, 0.15533806676311152, 0.09394903587443487, 0.1872521878353187, 0.10255585903567926, 0.09488303932760443, 0.09394980940435614, 0.14392955893916742, 0.12015808879264764, 0.14249711723199912, 0.12344641877072197, 0.09972916357219219], [0.022018863387139778, 0.04520982816549284, 0.077855664438435, 0.10341372407440629, 0.06491233754370894, 0.016733369058264152, 0.021079197559239607, 0.04362893656694463, 0.09446787767644439, 0.014584375711690103, 0.032850886162902625, 0.015913003257342746, 0.008271240097071444, 0.03366896530081119, 0.030143249846462692, 0.035261510738304684, 0.07756530573325497, 1.5422261761767524, 38.322421073913574, 40.93131331035069, 26.75221824645996, 27.033679349081858, 31.618746961866105, 68.02353123256138, 48.04894372395107, 53.82114928109305, 55.32243612834385, 55.726543358394075, 51.632921831948416, 52.93588277271816, 21.539393050330027, 0.34830356016755104, 0.26407529839447563, 0.15620417600231512, 13.853033474513463, 52.40427957262312, 57.3815347807748, 57.57692159925188, 61.365732601710725, 58.729454040527344, 57.71035133089338, 57.060371671404155, 58.31586251940046, 59.03402137756348, 53.6044453893389, 56.2137336730957, 54.271670477730886, 52.6642290524074, 50.73988723754883, 48.535401003701345, 46.190814767565044, 45.892664091927664, 42.45807572773525, 43.6611841065543, 46.90248053414481, 48.5060761315482, 53.43552425929478, 51.91008199964251, 52.17473888397217, 54.44034842082432, 54.63868474960327, 52.99347986493792, 43.72019863128662, 39.78558315549578, 38.2214845929827, 37.33810799462454, 35.634948185511995, 37.348297527858186, 38.44117621013096, 39.99968842097691, 42.53216436931065, 43.823893547058105, 46.35006053107125, 49.15851197923933, 40.67767974308559, 34.550264903477256, 37.00921501432146, 35.96543230329241, 36.09354318891253, 35.91186169215611, 33.62499066761562, 33.955610275268555, 35.36775173459734, 36.55506338391985, 39.36198622839791, 44.833213193076, 44.71371807370867, 40.76230532782418, 9.78547203540802, 36.67419719696045, 51.647909096309114, 41.82873221806118, 41.34323031561715, 35.36950615474156, 36.72310209274292, 36.02950164249965, 36.943797724587576, 35.379247529166086, 36.76791449955532, 35.73915031978062, 36.83841092245919, 34.70397642680577, 36.47654526574271, 38.59199728284563, 45.344267095838276, 51.436009883880615, 47.83433818817139, 42.285683972494944, 40.536999566214426, 38.08530337469918, 35.774210929870605, 35.886948926108225, 36.11428008760725, 34.20908750806536, 35.67779425212315, 36.20392574582781, 38.25194549560547, 39.56439420155117, 39.0776173046657, 43.399309975760325, 45.273760250636506, 45.23918948854719, 48.98468542098999, 49.473696163722444, 51.17105770111084, 49.55829395566668, 47.51115662711007, 44.328541210719514, 40.730138642447336, 42.41988148008074, 43.71396262305123, 45.69315004348755, 48.22231864929199, 49.8079114641462, 51.41512707301548, 47.93256834575108, 46.081585611615864, 48.86095537458147, 48.212295872824534, 48.974930150168284, 51.349886962345664, 52.710643018995015, 52.90612016405378, 51.26002590996878, 18.777869735445293, 5.374314793518611, 1.728193734373365, 0.5654001608490944, 0.09881914633193187, 0.23956072383693286, 26.45787344660078, 56.138324873788015, 47.96439109529768, 51.50036409923008, 49.11197641917637, 59.90390110015869, 52.40915025983538, 46.00302233014788, 28.085278783525737, 21.94191609110151, 30.1668062210083, 40.17714541299002, 2.725998261145183, 0.344152608620269, 0.08178030420094728, 0.025035765787054385, 0.05294377709339772, 0.03531204124114343, 0.040810278350753446, 0.047434720742915354, 0.03414806530677846, 0.038469247719539065, 0.029707535369587795, 0.02699227910488844, 0.013291566333334361, 0.019504204126341, 0.04538892409099, 0.02708232239820063, 0.051030362623610666, 0.1002963509942804, 0.06640565741275038, 0.0211325422860682, 0.03963413289082902, 0.050368451712919135, 0.11288820353469678, 0.012542678259446152, 0.028944539704493115, 0.06484841954495225, 0.10766541093055691, 0.054964193142950535, 0.02623012991222952, 0.04527197518785085, 0.03726070221247418, 1.8592209092208316, 48.310491289411274, 42.74411916732788, 24.345040900366648, 42.142109870910645, 34.72590146745954, 74.66394547053746, 51.44373280661446, 59.79824679238455, 59.41556780678885, 61.62037018367222, 55.304850237710134, 58.64604786464146, 23.98882586615426, 0.2919416188129357, 0.17098133877984115, 0.3077580529664244, 16.60825824737549, 56.69191912242344, 59.57625879560198, 60.520852497645784, 63.39815711975098, 59.63580485752651, 60.527661732264924, 60.970407894679475, 60.69364724840437, 60.26322719029018, 56.29268257958548, 58.49388926369803, 55.28847680773054, 53.21309852600098, 53.84235865729195, 51.63819898877825, 48.99495138440813, 47.25795384815761, 44.44710179737636, 46.091799463544575, 49.445458684648784, 52.24001373563494, 56.3045778955732, 54.71151229313442, 54.756262166159495, 54.913958481379915, 54.92817102159773, 54.53624745777675, 46.32639496667044, 41.37163455145699, 42.05633783340454, 39.16770069939749, 38.96098484311785, 41.829440934317454, 40.627576283046174, 41.22646583829607, 45.881842272622244, 45.63595942088536, 48.7281996182033, 50.18174539293562, 46.18456138883318, 39.165380001068115, 38.04984324319022, 37.20599494661604, 36.202970368521555, 38.43505137307303, 36.883271966661724, 37.270734786987305, 37.58514772142683, 38.87799555914742, 41.10044636045183, 46.98748132160732, 46.08116177150181, 47.160362924848286, 17.44611372266497, 41.122836930411204, 53.188005106789724, 43.777285030909944, 44.142725535801475, 37.545963355473106, 38.54294300079346, 37.97397586277553, 38.43185520172119, 36.75536952699934, 37.807302474975586, 38.41588476725987, 38.88546487263271, 38.15042189189366, 37.669780254364014, 42.68403809411185, 48.77586426053728, 52.523180621010916, 48.60259703227452, 44.49383190699986, 41.74726458958217, 39.58445365088326, 38.527250494275776, 36.732357093266074, 37.69298376355852, 37.073287827628, 37.65865271432059, 38.9917688369751, 41.00477313995361, 41.69895029067993, 41.97161149978638, 45.44669049126761, 46.72867134639195, 47.63796819959368, 48.59642008372715, 50.59547587803432, 55.162450381687705, 51.5522324017116, 50.163252762385774, 44.03904104232788, 42.68686253683907, 44.57474020549229, 46.781922340393066, 46.95895201819283, 50.595847606658936, 51.81903280530657, 53.16010114124843, 49.56607941218785, 47.99909734725952, 50.565980775015696, 50.201943806239534, 52.097978660038535, 54.07523100716727, 54.597148418426514, 55.62471750804356, 52.906679494040354, 21.998886108398438, 5.172639855316707, 2.6202942303248813, 0.6238994332296508, 0.18438491597771645, 0.06706851148711783, 30.203367641993932, 61.541702679225374, 53.57671512876238, 57.86629670006888, 54.30335078920637, 64.17538261413574, 59.901691573006765, 49.801793575286865, 34.65436628886631, 28.251828840800695, 30.00806072780064, 49.94710125241961, 4.25892264502389, 0.2649664862879685, 0.07447402232459613, 0.0418242539412209, 0.056635414715856314, 0.019571119553542564, 0.06492697354406118, 0.03937047793130789, 0.02156042816516544, 0.06337512324431113, 0.017167307469727736, 0.027007325618926967, 0.03832711838185787, 0.017634293929274594, 0.15676783504230635, 0.21602454249347958, 0.17162031520690235, 0.28623782630477634, 0.18558392806776933, 0.10516005608120135, 0.1188519224524498, 0.1600343297634806, 0.12729128317109176, 0.24577504609312328, 0.16772768194121973, 0.17736700469894068, 0.229957607707807, 0.20552216390413897, 0.06511198968759604, 0.17084283621183463, 0.35770213870065554, 4.152046322822571, 62.881739207676475, 55.73052815028599, 39.43193374361311, 40.87539073399135, 44.537442275456016, 82.18537044525146, 60.54840905325753, 63.14828600202288, 65.19019481113979, 66.08030073983329, 60.86612933022635, 64.7241860798427, 27.850031886781963, 0.4991895279714039, 1.0505531877279282, 0.7070863065975053, 20.23827859333583, 60.4926358631679, 60.79018551962716, 64.09236553737095, 67.15832764761788, 64.51370429992676, 63.07013266427176, 62.22307777404785, 64.51472568511963, 63.820336614336284, 57.90011705671038, 61.78671700613839, 59.317000661577495, 56.71964938299996, 56.73305245808193, 54.53143583025251, 51.90941844667707, 50.41336011886597, 47.69576678957258, 48.03827476501465, 52.04600266047886, 52.58355699266706, 58.851221220833914, 56.59805243355887, 57.99668312072754, 60.683593205043245, 59.54431792667934, 59.84518882206508, 48.231083801814485, 43.20342983518328, 43.94040094103132, 41.57798910140991, 41.79868125915527, 44.73849187578474, 43.676018510546, 45.59303344999041, 47.870969091142925, 48.90199143545968, 50.903413091387065, 52.69599969046456, 47.057922158922466, 40.97958592006138, 41.845046588352744, 38.50385938371931, 39.0238938331604, 41.27253586905343, 38.12520687920706, 37.8762320790972, 39.04077100753784, 42.32595920562744, 44.26370062146868, 50.188790866306846, 47.70741197041103, 45.73489482062203, 10.802504181861877, 41.98626872471401, 59.38072953905378, 46.59232684544155, 47.39136273520333, 39.013454164777485, 42.37322085244315, 41.19494186128889, 40.93014253888811, 38.437611784253804, 40.52285998208182, 40.409253461020334, 41.04493372780936, 39.72632196971348, 39.781105041503906, 43.60796437944685, 50.376037870134624, 54.863142830984934, 50.409250259399414, 47.39393356868199, 44.56248358317784, 41.89049128123692, 39.02096864155361, 40.439551080976216, 38.71298973900931, 39.27931656156267, 39.48582397188459, 40.08482469831194, 42.59119626453945, 43.3419908114842, 43.1546083177839, 46.54244920185634, 49.24507958548409, 48.67982625961304, 52.09091581617083, 52.23852334703718, 56.51820720945086, 55.12873077392578, 54.076610224587576, 46.5922087260655, 44.55910675866263, 46.928616183144705, 49.52671439307076, 50.36522299902779, 51.77615894590105, 53.97563900266375, 57.96068102972848, 50.41084834507534, 49.64173139844622, 51.24936389923096, 52.70096417835781, 52.53131348746163, 55.6724967956543, 56.268839836120605, 57.635491439274375, 56.539128235408235, 26.11932941845485, 5.608103437083108, 3.4372482214655196, 1.773903978722436, 0.5281420743891171, 0.30573154027972904, 31.331841945648193, 66.43360274178642, 55.82901886531285, 61.70624991825649, 57.257825578962056, 69.50893102373395, 63.01739583696638, 59.343765122549875, 39.84211022513253, 35.73295947483608, 40.723715032849995, 62.414486748831614, 10.202625376837593, 0.5064686345202583, 0.20663160937173025, 0.14911868263568195, 0.13586637803486415, 0.12818637942629202, 0.12785956981991017, 0.10387977585196495, 0.16794424317777157, 0.1506959508572306, 0.07664116139390639, 0.1701366848179272, 0.25095427674906595, 0.05048712748768074], [0.06998518069407769, 0.04796221047373755, 0.025873444408976605, 0.11526187509298325, 0.06136689707636833, 0.050143133981951644, 0.0057246638212486035, 0.08900453762284347, 0.005652349375720535, 0.01615808162439082, 0.03247154776805213, 0.04551092129466789, 0.09197481788162674, 0.07021031861326524, 0.02783468541955309, 0.043827567515628676, 0.018780324308733855, 0.05707617410059486, 12.750755616596766, 47.67975466591971, 31.344553674970353, 24.453627347946167, 27.918068647384644, 49.07817343303135, 61.86965070452009, 57.07806873321533, 55.65706484658377, 54.33091081891741, 53.354834829057964, 55.01478031703404, 19.09533987726484, 0.4178817623427936, 0.37232418837291853, 0.07096577236162764, 19.91803785732814, 64.38114656720842, 60.33808708190918, 62.18236133030483, 59.81561034066336, 56.947505133492605, 58.19626317705427, 60.10055596487862, 58.592345237731934, 56.82424061638968, 54.569699559892925, 56.36372096197945, 54.74239008767264, 54.83151463099888, 52.495182854788645, 48.51581403187343, 47.70939915520804, 45.79634121486119, 43.2000321660723, 40.64553737640381, 41.70814275741577, 44.418728828430176, 46.988033703395296, 51.98462922232491, 52.48475360870361, 51.42467737197876, 54.81939002445766, 48.98750638961792, 42.03844969613211, 41.14730153764997, 37.7425730569022, 34.70902081898281, 34.57485457829067, 37.71274791445051, 41.15389537811279, 41.687777587345664, 41.3232855115618, 43.25649322782244, 44.926506655556814, 40.32646220070975, 37.3539012500218, 35.76282978057861, 34.5858188356672, 35.674473013196675, 36.257378237588064, 37.9684659412929, 34.62235941205706, 36.04431520189558, 33.81615645544869, 36.71776935032436, 39.45173263549805, 46.91737052372524, 46.14432437079293, 44.94356100899832, 11.366289700780596, 36.305699484688894, 53.82223667417254, 43.059098379952566, 43.762461049216135, 35.88438504082816, 36.077857630593435, 34.3813750403268, 36.231944356645855, 33.46007169995989, 36.982572146824424, 35.870585918426514, 35.36603900364467, 35.67155476978847, 35.71844121388027, 34.92389038630894, 37.96898358208792, 46.75847217014858, 46.59921945844378, 42.94113533837454, 41.62669249943325, 39.242254870278494, 37.90820074081421, 37.32619530814034, 36.93527923311506, 35.9994854245867, 36.457625320979524, 37.33953584943499, 36.857942308698384, 37.88027593067714, 38.18544428689139, 41.664362158094136, 43.06028652191162, 46.726482663835796, 47.74553673607962, 48.6235145841326, 45.85907997403826, 47.65165615081787, 43.86736147744315, 42.585172176361084, 38.892319270542686, 40.6299386705671, 42.315988540649414, 45.95383950642177, 47.64304038456508, 51.13216863359724, 50.64702108928135, 46.04476015908377, 47.81464351926531, 49.12301015853882, 50.41970035008022, 51.78276668276106, 50.89739942550659, 51.56223085948399, 53.74593503134591, 50.87957034792219, 16.234254087720597, 5.274936880384173, 1.1856310537883212, 0.8627065760748727, 0.055574450575347455, 0.047381255576120954, 28.80104398727417, 56.106262411390034, 52.140539850507466, 47.596522194998606, 53.82567950657436, 54.85425608498709, 46.40302664893014, 37.10807745797293, 25.021071093423025, 24.374150378363474, 33.874146120888845, 24.976955243519374, 0.11265387146600656, 0.01992928426313613, 0.037664817313530614, 0.06910229806921311, 0.06305774527468852, 0.04248449904844165, 0.05473137081467679, 0.025442296472777213, 0.044606288229780536, 0.05844089122755187, 0.04997501675305622, 0.06000021219785724, 0.007812922770556594, 0.07562553017799344, 0.07618902636958019, 0.09490743944687502, 0.02305984976036208, 0.17489674368074962, 0.09749069011637143, 0.07666483548070703, 0.05707677799676146, 0.02036275787811194, 0.029525396214532, 0.0606458450534514, 0.06068452833486455, 0.03486018780884998, 0.01651720646103578, 0.05027998431718775, 0.04908603409837399, 0.034429467349712334, 0.031870162181024037, 0.0895418898601617, 16.84319073813302, 56.92503118515015, 25.160722936902726, 36.13421099526541, 36.39069332395281, 54.668735708509175, 70.8308744430542, 63.07264791216169, 61.38471508026123, 59.24410016196114, 59.51301629202706, 59.6710113797869, 20.985531296048844, 0.47970314217465265, 0.20426919470940316, 0.017074322727109705, 24.17379038674491, 66.19878142220634, 62.670173508780344, 63.44293131147112, 63.92831856863839, 60.241069384983604, 61.28170803615025, 60.77783857073103, 61.643354824611116, 59.548521586826865, 58.793940271650044, 57.89492327826363, 57.29836136954171, 56.84832307270595, 56.20396450587681, 49.667721135275706, 50.92523390906197, 46.00619765690395, 45.25558376312256, 44.38970272881644, 44.88737440109253, 47.19314799989973, 50.75380447932652, 52.752728257860454, 52.947496686662944, 54.50105135781424, 55.46431834357125, 49.168361050742014, 43.99020562853132, 42.47099937711443, 39.932325635637554, 37.942267758505686, 36.58233158929007, 40.658113615853445, 42.255431515829905, 44.19605295998709, 43.859377997262136, 46.72501311983381, 47.81477900913784, 45.14180701119559, 39.052315439496724, 37.93259239196777, 36.65784113747733, 38.68833058220999, 37.17562089647566, 40.048819133213584, 36.79593311037336, 38.14006560189383, 36.929150921957834, 38.8029202733721, 39.80481924329485, 47.95934322902134, 49.26660510471889, 51.53861740657261, 23.877632107053483, 38.82989318030221, 56.83816133226667, 44.49157721655709, 45.50498587744576, 38.679777349744526, 37.24326508385794, 36.77235092435564, 37.430446079799104, 37.70454904011318, 39.29845884868077, 37.95343698774065, 36.75345182418823, 37.589344433375764, 37.45247186933245, 38.39729486192976, 43.01977852412632, 49.90275090081351, 48.32570089612688, 45.300361428942, 43.33367034367153, 42.08830302102225, 39.65531485421317, 38.08080441611153, 38.50785459790911, 37.339473315647666, 39.34510905402047, 39.730424880981445, 40.10921287536621, 39.81279230117798, 38.85510471888951, 43.37220852715628, 44.611378056662424, 48.857040064675466, 49.63541896002633, 50.89085422243391, 49.08408635003226, 48.60956260136196, 46.11599309103829, 43.55420616694859, 41.392930780138286, 42.70199223927089, 43.77753864015852, 47.64293616158621, 49.669649260384695, 53.34437779017857, 52.45304550443377, 47.90274320329939, 49.31594426291329, 51.02857446670532, 52.76141003199986, 53.48456811904907, 54.17117520741054, 53.792095388684956, 55.214040756225586, 53.08353546687535, 20.456500666482107, 5.005600384303501, 2.8482348791190555, 1.399934560060501, 0.1251807135662862, 0.36313400151474134, 34.38888604300362, 60.84742477961949, 57.4039739881243, 53.311676093510215, 57.34132208142962, 57.14382301058088, 52.8975704056876, 40.64979314804077, 34.6814329964774, 23.71349307468959, 38.88120215279715, 31.16307715007237, 0.2521581064377512, 0.04261553094589284, 0.011717019037210515, 0.04270012390666774, 0.10720489599875041, 0.07488963180886847, 0.055030828674456904, 0.0240955791835274, 0.0219445790696357, 0.06466028892568179, 0.034974039199629, 0.03761158624131765, 0.05483083387038537, 0.0470434672731374, 0.279500244983605, 0.1300216538033315, 0.09952082618006639, 0.3248765143964972, 0.19614449782030924, 0.18446434528699943, 0.12403552287391253, 0.11206891999713012, 0.1049657372225608, 0.18537621492786066, 0.11711690840976578, 0.19124865052955492, 0.1867202299513987, 0.1635734869965485, 0.14635439882321016, 0.3445685234452997, 0.17154927259044989, 0.20291011620845112, 28.738498040607997, 67.76130621773856, 44.04908118929182, 38.95569378989083, 40.77840082986014, 61.40430900028774, 76.62032195499965, 66.71283694675991, 65.95958273751395, 66.07845946720668, 63.16230051858084, 65.76160076686314, 23.686176231929235, 0.6043301575950214, 0.7910860106348991, 0.3993274122476578, 27.337103707449778, 70.07817608969552, 63.18244334629604, 67.1818403516497, 68.99814810071672, 62.258437156677246, 62.17855371747698, 63.28213609967913, 64.37828390938895, 61.77542618342808, 61.523310797555105, 60.16231155395508, 61.42774527413504, 60.623498235430034, 58.684367179870605, 51.242922919137136, 53.905507360185894, 50.57142121451241, 47.25789826256888, 46.68413686752319, 47.14488928658621, 49.275276456560405, 53.88680975777762, 55.31249673025948, 57.83999082020351, 58.090424742017476, 57.94186878204346, 52.47199324199131, 46.75240291867937, 45.6241648537772, 43.57872288567679, 40.06365353720528, 39.02719075339181, 44.37249551500593, 46.240827901022776, 48.71108620507376, 45.846642698560444, 49.7849337714059, 50.510256222316194, 44.46475369589669, 41.842086655753, 40.608291557856965, 37.82924836022513, 40.11429895673479, 40.37471396582467, 44.277621337345664, 38.37602295194353, 40.675973960331504, 38.37868758610317, 41.254630361284526, 43.715623242514475, 51.10235391344343, 49.88717303957258, 50.32883528300694, 14.454812611852374, 36.1182405608041, 61.39629772731236, 47.696951457432334, 49.39820746013096, 40.94720384052822, 39.67454399381365, 40.37117385864258, 39.471496786390034, 36.64339583260672, 42.043254375457764, 39.605013370513916, 39.96363769258772, 38.828982966286794, 39.304427351270405, 39.29259456907, 42.49071489061628, 50.81401409421648, 50.688776288713726, 48.06717927115304, 46.555588245391846, 44.265170165470664, 40.806277002607075, 40.251230580466135, 41.10902043751308, 39.624589920043945, 41.00935895102364, 40.99761996950422, 40.87624536241804, 41.654130935668945, 41.8568411554609, 45.673344203404014, 47.18112414223807, 51.02033390317644, 52.70480653217861, 54.09235136849539, 49.633376189640586, 51.50005490439278, 49.01121016911098, 46.47675745827811, 42.10111549922398, 46.33529560906546, 45.98695114680699, 51.425632749285015, 52.160905020577566, 55.04469231196812, 56.97249085562569, 50.72026205062866, 51.101405484335764, 54.31760849271502, 55.81126969201224, 56.55918073654175, 55.26587779181344, 55.29464680807931, 56.69376039505005, 55.390174116407124, 25.76933475903102, 5.584461757114955, 4.221335930483682, 1.6626076251268387, 0.1983676092433078, 0.49480217482362476, 37.71764986855643, 64.74273082188198, 61.38324901035854, 56.69749852589199, 62.20591572352818, 64.69448253086635, 57.06716353552682, 49.783554553985596, 38.361747877938406, 37.10186576843262, 48.139468329293386, 45.450536319187705, 0.39525606642876354, 0.23540171129362925, 0.07796951582921402, 0.11339575451399599, 0.17361203261784144, 0.24864275221313747, 0.13625448649483068, 0.16388657662485326, 0.11405107006430626, 0.2081756836601666, 0.11099499583776508, 0.2309665349977357, 0.09245146159082651, 0.1039083150348493], [0.048150497156062295, 0.054258767781513076, 0.006355414707546255, 0.09611152019351721, 0.02884883912546294, 0.04533864464610815, 0.05000199530539768, 0.004763304380633469, 0.019849508900993636, 0.03069598786532879, 0.043878488176103146, 0.019534183499802436, 0.10015534463205508, 0.023137950837346058, 0.03470676425578339, 0.03863872880382197, 0.06312019763780491, 0.03461536219609635, 0.7917963553752217, 32.421354225703645, 37.95956877299717, 25.209429809025355, 22.355995723179408, 37.606805256434846, 58.105370317186626, 56.49168593542916, 53.90908915655953, 57.435115814208984, 50.66836595535278, 53.76537609100342, 20.57116331372942, 0.13732551330966608, 0.27431713310735567, 1.3193455530064446, 46.75025939941406, 59.53337451389858, 56.95315749304635, 62.571550777980256, 58.50770228249686, 54.39861059188843, 58.668872697012766, 57.167947156088694, 58.336463928222656, 58.397552490234375, 58.89737115587507, 56.387914589473176, 54.269165652138845, 55.80970287322998, 55.83704056058611, 50.08282388959612, 46.7059576851981, 44.61469234739031, 41.28060967581612, 41.66786405018398, 42.03991229193551, 40.250535760607036, 41.518509047372, 43.78201675415039, 46.75101327896118, 46.85424961362566, 47.54499435424805, 42.07311773300171, 40.20502158573696, 39.545422145298545, 38.46287890842983, 36.19813094820295, 36.29934883117676, 39.47551284517561, 41.55398307527815, 39.88090896606445, 39.67963702338082, 42.72375052315848, 41.3534163747515, 37.60592630931309, 36.977437428065706, 35.18131072180611, 33.4636743409293, 35.051844937460764, 34.653991086142405, 36.13177912575858, 33.14585678918021, 36.60257863998413, 34.6775142124721, 38.923919677734375, 39.630075522831504, 50.116776262010845, 48.118870394570486, 51.90103197097778, 18.21602623803275, 31.138185228620255, 56.61185155596052, 43.21835456575666, 45.07764734540667, 38.36265809195382, 37.77222449438912, 34.8313820702689, 34.22753497532436, 34.5440844808306, 35.338934080941335, 34.70286124093192, 36.365770135607036, 34.887141363961355, 36.51834910256522, 35.28319910594395, 36.17837374550955, 38.74252653121948, 43.59859125954764, 41.67365189961025, 40.5777542250497, 38.38921063286917, 41.0352965763637, 37.880088329315186, 37.0862774848938, 35.97959968021938, 36.22478771209717, 36.55259329932076, 36.74065671648298, 39.24641336713518, 37.25082472392491, 39.93040793282645, 38.9604081426348, 42.27378865650722, 45.55232048034668, 46.23984125682286, 44.72496720722744, 43.93162189211164, 38.25273411614554, 39.410706996917725, 38.77044439315796, 40.329727854047505, 44.952659675053184, 45.15790946143014, 49.38240030833653, 51.33871078491211, 53.5235926764352, 49.16657536370413, 46.20655243737357, 47.103061131068635, 48.390343461717876, 47.16437898363386, 49.383324418749126, 56.4064176423209, 54.27446365356445, 56.861093861716135, 15.42870773587908, 3.0737186883177077, 0.35544557550123757, 1.1349380825247084, 0.19862241271351064, 0.2856291261102472, 36.39844403948103, 56.58106061390468, 49.79940339497158, 49.93554639816284, 58.033484254564556, 56.75745453153338, 49.17016063417707, 26.536094529288157, 24.235568557466777, 30.44506072998047, 39.87053877966744, 7.1708853159632, 0.5104422984378678, 0.015501441234456641, 0.11377402421619211, 0.04471066048634904, 0.050418225649212084, 0.035547347007585425, 0.03786715645609157, 0.08905595022120646, 0.01896702321911497, 0.059629080684057305, 0.06804204639047384, 0.04088431330663817, 0.03161566744425467, 0.052140676616025824, 0.032323186086224656, 0.06070404300200088, 0.04170186657990728, 0.09606782932366643, 0.05488697246515325, 0.03496158129668661, 0.03475512005388737, 0.030896098020353487, 0.026565916536908065, 0.05202599062717386, 0.06847225116299731, 0.04259154473298362, 0.007947913071672832, 0.01725089959135013, 0.05865794100931712, 0.04466346837580204, 0.0577844696651612, 0.06793343329003879, 1.4598577788897922, 44.59043618610927, 39.092809540884836, 23.656920841762, 37.12111575262887, 42.173237800598145, 65.3697293145316, 61.093898228236604, 63.402916635785786, 62.925026484898154, 56.25976201466152, 58.7518550327846, 22.9391701902662, 0.18353771072413239, 0.1694457054670368, 1.4909588928733553, 50.29150261197771, 61.563269887651714, 60.424751962934224, 64.38556562151227, 62.98026466369629, 58.03516571862357, 60.44615936279297, 60.017670903887065, 62.03749833788191, 59.87054279872349, 60.512167249407085, 57.24299464906965, 56.37025226865496, 56.539222036089214, 56.8796420778547, 52.14124509266445, 49.77033560616629, 46.78539991378784, 43.47446516581944, 43.70444359098162, 44.13300500597273, 42.183305740356445, 43.5345983505249, 45.47192634854998, 49.77936131613595, 49.531341893332346, 49.264916692461284, 44.20961931773594, 44.05406652178083, 43.655208655766074, 41.75197894232613, 38.74355486461094, 39.820042746407644, 41.79238966533116, 42.47255229949951, 42.18545273372105, 41.29340130942208, 45.2029824256897, 44.072093623025076, 39.04748296737671, 38.69199228286743, 38.972171442849294, 35.830925600869314, 37.68445137568882, 36.182132720947266, 38.31838417053223, 37.0702862058367, 39.58092744009835, 38.1838253566197, 41.44885335649763, 42.749080181121826, 51.97478709902082, 50.07476050513131, 55.82729223796299, 32.687511920928955, 37.60652038029262, 56.48160062517439, 46.50945568084717, 46.17546967097691, 40.82764618737357, 37.50211327416556, 36.92167466027396, 36.67210578918457, 36.538474559783936, 38.89719690595354, 36.05448041643415, 38.1857465335301, 36.67720576695034, 38.10549136570522, 36.88257367270333, 38.76396172387259, 42.39317607879639, 45.17211157935006, 43.89766951969692, 43.674257142203196, 40.69710690634591, 41.071034635816304, 39.33490909848894, 36.93044328689575, 37.357764448438374, 37.90324320111956, 37.62021180561611, 39.347207409994944, 39.30938836506435, 40.133826868874685, 40.92888144084385, 41.49338436126709, 44.02873338971819, 46.345922878810335, 48.53017248426165, 47.36505685533796, 45.48247371401106, 40.14479807444981, 41.03049884523664, 40.781958307538716, 41.991288798195974, 47.52104391370501, 47.68566410882132, 52.68271126065935, 54.10421889168875, 54.789877550942556, 52.07705068588257, 47.32434735979353, 47.3668703351702, 49.9295084135873, 50.34513923100063, 51.90958520344326, 56.95736115319388, 56.78570243290493, 57.63092647280012, 20.75362127167838, 2.986290808234896, 1.1767516902514865, 1.8611874665532793, 0.10633637796023063, 0.24676454014011792, 43.816698687417166, 63.06994506290981, 53.702807562691824, 54.54517936706543, 62.82199164799282, 63.2169064113072, 53.24923958097185, 31.37056425639561, 29.664458411080496, 28.762643030711583, 49.57273926053728, 9.55923434666225, 0.3964564763009548, 0.04600563099873917, 0.05219295773921268, 0.012988324792656516, 0.020141211105510592, 0.04600605169045074, 0.06701155525765248, 0.0317452269207154, 0.042110490546162636, 0.04233480065262743, 0.025897871669647948, 0.07305992141898189, 0.008481742015906742, 0.011800947881835912, 0.1179121650223221, 0.10861803338463817, 0.12938605648066315, 0.2765404480908598, 0.17102787271142006, 0.18128852998571737, 0.09774704743176699, 0.1709483348365341, 0.14548968736614498, 0.15667692492050783, 0.1744641504649605, 0.11091344949922391, 0.21810803855104105, 0.1369393047477518, 0.1704752737922328, 0.24652808425681932, 0.26445071824959343, 0.18438464456370898, 3.64390675510679, 59.38580172402518, 52.46411745888846, 38.018388748168945, 37.258290563310894, 52.70714112690517, 69.84411212376186, 66.5612758908953, 64.01353822435651, 69.08513954707554, 60.44552707672119, 65.65598814828056, 23.909341948372976, 0.19105076257671627, 0.38302132008331163, 2.002586781978607, 52.489540917532786, 63.262298992701936, 61.37226390838623, 67.59677982330322, 64.42464923858643, 59.84765543256487, 62.798326083592, 61.22974245888846, 64.69929763248989, 62.144993918282644, 62.45059653690883, 63.06888893672398, 60.07053974696568, 57.17527403150286, 59.84608513968331, 54.357386929648264, 52.42775058746338, 48.71699912207467, 45.34786278860909, 45.86149794714791, 47.501067842756, 43.13895402635847, 46.262391635349815, 48.94684900556292, 52.66122743061611, 52.16851329803467, 53.09574692589896, 46.46862806592669, 47.00766931261335, 46.613015106746126, 44.234928131103516, 43.159777777535574, 43.316671575818745, 44.57194702965872, 46.86993517194475, 44.417287077222554, 44.089679513658794, 47.82665695462908, 47.68199545996529, 41.55994462966919, 42.29207631519863, 40.76295151029314, 38.024596963609966, 39.72719396863665, 38.555289949689595, 41.22866494315011, 38.55522394180298, 40.81327383858817, 40.426481519426616, 42.786534445626394, 46.412271227155415, 56.47112968989781, 52.57617105756487, 57.21464252471924, 21.51441775049482, 34.309120723179404, 64.3665692465646, 48.39612088884626, 49.20071881158011, 43.157085350581575, 41.70863260541643, 39.77640111105782, 40.31621708188738, 38.22937774658203, 39.93584142412458, 38.834291390010286, 41.7746057510376, 38.82871198654175, 40.99307584762573, 38.2883505821228, 39.49878931045532, 42.97857223238264, 47.70475081035069, 46.02804626737322, 46.03699207305908, 42.36246156692505, 43.264490604400635, 41.826679025377544, 39.179974692208425, 40.350944178445, 41.0292968068804, 40.57843862261091, 41.33248840059553, 41.87972157342093, 41.35571622848511, 42.725515365600586, 42.01018442426409, 45.594360555921284, 51.055828775678364, 50.49255221230643, 48.83183894838606, 47.6309609413147, 43.415388107299805, 44.60406507764544, 41.97808722087315, 43.90952314649309, 51.10564388547625, 49.39449712208339, 55.38640819277082, 54.81647872924805, 57.46975605828421, 54.22883830751692, 46.966845171792166, 49.1767510005406, 51.72793844767979, 51.00912993294852, 51.81269952229091, 60.554933411734446, 59.14116954803467, 61.339801924569265, 24.588691643306188, 2.4809735119342804, 4.64779942376273, 3.0698066353797913, 0.36983225494623184, 1.0405853454555785, 50.23627832957676, 65.19706657954625, 60.37335613795689, 58.07569456100464, 66.0099571772984, 66.46046447753906, 61.34658336639404, 37.60474511555263, 40.41051803316389, 41.2392053604126, 55.76299360820225, 17.455801248550415, 0.7634053102561406, 0.14724490818168434, 0.252044139696019, 0.1747803749250514, 0.15712775715759822, 0.274082712829113, 0.2776656762829849, 0.1722167610589947, 0.13418928374137196, 0.20440400604690823, 0.1344698579715831, 0.14782947967095034, 0.05607705842703581, 0.11997071813259806], [0.04779828319858227, 0.05803942919841834, 0.038472630216607025, 0.13271982116358622, 0.04516361653804779, 0.029682779019432406, 0.08570797022964273, 0.06204013952187129, 0.03642060122053538, 0.06549359778208391, 0.06720892073852675, 0.062104057520627975, 0.03537818144208618, 0.0429588900213795, 0.04143290886921542, 0.1287456958421639, 0.037010054769260545, 0.03890203431780849, 0.08224539924412966, 12.621321967669896, 40.98952184404646, 27.55365126473563, 22.78643488883972, 29.06528745378767, 55.02803747994559, 64.76091425759452, 46.99386324201311, 53.237768105098176, 53.24878794806344, 56.050325938633506, 23.96370812824794, 0.07229695628796305, 0.3579450813787324, 7.84598662172045, 67.48247500828334, 59.74217482975551, 64.76017080034528, 56.600303649902344, 62.15103885105678, 56.40510443278721, 57.972711835588726, 57.15151119232178, 58.23914398465838, 56.03971951348441, 59.06122357504708, 53.89108984810965, 57.06862613133022, 55.60191699436733, 54.16926097869873, 48.51795407703945, 46.83931793485369, 42.97601876940046, 40.384128774915425, 40.33408784866333, 41.321489402226035, 39.5869654246739, 39.62818908691406, 39.749341351645334, 38.811935561043875, 37.968351296016145, 41.399309226444785, 42.55367946624756, 40.53773954936436, 41.66865267072405, 37.19021558761597, 36.18998418535505, 36.94220658711025, 39.848109994615825, 42.15934487751552, 42.7687783241272, 36.68931647709438, 38.563401971544536, 38.27625376837594, 35.699427468436106, 36.20041690553938, 35.49765872955322, 32.50774812698364, 35.97957536152431, 33.42264870234898, 37.57109498977661, 34.938669204711914, 37.615011078970774, 38.68077789034162, 41.60056379863194, 41.6684615952628, 51.04115765435355, 48.47574724469866, 58.573369707380024, 24.733764818736486, 24.832496983664377, 59.23085689544678, 46.515490191323416, 50.67942748750959, 41.97553028379168, 39.206798212868826, 36.16678762435913, 38.90650054386684, 35.17398384639195, 35.41757379259382, 34.65565865380423, 35.90851960863386, 33.500458104269846, 34.80534717014858, 33.27645860399519, 34.430227824619834, 35.05324499947684, 39.47424479893276, 38.38840116773333, 38.259480816977366, 40.79877642222813, 40.97079644884382, 38.75380693163191, 39.0166711807251, 35.20895760399954, 34.83276128768921, 36.17713696616036, 35.30710438319615, 37.030577250889365, 36.69788013185774, 37.790776184626985, 38.476834365299766, 38.65208183016096, 37.56061363220215, 39.98926959718977, 39.15403011866978, 37.74495281491961, 37.61220748083932, 40.485221590314595, 38.32672895703997, 40.53444610323225, 42.73580912181309, 47.06394624710083, 51.21561302457537, 52.42150068283081, 54.38583632877895, 56.74861294882638, 48.82178143092564, 48.49083178383963, 48.71561990465437, 53.180289132254465, 55.241479192461284, 54.13271345411028, 55.061385359082905, 58.27552127838135, 31.55720329284668, 2.3957855573722293, 0.9856491961649486, 1.2704824549811227, 1.432592939053263, 0.4107019118964672, 45.24308047975813, 51.639310700552805, 53.70051465715681, 57.164730140141074, 49.597301142556326, 39.27886145455496, 38.69202702386038, 22.993341820580618, 28.669193233762467, 36.101585728781565, 29.30416304724557, 0.38554074774895397, 0.047799708122121434, 0.009042286580162389, 0.05737159467701401, 0.0174282058807356, 0.03821313128407512, 0.0497490103090448, 0.0912102989054152, 0.04273210326209664, 0.04168976830052478, 0.013879909629135259, 0.05582701148731368, 0.031222279981843064, 0.05311594856902957, 0.025332680836852108, 0.043262520871524296, 0.010497313325426407, 0.02501581346483103, 0.10025751164981297, 0.05361203569918871, 0.02589886572345027, 0.05336105916649103, 0.060511087998747826, 0.0301612174537565, 0.07978244604808943, 0.03483193700334855, 0.04111527305628572, 0.06763654029262917, 0.021814721037766764, 0.009169299005796867, 0.07590165321848222, 0.014725348147164499, 0.06983156715120588, 0.15087740469191754, 18.075115033558436, 50.93504129137312, 26.955892528806412, 33.17291307449341, 37.55378702708653, 62.14490359170096, 70.9318595613752, 50.34051867893764, 61.702351978846956, 58.17351477486746, 63.74934686933245, 25.879420280456543, 0.07897006999701262, 0.1694535764732531, 9.423302395003182, 70.94937597002301, 60.178730147225515, 65.72038405282157, 56.37303154809134, 65.38338947296143, 58.69373335157122, 59.4086890901838, 60.81654003688267, 61.56163011278425, 57.02762828554426, 60.37375913347517, 56.885617528642925, 60.08357456752232, 57.37151895250593, 56.60734564917428, 49.6371351650783, 48.774947098323274, 46.392409801483154, 44.310979638780864, 42.76591566630772, 43.27267210824149, 40.890405791146414, 42.067969117845806, 42.36651931490217, 42.96679850987026, 42.01020874295916, 42.47498416900635, 43.65632731573922, 43.28601612363543, 42.662522997174946, 39.580246516636436, 40.40385818481445, 39.44802924564907, 40.926234177180696, 43.33248220171247, 44.393750054495676, 40.33394888469151, 42.23908587864467, 41.103458404541016, 38.103789057050435, 37.97810309273856, 38.67820358276367, 35.50225496292114, 38.3792781829834, 36.10592835290091, 38.71257632119315, 37.69612087522234, 40.51391417639596, 41.52255984715053, 42.70992013386318, 45.10300479616438, 52.29764209474836, 51.4111179624285, 59.67472866603306, 41.73823193141392, 32.67978204999651, 59.31288732801165, 47.94932392665318, 51.62373283931187, 43.94509097508022, 39.51520095552717, 37.522999559129985, 39.32850980758667, 37.727276597704204, 38.018482548849924, 36.04287692478725, 36.354423727308, 35.782878807612825, 37.3455981527056, 36.25739213398525, 37.42805937358311, 38.56097705023629, 41.36949450629098, 41.48798213686262, 39.31416872569493, 43.396711349487305, 42.58421679905483, 39.68724877493722, 39.13489130565098, 37.43806825365339, 36.33314139502389, 36.88660710198538, 38.427262442452566, 38.5519826071603, 38.66020427431379, 37.884170395987375, 40.64068405968802, 39.82972853524344, 40.247593198503765, 41.104702132088796, 40.202874592372346, 39.49820566177368, 40.98470674242292, 42.028437341962544, 40.870804922921316, 43.29156078611101, 43.922457218170166, 49.59360817500523, 52.63345200674874, 53.34469740731375, 55.145840712956016, 56.2696145602635, 48.47400324685233, 49.17433302743094, 51.91596017565046, 56.13062626974923, 56.690942900521414, 57.1745479447501, 57.60279321670532, 62.45525877816336, 37.0550731250218, 2.38455878836768, 1.0196848383971622, 1.9713300934859683, 0.9854976385831833, 1.2451739673103606, 53.77329008919852, 56.485387393406455, 62.41866956438337, 63.26533535548619, 55.162339210510254, 46.00787912096296, 43.53003338405064, 30.451428753989084, 30.457716873713903, 41.03594970703125, 35.72823122569493, 0.8848231264523098, 0.05886635982564517, 0.0160959922775094, 0.055705160168664794, 0.021558528267113224, 0.02405264148754733, 0.03809656575322151, 0.03327871945553592, 0.06305918376892805, 0.05095567288143294, 0.015547281363978982, 0.0087753000136997, 0.013331837386691144, 0.04062277198370014, 0.04579776518845132, 0.28602026083639687, 0.11254610653434481, 0.18510592728853226, 0.27137763798236847, 0.19788506227944577, 0.16588898774768623, 0.14237635156938008, 0.1873818558773824, 0.07678269701344625, 0.30223800774131504, 0.20301557412104948, 0.12906508227544172, 0.18207917256014688, 0.08616052594568048, 0.07750287372618914, 0.268598521394389, 0.26636858390910284, 0.14878288922565325, 0.24800254085234233, 32.12192855562483, 59.458799498421804, 42.320438861846924, 37.52476787567139, 42.385936055864605, 66.31446198054722, 75.90991728646415, 55.74493524006435, 66.04129355294364, 63.114093916756765, 69.81201144627163, 29.411085401262554, 0.25169721831168446, 0.48110179283789223, 10.733272331101553, 74.45059408460344, 63.85854475838797, 67.62874848502022, 60.38236100333077, 68.05763299124581, 57.887947286878315, 61.98812443869454, 61.86728136880057, 63.76965645381382, 57.494748728615896, 64.22069876534599, 60.72722789219448, 61.68403652736119, 60.755514008658274, 59.37249592372349, 54.08108139038086, 52.84600782394409, 48.719142641339985, 45.00056055613926, 46.910745416368755, 46.22211640221732, 43.85200943265642, 43.43839011873518, 44.06408929824829, 44.75785650525774, 42.456932749067036, 45.00832516806466, 47.60739612579346, 46.370946816035676, 45.605286598205566, 41.39896181651524, 42.15377242224557, 41.73769692012242, 44.501975195748464, 47.96434940610613, 47.22686760766165, 42.98576361792428, 44.63882344109671, 41.44389929090227, 40.43616730826241, 41.05457782745361, 41.34335538319179, 36.48649508612496, 41.23581811359951, 37.38364996228899, 42.111780984061106, 38.881667682102744, 42.773336342402864, 42.851604325430735, 45.17578022820609, 46.63961975915091, 55.02765532902309, 52.22102083478655, 62.57630334581648, 27.420242377689906, 27.095883096967423, 67.73680686950684, 49.74326889855521, 55.52291250228882, 45.00242962156023, 44.25997986112322, 40.55550956726074, 41.63988018035889, 37.484968594142366, 39.87431859970093, 37.68167209625244, 39.10022326878139, 37.32484040941511, 38.86591611589704, 37.79887431008475, 37.98456491742815, 38.702466692243306, 42.617842606135774, 44.218787465776714, 42.17571483339582, 45.89198316846575, 43.746365547180176, 41.61563096727644, 41.508256980351035, 40.37211881365095, 37.990526471819194, 39.13347387313843, 38.62796115875244, 39.651496819087434, 40.78055477142334, 40.76123530524117, 43.88801499775478, 42.530222347804475, 42.716406277247835, 42.468824590955464, 43.297101974487305, 41.31574324199131, 43.096458843776155, 45.62936905452183, 43.55192368371146, 45.571070194244385, 45.09575087683541, 51.191068513052805, 54.461873940059114, 55.7636467388698, 56.489837714603965, 56.98318760735648, 50.181401457105366, 51.21951791218349, 53.741199834006174, 56.059080668858115, 57.803318228040425, 59.847231592450825, 61.96716867174421, 66.40730381011963, 42.37836946759905, 2.6467462394918715, 2.3579113611153195, 2.9881976544857025, 2.657110780477524, 1.5418977652277266, 61.31353078569685, 60.43838432856968, 66.08178070613316, 63.16684464045933, 60.732070786612375, 50.16786984034947, 50.09701211111886, 36.59209033421108, 43.116990770612446, 46.22098731994629, 51.294534138270784, 1.6523351477725166, 0.31951915472745895, 0.08734487489398036, 0.15432700887322426, 0.20582346059381962, 0.09050851727702788, 0.16428425242858274, 0.1141502990254334, 0.136105317356331, 0.2595854050346783, 0.09223741771919386, 0.1901790757796594, 0.16554718251739228, 0.12529751658439636, 0.19247977089669022], [0.015865833199183856, 0.03260343122695174, 0.037879431154578924, 0.09044776125145809, 0.02544742789385574, 0.01802056186300303, 0.02483683289028704, 0.04735820913421256, 0.050034032336303165, 0.05528810540480273, 0.04328413899721844, 0.015610776974686554, 0.04415956112955298, 0.042471752768116336, 0.05767238246543067, 0.14318949436502798, 0.07981763487415654, 0.04141418808805091, 0.09982120684747185, 3.359322871480669, 39.52285439627511, 40.99396174294608, 29.58473825454712, 19.80068973132542, 34.443366868155344, 64.48955930982316, 56.33170018877302, 53.73907021113804, 49.17357219968523, 57.520120075770784, 26.83389605794634, 0.05425121229408043, 0.232793178409338, 21.827713762010845, 75.08069147382463, 54.46515001569475, 62.246430669512065, 60.49310139247349, 58.0873258454459, 59.39612674713135, 60.29583508627755, 56.52060086386544, 57.7888103893825, 56.9524279321943, 58.582749775477815, 58.40646008082798, 56.78788764136178, 53.851554598127095, 52.020040716443745, 46.497866085597444, 42.50911372048514, 41.11820248195103, 40.493350982666016, 40.31976066316877, 41.650493553706575, 39.944776807512554, 39.9331351007734, 39.893919467926025, 40.4331031526838, 38.491971015930176, 40.144554887499126, 40.20638690676008, 39.53574677876064, 39.55102586746216, 37.62930004937308, 36.01146411895752, 37.92675937925066, 39.78546503611973, 42.21780702045986, 40.870283808027, 37.983237811497276, 38.72564240864345, 37.530649525778635, 37.21022639955793, 36.29972750799996, 36.844351632254465, 33.299109731401714, 36.883410930633545, 35.4535619871957, 36.9620680127825, 36.24178300585066, 38.6800274848938, 40.42198256083897, 43.66896956307547, 45.33532476425171, 53.13600826263428, 51.3335725920541, 55.49261835643223, 30.634684017726354, 21.539667504174368, 57.63801710946219, 52.23026541301182, 51.84320558820452, 45.34769950594221, 40.63349962234497, 39.000718116760254, 37.72207587105887, 35.04210008893694, 36.501273904527935, 34.82260996954781, 36.91661984579903, 34.44765738078526, 35.65966640199934, 34.473970208849224, 34.321436405181885, 34.70305926459176, 35.79410014833723, 37.527074677603586, 37.739102431706016, 43.058205536433626, 40.050973074776785, 38.47914464133126, 38.29909597124372, 35.37173652648926, 35.016162463596885, 35.879153047289165, 36.24439900262015, 36.544189453125, 38.81697995322091, 38.06526476996285, 36.493985244206016, 37.76060710634504, 37.49442161832537, 36.68733276639666, 37.280476161411826, 37.38335118974958, 36.599691663469585, 38.49669926507132, 40.470609528677805, 42.2954739843096, 45.92715842383248, 48.1594409261431, 49.41429601396833, 52.25513996396746, 49.8269807951791, 50.06349400111607, 51.429697445460725, 47.54062393733433, 52.87680571419852, 52.59617839540754, 51.44660588673183, 51.73610258102417, 54.23824616840908, 55.072113377707346, 52.38943474633353, 11.36791557925088, 2.5068559859480177, 2.1320655941963196, 0.39029024860688616, 4.157915813582284, 47.70746408190046, 50.266697543007986, 42.568701471601216, 43.6254425730024, 48.69234343937465, 40.36881147112165, 25.21784928866795, 23.984742062432424, 30.546733719961985, 40.92873205457415, 15.964160237993513, 0.768278277346066, 0.0191658865660429, 0.11443438806704112, 0.10591274140668766, 0.1214778394039188, 0.07632708788982459, 0.041104603093117476, 0.037835000681557825, 0.09226071182638407, 0.05449151547093477, 0.05473712818431003, 0.0250739130258028, 0.07990161036806447, 0.055311202736837525, 0.04557068326643535, 0.05484673194587231, 0.05179756859849606, 0.03704274319378393, 0.036490615856434615, 0.01638844426322196, 0.01294463307463697, 0.024643808337194578, 0.03114859786416803, 0.005467280645721725, 0.029127391321318488, 0.05832466496420758, 0.03306075365149549, 0.01964088822049754, 0.030874540962811028, 0.013259841428537453, 0.09091305985514607, 0.07979441540581839, 0.09162107722035476, 0.16815408691763878, 4.620305836200714, 52.4727714402335, 41.22741426740374, 34.58075359889439, 32.264342308044434, 38.540573665073936, 73.86032376970563, 56.175146852220806, 58.55145508902413, 55.19690302440098, 65.62385967799595, 29.66308614185878, 0.037789426877030304, 0.14886435413999216, 24.479054280689784, 78.00434058053153, 58.601787839617046, 64.00722231183732, 62.09667614528111, 61.105793544224326, 61.04959651402065, 62.91973195757185, 58.02744279588972, 60.22310829162598, 60.565675326756065, 60.049792425973074, 60.578522545950754, 58.049812521253315, 56.02221005303519, 53.374234199523926, 49.961504868098665, 45.23819242204939, 42.196340560913086, 43.40649788720267, 43.33781841823033, 43.2736622265407, 40.777445452553884, 41.736480985369, 41.954939297267366, 40.54364551816668, 40.08291046960013, 42.3100061416626, 40.830578327178955, 41.97339023862566, 40.77162633623396, 40.86848075049264, 39.93103674479893, 40.70453800473894, 42.134685720716206, 46.57380294799805, 43.76595251900809, 39.968626499176025, 41.9954195022583, 40.17114564350673, 40.22682850701468, 37.954204763684956, 39.60276215417044, 38.899444648197715, 38.69003289086478, 36.450371401650564, 39.60865075247628, 39.86557081767491, 41.12665149143764, 42.33995982578823, 45.07167189461844, 47.71471105303083, 53.92774854387556, 53.90584087371826, 58.440686907087056, 47.45843022210257, 29.43614755358015, 56.072869368961875, 54.25734676633562, 52.0773355620248, 48.3269168308803, 42.84585121699742, 40.36197444370815, 38.75232349123274, 38.025666986192974, 37.354085377284456, 37.63632467814854, 37.53691332680838, 37.71631234032767, 37.685858385903494, 37.33373410361153, 36.76354060854231, 38.0102002961295, 39.00988279070173, 39.211342334747314, 40.01904957635062, 44.16304554258074, 42.8290365764073, 38.73180546079363, 38.84263965061733, 37.389965874808176, 35.88142510822841, 38.348858969552175, 38.31863777978079, 37.91593755994524, 39.681391443525044, 38.43778548921858, 37.62524924959455, 38.64372662135533, 38.89281259264265, 38.80344138826643, 38.67045634133475, 38.593518938337056, 39.06380775996617, 40.41234540939331, 41.98239510399954, 45.56756135395595, 46.66327837535313, 51.38262340000698, 51.22139392580305, 54.1221730368478, 51.00481162752424, 48.89690882819039, 52.22046150479998, 50.40049205507551, 53.73914316722325, 55.899317264556885, 52.99928855895996, 55.55433225631714, 56.162414278302876, 58.172177246638704, 56.55653347287859, 15.12543797492981, 2.888616289411272, 2.568777246134622, 0.2898467912205628, 6.167360467570169, 56.54244252613613, 55.427725655691965, 52.794747488839285, 50.037257603236604, 54.39998286111014, 44.980129378182546, 28.86586720602853, 34.363830838884624, 33.76697015762329, 47.73938758032662, 18.679451976503643, 0.7355852116431508, 0.04671469330787659, 0.07487268200410263, 0.05435269059879439, 0.2631492338010243, 0.1213764798428331, 0.04526198036702616, 0.010233045988050955, 0.05124704260379076, 0.1304361844169242, 0.05803097465208598, 0.052434383891522884, 0.038248754372554164, 0.02857658712725554, 0.05160121413479958, 0.22578445449471474, 0.15226000121661595, 0.17089414702994482, 0.20883554539510182, 0.1814156195947102, 0.07642576723758664, 0.1790007541754416, 0.10326796796705041, 0.10174117596553904, 0.22620886457817896, 0.2534287039722715, 0.15192754619887897, 0.11534670554101467, 0.13164576808256762, 0.13222392063055718, 0.22666114888020925, 0.15704155606882914, 0.3326658792793751, 0.34451291071517126, 8.115261452538626, 65.94231646401542, 53.3148375238691, 45.13001591818673, 34.22978271756853, 46.152210576193674, 76.47779355730329, 65.41731752668107, 63.705746923174175, 60.789900643484934, 68.2056782586234, 33.338658877781455, 0.20722787880471774, 0.2046755286199706, 26.745513234819683, 83.42616585322789, 60.38659940447126, 66.17781175885881, 65.28072983877999, 64.39227063315255, 64.2154598236084, 63.218469755990164, 59.64297539847237, 63.691496167864116, 64.49379771096366, 63.64761134556362, 62.87561089651925, 61.66165637969971, 59.86742305755615, 57.01293631962368, 51.19917706080845, 47.851684365953716, 45.59425980704171, 45.265245233263286, 45.38138437271118, 45.435934679848806, 43.767116342272075, 45.054999692099436, 43.72453778130667, 44.1780675479344, 42.773384979793, 43.871492181505474, 44.92481476919991, 44.90785421643938, 45.244098390851704, 42.94686760221209, 42.02186434609549, 44.090419496808735, 46.08139106205532, 49.80929068156651, 45.74098144258772, 42.743017877851216, 44.61848258972168, 43.38665035792759, 41.303424085889546, 40.26889984948294, 42.90483100073678, 40.49754422051566, 42.68895047051566, 37.89313357216971, 43.446568148476736, 40.79526063374111, 44.716278484889436, 43.451918261391775, 47.468244552612305, 49.58474574770246, 58.56504576546805, 53.6181263923645, 61.17247540610177, 32.192595209394185, 23.63885031427656, 65.44964749472481, 58.324019704546245, 55.68643488202776, 50.051268645695274, 44.46832159587315, 43.175126348223, 41.310042245047434, 39.79572057723999, 39.51267875943865, 40.16290160587856, 39.88106877463204, 38.4673570224217, 40.90561887196132, 39.86646713529314, 39.46041440963745, 40.55554778235299, 40.48367214202881, 42.037080901009695, 42.79798855100359, 48.73405694961548, 43.43444006783621, 41.47442967551095, 41.20384250368391, 40.17468575068882, 39.5531450680324, 40.76332671301705, 39.41820410319737, 40.23958887372698, 42.89357491901943, 42.34825944900513, 38.48460592542376, 41.23836810248238, 41.44320099694388, 40.99349968773978, 40.9257721219744, 40.940915720803396, 41.45695843015398, 43.000580651419504, 44.1280266216823, 48.152510098048616, 51.17424692426409, 53.59473180770874, 52.90296915599278, 57.35380104609898, 52.80151850836617, 49.337275232587544, 53.065331186567036, 52.03141491753714, 55.42955650602068, 58.219140120915, 55.40554353169033, 58.26975427355085, 58.53749615805489, 61.875563621520996, 58.33124583108084, 18.19724699429103, 3.8536203248160223, 4.597141410623278, 1.0792886572224754, 7.537403225898743, 60.69572475978306, 60.0446229662214, 53.66464805603027, 53.99628210067749, 57.67967503411429, 50.88174860818045, 36.285917963300435, 39.647939341408865, 43.62890625, 54.95191649028233, 28.35106996127537, 0.7554912034954343, 0.09218787109213215, 0.2641185889286654, 0.2308022209576198, 0.3614038186413901, 0.22219116373785905, 0.18799542795334542, 0.14898677542805672, 0.21714575375829423, 0.3347480861204011, 0.14602738565632276, 0.17863568876470837, 0.12142415371324335, 0.1352316356663193, 0.17131409235298634], [0.07162672653794289, 0.052240723211850436, 0.06264297038848911, 0.058935550041496754, 0.06669308484664985, 0.021577325383467332, 0.03226669804592218, 0.027287584330354418, 0.03892767954883831, 0.005215412263558912, 0.05132389348000288, 0.06011067091354302, 0.036293420009315014, 0.03661273858909096, 0.02776841799329434, 0.02581469006171184, 0.03935488858925445, 0.08512679820082017, 0.038968476466834545, 0.030053856250430857, 17.504131180899485, 48.918368339538574, 25.611535957881383, 32.89174379621233, 24.400692496980938, 50.90932600838797, 69.20512104034424, 52.308189460209434, 53.39905663899013, 58.18638631275722, 37.11190938949585, 0.2953706362417766, 0.3186775270317282, 36.98631375176566, 68.18843282972063, 57.72550187792097, 60.43312454223633, 54.93726621355329, 61.898346764700754, 58.93081978389195, 61.23452281951904, 59.61284800938198, 56.65741089412144, 59.36129542759487, 59.90721539088658, 52.38212176731655, 49.766788550785606, 46.49783134460449, 43.71098184585571, 39.31639909744263, 41.25677040645054, 43.39764240809849, 39.99015896660941, 37.93993663787842, 42.494241101401194, 40.279099805014475, 37.97985403878348, 39.571217332567485, 39.24595478602818, 39.00220850535801, 39.42523915427071, 40.70467002051217, 37.842880725860596, 38.19878830228533, 36.851991176605225, 38.38952677590506, 38.04502119336809, 36.76238373347691, 40.46483210154942, 39.39067881447928, 37.610817841121126, 37.99371916907174, 37.340251513889854, 34.91368348257882, 36.85314457757132, 37.588462012154714, 36.11986296517508, 37.66138335636684, 36.76794924054827, 39.075932366507395, 38.34439475195748, 41.452407360076904, 42.42801782063076, 46.458320413317, 46.420692443847656, 51.697467122759136, 51.87499359675816, 55.860428197043284, 37.19545800345284, 20.35038082940238, 51.762262548719136, 54.44321455274309, 53.39167070388794, 49.122895513262065, 44.19733142852783, 42.541096278599326, 38.924148968287874, 38.158547810145784, 38.2771327154977, 35.739480359213694, 35.22608838762556, 35.66034732546125, 35.430757999420166, 34.89442307608468, 34.766364301954, 35.013351917266846, 34.82844645636422, 34.843913146427695, 34.69136544636318, 39.874874455588206, 39.56128488268171, 38.57658617837088, 39.272687980106895, 36.18312978744507, 35.10078804833548, 36.314370836530415, 35.594902242933, 36.259438378470286, 36.7906767981393, 37.20959758758545, 37.30426679338728, 35.92623404094151, 37.11514030184065, 37.148599352155415, 36.8882086617606, 37.39934941700527, 36.62851626532418, 37.792916229793, 39.14453540529524, 42.004104750497, 43.7220572744097, 49.091645990099224, 49.921118463788716, 54.014559337071006, 49.77968093327114, 53.93425900595528, 52.37496859686715, 53.17158998761858, 50.813819544655935, 52.34680754797799, 53.50621175765991, 49.254765374319895, 52.60114288330078, 55.63719994681222, 57.7075685773577, 33.49287067140852, 3.1690479729856764, 2.1027283455644334, 0.41060083732008934, 6.593142168862479, 48.861222880227224, 46.82590096337454, 45.43614659990583, 50.09036615916661, 53.25704935618809, 46.28238507679531, 20.425911222185405, 22.99189485822405, 24.190811736243113, 45.50778947557722, 3.534428766795567, 0.1732808125338384, 0.030802782491913865, 0.021628446211772304, 0.03011081926524639, 0.09958375351769583, 0.03390291738989098, 0.002492127869377977, 0.07516649445252759, 0.016102251763056432, 0.01771415919730706, 0.02943022150014128, 0.02490183654507356, 0.05057894345372915, 0.0363632107286581, 0.03319956495293549, 0.0763283838917102, 0.03719709633982607, 0.05022198992914387, 0.065208701283804, 0.051970228619341335, 0.00533929282599794, 0.04526438916634236, 0.06574946655226604, 0.07180785467582089, 0.08036071394703218, 0.08738288642572505, 0.025478114640074115, 0.027920818654820323, 0.03378601259152804, 0.018836004892364144, 0.09509035213185207, 0.03838731461603727, 0.07790928906095879, 0.027942584361881018, 0.12290709199649946, 20.35871171951294, 58.212525435856406, 23.52540533883231, 44.17753601074219, 31.098604815346853, 59.45497104099819, 74.59413691929409, 56.69342688151768, 58.606325013296946, 62.38195528302874, 40.569617884499685, 0.25529543523277554, 0.28975665462868555, 39.97314282826015, 71.72747693743024, 59.841158866882324, 61.06611238207136, 56.90091398784092, 66.44442803519112, 61.075360434395925, 63.404278482709614, 63.40302085876465, 62.17660127367292, 61.540563174656455, 62.38235133034842, 54.35444436754499, 53.776823248182026, 49.72707264763968, 44.80119936806815, 41.66326781681606, 43.356981549944194, 43.99712256022862, 41.744572162628174, 41.43929263523647, 42.74850000653948, 43.064535345349995, 39.664986746651785, 41.25601652690342, 42.25378826686314, 41.05038806370327, 41.102787903376985, 44.114043372017996, 40.951428345271516, 41.15723746163504, 40.31770747048514, 40.966408661433626, 44.08620888846261, 40.81208222252982, 44.271850858415874, 42.91289438520159, 40.45049796785627, 39.8847895349775, 38.38637229374477, 39.58202525547573, 39.115815026419504, 41.21016189030239, 40.27478844778878, 40.157332624707905, 39.687283515930176, 39.24454777581351, 39.84855120522635, 41.218947887420654, 45.199129649571006, 48.040974140167236, 50.285047735486714, 52.24708700180054, 55.18907935278756, 56.9053886277335, 51.55354561124529, 28.79750735419137, 50.721189635140554, 57.927221979413716, 56.39617599759783, 54.10239846365792, 48.565337317330496, 43.49266597202846, 40.692639214651926, 39.986486843654085, 39.54373025894165, 37.46939073290144, 36.11860186713082, 36.72498505456107, 36.92875140053885, 36.42898137228829, 36.46152326038906, 37.111871174403596, 36.973449162074495, 38.45603493281773, 37.85269505637032, 41.40151527949742, 41.62076221193586, 39.264294556209016, 40.2813857623509, 37.37207078933716, 37.02860743658883, 38.79410300936018, 37.24324771336147, 38.87266976492745, 38.11873115812029, 38.618789536612375, 37.407697677612305, 37.09074865068708, 39.44457599094936, 39.472198554447715, 38.898947851998464, 39.07897220339094, 39.49305009841919, 40.61120980126517, 39.739745889391216, 42.640809876578196, 46.044367585863384, 51.60027919496809, 53.15585926600865, 54.01219000135149, 52.3107533454895, 53.583708490644185, 54.795894690922324, 56.20073706763131, 53.48874051230294, 54.139310768672395, 55.50064352580479, 51.968262740543906, 55.147786208561485, 58.04391697474888, 62.34469904218401, 37.255591188158306, 3.3604649816240584, 1.769696627344404, 0.06635515405131237, 8.8441743850708, 57.18059287752424, 52.27918073109218, 48.43100431987217, 52.80151850836617, 59.91171087537493, 48.33410474232265, 26.2743923664093, 27.895990746361868, 29.87052113669259, 53.56504215512957, 3.4034990838595798, 0.2645160476011889, 0.019426009750791957, 0.07296639893736158, 0.017798908221136247, 0.012801742081397345, 0.034409925541175265, 0.053432010180716, 0.02075743455705898, 0.06142269979630198, 0.04528137629053422, 0.010987937400516654, 0.003850391916265445, 0.027519519474091272, 0.04342505714989134, 0.052332746131079536, 0.2198049867791789, 0.18007616432649748, 0.16075808235577174, 0.18927057167249067, 0.17954789767307894, 0.08863029841865812, 0.08503652590193919, 0.16506625046687468, 0.09091443728123393, 0.1619363719863551, 0.13611639104783535, 0.15010155418089458, 0.06878821099443094, 0.10171143577567168, 0.13022933980183943, 0.19899536270116056, 0.13245743167187485, 0.22278862739247934, 0.08658271043428353, 0.22929628033723148, 33.28976093019758, 65.90607466016496, 39.23782539367676, 49.22093806947981, 35.99349955150059, 61.66242068154471, 78.76033238002232, 60.5267584664481, 63.67671734946114, 70.35707678113664, 43.74693529946463, 0.45824954765183584, 0.4555014265435082, 43.354299545288086, 73.8010834285191, 64.31836264474052, 64.98989214215959, 59.4326742717198, 69.40132427215576, 63.7340121950422, 68.00873156956264, 65.51439080919538, 63.858676774161204, 63.7865822655814, 64.85943276541573, 57.43424381528582, 55.80245590209961, 52.83959116254534, 47.11347648075649, 42.91225515093122, 46.92850848606655, 48.126895563943044, 45.03939403806414, 41.15397180829729, 47.28536796569824, 46.22700098582676, 42.2103133882795, 43.41787903649466, 43.62604011808123, 43.78080429349627, 43.215339047568186, 46.86073228291103, 43.6655649457659, 44.45895542417254, 41.343598570142476, 43.73010328837803, 46.548640046800884, 42.54983016422817, 47.99123198645455, 45.70760924475533, 43.90464551108224, 42.59021309443882, 41.619230134146555, 40.438314301627024, 41.75378199986049, 44.62032733644758, 41.89026893888201, 43.939709595271516, 41.67639296395438, 41.90630885532924, 42.64389487675258, 44.35951280593872, 46.796916552952354, 51.087769644601, 50.69099276406424, 56.09473187582833, 56.046639919281006, 59.93935775756836, 38.21988650730678, 19.98484304973057, 55.372706345149446, 59.00265026092529, 58.42626244681222, 54.25852101189749, 49.917884077344624, 45.329078333718435, 41.65898077828543, 42.50254072461809, 40.29865550994873, 37.8525630405971, 38.80017226082938, 39.910803590502056, 39.43740545000349, 37.76031528200422, 37.66801193782261, 39.22759417125157, 40.69648504257202, 40.22109971727644, 39.45065566471645, 43.85854073933193, 44.7637277330671, 41.8379351070949, 42.656988756997244, 40.5457056590489, 39.98682383128575, 41.1461307661874, 39.332588400159565, 39.69486747469221, 40.068680558885845, 41.042470591408865, 39.60751819610596, 39.71920354025704, 41.125831604003906, 42.240871565682546, 41.05008929116385, 41.25508894239153, 41.09449175425938, 42.34979847499302, 42.08498525619507, 46.15912403379168, 48.519819668361116, 56.33472612925938, 55.011476448604036, 56.68172264099121, 52.13738884244646, 55.88006728036063, 55.790095056806294, 59.87080683026995, 55.55529458182198, 57.90968820026943, 57.40960897718157, 54.03676230566842, 56.826835768563406, 62.451909746442524, 62.67616980416434, 38.73918792179653, 4.614862356867109, 5.2891459465026855, 1.1725838567529405, 10.419069579669408, 63.24284403664725, 55.280069487435476, 55.20809309823172, 60.67927837371826, 60.06518963405064, 56.677789960588726, 31.468770095280238, 37.328634125845774, 35.46681220190865, 65.32566383906773, 6.791201438222613, 0.6249059992177146, 0.09918923968715326, 0.1549790267433439, 0.12253279850951262, 0.19156847122524465, 0.10749546504978623, 0.14675162679382733, 0.1427786685526371, 0.10164778919092246, 0.1696768823478903, 0.08585664403757878, 0.1351424218820674, 0.10539117867925338, 0.12059525533446244, 0.136838488014681], [0.03949329616235835, 0.04973750574780362, 0.06361555534281901, 0.0799250401822584, 0.06706560735723802, 0.0698385357058474, 0.03882509862471904, 0.03948672794337783, 0.044549213256686926, 0.010348703978317124, 0.10342611412384681, 0.013241909444332123, 0.025351413492379442, 0.022814048753519143, 0.06778719542281968, 0.02463865147105285, 0.03585233832044261, 0.046498169390750785, 0.024733944929071834, 0.033282020528401644, 1.4095011438642229, 46.647471223558696, 36.22356135504586, 21.07079437800816, 24.156025579997472, 24.460202080862864, 58.688543047223774, 62.366294043404714, 58.00721658979143, 60.262184960501536, 50.598984718322754, 2.1339832970074246, 0.09151956838156496, 39.68325356074742, 65.62203924996513, 60.06280640193394, 55.75211272920881, 48.97780670438494, 54.228056635175435, 56.08939218521118, 55.57952989850725, 56.86970962796892, 55.81128706250872, 55.363145623888286, 48.927526065281455, 47.82328013011387, 44.29182692936489, 44.188844203948975, 42.267813205718994, 42.87853901726859, 40.180011544908794, 40.48646879196167, 40.43284259523664, 41.597586495535715, 42.17775412968227, 38.858849797930034, 40.7270119530814, 37.93768889563424, 38.23967497689383, 40.24875354766846, 39.11652374267578, 40.64601680210659, 38.933223315647666, 39.07362903867449, 37.129140922001426, 38.75734009061541, 38.52091721126011, 37.95708131790161, 39.35696962901524, 38.262103761945454, 38.11220332554409, 36.6009110723223, 37.27518163408552, 38.26427854810442, 39.63303198133196, 36.60646963119507, 36.0729660987854, 36.83630214418684, 38.078671319144114, 38.651244572230745, 38.283730030059814, 41.31731353487287, 46.5457878112793, 47.47375447409493, 50.429667540958945, 52.59112010683332, 52.39585835593087, 52.39856467928205, 41.13700778143746, 23.634471212114605, 43.51411853517805, 59.0941858291626, 50.939675739833284, 48.10276447023664, 44.309718540736604, 46.46284369059971, 43.574793679373606, 41.32308748790196, 40.338927268981934, 39.52153076444353, 37.349822657448904, 37.24178511755807, 34.70536954062325, 36.16623871667044, 33.95021847316197, 35.72912754331316, 35.66353307451521, 34.50432341439383, 34.26957157679966, 37.5941595349993, 38.75960520335606, 38.016596112932476, 39.108679226466585, 36.92496463230678, 36.464041982378276, 34.59051581791469, 34.65925087247576, 36.569703238351, 37.358768463134766, 38.34839691434588, 35.6090453011649, 38.246644020080566, 36.62566750390189, 34.65613807950701, 36.32299702508109, 36.671734060559956, 36.80070652280535, 37.11251735687256, 38.761383942195344, 40.560699871608186, 44.1609263420105, 47.18902424403599, 53.21811859948294, 52.63397659574236, 52.7999621118818, 49.914000034332275, 51.12914269311087, 50.127580710819785, 51.5037339755467, 47.95574058805193, 47.64042786189488, 46.38743141719273, 53.25406163079398, 55.81226328441075, 62.13022204807827, 39.51854303904942, 5.635547952992575, 1.600991651415825, 0.1293365369950022, 7.76153039932251, 50.51785407747541, 47.526039668491904, 61.51652935573033, 51.2238883290972, 62.978340012686594, 26.3674304825919, 23.274181059428624, 33.67230095182146, 42.998197419302805, 19.9357488155365, 0.3298593227352415, 0.032594277789550166, 0.08721470473600285, 0.01711153019485729, 0.09111467296523706, 0.007638446820367659, 0.023325776115858128, 0.05710993800312281, 0.038087106975061555, 0.02274460408703557, 0.03175555761637432, 0.027697543314258968, 0.025073672145871178, 0.07457784496779953, 0.01292151877922671, 0.04454331000202468, 0.0028676942456513643, 0.05607792016650949, 0.01303662545979023, 0.03776251617819071, 0.031926548441073725, 0.06074267200061253, 0.018495879036241343, 0.06257076069180455, 0.017902878445706198, 0.030996470312987055, 0.01246056704050196, 0.033368771230535846, 0.027501165101836835, 0.012295878109788256, 0.04017875902354717, 0.017008028159450208, 0.05131737615114876, 0.015037162129634192, 0.004255828464270702, 0.1743996353553874, 1.6276609003543854, 59.263784408569336, 36.33610132762364, 24.964052438735962, 32.10973446709769, 30.038351399557932, 70.1093179157802, 63.11298220498221, 64.5701653616769, 64.45323412758964, 55.321373053959434, 2.304654721702848, 0.13216697797179222, 42.214235646384104, 68.75458594730922, 61.04633086068289, 58.85075569152832, 50.48625019618443, 57.96898760114397, 57.16619273594448, 58.38057804107666, 60.193495069231304, 60.55396066393171, 57.08359949929373, 51.78216913768223, 49.03082493373326, 47.06937279020037, 45.61167894090925, 43.87757880347115, 43.67538275037493, 42.52803366524832, 42.17979342596871, 43.385760988507954, 42.862245491572786, 44.36349759783064, 40.104123319898335, 42.73648657117571, 41.10979516165597, 40.83523709433419, 42.94153833389282, 42.92569991520473, 42.91506917136056, 41.47993612289429, 42.11478955405099, 38.98509856632778, 42.457016127450125, 43.18409647260393, 41.61195537022182, 43.17511592592512, 41.119623388562886, 39.26200859887259, 38.837077617645264, 39.92784752164568, 39.28093201773507, 40.800985949380056, 38.64004407610212, 39.70103400094168, 39.40837935038975, 40.990633555821006, 41.234779357910156, 40.204194750104634, 41.32038116455078, 48.413939544132774, 48.60973283222744, 53.38534436907087, 50.91224772589547, 54.00071505137852, 52.0734862600054, 55.107775006975444, 35.30677086966378, 43.12023210525513, 59.18308803013393, 50.96555083138602, 53.21584306444441, 48.10795824868338, 48.14819874082293, 45.366372789655415, 43.098192419324604, 41.80387156350272, 40.58361503056118, 36.865453311375205, 39.762417861393516, 37.82321037564959, 38.259849071502686, 37.17891781670706, 38.31933607373919, 36.62670278549194, 37.26008667264666, 37.331670488630024, 38.844838755471365, 39.32719659805298, 40.31979193006243, 38.0296448298863, 37.848289898463655, 36.16021115439278, 37.917657239096506, 37.80640615735735, 38.88529464176723, 37.849644797188894, 39.308568477630615, 36.390106201171875, 39.96658372879028, 38.77090644836426, 37.70751939501081, 38.61206715447562, 39.32873214994158, 38.530453613826204, 38.549578530447825, 39.76137910570417, 42.65789202281407, 47.47257328033447, 48.055363859449116, 53.95701435634068, 53.79830360412598, 54.42528125217983, 52.99381685256958, 52.32142577852522, 53.338440554482595, 54.47215379987444, 50.39124747685024, 48.75925459180559, 48.440697056906565, 55.143808364868164, 58.692350660051616, 64.541031564985, 43.77800416946411, 6.534628348691123, 1.7203577948468072, 0.3156651843871389, 10.058887992586408, 58.327785628182546, 53.25472170966012, 64.8875868661063, 54.613949162619456, 67.5670554297311, 30.663366181509836, 31.184925760541642, 37.73088618687221, 49.157897063664024, 23.669186149324688, 0.41368103346654345, 0.05526713867272649, 0.12093647702464036, 0.04876830668321677, 0.09470178905342307, 0.06508157096271004, 0.027871443357850825, 0.05393983257402267, 0.09081435336598329, 0.044151394960603545, 0.04991808766499162, 0.050598997556205304, 0.027555887254753282, 0.05181563798604267, 0.04716745258441993, 0.06356630048581532, 0.10786824540368148, 0.12297491835696356, 0.22129884947623524, 0.22197001560458116, 0.22997166695339338, 0.2699289114347526, 0.14985110690551146, 0.1800929105707577, 0.10014871534492288, 0.11703929757433278, 0.1685969667243106, 0.12745468797428267, 0.12259800572480474, 0.19018166778343065, 0.2067085009600435, 0.052045695284115415, 0.17357165978423186, 0.09023447733904634, 0.17411295431000845, 0.25605718578611103, 4.928988678114755, 69.85759162902832, 49.003942353384836, 38.30736085346767, 37.66749082292829, 34.49789980479649, 67.58038207462856, 70.111325945173, 67.94347408839634, 68.79007039751325, 60.11199269975935, 2.99115389585495, 0.6139353364706039, 46.72086157117571, 70.8314928327288, 64.88314696720668, 60.631294114249094, 52.99427195957729, 61.43070520673479, 60.54578958238874, 60.344833782741, 61.28627300262451, 61.248731885637554, 59.90433883666992, 53.43418673106602, 52.408118452344624, 48.10877813611712, 48.84484250204903, 45.729881695338655, 48.41808067049299, 44.661026409694124, 44.580361298152376, 45.70658091136387, 45.562013217381065, 47.73580578395298, 42.75981862204415, 45.7990996497018, 41.57044335774013, 42.965002400534495, 45.660055773598806, 46.3225074495588, 47.440736634390696, 45.276692390441895, 44.23350722449166, 42.28220987319946, 45.101774965013774, 45.96486282348633, 44.35132435389927, 47.01626076017107, 44.69174092156546, 44.5099447795323, 42.67228174209595, 41.55891629627773, 41.760170868464876, 44.28060211454119, 42.05504894256592, 41.33223131724766, 42.1762706892831, 43.95831339699881, 42.91824449811663, 41.93319490977696, 44.68323285239083, 51.95891393933977, 49.79720776421683, 54.696156774248394, 55.1289461680821, 57.86821092878069, 55.23540646689278, 44.310072898864746, 23.394793101719447, 45.197819914136616, 63.341466767447336, 53.8382487978254, 53.93009008680071, 48.38053607940674, 49.21034206662859, 47.45337540762765, 44.6136257989066, 45.02316304615566, 43.21014526912144, 40.062454972948345, 41.639074189322336, 39.449537004743306, 40.982889788491384, 38.877870491572786, 39.747701576777864, 38.947029386247905, 38.501625537872314, 40.000723702566965, 40.94467469624111, 43.78587647846767, 42.320046288626536, 41.89659527369908, 40.822122369493755, 39.93087346213204, 39.729146412440706, 40.0533424104963, 40.82283803394863, 41.656917163303916, 42.815800258091514, 38.6572756086077, 42.546609674181255, 41.538363524845664, 39.03389923913138, 40.939665045057026, 41.96587576184954, 42.871840953826904, 41.44232552392142, 41.88674620219639, 45.27041121891567, 50.1976637159075, 49.94675384249006, 56.807026454380576, 56.164939948490684, 57.35979386738369, 54.686151368277415, 54.42778607777187, 56.19312184197562, 57.17633363178798, 52.10572590146746, 52.243414878845215, 50.88648727961949, 58.585341453552246, 62.88083594185965, 66.8069155556815, 46.82243381227766, 7.651942542621067, 4.924035046781812, 0.4424223926450525, 11.426784191812787, 65.58692305428642, 56.4184102330889, 73.87158679962158, 60.40543597085135, 71.7960626057216, 35.832176276615684, 37.5245246887207, 48.541550159454346, 57.18065193721226, 39.7675838470459, 0.3255767353943416, 0.18256299516984395, 0.1869577443493264, 0.15390585575784954, 0.20733393382813248, 0.0858270666961159, 0.21215383947959968, 0.18451387834336075, 0.2698429546185902, 0.12130283165190901, 0.13413194753229618, 0.11297647415527276, 0.12312777872596468, 0.31018438562750816, 0.10473015664943627, 0.1507656364036458], [0.08699019785438265, 0.043868425501776595, 0.05599364272451826, 0.058819886962217946, 0.05314484737547381, 0.07577569676297051, 0.039076397461550574, 0.054374396934040954, 0.038757190840052705, 0.02139009891210922, 0.02278583187476865, 0.03986572028536882, 0.04956595852438893, 0.09385863465390035, 0.04038038909701364, 0.026695258882162825, 0.044132009215120754, 0.08843013737350702, 0.07230659827057805, 0.13180025693561348, 0.222181338550789, 17.84236775125776, 46.83775111607143, 58.856710297720774, 39.31666660308838, 28.50946978160313, 54.65489837101528, 56.45600693566458, 63.20938846043178, 49.18040575299944, 60.12404087611607, 6.780985849244254, 0.25077375929270473, 36.08684165137154, 67.09477247510637, 62.9888595853533, 60.193161555698936, 51.71526493344988, 46.51910672869001, 48.71342774799892, 48.27394029072353, 48.81771673474993, 44.44798074449812, 43.099880831582205, 42.900801045554026, 43.07672248567854, 42.251735074179514, 44.681231771196636, 42.036257539476665, 41.44644580568586, 37.49234063284737, 40.44973019191197, 40.19636413029262, 40.7127229826791, 40.193928786686485, 40.03078160967146, 38.74349927902222, 39.34515421731131, 40.63527488708496, 40.15324708393642, 40.41997800554548, 43.345791476113455, 40.30517292022705, 38.068929944719585, 39.22829941340855, 38.59633295876639, 39.52713796070644, 39.15021903174264, 41.1822509765625, 37.990734917776926, 37.50623008183071, 36.59277820587158, 38.63046598434448, 37.013727869306294, 37.3871796471732, 38.60918017796108, 36.47671202250889, 38.547108445848735, 38.83261340005057, 39.128102915627615, 39.96968609946114, 41.575925486428396, 46.29009757723127, 49.35686220441546, 52.05202327455793, 53.90835959570748, 54.008420603615896, 52.202913829258506, 42.883753640311106, 28.863327639443533, 38.57535982131958, 57.77708877835955, 51.31006683622088, 51.005645411355154, 49.04008688245501, 48.47339180537632, 48.00437797818865, 45.605644430433, 38.91795812334333, 39.97733954020909, 38.56057752881731, 36.30575507027762, 36.63289015633719, 37.27525806427002, 35.194244793483186, 36.32012047086443, 35.923426968710764, 35.55717352458409, 36.252257415226524, 36.16978924615042, 38.54393311909267, 37.67027357646397, 37.45656435830252, 38.02633053915841, 36.25048909868513, 38.639522961207796, 35.987277439662385, 36.878581932612825, 36.34031193596976, 36.42065743037632, 36.20739984512329, 37.55424213409424, 36.40503440584455, 36.00453329086304, 37.47029052461897, 37.50344385419573, 36.623117515019004, 39.82400321960449, 39.664319719587056, 38.13818958827427, 38.449788502284456, 42.334203243255615, 49.390595708574565, 52.541214670453755, 53.63266202381679, 53.78008542742048, 52.307136808122905, 48.01067304611206, 46.97684710366385, 43.79381479535784, 45.11176300048828, 46.763509614127024, 53.46595042092459, 54.966267994471956, 60.26502677372524, 43.77110808236258, 5.581306406429835, 0.3422570531921727, 0.019866282286654626, 14.220657450812203, 48.25453397205898, 51.718655654362266, 52.07525110244751, 50.99049139022827, 49.02421372277396, 25.066331659044536, 33.13334655761719, 31.917988504682267, 33.99658727645874, 1.8359629000936235, 0.019511177769995162, 0.09576557589960949, 0.019959952349641492, 0.02719696088960128, 0.06641626970044204, 0.056128983319337876, 0.023645678235750114, 0.0491040525957942, 0.060127464655254564, 0.07421270491821425, 0.00513251097540238, 0.09154071831809622, 0.029850689295147146, 0.03286608873999544, 0.02561632034900997, 0.07462408034397022, 0.03529358848131128, 0.028538093835647618, 0.021029196313715408, 0.015971170671816384, 0.09450194691973073, 0.09696800780615636, 0.021990241083715643, 0.03842571969809277, 0.023308517577658807, 0.027425428719392846, 0.17590109764465264, 0.018128130019509366, 0.011541859462990292, 0.044479354683841975, 0.03752319348443832, 0.06215862530682768, 0.011927384400873311, 0.05709429777094296, 0.08614523176636014, 0.037608695682138205, 0.23909921145864896, 22.406370162963867, 56.327312401362825, 49.44691433225359, 49.39667885644095, 32.905535970415386, 60.67507471357073, 67.8534323828561, 66.77889347076416, 56.4961119379316, 64.40740380968366, 8.281209622110639, 0.2359884540949549, 39.186353138514924, 69.515045438494, 66.02124105181012, 61.61584690638951, 54.857851777757915, 49.163636275700156, 52.72147178649902, 51.07029145104544, 52.254083837781636, 48.539979866572786, 46.1677884374346, 45.60036727360317, 43.40444816861834, 44.715145928519114, 46.88918515614101, 43.51126977375576, 43.0592998777117, 40.48893887656075, 41.83574295043945, 42.95386096409389, 43.932111740112305, 42.092544896262034, 40.786526748112266, 40.739793164389475, 41.30655424935477, 42.05300964627947, 43.295034885406494, 41.77989680426461, 44.56049639838082, 42.84937742778233, 41.75642926352364, 41.22022288186209, 42.46505866731916, 43.80782583781651, 42.40342467171805, 41.40095942361014, 41.12090185710362, 40.23895311355591, 38.42635570253645, 42.116272994450156, 39.840991565159385, 41.03257983071463, 40.06358058112008, 40.346268040793284, 38.80394513266427, 42.364215987069265, 39.842947483062744, 41.01818316323416, 42.96290751865932, 48.08657169342041, 52.20341757365635, 55.86265856879098, 55.09590400968279, 56.71666513170515, 53.498443671635215, 51.59770836148943, 42.4581104687282, 41.62631382261004, 60.02363245827811, 56.48433126722063, 54.68068661008562, 50.12764324460711, 50.458808285849436, 48.63390908922468, 46.000479289463584, 40.93607977458409, 42.34815870012556, 40.48666681562151, 39.32543175561087, 37.92582137244088, 39.43190942491804, 39.02271611349923, 39.16714136941092, 39.75839138031006, 37.63386154174805, 38.32577705383301, 38.39885125841413, 40.032963344029014, 39.03287785393851, 40.341817719595774, 40.36046321051461, 38.610701833452495, 38.6711859021868, 38.93469633374895, 40.270060198647634, 37.57642078399658, 37.11219426563808, 37.434152943747385, 39.72719744273594, 38.042707443237305, 39.260236808231895, 40.56913845879691, 39.60291501453945, 40.38031073978969, 42.35316835130964, 40.81074469430106, 40.58483443941389, 39.89683771133423, 45.27362128666469, 51.71866955075945, 55.24019724982125, 55.35451248713902, 57.387593609946116, 53.209940569741384, 52.176486355917795, 48.30010373251778, 46.761063848223, 46.39333043779646, 48.93468965802874, 55.99381971359253, 58.15659243719918, 61.621634755815776, 46.87940556662423, 5.3542440533638, 0.35942097646849497, 0.5890452063509396, 16.065504925591604, 55.0317200251988, 56.40455552509853, 57.548044885907856, 57.24184124810355, 53.05618040902274, 30.916756561824254, 41.396220752171104, 34.90913936070034, 41.23716606412615, 2.9173106125422885, 0.13348305092326232, 0.06951906784836735, 0.012372193791504418, 0.06317815131374768, 0.090521002321371, 0.02071320764454348, 0.050984768463032584, 0.012916199912849282, 0.03997940204239317, 0.021562233068315045, 0.010933104137490903, 0.0488153359453593, 0.04375948331185749, 0.019327196392363737, 0.02270679102678384, 0.028361287965838398, 0.19618995966655867, 0.11478880047798157, 0.10655205031590802, 0.11370259483477899, 0.19955060790692056, 0.16627759832356656, 0.10143135687602417, 0.19251449831894465, 0.0753146390031491, 0.13921682110854558, 0.24269303147281918, 0.11981831916740962, 0.13942724838852882, 0.21230881687785896, 0.12883637526205607, 0.14091774555189268, 0.11890932651502745, 0.17243736636425766, 0.1688351867986577, 0.21405578670757158, 0.4287714351500784, 35.9515289579119, 65.7965224129813, 64.93254171098981, 53.88545833315168, 38.95161519731794, 67.2561582837786, 67.8882498059954, 74.26620973859514, 58.69672107696533, 71.94294752393449, 8.8698262657438, 0.21421659950699123, 43.998425347464426, 72.38069793156215, 69.28964587620327, 65.38807255881173, 57.83912924357823, 51.11157069887434, 55.54642173222133, 53.37900761195591, 54.4287622996739, 51.64906249727522, 48.104129791259766, 49.45822947365897, 47.31716292245047, 47.170583724975586, 50.314546312604634, 48.071619170052664, 46.17683499200003, 40.86642060961042, 44.542931352342876, 44.84347915649414, 45.15613072259085, 43.92997864314488, 43.569019726344514, 42.802015032087056, 44.423109667641775, 44.66126959664481, 46.51874542236328, 44.781601973942344, 47.52614041737148, 45.10217448643276, 44.77655063356672, 43.99616718292236, 44.7804867880685, 46.050697394779746, 46.098170961652485, 45.84502029418945, 42.854321071079795, 43.82094056265694, 42.221757071358816, 44.54653051921299, 43.29857151848929, 43.67233943939209, 43.77249077388218, 41.52645778656006, 42.08513116836548, 43.383575780051096, 42.82828617095947, 43.01369885035923, 45.05073697226388, 49.36264310564314, 53.219049658094136, 56.207928453172954, 56.015494619097026, 60.00041157858712, 54.99809421811785, 45.11300325393677, 28.25932421003069, 37.34762702669416, 62.28472914014544, 55.74393122536795, 54.195101329258506, 51.204926695142476, 52.083008766174316, 50.13630417415074, 49.60201896939959, 42.60288660866873, 43.44333028793335, 42.5843939781189, 41.30850669315883, 39.55327360970633, 42.91690696988787, 39.8907858303615, 40.805905273982454, 42.32461820329939, 40.71812868118286, 41.66224990572248, 40.58970512662615, 42.48380838121687, 40.944928305489675, 41.77281311580113, 42.76284803662981, 40.07004240580967, 42.66077552522932, 39.93807874407087, 43.40260689599173, 40.21879291534424, 40.96180547986712, 41.32242046083723, 41.778573172433035, 40.72687646320888, 41.7742965562003, 43.68154927662441, 42.8350259235927, 42.220214571271626, 46.380903584616526, 43.733897004808696, 42.14956528799874, 42.50142206464495, 47.34738063812256, 54.93438618523734, 58.61207117353167, 58.07694523675101, 59.41652665819441, 56.212055683135986, 54.40673303604126, 53.34328344890049, 49.87722669328962, 49.325765541621614, 51.710689544677734, 59.6846923828125, 60.37405095781599, 64.64691516331264, 48.88834169932774, 6.888404999460493, 1.180328818304198, 1.0657467267342975, 18.453034503119333, 58.8427791595459, 62.43196841648647, 62.8222348349435, 62.30762345450265, 57.97941337312971, 36.04535048348563, 50.88396160943167, 42.94143411091396, 58.34246022360665, 5.743590704032353, 0.3344853845025812, 0.12496118034635272, 0.07698907343936817, 0.1266281237559659, 0.12929665270660604, 0.2487154911671366, 0.10605091149253504, 0.16377957165241241, 0.18354471320552485, 0.1824925768056086, 0.11271244260881629, 0.2266430455659117, 0.14449810343129293, 0.1420218034514359, 0.1147491740328925, 0.14950398196067127], [0.0525796141342393, 0.03796479085992489, 0.0661759190261364, 0.05911595893225499, 0.028375523630529642, 0.035913952692810974, 0.02719733408386154, 0.0530821473470756, 0.07948811791305031, 0.10374077795339481, 0.016896448164646114, 0.010155483498238027, 0.036906489969364235, 0.04480278179315584, 0.0126963511741321, 0.07900071942380496, 0.07648660468735866, 0.11087937347058739, 0.042983239250523705, 0.038703688353832276, 0.12663796251373632, 1.2533229014703204, 41.47234869003296, 46.52834783281599, 24.240534782409668, 24.861616883959087, 43.10002326965332, 55.2722110748291, 61.48048904963902, 52.62991884776524, 64.49643802642822, 20.046607324055262, 0.48415254056453705, 16.898969139371598, 67.56373419080461, 60.58466475350516, 61.33035237448556, 63.4229621887207, 52.350663798195974, 47.78223017283848, 43.23672212873186, 44.75283990587507, 43.52373831612723, 44.499008314950125, 40.59678534099034, 41.58675077983311, 42.15508215767996, 42.40106923239571, 42.20768696921212, 40.08606495176043, 39.5500739642552, 41.45969602039882, 40.15609931945801, 41.23733976909092, 42.03212683541434, 43.31606708254133, 39.378908566066194, 41.60124819619315, 42.14726543426514, 42.99596357345581, 43.06946856634957, 42.9450923374721, 38.71549456460135, 38.50123643875122, 38.00445066179548, 38.175237383161274, 38.984167507716585, 38.14457498277937, 39.860981532505576, 39.731581756046836, 38.911305223192485, 37.02062048230852, 36.798681122916086, 38.78335067204067, 38.61101450238909, 38.689438819885254, 36.86692632947649, 40.258835383823936, 39.22689240319388, 39.618364334106445, 40.62866367612566, 42.20237854548863, 45.345371859414236, 52.15289027350289, 51.458852086748394, 55.16577162061419, 55.55371734074184, 55.2160244669233, 43.8764705657959, 27.036693130220684, 36.6110519681658, 57.910480294908794, 54.791315828050884, 53.237295627593994, 50.27625479016985, 52.72039481571743, 51.67354794910976, 50.09680713926043, 45.22716563088553, 40.36475024904524, 41.17042166846139, 39.546485219682964, 36.94795969554356, 36.37552540642874, 37.75775139672415, 37.04004069737026, 37.06580114364624, 37.108268533434185, 35.8684458732605, 37.70306559971401, 39.41958679471697, 38.17697095870972, 38.74168232509068, 37.76450157165527, 38.01083605630057, 36.370758942195344, 37.4728787285941, 37.561124324798584, 37.580746037619456, 37.319938455309185, 35.99242605481829, 35.10890007019043, 36.6379519190107, 36.100342001233784, 35.48652424131121, 38.66323021480015, 38.391333307538716, 36.008201939719065, 37.937146936144146, 38.480555125645225, 38.02644171033587, 38.92080341066633, 39.34734637396676, 41.59440074648176, 41.56126478740147, 42.80936970029558, 42.39344358444214, 39.785339968545095, 40.57157032830374, 43.629722663334434, 44.0293413570949, 49.54620409011841, 52.19152920586722, 55.12256077357701, 61.27733761923653, 45.22187805175781, 2.0580086537769864, 1.347998512642724, 0.77106738196952, 20.760887350354874, 45.43968670708792, 55.10356787272862, 50.50668484824044, 62.18938595908028, 30.00162669590541, 17.633176599230083, 25.81090930530003, 38.15340266908918, 15.291308845792498, 0.4692787272589547, 0.05998078574027334, 0.13234551410589898, 0.05398026986845902, 0.0926833034359983, 0.018577934276046495, 0.06502183952501842, 0.014549685608861702, 0.02677137015520462, 0.10999782755970955, 0.007935343210452368, 0.02183462755887636, 0.03961851640737482, 0.0552216530777514, 0.04077282321772405, 0.0653985757380724, 0.028264913940802217, 0.06940162700733968, 0.04025803566245096, 0.024488427210599184, 0.01073423570155033, 0.021231510011213164, 0.017452332889661193, 0.035815500654280186, 0.018337061129776493, 0.05223110837063619, 0.06084589074764933, 0.03355576191097498, 0.04890215110832027, 0.006368060479871929, 0.008437789910073792, 0.050589800014027526, 0.037579902048621855, 0.02468050011832799, 0.07411510444113187, 0.09705349643315588, 0.06586490571498871, 0.0202780614407467, 1.6983464445386613, 51.473655223846436, 52.95450741904122, 29.70098509107317, 31.782887731279644, 46.445754596165244, 63.024851254054475, 66.82847581590924, 57.82957894461495, 69.87833200182233, 25.30322527885437, 0.5433282309344837, 18.3013779095241, 69.35772432599748, 63.83639390127999, 63.24953515189034, 65.56573799678257, 56.063454559871126, 49.23743656703404, 45.594944204602925, 45.78158671515328, 46.129889488220215, 47.65843759264265, 43.33989940370832, 45.70489249910627, 45.12041350773403, 44.74663863863264, 42.122310979025706, 43.83361060278756, 43.949913024902344, 42.82098708833967, 42.28237315586635, 43.21307046072823, 43.846134730747764, 44.82856832231794, 42.600128173828125, 43.166107586451936, 43.1566093989781, 45.38226679393223, 44.325438840048655, 45.438779967171804, 40.78386211395264, 41.63251856395176, 40.68024015426636, 42.02491807937622, 43.43880353655134, 41.95977871758597, 40.96059301921299, 41.32694721221924, 40.44876439230782, 38.719204902648926, 40.199049609048025, 42.14160960061209, 40.85092265265328, 40.794183662959504, 38.39951133728027, 42.316857065473286, 42.80150433949062, 42.76951483317784, 41.38170943941389, 44.6008689062936, 47.65817356109619, 55.40642942701067, 53.59687532697405, 57.30747045789446, 56.00239726475307, 55.45558793204171, 49.32290983200073, 41.9775139944894, 42.41532346180507, 57.77410452706473, 57.04990073612758, 54.775692803519114, 54.27937602996826, 53.884732246398926, 53.85797473362514, 50.58141619818551, 47.05069603238787, 41.73910045623779, 42.692535740988596, 39.72542217799595, 39.48810992922102, 37.96688870021275, 39.731540066855295, 37.81595993041992, 39.05109255654471, 40.12944255556379, 38.43662166595459, 38.88532938276018, 41.10048804964338, 39.004327705928254, 39.40380048751831, 40.556044578552246, 38.973654883248464, 38.762328897203716, 39.00955275126866, 38.60569218226841, 38.37661354882376, 40.4895954813276, 37.98496791294643, 36.80208574022566, 39.11039195741926, 38.77114268711635, 38.338113580431255, 39.688996246882844, 38.781384331839426, 40.32757043838501, 40.354081290108816, 40.847177573612754, 40.66387367248535, 41.083940914699006, 41.14384480885097, 44.43329225267683, 44.72709683009556, 46.63535703931536, 44.48446226119995, 43.643205642700195, 43.98630768912179, 46.89834288188389, 45.362005846840994, 52.27912514550345, 54.34435210909162, 59.48068632398333, 61.60097081320626, 47.3445075580052, 2.1427749395370483, 0.5814564707023757, 0.6768932896000999, 24.16640271459307, 51.280721119471956, 61.00844233376639, 55.697506836482454, 68.98083318982805, 32.31641558238438, 27.33839954648699, 31.499401228768484, 42.04605449948992, 21.698414734431676, 0.6281320803931781, 0.0585902299998062, 0.20733963352228912, 0.018104111576186757, 0.08820873818227223, 0.021546781129602875, 0.049926277582666705, 0.06018451587962253, 0.034973618507917435, 0.07520194790725197, 0.04852358624339104, 0.04895347888980593, 0.019713684849973236, 0.02689300094997244, 0.01840870764239558, 0.018342938939375535, 0.03160246654546686, 0.14880693650671414, 0.0762199539957302, 0.09702267058725868, 0.11847796823297228, 0.15072809984641417, 0.13336622076375143, 0.07595058916402714, 0.09390602353960276, 0.19751648205731595, 0.13974564416067942, 0.15991531472120965, 0.11554547558937754, 0.09497202919530016, 0.14810092081981047, 0.1479230903621231, 0.13518531886594637, 0.1665674549128328, 0.14555671305528708, 0.16098138823040894, 0.2631288506090641, 0.25582737954599516, 3.74275313104902, 65.53831345694405, 60.01501669202532, 37.87982777186802, 38.65539959498814, 53.81998545782906, 68.10584654126848, 72.76035445077079, 64.01043932778495, 74.89814145224435, 26.810464995247976, 0.45721263757773806, 23.32563246999468, 71.02864101954869, 66.86906719207764, 68.22627271924699, 69.15041787283761, 57.93949249812535, 51.90790373938424, 47.31722545623779, 49.76870625359671, 47.93058116095406, 51.02910600389753, 45.815403597695486, 48.58210332053048, 48.057514326913015, 46.42796720777239, 46.6821288381304, 45.41235596793038, 47.09838499341692, 46.794689655303955, 44.98799821308681, 45.64216763632638, 47.220266819000244, 48.33842999594552, 44.0827625819615, 46.021035534994944, 47.69080230167934, 48.287708146231516, 48.72314827782767, 47.860293184007915, 44.100932121276855, 45.29283652986799, 43.153965609414236, 44.872630323682515, 45.72307593481881, 44.85024670192173, 44.93134954997471, 44.971166202000205, 44.63449471337454, 41.24364873341152, 41.63605867113386, 45.104974610464915, 44.37526784624372, 43.482816900525776, 41.71762704849243, 45.69050625392369, 44.73465994426182, 45.320761340005056, 43.77880668640137, 47.41354833330427, 49.65846266065325, 57.483145236968994, 53.66152136666434, 60.11758599962507, 59.72157342093331, 58.07392971856253, 45.22950717381069, 27.96601469176156, 34.350403445107595, 63.49518176487514, 59.33495480673653, 57.317576612745015, 54.57797833851406, 56.64027663639614, 54.59376117161342, 53.877690247126985, 49.05955573490688, 43.146503244127544, 44.45710025514875, 43.8750079699925, 41.16093042918614, 40.98970249720982, 42.00661652428763, 39.304333550589426, 40.81201621464321, 42.1848795073373, 40.010155882154194, 42.42890024185181, 43.11978742054531, 40.477578571864534, 42.496950898851665, 43.32879965645926, 41.2455838067191, 40.60338960375105, 42.377188273838584, 43.086762632642476, 40.169544083731516, 42.497541495731895, 40.82685061863491, 39.32608141217913, 41.6303368295942, 42.058269432612825, 41.02264390672956, 43.047161374773296, 43.83445828301566, 43.53220122201102, 42.228145939963206, 43.74654620034354, 43.048061166490825, 43.63186270850045, 44.1183443069458, 48.14896304266793, 46.92597934177944, 50.52452087402344, 47.279993534088135, 45.793905871255056, 47.112107685634065, 49.094588552202495, 47.211063929966514, 56.2627705846514, 56.346829891204834, 61.762481689453125, 63.50891835348946, 50.568165983472554, 2.9747785116944994, 1.899711970772062, 2.1075358475957597, 24.956402472087316, 55.880845478602815, 66.77329322269985, 60.611561230250764, 74.56533663613456, 38.349682331085205, 29.269026006971085, 40.88323872429984, 51.19498382295881, 36.87823452268328, 0.5268226223332542, 0.15272764755146845, 0.3471483678690025, 0.0649447375908494, 0.24711371426071438, 0.08873580382870776, 0.1119104888556259, 0.259245404707534, 0.16027352692825453, 0.14610062672623567, 0.1370329154389245, 0.11212671082466841, 0.1447578194950308, 0.1441496214164155, 0.15589845526431287, 0.15422832274011203, 0.07187583709933928], [0.008085863481807922, 0.03306584944948554, 0.033290834698293886, 0.016183794708922505, 0.035717693224017105, 0.06475005910864898, 0.01992646834280874, 0.051704208965280225, 0.031008633053196327, 0.07304197416773864, 0.025523123564198613, 0.016555945721587965, 0.012445785155120705, 0.03429129047851477, 0.08095433709344693, 0.02445892959700099, 0.12269437126815319, 0.04703442579401391, 0.07533799417849098, 0.011676700486402427, 0.15155288630298205, 0.10084987272109304, 28.02822538784572, 41.439271790640696, 34.78223746163504, 46.0003160067967, 27.539551632744924, 66.27387060437883, 52.15101773398263, 60.15935162135533, 60.03380462101528, 34.00811086382185, 0.03906078776344657, 0.40946211985179354, 34.321967942374094, 70.72487272535051, 60.54072434561593, 64.38550308772496, 59.38740675789969, 52.543271337236675, 43.76796749659947, 49.28958627155849, 45.548544134412495, 44.47341462544033, 44.16620697293963, 46.211857386997764, 42.940134797777446, 42.95284652709961, 42.54523393086025, 42.83673518044608, 40.063518047332764, 39.3344018799918, 41.3453425679888, 40.18629619053432, 41.09795890535627, 42.52097429547991, 41.595793860299246, 40.8206285067967, 41.81615597861153, 40.33911487034389, 40.2871527671814, 40.22509840556553, 39.72611352375576, 37.874154567718506, 40.91491208757673, 39.48034879139492, 40.823435579027446, 38.99044173104422, 40.01524543762207, 39.73238774708339, 39.506824902125764, 39.12440299987793, 38.446085112435476, 37.65602282115391, 36.91679702486311, 37.51451928274972, 39.661787101200645, 41.1144574029105, 42.21148763384138, 40.97979089191982, 43.13228028161185, 43.128340653010774, 44.16171496255057, 48.77867828096662, 53.372903619493755, 51.96066835948399, 53.29000813620431, 51.84972299848284, 53.77159820284162, 25.293575968061173, 29.36199985231672, 57.73027876445225, 55.65861429486956, 53.347084113529746, 52.95799888883318, 55.38207251685006, 53.216253008161274, 54.219524247305735, 50.61107458387102, 41.61669751576015, 39.858410699026926, 40.0964629309518, 36.74654878888811, 37.004775115421836, 38.77715287889753, 37.70435449055263, 36.57741573878697, 36.00692694527762, 38.26103721346174, 37.914850166865754, 37.44593708855765, 37.53714261736189, 39.45439032145909, 37.608604839869905, 37.05903359821865, 36.71728645052229, 36.861937522888184, 35.76200294494629, 37.80636099406651, 35.66236230305263, 37.58074256352016, 35.701956612723215, 35.54573678970337, 35.80833353315081, 38.094673020499094, 36.924905572618755, 36.784590176173616, 38.17730794634138, 38.123792920793804, 38.83386060169765, 37.976147174835205, 38.78780446733747, 37.43879434040615, 36.39266313825335, 36.123795645577566, 38.50579445702689, 38.12432098388672, 42.1654314994812, 40.4054388999939, 43.03153487614223, 44.78522545950753, 50.83671038491385, 56.26599107469831, 57.0549590247018, 60.984804562159944, 43.63525342941284, 0.04904467399631228, 0.7829328966992242, 1.3119189058031355, 22.552310126168386, 50.35102088110787, 49.06114687238421, 56.460870674678254, 51.42742191042219, 20.984938962118967, 31.06453432355608, 25.98676300048828, 43.53015497752598, 2.820305726357869, 0.2838929449873311, 0.035994138568639755, 0.01128871416273926, 0.033140742752168856, 0.015687451431793824, 0.02978523780724832, 0.037751076077776294, 0.04530375437544925, 0.06531054260475294, 0.03145005400957806, 0.027760472348225967, 0.005861815680483622, 0.03152761734755976, 0.03307476879230567, 0.009464096178167632, 0.10667780321091413, 0.04083466150664857, 0.01662239635230175, 0.047150105836668184, 0.02592380527806069, 0.020088607678189874, 0.0264622550457716, 0.04782802338844963, 0.049198257005108256, 0.12205230072140694, 0.06788034471017973, 0.010673456775423671, 0.021048560006810085, 0.005225282827658313, 0.019882017513737082, 0.02306848920748702, 0.06811680737882853, 0.013662235595152845, 0.0531696987205318, 0.052672139169382196, 0.10055452678352594, 0.01870890680168356, 0.12784115437950405, 0.09118167151297842, 32.38145072119576, 48.61777884619576, 34.071648665836875, 53.07106692450387, 31.72371687207903, 69.56693458557129, 60.70409039088658, 63.76158959524972, 65.95621980939592, 37.462630135672434, 0.20317410704280647, 0.3113502173551491, 35.16698006221226, 73.41381863185337, 63.84528064727783, 67.9532779966082, 61.5656670161656, 55.322036606924875, 45.674546241760254, 50.14135898862566, 48.004072257450645, 47.10568755013602, 46.0227586882455, 47.20286852972848, 44.66002239499773, 46.193482875823975, 45.07859577451433, 43.829278400966096, 41.789370673043386, 43.315323625292095, 45.24018655504499, 43.675344535282676, 43.9444899559021, 44.39328452519008, 43.01958744866507, 43.447551318577354, 44.25437266486031, 42.8166618347168, 42.85996995653425, 43.42566796711513, 42.389701979500906, 41.739565985543386, 42.99152020045689, 43.89534534726824, 42.97118977137974, 42.37944991247994, 42.133508001055034, 42.26315443856375, 41.65284899302891, 41.28390312194824, 41.493620600019185, 41.07986579622541, 39.38332067217146, 39.957356521061485, 41.146606717790874, 42.54337528773716, 42.64744540623256, 44.71184206008911, 43.86921664646694, 47.21663291113717, 46.97690963745117, 52.92781591415405, 55.10794871194022, 55.3619053704398, 55.82956082480294, 54.87227623803275, 56.60470533370972, 36.81644071851458, 40.718611580984934, 56.34559658595494, 55.865066119602744, 56.02792842047555, 56.82139880316598, 57.80644491740635, 55.22604029519217, 55.18788078853062, 50.332358019692556, 43.667284624917166, 41.66260773794991, 41.41495656967163, 38.22955839974539, 39.482061522347585, 41.287206990378245, 40.867692129952566, 39.32442774091448, 37.81119694028582, 39.762504713875906, 40.06235074996948, 38.359243052346365, 39.801032475062776, 39.467748233250205, 39.57228735515049, 38.647033963884624, 38.04052223478045, 38.58586549758911, 39.06202207292829, 38.55335487638201, 39.14036301204136, 39.393513679504395, 38.499231883457725, 37.460191317967, 37.86714383534023, 40.24957343510219, 40.15355280467442, 39.292396545410156, 41.601307255881174, 39.67298412322998, 40.74774537767683, 40.20332622528076, 42.030125754220144, 41.486415318080354, 38.033876282828196, 38.864536898476736, 41.48716919762747, 41.2454274722508, 44.7407465662275, 43.98202412469046, 46.64665133612496, 46.83679573876517, 52.88134636197771, 57.07514354160854, 58.78341375078474, 62.1299649647304, 45.78713485172817, 0.13098748054887566, 0.946168880377497, 2.095523932150432, 26.5796788419996, 56.723022733415874, 55.65364285877773, 62.43714482443673, 56.44721746444702, 26.067148447036743, 38.132307938167024, 28.48238570349557, 49.720412799290244, 3.767100053174155, 0.3935501751090799, 0.07268194348684379, 0.12387445223118577, 0.024313638286132897, 0.035650793063853464, 0.024860902223736048, 0.00991916417011193, 0.03962827713361808, 0.040550372297210355, 0.02592096900168274, 0.019290297658049634, 0.03096803630303059, 0.017669976389567767, 0.040018197282084396, 0.10834153036453895, 0.041758673531668525, 0.0436182598184262, 0.08027870620467834, 0.09595526036407266, 0.1409236623772553, 0.13795945500688894, 0.12820569053292274, 0.19998151835586342, 0.15928043664566108, 0.16703065005796297, 0.1678241424794708, 0.16055270337632724, 0.15615410011793884, 0.06345993333629199, 0.22165328902857645, 0.12948700892073767, 0.14262621530464717, 0.11547914200595447, 0.21083723727081502, 0.16297466627189092, 0.23212970686810358, 0.118863864668778, 0.3161168172955513, 0.1157361710710185, 46.69222804478237, 56.093561104365754, 51.59102766854422, 62.4871301651001, 38.474187101636616, 77.08407946995327, 64.49012211390904, 72.24092102050781, 71.95001384190151, 43.71310799462454, 0.3070997382913317, 0.7832018679806164, 39.71495819091797, 76.05664239610944, 66.02488190787179, 69.97247314453125, 65.11015156337193, 59.513982091631206, 47.375819614955354, 52.314706870487754, 52.16573749269758, 49.81671830586025, 49.8929226739066, 50.14153616768973, 48.19970226287842, 49.82195029939924, 47.74097524370466, 47.457429681505474, 44.30385078702654, 45.870283944266184, 47.5710883140564, 47.15483910696847, 47.69228226797921, 47.559047085898264, 44.27616916384016, 46.33348560333252, 46.73927082334246, 46.46343081338065, 44.66910369055611, 45.6881160736084, 44.519085134778706, 44.808797223227366, 48.32289729799543, 46.01609883989607, 44.43475832257952, 44.121391092027935, 45.67296552658081, 46.16021490097046, 44.79014825820923, 43.541143553597585, 43.41970293862479, 43.973436151232036, 41.945128440856934, 42.60434920447213, 44.55841541290283, 44.626486914498464, 46.04755680901663, 46.41956336157662, 47.75983265468052, 48.681771755218506, 48.12241744995117, 52.69350528717041, 56.54108762741089, 55.4482957976205, 54.886818817683626, 54.847940172467915, 54.78460386821202, 27.38282459122794, 32.56189543860299, 57.545248235974995, 58.497537067958284, 55.954517228262766, 57.48432295663016, 59.36966800689697, 55.43729679925101, 56.71688052586147, 52.87994977406093, 45.28109754834856, 43.32110105242048, 44.113390241350444, 40.05072293962751, 42.25145019803728, 44.44348873410906, 42.27397973196847, 41.20376259940011, 41.41017273494175, 44.29330342156546, 41.91019984654018, 41.07781260354178, 40.952053683144705, 41.73138100760323, 41.7131940977914, 39.961928435734336, 39.814272267477854, 41.45983151027134, 40.09359679903303, 41.684522356305806, 40.44482823780605, 41.4532585144043, 40.176005908421104, 39.248146942683626, 41.02611453192574, 42.77695287976946, 43.09497887747628, 40.91980014528547, 44.84707137516567, 42.51297344480242, 42.194871016911094, 41.95066268103463, 45.25676148278372, 42.94446005140032, 40.62477615901402, 41.15413509096418, 44.538873604365754, 43.67121730531965, 47.23291948863438, 45.527199268341064, 49.323684556143625, 48.47481618608747, 57.132959502083914, 60.70173495156424, 61.63120242527553, 62.844524656023296, 46.51462861469814, 0.24156875322972024, 1.4490062126091547, 2.432956248521805, 28.290466036115372, 61.61119161333357, 60.302067620413645, 67.01399966648647, 63.47803361075265, 28.928387096949987, 45.305711541857036, 37.94527285439627, 60.825086321149556, 12.087965215955462, 0.526248744555882, 0.18260381583656582, 0.15938558243215084, 0.2018816199685846, 0.08747401367872953, 0.10249925564442362, 0.10134204131151948, 0.2429785318672657, 0.16324123553931713, 0.07069030750010695, 0.1094963223274265, 0.21222560134317192, 0.1397734098136425, 0.12220954442662851, 0.21798761215593132, 0.19796460015433176, 0.1523526483880622], [0.07610971919660058, 0.046436527876981666, 0.004222989913874439, 0.03716407882581864, 0.04298838933131524, 0.02073351450131408, 0.017109550568940382, 0.008551184137883996, 0.0752003804913589, 0.05630265435736094, 0.017619690159335732, 0.040946429794920344, 0.017118654812553098, 0.021561183035373688, 0.08725832096700158, 0.04993112910805004, 0.014412156738606947, 0.024484569739018167, 0.06235966844750302, 0.04681645320462329, 0.008668981209796454, 0.12517823012811796, 1.9739256799221039, 64.6971297945295, 30.855991091047013, 56.856257915496826, 37.95159918921334, 34.52113458088466, 73.54102625165666, 56.41371325084141, 59.61867754799979, 52.11486973081316, 6.865959278174809, 0.46067425182887484, 3.4399788635117665, 50.09268338339669, 66.96265247889927, 62.07058565957205, 63.999815532139365, 57.35912684031895, 55.38095038277762, 52.349343640463694, 48.91515132359096, 48.222551413944785, 49.11188609259469, 49.78729615892683, 46.93808657782418, 42.63545628956386, 44.370758465358186, 44.432371616363525, 40.962601048605784, 40.981277806418284, 42.62984561920166, 41.02422114780971, 40.893056528908865, 40.81602185113089, 41.693388257707866, 38.349821295057026, 38.98228107179914, 40.64628083365304, 42.12084490912301, 42.36310427529471, 40.11554963248116, 40.20071370261056, 39.627271924700054, 41.03908681869507, 40.19090979439871, 38.582488673073904, 38.28874315534319, 39.678108419690815, 37.480236870901926, 38.358582973480225, 38.15911408833095, 39.20411273411342, 37.847133023398264, 40.02491733006069, 41.130469526563374, 39.066145828792024, 39.84096029826573, 41.79763208116804, 45.34661211286272, 46.929182461329866, 45.72555991581508, 45.71832684108189, 50.91479771477835, 51.03500155040196, 54.89662272589547, 53.617101533072336, 56.90114675249372, 40.65467078345162, 16.45361566543579, 45.60629408700125, 60.05400998251778, 53.91716643742153, 52.085235663822715, 52.94613136563982, 56.7987094606672, 55.15133326394217, 50.961597306387766, 45.409420354025706, 40.9821845463344, 39.9008572442191, 38.68700000217983, 39.02130215508597, 35.68042067119053, 37.55470071520124, 35.332639013017925, 35.40403870173863, 39.04377262932913, 37.83276762281145, 37.067374910627095, 37.84436069216047, 37.99580710274832, 38.87487234388079, 36.79504721505301, 38.025865009852815, 38.381710052490234, 38.76713705062866, 39.17214754649571, 37.816039834703716, 37.485868385859895, 36.40295342036656, 37.17124700546265, 36.26453488213675, 38.48860808781215, 36.77495302472796, 38.20239094325474, 36.62101221084595, 38.56925235475813, 40.683686460767476, 40.60500158582415, 38.24217632838658, 39.0700854573931, 37.77112667901175, 39.24212980270386, 36.81168467657906, 40.72669233594622, 38.81482948575701, 42.772658893040244, 42.08319609505789, 47.35433578491211, 52.448164394923616, 58.06048148018973, 56.15358659199306, 65.0795864377703, 34.886856487819124, 0.11074061305927378, 0.33317073647465023, 1.2714540085622241, 27.049144302095684, 51.15795687266758, 49.52852092470442, 56.3857467515128, 31.189143317086355, 17.444923843656266, 30.722724642072404, 30.761485167912074, 37.379091944013325, 0.37968876319272177, 0.05153500268767987, 0.07469627646995441, 0.06851974182895251, 0.05539398740178772, 0.008206500222773423, 0.08543300748403583, 0.032757821692419906, 0.05552720418199897, 0.03420259577355214, 0.05777416950357812, 0.03104878536292485, 0.03090942444811974, 0.04227731177317245, 0.02579958756853427, 0.017172128461035233, 0.02417546141493533, 0.03235303823437009, 0.05929712778223412, 0.0041240277018265, 0.048923138196447065, 0.028018868661352565, 0.1109465416520834, 0.03335862373933196, 0.02063518120641155, 0.03192152388926063, 0.04444597415359957, 0.01867718528956175, 0.07500038229461227, 0.04116396812189903, 0.04216757908995662, 0.04988523299938866, 0.03321523232651608, 0.03142650545175586, 0.008672697037192327, 0.048966689966619015, 0.07923460365938288, 0.00944078341126442, 0.04508526609944446, 0.04429780585425241, 2.625131913593837, 72.09657219478062, 35.935176372528076, 63.01624938419887, 45.31277438572475, 42.02177749361311, 77.56001717703683, 62.21041815621512, 66.11732074192592, 57.16150617599487, 8.735831124441964, 0.4744357019662857, 3.5104772405964986, 51.44050884246826, 69.888274874006, 63.51123905181885, 66.86273738316127, 59.51359299251011, 58.26352868761335, 54.73775216511318, 51.91249997275216, 51.87137705939156, 51.21221188136509, 51.79314381735665, 48.597674233572825, 43.241895062582834, 45.9556564603533, 45.35448442186628, 45.455889906202046, 42.99924659729004, 43.92322499411446, 43.31070307322911, 43.30051701409476, 42.78084734507969, 43.059869629996165, 41.631681306021555, 41.22931807381766, 42.41692502158028, 44.122061593191965, 45.34291219711304, 43.077723026275635, 41.96646635872977, 39.511945724487305, 41.99759776251656, 43.313763754708425, 43.17221505301339, 42.322207178388325, 41.77658946173531, 40.65526485443115, 40.21053498131888, 39.70725958687918, 42.531174251011436, 39.895917075020925, 40.118554728371755, 41.80773823601859, 43.332978997911724, 40.85068988800049, 44.37637260981968, 46.42886699948992, 47.69236217226301, 49.09130552836827, 48.75193119049072, 54.628335407802034, 53.966408320835654, 55.72879804883684, 54.25934089933123, 61.88606234959194, 47.5735445022583, 24.741626705442155, 51.67586169924055, 59.17013658796038, 56.077253682272776, 55.27458735874721, 54.86496673311506, 58.49097796848842, 57.01067468098232, 53.19797229766846, 47.71269260134016, 43.09274155752999, 42.04237542833601, 40.29418087005615, 40.52120631081717, 38.9496488571167, 39.52318443570818, 37.37555531093052, 38.1118837084089, 39.109314986637656, 39.201010363442556, 39.53870323726109, 39.63052020754133, 39.99400132043021, 39.822172369275776, 37.2794999395098, 39.19287749699184, 40.23615298952375, 40.515800612313406, 41.505317892347065, 40.27074112210955, 40.69893775667463, 37.66624362128121, 39.36383792332241, 38.08418124062674, 40.13068628311157, 39.77901710782732, 41.345912320273264, 41.30239575249808, 41.65207774298531, 42.74091952187674, 42.78977925436837, 40.048992838178364, 40.6948869568961, 40.88492366245815, 42.13871567589896, 40.58070720945086, 42.61202001571655, 40.38712344850813, 46.00755255562918, 45.04385825565883, 51.382939543042866, 52.708120822906494, 59.48671041216169, 57.290933745247976, 66.24245779854911, 34.86174917221069, 0.12929161797676766, 0.38217581116727417, 1.938600821154458, 30.07928671155657, 56.824862480163574, 54.79881640842983, 63.09341607775007, 36.68777745110648, 27.61142553601946, 35.56947531018938, 31.325390543256486, 43.16089643750872, 0.48025812953710556, 0.02483516199780362, 0.0998175631144217, 0.0768680227920413, 0.05640799352633102, 0.05680770154244133, 0.03752004847462688, 0.019241719639727047, 0.06654383428394794, 0.046214629962508164, 0.03167516818003995, 0.021526513288595846, 0.027528601665315882, 0.03187037591955491, 0.08474743605724402, 0.0016198593345637033, 0.0735845850514514, 0.030597610465650047, 0.11173153881515775, 0.05802664559866701, 0.13466366114360945, 0.15950064840061323, 0.1440923394901412, 0.19326718364443096, 0.09954830684832164, 0.09869196851338659, 0.1359243927789586, 0.1212249765438693, 0.18793526903859206, 0.14780186329569134, 0.1269697118550539, 0.1492822231458766, 0.1736159681209496, 0.23678855544754437, 0.09383071972323315, 0.10610236480299916, 0.1518167821424348, 0.13057683115558966, 0.1320290725146021, 0.24826665382300103, 5.435587917055402, 87.3860831941877, 44.78977305548531, 74.13622978755406, 48.51303822653634, 47.05556671960013, 82.59375776563371, 69.07728808266776, 71.71596377236503, 64.27889687674386, 9.48611411026546, 0.4179299111877169, 5.261320582457951, 56.97392913273403, 71.38991955348423, 66.33618204934257, 68.57933153424943, 64.59824998038155, 60.5930164882115, 58.58287484305245, 52.96723304476057, 56.38288409369332, 55.03150463104248, 54.766399587903706, 52.16239193507603, 46.30612359728132, 49.29252188546317, 49.358574935368125, 46.63658339636666, 46.31180027553013, 49.24983215332031, 46.109420095171245, 45.265964371817454, 45.74561241694859, 46.88764613015311, 42.33496059690203, 43.414797510419575, 44.65511001859392, 47.08613184520176, 47.554054805210654, 46.48077004296439, 44.9976145199367, 43.264480182102744, 46.29655245372227, 46.346902574811665, 43.92257881164551, 44.345091819763184, 44.20982081549508, 44.4889577456883, 44.44337061473301, 43.92772742680141, 45.62266056878226, 43.94449690410069, 43.59987667628697, 46.814050810677664, 45.0241253716605, 42.67867408479963, 46.910651615687776, 48.29242597307478, 51.45015641621181, 50.07893637248448, 48.593977791922434, 54.61664158957345, 56.308197907039094, 59.01427459716797, 56.40736607142857, 62.08867876870291, 39.0854618208749, 20.709107637405396, 51.630184241703574, 63.83353124346052, 57.343184198652, 56.46033566338675, 55.91802181516375, 59.96312754494803, 57.20093720299857, 53.405369077410015, 50.04294122968401, 44.099653652736116, 43.538270473480225, 40.711100578308105, 43.86646168572562, 39.27397687094552, 41.27083008629935, 39.06871666227068, 39.22713906424386, 43.73004770278931, 41.42372519629342, 40.86500665119716, 40.42848607472011, 42.21957186290196, 42.401972498212544, 40.13479961667742, 41.73514345714024, 43.70254325866699, 42.0823449407305, 44.97495991843087, 42.48644869668143, 43.233352252415244, 39.88344505855015, 42.60740988595145, 41.204120431627544, 44.4994877406529, 41.746086869921, 43.44728033883231, 43.27622611182076, 45.04519925798689, 44.81550223486764, 45.246867247990195, 42.36084263665335, 43.695779187338694, 43.38293654578072, 44.79173592158726, 44.38786145618984, 45.801177161080496, 42.733967849186485, 48.06811032976423, 48.021095343998496, 53.13478537968227, 56.99409280504499, 61.18770585741316, 62.19217913491385, 67.00434167044503, 38.27680267606463, 0.14866767397948674, 0.4473291779203074, 2.5316610549177443, 32.97619220188686, 61.36266149793352, 60.457019397190635, 67.41404220036098, 42.179584980010986, 28.727433034351893, 45.45939179829189, 40.04883997780936, 56.983983176095144, 0.9172602487461907, 0.3468479668455464, 0.1627308822103909, 0.17704570479691029, 0.13980977929064206, 0.10835959975208555, 0.11866394111088344, 0.10624696061547313, 0.14258023777178355, 0.14869698669229234, 0.13515345486147062, 0.12601457882140363, 0.0758413721674255, 0.09740262984165124, 0.2746611503618104, 0.06494851024555308, 0.12541636877826282, 0.09976286640656845], [0.09731201827526093, 0.10072869315211262, 0.04319373777668391, 0.0033861709110039684, 0.020735212535198246, 0.0989322309781398, 0.011569644623835171, 0.02237402049026319, 0.0273334041038262, 0.0057336578029207885, 0.017815340642950366, 0.06824771713997636, 0.02494402276352048, 0.042674336183284006, 0.0474480030659054, 0.057100825277822356, 0.028347876721194813, 0.07249314111790486, 0.058338629214891365, 0.07585980796388217, 0.029701058752834797, 0.13454718382230826, 0.013797523603508515, 13.926179766654968, 49.167589800698416, 25.166866881506785, 46.049710750579834, 20.328025000435964, 46.855000019073486, 65.26492268698556, 53.07399559020996, 59.87855407169887, 24.72341547693525, 0.020423917632017816, 0.13074898906052113, 11.509439962250845, 67.24564565931047, 62.170618874686106, 66.03328227996826, 59.90720844268799, 57.19616379056658, 51.10934380122593, 53.947338989802766, 51.83388457979475, 54.31160177503313, 51.71104737690517, 50.976070404052734, 44.97320897238595, 43.6409717968532, 41.93435525894165, 41.83118840626308, 39.946322781699045, 43.069927147456575, 39.8827154976981, 39.51902593885149, 41.701114654541016, 42.907634598868235, 42.57198796953474, 43.764621938977925, 42.19710833685738, 40.63123798370361, 41.290472643715994, 41.65807751246861, 39.1015191078186, 40.83142948150635, 39.92842769622803, 39.63702719552176, 41.71062673841204, 38.86169161115374, 41.527406215667725, 39.29770844323294, 38.43717057364327, 38.34765345709664, 37.69715963091169, 39.14240230832781, 38.9647889818464, 40.07833855492728, 39.44736916678292, 43.43751464571272, 49.56653451919556, 49.838691983904155, 53.91635002408709, 48.041272912706646, 48.338482107434956, 46.456107412065776, 49.28292294910976, 47.83588068825858, 54.448585510253906, 52.12497935976301, 57.68469163349697, 28.053546360560826, 17.851563692092896, 57.217501708439414, 55.92281607219151, 54.03038385936192, 50.74879830224173, 56.51301690510341, 51.336862564086914, 51.52363361631121, 48.39014196395874, 42.83407749448504, 39.86309378487723, 41.421939509255544, 40.381742068699424, 38.98634924207415, 37.27828400475638, 37.76411942073277, 36.56158079419817, 39.01845339366368, 37.699775627681184, 36.89735943930489, 41.07361241749355, 39.32451111929757, 36.687912940979004, 38.35386167253767, 37.23800182342529, 37.63127333777291, 36.81259489059448, 38.24514320918492, 37.63364267349243, 39.0754668372018, 37.43145704269409, 37.743886266435894, 36.620581422533306, 37.92505012239729, 36.20325871876308, 37.43433359691075, 36.676768030439106, 39.64783164433071, 38.5779584475926, 39.884125982012065, 38.73724242619106, 44.85820933750698, 43.94220747266497, 45.658964906420024, 41.754984038216726, 42.503846985953196, 40.24865279878889, 44.07417460850307, 43.09536450249808, 50.54201643807547, 51.64816270555769, 60.473236492701936, 54.93839182172503, 66.95712866101945, 15.337387561798096, 0.6315550995724541, 0.4339829912143094, 2.302866646221706, 33.01290300914219, 55.00632435934884, 49.669065611703054, 56.68816362108503, 17.065816232136317, 27.870358841759817, 32.652955055236816, 42.03050790514265, 15.554404122488839, 0.320858040026256, 0.09114825366330997, 0.06804269778409175, 0.03998246562800237, 0.012246212739098285, 0.007656925025263003, 0.010259603848680854, 0.04830267559736967, 0.06749009886490447, 0.06896709996674742, 0.09784992691129446, 0.03523746684991887, 0.03199510761935796, 0.05209549975448421, 0.04401384573429823, 0.05988769752106496, 0.02513947816831725, 0.06540406508637325, 0.09528500347265176, 0.11927725534353938, 0.047911174462309906, 0.016546963614278605, 0.02874960337898561, 0.0447595760758434, 0.021781810393024768, 0.03970346899170961, 0.027504810531224524, 0.020869759244046042, 0.042879833906356773, 0.08373909230743136, 0.03576616098039916, 0.029427985727254833, 0.08064915239810944, 0.054576088075659106, 0.09495145601353475, 0.05645314324647188, 0.0371719803661108, 0.05978584262941565, 0.0651905843988061, 0.14457257943493979, 0.0309697394259274, 17.804972546441213, 56.62477173124041, 28.296134029115947, 58.97278690338135, 25.28670941080366, 59.513870920453755, 70.38263920375279, 56.83738660812378, 65.7680973325457, 28.16346686226981, 0.0566919977510614, 0.03522145003080368, 12.33949521609715, 69.92921366010393, 64.7141181400844, 67.90810080936977, 63.209235600062776, 61.838508878435405, 53.05269241333008, 57.005310671670095, 54.49820259639195, 59.09645789010184, 52.27400084904262, 54.75546659742083, 47.13669736044747, 46.67487144470215, 44.375997407095774, 45.788375105176655, 41.75327130726406, 44.69501004900251, 42.48287384850638, 43.379938398088726, 44.03705733163016, 45.01352936880929, 43.94430930273873, 45.80775015694754, 44.47281013216291, 43.029325348990305, 43.41209118706839, 43.500093596322195, 42.34395503997803, 42.90936470031738, 43.42297554016113, 42.788156849997385, 44.02010372706822, 41.72263322557722, 42.92801366533552, 41.4837715285165, 41.06644882474627, 40.20381954738072, 40.350763525281636, 40.94341707229614, 41.4084461075919, 42.21359641211373, 42.028850759778706, 44.72501237051827, 51.313419342041016, 52.12651491165161, 55.37771947043282, 50.68613249914986, 50.26995277404785, 49.10693550109863, 52.12776211329869, 51.60082115445818, 57.807640007564, 55.29820081165859, 71.3902530670166, 32.67582852499825, 21.672567435673304, 61.72249480656215, 57.29830578395298, 56.927046162741526, 52.4496408871242, 56.56689671107701, 52.53422825677054, 53.42533472606114, 50.00196770259312, 43.91255603517805, 40.93052121571132, 43.372983251299175, 40.49570294788906, 41.53880820955549, 39.09669705799648, 39.91192919867379, 38.09400946753365, 39.49316126959664, 39.58994272777012, 40.16968304770333, 40.519462312970845, 41.408244609832764, 38.779230390276226, 41.565874917166575, 38.946129594530376, 40.92614385059902, 40.00101900100708, 38.914873123168945, 40.74034902027675, 40.96268790108817, 39.80928693498884, 39.33274820872715, 38.70118127550398, 40.243966238839285, 38.07350185939244, 41.97383492333548, 40.16460044043404, 40.3295749936785, 40.52429478509085, 41.87319721494402, 40.07985673631941, 45.55047920772007, 45.19536025183541, 48.59202534811837, 45.00263459341866, 45.98975474493844, 41.001583916800364, 46.16973393304007, 44.57483748027256, 55.51920216424124, 53.14563499178205, 62.42370006016323, 56.37811762945992, 68.27202660696847, 16.388550996780396, 0.7340776696801186, 0.9236291412796293, 1.9758766038077218, 36.22551032475063, 61.00023651123047, 54.49197006225586, 63.937038557870046, 22.296539987836564, 37.6325135912214, 34.23320817947388, 45.2035938671657, 17.17365574836731, 0.4680824428796768, 0.13515730894037656, 0.08450701752943651, 0.03660698800480791, 0.06650933756359986, 0.03812767319115145, 0.03596699716789382, 0.05931994691491127, 0.03424534687240209, 0.030477791359382014, 0.05680474652243512, 0.05328646781189101, 0.03387877850660256, 0.04687409136178238, 0.09007055006389107, 0.02663509318205927, 0.11265769840351172, 0.04770716612360307, 0.2950360099119799, 0.23849485388823918, 0.17487714758941106, 0.12699217136417115, 0.13452283798583917, 0.24887288415006228, 0.09416088129260711, 0.10771554109773465, 0.0957103024369904, 0.12801608070731163, 0.1687263904937676, 0.23336944462997572, 0.21343176519232138, 0.13476987901542867, 0.19296378349619253, 0.12720650700586184, 0.16067861233438763, 0.24785329028964043, 0.2483357558293002, 0.1541864571294614, 0.21120254695415497, 0.20843953878751822, 0.22169649813856396, 28.46363946369716, 66.4841091973441, 39.70885419845581, 62.45427213396345, 30.415926933288574, 58.86096259525844, 74.96430914742606, 62.740704672677175, 73.45648751940045, 31.182434831346782, 0.24567093167986187, 0.2393590360879898, 15.086396047047206, 72.13304328918457, 66.81339822496686, 68.81443078177315, 65.19860213143485, 65.27576882498605, 57.124649456569124, 62.392210824149, 57.469613620213096, 63.71375124795096, 55.10180650438581, 57.4514753477914, 50.23660142081124, 50.6259263583592, 45.93780653817313, 47.610102449144634, 43.5833295413426, 48.250455379486084, 46.289017132350374, 45.60786090578352, 47.43501826695034, 49.25181933811733, 47.59186690194266, 48.68352617536272, 46.849365030016216, 45.411862645830425, 45.99991648537772, 47.13061073848179, 44.679696219308035, 47.08778204236712, 45.461538791656494, 44.99468585423061, 48.67340612411499, 44.467529501233784, 47.95362138748169, 44.87034089224679, 43.95338365009853, 42.79641825812203, 42.09746422086443, 44.14586264746529, 42.1625896862575, 43.826252460479736, 43.4797214780535, 47.54491792406355, 53.980697291237966, 54.40507936477661, 60.022715296064106, 52.081935269492014, 53.54972832543509, 50.113715580531526, 54.58856391906738, 53.506444522312705, 57.294852529253276, 56.96598039354597, 61.16113594600132, 25.480626685278757, 20.596948078700475, 62.72848973955427, 59.98156806400844, 57.761274678366526, 51.23640203475952, 58.782336780003135, 51.95579072407314, 53.91354642595564, 52.66125174931118, 46.632817472730366, 43.187674794878276, 45.44887569972447, 43.00863013948713, 42.830148288181846, 41.50762122017996, 42.33156292779105, 40.45119973591396, 43.72998864310128, 41.92826516287667, 42.46143518175398, 44.22642701012747, 43.14627047947475, 39.14644268580845, 44.40738589423043, 41.65066725867135, 42.26047938210623, 42.11721794945853, 42.152924742017476, 42.63807576043265, 45.43050813674927, 43.60061665943691, 41.72693068640572, 41.19992024557931, 44.25336170196533, 38.95559998920986, 43.040970529828755, 42.39226239068167, 43.923117297036306, 42.124162673950195, 43.65127944946289, 42.35878944396973, 48.991300106048584, 46.79191384996687, 50.807996954236714, 47.37344333103725, 47.506094864436555, 44.27514777864729, 50.356468268803184, 47.634782450539724, 57.3098258972168, 57.259170055389404, 63.95131710597447, 56.870560782296316, 69.65322426387242, 18.229111433029175, 0.7833751386829785, 2.449225672653743, 4.295193544455937, 39.6589800289699, 68.43076515197754, 58.07347113745553, 70.20307690756661, 26.700535808290752, 42.205376693180625, 42.18113790239607, 54.263016496385845, 28.510617971420288, 0.453216799135719, 0.25400567586932865, 0.18609205580183438, 0.1485482111041035, 0.41898028339658466, 0.11304881955896105, 0.12189550484929766, 0.2081590731229101, 0.13562726229429245, 0.1697618756443262, 0.18587689234742097, 0.16134871994810446, 0.1366256180086306, 0.09681443497538567, 0.19272621481546334, 0.21001038806779043, 0.15179751174790518, 0.1688903652663742], [0.029260991473815272, 0.06177188748759883, 0.08655989130160638, 0.0359335725328752, 0.0892871203167098, 0.02446057165174612, 0.060616559482046535, 0.015637307693915706, 0.08649050431059939, 0.031636518825377734, 0.047606495275561295, 0.08815765128071819, 0.01083913297458951, 0.03799658361822367, 0.07982736506632396, 0.053097902930208614, 0.041694585899157185, 0.059735203560973914, 0.0988356958010367, 0.20119692385196686, 0.05890346212046487, 0.03700139666242259, 0.14152765353875502, 0.7834042342645782, 51.40942260197231, 32.955597741263254, 27.609186479023524, 28.992855957576207, 24.324411698750087, 62.4098870413644, 59.27262946537563, 56.874351024627686, 48.04147788456508, 2.0729811532156805, 0.3066736182996205, 0.43653485285384314, 29.52542495727539, 70.71555519104004, 58.62389700753348, 65.72730445861816, 58.879743576049805, 58.22471605028425, 56.92086921419416, 57.4456319127764, 55.15930979592459, 57.477100304194856, 52.82606996808733, 44.90371656417847, 43.14788940974644, 44.46673045839582, 45.72145005634853, 41.300689969744, 42.29831232343401, 44.24028866631644, 41.45114973613194, 40.97801562717983, 43.94452122279576, 41.951027461460654, 41.561931814466206, 42.6312769481114, 42.089981010981965, 39.12961762292044, 42.359824725559776, 41.11324494225638, 38.35300357001168, 39.33181715011597, 40.19551992416382, 39.234750815800254, 40.49057865142822, 39.66530636378697, 41.114672797066824, 37.75766454424177, 40.89501939501081, 39.84327057429722, 39.82179021835327, 40.47311088017055, 42.60424150739397, 45.77917569024222, 51.82061352048601, 53.06270824159895, 52.540603228977744, 50.44766684940883, 52.86667176655361, 49.58387722287859, 49.04206017085484, 47.35864019393921, 48.121708733694895, 50.65423331941877, 56.83495126451765, 54.17775167737688, 56.46363953181675, 31.564832414899552, 42.11565807887486, 59.3212251663208, 52.43059934888567, 50.744229861668174, 49.565975189208984, 49.176087447575156, 48.93970625741141, 45.14762612751552, 42.02853809084211, 41.54026733125959, 40.45424999509539, 40.77099405016218, 39.588942187173025, 40.353000845227925, 38.74757787159511, 36.0169358253479, 37.42565877096993, 37.380582332611084, 38.45853975840977, 36.507784366607666, 38.47361387525286, 38.882466724940706, 39.207319327763145, 38.665849685668945, 39.54565143585205, 38.52774034227644, 39.47573866162981, 37.34379856927054, 38.632748467581614, 39.114692892347065, 39.59032140459333, 37.33670793260847, 39.95866625649588, 37.30027157919747, 36.79763541902815, 37.63342727933611, 39.179245131356375, 39.3596898487636, 41.23357384545462, 48.57373421532767, 54.4419777733939, 52.354523522513254, 52.955942222050254, 46.84371614456177, 48.07963739122663, 44.61174283708845, 44.0555534362793, 40.917375223977224, 48.73848990031651, 52.719224044254844, 59.85645880017962, 57.2082119669233, 60.633350781032014, 2.2102408621992384, 0.3331969550677708, 0.5209980234503746, 1.4268530756235123, 45.00838075365339, 55.04334783554077, 56.01599488939558, 32.51040581294468, 16.527688673564366, 29.209830829075404, 24.889833518436976, 45.61810255050659, 2.7749923978533064, 0.1816167916570391, 0.08887455745467118, 0.056550424812095504, 0.06515851683382477, 0.07473688000547034, 0.05344464450276323, 0.043245699988412004, 0.0594034202929054, 0.11108518671244383, 0.014563783870211669, 0.022207046592874185, 0.04439954200227346, 0.05987129732966423, 0.024678963236510754, 0.0449471842231495, 0.06597375630268029, 0.03154941867770893, 0.06387925440711634, 0.014601166060726558, 0.04278163292578288, 0.0866886501067451, 0.015148570794346077, 0.021685378692512, 0.041508311073162725, 0.055798787823213, 0.030671329902751104, 0.010449295098494207, 0.043686418661049435, 0.031661980851952515, 0.06563165930232831, 0.007505867014905172, 0.04176717557545219, 0.06114196950303657, 0.051469971891492605, 0.020202096052733914, 0.0027231026740212527, 0.036138198338449, 0.07492552631135498, 0.006835246259080512, 0.06358595085995537, 0.170754395957504, 1.001277214714459, 61.86874049050467, 34.42242499760219, 36.31623990195138, 39.1949028968811, 27.77031520434788, 70.09758240836007, 65.24545383453369, 62.73437486376081, 52.530076708112446, 2.5907869679587225, 0.3173866277294499, 0.5030814962727683, 31.058048180171422, 75.7820634841919, 62.98761585780552, 67.81001308986119, 61.0965176991054, 62.10523632594517, 58.649904114859446, 59.82521969931466, 57.330284867967876, 60.81156512669155, 54.32048852103097, 46.07388700757708, 47.21464572634016, 47.34292336872646, 49.05789858954293, 42.869593211582725, 44.45517560413906, 46.65106691632952, 44.90516873768398, 43.320496559143066, 45.81835658209664, 45.28100027356829, 42.55015325546265, 42.90194749832153, 45.48522172655378, 43.03594350814819, 44.052927017211914, 43.95897347586495, 41.56257799693516, 42.20062065124512, 42.794226101466585, 41.62024457114083, 43.5074691091265, 41.82824584415981, 43.87443821770804, 40.17884077344622, 42.70028993061611, 43.166142327444895, 42.283370222364155, 42.6267397744315, 44.28280816759382, 46.81029878343855, 52.667723996298655, 53.017899308885845, 55.421541758946006, 51.86012445177351, 55.594544955662315, 51.3923647744315, 52.15698276247297, 48.88494750431606, 50.409389223371235, 51.66355643953596, 56.89728355407715, 58.25727183478219, 69.2169051851545, 32.87952191489083, 42.03473588398525, 60.6581141608102, 55.70436123439244, 56.53080776759556, 51.47747325897217, 51.31925235475813, 49.999535833086284, 48.32677786690848, 43.59071200234549, 42.29090901783535, 41.16876799719674, 41.76373529434204, 40.25949546269008, 41.27396372386387, 40.477425711495535, 39.38643346514021, 38.65492016928536, 39.55018860953194, 42.016663619450156, 39.93618188585554, 40.49333013807024, 40.04697438648769, 42.84383971350533, 40.561453751155305, 41.41567570822579, 38.695587975638254, 40.184507029397146, 39.73473971230643, 39.91552141734532, 41.428766114371165, 42.01478065763201, 40.007762227739605, 41.722758293151855, 38.62763111931937, 39.62781041009085, 39.461661611284526, 41.507030623299734, 42.156061853681294, 44.175486292157856, 49.61688811438424, 57.10795988355364, 55.72003289631435, 54.27786827087402, 48.560577801295686, 50.855908257620676, 46.63891451699393, 47.26554128101894, 45.032101903642925, 52.141860008239746, 55.66648312977382, 60.87133353097098, 58.66407149178641, 61.591423988342285, 1.926024581704821, 0.5215760810034615, 2.1873048586504797, 1.2345068539891924, 52.28175851276943, 57.29465797969273, 64.23822212219238, 39.06054905482701, 24.201277460370743, 30.726084096091135, 25.133817774908884, 53.25653518949236, 2.6519775816372464, 0.3498089579599244, 0.04418686877137848, 0.008350169834946948, 0.027823282638564706, 0.0802942378712552, 0.04827236543808665, 0.07171033562294074, 0.12780300714075565, 0.03013139244701181, 0.012570566896881376, 0.031136849030320133, 0.017207188365448798, 0.02450018622247236, 0.017214584397152066, 0.018193125192608153, 0.023504987392308455, 0.04029533133975097, 0.04842901881784201, 0.15062175983829157, 0.17607005286429608, 0.14488072932830878, 0.10040855354496411, 0.18131439574062824, 0.12857200444809028, 0.19817022340638296, 0.18073926945882185, 0.11962633446923324, 0.14869887301964418, 0.1160867836858545, 0.16137466712721757, 0.19161260314285755, 0.16820231718676432, 0.22868185330714497, 0.1100972532959921, 0.23466482226337704, 0.1351724402712924, 0.20236659608781338, 0.422234265932015, 0.07624617937420096, 0.1997998473899705, 0.3053484394082001, 3.7748594539506093, 76.68607275826591, 46.78101212637765, 43.52971376691546, 42.306556361062185, 33.025229113442556, 74.46797847747803, 71.56983620779855, 68.08206285749162, 57.550289154052734, 2.974507749080658, 0.24301997678620474, 0.7018983906933239, 36.177595547267366, 76.3739457811628, 64.42976311274937, 68.7542176927839, 65.32225922175816, 65.461959702628, 63.75505134037563, 65.06140995025635, 60.09864521026611, 64.06708799089704, 57.904744556971956, 49.0440890448434, 50.52175201688494, 52.267330578395296, 52.81605413981846, 47.46600375856672, 48.41649300711495, 50.00077608653477, 47.00851351874215, 45.71370281491961, 49.25043317249843, 47.602299622126985, 44.64666100910732, 46.84190613882882, 48.12440810884748, 48.020084381103516, 46.839741774967735, 47.53898416246687, 43.180816922869, 46.166197299957275, 46.42294366019112, 44.99634994779314, 46.39495284216744, 43.241141183035715, 46.00882060187203, 43.56999247414725, 45.76992416381836, 45.8922506741115, 45.81259652546474, 46.453387192317415, 47.0666560445513, 51.03234386444092, 55.465120860508506, 57.21289505277361, 57.185116154806956, 53.43996068409511, 58.467534746442524, 52.23560162952968, 54.0431581224714, 51.44664410182408, 53.15761021205357, 54.65492268971035, 58.12389768872942, 59.64100211007254, 56.45794895717076, 29.78560025351388, 41.5673896244594, 61.883220536368235, 56.79178210667202, 57.20633942740304, 53.359733309064595, 52.92246232713972, 51.93296589170183, 48.718034403664724, 45.790337971278596, 44.888948168073384, 44.57176290239607, 44.24133784430367, 41.59835079738072, 43.903863838740754, 42.93420103618077, 40.566043036324636, 41.65131344114031, 40.86598982129778, 45.27625812802996, 41.25877148764474, 43.247227805001394, 42.88424001421247, 44.80950246538435, 43.59521790913173, 43.9100581577846, 42.745519229343955, 43.43585402624947, 43.41393940789359, 43.37582506452288, 44.29336248125349, 44.85633332388741, 42.39832469395229, 44.67108392715454, 40.96055827822004, 42.206818444388254, 41.95608575003487, 45.9068523134504, 45.56196805409023, 46.210974965776714, 52.58326169422695, 60.20678697313581, 57.458715370723176, 57.41083186013358, 51.52770526068551, 54.270124503544395, 49.34226751327515, 50.74212108339582, 48.410458496638704, 55.05637918199812, 58.19010359900338, 64.08301326206752, 59.64002241407122, 63.357114110674175, 3.4684417247772217, 0.8618046130452837, 6.711559448923383, 3.1732060355799536, 55.47572728565761, 65.11863531385148, 67.6688812800816, 43.07523557118007, 27.321670021329606, 44.2645309312003, 35.90674434389387, 63.80405003683907, 7.7974951437541415, 0.765453617487635, 0.18865264340170793, 0.11419204249978065, 0.09680515261633055, 0.1647603940218687, 0.21027671306260995, 0.12394273999546256, 0.14673669902341707, 0.23605419056756155, 0.06394138785877398, 0.0623767471739224, 0.14609076082706451, 0.1588989371167762, 0.0900415223357933, 0.12076658542667117, 0.18641840400440352, 0.09446351469627448, 0.15875576622784138], [0.0365464491104441, 0.03387340111657977, 0.049411910719105175, 0.06552606568272624, 0.03071537021813648, 0.03313074114599398, 0.11162053727145706, 0.1402142540152584, 0.11174916036959205, 0.013633039929637951, 0.032653954944440296, 0.031102413378123726, 0.0997286071734769, 0.011643688909576407, 0.09311025124043226, 0.07845320273190737, 0.03819073284310954, 0.06965126004070044, 0.0273083017008113, 0.018372158353616084, 0.06584567603256021, 0.06846735892551285, 0.08936694996165377, 0.10939093905368022, 22.594782727105276, 53.15571682793753, 25.954617159707205, 27.7530072416578, 27.470745359148296, 53.37064545495169, 48.74733148302351, 50.02585908344814, 59.34309114728655, 7.023972604955945, 0.12252333973135267, 0.1264547716294016, 1.9834618653569902, 53.32603801999773, 64.41196182795933, 67.08988094329834, 62.19607012612479, 57.91286700112479, 56.502650192805696, 62.33947399684361, 60.04647813524519, 59.34048557281494, 54.18833378383091, 46.95177452904837, 45.93700402123587, 44.55158185958862, 44.769136905670166, 46.252177783421104, 42.48435034070696, 42.51321315765381, 42.131732736315044, 42.219544070107595, 41.66680097579956, 42.88816922051566, 43.1315507207598, 41.24420806339809, 40.22525474003383, 41.83383566992623, 42.4259090423584, 43.69672761644636, 41.00202860151018, 38.522067138126914, 39.917817796979634, 39.847800799778526, 40.00906848907471, 38.59432145527431, 37.94057934624808, 39.60252938951765, 41.211513314928325, 41.11372436795916, 41.661461285182405, 41.597944327763145, 47.2663368497576, 53.24041884286063, 51.78728996004377, 53.29875939232962, 53.12646838596889, 51.742262159075054, 54.72996323449271, 52.09046418326241, 53.52749061584473, 52.351983955928254, 50.7182366507394, 51.96923548834664, 55.58890649250576, 56.52548197337559, 53.56271798270089, 52.423508712223594, 45.6454576083592, 56.3560779435294, 52.55671957560948, 51.707858153751914, 46.828562123434885, 47.05990239552089, 43.363860266549246, 45.31800985336304, 42.00666863577706, 41.56952272142683, 39.494769777570454, 41.88439423697335, 39.72764560154506, 39.9109981400626, 36.76709461212158, 37.37447139195034, 37.13409846169608, 36.218336309705464, 36.552860804966514, 38.90248448508126, 38.123476777757915, 37.741711480276926, 38.481371538979666, 39.581653526851106, 39.90182999202183, 39.46741819381714, 38.84598173413958, 37.966885226113455, 38.58242266518729, 38.660867827279226, 38.61763613564627, 38.257559640066965, 37.78771202904837, 38.37223270961216, 38.54130670002529, 38.02479498726981, 38.66335875647408, 38.78888143811907, 45.65099879673549, 55.47509152548653, 54.95919820240566, 53.0964104788644, 52.31852837971279, 54.799379212515696, 49.495624678475515, 52.68231521333967, 44.91765465055193, 44.51326254435948, 47.39325611931937, 55.16602175576346, 54.068300179072786, 61.2078069959368, 42.97361816678728, 0.1072151961603335, 0.2829745885516916, 1.0420777967997958, 2.110300362110138, 43.558628695351736, 55.91729572841099, 43.33943387440273, 9.920238426753453, 23.00052625792367, 26.883798020226614, 38.425042493002756, 25.646329062325613, 0.08709642929690224, 0.026496824708634188, 0.07228530584169285, 0.05415186458932502, 0.034746848712010045, 0.06445316611123936, 0.029078906601560966, 0.007243173030604209, 0.02603362617082894, 0.03587189369968005, 0.048639663229031224, 0.04461683944932052, 0.05566382720800383, 0.004421961826405355, 0.09234767965972424, 0.05946241212742669, 0.021647901507094502, 0.02007291146687099, 0.0707319966916527, 0.06366043364895241, 0.019619760336354375, 0.023336089848141586, 0.04397094535774418, 0.01134414114390633, 0.10824608762881585, 0.01317821366579405, 0.05819971274052348, 0.0265958450202431, 0.04066041710653475, 0.035649134045732875, 0.07229639310389757, 0.13960419675069197, 0.10652905476412602, 0.05109917964520199, 0.028527135495096445, 0.07224876673093863, 0.04911693797579833, 0.029203587411237613, 0.05680083137537752, 0.08367174092148032, 0.046087872835674455, 0.10082579151328121, 0.034196807869843075, 26.308336053575786, 60.635205950055806, 23.491517237254552, 41.62181486402239, 33.55707550048828, 60.08693749564034, 60.228791918073384, 55.30541998999459, 65.5192198072161, 8.157344954354421, 0.12835709883698396, 0.07199266047349998, 2.173652082681656, 55.978509357997346, 67.93289893014091, 69.42371136801583, 65.68443407331193, 60.757119042532786, 59.219774518694194, 62.34906251089913, 63.11605330875942, 60.848710196358816, 56.609318937574116, 48.71842002868652, 47.89931426729475, 48.33932283946446, 45.20129748753139, 47.606013434273855, 44.12408699308123, 44.70342084339687, 46.58857829230172, 45.03593036106655, 46.03829138619559, 44.93169348580496, 44.11020449229649, 44.7177653993879, 42.99083580289568, 45.16597284589495, 44.57091522216797, 44.382928235190256, 43.692169598170686, 41.29916831425258, 42.598464080265586, 42.398550510406494, 42.36619969776699, 42.991054671151296, 41.029494830540244, 44.17712606702532, 42.39771325247628, 43.03668349129813, 43.80502571378435, 44.089519705091206, 49.42230381284441, 53.57468972887312, 55.08465140206473, 57.0081524848938, 56.2868252481733, 54.288683141980854, 55.30134834562029, 54.37180444172451, 55.15405348369053, 52.33939034598214, 53.637577874319895, 53.67626196997506, 58.156460421425955, 57.618246010371614, 59.82598400115967, 67.3054210117885, 49.998438017708914, 57.36305604662214, 54.87056698117937, 54.1111740384783, 48.93136494500296, 49.06747668130057, 46.39287880488804, 46.798188073294504, 44.49083028520857, 42.810015882764546, 43.49879080908639, 42.81506027494158, 41.165696893419536, 42.27620315551758, 40.518347127096995, 39.983881269182476, 40.23236274719238, 38.99363095419747, 39.3617708342416, 40.20954833711897, 39.52753748212542, 41.19843333108084, 40.50825139454433, 42.267264298030305, 41.079712935856406, 40.97576093673706, 42.00330570765904, 39.67362335750035, 40.64235162734985, 41.350647517613, 40.79986034120832, 41.88379669189453, 40.805297306605745, 39.09669358389718, 40.555759702410015, 41.309364795684814, 41.834294251033235, 40.22649499348232, 47.06141710281372, 56.751030921936035, 57.18804134641375, 55.369722093854634, 55.68792527062552, 55.860865933554514, 51.79158047267369, 54.24427373068673, 47.56735018321446, 46.68727397918701, 51.4006643976484, 57.84297854559762, 58.852319036211284, 63.34497560773577, 45.042760440281455, 0.06417339255235024, 0.3588942161628178, 2.5716520633016313, 2.088356431041445, 49.560986382620676, 60.282994815281455, 50.940269810812815, 17.235095194407872, 30.463786125183105, 28.899770941053117, 43.72983578273228, 29.81083263669695, 0.12798279177929672, 0.05120336530464036, 0.03676571091637015, 0.03240436262318066, 0.06062907166779041, 0.024601613637059927, 0.05746799414711339, 0.03611241740041545, 0.031950270025325675, 0.02501662940319095, 0.0377177871497614, 0.03468648962942617, 0.08186425255345446, 0.025575655745342374, 0.03705625282600522, 0.04256854239585144, 0.024536552306796824, 0.03827581774177296, 0.012994802257578288, 0.1321144322199481, 0.15368533187678882, 0.1709600327802556, 0.1205641512892076, 0.0897643475660256, 0.20046250468918256, 0.1801130630608116, 0.2373929944421564, 0.2034013755619526, 0.10083311290613242, 0.09082635665046317, 0.15045177324541978, 0.19265956910593168, 0.21628250793686934, 0.11189879769725458, 0.17396636360457965, 0.16624677926301956, 0.12383143311100346, 0.1752027358327593, 0.09470951078193528, 0.22165175553943428, 0.12234423362783023, 0.1855480878480843, 0.1376505315835987, 39.61398696899414, 68.98493957519531, 38.74830743244716, 43.87828751972744, 38.920223236083984, 64.1299969809396, 61.85354478018624, 62.699939591544016, 74.62067903791154, 7.661424228123256, 0.1443676890007087, 0.2169557096702712, 2.916680497782571, 61.619286264692036, 68.22561958857945, 71.97739669254848, 67.42618070329938, 64.66267367771694, 62.81841332571847, 65.39207472120012, 65.31788185664585, 65.4348339353289, 59.92396054949079, 51.72438097000122, 51.50606509617397, 49.42580223083496, 48.24372952325003, 49.91004303523472, 47.20258365358625, 46.64060640335083, 50.164590290614534, 47.82350942066738, 47.408500467027935, 47.386102948869976, 46.012478828430176, 46.266046387808665, 45.62926483154297, 48.40849215643746, 47.275532790592735, 47.66919687816075, 48.2963273865836, 43.058083942958284, 45.925310203007285, 47.11376135689871, 45.61607367651803, 45.658176285879954, 43.93963316508702, 47.44780642645699, 44.82823133468628, 46.2341228893825, 46.13066421236311, 46.96977383749825, 52.97085305622646, 57.09919473103115, 56.53381633758545, 57.402949128832134, 57.79054396493094, 55.04713807787214, 58.91865348815918, 55.12056316648211, 56.099203041621614, 54.21230854306902, 56.15266595567976, 56.31154693875994, 61.34856360299246, 58.497606549944194, 58.21872322899954, 55.26940400259835, 46.667176314762656, 60.393582344055176, 54.71042490005493, 55.396159989493235, 49.2202536719186, 51.77549191883632, 47.415024825504844, 48.02136284964425, 44.84014054707119, 44.51596539361136, 44.726832798549104, 43.47813728877476, 43.33990287780762, 45.62839978081839, 41.43078804016113, 42.63531037739345, 42.59565700803484, 41.62534802300589, 41.34792382376534, 43.08301755360195, 42.09870100021362, 43.844223976135254, 44.41387551171439, 44.114213602883474, 44.241608824048726, 43.970434529440745, 45.052109241485596, 41.68337937763759, 43.61595828192574, 44.58574267796108, 43.09806735174996, 43.247578689030235, 42.447215693337576, 40.95008734294346, 42.82985993794033, 43.1234803880964, 44.15368284497942, 42.809328011104036, 50.257300104413716, 57.97715520858765, 59.52227824074881, 57.70082187652588, 59.185012681143625, 58.51544952392578, 53.590945039476665, 57.365553924015586, 52.345014912741526, 49.462926455906455, 54.66820069721767, 58.85236767360142, 61.23064572470528, 66.24140862056187, 48.1150940486363, 0.27136463725141113, 0.7505788813744272, 2.8246114381722043, 3.9348009058407376, 54.16023874282837, 66.59566947392055, 52.44592360087803, 16.454103776386805, 37.90671730041504, 41.78449303763253, 53.83297511509487, 42.434986863817485, 0.18375452980399132, 0.1699823723839862, 0.1181689091026783, 0.1579583790153265, 0.15783621557056904, 0.14924414376063005, 0.1316355900572879, 0.11610161646136216, 0.10584170557558537, 0.08259896348629679, 0.07033907741840396, 0.12761354659284863, 0.16867750883102417, 0.12556160241365433, 0.10426474948014532, 0.16824578414005892, 0.10741619180355753, 0.09969244804233313, 0.13058787770569324], [0.045652375490005524, 0.04294201824814081, 0.018764460159997855, 0.0820750394569976, 0.03222173831558653, 0.018630105137292827, 0.04318001440593174, 0.117687407082745, 0.03939227926145707, 0.04584207013249397, 0.03400771373084613, 0.07493610467229571, 0.08289973091866289, 0.013831660700296717, 0.045234621835074255, 0.026133681248341287, 0.04084023567182677, 0.053513302068625174, 0.040976078382560184, 0.08722262323967048, 0.030600256752222776, 0.04933797415079815, 0.04787857085466385, 0.19228497706353664, 1.6818433872291019, 46.78673049381801, 36.819438866206575, 30.169578552246094, 25.068765265601023, 38.16841772624424, 50.84694160733904, 53.80762113843645, 56.915133476257324, 15.908096960612706, 0.47706136107444763, 0.21580988115497998, 0.08770424739590713, 20.766643932887487, 62.33290100097656, 66.40081419263566, 66.15735626220703, 62.053291593279155, 62.078819274902344, 62.07938207898821, 59.89071341923305, 60.85838903699602, 52.15193837029593, 44.92691659927368, 44.013079098292756, 49.90223673411778, 50.38841956002371, 51.4539292880467, 47.25795037405831, 45.311600140162874, 43.967029912131174, 43.46300063814436, 43.37523794174194, 43.3783472606114, 42.258165631975444, 42.76612411226545, 42.43591097423008, 41.589130537850515, 41.0805640901838, 42.224647521972656, 42.37054927008492, 40.2597872870309, 40.02000147955758, 40.75236940383911, 39.512004784175325, 40.07329068865095, 40.52321086611067, 39.67953627450125, 42.71964413779122, 40.89168078558785, 40.625707217625205, 44.086295740945, 53.00062608718872, 54.90714577266148, 56.67715767451695, 56.080078125, 55.02870798110962, 54.35337781906128, 53.84168815612793, 53.29069600786482, 54.48342030388968, 54.27976860318865, 51.55791255405971, 52.79164859226772, 56.36405447551182, 57.313202721732004, 57.85254621505737, 52.985631874629426, 52.92164938790457, 51.824671268463135, 49.22089638028826, 50.21051440920149, 47.19425276347569, 45.96738154547555, 43.88418654033116, 41.04830013002668, 42.241847787584575, 40.847469397953574, 39.791968550000874, 40.17504358291626, 40.74573040008545, 40.71381037575858, 39.19100843157087, 36.99150405611311, 36.401383127485005, 37.59755720411028, 37.04591192517962, 37.12890815734863, 38.20728942326137, 40.181015559605186, 39.838490213666645, 38.86213629586356, 38.88584007535662, 37.71046890531267, 38.23098278045654, 37.90933329718453, 37.96544347490583, 36.77798243931362, 37.40328904560634, 39.90973009381975, 37.491736139569966, 38.05629811968122, 37.328849520002095, 38.81797354561942, 39.05731119428362, 41.82758229119437, 48.17797524588448, 55.70172439302717, 54.62717158453805, 53.746386664254324, 56.06794309616089, 53.14737204142979, 55.29096078872681, 50.145819732121055, 50.26528011049543, 46.89360073634556, 48.57681226730347, 55.382687432425364, 54.249210425785606, 62.01961367470877, 25.55542230606079, 1.0076855165617806, 0.7821669120873723, 0.07592390238174371, 3.3070774120943884, 45.31785699299404, 54.767591203962056, 25.786027806145803, 10.105144756180898, 36.46729373931885, 23.15838064466204, 41.82245452063424, 6.274467817374638, 0.3575405388006142, 0.05822907295078039, 0.11553722460355077, 0.07438871690205165, 0.014137105783447623, 0.04559778395508017, 0.06090516756687846, 0.03975562119324293, 0.032101386559328864, 0.0468092675187758, 0.07979305155043091, 0.0498666852446539, 0.03664163739553519, 0.013907592161558568, 0.038997266707675796, 0.015636171147759472, 0.05664154867242489, 0.0809048515345369, 0.09392389615199395, 0.018529134037505304, 0.02752092064890478, 0.016953063430264592, 0.02748126027706478, 0.06349917980177061, 0.030834280087479522, 0.020406503030764203, 0.015973092622256706, 0.01009561720171145, 0.021806977256866436, 0.008062599060524787, 0.012394706735254397, 0.038841397035866976, 0.030861163644918373, 0.06566965726337262, 0.05188689094835094, 0.06975697579660586, 0.060666228245411596, 0.07300391513854265, 0.06314045190811157, 0.08182581354464803, 0.04766518855467439, 0.018572139586987238, 0.122610422915646, 1.341546784554209, 56.90115022659302, 39.35894986561367, 29.472642966679164, 33.956117493765696, 45.34313106536865, 57.74735743658883, 57.59826646532331, 66.33228410993303, 18.330978972571238, 0.36388473265937393, 0.22252402587660722, 0.026706030625583868, 22.814264161246165, 68.64449174063546, 68.94565446036202, 69.70915726252964, 64.91677624838692, 64.0367591040475, 65.52748121534074, 63.60447692871094, 63.54488222939627, 53.866131918770925, 48.170492036002024, 47.87949105671474, 50.203274386269705, 51.99576023646763, 51.07251487459455, 48.194529329027446, 47.01352316992623, 46.57096113477434, 46.71595614297049, 44.984020369393484, 44.69953332628523, 44.52641895839146, 45.160188470567974, 45.253711223602295, 43.80083247593471, 43.49050508226667, 44.707436902182444, 44.18316405160086, 44.04403679711478, 41.86842727661133, 44.03964900970459, 42.14453479221889, 42.538994448525564, 42.009288106645855, 42.84629242760794, 43.256336893354145, 43.60485506057739, 41.94544805799212, 46.065180914742605, 55.1242596081325, 56.95193461009434, 57.08608348029, 59.12169374738421, 56.350165026528494, 56.58872447695051, 54.39919424057007, 57.26782751083374, 56.535588128226145, 56.15536880493164, 54.81387662887573, 57.13043730599539, 55.380953856876914, 58.84010410308838, 57.97156885692051, 58.807016781398225, 59.184498514447895, 53.29237052372524, 52.6170368875776, 52.39706039428711, 49.380802222660606, 48.791612352643696, 46.6211827141898, 44.205009187970845, 44.80046285901751, 43.42243358067104, 42.63467114312308, 40.75981092453003, 42.51402609688895, 40.93798358099801, 40.320396423339844, 39.72695425578526, 38.68446043559483, 38.94092886788504, 39.35494422912598, 38.875306606292725, 39.48410776683262, 40.79972832543509, 41.31028890609741, 41.585941314697266, 40.683821950639995, 40.22541454860142, 40.4178865977696, 41.10187421526228, 40.70945732934134, 39.95499413354056, 40.3546336718968, 41.14699929101126, 40.36080367224557, 40.82325145176479, 40.46109397070748, 40.49206904002598, 42.47255229949951, 44.74385935919625, 51.27098321914673, 58.428277424403596, 57.86080067498343, 57.80391577311924, 57.91733816691807, 55.69056558609009, 57.44187641143799, 54.089763164520264, 51.9981677872794, 50.708182607378276, 49.51126159940447, 58.89619691031319, 56.23604433877127, 65.28805324009487, 26.015328781945364, 1.0172313643353326, 2.032513758965901, 3.137981274298259, 3.73612802369254, 52.62912327902657, 58.347449030194966, 34.35600369317191, 15.31843113899231, 38.44393811907087, 24.644536052431377, 49.02992861611502, 7.856196131025042, 0.2872075614120279, 0.009885455398554248, 0.14125007843332632, 0.05253782994779093, 0.019602067535743117, 0.014477094236229147, 0.019007998252553598, 0.043794865520404916, 0.04042307573503681, 0.03354251351473587, 0.04252735532021948, 0.0788568225024002, 0.02922411648822682, 0.01190237105557961, 0.08375055954924651, 0.015727773375277008, 0.03500467166304588, 0.02018043551860111, 0.061647797003388405, 0.11965849702911717, 0.20980686827429704, 0.10399535750704152, 0.10573680406170231, 0.12665067825998577, 0.1419740617275238, 0.08894691642905984, 0.1938671985907214, 0.14112725002425058, 0.13106084375509194, 0.11363069047885281, 0.12249098718166351, 0.1525045180959361, 0.08987171894737653, 0.10348418993609292, 0.14714102447032928, 0.12270590636347022, 0.1882415326046092, 0.12309530403997217, 0.11651063737060342, 0.21362149715423584, 0.17038591073027679, 0.22326153915907654, 0.13606759080929415, 6.471183044569833, 74.85377720424107, 52.96658686229161, 45.867129462105886, 40.59941870825631, 47.66141489573887, 65.55797685895647, 64.61186150142125, 72.73842593601772, 22.26560139656067, 1.0577519557305743, 0.7901736253074237, 0.1083231759922845, 27.17008638381958, 71.400710105896, 70.79472296578544, 71.31041826520647, 67.91830771309989, 68.34209224155971, 66.70289407457624, 65.86252335139683, 67.07900006430489, 58.26404632840838, 50.293924059186665, 49.7638008253915, 55.23230062212263, 55.152118410382954, 55.682752336774556, 52.90655442646572, 48.78066546576363, 49.81562743868147, 48.60080787113735, 49.451694692884175, 46.5787535394941, 48.71239594050816, 47.74401160648891, 48.495441913604736, 46.114436694553916, 47.541013036455425, 47.21947125026158, 47.17815031324114, 47.26045519965035, 46.00245952606201, 47.17296348299299, 44.39354855673653, 45.855508599962505, 45.667851652417866, 45.598268917628694, 46.658369473048616, 46.201619216373985, 43.99898815155029, 47.77680362973894, 58.251824447086875, 60.33099297114781, 60.232161794389995, 60.4177690233503, 58.96918773651123, 58.791119303022114, 58.4240459714617, 58.96833310808454, 57.647522245134624, 59.07374422890799, 56.23413011005947, 59.77342782701765, 59.23336519513811, 58.99199867248535, 60.17416518075125, 58.52171679905483, 59.49583339691162, 56.66227810723441, 54.17560120991298, 54.007458278111045, 51.005954606192454, 52.90122863224575, 48.40528208868844, 44.808727741241455, 45.27485806601388, 44.418711457933696, 43.92370094571795, 43.03130211148943, 44.08802931649344, 44.686522824423655, 42.297235352652415, 41.0997029032026, 40.169241837092805, 41.179638453892295, 42.394906180245535, 42.22501925059727, 43.034348896571565, 44.73432295663016, 43.53495965685163, 45.05789361681257, 43.412164143153596, 40.55914000102452, 43.359204973493306, 42.88607781273978, 44.71301630565098, 40.623615809849326, 42.768503870282856, 43.5100017275129, 43.23948751177107, 43.87341683251517, 42.68873160226004, 42.4731741632734, 44.15453052520752, 47.73238032204764, 54.5822480065482, 59.18752098083496, 59.42835944039481, 60.31731196812221, 58.73493616921561, 56.83104290281023, 60.85877118791853, 56.4894242967878, 54.99081598009382, 52.62491961887905, 53.74953767231533, 60.40303884233747, 60.03405475616455, 66.5306829724993, 30.286527156829834, 1.1490397772618701, 2.775239493165697, 5.915490439959934, 3.673422268458775, 59.584395136152, 62.710090909685405, 34.04962982450213, 16.91647686277117, 52.78363731929234, 32.858732904706685, 61.5187805720738, 14.853549752916608, 0.4492000075323241, 0.13616966961749963, 0.19795826263725758, 0.22152303744639668, 0.14458665225122655, 0.15643562429717608, 0.24563312370862278, 0.10200844412403447, 0.11012834377054657, 0.09250421090317623, 0.18940679436283453, 0.16513569174068315, 0.10869073162653617, 0.06915571913123131, 0.14219237358442374, 0.05944506198699985, 0.15357304790190288, 0.14098650829068252, 0.17571714680109704], [0.027625035062166195, 0.025688547009070004, 0.011433927442080207, 0.039429018540041785, 0.04462207434698939, 0.040165795612015893, 0.01503005447531385, 0.019500814843922853, 0.014965977020827788, 0.11216524482837745, 0.022128826772261943, 0.012733784254773386, 0.08077582810074091, 0.0508935428224504, 0.044476012898875136, 0.02881427455161299, 0.05294015371639814, 0.05836028805268662, 0.021757819091102908, 0.06035554063107286, 0.04730673546769789, 0.010468156675675085, 0.05863532543714557, 0.035288767490003786, 0.1741832641086408, 8.212587475776672, 52.00963231495449, 32.906668526785715, 32.37351240430559, 16.08480875832694, 51.32633604322161, 63.511732373918804, 54.6568786076137, 34.409529141017366, 0.2703329926090581, 0.3400139792689255, 0.07496332749724388, 4.143403632300241, 49.71745981488909, 64.94312381744385, 66.80796473366874, 64.37638010297502, 63.19246959686279, 64.73380933489118, 65.59626838139125, 62.54106208256313, 51.6989540372576, 48.77571487426758, 55.36218329838344, 58.170600005558555, 64.19419138772147, 63.35329260144915, 58.23586443492344, 48.51048476355416, 45.885747160230366, 45.38024139404297, 44.014784881046836, 44.00296252114432, 45.15165955679757, 42.49655137743269, 42.601062706538606, 42.17808069501604, 41.56257104873657, 44.71136263438633, 41.87135941641671, 42.89936971664429, 42.57397515433175, 39.19227647781372, 39.535510540008545, 40.75048296792166, 40.98760414123535, 41.515194756644114, 39.77278457369123, 41.597739355904714, 43.50917836597988, 45.83448682512556, 54.15766096115112, 54.446886675698416, 55.68693515232631, 55.94167348316738, 57.02374076843262, 57.84973566872733, 56.43835503714425, 55.4869555745806, 54.53671646118164, 55.57931450435093, 56.966473715645925, 56.442339829036165, 55.01125063214983, 55.94693674360003, 57.44046940122332, 54.803165980747764, 50.669147627694265, 50.202537877219065, 46.86203507014683, 47.86594901766096, 47.91277640206473, 45.66524607794625, 43.26474073954991, 43.15594932011196, 43.16694484438215, 43.70697968346732, 40.16438157217843, 41.79631887163435, 40.90491362980434, 42.15973745073591, 39.94959885733468, 37.901808398110525, 39.19233553750174, 35.49669292994908, 38.4064039502825, 38.123160634722026, 40.38927044187273, 40.14712224687849, 39.226221902029856, 39.21118252617972, 38.17638036182949, 39.90329606192452, 37.21005269459316, 39.148777280535015, 39.21226297106062, 39.721930708204, 37.87671150479998, 39.1456366947719, 38.82386909212385, 38.48216015951974, 38.9835421698434, 40.0131505557469, 39.56046846934727, 40.340970039367676, 45.153903824942454, 52.241125447409495, 55.03341885975429, 60.99063410077776, 56.090080056871685, 56.84534576960972, 56.95686783109392, 56.452793393816265, 51.78304808480399, 53.31358337402344, 51.61357804707119, 57.23940243039812, 55.28352969033377, 63.76288890838623, 7.011041138853345, 0.8440985945718629, 0.20388249760227545, 2.7874361872673035, 6.6232118010520935, 50.22084290640694, 48.3800288609096, 9.203373670578003, 29.08548239299229, 29.167762960706437, 28.05247633797782, 37.45971884046282, 0.5811915706310953, 0.14376107869403704, 0.17553075323147432, 0.05487442974533353, 0.04755297243329031, 0.03998788373012628, 0.026951188720496635, 0.040335290266999176, 0.021144559141248465, 0.04213114854480539, 0.053206346396889, 0.03164515318349004, 0.07551517324256045, 0.02151896119383829, 0.04248509615925806, 0.07241253794303962, 0.013319284488846148, 0.018050541236464466, 0.02895374403202108, 0.09484116693160363, 0.024080364732071757, 0.05063335856954966, 0.01519492661048259, 0.01804882793554238, 0.046847696349556954, 0.02386923347200666, 0.022679595343236412, 0.013832464764293815, 0.02670797971742494, 0.029760576451995542, 0.020610709840963994, 0.048831169560019455, 0.05197880869465215, 0.030694003150399243, 0.03235177615923541, 0.06160492037556001, 0.010847711353562772, 0.013225699242736613, 0.04223387535395367, 0.02206553302572242, 0.06343425078583614, 0.17312827786164625, 0.09021464376045124, 0.04551579656877688, 0.4046649858355522, 12.455618722098214, 62.49771921975272, 30.557475634983607, 39.83442204339163, 25.007555110113962, 57.81133644921439, 67.66487216949463, 61.014938899448936, 39.18231276103428, 0.2173781655728817, 0.7887509816459247, 0.1517362128943205, 3.8234807763780867, 53.912538937159944, 70.88322217123849, 69.96988841465541, 67.42144203186035, 65.41831111907959, 67.7561923435756, 68.92196805136544, 65.32411439078194, 54.39384412765503, 51.64870466504778, 54.94759471075875, 61.19711371830532, 65.24156284332275, 64.9508363178798, 58.94254834311349, 52.31188242776053, 47.96740313938686, 47.00993095125471, 45.745824337005615, 46.33436107635498, 46.85095616749355, 44.784030369349885, 44.552971499306814, 44.99328926631382, 43.716575145721436, 46.87213427679879, 44.57136338097708, 45.26290021623884, 44.64209256853376, 42.817575522831504, 45.3283383505685, 44.65510654449463, 42.700192655835835, 45.74934359959194, 43.32284852436611, 45.186344964163645, 44.64321122850691, 49.40922382899693, 57.20493589128767, 56.436089924403596, 58.317933082580566, 57.32117577961513, 58.57302924564907, 58.37685380663191, 58.238945960998535, 56.51641110011509, 58.904791831970215, 57.350160190037315, 57.68470900399344, 58.47382981436593, 57.45604031426566, 58.02145344870431, 58.65688010624477, 57.09874309812273, 52.66744259425572, 51.36447817938668, 48.88961321966988, 51.019347258976524, 49.90319211142403, 48.19054453713553, 44.98986380440848, 44.921226024627686, 45.286784648895264, 45.63670287813459, 41.27618019921439, 43.88136904580252, 41.96693536213466, 43.552771363939556, 41.56389815466744, 40.56709916251046, 41.831869329724995, 37.35025691986084, 40.74030385698591, 39.2992787361145, 42.80290787560599, 42.75505215781075, 40.50325216565813, 42.7063626561846, 42.55142477580479, 41.399111202784944, 39.650305203029085, 40.25178991045271, 40.86857802527291, 40.238119329724995, 40.203020504542756, 40.21277577536446, 41.9638295173645, 40.77578483309065, 41.035789898463655, 41.53091158185686, 41.77497053146362, 42.4401285307748, 46.906166553497314, 53.78479283196585, 57.88501514707293, 62.50287478310721, 57.85389069148472, 59.96245356968471, 59.12917695726667, 58.484863553728374, 55.45967347281319, 55.41396474838257, 55.7806316103254, 61.040313720703125, 57.391290051596506, 63.5244962147304, 8.094896282468524, 0.859337785414287, 4.775991516453879, 2.7276282651083807, 7.4668373210089545, 56.66293471200125, 54.65205308369228, 16.463834728513444, 27.932937792369298, 33.89107888085501, 32.10071570532662, 44.968946252550396, 0.1928175049168723, 0.09747208468616009, 0.04755398684314319, 0.023382678062521985, 0.009088878187217882, 0.015623541914724877, 0.079928154657994, 0.05304302301790033, 0.010913962664614831, 0.03958398236760071, 0.022328916571236083, 0.0612620362745864, 0.01854590742316629, 0.03206033179802554, 0.016110938707632676, 0.08367705385067634, 0.05954896605440548, 0.026895469121102775, 0.07347656906183277, 0.04075514738048826, 0.09283944791448967, 0.11449285064424787, 0.10634618957660028, 0.0683172805500882, 0.10881674236484937, 0.05325966907132949, 0.054868577380797694, 0.0823871519948755, 0.10306670090981893, 0.19770529121160507, 0.09410277833896023, 0.14052642083593778, 0.13386931376797812, 0.12189314354743276, 0.09580569767526217, 0.17836306696491583, 0.15453419275581837, 0.15911980026534625, 0.12843442468770913, 0.12555531917938165, 0.1487616239381688, 0.2545665257743427, 0.2684820576437882, 0.19651770565126622, 0.4181508150483881, 26.292951004845754, 72.34412261417934, 48.19521025248936, 52.85405036381313, 25.61833303315299, 62.21656036376953, 75.84582015446254, 67.55123438153947, 42.62529107502529, 0.529061027935573, 1.4716159765209471, 0.19970485248735972, 6.199311758790698, 58.8081910269601, 74.18217822483608, 70.86418410709926, 70.28430829729352, 69.14656857081822, 68.1521006992885, 71.77804592677525, 67.94605881827218, 56.853760038103374, 54.308141572134836, 60.68442004067557, 63.76724542890276, 68.08953217097691, 68.00757122039795, 63.251564025878906, 53.169654914310996, 52.28409310749599, 50.22759655543736, 47.95322534016201, 48.162095138004844, 50.008995805467876, 47.03003903797695, 47.584154401506694, 47.09152364730835, 46.6246394429888, 50.90183237620762, 48.68103872026716, 50.424400806427, 47.7400997706822, 44.57741526194981, 48.09738309042794, 47.40786123275757, 45.485086236681255, 49.510809966496055, 46.19947917120797, 47.88303116389683, 48.2188514981951, 52.82307529449463, 58.111158166612896, 58.57582936968122, 59.829736028398784, 60.323092869349885, 61.13497597830636, 61.48975794655936, 59.08677904946463, 58.912198611668174, 60.578008379255024, 59.75939246586391, 60.30980096544538, 60.33573859078543, 57.37247780391148, 58.560744830540244, 61.832755770002095, 58.564316204616, 53.357579367501394, 54.461446625845774, 49.677848134722026, 53.904145513262065, 52.34090157917568, 48.550252778189524, 47.01858493259975, 46.565423420497346, 48.38075842176165, 47.9377794946943, 42.77775887080601, 43.7023035458156, 45.51296935762678, 46.42620931352888, 43.962923526763916, 42.659347670418875, 44.6053991317749, 39.16670363289969, 44.20502308436802, 42.188364028930664, 45.116380078451975, 46.49133825302124, 42.10375581468855, 44.02942820957729, 43.71818017959595, 44.02044766289847, 41.63499559674944, 43.22538961683001, 43.95038897650582, 43.23825420652117, 43.3039424760001, 43.12833717891148, 44.23426110403878, 44.762105328696116, 44.26994705200195, 44.590241636548726, 45.236524854387554, 43.704620770045686, 48.96306957517351, 57.25103718893868, 59.67760522024972, 64.67157432011196, 60.20973995753697, 60.97138064248221, 61.288677079336985, 60.285996437072754, 57.63880573000227, 57.96599292755127, 58.38558769226074, 62.275321279253276, 60.710642542157856, 67.05920464651925, 9.389772994177681, 1.023281291127205, 4.402491969721658, 10.071713498660497, 7.438072647367205, 61.36399555206299, 60.30040005275181, 15.329482248851232, 42.22077737535749, 44.14752674102783, 39.50528587613787, 57.77321515764509, 1.9801317240510667, 0.40061814870153156, 0.25945743333016125, 0.1887366460370166, 0.10673466444547687, 0.11140146545533623, 0.10443403039659772, 0.12819389759429864, 0.07305827936423676, 0.15550349360065802, 0.15325678272971086, 0.13200877074684414, 0.13365459814667702, 0.11974590591021947, 0.11014920872237001, 0.1529939454048872, 0.1369165466832263, 0.12110901490918227, 0.17678279961858476, 0.16350469711635793], [0.053711570001074245, 0.015838612070573226, 0.038207149997885735, 0.010267470614053309, 0.04376948491803237, 0.021069735388404558, 0.0769875060234751, 0.059152878022619655, 0.02439663160060133, 0.01896944728546909, 0.056976958710168085, 0.042824014223047664, 0.00956203677092812, 0.01435475267602929, 0.08673821030450718, 0.056946913179542334, 0.06902307232043572, 0.045953499153256416, 0.03468237770721316, 0.03093520538615329, 0.032695128449371884, 0.050197348929941654, 0.020258327946066856, 0.037165079664971144, 0.09424262440630368, 0.9659506188971656, 49.75608137675694, 36.89476776123047, 26.867931808744157, 24.38070774078369, 19.32331027303423, 69.32378932407924, 51.97065986905779, 42.259947844914024, 1.1750221316303526, 0.7833995116608483, 0.30186625197529793, 0.08557875002069132, 17.266091108322144, 57.77007457188198, 73.77483313424247, 65.33078466142926, 68.17266041891915, 64.67936325073242, 64.8810625076294, 58.15170785358974, 51.054439135960166, 55.050167492457796, 63.03335584912981, 64.79907376425606, 63.237646784101216, 63.66534314836775, 62.5951121194022, 54.04532943453108, 47.376774992261616, 44.07018634251186, 44.41664784295218, 43.18495804922921, 44.27930974960327, 43.01425123214722, 42.07005705152239, 44.08547585351126, 43.94572673525129, 42.611172335488455, 42.99408755983625, 43.2421486718314, 42.431575298309326, 42.38936499186924, 41.82804434640067, 40.36212035587856, 41.6419437953404, 39.805423736572266, 41.812539441244944, 41.70006200245449, 43.41236216681344, 44.974459648132324, 55.87912927355085, 53.943298612322124, 54.38993229184832, 55.358063016619, 56.85859251022339, 55.89504759652274, 56.17481681278774, 55.76173251015799, 57.6105717250279, 55.6224558694022, 56.26465007237026, 53.9559200150626, 54.933889389038086, 57.925530093056814, 55.933995723724365, 54.18909461157662, 50.71863269805908, 49.71695954459054, 48.34364114488874, 48.78701959337507, 44.86752339771816, 46.03670024871826, 48.1054812158857, 47.72092274257115, 49.59879500525338, 49.83376571110317, 44.80021619796753, 39.138257707868306, 41.25023562567574, 41.4106000491551, 37.8504820551191, 37.70705039160592, 40.59395742416382, 38.391416685921804, 37.94037437438965, 39.63891363143921, 39.883740356990266, 39.43826355252947, 40.46564851488386, 40.42022814069475, 39.997308662959504, 41.229658535548616, 39.21410076958792, 39.526978152138845, 37.855349268232075, 38.480558599744526, 38.67032779966082, 38.0635416167123, 38.47147730418614, 39.83525235312325, 39.84958301271711, 41.00177846636091, 40.767492158072336, 42.565150942121235, 44.38343892778669, 48.41589893613543, 52.8018798146929, 56.7517535345895, 56.410200936453684, 57.01965870176043, 58.11971834727696, 55.18732493264334, 55.11932291303362, 54.52379976000105, 52.815894331250874, 55.817860058375764, 61.33022730691092, 44.98201928819929, 0.02474012129407908, 0.07966567695673023, 1.9951044406209673, 1.4393513649702072, 12.794952239309039, 73.70749814169747, 30.587714195251465, 11.250595246042524, 42.39184897286551, 25.43244092805045, 42.700182233537944, 15.744442565100533, 0.238773161811488, 0.08986730846975531, 0.06602575244115931, 0.04291660711169243, 0.05182945295902235, 0.06390602261360202, 0.04756926066641297, 0.009645014818358635, 0.05257085763982364, 0.042180905517722876, 0.028789908359093324, 0.06239107783351626, 0.037911776918917894, 0.02861812025574701, 0.0698992306632655, 0.02303911542652973, 0.03395057090425065, 0.0493074740017099, 0.03020844009837934, 0.0439914710420583, 0.052737278531172445, 0.026120146171056798, 0.04484496631526521, 0.021631090802007487, 0.033243696870548387, 0.05590741110167333, 0.06335185627852168, 0.08651413089994874, 0.010021837544627488, 0.03419412765651941, 0.009707267013644534, 0.02472996192851237, 0.05950395882661853, 0.030997057245778184, 0.02099705410988203, 0.06579335419727222, 0.013358443592941123, 0.04118690599820443, 0.00932162333213325, 0.0322324998809823, 0.07752270730478422, 0.06729186485920634, 0.02332492116173463, 0.04741028330421873, 0.07640285989535706, 1.4527694221053804, 60.56377846854073, 42.106969356536865, 30.174862657274517, 30.51258679798671, 26.679074559892925, 81.51952457427979, 57.86446932383946, 51.17979506083897, 1.6397496802466256, 0.7267215358359473, 0.5579823617424283, 0.10030380809413535, 17.42565996306283, 60.203625542776926, 74.35390295301164, 68.45103999546596, 70.23331546783447, 65.34054688044957, 66.62492833818708, 61.596989495413645, 53.72921071733747, 57.750254835401265, 64.23208686283657, 67.75616455078125, 66.49912425449916, 65.63968072618756, 63.40406308855329, 56.16529778071812, 48.64262213025774, 46.35649108886719, 47.25247171946934, 44.624850613730295, 46.58595534733364, 45.8560505594526, 45.37297010421753, 46.03080817631313, 43.90654584339687, 45.73221976416451, 46.36745882034302, 46.55753721509661, 46.26186357225691, 43.8644050189427, 43.59461341585432, 42.887860025678364, 44.00570011138916, 42.15399129050118, 44.25342423575265, 43.71411200932094, 45.03416551862444, 48.39837210518973, 57.87493678501674, 57.408292293548584, 57.329916613442556, 56.35928453717913, 59.02446065630232, 57.92357417515346, 58.23873404094151, 58.01410225459507, 59.1701991217477, 57.59838111060006, 57.896615164620535, 56.36652456011091, 57.16303130558559, 60.75267914363316, 56.24746370315552, 54.67776836667742, 53.92488588605608, 51.166979108537944, 48.91442176273891, 50.21473543984549, 47.45515762056623, 47.06032970973423, 49.74149015971592, 49.03575120653425, 49.9621718951634, 48.82953214645386, 44.958433628082275, 42.63098859786987, 44.2880471093314, 43.78694997514997, 41.268512862069265, 39.60722289766584, 41.255623953683035, 39.46430540084839, 41.22762271336147, 41.48666197913033, 42.604922430855886, 41.01576171602522, 41.623225348336355, 42.28231062207903, 43.00449596132551, 42.27193348748343, 41.766010829380576, 41.52223675591605, 39.860595907483784, 41.361306054251536, 41.62388890130179, 41.336031981876914, 41.1251472064427, 41.80925989151001, 44.524296283721924, 42.221850872039795, 43.82671798978533, 44.2604523386274, 47.28038610730852, 50.813475608825684, 55.72926010404314, 56.917912755693706, 61.03522763933454, 58.132749693734304, 62.087643487112864, 57.59626885822841, 58.156769616263254, 57.01724420275007, 56.294058322906494, 58.13019275665283, 65.49112824031285, 46.27967527934483, 0.14059656778616564, 0.2741635670619351, 4.409565670149667, 2.017716484410422, 17.35278378214155, 73.01947362082345, 41.716223512377056, 14.432673045567103, 43.60394484656197, 29.56054810115269, 49.41150631223406, 17.195964676993235, 0.33277392919574467, 0.10924894881567784, 0.08314856328070164, 0.04673174150022013, 0.01201869740283915, 0.03559785036902342, 0.024640318970861178, 0.05533575891916241, 0.057839790625231605, 0.09370211698114872, 0.04993057270933475, 0.0471724873142583, 0.007715072931854853, 0.015747439016454985, 0.0661830436438322, 0.06270032695361547, 0.04828138995383467, 0.04693340210776244, 0.021451694624764577, 0.04743698026452746, 0.14355157422167913, 0.17287841412637914, 0.17656549199351243, 0.0746146079951099, 0.12004898036164896, 0.13014187663793564, 0.23293995910457202, 0.13682729218687328, 0.10894818138331175, 0.08614617493003607, 0.09124527060027633, 0.1423440668731928, 0.16191946289369039, 0.13044852018356323, 0.1656228798840727, 0.12428863000656877, 0.12202286587229796, 0.16713882211063588, 0.05902926251292229, 0.12166780206773962, 0.18065897162471498, 0.13702507157410893, 0.09690282094691481, 0.14280540283237184, 0.1970427017658949, 4.738560702119555, 78.16242599487305, 51.82327468054635, 42.817440032958984, 37.30982535226004, 28.731798240116664, 82.03872176579067, 64.13453415461949, 54.918127400534495, 2.6152355074882507, 1.5222479339156831, 1.1380822509527206, 0.13817512057721615, 21.715175526482717, 65.68278040204729, 77.6188406263079, 72.66176646096366, 72.80397524152482, 68.83425399235317, 67.71481582096645, 63.440568923950195, 55.88320786612374, 62.3892092023577, 66.2370034626552, 71.58145359584263, 67.79654053279332, 69.9024908883231, 65.38420936039516, 60.02845450810024, 51.74013948440552, 48.704280444553916, 50.62109041213989, 49.576644148145405, 48.597295556749614, 48.805397578648154, 48.2475961957659, 49.097934109824045, 46.58795990262713, 48.96106154578072, 49.03858607155936, 50.275254249572754, 48.3731883593968, 47.056695801871165, 45.64925479888916, 44.628032888684956, 46.31584760120937, 44.56187214170183, 46.713868209293906, 46.5299528666905, 47.074823651994976, 51.30755158833095, 60.178737095424104, 59.235039710998535, 59.057763372148784, 59.85952295575823, 60.62071895599365, 59.67766775403704, 61.226796422685894, 60.95622662135533, 62.35635117122105, 58.46923010689871, 61.644925117492676, 57.25926038197109, 58.940714018685476, 61.552757263183594, 58.86265795571463, 56.291522230420796, 55.91135501861572, 53.82678427015032, 51.34730223246983, 52.04512371335711, 49.81902510779244, 50.13099922452654, 52.45290306636265, 52.39627524784633, 53.845158781324116, 52.960302216666086, 48.850727626255576, 44.024005140577046, 45.874039445604595, 45.32253313064575, 42.257668835776194, 41.27742392676217, 45.08647503171648, 41.327954701014924, 41.21343796593802, 44.748900277274, 46.88315411976406, 43.67422240121024, 45.587096214294434, 46.127016408102854, 44.50487954275948, 45.244140080043245, 44.50050217764718, 45.38017538615635, 41.67981147766113, 43.10872936248779, 43.058976786477224, 43.62952463967459, 43.59441539219448, 44.63141318729946, 48.04767567770821, 45.132826464516775, 46.721021379743306, 46.73497336251395, 50.39092091151646, 51.76612227303641, 56.76306867599487, 60.052863529750276, 62.427702222551616, 59.617482457842144, 65.11183302743095, 59.60485063280378, 60.00369807652065, 60.905873026166645, 57.933669907706125, 61.1429386138916, 67.23246492658342, 49.9776177406311, 0.3591146586196763, 0.21278752333351544, 7.759135007858276, 5.690952454294477, 15.81844435419355, 86.73434911455426, 38.187660762241904, 16.982611554009573, 61.60143634251186, 37.562520912715364, 59.154544830322266, 29.28382566996983, 0.27421016884701593, 0.13923454444323266, 0.13873397558927536, 0.1255849033061947, 0.21678428458315985, 0.15591163241437503, 0.07223356754652091, 0.14609472347157343, 0.11202456416296107, 0.1623705665447882, 0.07184682972729206, 0.11574643052050046, 0.10404619335063867, 0.06069710837411029, 0.182975028774568, 0.0845103898484792, 0.13292388378509454, 0.14696441537567548, 0.12215317173727921, 0.1184328727956329], [0.013516384492894369, 0.04077994105006967, 0.051971205709768195, 0.05607260723731347, 0.0246282105134534, 0.05846377142838069, 0.09762987800474678, 0.07996221033057996, 0.04034017911180854, 0.020299179146864584, 0.11315300861107451, 0.0677071622173701, 0.012581298776370074, 0.036557146215013096, 0.021741956638704454, 0.04180596063711813, 0.032492076845041344, 0.016716850123235157, 0.046974616324795146, 0.11260019256068127, 0.014428696029686501, 0.1159381845167705, 0.015090730773018939, 0.03891763723056231, 0.036883324783827574, 0.27677497693470543, 14.063759309904915, 60.40791647774832, 30.747074604034424, 51.34576668058123, 12.807961004120962, 32.81718267713274, 67.96398517063686, 51.87082815170288, 8.121927380561829, 1.8944827999387468, 0.32448100990482737, 0.14512519192482742, 1.1246925294399261, 27.139017513820104, 71.77134786333356, 71.17075252532959, 71.65708473750523, 66.73747525896344, 66.59006227765764, 56.47421816417149, 56.978917939322336, 68.41431876591274, 65.29138142721993, 65.98289394378662, 67.79998683929443, 63.68616689954485, 62.61731856209891, 53.9392443384443, 47.96308135986328, 45.65120724269322, 44.46236004148211, 44.376424721309114, 45.45261035646711, 44.45184394291469, 43.00848422731672, 43.622625078473774, 43.76388890402657, 44.357233796800884, 43.942478452410015, 44.830663204193115, 42.266510418483186, 42.99882623127529, 42.77672358921596, 42.33720486504691, 38.693496567862375, 40.121076924460276, 41.55833264759609, 40.31902068001883, 43.23035063062395, 41.5082882472447, 50.295150416237966, 55.301292760031565, 55.63587631498064, 55.4453775542123, 54.90530450003487, 56.351717948913574, 56.065184661320274, 54.67798376083374, 55.61273186547415, 56.54102161952427, 54.592597348349436, 52.46898119790213, 54.06850167683193, 58.274326188223704, 56.46550164903913, 55.95945392336164, 50.95344359534127, 50.17643002101353, 49.39833600180489, 47.927694184439524, 48.267099789210725, 48.7408766065325, 48.43073681422642, 50.651679856436594, 51.12022468021938, 51.71579647064209, 54.94470773424421, 48.91129854747227, 42.44161197117397, 40.964643818991526, 39.66899585723877, 39.51430116380964, 37.112701484135215, 37.58679097039359, 39.47708313805716, 40.190086432865684, 40.988163471221924, 41.72617333275931, 41.24654265812465, 39.9065443447658, 39.82583406993321, 40.69902113505772, 40.67512628010341, 39.69271353312901, 39.53149448122297, 38.7651081766401, 40.31299311774117, 39.0579400062561, 40.5168011529105, 38.78667885916573, 41.6967442376273, 42.114522048405235, 41.62190866470337, 42.01275525774275, 41.81040287017822, 44.6292279788426, 49.403053828648154, 53.32311977658953, 59.48741912841797, 54.70043339048113, 59.81542273930141, 57.48078284944807, 57.866439138139995, 55.5030198097229, 60.71253245217459, 55.47973639624459, 64.43533556801933, 7.299987622669764, 0.23149598230208668, 0.07376124164355652, 3.7824868389538358, 0.41019876460943905, 25.430908850261144, 67.18462657928467, 7.79632089819227, 25.369559730802262, 33.628148623875205, 27.827259165900095, 49.78581966672625, 2.822381717818124, 0.4428632775587695, 0.11468677595257759, 0.017138725878404718, 0.08497593951012407, 0.03454781064231481, 0.021982149553618262, 0.021250732908291475, 0.0506948372349143, 0.07802029739000968, 0.056938160077801774, 0.056444600490587096, 0.03425215597131422, 0.021524318227810518, 0.03923585319093295, 0.026381480540814142, 0.03285432294277208, 0.026249354505645375, 0.03214942683864917, 0.050681897572108676, 0.014170427790044673, 0.04582917796713965, 0.0257343091070652, 0.027367056048076068, 0.029859486501663923, 0.013952487431067442, 0.043449518337313614, 0.03030941289450441, 0.09602413166846548, 0.002576086823994826, 0.028810464577483277, 0.0591104831546545, 0.05495113134384155, 0.014191198595134276, 0.06067521883440869, 0.05929450185171195, 0.08017527711178575, 0.03968414092170341, 0.033952613294656785, 0.029028532161776508, 0.0710859816255314, 0.04850451262401683, 0.028072846122086048, 0.004681140999309719, 0.030391122081450055, 0.05895493578697954, 0.3207112321896212, 17.032869611467632, 70.88857923235211, 30.019886561802455, 54.02362673623221, 17.028773648398264, 44.5262313570295, 72.35435036250523, 58.05251884460449, 9.328436034066335, 1.5949572495051791, 0.9385622314044407, 0.2809638993016311, 0.969114112002509, 29.954847948891775, 75.61866964612688, 72.69149780273438, 72.795547076634, 69.07580116816929, 71.92076887403215, 57.573416233062744, 58.585820879255024, 68.93942192622593, 68.16856792994908, 67.48196084158761, 68.28946658543178, 67.68557085309709, 62.83858394622803, 55.64876174926758, 51.5608412197658, 47.573752948216026, 47.60141372680664, 46.31859213965279, 48.12395300183977, 46.37961121967861, 45.26378958565848, 47.24724667412894, 47.07919406890869, 46.94205747331892, 46.86704124723162, 46.46223224912371, 44.845018182482036, 45.15095084054129, 45.51026998247419, 45.26514448438372, 43.9094362940107, 43.188890729631694, 43.78177009310041, 43.56371477672032, 43.77125399453299, 44.81074966703142, 53.57026720046997, 57.05765839985439, 57.60589906147548, 57.636075087956016, 58.43762969970703, 58.16751153128487, 57.62948472159249, 56.69851643698556, 58.18638631275722, 57.75536176136562, 57.35675403050014, 55.47119358607701, 55.60808004651751, 61.35581752232143, 58.6755360194615, 57.840473720005576, 51.664383275168284, 49.98762314660208, 50.519896847861155, 49.129291330065044, 50.25709513255528, 50.29337167739868, 50.23866850989205, 51.42954111099243, 54.690883091517854, 52.86002581460135, 54.56724337169102, 48.70250865391323, 44.03205810274397, 42.660014697483604, 43.09161594935826, 41.25667660576956, 40.040384020124165, 39.77110310963222, 40.390816416059224, 41.60633427756173, 43.31604971204485, 42.87133720942906, 44.362861837659565, 42.364723205566406, 40.21747970581055, 41.90662152426583, 42.16577890941075, 40.97030312674386, 42.2425217628479, 40.48080601011004, 42.904125758579795, 40.70314489092146, 42.503725392477854, 42.00378165926252, 44.55937426430838, 44.317222595214844, 44.58900138310024, 43.05670819963728, 44.795536586216514, 48.01361213411604, 51.544818673815044, 55.392352376665386, 61.43314402444022, 58.15124579838344, 60.83691215515137, 58.24752351215908, 62.3356385912214, 58.870043890816824, 63.37233066558838, 57.4862128666469, 66.14787891932896, 7.716137817927769, 0.3047234000904219, 0.9067964787994112, 4.952124876635415, 0.8370467158300536, 28.70335578918457, 71.58388546534947, 15.46703052520752, 20.763093403407506, 40.117550713675364, 28.097264426095144, 57.93687997545515, 4.334836491516658, 0.41584816575050354, 0.08696723622935158, 0.029430835574333156, 0.04147709167695471, 0.040673258381762674, 0.07097911236009427, 0.025429914905024425, 0.01646637061743864, 0.06629492728305714, 0.012822957326924162, 0.024243549011381607, 0.005428757668206734, 0.033029954946999035, 0.026140405530376092, 0.04356950029198613, 0.03838861061792288, 0.015100442305473345, 0.060434386400239806, 0.035781244813863716, 0.05828666700316327, 0.0675940029323101, 0.12193785900516169, 0.08861267686422382, 0.16697762933160576, 0.08135102223604918, 0.11285769660025835, 0.116333933281047, 0.28705149835773874, 0.0898512407605137, 0.09739830078823225, 0.3019272658441748, 0.13063297314303263, 0.2574121930769512, 0.11599849270922796, 0.1428545151970216, 0.19006508189652646, 0.11849204104925905, 0.12619721330702305, 0.21086538290338858, 0.18791829209242547, 0.09658371949834482, 0.14632062134998186, 0.10316796547600202, 0.19105621799826622, 0.11438991688191891, 0.2703773687992777, 27.131254638944352, 84.60497638157436, 40.781044619424, 76.42245810372489, 22.206715413502284, 44.19226271765572, 82.05576569693429, 66.87848894936698, 9.608813217708043, 3.447209984064102, 1.432385578751564, 0.20385941384094103, 2.0233382284641266, 32.884663581848145, 80.03533376966203, 75.85932745252336, 75.38491140093122, 72.30023084368024, 73.75419003622872, 60.684718813214985, 61.9260561806815, 73.59622274126325, 71.0628331048148, 70.07939202444894, 71.03026689801897, 67.98469775063651, 68.3562318256923, 59.396870204380576, 53.809750761304585, 51.6829697063991, 51.08124876022339, 48.37742676053728, 52.346102305821006, 50.528411865234375, 48.645592485155376, 50.512701988220215, 51.57379961013794, 49.602540084293906, 49.257037435259136, 47.808928625924246, 46.9723550932748, 48.075812407902305, 48.49489995411464, 48.89303868157523, 45.25257171903338, 45.820461886269705, 46.97512742451259, 45.11814839499337, 47.48178311756679, 45.44468246187483, 54.35304430552891, 59.1891051701137, 59.1017176764352, 59.012204033987864, 61.87944071633475, 61.53167642865862, 58.931778635297505, 59.38596848079136, 60.12330436706543, 60.484436988830566, 58.49070004054478, 54.908392974308555, 56.6917975289481, 61.53690842219761, 60.056344577244346, 58.98259081159319, 54.639244079589844, 52.37436062949044, 51.51076207842146, 49.118754386901855, 51.47757748195103, 51.68187536512102, 52.2009266444615, 54.580538749694824, 55.54537255423409, 54.43596410751343, 56.93984474454607, 49.556713240487234, 46.09759078707014, 44.95538336890084, 44.56553384235927, 44.06594099317278, 41.31523602349417, 40.531295095171245, 43.283587728227886, 43.996132441929404, 46.76893963132586, 46.08157171521868, 47.73565987178257, 44.63867405482701, 43.44939953940255, 45.220884459359304, 44.56373773302351, 43.02959285463606, 44.45849684306553, 42.6936856678554, 45.3733800479344, 42.75704976490566, 45.85717616762434, 43.4709597996303, 49.371387413569856, 48.03128835133144, 46.046358244759695, 45.478878021240234, 48.090271609170095, 49.85755981717791, 55.365254402160645, 57.28343663896833, 63.25746304648263, 59.73969432285854, 62.10015024457659, 60.6970032283238, 64.01373972211564, 61.89265619005476, 66.58536529541016, 59.11867128099714, 68.71156964983258, 9.148975355284554, 0.30129267275333405, 0.3595742168171065, 13.173487492970057, 2.6338885979993, 29.99053737095424, 79.79935904911586, 12.123077069010053, 38.82301446369716, 49.75870084762573, 39.08538539069039, 69.50934791564941, 8.80240615776607, 0.8547931749905858, 0.19600010556834085, 0.3054533680634839, 0.1745014970323869, 0.1212547370897872, 0.13605604214327677, 0.087334418669343, 0.15704836856041635, 0.21450405408229145, 0.18848709442785808, 0.15254607158047812, 0.1180170936776059, 0.1281743829271623, 0.13748929809246743, 0.07562039366790227, 0.18146279134920665, 0.12293815532965319, 0.13082248797374113, 0.11038947118712322, 0.13469153536217554], [0.05682768100606544, 0.08119127473660878, 0.03209552401676774, 0.17809695910130227, 0.039182639082095454, 0.04493241590846862, 0.05584248208573886, 0.01604363990814558, 0.010847045541075724, 0.005760570622182318, 0.09940656088292599, 0.0647831309054579, 0.029524225741624832, 0.08005998044141702, 0.04019835850756083, 0.05560125610125916, 0.03411357197910547, 0.001853725652576291, 0.06064484760697399, 0.03992556707401361, 0.04970352132139461, 0.0296109934071345, 0.06952385152024881, 0.029711884779057333, 0.04098457024831857, 0.06671672500669956, 0.5896405801177025, 47.71121958323887, 45.270459856305806, 33.54621199199131, 31.49684429168701, 12.585043685776846, 54.326172147478374, 67.41930893489292, 20.989618573869976, 1.0277915405375617, 1.2176818996667862, 0.14560510617281708, 0.28260174712964464, 1.4918782263994217, 42.325875827244346, 75.22488049098423, 71.62257998330253, 68.00919015066964, 63.88041768755232, 64.4945342200143, 65.3324452808925, 64.29759447915214, 67.88662392752511, 66.9697813306536, 61.46407740456717, 63.52638612474714, 61.07464476994106, 53.40704359327044, 47.572363308497835, 44.41308341707502, 44.86065510341099, 41.78158869062151, 43.73682567051479, 44.48979500361851, 44.9186795098441, 45.95329059873308, 45.5969626562936, 43.04323216847011, 42.73512472425188, 45.37768793106079, 43.21229573658535, 43.283775329589844, 44.39587272916521, 41.12723514011928, 43.56190129688808, 40.34936693736485, 44.6259206363133, 41.532388074057444, 42.808914593287874, 43.103962898254395, 47.6759157861982, 53.71491132463728, 53.62878492900303, 56.71245799745832, 56.523744923727854, 56.77599927357265, 55.07349606922695, 55.56614071982247, 53.32711846487862, 52.43814509255545, 51.054928983960835, 48.28204883847918, 52.235636370522634, 56.15486853463309, 55.23218250274658, 54.60458299091884, 49.682743140629356, 50.1874429157802, 49.61463689804077, 48.47505937303816, 50.04655429295131, 50.169162205287385, 54.115096296582905, 54.71056038992745, 54.93128034046718, 55.80055209568569, 55.735214710235596, 51.58257865905762, 46.8268598147801, 40.456862517765586, 41.194500650678364, 37.94941398075649, 37.84415919440133, 40.02217973981585, 38.64001975740705, 39.83804552895682, 40.48080253601074, 41.3205201285226, 42.95036602020264, 45.83800956181118, 46.02901554107666, 42.372001443590435, 38.99785198484148, 40.75218875067574, 38.57629435403006, 39.068320614951, 39.40196616309029, 39.954254150390625, 39.878876617976594, 40.46174710137503, 39.98949541364397, 42.46489885875157, 45.22847884041922, 46.45527015413557, 45.69726685115269, 46.5019724709647, 52.18774938583374, 54.50881596973964, 57.22123983928135, 59.25524507250105, 55.30843898228237, 55.74436548777989, 56.79226500647408, 61.01769038609096, 57.09132937022618, 65.17293548583984, 28.41013138634818, 0.09155464864202909, 0.03056345640548638, 1.4594135284423828, 2.162361259971346, 0.3012367071849959, 53.145523820604595, 37.59078965868269, 11.677709698677063, 51.26593535287039, 20.732926062175206, 38.37348338535854, 32.71826464789254, 0.4168271560754095, 0.07832949901265757, 0.028156903040196215, 0.08104855168078627, 0.045937295737011094, 0.026380620497678007, 0.04190827353990503, 0.044184022316975255, 0.01970526931940445, 0.024899607557537298, 0.01790837966836989, 0.08237371021615607, 0.07656089748655047, 0.07062393320458275, 0.04832506725298507, 0.054799095394888094, 0.06071815653038876, 0.0340965407501374, 0.026501260631318604, 0.031880024687520096, 0.06849941970514399, 0.026268628292850087, 0.031566185278019736, 0.016884639958984086, 0.017411961752389158, 0.020932284549676945, 0.030277481036526815, 0.0288831492486809, 0.026831323813114847, 0.06503121009362595, 0.045153577612446885, 0.03335536677124245, 0.05794929939189127, 0.01698145842445748, 0.04540007242134639, 0.05777784037802901, 0.017350605223327875, 0.048906354632760794, 0.02239774546719023, 0.045375601055898836, 0.03902608748259289, 0.03626125744943108, 0.031382756906428506, 0.0728566458980952, 0.08754589767860514, 0.007117899350955018, 0.09124486347926514, 0.898689016699791, 58.32634735107422, 48.89268779754639, 39.81456756591797, 37.71199403490339, 18.330325841903687, 67.83814634595598, 70.93338816506522, 26.44665036882673, 1.433226419346673, 2.3278599679470062, 1.2412318417004176, 0.15627246376659187, 1.147364284311022, 47.89783430099487, 76.66005175454276, 75.56166662488664, 72.46892615727016, 65.69361959184918, 66.93570041656494, 67.28762667519706, 66.87675884791783, 69.7473167691912, 68.97821371895927, 63.83833244868687, 64.31729262215751, 63.59766074589321, 55.52114765984671, 49.13399873461042, 46.772684710366384, 46.285272053309846, 43.88702140535627, 45.87486628123692, 46.90176486968994, 48.51085649217878, 48.245904309409006, 48.02152960641043, 45.72316626140049, 46.25887584686279, 49.42568063735962, 46.23174313136509, 46.575387137276785, 45.471922874450684, 43.03157309123448, 46.71478884560721, 43.651230812072754, 46.789940561567036, 44.34136758531843, 46.031145163944785, 45.727522781917024, 49.89741121019636, 54.78823430197579, 56.61565569468907, 59.062891142708914, 58.14009393964495, 57.985927309308735, 55.86833872113909, 55.87756592886788, 55.66065011705671, 57.12757464817592, 54.80192572729928, 50.84191458565848, 53.38963835580008, 58.49153382437569, 57.35982860837664, 55.27345480237688, 52.63859714780535, 51.04744577407837, 50.52481617246355, 50.736361026763916, 50.99648073741368, 53.59083039419991, 55.47838844571795, 55.89220578329903, 56.96311773572649, 56.853391783578054, 56.31351327896118, 54.731213910239084, 48.3524340902056, 42.19538518360683, 41.2684850692749, 40.08604063306536, 40.38146761485508, 42.08056272779192, 41.53446558543614, 42.11151695251465, 42.30537864140102, 43.58568845476423, 44.860675948006765, 47.66379117965698, 47.9547643661499, 43.772681849343435, 41.209585189819336, 43.9620932170323, 41.06945044653756, 41.54342876161848, 41.06384325027466, 43.2206301007952, 42.253030913216726, 43.418139593941824, 42.45184319359915, 45.30022593906948, 48.16230705806187, 50.201714515686035, 48.79110166004726, 48.32511377334595, 54.615870339529856, 57.39852660042899, 58.55692332131522, 61.52617345537458, 57.42868178231375, 58.82189982278006, 59.478567123413086, 63.417688505990164, 57.60449205126081, 66.19978891100202, 28.236424684524536, 0.09885237419179507, 0.02015476653884564, 2.682762009756906, 3.784039327076503, 0.7624581839357103, 53.349046979631694, 51.0935366494315, 13.644703030586243, 49.963957582201274, 29.306386470794678, 42.0407669203622, 37.19785165786743, 0.4583239693726812, 0.1039494885397809, 0.050715685223362277, 0.0579255913783397, 0.02323526972239571, 0.05197435071957963, 0.04167528157787664, 0.017536488195349063, 0.08128018318010227, 0.025866058555298617, 0.03442335035651922, 0.015154701358239566, 0.021328995137342384, 0.034326635367636166, 0.02395610461410667, 0.05879400763660669, 0.03418478083663753, 0.020563768788373897, 0.04928041063249111, 0.0408231535527323, 0.0496712468032326, 0.15275354044778006, 0.16484738221125944, 0.08666533564350434, 0.2529158129223755, 0.10964946768113545, 0.12683462910354137, 0.113644960070295, 0.10660888440907001, 0.12138810993305274, 0.11967071065945284, 0.29193467061434475, 0.0884059001026409, 0.13192296320838587, 0.23088823205658368, 0.22976856785161154, 0.14587301893958024, 0.08053699734487704, 0.06479189757789884, 0.12201157504958765, 0.1435139426695449, 0.06198604671018464, 0.11419504162456308, 0.17219196738941328, 0.10891738267881529, 0.1411266936255353, 0.24019290134310722, 2.5142655883516585, 74.30555738721574, 59.55429553985596, 50.88100167683193, 47.187248979296, 20.871570416859218, 66.96400042942592, 81.45762307303292, 26.998894929885864, 3.3540832783494676, 4.127970814704895, 0.7011994996241161, 0.3306187391281128, 1.7999649345874786, 51.05699954714094, 79.47458635057721, 78.63623755318778, 73.8819465637207, 68.96939645494733, 70.9294068472726, 70.23143945421491, 67.71259239741734, 72.52821513584682, 71.99691418239048, 64.66035992758614, 67.49133396148682, 66.49196066175188, 57.508408887045725, 52.80064998354231, 50.03156355449131, 50.85084302084786, 47.35580880301339, 49.46586554391043, 49.90156275885445, 50.070230279650005, 51.511832101004465, 50.30668095179966, 47.86186000279018, 47.43246132986886, 51.52475227628435, 49.050064495631624, 48.16731670924595, 49.61394902638027, 44.94051422391619, 49.9372695514134, 46.59834051132202, 50.38157211031233, 46.73556743349348, 48.381619998386924, 48.645915576389854, 52.712571144104004, 57.23639733450753, 58.297206606183735, 61.370853424072266, 62.00482790810721, 60.496457372392925, 58.0552008492606, 59.11309882572719, 58.870808192661826, 58.20347888129098, 56.232736996241975, 52.43306943348476, 52.83507483346121, 61.6114695412772, 60.092009680611746, 59.13010106767927, 54.51631307601929, 52.71309573309762, 53.55621794291905, 51.85715757097517, 54.06265129361834, 56.4812045778547, 57.486549854278564, 58.349436214991975, 58.17254202706473, 59.49105303628104, 59.8756080354963, 55.489988463265554, 52.70274986539568, 44.04470035008022, 43.942617416381836, 42.20458459854126, 41.85357550212315, 43.95797640936715, 44.00106566292899, 45.3393234525408, 44.78591333116804, 47.58121531350272, 47.05923536845616, 51.05748592104231, 51.38142483575003, 45.45417022705078, 42.77195712498256, 46.1587210382734, 42.971665722983225, 43.92125865391323, 45.22755125590733, 46.3583219391959, 45.427565574645996, 47.21850892475673, 44.1274151802063, 48.702901227133616, 50.766081946236746, 53.67100913184029, 51.170991693224224, 50.960127762385774, 58.177426610674175, 59.86645030975342, 62.06714630126953, 63.20976366315569, 56.64019673211234, 59.163299560546875, 60.08210849761963, 65.11316013336182, 61.127617835998535, 67.5347740990775, 32.55949483598982, 0.11675170729202883, 0.15386370516249112, 1.8875797646386283, 11.387901203972952, 0.5362329802342823, 63.66588510785784, 47.10357877186367, 17.83020666667393, 71.69758578709194, 34.70469209126064, 51.033875942230225, 49.96246371950422, 0.8697487924780164, 0.40899127083165304, 0.2154913768172264, 0.16210949341101305, 0.12276404324386801, 0.12292576528021268, 0.12783514255923883, 0.0922873036137649, 0.14039474433021887, 0.0954930694507701, 0.11213813735438244, 0.20986192460571015, 0.21181839890778065, 0.17936273903719016, 0.08308320678770542, 0.10328216291964054, 0.11096818691917829, 0.17749063377933844, 0.18129887085940155, 0.0989782695791551, 0.07400090021214314], [0.051372055895626545, 0.045255459645496945, 0.027087832102552056, 0.0707323495298624, 0.08705521507986955, 0.021327512538326637, 0.08225553655730826, 0.02859134865658624, 0.019961999829060266, 0.035617422711636336, 0.032697055488824844, 0.07256917096674442, 0.050073838593172174, 0.01596925889940134, 0.02839481777378491, 0.0337036486182894, 0.007048423302226833, 0.05059717229700514, 0.02382822790449219, 0.09138899110257626, 0.0404142988845706, 0.03636524633371404, 0.04474631750157901, 0.03727458503895572, 0.06968713418713637, 0.015974712624613727, 0.07381217926740646, 19.129151548658097, 61.816649845668245, 27.645711421966553, 41.67024728230068, 14.109038983072553, 27.875816651753016, 71.29106753213065, 42.50717864717756, 1.864877394267491, 2.342649642910276, 0.22113286623997347, 0.2031787210809333, 0.280695552272456, 7.639267291341509, 71.93489456176758, 71.33217307499477, 70.47999736240932, 66.13681738717216, 67.45354270935059, 67.21233599526542, 71.18613583700997, 68.0771713256836, 60.375579561506, 64.38507229941231, 67.82762677328927, 59.31044156210763, 49.43777050290789, 45.80477980204991, 45.51029430116926, 43.01060690198626, 43.90457950319563, 46.69816180637905, 45.35390772138323, 50.09776599066598, 52.986688000815256, 52.03686577933175, 50.89596462249756, 46.163761956351145, 44.71762990951538, 42.399415561131065, 42.58481434413365, 44.814421789986746, 41.508892740522114, 44.96876907348633, 41.73593207768032, 41.948345456804546, 41.49980449676514, 42.351834297180176, 42.84404468536377, 43.90687935692923, 49.565606934683665, 55.3216336114066, 53.66840008326939, 55.748864446367534, 56.876039436885286, 55.72116892678397, 56.879398890904014, 58.92718587602888, 55.49217367172241, 54.27780226298741, 48.57939352308001, 53.198003564562114, 57.098677090236116, 55.59474992752075, 53.91683292388916, 53.14963020597185, 48.22724839619228, 48.95294952392578, 49.5916314125061, 53.58153370448521, 51.42871427536011, 53.63774115698678, 55.31928859438215, 57.82125152860369, 55.163120882851736, 57.64810241971697, 54.43134355545044, 51.88093778065273, 42.293761253356934, 39.22917488643101, 39.21783890042986, 40.00303397859846, 40.37363699504307, 39.60244948523385, 41.208657605307444, 41.2395840372358, 44.63857678004673, 50.233655384608674, 57.51471437726702, 55.84378031321934, 53.00624023165022, 44.6362178666251, 40.28665597098214, 40.534494740622385, 40.47595616749355, 39.886655126299175, 40.61077206475394, 39.94295290538243, 39.19069576263428, 43.362463678632466, 50.51688132967268, 55.84357534136091, 55.09298229217529, 51.86101382119315, 53.021752085004536, 52.96421752657209, 57.249043055943076, 58.660270827157156, 59.84207602909633, 56.41642999649048, 59.85410336085728, 55.6350599016462, 61.256486075265066, 59.32221875871931, 61.91613415309361, 4.254402407578059, 0.2404070741363934, 0.08223461053733315, 4.20286761862891, 2.23955357500485, 3.662654731954847, 66.34239373888288, 13.697203619139534, 27.527138675962174, 34.58938326154436, 23.25935012953622, 48.6401937348502, 13.097870247704641, 0.5767642110586166, 0.04042270254077656, 0.05914690012910536, 0.014063758692438049, 0.01583719053970916, 0.03629191026889852, 0.01878623434874628, 0.04697040940767952, 0.00818443511213575, 0.015711776912212372, 0.048746423928865364, 0.04140658849584205, 0.024595052203429595, 0.03441689070314169, 0.09464536208127226, 0.033607330572392256, 0.006884285257131393, 0.05204292686123933, 0.013608263223432004, 0.08843824586697988, 0.028293921312849437, 0.035183258687279055, 0.02638515650427767, 0.04410816549456545, 0.055402058575834544, 0.03597427445596882, 0.02718729176558554, 0.02076388742508633, 0.022692662231358032, 0.019954459608665535, 0.03500794220183577, 0.020587057806551456, 0.03508207215262311, 0.0225412674979972, 0.012506511494783419, 0.056087490902947526, 0.03962175980476396, 0.029446448665112257, 0.03909416490101388, 0.009802887864810015, 0.09761966605271612, 0.041257005450981, 0.04146394845364349, 0.08831210620701313, 0.04608779480414731, 0.009093363303691149, 0.03208221455237695, 0.05873120243528059, 21.84956932067871, 69.28267683301652, 29.646003995622905, 49.035334314618794, 17.09888792037964, 40.40877056121826, 73.82201835087368, 48.46738856179373, 2.2288572575364793, 1.359522751399449, 2.8860150575637817, 1.2234561783926827, 0.2164193820208311, 8.84028947353363, 76.75153868538993, 71.85702610015869, 73.69692298344204, 68.18373584747314, 69.63215732574463, 69.17628601619175, 74.23474829537528, 68.42547757284981, 63.12725380488804, 64.37212085723877, 69.5170395714896, 60.18783923557827, 51.76646968296596, 47.867786816188264, 47.40021474020821, 45.07782799857003, 47.46365874154227, 48.93374817711966, 47.80555874960763, 50.1211119379316, 54.9713853427342, 54.150803089141846, 53.43122679846627, 48.595735686165945, 46.53175592422485, 44.395223072596956, 45.54237413406372, 47.448761803763254, 45.23033400944301, 47.64577450071062, 44.4750474521092, 44.932329245976035, 44.26090397153582, 43.89750623703003, 45.53172949382237, 46.28466408593314, 51.77200392314366, 56.808836460113525, 56.14838239124843, 58.214721066611155, 58.65489986964634, 58.16217878886631, 58.08232314246041, 61.021456309727256, 58.66609341757638, 55.89694792883736, 51.76577833720616, 55.4204752104623, 59.349851744515554, 56.894080434526714, 56.23961223874773, 53.29419789995466, 50.55570091520037, 50.79304790496826, 53.152350425720215, 54.905144691467285, 52.53925180435181, 55.581951345716206, 56.118397440229145, 59.91276700156075, 57.346765995025635, 59.80523668016706, 56.51019246237618, 52.649432863507954, 43.882459912981304, 41.68417494637625, 41.34793772016253, 41.5307309286935, 42.592863832201274, 40.74887098584856, 42.79357297079903, 43.38138014929635, 47.33876139777047, 50.632815497262136, 58.772915022713796, 57.70097126279558, 55.45654330934797, 45.70567069734846, 42.218480995723176, 43.0592234475272, 42.04606144768851, 42.49507141113281, 42.612568923405235, 43.17217336382185, 41.94798067637852, 44.43233340127127, 54.059500285557334, 58.23441573551723, 58.69314970288958, 53.76319088254656, 55.18424340656826, 55.955628940037315, 59.60521193913051, 59.026489530290874, 61.335153579711914, 57.497243131910054, 61.304574557713096, 56.434707232883994, 62.69133077348982, 59.6623261315482, 62.07473373413086, 4.325307037149157, 0.3507238674376692, 0.8804021722504071, 4.6296559401920865, 0.8040781649095672, 4.449786186218262, 70.15673242296491, 19.80746422495161, 22.12233301571437, 35.70075804846627, 23.284917763301305, 55.756017616816926, 15.769921609333583, 0.7654043829866818, 0.0271227274622236, 0.07461690822882311, 0.02872441615909338, 0.045717592883322916, 0.02156798534893564, 0.020894686924293637, 0.03172442642971873, 0.024933361282039965, 0.023100326070562005, 0.032674192251371484, 0.05354379882503833, 0.01839928957633674, 0.028027871124712483, 0.043680338987282345, 0.016122428001835942, 0.01529484598099121, 0.03513962888557996, 0.04767357864017997, 0.050489716098776886, 0.00985493658975299, 0.12346174009144306, 0.12849961833230086, 0.12085995184523718, 0.15377246934388364, 0.1352710449802024, 0.10710064587848526, 0.14462622441351414, 0.15349543706646987, 0.09510523240481104, 0.14669448057455675, 0.07185512142521994, 0.12773013247975282, 0.11825768862451826, 0.12830586944307598, 0.23501538059541158, 0.10906689787017447, 0.11220356848623071, 0.19767544924148492, 0.13309791444667748, 0.1970537890280996, 0.08308598878128187, 0.12661544872181757, 0.14895534568599292, 0.07191466965845653, 0.18040762868310722, 0.10664921653057848, 0.26725466921925545, 30.87178087234497, 87.27837221963065, 40.84531545639038, 61.04462160382952, 22.137532200132096, 40.52391958236694, 83.18548025403703, 54.99929278237479, 2.665558487176895, 5.826214339051928, 2.1262010974543433, 0.7147487040076936, 0.6096875986882618, 10.568098885672432, 79.21898296901158, 75.20891353062221, 76.44210760934013, 69.88858754294259, 74.55490044185093, 69.84675938742501, 78.01372759682792, 69.08265209197998, 62.15812601361956, 67.41814858572823, 72.81741305759975, 64.65510014125279, 55.33771869114467, 50.94221878051758, 50.46333156313215, 47.80267524719238, 49.59831210545131, 50.59730672836304, 50.73149381365095, 54.89323200498308, 58.48585714612688, 58.100996426173616, 58.728314535958425, 52.452614716121126, 50.267760617392405, 47.215646266937256, 48.89543581008911, 51.17316995348249, 47.152740750994, 50.963841574532644, 46.471334389277864, 49.09076009477888, 47.592738900865825, 46.76302671432495, 47.592388016836985, 47.42691319329398, 54.08826582772391, 59.57162434714181, 57.551911558423726, 59.240236963544575, 60.623018809727256, 59.58951595851353, 60.77028587886265, 63.56612982068743, 59.49076121194022, 58.23052127020699, 54.21417760848999, 54.87511805125645, 59.52081217084612, 58.10077060971941, 58.10688502447945, 55.89897680282593, 52.27182953698294, 51.69620255061558, 54.037359850747244, 56.05825383322579, 55.653097425188335, 58.35443196977888, 57.369590827396934, 61.5412996837071, 59.895028250558035, 62.61196844918387, 57.103162152426584, 55.820972851344514, 45.46334532329014, 42.57139389855521, 43.59064599445888, 42.93047680173601, 42.936507838112966, 42.22809730257307, 44.894555364336284, 44.72233383996146, 50.22887849807739, 54.283305236271445, 63.42712415967669, 61.23457840510777, 59.39980929238455, 49.138991015298025, 45.620798451559885, 44.62889446531023, 45.560154574257986, 44.84612989425659, 44.470201083592, 45.13655764716012, 43.61957481929234, 47.18993098395211, 57.10401330675398, 61.47606304713658, 60.51327201298305, 55.68171010698591, 59.15691416604178, 56.94792897360665, 61.553333963666645, 62.24791758401053, 63.92547675541469, 58.56387151990618, 61.64163167136056, 57.95270102364676, 63.87062072753906, 60.867477280753, 64.23158659253801, 6.3638012409210205, 0.3641402960887977, 0.3709262976688998, 13.313858475003924, 7.618104815483093, 3.7893955196653093, 80.65229211534772, 19.977967807224818, 41.71531329836164, 51.76692826407296, 34.06442601340157, 63.16619150979178, 25.774606704711914, 0.8974373638629913, 0.2826879753598145, 0.18659423956913607, 0.18612180277705193, 0.15603171954197542, 0.1560919734516314, 0.08209019114396401, 0.19165430590510368, 0.08517472991453749, 0.12548777780362538, 0.12752195793603147, 0.22631690092384815, 0.16759198850819043, 0.10550355764904193, 0.13889557548931666, 0.1327417107032878, 0.0824895632852401, 0.1203643905797175, 0.0894286355801991, 0.23618661346180098, 0.22654567579073565], [0.010181421347494637, 0.02901710563206247, 0.0018293647611114594, 0.03360601082178099, 0.07682495617440768, 0.04729833181149193, 0.022057287128908292, 0.021939254266076853, 0.0386165237453367, 0.057685512118041515, 0.06960547928299222, 0.003969853943479913, 0.16676735132932663, 0.03999551724908607, 0.07260917739144393, 0.05816411679344518, 0.03348766413650342, 0.055821108232651434, 0.04628413908981851, 0.009520110092125833, 0.027893841798816408, 0.02495123559076871, 0.034441260288336446, 0.02959488837846688, 0.06458378410232918, 0.02280550599763436, 0.06367734952696733, 1.158260471054486, 48.29672343390328, 45.176989214760916, 34.081459522247314, 38.96766901016235, 13.432894144739423, 50.03975200653076, 66.82536997113908, 8.573013986860003, 1.7587243361132485, 4.080483785697392, 1.4409812603678023, 0.3124413016651358, 0.47188701587063925, 22.21302264077323, 73.34687273842948, 73.49113818577358, 70.98115703037807, 73.1019834790911, 71.4531203678676, 70.40234429495675, 68.01278236934117, 67.57763753618512, 67.66430936540876, 64.47913701193673, 56.38250889096941, 47.37059804371425, 47.571609428950715, 44.68565082550049, 45.44583933694022, 43.93087496076311, 46.021164076668875, 53.42860385349819, 58.66493306841169, 58.666572843279155, 56.57448066983904, 55.03303670883179, 54.73421205793108, 50.14008746828352, 46.267015661512104, 44.42512117113386, 45.40117631639753, 44.31351573126656, 44.3187894139971, 42.792555059705464, 42.55852236066546, 43.63975586209978, 43.666443892887656, 42.87947007587978, 44.222699301583425, 45.99963508333479, 52.200051171439036, 53.992512702941895, 55.362673146384104, 56.81333194460188, 58.11836344855172, 54.660717487335205, 57.590866633823936, 55.63353477205549, 51.60533748354231, 49.42570148195539, 51.742144039699006, 59.237165859767366, 56.373629093170166, 56.39145122255598, 55.217400210244314, 53.62138857160296, 55.077988079616, 55.826670374189106, 56.32986239024571, 56.213407107761924, 57.69498886380877, 55.529110295431956, 55.79819665636335, 52.58407463346209, 48.27701834269932, 53.87769719532558, 51.81870971407209, 44.314436367579866, 39.86437225341797, 40.39337682723999, 39.92418582098824, 39.10663298198155, 40.0171422958374, 40.46658999579293, 43.18395750863211, 49.06795958110264, 54.805973052978516, 54.101099150521414, 56.44682836532593, 56.870439188820974, 52.62091745649065, 42.78329658508301, 38.8424277305603, 40.57089287894112, 40.73529420580183, 41.8037291254316, 42.80071571895054, 41.55938877378191, 49.3738887650626, 53.97287361962454, 55.6949394771031, 58.24988242558071, 59.21878787449428, 56.41569696153913, 55.85753427233015, 57.871601649693076, 57.19136258534023, 60.73638561793736, 60.57930074419294, 53.424355030059814, 58.69277450016567, 56.99653162275042, 62.8950172151838, 20.914175033569336, 0.42538182703512056, 0.2078567993428026, 0.9788286707230976, 3.2607652800423756, 1.8712851532867976, 15.88056993484497, 45.64017002923148, 13.703022735459463, 43.248190130506245, 51.12418862751552, 39.503180571964805, 49.04364436013358, 4.792790523597172, 0.5660753846168518, 0.05491088064653533, 0.08788890391588211, 0.02307936273116086, 0.01586169752824519, 0.06153836287558079, 0.08252984790929727, 0.047321317185248644, 0.0580777053588203, 0.0273133228599493, 0.05459300056099892, 0.06979368454111473, 0.05336024831714375, 0.0512331665626594, 0.04206453336934958, 0.04083109919780067, 0.014969770031582032, 0.038857804012617896, 0.04271468187549284, 0.11657412110694818, 0.04991362290456891, 0.058337916753121784, 0.041176327637263706, 0.08683712713952575, 0.02423783065751195, 0.09378072526305914, 0.024019525585962192, 0.033213264574962, 0.03363831587401884, 0.059945515490003994, 0.037599409930408, 0.029300485604575703, 0.018672321889815584, 0.04652809617774827, 0.08087871436561857, 0.019107137307790772, 0.03676315962470003, 0.011308396767292703, 0.05970481876283884, 0.031774322502315044, 0.008829493757470377, 0.0341210358643106, 0.05259686249441334, 0.012838079327983516, 0.004978128567537559, 0.08107601877834116, 0.04660993428634746, 0.12645872070321015, 1.530679030077798, 60.41833182743618, 48.199313163757324, 39.26464891433716, 40.221078872680664, 21.8898115498679, 66.53269100189209, 69.91061333247593, 11.456670999526978, 2.648766645363399, 4.219704840864454, 2.3523449855191365, 1.3564338428633553, 0.16266874197338307, 27.026739835739136, 76.84605503082275, 74.981262751988, 73.93902601514543, 75.88445213862828, 73.40591158185686, 70.70060961587089, 69.63847323826381, 68.72072737557548, 68.63939871106828, 67.49291815076555, 60.06134728022984, 50.35829911913191, 49.00932025909424, 48.69483436856951, 46.74068825585501, 46.778156416756765, 47.843322208949495, 56.03302839824131, 60.43670981270926, 60.01842825753348, 58.00517381940569, 57.24709061213902, 57.01630967003958, 51.06802633830479, 47.556114946092876, 47.32740804127285, 48.719844409397666, 45.42872939790998, 47.054319517953054, 44.58467960357666, 46.1997640473502, 45.22464343479702, 45.850627490452354, 45.90082822527204, 46.51755033220564, 49.28968702043806, 56.25357811791556, 55.707147462027415, 57.45181928362165, 57.25921521868025, 59.31287343161446, 57.812191077641074, 60.734822273254395, 56.911437034606934, 54.045120988573345, 51.674819469451904, 53.964188371385845, 60.4800248827253, 57.882447787693565, 57.41446924209595, 58.17244127818516, 55.945126737867085, 55.65040152413504, 57.75458703722273, 59.02991499219622, 58.921530042375835, 58.22577565056937, 57.69060107639858, 57.087709358760286, 54.64697742462158, 51.94646971566336, 57.10355472564697, 53.97477395193917, 47.02334444863455, 42.939335754939485, 42.01105989728655, 42.17725733348301, 41.358568464006694, 43.15912117276873, 41.6344119480678, 45.18328080858503, 49.98986741474697, 56.26159981318882, 56.44501141139439, 60.022944586617605, 59.85696601867676, 54.13281767708914, 43.75024611609322, 41.493672711508616, 42.6429568699428, 42.24708672932216, 43.13233239310128, 43.84334850311279, 44.50739826474871, 50.71851110458374, 56.727750982557026, 58.9623715536935, 60.644704137529644, 62.04163251604353, 58.89057581765311, 58.99896771567208, 60.4083194732666, 58.861657415117534, 61.91305610111782, 63.40740517207554, 54.07086753845215, 60.402566364833284, 57.56344904218401, 62.25541469029018, 21.486569370542252, 0.6337621297155107, 0.840590622808252, 1.9939219440732683, 1.648204118013382, 0.8667449450918606, 16.445993491581508, 57.301095485687256, 14.974057572228567, 49.48616470609392, 60.68947832924979, 39.50492109571184, 56.90129613876343, 5.28595324925014, 0.576761931180954, 0.011547557460809392, 0.1577321690108095, 0.040276512171008756, 0.00520109008565279, 0.05708543610359941, 0.10203635226935148, 0.01591825851106218, 0.03855032926159246, 0.03451271341847522, 0.022876943860735213, 0.02578863431699574, 0.062450558213250976, 0.018851548433303833, 0.06753805772002254, 0.050672652532479594, 0.023876376749415482, 0.032099405237074406, 0.022682772583461235, 0.0476068447210959, 0.011368122267802911, 0.1432536837777921, 0.1643182606037174, 0.14826329424977303, 0.14193579235247203, 0.17199314305824892, 0.10826393309980631, 0.09087736891316515, 0.09154871146061591, 0.1537051722407341, 0.1871335120605571, 0.1395717492061002, 0.09344457901482071, 0.268473318112748, 0.13025156860905035, 0.09774044528603554, 0.10744469705969095, 0.12443758201386247, 0.12063513962285859, 0.1029773446332131, 0.08218299437846456, 0.10182591141866786, 0.2005598201815571, 0.1439552754163742, 0.07433087857706205, 0.18772226332553796, 0.17371400286044392, 0.2565237193235329, 3.4535478268350874, 74.8605239050729, 59.2372978755406, 52.716389179229736, 56.63549280166626, 21.64949073110308, 64.71967669895717, 84.27949496677944, 11.532444579260689, 5.523984636579241, 11.18985583101, 2.3785659670829773, 0.7968238113181931, 0.6376331448554993, 29.65299388340541, 79.35448673793248, 79.4109547478812, 75.48270729609898, 78.6030182157244, 77.31997081211635, 71.23334189823696, 68.88367652893066, 71.11369391850063, 71.34599304199219, 69.44304125649589, 60.865740231105256, 51.90141759599958, 52.06275476728167, 52.89403377260481, 48.141611848558696, 48.91689184733799, 50.33790268216814, 59.7097475869315, 65.436904498509, 64.97625282832554, 61.55265304020473, 59.13511071886335, 60.62606906890869, 55.27014398574829, 51.06643172672817, 49.83992181505476, 51.264590876443044, 48.98484870365688, 49.36848306655884, 48.64506442206246, 48.34704228809902, 48.90846715654646, 48.99890490940639, 48.66122940608433, 48.998144081660676, 52.487456457955496, 58.615559169224326, 59.70293140411377, 59.972479820251465, 60.31945201328823, 62.10305459158761, 59.31247043609619, 63.16015352521624, 60.55576719556536, 56.922515937260215, 55.12100437709263, 55.403834274836946, 62.61536611829485, 60.025174958365305, 59.74675369262695, 61.1501647404262, 58.500420570373535, 59.48691190992083, 62.34015492030552, 61.14228548322405, 61.14829567500523, 60.74707889556885, 58.28693716866629, 59.04382528577532, 56.126328808920725, 52.56820147378104, 59.2873318535941, 55.13843045915876, 50.67927810123989, 44.930741582598, 43.41769143513271, 44.58685091563633, 43.30971990312849, 45.038191999707905, 44.408608777182444, 46.55155829020909, 53.20363507952009, 57.97400420052664, 57.74903890064785, 61.23373072487967, 61.53895814078194, 57.67180619921003, 47.151768003191265, 43.20348194667271, 45.282000814165386, 45.080791405269075, 47.61739805766514, 47.19983564104353, 48.260884625571116, 53.61223431995937, 60.251901626586914, 60.88782160622733, 62.59965624128069, 66.47393008640834, 61.80422646658761, 60.58305971963065, 62.88463660648891, 60.40444932665144, 64.84158284323556, 63.29608808244978, 56.9082339150565, 59.613521984645296, 59.25593989236014, 65.70132514408657, 26.155557325908116, 0.3387117348611355, 0.42225049648966106, 2.2606800070830753, 10.996229512350899, 4.044681021145411, 20.45335486957005, 60.547179222106934, 22.19701746531895, 64.01619243621826, 62.15244933537075, 52.25867312295096, 63.27561174120222, 11.696625300816127, 1.0385788359812327, 0.2725005048726286, 0.38912550253527506, 0.1918428029332842, 0.15675290727189609, 0.18878702047680104, 0.20128898748329707, 0.12564282305538654, 0.15973151315535816, 0.18024497026843683, 0.17016804670648916, 0.13297366111406259, 0.1200131130005632, 0.1450341460960252, 0.11875483766198158, 0.1455478649586439, 0.1381759483899389, 0.13160102548343794, 0.11474654131702014, 0.21806124677615507, 0.11529785101967198], [0.048651710618287325, 0.016387404408305883, 0.01788472424128226, 0.025991433167031834, 0.05265108762042863, 0.04548104200512171, 0.07633012772670814, 0.010214459217552627, 0.04272262752056122, 0.0450206322462431, 0.020264343159007173, 0.02458949839430196, 0.015594015463388391, 0.059507833261575015, 0.05137816610346947, 0.026949134455727677, 0.05327092935996396, 0.050461879199636836, 0.08058348377900464, 0.03285225001829011, 0.05660487724734204, 0.05910635766174112, 0.029905240117971386, 0.007635768303381545, 0.019956797161804776, 0.032705795019865036, 0.055965459772518704, 0.04853013749899609, 21.581111771719797, 58.26355995450701, 27.56937677519662, 36.35921451023647, 19.918614557811193, 13.311795728547231, 73.12814344678605, 22.656762395586284, 0.7849159017205238, 4.7338719708578925, 2.708349185330527, 0.28036022026623997, 0.17964278401008674, 0.159211592482669, 44.14922557558332, 79.41731234959194, 69.27495043618339, 76.23555156162807, 72.80139051164899, 73.32217189243862, 68.30833094460624, 70.40018340519497, 66.15706443786621, 64.1614236831665, 50.80229248319353, 48.98617580958775, 47.21019887924194, 46.80162395749773, 48.05044453484671, 48.046160970415386, 56.34280341012137, 61.73712771279471, 58.5342652457101, 60.36713055201939, 59.798302377973286, 60.36808245522635, 59.215772356305806, 58.55729157584054, 57.4931297983442, 48.718242849622456, 44.64190149307251, 44.060917445591514, 43.31937789916992, 43.03508540562221, 42.082796573638916, 40.08268117904663, 43.60517120361328, 42.5440353666033, 43.47188738414219, 44.34087773731777, 47.582879407065256, 56.04548304421561, 54.79006167820522, 55.72225979396275, 57.85619054521833, 60.14242580958775, 58.24733591079712, 56.464730398995535, 52.87782709939139, 51.27918209348406, 47.85217421395438, 57.419826303209575, 56.77977909360613, 58.15584203175136, 56.03710699081421, 57.36573805127825, 56.814547879355295, 56.5602125440325, 57.121151038578574, 58.09119599206107, 57.586649077279226, 57.07805136271885, 54.99650655473982, 58.85808604104178, 60.257175309317454, 50.738959653036936, 53.42066901070731, 44.546412399836946, 40.12006943566458, 39.31898035321917, 38.66062116622925, 40.191434383392334, 40.86742809840611, 42.15637452261788, 45.21139669418335, 49.153672558920725, 55.178917612348286, 56.85444096156529, 57.27951785496303, 56.66438341140747, 54.64178712027413, 50.77605955941336, 41.19964231763567, 43.328796182359966, 39.63662767410278, 42.884549209049766, 41.01745360238211, 45.85100964137486, 51.054025718144004, 57.42546476636614, 58.52900545937674, 58.3056069782802, 56.21182639258248, 58.02797085898263, 56.96636601856777, 61.74872425624302, 59.64276695251465, 63.34248120444161, 56.54435675484793, 57.28220680781773, 52.64902639389038, 52.321662017277305, 51.74318626948765, 1.5859182945319583, 0.3987292971994196, 2.037577258689063, 3.914343672139304, 2.220649480819702, 0.3320516693804945, 31.6446533203125, 25.95361488206046, 17.336620535169327, 40.22641508919852, 51.4368645123073, 43.73657553536551, 37.70925644465855, 0.2381537136222635, 0.09800223766693048, 0.0502398455781596, 0.007941824916218008, 0.05170563728149448, 0.07005313597619534, 0.04184556333348155, 0.08460054679640702, 0.026670314238539765, 0.02682598543885563, 0.03910471272787877, 0.04169456893578172, 0.09100401747439589, 0.005118900411097067, 0.01786118246881025, 0.04471438903627651, 0.019808172547657574, 0.010515206293868167, 0.001858465007639357, 0.014813310034306986, 0.06162232479878834, 0.06017175263592175, 0.0025674257485661656, 0.043523919702108414, 0.03475180541032127, 0.025445037754252553, 0.048299951279269795, 0.005247667273839137, 0.02709514501371554, 0.030440400687179396, 0.07620156569672482, 0.0658971836258258, 0.042316439495022805, 0.019355406485764042, 0.03614777246756213, 0.029483337221401076, 0.05813240885202374, 0.010943919985688158, 0.051679211735193215, 0.014278760146615761, 0.052300922838704925, 0.050857689032065015, 0.02062696754001081, 0.0495527169135, 0.030470025526093583, 0.030028601177036762, 0.08515376996781145, 0.043717414140701294, 0.05721470381000212, 0.15830686103020394, 23.871038266590663, 69.62490340641567, 31.277041503361293, 44.79349728993007, 17.043842554092407, 27.23062082699367, 79.08283996582031, 27.571310111454554, 0.5127178877592087, 3.8922566516058783, 3.4925046392849515, 2.983424024922507, 0.4733297441686903, 0.3975225905222552, 48.55530759266445, 80.07267338888985, 72.61494949885777, 76.34256771632603, 74.30753762381417, 73.40660640171596, 69.50723566327775, 71.13885334559849, 70.47919831957135, 66.55400112697056, 52.160550662449424, 51.54433229991368, 50.835386753082275, 48.130755288260325, 51.259178229740684, 50.652544907161165, 58.58020673479353, 62.31769139426095, 61.51782866886684, 62.746714864458355, 62.97538702828543, 62.08617046901158, 62.47130216870989, 61.9017722266061, 58.02820709773472, 49.48928792136056, 47.97320141111101, 47.26735128675188, 46.14138180868966, 43.54053906032017, 44.686762537275044, 44.35421827861241, 45.56904826845442, 45.9110872404916, 46.43093408857073, 46.76780012675694, 50.10814659936087, 56.612000942230225, 56.26295818601336, 59.148242814200266, 60.36291299547468, 60.39017077854702, 60.89927918570382, 58.46252509525844, 56.19377844674246, 54.537682260785786, 51.29607663835798, 60.235420499529155, 59.849031175885884, 59.14881256648472, 58.07623304639544, 59.20137568882534, 58.82864652361189, 58.73928574153355, 59.41081523895264, 59.98388876233782, 58.753724098205566, 58.24960102353777, 57.53511428833008, 60.00861740112305, 61.0009035382952, 54.32024533408028, 53.89555059160505, 47.727610383714946, 42.44562108176095, 41.97916766575405, 40.65857219696045, 41.55196114948818, 42.08612476076399, 42.971123763493125, 46.87001507622855, 51.494638783591135, 56.900229590279714, 60.14202281406948, 59.215417998177664, 59.911099433898926, 57.86353131702968, 52.75773443494524, 42.908721991947715, 44.484114851270405, 42.15299422400338, 45.05545827320644, 43.653572354997905, 48.40099852425711, 54.95439004898071, 59.347836766924175, 62.462714195251465, 59.21010957445417, 59.70689187731062, 60.83072131020682, 61.55779470716204, 62.283200536455425, 62.36759335654122, 64.74097987583706, 60.70641108921596, 59.060716356549946, 56.20408957345145, 51.54982485089983, 57.53219951902117, 1.3648943603038788, 0.9127054874386106, 4.520176214831216, 5.171255426747458, 0.5190977997013501, 0.5393076123935836, 34.9662709236145, 33.54866123199463, 22.38792964390346, 50.49748543330601, 54.47277218954903, 49.900492736271445, 41.653564657483784, 0.4827342395271574, 0.04268624447286129, 0.0725680785253644, 0.04227781728176134, 0.030009225609579256, 0.04096859414130449, 0.015395167383498378, 0.02595394241091396, 0.0444772342619087, 0.07381521910429001, 0.03825467119791678, 0.04500599963856595, 0.004339195821168167, 0.03718245355412364, 0.06899777653494052, 0.02678766517367746, 0.06359526036041123, 0.03434031802628722, 0.03137507249734231, 0.02258834765026612, 0.034343133946614604, 0.03518908730308924, 0.15116044878959656, 0.12564662285149097, 0.10718092335654156, 0.09972824076456682, 0.14494786358305387, 0.10043354398970093, 0.13239035169993127, 0.11170900466718844, 0.1920574235596827, 0.13921080928828033, 0.245477983461959, 0.18924131324248655, 0.08648762053677014, 0.1952518578618765, 0.1301759798079729, 0.1438946822392089, 0.12431387150926249, 0.0990203455356615, 0.17089707830122539, 0.17042964909757885, 0.22864825225302152, 0.2001539883869035, 0.08133552449622325, 0.10345374406980616, 0.15845510736107826, 0.07974518090486526, 0.151967281209571, 0.2653833510620253, 37.115807328905376, 81.52054595947266, 43.605157307216096, 61.27120930807931, 29.648943083626882, 21.154990911483765, 87.43956347874233, 31.61627687726702, 3.4632329642772675, 13.005214282444545, 8.580326965876989, 3.077676990202495, 0.3052599313003676, 0.48393790636743816, 51.35148852212088, 80.89593764713833, 73.3282585144043, 79.17297199794224, 77.65643038068498, 74.59847259521484, 72.48713043757847, 74.19317027500698, 73.08341094425747, 68.0554859978812, 55.14827953066145, 55.021648611341206, 54.88928542818342, 51.649128505161826, 55.12848063877651, 53.89770105906895, 62.76708698272705, 66.68222318376813, 63.46698597499302, 66.05448818206787, 66.76597676958356, 64.80330521719796, 64.73722090039934, 63.776173864092144, 60.57285976409912, 53.38432993207659, 49.44005993434361, 50.08333805629185, 48.55241366795131, 47.31455734797886, 47.73788676943098, 46.26069974899292, 48.5089179447719, 47.077269417899, 47.779447419302805, 51.05517564501081, 52.17653846740723, 61.607578550066265, 58.76971190316336, 61.3610634122576, 62.86797482626778, 64.11881732940674, 63.11516393933977, 60.76650605882917, 57.3925963129316, 58.12112883159092, 53.41521120071411, 59.49988419669015, 61.1011313029698, 60.276546886989046, 59.49331814902169, 62.524240493774414, 61.6528252192906, 59.62033816746303, 58.092797551836284, 60.69672530038016, 59.253570556640625, 59.83069487980434, 58.565490450177876, 60.717173848833355, 61.65515981401716, 55.68101181302752, 57.41071374075753, 49.413945129939485, 44.68589401245117, 45.59947443008423, 42.90705789838518, 44.29920939036778, 44.76239020483834, 45.01874399185181, 50.12138639177595, 54.14841985702515, 59.348496845790315, 61.67161314828055, 61.69219371250698, 62.82824502672468, 61.38097694941929, 56.62067576817104, 45.53204911095755, 47.809449740818565, 45.25260646002633, 49.33234895978655, 45.71272659301758, 51.340694495609824, 57.80124766486031, 64.24776894705636, 63.85734966823033, 60.68478829520089, 61.465084893362864, 63.325993129185264, 64.36419991084507, 64.92835889543805, 64.0505234854562, 66.7834723336356, 62.34019660949707, 61.79611791883196, 58.31963539123535, 54.69745608738491, 58.74007783617292, 2.9665073326655795, 0.7443996529494012, 4.961077630519867, 12.773402401379176, 8.38225987979344, 0.8844420611858368, 38.87554979324341, 34.13561725616455, 29.272003310067312, 52.77747426714216, 59.12843350001744, 55.968920843941824, 56.51704338618687, 1.7551526363406862, 0.4357937297650746, 0.1544325617807252, 0.22761203428464277, 0.19220425853771822, 0.18565986970705645, 0.12474459196840014, 0.13190314998584135, 0.1091144292482308, 0.13241325904216084, 0.10664879583886691, 0.14273531016494545, 0.1839405976768051, 0.09344652641032423, 0.1271104264472212, 0.06609173997172288, 0.15998224541544914, 0.0840814539364406, 0.10235658008605242, 0.09062133729457855, 0.15030746241765364, 0.09597209481788532], [0.07776277299438204, 0.0510442522354424, 0.04724661387237055, 0.057538616071854315, 0.01538430234151227, 0.02613967949790614, 0.0727996082444276, 0.02046611742116511, 0.023150378206212605, 0.08259089570492506, 0.025414988830951706, 0.04925933533481189, 0.044613674083458524, 0.03405772176172052, 0.0532647343352437, 0.020350028561162095, 0.08872961558933769, 0.04471374782068389, 0.02236437681131065, 0.01246060011908412, 0.015036968747153878, 0.09022887942514249, 0.08272249757179193, 0.03263052852292146, 0.038543811932738335, 0.008096161098884684, 0.1081538407930306, 0.028548913076519966, 1.4813307523727417, 50.64946685518537, 39.17792844772339, 41.49298831394741, 74.2770002910069, 8.355524948665074, 40.352920940944124, 48.01073905399868, 0.4423765508191926, 3.041805395058223, 1.876098517860685, 3.426196243081774, 1.0468746594020297, 0.20128773897886276, 9.114913548742022, 90.78034768785749, 63.50449235098702, 81.21495028904506, 68.11565044948033, 68.6682823726109, 71.74978760310582, 70.92592579977853, 58.105592659541536, 53.146183899470735, 49.18592609677996, 52.29227808543614, 47.07822479520525, 48.09330449785505, 47.96814659663609, 56.38789027077811, 60.76776368277413, 61.979717118399485, 62.93419810703823, 62.64982223510742, 61.10428578513009, 60.999110903058735, 59.17390945979527, 58.99582018171038, 59.74327959333147, 59.926586968558176, 54.15884910311018, 45.33766630717686, 42.21849489212036, 43.536255495888845, 41.918350083487375, 43.076812812260215, 44.17325939450945, 42.542621408190044, 43.85924598148891, 43.45822375161307, 47.36319126401629, 49.68844066347395, 54.068428720746724, 52.904216357639854, 58.70820644923619, 57.94547837121146, 56.80565765925816, 56.07867806298392, 54.62911013194493, 52.90054770878383, 50.60146869931902, 52.51698282786778, 59.37121050698416, 58.41976588112967, 57.67205286026001, 57.58218138558524, 57.63998692376273, 58.93853923252651, 60.3362249646868, 56.89100238255092, 59.35025474003383, 56.81540598188128, 59.42783832550049, 57.35208484104702, 59.002024923052105, 55.23053230558123, 48.69300699234009, 44.06214727674212, 39.60789687292916, 39.953594071524485, 39.32551513399397, 42.26713228225708, 40.718507358006065, 42.22290699822562, 45.42362594604492, 49.298292364392964, 52.48573677880423, 57.49287966319493, 56.82021413530622, 58.664050647190635, 56.34038891111101, 55.62364401136126, 43.12711429595947, 41.43330328805106, 41.91139841079712, 42.20818376541138, 43.845151560647146, 52.10648672921317, 52.23702253614153, 56.32921273367745, 56.45941155297415, 58.19410228729248, 57.14422600609915, 58.977775709969656, 58.69280229296003, 62.95746067592076, 58.14429759979248, 59.18579087938581, 55.45803369794573, 53.97148745400565, 43.864238262176514, 54.658104964665, 24.3454612663814, 0.14376243576407433, 0.15608621947467327, 2.2200139377798354, 1.3098285836832864, 0.6254449188709259, 0.4790549512420382, 29.880154814038956, 18.2266708782741, 30.628274304526194, 24.376382487160818, 23.897229501179286, 45.04274306978498, 11.379683222089495, 0.49617134992565426, 0.0971355177462101, 0.026672337969232882, 0.054082898290029595, 0.06232698341565473, 0.045267975223915916, 0.045603215627904446, 0.021157464877303158, 0.047951072321406434, 0.05040460066603763, 0.04491568662758384, 0.03955661026494844, 0.02075182307245476, 0.00891382378592555, 0.0587025343307427, 0.0162788303236344, 0.10426956029342753, 0.024564847217074463, 0.059932236559689045, 0.03176404269678252, 0.03817150655335613, 0.004553956395414258, 0.05238256077947361, 0.04436218864949686, 0.027893773945314542, 0.03179947918813143, 0.04121431202760764, 0.02766558601121817, 0.01123716585737254, 0.04271847827892218, 0.06192554174257176, 0.018977927276864648, 0.04827552741127355, 0.03184244402551225, 0.027640157911394323, 0.027881217654794455, 0.033238339836576154, 0.04290413224537458, 0.02563126338645816, 0.01819866373469787, 0.05262623627537063, 0.03746811679697462, 0.06264964038772242, 0.024099558791411773, 0.06904333337609257, 0.04255031355257545, 0.08333683639232602, 0.018748109162385975, 0.10241854390395538, 0.16498431057802268, 1.7953362401042665, 58.8326347896031, 43.25502020972115, 43.9833025932312, 67.95457730974469, 14.110981004578726, 58.06570305143084, 52.74297298703875, 0.9532047999756676, 0.41481543545212063, 4.398816806929452, 5.855029387133462, 2.802481859922409, 0.27438509517482346, 11.461639830044337, 90.39252008710588, 64.02129241398403, 82.82040105547223, 70.56750992366246, 72.60567365373883, 75.01187651497978, 73.63003267560686, 61.472074781145366, 56.386240073612754, 51.45455462591988, 53.33227750233242, 48.98301785332816, 50.046064444950645, 49.42275544575283, 56.42172104971749, 63.978387287684846, 64.94479138510567, 66.28908715929303, 65.0279265812465, 62.93444129398891, 66.64525876726422, 62.2902946472168, 63.69144753047398, 61.99967234475272, 61.89638042449951, 53.33504635947091, 47.15780946186611, 45.989977087293354, 44.705029351370676, 44.09895535877773, 45.07128974369594, 44.686960560934885, 45.21529810769217, 44.839108739580425, 47.10138314110892, 51.107210704258506, 51.48646422794887, 56.94925260543823, 56.46515423910958, 59.6194349016462, 59.402213369097026, 57.30148458480835, 59.01881871904646, 56.192809173039024, 57.357563495635986, 52.267073495047434, 55.442705971854075, 60.70894718170166, 61.179256847926546, 59.29305716923305, 59.13709790366036, 58.91081592014858, 60.80263669150216, 62.795011792864116, 59.43325097220284, 62.24852902548653, 57.45663438524519, 61.13356549399239, 58.70815086364746, 61.708681787763325, 60.29646042415074, 50.9672566141401, 45.71981028148106, 41.45812225341797, 43.34151833398001, 41.32424783706665, 43.68049315043858, 43.31510475703648, 44.646997996738975, 46.51229749407087, 51.122861521584646, 55.33664519446236, 60.16304111480713, 59.27207360948835, 59.29660769871303, 58.554505348205566, 58.829459462847026, 45.74203062057495, 45.23382895333426, 44.10452086584908, 46.02142463411604, 46.753511156354634, 54.8080609866551, 54.23854146684919, 58.900692394801546, 57.161763259342735, 60.37881047385079, 60.55019474029541, 62.50632803780692, 61.4183999470302, 66.13012627192906, 59.84974684034075, 62.253128732953755, 58.43782424926758, 57.95398991448538, 46.27264717647007, 58.571875844682964, 25.22819341932024, 0.05891811169151749, 1.627135985663959, 5.46280140536172, 4.933154557432447, 0.5015841594764164, 0.5960553416184017, 35.68132741110665, 21.8345890045166, 33.95297343390328, 24.49988498006548, 24.306949138641357, 55.59085546221052, 13.017495223454066, 0.5001548390303339, 0.04160570798973952, 0.04676625857661877, 0.03218911774456501, 0.019047651839043413, 0.023684634627508264, 0.016261168057098985, 0.059544670927737436, 0.036849133404237885, 0.009987036331689783, 0.05886470420019967, 0.03693592142579811, 0.060893408555005274, 0.05115602391638926, 0.0062927066215447015, 0.024353866931051016, 0.02432218613103032, 0.023496919610936726, 0.035790133622608016, 0.003848942819916244, 0.05230366751285536, 0.024393467931076884, 0.1618483117116349, 0.21135995350778103, 0.10434517623590571, 0.2599078177341393, 0.07925595715641975, 0.11804977192410401, 0.21498266554304532, 0.14746383072010108, 0.13604916179818766, 0.13726186672491686, 0.10400208857442651, 0.10281085249568735, 0.18966161140373775, 0.1495360088135515, 0.115810416372759, 0.13305930580411637, 0.18131347293300287, 0.11321170867553779, 0.09181158271219049, 0.12405183485576085, 0.06465119655643191, 0.20770159124263696, 0.16956014718328202, 0.12840995671493666, 0.15876339296145098, 0.18296285585633346, 0.2409040331840515, 0.37342156948787825, 5.137854133333478, 76.38181114196777, 60.72827707018171, 56.11923817225865, 93.6166023526873, 14.320097463471548, 54.941330909729004, 63.688564028058735, 1.0706192595618111, 7.059556066989899, 9.443843007087708, 12.007699625832693, 3.154482594558171, 0.18951689345496042, 12.07682204246521, 93.00047084263393, 66.22734546661377, 85.09394890921456, 72.90225056239537, 73.75334235600063, 76.98918792179653, 77.3301568712507, 62.45697498321533, 58.41208117348807, 53.65265893936157, 56.416134698050364, 52.97165904726301, 52.20091274806431, 52.88164166041783, 61.32799693516323, 67.34777723039899, 67.20078114100865, 70.02833666120256, 65.80033002580915, 65.03383255004883, 69.13568769182477, 64.91296863555908, 68.12713582175118, 65.80802168164934, 64.37450408935547, 57.78886250087193, 49.81670093536377, 47.30960675648281, 47.338389669145855, 45.31326423372541, 48.04110615594046, 47.13597127369472, 47.39218609673636, 49.21902731486729, 50.75273445674351, 53.88005263464791, 55.30648306437901, 58.84833771841866, 58.098818165915354, 61.941814695085796, 61.882998194013325, 60.29952457972935, 62.64225564684187, 59.78444072178432, 60.66738305773054, 55.82019117900303, 55.639454637254985, 64.2269868850708, 63.2953793661935, 62.802522795540945, 61.71138463701521, 61.1772974559239, 62.71680981772286, 64.1785579408918, 60.96061093466622, 64.43361936296735, 60.27164145878383, 63.101566314697266, 60.9655441556658, 62.470002855573384, 59.18425532749721, 53.07185901914324, 47.693112577710835, 42.55107389177595, 44.71120629991804, 43.77458218165806, 46.959983825683594, 44.88510928835188, 46.39888552256993, 49.52449791772025, 54.029866218566895, 58.976393018450054, 61.85080024174282, 61.503425053187776, 60.91286986214774, 60.72988905225481, 61.148309571402415, 48.27889435631888, 47.31977891921997, 47.830718176705496, 47.62943581172398, 49.969453607286724, 58.52835232870919, 58.700382777622764, 62.564699854169575, 59.41048867361886, 61.4207067489624, 63.00370788574219, 65.85151045663017, 65.3158460344587, 68.73003796168736, 62.606041635785786, 64.34568990979875, 61.66333089556013, 59.82124532972063, 50.10341140202114, 60.1237143107823, 32.13433803830828, 0.19215213347758564, 1.1784781004701341, 10.73473232133048, 9.996112755366735, 2.1691839567252567, 0.6900020976151738, 37.76873302459717, 28.822473968778336, 44.7723365511213, 36.92198038101196, 36.78749104908535, 62.4599210194179, 25.55582877567836, 0.69577599636146, 0.1890538882996355, 0.1070354658045939, 0.1887878890016249, 0.13640992529690266, 0.12251720577478409, 0.06366786360740662, 0.15396089851856232, 0.13997574895620346, 0.14431398973933288, 0.14953074338180677, 0.13886604564530508, 0.166653696713703, 0.17390517331659794, 0.12697575081671986, 0.125203919463924, 0.20071361692888395, 0.06147240927176816, 0.11876622347959451, 0.06183790894491332, 0.11284525905336652, 0.10276978077100855], [0.012579513381102254, 0.06944699385868651, 0.07919643606458392, 0.07333953891481672, 0.03382287061374102, 0.02902904784839068, 0.04746296815574169, 0.06279858560966593, 0.042756499988692145, 0.03997674218512007, 0.04089763294905424, 0.02320273736092661, 0.016666082133139883, 0.0358562568601753, 0.03013655949117882, 0.021776745129110556, 0.023530145774462392, 0.045731587668082545, 0.07436476461589336, 0.09547170238303286, 0.03737175125362618, 0.053726609729762585, 0.08112113457173109, 0.05197190799351249, 0.006397831627899515, 0.0518443366246564, 0.07265213544347457, 0.20664481366319315, 0.23066971663917812, 16.93239344869341, 52.633552755628315, 37.819812706538606, 44.93290247235979, 40.665360586983816, 11.226096766335623, 59.11830302647182, 5.284203605992453, 0.7618583589792252, 1.742702224424907, 3.5372176000050137, 2.4660641976765225, 0.16605757655841963, 0.9467427581548691, 68.59307507106236, 84.52188982282365, 69.21740545545305, 69.28598417554582, 65.51789270128522, 60.55644811902727, 55.00087002345494, 53.187244279044016, 54.80784559249878, 52.300310203007285, 47.04346295765468, 48.51142971856253, 49.17306498118809, 53.91328934260777, 63.622611727033345, 63.65170383453369, 64.43637779780796, 63.36937073298863, 63.21141733442034, 62.3430940083095, 64.81085790906633, 61.22123786381313, 60.161005292619976, 57.02112477166312, 59.885022844587056, 59.902059827532085, 54.08903707776751, 47.37350239072527, 42.00473008837019, 42.123502595084055, 42.839573519570486, 42.53606925691877, 44.07198245184762, 42.954156262534006, 44.65202154432024, 45.170523915972026, 47.91578844615391, 51.4746036529541, 54.954581124441965, 57.56987612588065, 58.163356508527485, 58.76480647495815, 61.33824552808489, 58.3262848172869, 57.81386906760079, 54.365311350141255, 52.526533126831055, 55.97516032627651, 52.13606868471418, 58.88050092969622, 60.34960719517299, 58.13643223898751, 58.86266490391323, 58.121233054569785, 58.79292583465576, 58.22271844318935, 60.131308691842214, 59.412100655691965, 56.2651538167681, 52.91216509682791, 50.00187042781285, 45.58968789236886, 43.61998476300921, 39.9508113179888, 40.00804015568325, 40.54186677932739, 41.18583277293614, 42.334408215114046, 44.82998922892979, 48.85346174240112, 49.76173026221139, 50.98475912639073, 59.295426504952566, 58.067589487348286, 58.21764625821795, 55.604758807591026, 56.00165033340454, 50.10304314749581, 42.57174825668335, 42.604585443224224, 41.22837311880929, 50.941006319863455, 53.144495487213135, 56.03409147262573, 57.07384770257132, 57.52083921432495, 59.86310127803257, 57.846219880240305, 58.19317470278059, 60.98738234383719, 60.312503814697266, 60.85966750553676, 57.56131941931588, 55.80275814873831, 47.03670236042568, 47.47229882649013, 44.30978454862322, 1.196067248071943, 0.1312139891088009, 4.2305062498365125, 3.6596531101635525, 0.8705957127468926, 1.009834572672844, 2.804232805967331, 27.94952314240592, 26.13669122968401, 39.22825077601841, 31.322003296443395, 47.51819862638201, 38.54598978587559, 0.6881653847438949, 0.28500169834920336, 0.062394117670399804, 0.0772096041057791, 0.025586062776190893, 0.021589048772252033, 0.018841887790975825, 0.05905487720987626, 0.025439246457868388, 0.030292381665536335, 0.059642787091434, 0.028936407462294613, 0.044371990087841234, 0.03678543592936226, 0.03298499521666339, 0.0308750566494252, 0.06649488476770264, 0.005602310810770307, 0.06942196270184857, 0.08061760730509247, 0.05655708124062844, 0.0716375152447394, 0.021995043415310125, 0.08266076445579529, 0.02738392273230212, 0.07992864320320742, 0.0282154724866684, 0.05199534459305661, 0.03374674916267395, 0.07060122263750859, 0.037537235766649246, 0.014889243191906383, 0.04348053756569113, 0.046369943235601695, 0.03372768232864993, 0.029631152682538544, 0.022855821065604687, 0.022577675990760326, 0.06051141369555678, 0.03486779418640903, 0.039851718715259006, 0.03473665711602994, 0.09317768405058555, 0.02361947321332991, 0.029055568389594555, 0.05321390527699675, 0.030930231724466597, 0.013741498663356262, 0.03849817027470895, 0.1461949430938278, 0.14513207226991653, 0.38180218264460564, 21.394429309027537, 61.776982579912456, 44.58939743041992, 64.15669195992606, 30.403097084590367, 21.116315501076834, 69.73250320979527, 5.657072603702545, 1.408324618424688, 2.598746346575873, 3.183965321098055, 7.314403397696359, 0.19682809471019677, 0.8310862470950399, 73.5765107018607, 81.69901738848004, 71.72560787200928, 73.52333613804409, 68.34728254590715, 60.718271664210725, 58.51494230542864, 54.78829683576311, 56.78724145889282, 53.792095388684956, 50.435413701193674, 50.01103857585362, 51.93985850470406, 55.21939434323992, 67.50714111328125, 66.56998893192836, 68.95523602621896, 64.35554245540074, 65.51113210405622, 66.19042273930141, 66.96272196088518, 65.29921204703194, 64.11232076372418, 61.12861837659563, 65.4571168082101, 60.480969837733674, 57.359724385397776, 50.23422166279384, 47.27578639984131, 45.318840163094656, 46.41482469013759, 44.64231491088867, 46.56136219842093, 45.48749031339373, 45.958616392953054, 47.40159395762852, 49.16342435564314, 54.899356842041016, 58.78005082266671, 59.77524825504848, 59.04506206512451, 61.2308680670602, 62.856169836861746, 59.347822870527, 58.62705148969378, 56.36736181804112, 56.04809209278652, 58.673854555402485, 56.28926059177944, 59.607400621686665, 59.97136116027832, 59.90560340881348, 63.26689870016915, 59.90966810498919, 61.4104859488351, 59.79502282823835, 62.46493761880057, 61.297320638384136, 58.49243014199393, 54.75605719430106, 52.63095760345459, 48.95336988994053, 44.88025944573538, 42.1934084211077, 43.20476736341204, 42.25161000660488, 41.66538354328701, 44.38825402941023, 46.51040758405413, 50.22054760796683, 50.78449467250279, 54.321423053741455, 59.86059297834124, 60.96449497767857, 60.02373668125698, 59.80217947278704, 58.55671487535749, 53.93973766054426, 44.7007040977478, 43.9805337360927, 43.802103996276855, 52.339689118521555, 55.32871035167149, 59.27735424041748, 59.753007071358816, 61.24849564688546, 62.14976038251604, 58.87925720214844, 60.645058495657786, 63.962566239493235, 61.92318657466343, 63.16013962881905, 59.688993317740305, 60.806638853890554, 52.21608413968767, 51.28025211606707, 48.696237904684885, 1.0591957696846552, 1.4211270000253404, 3.408847893987383, 4.3960001809256415, 1.6817083316189902, 1.639754131436348, 4.010267027786799, 34.057311058044434, 31.65875816345215, 48.62339299065726, 33.54642391204834, 51.783756801060264, 46.1906931740897, 0.587403205888612, 0.15345544421247073, 0.05468072835355997, 0.12089786838207926, 0.029660665563174655, 0.027535588879670416, 0.021376733468579392, 0.008299507865948337, 0.01565980282612145, 0.04328055293964488, 0.06184799876064062, 0.02282764489895531, 0.0364642683416605, 0.006556461240896689, 0.00958852084087474, 0.03113724597330604, 0.05146375311804669, 0.04964399005153349, 0.09647353219666652, 0.08861261579607214, 0.03495933873844998, 0.05739357242626803, 0.045365911575832536, 0.1768046213047845, 0.1270034486161811, 0.24032309864248547, 0.15113283241433756, 0.14712547244770185, 0.17332562298646995, 0.15683711346771034, 0.13358111280415738, 0.15325704057301792, 0.08630782911287886, 0.10708227793553046, 0.16107395397765295, 0.15519185603729316, 0.09347879753581115, 0.1597448531538248, 0.2167995244796787, 0.11560669301876, 0.1667683555611542, 0.14712697879544326, 0.23041784444025584, 0.12805662996002606, 0.11993814845170293, 0.1409554992403303, 0.13354759317423615, 0.059890052037579675, 0.17078349153910363, 0.2602685812328543, 0.35577186942100525, 0.4017608830971377, 33.24733175550188, 79.07179233006069, 52.59295095716204, 64.51440606798444, 57.81459862845284, 19.279144048690796, 75.73484352656773, 7.243417126791818, 5.793424487113953, 8.743652190480914, 10.110380223819188, 7.696295499801636, 0.235363279070173, 1.826888118471418, 72.81413350786481, 87.23884391784668, 73.78743021828788, 76.82738522120884, 71.16598606109619, 64.73273236410958, 60.58328901018415, 56.78161689213344, 61.18330764770508, 58.04073469979422, 53.98007542746407, 53.354817458561485, 56.12344183240618, 58.85488292149135, 70.93837697165353, 70.47643988473075, 71.69178404126848, 67.79151003701347, 68.21375206538609, 69.60674776349748, 71.21301146915981, 68.17782293047223, 66.51951026916504, 63.01967484610421, 66.87428528921944, 65.09909003121513, 60.27303804670061, 55.272179807935444, 49.18295226778303, 48.80461938040597, 48.882866518838064, 46.21764523642403, 50.05046960285732, 48.429034505571636, 47.71782384599958, 51.691703592027935, 51.79601342337472, 57.24409941264561, 59.667273248944966, 62.030320848737446, 60.9097501209804, 63.46465832846505, 66.1212464741298, 61.599852153233115, 61.069614274161204, 58.73405374799456, 57.05669954844883, 59.196192332676475, 56.599018233163015, 60.44348430633545, 61.706236021859304, 60.25656386784145, 63.56528908865792, 61.77086121695382, 61.3679838180542, 60.9758483341762, 64.69479519980294, 63.75967189243862, 59.590037073407856, 56.223620959690635, 52.949126039232524, 49.7033862386431, 46.866137981414795, 46.064229011535645, 45.90056071962629, 45.45152991158621, 43.156512124197825, 45.96983078547886, 48.104414667402, 55.200293745313374, 53.571292059762136, 56.040191990988596, 64.06544821602958, 63.8307797568185, 61.910721506391255, 62.044571604047505, 61.54756695883614, 57.264127595084055, 47.94253206253052, 47.31658969606672, 47.16308661869594, 56.52040631430489, 57.95077289853777, 62.7303101675851, 61.38849490029471, 64.34927518027169, 64.47572544642857, 62.22276510511126, 61.001091139657156, 66.77464117322648, 64.2176901953561, 65.99057170322963, 61.158050945826936, 64.15959630693708, 56.9611097063337, 54.80774136951992, 51.331290108816965, 2.439452814204352, 0.857988640666008, 11.157082046781268, 12.231686966759817, 3.5625012261526923, 2.91341375878879, 3.9295098526137213, 37.28513840266636, 42.41947501046317, 55.8252911567688, 50.456723826272146, 60.87084715706961, 60.306507519313264, 2.719049411160605, 0.814586229622364, 0.2781841313200337, 0.25395405292510986, 0.2268290455852236, 0.14603978927646363, 0.1507165376096964, 0.16779367625713348, 0.09236783893512827, 0.13894984472010816, 0.17108705453574657, 0.1945401289101158, 0.13011811434158257, 0.10866350880158798, 0.07337718403765134, 0.16048769972154073, 0.15247044206729957, 0.10530556113060031, 0.18093574605882168, 0.20965676275747164, 0.12344821010317121, 0.14349704714758055, 0.10246990221951689], [0.060881927742489746, 0.1317872562046562, 0.0686234694772533, 0.07600660901516676, 0.01732610502014203, 0.047756424373281856, 0.038779657134520154, 0.04031702071162207, 0.10541542952081986, 0.0653145798881139, 0.0744317699489849, 0.057802064078194756, 0.06438527868262359, 0.040796897640185695, 0.007175152439491025, 0.05367603512214763, 0.051108540035784245, 0.06199672006602798, 0.08183103147894144, 0.04149039096332022, 0.06303570645728282, 0.01295643110227372, 0.07501047211033957, 0.06109497416764498, 0.016200033748256307, 0.08213378701891218, 0.04930706009534853, 0.12874124465244158, 0.1301819644868374, 3.400384988103594, 45.64009012494768, 29.461876732962473, 14.913194826671056, 56.46284048897879, 13.938224468912397, 41.04469401495797, 25.55745812824794, 0.7469842199768338, 0.32798705462898525, 2.585053184202739, 1.173556387424469, 0.5383527779153415, 0.023889855847560933, 37.33383485249111, 85.63018308367047, 69.73390674591064, 76.86083384922573, 60.20809323447091, 69.2382778440203, 60.73872021266392, 61.63400949750628, 54.75550481251308, 54.49415527071272, 51.629902839660645, 51.49504177910941, 50.06610304968697, 63.46420669555664, 63.89205592019217, 65.36283670152936, 64.96863760266984, 65.80923761640275, 63.74217632838658, 62.51743820735386, 63.250695501055034, 62.52854837690081, 63.495862688337056, 59.231378010341096, 60.546150888715474, 59.72791017804827, 57.2544834954398, 51.962731974465505, 44.59930903570992, 42.52301706586565, 42.00613015038626, 42.25626182556152, 43.06131138120379, 43.35731158937727, 44.2261004447937, 45.49389655249459, 48.18331493650164, 47.39535100119454, 51.236037254333496, 54.80171728134155, 58.19218805858067, 56.169400691986084, 59.008319990975515, 59.610110419137136, 57.82928364617484, 59.05543572562081, 40.51690884998867, 41.69438532420567, 62.48870740618025, 56.75259774071829, 61.8216039112636, 58.012670925685335, 59.68575545719692, 57.186547483716694, 61.146072251456125, 58.50217151641846, 57.15441901343209, 55.05902991976057, 52.25922897883824, 49.12561920710972, 47.37032011577061, 44.484021050589426, 41.47289759772164, 41.53642497743879, 40.285109996795654, 39.60555533000401, 43.291262013571604, 41.63121577671596, 45.728082111903596, 46.101179531642366, 49.41320514678955, 53.32254655020577, 54.72485283442906, 56.754213196890696, 57.52438626970564, 58.894209725516184, 58.05557952608381, 54.197373390197754, 44.70276076453072, 42.746061188834055, 42.39950588771275, 52.600819792066304, 55.60546404974801, 56.76493426731655, 56.44375031335013, 58.029357024601524, 57.55032736914498, 62.29688153948103, 59.94026102338518, 60.96112510136196, 59.28544889177595, 62.40894903455462, 53.512242794036865, 53.08487299510411, 39.062873227255686, 58.55344922201974, 9.56216127531869, 0.5077196902462414, 1.040494584611484, 1.642386413046292, 5.330480779920306, 3.505811090980257, 0.5236277537686485, 6.196495567049299, 22.895895072392054, 30.397132056100027, 24.380473239081248, 29.007926600319998, 44.495457785470144, 11.899332046508789, 0.5778562724590302, 0.051564162730106285, 0.06479438101606709, 0.05170845320182187, 0.03029384051582643, 0.03028016464252557, 0.05343717722488301, 0.03517532322023596, 0.02540468018768089, 0.03730686634246792, 0.07985993474721909, 0.035700970728482516, 0.08376375705535923, 0.10157906716423375, 0.036322736114795716, 0.026427966974941746, 0.07499442475714854, 0.05520614515990019, 0.031255165181521855, 0.025323544362826005, 0.028179123365719403, 0.03759390701140676, 0.1250660140067339, 0.057790345778422694, 0.10174513861004796, 0.054250910345997126, 0.0829245720856956, 0.043001997351114235, 0.06842862136129822, 0.04103291926107236, 0.050388651700424295, 0.0649276656497802, 0.028298599811803018, 0.05978249066642352, 0.06834875100425311, 0.028009657548474412, 0.020847557578235865, 0.05829326914889472, 0.0059068776151564506, 0.025199126485469084, 0.03461348943944488, 0.02916506358555385, 0.02957503105114613, 0.03620177706969636, 0.014793615555390716, 0.036446633216525824, 0.09717746478106294, 0.05064503276454551, 0.024808061309158802, 0.032599851954728365, 0.06386393987174545, 0.27137066264237675, 5.80092419896807, 58.722158432006836, 34.91525724955967, 22.77965518406459, 64.5620915549142, 13.593489595821925, 55.91832406180245, 26.810857568468364, 0.7666732434715543, 2.2683733999729156, 2.4331998697349, 10.60863207067762, 1.2204919031688144, 0.005192252591119281, 41.84383760179792, 86.4571646281651, 72.3592835835048, 75.86396884918213, 63.30092402866909, 70.32945074353898, 61.61815370832171, 62.130298478262766, 56.257854734148296, 58.22495228903634, 54.74521105630057, 54.590016092572895, 51.481277397700715, 63.58755111694336, 65.6770133972168, 67.2182697568621, 66.64518928527832, 68.71398067474365, 64.53289522443498, 66.0498606818063, 66.73200702667236, 64.71455587659563, 64.96779687064034, 64.52006190163749, 60.99557426997593, 61.26410130092076, 58.37160096849714, 55.52503170285906, 47.09913887296404, 44.939412934439524, 43.98544263839722, 44.15951933179583, 44.719724791390554, 47.11288588387625, 47.29266357421875, 47.93183878489903, 50.93346405029297, 49.55864483969552, 54.67334236417498, 57.53326606750488, 60.554641587393625, 58.724103927612305, 59.24648339407784, 61.05732291085379, 60.472868238176616, 59.86712428501674, 44.555681296757285, 45.87303195680891, 61.80565084729876, 58.73482499803816, 62.53782422201974, 60.106996944972444, 61.97735473087856, 57.786680766514365, 61.181744303022114, 60.172942297799246, 60.75272083282471, 58.54522950308663, 54.597801549094065, 52.569434779030935, 49.49472141265869, 46.06353766577584, 43.45260265895298, 42.90566825866699, 42.87963683264596, 41.957871437072754, 44.51886279242379, 44.88351467677525, 47.35844911847796, 49.6048503603254, 50.739925452641074, 55.429507868630544, 58.36559077671596, 60.117870875767295, 59.18504742213658, 60.98142078944615, 60.256181716918945, 57.805538177490234, 45.98292119162423, 44.073309557778494, 46.141979353768484, 55.4067942074367, 56.88373804092407, 59.58067784990583, 58.77510370526995, 60.750754492623464, 59.75128391810826, 64.71384021214077, 60.95437840053013, 62.55427060808454, 60.38389655521938, 64.76301956176758, 56.99301583426339, 58.479256357465474, 46.102395466395784, 65.14694922310966, 9.95763189452035, 0.8781131207942963, 1.6728422130857195, 3.519452358995165, 1.9764337624822343, 2.8522316132272993, 0.14768238684960774, 7.15863607610975, 29.436981337411062, 40.15723534992763, 34.45326457704817, 30.632116658346995, 53.6685459954398, 13.195399505751473, 0.44453562210713116, 0.034126949296998124, 0.06106235020394836, 0.005424678824575884, 0.040927145829690356, 0.0459598332776555, 0.029143347072282007, 0.09006263156022344, 0.03557740950158664, 0.003095495414787105, 0.04699619034571307, 0.05405221493648631, 0.05161312920972705, 0.01662155327254108, 0.027263192692771554, 0.020637890257473503, 0.008849313765365099, 0.01902814395725727, 0.01152953302620777, 0.05716806131282023, 0.02164653256269438, 0.04951631350974951, 0.04633942273046289, 0.10766231002552168, 0.21772925316223077, 0.14013567966009888, 0.11674667256219046, 0.11015026045164891, 0.15285686776041985, 0.13161868096462317, 0.17164126836827823, 0.2292887078864234, 0.11647858337632247, 0.13023434739027703, 0.22070063943309443, 0.12257511195327554, 0.15484991509999546, 0.14088403593216622, 0.1231124574052436, 0.15214372745582036, 0.17757992898779257, 0.13959732997630322, 0.09719579201191664, 0.08581462914922408, 0.19891465774604253, 0.31255833538515226, 0.29780250574861256, 0.08060088141688279, 0.2836055446948324, 0.20521865519029753, 0.34295472289834705, 1.0825962168829781, 15.262921980449132, 75.62791769845145, 53.34536790847778, 31.24323504311698, 80.26307487487793, 23.16284486225673, 53.52198416846139, 33.74011884416853, 1.6028256501470293, 11.43712397984096, 5.4955326318740845, 7.740686672074454, 1.3527304530143738, 0.09187722418989454, 42.57627848216465, 88.94265338352749, 74.26710605621338, 81.35116972242082, 66.44007846287319, 75.51601696014404, 65.79279123033795, 66.8864654813494, 59.38975524902344, 62.42598601749965, 56.62400048119681, 57.64582688467843, 54.32345192773001, 68.14427007947648, 67.85243879045758, 69.65216813768659, 68.89522443498883, 73.76443862915039, 67.76824746813092, 67.38419273921421, 67.50569588797433, 67.47110080718994, 69.28073133741105, 68.19605500357491, 64.87132113320487, 64.86028044564384, 61.380351611546104, 57.439548764910015, 49.918620586395264, 47.99959066935948, 46.97777121407645, 46.331251757485525, 49.517876284463064, 49.53840821129935, 50.31005082811628, 50.61922482081822, 54.41528974260603, 51.416158880506245, 56.28458445412772, 59.381556374686106, 64.34243120465959, 61.82157611846924, 62.93769999912807, 63.92458043779646, 61.95216751098633, 63.23895999363491, 44.79066589900425, 45.62638480322701, 63.47025162833077, 59.59602642059326, 64.89175578526088, 62.24702821459089, 65.06405026572091, 59.40143517085484, 63.942617961338584, 62.62057031903948, 61.74253341129848, 59.46474020821707, 56.11717108317784, 54.53883218765259, 52.554180009024485, 48.8510958807809, 46.00266797201974, 46.209338665008545, 44.31029176712036, 43.55651991707938, 47.63995885848999, 47.80096251623971, 49.90550586155483, 52.95628268378121, 54.26529550552368, 58.7859776360648, 60.717312812805176, 61.04717854091099, 60.26875795636858, 63.178913661411826, 63.115191732134136, 61.738830021449495, 49.15344326836722, 47.74905252456665, 49.11365788323538, 58.29355880192348, 62.30211353302002, 61.14448806217739, 62.0899989264352, 62.986983571733745, 63.06788144792829, 65.95643520355225, 62.58951881953648, 65.72096770150321, 64.43553011757987, 67.52012034824916, 60.058581897190635, 62.80676119668143, 48.72874852589199, 67.59890597207206, 14.020992279052734, 0.47404931698526653, 3.036006037678037, 8.282267485346113, 12.095404999596731, 8.916506000927516, 0.930591344833374, 8.383368117468697, 37.5874788420541, 45.70513221195766, 40.88099793025425, 42.517823287418906, 63.17055497850691, 22.95584065573556, 0.6051930370075362, 0.2316093790744032, 0.15529145140733036, 0.1308557361896549, 0.11248321312346629, 0.17566534743777343, 0.1283591344420399, 0.21573957135634764, 0.1700928243143218, 0.1331488995679787, 0.19905531805540833, 0.18911556713283062, 0.259973011378731, 0.12413224125547068, 0.15405969321727753, 0.150791732860463, 0.2147924450359174, 0.2021167730646474, 0.08273406659385987, 0.19150668382644653, 0.12210476504904882, 0.0989482986873814, 0.29333636111446787], [0.08767332655510732, 0.049037104938179255, 0.029799405618437698, 0.03122026812551277, 0.0273490171946053, 0.0675218135916761, 0.022582637778084193, 0.0536200220563582, 0.030572674303714718, 0.03297847788780928, 0.016125871567055583, 0.02058869137960885, 0.05515614730705108, 0.02455519844910928, 0.010989786408442472, 0.047796420619956086, 0.042470368556678295, 0.06374515553138085, 0.017139455303549767, 0.02686039394965129, 0.054073615930974483, 0.10970232555908815, 0.06838571080671889, 0.018426604003512433, 0.05617705074005893, 0.06811811695141451, 0.0798973763095481, 0.11392959872526781, 0.029016997066459486, 0.38945090078881806, 24.309087446757726, 39.493484360831125, 26.206016881125315, 31.94334942953927, 38.76189463479178, 16.509204728262766, 48.761974811553955, 0.04996585653030446, 1.6114021156515395, 0.7581935099193028, 18.361467667988368, 2.251403944832938, 0.21479997677462442, 5.779106421130044, 83.3763542175293, 72.25795105525425, 79.03106893811906, 76.4973805291312, 70.07748126983643, 72.7005513054984, 68.72914859226772, 65.35972390856061, 55.13887514386858, 52.34552213123867, 51.697508811950684, 59.62297848292759, 66.56759875161308, 67.30202334267753, 66.97737571171352, 67.85218865530831, 63.720206124441965, 65.05920042310441, 67.44259234837124, 66.00543390001569, 64.73735291617257, 62.541555404663086, 61.63392611912319, 58.579630034310476, 60.69448103223528, 58.19387994493757, 54.877119132450645, 48.65840148925781, 45.41340167181832, 41.410534041268484, 41.86354616710118, 43.58980873652867, 44.09318487984793, 44.10659490312849, 46.88964026314871, 51.00136879512242, 49.89978749411446, 46.36548900604248, 49.788296699523926, 53.18544469560896, 56.68450539452689, 56.727243764059885, 62.30841554914202, 59.07844121115548, 62.053034509931294, 38.1681432723999, 45.82531172888619, 63.32839720589774, 56.548518725803916, 61.49554579598563, 57.0169106892177, 56.13068880353655, 54.045037610190256, 56.22182485035488, 52.731675216129844, 53.71445274353027, 51.20803253991263, 48.814739431653706, 44.873050689697266, 42.967677456992014, 42.93150860922677, 42.50558403560093, 41.76727887562343, 42.116332054138184, 42.23756422315325, 42.53976569856916, 43.92659487043108, 49.9278130531311, 47.201951367514475, 49.15163673673357, 50.200231075286865, 54.67084796088082, 57.0187554359436, 59.406688008989605, 57.47131592886788, 58.58555684770857, 56.464122431618826, 48.7711638041905, 40.723937375204905, 47.69096211024693, 53.31160661152431, 57.995745113917756, 54.700085980551584, 59.16571058545794, 57.78933845247541, 60.26176112038748, 59.30955219268799, 63.244692257472444, 58.89514078412737, 61.0795293535505, 54.427275385175435, 57.09374039513724, 39.03389229093279, 53.16547209875924, 28.993726219449723, 0.10513841081410646, 0.05745378562382289, 1.8161583627973283, 1.3808887877634592, 2.5107841065951755, 0.7648826166987419, 0.18587101623415947, 7.646477784429278, 36.757836137499126, 29.26331111363002, 17.60863903590611, 37.988313470567974, 25.496114219938004, 0.5033424336995397, 0.2520957626402378, 0.02641100190313799, 0.005617370471424822, 0.03418306414304035, 0.04857488688347595, 0.05781099359904017, 0.01585198599579079, 0.07260814601821558, 0.011214646128272372, 0.08406919280865363, 0.031127342754708867, 0.004433472324827952, 0.01233255207937743, 0.10323364088045699, 0.036183555011770556, 0.08261245276246752, 0.021040074926401888, 0.05284086707979441, 0.12495102946247373, 0.022663844849116037, 0.010581604338118007, 0.04556238817583237, 0.014686963421159556, 0.03057347158236163, 0.010333558228532118, 0.00981423890750323, 0.05115154219259109, 0.06339760310947895, 0.03606046197403755, 0.07206873103444066, 0.10774244501122407, 0.024250168120488524, 0.041856647203011174, 0.05704435759357043, 0.09992920926639012, 0.04347646635557924, 0.049910691633288345, 0.020791897350656133, 0.019844664160960486, 0.020108583749138882, 0.0917294460481831, 0.020906988764181733, 0.02791417918966285, 0.03397139175129788, 0.02571883172328983, 0.03916482753785593, 0.021605930723516003, 0.041791864072105715, 0.0654616727094565, 0.05903304873832634, 0.06250581131981951, 0.10836533337299313, 0.8659385197928974, 38.57999774387905, 51.59821210588728, 23.28367403575352, 43.12876796722412, 37.60166706357683, 25.024084874561854, 57.842728410448345, 0.04976464714854956, 0.49931475839444567, 2.0662761415754045, 9.321441803659711, 2.4809457191399167, 0.29870615154504776, 7.119577646255493, 88.41101891653878, 71.4139325278146, 82.21718624659947, 76.88778591156006, 72.64504909515381, 73.84403719220842, 73.17985194069999, 66.82851750510079, 57.59821435383388, 54.440094811575754, 53.0592862537929, 60.90883295876639, 67.7080135345459, 68.99937098366874, 69.82800619942802, 68.65274620056152, 66.79126821245465, 67.59156867436, 69.48286833081926, 67.86900329589844, 65.67161464691162, 64.86809716905866, 64.28653294699532, 61.752483231680735, 64.56676074436733, 62.66404519762312, 57.081560203007285, 49.90781266348702, 48.685937200273784, 45.74649831226894, 44.95167303085327, 44.84461171286446, 47.222472872052876, 45.93330063138689, 50.37108380453927, 52.210066999707905, 52.30624743870327, 51.413542883736746, 53.49834987095424, 55.26367521286011, 60.54030050550188, 60.33997004372733, 65.56099237714494, 58.82857704162598, 64.75443158830915, 39.69560398374285, 45.70236335481916, 65.46605913979667, 58.98054804120745, 63.55586733136858, 59.33770629337856, 59.785788672310964, 56.22479173115322, 58.17277479171753, 54.32269804818289, 56.36441578183855, 53.133312361580984, 51.73919800349644, 47.13989005770002, 45.726348536355154, 44.867717947278706, 45.4471560205732, 44.16755492346627, 43.90197045462472, 42.65700265339443, 43.5269136428833, 45.963170937129426, 52.192470686776296, 50.2162675176348, 52.46451003210885, 51.12559216363089, 58.57471765790667, 60.09837423052107, 62.28725133623396, 59.29673971448626, 61.79369299752371, 59.16175706045968, 52.42460305350167, 43.483101776668, 50.247899191720144, 55.354554176330566, 62.827279227120535, 55.977884020124165, 60.672601154872346, 60.02936472211565, 61.79119859422956, 60.70539665222168, 65.58579744611467, 59.34657914297921, 63.49024159567696, 58.41196305411202, 62.91425677708217, 45.252689838409424, 61.278199195861816, 31.592461926596506, 0.15557581186294556, 0.5173771977424622, 4.733014302594321, 2.8412267523152486, 1.7319839767047336, 0.8931285036461694, 0.047758358198085, 10.716238822255816, 43.877203600747244, 42.1015636580331, 20.044269255229406, 43.82433475766863, 33.577770709991455, 0.3866301764334951, 0.27149955715451923, 0.06523984604115997, 0.033959028843258104, 0.04505294747650623, 0.029217317567339966, 0.04729230302785124, 0.04266362211533955, 0.030772611432309662, 0.028912350003208433, 0.02261794704411711, 0.09844998935503618, 0.04473600037662046, 0.025855317345953414, 0.09218284314764397, 0.03386297881869333, 0.04976038594863244, 0.014664688812834876, 0.04533874981903604, 0.08694943147046225, 0.015501685507063354, 0.06343425078583614, 0.04379178157874516, 0.013737825244399053, 0.11883734752024923, 0.2264347081737859, 0.1388424461973565, 0.09190918318927288, 0.10829851124435663, 0.1549412730549063, 0.2083870880305767, 0.16943623311817646, 0.14493341078715666, 0.1305094254868371, 0.14358598951782497, 0.1778367409216506, 0.15726631400840624, 0.10045592885996614, 0.07094612877283778, 0.0797786530373352, 0.12352397532335349, 0.17879078829927103, 0.11025901604443789, 0.13692922171737465, 0.1932470854371786, 0.16455234161445073, 0.16812547988125257, 0.1018942738217967, 0.15608046549771512, 0.1447889506816864, 0.1527320308876889, 0.14875543569879873, 0.21002604865602084, 1.7450664575610841, 61.709195954459055, 62.842982155936106, 40.34737627846854, 50.29943050657, 59.53231143951416, 24.544945784977504, 63.00234603881836, 0.12716818334800856, 3.518897805895124, 7.939228841236659, 39.07138477052961, 4.409897880894797, 0.4109854038272585, 8.230069143431527, 86.71329607282365, 75.99855545588902, 84.76804365430559, 82.18191719055176, 75.93123435974121, 75.36773545401437, 74.10312162126813, 70.88263852255685, 60.05463532039097, 56.711242062704905, 57.35426310130528, 65.61841923849923, 71.68212604522705, 71.23812225886753, 72.55911377498082, 74.05583218165806, 69.20680250440324, 71.65931510925293, 73.27273545946393, 72.1739751270839, 70.03654248373849, 67.10154002053397, 68.08081218174526, 63.57444681440081, 67.25006471361432, 66.1785969052996, 61.766553333827424, 53.1944009235927, 52.26699359076363, 48.35165589196341, 47.27503946849278, 47.388124874659944, 48.985213484082905, 49.218697275434224, 51.66643646785191, 54.789224420275005, 55.74017224993025, 51.46681472233364, 54.170077392033164, 58.43990176064627, 61.108211517333984, 62.05465344020298, 67.69349874768938, 61.83058098384312, 65.32068198067802, 42.08163275037493, 48.542971066066194, 63.24176706586565, 60.598144258771626, 64.72178895132882, 61.15971156529018, 60.390254156930105, 57.58537408283779, 60.397292682102744, 55.933686528887065, 56.38909230913435, 56.149386405944824, 52.69733721869332, 47.99462618146624, 46.89274958201817, 47.00115885053362, 48.4804060118539, 46.9706632069179, 46.74983903339931, 46.54977260317121, 45.59235947472708, 48.745243549346924, 55.6834853717259, 52.8951871735709, 54.90396697180611, 53.01038135801043, 60.73692062922886, 62.82397883278983, 65.64399555751255, 61.96030385153634, 64.65448175157819, 62.72538389478411, 54.440772260938374, 46.11673654828753, 53.98577642440796, 58.52630261012486, 64.53721700395856, 57.54062073571341, 63.63520186288016, 61.36771978650774, 63.981534821646555, 60.92812810625349, 69.40879358564104, 60.90050901685442, 64.65858813694545, 59.761101722717285, 67.35986709594727, 50.19275828770229, 63.300708634512766, 35.84609004429409, 0.290496610637222, 0.2744225503078529, 6.975691744259425, 9.385225398199898, 6.584967178957803, 3.8977001309394836, 0.4011079695607935, 13.710148981639318, 55.505750451769146, 41.66119030543736, 31.733691011156353, 58.20786666870117, 47.73128598076956, 0.9582636313779014, 0.41104606485792566, 0.1560402690832104, 0.16077277942427567, 0.10583515092730522, 0.21097415206687792, 0.10944989696145058, 0.17331385718924658, 0.10962173595492329, 0.20343557372689247, 0.11628514661320619, 0.21639975878809178, 0.14251380919345788, 0.11842853017151356, 0.21786597796848842, 0.07721154471593243, 0.2072768011795623, 0.07204177283814975, 0.08799651278448956, 0.22783162178737776, 0.14462075542126382, 0.14842394420078822, 0.21013962184744223, 0.11745633876749448], [0.05891714138644082, 0.06589400808193854, 0.040448130640600405, 0.03410185367933341, 0.023150035546028187, 0.06956827520791974, 0.0739939995110035, 0.01781899794670088, 0.04538796396393861, 0.13618921142603668, 0.03832101156669004, 0.1147414930164814, 0.05248383891635707, 0.08840096036770514, 0.005983524082694203, 0.04000963077747396, 0.02656413707882166, 0.06768951352153506, 0.041111727710813284, 0.04083985569221633, 0.1354883797466755, 0.048301915638148785, 0.07550302746572665, 0.1064775607415608, 0.23773798878703797, 0.11321392069969859, 0.26761396708233015, 0.1799900039498295, 0.4368557727762631, 0.3968648186751774, 12.028622388839722, 36.89906174795968, 67.60802895682198, 57.62473215375628, 49.80280106408255, 25.793283462524414, 26.353382962090627, 6.654152997902461, 1.8123514013631004, 2.5797927464757646, 6.148259001118796, 2.104944169521332, 0.014458427737866129, 0.0558023026346096, 22.005115168435232, 102.43049648829869, 71.58903408050537, 79.42774159567696, 75.17228262765067, 78.7999301637922, 69.90823010035923, 70.14571952819824, 58.55397033691406, 56.75790616444179, 55.89350162233625, 63.707754952566965, 67.10745293753487, 67.8018489565168, 66.67247486114502, 66.29489585331508, 67.97229521615165, 66.91535609109062, 65.28530870165143, 65.70363889421735, 66.6050842830113, 63.52983937944685, 66.49781104496547, 61.954272815159385, 63.428479058401926, 58.46231664930071, 57.15004512241909, 50.33538743427822, 47.34672750745501, 43.08010278429304, 44.026593344552175, 43.26893745149885, 46.280040059770855, 42.81678690229143, 47.32619210651943, 48.95675713675362, 52.06953273500715, 47.848734855651855, 48.84686095373971, 48.66601324081421, 52.8454623903547, 52.953843866075786, 58.95301233019148, 58.30389772142683, 60.775733266557964, 42.19044154030936, 48.09361021859305, 63.09220709119524, 57.378192697252544, 60.22141293116978, 58.27673373903547, 55.204709325517925, 50.65550136566162, 50.113500186375205, 47.97875649588448, 48.380866118839805, 46.008174419403076, 45.088354519435335, 43.15435470853533, 42.24202496664864, 42.930827685764854, 42.056733880724224, 42.90453570229666, 42.02911826542446, 43.687368392944336, 42.11884730202811, 46.868882519858225, 47.333056926727295, 48.70503085000174, 50.83694314956665, 50.433853830610005, 52.869461468287874, 57.27090903690883, 58.794857433864046, 58.86717428479876, 58.01237562724522, 55.74822868619646, 51.98301724025181, 44.28887741906302, 48.69017212731497, 53.76773500442505, 56.98423331124442, 56.5013404573713, 56.1747681753976, 58.5174297605242, 59.4326673235212, 62.491834095546174, 62.75289181300572, 60.614604541233604, 58.035217830113, 56.39137479237148, 45.32131372179304, 41.78823464257376, 46.129218987056184, 1.3881146971668517, 0.11950862221419811, 0.2894954186465059, 3.4016111280236925, 2.0838859166417802, 0.5578790072883878, 0.918120196887425, 0.11445236924503531, 20.242880037852697, 41.145724296569824, 16.526997327804565, 28.886838606425695, 25.824920347758702, 2.3196704302515303, 0.2414545150739806, 0.09177543715174709, 0.07523896199251924, 0.07440986683858292, 0.05389978204454694, 0.004904552895043577, 0.011839783833628255, 0.05255413514428905, 0.05682938073628715, 0.0494572809631271, 0.06767894194594451, 0.06005296829555716, 0.04527640262884753, 0.01986637558521969, 0.04710624533306275, 0.11025187785604171, 0.050625117761748176, 0.021477791081581796, 0.07690074853599072, 0.09746992694480078, 0.06495249324611255, 0.03423592880634325, 0.053177559548722844, 0.02963400592229196, 0.054417707824281285, 0.05593186889642051, 0.06619734716202531, 0.054455698999975405, 0.057389535142907074, 0.008757591946050525, 0.09749710905764784, 0.027713141138000146, 0.013146358991174825, 0.09300603504691805, 0.05439300575692739, 0.04592382003154073, 0.07870385356779609, 0.08029757626354694, 0.04857495134430272, 0.03308440398957048, 0.03110606050384896, 0.05815169960260391, 0.10575131792575121, 0.037052612485630174, 0.02053523130182709, 0.07518216182610818, 0.047415535165263076, 0.02473884055923138, 0.10391083239976849, 0.07106135080435447, 0.42035358399152756, 0.17971598436789854, 0.39770848197596415, 0.24920167507869856, 18.097656726837158, 54.212148734501426, 70.65188189915249, 69.47555187770298, 59.40228285108294, 23.646196297236852, 42.17272710800171, 6.548732323305948, 1.361425906419754, 2.4698029799120764, 2.658507368394307, 4.300505442278726, 0.07340962479689292, 0.15772348376257078, 28.501267433166504, 101.64444678170341, 68.30578790392194, 81.39148317064557, 75.62002454485211, 81.09890147617885, 72.53842898777553, 72.11286572047642, 61.23703806740897, 59.215626444135395, 58.06900691986084, 67.63347326006208, 67.66134248461042, 67.77841963086809, 67.87596539088658, 69.27720860072544, 70.01192501613072, 68.94359084538051, 68.33259405408586, 69.48060321807861, 66.31933266775948, 67.82684162684849, 67.81988648005894, 63.56459426879883, 65.15522452763149, 62.616345814296174, 58.88693496159145, 51.33344405038016, 47.52609177998134, 46.2928386415754, 45.7263137953622, 45.14352669034685, 47.82509013584682, 47.91680288314819, 49.8876941544669, 53.07744884490967, 54.595776149204795, 51.0866961479187, 50.748958110809326, 50.49236461094448, 55.009666442871094, 55.515217372349326, 61.274794578552246, 59.11494704655239, 63.953596115112305, 44.053340435028076, 51.59285157067435, 64.29243196759904, 60.92822538103376, 62.427820341927664, 60.91179983956473, 58.97160570962088, 53.72021280016218, 53.90039348602295, 51.243468352726524, 50.55096224376133, 49.92542634691511, 49.13952950068882, 46.46813474382673, 44.98226247514997, 44.15574298586164, 44.129374572208945, 44.23326403754098, 44.89958586011614, 45.57968248639788, 43.82703413282122, 48.70274836676461, 50.053842953273225, 50.96062108448574, 51.08286074229649, 53.55795499256679, 57.4540114402771, 60.90212099892752, 59.27330344063895, 60.16370814187186, 61.84751374380929, 58.35077721732003, 55.33764573505947, 47.136221408843994, 52.773652757917134, 57.05643204280308, 61.032302447727744, 61.779845237731934, 58.66168825966971, 59.09636756352016, 62.42417253766741, 64.70447404044015, 65.94496372767857, 62.138288906642366, 60.71499211447579, 60.819048336574006, 51.80204445975167, 52.83787495749337, 51.72924470901489, 1.5562583889280046, 0.213779853656888, 1.454569114106042, 2.7063226997852325, 1.6561629538025175, 0.8219703733921051, 0.07389711149569068, 0.22717306283967836, 23.395479236330303, 56.82640845435006, 24.83491495677403, 26.057891709463938, 39.81455714362008, 3.1262600975377217, 0.2869537078908512, 0.059907300397753716, 0.08288694053356137, 0.06360409488635403, 0.05710491005863462, 0.028406737937725017, 0.07495504937001637, 0.013291316123546233, 0.06314608374876635, 0.026504712678225975, 0.07178541552275419, 0.01937437493221036, 0.05041245810155358, 0.005197070613836071, 0.03397158852645329, 0.00719268323986658, 0.0363785693688052, 0.028427092291946923, 0.01233973861339369, 0.05586162355861493, 0.052907010673412254, 0.01948883700450616, 0.024365741293877363, 0.05278035193415625, 0.10102917559977088, 0.16591102656509193, 0.24982636155826704, 0.0838260737114719, 0.1123581523341792, 0.2278916042830263, 0.23412552263055528, 0.07875339340950761, 0.11359517595597676, 0.23163383347647531, 0.09697251327868019, 0.16426462919584342, 0.1013478631419795, 0.1830355269568307, 0.1390067059546709, 0.12662469036877155, 0.19819906114467553, 0.18099734346781457, 0.2110807906304087, 0.10364252608269453, 0.2555135435291699, 0.16323037897901876, 0.19789663808686392, 0.24854132479854993, 0.4365713308964457, 0.22694734138037476, 0.7417857732091631, 0.30172612092324663, 0.7177722017679895, 0.7063937123332704, 33.24876308441162, 67.98158495766776, 79.54898071289062, 75.54498400006975, 75.58373410361153, 38.86847652707781, 38.21284450803484, 8.851328424045018, 2.9233635791710446, 10.93729315485273, 14.116852232388087, 6.9193679094314575, 0.2192709254367011, 0.21519947105220386, 27.23813877786909, 103.82827949523926, 73.065158026559, 84.30550207410539, 76.75906358446393, 85.2507141658238, 74.21088818141392, 75.58583940778459, 64.59683949606759, 64.00910527365548, 61.74126883915493, 69.68638106754848, 70.81715175083706, 70.77495534079415, 72.46342318398612, 72.55180427006313, 73.92515046255929, 72.76182746887207, 70.37528106144497, 72.62582342965263, 69.71876662118095, 69.77103097098214, 72.46226283482143, 68.50620869227818, 68.17580795288086, 64.6200395311628, 63.53778811863491, 55.21600709642683, 52.42001029423305, 49.35971096583775, 51.16132327488491, 49.29765313012259, 52.23368740081787, 51.01487956728254, 53.7735402243478, 55.19021190915789, 57.228969710213796, 53.951771940503804, 52.969630173274446, 53.77547877175467, 57.86978122166225, 59.001218932015554, 64.39354215349469, 63.68792479378836, 65.71889019012451, 47.03641748428345, 51.91246175765991, 66.86799022129604, 63.885851178850444, 65.82655252729143, 63.85169383457729, 61.27038247244698, 54.55341298239571, 55.473663670676096, 52.73534039088658, 53.298377241407124, 51.087745325905935, 49.192269802093506, 47.5180527142116, 47.08530848366873, 47.56565829685756, 45.71222284861973, 47.22808354241507, 45.63662992204939, 48.893577166966026, 46.36610392161778, 51.75163180487496, 52.77578932898385, 54.62220709664481, 54.97871221814837, 55.22768007005964, 61.002077783857075, 64.51520511082241, 61.21754142216274, 61.23366124289376, 64.25955309186662, 60.98540210723877, 58.368036542619976, 50.18766873223441, 54.60504504612514, 60.72134971618652, 64.4328203201294, 64.02861581529889, 61.70584692273821, 61.4974148614066, 63.811762537275044, 68.52867916652134, 67.3811285836356, 64.53274931226457, 64.06740760803223, 62.498858724321636, 57.95470210484096, 54.293244634355815, 53.1213823046003, 3.4741207914693013, 0.2847270002322537, 0.7986270859837532, 6.864292579037802, 6.20393100806645, 3.637365677527019, 1.360723378402846, 0.37480366389666286, 32.53175067901611, 56.40770305906023, 26.96872411455427, 44.83909484318325, 51.474753039223806, 7.98114732333592, 0.5268980211445263, 0.1562287796820913, 0.17505104254399026, 0.19855058299643652, 0.15587283378200872, 0.1785726257200752, 0.1888685803860426, 0.10207242319094283, 0.20653566452009336, 0.12658872801278317, 0.18974393127220018, 0.17043739796749183, 0.1526873425713607, 0.13139237596520356, 0.20584506514881337, 0.18050943607730524, 0.3168187753430435, 0.10693753963070256, 0.10923146296824728, 0.15641593321093492, 0.22024935936289175, 0.08640344148235661, 0.18363205423312529, 0.09705980680882931], [0.03679029084742069, 0.0358814576507679, 0.03801267846886601, 0.03886037566033857, 0.10280226224235126, 0.01208997835471694, 0.05459763834785138, 0.032713425146149736, 0.06852377911231347, 0.09011803394449608, 0.03961304062977433, 0.03595968934574297, 0.033740058807390075, 0.03303075222564595, 0.019117362830521803, 0.03831213293597102, 0.039513787919921536, 0.014300042397475668, 0.06671470975769417, 0.058194230177572796, 0.04841621486204011, 0.11009433559541192, 0.006888726268828447, 0.023447279685309956, 0.05461537864591394, 0.0654837115268622, 0.08032718074641057, 0.042147155185895305, 0.07163082488945552, 0.06340531126729079, 0.3252797813287803, 31.89389215196882, 51.91258682523455, 37.628869261060444, 27.004394429070608, 60.76398386274065, 14.081921032496862, 7.80140437398638, 0.404187052909817, 1.4551753444331033, 2.090195966618402, 1.9907950375761305, 0.3393759935029915, 0.010102418667104627, 0.24581225695354597, 27.77849497113909, 96.10535676138741, 80.28974900926862, 76.04865196772984, 76.27935300554547, 79.1188107899257, 73.79330144609723, 64.94313771384103, 53.48788935797555, 59.38689953940255, 68.47349657331193, 68.15214238848004, 69.30735683441162, 69.8545274734497, 64.7232619694301, 61.865495681762695, 66.50372396196637, 67.27318831852504, 66.44018963405064, 65.30444404057094, 61.827120780944824, 63.140017645699636, 63.86833477020264, 64.6156621660505, 60.76091970716204, 56.321559292929514, 53.834799017224995, 49.64290564400809, 43.358902726854595, 45.217566694532124, 43.89396265574864, 45.85421623502459, 44.53452055794852, 49.91533408846174, 51.46095391682216, 56.15105397360665, 54.190956728799, 54.35945749282837, 51.10748863220215, 57.929612159729004, 54.56648254394531, 63.66242490495954, 56.993227754320415, 65.30867549351284, 33.199552467891145, 43.10352863584246, 71.37013803209577, 55.87504025868007, 63.04863493783133, 51.87244013377598, 54.04097638811384, 47.88978133882795, 48.01396996634347, 44.96346412386213, 47.27807583127703, 45.991502216884065, 43.641857692173545, 41.94869286673409, 42.930674825395855, 42.90065165928432, 43.80678708212716, 43.9995196887425, 43.09155341557094, 45.14311327253069, 43.75553716932024, 45.52744245529175, 51.26806150163923, 50.64008331298828, 51.42958280018398, 50.96792016710554, 54.98456607546125, 58.361234256199424, 58.91147599901472, 60.21946743556431, 56.94075148446219, 59.92315455845424, 55.933446816035676, 46.611555985042024, 49.104663440159385, 54.59247922897339, 56.290629386901855, 57.58725357055664, 59.31552069527762, 63.02577536446707, 60.59879738943917, 65.3308332988194, 62.45348003932408, 62.66736643654959, 56.38759844643729, 55.18245424543108, 39.68283666883196, 54.21114124570574, 14.007689084325518, 0.3957562824445111, 0.723920923258577, 2.376063964196614, 5.538850741727011, 1.9177594823496682, 0.5198314317635128, 0.14476323420447962, 1.1323706145797456, 41.86906998498099, 26.082969495228358, 31.22999177660261, 37.578171730041504, 21.415511880602153, 0.20192444909896168, 0.13569211667137487, 0.022085403923743537, 0.06448446693164961, 0.02778504040491368, 0.04679784098906176, 0.06218174299491303, 0.04009543153058205, 0.0612973336662565, 0.0050053352772790405, 0.05558531392099602, 0.03476645837404898, 0.0450323301899646, 0.04596670683739441, 0.012636907265654631, 0.018520609941333532, 0.02801056339272431, 0.10908337270042726, 0.013471508731267281, 0.04477345211697476, 0.04879594680720142, 0.0080008930859289, 0.043016928514199596, 0.03146150768069284, 0.04144757201096841, 0.017076665369261588, 0.044347990304231644, 0.044769360550812314, 0.03613466995635203, 0.09955492256475346, 0.07076138404331037, 0.01872788542615516, 0.07909993481423173, 0.05969225229429347, 0.06793612707406282, 0.05922642443329096, 0.0327440168974655, 0.0337544539278107, 0.015435859128566725, 0.014683548693678208, 0.02942742932853954, 0.05885403084435633, 0.03804314808387842, 0.025210081433345164, 0.03375110875016876, 0.024829733717654432, 0.09051371485527072, 0.06751351510839802, 0.05093458740572844, 0.0693865092471242, 0.05034136459497469, 0.11033492375697408, 0.021249747336176888, 0.08610789198428392, 0.24505764458860668, 1.6658483083759035, 49.346071652003694, 62.88453238351004, 39.78608342579433, 45.847139494759695, 64.23807621002197, 18.659708670207433, 11.675369892801557, 0.7008681574038097, 2.2809029562132697, 2.919331452676228, 3.9159439291272844, 1.8434261339051383, 0.009983779363600271, 0.4873845928481647, 35.29793276105608, 94.81511797223772, 78.27312469482422, 76.55311897822789, 78.76844787597656, 79.31368691580636, 75.82690715789795, 66.76965931483677, 56.00179277147566, 63.47694274357387, 73.66270310538155, 70.66363130296979, 70.73116084507534, 72.59335449763707, 68.14854322160993, 64.70727416447231, 69.0976254599435, 69.63934871128627, 69.84802395956856, 68.25587204524449, 64.67716067177909, 66.22666454315186, 64.9179504939488, 67.12417725154332, 63.17533533913748, 60.08744471413748, 55.962799480983186, 52.06845576422555, 44.967719895499094, 46.98178727286202, 45.26266745158604, 48.829709325517925, 46.61689567565918, 50.88275262287685, 54.2827285357884, 58.405904224940706, 55.522815227508545, 57.26757737568447, 55.08055196489607, 58.432453291756765, 56.2613114629473, 63.96888910021101, 58.7616936819894, 69.33477442605155, 35.219901016780305, 43.462361403873985, 72.93734591347831, 59.22455487932478, 64.24696295601981, 54.299108913966585, 56.83294670922415, 50.39514889035906, 50.43461813245501, 47.43033865519932, 48.94865901129586, 47.297777448381694, 46.45483589172363, 44.6518235206604, 44.85746240615845, 44.7610387802124, 45.12679542813982, 45.391987323760986, 44.19539635522025, 46.657796246664866, 45.53670787811279, 46.66667257036482, 52.794222899845664, 53.41087205069405, 54.610346521650044, 53.56700154713222, 57.20086077281407, 61.36905384063721, 61.901938983372276, 61.599879946027485, 58.207585266658235, 61.51638344355992, 57.76684365953718, 48.98116268430437, 51.408446380070274, 57.250550815037315, 59.055456570216585, 61.024464879717144, 62.0245885848999, 65.23792893545968, 64.08763381413051, 65.62250477927071, 63.58187443869454, 65.57374926975795, 59.32792322976248, 59.74831008911133, 47.42532900401524, 61.698940413338796, 16.19135938371931, 0.33326657276068417, 1.205338316304343, 4.30671843460628, 2.717796346970967, 0.13687906440879616, 0.5724074191280774, 0.2769201291458947, 2.502248678888593, 50.77792862483433, 37.08321680341448, 28.583641801561626, 42.34220061983381, 33.41352571759905, 0.6916999007974352, 0.1898409074970654, 0.05881686069603477, 0.060090667701193264, 0.07404843837554966, 0.05443542776629329, 0.01915560506417283, 0.03860596913312163, 0.10820191499910184, 0.041584283246525695, 0.027594473844926273, 0.019923121468829255, 0.09390824913446393, 0.038885135403169055, 0.04677824829039829, 0.006314930763827371, 0.016164230847997323, 0.02663064029599939, 0.058366618784410615, 0.023815267885636007, 0.018493378634697626, 0.039585902621703487, 0.06754192536962883, 0.017957916117406318, 0.05225946095639041, 0.23180767414825304, 0.08353277016431093, 0.11490458569356374, 0.0851553984518562, 0.20868538559547492, 0.18064620159566402, 0.12400844932666846, 0.15444238696779522, 0.18454726226627827, 0.1309135609439441, 0.12951776012778282, 0.10147286964846508, 0.09796622781349079, 0.15701403468847275, 0.2143109972987856, 0.14872285244720324, 0.11491651433919157, 0.07717611161725861, 0.10366886002676827, 0.09623620778854404, 0.10465848299541644, 0.17843605019152164, 0.15262913783746107, 0.10929019695946149, 0.11800317013902323, 0.2299000679382256, 0.2857931415949549, 0.14796634018421173, 0.20077316516212054, 0.29329133353063036, 3.3456514222281317, 76.526125226702, 68.83569921766008, 50.594294684273855, 42.61354167120797, 82.234452520098, 24.180511031832012, 11.782867210251943, 0.5235657628093446, 6.411610058375767, 5.461237192153931, 9.750882165772573, 1.1080258637666702, 0.20173977900828632, 0.4635218733123371, 32.48993641989571, 98.33991827283586, 79.886565889631, 80.01379435403007, 81.54931150163922, 84.30866350446428, 80.14901324680874, 69.55634553091866, 59.49179649353027, 66.88391549246651, 79.06473990849086, 74.59601988111223, 74.10255186898368, 75.8249408176967, 70.13833359309605, 64.37180818830217, 71.71031488691057, 74.40821702139718, 73.40767642429897, 71.44057886941093, 65.4402882712228, 66.90885257720947, 69.09766020093645, 69.93260438101632, 68.02156489236015, 63.461913790021626, 59.01898547581264, 55.26136841092791, 47.72002989905221, 49.583307470594136, 48.95902572359358, 51.803329876491, 49.70556449890137, 54.40171296255929, 57.380954606192454, 62.46393013000488, 59.62238788604736, 60.485465322222026, 56.77931356430054, 63.793231691632954, 59.25945568084717, 66.9593312399728, 60.81738076891218, 68.9017835344587, 39.04592309679304, 46.32254913875035, 75.23071697780064, 61.74308231898716, 67.10613972800118, 55.64006607873099, 58.87419196537563, 51.97729539871216, 52.005324431828086, 49.37721347808838, 51.39648853029524, 50.890541553497314, 48.212810039520264, 46.25426919119698, 46.07768767220633, 47.572623865945, 48.17509174346924, 48.6723986353193, 45.737507343292236, 49.433882985796245, 49.12880495616368, 50.72780779429844, 56.328788893563406, 56.587466853005544, 57.704952580588206, 56.60307250704084, 59.89438206808907, 65.53517287118095, 62.784367152622764, 65.20558507101876, 59.72549220493862, 64.76155349186489, 61.295785086495535, 52.97382688522339, 53.8460168838501, 60.964988299778526, 60.41196032932827, 62.475818497794016, 64.57287515912736, 67.44309261866978, 66.33994797297886, 69.82222529820034, 65.31287915366036, 66.17618588038853, 60.57923126220703, 64.95219816480363, 51.108867849622456, 62.984676769801546, 21.364706652505056, 0.4407656544021198, 1.931167334318161, 10.47223458971296, 13.480046357427325, 5.747046564306531, 5.301389975207193, 0.808414492223944, 3.7677271280969893, 62.57930496760777, 33.57462665012905, 43.97363070079258, 55.07758508409773, 46.12748193740845, 1.208666286298207, 0.4082234134631497, 0.13753774549279893, 0.2256713155657053, 0.19418024750692503, 0.10814968137336628, 0.13771389318364008, 0.11266441590019635, 0.16246858771358216, 0.14953219544674667, 0.12845905550888606, 0.08945366673703704, 0.23768983994211468, 0.10852883995643683, 0.1000082857374634, 0.11827003796185766, 0.1002980066197259, 0.16732559565986904, 0.16792130869414124, 0.09975778417927877, 0.09105854454849448, 0.12083576885717255, 0.15233667567372322, 0.10890073821480785, 0.1402457651815244], [0.03625637199729681, 0.09999540035745927, 0.04424372322059103, 0.07757549732923508, 0.061729628326637406, 0.05012616042846015, 0.032723986543715, 0.014373186776148421, 0.034981272382927794, 0.05496909555846027, 0.023475511831098368, 0.0048670201545714265, 0.09798803592899016, 0.01186290236988238, 0.017437618857781802, 0.06799036916345358, 0.029490387200244834, 0.062093187389629226, 0.03375291365331837, 0.03293906857392617, 0.02538987455357398, 0.024006479053891132, 0.1229136466447796, 0.055603804000254185, 0.032853973497237475, 0.01421705841286374, 0.01969493692740798, 0.10313743140016284, 0.05403207601713283, 0.15080961904355458, 0.5620343557425908, 9.547803691455297, 59.11999838692801, 41.05993488856724, 21.122761692319596, 37.97984709058489, 47.18115540913173, 4.764156997203827, 0.05653275915288499, 0.72024098357984, 1.6880909034184046, 1.4711300368819917, 2.2356834283896854, 0.25915239112717764, 0.06528051064482757, 0.21839189689074243, 9.258470279829842, 79.2799881526402, 79.88079193660191, 78.35958112989152, 79.72943932669503, 74.92040348052979, 65.68841539110456, 58.328195571899414, 63.12311267852783, 67.80091094970703, 71.00025068010602, 67.4782713481358, 63.85953140258789, 63.34120273590088, 65.73724733080182, 68.93135506766183, 65.71470042637416, 66.1681398664202, 65.9752995627267, 65.63184315817696, 61.96469511304583, 67.33533995492118, 65.92420945848737, 60.48493725912911, 56.220456055232454, 53.85450758252825, 50.84430129187447, 47.77513953617641, 46.216971261160715, 43.10971253258841, 44.75207212993077, 46.187712396894185, 46.78448622567313, 55.41928359440395, 59.665890557425364, 56.674541677747456, 54.77705465044294, 55.16137341090611, 58.599481037684846, 55.03178603308541, 60.9750006539481, 55.03915112359183, 66.93941075461251, 34.293852056775776, 43.49866574151175, 70.86571965898786, 55.8485815184457, 63.554859842572895, 55.08217784336635, 55.06572798320225, 50.196086474827354, 51.73021398271833, 45.54641103744507, 46.34834085191999, 43.19438328061785, 44.89897094454084, 44.6797969681876, 44.302440302712576, 41.795964513506206, 44.5980201448713, 43.162713391440256, 44.302593163081575, 43.56525380270821, 46.11963047300066, 44.213565894535606, 47.73753241130284, 48.56322159085955, 51.264479705265586, 52.278531074523926, 53.63064009802682, 57.86572347368513, 59.78375285012381, 60.06737831660679, 59.97876099177769, 60.5724915095738, 56.78790153775896, 49.85300874710083, 49.936904770987375, 53.552031653267996, 59.73574774605887, 58.30181326184954, 60.2378454208374, 58.19703790119716, 65.681460244315, 61.006364822387695, 63.5858279636928, 60.8622522354126, 64.19430255889893, 44.90535633904593, 47.53563513074602, 34.29347685405186, 0.1829261878239257, 0.114574614113995, 0.5182919172304017, 4.4994262882641385, 0.5063130600111825, 1.5623838773795535, 0.8559732830950192, 0.1487121315939086, 20.422183513641357, 46.28831883839199, 75.63767991747174, 55.66164023535592, 37.33635704857962, 25.641017164502824, 0.8152824065514973, 0.02567887618871672, 0.15168596059083939, 0.03958948867927704, 0.03927377651312521, 0.0044456689917881575, 0.02476065376374338, 0.07919835631868669, 0.03691385207431657, 0.02702526269214494, 0.020567002007737756, 0.02493278791994921, 0.016206907307995216, 0.06577361561357975, 0.040460629255643914, 0.043982144578226974, 0.033108644653111696, 0.04100612052051084, 0.04261577182582446, 0.025149225323860134, 0.07545363011636905, 0.04600195673161319, 0.03490160219371319, 0.07786573389811174, 0.08376847965908901, 0.016696188731917312, 0.05675251628937466, 0.07031389698386192, 0.042523087334952185, 0.050507069631878815, 0.038528887555003166, 0.07839920491512332, 0.08099079477999892, 0.06920650069202695, 0.034304898498313766, 0.01969832112081349, 0.015861772167097245, 0.05044508885060038, 0.018117273459210992, 0.08090325697724308, 0.021441282504903417, 0.02031173713372222, 0.050349568083350144, 0.03796717591051545, 0.01379599011436637, 0.031290991830506494, 0.0413227215675371, 0.02655941277875432, 0.07572749363524572, 0.07444559170731477, 0.06490173882671765, 0.048646078777632544, 0.05985452394400324, 0.02590419222334666, 0.1363730944160904, 0.6941128256065505, 15.682924951825823, 75.00468512943813, 35.85058205468314, 25.22230134691511, 61.68060411725725, 39.953000000544954, 7.3014728001185825, 0.04634780942329338, 0.5578615825091089, 1.9290587731770106, 3.5228476396628787, 2.984366591487612, 0.8308830665690559, 0.2628766255719321, 0.19564420038035937, 14.181128280503408, 81.7775250843593, 80.15368938446045, 81.10182666778564, 80.41910362243652, 76.61873776572091, 70.90295505523682, 63.14290809631348, 65.90246854509626, 72.65517262050084, 73.46979331970215, 67.80182116372245, 66.2054864338466, 66.70202554975236, 69.51038319723946, 71.41552366529191, 67.21301691872733, 69.42196042197091, 68.09282561710903, 67.77978842599052, 63.375137737819124, 70.0591380255563, 67.15490913391113, 63.10848672049386, 58.70011874607631, 54.4813288961138, 52.480501311165945, 50.9714845929827, 47.059405599321636, 44.166464056287495, 46.29250512804304, 46.7282475062779, 50.37854616982596, 55.787711824689595, 59.38139656611851, 58.14318241391863, 55.527008465358186, 56.28480332238333, 59.45538098471505, 57.062977245875764, 63.23472159249442, 58.710443769182476, 67.95320156642369, 34.42952258246285, 43.71001257215227, 70.6306551524571, 57.911373138427734, 64.7309536252703, 55.2467737197876, 57.74319199153355, 52.811871324266704, 54.379690647125244, 47.779370989118306, 49.40624305180141, 46.68802091053554, 47.90983731406075, 45.49938562938145, 48.0225544657026, 44.35534736088344, 47.37861279078892, 44.70198604038784, 47.06828192302159, 44.39948926653181, 48.01273666109358, 47.409983907427105, 52.56807293210711, 50.951442514147075, 53.4967656816755, 54.91724497931344, 56.801419258117676, 59.4459661756243, 62.26940836225237, 58.923545019967214, 62.10239451272147, 63.35153470720564, 61.19816289629255, 52.35323115757534, 55.55072266714913, 56.63011142185756, 63.330822127205984, 61.02806404658726, 65.00228078024728, 58.66871983664376, 68.17978232247489, 63.893424715314595, 66.65877301352364, 61.36257117135184, 67.67624637058803, 50.19641998835972, 57.37591368811471, 36.51723391669137, 0.2034225051424333, 0.23614750270332607, 0.9311238591160093, 2.642374954053334, 0.6352793883000101, 1.2217144604240144, 0.35108495663319317, 0.16094647081834929, 26.58611634799412, 55.19482898712158, 66.29448590959821, 46.41109698159354, 46.281283787318635, 31.578124318804058, 0.9156980982848576, 0.028517999021070342, 0.08451836263494832, 0.03909124720043369, 0.1127119337075523, 0.055571196999933035, 0.046568041534296105, 0.05021781015342899, 0.03836903488263488, 0.017361020735864128, 0.045692001935094595, 0.045005246464695246, 0.04686580305652959, 0.03265701174469931, 0.013210717189524854, 0.013335124888856496, 0.06482515936451298, 0.017048904805311134, 0.09047373557197196, 0.023145837110600302, 0.06027195868747575, 0.05239424854516983, 0.014988604467362165, 0.05792237512235131, 0.030142696840422492, 0.10841703095606395, 0.12554714961775712, 0.154182548767754, 0.22523375547357968, 0.18685844753469738, 0.09521252914730992, 0.09067337414515869, 0.10357851987438542, 0.19217069819569588, 0.12406999245285988, 0.08430452910917145, 0.1989211445408208, 0.12985811329313687, 0.10598997904786042, 0.18916515447199345, 0.119325634890369, 0.16217627482754843, 0.25851459535104887, 0.1402863280049392, 0.10578497326267616, 0.09223018453589507, 0.1404881921729871, 0.19510171163294995, 0.22250041285795824, 0.13210600481501647, 0.1484478014920439, 0.2732397009219442, 0.34226356712835176, 0.34277472112859997, 0.33570517333490507, 0.9851091908557075, 28.035661697387695, 90.57669598715646, 58.390632084437776, 35.55151421683175, 61.40065424782889, 67.51800114767892, 11.506306324686323, 0.16541748733392783, 3.443610817193985, 8.279331002916608, 9.972071119717189, 6.77670966727393, 0.30650596586721285, 0.2583608664572239, 0.2345990315079689, 11.234106302261353, 82.79834052494594, 83.8344975880214, 83.72856535230363, 86.79037938799176, 79.56626783098493, 73.75476673671177, 65.28689289093018, 69.71600123814174, 74.65771988459996, 76.99242578233991, 71.68170915331159, 70.00715160369873, 68.61060537610734, 74.1300458908081, 74.140732220241, 70.86404514312744, 69.9170195715768, 71.75354657854352, 71.91136796133858, 67.13609341212681, 71.7206677028111, 69.42669214521135, 67.26148755209786, 61.109684535435264, 59.917408398219514, 56.952177797045024, 55.34396512167794, 51.724221161433626, 48.45976638793945, 49.5299140385219, 52.17214025769915, 51.94478130340576, 60.10774735042027, 63.02994428362165, 61.72227941240583, 57.06354352406093, 59.29787227085659, 62.71888732910156, 59.497723306928364, 65.71891798291887, 62.01420797620501, 69.0908648627145, 37.15059348515102, 47.82528815950666, 73.76634243556431, 61.204305103846956, 68.6459230695452, 59.49843202318464, 62.2969788142613, 56.10972261428833, 58.76697431291853, 50.49561289378575, 52.95749167033604, 48.248277119227815, 49.99152456011091, 49.056581905909944, 52.33525616782052, 46.64545277186802, 49.57824918201992, 46.751402378082275, 48.46444599969046, 48.00337743759155, 51.28232615334647, 47.58520705359322, 54.55669948032924, 54.12707151685442, 56.8278397832598, 58.64321299961635, 60.13875021253313, 62.6589869090489, 65.03782081604004, 60.71545764378139, 65.381409236363, 67.39562252589634, 64.25186838422502, 55.49606466293335, 58.77168519156319, 61.53557436806815, 66.2071123123169, 63.17196546282087, 66.63095242636544, 61.00181375231062, 71.83734880174909, 66.66781261989048, 67.44787992749895, 65.00046730041504, 72.55329813276018, 57.19594144821167, 57.78514174052647, 40.02733530317034, 0.734452383858817, 0.20149158446916512, 2.15626899259431, 12.61294765131814, 3.0588834158011844, 3.6220587960311343, 0.7657891394836562, 0.3019525073468685, 33.39424794060843, 59.9573883329119, 80.50875622885567, 69.04660483769008, 55.01856361116682, 41.67506585802351, 1.2057229642357146, 0.12882831426603453, 0.3310438006051949, 0.1108494975737163, 0.14798911181943758, 0.14070950315466949, 0.10968004925442593, 0.18853596251990112, 0.12480632508439676, 0.15008398012391158, 0.07430100946554116, 0.08976789630417313, 0.14728480604078087, 0.11735135582940918, 0.1436613883290972, 0.19621651752718858, 0.10427014383354358, 0.09423966599362237, 0.2110558883952243, 0.11238326491521937, 0.13580024801194668, 0.11832749630723681, 0.11902327968605927, 0.1828187078769718, 0.18456408993474074], [0.04929011029058269, 0.030902784982962266, 0.08251068608037063, 0.028800496898059334, 0.024577601979087507, 0.016708117377545153, 0.0836896203192217, 0.011491728447643774, 0.043970453419855664, 0.051233902773154635, 0.0830269358786089, 0.0456053971179894, 0.05354210927284189, 0.009925756137818098, 0.10905752730156694, 0.05735256176974092, 0.05489666533789464, 0.042101323538060696, 0.05448743747547269, 0.037679371889680624, 0.053687627892941236, 0.013886271743103862, 0.049877205930118046, 0.052227420532809835, 0.04372277456734862, 0.05802832158016307, 0.07650915919137852, 0.019275799061038663, 0.05603620383356299, 0.05029167886823416, 0.11916662699409894, 0.21755630815667765, 36.055116176605225, 63.867382866995676, 39.13146931784493, 24.74539089202881, 54.78652157102312, 25.306072303227015, 0.3192961609789303, 0.20382119874869073, 2.0717376427991048, 0.9843396778617586, 4.3407281296593805, 0.2882237897387573, 0.06403227083917175, 0.5142183186752456, 0.310785106250218, 5.421233373028891, 73.21744169507707, 81.87830870492118, 82.9006735937936, 79.92001451764787, 71.7641703741891, 58.755634852818076, 65.2343019757952, 68.22930908203125, 68.01681927272251, 66.66636044638497, 66.1053489957537, 61.71383735111782, 62.558988434927805, 68.56319086892265, 70.71207414354596, 68.46014213562012, 65.99006448473249, 64.3132904597691, 66.24063737051827, 65.40827097211564, 67.47891058240617, 61.650282178606304, 57.429994991847444, 53.30672550201416, 53.18776886803763, 48.063670430864605, 44.46331541878836, 43.702108996255056, 43.95373453412737, 45.304766586848665, 48.73258393151419, 54.87337057931082, 64.09953607831682, 59.55165522439139, 62.38604777199881, 55.9302020072937, 62.167283739362446, 56.559194632938926, 67.52951431274414, 59.237165859767366, 64.98380552019391, 30.644696371895925, 40.19813939503261, 72.3553022657122, 54.46352066312517, 62.45980290004185, 53.94568184443882, 55.731817041124614, 50.78896236419678, 49.51571886880057, 46.320662702832905, 46.91925001144409, 44.1203419140407, 45.474771635872976, 43.73082937513079, 45.20084932872227, 43.47622653416225, 44.884772300720215, 41.77478640420096, 45.29599448612758, 45.37070499147688, 45.5881210735866, 46.00529786518642, 48.87866285869053, 47.80774048396519, 50.02538660594395, 51.23150355475289, 54.33514922005789, 56.931152548108784, 61.73338958195278, 58.425942829677034, 60.07053974696568, 60.263942854745046, 58.32498550415039, 52.97307300567627, 51.843709332602366, 53.464060510907856, 57.195507185799734, 57.824496337345664, 65.48295715876988, 61.729637554713655, 61.81863008226667, 60.40474115099226, 62.39630331311907, 63.23407541002546, 55.26888983590262, 43.84876114981515, 47.561996596200125, 1.486386001110077, 0.24672336663518632, 0.05045094121513622, 1.181438684463501, 1.2736211951289858, 1.1329514405557086, 0.14523089411003248, 0.15376904952738965, 4.5470375163214545, 51.962294237954275, 40.689036573682515, 78.68623679024833, 36.29442603247506, 50.60968147005354, 6.791928393500192, 0.643305589045797, 0.036695876092250855, 0.06525846504207168, 0.03129880176857114, 0.062098595313727856, 0.050041401226605685, 0.06362643225916795, 0.029494095394121747, 0.014518462819978595, 0.02070637310056814, 0.05647785209917596, 0.08187170286795922, 0.030203049137656177, 0.07717791652040822, 0.06001851907266038, 0.10087341788624014, 0.023841539065220525, 0.04243555971022163, 0.013638195099442132, 0.06372762218649898, 0.0225017818489245, 0.03736160036974719, 0.013910925464837678, 0.06398459018341132, 0.053042327519506216, 0.07031600722776991, 0.036858554862971814, 0.03785364343119519, 0.005186133901588619, 0.027174983140347258, 0.042968610035521645, 0.0685693020267146, 0.011206993949599564, 0.04130305762269667, 0.07096220326742955, 0.033026402816176414, 0.03697380742856434, 0.03204630987186517, 0.024890328591157283, 0.0428223382415516, 0.01652563556230494, 0.04996533066566501, 0.04032770424549069, 0.03305790719709226, 0.07531522254326514, 0.06259832956961223, 0.03560952117134418, 0.0190863402094692, 0.022759653993749192, 0.03312098720510091, 0.06508705352566072, 0.03958724272836532, 0.06999757074351821, 0.06843873831842627, 0.07357792183756828, 0.06560352045510497, 0.6820243714111192, 47.55166809899466, 74.02853270939418, 31.097072737557546, 37.85523114885603, 73.99680028642926, 28.1398377759116, 0.3213501407631806, 0.9040298472557748, 2.140691999878202, 1.879599541425705, 4.645927318504878, 1.7494530507496424, 0.5876382504190717, 0.649260900914669, 0.8528387770056725, 8.547716464315142, 80.33356434958321, 79.09265082223075, 85.49768093654087, 79.98312500544957, 73.24828474862235, 59.532436507088796, 68.28026022229875, 69.49368667602539, 71.75777108328683, 69.46599810464042, 70.09030764443534, 62.39671325683594, 65.50520529065813, 70.49659660884312, 72.70474801744733, 70.32805415562221, 68.72037301744733, 65.25334698813302, 67.00630801064628, 67.1843625477382, 69.85284600939069, 65.53314399719238, 59.68650586264474, 56.838265555245535, 55.722746167864116, 50.169318539755686, 47.43283305849348, 46.91399369921003, 46.83057362692696, 46.540545395442415, 49.99125705446516, 58.06728376661028, 64.56659398760114, 61.99241842542376, 64.2880893434797, 57.69963026046753, 62.385908808027, 60.0693724496024, 68.88643496377128, 61.44148881094796, 66.96582780565534, 33.33655704770769, 41.63068076542446, 74.26844705854143, 54.91021340233939, 64.27098287854875, 55.939689772469656, 58.267037527901785, 53.04504592078072, 53.18612561907087, 48.16466249738421, 48.9527028628758, 45.42223283222744, 47.497725759233745, 44.07087074007307, 47.223063468933105, 46.113519532339915, 47.45455660138811, 44.93456309182303, 47.56515107836042, 45.6793509210859, 47.54685994556972, 47.43694986615862, 50.85647800990513, 51.710595743996755, 54.23297248567854, 53.17144060134888, 56.57916375568935, 59.22089317866734, 65.1543629510062, 59.9447078704834, 60.9167469569615, 61.27286992754255, 60.59461457388741, 55.43698065621512, 52.899665287562776, 55.40641205651419, 59.443082673209055, 60.43012292044503, 66.88518006461007, 64.97913633074079, 65.0053379876273, 63.533146721976145, 65.47564765385219, 67.2448535646711, 59.08262402670724, 52.500498226710725, 55.62355021068028, 1.3218448417527335, 0.2059092681322779, 0.5871325518403734, 0.9547772641692842, 0.4119561974491392, 0.6103205361536571, 0.23158525036914007, 0.15940374002924987, 7.84222504070827, 61.22391292027065, 47.959009715488975, 70.91216141836983, 39.3033503804888, 59.940983636038645, 7.961984191622053, 0.5523237053837095, 0.04736574426559465, 0.11268379486032895, 0.010529684534828578, 0.09227305437837328, 0.0033467196127665894, 0.04881829096536551, 0.07204600689666611, 0.03282058957431998, 0.08604283404669591, 0.030750073891665255, 0.0173120372928679, 0.052888700405934026, 0.08008384451802288, 0.06647573650947639, 0.04587988828175834, 0.045894958544522524, 0.04091450472229293, 0.04007030877151659, 0.077063766574221, 0.018022935039230754, 0.04155174409970641, 0.02635521105756717, 0.04770365470488157, 0.039433642756193876, 0.15405687051159994, 0.09159042779356241, 0.19711694706763538, 0.11070349719375372, 0.17943196317979268, 0.16296271048486233, 0.13618216823254312, 0.09500716373856578, 0.13734763355127402, 0.13354528615517275, 0.10103446138756615, 0.13597883842885494, 0.1203885871384825, 0.0968103501945734, 0.2519019458975111, 0.10658189907137837, 0.15436690673232079, 0.12122242525219917, 0.12427313226674284, 0.12292720377445221, 0.12677951848932675, 0.061216269087578566, 0.1162165602935212, 0.1294831819832325, 0.1320068979901927, 0.19587142818740436, 0.20110177967165196, 0.15405662623899324, 0.1398571003228426, 0.15927549691072532, 0.14772503956087998, 0.8208820575049945, 67.74732644217355, 83.98630183083671, 58.84325163705008, 38.65231806891305, 76.92586203983852, 41.185864039829795, 0.9129549711942673, 3.295075918946947, 8.057323898587908, 5.8802695870399475, 19.066591705594742, 2.5757523689951216, 0.20081843701856478, 0.4757209558572088, 0.4065174407192639, 6.104181366307395, 82.16768033163888, 81.44915321895054, 89.28330271584647, 84.7902500970023, 78.7337555204119, 63.10924407414028, 71.67072405133928, 72.82849543435233, 74.24014704568046, 74.47300202505929, 73.19228226797921, 67.44218935285295, 66.56645229884556, 72.80418368748256, 77.02822290148053, 76.10262557438442, 73.07988820757184, 68.94465391976493, 68.13574463980538, 71.67799186706543, 73.96293476649693, 68.65439292362758, 65.17287990025112, 61.22083486829485, 59.978962489536826, 54.155388900211875, 50.55655206952776, 50.00511523655483, 49.07779128210885, 50.41368668419974, 53.56992326463972, 60.736441203526084, 69.434800692967, 66.93631185804094, 68.72417368207658, 59.43973364148821, 65.92846870422363, 62.810068539210725, 71.737656048366, 64.87344033377511, 66.43282454354423, 35.039977414267405, 44.943032945905415, 76.30843816484723, 56.49386419568743, 66.11775847843715, 58.18202631814139, 60.32790797097342, 55.8594901902335, 54.13792807715279, 49.86021055494036, 51.74597249712263, 48.233185631888254, 50.76701995304653, 46.08037315096174, 49.80480909347534, 48.19859055110386, 50.6709680557251, 47.323854037693565, 50.0846061025347, 47.89004189627511, 50.6347644669669, 50.41738312585013, 53.356088978903635, 53.57242809023176, 56.93501227242606, 56.06238106318882, 59.17752252306257, 63.36583409990583, 72.69757052830288, 62.544084548950195, 65.130857195173, 64.90153190067836, 63.33130155290876, 58.71799646105085, 58.508410998753135, 57.0429664339338, 61.26451819283621, 61.849924768720356, 71.80217007228306, 66.47084508623395, 69.78505243573869, 65.24757998330253, 69.5398644038609, 67.7215416772025, 64.20611449650356, 54.66943052836827, 57.06809459413801, 2.2268574791295186, 0.26023560443094795, 1.28318495622703, 8.147699986185346, 4.555325848715646, 2.707694534744535, 0.3204020102109228, 0.33208822884729927, 8.374325905527387, 70.98984922681535, 51.13667801448277, 88.89908123016357, 49.603217533656526, 71.91230596814836, 12.487678578921727, 0.9284780068056924, 0.18422959931194782, 0.17005512490868568, 0.11760071744876248, 0.15461857537073748, 0.12860815679388388, 0.171721199793475, 0.21199499443173409, 0.12974949340735162, 0.17489341885915824, 0.2166038349803005, 0.12185595982841083, 0.166599590331316, 0.21422702180487768, 0.1389789945845093, 0.1619421938168151, 0.1367718151637486, 0.1875179157193218, 0.12289704967822347, 0.13029020439301217, 0.08743134739675693, 0.1816245133855513, 0.08095329214951821, 0.13808896020054817, 0.20413768105208874], [0.09101074854178087, 0.048068411382181306, 0.007952390554627138, 0.06680333321647984, 0.05826472318066018, 0.052651990072003434, 0.06500672855015312, 0.08898454798119408, 0.06757681564028774, 0.02177722519263625, 0.046450149467481036, 0.0682229031143444, 0.042356381458895545, 0.08508261878575597, 0.10928540650222983, 0.058181996191186566, 0.05621499102562666, 0.021842330627675568, 0.027274151033322726, 0.10253065824508667, 0.034918450218226225, 0.07188321277499199, 0.048184746211128573, 0.06477969073291336, 0.01855004987945514, 0.010959234521059054, 0.035847188239651065, 0.04107167718133756, 0.06486532185226679, 0.0931842794109668, 0.08853512709694249, 0.43577467650175095, 6.287474410874503, 62.599204608372276, 51.61259487697056, 28.000328370503016, 31.081324645451136, 61.35800620487758, 4.260139448302133, 0.44322490958230837, 1.3449896169560296, 1.3369474027838026, 1.681348545210702, 5.5020400541169305, 1.8832957659448897, 0.09256713824080569, 0.5724277751786369, 0.1126525347520198, 3.811193321432386, 84.42352417537144, 83.94946248190743, 80.35141427176339, 73.30045877184186, 65.93299198150635, 66.1785969052996, 67.7274476460048, 68.80684334891183, 65.19223758152553, 61.384951319013325, 66.01829501560756, 70.20259748186383, 71.64045769827706, 67.59343773978097, 67.74130930219377, 67.29763902936662, 65.96118082318986, 69.98475061144147, 66.24471596309117, 67.47487367902482, 62.266608238220215, 59.404304776872905, 54.873502595084055, 55.94383437292916, 51.12987920216152, 48.737225328172954, 45.13440717969622, 47.89009748186384, 43.36599336351667, 46.565465109688894, 54.24289798736572, 63.201391083853586, 60.31219809395926, 62.11131599971226, 58.25574670519148, 65.65691920689174, 56.45541981288365, 63.0248373576573, 55.52081414631435, 67.73643166678292, 27.605528252465383, 36.669270924159456, 74.68224702562604, 55.29963561466762, 63.23986325945173, 53.70429795128958, 55.347668511526926, 50.32647636958531, 49.93638365609305, 46.775780132838655, 50.02877385275704, 44.028917516980854, 45.344128131866455, 44.27549171447754, 44.54364701679775, 45.19201816831316, 47.27037027903965, 45.4213365146092, 46.24235303061349, 45.57741042545864, 44.53447192055838, 44.93050534384591, 47.26566982269287, 47.405877522059846, 49.82859625135149, 51.04284954071045, 54.48436178479876, 56.66531099591936, 62.10737637111119, 65.35444327763149, 61.84138543265206, 61.923214367457796, 61.190380913870676, 58.625960622514995, 52.10433278764997, 53.01955298015049, 59.0736608505249, 59.120672362191335, 60.83867004939488, 62.976477895464214, 63.22255529676165, 63.47200257437569, 65.81538677215576, 60.47625895908901, 47.092489446912495, 51.676817076546804, 6.517527529171534, 0.4110583870538643, 1.2847828247717448, 0.5600904343383653, 1.2517130907092775, 0.6055072258625711, 0.38538292050361633, 0.2603047064372471, 1.9621526088033403, 38.93552664348057, 39.563876560756135, 16.372888020106725, 25.378637552261353, 39.12171752112252, 25.00757074356079, 0.1229708878589528, 0.061826638478253565, 0.05142914783209562, 0.012891315489209123, 0.04585180032466139, 0.020079362638560787, 0.04051066442791905, 0.04119281943089195, 0.06920196129275219, 0.01622666455140071, 0.05495140275784901, 0.023964024814111844, 0.08216598350554705, 0.036797629203647375, 0.016339435375162532, 0.023896220506035855, 0.022777005830513578, 0.02459170193677502, 0.046758859152240415, 0.02192461656938706, 0.06108493184936898, 0.00720954907592386, 0.023380793431507688, 0.012757846802872206, 0.017396957646789293, 0.05134134879335761, 0.04034698481804558, 0.004812414624861309, 0.04773600386189563, 0.026846210871423994, 0.00790479895658791, 0.03720516072852271, 0.016811096940987875, 0.0447483802480357, 0.0718327976231064, 0.011217127870103078, 0.014855818556887763, 0.06936578000230448, 0.07603784198207514, 0.035011185599224906, 0.04100183557186808, 0.01605084934271872, 0.011916493913824005, 0.03507868626288005, 0.07049127960843699, 0.0570491955482534, 0.028620593515889983, 0.022667088246505176, 0.030039685046566383, 0.019290713260748556, 0.03772283884297524, 0.008505916522283639, 0.0679231331284557, 0.04550917745966997, 0.06630053876766137, 0.07051749820155756, 0.07988845357405287, 0.3219177488769804, 8.551994817597524, 79.85864107949394, 52.16740158626011, 26.61877461842128, 50.44001340866089, 63.43905421665737, 7.301262617111206, 0.569507686155183, 1.003688565322331, 1.4946639112063815, 0.6707248091697693, 2.9561803553785597, 1.3505329766443797, 0.9255740940570831, 1.1553966190133775, 0.5288866172943796, 7.6939539568764825, 88.07519858224052, 82.28215885162354, 84.24573366982597, 77.53573322296143, 70.52047061920166, 67.71360683441162, 71.01473767416817, 70.45374706813267, 65.95667144230434, 65.09097453526088, 68.61808163779122, 72.49616309574672, 73.60759694235665, 70.24833052498954, 71.26533835274833, 69.25920581817627, 66.63250187465123, 69.11318942478725, 68.52414199284145, 68.38794340406145, 62.744324684143066, 61.13214111328125, 57.414431027003694, 57.934639181409565, 52.6840626852853, 49.487307684762136, 47.38572079794747, 49.75170053754534, 47.141015665871755, 48.539688042231965, 56.52257762636457, 65.53893184661865, 62.77408381870815, 63.70544120243618, 60.48126861027309, 67.61877087184361, 58.170370715005056, 64.30056830814907, 58.01421342577253, 66.76742894308907, 29.89356483731951, 38.88427325657436, 75.54505348205566, 57.71411378043038, 65.62500613076347, 54.58231748853411, 57.68445192064558, 53.15790898459298, 52.11317784445626, 49.86828783580235, 51.893291677747456, 45.73514495577131, 46.68414034162249, 47.013158389500205, 49.14887135369437, 45.92119686944144, 46.98985760552542, 46.55361148289272, 49.69281802858625, 47.278193950653076, 47.06302561078753, 49.18632214409964, 50.15653732844761, 51.27385629926409, 52.68100895200457, 53.59792797906058, 57.800403458731516, 58.400512422834126, 62.2614735194615, 64.97847625187465, 62.87870284489223, 64.37277398790631, 65.56450816563198, 61.97365828922817, 56.96245418276106, 55.25331892286028, 61.940272194998606, 62.227753911699565, 65.1187047958374, 63.33419895172119, 65.4020801271711, 67.12993035997663, 69.8835778917585, 62.86161027635847, 54.17652532032558, 60.11799594334194, 6.58484992810658, 0.3939884001655238, 2.2827442288398743, 0.8562557707939829, 0.05598269116931728, 0.11853850712733609, 1.0472031789166587, 0.3463721238076687, 4.883157057421548, 44.7872439111982, 63.615545409066335, 28.160803965159825, 31.159325122833252, 48.078341552189414, 31.963214329310826, 0.13881872461310454, 0.05362993545298066, 0.0473969466984272, 0.03535851749724575, 0.04269127581002457, 0.023993505464334573, 0.02944506106099912, 0.017480702438790883, 0.02631068728598101, 0.05506455186488373, 0.03705084829458168, 0.050919802127672095, 0.052451167455209155, 0.08438680148018257, 0.0782570925408176, 0.07308136991092137, 0.04895806917920709, 0.02095055240871651, 0.036607334057667425, 0.05108745116740465, 0.03245730192533561, 0.00871684422184314, 0.0446164492916848, 0.02961999417415687, 0.08472161779978446, 0.06787315223898206, 0.11179622355848551, 0.14602079029594148, 0.16037471007023538, 0.08699736318417958, 0.09417819072093282, 0.17445462383329868, 0.11791406492037432, 0.16344436178249971, 0.13122108658509596, 0.08969693511192288, 0.09821319420422826, 0.1240364999643394, 0.1604280157813004, 0.17247824131378106, 0.15331977792084217, 0.14170234916465624, 0.19399944506585598, 0.17447727333222116, 0.11794009352368967, 0.1502102283494813, 0.09906298467623335, 0.12996495541717323, 0.09415930709136383, 0.14527517530534947, 0.20850702588047298, 0.17575547045895032, 0.11860714772982256, 0.26239595136472155, 0.39988030972225325, 0.20228654252631323, 0.2734053177492959, 0.7651215695909092, 13.572054403168814, 96.84693104880196, 68.72087328774589, 44.89836992536272, 44.248202664511545, 82.91363893236432, 9.148640973227364, 0.7974197821957725, 2.2325447968074252, 4.077248530728476, 4.451504562582288, 15.323150702885219, 4.074190889086042, 0.3487858900002071, 0.8916019084198135, 0.2530560525400298, 5.060921507222312, 90.01706722804478, 85.65440450395856, 86.3927617754255, 80.39270046779087, 72.38298388889858, 72.2133436203003, 73.10303960527692, 74.40893268585205, 70.17750058855329, 64.88625976017543, 71.59204265049526, 76.07586806161063, 79.86697196960449, 71.76324626377651, 74.50821549551827, 72.82914856501988, 71.32522487640381, 73.31184686933244, 71.89013426644462, 72.62690040043422, 67.60060133252824, 65.19937338147844, 61.35449736458914, 62.09313951219831, 57.59614726475307, 53.22598048618862, 51.423492704119, 54.0520726612636, 50.67482083184378, 52.327237946646555, 60.786683627537315, 69.49641036987305, 66.25811208997453, 67.32862104688371, 64.44124153682164, 71.60172149113247, 60.425919260297505, 66.60896832602364, 62.96586104801723, 69.17429883139474, 32.763386249542236, 40.87900379725865, 77.88616561889648, 60.49657549176897, 69.49106025695801, 60.81376075744629, 61.560657364981516, 57.73014327457973, 56.37845809119088, 54.20026731491089, 55.22331312724522, 48.204791818346294, 50.04678010940552, 50.5449937411717, 51.590190410614014, 50.53608267647879, 50.56871836526053, 48.44517517089844, 51.49734858104161, 50.92318071637835, 47.85495696749006, 50.84241138185774, 53.67737715584891, 54.00499166761126, 56.61828906195504, 57.6269451550075, 62.39470522744315, 63.874456133161274, 65.54744338989258, 67.5976413999285, 66.14467579977853, 67.93294061933244, 68.76716218675885, 68.0559515271868, 60.97777993338448, 60.84151186261858, 68.14838341304234, 67.1630037852696, 65.25951698848179, 66.76394789559501, 68.70974227360317, 69.91843005589077, 70.91611494336809, 68.03777503967285, 60.66551399230957, 59.080977303641184, 9.183636443955557, 0.283217368381364, 2.3013182835919515, 3.7236846685409546, 4.588542580604553, 1.8519604759556907, 2.19267321058682, 0.41473732250077383, 3.998932344572885, 58.18741117204939, 53.44047485079084, 26.840229340962, 41.739274161202566, 57.882593699863975, 47.694870471954346, 0.15790809957044466, 0.07492737871195589, 0.1499344174351011, 0.15634681763393538, 0.10596682064767395, 0.10651057147021804, 0.15090892942888395, 0.14384609913187368, 0.15482383221387863, 0.08294245826878718, 0.12788418707038673, 0.09682263167841093, 0.21761634493512766, 0.10799225446368967, 0.11561161918299538, 0.17095388525298663, 0.09820464466299329, 0.12307962988104139, 0.1639814493911607, 0.22206169925630093, 0.14282434753009252, 0.10966454472924982, 0.144206292661173, 0.14161750514592442, 0.09045747787292514, 0.1795490783240114], [0.11959406334374632, 0.05988467125488179, 0.08361125630991799, 0.04986251225428922, 0.11454378148274762, 0.05627513976235475, 0.03661241289228201, 0.0253927532383906, 0.08920849167874881, 0.026631459627034407, 0.07730620035103389, 0.042484675467546494, 0.026233098502936106, 0.043936740407454114, 0.09183681742953402, 0.005424795871866601, 0.010844703747092612, 0.0351523615952049, 0.028411920248929943, 0.0632046956036772, 0.017033805704808662, 0.028411626782534376, 0.04731467432741608, 0.08625442162156105, 0.016885177697986364, 0.037455465511551926, 0.10966330979551588, 0.01828560951564993, 0.004303596481414778, 0.03559869175244655, 0.10850464339767184, 0.04568907405648913, 0.06031769194773265, 26.59325041089739, 71.52893911089215, 45.10116004943848, 30.660138743264334, 66.90945012228829, 42.665726116725374, 1.8480451660496848, 0.48304006883076256, 0.7026688807776996, 0.22515047208539077, 1.047414664711271, 3.803458239351, 1.771754379783358, 1.6862370371818542, 1.1190081430333, 0.10115498956292868, 14.072430661746434, 103.10436058044434, 74.04326983860561, 86.27724797385079, 69.48610619136265, 68.03218173980713, 65.43570940835136, 69.34293855939592, 67.3324008669172, 73.31174959455217, 68.00358295440674, 69.83389132363456, 69.00674302237374, 72.11062840053013, 69.32002340044293, 64.56167466299874, 66.14871965135846, 69.77038478851318, 65.07454204559326, 66.82623154776437, 60.64233480181013, 61.363752365112305, 58.54490293775286, 57.77538646970476, 50.86994014467512, 51.66565479551043, 46.313620703560964, 49.00471012932913, 45.95590659550258, 45.818085602351594, 50.75271708624703, 66.89013413020542, 60.42864295414516, 67.4140213557652, 57.01968649455479, 64.21044322422573, 61.44119698660714, 68.66868536812919, 48.17317751475743, 64.34598173413957, 26.728464092527116, 35.46782316480364, 73.04609216962541, 53.20182159968785, 63.6659129006522, 54.480036531175884, 58.269549301692415, 50.345785413469585, 51.47154991967337, 44.71388483047485, 47.182656220027376, 44.27332387651716, 48.02590002332415, 45.32517344611031, 46.64143671308245, 45.832621233803884, 46.264246804373606, 45.556510244097026, 49.088894503457205, 48.4897826058524, 47.595292363848, 46.553340503147666, 46.25050674165998, 45.84931080681937, 46.390915938786094, 50.8428247996739, 54.45809759412493, 56.031958375658306, 61.63016019548689, 63.47690800258091, 61.548581395830425, 63.8556821005685, 63.24900014059884, 58.976531982421875, 57.493213176727295, 53.84314380373274, 56.52369628633772, 57.86368417739868, 63.98953219822475, 64.25175026484898, 65.50451047079903, 69.31994002205985, 61.867253576006206, 49.058555194309776, 57.167631013052805, 11.860530700002398, 0.3664070101720946, 3.15603660259928, 2.8697421593325476, 0.183187084538596, 0.17115112181220735, 0.24225192942789622, 0.3801732643374375, 2.8719082602432797, 25.375550815037318, 51.12505715233939, 9.886563113757543, 19.148827110018047, 32.49957357134138, 40.70166839872088, 2.2082495519093106, 0.24788325439606393, 0.0037768705265729553, 0.10624865016766957, 0.04008977933387671, 0.07757230821464743, 0.04585658060386777, 0.0936991653538176, 0.08070777782372066, 0.06287574861198664, 0.030032791130776917, 0.022532755276188254, 0.009275446479607905, 0.04841430139328752, 0.00483442545269749, 0.04308308907119291, 0.047812427261046, 0.052898410242050886, 0.04406043055600353, 0.07534241144146238, 0.05717253964394331, 0.04507761900978429, 0.0261580236921353, 0.13844722669039453, 0.06653906418276684, 0.09692174528858491, 0.027402719848656228, 0.13489718575562748, 0.04743642047313707, 0.03280529539499964, 0.030966102478227446, 0.07002627956015722, 0.02029204604748104, 0.04761095325063382, 0.015935133676975965, 0.1147483733615705, 0.03873424278572202, 0.0969149735090988, 0.031205014658293555, 0.026905714999884367, 0.056206261672611744, 0.058817484948251925, 0.05449738140617098, 0.028919762998287166, 0.035799911312226734, 0.06224656344524451, 0.020756121591797898, 0.042264188905911784, 0.024954623176849315, 0.05154585585530315, 0.07438776695302554, 0.013315437195290412, 0.05313648103869387, 0.041901488189718554, 0.02500199170650116, 0.06061014054077012, 0.04776229370119316, 0.04198270883145077, 0.04771467072090932, 0.3119123157645975, 34.997551713671, 84.74357209886823, 33.33073098318917, 41.08999626977103, 97.11611815861293, 41.66870478221348, 4.181489748614175, 1.373971096106938, 0.7300036368625504, 2.133070911679949, 1.0050355387585503, 2.0036385655403137, 2.5872761734894345, 2.45584882582937, 1.6944462252514703, 0.3903527009700026, 19.98623616354806, 103.96449198041643, 76.74338150024414, 87.30542850494385, 69.6010432924543, 69.04364490509033, 67.57758889879499, 72.69935621534074, 72.53622640882219, 74.99238681793213, 68.07413496289934, 69.80208941868374, 71.16660445077079, 77.17871393476213, 71.6186056137085, 67.68059594290597, 67.77774565560478, 70.96645464215959, 68.5592929295131, 69.4067508152553, 62.269095693315776, 63.4074399130685, 59.63064929417202, 60.82694843837193, 52.78555154800415, 51.56356143951416, 47.79913166591099, 51.81907796859741, 47.23261029379708, 49.192492144448416, 54.24418340410505, 68.83848544529506, 63.771150316510884, 70.069657598223, 59.37997218540737, 68.50823061806815, 63.121674401419504, 70.28032003130231, 49.55747754233224, 68.27881499699184, 27.525493689945765, 38.28540454592024, 75.46842874799455, 57.599784646715435, 66.266818182809, 56.37085328783308, 59.63108703068325, 52.23456634793963, 53.81377724238804, 48.73783329554966, 49.65539503097534, 47.384629930768696, 50.264870166778564, 47.44014951160976, 47.84235988344465, 47.86677237919399, 49.07973677771432, 46.87632404054914, 50.17351525170462, 50.34845699582781, 49.37399993624006, 46.06542757579258, 48.148521832057405, 47.23078291756766, 49.75528580801827, 52.085621288844514, 57.51555510929653, 59.376762117658345, 64.43386949811662, 67.26375266483852, 63.03765678405762, 63.48856013161795, 65.1539113180978, 59.76804992130825, 57.62583344323294, 55.44895935058594, 58.590073176792686, 60.397285733904155, 66.07641669682094, 67.53981154305595, 68.36989198412213, 69.61824703216553, 64.99208082471574, 53.864905561719624, 62.582869393484934, 13.015696508543831, 0.458812840282917, 4.842350287096841, 2.984966742140906, 0.16970820352435112, 0.12360970143760953, 0.2461147207234587, 0.7199028017265456, 6.124595173767634, 28.407273939677648, 76.69503593444824, 22.032379899706157, 17.37889337539673, 40.01189293180193, 50.47301387786865, 4.978997903210776, 0.6425386273435184, 0.05191705861528005, 0.14238720812967845, 0.08493834188474075, 0.0878453283969845, 0.04145138877044831, 0.020960618475718156, 0.03507226053625345, 0.024033455909895043, 0.03604054018589003, 0.059439667633601596, 0.02007880454350795, 0.06205003934779337, 0.033236205843942504, 0.08183768790747438, 0.02232700479882104, 0.08377020992338657, 0.05143721900614245, 0.08689384588173457, 0.027963413690615977, 0.021509700887171284, 0.026599963727806295, 0.024527261466053978, 0.04477531808827605, 0.05021447854648743, 0.06264486350119114, 0.2957959148500647, 0.12662849016487598, 0.18339973741344043, 0.17370288845683846, 0.19078062421509198, 0.12265749967523984, 0.1419508151177849, 0.12368839792907238, 0.14777534614716256, 0.12584835131253513, 0.137445329023259, 0.15820213593542576, 0.12582666533333914, 0.13215055742434093, 0.1273998487740755, 0.12065860336380345, 0.11185864878020116, 0.18879983121795313, 0.10784401491816555, 0.11438683633293424, 0.1009429202282003, 0.15044124238193035, 0.14770317716257914, 0.19551449162619455, 0.06409861120794501, 0.14040162467530795, 0.19631828420928546, 0.11949843061821801, 0.16624699639422552, 0.14513100018458708, 0.16723121143877506, 0.19316965102085046, 0.37264508115393774, 48.42787415640694, 96.86514227730888, 65.07247148241315, 45.67493881498064, 84.94851616450718, 66.68259838649205, 3.538237682410649, 1.2240790192570006, 0.8768607622810772, 5.522966725485666, 3.5595265286309377, 14.041354843548365, 11.328470655850001, 3.6966531361852373, 2.8643557855061124, 0.26198779898030417, 16.867528540747507, 107.29667431967599, 78.96329620906285, 92.13931805746896, 74.29381493159703, 71.5345879963466, 71.720431464059, 75.32512215205601, 74.15397548675537, 79.87167590005058, 73.7582060950143, 73.4865037373134, 74.58399949754987, 79.25152138301304, 75.82708086286272, 69.77540833609444, 70.94667312077114, 73.81896809169224, 71.78256225585938, 75.09489359174455, 67.69247041429792, 69.16928223201207, 63.782239641462056, 64.0457570212228, 55.983876841408865, 56.900041988917756, 52.049546241760254, 55.63778012139456, 52.675731795174734, 50.78204543249947, 55.956323759896414, 73.0105868748256, 68.06966727120536, 74.37060642242432, 63.185180936540874, 68.36775888715471, 66.00605923788888, 72.73338849203927, 50.77977337156023, 66.20852279663086, 30.79114702769688, 40.32962015696934, 76.42600168500627, 61.19290310995919, 68.35481439317975, 58.55032253265381, 62.64846733638218, 54.285278524671284, 57.62234197344099, 50.85566854476929, 52.260163511548726, 50.90956572123936, 53.821489742824006, 50.04800646645682, 49.43250029427664, 49.41006456102644, 50.553314208984375, 50.76078394481114, 54.192846638815745, 53.7976713180542, 52.68611587796892, 50.463317666734966, 51.4657690184457, 49.94892168045044, 52.65459884916033, 56.59935174669538, 61.40741484505789, 62.491646494184224, 69.43707275390625, 72.42557634626115, 63.97007724217006, 66.41549573625836, 69.364255632673, 64.33250222887311, 63.19918155670166, 59.131726946149556, 61.40504550933838, 63.296206201825825, 71.39199011666435, 69.90766729627336, 71.47721672058105, 72.77699538639614, 70.41028608594621, 60.22920880998884, 63.26183346339634, 14.186033708708626, 0.33733718576175825, 3.3242998250893185, 6.029256769589015, 0.8530357692922864, 0.6835924929806164, 0.35197622595088823, 0.6542782059737614, 5.139002323150635, 41.694006647382466, 67.85500267573765, 15.89509688104902, 30.899879387446813, 48.45597614560808, 68.6100217274257, 6.238872195993151, 0.787774108350277, 0.23456277059657232, 0.1855033045368535, 0.1852731725999287, 0.19622276004936012, 0.10740002909941332, 0.2424401007592678, 0.142858749255538, 0.07760923409036227, 0.12258207372256688, 0.16287017187901906, 0.08515541202255658, 0.17447948535638197, 0.13387265216026986, 0.12419556214341096, 0.12186818702944688, 0.1781125654067312, 0.1633034979126283, 0.18353678791650704, 0.23331328907183238, 0.21145121646778925, 0.16116220424217836, 0.21562048846057483, 0.18302080274692603, 0.18304068382297242, 0.12967101404709475], [0.06528821201728922, 0.07503914021487747, 0.04415542885128941, 0.037641848903149366, 0.046165995965046544, 0.07738704779850585, 0.13455938388194355, 0.05064386907698853, 0.11113286736820426, 0.06313252661909376, 0.03117206160511289, 0.019140906299331358, 0.15168574345963343, 0.05768213301364865, 0.05736387973385198, 0.0798584691115788, 0.06354643976581947, 0.0854817737958261, 0.08136127490018095, 0.095261180108147, 0.09055688325315714, 0.018731848070664064, 0.015414960249992353, 0.02839424441169415, 0.06334617694041558, 0.006252878736371973, 0.05758013562964542, 0.0922125494107604, 0.05180542603401201, 0.03748309885018638, 0.0213710320780852, 0.028432476467319896, 0.426836687539305, 1.271415142076356, 58.383086340767996, 60.731855392456055, 38.45077167238508, 24.659651858466013, 81.33918407985142, 32.75297089985439, 3.377432916845594, 0.5900518266218049, 0.7359941782695907, 0.5951062068343163, 0.6850861928292683, 2.567559574331556, 3.422456592321396, 1.525054897580828, 0.3102928698062897, 0.3978672320289271, 61.17765876225063, 87.85740729740688, 75.23938138144356, 88.93308571406773, 72.86770411900112, 70.09953485216413, 67.79994515010289, 69.09242820739746, 67.29170526776994, 72.9341219493321, 74.20144557952881, 74.0888569695609, 68.56351048605782, 65.31621428898403, 70.75160244532994, 70.13603373936245, 71.92909976414272, 66.61116395677838, 63.523815291268484, 59.12887123652867, 59.60162666865757, 56.53713410241263, 56.56509017944336, 53.55652713775635, 50.75621550423758, 46.24975981031145, 48.59727471215384, 45.008321693965364, 48.17437955311367, 43.297487599509104, 62.67364065987723, 61.56070600237165, 63.5850567136492, 61.924124581473215, 63.45996134621756, 58.70774786812918, 66.3197773524693, 58.965477398463655, 69.12856578826904, 27.379894188472203, 35.36230434690203, 71.16440882001604, 54.89549364362444, 65.55671923501151, 59.18780585697719, 61.80704048701695, 53.33935076849801, 53.4975369317191, 46.52956376756941, 48.713858536311555, 45.35319900512695, 48.526430879320415, 46.23160416739327, 47.619930676051546, 46.29534694126674, 52.047694546835764, 54.81757307052612, 57.45332704271589, 56.44311802727835, 57.360186440604075, 56.04017462049212, 55.27034548350743, 49.00451210566929, 47.23780754634312, 46.893913405282156, 53.375999041966026, 56.133513246263774, 64.45884827205113, 64.74425942557198, 67.57970115116665, 63.40712029593331, 65.44311618804932, 61.764496667044504, 61.08398314884731, 56.47008398600987, 63.689307485307964, 62.328461102076936, 62.20210116250174, 64.62810638972691, 69.0492034639631, 62.62122344970703, 59.75709956032889, 63.15663078853062, 14.147043892315455, 0.31230347763214794, 1.8490148740155357, 5.139817433697837, 0.39415363701326506, 0.07798432824867112, 0.06991395487317018, 0.11808227375149727, 6.6318336469786505, 23.52324618612017, 69.64673464638847, 9.344679185322352, 29.87936966759818, 49.00343860898699, 39.223706654139924, 10.434063792228699, 0.2561735952539103, 0.05145964798118387, 0.06934813809181962, 0.0460805717988738, 0.05126417900568672, 0.02905782451853156, 0.054284246771463325, 0.04943399364128709, 0.0255139429853963, 0.02713743131607771, 0.07729232430990253, 0.0692039222589561, 0.020743144609566246, 0.01266635229278888, 0.022337079347510422, 0.043352168918188126, 0.09220961813947984, 0.04993820622829454, 0.07246911419289452, 0.04954315635508724, 0.04548110646594848, 0.0872277868911624, 0.08261564187705517, 0.052464446385524104, 0.04959949172501053, 0.11451122537255287, 0.056750826737178225, 0.027491280542952672, 0.03603496262803674, 0.07073974556156568, 0.05162862355687788, 0.08294970502278634, 0.05940248391457966, 0.054581116020147286, 0.12293044717184134, 0.06413531316710369, 0.054768978618085384, 0.10671945169035878, 0.02876849040122969, 0.10286232616220202, 0.01565069518983364, 0.018438091601378152, 0.06719121775989022, 0.00818766578699329, 0.02099585479923657, 0.014659050186829907, 0.08371128594236714, 0.06676330643572978, 0.01814964127593807, 0.029424375920955623, 0.0859384685754776, 0.06683814884828669, 0.05708074064127036, 0.1516572449888502, 0.04715129327295082, 0.07582441557730947, 0.11184743938169309, 0.026872229296714067, 0.10843472036400012, 0.34691799165947096, 2.585634878703526, 72.86706488473075, 66.17633874075753, 24.667710031781876, 52.25269419806344, 102.33163057054792, 32.884569781167166, 6.103020148617881, 1.6781043878623416, 0.6773701097284044, 0.4440786423427718, 0.40884145029953545, 0.7083161920309067, 1.7019014252083642, 2.398505994251796, 0.5079582088759967, 0.531242273747921, 72.92539501190186, 84.42351027897426, 82.81610706874302, 91.33860765184674, 73.82866082872663, 70.19944299970354, 71.2602870123727, 70.85987622397286, 70.42316804613385, 76.98154490334647, 77.54753126416887, 74.68415778023856, 71.60632119859967, 68.5664565222604, 71.13146046229771, 71.53048855917794, 72.02477645874023, 66.0141122000558, 65.16762706211635, 61.513458251953125, 60.18274620601109, 60.037841524396626, 58.62429305485317, 56.6970260483878, 52.30522952760969, 48.56232179914202, 50.34967293058123, 48.086300713675364, 48.95080253056118, 47.81666544505528, 63.422329902648926, 62.909198488507954, 67.21859632219586, 63.065275873456685, 66.65512520926339, 60.347474098205566, 68.08609976087297, 59.17625100272042, 68.99985735757011, 27.874159506389073, 38.722487926483154, 72.53869301932198, 57.999389444078716, 68.94870471954346, 61.36630930219378, 63.06294822692871, 55.178476401737754, 56.21801028932844, 49.533398560115266, 50.38816247667585, 47.96441193989345, 50.451999051230295, 48.12750005722046, 48.457855633326936, 46.86205244064331, 52.44873414720808, 53.498384611947195, 58.33476161956787, 60.12761919839041, 57.92858035223824, 57.007839815957205, 56.23754167556763, 50.85416425977434, 48.51079395839146, 50.76975059509277, 55.166105134146555, 59.70814255305699, 65.10983194623674, 64.27818816048759, 69.7629085268293, 63.93606581006731, 67.90378597804478, 64.64776284354073, 63.6356326511928, 58.56244019099644, 65.6539523260934, 64.665084702628, 64.39976773943219, 65.9822199685233, 72.11677755628313, 65.08686814989362, 63.06119728088379, 67.83845206669399, 16.057620457240514, 0.453059867556606, 3.123923114367894, 5.603645299162183, 0.19380679540336132, 0.0626625529091273, 0.2303671171622617, 0.2894317720617567, 13.919186404773168, 26.97833694730486, 87.37276349748883, 26.96525870050703, 14.094721351351057, 41.973709855760845, 52.13924748556954, 16.319885424205236, 0.3232622795871326, 0.013626567553728819, 0.17052425044987882, 0.01422384291488145, 0.08865318540483713, 0.05408474729795541, 0.01932767984856452, 0.018063896501969014, 0.0659417701619012, 0.03458514024636575, 0.06136741954833269, 0.023355714777218442, 0.07208420841821603, 0.06495565521929945, 0.014984511204862168, 0.01881898893043399, 0.019023492599704435, 0.01711811707355082, 0.05777064112148114, 0.06885111797600985, 0.01967087437930916, 0.09990440202610833, 0.01813898827614529, 0.07410225977322885, 0.00870048813521862, 0.09499927916164909, 0.011558075601767217, 0.09811495590422835, 0.10832557122090034, 0.13998108224145003, 0.13021658334348882, 0.16850450954266957, 0.12873331936342375, 0.173536443816764, 0.18792819870369776, 0.1966323916401182, 0.13110618346503802, 0.15413414207952364, 0.08178409042635135, 0.21302563484225953, 0.12538915952401503, 0.12607138577316487, 0.1818229170250041, 0.16937041522136756, 0.1302684098482132, 0.11879553619240012, 0.18788759516818182, 0.15707899763115815, 0.1465735656342336, 0.14329457229801587, 0.19085556162255152, 0.19727078452706337, 0.1036716080935938, 0.21822299595390046, 0.20348674883799894, 0.23581683901803835, 0.18896479665168694, 0.09555294338081564, 0.09248563939971582, 0.6559517990265573, 3.6848702941622054, 95.91257899148124, 77.45118059430803, 55.17151083265032, 39.9268330846514, 99.39461312975202, 49.052065576825825, 6.247491002082825, 1.5172097299780165, 1.6688327768019267, 3.3700977904456, 2.3693993389606476, 9.941413061959402, 14.565206459590367, 2.6852140724658966, 0.5988402121833393, 0.47849855252674645, 69.14583206176758, 91.18326677594865, 82.9705377306257, 93.98107705797467, 78.45666830880302, 72.73844678061349, 74.57684285300118, 75.09612342289516, 73.97159917013985, 79.9843270438058, 82.63976178850446, 79.60339205605644, 73.13814885275704, 69.37817287445068, 76.72576086861747, 77.35183525085449, 78.26293863568986, 71.44076647077287, 67.42873764038086, 63.90703623635428, 64.7327879496983, 64.40718146732875, 61.77992861611502, 60.950695855276926, 55.53581530707223, 51.899670124053955, 55.19894232068743, 52.82001461301531, 53.07955067498343, 49.115975107465474, 67.155930519104, 66.9587128502982, 70.39330468858991, 65.30668830871582, 70.29308387211391, 62.80815083639962, 69.34965051923479, 62.650134904044016, 69.09907068525041, 31.691209724971227, 42.134289673396516, 74.88728141784668, 62.485532079424175, 72.54441138676235, 66.99840096064976, 68.54555634089878, 60.73230702536446, 60.34188774653843, 53.030058656420024, 52.93332583563668, 51.47224473953247, 53.729683194841655, 51.637816837855745, 51.5983475957598, 50.03423861094883, 56.13124813352312, 58.90382603236607, 62.06294958932059, 62.82895374298096, 62.075004713875906, 61.97284534999302, 62.948754583086284, 57.164688450949534, 54.04145581381661, 55.81638009207589, 61.26957648141043, 64.17281872885567, 69.64699867793492, 66.57192053113664, 72.66189152853829, 67.13991492135185, 71.03864642551967, 67.34393487657819, 68.66755975995744, 63.21965094975063, 71.50182723999023, 68.24407400403703, 67.39544882093156, 68.45180429731096, 75.38612733568463, 71.56843961988176, 68.6606810433524, 67.9226850782122, 17.495937517711095, 0.4219518325158528, 2.415105892079217, 10.005606600216456, 1.7838244863918848, 0.27390963211655617, 0.3691092351717608, 0.537103676370212, 11.053170868328639, 38.66467891420637, 84.7817246573312, 16.53950408526829, 43.9500207219805, 64.6644593647548, 64.23857648032052, 26.957612207957677, 0.5023908019065857, 0.2542087749711105, 0.23939833683626993, 0.13366345981402056, 0.30095831783754484, 0.12067309687180178, 0.12597374458398136, 0.12355628716094152, 0.13123978701020989, 0.12578489471759113, 0.1801287643611431, 0.10553297214210033, 0.12667549907096795, 0.22656371125153132, 0.11653686953442437, 0.11799728045506136, 0.16159280256501266, 0.11434833625597612, 0.13380813705069677, 0.1678056591855628, 0.08452967381370918, 0.21544481574424676, 0.1621687566595418, 0.15792850990380558, 0.056100159151745696, 0.1933432745614222, 0.09096372606498854], [0.05090988194569945, 0.07986628583499364, 0.06715145560779742, 0.057423251547983716, 0.11243870122624294, 0.03600317665508815, 0.10507029946893454, 0.03568008881328361, 0.02172680664807558, 0.04622798013900008, 0.016781855474359224, 0.041969026172799725, 0.04431609915835517, 0.07692017499357462, 0.06712033120649201, 0.019242118279050504, 0.03901389081563268, 0.07162308280489274, 0.018129726273140738, 0.026859807016860162, 0.061474845212485106, 0.025627285474911332, 0.07006778554724795, 0.043078719305672815, 0.040891431138983796, 0.08451521423246179, 0.06371874694845506, 0.05602165265008807, 0.030489061826041768, 0.03245792278487768, 0.09037534799426794, 0.09911536757967301, 0.18628097352172646, 0.5480558829648154, 11.327306832586016, 73.42683955601284, 67.6100856236049, 36.93108252116612, 25.498818806239537, 90.09565830230713, 27.357189212526592, 4.924416329179492, 0.6279680377670697, 0.5777934129749025, 0.2203140373208693, 0.5051232352852821, 0.9703001912151064, 4.00752683196749, 0.11643411219120026, 0.08616765734872647, 5.156376727989741, 82.9632351739066, 94.28358772822789, 73.39232785361153, 75.73353726523263, 74.2063649041312, 72.43619319370815, 78.40801007407052, 80.06755951472691, 75.90991033826555, 73.48309912000383, 71.35613741193498, 73.86632006508964, 70.94016960689, 70.97277750287736, 67.74550601414272, 68.60030119759696, 64.9360158102853, 63.62457111903599, 58.076135771615164, 60.532629694257466, 58.55243478502546, 59.729098320007324, 50.80104180744716, 50.182061535971506, 46.48561988558088, 50.96859761646816, 46.41555772508894, 50.053089073726106, 47.37827580315726, 56.26382671083723, 64.91546998705182, 66.04889488220215, 61.09240436553955, 69.45935562678746, 60.277394567217144, 67.32789148603166, 56.34349822998047, 72.54646805354527, 29.321467535836355, 24.59927896090916, 69.19512258257184, 54.08598334448678, 69.27350521087646, 57.06937653677804, 64.1538918358939, 55.17114952632359, 58.4619414465768, 49.21486186981201, 48.48803513390677, 46.43535661697388, 48.95228597096035, 45.478732109069824, 52.41888468606131, 55.22497374670846, 62.891022000994, 63.155227252415244, 64.1959284373692, 63.121382577078684, 62.89150142669678, 60.42172949654715, 60.69363335200718, 60.96334157671247, 56.352662903921946, 49.80662604740688, 48.80866323198591, 54.05043983459473, 62.00826031821114, 63.6015864780971, 66.51572350093296, 67.28189441135952, 62.46507658277239, 64.44745322636196, 65.42614868709019, 65.07201984950474, 62.03400339399065, 62.8299959727696, 67.02214990343366, 62.427743911743164, 65.54554653167725, 72.52293450491769, 56.83262014389038, 8.075939859662737, 0.5659384833914893, 0.8337265625596046, 2.4658355585166385, 0.21696633552866323, 0.3506744158055101, 0.06909590626933745, 0.2494846513228757, 12.132925271987915, 25.316154139382498, 76.58682468959263, 18.15340038708278, 25.19739726611546, 50.41927998406546, 46.22315168380737, 22.71683825765337, 0.1358007365571601, 0.043985981693757434, 0.04313586213226829, 0.04916947694229228, 0.04589036825512137, 0.03948825803984489, 0.034377667986388714, 0.011297370573239667, 0.02529655223978417, 0.022121461274634515, 0.04191970685496926, 0.06030340200023992, 0.02769422358168023, 0.044926841743290424, 0.055886529186474423, 0.10050295812210866, 0.038119937891938856, 0.030541451514831612, 0.03655688497903092, 0.033354810372527154, 0.08849163300224713, 0.035347901816878996, 0.03947343883503761, 0.0714820289452161, 0.08918502793780395, 0.03592432410057102, 0.1120506606197783, 0.0786057577601501, 0.011088567536457308, 0.051711896767041514, 0.03199024252327425, 0.052145219407975674, 0.05139081060354199, 0.05194644257426262, 0.07258704357913562, 0.03526577193822179, 0.05640747783971684, 0.07498447743377515, 0.03546677436679602, 0.017220392656911696, 0.018982336058148315, 0.08246645238250494, 0.07168709579855204, 0.05289938733247774, 0.05139798950403929, 0.09071377412016902, 0.06329633854329586, 0.0784440967919571, 0.05799234565347433, 0.024027206602373292, 0.06959787290543318, 0.061383568681776524, 0.029746703803539276, 0.05109178700617381, 0.14478994134281362, 0.03726022723796112, 0.05778104306331702, 0.07341165361659867, 0.026355450241161243, 0.17307153876338685, 0.1172609342528241, 0.4396209386842591, 18.857126099722727, 87.55655029841832, 58.4744690486363, 18.388834885188512, 61.17494201660156, 102.51850931985038, 30.963271277291433, 9.09594236101423, 1.0498901775905063, 0.15228214859962463, 0.39623429679444855, 0.6124364254730088, 0.736014860016959, 2.1029572018555234, 0.4984627898250307, 0.11718275344797544, 7.229672287191663, 92.62166895185197, 91.69855907985142, 74.45007991790771, 81.16988427298409, 78.84131363459996, 75.4448048727853, 82.08783858163017, 81.28768403189522, 77.7202843257359, 72.65287971496582, 76.61892536708287, 76.15668255942208, 70.88363906315395, 72.94178581237793, 70.14539296286446, 69.8436952318464, 68.27244349888393, 67.67420360020229, 61.0334141595023, 64.58804307665143, 59.31617382594517, 62.09140246255057, 52.673487527029856, 53.08005789348057, 47.21856798444475, 53.30087511880057, 48.33683885846819, 52.466069902692524, 48.359677587236675, 61.16128185817173, 67.60766070229667, 69.91704736437116, 64.34584971836635, 73.00335380009243, 61.38623673575265, 70.63266318184989, 57.708510058266775, 74.30288927895683, 31.049227442060197, 27.920785393033707, 71.73625251225063, 57.55570180075509, 73.14598642076764, 60.686490603855674, 66.03729833875383, 58.382905687604634, 62.102512632097515, 51.307673181806294, 51.53834990092686, 48.98770093917847, 50.23019518171038, 46.62631048474993, 52.4700859614781, 56.34541940689087, 61.95384202684675, 64.36698613848004, 65.83969157082694, 64.76568767002651, 66.5099356515067, 62.455717359270366, 63.5204245703561, 62.16244779314314, 57.315492153167725, 51.83633381979806, 51.28487614222935, 56.38579886300223, 65.62202535356793, 67.77638380868095, 68.41701466696603, 66.86190359933036, 63.60328183855329, 64.01519189562116, 64.10435117994035, 66.3990979875837, 64.92084789276123, 63.56795024871826, 69.72475596836635, 64.29483604431152, 69.51108496529716, 75.16874599456787, 62.51096248626709, 10.272769178662982, 0.5146132260560989, 1.3296546169689722, 1.6555135143654687, 0.2625573341335569, 0.3657688886991569, 0.1746150702238083, 0.3277009571237223, 23.456022364752634, 26.266301189150127, 86.89509568895612, 43.22718225206648, 9.916892000607081, 43.11213397979736, 56.721685205187114, 33.23661763327462, 0.27093118908149855, 0.0301597111060151, 0.006365104611696941, 0.06978052774710314, 0.05046664930081793, 0.03285355619820101, 0.017022582735600214, 0.08136877271213702, 0.06805950509650366, 0.026303723820352128, 0.011491831924234117, 0.03223393498254674, 0.03188809586156692, 0.04980917940182345, 0.03287501486816576, 0.027212482378152863, 0.032712207175791264, 0.03239712604720678, 0.025951335140104805, 0.024104719050228596, 0.061255216997648985, 0.06587965706629412, 0.04399248205923608, 0.023406816945810403, 0.06658348108508758, 0.05997354577162436, 0.06667576184762375, 0.05795965383627585, 0.08825274117823158, 0.1508843121784074, 0.1948186946766717, 0.19920577641044343, 0.3261855441544737, 0.14265778075371469, 0.17473515735140868, 0.20745651796460152, 0.10071681200393609, 0.13230269854622229, 0.11485773963587624, 0.11261489641453538, 0.09970848861017398, 0.1302272363432816, 0.21342789754271507, 0.19191627470510347, 0.13225245981344155, 0.15489123788263115, 0.09522008802741766, 0.20471379799502237, 0.14857725240290165, 0.09397836894329105, 0.12404982639210564, 0.13481156820697443, 0.1354801423315491, 0.1201216514621462, 0.2534600794315338, 0.10779948945024184, 0.11265915725380182, 0.20510018297604152, 0.2552134410611221, 0.2459846862724849, 0.4144758422459875, 0.8868925496935844, 25.12074647630964, 106.83120059967041, 84.24542794908795, 56.23940379279, 45.365264551980154, 108.89906787872314, 45.25282185418265, 8.831294161932808, 0.9538310063736779, 1.523985092129026, 0.8813178688287735, 1.3401019935097014, 3.4030646043164388, 12.434165290423802, 0.3569963808570589, 0.2978808358311653, 5.958063355513981, 88.07432310921806, 96.95915140424455, 77.44737298148019, 81.88731357029506, 81.9031902040754, 78.50411060878209, 84.46198245457241, 85.06589903150285, 82.70631163460868, 76.61574309212821, 78.2730691092355, 81.02085930960519, 75.25812067304338, 74.87353788103376, 73.71641268048967, 72.6691037586757, 72.93916634150914, 70.74939291817802, 66.84329632350376, 70.46769210270473, 63.20041833605085, 68.0677912575858, 55.94904204777309, 57.84387833731515, 53.53405318941389, 56.2729149545942, 50.91235194887434, 55.307740688323975, 52.862996169498985, 64.37189156668526, 71.55087457384381, 74.79146575927734, 66.42368766239711, 74.92445428030831, 66.49730382646833, 74.05383804866246, 61.79409599304199, 74.30968461717877, 34.923928601401194, 30.879017421177455, 72.69590990883964, 59.82804066794259, 76.24197169712612, 63.930632318769185, 70.97288172585624, 61.033393314906526, 65.01280730111259, 55.36943374361311, 53.46762841088431, 51.68349082129342, 54.39080776487078, 49.251326016017366, 55.6791045325143, 59.74949823107038, 66.94911738804409, 70.29104110172817, 67.31480802808488, 69.07744789123535, 72.16212844848633, 68.16045243399483, 67.35123743329729, 69.08368737357003, 64.1825531550816, 58.700382777622764, 54.94608000346592, 61.3087990624564, 71.11760575430733, 73.40038776397705, 70.76686763763428, 69.01411506107875, 64.59758295331682, 69.57907308850969, 67.36008943830217, 68.04347256251744, 67.05068615504673, 69.17011601584298, 74.97714247022355, 67.5667427607945, 73.20483071463448, 79.8949454171317, 61.92341586521694, 10.112271870885577, 0.47667036205530167, 1.1777356203113283, 4.036717082772936, 1.3467995141233717, 0.8743093620453561, 0.3794451148382255, 0.45938047553811756, 19.47531601360866, 42.872115407671245, 91.44856289454869, 29.159918444497244, 36.860422815595356, 72.65365791320801, 65.49884768894741, 48.79707711083548, 0.25754890431250843, 0.09535821740116392, 0.09125594395611968, 0.15100173944873468, 0.08815510677439825, 0.1571856497653893, 0.21754465092505726, 0.11920780049903051, 0.13638120969491346, 0.12214211161647524, 0.12426911533943244, 0.15961841493844986, 0.24064317718148232, 0.12572815561933176, 0.13208939427775995, 0.14625831826456956, 0.1593866138053792, 0.10391022850360189, 0.080851186199912, 0.08715420655374016, 0.1627873091825417, 0.18693931533821992, 0.0877886503668768, 0.1149791566921132, 0.23977500519582204, 0.15561299558196748, 0.1312159297189542, 0.23029171835098947], [0.10362145757036549, 0.0688844747575266, 0.07623169265155282, 0.04908861931679504, 0.042906201777181456, 0.09955433902463742, 0.011805689145278717, 0.028575175774416754, 0.0639257136998432, 0.07187737058848143, 0.12749649930213178, 0.04826920007222465, 0.027922574364181076, 0.05020516565335648, 0.09473640791007451, 0.06982072416160788, 0.08208480357591595, 0.01567436079494655, 0.04636757514838662, 0.04677757314805474, 0.04849014464499695, 0.02309863651836557, 0.010166211985051632, 0.06716324854642153, 0.09152511201266732, 0.024324640731460283, 0.06685454225433723, 0.024931607269016758, 0.10528400407305785, 0.036525618085371594, 0.10076131033045904, 0.16906921352658952, 0.17845913395285606, 0.14613411921475614, 0.35283639122332844, 31.891797270093644, 67.3573865890503, 61.6752679007394, 27.858355828693934, 32.834747723170686, 86.21784087589809, 35.42976093292236, 7.282007421766009, 0.134064555434244, 0.6289413283978189, 0.047815738511937, 0.1400421911052295, 0.6394154663596834, 2.240355223417282, 0.3788796237536839, 0.23319975659251213, 2.4404216536453793, 61.69892651694161, 96.38347230638776, 86.45041097913469, 79.05661051613944, 78.29745033809117, 71.18157087053571, 69.71492426736015, 77.2389200755528, 83.2462353025164, 79.70934513636998, 69.74834510258266, 69.64307294573102, 75.09679044995988, 74.70038877214704, 73.43294702257428, 63.18087305341448, 61.75790977478027, 59.945493016924175, 58.4223575592041, 57.52704742976597, 57.3913699558803, 55.209486212049214, 53.46123259408133, 50.235448019845144, 52.46472890036446, 49.134471212114605, 48.625362804957796, 46.24747732707432, 49.2150251524789, 59.85190078190395, 65.18273244585309, 63.108097621372764, 68.8577527999878, 63.86833477020264, 67.77914224352155, 63.1163729258946, 66.63567720140729, 30.756982735225133, 35.06224291665213, 62.336917059762136, 54.27130569730486, 65.7960707800729, 59.286011695861816, 60.88480608803885, 57.08727857044765, 57.52579327992031, 54.82290233884539, 49.2807377406529, 44.72609976359776, 47.71271344593593, 49.289881569998606, 56.21840633664812, 61.42660576956612, 64.11981787000383, 64.48092269897461, 65.09551865713937, 62.079250063214985, 60.935764176504954, 61.205215317862375, 62.57696342468262, 62.50993415287563, 63.20097419193813, 61.66332394736153, 56.01962532315935, 53.309549944741384, 61.43668065752302, 66.76878384181431, 76.50905350276402, 74.77161475590297, 72.9020004272461, 68.8254645211356, 66.87110996246338, 65.05692141396659, 68.88907527923584, 66.80078029632568, 61.17664432525635, 71.3819499697004, 62.77094323294503, 22.14819768496922, 0.09874551171170813, 0.3094996895108904, 0.27720514099512783, 0.03340737648042185, 0.31984211025493486, 0.2790936939418316, 0.3638375337634768, 1.365439576762063, 15.775933538164411, 26.4880234173366, 85.4441728591919, 22.51550725528172, 25.90749100276402, 54.22144195011684, 46.27312312807356, 36.433890274592805, 0.4935898227351052, 0.11495031895382063, 0.08856867386826447, 0.025879352752651488, 0.019779450160318186, 0.06490912128772054, 0.02671283293914582, 0.05129759685535516, 0.0044576680354241815, 0.08288151903876237, 0.039598302849169285, 0.026339891433183635, 0.04018655199823635, 0.011691228769320463, 0.004380292566825769, 0.03680659604391881, 0.02909982922886099, 0.0469006899345134, 0.0745413601398468, 0.03601019949253116, 0.0553692005175565, 0.02276399322519345, 0.01823350990058056, 0.08401760379118578, 0.04379668738692999, 0.037446237435298305, 0.04278160917705723, 0.11262010756347861, 0.025829029202993427, 0.054166989134890695, 0.012431332359223493, 0.034051876182534864, 0.046397369621055465, 0.09262940061411687, 0.1000338461516159, 0.05262127618438431, 0.05608029164639967, 0.07445061286645276, 0.021719934784674218, 0.050769201280283074, 0.05042983199070607, 0.0423148856498301, 0.10493630237345185, 0.06856500690004655, 0.05201223332967077, 0.06358832573252064, 0.08199023615036692, 0.038938380046082396, 0.01981078490747937, 0.042700452996151786, 0.052367205532001596, 0.05376820731908083, 0.017877753990303193, 0.05216886635337557, 0.06371577496507339, 0.07886809975441013, 0.09348778812480824, 0.051444679498672485, 0.03692815898518477, 0.043683426321617196, 0.031192916378911053, 0.1871544923633337, 0.0414946691266128, 0.3469476300690855, 44.677542277744834, 79.0089806147984, 46.361462524959016, 18.318737983703613, 69.2808564049857, 104.39056941441127, 36.857084206172395, 13.307526060513087, 0.15288166143000126, 0.8092129922338894, 0.3646563898239817, 0.11868819195244994, 0.7343056574463844, 0.7974672253642763, 0.3505657416369234, 0.2707335182598659, 4.672753010477338, 75.19025761740548, 102.03306647709438, 89.84723240988595, 80.17795249394008, 79.22730691092355, 71.31571974073137, 70.70241614750454, 83.00976725987026, 83.32133838108608, 76.91468933650425, 69.30498055049351, 70.93408298492432, 75.19069535391671, 75.55433627537319, 73.62788568224225, 63.570944922310964, 62.171285901750835, 60.441893168858115, 60.56306280408587, 59.430263246808735, 60.263296672276084, 57.195406436920166, 54.90130581174578, 52.22912243434361, 54.4382882799421, 52.02752045222691, 50.56612321308681, 48.47961391721453, 52.48838404246739, 62.93540014539446, 69.46897193363735, 65.11119379316057, 69.98888478960309, 64.30619634900773, 70.1490616117205, 61.696564129420686, 67.83083684103829, 33.413452761513845, 36.168215479169575, 66.65534060341972, 55.99092926297869, 70.84234591892788, 64.50144072941372, 64.69683102199009, 59.49770941053118, 60.39853640965053, 56.412097794669016, 51.34349809374128, 47.65475852148873, 50.59760897500174, 50.66736194065639, 58.13995497567313, 61.78491742270333, 65.83682891300747, 68.4891995021275, 67.97567204066685, 63.20911053248814, 61.99588557652065, 64.2932379586356, 65.39577116285051, 65.56720406668526, 64.43427249363491, 62.746353558131624, 56.93550212042672, 56.362557138715474, 62.03710229056222, 64.76363100324357, 70.97111688341413, 72.23325715746198, 70.29920523507255, 70.13287230900356, 70.59394087110246, 67.80664321354458, 70.41205092838833, 70.75436088017055, 64.96653924669538, 72.94635772705078, 69.54804243360246, 28.830493927001953, 0.6833558199661118, 0.4446315126759665, 0.020390121499076486, 0.06096114670591695, 0.032610348891466856, 0.35618683429700987, 0.5427471878273147, 2.6369214866842543, 29.09453763280596, 23.364806413650513, 97.68631512778146, 52.81580400466919, 9.596934403691973, 33.753768580300466, 51.38919986997332, 44.28617456981114, 0.5140559045331818, 0.2122960061367069, 0.04228040250018239, 0.011746576870791614, 0.1392645492617573, 0.014364628753225719, 0.0213256228182997, 0.07342431508004665, 0.04382490087300539, 0.044110689644834826, 0.014784190703981688, 0.04744904461715903, 0.01336694902939988, 0.07703211970095124, 0.016000529185735753, 0.021087568985032182, 0.02713208276379321, 0.04193816640015159, 0.031372582273823876, 0.06187119787292821, 0.03721843965883766, 0.05979210550763777, 0.021991878049448133, 0.12723520903715066, 0.019315749506599138, 0.06380990134286028, 0.026598606657769, 0.0724548174600516, 0.05541716615802475, 0.20540344741727623, 0.1020072770438024, 0.09934558772615024, 0.1495654708040612, 0.17941419913300446, 0.22198809177747794, 0.13412138952740602, 0.10447987222245761, 0.10021285726023571, 0.15512226548578056, 0.14292018381612642, 0.1531325022556952, 0.17659048922359943, 0.1469537623758827, 0.13727071482156003, 0.14059947191604547, 0.14217091830713408, 0.18741845605628832, 0.07428302828754697, 0.17755337112716266, 0.17677629925310612, 0.13471034435289247, 0.21353613744888986, 0.12859240121075086, 0.14195015015346663, 0.16821666141705854, 0.2905042645122324, 0.2184083310088941, 0.15197193595979894, 0.08165622728743724, 0.3839362838438579, 0.2715966962277889, 0.32162331896168844, 0.16479160663272652, 0.5668499459113393, 58.10490478788103, 93.6872307913644, 80.2930771963937, 41.766038622174946, 49.31047255652291, 101.54588658469063, 54.033416748046875, 13.878903354917254, 0.28925543438111034, 0.7792376492704663, 0.3831680193543434, 0.4269243542637144, 3.242620710815702, 6.705944001674652, 0.46093231226716724, 0.34982437427554813, 3.514077058860234, 66.78426442827497, 103.84206472124372, 92.16226100921631, 83.3723451069423, 82.40967914036342, 74.4975152696882, 72.08312048230852, 82.82044969286237, 87.21667916434151, 82.71769278390067, 70.52430602482387, 72.47403308323452, 79.84909425462995, 80.20902483803886, 77.36218806675502, 69.05968829563686, 64.86204528808594, 63.37706238882882, 64.44646658216203, 64.09159428732735, 63.501942362104145, 62.089769635881694, 60.75297791617257, 55.86112649100167, 59.594261578151155, 58.150585719517295, 54.8263521194458, 53.658405099596294, 55.62705210277012, 67.32674503326416, 73.09823840005058, 71.49679674421037, 72.94097982134137, 68.90486158643449, 72.25606114523751, 68.7637436730521, 71.40602547781808, 38.35509845188686, 45.323623997824534, 68.99723093850272, 60.842567988804404, 72.50733579908098, 71.17576912471226, 67.15401281629289, 66.4103957584926, 64.67667429787772, 61.64238207680838, 56.79170915058681, 52.11587027141026, 53.65510123116629, 56.045899936131065, 62.80879007066999, 66.82848971230644, 70.30462482997349, 71.70680604662213, 71.16146973201207, 67.51453399658203, 65.1497562953404, 67.90489768981934, 72.1001922062465, 70.15332085745675, 68.31749561854771, 69.27926526750836, 62.15474918910435, 61.69134603227888, 66.33195754459926, 71.8966725213187, 78.17320265088762, 77.15818200792584, 73.69337940216064, 74.9958609172276, 76.79549298967633, 74.04675088609967, 75.40219157082694, 74.96015412466866, 68.2288018635341, 79.33351707458496, 72.15379755837577, 26.155126537595475, 0.6775920178209032, 0.41229256082858357, 0.6606695715870176, 0.3701542876660824, 1.4260491473334176, 0.8265621012875012, 0.6895822201456342, 2.474750748702458, 26.589203085218156, 41.815697397504536, 101.3518511908395, 35.79445798056466, 36.60660859516689, 76.51993438175747, 58.90315900530134, 63.216385296412874, 1.5482839196920395, 0.3532165065407753, 0.11825519161564962, 0.14910739181297167, 0.1985989896846669, 0.1561844984867743, 0.1091737671356116, 0.22233242115804128, 0.18753816320427827, 0.17410311555223806, 0.07357909570315055, 0.10521451530179807, 0.1338977850973606, 0.22151477288986954, 0.09589957978044238, 0.15353481923895224, 0.07270226561065231, 0.11264800892344543, 0.15718824176916055, 0.1278471119169678, 0.07969374116510153, 0.07873755640217237, 0.12750895720507416, 0.13636254998190062, 0.13501432804124697, 0.11125523437346731, 0.08417970580714089, 0.16799786101494515, 0.12035172911626951], [0.08559262606182269, 0.10361461115202733, 0.06919933536223002, 0.05495951125132186, 0.05837367554860456, 0.042980898304709365, 0.047858730490718565, 0.06559173430183105, 0.04850877043125885, 0.023787563300824592, 0.03211973075355802, 0.03322368348017335, 0.05798599456569978, 0.06362069863826036, 0.11285784587796245, 0.11656033327536923, 0.05108752241358161, 0.040141008727784665, 0.021861081942915916, 0.031225557305983136, 0.0735453792980739, 0.03173712181991764, 0.04814420035108924, 0.07990210569862809, 0.06792580655642919, 0.0365645218906658, 0.05018129139872534, 0.03595293792230742, 0.025550855290410773, 0.09507134636597973, 0.08231595331536871, 0.042961458276425085, 0.07186604583902018, 0.04155278565096004, 0.02615416282787919, 0.2880526360656534, 58.64337975638253, 72.56351893288749, 56.62602588108608, 35.15482766287667, 23.015101841517858, 68.09954452514648, 53.689077922276084, 16.478222710745676, 4.395684472152165, 0.29050011187791824, 0.1999451353081635, 0.13148163046155656, 0.38264530311737743, 0.1757628664906536, 0.5560596649135862, 0.08503495848604611, 0.05226991378835269, 13.059220024517604, 40.437834875924246, 63.35551602499825, 70.06118774414062, 87.33858530861991, 94.07338387625558, 81.16915471213204, 69.20437758309501, 72.87905747549874, 76.24473708016532, 78.91020502362932, 86.67893028259277, 74.30003356933594, 64.17044244493756, 67.20962619781494, 64.78522600446428, 65.27969455718994, 62.65121187482561, 61.23090975625174, 58.5548597063337, 55.41846023287092, 53.46043702534267, 58.61653191702706, 58.04385791506086, 57.38132286071777, 53.323647839682444, 50.31931277683803, 47.78569037573678, 55.46772990907942, 64.62038694109235, 62.98128604888916, 65.5357426234654, 64.49654224940709, 68.55598558698381, 64.34386253356934, 70.93195683615548, 35.170930113111226, 28.556945085525513, 57.24030222211565, 55.96050657544817, 62.961122376578196, 64.79514108385358, 62.13878917694092, 59.59985487801688, 59.09875079563686, 57.63023860113961, 55.32522235597883, 51.13735893794468, 49.415505000523154, 53.443393094199045, 60.869909150259836, 65.39726502554757, 65.19152886526925, 64.66348661695207, 65.36966678074428, 63.06001608712332, 65.18244062151227, 62.90376499720982, 62.791829517909456, 59.988780294145855, 63.846413203648154, 63.21573911394392, 62.528339930943076, 60.45775590624128, 63.588412693568635, 69.00427641187395, 66.6713353565761, 74.41469969068254, 72.784013066973, 72.32083920070103, 75.7690703528268, 72.32134641919816, 60.67803464617048, 62.854453631809776, 67.66732488359723, 30.979964324406215, 0.5983432531356812, 1.1636820201362883, 0.031256145664623806, 0.253333464797054, 0.19547273458114692, 0.16163085480885847, 0.050881020458681245, 0.3987481061901365, 6.219847593988691, 19.339379719325475, 34.07022428512573, 80.3353430884225, 16.800198759351456, 19.62990300995963, 54.376560483660015, 48.750690937042236, 52.8895070212228, 1.9658325484820773, 0.1262466920805829, 0.055817315221897194, 0.04803320559273873, 0.024447401287034154, 0.023578898515552282, 0.01288292370736599, 0.03326220730585711, 0.01825939431520445, 0.04610146049942289, 0.04099721135571599, 0.09473804996481963, 0.06748641441975321, 0.07237133051135711, 0.05300800721826298, 0.09126621019095182, 0.037224577008081336, 0.03564308151336653, 0.02490663548399295, 0.036588793088282855, 0.04893719744203346, 0.015261848823034337, 0.03711566874491317, 0.06205037182995251, 0.13494780446801866, 0.037859414371528795, 0.0957863594272307, 0.10196714169744935, 0.08806353847363166, 0.04243578362677779, 0.02251841443856912, 0.061482309097690244, 0.06021265472684588, 0.03649581004200237, 0.04578383486451847, 0.01912596495822072, 0.013245399658834296, 0.04437840563644256, 0.018394799370850836, 0.0707017747419221, 0.027501268578427177, 0.0808506365865469, 0.038964449361498864, 0.012059714844716447, 0.07291415174092565, 0.02991470228880644, 0.03739757629643593, 0.015561869866879923, 0.039194686471351554, 0.033332269439207654, 0.07376410506133523, 0.0384250479484243, 0.08352519092815262, 0.056451277275170596, 0.051251392013260295, 0.07310747993843895, 0.04856705998203584, 0.022043227883321897, 0.04030134994536638, 0.010875212377868593, 0.0545817640210901, 0.0412925505079329, 0.09549328658197608, 0.0403392461261579, 0.07645824192357914, 1.2369381806680133, 72.32365322113037, 75.00465038844517, 38.98309748513358, 22.00569360596793, 58.873886244637625, 98.29205213274274, 49.72669744491577, 27.7578501360757, 5.680696044649396, 0.7050104779856545, 0.07589452181543622, 0.2661812539611544, 0.8630223934139524, 0.21553933567234448, 0.8043385595083237, 0.24976779041545732, 0.32591228453176363, 18.497381380626134, 53.77060808454241, 74.10226699284145, 80.0717909676688, 97.4248057774135, 95.4981814793178, 76.88293606894356, 66.81771305629185, 74.17529950823102, 74.93070071084159, 77.22940799168178, 83.97737339564732, 75.12163025992257, 67.38384532928467, 70.14155755724225, 65.82489885602678, 65.43207550048828, 62.252003124782014, 60.65771116529192, 58.587147985185894, 55.86710888998849, 56.11121300288609, 57.185765811375205, 58.79744911193848, 58.026383195604595, 55.39010116032192, 52.308182512010845, 52.27398347854614, 60.69865689958845, 68.3997414452689, 67.20036424909318, 68.92048113686698, 67.55720288412911, 71.65693187713623, 66.36017417907715, 72.25425461360386, 39.20994574683053, 37.536944593702046, 60.40880584716797, 59.30732876913888, 68.4415557043893, 66.8727844783238, 65.35867473057338, 63.698604175022666, 61.764642579214915, 59.027948651994976, 56.84872954232352, 52.461449350629536, 51.16019766671317, 54.465938636234824, 62.766558919634136, 66.93923010144914, 68.1252111707415, 66.70726449148995, 65.26267841884068, 64.99171257019043, 68.15875012534005, 64.73682485307965, 65.95649078914097, 63.91427625928606, 66.72947093418666, 65.93966920035226, 63.55028097970145, 58.71147905077253, 63.31356280190604, 69.64369828360421, 70.09205164228166, 73.95271396636963, 73.54281888689313, 69.18899427141461, 69.56689289637974, 73.20262813568115, 64.24546909332275, 61.03795828138079, 73.32286671229771, 41.89977754865374, 2.203368876661573, 1.3827438482216425, 0.15835796828780854, 0.3933218073632036, 0.15977555007806846, 0.2621956749686173, 0.13691757805645466, 0.5935873197657722, 11.05625673702785, 38.03695433480399, 25.255223648888723, 93.50396510532924, 46.32679796218872, 7.49199674810682, 41.00633301053728, 52.255417891911094, 64.73178740910122, 4.177551857062748, 0.3141494185796806, 0.03974049664767725, 0.07330869949821915, 0.030028526538184712, 0.0526153559663466, 0.02163713824536119, 0.03472019924915262, 0.12255714434598174, 0.049258901072399955, 0.029659878462553024, 0.01576386804559401, 0.06300916895270348, 0.03927783754521182, 0.03725494823551603, 0.0440347446128726, 0.05473961162247828, 0.03473640266539795, 0.1425613880689655, 0.012572694104164839, 0.04091491184330412, 0.10515492635646037, 0.017221401977751936, 0.032998735550791025, 0.06916885556919233, 0.04124106666339295, 0.07329063689602272, 0.048647629230150154, 0.05057260254397988, 0.05746575498155185, 0.08745807489114148, 0.11035326455852815, 0.2729750722646713, 0.11881315096148423, 0.11458458857876913, 0.1445933561772108, 0.09498087729194335, 0.161438612267375, 0.12869290581771306, 0.16586711177868502, 0.08635340631008148, 0.1790051782237632, 0.10505317324506384, 0.15700317812817438, 0.1324376727321318, 0.15494723059237003, 0.10640129340546471, 0.08375962477709566, 0.12824742043656961, 0.0740174361105476, 0.14431921445897647, 0.09003304064806018, 0.1146228579538209, 0.10785683244466782, 0.13675395612205776, 0.1591434675667967, 0.17101716542882578, 0.09690588113984891, 0.14065180053668364, 0.1589608873639788, 0.19343693953539642, 0.18624745389180525, 0.1283606950725828, 0.14458192964749678, 0.14729963881628855, 1.5703384791101729, 91.71014867510114, 87.86432075500488, 75.90674195970807, 46.17907926014492, 40.636761801583425, 84.98591136932373, 70.78136157989502, 30.348359176090785, 6.078820007187979, 0.446178138256073, 0.19327403684811933, 0.6287485701697213, 2.118996684040342, 0.5720405759555953, 0.8527754289763314, 0.4537381040198462, 0.2999746591917106, 14.44842895439693, 48.24883992331368, 74.50301824297223, 82.07816668919155, 98.19191469464982, 100.27399103982108, 81.03400530133928, 67.79722145625523, 70.73658043997628, 77.682861328125, 83.43423271179199, 90.11598873138428, 78.21811580657959, 69.7958151953561, 75.5747709274292, 71.88337366921562, 72.58821283067975, 68.42360155923026, 66.4504451751709, 65.87289701189313, 61.41283443995884, 61.14771897452218, 64.48104776654924, 62.862256458827424, 63.14750780378069, 59.53941249847412, 56.82289613996233, 55.508050305502756, 64.48604352133614, 71.65975979396275, 70.42658655984062, 72.4773473739624, 71.62319837297711, 74.75097860608781, 69.17790494646344, 74.02540602002824, 46.32411248343331, 40.5059689113072, 62.04835837227957, 63.520403725760325, 67.60458959851945, 72.27701691218785, 69.25647517613002, 67.43283012935093, 66.56483336857387, 63.37146214076451, 61.083128520420615, 58.538913590567454, 54.464208534785676, 59.305834906441824, 65.8984385899135, 72.72395978655133, 73.58539049965995, 72.02462359837124, 70.7635394505092, 69.62550789969308, 74.4208835874285, 71.05098642621721, 69.53522995540074, 69.80365971156529, 73.38827705383301, 70.36416394369942, 70.7701471873692, 64.38169547489711, 72.93385791778564, 76.18471854073661, 75.24939373561314, 78.06697859082902, 77.71054295131138, 72.55115113939557, 72.39294760567802, 73.24199662889752, 66.20900222233364, 66.93625627245221, 76.68013204847063, 39.58263322285244, 1.6848349124193192, 1.0410269903285163, 0.29046420380473137, 0.6944385224155017, 0.2934369742870331, 0.9012926912733487, 0.3192769991500037, 0.5815416947007179, 10.294154865401131, 33.080599308013916, 47.68900619234358, 91.95492676326207, 30.72346462522234, 27.14190796443394, 74.60535131181989, 59.0964856828962, 79.95834772927421, 6.024267963000706, 0.4101778657308647, 0.1806094657097544, 0.18924094683357648, 0.09180460737219878, 0.12586706530834946, 0.1454008264201028, 0.13641420006752014, 0.12060966741825853, 0.10365963195051466, 0.22171378721083912, 0.12545338964888028, 0.18065979943743773, 0.16661297104188375, 0.16436512023210526, 0.15486028311508043, 0.1909465260271515, 0.08042818746928658, 0.24802156697426522, 0.08066976629197598, 0.14958217633622034, 0.16367015109530517, 0.11859040148556232, 0.12612797559372016, 0.20612099819949695, 0.12479830480047635, 0.14548382482358388, 0.18956661650112697, 0.14379701390862465, 0.27610024171216146], [0.03560009292726006, 0.019116438326558897, 0.0971490205930812, 0.08748382529509918, 0.04513801880446928, 0.04848892667463847, 0.07902829508696284, 0.023472229417945658, 0.03789560064407332, 0.03013486654630729, 0.030036373795675378, 0.01188778764169131, 0.06334429739841393, 0.06164492001490934, 0.013104483202498938, 0.07853766677102872, 0.0762599604204297, 0.05803750894431557, 0.08099860471806355, 0.07941404903041464, 0.09051465801894665, 0.09393079006778342, 0.009892849733919969, 0.0662442407171641, 0.030703238012003045, 0.03220056463032961, 0.0535034531328295, 0.04479093796440533, 0.027698104801986898, 0.04860800278506108, 0.10385470398302589, 0.03647764226687806, 0.0728452465097819, 0.03496656852907368, 0.07505670070116009, 0.041323705443314145, 1.34107962676457, 71.96660614013672, 65.15917110443115, 66.42994104112897, 41.186249664851594, 6.70466640165874, 54.78887006214687, 66.98173223223004, 27.27800406728472, 11.883339030402047, 0.501220030444009, 0.7941240019031933, 0.015784614253789186, 0.26243481785058975, 0.12543892328228268, 0.02410302440901952, 0.37285534558551653, 0.11262320168316364, 0.10786234893436943, 1.5282620340585709, 6.981533442224775, 14.04186293057033, 31.329403127942765, 65.77398940495083, 93.17917156219482, 85.07771096910749, 73.96800000326974, 70.46553121294293, 70.43583461216518, 76.84136499677385, 82.5935423714774, 67.07965319497245, 67.54850373949323, 63.52110549381801, 65.12951619284493, 62.929494176592144, 63.05900165012905, 61.25596496037075, 65.32856123788017, 64.26122065952846, 63.72982937949044, 63.01326165880476, 58.62253516060965, 53.966102600097656, 50.960360527038574, 50.4775892666408, 59.196185384477886, 62.4838228225708, 63.24242714473179, 62.66876302446638, 67.63328565870012, 65.69496754237584, 66.92383289337158, 43.66739927019392, 19.87598214830671, 60.777998379298616, 59.04763289860317, 64.06744929722377, 64.79810101645333, 63.443396840776714, 58.78358745574951, 60.79866232190813, 58.50073323931013, 56.9864775793893, 51.27311979021345, 46.81627423422677, 54.64569548198155, 58.75675351279122, 63.18112318856375, 65.08363028935024, 64.2472061429705, 68.45370115552629, 65.95140470777238, 62.62855379922049, 63.35127067565918, 64.45885522024972, 64.69878346579415, 66.092501776559, 65.75151198250907, 67.48569202423096, 66.09794221605573, 63.414679936000276, 69.46360792432512, 79.55032866341728, 80.39515318189348, 78.81878062656948, 76.73030499049595, 67.3912660053798, 71.93328952789307, 77.45691285814557, 58.21218497412545, 10.084747450692312, 0.35845400978411945, 0.03995553457311221, 7.900286793708801, 2.52483640398298, 0.10214736059840236, 0.4364450419587748, 0.15134705949042523, 0.03084541145446045, 12.622418914522443, 18.42873838969639, 35.803924901144846, 77.38108716692243, 9.671526789665222, 31.485487461090088, 63.52353736332485, 47.7869028363909, 53.65868650163923, 3.696636199951172, 0.3099046934928213, 0.04598752429176654, 0.0503199703858367, 0.035025329661688635, 0.059843300974794796, 0.02182765561155975, 0.06619363557547331, 0.05708091027502503, 0.11223172768950462, 0.04126819449343851, 0.034122158839766464, 0.06569057649799756, 0.06066526472568512, 0.017553802712687423, 0.02127021534501442, 0.027549982303753495, 0.04749428254685231, 0.050413482689431736, 0.030452166484402757, 0.08228617241340024, 0.05564575442778213, 0.07243005771722112, 0.1296486495328801, 0.057586323869015486, 0.08150583678590399, 0.041187007778457234, 0.0738852507035647, 0.1032144044126783, 0.05228648700618318, 0.036454439761915376, 0.0542831543300833, 0.061719898134469986, 0.0918155928541507, 0.0458448181993195, 0.0557874902151525, 0.031684467502470524, 0.04026894650555082, 0.060241546747939925, 0.055369190339531214, 0.038989816393171034, 0.034576682307358296, 0.020160386505137597, 0.04517401847988367, 0.06510426117373364, 0.03400929132476449, 0.042222866123276095, 0.06326803006231785, 0.0478647389183087, 0.05125226053808417, 0.052600845494972806, 0.09649504854210786, 0.021972650063357184, 0.07923090564353125, 0.05406003844525133, 0.07462967147252389, 0.09969484327094895, 0.0628567903435656, 0.04669174864622099, 0.08258716376232249, 0.03457832775477852, 0.04242264040346656, 0.07025753786521298, 0.037274598609656096, 0.010617867794020899, 0.03219699892880661, 0.13078637634004864, 4.270751084600176, 88.29444898877824, 66.71260070800781, 52.99221529279436, 18.55920124053955, 23.88429890360151, 92.85121658870152, 62.44849123273577, 36.19395508084978, 18.88611398424421, 0.5725992002657482, 0.7755059780819076, 0.18632366694509983, 0.46084372273513247, 0.23029714663113865, 0.03707961139402219, 0.15909876567976816, 0.2023709522826331, 0.08085674340171473, 3.0385712257453372, 12.239043372017996, 21.399416378566197, 43.85507358823504, 80.51969964163644, 92.90032645634243, 78.23042106628418, 70.80262306758335, 68.86415903908866, 74.66747515542167, 78.39765725816999, 77.49434280395508, 66.8467217854091, 64.88096523284912, 63.32205350058419, 64.90228230612618, 63.53806604657854, 61.873222078595845, 60.82936641148159, 66.37884398869106, 64.22673674992153, 66.00872734614781, 64.04481901441301, 59.32269818442208, 53.96807588849749, 51.632904461451936, 52.799850940704346, 63.34120968409947, 63.55793789454869, 67.81742681775773, 65.90168339865548, 70.20105498177665, 66.57315036228725, 67.51625714983258, 45.596802847726, 26.041106598717825, 63.79909597124372, 61.140874998910085, 67.09585639408657, 68.3004377910069, 65.88844013214111, 62.7538298198155, 63.419154575892854, 63.12065301622663, 60.29120758601597, 53.142365864345, 48.849449157714844, 55.94106898988996, 61.1406318119594, 65.90913186754499, 68.74054363795689, 68.19900798797607, 70.67722197941372, 68.48872702462333, 65.14323888506208, 65.4871608189174, 66.22190502711705, 66.97494384220668, 69.6693788255964, 67.97518566676548, 65.70263835362026, 65.4427409853254, 65.34427111489433, 69.11644118172782, 71.84467915126255, 70.76760414668492, 71.25174072810582, 71.67306559426444, 72.14092254638672, 69.13782773699079, 74.26944759913853, 67.98366941724504, 16.790622404643468, 0.39360747060605455, 0.2846766800752708, 11.143565194947378, 3.759965556008475, 0.10246450786611863, 0.7392235164131437, 0.28787678693022045, 0.11847743897565774, 23.95265007019043, 32.32919331959316, 24.60657630647932, 98.3770980834961, 31.545808247157506, 12.219771674701146, 48.10264982495989, 49.695951666150776, 64.71763392857143, 5.802701200757708, 0.4160626913819994, 0.113560217831816, 0.081589669787458, 0.023910810705274343, 0.038221891171165874, 0.022998913923012357, 0.035391565545329025, 0.08993629512510129, 0.08331185951828957, 0.016827001801824996, 0.0005682048535423487, 0.03389393358624407, 0.018909245962277055, 0.022076815366744995, 0.002182604154638414, 0.0357260290267212, 0.014297996614394444, 0.042065985434289486, 0.05767725434686456, 0.022313763187932115, 0.028000127524137497, 0.1510289894150836, 0.06655949487217835, 0.07462055874722344, 0.05710699316114187, 0.05906840041279793, 0.07254494048122849, 0.0442735109079097, 0.03941173964579191, 0.03949431735756142, 0.15335966220923833, 0.1567803200866495, 0.2808542751840183, 0.15354345020438942, 0.15397498490554945, 0.0957323412543961, 0.13836101203092507, 0.170839429966041, 0.0632654923413481, 0.06977127252944879, 0.23849802943212645, 0.11672432161867619, 0.27692439034581184, 0.13063167035579681, 0.13551841170660087, 0.1475877176438059, 0.12785977338041576, 0.1908619398517268, 0.14821878235254968, 0.1367564531309264, 0.10808328672179154, 0.12856929030801567, 0.14537342717604979, 0.22739932712699684, 0.14630230090447835, 0.12466675043106079, 0.14825887020145143, 0.11049016578389065, 0.13996432242648943, 0.10937792475202254, 0.1382106893828937, 0.16038114258221217, 0.10113787012440817, 0.13751318252512387, 0.14183637340153965, 0.20520036188619478, 4.823609692709787, 104.10411603110177, 81.50392586844308, 87.52157306671143, 55.74169043132237, 16.765235424041748, 69.16828863961356, 81.50131334577287, 43.33055060250418, 18.51149664606367, 0.9467657740627016, 1.0732464385884148, 0.14275000723344938, 0.9624371102878025, 0.23752297461032867, 0.17466851164187702, 0.7588179792676653, 0.19815777907414095, 0.30808505256261143, 2.5582090360777716, 11.155763626098633, 16.99072183881487, 38.02950586591448, 74.49527100154332, 99.08075605119977, 87.72393935067313, 74.05759007590157, 70.70939213888985, 75.70935753413609, 82.27590547289167, 88.67599541800362, 72.01184586116246, 72.54688494546073, 69.25814274379185, 70.36858994620187, 68.62026337214878, 67.70199639456612, 65.7834667478289, 74.1952269417899, 71.6608715057373, 73.09130409785679, 71.10757950374058, 66.12023898533413, 62.06027453286307, 56.78797796794346, 55.428170340401785, 66.78602232251848, 67.96682003566197, 71.57574912479946, 69.34336239950997, 72.72375134059361, 70.8735294342041, 70.928941317967, 50.19480800628662, 30.69802032198225, 67.27788530077252, 67.34264945983887, 68.96806240081787, 72.65935543605259, 70.49221229553223, 68.32155336652482, 71.10946246555874, 69.11344650813511, 66.77696881975446, 58.90169293539864, 53.65327385493687, 63.13586957114083, 66.54416247776577, 70.87368924277169, 71.73482118334088, 72.16501195090157, 77.37324959891183, 73.35920579092843, 68.28208065032959, 71.60689789908272, 73.35856655665806, 73.44721862248012, 75.55060509272984, 74.55170427049909, 74.56078556605748, 73.57632310049874, 73.05108792441231, 77.9620885848999, 81.81847776685441, 76.78101294381278, 76.28631510053361, 78.0989680971418, 79.34931032998222, 80.5371813092913, 80.6070454461234, 66.99617058890206, 15.162572622299194, 0.2248288464865514, 0.1980100077177797, 13.437297565596444, 5.085464715957642, 0.09888455710772957, 1.1764335930347443, 0.1734768141593252, 0.14675484304981573, 19.6464900970459, 31.2021746635437, 47.879998275211875, 93.48436423710415, 24.769905873707362, 41.97863612856184, 84.13527815682548, 61.55448041643415, 80.65482820783342, 9.269600425447736, 0.5621941100273813, 0.2698591851762363, 0.17580185511282512, 0.1306663706366505, 0.15708054469100066, 0.053857695910015276, 0.1307977485869612, 0.18680534538413796, 0.16728406931672776, 0.10217674795006003, 0.14939473782266888, 0.15476517964686665, 0.10731235558965377, 0.13319708912500314, 0.09055477300924913, 0.1202028856745788, 0.11600518306451184, 0.07948954962193966, 0.245214331895113, 0.12341888381966523, 0.13295810909143516, 0.29870886568512234, 0.20317659048097475, 0.1657741524811302, 0.085514553822577, 0.13490515175674642, 0.13605232377137455, 0.18605844117701054, 0.18762924974518164, 0.17902417720428535], [0.20960121788084507, 0.07026395002113921, 0.05313559215781944, 0.15150989432420048, 0.03199652236487184, 0.13471856819731848, 0.04687420671273555, 0.0896074092015624, 0.028589014496122087, 0.03141346400869744, 0.04965892121461885, 0.05593291723302432, 0.06032445015651839, 0.026501806852008616, 0.09627527104956762, 0.042076794497136555, 0.12915793300739356, 0.057834816963544915, 0.05198561440088919, 0.10359581573201077, 0.07957915695650236, 0.06649554294667073, 0.06627025574977909, 0.03420431246714933, 0.062019199931195805, 0.10003232623317412, 0.06880157134894814, 0.05314362261976514, 0.04437605790527804, 0.03935679866533194, 0.04091656746874962, 0.08267896276499544, 0.045617916089083464, 0.08592107093759946, 0.04708776543182986, 0.030321731697767973, 0.03000169726354735, 4.763202922684806, 78.96544320242745, 70.69826112474713, 60.49084322793143, 48.90251949855259, 11.338985017367772, 45.628076689583914, 86.77494743892125, 39.39349978310721, 22.251777955463954, 5.637119114398956, 0.12528514010565622, 0.5386056814874921, 0.12922646504427704, 0.22885889666421072, 0.11072664202323981, 0.866421311029366, 0.7509848081639835, 7.620907545089722, 10.176854508263723, 2.2129465341567993, 0.027369807507576685, 0.4695335850119591, 13.358167137418475, 48.421728474753245, 81.81823457990373, 92.0392848423549, 85.94187232426235, 76.42561258588518, 69.8785126549857, 72.60940483638218, 78.18976715632847, 73.49049895150321, 74.37340654645647, 68.39374514988491, 70.77085590362549, 69.18289375305176, 69.52627372741699, 71.67519869123186, 67.7730347769601, 62.59265940529959, 62.604513032095774, 59.756126812526155, 57.804030418395996, 51.435127462659565, 55.0687643459865, 56.05727413722447, 61.06776605333601, 61.18915803091866, 66.14819853646415, 62.18217372894287, 68.8729554585048, 45.50454814093453, 21.379388196127756, 64.0800394330706, 60.926203455243794, 66.00770596095494, 64.17226982116699, 63.23017747061593, 60.936021259852815, 57.8429924419948, 56.7219283921378, 58.88673346383231, 52.91503470284598, 47.7984333719526, 53.826780796051025, 56.51014035088675, 61.36333547319685, 64.58875179290771, 68.61727564675468, 61.55958039419991, 62.14338888440813, 66.79287324632917, 64.96469797406877, 64.55435820988247, 62.286966460091726, 68.4647626876831, 65.23408658163888, 66.22334330422538, 68.419189453125, 78.64677797045026, 84.43956756591797, 85.72072505950928, 78.72356946127755, 68.91495731898716, 59.71321473802839, 50.157833167484824, 43.34587485449654, 15.072959968021937, 0.7140969304101807, 0.2662913394825799, 0.4920809237020356, 7.784122467041016, 4.784507402351924, 0.279471610805818, 0.31723205745220184, 0.6682676981602396, 0.9364148037774223, 15.482608386448451, 20.130143778664724, 48.65336404527937, 80.13988331386021, 7.736355338777814, 24.203551258359635, 57.87900842939104, 51.915237562997, 38.4953339440482, 1.7637737223080225, 0.1677984938557659, 0.04488690995744296, 0.14165857008525304, 0.08149894965546471, 0.029456185642629862, 0.06947104113974742, 0.02087937238892274, 0.010462987935170531, 0.036471850970493894, 0.007644713091264878, 0.044421496002801826, 0.043463329917618206, 0.02777371395911489, 0.06026959738561085, 0.02356621839239129, 0.0845082321071199, 0.07301856470959527, 0.0573317375300186, 0.0685295873720731, 0.017880091543442438, 0.026173194038814733, 0.09568947141191789, 0.04298571251066668, 0.06165338134659188, 0.11640460948858943, 0.055265364303652725, 0.09762955230793782, 0.07176830286958388, 0.015702715077038323, 0.09324297269007989, 0.10605541017970868, 0.13990602269768715, 0.04386199977514999, 0.046269842356975587, 0.0716746650370104, 0.04803377556215439, 0.08270104907985244, 0.0352401165291667, 0.058567797632089684, 0.05522741384005972, 0.03888694030631866, 0.04750649956986308, 0.04733597014897636, 0.03575461570705686, 0.10824030651045696, 0.10008396274809327, 0.03372939223689692, 0.07458636736763374, 0.032966369430401495, 0.029306422785988877, 0.08732664265802928, 0.17542450821825437, 0.023762963013723493, 0.13447375276259013, 0.061100266740790436, 0.007963774675902511, 0.03915924319465246, 0.03719468754050987, 0.02058652006754918, 0.04584685719705053, 0.040539179862077744, 0.04569358970703823, 0.05842088122985192, 0.026253883726894855, 0.12352310679852962, 0.05059050229777183, 0.14322884939610958, 0.23701467045715877, 9.120293191501073, 92.94612898145402, 71.5309749330793, 44.61673164367676, 16.056041479110718, 18.719824484416417, 84.14979294368199, 82.69234575544084, 39.896525042397634, 38.29109859466553, 8.656453166689191, 0.37299050976123127, 0.6657206948314394, 0.5294601150921413, 0.09618385202650513, 0.14349127959992203, 0.5870328343340329, 1.3986182021243232, 7.689446313040597, 8.517816628728594, 1.9006755990641457, 0.22628621757030487, 1.5297399376119887, 26.11936937059675, 66.7431171962193, 85.69020162309918, 86.50516278403146, 79.38490595136369, 76.42212459019252, 76.10045078822544, 73.86965520041329, 77.07226058415004, 69.76637567792619, 71.325850214277, 66.32184096745083, 67.68217318398612, 65.73550333295549, 64.34034674508231, 67.08254364558628, 66.65301990509033, 65.69870567321777, 65.19122314453125, 62.99293122972761, 60.15710040501186, 56.45759459904262, 59.100314140319824, 60.99240589141846, 66.054995400565, 66.98598452976772, 73.92285755702427, 66.36421803065709, 71.05318205697196, 51.36317886625017, 28.12889436313084, 68.93407876150948, 65.82069519587925, 67.08010482788086, 67.4621445792062, 69.7404727935791, 66.2662831715175, 64.26350661686489, 60.57834884098598, 63.127462250845774, 54.855631828308105, 51.72923081261771, 57.35979734148298, 61.82145799909319, 63.68170615604946, 66.60370853969029, 68.90256173270089, 63.875262124197825, 63.78663785117013, 70.81966005052838, 65.49820150647844, 68.45029653821672, 65.80350535256522, 67.22900472368512, 68.09312438964844, 70.66172749655587, 65.98712539672852, 70.6743106842041, 75.41914517538888, 82.72161156790597, 76.94388566698346, 71.95354352678571, 67.25096103123256, 58.974774088178364, 56.896199635096956, 25.901939392089844, 2.6405655997140065, 0.4985106129731451, 0.8481865780694144, 10.046283091817584, 5.944935602801187, 0.6364390860710825, 0.2712901883891651, 0.6963252840297562, 3.5021912966455733, 32.25655337742397, 26.409216948917933, 30.251654148101807, 106.49578326089042, 25.039266688483103, 9.154873507363455, 51.63451991762434, 53.64545713152204, 52.22148983819144, 3.8950150864464894, 0.22544506484908716, 0.032566457853785584, 0.004694757076712059, 0.051821337680199316, 0.10208636708557606, 0.058136941465948305, 0.06321788632443973, 0.04803160425009472, 0.0392655017785728, 0.027174016227945685, 0.04629439175395029, 0.028734400801892792, 0.029323895062719072, 0.05552926014310547, 0.05503560895366328, 0.018195659520902803, 0.03735620262367385, 0.02229840454778501, 0.13176650660378592, 0.03584360218207751, 0.038811989328158755, 0.10470954954091992, 0.07248795711036239, 0.04946577961423567, 0.1589262413659266, 0.06648054053740841, 0.1870612752224718, 0.02028114877508155, 0.032302962349993844, 0.005154341143289847, 0.10861946509352752, 0.4062157097671713, 0.13002484291791916, 0.07831180281937122, 0.22405972704291344, 0.11863240280321666, 0.15280053578317165, 0.047871510697794814, 0.2518316496695791, 0.11551826633512974, 0.12054162392658846, 0.10760605268712554, 0.14875468931027822, 0.10291447157838515, 0.18907138093241624, 0.11878391967288085, 0.19576212976660046, 0.1456493330853326, 0.19269747207207338, 0.08216109805341278, 0.22128123470715114, 0.21051101120454924, 0.21022206385220799, 0.17249459400773048, 0.12114845136446611, 0.1494664182620389, 0.1393523109810693, 0.1485034685049738, 0.1318730908845152, 0.18360446499926703, 0.11825897784105369, 0.11165027067597423, 0.17260965997619288, 0.15959301058735165, 0.19939463984753403, 0.1482713281043938, 0.3853674499051911, 0.1948018805789096, 10.715672544070653, 108.35753222874233, 85.86064788273403, 79.89164502280099, 62.05384744916643, 21.8832038130079, 60.49460915156773, 100.71067142486572, 56.96341303416661, 35.74141890662057, 7.650539006505694, 0.3136367718023913, 0.7032907988343919, 0.5968028700777462, 0.34138657418744905, 0.23461889901331492, 1.7458655003990446, 2.3467280183519637, 12.19985466344016, 11.183093496731349, 1.7008660350527083, 0.22640102569546017, 0.8311165911810738, 17.405918393816265, 56.12212862287249, 88.25501796177456, 95.18089199066162, 89.87002944946289, 80.74787153516496, 75.15926170349121, 79.37106513977051, 86.10443237849644, 78.69422721862793, 79.80863489423479, 72.46689033508301, 75.30627168927873, 72.58148002624512, 72.01518099648612, 74.955748966762, 74.35825947352818, 69.34463391985211, 70.85763890402657, 68.10796574183873, 67.47465828486851, 61.285126549857004, 64.03685637882778, 65.93896048409599, 70.99115548815045, 72.39727633340019, 76.55646800994873, 70.18844400133405, 73.97100857325962, 59.56139659881592, 34.19131401606968, 71.88777882712228, 71.21612426212856, 69.43781621115548, 72.02173314775739, 72.97186456407819, 72.13919939313615, 68.06610284532819, 65.59110586983817, 68.3182738167899, 60.92377158573696, 55.20504283905029, 63.06544263022286, 66.49788747514997, 69.40946756090436, 72.75138432638985, 75.79769693102155, 68.08550221579415, 68.22185366494315, 81.29747404370988, 69.88443946838379, 70.74921226501465, 71.7232107434954, 76.67781829833984, 75.65737806047711, 78.54329150063651, 75.35001059940883, 79.61635739462716, 87.7907462801252, 94.43421077728271, 84.53378513881138, 75.17190047672817, 63.92360768999372, 58.36497933523995, 51.37003673825945, 18.482793637684413, 1.8758803009986877, 0.3057656298790659, 1.3279619706528527, 11.24856550352914, 7.625707013266427, 1.8968614723001207, 0.47537712859255926, 1.0772594575371062, 1.7885968131678445, 24.12850202832903, 31.317799636295863, 62.36980288369315, 93.8335668018886, 20.272446359906876, 36.71218647275652, 76.12779194968087, 64.38347421373639, 67.4843510219029, 6.83411351272038, 0.4857664225356919, 0.1519009204847472, 0.20676138597939694, 0.2067324939583029, 0.1819066482463053, 0.11668290384113789, 0.16420859577400343, 0.14812091046145984, 0.21321061705904348, 0.13763370391513619, 0.0724912683612534, 0.13111957774630614, 0.1055705426260829, 0.08754692905183349, 0.1287407832486289, 0.27000127040914124, 0.15964508136468275, 0.11653978723500456, 0.25422826249684605, 0.09625867408301149, 0.07410225977322885, 0.18567804087485584, 0.11392250124897275, 0.1406958374593939, 0.18257600947150163, 0.1551074327102729, 0.23116181737610272, 0.12179177041564669, 0.11330965520547968, 0.11701064982584544, 0.19792966917157173], [0.06424826210630791, 0.059801638924649785, 0.0652591028649892, 0.09993371473891394, 0.07977398471640688, 0.043063767786536894, 0.06885767940964017, 0.08326164792690958, 0.08178047383470194, 0.07587107843054192, 0.011108046580505158, 0.04078503345538463, 0.06052286736667156, 0.08877044982675995, 0.057542694067316394, 0.05767456056284053, 0.07128322497010231, 0.09427743325276033, 0.054106708083833964, 0.0483327346986958, 0.05324677012062498, 0.06847088730760983, 0.07641282078943082, 0.03907476558483072, 0.0689534003447209, 0.05685115492503558, 0.07060840832335608, 0.020201051108805195, 0.0780329384974071, 0.05150694526465876, 0.03693561947771481, 0.0485093471860247, 0.06638046340750796, 0.05796920082398823, 0.003307100377112095, 0.036807766516825983, 0.0862440061090248, 0.11370444045002971, 7.430237684931074, 70.8459381375994, 70.70024136134556, 70.01299503871373, 57.998350688389365, 11.36421913760049, 31.610760007585796, 101.45711639949253, 53.17990698133196, 29.769602026258195, 14.029562882014684, 2.891524327652795, 0.6253194713166782, 0.04009735517735992, 0.14687839070601122, 0.1696881188877991, 0.2593448507998671, 11.781501020703997, 36.680572169167654, 36.288464478084016, 12.846475737435476, 0.32454823915447506, 0.0673589991139514, 0.12110222955899579, 3.3907052789415633, 21.46412147794451, 47.40582888466971, 78.02346897125244, 89.24132169995988, 76.61306108747209, 76.18778269631522, 78.61084883553642, 77.89958259037563, 78.98269557952881, 78.6298382622855, 75.24912275586809, 77.91937105996269, 76.09442670004708, 71.85811696733747, 70.79449367523193, 65.76805564335415, 63.14828600202288, 59.65907437460763, 54.2695825440543, 51.621961048671174, 53.6571683202471, 60.18662330082485, 57.65572806767055, 62.77447986602783, 67.26865809304374, 66.82031863076347, 38.35000889641898, 4.482272054467883, 63.694247654506135, 60.24452958788191, 67.41869749341691, 65.30982889447893, 61.763510022844585, 58.3422726222447, 54.33855731146676, 55.54722424915859, 55.893230642591206, 52.32609149387905, 48.17169407435826, 51.00592333929879, 59.660470962524414, 58.69119725908552, 64.04880033220563, 63.988712310791016, 72.59459822518485, 66.76342678070068, 59.382883480616975, 74.91986846923828, 73.56251008169991, 69.77857671465192, 63.71835790361677, 66.49640056065151, 71.95373112814767, 80.50157179151262, 83.84264087677002, 74.46843011038644, 50.41093519755772, 22.138388565608434, 8.586201667785645, 2.246674392904554, 1.1925746926239558, 0.18236022176487104, 0.2691703907081059, 0.015138601418584585, 0.12761528364249639, 0.47754474942173275, 1.772227400115558, 0.27874861817274776, 0.21899386601788656, 0.05747346992471388, 11.921571493148804, 16.687629256929668, 22.751982246126445, 64.97307750156948, 60.162582533700125, 4.063813754490443, 28.34581364904131, 50.92602947780064, 44.46769973209926, 51.715303148542134, 1.6752841791936328, 0.1519426911004952, 0.05395180871710181, 0.057043319434991906, 0.041450801837657175, 0.08357258659920522, 0.05567458198804941, 0.06431627167122704, 0.014196434340971922, 0.04764450680730598, 0.027487148264689103, 0.03274389476116214, 0.019140365167653987, 0.12292125980768885, 0.028002017244164432, 0.052274582109280994, 0.0722249908638852, 0.06817345826753549, 0.05634939184944544, 0.06850563508591481, 0.010399832440141057, 0.03968512140480535, 0.06254119692104203, 0.21181022934615612, 0.07884295324661902, 0.1293574765856777, 0.15354469870882376, 0.05118925856160266, 0.16531345434486866, 0.17402255987482412, 0.1376801428518125, 0.10646108591130801, 0.049982212616928985, 0.07818623312882014, 0.09116286252226148, 0.07739752437919378, 0.058831401701484404, 0.05482869648507663, 0.021784517747749175, 0.06403174836720739, 0.12792495345430716, 0.13236341385969094, 0.11089580080338887, 0.049048945374254665, 0.05118023404585464, 0.05578385666012764, 0.08210845052131585, 0.05372582941449114, 0.06353904373411622, 0.08760228393865482, 0.11199639138898679, 0.05772711310003485, 0.05552127039326089, 0.13472361649785722, 0.01743409047568483, 0.06332771400255816, 0.11881950204925877, 0.05589156730898789, 0.022163605084642768, 0.040033315042299886, 0.0185746196324804, 0.025665398786908815, 0.06744701867657048, 0.07635677379689046, 0.07045951059886388, 0.09602877963334322, 0.059388797863253524, 0.030168579558708837, 0.10230760342840638, 0.09481475156332765, 0.3373360186815262, 12.459527083805629, 88.23710550580705, 70.67404665265764, 58.39866420200893, 25.41168318475996, 11.467729926109314, 70.13977881840297, 103.50077615465436, 39.34374720709664, 38.97876180921282, 27.020213740212576, 3.1234148102147237, 1.0614662021398544, 0.026403839966016154, 0.134096392297319, 0.24040710127779416, 0.35152955991881235, 16.443021399634226, 44.90177454267229, 37.41825199127197, 16.672320638384136, 1.233033401625497, 0.08550816880805151, 0.22621281365198748, 11.5222133568355, 38.88847344262259, 64.41444928305489, 85.51352282932827, 83.19746589660645, 70.18194048745292, 74.22593103136334, 78.56664439610073, 78.29002271379743, 74.68265002114433, 75.72486591339111, 70.35363047463554, 77.15956469944545, 75.65880938938686, 71.62342766353062, 69.26261738368443, 65.58187866210938, 61.29559053693499, 60.82398155757359, 56.825960295540945, 57.21279777799334, 58.485301290239605, 63.93099362509591, 62.52604007720947, 65.92910099029541, 68.7800371987479, 70.71426282610211, 44.98938437870571, 8.970843519483294, 67.53267574310303, 62.18317426953997, 72.38597161429269, 69.77212183816093, 66.90209197998047, 62.600198200770784, 60.54957635062081, 62.49914360046387, 61.66428279876709, 58.00177615029471, 50.44216387612479, 54.23556416375296, 62.50056103297642, 63.45264489310128, 69.36379705156598, 71.37750312260219, 72.26036902836391, 69.06141144888741, 63.50640310559954, 73.53512028285435, 75.8620719909668, 71.49954128265381, 68.218594959804, 67.87629890441895, 68.81096363067627, 75.28621918814522, 81.02905123574394, 80.27823584420341, 61.818664823259624, 37.5740236554827, 19.57694557734898, 7.620077235358102, 4.9201922586985996, 1.1432125185217177, 0.323419699711459, 0.032547506370714734, 0.6474094231213842, 0.555081977375916, 0.9588983058929443, 0.5896621303898948, 0.2671378254890442, 0.15329617847289356, 15.51816405568804, 27.5877617086683, 17.29126443181719, 45.60489402498518, 91.80423423222133, 15.413694415773664, 10.335970861571175, 44.62735196522304, 48.485853399549214, 63.8958009992327, 3.6044108058725084, 0.2877659685909748, 0.07804979330727033, 0.09161505182938916, 0.11188141363007681, 0.08891640949462142, 0.052702086312430244, 0.02182075321408255, 0.011822215713826674, 0.0329723439312407, 0.020384608402049968, 0.07207771483808756, 0.025256762946290628, 0.04839288343542388, 0.042362498452088664, 0.022894892808316008, 0.04248558809714658, 0.04474972714004772, 0.07016165408172778, 0.042004693366054974, 0.04873780992680362, 0.0017556883685756475, 0.02235743879074497, 0.05735378313277449, 0.048120661971292326, 0.06371057060148035, 0.11831501126289368, 0.10342092333095414, 0.12439572997391224, 0.06719655783048697, 0.16409127706927912, 0.0940649432263204, 0.032302212568798234, 0.14225345530680247, 0.18388577204729828, 0.16830856219998427, 0.23781276334609303, 0.17349550101373876, 0.0750488161242434, 0.10289594757237605, 0.21196588527943405, 0.177317240940673, 0.21804585760193212, 0.14758937326925142, 0.1640791312924453, 0.12522833315389498, 0.16934220173529216, 0.13593400083482265, 0.23731987550854683, 0.15872284370873654, 0.17411234362849168, 0.11653316473322255, 0.20977557423923696, 0.23297478152172907, 0.12289886815207345, 0.19532121771148273, 0.1412389911711216, 0.1708928985255105, 0.13806430223797048, 0.18696913016693933, 0.1072264394855925, 0.17030559932546957, 0.10915153832840067, 0.16241180790322168, 0.1800650634935924, 0.14122540690004826, 0.17414076067507267, 0.054872115940919945, 0.18391813816768782, 0.16905151733330318, 0.3761139693004744, 13.389705879347664, 100.94801494053432, 89.29578168051583, 86.42629378182548, 74.77438013894218, 19.564376286097936, 48.7094464302063, 113.15733391898019, 66.63149438585553, 44.023171356746126, 23.098148448126658, 3.4906540300164903, 0.80482053650277, 0.09600001653390271, 0.430913081658738, 0.7379363626241684, 0.4540151905800615, 18.20577069691249, 50.479500021253315, 47.32400689806257, 16.596199648720876, 0.6104307845234871, 0.1722728487636362, 0.20073898056788103, 5.345182299613953, 27.321324348449707, 52.03995425360543, 83.7020023890904, 93.34225273132324, 78.87098939078194, 80.08023302895683, 83.96760422842843, 84.7227691922869, 84.67132472991943, 86.47634860447475, 79.63895293644497, 86.50905377524239, 84.37872219085693, 81.80151721409389, 77.96657712118966, 74.01934719085693, 69.55251012529645, 69.76369367327008, 64.76271384102958, 62.819483348301475, 65.09578963688442, 69.83569090706962, 67.61133629935128, 71.92237390790666, 76.28817026955741, 75.19054249354771, 46.62197133472988, 8.125902618680682, 70.32430907658168, 68.02914537702287, 77.73078305380685, 76.65446540287563, 74.02769197736467, 70.62031623295375, 65.72203077588762, 70.22815295628139, 68.79632377624512, 63.85678686414446, 56.55524805613926, 61.769151960100444, 68.0295900617327, 69.20548234667096, 71.18999903542655, 75.16414628710065, 82.50744029453823, 80.04088538033622, 66.28365366799491, 80.79279163905552, 81.98578344072614, 77.55894020625523, 71.66155242919922, 72.37749481201172, 76.14516939435686, 87.70853519439697, 93.26594066619873, 88.0403950554984, 57.40309156690325, 26.918698821749004, 11.696111134120397, 4.034568786621094, 2.2452293847288405, 0.6226221046277455, 0.3379006140998432, 0.13879393094352313, 1.0410519604172026, 1.2717125032629286, 3.9487346495900835, 1.4943020620516367, 0.5602205502135413, 0.14049215481749602, 15.72166463306972, 25.965833289282664, 30.53439371926444, 78.13584913526262, 73.00906521933419, 14.539979287556239, 41.0508952822004, 65.05226612091064, 58.088100569588796, 78.13359097072056, 6.194656465734754, 0.5993808146033968, 0.1499264242925814, 0.2657556767974581, 0.3045156326677118, 0.1588604370398181, 0.1572509655462844, 0.12609912428472722, 0.09684212598949671, 0.09975907339581422, 0.1314947126167161, 0.13447322350527557, 0.07792688347399235, 0.20207724161446095, 0.13359058515301772, 0.1322698574513197, 0.10330921611083405, 0.2472138660294669, 0.153761857056192, 0.1357678954622575, 0.1524618382432631, 0.1142860467412642, 0.20296272981379712, 0.31687140251908985, 0.21116232339824947, 0.16275704652071, 0.17829639411398343, 0.22352991332965239, 0.2914334775081703, 0.28531691857746666, 0.18737135215529374, 0.19243577468608106, 0.08226221334189177], [0.08041935294334378, 0.055393831338733435, 0.1619596050253936, 0.047464321833103895, 0.10749883736882891, 0.03427899203130177, 0.10634397755243949, 0.06947774506573166, 0.09467650683862822, 0.13186641409993172, 0.03815940488129854, 0.09399865714034863, 0.061039911050881655, 0.07610752074314014, 0.06254335466240134, 0.03492429579741188, 0.21237478405237198, 0.07681255933961698, 0.16436217539012432, 0.13101272205156939, 0.07186586263456515, 0.11203272693923541, 0.10209409559943847, 0.027922547222780328, 0.017043642766241516, 0.06050073355436325, 0.08917247503995895, 0.004814388737681189, 0.08555274177342653, 0.02478805131145886, 0.09799161180853844, 0.055115591268986464, 0.05398629525942462, 0.01679215393960476, 0.031918629937406094, 0.07367517626179115, 0.030680351025824035, 0.13048184982367925, 0.17150752911610262, 1.609694812979017, 40.05543034417288, 69.4365655354091, 59.77062770298549, 69.42794976915631, 21.187234027045115, 29.37019177845546, 88.08621147700718, 81.25495106833321, 32.45548030308315, 16.93000500542777, 15.120497805731636, 0.23461083801729338, 0.39958566267575535, 0.04775812749617866, 0.49320512052093235, 1.1994075945445468, 3.5659481840474263, 14.505935720035009, 20.429814372743877, 5.349544031279428, 0.267915670893022, 1.4037740911756242, 0.10117086728236505, 0.10778999674533095, 0.07650167495012283, 5.414120154721396, 31.65109430040632, 74.56530884334019, 90.60630226135254, 88.049455506461, 86.04667895180839, 85.51739297594342, 83.40792683192662, 82.19160992758614, 82.97431060246059, 79.7399172101702, 76.34448541913713, 69.96624755859375, 67.23319448743547, 62.74498476300921, 59.07228510720389, 54.3006375176566, 51.67627511705671, 49.93850980486189, 52.835734912327354, 58.195974826812744, 63.536474909101216, 60.56147166660854, 65.46992928641183, 26.540001153945923, 0.33616565433996065, 47.296592780521934, 64.80825233459473, 60.564278738839285, 62.20986230032784, 56.62528589793614, 54.33934245790754, 55.18110629490444, 54.13878617967878, 57.26585422243391, 53.55841704777309, 49.864556653159006, 48.05613163539341, 54.861489159720286, 58.13234322411673, 63.07642773219517, 66.34144878387451, 72.37022004808698, 72.51499271392822, 75.95701912471226, 68.97008432660783, 59.65550994873047, 65.47647448948452, 74.59568636757987, 79.98973274230957, 73.16883209773472, 55.77712277003697, 29.584741728646414, 10.289503914969307, 1.310532523053033, 0.24477222561836243, 0.8316310835736138, 0.17910319939255714, 0.21466152848941938, 0.13414475827344827, 0.7275522255471775, 0.7169704447899545, 1.218765492950167, 0.2938002890774182, 0.13465235675019877, 0.9673822735037122, 1.315615673150335, 13.671924335615975, 34.302075249808176, 48.76117924281529, 82.75558825901577, 48.68958500453404, 14.660464525222778, 45.124012674604145, 45.616097995213096, 54.66100583757673, 41.051287855420796, 1.1043936929532459, 0.13724780747933046, 0.03687158952068005, 0.05343180662021041, 0.0654820559014167, 0.03442396103803601, 0.052695725046630414, 0.062156922183930874, 0.06787100128297295, 0.041409872605332305, 0.07020660702671323, 0.058707209437021186, 0.03657909682286637, 0.07188632046537739, 0.08406928780355624, 0.05161458806001714, 0.0749958496806877, 0.03287327442584293, 0.031085521248834472, 0.04978570548285331, 0.05950655761573996, 0.053092535718211105, 0.06439531421554939, 0.026608808431774378, 0.04861140224550452, 0.18089515609400614, 0.1303648025329624, 0.16722540317901544, 0.20996804748262676, 0.1958342580390828, 0.17755377824817384, 0.11959425333355155, 0.044730395677366426, 0.05602722002991608, 0.0683777719470007, 0.051639812599335394, 0.09478701983711549, 0.05662340803870133, 0.039730922518564124, 0.0405087306031159, 0.0754966288805008, 0.0697124774700829, 0.06521539163908788, 0.061717312916048934, 0.06513455776231629, 0.10759917912738663, 0.06420125998556614, 0.06398154356117759, 0.03908011583345277, 0.04191504192671605, 0.08049227510179792, 0.08618503463055406, 0.08055541957063334, 0.07301582342811994, 0.07021512264119727, 0.11382693637694631, 0.05584658382992659, 0.024084271397441626, 0.012809379841201007, 0.03909298764275653, 0.08711073281509535, 0.07170577586761542, 0.020928846073469946, 0.019880947124745165, 0.039185393934271166, 0.02134752762503922, 0.04413047233330352, 0.0443708026515586, 0.02173908643557557, 0.07151814736425877, 0.037546341706599505, 0.10383551501269851, 0.16894148609467916, 3.809635187898363, 62.56241389683315, 76.93415124075753, 57.52160699026925, 34.642988613673616, 11.018390791756765, 56.11923122406006, 107.2755378995623, 63.02303777422224, 25.127734627042496, 37.98115335191999, 19.417875255857194, 0.29868883533137186, 0.5907102770039013, 0.06614522210189275, 0.6969064899853298, 0.9426378927060536, 7.784490721566336, 23.24682252747672, 28.417030947549, 12.144956077848162, 2.083814480475017, 2.1263229080608914, 0.10518963342266423, 0.10269020896937166, 0.5109231897762844, 14.262745295252119, 51.942356382097515, 85.39049107687813, 88.7469504220145, 81.11846760341099, 79.21170820508684, 79.71790531703404, 80.34184660230363, 80.09328174591064, 77.49881049564907, 77.60751506260463, 74.93018654414585, 73.20149557931083, 71.34759112766811, 71.45726844242641, 67.14329869406563, 63.478881290980745, 60.6116862978254, 59.66864204406738, 63.092596190316335, 67.40036119733537, 72.06129619053432, 66.77858080182756, 66.56671633039201, 34.31721190043858, 0.2234069492135729, 55.910875592912944, 68.20386477879116, 65.34464631761823, 67.27174309321812, 65.04196194240025, 63.298332350594656, 62.638274329049246, 61.51674474988665, 63.71350111280169, 59.314026832580566, 56.172694138118196, 55.52920062201363, 62.336548805236816, 59.06034115382603, 65.62217821393693, 64.21873242514474, 77.31296702793666, 77.21350356510708, 77.09433501107353, 75.31964002336774, 64.34163216182164, 64.08916241782052, 69.68080166407994, 75.89700058528355, 76.01238237108502, 66.63664994921002, 42.963776043483186, 23.9691572529929, 5.269311010837555, 0.7210220588105065, 0.2936886836375509, 0.23877047481281416, 0.6696460470557213, 0.9732414505311421, 1.5563299336603709, 0.9952749482222966, 1.9416319727897644, 0.7311506867408752, 0.11863758681075913, 1.0193779234375273, 2.195667667048318, 29.70470585141863, 49.720715045928955, 28.50858736038208, 71.29462500980922, 81.34531933920724, 16.31668404170445, 18.537726095744542, 39.09244128635952, 60.17707647596087, 53.1383706501552, 2.701770109789712, 0.04418844636529684, 0.058633758021252494, 0.09820910263806581, 0.00045401923125609756, 0.006846525631512382, 0.03474588179960847, 0.013892451500786203, 0.016459100114713823, 0.015614771849608846, 0.03806784675855722, 0.021021566187430705, 0.02621899006356086, 0.0554179464732962, 0.07953690458089113, 0.02337486982079489, 0.041898645127990415, 0.036645667893545966, 0.01789408123918942, 0.072201187855431, 0.061743823279227526, 0.07427636507366385, 0.060499057572867186, 0.05140809289046696, 0.0346386834446873, 0.055894281449062486, 0.06447173761469976, 0.06926238483616284, 0.02402562731211739, 0.20263393888516085, 0.04159555032051035, 0.09134806187025138, 0.009879919400970851, 0.05732649923967464, 0.13673806483192102, 0.10976918161447559, 0.18412245863250323, 0.1684542300977877, 0.15489992313086987, 0.173942180616515, 0.12707864386694773, 0.1971561121089118, 0.18624563541795525, 0.2563847010689122, 0.17484506645372935, 0.19189581008894102, 0.13720671539860113, 0.1456933564373425, 0.1438482975853341, 0.10431886943323271, 0.19387661665678024, 0.10846498981118202, 0.1961599277066333, 0.14541788479047163, 0.1625026230301176, 0.17577814709927353, 0.16443268874926226, 0.09083777639482703, 0.16891612245568208, 0.13103956489690713, 0.19965044754956449, 0.1749185925083501, 0.1809190133852618, 0.15139047216091836, 0.2570133501929896, 0.13173282412546022, 0.16341783106327057, 0.12040468198912484, 0.10166581786636796, 0.13968608235674246, 0.1247381323150226, 0.2209553886204958, 0.37479657999106814, 4.519788418497358, 69.07457828521729, 93.83073888506208, 74.50572804042271, 83.31674562181745, 30.904440879821777, 47.78299100058419, 101.19962310791016, 93.34025165012905, 44.13613516943795, 30.595836639404297, 20.24028835977827, 0.39068170902984484, 0.7882386062826429, 0.11267303329493318, 2.0514873351369585, 3.0377413502761295, 10.229150993483406, 27.887738023485454, 48.62951782771519, 12.664355635643005, 0.9934429036719459, 2.322434727634702, 0.2577174524111407, 0.18379689753055573, 0.13687298473502907, 7.696813140596662, 39.14039427893502, 84.25739969526018, 98.75367655072893, 91.02270085471017, 89.04012966156006, 89.21482821873256, 88.56975746154785, 88.30857467651367, 86.98175362178257, 87.20868178776333, 84.95367172786167, 81.42218726021903, 79.42570577348981, 79.22060189928327, 76.16356822422573, 72.42613915034703, 68.38212081364223, 67.53729629516602, 70.36733927045549, 76.11806447165353, 79.32361589159284, 68.29419136047363, 73.33504690442766, 35.41198396682739, 0.31396181721772465, 56.024086066654746, 76.01427922930036, 70.52369458334786, 73.1486336844308, 71.57785442897251, 69.04718153817313, 69.69157137189592, 68.05112947736467, 71.29204027993339, 65.39566693987165, 61.46219444274902, 60.11326422010149, 68.64782687595913, 67.92943177904401, 72.85737214769635, 73.48491954803467, 83.47297586713518, 85.33213315691266, 88.13870511736188, 77.58618409293038, 64.77582509177071, 68.58460521697998, 79.51811681474958, 86.5206572668893, 84.89689104897636, 66.90344687870571, 31.799917766026088, 12.533719948359899, 1.5854193270206451, 0.32480575676475254, 1.1949413142033984, 0.2035974178995405, 0.8625784143805504, 1.3735181604112898, 1.7360343422208513, 1.695364038859095, 4.569521886961801, 1.7279724776744843, 0.2185747077954667, 0.8923139359269823, 2.30291810631752, 22.341185637882777, 49.40465191432408, 60.15725326538086, 100.40418638501848, 63.977400643484934, 23.291136401040212, 59.932812554495676, 59.12511920928955, 73.4185573032924, 66.03707599639893, 4.163591623306274, 0.26052468749029295, 0.1476875301450491, 0.13091003256184713, 0.11170884181878396, 0.1168697045317718, 0.09558958427182265, 0.1398335958697966, 0.2924683248358113, 0.10317823171083416, 0.14753365197352, 0.12183426027851445, 0.06468882132321596, 0.1286517187420811, 0.16753078464950832, 0.07898329464452607, 0.18095383580241883, 0.11623618352626051, 0.1492617992418153, 0.1923723588032382, 0.2171260898134538, 0.16536562011710235, 0.19628335322652543, 0.13400616071053914, 0.08845584706536361, 0.20722302049398422, 0.30017591267824173, 0.1613523026130029, 0.19231042212673596, 0.3191751374730042, 0.19089148326643876, 0.16680502359356197, 0.10284282506576606, 0.15135286775018486], [0.06215818425906556, 0.07276795458580766, 0.10353506649179117, 0.09960739367774554, 0.24239814015371458, 0.07721534451203686, 0.11732454012547221, 0.23045814942036355, 0.09785025260810341, 0.19068434009594576, 0.14628130703100137, 0.17882037242608412, 0.12895115624581063, 0.07162126433104277, 0.09541453580771174, 0.13710333380315984, 0.10306344394172941, 0.08892894203641585, 0.07251783300723348, 0.20701579589928898, 0.14520010219088622, 0.10405880731663533, 0.04545115253755024, 0.06301695174936738, 0.05247121477233512, 0.12124834528991155, 0.05338116755176868, 0.08113884433571782, 0.09514974430203438, 0.09408491251191922, 0.10635122430643865, 0.07152424739407641, 0.05039377124714, 0.022183601511642337, 0.13605346371020588, 0.05078120456476297, 0.029822255285190682, 0.057423964009753296, 0.09781298067952905, 0.06960607639380864, 0.18000915220805577, 16.95472148486546, 79.71008164542062, 73.98152814592633, 69.30993461608887, 55.6048560823713, 21.391884531293595, 47.13589136941092, 99.97786576407296, 47.946551595415386, 37.83075264522007, 25.22044096674238, 4.788767516613007, 0.1920951772481203, 1.226045685155051, 0.23260166868567467, 0.2461103509579386, 2.9667993741376057, 6.415253954274314, 8.119348730359759, 1.839112171104976, 1.0930991790124347, 0.13690803785409245, 0.32516334471958025, 0.07031113534633603, 0.2004270308784076, 0.23343805809106144, 1.6964607685804367, 16.89438680240086, 47.8429331098284, 76.75781290871757, 89.91795117514474, 86.92896815708706, 87.60512515476772, 91.57570103236607, 90.27158669063023, 86.02010904039655, 73.46151801518032, 62.24552740369524, 57.05821425574166, 52.25899274008614, 46.08704342160906, 38.30731569017683, 40.14598274230957, 39.97554343087332, 55.849151270730154, 53.37068714414324, 64.49093505314418, 46.57624871390206, 2.8806736298969815, 0.3411800009863717, 21.688532658985682, 73.1109674998692, 54.881117820739746, 59.953212465558735, 52.18435519082205, 49.09377213886806, 47.029486656188965, 50.26112856183733, 45.66825117383684, 47.71025378363473, 44.45951475415911, 50.272245679582866, 53.2464359828404, 62.71330792563302, 64.36776433672223, 67.97892379760742, 68.9729539326259, 66.76601845877511, 65.6801678793771, 70.6102830341884, 85.31021853855678, 74.2152933393206, 51.97425556182861, 22.28683509145464, 9.394280638013567, 4.2982898354530334, 0.9759714411837714, 0.7076114384191377, 0.7140517671193395, 0.06533954997680017, 0.16093892550894193, 1.0406074928385871, 1.3209289823259627, 0.33883226982184816, 0.17703712811427458, 0.44274662381836344, 0.22303892539015838, 0.5010925201433045, 0.3762497034456049, 10.387542128562927, 22.030740124838694, 21.07480696269444, 47.67333453042166, 68.75063937050956, 35.43092475618635, 10.066488453320094, 54.47540903091431, 57.13310888835362, 59.16882337842669, 32.846358163016184, 0.3047176461134638, 0.09083956094192606, 0.08340654908014195, 0.004568289175430047, 0.06083352105425937, 0.046488459554633925, 0.09933153526591403, 0.008901622029952705, 0.05469658910962088, 0.013856863187226866, 0.026901738784675087, 0.04269207987402167, 0.04349938726850918, 0.08763856520610196, 0.06635949667543173, 0.11449605332953589, 0.12388047762215137, 0.08351936231234244, 0.1464808913213866, 0.1306358501315117, 0.060952624306082726, 0.06286473598863397, 0.031436561340732236, 0.042812662332185676, 0.07892330536352736, 0.18155771839831555, 0.08963061509920017, 0.15689835803849356, 0.208433526967253, 0.24012010810630663, 0.12962632573076657, 0.1297205335327557, 0.07097542112959282, 0.1398306917399168, 0.11478082090616226, 0.05516948391284261, 0.07446651772728988, 0.023430932080373168, 0.031715076217161756, 0.1898550617375544, 0.08541519593979631, 0.17675408401659556, 0.1370838327067239, 0.0682891688442656, 0.13812271053237574, 0.10798847502363579, 0.1139600785183055, 0.1661532907081502, 0.050094533911240954, 0.010854084493725427, 0.12858360739690916, 0.042715139886630435, 0.020105735598398105, 0.06021871404456241, 0.14910409413278103, 0.1184356819306101, 0.060446152197463174, 0.021008672325738838, 0.035121257549950054, 0.09438014988388334, 0.12433619531137602, 0.010859282071968275, 0.09077727821256433, 0.034943783323147466, 0.02010394087327378, 0.06723980765257563, 0.017955793999135494, 0.048463101631828716, 0.0872702563979796, 0.043914128227957656, 0.04897559913141387, 0.016081481806135604, 0.013505674665793777, 0.06221552725349154, 0.03995844888101731, 0.25002642082316534, 31.39360795702253, 90.44427721840995, 77.9845312663487, 51.64021396636963, 37.03670903614589, 35.82116338184902, 85.96026420593262, 92.90423134395054, 28.077220610209874, 47.40101725714547, 39.247709206172395, 9.156277912003652, 0.12901841263685906, 0.7513730387602533, 0.4755939883845193, 0.6804555984480041, 3.6072897485324313, 9.755871840885707, 6.684541812964848, 6.649139872619084, 4.097187689372471, 2.672685819012778, 1.5999146806342261, 0.38592873407261713, 0.0899130010179111, 0.6169850528240204, 8.338982156344823, 34.645621980939595, 67.51110853467668, 82.84068284715924, 89.89554323468889, 85.89943272726876, 84.39433479309082, 84.01165580749512, 85.08117117200578, 79.54650715419224, 71.06771768842424, 67.72286183493478, 64.00035054343087, 62.82817554473877, 60.6212192262922, 56.07506847381592, 57.271440574101035, 55.73681974411011, 65.0429277420044, 60.32587909698486, 64.74362019130162, 59.6859986441476, 5.991994449070521, 0.5174695870706013, 29.466403484344482, 78.00950309208461, 64.78663648877824, 68.93892860412598, 60.929788725716726, 58.140872137887136, 55.02375044141497, 59.68116964612688, 56.44096755981445, 56.27670519692557, 51.70411307471139, 54.79035002844674, 58.60323306492397, 70.64884553636823, 72.6837991986956, 76.53387246813092, 71.97367245810372, 70.73313413347516, 71.1920418058123, 68.15515095846993, 81.30458899906704, 80.04863262176514, 69.08090114593506, 39.3003557068961, 21.5787250655038, 11.635881543159485, 4.932720295020512, 1.1782681345939636, 0.5768550261855125, 0.2217040163065706, 0.47895230246441706, 2.789329354252134, 1.9142591101782662, 0.6213699632457325, 0.64730411448649, 0.49150834871189936, 0.7068532162478992, 0.6910378134676388, 0.5210402011871338, 15.205913748059954, 36.69933230536324, 18.026111125946045, 36.31557634898594, 93.11080128805978, 60.677916526794434, 11.042950068201337, 37.37639256886074, 59.48557090759277, 65.11470263344901, 44.38906002044678, 1.0585606609072005, 0.059663801320961544, 0.04934937693178654, 0.022790681703814437, 0.04280889307015708, 0.010135951867726232, 0.04922720670167889, 0.019474947392674427, 0.007080428526803319, 0.03888458918247904, 0.01760285740186061, 0.024845173782003776, 0.048234533718121905, 0.14684001276535646, 0.042276500923825164, 0.12810602730938367, 0.13991831775222505, 0.024079357107569064, 0.11348903272300959, 0.09807028794395072, 0.060799594303326945, 0.043309964040028195, 0.08363546643938337, 0.012623690251660134, 0.05320754401119692, 0.1379953087972743, 0.15541605757815496, 0.1549897747380393, 0.11576731582837445, 0.14115573492433342, 0.14636028850717203, 0.1022653646234955, 0.1456478267375912, 0.1119443273970059, 0.09232289956084319, 0.12643172858016832, 0.08792693580367736, 0.14486802715275968, 0.1218935778098447, 0.3541384999241148, 0.14256320654281548, 0.3123701369123799, 0.323885581855263, 0.20734308048018388, 0.25153491273522377, 0.21604413858481816, 0.2341434359550476, 0.2600502015224525, 0.12818730223391736, 0.17537911422550678, 0.22035417945257255, 0.16675174502389772, 0.1186938373638051, 0.11874617955514363, 0.21980263904801436, 0.23314959928393364, 0.17193322841610226, 0.16390747550342763, 0.1321394294500351, 0.24942996140037263, 0.2093313102211271, 0.16863686458340713, 0.20298586785793304, 0.18651050834783486, 0.1964243392327002, 0.1507407748805625, 0.19593377198491777, 0.12140970091734614, 0.11680300453943865, 0.12978749136839593, 0.12415164735700403, 0.08985788361834628, 0.14276524712996824, 0.1541842179638999, 0.15351406963808195, 0.49102669741426197, 39.461918694632395, 105.68641539982387, 93.2980899810791, 87.22005598885673, 64.53874560764858, 34.55574008396694, 61.94808891841343, 109.76844733101981, 58.021279743739534, 54.46217966079712, 39.53159870420183, 7.12410352911268, 0.2299706084387643, 1.268215822322028, 0.8530927119510514, 1.5843091351645333, 7.149006741387503, 17.009513241904124, 25.817887033735, 12.132729853902545, 2.577438827071871, 1.1561904507023948, 0.951779767870903, 0.19458302589399473, 0.2293907595532281, 0.29952204919287134, 2.6214072448866705, 20.54380304472787, 55.957841941288535, 82.40727506365094, 98.29273305620465, 96.61404827662876, 96.69710009438651, 100.51605238233293, 99.61307838984898, 91.31918743678501, 83.03254345485142, 75.30115781511579, 72.70073890686035, 71.44664464678083, 70.15318189348493, 64.6468665259225, 68.41787624359131, 60.79800224304199, 68.28208065032959, 62.9587391444615, 74.04408972603935, 59.821745600019185, 3.3175709290163855, 0.5668304041028023, 27.493957553591045, 87.01172120230538, 72.90930298396519, 76.7544777733939, 67.4234848022461, 65.61138766152519, 61.42836366380964, 68.97177968706403, 63.32659067426409, 66.27047988346645, 58.30516924176897, 64.7313288279942, 64.8628373827253, 78.86583382742745, 78.60708291190011, 80.88112408774239, 79.18770217895508, 76.20184585026333, 69.83919974735805, 75.20704446520124, 89.73240647997174, 82.75679029737199, 60.657155309404644, 27.425060953412736, 11.033810581479754, 4.945600518158503, 2.1791509304727827, 0.9994153146232877, 1.364090757710593, 0.3676949239202908, 0.5567048160093171, 2.25414131794657, 5.6021405799048285, 1.137049792068345, 0.9909921437501907, 1.778540272797857, 0.5451171749404499, 0.4999298911009516, 0.7319395244121552, 16.09666759627206, 35.9086412021092, 31.97885125023978, 60.22345570155552, 83.15394238063267, 46.275290966033936, 19.57857666696821, 70.89303997584751, 71.50274440220424, 76.39797960008893, 54.217200074877056, 1.7278208115271159, 0.2226649983120816, 0.13472942475761684, 0.06328461345817361, 0.13724326129470552, 0.07813308348080941, 0.19481988889830454, 0.1320775741977351, 0.10515553703797714, 0.12613486950950964, 0.07011534406670503, 0.09921465760895185, 0.0863263870456389, 0.1133404742660267, 0.13400275446474552, 0.179420658786382, 0.2214637334857668, 0.1441881622054747, 0.1858524243746485, 0.14266362972557545, 0.15133054394807133, 0.09424693988902227, 0.132525733006852, 0.08442708610423974, 0.21372996776231698, 0.2732331598443644, 0.3453814083976405, 0.17496501787432603, 0.13958126226706163, 0.16832206504685537, 0.14119131730071136, 0.26129219202058657, 0.17398177992020333, 0.10959815007767507, 0.2514623909124306], [0.06354419381490775, 0.07370549320642437, 0.17124307687793458, 0.22840384393930435, 0.0968984579667449, 0.2604218487228666, 0.16331953848046915, 0.29006880787866457, 0.1861936460648264, 0.27586801988737925, 0.13010098811771187, 0.07396496499755553, 0.13301630025463446, 0.1555646974593401, 0.15767681412398815, 0.16981432640126773, 0.07815830462745257, 0.07192380273980753, 0.09914512812559094, 0.08658866118639708, 0.058059900599930964, 0.07673080944057022, 0.08739210771662848, 0.0729839119261929, 0.0916498199637447, 0.06789960153400898, 0.055071164188640456, 0.08865684270858765, 0.022766388453809277, 0.030903836712241173, 0.07552039117685386, 0.07259810369993959, 0.06341541465371847, 0.02225613351246076, 0.013529886491596699, 0.03682623624003359, 0.009698060141610248, 0.06092140490987471, 0.039882751514336894, 0.05277632822149566, 0.06603209674358368, 0.18357512514506066, 6.408943687166486, 56.29084825515747, 73.95516668047223, 74.83090373447963, 50.226109640938894, 31.454460280282156, 37.37477363858904, 87.0181552342006, 67.25341374533517, 48.13765484946114, 32.78822953360421, 20.647428478513444, 7.5830885001591275, 0.18962687041078294, 0.3799361842019217, 0.08211488981864282, 0.0963289567402431, 1.3862708189657755, 6.342670900481088, 4.828536834035601, 6.255034574440547, 1.317586790238108, 0.18982315702097757, 0.41026762234313147, 0.21174807553844793, 2.5588604296956743, 3.818982252052852, 1.2774391216891152, 6.615635224751063, 21.57399681636265, 41.72183765683855, 56.68720824377877, 63.25484357561384, 61.55408436911446, 52.65459884916033, 41.222901412418906, 33.91286843163626, 28.264926195144653, 31.042581490107946, 30.647777897971018, 27.671219996043614, 25.70915641103472, 25.574620178767614, 41.221529143197195, 39.92828178405762, 30.37144456590925, 2.7959798659597124, 0.043011822538184266, 0.24589351830737932, 3.962633652346475, 58.50853606632778, 47.95987824031285, 51.32301480429513, 45.90355886731829, 43.614846570151194, 39.95720713479178, 40.19380371911185, 37.68997171946934, 39.62165778023856, 42.8756103515625, 47.61454929624285, 51.62035601479666, 55.253332819257466, 62.0916109085083, 68.66587829589844, 67.52374730791364, 72.75289903368268, 82.7804628099714, 64.86069733755929, 22.763875825064524, 4.249355844088963, 0.46030160039663315, 0.07649391929485969, 0.15042583963700704, 0.21868772458817276, 0.8304299137422017, 0.23429428786039352, 0.5567062816449574, 0.6291326752730778, 0.7610795636262212, 4.137849416051592, 1.3517631334917886, 0.9096625564353806, 0.47289423325232094, 0.16614794385220322, 0.03892131149768829, 4.831937977245875, 13.282328418322972, 29.606468745640345, 41.67069891520909, 76.64502280099052, 53.19081217902047, 20.149834973471506, 21.777549505233765, 50.94046088627407, 48.793856620788574, 46.18396036965506, 17.2424133845738, 0.11885446017341954, 0.06695581360587052, 0.10954778920859098, 0.11696062822427068, 0.1583042283143316, 0.04146593316857304, 0.03844601807317563, 0.015251190734228917, 0.05328484611319644, 0.02120952038759632, 0.025173963014302508, 0.03599400964698621, 0.03551839391833969, 0.0433167392121894, 0.0548723873549274, 0.06064856597887618, 0.1767266033483403, 0.10123471064226967, 0.09595249194119658, 0.05569832392835191, 0.05643764211397086, 0.021621523458244543, 0.0530437931551465, 0.006906591671785074, 0.01707754746478583, 0.15690184570848942, 0.03596713626757264, 0.11810869590512343, 0.15069582872092724, 0.33931644526975496, 0.31057125915374073, 0.1996189635246992, 0.240840739437512, 0.06612796695636851, 0.07530934643000364, 0.04940870803381715, 0.025427485749657665, 0.07300935020404202, 0.12781090528837272, 0.11938777512737683, 0.030252541481916393, 0.20909957694155829, 0.1127883910334536, 0.2751019538513252, 0.2086226346769503, 0.2270711197384766, 0.1307308314634221, 0.09156995639204979, 0.1396597009152174, 0.1874527492161308, 0.15911355774317468, 0.09093165171465703, 0.03035021320517574, 0.05433223955333233, 0.06296218040266208, 0.10776903679860489, 0.08405984938144684, 0.1580477827893836, 0.05978477732943637, 0.12338916398584843, 0.04211387982858079, 0.04293099205408778, 0.1100137120644961, 0.06502372585237026, 0.03752999579800027, 0.04474922502413392, 0.07427205637629543, 0.08004757003592593, 0.10289359984121152, 0.05507109633513859, 0.08623606046395642, 0.0123289778961667, 0.0456288913930101, 0.06405732235206024, 0.0747078862041235, 0.055566240301621814, 0.029606820416769812, 0.06197595689445734, 17.178410053253174, 73.96393530709403, 80.26379748753139, 73.93942901066372, 30.82392862864903, 20.00626608303615, 66.4235417502267, 105.41312190464565, 60.63196114131382, 43.714250973292756, 37.763379437582834, 30.800349916730607, 7.800918868609837, 0.2828882788973195, 0.8009611378823007, 0.06786332705191203, 0.19902025136564458, 1.3901968768664767, 2.5155004135199954, 5.2480573398726325, 3.840036162308284, 3.889901646545955, 3.2237478835242133, 1.2827838063240051, 1.7371475739138467, 2.0013093990939, 3.411652143512453, 5.133237489632197, 17.66525990622384, 43.11049420492989, 59.60683781760079, 72.82960019792829, 78.41267231532505, 75.51608644212995, 72.82680702209473, 68.29542813982282, 64.9522954395839, 63.43906116485596, 59.0694363457816, 54.98357943126133, 44.77272565024239, 41.872523239680696, 40.85305574962071, 62.19528497968401, 59.10219710213797, 53.31922183718, 7.811219573020935, 0.06378517552678074, 0.2088782659598759, 8.60412802015032, 73.80107648032052, 55.23709487915039, 65.51421015603202, 59.16247967311314, 61.24786336081368, 55.112065519605366, 53.77291488647461, 53.33161742346627, 56.97649996621268, 56.213184765407014, 61.88756316048758, 62.49625314985003, 61.625192233494346, 64.00321320125035, 67.81041608537946, 70.78085436139787, 72.01813398088727, 81.50407872881208, 79.18327617645264, 41.707777976989746, 13.983924508094788, 3.125912470476968, 0.4877453020640782, 0.23753665387630463, 0.23493012945566857, 0.7978092070136751, 0.5642187499574253, 0.304733008146286, 0.20507545715996198, 1.1862367412873676, 1.7555340273039681, 0.22950214786188944, 0.384114032877343, 0.7296840740101678, 0.11884907260537148, 0.025507498599056686, 9.436376299176898, 32.970036097935264, 36.07301126207624, 34.25899294444493, 72.13477339063371, 82.12737383161272, 29.850722244807653, 11.049817493983678, 34.266597747802734, 54.27067688533238, 55.547269412449424, 25.08911827632359, 0.32146497602973667, 0.05506925071988787, 0.04238976198913796, 0.050463280374450345, 0.11683159800512449, 0.05831887027514832, 0.02902891892673714, 0.08729709924331733, 0.031920672327812226, 0.06718588447464363, 0.02890713546159012, 0.029186311909662824, 0.07975184411874839, 0.02747645116012011, 0.03155518283269235, 0.0327247906077121, 0.0926945535466075, 0.05986780287431819, 0.10423853088702474, 0.12944640538522176, 0.11858468822070531, 0.03364045665200267, 0.05235243721732071, 0.014115841344131954, 0.13559276557394437, 0.12938263666416916, 0.0783071480691433, 0.15460724383592606, 0.20185343362390995, 0.18259481846221856, 0.38811380682247026, 0.16599897827420915, 0.08799003956041165, 0.10327283984848432, 0.02482368627430073, 0.009540125178838415, 0.21617667004466057, 0.2315436154603958, 0.23557359778455325, 0.31739325023123194, 0.21970624636326516, 0.3185080832668713, 0.1988935281655618, 0.33144766464829445, 0.3055141919425556, 0.2511448365237032, 0.2995369498218809, 0.20765576298747743, 0.2097418781902109, 0.26351518130728174, 0.2979448895369257, 0.22379846391933306, 0.11403540947607585, 0.1705704993967499, 0.1285700366965362, 0.15689529106020927, 0.161517933011055, 0.27739800778882845, 0.14024524949491024, 0.15734989595200333, 0.12414038367569447, 0.09356349906218903, 0.18915807056639874, 0.1519360143159117, 0.14446431238736424, 0.18501015885600022, 0.18477565715355532, 0.1254658339811223, 0.13333378678986005, 0.1060505315129246, 0.14962458477488585, 0.15776667930185795, 0.0766565166413784, 0.10880891885608435, 0.38662434103233473, 0.14323961096150534, 0.18917378543743066, 0.3703187645546028, 19.564480509076798, 84.84880256652832, 97.24358980996269, 90.73002883366176, 63.27726541246687, 44.25087077277047, 54.04966163635254, 105.25963619777134, 80.72089168003627, 62.67553751809256, 52.46502072470528, 33.99858488355364, 11.075897557394844, 0.30845143433128086, 0.914499316896711, 0.12667659829769815, 0.35342527819531305, 4.7276463849203925, 16.412808895111084, 17.37459765161787, 12.279504469462804, 5.455719453947885, 3.1670447204794203, 1.3183830103703906, 1.1289240909474236, 5.329700410366058, 4.781665589128222, 1.8271951419966561, 7.526219231741769, 25.88980610030038, 45.72439956665039, 66.60444504874093, 71.94222491128104, 72.55468777247837, 68.82964733668736, 70.38636343819755, 71.36197389875139, 71.91298689161027, 67.97931289672852, 66.54302992139543, 56.94330842154366, 55.07680688585554, 52.85544000353132, 70.07523700169155, 61.35841614859444, 47.32410069874355, 4.151018857955933, 0.09541531612298318, 0.5031923417534147, 8.032896637916565, 80.17984935215541, 61.93948010035923, 76.09936686924526, 73.38672065734863, 72.43094730377197, 65.92176369258335, 65.50571945735386, 63.84280708857945, 68.73098986489433, 67.04055568150112, 74.31103256770542, 72.87588214874268, 71.44348321642194, 75.71096951620919, 78.02493504115513, 74.22985676356724, 79.11660821097237, 91.64672551836286, 69.8431532723563, 27.528363295963832, 6.4583549329212735, 0.8982087224721909, 0.19810061928417, 0.2571976403040545, 0.22028021913553986, 1.459111607500485, 1.112088497195925, 0.6421831292765481, 1.1226331485169274, 2.8464663454464505, 14.353943875857762, 3.5519351874079024, 2.5222534111567905, 0.8454732522368431, 0.20191245259983198, 0.07315636160118238, 7.853071178708758, 22.456100157329015, 47.988525663103374, 57.02418892724173, 90.50299644470215, 64.11356449127197, 30.291074752807617, 31.303357805524552, 62.89470454624721, 65.922653062003, 70.77608789716447, 33.07673263549805, 0.6244479066559246, 0.11968979106417724, 0.13671776306416306, 0.2154039815068245, 0.21431774193687098, 0.15947783605328628, 0.1357984702501978, 0.2537644973823002, 0.11286906206182071, 0.17701937763818673, 0.11541981090392385, 0.13141255559665815, 0.14381468296051025, 0.11107211812798466, 0.1310584960239274, 0.11310093104839325, 0.29136339841144426, 0.14415895805827209, 0.1574040837585926, 0.21810742786952428, 0.2848902557577406, 0.19011342073125498, 0.18038773403636046, 0.09338557360959904, 0.2053067290357181, 0.2810112067631313, 0.12264850230089255, 0.273388110101223, 0.18805615683751448, 0.3754010461270809, 0.5710546917148999, 0.413303442299366, 0.25139339747173445, 0.17167389233197483, 0.17852028352873667, 0.19095525198749133], [0.05633409767012511, 0.026363972640995468, 0.08459490138505187, 0.14838515913912229, 0.16413268127611705, 0.07546002870159489, 0.07147034457219498, 0.14873959869146347, 0.13637408507721765, 0.16103732665734632, 0.1724829910589116, 0.050559690022575, 0.044750782262001715, 0.11190631586526122, 0.06048366839864424, 0.18269317889852182, 0.3145225042743342, 0.15501429699361324, 0.11515150458684989, 0.047593121350343735, 0.10024823607610804, 0.057341481292886395, 0.10215470234730414, 0.12222056383533136, 0.05459358749379005, 0.028477660114211694, 0.0749583945476583, 0.05450362053566745, 0.0654778964817524, 0.08428803392286811, 0.05392722878605127, 0.10308983216860465, 0.05560297958020653, 0.06493185899619545, 0.050745425413229635, 0.03177568296502743, 0.011980954740595604, 0.007958121631028396, 0.08093487670911209, 0.09595713990607432, 0.05976589369986739, 0.026534982125407884, 0.14548485619681223, 1.2662740179470606, 41.251389026641846, 73.1692281450544, 76.84643718174526, 74.06537900652204, 47.319834504808696, 28.571407760892594, 56.79101433072771, 71.0369232722691, 77.0389370237078, 50.12428726468767, 51.13441290174212, 23.8211658341544, 3.164754854781287, 0.24083384552172252, 0.23897034408790724, 0.23376589907067163, 1.3527672567537852, 1.871929598706109, 2.8067185240132466, 6.531969794205256, 4.994897987161364, 2.38071317757879, 2.9604252704552243, 52.34647056034633, 66.29497228349958, 9.773834671292986, 0.41119298126016346, 0.045642875999744446, 0.6399510747620037, 1.8102721529347556, 2.4190618055207387, 3.2797269139971053, 3.775049226624625, 4.31622747864042, 3.5281274020671844, 1.9012939887387412, 1.3934201896190643, 3.428187987634114, 7.692093576703753, 11.333648800849915, 13.174767698560442, 9.736521976334707, 2.715299120971135, 0.08107688051781484, 0.23062208348086902, 0.3601644065763269, 0.9125708660909108, 0.12683108715074404, 23.716527700424194, 49.13764306477138, 37.60004465920584, 35.617772238595144, 30.32995339802333, 24.42415656362261, 20.698918104171753, 20.21999614579337, 21.96091594014849, 27.353708165032522, 35.3917612348284, 42.296651703970774, 54.176313400268555, 67.62956837245396, 76.9385633468628, 78.34824861798967, 56.80830144882202, 21.945642062595912, 0.6693333781191281, 0.06571000295558146, 0.32124241654361996, 0.6480291155832154, 0.3574823204960142, 0.20143689454666205, 0.4448042948331152, 0.05562225676008633, 0.08004224353602954, 0.306379785495145, 1.8136336696999413, 0.9278735135282788, 0.582339597599847, 0.49947125571114676, 0.015776665216045718, 0.10268022771924734, 2.1228477231093814, 17.86417988368443, 13.47149051938738, 36.53360039847237, 63.13902405330113, 53.117199489048545, 29.47628034864153, 16.032801491873606, 45.504673208509175, 58.73004463740757, 55.59985337938581, 41.41618640082223, 6.75255903175899, 0.19304854609072208, 0.05928500236145087, 0.0925916333549789, 0.04697177326306701, 0.06868344518755164, 0.03632198633360011, 0.032711437038545094, 0.019852219648393135, 0.10984790524733917, 0.03308472290102925, 0.014864934674863304, 0.06680492777377367, 0.062989722139069, 0.022745911963284016, 0.05342605942860246, 0.023942408384755254, 0.05342088220641017, 0.011769686077189232, 0.04957869801936405, 0.01806505340417581, 0.036746406595089605, 0.08876439050904342, 0.06538982942168202, 0.02401889794106994, 0.009182585569630777, 0.08250528494162218, 0.038506434831236086, 0.05451160689283695, 0.1193094721862248, 0.2130161760640996, 0.10954194702208042, 0.20914468594959804, 0.09363007013286863, 0.08704456208007676, 0.05306424420060856, 0.05376568316881146, 0.06880451619092907, 0.07270005358649151, 0.10759009354348693, 0.05575210461392999, 0.19215556686478003, 0.1352000023637499, 0.08954070920922927, 0.10334711229162556, 0.25618162910853115, 0.15732276812195778, 0.2848303275448935, 0.16339035039501532, 0.0729131678651486, 0.05225054839892047, 0.05983111448585987, 0.08363534430308, 0.011752347811125219, 0.22851748498422758, 0.196176144693579, 0.03943355115396636, 0.05468227541340249, 0.09709656983613968, 0.09192901676786797, 0.10596933122724295, 0.020521864161959717, 0.03218990145251155, 0.0381594761274755, 0.07531358048852001, 0.026284928400335566, 0.13144473172724247, 0.10328501955206905, 0.06498497471745525, 0.07710747101477214, 0.04050026587875826, 0.11277275080127375, 0.06076093816331454, 0.04013056268117257, 0.06369265727698803, 0.027541997642921548, 0.08982853697878973, 0.15905106466795715, 0.08373100417000906, 0.015321938187948294, 0.44241316456879887, 4.245190399033683, 59.17006710597447, 83.79887417384556, 77.98979105268205, 59.957284109933035, 28.496125766209193, 36.71876989092146, 72.37516021728516, 85.22561032431466, 69.12640489850725, 46.872707503182546, 59.11345318385533, 33.51513964789254, 5.660718670913151, 0.2968837150505611, 0.20597165264189243, 0.17156956078750746, 0.5180093752486365, 1.008023047021457, 1.485243022441864, 6.286273675305503, 6.839539621557508, 2.770479108606066, 3.674210888998849, 38.408439772469656, 36.8860581942967, 3.9822792496000017, 0.6734477430582047, 0.38533325174025124, 4.967814343316214, 7.314874138150897, 10.340812018939427, 11.244555524417333, 11.952436259814672, 14.928036178861346, 19.238434553146362, 17.934337581907, 27.036486421312603, 28.860887084688457, 31.12161030088152, 31.46071365901402, 30.136779580797466, 22.80617298398699, 8.929566877228872, 1.111948339002473, 0.4166268253965037, 0.35410210330571446, 1.2859260205711638, 0.396116530256612, 46.39301776885986, 66.47932188851493, 53.89387607574463, 52.999608176095144, 48.39589854649135, 45.496439593178884, 44.831632477896555, 43.29700122560774, 44.38314710344587, 48.16508633749825, 52.21645934241158, 59.45053114209856, 70.06052766527448, 77.14398683820451, 79.3107269832066, 76.05824742998395, 72.47093418666294, 36.988884585244314, 4.07943069934845, 0.0834080350718328, 0.13020595748509678, 0.7244273275136948, 0.8350917750171253, 0.5601715328437942, 0.0928171444684267, 0.0506224952239011, 0.09299027267843485, 1.2627556238855635, 1.1701080181768961, 0.48680192125695093, 0.5678261678133691, 0.699810728430748, 0.036181251385382245, 0.3990070622946535, 2.5110164369855608, 26.88287912096296, 22.632297788347515, 25.484823397227697, 60.77890164511544, 78.45231178828648, 51.9685754094805, 13.590391567775182, 22.986673286982946, 48.26915645599365, 62.877000536237446, 52.25448335920061, 10.67112590585436, 0.2697318105825356, 0.0403073142681803, 0.20548061041959695, 0.019912214018404484, 0.016548149354223694, 0.021155819429882934, 0.07111020532569715, 0.06340544697429452, 0.010931222050982927, 0.06438251704509769, 0.032248150291187425, 0.027617350653080002, 0.07239343039691448, 0.029427609140319482, 0.01980528368481568, 0.04983177801061954, 0.012437371320889463, 0.025232873424621563, 0.054028798692992756, 0.08608502535415546, 0.046660434255110364, 0.045846718097371716, 0.03276487845661385, 0.03210861295727747, 0.03523113951086998, 0.05282868737620967, 0.19331861659884453, 0.11269212048500776, 0.16783060213284834, 0.31301143392920494, 0.23917219468525477, 0.23913927216614994, 0.13759342607642921, 0.04548987653106451, 0.04908172879368067, 0.14203878039760248, 0.012840167519503405, 0.12994453151311192, 0.13692984596959182, 0.20988707111350127, 0.20604515155511244, 0.3093675108892577, 0.11412655029978071, 0.1886617493416582, 0.339561287845884, 0.2815335158790861, 0.2630148838673319, 0.3077001060758318, 0.3121552313012736, 0.09575857341821704, 0.23162058847291128, 0.18368165514298848, 0.19576521031558514, 0.38831571170261925, 0.330113311963422, 0.11160537879914045, 0.11277368717959949, 0.1380148506058114, 0.13045147859624454, 0.17179159101630959, 0.14063277441476071, 0.18972126820257731, 0.12424357528133051, 0.15209773635225637, 0.14330730161496572, 0.1359155989651169, 0.16353638470172882, 0.12117449353848185, 0.17433179542422295, 0.13879812428993837, 0.23330433240958623, 0.13971650786697865, 0.10893017306391682, 0.1273704817784684, 0.09019480339650597, 0.31772339822990553, 0.33942283956067903, 0.18962777964770794, 0.169171292334795, 0.30729670343654497, 5.025562993117741, 68.45734201158795, 99.51943056924003, 94.38803999764579, 90.19852638244629, 62.90283393859863, 46.622732162475586, 73.66597570691789, 86.91250092642647, 87.69108131953648, 64.40627125331334, 70.16242994580949, 39.678844928741455, 6.653502907071795, 0.2825445330568722, 0.2841272566999708, 0.634067850453513, 3.010924994945526, 8.333617278507777, 10.97521902833666, 16.47531315258571, 16.040380239486694, 5.224667532103402, 5.214937448501587, 65.27515043531145, 83.34763036455426, 13.840033394949776, 0.3669034263917378, 0.13157434548650468, 1.2145916883434569, 1.8918887334210532, 2.749552437237331, 3.5677395164966583, 4.187176414898463, 8.024578775678362, 13.154958384377615, 14.72710817200797, 27.492404631205968, 34.438624722617014, 41.55475779942104, 40.98905978884016, 38.09675053187779, 21.05284023284912, 5.737593974385943, 0.3962108737656048, 0.4352281843977315, 0.8268420376947948, 2.4196697728974477, 0.2871789000928402, 42.45361498423985, 82.21088423047746, 62.388806206839426, 62.78511755807059, 61.15002577645438, 60.28292533329555, 57.50331585747855, 55.24993167604719, 57.85522821971348, 62.80152920314244, 67.07887499673026, 73.15503992353166, 84.26709243229458, 92.02577754429409, 89.12145137786865, 92.04657350267682, 71.70773015703473, 22.6520254611969, 1.3045084348746707, 0.16302924762879098, 0.4678419700690678, 1.869225229535784, 2.695817240646907, 1.0040767959186008, 0.6350551460470472, 0.1334968116134405, 0.17943773072745117, 2.2931760804993764, 4.10547993012837, 2.1864133179187775, 2.8127161221844807, 1.7406438205923354, 0.19159397057124547, 0.41294289593185696, 2.4700906787599837, 26.774129390716553, 23.309889589037212, 47.37812294278826, 78.82538836342948, 65.59739398956299, 42.40729134423392, 25.391667161669048, 60.78200054168701, 69.67289461408342, 76.56598009381975, 62.152470179966514, 12.24834874698094, 0.3192621799451964, 0.1350794266909361, 0.32077601871320177, 0.11483521227325712, 0.11415066543434348, 0.07084984465369157, 0.18307214070643696, 0.20009691002113478, 0.15966622451586382, 0.17995645717850753, 0.2837880163320473, 0.1433703646595989, 0.19404986021774157, 0.09726922985698495, 0.1394045038947037, 0.11513084998088223, 0.11346014748726573, 0.1097870474415166, 0.1333479681717498, 0.16865293229264872, 0.17161519905286177, 0.21742222963699273, 0.2696538061967918, 0.20210432873240539, 0.10160768098597016, 0.16459825129381248, 0.21178493356066092, 0.1280848705875022, 0.2227127400359937, 0.32781505957245827, 0.3308301434985229, 0.42259212530085016, 0.19625767746141978, 0.21472635572510107, 0.08268281684390136, 0.21452819635825499, 0.13304692932537623], [0.0296000486372837, 0.0576453564156379, 0.016764644433611205, 0.07527541289372103, 0.013448838876294238, 0.038526882484023056, 0.09063384269497224, 0.03546530533848064, 0.06979806787733521, 0.12061166231121336, 0.1065419672855309, 0.030483558907040527, 0.0332903257970299, 0.10625383417521204, 0.11047462054661342, 0.08755062028233494, 0.09708736211593662, 0.07001855783164501, 0.023227800748177936, 0.030775359499135187, 0.10039396504206316, 0.05413366288744977, 0.029999627731740475, 0.040832388414336104, 0.044520026072859764, 0.07680971627788884, 0.0731004299595952, 0.05635479977354407, 0.07749269570090941, 0.06651735784752028, 0.08796546302203621, 0.034534100842263014, 0.07580821894641433, 0.025424834374072294, 0.07929637070213046, 0.04178865460146751, 0.02145853765042765, 0.016899503268567578, 0.06697049710367407, 0.037915481720119715, 0.043946416316820044, 0.021644110192677805, 0.024242868780025413, 0.10166801631982837, 0.3277937535728727, 13.366707342011587, 53.649052824292866, 65.25433363233293, 73.85760702405656, 64.3946121760777, 35.06961842945644, 38.08134984970093, 51.4514730998448, 75.56002685001918, 68.74233627319336, 55.41558715275356, 36.00127111162458, 19.924586534500122, 1.4709083459206989, 0.15769267827272415, 0.15108123661151954, 0.2793225773743221, 0.7998680993914604, 4.9962615711348395, 3.569602285112653, 1.8540314733982086, 7.782111832073756, 57.9420668057033, 70.51799706050328, 3.2466799787112643, 0.3179083397345883, 0.2851434578852994, 0.11839388417346136, 0.33862233108707834, 0.438486536698682, 0.06040235276200941, 0.4286231616778033, 0.21311453650040285, 0.04777695684294615, 0.1237753861184631, 0.13795779938144342, 0.18061105348169804, 0.5249434603112084, 1.1117911360093524, 0.4853093613471304, 0.11007768434605428, 0.8615414500236511, 0.39944056474736755, 0.3914646570171629, 0.2623201182910374, 0.40410402736493517, 0.43147832847067286, 0.5063214195626122, 14.76669727052961, 20.598382881709508, 16.388283491134644, 10.691403354917254, 8.076665946415492, 7.2196877258164545, 6.216568912778582, 5.883158734866551, 6.419652163982391, 12.912747655596052, 25.01601106779916, 33.13688666479928, 41.78217233930315, 41.37485156740461, 20.22511523110526, 1.279557779431343, 0.4704498244183404, 0.7968904163156236, 1.424870993409838, 0.35037453046866823, 0.2014446027044739, 0.14487420182142938, 0.10182443899767739, 0.12207306389297758, 0.04167128500661679, 0.03986481783379402, 0.43767964999590603, 1.465957645859037, 0.3690168729850224, 0.28262294456362724, 0.1718137248286179, 0.559097167636667, 12.620580247470311, 24.809739896229335, 39.068907737731934, 66.26811749594552, 75.10030623844692, 34.066607747759136, 15.162546566554479, 31.83000694002424, 60.408382007053916, 57.594580445970806, 45.89249038696289, 20.389434916632517, 0.2428568841091224, 0.054365358847592554, 0.12227423595530645, 0.072550708028887, 0.05929697171917983, 0.04560397558712533, 0.005574202497622797, 0.02118238407586302, 0.02271001406812242, 0.036518269551119635, 0.016157448890485933, 0.030179154526974474, 0.030252792539873292, 0.0227514165786228, 0.035008250935269256, 0.039560250605323484, 0.026373782561027577, 0.03649906361741679, 0.02525073246631239, 0.07527058172438826, 0.022963747149333358, 0.015499180016506995, 0.07819226530513593, 0.01822190864809922, 0.051127606869808266, 0.041514635019536526, 0.04321127790691597, 0.016161905169220905, 0.03204434212031109, 0.04246632109529205, 0.09432598243334464, 0.07185305189341307, 0.1276897189340421, 0.026910385017150214, 0.08138684209968362, 0.013503475364164581, 0.07775272389075585, 0.049202745514256616, 0.07404741378767149, 0.051929143323962174, 0.029742320467318808, 0.06452460227800266, 0.009245322917455008, 0.01846638142264315, 0.10118406478847776, 0.1562823568071638, 0.16422409351382936, 0.28523519581982065, 0.1388897808002574, 0.10750223682927233, 0.10156594429697309, 0.060255259940666814, 0.04532767952020679, 0.09929013105907611, 0.14406488596328668, 0.08012893995536224, 0.013958655314386954, 0.09742827168000595, 0.01852815185806581, 0.047424454508083205, 0.11086800122367484, 0.10289221562977348, 0.011994558519550731, 0.057798243926039765, 0.10737191060824053, 0.0190459521088217, 0.11808318298842226, 0.21796686255506106, 0.014455158895413791, 0.17464662210217544, 0.20529785379767418, 0.0732428612453597, 0.042645230423659086, 0.16579940755452427, 0.060751832223364284, 0.07302564182983977, 0.00451955509405317, 0.02418770218667175, 0.01788375393620559, 0.06784049434853451, 0.06892713425414902, 0.11616789576198373, 0.03978376682581646, 0.5370887485998017, 27.3762845993042, 69.62176976885114, 78.30865083421979, 80.01218237195695, 51.79891429628645, 32.311371190207346, 44.885661670139854, 71.79741750444684, 82.35339178357805, 67.28634125845772, 53.186351435525076, 40.08546045848301, 22.852046728134155, 2.381673983165196, 0.14994584396481514, 0.13473314312951906, 0.44832206464239527, 0.712445756154401, 1.7133262178727557, 1.6196322568825312, 2.0334170247827257, 7.679611137935093, 75.73104981013707, 85.07107543945312, 10.466571807861328, 1.2447305853877748, 1.2195029790912355, 0.08593443129211664, 0.9289046696254185, 1.0877230103526796, 0.12741146529359476, 0.834886043199471, 0.7358722048146384, 1.4693481496402194, 0.5232774668506214, 1.413988811629159, 1.119195744395256, 2.4743095380919318, 4.347782288278852, 2.957693977015359, 0.6597632659333093, 0.5939542172210557, 0.5545211817537035, 0.09724659392876284, 0.3199182418840272, 1.866526940039226, 0.7565142171723502, 3.2180043288639615, 40.450730732509065, 47.31049960000174, 46.14737810407366, 35.53012766156878, 32.08959858758109, 29.524851730891637, 31.074501514434814, 31.695906707218715, 40.84216792242867, 45.57586792537144, 53.04143980571202, 52.8848934173584, 57.724278994968955, 54.87545851298741, 40.146722725459504, 5.672891914844513, 0.5605414158531598, 0.798060590667384, 1.5778092039482934, 0.7401318848133087, 0.21417474746704102, 0.07207005417772702, 0.12102677646492209, 0.4896428659558296, 0.09163205591695649, 0.1051110862089055, 0.8674207659704345, 0.3822457545569965, 0.08347313372152192, 0.10770194325596094, 0.3033273550016539, 0.6955265668886048, 13.476164919989449, 32.18388564246041, 40.615493365696494, 42.367106437683105, 78.52306529453823, 61.86732305799212, 21.07537497792925, 15.414472614015851, 45.78750658035278, 59.45021847316197, 57.53441946847098, 29.23017168045044, 1.4192141826663698, 0.2131043720458235, 0.0848414810108287, 0.20819819745208534, 0.06539798541260616, 0.031889283297849555, 0.02257821542610015, 0.029442000868065015, 0.011821380267584962, 0.039893004178468666, 0.03522985029433455, 0.05277624001194324, 0.037213364216898165, 0.009290229213157935, 0.015249258605763316, 0.0414961754743542, 0.01491792147446956, 0.05894654230879886, 0.14978337553994997, 0.033192358911037445, 0.03312011528760195, 0.019447850096704702, 0.006523302930872887, 0.025143430634800876, 0.002527577931427264, 0.010038516783554639, 0.016695910532559668, 0.058459761286420484, 0.06964485467012439, 0.09873964916914701, 0.2404962336378438, 0.06014691825423922, 0.1982804989176137, 0.034640892076173, 0.25750211253762245, 0.05142211481662733, 0.07306275769535985, 0.017636407565857683, 0.0625050717166492, 0.09607995474444968, 0.19045300036668777, 0.10645708255469799, 0.16186701213674887, 0.10678031628153153, 0.13394704673971447, 0.28421687760523384, 0.2217747060848134, 0.4018074848822185, 0.34793481709701674, 0.19683057814836502, 0.23190060630440712, 0.18453772206391605, 0.312413291739566, 0.22050324002546923, 0.19927816252623284, 0.18166137140776428, 0.1263818833976984, 0.2687308357230255, 0.1219512125743287, 0.21980624885431357, 0.2129480375775269, 0.15344111355287687, 0.10061028879135847, 0.19915270140128477, 0.21649750854287828, 0.10822683080498662, 0.22293672444564955, 0.31400521631751743, 0.26078983183418003, 0.23765906159366879, 0.2583008568201746, 0.16123973365340913, 0.13647020634795937, 0.3183716434453215, 0.20818583454404557, 0.18958395985620363, 0.1969762189047677, 0.17732800250606878, 0.2533724127071244, 0.22901843381779535, 0.25744668979729923, 0.1578429602086544, 0.1475002680506025, 0.6912337743810245, 27.176079205104283, 78.37552029745919, 91.93777166094098, 95.26204000200543, 83.81853062765938, 51.14905275617327, 53.377440793173655, 70.99046761648995, 86.56899588448661, 82.89102254595075, 70.09434454781669, 52.62988758087158, 27.574428115572246, 2.887809429849897, 0.30907242958034786, 0.22736548180026667, 1.1620160809585025, 2.160056412220001, 9.37504802431379, 10.59234288760594, 12.483546137809753, 14.218253374099731, 81.62116282326835, 72.72953919001988, 4.479962646961212, 1.2043802248580115, 2.0358695217541287, 0.13013961033097335, 1.3451654932328632, 0.9696896182639259, 0.17029627625431332, 0.3664107014025961, 0.3977062020983015, 0.6594360492059163, 0.2015026310192687, 0.6201850239719663, 0.44880971418959753, 1.7737523125750678, 3.1670942263943807, 2.0327573801789964, 0.8567207029887608, 1.3242377362080981, 0.6974006806101117, 1.22996001797063, 1.921942297901426, 1.3734633347817828, 0.7782197381768907, 1.7941604746239526, 37.660657269614084, 60.68280805860247, 62.243429047720774, 52.83524506432669, 46.39335823059082, 46.054359095437185, 47.790550640651155, 47.996373653411865, 55.932425430842805, 58.91407462528774, 63.20129380907331, 55.729152406964985, 52.05154732295445, 44.3748231615339, 25.268781321389334, 2.1052464161600386, 0.45391137472220827, 1.5407728084496088, 3.007032266684941, 1.4485102849347251, 0.5034924713628632, 0.20632767996617726, 0.17758439374821527, 0.8874625733920506, 0.43426697169031414, 0.1683863223131214, 1.510452389717102, 4.1018872771944315, 0.6296999305486679, 0.5777014579091753, 0.40814188069530893, 1.0765087263924735, 19.995677028383525, 38.24322550637381, 55.55434267861502, 77.89066805158342, 92.64274978637695, 46.73594958441598, 27.264067717960902, 41.51325273513794, 76.86459282466343, 73.64408888135637, 70.86676188877651, 34.81703404017857, 2.1057935867990767, 0.25678777801139013, 0.18518253389213765, 0.2713596432336739, 0.14207751117646694, 0.12179527165634291, 0.1267224129821573, 0.08610270119139127, 0.10926993590380464, 0.12315715929227215, 0.1850588098168373, 0.1453154667147568, 0.19234698159354074, 0.11951590968029839, 0.12253555336168834, 0.1905135256903512, 0.14416138721363886, 0.11255819802837712, 0.24399657866784505, 0.16995122762663023, 0.2249426639505795, 0.05253427103161812, 0.2390137431877, 0.11516711089227881, 0.13304110749491624, 0.10798015618430716, 0.1375229534293924, 0.19005695304700307, 0.1638325516666685, 0.17222274573785917, 0.3626563400030136, 0.2332920916378498, 0.339942353112357, 0.08700551238975354, 0.3326113793466772, 0.08399101878915514, 0.2991586801196848, 0.12158219808978693, 0.14229548376585754], [0.017697426523747187, 0.07496562094560691, 0.028241719917527268, 0.03574628668970295, 0.02267336469542767, 0.012341662260171558, 0.024504053872078657, 0.010348343506588467, 0.060981319552021365, 0.01826862578413316, 0.012760401487217417, 0.023398111341521144, 0.048568759712257555, 0.05647287165213909, 0.024604392237961292, 0.060436720560703955, 0.018458222039043903, 0.016386259380461912, 0.02843655107010688, 0.01748263117458139, 0.035481793739433796, 0.03330490072923047, 0.009558698378636368, 0.025560624498341764, 0.030469536980880157, 0.06332187181604759, 0.02003148351130741, 0.04515820861394916, 0.01552854192310146, 0.025047071876802614, 0.03935153323358723, 0.025544753564255576, 0.08809749236596481, 0.06477348213749272, 0.023706256145877496, 0.02621172464984868, 0.025442065770870874, 0.062252778826015334, 0.022264606718506132, 0.023598516659278954, 0.10066741465457849, 0.060301787086895535, 0.038257941736706665, 0.07458410106067147, 0.1046543846439038, 0.1692575884184667, 0.8037880776183945, 19.409744126456125, 45.40830864225115, 62.44695568084717, 66.47513907296317, 51.04984637669155, 41.33982569830758, 46.535983903067454, 60.70971843174526, 82.66285065242222, 72.29104532514299, 65.83291012900216, 35.2128381729126, 12.526841231754847, 0.8282229378819466, 0.45989985338279177, 0.06767149163143975, 0.4914012487445559, 0.42608772058572086, 1.4154706235442842, 3.097194914306913, 8.29382233960288, 8.062303151403155, 5.529392506395068, 1.0788275791066033, 0.8695630910141128, 0.5241006112524441, 1.2602728371109282, 0.3531534570668425, 0.04614783836794751, 0.22544019296765327, 0.07607181623045887, 0.03843661697049226, 0.1717644224741629, 0.2012331440512623, 0.1386940370180777, 0.43474916581596645, 0.23156785273126193, 0.30578975858432905, 0.43721686197178705, 0.12887102126010827, 0.010594488869953369, 0.2948867322078773, 0.4635451063513756, 0.2752708819295679, 0.5492529273033142, 0.2780809939971992, 0.13993889093399048, 0.7540411470191819, 3.870410646711077, 3.8335091982569014, 2.884013976369585, 2.9408026891095296, 2.4474892743996213, 2.5729201095444814, 1.2022273689508438, 0.5678315960935184, 1.0529740921088626, 0.9156244908060346, 0.7504437171987125, 0.4382393056792872, 0.09085975414408104, 0.14875481144658156, 0.31488676901374546, 0.11818355188838073, 0.04573511605017951, 0.22541491075285844, 0.04689444401966674, 0.11992715618440083, 0.02048461598211101, 0.09677328182650463, 0.22780486036624226, 0.2840345688164234, 1.0138137191534042, 0.3154453661824976, 0.1507680927004133, 0.34150463928069386, 9.012815850121633, 35.457862922123496, 52.13203525543213, 64.65037536621094, 66.52144186837333, 53.45866870880127, 32.53810828072684, 30.723346505846294, 48.414113249097554, 60.243112155369346, 50.100715500967844, 30.618119512285503, 5.023690019335065, 0.12659080432994024, 0.11119855634335961, 0.0645138949954084, 0.05771768146327563, 0.11215998618198292, 0.10189590909119163, 0.05782438788030829, 0.03386246991742935, 0.021017605239259343, 0.03132942405396274, 0.06327977550349065, 0.04398625310776489, 0.047734273597598076, 0.06133216965411391, 0.01593735587916204, 0.018018933378958275, 0.05674757994711399, 0.053981314812387736, 0.08325943590274879, 0.08031755911984614, 0.019297985459810922, 0.0003451618847196057, 0.008314528934923666, 0.006817001300597829, 0.09006844660533325, 0.010982447204047015, 0.05688150918909481, 0.049878311942198446, 0.032440498005598783, 0.06873959396034479, 0.022955272246950438, 0.05198655077921493, 0.01794439969983484, 0.02396093069442681, 0.05099237823326673, 0.0072301799331658655, 0.03040049265005759, 0.01836993615143001, 0.00913138925430498, 0.015719418912859898, 0.06530330263610397, 0.05448695232293435, 0.083512760166611, 0.013815519200371844, 0.058735192221190245, 0.030101153533905745, 0.0650350980992828, 0.009975612346482064, 0.12842914568526403, 0.027021562979955758, 0.037199600134044886, 0.0576874798695956, 0.025140233038525497, 0.06311476935765573, 0.03470237074153764, 0.055820684148264785, 0.01835658767127565, 0.040352355422718186, 0.04275447456166148, 0.059396248177758286, 0.02111944995288338, 0.0056034087652473575, 0.030171677071068968, 0.07150872929819993, 0.024199106663997685, 0.0669700831973127, 0.015335093285622341, 0.03453495240371142, 0.08833434858492442, 0.025384498859888742, 0.028336036285119395, 0.05592732271179557, 0.04693082367469158, 0.03052538719826511, 0.023705279055450643, 0.03429143636354378, 0.049196438531258276, 0.10111634699361664, 0.02487491227553359, 0.04163068486377597, 0.02808066793451352, 0.06349588890693017, 0.09213879265423332, 0.16664621925779752, 0.05998023612690823, 0.22814214655331203, 3.4553376393658772, 32.2280900818961, 60.18601185934884, 76.87727328709194, 64.19380923679897, 46.22238390786307, 36.88567951747349, 56.185461453029085, 78.72819696153913, 93.26663548605782, 70.37243230002267, 64.99146243504116, 39.15939065388271, 14.298043012619019, 1.161565316574914, 0.319789211664881, 0.0560176221520773, 0.18456429349524633, 0.31156211027077263, 1.4942385511738914, 2.1848573556968143, 23.709155661719187, 24.652279819761002, 5.2404069389615735, 2.2358512708118985, 2.62942698597908, 3.352739453315735, 2.472010552883148, 0.798100868506091, 0.5792222991585732, 0.33269375349794117, 0.15610148651259287, 0.11193878376590354, 0.22137525251933507, 0.43781893966453417, 0.3261546572404248, 0.36470497293131693, 0.3000916929117271, 0.7061881976468223, 0.7546038968222482, 0.43858006596565247, 0.026791288550677042, 0.10860021505504847, 0.29290228869233814, 1.7677272473062788, 1.8219618456704276, 1.1697851440736224, 1.0316912169967378, 7.111426975045886, 10.653749329703194, 9.225325635501317, 6.379680914538247, 4.3154245274407526, 6.370841937405722, 8.195943066052028, 7.278324007987976, 7.971099359648568, 6.779934065682547, 5.1083429626056125, 3.50349668945585, 2.060587738241468, 0.2940368806677205, 0.3457739273352282, 0.8370060580117362, 0.13327684413109506, 0.16072543125067437, 0.08082425514502184, 0.02188535314053297, 0.05088802633274879, 0.0644557106175593, 0.018190702822591578, 0.3228455233786787, 0.2912296455885683, 0.5486383917076247, 0.2617157335792269, 0.10335229629916803, 0.31162562114851816, 5.576242472444262, 28.35330901827131, 50.5032559122358, 56.08418451036726, 74.83346761975969, 73.44901125771659, 39.76804937635149, 14.976550238473074, 27.197922604424612, 58.31935051509312, 61.6695008959089, 42.18100936072213, 10.08976491859981, 0.10832865176988499, 0.0565067509056202, 0.05860329179891518, 0.12717201028551373, 0.053981928886579614, 0.050147422323269505, 0.04254691409213202, 0.03124935013641204, 0.04495844111910888, 0.06768601228083883, 0.03081497915887407, 0.0393387971312872, 0.04666349444804447, 0.042688680413578234, 0.02221757745636361, 0.05296931375882455, 0.03173403787825789, 0.02229158696718514, 0.04394303381975208, 0.07459049286054713, 0.06311452508504901, 0.024519066459366252, 0.02551714567068432, 0.0036886232306382483, 0.02579398117294269, 0.005670850905257144, 0.03664457545216594, 0.038310619802879434, 0.029572897058512484, 0.05071445707497852, 0.06219890993088484, 0.026292173457997184, 0.054400696951363764, 0.021923395206353495, 0.10851853300950356, 0.08160747454634734, 0.042981118828590424, 0.10755991909120764, 0.033865173879478655, 0.09330414262201105, 0.1349770493273224, 0.19108144593025955, 0.22919726850731031, 0.15546503423580102, 0.1547844907534974, 0.11992604338697024, 0.25137583698545185, 0.15080666063087328, 0.19247077352234296, 0.08048968988337687, 0.12369907807026591, 0.1537836380302906, 0.20221715553530625, 0.17180693947843143, 0.098899600229093, 0.23528915590473584, 0.08624103412564312, 0.09632003400474787, 0.19498465077153274, 0.11632357883666243, 0.09023597011608736, 0.18787639934037412, 0.09545420296490192, 0.13219527288206986, 0.07903711604220526, 0.1967858491199357, 0.10329797278557505, 0.14621379279664584, 0.07298487544591938, 0.14252701348492078, 0.13983652714107717, 0.14080201461911201, 0.18154448696545192, 0.12502375484577247, 0.11930612022323267, 0.1055332367707576, 0.20341574693364756, 0.10016751755028963, 0.14613102509507112, 0.1368077639490366, 0.20008405856788158, 0.10945721835430179, 0.19785931866083825, 0.24720401370099612, 0.13654576800763607, 0.30644972888486727, 3.191834156002317, 35.45161649159023, 72.40163285391671, 92.6899836403983, 84.57844815935407, 66.89595672062465, 56.773772375924246, 64.28317696707589, 79.28508118220738, 99.36174815041679, 86.7018940789359, 85.79885060446603, 52.496141706194194, 21.862004859106882, 1.6934364565781184, 0.8826027427400861, 0.2089322909180607, 2.153450629540852, 2.4683193223817006, 6.659068414143153, 20.647237403052195, 18.90938697542463, 12.975125976971217, 18.926769631249563, 2.0931843434061324, 3.245246695620673, 2.9520513883658817, 1.598960280418396, 0.5209550857543945, 0.7733669100063187, 0.3578826832984175, 0.2091329608644758, 0.13792038496051515, 0.6579767646534103, 0.8011803861175264, 0.6527158926640237, 0.623707977788789, 0.6661753675767353, 1.988453711782183, 1.4774061058248793, 0.6032167630536216, 0.18212151314531053, 0.956903738634927, 1.3011392099516732, 4.414077656609671, 2.9912780949047635, 0.7343327988471303, 0.3553427095924105, 3.540214227778571, 9.485796230179922, 10.112316165651594, 7.989068269729614, 6.3470087477139066, 9.087319646562849, 9.229914052145821, 5.5766802089554925, 4.417753253664289, 2.4516607991286685, 1.4569830702883857, 0.8357335062963622, 0.5450812397258622, 0.24101186596921512, 0.673659120287214, 1.7949818819761276, 0.20625825226306915, 0.2836159941341196, 0.3826400376856327, 0.10819155376936708, 0.28273444143789156, 0.17928974223988398, 0.3157198471682412, 0.6617175010698182, 1.1426649136202676, 2.181839231933866, 0.5342463925480843, 0.4553363525441715, 0.7719728733812059, 14.532110452651978, 50.08398771286011, 68.22673824855259, 76.54610129765102, 78.79645606449672, 66.92890507834298, 45.90675156457083, 40.11668913705008, 60.616904394967214, 74.21456377846854, 72.90367494310651, 52.22704144886562, 11.798044681549072, 0.2697079804326807, 0.27530402157987865, 0.20057640357741288, 0.18238789242293152, 0.13858468431447232, 0.2803689055144787, 0.10571234965963022, 0.1097015995266182, 0.08918509579130582, 0.14868382311293057, 0.1415450376059328, 0.15413408779672214, 0.15552155620285443, 0.15648610730256352, 0.1447878378842558, 0.16649225966206618, 0.18052424171141215, 0.12397913661386285, 0.14796932573829377, 0.17582161405256816, 0.17399018018373422, 0.09405551158956119, 0.08955450382615839, 0.06819653524351971, 0.13843719794281892, 0.0616282212681004, 0.15654640192432062, 0.07622008970273392, 0.09548176505735942, 0.181030469547425, 0.11809920998556273, 0.1539440301379987, 0.16307690792850085, 0.19370969704219274, 0.1524884503866945, 0.13180696086159774, 0.12657313527805464, 0.15191003999539784, 0.0973854221935783, 0.11830628530255385], [0.051105096470564604, 0.025571287676159824, 0.04822162798206721, 0.008901876480584698, 0.022365019723240818, 0.03979410430682557, 0.059552209451794624, 0.05295700852626136, 0.061566216738096306, 0.038747542072087526, 0.03464974356549127, 0.040653940489781756, 0.011627870561954166, 0.030123443409268345, 0.09518443779753787, 0.019500027743301222, 0.10512293343033109, 0.012695810042454727, 0.0059541015320324474, 0.019853485116202916, 0.07513191630797726, 0.03715652333838599, 0.09068203225199666, 0.0309553307348064, 0.022142979316413403, 0.07970609050244093, 0.020070253305935433, 0.0189432863678251, 0.07437661862266914, 0.056188979385686774, 0.0589057555688279, 0.031172672286629677, 0.031163742765784264, 0.10961708799004555, 0.07894588700894799, 0.009984132201809968, 0.07287776190787554, 0.0785936526954174, 0.042589007012013874, 0.019335980028180138, 0.021752419648692012, 0.0474412245010691, 0.01537455348963184, 0.03762977776516761, 0.11153393584702696, 0.06339518752481256, 0.09457248063491923, 0.4672609812447003, 2.658883873905454, 27.078774894986832, 46.13787644250052, 58.575933592660085, 63.54705701555525, 49.81995269230434, 44.33341537203108, 37.60464784077236, 47.79607098443167, 67.74351188114711, 74.61447429656982, 52.22800724846976, 33.03571741921561, 6.221340153898511, 0.18721128574439458, 0.0412981755632375, 0.24932611840111868, 0.4349517763725349, 0.3177865019866398, 1.1211222410202026, 1.116188911455018, 3.043850119624819, 3.79855454819543, 3.6355580602373396, 2.7331093081406186, 0.27814724615642, 0.7381161472627095, 0.5259567573666573, 0.34391579989876064, 0.36800205601113184, 0.12372589377420289, 0.12620801558451994, 0.28306730357663973, 0.3613813727029732, 0.07177620780255113, 0.12482183639492307, 0.0294171088109059, 0.08137040119618177, 0.06659283129764454, 0.09087949951312371, 0.6917881103498595, 0.27489787765911644, 1.05575130879879, 1.138679904597146, 1.385607157434736, 0.24392782949975558, 0.012124034875471677, 0.06910630142582314, 0.008168244418422026, 0.03902644371347768, 0.019417561989809786, 0.1611278567995344, 0.08231156997914825, 0.15554318789924892, 0.13949032500386238, 0.23104367085865565, 0.17518459180636065, 0.4628051774842398, 0.14106551690825395, 0.8343982036624635, 0.9896497300692967, 0.12053920834192208, 0.05156566907784768, 0.02031221041189773, 0.068924440470125, 0.048626099314008436, 0.21978749414639814, 0.07274789030530623, 0.6447079309395382, 0.06899101154080459, 0.12243779003620148, 0.2148864764188017, 0.7538387807352203, 7.09347630398614, 29.883208547319683, 54.29053831100464, 63.46352577209473, 50.31217350278582, 39.03301681791033, 26.852048226765223, 35.85919087273734, 70.61696720123291, 67.84945801326207, 63.75512777056013, 43.454190322331016, 14.550046358789716, 0.611286498606205, 0.17668240357722553, 0.11136863793113402, 0.051895321745957644, 0.04924830235540867, 0.07765772220279489, 0.06377330794930458, 0.14346937648952007, 0.027355868701956103, 0.08040396376912083, 0.033345924956457954, 0.08663638933960881, 0.0386537244277341, 0.03903958015143871, 0.04758754039981535, 0.008303013347488428, 0.025588256140638675, 0.04098665335082582, 0.012581976463219948, 0.019834774513063685, 0.05511534360370465, 0.014912186157224434, 0.017054436562050666, 0.015614061084176813, 0.06332604480641228, 0.04547966457903385, 0.023378873177404915, 0.021218975773081183, 0.02472415197241519, 0.029329550652099506, 0.045257352758198977, 0.08077308681926557, 0.004780025603914899, 0.06078491759087358, 0.040317709424666, 0.02047497739217111, 0.028012266515621116, 0.027168620178209882, 0.054553017885025056, 0.03334980278408953, 0.0034561717641606393, 0.027831391132037555, 0.03282729350030422, 0.052861440261559825, 0.054716897662729025, 0.04417490280632462, 0.01491301566628473, 0.06025135836430958, 0.010627685347571969, 0.02922679330887539, 0.048520892459367, 0.0970384261703917, 0.041300017785813124, 0.04102358940456595, 0.024949055797021304, 0.053139449629400454, 0.07011657221508877, 0.034233140027416606, 0.04284604286242809, 0.02648386129710291, 0.021410192030348947, 0.08845734662775483, 0.041386246015982966, 0.022536746758435453, 0.005111438222229481, 0.0776540038308927, 0.005078668797588242, 0.014164253969543746, 0.045757256647838015, 0.05656665197706648, 0.01680869153434677, 0.06437582668981381, 0.04472289786541036, 0.01311938976868987, 0.02668659738264978, 0.009808985350121344, 0.004375609827028322, 0.015019487988735949, 0.05897830453302179, 0.042861937545239925, 0.0469021453921284, 0.055706995605890236, 0.03762978794319289, 0.058420365543237755, 0.06693166454455682, 0.02720692687268768, 0.21244537883571216, 0.12012121719973427, 0.11993322228746754, 0.33168045644249233, 6.319418319634028, 39.42296709333147, 65.39712606157575, 73.55055223192487, 67.74464443751744, 48.37776722226824, 43.905965668814524, 51.20042078835623, 73.82808412824357, 85.40761838640485, 71.02427060263497, 58.10653066635132, 35.051476682935444, 6.7263873389789035, 0.4370182954839298, 0.2941966620939118, 0.27207712616239277, 0.19631983126912797, 0.4111878515354225, 0.8014121736798967, 2.3131617052214484, 3.399309537240437, 2.6831174535410742, 3.798882416316441, 6.570295189108167, 5.8038871714047024, 2.007543236017227, 0.6059036531618663, 0.6088722167270524, 0.29999764795814243, 0.06137923962835755, 0.10588905374918665, 0.11526593273239476, 0.33950982775006977, 0.37785734289458817, 0.19155096502176353, 0.09237188978918962, 0.17259100026318006, 0.06249765532889536, 0.021818425838968585, 0.8229456724865096, 0.31835619998829706, 0.8903763113277299, 1.6284009920699256, 1.6304446309804916, 0.16180312127939292, 0.06316631766302244, 0.5654948300548962, 0.38542965799570084, 0.2742419514272894, 0.25128841453364914, 0.47157668109451023, 0.24798508893166268, 0.43575752313647953, 0.5420321204832622, 0.4999213144183159, 0.22955792344042233, 0.19119712258023874, 0.21096972801855632, 0.3619239293038845, 1.5276212798697608, 0.0949060959475381, 0.1112703996311341, 0.12867687882057258, 0.1252920611628464, 0.01325068883930466, 0.17532742342778615, 0.15564065266932758, 0.5334229224494526, 0.1529915841030223, 0.19970914082867758, 0.05320634300421391, 0.5648596669946397, 1.7084265436444963, 20.354150227137975, 50.5218562398638, 72.9355115890503, 74.99922384534563, 58.37479019165039, 38.33894041606358, 29.243793623788015, 54.39758225849697, 64.29673985072544, 68.7423849105835, 52.868492194584434, 22.731476375034877, 1.9577778492655074, 0.2938538390610899, 0.06722513094012227, 0.12131154404154845, 0.02650347604815449, 0.08638899547180959, 0.014872179732524922, 0.17157208493777684, 0.046830003548945696, 0.06055595951953104, 0.07317491274859224, 0.05218505959159561, 0.020913473862622465, 0.039459009787866046, 0.04768908655803118, 0.025450659416882054, 0.005389555307504321, 0.06542497753564801, 0.02375562465749681, 0.009579906838812997, 0.049533697576927285, 0.02163737403628017, 0.016421175096184015, 0.03004919132217765, 0.028947396336921623, 0.022403379004182558, 0.03680050279945135, 0.05215961792107139, 0.018930300903905715, 0.0625726877312575, 0.01619697185898466, 0.034507912783218284, 0.002782216856888096, 0.054063417549644194, 0.012856942601501942, 0.014939943328499794, 0.07091028855315276, 0.03681999371786203, 0.01458344272603946, 0.08694897006664958, 0.019665878665234362, 0.04690113437495061, 0.10522973484226636, 0.17104513464229448, 0.1731944214552641, 0.07781138324311801, 0.09300815207617623, 0.1563995669462851, 0.11227271798998117, 0.21131073257752828, 0.17528654847826275, 0.14278953868363584, 0.19708638585039548, 0.15642087294587068, 0.12143756156521184, 0.09903009608387947, 0.3820537562881197, 0.11449134429650647, 0.18100156395563058, 0.12224432613168444, 0.1547601856291294, 0.22577677347830363, 0.19200987182557583, 0.09988643441881452, 0.14291349346084253, 0.1727523830320154, 0.14356395070041927, 0.15897819000695432, 0.15325606348259108, 0.10994457613144602, 0.09242714968110834, 0.11746251343616418, 0.22759629227221012, 0.11113682322736297, 0.10848263172166688, 0.16338304935821465, 0.18262058922222682, 0.083707241873656, 0.12233136860387665, 0.14393923484853335, 0.14910737824227127, 0.13611747670386518, 0.08155929856002331, 0.18905163556337357, 0.08720802116606917, 0.184630722073572, 0.27936052105256487, 0.16041122882493905, 0.18997052125632763, 0.5762960218957492, 5.198199672358377, 41.04560422897339, 80.82694203513009, 90.6904935836792, 86.46073600224086, 67.29670797075543, 61.27851186479841, 54.8858425957816, 70.09109279087612, 81.81900582994733, 87.98472608838762, 68.6644539151873, 49.77059268951416, 10.26101803779602, 0.5805307860885347, 0.8392865327852113, 0.7358210161328316, 0.7545754526342664, 6.712870921407427, 6.709537523133414, 11.446944390024457, 17.185356514794485, 11.087201407977513, 11.694568634033203, 13.180814368384224, 8.524776986667089, 4.745651773044041, 1.6525939681700297, 0.6848698215825217, 0.7701451714549745, 0.6465918698481151, 0.3243401731763567, 0.4287096070391791, 0.5615134579794747, 0.4928113530789103, 0.21918270231357642, 0.13210620837552206, 0.6559086984821728, 0.11328518723270722, 0.4651064968534878, 1.7074126494782311, 1.0371502212115695, 3.621789336204529, 3.2365781664848328, 3.2199743602957045, 0.3968161812850407, 0.1878826418625457, 0.3708935108567987, 0.2503757035093648, 0.2740892810480935, 0.1811927615531853, 0.41480995288916994, 0.3659542373248509, 0.6327433500971112, 0.6384232310312135, 0.584924653172493, 0.23515562021306582, 0.44293373663510593, 0.30351218794073376, 1.2476707590477807, 1.5765044625316347, 0.3398953170648643, 0.19060242734849453, 0.4347042196563312, 0.4312313145824841, 0.2318698008145605, 0.6198623669998986, 0.23934258839913777, 1.2387856415339877, 0.22550678439438343, 0.327873305018459, 0.2921686294887747, 1.0033843645027705, 11.615691815103803, 44.317267758505686, 71.88884884970528, 77.53401006971086, 64.64543519701276, 50.813913345336914, 40.041214329855784, 43.611699036189485, 79.43576676504952, 82.0455379486084, 82.34642968858991, 62.283791133335654, 25.42224965776716, 2.0110535962241034, 0.40444644327674595, 0.2399618194571563, 0.4746216748441969, 0.1646669597498008, 0.1653522394065346, 0.15818397833832673, 0.32784122388277737, 0.165175928867289, 0.13036948442459106, 0.214774273868118, 0.18744851515761443, 0.13611504754849843, 0.11221741060061113, 0.16082265174814633, 0.1127165002482278, 0.13988405173378332, 0.20402201797280992, 0.18710836555276597, 0.09125094315303223, 0.10778271606458084, 0.07594140858522483, 0.10607755077736718, 0.13334708607622556, 0.09746342657932214, 0.18741587762321743, 0.24899705605847494, 0.16574906025614056, 0.08524552147303309, 0.12459213872041021, 0.1538243501314095, 0.2208081872335502, 0.13253676598625524, 0.15031572697418077, 0.07027905421065432, 0.16090300386505468, 0.1346744227090052, 0.09384396472679717, 0.08415728022477456, 0.17200313109372342, 0.1887329276651144, 0.10541701729276351], [0.03694660495966673, 0.014928455730634076, 0.025984216947108507, 0.009134792107423502, 0.03233766263084752, 0.037803123106381724, 0.042816065185304196, 0.023572099594665424, 0.06740151611821991, 0.028067346595759903, 0.051903952711394856, 0.03516003582626581, 0.08819229727877037, 0.009683621764582182, 0.06254391784646682, 0.08186852053872176, 0.00499519075466586, 0.015808646267812167, 0.02008507081440517, 0.03797531154538904, 0.010890598159416445, 0.034754142963460515, 0.01826487518181758, 0.0331396672741643, 0.005109729586235646, 0.05532857323331492, 0.0022979737675216582, 0.026448726753837297, 0.027410417828442793, 0.04064343337501798, 0.020049498616052524, 0.007708871969953179, 0.054603080198700936, 0.02292161012467529, 0.038585867533194165, 0.012937566132417746, 0.02460866531224123, 0.06150982369269643, 0.023241166191707765, 0.0885318565581526, 0.05390244868717023, 0.06290786367441926, 0.04587280098348856, 0.06995563049401556, 0.07580996956676245, 0.1685459137495075, 0.07226508549813714, 0.33785805638347355, 0.1853081714361906, 0.17358041288597242, 3.1597538888454437, 18.867887122290476, 37.29048504148211, 48.409867899758474, 60.878379004342214, 49.65969249180385, 31.344491141183035, 25.07389303616115, 51.656469276973176, 57.4044360433306, 65.73558671133858, 55.45361811774117, 33.22460767201015, 8.4425676379885, 1.133998881493296, 0.23065734016043798, 0.291804527597768, 0.1120012089876192, 0.8458248962249074, 0.816567063331604, 0.9477221284593854, 2.8514464667865207, 3.1753111226218085, 2.2264633859906877, 0.3693450668028423, 0.1293030987892832, 0.11417244640844208, 0.13146477565169334, 0.08616836302514587, 0.22395610117486545, 0.029227600765547583, 0.07285922433116607, 0.21583012863993645, 0.06202388860817466, 0.06450915203562804, 0.11926878722650663, 0.07746157808495419, 0.755584081368787, 0.10170587178851877, 0.09912566095590591, 0.17504041668559822, 0.4651929150734629, 0.4605397933295795, 0.900569210095065, 0.063842783149864, 0.2444801570049354, 0.08796291173036609, 0.07383078469761781, 0.029101929294743707, 0.20740253371851786, 0.0517501084666167, 0.16552998844001973, 0.08978209125676326, 0.0868571303518755, 0.15949716073061737, 0.5501403425421033, 0.5382994722042764, 0.1854441634246281, 0.19394498584525927, 0.03413784656939762, 0.04909505522144692, 0.11238997562655381, 0.09562120400369167, 0.30968452244997025, 0.5583679324814251, 1.6506067833730151, 0.024790268424632292, 0.1800405140966177, 1.951466279370444, 10.11158834184919, 29.067757538386754, 44.55065427507673, 51.50978585651943, 55.26220914295742, 30.651199885777064, 22.808412040982926, 35.693757738385884, 45.394353185381206, 54.54773283004761, 56.04323182787214, 46.812244279044016, 21.86175124985831, 3.876307930265154, 0.11354708139385496, 0.12601684512836592, 0.11629923300019332, 0.06871904791998011, 0.02060251313793872, 0.033596256880887916, 0.01989565267493682, 0.09667600026088101, 0.11172277892806701, 0.06785016347255025, 0.04307040385901928, 0.07991716917604208, 0.04496394403811012, 0.065580307772117, 0.025643197121098638, 0.01983922061377338, 0.02244412842472749, 0.0319821340298014, 0.054684796170996766, 0.057135993747838905, 0.058143360407224724, 0.07845510262995958, 0.07155413686164788, 0.05426319861518485, 0.0183958460111171, 0.05791872460395098, 0.023984918603673577, 0.01376622956844845, 0.06917879610721554, 0.09239805409950869, 0.02262434732568051, 0.03134555283135601, 0.007308031648530492, 0.07593731701906238, 0.03934587085885661, 0.05045331948037658, 0.08247593151671545, 0.0500082106861685, 0.019355316579874073, 0.018090070990313376, 0.02532530007218676, 0.04940664868003555, 0.04686280053907207, 0.039262428014938316, 0.05072184292865651, 0.010893293639778026, 0.08755442007843937, 0.013280781019212944, 0.061713967738407, 0.03671941786472287, 0.01029138982162944, 0.012696947436779737, 0.058716559649578164, 0.04202453712267535, 0.038165616869394264, 0.0257275814323553, 0.04439684143289924, 0.028833107291055576, 0.06331738669957433, 0.030775200043405806, 0.025464394661997045, 0.03465179952659777, 0.029054876283875535, 0.03860981981935246, 0.040987640619277954, 0.05220134782471827, 0.046896394807845354, 0.014136384839990308, 0.009274226812911885, 0.020517621621755616, 0.028965645536248173, 0.03997293560366545, 0.023966945907367126, 0.012897233162740511, 0.04696967998253448, 0.011105857456901243, 0.05068933092323797, 0.03628712998969214, 0.013381620652840605, 0.032046662710074864, 0.03394770409379687, 0.04229814279824495, 0.045702349594128985, 0.08345178022448506, 0.032680085328008444, 0.08412053755351476, 0.0033301364289530155, 0.04584909636261208, 0.3098487007830824, 0.04918815701135567, 0.16267187680516923, 0.3736857638827392, 0.5591420052306992, 9.367945228304182, 33.91744729450771, 59.30753721509661, 70.10160541534424, 67.30555302756173, 44.30076926095145, 25.921455144882202, 34.6255555834089, 72.32222189222063, 69.58741787501744, 75.17842483520508, 51.05916738510132, 27.89368568147932, 7.31844116960253, 1.4555630322013582, 0.20704950551901544, 0.17646995426288672, 0.22610914707183838, 0.5232586307185036, 0.2458858915737697, 0.3243560237543923, 1.1816671064921787, 1.6482354934726442, 2.2371662173952376, 0.13248720578849316, 0.19702826254069805, 0.09126763511449099, 0.10834494339568274, 0.07856203296354838, 0.18949519390506403, 0.058410784628774436, 0.23406022042036057, 0.14343935810029507, 0.18673373279826982, 0.07471123816711561, 0.09404349473438092, 0.03804196064759578, 0.3559264396982533, 0.13067311527473585, 0.17283382080495358, 0.6804933792778424, 0.3769376293889114, 0.9943515977689198, 1.1782191715070178, 0.2044895693127598, 0.2511898912489414, 0.02793995164600866, 0.05998951170061316, 0.08994812877582652, 0.2678525128534862, 0.044280798374009986, 0.1002997165279729, 0.13962373855922902, 0.15433911393795693, 0.20002646451549871, 0.2514862482036863, 0.0697511811075466, 0.1914316921361855, 0.11566165435527052, 0.07375919925315039, 0.04694283713719674, 0.1098523089396102, 0.1376107558608055, 0.1495333896683795, 0.13864542676934175, 1.6737557926348277, 0.25252095982432365, 0.16228486757193292, 0.43955384514161516, 1.5359984189271927, 18.66364656175886, 43.72302654811314, 61.30820151737758, 74.59476920536586, 52.406238964625764, 29.56362267902919, 20.829136031014578, 30.313163076128276, 55.77301638466971, 67.80875546591622, 57.76910182407924, 32.965158462524414, 6.977827446801322, 0.06370292351182018, 0.04702115025637405, 0.09364713528858763, 0.1715900796864714, 0.007894327464912618, 0.07483129136796508, 0.042247863353363106, 0.05411438231489488, 0.05019563562901957, 0.0462576864021165, 0.06272905612630503, 0.04202415714306491, 0.022400108465392674, 0.014113507183667804, 0.08151964497353349, 0.023113455723172853, 0.055340013333729336, 0.06257292521851403, 0.019868967588990927, 0.06700751118894134, 0.029224486289811984, 0.04077907931059599, 0.034052140811192136, 0.022767382507611598, 0.02802169306336769, 0.034938056487590075, 0.050815541829381666, 0.045408866235188076, 0.07703167186783892, 0.040208397433161736, 0.011517227793644582, 0.03593765052833727, 0.0890929778771741, 0.019139232014172843, 0.01821863810930933, 0.0237583387975714, 0.023283310001716018, 0.02582760258311672, 0.014035876840353012, 0.012839145476131566, 0.017704094826642956, 0.016624742387128726, 0.014908238779753447, 0.06877907112772975, 0.09438821087990489, 0.09923586861363479, 0.34803882294467514, 0.11279412465436117, 0.20877800562552043, 0.11345144188297646, 0.1684363167732954, 0.14543974718877248, 0.10602379044783966, 0.1314065030642918, 0.08364411097552095, 0.07474490707474095, 0.11206388526729175, 0.1107264995308859, 0.2153473916862692, 0.2090194962386574, 0.14087782055139542, 0.09264918669526066, 0.2072328592517546, 0.11341012588569097, 0.16443746563579353, 0.139950371746506, 0.11868502997926303, 0.053113990995500765, 0.1334497212831463, 0.11573988944292068, 0.08313016819634608, 0.1463959387370518, 0.12263726576098374, 0.10126709711870976, 0.14200356443013462, 0.06449062802961894, 0.12338750836040292, 0.12992589894149983, 0.0918172484795962, 0.1259858360780137, 0.12058509087988309, 0.1133814442104527, 0.19828180170484952, 0.15536885868225778, 0.11601538823119231, 0.1484057866036892, 0.12755759459521088, 0.18301639226930483, 0.33210304805210655, 0.17412142242704118, 0.5534452966281346, 0.33718815233026234, 0.4746362769177982, 8.187342064721243, 38.010735307421, 71.54325239998954, 85.20402921949113, 88.04378577641079, 68.87155192238944, 45.737128666469026, 42.69108704158238, 69.42926297869, 70.60908794403076, 85.58230999537876, 72.48956230708531, 48.40718936920166, 13.58236118725368, 3.542379677295685, 0.36720928283674376, 0.43079341522284914, 0.4389867255730288, 2.6713133326598575, 2.403378418513707, 4.102435750620706, 7.151402567114149, 5.977683765547616, 11.419028265135628, 2.6657615048544745, 0.5630105776446206, 0.2242793823991503, 0.16422971178378376, 0.24741943499871663, 0.5751828987683568, 0.12650997723851884, 0.27338745870760506, 0.3131228765206677, 0.23099582056914056, 0.25053372074450764, 0.3924433487866606, 0.24607981688209943, 3.3089959834303175, 0.11918440461158752, 0.4316095571432795, 0.722792383815561, 0.7236308359674045, 5.836890246186938, 1.8231491191046578, 1.2043684997728892, 0.5938725216048104, 0.1334675531834364, 0.14188164525798388, 0.16139593241470201, 0.33543698915413445, 0.10692122764885426, 0.3453310882406575, 0.29355992483241217, 0.2758106972490038, 0.2341285896088396, 0.9379348307847977, 0.3599591904452869, 0.32844932696649004, 0.4024449549615383, 0.19375118267323288, 0.11378894520125218, 0.5265230898346219, 0.7333027284060205, 0.6390986719301769, 1.2282579264470508, 2.925016816173281, 0.19559926779142447, 0.40129016978400095, 2.322417574269431, 15.6680314881461, 43.37039157322475, 64.40379769461495, 69.63027436392647, 68.3777573449271, 44.03718934740339, 34.62308202471052, 47.36966003690447, 55.711135728018625, 68.38697065625871, 72.98953383309501, 67.46035889216832, 37.359049865177695, 6.679602946553912, 0.20957939619464533, 0.2810864970088005, 0.28099066072276657, 0.25578921873654636, 0.09828159731945821, 0.19243451261094638, 0.0885600768295782, 0.195646697389228, 0.163302941513913, 0.20925737704549516, 0.1447716751801116, 0.13318849887166703, 0.20415384375623294, 0.13633397008691514, 0.19929568230041436, 0.10929015624736037, 0.08809513784945011, 0.11346580646932125, 0.17228089618895734, 0.16361166137669766, 0.10972863236176116, 0.13689368005309785, 0.2263623491993972, 0.13506243617406913, 0.08485974717353072, 0.18193503815148557, 0.1487408879079989, 0.09951049887708255, 0.18172925205102988, 0.17701500787266664, 0.1038439084908792, 0.07045736642820494, 0.12128299128796373, 0.2198267270411764, 0.053715597106409926, 0.1288965477475098, 0.12386421992310456, 0.13306586045239652, 0.13334571543548787, 0.05238324609984245, 0.09000174661300012, 0.07861749641597271, 0.08983873536012002], [0.011410225365710045, 0.05356930156371423, 0.04404083785734006, 0.02153017737769655, 0.03720628370397857, 0.09164380814347949, 0.028902138051177775, 0.03352776894878064, 0.02252322864452643, 0.036579483587827, 0.040929965142692835, 0.029658758879772255, 0.027256828034296632, 0.053031253828001876, 0.027251420110198002, 0.056047175744814534, 0.016521409985476306, 0.10336237254419497, 0.034742339846811125, 0.04043804082487311, 0.03977266938558646, 0.027263116357581954, 0.022633059715319957, 0.01573956461756357, 0.0625991438116346, 0.01550433857898627, 0.05084403012213962, 0.10256023558654956, 0.00522166326741821, 0.07901020534336567, 0.06287714639412505, 0.03599687306476491, 0.021416453212233524, 0.015890587853001695, 0.015550981076168162, 0.02096169225738517, 0.047981100888656716, 0.06252533277230603, 0.03537281762276377, 0.03744248852932027, 0.02341678971424699, 0.07318178630833115, 0.07146455666848592, 0.0327571194086756, 0.025212882086634636, 0.047023436919386895, 0.03250679766227092, 0.3105208304311548, 0.03508065062175904, 0.11069489336971726, 0.12021974048444203, 0.7539989149996212, 4.29369056224823, 15.1709851537432, 32.64661829812186, 63.757052421569824, 74.46101638248989, 51.234612873622346, 34.895135266440256, 39.11736100060599, 45.145347118377686, 62.087101527622764, 67.2176513671875, 59.30906581878662, 44.11498832702637, 11.64444693497249, 3.3315741547516415, 0.36324579694441383, 0.03261290018313697, 0.14161666376250132, 0.055649750999041965, 0.1444531844130584, 0.5666474710617746, 0.2879442333110741, 0.0376305343317134, 0.2476167529821396, 0.36496411902563913, 0.22924503737262317, 0.21631800888904504, 0.37998132035136223, 0.19997899420559406, 0.16823754672493252, 0.7603626506669181, 0.18981121480464935, 0.40671511154089657, 0.0650913757937295, 0.727428026497364, 0.6657553272587913, 0.13111153032098496, 0.09791227749415807, 0.8984485981719834, 0.8115648488913263, 0.0545325125567615, 0.9939101700271878, 0.34121748326080187, 0.23183174857071467, 0.018697997654921243, 0.08177887249205794, 0.03615219990855881, 0.01964096455568714, 0.07014647525336061, 0.01067377399054489, 0.10850671971482889, 0.20761055898453507, 0.15419693371014936, 0.42731752459492, 0.3798342953835215, 0.4356112852692604, 0.7468885736806052, 0.3761184476315975, 0.7579000570944378, 0.48799277735607965, 0.2614768078284604, 0.41469300059335573, 0.5219488952841077, 0.32143430624689373, 1.8928805887699127, 10.523995195116315, 28.62706630570548, 37.73403024673462, 43.59392901829311, 46.44577891486031, 34.27960824966431, 32.31048876898629, 40.3150497845241, 60.911994389125276, 59.85098361968994, 61.15976020268032, 46.35648761476789, 32.276553767068044, 8.22155933720725, 0.05745094256209476, 0.16487212159803935, 0.03297067473509482, 0.06182457573179688, 0.13932548170643194, 0.0860681434028915, 0.020038502956075326, 0.05825374448405845, 0.026939724871356572, 0.021958360115864446, 0.022298674265454923, 0.017829812098560587, 0.03002179886347481, 0.0508950966676431, 0.03724422738222139, 0.020330476574599743, 0.055770805039043934, 0.0300186911730894, 0.018502153788826296, 0.004232621718464153, 0.02978419964866979, 0.022285992445956384, 0.051714702509343624, 0.020520415489694903, 0.04720889411068388, 0.006375014615644301, 0.05717866002981152, 0.034318187606654, 0.00830127629784069, 0.04936125807996307, 0.04060666016968233, 0.06288594699331693, 0.01587793996025409, 0.026937663821237426, 0.05969151269112315, 0.015596911111580474, 0.021814912723909532, 0.08165067687098469, 0.009059629935239042, 0.015206400637647935, 0.06260273326188326, 0.008534002783043044, 0.11440781663571085, 0.012679761841094919, 0.05790383754564183, 0.032138672058603594, 0.02458179023649011, 0.045436849019357135, 0.03330781842981066, 0.048911575959729295, 0.04115627692746265, 0.038660051766783, 0.022964768344536424, 0.006343115836248866, 0.013581860577687621, 0.02551709478055792, 0.06350240284310919, 0.041535622107663324, 0.03234680249754872, 0.029151326644101312, 0.04647073282727173, 0.09356341085263661, 0.04873674462682434, 0.04701600017558251, 0.031028656621596644, 0.013630643004684575, 0.028410870215988586, 0.037218137710754357, 0.05381369969940611, 0.06049027732972588, 0.01841748788553689, 0.01628019587535943, 0.0868164182507566, 0.015469254925847054, 0.05672195507213473, 0.046619613588388474, 0.010043701639265885, 0.019758922779666524, 0.03952894299956305, 0.026305857812985778, 0.035863890379135094, 0.028310192582596625, 0.0215988536032715, 0.0376528750972024, 0.050607024625475915, 0.020008075749501586, 0.06728995817580394, 0.04596049824197378, 0.0610091666291867, 0.14085887585367474, 0.035163754198168, 0.0457206666469574, 0.23519036120602063, 0.017020616680383682, 0.10825425719044038, 0.27941054265413967, 1.4142743391650063, 9.84221797330039, 29.109059367861065, 57.47513396399361, 78.78595038822719, 65.43776607513428, 37.164006982530864, 29.663166046142578, 46.87010540281023, 59.888281549726216, 81.91582897731236, 76.57328959873745, 54.27470684051514, 35.89742333548409, 10.237447142601013, 2.9657858056681494, 0.7922237238713673, 0.059868176068578444, 0.082122028007039, 0.08236853299396378, 0.048993383534252644, 0.27805279408182415, 0.0811747456235545, 0.024565069437293068, 0.08222320436366967, 0.321926868387631, 0.28099399911505835, 0.06279334053397179, 0.1840833750154291, 0.05339624120720795, 0.1119230417534709, 0.5314294408474649, 0.5256988054939679, 0.43144385889172554, 0.23596627957054547, 0.6168745330401829, 0.7734281410064016, 0.42824907175132204, 0.642941622861794, 1.7009989193507602, 2.2718533618109564, 1.0925447344779968, 2.506661219256265, 1.295616694859096, 0.1203525433582919, 0.1030529537903411, 0.09820144876305546, 0.08175295245434556, 0.1239253423575844, 0.05297913894589458, 0.12130954914859363, 0.0724773108959198, 0.17588010377117566, 0.21847425747130597, 0.21656807618481771, 0.031004046156470264, 0.22883398085832596, 0.9331671723297664, 0.4552863309425967, 0.337953295558691, 0.23450210956590517, 0.1063476280708398, 0.3127637415059975, 0.5513515546917915, 0.528914464371545, 0.4970536082983017, 6.240761237485068, 22.643260308674403, 36.70898682730538, 51.37302098955427, 63.76289585658482, 54.34249694006783, 42.536236013684956, 23.809081179755076, 37.325375420706614, 56.082669803074424, 69.89239515577043, 55.92423003060477, 39.89553492409842, 13.731246318135943, 0.3723196286175932, 0.0966045640941177, 0.08180325225527797, 0.07185567782393523, 0.14882083290389606, 0.1211088520607778, 0.018023301448140825, 0.049063947783516984, 0.02870323568848627, 0.08919585735670157, 0.07982986886054277, 0.04717533037598644, 0.04407831334642001, 0.08523712120950222, 0.02014186080279095, 0.021515275052349483, 0.04052703069256885, 0.10064659720020634, 0.057129350890006335, 0.0358079112400966, 0.00680780248616689, 0.012347085451308106, 0.07147656673831598, 0.0855281041668994, 0.04529402079060674, 0.0486446436760681, 0.01071713153006775, 0.017230955750814507, 0.023735385654228072, 0.013098719895684292, 0.04381981525304062, 0.02591250597366265, 0.04526360206572073, 0.03072518522718123, 0.01564954168030194, 0.06794091753129448, 0.010083647843982493, 0.05950847786984273, 0.061732579953968525, 0.029639586872820343, 0.014145318601679589, 0.012526871786186737, 0.021359076291056614, 0.021105942016999637, 0.009105327572407467, 0.09175802594316856, 0.19424530544451304, 0.1290444548108748, 0.06138329726776906, 0.1599272433668375, 0.12100183351763658, 0.18372312720332826, 0.15015552485627787, 0.1965748925826379, 0.10183480022741215, 0.0694834515452385, 0.15528990434748785, 0.13029533411775315, 0.20090139470994473, 0.13699328899383545, 0.1003873764670321, 0.20284980801599367, 0.24900492706469127, 0.08967835682311229, 0.10471310506441764, 0.10976735635527543, 0.17644133365580014, 0.1635295179273401, 0.16659283212253026, 0.146516636546169, 0.09652774035930634, 0.16236456829522336, 0.21872940020901815, 0.07017293133373771, 0.154458970363651, 0.1992345598659345, 0.08727981695639235, 0.07954518270811864, 0.09399282852453844, 0.11988709547689982, 0.08599342991198812, 0.17397052980959415, 0.08836264349520206, 0.10971303962703262, 0.3284214256065232, 0.1638018547424248, 0.15033252750124249, 0.17699246693934712, 0.09293852759791271, 0.18919211945363454, 0.1902269260691745, 0.13534078480941908, 0.46131364894764765, 0.09835875353642873, 0.1742585679250104, 0.38269489045654026, 1.225317318524633, 9.925335798944745, 37.42163576398577, 76.1152435030256, 93.69696521759033, 93.10785525185722, 67.61230209895542, 49.94962692260742, 57.70265620095389, 62.64987782069615, 78.04297256469727, 87.41704436710903, 79.54786205291748, 58.741939953395296, 19.984740563801356, 6.490393510886601, 1.4734560549259186, 0.09638834891042539, 0.1643789080636842, 0.27961581306798117, 0.2492512081350599, 1.3250633776187897, 0.4316311074154717, 0.10179364029318094, 0.27563083118626047, 0.7409555177603449, 0.4854132043463843, 0.3333918574665274, 0.9484329074621201, 0.4594650481428419, 0.389117278690849, 1.6959020899874824, 1.36587535909244, 1.1137231694800513, 0.7037434088332313, 3.318024298974446, 1.1052801311016083, 0.7412433794566563, 3.858685995851244, 6.029392693723951, 4.775703600474766, 0.9416816468749727, 7.9052643094744, 3.437442336763654, 1.0808288774320056, 0.11752040604395525, 0.20140849107078143, 0.15118486247956753, 0.26953272840806414, 0.20048093370028905, 0.24680796638131142, 0.20288302909050668, 0.21755701383309706, 0.22320866771042347, 0.689660333096981, 0.44115896044032915, 1.7493639183895928, 1.4266624344246728, 1.3666319527796336, 1.668917023709842, 1.432057493499347, 0.8634772832904543, 0.4816890241844313, 0.6830460823007992, 0.5357621854969433, 3.45959341100284, 21.70751861163548, 48.800509520939414, 62.29992485046387, 61.335334232875276, 63.67284025464739, 48.02356195449829, 49.49558646338326, 53.42019305910383, 72.58628817967006, 72.19846752711705, 81.48590918949672, 66.37161786215646, 45.604616097041536, 13.575982740947179, 0.3462255602436406, 0.1987040133348533, 0.3683282413652965, 0.13475291563996247, 0.26075699073927744, 0.2049107359988349, 0.10415921692869493, 0.1924331555409091, 0.11354089315448489, 0.19779598420219763, 0.19545901460306986, 0.08113534309502159, 0.07531472042735134, 0.15267749024288996, 0.12438808966960226, 0.12646811162786825, 0.11228473484516144, 0.14516842817621572, 0.15359187046332018, 0.10466919027801071, 0.13604772330394813, 0.11109545973262616, 0.19574652346117155, 0.2202206166195018, 0.1019894519288625, 0.13641187947775635, 0.13096017629972526, 0.050886835503791056, 0.12256170410130705, 0.127650418185762, 0.13023121255849088, 0.14917969650455884, 0.10866516442703349, 0.13821599552673952, 0.0991904271234359, 0.13843622085239204, 0.08317686497632946, 0.18425052533192293, 0.17092645886753285, 0.1330448801496199, 0.13613463006913662, 0.09524030158562319, 0.3408139449145113, 0.10552288911172322, 0.10089291898267609], [0.009499129789349223, 0.031199318356812, 0.02705373741420252, 0.012268723986510719, 0.022098613304219077, 0.04565372916736773, 0.07322234234639577, 0.06820301525294781, 0.018620285039235438, 0.039569661886032136, 0.06097638660243579, 0.02523515499862177, 0.039447145603064976, 0.026334376639819572, 0.06372466377381768, 0.04796241742691823, 0.08036995559398617, 0.044176439688141854, 0.06057655984269721, 0.06836288488869156, 0.02466141462459096, 0.044037105914737494, 0.04855875132073249, 0.05316333406205688, 0.0695872199056404, 0.03984847192519477, 0.06895745119878224, 0.025837000293125, 0.032542325755847354, 0.03540455949093614, 0.07684406372053282, 0.027740150224417448, 0.021414119051769376, 0.022031855636409352, 0.05044932630179184, 0.05530125541346414, 0.036231127101927996, 0.021683161579338566, 0.06198120875550168, 0.04933205054008535, 0.04302213627046772, 0.0777605338288205, 0.027301200831841146, 0.08020441340548651, 0.18409408229802335, 0.039627116838736196, 0.042268606168883185, 0.1076017100630062, 0.11888050234743527, 0.16602242844445364, 0.01696644414083234, 0.15672815431441578, 0.20645786369485514, 1.6552212557622363, 6.480939183916364, 31.284187725612096, 53.99743550164359, 49.417658942086355, 61.28387587411063, 44.17598308835711, 40.725941930498394, 24.92915163721357, 40.979665824345176, 56.475253445761545, 67.51880019051688, 64.62247834886823, 44.037422112056184, 28.52457169124058, 17.29955015863691, 10.421243497303553, 4.866530018193381, 1.9006323899541582, 1.0905158604894365, 0.9932204527514321, 0.401662142681224, 0.10369653068482876, 0.0409673863489713, 0.18009269343955175, 0.49318357024874004, 0.4703951616372381, 0.12916786676006659, 0.6014740679945264, 0.40660660022071426, 0.4454374765711171, 0.30592679551669527, 0.20440860651433468, 0.09822001348116569, 0.2635657728782722, 0.07275043481162616, 0.46183166972228457, 0.7077758610248566, 1.742996980037008, 1.0714733451604843, 1.5332073058400835, 0.576057177569185, 0.15486966046903813, 0.20282873271831445, 0.0759773166584117, 0.07622724146183048, 0.061404657550156116, 0.12009537858622414, 0.21286601626447268, 0.13807927072048187, 0.43816056847572327, 0.24552933499217033, 0.5466566351907594, 0.5211119630507061, 0.1303232761898211, 0.25421957724860733, 0.04398491300110306, 0.1184294665498393, 0.33023297839931076, 0.5413566253014973, 1.4650081310953413, 3.869334544454302, 11.455545391355242, 24.398951973233903, 34.52493871961321, 44.775977407182964, 38.361438683101106, 32.29948282241821, 25.935787541525706, 39.73631695338658, 51.34593691144671, 64.31455503191266, 57.96045173917498, 41.64037002835955, 18.457389286586217, 4.156372444970267, 0.07226706682039158, 0.2571701189236981, 0.08486812708101102, 0.0649499080276915, 0.02240883612207004, 0.01726352034269699, 0.036719200733516894, 0.08996969261871916, 0.023672198776953986, 0.10064453445374966, 0.02386287729521947, 0.023242677628461803, 0.011149444850161672, 0.056939171094979556, 0.01866240849319313, 0.06252820297543492, 0.021315521128209572, 0.039809344203344414, 0.052061539076800854, 0.0268291134852916, 0.049479502984987836, 0.020656750138316835, 0.03760871264551367, 0.03431918166045632, 0.06395920618836369, 0.020599376609815017, 0.0031212197375550333, 0.02816975279711187, 0.0895550941516246, 0.017454465185957294, 0.030604429742587463, 0.02136361738666892, 0.04137796110340527, 0.10776241429682289, 0.033007715961762836, 0.039574208070657084, 0.033955758304468224, 0.049619284591504505, 0.005193093974542404, 0.03422409176294293, 0.04242280664454613, 0.03903274730380092, 0.020310147665441036, 0.07160041973526989, 0.01800132030621171, 0.008548695610703101, 0.034537120323096, 0.026305062230676413, 0.016578861545505266, 0.016003794635512998, 0.03417210240981408, 0.03837450048221009, 0.0254065834784082, 0.053020234419299025, 0.03156799018116934, 0.0207821484987757, 0.036231144065303464, 0.0304926580616406, 0.03691662049719265, 0.03890246179487024, 0.03294405919898834, 0.013436962817130345, 0.02567530200550599, 0.048837249233786545, 0.09800546070826904, 0.026178410276770592, 0.065376584418118, 0.04372074235496776, 0.051002671609499624, 0.013340564195199736, 0.07816947331385952, 0.018688016404796923, 0.06293320017201559, 0.08128772848950964, 0.017831169168597887, 0.04747888658727918, 0.02643636554213507, 0.1260121360953365, 0.05118131630920938, 0.02225258986332587, 0.025406564818695188, 0.04115255516288536, 0.03283531378422465, 0.04210282310045191, 0.05706933446760688, 0.07910985499620438, 0.04538553820124694, 0.02658411654244576, 0.07331638729998044, 0.06311901698687247, 0.07378330081701279, 0.04189253492014749, 0.03290258713864854, 0.03328978975436517, 0.1687544004193374, 0.26689906258668217, 0.10627159822200026, 0.04031757711033736, 0.20247057479407105, 0.28385399707726067, 3.646372062819345, 14.821534190859113, 49.2638292993818, 74.03548090798515, 64.99735450744629, 57.72894818442208, 39.27024221420288, 34.75073085512434, 33.106682845524375, 60.50138364519392, 79.59228188650948, 82.96185943058559, 58.04409415381295, 38.45236280986241, 19.078721523284912, 8.15974121434348, 5.133964879172189, 1.6676675421851022, 0.4514169714280537, 0.15462495359991277, 0.21485712299389498, 0.3728189489671162, 0.0661575917952827, 0.02433442690276674, 0.07724919662411724, 0.2728218861988613, 0.19729050275470528, 0.030302627544317926, 0.17382995092443057, 0.22050695839737142, 0.7046652936509678, 0.18422456458210945, 0.04220171279406973, 0.1211985679609435, 0.0998829806755696, 0.062174862649823935, 0.07373471092432737, 0.7005307355097362, 1.5794622238193239, 1.6785974928310938, 0.8190457246133259, 0.18424715979823045, 0.03137074683659843, 0.06814285633819443, 0.16490722899990423, 0.07139412473355021, 0.06481116797242846, 0.0180428178116147, 0.16211477241345815, 0.028063312705074037, 0.360710084438324, 0.17677415508244718, 0.15231773097600254, 0.2781169020703861, 0.1375449379639966, 0.2789563855954579, 0.07110609340348414, 0.7113660169499261, 0.4774201703923089, 0.4012522803885596, 0.40850229135581423, 1.4900309826646532, 8.139250976698738, 23.620699882507324, 36.939434255872456, 62.671931403023855, 60.53105245317732, 53.110862731933594, 39.891244411468506, 24.707340819495066, 39.46992996760777, 59.42885971069336, 70.67960521153041, 58.15124232428414, 28.89068443434579, 8.223088809422084, 0.5658171613301549, 0.1990772754486118, 0.061682110519281456, 0.0735109436458775, 0.048750505317002535, 0.021239292807877064, 0.09894228686711617, 0.0724838859002505, 0.05672008910083345, 0.04228545080072113, 0.0572822384004082, 0.020678373353023614, 0.031090701863701855, 0.04149183285023485, 0.022346546607358114, 0.033824692480266094, 0.026504475190969448, 0.05914536663996322, 0.026763687442455972, 0.021046198704945188, 0.02779851950305913, 0.029787901057196513, 0.029715141747146845, 0.05010909866541624, 0.10266797337681055, 0.06499000944729362, 0.04134120825412018, 0.04736949656424778, 0.06433442248297588, 0.05646982502990535, 0.06131686868944338, 0.04107507324910589, 0.06761341581919364, 0.021311030922723666, 0.01580056661207761, 0.02173746982589364, 0.027149500757721916, 0.0382675633632711, 0.015024071492786919, 0.07346073205449752, 0.09563691208937339, 0.06038744534764971, 0.056830517282443385, 0.05132722169426935, 0.0829725648675646, 0.018049642177564756, 0.03208603809720703, 0.12428204821688787, 0.09124823579830782, 0.13053971529006958, 0.09110385711703982, 0.09767879359424114, 0.09905223668153797, 0.22269363248986856, 0.10533246504408972, 0.09546526987105608, 0.21042373803045067, 0.11566074511834554, 0.08533770045531647, 0.17566272829260143, 0.07602615760905401, 0.18764705450407096, 0.14832989924720355, 0.18956371237124714, 0.10483985540590116, 0.22208513585584505, 0.18004677018948964, 0.14449753346187727, 0.15935689397156239, 0.12171098403632641, 0.20733645797840186, 0.14713646471500397, 0.1850203097398792, 0.15673119415129932, 0.10917228792927094, 0.08282856616590704, 0.11831300279923848, 0.26319664982812746, 0.1672278187636818, 0.1582594992859023, 0.1516382052962269, 0.17714995491717542, 0.13741251506975719, 0.14988997339137963, 0.11295338360858814, 0.143585880952222, 0.1543112261486905, 0.16570947452315263, 0.14621430848326, 0.13712807318993978, 0.19617353911910737, 0.19162907797311032, 0.08959219644644431, 0.10419259406626225, 0.3031772901969296, 0.21971008687147073, 0.31440294640404837, 0.14277325384318829, 0.2312304036957877, 0.42203960780586514, 2.680742906672614, 15.48140982219151, 58.400262287684846, 89.86452647617885, 81.21139975956508, 85.53557641165597, 64.93713447025844, 60.59107099260603, 39.746270247868125, 61.70235892704555, 80.1543355669294, 90.34928144727434, 89.106429372515, 65.71844550541469, 43.061036927359446, 25.123108863830566, 14.930659123829432, 7.869098935808454, 3.3287764191627502, 1.585333017366273, 2.42877864411899, 1.0358006422008788, 0.22947378509810992, 0.09076171940458672, 0.2209051770291158, 0.36788952776363915, 0.5307355980787958, 0.11136937753430434, 0.6643100476690701, 0.9859621907983507, 1.3540460509913308, 0.5116891743881362, 0.28281041021857944, 0.1933811910982643, 0.4299956480307238, 0.19291752097862108, 0.6999136486223766, 2.8957614260060445, 7.576923710959298, 6.233702736241477, 3.1164514124393463, 1.11806611929621, 0.2989404632576874, 0.35807763997997555, 0.35538138608847347, 0.18928642225052628, 0.15950068911271437, 0.2219293713569641, 0.39929649819220814, 0.20085970551839896, 0.37217054090329577, 0.3023283343229975, 0.40023678487965036, 0.525691531598568, 0.21014925704470702, 0.42172232483114513, 0.5864687274609293, 0.6477700780544962, 0.8163268619350025, 1.637822966490473, 4.961190973009382, 11.161370822361537, 26.22201337133135, 53.487399509974885, 63.76288196018764, 66.85995810372489, 54.68788146972656, 51.157727582114084, 45.79078265598842, 55.77220344543457, 64.42610836029053, 78.82864012037004, 81.51122842516217, 71.07655579703194, 37.36851678575788, 8.639113068580627, 0.4513630414647715, 0.4337325303682259, 0.29820181003638674, 0.21576949475067003, 0.15122315899602004, 0.16080982743629388, 0.2626209264355046, 0.15517363058669226, 0.23109092403735432, 0.17051529378763267, 0.15106264475200856, 0.10892004932143859, 0.09024299973888056, 0.14170861882822855, 0.12845478073826858, 0.1842331276940448, 0.16040626194860252, 0.16171123406716756, 0.1701911711799247, 0.12139045766421727, 0.10090586543083191, 0.08631632437131234, 0.12643100933304854, 0.11185203984911953, 0.20201488424624714, 0.19913313245134695, 0.19139667972922325, 0.14294834301940032, 0.19261927769652434, 0.14043040813079902, 0.11631929049534456, 0.11058796303612844, 0.20422270148992538, 0.19755789983485425, 0.04950843232550791, 0.18609132298401423, 0.12854261031108244, 0.14817526111645357, 0.1337368365909372, 0.1586803945579699, 0.23928751849702426, 0.09684441265250955, 0.11350822169333696, 0.1648416825171028, 0.16551819550139563, 0.0712281550679888, 0.10381606141371386], [0.05104808595829776, 0.03528056400162833, 0.013143087604216166, 0.013674538283209716, 0.06026516655193908, 0.06436314487031528, 0.037289448348539214, 0.07256438050951276, 0.039730922518564124, 0.04806005861610174, 0.013974165776744485, 0.0355008707514831, 0.02054643052230988, 0.0117642052105761, 0.010982465015591254, 0.025859402126765678, 0.007553360225366694, 0.037052096799016, 0.06262820546648332, 0.08677749748208693, 0.07038510244871889, 0.04496419170339193, 0.03576813890997853, 0.03732560747968299, 0.05100076153342213, 0.009457837540789374, 0.03922206196667893, 0.062106452749243805, 0.0381457697200988, 0.0494769109812166, 0.07876809047801153, 0.027650770199085985, 0.007936109106854668, 0.017631673087765063, 0.05338037705847195, 0.015299056290781923, 0.03638221649453044, 0.01313655246381781, 0.05714702672724213, 0.05526988334687693, 0.044925922328340154, 0.055670137583677254, 0.0519939434182431, 0.005052308136198137, 0.059625036615346155, 0.040482780031327686, 0.005544306668785534, 0.20488747581839561, 0.052205741338964017, 0.08711154027176754, 0.19729674527687685, 0.03084778632702572, 0.04446153974692736, 0.084346828982234, 0.21349317261150905, 1.2075242847204208, 8.883617571422032, 21.47688010760716, 53.477762358529226, 62.32990632738386, 60.588632174900596, 52.603008474622456, 33.7004793712071, 24.956815889903478, 19.316309962953838, 50.37581205368042, 55.45680386679513, 65.97021348135812, 65.15225069863456, 55.4103273664202, 36.92309209278652, 33.77316100256783, 27.016088247299194, 19.508976561682566, 15.308210338865008, 13.49146398476192, 14.973312377929688, 10.068462610244751, 8.134601763316564, 4.900706470012665, 2.8090724434171404, 0.7551874912210873, 0.08937897360218422, 0.4188872698162283, 0.22447534331253596, 0.06297553397182908, 0.039438372145273855, 0.1777526025793382, 0.25471037519829615, 0.2572329784078257, 0.5361472676907266, 0.752193631870406, 0.9643595899854387, 0.4406151281935828, 0.4253785157842295, 0.24672114104032516, 0.22072016767093114, 0.21813234367540904, 0.033123850622879605, 0.128245724099023, 0.14361779923949922, 0.1601989966418062, 0.36167108001453535, 0.6866303214005062, 1.0279680682080132, 1.9928428019796098, 3.525939805167062, 3.00192078096526, 3.907636489186968, 3.9609426345144, 6.21155274765832, 6.665076868874686, 10.121964607919965, 10.089836137635366, 24.208995171955653, 28.813458681106567, 32.52011592047555, 61.8620354788644, 34.1273523739406, 39.56796210152762, 35.60091243471418, 38.839307989392964, 62.35432229723249, 67.03648403712681, 52.19629567010062, 17.312202828271047, 3.2534106118338446, 0.16762862939919743, 0.17460680566728115, 0.026083457782598476, 0.21432378089853696, 0.014948336806680475, 0.08181751506136996, 0.0821837814790862, 0.09447992167302541, 0.04873923485034278, 0.14673395774194173, 0.0484765637665987, 0.03875205772263663, 0.01241340461586203, 0.02419154778388994, 0.038454842421093156, 0.029280037951788733, 0.07072645984590054, 0.049463509914598296, 0.017488210428772227, 0.10745849167662007, 0.05387479159981012, 0.11777686513960361, 0.02737882693431207, 0.07406747128282275, 0.027539792404110943, 0.04015532920935324, 0.01813169741736991, 0.008365671815616744, 0.021414373502401367, 0.009663812782881516, 0.0685028802337391, 0.014316751322309886, 0.08712507704538958, 0.029880429485014508, 0.006422234291676432, 0.02754697808995843, 0.013983340418365384, 0.13603294481124195, 0.028882677666842937, 0.05952400275106941, 0.025853268170197095, 0.04775113858548658, 0.047315600527716536, 0.05881340695278985, 0.07932499809456722, 0.033008910183395655, 0.010102835966141095, 0.03779896368671741, 0.030764204383428608, 0.012084030147109712, 0.019091680280065963, 0.01861059555916914, 0.006201873259020171, 0.05189441250903266, 0.07418689344610487, 0.034992271435580084, 0.0271645201303597, 0.06062230667365449, 0.015358282219884651, 0.022358931567785994, 0.03098274694223489, 0.04639195491160665, 0.057459281757473946, 0.05893987909491573, 0.07038236116724354, 0.029778340498783758, 0.06386034363614661, 0.006591844721697271, 0.03364387307582157, 0.022028620720707943, 0.033971323897796016, 0.02607053847584341, 0.0410518775294934, 0.04569337596850736, 0.05183102376759052, 0.012856315804778464, 0.009335784357972443, 0.07791235603924308, 0.022126898036471436, 0.01670026503104184, 0.054355394560843706, 0.02146880897427244, 0.04016866581514478, 0.016723671096510122, 0.000538117391572866, 0.10617649475378649, 0.10952723638287612, 0.032266820182225535, 0.03142293296488268, 0.05687532094972474, 0.05469352891668677, 0.051503457594662905, 0.020076879200392535, 0.032213612858738215, 0.06821066234260798, 0.04936769398461495, 0.07583451217838696, 0.07556602265685797, 0.07981817770217146, 0.2143380165632282, 0.0367705556564033, 0.006025672133546323, 0.23692447958248003, 0.20124386490455695, 3.9197372112955366, 19.04132284436907, 35.538076400756836, 74.66262531280518, 70.8300267628261, 62.27564089638846, 40.49554661342076, 32.1938076700483, 33.308114596775596, 38.26219408852713, 74.9711183820452, 68.43938091823033, 70.89479092189244, 61.170974595206125, 46.54231718608311, 25.4590334211077, 17.13998130389622, 12.01548421382904, 7.901775445256915, 4.631696105003357, 2.8619475833007266, 3.089893877506256, 2.4205191901751926, 3.0981446462018147, 1.1693835599081857, 0.5302228970187051, 0.28443387310419765, 0.15265037598354475, 0.45962159974234446, 0.38288284465670586, 0.07509522791951895, 0.0797311013032283, 0.26917465190802303, 0.09278635254928044, 0.21895704870777472, 0.43060741520353724, 0.4924086832574436, 0.3775440497057778, 0.3149137204246861, 0.17144129052758217, 0.11598432489803859, 0.2958302487220083, 0.2084658116634403, 0.038735287729650736, 0.09275575061993939, 0.08910390229097434, 0.21812323773545877, 0.23693957020129475, 0.5209630653262138, 0.3498626707920006, 0.42183919570275713, 0.9923172955002103, 1.4277682836566652, 1.5195120807204927, 0.8314812630414963, 4.048869916370936, 5.341592686516898, 8.354949116706848, 14.768568073000226, 26.21059226989746, 48.577350752694265, 57.810641629355295, 69.63206699916294, 55.6156952721732, 42.07420860018049, 27.056832483836583, 21.74175759724208, 54.97648879459926, 72.38276849474225, 66.97497163500104, 30.023958206176758, 6.727979344981057, 0.6325618284089225, 0.23455802085144178, 0.05300109973177314, 0.27020776218601633, 0.06268550774880818, 0.028468062236372913, 0.08133924965347562, 0.11420793378991739, 0.04116419543113027, 0.1513293632971389, 0.07592990741665874, 0.034456221985497644, 0.006771485171546894, 0.079857966995665, 0.024837850692815015, 0.07303151115775108, 0.033540393092802594, 0.05848914185272796, 0.024851504513727765, 0.1036353132554463, 0.011361115545566593, 0.061406523521457396, 0.08390029187181167, 0.04043530293607286, 0.033807576434420686, 0.01545411511324346, 0.03804949917165296, 0.04017811441527946, 0.015292264155245252, 0.021410521119832993, 0.034551240636834075, 0.017349892761558294, 0.09834760520607233, 0.052230568935296366, 0.053481519488351684, 0.02823217462615243, 0.05080159454207335, 0.07061706643019404, 0.06266645448548452, 0.04104809130408934, 0.016497011562543254, 0.03808345984933632, 0.047975692964558087, 0.01880732660980097, 0.08356072580707924, 0.07958826289645263, 0.04593128052407077, 0.06581479590386152, 0.014948236722765225, 0.1320230064115354, 0.12936979878161634, 0.1216702719352075, 0.1332105512597731, 0.21088035138589994, 0.17338411270507745, 0.23470151743718556, 0.1665450089744159, 0.1671261199350868, 0.13284510586942944, 0.11199164164385625, 0.18337631438459667, 0.15823524844433579, 0.1319986605750663, 0.1356340612151793, 0.1564533883439643, 0.18732780377779687, 0.11583567144615309, 0.23822664256606782, 0.15380149707198143, 0.11841719863670212, 0.09819385595619678, 0.12716697555567535, 0.10036628081330232, 0.14002391137182713, 0.1145967072142022, 0.11157306017620222, 0.1509666863296713, 0.1441901842398303, 0.14207037298807076, 0.18089780238057884, 0.17621158169848578, 0.13514311398778642, 0.16100633117769445, 0.16289849393069744, 0.14536079285400255, 0.2239796734814133, 0.10702699768756117, 0.14020533806511334, 0.22421629221311637, 0.14211557699101313, 0.12620173235024723, 0.2242291300956692, 0.13161941378244332, 0.16284431969480856, 0.1466899343899318, 0.1155185377491372, 0.21749260728912695, 0.1319146172276565, 0.20817679645759718, 0.2699809686413833, 0.12549791511680397, 0.10996794487748827, 0.3404984532722405, 0.3752390391060284, 3.2601607867649625, 18.524144104548864, 45.23877259663173, 87.3741044998169, 89.0683810370309, 83.6933935710362, 72.96625736781529, 51.71399688720703, 42.125006880079, 35.52184540884835, 70.83730847494942, 77.08218955993652, 88.33026000431606, 86.18180751800537, 81.09660857064384, 53.63307196753365, 49.187082971845356, 42.038908277239116, 33.07812574931553, 30.497655119214738, 23.42296804700579, 22.026093517030986, 14.462813462529864, 12.111402358327593, 7.204204533781324, 3.827913727079119, 0.6681812799402645, 0.18056207682405198, 0.5739335800920213, 0.2945086253540856, 0.09419507267219679, 0.13586256466805935, 0.29652056310858044, 0.4098843586231981, 0.766411328954356, 0.8773609240140233, 2.0620598878179277, 2.6445336725030626, 1.9335883472646986, 1.168960805450167, 0.36162176408937996, 0.49712732434272766, 0.5258204532521111, 0.3043404349258968, 0.1745699747864689, 0.23780312814882823, 0.31089369899460245, 0.4618139735289982, 0.6779583181653703, 0.7504610876951898, 2.344602086714336, 3.734423977988107, 4.680369973182678, 7.114002585411072, 8.120146904672895, 16.889278139386857, 22.60689343724932, 32.148112842014854, 38.80588368007115, 58.28150715146746, 60.25048419407436, 60.126111439296174, 81.50008351462228, 56.92753601074219, 59.249985286167686, 53.44032893862043, 53.894814082554404, 76.0796617780413, 81.47710582188198, 77.40065329415458, 39.44230393001011, 7.400213650294712, 0.4447255033467497, 0.30266863320555004, 0.19938321331782, 0.5007482586162431, 0.20533422327467374, 0.2406784881438528, 0.2178491231586252, 0.1760733641151871, 0.09897848671036107, 0.3082110700862748, 0.18495511609528745, 0.153151379099914, 0.10042684684906687, 0.17414589039981365, 0.11446177374039378, 0.13063424878886767, 0.21122309299451963, 0.18641487562230655, 0.08901552310479538, 0.17272600159049034, 0.1306524606687682, 0.1627092505139964, 0.16346737769033226, 0.18408227578869887, 0.12569724156388215, 0.0968138175085187, 0.13567641537104333, 0.10917747193681342, 0.11784113597656999, 0.06119954998471907, 0.2071531992405653, 0.08571550875369992, 0.12282663131398813, 0.12905761839023658, 0.20927872375718184, 0.12842527803565773, 0.16441744885274343, 0.21778870640056475, 0.12101891902940613, 0.12378063797950745, 0.066502138307052, 0.09723030908831529, 0.16650146059691906, 0.12830124183424882, 0.15244871537600244, 0.14057375543883868, 0.15303438609199865, 0.13069602261696542, 0.18045226271663392], [0.0687303998108421, 0.05657567310013941, 0.04193762357213667, 0.01207815997102963, 0.004910949783931885, 0.0704602502020342, 0.014411708905494638, 0.021605153800919652, 0.12850786931812763, 0.02973704146487372, 0.05379567780931081, 0.012308925490028091, 0.06726876752717154, 0.13403854040162905, 0.10628516892237322, 0.07261484994419984, 0.03753677775551166, 0.0269315536133945, 0.06527474988251925, 0.06429951864161662, 0.03729170447747622, 0.059894856065511703, 0.012836901221557387, 0.048962160745369535, 0.05242945094193731, 0.06474242558968918, 0.05955740703003747, 0.09435873531869479, 0.1061496315523982, 0.07041570437805993, 0.07387848570942879, 0.025893294950947165, 0.014348438907680767, 0.04891044280624815, 0.03228474707741823, 0.027958650374785066, 0.08700853187058653, 0.033589169582618136, 0.05737048187958343, 0.06106633320450783, 0.020393052770357047, 0.024226495730025426, 0.034664159041962454, 0.017451369369934713, 0.03175574082082935, 0.026108957128599286, 0.023113638927627887, 0.12763441833002226, 0.03635323287120887, 0.09225430645580802, 0.023036009432481866, 0.10452042147517204, 0.05647565025304045, 0.04654854043786015, 0.07568155002913304, 0.1073350797274283, 0.0530055373507951, 1.0480217635631561, 11.917529378618513, 41.608081749507356, 62.19058799743652, 61.69560527801514, 53.397875445229666, 49.89040742601667, 42.121967043195454, 27.079143149512156, 19.895782777241298, 22.324661084583827, 41.69424983433315, 60.37296009063721, 71.12845189230782, 65.36082172393799, 73.3363948549543, 65.85288619995117, 55.8750124658857, 50.37739624295916, 45.585289682660786, 43.401950291224885, 36.06998184749058, 29.48561872754778, 24.281197377613612, 15.871406997953143, 10.254001225743975, 7.671686717442103, 4.373286085469382, 2.141025730541774, 1.4013883620500565, 1.0299653496061052, 0.5099821431296212, 0.22341772434966906, 0.40703920700720375, 0.4205523133277893, 0.3841220667319638, 0.34332525730133057, 0.3002034883413996, 0.2855395052049841, 1.0353725680283137, 0.9140642945255552, 1.3400829945291792, 2.714053873504911, 2.998381108045578, 4.529036036559513, 8.118805033820015, 15.60870429447719, 21.698692662375315, 29.59171772003174, 45.26124654497419, 47.01054586683001, 42.62779590061733, 34.29323714120047, 25.079889331545147, 24.355131421770366, 21.226585149765015, 19.22854379245213, 22.33439724785941, 20.65177457673209, 21.41412397793361, 41.92091396876744, 32.35572154181344, 43.1786664554051, 56.98581402642386, 68.54849542890275, 60.278700828552246, 34.657986300332205, 5.607180629457746, 0.646835979606424, 0.13670111181480543, 0.024267959308677485, 0.13768975090767654, 0.07441653005246605, 0.10261940384017569, 0.008107457010607635, 0.03802860029307859, 0.08311361194189106, 0.05170404611687575, 0.027171381815735782, 0.036505974496581724, 0.035257483632969, 0.04840319716770734, 0.05253235077751534, 0.009478306397795677, 0.02050686514537249, 0.011090424177902085, 0.03899598427649055, 0.021758255049852387, 0.02265509344371302, 0.053851877472230365, 0.030397466383874416, 0.0056153946622673956, 0.031873548070767095, 0.03177023432882769, 0.01302010822109878, 0.028900580813309977, 0.0761741189552205, 0.03959216549992561, 0.09643188371722188, 0.04543075577488967, 0.045894900869045935, 0.09212797680603606, 0.02039126991959555, 0.02314440200903586, 0.07682333447571311, 0.03276404046586581, 0.04457443440333009, 0.042967073153704405, 0.02047138285290982, 0.06247121960456882, 0.02187080874240824, 0.07588582978184734, 0.047641684101628404, 0.05434848028900368, 0.023733495934201137, 0.038101926179868836, 0.05943079239555767, 0.03870818364833083, 0.05088233681661742, 0.05844685555036579, 0.06404294419501509, 0.03309197983305369, 0.017688400311661617, 0.06819125624107462, 0.013066758351799632, 0.12206432436193738, 0.01227380451746285, 0.08956747063036476, 0.07038540778947727, 0.0478595175913402, 0.11965895843292985, 0.06869376570518528, 0.02091891910614712, 0.015609801580597247, 0.03637619449623993, 0.06501215004495212, 0.08158112024622304, 0.011635588897791291, 0.044926000359867296, 0.011229038704186678, 0.09411106325153794, 0.015406775421329906, 0.0666537501716188, 0.030589006641613584, 0.05095330818689295, 0.08357882233602659, 0.05449052480980754, 0.1259056603802102, 0.022148148056917956, 0.040113433064626794, 0.07864567597529717, 0.00943284624788378, 0.04405275293226753, 0.01842640044300684, 0.023144066134201627, 0.041496714909694025, 0.058145436724381785, 0.07448700269950287, 0.05339097238278814, 0.08017456465001617, 0.07525458865399871, 0.020009208902982727, 0.07661772479436227, 0.052103499682354074, 0.04442743657689009, 0.007415587930673999, 0.06547160646212952, 0.06551356706768274, 0.09708301949181727, 0.03801823906334383, 0.055668213936899386, 0.10490095069898026, 0.04896225913294724, 0.06825121838067259, 0.11117567614253078, 0.18075669423810073, 2.9799638220242093, 21.515875135149273, 60.35920960562569, 77.15065710885185, 70.14101559775216, 49.464729513440815, 40.215892042432515, 29.322322164263042, 28.389611618859426, 36.02190726143973, 46.7107241494315, 61.90792138235909, 72.00112479073661, 64.3887687410627, 60.98816054207938, 54.31683724267142, 44.05433750152588, 31.94141435623169, 25.09502945627485, 18.78458169528416, 12.638569133622305, 7.884957330567496, 5.369553540434156, 3.407705783843994, 4.737583177430289, 1.876694108758654, 1.4151600173541476, 1.034161735858236, 0.5583461650780269, 0.4474431446620396, 0.5778152889439038, 0.4844400765640395, 0.1630784007055419, 0.30348569793360575, 0.2163020633161068, 0.22120963569198335, 0.2745651240859713, 0.006504069855769298, 0.18142825391675743, 0.6965764505522591, 0.9017058376755033, 0.31731291168502396, 0.4959644781691687, 0.9504175952502659, 1.6020688393286295, 3.799495594842093, 5.342334840978895, 4.787937641143799, 8.119135073253087, 11.945949247905187, 22.43900237764631, 30.339083330971853, 37.61855466025216, 37.78563104357038, 40.86134842463902, 48.20896768569946, 50.78065231868199, 54.20746217455183, 51.4458589553833, 42.21824475697109, 65.50563607897077, 29.037463392530167, 33.86225427900042, 51.757638522556846, 62.67256368909563, 71.02936363220215, 49.42586129052298, 11.741138935089111, 1.0834888432707106, 0.11349391138979367, 0.1308378092944622, 0.26954057227287975, 0.07313481132899012, 0.11828765273094177, 0.046426516092781506, 0.10411036919270243, 0.07094117546720163, 0.0235787136147597, 0.012739092943125536, 0.0524770467808204, 0.06064423014010702, 0.044029791307236464, 0.039112146079008064, 0.043353590449052196, 0.016011102457663844, 0.044721245632639954, 0.01103932794649154, 0.042025426003549776, 0.04030926844903401, 0.055153887785438976, 0.02636881059567843, 0.02420516767805176, 0.023908676712640693, 0.09783824253827333, 0.023469299843002642, 0.018908587783308964, 0.05733501485415867, 0.018813341822741286, 0.05037262470328382, 0.0322389222149338, 0.04655521382976856, 0.10068564689052956, 0.02135234183099653, 0.015250870126432605, 0.08494717641068356, 0.02719820260868541, 0.08119479633335557, 0.08862016110547952, 0.04043032248903598, 0.0549042683227786, 0.030658223998865912, 0.06921219360083342, 0.06255238596349955, 0.03812700144148298, 0.009446825765605484, 0.03095177181863359, 0.021868372801691294, 0.02544981294444629, 0.015817775956488082, 0.20183229047272885, 0.26500565132924486, 0.30653196732912746, 0.1983691155910492, 0.21421178190835885, 0.17297992296516895, 0.29123930792723385, 0.14753665109830244, 0.1961200569889375, 0.2046070915779897, 0.21550211124122143, 0.15260418131947517, 0.12724731410188334, 0.24056614988616534, 0.2547142564186028, 0.16005457724843705, 0.13880326758537972, 0.1493062297148364, 0.1411800400487014, 0.17910937406122684, 0.17983574579868997, 0.133173652525459, 0.14459731882171972, 0.1815126636730773, 0.09103045998407261, 0.12252130412629672, 0.13101144640573434, 0.1611970266593354, 0.19497155504567282, 0.1272231853966202, 0.13885961313332829, 0.09172222643558468, 0.10361851951373474, 0.15787410496601037, 0.17943980704460824, 0.1219352941427912, 0.10953139580254044, 0.135239411677633, 0.2463007750255721, 0.1831699718854257, 0.12961408495903015, 0.2490501989211355, 0.1513762500669275, 0.19782759036336625, 0.1855425645730325, 0.11058824123548609, 0.07732221377747399, 0.17585252810801777, 0.12269234923379761, 0.2629660022045885, 0.16349705681204796, 0.2915791454059737, 0.20767235995403358, 0.09744008497468062, 0.19273453365479196, 0.32614651482020107, 0.2645066838179316, 2.4169944993087222, 25.905112981796265, 70.53039959498814, 90.13107327052525, 84.91427544185093, 73.9433547428676, 70.1702744620187, 61.65696634565081, 40.43359647478376, 35.21668400083269, 37.59874882016863, 56.63588884898594, 78.2470828465053, 85.17773028782436, 86.85528251102993, 93.46009417942592, 96.81590734209333, 88.82678522382463, 85.93692520686558, 78.88039030347551, 69.86020415169853, 58.84075723375593, 50.62668718610491, 40.128879751477925, 27.048975808279856, 14.921485764639717, 10.432173013687134, 5.966204907212939, 2.6589835371289934, 1.9567790457180567, 1.593308680823871, 0.6428725208554948, 0.4603264076369149, 0.5210967095834869, 0.39077895666871754, 0.5393524499876159, 0.4388173089495727, 0.18149016345185892, 0.3893902940409524, 1.3525857350655963, 2.025994828769139, 1.7370036159242903, 3.2131286476339613, 4.994864983218057, 9.948392527444021, 17.21897884777614, 29.241358280181885, 35.31416722706386, 46.200882707323345, 60.90588692256382, 63.891305514744346, 65.35008675711495, 62.448727471487864, 64.65062550136021, 58.97094563075474, 51.08049488067627, 52.145400115421836, 45.253436769757954, 48.43032339641026, 43.427245208195274, 67.48463589804513, 58.531472069876536, 57.95044980730329, 69.07769107818604, 79.26266629355294, 80.05344077519008, 56.931847367967876, 12.907573853220258, 0.7899489487920488, 0.2234608791768551, 0.2607157900929451, 0.2163994059498821, 0.16347884493214743, 0.167381954778518, 0.1923545811857496, 0.16136923884706839, 0.2002008751566921, 0.10491693019866943, 0.11994079473827567, 0.1433789956250361, 0.154931475009237, 0.21033900257732185, 0.12709927133151463, 0.13299673130469664, 0.09848810266703367, 0.1423597681735243, 0.1515923227582659, 0.08051500602492265, 0.06549975888005324, 0.14394084976187774, 0.10683191886969975, 0.1440236038927521, 0.08938095492443868, 0.15556296040969236, 0.10047950116651398, 0.1422379304255758, 0.21021028448428425, 0.1712668120328869, 0.17344488230134758, 0.10572946231280055, 0.1442393644579819, 0.27182289266160553, 0.14445118952010358, 0.12707331058170113, 0.24398640064256533, 0.09108643912311111, 0.2678641565144062, 0.1651223517422165, 0.10487625880965165, 0.14898134714790753, 0.08451168585036482, 0.14520589687994548, 0.18696017350469316, 0.18689477629959583, 0.18517559926424706, 0.16933063949857438, 0.16432972784553254, 0.1326139968420778, 0.13145467905061586], [0.04072696442848869, 0.009968480943436069, 0.0577260342293552, 0.03754277600507651, 0.024734859255009463, 0.09091960771807603, 0.03976501551057611, 0.009791801450774074, 0.023191780716712986, 0.03243591450154781, 0.06520967837423086, 0.039191470215363164, 0.07566622192306177, 0.04498845611565879, 0.01744337283473994, 0.04109310870990157, 0.0424117295603667, 0.05232871902574386, 0.02747622554722641, 0.0500880335457623, 0.09082216330404792, 0.013684358381267105, 0.09047725716871874, 0.08676928720836129, 0.05391521193087101, 0.031141049162085568, 0.04858085120628987, 0.049811150546052625, 0.019332275226978318, 0.02534981214973543, 0.02223549078085593, 0.033070144576153586, 0.09425177105835505, 0.0302288911438414, 0.04463710389765246, 0.02925383292936853, 0.12406844539301735, 0.04029056802392006, 0.02328445842223508, 0.030169665214738677, 0.09410031525684254, 0.045165346802345345, 0.023701338463329842, 0.08276467530855111, 0.038152188661375215, 0.02216231926078243, 0.052538196356701, 0.07306155668837683, 0.05644757925931897, 0.07817930528627974, 0.016835157792749147, 0.04422555883814182, 0.03118644654750824, 0.11350818776658603, 0.13354690106851713, 0.06367546319961548, 0.12427307798394135, 0.048969709447452, 0.1604197919368744, 0.06680450029671192, 15.312818731580462, 51.700065749032156, 62.691129275730674, 58.97241170065743, 51.26505293164934, 52.227979455675396, 41.38906758172171, 38.691936697278706, 31.333763122558594, 34.51632990155901, 32.51015567779541, 36.03740174429757, 50.53141696112496, 47.18811750411987, 49.96918262754168, 47.741416454315186, 52.48270041601998, 56.50812537329537, 58.22523716517857, 45.01596818651472, 46.29056658063616, 41.76319680895124, 42.228951930999756, 49.347933769226074, 51.8751151902335, 45.7426038469587, 41.03550154822213, 32.68925939287458, 26.71679633004325, 20.952134779521398, 17.64431803567069, 15.738239560808454, 14.413134711129324, 13.370781591960363, 16.493878739220754, 12.470640727451869, 11.001946142741613, 9.99397965839931, 12.54341789654323, 14.257261429514203, 21.778709854398453, 26.706351450511388, 25.857788801193237, 35.16791112082345, 38.164141110011506, 42.532393659864155, 50.71551295689174, 65.52143628256661, 50.95068168640137, 36.24971090044294, 33.00716379710606, 21.530839817864553, 19.35365653038025, 23.74765041896275, 24.154868704932078, 32.34415626525879, 37.30687236785889, 40.71158695220947, 54.88538748877389, 69.75675937107631, 63.05549280984061, 52.983811446598594, 9.350077935627528, 0.7152878950749124, 0.17856341121452196, 0.08310067227908544, 0.04807178370122399, 0.02738208050972649, 0.02865497149260981, 0.23562147521546908, 0.16504672222903796, 0.061252543569675515, 0.02787588776222297, 0.05941796129835503, 0.02234268743943955, 0.1470245878611292, 0.02445040550082922, 0.015421240091589945, 0.03117091827360647, 0.03188328844095979, 0.03036583647398012, 0.037272108386137655, 0.030827247072011232, 0.012864808518705624, 0.03545119859544294, 0.07084651304674999, 0.02690035118056195, 0.03291405098778861, 0.03948786109685898, 0.015322557351152812, 0.0251707535436643, 0.031179613699870448, 0.018304077542519996, 0.0366325009215091, 0.039373904533152065, 0.06012857745268515, 0.03286506415211728, 0.026224294511069144, 0.08397493072386299, 0.04104510914268238, 0.03810876242018171, 0.08162920123764447, 0.02065227011085621, 0.08357616926410369, 0.05228281952440739, 0.050963146944663355, 0.050837126028324874, 0.06702863398407187, 0.07918442599475384, 0.0141483245118122, 0.0033200570032931864, 0.06823855013187442, 0.14544303129826272, 0.04576906654983759, 0.043982541521212885, 0.10754168685525656, 0.05595659471250006, 0.04760768271184393, 0.030986156580703597, 0.04948876838066748, 0.03899317514151335, 0.07019560118871075, 0.06213272562516587, 0.07409479588802372, 0.034394787424909215, 0.04472812258505395, 0.08837456535547972, 0.044442951280091486, 0.05273647785985044, 0.014566677822066205, 0.03084078384563327, 0.030187184988920177, 0.023496052782450403, 0.04206506601933922, 0.04800551797130278, 0.03794199886864849, 0.10212838875928096, 0.018701656655009304, 0.030059372740132467, 0.03843367891386151, 0.023381834982761314, 0.04112928141174572, 0.04882687782602651, 0.011599399232571679, 0.018355758162215352, 0.06564410363457032, 0.025091249595529268, 0.004642188424311046, 0.11904520993786198, 0.07168768612401825, 0.04744611334587846, 0.020257656196398393, 0.08047841941671711, 0.0275670729045357, 0.03384909599221178, 0.05739137397280761, 0.053716078866273165, 0.04112143415425505, 0.0689207695956741, 0.06567655117916209, 0.08160066205476012, 0.08339639141091279, 0.042736910682703765, 0.017129536817914674, 0.03519242908805609, 0.03412537170307977, 0.04898716136813164, 0.09334354515054397, 0.007930374637778317, 0.07570985172476087, 0.11909109247582299, 0.0969599603808352, 0.04983033612370491, 0.09446867156241621, 0.2489352822303772, 1.4404703506401606, 26.594115461621964, 75.49141338893345, 81.47711971827916, 68.8533684866769, 52.55982542037964, 37.2286947114127, 25.527695519583567, 22.39861249923706, 35.584535530635286, 49.702844279153005, 53.69126660483224, 56.623045103890554, 70.85214982713971, 65.66294329507011, 55.96534946986607, 43.84312963485718, 49.09073577608381, 45.53521054131644, 38.45075082778931, 30.782072680337087, 26.210013832364762, 24.4567540373121, 22.901069743292673, 23.015598637717112, 19.52123318399702, 14.836828913007464, 12.517029506819588, 10.169865489006042, 5.974707765238626, 5.456065995352609, 4.536731166499002, 4.260684447629111, 2.0925898381641934, 2.8448964868273054, 4.519449259553637, 3.823533756392343, 6.217952472823007, 5.083491861820221, 6.106080395834787, 6.820095956325531, 11.06099019731794, 14.219786320413862, 21.770955664770945, 32.859813349587576, 38.38666064398629, 43.657671792166575, 58.507382665361675, 74.63898059300014, 76.24438967023576, 74.24002197810582, 67.3599991117205, 57.58156647000994, 49.963881152016775, 41.51149484089443, 30.63427059991019, 25.755035366330826, 26.192056213106426, 42.43212768009731, 51.99931076594761, 69.63472815922329, 74.00239358629499, 69.36521448407854, 17.740944896425518, 1.503224526132856, 0.22841274631874903, 0.10421200695314578, 0.08522386263523783, 0.06880123208143882, 0.06791090592741966, 0.09354696316378457, 0.07480244684432234, 0.10152976480977875, 0.11775873468390533, 0.0332830485089549, 0.0471082300479923, 0.059682379609772136, 0.011397318781486579, 0.04618621291592717, 0.030821279356522218, 0.08625820106161491, 0.024364630192784325, 0.020642828296071718, 0.06977686365800244, 0.02663315087556839, 0.06608699022659234, 0.05358593924237149, 0.010887750856844442, 0.00813065781923277, 0.057419560317482264, 0.014660252890150462, 0.06264481600373983, 0.0498084499766784, 0.0229087518860719, 0.053292686585336924, 0.032454642068062506, 0.08476603470210518, 0.019012171242918288, 0.06366156001708337, 0.018971065591488565, 0.05062779797507184, 0.06125075223722628, 0.032477712258696556, 0.0411724633803325, 0.021861053105177622, 0.03052539737629039, 0.026551333123019764, 0.03169369897139924, 0.06997179319815976, 0.05860275575625045, 0.054767743684351444, 0.054059197061828206, 0.05421640684029885, 0.028044644510373473, 0.05949393007904291, 0.003355720803873347, 0.03174009380329933, 0.18355942384472915, 0.15300020149775914, 0.13528734339135035, 0.15241910410778864, 0.1395525195236717, 0.17064539609210833, 0.24540242180228233, 0.17270340637436934, 0.14240959978529386, 0.11613721240844045, 0.18446688300796918, 0.2503380041037287, 0.09864272044173308, 0.14084468090108462, 0.15913638366120203, 0.0749332480398672, 0.09355838290814843, 0.13482656383088656, 0.15420390905014106, 0.10212105379572936, 0.24723286500998906, 0.13125794460730894, 0.14471034918512615, 0.15016104813132966, 0.1195788641593286, 0.11880635204059736, 0.19926734667803558, 0.10983304533043078, 0.13402240483888558, 0.13215708493122033, 0.11566393423293318, 0.07082870828786067, 0.3550325648060867, 0.19443304251347268, 0.16036683906401905, 0.139176448274936, 0.3501197541398661, 0.0948902317988021, 0.2571580410003662, 0.11326603218913078, 0.28709278042827335, 0.11334044712462596, 0.15313057521624224, 0.1507785421397005, 0.1463408824056387, 0.23259675609213964, 0.17150702700018883, 0.14204320444592408, 0.22678427584469318, 0.22139738633164338, 0.15689409683857644, 0.18671573804957525, 0.17574109908725533, 0.2324500839625086, 0.1757658249033349, 0.2596252214695726, 0.13897877745330334, 0.15539813068296227, 0.2826907437826906, 1.2384132615157535, 29.922083718436106, 92.99833079746791, 98.72255556924003, 88.8205179486956, 81.48643030439104, 81.85841601235526, 58.85075569152832, 59.940365246364046, 47.85164615086147, 51.78816543306623, 53.22830465861729, 56.114169461386545, 73.33104474203927, 68.09089401790074, 65.90502548217773, 69.7646733692714, 72.11545739855084, 72.90880966186523, 77.61147553580147, 65.63180146898542, 68.40245819091797, 71.24029009682792, 70.86851283482143, 74.3627758026123, 72.08456570761544, 64.44645963396344, 57.723285402570454, 48.96935422079903, 38.89989628110613, 33.97780629566738, 26.20068413870675, 24.66668517248971, 24.529301915849956, 24.310355493000575, 28.843558277402604, 30.453985691070557, 29.922465869358607, 34.11373043060303, 37.89309535707746, 38.83402735846383, 47.31073236465454, 54.93657486779349, 62.30219691140311, 74.31721646445138, 70.65964303697858, 72.26792866843087, 70.8095782143729, 85.25099904196603, 70.92118018014091, 59.46362154824393, 61.67996488298689, 47.52922889164516, 54.40423168454851, 57.003733430589946, 53.21410601479666, 63.5622318812779, 63.91491549355643, 54.11749342509678, 65.19561440604073, 83.00184631347656, 83.8184403010777, 76.67954839978898, 23.123651811054774, 1.4090831662927354, 0.18545146446142877, 0.21988566459289619, 0.2376724694456373, 0.18966144855533326, 0.09627873157816273, 0.37205331719347406, 0.3648979482906205, 0.24440953508019447, 0.1751300511615617, 0.13802933054310934, 0.08591578514980418, 0.1832316778600216, 0.23358163610100746, 0.17921555122094496, 0.24682943522930145, 0.15601813527090208, 0.15595809849245207, 0.11504945292004518, 0.1061838704294392, 0.09715944967631783, 0.181639129029853, 0.20780957330550465, 0.08380965994937079, 0.21302889181034906, 0.2491122441632407, 0.2611283122428826, 0.08449776909713234, 0.08310924217637096, 0.12332952075770923, 0.1395365603800331, 0.13041300566068717, 0.2686706632375717, 0.11457773537508079, 0.08002498839050531, 0.15804144527230943, 0.132761293223926, 0.1876043067978961, 0.09357394850147621, 0.1275508499571255, 0.12046375524784837, 0.10760276857763529, 0.09191367509109633, 0.15862028992601804, 0.1690514494798013, 0.18290737883320876, 0.12293024361133575, 0.10707657824137382, 0.16280435398221016, 0.2743206343480519, 0.15998987214905874, 0.12178482221705572, 0.09762974229774304], [0.01635434278952224, 0.03092450149623411, 0.05252784191231642, 0.01414848311937281, 0.027351660088502934, 0.06029672521565642, 0.025661934865638614, 0.03449020980458174, 0.014223692789008575, 0.04357599387211459, 0.005923874493289206, 0.07633071126682417, 0.016001421459285275, 0.046474427450448275, 0.05016287595831922, 0.029312397286828076, 0.0313926499470004, 0.056411654222756624, 0.013030022465890008, 0.0369609763313617, 0.06395727914891072, 0.03571440572185176, 0.11356153418975216, 0.02440605645201036, 0.03935895301401615, 0.02750957215071789, 0.11128000768699817, 0.07336091955325433, 0.07309572092656579, 0.023729821667075157, 0.005308642126952431, 0.08582271050129618, 0.044555683088089736, 0.03737313885773931, 0.10475102838660989, 0.013420816228192831, 0.010434279118531516, 0.04025307896413973, 0.020751307385840585, 0.05196295811661652, 0.030466717667877674, 0.10973670692848307, 0.05168741861624377, 0.017626567111749734, 0.023546281337205852, 0.07329778865511928, 0.0361485392121332, 0.05266709426151855, 0.007295547452356134, 0.09205023704894952, 0.009573144389183393, 0.04381993738934398, 0.027831535320729017, 0.014209873575185026, 0.03254726888345821, 0.037966276851615736, 0.06321144702711276, 0.0487855143312897, 0.30045793897339274, 0.04531657190195151, 0.16318592136459692, 1.4930735336882728, 10.762511219297137, 29.802435738699778, 49.20906012398856, 54.12385450090681, 60.49549157278878, 62.52827739715576, 55.50120632989066, 53.88752542223249, 47.547909123556956, 50.58269119262695, 52.777324880872456, 47.461511748177664, 46.15109191622053, 45.21717759541103, 25.31141894204276, 38.926775387355256, 38.616979530879426, 39.79558508736746, 50.5458379473005, 34.67631564821516, 31.02965784072876, 38.99305077961513, 50.15104825156075, 48.480690887996126, 55.11402838570731, 66.96971879686627, 54.251621450696675, 53.22546979359218, 38.076329776218955, 37.13297980172293, 32.072241987500874, 40.2750038419451, 39.12575789860317, 34.21733154569353, 18.94665711266654, 21.564212015696935, 28.890635796955653, 28.121365989957535, 33.38254370008196, 41.13245323726109, 39.61128411974226, 29.114185401371547, 26.787963254111155, 27.29318414415632, 38.73629052298409, 32.39550345284598, 29.612649168287003, 43.515428270612446, 38.63432223456246, 38.70376947947911, 50.14075102124895, 45.31515761784145, 56.77260160446167, 55.28459276471819, 65.89055933271135, 61.36734458378383, 57.61734969275338, 45.134619099753245, 11.183267201696124, 1.2176716945001056, 0.10212282477212803, 0.12618597676711424, 0.05668375015790973, 0.01610505920169609, 0.06097962321447475, 0.04728151771372982, 0.01236945590270417, 0.10060778499713965, 0.054264511580445936, 0.08138824666717223, 0.07738448293613535, 0.04451291163318923, 0.08734524808824062, 0.05818027949758938, 0.09892114371593509, 0.03973253743190851, 0.026719928719103336, 0.03772927814030221, 0.08752989103751523, 0.07428296043404511, 0.033870154326515536, 0.044767545469637425, 0.023431595348353897, 0.022737674548157623, 0.09146941107298646, 0.07161291835031339, 0.0333478112838098, 0.03735273530972855, 0.05495831363701394, 0.05764855231557574, 0.0321611112116703, 0.0007105752831973534, 0.024640992416867187, 0.029437434327389513, 0.04106749401294759, 0.04135907408116119, 0.022308518112237965, 0.051125137002340386, 0.06611069824014391, 0.046358835617346425, 0.018827752210199833, 0.030667764201228107, 0.010185512913657086, 0.0265439845887678, 0.039887358767113516, 0.06431484674768788, 0.028185350620853047, 0.017927086878834025, 0.060199375796530924, 0.014864973690626877, 0.1522193569689989, 0.020301060385203788, 0.03303881661434259, 0.038842143424387486, 0.01034717557818762, 0.03680824488401413, 0.054376564853425534, 0.052401885456804714, 0.04610816781808223, 0.05015835691509502, 0.0474049296629216, 0.03275929411341037, 0.01966638078114816, 0.020103516788887124, 0.04633514456717031, 0.05603697057813406, 0.01740766323304602, 0.056132576162261624, 0.07710900450391428, 0.04458535881713033, 0.024999983242845962, 0.03825325305972781, 0.05896568378167493, 0.04383703986448901, 0.001593142866373195, 0.07030824478715658, 0.16728875120835646, 0.0334991720904197, 0.008390239024135684, 0.02725500786410911, 0.10824957529881171, 0.06701186059841088, 0.12186943553388119, 0.026989358011633158, 0.031707103430692635, 0.008380199250366007, 0.04443450351910932, 0.008396334813109465, 0.07258403766900301, 0.025085627932899764, 0.019486526592767665, 0.019044187917773212, 0.06813246796705894, 0.05051883203642709, 0.014345723071268626, 0.09914921969175339, 0.07891810099993433, 0.047655081775571616, 0.021180253475904465, 0.12088896600263459, 0.02293879572036011, 0.04293232198272433, 0.04629163011642439, 0.05200103071651288, 0.01886772470814841, 0.05985066307974713, 0.06950247766716139, 0.04702992032149008, 0.021264313786689724, 0.08709174740527358, 0.0426090746851904, 0.09502715338021517, 0.16953528566019876, 0.08490280700581414, 0.29492416019950596, 3.354646299566541, 27.08954460280282, 63.25863034384591, 78.4688207081386, 73.45434747423444, 63.19647175925118, 50.84078550338745, 40.68851545878819, 44.04643045152937, 46.22703225272042, 44.92172629492623, 61.65361731392996, 53.59828928538731, 55.400044032505576, 47.174294063023154, 37.016798973083496, 45.9098539352417, 46.101349762507844, 40.44114916665213, 53.72062621797834, 48.18774093900408, 54.71678597586495, 64.30575166429792, 70.65161091940743, 69.25564139229911, 71.91049248831612, 64.1357570375715, 65.14949921199253, 59.31280394962856, 63.446058000837056, 56.713006905147004, 49.65464115142822, 42.90464687347412, 43.0866688319615, 36.586271217891145, 37.44413750512259, 33.09745911189488, 27.991676126207622, 28.454664128167288, 34.78103542327881, 39.7598991394043, 44.82025480270386, 45.09944037028721, 51.228505407060894, 48.02745294570923, 70.85802105494908, 71.80049555642265, 51.83011170795986, 56.081419127328054, 44.58351578031267, 32.56451490947178, 32.11461557660784, 37.7053724016462, 42.939808232443674, 50.53556850978306, 63.73521423339844, 73.14455509185791, 76.81798430851528, 62.43684605189732, 19.009592158453806, 2.7256864607334137, 0.09975232875772885, 0.07931438580687557, 0.046784300822764635, 0.11237603173192058, 0.03267822274938226, 0.060490847299141545, 0.13857640618724482, 0.02517060935497284, 0.039880020410886834, 0.07852320718978133, 0.0603512047923037, 0.014749763533473015, 0.05184093377153788, 0.05579430949208992, 0.08688305038958788, 0.045758376230618784, 0.025412415486893485, 0.021213019931954995, 0.03909597658951368, 0.019223957289276377, 0.025734176792736565, 0.04286655158336673, 0.05073340177269919, 0.06501922037984643, 0.02022297796793282, 0.033733253101153035, 0.08648460105593715, 0.028794060993407453, 0.0188121815278594, 0.06155175715684891, 0.05985922619168248, 0.12624319083988667, 0.0629907331562468, 0.005109784717205912, 0.04198165370949677, 0.022134243178048303, 0.07142319317374911, 0.06821237903620515, 0.02695646433026663, 0.028816486575773785, 0.03317554820595043, 0.03132133252386536, 0.03707445452788046, 0.03652840007894805, 0.01795789915403085, 0.06499623161341463, 0.03988018325929131, 0.0029943744011688977, 0.09407647153628723, 0.07649218903056212, 0.12104025217039244, 0.06763378544045345, 0.03359373612329364, 0.06186585780233145, 0.07320906341608081, 0.11909082106181554, 0.1533158559884344, 0.07002188265323639, 0.21354266495576926, 0.09710203882838998, 0.11045940100614514, 0.21368549657719477, 0.230690669800554, 0.1770294335271631, 0.16592823421316488, 0.23478568292089871, 0.1281856737498726, 0.1254765141223158, 0.20110435810472282, 0.12785811775497027, 0.14234171914202826, 0.16211507096886635, 0.09764207127903189, 0.15260902605950832, 0.12735369482210704, 0.14293709290879114, 0.26395270068730625, 0.08473175511296306, 0.15362714071358952, 0.2461775802075863, 0.19832000322639942, 0.24407599440642766, 0.15210320534450666, 0.13139038107224874, 0.1836733498743602, 0.13815745152533054, 0.11488682164677552, 0.08661758034889187, 0.38404126678194317, 0.07215435536844389, 0.11840445574905191, 0.056263289148254056, 0.11910245115203516, 0.10010853250111852, 0.1059677502406495, 0.19670932394053253, 0.19815843046775886, 0.14589519346398966, 0.23027410358190536, 0.10844929529620068, 0.09040123410522938, 0.1805289371737412, 0.24040704699499266, 0.1790038211537259, 0.12691747822931834, 0.1484563781746796, 0.0993975227964776, 0.1212583061839853, 0.2253293339163065, 0.20681724298213208, 0.14022049653742993, 0.19574349719498838, 0.3456348276564053, 0.15405844471284322, 0.45642727400575367, 4.202786411557879, 28.456142357417516, 72.02674974714006, 96.29828044346401, 98.08774730137416, 100.60044520241874, 91.47702271597726, 81.79346425192696, 75.76717349461147, 74.07442556108747, 70.24502318246024, 78.25278731754848, 67.49546119144985, 67.70577621459961, 62.56211512429373, 36.783860615321565, 53.46455730710711, 53.82939331872122, 56.30250038419451, 73.56465707506452, 55.247610977717805, 52.08488130569458, 56.722612789699006, 68.77894633156913, 64.7413967677525, 73.35919189453125, 84.23136479513985, 74.34186172485352, 76.45089708055768, 62.998545374189106, 63.97313444955008, 59.852116176060264, 72.12578936985561, 74.4144287109375, 61.697189467293875, 45.31772150312151, 47.183882577078684, 65.14477443695068, 66.26891653878349, 66.11051845550537, 69.22440923963273, 71.46955285753522, 53.119318689618794, 49.24367952346802, 39.587003639766145, 56.41300106048584, 51.245983600616455, 43.93963316508702, 77.68802383967808, 59.607004574366975, 70.58510276249477, 76.3305334363665, 76.15732179369245, 81.15626580374581, 78.38678332737514, 84.85784912109375, 90.73922824859619, 91.86138316563198, 69.745468548366, 22.097520998546056, 3.288263210228511, 0.17059328460267612, 0.16429273411631584, 0.16569394964192594, 0.31881600245833397, 0.2020965798624924, 0.1406186744570732, 0.22806045093706676, 0.14973477886191436, 0.13079948563660893, 0.18220901702131542, 0.1508008795125144, 0.1200059883828674, 0.1582046736563955, 0.18101091416818754, 0.25465052840965136, 0.0904808941164187, 0.07274828385561705, 0.20056094654968806, 0.189077012773071, 0.12430746613868646, 0.11976846041423933, 0.13791491596826486, 0.13971927628985473, 0.10568204628569738, 0.3407713329153401, 0.24286513509494917, 0.1493871518011604, 0.2501074107629912, 0.06870932451316289, 0.14483253977128438, 0.21977905317076615, 0.18060599161045893, 0.1321125594632966, 0.10674465926630156, 0.10448789929172822, 0.17728499695658684, 0.15225557716829435, 0.1519204487225839, 0.1882718631199428, 0.20551555497305735, 0.1297094869826521, 0.20229035589311803, 0.10823641850480012, 0.0820471245263304, 0.13356352517647402, 0.1948882852281843, 0.14679836428591184, 0.16813299804925919, 0.19821728659527643, 0.20947908157748835, 0.20733823574015073, 0.15618582841541084, 0.12188521825841495, 0.24146227751459393], [0.028272348988269056, 0.04104182842586722, 0.054062922219080586, 0.0902696390237127, 0.057735235164208074, 0.058802204339631965, 0.017181500725980316, 0.0378733684441873, 0.04217968076201422, 0.038481234040643485, 0.08375789451279811, 0.041573786309787204, 0.04569354220958693, 0.03752619939457093, 0.008884307512614344, 0.028055899709995304, 0.058588228321501186, 0.00089843305717555, 0.05282117938622832, 0.022559783022318567, 0.1015409402815359, 0.029738123728228465, 0.06354002082454306, 0.030917471873440912, 0.08330263822738614, 0.021085485882524933, 0.03985966096765228, 0.020167665489550148, 0.03705375920981169, 0.06334074187491621, 0.07084628234484366, 0.01592397516859429, 0.10100935559187617, 0.027640924655965397, 0.09065018860357148, 0.026605905998232107, 0.04503462703100272, 0.024677687590675693, 0.038279142563364336, 0.044222220445850065, 0.07666996520544801, 0.030995350730206286, 0.01716482572789703, 0.0483204837489341, 0.02490513422526419, 0.014314771696392978, 0.11608972852783543, 0.06993934565356799, 0.013440185858468925, 0.06443367858550378, 0.0035730453923211564, 0.02025576986904655, 0.06348398061735289, 0.020939444790461233, 0.016018274572810957, 0.017437478061765432, 0.09418551211378404, 0.04076625160606844, 0.0653234144140567, 0.018876231840944717, 0.2937350682914257, 0.1181301511824131, 0.4769580066204071, 2.7092094591685703, 4.546583712100983, 7.489350352968488, 26.581144911902292, 38.56234931945801, 45.656651156289236, 53.07508993148804, 65.7296598979405, 61.543154852730886, 57.212144647325786, 51.24664715358189, 50.549530914851594, 61.02322810036795, 56.871675968170166, 55.72792604991368, 57.80189732142857, 55.62625305993216, 48.573320797511506, 47.47799982343401, 42.29604026249477, 36.086372647966655, 42.346192359924316, 50.557403223855154, 38.27180692127773, 43.9108259337289, 39.30989210946219, 38.20883887154715, 34.06839343479702, 22.061637026923044, 19.508141040802002, 23.9999794619424, 31.141336236681255, 71.14381435939244, 36.817201546260286, 69.01688044411796, 52.72322620664324, 18.090856177466257, 39.73733833857945, 42.76549530029297, 40.41966881070818, 26.85841277667454, 43.87454244068691, 61.172551836286274, 57.70785345349993, 47.13999080657959, 66.78360434940883, 62.97927107129778, 68.60663795471191, 70.40133680616105, 69.40840448651994, 68.71027728489467, 74.49130358014787, 73.9648107801165, 57.01747349330357, 24.566634586879186, 8.95584670134953, 1.2990844973496027, 0.12150918772178036, 0.1196135508694819, 0.0567278447560966, 0.06673621253243514, 0.07152861037424632, 0.030776913344327892, 0.05484297964721918, 0.05083296660866056, 0.06749247373746974, 0.07150279211678676, 0.0869647663618837, 0.03592326558594193, 0.0693536749375718, 0.03535940298544509, 0.01389327846534018, 0.03530871641955205, 0.046490647830069065, 0.07828542137784616, 0.04210126246990902, 0.0422021809832326, 0.0358197109640709, 0.02918136538937688, 0.03567875888464706, 0.0504567766162966, 0.03283728492845382, 0.015870286085243736, 0.0571248522028327, 0.029631980495261293, 0.04435247881338, 0.03581796373639788, 0.00914599302424384, 0.02393443899096123, 0.016725350470681275, 0.0026442100435295807, 0.02614137583545276, 0.01521002740732261, 0.01932656535479639, 0.015323463195402707, 0.011478183192334004, 0.04651883417474372, 0.014062935968727937, 0.03365785089720573, 0.012496933972995197, 0.022178595619542257, 0.017657900162573372, 0.01485983039518552, 0.029237045973007168, 0.028266002989507148, 0.07109606465590851, 0.025897004841161624, 0.016830109492210404, 0.06600583743836198, 0.020899709779769182, 0.08967093365000826, 0.02769338389459465, 0.04813194600865245, 0.06384498160332441, 0.017192732176876495, 0.06232747196086815, 0.0327359830428447, 0.029096083715558052, 0.0655490273077573, 0.030352767889520953, 0.03595336200669408, 0.019356590529371585, 0.03153420252991574, 0.0034715842630248517, 0.020382571100656475, 0.05726178056959595, 0.02737004160215812, 0.027194563964647905, 0.044094374270311425, 0.057890450049723895, 0.03464182845449873, 0.016785684108201946, 0.023179933495287384, 0.044889841228723526, 0.09661590241427932, 0.07229578920773097, 0.09877998129065547, 0.045885472624961815, 0.03413773121844445, 0.017530181212350726, 0.0286358978732356, 0.0514422130238797, 0.016847077956689254, 0.056114673015794585, 0.028683151051934277, 0.051052024854081016, 0.03259900039327996, 0.1679094343313149, 0.012600678584671446, 0.014362783137974995, 0.02887405687943101, 0.06104799918830395, 0.01066384108604065, 0.012736703651691121, 0.027741120529494116, 0.00649729510769248, 0.08012405450322799, 0.03527040972507425, 0.03241438797808119, 0.03646137099713087, 0.037982588833464045, 0.059574078635445664, 0.04160113466371383, 0.06239109140421663, 0.03075708994375808, 0.010370251706003078, 0.047415012693298716, 0.05747866750295673, 0.025874468996854763, 0.08587788896901266, 0.11865434662571975, 0.06876550721270697, 0.05282079601394279, 0.461321194257055, 0.29894119607550756, 0.8807640756879533, 2.9064814107758656, 17.202341386250087, 37.62634359087263, 61.37855897630964, 72.32304872785295, 78.24877820696149, 71.86212607792446, 68.95449951716832, 62.30507346561977, 60.240332875932964, 49.881680488586426, 52.43229818344116, 47.31973723002842, 29.297270434243337, 42.63505676814488, 43.49112694604056, 49.04774032320295, 55.820125171116416, 40.918653692517964, 40.77586126327515, 44.957832608904155, 57.07917349679129, 56.70914370673043, 61.12983431134905, 65.17722947256905, 59.95751340048653, 66.03964682987758, 52.79217318126133, 50.51523460660662, 51.77561698641096, 58.61575371878487, 55.109491212027415, 75.7009710584368, 53.09600748334612, 69.02695533207485, 59.28051567077637, 43.17600529534476, 58.964087758745464, 59.62445150102888, 54.332092012677876, 38.703828539167134, 43.59231356212071, 33.35004002707345, 40.40748167037964, 31.7816162109375, 38.00811931065151, 39.59843690054757, 49.44470827920096, 57.86724165507725, 68.1109812600272, 66.9488742010934, 81.92808559962681, 82.74861921582902, 76.88235936846051, 40.85432379586356, 15.842023066111974, 2.2832306027412415, 0.142176482294287, 0.18758570136768477, 0.05223618041990059, 0.0006870800009762336, 0.06740113613860947, 0.0695898729775633, 0.041227044737232585, 0.01919428495291088, 0.10632401505219084, 0.08872025180608034, 0.1086143557248371, 0.011588322996561016, 0.035361221459295065, 0.020475392994870032, 0.05075946091009038, 0.07302881737372705, 0.09619924120072808, 0.026887613381924372, 0.10373078313257013, 0.01071502807150994, 0.02060161577537656, 0.01604527178486543, 0.031355666395808966, 0.013638682796486785, 0.049608173580574136, 0.017247176130435297, 0.06818987202963658, 0.1446649416216782, 0.0514446693206472, 0.041518190543034246, 0.011592245777137578, 0.02448304812423885, 0.08156482862042529, 0.014035575740438486, 0.04200180959222572, 0.017659002781978676, 0.016244862860600864, 0.06522650604269334, 0.04072024014645389, 0.03566147999039718, 0.019003323146275113, 0.04104364011436701, 0.08559238178921597, 0.05174355721101165, 0.022242712089791894, 0.024952920053952506, 0.029925623309931586, 0.022500487543376427, 0.01624742433029626, 0.01851514434175832, 0.019526534713804722, 0.11222569551318884, 0.07794927512960774, 0.06892299519053527, 0.06198304080005203, 0.01026034345185118, 0.09310969484171697, 0.14432199645255292, 0.1988542274172817, 0.12823250623685972, 0.15344901170049394, 0.1589784478502614, 0.07329945785126515, 0.12988382977034363, 0.1430041864514351, 0.14444006154579775, 0.14317354879208974, 0.14677125002656663, 0.12403473577329091, 0.1593026247407709, 0.13248925496424946, 0.14571181258984975, 0.11772820060806614, 0.22498134044664247, 0.13972489455980913, 0.07015159140740122, 0.24480015411973, 0.2587786540389061, 0.15245327513132775, 0.17056246554212912, 0.09100458065846137, 0.10639112216553517, 0.10547721013426781, 0.1351855088557516, 0.15385493849005016, 0.15903045077409061, 0.18825541543109076, 0.13835213679288114, 0.2819236735148089, 0.10278137014912707, 0.2092273315148694, 0.18147683702409267, 0.14104943562831196, 0.09080232294010264, 0.10727742460689374, 0.08244636096060276, 0.20484273321926594, 0.0848879674449563, 0.09846364826496158, 0.21184017988187925, 0.07732101277049098, 0.10865565815142222, 0.12413092489753451, 0.29547301360539024, 0.1416408603212663, 0.14679628796875477, 0.13450632244348526, 0.06608200977955546, 0.11235011169420821, 0.11509367983256068, 0.11109765818608658, 0.19950111556266034, 0.20935894016708645, 0.2670417720718043, 0.2990020199545792, 0.12228096702269145, 0.62595192023686, 0.38306146221501486, 0.7268479604806218, 3.638286965233939, 19.413131373269216, 41.27757331303188, 67.8564270564488, 85.36975765228271, 97.4478668485369, 95.84126268114362, 96.03206716264997, 96.51578685215541, 86.44682570866176, 80.10889434814453, 77.02253232683454, 92.39189202444894, 87.23448044913155, 88.81985786982945, 88.56730474744523, 87.1608086994716, 81.03624262128557, 75.7559243610927, 68.26172937665666, 66.24786349705288, 67.1035133089338, 72.28673049381801, 60.70300647190639, 61.36194583347866, 57.846150398254395, 55.75828272955758, 52.8564579146249, 36.8284888948713, 34.99630103792463, 45.40638746534075, 54.01340593610491, 110.47068091801235, 77.02900804792131, 136.1226588657924, 81.7627671105521, 40.19847638266427, 68.86423546927315, 71.63956832885742, 67.01429843902588, 47.35985265459333, 76.2488295691354, 96.85772160121373, 96.78694030216762, 71.9454071862357, 93.4285215650286, 81.79972457885742, 86.19505078451974, 85.67199734279087, 86.0656544821603, 84.19653347560337, 95.96144567217145, 101.72282246180943, 89.25853238786969, 50.519236768995015, 18.300526755196707, 2.4068331931318556, 0.22941553965210915, 0.27753604895302225, 0.15462314869676316, 0.13414960301348142, 0.17271719420594828, 0.17622200399637222, 0.15957133817885602, 0.07264609648180859, 0.11962951001312051, 0.2527113567505564, 0.16200441547802516, 0.12325965879218918, 0.16350133158266544, 0.10289941488632134, 0.12583419707204613, 0.20201964756207808, 0.2718627633793013, 0.1604642631219966, 0.14464683830738068, 0.24367074615189008, 0.1503183596900531, 0.1256040379937206, 0.1643367710390261, 0.28633564391306465, 0.15644793292241438, 0.09302578720131091, 0.1996879976774965, 0.27442483018551556, 0.07704246735998563, 0.14392684479909285, 0.09737878612109593, 0.14908690005540848, 0.1826897319406271, 0.1278112716972828, 0.20374223084322043, 0.11980318783649377, 0.08284340572676488, 0.1518750683005367, 0.11207844662879195, 0.11873773857951164, 0.1205292067357472, 0.20406624488532543, 0.20692930982581206, 0.21922648139297962, 0.12066860496997833, 0.1293674646211522, 0.12157463920967919, 0.10460616116012846, 0.15874622602547916, 0.12001043957258974, 0.09896458352782897, 0.1340131089091301, 0.1288844155413764, 0.1431397713188614, 0.2602175825408527, 0.18492821896714823], [0.04029791655817202, 0.03896844254008361, 0.02838421905679362, 0.07143440935760736, 0.0407934303262404, 0.06977557444146701, 0.041347427027566094, 0.03698680476684656, 0.04689309712765472, 0.06954816342996699, 0.05581171391531825, 0.008262667655279594, 0.029806458989956548, 0.047797842150820155, 0.03497939623360123, 0.03657572789649878, 0.030439542340380803, 0.04104010833959494, 0.04454828366371138, 0.01736940403601953, 0.06247601006180048, 0.06978126056492329, 0.04345615780247109, 0.0343067407208894, 0.05487593270039984, 0.0376208482443222, 0.007636173728055188, 0.08775773631142718, 0.009113671008630522, 0.029515879760895456, 0.020708364600847875, 0.040535186683493, 0.0987043653481773, 0.05377122340723872, 0.030631259017224823, 0.03626314377678292, 0.059883110624338896, 0.03239993518218398, 0.03970111447519489, 0.028682292705135684, 0.05220931043316211, 0.02760343050717243, 0.03827724605798721, 0.06940659388367619, 0.023223397055906907, 0.013705236055622143, 0.030237118380942514, 0.1497988189969744, 0.017019234165283184, 0.05578174302354455, 0.05667665607428976, 0.07023019290396146, 0.10608189340148654, 0.034183467871376445, 0.05989978222974709, 0.024151904375425408, 0.051121011509427, 0.020947325974702835, 0.08465501280235392, 0.05079377781865852, 0.10177387456808772, 0.0861909853826676, 0.1645755475120885, 0.4309554493853024, 0.21182214442108357, 1.757185852953366, 4.017622564520154, 4.001239580767495, 1.6103500063930238, 20.7273952960968, 52.84449659075056, 63.37939003535679, 62.615102086748394, 47.0237717628479, 56.2675370488848, 66.99510056631905, 68.6601390838623, 78.28503390720913, 70.06399481637138, 70.88855143955776, 59.85421453203474, 67.86816951206752, 70.19592721121651, 72.05580711364746, 71.69650186811174, 71.32236916678292, 78.57033388955253, 60.243800027029856, 71.12910502297538, 69.32448414393834, 75.05587250845772, 76.79877253941127, 68.23754964556012, 56.31402397155762, 28.960423503603252, 59.18686090196882, 72.9976076398577, 83.61039733886719, 46.30498061861311, 45.94269806998116, 56.73642928259713, 57.14992005484444, 64.11182744162423, 72.35450322287423, 72.92351899828229, 63.21243177141462, 76.04250281197685, 70.83485576084682, 77.68146474020821, 81.10562038421631, 78.85659272330147, 69.2492698941912, 67.39784594944545, 59.89823137010847, 40.256504263196675, 21.225579398018972, 5.365796302046094, 0.3589139479611601, 0.21421502530574799, 0.03908757632598281, 0.07424307614564896, 0.0390415411176426, 0.04682401887008122, 0.05558180250227451, 0.0790162103782807, 0.03249586646312049, 0.01661362628718572, 0.06417037985686745, 0.032430662640503476, 0.015377840991797192, 0.10057120517428432, 0.034488493110984564, 0.045219168200024536, 0.023316179934356893, 0.034580180155379434, 0.09647216834127903, 0.04732669457527144, 0.06671111352209534, 0.08452942275575229, 0.037534182359065325, 0.09566408741687026, 0.05263327268351402, 0.0840073104149529, 0.08252511852021728, 0.09598833216088158, 0.05315922213984387, 0.08776169217058591, 0.14004187897912093, 0.017163482228560106, 0.005022643857435989, 0.04479864951489227, 0.018076281462396895, 0.05512105347588658, 0.039059016787047894, 0.0427736431759383, 0.044991305962737115, 0.028033426630177667, 0.02094475263064461, 0.07690869418105908, 0.041035348416439126, 0.010990140942989715, 0.06078274627881391, 0.03887565966163363, 0.06871507170477084, 0.029145121441355774, 0.02268864700038518, 0.05047688839424934, 0.0771682338256921, 0.024688296485692263, 0.021186487516388297, 0.031875044240483215, 0.07629820265408073, 0.0733590264405523, 0.06380165714238371, 0.042592562535511594, 0.10892527404108218, 0.006259085635455059, 0.039861292844372134, 0.046982751959668737, 0.06719161131020103, 0.0434839675602104, 0.018518369079434445, 0.02268857236153313, 0.036535816466701884, 0.02866960410028696, 0.04349581138896091, 0.03220918541774154, 0.03745971653344376, 0.07725822113986526, 0.054504417814314365, 0.015039134970200914, 0.0038527027520883295, 0.05328403187117406, 0.03064769652805158, 0.029538939773504223, 0.024123265108625804, 0.03794337629473635, 0.07897488759564501, 0.04672256092141781, 0.01693273621744343, 0.015479395631700754, 0.03277920572353261, 0.08146881591528654, 0.017371317504772117, 0.027063920528494885, 0.03620641485654882, 0.027949181418599825, 0.05689495096781424, 0.02683715073258749, 0.04346676330481257, 0.05538793486942138, 0.023446767391370874, 0.026325095977102007, 0.059975486381777694, 0.010231397147955639, 0.03542094950431159, 0.008589885230841381, 0.08067941505994115, 0.005927080147167934, 0.0336352726444602, 0.08930024996932064, 0.01779573946259916, 0.05872704301561628, 0.11080332326569728, 0.09283222830189125, 0.08270070981234312, 0.03793844334515078, 0.08091917540878057, 0.022998995347214595, 0.017142627454761947, 0.01734969937907798, 0.046927023878587146, 0.05603838871632304, 0.06687924092901604, 0.13298748965774262, 0.04765282564663461, 0.07309886932905231, 0.07425649078296763, 0.23913430528981344, 0.32749774945633753, 0.9058503838522094, 3.3963884711265564, 6.344846555164882, 15.097674710409981, 20.28779493059431, 50.02929496765137, 81.78730814797538, 82.60746656145368, 84.72131701878139, 72.7801012311663, 64.72168472834996, 67.86953135899135, 55.9574111529759, 58.41492993491036, 54.21634892054966, 54.90555810928345, 48.29773439679827, 35.1661810193743, 29.798992906297954, 30.73633963721139, 42.77172436032976, 39.58083363941738, 42.1305376461574, 45.04222195489066, 36.99242469242641, 40.09763717651367, 34.46937050138201, 23.205379996980938, 18.132845878601074, 30.918198313031876, 32.54085629326956, 82.20262282235282, 58.042040961129324, 89.6695669719151, 59.77631827763149, 28.030275106430054, 46.55893727711269, 53.046508516584126, 45.17489085878645, 32.21068137032645, 47.02898291179112, 53.96005766732352, 55.39580910546439, 54.83252559389387, 72.01467377798897, 81.89802769252232, 87.17760944366455, 83.45885712759835, 84.09338051932198, 75.51184109279087, 58.664953913007466, 35.10726029532296, 9.398069143295288, 0.4857673453433173, 0.15469934817935738, 0.08626553602516651, 0.049452449793794324, 0.02903620300016233, 0.10406306851655245, 0.07808257333402123, 0.0560798234572368, 0.11175017817212002, 0.04969039506145886, 0.05682741298473307, 0.12332512385078839, 0.026419670188001225, 0.06373800377228431, 0.0537895099259913, 0.03404911793768406, 0.04352685097338898, 0.029590606822499206, 0.027998095311756645, 0.03212137959365334, 0.01294609107675829, 0.03195128104250346, 0.03999854012259415, 0.058544808865657876, 0.047434781811067035, 0.041560507379472256, 0.0708210544128503, 0.04025429693449821, 0.03634566381307585, 0.02073092419388039, 0.013313695056630033, 0.017233574895986488, 0.04642519634217024, 0.05339193590251463, 0.017750399752653072, 0.014270212301718337, 0.05306832219607063, 0.026454292437327758, 0.10444722111736025, 0.13120341753321035, 0.0560131031088531, 0.06483835008527551, 0.03015326502333794, 0.07346964800464255, 0.04638820939830371, 0.05126385670155287, 0.043707388785800765, 0.0595283250191382, 0.021554221266082356, 0.023471074212076407, 0.026633079629391432, 0.02575604767272515, 0.09615297189780644, 0.04989532960046615, 0.09048563707619905, 0.01728585093016071, 0.057158738241664, 0.07651940507016011, 0.10514921309160334, 0.10045053450656788, 0.2043618961636509, 0.12615783113454068, 0.16207012480923108, 0.11223597531872136, 0.19462985838098185, 0.0833299628325871, 0.1060585585821952, 0.10597101399408919, 0.15963278631014483, 0.17162750767810003, 0.12096432410180569, 0.15114795017455304, 0.12596130025173935, 0.11119749104338032, 0.14498768001794815, 0.14007930697074958, 0.08712075477732079, 0.1032568739194955, 0.1024301400674241, 0.1906462607106992, 0.19749312688197407, 0.12897018236773355, 0.12113918257611138, 0.11088139550494296, 0.11989713779517583, 0.20044385854687008, 0.14777626895478793, 0.11249546068055288, 0.09333687515131064, 0.13492632204932825, 0.24496083121214593, 0.14671666866966657, 0.20087672317666666, 0.16750443034938403, 0.09190227570278303, 0.07073443263236966, 0.16259375028312206, 0.11559000105730124, 0.2573778049222061, 0.16064688403691563, 0.18836812009768827, 0.08753550252211945, 0.17554933152028493, 0.16188685250069412, 0.12939770014158317, 0.10869086733353989, 0.19415181688964367, 0.26244700433952467, 0.19181894564202853, 0.08146634604781866, 0.2126737737229892, 0.1978241569761719, 0.10974933446518012, 0.0959181852106537, 0.11307482780622584, 0.13678482946540627, 0.13522461961422647, 0.3818855338862964, 0.13317296041974, 0.20038644091359206, 0.1791915717933859, 0.3955613800457546, 0.592642961868218, 0.4778202889221055, 2.3915693036147525, 6.3873730046408514, 15.770774500710623, 17.737333570207866, 54.07823610305786, 88.94628034319196, 96.4382380076817, 101.15425831930978, 92.82910742078508, 87.46645995548793, 94.05673599243164, 92.46525805337089, 98.6154282433646, 89.94806466783795, 93.06315749032157, 76.58349650246757, 83.98632962363106, 87.46547331128801, 87.9522293635777, 94.8260474886213, 103.25293391091483, 116.34447261265346, 83.87882014683315, 95.92599596296037, 94.41425555092948, 107.22039004734584, 111.62169170379639, 98.85425867353166, 84.89541803087506, 51.73713786261422, 89.32483209882463, 130.06627546037947, 125.95413698468889, 66.62149592808315, 81.8901206425258, 91.92568179539272, 87.84959752219063, 92.6753785269601, 104.97587871551514, 97.83306108202252, 79.38612883431571, 91.3456392288208, 87.25239290509904, 95.69327994755336, 101.05462115151542, 104.37695789337158, 95.92937973567417, 98.37118516649518, 84.49604947226388, 67.0899017878941, 34.91136973244803, 10.506605591092791, 1.016367182135582, 0.23286684017096246, 0.1910219384091241, 0.11698648040848118, 0.12395926910851683, 0.20147931655602797, 0.24533410689660481, 0.19908361296568597, 0.1801848927778857, 0.10989207787705318, 0.09876318076359374, 0.18190499262085982, 0.10573620016553573, 0.19504193269780704, 0.1659194811114243, 0.19135665973382338, 0.1007002421787807, 0.11881092536662306, 0.2678264028259686, 0.16017471865883895, 0.20686220271246775, 0.19127528981438705, 0.18323386274278164, 0.20166698577148573, 0.1524012450660978, 0.2211698056863887, 0.19726284566734517, 0.18545202086014406, 0.19798267632722855, 0.11385858325021607, 0.18351583475513117, 0.08418826213372604, 0.12459927690880639, 0.23186154982873372, 0.0606157248839736, 0.178065475076437, 0.1118092785722443, 0.13433663440602167, 0.1852873404111181, 0.21700944964374813, 0.12955776655248233, 0.15879664117736475, 0.09158866360251393, 0.11586502487105982, 0.15535000897943974, 0.19240795475031647, 0.17969698538737638, 0.16171252328370297, 0.12343020178377628, 0.13386650463300093, 0.08014534014676299, 0.1055667699713792, 0.18086707831493445, 0.1292465768222298, 0.1433431011225496, 0.2187650775802987, 0.14786360998238834, 0.1700237901615245, 0.33104559193764416], [0.09512189043951885, 0.058536238968372345, 0.014433991995507052, 0.030332744321120635, 0.0007836063783283212, 0.034635083816413365, 0.04006688216967242, 0.036293983193380494, 0.08296487028045313, 0.0509274797514081, 0.04611083446070552, 0.047700445234243355, 0.026048287616244385, 0.06005419644394091, 0.03763175908742206, 0.017501988082325885, 0.07828248332121543, 0.04770706434335027, 0.038695681640612226, 0.043134430423378944, 0.06466639574084963, 0.027978463597329598, 0.0833038595904197, 0.06266955539051976, 0.01873762918902295, 0.06326762972665684, 0.0913014125877193, 0.06247299736631768, 0.011830568479906236, 0.051467159363840304, 0.011094650602899492, 0.0270140108851982, 0.007199660276195833, 0.02117235363194985, 0.034107288744832785, 0.04446810118055769, 0.03428839991933533, 0.030608796115432466, 0.04359198694250413, 0.04488802614754864, 0.03376380753304277, 0.05862015339412859, 0.051280161898050985, 0.07277569667037044, 0.04234739086989846, 0.05218811299917953, 0.12039553533707346, 0.041812817233481576, 0.04757133698357003, 0.09858732484281063, 0.027905344663720046, 0.04686355710561786, 0.05191082627113376, 0.03225130208634904, 0.06543595623224974, 0.020872011980307952, 0.04975757681365524, 0.006210972837704633, 0.036496566608548164, 0.05242783263591783, 0.06797924118914775, 0.03552759824586766, 0.07193293582115855, 0.12307968416384288, 0.026477447444839135, 0.33923762664198875, 0.29753928844417843, 0.21276061263467583, 0.8128725215792656, 2.4401185384818485, 7.591680816241673, 10.11328717640468, 14.232002990586416, 15.952829463141304, 43.59697927747454, 54.269370623997276, 60.95551095690046, 65.45529638017926, 81.11320781707764, 82.13405105045864, 91.13498374394008, 80.45439352308, 77.94378008161272, 90.34154115404401, 88.45473003387451, 87.1804165158953, 90.1637714930943, 86.32669830322266, 97.5686126436506, 92.3036776951381, 85.62295695713588, 85.9958598273141, 85.42352281297956, 79.93625245775495, 78.97672707693917, 67.77562645503453, 74.50805568695068, 63.665648869105745, 77.72923360552106, 85.96269607543945, 78.47569942474365, 78.31481388636998, 70.62422806876046, 70.47918442317417, 79.66896220615932, 70.49387291499546, 71.9380281993321, 76.29921790531704, 65.00046730041504, 44.73650469098772, 29.96657998221261, 19.08748320170811, 4.844630599021912, 1.273766998733793, 0.1109982460205044, 0.09388402543429818, 0.10592660387711865, 0.029634776059538126, 0.13716983023498738, 0.0603555202750223, 0.07563346903771162, 0.005753376454647098, 0.020855091013280407, 0.035564364665853124, 0.0594439831163202, 0.047465159823851924, 0.03919021492557866, 0.03491486416065267, 0.06078078531261001, 0.02090990816109947, 0.07675798476806708, 0.041841098573058844, 0.018794315700818385, 0.040778807896588526, 0.08793621816273246, 0.04781703112114753, 0.03027216132198061, 0.020949789056820527, 0.053682345497821055, 0.06654031947255135, 0.040482783424002786, 0.10188381081180913, 0.009894023599502231, 0.04428007234154003, 0.05836355180612632, 0.023521245091355274, 0.05428942399365561, 0.05446781424273338, 0.01915242612761046, 0.01588104086528931, 0.06304657658828156, 0.054282991481678824, 0.012849229354677456, 0.04352357364924891, 0.034301566891372204, 0.016778026840516498, 0.10257777571678162, 0.055320776865950654, 0.04090731903644545, 0.03481760295107961, 0.051260613304163725, 0.07825817819684744, 0.04567265011636274, 0.021301904626722847, 0.022494209398116385, 0.06693296733179263, 0.020644107334581868, 0.03701542876660824, 0.016393090531762158, 0.062418307443814616, 0.012944832394298698, 0.04936524447319763, 0.048344174799110205, 0.007821063494442828, 0.03131658277873482, 0.013538679457269609, 0.042146052566490004, 0.030365958610283475, 0.02789479005150497, 0.07115893771073648, 0.031722180478807004, 0.024295424709894826, 0.032259054348937104, 0.05413819889404944, 0.034417501384658475, 0.05011468640129481, 0.03745594387874007, 0.021683846899707402, 0.05585135393110769, 0.042070083785802126, 0.033693409524858, 0.0555022340933127, 0.09694090033216135, 0.0369186561022486, 0.03260561950238688, 0.09546632838568517, 0.04823819102187242, 0.0042326581897214055, 0.05955522893262761, 0.03662304214334913, 0.04666346052129354, 0.049150691700301, 0.016687980154529214, 0.07462849760694162, 0.025181642334376062, 0.004829038308733808, 0.008415444055572152, 0.028983555468065397, 0.014086385290803654, 0.006613907287828624, 0.04637704071189676, 0.05349316654194679, 0.030817862932703326, 0.014381746495408671, 0.07955958800656454, 0.09995360938566071, 0.018582488942359175, 0.046990534756332636, 0.013333828038802105, 0.11527988341237817, 0.03463210165500641, 0.06615905743092299, 0.10521111584135465, 0.07426671630569867, 0.09032107876347643, 0.01869836406383131, 0.055056663895291943, 0.04216508886643818, 0.02803047839552164, 0.03766426430749042, 0.008156336977013519, 0.08047866368932383, 0.08913407674325363, 0.05318762900839959, 0.0275488762916731, 0.010234501445665956, 0.19371089126382554, 0.11503204171146665, 0.052040680910327604, 0.10630140626536948, 0.15795137653393404, 0.08457253687083721, 0.31022053797330174, 0.8565128541418484, 2.1113050282001495, 7.360087803431919, 18.6931277683803, 28.951017379760742, 34.483009815216064, 34.22634335926601, 62.09480707986014, 74.94870349339077, 79.53015109470913, 87.49098709651402, 91.9886394228254, 90.27277483258928, 90.03099836621965, 89.91929912567139, 86.32764325823102, 84.74542031969342, 85.81582505362374, 84.67815480913434, 87.4844696862357, 77.76359939575195, 86.71233722141811, 76.21772248404366, 76.36197403499058, 70.96348081316266, 65.91602448054722, 66.87235369001115, 56.053463050297324, 59.92794186728341, 65.61457688467843, 71.17125974382672, 66.4869510105678, 60.91434288024902, 63.824581963675364, 66.48094081878662, 77.39743627820695, 77.32832254682268, 89.3807373046875, 86.26254558563232, 90.69068118504116, 92.77869129180908, 86.567460332598, 69.86847945622036, 50.864979130881174, 33.919569969177246, 13.023931860923767, 5.480924044336591, 0.8745808303356171, 0.03890285873785615, 0.1603193823248148, 0.019730442968596305, 0.14619802364281245, 0.05404762125441006, 0.06343024742922612, 0.03154351881572178, 0.06544605961867742, 0.0373008511295276, 0.054335072437035184, 0.027487161835389476, 0.020529672403686812, 0.029706392038081373, 0.05902810900339058, 0.027745120493429046, 0.049682069436780045, 0.015641309354188185, 0.04733209232134478, 0.07311664016119071, 0.029964886738785675, 0.06361012027731963, 0.016367750641490732, 0.04960047899346266, 0.00790565475888018, 0.010095403463180577, 0.08352908571915967, 0.03963079789121236, 0.06500581252787795, 0.052144503553531, 0.061850889319820065, 0.02472386529136981, 0.02817682652468128, 0.02175369529452707, 0.05217520047777465, 0.008508617939826633, 0.051193343342414925, 0.026428324902164083, 0.03478245483711362, 0.03923712883676801, 0.046533897652157714, 0.07479072854455028, 0.05196492926084569, 0.031577238613473516, 0.029810581090194837, 0.039426585991999934, 0.025389698134469132, 0.048099763092717955, 0.023720057548156807, 0.023642227885180285, 0.058643562852271965, 0.0152037322986871, 0.09014440860067095, 0.02479917080407696, 0.029982026533356736, 0.06533948890864849, 0.05706542610589947, 0.03420744729893548, 0.042992399473275454, 0.007231150238242532, 0.03260708513802715, 0.02360508487825947, 0.1936863690082516, 0.21100845879742078, 0.14786241576075554, 0.18186782247253827, 0.13486829373453343, 0.1624067731733833, 0.10312561810548816, 0.11911239847540855, 0.18242874023105415, 0.1918533066553729, 0.12732275362525666, 0.21598923153110913, 0.10356544450457607, 0.10980618212904249, 0.1201870758086443, 0.12624274300677435, 0.15370761496680124, 0.15605454546000275, 0.1662605263824974, 0.23304013801472528, 0.09665126087410109, 0.09922554131065096, 0.12893780267664365, 0.13230324137423718, 0.17876543823097432, 0.15281593852809497, 0.09948465347822223, 0.1786982768348285, 0.18687949569097587, 0.12927191331982613, 0.08854760535593544, 0.16196926736405917, 0.10656793482069458, 0.12933760908033165, 0.13599865165139946, 0.12465817374842507, 0.11770479114992277, 0.0629854609391519, 0.10603096934833697, 0.1563644324030195, 0.12108230777084827, 0.16355132604283945, 0.13911231314497335, 0.14773377909192018, 0.12509064482791082, 0.17052965158862726, 0.21533505591963018, 0.10870715895933764, 0.09353587590157986, 0.13054882123001985, 0.06909672051135983, 0.11518978753260203, 0.10510657395103148, 0.07436613525663104, 0.11877420305141381, 0.20051160348313196, 0.21532749703952245, 0.10883094410278968, 0.08831772447696754, 0.1066979014181665, 0.29825693422130173, 0.20062771439552307, 0.37343511304685045, 0.25439409645540373, 0.16019521041640214, 0.5226224905678204, 0.337951477084841, 0.3534868077508041, 1.355881895337786, 4.4735420772007535, 12.22991865021842, 19.687480994633265, 27.072448560169764, 29.910747732434952, 65.52970463888985, 79.5475354875837, 89.66915007999965, 92.5569395337786, 109.5606267111642, 105.34489059448242, 117.39551271711076, 110.16553688049316, 108.85511357443673, 114.60795102800641, 109.81514617374965, 104.86070537567139, 106.28605188642229, 108.94622530255998, 116.48072678702218, 111.62108721051897, 101.86655289786202, 103.69023963383266, 103.99259744371686, 105.71985707964215, 99.28535270690918, 85.8021023614066, 89.53784997122628, 78.87008612496513, 101.03869588034493, 106.85898644583565, 91.97181783403668, 94.14561734880719, 92.543869972229, 89.17340305873326, 104.6598676953997, 102.04051494598389, 103.9528329031808, 105.75460502079555, 88.79234300340924, 71.55948339189801, 50.13733945574079, 32.22884743554251, 10.80833980015346, 4.175291086946215, 0.5279362340058599, 0.23866345626967295, 0.25717497723443167, 0.060040849660124095, 0.2382467814854213, 0.10621931031346321, 0.22224176887954983, 0.17079331672617368, 0.19636146617787226, 0.19680467168135302, 0.11253087342317615, 0.2502405936164515, 0.09583748025553566, 0.17011710229728902, 0.1572900220219578, 0.12650776521435805, 0.23718283857618058, 0.10863351755376373, 0.12679432412343367, 0.21774988062679768, 0.18195092944162233, 0.11355028407914297, 0.13321455461638315, 0.11114280112087727, 0.19336821750870772, 0.16604952913309845, 0.23762451059051923, 0.15549292202506745, 0.14973057194479875, 0.10867258081478731, 0.16264673029737814, 0.1486698995743479, 0.26300994413239615, 0.10856153855898551, 0.10089126335723059, 0.09053127534155335, 0.1313121866966997, 0.1389975185905184, 0.10641944421721355, 0.11110193974205426, 0.09510002125586782, 0.16246560215950012, 0.19939791038632393, 0.20061726495623589, 0.10540511578853641, 0.1441784862961088, 0.17035213325704845, 0.13473426949765, 0.07580103326056685, 0.08813760735626731, 0.0955753553924816, 0.09812149019645793, 0.16009545219796045, 0.14980050176382065, 0.11567435653081962, 0.14928275240319117, 0.10570525218333517, 0.15980024875274726, 0.07619283295103482, 0.1744311736630542, 0.12681640365294047, 0.12317687751991407], [0.029397522897592614, 0.009660587197036614, 0.05960531160235405, 0.06929013013307538, 0.0026474606503532933, 0.034990514029881785, 0.08342200610786676, 0.03112570069996374, 0.13785455349300588, 0.053490069029586654, 0.035334565211087465, 0.018677733206589307, 0.02098018572931843, 0.009654974016094846, 0.05733324387776, 0.0428043672415827, 0.1360192248331649, 0.035569440107792616, 0.03710975531222565, 0.05919303372502327, 0.02361126972495445, 0.012116576927447957, 0.10110004179711853, 0.0190484372433275, 0.030381242611578534, 0.045471474661358764, 0.027454607421532273, 0.02007518625552101, 0.04323516233957239, 0.010399246355518699, 0.08408670579748494, 0.06549813039600849, 0.0454968111589551, 0.030516868191105977, 0.08155690333140747, 0.0456422992449786, 0.01836222629728062, 0.045556576523397646, 0.05973207551453795, 0.02607674028591386, 0.02763797133229673, 0.020156464572729807, 0.03285207020651017, 0.036919751936303716, 0.07063368375280074, 0.07092932146042585, 0.03857700586585062, 0.03370923635416797, 0.025616854695337157, 0.034397426926131756, 0.006167986372020096, 0.028095273400789926, 0.10165040155074426, 0.097129838408104, 0.02875093330762216, 0.06400906494153397, 0.020430475672973052, 0.04089287641857352, 0.034301644922899346, 0.09007999527135066, 0.05129319655575922, 0.04176011202590806, 0.009562191137644862, 0.11402764703546252, 0.060852499678730965, 0.10354119366300957, 0.08803995938173362, 0.06496000462876898, 0.10845654883555003, 0.2097650705171483, 0.19589352128761156, 0.11044575566692011, 0.02414659483890448, 0.24323900789022446, 2.5406563665185655, 4.526186840874808, 12.549776366778783, 14.508415358407156, 16.821460247039795, 27.53871958596366, 31.781098570142472, 23.30434318951198, 27.27122609955924, 55.65870809555054, 49.64486503601074, 52.20543949944632, 53.785046441214426, 63.24176706586565, 65.31675624847412, 72.27252837589809, 80.22978605542863, 77.92260197230748, 65.40950080326625, 68.68197727203369, 72.51987729753766, 73.19777829306466, 71.86304324013847, 74.322726385934, 68.06080136980329, 74.16720485687256, 72.84218338557652, 62.046913146972656, 59.974091802324565, 51.41299745014736, 46.702806677137104, 33.67507675715855, 22.160643645695277, 11.803225432123456, 3.7807910442352295, 0.9529251349823815, 0.13113875314593315, 0.057673630969864983, 0.10395658601607595, 0.0404083718811827, 0.051694780721196106, 0.06313655711710453, 0.09778538466032062, 0.07168631548328058, 0.07446885188775403, 0.006405153868919504, 0.03677560734961714, 0.032911727005349736, 0.019188836316711137, 0.026177048117720654, 0.04813667539773243, 0.059705985843070915, 0.010097928461618721, 0.01043809502984264, 0.031082332134246826, 0.060278289419199736, 0.02038833525563989, 0.031510396128786464, 0.06097931108836617, 0.03286546448777829, 0.038558519179267545, 0.058977605641952584, 0.029683175962418318, 0.016760152531787753, 0.02114033356441983, 0.034250198397785425, 0.04373592457601002, 0.07889124458389622, 0.05157157911786011, 0.03506586534370269, 0.03236797618280564, 0.01492361438327602, 0.01928294912379767, 0.006787766619319362, 0.009743751841597259, 0.007443794631399214, 0.050336645383919985, 0.05062578611874154, 0.019440976536965797, 0.05330190109089017, 0.052741319207208495, 0.043541280020560534, 0.011848682820397829, 0.06636128800788096, 0.04368292759837849, 0.08617651223071984, 0.06478625895189387, 0.07413591511015381, 0.058703185724360604, 0.048494826536625624, 0.020506503825475062, 0.07873510689075504, 0.030279995008770908, 0.09468636595244918, 0.07663840654173068, 0.058577636389860084, 0.06097060548407691, 0.020261917396315506, 0.050241803151688406, 0.0809930068041597, 0.11799828468688897, 0.0674409865002547, 0.039144848074231825, 0.012245754727960696, 0.1154502092727593, 0.04911338245230062, 0.021539727758084024, 0.0728255214967898, 0.14539618524057524, 0.05667329393327236, 0.079698925172644, 0.03894865645893982, 0.03869543058265533, 0.032726931385695934, 0.05101926179070558, 0.049666259570845535, 0.01826008302824838, 0.0699401938223413, 0.029641693724053245, 0.02648440751779292, 0.03857710764610341, 0.05558233854493924, 0.029274619849664823, 0.05123792648581522, 0.04262602788263133, 0.006418114735944462, 0.06343058669673544, 0.0644461704151971, 0.0697744277172855, 0.031515654775180986, 0.04682436153026564, 0.06981028150767088, 0.035258721959378035, 0.042011397292039225, 0.05379057861864567, 0.050972313952765295, 0.07493616574044738, 0.0386834951516773, 0.019702253231246556, 0.035401726607233286, 0.03838883453447904, 0.041473983986569304, 0.036475671122648885, 0.06627058144658804, 0.05267689230718783, 0.005706560082866677, 0.08786348599408354, 0.07709872469838176, 0.05423598936093705, 0.02598714143303888, 0.03449438279494643, 0.02112216070028288, 0.051199721571590216, 0.031330631846295934, 0.0766289002661194, 0.08316572343132325, 0.037646188134593625, 0.05447756139827626, 0.017804278825808848, 0.06478887809706585, 0.0770127068140677, 0.04438083818448441, 0.05384941439011267, 0.043790692530040226, 0.10845900513231754, 0.04880849291969623, 0.047339556206549914, 0.05858152439551694, 0.011011104282390858, 0.13220133898513658, 0.07605038130921976, 0.19005704804190568, 0.5630706144230706, 0.34557671791740824, 0.9275972140686852, 2.2451764047145844, 11.036339725766863, 16.30149527958461, 29.86841583251953, 33.097372259412495, 44.20425878252302, 53.63613264901297, 60.76040554046631, 51.67296082632882, 54.40541982650757, 84.95752797807965, 79.68608951568604, 85.05998611450195, 86.95349529811314, 94.5176030567714, 93.6481054850987, 98.27231924874442, 102.51938479287284, 98.09691892351422, 88.65403216225761, 91.7529217856271, 99.63845321110317, 90.724775995527, 95.77551882607597, 94.53869083949498, 91.18646989549909, 99.12092358725411, 100.42402349199567, 91.28436306544712, 80.229660987854, 73.9694104875837, 73.09577178955078, 57.78347069876534, 44.25096109935215, 30.291654927389963, 14.70726932798113, 6.055800625256129, 0.7436911538243294, 0.10354626231959888, 0.11299493709313017, 0.053028220776468515, 0.03258245770952531, 0.1809373474014657, 0.10997148683028561, 0.019498273730278015, 0.04948998295835086, 0.02550135107178773, 0.06915911180632454, 0.004203776346652636, 0.02488796898562993, 0.016690061560698917, 0.046432354886616976, 0.02179618176471974, 0.043191223804439814, 0.013745239087646561, 0.07142628050808396, 0.09057682539735522, 0.0793813436425158, 0.007870644048255469, 0.020257235504686832, 0.02566504425236157, 0.024214322811790874, 0.051476200842963796, 0.048660012494240484, 0.024754216162753955, 0.01923206408641168, 0.023685567613158907, 0.006687513070314058, 0.03904567678858127, 0.06657295700694833, 0.008672729267605712, 0.03217927898679461, 0.08857067554656949, 0.04640647556100573, 0.019007920221026455, 0.060239640064537525, 0.015058571605810096, 0.035548130715531964, 0.015205786563456059, 0.030276568406926732, 0.04459988625187959, 0.010718689616104322, 0.04057275377480047, 0.07859728964311735, 0.05557538695367319, 0.0602746456861496, 0.030326566259775842, 0.025161981782210723, 0.1517656206020287, 0.08743300302220242, 0.04432700660877994, 0.04668951626600964, 0.061997276464743276, 0.014286078146791883, 0.10297304950654507, 0.06648019448454891, 0.06638773051755768, 0.023249944738511528, 0.04017621451722724, 0.05147059953638485, 0.055854427694742165, 0.01738543781851019, 0.09092167046453271, 0.08701619253094707, 0.08027849585882255, 0.1936821485204356, 0.21263597932245049, 0.1630747230457408, 0.16074377883757862, 0.25034329667687416, 0.23697702533432416, 0.17060796810047968, 0.14691862783261708, 0.2290234278355326, 0.12355756280677659, 0.13611025709126676, 0.1239966835294451, 0.19987988738077028, 0.16706267691084317, 0.32270113112671034, 0.1272326306040798, 0.25245424626129015, 0.22345256033752645, 0.10852390022150107, 0.11102468174483095, 0.18702227302959987, 0.09726776422134467, 0.1538606517549072, 0.10485210296298776, 0.13362343981862068, 0.13715297542512417, 0.15556814441723482, 0.14503170336995805, 0.1848625096359423, 0.1648017575166055, 0.10683638363012246, 0.11472120481942381, 0.10963992069342307, 0.12423635566873209, 0.09461760321365935, 0.1468679141253233, 0.11231853267444031, 0.1057677316878523, 0.11300398875027895, 0.11943144564117704, 0.1021107400634459, 0.09575227661324398, 0.13940584739404066, 0.16613822723073618, 0.08862941632313387, 0.11746871524623462, 0.11873376236430236, 0.16009467866803917, 0.08855686735893999, 0.11424655600317887, 0.30891560656683786, 0.23243656754493713, 0.17020699461655958, 0.2724994734994003, 0.15936293293322834, 0.17276245249169214, 0.1648954903440816, 0.13813736688877853, 0.21220308755125317, 0.07949466577598027, 0.3044177336352212, 0.1808418639536415, 0.09541853916432176, 0.1496015688670533, 0.15346980201346533, 0.13772920093366078, 0.28588544949889183, 0.25618477751101765, 0.31569813404764446, 0.16484147895659718, 0.2332780323922634, 0.588204094341823, 4.239945811884744, 7.698473760059901, 19.594180583953857, 23.100754022598267, 31.898439747946604, 42.42766693660191, 48.175929001399446, 43.45234210150582, 51.28603301729475, 79.82037734985352, 76.44179494040353, 86.06876032693046, 86.00335693359375, 93.12551062447685, 90.96969999585832, 98.76557881491524, 110.72258785792759, 107.78395148686, 98.11237171718052, 102.96543829781669, 112.75132983071464, 112.79033701760429, 112.21567235674176, 116.36663041796002, 98.51171943119594, 101.85228824615479, 104.25305066789899, 93.11622783115932, 89.55633217947823, 79.92240469796317, 76.50710800715855, 55.09754031045096, 39.06153222492763, 23.891542400632584, 10.427790437425886, 3.958930696759905, 0.5001191209469522, 0.12625537732882158, 0.2605238732482706, 0.13066018239728042, 0.1525562631764582, 0.2233890223183802, 0.18724697668637547, 0.12693695218435355, 0.15145046822726727, 0.11168925251279559, 0.1058777832825269, 0.12623298567320618, 0.12459326508854117, 0.078032280318439, 0.08583728543349675, 0.45918451462473187, 0.13848808806921753, 0.06586586923471519, 0.11189733206161431, 0.1786861310579947, 0.18806827547294752, 0.1061795074492693, 0.12412837360586439, 0.13161268271505833, 0.1437206787190267, 0.16308738450918878, 0.17612987251154014, 0.18910730257630348, 0.21184832230210304, 0.1528124508580991, 0.1944567369563239, 0.11943645322961466, 0.23801892942615918, 0.078664736023971, 0.09261619632265397, 0.16302415861615113, 0.17954548208841256, 0.1243288264210735, 0.0675293385450329, 0.1704263107052871, 0.13244052257921013, 0.16726333328655787, 0.17483604193798133, 0.1466406863182783, 0.10250741163534777, 0.12931071195219243, 0.13908555172383785, 0.21699654390769346, 0.19339271262288094, 0.14104065538517066, 0.14205625945968287, 0.28375194541045595, 0.2755199857056141, 0.24439504157219613, 0.20071149989962578, 0.18634219095110893, 0.15102208192859376, 0.2178949514137847, 0.16662950015493802, 0.3966769187578133, 0.10955854398863656, 0.2113327035414321, 0.15267719168748173, 0.21864790815327848, 0.23068532294460706, 0.16554167281304086], [0.06599946599453688, 0.04484835899035845, 0.058719925183270655, 0.034129887353628874, 0.05728860305888312, 0.03421683483091848, 0.0729179447516799, 0.0665768925100565, 0.09296123816498689, 0.019517706973212104, 0.02063205655265067, 0.0575312946790031, 0.066394800852452, 0.03343881979318602, 0.04518647977550115, 0.033133672417274544, 0.007783349669937576, 0.09070552991969244, 0.03911225125193596, 0.0889697287763868, 0.05981941654213837, 0.04459127564249294, 0.00645007288715403, 0.024028843568105782, 0.02938444074243307, 0.007790561649017036, 0.08146826630192143, 0.08192610102040426, 0.0067005235552122545, 0.055954199483884234, 0.023837109927886298, 0.059792587267501016, 0.08231926456625972, 0.049181005252259116, 0.055123618338257074, 0.037734747132552524, 0.043726581148803234, 0.05656592933727162, 0.03465284786320158, 0.024875207438266704, 0.028368041085611497, 0.009934162338530379, 0.07246053072490863, 0.006564413671315248, 0.019439907844311426, 0.019204128799693923, 0.08342232501932553, 0.055706734369908056, 0.03549646366653698, 0.05244138976559043, 0.019030973448285034, 0.03317760755973203, 0.02786555197755141, 0.027159607536824684, 0.051600152227495394, 0.022923908662050962, 0.07919857344989266, 0.027847260369786193, 0.10894733321453844, 0.06150333011256797, 0.0796988776751927, 0.009220279886254241, 0.008065497253223189, 0.07923866129879441, 0.02015291413824473, 0.0843054112046957, 0.033474619300769906, 0.02097070829144546, 0.057443363325936456, 0.09610995277762413, 0.047193993481674364, 0.07056769622223717, 0.02798724384047091, 0.04615722589993051, 0.04164011989321027, 0.042734440815235884, 0.026878841620470797, 0.01356342647756849, 0.02653049022358443, 0.23651811853051186, 0.1421792914292642, 0.18803759211940424, 0.661928824016026, 0.7692442940814155, 0.7324499998773847, 2.019861306462969, 1.1341143952948707, 1.71375972032547, 0.4854337232453482, 1.5888302411351884, 3.33943777850696, 3.071832252400262, 4.679494934422629, 10.149162462779454, 10.71818779196058, 8.484546048300606, 7.531387822968619, 5.703333275658744, 2.536490487200873, 2.338570398943765, 2.540525436401367, 1.2266659204448973, 1.8178058458226067, 1.7449722226176942, 1.5798909493855067, 0.7023278762187276, 0.13882476357477053, 0.03974584011094911, 0.10493090802005359, 0.11290613721523966, 0.048930096573063304, 0.06129614622997386, 0.05343761148729494, 0.03382370521181396, 0.025588461397481815, 0.07744600570627622, 0.031020185111888816, 0.015082846196102244, 0.028592868575028012, 0.05899896592433963, 0.02934266334133489, 0.015646966639906168, 0.026659625615658503, 0.049064982549420426, 0.04785945652318852, 0.06396539442773376, 0.053819063518728526, 0.011368609116678792, 0.02603522072812276, 0.04858192329161933, 0.031804534274020364, 0.022630226831617098, 0.020496132417715023, 0.020002779783681035, 0.01449449357044484, 0.021202578974355544, 0.016664621586512243, 0.061044138324047835, 0.022260372659989765, 0.04672047781891056, 0.05522594481174435, 0.03293901429112468, 0.02103382901155523, 0.0645183597558311, 0.022290940662579875, 0.0619859652859824, 0.062807793329869, 0.06935682334005833, 0.028475889137813022, 0.06223641934671572, 0.057441599134887965, 0.07583370472171477, 0.10370406920888595, 0.026159295945295265, 0.06925349602741854, 0.04074586841410824, 0.061620818451046944, 0.0198600702985589, 0.04559727505381618, 0.026809586943792443, 0.02609585801006428, 0.0400396830934499, 0.023627805623358915, 0.08638307186109678, 0.05709748010018042, 0.06773711953844343, 0.06962523822273527, 0.006292888977830964, 0.1135895848274231, 0.021929673351613537, 0.08454464229622058, 0.06919780187308788, 0.033415179633136304, 0.014519187156111002, 0.07028505924556937, 0.013979696685315242, 0.03547950029107077, 0.06825788159455572, 0.03878565538408501, 0.07386358508041926, 0.04645945896793689, 0.01986075731526528, 0.04291636283908572, 0.09609463824225323, 0.11676511514399733, 0.04131398203649691, 0.08042111034904208, 0.08441965614578553, 0.035972208316837034, 0.12497719377279282, 0.05753593585853066, 0.06196189086352076, 0.03245526632027967, 0.1059682998540146, 0.11779666479144778, 0.03675838613084384, 0.06683080031403474, 0.08988987654447556, 0.04856248665601015, 0.03693710207673056, 0.05789522693625518, 0.028184454954628433, 0.039563748453344615, 0.026078266989705817, 0.04488631284662655, 0.04213008324482611, 0.03747840678053243, 0.0409958475003285, 0.10851509962230921, 0.03327041757958276, 0.026033497249175395, 0.08201811715428318, 0.07985280334417309, 0.07445198350719043, 0.05435003413419638, 0.013634465701345886, 0.04791829568733062, 0.031238222162106206, 0.08926798562918391, 0.04056494044406073, 0.05713866717581238, 0.06770051935953753, 0.06049203473542418, 0.04873913646276508, 0.05107205860050661, 0.024330476132620658, 0.02078673369916422, 0.0405431696479874, 0.017514627493385757, 0.0190261219229017, 0.03580778571111815, 0.09108717872628144, 0.07570355491978781, 0.03400227187999657, 0.15902336686849594, 0.003914712371105062, 0.05962578300386667, 0.04217874099101339, 0.08128565217235259, 0.03517907551888909, 0.07235377681042467, 0.06209508050233126, 0.053951737470924854, 0.07770289227898632, 0.10000614835215466, 0.05951239301690033, 0.028354159955467497, 0.010829684374454831, 0.029730150941759348, 0.015604799081172262, 0.12431750845696245, 0.10242047772875854, 0.3989010208419391, 0.5119732362883431, 0.30811441955821856, 1.4117924209151949, 1.9224935940333774, 2.338948424373354, 3.9783509118216376, 5.704629983220782, 4.842968676771436, 6.770319930144718, 5.849414374147143, 6.368500394480569, 4.759175138814109, 7.675635031291416, 10.979319334030151, 11.66200155871255, 13.567587579999651, 22.568937165396555, 25.613101039613994, 21.332797050476074, 17.964470182146343, 15.811077526637487, 11.761084607669286, 10.060026628630501, 11.183276755469185, 8.723150662013463, 11.102639436721802, 9.394229395048958, 7.397919876234872, 4.250108855111258, 0.4027767043028559, 0.06053244149578469, 0.11635150733803, 0.18998411909810134, 0.08106301126203366, 0.07841135747730732, 0.012871760109971677, 0.03770156337746552, 0.012804116953962615, 0.12571978249720164, 0.04269848185192261, 0.028556217505995716, 0.02066510120805885, 0.023240165352555256, 0.0053954250595000175, 0.033307635225355625, 0.07593327973570142, 0.009620059148541518, 0.035173399573458095, 0.07441547832318715, 0.03799408321667995, 0.06332775471465928, 0.032518658454396894, 0.050685246142425706, 0.031361020037106106, 0.03620723927659648, 0.04266079601698688, 0.05251799297652074, 0.03238654429359095, 0.03543364489451051, 0.015567511885559984, 0.017565505745421563, 0.007088795711752027, 0.05698509434504168, 0.015154474049008318, 0.03099686386329787, 0.032547920277076106, 0.024306914004098092, 0.01160370877810887, 0.06609672720410995, 0.008559262945449777, 0.06238346467060702, 0.044436796967472346, 0.02685475193097123, 0.016070285978327905, 0.08425963044698749, 0.08392053257141795, 0.019070438741307174, 0.026403397221916487, 0.01005240045820496, 0.04945285691480551, 0.039815332274883986, 0.01972612918221525, 0.0541649772785604, 0.02465752831527165, 0.05616558349824377, 0.05812683129417045, 0.07558965603155748, 0.040415194550795216, 0.04207779194361397, 0.08045445355985846, 0.050647699407168796, 0.09406001027673483, 0.10075526458344289, 0.10752418065177542, 0.0709419014996716, 0.08355046635759728, 0.03184255937646542, 0.09088602702000312, 0.04456942342221737, 0.11518772478614535, 0.26391548982688356, 0.16014791652560234, 0.18073898447411402, 0.1185405563030924, 0.11090726804520402, 0.14218508611832345, 0.22083801563296998, 0.17263709993234702, 0.10782759437071425, 0.18439172846930368, 0.1748615141425814, 0.20150934851595334, 0.15061143253530773, 0.23830079287290573, 0.11208787148020097, 0.10384745722902672, 0.13957620039582253, 0.27652687739048687, 0.14503672452909605, 0.14519626168268068, 0.14977308894906724, 0.16624743065663747, 0.08852516620286874, 0.11823076435497828, 0.17254376065518173, 0.2572923095098564, 0.13985748030245304, 0.0801006043329835, 0.21504988122199262, 0.11607158450143677, 0.3162345566919872, 0.19841638234044823, 0.11452483678502695, 0.11555619644267218, 0.250037358807666, 0.15431456454098225, 0.1342320314475468, 0.1145373625414712, 0.12267320097557136, 0.14911972757961067, 0.14364799404782908, 0.25465427392295426, 0.13336582721344062, 0.10363337943064314, 0.15909188533467905, 0.238783204129764, 0.1532988247594663, 0.11767513916960784, 0.16357774819646562, 0.1452616181756769, 0.1552140712738037, 0.08774464058556727, 0.14701544120907784, 0.09115976161722626, 0.19389206011380467, 0.13136044410722597, 0.12717914847390993, 0.22263177723756858, 0.10283386161816971, 0.22576837321477278, 0.07315681621964489, 0.21073095154549393, 0.1451306744877781, 0.10450565655316625, 0.2556154323475701, 0.12186753563582897, 0.15764416301889078, 0.26581479076828274, 0.11920974110918385, 0.1420903762004205, 0.16128900886646338, 0.1350678237421172, 0.10818041900971107, 0.1627579421869346, 0.13136109550084385, 0.15413138722734793, 0.12111339824540274, 0.13403099509222166, 0.4105714703244822, 0.5350569433399609, 0.8688987780894551, 1.5856668565954481, 1.7928805947303772, 1.605833894440106, 2.501809856721333, 2.2486259681837897, 2.311374932527542, 1.6131036643471037, 3.021699045385633, 4.708137580326625, 5.808292329311371, 8.010001455034528, 15.118250063487462, 18.18879451070513, 13.22227166380201, 10.994064279964991, 8.352424315043859, 5.742477689470563, 4.379940722669874, 4.68688564641135, 3.506173917225429, 4.2845141632216315, 3.9839450802121843, 3.1404426736491065, 1.7069034768002374, 0.12676484856222356, 0.07849709716226373, 0.25017767984952244, 0.2646294986563069, 0.15925725788942405, 0.21696516844843114, 0.16853456864399569, 0.15968583417790277, 0.1996199677565268, 0.16681313887238503, 0.1012462457375867, 0.06936755097870316, 0.10198677171553884, 0.13069645687937737, 0.16812732549650328, 0.1915647392826421, 0.1653034527386938, 0.1784888266452721, 0.12320496886968613, 0.1690703806068216, 0.20703797042369843, 0.16983408534101077, 0.1304197231573718, 0.17014306304710253, 0.1864638522799526, 0.1135754238015839, 0.08998004027775355, 0.10163106330271278, 0.0617098015333925, 0.1065887115629656, 0.11264315739806209, 0.08581337385943957, 0.15747309076998914, 0.13136391820652144, 0.14042457272963865, 0.1590724792331457, 0.08548891198422227, 0.18650280019002302, 0.04691062368718641, 0.2921957980309214, 0.1151754433023078, 0.26158132936273304, 0.10840396237160478, 0.1584430837205478, 0.11798810666160923, 0.1795582521174635, 0.19777463749051094, 0.10025373899510928, 0.13882086878376348, 0.12389149703085423, 0.13707315256553038, 0.10059864513043847, 0.22272346088928835, 0.17235006604875835, 0.0798281521669456, 0.16143409322415078, 0.10382900786186967, 0.18686539573328836, 0.1415691255990948, 0.17645099599446568, 0.15847177218113626, 0.14405373084758008, 0.18782230652868748, 0.2226783111691475, 0.1616232416459492, 0.13244223248745712, 0.3296716942318848, 0.16800938253956182, 0.11477419840438025, 0.10150354621665818], [0.04948990831949881, 0.05305894823478801, 0.06174199123467718, 0.06015238046113934, 0.0422149815463594, 0.03277995550472822, 0.07591163446860653, 0.06722597232354538, 0.04400668379717639, 0.03873683478949325, 0.01779919320584408, 0.015760487244863595, 0.027744806670982922, 0.02283566857555083, 0.05936798040888139, 0.040082155992942195, 0.019696752008582865, 0.037651328037359884, 0.022726894323048846, 0.01896182224819703, 0.08118716959974595, 0.05179876282012888, 0.028232381579333117, 0.050479239518088956, 0.027333622931369712, 0.028592013620904515, 0.03533451771363616, 0.016055420972406864, 0.0670574310102633, 0.04529044491105846, 0.04836123316947903, 0.09840196264641625, 0.023620776000565717, 0.0535167558118701, 0.03114163948755179, 0.04000084035630737, 0.01444870772372399, 0.051787641631173234, 0.0468084159573274, 0.038114173736955435, 0.036411953291722705, 0.06874141243419477, 0.034495454880275896, 0.04689439312954034, 0.03447558737492987, 0.05421061893658979, 0.0066519463850584415, 0.046627566018807035, 0.012425793817133775, 0.05883780028671026, 0.02936176410210984, 0.037364677526056767, 0.024388090541054095, 0.0490979763147022, 0.036308032260941606, 0.06750539982957499, 0.11308723821171693, 0.02611822591695402, 0.06694009194948844, 0.06310399422155959, 0.0204445841123483, 0.04832536241571818, 0.060258740825312476, 0.04452449083328247, 0.015496643991874797, 0.03510922033871923, 0.10101449888731752, 0.04746045757617269, 0.04178694808589561, 0.04274375031569174, 0.03494705046926226, 0.025466543921668614, 0.0363738026602992, 0.01921287172340921, 0.004878279595037124, 0.07914255359875304, 0.008988262470146375, 0.0678522465750575, 0.053318430203944445, 0.044178709387779236, 0.08679572293268782, 0.049544435393597396, 0.06028979058776583, 0.07159209411059107, 0.047025160398334265, 0.06640983718846526, 0.013820440275594592, 0.017739458375477364, 0.033650302195123265, 0.08335209664489542, 0.17162791479911121, 0.0504948797502688, 0.22024458247636045, 0.4316123527075563, 0.27727896560515675, 0.24940197861620358, 0.1673768793365785, 0.16848422134561197, 0.11343784404120275, 0.0985749415787203, 0.013361885461823216, 0.05927844771317073, 0.09805307351052761, 0.10207862500101328, 0.046067258941807916, 0.050466832505272965, 0.07129465828516654, 0.002167498480827947, 0.06648308504372835, 0.0518893709938441, 0.0274421936233661, 0.03954238138560738, 0.011592469693693732, 0.06191817285226924, 0.01808493278388466, 0.10463446285575628, 0.022662518313154578, 0.09921322590006248, 0.00494348765849801, 0.05779886817825692, 0.015194431279918976, 0.023519201004611592, 0.013393317748393332, 0.0245835035374122, 0.025456498210717524, 0.008066338636646313, 0.025134865826527988, 0.035999807728720565, 0.03521065114598189, 0.029319891706109047, 0.09538229182362556, 0.06467887399984257, 0.00826639705337584, 0.01223927132585751, 0.01900408140915845, 0.039070226185555966, 0.033332384790160825, 0.012260313544954573, 0.03883917822635599, 0.027440088468470743, 0.027495587543983544, 0.044208734562354426, 0.005163471256050148, 0.08812630296285663, 0.03161361826849835, 0.05425355323989477, 0.03840125851067049, 0.07047654182783195, 0.01742449768685869, 0.04400305024215153, 0.05539225713749017, 0.04458253950412784, 0.057728856935032775, 0.017913119235475148, 0.0654986257265721, 0.05964828322508505, 0.03572794249547379, 0.03280701208859682, 0.048892403952777386, 0.016160520957782865, 0.03489634015464357, 0.022999302384310534, 0.019024630842198218, 0.03384063466052924, 0.020598911813327243, 0.024886990198865533, 0.01989841940147536, 0.03664290625602007, 0.031731093036276956, 0.06800032327217714, 0.05279662998925362, 0.02982665897746171, 0.012420844752341509, 0.01048296146161322, 0.02767101938038, 0.05965064452694995, 0.02628509633775268, 0.08836540513272796, 0.03639379230194858, 0.05518738366663456, 0.03553983223225389, 0.042306207186941586, 0.05141646261992199, 0.06234531064650842, 0.007738742777811629, 0.011767675069027712, 0.03687215270474553, 0.03274495327579124, 0.03181494978655662, 0.005247877195610532, 0.08085333715592112, 0.03364305883379919, 0.020951295404561927, 0.044058398343622684, 0.039432105874376636, 0.018383508548140526, 0.031119766911225658, 0.06909098010510206, 0.019996669575838105, 0.01613441601927791, 0.06314127972083432, 0.02214715739579073, 0.025643982525382723, 0.02941431663930416, 0.03272347764245101, 0.040616990865341256, 0.011056598359053689, 0.04944635654932686, 0.011092115426436067, 0.03890283838180559, 0.05172370666904109, 0.02794531376899353, 0.020970433484762907, 0.030493597832641432, 0.029440626834652255, 0.03213237864630563, 0.04004151174532516, 0.023563027581466094, 0.05267463957092591, 0.11532744871718542, 0.08825375219540936, 0.04983723343216947, 0.017847068940422366, 0.056307061442307065, 0.023946393081652265, 0.04062965911413942, 0.06068795493670872, 0.06132615783384868, 0.030984731657164435, 0.06482070817479066, 0.03616519385416593, 0.006773265901886458, 0.0302790450597448, 0.050481461720275025, 0.019258515077776144, 0.02891317442325609, 0.045847047186855755, 0.04952637957675116, 0.09275580490274088, 0.033328639276857884, 0.040885256470314095, 0.03458972714309182, 0.185541926750115, 0.08880264631339482, 0.03154686399336372, 0.058511750639549324, 0.06998493642147098, 0.06010702718049288, 0.05816386573548828, 0.01853305596991309, 0.012253684257822377, 0.020139124610328248, 0.04575253065143313, 0.07422439607658557, 0.06765280477702618, 0.06358627655676433, 0.1228757436786379, 0.11648099896098886, 0.03448242700791784, 0.027048117447910563, 0.06287916164313044, 0.024254441194768463, 0.07701614020126206, 0.07418861692505223, 0.13236831288252557, 0.10339919663965702, 0.18216975698513643, 0.0908613351306745, 0.09486285969614983, 0.25074998342565125, 0.2610717767051288, 0.14055764701749596, 0.09292258881032467, 0.07674288736390215, 0.1609259926314865, 0.08615597297570535, 0.050591682948704274, 0.07280699749078069, 0.06429617346397468, 0.11658047219472271, 0.10738040586667401, 0.028372058012921895, 0.05807658577603953, 0.019353696577517048, 0.02673162835916238, 0.055723199022135565, 0.05896732583642006, 0.05191425626565303, 0.11472077055701188, 0.09313591343483754, 0.0584989602544478, 0.058830268548003266, 0.04123428470588156, 0.0504867983981967, 0.009227279823140373, 0.048398128511118035, 0.0704975492720093, 0.019212050696036646, 0.004344919264050466, 0.01783395794752453, 0.08411426788994245, 0.011959933725717877, 0.05285546236804553, 0.04491003782355359, 0.061507394537329674, 0.03884196700528264, 0.05988291384918349, 0.030229545930134397, 0.03354105805712087, 0.046383544470050504, 0.020440458619434918, 0.022983830089547803, 0.02635411183083696, 0.030331505994711603, 0.04842775335003223, 0.07412112983209745, 0.017180577918354954, 0.02091654932259449, 0.09655317863715546, 0.027283097517543604, 0.0515004957893065, 0.12446606691394534, 0.029320916293987205, 0.007547824227783296, 0.07114975034658398, 0.04557209122659905, 0.03510241802515728, 0.012449294029335891, 0.04359029060495751, 0.013976658544769245, 0.020654902826728563, 0.029173993106399263, 0.05942955067647355, 0.017937159731185863, 0.005028249828943184, 0.02950462625761117, 0.03269346943125129, 0.020562041916751435, 0.01735426252707839, 0.01744479436560401, 0.034599206277302334, 0.027577832773593918, 0.016274294317034737, 0.06985679508319922, 0.02904557017609477, 0.0279731404901083, 0.0528264108912221, 0.010793984102617418, 0.042462382199508805, 0.024202987884304354, 0.015298449001940233, 0.05702903627284935, 0.11130349178399358, 0.11067590117454529, 0.11967197273458753, 0.11394295229443482, 0.15723985114267894, 0.1545063049665519, 0.15550795836108072, 0.14477319509855338, 0.14438238606921264, 0.15730043074914388, 0.07738189093236413, 0.11834653599986009, 0.07737554662993976, 0.08247252527092185, 0.1639701042856489, 0.1689721830189228, 0.06133034439491374, 0.167379335633346, 0.10361281303422791, 0.10861981793173722, 0.11130645019667489, 0.29760749478425297, 0.0783971082419157, 0.19006468834621565, 0.12998377797859056, 0.11465708326016154, 0.10520935165030615, 0.11801116328154292, 0.12186104884105069, 0.1732749907033784, 0.08383983440165009, 0.12687527335115842, 0.10516082282577242, 0.0861972618315901, 0.1501399049801486, 0.13337063124137266, 0.1053492452151009, 0.1622745402689491, 0.20698861378644193, 0.10598457112376179, 0.11357596662959882, 0.16242482220487936, 0.19054354407957622, 0.143929070393954, 0.13173712603747845, 0.12950408086180687, 0.09904872865549155, 0.13904808302010807, 0.17752817033657006, 0.12772730977407523, 0.18632686963038786, 0.2189568994300706, 0.06835886117603097, 0.1114484200786267, 0.10556604393890925, 0.12548015107001576, 0.23242891366992677, 0.16769342949347837, 0.11099997628480196, 0.11212672439536878, 0.1941161666597639, 0.13253098486789636, 0.17234294143106255, 0.1590216298188482, 0.10818534517394644, 0.16385996448142187, 0.25732648053339546, 0.11402874626219273, 0.1353107935615948, 0.13935989700257778, 0.15981650645179407, 0.11143494437315635, 0.13304160961083003, 0.1825631580182484, 0.06930444722196885, 0.12981360139591352, 0.08075862723801817, 0.12949390283652715, 0.13556213650320256, 0.07730452436953783, 0.22178200712161406, 0.28212859109044075, 0.1388712567942483, 0.21841905186218874, 0.13937979164932454, 0.1278717698795455, 0.11391815862485341, 0.1096489859212722, 0.13079126179218292, 0.20699014727558407, 0.25453200191259384, 0.1595953990306173, 0.21761857052998884, 0.4738817459770611, 0.45143417907612665, 0.38317526610834257, 0.14880336741251604, 0.2967980025070054, 0.19864279590547085, 0.11410874554089137, 0.12294568706836019, 0.21618250544582093, 0.17663581536284514, 0.2888390581522669, 0.15160571703953402, 0.13404707637216362, 0.1749336424150637, 0.08808282922421183, 0.16346640059990541, 0.12767931020685605, 0.13813839826200688, 0.22681436208742006, 0.14587801295731748, 0.291106070790972, 0.12379678711295128, 0.206327707107578, 0.12219157681933471, 0.10576801667256014, 0.16201331785746984, 0.1659248958208731, 0.12574368050055845, 0.10766264929303102, 0.1446258851460048, 0.10096994627799306, 0.1881884711661509, 0.09864552957671029, 0.1868221459111997, 0.18867974409035274, 0.1356963235884905, 0.12381723815841333, 0.21928962586181505, 0.15929617865809373, 0.13109657540917397, 0.20473989445183957, 0.14879252442291804, 0.216679790190288, 0.14627799578011036, 0.09590890963694879, 0.1353133584239653, 0.13399539914514336, 0.11933275950806481, 0.08039844727941922, 0.16904475912451744, 0.12237550052148954, 0.14065739166523727, 0.20434330430413994, 0.13490949438086577, 0.10490901848035199, 0.1374831369944981, 0.12901250938219683, 0.1202562999512468, 0.11889340808348996, 0.16090562301022665, 0.07049386482685804, 0.16692587068038328, 0.10813773915703807, 0.13604779115745, 0.10107247970466103, 0.09969344548881054, 0.1483200876308339, 0.15581627110285418, 0.12095861083694867, 0.0876226332038641, 0.07651420070656709, 0.07178760719086442, 0.1391293579446418, 0.08751235090728317, 0.15201856488628046, 0.10013756701456648, 0.14849367045930453, 0.1566503263477768, 0.11117617147309439, 0.11059663471366678, 0.1226142905652523, 0.12616437221212046, 0.2692801776741232], [0.007006807477279965, 0.06755416614136525, 0.0927806935672249, 0.012395010379675244, 0.00787768978625536, 0.026630499499983022, 0.045344585220196416, 0.04758946404659322, 0.021718972961285284, 0.008371977950446308, 0.008296745380253663, 0.021464658036295856, 0.02281985022792859, 0.02513199731973665, 0.06000749287860734, 0.04348594888246485, 0.0525506949717445, 0.0378285885256316, 0.017671967889847498, 0.1288973212774311, 0.02935717042003359, 0.046247749256768396, 0.026157748885452747, 0.04197753839460867, 0.05908871575125626, 0.030858955013432672, 0.006397080150366361, 0.03636865597218275, 0.026985914446413517, 0.07256256882101297, 0.061172795348933766, 0.05116150987201503, 0.07769761327654123, 0.049939895780490975, 0.058927841883684905, 0.04776185265343104, 0.029712695628404617, 0.051039549987763166, 0.02544627777699913, 0.008310492499731481, 0.03358895245141216, 0.06463392105485712, 0.02072073768691293, 0.018365339076678668, 0.0544885367022029, 0.023468667109097754, 0.03783878351428679, 0.05400661399055805, 0.057336012300636084, 0.084136774896511, 0.023983598853062307, 0.059039528747754436, 0.01942927180789411, 0.053272408566304615, 0.03321801092741745, 0.03763160980971796, 0.04530722168939454, 0.035299111756363084, 0.07557495217770338, 0.03456111332135541, 0.049890542535909584, 0.0629419804151569, 0.033185492136648724, 0.017087918872545873, 0.05903772384460483, 0.041371240214045556, 0.031020578662199632, 0.006499400686672223, 0.010011846964646662, 0.11045926529914141, 0.04426957540480154, 0.07507239521614142, 0.01685220598509269, 0.015532365467931544, 0.028463777287730148, 0.05189316739727344, 0.03368991167683687, 0.016128499193915298, 0.04553806269541383, 0.013863321144266852, 0.021650028714377965, 0.03755765288536038, 0.01195026544987091, 0.04335544963500329, 0.047287889157554934, 0.03040629412446703, 0.027800103882327676, 0.07325631659477949, 0.041322263556399515, 0.038349554142249484, 0.034068842950676165, 0.07254726107099227, 0.036976100876927376, 0.052360528747418096, 0.16935341113380023, 0.07869441514568669, 0.08886011144412415, 0.08572624317769494, 0.011437449886995767, 0.03576761304533907, 0.0958922380315406, 0.020522780184234892, 0.008803942673174399, 0.012748294726147183, 0.07010701165667602, 0.06979101111314126, 0.10097126942127943, 0.06679956056177616, 0.04736667725124529, 0.01785480763231005, 0.05996065360627004, 0.03463756386190653, 0.04066893272101879, 0.030364062104906355, 0.05228327753554497, 0.05754179161574159, 0.018338872818276286, 0.015724770857819488, 0.09282831315483366, 0.06517036405525037, 0.08531904752765383, 0.05782846587577036, 0.06817100197076797, 0.07684622824724231, 0.012249690231068857, 0.02313850723606135, 0.02109512107978974, 0.042543083761951754, 0.09530616019453321, 0.025834004561017667, 0.014181595628282853, 0.02588639424980751, 0.03931473967220102, 0.05977941690278905, 0.029763375408947468, 0.033995527241911204, 0.05038083836968456, 0.07897325911160026, 0.0915744211524725, 0.0302009287157229, 0.0207527306130422, 0.0446617313261543, 0.03337624529376626, 0.04272774028192673, 0.031489093521875997, 0.06924526539764234, 0.035106200857886245, 0.018427820277533362, 0.04480853916278907, 0.01733460197491305, 0.06657539294766528, 0.011443309036881795, 0.005376992655718433, 0.06411271116563252, 0.03313445273254599, 0.01888990092889539, 0.005263457207807473, 0.052343019151261876, 0.04082002889897142, 0.05074459760050688, 0.030459969637117217, 0.10671282918857676, 0.02286409240748201, 0.015904662365626012, 0.02828611816013498, 0.03101374242188675, 0.023052543634548783, 0.035497376296137056, 0.0518892692135913, 0.004644223605282605, 0.04732879803382924, 0.02610717767051288, 0.027560007658654025, 0.013849718213480498, 0.029850757148649012, 0.027059481213135377, 0.03511645691469312, 0.02007735417490559, 0.074125078905906, 0.0433946044982544, 0.09784125523375613, 0.03829488796847207, 0.07058046625128814, 0.06946084275841713, 0.07196554621415478, 0.02284428257761257, 0.01822422754152545, 0.00536581251903304, 0.05612364324874111, 0.025402829483417527, 0.06444121032421078, 0.04109669816015022, 0.05040712820898209, 0.041471347878021855, 0.022956308709191423, 0.047515147498675754, 0.03045487044645207, 0.06529549269803933, 0.04604000219010881, 0.02073469345590898, 0.07248780783265829, 0.10355364478060178, 0.05124705956716623, 0.07033130140709025, 0.05384932278788515, 0.03356301545032433, 0.05306690405788166, 0.011691578214855065, 0.036760554050228426, 0.019426357499989014, 0.03303021279030612, 0.05855545508010047, 0.011125467118940182, 0.025150906394368837, 0.052379554869341, 0.012581107938396079, 0.011421029339544475, 0.04482437617012432, 0.03806068142876029, 0.048526422519768984, 0.04337327474994319, 0.03654302250859993, 0.034632766619324684, 0.03315556874232633, 0.05680531309917569, 0.08715084780539785, 0.028091146211538996, 0.030654274925057377, 0.03860301072044032, 0.04165145821337189, 0.04839050517018352, 0.009408882935531437, 0.05287378281354904, 0.021391859710482613, 0.023816105876384035, 0.046095112804323435, 0.060662883067769666, 0.016067470058000514, 0.06727783275502068, 0.039618713182530234, 0.05074156454897352, 0.06707072351127863, 0.04816189654437559, 0.018861210771969388, 0.04437123012862035, 0.08649773070854799, 0.013012176994899554, 0.03156863139676196, 0.019168124035266892, 0.016784389802653874, 0.01263797256563391, 0.06334847717412881, 0.018247321480885148, 0.0450221894841109, 0.023748089526114718, 0.06314270464437348, 0.04364373880837645, 0.028005386170532023, 0.04025045642629266, 0.02726466511376202, 0.09220264279948813, 0.03645818527521832, 0.031890613226486106, 0.0832624960956829, 0.023028822050296834, 0.017185923077964356, 0.03145484107413462, 0.011110259452834725, 0.044964106886514595, 0.04756808340815561, 0.061820314531879764, 0.07431394912834678, 0.10252916546804564, 0.021209516994921223, 0.05289345693641475, 0.0056456967639470735, 0.05420188619089978, 0.02298032715251403, 0.07891296448984317, 0.11952103940503937, 0.07967117309038128, 0.03252094511740974, 0.0699566618672439, 0.04659183436472501, 0.03709598783669727, 0.02876260071726782, 0.021330209715025764, 0.011861465571980392, 0.04676475901422756, 0.03362113536734666, 0.015203913806804588, 0.0153951572054731, 0.04756138626752155, 0.04986880566658718, 0.020739504269191196, 0.05612353468313813, 0.008407127760749842, 0.02483183378353715, 0.023319094242261987, 0.02171209770520883, 0.03349080575363977, 0.01276043541396835, 0.040148068884653706, 0.0313598665275744, 0.07241960827793394, 0.05264560505747795, 0.042708741301404576, 0.05130428721063903, 0.05173700934808169, 0.05743928533047438, 0.03228113727111902, 0.04776060075632163, 0.049062326084822416, 0.07069849063243185, 0.02263957874051162, 0.03797000200886812, 0.029760495027793304, 0.040713515864419084, 0.015105653454416564, 0.03950209676155022, 0.020042429977495755, 0.004469269711989909, 0.04852183223036783, 0.10406515840440989, 0.02719591255299747, 0.004705833736807108, 0.033803400051380904, 0.029541575882051672, 0.055673136708459685, 0.015213966303105866, 0.025312830294881548, 0.004815685587735581, 0.039111623607043705, 0.06714303498821599, 0.019000059392835413, 0.04409969737753272, 0.02128802010390375, 0.04951204552448221, 0.04148779895954898, 0.03338809251519186, 0.03920660833162921, 0.10540291054972581, 0.02956569780196462, 0.04328013224793332, 0.01884066473160471, 0.0349418087862432, 0.018740679203931774, 0.0684939439275435, 0.08567262534052134, 0.03972581993522389, 0.02261422188686473, 0.08415385362293039, 0.0970242176471012, 0.1862471146242959, 0.16676663208220685, 0.09749769259776388, 0.11754955590835639, 0.163656173273921, 0.2254830492394311, 0.14866007438727788, 0.10690771123128277, 0.1607970574072429, 0.10105233399995736, 0.07705706943358694, 0.11044471750834159, 0.11041419700320278, 0.19471098402781145, 0.09512514062225819, 0.11765155329235963, 0.1018071092133011, 0.0817422926692026, 0.2404368482530117, 0.11396013280110699, 0.12373719816761357, 0.09015760610678367, 0.17739634455314704, 0.12293731394623007, 0.10604025849274226, 0.16428474097379617, 0.17342367129666464, 0.12592484935053758, 0.11296953952738217, 0.16394297645560332, 0.06860388695661511, 0.16196686535009316, 0.13735401178044931, 0.15666775112705572, 0.12071207192327295, 0.0760091467361365, 0.10593309745724712, 0.19989705431674207, 0.08673485155616488, 0.07964426917689187, 0.07891711712415729, 0.11433111503720284, 0.16848439776471683, 0.19667675425963743, 0.15958147549203464, 0.14874840607600553, 0.12890361808240414, 0.16382811404764652, 0.21847968575145515, 0.1521870179900101, 0.14798430779150554, 0.07928012657378401, 0.24702536900128635, 0.13256959351045744, 0.08444910456559487, 0.1493656558117696, 0.11059648543596268, 0.10940476759736027, 0.10090824030339718, 0.1340371969022921, 0.10486559902450868, 0.11677774946604456, 0.14069723524153233, 0.176155046160732, 0.18980825639196805, 0.11083380305873496, 0.066775540422116, 0.13899522514215537, 0.1953754462301731, 0.1567379523600851, 0.14145419533763612, 0.0661022165524108, 0.09321847079055649, 0.24673615023493767, 0.15022416545876435, 0.1406734050916774, 0.16871382402522223, 0.1370857326047761, 0.09276741463690996, 0.2320140302181244, 0.13577421940863132, 0.13980919575052603, 0.17174066017780984, 0.1652660383177655, 0.14150323984878405, 0.08427580672183207, 0.16188256415937627, 0.1581047661602497, 0.16113580922995294, 0.07507080744419779, 0.2042963903929506, 0.09408145198332411, 0.14597426993506296, 0.36342387167470797, 0.20712607141051972, 0.1996894497424364, 0.2904324212244579, 0.1940128800592252, 0.11979100134755884, 0.1945601049810648, 0.07746758311986923, 0.1501115829284702, 0.17109379917383194, 0.1766187705631767, 0.18294081703892776, 0.19115114504737513, 0.12047085272414343, 0.06878017713981015, 0.1337710211851767, 0.21572908120495932, 0.09521431369440896, 0.17568942186023506, 0.095186480187944, 0.08772714795278651, 0.16949092304067953, 0.15865285960691317, 0.14381173811852932, 0.13393236324191093, 0.11166868611638035, 0.17964935222906725, 0.18859594501554966, 0.15630591554301126, 0.18214991662119115, 0.1121061240722026, 0.15274587300206932, 0.09142924179988247, 0.18942811393312045, 0.21297573537698813, 0.09499833599797317, 0.1696239701871361, 0.12228814592318875, 0.17450486256607942, 0.16448737867176533, 0.14562474297625677, 0.1333823020436934, 0.1637644674628973, 0.20128334207194193, 0.1687890464173896, 0.10233779145138604, 0.1450187297804015, 0.1417211310139724, 0.19628561953348772, 0.22606549012873853, 0.1170839723199606, 0.11006472432719809, 0.13723213332039969, 0.18934465412582668, 0.10768261857862983, 0.10189009404608182, 0.14297381522400038, 0.09639836408730064, 0.11444516320313726, 0.19087495415338449, 0.12090198030429226, 0.12274693059069769, 0.08050067536532879, 0.15905311384371348, 0.08019363826939038, 0.19310001975723676, 0.09956598268555743, 0.2834123522043228, 0.11950820152248655, 0.13218756472425802, 0.16320907297943318, 0.15318906493484974, 0.13644740757133278, 0.16090727863567217, 0.09919175026672226, 0.09615882086966719, 0.17120224264051231, 0.1464898344129324, 0.09719304394509111, 0.1336432123290641, 0.11799893608050686, 0.26474436106426374], [0.010992705805360206, 0.0476423388879214, 0.04591283794226391, 0.027333656858120645, 0.04707970104313322, 0.03164932617385473, 0.06628873904368707, 0.02545640491215246, 0.04308861234624471, 0.026676468551158905, 0.034620325679757764, 0.011358042630100889, 0.014990460260638168, 0.04619328664349658, 0.025639768822916915, 0.0257583309430629, 0.04083468186269913, 0.017176737410149405, 0.035171112910445244, 0.026286275292347585, 0.04134766112214752, 0.05167840427852102, 0.031357854671244106, 0.05566930298560432, 0.0672617582604289, 0.04138971332992826, 0.00478532920325441, 0.027334555917020355, 0.0628036203395043, 0.04198991148067372, 0.05444493404190455, 0.02775822639731424, 0.019060857826843858, 0.01845537728097822, 0.019838450476527214, 0.020710478237430965, 0.023182905478669063, 0.04240707141746368, 0.020531543464000736, 0.01524700756583895, 0.030494544388992444, 0.014042829279787838, 0.02208100532048515, 0.03028901613184384, 0.02432025739523981, 0.026077094820461104, 0.04919566839401211, 0.01034739101305604, 0.04554508553285684, 0.03515141164617879, 0.06464702356606722, 0.008240296355714756, 0.023570031759196093, 0.0270529689732939, 0.03403277202908482, 0.042949244646089416, 0.055313913484237025, 0.03874678211286664, 0.02489631327002176, 0.012546340652209307, 0.038589368773890395, 0.01700458120155547, 0.03953064612245985, 0.08215893352670328, 0.031372073372559886, 0.025182400597259402, 0.03849183615030987, 0.07998626439699105, 0.04706843396914857, 0.07982064078428916, 0.058774669388575215, 0.0437255938803511, 0.03414219258619206, 0.03137084183150104, 0.02880674959825618, 0.017156159139371345, 0.052405776855136664, 0.021648949843698313, 0.06875383641038622, 0.037458451065633974, 0.030947731142597537, 0.0403652475880725, 0.14248210803738662, 0.019400313629635742, 0.07816727486039911, 0.03770712736461844, 0.014720382967165537, 0.010820592853373714, 0.04954796038301928, 0.02951249047847731, 0.07237700984946319, 0.050322969510619125, 0.05966650189033576, 0.04168650454708508, 0.08106305197413478, 0.12172262769724641, 0.03588012432945626, 0.051899644014026435, 0.004455595535026597, 0.07725342389728342, 0.008668786979147365, 0.01103521347977221, 0.04346877855381795, 0.057939725262778144, 0.08594153555376188, 0.11569312480943543, 0.06255659966596536, 0.021572485732446824, 0.03242271360276001, 0.006651610510224211, 0.03458923859787839, 0.08072463263358388, 0.027446848373594027, 0.020383303918476616, 0.03566310168909175, 0.037455034641815085, 0.029372451028653553, 0.03495741169899702, 0.02724535231079374, 0.058932130225002766, 0.049671782845897336, 0.02650065503881446, 0.04103271570056677, 0.02092050518175321, 0.05000592741583075, 0.04389851174450346, 0.054996908708874664, 0.047766429372131824, 0.03652105154469609, 0.031178782494472604, 0.02229515606138323, 0.05883279948362282, 0.04273546201043895, 0.04331000814480441, 0.02987170352467469, 0.019056075851299932, 0.00786573569556432, 0.020278012246957848, 0.01755414537287184, 0.0041187202857275096, 0.03592511120119265, 0.05330895446240902, 0.03457903003852282, 0.014023113596652235, 0.03010363018672381, 0.023949229358030216, 0.03835258719378284, 0.04503098329795258, 0.06274276931903192, 0.05443704607231276, 0.051808856028531275, 0.07310357157673154, 0.05133227678015828, 0.021871740031721335, 0.007689177491036909, 0.03932744524042521, 0.03048544523439237, 0.05079847667366266, 0.04551608155348471, 0.03992050520277449, 0.04073667087193046, 0.020979851550821747, 0.02102608183797981, 0.0392693185380527, 0.022813609402094568, 0.02496366635231035, 0.03914587605478508, 0.026521002607686178, 0.06953452487609216, 0.00807691106040563, 0.014872702204489281, 0.01375274283678404, 0.1066013662410634, 0.02251697424799204, 0.040316203076924594, 0.003372765815583989, 0.025829802732914686, 0.04679027871627893, 0.042794589551963975, 0.020791084804971303, 0.0505595916349973, 0.06559437380305358, 0.0313174954083349, 0.06672626520906176, 0.042037924618593285, 0.045017555089933534, 0.037403618650777, 0.011730735622612494, 0.0076931163868201625, 0.045584281108209064, 0.007153692921357495, 0.0982368682910289, 0.028596620873681138, 0.018338898263339485, 0.028174919841278876, 0.0181018316985241, 0.03143413897071566, 0.0344261221720704, 0.026476617935778837, 0.027536196168512106, 0.06892852525093726, 0.02230933235426034, 0.036080268411231894, 0.027112613897770643, 0.01925661857239902, 0.046319731644221714, 0.03585745786715831, 0.021237184260306612, 0.014953408855944872, 0.0017710534760096508, 0.02896944193967751, 0.021336174037839686, 0.05605134194982903, 0.0219680478995932, 0.0037104847807703273, 0.07421664042132241, 0.037489772242094786, 0.0028128987261360244, 0.006415292030266885, 0.06941981853118964, 0.026540542719885707, 0.11896846762725286, 0.03623279969074896, 0.0703012558764645, 0.06351289977984768, 0.014772097513611828, 0.028986137293811356, 0.053135076471205266, 0.007113569873451654, 0.038278094226760526, 0.031001074173088585, 0.03215966932475567, 0.06382342454578195, 0.049395391784076176, 0.05720460042357445, 0.06240846190069403, 0.027130143849977424, 0.033493906658674986, 0.06190715344356639, 0.08005704238478627, 0.06340216286480427, 0.03565425019977348, 0.030688629153051546, 0.01895123710190611, 0.019706371938809752, 0.06304528737174613, 0.016176495368459394, 0.028454109860051955, 0.08727204773042883, 0.019008622504770756, 0.037279948858278136, 0.05098724172317556, 0.1430610612566982, 0.0701085247897676, 0.06177809608301946, 0.05312550573476723, 0.06710688942777258, 0.08965080151600496, 0.03742547087105257, 0.09099112530904156, 0.07046221116823809, 0.08051741482423884, 0.03243046586534806, 0.054200793749519756, 0.12766776154083864, 0.08970354404300451, 0.03696024351354156, 0.07490396246846233, 0.061793193487184386, 0.0715827913954854, 0.06335569678672723, 0.06260096907083477, 0.04251871756943209, 0.1384045196963208, 0.012911366199010184, 0.03972181657861386, 0.053527412204337974, 0.02241815410421363, 0.09601357366357531, 0.06486407334783248, 0.0332182382366487, 0.02747857497472848, 0.04408978398091026, 0.057405087165534496, 0.043361166292535405, 0.043931539436536174, 0.010147332596326513, 0.026494497333520224, 0.024406054755672812, 0.04916141933894583, 0.017193816136568785, 0.0036876978785065667, 0.06253200277153935, 0.06319399510643312, 0.03985559993556567, 0.03977195692381688, 0.042804245105279345, 0.0285418664903513, 0.0031764989253133535, 0.03377230279147625, 0.03638664393552712, 0.013685849461970585, 0.006108918202309204, 0.011082548930841898, 0.028435816555949192, 0.033138218601899486, 0.015479334563549076, 0.008129360969178379, 0.04225199902430177, 0.028755031659134796, 0.04442802690235632, 0.05304899412606444, 0.05006060716030853, 0.08563044081841197, 0.027437900193035603, 0.023043527600488493, 0.007191882568544575, 0.02436585834116808, 0.04803238456536617, 0.034533395165843625, 0.015198726406587022, 0.015594210542206253, 0.02224362302305443, 0.02480518601701728, 0.054520091973245144, 0.005133374835297997, 0.06348953781915562, 0.048855549323239496, 0.04080245144931333, 0.023724769973861318, 0.03735934424081019, 0.059594468612756045, 0.02218892631520118, 0.04980214638635516, 0.08450525333838803, 0.03784310578235558, 0.023002399896670665, 0.04431103389444096, 0.018138006096705794, 0.01634452269146485, 0.010991260525770485, 0.019642542149605494, 0.027575937964554344, 0.04279998051268714, 0.05174405932692545, 0.006966467722252543, 0.011106286630300539, 0.031571701767721345, 0.01679825227308486, 0.030928827156977992, 0.01015807465384049, 0.016845990604321872, 0.13306390627154283, 0.13381147544298852, 0.18384328218443052, 0.09286447907132761, 0.19725804163941316, 0.12850177607366017, 0.12546450405248574, 0.19761524961463042, 0.09563302408371653, 0.11974027406956468, 0.07605142625314848, 0.11200897142823253, 0.07292244343885354, 0.158143781923822, 0.12395287730864116, 0.15364866384438106, 0.11219818770353283, 0.14590690497841152, 0.12958929128944874, 0.08833900333515235, 0.09367219358682632, 0.08123703513826643, 0.0992750675816621, 0.0994070019306881, 0.12994405653859886, 0.16931272617408208, 0.15856663137674332, 0.09839006792753935, 0.19215192991708005, 0.16256137059203216, 0.17219625573073113, 0.09373363493276493, 0.08733447973749467, 0.07894643662231308, 0.08263280881302697, 0.11999829379575593, 0.16836123008813175, 0.0922823299520782, 0.11733855865895748, 0.1524874054427658, 0.11854507534631661, 0.11431720506932054, 0.1020287119650415, 0.15605731388287886, 0.09254215458141905, 0.16114970562713488, 0.05138600318293486, 0.1287529290254627, 0.14233208394476346, 0.09463261919362204, 0.10242826731077262, 0.13251677634460585, 0.08691119602216141, 0.07282096852681466, 0.10880670683192355, 0.09874275685953242, 0.11097366269677877, 0.14635435811110906, 0.1213849208184651, 0.13206435633557184, 0.11903904883989266, 0.16040305926331452, 0.17681775774274552, 0.1842505931854248, 0.10671185209814991, 0.10472154604004962, 0.09792763952698026, 0.13012057063835009, 0.1465643918407815, 0.199936056509614, 0.13987227236585958, 0.12494885815041405, 0.13566922289984568, 0.09249384288809129, 0.07790951976286513, 0.09131016568945986, 0.17842074244150094, 0.14934235491922923, 0.29770539381674355, 0.13021693618169852, 0.1389090240533863, 0.16171016198183807, 0.15602615555482252, 0.13546936719545297, 0.20092017655926092, 0.2131786716303655, 0.06860632289733205, 0.11194283461996488, 0.17948288044759206, 0.14875029240335735, 0.17630312964320183, 0.16393996376012052, 0.2540133568857397, 0.27619439523134914, 0.22497201737548622, 0.2559676734464509, 0.24742575894509042, 0.2138126947517906, 0.16724512140665734, 0.17860322764941625, 0.12100837459521634, 0.06565890926867723, 0.15414752279009136, 0.17032180274171488, 0.16713643366737024, 0.23255463263818196, 0.1369477864354849, 0.11574145007346358, 0.12962604074605874, 0.09616460198802607, 0.11964739619621209, 0.15357038804462977, 0.2081030397010701, 0.16306478929306778, 0.09493359697184392, 0.1387726113732372, 0.114120375631111, 0.12484131034995828, 0.19652462670845644, 0.14701217067028793, 0.13661199302545615, 0.17713964118489198, 0.09509261165346418, 0.1814109105616808, 0.16005313875419752, 0.16681730507739953, 0.16683458057897432, 0.12301257705049855, 0.09478874331606285, 0.07985030633530446, 0.10254568101039954, 0.1694241687655449, 0.1353807369513171, 0.07894417031535081, 0.19444075067128452, 0.21327454862850054, 0.15389932825097016, 0.13986376353672572, 0.11950358748435974, 0.11412584462336131, 0.09532045014202595, 0.12251430164490427, 0.11799652049584047, 0.09050323827458279, 0.11100323325289146, 0.11363620696855442, 0.07829648149865014, 0.13955398515931197, 0.18347307347825595, 0.10753708638783012, 0.19999731465109757, 0.13215671852231026, 0.225669157824346, 0.10247564262577466, 0.13813127364431108, 0.1377419845334121, 0.12746232827859266, 0.22905743601066725, 0.14377205739063875, 0.11746594682335854, 0.10056420947824206, 0.09615831875375339, 0.06219386163034609, 0.14535858082984174, 0.08491511563105242, 0.08266351252262082, 0.15693353329386028, 0.12418804397540432, 0.1067958479481084, 0.10388428132448878, 0.08469775372317859, 0.10305364589606013, 0.15735782124102116, 0.14271123574248382, 0.08558506718171494, 0.10945723192500216], [0.06180818232574633, 0.0794508731258767, 0.016607066549892937, 0.05786748842469283, 0.05198705968047891, 0.029139231757393906, 0.018300245516002178, 0.035846927003668885, 0.047657137736678123, 0.019936761719041636, 0.06376529445073434, 0.04497770472828831, 0.07291103726519005, 0.025055458569633107, 0.024648610668789064, 0.0019946758236203876, 0.027595344066087688, 0.026436513123501624, 0.0281341432793332, 0.012262975946733994, 0.026735356909089854, 0.03899811487644911, 0.07763697260192462, 0.06827103838856731, 0.012738638324663043, 0.02381513557130737, 0.006532269347059939, 0.04704709065013698, 0.10382028190152985, 0.017279447255922214, 0.05365386738308838, 0.05180371951844011, 0.021073460545656935, 0.016484345010082637, 0.046632471826991866, 0.027599255820470195, 0.014624584000557661, 0.004614084352007402, 0.025534185381340127, 0.039128559841109176, 0.009416004160552152, 0.019063819632200257, 0.03296246785404427, 0.02455396351537534, 0.12479194014200143, 0.024056171565981846, 0.06834442873618432, 0.01759194316608565, 0.06641972344368696, 0.031359557794140916, 0.02985115409163492, 0.04590924509934016, 0.0753609286621213, 0.05463876096265657, 0.06065368213291679, 0.026816406220729862, 0.0027101543174857007, 0.036650268360972404, 0.019649298662053685, 0.028944237756409814, 0.06256590238107101, 0.021044254702116762, 0.005944464214345706, 0.04049528882439647, 0.02170220636097448, 0.0407911708046283, 0.021659397586647953, 0.01851036915156458, 0.028405194270557592, 0.05376138125679322, 0.020315462290974598, 0.03370497854692595, 0.03143755878720965, 0.07173029812318937, 0.011085583678712803, 0.04196960632024067, 0.04541393489177738, 0.0396136580966413, 0.023086970805057457, 0.02601393678092531, 0.039038046662296565, 0.01955837327321725, 0.01352476779304977, 0.01797092193737626, 0.029697781428694725, 0.06275129850421633, 0.026991056045517325, 0.025197967886924744, 0.008580399311280676, 0.027880997130913392, 0.03370622705136027, 0.04663002910092473, 0.06511638659451689, 0.10845720022916794, 0.02581844405670251, 0.0533462162129581, 0.0630707595763462, 0.05545717936807445, 0.040455411321350505, 0.015390602539160421, 0.041032149123826196, 0.03157003935692566, 0.028463689078177725, 0.055370482948741744, 0.01159117029913302, 0.016701881640723774, 0.02570065377014024, 0.03245486259194357, 0.037742587604693005, 0.03504836253289666, 0.09174448238419634, 0.0132613876402112, 0.00017706593955933516, 0.04108659816639764, 0.018010675607781326, 0.04378018880795155, 0.057900892703660896, 0.01766248536296189, 0.023102734869878207, 0.025629726504640918, 0.030335237937314168, 0.05450105906597205, 0.04110623496983733, 0.05610228975170425, 0.016507625546572462, 0.01564673424166228, 0.03501552822334426, 0.04007011538903628, 0.028109218991760696, 0.018863639927336147, 0.008198339991005403, 0.017403037320556383, 0.046343063070837937, 0.058398645637290816, 0.02969459570678217, 0.09475542046129704, 0.018138818642390624, 0.039094039372035434, 0.0680636034480163, 0.011487239938495415, 0.13136888508285793, 0.0060403649612063804, 0.049907926603087356, 0.02834513713605702, 0.03271147096529603, 0.03031846455165318, 0.048709202890417407, 0.023460302468655363, 0.027292115247941444, 0.04606177977153233, 0.028011830556871634, 0.04915377564196076, 0.013404479649450098, 0.05645321109997375, 0.03852442618725555, 0.04109712902988706, 0.008061476085068924, 0.027766151686332056, 0.019859205166410123, 0.0304756912934993, 0.028498755767941475, 0.0155252832586744, 0.03085526717560632, 0.06091495882719755, 0.06489566593830075, 0.03279842183526073, 0.031199416744389703, 0.04379183925422175, 0.005538582377734461, 0.022208391788548658, 0.011381256161257625, 0.007886023044453135, 0.018892623550657715, 0.02804072597064078, 0.06128656531551054, 0.005181382036036146, 0.0287120057536023, 0.04464013355651072, 0.03473763759913189, 0.04138064470940402, 0.009682764265952366, 0.03462093636127455, 0.04361369667042579, 0.04039372909548027, 0.027625739042248045, 0.028172587377152274, 0.01568836915040655, 0.05742572820080178, 0.019312261836603284, 0.012241916764261467, 0.036550896907491345, 0.03662873844483069, 0.07000497356057167, 0.0256996190042368, 0.022246891865506768, 0.045458602852055004, 0.023740411902378713, 0.02558604411647788, 0.06465852473463331, 0.07412370147981814, 0.024552847325269665, 0.008082550534579371, 0.025825724737452607, 0.07119443187756197, 0.06598169516239848, 0.00959457761408495, 0.02522497866967959, 0.028732697678995982, 0.03458044139136161, 0.030653725311692272, 0.12385729886591434, 0.036093082545059066, 0.04280473704316786, 0.00957102227091257, 0.038794435627226315, 0.019784505246207118, 0.03668866326500263, 0.019484111008101275, 0.038481610627578836, 0.05819910205900669, 0.08156136809183018, 0.07989500822233302, 0.022729031708357588, 0.027329017374930636, 0.02987023110368422, 0.029971058014780283, 0.05737170324261699, 0.03599374841100403, 0.07819938992283174, 0.02037309027010841, 0.06837794836610556, 0.024734559003263712, 0.03459853792030897, 0.07339912786015443, 0.07020269187965564, 0.04498190486005374, 0.060388904197939804, 0.022132373814071928, 0.04506279641230192, 0.08374849680278983, 0.017540026755471314, 0.06093639374843665, 0.02811801280560238, 0.08282857973660741, 0.041133257626954994, 0.06952216196805239, 0.039708490150847604, 0.034840384764330726, 0.03633316859070744, 0.017744901922664473, 0.020509212876537015, 0.06634969862976245, 0.011196161986195614, 0.06093740476561444, 0.013930678467399307, 0.04362661936985595, 0.06701492079134498, 0.03019528669704284, 0.023877168939049755, 0.0546938172940697, 0.0313047932327858, 0.03582072876659887, 0.039701029658317566, 0.023832663827176605, 0.029850590907569443, 0.036550198016422134, 0.0552946939798338, 0.043750472366809845, 0.08748174897794213, 0.07187091772045408, 0.008140689959483487, 0.003839350031090102, 0.009322977009495454, 0.03196786104568413, 0.14691594083394321, 0.04544338331158672, 0.06991607868777854, 0.037177992186376026, 0.009856754215434194, 0.05222764105669089, 0.09437504051519291, 0.02521786423000906, 0.003988208315734352, 0.044240629100905995, 0.0363035166103925, 0.05926980996238334, 0.03012980128239308, 0.02751767385884055, 0.04449099495208689, 0.04627619683742523, 0.04530475182192666, 0.06159753112920693, 0.048484991171530316, 0.06884829527033226, 0.028211077276085104, 0.033397055962788205, 0.02397702045605651, 0.025392217195725868, 0.06375754558082138, 0.04743471735024026, 0.00518075269480635, 0.05806382931768894, 0.04188091840062823, 0.012593604008933263, 0.019970340720777, 0.009184969772052552, 0.09310014785400458, 0.0031308771992501405, 0.06420401483774185, 0.04800024914688297, 0.009970512307648147, 0.02754570753313601, 0.05752243979700974, 0.018550970990742956, 0.06490401191903011, 0.03774960704946092, 0.03813442122191191, 0.023097990213760307, 0.0247112716814237, 0.026726992268647467, 0.018834116868674755, 0.030900064057537487, 0.0382186138470258, 0.017259559394525628, 0.07487302805696215, 0.06071794618453298, 0.0410173367043691, 0.05816278686480863, 0.0099256289125021, 0.06352139503828116, 0.022710779116355946, 0.0541553386886205, 0.02141754565361355, 0.01747043281128364, 0.043655664061329195, 0.04243410764528172, 0.019773652078583837, 0.020873055227899125, 0.014597635982292039, 0.014679694614772285, 0.05608727377174156, 0.026425164625314728, 0.025061862243871604, 0.0014721071680209466, 0.03100261784025601, 0.029981208898659264, 0.11029200641704456, 0.011043718916230967, 0.04536138574725815, 0.016228038584813476, 0.04963197998170342, 0.044447867266301594, 0.20254112886531012, 0.21416268311440945, 0.07414753841502325, 0.14710384075130734, 0.19026739389768668, 0.11958744084196431, 0.1422987135925463, 0.17862798060689652, 0.10404434095003776, 0.11244157821472202, 0.15746626470770153, 0.1444822121411562, 0.2145276399595397, 0.18018843473068305, 0.07705004659614392, 0.08940916841051408, 0.12535194866359234, 0.10545374639332294, 0.08668898937425443, 0.16332682594656944, 0.12744480850441114, 0.1194895960922752, 0.1141753505383219, 0.1999222551073347, 0.0746587874101741, 0.07134907000831195, 0.0822824811828988, 0.24099093994924, 0.20213628773178371, 0.19834703606154236, 0.11988602339157037, 0.11446249298751354, 0.15733617597392627, 0.13904815087360994, 0.19579611080033438, 0.24040129301803453, 0.09127097350678273, 0.08535960356571845, 0.16141376431499208, 0.18168460444680282, 0.14049090631306171, 0.09520136724625315, 0.07567665779164859, 0.15277251228690147, 0.26147317088076044, 0.1372558141925505, 0.09994364170623676, 0.10209133396191256, 0.15473220284496034, 0.12330113085252897, 0.14042863036905015, 0.13719508530838148, 0.15200670409415448, 0.17072930373251438, 0.1764654487903629, 0.09329709942851748, 0.08169045937912804, 0.14729601543928894, 0.15274997135358198, 0.07647665736398526, 0.1596252138593367, 0.08995382168463298, 0.12621504520731314, 0.11866080627909728, 0.1257098080324275, 0.14041484253747122, 0.1758497054023402, 0.17187916274581636, 0.09939966696713652, 0.12517018270279678, 0.113345943258277, 0.1574733621839966, 0.18451036353196415, 0.14804730298263685, 0.08164957085890429, 0.18489307085318224, 0.17144392324345453, 0.09547605857785259, 0.10406576908592667, 0.1922122109681368, 0.15162577453468526, 0.14074068862412656, 0.1686057062553508, 0.12416243606380054, 0.17131968348154, 0.12763587039496216, 0.10178897875760283, 0.06744464380400521, 0.22619823871978692, 0.19408218562602997, 0.12846428022852965, 0.16026020050048828, 0.16884775326720305, 0.21434286130326136, 0.14551703232739652, 0.15788306162825652, 0.1235169457005603, 0.14610804989933968, 0.2334163449704647, 0.14168507366308145, 0.10721881275198289, 0.11777979641088418, 0.17820350266993046, 0.13267484786255018, 0.1330906676926783, 0.1424668681408678, 0.06184097592319761, 0.15534956114632742, 0.15160779335669108, 0.1557190641760826, 0.21782278242920125, 0.1323333547583648, 0.12014792433806828, 0.10692550920482193, 0.08406926066215549, 0.2016351760498115, 0.15790480189025402, 0.10918971949390002, 0.11160237288900784, 0.12873980615820202, 0.09772939873593194, 0.0954353396913835, 0.18791570008865424, 0.11217462896768536, 0.0889037616018738, 0.13125601756785596, 0.14777488474334988, 0.13191339586462292, 0.10187505771006856, 0.07282368945223944, 0.23052119889429637, 0.07770648172923497, 0.15091388273452008, 0.1668544073722192, 0.09505593005035605, 0.3014038439307894, 0.12719280059848512, 0.24066152476838656, 0.13223880768886634, 0.11772749493164675, 0.22703876718878746, 0.0730178929599268, 0.14372788476092474, 0.16039607035262243, 0.09575500432401896, 0.14221279748848506, 0.20105847556676182, 0.11515073105692863, 0.09703708945640496, 0.09883781283029489, 0.16974308022430964, 0.14526205243808882, 0.08629336274628129, 0.0943834814908249, 0.1103487251592534, 0.096659444006426, 0.09704950664724622, 0.11465329703475748, 0.08611460269561835, 0.16708187945187092, 0.11463861353695393, 0.08129501595560994, 0.08088073639997415, 0.17624793760478497, 0.1742365833904062, 0.11004261765629053, 0.0962195090417351, 0.1777423159884555, 0.07978108897805214, 0.15602242361221993, 0.1878513071153845, 0.0880388669403536, 0.10339814491037812, 0.10017242335847446, 0.14733741964612687, 0.10451231976704937], [0.04533347420926605, 0.03448478491710765, 0.017148481515635337, 0.005512864204190139, 0.016468747186341455, 0.03142712970397302, 0.023309145222551057, 0.045204182754137685, 0.042106935022664924, 0.04462331945874861, 0.04425314807200006, 0.03710447970245566, 0.03408144334597247, 0.019648060335644653, 0.02254228699686272, 0.004908546921797097, 0.0632111756131053, 0.029172083030321767, 0.04394971738968577, 0.0756617435919387, 0.030369788940463747, 0.01761116267048887, 0.07262930952544723, 0.036237315341298065, 0.03695354298023241, 0.010011677330892001, 0.020954674508954798, 0.04705317032390407, 0.039263530634343624, 0.017384879723457352, 0.019679717386939695, 0.03808660825182285, 0.058661876512425284, 0.010317217408945518, 0.05012159728045974, 0.01788810164933758, 0.019715360831469297, 0.02239332311520619, 0.045194791829479594, 0.028747024945914745, 0.03272643944780741, 0.016907080808388333, 0.022376364828752618, 0.037398885869021924, 0.07988134931240763, 0.04952084273099899, 0.08853094053587743, 0.007836868271364697, 0.059375980336751254, 0.01889062865770289, 0.05305511111925755, 0.07029329666069575, 0.043576248322746584, 0.022511931036465933, 0.06140127844576325, 0.027919541312647716, 0.057509900469865115, 0.04673062531011445, 0.02247714763507247, 0.03060749332819666, 0.04869488240884883, 0.03919604693406394, 0.024737252787287747, 0.04593498871794768, 0.020746528802971755, 0.05499661693881665, 0.08386536088905164, 0.01902874106807368, 0.12396282463201455, 0.011483953284498836, 0.05161757700677429, 0.09965045351002898, 0.025811857178008983, 0.029242050168769698, 0.03561492570276771, 0.016669459541195204, 0.017409875257206813, 0.08139582590333053, 0.03395404161087104, 0.04494118597358465, 0.030146065766790082, 0.04005561170301267, 0.11747677624225616, 0.023470336305243627, 0.03622454531224711, 0.032638650587094684, 0.0461784165485629, 0.053764865534113984, 0.03483884448983839, 0.02019140064450247, 0.036907799541950226, 0.03714372616793428, 0.052779649650411944, 0.022617662059409276, 0.07972925568797759, 0.04176962169419442, 0.056104440707713366, 0.026316127440493022, 0.03505218947040183, 0.01681003673002124, 0.07566065115055867, 0.041950332533035956, 0.08703826527510371, 0.026142819418704936, 0.013168866845912166, 0.0742137837888939, 0.01253159947892917, 0.046632397188139815, 0.024133833291541253, 0.018197891901114156, 0.0944176185876131, 0.0036309392723654, 0.03613909061199852, 0.03930598317778536, 0.0285806753007429, 0.0608619177447898, 0.021759613816227232, 0.037622897420078516, 0.11157399655452796, 0.035624231810548475, 0.019845413942156092, 0.043921795673668385, 0.04211289256012865, 0.03545305099604385, 0.008341938357001968, 0.033793622361762185, 0.03600616899452039, 0.023797084843473773, 0.0052397750634034825, 0.03519376580204282, 0.040222558459000926, 0.04980839230120182, 0.017095155448519757, 0.002824492133056213, 0.07905794028192759, 0.06930037601185696, 0.03524702740833163, 0.0305759448425046, 0.07700445582824093, 0.03231587826407381, 0.03667575413627284, 0.046015829380069456, 0.02004522384543504, 0.07731582197759833, 0.02055572984474046, 0.013228709393713092, 0.03851051961204835, 0.07003341096320323, 0.0066338774215962204, 0.02942287635856441, 0.02825821510383061, 0.03248568504516568, 0.029412973139967238, 0.023032667647515024, 0.043104106693395546, 0.0590913552524788, 0.03643759173740234, 0.027768686014626707, 0.02541162329725921, 0.03461376763880253, 0.027821772898148214, 0.039254082034208944, 0.037236695643514395, 0.04181638972035476, 0.0358185574545392, 0.013727356297230082, 0.023460835118645003, 0.01458461319894663, 0.042459593420582156, 0.033445883342730146, 0.013296914885618856, 0.044375172417078695, 0.016164352984300683, 0.023348953175757612, 0.04160922619381121, 0.01572681324822562, 0.05715641086655004, 0.02475498630000012, 0.015165939594485929, 0.02141747440743659, 0.019819597381034067, 0.02476322541146406, 0.01704200410417148, 0.023374357526855807, 0.03069749421307019, 0.05296937482697623, 0.034259626641869545, 0.03642393622015204, 0.026072755589016845, 0.11174385422574622, 0.007553142245991954, 0.04715807183778711, 0.02635975893852966, 0.033618869060384374, 0.04278822150081396, 0.09242294276399271, 0.009694664073841912, 0.01806086005776056, 0.0762881264090538, 0.0647276131702321, 0.01607496108460639, 0.005989025729442281, 0.016501915674390535, 0.0329105904591935, 0.03170848424945559, 0.028447780824665512, 0.037813989844705374, 0.00472618724286024, 0.05489977302828005, 0.02180167959470834, 0.12858337669500283, 0.05433303004662905, 0.018589340449709977, 0.03147801983037165, 0.014016267178314072, 0.018277770739846995, 0.04041292824383293, 0.06513919215649366, 0.035035802849701474, 0.05812437499740294, 0.02886435722133943, 0.00141124554543889, 0.05480180614228759, 0.08280530598546777, 0.09772253196154322, 0.03007112835933055, 0.04049221845343709, 0.032720794036452255, 0.005218856252862939, 0.06723724957555532, 0.02579129078159375, 0.044348159937986305, 0.012377761171332427, 0.019066487971161093, 0.05358176285933171, 0.05496143829077482, 0.023203083413786123, 0.08848102749990565, 0.030685175409806625, 0.018453692817794423, 0.024639426697311655, 0.013564012562190848, 0.042441371362656355, 0.06250372821731226, 0.01934258047757404, 0.014377615913482649, 0.04857597253950579, 0.05759727542421647, 0.045994821935892105, 0.04193692807374256, 0.0577853246192847, 0.02314116370065936, 0.02073846271793757, 0.027621501591056585, 0.06978157269103186, 0.02901241016973342, 0.025009123109547154, 0.004284888422781867, 0.02229587870117809, 0.04635501546519143, 0.0370914552227727, 0.06318479417158024, 0.022185387755078927, 0.03564100519620946, 0.07463198527693748, 0.02253075359788324, 0.02619897497684828, 0.04572137910872698, 0.03593458355005298, 0.02780169335060886, 0.037153707418058596, 0.004263894549304885, 0.03830421443230339, 0.009073433033855898, 0.03339762253952878, 0.028733484779617617, 0.08530144632927009, 0.06039868188755853, 0.0668037064107401, 0.04832648878384914, 0.030696778358625512, 0.09921416227838822, 0.07724973266678196, 0.021413311595097184, 0.020637445817036287, 0.06129307246633938, 0.06290897647184984, 0.031437026137220006, 0.0819203131166952, 0.035363430090780766, 0.0393954276639436, 0.01336906266598297, 0.030336554295250347, 0.05959803770695414, 0.027092878706753254, 0.03202413874013083, 0.029395022496048893, 0.02910752042329737, 0.08763680780040366, 0.023091420298442245, 0.032133956240223985, 0.00964968144294939, 0.03920112576867853, 0.06708247573780161, 0.03807728857334171, 0.02479658558565591, 0.06123887787439993, 0.04461897683462926, 0.059886401519179344, 0.02871524915099144, 0.024410979223570654, 0.07243529600756508, 0.03146253566124609, 0.04316392973331468, 0.01728672963300986, 0.03563749038481286, 0.03782857156225613, 0.03128856946048992, 0.01704308297485113, 0.06030731036194733, 0.025421536693881665, 0.011353324267214962, 0.07308719174138137, 0.043072171442742856, 0.0061927308478126565, 0.04750397541959371, 0.01871841646996992, 0.03974380111321807, 0.016082852446873273, 0.03575963008084467, 0.0643079596172486, 0.05173092628163951, 0.015664237052468315, 0.03767698683909007, 0.007915201746592564, 0.011133861445289637, 0.04524184484034777, 0.035242691569562466, 0.04012719714748008, 0.03463073101426874, 0.04093681834638119, 0.03234469225364072, 0.035483978622193844, 0.009741334560593324, 0.03779457017247166, 0.039385297136115174, 0.04515663780538099, 0.027412565391776816, 0.04691093920597008, 0.007203724700957537, 0.07610621795590435, 0.024815399665385485, 0.17224968357809953, 0.14080430806747504, 0.09435585833021573, 0.15621130062001093, 0.18435841239988804, 0.10230606315391404, 0.12951917148062161, 0.13975854989673409, 0.12032857750143323, 0.17828141206077167, 0.21471144152539118, 0.17320464019264492, 0.08964592963457108, 0.1927321044994252, 0.12237730542463915, 0.1698544006794691, 0.14689213782548904, 0.1187014640974147, 0.04903580893629363, 0.14078410129461968, 0.1140866931527853, 0.14517097946788582, 0.1638986138360841, 0.17150737983839853, 0.14322994862283978, 0.12035015491502625, 0.09899506332086665, 0.1132632637662547, 0.07737220145229783, 0.09708786423185042, 0.09828068808253322, 0.07900243611740214, 0.20425345269697054, 0.08161895535886288, 0.18033562254692825, 0.19384628614144667, 0.09589630924165249, 0.18068966854895863, 0.1150050088763237, 0.10302146298012563, 0.11719717910247189, 0.11100191010960511, 0.10784672905824014, 0.15055330922561033, 0.20221334216850145, 0.19575143605470657, 0.19702443560319288, 0.11112002948565142, 0.1440303756722382, 0.08789798271443162, 0.16434337997010776, 0.2247408540653331, 0.15798493687595638, 0.14663650654256344, 0.14077256619930267, 0.05029128871059843, 0.11666621187967913, 0.2438966440302985, 0.18948815071157046, 0.13607690030975, 0.19985840496207985, 0.15948071304176534, 0.12732119299471378, 0.2465853254709925, 0.06180386005767754, 0.10047601349651814, 0.2305626438132354, 0.16050862574151584, 0.17377090480710777, 0.14282273261674813, 0.10865375146801982, 0.1712853903216975, 0.15607897272067411, 0.1653522936893361, 0.10629734184060778, 0.0862536413062896, 0.09617397255663361, 0.09537749458104372, 0.1869244147092104, 0.10613493448389427, 0.08916068888668503, 0.06444598721074206, 0.16063628531992435, 0.12910953988986357, 0.07009536121040583, 0.12506918955062116, 0.10077410750091076, 0.0820559658376234, 0.12079587099807602, 0.15188627769904478, 0.07259469066879579, 0.12251246960035392, 0.17627744030739578, 0.18813467690987246, 0.24212857176150593, 0.21098576858639717, 0.13296237029135227, 0.17649162667138235, 0.15048314870468207, 0.1681532726756164, 0.14972409872072084, 0.1447344778903893, 0.1873685565910169, 0.16331036468701704, 0.13012978514390333, 0.19368594831654004, 0.11154648195952177, 0.16766427962907723, 0.11326773531202759, 0.1828534895820277, 0.2666977276759488, 0.30544500851205414, 0.18694942550999777, 0.11475846996264798, 0.20915368332394532, 0.10840494624738183, 0.07734321443630116, 0.12037140663181033, 0.2141912765800953, 0.07255910150706768, 0.08435237939868655, 0.10354568556483303, 0.16222932269530638, 0.12321427837014198, 0.12068560905754566, 0.09653874619730882, 0.15738895242767675, 0.10075579384075743, 0.15394354159278528, 0.08800676544862134, 0.1271044553390571, 0.17633504793047905, 0.13630034189139092, 0.10691589436360768, 0.1624727946306978, 0.23818693469677651, 0.1598476240677493, 0.21665183454751968, 0.14690512498574598, 0.1340721414557525, 0.11962064834577696, 0.13595279625483922, 0.169588781361069, 0.23961275390216283, 0.10486709180154971, 0.11758151490773473, 0.22590072825551033, 0.1306945298399244, 0.12832285995994294, 0.10871205119682209, 0.060221306048333645, 0.07872084408466305, 0.09214249067008495, 0.11696250098092215, 0.2071113879127162, 0.15970562025904655, 0.10175072295325142, 0.0764257333108357, 0.12216499181730406, 0.19069981069437095, 0.13945280201733112, 0.1362113045262439, 0.11199931587491717, 0.1639988198876381, 0.07257149834185839, 0.16169908829033375, 0.10841729558472123, 0.08798061470900263, 0.17037673693682465, 0.13356150314211845, 0.10792204644531012, 0.07803738968712942, 0.08080634182052952, 0.10697217205805437, 0.21067647875419684, 0.09596881749374525], [0.0319347926415503, 0.025425904763064215, 0.06020206279520478, 0.0190962044123028, 0.02120876212471298, 0.00982564253666039, 0.006080047385434487, 0.027056305669248104, 0.0521420913615397, 0.0662822522489088, 0.0196296109684876, 0.03485614713281393, 0.010414756817876228, 0.03147559406767998, 0.016578386570992212, 0.03792884885998709, 0.02714053900646312, 0.11939916094498974, 0.008811871354867305, 0.04446781958852496, 0.0728603642699974, 0.007662063231691718, 0.011607338092289865, 0.019362768590716378, 0.028553829062730074, 0.029712525994649956, 0.017079803593722836, 0.015703356292630945, 0.03515890267278467, 0.01872755803300866, 0.01587919525003859, 0.07116525487176009, 0.03419646181698356, 0.049375785514712334, 0.03393295952784164, 0.05447008054969566, 0.041081946808844805, 0.040003001490341764, 0.06120720385972943, 0.07540958640830857, 0.03559060022234917, 0.008748445293999143, 0.014121648755722811, 0.06727744599006005, 0.011905389688243824, 0.019594864886520163, 0.01580899062433413, 0.043218429666012526, 0.008979766363544124, 0.012612191627600362, 0.0542828014918736, 0.055261228632714064, 0.010392202313856354, 0.04992427590436169, 0.024608256494892494, 0.05436191867504801, 0.023884673536356007, 0.04485992122707622, 0.09169786024306502, 0.006337636241888893, 0.025109549684982215, 0.021634520796526755, 0.07766472468418734, 0.05894457455724478, 0.006738797595192279, 0.04796116552980883, 0.048221957071551254, 0.0672098978289536, 0.04787240975669452, 0.02685004459427936, 0.04488208218078528, 0.014377393693264042, 0.029790180934859172, 0.04426703089848161, 0.04165167534457786, 0.019442611806360737, 0.007903870211781135, 0.03200815924044166, 0.04096845164895058, 0.02226247781488512, 0.014952525064083082, 0.01730650383979082, 0.06175079183386905, 0.03249222273007035, 0.018991725286468863, 0.02954840872968946, 0.015239865984767675, 0.048347408018474064, 0.013302337228586631, 0.028466857836714814, 0.06981842392789465, 0.05214631863470588, 0.06011189906192677, 0.025834180980122516, 0.036413072874503474, 0.01658890556011881, 0.02506754667099033, 0.019674406154081225, 0.02466340103585805, 0.09104515026722636, 0.04386077841211643, 0.008230733252795679, 0.018957937635215263, 0.022214666541133608, 0.05329256784170866, 0.04443232202902436, 0.04373690166643687, 0.04147047596052289, 0.019574632668601613, 0.04880386531086905, 0.011502151593698986, 0.07962013368627854, 0.03443632394607578, 0.0819025965673583, 0.0502350788696536, 0.03055690514988133, 0.00500585266023076, 0.01262808800674975, 0.040136296302080154, 0.05125185680974807, 0.017423247486086826, 0.03747668330158506, 0.03938733274117112, 0.03472293035260268, 0.004992203928330647, 0.052898630765931945, 0.03629782030891095, 0.027478919331250445, 0.019789295703438774, 0.04963814447234784, 0.0057669386733323336, 0.04132708454770701, 0.022974522285429493, 0.03782823908009699, 0.046948418087725124, 0.02708356750995985, 0.058014072344771454, 0.05476933145629508, 0.04321384955463665, 0.06576895407800164, 0.07528192682990006, 0.04169642133638263, 0.01170818620760526, 0.05103080367137279, 0.035471201807792695, 0.027252244530245662, 0.024232912974964296, 0.03785993005814297, 0.003813428721124572, 0.028091102106762782, 0.011035604485576707, 0.028064296580851078, 0.02566654042207769, 0.04752798877390368, 0.0710391898506454, 0.03494050939168249, 0.017557507513889244, 0.024237732269934247, 0.05889552326074668, 0.03948982884841306, 0.003005768488427358, 0.0642662432843021, 0.010833563898423952, 0.015096768038347363, 0.04199729733435171, 0.06520957659397807, 0.01986715929316623, 0.024501489009708166, 0.06778482733560459, 0.053657582362315485, 0.024209106573835015, 0.020808200850816708, 0.006743113926079656, 0.02200975744718952, 0.04478074636842523, 0.007929447589309087, 0.027650765110073344, 0.026597173252542104, 0.008093352812076253, 0.05221158013279949, 0.047205986588128974, 0.039619876870087216, 0.038856206062648974, 0.028560611020241464, 0.02125196105667523, 0.05235794013632195, 0.040472846278654676, 0.07513385013278041, 0.023279942771685973, 0.06399851372199399, 0.014714917367590325, 0.051265237520315816, 0.023586040096623555, 0.020287430313016688, 0.049070967228284905, 0.042660246403621774, 0.055039768373327594, 0.06004914135805198, 0.02042097448637443, 0.018427989911288023, 0.07538201753050089, 0.012370607715898325, 0.008980825726341988, 0.02246517318833087, 0.028684263849364858, 0.08457704234336104, 0.06038960308900901, 0.03390398947522044, 0.03174411751595991, 0.02818801047812615, 0.050838367747409005, 0.08480329305997916, 0.040973065687077384, 0.040117212504680665, 0.009898845438978501, 0.05966648831963539, 0.0712695185627256, 0.02325398032553494, 0.03166629633467112, 0.04371733271649905, 0.063199375889131, 0.09736596180924348, 0.056894608307629824, 0.01895592238620988, 0.06740513270986931, 0.045077666507235596, 0.04086835077032447, 0.017393339358802353, 0.034257363727582354, 0.02595456496679357, 0.005961788061540574, 0.029578664606170993, 0.04397917938019548, 0.07559368652956826, 0.004855443498984511, 0.0640011667939169, 0.048646791239402125, 0.019624659359189014, 0.07092309929430485, 0.03991292935929128, 0.05255485439140882, 0.06974008027464151, 0.04931749596393534, 0.03440770333898919, 0.020998236457152025, 0.017956708325073123, 0.0399397280998528, 0.04616857100544231, 0.02289239240677229, 0.06537528163088219, 0.06078397442719766, 0.013473223728526915, 0.012820782622189393, 0.06452042928763799, 0.0408480523952416, 0.03371919046289154, 0.005978632693378521, 0.03637637770069497, 0.049175132531672716, 0.04193716895367418, 0.09099127458674566, 0.09777163075549261, 0.04691403332565512, 0.09410102771861212, 0.025035994792623178, 0.016206858114206364, 0.07781111861446074, 0.04395127123487847, 0.0151410034325506, 0.07676926880542721, 0.027608580587963973, 0.012962709247533764, 0.04149074719420501, 0.04942111504663314, 0.06428771213229213, 0.07940678192036492, 0.07606322597712278, 0.010851675694409226, 0.047472382829125435, 0.017050268660698618, 0.040479655377566814, 0.015797056889693652, 0.02572999192800905, 0.09269242294664894, 0.020936079256768738, 0.024306033604911396, 0.027329105584483062, 0.033771787104862075, 0.039979900765631876, 0.030859779433480332, 0.08097220970583813, 0.04370713433516877, 0.02310085532787655, 0.019535589763628583, 0.02396355662494898, 0.03651679034477898, 0.03368571154507143, 0.02078148183811988, 0.05020525047023382, 0.03450813330709934, 0.01646333247689264, 0.0632161424894418, 0.009429114305281212, 0.04849268575864179, 0.05890639339174543, 0.052782591099717786, 0.026512678679344908, 0.011715691653080285, 0.025743242020585706, 0.04787004166947944, 0.017558426928839514, 0.03007725892322404, 0.027656356238627007, 0.06823105231991836, 0.022059400765491382, 0.007894005160778761, 0.08695592505059072, 0.07144624300833259, 0.03995791623102767, 0.09656317345798016, 0.045425266426588805, 0.022252606826701334, 0.020013493851625493, 0.031013528683355877, 0.04924704706562417, 0.0223416849039495, 0.02836895201887403, 0.03584986166762454, 0.056815979669668844, 0.07432989470128502, 0.023002854515133158, 0.06748083686189991, 0.016538173193112016, 0.05164919334596821, 0.03735628744055118, 0.04894106848431485, 0.07409458554216794, 0.017606509616598487, 0.0380808576675398, 0.04314691886039717, 0.022209209423246126, 0.05715001906667437, 0.03281631480370249, 0.0250661811192653, 0.04149676579982042, 0.013798932411840983, 0.03964994954211371, 0.03973618455763374, 0.03820175564448748, 0.04253476152994803, 0.031330221332609653, 0.044368573664022345, 0.13652712186532362, 0.11531284664358411, 0.10193607836429562, 0.10039302187838725, 0.10182331941489663, 0.10577444918453693, 0.15486655277865274, 0.06718939928604023, 0.17394173278340272, 0.09931190524782453, 0.08817464179758515, 0.11762020497449807, 0.1232243071177176, 0.2730670544717993, 0.12185609553541456, 0.11996739331100668, 0.13307963471327508, 0.15346275881997176, 0.07912395495389189, 0.1170602235943079, 0.148799472621509, 0.13238834323627607, 0.08043491853667156, 0.07797448270555053, 0.19438488009784902, 0.0868269151874951, 0.10537343498851572, 0.10196323333574192, 0.10520376730710268, 0.16373060856546673, 0.11225329153239727, 0.11819438130727836, 0.1304160047854696, 0.12021470575460366, 0.1443594651562827, 0.12059285332049642, 0.15859602551375115, 0.07739684584417514, 0.09936586235250745, 0.1750138316835676, 0.17136538960039616, 0.11312788924468414, 0.15704471804201603, 0.11856950260698795, 0.14226291408496244, 0.17259763633566244, 0.15607281162270478, 0.1631304036293711, 0.10769855736621789, 0.10379789024591446, 0.17616887470441206, 0.18737657687493733, 0.1254257054201194, 0.12375861273280211, 0.07179332045572144, 0.10775646354470934, 0.10800173359790019, 0.22082687408796378, 0.1872908914727824, 0.16362262650259904, 0.10864853353372642, 0.10485135657446724, 0.15016243234276772, 0.12054298099662576, 0.14910047075578145, 0.22226464908037866, 0.17191968485713005, 0.09405411380742278, 0.1268218726451908, 0.08243599294551782, 0.1532962598970958, 0.09968490273292575, 0.13472325008894714, 0.2276139748947961, 0.19169262956295693, 0.13276338311178343, 0.12248747237026691, 0.1514211826558624, 0.09797928961259977, 0.18990037430609974, 0.05482674230422292, 0.10338008230818169, 0.18287194573453494, 0.0809427070032273, 0.17672399777386869, 0.2415650077164173, 0.09199892623083931, 0.19734641404024192, 0.08429785232458796, 0.1773181908896991, 0.16522719897329807, 0.14975491778126784, 0.0900474391611559, 0.18231874970453127, 0.21368479090077536, 0.19228375570050307, 0.11837658153048583, 0.13970421281244072, 0.15250211608197006, 0.15455414168536663, 0.11417768469878606, 0.11617867089807987, 0.08448259026876517, 0.1022322860413364, 0.07777196035853454, 0.1636510028370789, 0.10749720888478415, 0.1547300722450018, 0.11926261255783693, 0.12780150079301425, 0.0990170274994203, 0.16995595023036003, 0.1052788132801652, 0.25451845835362163, 0.1457099262624979, 0.12644289726657526, 0.12593570591083594, 0.12816694618335792, 0.14510801141815527, 0.13818084741277353, 0.09235714522323438, 0.14004372459437164, 0.1882884736571993, 0.11796277016401291, 0.08765096204089266, 0.18488505056926183, 0.14696763163166388, 0.13058057666889258, 0.18532180999006542, 0.09496833796479873, 0.11983145560537066, 0.10771778026329619, 0.13227037313793386, 0.10255698540381022, 0.10547438064324004, 0.07783696401332106, 0.13979331803108963, 0.08123204112052917, 0.11489113712949411, 0.17601745282965048, 0.204584360654865, 0.17786605363445623, 0.09665128801550184, 0.23031655273267201, 0.17472065027270997, 0.2655696224953447, 0.12212261052003928, 0.07623446785977908, 0.16393856597798212, 0.13497509514646872, 0.13120089338294097, 0.0945588420810444, 0.1798894993428673, 0.10095393285155296, 0.1469319271189826, 0.14240695349872112, 0.06699123991919415, 0.1311346683651209, 0.1320312845387629, 0.11447903567126819, 0.17649177594908647, 0.15291215479373932, 0.10404263782714095, 0.0870488097092935, 0.10338955465704203, 0.13596480632466929, 0.14945159905723163, 0.08989133539476565, 0.17717043310403824, 0.12790496381265776, 0.1015950059518218, 0.22809052360909327, 0.129622593788164, 0.0919026963944946, 0.11046040523797274, 0.16689511947333813], [0.01056094718764403, 0.022520826630560414, 0.05840649628745658, 0.05606255813368729, 0.010932451895704227, 0.0841181016127978, 0.016956030324633633, 0.019080065456884246, 0.04120425953130637, 0.01431372675246426, 0.0626575860327908, 0.03154572405453239, 0.004868491303308734, 0.05104875770796623, 0.020830483940829123, 0.08689571863838605, 0.04550458377759371, 0.023614564012469988, 0.03969009167381695, 0.05565829714760184, 0.02233737620658108, 0.016016422172210047, 0.04102959443948098, 0.009385144387904023, 0.020152810661654388, 0.002948464509764952, 0.0026082220304358217, 0.009171653522311576, 0.04283766295494778, 0.032878125951226266, 0.03133826536525573, 0.01688524555148823, 0.041493179742246866, 0.0631974149229271, 0.06378386595419475, 0.0542172889358231, 0.07443348664258208, 0.0548549693609987, 0.028982276429555247, 0.07149510431502547, 0.04248574755287596, 0.04356465555195298, 0.03932267513924411, 0.015571966467957412, 0.034460598536367924, 0.07526196432965142, 0.052320417149790695, 0.03161950795246022, 0.010857265126625342, 0.06686510025922741, 0.06412153212087494, 0.03942317635353122, 0.03177668719685503, 0.034734611332948716, 0.07145175271268402, 0.034466383047401905, 0.06501994641231638, 0.029871954582631588, 0.02331060407284115, 0.024544984800741076, 0.016235078385631953, 0.03125615244997399, 0.03584590241579073, 0.044792817506406984, 0.051623358125133176, 0.042858863781605444, 0.019703352457976768, 0.024236310739070177, 0.03179878368973732, 0.06618396645145756, 0.05578746646642685, 0.012930506823717483, 0.017654682210247432, 0.04065397780920778, 0.02384043305314013, 0.013997610009807562, 0.0254536738087024, 0.03090220144284623, 0.03409211330914071, 0.02102155770574297, 0.0503503925033978, 0.02476310157882316, 0.05739687689180885, 0.0646344842389226, 0.053668055550328324, 0.06857865902462176, 0.040439357182809284, 0.04706707689911127, 0.031144017752792155, 0.09846919868141413, 0.02799883152225188, 0.010969336211149181, 0.01103050953575543, 0.030626363387065272, 0.052117270550557544, 0.0276576912562762, 0.08757357512201581, 0.019273434366498674, 0.02778104892266648, 0.011052375326731374, 0.03808210277929902, 0.012922233785502613, 0.02723327269112425, 0.006081395549699664, 0.02836226505626525, 0.04230715713596769, 0.06338762185935463, 0.03632380480745009, 0.03377285919019154, 0.021852664716009582, 0.045826887911451716, 0.03221165528520942, 0.03584564796515873, 0.046711005470050235, 0.050115056202879975, 0.048623948357999325, 0.01621526855576251, 0.02564870173643742, 0.047136586026421616, 0.018967832372124706, 0.05130167145814214, 0.016254148612331067, 0.02811668287696583, 0.05311849646802459, 0.06637148638921124, 0.03240726336038538, 0.015183427138254046, 0.04347258513527257, 0.0600716212232198, 0.0342944897711277, 0.02735795858981354, 0.05641849724841969, 0.013849414569059653, 0.04236533133579152, 0.04073626035824418, 0.036936440505087376, 0.012407771927038473, 0.022830126640786017, 0.01297379142072584, 0.028616739436984062, 0.01195225101296923, 0.04427552615691509, 0.05954572944236653, 0.02928062149190477, 0.0248050740587392, 0.017211135742919784, 0.016517800179177096, 0.01919541641005448, 0.021981221656980257, 0.014483206140409623, 0.11732964270881244, 0.037831692823341916, 0.032021302463752885, 0.028453175178063766, 0.03332730934822133, 0.12161711550184659, 0.08643598402185099, 0.0045629571624366295, 0.04551159982968654, 0.01490403016630028, 0.015132304613611527, 0.07854646737022059, 0.023502067995390723, 0.026294885901734233, 0.042428350275648494, 0.05399240885994264, 0.02105754381045699, 0.019411828368902206, 0.02812881508309926, 0.03954571299254894, 0.05417892795854381, 0.05946793540247849, 0.008624838265989507, 0.019247755208717923, 0.02735050827530878, 0.02331673802940973, 0.020174586546740363, 0.049743598992271085, 0.04220359572874648, 0.034028697426297834, 0.012799774329843265, 0.020267873237441694, 0.05072395317256451, 0.00666315239089142, 0.05327806415568505, 0.01527016596602542, 0.03226170402818492, 0.03373268313173737, 0.022884482384792397, 0.023057517296235477, 0.030849123041012456, 0.0246887782455555, 0.018322801716359596, 0.06315261125564575, 0.04054806188547185, 0.0401181488830064, 0.024148647407335893, 0.016456255356648138, 0.02043181238695979, 0.024955837754532695, 0.004026710513114397, 0.029503798444888422, 0.03798559135092156, 0.045714227349630425, 0.07751424597310168, 0.06662166225058691, 0.005132182310002723, 0.02015834072205637, 0.03490886591108782, 0.032878689135291746, 0.011367500560092074, 0.08360563803996358, 0.056204487303537984, 0.04546229747523155, 0.04686798793928964, 0.014618251572496124, 0.007360332279599139, 0.060082891689879556, 0.0075290254150916424, 0.006538919838411468, 0.05730809058461871, 0.018883349673290337, 0.02734256093390286, 0.023539000656455755, 0.02413059159048966, 0.04665645803990109, 0.031934762107474465, 0.013021187091778432, 0.0447379409867738, 0.012360239700813378, 0.04034883721864649, 0.025973448596362556, 0.05925753526389599, 0.023891065336231674, 0.018783170763137083, 0.016428630499701415, 0.047698372309761386, 0.047410368121096065, 0.03932468021022422, 0.027723836546231593, 0.03294108721560665, 0.030328812210687568, 0.05567765575168388, 0.06221229064145258, 0.04716527448701007, 0.0512141913308629, 0.03188382448362453, 0.012559727299958467, 0.02006613968738488, 0.015208743279799819, 0.027146868041849563, 0.017516805590795617, 0.03378458088263869, 0.06373864159520183, 0.03933444432914257, 0.01411198387255094, 0.025359581357666423, 0.03856126046074288, 0.02485639844754977, 0.0668984434700438, 0.054581116020147286, 0.0756671650867377, 0.06507686192968062, 0.10651422877396856, 0.032090872659214904, 0.08106208845440831, 0.01796291352781866, 0.023087478009983897, 0.06115542485245636, 0.013041365026895489, 0.029005109132932763, 0.03212321503087878, 0.03361547638529113, 0.03303952229076198, 0.022614891940195645, 0.05517479005668845, 0.05032300343737006, 0.04581114250634398, 0.09057656076869794, 0.0047220401216431385, 0.035579170299960036, 0.018487600909013833, 0.028306326629327874, 0.062440135915364535, 0.09170255570539407, 0.009471664388131882, 0.04115118452214769, 0.023891516562019075, 0.017795910792691366, 0.0271099489514849, 0.054155389578746896, 0.04251456154244287, 0.0328784584333854, 0.04985948598810604, 0.048209892718919685, 0.031176685821264982, 0.026095014930303608, 0.02114201124225344, 0.045772499937031946, 0.10606558141963822, 0.025539598394451395, 0.037500771294747076, 0.03231101316799011, 0.03033216417367969, 0.06174050524298634, 0.062312008147793155, 0.029099018379513706, 0.07110082118638925, 0.037312145344913006, 0.08216254333300249, 0.0414302082998412, 0.05270124153633203, 0.016716806018458943, 0.04528874518083675, 0.05205833639151283, 0.08898151492966072, 0.031104004542742456, 0.02149121928960085, 0.03248678087922079, 0.019603460228868892, 0.03153458929487637, 0.016591655323281884, 0.015564505975427372, 0.046774706337600946, 0.031408008587147505, 0.014725480461493134, 0.008616352337412536, 0.010061740492736655, 0.03330101611624871, 0.03477744046332581, 0.011371858451249344, 0.06681598110922746, 0.01962252875923046, 0.01213010267487594, 0.015954270060839396, 0.017288860232968415, 0.005466605079293783, 0.030638994316437414, 0.040450678539595435, 0.019817716142694865, 0.042024550693375726, 0.08195432807718005, 0.041486947398100577, 0.06127593945711851, 0.03735431629632201, 0.03602725447022489, 0.04580399413992252, 0.043427669509713135, 0.0507380124181509, 0.028448130270200114, 0.058275905437767506, 0.06571646939430918, 0.07323458311813218, 0.14504998310336045, 0.18861000426113605, 0.1180101183376142, 0.12650952940540655, 0.1829440604363169, 0.18975763767957687, 0.08493323251605034, 0.1339701305010489, 0.09105543007275888, 0.13325681377734455, 0.13012986656810555, 0.09372464434376784, 0.08700445387512445, 0.08976633567363024, 0.1255019320441144, 0.12775864452123642, 0.07753419490264994, 0.15567417229924882, 0.09362236197505679, 0.0552662328284766, 0.08121685550681182, 0.15847433704350675, 0.0746835810797555, 0.07408470607229642, 0.07665418926626444, 0.12520857421415194, 0.1250459836529834, 0.16805559077433177, 0.22177412254469736, 0.05412076393674527, 0.0903840535985572, 0.09227691524262939, 0.12296275900942938, 0.15404405977044786, 0.16017683568809712, 0.14635047689080238, 0.18981095696134226, 0.07961284622017827, 0.21948823306177342, 0.10455090126820973, 0.11384801167462553, 0.1687345600553921, 0.09696186027888741, 0.15593607324574674, 0.20739855750330857, 0.08594366615372044, 0.15992530275668415, 0.11907590686210565, 0.20016545562871865, 0.1796137834233897, 0.1465866206479924, 0.09820442753178732, 0.10143366389508758, 0.16211270966700145, 0.08620351792446204, 0.1923929862678051, 0.100563334168068, 0.14188250021210738, 0.05636727463986192, 0.1242029174630131, 0.11223858089319297, 0.12731401409421647, 0.15032214591545717, 0.163823255736913, 0.12112692823367459, 0.17414230773491518, 0.1586666881505932, 0.23512562896524156, 0.13816483398633345, 0.15807130081312998, 0.09966432955116034, 0.11505493548299585, 0.0980826033545392, 0.14992418512701988, 0.10937597735651902, 0.21917147934436798, 0.0999295213924987, 0.15229715779423714, 0.13745381071099214, 0.0962516376748681, 0.07968088292649814, 0.10894255632800715, 0.19742686115205288, 0.17607652608837399, 0.1679408097905772, 0.1346396952867508, 0.2244494775576251, 0.15787562488445214, 0.18200888990291528, 0.12442878820002079, 0.12025164520101887, 0.1683786820088114, 0.12346495634743146, 0.17822585361344473, 0.17868349834212235, 0.1359105778059789, 0.15023952749158653, 0.21337889374366828, 0.10153642802366189, 0.09315128903836012, 0.11811743543616363, 0.11078778481377022, 0.08136202807405166, 0.06460840135280575, 0.12141232006251812, 0.1245972141623497, 0.17264767150793756, 0.1449135025697095, 0.06742558375533138, 0.1373569294810295, 0.08826806928430285, 0.24762584535138948, 0.12574026068406446, 0.1407593483371394, 0.10472253670117684, 0.11153844810490098, 0.1287166816847665, 0.12791838523532661, 0.1035160335845181, 0.1277488600462675, 0.1656019538640976, 0.20442461994077477, 0.24093188026121684, 0.16300435896430696, 0.22316636783736093, 0.079895917459258, 0.11032072880438396, 0.15274299601359026, 0.18043061744953903, 0.15067951673907892, 0.11194185752953802, 0.11052888977740492, 0.15660880000463553, 0.08566361439547368, 0.25149835326841896, 0.07152871215449912, 0.1679817797350032, 0.11004222410597972, 0.15239683458847658, 0.1336890405842236, 0.09847941063344479, 0.11796783203525202, 0.13239800557494164, 0.06915755117578165, 0.07510856791798558, 0.1631892868982894, 0.08669571365628924, 0.14554458084915364, 0.09084184081958872, 0.2484960529421057, 0.12406381778419018, 0.04987072592068996, 0.12143810439322676, 0.08201758111161844, 0.1221816430666617, 0.16524044397686208, 0.09150023691888366, 0.05729187359767301, 0.12136852741241455, 0.057194625958800316, 0.17142709557499203, 0.13523190708032676, 0.10237896495631763, 0.21132158913782664, 0.20638440549373627, 0.14392714335450105, 0.1683099056993212, 0.07092172865356718, 0.1289137825369835, 0.16307799358453068, 0.25214399290936335, 0.18557928688824177, 0.07234093892787184, 0.09920746513775416, 0.19525089434215], [0.03590233956596681, 0.010510038401532387, 0.0616944395005703, 0.0414045528907861, 0.02410662403729345, 0.03240272056843553, 0.04584165961880769, 0.09575134023491826, 0.047646444024784226, 0.03504445077851415, 0.015909820928105285, 0.02393317861216409, 0.03617403516545892, 0.025443913082459142, 0.01600836287252605, 0.030882469644503932, 0.018621570863095776, 0.08101235183754138, 0.05330942604424698, 0.009080844332597085, 0.04847476225612419, 0.05065356194972992, 0.009911787646290447, 0.011858458813679005, 0.01355588371266744, 0.02878005603062255, 0.05099596089816519, 0.08266671520790883, 0.04708075616508722, 0.03045938948967627, 0.010369961632282605, 0.026128195292715515, 0.05890233575233391, 0.058482139371335506, 0.02893030403980187, 0.01189895039091685, 0.018204672162288, 0.022037748713046312, 0.020139014348387718, 0.01564928892600749, 0.018055201075705032, 0.039789307064243724, 0.06565069899495159, 0.0437657563681049, 0.021924426579581838, 0.012200873029152197, 0.012538917479105294, 0.014620762152065123, 0.003956601306396935, 0.08499071121748004, 0.00408372187355001, 0.00504775092537914, 0.019868692782308375, 0.0399509714251118, 0.02869964963091271, 0.011647604056634009, 0.08156383117394787, 0.05243001751867788, 0.02831387872408543, 0.01327958086039871, 0.030409445919628655, 0.009647893503175249, 0.042037490356181345, 0.0574716039534126, 0.07062186367277588, 0.022309086385316083, 0.015409343676375491, 0.006883030815515667, 0.05234327020921877, 0.06396867175187383, 0.041155337156461816, 0.04477996266047869, 0.03637927843789969, 0.03972457482346466, 0.07869269166673933, 0.008557407152173775, 0.016520113983590688, 0.04589669220149517, 0.021574144750567417, 0.02228554630918162, 0.016712649991469722, 0.008784030214883387, 0.03733575836356197, 0.019368522567674518, 0.028602921071329286, 0.05141760595142841, 0.03174285204815013, 0.023705489401306425, 0.03937393167455282, 0.09625391076718058, 0.018664917376424586, 0.08063664699771575, 0.038202624169311354, 0.0238913282685514, 0.04622012270348413, 0.06836023181676865, 0.028847376882497753, 0.07649002450385264, 0.057786159217357635, 0.02912707580253482, 0.056777086042399914, 0.038306226288633685, 0.026353796312053288, 0.029615719403539385, 0.06392291813556637, 0.020161390736965195, 0.02622588737202542, 0.04618073035297649, 0.1031844878037061, 0.04539227266130703, 0.02482365574022489, 0.02113806895379509, 0.04772978848112481, 0.045159752281116586, 0.05386524800477283, 0.016252642264589667, 0.05246140994131565, 0.06351253337093762, 0.00998147573721196, 0.01720016892068088, 0.06392749146159206, 0.08490628789045981, 0.058056521495538096, 0.027431315010679618, 0.008237759482913783, 0.06318373565695115, 0.03765085306284683, 0.048128234422100444, 0.030144311753766875, 0.0381936132242637, 0.02280121935265405, 0.038221402625952444, 0.05078657856211066, 0.010279645228625407, 0.01002792570008231, 0.0716859083622694, 0.018981382716447115, 0.06106566824018955, 0.02142072967918856, 0.05966487340629101, 0.039908552808421, 0.07073659037372895, 0.013352218034145023, 0.02074177566516612, 0.021015978451552134, 0.04322444487895284, 0.04956995848832386, 0.04735257729355778, 0.07401687292648212, 0.031664006278983185, 0.05027971290318029, 0.023854782372446995, 0.03146895460252251, 0.022393886299271668, 0.05159960261413029, 0.05982054291026933, 0.07444081482078348, 0.03293933659525854, 0.08112304804048368, 0.031897137340690405, 0.011646598128468862, 0.016598172652136003, 0.052889806418014426, 0.024475920113867948, 0.02368953195400536, 0.02455579555992569, 0.026347116134794693, 0.05904276535979339, 0.03759455840502467, 0.04532921640202403, 0.005972519092860499, 0.036549882497638464, 0.06436746713838407, 0.011595609614492526, 0.04495536057012422, 0.06344856787472963, 0.027006105952230946, 0.048001680855772326, 0.13825796970299312, 0.025239214334370833, 0.011554697345543121, 0.014824166594605361, 0.03111031831109098, 0.053729849734476635, 0.07584944673414741, 0.06674540668193783, 0.026677774731069803, 0.04826678788023336, 0.0629330983917628, 0.00492219310919089, 0.009566202127773846, 0.010096628218889236, 0.05171118430527193, 0.04000738821923733, 0.07727544914398875, 0.05119694975603904, 0.12102541939488479, 0.021256176455478584, 0.019850981321984103, 0.006754834346273648, 0.0428841392110501, 0.024951354334396974, 0.037981353899730105, 0.015090720594993659, 0.010262478292653603, 0.04264240771798151, 0.09672750785414662, 0.022293446153136234, 0.01737987552769482, 0.037769712042063475, 0.033991822440709384, 0.01063646559071328, 0.015136034859876548, 0.03318100023482527, 0.023978710008252944, 0.028013496360342418, 0.05970577549721513, 0.021190109197050333, 0.043522331930164776, 0.009089045276466225, 0.0002183855680673982, 0.055591420736163855, 0.11266247529004302, 0.038382575048932006, 0.03272119437211326, 0.04327054115544472, 0.03397978862215366, 0.016367282452327863, 0.00973512087616005, 0.024031242189396704, 0.026551041352961744, 0.03322627887661968, 0.08854457908975226, 0.03922843001782894, 0.01944272206830127, 0.07534473881657634, 0.015857697564310262, 0.05962331992174898, 0.03495142362745745, 0.04644892471177237, 0.0720159410099898, 0.0444114706479013, 0.0028474683889986147, 0.024640843139163086, 0.05022946399237428, 0.06393794090087924, 0.07860609024230923, 0.032752430731696744, 0.030679112699415003, 0.05456638163221734, 0.06365771950887782, 0.04422086337581277, 0.044798045618725676, 0.022745240213615552, 0.03151864032926304, 0.013733682788110204, 0.021991794928908348, 0.025497883757842437, 0.04611480389056461, 0.03166651685855218, 0.020629534098718847, 0.03182595901723419, 0.01838224477666829, 0.03831267237131085, 0.07698724818016801, 0.029686605956937586, 0.02909884535308395, 0.03626248899048992, 0.039758969763559956, 0.03466294785695417, 0.04420028001602207, 0.017735667061060667, 0.08306958858988114, 0.03084961837157607, 0.04256273413609181, 0.008557249392781938, 0.06846691787775074, 0.04802637953045113, 0.035506580623665025, 0.08442665862717799, 0.11309725338859217, 0.07469354875917945, 0.0030925558738610043, 0.1037254227059228, 0.04359354757304702, 0.05926780149872814, 0.04176528246275016, 0.05191830372703927, 0.027241640724241734, 0.034707537785704644, 0.057856312952935696, 0.05485382602949228, 0.024445854227191637, 0.07832516995923859, 0.016922302045194165, 0.0161182312627456, 0.05034963593685201, 0.06014658577208008, 0.030834816130144254, 0.008193058444053998, 0.07061926488365446, 0.004832624366307365, 0.01007327898072877, 0.023456572222390344, 0.02155928822633411, 0.026148609018751552, 0.03424113316993628, 0.03969225620052644, 0.016374817583709955, 0.08193412130432469, 0.038095985605780563, 0.03187114266412599, 0.01901713981559234, 0.021564526516678076, 0.036885665729641914, 0.08421576315803186, 0.00986987114551344, 0.030691305973700116, 0.02284435212745198, 0.027604461880400777, 0.07912280144436018, 0.02740747298646186, 0.06613296775945596, 0.040353756597531695, 0.060053612903824875, 0.02172196190804243, 0.044810388170714886, 0.03539959600727473, 0.06419697164424829, 0.02356280536124749, 0.049412843704755814, 0.021448027142988782, 0.0615567308185356, 0.06652504564928156, 0.09044301829167775, 0.01772430838484849, 0.04823475084932787, 0.0337199639928128, 0.04579783982730337, 0.0808419988357595, 0.037991565851760764, 0.09139839559793472, 0.029902176532362188, 0.05902713869831391, 0.014968859098319496, 0.011991752777248621, 0.02619397926277348, 0.04171431430482438, 0.07818408217281103, 0.0054342593149548125, 0.019328606048864976, 0.05664691249174731, 0.12871250190905162, 0.10407300226922546, 0.19791217653879098, 0.09556598482387406, 0.1669440282774823, 0.07728412082152707, 0.13602793722280435, 0.20752692275813647, 0.17768682539463043, 0.10584980728370802, 0.10000819074256079, 0.11162083582686526, 0.10222690525863852, 0.07265165368361132, 0.159448061936668, 0.08652729447931051, 0.10782276998673167, 0.203783621479358, 0.09513451119086572, 0.14860305030431065, 0.20296521325196537, 0.10838412879300968, 0.058003799324589114, 0.07416938045727355, 0.1717803001935993, 0.1615567316434213, 0.19264700263738632, 0.10488056072166987, 0.10398732365242072, 0.12134572863578796, 0.19057493310953888, 0.16831298624830587, 0.11185342406055757, 0.21578997293753283, 0.12541478100631917, 0.07467506546527147, 0.10335710711245026, 0.10149385673659188, 0.0741977703624538, 0.098371971398592, 0.13070450430469854, 0.2303112330181258, 0.16038229609174387, 0.1266400795429945, 0.1190098582633904, 0.1802660727075168, 0.1619930432311126, 0.14409999336515153, 0.06710301499281611, 0.1760661852146898, 0.12711265204208239, 0.1492158488503524, 0.13902474141546659, 0.10945820223007884, 0.13226831039147718, 0.20005072892776557, 0.16902091540396214, 0.17495296709239483, 0.09096098478351321, 0.13740847100104603, 0.17300785146653652, 0.16837633427764687, 0.13832749240100384, 0.13737222366034985, 0.16657596374196665, 0.17341236690325396, 0.06711243984422513, 0.1463894655129739, 0.1237465755215713, 0.15499802572386606, 0.11210682296327182, 0.16902965493500233, 0.12491617990391594, 0.1441484679068838, 0.1898535689605134, 0.14080175677580492, 0.118879837383117, 0.13746529152350767, 0.12630675600043365, 0.12415379152766295, 0.10841623028474194, 0.08183721971831151, 0.26608202500002726, 0.0790040171039956, 0.09418532212397882, 0.16317027434706688, 0.1256604106830699, 0.17884739169052669, 0.18637344427406788, 0.24544945784977504, 0.09720988518425397, 0.1252659104232277, 0.14993489240961416, 0.17689234231199535, 0.12268967580582414, 0.15484998295349733, 0.18168343736657075, 0.19002337913428033, 0.12637080970619405, 0.09544846934399434, 0.11990363816065447, 0.13876488964472497, 0.10212475859693118, 0.11788980050810746, 0.17708191142550536, 0.19323541463485785, 0.11061957598264728, 0.14784474670886993, 0.1765287968197039, 0.18609171653432505, 0.13332046036209377, 0.16355748714080878, 0.13647206553391047, 0.14012620731123857, 0.13971861132553645, 0.16290124878287315, 0.12830242248518126, 0.18756883298712118, 0.06195973990751164, 0.07713364211044141, 0.16598798600690706, 0.20559125233973774, 0.1666449571826628, 0.06818884065640823, 0.11910078195588929, 0.12228100773479257, 0.12106955131249768, 0.0958046323752829, 0.1520785880940301, 0.16279988922178745, 0.10088504797645978, 0.12036311493388244, 0.17222733263458523, 0.18443884594099863, 0.10551232432148286, 0.2047986284430538, 0.10471075733325311, 0.1320573945662805, 0.21338619478046894, 0.23060009894626482, 0.07441837566771678, 0.08072495833039284, 0.09594445808657578, 0.13517501870436327, 0.1540735624730587, 0.1812885028443166, 0.25429017203194754, 0.12810783221253327, 0.2021383097661393, 0.17013375354664667, 0.10377646889537573, 0.20030878936605795, 0.11436277548117296, 0.16420744226447173, 0.09876482960368906, 0.15300329561744416, 0.2725020247910704, 0.08046661969274282, 0.1902529275310891, 0.19787398858794145, 0.10627931995051247, 0.08979246605719839, 0.09615521106336798, 0.15470592996903829, 0.13169872095542295, 0.09134547665183033, 0.18868354388645717, 0.17808950878679752, 0.1570227877902133, 0.10148224700242281, 0.0933284138196281, 0.14621323639793055, 0.1899194682815245, 0.1674733263041292, 0.09659997041204146, 0.12605719082057476], [0.13901501122329915, 0.06716435455850192, 0.0812704326318843, 0.021053723658302, 0.05876575343843017, 0.030594764011246816, 0.03594469711450594, 0.05332504931305136, 0.025551939250103066, 0.025947233395917074, 0.012989475757681897, 0.0384257027347173, 0.027633774593206387, 0.026637700452868427, 0.04294108526249017, 0.053932921694857736, 0.06426436374230043, 0.03842752460124237, 0.042511674375938516, 0.045616311353764365, 0.01628701515229685, 0.09151611463832003, 0.023906834490065063, 0.02511877267222319, 0.02760703013544636, 0.015178361874339836, 0.06306691906814064, 0.022458557471899048, 0.04867638215156538, 0.055279114815805636, 0.025623918244881288, 0.00576708116568625, 0.04985655810950058, 0.029130926488765647, 0.05936169717460871, 0.10299815530223505, 0.027761127134518962, 0.04500150095139231, 0.011894490719506783, 0.03030996590054461, 0.05059869221544691, 0.054428123336817534, 0.039477228453116756, 0.01861090598894017, 0.0667695693139519, 0.05563767307571002, 0.03327633101227028, 0.04514794237911701, 0.045229570141860416, 0.04064420351226415, 0.04827026537220393, 0.023895226452233534, 0.010877697512374392, 0.032197304269565005, 0.025270089374056885, 0.009247389056586792, 0.0668669662305287, 0.04629532473960093, 0.09156774436788899, 0.03199152834713459, 0.011057010569077517, 0.05347090720066002, 0.02081962059518056, 0.0492246418393084, 0.015656238820936, 0.04625435479517494, 0.010858561976679733, 0.015119909475158368, 0.02824799297377467, 0.056970173359981606, 0.051707408257893155, 0.03977349380563412, 0.009886423159124596, 0.07012954580464534, 0.02413291726926608, 0.056851005647331476, 0.02681544779001602, 0.025991730026102493, 0.011251594056375325, 0.031028985711080686, 0.026711175617362772, 0.03231992572546005, 0.02387687547265419, 0.022252055516998683, 0.007277025142684579, 0.03164562137265291, 0.011345969795781587, 0.05960853464369263, 0.0717129615534629, 0.04263784796265619, 0.020864690587456738, 0.027386828558519483, 0.0390119773468801, 0.018019662804103324, 0.022904704424685667, 0.017544045379119258, 0.04733582426394735, 0.02647784778050014, 0.024833365576341748, 0.03374599938147834, 0.04489731868462903, 0.036755817875798256, 0.06394924529428993, 0.0522633862814733, 0.06412212244634118, 0.010925060953013599, 0.030312286490308385, 0.021458254362057363, 0.005112498433196119, 0.009204300386565072, 0.01614407157259328, 0.03471217217988201, 0.04357240102919085, 0.06861422104494912, 0.0338090251066855, 0.03789242510018604, 0.01801985957925873, 0.057073812798729966, 0.0736789692725454, 0.015021364138062512, 0.03329554033864822, 0.08933939465454646, 0.02806623719100441, 0.0313980714417994, 0.0408740572498313, 0.03250160686937826, 0.05352091183885932, 0.04389695789931076, 0.0036504844735775676, 0.05353203642049006, 0.045060492785913606, 0.05134007654019764, 0.03940925281494856, 0.0082517449378169, 0.03889369172975421, 0.03704966425097414, 0.024790812948984758, 0.05844798870384693, 0.045489713682660034, 0.084356470964849, 0.04472032282501459, 0.028519746248743365, 0.023420735395380428, 0.027047013132167712, 0.018715834644223963, 0.045123701715575795, 0.03951436806736248, 0.02501460736883538, 0.008093906666285225, 0.05226873992277043, 0.014050618861801922, 0.03144794037299497, 0.039289213184799464, 0.05882110832525151, 0.020847927379821028, 0.01951904029452375, 0.022264856080125486, 0.03986810194328427, 0.001849293546651357, 0.0712733387148806, 0.07864391178424869, 0.027503735053219965, 0.029079069449965442, 0.009679866921422737, 0.043940245040825436, 0.03577364861432995, 0.014877657206462962, 0.023610443608569245, 0.044160992838442326, 0.03497471773464765, 0.01683821120033307, 0.11849555586065565, 0.047381279324846606, 0.05052968520405037, 0.018528491125575135, 0.015644303389957974, 0.02534460269712976, 0.02005824662878045, 0.06174815233264651, 0.04693312730107989, 0.0957900235163314, 0.015834018388496976, 0.017767330897705894, 0.016567501172955548, 0.02937641367316246, 0.07630217208393983, 0.002104069663411272, 0.023453805495851805, 0.020571459982810274, 0.0197515063919127, 0.03574102125795824, 0.06868945700781685, 0.050737472982811074, 0.04097208859665053, 0.017130232316308787, 0.033802260112549574, 0.05305063618080957, 0.024605615297332406, 0.05653098478381123, 0.06411082483828068, 0.05343308565872056, 0.05740852055272885, 0.048912084860993285, 0.023581809430782284, 0.04160266815285597, 0.01907273388600775, 0.032854143130992136, 0.02658451857444431, 0.03046093654951879, 0.05182841819311891, 0.044964422405298264, 0.0566210128100855, 0.03843638966126101, 0.02925265227843608, 0.12604741991630622, 0.03801456479621785, 0.059652802268309255, 0.04936592640089137, 0.02643344784155488, 0.011481073751513447, 0.047669188518609316, 0.02594021225481161, 0.02380819246172905, 0.03733256924897432, 0.010455330667485083, 0.04280252501900707, 0.012359120966201382, 0.02348557789810002, 0.07762750703841448, 0.14399236414049352, 0.021257698070257902, 0.022325415330539857, 0.041666467407984395, 0.025728729852874364, 0.05427737660439951, 0.0345977168929364, 0.046618609356560876, 0.04761353846905487, 0.020587157890466706, 0.06357717740216426, 0.014054303306953182, 0.04844965985310929, 0.027354750815512877, 0.008672655476922435, 0.01381786523519882, 0.010578716323444886, 0.04367400486288326, 0.018862761224486997, 0.03635226256613221, 0.06149316565798862, 0.028942728015993322, 0.04935176198237708, 0.022464564203151634, 0.09391992672213487, 0.048288185482046435, 0.027230171786089028, 0.020023381803184748, 0.04040597325989178, 0.06447684698339019, 0.03584168871332492, 0.0277632679125028, 0.002309446522433843, 0.02732574344346566, 0.06570758058556489, 0.04271324338125331, 0.020878607340689217, 0.006919811654370278, 0.017726135340386202, 0.02170728689192661, 0.050249619875103235, 0.039877628574946096, 0.014591495240373271, 0.026146720995062163, 0.02955887173967702, 0.04505983799962061, 0.0395592361954706, 0.07525973194944006, 0.052374411573899646, 0.02397946996747383, 0.07164262461342982, 0.05452668394095131, 0.020713826807747995, 0.02251761546358466, 0.04707447971616473, 0.030703977615173374, 0.035892887573157034, 0.05703623552939721, 0.0322187900809305, 0.021491597572873746, 0.03921927658042737, 0.02512813645548054, 0.05187131178432277, 0.05334784808967795, 0.020705521539119736, 0.017646446491458585, 0.03435386837060962, 0.03168883726799062, 0.023777973904673542, 0.04832878901756235, 0.038848575936364274, 0.011364907708152064, 0.011104743811301887, 0.048230771241443496, 0.06940448363976819, 0.07280109423611845, 0.04037636877702815, 0.010550282313488424, 0.07635222082691533, 0.06384133108492408, 0.019520166662654707, 0.04279757849872112, 0.08206335508397647, 0.030287251940795352, 0.05386507497834308, 0.00903589986929936, 0.022206064413434694, 0.015271492501986879, 0.02865752617695502, 0.03348645634417023, 0.10271139283265386, 0.06533963818635259, 0.024069094265412008, 0.04964579834735819, 0.0796040863330875, 0.024229338791753565, 0.043054621134485514, 0.05454876686313322, 0.05475751816162041, 0.07942829148045608, 0.011733740684576333, 0.045526609024299045, 0.04420049036187785, 0.0439464366728706, 0.013373014284297824, 0.021022365162415162, 0.041057668825877566, 0.009041211102157831, 0.03080906572618655, 0.01728825972947691, 0.02756381593644619, 0.04852971341460943, 0.03585696592926979, 0.033792289040450535, 0.037774685703750165, 0.06128134738121714, 0.03010905168152281, 0.01493191286655409, 0.08819803089967795, 0.024696252308785915, 0.004661268404951053, 0.02078016717652125, 0.022678470671443, 0.2721995067383562, 0.13644196572048323, 0.14748344038214, 0.1330737450293132, 0.1916736170117344, 0.08913573915404932, 0.08730823400297336, 0.1682759110948869, 0.06913750046598059, 0.09313805082014628, 0.06771240729306426, 0.15505631188196795, 0.10055222654981272, 0.1440850113119398, 0.11989130239401545, 0.1527879693146263, 0.1480050709630762, 0.16854698583483696, 0.09969365583466631, 0.13778207238231385, 0.11597836736057486, 0.24567437863775662, 0.13757256790995598, 0.16497638528900488, 0.20747493340500764, 0.15286153608134814, 0.15720369879688534, 0.07524180505424738, 0.14484654473406927, 0.12004239857196808, 0.0930319686553308, 0.06482754780777863, 0.15658232356820787, 0.09164955533508744, 0.119203742859619, 0.17727354328547204, 0.13438665600759642, 0.0904889279710395, 0.21847983502915927, 0.07816410610186202, 0.26431851248656, 0.20180273348731653, 0.15085466019809246, 0.11319059945110764, 0.1809600376124893, 0.14865848661533423, 0.08884875276791197, 0.13453060042645248, 0.16076341564101831, 0.21799929652895245, 0.14778278289096697, 0.1126414474898151, 0.14892787858843803, 0.2188886795192957, 0.18159521424344607, 0.10305137958909784, 0.1506993571030242, 0.18420694981302532, 0.20485603250563145, 0.14810409636369773, 0.17220618948340416, 0.24769657584173338, 0.07818335614034108, 0.1472658206309591, 0.0877914120044027, 0.10179330102567162, 0.13002408295869827, 0.05669946163626654, 0.12117808977408068, 0.18353947491518088, 0.1313853192010096, 0.1329955913658653, 0.1443603201104062, 0.17164061697466032, 0.18726417076374802, 0.20834400105689252, 0.12216762453317642, 0.13102366003607, 0.10511641270880188, 0.07803061790764332, 0.10734688623675279, 0.1832953787275723, 0.16206339374184608, 0.1402389934020383, 0.07022743805178575, 0.09726124349981546, 0.07464910471545798, 0.16186851848449024, 0.19542968831956387, 0.19423169403203897, 0.18533193373254367, 0.04995590242158089, 0.10429400112479925, 0.15441342709319933, 0.15178984430219444, 0.11629767236965043, 0.16053411151681626, 0.16746422036417893, 0.1372969876974821, 0.15064340510538646, 0.21889835542866162, 0.19695587642490864, 0.14319200494459697, 0.3080459146627358, 0.20025682715432985, 0.1418520204190697, 0.08542428830904619, 0.13053637689777783, 0.10821853910705873, 0.0962548064334052, 0.14022037440112659, 0.08282796226974044, 0.14090516551264695, 0.22024253330060414, 0.1160502377897501, 0.11206158503357853, 0.17846676068646566, 0.11390313585954052, 0.14885752807770455, 0.09578715331320252, 0.13839386669652803, 0.13565110601484776, 0.1296820877385991, 0.11122100906712667, 0.1742622862969126, 0.16727443411946297, 0.10977719511304583, 0.23292956394808634, 0.23625300132802554, 0.16507584495203836, 0.18512977100908756, 0.17787160405090877, 0.10182328548814569, 0.16065170163554804, 0.14044263533183507, 0.21073019158627304, 0.12968763815505163, 0.2040076194597142, 0.08341460329081331, 0.20935934728809766, 0.10395355974989277, 0.08911326607423169, 0.1199136126254286, 0.15164530277252197, 0.1556388884782791, 0.10376050296638693, 0.15754843529845985, 0.14697894959577493, 0.08720620269221918, 0.13000478542276792, 0.12849230372479983, 0.11519489011594228, 0.2035321021186454, 0.15028256018246922, 0.10451746306249074, 0.11766118848962442, 0.10776781543557133, 0.08400913567415305, 0.14753865956195764, 0.16957550921610423, 0.11766866594552994, 0.11588178468602044, 0.1289155874401331, 0.17506173625588417, 0.08892974949308804, 0.17497164037610802, 0.07900886184402875, 0.144566947594285, 0.15857644299311296, 0.11553341123674597, 0.109552301466465, 0.14738096802362374, 0.12868732825985976, 0.13002759777009487, 0.12575829614486012, 0.11438189659799848], [0.033155263401567936, 0.05721184717757361, 0.015105780679732561, 0.043684043788484166, 0.05909400832440172, 0.056668157423181195, 0.0103882888631363, 0.03625830242942486, 0.035355721932968924, 0.05618939329204815, 0.050661334568368535, 0.0008431257208160657, 0.012080399136591171, 0.018938173606459583, 0.003522054969965081, 0.010213353205472231, 0.011533649189264646, 0.014944942435249686, 0.03672428296080657, 0.02342170909313219, 0.022172022311549102, 0.07574580729539905, 0.06562422255852393, 0.01687787157217307, 0.02681397197635046, 0.026641276332416704, 0.014526864779847009, 0.05483532577220883, 0.00876169029756316, 0.039950102900287936, 0.016740320649530207, 0.031106905279947177, 0.048241736367344856, 0.03640180919319391, 0.01834765136508005, 0.04141373007691332, 0.01987637549505702, 0.09738887593682323, 0.019188707395057594, 0.03515058383345604, 0.031142731928931813, 0.09571842450116362, 0.028316056821495295, 0.03363156784325838, 0.12114003753023488, 0.0382096809335053, 0.05064864596351981, 0.07368507608771324, 0.05945060561810221, 0.050804729373859506, 0.08784341492823192, 0.048930507086749585, 0.03193101320149643, 0.025984539251242365, 0.03516552856724177, 0.029925898116614138, 0.06684822509331362, 0.08916352516306297, 0.027004949050024152, 0.05507729135985885, 0.024273818458563516, 0.01748285848381264, 0.03504245249288423, 0.028764660071049417, 0.029619990781481777, 0.02918199303426913, 0.0019711743391651127, 0.026558752903448682, 0.037549391721508334, 0.007972205473509218, 0.02773182629607618, 0.04386171139776707, 0.04278080850573523, 0.048593081800001006, 0.08703404478728771, 0.01573479451638247, 0.033745972240077596, 0.023282728157937527, 0.054678000642785, 0.024825202800067406, 0.03482394725350397, 0.048277966744665585, 0.010978150381041425, 0.035397478978016546, 0.022865646252674714, 0.048688975761511495, 0.021823358788554157, 0.08916351837771279, 0.007456098167624856, 0.042416078969836235, 0.01721779047511518, 0.01958439339484487, 0.035909579534615786, 0.06868446977542979, 0.02793505262317402, 0.07806005954210248, 0.019003428319203, 0.0530026739330164, 0.02413160939301763, 0.02557599331651415, 0.017820465278678706, 0.015863085132358328, 0.042564074242753644, 0.01242751899241869, 0.011540676267551524, 0.02610243471073253, 0.0660772668197751, 0.015993770976950015, 0.02498799013639135, 0.04379373236692377, 0.0227379866742662, 0.026197634870186448, 0.029644489288330078, 0.08930340515715735, 0.023186405023027743, 0.024420894316530654, 0.02756701353272157, 0.042748788438205204, 0.020170564530417323, 0.03869413458076971, 0.024090617396203533, 0.057106063568166325, 0.032271960084991794, 0.01631015319643276, 0.009164805407635868, 0.023305571039340327, 0.04685215771730457, 0.009983629237727394, 0.016003323053675036, 0.06978384578334433, 0.014006629436542945, 0.07907168061605521, 0.09430771627064262, 0.0380313585379294, 0.022823129248406206, 0.0344254707784525, 0.03528820091326322, 0.057112814991601875, 0.031668328547051976, 0.026607866964436004, 0.05246204437155809, 0.004599045895572219, 0.009289815306796559, 0.009294952665056502, 0.03790862173108118, 0.03924359527549573, 0.02564659827787961, 0.07760725276810782, 0.027455565852246115, 0.03942139519910727, 0.026375892804935575, 0.05063315840171916, 0.05952468128608806, 0.05734015814960003, 0.018552311097404788, 0.027487965899386575, 0.030117631756833622, 0.03660542058891483, 0.043484506995550225, 0.014087369166580694, 0.06824518620435681, 0.01631573584329869, 0.02010018178927047, 0.030685114341654947, 0.0393769511553858, 0.04234977252781391, 0.052849165563072474, 0.04447674910937037, 0.05574423700038876, 0.031112615152129104, 0.00979796763775604, 0.041684272166873725, 0.054660738711910586, 0.05218038109264203, 0.007696656643279961, 0.05307805917358824, 0.029007789346256425, 0.038656886400921006, 0.009626290644519031, 0.018239726977688924, 0.034564319399318526, 0.03611740463280252, 0.02815536955105407, 0.022808052200291837, 0.030068044417670796, 0.021300969944734658, 0.017896588426083326, 0.02680217394871371, 0.03196935382272516, 0.05979893835527556, 0.041559116382684023, 0.03153740182252867, 0.04660855007490941, 0.027139056407447373, 0.018549010024539063, 0.036770443698125224, 0.011680367120009447, 0.09187571784215313, 0.06897169364882366, 0.022907182773841277, 0.018676837540364692, 0.032572405213224034, 0.07080595022333519, 0.029954885132610798, 0.034692647334720404, 0.02537002570794097, 0.03777450589197023, 0.022095134115910957, 0.023986185767820904, 0.07786700275859662, 0.013266531783821327, 0.022730030851172547, 0.010654021836152034, 0.08914156776985951, 0.05246224453938859, 0.05202384984919003, 0.02502366411499679, 0.03143766735281263, 0.021093190647661686, 0.03695646746616278, 0.07715395744889975, 0.0203125004856182, 0.040028222636984925, 0.06983470198299203, 0.062377147509583404, 0.01814300859613078, 0.0531817020050117, 0.051783641667238305, 0.011013188233066882, 0.0623561672068068, 0.02940507499235017, 0.02762018353678286, 0.03726623227287616, 0.04723920426996691, 0.030204776009278636, 0.014249779915969287, 0.01851809936176453, 0.034807180653193166, 0.006779675937390753, 0.023032017950234667, 0.01940673596358725, 0.0621063034715397, 0.032015049763556035, 0.0007528208204478558, 0.0307820294983685, 0.018138292777751173, 0.006907620924591486, 0.04098117757322533, 0.05383491409676416, 0.04280485239412103, 0.09128411673009396, 0.0211391936255885, 0.059035620386047025, 0.04904289284188833, 0.04546365115259375, 0.01932869595475495, 0.03843329554157598, 0.017719355079212358, 0.05025649004216705, 0.004213411543917443, 0.02997464407235384, 0.04959901335782238, 0.03785512942288603, 0.03163876138361437, 0.03588925401813217, 0.03285284712910652, 0.03242530560653124, 0.03958936993564878, 0.028892272152006626, 0.0477096631324717, 0.029407307372561524, 0.019488563894161155, 0.004321612858413053, 0.051563317954008064, 0.03696041993264641, 0.021104691816227775, 0.06581374417458262, 0.06057364214211702, 0.07320636284670659, 0.020077391494331614, 0.03360084717028907, 0.07698250522038766, 0.09051544511956827, 0.043868252475346835, 0.06884720961430243, 0.09038256082151618, 0.02937110752931663, 0.017633430493463362, 0.022204064431467226, 0.03535906711061086, 0.04175099251525743, 0.02252588341278689, 0.020248825063130686, 0.03752285760960408, 0.02686350333637425, 0.027682680004675473, 0.0227345736431224, 0.020885613214756762, 0.026364657961364304, 0.04291949767087187, 0.0516262079722115, 0.05705352460167237, 0.032248669370476685, 0.04391392466745206, 0.01944521738083235, 0.06403279331113611, 0.021988034148567488, 0.08918111957609653, 0.0463485558118139, 0.05589842051267624, 0.006861342291813344, 0.01176899906048285, 0.053462099816117964, 0.03743833250233105, 0.022245841832565408, 0.062321059804941924, 0.05113251607066818, 0.04216344681169305, 0.022947949157761674, 0.030389334141675915, 0.039885988126375845, 0.06382680365017482, 0.05283712835184165, 0.033319662258561165, 0.07159431970545224, 0.020783246029168367, 0.026724496956116388, 0.020692865164684396, 0.00661071647690343, 0.03360301848234875, 0.02443248199831162, 0.031593157045011006, 0.010222040150048477, 0.06375747772731952, 0.057301088103226254, 0.03105077686320458, 0.041299515669899325, 0.019710551714524627, 0.05116648692637682, 0.024063136727948273, 0.04681130651650684, 0.048537743876555135, 0.032498889336628575, 0.06997738432671342, 0.03204370769006865, 0.023727378941008022, 0.04002879260640059, 0.05904002407831805, 0.06141510020409312, 0.0730758805626205, 0.011829544740196849, 0.024708065603460585, 0.12293584831058979, 0.17493022259856972, 0.09882105980068445, 0.13216586517436163, 0.1100014645074095, 0.233913602573531, 0.06271049140819482, 0.07363063722316708, 0.17492304369807243, 0.14762525420103753, 0.12368250824511051, 0.12482643686234951, 0.08504146563687495, 0.09298985877207347, 0.0772334546116846, 0.21138529000537737, 0.17491818538733891, 0.10409604531845876, 0.1536513101309538, 0.1665515907640968, 0.06616947294345923, 0.2513726885829653, 0.15133339379514965, 0.06583995598235301, 0.07485751674643584, 0.17230016658348696, 0.12929939398808138, 0.1350803223571607, 0.09097710677555629, 0.09065059572458267, 0.2190789950213262, 0.06863399355539254, 0.10587907249906234, 0.11222312386546816, 0.06713698924119983, 0.1365501242024558, 0.07578695365892989, 0.16612300090491772, 0.13844314190958226, 0.1659265243049179, 0.2075340880879334, 0.16092048292713507, 0.11771004301096712, 0.14141864010265895, 0.19430262808288845, 0.12686695451182978, 0.14165390176432474, 0.1184403095394373, 0.1286256087145635, 0.11079577117093972, 0.13461324599172386, 0.10059700307569333, 0.0819040486322982, 0.13144161046615668, 0.0986545676631587, 0.11076217690216643, 0.13689430430531502, 0.2683633682983262, 0.15616790152021817, 0.11679980185415063, 0.2202365757631404, 0.21041882543691567, 0.17886010743677616, 0.188239632706557, 0.0772676867033754, 0.16142034610467298, 0.09882452032927956, 0.10441582530204739, 0.16796525062194892, 0.14376076656792844, 0.06325091740914754, 0.1236440081681524, 0.19230833223887853, 0.21447295003703662, 0.2167116677654641, 0.15980501206857817, 0.1313528445150171, 0.09495936773185219, 0.16459804773330688, 0.07698342124266283, 0.22133729527039187, 0.14322465604969434, 0.15086092986166477, 0.1195215822330543, 0.18596757176731313, 0.13924207618193968, 0.07733157077538115, 0.11937284735696656, 0.15448178271097796, 0.11017664867852416, 0.08001306653022766, 0.1775206657392638, 0.15343223831483296, 0.18263916751103743, 0.12152833598000662, 0.20221625986908162, 0.15427647158503532, 0.13446314047489846, 0.10045753020261015, 0.08010764074112688, 0.10381329977618796, 0.15130152979067393, 0.23622447571584157, 0.05166093539446592, 0.1130976944363543, 0.24135593750647136, 0.22863386731062615, 0.09311303323400871, 0.16223333962261677, 0.1763748779360737, 0.17690965852567128, 0.12760285288095474, 0.12288389966956206, 0.14040689010705265, 0.2487971325005804, 0.185486693999597, 0.17764147211398396, 0.16509003990462848, 0.07027436553367547, 0.09579216768699032, 0.09847459303481237, 0.11944277717598847, 0.1356005822973592, 0.1880715052996363, 0.1326009961111205, 0.152991936941232, 0.11833254460777555, 0.11393684547926698, 0.10783034243753978, 0.12179871861423765, 0.11308625433593988, 0.1674514910472291, 0.15021412314048835, 0.14583605235176428, 0.05123033707163163, 0.10614330082067422, 0.130526958831719, 0.16955116337963513, 0.08853970042296819, 0.13533391803503036, 0.12138329233442034, 0.10856272599526814, 0.1227419094315597, 0.10430744290351868, 0.14159395998077734, 0.2848499779190336, 0.14705931528338365, 0.1113499239353197, 0.20230845920741558, 0.10734905754881245, 0.10506361589900085, 0.2235474602452346, 0.13797341925757273, 0.10966423938849143, 0.12327066463019166, 0.10145768403474774, 0.15054720241044248, 0.15635903126427106, 0.1462342981249094, 0.10137636839811291, 0.10863555315881968, 0.1580587343445846, 0.08508010142083679, 0.10163713619112968, 0.15100950188934803, 0.09599903944347586, 0.2045571514006172, 0.11945201882294246, 0.15353163012436458, 0.07711161686373608, 0.1478370792631592, 0.09619998758924858, 0.25267498727355686, 0.23478383730564797, 0.06842290131109101, 0.16739119642547198], [0.06731718100075211, 0.02772467114430453, 0.05610710735033665, 0.09778781381568738, 0.051317956298589706, 0.05250724498182535, 0.007590615190565586, 0.05404827943337815, 0.0025031551236419803, 0.035179251937993934, 0.04651179098125015, 0.03431765156398926, 0.03357187372499278, 0.10904602613300085, 0.018880791596270034, 0.062485631688364913, 0.04545682169763105, 0.09837069575275693, 0.03943354436861617, 0.025307052569197755, 0.029505131766200066, 0.01860077037209911, 0.024287000697638308, 0.008866810638989722, 0.04216652736067772, 0.07154043723962136, 0.005696889686597777, 0.05571939244068094, 0.01313292739048068, 0.0770319839939475, 0.04588467873899, 0.09908079622047287, 0.017457701797996248, 0.021924769239766256, 0.007087817349072013, 0.015664454183674285, 0.05059003071593387, 0.04574061218383057, 0.036156780019934685, 0.022686796296121817, 0.007455848806005503, 0.004679787321947515, 0.029290799517184496, 0.037304379511624575, 0.05161930048572166, 0.015443850574748856, 0.06707683711179666, 0.03988708735310605, 0.017287118094308034, 0.07784083844827754, 0.0455397827816861, 0.044514733499714305, 0.032613731388534815, 0.014235221947144185, 0.08818171213247947, 0.05987713951617479, 0.04536172501476748, 0.007151064446329006, 0.06149090613637652, 0.04625869741929429, 0.05083285465038248, 0.02034265118917184, 0.04998950347570436, 0.006253849465533027, 0.08291514044893639, 0.07162098613168512, 0.016151633845376115, 0.03181638828079615, 0.029237449701343263, 0.024612517694809606, 0.0611924050109727, 0.04692671175247856, 0.02189855064664568, 0.06624898367694446, 0.025934471848553846, 0.01983430971657591, 0.018294096292395676, 0.01966644524197493, 0.0407438803065036, 0.11565899449799742, 0.02059272357395717, 0.04315967192607267, 0.014524450891518166, 0.07270846063537256, 0.06485292501747608, 0.03929509608341115, 0.059288184690688334, 0.043834766772176535, 0.02225955841796739, 0.02215892997836428, 0.015121315738984516, 0.022016812515045916, 0.05828197832618441, 0.024956378886210065, 0.062243035063147545, 0.026372930999579172, 0.11138376926204988, 0.07115999622536556, 0.03457370014595134, 0.04137861928237336, 0.08030902314931154, 0.05426823673769832, 0.01555985292153699, 0.006031486754571753, 0.07327807042747736, 0.055201497195022445, 0.0038643574392023894, 0.015220890752971172, 0.03624245863673942, 0.016672041366941164, 0.0238023434898683, 0.045235782129956145, 0.042603829609496255, 0.021238130816657628, 0.02196078927123121, 0.0352721976648484, 0.01081578797727291, 0.054346895909735134, 0.07881866847830159, 0.02431537363944309, 0.014977992179670503, 0.0537438241631857, 0.05794535031808274, 0.043111305949943404, 0.017085265800622956, 0.05414942864860807, 0.04336222141448941, 0.07213977365089314, 0.008976416096889546, 0.02348450242009546, 0.03992442374250718, 0.015232308800997478, 0.013707739001672183, 0.03427243059767144, 0.034051133186689446, 0.013474191489097263, 0.04568713344633579, 0.041291994109217606, 0.04703103651159576, 0.015185186240289892, 0.05496248323470354, 0.028233799717522094, 0.04294943463589464, 0.04279804668788399, 0.03782087018979447, 0.04049931253705706, 0.02751143812201917, 0.03632487350010446, 0.022070443922919885, 0.07921804061957768, 0.014574689624298896, 0.02851129848776119, 0.026066567349646772, 0.02083070616104773, 0.06165229569056204, 0.039352635852992535, 0.022808515300442065, 0.03843430316607867, 0.06955035509807722, 0.04896348049598081, 0.03466289357415267, 0.011306283130709614, 0.03415440621652773, 0.02617894801577287, 0.03632493456825614, 0.03605277417227626, 0.007611451304650733, 0.015406917913683822, 0.03524616227618285, 0.03882185183465481, 0.04596186209736126, 0.030373816045799425, 0.032736396949206076, 0.06475302430668048, 0.010155134900872196, 0.013370999035292437, 0.049360688110547404, 0.0515888071219836, 0.06237579722489629, 0.029958813850368773, 0.03343100646244628, 0.06247759783374412, 0.06361271906644106, 0.009812104066700807, 0.008488629146346023, 0.022873503688190664, 0.026680088535483395, 0.028221608139574528, 0.07507907878607512, 0.12185084367437021, 0.06538754275866918, 0.013111155746238572, 0.01653552521020174, 0.03832712855988315, 0.007442838745191693, 0.03617311575050865, 0.010484118363820016, 0.029557555381740843, 0.030767495278269053, 0.007341636095329055, 0.03381016843819192, 0.03976849300254669, 0.06510377262852021, 0.03467852362830724, 0.051169472480458875, 0.03792986666251506, 0.02907756988757423, 0.06101452027048383, 0.01443111670336553, 0.07500989535557372, 0.012881610742104905, 0.05815384377326284, 0.01265742107560592, 0.06988566674824272, 0.023741170165262053, 0.029004379707787718, 0.013171927038846272, 0.01799931184255651, 0.012531563007671918, 0.0573014680828367, 0.03516401882682528, 0.008727311472674566, 0.030856522465390817, 0.009350012389144726, 0.02384759668659951, 0.06476628966629505, 0.07033153889434678, 0.019319364401910986, 0.0038829857699706084, 0.04082481935620308, 0.08156839092927319, 0.0280277880041727, 0.017611705498503785, 0.028027676045894623, 0.02203548070974648, 0.06507730297744274, 0.026451678381168416, 0.053032502332436185, 0.01371452774453376, 0.01142596737814269, 0.014830013870128562, 0.072402108859803, 0.03555191354826093, 0.026120483742228577, 0.011466896610467561, 0.015784841563020433, 0.06413015630096197, 0.06007068484489407, 0.011192354556572224, 0.10661803784647159, 0.018494437149326717, 0.016992606754813875, 0.03779744716095073, 0.006442630630252617, 0.05047520902007818, 0.03576632043612855, 0.01813719015834587, 0.039965193519102674, 0.048200169312102456, 0.014978222881576844, 0.04364266333037189, 0.03181032557040453, 0.056408363327916176, 0.015366609540901013, 0.06378829000251633, 0.07970066900764193, 0.05924818505133901, 0.06069686410150357, 0.06202390217887504, 0.025739532130371248, 0.013470132153348198, 0.003953511003471378, 0.057457429356873035, 0.015356060017698576, 0.06755259194012199, 0.024284761532076767, 0.04354595173416393, 0.0300509724766016, 0.06954171056193964, 0.020291606696056466, 0.05503422474222524, 0.01586612836191697, 0.053107049582259994, 0.000609456814085466, 0.03408375036503587, 0.03033806403566684, 0.039996358632509194, 0.019270859326102903, 0.025538855398605977, 0.04929875821939536, 0.0311504706208195, 0.022898841882124543, 0.02966176139722977, 0.03283862164244056, 0.05667316161894372, 0.01879286702855357, 0.09584864215659243, 0.016271123862160102, 0.052830234436052184, 0.07272096603576626, 0.02844034747353622, 0.07109879236668348, 0.04764659669516342, 0.050454839398818355, 0.016358125622251203, 0.0207705777803702, 0.03725223070276635, 0.009618791984394193, 0.024756261945835183, 0.015022151238684143, 0.07026648095675878, 0.00988536888533937, 0.03396366323743548, 0.04159343668392726, 0.06414429018540041, 0.018266279749306183, 0.06045663556350129, 0.029331681252058064, 0.08428559798215117, 0.035835534400705776, 0.06548600497522525, 0.010064351156220903, 0.03261401637324265, 0.01767003915405699, 0.029925063518541198, 0.027207310244973217, 0.042973729582237344, 0.008873333905025252, 0.057017691167337556, 0.040560787809746604, 0.007503876362794212, 0.031055764095591645, 0.015866469325763837, 0.022279103619179556, 0.0352826369261103, 0.025979884501014436, 0.011286704002746513, 0.0728285274069224, 0.03891314872141395, 0.01625947341588991, 0.03144849677171026, 0.06884103494563273, 0.08485655127359287, 0.00946740318821477, 0.031356711339737685, 0.029888717790267298, 0.020946742434586798, 0.038572720917207856, 0.012998792891656714, 0.02255936911595719, 0.03334720399496811, 0.04923846699031336, 0.22923800774982997, 0.2126491293311119, 0.15258712294910634, 0.14719696289726666, 0.09437658078968525, 0.18208354232566698, 0.11816204232828957, 0.09683466210429158, 0.09068219510040113, 0.13042743131518364, 0.13082423859408923, 0.11265875013279063, 0.07782645350588219, 0.21805163872029099, 0.15318557726485388, 0.12810680083930492, 0.0811949795378106, 0.14760193973779678, 0.05884447028594358, 0.13454882587705339, 0.10543592127838305, 0.07904513632612568, 0.09774922552917685, 0.149034123601658, 0.10224153447364058, 0.16740602920097963, 0.13338899239897728, 0.11146248610956327, 0.11000152557556118, 0.18832651233034475, 0.06560558320156165, 0.17395176153097833, 0.08238043449819088, 0.12005111096160752, 0.1084442673517125, 0.15402523720903055, 0.08608374970832042, 0.14098102572773183, 0.1647203333143677, 0.08027463499456644, 0.09334855952433177, 0.08392163858349834, 0.128950369145189, 0.1521531862339803, 0.1241220903715917, 0.10377406688140971, 0.10293134674429893, 0.0950255316815206, 0.13657290940838201, 0.15531077608466148, 0.15285804841135228, 0.13018690422177315, 0.12785692353333744, 0.1141031137002366, 0.22761139646172523, 0.19683820488197462, 0.10169465560466051, 0.1215518404330526, 0.16489542249057973, 0.15168453566730022, 0.10544261163366692, 0.16034679513956818, 0.11818253408585276, 0.07605237620217459, 0.17929234781435557, 0.1451961395463773, 0.10742280751998935, 0.17714110682053225, 0.102365624957851, 0.07055502797343902, 0.2143677906798465, 0.1773135768515723, 0.2092527901487691, 0.21253626181610993, 0.09441033112151281, 0.07157565320708922, 0.13723746660564626, 0.19883533700236253, 0.12160860667271273, 0.19538516285164015, 0.12148199203823294, 0.14333795782710823, 0.14944123104214668, 0.10689383519015141, 0.1901623566767999, 0.12236882373690605, 0.11412513894694191, 0.0937595549704773, 0.10165446597550597, 0.18155855978173868, 0.13916734233498573, 0.09290312842598983, 0.19524786807596684, 0.09131342265754938, 0.274743877351284, 0.12081605062953063, 0.16897553498191492, 0.171337040407317, 0.23558217446718896, 0.13304340094327927, 0.15922478320343153, 0.13500120517398628, 0.1157631767647607, 0.07361688331833907, 0.1861674003303051, 0.16523599278713974, 0.2799693840954985, 0.07714436296373606, 0.08366895214255367, 0.096057807361441, 0.1063769543543458, 0.0629540311970881, 0.18203172939164297, 0.14813084421413286, 0.07162457558193377, 0.19438918200986727, 0.09612918924540281, 0.17883373956595147, 0.1283354399991887, 0.09065685181745461, 0.1823733989149332, 0.15366102675242083, 0.11227535749120371, 0.10403431220246212, 0.08771241695753165, 0.22331430204212666, 0.11831796967557498, 0.1436916102788278, 0.10344803080494915, 0.11100132656948906, 0.1609944568148681, 0.09240094465868813, 0.16841488863740647, 0.1873802545347384, 0.10159924679568835, 0.08422630080687148, 0.15841975568660668, 0.1251243951597384, 0.10503430997154542, 0.07413588796875306, 0.15201665141752788, 0.0714799254866583, 0.08818383594708783, 0.12523137299077852, 0.13002495148352214, 0.09530802616583449, 0.06527362351438828, 0.10398361206586872, 0.10617758719516651, 0.17772262490221433, 0.17165747178452356, 0.11497456979538713, 0.2061236309153693, 0.19631703570485115, 0.0925561934709549, 0.09082653306956802, 0.09535774242665086, 0.09727323999894516, 0.1836823472487075, 0.13742468798799173, 0.10846055219216005, 0.10730674410504953, 0.10593437310308218, 0.08470503440392868, 0.14004795865288802, 0.18864922358521394, 0.14173231327107974, 0.06606822194797651, 0.13984476455620357, 0.15493246567036423, 0.14374805082167896, 0.15786463261715003, 0.24564018047281674, 0.11013782290475709, 0.1246282910662038, 0.09633032059563057], [0.014816141221672297, 0.01688599194000874, 0.024588270245918205, 0.024748233180227022, 0.06658825797161885, 0.04118716384151152, 0.013607141096144915, 0.06720321425901991, 0.03884656068735889, 0.03422036660569055, 0.008330350675221001, 0.030191151026104177, 0.0523920025942581, 0.023037400429270098, 0.04574740431936724, 0.015612122170361025, 0.04206238580601556, 0.014883361989632249, 0.04257563647947141, 0.04244291163714869, 0.041287939862481186, 0.010700860260320562, 0.02706706214563123, 0.055488673570965014, 0.06887773690479142, 0.02870228573946016, 0.011471033129574997, 0.038519384672066996, 0.032377421390265226, 0.01669450257239597, 0.06251670180686883, 0.04647025785275868, 0.04398701645966087, 0.002218355528644419, 0.0413842205889523, 0.033123328150915246, 0.004183645908986884, 0.042877537065318654, 0.05650788066642625, 0.045395095366984606, 0.04179568083158561, 0.07080728015197174, 0.06487417673426014, 0.0373239450688873, 0.04806629435292312, 0.07712760993412562, 0.0224759517171021, 0.006573683307838759, 0.029373217773224627, 0.052042536703603606, 0.019243629715804542, 0.05718024780175515, 0.020287023192005496, 0.04244223649480513, 0.02080023824237287, 0.012863952716413354, 0.02417852669688208, 0.01887287987795259, 0.0681422253006271, 0.05225994271625366, 0.041871069464832544, 0.008657363842108419, 0.005663858601889972, 0.05853036964046104, 0.025077787460759282, 0.030985389836132526, 0.02073049502048109, 0.034120387863367796, 0.024684238846280744, 0.042260545172861645, 0.030337521207651923, 0.04568482642727239, 0.031887162875916274, 0.03800639523459332, 0.027476228939901506, 0.04926504520699382, 0.020160674882520522, 0.016062884857611995, 0.0309152700273054, 0.032749682664871216, 0.04985966919256108, 0.04487221288893904, 0.042991018654512506, 0.0256343541134681, 0.016839702281036546, 0.03558689881382244, 0.00808379055732595, 0.030746067142380134, 0.030877258495560715, 0.004768454037340624, 0.046861297584005764, 0.11021885355668408, 0.008458094222338071, 0.028001764489869987, 0.012954724586701818, 0.02994143996121628, 0.02268662496602961, 0.027637350472754667, 0.00859463497597192, 0.022858372357274805, 0.04469273698383144, 0.060208359600177834, 0.03760663293568151, 0.023677150386252573, 0.017610472261107395, 0.03595674789643713, 0.029969429530735527, 0.02390168440927352, 0.034206253077302656, 0.036788706468152146, 0.01712900586426258, 0.057964159308799675, 0.036697243340313435, 0.029630996619484255, 0.05101898359134793, 0.016475295049271414, 0.025246162532961795, 0.014702793643144625, 0.007483915558883122, 0.0171413704686399, 0.042194014814283164, 0.01623743459848421, 0.03336496464908123, 0.059743393478649, 0.095130555331707, 0.04607315201844488, 0.055166946191872866, 0.04713322388540421, 0.020581295347905586, 0.03168958704918623, 0.02949483160461698, 0.03012214062203254, 0.0382640994420009, 0.05966564015086208, 0.028259950457140803, 0.04538541606494358, 0.10139965571995292, 0.03484890716416495, 0.11676735430955887, 0.07129009852984122, 0.009395021313269223, 0.0074346708799047125, 0.008961402661433178, 0.048376842867583036, 0.008096786199270614, 0.055520744528621435, 0.03829016536474228, 0.024322701817644492, 0.06410361201103244, 0.024533805936308842, 0.05473789832155619, 0.04500976550791945, 0.05846261113349881, 0.023381037704114403, 0.06812678862895284, 0.057947867683001926, 0.020597710806344236, 0.07744150023375239, 0.02398351064350988, 0.027232840125049864, 0.05696982052177191, 0.02197239900540028, 0.027665950723790696, 0.09538836471204247, 0.010491212447439986, 0.03058138330067907, 0.004544398805592209, 0.055478573577212434, 0.0032804553671407378, 0.007798674383333751, 0.02840420021675527, 0.057044011540710926, 0.0803302273686443, 0.04344544034185154, 0.029658294083284478, 0.06166919121252639, 0.06535369743193899, 0.00511458153570337, 0.03501334334058421, 0.03149366345522659, 0.034323531069925854, 0.026627400291285346, 0.030831738973834684, 0.021103256714663336, 0.07415852389697518, 0.01687420917940991, 0.05618576991504856, 0.04010943988604205, 0.021868189597236257, 0.03918054919423802, 0.07005462196788617, 0.02826506152216877, 0.05525604462517159, 0.03942513392706003, 0.015610371550012912, 0.048392272753907103, 0.018969016415732246, 0.030556263934288706, 0.03573122660496405, 0.01915631752594241, 0.019673739493425404, 0.01691509430695857, 0.03626501653343439, 0.037912353673683744, 0.008066233463718422, 0.04755978492487754, 0.03829140369115131, 0.020188788284680674, 0.012773782197785164, 0.0077247395113642725, 0.01311084277196122, 0.05047196562268904, 0.029518464979316508, 0.023306551522442272, 0.11249007311250482, 0.043871400877833366, 0.05722609641296523, 0.022764522482507994, 0.03752961581838982, 0.009768835584899145, 0.03146762128121086, 0.05499077814498118, 0.047045441810041666, 0.0241051193858896, 0.02817141860058265, 0.03439297912908452, 0.07872667948582343, 0.028675822873732874, 0.01852842666474836, 0.021978492249867747, 0.009163656138948031, 0.011926259729079902, 0.05543593782931566, 0.04926803076107587, 0.01693429854432387, 0.0371988910649504, 0.06716369637953383, 0.011439693293401172, 0.042347275518945286, 0.01977443409019283, 0.01929957153541701, 0.03132179053500295, 0.012129331689461, 0.027016243265409554, 0.05528928605573518, 0.05336106934451631, 0.009653013049890953, 0.02583411312662065, 0.03319213499448129, 0.025761145167052746, 0.08348703011870384, 0.014713014076863016, 0.02643628411793283, 0.050105193696383915, 0.04352754647178309, 0.020584065467119217, 0.027259635472936288, 0.011101919409286762, 0.024561140719535093, 0.053305595714066706, 0.05165063523288284, 0.067875588179699, 0.03657118849722402, 0.027784083670537387, 0.013523077392684562, 0.009996095622357513, 0.02510473717536245, 0.026129776279308965, 0.028626462843801295, 0.02792949372503374, 0.05684916003208075, 0.05029275095356362, 0.04274485972044723, 0.11184190253594092, 0.014891821624977248, 0.028862989973276854, 0.018465197379035608, 0.047007321712694, 0.0892269206898553, 0.027547405567020178, 0.004006129697830017, 0.03452343427176986, 0.017936532086293613, 0.026467900457126752, 0.04595477819176657, 0.01771880207317216, 0.0226336398627609, 0.010337252851708658, 0.057066627112882476, 0.03385748607771737, 0.0137997644654076, 0.0626986984695707, 0.04183253885379859, 0.014872303565165826, 0.035590800390179665, 0.025838969741016626, 0.022851463174447417, 0.06021050377083676, 0.029176832775452306, 0.022269575291180184, 0.04584206673981888, 0.02102511831825333, 0.029894390343023197, 0.038750480128718276, 0.04757333866187504, 0.02309714034864945, 0.016314612867842828, 0.029250219730394225, 0.03980592777952552, 0.02545114965843303, 0.07771271746605635, 0.027869658810751777, 0.037126301388655386, 0.03187458962202072, 0.0702237943187356, 0.00664841673070831, 0.028282097840149487, 0.05088953607316528, 0.02592062294882323, 0.003325919121769922, 0.0418104457535914, 0.045158608949610164, 0.01520649902522564, 0.03514645494786756, 0.023882083228922317, 0.047345584990190606, 0.0644523450838668, 0.03638122244072812, 0.10237156213926417, 0.014588373979287488, 0.031117324185158526, 0.043355439456978014, 0.01852118330342429, 0.038209250063768456, 0.0245423877079572, 0.05122998423342194, 0.01964923589756446, 0.023571536410599947, 0.024724306339131932, 0.11569882450359208, 0.07474291896713631, 0.03562645401273455, 0.02973312631781612, 0.06602693309209176, 0.03335262209709201, 0.05422756874135562, 0.004024016729090363, 0.007350618202638413, 0.05011398411755051, 0.021876052121764848, 0.04250689748940723, 0.037434681983930726, 0.16172385481851442, 0.08321879844048194, 0.12603546412927763, 0.2816820336239678, 0.17282827038850102, 0.10987923999450036, 0.07690667214670352, 0.14177174972636358, 0.11585206485220365, 0.11051592297319855, 0.11376698780804873, 0.07897646858223847, 0.10358059619154249, 0.11095587829393999, 0.2156601691884654, 0.14129484817385674, 0.1129391547292471, 0.1562622178878103, 0.07714749779552221, 0.19182027557066508, 0.17803701731775487, 0.08223109572593655, 0.12531369285924093, 0.10996468790939876, 0.10831632278859615, 0.14385367158268178, 0.07923613714852504, 0.16775020930383885, 0.16012863256037235, 0.12075457535684109, 0.13122409928057874, 0.14168656644012245, 0.2024912836828402, 0.1440763667758022, 0.07706027890422515, 0.1952516000185694, 0.11551344873649733, 0.12378571342144694, 0.15724418019609793, 0.16198985411652497, 0.1506896269108568, 0.13919962703117303, 0.13695130124688148, 0.1275733094662428, 0.11042691274945225, 0.20525187626481056, 0.13017135219914572, 0.06710581055709294, 0.09988350314753396, 0.19603076178048337, 0.15259453255150998, 0.13370911165007524, 0.07108988320188862, 0.11860136661146368, 0.1538766651813473, 0.1328149517732007, 0.2061437155519213, 0.11035398380564791, 0.0926943432007517, 0.10867964436433145, 0.16293111789439405, 0.13980163687041827, 0.05753295708979879, 0.1789192214076008, 0.08015655633062124, 0.0892051329304065, 0.12001178307192666, 0.08991407988859074, 0.18164448945650033, 0.1586574057915381, 0.0822676687634417, 0.12141179080520358, 0.14451824235064642, 0.1519260805632387, 0.13978342499051774, 0.15867029795689241, 0.12912194351000444, 0.08513821794518403, 0.13525013253092766, 0.09995961442057576, 0.12207110971212387, 0.13758851348289422, 0.10031812518302884, 0.118691869612251, 0.11481146354760442, 0.11019400560430118, 0.13563726390046732, 0.10874324345162936, 0.11680957275841918, 0.05822087624775512, 0.1958444496350629, 0.2758114572082247, 0.07846675307622977, 0.07807928922453097, 0.11665293973471437, 0.1120207372254559, 0.1309368618364845, 0.18168417018439087, 0.07388795127293893, 0.08867208260510649, 0.10280864047152655, 0.17183091890599045, 0.18723067827522755, 0.10908550330038581, 0.10267429732318435, 0.15877830716116087, 0.09337542272572007, 0.11578969391328947, 0.11179540253111295, 0.09667251259088516, 0.12124966164784771, 0.10275874779160533, 0.1499115100928715, 0.09765573018895728, 0.15046131344778196, 0.09163991335247244, 0.10193928104958364, 0.11756719781884126, 0.07454013199146305, 0.09629957617393561, 0.10971301248563187, 0.08649644149201256, 0.150740937728967, 0.1340342927724123, 0.13734691430415424, 0.1321994119456836, 0.14591184471334728, 0.1819048569138561, 0.1117414589971304, 0.13347421639731952, 0.10010231033499752, 0.1459554202322449, 0.07130581340087311, 0.14300842050995144, 0.12461191123085362, 0.2064528153943164, 0.16420075190918787, 0.13884150981903076, 0.18134692470942224, 0.1364301863525595, 0.052585636132529805, 0.126344319699066, 0.08027510318372931, 0.13241761523698056, 0.13853779754468373, 0.14712738591645444, 0.12982880058033125, 0.18501953620995792, 0.14999225576009068, 0.07405090824301754, 0.16116337132241043, 0.16215624447379792, 0.21543336207313196, 0.13259037025272846, 0.1372282113879919, 0.1942887452564069, 0.0753404979727098, 0.12962654286197253, 0.09846185014716216, 0.0866889486621533, 0.09064945578575134, 0.12748366141957895, 0.09942140044378382, 0.18018586986831256, 0.11622368491121701, 0.11901645362377167, 0.1278475054672786, 0.22241476816790445, 0.08838090965790407, 0.14221158969615186, 0.09624969706471477, 0.09856626990118197, 0.19142490678599902, 0.10109417925455741, 0.14684233335512026, 0.168149255748306], [0.016094245049836378, 0.004497848758806607, 0.016266363939004283, 0.03290901625795024, 0.06942270909036909, 0.07673284504562616, 0.05767979206783431, 0.027143346445102776, 0.022224786890936748, 0.048098636724586995, 0.022659018768795898, 0.024942436687914387, 0.03723928425461054, 0.05237128692013877, 0.037302469435547075, 0.03697657585144043, 0.033436346533043046, 0.025593523268720934, 0.035963757163179774, 0.04175635972725494, 0.04175041236781648, 0.036143107539308925, 0.04454856525574412, 0.028552909647779803, 0.0604091381121959, 0.043066431036485095, 0.009213134912507874, 0.025164159879620587, 0.02825899881177715, 0.07418434215443474, 0.06722800114325114, 0.056013442376362424, 0.03875761831711445, 0.03781586938670703, 0.04451427888125181, 0.02873728796839714, 0.02814440442515271, 0.021810783838321055, 0.03078007871018989, 0.021663558702649813, 0.01171078414855791, 0.01391036482527852, 0.02677561778442136, 0.024737167970410416, 0.0923087860324553, 0.06156590461198773, 0.06366426737180778, 0.015115487123174327, 0.03232400372092213, 0.02653289902290063, 0.027879936919946755, 0.0135444444604218, 0.022596713987046053, 0.026152848166280558, 0.04569869568305356, 0.05872878006526402, 0.015372980984726121, 0.07867331270660673, 0.0556077123619616, 0.073782690135496, 0.029295301597033228, 0.025445363451061503, 0.037568251602351665, 0.02282184172820832, 0.05736165413899081, 0.03607510815241507, 0.039336907411260266, 0.09339738011892353, 0.012300900965263801, 0.03197779819103224, 0.08502940128424338, 0.041342504256005795, 0.06081108868654285, 0.04076302517205477, 0.037981160517249785, 0.005850637240135776, 0.015583141939714551, 0.061411727885050435, 0.006270102923735976, 0.032045794185251, 0.03315021849370428, 0.021819676039740443, 0.04465924449531095, 0.025107737996482422, 0.043981119990348816, 0.01396591987993036, 0.029355039820075035, 0.03273626124220235, 0.012932667109583105, 0.039007875602692366, 0.017065047153404782, 0.03176293329202703, 0.012868903477543166, 0.0538800739949303, 0.0413849262653717, 0.02935994223558477, 0.03428282914683223, 0.0672830439039639, 0.06522597000002861, 0.06213045931820359, 0.03904069973421948, 0.04734603621597801, 0.043784711243850846, 0.08896519616246223, 0.06078877845512969, 0.018418831384873817, 0.04010149424097367, 0.03952819661104253, 0.02940514963120222, 0.04832611558958888, 0.046733468371842585, 0.06709174452615635, 0.01644189585931599, 0.08032242421592985, 0.010135781385802796, 0.06764823145100049, 0.04291242394330246, 0.03978531388565898, 0.0065932357184855, 0.02814259104031537, 0.01902055454307369, 0.026732671606753553, 0.0414447153785399, 0.051181614864617586, 0.056128983319337876, 0.022623053020132438, 0.009815360186621547, 0.03611260399754558, 0.050326674311820946, 0.03577689540439418, 0.01845980981098754, 0.04388824550967131, 0.024458893973912512, 0.012630606219837708, 0.024598414344446998, 0.027567232360265086, 0.05679945055661457, 0.06356200535914727, 0.07080175687691995, 0.025514972662287097, 0.023924211771892648, 0.02137899468652904, 0.04194087714755109, 0.05279400745140655, 0.0342544290636267, 0.05215540421860559, 0.06692812937710967, 0.03318134289500969, 0.0031026997603476048, 0.02341155651291566, 0.02333956055476197, 0.055002296276922734, 0.0537925701189254, 0.035841451226068397, 0.029460813251457045, 0.0350094315862017, 0.057393986332629404, 0.007663695108411568, 0.05559893551149538, 0.053428641254348416, 0.055366533874933205, 0.0147099352242159, 0.009410778592739786, 0.013893205522825676, 0.027366250287741423, 0.004562592449864107, 0.01844164712487587, 0.06410971204085009, 0.043828927978341065, 0.0634653005482895, 0.0702638007434351, 0.02545690702806626, 0.022753718508673564, 0.01827408459835819, 0.05120483433295574, 0.03427441531260099, 0.023522352799773216, 0.04361715041367071, 0.041163679744516096, 0.018989129890022532, 0.03209885223103421, 0.024579247426507727, 0.033100994170776436, 0.0464710008486041, 0.045243710811649046, 0.04346492786758712, 0.042236375755497386, 0.018630614038556814, 0.02871014317497611, 0.03535191195883921, 0.020357483964679495, 0.05010014878852027, 0.020411815959960222, 0.02938275458291173, 0.0906635828848396, 0.032654867574040375, 0.03401707751410348, 0.03625915399087327, 0.08886556686567408, 0.014002404707883085, 0.022521323657461574, 0.047560029197484255, 0.013587318543743874, 0.07617523853800126, 0.018288735865748355, 0.03289806470274925, 0.03462875308468938, 0.021661775851888315, 0.006506638958983655, 0.03305930158655558, 0.10926521330007485, 0.16352768588278974, 0.013040231873414345, 0.06375576781907252, 0.017379658396488855, 0.06762002475027527, 0.059676299936005046, 0.04480085136102779, 0.02123288743730102, 0.08345952230904784, 0.011780568082550806, 0.05023836297914386, 0.015111585546817099, 0.026305367571434805, 0.01824304162125502, 0.019938278244808316, 0.03882161095472319, 0.03533589853239911, 0.03825080694098558, 0.05957087595015764, 0.05247798655182123, 0.02689650558334376, 0.04469261824020317, 0.03757873157571469, 0.02670375074792121, 0.04712448435436402, 0.05018864332565239, 0.033605009982628484, 0.03769141588626163, 0.029057498821722608, 0.02891238732263446, 0.03386231724705015, 0.05039045321089881, 0.025509150831827095, 0.029781322660190717, 0.006816417336397405, 0.11829614798937525, 0.03853121153744204, 0.041542020692889176, 0.023688052747664706, 0.008582059177570045, 0.03136343901444759, 0.04732548678293824, 0.02106751488255603, 0.02063421599034752, 0.0320553818850645, 0.032408603467047215, 0.041860762517899275, 0.04186617722734809, 0.0982402338247214, 0.03408958237352116, 0.04263060799400721, 0.0235409853713853, 0.04378372397539871, 0.06266469707978622, 0.037647925184241364, 0.01582615077495575, 0.04784974329439657, 0.0721994372350829, 0.05102716333099774, 0.04711945980255093, 0.044683983882090876, 0.054540855144815784, 0.04756710971040385, 0.08356079366058111, 0.03240638465753623, 0.03214780853262969, 0.03992650005966425, 0.03175208351707884, 0.04026119763563786, 0.05043797101825476, 0.031554528046399355, 0.025307303627154658, 0.015490611815559012, 0.014732783194631338, 0.035677137185952494, 0.04405985380123768, 0.0396160160058311, 0.033856200253857036, 0.05035657735009279, 0.04407521922673498, 0.04980167819719229, 0.012034382587963981, 0.03580379931788359, 0.04450783279857465, 0.04487188719213009, 0.044605429882981946, 0.03306986976947103, 0.048294224443712404, 0.033262380332286866, 0.018251002533361316, 0.04900566841076527, 0.05300580197945237, 0.012500826219495918, 0.04141713971538203, 0.007839983595269067, 0.02204924139992467, 0.06131105364433356, 0.06715479400008917, 0.0323174897847431, 0.061609541199037006, 0.012484644007469927, 0.05449398533840265, 0.058948964678815434, 0.01886149406033967, 0.04554693454078265, 0.05479372479021549, 0.04775670596531459, 0.02075815380417875, 0.06532289194209234, 0.01236176725277411, 0.03544471858601485, 0.00863329620499696, 0.03234069568238088, 0.041681622487625906, 0.051386311916368346, 0.035354843230119774, 0.023313654087749974, 0.01706892328469881, 0.01927614850657327, 0.05310855932267649, 0.03865835203656128, 0.0048887778040287745, 0.05548339456851993, 0.0406977433179106, 0.048149017949721644, 0.023200469357626777, 0.038179353810846806, 0.02796274533362261, 0.04131051811522671, 0.017653184344193766, 0.04823404856558357, 0.10206740203180484, 0.017457708583346436, 0.05902933715177434, 0.03591004093842847, 0.034041274072868485, 0.02527253040378647, 0.04568050755187869, 0.04982623437951718, 0.032622708406831534, 0.027764820061357956, 0.09587793451334749, 0.05729565303772688, 0.09739823972008058, 0.12781687639653683, 0.15055561624467373, 0.10269584759537663, 0.11082687521619455, 0.17901422988091195, 0.20730147271284036, 0.15398206881114415, 0.10092702215271336, 0.15428504826767103, 0.11906399178717818, 0.13100979078028882, 0.12825929479939596, 0.12554758388016904, 0.0859550858980843, 0.11088890688759939, 0.14211104437708855, 0.13967279664107732, 0.16982630932969706, 0.11860429788274424, 0.14432354351239546, 0.0692302222762789, 0.07954959318573986, 0.19184738983001026, 0.07927452187452998, 0.14553675055503845, 0.091041608314429, 0.15020876271384104, 0.1690215803682804, 0.22032903294478143, 0.08964408401932035, 0.0733322175219655, 0.16464524662920407, 0.2576712306056704, 0.11539022677711078, 0.13669241299586637, 0.11298590579203197, 0.19865632589374269, 0.22084176114627294, 0.17894022885177815, 0.16086516875241483, 0.14069536248488085, 0.1512901982558625, 0.24836265295743942, 0.1291610135563782, 0.12081335006015641, 0.09483046643435955, 0.1871907939868314, 0.14801957804177487, 0.07890560238489083, 0.1383899176227195, 0.1480469230030264, 0.1294840776494571, 0.10583746473171882, 0.11160855434302773, 0.15725373396916048, 0.10818494483828545, 0.18079627997108869, 0.12538191277001584, 0.1747793706932238, 0.08758721367589065, 0.09811254710491214, 0.08721216022968292, 0.10162315836974553, 0.14489681060825074, 0.18567272116030964, 0.11560837578560625, 0.14449392365557806, 0.16799692463661942, 0.1102253199954118, 0.13069256208837032, 0.10971058333026511, 0.12548591861767427, 0.08966081669288022, 0.06822409055062703, 0.10568771883845329, 0.13982814044824668, 0.10577941606087343, 0.11933117173612118, 0.13580974750220776, 0.15150994860700198, 0.2032169226024832, 0.14820971712470055, 0.10947203077375889, 0.09206071362963744, 0.10587597837937729, 0.12897877262106963, 0.05338035670242139, 0.13974143724356378, 0.14382756155516419, 0.14508612187845366, 0.20618364055241856, 0.22015011683106422, 0.16801512294581958, 0.09827270851071392, 0.17461931785302504, 0.15561553330293723, 0.13362562470138073, 0.10633124823548964, 0.1420557844851698, 0.121976657637528, 0.2375253630535943, 0.20730331832809107, 0.09809523089123623, 0.1061166547504919, 0.09382020921579429, 0.08614268047469002, 0.25112952877368244, 0.12038053971316133, 0.17033668980002403, 0.18392913043498993, 0.14585563487240247, 0.09493197527314935, 0.11669374683073588, 0.07152311424059526, 0.05531774381441729, 0.0643035898517285, 0.15935871244541236, 0.1692690828016826, 0.0650759187660047, 0.13192680371659143, 0.11244139501026698, 0.20835991948843002, 0.11927179992198944, 0.10706840189439909, 0.061468745182667456, 0.17816603396620068, 0.06380855105817318, 0.14602491578885488, 0.08777287442769323, 0.12957110655094894, 0.13187408154564245, 0.16133509496492998, 0.10719979341541018, 0.16036932250218733, 0.13590506810162747, 0.18050802472446645, 0.13579590538782732, 0.12058237673980848, 0.10104134851800543, 0.13906725841973508, 0.1373785204653229, 0.06530056135462863, 0.14833177200385503, 0.10304573417774268, 0.19635564434741223, 0.11704973344291959, 0.13457737863063812, 0.11168472668422119, 0.18496851037655557, 0.17883369885385036, 0.17575766891241074, 0.10621131038559334, 0.1336030430559601, 0.12345518544316292, 0.15583299020571367, 0.22160945566637175, 0.14291985811931746, 0.1722593323460647, 0.12381277339799063, 0.07454518029200179, 0.0882280289328524, 0.11134052622531142, 0.1041361331673605, 0.22400882334581443, 0.11252624581434897, 0.15862438827753067, 0.12530024429517134, 0.16818059049546719, 0.086889713603471, 0.1202371245516198, 0.10875129766230072, 0.08504970983735152, 0.12870368095380919], [0.04490495898893901, 0.03709079704380461, 0.0038339573740293936, 0.03684872967590179, 0.033011471653091054, 0.023853739124855826, 0.04865778350670423, 0.009660449793695338, 0.05511336906680039, 0.029379952233284712, 0.011875981980535601, 0.030189278269452707, 0.014467599834980709, 0.023486960413200513, 0.05201996523620827, 0.040501151366957595, 0.04321632620745471, 0.023239032199074115, 0.03896122292748519, 0.023592280922457576, 0.02788732955897493, 0.0082765453927485, 0.04387423036886113, 0.02085850404442421, 0.05827985451157604, 0.030191198523555483, 0.03853124885686806, 0.020887864254681126, 0.025400149270093868, 0.051886643283069134, 0.01179653316337083, 0.018648079529936825, 0.016286214480974844, 0.030115697932030474, 0.05374112020113638, 0.0463222998992673, 0.036956026418400664, 0.04631065623834729, 0.05168684186147792, 0.03992273419031075, 0.028596234108720506, 0.059394450059958866, 0.015984875382855535, 0.01497056391755385, 0.03956218782280173, 0.029199078546038697, 0.024346111275787865, 0.05989283403115613, 0.05878564129982676, 0.13687641812222345, 0.05576217746628182, 0.031517449500305314, 0.03692991299820798, 0.03995210797126804, 0.026390355778858066, 0.038330809612359316, 0.06705492721604449, 0.01041134209039488, 0.017821043729782104, 0.017382021394691298, 0.02019631493437503, 0.07509070887629475, 0.05072763083236558, 0.016443263107378567, 0.05268934681745512, 0.03672522612448249, 0.06473602700446333, 0.06326151612613883, 0.03255415940657258, 0.00918320897367916, 0.08564570107098136, 0.028752426084663187, 0.031038871966302395, 0.004226802008426083, 0.020551524623962383, 0.03961227388520326, 0.05168975956205811, 0.028935501618044715, 0.05043773692367332, 0.02465845112289701, 0.004505487366779042, 0.025275195350072215, 0.012413368144604777, 0.07762154950095074, 0.04974490517218198, 0.07604321597942285, 0.021825574205390046, 0.07178335956164769, 0.06568338402679988, 0.027594295729483877, 0.021172049987529005, 0.016267432631658654, 0.01627718487621418, 0.08841431393687214, 0.03857829508238605, 0.034545361130897484, 0.07936763044978891, 0.03936392328302775, 0.030542147013225725, 0.05147175643859165, 0.022225555331845368, 0.05338642280548811, 0.0560756063620959, 0.009403748121777815, 0.018336650616090213, 0.043586148148668666, 0.01755586715548166, 0.018829155081350888, 0.03580192656123212, 0.02100385133443134, 0.03846998732270939, 0.017530474678746293, 0.024522126652300358, 0.01350578577590308, 0.0499940055555531, 0.02783154889142939, 0.044650213194212744, 0.04324240909357156, 0.05492062780207821, 0.04568536246993712, 0.0771082988274949, 0.07008883370352642, 0.034102796843009334, 0.024611845945141146, 0.012987851514481008, 0.04991205209600074, 0.022376894086067165, 0.03334235246958477, 0.0465817004442215, 0.06897532381117344, 0.014403023657255938, 0.030979707105351344, 0.01828228808673365, 0.06153286674192973, 0.040252580240901024, 0.019123104933117117, 0.05113015476880329, 0.02807909882228289, 0.05000882476036038, 0.0011829177695160198, 0.002440763616635065, 0.022840028163045645, 0.040823201050183604, 0.03064656337457044, 0.02129140429730926, 0.03282843004646046, 0.03220916845436607, 0.0381066114641726, 0.044586868557546816, 0.06272788226072278, 0.0541613097967846, 0.02393863912272666, 0.039368479645677974, 0.06592769734561443, 0.020544802038265125, 0.04111230446557913, 0.0567239804991654, 0.04208431945049337, 0.0391812616560076, 0.05638602934777737, 0.05190048200477447, 0.05559971582676683, 0.03625792584248951, 0.035959543460713964, 0.03156880781586681, 0.028642181107508283, 0.050949881585048776, 0.03439066193199583, 0.027323080193517462, 0.022016988934150765, 0.009287511680408247, 0.06476836598345212, 0.07622074109635182, 0.0653291887470654, 0.04886395297944546, 0.030260242854378054, 0.015424363049013274, 0.02273137095783438, 0.04502758044483406, 0.03301402633743627, 0.05793180675911052, 0.020553965653691973, 0.05859506116913898, 0.029913335040743862, 0.02689050733377891, 0.030086768591510396, 0.03579212851556284, 0.03023217186065657, 0.008557390188798308, 0.023847035198871578, 0.07390828018209764, 0.056650213564613035, 0.019729986653796265, 0.03458876362336533, 0.07248942953135286, 0.013465368837517287, 0.021575878407540064, 0.013999446295201778, 0.018847271966348802, 0.010786127515270241, 0.031238656424518143, 0.02924818073266319, 0.06318673478173358, 0.00453900360402518, 0.015556131156959703, 0.040133673764233074, 0.014307565654494932, 0.020922459362606918, 0.029951919934579303, 0.030432974121400287, 0.05769782752862998, 0.014995573022003685, 0.0519266700638192, 0.07497518828936986, 0.006970114847977779, 0.00580103845069451, 0.03469470329582691, 0.04128142592630216, 0.00640703977218696, 0.04269627322043691, 0.10757701817367758, 0.022457078265558397, 0.06248023733496666, 0.023479026642494967, 0.09433150570839643, 0.06916770205966064, 0.03548986152080553, 0.036995890350746255, 0.060989753742303164, 0.0321862611121365, 0.05241456727630325, 0.03577994541930301, 0.04554737898121987, 0.030364150314458778, 0.03718929657978671, 0.005827220996642219, 0.03707069544387715, 0.027657888031431606, 0.005363722631175603, 0.018495848502165506, 0.010049543825776448, 0.027130710426717997, 0.030338559366230453, 0.015564994520640798, 0.04965368631694998, 0.013063094262698931, 0.043023361026176384, 0.03699156129732728, 0.024368229821058254, 0.03134262156007545, 0.03290952515921422, 0.03401046858302184, 0.05640876027090209, 0.06227141818297761, 0.014106490283406206, 0.044061991186546426, 0.024077033125130192, 0.10613911425960915, 0.026011687437338487, 0.04211249900981784, 0.030427247285842896, 0.06592213335846152, 0.03098045688654695, 0.012574573646166494, 0.061214152058320384, 0.03447293430300696, 0.01610573604037719, 0.051835644591067515, 0.008285061855401312, 0.031725892065359015, 0.04051121404128415, 0.03917406579213483, 0.08160927944949695, 0.06988893050168242, 0.026568352477625012, 0.04379473999142647, 0.05112467220585261, 0.019025495974346995, 0.005535223629392151, 0.11837868498904364, 0.020208341967580572, 0.018202743426497494, 0.02822923656952168, 0.06274705087499959, 0.018675432972876087, 0.009814188865545605, 0.002253946810794462, 0.05464548524469137, 0.03651935859982457, 0.0634003443909543, 0.027453718540657843, 0.033066192109669955, 0.03432400604443891, 0.03167379753930228, 0.06763381936720439, 0.009349723163593029, 0.029880361631512642, 0.03186754982120224, 0.014687387505546212, 0.03714232160044568, 0.028508424891957214, 0.05279903878856983, 0.026976386118414145, 0.08396593334951571, 0.012026952629509782, 0.05344559784446444, 0.009531189720811588, 0.011209172047009426, 0.02923638779403908, 0.05989368219992944, 0.032732427519346984, 0.022557613406596438, 0.06726106615470988, 0.05565774753423674, 0.04503311389791114, 0.07136633193918637, 0.016368958433823924, 0.010037390415423682, 0.049456249589898756, 0.01624154143168458, 0.02643578200201903, 0.03098386652501566, 0.008390846312977374, 0.016023791062512567, 0.03418985627857702, 0.06496049317398242, 0.01617312304941671, 0.04725257819518447, 0.019291702225538235, 0.00994003505911678, 0.01092734422335135, 0.03228403122297355, 0.05439189974484699, 0.0503352849212076, 0.07165640565965857, 0.04011185207803335, 0.033073391366217814, 0.04429804673418403, 0.012037280780662383, 0.04713232143382941, 0.09039649793079921, 0.020314456362809454, 0.035884975854839594, 0.047857146111450026, 0.019785711342202764, 0.051646007624055655, 0.048796696588397026, 0.04604364592315895, 0.08439018736992564, 0.03858408298609512, 0.07287186543856349, 0.010511781388361539, 0.103920420099582, 0.13629290514758655, 0.08225321596754448, 0.06826278740274054, 0.18544561548956803, 0.13143587005989893, 0.12756287359765597, 0.0949233171663114, 0.12122394517064095, 0.12309401482343674, 0.21670713515153953, 0.09476891652281795, 0.12658946083060332, 0.17988888866135053, 0.13035495020449162, 0.13317498245409556, 0.11152833114777293, 0.17520061880350113, 0.13178751404796327, 0.22698323588286126, 0.09338116991732802, 0.13596116937696934, 0.07651111337223224, 0.13909222850842135, 0.17037950535970076, 0.10870761357780014, 0.09905190419937883, 0.11193586606532335, 0.09430905976997954, 0.18970990952636513, 0.1214872846113784, 0.11478037307304995, 0.16562545831714356, 0.09227557852864265, 0.1362349853983947, 0.13844652101397514, 0.14015940124435083, 0.13537833493735107, 0.12180373977337565, 0.10824633190142256, 0.1403088825089591, 0.09478553384542465, 0.068712676476155, 0.14981196900563581, 0.17187787352928094, 0.12329849813665662, 0.11460566387644835, 0.14771733140306814, 0.1917445646332843, 0.19539631796734674, 0.20645779584135326, 0.10238413539315973, 0.12840174644121102, 0.1728254205414227, 0.14155771264008113, 0.15422909627003328, 0.1841619357998882, 0.12563886041087763, 0.11635088308581285, 0.09358837415597268, 0.11432191410234996, 0.11782369762659073, 0.12451961689761706, 0.12074126249977521, 0.124054969687547, 0.11946109762149197, 0.10990327370486089, 0.14949711518628256, 0.10853253118693829, 0.09593985083379916, 0.21756518339472158, 0.14228826415325913, 0.07952807005494833, 0.08644387538411788, 0.14227375707456044, 0.11418703491134302, 0.12627396918833256, 0.15049727580377034, 0.13067392951675824, 0.12171231396496296, 0.04302286230293768, 0.16427635428096565, 0.07634546261812959, 0.1477322998855795, 0.09902785691831793, 0.21414597758225032, 0.10001874874745097, 0.1267830061593226, 0.11211615960512843, 0.111524076733206, 0.11266418519829001, 0.23527713226420538, 0.06412016148013727, 0.19656827008085592, 0.14921484461852483, 0.09950908073889357, 0.1373813296003001, 0.1303924596203225, 0.10823067131319217, 0.08863189297595195, 0.16110689006745815, 0.12802119686135224, 0.09222461376339197, 0.16160606113927706, 0.06034998342927013, 0.08672563705061163, 0.11057416163384914, 0.14524157425122602, 0.10237972491553851, 0.06562209195856537, 0.1065980007073709, 0.18923136591911316, 0.07027650291898421, 0.10603665547179324, 0.11858951939003808, 0.1279998365789652, 0.11541020284805979, 0.09693084444318499, 0.13212542448725018, 0.1410639291363103, 0.11974133258419377, 0.1331975098167147, 0.12815379617469652, 0.2045206462166139, 0.12877880835107394, 0.11925400873380047, 0.13148621735828264, 0.2680301804627691, 0.08836782071739435, 0.13336003252438136, 0.07619494319494281, 0.1573974069740091, 0.09730094458375659, 0.13207946052508696, 0.1623501562114273, 0.08849292221878256, 0.20743696258536407, 0.132748740326081, 0.14835340370024952, 0.13167403585144452, 0.11926737587366786, 0.18511959298380784, 0.09569238911249808, 0.1406022131975208, 0.20292680816990988, 0.11324733854936701, 0.09417366489235844, 0.16501343330102308, 0.14569995179772377, 0.13952613808214664, 0.11365997605025768, 0.1296930257230997, 0.16097224157835754, 0.09733151258634669, 0.1353236043027469, 0.10826244032276527, 0.20824766265494482, 0.1947216098862035, 0.21638156047889165, 0.11125437941934381, 0.12515300219612463, 0.10269017504262072, 0.15236837682979448, 0.1301389725080558, 0.1745114443557603, 0.06732639550630536, 0.16449786882315362, 0.11968738905021123, 0.13205805953059876, 0.0857288216107658, 0.1501053132648979, 0.19936759344169072, 0.22675442030387266, 0.1494998564677579, 0.17344348451920918, 0.10195329958306891], [0.03398431445072804, 0.033743278456053565, 0.026643800482686077, 0.02652675997731941, 0.03102534537070564, 0.08016769787562744, 0.03109111577006323, 0.09246245385812861, 0.03233186454911317, 0.035063694031643014, 0.03151326633191534, 0.03995115462956684, 0.051209170171724896, 0.03966322847242866, 0.030938509851694107, 0.05337409043152418, 0.03166742609547717, 0.02636314313193517, 0.030386094136961868, 0.0477014800001468, 0.03508013493514486, 0.02687874323289309, 0.011568912654183805, 0.0715319351958377, 0.009316062737655426, 0.01998204205717359, 0.06880084531647818, 0.035035992839506695, 0.034674238679664474, 0.03672738725851689, 0.05972107646188565, 0.03503110399469733, 0.059048397200448174, 0.0373049189469644, 0.05156308046675154, 0.016129861352965236, 0.028256664651312997, 0.03783169621601701, 0.08784325886517763, 0.053083534951188734, 0.06490935877497707, 0.06437631523502724, 0.034511335992387364, 0.040473555347749164, 0.04624379679028477, 0.026017283654904792, 0.024573812361008356, 0.029413777203964334, 0.027893151389434934, 0.04767079325392842, 0.021323543108467544, 0.03486725135839411, 0.010718124735701298, 0.03997583634087017, 0.049396307806351354, 0.08390889569584813, 0.026468685861410837, 0.008502449208338345, 0.024542304587417414, 0.039153920087431154, 0.05106576518820865, 0.027173283410125544, 0.03393676610929625, 0.07998810322689158, 0.056331193540245295, 0.03221692410962922, 0.039215096804712496, 0.023247345949390104, 0.025749847558992248, 0.02223720238544047, 0.01343686697405896, 0.022070722122277533, 0.028267580583425503, 0.009115018748811312, 0.05152086880324142, 0.04420311629240002, 0.019268141793353216, 0.005412518628872931, 0.010674789248566543, 0.02196021590914045, 0.016867274551519325, 0.02433064576637532, 0.07638604579759495, 0.021678734138341885, 0.00400640323225941, 0.05525777488946915, 0.037183339042322974, 0.03575352326567684, 0.010380443301983178, 0.02752301053676222, 0.03790817389796887, 0.069508794828185, 0.06946243053036076, 0.06514020995902163, 0.036619734285133224, 0.04401042931047933, 0.033032068583582125, 0.02376266276197774, 0.04191634810662695, 0.020468186952971985, 0.046982134492801766, 0.02387851243838668, 0.06639237848243543, 0.06230803193258388, 0.049227997194975615, 0.03091974157307829, 0.017501681045229946, 0.05765506625175476, 0.02426782190533621, 0.0411985191250486, 0.017702490091323853, 0.06120043208024331, 0.017784696305170655, 0.04735028723786984, 0.055626874190888236, 0.03899338548736913, 0.08736894931644201, 0.04221883901794042, 0.04938446058492575, 0.023364216821002107, 0.02598009484687022, 0.025995473843067884, 0.0036915939417667687, 0.026191402526040162, 0.010545133080865656, 0.023717287428943173, 0.03666769992560148, 0.03464784027476396, 0.008383247568937284, 0.07753508378352438, 0.08193935280931847, 0.06491994392126799, 0.01989550339723272, 0.042414433522416015, 0.02646090306474694, 0.039650122568543465, 0.045250245103878636, 0.0315187624655664, 0.009607854848062354, 0.04593048324542386, 0.046884089575282166, 0.014595032104157975, 0.02871051976191146, 0.024183568212070634, 0.024704757745244672, 0.033385890669056346, 0.06883735050048147, 0.02451931412464806, 0.04512003084112491, 0.018887481951553906, 0.019007501225652437, 0.0221701919633363, 0.07012611241745097, 0.040635453803198676, 0.02273195789062551, 0.06758406239428691, 0.03650130617565342, 0.05089607715074505, 0.008854861637311322, 0.04140067506315453, 0.03912767096023474, 0.030072838267577544, 0.01653899422048458, 0.0809725761147482, 0.059844461269676685, 0.03569580029164042, 0.05371101020968386, 0.009599858312867582, 0.036511833646467755, 0.05554329563996621, 0.031947501602449586, 0.0392141909604626, 0.042146765028259585, 0.05487741529941559, 0.036436010750808885, 0.017208350356668234, 0.07387767146740641, 0.03691014727311475, 0.03176726234544601, 0.014680612333385008, 0.045522290148905346, 0.04693491184817893, 0.11287869047373533, 0.0832896985645805, 0.05412125587463379, 0.0613322239369154, 0.02075464747446988, 0.03510037224207606, 0.04243834509647318, 0.03958324954978057, 0.020859581218766313, 0.11827338992484979, 0.03098062312762652, 0.02983406518719026, 0.03499210858717561, 0.020757689007690976, 0.05839333949344499, 0.02961602813697287, 0.025013850802289586, 0.05338418024725147, 0.039341280569455454, 0.026414754201791117, 0.04967837142092841, 0.03243328178567546, 0.039374505036643574, 0.04668164525979331, 0.037250371516815255, 0.02290539992307978, 0.04226922702842525, 0.037818834584738524, 0.041590868428881676, 0.035954552835651805, 0.0353967970503228, 0.017552676344556466, 0.034765250581715784, 0.07293399889022112, 0.10891209010566984, 0.027659955866900936, 0.031018655015421764, 0.04854854276137693, 0.08063078445515462, 0.03397849940561822, 0.04991487140900322, 0.020074919930526187, 0.01677768418033208, 0.068222088872322, 0.040215376165828536, 0.0304552063212863, 0.00461887735374538, 0.03330240711303694, 0.021043063873159032, 0.03179641899519733, 0.029809553109641587, 0.03313570462965539, 0.025193660885893872, 0.008733433554880321, 0.04704809488196458, 0.01818172580429486, 0.020985420626987304, 0.04024866848651852, 0.08819989687097923, 0.08772487486047403, 0.0452768708180104, 0.03604886581056884, 0.10949433421982185, 0.03758040416453566, 0.02019484929873475, 0.07204171855534826, 0.04081574395032866, 0.022016402001359632, 0.012985194201714225, 0.059491948756788454, 0.02148642035068146, 0.03465024568140507, 0.01715203025378287, 0.06159072542296989, 0.03235828331006425, 0.04553105682134628, 0.02021684910037688, 0.06750280104045357, 0.05738475825637579, 0.013850674947856792, 0.034251487614320855, 0.07280966413340398, 0.003914866737821805, 0.09334846452942916, 0.05557425719286714, 0.056660822459629605, 0.03219256470245974, 0.03542272048071027, 0.06729641782918147, 0.005117799912113696, 0.027656186604872346, 0.06298712334994759, 0.02772969230344253, 0.02406376606917807, 0.0863038461123194, 0.023670032553906952, 0.06508988980203867, 0.04595565010926553, 0.04229645663872361, 0.014780506258830428, 0.016694602656311223, 0.015025454007887414, 0.08193509839475155, 0.0170672710519284, 0.009571028208093984, 0.04421119764447212, 0.008766844619198568, 0.07542281784117222, 0.014566733801205243, 0.06113213074526616, 0.03404788300395012, 0.04918237589299679, 0.02000542267757867, 0.01489227285076465, 0.030641046884868826, 0.051654373960835595, 0.024173497056056346, 0.0954113941905754, 0.046301455303494415, 0.019059799312214767, 0.015226149399365698, 0.02060785490487303, 0.015872408203514557, 0.021899660051401173, 0.012567121635324188, 0.013303476319249188, 0.018564482319301794, 0.01031475093415273, 0.02800730472829725, 0.02554426501904215, 0.03459696711174079, 0.028885727681751763, 0.06299573395933424, 0.011105929551246976, 0.011811823101847299, 0.009035029648137944, 0.05024096176826528, 0.015586644876748323, 0.022155316779389977, 0.0717979141377977, 0.12118548580578395, 0.021938450202079754, 0.04588715199913297, 0.049942436894135814, 0.03549089967938406, 0.015590383604701077, 0.00827222821369235, 0.10022928459303719, 0.049811900327248235, 0.03012586577928492, 0.017144093090402227, 0.024651596222871115, 0.023052667467189685, 0.018861402458112155, 0.03182077840236681, 0.032691447396895716, 0.018944080253796916, 0.07516451313027314, 0.024806836553450142, 0.006790487544744143, 0.013310396528270627, 0.024767656245135834, 0.011016262844870133, 0.0543428450556738, 0.047334378984357627, 0.07427973739270653, 0.02481362359997417, 0.08394217105316264, 0.024223912207941924, 0.036574581172317266, 0.1255079438643796, 0.07875380053051881, 0.09543856273272208, 0.09486009127327374, 0.13757856615952083, 0.17930927047772066, 0.22366631243910107, 0.166942779773048, 0.13330566829868726, 0.09931093494274787, 0.11687772481569222, 0.11807936962161746, 0.1843045638608081, 0.14149247828338826, 0.13670415165168898, 0.3430977852216789, 0.1505942248872348, 0.07575800735503435, 0.1292425056121179, 0.19605149781065329, 0.10545399066592966, 0.06698963857655015, 0.06471879900033985, 0.10794371885380574, 0.09788818271564585, 0.09198680759540626, 0.2894440128334931, 0.13490435108542442, 0.111565046677632, 0.13521806496594632, 0.14993534024272645, 0.27312787835087093, 0.15327204976763042, 0.1023553383669683, 0.1235371253320149, 0.11396129988133907, 0.10463653238756315, 0.11059068396155323, 0.16523582993873528, 0.14590214166258061, 0.22128244249948434, 0.19781187549233437, 0.08905922754534654, 0.16814914718270302, 0.29356605878898073, 0.0778371404324259, 0.10437805125755922, 0.13782541719930513, 0.17168468103877135, 0.11403220679078784, 0.18172324023076467, 0.08505151474050113, 0.15450673922896385, 0.09913388480033193, 0.07867795388613429, 0.15357006234782083, 0.10707684287003108, 0.12498848459550313, 0.14785126064504894, 0.1168205514550209, 0.17675861663052014, 0.08619422199470655, 0.09278268167482955, 0.19086348691156932, 0.16776376643351146, 0.2025153852467026, 0.1074777552857995, 0.23892043105193547, 0.14857400900551251, 0.12554029641406877, 0.10630865301936865, 0.10927452280053071, 0.12795137560793332, 0.10247251457933869, 0.14233124256134033, 0.1762362125196627, 0.1162303616958005, 0.1453368134264435, 0.11526680125721864, 0.163057447544166, 0.16620963625609875, 0.07935484006468739, 0.10038530693522521, 0.176386969430106, 0.20774531603923865, 0.15333305006580694, 0.14070593406047138, 0.11466104590467044, 0.08846964846764292, 0.272212344620909, 0.1618755752486842, 0.11106270006192581, 0.13268148393503257, 0.1482126483959811, 0.13191895985177585, 0.15212717120136532, 0.2563123149531228, 0.0978255064359733, 0.13128606309848173, 0.08355273944990975, 0.21138964620019707, 0.11105430658374514, 0.15621841166700634, 0.12887286687535898, 0.21996187764619077, 0.11414074525237083, 0.07212304776268345, 0.12499807908066682, 0.1804532262363604, 0.1398958989552089, 0.15425340139440127, 0.07400044559368066, 0.11391501022236687, 0.18650468651737484, 0.16107012704014778, 0.15366743212299688, 0.25106069818139076, 0.1279856687677758, 0.14648235695702688, 0.0488522855697998, 0.10774479952773877, 0.18338493177933352, 0.1078087514532464, 0.17660825327038765, 0.10526993804212127, 0.09963180736771651, 0.16126413377267973, 0.11293183333639588, 0.1576558066798108, 0.1136987271851727, 0.19102001136967114, 0.12133245649082319, 0.11271672416478395, 0.0974251911310213, 0.19287344334380968, 0.1431231607816049, 0.11284211743623018, 0.09045823104679585, 0.3550858976585524, 0.14400715620390006, 0.15337372145482472, 0.12863746950668947, 0.12628041527100972, 0.1912748555519751, 0.10890230563070093, 0.1749723053404263, 0.21258709765970707, 0.08052063786557742, 0.08943905787808554, 0.07319577091506549, 0.09132715620632682, 0.17561291025153228, 0.1444910873792001, 0.18637743405997753, 0.0843937700348241, 0.10921014339796134, 0.13748116924294404, 0.1392026532973562, 0.06050378017659698, 0.13261333187775953, 0.16074559731142862, 0.1831391528248787, 0.13724250133548463, 0.19012875562267645, 0.1125229617048587, 0.11902370037777082, 0.09449425911796944, 0.07969245873391628, 0.12649194177772316, 0.16082081970359596, 0.13514103767062935, 0.10115014482289553, 0.12270077663872923, 0.20613504387438297, 0.09513418549405676, 0.08543208467641047], [0.008621091056349022, 0.012082409296583916, 0.09552147971200091, 0.07223772696618523, 0.02416770575967218, 0.02124811545945704, 0.03419529812942658, 0.03889723028987646, 0.049959817568638494, 0.018960300633417707, 0.019075855147093534, 0.01749992703220674, 0.012715698752020086, 0.020674115545781593, 0.029234342010957853, 0.055254646843033176, 0.05211058358794876, 0.039389975635068755, 0.014621944499335118, 0.040254473353603056, 0.03892656335873263, 0.01654998479144914, 0.05899503042123147, 0.01078450242390058, 0.035814638914806504, 0.03393139550462365, 0.048214235343039036, 0.029374137188174894, 0.03524968387292964, 0.018072737813262, 0.06316001407269921, 0.043677716449435265, 0.04912628140300512, 0.021412080054038336, 0.019401385714965205, 0.07772100237863404, 0.05124517323981438, 0.020835155654432516, 0.011594451015948184, 0.024277933773451617, 0.035355213031704934, 0.02246574655042163, 0.012192494818009436, 0.0287345466869218, 0.06551653905106442, 0.041198963565485816, 0.02291889937727579, 0.04821909026109746, 0.04438575077801943, 0.04565040434577635, 0.048103501820670705, 0.0599081621372274, 0.042783118917473724, 0.03689093455406172, 0.024384085488106524, 0.05678444475467716, 0.05923632425921304, 0.041344112383999994, 0.0632436095869967, 0.0706079469195434, 0.071222631792937, 0.03449862024613789, 0.010105927541319813, 0.009119629394263029, 0.05225848047328847, 0.04241033856357847, 0.029933243258191005, 0.03437950342361416, 0.015541286507089223, 0.04025322824184384, 0.03436764941683837, 0.0038805226878529148, 0.04754879944292562, 0.0323685970423477, 0.01969243143685162, 0.014343668806499668, 0.012813621533236333, 0.04280252501900707, 0.01673390170825379, 0.05102862896663802, 0.060606177896261215, 0.02582851690905435, 0.04068557718502624, 0.07536882680973836, 0.01020543385363583, 0.029782523667173724, 0.014694289903023412, 0.03772974293678999, 0.027758521560047354, 0.005904328867992652, 0.01297051240024822, 0.007737193173462791, 0.014913572065000023, 0.03612930952970471, 0.023140865145251155, 0.0466801456974021, 0.06584212729441268, 0.02846485955108489, 0.05061923825581159, 0.018408800940960646, 0.004257290283151503, 0.03269915555470756, 0.008569636049547365, 0.053822975273111036, 0.013771109931570078, 0.004474311227178467, 0.031042617479605333, 0.01933293340594641, 0.04505089830074992, 0.05136516537251217, 0.015365724052701677, 0.042602221481502056, 0.03821878008810537, 0.016906783949317675, 0.06228606775403023, 0.02995164173522166, 0.03953831696084567, 0.03932761487417987, 0.020556939333411198, 0.02176783257164061, 0.01729599672502705, 0.04067567057375397, 0.03486728189246995, 0.0025593032603085574, 0.07943165701414857, 0.016690453414672186, 0.01748650221686278, 0.006887049863247999, 0.06442184493477855, 0.008969810558483005, 0.02264387047450457, 0.05725257284939289, 0.06015947115208421, 0.06152618317199605, 0.013309578893573155, 0.052302439364471605, 0.01698134476984186, 0.02991018324558224, 0.07152066472917795, 0.04787984310782381, 0.010147602313996425, 0.009723981875660164, 0.022783302635486637, 0.07967896267239537, 0.061244665778109005, 0.038559357170015574, 0.01893970200658909, 0.013604474453521627, 0.044293704110064676, 0.05727198573627642, 0.04364077700302005, 0.04172627009185297, 0.006067330366931856, 0.025717216809945445, 0.034385097944842916, 0.024343149470431463, 0.02295841895309942, 0.03346323687583208, 0.020167095520134484, 0.03427809636507716, 0.07436442534838404, 0.020117223196263825, 0.04809580044820905, 0.03355245066008397, 0.04601544600778392, 0.022544236088703786, 0.03622608219406434, 0.034645302553794215, 0.0825839475063341, 0.029444430023431778, 0.05431167994226728, 0.046538949345371554, 0.015232444508001208, 0.018434656517846242, 0.024566387491566793, 0.07087467903537409, 0.00939837666893644, 0.018678118275212388, 0.09465415589511395, 0.07180041114666633, 0.036452882524047575, 0.06064786708780697, 0.04485053030241813, 0.048501754379166026, 0.027454894102577652, 0.026106629753485322, 0.06219562582139458, 0.05859504081308842, 0.027363247770283903, 0.03542944476274507, 0.03531319135800004, 0.04980689952416079, 0.04040053140904222, 0.009816607842887086, 0.034879091794469526, 0.02521662420726248, 0.0304717252563153, 0.022063376980700662, 0.030660748149135282, 0.050560405877019675, 0.03522313279764993, 0.02784651398126568, 0.009762446329529797, 0.01800503019642617, 0.010258156024584813, 0.027557968660922985, 0.03657559558217015, 0.006183342891745269, 0.02006689625393067, 0.010328763530456593, 0.029913287543292557, 0.10143253752695662, 0.051955341561032195, 0.03104209840031607, 0.04390327845300947, 0.028620298353156874, 0.02230295751776014, 0.01056644247312631, 0.0578251342688288, 0.05215727018990687, 0.02679069313619818, 0.02079853511947606, 0.012632081185334494, 0.03102544036560825, 0.04761165214170303, 0.02909603961078184, 0.07474863901734352, 0.009317415566848857, 0.02629287404540394, 0.014869579247065952, 0.02695353645166116, 0.027766928608928407, 0.012956115583490049, 0.036928077560982535, 0.0410984657438738, 0.02172360396278756, 0.019590593508577774, 0.0377422381591584, 0.03551715898460575, 0.056662542545901876, 0.011046418637436415, 0.04713917803019285, 0.02873401064425707, 0.04052357355664883, 0.00814635063787656, 0.029002323746681213, 0.0259472452702799, 0.031627541807081015, 0.048824007622897625, 0.028980593662708998, 0.05071176329095449, 0.036699299301419935, 0.018884649067851048, 0.03733944620138832, 0.033211083084877045, 0.010911555561636175, 0.08147826112274613, 0.021477480651810765, 0.06622666666018111, 0.013304529744865639, 0.022316080385020802, 0.040892686428768296, 0.05404947365501097, 0.0639035188193832, 0.03893914000530328, 0.04837598791345954, 0.04243932218690004, 0.04838096836049642, 0.008447825442999601, 0.026557702870507325, 0.022399862496448413, 0.040348986496350596, 0.03076114079781941, 0.05186802088948233, 0.03510299477992313, 0.023587302171758244, 0.03642971733851092, 0.011462928028777242, 0.04916468309238553, 0.08393482930426087, 0.007735454427477504, 0.0434393369193588, 0.02266168880409428, 0.09456588527453796, 0.07398509034620863, 0.044631129396813254, 0.081881154860769, 0.05828477389046124, 0.01820566621609032, 0.060612108292324204, 0.09051706681826285, 0.02718187027078654, 0.02337015569875283, 0.05567054470468845, 0.02543637286206441, 0.03445500062246408, 0.005858006130438298, 0.04502235911786556, 0.03282546824110406, 0.026973665192989365, 0.020069754582696726, 0.0035979438107460737, 0.03524430648290685, 0.02242713112251035, 0.015954161495236412, 0.0389227126725018, 0.040253123068915944, 0.06971981243363448, 0.07993743701704911, 0.019050718817327703, 0.016405745209859948, 0.017108624368639927, 0.026749502667891126, 0.0687853272206017, 0.028399674388180886, 0.019696353369259408, 0.0373988485495959, 0.03494247714323657, 0.0346998296278928, 0.02338358560310943, 0.03325057721563748, 0.023362218535372188, 0.05463034034307514, 0.033950109500437975, 0.035660920199006796, 0.011319271139135318, 0.03570176800712943, 0.07657537742384843, 0.01378010052056717, 0.010167667442666633, 0.052350930869579315, 0.04098017673407282, 0.02888110346559967, 0.03076146649462836, 0.03706536555130567, 0.025972335798931972, 0.06229159102908202, 0.01676679030060768, 0.07286440155335835, 0.05098336389554398, 0.05320962032835398, 0.03202929221359747, 0.05066899522872908, 0.13358047498123987, 0.04313152968617422, 0.02989674485953791, 0.020001895991819243, 0.043856992186712365, 0.06617179353322301, 0.044694613133158, 0.07313731512320892, 0.05224570705156241, 0.20751283637114934, 0.16684185447437422, 0.15336294631872857, 0.27471518889069557, 0.13874211800949915, 0.09625130519270897, 0.09689501100885016, 0.12278671988419124, 0.24636485587273324, 0.11924700625240803, 0.09154873860201665, 0.11407396383583546, 0.09480280934699944, 0.12742407247424126, 0.1438068255249943, 0.12604383725140775, 0.14298292116395064, 0.11127409086163555, 0.09726759458759002, 0.11602374778262206, 0.10390746686607599, 0.14281518730734075, 0.1316768449864217, 0.14677510410547256, 0.12282565422356129, 0.12537653877266816, 0.18986944667994976, 0.0931154013212238, 0.08867880688714129, 0.06780069826969079, 0.1241930787052427, 0.17728203854390553, 0.10148759385836975, 0.08430633401232106, 0.09651878369706017, 0.1628911250403949, 0.14427912661007472, 0.14142902168844426, 0.14500133214252336, 0.1138821691274643, 0.07639306184968778, 0.06818555654691798, 0.0989856995376093, 0.10027849195258957, 0.17775484174489975, 0.1680645745779787, 0.11484826728701591, 0.09746832560215678, 0.09233243976320539, 0.11390738348875727, 0.1650322965745415, 0.13370991232139723, 0.1011115497510348, 0.13501162747187273, 0.1187665763178042, 0.14356019161641598, 0.16377479476588114, 0.2039599320186036, 0.26554443527545246, 0.22528312568153652, 0.09358744456299714, 0.12949384855372564, 0.15196520489241394, 0.18671206038977417, 0.15272106576178754, 0.13917179352470807, 0.14535837726933615, 0.164333310510431, 0.1931975388101169, 0.08169194537081889, 0.10203494091651269, 0.18329019472002983, 0.1897774644728218, 0.10740273645413773, 0.1363885107317141, 0.05412160871284349, 0.06417503460709538, 0.10982621926814318, 0.07304177739258323, 0.07973946764000825, 0.21379513426550797, 0.11718385267470564, 0.21759298975978578, 0.09501444441931588, 0.12538166849740914, 0.20537779879357132, 0.14060556516051292, 0.1357338601457221, 0.12305379126753126, 0.13545632575239452, 0.19985654577612877, 0.08570172092212097, 0.07703024015894958, 0.17456168308854103, 0.16856612052236283, 0.07247908187231847, 0.17087179608643055, 0.09600255425487246, 0.14246830663510732, 0.08746653622282402, 0.08155664548810039, 0.08934619357543332, 0.11989909197602953, 0.22138446702488832, 0.05934379742081676, 0.06774499733000994, 0.12942778638431005, 0.16327888066215174, 0.14388943037816457, 0.11047665615166936, 0.1347448275025402, 0.1859706523162978, 0.09931038532938276, 0.12151468385543142, 0.12049684061535768, 0.0737684816122055, 0.13746816851198673, 0.10588942694344691, 0.08488726855388709, 0.14845721955810273, 0.11203670993979488, 0.1726442381207432, 0.10542065424046346, 0.09226168891681091, 0.09128698014787265, 0.12298574777586119, 0.15907688971076692, 0.10433332901448011, 0.16112632331039223, 0.15055875107645988, 0.2524770993207182, 0.13677561495985302, 0.1290601153991052, 0.13956815297050135, 0.13319175583975656, 0.15100059950990335, 0.15964673699012824, 0.15390232737575257, 0.1660744042268821, 0.12019914016127586, 0.09380220089639936, 0.08821765413241726, 0.12704622346375669, 0.08095310894506318, 0.13058200159243175, 0.16925083020968096, 0.13569287663059576, 0.05057699605822563, 0.10937788403992142, 0.20935501823467867, 0.062461950816214085, 0.08135432670158999, 0.15857942854719503, 0.09266399911471776, 0.13723958363490446, 0.09823076826121126, 0.07875296593244586, 0.11810652459306376, 0.13268546015024185, 0.07277429210288183, 0.1680952850729227, 0.11789991067988531, 0.10553101117589644, 0.11874076484569482, 0.1685177952583347, 0.09554444812238216, 0.1443527340888977, 0.21525767578610353, 0.16244976515216486, 0.09361965462033238, 0.0688501341002328, 0.12967071549168654, 0.3011801987886429, 0.07387475376682621, 0.19062259340924875, 0.19933556658881052], [0.02578814746811986, 0.031008544843643904, 0.00542195959548865, 0.06628466783357517, 0.008013483303199922, 0.05418006111202495, 0.03421232257304447, 0.10885912366211414, 0.06086885915803058, 0.01668947293157024, 0.021829282399266958, 0.041499798851353784, 0.04069420136511326, 0.07762033492326736, 0.03529140020587614, 0.0778062128062759, 0.04747600620612502, 0.006695398919483913, 0.07337386600141015, 0.013935227196530571, 0.005349016656899559, 0.03308551000165088, 0.05062013052936111, 0.015696268994361162, 0.01768888546419995, 0.026404988386535218, 0.03544901371268289, 0.02550529166390853, 0.059105414498065195, 0.005788941443565169, 0.02213307609781623, 0.04833256845761623, 0.006428659594218645, 0.01853272857676659, 0.03897767400901232, 0.029869742558470795, 0.0013478480042457314, 0.019312406025294746, 0.004843942754502807, 0.04920998887558069, 0.047202583735010455, 0.05880765297583171, 0.012239837902598083, 0.06731619712497507, 0.08141071296163968, 0.0011563331915697614, 0.0167417286096939, 0.049465192681444545, 0.024494250737396733, 0.012190700092885112, 0.04265830579346844, 0.03148111395005669, 0.05139000653954489, 0.01538716915196606, 0.062495470446135314, 0.023480261576228907, 0.004610480482889605, 0.028858450574002097, 0.006272755571574504, 0.025735270930454135, 0.03678739011021597, 0.01582400151528418, 0.0022059243430183934, 0.029713835567235947, 0.06768328457006387, 0.003934383525380066, 0.010132573611502136, 0.020131202713985528, 0.02634611020662955, 0.038356325921735594, 0.07758385688066483, 0.09362619569791214, 0.021579600172117352, 0.021218448212104182, 0.027665891351976564, 0.029474156642598764, 0.023710703942924738, 0.04396683682820626, 0.03726379293948412, 0.06346473057887383, 0.04236455102052007, 0.05759708543441125, 0.09742103849670716, 0.0333512243149536, 0.06465222792966024, 0.061141643806227615, 0.05915167023028646, 0.022010200191289186, 0.03752550050350172, 0.0028483152855187654, 0.02421288431755134, 0.02697860662426267, 0.09454825693475348, 0.0027241086021863987, 0.10683287560407605, 0.041130231360771825, 0.039691370712327104, 0.03802996754114117, 0.027320700231939554, 0.009433893736318817, 0.0286525660859687, 0.036171293883983574, 0.02966866209836943, 0.0872544397466949, 0.006058455552972321, 0.008884466120174952, 0.03275086670847876, 0.060025528339403014, 0.05364477840651359, 0.011931991653649934, 0.013177632670184332, 0.032324960455298424, 0.007154241686553827, 0.02104967280424067, 0.052451557612844875, 0.017740352345364432, 0.03106525001515235, 0.04629208812756198, 0.03273379476740956, 0.029952934344432185, 0.02862789455269064, 0.06929842183100325, 0.08822663115071398, 0.014049709624876934, 0.055881484278610775, 0.030165960413536856, 0.06398923814828907, 0.002956349722808227, 0.061264065094292164, 0.016046727242480432, 0.009347864825810705, 0.012567767091760678, 0.04029930755496025, 0.01868644050721611, 0.01662547859762396, 0.07034457355205502, 0.035357648972421885, 0.02395053723427866, 0.11093077249825001, 0.07768787629902363, 0.022399348506171788, 0.022179102824468697, 0.028610639407166412, 0.029644655529409647, 0.02588294050656259, 0.059273033003721914, 0.018160528370312283, 0.017405636109677807, 0.03962682506867817, 0.03635432870526399, 0.03983323881402612, 0.06202912011316844, 0.0682402668254716, 0.032715633777635436, 0.051927538588643074, 0.048484560301793475, 0.007192646768609328, 0.02430696489422449, 0.07553575320967607, 0.014568209614870804, 0.0239548866437482, 0.027878472980644022, 0.03997545975393482, 0.006072262468348656, 0.021126645816756145, 0.004247448132706008, 0.03172567154147795, 0.021765554390315498, 0.009669272445275314, 0.06905538415802376, 0.032420891736234934, 0.012139460520951875, 0.058820687633539946, 0.03009995591959783, 0.039298271627298424, 0.09098818046706063, 0.04564395147774901, 0.030386416441095725, 0.03266130008601716, 0.05506641783618501, 0.03479925536417535, 0.01404831777991993, 0.008991983386554887, 0.0408317370207182, 0.04227840082187738, 0.021888326820252196, 0.02324668437774692, 0.02094147869917963, 0.036611822566815784, 0.05663566238113812, 0.008359716822659331, 0.03720170698527779, 0.037547817520265064, 0.012511715858376451, 0.048391858847545724, 0.053199001255312135, 0.04895523629550423, 0.02055824381698455, 0.004072886517470968, 0.10418180535946574, 0.018865276893068637, 0.04040883667767048, 0.020397196922983443, 0.03935200481542519, 0.06492341123521328, 0.06351883696126086, 0.030621735778238093, 0.015557228687352367, 0.022859351144039204, 0.04592059359752706, 0.014493886281603148, 0.03612403052725962, 0.0653830576421959, 0.05106132756918669, 0.04858772137335368, 0.09835031256079674, 0.02107566239179245, 0.02975595902119364, 0.012597270642540284, 0.03654129224430237, 0.12256250477262906, 0.02840470233266907, 0.010231445493575717, 0.011980004791569496, 0.024318299821711013, 0.06254589238337108, 0.02622493403032422, 0.1260533503123692, 0.021720803309498087, 0.04270080244168639, 0.07491633216185228, 0.03194587311840483, 0.044413950693394454, 0.00652777829340526, 0.04489497773881469, 0.05949452718985932, 0.05872369783797434, 0.0227960726645376, 0.026065130551744784, 0.06676963038210358, 0.03541688847222498, 0.031175131976072277, 0.027821416667263423, 0.021102237215797816, 0.007394717889837921, 0.04175232583656907, 0.07842059233891112, 0.0661211001819798, 0.04755715560168028, 0.0348342236663614, 0.012370904574968984, 0.037394471998725615, 0.022794308473489115, 0.0029386246917835835, 0.04334312743906464, 0.0875365338953478, 0.05292210129222699, 0.05330827932006546, 0.04968791162329061, 0.07228622864931822, 0.06204694522810834, 0.017576136692826237, 0.0786547004910452, 0.055908272841147015, 0.06725065742752381, 0.035294959122048955, 0.003586532548069954, 0.040876333734818866, 0.03288419883964317, 0.03540335848395314, 0.04084423224308661, 0.04128252176035728, 0.009451813846161323, 0.07825583046568291, 0.016515130143878714, 0.02045722182707063, 0.019629626235525523, 0.018751337292737195, 0.04927758453413844, 0.04046680731698871, 0.03788969738941107, 0.025382532804672207, 0.022485670034906695, 0.014441043670688356, 0.03504948550835252, 0.01835131036516811, 0.037829762391213856, 0.018434468224378567, 0.03332389970975263, 0.05014687610257949, 0.0434930056466588, 0.057610120092119486, 0.01145030727743038, 0.11870287545025349, 0.03920864054401006, 0.007761126799908067, 0.023484471886019622, 0.030024933695260967, 0.06075578808252301, 0.029107808800680295, 0.03608239222584026, 0.011262557485939136, 0.059112152350800376, 0.04691719190616693, 0.03163867656673704, 0.022930380189791322, 0.02626995143613645, 0.05616467086864369, 0.052567956902618916, 0.02084805121246193, 0.07010243833065033, 0.10678889296416726, 0.011366161301599016, 0.05221627898780363, 0.017072926641308835, 0.022758110326581767, 0.031460130254604986, 0.04045287699305585, 0.055058981092380624, 0.009706209347184216, 0.03305953907381211, 0.029775941877492836, 0.04901495755517057, 0.02680743598778333, 0.06388490660382168, 0.01680225562969489, 0.045191385583685975, 0.017076777327539663, 0.02382590901106596, 0.07532493916473218, 0.03423303146181362, 0.020357940279479538, 0.0428446790070406, 0.019419232882293205, 0.0060979882754119375, 0.04036468779668212, 0.015450384866978441, 0.014872681848438722, 0.03538528909640653, 0.019067685585469007, 0.03928948799148202, 0.044366585556417704, 0.025732363407899226, 0.034173849637487104, 0.004920651138361011, 0.09516706051571028, 0.049106508892561705, 0.02490675592395876, 0.014772882917895913, 0.024751948159454123, 0.021689281965206777, 0.054764283155756335, 0.16747955525560038, 0.10587812255003623, 0.09248648078313895, 0.1099776682843055, 0.1529422410364662, 0.12315676574196134, 0.11665929082248892, 0.24243073697601045, 0.0924095416973744, 0.12108477763831615, 0.06861736944743566, 0.08245135497834001, 0.1177412284804242, 0.20838001769568237, 0.13734775568757737, 0.17703961155244283, 0.10997886929128851, 0.1373382154852152, 0.0989575335489852, 0.15513107287032263, 0.13328517654112407, 0.11001343386513845, 0.21761874694909367, 0.1790554848100458, 0.20108310638793878, 0.20695673621126584, 0.0881138654159648, 0.09548751903431756, 0.1571370530873537, 0.19284775400800364, 0.11121322627046279, 0.14929145122213022, 0.1501664492700781, 0.11716935916670732, 0.14311024147484983, 0.1360305156558752, 0.17600874044001102, 0.20421732749257768, 0.13935791568032332, 0.17613789279546055, 0.08779887588960783, 0.13166526917900356, 0.12981907038816384, 0.10438170177595955, 0.2065063789486885, 0.0910748972424439, 0.08855859762323753, 0.08793279834623847, 0.17003654661987508, 0.15482628851064614, 0.16377383124615463, 0.19212548062205315, 0.13438483753374644, 0.11836500572306768, 0.1445068158209324, 0.15412040853074618, 0.09187075775116682, 0.09636136357273374, 0.10467972114150013, 0.11448382612849985, 0.1288563377623047, 0.051406349055469036, 0.13402016567332403, 0.1348689179867506, 0.10964897235057183, 0.0873720705775278, 0.11869125893073422, 0.11751686409115791, 0.18959554923432215, 0.19155718040253433, 0.17249044137341635, 0.18618866561778954, 0.15912632777222566, 0.12131716231150286, 0.10508912881570202, 0.2803930885025433, 0.14239156432449818, 0.13627622675682816, 0.13675865158438683, 0.23161442737494195, 0.13487410199429306, 0.143276021150606, 0.1717495218451534, 0.17358746965016636, 0.17760617472231388, 0.1377015167048999, 0.16115664025502546, 0.20849559935075895, 0.1362274672303881, 0.13422801452023642, 0.06817442857261215, 0.12907269543835095, 0.21353950298258237, 0.08000398094632796, 0.1843005469334977, 0.1666378868477685, 0.14807588287762233, 0.10237458840544734, 0.10888084356806108, 0.07990902675581829, 0.1378009356558323, 0.10043570173106023, 0.12456939422658511, 0.22947869769164495, 0.07233042163508278, 0.07070260933999505, 0.10278203511344534, 0.12428708294672625, 0.2195415116314377, 0.10959548343505178, 0.13105717966599123, 0.07780822126993112, 0.13132074980863503, 0.10120137421680347, 0.184654226526618, 0.10360592590378863, 0.11046903620340995, 0.19477217431579316, 0.11541341910404818, 0.15206832864454814, 0.11727214365133218, 0.17424659856728145, 0.27293419731514795, 0.09508269147149154, 0.09604667938713517, 0.08811799769422837, 0.23293344516839298, 0.16703702828713826, 0.1336056622011321, 0.17231612572712557, 0.052224017679691315, 0.16553434463483946, 0.13338987449450151, 0.11614231499178068, 0.14477733416216715, 0.26266926527023315, 0.09590289781668357, 0.16077610424586705, 0.19469016657343932, 0.11245698774499552, 0.058958803436585834, 0.0804877153464726, 0.10846034184630428, 0.10370997246354818, 0.08293694177908556, 0.14835273873593124, 0.13122468282069477, 0.08243686147034168, 0.28925361590726034, 0.11795940463032041, 0.14320064948073455, 0.1143909211137465, 0.12990088814071246, 0.1936635295195239, 0.10531782904373747, 0.1439352857747248, 0.08848454909665243, 0.11867383415145533, 0.17196288039641722, 0.1756863413112504, 0.11551334017089435, 0.08312395960092545, 0.2476834665451731, 0.10020037221589259, 0.1855639112847192, 0.13461435878915445, 0.13123434515936033, 0.0917358242773584, 0.10822279352162566, 0.14403558682118142, 0.09686630219221115, 0.09455116784998349, 0.09809464056577001, 0.09783226464475904, 0.1297689945037876, 0.14411691602851662], [0.10067595741046326, 0.01877335405775479, 0.00720818097969251, 0.03603040626538651, 0.04431744944304228, 0.024974007225994552, 0.054162293672561646, 0.009408717542620642, 0.03323101844372494, 0.026029655044632297, 0.0376592533263777, 0.01675979121189032, 0.01383896597794124, 0.04383120107065354, 0.04350086647484984, 0.016540953490350927, 0.015359680002023066, 0.008531630454984094, 0.03512590890750289, 0.044310949077563624, 0.04850916058889457, 0.018777988451932157, 0.020040423210178102, 0.016805851865293722, 0.036271269233631234, 0.07344819951270308, 0.032721248654914756, 0.015558779139869978, 0.024126678139769604, 0.034538965938346725, 0.06864694000354835, 0.04883485400517072, 0.04863870988733002, 0.05966971814632416, 0.026138322427868843, 0.011218169421356703, 0.043566728476434946, 0.006369803890785468, 0.035423609361584694, 0.059315502510539124, 0.04715277926464166, 0.01791974512993225, 0.032385855580547025, 0.042061836192650456, 0.08898174563156706, 0.04548225997548018, 0.0453761201351881, 0.029145406426063607, 0.035550169713263, 0.026463478105142713, 0.027194233178826313, 0.008799338813072868, 0.0036592146747612526, 0.04988002185044544, 0.03108774684369564, 0.04068683247481074, 0.02632649545557797, 0.027387400224272693, 0.03068134168695126, 0.037724009315882406, 0.04953718185424805, 0.012655916424202067, 0.06125173611300332, 0.017156413590003337, 0.04610744857096246, 0.02328413611810122, 0.022440869760300432, 0.02553411413516317, 0.028900808122541224, 0.02672112633341125, 0.05022600346377917, 0.03209943577115025, 0.030573166241603236, 0.031149805656501224, 0.01484462951443025, 0.039183555104370625, 0.0637840898707509, 0.03469561931810208, 0.03763287867020283, 0.03891880770346948, 0.0418392597431583, 0.013394447509199381, 0.1356561950274876, 0.012839793477074375, 0.006587552563619933, 0.03331825090572238, 0.036801093124917576, 0.10298117157071829, 0.031110437054719244, 0.02784069554348077, 0.006702481976909829, 0.04085491916963032, 0.046056331135332584, 0.00995646239191826, 0.05155328581375735, 0.03265071493972625, 0.017877334994929175, 0.04627471084573439, 0.03859777921544654, 0.01161605557094195, 0.020914975121351223, 0.03403298916029079, 0.006078413388292704, 0.024380173733724014, 0.0807128261242594, 0.05154504161328077, 0.06066136993467808, 0.03679945785552263, 0.020476644891979437, 0.019278102687426975, 0.02273690271457391, 0.035381465551576445, 0.058343942144087384, 0.03465591484148588, 0.03544788055920175, 0.0033627606046918246, 0.01165662772421326, 0.057853164550449164, 0.016587753746924654, 0.026912130548485687, 0.0565525859461299, 0.04721913320411529, 0.01841154900778617, 0.05542122719011136, 0.026446307776495814, 0.03198989647041474, 0.03155925065012915, 0.027060755162632892, 0.05718993049647127, 0.053864803564335616, 0.05465102887579373, 0.045164111868611405, 0.13022497003631933, 0.015028471792382854, 0.05440457138632025, 0.024298578201393996, 0.006624079375926937, 0.018951727343457084, 0.03764467500150204, 0.03879929393795984, 0.005011267369679574, 0.00584873988658988, 0.011155010533652135, 0.009448998774002706, 0.027672347612679005, 0.02135633840225637, 0.05276302554245506, 0.04302612266370228, 0.016599200632689253, 0.022317674942314625, 0.028268459286274653, 0.05600397002750209, 0.10442383880061762, 0.03517589658232672, 0.006410806065624846, 0.029210074206015894, 0.02921582818297403, 0.04455334892762559, 0.03349720433886562, 0.019959465500765612, 0.01848491221400244, 0.04687455276559506, 0.04169831444908466, 0.03768961776846221, 0.020662047800474932, 0.015104678060327257, 0.025167364261246154, 0.03750539551089917, 0.045769229398242066, 0.027475460498992885, 0.026688010431826115, 0.025519744459805743, 0.06561914033123425, 0.01395942545163312, 0.03513629049328821, 0.011237858811260333, 0.05269170133396983, 0.05036419051300202, 0.023957341244178157, 0.029909005987324884, 0.013960064122719424, 0.05069804670555251, 0.03917850001848169, 0.050680099454309256, 0.01805438004833247, 0.014822924875521233, 0.017685097542458346, 0.04462891058730228, 0.050739668043596406, 0.0352799770688372, 0.046044979244470596, 0.01969954078750951, 0.012735439032050115, 0.03799755053062524, 0.03316674082140837, 0.06759988583092179, 0.025514611342389668, 0.024987683099295412, 0.06575806359095232, 0.048261542804539204, 0.02659432340546378, 0.033245654444077184, 0.07198445698512451, 0.007413011193940682, 0.01816005169946168, 0.04250062443315983, 0.016165404713579586, 0.007765056365834815, 0.04492748974423323, 0.04429442335718444, 0.032127316775066514, 0.04996319328035627, 0.012612503753708941, 0.036710993852466345, 0.01597343697877867, 0.04365331293748958, 0.010748519711861653, 0.059408292174339294, 0.04769752074831298, 0.022687881952151656, 0.021382256743631194, 0.07064765478883471, 0.016915978098820363, 0.019648491205381494, 0.02848033354218517, 0.04304681119642087, 0.09412622172385454, 0.02485909901692399, 0.0135285803116858, 0.005960507750777262, 0.06298517595444407, 0.030662559837635075, 0.038874730068658075, 0.02107482440104442, 0.058048460499516556, 0.04830311664513179, 0.04782240851117032, 0.05582454840519598, 0.028975579288921187, 0.06878488617283957, 0.07143801916390657, 0.057654211297631264, 0.021538241766393185, 0.02985104891870703, 0.06700170292918171, 0.051265946589410305, 0.03496872627043298, 0.027234163268336227, 0.05025153673653092, 0.036255873274058104, 0.09406445468110697, 0.09512598200568131, 0.028965910164905444, 0.004034709168731102, 0.01925452529186649, 0.07289784654442753, 0.06522290302174431, 0.033172735678298135, 0.031083071737417152, 0.045975419227033854, 0.017268175092924918, 0.056539575037147315, 0.040097589271941354, 0.09241591992654971, 0.01728926396130451, 0.04746931245816605, 0.017814843616049205, 0.055318551271089485, 0.03351451037451625, 0.05665099387988448, 0.046664810805980644, 0.025183323404884765, 0.007457967531601233, 0.03107231017202139, 0.027037903799542358, 0.009465219153623496, 0.06463351393384592, 0.010209452477283776, 0.027241776431245462, 0.07427696218448025, 0.05557178393272417, 0.03889898430289967, 0.04325674314584051, 0.0019442263208994909, 0.05319508610825453, 0.005977922352030873, 0.01517856543484543, 0.05468835508716958, 0.05712720671934741, 0.022911893503208245, 0.04144799948803016, 0.039771997635918, 0.026988888126132742, 0.06368661831532206, 0.013967583987063594, 0.056008132839841504, 0.08362287282943726, 0.06609543120222432, 0.061523367251668654, 0.04385242225336177, 0.0658212284158383, 0.03397366823628545, 0.02026546443812549, 0.03881777044651764, 0.021276196631203805, 0.010437223112343677, 0.060500814978565486, 0.03354483749717474, 0.014754216419532895, 0.031304616813680956, 0.047333741161440096, 0.0361583270797772, 0.024438699075419987, 0.028127291771982397, 0.02714977047539183, 0.06042347555713994, 0.06715343014470168, 0.07571771594562701, 0.015585297984736306, 0.03746974528101938, 0.02121860597149602, 0.05466435191088489, 0.02271549154206046, 0.01426614448428154, 0.0702589356473514, 0.009144105848723223, 0.03004286398312875, 0.043217469538961134, 0.07068423461169004, 0.06678187793919019, 0.0396871570098613, 0.060780547825353484, 0.044704784373087544, 0.027289158531597683, 0.030149699321814945, 0.029630660744650022, 0.11002410043563161, 0.056108908860811164, 0.029488626401871443, 0.05890365211027009, 0.03470416546666196, 0.01778116961941123, 0.06594345971409764, 0.044996266053723435, 0.07942977068679673, 0.06045325645910842, 0.030246075043188672, 0.015787632038284625, 0.05927171664578574, 0.02019304609192269, 0.006078997776577515, 0.05946801004133054, 0.21503210360450403, 0.08902065282953636, 0.12420018975223814, 0.1265598495623895, 0.08317044603505305, 0.14008959356163228, 0.17096185125410557, 0.11772117098527295, 0.08366096578538418, 0.1365915826920952, 0.12499084589736802, 0.11279071162321738, 0.13983990624547005, 0.06016823782452515, 0.13176993999098027, 0.10297644896698849, 0.1274614054709673, 0.1148699125541108, 0.15283804519900254, 0.1609763806419713, 0.05935373795883996, 0.07440341397055558, 0.19623170314090593, 0.12524765783122607, 0.11800637282431126, 0.21526549250951835, 0.1711886040866375, 0.15399992785283498, 0.1009930232539773, 0.11964548272745949, 0.12750089620905264, 0.09904317145368882, 0.20215519171740326, 0.2577367499470711, 0.20862221398523875, 0.0996528487386448, 0.14936207314687117, 0.20512330744947704, 0.09670787105070693, 0.1254383668835674, 0.17403417639434338, 0.12494387770337717, 0.14003760420850345, 0.11153933020042521, 0.15118737305913652, 0.0766977851412126, 0.12838742935231753, 0.11461878674370901, 0.19680331461131573, 0.14546734999333108, 0.10220874766153948, 0.08128255805266754, 0.1391965193407876, 0.11986660371933665, 0.10661746787705592, 0.07790962154311792, 0.10640230442264251, 0.12834169609206064, 0.10307959307517324, 0.08455082375024046, 0.1282237802765199, 0.1617303416132927, 0.21069245146853582, 0.17661358655563422, 0.12647649832069874, 0.0984576160886458, 0.09140668051051241, 0.09025332025651421, 0.15496283689779894, 0.09587272336440426, 0.12492250385028975, 0.07279766084892408, 0.1439591294952801, 0.11296915954777173, 0.1818379262196166, 0.17752165640039103, 0.16313739254006318, 0.06061525669481073, 0.09744005104792969, 0.31478976564747946, 0.1321806843791689, 0.14490765359784874, 0.203489625826478, 0.12756414924349102, 0.08980329547609602, 0.1254793368279934, 0.14226808452180453, 0.162800309913499, 0.12941283147249902, 0.11546265360500131, 0.07252558866249663, 0.15870075060852937, 0.16828619768576963, 0.19844334732208932, 0.12038845143147878, 0.17798694143337862, 0.12339668215385505, 0.11574686478291239, 0.1178466049688203, 0.13028481682496412, 0.10719850419887475, 0.15144368287708077, 0.10112763781632696, 0.10382999173764672, 0.17683791023279938, 0.12007688172161579, 0.1472742480358907, 0.06510234770498105, 0.11892219153898102, 0.14280268869229726, 0.07015761001301662, 0.17272864787706307, 0.15871661475726537, 0.09518219184662614, 0.16490842322153704, 0.11647265298025948, 0.10325679249529328, 0.13836048277361052, 0.07746255517538105, 0.17558894439467362, 0.19091421418956347, 0.15303829445370606, 0.06961509412420647, 0.1286884681986911, 0.11818123129861695, 0.11551247164607048, 0.10859199799597263, 0.16403314018888132, 0.14172797064696038, 0.13712400197982788, 0.1635346340813807, 0.1660947331360408, 0.24731114080974034, 0.13380331945206436, 0.11829865856894425, 0.06284355212535177, 0.08719457938734974, 0.10656378897173063, 0.11853188462555408, 0.1785443579511983, 0.09451700361179453, 0.1668087419654642, 0.09285407712949173, 0.09388454112091235, 0.13700270705989429, 0.11191073312823262, 0.060451241210103035, 0.11761010837342058, 0.22286213987639972, 0.09245611634105444, 0.10236548246549708, 0.12910206243395805, 0.28336960449814796, 0.10833660420030355, 0.11704464443027973, 0.1749694419226476, 0.1054720396974257, 0.08918433583208493, 0.11790620748485837, 0.09862646274268627, 0.2370595351925918, 0.15926250975046838, 0.126149946557624, 0.09389212714242083, 0.09779668226838112, 0.10530115743832928, 0.20606610471648829, 0.11226036865264177, 0.1754526131387268, 0.14121445534484728, 0.08887573132025343, 0.13186319784394332, 0.1386871023901871, 0.10260641667991877, 0.12861209229699203, 0.1699256468564272], [0.015920289027105485, 0.06469289931867804, 0.04428178224978702, 0.016055203841200898, 0.069995670845466, 0.007645203332815851, 0.02699307638353535, 0.08053369287933622, 0.014910751055659992, 0.009871128131635487, 0.020869655767455697, 0.0569180618705494, 0.023387673776596785, 0.025244400038250854, 0.0236029865087143, 0.03733608406037092, 0.06870175884770495, 0.030691305973700116, 0.019742439467726008, 0.030296673399529288, 0.038896470330655575, 0.042053971971784315, 0.041660065430083444, 0.020207497191482356, 0.014416672389156051, 0.03954748736162271, 0.06489597127905913, 0.020714257677484835, 0.0665058023961527, 0.0461400623566338, 0.05628954166812556, 0.015698772788579975, 0.03155522693746856, 0.03228688107005187, 0.06903491954186133, 0.07399506481098277, 0.05279556129659925, 0.014645396365917154, 0.10551267037434237, 0.03973060699978045, 0.03950836642512253, 0.01776480844377407, 0.05567939280133162, 0.038619519477444034, 0.03205214188035045, 0.0669684750693185, 0.05571817786299756, 0.03246151562780142, 0.053142469110233445, 0.04806432660136904, 0.02550443501344749, 0.016688283798950057, 0.051767400931566954, 0.027386480809322426, 0.10189775470644236, 0.01234705322089472, 0.04503677798701184, 0.03871265858677881, 0.04071334623066442, 0.04248206650039979, 0.06797698166753564, 0.042761344728725295, 0.03425313984709127, 0.022705479757860303, 0.03031456976064614, 0.01742778349268649, 0.07167963869869709, 0.023651384715256945, 0.044707590115389655, 0.02088707545772195, 0.040850556189460416, 0.06579112181706087, 0.028547484760305712, 0.042552271126104255, 0.045813748080815585, 0.010718279950586813, 0.011154452438599296, 0.007537940517067909, 0.054385080467909575, 0.07680328376591206, 0.07714888879231044, 0.004803357030531126, 0.025342075154185295, 0.017192345411915864, 0.0176508315240166, 0.042789442863847525, 0.10109894257038832, 0.01782127782436354, 0.018646447653216974, 0.016713060505156006, 0.07507365050592593, 0.03319276263937354, 0.025652359040187936, 0.0595683857266392, 0.035445478545235734, 0.08031584921159915, 0.004745926250637109, 0.07227962650358677, 0.05179590279502528, 0.03424663269626243, 0.07174823180373226, 0.015331899082022054, 0.017938228423840234, 0.042796944068478684, 0.03557199139946273, 0.05555300208340798, 0.08595757612160274, 0.03371169265093548, 0.015633168630301952, 0.05517991299607924, 0.03515396972319909, 0.040285302592175345, 0.058460120909980366, 0.004402456913209919, 0.019430774762960415, 0.04299612123785274, 0.028075063235259483, 0.028760700819215605, 0.03606428551886763, 0.024473570686365877, 0.03356312062325222, 0.09554916394076177, 0.026404733935903226, 0.07990477234125137, 0.024875617951952984, 0.017154673147680502, 0.0832073719107679, 0.04468852328136563, 0.04683134026293244, 0.0388350595187928, 0.07438095446143832, 0.004636667693765568, 0.01176926029646503, 0.03808348359806197, 0.02044327962877495, 0.0531698479982359, 0.03343193266274674, 0.042370919071670086, 0.03227972931095532, 0.05682383031983461, 0.05814797444535153, 0.01951031433418393, 0.04736341689048069, 0.07795641331800393, 0.03921806878809418, 0.045175521434949975, 0.017200698177995424, 0.01770114659198693, 0.023345643621204153, 0.037324528609003337, 0.009529300000784653, 0.03203468656699572, 0.07604989276400634, 0.007475868981730725, 0.023894698891256536, 0.03404053446969815, 0.008555577652129744, 0.05453582041497741, 0.03205590774970395, 0.04976929850610239, 0.06612167015139546, 0.013389595135647272, 0.012176508532970079, 0.02588498798598136, 0.09705274325928517, 0.06860709642725331, 0.059143541380763054, 0.05002512317150831, 0.04658889291541917, 0.07222481444478035, 0.059431396291724274, 0.027019948066611375, 0.0394003470428288, 0.021652077890134284, 0.04824525796409164, 0.03549659258819052, 0.03932877516906176, 0.06434221885034017, 0.06279083673975297, 0.016807049479601637, 0.035577406108911545, 0.02876268553414515, 0.04125913944361465, 0.01277778555439519, 0.018507180036976933, 0.05223000914390598, 0.033986234704830816, 0.04644807993567415, 0.04121399650882397, 0.0312069993732231, 0.04385320596130831, 0.015222310587497694, 0.07130630194608654, 0.04346328581284199, 0.018962434626051357, 0.015028006995895078, 0.006776109811783369, 0.022649195278063416, 0.034191698501152654, 0.08092968591621943, 0.04706819308921695, 0.036532165948301554, 0.04358379023947886, 0.04532279406807252, 0.0466888309456408, 0.05553478002548218, 0.029956452548503876, 0.0582033632589238, 0.02920040168932506, 0.00905772834084928, 0.012190647506421166, 0.00888378419248121, 0.0664239710729037, 0.029554932843893766, 0.0500678505216326, 0.032765753766787906, 0.015693049345697676, 0.04522341922191637, 0.011603827521737133, 0.06244308075734547, 0.061258772521146705, 0.07715024586234774, 0.016114404325240424, 0.03144788269751838, 0.03095094400591084, 0.014899624777691705, 0.009883217929330255, 0.04899943606661899, 0.046554084068962505, 0.04953646260712828, 0.07147563035999026, 0.03741411558751549, 0.03733602638489433, 0.015727759804576635, 0.0221104978450707, 0.053187048860958645, 0.014781588522185172, 0.045028235231127055, 0.03302179556339979, 0.025598054186307957, 0.02665898609640343, 0.04119702295533248, 0.019291603837960532, 0.043596282069172175, 0.026715696356924515, 0.026206186107758964, 0.03177230725330966, 0.05946848501584359, 0.050088094613913975, 0.05742499538298164, 0.06768211748983179, 0.023187829946566905, 0.023720617339547192, 0.08412741789860384, 0.03136125073901244, 0.01987206340501351, 0.04345100432900446, 0.02495805317136858, 0.08254062304539339, 0.05453536579651492, 0.0541163331030735, 0.04624418694792049, 0.04065564700535365, 0.06666185866509165, 0.06095964035817555, 0.018251809990033507, 0.08045129158667155, 0.007371165939340634, 0.037422722804227045, 0.03693314282489674, 0.04556533980316349, 0.06421911902725697, 0.07027835531958512, 0.09242990453328405, 0.12044116003172738, 0.030958306110863174, 0.028899827639439275, 0.05104604696056672, 0.025013520016467998, 0.08068333020699875, 0.010043309785292616, 0.046823659246521335, 0.038035154941358736, 0.0485644679782646, 0.024952158398394073, 0.02777536110287266, 0.04281022299879363, 0.027986758687932576, 0.05315396010077425, 0.03731619280629924, 0.04153523873537779, 0.021544813378048793, 0.009407394399334277, 0.033670376653649976, 0.032677523858313046, 0.022082757637170807, 0.004693480582708227, 0.0001799263092315024, 0.036545241318110905, 0.031682435290089676, 0.012780608260072768, 0.04366516355159027, 0.05346365026863558, 0.03619921560000096, 0.022005828729431545, 0.02211847572055246, 0.06131417490541935, 0.022138288943096995, 0.0433946553883808, 0.024769232142716646, 0.029584421975804225, 0.008880651057032602, 0.035790354146489074, 0.03292527734967215, 0.01987507101148367, 0.0651535296014377, 0.06707887950220279, 0.03126872909654464, 0.020555022471983517, 0.046105680987238884, 0.062294705504817624, 0.052707029440041096, 0.03079812095633575, 0.04351350079689707, 0.047672703330005915, 0.007002003025263548, 0.056229966293488226, 0.05489927091236625, 0.02420855187145727, 0.00844523768007223, 0.041095470011766465, 0.026319077371486595, 0.03737945601876293, 0.015584409103861876, 0.04834076855331659, 0.052618819887616804, 0.01637547745901559, 0.03952867497823068, 0.04545240782733474, 0.04871077369898558, 0.04997309310627835, 0.03452304411413414, 0.033270875590720346, 0.020770053612068295, 0.019012673358832086, 0.034136716808591566, 0.08831635383622986, 0.02691537733854992, 0.02495769863682134, 0.06513466632791928, 0.07937138274844203, 0.004302438306954822, 0.0772913336487753, 0.16424588805862836, 0.16668257516409668, 0.08696653055293219, 0.22449358233383723, 0.06169264138277088, 0.07461432301040206, 0.12481996363827161, 0.07109518934573446, 0.14049755595624447, 0.10900686109172446, 0.08567862359008618, 0.14355290415031569, 0.17131532728672028, 0.0985024943947792, 0.10556064958551101, 0.13965191133320332, 0.1172526018427951, 0.07091425798301186, 0.11344743174101625, 0.164892776204007, 0.10905432461627892, 0.2429186307958194, 0.1509879787585565, 0.2032427747866937, 0.11551141313144139, 0.18984098892126763, 0.1296667799885784, 0.15784211882523128, 0.12448609726769583, 0.12038115039467812, 0.1445667983165809, 0.14189430672143186, 0.12059653098029749, 0.07361629977822304, 0.14706588350236416, 0.16219037478523596, 0.09826161446315901, 0.25772877037525177, 0.1350011916032859, 0.15085984420563492, 0.1021648668018835, 0.13559632109744207, 0.14464799181691237, 0.18321014115852968, 0.1471142087663923, 0.18892648656453404, 0.06799941403525216, 0.12228575747992311, 0.14532806032470294, 0.07518104224332742, 0.19323958083987236, 0.18251495489052363, 0.15364794459726128, 0.14536510833672114, 0.09201186589364495, 0.09008718774254833, 0.140732844759311, 0.13652547981057847, 0.1123979619837233, 0.16748890546815737, 0.1375375147908926, 0.2105466750051294, 0.08587527660919086, 0.1012631616156016, 0.10267851781100035, 0.22169846589011805, 0.10144126348729644, 0.10238999115037066, 0.08538439723529986, 0.0873875818880541, 0.12557239112045082, 0.14962252202842916, 0.08520214272929089, 0.15036140595163616, 0.06622281936662537, 0.1379142374332462, 0.16405808313616685, 0.12385740743151732, 0.1667687219700643, 0.19047103582748345, 0.13403194504124777, 0.1808782605720418, 0.10490477085113525, 0.10804553981870413, 0.16563943613852772, 0.26818730203168734, 0.15422550003443444, 0.11560292036405631, 0.07631019915321044, 0.15549123925822123, 0.03997373966766255, 0.15982557167964323, 0.12192489898630551, 0.26965255769235746, 0.2434627344565732, 0.18486556304352625, 0.27831039311630384, 0.14231294925723756, 0.10929973716182367, 0.13614499808422156, 0.16275522804686002, 0.10584604819970471, 0.11491238884627819, 0.11940232291817665, 0.1919190159865788, 0.16597296324159416, 0.17612604557403497, 0.14618662425449916, 0.12764561415782996, 0.14463569676237448, 0.15575318091682025, 0.10939598056886878, 0.08221285670463528, 0.08779558499476739, 0.22787561799798692, 0.09569660281496388, 0.08893234828220946, 0.23239989951252937, 0.06999138928949833, 0.08402811429862465, 0.297063092568091, 0.14189159258135728, 0.16095997366522038, 0.09980547162038939, 0.0982050992814558, 0.15291884514902318, 0.11744112601237637, 0.12898679290499004, 0.08456271168376718, 0.1702289112976619, 0.08258849369095904, 0.10292059874960355, 0.11323330644518137, 0.07610507123172283, 0.13436910909201416, 0.1829653935773032, 0.11512079409190587, 0.15731269866228104, 0.09997152949550323, 0.1954740916511842, 0.07402342757476227, 0.0696963554780398, 0.10407937371305057, 0.14873297618968145, 0.171425711363554, 0.07944115650440965, 0.10780736045645815, 0.1591878030449152, 0.10550607501396111, 0.1777643140937601, 0.14356381499341556, 0.1390804084283965, 0.11633208766579628, 0.13819327817431518, 0.11375708119677645, 0.11841704935899802, 0.10482444587562766, 0.11084812014762845, 0.13319403571741922, 0.11172541164393936, 0.07878423961145536, 0.09860418643802404, 0.12643817466284546, 0.1941354234835931, 0.15622825042477675, 0.2201977635600737, 0.10770418242152248, 0.09191816699291978, 0.09588512019919497, 0.14942755177617073, 0.09672965881015573, 0.16148061358502933, 0.10858779107885701, 0.13849351634936674, 0.13257405827088015], [0.03093162950660501, 0.06519031977014882, 0.05172581352027399, 0.031228349477584873, 0.05713440597589527, 0.04390315631670611, 0.060264895137931616, 0.007336141658015549, 0.011438132662858282, 0.04161803357835327, 0.07695872256798403, 0.030088637955486774, 0.054691384746027846, 0.01720944110171071, 0.05775661580264568, 0.03693228108542306, 0.04686129419133067, 0.03252132509702018, 0.09299263398029975, 0.030689670704305172, 0.02817418023810855, 0.0596700981259346, 0.009794840439488845, 0.05305480917117425, 0.014215831960817533, 0.024769047241924063, 0.043882118338452916, 0.017277884929041778, 0.005679861426220408, 0.039793931280395815, 0.02443511980319662, 0.019965889531054666, 0.04753648403233715, 0.02929209212639502, 0.03462129598483443, 0.008187290048226714, 0.029599231002586227, 0.06182243834648814, 0.04257115136299815, 0.04568729629474027, 0.027443681311394488, 0.020549987742145146, 0.019501937819378715, 0.0677747850173286, 0.01659071215960596, 0.039725389065487046, 0.008792773138598671, 0.03390673414937087, 0.06486479259495224, 0.0062311232073365575, 0.04282963927835226, 0.02803962504757302, 0.01308429254485028, 0.015944928329970156, 0.06140548536287887, 0.03579504621614303, 0.004277382553222456, 0.02407069900073111, 0.04473560004095946, 0.03633507866678493, 0.04592463427356311, 0.043280159389334064, 0.06824515906295606, 0.03936823198039617, 0.045719838834234645, 0.024811447198901857, 0.042847254047436376, 0.03288794096027102, 0.03741738273363028, 0.028862040024250746, 0.03114473699991192, 0.03505892053778682, 0.07876999037606375, 0.02144722138265414, 0.01658909215724894, 0.05276984142671738, 0.06524074849273477, 0.007167730114555785, 0.1048363745212555, 0.028061757163543786, 0.02344837721570262, 0.023592245299369097, 0.01895475191330271, 0.024272814226735915, 0.05021753873942154, 0.05623168298708541, 0.0985266909535442, 0.013915318130914654, 0.0508664319557803, 0.02467387422387089, 0.024930849006133418, 0.035927258764526675, 0.012732704535924962, 0.016163562491003956, 0.04086064939786281, 0.06697780492582492, 0.055988655492131195, 0.07638766749628953, 0.026440116144450646, 0.052419717357094796, 0.09091861027159862, 0.02424745906942657, 0.04728905623778701, 0.04300891501562936, 0.03538032900542021, 0.0050811590211066815, 0.02088391687721014, 0.06664731087429182, 0.021931656370205537, 0.035048186113791804, 0.03080419384475265, 0.022189204514558827, 0.015566862188279629, 0.014734140264668634, 0.023289323518318788, 0.015010052959301641, 0.031086284600730454, 0.03010268702304789, 0.010851144740757133, 0.022005908457296233, 0.03660743923059531, 0.021929764953841056, 0.01291770117157804, 0.0775003767173205, 0.029586579717163528, 0.034601601505918164, 0.008622240325036858, 0.049504405220172236, 0.02977160264604858, 0.014566089192937528, 0.03776023969320314, 0.020290312390508394, 0.013340584551250296, 0.029179760654057776, 0.02041277608701161, 0.022316585893609693, 0.03508641477674246, 0.033594852313399315, 0.007347317977941462, 0.025851751644430414, 0.056894442066550255, 0.051977957133203745, 0.0044767598904270145, 0.05556912746812616, 0.038257358196590624, 0.02459513023495674, 0.04786278473745499, 0.018874002853408456, 0.08573241106101445, 0.041252371056803634, 0.040947400099997006, 0.02561013719865254, 0.03970239690638014, 0.028268308312233006, 0.05181363630773766, 0.02736224014578121, 0.013566700409033468, 0.015174214329038347, 0.015451292407565882, 0.03717139004064458, 0.020391190191730857, 0.01986179208116872, 0.014284324133768678, 0.02415596540751202, 0.014522264312420572, 0.024255752463692, 0.017628012391339456, 0.046517697628587484, 0.10451596350009952, 0.0620527874146189, 0.018204768853528158, 0.011277399591303297, 0.026950954625915204, 0.02498902490229479, 0.04978102698389973, 0.042568915590111694, 0.03710058830412371, 0.06725708993950061, 0.012677496382301407, 0.020211783836462667, 0.04064215772918292, 0.07101768029055425, 0.017622690980455706, 0.003147878954353343, 0.008982131906252886, 0.0769923236221075, 0.02912071792941008, 0.014764988162953938, 0.02027937610234533, 0.020724540875692452, 0.01667719823308289, 0.02681125105092568, 0.03189020610547491, 0.03490876413083502, 0.006943163012952677, 0.029952225275337696, 0.026458618098071644, 0.021864861382969787, 0.004762242049244898, 0.0572034672700933, 0.08133272893194642, 0.023178868195308105, 0.04882711870595813, 0.07127953373960086, 0.015748714662290046, 0.031740687521440644, 0.030539823030786853, 0.037559094772275, 0.018117546569555998, 0.011492189851456454, 0.06895540880837611, 0.027395881912005798, 0.025913513598165343, 0.05595433179821287, 0.048748035449534655, 0.025523244004164423, 0.027497755463368127, 0.13959571506295884, 0.015476259103577052, 0.010973451526037284, 0.04754319813634668, 0.025458501585360085, 0.024238890868478587, 0.028280577921707715, 0.0279571525087314, 0.04930181162697928, 0.06222436177943434, 0.05370353953912854, 0.033076746721885035, 0.017239859826596718, 0.04024587292224169, 0.017113938994173492, 0.05059210703309093, 0.05490021068336708, 0.016145391323204552, 0.028541293128260543, 0.05002715877656426, 0.03325246015031423, 0.038941538626594205, 0.014875984617641993, 0.08035306685737201, 0.016442515022520508, 0.05128495574795774, 0.034572343075914044, 0.009983657227296914, 0.03544201123129044, 0.006190531122099076, 0.029989137580352168, 0.03795807336324027, 0.041077661860202036, 0.019623892614617944, 0.042787291907838414, 0.07684524437146527, 0.022653984038957527, 0.07907433368797813, 0.012449866543257875, 0.031218127347528934, 0.0331716975197196, 0.05536886803539736, 0.015606490329706242, 0.06138175020792654, 0.05843820422887802, 0.036934191161500554, 0.029394330390329872, 0.02190487289668194, 0.006791844190697053, 0.04020458745903202, 0.05316554608621767, 0.0356550949758717, 0.026394270925915668, 0.04862770065665245, 0.05890899896621704, 0.08980092738888093, 0.03950129609022822, 0.01032365670627249, 0.035096043188657076, 0.005855641859982694, 0.030471491161733866, 0.07029036538941519, 0.02342061495541462, 0.045535776032400985, 0.02190146834722587, 0.03177120802657945, 0.05132619032104101, 0.03245398388909442, 0.026413510786369443, 0.04091188557712095, 0.04886386476989303, 0.013503378672924424, 0.01471345342828759, 0.022880136367997954, 0.013479139705720757, 0.032447832969150374, 0.01371526310686022, 0.03149544460965054, 0.018925853106858473, 0.07432191512946572, 0.045619697243507416, 0.047356750283922465, 0.0492460258704211, 0.013838446050483202, 0.04976104412760053, 0.016858046475265707, 0.05400244778554354, 0.052301109435835054, 0.030991727353206704, 0.03816022251599601, 0.04519375706357615, 0.02251254171798272, 0.019689378029267703, 0.026848494141761745, 0.02548824347156499, 0.03355150410373296, 0.03996660147926637, 0.029325706751218865, 0.019037965751652206, 0.03903921374252864, 0.024655889653201615, 0.0009780699557658018, 0.03987166764480727, 0.07968964959893908, 0.011500641853282494, 0.050254315337432284, 0.038958546106836626, 0.06239715750728335, 0.06248314825019666, 0.011898854547845466, 0.014715371986052819, 0.031638188021523614, 0.01399756844953767, 0.026963841702256883, 0.04858274092631681, 0.03043980696903808, 0.048898799145328145, 0.06024093606642314, 0.02472672701281096, 0.03494923535202231, 0.043680169353527684, 0.007488365052267909, 0.02876114865232791, 0.030039705402616943, 0.05504343585510339, 0.029372400138527155, 0.03013434068166784, 0.08510789421520062, 0.05379497213289142, 0.06152853090316057, 0.03813806834763714, 0.023850717947685292, 0.05306685656043036, 0.07940910929547888, 0.042494629576270065, 0.11836500572306768, 0.18198747533772672, 0.11762745172849723, 0.1871459563927991, 0.2594523850296225, 0.2540719008871487, 0.11196503628577505, 0.12906353521559918, 0.08569781256041356, 0.1135099655283349, 0.11922238900193147, 0.07806098234972783, 0.11134105548262596, 0.13530144334903785, 0.11136811545916966, 0.0740942462746586, 0.09248990059963294, 0.06034411410135882, 0.17685169806437834, 0.11828145092087132, 0.1141299158334732, 0.127100994810462, 0.13477253887270177, 0.21756568551063538, 0.1276883211519037, 0.1356921438127756, 0.3148457040744168, 0.17652233716632637, 0.1233439464122057, 0.06843486388346978, 0.09946816507726908, 0.19623331805425032, 0.12321345055741922, 0.14072854284729275, 0.16060243999319418, 0.14675674294786795, 0.09105462940143687, 0.13813723118177482, 0.1459573201302971, 0.15069738935147012, 0.07683998572507075, 0.18939097092619964, 0.11388645746878215, 0.11118991859257221, 0.12500870493905886, 0.13348168028252466, 0.06436139424996716, 0.11449766824288027, 0.15097599583012716, 0.14396283429648193, 0.12119425247822489, 0.11497239848332745, 0.09462886010961873, 0.22987121662923268, 0.11319991573691368, 0.14050211571156979, 0.12610922088580473, 0.20115619818014757, 0.08112614216016871, 0.10963833970682961, 0.1474366078951529, 0.19176146015524864, 0.1590373854019812, 0.17567583758916172, 0.1973641916577305, 0.09959783990468297, 0.09181376080960035, 0.13078476142670425, 0.07521747278847865, 0.2035608720034361, 0.19880136953932898, 0.20745874355946267, 0.12970122242612497, 0.15487100396837505, 0.07254439086786338, 0.10498885491064616, 0.1502557173371315, 0.07013002077915839, 0.15796120172100409, 0.129682739132217, 0.15910925583115645, 0.17276083757834776, 0.15002645392503056, 0.048000537524265904, 0.12221284210681915, 0.1436336226761341, 0.18092449594821247, 0.14543768444231578, 0.16140123855854782, 0.07127801382115909, 0.10744019837251731, 0.20259363390505314, 0.0812830805246319, 0.1506575864872762, 0.14405597001314163, 0.186362533430968, 0.19932788557239942, 0.15476655028760433, 0.1477578128022807, 0.16665301817868436, 0.11933867633342743, 0.1341658742832286, 0.12969223862247808, 0.1743241279785122, 0.1481777716960226, 0.08133180612432105, 0.14493788911827973, 0.1532093124198062, 0.12922727928629943, 0.10362539985882384, 0.1344068899218525, 0.1566828146044697, 0.10552291625312396, 0.09212325420230627, 0.11754009713019643, 0.13815266106809887, 0.16988646824445042, 0.14542678716991628, 0.10209288102175508, 0.06796702077346188, 0.15960286291582243, 0.10644395290208714, 0.1302470631365265, 0.1331955013530595, 0.10597254748323134, 0.14728878225599015, 0.25030489159481867, 0.1407454926520586, 0.14223041225756916, 0.09455544940595116, 0.13140396534332208, 0.05836047125714166, 0.0648432762495109, 0.0877917173451611, 0.1261810098907777, 0.07612500659057073, 0.15144721125917776, 0.13155066461435386, 0.09761135399873767, 0.09771582125020878, 0.23677490332296916, 0.10807277621435267, 0.10109130226607833, 0.11904691984610898, 0.17171929989542278, 0.08384999885622944, 0.17634177899786405, 0.11352534791720764, 0.11343840722526823, 0.11052207728581769, 0.09556878717350108, 0.16382735408842564, 0.07966630120894738, 0.13706714074526513, 0.07933134239699159, 0.14865680384848798, 0.1162582766264677, 0.07095327374658414, 0.13411944891725266, 0.08854211600763456, 0.1180693544447422, 0.12795957231095859, 0.08418681685413633, 0.11422026955655643, 0.12060635616736752, 0.10753981409860508, 0.1125512837565371, 0.13158441494618142, 0.2999223305710724, 0.1146541384181806, 0.16703607833811215, 0.10404442237423998, 0.10273975559643336, 0.10093095765582152, 0.20348005848271505, 0.15087868033775262], [0.021014689235016704, 0.020812099034498845, 0.04897049994074872, 0.07418573993657317, 0.021196558672402586, 0.07475722927067961, 0.014378581129546677, 0.05952589586377144, 0.028446975064330866, 0.008489121932403317, 0.03989523316600493, 0.025975121185183525, 0.023466962289863398, 0.08750248500811202, 0.028089326041351472, 0.04741440540445702, 0.0060246763834064555, 0.04222839957635317, 0.03819722303056291, 0.059836563122059615, 0.05439860027815614, 0.016198043944314122, 0.019967923439773064, 0.008484949790207403, 0.00924445184812482, 0.007193332937146936, 0.04065858845465949, 0.05345881570662771, 0.021212334611586163, 0.03453498972313745, 0.0914319423692567, 0.1092862750270537, 0.029483432216303687, 0.01698518018903477, 0.03452062852946775, 0.036612931971571276, 0.03623792602281485, 0.012270418627719794, 0.06370836536266974, 0.019069984122844677, 0.049867051653563976, 0.029461264477244446, 0.016680093881274973, 0.022734744973214607, 0.054655690411371846, 0.048308314223374636, 0.021534676064870188, 0.0042129522605266955, 0.09742766099848918, 0.041171835735440254, 0.04600379216883864, 0.00883372187880533, 0.10159644444606133, 0.06000085680612496, 0.02229469465757055, 0.04316239285149744, 0.01055598964116403, 0.057238588242658546, 0.02796639924469803, 0.004072501024763499, 0.08625222316810063, 0.028262201497065167, 0.014789724157058766, 0.02961693737389786, 0.036059386496032984, 0.02986332361719438, 0.06121182468320642, 0.05413002593974982, 0.07163773916129555, 0.03643005321334515, 0.03618792138461556, 0.07783224140959126, 0.013800088465879006, 0.018704643905428902, 0.04229462120149817, 0.09772090347749846, 0.026038440376786248, 0.015889239264652133, 0.01299245367824499, 0.02045014640316367, 0.04497560466240559, 0.06412524370742695, 0.015565567882731557, 0.02928720667426075, 0.03962147482005613, 0.017580988218209574, 0.020111420025516833, 0.011162426073237188, 0.018228008677916865, 0.03715676421831761, 0.057553754188120365, 0.0822174164599606, 0.025511323840224316, 0.05110209395310708, 0.03317511733621359, 0.05330709866913302, 0.08301732103739466, 0.009438799544503646, 0.04894426777692778, 0.06399525675390448, 0.04054905254659908, 0.03522103273176721, 0.07001537550240755, 0.07742273874048676, 0.023611061075436215, 0.0428699849705611, 0.040588814698691876, 0.015345178012337004, 0.02368136408871838, 0.04924420739657112, 0.053861862115029774, 0.006156585711453642, 0.03139481447370989, 0.02923740559656705, 0.02180198154279164, 0.05443275433831981, 0.007070527004543692, 0.04407036770135164, 0.028076545834275227, 0.013494460178273065, 0.010422495509763914, 0.019094207823010426, 0.07500811759382486, 0.01576491298952273, 0.03612985575039472, 0.06736388456608568, 0.01932694194173174, 0.038448440443192206, 0.046483614814600775, 0.05572235763871244, 0.04911922463881118, 0.04325085346187864, 0.029064128108854805, 0.025536404190851108, 0.05492752171786768, 0.07703729013779334, 0.021395026772682155, 0.04157257851745401, 0.025016419057335173, 0.011808497432087148, 0.044513030376817496, 0.009351703637678708, 0.048778454174420664, 0.02554412591936333, 0.02470494094969971, 0.03368881923545684, 0.05480246092858059, 0.017085060543779815, 0.0206342261683728, 0.098019940645567, 0.08726961857506207, 0.06663715320506267, 0.033534262528909106, 0.05643014769468989, 0.059150537076805315, 0.04671712585591844, 0.029331569293779985, 0.050530811572181325, 0.05330428274880562, 0.0481907071412674, 0.028054637634860616, 0.04007446140583072, 0.03406665128256593, 0.08828148392162152, 0.0579612348228693, 0.05942095363778727, 0.037012969077165635, 0.02340882201679051, 0.01108116896024772, 0.03396561402561409, 0.03386049877320017, 0.06067589058407715, 0.06730825826525688, 0.0041507857302869, 0.024033642507025173, 0.02963286598346063, 0.017379210563376546, 0.042036777894411764, 0.03056440974718758, 0.0813823841246111, 0.009997247435551668, 0.038819653381194384, 0.047307848265128474, 0.01339623544897352, 0.012423600452685995, 0.047327586848820956, 0.02700498976212527, 0.022529998727674996, 0.06810460053384304, 0.0720233777537942, 0.039246373876397095, 0.006799598997791431, 0.05522122220801456, 0.06075008160301617, 0.008863373010951494, 0.05895117670297623, 0.024013288152803267, 0.04404040698760322, 0.022989848695163215, 0.03126931942201086, 0.018537883746570775, 0.034098925800727944, 0.012275483891634005, 0.04302841271939022, 0.033930320026619096, 0.043937432513173134, 0.05739615764468908, 0.07263427640178374, 0.02668220895741667, 0.014587856596335769, 0.03306502163676279, 0.04361492142613445, 0.07165807485580444, 0.010065438508588289, 0.06308762117155961, 0.028754600789397955, 0.04654350910069687, 0.04468034693439092, 0.08344424170042787, 0.032171564043632576, 0.005165482688296054, 0.06951498306755509, 0.03216842242649623, 0.036554781520473104, 0.03390656451561621, 0.020558398183701292, 0.03708077508157917, 0.033371366626982174, 0.05493799829855561, 0.05128174627731953, 0.021200609526463916, 0.03164752127070512, 0.01228875688476754, 0.058430672490171025, 0.013296340675359326, 0.016454589553177357, 0.08522986767015286, 0.023967855144292116, 0.022884031159004996, 0.045685189443507364, 0.04997464695147105, 0.01953246341353016, 0.052146121859550476, 0.033941821195185184, 0.04122761470664825, 0.08809525998575346, 0.04472441439117704, 0.04117793237258281, 0.059714501457554955, 0.033797588398946185, 0.04562789733920779, 0.01871844021869557, 0.005588059879041144, 0.014514588385022112, 0.006922686522427414, 0.026013667063255395, 0.08563120756298304, 0.030785768226321255, 0.021820900795449103, 0.03388426106955324, 0.020191919723791734, 0.03348317902003016, 0.014504088055608528, 0.056118676372404606, 0.049442855308630636, 0.045041202035333426, 0.025247886011909162, 0.02632948100966002, 0.03654427779838443, 0.06224001558231456, 0.058052680987332544, 0.07466165082795279, 0.02747430190044854, 0.06225317916167634, 0.04747736666883741, 0.0152969596175743, 0.024137326050549746, 0.04809983094621982, 0.01597474146235202, 0.03856365229668362, 0.03133311867713928, 0.05833769283656563, 0.07149281765201262, 0.10981234322701182, 0.016136041110647575, 0.026049412288037792, 0.058932184507804256, 0.051622323359229734, 0.01892124585408185, 0.03298269159027508, 0.024759629175865223, 0.014898425467046244, 0.003977147770845997, 0.08266137513731207, 0.029566871667546884, 0.017020765958087783, 0.04613815906590649, 0.0391243800653943, 0.07322524647627558, 0.03520102273406727, 0.04773055522569588, 0.12192548252642155, 0.05040378303134015, 0.05857262201607227, 0.04169366309153182, 0.0064586135226168805, 0.03551179516528334, 0.034234744762735705, 0.05347175197675824, 0.03364909101011498, 0.02058295945503882, 0.03554015114371266, 0.036331719918442626, 0.030700388164924722, 0.011484612311635698, 0.024007900584755198, 0.07234597365771021, 0.041259122480239184, 0.03589241259864398, 0.026918943040072918, 0.059499195510787625, 0.0341502535822136, 0.03829269290768674, 0.03911492807258453, 0.02278883269588862, 0.049954843906951804, 0.09259147729192461, 0.058537100707846026, 0.04794729288135256, 0.02485027297266892, 0.04031605379922049, 0.024677058249445896, 0.04713204662714686, 0.03417956968769431, 0.01696309557051531, 0.037704589643648694, 0.018700072275740758, 0.027716348912300806, 0.03392863725977285, 0.01884122791567019, 0.008993837483493345, 0.019689944606008272, 0.033843738958239555, 0.04984285509479897, 0.010267908269140338, 0.02679902215355209, 0.02712931264457958, 0.019691318639421036, 0.0505460345053247, 0.03072536164628608, 0.03716989387092846, 0.011160967222947096, 0.10045707558414765, 0.11884129659405776, 0.09002584139151232, 0.25384768577558653, 0.11952426923172814, 0.17584092515919889, 0.10975307997848306, 0.17563807033002377, 0.0882597097328731, 0.1544571111776999, 0.1770109502332551, 0.09505259844341449, 0.22328720135348185, 0.17930723487266473, 0.14145529456436634, 0.13671230764261313, 0.13370352052152157, 0.1747327281960419, 0.11440831875162465, 0.12669969562973293, 0.11998195467250687, 0.12229510769248009, 0.12120846100151539, 0.08523040371281759, 0.07853483049465076, 0.14763818707849297, 0.14050325565040112, 0.1941056222255741, 0.09143919590860605, 0.1572312337479421, 0.14832030476203986, 0.17676795327237674, 0.07289722907756056, 0.13402905448206834, 0.12540115602314472, 0.15525278848196777, 0.19104172449026788, 0.10381166450679302, 0.1497028741453375, 0.10825373471847602, 0.11943947949579783, 0.07803906566862549, 0.09459256527147122, 0.2369021964924676, 0.14891687275043555, 0.17985768962119306, 0.06911829113960266, 0.06405684737754719, 0.20769020542502403, 0.12183856219053268, 0.14809268340468407, 0.10364447347819805, 0.1877765054149287, 0.16034260179315293, 0.07436255937708275, 0.13845701116536344, 0.11076888761350087, 0.1624327339231968, 0.12920923025480338, 0.1595862116664648, 0.12571169435977936, 0.06686708836683206, 0.09685033626322236, 0.13512900045939855, 0.08420305419713259, 0.12890038825571537, 0.14742598203676088, 0.10287797996508223, 0.19128242800278322, 0.15945997701159545, 0.13635355260755333, 0.16298769414424896, 0.17094914907855646, 0.08086946593331439, 0.10224742415760245, 0.22275053443653242, 0.13608080867145741, 0.06735006280775581, 0.08080949700836625, 0.18195931613445282, 0.1922972449766738, 0.1137413934671453, 0.11784705280193261, 0.1226303039916924, 0.09651273116469383, 0.10341128813368933, 0.1300289819815329, 0.20269754475780896, 0.12949255933719023, 0.1465924967612539, 0.09268662825758968, 0.19057882790054592, 0.13231035242123262, 0.19862044496195658, 0.11244662651526076, 0.15111330417650087, 0.18076897572193826, 0.1658909690699407, 0.1403916094984327, 0.16711184355829442, 0.10732721550656216, 0.08648456034383603, 0.13385803651596817, 0.10327836312353611, 0.13734713143536023, 0.13012726099363395, 0.16345705038734845, 0.2142351913665022, 0.1364114587860448, 0.14378344320825168, 0.09863705467432737, 0.13195693067141942, 0.11733489456985678, 0.123427026239889, 0.26645589779530254, 0.08468235776360546, 0.06910659319588117, 0.11619914908494268, 0.1262313843305622, 0.17324289599699633, 0.13327347859740257, 0.12923325039446354, 0.16536933848900454, 0.11351557701293911, 0.14136959559151105, 0.12099736875721387, 0.1864989461111171, 0.15751404714371475, 0.14070714185280458, 0.13007962783532484, 0.15973804066223757, 0.0773783354088664, 0.09831875389707939, 0.114497912515487, 0.11149823811969586, 0.20872680337301322, 0.10067415250731365, 0.07357608979301793, 0.062271899942840846, 0.1258756419909852, 0.12012634692447526, 0.1379932053387165, 0.15533286918486866, 0.0908030014751213, 0.1722367507006441, 0.11485415697097778, 0.14208808275205748, 0.09978669655642339, 0.08731973517153944, 0.19018035142549447, 0.21946303227118083, 0.16412415887628282, 0.19791067019104958, 0.12019418685563973, 0.10658882691391877, 0.1186277616236891, 0.08690314181149006, 0.1256266739219427, 0.10158304337944303, 0.13973914379520075, 0.11744810135236808, 0.08657587080129556, 0.16060393277023519, 0.23440776605691227, 0.09375974496028253, 0.14673139287957124, 0.1530107595026493, 0.1363788212516478, 0.1267503143421241, 0.11974895931780338, 0.1027561015050326, 0.17619001785559313, 0.12808846682310104, 0.0785340637500797, 0.14360193509076322, 0.05603822586791856], [0.02339071361348033, 0.0524627907600786, 0.006697951907491577, 0.04042990179732442, 0.04216185564707432, 0.02669151167252234, 0.01632988838745015, 0.012412289273925126, 0.024994217391524996, 0.0670441792213491, 0.044696177156375985, 0.029460073648286716, 0.023271956414516484, 0.005236708933287966, 0.034023557523531575, 0.07048298112515892, 0.009715983644127846, 0.03732739881213222, 0.06111226323992014, 0.044120226454521926, 0.02940829124833856, 0.041405418022934876, 0.025650236921917115, 0.008934124705514737, 0.0370152964522796, 0.04392692539840937, 0.0022979760999857846, 0.020973010221496224, 0.011582707271112927, 0.03617351269349456, 0.03214040232290115, 0.07350164771612201, 0.0440225445532373, 0.06501333069588457, 0.014044126978011003, 0.021944126147510748, 0.013542676028529448, 0.08328416850417852, 0.03436308626883796, 0.040024070002670796, 0.013799256412312388, 0.011289513985892492, 0.0841196079605392, 0.043883841817400286, 0.022697396709450653, 0.1519666298159531, 0.023717241627829413, 0.04181379771658352, 0.0348469224492354, 0.011138925012866301, 0.08705494366586208, 0.008116229620229985, 0.02184922793614013, 0.018405281040551405, 0.034212763620806594, 0.04991341595138822, 0.014234926784411073, 0.07119697638388191, 0.05140128718422992, 0.06597025506198406, 0.02191275916993618, 0.06507282464631967, 0.04382748269875135, 0.013782857917249203, 0.05526979174464941, 0.030511120999498025, 0.01767820362666888, 0.04892975730555398, 0.03705188984583531, 0.0727746585117919, 0.04603753910799112, 0.0076304214474345955, 0.0259016103976007, 0.09191957834575858, 0.033281840716621706, 0.05180905619636178, 0.05748028241630111, 0.07886111084371805, 0.022884180436709096, 0.0386360519831734, 0.030391715799591372, 0.026677627149703245, 0.07849322951265744, 0.024233111446457248, 0.056339312211743424, 0.04855980644268649, 0.01485481093238507, 0.021877027515854155, 0.01613252460291343, 0.012905284828905548, 0.07139628926025969, 0.03710016421973705, 0.05782600957900286, 0.021806446303214346, 0.05748222302645445, 0.0349548604073269, 0.03354418949623193, 0.022782288225633756, 0.018667813024616668, 0.10043371362345559, 0.03136617011789765, 0.014960760782871927, 0.03215742337384394, 0.09134899824857712, 0.05228985932522586, 0.03298459827367749, 0.01467431043939931, 0.014305043200563108, 0.08381168876907655, 0.04887026335511889, 0.04068434903664248, 0.0024891128414310515, 0.015043287604515041, 0.029964710319680826, 0.0897242868585246, 0.029617819469422102, 0.06398368773183652, 0.01962295114727957, 0.0440055268949696, 0.037514874645109685, 0.02776344433160765, 0.02612585434690118, 0.053866635608885965, 0.09210728827331748, 0.044680313007639985, 0.0446498332146023, 0.05661711123372827, 0.07771195072148528, 0.013720271543466618, 0.04338316100516489, 0.049673910053180795, 0.031176604397062744, 0.07112550629036767, 0.06387316794799906, 0.033170018145548444, 0.015580083443117993, 0.01019502936729363, 0.07738461864313909, 0.06106011103838682, 0.03753327990749052, 0.03328856499865651, 0.01961555002656366, 0.021359658134835105, 0.014885874265538794, 0.03380431268098099, 0.04026317895789232, 0.025847029040700624, 0.06132881769112178, 0.01497752229417009, 0.04870163383228438, 0.04831492654713137, 0.023709050013816783, 0.048676497502518554, 0.04748218087479472, 0.032478343296263895, 0.036373955330678394, 0.012502388546376355, 0.04266253306663462, 0.015763722160565, 0.019482124596834183, 0.06351715419441462, 0.036142805591225624, 0.041154417741511545, 0.06896070138152156, 0.04624646343290806, 0.07229849656245538, 0.015754090355975286, 0.035142723005265, 0.04679192416369915, 0.04390618936823947, 0.03361329150253108, 0.029262199266148464, 0.0187292696375932, 0.04272455795268927, 0.03653168758111341, 0.019277636194601655, 0.02730222711605685, 0.014859601389616728, 0.028993119419153248, 0.014116510549294097, 0.028967189203415598, 0.09164986067584582, 0.02449389111383685, 0.055854353055890114, 0.08281186063374792, 0.06861180546028273, 0.07509291411510535, 0.022581272226359164, 0.07916713692247868, 0.05200904421508312, 0.030170258932879994, 0.007293478768718029, 0.03778632597199508, 0.013653595299859132, 0.01810573666755642, 0.04955597048891442, 0.04545795824378729, 0.05964360133345638, 0.008679978566111198, 0.09526692729975496, 0.00694810614056353, 0.04056502186826297, 0.014804558628903968, 0.00814603766359921, 0.02994226777393903, 0.12316684877233845, 0.02439877577126026, 0.05305562341319663, 0.09013893282307045, 0.02279910571607096, 0.03395087963768414, 0.03674471025754299, 0.031238401973886148, 0.030751593810107027, 0.039450348288353, 0.006195393249592078, 0.033926815393247774, 0.05224639576460634, 0.07988200749137572, 0.06451531991894756, 0.041784566427980147, 0.05095061779554401, 0.04061012748362763, 0.005372451984190515, 0.020966479321941733, 0.011298564794872488, 0.031981886364519596, 0.023694424191489816, 0.07102397031017713, 0.03054779242458088, 0.026918164421139017, 0.09316160277064357, 0.011098739624555622, 0.03909538626404745, 0.0286316807780947, 0.015534126266304935, 0.029585202291075672, 0.049078861983226876, 0.017166330379300883, 0.020559124216171246, 0.045250933816922564, 0.011268775411216276, 0.037673702729599814, 0.060403085579829555, 0.08545233216136694, 0.10401679242828063, 0.021237102836104374, 0.023546318656631877, 0.051579931883939674, 0.07586096147341387, 0.07038756553083658, 0.05343141306989959, 0.04411944953192558, 0.03707391848521573, 0.019657790527812073, 0.008487811511648553, 0.0681876057226743, 0.01305643528965967, 0.042008197999426296, 0.035527778057647605, 0.025129183095746806, 0.05154167268691318, 0.07782020419836044, 0.08637836282806736, 0.035334429504083734, 0.01904415738369737, 0.017268504182408963, 0.03262528344722731, 0.07055466834987913, 0.03816843618239675, 0.026152312123615826, 0.03359820427639144, 0.0619311464418258, 0.04286910626771195, 0.056883799244782755, 0.045183473865368536, 0.08136740885674953, 0.029713659148131098, 0.05206297757104039, 0.061536524045680246, 0.041953759134880135, 0.0066542911476322585, 0.0533260331888284, 0.03518433416528361, 0.036329504501606734, 0.008993359116305197, 0.022389265475794673, 0.04487383458763361, 0.08633722324988671, 0.01062699409002172, 0.01845827971452049, 0.0400317510190819, 0.05105601803266576, 0.03183052895058479, 0.018819155171513557, 0.05510281106191022, 0.041822449038071294, 0.02897635960419263, 0.07161178519683224, 0.09420019561158759, 0.05588467678587351, 0.03999839763024023, 0.02652085672265717, 0.07376956048288516, 0.012827976789724613, 0.03241865935602358, 0.017671984853222966, 0.027384292533887283, 0.042572128453425, 0.08239112142473459, 0.00907299792327519, 0.06558656386498894, 0.020769319097910608, 0.05967037632529225, 0.04363394415538226, 0.053809971149478636, 0.0908734876928585, 0.0070382457010314935, 0.006180467599603746, 0.018859497471047298, 0.030817506701818535, 0.03738891140424779, 0.010468557859504861, 0.017229239057217325, 0.00692607241217047, 0.019816701732841984, 0.020672383585146496, 0.026531764173081944, 0.002910033558561866, 0.023865822137200406, 0.015468625584617257, 0.0309702415418412, 0.06101278322083609, 0.005262049671728164, 0.023470845206507614, 0.017037658087377037, 0.038140256623072286, 0.01894575623529298, 0.02619593683630228, 0.045178310213876624, 0.021844585060275028, 0.010889107078712965, 0.027726165617683103, 0.010612101942699934, 0.030295428287770067, 0.05793312990239688, 0.021450441031317626, 0.03304758667945862, 0.04210327093356422, 0.06308758045945849, 0.015076184678556663, 0.018352589403678263, 0.05146159537668739, 0.06602195943040506, 0.09090748908264296, 0.1264380525265421, 0.14450121112167835, 0.17535342488970074, 0.10728640841054064, 0.09389796254358121, 0.19269189451422009, 0.10628117913646357, 0.15969603934458323, 0.09646539656179291, 0.11823205357151371, 0.23864527153117315, 0.1381652953901461, 0.13879337454480783, 0.07854776337210621, 0.09887211956083775, 0.11911778604345662, 0.12184840094830308, 0.09333437135709183, 0.12270065450242587, 0.16050165040152414, 0.18539769734655107, 0.13919854137514318, 0.08786303816097123, 0.07426115910389594, 0.06435701769909688, 0.16295798788113253, 0.16840837470122746, 0.11745219970388071, 0.12425483896264009, 0.19490039029291698, 0.10549494025430509, 0.1095471310296229, 0.07570281531661749, 0.08800094361816134, 0.1944631558976003, 0.10536584218165704, 0.09978130220302514, 0.09372402009155069, 0.10578296479902097, 0.1834733448922634, 0.18971014022827148, 0.09822504821100406, 0.25321496544139727, 0.13065308492098535, 0.10678341040121657, 0.15518416145018168, 0.049273421721799035, 0.13097194209694862, 0.1372281163930893, 0.14091893977352551, 0.11240075754800014, 0.22808574672256196, 0.19795902259647846, 0.19960342507277215, 0.13515791962189333, 0.13580327427812985, 0.126611608213612, 0.09664192423224449, 0.14987279288470745, 0.17671155344162667, 0.0904028829453247, 0.11191367797021355, 0.2622794061899185, 0.11323301467512335, 0.16889377151216778, 0.1426888033747673, 0.25494387266891344, 0.05575795019311564, 0.10200532964829888, 0.13319902973515646, 0.15493646902697428, 0.16562024716820034, 0.13738005395446504, 0.17420854632343563, 0.11247991544327565, 0.057440343845103464, 0.12603511129106792, 0.15689273976853915, 0.1405481339565345, 0.15525048146290438, 0.09851714396583182, 0.09465420339256525, 0.11901702359318733, 0.1432247781859977, 0.21132925658353738, 0.06333966978958674, 0.07053862099668809, 0.1647417207381555, 0.16596638145191328, 0.1550230500953538, 0.14302279188164643, 0.1764276951019253, 0.18259598554245063, 0.14413833059370518, 0.07895809385393347, 0.09380798201475825, 0.15256975245262894, 0.16407590146575654, 0.1558986995369196, 0.1306529085018805, 0.16445061564445496, 0.08961150076772485, 0.0789297107341034, 0.10358899645507336, 0.09199655135827405, 0.14380417923842156, 0.1430277723286833, 0.13072325901261397, 0.22048873294677052, 0.23830280133656093, 0.09753976176892008, 0.1248610285776002, 0.14613118794347557, 0.14829971800957406, 0.09733801973717553, 0.06023117873285498, 0.1465595063886472, 0.09365993924438953, 0.1422944659633296, 0.17522436752915382, 0.29488021827169825, 0.09649864477770669, 0.1204855769340481, 0.09928908611514739, 0.25750186826501575, 0.07195355650037527, 0.15660181109394344, 0.0670917241701058, 0.11675452999770641, 0.15362682858748095, 0.1406301145574876, 0.10772326282624688, 0.11409141575651509, 0.1111377121082374, 0.19569255278578826, 0.12504812782364233, 0.12929027447743074, 0.10600914087678705, 0.060436720560703955, 0.06731772382876702, 0.08516824311975922, 0.14029141701757908, 0.15881458164325782, 0.10388878001166241, 0.08921499882957765, 0.17973986880055495, 0.11346780814762626, 0.19860569361065114, 0.12366783831800733, 0.13348083889910153, 0.1040852769677128, 0.056917227272476466, 0.12852257995733193, 0.12604284659028053, 0.1278997662344149, 0.16829497792891093, 0.10307135566004685, 0.19929121753999166, 0.10350479704460927, 0.11108652342643056, 0.19299950157957418, 0.14822030227099145, 0.14376904469515595, 0.08352021726646594, 0.1597062580819641, 0.1171892402427537, 0.12379285160984312, 0.12944445120436804, 0.07536236715636083, 0.20039774530700274, 0.13336077891290188, 0.11870322828846318, 0.1020405591864671], [0.025797421345487237, 0.01037857648251312, 0.027073379306654845, 0.04095953230613044, 0.02663906430825591, 0.04270847328007221, 0.05904408171772957, 0.033660612534731627, 0.10013214551976748, 0.06210447821233954, 0.023249252632792507, 0.029890471803290502, 0.0243769676557609, 0.04385878691183669, 0.03746411004768951, 0.01071664468119187, 0.04561762771170054, 0.01132875875503357, 0.0372367431409657, 0.0171962944857244, 0.05537328190569367, 0.021673753691305007, 0.01529494606490646, 0.06510983194623675, 0.05809200887701341, 0.017109784663521817, 0.05347539570980838, 0.03376362093591264, 0.11431489805025713, 0.030123898027730838, 0.04059685194598777, 0.024168396169053655, 0.019745056916560446, 0.04000525761927877, 0.06690995142396007, 0.01815253692413015, 0.05991814338735171, 0.0210383361804166, 0.032924164552241564, 0.06603176426142454, 0.050655254894601445, 0.07104074369583811, 0.03506694421438234, 0.038204887083598545, 0.050793581043503115, 0.06532261374273471, 0.04657536292714732, 0.010357144953949111, 0.048120326096458096, 0.005005569795944861, 0.012891133132922863, 0.04131003296268838, 0.009790444380736776, 0.04408922079684479, 0.06397091770278555, 0.07709730656019279, 0.04400812568409102, 0.024384380650839636, 0.07242335379123688, 0.05444694250555975, 0.016481269550110613, 0.07661646271922759, 0.058256892886544974, 0.03691876127517649, 0.0461764589750341, 0.01756164148849036, 0.018887076526880264, 0.009880441024766436, 0.01539545745721885, 0.021616765231426274, 0.02887750044465065, 0.021545680206535116, 0.04924102846000876, 0.1015416866700564, 0.012559332053310104, 0.03589934044118438, 0.06454767246863671, 0.017058740170406442, 0.016813612609569515, 0.06667956842907838, 0.029007728278104748, 0.017643856184024895, 0.012064825909744416, 0.044262667918311696, 0.04157804072435413, 0.02356935492051499, 0.013851826761050947, 0.05322052438610366, 0.0761609146637576, 0.03272172362942781, 0.06282622234097548, 0.022347313351929188, 0.02866198754470263, 0.07269633521458932, 0.03980692183332784, 0.012871222370969397, 0.02856781706213951, 0.047060735989362, 0.06355844305029937, 0.032257972085582357, 0.03910031582095793, 0.014032864144870212, 0.053825054982943196, 0.016193085549665347, 0.031117293651082685, 0.059676761339817724, 0.017239451009247984, 0.0352609984443656, 0.03546605172700115, 0.06388967670500278, 0.02786051724771304, 0.04160835088363715, 0.033739909529685974, 0.012455800331995955, 0.040856798711631975, 0.03059534076601267, 0.0561141132244042, 0.04728531411715916, 0.009959095107790614, 0.028656399808824062, 0.02472503067526434, 0.04108465077089412, 0.007998323982714542, 0.013562172884121537, 0.05745002653981958, 0.05482644374881472, 0.0721207678850208, 0.045142188402158875, 0.0762092060010348, 0.019814971468544433, 0.03938300368775215, 0.11084119230508804, 0.03174948472795742, 0.004076753742992878, 0.07021244242787361, 0.010735183954238892, 0.07160007368241038, 0.008925135812855192, 0.050941386326615296, 0.017291063775441477, 0.019522259943187237, 0.05741624228124108, 0.047243828486118994, 0.05157832714862057, 0.06106038923774447, 0.04607942507469228, 0.023781480234382407, 0.04847931522609932, 0.023178321974618093, 0.07665824012032577, 0.03402211224394185, 0.017013671874467815, 0.014285771109695946, 0.04992608080751129, 0.013162015338561364, 0.005754838273527899, 0.05401228315063885, 0.02612042097773935, 0.03365158462630851, 0.06238443497568369, 0.05116685672796198, 0.03373780607112816, 0.02520307047026498, 0.010241209612494069, 0.051260223146528006, 0.035083357976483445, 0.02462407823518983, 0.023666992717023407, 0.032096053274082284, 0.012529842921399643, 0.026298178492912223, 0.028293931490874717, 0.048464017654103894, 0.03707421364794884, 0.048438630266381164, 0.021602977399847338, 0.019877793633245995, 0.0159887091057109, 0.007937668889228786, 0.03282126132398844, 0.07330411260149308, 0.06735956908336707, 0.01696657475882343, 0.011108668288215995, 0.06000537584934916, 0.05316132899107678, 0.04312641013945852, 0.022408096518899714, 0.019162327649870088, 0.02288515752713595, 0.021199379681742618, 0.030278722755610943, 0.039660972343491654, 0.029473047237843275, 0.02852847220908318, 0.01898693143656211, 0.020374662775014128, 0.039607938046434095, 0.02302169064725084, 0.019047263377745236, 0.07069659751972981, 0.0467134821228683, 0.012523387508865978, 0.03786124302340405, 0.04460941627621651, 0.019393424802858914, 0.03331712453759142, 0.03183209975915296, 0.06294951893921409, 0.03434501009594117, 0.03970726878781404, 0.02306642985370542, 0.10236227978020906, 0.06746788362839393, 0.035544408950954676, 0.01949153927021793, 0.02500671431023095, 0.056854930972414355, 0.02693034242838621, 0.00954038811115814, 0.04381678559418235, 0.03165366201262389, 0.04587346934048193, 0.008205345016904175, 0.03289536752605012, 0.012067364478882934, 0.05529875161924532, 0.04903834326458829, 0.015902575870443667, 0.09130990784615278, 0.05795905672545944, 0.02030254468055708, 0.027878035325556993, 0.045417602373553176, 0.006879700056742877, 0.03509245373840843, 0.01859316060186497, 0.034598422569355795, 0.07608471518116337, 0.04444065783172846, 0.11042825624878917, 0.015401613466175539, 0.06342361135674374, 0.04535499734005757, 0.02700983959117106, 0.06362563837319613, 0.035951560496219566, 0.019872704620606134, 0.0539652708518718, 0.07175150234252214, 0.02911770184125219, 0.04333960584231785, 0.04226681822910905, 0.032712583762726614, 0.04148722220478313, 0.02225361275486648, 0.0498749701572316, 0.03929493323500667, 0.024548307925994908, 0.07511984516999551, 0.010813572560437024, 0.047467276853110106, 0.01979894786407905, 0.08294267539999314, 0.09244043539677348, 0.07943620319877352, 0.01887982807654355, 0.046662100058581145, 0.04117742347131882, 0.04985324346593448, 0.06517794329140868, 0.06864539972905602, 0.03559163159557751, 0.008896177634596825, 0.024667119407760243, 0.060534300681735785, 0.009831706095220787, 0.02364908278520618, 0.07359216428760972, 0.007342143300255495, 0.038580028739358695, 0.03239091745178614, 0.0839107141696981, 0.044592150952667, 0.009804522286036184, 0.01473583490587771, 0.028043285743998628, 0.018357486730175357, 0.011001127273110407, 0.01250417054896908, 0.01888621987641922, 0.03336199266569955, 0.04144716828263231, 0.11013664903917483, 0.019568854942917824, 0.07357925176620483, 0.03734774807734149, 0.0637040159532002, 0.05328465612339122, 0.026434601351086582, 0.03305416846913951, 0.03505643031426838, 0.10157549807003566, 0.029608920482652526, 0.09041422805083649, 0.015208595698433263, 0.019429331179708242, 0.08804915353123631, 0.020573312383411185, 0.04607169656082988, 0.034633326410715065, 0.027268829622438977, 0.038606481427060704, 0.03268818025078092, 0.004583611768404288, 0.018381187958376746, 0.006736619497782418, 0.023246014324416007, 0.023915351800886647, 0.023652584025902406, 0.033832041014518054, 0.01696398784406483, 0.034869246251348934, 0.043832503857889345, 0.0023452945876800057, 0.1068939505411046, 0.05437547241204551, 0.05933007744273969, 0.012243682651647499, 0.05530705688787358, 0.01115680271427014, 0.007767248882113823, 0.033791335698749335, 0.027928757514538508, 0.053082805526043685, 0.012904346754242266, 0.062302488301481516, 0.019861011765897274, 0.024677268595301678, 0.021604778910321847, 0.022923033351876905, 0.0345866228453815, 0.03548869104789836, 0.03585062162684543, 0.023554495003606592, 0.04965408665261098, 0.01610603289944785, 0.04366663597258074, 0.019847200185592686, 0.052333227890942774, 0.03821331448853016, 0.004703431298756706, 0.08469282077359301, 0.10432661830314569, 0.14504086359270982, 0.11998612087752138, 0.1829387407217707, 0.15627387511943067, 0.13935057393142156, 0.12708895759923117, 0.17780368269554206, 0.18164577867303575, 0.06672897256378617, 0.07367327636373894, 0.12483677773603372, 0.10592139951352562, 0.11242367167557989, 0.0957716487880264, 0.0851842633315495, 0.06281349302402564, 0.051401032733597925, 0.1139736899307796, 0.08902838812874896, 0.20072832756808826, 0.08579927390175206, 0.09897902953837599, 0.15086920798889228, 0.10100426657923631, 0.12990175666553633, 0.09344599715300969, 0.2689672644649233, 0.07639971149287053, 0.17426576039620809, 0.1186258074428354, 0.20792609133890697, 0.18453583573656424, 0.1327251951609339, 0.13441283388861588, 0.20562028006783553, 0.20068399208996976, 0.11680467373558454, 0.1326603814959526, 0.18088786862790585, 0.25594560748764444, 0.15082336616303238, 0.058071374627096314, 0.15377227935407842, 0.13547474119280065, 0.12025326011436326, 0.06376925709524325, 0.14015455650431768, 0.12053631778274264, 0.093665632153196, 0.20006219616958074, 0.05374647384243352, 0.248430642166308, 0.19122768379747868, 0.21537871286273003, 0.08035969614450421, 0.09093970592532839, 0.18922254496387073, 0.08068898240370409, 0.14739098320049898, 0.16460593231022358, 0.20740796199866704, 0.18105360759156092, 0.16160705180040427, 0.07120088474558932, 0.19321311797414506, 0.14523378466921194, 0.15733669166054043, 0.10905720160475799, 0.1273021533020905, 0.06979387453091995, 0.20823415980807372, 0.18455004425985472, 0.09857912813978535, 0.20765011757612228, 0.1419771287058081, 0.07823302490370614, 0.12152852596981184, 0.09248252492398024, 0.12632422149181366, 0.12064269850296633, 0.0994481211528182, 0.10903306611414466, 0.10441775912685053, 0.08503778119172369, 0.12095787801912852, 0.16325807677847998, 0.2409186895404543, 0.10824573479060616, 0.1457172001578978, 0.1064708296741758, 0.12164558683122907, 0.15623487292655877, 0.17338883530880722, 0.11811029724776745, 0.1874581232134785, 0.17611807957291603, 0.09745651909283229, 0.15642997888582094, 0.11818129915211882, 0.09930279252252408, 0.14083908977253096, 0.11607887196753706, 0.14188047817775182, 0.11912187082426888, 0.15066107415727206, 0.12460410807813917, 0.09122858542416777, 0.0665142365864345, 0.09568310675344296, 0.11994251821722303, 0.18757457339337893, 0.0961948646498578, 0.1571117437311581, 0.1499161919845002, 0.18308742131505693, 0.15463559302900518, 0.08297580147960357, 0.0858218012643712, 0.14797658606299333, 0.14241531305015087, 0.12583077725555214, 0.1339939335095031, 0.0700157011992165, 0.15212748332747392, 0.25224827017102924, 0.12993382423051766, 0.17728125144328388, 0.10245492016630513, 0.06984308189047234, 0.29775601252913475, 0.19845193757542542, 0.10542541077094418, 0.1436854898929596, 0.1266610598457711, 0.08321795705705881, 0.11394850271088736, 0.11118792369961739, 0.14064231461712293, 0.1255574497793402, 0.13961685821413994, 0.12298528637204852, 0.12740465280200752, 0.10469697628702436, 0.12601881287992, 0.1688780023583344, 0.08199057541787624, 0.046495434894625626, 0.1713403652289084, 0.18825622967311315, 0.08788106683641672, 0.09398991760930844, 0.11272859174226012, 0.12599910822297844, 0.06357392721942492, 0.0896795035472938, 0.13106997683644295, 0.12708545635853494, 0.1428212941225086, 0.18186400910573347, 0.12807725742459297, 0.087134807237557, 0.08180559998644249, 0.09517527078943593, 0.16404194757342339, 0.11881776499961104, 0.14045446898256028, 0.16926035684134277, 0.12270795553922653, 0.11933119887752192, 0.12106991772140775, 0.13217388545828207, 0.10392789077013731, 0.11325821546571595, 0.08154717313924006], [0.09560725332370826, 0.02760121169766145, 0.012086891868550862, 0.08092100066798073, 0.05053341036130275, 0.02772574662230909, 0.024553122131952217, 0.01800178171002439, 0.012742195544498307, 0.05795498551534755, 0.055670273290680986, 0.06480443011969328, 0.023653991986066103, 0.03204641843746815, 0.016856797970831394, 0.018358331506273577, 0.03720856697431632, 0.030779138939189057, 0.0416516549885273, 0.028103968827053905, 0.016024764760264328, 0.017549295543826053, 0.04233372178194778, 0.03033485117235354, 0.04331187750878079, 0.036778304526316266, 0.028274608509881154, 0.033528684971055815, 0.013702638962838267, 0.016262915284772004, 0.034450800490698645, 0.0016126906120916829, 0.014333624791886126, 0.06562178661780697, 0.027371229038440754, 0.07330884877592325, 0.021927301871723363, 0.048531012809170146, 0.01743610911736531, 0.015594873810186982, 0.03807010967284441, 0.0627551729391728, 0.020720444220517362, 0.03157856175675988, 0.027605220143284117, 0.04615328021879707, 0.028831790933119397, 0.02095934622255819, 0.03917278675362468, 0.02788641014402466, 0.0012306357447024702, 0.02274267535124506, 0.051720168108918836, 0.019878587519217814, 0.029720597168696777, 0.04820956023676055, 0.0187220398469695, 0.042221576906740665, 0.039711187327546735, 0.0684995621974979, 0.02430946529576821, 0.037920777685940266, 0.024887534723218, 0.02387068553694657, 0.05512317389781986, 0.07724151560770613, 0.0382218267103391, 0.05328598265935268, 0.024129161577937857, 0.060890456927674155, 0.05561569871913109, 0.030748547187873294, 0.04337961565969246, 0.062224402491535456, 0.022288993267076354, 0.02770959579252771, 0.00861372725505914, 0.03694352101800697, 0.024500381301290224, 0.035860826793525896, 0.03310727061969893, 0.018814661573352556, 0.018497429488758956, 0.09599779093904154, 0.12358963037175791, 0.04640857901956354, 0.019296577499647225, 0.0060043729193109486, 0.03142741468868085, 0.06066808064601251, 0.07333934213966131, 0.022323110007814, 0.02960372290440968, 0.08210061344185046, 0.025761340245870606, 0.029882146178611686, 0.04812489602980869, 0.016399338142946362, 0.005480096475886447, 0.02993236794801695, 0.03391120908781886, 0.050323848213468275, 0.05046569935179182, 0.042530140706471035, 0.03204696126548307, 0.0634100745831217, 0.03523776201265199, 0.07869250846228429, 0.024781084453154887, 0.035694344834025414, 0.04968002365369882, 0.0185573000261294, 0.05046557043013828, 0.01259288560998227, 0.003941741813572922, 0.028781016157673936, 0.012467287929861673, 0.05028004199266434, 0.021851643520806516, 0.014962136512622237, 0.03903420276141592, 0.03450434368902019, 0.03575174550392798, 0.00881292053963989, 0.026391158146517615, 0.03128986885505063, 0.02627204980568162, 0.037673950394881625, 0.06295687425881624, 0.030744737213743583, 0.06859232471989733, 0.035214817350996394, 0.03135166643187404, 0.032418537219720225, 0.06330707296729088, 0.0444834598207048, 0.028101195315165178, 0.05597998720726796, 0.03383640738736306, 0.017653867968225052, 0.060248935994293006, 0.054792347364127636, 0.025729734084701965, 0.05306414242035576, 0.010641665713462447, 0.0038273293591503587, 0.01082637906074524, 0.08418965991586447, 0.06304618303797074, 0.040627056932342906, 0.02853589877486229, 0.022655933130798594, 0.026295793442321674, 0.018347948224150708, 0.04827058767633779, 0.026949612822915827, 0.02668917751205819, 0.03444158259247031, 0.02158359165436455, 0.025084616915721978, 0.039556586516222784, 0.006993259677463877, 0.01141424653386431, 0.012041167938150465, 0.01776538010952728, 0.015871370044936026, 0.03775474355955209, 0.08221141142504555, 0.017455849397395338, 0.03640605342973556, 0.04157550300338438, 0.027835789735295942, 0.08312355926526444, 0.014435379599620188, 0.045095715538731644, 0.013877257405381118, 0.02096423167469246, 0.016193704712869864, 0.016184005054778287, 0.05359198498938765, 0.055774940709982596, 0.06767396149890763, 0.008784788477766727, 0.01353021727741829, 0.016540130766640817, 0.03500218143952744, 0.06594496606183903, 0.034247334980006726, 0.06795761627810341, 0.010386412713809736, 0.11975676247051784, 0.019294735277071595, 0.02401137807672577, 0.04498699387269361, 0.053389089448111396, 0.018181169405579567, 0.03712090024990695, 0.05644518742337823, 0.020912936123620187, 0.025319462974688837, 0.023525441830445613, 0.03130009098510657, 0.04280307123969708, 0.044447331223636866, 0.03916760953143239, 0.05008052555578096, 0.015146092445190464, 0.036504444400114675, 0.029428786398576837, 0.08387708597417388, 0.024756882805377245, 0.036244541739246676, 0.010077096588377441, 0.061086777464619706, 0.04907100794038602, 0.04625657021201082, 0.03210977664483445, 0.018333690507071357, 0.01854784124796944, 0.06033032626977988, 0.01573313889093697, 0.05571647474010076, 0.040032958811415095, 0.06289391977978603, 0.019977818176682507, 0.03643106423052294, 0.045182015015078444, 0.04694628070241638, 0.03624991912926946, 0.006601851416884789, 0.03340252495503851, 0.06337776274553367, 0.08382841465728623, 0.04266152883480702, 0.020654726407623718, 0.01636052593987967, 0.014067730666803462, 0.028123232436233332, 0.014980036266414183, 0.01534187185045864, 0.07675131476883378, 0.05839169065334967, 0.023955080026228513, 0.08729328587651253, 0.024430375147078718, 0.06092605966010264, 0.01199641770550183, 0.015133263044325369, 0.007290147161776466, 0.02260359942114779, 0.030457920461360897, 0.03314758917050702, 0.013047446397000124, 0.0187364994282169, 0.02514079282991588, 0.06336552875914744, 0.029385648534766266, 0.03057257252346192, 0.027244780645040528, 0.037229062124554596, 0.02680443347032581, 0.0761007150369031, 0.014575166295149496, 0.012759526177043361, 0.019134312635287642, 0.025779638638986007, 0.05249384052253195, 0.07097540077354227, 0.028231804824567268, 0.03703958800594721, 0.04292432884020465, 0.02590339833737484, 0.015225062046998313, 0.02558584394864738, 0.0280671718729926, 0.04611884456660066, 0.035911842448902984, 0.048927837051451206, 0.053795419966003725, 0.0323980658182076, 0.0159038141968527, 0.015642064224396433, 0.0025138696156708257, 0.09318500544343676, 0.027816383633762598, 0.040447815121816735, 0.04511303175240755, 0.03270296213616218, 0.02349870076536068, 0.04891532486570733, 0.09922528346734387, 0.04556014222492065, 0.01987182761409453, 0.04381591706935849, 0.020718194876930544, 0.03683675692549773, 0.018481896125844548, 0.03643143063943301, 0.06517334960933242, 0.027218612942046354, 0.0298458920525653, 0.044585711655340025, 0.049269303014235835, 0.04775465000420809, 0.031036853324621916, 0.0632794498066817, 0.05850381177983113, 0.06250350430075612, 0.04514735883900097, 0.016011136384414773, 0.07525027317128011, 0.04031762460778866, 0.04581385664641857, 0.0070608888386881775, 0.008629133392657553, 0.02551872156826513, 0.012953528668731451, 0.023320295249244997, 0.06133325531014374, 0.077869126573205, 0.020632166814591204, 0.016182834581871117, 0.052171957080385516, 0.10451038594224624, 0.06725324264594487, 0.0599685042564358, 0.0810475813757096, 0.022789031167381575, 0.04210768819653562, 0.027793301568765725, 0.008977997083482998, 0.045927158423832486, 0.06372939994824783, 0.008580308557221932, 0.015242469862901738, 0.006186856854973095, 0.13239317440560885, 0.033990495904747925, 0.03888766294611352, 0.011947072942608168, 0.010777826487485851, 0.013701779767870903, 0.024007303473938788, 0.03105892606877855, 0.003598397581039795, 0.020219381732333983, 0.04561143268698028, 0.07554696260818414, 0.09730681391166789, 0.00885787433279412, 0.012670637241431644, 0.005978642871403801, 0.2847546030368124, 0.07155957871249743, 0.09018242691776582, 0.19296375635479177, 0.1594848928174802, 0.14526027467633995, 0.1189284340611526, 0.10196459040577922, 0.11496296684656825, 0.1224068488393511, 0.1311640896435295, 0.12817888839968614, 0.191692995971867, 0.13164373247751168, 0.2058882335466998, 0.11791694190885339, 0.11943144564117704, 0.2990846655198506, 0.15211787527160986, 0.13197013496288232, 0.11504202974694115, 0.12088550547403948, 0.10080698252256427, 0.12264654812003885, 0.09326277234192405, 0.07264839671552181, 0.14227197931281158, 0.10842954314180783, 0.08644726127386093, 0.1208443319691079, 0.14600303981985363, 0.10954011497753006, 0.12839373972799095, 0.1793491140540157, 0.07372092309274844, 0.15528127338205064, 0.12082561797329358, 0.18213815082396778, 0.11302707929696355, 0.06923398136028222, 0.1405548650239195, 0.11485167353280953, 0.15173809922167233, 0.10150209415171828, 0.07547096668609551, 0.13410222769847938, 0.17278925462492875, 0.1442798322864941, 0.08693207454468523, 0.08094791815217052, 0.07971893517034394, 0.1395207369433982, 0.1906744741967746, 0.09012492107493536, 0.08212050808859722, 0.16769113604511532, 0.1574766191520861, 0.12327489868870803, 0.11912269863699164, 0.10926126422626631, 0.12355654500424862, 0.1255410835146904, 0.07199965616954224, 0.10561075939663819, 0.23928038030862808, 0.15642459131777287, 0.11518943469439234, 0.23588575103453227, 0.07142137469989912, 0.11303391892995153, 0.10586841949926955, 0.10872790177485772, 0.11820369080773421, 0.2276196881596531, 0.09114712729517903, 0.07781809395445244, 0.0747347426201616, 0.1349946776671069, 0.12868496695799486, 0.14631114900112152, 0.12979742512106895, 0.1371888563569103, 0.12277450625385557, 0.1713587806693145, 0.16804240005356924, 0.1364491581916809, 0.06321141988571201, 0.08988731168210506, 0.08939886146358081, 0.2013802911554064, 0.11834710596927575, 0.14392582699656487, 0.09836550495986428, 0.09360024851879903, 0.1953497976064682, 0.10425487679562398, 0.15358756855130196, 0.12527235650590487, 0.150422636951719, 0.15737584313111647, 0.10221750076328005, 0.18452436849474907, 0.14879451931587287, 0.08534723387232848, 0.1273649042206151, 0.15409394566501888, 0.13035789504647255, 0.13034972548484802, 0.08883314646248307, 0.12298874690064363, 0.11955161419297967, 0.08007792090731007, 0.21320472737508162, 0.13041011510150774, 0.1437727359256574, 0.17604958824813366, 0.11145221308938094, 0.13410123703735216, 0.06920061779341527, 0.16609476027744158, 0.21420381590723991, 0.1379502405013357, 0.1645626960588353, 0.14578896202147007, 0.13815941927688463, 0.1040477811225823, 0.2058445494621992, 0.1459766583783286, 0.09320676606148481, 0.1778616024447339, 0.18020210042595863, 0.1077347911362137, 0.15926906439874852, 0.10149517309452806, 0.16330417644764694, 0.11822141414242131, 0.10963232788656439, 0.131179899509464, 0.1264951444630112, 0.1232051317180906, 0.1664373797497579, 0.15743197154785904, 0.08689983056059905, 0.1788884430591549, 0.1052343760217939, 0.10140526720455714, 0.14252576498048647, 0.25677029894930975, 0.1749900829579149, 0.10120991018733808, 0.13955584434526308, 0.10867048414157969, 0.09392817092261144, 0.061121776300881586, 0.15696063398250512, 0.12481380254030228, 0.13678007972027573, 0.09204669509615217, 0.06325425580143929, 0.0891223448727812, 0.1826946988169636, 0.10003398185861961, 0.1166831481137446, 0.07547695815031018, 0.11264805642089673, 0.13642851715641363, 0.09546247430677925, 0.19303451398653643, 0.04061367282910006, 0.14088822927858147, 0.14661540410348348, 0.12129790548767362, 0.21053729765117168, 0.11023117575262274, 0.1856454847646611, 0.13351053159151757]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.05286295000197632, 0.013916696405171283, 0.015631933696568012, 0.011109588551335037, 0.04957691007958991, 0.08997451700270176, 0.015194772243765848, 0.053908219627503834, 0.021071000856214335, 0.030528420249798467, 0.05444779745968325, 0.015354438319004007, 0.025172870572922484, 0.009680235026670354, 0.0378198014971401, 0.03708634585408228, 0.02670349120827658, 0.012143442673342568, 0.036438049748539925, 0.028167330427095294, 0.0500994295414005, 0.04822915293542402, 0.048768690055502315, 0.012450816492283983, 0.019384815889809812, 0.10268775267260415, 0.041176005333129845, 0.061573510989546776, 0.07169616102640118, 0.04411484906449914, 0.0013555055899944688, 0.01106295538400965, 0.004100110614672303, 0.03950569638982415, 0.07304230664989778, 0.03743320617026516, 0.0662179814119424, 0.024877159922782863, 0.05909189808049372, 0.04262959697682943, 0.03870845506233828, 0.07391590013035707, 0.07564715508903776, 0.01975467854312488, 0.03717345617977636, 0.03999240955870066, 0.02220017133679773, 0.03921961245526161, 0.02965305240026542, 0.007682881534232625, 0.03941446057121668, 0.023532354405948093, 0.029999363103083203, 0.05591628973239234, 0.02920207767082112, 0.02895372367597052, 0.05365567567891308, 0.03460485508133258, 0.06066867097147873, 0.03640615860266345, 0.03548378184703844, 0.029680098806108748, 0.04695375815832189, 0.0024854962497816552, 0.001683139192339565, 0.06872497153069292, 0.007658313477544912, 0.05823053180107048, 0.01983696278849883, 0.03372656613854425, 0.007182187151296863, 0.09826562460511923, 0.04619600756892136, 0.04115674850930061, 0.09246337666575398, 0.02644598886503705, 0.04347188285152827, 0.02178609025265489, 0.08143334888986178, 0.07418253046593495, 0.0428723428797509, 0.02503048848094685, 0.029997687121587138, 0.0873150397092104, 0.07160919319306101, 0.021228161440896134, 0.030414752063474486, 0.007537961721287242, 0.041700658787574084, 0.015691441217703477, 0.0625985467008182, 0.04807597365496414, 0.03333506500348449, 0.008489023544825613, 0.015895463127110685, 0.0500635825363653, 0.03495132863255484, 0.11734349839389324, 0.02243432868272066, 0.04772401414811611, 0.029621707475078956, 0.04063642071560025, 0.03864716638677886, 0.04661863649796162, 0.040364246748919995, 0.007398678838009281, 0.03175592741795948, 0.030066527891904116, 0.030489356988774877, 0.0567700157075056, 0.07228289704237666, 0.04837337216096265, 0.032477037116353, 0.02865160595891731, 0.07369742542505264, 0.03302409579711301, 0.03519486163609794, 0.030799936037510633, 0.024899895934920226, 0.03360408717500312, 0.02534978331199714, 0.03767896816134453, 0.03208952915987798, 0.06792699399271182, 0.020125833805650473, 0.021016489049153667, 0.029589361710739986, 0.04626113675268633, 0.01803332001769117, 0.07312077243945428, 0.027450604064922248, 0.07164789683052472, 0.03235451065536056, 0.04140396595799497, 0.075449735325362, 0.02408848679624498, 0.050909488395388634, 0.04582962240757687, 0.04412351056401219, 0.03331456306789603, 0.02473767178266176, 0.08426315204373427, 0.02154722048102745, 0.010391356689589364, 0.06068941378699882, 0.025396834626527767, 0.020693136578691856, 0.041989134558077366, 0.02331181356151189, 0.007751137068096016, 0.02329762539427195, 0.02067299765933837, 0.02233584611011403, 0.07842566099550043, 0.029948778317442963, 0.015066720811384065, 0.013762433165019112, 0.033380238472351005, 0.027591569715046456, 0.011800171807408333, 0.031848947783665996, 0.04407784176458206, 0.026024013025952236, 0.020493530235918503, 0.023611486856160418, 0.04704883448513491, 0.021494479650365453, 0.019532722953174795, 0.03590212922011103, 0.010161770125185805, 0.051543694721268754, 0.021055593022278378, 0.04663873131253889, 0.05230347413037505, 0.023021711003301398, 0.03328593906813434, 0.045062212872185876, 0.024113806330465844, 0.030758718427802836, 0.04194849370313542, 0.019155786572290317, 0.06278346106410027, 0.06624382681080274, 0.07209564173328024, 0.022582334133663347, 0.06331759704543011, 0.05266644965325083, 0.03880196397325822, 0.03932564712262579, 0.04369385201217873, 0.02319115137548319, 0.015101376987461532, 0.05909539253583976, 0.011907230214481907, 0.02943352935835719, 0.03989524334403021, 0.02994151120739324, 0.037376426359904666, 0.046899000382316966, 0.068755356328828, 0.07269894757441112, 0.02160559654501932, 0.06806299276649952, 0.02487940587369459, 0.023918300035542676, 0.01006186771805265, 0.015547194850764104, 0.04901371244341135, 0.05725447953279529, 0.05511135042511991, 0.04957533927102174, 0.01928434520959854, 0.05240861313151462, 0.01201252527867577, 0.05499105973701392, 0.028861229174903462, 0.08888641146144696, 0.029630891446556364, 0.03000082534604839, 0.018701251230335662, 0.07469149279807295, 0.00776860849665744, 0.003138228914135003, 0.044875809124537876, 0.04590330791792699, 0.006560802168678492, 0.01996448326722852, 0.027939398639968464, 0.08957732295883553, 0.09378013493759291, 0.035044447385839055, 0.04983368469402194, 0.0027942108115114805, 0.08216320151197058, 0.07939921625490699, 0.010696890830461468, 0.009963312202931514, 0.014347224329997386, 0.016718205496934906, 0.02725609521647649, 0.028369030050401176, 0.02490608756696539, 0.01927438940453742, 0.02247909503057599, 0.018397671270317266, 0.025886947255847708, 0.03402107747803841, 0.02139239914582244, 0.04140718899933355, 0.04070240146081362, 0.05187986811090793, 0.051279805667166195, 0.08930854166724853, 0.048111213371157646, 0.061384823971561024, 0.040558474005333016, 0.045097656148884974, 0.024533417475010668, 0.052501304407737086, 0.015463104005903006, 0.04270527398745928, 0.027496539189347198, 0.023597090039402246, 0.025881356127294045, 0.0871072451450995, 0.0871516213353191, 0.012074486552072423, 0.04157686007342168, 0.013017230384450938, 0.006508714852056333, 0.01600631369676973, 0.024896026588976383, 0.06693986803293228, 0.05125811968797019, 0.07751725866858448, 0.012563129304908216, 0.01265642193279096, 0.03232423781550356, 0.022342585659186755, 0.03106836449088795, 0.01595192063333733, 0.05136206786015204, 0.024217878335288594, 0.03589654487690755, 0.026570846093818545, 0.026794655780707086, 0.08026714396796056, 0.022169308171474507, 0.04317084061247962, 0.024334864557853768, 0.02736267101551805, 0.01905029982195369, 0.019577217887022665, 0.030826694065971032, 0.022789543461320654, 0.02062236876892192, 0.022524319389568906, 0.027446704184902564, 0.0695667824308787, 0.04980431091306465, 0.02254399181609707, 0.021388714700671177, 0.03574087876560433, 0.05045166385493108, 0.021620626095682383, 0.03339605173096061, 0.042048774393541474, 0.06162010598927736, 0.035940466448664665, 0.04577138035425118, 0.03564169730192848, 0.039392852623547824, 0.03626014804467559, 0.031076934388173477, 0.05218646415908422, 0.06404304597526789, 0.03520770291132586, 0.07326448615640402, 0.06578516427959714, 0.01810257978338216, 0.04264524060168436, 0.02210905765449362, 0.017896422185003757, 0.04917447096002953, 0.025884258560836315, 0.03718185983598232, 0.045002566251371584, 0.009722669758567852, 0.02054775705827134, 0.052582301132913144, 0.05480954822685037, 0.059827531820961406, 0.026291856242875968, 0.017607970163226128, 0.05746317654848099, 0.006254430037058357, 0.01400368713906833, 0.052386323256152015, 0.0167736825200596, 0.03856077870087964, 0.03860228468797036, 0.028879301955125163, 0.0082874647175361, 0.021159588691911528, 0.01441002613864839, 0.015163547758545195, 0.01753394877804177, 0.020847306520278965, 0.04209642790790115, 0.051744466447936635, 0.046987220112766535, 0.03174037539533206, 0.1737824941852263, 0.12306082089032445, 0.08313430725995984, 0.12771748458700521, 0.1530489610241992, 0.1288639237838132, 0.18488157646996634, 0.10502486476408583, 0.1249027449105467, 0.1409004700503179, 0.17525606868522509, 0.11865137464233808, 0.13741460495761462, 0.09346002925719533, 0.1243527787072318, 0.060989122704735825, 0.12369085422583989, 0.09713470350418772, 0.13929312915674277, 0.10453012452593871, 0.17171046536947998, 0.1535183579793998, 0.10345626143472535, 0.13854741917124816, 0.0996876440144011, 0.14824624945010456, 0.17603898953114236, 0.12780698335596494, 0.1225695072540215, 0.12369559040027005, 0.1405599947486605, 0.10788783470966987, 0.238330675555127, 0.1540721511202199, 0.10126239487103053, 0.1539759212838752, 0.15829299177442277, 0.08696257469377347, 0.16362874688846724, 0.10743230701025043, 0.20555495071624005, 0.13060243906719343, 0.18073318978505476, 0.22080609734569276, 0.08060457943273441, 0.11395166468407426, 0.10796087221907717, 0.1405571720429829, 0.09526875255895512, 0.06703155168465205, 0.08583894105894224, 0.14598397298582963, 0.1906759398324149, 0.17340174104486192, 0.14309665720377648, 0.17442924662360124, 0.13715828156897, 0.18857476115226746, 0.11602772399783134, 0.1802496521600655, 0.08269184814499957, 0.0929481220830764, 0.1481052227318287, 0.1430541809116091, 0.05168467054941824, 0.24604616154517445, 0.06743244374436991, 0.19673125419233525, 0.11383490916341543, 0.07950421276369266, 0.12181758188775607, 0.13996586948633194, 0.1496319536651884, 0.08251951382096324, 0.1825625201953309, 0.12484844853835446, 0.16118356452456542, 0.15013735368847847, 0.17835151829889842, 0.18361006969852106, 0.14574725925922394, 0.18805637396872044, 0.2424382008612156, 0.12309180279927594, 0.09243092912116221, 0.053635170350649526, 0.07666687108576298, 0.06249202348824058, 0.10517920433942761, 0.24410671847207205, 0.09363557305186987, 0.10509438746209655, 0.06942654959857464, 0.07509036282343523, 0.09622431985501732, 0.14726332362209046, 0.1713288572749921, 0.26330779386418207, 0.10701346091393914, 0.12598014995455742, 0.10420564229467086, 0.20953556283244065, 0.20582298561930656, 0.13610942927854403, 0.09545921733868973, 0.1526278214795249, 0.08298668518130269, 0.16773355805448123, 0.11035242996045522, 0.15204266645014286, 0.1282394001526492, 0.10197910426982812, 0.12060892102973801, 0.19224535061844758, 0.09279773836689335, 0.1082752849906683, 0.10843634884804487, 0.13518146478704043, 0.10472217707761697, 0.08453600454543318, 0.1436859920088734, 0.1173345824437482, 0.1271196680941752, 0.11519419801022325, 0.14104406163096428, 0.06981349097830908, 0.0881762227841786, 0.15551914061818803, 0.11925361518348966, 0.11622449915323939, 0.15997601646397794, 0.14242825949830668, 0.1378578104610954, 0.10916877990322453, 0.1455774897975581, 0.11357509810477495, 0.0948934480547905, 0.12484805498804365, 0.1009965380653739, 0.15539614936070784, 0.1308490051222699, 0.2148939674454076, 0.13508712127804756, 0.12357578825737749, 0.1376942970923015, 0.09037879495216267, 0.16332043414669378, 0.12581215825464043, 0.13638224106814179, 0.13794946697141441, 0.11162800115666219, 0.11457420699298382, 0.10477689414152078, 0.18639679944940976, 0.1571466882846185, 0.08925909003508942, 0.14262084130729946, 0.11096373572945595, 0.11264097930065223, 0.12306514994374343, 0.06444116961210966, 0.11570429349584238, 0.1264500490256718, 0.15841390671474592, 0.14209006407431193, 0.183932699529188, 0.057076180885945044, 0.21469764012311185, 0.15674796753696033, 0.086687700157719, 0.12348635734191962, 0.09435589225696665, 0.15040107310882636, 0.10082511297826256, 0.15382166313273565, 0.10105715159858976], [0.04469000588038138, 0.018620478421715752, 0.07225978613964149, 0.015596911111580474, 0.04737408685364893, 0.009240882753926729, 0.027096837958587066, 0.01515626029244491, 0.02924234533150281, 0.03845876096082585, 0.04827873009656157, 0.042065887046711783, 0.0788909528138382, 0.03670111098991973, 0.014255091148827757, 0.03993793337472847, 0.03509079132761274, 0.015935333844806467, 0.10138978303543159, 0.002006418084160292, 0.04229336591171367, 0.08341940731874534, 0.030113855709454844, 0.037471550184168985, 0.03157146428046482, 0.02303788727814598, 0.04675122902595571, 0.018636442654367005, 0.036294020512806516, 0.06366833179656949, 0.06554814521223307, 0.04577105805011732, 0.018568738430206264, 0.025977565607588207, 0.0625842838947262, 0.019972683362928883, 0.046636526073728285, 0.034898511466703246, 0.008945268795027264, 0.06351201768432345, 0.0955724919747029, 0.031128577688442807, 0.026144466562462703, 0.0559428713417479, 0.02001972958844687, 0.023554092971608043, 0.0444392329081893, 0.012218253703654876, 0.014468787271263344, 0.028770654927939177, 0.03215735891301717, 0.03651270556396671, 0.02014114664468382, 0.02905293906639729, 0.046774889542055983, 0.0397998616764588, 0.019013436710728065, 0.013038368446619382, 0.019223034481651018, 0.03626071122874107, 0.07769268032695566, 0.029611159648214067, 0.02603980423217373, 0.013703383655021233, 0.03979033843747207, 0.06765608888651643, 0.028486009487616162, 0.05266439708481942, 0.022161160662238086, 0.055953582017017264, 0.0199466462779258, 0.09026012596275125, 0.025073112354480794, 0.07209079020789691, 0.009143741984319474, 0.021713178272226026, 0.008809098691147352, 0.015150981289999825, 0.056031199637800455, 0.01811637100763619, 0.011648709220545632, 0.030330355877854993, 0.037462708872876, 0.07812954831336226, 0.030349602523658956, 0.04817215599385755, 0.05831030716321298, 0.05532681243494153, 0.026938944556085125, 0.038640720304101706, 0.04569723004741328, 0.0987670144864491, 0.030667937227657864, 0.021275694515290003, 0.054821320809423923, 0.056638597045093775, 0.028406317246013453, 0.02611198339478246, 0.012411532707379332, 0.046790400852582285, 0.05111832111807806, 0.039466510992497206, 0.05569729594779866, 0.020139984653464386, 0.048362454532512596, 0.05945980655295508, 0.05069075584677713, 0.020617132174915502, 0.06742956675589085, 0.03130044382331627, 0.0191800187541438, 0.03514624120933669, 0.019114787790126035, 0.035428304823913744, 0.11951368408543722, 0.07120286606784378, 0.0028949013794772327, 0.04251798475161195, 0.05960196642471211, 0.02438722880158041, 0.017742158944851587, 0.029574559469308172, 0.09420687918152128, 0.032845596982432265, 0.027810480379100357, 0.01779248927985983, 0.00418825909894492, 0.03061339319018381, 0.024488998876352395, 0.042906215347881825, 0.014716896993507231, 0.02028312161564827, 0.024409403325989842, 0.007567772309162787, 0.028096272543604885, 0.05081732298380562, 0.015431000817833202, 0.042570438901228566, 0.033518822464559755, 0.017181005395416702, 0.04502938874065876, 0.023783039168587754, 0.11016260300363813, 0.031148886241550957, 0.029368420530642782, 0.0240715573475297, 0.008183502974653882, 0.01543475650916142, 0.045462891193372865, 0.018102593354082534, 0.007272666403358536, 0.01825915852428547, 0.022993407611336027, 0.038153182715177536, 0.024502238790903772, 0.02645148160601301, 0.04460689212594714, 0.07246249169111252, 0.013918745580927601, 0.10485729375588042, 0.04668429493904114, 0.03636920219287276, 0.02859403904793518, 0.05138888695676412, 0.031188180204480886, 0.030844956835997955, 0.05064122618309089, 0.009351841041019984, 0.007186651063550795, 0.05514359440920608, 0.017651857808232307, 0.06696423422545195, 0.017889529965551834, 0.012599292676895857, 0.014806136222822326, 0.09684136603027582, 0.022958688670769334, 0.03589225992826479, 0.03622104746422597, 0.08610150018440825, 0.030208684370986054, 0.025355369351538162, 0.04082590840490801, 0.04115638888574072, 0.04217301754813109, 0.051228871435991356, 0.04807710341577019, 0.00849040605992611, 0.06722310890576669, 0.022459548133026277, 0.007876210579914706, 0.0027616568217386623, 0.030712130213422433, 0.0317308691197208, 0.03916000993922353, 0.007428168818088514, 0.05110480809318168, 0.07237715912716729, 0.013166586120080735, 0.009617128725429731, 0.04220538027584553, 0.019918442969875674, 0.057315493401672156, 0.04202596204621451, 0.015864998601110916, 0.12661079397158964, 0.04164443537592888, 0.039025866958711825, 0.034628413817180057, 0.02551155454213066, 0.03686045476102403, 0.018636668267260705, 0.03850937628054193, 0.02652732146504734, 0.0489933055027255, 0.04905118114714112, 0.042972294480672905, 0.006880991393700242, 0.050954617759478946, 0.04726780791367803, 0.05111410402293716, 0.0402709685399064, 0.04669215237455709, 0.032127578011048694, 0.013078961804110025, 0.05002009183434503, 0.020654716229598438, 0.04936425720474549, 0.03537861231182303, 0.018766896100714803, 0.033101248621408424, 0.06516511897955622, 0.020652392247159566, 0.016909803430150663, 0.03356340221528496, 0.02163829345123044, 0.0270167470776609, 0.019509859715721438, 0.05357806145080498, 0.010386745195968874, 0.02196517600012677, 0.10655945991831166, 0.007394289564607399, 0.04148835875093937, 0.040112764707633426, 0.022913591537092413, 0.0529636140646679, 0.03205951755600316, 0.027637358954442397, 0.02870907787499683, 0.02511958691424557, 0.02533115752573524, 0.030338233669421504, 0.049170301362339935, 0.02057765331119299, 0.005288447228459907, 0.03018079318904451, 0.038030276274574656, 0.021942085453442166, 0.04949146555736661, 0.038081906004143615, 0.04582900833338499, 0.008039917331188917, 0.011595553635353488, 0.011119903979956039, 0.031189014802553823, 0.038178159589213986, 0.020815995521843433, 0.08797735095556293, 0.0424701141060463, 0.013856613825607513, 0.06643400660582952, 0.01221976853308401, 0.04447675928739565, 0.07055403731231179, 0.03228065211858068, 0.019161752591441785, 0.013918882136100104, 0.0444774853198656, 0.04075564271105187, 0.034146518246935945, 0.038166851803128204, 0.07961999797927481, 0.03749943458076034, 0.04606464997466121, 0.023721974409584488, 0.005388567190883415, 0.008740335952357521, 0.007154548723649765, 0.04350028972008398, 0.07914433814585209, 0.054222958095903905, 0.04614009289070964, 0.07159176162843194, 0.046740840654820204, 0.0555260845992182, 0.06034194278929915, 0.014937537921858686, 0.06439947363521371, 0.013885354872659912, 0.013241704187488981, 0.011411593461941396, 0.04082471079060009, 0.015129649845351065, 0.06905194398547922, 0.0878010539870177, 0.006346323610549527, 0.036056563790355406, 0.020334272978029082, 0.05435683305508324, 0.020399736340290735, 0.055786930423762114, 0.049095024687371085, 0.026059988952640976, 0.020477369228111844, 0.026549475633406212, 0.01827054264556084, 0.04310489379401718, 0.03661889968706029, 0.07359028474560805, 0.046925822871604135, 0.06827376609934227, 0.02131893585569092, 0.011459913636956896, 0.029309812068407024, 0.020194881529148136, 0.06141105613538197, 0.031452500128320286, 0.03931566247982638, 0.03864741065938558, 0.020848580469776477, 0.040141510843698464, 0.0071807113376313025, 0.006405678885390184, 0.06567942816764116, 0.05532367081780519, 0.02556560155270355, 0.03276702941262296, 0.015368741837197115, 0.03048194060102105, 0.05583260600854244, 0.020795593670170223, 0.05715400885258402, 0.017754343737448965, 0.028945937486631528, 0.02717985841445625, 0.02216220730250435, 0.030683445145509074, 0.04381857692663159, 0.04042262790192451, 0.04349697507651789, 0.016619548201560974, 0.10932465296770845, 0.12152017998908247, 0.17820462903806142, 0.17676910678190844, 0.105935567324715, 0.13511428982019424, 0.16999093549592154, 0.13492618634232453, 0.1383482420018741, 0.20280327408441476, 0.11818904802203178, 0.11000185805772032, 0.24036351218819618, 0.11749642661639623, 0.08053917544228689, 0.11910298040934972, 0.1721474283507892, 0.08496530008103166, 0.11611803700881344, 0.09128828972045865, 0.09087998127298695, 0.20188339773033345, 0.10943116939493588, 0.07672472976680313, 0.13750734712396348, 0.08632491462464843, 0.142304196155497, 0.09804412363363163, 0.07981129057173218, 0.20507309585809708, 0.14238149486482143, 0.11594870180955955, 0.24678807173456463, 0.09579819307795592, 0.09492809405284268, 0.08481253470693316, 0.18338305902268204, 0.1128719322649496, 0.07362579926848412, 0.14036526876900876, 0.17272319245551312, 0.09490921720862389, 0.11468146980873176, 0.24097270092793874, 0.12034312529223305, 0.06946866626718215, 0.1586119710866894, 0.08109110261180572, 0.07724080993128674, 0.133681413850614, 0.15036758062030586, 0.19195729893233093, 0.1628921971257244, 0.12172303481825761, 0.12861635349690914, 0.2596028026725565, 0.07311947643756866, 0.0768685249079551, 0.1131098402131881, 0.1718902364373207, 0.16176991377558025, 0.0840259836986661, 0.13492827623018197, 0.1368605268320867, 0.10010783361004931, 0.17555524834564754, 0.171628634046231, 0.10604509644742523, 0.13356731140187808, 0.13286007435194083, 0.11398343369364738, 0.16127048486045428, 0.08125053119978734, 0.15864739061466285, 0.12272126839629241, 0.10101442424846546, 0.08263945845620972, 0.12464077611054693, 0.0957959946244955, 0.12734557954328402, 0.13704432839793818, 0.09383764756577355, 0.06499924430889742, 0.19224035660071032, 0.10919049302382128, 0.1833607487912689, 0.11194379135434117, 0.17498023062944412, 0.05964408987866981, 0.1396982959870781, 0.14199349497045788, 0.1061525424676282, 0.1428062849278961, 0.15419109830898897, 0.14165776941393102, 0.2490320141826357, 0.11414658065353121, 0.12686395538704737, 0.145164071981396, 0.14772358749594006, 0.1482086450393711, 0.12278009738240923, 0.13341886151049817, 0.11851763539016247, 0.07666229775973729, 0.16240086991872105, 0.15858991869858333, 0.08219547263745751, 0.15970435818391188, 0.11080503317394427, 0.0955524616209524, 0.06282484491488763, 0.20855251486812318, 0.12877504926707062, 0.22308636855866226, 0.17268546590847628, 0.1294268500059843, 0.1598835592823369, 0.1728190423122474, 0.1072255370340177, 0.10563100688159466, 0.10938679320471627, 0.11664908565580845, 0.09019592297928673, 0.07864855974912643, 0.17916862373905523, 0.13451469556561538, 0.1204236266868455, 0.11405964674694197, 0.27491215403590885, 0.13186517916619778, 0.10388123470225505, 0.08329224307090044, 0.11330042034387589, 0.1359220314770937, 0.10987966747156211, 0.1535247497792755, 0.20726465540272848, 0.16570917596774443, 0.12110284024051257, 0.08105319286031382, 0.15220186433621816, 0.17435534058937005, 0.12237551409218993, 0.132672839398895, 0.14311664684542588, 0.07541551680437156, 0.057619714577283175, 0.16544882208108902, 0.1529765749084098, 0.09763097723147698, 0.13837884393121513, 0.17358100999678883, 0.12651273209069455, 0.10960343586547033, 0.11605717241764069, 0.09376504431877818, 0.14779773780277797, 0.22332928409533842, 0.25473368966153687, 0.0871705049648881, 0.08331906556018762, 0.15844065456518105, 0.13580312500042574, 0.09932519096348967, 0.10498158101524625, 0.1454125243638243, 0.07606134643512112, 0.08571554946580104, 0.16517830373985426, 0.07255291326769761, 0.08858688574816499, 0.06305634070719991, 0.07611675560474396, 0.17702168465725013, 0.14412949606776237], [0.017655392975679467, 0.044537932612001896, 0.014746637183374591, 0.0374948883961354, 0.04732407543009945, 0.020982146695522324, 0.039696517400443554, 0.021391311793455055, 0.019355316579874073, 0.06451899757874863, 0.06347053883863346, 0.01735499025588589, 0.014663177376080836, 0.025258907116949558, 0.0438626477760928, 0.05335004993581346, 0.05827819210078035, 0.014203307900710829, 0.027603547554463148, 0.06399290902273995, 0.03211197509829487, 0.07671115906643015, 0.052995311828064065, 0.017143809802031944, 0.07776044561926808, 0.02652002382092178, 0.02914071435640965, 0.017514619011698023, 0.009149417929750468, 0.030995849453444992, 0.057038936098771434, 0.011236734139466924, 0.03356197050639561, 0.021462907415947745, 0.003769358719832131, 0.012060374720022082, 0.03548206854611635, 0.029890790714749267, 0.027067681308835745, 0.004382435889315924, 0.06325373332947493, 0.10390566196292639, 0.036440014107418914, 0.024729975499212742, 0.01726557800014104, 0.037976057933909554, 0.026524324036602463, 0.0568628901881831, 0.0334782901752208, 0.05958313029259443, 0.05420105159282684, 0.04907316568174532, 0.0910229893135173, 0.03654903432886515, 0.007800862658768892, 0.01617524347134999, 0.011969440849497914, 0.038177426771393845, 0.04291649176073926, 0.05112715225134577, 0.053980191836931875, 0.03126759933573859, 0.014792567218786903, 0.050137295188116174, 0.027112130441569855, 0.05856927005308015, 0.03435444173270038, 0.04940656725583332, 0.013945432363211043, 0.018522184142576795, 0.06833974005920546, 0.006388178619090468, 0.066393599845469, 0.04699942356507693, 0.022815287079928175, 0.05280346283689141, 0.06946136523038149, 0.005331853537687233, 0.04976763270263161, 0.04064921110070177, 0.017413941378306066, 0.045624525020165105, 0.060559705032833984, 0.019299211911857128, 0.022410892083176544, 0.03101995101730738, 0.019741112931764553, 0.08898819171424423, 0.01531511721467333, 0.06722750581268754, 0.054114701226353645, 0.04676068441144057, 0.035375776035445075, 0.03357168373518756, 0.016529070645836846, 0.041069916382964165, 0.02934032239552055, 0.01859441928432456, 0.012968659151478537, 0.016788898667852794, 0.04682746922065105, 0.016226813829104816, 0.017464610980823636, 0.06486396478222949, 0.016200089727395346, 0.08758861824337925, 0.08144666174692766, 0.025498915131070783, 0.017599542758294513, 0.05610165192878672, 0.029762225292090858, 0.0577767886487501, 0.002110068973187091, 0.029532894026488066, 0.037291209146912606, 0.05847985949367285, 0.022790601975949745, 0.03214253631553479, 0.01899492966809443, 0.03322903372879539, 0.00782941117150975, 0.023739229555108717, 0.024554833736536757, 0.025174074972580587, 0.024588809681258032, 0.0824882604980043, 0.020342971796968153, 0.013743287451299173, 0.032937412948480675, 0.0479641409058656, 0.03590934544003435, 0.02856878058186599, 0.04888683996562447, 0.026081712251263003, 0.06893058799739395, 0.03367679898760148, 0.0541038277026798, 0.005561127551897828, 0.017004109619717513, 0.013029703554431242, 0.01636927225627005, 0.02477329147846571, 0.029730290041438172, 0.013437961959945304, 0.036010057000177245, 0.026211169947470938, 0.025713652804759995, 0.03383690271792667, 0.04323808343282767, 0.0514741889866335, 0.028402836361367787, 0.07815225209508624, 0.043950735192213736, 0.05486933394734349, 0.0234304130010839, 0.023716162757149765, 0.036667404762868366, 0.06119930571211236, 0.02896799666008779, 0.01917671937761562, 0.04625403927639127, 0.06965071721268551, 0.04616380090426121, 0.03229277075401374, 0.02999537331717355, 0.06940685851233346, 0.019244852775175656, 0.03034252201073936, 0.05201238260737487, 0.09222753146397215, 0.051598228580717526, 0.023444813210517168, 0.0017081298491185798, 0.029111089517495463, 0.06238422462982791, 0.01587125808665795, 0.00560341851918825, 0.02818740318928446, 0.030250797646918466, 0.036614387429186275, 0.04191335915986981, 0.03468832167397652, 0.02053200826048851, 0.03278225913111653, 0.017558386216738393, 0.056389578085924895, 0.07361888499664408, 0.014514571421646645, 0.044060196461422105, 0.0488591116320874, 0.044050506981355805, 0.07529161630996636, 0.04673992802522012, 0.00640953381246488, 0.051302217678832154, 0.007228950088444565, 0.019502029421606233, 0.10788950390581574, 0.037259236576833894, 0.04138838340129171, 0.006758658739272505, 0.022833168174007108, 0.034575725572982004, 0.010241487811851715, 0.01425520989245602, 0.016430418439475552, 0.014378160437835115, 0.013235460817148643, 0.01840639383798199, 0.050827982768948586, 0.03238976394225444, 0.013192528210181211, 0.03032335339646254, 0.014942374180204101, 0.059414147931550226, 0.03044809866696596, 0.011049198086506553, 0.01859585608222655, 0.029316709376871586, 0.07692858882780586, 0.05570714149091925, 0.03670438152870961, 0.04708916321396828, 0.06737765204161406, 0.04417076035003577, 0.038766524089234214, 0.07776638958603144, 0.047179293020495346, 0.027450621028297713, 0.03654672730980175, 0.028168568753504326, 0.040464578329452446, 0.018223189382946918, 0.007503567629360727, 0.06649004002766949, 0.1264418251812458, 0.08416803500482015, 0.027451060379722288, 0.037194378807076385, 0.011602664682348924, 0.05436700090233769, 0.008973837663818682, 0.02331696024962834, 0.043297747017017434, 0.05680095351168087, 0.05944700938250337, 0.017044738600296632, 0.022445784050172994, 0.03433396015316248, 0.05762438289821148, 0.030807260823036944, 0.022329556090491157, 0.08400534944874899, 0.05937281836356435, 0.01754239314634885, 0.05040241917595267, 0.007874060472074364, 0.06149756256490946, 0.02232750691473484, 0.0076467961937721285, 0.05167370542351689, 0.06561614799180202, 0.051416150493813415, 0.08747300266155175, 0.029160066175141504, 0.032441512415451665, 0.024115975946187973, 0.015125012058498604, 0.018986990808376243, 0.029193626517163854, 0.021647613129711578, 0.02872493863105774, 0.02711852902679571, 0.018058748117515018, 0.025927849346771836, 0.03439408174848982, 0.051076625141182115, 0.0383131982359503, 0.03967286366969347, 0.006428122279300753, 0.048847484934542856, 0.020426256881494607, 0.022859642914097224, 0.01769746045049812, 0.034295789165688415, 0.05374880461022258, 0.035539523498820405, 0.05707425384649208, 0.029560717354927744, 0.041418028596256456, 0.013334040080995431, 0.03972187764676554, 0.02755954286216625, 0.021969932530607496, 0.042275021717484505, 0.015764916382197822, 0.025218951582376446, 0.056424431037157774, 0.048543165371354134, 0.03461543004959822, 0.036124264621841054, 0.05650236078404954, 0.013399980962276459, 0.024030519549601843, 0.06397916868861232, 0.03191647898139698, 0.02753929028819714, 0.02691793371923268, 0.033778803156954904, 0.04298117311139192, 0.023488186865246723, 0.005474993892546211, 0.04015112229223762, 0.0181987485515752, 0.05800358219338315, 0.05064889023612652, 0.03438346946079816, 0.0528977486704077, 0.00463073602544942, 0.04869852274922388, 0.024879918167633668, 0.018692951050720046, 0.041226590118770085, 0.0045848696026951075, 0.0585663319964494, 0.018660031924290315, 0.043694371091467996, 0.052765508980623314, 0.0628075422719121, 0.009757370887590306, 0.02711007448046335, 0.03754981919857008, 0.011831202061979898, 0.023387415933289697, 0.0357498286425003, 0.034175610435860496, 0.04561266762071422, 0.030315930223358527, 0.06769399863800832, 0.02614174224436283, 0.041264530404337814, 0.016259566714454974, 0.03548105752893856, 0.0789624907608543, 0.09245976007410459, 0.0742872827021139, 0.010870463480906827, 0.0132921244283872, 0.031606442760676146, 0.014746750837990215, 0.0513494844282312, 0.033289542089083364, 0.16255453095904418, 0.13299396288182053, 0.10328425959284816, 0.1274075840732881, 0.13585648499429226, 0.08272920828312635, 0.08163613586553506, 0.17586639736379894, 0.1297868671161788, 0.1706561440868037, 0.19400251204414026, 0.12332954789910998, 0.09501121459262711, 0.10093798727861472, 0.142000375315547, 0.1585155919726406, 0.13150243434522832, 0.1035639720835856, 0.15241565714989389, 0.12525263827826294, 0.14975319430232048, 0.2790999093226024, 0.18324630707502365, 0.14376098369913443, 0.17695716954767704, 0.09837794929210629, 0.17743500747850963, 0.09200497876320567, 0.15584916648055824, 0.09990871750882693, 0.11437155572431427, 0.09450284937130553, 0.06440752106053488, 0.07856146299413272, 0.06876434691782508, 0.2122233621776104, 0.13918767124414444, 0.08627960884145328, 0.11141828633844852, 0.13387407708380902, 0.12383561288671834, 0.13141220275844845, 0.10024722505893026, 0.10340265038290194, 0.11256790786449399, 0.10030682757496834, 0.13578188685434206, 0.143475741147995, 0.08891309145838022, 0.10101537419749157, 0.1181075559662921, 0.14486795929925783, 0.23977258961115563, 0.11265757626720838, 0.09234367630311421, 0.07306615715580327, 0.14783877560070582, 0.10490432301802294, 0.1279033896114145, 0.23271818671907696, 0.231116382671254, 0.12413875519164971, 0.14278116556150572, 0.10231620725244284, 0.14649702688413008, 0.1245805493422917, 0.20805399518992218, 0.1575065018343074, 0.1463385753865753, 0.1188913317663329, 0.12000853967453752, 0.09246825533253805, 0.18629353999027184, 0.1307167722178357, 0.11647268012166023, 0.1401887953813587, 0.136979555445058, 0.12515098016176904, 0.11345391853579453, 0.12175583520105906, 0.14872620441019535, 0.2148027859096016, 0.11218601478529827, 0.08336906002036162, 0.0889156631061009, 0.26071953560624805, 0.11186842646981988, 0.19496661531073706, 0.10290624094860894, 0.09729092940688133, 0.10937104440693345, 0.1384084959115301, 0.12397146916815213, 0.12218275586409227, 0.08307590575090476, 0.0964886024594307, 0.12504580723387854, 0.11516935005784035, 0.05399683290826423, 0.16193462136600698, 0.31257763292108265, 0.12761016748845577, 0.1594593391886779, 0.1468927077949047, 0.11380534539265291, 0.15305364291582788, 0.1445933018944093, 0.22663061480437005, 0.2288563996553421, 0.12238257085638386, 0.0749116095581225, 0.2219459004700184, 0.11140319571963378, 0.09840448001133544, 0.14354816797588552, 0.15306660293468408, 0.07898764405399561, 0.11812431578125272, 0.11916959897748061, 0.1639603062399796, 0.07403389058474984, 0.13918019378823893, 0.11400693814669337, 0.0734737870682563, 0.13426922873726913, 0.11864057236484118, 0.05417930454547916, 0.07484921826315777, 0.15268637905163424, 0.16776197510106222, 0.09965113204504762, 0.12006012190665517, 0.1353375142706292, 0.0981568011588284, 0.1320765292538064, 0.1556660977325269, 0.10724026124392237, 0.08326111188424484, 0.10525152260171515, 0.1494530239807708, 0.0771472535229155, 0.09990435452865702, 0.1360805779695511, 0.1444992840822254, 0.12275244029504911, 0.08039151265152863, 0.24059828530464852, 0.0922902145289949, 0.1844746590192829, 0.1473820943917547, 0.09533679605062519, 0.15190823509224824, 0.2186936821256365, 0.13886786411915505, 0.126371936074325, 0.15985673000769957, 0.10083010699599981, 0.09377474736954484, 0.09127622536782708, 0.17485571945352213, 0.160771408783538, 0.12053771556488105, 0.1505620623273509, 0.12923289755625383, 0.08845383860170841, 0.13566946717245237, 0.08165476843714714, 0.16341403126716614, 0.14535797014832497, 0.2150353877139943, 0.08834729503308024, 0.059554998230721266, 0.07531567037637744, 0.09567881162677493, 0.20557278261653014, 0.18920722364314965], [0.052519482360886674, 0.030739339467670237, 0.05634592114282506, 0.07441256062260695, 0.032781651842274835, 0.03360981061788542, 0.03469689157126205, 0.011306076177528926, 0.008247064742525774, 0.02122149653067546, 0.01785701117478311, 0.04095858235710433, 0.08296824259949581, 0.0025935866662101553, 0.04625552187540701, 0.0761122637029205, 0.042511297789003165, 0.06371791235038213, 0.05289692085768495, 0.04380966436916164, 0.01812600450856345, 0.03129015044708337, 0.009772531904413231, 0.06307898342077221, 0.020616282309804643, 0.06531003370348896, 0.013160513231663831, 0.03165735663580043, 0.029545440138982873, 0.041556073153125386, 0.040148584571267874, 0.03741277548085366, 0.02374725492804178, 0.06138035921113832, 0.018052661658397744, 0.023423329095489213, 0.014227981130326433, 0.017886917605730038, 0.0606504115941269, 0.03178145390536104, 0.017891533340194395, 0.06921197646962744, 0.026431963546201587, 0.0247357447432088, 0.044322996466819725, 0.03875299410096236, 0.0149258077477238, 0.022312648694163988, 0.036845873043473275, 0.07589195016771555, 0.027749500436974422, 0.031101249690566744, 0.04194015111508114, 0.029686812910118272, 0.04761971992307475, 0.07393789145031146, 0.043655911726611, 0.023444557063547627, 0.05659838366721358, 0.04876884951123169, 0.011474796454422176, 0.035718141057129414, 0.033166991879365275, 0.027567308695454682, 0.031153948112790073, 0.031013247091323137, 0.016198834437610846, 0.04199757892638445, 0.08681205527058669, 0.006141587543035192, 0.015952071607378975, 0.022767418130700077, 0.038621633114027124, 0.009040499488557023, 0.03499763864757759, 0.03220225078985095, 0.0464775792456099, 0.037960617869560204, 0.03664725227281451, 0.02708218160218426, 0.01511197570445282, 0.05227282809625779, 0.027841969492978284, 0.022849300344075476, 0.08779727454696383, 0.015940599276551178, 0.026497157190793326, 0.059326019803328175, 0.004517425342263388, 0.03061278929401721, 0.04462542291730642, 0.07572623834546123, 0.04345622565597296, 0.03908864501863718, 0.051112132878707986, 0.05434241079326187, 0.07072515705866472, 0.020460193810452307, 0.02607869785944266, 0.0983273373650653, 0.04621902008407882, 0.026819878623687794, 0.03315092417012368, 0.05090486417923655, 0.020810161817020605, 0.06873498670756817, 0.03762217478028365, 0.03991074447653123, 0.042860549941126785, 0.028326482512056828, 0.04320264694147876, 0.01620675972662866, 0.02498996806597071, 0.03243938181549311, 0.026825725899211, 0.016945560529295887, 0.03746312617191246, 0.04511018869067941, 0.04740505858457514, 0.01490368920245341, 0.023544445899980407, 0.034319419147712846, 0.06049358858061688, 0.04702481434547475, 0.042216355579772165, 0.020387984113767743, 0.037699595625911436, 0.03535319099734936, 0.03890239054869328, 0.04723933319162045, 0.02374879180985902, 0.0365120100655726, 0.06019985755639417, 0.0334691503085196, 0.02277751642811511, 0.027868793678603003, 0.03812499976317797, 0.029696953615971973, 0.06768323028726236, 0.012705598758267505, 0.007543911625232015, 0.013171055969516081, 0.048269773434315405, 0.05799445589738233, 0.06474062747188977, 0.018621331679501703, 0.08800973743200302, 0.023194045327337723, 0.014414043065958788, 0.04429666591542108, 0.0533156889224691, 0.037343982207987986, 0.0061583889182657, 0.04869629376168762, 0.05633830458724073, 0.0423309499663966, 0.048305359203368425, 0.018182511208578944, 0.10501977575144597, 0.01191810458632452, 0.007508629500599844, 0.05787027720361948, 0.004791089965562735, 0.013655522339312094, 0.029262928691293513, 0.023753880822498883, 0.002569944173696318, 0.020447703677096536, 0.06531376564609152, 0.026944296501044716, 0.06616867227213723, 0.042702865188143084, 0.04565728469086545, 0.011475209512614777, 0.03557892602735332, 0.034901649691164494, 0.10682072982724224, 0.05966528731265238, 0.029650294155414616, 0.09783812718732016, 0.04765931583408799, 0.025643605938447372, 0.010801167243958583, 0.03499314674575414, 0.03591959471149104, 0.01753370789811015, 0.03824377392551728, 0.010047425948349493, 0.031327459695083756, 0.016940424019204717, 0.036674570092665296, 0.04482804025922503, 0.040020962312285385, 0.04212483138378177, 0.03888274695990341, 0.052354259083845785, 0.09952024263995034, 0.053816390090755055, 0.04086652211844921, 0.058661374396511486, 0.02095968888274261, 0.016990986752456853, 0.05013333932895746, 0.015246922748961618, 0.05584836159167545, 0.03611961665696331, 0.03692097329933729, 0.019178865244612098, 0.045571840168642144, 0.013889510899649134, 0.01686528305123959, 0.0372938723968608, 0.04048235255426594, 0.03341395827010274, 0.07511234735803944, 0.012285068198772413, 0.044026670046150684, 0.054525333656264205, 0.01791886133807046, 0.011251407459245195, 0.01067761704325676, 0.0464115611809705, 0.036692398600280285, 0.058900157654924054, 0.010482526351032513, 0.020982318025614535, 0.03406660717778972, 0.027849774342030287, 0.018183203314297965, 0.03928764916158148, 0.05089187023362943, 0.0545351249165833, 0.04682299428220306, 0.08807375042566232, 0.049278900892074616, 0.052617754587637525, 0.0424371814089162, 0.06290187899555479, 0.028103945078328252, 0.06060402015490191, 0.05651087639853358, 0.029579468670168092, 0.02147100742773286, 0.038010215386748314, 0.023220937366464307, 0.01797660636449499, 0.04312214215419122, 0.04834603398506131, 0.04854315858600395, 0.04916273230420692, 0.07837479801050254, 0.06436530261167459, 0.0939041439976011, 0.016418544076649205, 0.03438191222293036, 0.010911611540775214, 0.07586286815681628, 0.03936888337401407, 0.060837721186024804, 0.04886354925110936, 0.04723298888919609, 0.07011959169592176, 0.029952225275337696, 0.03321513733161347, 0.011852694658695586, 0.020972482660519223, 0.019062691567731754, 0.05503351228045566, 0.04680663141022835, 0.01807692607066461, 0.06357991868363959, 0.015502630367076822, 0.060860560674752505, 0.03405080748988049, 0.015578755210818989, 0.08327129669487476, 0.01370274243942861, 0.05320615640708378, 0.06187594761805875, 0.02892793934526188, 0.01308221962036831, 0.04674630964707051, 0.0945625536675964, 0.05341134539672306, 0.07188092611197915, 0.03602574812248349, 0.020043427423973168, 0.025926297197916677, 0.057963697904987, 0.0457692599323179, 0.058360817310001166, 0.05202133248427084, 0.041451270026820045, 0.04082378459029964, 0.029977660160511732, 0.047814411975975545, 0.03681639748226319, 0.012148904032073915, 0.04707980282338602, 0.058397261425852776, 0.009346373745107224, 0.0456797984827842, 0.004055540617887995, 0.02838456171697804, 0.028987789526581764, 0.043419649225792716, 0.03676587376477463, 0.07849312094705445, 0.008249350557369846, 0.051123148894735744, 0.062049767933785915, 0.051071200253708024, 0.06464321019926242, 0.05467844847589731, 0.05907618999481201, 0.05559769718508635, 0.02478985282193337, 0.010096650271277343, 0.06815174514693872, 0.05941118273351874, 0.06563552695193461, 0.020907670691875473, 0.029831954943282262, 0.03168320882001093, 0.018307923139738183, 0.08951785614980118, 0.037609611704413376, 0.04636050820616739, 0.05470272645886455, 0.01132136526783662, 0.07444941185946975, 0.04323396472526448, 0.028815797862729857, 0.031244135594793727, 0.036893706369612894, 0.04651338214586888, 0.050068641014929326, 0.03861609626827495, 0.05259365980912532, 0.01604743461523737, 0.055825488176196814, 0.03575018148070999, 0.03094128505992038, 0.04970464090417538, 0.06574162268745047, 0.04184649971180728, 0.1465049386024475, 0.011624276022692876, 0.039928623874272616, 0.05626601685902902, 0.03572767786681652, 0.06800282028104578, 0.17271059884556703, 0.11607971335096018, 0.13604419492185116, 0.32923973883901325, 0.2291062633906092, 0.11243958332176719, 0.11849244817027024, 0.11869495016123567, 0.10586535930633545, 0.09719979536852666, 0.1139815202248948, 0.11293193511664867, 0.1982197021799428, 0.07301829329558782, 0.22799482303006308, 0.1530862668795245, 0.17821765691041946, 0.12813717206673964, 0.13810941124601023, 0.2110665821071182, 0.2990288899413177, 0.12158362301332609, 0.10975236751671348, 0.19118219480982848, 0.11431853499795709, 0.1459466399891036, 0.11278618579464299, 0.0705808869429997, 0.1596577021160296, 0.11310078855603933, 0.10387693279023681, 0.15893632439630373, 0.1489345282316208, 0.1363174274031605, 0.08389333688787051, 0.09046534209379128, 0.09587799558149916, 0.11794535895543438, 0.24917260663849966, 0.08523533666240317, 0.1439447309821844, 0.1204159456704344, 0.16527252511254378, 0.1615618070853608, 0.11553186417690345, 0.10776522343180009, 0.0906794470335756, 0.1476441039038556, 0.15234936427857193, 0.10393475754452602, 0.1226328688540629, 0.1018818159188543, 0.15820905699261598, 0.10176793738667454, 0.1272174042782613, 0.17992391463901314, 0.09010625457657234, 0.10097446532121726, 0.231326945658241, 0.14772532454558782, 0.1297984022114958, 0.23113532736897469, 0.148828690339412, 0.08781078417918511, 0.10604888945817947, 0.1319943450923477, 0.1343438404479197, 0.13322283274361066, 0.12309291559670653, 0.08551910000720195, 0.09725477027573756, 0.13494704450879777, 0.11299707447843892, 0.15423035834516796, 0.14127069232719286, 0.10028959957084485, 0.2130703774413892, 0.1341208466993911, 0.146359704967056, 0.1323018435920988, 0.12284552172890731, 0.14347335270472936, 0.10869949151362691, 0.17084177769720554, 0.15272572051201547, 0.16769475942211493, 0.11192195609744106, 0.12837191804179124, 0.11278254884694304, 0.1219707408121654, 0.2012583448418549, 0.23964953050017357, 0.135100054155503, 0.09124808652060372, 0.12455084307917527, 0.180857565253973, 0.19234232684331282, 0.14015988978956426, 0.15325885904686792, 0.1943768055311271, 0.09612798145306961, 0.17395286075770855, 0.11576283749725137, 0.1329835812960352, 0.1089298812938588, 0.11252504480736596, 0.15908842480608396, 0.14965943433344364, 0.10533433101539101, 0.09717943253261702, 0.08873063339186565, 0.06646550420139517, 0.2514771558344364, 0.10941370390355587, 0.14828852218176636, 0.11128272861242294, 0.11617867089807987, 0.09533743387354271, 0.1079589519649744, 0.0919883478698986, 0.13233320548066071, 0.1221740570451532, 0.15980411640235356, 0.1161187155438321, 0.11433925745742661, 0.04597393323534301, 0.15828214878482477, 0.11119223239698581, 0.10700772729303155, 0.1664197649806738, 0.07120931215052094, 0.12614473540868076, 0.10640268440225295, 0.12526638539774076, 0.13463540694543294, 0.09835211067859616, 0.2486045371208872, 0.09916673268058471, 0.11905076035431453, 0.1336815088455166, 0.10649724504245178, 0.049622487276792526, 0.2606797734541552, 0.1641093532421759, 0.13240386811750277, 0.09648198674299888, 0.1407087974782501, 0.11495301952319485, 0.16172761390251772, 0.16168345484350408, 0.1999544719500201, 0.1312600073537656, 0.18310513107904366, 0.11844781413674355, 0.13540181224899633, 0.19841501169971057, 0.11638003295021397, 0.10064534869577203, 0.13890172301658563, 0.10331631358712912, 0.11726739390620164, 0.1872247750205653, 0.16081976118896688, 0.14268508500286511, 0.15386803421591008, 0.1659351959824562, 0.1788625501628433, 0.18223611770996026, 0.14307984310601438, 0.08957189467868634, 0.19283882448715822, 0.09883667289146356, 0.13947821993912968, 0.13471290921526297, 0.14929883368313313, 0.11245252976992301], [0.045529323164373636, 0.017025856667065194, 0.08101348499102251, 0.05580204479130251, 0.0626200291195086, 0.013270787046557026, 0.031244227197021246, 0.06278983929327556, 0.06329643353819847, 0.00827957589977554, 0.04223778032298599, 0.11163610965013504, 0.024804911210334728, 0.028371560986020734, 0.05134102988189884, 0.04714239428618124, 0.006672895305590438, 0.03345451091549226, 0.022348836663046052, 0.00779240471976144, 0.0010521792324392923, 0.03713873554287212, 0.02144880236924759, 0.030711326149425337, 0.044272991828620434, 0.01904448986585651, 0.06347888481936284, 0.031158155029905692, 0.04266507078760436, 0.04322421078437141, 0.08090137743524142, 0.02218544712689306, 0.05083023211253541, 0.058374136952417235, 0.015901642884793024, 0.06039431890738862, 0.014093320766863014, 0.021289238074262227, 0.07806334365159273, 0.015809143294713328, 0.026830351811700633, 0.06418532798332827, 0.001989925866447655, 0.062308323702641895, 0.007522117080433028, 0.02166307863912412, 0.03640752924340112, 0.0074737502561349955, 0.007512124804114657, 0.0326585689825671, 0.014548113103955984, 0.04198809979217393, 0.013139223347284963, 0.05875022855720349, 0.025055066715659838, 0.04736003778608782, 0.023463350787226642, 0.03172970203948872, 0.02252813445271126, 0.03339246906606214, 0.02537712996958622, 0.03731418094996895, 0.06177730219704764, 0.0460398054149534, 0.021328191073345285, 0.011039045506290026, 0.022889364444251572, 0.03356292384809681, 0.02910762559622526, 0.03597367395247732, 0.047692835464009216, 0.043157833096172125, 0.05849706035639558, 0.011327055632136762, 0.03976370254531503, 0.08119405673018523, 0.05941021242844207, 0.013869712095973747, 0.024320350693804876, 0.05031784317855324, 0.048518005292862654, 0.008280286665207573, 0.032840229770434756, 0.020653918950951526, 0.0384059234389237, 0.11749080834644181, 0.05665530936260309, 0.03433715944577541, 0.01836447903354253, 0.021334101113357713, 0.06639666682375328, 0.02921839983069471, 0.03940031311607786, 0.025663034092368822, 0.029772321893168346, 0.014218497755272048, 0.024588969136987413, 0.01941131946763822, 0.020514103417683924, 0.0663845142615693, 0.024250273293416415, 0.03715608907597406, 0.031520801463297436, 0.041955404582300355, 0.04910276337925877, 0.012475737387181392, 0.02484591508151165, 0.05143919015037162, 0.0140923487654488, 0.04860983822228653, 0.03163058842931475, 0.04813188833317586, 0.04196996594380055, 0.07902903469013316, 0.02137877925166062, 0.02368441240728966, 0.026540171221962998, 0.021773622171687226, 0.0589500367641449, 0.01940228647020246, 0.03774880298546382, 0.01180781380805586, 0.05177270368273769, 0.042873252116675885, 0.023131185843210136, 0.013103600258805921, 0.021442083176225424, 0.03651508043653198, 0.0024660129648899393, 0.026469225296750665, 0.02048219191575689, 0.06744602123009306, 0.057957984640129974, 0.016452406366754855, 0.02132871693798474, 0.06601965919669185, 0.04901859111019543, 0.03154321347496339, 0.031764873902180364, 0.019451303839949623, 0.11491527940545763, 0.058431405307991166, 0.026814021170139313, 0.016189641984445707, 0.029083018523773978, 0.034940394040729315, 0.041760841451053105, 0.007194629787201328, 0.018066035583615303, 0.018383206600057225, 0.04584825497918895, 0.044744760263711214, 0.009949903502794248, 0.023018459124224525, 0.022076153795101812, 0.04726724133693746, 0.020972480964181677, 0.02470264580499913, 0.040558151701199155, 0.04598877958155104, 0.049326646008661816, 0.05667677142524293, 0.04715828896899309, 0.01635564727309559, 0.004430656828584948, 0.03629049891605973, 0.03348396951332688, 0.020129779486783912, 0.041785261926374266, 0.03411045750336988, 0.04977286420762539, 0.037857412693223784, 0.026764221788783158, 0.040366513055882285, 0.06195561441459826, 0.07413980311581067, 0.07308035210839339, 0.04290579126349517, 0.018989740571539317, 0.07054693305066653, 0.043314547544079166, 0.03058221789875201, 0.012534621504268475, 0.07533599250018597, 0.0389987696627421, 0.027869998078261102, 0.037810851620244126, 0.07305226754397154, 0.011638560881172972, 0.036912121810019016, 0.026707089140212963, 0.03475860093853303, 0.051915253712130446, 0.016157197832529033, 0.0043287722510285676, 0.03617611148261598, 0.017389833029093485, 0.04512620550979461, 0.019525861267798712, 0.00486192266024383, 0.02549564798495599, 0.03243798403335469, 0.025540963946176425, 0.06973550016326563, 0.03734733756365521, 0.002349947005443807, 0.058259009915803156, 0.00480119716874989, 0.030986516204263483, 0.035161613420184167, 0.019589845423719714, 0.030997142062655518, 0.041591899802110026, 0.024071386017437493, 0.06774397952748196, 0.016501837642863393, 0.053310311532446315, 0.03175309453425663, 0.015293775591999292, 0.06532745848276786, 0.07470518563474927, 0.08198352543903248, 0.03443639858492783, 0.02437536122410425, 0.010593409999273717, 0.011801943631975778, 0.023313007783144712, 0.04925804951095155, 0.0608485641756228, 0.024474822583475282, 0.05416460069162505, 0.028540455137512515, 0.019576915938939368, 0.017432149865531495, 0.01841127929011626, 0.02021335294869329, 0.05092766295586314, 0.07138256928218262, 0.02354175890130656, 0.013406784972175956, 0.029194254162056104, 0.011769354443198867, 0.034048229056809626, 0.030614780794296945, 0.029759847026850497, 0.03413436907742705, 0.017274678851078664, 0.021848379767366817, 0.04514105524867773, 0.025993283871295195, 0.03399920490171228, 0.012957733889509524, 0.015762558473008018, 0.05332122916089637, 0.025461751768099408, 0.041397000796028545, 0.09436292866511004, 0.04281231627932616, 0.04320422114272203, 0.011465901708496469, 0.032976415141352584, 0.08376904962850468, 0.05011521565860935, 0.040068463156265874, 0.04309603212667363, 0.03985883315492954, 0.04661659410755549, 0.02568459284624883, 0.0412804997260017, 0.02897405597780432, 0.04564384291214602, 0.03304780041798949, 0.011069833184592426, 0.022850253685776676, 0.026453215262985656, 0.013552502911937023, 0.0077759477010528955, 0.041205996580954106, 0.07301971143377678, 0.03631960467568465, 0.024630144338256547, 0.053663831669837236, 0.029663552729679004, 0.03438200043248279, 0.056945888591664176, 0.060368480293878486, 0.027989857896630253, 0.05536826074655567, 0.11226117610931396, 0.08687827350305659, 0.04754477912294013, 0.022935311443039348, 0.023677735622706156, 0.024772994619395052, 0.07836029771715403, 0.008320537362513798, 0.052414628344454935, 0.02296435783085014, 0.04322583248306598, 0.02882780453988484, 0.02790960586363716, 0.006784672075549939, 0.06153464450367859, 0.0055104422582579506, 0.01713611351858292, 0.0650804853066802, 0.051088299336177964, 0.00894840617131974, 0.028933900275400708, 0.05226894687595112, 0.025727388049874986, 0.03737669098856194, 0.07298766422484602, 0.030787118511008363, 0.08186514821967908, 0.006053997153815414, 0.08628576315407242, 0.06731436508042471, 0.0185480108817241, 0.02001312405004033, 0.004081721043413771, 0.021698197915351818, 0.04789996845647693, 0.03101628353553159, 0.017070171789133122, 0.02804727722624583, 0.02709598300446357, 0.035289327281394174, 0.07233771588653326, 0.09837855318827288, 0.03727089720112937, 0.1045501141675881, 0.03096752061641642, 0.01139396766666323, 0.015416120544874241, 0.045326101926288435, 0.05101999121585062, 0.09401632619223424, 0.036763654955263646, 0.022684743727690408, 0.01105705467385373, 0.02396100533327886, 0.022416513745806048, 0.01691816807059305, 0.030708042039935077, 0.06280034301536423, 0.011029792833141983, 0.05884593592158385, 0.042270248223628314, 0.05295170238241553, 0.0285571301355958, 0.008793251505786819, 0.13455441700560705, 0.10654977043824536, 0.13306971453130245, 0.09949177809591804, 0.13379489204713277, 0.08774205536714622, 0.08949068082230431, 0.11074437892862729, 0.14222465828061104, 0.06202430251453604, 0.12356801224606377, 0.21040306985378265, 0.12907185405492783, 0.10815496716116156, 0.20944302422659739, 0.0925385176337191, 0.13521640934050083, 0.1264145616441965, 0.10196860054773943, 0.07765624978180442, 0.06946844235062599, 0.14143092158649648, 0.07841589009123189, 0.05878724264247077, 0.20467018176402363, 0.06755297191973243, 0.14705402271023818, 0.13498631811567716, 0.14846811683050223, 0.13032318119491848, 0.22344293871096202, 0.1543540417083672, 0.15309778840414115, 0.17032358050346375, 0.10070038467113461, 0.1776213739067316, 0.11119996769619839, 0.1035607558275972, 0.14907463214227132, 0.06572982974882637, 0.1491120465631996, 0.1679845888699804, 0.13508060734186852, 0.11546791903674603, 0.18810621915119036, 0.11368738886501108, 0.10424910246261529, 0.07233479818595306, 0.11261097448212759, 0.10779197128223521, 0.06240547634661198, 0.10209237890584127, 0.09753796365112066, 0.1042460829817823, 0.16474033652671746, 0.12744559560503277, 0.08841966079281909, 0.1536072732082435, 0.13011934927531651, 0.17185914596276625, 0.12755631894937583, 0.15385591558047704, 0.1386227094169174, 0.0805422899180225, 0.15028566787285463, 0.06354342707033668, 0.154514094548566, 0.1358945100967373, 0.18322809519512312, 0.08938135526009969, 0.16209126796041215, 0.12153208149330956, 0.09368506539613008, 0.09503455619726862, 0.08951482309826783, 0.15476824662515096, 0.11921951201345239, 0.1862149927765131, 0.0820259881604995, 0.09846181622041122, 0.10061278580022709, 0.12473739949720246, 0.1402637463595186, 0.06152959620313985, 0.12076008506119251, 0.20975489249186857, 0.1982332593096154, 0.16455221947814735, 0.07948931213468313, 0.18968325667083263, 0.16442210360297135, 0.13647011135305676, 0.14354805941028254, 0.13354087567755155, 0.14156744283224854, 0.18286748097411223, 0.14343023858964443, 0.10355764135186162, 0.11291837798697607, 0.10385169807289328, 0.12151282466948032, 0.11453996811594282, 0.15750727536422865, 0.14675523660012654, 0.1698593675558056, 0.14434772650046007, 0.08415314116116081, 0.12373855523765087, 0.12650068130876335, 0.1820317158209426, 0.09117406513541937, 0.18472620552139624, 0.12704715984208242, 0.2657715273754937, 0.12158097672675337, 0.10027786770037242, 0.18445895771895135, 0.13447888248733111, 0.12892919885260717, 0.0734637515353305, 0.13851900212466717, 0.15112952116344655, 0.1400478229458843, 0.11670715468270437, 0.08868612149464232, 0.07219828372555119, 0.0633331626387579, 0.12991744439516748, 0.06997802893498115, 0.16354048305324145, 0.19938290119171143, 0.12112181207963399, 0.15649005637637206, 0.12964118564767496, 0.07857316093785421, 0.2133511280907052, 0.18320555426180363, 0.1376523229160479, 0.14012546092271805, 0.07351590373686381, 0.15922778232821397, 0.18000269255467824, 0.17266981889094624, 0.0827376696148089, 0.0723668589655842, 0.1277474079813276, 0.17757010380072252, 0.08422556120370116, 0.16599261361573422, 0.17737764412803309, 0.12937031446823052, 0.1417501587420702, 0.08071145548352174, 0.19210489386958735, 0.1264041257756097, 0.19494087169212954, 0.08936530790690865, 0.09738882843937192, 0.09379642656339066, 0.11985916697553226, 0.15101038398487227, 0.23060484869139536, 0.11969288518386227, 0.14723436374749455, 0.07481031785053865, 0.12139933290226118, 0.15221616785441125, 0.06487695194248642, 0.13613206520676613, 0.12604865485004016, 0.15696463733911514, 0.15830658961619648, 0.08002812322229147, 0.1673243607261351, 0.11316233846758093, 0.11841571943036147], [0.0307641059958509, 0.02365500639591898, 0.013218259106257131, 0.024017322043489133, 0.09403707579310451, 0.032771826655204804, 0.0641282835443105, 0.03797021574739899, 0.06264665483364038, 0.03075539699888655, 0.03791555296629667, 0.023093072531212653, 0.03978395342294659, 0.044258403325719495, 0.03650374550904546, 0.06294649267303092, 0.043756138134215555, 0.03968795428850821, 0.050126089182283194, 0.04730619263968297, 0.025615029436136996, 0.01777611792619739, 0.03994550921821168, 0.016716154624841044, 0.023380484698074203, 0.011625243783263224, 0.03606115747243166, 0.03094311710447073, 0.033426124402987104, 0.04794821908165302, 0.019751687900030186, 0.055701686069369316, 0.024041895189189484, 0.031117487033563, 0.017256358405575156, 0.02177171888095992, 0.04203153621139271, 0.07971903695059673, 0.009020516632257827, 0.01740470142768962, 0.08244566206953355, 0.024580502716292228, 0.0022966024906574084, 0.012358148116618395, 0.04983113340235182, 0.01865711422371013, 0.04221043196905937, 0.023784803359636238, 0.010728028802467244, 0.02621398926047342, 0.0366117614986641, 0.06528352334031037, 0.013905173184217086, 0.03600516476269279, 0.010797706715363477, 0.03116786147334746, 0.03428100049495697, 0.07155554142913648, 0.03551142875637327, 0.04060847864353231, 0.026719000822465335, 0.02054531093952911, 0.02479142871951418, 0.05371872854552098, 0.0515973396998431, 0.025363577928926264, 0.03768516318606479, 0.03098204805116568, 0.023110436242339865, 0.03970380486654384, 0.024012937010931115, 0.0325306549535266, 0.014520601901624883, 0.06647755498332636, 0.017172469424882104, 0.01593848055095545, 0.042107891757041216, 0.02835180883162788, 0.06045377214572259, 0.017999649413728287, 0.024014470500073264, 0.0371091751647847, 0.06268454422908169, 0.03500793202381049, 0.06779805198311806, 0.04563646045114313, 0.025084065606019328, 0.014810758742636867, 0.11617765309555189, 0.03716177519943033, 0.04560674061732633, 0.013025935988740196, 0.041916137760771174, 0.02877027155565364, 0.028129201848059893, 0.027376202700127448, 0.04973715630226901, 0.014851647262860621, 0.051687486469745636, 0.027186431722449403, 0.010706380142697265, 0.013431489584036171, 0.008678493422589131, 0.010017206543125212, 0.030041791897799288, 0.05010698502883315, 0.045800916983612945, 0.048344436035092385, 0.04575875621022923, 0.02402281478446509, 0.02027495375036129, 0.013009437409761761, 0.025626986919503127, 0.06353084024574075, 0.04052841829668198, 0.05640266024108444, 0.03418179867523057, 0.05236938362941146, 0.02048866853250989, 0.04684826631897262, 0.016031419492459724, 0.027158018068543503, 0.02937047988442438, 0.09349812899849244, 0.13572103583386966, 0.021209501727883304, 0.0748970481966223, 0.0612642482987472, 0.006072956694489611, 0.05584770680538245, 0.037345631048083305, 0.024697470279144387, 0.04865328821220568, 0.04083252412133983, 0.016100250084751418, 0.03470373798960021, 0.06405633169093303, 0.06857317646167108, 0.045682814570942094, 0.03726846804576261, 0.04216067499614187, 0.06910344479339463, 0.016882273568106548, 0.037557191481547694, 0.025889244096885835, 0.05658033124304243, 0.015200670409415449, 0.022571922013802186, 0.0408108042153929, 0.04236109388460006, 0.032582118442015987, 0.025111619216789092, 0.04776163212954998, 0.0397547289196934, 0.025888224598020315, 0.020537049775677066, 0.04039608021931989, 0.08086570684931108, 0.06114930446658816, 0.06661061570048332, 0.012734199857472308, 0.011099519939827067, 0.01613920647650957, 0.06224876189870494, 0.010210627191034811, 0.05661245309082525, 0.03617290879732796, 0.02725077889460538, 0.014379485277459025, 0.008323702728375793, 0.05908184219151735, 0.01391091019779976, 0.06453440710902214, 0.008692751139668482, 0.03380405144499881, 0.03337681187050683, 0.009286895909878825, 0.06872180277215582, 0.020401563295828443, 0.03463102617700185, 0.05823174637875386, 0.015807187417522073, 0.053147201891988516, 0.02015789458528161, 0.031829490792006254, 0.05771638546139002, 0.022276406442480426, 0.020583132481468574, 0.03936817091224449, 0.03654711746743747, 0.042962323408573866, 0.03937758558562823, 0.004090273129155061, 0.03482778436903443, 0.04471116938761302, 0.03896687512419053, 0.02041964964675052, 0.020384825533255935, 0.05875448975712061, 0.026521732032831227, 0.010890732170082629, 0.018846893683075905, 0.0501656986639968, 0.048684975797576566, 0.021140616852790117, 0.0037584991909430493, 0.030805045406201055, 0.06931811970259462, 0.03901192645675369, 0.00866208559766944, 0.05161452359919037, 0.023336135649255345, 0.06610374325620276, 0.02033314491356058, 0.023356352600135973, 0.015406704175152948, 0.021515478612855077, 0.028790590286787068, 0.03755740861275366, 0.02474102713832898, 0.03430359571107796, 0.04470035353941577, 0.0511669958276408, 0.057522120885550976, 0.03181273776239582, 0.06382773324315037, 0.08219925886286156, 0.01709580684213766, 0.017977118658434068, 0.03578673755483968, 0.045342356232660155, 0.06815097161701747, 0.039692069603396316, 0.09240341452615601, 0.036486273232315264, 0.038397407824439664, 0.04140514321625233, 0.023163292423955033, 0.03572830890438386, 0.013159258790048105, 0.017408613182072128, 0.03440655322213258, 0.027523826475122144, 0.009154973435215652, 0.05971465752060924, 0.11161153989710978, 0.03487201128154993, 0.010671332112646528, 0.017295543802902102, 0.06528558608676706, 0.028326373946453844, 0.01188736270913588, 0.026840104056256156, 0.03471061833468931, 0.010328126555707837, 0.04517399473115802, 0.03216665145009756, 0.05306224591497864, 0.04222121728318078, 0.039777375025940795, 0.04864913557789155, 0.045467976813337634, 0.019892945320212414, 0.052148778324148486, 0.027515254881499068, 0.03099066883857761, 0.06560881302825042, 0.01040998162768249, 0.031616016889789274, 0.044116633611598184, 0.023970484467489377, 0.06435742482010808, 0.02569999050215951, 0.022445877348738055, 0.027000514823677282, 0.02327883506326803, 0.025309088174253702, 0.04749927317191448, 0.015781569327893, 0.02626670294973467, 0.08494195847639016, 0.05456545203924179, 0.009806643556138235, 0.03031949253220643, 0.14851264229842595, 0.01777776167728007, 0.03700399545154401, 0.03440790350681969, 0.030125682574829886, 0.04688194879729833, 0.014111655631235667, 0.009431657115263599, 0.005120341873927308, 0.019575855727972727, 0.04071003158709832, 0.013142826368233987, 0.016960245723436986, 0.06466805815164532, 0.05032711196690798, 0.04137609513210399, 0.08932648213314158, 0.1098068335226604, 0.06806935063962426, 0.07822013273835182, 0.051286614766078334, 0.09267802443355322, 0.039856336146060906, 0.03763746895960399, 0.04212754213118127, 0.006778789176938257, 0.032538712556873045, 0.05148204642214945, 0.04048143992466586, 0.04931593533339245, 0.06603517729256835, 0.0049835776278216925, 0.02329966439200299, 0.017928956242810403, 0.03730410131226693, 0.05914981782968555, 0.04701220377215317, 0.0840095156537635, 0.036297932267189026, 0.03549714220155563, 0.09873422767434802, 0.09075665074799742, 0.021301017442185963, 0.03853521489405206, 0.052719524662409506, 0.04132978850975633, 0.029329526903373853, 0.06538413651287556, 0.05485526452373181, 0.026634745432862213, 0.03117475878181202, 0.0709122291633061, 0.028994578269443343, 0.019244845989825468, 0.024410516123420427, 0.007284705310926906, 0.022102487739175558, 0.0194772713751133, 0.04969811339729598, 0.06197217066905328, 0.016636967891827226, 0.039478144475391934, 0.017903752059542706, 0.03324317439858403, 0.08322340569325856, 0.01794340564603252, 0.017320909138236727, 0.019250942626968026, 0.05169466197756784, 0.12348818938646998, 0.1277858130633831, 0.10355612143341984, 0.16156870100115026, 0.09218046148972851, 0.1336891355791262, 0.08069807477295399, 0.13884427824190684, 0.13201132203851426, 0.1360023021697998, 0.08178601068045412, 0.12812888036881173, 0.11962906218000821, 0.13063063898256846, 0.14321451873651572, 0.14776267111301422, 0.18703642727008887, 0.08323962946555444, 0.07661707340074436, 0.13757813189710888, 0.09570534234600407, 0.11775466347379343, 0.0789326284346836, 0.07255422962563378, 0.07290802456970726, 0.13449702651372977, 0.05567133519798517, 0.09855140998427357, 0.18360677201833042, 0.15003963107509272, 0.18979210725852422, 0.1896238305738994, 0.09819738433829375, 0.12897916617138044, 0.11390579571681363, 0.1267150305211544, 0.12455040881676332, 0.10672447963484696, 0.07243479389165129, 0.17192201901759419, 0.11127654715840306, 0.18470479095620768, 0.06433745553450924, 0.13594317462827477, 0.10698380893362419, 0.13777308857866696, 0.12188827166599886, 0.0811448290145823, 0.131860347996865, 0.1235772403223174, 0.23816106894186564, 0.08145553698497159, 0.22961201625210897, 0.08794408916894879, 0.1400469544210604, 0.10685876171503748, 0.2248223732624735, 0.12797661711062702, 0.1304194246019636, 0.12349209774817739, 0.16673529733504566, 0.1592127459922007, 0.08333491613822323, 0.1340836901217699, 0.09921347017266921, 0.08303494259182896, 0.08602614887058735, 0.19067410778786453, 0.2508296434368406, 0.12039379828742572, 0.08276571346712963, 0.09068216795900039, 0.2072128831808056, 0.08539098581033093, 0.06366020294704608, 0.11797009834221431, 0.13249137199350766, 0.09199615780796323, 0.09540673265499727, 0.12181049798216138, 0.20472580806485244, 0.200503053941897, 0.16765461729041167, 0.18580827888633522, 0.16090007259377412, 0.1563966085336038, 0.11484016557889325, 0.17351945329989704, 0.14230472541281156, 0.1378872860223055, 0.127757938844817, 0.13220421597361565, 0.1196659202022212, 0.09278516511299781, 0.16290194088859217, 0.24055917454617365, 0.08348662299769265, 0.09166822861880064, 0.1327788129981075, 0.101903963301863, 0.14559830725193024, 0.08663748178098883, 0.11680958632911954, 0.12032107290412698, 0.16824224218726158, 0.09474901509072099, 0.19407502029623303, 0.1731904452400548, 0.07511782992099013, 0.12965263931878976, 0.15709948938872131, 0.0780653114031468, 0.1403127908706665, 0.05463863882635321, 0.1836564407816955, 0.06816331416900669, 0.11110084051532404, 0.10921802797487803, 0.1862188061433179, 0.1095476331455367, 0.16537461749144963, 0.1836613126631294, 0.22576397630785192, 0.1908762976527214, 0.17541719361075334, 0.1841113306581974, 0.1238274976078953, 0.12435306369193963, 0.2166672780045441, 0.10253463446029595, 0.12382080725261144, 0.1864238322845527, 0.10973513272723981, 0.10088192671537399, 0.20035236488495553, 0.13401472382247448, 0.13084083556064538, 0.14895587494330748, 0.13775962644389697, 0.1273479951279504, 0.15598431708557264, 0.09634748753160238, 0.13038967762674603, 0.16797787137329578, 0.15768619147794588, 0.09127655106463603, 0.12102520226367883, 0.14195597198392662, 0.138169366600258, 0.13605796918272972, 0.12040555051394872, 0.13513189101857798, 0.10589733187641416, 0.15436891519597598, 0.14771365374326706, 0.08223171319280352, 0.15272282995283604, 0.12937560704137596, 0.17234151650752338, 0.08160426507570914, 0.10157220717519522, 0.11993790417909622, 0.15745846155498708, 0.1458305697888136, 0.24610788109047071, 0.13256446378571646, 0.17735868585961206, 0.28790243555392536, 0.11785254893558365, 0.05533328226634434, 0.10863074913088765, 0.15171458119792597, 0.11552522810442106, 0.10468885422285114, 0.05328091400276337], [0.019236198061012795, 0.04229002073407173, 0.009080405829341283, 0.03366887369858367, 0.05768760879124914, 0.06103256930197988, 0.02474366155053888, 0.07760212982871703, 0.07557454505669219, 0.03188484567882759, 0.026161847236965383, 0.025723810473989164, 0.020394072269222567, 0.04323512162747128, 0.06561445165425539, 0.019348972277449708, 0.01396293517401708, 0.015961384500509927, 0.007335475845528501, 0.013984626242225724, 0.03507399758590119, 0.07684185169637203, 0.02116950717754662, 0.019762798910960555, 0.03270274839763131, 0.07026415358164481, 0.06976486037352256, 0.0038619376136921346, 0.022703815650727068, 0.03601679824558752, 0.0541401734309537, 0.03696792792262776, 0.04205245544601764, 0.023498858524752513, 0.003201447385695896, 0.05635756141106997, 0.0720864747251783, 0.03827177706573691, 0.024473244989556924, 0.024439925527466193, 0.0065207266182239565, 0.05203866905399731, 0.0758305291778275, 0.03723619692027569, 0.04232677358335682, 0.018224242808563367, 0.06336721152599369, 0.02961068128102592, 0.04857975537223475, 0.08542975730129651, 0.0737333402835897, 0.013207534860287393, 0.014280051059488739, 0.06005156372806855, 0.01579825111132647, 0.029579852042453628, 0.051346668507903814, 0.030869068577885628, 0.032268838823906014, 0.007358719910761076, 0.05137740953692368, 0.039964823717517514, 0.02437323740949588, 0.06259685714862176, 0.03509095756869231, 0.05860612128994294, 0.045289003024143834, 0.10433501178132636, 0.03329839697107673, 0.027899390518931404, 0.027938579308933446, 0.017490003457559005, 0.007325986533292702, 0.0042653025094685805, 0.035356454750789065, 0.025385591301268766, 0.05200585849317057, 0.03710881554122482, 0.03635672732655491, 0.04348563336368118, 0.015121807676873036, 0.045007899536618164, 0.037930687689887624, 0.04366631027577179, 0.062258973850735595, 0.06312964963061468, 0.024508101333464895, 0.02216854481957853, 0.01062691436215703, 0.029236625281295607, 0.018825426531423415, 0.02251899628234761, 0.007119678809041423, 0.08749736885407142, 0.06330351744379316, 0.039080417781536064, 0.018223783101088235, 0.06400915315108639, 0.04234081586556775, 0.04649000322180135, 0.010156756599566765, 0.03106850359056677, 0.026870610990694592, 0.04994433339951294, 0.008615154723104621, 0.07283031195402145, 0.015135637916890638, 0.03632880561053753, 0.0523441624827683, 0.043356548861733506, 0.02869476078610335, 0.04441413729052458, 0.040113324499023814, 0.003174826124450192, 0.007505822061960186, 0.002099716861266643, 0.09863269847950765, 0.02832993964797684, 0.028137469797262123, 0.02178261276068432, 0.021840663127867237, 0.05693402101418801, 0.07770747239036219, 0.020727165109877075, 0.04737902658858469, 0.06138289014675787, 0.026950727316683958, 0.04584741020309074, 0.014909946991662894, 0.023824741930833886, 0.05202400251956923, 0.08660612667777709, 0.03209561901167035, 0.028669166445199932, 0.050559588242322206, 0.03199619666806289, 0.044526329663183005, 0.07007802464067936, 0.016861181307051862, 0.01211872449078198, 0.04990111750417522, 0.0153844634935792, 0.0074926567862608606, 0.05155968100630811, 0.035193490995360274, 0.042185020832610984, 0.12565575593284198, 0.04313636764085718, 0.048235239394541295, 0.035686585786087174, 0.05173157088990722, 0.012940773906718408, 0.037147726131869216, 0.04862620787961142, 0.04633223365194031, 0.028410800666149174, 0.0260770693753979, 0.030434300657361746, 0.0063537836789951795, 0.039303245288985114, 0.08455239795148373, 0.01351159658016903, 0.03726089898762958, 0.10693023859390191, 0.03677602464865361, 0.03100503681759749, 0.0030339037309334215, 0.07697683266763176, 0.02754055575600692, 0.09409283101558685, 0.056439962703734636, 0.02894121827557683, 0.01860731314601643, 0.010032953644570495, 0.008269080659374595, 0.004544799565337598, 0.03854141331144741, 0.01462299792495157, 0.005370566080923059, 0.002838380048550399, 0.026115374373538152, 0.029098014147686105, 0.01861816461730216, 0.017183251346328428, 0.12052923387714795, 0.023140140809118748, 0.013578543389615203, 0.035943720024079084, 0.04538619298753994, 0.053336611549769125, 0.09139477900628533, 0.018576750232438956, 0.018236458135236586, 0.021466386604255865, 0.05906295856194837, 0.01470916169429464, 0.018855129401864748, 0.05078304000198841, 0.008985034339795155, 0.030104346041168486, 0.03853029551516686, 0.014565658323200685, 0.01989944398935352, 0.028163338944848095, 0.027407946264637367, 0.045228206286472936, 0.01775687636940607, 0.03005765943921038, 0.03962912869506648, 0.016364690448556627, 0.026639130465420227, 0.07861527082111154, 0.030787016730755568, 0.03051395049052579, 0.03610826476610132, 0.015760317611108934, 0.021330627014062235, 0.026943214237689972, 0.019317199875201498, 0.018490732348124896, 0.02025563076936773, 0.0215582653347935, 0.03373277134128979, 0.008767465478740633, 0.016022898788963045, 0.031940258241125515, 0.06186837516725063, 0.01949854684062302, 0.01141229150484183, 0.01958481239021889, 0.06646621666316475, 0.03120053293449538, 0.03728721936100295, 0.07529718708246946, 0.02348913172526019, 0.0029540299812132226, 0.05205452302470803, 0.040249777891274006, 0.00557443659220423, 0.06530326192400285, 0.03641011446182217, 0.02396421819659216, 0.03466412511521152, 0.00881791370920837, 0.014328698627650738, 0.04138902461688433, 0.013477252530200141, 0.0422432968126876, 0.03006908596892442, 0.03709899713950498, 0.07639893117759909, 0.0623253413609096, 0.05181603153635349, 0.05103790793301804, 0.007983011143681194, 0.001923576379860086, 0.01932264511872615, 0.043756440082298856, 0.029198074314211096, 0.04817615256511739, 0.04180747377020972, 0.04873129938329969, 0.04524008743464947, 0.048740680129932504, 0.06155177751289947, 0.009849776330936168, 0.0008027253747319005, 0.04491027531081012, 0.011266904350902354, 0.05533503627936755, 0.030813581376735653, 0.04726421846342938, 0.032670436560043266, 0.02332758780435792, 0.08567194680550269, 0.03615534491837025, 0.03729900551427688, 0.037501219127859385, 0.03830723391313638, 0.06948202662169933, 0.025774234107562473, 0.025183131718741994, 0.05462851508387497, 0.017348035271944742, 0.0578491815498897, 0.01874825165473989, 0.022368900943547487, 0.050632076138364415, 0.02722493519208261, 0.009777737964343811, 0.03851896398035543, 0.03454750530155642, 0.06642538921109267, 0.0053752216793197605, 0.06383651348629168, 0.06478213345898048, 0.044333771602915864, 0.08226132446101733, 0.02532471313939563, 0.042051929581378183, 0.02612664144752281, 0.017913743487692306, 0.03168660828045436, 0.0574441911386592, 0.06710289964186293, 0.03904380063925471, 0.024635482712515762, 0.004225278697309217, 0.026421478483825922, 0.04543191606977156, 0.021386986132711172, 0.01949776482901403, 0.01961141774830009, 0.08906809599804026, 0.03480157595393913, 0.040603800144578726, 0.01611505911153342, 0.017410200954015766, 0.020583103643730283, 0.019491632568782995, 0.025720599307013408, 0.024571188126823733, 0.06241898597883327, 0.043844120377408605, 0.024072302039712667, 0.11245522355394703, 0.08624669989304883, 0.052523709634052854, 0.022175837374691452, 0.07342059670814446, 0.037740582533712895, 0.045273417074765475, 0.04504110364775572, 0.03141747075798256, 0.015116421805162514, 0.009564618596674075, 0.06088668427297047, 0.07350799201854638, 0.0503097312924053, 0.08347582750554595, 0.04716474183702043, 0.07166958280972072, 0.03044665338737624, 0.06182342900761536, 0.04588613758928009, 0.026796331762203147, 0.03321717293666942, 0.0446500842725592, 0.02235612243280879, 0.04467081351737891, 0.027656189997547438, 0.028709888724344115, 0.08802499089922224, 0.12040268709617001, 0.19807098087455544, 0.10599374491721392, 0.13735832726316793, 0.21013286363865646, 0.12079429679683276, 0.14043221303394862, 0.22275816117014202, 0.11963425975825105, 0.15259370473878725, 0.10305377481771366, 0.1036922423435109, 0.21140514394002302, 0.18487313549433435, 0.11001017689704895, 0.13533146173826285, 0.10191046366734163, 0.11198901571333408, 0.11369897824312959, 0.11051544121333531, 0.19858193131429808, 0.05537720723077655, 0.10592353689883437, 0.16939111053943634, 0.09072440676391125, 0.139825277030468, 0.10941198720995869, 0.13796682389719145, 0.1299761783863817, 0.19144375648881706, 0.13762394658156804, 0.19699859698968275, 0.06176201480307749, 0.10915190473731075, 0.17917881533503532, 0.15873615656580242, 0.19155779108405113, 0.11087950239224093, 0.12022075828697, 0.0838485671473401, 0.14708276545362814, 0.09941669819610459, 0.09178373563502516, 0.13596677407622337, 0.11049125143992049, 0.1426087769546679, 0.09743344890219824, 0.10055859799363784, 0.15996833544756683, 0.16657698154449463, 0.12254859480474677, 0.08529286964663438, 0.13647834876818316, 0.17761496853615555, 0.1477750747331551, 0.15223348406808718, 0.16485503608626978, 0.10442480232034411, 0.1533796111387866, 0.16275376241121972, 0.15191797885511601, 0.12257606190230165, 0.10114065890333482, 0.1769641584583691, 0.16231033977653297, 0.20383559726178646, 0.14382457600108214, 0.07357875643564121, 0.1317859941295215, 0.12571580628199236, 0.11682838174913611, 0.06835996718811137, 0.1319585455847638, 0.11636506446770259, 0.1502227812473263, 0.18181442176657064, 0.1610629345689501, 0.12314942399305956, 0.1295496919857604, 0.10797421900289399, 0.173578214432512, 0.1397120159651552, 0.14281088539532252, 0.14109691950891698, 0.2306756606059415, 0.12303705859397139, 0.11960965607847486, 0.1624672577849456, 0.07556376992059605, 0.12767494044133595, 0.15770589613488742, 0.1144832968711853, 0.16210220594491276, 0.16490155644714832, 0.16797168313392571, 0.15515174104699067, 0.10637873211609465, 0.13528104658637727, 0.1417165169758456, 0.10877034414027419, 0.18456178291567735, 0.1550015133938619, 0.13165931164153985, 0.1382790585713727, 0.15128249009805067, 0.16160306201449462, 0.10559730404721838, 0.18651353461401804, 0.12722180118518217, 0.09868876582809857, 0.10180902946740389, 0.14596376621297427, 0.09013016615062952, 0.10987474809267692, 0.13985530899039336, 0.20007835887372494, 0.08815845873739038, 0.15166108549705573, 0.09794652994189944, 0.1791423780045339, 0.15372718391673906, 0.15267518322382653, 0.1486727087093251, 0.11802615890545504, 0.10019197195236172, 0.13605055958032608, 0.1395091882773808, 0.11840160590197359, 0.15493925102055073, 0.10920977698905127, 0.237205121666193, 0.071525760527168, 0.07255419569888286, 0.1326781048306397, 0.1419732474855014, 0.10253401699342898, 0.16536586438970907, 0.1366215603692191, 0.09690606434430395, 0.22540405419256004, 0.12865705202732766, 0.12722659164241382, 0.1328045701874154, 0.08550259125019823, 0.07864220866135188, 0.16696648778659956, 0.16843995372099535, 0.10641865033124175, 0.12439332795994622, 0.16965858904378756, 0.20807782533977712, 0.11197309049644641, 0.11581144774598734, 0.12880851461419038, 0.09544762117522103, 0.16240685459758553, 0.06899950001388788, 0.11812856341046946, 0.14187107368239335, 0.11778854951262474, 0.08882773853838444, 0.1635757533035108, 0.1877413165888616, 0.11025029686944825, 0.22723239394170897, 0.0881464486675603, 0.22485091244535788, 0.1528250037559441, 0.2460068879382951, 0.15636984711246832, 0.0932396546538387, 0.061617934677217684, 0.09937734995037317, 0.1690030020794698, 0.08132999443582126], [0.04380834461855037, 0.03034540917724371, 0.025614788556205373, 0.015793255397251675, 0.033122561406344175, 0.042715041499052725, 0.049757027200290134, 0.039049368019082716, 0.04859239308695708, 0.018291797755020003, 0.022002522567553178, 0.043187956658325026, 0.01606781441452248, 0.041149423723774295, 0.052736532142651935, 0.004239782383332827, 0.04161132625969393, 0.03539606083982757, 0.021478215165968453, 0.04357680132878678, 0.04591143337477531, 0.01757898145089192, 0.0034355283964292277, 0.023395956992836933, 0.02268740358496351, 0.02127308045913066, 0.11978929143931184, 0.04368305652003203, 0.034733396755265336, 0.024906579504853914, 0.017552988470665047, 0.023553796112537384, 0.011988229484164288, 0.017517384041899016, 0.019263483650450195, 0.03166833872507725, 0.009103454815755998, 0.0265246565187616, 0.0500521356506007, 0.024844383288707052, 0.01479515922255814, 0.030495572369545698, 0.077455749469144, 0.018440474955631152, 0.013535072195476719, 0.03955457805256758, 0.044249460234173706, 0.024861406035987393, 0.02610376463936908, 0.05944097720618759, 0.02276427990623883, 0.006137939145056797, 0.0751423928886652, 0.006167253554199955, 0.052507119452846904, 0.05109830433502793, 0.030246872321835587, 0.07138349887515817, 0.06677000357636384, 0.030740096034216027, 0.045454640207546096, 0.051170069591275284, 0.0467350697144866, 0.06425397537116494, 0.04570302473647254, 0.035620286129415035, 0.05212224081956914, 0.016039931714268665, 0.05966081576687949, 0.01850425385470901, 0.09630650401647602, 0.06461187545210123, 0.005355511085196797, 0.015398254717833229, 0.03098661798451628, 0.030464247800409794, 0.035202922632119486, 0.03386366753173726, 0.10281634184398822, 0.020040592843932763, 0.009770977211051753, 0.04950968422261732, 0.03116856375709176, 0.03768161105524216, 0.042362742724695375, 0.02383245008864573, 0.012415553027364825, 0.02777230939162629, 0.04284263661663447, 0.02333520775261734, 0.022142180341428945, 0.05445003662524479, 0.009728008980995842, 0.0590818693329181, 0.046160085925034115, 0.013273573280977351, 0.01555448062052684, 0.029609785614801303, 0.09033984025674206, 0.02337307679200811, 0.0426216275830354, 0.02620042534545064, 0.04193815961480141, 0.026091754569539, 0.05216605382572327, 0.0516486980154046, 0.04430343769490719, 0.013324331093047346, 0.05910673764135156, 0.028385872985901575, 0.027181381725573113, 0.041238064145935435, 0.025558621123699204, 0.04262372086356793, 0.03368638329473989, 0.021152701561472247, 0.02651317909892116, 0.049914060559655936, 0.05193293972739151, 0.019629929879946367, 0.04642327608806746, 0.015112184353971055, 0.026636431592383554, 0.062353955182646, 0.009848484569894416, 0.027309207545061196, 0.04905393599931683, 0.012679245306311973, 0.028368967285911952, 0.0245450475652303, 0.011473128954613847, 0.025536000462515012, 0.024627347077642168, 0.04520948550530842, 0.024422312454719628, 0.044176761992275715, 0.045382705317544084, 0.03154561209625431, 0.04319918641288366, 0.009737237057249461, 0.02538569308152156, 0.042615951637604406, 0.04852591022582991, 0.03787868476605841, 0.03886883359934602, 0.01609473189871226, 0.02508929541467556, 0.06764823823635067, 0.025483247757490193, 0.027522866348070756, 0.017450358352756927, 0.011133588334944631, 0.01691526054803814, 0.017417620734444687, 0.017930471072239534, 0.04188029754108616, 0.018761303275823593, 0.03520563677219408, 0.06602103662277971, 0.03608776283051286, 0.018583057215437293, 0.023801305331289768, 0.02146588109566697, 0.004755772641926471, 0.10112104924129588, 0.030561183313173906, 0.0473722480237484, 0.007159116112494043, 0.025248471248362745, 0.023288611056549207, 0.05081027979031205, 0.034658812186015506, 0.03253530291840434, 0.030789327142494063, 0.046251376026443074, 0.03794102177822164, 0.042271228706730266, 0.033613912362073145, 0.05591644918812173, 0.029479774912553172, 0.015669002064636776, 0.06450155922876936, 0.03459744208625384, 0.05076729798955577, 0.04270603733935526, 0.02001172796423946, 0.05750531357313905, 0.01327768265868404, 0.06510138418525457, 0.06746835181755678, 0.028050169481762817, 0.03858952144426959, 0.044291627792907615, 0.0041125948108466604, 0.06777648135487523, 0.054267972109041045, 0.04309226625732013, 0.018362440035811493, 0.011780151631683111, 0.057675578365368504, 0.005736515707602459, 0.03740921995735594, 0.06876314591084208, 0.04234765549855573, 0.046331429587943215, 0.030923012111868178, 0.02924118164394583, 0.0503086761704513, 0.011231506027148237, 0.025044349255040288, 0.020349100664524094, 0.03475027870652931, 0.039535616391471455, 0.05515978764742613, 0.029881433716842105, 0.04205263525779758, 0.0414466220619423, 0.05894367889102016, 0.06971812288143805, 0.019593714769663553, 0.016710057987698486, 0.024914469170783247, 0.03371798267055835, 0.04195385752245784, 0.07303443564368145, 0.01248898239074541, 0.05613225385812776, 0.01054282860630857, 0.0670101371194635, 0.010669046297802456, 0.049453199574989934, 0.010176299256272614, 0.06616497425628559, 0.03910613086606775, 0.080172339055155, 0.027235518642035977, 0.0507942392224712, 0.02997324289754033, 0.049684630906475444, 0.03514269247118916, 0.05387900869495102, 0.029707179138703004, 0.10100276701684509, 0.03728444076010159, 0.0394644550313907, 0.023452434855114137, 0.06473574880510569, 0.041090404747852256, 0.03691570447491748, 0.012273960580517138, 0.026274428070921983, 0.07657381000795535, 0.019164600742182562, 0.10217164536671978, 0.009031240878227566, 0.04241092210369451, 0.04194328933954239, 0.027875294044081653, 0.011965015953007554, 0.019550865283235908, 0.024705731442996433, 0.05322694332738008, 0.016073157877794335, 0.049062583928129504, 0.029548798887325183, 0.02747565897048584, 0.03761916208480086, 0.0693864074668714, 0.02903527340718678, 0.023931039530517798, 0.034459383958684545, 0.010043619366894876, 0.04156711970322898, 0.04148801609075495, 0.021053716872951815, 0.008914043461637837, 0.040757386546049795, 0.034701814342822344, 0.008233629749156535, 0.020451747745807682, 0.10827981081924268, 0.07894516097647802, 0.02424935727114124, 0.017001880632181252, 0.033698732632079294, 0.018594940059951375, 0.02435577191811587, 0.04208084535119789, 0.06285841882761035, 0.02107544695692403, 0.035935916871364625, 0.06609582475253514, 0.05860603308039052, 0.08611265530011483, 0.05845861456223896, 0.04682394423122917, 0.02956118554409061, 0.024663112658475126, 0.044702989647963216, 0.009682658244855702, 0.02293825798135783, 0.057007397791104655, 0.028440686741045544, 0.03313318047938602, 0.014660797414502926, 0.03823389106297067, 0.029270653812480823, 0.006547415096844945, 0.022129902250266502, 0.03931570997727769, 0.015435443525867803, 0.05012256419286132, 0.006991141375952533, 0.004640830082020589, 0.06559489627501794, 0.02305199232484613, 0.05899855201797826, 0.031012656765856912, 0.05772979331335851, 0.014362613504220332, 0.041161474505705495, 0.009322232317312487, 0.028786162845790386, 0.031202670319804122, 0.035513237052197964, 0.03966440912336111, 0.03804741606914571, 0.018074664852714965, 0.05424130229013307, 0.03770233690738678, 0.0696049432403275, 0.055377332759754996, 0.039218618401459286, 0.04098048546750631, 0.04178959097979324, 0.038715959659644535, 0.046794814722878594, 0.024488875043711493, 0.045572759583592415, 0.022718741724799787, 0.06029359716922045, 0.053726908285170794, 0.006229914142750204, 0.022184692256684815, 0.04339569354695933, 0.040103207541895766, 0.0196483639800655, 0.03191390394100121, 0.012723009966846024, 0.022333384724333882, 0.036070612857916524, 0.01874381403571793, 0.11759253431643758, 0.060360582146261416, 0.1384062703166689, 0.0528697387448379, 0.15380460476236685, 0.136790094897151, 0.15617563681943075, 0.15448674958731445, 0.08936168452990906, 0.09089940094522067, 0.16390451709074633, 0.1698755302599498, 0.10440922994166613, 0.20153967903128692, 0.08282045088708401, 0.15823140793613025, 0.11168717619563852, 0.15243487326162203, 0.11062315186219555, 0.1552515806896346, 0.12331889489931719, 0.07301317035619702, 0.16033481221113885, 0.20333927603704588, 0.12553573665874346, 0.0882649344525167, 0.19803112372756004, 0.09876068375472512, 0.25426951742597986, 0.14031287229486875, 0.10750309856874601, 0.08525067833917481, 0.12338220221655709, 0.12339737425957407, 0.11962697229215077, 0.11900646558829717, 0.14375377765723638, 0.147406046677913, 0.18671664728650025, 0.06856872527194874, 0.126463117610131, 0.20458760405225412, 0.13719623881791318, 0.1161584776959249, 0.1268510767923934, 0.10556256305426359, 0.12087939865887165, 0.09075157530605793, 0.16820809830512318, 0.10734995321503707, 0.09483116532542876, 0.10533741156437568, 0.29986891629440443, 0.1837873708988939, 0.1330457893865449, 0.08182124700397253, 0.2084962778857776, 0.15809385531714984, 0.24155333691409656, 0.2083661077278001, 0.12383443223578589, 0.15913733361022814, 0.15325743412332876, 0.1502876899072102, 0.212345349203263, 0.09734835382550955, 0.28007908963731354, 0.1259700669241803, 0.16401419549116067, 0.08008658579949822, 0.1703393225158964, 0.2612375020980835, 0.11841314099729061, 0.14856008546692984, 0.22069686677839073, 0.20802651452166693, 0.11915380268224648, 0.19426097960344382, 0.14614231591778143, 0.1182048578879663, 0.17463562983487332, 0.1715106910892895, 0.14927843692047255, 0.1329657765371459, 0.15548198404056685, 0.16372579096683434, 0.05251238488459161, 0.14469470216759614, 0.15578370142195905, 0.0866105914381998, 0.14781286913369382, 0.16207104761685642, 0.1365627720952034, 0.15446985406535013, 0.14252633494990213, 0.1797240860760212, 0.10624774771609477, 0.1306483351758548, 0.16222815561507428, 0.13065358703689917, 0.10167927321578775, 0.10990076312529189, 0.1011804278407778, 0.049967790355107615, 0.1992410330900124, 0.18006507706429276, 0.1282798679811614, 0.1409643201955727, 0.1799662552241768, 0.13851991136159214, 0.08888625539839268, 0.15406520292162895, 0.1001831984945706, 0.05265651250790272, 0.14484018007559435, 0.15148135514131614, 0.13931116461753845, 0.16365595614271505, 0.16211146116256714, 0.11602168503616538, 0.09398214838334493, 0.11823691188224725, 0.17479075651083673, 0.22604735967304024, 0.10950390834893499, 0.09610084005232368, 0.0954642995659794, 0.1347854717501572, 0.07649809228522436, 0.2254712970129081, 0.2247908485255071, 0.0942374878962125, 0.08567057616476502, 0.07379728542374712, 0.11031266780836241, 0.13311869118894848, 0.1831749930445637, 0.08499599700527531, 0.15876480431428977, 0.07281226970787559, 0.1218595424933093, 0.11312094783144337, 0.23339574464729854, 0.11957264877855778, 0.12439017955745969, 0.17005937253790243, 0.05948833216513906, 0.15606568700500897, 0.07636170674647604, 0.1322998758405447, 0.10575667156704835, 0.14530883064227446, 0.15279015419738634, 0.11420649529567786, 0.08202796269740377, 0.12335533222981862, 0.11713468602725438, 0.12019197483147893, 0.1275867037475109, 0.251516836562327, 0.15090423396655492, 0.06617302846695695, 0.14554804137774877, 0.11923324556222983, 0.16611097726438726, 0.14025877948318208, 0.12323277523475033, 0.11468236547495637, 0.17461621016263962, 0.09136885218322277, 0.06879867400441851, 0.18216052890888282, 0.1668342955942665, 0.1129815699532628, 0.14664273549403462, 0.18824940361082554], [0.07787129788526467, 0.022664251970127225, 0.02921944477462343, 0.041269269971443076, 0.03206209259639893, 0.050153569850538454, 0.03091186038883669, 0.036139792895742824, 0.023960861144587398, 0.03850844668756638, 0.08736876611198698, 0.04940142735306706, 0.020965644723868797, 0.10716181581041642, 0.030929834781480686, 0.03153580387255975, 0.01183831226080656, 0.008085178161439086, 0.026911043196118305, 0.05573030328378081, 0.07161555106618575, 0.045741616415658166, 0.07860557455569506, 0.02753547522505479, 0.03502825414761901, 0.07976626977324486, 0.05093961874289172, 0.017486636227528964, 0.04759140804942165, 0.011077249572346253, 0.05268819330792342, 0.0308260087456022, 0.04723016618351851, 0.023813345935195684, 0.013400358397380581, 0.09184969602418797, 0.020310620943616544, 0.09410583853189435, 0.02368946240416595, 0.011729445557908287, 0.03702564750398908, 0.02352178791937019, 0.005874374939594418, 0.05133095024419682, 0.03540101075278861, 0.03942626029519098, 0.061137844010123184, 0.024516616947948933, 0.007057118728490812, 0.021355402023930634, 0.008853229760591472, 0.03596191833327923, 0.0703164211341313, 0.038275790600372214, 0.08773887982325894, 0.014339940256572195, 0.027842817661751593, 0.04067338391074112, 0.03890706904764686, 0.04051928521533098, 0.032635807525366545, 0.0165897384618542, 0.019895562769046853, 0.05476182007363864, 0.01841849211736449, 0.06316029227205686, 0.03332453413999506, 0.032977181885923655, 0.018147486927253858, 0.017511183928166116, 0.0365104019375784, 0.026065179745533636, 0.027420509340507642, 0.02756084395306451, 0.054973733345312734, 0.0263122224714607, 0.05621140157537801, 0.05680779993001904, 0.08258939614253384, 0.045494521103267155, 0.04584995470941067, 0.023885754103373204, 0.053298002907208035, 0.05017352217276182, 0.03813106586624469, 0.08960747026971408, 0.030435182752885988, 0.05220517136954835, 0.06680713979793446, 0.0015503914494599614, 0.03445924485900572, 0.017698756452383738, 0.03731051686086825, 0.04306483308651617, 0.03163340774231723, 0.003597012097348592, 0.0023249866706984384, 0.035543808447463174, 0.03793457230286939, 0.051117727399936745, 0.03494912000106914, 0.06562656350433826, 0.04311197091426168, 0.05334154110667961, 0.053284438992185254, 0.05600475373544863, 0.06531303961362157, 0.05500728690198489, 0.02695435917537127, 0.0557525015569159, 0.017464309032740336, 0.04467960733122059, 0.03235541310693536, 0.043487221135624816, 0.06536275587443795, 0.037476805437888415, 0.06181242995496307, 0.05577311545078244, 0.020289962944973792, 0.04183184674807957, 0.026213293762079308, 0.03082984246845756, 0.028698000790817395, 0.029002323746681213, 0.021359859999003153, 0.023087618806000267, 0.055423330648669174, 0.04493007156997919, 0.025394179858267307, 0.067349669257445, 0.02946160713742886, 0.053206617810896466, 0.041107483474271636, 0.018583728965105753, 0.05349548713171056, 0.0210645666479, 0.0703782696010811, 0.01216348066061203, 0.03486613856096353, 0.019677607143031697, 0.03708202697868858, 0.027903755195438862, 0.019678133007671152, 0.09849380236119032, 0.021556926924469214, 0.011441522793445204, 0.0461216367382024, 0.05222793621942401, 0.059172236626701694, 0.005278599564917386, 0.04540494430278029, 0.039042280720812936, 0.03345043631270528, 0.012083081046252378, 0.041071002038994005, 0.036194343718567064, 0.055632224439510276, 0.09830049451972757, 0.01822091798697199, 0.03631950968078204, 0.017079951175089394, 0.03347046666645578, 0.006093081619058336, 0.016250820398064594, 0.013323606756914939, 0.04092683709625687, 0.051612929041896544, 0.006008715119345912, 0.01952693674580327, 0.0897692669449108, 0.04808932722413114, 0.023844244723607386, 0.0369536956506116, 0.0470589310862124, 0.09378470826361861, 0.02272700797766447, 0.04316254212920155, 0.042495192760335546, 0.019274146828268255, 0.03299238785569157, 0.03878940429006304, 0.04439699410327843, 0.036702630908361504, 0.04450443673080631, 0.07868163833128554, 0.028136655555239747, 0.049716695078781674, 0.015627465543470213, 0.008079487797138947, 0.04534213910145419, 0.038514987765146155, 0.025059265151087726, 0.029150648109082664, 0.010639397710162615, 0.016007563897541592, 0.06883182722542967, 0.023566562748913254, 0.04578244386773024, 0.05301688924165709, 0.052352647563176494, 0.007490760280883738, 0.04588383735556688, 0.00993668139978711, 0.023677786512832557, 0.04826090158894658, 0.03640299662947655, 0.047804220379995446, 0.08414473411227975, 0.049121307741318426, 0.04665498222623553, 0.03149381273293069, 0.03637048462405801, 0.04179725842550397, 0.027360163828624145, 0.04491939142878566, 0.026154756546020508, 0.04840836421187435, 0.026056784571015408, 0.050935418611126285, 0.058749034335570674, 0.04902862325044615, 0.032088100843663724, 0.020909438275599053, 0.05410555796697736, 0.028798040601291826, 0.023440131318888495, 0.032360057679138014, 0.03143197444400617, 0.03647696712453451, 0.013636296897727464, 0.036809466247047694, 0.034033040050417185, 0.059114249024008, 0.011450156303388732, 0.05099273785682661, 0.04032494939331498, 0.04155147607837405, 0.02663353594419147, 0.027489448498402323, 0.03569473838433623, 0.030047450879854814, 0.01160032204019704, 0.07092832401394844, 0.03142195587445583, 0.035860267002135515, 0.013255321537144482, 0.04432452317061169, 0.05565937601828149, 0.023083829187921116, 0.007468819002886968, 0.04479997605085373, 0.09458568492638213, 0.02892192413232156, 0.038655030607645, 0.015783978127209202, 0.044284218190503974, 0.06970968190580606, 0.019207592720964124, 0.04124303441494703, 0.03787186548912099, 0.016554761677980423, 0.04369506658986211, 0.031080004759132862, 0.04401362521041717, 0.08620635420084, 0.05474656999909452, 0.044372403994202614, 0.008701524597459605, 0.015963365822764378, 0.015951961345438446, 0.07776442183447735, 0.027711405784689953, 0.0309621601897691, 0.03482382511720061, 0.006732893916445651, 0.07234892528504133, 0.07206651222492967, 0.016477814110528146, 0.01817555452830025, 0.04783887655607291, 0.03897314478776284, 0.02020052185149065, 0.03826559561171702, 0.04506141220086387, 0.02670710949626352, 0.04443695303052664, 0.03681924393666642, 0.005288753417387072, 0.03776922010417495, 0.08543003550065414, 0.012419690394641032, 0.023329533503523896, 0.027691232938585535, 0.0649805845958846, 0.04236477493707623, 0.09255720448813268, 0.022786836106596247, 0.031566687393933535, 0.019330673884334307, 0.04191889600562198, 0.014409702138176985, 0.021860215114429593, 0.03291691440556731, 0.07039600650646857, 0.028469823034746305, 0.09368074991341148, 0.08077787049114704, 0.06012134426938636, 0.008795230283534952, 0.016309944546914527, 0.029462970992816345, 0.02043565798417798, 0.04995017897869859, 0.0778495372672166, 0.05491396119551999, 0.03498866502195597, 0.012958095209406955, 0.09646068074341331, 0.016224147186481526, 0.051505720508950095, 0.05880875898791211, 0.025705705463354076, 0.023212184264723743, 0.028973706532269716, 0.042152247591210265, 0.04105421168995755, 0.05714011924075229, 0.017583938149203147, 0.03367511622075524, 0.0515913651990039, 0.050589759301926406, 0.09427039005926677, 0.09948912502399512, 0.03668422225330557, 0.015737154121909822, 0.03487740224227309, 0.03502294461109808, 0.01861479738727212, 0.03144943654271109, 0.02028891460836998, 0.0034164980336624596, 0.038548510787742477, 0.09048143015908343, 0.04737687902525067, 0.02480054653382727, 0.03934791664193783, 0.017064341476985385, 0.026056363879303848, 0.03884718833225114, 0.03505646763369441, 0.047718782643122334, 0.0517348957114986, 0.12018311316413538, 0.15322322238768848, 0.16404614091983863, 0.1959291443760906, 0.13702314453465597, 0.15303328686526843, 0.13085652329027653, 0.20184016147894518, 0.18452153221837111, 0.12045489358050482, 0.11631071381270885, 0.10045364898230348, 0.06294586163546358, 0.1757286547550133, 0.06799735807414566, 0.14575789868831635, 0.11720395088195801, 0.06397918225931269, 0.1055517607767667, 0.15060189233294555, 0.13948894079242433, 0.11395779864064284, 0.1649788822978735, 0.10682016664317676, 0.07582997956446239, 0.20085036887654237, 0.11225565283426217, 0.16980121710470744, 0.25745149382523125, 0.17490956799260207, 0.17689949407109193, 0.24373379562582287, 0.11284541511642081, 0.10470287275633641, 0.08873406677906003, 0.18869054636784963, 0.14553635700472764, 0.16720203443297318, 0.12162482365965843, 0.0741217133722135, 0.07851882385356085, 0.15966117621532508, 0.15119780892772333, 0.15184522633041653, 0.11693852155336312, 0.10208500323018857, 0.10648600850254297, 0.14869812663112367, 0.06996987294405699, 0.1322069029722895, 0.10132996338818755, 0.17748876102268696, 0.19312553267393792, 0.09417485911399126, 0.1620391836123807, 0.11843878962099552, 0.1320310809782573, 0.1262194692556347, 0.14126006646880082, 0.18926438343312058, 0.06969153109405722, 0.10623132716864347, 0.08092342303799731, 0.15879418488059724, 0.10865942402077572, 0.1039245795192463, 0.11376919983220951, 0.16842133472008364, 0.12318497922803674, 0.13483309133776597, 0.1310288847557136, 0.13376902629222187, 0.09633125697395631, 0.13078235941273825, 0.2304114390696798, 0.1755685204906123, 0.13086686416396073, 0.16452004334756307, 0.19458649999329022, 0.2278661456491266, 0.14408224288906368, 0.09427658508398704, 0.21451310573944024, 0.19414458370634488, 0.1238000847931419, 0.13932678449366773, 0.14244613211069787, 0.14816679299942084, 0.13099882565438747, 0.17665389153574193, 0.1456914429685899, 0.063441850378045, 0.1724841445684433, 0.14332202582487039, 0.12323787781809058, 0.08766225286360298, 0.06178193659122501, 0.09455304739198514, 0.10355283053857939, 0.15219448187521525, 0.10508880311889307, 0.13434618817908422, 0.13888679524617537, 0.10647287884993212, 0.15353365215872014, 0.08876895704971892, 0.09729577414691448, 0.1514753976038524, 0.09129713781710182, 0.12107003985771111, 0.2524279462439673, 0.15548051840492658, 0.0881364131346345, 0.22511083206960134, 0.15780417514698847, 0.12671238423458167, 0.15638212859630585, 0.15589280985295773, 0.0935576908024294, 0.13114016449877194, 0.07996442914009094, 0.11274419126233884, 0.180802549634661, 0.1514626004334007, 0.10153077582695655, 0.14827254946742738, 0.09858565564666476, 0.1320907242063965, 0.10201518197676965, 0.2849979799773012, 0.11641752879534449, 0.1240341386624745, 0.12656535926674092, 0.16157073660620622, 0.10297281201928854, 0.15725931152701378, 0.14495399753962243, 0.13251631494079316, 0.14127378644687788, 0.09844730235636234, 0.09019335133156606, 0.20602737393762383, 0.12853834911116532, 0.16580890704478535, 0.21157865891499178, 0.09443046325551611, 0.13262045649545534, 0.13598717083888395, 0.11026093629854065, 0.08807464609188692, 0.19324002867298468, 0.2441512303692954, 0.22092547879687377, 0.11651005383048739, 0.19866467187447207, 0.1553636882454157, 0.16327635651188238, 0.1632036989820855, 0.06383451180798666, 0.1243957978274141, 0.19772201031446457, 0.06892760244331189, 0.10654872549431664, 0.06887578272393771, 0.06089012444551502, 0.10890867028917585, 0.14121472675885471, 0.12122676787631852, 0.20463658070990018, 0.24597895943692752, 0.1131006528490356, 0.1378841647612197, 0.07220105893377747, 0.11946587450802326, 0.1835733609540122, 0.12088691682687827], [0.0304339715678777, 0.02527057791927031, 0.06471981680286781, 0.019133104842954447, 0.029329839029482434, 0.015252630924805999, 0.03411864063569477, 0.039700127206742764, 0.01448822221053498, 0.014072837490987564, 0.07843008504382201, 0.02583933954260179, 0.01250007898280663, 0.017699943888666372, 0.03585539172802653, 0.04369207764310496, 0.018277385671223913, 0.017988090569685613, 0.022819485515356064, 0.06833844405731984, 0.06281705533287354, 0.060027027901794226, 0.03811914400596704, 0.02902018278837204, 0.03892586107498833, 0.034327812625893524, 0.0667590723772134, 0.014511117678401726, 0.026039805928511277, 0.05930066973503147, 0.039132766758224795, 0.024098800528528433, 0.04395432464246239, 0.02241427288390696, 0.047361764657710276, 0.025564278409417187, 0.03169675577165825, 0.03558944332014237, 0.031819540075957775, 0.030816370155662298, 0.048819237521716526, 0.02803013743167477, 0.02085735053489251, 0.06964036955365113, 0.046301682612725666, 0.02526506482224379, 0.005924824442315314, 0.06796693934925965, 0.005320555929626737, 0.010667791008017957, 0.023709184024482965, 0.05449740176222154, 0.03354605546753321, 0.03203268488869071, 0.024838627615411366, 0.03649324178695679, 0.019463819418368594, 0.023508305428549647, 0.016680087095924785, 0.11350299697369337, 0.04946712989892278, 0.03378105928589191, 0.02297050366178155, 0.00799816707149148, 0.06619200030607836, 0.023635395037542497, 0.0459645999861615, 0.0387532756929951, 0.04878742440736719, 0.04266521327995828, 0.05123097150187407, 0.041518000553229024, 0.0492580257622259, 0.04913886822760105, 0.0346483729247536, 0.08372115184153829, 0.10497499922556536, 0.01086986721825919, 0.04137660064069288, 0.02438876568339765, 0.0300364145077765, 0.026078540100050823, 0.03131037757598928, 0.07481299806386232, 0.0308448346996946, 0.02488162468320557, 0.021211265918931792, 0.03136517606409533, 0.0395894615378763, 0.02524574862660042, 0.053426541188465695, 0.007331805819246385, 0.025584166270813773, 0.03893443436494895, 0.029028057187263454, 0.03627146261611155, 0.047173549221562486, 0.013618445489555597, 0.02002424523899598, 0.061725767462381294, 0.033602187276950905, 0.028378236074266688, 0.042995544483086894, 0.05592501908540726, 0.07448496030909674, 0.020152642724237273, 0.05169033631682396, 0.03345477215147444, 0.02743101306259632, 0.0479750856757164, 0.014821306569501758, 0.050508290994912386, 0.0032209970397941235, 0.05001676022740347, 0.029171475741480078, 0.046721461694687605, 0.03235951824379819, 0.006699372590186873, 0.024110613823203102, 0.0725424231163093, 0.03818525367283395, 0.01541580502609057, 0.027082992451531545, 0.043339015516851626, 0.04382993560284376, 0.018669643372829472, 0.017058363583471094, 0.068455138509827, 0.008087199347625886, 0.07494926825165749, 0.03484772312055741, 0.02077644710828151, 0.008399334786060666, 0.009774416535427528, 0.005432421333223049, 0.018470313533076217, 0.07295877898910216, 0.01162222006158637, 0.05737273461584534, 0.035135815518775156, 0.017362040234729648, 0.025633678971124545, 0.03967910958454013, 0.015787691410098757, 0.09372686993862901, 0.02205082238651812, 0.019906631371538554, 0.006088393366163862, 0.043206039616572, 0.028392464953607748, 0.05494988283940724, 0.021635448693164756, 0.018415847527129308, 0.029564975162169764, 0.058089369375790866, 0.0482944788943444, 0.023538715671747923, 0.0556887430138886, 0.0906771400145122, 0.05438211866255317, 0.027546508204458014, 0.06096819668476071, 0.04471745262188571, 0.04286020728094237, 0.015189153973811438, 0.12100118212401867, 0.05541198215048228, 0.04174336917432291, 0.039852054590093236, 0.003373137949633279, 0.022116747152592455, 0.028986714048577205, 0.0624221818787711, 0.02801886017966483, 0.06746190573487963, 0.01605660162333931, 0.020605047466233373, 0.08406379845525537, 0.04080892128071614, 0.02014805413117366, 0.04775564405801041, 0.035771467124245, 0.023590028186195662, 0.03851844829374126, 0.01100063363888434, 0.0114470969586234, 0.030409693584910462, 0.06001948259238686, 0.010878065617622008, 0.05279049603268504, 0.01104325581608074, 0.02423423951092575, 0.009811260986940136, 0.03369219833984971, 0.03330775736165898, 0.025810096379635588, 0.04621286577145968, 0.023560113273561, 0.05311921910781946, 0.08813913406005927, 0.064945741822677, 0.04418423266283103, 0.032927648829562325, 0.01430021203123033, 0.09993903445346014, 0.013298980176581867, 0.014226913285840834, 0.020100278480510627, 0.029321550724229643, 0.039278108959219286, 0.00937543624812471, 0.04268168471753597, 0.03215379321149417, 0.04104563161464674, 0.018272359423073273, 0.0383261989669076, 0.04339391578521047, 0.06797680524843079, 0.001332326727736342, 0.05774443609906094, 0.03636248469618814, 0.004471387165332479, 0.08269535617104598, 0.033509675812508376, 0.023633362825161645, 0.06666155332433325, 0.033020418137311935, 0.08469603702958141, 0.04300706600770354, 0.037574989455086846, 0.03450998570770025, 0.034631212774131975, 0.0878215321738805, 0.0615208363160491, 0.057797511108219624, 0.06202019059232303, 0.04555545015526669, 0.0017099175768505248, 0.019112065168363706, 0.015800844811435257, 0.057148295587727, 0.03513817682064005, 0.025176164860438024, 0.06013817872319903, 0.01603199794356312, 0.016410106493692313, 0.022483320607404624, 0.014834057938839709, 0.009204826251204525, 0.01954350826729621, 0.053826564723359685, 0.059149363211223056, 0.04758084325918129, 0.036259690033538, 0.027447818678670695, 0.059913583632026396, 0.013024327012577226, 0.016683512001431415, 0.043748806563339064, 0.008208110895273941, 0.0047636792712312725, 0.03703466184171183, 0.023972131611247147, 0.03881873396624412, 0.030071616904543977, 0.03685215288507087, 0.05791269921298538, 0.02328030069890831, 0.04377805820799299, 0.021843691090387956, 0.03742277030167835, 0.04022130995456662, 0.06801430109356131, 0.024463742106620754, 0.026240827016798512, 0.07330955445234265, 0.06555630120315722, 0.030935805889644792, 0.00859497339531247, 0.017256846950788583, 0.029932978629533733, 0.01544118732480066, 0.028333255987880484, 0.028436915782679404, 0.06185444484331778, 0.00918178235380245, 0.052914138683783155, 0.02517655162539865, 0.05103327353884067, 0.006406892190820405, 0.03583226725459099, 0.03715102381205984, 0.041165179306907315, 0.03504464755366955, 0.06293438760829823, 0.05891711424504008, 0.03383590527144926, 0.036807525636894364, 0.07536020941500153, 0.003993112851666021, 0.006309514782125396, 0.02276169299148023, 0.1018025426726256, 0.016469128862289444, 0.03259286982938647, 0.03622051142156124, 0.012009728866230165, 0.00885294986489628, 0.05975196337593453, 0.04587873137955155, 0.03867709995912654, 0.026265400162498866, 0.04345516714134386, 0.022129941266030073, 0.045560634162809165, 0.04562327990840588, 0.04156011722183653, 0.029662463680974076, 0.08213227388582059, 0.013339183376436787, 0.0217483586166054, 0.0544808047956654, 0.04177285830623337, 0.0072033752554229325, 0.055025010236671994, 0.010622361392181898, 0.0849412799413715, 0.03362029059124844, 0.012831572177154678, 0.02826493768952787, 0.03377950883337429, 0.061636479039277346, 0.030439664476684163, 0.01469300577550062, 0.055046821744846444, 0.049123177105294805, 0.028303044216175164, 0.0056567696072826424, 0.03219310753047466, 0.027620750113523433, 0.0620171914675406, 0.051058345407779725, 0.04892243591270276, 0.03586884368477123, 0.023023183424291865, 0.021194389056680456, 0.03961553763864296, 0.029017343119318997, 0.02865238966686385, 0.033357561832027774, 0.029091011666293656, 0.026771607642461146, 0.09264583473226853, 0.13142789048807962, 0.13168257182197912, 0.11838856445891516, 0.0777822673054678, 0.1090683906472155, 0.08669850922056607, 0.09154417206134115, 0.048608009570411274, 0.16275604228888238, 0.14847659851823533, 0.11886975435273987, 0.09098171402833291, 0.14589606198881352, 0.1382280598793711, 0.14694631206137793, 0.1448967427547489, 0.09602308672453676, 0.09492359536566905, 0.11716967129281589, 0.13504045163946493, 0.1557077733533723, 0.16753083893230983, 0.1615190865205867, 0.14159771906478064, 0.08350332174450159, 0.20789516371275696, 0.13647335475044592, 0.14545778264956816, 0.2096376416406461, 0.1075529573219163, 0.15097324097795145, 0.13093957597655909, 0.1636273491063288, 0.11833634440387998, 0.14159049945218222, 0.08827905476625476, 0.11214204571608986, 0.13564647840602057, 0.13046165662152426, 0.12540407372372492, 0.12800214359802858, 0.1593170775366681, 0.178009441654597, 0.12553732443068708, 0.09183013385960034, 0.17601977341941424, 0.1613772184188877, 0.0688771465793252, 0.21067271967019352, 0.08529726655355521, 0.2515893041023186, 0.07180303707718849, 0.12382281571626663, 0.07508530095219612, 0.1138384850429637, 0.15250765292772225, 0.2086877604680402, 0.2425179694380079, 0.17675512896052428, 0.10801289549895696, 0.07816895762724535, 0.10375841986387968, 0.1902790375586067, 0.15285530712987694, 0.13024633031870636, 0.09918836437697921, 0.18117657170764037, 0.10107492243072816, 0.13227230017738684, 0.0804546299789633, 0.1261549134339605, 0.1599270940891334, 0.15599499722676619, 0.06832621007093362, 0.23483445601803915, 0.15027889609336853, 0.17179832208369458, 0.15761736088565417, 0.15796538149671896, 0.15112189442983695, 0.08781011921486684, 0.10238799625741583, 0.09566660478178944, 0.07074665304805551, 0.09721506240644626, 0.10172710993460246, 0.14664809592068195, 0.12872145857129777, 0.13867193034717015, 0.16423433939261095, 0.0862995781270521, 0.13305820657738618, 0.13231464076255048, 0.0652992178552917, 0.19971739181450435, 0.19096213233258041, 0.13649175662015164, 0.08647291668291603, 0.1519325944994177, 0.14013496041297913, 0.08456736643399511, 0.11173529111381088, 0.11061260742800576, 0.12209424775625978, 0.09252337273210287, 0.20396544172295503, 0.1043926261897598, 0.19359526889664785, 0.10818279388227633, 0.18009911238082818, 0.11532653948026043, 0.1494658618633236, 0.11452200050864901, 0.11730851312833172, 0.16590079425701074, 0.1243348518120391, 0.09564544805990798, 0.18239546487373964, 0.11309080730591502, 0.1281263290771416, 0.09715024195611477, 0.15807628126016685, 0.11524293039526258, 0.10618800270770277, 0.06125181075185537, 0.1676175014248916, 0.12275391950138978, 0.19822122209838458, 0.21095197754246847, 0.11157981159963778, 0.12448830929185663, 0.13356166599052294, 0.10288325896752731, 0.16769960416214807, 0.17538294116301195, 0.1323636309908969, 0.12876244208642415, 0.12231593871755259, 0.1319298164120742, 0.12987256608903408, 0.087842872100217, 0.14411975230489457, 0.09016361792704888, 0.12113988825253078, 0.1041260976344347, 0.1476802426789488, 0.14547093265822955, 0.12717305522944244, 0.09467380626925401, 0.2144272710595812, 0.09925317804196052, 0.09874501638114452, 0.1393359447164195, 0.15509756681110176, 0.1257211667086397, 0.10995128684278045, 0.11506097444466182, 0.13472110591828823, 0.1132016120744603, 0.12267347238957882, 0.1325052955320903, 0.11501266275133405, 0.17124247976711818, 0.11901996843516827, 0.2469536614205156, 0.13167330303362437, 0.08351627497800759, 0.07545782346278429, 0.1350679730198213, 0.10814644476132733, 0.08275610541126557, 0.24312362979565347, 0.11255376040935516, 0.12273368558713368, 0.1119350857500519], [0.01652605116500386, 0.019675895538447157, 0.04668203541742904, 0.02686432606008436, 0.03602536475019796, 0.01392140204552561, 0.0047387541354899955, 0.04248294181057385, 0.026353090635633895, 0.03911820878939969, 0.031521469820290804, 0.029033865447023084, 0.03624842295955334, 0.0454323469395084, 0.027472759929618666, 0.0371928656739848, 0.08142866699823312, 0.052272471865372996, 0.015064829395019581, 0.0341156177621867, 0.044068145499165566, 0.08980456433658089, 0.05371891514265111, 0.048142263133610995, 0.013661653751374354, 0.02966959508402007, 0.02389043429866433, 0.059075036485280306, 0.07765487914106675, 0.07185759129268782, 0.04665865310068641, 0.016043712850660086, 0.05571940601138132, 0.0834537208346384, 0.02301002323760518, 0.06625603365578822, 0.04702250732641135, 0.06054865848273039, 0.08275605791381427, 0.061986460616546016, 0.029128578757601123, 0.05227154566507254, 0.03368319757282734, 0.07328334942992244, 0.018555016755791645, 0.05720120096313102, 0.04366396254460726, 0.017805868294090033, 0.01450174710979419, 0.042055434214749506, 0.03292673280728715, 0.02988315380311438, 0.050047969445586205, 0.08853148336389235, 0.046411849558353424, 0.0044519556187359345, 0.012412341860389071, 0.057303761531199725, 0.06760819109955005, 0.019335053827879683, 0.05095118097960949, 0.03496405116415449, 0.07566369098744222, 0.03261089850483196, 0.05233032376106296, 0.062057116468037875, 0.018917956655578952, 0.038386931243751726, 0.007887786387332847, 0.024232349790898815, 0.029545721731015613, 0.04080140989805971, 0.03342927959082382, 0.04968714148604444, 0.0727675813915474, 0.022167109718014087, 0.06412323524377175, 0.07672261273754494, 0.03859637804063303, 0.03343334062291043, 0.03851692498262439, 0.016044912161305547, 0.037723839682127745, 0.013832087329189693, 0.06954365117209298, 0.12447522713669709, 0.028885585189397846, 0.014680101735783475, 0.019689932731645446, 0.04054409584828785, 0.04289445294333356, 0.10056152926491839, 0.022586456233901635, 0.013309773124222244, 0.028893415483513048, 0.013461739523336291, 0.002880574536642858, 0.005376290796058518, 0.036352242210081646, 0.005171567451075784, 0.009977439302019775, 0.020733283799407736, 0.06388556478278977, 0.07477468119135924, 0.017321100824379494, 0.08416872032518898, 0.05177654419094324, 0.008598740961003517, 0.010099341510795057, 0.04767149893034782, 0.06044246775231191, 0.01199886467241283, 0.015185975037249071, 0.020123723561742475, 0.037532296031713486, 0.01793374161102942, 0.02327620574007077, 0.03479036655543106, 0.023344669923452393, 0.03337980420993907, 0.06789796626461403, 0.02710045624657401, 0.03184506656335933, 0.03530363079958728, 0.02169530057082219, 0.04235680215060711, 0.018253943982667158, 0.06147900463214942, 0.12438453414610454, 0.04926349136180111, 0.010546813303205584, 0.021254330840227858, 0.07485443619745118, 0.01543618312903813, 0.06047564811472382, 0.0527906656664397, 0.05747674046350377, 0.057602785128567896, 0.04368910565972328, 0.05085741083270737, 0.011381453784581805, 0.024181539392364875, 0.059750585949846675, 0.026992977995957648, 0.04208493013201015, 0.018576127676559345, 0.03234353535143392, 0.02630243799649179, 0.024027316864313822, 0.043397776649466584, 0.006079460452643356, 0.042310285182403665, 0.03370926010289362, 0.02939701060365353, 0.024359181556584578, 0.07876895900283541, 0.01865779106239123, 0.051923185786498446, 0.06068643501826695, 0.013820131542161107, 0.046881975938699076, 0.011734903523964542, 0.019376315542363694, 0.029912992380559444, 0.03820553508454135, 0.07895477581769228, 0.01437483900891883, 0.019328572122114043, 0.049690713972917626, 0.06362968922725745, 0.013197725788424057, 0.023996273887210658, 0.04173086377392922, 0.056473105746720514, 0.0363432278723589, 0.04992087305124317, 0.03599467121862939, 0.014981523954442568, 0.06406751394804035, 0.018591184368623153, 0.04012697323092392, 0.03435895399057439, 0.03880976712597268, 0.07916755761419024, 0.017301165465531603, 0.017816249879875352, 0.025395762541198304, 0.03825643538896527, 0.012369006373254316, 0.03061376977711916, 0.05778833052941731, 0.046986287127115896, 0.03285550359370453, 0.01602843733105276, 0.06443718661155019, 0.04141871391662529, 0.023016216565987895, 0.02267238081965063, 0.05682201523865972, 0.03685851754354579, 0.050336608064493964, 0.042136305410947116, 0.06549990137240716, 0.04510599534426417, 0.05360010705356087, 0.0876117359314646, 0.046475363828774006, 0.047507853247225285, 0.04252731121544327, 0.043531817849725485, 0.02029097226581403, 0.05962040222116879, 0.020939894319911088, 0.052711402598236284, 0.03183423375178661, 0.09117170383355447, 0.026609120557882955, 0.03522250854543277, 0.014558879758364387, 0.054097636070634635, 0.046142070820289, 0.08256923008177962, 0.04237967895876084, 0.06169906032404729, 0.02236764395742544, 0.02706089595864926, 0.017948214762977192, 0.03331634082964488, 0.040896645680602105, 0.04594807765845742, 0.0035085748116086635, 0.03932247497141361, 0.032021058191146166, 0.06168335223836558, 0.03912306031478303, 0.009245406886163567, 0.05289748743442552, 0.0348058575099068, 0.09656345844268799, 0.026769212413845316, 0.03742749969075833, 0.042205397239220996, 0.00958035552009408, 0.019555179069616964, 0.02754322070229266, 0.03926525411329099, 0.010715603129938245, 0.05710387868540628, 0.06535169575363398, 0.05275271859552179, 0.05920258071273565, 0.011059714531126832, 0.06123473881078618, 0.03199104658727135, 0.041871781926602125, 0.033906425415937386, 0.038207563904247115, 0.06046910025179386, 0.0459320676246924, 0.032522590564829965, 0.05335171913195934, 0.03612738249025174, 0.01838566968217492, 0.03245934770841684, 0.012193020682648888, 0.015422196825966239, 0.025341084493058066, 0.042656690880124054, 0.03364163051758494, 0.02669239546438413, 0.02352567931770214, 0.014011592072035586, 0.026961410850552574, 0.08077618772430079, 0.05297323569123234, 0.062351722802434645, 0.0425956227284457, 0.01672209519892931, 0.09198381525597402, 0.01726073326010789, 0.00969275484593319, 0.06768346777451889, 0.035826991644821, 0.021950889445309128, 0.0030733919245124397, 0.006666390699267919, 0.02666355263707893, 0.023182031864832555, 0.01926327669726951, 0.033484702331147025, 0.021737211982586553, 0.10771817381360702, 0.06292972607272011, 0.05370059469714761, 0.05132930140410151, 0.03715951567781823, 0.044071775661515336, 0.01605049311183393, 0.02725886703202767, 0.05490772206602352, 0.015167474779965622, 0.019066832327683057, 0.030431179396275963, 0.038020485014255555, 0.04063424601086548, 0.03490825183689594, 0.04675201273390225, 0.03664860934285181, 0.03982639918103814, 0.02216215132336531, 0.02220994054472872, 0.02038987722646977, 0.0625563757494092, 0.07156312066529479, 0.02362350031866559, 0.021482210040890744, 0.05371640117040702, 0.040452378269817145, 0.08461634309164115, 0.0202975896785834, 0.0913625078807984, 0.014918717056778925, 0.003578794704351042, 0.025967757383893644, 0.07307783474347421, 0.053820820924426825, 0.00982796143008662, 0.049025878576295714, 0.050368617953998704, 0.015524431697225996, 0.03527068453175681, 0.06162182268287454, 0.07817437912204436, 0.028035170465175594, 0.03847592111144747, 0.03349939939965095, 0.0727070357118334, 0.06964537714208875, 0.02370519084589822, 0.11184879645173039, 0.010977515950798988, 0.06401725485920906, 0.007836829255601125, 0.018444461348865713, 0.06397302794669356, 0.025402398613680686, 0.015106023256001728, 0.022145113309047053, 0.040573907284332175, 0.02079683030024171, 0.03598531422072223, 0.032109864854386876, 0.11783595196902752, 0.09672558081469365, 0.13390359335712024, 0.1456108330083745, 0.15955360127346857, 0.08450468336897236, 0.14221351673560484, 0.10489329003861972, 0.1740588614983218, 0.14972571363406523, 0.16465022707624094, 0.09710315841117076, 0.12939706231866563, 0.16198629859302724, 0.094278912459101, 0.09730934484728745, 0.14582896844616958, 0.06544704349445445, 0.09322641643562488, 0.14037018136254378, 0.11778192701084272, 0.1332599078970296, 0.13099532441369124, 0.1362308327640806, 0.15841525021408284, 0.12575160578957625, 0.18787703716329165, 0.13987008748309954, 0.11499379947781563, 0.11598564125597477, 0.13401575519570283, 0.12455334008804389, 0.2291890446628843, 0.12871722451278142, 0.11186373779284102, 0.19090266552354607, 0.12240726953106267, 0.19846269914082118, 0.13435156217643193, 0.12565742512898787, 0.18338068415011677, 0.09273921472153493, 0.06551307852246932, 0.1465654774968113, 0.1402037095810686, 0.16480851572539124, 0.12298515066504478, 0.10904199563499008, 0.11295754302825246, 0.1218030069555555, 0.20392798658992561, 0.1591361936713968, 0.06941715867391654, 0.10678763088903256, 0.11705772658543927, 0.18192240382943833, 0.14742815334882053, 0.1475948422615017, 0.08008773930902992, 0.18983678200415202, 0.064346615757261, 0.12191123329102993, 0.2614961325057915, 0.1120637631309884, 0.1377322950533458, 0.12559976322310312, 0.09600699187389442, 0.11389951248254095, 0.11687882404242243, 0.17541225387581758, 0.0998013054153749, 0.14931407357965196, 0.1260706800967455, 0.17003979001726421, 0.16467265944395745, 0.09181072775806699, 0.1293694730848074, 0.132685975836856, 0.06690993106790952, 0.0913267151585647, 0.0634396994220359, 0.11186573947114603, 0.2305911151426179, 0.13012029922434262, 0.16256761311420373, 0.15102214978209563, 0.09772546323282377, 0.09307841437735728, 0.08884305307375533, 0.21118528502328054, 0.10519525847796883, 0.17224825865456037, 0.15752655932945864, 0.09515711997768708, 0.12426588551274367, 0.07881119102239609, 0.10759706888347864, 0.13933179208210536, 0.1627714586045061, 0.104705695462014, 0.08653375413268805, 0.09926987000341926, 0.14829158916005067, 0.176200019461768, 0.1697196029126644, 0.14780095405876637, 0.23533100794468606, 0.11694542903985296, 0.06755788451326744, 0.10257324310285704, 0.15268811610128197, 0.2145511308418853, 0.09135837560253483, 0.1289730050734111, 0.16605570380176815, 0.29673058326755253, 0.13316981201725347, 0.16560187243989535, 0.17601323234183447, 0.11822049133479595, 0.15164808476609842, 0.08603951601045472, 0.10235398808228117, 0.06908086314797401, 0.0837642727419734, 0.145757776552013, 0.13460533427340643, 0.1723663237478052, 0.15764480084180832, 0.1591458288686616, 0.11198934141014304, 0.0791421193363411, 0.09882373322865792, 0.08244407429758992, 0.14488537050783634, 0.24673007056117058, 0.12718631380370685, 0.1972378348665578, 0.12092050431030137, 0.12649274244904518, 0.15063959173858166, 0.13980103975960187, 0.2292559210743223, 0.08082855027168989, 0.18851594573685101, 0.12352086763296809, 0.07660262739019734, 0.09340784991426127, 0.19225801208189555, 0.1350475355450596, 0.11661179337118353, 0.125015042456133, 0.12257182784378529, 0.10094646896634783, 0.16360425177429402, 0.2015557060284274, 0.32725344970822334, 0.08257179494415011, 0.14798084726291044, 0.08202024096889154, 0.15156352573207446, 0.14047874696552753, 0.10977327318063804, 0.2208649127611092, 0.12018921997930322, 0.1421263249857085, 0.08623709862253495, 0.10322837544871227, 0.16337387556476252, 0.09443778464836733, 0.07460217044821807, 0.16041379368730954, 0.08038829639554024, 0.16633869361664566, 0.15512865728565625, 0.18331896460482053], [0.02785105168420289, 0.04427134638120021, 0.07720160417790924, 0.02689064812979528, 0.013879025837273469, 0.027903492263119136, 0.046174735496086736, 0.02704562892072967, 0.05564706400036812, 0.05871984375906842, 0.04715988352628691, 0.07567245087453298, 0.03294971818104386, 0.03585245706407087, 0.04370671025078211, 0.03308006475812622, 0.014348082676795977, 0.041263597418687174, 0.04381752859002777, 0.05051011625411255, 0.024844507121347954, 0.064768325271351, 0.02924710525465863, 0.048245702404528856, 0.032521952741912434, 0.04793554065482957, 0.03452734602615237, 0.01948902869064893, 0.05187498605144875, 0.025531634089670012, 0.04037630092352629, 0.0191733674146235, 0.02496246195265225, 0.04257345838206155, 0.052634348161518574, 0.06468188669532537, 0.028020380098106604, 0.005859364472728754, 0.09593994582870177, 0.016594883453633105, 0.013440291031396814, 0.07381740398705006, 0.01052649033122829, 0.04221286790977631, 0.012737181170710495, 0.01931641955993005, 0.011064145364798605, 0.049427513631858995, 0.048368568133030615, 0.023098424476172243, 0.04935283406770655, 0.036306868573384624, 0.01044985234537827, 0.015188539899619562, 0.013026420293109757, 0.030692751253289834, 0.005934388393403164, 0.042551741868789704, 0.05801074752318008, 0.01145443955569395, 0.02592460425304515, 0.014782601235700505, 0.032616710157266686, 0.0315327674283513, 0.0393132435024849, 0.03630737068929842, 0.0069745732471346855, 0.07652249240449496, 0.02733853891757982, 0.01648024496223245, 0.01226438136239137, 0.012513015252937163, 0.04529460093804768, 0.01606452521601958, 0.022372575210673467, 0.019437175044523816, 0.019528492287333523, 0.030689840338059833, 0.031524333238069496, 0.032148900974009714, 0.044576687139592, 0.03589630399697593, 0.0564450992138258, 0.03251576450254236, 0.011827573595967675, 0.05470155259328229, 0.009808512920114611, 0.016722492141915218, 0.021009269436555247, 0.01576867885887623, 0.01362466426300151, 0.011484388395079544, 0.06670903041958809, 0.025940236003537263, 0.02906122397897499, 0.03361126268282533, 0.01663905269067202, 0.0098275076597929, 0.04618015020553555, 0.020903509575873613, 0.06590972295297043, 0.0815122150150793, 0.02673705155029893, 0.03651089048279183, 0.03874232753046921, 0.05332235213635223, 0.03712430310302547, 0.013899168997470821, 0.02652036987378129, 0.029766232041375976, 0.028971005962895494, 0.08652158799980368, 0.014115746349229344, 0.013337343698367476, 0.016168588739154593, 0.048218893485942056, 0.04578996542841196, 0.021620904295040027, 0.023086879202829938, 0.035717900177197795, 0.016165645593511205, 0.03940442843096597, 0.05385990793417607, 0.013831524993292987, 0.012644388962404003, 0.07759286782571248, 0.011659866880758532, 0.025034449429118207, 0.025836494784536104, 0.06945761293172836, 0.024687005572819283, 0.04604847709249173, 0.06450266524084977, 0.04696424152436001, 0.02113659314012953, 0.018270140613562295, 0.040370662297521315, 0.053846656145261865, 0.0836814846843481, 0.06745950372091361, 0.07670716249517032, 0.03245967001255069, 0.02152519523432212, 0.01771902259705322, 0.03423234274876969, 0.06838129354374749, 0.06135646799313171, 0.09829453698226384, 0.04032197740993329, 0.011481698851899376, 0.026768917251112204, 0.0160414465436978, 0.029910773571048464, 0.006353044923993626, 0.027702143781685402, 0.025024441037593142, 0.03600729536265135, 0.02592362546628075, 0.04874436118240867, 0.022604364469381313, 0.03040196167837296, 0.0554978168303413, 0.06819861156067678, 0.018127763610599295, 0.014118957516205097, 0.03500970978555935, 0.04385711432301572, 0.06333141201840979, 0.01658272240976138, 0.05297298124060035, 0.05173771841717618, 0.04340757469513586, 0.05256833688222936, 0.01784334547950753, 0.0710925091324108, 0.05997149659586804, 0.04400117409282497, 0.07158412132412195, 0.05442130745255521, 0.016080201071287905, 0.013425632978656461, 0.022962844697758555, 0.027085508120113184, 0.011862772600060063, 0.09231312187122447, 0.040633492836994786, 0.026205985939928463, 0.11231237836182117, 0.03308983566239476, 0.02987235491829259, 0.09352898198579039, 0.048112461875591955, 0.026347234878422957, 0.06640018163514988, 0.01067162981988596, 0.05130123380305512, 0.022114704762186323, 0.04992492051262941, 0.02589953238410609, 0.01434336176940373, 0.03350590994315488, 0.01128637491326247, 0.024549622587593536, 0.06562365937445845, 0.03412187724773373, 0.04248401728857841, 0.009865644720516034, 0.01154799766040274, 0.05563767307571002, 0.043558982999197075, 0.030710939384464706, 0.002977911869363327, 0.04012828280350991, 0.015187272735472237, 0.04453379354838814, 0.02582422687139894, 0.01552987185173801, 0.04828434497384088, 0.05540839948558381, 0.07060639985970088, 0.022353228480954255, 0.024517795902543833, 0.03512316084067736, 0.040548200985150676, 0.07928833006215946, 0.03590014450518148, 0.03486737349469747, 0.029884500695126395, 0.013377766573934682, 0.019219139690643976, 0.04734553410006421, 0.03276759259668844, 0.02904029456632478, 0.02158241269976965, 0.041126750476126156, 0.03997296613774129, 0.029686409181782177, 0.016135206512574638, 0.01437561253884009, 0.02886864895533238, 0.13426503539085388, 0.06738399634403841, 0.047889563121965954, 0.0910941269248724, 0.059548022890729566, 0.025327279698103666, 0.010680870618671179, 0.04558288332607065, 0.030886174445705752, 0.06416077858635358, 0.02514782584538417, 0.019496209287483777, 0.07383805180766753, 0.08247403161866323, 0.030155792566282407, 0.05398501282823937, 0.04225979878434113, 0.019975458571155156, 0.012132635306833046, 0.050741645973175764, 0.07279054301657847, 0.042391088525099416, 0.036920386366546154, 0.03217856652502503, 0.03237136885789888, 0.0536816703554775, 0.013997213914990425, 0.004459198980060006, 0.03409639147243329, 0.03898435757894601, 0.06585305170821291, 0.04386620669226561, 0.0414219267799386, 0.05439599470368453, 0.03926733382312315, 0.023518536040293317, 0.04292454597141061, 0.0770360484187092, 0.03701808523120625, 0.02302021313724773, 0.05459801832746182, 0.05472550827211567, 0.018855412690235034, 0.03873053119917001, 0.020155243209696243, 0.06326302247388021, 0.022686424798199108, 0.07340304979256221, 0.024502908844234686, 0.02670143524717007, 0.006236160481681249, 0.036492322372006517, 0.03194842101739986, 0.039031179887907844, 0.043968828328486, 0.04587526745828135, 0.031621896395725865, 0.010065429178731782, 0.040603219997137785, 0.058179519538368495, 0.06002525692539556, 0.0405400551722518, 0.026060053413467746, 0.06918931340000459, 0.05945008993148804, 0.027050349828121916, 0.06991751039666788, 0.02313423585811896, 0.04002382912273918, 0.11323174581463848, 0.013721114623227289, 0.018040799169934223, 0.02363516772831125, 0.10993548376219613, 0.03226896435288446, 0.007908056772846197, 0.04286011567871485, 0.0038267216462242815, 0.01411030873922365, 0.05014342235933457, 0.02867531736514398, 0.009574372537567146, 0.02954484981351665, 0.022751079007451023, 0.023885945789515972, 0.041805875820240805, 0.023550411919131875, 0.01469490397721529, 0.013920093321108391, 0.00967650138773024, 0.027339646625997763, 0.01989344065077603, 0.04819958916466151, 0.021222302291010107, 0.04516451220427241, 0.020134781986208897, 0.05275444885981934, 0.07227633560874633, 0.02347004962419825, 0.076311020180583, 0.017424032890370915, 0.04165379237383604, 0.03699788185102599, 0.10850758145430259, 0.026001899569694484, 0.10683219706905739, 0.020165056522403444, 0.03352192336959498, 0.03855787796367492, 0.014007676924977983, 0.058047408770237646, 0.05043168778398207, 0.08714869006403855, 0.12402481559131827, 0.15800191382212297, 0.10739054996520281, 0.11415347456932068, 0.11495543510786124, 0.10552029710795198, 0.13671009561845235, 0.1374916729650327, 0.08713047139878784, 0.16090555515672478, 0.2208796234003135, 0.13257446539189133, 0.13542153047663824, 0.1736165788024664, 0.20270355657807418, 0.08594313011105571, 0.08190651849976607, 0.10928030391888958, 0.09504666126200131, 0.09148914287132875, 0.16110389094267571, 0.11172030227524893, 0.12077898904681206, 0.10062639721270118, 0.16412259824573994, 0.16880031009869917, 0.08324290000434433, 0.09551272661026035, 0.10442486338849578, 0.1955209919916732, 0.09943279304674693, 0.16993830831987516, 0.11986976569252354, 0.12598177843860217, 0.08486565042819295, 0.16495003098888056, 0.08434463052877358, 0.1500483298940318, 0.1181767393967935, 0.05941097238766296, 0.1182455699890852, 0.12774905003607273, 0.15260503627359867, 0.13842893338629178, 0.11282039074493305, 0.09743702478174653, 0.19843745763812745, 0.21617034609828675, 0.20165014453232288, 0.13992500810750894, 0.08467519243380853, 0.08761357476136514, 0.08129245109323945, 0.1195332801767758, 0.1376770758735282, 0.10933740264070885, 0.08315882951553379, 0.12974547648004123, 0.10855921118387155, 0.10143101760851485, 0.09248878101685218, 0.13046844197171076, 0.05128356475116951, 0.215308633766004, 0.1589321717619896, 0.108956886987601, 0.21561128752572195, 0.1648427274610315, 0.06688675231167249, 0.09329476526805333, 0.14803008176386356, 0.10863470499004636, 0.10946388156818491, 0.10400065008018698, 0.09987270087003708, 0.1367266790143081, 0.11620854000960078, 0.15841121971607208, 0.1027743269556335, 0.1526134636785303, 0.10444743146321603, 0.08752104294087205, 0.11884083519024508, 0.10150708138410534, 0.10898096819541284, 0.0763009846476572, 0.10478289239108562, 0.117360991026674, 0.16827425546944141, 0.16709774360060692, 0.053491117366190465, 0.15489281208387443, 0.12402759758489472, 0.08952390189681735, 0.07806136232933827, 0.14102719325040067, 0.11458794054176126, 0.14344684912690095, 0.1584587443087782, 0.16511259440864834, 0.2724860113646303, 0.09138559164213282, 0.1222807906035866, 0.1028214715687292, 0.18941409539963516, 0.09667657701564686, 0.14649161217468126, 0.10121324857962982, 0.10613559266286236, 0.15897420022104466, 0.1420982607773372, 0.08155722224286624, 0.1303925003324236, 0.0864614833678518, 0.12724803334900311, 0.15996145510247775, 0.10099689090358359, 0.148169127159885, 0.1229157093912363, 0.09915561149162905, 0.11783114794109549, 0.14285298170787947, 0.14755814708769321, 0.15051483629005297, 0.11170496059847729, 0.12027643887060029, 0.17868480112935814, 0.102148548034685, 0.18925857517336095, 0.119394112644451, 0.1403952735875334, 0.16689590657395975, 0.1957873169864927, 0.08418705434139286, 0.152819941884705, 0.0889858507684299, 0.13956317252346448, 0.1311530295227255, 0.20190159603953362, 0.1113977131566831, 0.09374049492180347, 0.08525112617228713, 0.15150363823132856, 0.07166250568947621, 0.15890929156116076, 0.20557720666485174, 0.11096452283007757, 0.15831690334847995, 0.12549239184175218, 0.13175430654415063, 0.13655973225831985, 0.09388620353170804, 0.09328612073191575, 0.08111865113356284, 0.08472813173596348, 0.11188876216432878, 0.10600566677749157, 0.1251122358122042, 0.1566258855164051, 0.1495288299130542, 0.09988764221114771, 0.16226628928312234, 0.11869115036513124, 0.061548574827611446, 0.12122651003301144, 0.18214991662119115, 0.1853306173746075, 0.09979648781674248, 0.17170500994793006, 0.09706609004310199, 0.08099688123911619, 0.14222742670348712, 0.09081473334559373, 0.16043298265763692, 0.17423418137644017], [0.033351896064622064, 0.023407619313469956, 0.05443885776081255, 0.02013706525654665, 0.052302218840590546, 0.0339537091287119, 0.03703584588531937, 0.10409831841077123, 0.035480165255389044, 0.062311506031879356, 0.031685084969337494, 0.04530877892726234, 0.06689887773245573, 0.023585388703005652, 0.03441559809393116, 0.03155113197863102, 0.04545666902725186, 0.0416378976910242, 0.06251598934509925, 0.0670402640742915, 0.05687458473922951, 0.02678914607635566, 0.02874470774882606, 0.04311503789254597, 0.033402144975428066, 0.045284999667533805, 0.042430728540888855, 0.08605609940631048, 0.0067715263077323985, 0.03779358968936971, 0.03794181227151837, 0.005425988821246262, 0.04174478731251188, 0.010840320410872144, 0.023025904349716644, 0.010849661293572612, 0.008042008067215127, 0.014805874986840146, 0.02921140074197735, 0.03925055025943688, 0.022450135155980076, 0.06512347728546176, 0.09234111144074372, 0.09296933308775936, 0.02542762315299894, 0.011831423434029733, 0.027727795798065405, 0.033013921164508374, 0.04540158894711307, 0.04089430134211268, 0.029192703709538494, 0.028476048593542407, 0.05613551421889237, 0.02405475851680551, 0.03548889121572886, 0.018661989497819116, 0.030732411625129834, 0.03740145412406751, 0.055521809828600714, 0.041019738718335114, 0.0778903579339385, 0.015008378674143126, 0.02882502254630838, 0.03231009375303984, 0.030124990469110862, 0.025481274916923473, 0.008182023768313229, 0.11872260724859578, 0.05233770961474095, 0.041444929117070775, 0.028313956755612577, 0.054542788969618936, 0.022842964523338845, 0.030492261118654693, 0.007681439647317997, 0.04146309689219509, 0.05533655619780932, 0.02694126175317381, 0.04011469174708639, 0.02460642614667969, 0.10354944464883634, 0.006306217950103539, 0.0903834971998419, 0.03654923788937075, 0.02854551361607654, 0.01564206592073398, 0.006803835600814117, 0.029403751849063804, 0.07546879537403584, 0.014894400058048112, 0.04055477259680629, 0.03304075722449592, 0.04109178217394011, 0.02645658758202834, 0.040942385726209195, 0.04246443137526512, 0.023684025642329028, 0.09298574684986047, 0.030327858868986368, 0.043359259609133005, 0.006590474929128374, 0.022713193004684787, 0.02157179532306535, 0.036533329635858536, 0.020467257359996438, 0.0335797990140106, 0.012005049519107809, 0.02719064542491521, 0.0278837553757642, 0.11815742829016276, 0.04570608492940664, 0.023822953991059746, 0.05716525896319321, 0.04304552197988544, 0.04798163014597126, 0.03888501665954079, 0.01872114248440734, 0.02249010426125356, 0.037549710632967095, 0.03423366589205606, 0.006444770560067679, 0.005086984244241778, 0.056824176372694116, 0.028035794717392752, 0.03566817034568105, 0.07171971297689847, 0.015962373465299606, 0.04519476129540375, 0.044723993699465475, 0.017704281423773085, 0.0071254650164129475, 0.06870498867439372, 0.054800761198358874, 0.057153635658323765, 0.02716210963470595, 0.058844931689756255, 0.004465207407650138, 0.022011336737445424, 0.08269877598753997, 0.030300598724612167, 0.1168607207281249, 0.06635294881250177, 0.0359212198028607, 0.026176578232220242, 0.022115240804851055, 0.004685367848391512, 0.04992901547146695, 0.021125582213114415, 0.04091078295771565, 0.0019443098655236618, 0.03443638501422746, 0.048253407169665606, 0.03891020387943302, 0.04329669189506343, 0.0728731614404491, 0.02067529789305159, 0.036997722395296605, 0.06339358618216855, 0.028907959881637777, 0.006119611914203103, 0.021695415921775357, 0.03568266724635448, 0.0543963136151433, 0.04355104753215398, 0.07254696930093424, 0.041228242351540496, 0.04742521446730409, 0.0338368857545512, 0.013049861981666513, 0.03934394381940365, 0.004094469020076628, 0.032844436687550375, 0.031066674938691512, 0.041467154531606605, 0.09802448004484177, 0.014832478648583804, 0.014381140902904528, 0.04759292118251324, 0.03288187146452921, 0.019080920411007743, 0.011328243068419397, 0.031768934934266975, 0.018373703717121055, 0.013898562556797904, 0.04565391915717295, 0.03240885791767921, 0.03503224393352866, 0.027927839795925787, 0.09689338252480541, 0.023884880489536693, 0.0574411309457251, 0.03322313047413315, 0.022516093848805343, 0.036158408503979445, 0.02289688939760838, 0.036713273730129004, 0.031375364267400334, 0.005531195251803313, 0.036127413024327586, 0.012418396937261735, 0.033771580151681385, 0.012586532825870174, 0.09984997673226254, 0.05150956780250583, 0.016690604388713837, 0.052251949573733976, 0.04814384751287954, 0.020688965284664716, 0.01795460656285286, 0.06732425812099661, 0.01445142356013613, 0.014535546635410615, 0.04694348174546446, 0.02320786708566759, 0.05262151027896574, 0.055238521458314996, 0.020038916862436702, 0.043034977545695643, 0.12620733704950127, 0.04646121298096009, 0.019896653514089327, 0.03681905733953629, 0.03423535544425249, 0.03437410567754081, 0.03815932006442121, 0.06264854794634239, 0.025267663611365215, 0.006952137062658689, 0.059142998552748134, 0.048579609487205744, 0.05843898454414947, 0.03890937945938536, 0.026717402872496417, 0.03437555095713053, 0.0551254605608327, 0.04539218784442969, 0.05241422122344375, 0.003591393827394183, 0.007568958897276649, 0.03627665001632912, 0.06567547909383263, 0.02596903981507889, 0.056621250297342024, 0.06548882768090282, 0.0300324484705925, 0.016417190399287, 0.02168349066882261, 0.02797559678687581, 0.02174377002354179, 0.028595898233886276, 0.03282816881047828, 0.07625158051294939, 0.035854221255119355, 0.012624233927843826, 0.010826041489573461, 0.048779950344136784, 0.03738661117053457, 0.015212115598842502, 0.0662329431091036, 0.0018986964091059885, 0.050193813762494495, 0.06363319725330387, 0.03543159232607909, 0.03409947541409305, 0.06349017564207315, 0.018029817080657397, 0.027739469993061254, 0.03141014597245625, 0.04864528489166072, 0.010471199905233724, 0.09561262732105595, 0.01313401389467929, 0.03603321879303881, 0.005971002991178206, 0.05818113445171288, 0.07427498086222581, 0.056653972648616345, 0.03593510602201734, 0.03936097504837172, 0.052018160333058665, 0.01654775919658797, 0.014400779402681758, 0.057432153927428384, 0.018185069285599247, 0.05418317898043564, 0.028372032567858696, 0.06291787885129452, 0.03249216844726886, 0.023547083704865406, 0.011442163160869052, 0.03218015429696866, 0.03707772845934544, 0.06958443791206394, 0.035695399955979416, 0.04948452414412584, 0.05301813096074121, 0.014341027608939579, 0.014232665566461427, 0.06367672527475016, 0.017892389990655438, 0.04464690872867193, 0.02686900964805058, 0.036403403750487735, 0.02762775938026607, 0.006451768376531878, 0.030066840018012693, 0.018990997557661364, 0.02567393475744341, 0.038389458786696196, 0.018783744125227844, 0.030645440399114574, 0.013654407845543963, 0.031309044254677634, 0.019815697501014386, 0.060124791227281094, 0.034935491625219584, 0.06115832219698599, 0.05822177869932992, 0.027212546838979636, 0.03484257982511606, 0.03949824946799448, 0.009348894502701504, 0.03140740129830582, 0.05257608235946723, 0.020140566497242877, 0.030569037356014763, 0.056827786178993325, 0.03139485179313591, 0.038490669070077796, 0.022314251733145544, 0.01526559263999973, 0.00937267461059881, 0.031306710094213486, 0.03965289777676974, 0.020959595584177544, 0.04113667744344898, 0.043306930988494835, 0.049135787678616386, 0.010631036462395318, 0.0652788414486817, 0.05245192402175494, 0.025042493461764286, 0.026279578151713525, 0.008523641553308283, 0.024274581810459495, 0.02078468113073281, 0.040040833210306506, 0.00813686556648463, 0.005526182574353048, 0.04705940266805036, 0.04021192242258361, 0.013259159500843712, 0.0887647501326033, 0.12057111305849892, 0.10819981832589422, 0.11560568878693239, 0.12612747347780637, 0.0903644235804677, 0.10902187707168715, 0.1907302633460079, 0.16875255480408669, 0.23667163029313087, 0.08196570032409259, 0.0990291257788028, 0.22225726661937578, 0.12324417462306363, 0.152644635577287, 0.12589492595621518, 0.14924012683331966, 0.15596986428967544, 0.10039762913116387, 0.17922570210482391, 0.14918486694140093, 0.06473424924271447, 0.09825703435178314, 0.1075203265728695, 0.09397610263632876, 0.09122481955481426, 0.1711372389857258, 0.1826476084866694, 0.21424129818167004, 0.172406669440014, 0.1545410459595067, 0.09413917495736054, 0.0964971384299653, 0.10792654513248376, 0.11695437213139874, 0.15694911245788845, 0.100201769998031, 0.12300800372447286, 0.10564869628953082, 0.10994693064796073, 0.13935787496822222, 0.16392905291702065, 0.2780372420591967, 0.2321595081261226, 0.14109728591782705, 0.09344935590135199, 0.1466490322990077, 0.20074425957032613, 0.14783302162374767, 0.1552072859236172, 0.1266511260930981, 0.08689822921795504, 0.18990885599383286, 0.1312763871891158, 0.10321755960051503, 0.08833108483148472, 0.1299394289297717, 0.15474561069692883, 0.22018654059086526, 0.14305369236639567, 0.11825568016086306, 0.14732713305524417, 0.08651888743042946, 0.09001701365091971, 0.15537059573190554, 0.1054204846067088, 0.10112874382840735, 0.16982320163931164, 0.10305738462401287, 0.16507375506418093, 0.13099497157548154, 0.12227707223168441, 0.11904955256198134, 0.14418402314186096, 0.11500453390181065, 0.15203026283000196, 0.151316050440073, 0.2038820226277624, 0.07289653018649135, 0.12446175143122673, 0.19313956477812358, 0.12056025649820055, 0.14184816634016378, 0.10055697629494326, 0.12601151184311934, 0.11379473310496126, 0.09413187392055988, 0.08326155293200697, 0.15455252677202225, 0.08470124139317445, 0.14078879675694875, 0.10597082400428397, 0.11056569351681642, 0.08758559876254626, 0.22001575332667145, 0.1632735745183059, 0.1748860635395561, 0.13749862116362366, 0.19784042824591908, 0.18254946518157208, 0.14648859947919846, 0.13547369624887193, 0.13228874786623887, 0.12990837916731834, 0.09859585402799503, 0.10376399742173296, 0.14444836681442602, 0.09373489022254944, 0.1740250161715916, 0.17293611674436501, 0.16286044168685163, 0.14353575078504427, 0.1015739713662437, 0.10267327952065639, 0.19546786269971303, 0.09830932226032019, 0.11341206649584429, 0.13492450357547828, 0.12113303504884243, 0.12375781206148011, 0.09386138272072587, 0.07237323719475951, 0.12323695501046521, 0.0788871937298349, 0.10389610140451364, 0.1288965070354087, 0.05873604038996356, 0.10822398095790829, 0.08277229525681053, 0.06423904081540448, 0.06700249002980334, 0.2040650506636926, 0.1261262928268739, 0.18117841732289108, 0.12847125556852135, 0.14609067940286227, 0.2073922742690359, 0.1163311241460698, 0.12942683643528394, 0.17427287144320353, 0.30257846947227207, 0.101058942931039, 0.1343104972371033, 0.10080712501491819, 0.14133173333747046, 0.07249400285737854, 0.13398397261542933, 0.1699241812207869, 0.09091582827802215, 0.12497409965310778, 0.13319219010216848, 0.11927944022629942, 0.16874959639140538, 0.11251646812473025, 0.20873543433845043, 0.09396371258688824, 0.14014589839747973, 0.11421074292489461, 0.1216515443686928, 0.14147877187601157, 0.14344184153846332, 0.09889147137956959, 0.10663278241242681, 0.16134771571627685, 0.2774041960281985, 0.08597061077931098, 0.17395587345319136, 0.09071450693798916, 0.1482924712555749, 0.08465077874383756, 0.08538690102951867, 0.13102934615952627, 0.056837943848222494, 0.12071503033595425, 0.2540965995618275, 0.0884926033073238], [0.07992182392627001, 0.01800599371615265, 0.03321011277980038, 0.04673112742602825, 0.015392175044066139, 0.015510511551318424, 0.029217999495033706, 0.030360608361661434, 0.02591671289077827, 0.05260871650118913, 0.04539368401414581, 0.031734081983034096, 0.01460986996867827, 0.004572927810451282, 0.019908712777708257, 0.02749605064413377, 0.03161481588280626, 0.02215986805302756, 0.005413203949241766, 0.04997928813099861, 0.03252379835716315, 0.06189255815531526, 0.008442853477650454, 0.026837881854070083, 0.03555205604061484, 0.052088744938373566, 0.06463926112545387, 0.0784036832462464, 0.006643865032986338, 0.06351944085742746, 0.026023607601278594, 0.015404417512140103, 0.05539170413144997, 0.05368114109816296, 0.018704167234578302, 0.012379712807679815, 0.02095271523908845, 0.02224618788542492, 0.025355267571285367, 0.04347520428044455, 0.017258860503456423, 0.09486674770180668, 0.0913812897301146, 0.03450136831296342, 0.040969099649893384, 0.06748357135802507, 0.043419004617525, 0.03726252407899924, 0.05043765210679599, 0.011362927234066384, 0.024562692868390253, 0.018691022314929535, 0.03332188446074724, 0.009379769542387553, 0.039895847240196805, 0.03614026787025588, 0.02359060324462397, 0.06758499198726245, 0.031348518029387505, 0.05444284076137202, 0.04327058865289603, 0.03889338978167091, 0.048840339960796494, 0.08452893421053886, 0.03685477203024285, 0.018898642156273127, 0.05206247545512659, 0.03032055443951062, 0.05715057546538966, 0.03644292162997382, 0.03530911336253796, 0.03322823305747338, 0.054305627409900935, 0.03905783613611545, 0.024516038496845534, 0.03820392695654716, 0.043985086027532816, 0.011077237697983426, 0.03503265105453985, 0.050275214216006656, 0.042895820191396136, 0.01822183231290962, 0.013770288904197514, 0.023960280997146453, 0.03249664677839194, 0.09647043807698147, 0.010998932212325079, 0.04866760530109916, 0.022074359069977487, 0.05902410564678056, 0.02333988285889583, 0.02238750467742128, 0.05918117293289729, 0.05048028785469277, 0.01430165222180741, 0.03171325095796159, 0.011392823486988033, 0.10073508495198828, 0.017499016098944203, 0.023507516631590467, 0.05814253937985216, 0.044837173340576034, 0.02695962121444089, 0.017594757390075495, 0.07770637994898216, 0.07504133866833788, 0.04118295353172081, 0.032599583933396, 0.11016592103987932, 0.028372478704633455, 0.040867204046142955, 0.043444470036774874, 0.024695158171068345, 0.039088821437742026, 0.01970432615572853, 0.01389541500248015, 0.022712726511859467, 0.03053840828527297, 0.06955710652151278, 0.047183554220412455, 0.06258786655962467, 0.041670396125742366, 0.0384295194941972, 0.008994242059998214, 0.02186323798793767, 0.057417897906686576, 0.0380449631650533, 0.051038070781422515, 0.03204873224188175, 0.019960756413638592, 0.01463704529617514, 0.017730396540303315, 0.026425005169585347, 0.038533040189317296, 0.014360906988648432, 0.01434472732112876, 0.02009455843030342, 0.04986932135320135, 0.07374191018087523, 0.04639910327802811, 0.08597830536642245, 0.022573786288765923, 0.042303214847509346, 0.016512502517019, 0.05679139634594321, 0.030906235333532095, 0.05872399639338255, 0.033631459277655394, 0.034120123234710524, 0.018738234781527092, 0.04562502374340381, 0.02913035312667489, 0.03256459866783448, 0.05195299382986767, 0.02501894999295473, 0.019237081852874587, 0.03823582488777382, 0.05659127262021814, 0.019314495913152183, 0.02843711425417236, 0.03739234818411725, 0.01101971319543996, 0.03930088398712022, 0.04893086671030947, 0.0062375366355159455, 0.03251524881592818, 0.06800851997520242, 0.027879390699256743, 0.04320437381310122, 0.05082330087731991, 0.023806331579440405, 0.009343531531547862, 0.04346852410318596, 0.004759447757221226, 0.029579872398504188, 0.03470772438283477, 0.10603741543101412, 0.0578607777133584, 0.028652796787875037, 0.05634616880810686, 0.055245700358812294, 0.043983661103993654, 0.04130780736782721, 0.045939874170081954, 0.050710256943213086, 0.01690099774194615, 0.07785912496703011, 0.05022516208035605, 0.03514802575643573, 0.051817412355116436, 0.03160983882844448, 0.05845307093113661, 0.0450955357269517, 0.01978601498662361, 0.036160617135465145, 0.019163364112111073, 0.05774359471563782, 0.032343952650470395, 0.04121459022696529, 0.015479320992848702, 0.05752543892179217, 0.011267040057906082, 0.05735165253281593, 0.005720892862882465, 0.045188128615596464, 0.08024215352322374, 0.0276590958237648, 0.05960126753364291, 0.03546730701678565, 0.04506500504378762, 0.04927233945844429, 0.05543669778853655, 0.0210297781574939, 0.00897801828770233, 0.019653571736333624, 0.026555015871833478, 0.04286518433530416, 0.023369358420105915, 0.0329197269332196, 0.031099488892193352, 0.02893547447664397, 0.03182364182014551, 0.08983536304107734, 0.03217462423656668, 0.09283867438456841, 0.013380423886701465, 0.041786961656595976, 0.04441105674153992, 0.019994145425568734, 0.03130918674703155, 0.05437061410131199, 0.011699788488580712, 0.004550198583664107, 0.039102609269320965, 0.010994726143378233, 0.052465420083275864, 0.050870618516845365, 0.06584051238106829, 0.04331060525562082, 0.04701822577044368, 0.08003684918263129, 0.018619592933516418, 0.0459254960130368, 0.05829129461199045, 0.03831589201997433, 0.04475606804979699, 0.09213316081357853, 0.07020396752549068, 0.04033516473802073, 0.0510293414284076, 0.04217985039576888, 0.04485497809946537, 0.060193391117666445, 0.009845988409194564, 0.04242592451295682, 0.07466657699218818, 0.054417724787656746, 0.0232182554568031, 0.01942634392928864, 0.01679083758166858, 0.03609148459509015, 0.03651800492246236, 0.014782204292714596, 0.05322548447708998, 0.05117038171738386, 0.05083875451236963, 0.02847877291164228, 0.0314622337131628, 0.047809909896126816, 0.04236819136089512, 0.03966493498800056, 0.05673480652538793, 0.055901836936495135, 0.04293639658551131, 0.020357901263715963, 0.038146746810525656, 0.006896927636781973, 0.027689763910270164, 0.024193729273974895, 0.012174255796708167, 0.035648530149566274, 0.038183937314897776, 0.10096999377544437, 0.029451992296214615, 0.02914585086650082, 0.004603198529886348, 0.034469640015491416, 0.06788490446550505, 0.025402759933578115, 0.014797194827614086, 0.01920452743901738, 0.040152255445718765, 0.045736466334866624, 0.03213647021246808, 0.05015695574028151, 0.0839907880872488, 0.08487010840326548, 0.022892014123499393, 0.02379427061948393, 0.011312661359884908, 0.022318960766174963, 0.06691851453589541, 0.022795653669163585, 0.029913426642971377, 0.04733867411102567, 0.05446605344435998, 0.04795321309939027, 0.03265296767598816, 0.010125294627089585, 0.017379410731207048, 0.028516177154545273, 0.04490799543314746, 0.046943220509482284, 0.041278959451509376, 0.07019285990723542, 0.04679299285635352, 0.04410235723480582, 0.03432555649695652, 0.05147120003987636, 0.01196450789991234, 0.012071563762479594, 0.06270195543766022, 0.032448545430919955, 0.023807361256331205, 0.00770276939562921, 0.02665566636382469, 0.04037996501262699, 0.03751555657280343, 0.0018244833377788641, 0.05130200054762619, 0.09652135534478085, 0.02880927374852555, 0.055627868244690556, 0.035538529445018084, 0.011894165022697831, 0.03719591229621853, 0.028430249176121185, 0.04297756330509271, 0.05421735339664987, 0.011065726351392056, 0.03773866906496031, 0.05639990199623363, 0.04582436715385743, 0.027227769772123014, 0.032424521898584704, 0.07735733475003924, 0.014623567894367235, 0.029974684784454957, 0.02983805158042482, 0.05193196602963975, 0.0713000458532146, 0.01778098980763129, 0.21040552615055017, 0.10089511743613652, 0.1912872048893145, 0.13193315480436596, 0.11602076222854, 0.12268044772957053, 0.19630552775093488, 0.17434969517801488, 0.15896729273455484, 0.2305834884090083, 0.16804998607507773, 0.16260675101407937, 0.14352380856871605, 0.10199052401419197, 0.08993527053722314, 0.15580187258975847, 0.11688885278999805, 0.13858112879097462, 0.14382226898201875, 0.16271668725780078, 0.09855915885418653, 0.1676266345062426, 0.10494018359375851, 0.16858464452837194, 0.0867919163512332, 0.09111844561994076, 0.21034989984972136, 0.12120812173400607, 0.18589954184634344, 0.18386783158140524, 0.08100618395422186, 0.14618305516030106, 0.11487652148519244, 0.0812500494399241, 0.166795781946608, 0.17599933594465256, 0.1040433638596109, 0.08016017970762082, 0.14979200650538715, 0.13897010577576502, 0.15914373898080417, 0.2559794528143746, 0.14211620124323027, 0.12038041757685797, 0.08079690339842013, 0.1329821970845972, 0.17686442738132818, 0.09399276067103658, 0.1862748395651579, 0.11882296257785388, 0.07778080166982752, 0.14186997445566313, 0.13065271851207527, 0.13092375253992422, 0.20425745605358056, 0.1124100602631058, 0.10925014303731066, 0.23979481841836656, 0.09331500596765961, 0.14198647891836508, 0.16822868505758898, 0.14337279381496565, 0.20259233111781733, 0.20161186158657074, 0.14901888370513916, 0.05500154310305204, 0.22063693856554373, 0.10859595385513135, 0.2396783818091665, 0.14930525262440952, 0.1257847182984863, 0.14505986257323197, 0.2113632240465709, 0.09256534690835647, 0.15909086753215107, 0.15743464497583254, 0.1274968928524426, 0.13967338018119335, 0.11774688746247973, 0.20803040931267397, 0.15515271813741752, 0.18059542003486836, 0.11711537492062364, 0.07466521313680069, 0.10936974840504782, 0.2165976603116308, 0.05993759020098618, 0.15053737722337246, 0.11228292994201183, 0.13377315178513527, 0.15787027802850517, 0.1378329625087125, 0.14863481931388378, 0.15928392431565694, 0.07698965019413403, 0.1276615054479667, 0.12883847872061388, 0.16983534741614545, 0.09519575576164893, 0.09179100274507489, 0.19754369131156377, 0.13929531403950282, 0.06603332489196743, 0.10081085695752076, 0.11596618087163993, 0.22746906695621355, 0.1766839777784688, 0.16557426963533672, 0.1536502923284258, 0.10112383802022253, 0.10057240618126732, 0.17292076828224318, 0.1030819204502872, 0.1380407027900219, 0.08595307743442909, 0.12632648779877595, 0.22226308844983578, 0.11940353071050984, 0.1594763161348445, 0.13541406659143312, 0.2478663453033992, 0.10983750330550329, 0.1479066698146718, 0.08594644136194672, 0.13766602932342462, 0.16891859232314996, 0.08581550445939813, 0.13288968562015466, 0.08171003511441605, 0.1271873858890363, 0.11550690765891757, 0.1092412881553173, 0.10866015683859587, 0.10995513413633619, 0.06953730686966862, 0.11273746698030404, 0.1046481556924326, 0.1055283716746739, 0.18344236298331193, 0.09810814341264111, 0.11649280547031335, 0.1146648321300745, 0.08207517516400133, 0.12836958388132708, 0.1194246874323913, 0.16835695531751427, 0.14875501500708715, 0.10118711819606167, 0.1444870161690882, 0.10946697568786995, 0.14726419214691433, 0.17210734050188745, 0.16710494964250497, 0.08688726409205369, 0.16812713550669806, 0.15585482546261378, 0.13883667864969798, 0.06324544163154704, 0.09401570872536727, 0.1343658385532243, 0.09492953254708222, 0.09474362752267293, 0.1530416328459978, 0.10538821348122188, 0.11671935474233967, 0.16500968778772013, 0.18012192472815514, 0.06662128905632667, 0.10789511539041996, 0.20433756389788219, 0.06245948773409639, 0.09515388336564813, 0.1132107994386128, 0.11616478807159833, 0.1982913961900132, 0.09380294049956969], [0.007635029548379991, 0.04457202221133879, 0.09166005227182593, 0.03245998892400946, 0.005204129922536335, 0.023990636957543235, 0.008898621208832731, 0.006857390249414104, 0.03273758438548871, 0.025439193871404444, 0.03993010647328837, 0.06184932190392699, 0.04854170652106404, 0.014805176095770938, 0.04054769886923688, 0.00788683389380042, 0.06553604014750038, 0.04789131713498916, 0.057476808317005634, 0.05157554515504411, 0.007744127801353378, 0.04510058402749045, 0.02966265706345439, 0.04704660889027374, 0.014449574552210314, 0.02591555259589638, 0.07225457499069826, 0.010096439077252788, 0.08640327184860196, 0.018916214516918575, 0.03895771150876369, 0.03494676209187933, 0.004234629758034966, 0.011131677410698362, 0.08086287735828332, 0.007592331035993993, 0.020172225244875466, 0.05075137955801828, 0.019385224707158547, 0.022763684491759965, 0.039788743880178244, 0.04284224306632366, 0.024539934803864787, 0.025543662819213102, 0.06151945888996124, 0.031080890247332196, 0.021894657551976185, 0.037415014646415196, 0.011260867933742702, 0.043070994184485505, 0.018328214729470865, 0.036181756893971136, 0.02865073743409344, 0.031090420271669115, 0.03630741140139954, 0.07793270530445234, 0.015211199576567327, 0.019192963505962064, 0.06758771291268723, 0.06845588489834752, 0.016420952875965407, 0.02290896901727787, 0.009624858935629683, 0.02330499598091202, 0.01975655978146408, 0.010962259939073451, 0.046718730591237545, 0.017353807908615897, 0.030753670127264092, 0.027727951861119697, 0.03579317345949156, 0.0260155957990459, 0.015723719128540585, 0.08706721836434943, 0.03466357210917132, 0.03408357394593103, 0.02675654416504715, 0.049762981345078776, 0.04998896064768944, 0.046760351929281435, 0.04402689735538193, 0.028405267213072096, 0.010846113403593855, 0.06960355224353926, 0.0236562515076782, 0.016768104962206314, 0.024893765371026735, 0.025509754727993692, 0.13607859664729663, 0.04912468345303621, 0.0287685345060059, 0.019892809613208686, 0.05350030812301806, 0.009274335378514869, 0.04251918915127005, 0.05462004018149205, 0.034225201167698414, 0.028963643857943158, 0.05021275506754007, 0.012775437823230667, 0.0589648423982518, 0.08231951562421662, 0.06996956760329859, 0.011462917002583188, 0.02816987662975277, 0.04758046327957085, 0.012106569384091666, 0.02017888336974595, 0.06454404230628695, 0.013589778233186474, 0.018942300795710514, 0.04015961415799601, 0.013243319100833364, 0.0741318506853921, 0.07075461904917445, 0.024517904468146817, 0.038661018679184575, 0.023402976437604854, 0.06206223940742867, 0.04194488050416112, 0.04173827337633286, 0.045510032413793464, 0.03052423368873341, 0.036318298495773754, 0.02220981671208782, 0.05119638657197356, 0.040692525383617194, 0.023097274359315634, 0.017501711579305784, 0.01586049821759973, 0.02695884938085718, 0.02721588862394648, 0.022100821935704777, 0.03222696303523012, 0.04034450137987733, 0.04353374149650335, 0.024073779549715773, 0.06282563880085945, 0.010110399935261478, 0.024064866992245828, 0.033473927195050886, 0.051746977027505636, 0.03071678157097527, 0.07914582413754293, 0.040410061433379135, 0.057114056710686, 0.02786288533492812, 0.03807642683386803, 0.01764918946927147, 0.07381335313298873, 0.06057283468544483, 0.05115218340818371, 0.023616302758455276, 0.0878314252144524, 0.04594667309096881, 0.042417011955486875, 0.025687851510675888, 0.027714226794029986, 0.006147770269308239, 0.030041489949715987, 0.07553172271166529, 0.11668177747300693, 0.01054248509795538, 0.07658275988485132, 0.06373138805585248, 0.034825080406985114, 0.016459032261211957, 0.02995251026004553, 0.025206064506034766, 0.045535589435270855, 0.047785343535776646, 0.020530944656846777, 0.018845154937090616, 0.048759261811418195, 0.061153857436563284, 0.044305452943912575, 0.04193625293139901, 0.07542988817606654, 0.021024192117952874, 0.015037669334560633, 0.06910413689911366, 0.06830374377646617, 0.017207821099353687, 0.037337454701108594, 0.04776871942781976, 0.023993859998881817, 0.04605852619611791, 0.06953807361423969, 0.06519723404198885, 0.024855311095182384, 0.04353700185726796, 0.014452555017279727, 0.08187426773032971, 0.005642570413848651, 0.08479797334543296, 0.055428480729460716, 0.029514448052006106, 0.025154656996684413, 0.03666473812024508, 0.0616940866623606, 0.026171406099040593, 0.03458911306889994, 0.061817457899451256, 0.01595411230144756, 0.02773974140706871, 0.05853269023022481, 0.04193410876074007, 0.03861398941704205, 0.027625844215175936, 0.016044627176597714, 0.03853435993992856, 0.011196508039055126, 0.035082370708031316, 0.041943547182849476, 0.10800912284425326, 0.0361646544188261, 0.020690666711223975, 0.006321183039939829, 0.016934100072830915, 0.08774363635373966, 0.04158667168979134, 0.032433488738856146, 0.04048350267112255, 0.03520839501704488, 0.02061907108873129, 0.04012751605893884, 0.011716306575440934, 0.005977849833600755, 0.05612774160025375, 0.03607467728267823, 0.02972573707146304, 0.028923318521784883, 0.03760259225964546, 0.05992325275604214, 0.0670278604541506, 0.05708683388573783, 0.007015704767711992, 0.014762945772547807, 0.029945399213050092, 0.03990062751940318, 0.06990031631929533, 0.06371259942118611, 0.07388318795710802, 0.03353209800219961, 0.027989108115434647, 0.012467852810264697, 0.03592352682192411, 0.0617707950462188, 0.03037802635559014, 0.03947352025923984, 0.06864303842719112, 0.06788120644965343, 0.04796320452753987, 0.05142387222232563, 0.030625413438039165, 0.029426520091614554, 0.05264029212828193, 0.04739671938919595, 0.013348767683575196, 0.05175386755062001, 0.009496148476111037, 0.036453578022441695, 0.054669471457600594, 0.026324931432359984, 0.029363087245396206, 0.03260784509724804, 0.042773765312241654, 0.03882986194054995, 0.031168590898492506, 0.04600467765703797, 0.036500478362930674, 0.017076580552384257, 0.07512345497629472, 0.05004951311275363, 0.011365530264031674, 0.06780648617339985, 0.10605853144079447, 0.05010148210983191, 0.045551860705018044, 0.08921613876840898, 0.02944417218012469, 0.035278362155492814, 0.021696828970951692, 0.047548226080834866, 0.057955256929355006, 0.03572022755231176, 0.019061307356293713, 0.04246315572943006, 0.025858026397015368, 0.09502590487578086, 0.04992797052753823, 0.006228803041657167, 0.06780602476958718, 0.05897320873503174, 0.032608964680028815, 0.016682579015780772, 0.05419558599325163, 0.03707726705553276, 0.011523502546229532, 0.02453933938938592, 0.03238530596718192, 0.018586578812184076, 0.008736328354903629, 0.05239955468901566, 0.03590620382289801, 0.02820811207805361, 0.026390983423750316, 0.057336616196802685, 0.04959566818018045, 0.0369920532352158, 0.024752455364380564, 0.04979496070050767, 0.03693285784018891, 0.016882115808714713, 0.03741909942722746, 0.06523022441459553, 0.08001838624477386, 0.018338441948539445, 0.05973500678581851, 0.02887874555640987, 0.031982032249548605, 0.01569519012368151, 0.017024667534445013, 0.05710628069937229, 0.05189382896891662, 0.02524998947046697, 0.04743451039705958, 0.06615951204938547, 0.050081981013395956, 0.05964921960341079, 0.014739465068227478, 0.014285615046641656, 0.0522094664962164, 0.0461365000477859, 0.01836358167098037, 0.043512001234505854, 0.029544551258108447, 0.031864140182733536, 0.040775140414812734, 0.08309778850525618, 0.046366764299039326, 0.021219347271003892, 0.027526265808514187, 0.047211489507130215, 0.023762912123597095, 0.04065236968121358, 0.017009651554482322, 0.04040565774110811, 0.05478301750762122, 0.047152786049991846, 0.026275359360235076, 0.08281286486557551, 0.17193466691034182, 0.10373979407761778, 0.12553873578352587, 0.07763641620320932, 0.10737119814647095, 0.16203503097806657, 0.09976663227592196, 0.21084670961967536, 0.1475972035633666, 0.08934633606778723, 0.1619143331689494, 0.18648832025272505, 0.14392503989594324, 0.05077151847737176, 0.09921258807714496, 0.1070266312786511, 0.28275620884128977, 0.1174982450902462, 0.15838295194719518, 0.1081762867314475, 0.1633150872907468, 0.13768156777535165, 0.1797369375292744, 0.1981886931295906, 0.13190039513366564, 0.08939205575734377, 0.21612150514764444, 0.061450397595763206, 0.10199865286371537, 0.12396651586251599, 0.3081684038043022, 0.1035167799730386, 0.10341473509158407, 0.07109032424965075, 0.10246397860880409, 0.08162820379116706, 0.13113057001360826, 0.141564511560968, 0.15996513276227883, 0.15749084124607698, 0.10054156676466976, 0.13068454180444988, 0.15358075605971472, 0.1501216252467462, 0.10604911337473563, 0.10762087867728301, 0.13025060508932385, 0.11818706669977733, 0.19391223974525928, 0.18229711800813675, 0.10734713729470968, 0.08547962283981697, 0.09657417251063244, 0.17809907613056047, 0.14981351606547832, 0.12358292644577366, 0.15791633698557103, 0.2083141048039709, 0.2553689612873963, 0.17153061287743704, 0.11979942875249044, 0.1446685514279774, 0.16977395356765815, 0.09594903819795166, 0.18261792936495372, 0.10776710975915194, 0.10268404108605214, 0.07831073073404175, 0.1485224539147956, 0.12319522510681834, 0.09445628151297569, 0.11714044000421252, 0.07985255228621618, 0.23488105780311994, 0.07392389327287674, 0.2014310998576028, 0.21949535767946923, 0.1701587372060333, 0.11375520844012499, 0.10014723613858223, 0.1883026278976883, 0.14236065026904854, 0.1853627392223903, 0.17215938413781778, 0.10476341843605042, 0.17367419999625, 0.14205986926598207, 0.18327021864908083, 0.16278429648705892, 0.09803132646317993, 0.20115857305271284, 0.09811740541564566, 0.1231533187840666, 0.07949119846203498, 0.1649552285671234, 0.15952755909945282, 0.1571421828120947, 0.13673061451741628, 0.15163626468607358, 0.22854457210217202, 0.17495376776371682, 0.3582106871264321, 0.1668327892465251, 0.15153700858354568, 0.0935183832687991, 0.11159085814974137, 0.18514537731451647, 0.12396302819252014, 0.16307378666741507, 0.10276161799473421, 0.087370258889028, 0.177908434931721, 0.08709089245115008, 0.2608042982007776, 0.13231442363134452, 0.158656347276909, 0.13463702185877732, 0.13877840606229647, 0.0741920435268964, 0.12198463720934731, 0.18375329487025738, 0.07896496741367237, 0.11173580001507487, 0.09902846759983472, 0.10086097355399813, 0.10693085606076888, 0.13151006107883795, 0.12649362454456942, 0.08169307852430002, 0.14742416356291088, 0.056634027111743174, 0.10349597608936684, 0.12091770874602453, 0.1273270555372749, 0.13963587076536246, 0.1331433355808258, 0.09455279633402824, 0.169982073828578, 0.06047055910208395, 0.14279565906950406, 0.11420534178614616, 0.14274224479283604, 0.12834981137088367, 0.20570018435163157, 0.12872645258903503, 0.13613313729209559, 0.10086524153926543, 0.12759297341108322, 0.1818555545594011, 0.17964704521000385, 0.10254310936267887, 0.11379475346101181, 0.11396287408258234, 0.15901112609675952, 0.12328614879931722, 0.09134172435317721, 0.1386268213391304, 0.12249471912426607, 0.07746456363903624, 0.14817978015967778, 0.10545981928173985, 0.2295664186988558, 0.07795983313449792, 0.23895164366279328, 0.13155493938497134, 0.13148981359388145, 0.12091329826840333, 0.16300038274909767, 0.10809318654771362, 0.15925383807293006, 0.11862810089119843, 0.05382195407790797, 0.16210785135626793, 0.07732084992208652, 0.09825647116771766, 0.28008598355310305], [0.05869813742382186, 0.009713351776424264, 0.035574637686035464, 0.05990704933979681, 0.023038285917469432, 0.05685019479798419, 0.02296424417623452, 0.024442612526140044, 0.05642986610265715, 0.09476464175220047, 0.013717354691055204, 0.048595175080533536, 0.03891617838027222, 0.020141002455992357, 0.06756941960858447, 0.08737052351768528, 0.04107477469369769, 0.05320750669177089, 0.04500711243599653, 0.03700206841209105, 0.048411410834108076, 0.018362782695995908, 0.05565855499090893, 0.02578445284494332, 0.05792358970003469, 0.07728135239865098, 0.008069627835149211, 0.04360425824831639, 0.11350136170429842, 0.014661112933286598, 0.02521100254463298, 0.07729122508317232, 0.025754719440426146, 0.07626254563885075, 0.055763361509889364, 0.05058777458699686, 0.04290429848645415, 0.015590353070625236, 0.008883841019789023, 0.016209136295531477, 0.04018282005563378, 0.03050648999799575, 0.08323008926319224, 0.04406471211197121, 0.019231239666364024, 0.0411870756319591, 0.03686318925714918, 0.10259627936674015, 0.02142738101870886, 0.03571046343339341, 0.01500079604530973, 0.0761142246691244, 0.034928367007523775, 0.019194741267710924, 0.051474643605096, 0.06537011797939028, 0.029679864711527313, 0.09625785984098911, 0.04333115129598549, 0.11355302536061831, 0.021272630929680805, 0.03862196220351117, 0.032053716081593714, 0.04597452016813414, 0.09521692605423075, 0.04964875336736441, 0.013518855208531022, 0.051296121041689596, 0.06149872285979135, 0.03667351836338639, 0.09126683444316898, 0.05438782514206, 0.02986985112407378, 0.04180846782401204, 0.06351763595427785, 0.031662075846855126, 0.00628246837628207, 0.04782475284965975, 0.007798432655233357, 0.07103484722652606, 0.019114100773419653, 0.059750450242842944, 0.026401227606194358, 0.015645979371454035, 0.014997832543615783, 0.031753294702087126, 0.03726608638784715, 0.008052929936509048, 0.04640965789024319, 0.11473040575427668, 0.04133087077311107, 0.027856245869770646, 0.03444055121924196, 0.00768853966811938, 0.06346070686621325, 0.037196251563727856, 0.007323132445370513, 0.021159704042864696, 0.02879987603851727, 0.04861805188868727, 0.05607219672362719, 0.010344657365099659, 0.011048277823387511, 0.09299848973751068, 0.04075172756399427, 0.07422443000333649, 0.06484330339091164, 0.033011420762964656, 0.051631941593119075, 0.04279486096597143, 0.044007457327097654, 0.04445215221494436, 0.012629560427740216, 0.015612432600132056, 0.05348641851118632, 0.08055452390440873, 0.022421487407492738, 0.06491442064621619, 0.06203100644052029, 0.04870432761630841, 0.019035848722394024, 0.03767312936750906, 0.032888266657079966, 0.019148733200771467, 0.04632838635838457, 0.023835013254678676, 0.0475616644668792, 0.05659612753827657, 0.07101922056504659, 0.04673383478075266, 0.014394002534183008, 0.04717673833615013, 0.047937009683144946, 0.03362012095749378, 0.015241073777100869, 0.044194777097020826, 0.059608181805482933, 0.03192233813128301, 0.027749308750831654, 0.051845768333545754, 0.04165148535477264, 0.02747852578093963, 0.027160328480282, 0.057389799771564345, 0.034984583633818796, 0.0015364657904553625, 0.02180867189807551, 0.011254415913884128, 0.049266364957605085, 0.05571044934913516, 0.016974025073328187, 0.050680323370865414, 0.04413925936179502, 0.024549071277890886, 0.04705875127443245, 0.0003250936549323212, 0.054679540917277336, 0.025672209582158496, 0.037807631971580644, 0.023871791549026966, 0.035833780387682576, 0.02896119773920093, 0.045609200306768925, 0.048196423798799515, 0.019026357713820677, 0.02894342690706253, 0.01958693959750235, 0.04019292683473655, 0.021652513848883764, 0.05155582692740219, 0.04594299543116774, 0.07040998432785273, 0.04974900691636971, 0.04660646357972707, 0.045173071923532655, 0.036316843038158755, 0.013601962177615081, 0.022667982216392244, 0.03610021055542997, 0.01681137683668307, 0.021859833438481604, 0.026336768475760306, 0.01278274310087519, 0.04703014423804624, 0.1041267015306013, 0.07245158084801265, 0.03526591443057571, 0.027858529140108397, 0.01060151934091534, 0.04679093350257192, 0.03873951839549201, 0.014929622810866152, 0.029062258744878427, 0.020482465026101897, 0.04978109483740159, 0.03679724922403693, 0.029067843088081906, 0.02231222121710224, 0.027364129865808145, 0.049895465307469876, 0.08655913134238549, 0.023467018269002438, 0.013494007256148117, 0.026157387565555315, 0.020805032092279623, 0.011671563976311257, 0.05979420896619558, 0.025709788547828794, 0.025167572910764387, 0.016677696956321597, 0.021294598500909548, 0.014893804643569248, 0.017276159753756862, 0.010470687611294644, 0.03170201102537768, 0.04666292108595371, 0.022853268077597022, 0.028944794155125107, 0.07181942369788885, 0.024554033065214753, 0.05401440696524722, 0.048150381805109124, 0.04495039369378771, 0.013748009206860192, 0.10464075287537915, 0.057107780261763504, 0.014242792701614755, 0.021393113303929567, 0.014140202447638979, 0.045614333424185, 0.05683421190561993, 0.020398908527567983, 0.00824583659414202, 0.08459007021571908, 0.030424237983035188, 0.035901233553886414, 0.06208581171397652, 0.011331885105131992, 0.026087501851309623, 0.03031162152599011, 0.03731402149423957, 0.02235493838920125, 0.020820813120475838, 0.05168668240574854, 0.07209925153957945, 0.037249994929879904, 0.060686000755855014, 0.018405762800414647, 0.043537334339427095, 0.024882248935422728, 0.029219566910926784, 0.07979130771543298, 0.02859827989180173, 0.010858856291244072, 0.017010309733450413, 0.0969222066923976, 0.02886418758758477, 0.05907767598650285, 0.011121669867342072, 0.01665599231741258, 0.07307860148804528, 0.052327470521309545, 0.026574396528303623, 0.03517005439581616, 0.030233841056802442, 0.04247979001541223, 0.019968842854723334, 0.031488730505641015, 0.026609398757240603, 0.0024556004209443927, 0.04005785086857421, 0.04573146553177919, 0.010991806746460497, 0.05791880602815321, 0.08200851588376931, 0.00769656164837735, 0.06829657166131906, 0.01736146517630134, 0.047262444094355614, 0.013400127695474242, 0.06325965694018773, 0.07870714446263653, 0.03076579554804734, 0.028585900020386492, 0.04301530003015484, 0.05925254124615874, 0.019884458543466668, 0.002958472689247823, 0.022747374206249203, 0.036246224506092925, 0.027296295023656318, 0.050124650688043663, 0.022829385341278145, 0.03326639386692217, 0.05079908056982926, 0.02424387470819056, 0.014891621457146747, 0.013546550463485931, 0.06404894922993012, 0.0854268463860665, 0.05261459939980081, 0.03240814545590963, 0.07185576603348766, 0.02219222399539181, 0.015885478484311273, 0.018439119581931403, 0.046073915370340855, 0.028622323780187538, 0.029501783195883036, 0.07462245185992547, 0.024073793120416145, 0.07512365853680031, 0.04540320046778236, 0.012307709216007164, 0.03743069219802107, 0.14598892629146576, 0.04275654409346836, 0.036933448165655136, 0.04133468074724078, 0.08218490106186696, 0.045774630536990504, 0.02620131422632507, 0.02544466795266739, 0.012326470709272792, 0.013942215259053876, 0.01866183173842728, 0.051162697308297665, 0.01767483470030129, 0.04538851357730372, 0.048974194563925266, 0.10030891067747559, 0.019544982384624224, 0.0464751670536186, 0.04496835112305624, 0.0601789586778198, 0.004365757498557546, 0.00818306447139808, 0.00935930322988757, 0.03308885178661772, 0.032498702739498446, 0.03286733045907957, 0.04239418603745954, 0.03627878740163786, 0.05489831078531487, 0.053328665904700756, 0.04546445182391575, 0.05087247431012137, 0.023406425091837133, 0.015647122702960457, 0.04800208119143333, 0.04367888352966734, 0.03969619509630969, 0.14456913247704506, 0.11138143510158573, 0.10658418573439121, 0.13023664083864006, 0.08995017795158283, 0.11419922140027795, 0.15192257932254247, 0.12453721809600081, 0.24064545705914497, 0.17376365805310862, 0.10868015326559544, 0.11104108872158186, 0.07450616452842951, 0.13842463147427353, 0.17997663680996212, 0.20864160651607172, 0.12743422335812024, 0.16494378846670898, 0.11144094940807138, 0.11635443860931055, 0.11302345591996397, 0.10071756517780678, 0.1467352198170764, 0.09038415537880999, 0.15286108824823583, 0.16097159018473967, 0.06459841331733124, 0.11062161837305341, 0.21155774646571704, 0.0906921017116734, 0.1743155920079776, 0.1426180186016219, 0.07874413140650306, 0.15922696808619158, 0.08207001829785959, 0.12524145602115563, 0.20917123023952755, 0.11599117810172693, 0.11655798554420471, 0.10165553127548524, 0.20381412841379642, 0.15526631847023964, 0.1510598627584321, 0.21086778491735458, 0.13727942721119948, 0.18028462385492666, 0.10730713765536036, 0.2146902848035097, 0.13254180071609362, 0.09989143522190196, 0.10922686250082084, 0.13532698340713978, 0.11390720706965242, 0.10866976489445992, 0.162016452689256, 0.1376206081892763, 0.124110894543784, 0.19204993253307684, 0.10513243292059217, 0.2666715090828282, 0.11193196448896613, 0.11398806130247456, 0.11327438495521035, 0.1331852147621768, 0.14485343864985875, 0.14923435928566114, 0.14360888328935417, 0.11907418338315827, 0.08846430161169597, 0.10572930624974625, 0.18526079612118856, 0.09206105289714676, 0.11798176914453506, 0.10579671870384898, 0.09919464082590171, 0.16322866907077177, 0.08386069935347353, 0.16995333108518804, 0.041756149381399155, 0.1720950725887503, 0.12638397328555584, 0.11645625957420894, 0.10496049214686666, 0.1098751552136881, 0.10941622126847506, 0.14438151754438877, 0.09184368420392275, 0.14742158512984002, 0.22556044294365815, 0.1808178573846817, 0.12620513859604085, 0.08557471952268056, 0.1484461865786995, 0.08703477760510785, 0.182737066543528, 0.09520403388887644, 0.11017849429377488, 0.2157145741262606, 0.1363404704523938, 0.24965281944189752, 0.20438763978225843, 0.10344209362353597, 0.14695007114538125, 0.14455434041363852, 0.12739471904933453, 0.1788710318505764, 0.15731486997434072, 0.07456642522343568, 0.1457366334008319, 0.19053741012300762, 0.14488903459693703, 0.13195992979620183, 0.1904375297682626, 0.11903965952140944, 0.10968801525554486, 0.11882712878286839, 0.10447012167423964, 0.16259228464748177, 0.1491568705865315, 0.12285688040511948, 0.051432014642549415, 0.07801639581365244, 0.1408100484737328, 0.1854105895119054, 0.14925348040248665, 0.1900661132697548, 0.17650347389280796, 0.18333938850888185, 0.17922712702836308, 0.07218463160097599, 0.16994660001780304, 0.21493824864072458, 0.10505936826978411, 0.1923829439495291, 0.2030155062675476, 0.08041795516120535, 0.15577739104628563, 0.137930603697896, 0.12266587279736996, 0.20408903009125165, 0.15761049411126546, 0.13843618014029094, 0.14856170038027422, 0.11766934448054858, 0.08767272265894072, 0.18704507180622645, 0.14658495145184652, 0.08040132426789828, 0.12934609076806478, 0.09222711755761079, 0.0931396996602416, 0.11666520764785153, 0.10492850600608758, 0.08393187767692975, 0.11017706937023572, 0.06510319587375436, 0.14309677934007986, 0.11920181582016603, 0.15595756923513754, 0.17124003704105104, 0.1827174297400883, 0.09041139177445855, 0.10207029937633447, 0.15170965503369058, 0.10277347200151, 0.28733936005405014, 0.10034725469137941, 0.18792201046432766, 0.2186029212815421, 0.16309260922883237, 0.1104060070855277, 0.21670997142791748, 0.10115701838263444, 0.1845031710607665, 0.1296612431428262, 0.12305950453238827], [0.05876775511673518, 0.0476229124303375, 0.054859895525234084, 0.0364948906270521, 0.08559339280639376, 0.026502744926671897, 0.030436302335666757, 0.035803341306746006, 0.057519053907266686, 0.029517277543033873, 0.026448531675019434, 0.08372618657137666, 0.05014207885999765, 0.06115101437483515, 0.010125359087916357, 0.03963532032711165, 0.016363637022940174, 0.03754193801432848, 0.013370167829894593, 0.018171756428533366, 0.017099660921043584, 0.031131417357495854, 0.023415164622877325, 0.015277256656970297, 0.05171639206154006, 0.042814178857952356, 0.033137224548097165, 0.01353750643985612, 0.06838265739913497, 0.03897942462936044, 0.05196582492707031, 0.10016715792672974, 0.01538829891277211, 0.04913008798445974, 0.035417153100882254, 0.03979829426056572, 0.030792787671089172, 0.04971173498779535, 0.01821733532207353, 0.05085308856463858, 0.055466729748461924, 0.06324146541633777, 0.02957204888973917, 0.029333282594702074, 0.04229665680655411, 0.005398877530491778, 0.01961797070024269, 0.053571374488196204, 0.02238304161333612, 0.015489646599494984, 0.017280351403834562, 0.0933129500065531, 0.010395090328529477, 0.023135677745033587, 0.02775774633378855, 0.03222530062443443, 0.008526247127779892, 0.019884472114167044, 0.03327997135264533, 0.04541680509490626, 0.03326871445668595, 0.011433619556815496, 0.044087283579366546, 0.019285337567063313, 0.06247087355170931, 0.06109369852180992, 0.02812193813068526, 0.07060357036867312, 0.0059777595036263976, 0.03520489377634866, 0.04557250174028533, 0.05463333946785756, 0.03231351017685873, 0.1069794934509056, 0.039064485779298205, 0.03717073864702668, 0.036497760830180984, 0.010572705351348435, 0.03090765347172107, 0.032870794380349774, 0.060446002919759066, 0.014276342865611826, 0.047524725020463975, 0.016959210957533548, 0.05414583919835942, 0.04188421268814376, 0.026838322901832204, 0.04187057413426893, 0.053307183486010344, 0.038744580266731124, 0.013100060850514897, 0.04334338867504682, 0.03427920237715755, 0.03310858019228492, 0.019522392257515873, 0.026152183201962283, 0.05604861084637897, 0.011659563236337687, 0.09150663550410952, 0.0802329865151218, 0.03947457877386894, 0.019658842257090976, 0.02639542443544737, 0.013892729700143849, 0.12016540340014867, 0.03257319909919586, 0.03938139895243304, 0.09391666296869516, 0.029489196371287107, 0.04270629518266235, 0.05854316681091275, 0.022291057709870592, 0.05436105015022414, 0.022510143096691797, 0.06723843022648777, 0.009547749367941703, 0.09040567172425133, 0.06690512703997747, 0.03051982999646238, 0.03157012417380299, 0.05749086756259203, 0.051661406976303885, 0.0381106792816094, 0.06314621945577008, 0.06759267978902374, 0.05101007442655308, 0.025707710534334183, 0.005118651897646487, 0.060970320499369075, 0.05994382593780756, 0.03144676311473761, 0.0360011953328337, 0.015216220735705324, 0.03525058971717954, 0.022529065742024353, 0.04859705462253519, 0.0263863982233618, 0.03551229728119714, 0.028887549548276832, 0.06888369444225516, 0.016492144770122, 0.018626578451533402, 0.056985453968601565, 0.0035823061230725473, 0.06204335577785969, 0.03487867110275796, 0.03854415798559785, 0.058090360036918094, 0.07474251863147531, 0.007672146262068833, 0.031272196410489936, 0.017902493377083113, 0.02691250543908349, 0.006774440191553107, 0.01783431926742196, 0.02329140662082604, 0.01135269831866026, 0.031225631944835186, 0.020529675796361904, 0.021874776475929787, 0.009501857500124191, 0.010384096364889826, 0.04807435195626957, 0.02816182411541896, 0.03948512999340892, 0.06370309993092503, 0.04162146696554763, 0.03314670707498278, 0.007964028278365731, 0.08033879726592984, 0.01950113714805671, 0.04495446151122451, 0.02239289733448199, 0.029290809695209776, 0.003441568206263972, 0.002355444835432406, 0.02460800713327314, 0.006067935959435999, 0.059341856810663424, 0.050794062803366354, 0.008876565428051566, 0.023144295139770423, 0.05302651086822152, 0.10410561944757189, 0.006339143861883453, 0.01905563480353781, 0.058623993902334144, 0.01276343793142587, 0.011946672606947166, 0.03801965380885771, 0.053719783667474985, 0.03977829783356615, 0.02574997648064579, 0.03758672132555928, 0.01907695098114865, 0.03415005002170801, 0.03403030216161694, 0.03518048008637769, 0.020492817774148922, 0.041997029313019345, 0.04842978556241308, 0.029949636664241552, 0.05043580309887018, 0.028593587822147777, 0.016862093936651945, 0.02084713349384921, 0.04936797896932278, 0.11652403165187154, 0.016636426760149852, 0.014417678317321199, 0.014912891833643829, 0.04131054525662746, 0.028750743317816938, 0.021366618207788894, 0.02024068942825709, 0.021122347297413007, 0.05048025392794183, 0.036053741084677834, 0.003937310131732374, 0.0540798347044204, 0.04391755482980183, 0.07352336762206894, 0.039512264608804665, 0.012597517459653318, 0.02296003556278135, 0.06203864674483027, 0.007546350110455283, 0.04661567129993013, 0.008184649698835398, 0.029134227561631372, 0.03420127263026578, 0.0316487867385149, 0.027642673579975963, 0.048427614250353405, 0.026641222049615214, 0.01535254011728934, 0.029297622186797004, 0.04752351383545569, 0.012305368270192827, 0.06335685029625893, 0.033236769028007984, 0.051493615444217405, 0.008569039786899728, 0.0017296554183953308, 0.04090430973363774, 0.056209946117763004, 0.03517016635409423, 0.03419135584096823, 0.013075997454247304, 0.07957588641771249, 0.03797596972435713, 0.0470146973883467, 0.03543873729982546, 0.0373967891958143, 0.04496168112382293, 0.03082138452945011, 0.10902108318571534, 0.04097078920208982, 0.021355268013264452, 0.0211128393254642, 0.037628227312649996, 0.08267065749636718, 0.06882550327905587, 0.009313069550054414, 0.023714490168328797, 0.03341414825990796, 0.011635881516018083, 0.032848962516124756, 0.06577560372118439, 0.0259033932483622, 0.04563287778624466, 0.0646294630797846, 0.012544120994529553, 0.05801435732947929, 0.0151281265342342, 0.08604686454470668, 0.06004281062632799, 0.03509633835139019, 0.02330005624597626, 0.027706287934311798, 0.040551267963434966, 0.03153524408116937, 0.04430817047666226, 0.06929430990879025, 0.02885460328044636, 0.03217297200379627, 0.04661917254062636, 0.04124308530507343, 0.09315209649503231, 0.04790227208286524, 0.04196824585752828, 0.01875418035446533, 0.044969759083219936, 0.05797059860612665, 0.018530759128874967, 0.07101351408553974, 0.032284007474247894, 0.02528357016853988, 0.02366864325345627, 0.05795670899429491, 0.020164096395352056, 0.015384553399469172, 0.023859947720276456, 0.004213973455729761, 0.05367365685690727, 0.038868874311447144, 0.03554420539044908, 0.036193722859025, 0.09060389894459929, 0.02064463489555887, 0.008578725874290934, 0.03132262513307588, 0.023378530517220497, 0.08431114482560328, 0.041673032234289815, 0.02973468355568392, 0.04268080601468682, 0.0686159852359976, 0.030025445989200046, 0.02747975053664829, 0.005032795589483742, 0.034778519334005456, 0.0074178211590541256, 0.04323188501543232, 0.0575279291453106, 0.02092986217966037, 0.06814959419092961, 0.03004436693819506, 0.05163164303771087, 0.049764080571808984, 0.028549520365361656, 0.0336761883060847, 0.01626591440955443, 0.01669530663639307, 0.050451009068638086, 0.04219845582598022, 0.04932200482913426, 0.07259169154401336, 0.04153873658339892, 0.02346122866895582, 0.04558822339666741, 0.04407435070191111, 0.017383890758667673, 0.02214316082453089, 0.07790939762656178, 0.02692844931568418, 0.0353098970704845, 0.005196279272370572, 0.03069237805902958, 0.015093448305768626, 0.0056746871726188275, 0.023283035195033466, 0.15089632224823746, 0.11271557744060244, 0.10438953207007476, 0.17909264138766698, 0.1344468013516494, 0.08989162716482367, 0.15834761384342397, 0.10228616172181708, 0.1280963106879166, 0.09773570232625518, 0.06648867617228202, 0.1671150733849832, 0.07788619851427418, 0.10352967892374311, 0.17689507002277033, 0.1452587954699993, 0.07616294348346335, 0.18702353510473455, 0.07061450156782355, 0.09553869414542403, 0.06527774900730167, 0.13381250681621687, 0.18818648984389647, 0.13075643937502587, 0.11603319299008165, 0.13185665676636354, 0.1334852629474231, 0.1498845722526312, 0.2943497938769204, 0.07756751775741577, 0.14185130117194994, 0.2162830371941839, 0.08643918670713902, 0.1481788030692509, 0.08731771992253405, 0.11480638810566493, 0.1184128967246839, 0.09213023632764816, 0.09106789476105145, 0.1264919824898243, 0.09135512541979551, 0.10909739123391253, 0.06016167639089482, 0.1033013586753181, 0.10289509940360274, 0.16084318421781063, 0.12918050108211382, 0.13208883787904466, 0.08491305288459573, 0.12565917574933597, 0.0984227733154382, 0.2521584592759609, 0.10309148100869996, 0.11066666631294148, 0.10740081620003496, 0.12008088507822581, 0.060208644584885666, 0.13424623997083732, 0.13739708518343313, 0.10660209905888353, 0.1387490119252886, 0.16591147439820425, 0.10664663809750762, 0.1527776284409421, 0.13166674838534423, 0.15800149313041142, 0.08644749876111746, 0.10144055102552686, 0.09348706887768847, 0.08514258771070413, 0.14832928856568678, 0.1896067722035306, 0.1446604768612555, 0.21738060829894884, 0.22377657437963144, 0.13747633807361126, 0.10234861408493348, 0.10014859999396972, 0.12241706757673196, 0.11854008132857935, 0.21289242484739848, 0.12213837967387267, 0.1424731785165412, 0.08911586486335311, 0.18424981965550355, 0.20847737390015805, 0.1002972534458552, 0.18710516286747797, 0.10584410758955137, 0.15760372233177933, 0.10519217792898417, 0.10686804407409259, 0.23311086850506918, 0.09069913811981678, 0.1381228869514806, 0.22079309661473545, 0.17071923427283764, 0.16370414569973946, 0.13917050430817263, 0.21405539315726074, 0.17412227738116468, 0.12336337965513978, 0.11416578319455896, 0.11020924550082002, 0.18343206282172883, 0.1857024545648268, 0.1456769494605916, 0.2089629199888025, 0.18909181840717793, 0.12975212612322398, 0.13863923852997168, 0.1394053181367261, 0.17556562993143285, 0.12325949594378471, 0.11402354868394987, 0.1004017274826765, 0.1943865492939949, 0.19065546164555208, 0.11069573475314037, 0.17552191870553152, 0.158161138849599, 0.1211883763649634, 0.12781556003860065, 0.14190539398363658, 0.23470653859632357, 0.1427903122135571, 0.12698273972741195, 0.06959806968058858, 0.12035422612513814, 0.22649156940834864, 0.11948036801602159, 0.13600599340030126, 0.15166211687028408, 0.1343665849417448, 0.13429966781820568, 0.10649714326219899, 0.08818734397313424, 0.2314113825559616, 0.16878709223653587, 0.14751948416233063, 0.19000157101878098, 0.1138674042054585, 0.15186600307268755, 0.09213505392628056, 0.09931447011019502, 0.0908769957189049, 0.18483725456254824, 0.21508079527744225, 0.1289406796651227, 0.05217452194275601, 0.12300951007221426, 0.10043868728514228, 0.1759658298854317, 0.06663781138403074, 0.1014350548918758, 0.16533875013036387, 0.11827364776815687, 0.09777709296239273, 0.12022546731999942, 0.11390582285821438, 0.09569837379136256, 0.15492266762469495, 0.16777858563831874, 0.06158014027667897, 0.08238403073378972, 0.11228314028786761, 0.12380646302231721, 0.07205503819776432, 0.14432965032756329, 0.1775908398308924, 0.0806041383849723, 0.18540174141526222, 0.11122345179319382, 0.1682191448552268, 0.12554784172347613, 0.19661882093974523], [0.026422123092093637, 0.09946424993021147, 0.05199869655604873, 0.026042314811742732, 0.02026717604271003, 0.03204594685563019, 0.06336292997002602, 0.050721235639814816, 0.006780852347479335, 0.026239890638472776, 0.006205301981286279, 0.0610181029353823, 0.02008271969056555, 0.05977104378065892, 0.08084708784839936, 0.04428303414689643, 0.04502673227606075, 0.03386722305523498, 0.04416433123073407, 0.05188454660986151, 0.02104638021306268, 0.032573022680091004, 0.038672910005386384, 0.04458394407161644, 0.01505726033688656, 0.05922392063907214, 0.027804631407239606, 0.0025286869120983674, 0.02183317210126136, 0.03217147922675524, 0.05026352984298553, 0.01977235946937331, 0.01654643435696406, 0.0077076446697381985, 0.015982748175572072, 0.024227701826021075, 0.049309058380978446, 0.06189983883606536, 0.020407446194440126, 0.03317213856748172, 0.045577712889228544, 0.05338221588837249, 0.024728825382356132, 0.060284084108258994, 0.05996467053358044, 0.015041771078748363, 0.026387337994362627, 0.05435779318213463, 0.039890893934560676, 0.048200539113687615, 0.045312612650117705, 0.02128427119792572, 0.0756347786102976, 0.03120697901717254, 0.008140996148410653, 0.029695101215371063, 0.051177594544632096, 0.11270919242607695, 0.042418864356087785, 0.10512666537293366, 0.03101503842377237, 0.035892015655658076, 0.06662360286074025, 0.03567620759297695, 0.05589521782738822, 0.012333833662393903, 0.08231928492231028, 0.09509971591510943, 0.02847880683839321, 0.05998383914785726, 0.06444212634648595, 0.019584591866337826, 0.042162998978580744, 0.028755455743521452, 0.05575108341872692, 0.025470845833686844, 0.029752166010439396, 0.05267613913331713, 0.018503266586256877, 0.04942488430866173, 0.09106136046882186, 0.05609391323689904, 0.03389364181618605, 0.06032913883349725, 0.04024381356846009, 0.018441645428538322, 0.04762602012072291, 0.03881258983165026, 0.05607019504532218, 0.03763790661469102, 0.07353408169001341, 0.0327947747095355, 0.021496192951287543, 0.0391233758335667, 0.032748291668082984, 0.057867332361638546, 0.015623155149764248, 0.03129330902759518, 0.07425927956189428, 0.07222011219710112, 0.05648189616788711, 0.041771416419318745, 0.03989088375653539, 0.013546351991992975, 0.030288134036319594, 0.08042343093880586, 0.024222164980268905, 0.01640957554004022, 0.012875494597080563, 0.054352025634476116, 0.017227932877306427, 0.008080284227617085, 0.0473284723370203, 0.030092261332486357, 0.0572917243199689, 0.03248492508594479, 0.02462309435941279, 0.029512029074664627, 0.030802534826632057, 0.009125983026543898, 0.02149013532990856, 0.045086643525532315, 0.022007328291822757, 0.01302323626753475, 0.0399236128931599, 0.02899062241028462, 0.05438094479697091, 0.06924928232495274, 0.049875448524419747, 0.03794100820752127, 0.05530526555542435, 0.09315773512103728, 0.03458102493147765, 0.0453309873784227, 0.03239056461357644, 0.02412225239511047, 0.015925600259963955, 0.09381035010197333, 0.053098187914916446, 0.0370490841035332, 0.03509684046730399, 0.04160391665729029, 0.026047680327402692, 0.042108393872955015, 0.034632634304996045, 0.019059575395658612, 0.04709493076162679, 0.03290081616224987, 0.05525963068274515, 0.02858698906909142, 0.030957688643996204, 0.026146861791078533, 0.035238165740988085, 0.02381999897105353, 0.0798860787014876, 0.014167515178477126, 0.0681084885394999, 0.035826981466795714, 0.05242377160383122, 0.056025717074849775, 0.02583524628010179, 0.01975252928345331, 0.018246229039505124, 0.05709970569504159, 0.022321681691599742, 0.04072878968768886, 0.0455410380714706, 0.05105953623673745, 0.057431271831904135, 0.028856682990278517, 0.018147278277735625, 0.028566965500691106, 0.02255443955904671, 0.052872144151479006, 0.06374027007924658, 0.014887616404199173, 0.03367796606783356, 0.09806511750710861, 0.051136678883007596, 0.04254737210326961, 0.01986994976843042, 0.030868505393820148, 0.10163233216319766, 0.010280635889752634, 0.03092224197462201, 0.014716001327282615, 0.012723540920498115, 0.042790548875927925, 0.05877282377332449, 0.023363655333274176, 0.024719320803082416, 0.04520094953477383, 0.07208873424679041, 0.017905304208397865, 0.0295485410440181, 0.02294197296058493, 0.024775914016312788, 0.04402258526533842, 0.02905571088194847, 0.01622284439924572, 0.022375070523204546, 0.06772101111710072, 0.044040871784090996, 0.008243683941795357, 0.04581608563395483, 0.04168681328051856, 0.012953663527566408, 0.014267618601609553, 0.03948254477498787, 0.006363108446488955, 0.01642366192702736, 0.020411497048501457, 0.022507707155974846, 0.04740481431196843, 0.04468972428834864, 0.04892735529158797, 0.02545094779426498, 0.04700417331020747, 0.08258835119860512, 0.039456027626459084, 0.03532136770497475, 0.01816304912790656, 0.021853825010891472, 0.043200933640556674, 0.028396390278690627, 0.02221804903820157, 0.05707267964524882, 0.05232570972293615, 0.04440320948404925, 0.04359039238521031, 0.02693733642809093, 0.024470362912065217, 0.05089268108297672, 0.007383454208528357, 0.007832116829896612, 0.028639086987823248, 0.013202420402584332, 0.07150319245244775, 0.009292370839310544, 0.03457762886370931, 0.04901092027180961, 0.009421213613157826, 0.055183614404605966, 0.05008997415591564, 0.017862017066883187, 0.0937192974878209, 0.01403434419937964, 0.03936369258112141, 0.03677797882950731, 0.05168970527925661, 0.018615849116551023, 0.021018612863762037, 0.05730045028030872, 0.05310255768043654, 0.03762656490185431, 0.07264121102967433, 0.02574459569794791, 0.0428980457862573, 0.10051987400012356, 0.06141744114990745, 0.04580681684560009, 0.045172064299029965, 0.06702785366880042, 0.04058877398659076, 0.040671202420656166, 0.057904353232256005, 0.03317657957917877, 0.045171741994896104, 0.022973886158849512, 0.07791105325200728, 0.028084218368998597, 0.02415495439033423, 0.01224152066944433, 0.04951025079935789, 0.13964110905570642, 0.046718018129467964, 0.05122247963611569, 0.08650298256959234, 0.02781615123551871, 0.04417010895641787, 0.030459918746990815, 0.019394339128796543, 0.013660600325757903, 0.025658852620316402, 0.05390265224767583, 0.03206806370456304, 0.04352213854768446, 0.025691171243254627, 0.0024627551486316535, 0.029171360390526906, 0.039331852325371335, 0.06302064297986881, 0.04574607778340578, 0.06776614048119102, 0.05785729004336255, 0.054523905340049944, 0.027756005891465714, 0.030480312116976296, 0.03854129117514406, 0.014165940977233862, 0.02761740663221904, 0.034194222651422024, 0.003872502828016877, 0.08952405117452145, 0.06059388962707349, 0.03079678424234901, 0.03286856539281351, 0.03772689987506185, 0.02721055703503745, 0.011929330948208059, 0.005877003414622907, 0.05320528448958482, 0.11350991124553339, 0.0666092722011464, 0.023006440572706715, 0.038168972225061486, 0.03495346262518849, 0.029786001159144298, 0.041457465051540306, 0.061431480039443286, 0.1167781837284565, 0.03450962269146528, 0.01323122760680105, 0.03690845432824322, 0.01882514663572822, 0.02179402402336044, 0.019255456581179584, 0.020525212732276747, 0.060823709437889714, 0.033060207430805476, 0.02297008127373244, 0.04825190082192421, 0.04173823605690684, 0.007034395862969437, 0.048866585695317814, 0.1339374386838504, 0.04489141882264188, 0.0386176297574171, 0.04700432598058667, 0.03535956583384957, 0.005848885347534503, 0.017216148420370052, 0.023251227169696773, 0.026922469725832343, 0.05387178568967751, 0.022621660327006663, 0.028647195481296097, 0.033021201845258474, 0.023471632307129245, 0.021699142775365284, 0.01875455694140068, 0.055548673029989004, 0.06422865244426898, 0.23867887258529663, 0.1821508529995169, 0.1951027022940772, 0.11664709076285362, 0.16000849114997046, 0.18993085409913743, 0.13814112597278186, 0.07888451351651124, 0.08652982541493007, 0.061863754343773635, 0.25076439550944735, 0.13289032344307217, 0.17258359066077641, 0.12340064479836396, 0.17862168380192348, 0.22783384738223894, 0.19613499833004816, 0.10178519253219877, 0.1900293231010437, 0.07085025177470275, 0.12788026513797895, 0.1415790050689663, 0.10677806354526963, 0.10034133786601679, 0.15868157520890236, 0.16630606965294906, 0.06867917720228434, 0.14857487753033638, 0.10852045326360635, 0.0715235552883574, 0.16428334319165774, 0.23198015774999345, 0.06659106032124587, 0.12868464126118592, 0.15801087048436913, 0.11324435299528496, 0.158453424594232, 0.10878616757690907, 0.21104887234313147, 0.16651583196861403, 0.21392245457640716, 0.17264681655381406, 0.09861225421939578, 0.10815558462802853, 0.09267555456608534, 0.11519258309687887, 0.1025686494207808, 0.18565198513013975, 0.22156818716653756, 0.12182579216148172, 0.09384569499109473, 0.14703017898968287, 0.12712399714759418, 0.10891512994255338, 0.10798135719129018, 0.11568209183003221, 0.24022234976291656, 0.12907660380005836, 0.23628551672611917, 0.19325269013643265, 0.1430515753371375, 0.1253998532359089, 0.1386387228433575, 0.18175286506967886, 0.13678233245653765, 0.13566536882093974, 0.11184000263788871, 0.1092232730505722, 0.1519169881939888, 0.0888342864013144, 0.1531820488827569, 0.21108608320355415, 0.07931499648839235, 0.14740215188690595, 0.06331203305827719, 0.15011857183916227, 0.1987922635993787, 0.11290128568985633, 0.16579654413674558, 0.17357949007834705, 0.09118756119694028, 0.2466756791940757, 0.18093900302691118, 0.12640609352716378, 0.12815511253263268, 0.18714636351381028, 0.1887411107974393, 0.253203131790672, 0.14860645655010427, 0.17029510917408125, 0.14193211469267095, 0.09490914256977183, 0.16290968975850514, 0.1629514875156539, 0.1801693950380598, 0.06571192999503442, 0.10471571742423944, 0.2521742827125958, 0.16514531336724758, 0.15760132031781332, 0.1601616365036794, 0.1006779930155192, 0.09749549414430346, 0.12120804030980382, 0.1379785489823137, 0.05013466925759401, 0.1522259387586798, 0.13422956158007893, 0.1785013931138175, 0.157939149332898, 0.196792227349111, 0.12779204201485428, 0.13017626479268074, 0.10255316525165524, 0.09614552836865187, 0.13236562588385173, 0.24677110835909843, 0.1486519319670541, 0.13733753695019654, 0.10306707410407917, 0.1736424852694784, 0.12253670687122004, 0.15737775659986905, 0.13001253429268086, 0.1668203177728823, 0.19150436323668274, 0.2100309883909566, 0.14685598547969544, 0.08817251119762659, 0.12874595368547098, 0.158013557483043, 0.14456816895731858, 0.12337156278746468, 0.09689898043870926, 0.152300645464233, 0.1682513074151107, 0.2066897191107273, 0.16638176701962948, 0.06381937369172062, 0.15779605986816542, 0.06383105806474175, 0.13730103176619324, 0.13274067933005945, 0.1602439156600407, 0.14255543053150177, 0.14177864364215306, 0.08659921240593706, 0.1471679623105696, 0.12593358888157777, 0.09765973354556731, 0.11047293777976717, 0.09575158450752497, 0.12464281171560287, 0.1016009363478848, 0.18611946861658776, 0.13441725793693746, 0.062352862741265974, 0.23920066601463727, 0.22084797652704374, 0.19231921594057763, 0.11339776297765118, 0.09433277456888131, 0.10573513486555644, 0.09881477656641177, 0.07857419231108256, 0.09076148870268039, 0.08720485240753208, 0.10193983066294875, 0.07504977964396987, 0.10440068718578134, 0.12013735276247774, 0.09565054385789803, 0.1093653447127768, 0.12360900933189051, 0.12144335625427109], [0.05580595315300992, 0.015881446289962957, 0.017093771237081716, 0.031450420418488126, 0.025510304341358796, 0.04884437045880726, 0.02433123269916645, 0.026172741116689782, 0.017025505525193045, 0.07283192008201565, 0.03751457269702639, 0.028889486765755073, 0.03198802710643836, 0.012247673285725926, 0.06181065219321421, 0.0704407219641975, 0.0932942767228399, 0.041987580712884665, 0.0103312198272241, 0.031538154996399365, 0.018488303192758133, 0.03744937226708446, 0.02760459080205432, 0.04843931558674999, 0.03560095127405865, 0.029071435931005647, 0.023427912599540184, 0.0232599497373615, 0.09632942492940597, 0.05211011879146099, 0.01137091189489833, 0.019714144557448368, 0.096021057904831, 0.034683911196355305, 0.020382476105753864, 0.04653083406654852, 0.04531701294971364, 0.029063239227980375, 0.017332366202026606, 0.014705936956618513, 0.006015224390596683, 0.039364985190331936, 0.02364810908745442, 0.03890777472406626, 0.0368328078516892, 0.03145716844924858, 0.03413822654900806, 0.01573236027200307, 0.030126364502523626, 0.0252419166000826, 0.034120051988533566, 0.024622580369136164, 0.030425730760076215, 0.028730614576488733, 0.04726856108754873, 0.06321874127856322, 0.048323557512568574, 0.05717971854444061, 0.04960155447146722, 0.001318435843651449, 0.010982710984535515, 0.04146931905831609, 0.07414555030741862, 0.042004808717008145, 0.011719445648070956, 0.026539312875164405, 0.024450363092390553, 0.025216988919835006, 0.03265164792537689, 0.034660939393298965, 0.03471813650269594, 0.04346421879849263, 0.024333532932879667, 0.053976093485419235, 0.06511690906648125, 0.07874553597399167, 0.031083054774041687, 0.04335999921230333, 0.02927011776981609, 0.06688878791672842, 0.027714330270620327, 0.03396884385230286, 0.07186200177030903, 0.08195416522877556, 0.060630632298333306, 0.018208395623202835, 0.02574264321343175, 0.024010825070685575, 0.010192837699183395, 0.09675967719938074, 0.05061792189787541, 0.010509535437449813, 0.025734266698626534, 0.040080961771309376, 0.02910505055582949, 0.06284919075135674, 0.036614428141287396, 0.05060407978349498, 0.06995546764561109, 0.07897541006760937, 0.028676148570541824, 0.02384342539257237, 0.005434726231864521, 0.006095861916297248, 0.009460677209842418, 0.030899029291634048, 0.05152707400598696, 0.06501820257731847, 0.018093039581019963, 0.046126634148614745, 0.018851621375818337, 0.043689183691250424, 0.04059053139228906, 0.017137904851032153, 0.03959520533680916, 0.032730334238814454, 0.026286219313208545, 0.042086053107466014, 0.04681448206039412, 0.056992727864001475, 0.03769571440560477, 0.03962658418874655, 0.03257933305576444, 0.029413074920220033, 0.04787896101229957, 0.021029710303992033, 0.03539748915604182, 0.0370039004566414, 0.05430588525320802, 0.01707143895328045, 0.0471982920010175, 0.04523677279108337, 0.034191081034285684, 0.037323887393410714, 0.0416034586461527, 0.03176225475700838, 0.07047848243798528, 0.013919280775423561, 0.012962150304312152, 0.029878051219774143, 0.043595983513763974, 0.04337030955191169, 0.05203741715688791, 0.02880246125693832, 0.03242482045399291, 0.030303903190152984, 0.02775828746546592, 0.02680449284213994, 0.07329790400607245, 0.05396128785131233, 0.06479089334607124, 0.0657074720199619, 0.03693593838917358, 0.04626695519047124, 0.11612780791308198, 0.0612497412200485, 0.024423328560910056, 0.05569765217868345, 0.0444132755510509, 0.021009557813938175, 0.0176265331849988, 0.023576757737568448, 0.026012944423460534, 0.03815605631098151, 0.029213680619640008, 0.04865786153823137, 0.04196072429684656, 0.02472666255198419, 0.014719913081665124, 0.04008351984832968, 0.054899128420012336, 0.010501404043420084, 0.02707977619554315, 0.021627078963709728, 0.021639192510130148, 0.02972598812941994, 0.11077504192612, 0.019226430549419353, 0.034504618495702744, 0.003393205622809806, 0.025057840227548565, 0.05140992154234222, 0.05800704950732844, 0.01914841089663761, 0.007862595774765526, 0.042476655183626075, 0.08171058472778116, 0.04579901708556073, 0.02940208265291793, 0.021751875124339546, 0.024668293273342506, 0.026272048109344075, 0.01690459397754499, 0.0723809182111706, 0.05113980692944356, 0.01191753292057131, 0.017834392209936465, 0.06235913919018848, 0.02515839402829962, 0.11878952437213489, 0.045422257123781104, 0.04425656110314386, 0.039433619007468224, 0.030120295006781816, 0.10551790187933616, 0.009158521325194409, 0.022400686916496073, 0.039358674814658504, 0.042684046019400866, 0.06120830987180982, 0.0046354967967740125, 0.026284969112436687, 0.06905731119747673, 0.020372041933504597, 0.01415508272059794, 0.060292525083890984, 0.023958867947970117, 0.06420938204973936, 0.026234012828873735, 0.012232656457594462, 0.02735805358471615, 0.02855292321848018, 0.016011702961155345, 0.02051199826278857, 0.009736445715783961, 0.030262828072799102, 0.039744486433586905, 0.020967025542631745, 0.0175406628820513, 0.02501199670535113, 0.031950286988701136, 0.10069934651255608, 0.07316045316734485, 0.04209246526339224, 0.057523213326931, 0.042993206929947646, 0.05288945697247982, 0.06193236780485936, 0.03575074127210038, 0.029776474527482475, 0.029743993056139777, 0.08188095808561359, 0.010174892992446465, 0.038296010943927934, 0.04412273703409093, 0.01793676278819995, 0.07867055106908083, 0.011419735033996403, 0.06205813427056585, 0.03445509222469159, 0.030405920930206776, 0.0404426616483501, 0.0952469240874052, 0.07842055162681, 0.04235224239528179, 0.09744202558483396, 0.012921478915294366, 0.0396112967947764, 0.04096531342448933, 0.03881704441404768, 0.055975352813090594, 0.04421598131635359, 0.004471675542715404, 0.014719590777531266, 0.049635223379092555, 0.04728804522060922, 0.019769183925486038, 0.04020254506862589, 0.008560508057208998, 0.09586649441293307, 0.04414563419829522, 0.07746520824730396, 0.022290621751121113, 0.05184974115607994, 0.03933771826060755, 0.08779853662209851, 0.033149746911866326, 0.01085340341420046, 0.018832681767110313, 0.014712069216849548, 0.02691927382589451, 0.046505667202706845, 0.0384065273350903, 0.08253609721681901, 0.05064145349232214, 0.019033020927703807, 0.0071407812481213894, 0.034918748773634434, 0.04451841455219047, 0.017965056002140045, 0.03693248464592865, 0.04499830165877938, 0.003969677100290677, 0.03176645828144891, 0.008100224675477614, 0.04477882272164736, 0.027555454688678895, 0.009349244796404881, 0.04130487270387156, 0.041226892066853385, 0.01526502097424652, 0.011158832382144672, 0.052724898659757206, 0.01389411136707557, 0.030513136248503412, 0.018878438776092868, 0.03901028100933347, 0.059461251832544804, 0.022443453282383934, 0.05097755902845945, 0.026496911221849065, 0.05873634573072195, 0.1168298880968775, 0.08388619191412415, 0.03998276757608567, 0.005124504262182329, 0.08297552328024592, 0.03201319057760494, 0.01807730265759996, 0.0068129080380978325, 0.022522628141034926, 0.018395362554916313, 0.012266109930351377, 0.03375976685700672, 0.04849894863686391, 0.05735392562512841, 0.04843944450840354, 0.06405169729675565, 0.023345431579010825, 0.035920938210827966, 0.10911804583988019, 0.018403576221317053, 0.06085211969912052, 0.022276593039610555, 0.013313690815786166, 0.0853798103385738, 0.06109016335436276, 0.05827623791992664, 0.0068803081937533405, 0.02469397921647344, 0.021886599948629737, 0.015537707234865852, 0.028983884557549442, 0.023951130952419977, 0.03189862333238125, 0.05772721488028765, 0.03806988914896335, 0.026452718236084496, 0.04179667488538793, 0.01161438976747117, 0.01321643469522574, 0.016884911372991543, 0.21462804957159928, 0.13572841829487256, 0.0887428130954504, 0.09815294707992248, 0.11054374290896313, 0.09751311569873776, 0.1153581320707287, 0.0838467011760388, 0.22109200486115047, 0.23317893913814, 0.11854423396289349, 0.10978839094085352, 0.10760133686874594, 0.09010229193206344, 0.15600870363414288, 0.11781019477971963, 0.1645302620849439, 0.15968906400459154, 0.12407909839281014, 0.08939056976565293, 0.04525198554620147, 0.11517420836857387, 0.07165686706347124, 0.2146438458668334, 0.21186080734644616, 0.116416565275618, 0.18356593778090818, 0.13039946210171494, 0.1964649563389165, 0.14753418123083456, 0.19872955339295523, 0.10352689014481646, 0.15055353992751666, 0.16589053480752877, 0.11061786607440029, 0.08922818955034018, 0.19761598243245057, 0.12988275768501417, 0.06240669770964554, 0.13561500795185566, 0.14277877711824008, 0.1355589609593153, 0.08662651665508747, 0.09553625820470707, 0.07637366253350462, 0.15494068951479026, 0.17349479533731937, 0.09184691403061152, 0.16434583626687527, 0.11868421573724065, 0.09363201752837215, 0.15648864502353327, 0.11216681902962071, 0.08613358132008996, 0.10061429214796849, 0.1469774568187339, 0.1149808666003602, 0.23869035339781217, 0.148151444537299, 0.19265362513916834, 0.11880716628261975, 0.29404819863183157, 0.14245397597551346, 0.08084703356559787, 0.1367764292018754, 0.12535664412592137, 0.10534395264195544, 0.1560919327395303, 0.10542758208300386, 0.12527042946645192, 0.23485299359474862, 0.08253242634236813, 0.12994804632450851, 0.1487849655428103, 0.12768042300428661, 0.21435841332588876, 0.17039903359753744, 0.11779864611370222, 0.11883787677756377, 0.18744433538189956, 0.12008174003234931, 0.11606739115502153, 0.16476118112249033, 0.18585102659251007, 0.12453724523740155, 0.14508422198040144, 0.12302868547184126, 0.18641566272292817, 0.1286469961383513, 0.11822841662381377, 0.16195104191345827, 0.11956122224884373, 0.05402475462428161, 0.1988488127078329, 0.0820555587166122, 0.16187349893152714, 0.09564229965742145, 0.11506664699741773, 0.1190715099551848, 0.17064141987689904, 0.1402189630482878, 0.0787422043670501, 0.08784931818289415, 0.13237560034862586, 0.1856532743466752, 0.19035507419279643, 0.1415797650281872, 0.34329594458852497, 0.14360052373792442, 0.1528041727308716, 0.12420441024005413, 0.10308367107063532, 0.13405004835554532, 0.11069453374615737, 0.13505114535135881, 0.16875919087656907, 0.12709776498377323, 0.0883794372369136, 0.09997691706355129, 0.12113507065389838, 0.09455768178616251, 0.07189548747347933, 0.1370889488607645, 0.10695973451116256, 0.11658427199082715, 0.07942609981234584, 0.12397870235145092, 0.11101689894816705, 0.09293411712029151, 0.10314995037125689, 0.1223980685962098, 0.20620308736605303, 0.14392584056726523, 0.10753070137330464, 0.09524237111743007, 0.09371986745723657, 0.17586734731282505, 0.16703843963997705, 0.07920071762055159, 0.17274272069334984, 0.11398793916617121, 0.07963010136570249, 0.1675108221492597, 0.07655629701912403, 0.1903957455818142, 0.163713699472802, 0.13510404394141265, 0.16227901860007218, 0.1466290969401598, 0.2763752926673208, 0.1155559385993651, 0.2040201723575592, 0.14997374532478197, 0.13234407561165945, 0.2029175665229559, 0.18845411762595177, 0.07584477162786893, 0.18488663834120544, 0.15162130977426255, 0.2897218322115285, 0.12298616846757275, 0.11132945253380708, 0.08931284357926675, 0.1694660343761955, 0.11842888300972325, 0.1284559749599014, 0.1371657590248755, 0.132577545940876, 0.12062407950205462, 0.18066601481820854, 0.12312031484075955, 0.10624222444104296, 0.09637585708073207, 0.13481542228588037, 0.09884501208684274, 0.12229976244270802], [0.02097343260954533, 0.02877418670271124, 0.07408851265375103, 0.041547781455197504, 0.0111451760167256, 0.029308848548680544, 0.032059388634349616, 0.01623601815663278, 0.005717602816210794, 0.07531049315418516, 0.03332380471485002, 0.03328829697732415, 0.04763758575011577, 0.0038312462025455064, 0.014431807112747004, 0.048114646758352, 0.04794955240296466, 0.030300625866012912, 0.024153461613293205, 0.03827985841780901, 0.022036500208612, 0.010295195554915284, 0.043169320694037845, 0.05720593713756118, 0.04614209456901465, 0.03692382314641561, 0.04671688497598682, 0.025585596283365573, 0.06390234495380095, 0.10859294794499874, 0.026142017051045383, 0.02012783209128039, 0.03219330091295498, 0.050134849069373946, 0.05108487612700888, 0.04161093270938311, 0.04822969576343894, 0.028795238251664808, 0.036472638071115525, 0.05024639004841447, 0.03993895796260663, 0.006770659903330463, 0.03621060141761388, 0.025269169959106615, 0.06031781408403601, 0.003277634993927287, 0.07751424597310168, 0.03524913086688944, 0.07239581205482994, 0.0520549403237445, 0.04284370530928884, 0.03947882640308567, 0.021556365436741283, 0.07334442436695099, 0.04390008594574673, 0.0028346478939056396, 0.03507401454927666, 0.03151580744556018, 0.0333331006446055, 0.009555795945094099, 0.060225702955254486, 0.038962003242756636, 0.052647128368594816, 0.05735568981617689, 0.01106498929272805, 0.0158908609633467, 0.05072449939325452, 0.03779632418549486, 0.016064426828441874, 0.06313043673123632, 0.015098301527489508, 0.04883681157869952, 0.028966853328581368, 0.07249283577714648, 0.0788557097049696, 0.13380015747887747, 0.028358107332938483, 0.08228928688913584, 0.03503822521971805, 0.016473471486408795, 0.0712968838800277, 0.11902766302227974, 0.0524264416391296, 0.045094534887799194, 0.08340950070747308, 0.06296220075871263, 0.030682488411132778, 0.050375444016286304, 0.10622886408652578, 0.04542731560234513, 0.04322493342416627, 0.04282164952850767, 0.07989103200712375, 0.026657852942922285, 0.025299027196264694, 0.04900076599525554, 0.03990971988865307, 0.022147466129224216, 0.1091628766485623, 0.05384376897875752, 0.08099116118890898, 0.035861199987786155, 0.030057530517556837, 0.07548968746726002, 0.09023743575172764, 0.04048052729506578, 0.0756527055054903, 0.06672418210655451, 0.04727464076131582, 0.01996027465377535, 0.0573996656707355, 0.012481058798065143, 0.03470036906323262, 0.02034224915717329, 0.011421060721789087, 0.020581049378961325, 0.0317487926222384, 0.06772008152412516, 0.06690452314381089, 0.03284509486651846, 0.10602097452751227, 0.04568423270913107, 0.05492800687040601, 0.015654243927981173, 0.026152647998450056, 0.07410285688404526, 0.023184321920520494, 0.03423448691942862, 0.02509589077505682, 0.03669056316305484, 0.014683811625997936, 0.07223292972360339, 0.02113185526936182, 0.031072544266602824, 0.0561940378642508, 0.05391406859936459, 0.024584197339468768, 0.05548276013827749, 0.06271615039025034, 0.03823462048811572, 0.037920401099004915, 0.059687556831964424, 0.08779236873877899, 0.03250718103455646, 0.0386257111094892, 0.02009231926474188, 0.05865356445844684, 0.03218964360920446, 0.01807817118242383, 0.07642441016754933, 0.04776720290205308, 0.022200507211631963, 0.020940864624987756, 0.04787907297057765, 0.03778124035203031, 0.04620078784812774, 0.024492791887106638, 0.0210383616254798, 0.020590408073206033, 0.0102863762960104, 0.03057993802108935, 0.036050039676151106, 0.052610083749251704, 0.03750979241782001, 0.027777817399640168, 0.00575231369917414, 0.034145605617335865, 0.037918324781847854, 0.028403906750359705, 0.013888113965679492, 0.04312220661501799, 0.01170547800471208, 0.0369250343314239, 0.04868749316249575, 0.0219781631603837, 0.0493267036841384, 0.03177701967901417, 0.03718026188601341, 0.0419798284502966, 0.0634276486401047, 0.07844736733074699, 0.016382313699328473, 0.05557741916605404, 0.01717975689098239, 0.028704151710761443, 0.026964055440787758, 0.009935040193210756, 0.03740819197680269, 0.011268480248483164, 0.04774466536140867, 0.014218591053837111, 0.022797636687755585, 0.048552746285817454, 0.0901719978345292, 0.023677822135921036, 0.04264181739251528, 0.06516570251967226, 0.0036932940960728695, 0.018542239941390495, 0.05117433079119239, 0.03455715746219669, 0.037767540730003796, 0.03625882490138922, 0.00519886109811653, 0.02405271782273693, 0.049131631651627164, 0.022148008957239132, 0.038214020164949555, 0.025621188837768774, 0.04373953777498432, 0.0088872167315068, 0.02059645382022219, 0.08390451914497785, 0.0348542031299855, 0.035736254549452236, 0.06028814174767051, 0.04846792262313621, 0.02410285477526486, 0.03730731078290513, 0.023520110241536583, 0.004278630209487996, 0.02618791994505695, 0.016277834573494535, 0.06143964960106781, 0.07869886633540903, 0.02474419928954116, 0.019429229399455444, 0.03383712663448282, 0.017246173594945242, 0.03240952966734767, 0.023494425994743193, 0.03878839327288525, 0.03750764485448599, 0.09054951436285462, 0.060945866097296984, 0.027996236125805547, 0.018699558285464133, 0.03746565032218184, 0.07470095157623291, 0.05083970785407083, 0.056228079966136386, 0.011454361524166805, 0.07358814736029931, 0.027251087628038864, 0.020521166967228055, 0.030967629182019403, 0.03350487517725144, 0.014964942254924347, 0.027207279710897377, 0.07301764190196991, 0.0625182149399604, 0.06071615485208375, 0.08794896783573286, 0.06913761581693377, 0.03486716654151678, 0.09341800758349043, 0.023774825502187014, 0.028088706878146956, 0.050033228272306066, 0.04992359397666795, 0.03505040831597788, 0.053139792289584875, 0.060967680998146534, 0.03351908030786684, 0.06917667907795735, 0.013390928456958915, 0.05698799168957131, 0.04510647710412741, 0.019146480464509556, 0.02967744573418583, 0.06124273195330586, 0.048539630203906975, 0.0494545702157276, 0.04155237174459866, 0.05993765126913786, 0.05056616324665291, 0.019350631295570304, 0.03374348540923425, 0.04918217233249119, 0.05051553435623646, 0.0586766821465322, 0.06675601896962949, 0.04160550103655883, 0.024730294410671507, 0.06431908759155444, 0.07358199983303036, 0.027064363272594552, 0.014330869939710413, 0.033778189082763026, 0.005238046071359089, 0.01628405673961554, 0.04544762076277818, 0.039106012122439485, 0.045924420535032234, 0.03102234624592321, 0.06954769524080412, 0.019566736217322092, 0.11448617385966436, 0.010017746826633811, 0.030007939785718918, 0.05250578952421035, 0.019752692131857787, 0.005590234159691525, 0.02069268874557955, 0.05427572097895401, 0.02352298383734056, 0.018061625105994086, 0.02171328683782901, 0.015811528345303874, 0.008784009858832827, 0.020685014514518634, 0.03823209633784635, 0.03089440507548196, 0.07432399144662277, 0.02645976821492825, 0.007074114334370408, 0.06398457661271095, 0.019107498627688204, 0.05819930561951228, 0.0469722278815295, 0.010032170784792729, 0.06621373378272567, 0.06803128482507807, 0.026315706748781458, 0.0811603878225599, 0.08199364918151072, 0.06873551596488271, 0.05038868223450013, 0.014274979010224342, 0.03912148272086467, 0.015356709714978933, 0.007083624426741153, 0.01911685223292027, 0.025308004214561412, 0.018913646261872988, 0.009129848979812647, 0.02824096504731902, 0.03484121596972857, 0.046027337333985736, 0.016611439708088125, 0.01803525384249432, 0.02676586214719074, 0.022683846365128244, 0.023879131601591195, 0.032088969368487597, 0.0034216548998041874, 0.008102552898760353, 0.02343033836223185, 0.05068206042051315, 0.07336381689778396, 0.044983791187405586, 0.02748097529235695, 0.07841107927794967, 0.1923483929463795, 0.1464169461812292, 0.13196515451584542, 0.14379575183348997, 0.17178224080375262, 0.1888169167297227, 0.11329301074147224, 0.09271592739969492, 0.20627297647297382, 0.10138838525329318, 0.10654384682753257, 0.10529714729636908, 0.16537783374743803, 0.11383652407675982, 0.1341371993933405, 0.1282326148024627, 0.16799840384296008, 0.15054678171873093, 0.13990518131426402, 0.12886671934809002, 0.09456293364720685, 0.09723208685006414, 0.1512102668306657, 0.10535909075822149, 0.21729173378220626, 0.16723984240421227, 0.12531785906425544, 0.08701939521623508, 0.1243677879018443, 0.05833708215504885, 0.0922096384955304, 0.14295416484986032, 0.13210246286221913, 0.10485214367508888, 0.1452879724758012, 0.146360505638378, 0.11505916954151221, 0.19988124445080757, 0.1717102618089744, 0.09301111048885755, 0.11840801127254963, 0.07297158294490405, 0.09716321554567132, 0.07737520057708025, 0.11078671951379095, 0.14800063334405422, 0.14080254387642654, 0.12512051393943174, 0.1393964428986822, 0.13124883866735867, 0.06520165809031044, 0.06857474387756415, 0.11782631677176271, 0.1540191439645631, 0.11133620395724263, 0.09690161315458161, 0.16752779909542628, 0.14676340616175107, 0.18135189158575876, 0.12110250097300325, 0.17334649472364358, 0.1406475529074669, 0.1288629738347871, 0.10970964016658918, 0.07948562090418168, 0.2569635457226208, 0.1753049503479685, 0.15327465534210205, 0.16040067082004889, 0.14878246853394167, 0.13990193791687489, 0.12262737272041184, 0.18748174980282784, 0.19116103808794702, 0.2641290926507541, 0.20861048890011652, 0.17537279027913297, 0.14032537090991223, 0.14370104191558702, 0.21990235655435494, 0.18473024959010736, 0.11009500734508038, 0.1837082944278206, 0.1318158632410424, 0.1452138085982629, 0.19066523254982062, 0.16003806170608315, 0.2372324801981449, 0.1099680263016905, 0.17774796139981064, 0.14756225900990622, 0.1107379464166505, 0.11897245741316251, 0.13483184283333166, 0.12710461818746158, 0.1773742243115391, 0.10610926550413881, 0.18636990232127054, 0.13586913288703986, 0.24468409749014036, 0.13438258479748452, 0.06575703900307417, 0.12046847785157816, 0.2004789523780346, 0.18288827128708363, 0.1460467917578561, 0.14533814335508005, 0.15431696655494825, 0.1473223018859114, 0.11794782882290226, 0.0692538149388773, 0.0870899764288749, 0.09117871310029711, 0.15291505892361912, 0.14571346821529524, 0.158734175243548, 0.16940218423094067, 0.12559968179890088, 0.18523408898285457, 0.16567756980657578, 0.2300548553466797, 0.15584823010223253, 0.12463899834879807, 0.17192174760358675, 0.0990500110866768, 0.0718181412667036, 0.19713519965963705, 0.12081581992762429, 0.109670773680721, 0.08709997803504978, 0.13697872763233526, 0.10733008570969105, 0.12024549767374992, 0.1738178458596979, 0.1130387568846345, 0.10051205727670874, 0.16702348472816603, 0.14829099204923424, 0.08531769045761653, 0.18711648083158902, 0.14338588954082557, 0.17032714959766182, 0.19021691089229925, 0.1190293865012271, 0.10359507612884045, 0.11114452459982463, 0.0683329886357699, 0.1280881818383932, 0.22455836885741778, 0.18344215942280634, 0.1216973861945527, 0.0774448046992932, 0.13012413973254816, 0.08960282230483634, 0.17554950793938978, 0.12769672141543456, 0.10627217497676611, 0.09984265533941132, 0.1388793992144721, 0.09919648644115243, 0.11956678623599665, 0.16224745315100464, 0.10395659280142613, 0.10061600205621549, 0.09615783020853996, 0.10151122723306928, 0.12033635351274695, 0.09869340700762612, 0.15564036768461975, 0.09406284655311278, 0.17053425205605371, 0.1903116208102022, 0.09579272408570562, 0.08620758913457394, 0.09965338478130953], [0.08220967437539782, 0.0939964654722384, 0.09086156583258084, 0.01223944265594972, 0.08386829894568239, 0.027446599011974673, 0.020333477395719717, 0.09018462537122623, 0.06004813712622438, 0.07225167764616863, 0.045040547249040434, 0.03868668426626495, 0.05504606857097574, 0.08114036425415959, 0.06817292901022093, 0.028289222457845296, 0.04988355362521751, 0.05356639064848423, 0.02111150261147746, 0.0593002490433199, 0.044703230527894836, 0.03253896700750504, 0.04602237045764923, 0.01745408520634685, 0.055183217461620054, 0.007494003678272877, 0.012170376272739043, 0.05132943032575505, 0.040024222673049996, 0.03719767648726702, 0.052264763707561154, 0.09512715587126357, 0.08870498476816074, 0.07043416053056717, 0.03624798530446632, 0.03535981010645628, 0.029684482142329216, 0.08249785498316799, 0.07215028415833201, 0.013128539813416345, 0.05156080398176398, 0.06559163252157824, 0.018503122397565415, 0.041829485446214676, 0.0342150163570685, 0.0354970064945519, 0.0160091906852488, 0.013378486669223224, 0.05200302560946771, 0.03156094698767577, 0.033814422852758846, 0.0378851647754865, 0.035377848959927044, 0.07588169750358377, 0.03387222385832241, 0.016390291574810232, 0.024507171740489345, 0.03767075449494379, 0.06701692925500018, 0.027521928273407475, 0.016276955870645385, 0.03432769727494035, 0.03537081255178366, 0.023831281312076107, 0.03941528499126434, 0.054836625166769536, 0.021660601986306052, 0.045562676553215296, 0.018768728145265152, 0.022551489628053138, 0.10300975146570376, 0.0519372619954603, 0.024663212742390375, 0.02166997085857604, 0.04976295081100293, 0.058207414112985134, 0.12338931326355253, 0.047026093383984904, 0.07314464330141034, 0.03855940466746688, 0.044215390990887365, 0.018733444324295436, 0.06958953371005398, 0.037482610304972956, 0.06431234295346908, 0.0218690971378237, 0.06034004967659712, 0.04850539471954107, 0.03274170309305191, 0.06825195798384291, 0.04767464394015925, 0.016131696790190678, 0.05541778023221663, 0.07012155266212565, 0.051086053385266235, 0.04172642615490726, 0.037942928461624045, 0.07921661569603852, 0.042913496028631926, 0.0685183440468141, 0.030523555153714757, 0.0769438830071262, 0.043787622159080844, 0.05572229657056076, 0.029870092004005398, 0.014432687511933702, 0.02383442292921245, 0.05043552150683744, 0.02665756456553936, 0.009370408303636526, 0.03550621760743005, 0.05489627518025892, 0.056503168240721734, 0.02430274271007095, 0.03038832312449813, 0.04612194547163589, 0.02616520089629505, 0.033889960763709884, 0.026998667512089014, 0.034360830139900954, 0.010036912896404309, 0.01624255414519991, 0.014315874315798283, 0.018744438287935088, 0.02368721814959177, 0.06304151471704245, 0.04621586150356701, 0.06819702378873314, 0.0377424858244402, 0.07481686571346861, 0.046150376088917255, 0.020967524265870452, 0.02031833927945367, 0.037759554372834306, 0.015784398818920766, 0.03254030032881668, 0.034181856350707154, 0.055885596200823784, 0.019399694466431226, 0.06622751482895442, 0.04279824685571449, 0.034204288718423674, 0.011253324320672877, 0.06452419515699148, 0.008474548696540296, 0.026329401281795332, 0.022104083992806927, 0.039381236104028564, 0.035578793713024685, 0.04861647429476891, 0.02288233651779592, 0.004798463944877897, 0.024166404668773924, 0.06152322475931474, 0.02251843479461968, 0.024520939216017723, 0.028932475351861546, 0.05725190109972443, 0.017886537626119595, 0.0496490078179964, 0.012191064805457634, 0.03767612509961639, 0.024126588233879635, 0.06170724345637219, 0.016502243067537035, 0.03146571459780846, 0.0356358652934432, 0.02382331870363227, 0.015764795942232013, 0.040909334285450835, 0.016663200055648173, 0.011463841506546097, 0.022861108549737504, 0.051738983884985955, 0.05143972619303635, 0.02593999681994319, 0.039893268807125945, 0.050494313173528226, 0.03870140847616962, 0.04376383272132703, 0.06280940824321338, 0.019875836059717194, 0.0343336989171803, 0.044357455867741785, 0.02014835099024432, 0.07945312586213861, 0.024293658822508793, 0.01724349507795913, 0.058387381955981255, 0.13225889232541832, 0.03087961979742561, 0.023555692617914507, 0.011254528720330979, 0.010033072388198758, 0.027101256917896013, 0.04848744407562273, 0.017672909357185875, 0.04255960608965584, 0.06798907316156796, 0.060633543213563304, 0.021735651352043663, 0.01051894502182092, 0.015008692496589251, 0.06636250937091452, 0.00919011900467532, 0.05256497474121196, 0.03489518664511187, 0.02318455940777702, 0.025721299894420162, 0.03818340127223304, 0.010441445296497216, 0.02027720818296075, 0.10853883477726153, 0.05977035846029009, 0.013071578494938356, 0.020669576146506836, 0.015815757314807603, 0.027098159405535886, 0.011266503167072577, 0.02478731340462608, 0.018017130172146217, 0.010181510405215834, 0.01950994792527386, 0.03789906456534352, 0.07800991580422435, 0.03642928986144917, 0.03241132439247199, 0.01136043616237917, 0.02165500576873975, 0.028126177278214266, 0.05379128768774016, 0.08506579790264368, 0.047850387902664285, 0.057664613239467144, 0.064258962603552, 0.029466536694339344, 0.03848281841991203, 0.023572125039728622, 0.012655259093402751, 0.02655237976328603, 0.052341241389513016, 0.043748168740421534, 0.08758920856884547, 0.024011939564453702, 0.048814504739961455, 0.017662475184936608, 0.027709356608933637, 0.047232273034751415, 0.014697209299941148, 0.004807135198331837, 0.042708269719566615, 0.03203329896288259, 0.020773425931110978, 0.07406698952295951, 0.07928624695965222, 0.027948363783902357, 0.08720816365842309, 0.07066938148013183, 0.008913674508221447, 0.03801828656079514, 0.0641097052554999, 0.05258725443854928, 0.06204286044729607, 0.018660308427310417, 0.053114700064595254, 0.03980671488014715, 0.048057391973478455, 0.009053571465691286, 0.023381309118121862, 0.053993715039853535, 0.061459428896861415, 0.05436459888837167, 0.01852778544915574, 0.025111593771725893, 0.12955368177167007, 0.10899314111364738, 0.06726337317377329, 0.05513210681134036, 0.03515411221555301, 0.05228744713323457, 0.058786265552043915, 0.05736528430134058, 0.04802540583269937, 0.04584895387025816, 0.04544574461345162, 0.08225365701530661, 0.005222220090217888, 0.08569860644638538, 0.041649982399706326, 0.04362310116578426, 0.07553436221288783, 0.03696413151919842, 0.014128518074617853, 0.01614711480215192, 0.05063059014667358, 0.04617195689518537, 0.028672328418386833, 0.0323706563961293, 0.03930886695161462, 0.02204810655010598, 0.013180479124587561, 0.054171233371432335, 0.046208316194159646, 0.012763469313670481, 0.02708405435883573, 0.0609379272375788, 0.06329563286687646, 0.021569179570568458, 0.008606549202730613, 0.03742125377591167, 0.0056123471918648905, 0.02033080566408379, 0.027617338778717176, 0.004566825236127312, 0.05842003306107862, 0.032009404352200885, 0.033132698719522784, 0.02068673460079091, 0.04523124612335648, 0.04266351694241166, 0.028796015174261162, 0.025926470224346434, 0.029370330606720278, 0.05063863417931965, 0.026184186306116835, 0.09733942430466413, 0.05982121465993779, 0.06206994077989033, 0.04934614371242268, 0.08109892612057072, 0.0136374207213521, 0.031426939714167795, 0.07657163191054549, 0.017146152444183826, 0.0420426336516227, 0.01296338438987732, 0.023824443375425677, 0.03451830115435379, 0.045622258713202815, 0.06066324269132955, 0.055569517625761886, 0.03772438929549285, 0.0737068367057613, 0.040721006891024966, 0.030437011404761245, 0.06322659871407918, 0.021472907325785075, 0.024203673204673187, 0.007528454597507204, 0.0165231453387865, 0.0384131532295474, 0.038536293764731715, 0.15960861689278058, 0.14945044554769993, 0.1758440871323858, 0.1313105717833553, 0.14881624600717, 0.10256830336792128, 0.09322927985340357, 0.11708721571734973, 0.23126576894095965, 0.1350786124489137, 0.12739752818431171, 0.13177236914634705, 0.12591427777494701, 0.2163227450634752, 0.11711137156401362, 0.11494194583169051, 0.1208381573004382, 0.1526989048080785, 0.060459227567272525, 0.12801515789968626, 0.0765409010595509, 0.13108783587813377, 0.21586797732327664, 0.13230512770158903, 0.1542899880026068, 0.05630349913345916, 0.0868280144142253, 0.14285820642752306, 0.14462375454604626, 0.208042745079313, 0.09605859446206264, 0.20537691669804709, 0.21612320148519107, 0.1547775561256068, 0.11997773418469088, 0.11164030299655028, 0.15920855264578546, 0.07969277086002485, 0.24449310345309122, 0.10232346757714238, 0.11739627484764371, 0.10974248804684196, 0.11163122419800077, 0.12809222590710434, 0.09655621168868882, 0.07793166714587382, 0.1203241263117109, 0.10921812975513083, 0.2122279762157372, 0.08677512260952167, 0.13703841157257557, 0.14401257091334888, 0.058769817863191874, 0.15955214920852864, 0.09233824802296502, 0.08168048491435391, 0.16905713560325758, 0.13086600920983724, 0.13243223088128225, 0.15110938224409307, 0.10059613455086946, 0.09860251045652799, 0.07997550961694547, 0.16786356536405428, 0.11374057243977274, 0.1580311722521271, 0.14298445465309279, 0.13532578918550695, 0.1726511048951319, 0.15181623931441987, 0.2970872755561556, 0.1450201275625399, 0.13805283499615534, 0.10132969875953027, 0.13035413596246923, 0.1559125552220004, 0.16413120206977638, 0.16499490929501398, 0.3053757165159498, 0.09007476376635687, 0.30910809338092804, 0.2503600429211344, 0.17948663953159535, 0.12938068248331547, 0.13843588158488274, 0.14935621060431004, 0.16115240619650908, 0.06268526347620146, 0.18206512688526086, 0.16520720933164867, 0.09213555604219437, 0.052080772151904445, 0.23341542216283934, 0.16294939762779645, 0.1314992452306407, 0.1677894964814186, 0.08803525713405438, 0.12299429731709616, 0.23768986708351544, 0.2247520498931408, 0.16141353361308575, 0.20812148228287697, 0.16000169222908361, 0.11289156906838928, 0.14545916686100618, 0.19043738049055847, 0.10362910466002566, 0.10348442742334944, 0.16458997316658497, 0.18108952923544816, 0.13659767593656266, 0.13118470353739603, 0.1567277064813035, 0.08804936387709209, 0.21020195207425527, 0.1523647398820945, 0.07557109809879746, 0.08963358708258186, 0.11131153242396456, 0.13979406441961015, 0.15112672559916973, 0.1468050546411957, 0.14329511512603077, 0.08813227407102074, 0.09909410907753877, 0.19541755611343042, 0.10604548999773604, 0.14463826162474497, 0.07335546413170439, 0.17423875470246586, 0.1806237692279475, 0.08992471931768314, 0.08718906968299832, 0.15299271047115326, 0.15483451235507215, 0.07961617104176964, 0.1056989078809108, 0.08347276052726166, 0.10416468592094523, 0.14104167318769864, 0.09062397679580109, 0.12661646652434552, 0.10321696248969861, 0.11745403174843107, 0.10069534994129624, 0.08677487155156476, 0.052693893002080064, 0.19609451693083557, 0.11029652546026877, 0.21747848019003868, 0.11998498093869005, 0.11010737703847033, 0.20119169913232327, 0.15769565025610582, 0.13489839354796068, 0.13434883446565696, 0.12658562032239778, 0.17705289726810797, 0.14463955084128038, 0.10532220559460775, 0.14977152831852436, 0.1639964992978743, 0.2739462730075632, 0.18849683819072588, 0.12416600515799862, 0.10407796914556197, 0.175737557134458, 0.1237446620528187, 0.0894137281658394, 0.14318819157779217, 0.09385219535657338, 0.11097176279872656, 0.06798105966299772, 0.17117200712008135, 0.15914012917450496, 0.15866595533277306], [0.06721130239644221, 0.016146107177649225, 0.045451159322900433, 0.044994545967451165, 0.024852293310686946, 0.02062400403831686, 0.0582924277654716, 0.046934406339590035, 0.017891314512650882, 0.024300140528274432, 0.0535792047823114, 0.056312727209712775, 0.03961540532431432, 0.001925645487582577, 0.05080984213522502, 0.034186572169086764, 0.0217064641682165, 0.015253921837678977, 0.01078653718078775, 0.005588986079341599, 0.036700351030698845, 0.013195775000245442, 0.024902018053191047, 0.010947564566907073, 0.02067842424315001, 0.04585477909339326, 0.046493976044335535, 0.03425151136304651, 0.0461258029432169, 0.027981442366061465, 0.02367743706729795, 0.0187241500908775, 0.04594594705849886, 0.07675052766821214, 0.012443808073710119, 0.021218178494434272, 0.029366622412843362, 0.014062322742704834, 0.012510008494635778, 0.0056684624619915015, 0.044420386598046334, 0.039575836554701836, 0.006272826393667076, 0.06948782131075859, 0.021806320774235895, 0.06623428660844054, 0.0931969815865159, 0.027363525969641547, 0.026387056402329887, 0.007197990231881184, 0.041846489533782005, 0.02747252074602459, 0.020472794205748608, 0.018736636831558177, 0.05804077269775527, 0.032612852685685666, 0.037244871990489106, 0.050425994875175614, 0.054473252700907845, 0.008893203954877598, 0.0036653079192287153, 0.013788264145010283, 0.04041955753096512, 0.001346460188090402, 0.012608612355376993, 0.01867371627927891, 0.033895969191300016, 0.03950625278853944, 0.03706304496154189, 0.05887004427079644, 0.04490796829174672, 0.03769997899819698, 0.03722683313701834, 0.04429743605266724, 0.03145356882097466, 0.08125517916466508, 0.09223578923514911, 0.1291890506233488, 0.04062601198841419, 0.021621413196304014, 0.011104807423959886, 0.07008331721382481, 0.08420131036213466, 0.14441484718450479, 0.1096849347065602, 0.031152024466012205, 0.06086613144725561, 0.033833896807794056, 0.029210871484662806, 0.05416389501520565, 0.10218207444995642, 0.009937584699530686, 0.028028790539662753, 0.034317339437880685, 0.06636100980852332, 0.03655643714591861, 0.04458846650751574, 0.016714025721220032, 0.05670146670724664, 0.1005340146699122, 0.039466266719890494, 0.03739887908367174, 0.028956773690879345, 0.06914970052561589, 0.07810248833681856, 0.04444641520136169, 0.07445695716887712, 0.06635993093784366, 0.04656099494812744, 0.018453601215566908, 0.054986957992826185, 0.04541605870638575, 0.02602997056341597, 0.05032944952004722, 0.07072785084268876, 0.015214334408353482, 0.051896129202629836, 0.010409699187480977, 0.04239726658644421, 0.0076618732418864965, 0.025231609653149332, 0.03478848362075431, 0.07279401033052377, 0.04402220867840307, 0.03849098119618637, 0.034447903146169016, 0.06004778428801468, 0.02537920798308083, 0.0076997846897159305, 0.023384109771411334, 0.03449045746986355, 0.020399485282333832, 0.0492007438359516, 0.0200939901572253, 0.024850517245275632, 0.026902658199625354, 0.06376641403351511, 0.06122563287083592, 0.055799113520021947, 0.013342371642855662, 0.06843911829803671, 0.025094034981780818, 0.008904516829976013, 0.018829346767493656, 0.0010420155200076156, 0.020863440386684876, 0.024671618094933883, 0.03716915426775813, 0.024712411620255028, 0.0508020220191351, 0.03179790159421308, 0.018508226677243198, 0.02033744682557881, 0.024242627900093794, 0.008631053646760327, 0.06729662817503725, 0.05738522644553866, 0.029400698441479887, 0.06129994602607829, 0.05949334653892687, 0.06554298156074115, 0.033990835172257254, 0.05670135814164366, 0.003047559248183721, 0.039008055414472304, 0.034911993957523785, 0.029345258737781217, 0.0576753273074116, 0.037653482386044095, 0.03851224648367081, 0.02765549619549087, 0.015278864784964492, 0.04627005948818155, 0.04027140619499343, 0.036259747709014585, 0.037109650139297755, 0.03122012224048376, 0.03431459476373025, 0.06786834821105003, 0.06069683017475264, 0.0796117741348488, 0.05986206925341061, 0.05016656379614558, 0.06499485418732677, 0.048600620324058194, 0.047419117830161533, 0.04090522236323782, 0.013558593611898167, 0.07842676022223063, 0.056858374537633996, 0.025746982444876006, 0.03768084431067109, 0.028926049625234942, 0.06031896759356771, 0.04100010870024562, 0.04161128554759281, 0.05275586021265813, 0.03454255199592028, 0.053601962846836874, 0.0473174766770431, 0.04981746770707624, 0.04386035432772977, 0.04404168602611337, 0.005975247227719852, 0.011471399538485067, 0.03065184237701552, 0.05797743823911462, 0.0033880256440690054, 0.025225026167130897, 0.059329534614724774, 0.03769453375467232, 0.028249819929312383, 0.009450001309492757, 0.0569575729646853, 0.02713187750695007, 0.022164678866309778, 0.03114661654191358, 0.03158808160307152, 0.016423892628933703, 0.046833986549505165, 0.05210776088227119, 0.02817986296888973, 0.1083344193175435, 0.04757020043741379, 0.03366898226418665, 0.03216097889734166, 0.011503576517238148, 0.08205398451536894, 0.0287792282178998, 0.052008616738021374, 0.046660098380276134, 0.019779311060639362, 0.02917978440278343, 0.05621531332976051, 0.04262406013107725, 0.028556685695158582, 0.0073347124936325205, 0.018267533342753137, 0.04620214491816504, 0.05239433336204716, 0.0676432577893138, 0.06314773937421185, 0.021716576036331908, 0.012583010380954614, 0.055650741660169194, 0.048174137316112, 0.05599912528746894, 0.09897522974227156, 0.05067840650943773, 0.01192970244613077, 0.020172321936115623, 0.03795765606420381, 0.0267411583834993, 0.05971602816134691, 0.07786303332873754, 0.09055415554238216, 0.04465548201863255, 0.0657902057947857, 0.11699982040694781, 0.05086071869092328, 0.01374292273872665, 0.021133639816460863, 0.030264904389956167, 0.041173335297831466, 0.03744949779606291, 0.03826365500156369, 0.07344051849629198, 0.03438046355066555, 0.05142474413982459, 0.03787811140396765, 0.05445004001791988, 0.03852240754557507, 0.04085827452529754, 0.05304027155839971, 0.061610084027051926, 0.0803837434255651, 0.0387513690095927, 0.03985376449834023, 0.026370875038472668, 0.09015046113303729, 0.06044398767075368, 0.02019503928853997, 0.027874937813196863, 0.03459011730072754, 0.05701986926474741, 0.050199435425124, 0.03262290518198695, 0.026407926443165967, 0.02789310728465872, 0.03546094914366092, 0.04417929292789527, 0.024119794402005415, 0.023733131221628616, 0.02820809681101569, 0.046468100111399374, 0.02125798984031592, 0.018915351081107343, 0.0743034454062581, 0.02781344557713185, 0.02339884076666619, 0.02357760421000421, 0.028960342785077434, 0.04089903751654284, 0.0295306175415005, 0.04467678123286792, 0.023700960180056945, 0.03681409385587488, 0.057343869736152034, 0.004769790751327361, 0.010361245001799293, 0.012711190734989941, 0.03491559697847281, 0.02557432072769318, 0.09232249243983201, 0.01684558348331068, 0.01789161985340927, 0.04863869631662965, 0.01313896126313401, 0.055449260864406824, 0.02763587126641401, 0.07766215303646666, 0.020006835726755004, 0.02179214108868369, 0.03991494121562157, 0.03297176717647484, 0.051586964899407964, 0.030215042244110788, 0.03039332732026066, 0.029620645567774773, 0.01953386458834367, 0.016740230743640235, 0.02041698639680232, 0.03974870013605271, 0.05212779802137187, 0.018076707243121097, 0.05385172140917607, 0.007911586003111941, 0.02586070491400148, 0.05387959223506706, 0.05494014246921454, 0.03173502175403493, 0.023647764730932455, 0.025710319501480887, 0.048084102504487546, 0.03453289304992982, 0.008748450383011783, 0.0031998301398873863, 0.06195140749748264, 0.04412754445469805, 0.02256242252354111, 0.03695825879861202, 0.025682472424315553, 0.11853472090193204, 0.08983920354928289, 0.11729680161390986, 0.10806760577751057, 0.11869203246065549, 0.15252336779875414, 0.1782034890992301, 0.15603106814835752, 0.07935907412320375, 0.13215344798352036, 0.1580105447875602, 0.1437096321689231, 0.16286620923451015, 0.12558889309210436, 0.13121690680938108, 0.16752321219870023, 0.07984127503420625, 0.1183691176452807, 0.0851390864700079, 0.172701574329819, 0.2142223941960505, 0.09660363450114216, 0.09096879472157784, 0.192668457914676, 0.10476612579077482, 0.1383894562189068, 0.08680776014391865, 0.1867015566676855, 0.1005648880132607, 0.09504252898373775, 0.12610140416238988, 0.08127853434000697, 0.27271182781883646, 0.17684104506458553, 0.09627519641071558, 0.09526960751307861, 0.06035870260425976, 0.14396774689001696, 0.08598163018801383, 0.10312855616211891, 0.14520732180348464, 0.17414158848779543, 0.15415411815047264, 0.14677674616021769, 0.1648162645953042, 0.13214302568563394, 0.2724111010985715, 0.1760091475610222, 0.1728895285299846, 0.16879048491162912, 0.1123719537364585, 0.14844120613166265, 0.16537938080728054, 0.1041590269388897, 0.1517688368580171, 0.11661726236343384, 0.27313363232782906, 0.19259638392499515, 0.08602179267576762, 0.11576906644872256, 0.08848450159920113, 0.06855274577225957, 0.14677004223423346, 0.19660514167376927, 0.10820903283144746, 0.15558137585009846, 0.14982287984873566, 0.13806336585964474, 0.19626425925110066, 0.1952849839414869, 0.2274026112364871, 0.22810946830681392, 0.20700014888175897, 0.10242276439177138, 0.17852306552231312, 0.25190501287579536, 0.13417203538119793, 0.25704605558088844, 0.21932115059878143, 0.20188966739390576, 0.15478877909481525, 0.20405724751097815, 0.21600813551672868, 0.2766383471233504, 0.16186853205519064, 0.08455306970115219, 0.11521804173077856, 0.23493726764406475, 0.1879801880568266, 0.10180627461522818, 0.16958362449492725, 0.09636087502752032, 0.17979769355484418, 0.07774303441068955, 0.3303166281964098, 0.09440731842603002, 0.15275063631790026, 0.12559319500412258, 0.13281469392989362, 0.2157137327428375, 0.14795032675777162, 0.21254738979041576, 0.11856807768344879, 0.15296022221446037, 0.19953971063452108, 0.18527212765599999, 0.0911891625395843, 0.08700735800500427, 0.17241437759782585, 0.21097302569874696, 0.12108709822807993, 0.11844485572406224, 0.10785107846770968, 0.100209301736738, 0.13857289137584822, 0.09070063768220799, 0.1283758535448994, 0.12508983058588846, 0.1914326420852116, 0.13527431551899227, 0.08068400195666722, 0.20138855571193354, 0.13666832500270434, 0.11800319728042398, 0.09978795863155808, 0.15693324830915245, 0.1428801773914269, 0.08683066748614822, 0.13335772550531796, 0.12333868098046098, 0.13685247940676554, 0.097787399909326, 0.08392172000770058, 0.059948826740894995, 0.053408882314605374, 0.1321329969380583, 0.1028505875063794, 0.28881995060614174, 0.13109471622322286, 0.0905415890738368, 0.1318139090601887, 0.09637817767049585, 0.1460336417491947, 0.1519171374716929, 0.14251321208264145, 0.0817932981465544, 0.11067755001464061, 0.10231736076197454, 0.10253436304628849, 0.12275062182119914, 0.2213345675596169, 0.09967755419867379, 0.12971483383859905, 0.11207926765616451, 0.09174327459186316, 0.17651480542761938, 0.1082349664398602, 0.11890752161187784, 0.09676425052540642, 0.1630142791462796, 0.1461305772619588, 0.17229247199637548, 0.1494345949696643, 0.06451557097690445, 0.13704352772661618, 0.10786821826228074, 0.05208610204447593, 0.14354439532118185, 0.23247964094792092, 0.10207844858190843, 0.07666733248957566, 0.13943121103303774, 0.0712155071752412, 0.14763602933713368, 0.08222423573689801, 0.15497678757778235], [0.024436324202854718, 0.04044615271102105, 0.02815156975494964, 0.014443538983219435, 0.048633156078202386, 0.018611435246254717, 0.022976559586822987, 0.026629773467513065, 0.030841971281915903, 0.0027305228785345598, 0.09732126670756511, 0.05707888824066945, 0.02594658200229917, 0.026953409226345162, 0.052843167313507626, 0.06301674818886177, 0.04788016541195767, 0.023060965950467756, 0.02354037299353097, 0.03811915418399232, 0.047017323318868876, 0.04096991049924067, 0.009318596217781305, 0.015603562451100774, 0.030201166202979426, 0.06452654967350618, 0.06112060243529933, 0.03977018594741821, 0.05202058609575033, 0.009732729040219315, 0.027441594816212143, 0.025080476155770675, 0.015961335306721072, 0.025109680302973305, 0.06889437458344869, 0.0075248532728957275, 0.05458616432068603, 0.04254344677818673, 0.07307915788676057, 0.025072737463882992, 0.07305031336311783, 0.012598044172461544, 0.0691698326596192, 0.026832845427894166, 0.04171258743320193, 0.03476093849167228, 0.02515329823030957, 0.011191499602448727, 0.0451032167433628, 0.04660901487139719, 0.019679496863058636, 0.04118916551981654, 0.08201562693076474, 0.040038064787430425, 0.03254533845133015, 0.02563821497772421, 0.037911010174346824, 0.02236471777515752, 0.05411709984764457, 0.06071327107825449, 0.01422235946769693, 0.012580536272642868, 0.021621547206970196, 0.058394208018268855, 0.049589201741452725, 0.01803290780766734, 0.026798380937959467, 0.05877493401723249, 0.0179817445709237, 0.05147433147898742, 0.06944311263837985, 0.04475138955084341, 0.027894169191962907, 0.05866366784487452, 0.047909450983362536, 0.05114609694906643, 0.10846538336149283, 0.10524915451450007, 0.010233779654039868, 0.08282861366335835, 0.04945310458008732, 0.18610943986901216, 0.07543327406580959, 0.01946788214679275, 0.08131171470241887, 0.07164008689246007, 0.04975369220067348, 0.05836201831698418, 0.10041034487741334, 0.07453798782080412, 0.0709729241207242, 0.04243212632302727, 0.010930924343743494, 0.025514528221849884, 0.007194997044280171, 0.0488681497185358, 0.030058962226446186, 0.02832993625530175, 0.06153573015970843, 0.1371702237852982, 0.06724677620721714, 0.04658125261110919, 0.038261531186955314, 0.015331169656877006, 0.03435178866077747, 0.0767170080382909, 0.031425294266747575, 0.09096670483372041, 0.006252620044896113, 0.04260750048394714, 0.018448060977139642, 0.06708008050918579, 0.058880324076328955, 0.023601619260651723, 0.04147752933204174, 0.013268865096116704, 0.020171144677858268, 0.05546160341639604, 0.05318046367860266, 0.09117275556283337, 0.06261876025902373, 0.05147301172837615, 0.022391377416040217, 0.04737808681758387, 0.012554955502439822, 0.023590859391593506, 0.037401060573756695, 0.011026010000413018, 0.04169665203828897, 0.00699311464060364, 0.03148655240823116, 0.05916300176509789, 0.022973658849618266, 0.019383041520736048, 0.08775568035032068, 0.04190540672945125, 0.041123775100069385, 0.02640194176430149, 0.009337948036513158, 0.026199890999123454, 0.04359607172331639, 0.036436292342841625, 0.04543575657797711, 0.07989118128482785, 0.04345147930351751, 0.05636631451281054, 0.016153160549168075, 0.07447959309709923, 0.037803442017840486, 0.05306378618947097, 0.040312505061072965, 0.05602975435821073, 0.07627255403037582, 0.047071551837559254, 0.07037546725145408, 0.030411467953984226, 0.03399345092475414, 0.06250246614217758, 0.010759229538962245, 0.018976700824818442, 0.08067907579243183, 0.055481589665370326, 0.029138152886714255, 0.020757220818528106, 0.0663158329469817, 0.021930317959881256, 0.03464111938540425, 0.01755880012309977, 0.07421678969902651, 0.02812433335930109, 0.04976448430014508, 0.01921918718809528, 0.030091131571680307, 0.04902275392253484, 0.006048126977735332, 0.013666768209077418, 0.046414414420723915, 0.039991724238331826, 0.06586423396532025, 0.053623550438455174, 0.01678248990460166, 0.011146409254121994, 0.01681873724529786, 0.027065114750127708, 0.06488247521753822, 0.009004200409565653, 0.0441972537498389, 0.0369350223668984, 0.04772017363991056, 0.07037713644759995, 0.02227227246787931, 0.027789494987311106, 0.024056037555315664, 0.013282917556352913, 0.022069404068003808, 0.019704738365752355, 0.045740768246884854, 0.09385564231446811, 0.017635440653456107, 0.04102255463866251, 0.05014946471367564, 0.014843696528779609, 0.028865721076726913, 0.03222557882379208, 0.06512565538287163, 0.022507366192127978, 0.04458425280504993, 0.011407663047845875, 0.037034672019737105, 0.054443953558802605, 0.03836667697344508, 0.016548434338931526, 0.034429080584751706, 0.046101362111845186, 0.028579827131969587, 0.02699954282226307, 0.06731007673910686, 0.01983494753949344, 0.07016949794654335, 0.06303325016051531, 0.006307095804783914, 0.020437585023630942, 0.018742053237344538, 0.004600335960276425, 0.03395006539566176, 0.05120286997407675, 0.03597093267100198, 0.015774473547935486, 0.04718973567443235, 0.05426672360460673, 0.02811980413805161, 0.031875078167234144, 0.055600085628351996, 0.04261019426797118, 0.019097225607505867, 0.04173209870766316, 0.05268651732642736, 0.02314196776465646, 0.03496878733858466, 0.006938065094540694, 0.014766168813886387, 0.01955113330456827, 0.020416587757478868, 0.01930694212205708, 0.02608419399309371, 0.10782152826764754, 0.06559149681457452, 0.059772509416299205, 0.042654037808201144, 0.018327079879652177, 0.02967438893392682, 0.034449755546769927, 0.10551911645701953, 0.026580423615606766, 0.020248528204060028, 0.08632217334317309, 0.05122884429459061, 0.10108322769935642, 0.04895661372159209, 0.08073533313082797, 0.06320548948964902, 0.03359230441440429, 0.030780526543302194, 0.0503111358598939, 0.018718543695285916, 0.1301718136029584, 0.05822375323623419, 0.06794945350182907, 0.042324123904109, 0.006644182248107556, 0.044755688070186546, 0.0210150929633528, 0.0406837383551257, 0.04878012676324163, 0.06345397579882826, 0.13214827754667827, 0.04495612731469529, 0.03482486666845424, 0.054361603156264336, 0.03928977297618985, 0.011542342071022307, 0.049497440058205805, 0.049756056895213466, 0.09853600045400006, 0.04946499590628913, 0.04875742976686784, 0.06873240148914711, 0.03241877470697675, 0.013785038559165384, 0.01362484916379409, 0.021050436156136648, 0.035261361460600577, 0.004523097895019288, 0.01661766696322177, 0.03034334982346211, 0.035246708496872864, 0.07436883582600526, 0.049483129754662514, 0.051594717161996026, 0.04950601674084153, 0.05918946463082518, 0.032777370286307166, 0.014552491351163812, 0.05504815506615809, 0.07875747819031988, 0.038368468305894306, 0.03293904821787562, 0.013596473677482988, 0.04337060132196971, 0.05426855904183217, 0.05462009785696864, 0.062253437004983425, 0.028214223982234086, 0.014091333507427146, 0.020507935534364412, 0.041657595562615564, 0.020088495719911795, 0.015692616779623286, 0.04517353672002043, 0.036426487511822155, 0.04114532537226166, 0.02925487787329725, 0.08994484466633626, 0.017094288620033433, 0.06693004963121243, 0.10845969045268637, 0.0785403944818037, 0.038103846433971605, 0.029024114898805107, 0.00941767674937312, 0.03860346533890281, 0.06847291612731558, 0.018934953957796097, 0.0651771222640361, 0.02176350012554654, 0.010357617383955844, 0.037329719401896, 0.03772949527150818, 0.03950004080044372, 0.042010498233139515, 0.07136319032205002, 0.034110993546034606, 0.013097272919757026, 0.058026340257908614, 0.05232740266780768, 0.027937807475349734, 0.055806950599487336, 0.024746370601600835, 0.03073416563815304, 0.036890357799295864, 0.021788217459938357, 0.07623895297625236, 0.13659040204116277, 0.07347994138087545, 0.21350944388125623, 0.10151843327496733, 0.09100163581648044, 0.13113287703267165, 0.12909871047096594, 0.11086300720593759, 0.10208861303648778, 0.08776207893554654, 0.18292341940104961, 0.11577081706907068, 0.11936421639152936, 0.11832145734557084, 0.09100616164505482, 0.12294736983520643, 0.14562827135835374, 0.15954441390931606, 0.08673679216631822, 0.18434438029570238, 0.11249341150479657, 0.1987830898059266, 0.09321773118738617, 0.07320627463715416, 0.1353239028581551, 0.1051738371274301, 0.15331743018967764, 0.0750790855714253, 0.13728846529764788, 0.09886329860559531, 0.12082469516566821, 0.09574296711278812, 0.12724812834390573, 0.15398828419191496, 0.11273237118231398, 0.07810727879405022, 0.11361997641090836, 0.1225945180548089, 0.15273762201624258, 0.1509415398218802, 0.15621866951031343, 0.11387705297342368, 0.16150343950305665, 0.0984305561121021, 0.10834689757653646, 0.15726358629763126, 0.19903226143547467, 0.13727178690688951, 0.12934666073748044, 0.1714657177882535, 0.11357485383216824, 0.087262521098767, 0.1592028122395277, 0.164053794794849, 0.17493516233350548, 0.18147028237581253, 0.1763472751315151, 0.12466407700308732, 0.19085292890667915, 0.1689428160233157, 0.12750671803951263, 0.13637152021484716, 0.1447369341871568, 0.12292849299098764, 0.25630224549344605, 0.17615890023963793, 0.08515616519642727, 0.11379144221012082, 0.11189983585583312, 0.1365761799471719, 0.2628585493990353, 0.1467910496784108, 0.10296099872461387, 0.13408051457788261, 0.1738283902938877, 0.1665837668946811, 0.30664913675614763, 0.1775890349277428, 0.16796599701046944, 0.20319596944110735, 0.22734328013445648, 0.25030991275395664, 0.20899365762514727, 0.2794943010168416, 0.21482505542891367, 0.19870499042528017, 0.1402975238327469, 0.1454052911805255, 0.1559292200420584, 0.19647227094641753, 0.210053488612175, 0.16026609018445015, 0.14698897834335053, 0.138414752004402, 0.1455325572086232, 0.13880884514323302, 0.12751643466097967, 0.13577219737427576, 0.22614079394510814, 0.31615318677255083, 0.33221530488559176, 0.1455777340701648, 0.0983118192691888, 0.18576623685657978, 0.11289298720657825, 0.10382630050714527, 0.21003396037433827, 0.15917758430753434, 0.13356653787195683, 0.14444751186030252, 0.14303761108645371, 0.1296182240226439, 0.1423749402165413, 0.08114776707121304, 0.09717047587037086, 0.11088680342904159, 0.08610864515815463, 0.08960291729973895, 0.10138153883495502, 0.16128173497106346, 0.20736448147467204, 0.09491713571229152, 0.1381024494767189, 0.2785959749349526, 0.13330820601965698, 0.11581650961722646, 0.12776479204850538, 0.12152145563491754, 0.15227824023791722, 0.09261196904948779, 0.1359757035970688, 0.10776478238403797, 0.07833316988710846, 0.13276153749653272, 0.23695403656789235, 0.12882783929152147, 0.09920995536127261, 0.09091317520609923, 0.12501401108290466, 0.09824132626610142, 0.12992811096566065, 0.07696966733783484, 0.20786308257707528, 0.20082401457641805, 0.1386220987354006, 0.11636654367404324, 0.18579944436039242, 0.1027871241260852, 0.2125735812421356, 0.141921054571867, 0.19451430386730603, 0.09991979120033127, 0.1648305816841977, 0.1073220247136695, 0.10732580415372338, 0.15025535092822143, 0.09956746867724828, 0.17218818116400922, 0.10044328775256872, 0.11194343851613146, 0.1551992249275957, 0.1558223914887224, 0.11692014682505812, 0.12523111514747143, 0.14698953474206583, 0.10320209578744002, 0.0704577871199165, 0.0924026206401842, 0.1099082405811974, 0.13927803853792803, 0.1343899401170867, 0.07907948376876967, 0.10945581378681318, 0.22728370475981916, 0.13771010695823602, 0.14720891868429525], [0.04274264769628644, 0.05070720353562917, 0.05722959086831127, 0.024708029980372106, 0.04050711229709642, 0.04680784259523664, 0.039042820156152756, 0.01845638151280582, 0.028116435211684023, 0.04117523180320859, 0.02366675522976688, 0.012065469669843358, 0.030979564612997428, 0.04102650031979595, 0.06566222051956824, 0.042966208021555624, 0.04419271095788904, 0.04846752228747521, 0.01542299919362579, 0.034033002730991156, 0.0506225461140275, 0.03051393013447523, 0.021065674356317947, 0.020234085586188093, 0.06476377230137587, 0.01079900102091155, 0.0554683005570301, 0.025575133273378015, 0.042211734756295166, 0.03492158505001238, 0.03745339597974505, 0.050219265611044, 0.025034668256661723, 0.03840736871851342, 0.0732358248372163, 0.016515718773007393, 0.0326295548251697, 0.054025114247841496, 0.028655521105974913, 0.03855905182925718, 0.01058360856092934, 0.028169915645516345, 0.05527230232421841, 0.0024726740583511336, 0.02207470003382436, 0.03951964706980756, 0.06941304675170354, 0.016911701631865332, 0.025182934943586588, 0.055046601220965385, 0.016181479208171368, 0.03529937977769545, 0.07630731537938118, 0.028466901941491023, 0.014031069419745888, 0.043642357989613495, 0.07423630436616284, 0.03704077544222985, 0.028608725938413824, 0.08309389371424913, 0.06095214933156967, 0.019388820942757384, 0.014921814569139054, 0.07148810861898319, 0.07315827506993498, 0.0332043791588928, 0.026629101717844605, 0.06533955676215035, 0.0553613159406398, 0.08941347032253232, 0.1048630748742393, 0.03210086069468941, 0.04243468440004757, 0.01945151248946786, 0.056929176274154863, 0.11424043561731066, 0.14511163479515485, 0.1648001561739615, 0.08642554815326418, 0.14173687302640506, 0.10892795425440584, 0.16503775199609144, 0.18684476826872143, 0.1419254650494882, 0.12685824212219032, 0.052646510901727846, 0.07730333014790501, 0.045307842548936605, 0.13761699838297708, 0.0627129137782114, 0.1555248810244458, 0.09915627645594732, 0.034357617276587656, 0.026484251454738632, 0.052287871217621226, 0.046472429164818356, 0.030005690442132096, 0.02598588614325438, 0.09462938258158309, 0.1924353947064706, 0.07435535333518471, 0.07016512818102326, 0.05630035073097263, 0.0643286956474185, 0.09979508324925389, 0.14411379476743086, 0.09271139478577034, 0.09922570415905543, 0.04056710836344531, 0.0167539541143924, 0.05404442874714732, 0.060101205350032876, 0.03711954317986965, 0.020610989736659185, 0.03582163800352386, 0.017681087400498133, 0.04216685984283686, 0.024562833664406623, 0.01922541274689138, 0.037288349121809006, 0.012538284745200403, 0.028122080623039176, 0.040700236934104135, 0.017210379176373993, 0.05330230142655117, 0.04112133237400225, 0.029441885517111847, 0.012569220853038132, 0.02358808079069214, 0.04065072423379336, 0.04918577874611531, 0.020498683709385138, 0.03464333480224013, 0.032424148704324446, 0.020930874893175702, 0.008347239411835159, 0.045306475300874026, 0.0659859970744167, 0.07693327071943454, 0.027166155399754643, 0.0396361990299608, 0.04165257440347757, 0.041628411771463494, 0.03842727354328547, 0.01235224401378738, 0.075737400246518, 0.02881489201847996, 0.01686217027184154, 0.10054985167724745, 0.008146207297353871, 0.03460121813363262, 0.018629879524399127, 0.02368888395306255, 0.016802145367754356, 0.038620157300361564, 0.06065870329205479, 0.021528031510700072, 0.039356615460876904, 0.00864036993256637, 0.021248050998630266, 0.07494920039815561, 0.060724650110517225, 0.055517284000026326, 0.02884875430858561, 0.04448135296947189, 0.01855841960891017, 0.026044781286535517, 0.004319743918521064, 0.033588677644729614, 0.05382739592875753, 0.02906509841393147, 0.03624701499938965, 0.013710034994541534, 0.05822316291076796, 0.057431088627449105, 0.02449100903634514, 0.06127131863364151, 0.01679482906391578, 0.052785956633410284, 0.04076457901724747, 0.06371003455881562, 0.025272764498367906, 0.03706452416788254, 0.03548608886610184, 0.03813572061647262, 0.033504888747951815, 0.03899383332048144, 0.04828447050281933, 0.04226303878905518, 0.04165448787223015, 0.03519669368064829, 0.0532557471389217, 0.01991490780242852, 0.06453345037464585, 0.013809436982098435, 0.0613161562276738, 0.03354399272107652, 0.014594855685053127, 0.0610394903591701, 0.01833124947734177, 0.021784514355074083, 0.04189203280423369, 0.010650479035185916, 0.028591616677918603, 0.007967083382287195, 0.023767514287361076, 0.02469850843772292, 0.049285648922835074, 0.02325696587961699, 0.06826668897909777, 0.08437957508223397, 0.0465274787108813, 0.08430058003536292, 0.05210572188454015, 0.015403131688279765, 0.03298216911831072, 0.039349399240953584, 0.013893077449340905, 0.016065492128421153, 0.035827415729207654, 0.0382270480373076, 0.036836841742375066, 0.08798392595989363, 0.02244472723188145, 0.031597201113722155, 0.024243026539417248, 0.05378714183877621, 0.060457490517624786, 0.09330995088177067, 0.028061612974852324, 0.018176117712365727, 0.059012550195412974, 0.022328913178560988, 0.026876599062234163, 0.06814547548336641, 0.024505290502150143, 0.011052846060400563, 0.05535668493913753, 0.06392819035266127, 0.08699973127139465, 0.06321088384304728, 0.02461556431704334, 0.020992579171434045, 0.09180000690477234, 0.09423278564853327, 0.12680756912699767, 0.10143924823829106, 0.054565007598804574, 0.08216005310948406, 0.05770784270550523, 0.009187477807115232, 0.05695182577307735, 0.11912374358092036, 0.12133249720292431, 0.1816272275256259, 0.10044818677540336, 0.14361739211848804, 0.1572614692683731, 0.1714794784784317, 0.1466174939913409, 0.12598071992397308, 0.0650560851874096, 0.016065351332404783, 0.014324769909892763, 0.04812750838963049, 0.07312480972281524, 0.14030049581612858, 0.06637800032539026, 0.08554001245647669, 0.02589854850832905, 0.05209612400670137, 0.06623266490974597, 0.04169487088386502, 0.05780745164624282, 0.060494647095245976, 0.18773746250995568, 0.11070543780390706, 0.04069065601964082, 0.03604439087212086, 0.0390398379947458, 0.024101029516064694, 0.044363990159971375, 0.044834130111017396, 0.06047157011926174, 0.008789019143607999, 0.031130799890628884, 0.022658087479482805, 0.045034562570175955, 0.055607396843177934, 0.0221511878938015, 0.016336502407544425, 0.036184973149959526, 0.055828314274549484, 0.10220777057111263, 0.05504897270085556, 0.02906636388174125, 0.04557448984788997, 0.061039897480181286, 0.04930728401190468, 0.02740317616345627, 0.017110050988516638, 0.026340193381266933, 0.027512952951448302, 0.029522587079554796, 0.020866078191569874, 0.01700654556043446, 0.006109947879200003, 0.04557633546314069, 0.056503510900906155, 0.011100572517274745, 0.02919373508276684, 0.02140726924075612, 0.024541622659723674, 0.04231605273006218, 0.011692582446682667, 0.02953389486564057, 0.010475975095427461, 0.05425244044246418, 0.017193008679896593, 0.009000550739334097, 0.033192861026951244, 0.03079170880040952, 0.05946180144590991, 0.06797844051782574, 0.019518334618104354, 0.03195766944970403, 0.07321903788085495, 0.05267708229699305, 0.011643230050270046, 0.030227649424757277, 0.0359285988711885, 0.05019492655992508, 0.03948866855353117, 0.03499607462435961, 0.02443959643798215, 0.03831606165372899, 0.03515862447342702, 0.027339254772024493, 0.052164096252194474, 0.06180094914244754, 0.0487345054612628, 0.024536867825580493, 0.040348555626613755, 0.04290368441226227, 0.04585775786212512, 0.057952732779085636, 0.0648360905636634, 0.05358314367809466, 0.0525259962970657, 0.06692470956061568, 0.042511467422757826, 0.01710335724055767, 0.11759570986032486, 0.150913733456816, 0.16327565083546297, 0.15959214206252778, 0.228432830955301, 0.11227411577211958, 0.09276786925537245, 0.07938040726419006, 0.09183455790792193, 0.07607743450041328, 0.09918501919933728, 0.18582381733826228, 0.1428473905793258, 0.09532477919544492, 0.09772204341632978, 0.14652066704417976, 0.12381517541195665, 0.14434598945081234, 0.12489684165588447, 0.21045858758900846, 0.17039675371987478, 0.06671672500669956, 0.10158959802772317, 0.06417759268411569, 0.12267989133085523, 0.05947347903358085, 0.11478495996977602, 0.08622652026159422, 0.09682599721210343, 0.09115741388606173, 0.13918205297419003, 0.16395637073687144, 0.16813769351158822, 0.18440816258745535, 0.18790495209395885, 0.1677553118871791, 0.21105132863989898, 0.13049846036093576, 0.1317053163158042, 0.08796013652213983, 0.09915690070816449, 0.12512546724506787, 0.1168939960854394, 0.13566246469105991, 0.12373911163636617, 0.14305667792047772, 0.1737573476774352, 0.08683992270380259, 0.07713394745119981, 0.14008949856672967, 0.14572834170290402, 0.13418775025222981, 0.14435681886970997, 0.1714021119156054, 0.09074157369988305, 0.1625830294298274, 0.14442009904554912, 0.12001114524900913, 0.19380678183266095, 0.10101103835872241, 0.1037756750094039, 0.14936104177364282, 0.2903257283781256, 0.19425167010298797, 0.189408558553883, 0.2064883163464921, 0.07815536657082182, 0.13917486050299235, 0.20920095007334435, 0.1745610452656235, 0.2121258159833295, 0.11153820383229426, 0.1456404985593898, 0.1167024727910757, 0.1429566890001297, 0.19018162707132952, 0.2648667144988264, 0.32117942135248867, 0.3500183810080801, 0.2576501688786915, 0.41195864017520634, 0.3433483274919646, 0.3630775474011898, 0.31047726848295754, 0.22194554763180868, 0.1982139346322843, 0.16894395596214704, 0.13455761969089508, 0.18587560313088552, 0.2490939237177372, 0.3833826264100415, 0.18445287804518426, 0.1510307400354317, 0.22613487711974553, 0.24088886114103453, 0.1400436974529709, 0.08523053941982132, 0.17444796061941556, 0.12635430773454054, 0.3380214476159641, 0.2831221292061465, 0.26612469128199984, 0.08084795637322323, 0.1385079284331628, 0.21727307406919344, 0.2831679710320064, 0.19310577373419488, 0.22731881216168404, 0.13788006640970707, 0.13805928107883247, 0.23747990120734486, 0.1682773224477257, 0.12027172983757087, 0.15322706289589405, 0.15457265212067536, 0.10659772250801325, 0.16994563649807656, 0.17422715175364697, 0.14397464080580644, 0.09107844598059144, 0.1454366259276867, 0.161457787667002, 0.20573503391018935, 0.09041012291397367, 0.16920097145651067, 0.16721996132816586, 0.09198530803301505, 0.07809514658791677, 0.09402030919279371, 0.15251147986522742, 0.13373268395662308, 0.09882838119353567, 0.14483361185661384, 0.14433492933000835, 0.07146309781819582, 0.09018046595156193, 0.09526836579399449, 0.09512532382671322, 0.13121329700308187, 0.11569813239787306, 0.10317533436630454, 0.16876261069306306, 0.13259053310113295, 0.1056892184008445, 0.10650816945625202, 0.1637309342622757, 0.20861327089369297, 0.15121731002415928, 0.17052384332886764, 0.16163502101387295, 0.20184905028768949, 0.15510180086961814, 0.12349511044366018, 0.09485011680849961, 0.07919630035758018, 0.15650908249829495, 0.37526368349790573, 0.15593714533107622, 0.09738192095288209, 0.10963751189410686, 0.14565754335905823, 0.09450498675661427, 0.12296159192919731, 0.14837624318897724, 0.10708661377429962, 0.14571542239614896, 0.1273695318294423, 0.08741002782647099, 0.14219516914870056, 0.13066063023039273, 0.19539536801832064, 0.11187034672392265, 0.13638764220689023, 0.10877653237964426, 0.15681531892291137, 0.10097255863781486], [0.01350626753576632, 0.06484857560800654, 0.03750940565285938, 0.060594113543629646, 0.033706277941486666, 0.02463600518448012, 0.03804359252431563, 0.01974124524609319, 0.018646276323124766, 0.011556507337705364, 0.05373482678883842, 0.006151765144230532, 0.042494364947612794, 0.01257610967981496, 0.03958809768248882, 0.047416074600602896, 0.023509755797152008, 0.006276012963748404, 0.021793582975598316, 0.07057679537683725, 0.03531709971970745, 0.02878860557185752, 0.009600201821220773, 0.058961239377302785, 0.031341912490980964, 0.042731265271348615, 0.02857151168531605, 0.04943987653989877, 0.0388574002842818, 0.03038366498159511, 0.045691533745931726, 0.07030007522553205, 0.055935767080102644, 0.01913083005430443, 0.04812516744381615, 0.012391036708972283, 0.06144581748438733, 0.05959113700581448, 0.007182976796424815, 0.017123838820095574, 0.020283489720895886, 0.03456102171912789, 0.011731822974979877, 0.038988771449242315, 0.0350586321604039, 0.03082348798800792, 0.013411227680210556, 0.061088344880512783, 0.030700683327657834, 0.024251744018069336, 0.035366568315242014, 0.05628308201474803, 0.022241521260834167, 0.013004572313678051, 0.14794137009552547, 0.029976886630590473, 0.03095360386318394, 0.04514695850333997, 0.08723594966743674, 0.060024239122867584, 0.045521659111338, 0.0673645291743534, 0.09214052970388106, 0.07630653506410973, 0.07878346608153411, 0.039903066852795224, 0.03351268511531608, 0.05733166289116655, 0.014693088896040405, 0.08016126536365066, 0.16849106097859995, 0.048497445681797605, 0.004274931345467589, 0.05169661955109664, 0.09329945394503218, 0.1799645453159298, 0.29861457645893097, 0.23520195058413915, 0.24354250303336553, 0.1429276205599308, 0.20781570726207324, 0.29858985064285143, 0.12921981540109428, 0.21890108313943657, 0.07812747878155538, 0.05233805566760046, 0.022202788785632168, 0.11362519434520177, 0.05308803703103747, 0.05057386461911457, 0.23249242454767227, 0.03570622598220195, 0.1272466898496662, 0.007923142302648296, 0.0620751790702343, 0.05109511522044029, 0.024438855138474276, 0.047978254434253485, 0.14219089437808308, 0.17906092666089535, 0.13400252376283917, 0.041400610602327755, 0.007684403997180718, 0.016908578674442003, 0.06962429505905934, 0.06565316207706928, 0.06896155633564506, 0.05788774269499949, 0.022261697499613677, 0.047543211707047055, 0.027243382862902114, 0.0046621284480871895, 0.04584914046738829, 0.027452617617590085, 0.05039868723335011, 0.07817650972200291, 0.053597301311258755, 0.03352124483457633, 0.02000685438646802, 0.02480809184323464, 0.03160747413390449, 0.011704218474083712, 0.010039772921507912, 0.018382219331605092, 0.04747366865298577, 0.02614531642757356, 0.06342433060386352, 0.025144139703895365, 0.07493080531380006, 0.05314701868753348, 0.04961495553808553, 0.030727597419172525, 0.02499640905963523, 0.05071860631661756, 0.01783167806986187, 0.023956969746255448, 0.041734090207942894, 0.05013220278280122, 0.01116535225550511, 0.025404707329081636, 0.0410963046098394, 0.02958967722952366, 0.03718652815691062, 0.033904891926795244, 0.0396797270514071, 0.030471043328621557, 0.05087595858744212, 0.04592471909044044, 0.07649794300752026, 0.03690324657197509, 0.02656646106126053, 0.025523444171994925, 0.03372671541624835, 0.015076987046216215, 0.025169852788427045, 0.04064963857776352, 0.059758368746510575, 0.03662311338952609, 0.04393367003649473, 0.05249158778627004, 0.10004988671945673, 0.029399337978767495, 0.05731469951570034, 0.03540617779695562, 0.01272026783720191, 0.0006431748624891043, 0.03888477238693407, 0.0465568999892899, 0.04891667175771935, 0.03331663938505309, 0.016596182848193815, 0.03801359109846609, 0.00789577528900866, 0.017332737699949315, 0.026349718316591213, 0.06107973427112613, 0.03193772052015577, 0.034415462386927435, 0.019659517399434532, 0.021636144191558872, 0.02280381305276283, 0.004041195539424994, 0.03849570379991617, 0.053337415613766224, 0.08174752417419638, 0.059380512950675826, 0.0237824624138219, 0.044871507212519646, 0.04656005517712661, 0.02766695834829339, 0.04018588024856789, 0.08388575765171222, 0.04946398488911135, 0.03786047627883298, 0.026333674356075268, 0.037922965961375406, 0.04884865880012512, 0.038921501487493515, 0.007844028512148984, 0.034795319861067195, 0.017159351646634083, 0.045235106987612586, 0.030345792549529245, 0.008665941372912909, 0.05853155029139348, 0.008566814192038561, 0.057519630662032535, 0.027521863812580705, 0.018647429832656468, 0.015752755338326097, 0.00486045829685671, 0.060225234766091616, 0.04611654094021235, 0.030386684462428093, 0.030035196537418023, 0.046688705416662354, 0.035639105298157246, 0.02588391420431435, 0.015984137476022755, 0.08030210887747151, 0.016419317606570463, 0.05926627479493618, 0.022375915299302766, 0.043839221354573965, 0.05735027510672808, 0.04745346527280552, 0.026183217697377716, 0.09681119836334671, 0.04904729314148426, 0.09881307344351496, 0.026343757386452386, 0.05765169393271208, 0.027278488568429436, 0.03761083646012204, 0.05037041946447321, 0.027105567311601977, 0.03724680920796735, 0.04258871524195586, 0.09397515268730265, 0.09311990000839744, 0.018396336252668073, 0.010379112525177854, 0.07029635685362987, 0.07329615338572434, 0.041685157655073066, 0.051833456315632374, 0.12049920191722256, 0.11840121235166277, 0.049606602772005966, 0.07367314065673522, 0.033959724341652224, 0.1083613775138344, 0.11936231649347714, 0.14679769932159356, 0.2014269879353898, 0.1552568054092782, 0.0331168243927615, 0.195642585467015, 0.24306636144007954, 0.1346861342234271, 0.04851217328437737, 0.11081783034439598, 0.0802233988153083, 0.09056128016007797, 0.059859538317791054, 0.06327853378440652, 0.17991201313478605, 0.05086195023198213, 0.10641791072807141, 0.05372025524931295, 0.032189385765897374, 0.021174078807234764, 0.0406175201226558, 0.049318021828574796, 0.14607401458280428, 0.3186351593051638, 0.18610431014427117, 0.05251689035711544, 0.012165774957143834, 0.037064100083495886, 0.12228127914880003, 0.049585011787712574, 0.03944940851735217, 0.013765700311133904, 0.010854888557722526, 0.017270130970116173, 0.029569467063993216, 0.06417997434203114, 0.061163831901337416, 0.0452106491928654, 0.007419137516990304, 0.044280625347580226, 0.028905456087418964, 0.06666719195033823, 0.02413261023217014, 0.023669031714754443, 0.07228705646204096, 0.02350628000151898, 0.04767305277554052, 0.010757310981197017, 0.02779203949363104, 0.037881548183837106, 0.08512901022498097, 0.042487898508885076, 0.05947403543229614, 0.03976722074938672, 0.03311604747016515, 0.02726994072353201, 0.05394600724269237, 0.06185540836304426, 0.05645297022004213, 0.03544707310252956, 0.08214830088296107, 0.04351583495736122, 0.01654296025766858, 0.04196536208369902, 0.021158313046076467, 0.03386123498369541, 0.09310488402843475, 0.06339824771774666, 0.03871904360130429, 0.027757797223914946, 0.09850168015275683, 0.030105886315660815, 0.0644146388928805, 0.04728610121778079, 0.011892013218519943, 0.01821986456135554, 0.027225956387285675, 0.0451789717855198, 0.03152836373608027, 0.01986666565894016, 0.03618182135479791, 0.03643334750086069, 0.07605473750403949, 0.025326270377263427, 0.08737736993602344, 0.07555482682905026, 0.06330090508397136, 0.055911489097135406, 0.02939263066010816, 0.03195538617936628, 0.029343141708523035, 0.030854917730071714, 0.030510157479771545, 0.037846993788012435, 0.004581891682132014, 0.04112563089334539, 0.033034450241497586, 0.03560906655288168, 0.03451406031048723, 0.03320048776056085, 0.10889958470527615, 0.23723142168351583, 0.14190058995570454, 0.1852255394416196, 0.14790141795362743, 0.1176537246044193, 0.1263066338641303, 0.080392035123493, 0.13928848797721521, 0.1293199671698468, 0.1271643564105034, 0.094080502034298, 0.14745329985661165, 0.10168127489409276, 0.17648140793400152, 0.12451379506715707, 0.08708579665316002, 0.11322175777916398, 0.1532377837491887, 0.2716022602149418, 0.15781853294798306, 0.13839792433593953, 0.14279299921223096, 0.13716915169996874, 0.0744696661297764, 0.14110658184758254, 0.09903173813862459, 0.09279823369745697, 0.1403743475675583, 0.07494359569890158, 0.1327498938356127, 0.17829243146947452, 0.1469664102686303, 0.12069185157971722, 0.1264535231249673, 0.1656081692448684, 0.15072700061968394, 0.09962479131562368, 0.08893319645098277, 0.11987881734967232, 0.07040368752287966, 0.09596473949828319, 0.07509006426802703, 0.2461153721170766, 0.1134019223973155, 0.1730128319135734, 0.09852230083197355, 0.11775520630180836, 0.18369576867137635, 0.11509794103247778, 0.15558761837227003, 0.24955866592270987, 0.1506848500243255, 0.10069564849670444, 0.26230478339961594, 0.16505869158676692, 0.10306055338254996, 0.13859171393726552, 0.18843631286706242, 0.14568013857517922, 0.09637425573808805, 0.07887093603078808, 0.24308424762317113, 0.2599804752639362, 0.1825402642467192, 0.08237928098865918, 0.11831015295216016, 0.13889682399375097, 0.1509339673710721, 0.1831051989325455, 0.23819135874509811, 0.14917596456195625, 0.11621839233807155, 0.09514902505491461, 0.1299462007092578, 0.28189517504402567, 0.4012228862515518, 0.3521481938660145, 0.3297407419553825, 0.28699887118169237, 0.4175924078694412, 0.3842103848499911, 0.35505780630878037, 0.28703933901020456, 0.22073240844266756, 0.1978480549795287, 0.2053016535937786, 0.23738585625376019, 0.16149620631975786, 0.16771880670317582, 0.31633563126836506, 0.0955146604350635, 0.26275334932974403, 0.23000697791576385, 0.2723872166659151, 0.09507072889911276, 0.13188271251107964, 0.17340775286512716, 0.4442651037658964, 0.35427035284893854, 0.41614300278680666, 0.2691699021628925, 0.05827338807284832, 0.0896813627332449, 0.18151556780295713, 0.2171511820384434, 0.11303277220577002, 0.14662980261657918, 0.1221380675477641, 0.1924143194087914, 0.09236566083771841, 0.163032558879682, 0.1218107422547681, 0.1525606465126787, 0.10971422706331525, 0.1732532504413809, 0.13580874327038014, 0.1899169712726559, 0.13909353129565716, 0.12503006522144589, 0.1226973296808345, 0.16206437083227293, 0.13323278006698402, 0.13312361735318387, 0.11864472499915532, 0.1261047696960824, 0.2041244496192251, 0.18036348319479398, 0.1548602016908782, 0.16122696362435818, 0.14581980822341783, 0.12652946476425442, 0.1574227570423058, 0.09471253026276827, 0.13267412861543043, 0.09393648976194006, 0.18622590361961297, 0.10389568749815226, 0.0781764690099018, 0.11087038966694049, 0.12550149778170244, 0.1094092187870826, 0.21440757997334003, 0.18191191367805004, 0.10960986837744713, 0.17161601329488413, 0.28573386477572577, 0.16606347981308187, 0.1681839967412608, 0.09197588318160602, 0.10085454782737152, 0.09443206459816013, 0.09441418520041875, 0.1489252730139664, 0.1618728611086096, 0.18461901055915014, 0.11184445382761103, 0.2183615392340081, 0.21306683548859187, 0.11491792569203035, 0.11426803842186928, 0.1425561769200223, 0.1212559991649219, 0.1265013734144824, 0.1278486589768103, 0.13399368923689636, 0.22088155043976648, 0.14344781264662743, 0.1706133828099285, 0.16104090932224477, 0.11375308462551662, 0.1284061704895326, 0.12117393713976655, 0.20112658691193375, 0.13667029275425843, 0.130833181685635], [0.026595616014674306, 0.015352121121915323, 0.0330519123402025, 0.012452187981190426, 0.03835038874032242, 0.03538917710206338, 0.0121699962931286, 0.05659660929813981, 0.03699592427749719, 0.1087118951337678, 0.05295749707147479, 0.07006357863013234, 0.01572806853801012, 0.017252543342432806, 0.03536469895126564, 0.03991776392129915, 0.05906303320080042, 0.01799464861064085, 0.003252999931906483, 0.03668028675019741, 0.009128580119327774, 0.018163001630455256, 0.02215074175702674, 0.044358188685561926, 0.04679424475346293, 0.06078587432524987, 0.103855253596391, 0.03992219814764602, 0.024550112829144512, 0.031249343351061856, 0.04392313578033021, 0.01210826656980706, 0.032179845563535175, 0.04459817973630769, 0.018780205565105592, 0.07550943962165288, 0.044115266363535605, 0.03406819494973336, 0.010279758883241032, 0.05153386953419872, 0.024615627081532563, 0.03629041749185749, 0.026399812860680476, 0.04497796257159539, 0.021192567190155387, 0.04640076908149889, 0.04103180307096668, 0.023352858144789934, 0.05100652229573045, 0.0630434417564954, 0.04776363720053008, 0.03123764880001545, 0.03408688858949712, 0.03654525149613619, 0.04082360817119479, 0.13339262934667723, 0.06932508147188596, 0.05320017851356949, 0.06672717444598675, 0.09396823841546263, 0.021336012885772755, 0.04507497950856175, 0.01864705154938357, 0.14605938536780222, 0.0822827322408557, 0.009917451717358614, 0.0291753807105124, 0.03896799470697131, 0.06961729936301708, 0.11244482839746134, 0.18828417174518108, 0.10288264150066034, 0.12191200682095119, 0.34234670123883654, 0.3760301837963717, 0.3036980251116412, 0.7601146868297032, 0.5305857775466782, 0.5186798764126641, 0.3819194606372288, 0.628115849835532, 0.7900435094322477, 0.5856067708560398, 0.3602530503911631, 0.1312709046261651, 0.20174239815345832, 0.03330245800316334, 0.10489873188946928, 0.029004586660968404, 0.04274593519845179, 0.26752744029675213, 0.10937983822077513, 0.28988812757389887, 0.14953049910920008, 0.3898925185203552, 0.03489710011386445, 0.14802058227360249, 0.06792839177485023, 0.008705680624448826, 0.277743110699313, 0.2797165076647486, 0.07900159473397902, 0.02975642042500632, 0.016346685521836792, 0.07214273884892464, 0.04267084172793797, 0.026988693047314882, 0.05815045788351979, 0.05625476335574474, 0.0498684460430273, 0.06391521676310472, 0.054504302463361194, 0.03180740786982434, 0.02430242719128728, 0.07536611945501395, 0.0834408150985837, 0.014716277830302715, 0.04060575771810753, 0.003425562201300636, 0.041130699549934695, 0.023635886975431016, 0.02903690867658172, 0.04154839213671429, 0.028855919638382535, 0.024722420011780093, 0.06430853637201445, 0.046005932946822474, 0.019973193960530416, 0.056026273473565064, 0.02100353072663503, 0.014119311202583569, 0.06281531828322581, 0.011341121663073344, 0.0565778885169753, 0.02063586822311793, 0.018562792767105357, 0.07298017319824014, 0.029024623800069094, 0.004944557199321155, 0.038021180512649674, 0.07425238564610481, 0.04216913632782442, 0.019847997464239597, 0.04926918087793248, 0.04232983716896602, 0.008962605364753731, 0.08556826665465321, 0.04387986220951591, 0.012053614814898797, 0.02453751752286085, 0.01908860482009394, 0.05656602093949914, 0.07973184769174882, 0.028271500819495747, 0.023516444456098334, 0.05524881822722299, 0.010483303273628865, 0.026090955594554543, 0.032403758727014065, 0.044402934677366696, 0.0325972735216575, 0.04422997270843812, 0.0325666987337172, 0.005727254976851067, 0.03332786574693663, 0.02518714016436466, 0.038201090680169206, 0.03431367874145508, 0.035474682692438364, 0.010478802041948905, 0.003728078769719494, 0.0479713198063629, 0.040835136481161625, 0.03427112102508545, 0.048099837731570005, 0.02110586398547249, 0.03255907539278269, 0.03709777577647141, 0.018751968330304538, 0.004289574555254408, 0.01784711134886103, 0.028814627389822687, 0.01968107445697699, 0.021542614924588373, 0.08638904296926089, 0.0847773662369166, 0.050679875537753105, 0.012145488456423794, 0.0144612283911556, 0.031172478904149363, 0.028932549990713596, 0.02402885035345597, 0.10140253949378218, 0.007352057545046721, 0.044765062031469176, 0.010089451862898256, 0.018594010466975824, 0.04798101946445448, 0.03813515743240714, 0.03229240434510367, 0.05705389779593263, 0.01575646862121565, 0.06431709269859961, 0.01237716745319111, 0.0097473828521158, 0.03875402547419071, 0.03834563899519188, 0.013385404333738344, 0.019588920919756805, 0.05512747580983809, 0.04328867161114301, 0.07407730325524296, 0.04990260688854115, 0.08909647911787033, 0.014346369375873889, 0.05711744938577924, 0.03378348504858358, 0.048086643618132384, 0.030957125459930727, 0.024685071748016135, 0.10900834029806511, 0.0010030139632622845, 0.0691838376224041, 0.04496402546231236, 0.05365810822695494, 0.08486926701984235, 0.027688944579235146, 0.018231318232470324, 0.020061814026640992, 0.03601719858124852, 0.009855394600890577, 0.0599512355402112, 0.025747978195015873, 0.021302863057436686, 0.056889241095632315, 0.05303020888407316, 0.028488957722272192, 0.028429568944764987, 0.059029276083622656, 0.13659892444099697, 0.06512850522994995, 0.055741719635469575, 0.11193052599472658, 0.06615489801125866, 0.06890261199857507, 0.13303470212434018, 0.24896999608193124, 0.18550382022346767, 0.037319887429475784, 0.16513290974710668, 0.03860003873705864, 0.15727628847318037, 0.6176141904933112, 0.43615061204348293, 0.3080006428062916, 0.4263188567544733, 0.30806130383695873, 0.5607957307781491, 0.48153811799628393, 0.31993227398821283, 0.15383777155407838, 0.09367984746183668, 0.06133942997881344, 0.0874726769647428, 0.06441537171070065, 0.05357804109475442, 0.1870967083211456, 0.09516091977379151, 0.10618733095803431, 0.13104682522160666, 0.27853148696678026, 0.01694692438468337, 0.07423741037824325, 0.03190305416605302, 0.1661295419824975, 0.31200068816542625, 0.2701840406017644, 0.04676373103367431, 0.057607405952044895, 0.09804221695022923, 0.13837471843830176, 0.08993303815701179, 0.028180733190051148, 0.03627429549981441, 0.034866803525281806, 0.042837221907185655, 0.011938765129473592, 0.10229215997138194, 0.06500515434890985, 0.048596426977642944, 0.06693251271333013, 0.027268361433276107, 0.012246146581933966, 0.021138866232442002, 0.013448492823434728, 0.04780556387933237, 0.010453700487102782, 0.00837149703875184, 0.04750335795272674, 0.02212850277179054, 0.042499291111848185, 0.07583741630826678, 0.06412028361644063, 0.019165199549336518, 0.01883971647891615, 0.02639035408252052, 0.03599674753578646, 0.024250283471441696, 0.027715136030954973, 0.01622645590188248, 0.050789974629879, 0.02348208344275398, 0.061945022482957156, 0.03767004881852439, 0.039748995298785825, 0.025471196975558996, 0.06381870872740235, 0.021951452629374604, 0.05032749533919351, 0.03252411387594683, 0.039426379038819244, 0.052469830560897074, 0.03627500796158399, 0.04933566373905965, 0.015022824684690152, 0.03358992275648883, 0.005831488557825131, 0.03886270642812763, 0.11518897329057966, 0.024981394776010087, 0.0389525308938963, 0.056960985995829105, 0.021791104626442705, 0.04467258110110249, 0.020037325697817972, 0.04279045048835022, 0.006245869469629335, 0.02805958585148411, 0.015522199317014642, 0.04436885864873018, 0.03353308866332684, 0.023544586695996777, 0.12460565513798169, 0.050056071153708866, 0.06892049139631645, 0.0033550679259600914, 0.021308306604623795, 0.04071735297994954, 0.05791047361812421, 0.023757022439635227, 0.04533811538879361, 0.08201815108103411, 0.09440470606620822, 0.0706472544531737, 0.14637414419225284, 0.06681623895253454, 0.12703821675053664, 0.15501009007649763, 0.17963770856814726, 0.14328001093651566, 0.09427964527692113, 0.2285798830645425, 0.14473812840878963, 0.0896470695734024, 0.04622010574010866, 0.06330524092274052, 0.07939403224736452, 0.09401786646672658, 0.19580323541803019, 0.07503553040857826, 0.1277960996542658, 0.13403642337237084, 0.12965842043714865, 0.14425682994936193, 0.1504071799239942, 0.14447143700506004, 0.1721245888620615, 0.16478505198444637, 0.24708250164985657, 0.07913422118872404, 0.11873241886496544, 0.13528271578252316, 0.09111820813268423, 0.07616850747061626, 0.11069807569895472, 0.15424413260604652, 0.12090632292841162, 0.11817968423877444, 0.12001451078270163, 0.15440111846796103, 0.09159432258456945, 0.13075566584510462, 0.11242484554116215, 0.11917414516210556, 0.1552960518747568, 0.09821928066334554, 0.27656202550445286, 0.1150899478899581, 0.1125900891742536, 0.13613317800419672, 0.15356956023190702, 0.1450161106352295, 0.09852380717971496, 0.0885831673762628, 0.09693885115640503, 0.06296409387141466, 0.1057554909161159, 0.3104997415627752, 0.10601466415183884, 0.16223158900226864, 0.17301896587014198, 0.1902328428945371, 0.1793364118784666, 0.11075239242719752, 0.16809821634420327, 0.23965246177145413, 0.19192994040037903, 0.10728892577545983, 0.19656107760965824, 0.13101569403495106, 0.11985067171709878, 0.22877991518804006, 0.42150725637163433, 0.211295004135796, 0.25798311244164196, 0.5303157206092561, 0.49093251675367355, 0.44305011896150454, 0.90178758757455, 0.6303124033979007, 0.7547494290130479, 0.4853667382683073, 0.8111750440938132, 0.7618406085031373, 0.6812369450926781, 0.4646111662898745, 0.1904701673026596, 0.3333824665418693, 0.42589303531817024, 0.28851849106805666, 0.16057158022054605, 0.22831411446843827, 0.37802931080971447, 0.2677467428147793, 0.2552785261401108, 0.4663810027497155, 0.5729577381696019, 0.15150865939046654, 0.2328025693339961, 0.1732433166887079, 0.2471817848937852, 0.40465274506381577, 0.40046024003199165, 0.24495268879192217, 0.1435244463916336, 0.1712205359446151, 0.20416489030633653, 0.18309324314551695, 0.09055304274495159, 0.13069219567946025, 0.1665479673870972, 0.17184158547648362, 0.17205099495393888, 0.19167698254542692, 0.1590946673282555, 0.10077545100024768, 0.16091829804437502, 0.13270796037146024, 0.14967231292809757, 0.15133882207529886, 0.16161940113774367, 0.18315549194812775, 0.10438682471535035, 0.12714972719550133, 0.11792703850993089, 0.12224048562347889, 0.11014524607786111, 0.19760370094861301, 0.1688342775617327, 0.11423983850649425, 0.12410410919359752, 0.12464777859193937, 0.08630676381289959, 0.13311860976474627, 0.07058138227356331, 0.0898447200389845, 0.23543585517576762, 0.120254196492689, 0.16266062669456005, 0.15715328364499978, 0.09714436584285327, 0.08751734492502042, 0.1594026679439204, 0.15297452573265347, 0.06608771625906229, 0.11170629731246404, 0.13004538895828383, 0.22430921079857008, 0.20099324121006898, 0.13318833602326258, 0.09308089103017535, 0.18930280208587646, 0.18681188646171773, 0.12729614148182528, 0.13268379095409596, 0.11393305925386292, 0.10311295664204018, 0.16132275919829095, 0.14429668709635735, 0.12511234437780722, 0.10561609268188477, 0.17782269524676458, 0.14953180189643586, 0.19627073247517857, 0.07963824378592627, 0.12620448720242294, 0.1534427148955209, 0.09780027850397996, 0.17464826415692056, 0.07602421699890069, 0.2225433098418372, 0.10234302974173001, 0.15041572946522916, 0.1330149567552975, 0.1153695857418435, 0.10301895240055663, 0.15577171849352972, 0.11758089065551758], [0.03360482677817345, 0.04339412273839116, 0.04941508287031736, 0.053662576380052736, 0.050922492519021034, 0.05010347021743655, 0.0712195716000029, 0.07775670689131532, 0.024871370322736244, 0.04519653566447752, 0.03681030763047082, 0.048453021994126697, 0.08733715316546814, 0.06474395229348115, 0.13261254477713788, 0.03857002713318382, 0.1309660795543875, 0.058921015821397305, 0.0780385092699102, 0.056050392000802925, 0.10896886313068015, 0.09011550300887652, 0.04376797178494079, 0.01563646800683013, 0.13207517218376907, 0.10541816401694502, 0.05968191142060927, 0.04042434798819678, 0.07851535653961556, 0.055132021994463036, 0.10604023135134152, 0.06234149049435343, 0.0453892260390733, 0.09760970515864235, 0.08357885626277753, 0.07492045086941548, 0.04432906596256154, 0.025898309324734976, 0.06319747599107878, 0.03778992220759392, 0.015678862874795283, 0.039159368723630905, 0.01859324881141739, 0.022827687307393978, 0.05112442114789571, 0.09775678440928459, 0.04461173347330519, 0.14828823719705853, 0.01786929605129574, 0.03526382454271827, 0.09015010150947741, 0.0500186024499791, 0.04927194930080857, 0.03854855828519378, 0.04889204093654241, 0.017764986559216465, 0.06978774735970156, 0.07767658547631331, 0.04721265998003738, 0.07521376120192663, 0.06153022724070719, 0.037821847280221324, 0.2295133572603975, 0.1619587500712701, 0.25501107477716034, 0.07752908553395953, 0.09779038546340806, 0.12748340357627186, 0.12619436345994473, 0.4213630812508719, 0.27617002225347925, 0.027483745411570584, 2.7937238727297102, 6.693300885813577, 6.736490888254983, 8.916215913636343, 20.479315076555523, 26.06944830077035, 32.17177493231637, 29.925057547433035, 28.459149190357753, 30.697440147399902, 32.786065169743125, 43.698033877781455, 63.4869828905378, 69.74287687029157, 70.87435626983643, 75.13169125148228, 76.41921329498291, 75.06757327488491, 52.32675504684448, 17.469881772994995, 5.094545142991202, 8.493306858198983, 8.469108019556318, 3.3159585126808713, 2.03538054227829, 1.0739776279245103, 0.04359684864591275, 0.30182312428951263, 0.5926252113921302, 0.141005846538714, 0.11357505060732365, 0.1402746300612177, 0.18726281369371073, 0.33467993406312807, 0.12143283896148205, 0.1296926321727889, 0.04899421813232558, 0.07692700105586223, 0.1043226895853877, 0.10840838641992637, 0.04862150902460728, 0.0760681860681091, 0.02404461781095181, 0.06281590860869203, 0.02749211005201297, 0.05732996655361993, 0.05640159494110516, 0.055946711849953444, 0.10608514358422585, 0.0511388332316918, 0.0836812404117414, 0.007999227282458117, 0.02972802034180079, 0.03095825861341187, 0.09965186486286776, 0.025576509003128325, 0.06588668668908731, 0.007001143830296184, 0.03327634119029556, 0.019785599383924688, 0.039406087449086566, 0.02114061006743993, 0.06382296314196927, 0.05407695771594133, 0.04309575392731598, 0.036644731515220234, 0.0017223203488226447, 0.04181012684213264, 0.06361999296184097, 0.09247658095721688, 0.1657790650746652, 0.1333249115518161, 0.03632803886596646, 0.06874960235186986, 0.08964217055056777, 0.04733078274875879, 0.04752877587452531, 0.0184472043266786, 0.02293355403734105, 0.08723132205860955, 0.06841963755765132, 0.07623793517372437, 0.01684854189599199, 0.050152005827320476, 0.07268420979380608, 0.09388795415205614, 0.08049438534570591, 0.05362647831706064, 0.06821262330881186, 0.020917333030541028, 0.05652630967753274, 0.046061922263886244, 0.028902287328881875, 0.00501588564865025, 0.052296525931784084, 0.0390930521035833, 0.0366168335479285, 0.062129740071083815, 0.05951474753341504, 0.011111236543261578, 0.016420747619122267, 0.12451348294104848, 0.12536649645439216, 0.044000498950481415, 0.021523422561585903, 0.03740520981539573, 0.022126711439341307, 0.07360573498798267, 0.04922534751572779, 0.03596934489905834, 0.07871739712676831, 0.07956321138356413, 0.0323101616065417, 0.012571335337789995, 0.08811746165156364, 0.022623088643220917, 0.0703038682362863, 0.05003233939143164, 0.10161666478961706, 0.0977503993947591, 0.05902728119066783, 0.04531815628122006, 0.13789162864642485, 0.12668404861220292, 0.08533760546041386, 0.0853908568886774, 0.0777648560968893, 0.07906250682260309, 0.1035967521103365, 0.07978654439960207, 0.04942155609439526, 0.05242449424362608, 0.04567243977050696, 0.03155543389064925, 0.06404010113328695, 0.09287294040301017, 0.015142358806250351, 0.03902569053960698, 0.052310279836612086, 0.12982122812952313, 0.0909946740471891, 0.0791542718985251, 0.06678988465241023, 0.04063510096498898, 0.045712619221636226, 0.015991852419184785, 0.04085890217018979, 0.03422645985015801, 0.12190534360706806, 0.04743129414107118, 0.07255970540323428, 0.06266610843262502, 0.012758109735191932, 0.05650988234473126, 0.0757312255778483, 0.10136712675115891, 0.12198085098394326, 0.15399365818926267, 0.07943187414535455, 0.06223238884870495, 0.029314222546028237, 0.043330954520830085, 0.025527106564758078, 0.060904319398105145, 0.04060961179701345, 0.049342340523643155, 0.11319748658154692, 0.17531738110951015, 0.35592527261802126, 0.1712184731981584, 0.24704914486833982, 0.14320385216602258, 0.1777167623596532, 0.4572259911469051, 0.30472296582801, 0.14769878025565827, 1.9847316486494881, 4.875291262354169, 4.650153126035418, 7.50537463596889, 18.486179147447857, 23.698959180286952, 32.86258568082537, 33.56954404285976, 28.181664194379533, 31.644820077078684, 33.367427894047324, 44.140429156167166, 66.87357657296317, 72.3901891708374, 78.18627221243722, 82.18949072701591, 82.02357469286237, 78.8274450302124, 59.51523276737758, 20.7050290448325, 3.5401634190763747, 9.400791100093297, 7.829601900918143, 3.1636963401521956, 1.6965068003961017, 0.8018621238214629, 0.07282641716301441, 0.21780286064105375, 0.36204709698046955, 0.0611631872930697, 0.10630544354873044, 0.18814646984849656, 0.2961353452077934, 0.42343228736094063, 0.09840065307383027, 0.09603167019252266, 0.04454673660386886, 0.09486399963498116, 0.09609438718429633, 0.14264119735785893, 0.06895213148423604, 0.019220825850165317, 0.04915011155286005, 0.04894781651507531, 0.09743376102830682, 0.1471670123615435, 0.202418286885534, 0.029251064506492445, 0.08097593486309052, 0.030623333728207008, 0.038350826395409446, 0.12067910869206701, 0.06532047635742597, 0.02295982012791293, 0.1427924699549164, 0.07363497984728642, 0.04089307997907911, 0.008556517423130572, 0.07999684954328196, 0.04091093562809484, 0.06651635361569268, 0.038763290869870355, 0.060313403606414795, 0.08479180546211344, 0.15924110875598022, 0.05437530617096594, 0.054983439788754494, 0.028298917026924233, 0.12599849754146167, 0.08306718657591514, 0.07328442151525191, 0.033303387596138885, 0.08662788729582514, 0.10502479691058397, 0.045641210196273665, 0.0105737519916147, 0.032459486808095656, 0.0467418957767742, 0.07882187116358962, 0.0743925574102572, 0.01856985122763685, 0.06358897712613855, 0.02296507029261972, 0.026280750320958238, 0.11451685721320765, 0.021902230002784302, 0.01521178990203355, 0.03755774448758789, 0.08580183197877236, 0.022516763902136257, 0.015497678757778235, 0.09898623558027403, 0.05031647593049066, 0.002914669649076781, 0.05633683895160045, 0.06469787298036472, 0.06570274263088192, 0.019971813141767467, 0.017906206659972668, 0.03208433158163514, 0.0215867298788258, 0.05702193879655429, 0.06458814708249909, 0.03681166809318321, 0.12203939498535224, 0.15517348130898817, 0.17552141658961773, 0.22683699801564217, 0.16382854831005844, 0.1464351580611297, 0.22184603368597372, 0.2940155475267342, 0.10398990208549158, 0.13048529678157397, 0.12841934763959476, 0.14582075817244394, 0.17625005463404314, 0.3168384257171835, 0.2311706111899444, 0.1042588326547827, 0.20422388214085782, 0.1351251463804926, 0.15084682990397724, 0.1958634757569858, 0.2562055949653898, 0.19830150636179106, 0.21622598596981593, 0.1332357113382646, 0.22197730307068142, 0.2010750996747187, 0.17686153682214872, 0.11638327634760312, 0.19244925039155142, 0.14066675544849463, 0.24052038948450769, 0.19227269557969912, 0.1103314021602273, 0.201985951513052, 0.18248527576880796, 0.23957991280726024, 0.20821612434727804, 0.1699929575302771, 0.17634886290345872, 0.15292063648147242, 0.14502277384911264, 0.14786386782569544, 0.20790782517620496, 0.13931979558297566, 0.24543024173804692, 0.20080829970538616, 0.2551665407206331, 0.2655613443681172, 0.24051493406295776, 0.19496744312345982, 0.20800374288644108, 0.23132550716400146, 0.21623788747404302, 0.26028492035610334, 0.15436126132096561, 0.17929613403975964, 0.21238824618714197, 0.1391162079359804, 0.14666068953062805, 0.10074003147227423, 0.1880798784217664, 0.17414966305451735, 0.3444171015705381, 0.40888455084392, 0.585021439407553, 0.29832410918814795, 0.3179652009691511, 0.20923920587769576, 0.2506716804844992, 0.612849517592362, 0.46807636320590973, 0.1862900930323771, 4.898229871477399, 9.50936712537493, 10.40557965210506, 13.609974196978978, 28.883423566818237, 35.79568086351667, 51.944961956569124, 50.917201791490825, 47.14224897112165, 44.404425961630686, 49.270680223192485, 63.36354814256941, 89.65803296225411, 99.6260506766183, 105.51790073939732, 105.98983628409249, 109.11034870147705, 105.08192212241036, 77.32568223135812, 35.61897427695138, 8.693806682314191, 17.060744047164917, 14.255286404064723, 5.717216210705893, 3.6417113414832523, 2.456916459969112, 0.0994746790134481, 0.3184908756187984, 0.7150593101978302, 0.4096102576170649, 0.28279282259089605, 0.32380483618804384, 0.32241267231958254, 0.49673453399113243, 0.2956359162926674, 0.16296960440065178, 0.2550315393933228, 0.40639104321599007, 0.2338617353567055, 0.2744717576674053, 0.1584932953119278, 0.18040024622210435, 0.2428818813392094, 0.21925401634403638, 0.18368622846901417, 0.2627563348838261, 0.24263592596564973, 0.11851488053798676, 0.1816429423966578, 0.13482610242707388, 0.17684641906193324, 0.2034329410110201, 0.2041289008089474, 0.12824915748621735, 0.30680104717612267, 0.1371324700968606, 0.21572647563048772, 0.1007697173793401, 0.13488122661198887, 0.12076910957694054, 0.21117076437388146, 0.08424580190330744, 0.12968894094228745, 0.137843859781112, 0.2057345182235752, 0.24790941870638303, 0.13823268748819828, 0.11787734260516507, 0.2316271566918918, 0.29885217228106087, 0.3488418012857437, 0.2270173526235989, 0.12350840973002569, 0.23012797428028925, 0.2291015950696809, 0.16153633488076075, 0.17684515698679856, 0.1442777288279363, 0.22120532020926476, 0.16698573103972844, 0.14230422329689774, 0.2013015675225428, 0.13892043701239995, 0.12327388088618006, 0.23378820930208477, 0.1624574325978756, 0.1109729502350092, 0.14756486458437784, 0.13197499327361584, 0.1336678702916418, 0.16582980592335972, 0.1671770779149873, 0.13562228184725555, 0.15846909875316278, 0.09638505801558495, 0.20793713788901055, 0.10105552989989519, 0.2080198920198849, 0.2548153038535799, 0.14562903131757463, 0.15977839992514678, 0.23567760363221169, 0.18613359571567603, 0.18328153661319188], [0.05794693809002638, 0.03612533670717052, 0.0249556341940271, 0.021300825756043196, 0.04681787134281226, 0.035511184483766556, 0.014967642824298568, 0.017898817413619587, 0.05077609180339745, 0.006011708306946925, 0.058594891535384316, 0.01638870549920414, 0.044889725877770355, 0.08015671917902571, 0.013425577847686197, 0.09805078684751477, 0.00972401156156723, 0.015500976437968867, 0.06949454559279339, 0.03650826794494476, 0.0675223157075899, 0.07434261723288468, 0.03826225043407508, 0.032284852250346115, 0.08881995574172054, 0.036437842795359235, 0.06735264124082667, 0.03212809369766286, 0.01278686520111348, 0.05521418919254627, 0.10008339956402779, 0.05042884811492903, 0.01956754028131919, 0.02412384864874184, 0.014755325824288386, 0.054946289996483495, 0.029300801123359373, 0.02721304725855589, 0.041795154966946156, 0.05956115254334041, 0.08148174879274198, 0.032694792574537654, 0.04702921803774578, 0.036992185549544435, 0.011700917401217988, 0.02564099188228803, 0.07947173129234995, 0.015591107940833484, 0.01663630801652159, 0.04640124744868704, 0.01652955070936254, 0.020176788392875875, 0.035132612833487134, 0.024061520118266344, 0.03804231348580547, 0.08956505504569837, 0.014261264121159911, 0.0202780359956835, 0.14061609602400235, 0.142197259036558, 0.1461311336606741, 0.1534584704786539, 0.39315144079072134, 0.413052818604878, 0.4867907389998436, 0.018444128866706575, 0.11286235135048628, 0.08359220983194453, 0.8205019693289484, 11.795915927205767, 32.5865615436009, 50.83733572278704, 83.96137864249093, 95.75299276624406, 86.34002494812012, 99.28729820251465, 106.23079286302838, 115.2695654460362, 113.25506728036063, 112.60996178218296, 111.5663423538208, 114.31686319623674, 122.87798881530762, 134.40150669642856, 113.7741185597011, 115.66839204515729, 125.06731060573033, 118.48790849958147, 115.14327498844692, 113.7685877936227, 126.12638282775879, 91.22608157566616, 54.33071279525757, 101.9397382736206, 113.58969252450126, 98.99956635066441, 96.01165335518974, 90.30887072426933, 69.89962823050362, 54.57602936880929, 29.867905139923096, 7.942188773836408, 2.4748755991458893, 0.587392077914306, 0.1837397241698844, 0.46252882374184473, 0.2643296947436673, 0.12221425345965795, 0.01441654346750251, 0.07549842699830021, 0.053370158321091106, 0.04380136249320848, 0.07458472531288862, 0.14792417601815291, 0.08982247087572302, 0.08718007909400122, 0.03635788083608661, 0.04310029332659074, 0.08179558480956725, 0.1338930217815297, 0.026675985094958117, 0.03416205669886299, 0.06499159721923725, 0.005201057007070631, 0.042564596714718, 0.021036025768678104, 0.0329614466588412, 0.009201408979216856, 0.04189315577968955, 0.040936981194785664, 0.025899335608950684, 0.012729070132731326, 0.0280334351118654, 0.082043507934681, 0.038914709351956844, 0.0684996639777507, 0.061347382409232, 0.012544238889989043, 0.050882706618202586, 0.02402772568166256, 0.05274820973032287, 0.10620242836219923, 0.05060584397454347, 0.03738178678655198, 0.02226956172047981, 0.06144507109586682, 0.03701994102448225, 0.02222876819515867, 0.022075295448303223, 0.09810728167316743, 0.03244887791307909, 0.03199686502505626, 0.03005333717114159, 0.07873902203781263, 0.024720950983464718, 0.042218302975275686, 0.043525646573730876, 0.052252960590911765, 0.07938371851508107, 0.032175099211079736, 0.05367355168397937, 0.027028063345434408, 0.059540029748209884, 0.033134232208664925, 0.04757322670359697, 0.05502552931596126, 0.032719375898263285, 0.08248040306248836, 0.03899861699236291, 0.04880526987835765, 0.057113954930433204, 0.021592702683327452, 0.0341234989464283, 0.026717670893828784, 0.030647652423275367, 0.053573332061725, 0.04870190863896694, 0.09454549529722758, 0.020007875581671084, 0.03968515872423138, 0.008424924886120217, 0.04480285643200789, 0.030778246665639535, 0.03441532328724861, 0.04363658704927989, 0.054109089741749425, 0.047150743659585714, 0.019448518453698074, 0.029634480896805013, 0.01727314875461161, 0.018947335525548885, 0.06264323501714639, 0.011788102365764124, 0.039531066814171414, 0.010149857594764658, 0.05762501393577882, 0.02232374274171889, 0.06142306620521205, 0.06235563116414206, 0.013925808282302958, 0.07505047853503909, 0.02950567120153989, 0.04355499999863761, 0.02224251361829894, 0.05040027161261865, 0.015783494671008418, 0.06667102567319359, 0.07426979006933314, 0.03595548921397754, 0.07066326109426362, 0.03708410668852074, 0.019259878933163624, 0.02059138346729534, 0.02568833327053913, 0.02358631999231875, 0.0498219562162246, 0.02943736986656274, 0.03296442882024816, 0.015759779872106652, 0.03883884913687195, 0.013783034336354052, 0.01831241843423673, 0.0672285236152155, 0.07032980863004923, 0.03426503795864327, 0.04046097191582833, 0.09688020537474326, 0.023662850260734558, 0.032364193350076675, 0.06205850067947592, 0.030084485321172645, 0.09069657325744629, 0.06498272198119334, 0.06549388276679174, 0.03284415848819273, 0.05424636076869709, 0.08191688651485102, 0.1112775785316314, 0.07376227301678487, 0.3049027776079518, 0.5251589630331311, 0.19418435942913803, 0.40371538964765413, 0.119622833228537, 0.4680236003228596, 11.55601634298052, 35.08374064309256, 59.294266155787874, 96.74556377955845, 112.19130502428327, 103.80568395342145, 119.19586045401437, 127.64043698992047, 134.38137081691195, 135.90242876325334, 133.5689596448626, 139.55106680733817, 136.54182979038782, 144.93967274257113, 159.99580764770508, 139.05288096836634, 141.49692371913363, 150.77770205906458, 142.86091068812777, 138.01458386012484, 139.96041297912598, 149.11701311383928, 114.81934997013637, 71.61642387935093, 130.984646660941, 139.66569818769182, 118.70153781345913, 113.78225490025112, 112.24796758379254, 82.79853507450649, 60.4580477305821, 31.999952929360525, 7.809778690338135, 1.5029296619551522, 0.3299909313874585, 0.139301651556577, 0.38776786252856255, 0.16117063164710999, 0.07591987188373293, 0.04932165538359966, 0.10746782153312649, 0.020053920968036567, 0.029500107214386975, 0.04190979006567171, 0.10906082498175756, 0.06689435190388135, 0.023491280984931757, 0.09312553184905223, 0.09938933966415268, 0.06447385464395795, 0.07657233080161469, 0.02255589671299926, 0.01789086328686348, 0.065455104490476, 0.03487597731873393, 0.12173625268042088, 0.02608742890879512, 0.042124651572001834, 0.031179790118975297, 0.01303919795567968, 0.008042713743634522, 0.07862867188772985, 0.06783611101231404, 0.05352788717885103, 0.06044992485216685, 0.03305920998432806, 0.025952001800760627, 0.07724496935095106, 0.025013772770762444, 0.05991314936961446, 0.04055584468213575, 0.021770772324608903, 0.029422109613993337, 0.022966415488294194, 0.07072455994784832, 0.05451615986281207, 0.039456254935690334, 0.06930034887045622, 0.014679716667160392, 0.04277657444721886, 0.05592256957398994, 0.017038658926529542, 0.08170031849294901, 0.06174651027790137, 0.03230911326993789, 0.011454176623374224, 0.04330686652766807, 0.04322294192388654, 0.02845629643914955, 0.02160942178618695, 0.016273478378674815, 0.015682209748774767, 0.03969987614878586, 0.04359675704368523, 0.039892909183566055, 0.02977297667946134, 0.01524722808972001, 0.01415026088112167, 0.06911280857665197, 0.06546169985085726, 0.051495169289410114, 0.05773457698523998, 0.04727704277528184, 0.04698627355641552, 0.02635964358757649, 0.05494664962004338, 0.042889974612210474, 0.13398972659238748, 0.1881531873451812, 0.11608116541590009, 0.12068054718630654, 0.23001324757933617, 0.17275779774146421, 0.14462294030402387, 0.12979906717581408, 0.14104032968836172, 0.06435929079140935, 0.1503406563507659, 0.06941071259123938, 0.12651182285376958, 0.18643916717597417, 0.09329567450497832, 0.33846852076905115, 0.10693931060710124, 0.11608128755220345, 0.17279286443122796, 0.13832020493490355, 0.13938059232064656, 0.15241875126957893, 0.07487468368240766, 0.10037242155522108, 0.24067615398338862, 0.09697168546595744, 0.13624837967966283, 0.13425219750830106, 0.18749367844845566, 0.15712790643530233, 0.17363211725439343, 0.1953641146953617, 0.15741380038005964, 0.1809318241264139, 0.10734022302286965, 0.22238378625895294, 0.17291163520089217, 0.11966961143272263, 0.1352569450225149, 0.14854164288512298, 0.2781911338014262, 0.07793079183569976, 0.13940332324377128, 0.1536892538091966, 0.10016896961522953, 0.14854852323021206, 0.2658193233822073, 0.2095611978854452, 0.08021442179701158, 0.22005095572343894, 0.2054264633251088, 0.16610180347093514, 0.09715879828269992, 0.15685176982411317, 0.240768841866936, 0.27418633869716097, 0.13886364363133907, 0.24507474367107662, 0.21439612630222524, 0.14085636527410575, 0.26193313619920183, 0.40734932465212687, 0.6175792866519519, 0.5380436916436467, 0.7473555143390382, 0.17831475527158805, 0.5911555045417377, 0.6088792734912464, 2.586428710392543, 19.236634969711304, 48.866110937935964, 77.876542363848, 120.1965400150844, 134.92722129821777, 122.06556374686105, 139.51140648978097, 145.49411119733537, 151.6773409162249, 149.78534643990653, 149.22211156572615, 150.01736068725586, 153.48765236990792, 162.40713827950614, 168.23129899161202, 148.44420514787947, 148.4596162523542, 158.1015897478376, 151.40017727443148, 146.43347985403878, 145.0025817326137, 162.3236209324428, 140.7484359741211, 100.46107823508126, 152.84509686061313, 159.56932721819197, 139.87317139761788, 136.73244667053223, 135.83492006574357, 104.62468201773507, 79.92180020468575, 48.04019941602434, 13.491315467017037, 4.864199331828526, 1.0101778571094786, 0.16660106953765663, 0.5541343082274709, 0.529422117131097, 0.33143230261547224, 0.09366209698574883, 0.16558098713202135, 0.1088918222646628, 0.19648143116916927, 0.16655487487358706, 0.2875019370445183, 0.16063814450587544, 0.13439283067626612, 0.15641828094209942, 0.12778372317552567, 0.18847406655550003, 0.30468795342104776, 0.15966469102672168, 0.11085023039153644, 0.22368456503110273, 0.09506048302033118, 0.22796352899500302, 0.08646474033594131, 0.16226605858121598, 0.11276606723134007, 0.11869123178933348, 0.10865526460111141, 0.16377467262957776, 0.10949000516640288, 0.11380031744816474, 0.20156819107277052, 0.14746620559266635, 0.16546525619924068, 0.1439074251268591, 0.06164371222257614, 0.14475192981106894, 0.15597293126795972, 0.12308834227068083, 0.160350608506373, 0.11020660599959747, 0.0996376902663282, 0.21805110946297646, 0.11883938312530518, 0.21206402858453138, 0.1547297736895936, 0.16227470311735356, 0.1482590873326574, 0.13021134505314486, 0.09902698839349405, 0.19884449722511427, 0.20155227264123304, 0.1489671521953174, 0.16999161403094018, 0.13745098800531455, 0.15754110712025846, 0.16798601379351957, 0.1310067373727049, 0.1573414278349706, 0.12142693570681981, 0.15139167995325156, 0.126725968505655, 0.12244253978133202, 0.09882893759225096, 0.24959085562399455, 0.1745279056153127, 0.1109598952212504, 0.07611198550356285, 0.16047650389373302, 0.2395524728511061, 0.17711536320192472, 0.12177369424274989, 0.13108856869595392, 0.12601326246346745], [0.023747212519603114, 0.032995984091290405, 0.06969056757433073, 0.032579027715006044, 0.02462712485742356, 0.046697590832731554, 0.04527954763865896, 0.04580870656562703, 0.03661750190492187, 0.05938884536070483, 0.05702748242765665, 0.05808720484908138, 0.027370357120941793, 0.06868086675448076, 0.04971609118261507, 0.03093916124531201, 0.03037016892007419, 0.01648216860901032, 0.021208673915160552, 0.0606704962306789, 0.028934578810419356, 0.03016205205182944, 0.03307115559333137, 0.043639348686805794, 0.022304088974903737, 0.03127977564664824, 0.03939305618405342, 0.005228735298650073, 0.06161048436271293, 0.08545524307659694, 0.03006418016073959, 0.041852419929844994, 0.089018529014928, 0.04436620557680726, 0.033522493339010646, 0.059433364043278356, 0.07184603584132024, 0.05025839672556945, 0.05524463505883302, 0.060134724979954104, 0.059122343946780474, 0.015481356597904648, 0.009015584530841027, 0.05288142990320921, 0.009277694126857179, 0.07296695533607687, 0.018296859626259123, 0.03862763475626707, 0.0636487424905811, 0.045858667099050114, 0.01834381594588714, 0.04868422940905605, 0.06310239966426577, 0.05243336948167, 0.03445079709802355, 0.1575280385357993, 0.0064584901140603635, 0.043720087568674765, 0.47324495443275993, 0.2973350222621645, 0.4270308299788407, 2.4705668474946703, 4.43139647586005, 14.904111794063024, 27.381339413779124, 43.49954816273281, 54.971138681684224, 62.14050538199288, 78.25121702466691, 87.40117468152727, 96.45109217507499, 101.27287101745605, 103.53192492893764, 89.84808009011405, 99.68294252668107, 100.74054173060826, 96.4617646081107, 87.09952558789934, 78.64007990700858, 81.03507532392229, 94.07857418060303, 93.50129699707031, 104.53090912955147, 81.37097903660366, 101.3556935446603, 94.98742634909493, 69.02917875562395, 86.05610765729631, 96.53361592973981, 87.17454528808594, 92.76266179765973, 93.8207334790911, 109.88945020948137, 100.70552975790841, 97.72484288896833, 80.82264110020229, 94.44730118342808, 93.74030808040074, 106.90687343052456, 106.15389020102364, 116.14034148624965, 104.06418473379952, 100.76729229518345, 80.93620940617153, 50.98158379963466, 21.270202466419764, 6.669255776064737, 2.1160816976002286, 0.0864518413852368, 0.5388517454266548, 0.12253157714647905, 0.05150033633357712, 0.0033154961877569023, 0.09176397669528212, 0.08761925409947123, 0.034635365408446105, 0.01717486634983548, 0.02489902062474617, 0.019585095678589175, 0.058075113355049064, 0.03986328773732696, 0.03434543078765273, 0.06533226929605007, 0.051940074523112605, 0.06178664562425443, 0.0212487872091255, 0.05341738775106413, 0.0522336630549814, 0.05003322148695588, 0.02136466233059764, 0.01964403492664652, 0.099348817552839, 0.0546195143168526, 0.013107716421862798, 0.05130506752591048, 0.024519943465877856, 0.03464646963402629, 0.04114414132865412, 0.007711598832559372, 0.0151635698109333, 0.05423311237245798, 0.04665426637179085, 0.05805334595165082, 0.034530552104115486, 0.05029127513989806, 0.03059639249529157, 0.06894684569644076, 0.028998320390071188, 0.045370790242616615, 0.01935936404126031, 0.07774439826607704, 0.029176581717495407, 0.060941211347069056, 0.046283046648438485, 0.07030515745282173, 0.01888825378513762, 0.018792412410091077, 0.026545704675040076, 0.0071565147788663, 0.033936827177447934, 0.02100700991494315, 0.07291903040770974, 0.01702524598554841, 0.07219147801931415, 0.034339449501463344, 0.09309239898409162, 0.07958725187927485, 0.03042303697605218, 0.06870490725019149, 0.054661576702658615, 0.06003721271242414, 0.10864666077707495, 0.09405665152839252, 0.020096136024221778, 0.025146916608459184, 0.030808288803590194, 0.03798856672697833, 0.05696857201733759, 0.05710513397519078, 0.09772628426019635, 0.014299229851790836, 0.037051896631185494, 0.057034186353640895, 0.04345287030030574, 0.016756161049540554, 0.07892646733671427, 0.01239327502636505, 0.02610452120591487, 0.08069042089794363, 0.08181878392185483, 0.03881287481635809, 0.019688928499817848, 0.016178110281803777, 0.039923762170864005, 0.013429068910357143, 0.02342028247325548, 0.04186608562512057, 0.0439704330638051, 0.03409947541409305, 0.08606661669909954, 0.06974590210510151, 0.029225901035325866, 0.046085090842098, 0.04981600885678615, 0.02507836591186268, 0.090636271850339, 0.0947777306927102, 0.029146193526685238, 0.044929125013628175, 0.04453245344172631, 0.04177022898303611, 0.04458318750507065, 0.045459630832608254, 0.02216787137357252, 0.04144293422411595, 0.02631720800751022, 0.02619526339029627, 0.057401721631842, 0.02279070545254009, 0.023287321840013777, 0.1327445741210665, 0.05342926889924066, 0.017136566440707872, 0.02325885051063129, 0.04752859267007027, 0.013167288403825035, 0.037064622555460246, 0.0447436644296561, 0.05736755060830286, 0.02358716816109206, 0.07783473841845989, 0.0344958552159369, 0.040632332542112896, 0.06850632719163384, 0.38176000490784645, 0.24624983061637196, 0.3048865741917065, 2.15178154196058, 3.03820383974484, 14.184706602777753, 27.84792831965855, 48.49917309624808, 62.67238303593227, 69.00803538731166, 90.34013761792863, 100.79618290492466, 112.74226937975202, 114.56989574432373, 122.2545964377267, 107.06440993717739, 115.28704711369106, 116.07700170789445, 119.27112334115165, 101.6054882322039, 96.68618447440011, 119.98603739057268, 108.52251025608608, 108.56977885110038, 128.5339197431292, 107.00745555332729, 118.60783440726144, 116.57438850402832, 100.44297817775181, 117.47402736118862, 123.428925377982, 115.05034978049142, 136.2132911682129, 122.45669174194336, 146.37896428789412, 131.035368510655, 111.9616948536464, 108.41668919154576, 121.95197459629604, 106.8844724382673, 128.0652915409633, 127.36539949689592, 139.16877692086356, 121.84719576154436, 116.2342255456107, 91.97438171931675, 53.93518659046718, 21.62647656032017, 7.360409157616751, 1.9688673913478851, 0.06709994801453181, 0.3638435862958431, 0.02541783867803003, 0.05605358790074076, 0.08074085640587977, 0.0839994258380362, 0.002907063695602119, 0.08733386905597788, 0.10507916792162827, 0.05059633430625711, 0.027832699008286, 0.07288861168282372, 0.03731464574645672, 0.03958071522148592, 0.06144724240792649, 0.06708592948104654, 0.010488315102910357, 0.05581926601007581, 0.05469578165294869, 0.06674139653997761, 0.0877615428928818, 0.019409068427713852, 0.04176794910537345, 0.11364981159567833, 0.022104336747101376, 0.050722307725144286, 0.026275774962933998, 0.08839555244360651, 0.04241792797776205, 0.05645828993458833, 0.021884031693584154, 0.025349179415830543, 0.10696764622947999, 0.05260554434997695, 0.06150991190224886, 0.0456245284128402, 0.0345447029519294, 0.045156101762716255, 0.03511063169155802, 0.07430049377892699, 0.04257766190650208, 0.01840733869799546, 0.08595267031341791, 0.019376476694430624, 0.097964416124991, 0.09649164229631424, 0.04499188271750297, 0.03332696668803692, 0.03296578928296055, 0.011422009822646422, 0.0629562364358987, 0.034256186469324997, 0.05236740909250719, 0.06806737610271998, 0.021633818512782454, 0.07233341397451502, 0.03360475553199649, 0.07151305156626872, 0.04425012859116707, 0.04507851128333381, 0.06863066873380116, 0.04125310048194868, 0.026056083983608654, 0.061774208077362606, 0.02879287355712482, 0.05038574757054448, 0.040394404237823825, 0.09007328456001622, 0.11436478394482817, 0.13842119808707917, 0.22352149949542113, 0.17231303160744055, 0.25442666613629883, 0.13531338556536607, 0.13510724662670068, 0.15095521908785614, 0.1300610631172146, 0.20869647285767964, 0.10069540422409773, 0.11959137634507247, 0.1831131920750652, 0.2004687607820545, 0.10386140112365995, 0.09525925985404424, 0.14712191692420415, 0.06510477686034781, 0.11569145561328956, 0.10698779193418366, 0.12540320519890102, 0.09054902581764118, 0.1541638212012393, 0.17584365286997386, 0.09962257250611271, 0.22634081249790533, 0.09559907697673355, 0.2151717325406415, 0.14039445934551104, 0.19428341197116034, 0.1413057047341551, 0.09709057837192502, 0.18410872508372578, 0.09612334027354207, 0.1515107357076236, 0.1803170713995184, 0.2081078572997025, 0.08689209526138646, 0.16604467082236493, 0.15196411923638412, 0.12219825360391821, 0.13036154556487287, 0.21904749742576055, 0.12672837051962102, 0.30120014771819115, 0.13876425182180746, 0.15769479530198233, 0.10689868671553475, 0.1619207521102258, 0.21162697060831956, 0.13303303292819432, 0.13007077973868164, 0.235051017254591, 0.08227148891559669, 0.1262541152536869, 0.2808119888816561, 0.13559718962226594, 0.4136644500706877, 0.7387944651501519, 0.2557925842702389, 1.4016703069210052, 7.219637785639081, 9.647832563945226, 24.800073214939662, 45.51798595700945, 67.29836859021867, 82.00637095315116, 88.2951854978289, 112.87549413953508, 122.13925634111676, 127.2073974609375, 128.4460667201451, 127.44477571759904, 111.32619176592145, 122.83479881286621, 122.12743050711495, 119.61997849600655, 108.44888714381626, 102.97638171059745, 106.19240406581334, 119.51767321995327, 114.52315521240234, 126.97805132184709, 104.09973171779087, 128.66121074131556, 119.5859740121024, 95.20739936828613, 113.25952107565743, 123.96246365138462, 115.19571304321289, 120.63879285539899, 122.71337209429059, 145.26184681483676, 128.54870550973075, 122.4125428880964, 106.98683329990932, 121.34149197169712, 116.59502465384347, 134.63008853367396, 137.62684658595492, 151.78263391767229, 141.23721395220076, 136.80690356663294, 116.66742488316127, 73.60534572601318, 32.322130475725444, 12.964000173977443, 4.163012317248753, 0.21245687321892806, 0.9989596647875649, 0.31379063640322, 0.0961528429761529, 0.26272001968962805, 0.3826815097459725, 0.21135628941868032, 0.28582242716635975, 0.2093753878559385, 0.12340686017913477, 0.09689822726483856, 0.15866812664483274, 0.10152902520660843, 0.1810979973524809, 0.20774991650666508, 0.12009996548295021, 0.12410765114639487, 0.1593975925019809, 0.21980012846844538, 0.19835543632507324, 0.19005696661770344, 0.15393872399415287, 0.11303862117763076, 0.27465222084096497, 0.16199137403496675, 0.2540299402815955, 0.12250852052654539, 0.08432231351201024, 0.1340957816158022, 0.17813669411199434, 0.08363479468971491, 0.1906596685626677, 0.23840213886329106, 0.14297595939465932, 0.18702479717986925, 0.15210311034960405, 0.1312306403581585, 0.14560601540974208, 0.18535618457411016, 0.12026387240205492, 0.0910228875332645, 0.09164629836699792, 0.12019240909389087, 0.10605186144156115, 0.21867346178208077, 0.13195702566632203, 0.21316605087901863, 0.17872452256934984, 0.11333311216107436, 0.09461727073150021, 0.19231469689735345, 0.09132083225995302, 0.15968539991549083, 0.25173016797219006, 0.06083412495042596, 0.17110906621175154, 0.19870364692594322, 0.17253442401332514, 0.08753001317381859, 0.11436268048627035, 0.2702105577502932, 0.14948009752801486, 0.12916717465434754, 0.20834704089377606, 0.20180801248976163, 0.14016218323792728, 0.09783284139952489, 0.1190484669059515], [0.03909150504374078, 0.07642831174390656, 0.022171552426048687, 0.06335201234157596, 0.052678293482001336, 0.022027014289051294, 0.04432514063747866, 0.019881605303713253, 0.023611083127824322, 0.034462043815957646, 0.0764612274776612, 0.048084404452570846, 0.047867018795971356, 0.04056427547974246, 0.07604946528694459, 0.05787340525005545, 0.07469576756869044, 0.0295281578520579, 0.06586891585694891, 0.02711065293156675, 0.03481791846986328, 0.07511310731726033, 0.014349432961483086, 0.024102461224954044, 0.036315231517489464, 0.03983133213062372, 0.048739424840148, 0.06588108877518348, 0.06467271968722343, 0.05223123050693955, 0.0216772210052503, 0.06183020078710147, 0.008963055742372359, 0.05766396863119943, 0.023740016655730348, 0.011559033184312284, 0.06064371445349284, 0.036110951764775176, 0.13531941095633165, 0.08955907036683389, 0.06045545491256884, 0.05263564755607929, 0.050307950137981346, 0.045538239114518674, 0.07948178718132631, 0.09943767171353102, 0.07312338479927608, 0.022286582771422606, 0.043307646842939515, 0.015924585850111077, 0.07595032453536987, 0.037259762441473346, 0.10226891336164304, 0.017407583505181328, 0.026131932324330722, 0.18016315251588821, 0.15016245948416845, 3.7528228078569685, 15.158250842775617, 44.110072476523264, 57.30595575060163, 75.51247337886265, 80.33958148956299, 79.24232196807861, 88.01488127027238, 89.97687884739467, 79.8826471056257, 83.73721585954938, 84.43504428863525, 80.01385688781738, 68.84289755140031, 63.5360997063773, 49.03069291796003, 43.78107874734061, 41.35428837367466, 57.7453042439052, 36.851973806108745, 52.405443395887104, 43.79259538650513, 30.199438435690745, 54.955223832811626, 41.62384373801095, 48.22659526552473, 39.09439720426287, 44.33443675722395, 35.85043266841343, 38.51450054986136, 31.83213656289237, 36.491046156202046, 38.86848694937569, 18.104537180491857, 39.54651996067592, 29.021499906267437, 54.34192371368408, 63.420426096235005, 39.169000012534006, 33.384082726069856, 69.47982501983643, 69.34163229806083, 77.9982053211757, 83.76131221226284, 98.79629680088588, 91.17672852107457, 98.40781606946672, 103.99986525944301, 99.8272705078125, 101.01229272569928, 85.91949912479946, 53.88330439158848, 20.91648530960083, 2.3450776040554047, 0.13214913250080176, 0.23867740694965633, 0.06740166539592402, 0.07696584040032965, 0.07767278568020888, 0.07740823844713823, 0.185460896098188, 0.14635065330990724, 0.1483997476420232, 0.08382673867579017, 0.07008905762008258, 0.0610333631879517, 0.11290973345083849, 0.13585254949118408, 0.05698689924819129, 0.051185258597667725, 0.10498834600938217, 0.06450387303318296, 0.03195867028885654, 0.09948823614312069, 0.07991195124174867, 0.05624299416584628, 0.08610603958368301, 0.049459092651626894, 0.09207997723881688, 0.025316482509619424, 0.016146280204078982, 0.01633134893407779, 0.03331754183662789, 0.036574075663728375, 0.058143360407224724, 0.013374199176074138, 0.05131058740828719, 0.03757730665217553, 0.06047724945736783, 0.07812487320708376, 0.0447383379297597, 0.07851174673331635, 0.10993476451507636, 0.06560124057744231, 0.02324167509297175, 0.09683354930686099, 0.11833311457719121, 0.08615855140877621, 0.07217429072729178, 0.1058583025421415, 0.03696691690544997, 0.08906867275280611, 0.013886248842546982, 0.043639196016426594, 0.002547576478848766, 0.10762672764914376, 0.11223833662058626, 0.06202014309487172, 0.090158637480012, 0.07902532988893134, 0.03724517393857241, 0.01835694390216044, 0.05168056880523052, 0.06390174105763435, 0.04168196175513523, 0.014986277092248201, 0.03481737903452345, 0.08210408075579576, 0.04095354762726596, 0.04217133478128484, 0.04973417753353715, 0.07232296453522784, 0.09282639968608107, 0.052408155120377026, 0.065077676171703, 0.13267912263316767, 0.004199197931614305, 0.0753210647297757, 0.048394630663096905, 0.06389914226851293, 0.06571256103260176, 0.04765491892716714, 0.04735176983688559, 0.11597813665866852, 0.07037991165582623, 0.06118928374988692, 0.0686889820333038, 0.06667101888784341, 0.06120819452085665, 0.09784147915031229, 0.06612848264298268, 0.04086725154359426, 0.1272761518401759, 0.06527591017740113, 0.027838600566610694, 0.037630473263561726, 0.0817555987409183, 0.050092474557459354, 0.03286296408623457, 0.04162818106955715, 0.10374568376157965, 0.03919946675055793, 0.03316338546574116, 0.048603331071457694, 0.028406096722132394, 0.08894752032522645, 0.04199777909421495, 0.07509904128632375, 0.13234742757465157, 0.08011923690459558, 0.059286339075437615, 0.058055510478360314, 0.08705693855881691, 0.07856089981006724, 0.0876311148915972, 0.11099229526839086, 0.08463731660906758, 0.02394133121041315, 0.08790386561304331, 0.06729764597756521, 0.015468003028737647, 0.1262209756033761, 0.08093003875442914, 0.15681602459933075, 0.15533056216580526, 0.12844733042376383, 1.9043164551258087, 10.377654841967992, 38.95744126183646, 59.606045722961426, 81.70462458474296, 91.81021663120815, 95.3865030833653, 102.78183909824916, 103.74469266619, 90.47977556501115, 98.8938217163086, 94.73185076032365, 104.60713781629289, 93.8170439856393, 103.80553804125104, 94.21397372654506, 77.34704794202531, 85.9495917728969, 92.86791310991559, 68.76721082414899, 78.83871500832694, 83.13408442905971, 54.893714904785156, 106.13836097717285, 79.60814462389264, 90.92902524130685, 85.1101382119315, 85.66488238743374, 83.0139639718192, 67.59213147844586, 67.58217470986503, 81.05036136082241, 75.01539925166539, 54.33119569505964, 71.52914755684989, 62.010810307094026, 101.51900400434221, 113.59768295288086, 70.45330933162144, 64.39598791939872, 118.12913131713867, 107.4187263761248, 109.70560087476457, 108.2959156036377, 121.71549960545131, 112.36545467376709, 118.72382763453892, 124.51398386274064, 119.84255708966936, 116.71925844464982, 101.25004618508476, 59.05356666019985, 22.180987971169607, 1.9936650778566087, 0.08795666242284433, 0.3531602695584297, 0.06245945380734546, 0.03547418736187475, 0.01808781995038901, 0.15036394367260592, 0.26538435529385296, 0.18640696390398911, 0.1923951440091644, 0.06131417490541935, 0.06976708596838371, 0.05604742341009634, 0.09203125842447792, 0.06291253199534756, 0.11405858823231288, 0.04068836935662797, 0.1177050354225295, 0.04760461234088455, 0.09508367534726858, 0.06427068090332405, 0.015932195620345216, 0.0963414553552866, 0.07575295905449561, 0.046988044532814195, 0.09219826624861785, 0.033372699948293824, 0.09709574880876712, 0.08008061469133411, 0.006788475264329463, 0.11821604014507361, 0.0548220841613199, 0.009094944290284599, 0.09415152429469995, 0.08371157092707497, 0.04412036555420075, 0.1430198470396655, 0.09160187467932701, 0.07493361444877726, 0.11574603697018963, 0.11283358825104577, 0.06820474551724535, 0.15775598558996404, 0.04604773070397122, 0.07610605510749988, 0.10033953296286718, 0.07536094901817185, 0.00898594527305769, 0.037045040034822056, 0.01987664182005184, 0.023104717888470207, 0.1034445431349533, 0.087138118488448, 0.05382099734353168, 0.060964206898851056, 0.10634620993265084, 0.08334993890353612, 0.06232407928577491, 0.08668554920170989, 0.07875829243234225, 0.07304978410580329, 0.05729973103318896, 0.12442600620644433, 0.0845865486189723, 0.11631171804453645, 0.03011510082121406, 0.14125488246125834, 0.17786542938223907, 0.2268762851932219, 0.19050933234393597, 0.17467795684933662, 0.20445123208420618, 0.17450513398008688, 0.12416922141398702, 0.1449470900531326, 0.30516841049705234, 0.2111713072018964, 0.15491072540836676, 0.1579615952713149, 0.14563365892640182, 0.20122159538524492, 0.1368946707142251, 0.1870186496526003, 0.24795602049146379, 0.18698989333850996, 0.1988786139658519, 0.20134112611413002, 0.20806570670434407, 0.07890396711549588, 0.19379714663539613, 0.16317003007446015, 0.16834045334586076, 0.28988812757389887, 0.16214635143322603, 0.14147486351430416, 0.1083565124177507, 0.15287588031164237, 0.1392316267426525, 0.12715461264763558, 0.22532177503619874, 0.15905111895075866, 0.15267822306071008, 0.23125624230929784, 0.12760232362364018, 0.19752751503671917, 0.20688740350306034, 0.16611967608332634, 0.14641390634434565, 0.11127874561186347, 0.25635663686054094, 0.23022223636507988, 0.20613897937749112, 0.20773835426994733, 0.19039730621235712, 0.11350465938448906, 0.1594916238848652, 0.13817809256059782, 0.3394693599215576, 0.20757508517376014, 0.2041511024747576, 0.3848217991845948, 0.5170835277863911, 0.2814102124954973, 8.951829774039131, 29.56917428970337, 68.38562965393066, 90.04953616006034, 106.78261879512242, 111.3007961000715, 110.72026715959821, 113.99753093719482, 114.49630042484829, 101.96908746446881, 107.96615409851074, 106.84461757114956, 101.37830993107387, 93.0081069128854, 83.83761038099016, 68.33260795048305, 67.36757959638322, 57.72670044217791, 80.9011765888759, 54.84142623628889, 76.82515484946114, 69.68956334250313, 41.30605745315552, 73.82301194327218, 63.59215777260916, 69.57573795318604, 56.3815917287554, 61.74657031467983, 56.11130332946777, 56.184269836970735, 44.97343478884016, 51.96825579234532, 54.47759076527187, 29.077978338514054, 60.455476897103445, 41.1413573537554, 76.91728796277727, 89.45766775948661, 58.09995419638497, 52.147800718035015, 103.19596563066754, 95.01718548366001, 104.52982521057129, 108.79353863852364, 120.7815922328404, 114.09682069505963, 124.15776361737932, 135.9661020551409, 135.81618772234236, 138.12197521754672, 117.79072625296456, 78.21756689889091, 32.715732029506135, 4.991588473320007, 0.2324951115463461, 0.6413374575121062, 0.19796344664480003, 0.11082504317164421, 0.13961204061550753, 0.1966607001210962, 0.35599155191864285, 0.29154242309076445, 0.43108510385666576, 0.2480461299419403, 0.22401577154440538, 0.16776547634175845, 0.29729827280555454, 0.19291011137621744, 0.20566053076514176, 0.14656352331595762, 0.22636810317635536, 0.1069089529503669, 0.16032025084963866, 0.20890852862170764, 0.3911954957459654, 0.1865445300936699, 0.17117607833019324, 0.14916774071753025, 0.19575208744832448, 0.09723623948437826, 0.13497050824974263, 0.09709040873817035, 0.1816752813756466, 0.2244650295802525, 0.16393065425966466, 0.16427043745560305, 0.15272316922034535, 0.1962087279451745, 0.18233662231692246, 0.3084942634616579, 0.21233662324292318, 0.14071513499532426, 0.21835655878697122, 0.18602515224899563, 0.1505542184625353, 0.19645686820149422, 0.23436219564505986, 0.14835818058678082, 0.18188907418932232, 0.20041048819465296, 0.18190092141074793, 0.1734781712293625, 0.0985536016523838, 0.2091099178152425, 0.26587623889957157, 0.16792649270168372, 0.16359986843807356, 0.1679649656372411, 0.24702659036431993, 0.13048681670001575, 0.1520197591079133, 0.24213568280850137, 0.12786184969757283, 0.10811300655560833, 0.08278110942670278, 0.2557020405573504, 0.15385169509266103, 0.21232105764959538, 0.15820589501942905], [0.015993742139211724, 0.051068693066814115, 0.016333545691200664, 0.08313609859240906, 0.029389207450939075, 0.02959661864276443, 0.014826958766207099, 0.04019902007920401, 0.035863669855254035, 0.03071153988795621, 0.04128761416567223, 0.026584750972688198, 0.0143982739121254, 0.009237064298109283, 0.036207249454621754, 0.041873936275286336, 0.026988844021356533, 0.07407241780310869, 0.012490150319146258, 0.03447799278157098, 0.09452596705939088, 0.04405930418787258, 0.08341418259910174, 0.05788903869688511, 0.03724102808960846, 0.05411532887124589, 0.03678921197674104, 0.02163418661803007, 0.07455924632293837, 0.05523863680926817, 0.03591046841549022, 0.010028251396891261, 0.08326195326766797, 0.06414450731660638, 0.053289897806410275, 0.0059823701490781134, 0.05977825660790716, 0.03796547278761864, 0.016056671173178723, 0.06999364202576024, 0.01868862538997616, 0.06225123176617282, 0.04811338807589241, 0.04632126513336386, 0.05932710545935801, 0.03088990638830832, 0.06682878506502934, 0.11024839018604585, 0.061131710053554604, 0.17669940766479286, 0.06653668252485138, 0.1323116280670677, 0.3995390066078731, 0.11869927921465465, 0.8728196248412132, 9.146363701139178, 34.469064780644004, 70.76818084716797, 81.8893563406808, 69.74183464050293, 75.46153613499233, 74.31184550694057, 77.29547146388462, 78.12416921343122, 78.65380259922573, 56.88852187565395, 64.31080300467355, 75.1485823222569, 87.29112216404506, 35.52450656890869, 33.07167434692383, 34.1587165423802, 36.886051246098106, 37.452374594552175, 36.60551077978951, 48.24363572256905, 79.10339968545097, 51.93952151707241, 52.68829066412789, 76.18854699816022, 36.0874148777553, 43.72612197058541, 47.62013564790998, 52.1782477242606, 36.58372470310756, 48.338780879974365, 63.42945875440325, 70.89171286991665, 61.99321746826172, 68.72352055140904, 93.98950522286552, 66.44449751717704, 72.7720969063895, 60.99446255820138, 39.51054566247122, 52.578120027269634, 53.16979387828282, 29.744122982025146, 27.1653824533735, 30.46146195275443, 28.26778016771589, 45.123488085610525, 47.9824355670384, 72.69087246486119, 97.49796336037772, 86.56029673985073, 94.26108946119035, 93.18803746359688, 110.4474183491298, 105.67745917184013, 86.11020633152553, 42.14047704424177, 11.922405276979719, 0.4778249572430338, 0.15711605921387672, 0.06840998200433594, 0.01579660057489361, 0.23599513087953838, 0.17582516957606587, 0.19684452882834844, 0.10476987808942795, 0.07209545174347502, 0.007898475010214108, 0.09243968222290277, 0.049610341499958716, 0.052322235623640675, 0.07341613194772176, 0.04227937112695404, 0.09698880490447793, 0.006719314310300563, 0.05424517333241446, 0.0355377185956708, 0.08364440953092915, 0.023152842984667847, 0.04049839312210679, 0.07563285157084465, 0.04303994102935706, 0.06850454942988497, 0.06424648434455905, 0.01579766078586025, 0.20838826868150914, 0.04999498264597995, 0.0343365080521575, 0.10105137048023087, 0.04987304651045373, 0.027500922525567666, 0.01829970268798726, 0.07153160271367856, 0.0075396945300911155, 0.054816255545509715, 0.09427025435226304, 0.03575493122584053, 0.07124237716197968, 0.004297627917756992, 0.009985349323999668, 0.03694522753357887, 0.04340057560641851, 0.03157215638618384, 0.06507894503218786, 0.07081743782120091, 0.032678952174527306, 0.056350647139229944, 0.01797408391056316, 0.03963692845510585, 0.03124484805656331, 0.05270464438945055, 0.016907664348504374, 0.03588347629244838, 0.04604876546987465, 0.09421002079865762, 0.004280246395085539, 0.06872592826506921, 0.040802716077970605, 0.01563491585797497, 0.035369492801172395, 0.0340070250178022, 0.026647595189777867, 0.06559125932731799, 0.05816712270357779, 0.06612819765827485, 0.02623032668738493, 0.028381884896329472, 0.014575490295620901, 0.0472325308780585, 0.048498534730502536, 0.07631952900971685, 0.05300490292055266, 0.04330103451918278, 0.027851345150598457, 0.032470112666487694, 0.03045397817290255, 0.058925636644874296, 0.021652904006519487, 0.0634390955258693, 0.006095232150983065, 0.06639282631554774, 0.061134084926119873, 0.02109306681502078, 0.020505263802728484, 0.022845123961035694, 0.002835832573639761, 0.031488791573792696, 0.024766177038795183, 0.06469604093581438, 0.010074494406580925, 0.07157428256635155, 0.03960856569132634, 0.0414897972451789, 0.00765393183766199, 0.05519893911800214, 0.04718358136181321, 0.0018680980844822312, 0.0633030424692801, 0.033274766989052296, 0.058403273246118, 0.03061598858663014, 0.058790642102914195, 0.021909312212041447, 0.03383640738736306, 0.059693229384720325, 0.03741818679762738, 0.11366018639611346, 0.042975381815007756, 0.0597228135115334, 0.06023598276078701, 0.08956892269530467, 0.05190539799098458, 0.12919378679777893, 0.13501040610883916, 0.12804612623793737, 0.781594662794045, 6.771833334650312, 32.47854484830584, 74.58705670492989, 93.0109417779105, 88.21150834219796, 89.61755275726318, 90.87715693882534, 87.2090014048985, 85.26489543914795, 96.88487516130719, 89.44888523646763, 105.01318359375, 109.695129939488, 111.05450330461774, 57.87233468464443, 54.06911311830793, 36.34841006142752, 27.250018460409983, 32.35070146833147, 23.29112250464303, 40.32577085494995, 51.840808459690635, 43.617403507232666, 42.73839732578823, 28.19807583945138, 25.858520099094935, 29.934072835104807, 28.433925492422922, 30.591747624533518, 19.39446677480425, 27.054701123918804, 39.35558346339634, 35.077466419764924, 30.552163737160818, 30.148014817919048, 28.825842108045304, 42.57037251336234, 36.54022550582886, 43.412619250161306, 35.214113167354036, 38.41459240232195, 34.90877110617501, 36.46276003973824, 37.216170583452495, 53.801405974796836, 59.34217398507254, 83.8657922744751, 89.18569442204067, 108.72395937783378, 114.56205817631313, 100.75550815037319, 106.1040438243321, 104.93316813877651, 125.12421635219029, 121.45424733843122, 97.37139497484479, 48.72734151567732, 13.066763162612915, 0.11895786891026155, 0.09441339809979711, 0.06893124617636204, 0.04680818186274596, 0.06185020399945123, 0.06490737745272261, 0.1367035816822733, 0.046521141193807125, 0.07941373011895589, 0.05334296263754368, 0.04694904912529247, 0.05238315449761493, 0.04234690911003521, 0.02134993133534278, 0.03437930664845875, 0.03083046672067472, 0.030105913457061564, 0.04952633886465004, 0.05841635540127754, 0.1352694979203599, 0.049235498399606774, 0.024520722084811757, 0.06154160627296992, 0.045766080995755534, 0.02950731325628502, 0.030000621785542796, 0.053868040176374574, 0.015011566092393227, 0.062089876138738224, 0.01985544099339417, 0.035822923827384195, 0.016896799306518266, 0.049227081172700436, 0.0649237030052713, 0.06095517559775284, 0.044784569913255315, 0.036864580253937414, 0.03511066222563386, 0.04821635237229722, 0.09266678110829421, 0.004284531343728304, 0.028542266826012304, 0.0324201555257397, 0.010332050184453172, 0.05565698418234076, 0.025433729968166778, 0.046736576062227995, 0.01970853646551924, 0.014975688553282192, 0.08463454818619148, 0.025125283215727125, 0.07402089663914271, 0.00702510035729834, 0.038049051338540654, 0.05314474220254591, 0.07480011946920838, 0.07294185632573706, 0.051095803933484216, 0.011224683357535728, 0.07884096513901438, 0.006833748393026846, 0.03927013278007507, 0.01535283019100981, 0.0707615672477654, 0.17128887799169334, 0.0736026612243482, 0.09217758450124945, 0.09888524921344859, 0.11333961252655302, 0.15680032329899923, 0.14010262143399033, 0.12303272954055242, 0.1363251084195716, 0.1153848934918642, 0.09735889825969934, 0.2461573870054313, 0.13645248301327229, 0.11314350912081343, 0.20413476335150854, 0.11510027519294194, 0.19854074423866613, 0.11060745056186404, 0.20252754459423677, 0.14701237423079355, 0.1406851573182004, 0.1318532233791692, 0.11169267232928957, 0.12445521035364696, 0.22347902320325375, 0.17267332013164247, 0.1317273551332099, 0.10641276064727988, 0.10720077050583703, 0.05583053308406046, 0.1204960670854364, 0.1812482521470104, 0.14550152101687022, 0.11322309449315071, 0.24141969265682356, 0.1942203217851264, 0.1923200437533004, 0.15629983586924417, 0.23698334928069795, 0.18274632176118238, 0.13776057639292308, 0.1779604378555502, 0.18680951158915246, 0.14129680235471043, 0.1413760416741882, 0.16729215745415005, 0.2799748123756477, 0.1275818454367774, 0.2599476884518351, 0.16386354714632034, 0.4375072478183678, 0.4258319671664919, 0.2589030702199255, 2.859847273145403, 20.81317949295044, 59.88897636958531, 100.51407214573452, 110.9324929373605, 95.91886016300747, 96.71461650303432, 95.58167798178536, 96.76945168631417, 94.0018174307687, 103.00813497815813, 76.21859795706612, 86.42301423209054, 95.44712611607143, 112.78447273799351, 51.543001719883506, 48.65340573447091, 46.0695652280535, 48.90742492675781, 52.75865854535784, 47.96336623600551, 62.88628332955496, 101.63760280609131, 76.0944128036499, 75.82709475925991, 107.62099538530622, 52.14454896109444, 62.96199090140206, 73.16795662471226, 73.58678708757672, 53.473353726523264, 67.051089150565, 93.68151937212262, 94.68835503714425, 83.8018410546439, 88.006258555821, 121.51779556274414, 92.26703984396798, 100.22429752349854, 78.02037007468087, 51.92275203977312, 68.9530473436628, 68.76725251334054, 41.20658356802804, 35.674316678728374, 42.65749944959368, 45.98749658039638, 65.30909238542829, 69.84031145913261, 97.11361680712018, 120.12833649771554, 108.25090517316545, 115.62536185128349, 115.08593845367432, 135.18017741612024, 138.52447046552385, 118.7754944392613, 68.5237181527274, 21.21910193988255, 0.8468718486172813, 0.2382548696228436, 0.09909979520099503, 0.08116578896130834, 0.27722856402397156, 0.32614605341638836, 0.2959789021738938, 0.19824788852461747, 0.220528956502676, 0.17462854592927865, 0.16499551997653075, 0.13106652987854822, 0.11015207892549889, 0.1489077125276838, 0.12093719627176013, 0.11992429276662213, 0.08076286129653454, 0.18193624594381877, 0.19799300363021238, 0.33366443855421885, 0.193382344607796, 0.13419188931584358, 0.22026485710271768, 0.07231213511633021, 0.1269958625946726, 0.14136210456490517, 0.13424375653266907, 0.2556037615452494, 0.21064563255224908, 0.1378548927605152, 0.1758548351270812, 0.1815753738795008, 0.19318664153771742, 0.16137591563165188, 0.24078699946403503, 0.09639613849243947, 0.10823169590107032, 0.2827581630221435, 0.13025049652372087, 0.18539488821157388, 0.07111021211104733, 0.154969133702772, 0.1654453751231943, 0.17109991955970014, 0.12691698968410492, 0.08433254582009145, 0.1457140381847109, 0.13058213729943546, 0.17233740458531038, 0.12883478749011243, 0.1406990537153823, 0.19265420867928437, 0.12491425286446299, 0.09624418736036335, 0.10323294877473797, 0.12545881792902946, 0.2408536316028663, 0.08655718394688197, 0.16632019675203732, 0.12085735984146595, 0.10309730962451015, 0.08768566910709653, 0.13681936689785548], [0.024323865505201474, 0.05415401554533413, 0.06274424852537257, 0.04025794066754835, 0.0131334066058376, 0.04829011930684958, 0.05459338393328445, 0.0736397635191679, 0.03817749123222061, 0.07347877430064337, 0.11686348915100098, 0.021423974772915244, 0.02138386826430048, 0.006934087607078254, 0.09351189647402082, 0.036257820669561625, 0.052427310163953474, 0.04257426244605865, 0.04323223106829183, 0.05988615724657263, 0.022389394397448217, 0.013044448120386472, 0.029332173189946582, 0.03348719594734056, 0.0815958987389292, 0.02277094142378441, 0.04941010920863066, 0.04017970557989819, 0.027538250433281064, 0.02678492389220212, 0.04040228542206543, 0.029950695178870643, 0.014590441814756818, 0.06875313073396683, 0.01844261403727744, 0.03904316620901227, 0.04764064255037478, 0.06955618371388742, 0.04018573097086378, 0.043752151740981, 0.09965437544243676, 0.019093973728428994, 0.040199505231742344, 0.074609736113676, 0.16436195825891836, 0.031145880331418345, 0.03662701157320823, 0.022792335632922392, 0.035228825706456385, 0.20646177205656255, 0.6557624606149537, 4.212516929422106, 16.823275463921682, 35.94870451518467, 60.05205059051514, 89.85709885188511, 92.53166893550328, 85.53608363015312, 67.34758268083844, 72.223251751491, 68.03844206673759, 63.56874234335763, 56.670174734933035, 38.924572808401926, 28.26077117238726, 23.564316987991333, 17.8841107913426, 13.886846882956368, 28.72631958552769, 55.02558476584298, 58.36511829921177, 92.92958532060895, 102.74008737291608, 97.32445294516427, 122.15401431492397, 91.78279209136963, 100.63043362753731, 72.67417594364711, 93.79578249795097, 88.18122114453996, 132.3619463784354, 92.45022215162004, 102.3425600869315, 144.69456808907645, 105.05954197474888, 135.48139572143555, 93.4542646408081, 101.22859014783586, 108.79121099199567, 101.92117268698556, 129.76273645673479, 85.47842747824532, 104.25477382114956, 131.38475172860282, 127.91333443777901, 107.43977941785539, 101.34495162963867, 133.51080322265625, 113.456453868321, 91.94904858725411, 54.989996092660085, 32.44902890069144, 26.974697828292847, 26.092172384262085, 38.497182164873394, 48.199955872126985, 65.30942589896065, 65.71975871494838, 76.13977759225028, 86.7454662322998, 78.79821395874023, 98.84997163500104, 92.9852751323155, 63.25942938668387, 23.95825031825474, 3.5277545877865384, 0.3617033511400223, 0.2029222348438842, 0.26775819648589405, 0.2831689209810325, 0.2972688243857452, 0.15217785776725837, 0.015606860131291407, 0.10035778555486884, 0.057971684262156487, 0.02143946403105344, 0.062149743283433576, 0.0397347494560693, 0.057659374949123175, 0.028834956298981394, 0.026030133411820446, 0.093486105357962, 0.07117446937731334, 0.0804595018603972, 0.03611236311761396, 0.07644813175180129, 0.007482651787410889, 0.016406333838988627, 0.027512028447485397, 0.05732601069446121, 0.09552215824701957, 0.04669499882896032, 0.045586659373449426, 0.027616449897842746, 0.035903666101928265, 0.03485157380678824, 0.051570466320429525, 0.016021117634539093, 0.11626974386828286, 0.011412292353010603, 0.0928590643618788, 0.026865717056872587, 0.053389611920075755, 0.09007843464080777, 0.057431258261203766, 0.06534293586654322, 0.022071561809363108, 0.05048616057527917, 0.03706473790641342, 0.06863353893693004, 0.07191987402204957, 0.007476445736496576, 0.013420302237916206, 0.013908485283276864, 0.00594706045896081, 0.024686194723472, 0.03694447096703308, 0.040898538793304136, 0.0382177622855774, 0.037056673517716784, 0.0019265699915454856, 0.02772016397544316, 0.032535760929541926, 0.09577497360961777, 0.00394874217454344, 0.02594222580747945, 0.00824168904884053, 0.018858927501631633, 0.03399490638236914, 0.03828074051333325, 0.0150924576446414, 0.019314399221912026, 0.020950277602033954, 0.0313490235379764, 0.02869979551594172, 0.012001723849347659, 0.033586713285850625, 0.04881554289853998, 0.0477589587015765, 0.07981585711240768, 0.03486465935462287, 0.01690945228827851, 0.044889183049755435, 0.049310269565986733, 0.023000491516930715, 0.05841081177017518, 0.08745296552245106, 0.012385693245700427, 0.04900330710890038, 0.005281423966932509, 0.018037940841168165, 0.010628571683940078, 0.06520010424511773, 0.08714265788772277, 0.07172618620097637, 0.04484360585255282, 0.025877245901418582, 0.013277749664017131, 0.036453893541225364, 0.015536088928846377, 0.03319120879418083, 0.038051480493907414, 0.027439077451292957, 0.04481346871969955, 0.032945867494813035, 0.06719788775912353, 0.04420506029522844, 0.05172318758975182, 0.03134139680436679, 0.04708359922681536, 0.10373663210443088, 0.041477576829493046, 0.037079139812184234, 0.011383471578093511, 0.10590291621961764, 0.13468479072409018, 0.3557656268988337, 0.4348743962390082, 8.288031884602137, 29.373763152531215, 53.69615118844168, 89.60253075190953, 104.53401497432164, 97.63042381831578, 83.18184634617397, 82.10796056474958, 88.60878549303327, 84.3377764565604, 90.63180215018136, 74.62945461273193, 63.848497663225444, 39.0809211730957, 32.07727943147932, 33.18093476976667, 43.73123237064907, 34.77319090706961, 35.11312804903303, 61.376134055001394, 65.94311550685337, 78.38656098502022, 82.65023967197963, 70.40080874306815, 88.10604163578579, 69.72322041647774, 69.41082940782819, 78.80906009674072, 82.12847859518868, 72.30901336669922, 77.90971306392125, 90.35732051304409, 76.41650349753243, 80.82769938877651, 71.25200475965227, 74.19414302280971, 69.71853038242885, 76.46874005453927, 89.37709644862584, 77.27479362487793, 84.67909976414272, 79.98084599631173, 81.44225365774972, 76.89179502214704, 83.12910951886857, 82.13364110674176, 59.6774662562779, 48.86079209191458, 30.046355724334717, 23.237557104655675, 26.10263637134007, 42.11357709339687, 70.27223232814244, 81.22670664106096, 102.67625427246094, 97.73173550197056, 98.63842678070068, 99.74373926435197, 92.95040212358747, 112.89680426461356, 111.65855189732143, 73.74864537375313, 28.38368480546134, 4.127017608710697, 0.2621748575142452, 0.24174576944538526, 0.25382423560534206, 0.14038148575595447, 0.04703905340284109, 0.05239324431334223, 0.01487384214332061, 0.06948260337646518, 0.025724392317767655, 0.05844123049506119, 0.04120190501479166, 0.05189704183222992, 0.04664538434839674, 0.03285538824275136, 0.038910838309675455, 0.031403258842016966, 0.09147823881357908, 0.03862630482763052, 0.030179588789386407, 0.0832960225109543, 0.017955571778916886, 0.019970279652625322, 0.02335445609475885, 0.048244572643722804, 0.028230339188926985, 0.044069604349455664, 0.03723378472828439, 0.029178485008222715, 0.011270047664376242, 0.059497587382793427, 0.016016603680327535, 0.04209313022771052, 0.03967758288074817, 0.023448463728917495, 0.042339991445520093, 0.02768524656338351, 0.003969064298351961, 0.047790958413055966, 0.058025892424796305, 0.0272758456745318, 0.0364952909627131, 0.038026395054267983, 0.03879900895325201, 0.09698433335870504, 0.011598106623361153, 0.026158373137669902, 0.02448145017426993, 0.002286048514568912, 0.02080496763145285, 0.013253001795549477, 0.017249796971944825, 0.004477639865529324, 0.024142974854579995, 0.07649332896939345, 0.02489615890330502, 0.019194383340488588, 0.015688777967755283, 0.043714791602854214, 0.04988615919968911, 0.02191090676933527, 0.18894435917692526, 0.12248169125190803, 0.13697441214961664, 0.10719384266329662, 0.10983578661190611, 0.14451235266668455, 0.13261339973126138, 0.08814119680651597, 0.15165971485631807, 0.18367577902972698, 0.18021339124866895, 0.21127954710807118, 0.11511742855821337, 0.11225656207118716, 0.1787222834037883, 0.11314088997564145, 0.1322915434305157, 0.15909449090915068, 0.12530922809881823, 0.12190186950777258, 0.2569383042199271, 0.07555111524249826, 0.13805031084588595, 0.08306158866201128, 0.1373935839427369, 0.09033901244401932, 0.12325188278087548, 0.09891970522169556, 0.11636533588171005, 0.131440348391022, 0.15277735702693462, 0.1326012403837272, 0.12516714286591324, 0.2258557142423732, 0.12015859090856143, 0.14919275151831762, 0.10246237726616007, 0.24656589222805841, 0.1080106563333954, 0.18290617104087556, 0.1151480847703559, 0.10807191447487899, 0.11020436683403594, 0.15435818077198096, 0.24122424743005208, 0.1910264031695468, 0.12697284668684006, 0.10257724645946707, 0.22351560981145926, 0.30889687900032314, 1.1587308858122145, 11.113760897091456, 33.844519002096995, 63.72726549421038, 89.52965804508754, 119.89334842136928, 117.2864259992327, 105.21377113887242, 86.71252482278007, 91.28343895503453, 88.80646174294608, 82.79438005174909, 75.05870737348283, 57.42954683303833, 40.65750217437744, 30.248110566820415, 28.008956296103342, 23.470123733792985, 40.4636925969805, 82.00254249572754, 85.86924975258964, 138.90862246922083, 147.5034885406494, 141.00714520045688, 180.81354168483188, 133.37015778677804, 137.74214499337333, 102.75707571847099, 137.07399232046944, 125.2993665422712, 196.64495658874512, 138.99177850995744, 155.06608854021346, 216.79106385367257, 160.01997348240442, 203.8368146078927, 140.7197538103376, 149.50769642421176, 165.32050405229842, 153.2106554848807, 199.20289421081543, 129.630526133946, 151.54218455723353, 181.80734252929688, 188.97122710091728, 157.2514498574393, 152.12130301339286, 186.19568579537528, 161.60448237827845, 125.70942143031529, 80.43522344316754, 46.04293278285435, 38.78346879141671, 35.894769123622346, 54.54043027332851, 67.633542742048, 88.05963461739677, 86.88081019265312, 97.16993195669991, 104.75243159702846, 99.09486784253801, 120.96524701799665, 124.50857816423688, 93.71350193023682, 41.266591685158865, 8.495987125805446, 0.9160513707569667, 0.2888298843588148, 0.4867630547710827, 0.5939013457724026, 0.7056740309510912, 0.312373231032065, 0.16764549777976104, 0.2621149293013981, 0.17490380044494355, 0.12802164469446453, 0.15625345121536935, 0.19311363116971084, 0.15662507127438272, 0.12708354288978235, 0.1320829481950828, 0.16738090983458928, 0.31268052597131046, 0.22174805322928087, 0.13064874229686602, 0.20286309373165878, 0.13504240582031862, 0.12239175822053637, 0.21097008085676602, 0.1139111832848617, 0.2521422558597156, 0.12632910694394792, 0.15394822348441395, 0.11809334744300161, 0.09659524780831166, 0.13300981345985616, 0.12333300842770509, 0.1354778760245868, 0.1745367401412555, 0.07789384560393435, 0.15623433009854384, 0.1298551277390548, 0.07918919609593493, 0.1403697199587311, 0.14280093807194913, 0.20022914292556898, 0.08264217259628431, 0.14181555594716752, 0.077699133194983, 0.32065724794353756, 0.14579327750418866, 0.15175556471305235, 0.11773556949836866, 0.13878991401621274, 0.12229556909629277, 0.1245930479573352, 0.10997261319841657, 0.20076328569224902, 0.0959389755236251, 0.15372693964413234, 0.11948830687573977, 0.11265777982771397, 0.09681987682623522, 0.21684866398572922, 0.13319320790469646, 0.19289739562996797], [0.028416174663496867, 0.10282470818076815, 0.05987986044159957, 0.08901021696094956, 0.046154491403805356, 0.04711389242272292, 0.041393316350877285, 0.0930045083431261, 0.1293677088937589, 0.06682841187076909, 0.1084190665611199, 0.10845658276230097, 0.052447913879794736, 0.07096645768199648, 0.07319874968379736, 0.061963431138013086, 0.19953562585370882, 0.07511424725609166, 0.14479574960257324, 0.12515950256160327, 0.11734014643090111, 0.19078090919979981, 0.06327337691826479, 0.11619962405945573, 0.1533965202314513, 0.03719568498698728, 0.02131466447774853, 0.07235686414475952, 0.04236527705299003, 0.03297715135184782, 0.08658079018018075, 0.0812594403645822, 0.12559111868696554, 0.12323459370860032, 0.07442506602300064, 0.056726111099123955, 0.055667749140411615, 0.0733218766482813, 0.048817961875881465, 0.046791031890149624, 0.07216370558100087, 0.09417124252234187, 0.11420779808291368, 0.1357755764786686, 0.11224867749427046, 0.13190217289541448, 0.14487101270684175, 0.21655952664358274, 1.3865778424910136, 5.435321279934474, 35.70649031230381, 61.809917041233604, 58.47355883462088, 74.43009689876011, 80.88176332201276, 78.08004815237862, 67.48729705810547, 76.16768155779157, 46.90742070334298, 22.342894894736155, 26.810140166963848, 23.116635867527553, 20.299747569220408, 17.385353463036672, 33.58387122835432, 91.0521959577288, 111.76777757917131, 87.75644997188023, 75.09968784877232, 56.2345643724714, 48.22336087908064, 16.98610302380153, 10.988452741077968, 5.036811692374093, 2.6309801254953658, 0.8357039221695491, 0.8670045254485947, 0.8570946572082383, 1.0749657920428684, 0.993882051536015, 1.4997289308479853, 1.1278497257402964, 1.6105682232550211, 1.7827986500092914, 1.512096832905497, 1.4154414193970817, 1.2866564499480384, 1.0202256036656243, 0.45730095569576534, 0.9907983541488647, 1.126022349510874, 1.406615904399327, 1.5071899933474404, 1.630756214261055, 1.4695817828178406, 4.614767253398895, 4.767988928726741, 11.42447999545506, 32.17368221282959, 69.07789952414376, 107.22281496865409, 122.75996671404157, 135.3212397439139, 92.37561239515031, 47.29801368713379, 29.83785765511649, 19.051727771759033, 14.876812321799141, 37.04127747671944, 60.181043897356304, 72.21921484810966, 76.23450238364083, 72.32935769217355, 76.16686861855644, 90.95018945421491, 78.07000800541469, 43.2869610786438, 27.18062332698277, 19.14131784439087, 8.59682720048087, 4.164827534130641, 0.5767193734645844, 0.7194035628012249, 0.0642736189599548, 0.09725521132349968, 0.19491758437028953, 0.09988109434821776, 0.10709803351866347, 0.05802214691149337, 0.18210453619914396, 0.06974845339677163, 0.1069958054327539, 0.14939555206469127, 0.10131710514958416, 0.11638843321374484, 0.05774661419647081, 0.09898981145982232, 0.08484651574066707, 0.08303093244986874, 0.10373120382428169, 0.10291985236108303, 0.14144252453531536, 0.06477236255471196, 0.135093323088118, 0.09411324813429799, 0.04711496790072747, 0.11665341470922742, 0.053509875466781, 0.15899045792009148, 0.12360793724656105, 0.12945988109069212, 0.1135021216635193, 0.08537892824304955, 0.09292329448674407, 0.12944050213055952, 0.033671455524329624, 0.06731466363583292, 0.06895110011100769, 0.17613644073052065, 0.08355456470910992, 0.06148881624851908, 0.06964131950267724, 0.04537025759262698, 0.1540899287377085, 0.06629220635763236, 0.0495818837412766, 0.08584428112953901, 0.06281359480427844, 0.07741841647241797, 0.011507076061596828, 0.11960976464407784, 0.09968630730041436, 0.01907647431029805, 0.08513236218797308, 0.07019330774034772, 0.042751339729875326, 0.05190792553392904, 0.050172192244125266, 0.07233384823692696, 0.06810506193765573, 0.08239154890179634, 0.08519397316766636, 0.061472321062215736, 0.03340957832655736, 0.028305313915812542, 0.045082083770207, 0.05482361086511186, 0.03586235010464277, 0.05366635582010661, 0.07662083248474769, 0.11353403995079653, 0.027788784221879075, 0.08361455399010863, 0.12988644891551562, 0.12235556516264166, 0.14742518136543886, 0.07672458048909903, 0.050283763757241626, 0.028396771954638616, 0.08017933475119726, 0.06631516119731323, 0.11168621946126223, 0.022623565314071517, 0.10923875043434755, 0.12717252597212791, 0.10624989867210388, 0.07029878600899662, 0.038566525892487595, 0.09172624336289507, 0.09553452794040952, 0.06071914719151599, 0.03989028664571898, 0.0798779498519642, 0.12723807245492935, 0.03492364779646907, 0.1295687181076833, 0.040307507650660615, 0.07417575190109865, 0.033167212403246334, 0.133627999573946, 0.12874024042061397, 0.12432635655360562, 0.06878938486001321, 0.12358357783939157, 0.9171546144144875, 2.0893758620534624, 20.76208938871111, 58.09589992250715, 68.19766698564801, 85.69189698355538, 95.36178139277867, 91.94524097442627, 77.93062019348145, 91.89540154593331, 74.27519375937325, 48.82716975893293, 50.296738079616, 49.35610832486834, 35.34209898539952, 27.902343136923655, 22.00268677302769, 57.27336869921003, 49.71205064228603, 28.26928792681013, 51.520336696079795, 56.74016741343907, 50.325204849243164, 25.75889161654881, 17.496205023356847, 7.873879296439035, 4.440411329269409, 1.3518918922969272, 0.39191653419818195, 0.34102871481861385, 0.7756910281521934, 0.7045169930372919, 2.245906616960253, 1.089771426149777, 1.738000682422093, 1.8873517768723624, 1.7677019515207835, 1.9455509739262717, 1.3224571517535617, 0.4719494953751564, 0.39721738547086716, 0.5066891312599182, 0.42259690218738144, 1.456352738397462, 1.498595071690423, 2.6916598294462477, 2.910072760922568, 6.121849766799381, 7.0038041557584485, 15.755790710449219, 32.99950688225882, 60.13481058393206, 80.97237477983747, 69.86872959136963, 76.18476022992814, 46.293245111192974, 32.6837112562997, 25.35519085611616, 32.51942457471575, 31.333137784685405, 68.71876103537423, 93.5602594103132, 91.35973712376186, 88.2119391305106, 82.28315939222063, 89.08764839172363, 107.64634936196464, 92.55381284441266, 52.741350582667756, 30.64097908564976, 20.872525794165476, 7.496238623346601, 2.8894787345613753, 0.3606459493083613, 0.7822794946176665, 0.10670168764357056, 0.08616004418581724, 0.27940953842231203, 0.008840892297614898, 0.09504516848496028, 0.03859575039574078, 0.1613019010318177, 0.12574589252471924, 0.0628882133002792, 0.10716464530144419, 0.10868392592029912, 0.05009821157104202, 0.05916484059499843, 0.09373454416968993, 0.0631555493122765, 0.11853487017963614, 0.09991197447691645, 0.0583505578605192, 0.1680277029850653, 0.10112983626978737, 0.11467107465224606, 0.06107368173875979, 0.05392191246418016, 0.06906288875533001, 0.045553957378225665, 0.1120461822886552, 0.09845021327159234, 0.12046142108738422, 0.11167226878127881, 0.0926095534648214, 0.04138353526858347, 0.07552877108433417, 0.01190210473058479, 0.033973308612725565, 0.05127313227525779, 0.05258710516084518, 0.11334063711443118, 0.053135093434580734, 0.15187684606228555, 0.1211554402751582, 0.07270611290420805, 0.03392890188843012, 0.07332621927240066, 0.01741202112420329, 0.00742845465096512, 0.04432642985401409, 0.0654200581567628, 0.030921305596296276, 0.07475814529295478, 0.007521602241987628, 0.072399998615895, 0.03162857657298446, 0.07339700404554605, 0.17773862475795404, 0.18309017616723264, 0.2104927586125476, 0.23874181349362644, 0.2188035233744553, 0.20448973216116428, 0.1611466250781502, 0.3618140880550657, 0.1895192140447242, 0.15471366526825087, 0.26995209019098965, 0.2180588176207883, 0.18601847546441214, 0.22909005997436388, 0.30098993756941383, 0.11503354805920805, 0.374638698462929, 0.17631876309003147, 0.24950033905250685, 0.3078836633690766, 0.24989036098122597, 0.3075509097959314, 0.2146484191928591, 0.2671525632696492, 0.24284914880990982, 0.1936880110629967, 0.1523086657481534, 0.24283728801778384, 0.31561836547085215, 0.25547234288283754, 0.15691290582929338, 0.21869121225816862, 0.29078591082777294, 0.30256557730691774, 0.163266300622906, 0.20784191228449345, 0.22195295723421232, 0.24091847240924835, 0.2136460194098098, 0.32146497602973667, 0.18961331328111036, 0.15082685383302824, 0.1306870523840189, 0.4138532727956772, 0.21652276361627237, 0.2781169292117868, 0.291513843195779, 0.32661589820470127, 3.6379603999001637, 25.871794632502965, 65.62547166006905, 99.5565686907087, 89.2191083090646, 103.62963744572231, 102.44272531781877, 97.95216015407017, 85.68162059783936, 96.27828352791923, 61.921887261526926, 37.45106833321707, 38.22232532501221, 33.31085566111973, 28.458846943719045, 23.662762539727346, 49.190828050885884, 110.56395353589738, 139.98769160679407, 117.87928799220494, 106.18849223000663, 80.74206978934151, 74.55075236729213, 26.652582815715245, 18.919904811041697, 7.98474041053227, 3.862273003373827, 1.2596422880887985, 1.6089786056961333, 1.11906199157238, 1.5388606424842561, 1.0799007500920976, 2.0619867146015167, 1.581012323498726, 2.6905509403773715, 3.0993013041360036, 2.251811282975333, 2.5799204196248735, 2.2927908897399902, 1.8790519365242548, 0.7845296795879091, 1.1291667350700922, 1.3723377266100474, 2.4415746203490665, 1.574979658637728, 2.9585190755980353, 2.4277390199048177, 6.834318918841226, 8.21096854550498, 18.299957002912247, 46.16698244639805, 95.93783569335938, 152.69316755022322, 175.46823692321777, 189.22348839896065, 130.42446899414062, 67.93906893048967, 44.11639533724104, 28.0790080342974, 23.586916003908428, 50.38026237487793, 79.21502944401333, 94.4497400011335, 97.5454820905413, 90.01619870322091, 94.59165000915527, 118.78687558855329, 109.82514463152204, 72.97221197400773, 45.54028967448643, 33.58509063720703, 17.18779706954956, 9.418242369379316, 1.2586680203676224, 1.0793621561356952, 0.18749127643448965, 0.30343005806207657, 0.6231416996036256, 0.28896146586963106, 0.2566243867788996, 0.2845487897949559, 0.32387532240578104, 0.2666877124990736, 0.2424120365508965, 0.19499363457517965, 0.26761147007346153, 0.22618270026785986, 0.20726624317467213, 0.1761763793017183, 0.29115671664476395, 0.31122865102120806, 0.22485115671796457, 0.18871878699532577, 0.4756414315530232, 0.19429278932511806, 0.32119901744382723, 0.2385032677224704, 0.25321811384388376, 0.22602652864796774, 0.21360461520297186, 0.2558022737503052, 0.29695335988487515, 0.3261641024478844, 0.1590233804391963, 0.2695458377046244, 0.18602930488330977, 0.22182573191821575, 0.15738378199083464, 0.1564560889133385, 0.19531637297144958, 0.24026979293142045, 0.22793410771659442, 0.13122967683843204, 0.3144553835902895, 0.2587547424648489, 0.30865876749157906, 0.1713218955057008, 0.21175308312688554, 0.17163266454424175, 0.22238886170089245, 0.3678180644554751, 0.1089405750057527, 0.2181019995893751, 0.1749559390757765, 0.16703398845025472, 0.21253570541739464, 0.20802893010633333, 0.17774513869413308], [0.0633749400398561, 0.020291669460545694, 0.040286819117942026, 0.05830717911677701, 0.012814432382583618, 0.04022516403347254, 0.1126621292371835, 0.034781864511647394, 0.04327243426814675, 0.06895285751670599, 0.05661083817748087, 0.05938693867730243, 0.019290336673813205, 0.029411117346691232, 0.036841174188469133, 0.017478960300130502, 0.0499353631665664, 0.008653617480636706, 0.07277373570416655, 0.08973382706088678, 0.05221835869763579, 0.03959065915218421, 0.12631010796342576, 0.04101178289524146, 0.04908739795376148, 0.01121828137963478, 0.02677171960073922, 0.05196726002863475, 0.026845863122226934, 0.05621171370148659, 0.012085290525906851, 0.07510045263916254, 0.014060674750778292, 0.024640188352870088, 0.06719902769795486, 0.022576461413076947, 0.046938202743019374, 0.07637961328561817, 0.026782394652920108, 0.001995769325211378, 0.06242094694503716, 0.06539432132350546, 0.08048553724906274, 0.1989004085106509, 0.06456549079822642, 0.06066943093069962, 2.5098688985620226, 18.401329483304703, 46.30712761197771, 65.58397701808384, 75.2037718636649, 73.22479983738491, 53.62474455152239, 67.12107835497174, 69.72789655412946, 80.55066776275635, 90.67045497894287, 53.31244386945452, 30.027810982295446, 53.07419013977051, 55.05761596134731, 28.39621935571943, 57.160342352730886, 72.20424148014614, 90.47861521584647, 83.86642456054688, 60.76245525905064, 53.12037828990391, 15.450464282717023, 1.3086438072579247, 0.17993918167693274, 0.21387431930218423, 0.15090666312192166, 0.09521900237138782, 0.032292655403060574, 0.055082125921866724, 0.17333603171365602, 0.12619779684713908, 0.15534387502287114, 0.09493238239416055, 0.06635973416268826, 0.09503738568829638, 0.03386071251173105, 0.10645587476236479, 0.07894600235990115, 0.05701628659984895, 0.029092300882829086, 0.216383392523442, 0.1489640852170331, 0.38217247277498245, 0.36400277061121805, 0.0411811486285712, 0.12547654126371655, 0.04215572847585593, 0.08210755485509123, 0.14842177288872854, 0.030754511510687213, 0.24189336438264164, 0.8437866855944905, 1.1446831481797355, 0.9505014078957694, 6.355251916817256, 21.76359404836382, 65.35188634055001, 96.29111685071672, 105.44862719944545, 92.46306937081474, 63.81567437308175, 39.58256721496582, 29.559922763279506, 34.056918484824045, 65.72299657549176, 64.2282167162214, 71.43122659410749, 72.70659623827252, 70.57413155691964, 88.48495469774518, 87.14641898018974, 93.74151011875698, 93.63931601388114, 79.64866651807512, 58.15339626584734, 15.586949484688894, 0.8073043546506337, 0.07077594540481057, 0.0813293226861528, 0.13284636794456414, 0.07804073486477137, 0.031381220024611266, 0.05922333709895611, 0.04353824357635208, 0.055571458235915215, 0.023449805531916872, 0.044016661654625616, 0.06657421908208302, 0.0636562267318368, 0.06320977104561669, 0.037008470389992, 0.013725632818282714, 0.04764136179749455, 0.06636153906583786, 0.018439932127616236, 0.05943556928208896, 0.026863596634939313, 0.08206289368016378, 0.06669907631086451, 0.05351604335010052, 0.03879493774314012, 0.043099876027554274, 0.03870951018429228, 0.016557535189869146, 0.02314947745097535, 0.028544115833938122, 0.04535441379994154, 0.025001182553491423, 0.056140691441084654, 0.054422847727047544, 0.03474274696782231, 0.0732495855273945, 0.04757756932771631, 0.03635069175756403, 0.03330828322629843, 0.02591807335349066, 0.008370921980323536, 0.054838084017059634, 0.008155594829336872, 0.02540332481398114, 0.04488866736314126, 0.062188670837453434, 0.05684519060222166, 0.02417791771170284, 0.012990724262116211, 0.01960149247731481, 0.012525529135018587, 0.01608870311507157, 0.015095612832478114, 0.07054731303027698, 0.022586612296955924, 0.03257208290909018, 0.06084534113428422, 0.013741804004114653, 0.035588666397546015, 0.11181303765624762, 0.07938095009220497, 0.03202226598347936, 0.022952793897794824, 0.0210376084516091, 0.04460388282313943, 0.009053974345858608, 0.012609598775660353, 0.041781557125172446, 0.015862761131886925, 0.04998281651309558, 0.0712014954271061, 0.04755859748859491, 0.0617797856352159, 0.04115349493388619, 0.039224491122045686, 0.11839278494673115, 0.10654943795608622, 0.030042032777730907, 0.03819905507511326, 0.055934518575668335, 0.025037979507552724, 0.05695567985198327, 0.024722364032641053, 0.07988154608756304, 0.02255495694199843, 0.02328887059619384, 0.005784466081032795, 0.052346985188445876, 0.061504510763500414, 0.044922468585095236, 0.041745109616645744, 0.00632536578424541, 0.1016352227223771, 0.03666230896487832, 0.09850803802588157, 0.09213002598179237, 0.08163045652742897, 0.26718081746782574, 0.03724942156778915, 0.7801672965288162, 2.750060089996883, 31.064332825796946, 61.966286250523154, 86.29909311022077, 85.40945271083287, 62.853647640773225, 79.43081964765275, 76.83010196685791, 92.53374644688198, 102.83583354949951, 80.89225510188511, 46.056804861341206, 30.828469276428223, 36.68470287322998, 24.638529334749492, 31.766608101981028, 37.363312585013254, 56.464181491306846, 73.77697317940849, 74.02269622257778, 53.39466885157994, 21.492907864706858, 2.247289308479854, 0.18440839328936168, 0.6117096330438341, 0.2691824143486363, 0.18279930177543843, 0.07497189060917922, 0.2287013136914798, 0.1337540985218116, 0.12054831428187233, 0.14563209829585894, 0.03568800053160105, 0.03590860244418893, 0.13636778827224458, 0.0861343616353614, 0.11866765948278563, 0.06882370516125645, 0.09533303696662188, 0.03225506795570254, 0.21059216399277958, 0.16248020423310144, 0.34826643073133057, 0.28669917583465576, 0.16518745039190563, 0.11737553881747381, 0.14166006286229404, 0.17204187544328825, 0.3501884490251541, 0.261730145663023, 0.5753617605992726, 0.9700711177928107, 0.6656509414315224, 0.6484874252762113, 7.965731007712228, 25.84520561354501, 62.627553258623394, 75.30657046181815, 72.96351282937187, 45.36396523884365, 26.910663230078562, 29.763432025909424, 38.45748710632324, 62.43945162636893, 95.94516604287284, 97.03224645342145, 91.16914803641183, 84.29956831250871, 79.03117316109794, 102.0301273890904, 101.88244342803955, 109.28043365478516, 104.684068271092, 88.07456629616874, 62.02517223358154, 13.738423807280403, 0.5330813207796642, 0.08717675427240984, 0.11852337579642024, 0.22687936574220657, 0.08359370939433575, 0.0007875684397211963, 0.08597760647535324, 0.03548800912020462, 0.041121549505208216, 0.08734667979712997, 0.07255928471152272, 0.03455708621601973, 0.08800303350601878, 0.054738319013267756, 0.060618391526596885, 0.009303576845143522, 0.014523848691689116, 0.032660482451319695, 0.04961129144898482, 0.027943322268713797, 0.010936821661224323, 0.052682955017579455, 0.03089369261371238, 0.00925282497025494, 0.030406477328922068, 0.006789805192966014, 0.051304165074335675, 0.027147119099806463, 0.0670976002833673, 0.010550681800980653, 0.03582268634012767, 0.06359008992356913, 0.03224892721378377, 0.12126252667180129, 0.00413666117570496, 0.04088493077350514, 0.025450462641726648, 0.06786973920783826, 0.02908453844221575, 0.04668151633813977, 0.030069069005548954, 0.01514101869958852, 0.060645180089133124, 0.05360750987061432, 0.007618207817098924, 0.011983465320164604, 0.03293474969853248, 0.033131053272102556, 0.05646217454757009, 0.003936076470251594, 0.023217546387708614, 0.023603846551850438, 0.036211110318877866, 0.16687973029911518, 0.08828394021838903, 0.10444253922573157, 0.13974191221807683, 0.12131647020578384, 0.12906825781932899, 0.204863075699125, 0.17350985881473335, 0.10885410928832633, 0.2341965516763074, 0.09554554734911237, 0.11456273975116865, 0.062016743634428294, 0.09319068478154284, 0.11315437925181218, 0.12039913157267229, 0.17025897039898805, 0.08011456858366728, 0.16618865595332213, 0.22645424998232297, 0.11638316778200013, 0.12696500282202447, 0.20897077742431844, 0.11531880418104784, 0.16819459545825208, 0.07437796212200608, 0.19841873007161276, 0.18098219856619835, 0.18780478675450596, 0.11432361043989658, 0.15029287391475268, 0.18784764302628382, 0.08945836898471628, 0.10353121241288525, 0.253699249454907, 0.20895959516721113, 0.21325454541615077, 0.24101460725069046, 0.09691764015172209, 0.2479390571159976, 0.11968854255974293, 0.1359353307634592, 0.22994208282658032, 0.3180758021771908, 0.3373711125126907, 0.1313448649431978, 5.625812223979405, 30.61219964708601, 77.65001719338554, 102.52492250714982, 101.87417507171631, 95.84154755728585, 74.28635951450893, 89.28779820033482, 92.92826516287667, 101.99174554007394, 109.53170136043003, 70.23900604248047, 45.175589152744834, 69.96652548653739, 76.31552532741001, 41.05347306387765, 86.89909785134452, 114.24651963370187, 131.82353046962191, 120.60121699741909, 86.83523695809501, 83.57438482557023, 26.46839996746608, 3.505111059972218, 0.20343158394098282, 0.7547429150768689, 0.29924116283655167, 0.1571126529680831, 0.09411342455340282, 0.27334264825497356, 0.40425468928047587, 0.2102394886314869, 0.22400921689612524, 0.1456317183162485, 0.12305894813367299, 0.19285774204347814, 0.15359694590525969, 0.2160880398005247, 0.14448530626084122, 0.20952349847980908, 0.12022672939513411, 0.3485769826386656, 0.417885779270104, 1.0988783431904656, 0.6758022052901131, 0.33962835424712723, 0.2090010672275509, 0.15242466809494154, 0.20826271256165846, 0.27047583780118395, 0.360307333192655, 0.460332487310682, 1.2109253193650926, 1.2066762787955148, 1.1373149092708315, 10.980363300868444, 33.12274708066668, 98.92987591879708, 146.388274874006, 152.23596218654086, 124.95238740103585, 88.34433010646275, 55.005122320992605, 40.326295443943565, 47.70683874402727, 83.59270027705601, 85.75247832706997, 96.6045639855521, 92.45514147622245, 86.84613868168422, 113.14432689121791, 114.93956770215715, 120.7872758592878, 124.62245913914272, 110.09214305877686, 85.61061000823975, 32.02367407935006, 0.988839287843023, 0.24134782222764833, 0.13084380754402705, 0.415953338678394, 0.2869366630911827, 0.1386543427194868, 0.2205202848251377, 0.11027724149503879, 0.22716702387801238, 0.1703092498438699, 0.11862500677151339, 0.17664018512836524, 0.2647767407553536, 0.15808485794280255, 0.14318649524024554, 0.12676098091261728, 0.15731942972966603, 0.21375602350703307, 0.1043126065550106, 0.13259465859404632, 0.0779059167419161, 0.16469361260533333, 0.2525201184409005, 0.08152489004922764, 0.13780204845326288, 0.24758505182606833, 0.1423858374889408, 0.10386879037001304, 0.1381273517119033, 0.2086655180901289, 0.09678774819310222, 0.10437980187790734, 0.18729619761662825, 0.19288032368889876, 0.11553221701511315, 0.11700538439410073, 0.0760896752721497, 0.13651773094066552, 0.1773366199008056, 0.15002102564488137, 0.0933777161740831, 0.10486834030598402, 0.14510890708437987, 0.1454175862350634, 0.14567210472055844, 0.12875797732600144, 0.09056915795164448, 0.14928245384778294, 0.09352523647248745, 0.09055849816650152, 0.14786622912756034, 0.10681323880063635, 0.09205311403742858], [0.0313318023192031, 0.011171079939231277, 0.04700630051749093, 0.0032502684043720365, 0.029321102891117334, 0.05362761825589197, 0.05290623035814081, 0.02425894157827965, 0.018402115674689412, 0.06636112515947648, 0.012203883180128676, 0.02164366575224059, 0.07825880923441478, 0.040301017463207245, 0.019389664022518054, 0.029296533138092076, 0.01081395338821624, 0.037177038844674826, 0.0014817157539904916, 0.016355143460844244, 0.03068152828408139, 0.07421687112322875, 0.04952721078214901, 0.0860609170049429, 0.06661381838577134, 0.04206246044486761, 0.05532154021784663, 0.026338100100734403, 0.08347534574568272, 0.0741620726351227, 0.135929101811988, 0.021652900613844395, 0.03277882235124707, 0.07481829742235796, 0.07113776741815464, 0.05436002216967089, 0.05720013566315174, 0.05064507008397153, 0.17414058425596782, 0.017894681742680923, 0.0792432821222714, 0.008431579618315612, 0.07525440544954368, 0.09789391633655344, 2.4025763358388628, 25.885598966053553, 53.69814184733799, 66.7839309147426, 73.74988215310233, 77.40175805773053, 72.14627960750035, 77.37558419363839, 52.46506241389683, 51.56810556139265, 73.22471645900181, 42.567798205784385, 17.480932882853917, 21.951096398489817, 34.437922954559326, 106.25119972229004, 73.92585917881557, 89.01831926618303, 84.79324477059501, 65.2740456717355, 34.44149432863508, 16.53723897252764, 1.2129244463784354, 0.4745319996561323, 0.4792642114417893, 0.025629109037773948, 0.2662566527724266, 0.03865947161934205, 0.04321731347590685, 0.04957949869068606, 0.04192864655383995, 0.06423787373517241, 0.2882424630224705, 0.3438119026167052, 0.2706792897411755, 0.3644769580236503, 0.32729101340685574, 0.19308939389884472, 0.3176447967333453, 0.3600082892392363, 0.19441823687936577, 0.18291283425475868, 0.22841217634933336, 0.4628157083477293, 0.18307727043117794, 0.35472252858536585, 0.4416485641683851, 0.2462726022515978, 0.5890776674662317, 0.23769784665533475, 0.09595897195062467, 0.27415211339082035, 0.14192642856921467, 0.1991643722036055, 0.7211548888257572, 0.632605254650116, 0.19560222620410578, 0.2795340360275337, 0.4222238707755293, 0.2933090297239167, 4.871082825320108, 22.679990223475865, 77.05472333090646, 110.36507524762834, 115.11431489671979, 90.85831342424665, 35.16237688064575, 19.23228018624442, 19.936289037976945, 25.293021849223546, 42.45902068274361, 64.24803297860282, 67.81625257219586, 70.20120089394706, 62.633591243198936, 71.83981541224888, 74.2063718523298, 80.45487294878278, 81.50981099264962, 36.690726961408345, 1.9010253974369593, 0.2610071801713535, 0.057703228667378426, 0.032980961325977526, 0.0669715895450541, 0.061587448098829815, 0.04707861877977848, 0.09234708254890782, 0.05275203327515295, 0.102428681217134, 0.02695902919263712, 0.011601116774337632, 0.0313092104957572, 0.029035996046981642, 0.042423332509185584, 0.04367050701486213, 0.003870207683316299, 0.01121941622945347, 0.026022642385214567, 0.047687861802322526, 0.0142097980881642, 0.011883200744965246, 0.03373765340074897, 0.061010564411325116, 0.06257386159683977, 0.0027721003238444348, 0.030350606755486557, 0.01716922772383051, 0.10711443371006421, 0.07537400403193065, 0.024053124943748116, 0.015715001649888496, 0.060940125691039224, 0.018548485856237154, 0.07480273182903018, 0.02410211686843208, 0.0183658496742802, 0.015374249845210994, 0.05232447478920221, 0.05598901850836618, 0.019143450805651288, 0.04452129154066954, 0.028351829187678437, 0.05152145912870765, 0.02364102009284709, 0.05283784081361123, 0.013249492073165519, 0.07247218117117882, 0.027784316068781272, 0.04925070436937468, 0.008439292865140098, 0.013550193348367299, 0.03972376058144229, 0.04877904789256198, 0.01758653693832457, 0.026585975728396858, 0.028452835910554444, 0.04326484485396317, 0.015354416266615902, 0.057972071027117114, 0.01743335765786469, 0.026500224169077616, 0.024477572346638356, 0.00957931312067168, 0.06498500864420619, 0.02937957564634936, 0.0247719411937786, 0.02065018531201141, 0.006141706710747842, 0.006951363532737429, 0.016038688298846995, 0.040599179321101735, 0.046276610743786604, 0.05890009658677237, 0.019024130422621965, 0.042424126395157406, 0.025407177196549516, 0.0031201495606053087, 0.08283432014286518, 0.03605598025023937, 0.05170470768851893, 0.013606639828399887, 0.08320762975407497, 0.0240782341321132, 0.012308609123075647, 0.04845003304736955, 0.034500560856291225, 0.01270344780225839, 0.10595268676323549, 0.03977249635915671, 0.008611929985428495, 0.037628057678895335, 0.06771350651979446, 0.0567265894663121, 0.022831146139651537, 0.02019289511788104, 0.8705783422504152, 8.019912191799708, 38.66727406638009, 70.8798245021275, 85.02825369153703, 87.05349377223423, 80.79977457863944, 83.7378203528268, 62.55213751111712, 71.72587190355573, 80.36104447501046, 67.33099038260323, 49.737342085157124, 35.490714005061555, 29.123793022973196, 105.22604165758405, 63.224063055855886, 36.023689474378315, 65.0883481161935, 56.8006341116769, 41.08216912405831, 17.38251859801156, 1.574618678007807, 0.37341212428041864, 0.9622744790145329, 0.05531959282234311, 0.05957740345703704, 0.06076361159128802, 0.08394482412508555, 0.08666948827781848, 0.04320785469774689, 0.17013185364859446, 0.48356661200523376, 0.2686656963612352, 0.31314306972282274, 0.5567962282470295, 0.37966045471174376, 0.38940082490444183, 0.8679035029241017, 1.1598978574786867, 0.6273110530206135, 0.8143297433853149, 0.7295321907315935, 1.3241109315838133, 0.7313803029911858, 0.7298024648002216, 0.8747417788420404, 0.457326631460871, 0.5947977176734379, 0.25875547528266907, 0.11231801698782615, 0.17520029310669216, 0.011069681362382002, 0.1926354132592678, 0.5312604042036193, 0.2321548940879958, 0.11325253612760987, 0.4316168581800801, 0.7780020641429084, 0.12477455607482366, 4.328264364174434, 23.79239855493818, 70.53375557490757, 84.2111941746303, 72.62210614340646, 54.410571915762766, 27.30327640260969, 34.99896567208426, 38.143421581813264, 49.36280638831002, 73.57981804439, 83.60497774396623, 81.7966673714774, 80.45988954816545, 75.66303389413017, 83.63764122554234, 85.55628899165562, 91.16843237195695, 92.62813772474016, 35.24336855752127, 0.8171081000140735, 0.15686407844935144, 0.13635348475405148, 0.02150717843323946, 0.05338118112246905, 0.05557019955345562, 0.021070083137601614, 0.022383852462683405, 0.020356666329982023, 0.01231342926621437, 0.034639202523976564, 0.027058602510286228, 0.07435789784150464, 0.053750969136932066, 0.01723835347885532, 0.014270180071304952, 0.03896558930033019, 0.06340294996542589, 0.028670455661735365, 0.012924807977729609, 0.014301996578329375, 0.05021747088591967, 0.016419046192563007, 0.058612323100013394, 0.08297390158155135, 0.05047406229589667, 0.028450232032420378, 0.0302342651411891, 0.011315800432514931, 0.07768552178250891, 0.019956912512757947, 0.05967969261109829, 0.02477948650318597, 0.03842581469299538, 0.03316880017518997, 0.039715638517269065, 0.029376461170613766, 0.01660278160125017, 0.04400499424497996, 0.015731483265491467, 0.016680945442723374, 0.0194613817813141, 0.05155547408919249, 0.03395585669204593, 0.0702543216092246, 0.03660163436351078, 0.024002014293468425, 0.03073205878692014, 0.017272543162107468, 0.02776714234745928, 0.04359404968896082, 0.02764856326393783, 0.07674820029309817, 0.11708184172000204, 0.15192313572125776, 0.0691772558327232, 0.17651086992451123, 0.20131118914910726, 0.13136116335434572, 0.13554312395198004, 0.08167032724512474, 0.11654803822083132, 0.08779069954263312, 0.087423673165696, 0.10443387433354344, 0.11726511402853898, 0.10404328243540865, 0.09464762160288435, 0.14830628622855457, 0.11639510999832835, 0.05518293247691222, 0.1432537787726947, 0.11509176636380808, 0.15683423647923128, 0.08432787071381297, 0.18572172495935643, 0.1529421460415636, 0.12290847620793752, 0.1723474876156875, 0.0909298060994063, 0.12038922496140003, 0.14336158441645758, 0.1572290217237813, 0.12448039757353918, 0.15879213570484094, 0.13123914918729238, 0.11025767933045115, 0.11261571744190794, 0.18243671980287346, 0.1207638034330947, 0.3362843708268234, 0.11064167586820466, 0.3277067925248827, 0.14601397780435427, 0.13595118134149484, 0.2074833336685385, 4.623462923935481, 44.34033925192696, 84.19488675253731, 101.27733176095145, 99.79569789341518, 98.04779515947614, 90.97835050310407, 100.57683522360665, 74.53543853759766, 76.72128622872489, 95.79133292606899, 59.03363227844238, 27.942910194396973, 30.581516402108328, 48.07570818492344, 118.12785284859794, 98.91534723554338, 134.012268611363, 121.28851890563965, 95.60542692456926, 51.386667251586914, 27.60036747796195, 3.7386298094476973, 0.8411614607487405, 1.0786664677517754, 0.15876009528126034, 0.3684590086340904, 0.14450102113187313, 0.18570755714816706, 0.1559634046362979, 0.17960393109491893, 0.2847180978528091, 0.4431489679430212, 0.4051702230104378, 0.3878461926111153, 0.4736205371362822, 0.4587994324309485, 0.47594362390892847, 0.5511885434389114, 0.4594789445400238, 0.35865553468465805, 0.5030170625873974, 0.4951859542301723, 0.7719415522047451, 0.47884997938360485, 0.6096169224807194, 0.7470006133828844, 0.5010418200067112, 0.8252449291093009, 0.585187761911324, 0.4721125066280365, 0.5367216882961137, 0.28312329628637856, 0.40984611638954704, 0.8472486798252378, 0.6432236762983459, 0.2741997736905302, 0.4634909321154867, 0.7189573581729616, 0.60658055969647, 7.358706848961966, 37.18807554244995, 115.22273458753313, 152.8464309147426, 160.78695733206612, 121.19271714346749, 48.884402070726665, 30.042805194854736, 29.146237441471644, 34.29130206789289, 57.846435274396626, 87.95017964499337, 86.94059249332973, 88.76974051339286, 81.41548919677734, 89.77985572814941, 92.1120046888079, 99.1945605959211, 107.49871403830392, 63.364013671875, 4.211665340832301, 0.5732165585671152, 0.1409980705274003, 0.1383780161184924, 0.11858637098755155, 0.25847743877342766, 0.1665187089570931, 0.16794033481606416, 0.0777079202234745, 0.11485315273915019, 0.19229446298309735, 0.08004538515316588, 0.15708116894321783, 0.13794578931161336, 0.15692909567483834, 0.15661722740956716, 0.15987742532576832, 0.11281631953482117, 0.09857329952397517, 0.14589546487799712, 0.09715776012412139, 0.1898206735828093, 0.12064724468759128, 0.10065316541918687, 0.17127207746463163, 0.1717960557767323, 0.1116107731525387, 0.1405985491084201, 0.1762432421424559, 0.21561922638544015, 0.11197079026273318, 0.12452611726309572, 0.19548045630965913, 0.10277845244854689, 0.1351018590586526, 0.08670389000326395, 0.12662082271916525, 0.12887551316193172, 0.10098784603178501, 0.20510848824466976, 0.13941557758620807, 0.11157551647296973, 0.16826544808489935, 0.19251377907182488, 0.1493584361991712, 0.1878024254526411, 0.10481748410633632, 0.18464278642620358, 0.1589311539594616, 0.10061661273773227, 0.08253913026835237, 0.07615397325051682], [0.03223901042448623, 0.036412268810506375, 0.09644136285143239, 0.045984660873987844, 0.05100053422419088, 0.02188186886321221, 0.041545650855238946, 0.03634020499885082, 0.062409812185381136, 0.038057916398559294, 0.011732152064463921, 0.024583216856366823, 0.05052642823596086, 0.019514117522963455, 0.013503568662729646, 0.017741933331957886, 0.03434040962851473, 0.04106611319418464, 0.016649480077571104, 0.0396707873525364, 0.07766315048294407, 0.03519269710938845, 0.0387497133841472, 0.03991669862131987, 0.0314353705117745, 0.04347554015527878, 0.05386153641822083, 0.027142136956432035, 0.05310610981125917, 0.07353056687861681, 0.011763129732571542, 0.06575060649109737, 0.08076733962765761, 0.028325425693765283, 0.06462662001805645, 0.030712676434112445, 0.07341709546744823, 0.05398841568135789, 0.054886609448918273, 0.02335469188567783, 0.07212998239057404, 0.07277824117669038, 0.17699389186288628, 10.534583381244115, 61.833672932216096, 84.77167061397007, 72.40534319196428, 74.62060260772705, 70.44595118931362, 68.00874546595982, 57.04610701969692, 66.10088130405971, 46.43354661124093, 25.66314717701503, 26.754684856959752, 28.128923892974854, 38.650146756853374, 56.98066888536726, 64.341354233878, 39.54650259017944, 45.3412515776498, 53.682167938777376, 20.805387088230678, 3.5866748775754655, 0.13992580877883093, 0.24609137911881718, 0.0935112993632044, 0.3665877990424633, 0.18636129849723407, 0.0603138039420758, 0.17629163525998592, 0.02852086243884904, 0.13522651951227868, 0.12831295334867068, 0.20823441765138082, 0.09253705199807882, 0.16967339467789444, 0.16440444812178612, 0.20481119491159916, 0.16090503947011062, 0.11318864527025393, 0.01951800722495786, 0.13841714044766767, 0.49733224191835945, 0.3029042477054255, 0.1542883323771613, 0.15285380078213556, 0.5246955507567951, 0.1318840424397162, 0.2372325344809464, 0.19992342218756676, 0.16177398498569215, 0.09462740804467883, 0.018504389561712742, 0.0951440106811268, 0.2498178934412343, 0.17677429078945092, 0.22123350655393942, 0.3544290486191, 0.5990276506968907, 0.2889305518141815, 0.3331574914710862, 0.30865317636302536, 0.3271909973451069, 0.3416013983743531, 0.27440311706491877, 0.40670572061623844, 12.830918720790319, 46.75787462506975, 77.33725098201207, 100.70489747183663, 72.31779588971818, 58.908050537109375, 34.847025939396445, 14.573045764650617, 18.915925230298722, 32.895012923649375, 33.03075987952096, 45.630056926182334, 59.461613518851145, 67.7077772957938, 72.97120448521206, 76.91278553009033, 82.17193262917655, 53.22856174196516, 7.975706883839198, 0.4061020144394466, 0.0965200254161443, 0.040583464450069835, 0.07714157418480941, 0.05400137570021408, 0.026266112624268447, 0.00962743312785668, 0.03644314893920507, 0.0390159433840641, 0.03688309068924614, 0.05427109676280192, 0.06778816572789635, 0.039520685228386095, 0.11996718975050108, 0.01572797354310751, 0.01980510726571083, 0.07989990724516766, 0.032107059112084765, 0.0016848253518609063, 0.03451741227347936, 0.022346080114532794, 0.04574719397351146, 0.02885254392666476, 0.010964389690863234, 0.00974821490568242, 0.024753905732982924, 0.03992608615330287, 0.02760794785405908, 0.0739472077361175, 0.017400957610724226, 0.028561282769909928, 0.02345239244667547, 0.056026219190763574, 0.05101450526022485, 0.020704288301723342, 0.010564361915125378, 0.024103078691821014, 0.030238492414355278, 0.07757266783820731, 0.05622288917324372, 0.05886420886963606, 0.029414856074643985, 0.025615302546482, 0.03846287627571395, 0.011792030235353326, 0.03388240866895233, 0.07845106534659863, 0.019549197783427577, 0.05635916953906417, 0.03066769295505115, 0.05009438802621194, 0.04016271845570632, 0.05025459014411483, 0.06957128790340253, 0.02883695119193622, 0.017220333285097564, 0.02453455571750445, 0.01496497109266264, 0.05782678310892411, 0.012712601239659956, 0.027197712367134433, 0.02560358933572258, 0.0360508946302746, 0.022997064915086542, 0.02737174302871738, 0.09460880939981767, 0.034688348815377266, 0.04844961574833308, 0.023986431736765162, 0.02585131229300584, 0.03612895329881992, 0.025623097217508724, 0.04070476276267852, 0.023173490805285316, 0.025525437368612205, 0.01347006599618388, 0.0731782918529851, 0.023449774997841035, 0.03767989436164498, 0.04844205008287515, 0.0367761807117079, 0.01296990002239389, 0.06904355050729853, 0.029644200910947154, 0.08415175694972277, 0.06195642865662064, 0.08525473597858634, 0.061788009479641914, 0.036869971214660575, 0.011317691848879414, 0.04737440915778279, 0.02453634704995368, 0.11691425714109625, 1.5394876088414873, 44.220760754176546, 91.22782557351249, 84.87660230909074, 83.57481561388288, 79.68444974081856, 81.7829863684518, 75.796890939985, 87.18550259726388, 56.27880007880074, 35.7126498903547, 54.39247533253261, 30.545722757066997, 19.95432308741978, 24.040233850479126, 22.6312347139631, 36.43404313496181, 46.999532972063335, 57.07438966206142, 27.213283334459575, 5.62497626883643, 0.4921226128935814, 0.19244417494961194, 0.0480657040274569, 0.22962186858057976, 0.4855323008128575, 0.09453674219548702, 0.20092829183808394, 0.27919536562902586, 0.5374743193387985, 0.6115255057811737, 0.6172152661851474, 0.9449003998722348, 0.9393060143504823, 0.5910549727933747, 0.8203238131744521, 0.49254927571330753, 0.563375249505043, 0.7902784453971046, 0.37475030390279634, 2.1799004673957825, 1.8671848475933075, 1.8913250608103616, 1.90019291639328, 2.350379296711513, 1.974131737436567, 1.944386499268668, 1.6934990989310401, 1.557771576302392, 0.783598892390728, 0.957531247820173, 1.4157041481563022, 1.252224434699331, 1.3067560685532433, 1.1548562880073274, 0.9069339228527886, 0.7880606129765511, 0.09420727273183209, 0.2301956649337496, 0.5836824998259544, 0.06959398489977632, 0.27162112348846024, 0.25991321887288776, 0.1567971341844116, 15.142573969704763, 49.88536303383963, 68.26850387028286, 64.65290451049805, 32.15598167691912, 33.46652657645089, 28.540248564311437, 22.83157386098589, 36.98707110541207, 62.61811760493687, 60.65140220097133, 66.97568729945591, 83.97881167275565, 76.57495021820068, 84.34983852931431, 85.72257328033447, 93.96485996246338, 54.30068268094744, 6.062353210789817, 0.14967193294848713, 0.10787769061114107, 0.07287770083972386, 0.1076078779463257, 0.04897610803267785, 0.07428730305816446, 0.03785154675798757, 0.06507766260100262, 0.05762732774019241, 0.07548921249274697, 0.008052808648374463, 0.03282783632831914, 0.06832860529954944, 0.0706871183855193, 0.023929063297275985, 0.04868423280173114, 0.04921695064487202, 0.022955675975286534, 0.028699503745883703, 0.040451747232249806, 0.04649408121726342, 0.026711998341072882, 0.0354793849401176, 0.04528283853349941, 0.008284096639337284, 0.025654454017058015, 0.08776206536484615, 0.019967953973848904, 0.03854964054854853, 0.05148813288126673, 0.05870068871549197, 0.037876567736800225, 0.028527786888714348, 0.0011147522475636962, 0.03413131906251822, 0.026305957896901027, 0.024771466219265546, 0.030667825269379785, 0.09343467240354844, 0.05459082246358905, 0.03857373193438564, 0.06305573681103331, 0.022960841323115995, 0.02730586236741926, 0.02362562413327396, 0.06660924505974565, 0.09250642292733703, 0.019698804577014277, 0.0377467063122562, 0.06300795437502009, 0.19176420143672399, 0.13162718979375704, 0.13320170316312993, 0.14623185539884226, 0.1294054625821965, 0.15414065601570265, 0.17112499821398938, 0.09424005275858299, 0.13731323182582855, 0.11504325110997472, 0.12097569634871823, 0.08947066403925419, 0.16568233312240668, 0.14823391368346556, 0.14390017837285995, 0.20108290282743319, 0.1226681119629315, 0.1415651493838855, 0.07658341127846922, 0.09702709463558026, 0.1866796671279839, 0.14922589116862842, 0.14116125819938524, 0.08335028495639563, 0.14842528770012514, 0.1449230427720717, 0.18609495993171418, 0.11407200965498175, 0.1658409067562648, 0.1942326711224658, 0.15104796125420503, 0.0965596925733345, 0.17483958389077867, 0.09573690100972142, 0.20767744896667345, 0.12883648382765905, 0.24887823100600923, 0.1394564253943307, 0.18016343750059605, 0.1606226060539484, 0.1665389971541507, 0.12851196766964026, 0.33949899833117214, 21.365278141839163, 89.90904358455113, 112.17212104797363, 94.72089345114571, 94.64005810873849, 90.34174960000175, 91.08967454092843, 77.89195346832275, 85.37186990465436, 66.78749534061977, 42.80917862483433, 47.1387540272304, 44.70804834365845, 54.20635393687657, 77.2727439062936, 96.83916991097587, 55.065491744450156, 69.36675003596714, 78.22882992880685, 34.34428208214896, 6.375587557043348, 0.5661274418234825, 0.3805716186761856, 0.1933994572609663, 0.6236459868294852, 0.7877421357801982, 0.18753942527941295, 0.24662981022681507, 0.4269811340740749, 0.2708956338465214, 0.3135106728545257, 0.4348431022039482, 0.4710256020937647, 0.6301880414996828, 0.28706420053328785, 0.24020723200270108, 0.17163833709699766, 0.1993567640227931, 0.33189517206379343, 0.19405371429664747, 0.631933287850448, 0.576367838042123, 0.5365312642284802, 0.4457447443689619, 0.8734066390565464, 0.870322615972587, 0.968118673988751, 0.8267560537372316, 0.4933127633162907, 0.2510335567806448, 0.3558743010674204, 0.4333917700818607, 0.6456430064780372, 0.5256348603538105, 0.576728818672044, 0.45915938168764114, 0.9879670717886516, 0.4778998132262911, 1.1051210824932372, 0.7544318203415189, 0.3459416611918381, 0.3964782708457538, 0.5207811093756131, 0.717996172606945, 20.483133111681255, 67.65478338514055, 109.82777105058942, 139.78344236101424, 98.62587138584682, 81.42766938890729, 53.1157785824367, 24.561814274106705, 27.77761776106698, 50.40514734813145, 51.38693128313337, 61.89037718091692, 81.19669042314801, 89.43252222878593, 93.34739439828056, 95.54977880205426, 100.71054635729108, 82.86537674495152, 18.094061034066335, 0.7071467776383672, 0.6233657790081841, 0.12056541336434227, 0.16831785812973976, 0.14647327815847738, 0.26777562126517296, 0.13822415151766368, 0.12069751056177275, 0.13387694050158772, 0.1462990032242877, 0.1176235026546887, 0.12530902453831264, 0.2552546417074544, 0.247102966266019, 0.14646711706050805, 0.18991665914654732, 0.15341044377003396, 0.14118428767791816, 0.08213585655071906, 0.09562317854059593, 0.14326386180307182, 0.11463473231664725, 0.10039930511265993, 0.12143515955124583, 0.10233087717954602, 0.1802078951150179, 0.14121160549776895, 0.10510468083832945, 0.1828120175216879, 0.13505402233983788, 0.1785279916865485, 0.08597757933395249, 0.1291021845702614, 0.13175985696060316, 0.09829446234341178, 0.12218058455203261, 0.1208284678203719, 0.10881911723741464, 0.2055610575314079, 0.1349127920610564, 0.18426975501435144, 0.09484597095953566, 0.14021741598844528, 0.12813827129346983, 0.09480837333415236, 0.17911318742803164, 0.15857588659439767, 0.11206211429089308, 0.12811400688120297, 0.15083192927496775], [0.0545243837072381, 0.017150912367339646, 0.045396533861224136, 0.03461399155535868, 0.01391569641418755, 0.028164755386699523, 0.04448952253109642, 0.015772342947976928, 0.027281148425702537, 0.017037678443427597, 0.05113146094871419, 0.023755658584247743, 0.02437348846745278, 0.03381306917539664, 0.10475405465279307, 0.0445798491127789, 0.03271184415955629, 0.04856786404603294, 0.03348130626337869, 0.019496309371399026, 0.01689657030094947, 0.04243927468944873, 0.02998903240742428, 0.011870546066867453, 0.010630688713198262, 0.03272805775382689, 0.03990779284920011, 0.03224976520453181, 0.07274467404931784, 0.01916056006614651, 0.033534221816807985, 0.0275845706263291, 0.044132351875305176, 0.06711028210286583, 0.05961146591497319, 0.020605608953961303, 0.05637534920658384, 0.02518047864681908, 0.0603305705423866, 0.1676224818719285, 0.1491191168980939, 0.831466769533498, 35.95901216779436, 77.22548225947789, 83.56538690839494, 65.67435918535504, 61.07728508540562, 68.81614003862653, 74.84420258658272, 54.70612396512713, 13.669018251555306, 8.483880758285522, 21.10229751041957, 40.53038488115583, 23.961715732301982, 51.10172162737165, 86.48159449441093, 76.13578237806047, 66.86620453425816, 53.67243351255144, 20.89301429476057, 2.4620689834867204, 0.0900227404864771, 0.2734999055308955, 0.033135188943041224, 0.14775284592594418, 0.09570188860275916, 0.037647328073424954, 0.1619401853531599, 0.08271697429674012, 0.10522111066217933, 0.061169015908879895, 0.18443826240088257, 0.18051734779562267, 0.036472973945949755, 0.4263272705887045, 0.923303661601884, 1.0402775619711195, 1.2507000650678362, 2.1151591071060727, 1.7292904640947069, 0.425515851272004, 2.515730355467115, 9.503811172076635, 4.0164400679724555, 3.407051350389208, 5.243983089923859, 5.952765788350787, 3.6131805181503296, 1.5775109742368971, 2.18341777580125, 1.3493195388998305, 1.0972065414701189, 0.7068158696804727, 0.6829113523874963, 0.2020242887416056, 0.37103657318013056, 0.352021009262119, 0.2751197586102145, 0.1543815088059221, 0.26471694824951036, 0.14987074370895112, 0.08838408520179135, 0.052840806011642726, 0.41873468086123466, 0.1906378875885691, 0.19197420802499565, 0.5042654584561075, 0.09218658866094691, 6.852751621178218, 39.35028198787144, 80.65157645089286, 79.81680597577775, 76.32455103737968, 94.87741552080426, 53.3066143308367, 13.625506026404244, 16.935202257973806, 13.298648868288312, 14.616847208568029, 33.65979072025844, 42.79400723321097, 76.40535163879395, 74.58995410374233, 76.16546508244106, 68.27451406206403, 31.90054852621896, 6.895407046590533, 0.5147122921688216, 0.1782488559505769, 0.0259711178285735, 0.05409517638119204, 0.06711862129824502, 0.053437781121049605, 0.007413542995761547, 0.1333915436906474, 0.048747116034584384, 0.030430785845965147, 0.02553608188671725, 0.039643628988415, 0.03169329185038805, 0.08132293088627712, 0.03490441132869039, 0.08672367608440773, 0.02804920426569879, 0.042039661668241024, 0.06789452609206949, 0.024894194544426033, 0.04483830988673227, 0.04570669221824833, 0.0617115589390908, 0.018304688224036778, 0.020850152974682193, 0.04414730339444109, 0.020672936591186693, 0.050365584902465343, 0.016141196280451756, 0.02399113568078194, 0.0691692762609039, 0.05166911852679082, 0.0039022973006857292, 0.070135937604521, 0.029187404351042848, 0.016449071367138197, 0.04791080126804965, 0.00763694810614522, 0.019785555279148475, 0.01124348386656493, 0.008390593558682926, 0.010326519275882413, 0.025851673612903272, 0.047564008805368624, 0.028932977467775345, 0.08421154945556607, 0.036721677386334965, 0.04321868072396942, 0.054506718048027585, 0.06518649283264365, 0.07417662042592253, 0.024740136561117003, 0.03902155826134341, 0.008391048177145422, 0.02810691366903484, 0.02494557830505073, 0.044762229147766314, 0.033702491716082604, 0.02842878014780581, 0.01937397290021181, 0.05019046858485256, 0.04203498995463763, 0.09333606769463845, 0.014358411676117351, 0.0028014367853756994, 0.07325757866991417, 0.022961804842842475, 0.059667445054011684, 0.023288924878995334, 0.04348177928477526, 0.05333119344764522, 0.013664858981168695, 0.03888016174148236, 0.03865650642131056, 0.06442818923720292, 0.07082203828862735, 0.05581734575597303, 0.02729296850572739, 0.007057603881029146, 0.056620989061359844, 0.056371600300605805, 0.04763946868479252, 0.034044059459120035, 0.008659345164362873, 0.07989903872034379, 0.015332581009715796, 0.11045815928706101, 0.14363762603274413, 0.13345333108944551, 0.09680391089724642, 17.258098942892893, 70.84236676352364, 99.18720940181187, 81.75390815734863, 82.11196272713798, 81.79873793465751, 84.73123904636928, 65.54517827715192, 34.54580763408116, 30.37280641283308, 40.121031761169434, 33.08762046269008, 22.932894229888916, 37.028906209128245, 45.57947404044015, 49.98015035901751, 61.72836603437151, 58.4612466267177, 27.80428668430873, 4.647397296769278, 0.2122953004602875, 0.27636020204850603, 0.10111139368798051, 0.35858624268855366, 0.24923807169709886, 0.25884593757135527, 0.40521261787840296, 0.4672405166285378, 0.40398406237363815, 0.2850969375244209, 0.7777222905840192, 1.1342138413872038, 1.5160988867282867, 1.8099523186683655, 2.9736559433596472, 2.8657165467739105, 5.122306670461382, 7.245771263326917, 6.486380926200321, 5.500940501689911, 7.4513862643923074, 7.068101916994367, 9.618512034416199, 10.577197551727295, 11.263701285634722, 10.04746949672699, 7.733307685170855, 4.975045246737344, 5.844801204545157, 6.086773089000157, 4.965321242809296, 4.300147610051291, 3.8726049746785844, 1.4827498133693422, 1.7348178646394183, 0.951499451483999, 0.7151442084993634, 0.3300093061157635, 0.9903917759656906, 0.7715221632804189, 0.8005466886929103, 0.42679730536682264, 0.24294731925640786, 0.13691466035587446, 0.03411531920677849, 0.45281776626195225, 0.18019334732421807, 7.260143177849906, 37.885136195591514, 68.27809238433838, 55.40867369515555, 51.714959212711875, 50.41760546820504, 39.63315010070801, 19.06661081314087, 23.839886018208094, 24.24632784298488, 30.388533660343715, 56.01763466426304, 55.85712432861328, 86.85080092293876, 82.115784236363, 88.8864494051252, 76.4709495816912, 29.1906954901559, 4.948636446680341, 0.3320825291531426, 0.09580961282231978, 0.023701613270012394, 0.03497044974938035, 0.048703754254217656, 0.05154137073882988, 0.02014411353905286, 0.06542341011975493, 0.041350137774965594, 0.021005892028499926, 0.02721734408156148, 0.021377630831141557, 0.032716844962643724, 0.04130552749016455, 0.020496553109426583, 0.037954504269042184, 0.02514062319616122, 0.03911125719813364, 0.028443010723484412, 0.014511553637151207, 0.07617571351251431, 0.01789487342882369, 0.030273474287241697, 0.022690399317070842, 0.06187506552253451, 0.08261616434901953, 0.0504105887375772, 0.07536160719713994, 0.013856922559040998, 0.03038315608033112, 0.06057477529559817, 0.007258600372421954, 0.03437752888670989, 0.056939062529376576, 0.03701696904110057, 0.04294865771329828, 0.035709242070359845, 0.008860072786254542, 0.037414644844830036, 0.02054642204062215, 0.07911088636943273, 0.017400621735889996, 0.026272509513156753, 0.05569814411657197, 0.026323162152298858, 0.029996978052492653, 0.01458199744644974, 0.043890813764716895, 0.115032964519092, 0.15490722416767053, 0.14987558844898427, 0.08615978634251015, 0.13137123281402246, 0.14503147266805172, 0.09419636188873223, 0.11823981601212706, 0.15512754448822566, 0.0581397573862757, 0.15237269231251307, 0.15115271349038395, 0.1437810276235853, 0.13983443725321973, 0.19481868110597134, 0.1143405195325613, 0.08225842033113752, 0.08458471657442194, 0.13683930225670338, 0.08755528181791306, 0.14734742125230177, 0.1564021860914571, 0.13067090325057507, 0.1047521751107914, 0.1988275609910488, 0.10580511218202965, 0.18606791352587088, 0.1784574511860098, 0.23662223294377327, 0.2736015229352883, 0.09770303086510726, 0.15542840691549437, 0.1451769641467503, 0.1455595086195639, 0.19614619415785584, 0.19735773200435297, 0.15928533566849573, 0.1574920490384102, 0.3588497856897967, 0.3056255259684154, 0.36196431570819443, 4.521574539797647, 63.731552532741, 105.97113868168422, 103.94456454685756, 86.63813046046666, 84.25713566371373, 90.19666426522392, 98.28242192949567, 73.65793664114815, 25.473694120134624, 17.398487295423234, 39.59332997458321, 61.084921155657085, 41.61349092211042, 74.06874193464006, 132.52578490121024, 114.2449562890189, 94.17222200121198, 82.58497524261475, 36.51840468815395, 5.338999271392822, 0.45877196533339365, 0.588514863380364, 0.23012935849172728, 0.7598189541271755, 0.3312411457300186, 0.2733933755329677, 0.3909314370581082, 0.6471010425261089, 0.27689135926110403, 0.15873112183596405, 0.4074458937559809, 0.6297649070620537, 0.911005784358297, 1.533318585583142, 2.9976487244878496, 3.0122247423444475, 4.154056523527418, 6.037124735968454, 4.932179638317653, 6.856992193630763, 11.899749806949071, 17.66078700338091, 11.21620079449245, 12.778181893484932, 13.893851535660879, 10.781611817223684, 8.77152054650443, 4.794489792415074, 5.5442321215357095, 4.67995525257928, 5.265715318066733, 4.518052671636854, 1.5544339439698627, 0.8060980279530797, 1.1204764928136552, 0.5744730425732476, 0.4514205812343529, 0.1277628242969513, 0.38763174840382164, 0.24020782911351748, 0.43699603953531807, 0.3615456596016884, 0.5890135594776699, 0.22375632689467498, 0.28986283178840366, 0.6731883798326764, 1.0703406802245548, 12.981860518455505, 60.04996613093785, 124.75272396632603, 118.4273202078683, 100.923967225211, 114.64298384530204, 76.12842423575265, 21.120656388146536, 25.078270401273453, 24.52079037257603, 27.388754878725322, 47.66801915849958, 59.99014214106968, 97.80995832170758, 93.53655215672084, 93.99295152936662, 94.76456982748849, 56.17165885652815, 15.514714275087629, 1.1289497124297279, 0.26665527852518217, 0.09862148229564939, 0.12988453544676304, 0.1712424661964178, 0.12255525801862989, 0.07422630275998797, 0.19834053569606372, 0.19714085864169256, 0.07607604350362505, 0.12053477072290011, 0.12404218608779566, 0.10036396022353854, 0.19571125321090221, 0.0935099965759686, 0.11594587910388197, 0.15968394785055093, 0.10752464884093829, 0.16832779188241276, 0.09474834334105253, 0.16686620031084332, 0.1772130179618086, 0.13221321334796293, 0.09851064360035316, 0.11016656564814703, 0.14010306926710264, 0.13106343575886317, 0.15267316118947097, 0.05547764737691198, 0.10829477251640388, 0.17004718604896749, 0.14129288042230265, 0.08606073380048786, 0.20653510812137807, 0.1005163931154779, 0.11751397353197847, 0.1289254126272031, 0.10373252018221787, 0.1344310457685164, 0.1858370080590248, 0.14389891629772528, 0.08007237049085753, 0.08550236054829188, 0.2812085790293557, 0.10352873576006719, 0.15968378500214644, 0.10781800667090075, 0.11175545038921492], [0.07009886245110206, 0.021949062489771416, 0.057242849442575655, 0.030746382661163807, 0.036572728771716356, 0.037169649598321745, 0.028945713570075374, 0.03186883903773768, 0.12533817440271378, 0.01957483114009457, 0.09483980307621614, 0.036458907915013175, 0.02984310666631375, 0.020259934377723506, 0.02903314959257841, 0.020751470234245062, 0.02985926597778286, 0.05727722402662039, 0.006989897112362087, 0.026850697684234807, 0.03590354396562491, 0.022747570981404612, 0.010123923138183142, 0.09956013371369668, 0.11734298270727907, 0.024077492832605327, 0.03765531103791935, 0.013894554111175239, 0.016750327344717722, 0.018542114412412047, 0.155940158026559, 0.02463830541819334, 0.019481230626947114, 0.0770732049963304, 0.06805594957300595, 0.021846155868843198, 0.011555018801508206, 0.01141652895603329, 0.0037829934569474843, 0.04266342194750905, 5.82073655298778, 61.65095615386963, 96.01066671098981, 88.87340763636998, 67.84565040043422, 81.15605735778809, 55.98479052952358, 28.303030116217478, 25.059730870383127, 33.78058515276228, 27.434814487184795, 43.00667422158377, 32.88007082257952, 37.18493843078613, 64.56059074401855, 43.95802852085659, 41.656573227473665, 34.57213088444301, 16.838488544736588, 2.536450969321387, 0.08788191500519003, 0.1167919851307358, 0.10878563831959452, 0.06398044433444738, 0.09330535719969443, 0.02396234543994069, 0.13343293432678494, 0.049390262059335194, 0.22198601546032087, 0.33289777540734833, 0.917024009994098, 0.7760564599718366, 2.0120547882148196, 1.5555395760706492, 1.608298550759043, 2.284620676721845, 1.714687847665378, 1.4319208094051905, 5.212727052824838, 5.5410211852618625, 2.4916470306260243, 4.8485016141619, 3.0466239707810536, 9.288457836423602, 8.490063786506653, 12.256981015205383, 15.566898720605032, 10.706295081547328, 6.200585884707315, 4.5560332621846875, 6.689570137432643, 7.18355188199452, 4.986244874341147, 4.457603343895503, 6.966125377586909, 2.9222001901694705, 4.005216555935996, 2.962923147848674, 2.260354310274124, 2.687489824635642, 1.1519217597586768, 0.7612725389855248, 0.31276865409953253, 0.08221447840332985, 0.08561682262058769, 0.07921956732336964, 0.08106604431356702, 0.20697995567960398, 0.06341551643397127, 0.3242727539369038, 0.3134732177214963, 7.18595335313252, 33.252786091395784, 60.195718492780415, 65.8984455381121, 76.41090324946812, 106.02329880850655, 52.02206264223371, 65.97878061022077, 74.41502625601632, 15.857234409877233, 24.502242156437465, 55.08525242124285, 59.72191388266427, 60.38324342455183, 70.78049305507115, 84.48014504568917, 70.53371388571603, 33.430809361594065, 10.764047639710562, 0.4182552822998592, 0.11862830445170403, 0.05653398730126875, 0.033040207611130815, 0.03835709945165685, 0.014203788812405296, 0.03601448783384902, 0.03560326847114733, 0.03855373890006116, 0.10242699845028774, 0.05740525679928916, 0.022824637292485152, 0.037720324870731146, 0.029109294792371135, 0.03876599143924458, 0.06485192757099867, 0.052204974594392946, 0.03692185539486153, 0.09725147938089711, 0.06385978045208113, 0.08212544782353298, 0.008358754151101624, 0.06629658290850264, 0.012890105152369609, 0.03144396076511059, 0.05173191355009164, 0.028843882427151715, 0.04178280902228185, 0.00786418778755303, 0.013079194202353912, 0.0312302934804133, 0.0026514752451995654, 0.023689630341583064, 0.00934630334709904, 0.04131026027191963, 0.03426932290728603, 0.019093997477154647, 0.043145222522850545, 0.03179264294781855, 0.040974154735782316, 0.03225201454811862, 0.022072937539113418, 0.017781719232776334, 0.058793709081198485, 0.04636896614517484, 0.03448599949479103, 0.052737051221941195, 0.023850039412666644, 0.06851191153483731, 0.02088232571259141, 0.03555181176800813, 0.04478255805692502, 0.01976274462815906, 0.010930439191205161, 0.061644709669053555, 0.03140372024582965, 0.08905934968164989, 0.017674607391070043, 0.032742418947496583, 0.023458012412967424, 0.045005768936659606, 0.04622555098363331, 0.04673933091440371, 0.04480111938236015, 0.023639266079823886, 0.04692723422444292, 0.02113518348362829, 0.008814258949964173, 0.03406640700995922, 0.081882355867752, 0.05394132874373879, 0.027598402562684247, 0.02659231154913349, 0.05499813685725842, 0.008695802850914853, 0.03420595112921936, 0.012568145375033575, 0.06162893372986998, 0.06389488106859581, 0.06212786052908216, 0.05239662002506001, 0.07420558030051844, 0.059542764244335036, 0.018399920613904084, 0.03760311133893473, 0.08133325818926096, 0.6431756360190255, 42.79063735689436, 100.68105820247105, 101.27084214346749, 78.39393302372524, 78.8192947932652, 66.97887652260917, 53.48383508409773, 55.40424074445452, 54.357977526528494, 20.49827149936131, 20.917477164949688, 29.490701334817068, 44.803752831050325, 42.70006758826119, 33.00683723177229, 42.989870003291536, 45.88416991915022, 23.583254303250992, 3.354816747563226, 0.04053805349394679, 0.18118715685393127, 0.09523474438382046, 0.05627547224451389, 0.14206375048628875, 0.11282201922897782, 0.3332785964012146, 0.7361468757901872, 1.5957920104265213, 1.910673188311713, 1.0743738923754012, 1.3921888385500227, 1.479136967233249, 3.025462580578668, 2.879660278558731, 2.158567326409476, 2.1123733137335097, 4.417253851890564, 7.063324161938258, 10.290798885481697, 9.729077850069318, 11.261221647262573, 18.08030012675694, 9.766203812190465, 11.914063964571271, 17.248991591589792, 16.513648101261683, 16.580435923167638, 11.436828681400844, 9.137339728219168, 13.353140984262739, 9.47954979964665, 4.404457441398075, 3.6707411323274886, 7.04922149011067, 3.2905797830649783, 4.193572665963854, 1.9180625975131989, 1.9940404977117265, 1.5789849694286073, 3.384814726454871, 3.0217674417155127, 1.0545462306056703, 0.7377349734306335, 0.2776749315006392, 0.4106092240129198, 0.3285494515938418, 0.1540186825607504, 0.03904708135606987, 0.2798108511737415, 0.14170802171741212, 7.290653586387634, 32.37934194292341, 51.35606738499233, 56.72084447315761, 60.58906296321324, 51.4231835092817, 37.11484152930123, 31.23122160775321, 48.32095527648926, 32.4059431212289, 40.50356830869402, 67.83522810254777, 69.2831562587193, 68.2136617388044, 82.4056978225708, 96.59282847813198, 78.31904533931187, 31.784218311309814, 8.344037839344569, 0.2526816369167396, 0.20350821768598898, 0.035427334518837075, 0.03239247468965394, 0.08884052213813577, 0.03853031247854233, 0.051324409166617055, 0.09117656214428799, 0.020429764907541018, 0.05541403471891369, 0.08930985123983451, 0.029115259115185057, 0.04375898798129388, 0.009286293710049773, 0.011884422956167586, 0.03754261994202222, 0.0498770295110132, 0.0719970166683197, 0.02087909758224019, 0.09339530380176646, 0.030173631251922677, 0.04475230218044349, 0.021494801954499314, 0.02109657314472965, 0.03846595003934843, 0.022376417415216565, 0.06143741722085646, 0.19383344825889381, 0.012336521509236522, 0.03803280042484403, 0.02873525914869138, 0.052985025237181356, 0.039643859690321345, 0.008580044776733433, 0.06396701612642833, 0.03469219271625791, 0.05746978547956262, 0.01828441020500447, 0.038054927451802154, 0.02570758500535573, 0.04859676963782736, 0.03655184007116726, 0.030361615986164128, 0.04496802542624729, 0.017782014395509447, 0.0560855943975704, 0.13849374705127307, 0.0965531582811049, 0.11412831449082919, 0.11647662919546876, 0.11729206543947969, 0.13742129531289848, 0.13992947286793164, 0.08229196031710931, 0.20009710001094, 0.06787602922746114, 0.22080634161829948, 0.08387079595455102, 0.09955784705068384, 0.10170783275472266, 0.10535599663853645, 0.13044257621679986, 0.08406936244240829, 0.13403023513300077, 0.06939327424126011, 0.13930311719221727, 0.11036873515695333, 0.21574740165046283, 0.059593742580286095, 0.15944281007562364, 0.279192895761558, 0.12491220368870667, 0.08124991373292037, 0.1090312408549445, 0.1424232790512698, 0.10677475229437862, 0.2899722387748105, 0.14421169379992144, 0.20295749152345316, 0.2458792147891862, 0.22893491972770008, 0.17417594950113977, 0.29015737026929855, 0.07294969340520245, 0.14742374287119933, 0.15586279146373272, 18.50612916265215, 94.05143451690674, 117.43782724652971, 105.96414184570312, 87.4197611127581, 95.98910645076207, 74.01979187556675, 47.23744624001639, 40.41898788724627, 51.60812371117728, 42.42716319220406, 63.91612448011126, 51.00578090122768, 53.86039618083409, 94.99363109043666, 63.711611202784944, 57.16139847891671, 50.21659755706787, 28.271262952259608, 3.0921351058142523, 0.41113484437976566, 0.3767776036901133, 0.2846019055162157, 0.31212741136550903, 0.18755363380270346, 0.12981809329773697, 0.5670624630791801, 0.6167754669274602, 2.9182931312492917, 1.7512772785765784, 2.890536597796849, 4.586465069225856, 5.98091858625412, 6.946299561432429, 8.60950071471078, 9.872116940362112, 8.946695055280413, 12.077078257288251, 12.649516889027186, 19.816019194466726, 13.8531585420881, 13.049198116574969, 17.412651198250906, 26.789867060525076, 22.730427197047643, 30.625866753714426, 35.37721170697893, 33.11995390483311, 23.490235294614518, 20.910991021565028, 26.83212079320635, 21.824125017438615, 17.105276788984025, 18.61356394631522, 22.772253615515574, 16.36352184840611, 15.274624483925955, 11.492627927235194, 7.740941149847848, 7.111367046833038, 3.4133863704545155, 2.6731346292155127, 0.8420359566807747, 0.6006063574126789, 0.16529763090823377, 0.2387358695268631, 0.22739404812455177, 0.45248601692063467, 0.14704187693340437, 0.4585833325982094, 0.99138471697058, 11.460422158241272, 52.84229053769793, 88.73816095079694, 95.87421103886196, 103.21679633004325, 133.753851209368, 75.07024833134243, 78.56131512778146, 88.04849665505546, 25.87543375151498, 38.10955606188093, 70.6312665939331, 78.4765818459647, 79.99972425188336, 87.49863706316266, 102.67903355189732, 97.2437357221331, 56.94484049933297, 20.777151346206665, 1.09899494264807, 0.5351005867123604, 0.12600383082670824, 0.1417765130421945, 0.1758868076971599, 0.17324558299567017, 0.14574335089751653, 0.13535632326134614, 0.10257724645946707, 0.14509099375988754, 0.20971730165183544, 0.2622646412679127, 0.18634725282234804, 0.09404433611780405, 0.10687116533517838, 0.15238702297210693, 0.189229940995574, 0.27790237643889015, 0.19018130137452058, 0.2003594623612506, 0.22358997724950314, 0.12949861186955655, 0.1446905088211809, 0.17467999245439256, 0.09638821320342165, 0.16641101187893323, 0.1536422177617039, 0.28932119799511774, 0.09360286766397101, 0.11897157531763826, 0.18563289115471499, 0.06442994664290122, 0.1890591537313802, 0.07238299452832767, 0.11971904949418136, 0.09426785912364721, 0.1478582224143403, 0.0816738149151206, 0.11961619715605463, 0.08684301682348762, 0.16198135885809148, 0.1840045563876629, 0.13077607617846557, 0.16733995346086367, 0.15470373151557787, 0.12475285652492728], [0.00462530180811882, 0.0693820377013513, 0.0192868507001549, 0.03282505772741778, 0.03438106744683214, 0.023602798215246627, 0.03280439633609993, 0.016661044010626416, 0.020633532366316234, 0.01926992125143962, 0.030058585639510835, 0.03637719533539244, 0.028264069164704, 0.03150172105857304, 0.012878970392713589, 0.07193643027650458, 0.03819553687104157, 0.02781754732131958, 0.021541603907410587, 0.035024525597691536, 0.024797834090090225, 0.007369420408005161, 0.08133289178035089, 0.03316157716991646, 0.03280263553772654, 0.06864451084818159, 0.030756523367017508, 0.007369994618264692, 0.02878494148275682, 0.08582946871008192, 0.030143704464925185, 0.06770267710089684, 0.021861780833985125, 0.08721338837806668, 0.022570678598380516, 0.044615842002843104, 0.1186022079948868, 0.06500250806233712, 0.3178974288914885, 23.722444091524395, 82.52384499141148, 90.44467326572963, 84.11702523912702, 63.29549053737095, 63.80411951882498, 95.44824477604458, 106.88721002851213, 37.21751158578055, 13.183632731437683, 26.50800469943455, 93.75891535622733, 73.48259884970528, 55.8312839780535, 35.40891286305019, 34.914051737104145, 38.47644179207938, 21.714124611445836, 5.885632727827344, 0.1703881634665387, 0.06281309268836464, 0.12386725975998811, 0.01626655223247196, 0.0695848586037755, 0.0938396831708295, 0.166776497981378, 0.3012974496398653, 0.09810578211077622, 0.6249670673693929, 1.2714055883032935, 1.1787753530911036, 2.670674749783107, 4.012179519448962, 3.799496897629329, 3.962651457105364, 4.65092133624213, 5.300953107220786, 3.6651308962277005, 3.5469033888408115, 8.893566523279462, 12.826627339635577, 13.800929801804678, 4.863920969622476, 11.21667674609593, 10.448952913284302, 12.570435098239354, 11.78217499596732, 9.104787417820521, 14.945173910685948, 8.11925492967878, 5.209886542388371, 6.941664244447436, 11.887827566691808, 6.731120799268995, 7.537650755473545, 11.351964252335684, 7.013368351118905, 5.9568734765052795, 7.007506677082606, 2.5224798790046146, 5.3468372736658365, 6.752079606056213, 6.0060953838484625, 2.2451937752110616, 0.9599300048180989, 1.1374403025422777, 0.5075952740652221, 0.18602705214704784, 0.07141859949167285, 0.08266450996909823, 0.2776850552431175, 0.005231823905238083, 0.10275549760886601, 0.03801303809242589, 11.439293554850988, 43.603201389312744, 60.83953857421875, 78.83040496281215, 68.28001703534807, 95.7775546482631, 113.30228723798479, 41.74606949942452, 22.094540221350535, 21.822212525776454, 35.01857001440865, 43.88393293108259, 59.279827799115864, 73.82927227020264, 75.91452394212995, 82.16103090558732, 78.32318646567208, 29.95749521255493, 3.1349744413580214, 0.3759941942989826, 0.06334038225135633, 0.008748602205222207, 0.15704220746244701, 0.01554324577695557, 0.05460252719266074, 0.03455968839781625, 0.03054307321352618, 0.03170348683904324, 0.07547747383692435, 0.03919118183798023, 0.07487593218684196, 0.059965667980057855, 0.03666135901585221, 0.06523146613367967, 0.05696120312703507, 0.025266845976667743, 0.05319255856531007, 0.07982948209558215, 0.022181718576965586, 0.0325861285839762, 0.05082433225054826, 0.017567912848400216, 0.027624180108042698, 0.029160452940102135, 0.04302247893065214, 0.02473668790688472, 0.01597989832849375, 0.039262841921299696, 0.025185440434142947, 0.0364720511383244, 0.0835785169952682, 0.03497203752132399, 0.041288140030311685, 0.05798910225608519, 0.0274680492002517, 0.019877403475610272, 0.034967094393713136, 0.022390469875452772, 0.021190348380644406, 0.030202533451042006, 0.09408622208450522, 0.02038576191158167, 0.09174750186502934, 0.028425786112036024, 0.04372404342783349, 0.022237244793879132, 0.04699274678049343, 0.11129046391163554, 0.07261037839842693, 0.06925621016749314, 0.024140153845239962, 0.048079593639288626, 0.01416655081058187, 0.033975758124142885, 0.04190510478136795, 0.028392407278131162, 0.022309607160942893, 0.009115052675562245, 0.013789146240534527, 0.016610364230083566, 0.06840746463941676, 0.013525994245095976, 0.019214512081816792, 0.0628339508548379, 0.024591357580253055, 0.015132903420765485, 0.043268678576818535, 0.016594118405399576, 0.06606507354548999, 0.034169924312404225, 0.022190486945744072, 0.06067691517195531, 0.05950475949794054, 0.021973466001717106, 0.05202217047501888, 0.06105997533138309, 0.03225537668913603, 0.021684247235368406, 0.1040015457464116, 0.06906691925334078, 0.12373894878796168, 0.1478118241897651, 12.35869916847774, 71.3566654750279, 102.93608910696847, 92.28620297568185, 79.2605470929827, 71.43231051308769, 112.77313327789307, 89.93657234736851, 29.392519814627512, 22.130901881626674, 38.32382113592965, 57.25366013390677, 57.80527067184448, 44.80099439620972, 35.88477413994925, 43.88048315048218, 48.449580328805105, 32.42138549259731, 8.662309629576546, 0.2570490411349705, 0.06290208255606038, 0.04584215155669621, 0.013818913571802633, 0.18742883764207363, 0.3414578746472086, 0.7744398638606071, 1.3773611656257083, 1.1467921435832977, 0.8020035848021507, 1.2532562421900886, 1.5868970134428568, 2.152675688266754, 2.3004402049950192, 1.6525229662656784, 1.8602253581796373, 1.6495628165347236, 1.5231608620711734, 0.9608065634965897, 1.2551058743681227, 0.8282788491674832, 6.099120472158704, 9.990234579358782, 13.703952925545828, 18.271321739469254, 24.996913943971904, 11.294592108045306, 10.41046336718968, 6.910116383007594, 9.41044909613473, 9.800500988960266, 7.342096311705453, 4.76930604662214, 1.2906351621661867, 3.556004226207733, 1.2706124080078942, 3.9806503312928334, 0.7941470720938274, 1.8208465512309755, 1.4937719362122672, 0.40006074575441225, 1.972922533750534, 2.0287695484501973, 3.7990057468414307, 1.1539977512189319, 0.6760438180395535, 1.3929362041609628, 0.6977249117834228, 0.5720635918634278, 0.2910035034375531, 0.36628194259745733, 0.5167449116706848, 0.048355923632958105, 0.1444390844553709, 0.22556737757154874, 12.75406209060124, 41.62259653636387, 56.57594673974173, 69.59043339320591, 49.89704990386963, 83.83370549338204, 105.21711322239467, 34.1423465864999, 26.357381650379725, 40.513167245047434, 54.082415444510325, 53.02612945011684, 70.22158690861293, 81.43540968213762, 85.75142220088414, 94.8439529963902, 84.74271052224296, 29.541061878204346, 2.4814928897789548, 0.09179843948887927, 0.1942364844892706, 0.07500296751303331, 0.06587779109499284, 0.06859640271535941, 0.06625234242528677, 0.053523649727659564, 0.024778064972321902, 0.004420297295187733, 0.015383106423541903, 0.030093974633408443, 0.04797506871234093, 0.0691932285470622, 0.04987974365108779, 0.10784368922135659, 0.02739061478392354, 0.010083353529418153, 0.052803374627338986, 0.13328444372330392, 0.06912838774068014, 0.05766507464327982, 0.031839047957743914, 0.05952550909881081, 0.02695952621953828, 0.03696463702778731, 0.06723186879285745, 0.03758682310581207, 0.00317563146070045, 0.010640475732673491, 0.026123018070523227, 0.030507175318364586, 0.028701502031513622, 0.039898127117859464, 0.028023292709674155, 0.05894408601203135, 0.02681716617995075, 0.06308779080531426, 0.047719118517956564, 0.01385042813074376, 0.019171085840623294, 0.04265885201415845, 0.03795985791033932, 0.009460002067498863, 0.026669260812923312, 0.18580841459333897, 0.15720230101474694, 0.22525329728211674, 0.10532097066087381, 0.25039825801338467, 0.16652260374810013, 0.1642877265278782, 0.1476910856685468, 0.1567536943725177, 0.0743320592279945, 0.14086263493767806, 0.13689408717410906, 0.1218684177313532, 0.19738385560257093, 0.1263416191296918, 0.15063543910426752, 0.08719667606055737, 0.11803920034851346, 0.11429469127740179, 0.08702086763722555, 0.1276225439671959, 0.14012997996594223, 0.21252754942647048, 0.13053823608372891, 0.13615941016801766, 0.24712052675230162, 0.10721942343349967, 0.14517433143087796, 0.11767439278108732, 0.13593584645007337, 0.13811901930187429, 0.21766350311892374, 0.10728355177811214, 0.1534851233341864, 0.1157867219299078, 0.41061272525361603, 0.25166239589452744, 0.2054313759186438, 0.4266661581184183, 42.275195666721885, 115.1482012612479, 107.73211792537144, 100.16390378134591, 83.53379344940186, 80.9595900944301, 109.72486128125871, 120.65974862234933, 55.65231922694615, 25.991501671927317, 42.08721215384347, 129.79015404837472, 109.05922385624477, 79.32780565534318, 55.51505756378174, 51.28219066347395, 58.81174155644008, 38.81018808909825, 11.58230311529977, 0.6007424986788205, 0.18172119105500834, 0.23564291692205838, 0.20252867096236774, 0.18154986096279963, 0.20294662139245442, 0.42463584563561846, 1.5075830008302415, 1.2033629651580537, 2.184753784111568, 6.073504635265895, 6.526221462658473, 9.52757487978254, 13.926750387464251, 15.650667939867292, 16.356622287205287, 14.201825227056231, 11.930069140025548, 12.243452004023961, 15.577314070292882, 25.664489916392736, 31.998337473188126, 33.39749274935041, 20.050359351294382, 24.923553126198904, 21.844146251678467, 28.965087481907435, 27.97438553401402, 26.574170657566615, 33.33923557826451, 24.683307000568934, 23.316968066351755, 23.880390541894094, 33.614849771772114, 25.12028615815299, 20.397645950317383, 34.166627066476, 23.252898727144512, 20.254123960222515, 21.211936610085623, 13.883417078426906, 21.559016500200542, 21.087197337831768, 20.634807075772965, 9.875631860324315, 7.771123256002154, 4.204672847475324, 1.2797471178429467, 0.26235241655792507, 0.23617035576275416, 0.23147112077900342, 0.405840452760458, 0.13614778007779801, 0.26776069349476267, 0.5001637956925801, 20.203841584069387, 60.74912166595459, 89.29223809923444, 112.57622132982526, 92.62621307373047, 109.8659027644566, 125.7490678514753, 57.56148270198277, 33.0012196132115, 35.21713215964181, 51.08889525277274, 60.03588908059256, 81.25844601222447, 90.50576877593994, 94.31946127755302, 101.34936373574394, 100.22383894239152, 53.6668575831822, 10.99163327898298, 0.8763708599976131, 0.4606719176684107, 0.1239284093358687, 0.3023241274058819, 0.1685124755437885, 0.13356382373188222, 0.13667538176689828, 0.15850489826074668, 0.12863430753350258, 0.1600380345646824, 0.12993797686483177, 0.18702382008944238, 0.1799492918487106, 0.20237452137683118, 0.21208332612046174, 0.17431582270988397, 0.1460305747709104, 0.11002931836992502, 0.21086891128548554, 0.1609770998890911, 0.06827998826546328, 0.10662219048078571, 0.19880204807434762, 0.09224720897951297, 0.10898923275193997, 0.15911342203617096, 0.10526336982314076, 0.17964050413242408, 0.1744397503456899, 0.10092960058578423, 0.0887933639543397, 0.16251027690512793, 0.14034397634012358, 0.17321966295795782, 0.1073008408503873, 0.09778967978698866, 0.11324228346347809, 0.10444159606205565, 0.19496430829167366, 0.1248921597642558, 0.10090153637741293, 0.13412926053362234, 0.08191137002514941, 0.19488885519759996], [0.04741038169179644, 0.05976166642670121, 0.06160603995834078, 0.06151780326451574, 0.03138755754168544, 0.07733412206705127, 0.09412775521299668, 0.026010991938944374, 0.06802356309656586, 0.037056802439370325, 0.01792462040404124, 0.03102126737524356, 0.041837509122810194, 0.02307038571286414, 0.0970235662534833, 0.050157179656837664, 0.013638720115912812, 0.018973722056086575, 0.07488305001918759, 0.0522323568750705, 0.002278344809643126, 0.03849909308233431, 0.019040832562105994, 0.04415649415126868, 0.044758639697517665, 0.08760482844497476, 0.02273433276319078, 0.04728522590760674, 0.0341902667922633, 0.13341370464435645, 0.0556647975130805, 0.06795186230114528, 0.02617678518540093, 0.05012020628367152, 0.12493139265903405, 0.07195567352963345, 0.08520324195602111, 1.5441510443176543, 31.693509578704834, 90.69037546430314, 92.23756558554513, 76.15898936135429, 75.68294048309326, 53.04171425955636, 31.624976021902903, 20.817334515707834, 91.82328619275773, 75.70978832244873, 70.69760799407959, 63.52815791538784, 51.70711817060198, 38.93354640688215, 51.62088755198887, 46.46532767159598, 24.810856819152832, 6.848938797201429, 0.6570180218134607, 0.15402628215295927, 0.06637945239033018, 0.08061675235096898, 0.05447715088458998, 0.032017149829438755, 0.12025302941245691, 0.1434402944786208, 0.9121878466435841, 1.4711677091462272, 1.9992898617471968, 13.420955402510506, 30.417285306113108, 59.693217822483604, 59.185895102364675, 67.31794166564941, 70.52001898629325, 49.30918366568429, 20.175303595406668, 8.197017431259155, 5.059584413255964, 4.672078166689191, 4.3561270747865946, 6.211561432906559, 4.997119673660823, 15.155171053750173, 21.570873601096018, 3.5264075057847157, 7.489024656159537, 12.564529129437037, 9.131957479885646, 9.048999462808881, 6.598868787288666, 5.915506507669177, 7.192447313240596, 4.424777013914926, 1.489058017730713, 0.6632677635976246, 7.645769936697824, 13.161256057875496, 30.89840636934553, 32.08656569889614, 43.147559370313374, 31.618350914546422, 40.997613021305625, 25.033286026545934, 13.56017906325204, 5.082373201847076, 8.625779475484576, 2.190562043871198, 0.8964737355709076, 0.5652034399764878, 0.07497428583779506, 0.09704202919134072, 0.10378462488629989, 0.08122104885322706, 0.03221162135845848, 0.20121504073696478, 0.1969945936330727, 13.320558275495257, 35.510078634534565, 54.85989454814366, 36.410342829568044, 43.04141174043928, 74.36303983415876, 47.302290303366526, 18.602901935577393, 10.987536447388784, 23.73360116141183, 33.44658177239554, 52.418957642146516, 70.15969930376325, 68.32144219534737, 69.31524998801095, 72.96652834756034, 58.59273433685303, 20.650077479226248, 1.2639059850147791, 0.08853840442108256, 0.05409581081143447, 0.013953923380800655, 0.1093005785452468, 0.04273815918713808, 0.07713473455182143, 0.029715939025793756, 0.09476385465157883, 0.012395031583894576, 0.03475642962647336, 0.024285903167245642, 0.03261996034000601, 0.05884791724383831, 0.03234699588002903, 0.02613135048055223, 0.05576292385480233, 0.018628217113603438, 0.05805530691785472, 0.05381499570129173, 0.016102796287408898, 0.09407814073243312, 0.006990375055465847, 0.040863180333482366, 0.03714739364971008, 0.0358066050601857, 0.026089914043300917, 0.04313146522534745, 0.01572854520886072, 0.012058110957566117, 0.08816337133092539, 0.039313572591968944, 0.05811598151922226, 0.020305589606453265, 0.015351588471925684, 0.042091746016272476, 0.036954791484666724, 0.07041484263858624, 0.02526284092372017, 0.04604253651840346, 0.03654521078403507, 0.019434018160349557, 0.018061541985454302, 0.04299156487520252, 0.02732070871362729, 0.04901733582041093, 0.03556415431999734, 0.01080054129540388, 0.03707848163321614, 0.02747795411518642, 0.0731436051428318, 0.02544665606027203, 0.03167893744206854, 0.04124900891578623, 0.037109836736427884, 0.02074464756463255, 0.05453790691015976, 0.07563501609755413, 0.1271483294133629, 0.047015511630369086, 0.02361258608289063, 0.025693591916933656, 0.06366432843995945, 0.01461752554002617, 0.026726675053526248, 0.02837199524843267, 0.008253819558636417, 0.047272028401494026, 0.0462096902275724, 0.026652078609913588, 0.03775719307096941, 0.008012929448990949, 0.0203071044358824, 0.08176510501652956, 0.05039549133341227, 0.02042182095881019, 0.024393837732662047, 0.16169186867773533, 0.014739909508664693, 0.3210787810385227, 0.4360869111759322, 18.66245494570051, 94.28137125287736, 102.59887218475342, 90.33893557957241, 84.4113439832415, 71.48751395089286, 58.933467047555105, 50.83572721481323, 93.80102143968854, 56.34156315667288, 24.72966190746852, 37.21505192347935, 50.85207632609776, 39.211651529584614, 48.18781042098999, 52.724577631269185, 31.750085285731725, 9.700248905590602, 0.666387559047767, 0.1579218874020236, 0.023773914568924477, 0.04053264217717307, 0.19152927904256753, 0.2880469635128975, 1.2813834186111177, 0.5692058737788881, 0.2940762899816036, 1.3335817605257034, 2.823391160794667, 16.683274473462784, 37.38265984398978, 60.3348422731672, 68.73845223018101, 76.38391644614083, 79.71412549700055, 57.995599201747346, 27.772125210080826, 13.037651947566442, 9.348934088434492, 6.426192590168544, 3.3328100655760085, 1.6881898066827228, 2.864231586456299, 3.248887768813542, 16.28876965386527, 6.738847630364554, 5.481450804642268, 5.349260023662022, 3.0532358331339697, 1.8465361041682107, 2.998893754822867, 3.036570144551141, 1.1697133822100503, 0.8959486037492752, 0.7349148733275277, 2.05279945901462, 13.02641671044486, 21.487015792301722, 41.23501559666225, 44.452702045440674, 53.9024327823094, 43.39296974454607, 46.61336946487427, 34.19036211286272, 17.907531431743077, 6.864857988698142, 1.7266790270805359, 2.458417053733553, 1.0171698076384408, 0.21416347021503107, 0.5022155770233699, 0.5556665488651821, 0.5113185314195496, 0.0377017228331949, 0.06464088282414845, 0.3382642003042357, 0.7235488689371518, 16.381163324628556, 39.86385113852364, 55.00337137494768, 40.36865166255406, 42.37171309334891, 44.46386432647705, 35.17099959509713, 27.23964306286403, 24.596826246806554, 37.43878391810826, 53.2401374408177, 65.22468566894531, 76.17781897953579, 74.69391999925885, 78.53002044132778, 83.7568792615618, 57.7705192565918, 18.727081877844675, 1.0605152760233199, 0.007578106397496802, 0.011791668915455895, 0.06411915724830967, 0.050879130738654306, 0.07612839926566396, 0.07746687744344984, 0.08519462456128427, 0.06548949943057128, 0.04816607292741537, 0.06053846688675029, 0.018683572000424777, 0.011356051129821156, 0.03512913194884147, 0.010137229209898837, 0.04023500618391803, 0.057305600361100266, 0.020827883455370153, 0.03996529529935547, 0.03304457398397582, 0.03426849509456328, 0.0645571176760963, 0.06673636859548943, 0.07871451335293905, 0.037686632214380164, 0.08470990628536258, 0.025977801398507187, 0.0347642904546644, 0.06304803543857165, 0.04596589259537203, 0.05616644184504237, 0.07001045612352234, 0.044157657838825665, 0.014481367310509086, 0.075964410922357, 0.04003264329263142, 0.02849993302619883, 0.040018570476344655, 0.05508398510781782, 0.027956470581037656, 0.014037725848278828, 0.060138321215552945, 0.015672537232083932, 0.14097888155707292, 0.14064185321331024, 0.21619068857814583, 0.12479601135211331, 0.18985097695674213, 0.16783258345510277, 0.20187292114964553, 0.13714188816291945, 0.19430561363697052, 0.1402830167540482, 0.11388409616691725, 0.23592868873051234, 0.15813838078507356, 0.10952967232359306, 0.16698551390852245, 0.195992288844926, 0.1440056769975594, 0.13890861693237508, 0.15237664138632162, 0.11665017131183829, 0.10933835258973496, 0.14244178948657854, 0.0990970471341695, 0.1175645651029689, 0.15079041650252684, 0.22061510330864362, 0.23373930049794062, 0.13791065476834774, 0.09196994600019284, 0.16862792149186134, 0.14733674111110823, 0.2141838398362909, 0.18310891730444773, 0.179314522338765, 0.36898785882762497, 0.18398363036768778, 0.9718488795416695, 5.990344251905169, 59.13962009974888, 120.15779685974121, 102.97372055053711, 95.9674767085484, 91.78590488433838, 69.62889167240688, 48.63765416826521, 33.32368550981794, 105.15501022338867, 94.75691291264125, 100.52001980372837, 95.5175530569894, 73.77509716578892, 62.70475469316755, 75.59879084995815, 73.80484240395683, 40.71024942398071, 12.80029192992619, 0.950230536716325, 0.4072566367685795, 0.18197626593921865, 0.0983676016330719, 0.20158681007368223, 0.18237692729703017, 1.118034309574536, 0.7839129183973584, 2.1121857123715535, 3.3114070083413805, 7.91337285723005, 21.41473020826067, 38.842462471553254, 69.53906536102295, 69.89116532461983, 75.99437264033726, 81.17069721221924, 57.97461911610195, 27.61693545750209, 14.000280567577907, 10.68181049823761, 11.57504311629704, 13.376278485570635, 21.017956801823207, 22.951930556978496, 36.83441570826939, 43.79631267275129, 9.547429357256208, 25.566886833735875, 40.914099148341585, 30.022898605891637, 28.17736152240208, 22.72459592138018, 22.292332853589738, 20.250863518033707, 14.935006959097725, 9.731514930725098, 3.2926707565784454, 16.026315348488943, 20.62945522580828, 38.048992088862825, 39.01672676631382, 50.6382211957659, 35.095750604357036, 48.311717646462576, 37.127400398254395, 24.632687636784144, 17.744476318359375, 19.944031068256923, 10.948194878441946, 3.5345395037106107, 1.901663328920092, 0.2749776733773095, 0.12343303806015424, 0.6452350169420242, 0.12003714671092373, 0.19596654522631848, 0.427821757537978, 1.0834809179816927, 24.855280126844132, 54.201729910714285, 86.52307523999895, 51.782037121909006, 65.75743879590715, 106.35882731846401, 65.54838834490094, 28.208578041621617, 18.992206028529576, 39.035309723445344, 49.01309660502842, 68.89073589869908, 88.66186973026821, 86.68068817683628, 85.82079996381486, 93.73193550109863, 87.84625543866838, 44.92282411030361, 3.1251069137028287, 0.3395172916352749, 0.15871888106422766, 0.20558686900351728, 0.21853603129940374, 0.1809955249939646, 0.15563039321984562, 0.3067837581038475, 0.21838649575199398, 0.15297448502055236, 0.15870643673198565, 0.1453715544193983, 0.07293081656098366, 0.1498203556984663, 0.12980549968779087, 0.13925312273204327, 0.16553671950740473, 0.13190650194883347, 0.1559241446001189, 0.21973161000226224, 0.16078238748013973, 0.14492472553891794, 0.2577320273433413, 0.1710892937013081, 0.11184798220970801, 0.1306173668376037, 0.1288277307259185, 0.13781747833958694, 0.09424209514898912, 0.14058451700423444, 0.09771297140313046, 0.2205621368650879, 0.09961041994392872, 0.06754717723067317, 0.20901771847690853, 0.09823669865727425, 0.10113503384803023, 0.13451295851596765, 0.2210074865392276, 0.08382026545171227, 0.09972347066338573, 0.12418405418949467, 0.14430926713560308], [0.017079874839899794, 0.03931279906204768, 0.049436175131372044, 0.0428831824766738, 0.0351605922249811, 0.030702243958200728, 0.009744644963315554, 0.041122004123670716, 0.02584863716869482, 0.02554677050959851, 0.039527423081121275, 0.03452549362555146, 0.0646521532908082, 0.021744114380063753, 0.059829445289714, 0.02346242289058864, 0.08219621902597801, 0.05002453963139227, 0.054377022864563127, 0.052811642576541216, 0.061305632149534564, 0.014584284109462584, 0.034573666219200404, 0.04912196931296161, 0.04061754047870636, 0.03976956508787615, 0.06735506361084324, 0.050594844921891174, 0.02363754090453897, 0.02051615937879043, 0.0343363587744534, 0.017450134436200773, 0.04169965794842158, 0.055290568486920426, 0.061283898672887256, 0.20578810891934804, 3.527769786970956, 67.0802229472569, 102.07822976793561, 86.06767640795026, 76.95870617457798, 78.97953414916992, 43.733330726623535, 20.717669555119105, 24.292194638933452, 34.1527167728969, 59.74399525778634, 73.01949446541923, 70.25568171909877, 73.9468218939645, 38.27307844161987, 45.957657541547505, 28.38345030375889, 7.143058214868818, 1.0530541049582618, 0.08259808817612273, 0.04031538204955203, 0.09479166780199323, 0.08861163870564528, 0.18319693686706678, 0.14324680343270302, 0.07863124353545052, 1.0842013593230928, 2.452440300158092, 5.4725940227508545, 27.35953422955104, 78.0218083517892, 101.5617493220738, 112.06840528760637, 106.53684711456299, 114.9171667098999, 111.38776670183454, 112.28991385868618, 121.16207558768136, 124.10608291625977, 111.11605739593506, 114.68050411769322, 99.9849042892456, 85.95640100751604, 50.577024936676025, 16.5917614868709, 13.127169932637896, 14.831484011241368, 21.11119294166565, 4.866091413157327, 2.6383235028811862, 5.104186202798571, 6.4811055064201355, 6.980958044528961, 2.470867791346141, 1.2823174084935869, 1.8531503549643924, 22.511241061346873, 67.86009570530483, 102.69392354147774, 118.95999690464565, 130.91344152178084, 131.77134949820382, 124.66117450169155, 136.89254706246513, 128.99030521937777, 121.59164101736886, 106.70887061527797, 72.52444226401192, 30.43428407396589, 7.529547418866839, 2.9038070057119643, 3.5958879717758725, 3.356818045888628, 18.829055377415248, 7.23022814307894, 0.4313905531806605, 0.25580498789037975, 0.16511977330914565, 0.03095269462625895, 0.2777588255703449, 2.6625887836728777, 19.38264094080244, 42.779770374298096, 51.32198647090367, 64.0448329108102, 57.10041413988386, 51.92563206808907, 38.88904319490705, 17.163269928523473, 11.378856386457171, 21.89154859951564, 40.650842326028005, 59.31372806004116, 58.495668002537315, 71.83909279959542, 78.78889642442975, 81.95587144579206, 52.72855200086321, 7.763965742928641, 0.43019966994013104, 0.06219519834433283, 0.03764617456389325, 0.03041580379275339, 0.040425606670656374, 0.05257408068116222, 0.05099246644281915, 0.0373824313948197, 0.04069627768227032, 0.05923787131905556, 0.013660912451866482, 0.04596121409641845, 0.021020692573594194, 0.021109161665663123, 0.0713983452213662, 0.03502275462129286, 0.019297320495492647, 0.05508522343422685, 0.046818312390574386, 0.003971351385449192, 0.06202263331839016, 0.03085335370685373, 0.05257847419540797, 0.02604957513644227, 0.050049092421042066, 0.015769197938165495, 0.046459872874298265, 0.030295268832040683, 0.03350287689162152, 0.009305475895026965, 0.048210194667002985, 0.018484082704942142, 0.0202900833849396, 0.036774209567478726, 0.05909187772444316, 0.029835798844162906, 0.003418605521021943, 0.03801873778658254, 0.06415555386670999, 0.032908972153174024, 0.03320930193045309, 0.011303564749791153, 0.023773385311609933, 0.008713309054395981, 0.03330513482381191, 0.011305292469582387, 0.013536903391858297, 0.020536959869787097, 0.022500689407544475, 0.05363021704501339, 0.027555793956188217, 0.03716488967516592, 0.07151638317321028, 0.030704052254025425, 0.023915543487029414, 0.05312087134058986, 0.032147486228495836, 0.07809482089110784, 0.038477098369704824, 0.10035767020391566, 0.07336698565632105, 0.021936787791284065, 0.03009557258337736, 0.005624447167584938, 0.014073955377430787, 0.07739267963916063, 0.016887354099058678, 0.026042134999962788, 0.04231486190110445, 0.045394678067948134, 0.03619911381974816, 0.04769323919234531, 0.0777578196887459, 0.04238651519907372, 0.11011175358934061, 0.08223209995776415, 0.00534240687764915, 0.662376982825143, 57.76280328205654, 109.11139093126569, 98.54318087441581, 91.17627688816616, 83.32190813337053, 68.74542822156633, 39.94713224683489, 37.78665937696184, 20.356759275708878, 60.391060147966655, 73.93109812055314, 55.566977977752686, 57.92912925992693, 38.586365767887656, 50.14352682658604, 37.70705386570522, 10.929828183991567, 0.999700842159135, 0.12593153970582144, 0.01737071869761816, 0.13891522586345673, 0.1264103547270809, 0.4470636264554092, 0.5800150451915604, 0.8606317245534488, 1.015812086207526, 0.3045157683747155, 6.723664079393659, 33.779508181980674, 84.00297055925641, 107.57895878383091, 116.25600119999477, 114.53103446960449, 120.22238731384277, 116.8883775983538, 115.25213241577148, 128.05866295950753, 127.38233920506069, 120.17969758169991, 125.63454764229911, 112.94792910984584, 98.43889536176408, 61.40211336953299, 21.396366119384766, 2.3716110374246324, 2.1024530231952667, 1.8227035658700126, 1.3842871082680566, 1.4603289536067416, 3.2961965331009457, 3.6065614904676164, 2.7344982964651923, 1.138702160545758, 0.7627472398536546, 3.1528749551091875, 30.15732192993164, 80.64428084237235, 115.98937797546387, 129.1540881565639, 137.8100149972098, 141.79696083068848, 131.71593066624231, 144.72140203203475, 134.821900503976, 131.94133022853305, 116.486250604902, 85.50230148860386, 41.18079532895769, 12.65082401888711, 2.771968628679003, 0.587886919932706, 4.132481064115252, 12.772348012242999, 9.31964829989842, 0.5917416502322469, 0.24436315042631968, 0.043284111855817695, 0.05427419766783714, 0.4467469405915056, 4.176154834883554, 24.326649018696376, 49.327474798474995, 53.137394428253174, 50.62190335137503, 40.94576556341988, 27.27718070575169, 20.306266716548375, 32.30065359388079, 26.3610520362854, 44.34593602589199, 63.56660229819161, 76.4086867741176, 70.1224639075143, 78.16578892299107, 91.46501622881208, 94.82401166643415, 52.943518842969624, 6.878066948481968, 0.38180628099611824, 0.009306021267548203, 0.014135835226625204, 0.02738405335029321, 0.06453529598989657, 0.020614458746942024, 0.07755839146141495, 0.07905468331383807, 0.029138220740216117, 0.045033755113503764, 0.029533925399716412, 0.03113437577017716, 0.048535796481051614, 0.0166143387489553, 0.059465682666216574, 0.02170182977403913, 0.057335455901920795, 0.0907518467200654, 0.05128320852028472, 0.02698108327708074, 0.021245486136259775, 0.018983087535681467, 0.03573387289153678, 0.030190017872623036, 0.06228114837514503, 0.030405289892639433, 0.013810939088995968, 0.05715300462075642, 0.09428539246852909, 0.03533354062320931, 0.0313555001547294, 0.014292946617518152, 0.06275507115892001, 0.027922956040129066, 0.05019430570038302, 0.04819255954186831, 0.06102547861103501, 0.020156486625117914, 0.020943288691341877, 0.08962444721588067, 0.05011294935164707, 0.1443354585873229, 0.12037599352853638, 0.11528004626078264, 0.14316084661654063, 0.07779155644987311, 0.11978633302663054, 0.17445835577590124, 0.13334627183420317, 0.1419814849006278, 0.09922222327440977, 0.138851524995906, 0.16601102905614035, 0.16739517264068127, 0.10594841199261801, 0.11802904946463448, 0.268470006861857, 0.1262901590338775, 0.1389252817524331, 0.18838217934327467, 0.20261179150215217, 0.17706298029848508, 0.12830759292202337, 0.05918105758194413, 0.2011274147246565, 0.13024829807026045, 0.20130544874284947, 0.12543266718941076, 0.14472740755549499, 0.08311574254184961, 0.14392935537866183, 0.2525256010038512, 0.12838595014597687, 0.11384404903011662, 0.18767313739018782, 0.16803872239376816, 0.2958109511860779, 14.726201432091848, 102.10268742697579, 129.42466490609306, 102.71116897038051, 97.98805454799107, 96.16428443363735, 57.90360505240304, 31.993598801749094, 36.112810543605256, 54.58942549569266, 72.99818434034074, 82.21950694492885, 99.55063492911202, 111.08091340746198, 61.10155514308384, 75.75347859518868, 48.604139532361714, 14.368524670600891, 1.7063556547675813, 0.4116916502160685, 0.09813046721475464, 0.4462843154157911, 0.22713768402380602, 0.44923634986792293, 0.6143333922539438, 0.9845429126705442, 4.696825044495719, 8.342621275356837, 14.32161477633885, 36.28474371773856, 92.31107752663749, 107.1652421951294, 121.86448287963867, 115.83826160430908, 127.84126772199357, 123.9502626146589, 124.20799909319196, 132.96663420540946, 129.92835371834892, 123.266295841762, 129.12712914603097, 112.00278650011334, 97.60419436863491, 56.62584522792271, 23.68886171068464, 29.47754839488438, 38.10993473870413, 47.05908250808716, 21.509434155055455, 15.944597584860665, 12.616327949932643, 14.384608013289315, 14.45409607887268, 10.244133046695165, 4.508812001773289, 2.807257443666458, 29.26926224572318, 78.79553195408413, 121.04597118922642, 134.8197465624128, 148.30743680681502, 150.20536504473006, 140.89866992405481, 155.5501000540597, 143.54277910505022, 132.6495462145124, 117.94293349129813, 80.08663926805768, 38.17455298560006, 11.136233108384268, 9.923614382743835, 8.776088987077985, 10.691135849271502, 28.063982554844447, 11.43374194417681, 0.7582091433661324, 0.48542107535260065, 0.31762533634901047, 0.17796593398920127, 0.46121767695461, 7.06069426877158, 32.19603456769671, 69.24113355364118, 78.55224078042167, 95.19602516719273, 82.35093906947544, 78.51536669049943, 56.653016158512656, 27.598830189023698, 19.085235459463938, 36.71032782963344, 55.77076516832624, 78.9231356212071, 75.21675109863281, 89.36320005144391, 94.45255402156285, 104.83252348218645, 81.41032668522426, 18.03977475847517, 0.6022190451622009, 0.18275858967431954, 0.10727101245096751, 0.1823553770248379, 0.17766553296574525, 0.15048362367919513, 0.21611819389675344, 0.1688182098524911, 0.12858944279806955, 0.13579148133950575, 0.16896618476935796, 0.1387328085090433, 0.17192652449011803, 0.06627279347074883, 0.14309927634894848, 0.0635011000558734, 0.13601127240274632, 0.13875575656337397, 0.1604281650590045, 0.0726658214948007, 0.19387866583253655, 0.10978596178548676, 0.1561808343976736, 0.09485397088740553, 0.1226120785410915, 0.10897509886750154, 0.16812043158071382, 0.17594636950109685, 0.18417455655123505, 0.14339883598898137, 0.14883464787687573, 0.13293389896196978, 0.20507857842104776, 0.13474839659673826, 0.16158360163015978, 0.10384538091186966, 0.1367622749613864, 0.162288545231734, 0.10758191041116204, 0.14772710230733666, 0.12146661643471036], [0.015720545280990855, 0.050556741787918975, 0.11254654758210693, 0.010178712296432682, 0.06766507269016334, 0.034005949539797645, 0.04894138400309852, 0.026555770742041723, 0.03857427476240056, 0.11351686622947454, 0.011219763130481755, 0.08068786960627351, 0.03884818238605346, 0.034223355552447696, 0.0169609412218311, 0.03034247112061296, 0.028103134228980968, 0.03671468508296779, 0.03170829425965037, 0.06553441844880581, 0.025487941523481692, 0.03729533463982599, 0.01398875767232052, 0.05328902928158641, 0.03275833737903407, 0.03526602978152888, 0.03763582690485886, 0.0697811519993203, 0.019037987804040313, 0.03000620273607118, 0.0735443207834448, 0.0024291015080442385, 0.024921037389763763, 0.037166243352528126, 0.20411723000662668, 15.788398606436592, 83.75277982439313, 92.10981600625175, 89.42954839978898, 75.89036505562919, 65.61546625409807, 42.7428754397801, 20.944375378744944, 35.53811114174979, 61.15184620448521, 56.396471296037944, 41.70659678322928, 35.23964432307652, 41.20005920955113, 35.39250816617693, 32.75678893498012, 10.43000430720193, 1.160811219896589, 0.14932240598968097, 0.13482019917241164, 0.08263136353343725, 0.0606984586587974, 0.04758727916383317, 0.10812897926994733, 0.5728449385081018, 0.5226803560342107, 1.8491768538951874, 8.490345188549586, 37.519921507154194, 92.0682657786778, 110.71447931017194, 106.51482827322823, 95.98171356746128, 94.68073981148856, 96.7948751449585, 92.58366230555943, 83.58828122275216, 85.14893000466483, 90.67137908935547, 96.8708745411464, 93.19842502049038, 95.90551267351422, 103.74488721575055, 117.1266313280378, 120.76801545279366, 122.31917299543107, 38.73025948660714, 4.590352152075086, 2.065974546330316, 2.565267537321363, 7.682317461286273, 34.57795000076294, 49.859512260981965, 36.122131552015034, 26.441267251968384, 29.890181064605713, 75.1572745186942, 111.01423849378313, 119.73888996669224, 110.50820813860211, 103.56818062918526, 97.28591128758022, 95.77742958068848, 100.24536446162632, 97.23846898760114, 102.02103219713483, 105.21188817705426, 105.01777635301862, 108.86951719011579, 119.83441380092076, 106.45195402417863, 72.7278299331665, 26.087312119347708, 9.653886181967598, 13.902763468878609, 0.474246689251491, 1.1406125894614627, 0.3578812176627772, 0.03355855747525181, 0.18607359964932713, 0.0065638869585070226, 0.112976847349533, 0.15537691967827932, 8.727618353707449, 29.892143930707658, 41.8841232572283, 60.02780137743269, 67.3286349432809, 69.62978104182652, 35.663804054260254, 35.197312423161094, 13.983959249087743, 12.466934732028417, 9.994248032569885, 31.16481419972011, 68.87539427621024, 57.61766930988857, 66.28805187770298, 77.03542123522077, 70.87473842075893, 20.131165163857595, 0.7661906150834901, 0.3372913439358984, 0.07624413698379483, 0.06650519171463591, 0.09166040511003562, 0.042182123488081355, 0.024905839901683584, 0.003196807902505887, 0.0508508188650012, 0.029785251377948692, 0.01433617269088115, 0.04110592284372874, 0.02650582038664392, 0.04112513895545687, 0.06474166563046829, 0.04291378440601485, 0.06142911873757839, 0.030875616440815584, 0.040708732192537615, 0.049196438531258276, 0.05357578496581741, 0.03847266753603305, 0.02239355890612517, 0.02967408698584352, 0.023772774630093148, 0.04127053204657776, 0.07636068215859787, 0.0545124855956861, 0.05294377030804753, 0.031764724624476263, 0.044434961530246904, 0.012754672107153704, 0.03708600997924805, 0.029918291739055088, 0.07093310768582992, 0.008982846064360013, 0.10067755875310727, 0.062427868002227375, 0.03381222100662334, 0.055990494322031736, 0.03598077142877238, 0.07002877656902586, 0.127676216087171, 0.019919803432588066, 0.06115678192249366, 0.03885341049837215, 0.006452293393002557, 0.04809839923733047, 0.0319521631380277, 0.08429706522396632, 0.07307261002383061, 0.05947032384574413, 0.06662555704159395, 0.027731600683182478, 0.042765907876725705, 0.011657401254134519, 0.034478654353214164, 0.04256924807227083, 0.02048319954025958, 0.04903506933312331, 0.027989338817340986, 0.1095542556473187, 0.018713554766561304, 0.043898114801517556, 0.028353992018050382, 0.048313325204487355, 0.046990775636264255, 0.03394819263901029, 0.027282010165176222, 0.08147288034004824, 0.06066880667848246, 0.026263335719704628, 0.07121714922998633, 0.041389184072613716, 0.27353266520159586, 10.525729639189583, 81.13774190630231, 107.37970529283795, 101.4819701058524, 89.48518957410539, 83.05650084359306, 76.88265119280133, 33.404260294778005, 17.30324833733695, 25.701044389179774, 36.73371546609061, 48.86602061135428, 50.03976937702724, 44.54497759682791, 44.64281518118722, 41.07711778368269, 16.5790410723005, 1.2764680023704256, 0.1657070725091866, 0.15938315327678407, 0.03840839669906667, 0.30713108660919325, 0.4352574428277356, 0.47834851486342295, 0.9216227403708867, 1.1799122520855494, 0.9014066308736801, 12.28619384765625, 47.60588836669922, 101.2857390812465, 118.51703534807477, 109.2261334827968, 100.79771845681327, 100.46321133204869, 103.52648448944092, 99.6534126826695, 90.09023870740617, 90.31129564557756, 98.25954151153564, 102.2897537776402, 99.57518986293248, 99.826582636152, 107.85628918239048, 119.75281415666852, 128.4380484989711, 133.8979012625558, 54.46087339946202, 6.341103647436414, 1.0020292486463274, 3.172932667391641, 10.117604613304138, 39.83456448146275, 58.28594357626778, 45.95984969820295, 33.76270048958914, 38.41469662530081, 87.64573042733329, 120.32124628339494, 123.87010819571358, 113.13414083208356, 106.57891150883266, 102.89546298980713, 101.7281447819301, 103.76668371473039, 101.46716349465507, 105.69434329441616, 110.05720751626151, 109.81024074554443, 118.13022913251604, 128.8335816519601, 120.67611857822963, 84.36895302363804, 36.73501477922712, 12.776232055255345, 8.511380859783717, 0.46811642391341074, 0.44086917170456474, 0.28777704228247913, 0.14041581962789806, 0.34843484312295914, 0.03571813087910414, 0.2048943154513836, 0.1690166677747454, 10.40798112324306, 35.69790581294468, 44.94923421314785, 49.625976358141216, 48.570517199380056, 51.2414881161281, 27.823976142065867, 24.787342378071376, 17.13085310799735, 16.037997007369995, 23.897545644215175, 43.02624034881592, 79.0051521573748, 66.12032931191581, 77.11819512503487, 87.83968244280133, 76.73823288508824, 19.772019726889475, 0.38488256878086496, 0.12856072719608033, 0.024547634479988898, 0.09504498528050524, 0.06331839093140193, 0.04822350413139377, 0.05337622442415782, 0.031216712602015053, 0.04657548167077558, 0.09752245912594454, 0.06025701056101492, 0.10802949246551309, 0.028920427962605442, 0.08438610937446356, 0.03464684961363673, 0.022813670470246246, 0.04992814016129289, 0.03830676572397351, 0.01710923674649426, 0.021464006642677953, 0.011442164009037827, 0.020843888400122523, 0.023690610824685012, 0.05784954795879977, 0.013801549012506647, 0.039420971114720614, 0.03971501426505191, 0.024648083107812063, 0.025805724917777946, 0.052312352761094055, 0.043899068143218756, 0.016577862402690307, 0.024007445966292704, 0.006666687982422965, 0.04600792105442711, 0.04465909521760685, 0.07173506822437048, 0.03403550652520997, 0.028805426454969814, 0.008184638672641345, 0.18726320724402154, 0.19113206464265073, 0.2519662710172789, 0.16762400179037026, 0.19816168743584836, 0.15679452860993998, 0.20098083758992807, 0.10638610100639717, 0.1401906409966094, 0.15999718675655977, 0.10745668677347046, 0.14957494315292152, 0.17598215543798038, 0.09263085267905678, 0.11078895867935248, 0.09185062561716352, 0.10333286305623395, 0.14563520598624433, 0.08810771110334567, 0.17768248277051107, 0.17761101946234703, 0.13830039171235903, 0.07639767588781458, 0.15427003907305853, 0.14807069887007984, 0.07525724172592163, 0.1560638549604586, 0.22925412974187306, 0.18265583233109542, 0.1989246186401163, 0.12518999592534133, 0.08535065368882247, 0.10768153292259999, 0.11170177826923983, 0.36837188473769594, 37.470613615853445, 118.46204730442592, 112.82650933946881, 104.93786512102399, 98.96409579685756, 80.0909263065883, 60.449473653520855, 34.33136190686907, 53.192208766937256, 94.97821303776333, 81.97655623299735, 61.34442247663225, 58.60117639814104, 61.253929138183594, 54.753423827035085, 50.79130738122122, 19.417475734438213, 2.4120352225644246, 0.3238430241388934, 0.34288952925375527, 0.1985224780759641, 0.3487825516079153, 0.3865930741386754, 0.22379193641245365, 1.0495111750704902, 5.5532382896968295, 9.517496517726354, 19.69270430292402, 45.32146658216204, 104.22939899989537, 121.62267167227608, 115.25491169520787, 107.73061711447579, 105.4704167502267, 109.4185846873692, 104.35468196868896, 93.89656611851284, 97.34738200051444, 100.77676268986293, 106.23116111755371, 102.30680465698242, 105.9009062903268, 114.40584877559117, 127.32551683698381, 136.98326274326868, 137.40462929861886, 48.89473404203142, 15.565258945737567, 10.367558240890503, 5.623002111911774, 11.409623878342764, 46.68109008244106, 63.48135484967913, 52.47874689102173, 39.42866461617606, 43.87153387069702, 93.05700138636998, 126.79848207746232, 132.02259635925293, 118.52804129464286, 110.61225741250175, 107.34175423213414, 104.38063349042619, 108.83672864096505, 105.3423683983939, 109.11724131447929, 115.90528392791748, 115.29273768833706, 123.86827387128557, 136.39693205697196, 124.70943668910435, 84.93899713243756, 32.03778239658901, 14.27028843334743, 24.628475291388376, 2.318156591483525, 1.4400744118860789, 0.26026347864951405, 0.290299509785005, 0.522996227656092, 0.11895078500466687, 0.3029322033481938, 0.9957225642033986, 14.113354682922363, 46.61468614850725, 65.7916795185634, 91.0896189553397, 100.95720740727016, 99.90798078264508, 52.38826744897025, 51.705579144614084, 23.59207156726292, 23.176598821367534, 21.11998588698251, 43.578198296683176, 89.0487037386213, 74.05105182102749, 84.43266105651855, 90.79764175415039, 97.36826133728027, 40.401666028159006, 1.611477243048804, 0.5541765402470316, 0.13542794941791467, 0.2789233816521508, 0.19065337175769465, 0.2563742787710258, 0.18174363699342522, 0.16612944698759488, 0.17579133782003606, 0.1745925157197884, 0.12760324643126555, 0.12582842952438764, 0.12309326843491622, 0.22728601177888258, 0.15031609338309082, 0.06014391912945679, 0.10353141597339086, 0.1857593429407903, 0.14528331772557326, 0.10960153596741812, 0.17534579815609114, 0.11078132516039269, 0.11169523040630988, 0.2031837422400713, 0.15201635286211967, 0.07869543294821467, 0.10434042649077517, 0.10233629867434502, 0.18209004269114562, 0.10923592772866998, 0.16077523572104319, 0.13982780118073734, 0.14943090373916285, 0.1547804195433855, 0.14014899251716478, 0.08297868525343281, 0.1841364907366889, 0.1299756219876664, 0.20311246892171247, 0.10609207821211644], [0.020263557754723088, 0.28028387150594164, 0.21181116572448186, 0.07078834223960127, 0.0721555088779756, 0.08554310657616172, 0.04858542453231556, 0.10917834724698748, 0.0554697051245187, 0.22407434268721513, 0.06285391335508653, 0.03487962105178407, 0.04083471918212516, 0.045922334039849896, 0.08781959156372718, 0.11557052710226604, 0.020092039369046688, 0.05148806842043996, 0.035523133485444953, 0.044164541576589854, 0.09430633884455476, 0.1669391563960484, 0.17241724101560457, 0.14468988456896373, 0.411132347370897, 0.11933645073856626, 0.06738555018923112, 0.10517307038285903, 0.0734399553122265, 0.03781365736254624, 0.048100173606404235, 0.0700783571228385, 0.04372585850900837, 0.8812934958509037, 44.91104343959263, 102.03449780600411, 85.84625816345215, 90.94403335026333, 103.16836043766567, 74.00459616524833, 30.26773922783988, 15.784884554999215, 41.71200248173305, 63.08639144897461, 55.315672057015554, 53.948541028159006, 34.58856684820992, 35.51267031260899, 29.32193306514195, 17.902259486062185, 2.3283437362739017, 0.16561818442174367, 0.3514843152037689, 0.017032397744644965, 0.22955306512968882, 0.13209095490830286, 0.10227509481566292, 0.13497666934771196, 0.8928947619029454, 1.1440389198916299, 6.502027835164752, 51.398347173418315, 101.31419890267509, 108.16385119301933, 98.72744015284947, 85.83046490805489, 88.44426604679653, 96.47142955235073, 106.90653991699219, 101.99885354723249, 94.27867535182408, 80.45525509970528, 88.56888893672398, 106.4960264478411, 107.28340326036725, 100.18403966086251, 96.91542639051164, 90.94308144705636, 83.84024374825614, 86.60095759800502, 89.67727947235107, 128.60404096330916, 47.905046531132285, 27.0508222920554, 61.64409828186035, 111.46890776497978, 122.25566646030971, 139.35102816990442, 131.69856016976493, 108.49545397077287, 66.95250810895647, 89.90619482312883, 101.01067379542759, 114.72828687940324, 119.20351736886161, 106.94400460379464, 108.27978188650948, 99.35448033469063, 99.03084019252232, 106.26717363085065, 103.29100309099469, 102.2097452708653, 104.83492755889893, 100.18410914284843, 96.23325225285122, 103.52101625714982, 108.94237600054059, 123.38666643415178, 103.475081716265, 70.37182780674526, 66.76882553100586, 35.06161757877895, 10.676703572273254, 0.2481879980436393, 0.09027157963386603, 0.17368728215140955, 0.04399547100599323, 0.15767009662730352, 0.284312903881073, 1.1446724001850401, 12.868614435195923, 32.896489415849956, 40.496463775634766, 46.811292375837056, 71.2524494443621, 80.7915826525007, 88.04321602412632, 156.3838005065918, 96.01976885114397, 30.677790641784668, 26.658440147127422, 54.34422704151699, 66.64695412772042, 64.53714057377407, 77.04403005327497, 80.25239549364362, 46.778531619480674, 3.1710811895983557, 0.13823575446648256, 0.054682268628052304, 0.13686302384095533, 0.040200221086187024, 0.02372069367473679, 0.0940281462722591, 0.038632374323372326, 0.06308478489518166, 0.11339285038411617, 0.0510127241058009, 0.05505135775144611, 0.4992451678429331, 0.2289823086134025, 0.152501858238663, 0.16028241573699883, 0.19062475115060806, 0.18609470208840712, 0.08114299018468175, 0.025578458094969392, 0.056669036126030345, 0.1060223723096507, 0.06353495895330395, 0.0645973344466516, 0.06398849854511873, 0.017796417997617806, 0.02802929774458919, 0.10281256918928453, 0.029737472334610562, 0.07087656536272594, 0.058465915599039624, 0.03647199007017272, 0.017766121409035156, 0.11335856400962387, 0.19500097632408142, 0.29471104592084885, 0.23844556510448456, 0.1021828886919788, 0.04576852372182267, 0.04586805123835802, 0.28217597997614313, 0.19331903729055608, 0.21018097177147865, 0.07662024215928145, 0.01861306542663702, 0.0893580000847578, 0.03391541939760957, 0.07317211039896522, 0.20683951250144414, 0.10025580174156598, 0.04524375152375017, 0.02950741842921291, 0.08081111870706081, 0.09619956689753703, 0.06523758651954786, 0.031982256166104756, 0.008986667064683778, 0.03226665733382106, 0.07054964040539094, 0.054273644661796946, 0.10698684877050774, 0.2866463043860027, 0.07364309512610946, 0.4296355630670275, 0.12231534160673618, 0.010266521513195974, 0.07246067321726254, 0.08564846270850726, 0.018007116691608514, 0.022859710767599087, 0.05989217585218804, 0.05824321362056902, 0.6233294095311845, 35.15407378332955, 105.61202798570905, 96.72510828290666, 101.14743518829346, 104.98341056278774, 89.14317839486259, 51.9016364642552, 17.950181211744034, 21.816931894847325, 36.14877789361136, 43.535946301051546, 42.235639572143555, 38.86891426358904, 40.472676617758616, 38.58183901650565, 25.900777305875504, 3.9234970552580695, 0.2621034484888826, 0.33663319210921017, 0.10418808180838823, 0.13003206253051758, 0.3547115906008652, 0.4391908017652375, 0.6157727007355008, 0.598928910280977, 1.5834459300552095, 11.095513190541949, 58.239536557878765, 109.16243239811489, 115.5690814426967, 97.8193939753941, 89.64378915514264, 94.46080153329032, 100.49354716709682, 112.27170263017926, 108.92479705810547, 103.53207778930664, 86.33370903560093, 92.01568875994, 110.61326490129743, 112.41606535230363, 105.73908969334194, 101.7467520577567, 98.0100108555385, 89.74227292197091, 92.31867190769741, 92.70860481262207, 129.7375978742327, 59.04445062364851, 36.767629623413086, 73.6885712487357, 127.14507211957658, 134.97280148097445, 149.84811646597726, 142.78945541381836, 118.64511844090053, 74.43213966914585, 93.97855486188615, 102.68578025272915, 120.18556186131069, 124.58140918186733, 112.78101253509521, 111.64906065804618, 102.4259593146188, 105.72155244009835, 111.50855418613979, 109.32225486210415, 109.21439102717808, 111.62225450788225, 104.70299516405377, 101.69792706625802, 108.43674864087785, 115.88729504176548, 128.46021325247628, 115.56676074436733, 86.36714376722063, 82.68221528189522, 48.1408440726144, 19.393388066973003, 0.646315298974514, 0.13201665532376083, 0.20147485179560526, 0.23852802067995071, 0.1698484702834061, 0.3111575948340552, 1.7505965722458703, 16.681532212666102, 42.41148110798427, 41.67855732781546, 43.644379888262065, 49.837191173008506, 44.9831622668675, 36.147735663822715, 106.71865367889404, 60.6777150290353, 37.077279567718506, 44.28924567358834, 58.19952188219343, 72.04096576145717, 69.29957485198975, 87.94765050070626, 85.90191323416573, 51.216835907527376, 2.4839647114276886, 0.18572105999503816, 0.007228526004057909, 0.08520371014518396, 0.05041543687028544, 0.045256545301526785, 0.1510659967150007, 0.06342690903693438, 0.03724603567804609, 0.11013101719852005, 0.023295937538413063, 0.09536989498883486, 0.3634814385856901, 0.266527958214283, 0.11441779110048499, 0.12342868186533451, 0.16269683332315513, 0.19105558017534868, 0.08956138417124748, 0.04508292515363012, 0.05616386680464659, 0.13967827920402798, 0.0638197808127318, 0.06483169365674257, 0.03863736155575939, 0.09754668961146049, 0.049537287027175934, 0.08482375089079142, 0.05430485387997968, 0.07165812913860593, 0.04830738802307418, 0.04583171908078449, 0.012639775772445967, 0.14547480030783586, 0.34156920867306845, 0.3780656260039125, 0.22165981653545583, 0.016227897788797106, 0.0616768654435873, 0.10331608967057296, 0.3431678371770041, 0.38762208606515614, 0.2487528920173645, 0.17362618685833045, 0.14404554771525518, 0.16045891626604966, 0.20817366162581102, 0.1656238298330988, 0.3531741388142109, 0.13398165202566556, 0.21371198658432278, 0.11049734468438796, 0.14233835360833577, 0.2447242939046451, 0.14721749536693096, 0.1092202060722879, 0.218713712479387, 0.11156482276107584, 0.1857446458722864, 0.18943310795085772, 0.22381115252418177, 0.36332893105489866, 0.31865527108311653, 0.6243708250778062, 0.39625367575458115, 0.23681200561778887, 0.17030265448348864, 0.23022163925426348, 0.2496415286191872, 0.09267085910375629, 0.11023826644356761, 0.06467493849673442, 1.594177857041359, 77.54985891069684, 130.47207805088587, 104.5059095110212, 109.9619060243879, 123.71305111476353, 85.99820137023926, 47.67519317354475, 23.617762531552994, 72.39500427246094, 101.85949352809361, 85.27374744415283, 86.22264902932304, 53.32396398271833, 58.18896409443447, 50.74846131461007, 35.85297570909773, 5.343615046569279, 0.3436744585633278, 0.514716851924147, 0.29081934903349194, 0.4531153717211315, 0.3386200512094157, 0.33663796899574144, 0.6996448401893888, 2.598059126308986, 6.236171518053327, 11.236868211201259, 58.383600507463726, 117.90495463779995, 123.15884889875139, 106.98497813088554, 96.37671865735734, 101.8541990007673, 106.8285185950143, 118.99590519496373, 116.5170658656529, 110.14840262276786, 92.1661867414202, 100.20209802900041, 117.30853516714913, 115.77516501290458, 110.56664943695068, 108.14896815163749, 100.917053767613, 91.8681229182652, 95.50276729038784, 101.4897381918771, 136.15581566946847, 60.87813581739153, 37.506337778908865, 87.7738343647548, 133.12498365129744, 132.81735910688127, 146.94122641427177, 141.57151957920618, 133.00169481549943, 87.61873667580741, 99.28681877681187, 104.80156925746373, 119.21349498203823, 124.88628223964146, 115.94007355826241, 115.50760378156389, 111.5565801348005, 113.54727377210344, 118.85517638070243, 114.69775649479458, 113.39885330200195, 114.91536017826625, 106.34248515537807, 103.8543004989624, 112.97297041756767, 119.30458586556571, 137.94433757237024, 115.69347504207066, 79.11553818838937, 73.74756840297154, 41.83598613739014, 15.598964657102313, 0.5214148068002292, 0.24951317693505967, 0.2855589655893189, 0.2907001982842173, 0.3661726170352527, 0.5275933838316372, 3.150608322450093, 25.488102946962627, 55.96376528058733, 59.14350414276123, 66.83774471282959, 110.95894472939628, 113.46855763026646, 118.37102590288434, 174.6384274618966, 106.01398822239467, 46.34051718030657, 39.71996089390346, 67.7475835255214, 80.95411491394043, 81.52779293060303, 94.87983349391392, 98.2365082332066, 80.24494702475411, 6.8538468309811185, 0.2903707559619631, 0.15101856711719716, 0.25354207360318726, 0.14905738378209726, 0.1860784308186599, 0.18702129593917302, 0.12181226217320987, 0.14028995138193878, 0.215113351387637, 0.10647838855428354, 0.2182223852723837, 0.657985015639237, 0.43176928428666933, 0.20523697563580104, 0.2957742560122694, 0.20897471292742661, 0.2565051003226212, 0.16648084670305252, 0.0717985180339643, 0.16389049855726107, 0.23410747359905923, 0.12051564960607461, 0.2973647692373821, 0.16398067586123943, 0.25025313294359613, 0.14789552826966557, 0.2031544702393668, 0.12107191261436258, 0.15895630046725273, 0.08660480353449072, 0.1589531927768673, 0.14086855176304067, 0.27545134510312763, 0.24628240029726708, 0.4951936623879841, 0.34860100277832573, 0.19694843968110426, 0.17165200279227324], [0.03706115524151495, 0.09776338655501604, 0.0865125363426549, 0.17895525161709103, 0.03507581266707607, 0.06917186826467514, 0.17112839088908263, 0.20274363085627556, 0.12992782598095282, 0.09576470737478562, 0.13501092179545335, 0.013662417951439108, 0.053614573420158455, 0.1298019713056939, 0.07994636653789453, 0.13437946353639874, 0.07768360152840614, 0.02893382224387356, 0.003793461980032069, 0.0213505759436105, 0.046067123234804185, 0.14712450892797538, 0.16071863232978753, 0.20706279123468058, 0.07987394649535418, 0.035158186818339994, 0.12548206453876837, 0.031220763456076384, 0.016761882796085308, 0.006493185729985791, 0.09801352848964077, 0.04470301000401378, 0.412867469979184, 53.89807973589216, 114.70954758780343, 89.98586981637138, 90.84650843484062, 80.9317695072719, 56.398187501089915, 29.854693140302384, 23.710984774998256, 69.32849325452531, 49.97771501541138, 40.50129277365548, 44.380861146109446, 40.607193742479595, 37.04456744875227, 24.602702685764857, 7.224755133901324, 0.18082310924572603, 0.380801044936691, 0.031209872969027077, 0.1476828075413193, 0.045971246236669164, 0.07416957723242895, 0.1692708877048322, 0.06428824138960668, 1.4886278808116913, 5.236492497580392, 49.215455940791536, 88.77333273206438, 111.84167861938477, 95.66401413508824, 85.2798410143171, 87.55598749433244, 95.8282973425729, 84.49616064344133, 86.25283200400216, 96.4708320072719, 100.41452530452183, 89.4842585154942, 75.91130692618233, 78.90180465153286, 94.57782309395927, 92.17911039079938, 90.68839522770473, 75.37057031903947, 76.24934373583112, 78.38501848493303, 97.2098285130092, 87.1571261542184, 99.04867621830532, 74.78895051138741, 48.34422826766968, 86.42907306126186, 101.34253365652901, 77.52993147713798, 70.38408442905971, 85.51189000265938, 88.54844038827079, 61.97419330051967, 89.42356600080217, 100.27226093837193, 104.70649010794503, 111.18002946036202, 103.33272007533482, 94.82906995500836, 89.04140813010079, 84.53137411390031, 85.28685869489397, 85.48461832318986, 84.10026618412563, 87.43899372645787, 91.3348695210048, 99.84682968684605, 103.08066027505058, 99.8534791128976, 92.36837932041713, 101.02835696084159, 116.74791281563895, 114.53793403080532, 129.69435228620256, 118.18250737871442, 75.63588728223527, 10.121867333139692, 0.2577231792466981, 0.14487672597169876, 0.1873759390520198, 0.05229502297671778, 0.044733259095145125, 0.137700173205563, 3.7028253078460693, 25.703328609466553, 45.99148484638759, 56.483115332467214, 60.183642523629324, 69.24706036703927, 124.00302723475865, 116.84153284345354, 25.36008412497384, 20.529793739318848, 21.00431748798915, 58.96673502240862, 64.04725783211845, 62.22546795436314, 74.4749127796718, 82.34875733511788, 61.93223312922886, 3.5778109303542545, 0.19306864429797443, 0.09385408168392521, 0.13398722958351883, 0.052413688573454104, 0.04236290218042476, 0.1123134708032012, 0.06307410475398813, 0.014170737371646931, 0.045095213422817845, 0.11212559802723782, 0.24074026197195053, 0.22403129642563208, 0.15536595455237798, 0.16110732432987007, 0.17119962349534035, 0.17107512589011872, 0.0961344139650464, 0.02787018976440387, 0.08290189544537238, 0.12229784897395543, 0.03671565538804446, 0.13535188564232417, 0.007695116368787629, 0.061796199397317, 0.09563364833593369, 0.019947572478226254, 0.030647231731563807, 0.07656631898134947, 0.08793812484613486, 0.014049169341368335, 0.042742111653621705, 0.18407299342964376, 0.22275212220847607, 0.1523711181112698, 0.12794814578124455, 0.03142792019726975, 0.12791173559214386, 0.07788868873779263, 0.09380707277783326, 0.04321741186348455, 0.14483766949602536, 0.1015770315591778, 0.07184395952416317, 0.15577133851391928, 0.19663320588214056, 0.12881189371858323, 0.03031571987750275, 0.14152811494256767, 0.02020602477049189, 0.09896166582724877, 0.1182889419474772, 0.06411129981279373, 0.14752059695976122, 0.025899133744782636, 0.08305639786911861, 0.008964429775785123, 0.07892994143600975, 0.029153816867619753, 0.1715511724885021, 0.1351867573601859, 0.2636463556970869, 0.06515500202242817, 0.05177749074729426, 0.12585221896214144, 0.07387866212853364, 0.036168494927031655, 0.05579652151625071, 0.1486017746584756, 0.15225104455436977, 0.07316053459154707, 47.7201167515346, 128.83177512032645, 100.89654963357108, 106.39205360412598, 87.8736799785069, 87.35392693110875, 56.0070595060076, 18.14564446040562, 22.527748244149343, 43.80887848990304, 42.23411096845354, 40.36857523236956, 44.19631004333496, 44.34803785596575, 35.816612311771934, 11.324057681219918, 0.35058645052569254, 0.3520575687289238, 0.03471012639680079, 0.19956101663410664, 0.7672280679856027, 0.16893977618643216, 0.97646150631564, 1.4059630994285857, 1.2765407413244247, 8.596939240183149, 54.48172494343349, 96.77146666390556, 113.99625941685268, 98.40142372676304, 89.42715127127511, 93.8993592943464, 100.99085058484758, 89.9448823928833, 92.26876299721854, 101.50545501708984, 105.80220018114362, 92.16344220297677, 79.52804579053605, 84.49900940486363, 98.59059538160051, 97.0617207118443, 97.3603264944894, 78.83303138187954, 79.31520162309918, 83.77281148093087, 101.67451858520508, 95.07557814461845, 107.69459765298026, 79.60562242780412, 53.90168237686157, 100.26630633217948, 109.0925543648856, 85.55589294433594, 75.74482113974435, 93.85602337973458, 96.33506420680455, 70.2679522378104, 93.4846282686506, 104.70112609863281, 104.2835532597133, 114.0471202305385, 106.46139662606376, 99.827499798366, 90.52937180655343, 87.99574593135289, 86.54312079293388, 88.13533524104527, 87.1439801624843, 90.0767800467355, 96.24336882999965, 104.55504022325788, 107.41432816641671, 104.37233039311, 97.10849598475865, 102.95324420928955, 118.45936529976981, 118.60629190717424, 130.3866568974086, 128.29006576538086, 90.37019552503313, 18.845864806856426, 0.03538022722516741, 0.10993232178900923, 0.21235281308846815, 0.05769829571779285, 0.2774144283362797, 0.0345406826319439, 4.485214616571154, 33.38532645361764, 49.09634297234671, 46.3639360836574, 54.765204497746055, 70.87648936680385, 144.623112814767, 126.77783203125, 35.81472587585449, 33.45242173331124, 37.485045024326865, 71.11286013466972, 67.03790841783795, 72.68072114671979, 80.97265270778111, 91.02076925550188, 69.32519286019462, 2.8831513140882765, 0.15063020081392356, 0.13049153930374555, 0.16065662779978343, 0.0567686620301434, 0.060560363211802075, 0.08566332262541566, 0.10650310758501291, 0.025760407260219966, 0.02446882433391043, 0.0768559245126588, 0.29699849603431566, 0.2073056660592556, 0.1307602934539318, 0.1715621647558042, 0.14210858808032104, 0.17859904787370137, 0.08412963670811482, 0.045114816299506595, 0.06145634834787675, 0.1044474450339164, 0.0605277663895062, 0.12322727910109929, 0.02813739176573498, 0.04333515125992043, 0.04224254024614181, 0.017753519317401305, 0.08736301892037902, 0.11468889298183577, 0.06250117692564215, 0.04996721360034176, 0.03751952939533761, 0.05993063521704503, 0.23227855030979427, 0.17966936901211739, 0.054561960976570845, 0.04598441660138113, 0.09549199058009045, 0.2080206519791058, 0.18768289472375596, 0.17988289041178568, 0.23948833772114345, 0.20934859929340227, 0.2291990326983588, 0.21317659531320843, 0.26005367562174797, 0.19442069317613328, 0.1770335454493761, 0.22642025537788868, 0.07871249131858349, 0.19326090041015828, 0.29049598638500485, 0.1587988260601248, 0.21494462686989987, 0.17101754540843622, 0.22305697442165442, 0.0760788254972015, 0.21753090380557946, 0.18823656572827271, 0.24836501425930432, 0.26149488400135723, 0.4619815988200051, 0.23370113968849182, 0.11855490053338663, 0.23579556015985353, 0.2896819886352335, 0.1037793933813061, 0.16816385782190732, 0.20199940007712158, 0.16738176478871278, 1.7034916941608702, 93.09346553257534, 138.01297187805176, 108.87162944248745, 115.95785399845668, 102.01959392002651, 72.01531996045793, 47.3267479624067, 40.376537867954795, 112.66866711207798, 78.59199837275914, 61.06395149230957, 67.3506190436227, 62.90181255340576, 63.037524768284385, 44.742014612470356, 14.362820199557714, 0.5790037565997669, 0.7295922275100435, 0.24542310354965075, 0.42644935260925976, 0.2842808227453913, 0.14162692321198328, 0.5320980963962418, 2.3805333929402486, 7.169142186641693, 12.719896929604666, 60.868311064583914, 95.1733740397862, 121.12240137372697, 105.28010559082031, 92.42848818642753, 97.07835469927106, 106.47266660417829, 96.31290640149797, 100.17430523463658, 111.07032435280937, 112.99602454049247, 97.68387631007603, 87.0397641318185, 92.0574265888759, 104.03473826817104, 102.54828235081264, 103.94717706952775, 87.30574117388043, 85.00841658455985, 90.7595795222691, 106.637526512146, 98.13509232657296, 110.76024709429059, 87.39258670806885, 72.52251761300224, 112.68989385877336, 110.70357758658272, 94.83315549577985, 84.63272748674665, 102.54357842036656, 102.84836809975761, 79.15482330322266, 94.96625518798828, 106.43710572378976, 107.95385578700474, 116.79079709734235, 109.9715223312378, 101.87354278564453, 93.86028957366943, 90.11424473353794, 89.57732963562012, 91.23482935769218, 92.31787981305803, 95.73939514160156, 100.13654177529472, 110.0957283292498, 109.8536183493478, 107.59650993347168, 97.5709194455828, 107.70796598706926, 128.03980554853166, 128.3412878853934, 140.9413457598005, 132.41814340863908, 86.4663084575108, 15.165998084204537, 0.22702103028339998, 0.33200683178646223, 0.45300154068640297, 0.22424561849662236, 0.43447370773979593, 0.30604144079344614, 7.507266283035278, 47.32973568780081, 73.19823687417167, 79.40686225891113, 82.87260287148612, 86.28665583474296, 124.80717005048479, 130.71972574506486, 36.8975887298584, 31.707524095262798, 33.86059365953718, 71.26123196738106, 79.98682839529855, 80.74256311144147, 92.59762123652867, 95.28132125309536, 93.15103135790143, 6.292811495917184, 0.5420541050178664, 0.17514609172940254, 0.4351403276835169, 0.2219657272632633, 0.18317660795790808, 0.2784011539603983, 0.22497117599206312, 0.14169390818902425, 0.1558803655207157, 0.20716587427471364, 0.47777262862239567, 0.2631802564220769, 0.3227505013346672, 0.24887728105698312, 0.4434468719576086, 0.2010392187429326, 0.17160632381481783, 0.19655235164931842, 0.20667141223592417, 0.31226129989538876, 0.31026697690997807, 0.31822008586355616, 0.14663585514894553, 0.13911991273718222, 0.2626136525401047, 0.13245948084763118, 0.07840159335838896, 0.21501015978200094, 0.2866973030780043, 0.1223328478102173, 0.16126132463770254, 0.2685707557414259, 0.29706048699361937, 0.2309979647397995, 0.16828432492911816, 0.15459207179290907, 0.2026480117014476], [0.05385890370234847, 0.08673337234982423, 0.12612788059881755, 0.14964176528155804, 0.1379868813923427, 0.09588016010820866, 0.1020222387409636, 0.014517010755038686, 0.06571005723838295, 0.12535604701510497, 0.1583854625267642, 0.02159395458043686, 0.0759120551603181, 0.0825715438861932, 0.09079730178096465, 0.21119295246899128, 0.15075336849050863, 0.031061453611723015, 0.01510345669729369, 0.05288750618430121, 0.01642552111297846, 0.150476268359593, 0.16300901371453488, 0.12584423939032213, 0.1264873548809971, 0.07538187503814697, 0.03198588972112962, 0.06665338376270873, 0.03293934677328382, 0.03972083609551191, 0.06092273483851126, 0.4337702840566635, 48.31749507359096, 117.40914508274624, 91.64608628409249, 103.19656317574638, 74.36996718815395, 65.64885929652623, 21.710289205823624, 17.778492961611065, 50.20677627835955, 41.56396416255406, 37.768420355660574, 31.54537398474557, 31.489493097577775, 31.032690729413712, 18.08964024271284, 2.2228383805070604, 0.5537733275975499, 0.4061302957790238, 0.09247065056115389, 0.2539143721972193, 0.3867915320609297, 0.1091147753010903, 0.8703457404460225, 1.7796590413366045, 2.7000109127589633, 15.910256113324847, 70.68394088745117, 101.37908812931606, 96.92140184129987, 95.00030136108398, 101.29661996023995, 101.92333357674735, 99.18348516736711, 98.79846463884626, 94.84844848087856, 87.65874440329415, 98.30704634530204, 102.24603571210588, 94.6093053817749, 74.31455530439104, 72.71687957218715, 90.94789654867989, 90.87315477643693, 79.02407905033657, 80.94294915880475, 90.68581744602749, 91.21579129355294, 89.78737367902482, 94.96475437709263, 108.43180847167969, 91.83326380593437, 32.11686679295131, 79.71935749053955, 91.50516986846924, 86.37378624507359, 73.2532457624163, 95.32214191981724, 77.4928697858538, 60.72286442347935, 102.54663562774658, 97.11027472359794, 96.53679820469448, 103.3245073046003, 103.93958268846784, 107.1101290839059, 101.0060601915632, 97.28216620853969, 92.96172073909214, 87.88566562107631, 81.71872942788261, 82.43671458108085, 81.32006958552769, 81.28999083382743, 90.046875, 97.22257845742362, 108.67118086133684, 106.05339840480259, 92.76127215794155, 89.1390928540911, 87.94414166041783, 92.71723447527204, 114.7548498426165, 114.42819418225969, 40.346594606127056, 1.469633242913655, 0.23662017019731657, 0.03885053011721798, 0.17233379477901117, 0.05536501056381634, 0.1430084476513522, 0.9287125085081372, 15.560787779944283, 35.68821655000959, 42.265645367758616, 39.059183733803884, 42.9201865196228, 31.75613716670445, 34.29970938818795, 27.67204683167594, 23.57249501773289, 15.164618866784231, 38.68760102135794, 55.22181231634957, 66.83138016292027, 66.61890425000871, 73.65633160727364, 57.70518881934029, 2.434018237250192, 0.5586715904729707, 0.04748432843812874, 0.02486389795584338, 0.14032200537621975, 0.02259537048770913, 0.0763064536399075, 0.08274716910506998, 0.014758755818807652, 0.0531521823390254, 0.18184771069458552, 0.15357607416808605, 0.08691520616412163, 0.17217317196939672, 0.0981329506529229, 0.019658199345160807, 0.02222668339631387, 0.03998461319133639, 0.04738310119137168, 0.07139768025704793, 0.012984650525530534, 0.03204585525340267, 0.04346249192687018, 0.04838801833934017, 0.03835223774824824, 0.021896014622013484, 0.013791438840728785, 0.027865105840776647, 0.058039123857659955, 0.018433346945260252, 0.09721166294600282, 0.07170047650911979, 0.21954083309641906, 0.10618208588234015, 0.10298066945480448, 0.07753106007086379, 0.03151667257770896, 0.039089438904608996, 0.01116265677514353, 0.1283471379429102, 0.13136546526636395, 0.10916963485734803, 0.13851643726229668, 0.084788114231612, 0.04992121910410268, 0.040382526482322385, 0.11875912600329944, 0.0976023023415889, 0.02790149737016431, 0.056398650099124224, 0.07290330875132765, 0.13284691077257904, 0.0838215071707964, 0.04860125136162553, 0.042654373683035374, 0.06813942295100008, 0.06083514953830412, 0.06701217272451945, 0.0667234832154853, 0.0660455928051046, 0.08497367320316178, 0.09890520492834703, 0.051614910364151, 0.06320607302976505, 0.04844103567302227, 0.04525359028152057, 0.039669616879629235, 0.07629808051777737, 0.8158779431666646, 47.923389775412424, 131.221524647304, 103.05507700783866, 111.47466782161167, 94.2214777810233, 86.83329146248954, 32.70511170795986, 16.817155838012695, 24.427656718662806, 50.57461391176496, 41.81304318564278, 39.022139413016184, 38.11101518358503, 41.26946129117693, 26.278672456741333, 3.6134829819202423, 0.5903058158499854, 0.4313672387174198, 0.05943933515144246, 0.4277171545795032, 1.2353030741214752, 0.5753954702189991, 0.4919162839651108, 0.9007004116262708, 2.0247350335121155, 21.333648204803467, 79.06646306174142, 108.51128891536167, 100.34270872388566, 99.46752752576555, 106.18652588980538, 107.9349844796317, 101.34387465885708, 103.15875802721295, 101.85737432752336, 93.9449325289045, 103.85691302163261, 107.55976091112409, 101.8664903640747, 77.94314084734235, 78.43201610020229, 94.88078539712089, 95.32914570399693, 84.46854850224086, 86.59580898284912, 95.58328996385846, 94.87405259268624, 94.97342572893415, 97.91547366550991, 111.47102001735142, 96.52536146981376, 40.25258200509207, 84.1533990587507, 101.06636360713414, 94.67679323468889, 80.88305568695068, 105.96022306169782, 84.92287036350795, 65.47158990587506, 104.99806431361607, 99.67937810080392, 99.63400636400495, 103.34048816135952, 106.27014051164899, 109.79487133026123, 106.80498504638672, 101.96219485146659, 98.68163762773786, 91.86576053074428, 85.975036076137, 84.86059365953717, 83.63032477242606, 82.37252712249756, 92.18077101026262, 101.34225572858537, 111.37276554107666, 110.10611588614327, 98.72912161690849, 96.40061351231166, 92.83775792803083, 96.16762651715959, 119.6529963357108, 125.72014944893974, 54.930637632097515, 4.568292490073612, 0.15448293622050965, 0.018442064423912337, 0.20114779791661672, 0.03037366337542023, 0.2548125082893031, 1.1537185204880578, 20.934065989085607, 42.533481052943635, 45.24188191550118, 42.13972316469465, 45.62035376685006, 29.04802986553737, 24.560476745877946, 26.493832111358643, 30.22830125263759, 32.59364523206438, 51.103816509246826, 58.70193222590855, 80.66857174464634, 74.8011723927089, 86.90515668051583, 65.6790909085955, 3.067356526851654, 0.42704304360917633, 0.034172373823821545, 0.11696483514138631, 0.06887522632522242, 0.0791745058127812, 0.05799958562212331, 0.10434998026383774, 0.025005959440022707, 0.04149238924895014, 0.18049296124705247, 0.10280971255685602, 0.13550212686615332, 0.1542895265987941, 0.037303534735526354, 0.01919968269898423, 0.03429360428292837, 0.05248019179063184, 0.05119974532031587, 0.05161924281024507, 0.05520946319614138, 0.05331643531098962, 0.01364501437637955, 0.03750299010425806, 0.037964064827454944, 0.09963592607527971, 0.05095982551574707, 0.09240214566567115, 0.06671635859778949, 0.01678186734872205, 0.044395528467638154, 0.032872555178723166, 0.11343797974820648, 0.08167944675577538, 0.08778134254472596, 0.051829530990549495, 0.03625402765880738, 0.14049550678048814, 0.1473690393779959, 0.2582235038280487, 0.2840927056968212, 0.1784038469195366, 0.26268427446484566, 0.22383521337594303, 0.11917196027934551, 0.1278550914887871, 0.2570240710462843, 0.17060354405215808, 0.09274208492466382, 0.253769545682839, 0.21042113245597907, 0.19113962352275848, 0.2888727406305926, 0.32454232232911245, 0.17387488351336547, 0.11404606247586863, 0.20140683544533594, 0.11703499566231455, 0.27348514060888973, 0.32828582716839655, 0.2057603704077857, 0.2995830087789467, 0.1402248391615493, 0.18789801746606827, 0.17222668124096735, 0.23531765437551908, 0.08687757461198739, 0.18011820635625295, 1.443099592413221, 91.45714391980852, 138.981661932809, 112.36208479745048, 128.6463554927281, 96.62199701581682, 90.71531949724469, 36.14441442489624, 26.171329736709595, 82.0729069028582, 57.61617544719151, 57.00810732160296, 53.53519269398281, 55.9313554082598, 51.47960983003889, 31.794293199266704, 4.622518837451935, 0.8111580535769463, 0.6279094123414585, 0.23415643668600492, 0.37882688801203457, 0.42824806751949446, 0.4042898916772434, 2.9952172892434255, 5.101448612553733, 10.687649590628487, 22.97476407459804, 79.6182473046439, 113.05709225790841, 107.99505165645054, 102.56814725058419, 108.61940288543701, 113.250474521092, 107.4955804007394, 110.00298377445766, 107.31185613359723, 99.3055441720145, 110.84246512821743, 113.79601928165981, 106.97563280378068, 84.55050250462124, 83.12050070081438, 100.48504952022007, 99.73087814876011, 91.39836910792759, 91.58585929870605, 99.261047908238, 98.6206602369036, 98.6274277823312, 103.93243299211774, 115.45135811397007, 94.18730654035295, 45.067475182669504, 92.37573051452637, 113.52043288094657, 102.22993673597063, 83.55052471160889, 112.22358635493687, 92.9996440070016, 74.56562151227678, 107.65618106297084, 103.494599206107, 102.2836046218872, 104.15686675480434, 108.93291255405971, 112.7960901260376, 111.54928452627999, 107.80214881896973, 102.51828697749546, 95.73734542301723, 89.59604808262416, 87.14190265110561, 84.90926579066685, 86.19929613385881, 97.27926880972726, 105.89354119982038, 118.47342845371791, 112.48242064884731, 99.91934108734131, 97.99680233001709, 97.11261626652309, 102.72047955649239, 130.64296204703194, 129.9521999359131, 49.82233592442104, 4.125059519495283, 0.21279367086078438, 0.19366807570414885, 0.4647889424647604, 0.20042365177401475, 0.3393268132848399, 1.584492285336767, 29.022554295403616, 61.2524630682809, 64.44424315861293, 53.28689186913626, 62.98198086874825, 40.83164487566267, 47.87843145642962, 37.602386202131, 34.06959547315325, 24.912877219063894, 50.615413733891074, 72.23473712376186, 87.0861155646188, 85.03061607905796, 89.21649578639439, 87.14993476867676, 8.370779718671526, 0.8971037960478238, 0.1452381680054324, 0.12823978013225965, 0.19020133172827108, 0.18986403197050095, 0.15901857641126427, 0.2291947172156402, 0.06404162105172873, 0.21552675563309873, 0.3875791755105768, 0.3299813504729952, 0.2585323729685375, 0.3508281446993351, 0.231569019811494, 0.18802180939487048, 0.10624198016843625, 0.12123191117175988, 0.10198610675122056, 0.19569590474878037, 0.2505739171590124, 0.1900845015687602, 0.11943781029965196, 0.0741398845400129, 0.17947057182235376, 0.21183100608842714, 0.15268857750509465, 0.1585994181888444, 0.18156725860067777, 0.1095115282971944, 0.3072118322764124, 0.1588138352547373, 0.3081123296703611, 0.24062803227986607, 0.20044004518006528, 0.1695136268224035, 0.13455270709736006], [0.031310431858790774, 0.07277552025126559, 0.13996968285313674, 0.07271164296461002, 0.11958798366997923, 0.05806557993803706, 0.09644312025713069, 0.03811592096462846, 0.032317869764353545, 0.004147281945084355, 0.057422613725066185, 0.03165095805057457, 0.08589274210057088, 0.026683272561058402, 0.17176424605505808, 0.1046127158084086, 0.06132613747779812, 0.04213869724688785, 0.044244876730122736, 0.07083116458462817, 0.059221138645495684, 0.0891511147575719, 0.04635416729641812, 0.08601282922817127, 0.060656871247504435, 0.047267309190439324, 0.0569853861150997, 0.04676634000082101, 0.03942365472071937, 0.01300240439429347, 0.631242647767067, 42.03050790514265, 105.06803267342704, 95.47516904558454, 96.48954350607735, 67.00233364105225, 43.56323535101754, 13.488320793424334, 48.98926428386143, 81.33671746935163, 52.819333689553396, 36.32268435614449, 36.77281992776053, 27.921419416155132, 29.548187255859375, 7.07430796112333, 0.19727501858557972, 0.7292999146240098, 0.0325512383133173, 0.16285129503480025, 0.20403381091143402, 0.20039087853261403, 1.7129091088260924, 7.90396933896201, 5.659837552479335, 9.891500677381243, 44.76059756960188, 94.12460599626813, 98.72580732618059, 96.60543251037598, 101.37978989737374, 105.11235523223877, 102.72936630249023, 94.98581436702183, 93.32613985879081, 96.3917545591082, 100.10651860918317, 83.81254128047398, 89.12620394570487, 93.65232304164341, 94.08545289720807, 71.4396061216082, 68.78271225520542, 66.18544088091168, 67.0458015714373, 73.60551248277936, 91.95853287833077, 92.20381123679024, 100.93718269893101, 97.1858572278704, 105.06767831529889, 87.01236043657575, 114.81919710976737, 63.27766840798514, 55.099002906254356, 86.7384763445173, 70.12770284925188, 73.96645055498395, 90.18398380279541, 53.81445121765137, 57.51504789079939, 108.1143661226545, 94.44689123971122, 106.55222347804478, 98.41295078822544, 91.99772071838379, 89.75776740482875, 97.0326702935355, 92.29678508213588, 95.66591794150216, 87.12166254861015, 84.75083296639579, 79.16289710998535, 80.18514387948173, 77.22253622327531, 81.4489517211914, 81.6364141191755, 87.28850964137486, 90.02300793784005, 94.00321401868547, 83.3587474822998, 90.9522044318063, 91.87753772735596, 89.57999079568046, 94.82698549543107, 116.15692683628627, 79.69466359274728, 12.668511526925222, 0.05868057693753924, 0.013923344352016491, 0.08279022215200321, 0.0958084457420877, 0.18239717478198664, 0.4042629131249019, 8.266049521309988, 25.663138491766794, 33.48079122815813, 48.103184836251394, 72.15955761500767, 69.61440467834473, 71.94357286180768, 33.85932213919503, 22.642641918999807, 17.784947838102067, 34.84961066927229, 35.02091155733381, 52.85324089867728, 70.83837849753243, 76.04005009787423, 68.3689956665039, 12.001728517668587, 0.7288744460259164, 0.07889048462467534, 0.05515666638634034, 0.11841034543301378, 0.0856504033186606, 0.08504512972597565, 0.0014761639592636908, 0.03209986664088709, 0.11157184559851885, 0.04509240768051573, 0.1362927287284817, 0.13938942684658936, 0.0880478982414518, 0.07704322731920651, 0.09238940277802092, 0.055491726978548934, 0.03185821996469583, 0.0724664679063218, 0.10896640683391265, 0.08025568351149559, 0.02982691003541861, 0.10219394881278276, 0.01670304193560566, 0.0885670996670212, 0.018400714499875903, 0.01993110782599875, 0.02667540155484208, 0.013618875511123665, 0.02385984254734857, 0.08701742746468101, 0.08835750019976071, 0.21420804996575626, 0.10747791813420397, 0.0601762445377452, 0.024229698415313448, 0.04205630952492356, 0.10037548174815518, 0.12202966479318482, 0.046543817834130356, 0.10165992818240609, 0.04518532965864454, 0.046256916264870336, 0.06975852285644837, 0.049080805986055305, 0.08767226804047823, 0.056489122565835714, 0.004351171964247311, 0.1293028545166765, 0.07139683208827462, 0.09368197806179523, 0.11260601439114128, 0.059782802792532105, 0.0373918223194778, 0.0222189124740128, 0.10063061770051718, 0.09848126981939588, 0.06650363108409302, 0.0783459534868598, 0.045395522844046354, 0.05075783581872072, 0.0442229057662189, 0.04793325059914163, 0.03268924215808511, 0.019738900907603756, 0.02707028009795717, 0.8420185319014958, 46.16266066687447, 119.6665175301688, 107.85626138959611, 109.93729550497872, 85.71991212027413, 72.20249053410122, 42.483822277614046, 37.439315455300466, 22.16061064175197, 49.40710462842669, 39.922327177865164, 41.20232432229178, 36.26230798448835, 38.62087747028896, 11.02073928288051, 0.2574739397636482, 0.7672121631247657, 0.07390259405864136, 0.08695903952632632, 0.4611133454101426, 0.6529316125171525, 2.505441810403551, 2.416802989585059, 0.8340352145688874, 10.262120195797511, 49.845879895346506, 97.54036821637834, 103.5228853225708, 97.32372338431222, 104.71909414018903, 108.27006135668073, 105.62470149993896, 97.55123519897461, 100.7206004006522, 100.00279590061733, 104.3553420475551, 89.10462284088135, 93.81428555079869, 98.78698621477399, 97.79078129359654, 77.03586591993059, 74.09601361410958, 70.12792519160679, 71.95304325648716, 80.86073112487793, 98.56989669799805, 96.69798946380615, 107.20655618395124, 100.05901377541679, 110.72895240783691, 92.78286715916225, 117.12779862540108, 67.0506375176566, 60.59102235521589, 96.11887795584542, 75.51440497807094, 80.28414181300572, 98.95992687770298, 61.28056853158133, 63.664182799203054, 114.98921258108956, 97.19633511134556, 112.04457991463798, 99.39530100141252, 97.21012033735002, 90.62359632764543, 98.70717920575822, 95.23243372780937, 98.21659469604492, 88.28819561004639, 89.25686482020787, 82.11119842529297, 84.68551989964077, 81.83044951302665, 84.51006398882184, 82.40703187670026, 89.39549527849469, 90.95970153808594, 96.15207644871303, 86.54442705426897, 94.62712751116071, 96.62994575500488, 94.32428332737514, 97.90983172825405, 124.66855348859514, 96.71014186314174, 20.944995505469187, 0.053504141845873425, 0.08040358378951039, 0.10309440549463034, 0.08371701956327472, 0.140447290082063, 0.4532531143299171, 10.009028588022504, 33.51881871904646, 39.90157985687256, 49.85362366267613, 58.70186274392264, 45.031664167131694, 35.71925067901611, 33.552962166922434, 29.862794739859446, 28.17279134477888, 57.33996023450579, 47.21102224077497, 63.05361679622105, 77.77281270708356, 87.85576057434082, 81.1792573928833, 13.684608272143773, 0.4471939323203904, 0.015696336847863028, 0.12326469352202755, 0.18004033767751285, 0.08757185164306845, 0.04918901875082936, 0.09141610536192145, 0.027837499643542936, 0.12818865930395468, 0.11061684148652212, 0.250992193285908, 0.06216281186789274, 0.1512732348803963, 0.017213042426322187, 0.08233641114618097, 0.062388302625289986, 0.05010905795331512, 0.05363613047770091, 0.11451723719281809, 0.05847928952425718, 0.061794611625373363, 0.020210430159100463, 0.04168057754369719, 0.048316748413656435, 0.030864895587520938, 0.03588650934398174, 0.07363359563584838, 0.02842011525561767, 0.03323829912447503, 0.055628444999456406, 0.12312677449413709, 0.2575215186391558, 0.09373259677418641, 0.12279156462422439, 0.041251678951084614, 0.11432392256600515, 0.14228845414306435, 0.18815330948148454, 0.16423609001295908, 0.2100450069244419, 0.13189826453370707, 0.22698335801916464, 0.15121838210948876, 0.1306774578988552, 0.16100474340575083, 0.13926748053303786, 0.11372128847454276, 0.19402535153286798, 0.23991049506834575, 0.22793535622102873, 0.14483811732913765, 0.16947690450719424, 0.14194341908608163, 0.06988454038011176, 0.21429665306849138, 0.26004599460533684, 0.21555686901722634, 0.08784768291349922, 0.22696415547813686, 0.23852810210415296, 0.19359598814376763, 0.15539655648171902, 0.1406075871948685, 0.0718041363039187, 0.09185691563678638, 1.1721879179988588, 89.13119275229317, 135.3812026977539, 116.29658562796456, 121.63198225838798, 87.60411766597203, 63.29215540204729, 27.14522225516183, 74.88430064065116, 115.3272146497454, 75.92707933698381, 60.19714982169015, 59.08421516418457, 50.238338470458984, 48.62632165636335, 14.488144857542855, 0.861151428094932, 1.1084317905562264, 0.14306887798011303, 0.298059697662081, 0.3886050933173725, 0.295422937721014, 5.295689846788134, 16.39610368864877, 12.293002213750567, 17.478820630482264, 51.46469552176339, 102.06233228955949, 103.77170031411308, 99.61722646440778, 107.09049347468785, 112.95885167803083, 108.07549095153809, 97.92403384617397, 102.82252774919782, 106.45610904693604, 109.92403834206718, 94.31365953172956, 102.04936000279018, 105.17737647465297, 104.10121168409074, 81.48149013519287, 78.91745894295829, 77.6070008959089, 76.5438153403146, 86.59031990596226, 106.52129009791783, 102.89708192007882, 112.39284447261265, 103.51160839625767, 113.95593207223075, 94.90493038722447, 120.42203685215541, 69.79878902435303, 73.98423794337681, 107.26542132241386, 87.81737177712577, 92.17314883640834, 109.71013110024589, 69.98963519505092, 68.21734428405762, 117.1332460130964, 99.93592643737793, 116.59542764936174, 103.55943979535783, 98.03451020377022, 92.65317208426339, 102.08113411494664, 100.81840324401855, 100.5195403780256, 93.61005020141602, 93.91740376608712, 87.35282911573137, 90.13251154763358, 86.68072291782924, 90.36735371180943, 84.99363776615688, 94.13460445404053, 97.96107469286237, 104.73941762106759, 92.95117337363106, 99.1240085874285, 100.62376335689, 97.91734273093087, 104.69624151502336, 133.7335763658796, 94.24982643127441, 17.44816517829895, 0.14983896112867764, 0.18974147497543267, 0.1890818439424038, 0.17844143775956972, 0.21378024720719882, 0.6902374135596412, 14.473930580275399, 45.11779751096453, 55.165604863848, 75.58670098440987, 106.48758438655308, 100.77403899601528, 99.31960732596261, 49.79532480239868, 32.217188358306885, 29.971648693084717, 48.88825832094465, 50.86327682222639, 71.10219464983258, 90.92320959908622, 91.87728759220668, 102.84357384272984, 25.8508996622903, 1.174184873700142, 0.22766178447221005, 0.22132865073425428, 0.3868178320782525, 0.2274021634033748, 0.1970861822898899, 0.1596977221114295, 0.12144585326313972, 0.20785907922046526, 0.2222400318299021, 0.3598314901547772, 0.17846350371837616, 0.21228956005402974, 0.1310517242444413, 0.12207421740250927, 0.14991726406982966, 0.09527508329067912, 0.26936887577176094, 0.31702282439385143, 0.18826129154435225, 0.15077965493713105, 0.12935876580221312, 0.14068190035011086, 0.0948702557278531, 0.1252433830606086, 0.192667548677751, 0.15620710727359566, 0.098983141460589, 0.11033167357423476, 0.10770726297050714, 0.22508466775928224, 0.4047362320125103, 0.24198803358844348, 0.28161993409906116, 0.13988724084837095], [0.015512791428981083, 0.02965826015653355, 0.021110430526147996, 0.09557991514780692, 0.06905387102493218, 0.02867879146443946, 0.06788716398711715, 0.014615471275257213, 0.08268979896924325, 0.0744543583797557, 0.024964478897995183, 0.0312990697899035, 0.04657510169116514, 0.11006466325904642, 0.08466405767415251, 0.09864314791879483, 0.020134870195761323, 0.024715887415888052, 0.02217030561795192, 0.046024718188813755, 0.028869439448629106, 0.05699509595121656, 0.14761266059109143, 0.05778691239122834, 0.042560145524995666, 0.042544790277523656, 0.04814368127179997, 0.10637420628752027, 0.062265901693276, 0.21377836087984697, 59.510438510349815, 101.32473237173897, 98.58273002079555, 77.81391130174909, 59.997389112200054, 48.73723227637154, 25.240628957748413, 21.285893235887798, 42.77397905077253, 49.503417083195274, 36.382772377559114, 35.317453724997385, 29.1653345652989, 21.310427325112478, 3.184428244829178, 0.6400068774819374, 0.09517223095255238, 0.14378280538533414, 0.1670544666371175, 0.0975650507690651, 0.19751501642167568, 1.8101204867873872, 8.069048983710152, 0.4712841510772705, 26.672718695231847, 78.04996940067836, 91.58339268820626, 87.29242842538017, 97.91252068110875, 101.66217858450753, 101.51126371111188, 94.75562054770333, 99.79068129403251, 97.42851611546108, 96.21782030378068, 90.0856112071446, 95.66889871869768, 91.5351791381836, 86.20508398328508, 88.07410076686314, 90.23966666630336, 69.36768109457833, 70.88238143920898, 67.3802739552089, 83.80099337441581, 95.2372488294329, 95.40777151925224, 91.31829806736538, 100.93645313807896, 92.60056727273124, 96.30741732461112, 95.43836443764823, 98.04810088021415, 87.1920200075422, 34.56580454962594, 85.46927670070103, 76.48976530347551, 86.27587223052979, 86.29538972037179, 44.409553732190815, 87.03267002105713, 99.34637178693498, 90.86547701699394, 96.6533750806536, 96.61704295022147, 100.37244701385498, 90.38971301487514, 88.85650961739677, 97.61770166669572, 96.43995421273368, 89.02754647391183, 83.7551908493042, 81.45884595598493, 78.28262288229806, 77.58702482495988, 78.46186556134904, 77.55087334769112, 74.43538447788784, 71.87256922040666, 71.74349253518241, 72.13077122824532, 70.70978818620954, 74.22128963470459, 82.61563069479806, 94.48968519483293, 87.36498846326555, 100.93802343096051, 104.11410754067558, 33.66226427895682, 0.2355053371616772, 0.02002054043779416, 0.18054184290979589, 0.07119996193796396, 0.07374296191015414, 0.06043026090732642, 4.086141790662493, 21.404104675565446, 28.463146141597203, 28.1807313987187, 47.45391389301845, 57.8792724609375, 62.133855955941335, 37.33541209357125, 19.2374426977975, 11.75026626246316, 23.80926009586879, 40.544038091387065, 58.12957436697823, 74.10877745492118, 75.11541857038225, 90.9289140701294, 20.243861470903667, 0.8175294974020549, 0.3433103295309203, 0.11420995582427297, 0.02762754394539765, 0.08565820647137505, 0.09957711744521346, 0.047405228218329806, 0.17804826742836408, 0.10911118585084166, 0.03779727074184588, 0.0628697910745229, 0.0636099370728646, 0.07967899659914629, 0.06653117960585014, 0.056479283808065314, 0.009117989035855447, 0.048794542239712815, 0.06679614753063236, 0.08997666795871087, 0.07480919826775789, 0.02271383422027741, 0.02010245148890785, 0.0504176183603704, 0.028926762087004523, 0.06566795414047581, 0.023836348272327865, 0.015208091886181916, 0.025480409784774696, 0.04595573492614286, 0.23035213510904992, 0.1606288757175207, 0.0764792493677565, 0.07639260723122529, 0.006411563056255025, 0.022966122021898627, 0.09155385475605726, 0.1027323527793799, 0.02981107302808336, 0.07175093915845666, 0.05315898804526244, 0.07322745171508618, 0.06569670366921596, 0.026814073756603257, 0.04107081204918878, 0.025684791317741786, 0.03086934338456818, 0.13374750316143036, 0.08145053618188415, 0.10300409248364822, 0.09373674262315035, 0.05275586360533323, 0.021936346743521944, 0.016930490266531706, 0.08912849240005016, 0.006588793434535286, 0.07451140281877347, 0.029913915188184807, 0.029213290462004285, 0.058571088526930125, 0.06956358653094087, 0.07329978354807411, 0.08698579416211162, 0.04561917477154306, 0.2615857262696539, 66.35577596936906, 117.64646775381905, 109.37952886308942, 96.26199000222343, 76.44667952401298, 67.01740428379604, 41.293498584202354, 32.873070512499126, 46.96890878677368, 63.48300852094378, 43.143227168491904, 43.34580189841134, 37.27305201121739, 30.097220012119838, 4.823511115142277, 0.2942413639809404, 0.21016023574130877, 0.10709272737481765, 0.17723083629139832, 0.3530517853796482, 0.667186547602926, 0.5832967662385532, 1.4371258786746433, 3.042834162712097, 30.683404786246165, 84.54120581490653, 96.26540156773159, 91.28232029506138, 100.44226251329694, 104.8973501750401, 103.24704183850969, 98.83729812077114, 100.66989939553397, 99.50111511775425, 97.75296919686454, 94.47537885393415, 100.71634115491594, 97.74856403895787, 91.07693154471261, 91.36374623434884, 94.34596865517753, 74.54556901114327, 74.3789164679391, 73.29465702601841, 87.95695413861955, 101.15061746324811, 99.23297718593052, 95.17873804909843, 100.95088454655239, 95.79985836574009, 98.88431658063615, 99.25722639901298, 101.50269658224923, 89.93400151388985, 42.607983112335205, 94.76854419708252, 84.28679057529995, 93.484774180821, 93.47565119607108, 51.043429715292795, 90.79050595419747, 102.92585441044399, 91.76094695499965, 99.19531100136894, 98.11950056893485, 104.33453219277519, 90.13716684068952, 90.73935331617082, 101.14243248530796, 100.48082501547677, 91.9372922352382, 87.96009472438267, 85.04381765638078, 82.66164861406598, 79.94721671513149, 82.3044764654977, 79.31331171308244, 77.12776279449463, 72.79570688520158, 73.7043992451259, 73.97515664781842, 73.79682418278286, 75.9082636151995, 87.53469126565116, 100.5011693409511, 91.99344757625035, 105.05349704197475, 115.92618410927909, 47.52226332255772, 1.8435436018875666, 0.02225873739059482, 0.13951946129756315, 0.07251488137990236, 0.09355725654001747, 0.11156551486679486, 4.576300288949694, 25.775379691805156, 35.10373408453805, 33.33258267811367, 42.70421566282, 49.34910454068865, 29.573065280914307, 20.70145419665745, 26.45471027919224, 20.056824650083268, 37.46110848018101, 49.72400849206107, 68.45937783377511, 79.50694411141532, 86.34029592786516, 103.95525782448905, 26.473152535302297, 0.6239588186144829, 0.25266955899340765, 0.1352101532476289, 0.10515886185956852, 0.04414562062759485, 0.025076109782925675, 0.11107324449611561, 0.1418086348899773, 0.0720145364425012, 0.012518811638333967, 0.0062822461560634625, 0.049397417211106846, 0.08005844695227486, 0.018990861850657632, 0.05411553582442658, 0.020063975160675387, 0.06187018685575042, 0.01602336358545082, 0.02721965279696243, 0.05554000135245068, 0.09452670666256122, 0.061197093687951565, 0.03640894738159009, 0.020119404686348777, 0.09362806845456362, 0.03171410930476018, 0.06000658364168235, 0.02673499219651733, 0.0899618419685534, 0.16748163157275744, 0.16945384788726056, 0.09203602174030882, 0.0538598400806742, 0.0412368767096528, 0.10959533415734768, 0.13776623537497862, 0.2296172274010522, 0.13792680390179157, 0.2373879732830184, 0.10763031709939241, 0.1498848708080394, 0.14249172966395104, 0.15500680596700736, 0.09422051095004592, 0.11373272857495717, 0.08072850028319017, 0.23606583422848157, 0.18947751128247806, 0.2669658847153187, 0.1902922825621707, 0.15182326893721307, 0.09359590589467968, 0.17498932299869402, 0.1277969546083893, 0.12079143337905407, 0.17273844592273235, 0.2747490885002272, 0.32632849791220253, 0.2814264973359448, 0.14669663831591606, 0.12479565851390362, 0.30176026480538504, 0.12847757951489516, 1.0821475152458464, 112.31532342093331, 129.61626843043734, 121.09950011117118, 106.5605057307652, 78.92700576782227, 68.61485767364502, 36.39186062131609, 36.502767767224995, 69.92081328800747, 76.79831395830426, 56.27747297286987, 55.81566095352173, 48.23216424669538, 38.72292218889509, 6.455316398824964, 0.7290501594543457, 0.40868126175233294, 0.3855310311274869, 0.3559930446956839, 0.3120281281215804, 0.946496205670493, 6.13447116953986, 23.55474237033299, 4.688977488449641, 27.99675178527832, 84.6456024987357, 98.20249680110386, 93.9854405266898, 103.04101385389055, 110.56345326559884, 109.17025606972831, 101.35144124712262, 107.12912545885358, 104.05309540884835, 102.38307503291539, 96.75184495108468, 105.75198554992676, 102.53488622392926, 96.50430147988456, 98.60231004442487, 101.16021292550224, 78.00603594098772, 79.17370155879429, 76.08420589991978, 92.17712320600236, 106.6726496560233, 104.52234894888741, 98.49846226828438, 106.65763459886823, 99.56744956970215, 103.58551638466972, 100.57737023489815, 105.88546739305768, 92.84584563119071, 49.26199497495379, 104.73884092058454, 93.63983018057687, 102.09979002816337, 104.49973951067243, 60.19354370662144, 92.14509201049805, 108.21355860573905, 93.63360459463937, 104.08259746006557, 101.31920855385917, 110.57538332257951, 90.46341950552804, 93.159515108381, 106.5648969922747, 106.9483402797154, 97.13759504045758, 91.240964617048, 90.6000280380249, 85.56486306871686, 83.41295037950788, 86.08219119480678, 82.83599281311035, 82.26001494271415, 76.91300787244523, 77.37755748203823, 76.81530230385917, 77.20328971317836, 82.40297412872314, 94.27502754756382, 104.10808345249721, 96.38210351126534, 115.02075045449394, 119.02293368748256, 43.93382099696568, 1.6530018491404397, 0.1035594530403614, 0.19456982160253183, 0.14144510296838625, 0.2252396722989423, 0.18146106787025928, 7.598283341952732, 35.12063210351126, 46.538610322134836, 41.14756209509713, 68.78369889940534, 82.14997632162911, 87.97173295702252, 52.51645476477486, 29.250658443995885, 19.482757534299576, 36.21749210357666, 56.415808132716585, 76.58801977975028, 92.71560859680176, 90.68630381992885, 117.54253659929547, 47.1917062486921, 1.4014944306441715, 0.5538282617926598, 0.29457246192864006, 0.13387702192578996, 0.16753598222775118, 0.2403927706182003, 0.15921778072203907, 0.2566569564597947, 0.28251576317208155, 0.19340826464550837, 0.09448046450104032, 0.20742360901619705, 0.2504387529832976, 0.11316239275038242, 0.13960792869329453, 0.1303619255444833, 0.15811293572187424, 0.23608868728790963, 0.2559132549379553, 0.09165678173303604, 0.14464537267174038, 0.17740618331091745, 0.19022398122719356, 0.12111771372812134, 0.19532558747700282, 0.12704002165368625, 0.09483248168336493, 0.1355011769171272, 0.2511017902621201, 0.39865707393203464, 0.1863090648714985, 0.12846738791891507, 0.21338116005063057, 0.09364008530974388], [0.014878037186073405, 0.06137089364762817, 0.07465261952685458, 0.03737865195476583, 0.052576994989067316, 0.09020225371101073, 0.006165268839270408, 0.04818256472104362, 0.03648060067955937, 0.04857503955385514, 0.036091793328523636, 0.011731553257309964, 0.07630582260234015, 0.10493860260716506, 0.032963054786835394, 0.06307641177305154, 0.03776017862505146, 0.11875657471162931, 0.01545204727777413, 0.023195124198017374, 0.012249233068100043, 0.018816907524264286, 0.035620957879083495, 0.07984628940799407, 0.03270099099193301, 0.061636723311884065, 0.028141817510394112, 0.02226794171812279, 1.0143301657267978, 69.88369601113456, 99.98202773502895, 94.3941822052002, 87.51563235691616, 73.0387965611049, 38.412219592503135, 32.8534175327846, 39.10649749210903, 70.68977042606899, 61.15513965061733, 31.886728559221538, 35.00704295294625, 24.66137327466692, 14.943508080073766, 0.0998523516048278, 0.09896292111703328, 0.03756522533616849, 0.016289028704964688, 0.20506388135254383, 0.054898656838174374, 0.27019742131233215, 2.129978094782148, 4.96605167218617, 30.57179239818028, 94.47168241228376, 113.97686004638672, 97.21843038286481, 92.8061158316476, 90.90418543134416, 95.52685669490269, 97.3882165636335, 98.93105711255754, 100.26470824650356, 91.88947473253522, 89.10697828020368, 88.64442975180489, 96.0330399104527, 94.82322651999337, 92.20220620291573, 81.56338160378593, 81.94750581468854, 75.31224019186837, 68.07976300375802, 66.27115385872978, 76.76082147870744, 87.90118094852993, 92.61078112465995, 89.46713120596749, 93.64527062007359, 89.53973293304443, 91.79512514386857, 87.06918280465263, 88.45398657662528, 88.33184419359479, 106.17973055158342, 64.9589170728411, 46.704220635550364, 71.16948795318604, 73.21915790012905, 60.96348054068429, 39.528614452907014, 97.86487688337053, 88.88770702907017, 99.60327448163713, 83.29055091312954, 90.09419223240444, 86.04221820831299, 96.27106434958321, 80.93391650063651, 92.73849596296037, 91.74295112064907, 88.64908504486084, 79.81638213566372, 80.489759853908, 79.35518155779157, 79.6210891178676, 73.59324891226632, 75.05524022238595, 69.05952153887067, 75.0870143345424, 81.37837191990444, 84.23452622549874, 82.21549783434186, 79.52164649963379, 69.80671691894531, 72.97476196289062, 86.24937874930245, 85.24167455945695, 87.84269796098981, 98.28573622022355, 43.020997932979036, 0.9026839594755853, 0.05752132021422897, 0.04098135059965508, 0.05927055635090385, 0.08016674792660133, 0.13557312877050468, 1.3260184292282378, 12.96837145941598, 29.930647373199463, 27.747377463749476, 40.81990589414324, 79.30674566541398, 80.05638681139264, 37.63075222287859, 37.29122849873134, 19.665719236646378, 30.81814772742135, 45.72214140210833, 50.30783782686506, 73.85945524488176, 80.68303094591413, 96.80775015694755, 50.28114979607718, 3.2141860766070227, 0.48451080705438343, 0.04510011923100267, 0.060596542698996406, 0.04376533228371825, 0.025522319500201514, 0.032470302656292915, 0.08911013802779572, 0.0929375369367855, 0.12530891597270966, 0.044596520718187094, 0.0701230861512678, 0.028439896247748817, 0.05620836852384465, 0.026716661572988545, 0.014801810562078441, 0.03576021362096071, 0.021053204579012733, 0.07422367682946579, 0.013689248922414013, 0.012964082432777753, 0.06689744602356638, 0.07758694421499968, 0.04381601545693619, 0.12729169029210294, 0.042162819166800806, 0.05581455358437129, 0.03340808894219143, 0.09076133263962609, 0.1764545515179634, 0.06028780248016119, 0.0072501441297520485, 0.0305872424505651, 0.0279271816169577, 0.056139310622321706, 0.025795887856345092, 0.04571998132658856, 0.03223426067935569, 0.0560544224988137, 0.026505033286022286, 0.04668690051351275, 0.06860128816749368, 0.05444469316197293, 0.046297937099422724, 0.04041477046640856, 0.033379841529365094, 0.0602586797571608, 0.05702607786016805, 0.034280260891786644, 0.04266405637775149, 0.06504653819969722, 0.021529240999370813, 0.029223577052886997, 0.09582209108131272, 0.09348266518541745, 0.015803012730819837, 0.09274568794561283, 0.09464243759534188, 0.13006605713495187, 0.05108484898560813, 0.08604408933648042, 0.8089775134410176, 81.91329288482666, 117.6844049181257, 109.03398105076381, 103.89086886814663, 82.90173666817802, 60.10121604374477, 55.56203433445522, 35.50875847680228, 35.14659752164568, 57.40272331237793, 38.24194703783308, 42.634890011378694, 34.203938892909456, 19.66448245729719, 0.4905446118542126, 0.20933329154338154, 0.03047742155779685, 0.09904441995812313, 0.20162545942834445, 0.16068471914955548, 0.26030294224619865, 0.608854629099369, 7.370445830481393, 39.76559666224888, 104.4745592389788, 120.83099392482212, 99.07209164755685, 95.97926085335868, 94.82473427908761, 99.14165006365094, 99.28206620897565, 101.79096344539097, 102.91504996163505, 95.36440086364746, 93.17212608882359, 94.84054143088204, 99.63329069955009, 98.89403711046491, 98.2979303087507, 86.2268318448748, 84.17478561401367, 78.63185323987688, 71.93477644239152, 70.181718145098, 82.96146338326591, 94.90456213269914, 97.36410631452287, 93.68080370766776, 96.34320054735456, 94.11999934060233, 95.73374625614711, 91.39527715955461, 92.52163573673793, 91.69680118560791, 110.74648966108049, 71.07700742994035, 53.78787783214024, 79.41115624564034, 81.15667574746269, 68.4761438369751, 47.04786811556135, 102.61025333404541, 92.8435388292585, 105.34653036934989, 86.02354839869908, 93.4754080091204, 90.0130581174578, 99.65212031773159, 82.40504469190324, 91.70099789755685, 93.14242253984723, 91.06022807529995, 83.65488665444511, 84.61332811628068, 82.96329075949532, 84.46634592328752, 77.83520753043038, 76.270035471235, 70.44591644832066, 79.36155305589948, 87.22641359056745, 90.84904452732631, 87.42231804983956, 82.73552186148507, 73.15449101584298, 74.50575583321708, 90.33548927307129, 90.97319493974958, 89.37329578399658, 104.53894819532121, 55.106590339115684, 2.2906423764569417, 0.10690532957336732, 0.11094981897622347, 0.059857278796178956, 0.08286515955946275, 0.16342826693185739, 1.5700732533420836, 15.76139269556318, 36.408275740487234, 31.463517257145472, 35.535245009831016, 67.30934674399239, 50.80315753391811, 11.537165880203247, 30.087409155709402, 32.48200852530343, 44.90775694165911, 53.54947471618652, 60.32029969351632, 83.63869040352958, 88.55936990465436, 109.3353522164481, 60.98766721997942, 4.153660476207733, 0.3654243286166872, 0.07821991560714585, 0.08980238623917103, 0.022359644029555575, 0.04526246551956449, 0.08628282509744167, 0.04817352324192013, 0.04993296454527548, 0.07599297046129193, 0.04858983840261187, 0.05356887408665248, 0.0534126312205834, 0.030646363206739937, 0.03321403131953307, 0.0006241541476421324, 0.01196785138121673, 0.11592892929911613, 0.03379569189356906, 0.033491609817636867, 0.013681348230290626, 0.06328495272568294, 0.0898605366902692, 0.039358003064990044, 0.03178382877792631, 0.05607761821842619, 0.05356979350160275, 0.016631449705788066, 0.1438168135604688, 0.1929891335644892, 0.1322846088026251, 0.01748183898494712, 0.03193148478333439, 0.09175162057259253, 0.1383519060909748, 0.17482585034200124, 0.17461705154606275, 0.11523094746683325, 0.15852875555200235, 0.11177687173975365, 0.17532624277685369, 0.1607538890093565, 0.22139266372791358, 0.09129886129604918, 0.1731503438204527, 0.11917456585381712, 0.21346079292041914, 0.10566421438540731, 0.17291641208742345, 0.1583081909588405, 0.25002430379390717, 0.14196528148438248, 0.07047527296734707, 0.12456805072724819, 0.16318528354167938, 0.16668366082012653, 0.1373574315969433, 0.20733370312622615, 0.17180843225547246, 0.18463710030274733, 0.2141799721866846, 3.702268583433969, 124.47179440089634, 129.46185166495187, 123.1950351170131, 114.99383313315255, 93.19363076346261, 57.47429323196411, 47.76350825173514, 52.59119653701782, 109.7606167112078, 85.24937316349575, 50.65568549292428, 57.98133455004011, 45.82659019742693, 25.728060722351074, 0.9053856687886375, 0.4661770079817091, 0.153294156438538, 0.24834435965333665, 0.24252551474741527, 0.24137089241828236, 0.7311308192355293, 5.226668179035187, 9.536953210830688, 36.62415279660906, 107.50663498469761, 126.81232288905552, 100.63576289585659, 99.18591703687395, 97.51226970127651, 104.28935500553676, 100.31007998330253, 105.24780341557094, 106.40028721945626, 101.1471781049456, 96.3205007825579, 100.67486040932792, 104.25045204162598, 102.50958088466099, 104.39729527064732, 91.6951961517334, 90.40506853376115, 85.29724625178746, 74.98809977940151, 75.87272357940674, 85.88723169054303, 100.6776396887643, 103.34217657361711, 96.98711095537458, 101.7628927230835, 100.8957714353289, 100.51652485983712, 93.9126511982509, 97.97150393894741, 96.39859158652169, 116.48642430986676, 74.82768671853202, 60.23876953125, 88.32424981253487, 93.71962329319545, 79.53572354997907, 49.85969638824463, 105.13211590903146, 98.30112648010254, 109.17113154275077, 89.53174945286342, 97.01710632869175, 93.85672514779228, 106.94689505440849, 81.8983403614589, 97.25397041865757, 95.27253873007638, 96.03026757921491, 88.20927102225167, 90.20154884883335, 88.37700053623745, 89.69043936048234, 81.61613927568708, 79.42163412911552, 72.80495493752616, 81.63824149540493, 91.24377863747733, 94.97665664127895, 90.28371824537004, 86.79028211321149, 75.57786287580217, 79.67922469547817, 98.5724675314767, 94.74950613294328, 97.90144525255475, 112.24823161533901, 50.63040794645037, 2.2310459400926317, 0.14810031013829367, 0.14287295777882847, 0.23397429074559892, 0.1515930691467864, 0.2770228050649166, 2.274536017860685, 24.405420746122086, 52.120292799813406, 47.708787713732036, 55.082229954855784, 108.20105184827531, 114.14387389591762, 54.33826548712594, 52.15238305500576, 28.748376641954692, 45.14289787837437, 63.44627339499337, 70.58376176016671, 91.59906087602887, 95.7388253893171, 119.14598628452846, 80.80231067112514, 8.82007282120841, 0.7240807861089706, 0.15387287895594323, 0.19498257445437567, 0.06602953188121319, 0.09235867192702633, 0.20748254656791687, 0.1839960611292294, 0.20871355836944921, 0.21904794525887283, 0.18225067907146045, 0.20792529066758497, 0.1594814865716866, 0.13851463235914707, 0.14175243861973286, 0.07244368948574577, 0.14366012625396252, 0.226372201527868, 0.13138434211058275, 0.1684738261891263, 0.09708550292998552, 0.11780741278614316, 0.17470637389591762, 0.13461994991770812, 0.18931264084364685, 0.11971040495804378, 0.1588444100426776, 0.08306548345301833, 0.33399689357195583, 0.3514239527285099, 0.2630117897476469, 0.24297098655785832, 0.0985200209543109], [0.04816783372578876, 0.016985772210838537, 0.041812627243676355, 0.029125342145562172, 0.05212688539177179, 0.12048207569335188, 0.05372669115396483, 0.035145277689610205, 0.08528470008500985, 0.03371418287445392, 0.01695076998190156, 0.06654111335852317, 0.008550670995776142, 0.08009893513683762, 0.07582052078630243, 0.05033674716417279, 0.04427535652316042, 0.0535491830004113, 0.09987107917134251, 0.03984863477359925, 0.02435064728238753, 0.09052818122186831, 0.08384015331310885, 0.045310230992202244, 0.02807674091309309, 0.03431186366028019, 0.04706507522080626, 0.628967492708138, 78.19055230276925, 105.20157010214669, 112.47124794551304, 89.39213929857526, 68.39430100577218, 51.53372240066528, 30.651922498430523, 25.692774295806885, 61.980738503592356, 88.82359600067139, 46.44224228177752, 41.092275278908865, 31.74166406903948, 10.22148973601205, 0.8127881118229457, 0.021642588577898483, 0.02049812052531966, 0.06958060418920857, 0.253749352480684, 0.11598660477570125, 0.4586131338562284, 1.620481239897864, 31.955064092363628, 93.62348801749093, 118.34283011300224, 95.2537646974836, 87.43183708190918, 97.45313358306885, 95.33014624459403, 88.80744143894741, 94.1012739453997, 93.36222185407365, 89.01894460405622, 84.8208360671997, 80.99896553584507, 79.26713398524693, 81.55022866385323, 84.90859876360211, 97.2946104322161, 93.00553607940674, 89.52695519583565, 75.51903942653111, 71.44977828434536, 63.664988790239605, 69.61578736986432, 88.07462882995605, 93.83473409925188, 95.33475290025983, 93.89218875340053, 87.28766890934536, 85.57734203338623, 76.71779823303223, 80.5321021761213, 76.08577619280133, 82.21727657318115, 83.690475327628, 90.23944432394845, 47.98574985776629, 61.82355635506766, 80.92835099356515, 36.45434577124459, 88.6930046081543, 94.01909065246582, 91.16729981558663, 91.53499153682164, 84.46517167772565, 82.21480301448277, 87.3511129106794, 87.44852665492466, 95.3413953781128, 83.43809591020856, 91.49902766091483, 87.68147196088518, 82.41243062700543, 77.26268291473389, 80.85526289258684, 77.37608446393693, 74.3012911932809, 71.93335206168038, 71.70586109161377, 86.0913280759539, 93.55027484893799, 91.42298657553536, 89.0542345046997, 83.18461867741176, 83.04161780221122, 76.1658958707537, 71.51056112561906, 79.70529433659145, 85.12030342647007, 83.23001820700509, 83.82456861223493, 30.58920110974993, 1.2429198196956088, 0.09262746000396353, 0.044252262583800724, 0.18531758950224944, 0.08461744231837136, 0.09938266966491938, 0.07983419112861156, 3.2935110543455397, 22.47241105352129, 26.5706079687391, 34.95337506702968, 49.29697915485927, 78.72324984414237, 45.63712324414934, 30.40455620629447, 17.417693853378296, 32.10630553109305, 47.200082302093506, 56.07818126678467, 67.30994428907121, 69.1525787625994, 80.93151937212262, 71.97449929373605, 13.698087777410235, 0.5816610625811985, 0.02791465586051345, 0.10664405966443674, 0.01287844028723027, 0.07090234290808439, 0.023128480184823275, 0.04661891130464418, 0.017555678862013986, 0.015657321084290743, 0.08730460384062358, 0.05763218605092593, 0.03095565303894026, 0.02784573705866933, 0.008457587865580405, 0.023847050465909497, 0.014108108589425683, 0.0567096226981708, 0.012910248312566961, 0.049274544697254896, 0.03745588620326348, 0.037086271215230227, 0.06084860488772392, 0.008530075761622615, 0.0467058519965836, 0.0895577132967966, 0.07825854460575751, 0.023444758927715675, 0.05777898031686034, 0.02897979299138699, 0.11123534651207072, 0.010981501495864774, 0.1315102239272424, 0.00860771713113146, 0.015934265152152096, 0.020714430703914592, 0.05561390060133167, 0.03833918273448944, 0.035319359241319556, 0.014523999665730765, 0.09743705870849745, 0.07845667683120285, 0.049894844447927814, 0.03019415693623679, 0.05331241838367922, 0.030573719247643436, 0.06710830756596156, 0.048656314478388855, 0.021044646556090032, 0.0915766263912831, 0.018639138134728585, 0.05786577851644584, 0.06824805640748569, 0.061799625999161174, 0.09047003755612032, 0.01983284916994827, 0.05103394528850913, 0.03755404307906117, 0.08459281828254461, 1.6030756767307008, 93.30373191833496, 121.90101650782994, 122.39572824750627, 102.74761922018868, 80.2897698538644, 75.777679170881, 46.03207622255598, 29.365001474108013, 37.71236228942871, 67.6668176651001, 49.0377905028207, 46.905360562460764, 42.669620582035606, 12.733377303395953, 0.3960127686815602, 0.03458184256617512, 0.015891539498365352, 0.11349572307829346, 0.5367904646056039, 0.39722224378160065, 0.16607506919120038, 2.0188770507063185, 39.83524887902396, 105.8064524786813, 124.20471954345703, 99.58253410884312, 91.82066672188895, 100.46775545392717, 97.88238634381975, 94.57247298104423, 96.08275427137102, 98.03582341330392, 91.42621053968156, 89.23403303963798, 83.10404736655099, 82.44574723924909, 85.91120297568185, 90.41889544895717, 99.59964752197266, 98.79994460514614, 93.00674506596157, 80.55558013916016, 76.33816950661796, 67.5848845073155, 72.73882893153599, 93.14872455596924, 96.50570501599992, 97.01328481946672, 97.23013809749058, 93.10024002620152, 89.53231225694928, 80.98115730285645, 82.89477457318986, 77.01925277709961, 84.56986713409424, 88.1248504093715, 93.66084848131452, 55.25942638942173, 68.87763854435512, 89.06483745574951, 45.46634347098214, 91.24993474142892, 96.297821862357, 94.36699390411377, 92.68571744646344, 87.85494763510567, 83.82515920911516, 90.97533498491559, 90.02810791560582, 97.26958996909005, 84.82032884870256, 95.24097306387765, 92.2462716783796, 86.14754595075334, 81.99094595227922, 84.45034422193254, 82.44175897325788, 77.03421224866594, 74.47812284742082, 74.69355174473354, 90.89424950735909, 97.83464527130127, 95.39247853415353, 94.7544949395316, 88.3312188557216, 87.56074701036725, 82.29476983206612, 74.41428974696568, 83.16048063550676, 92.96109540121896, 89.99836267743791, 91.10603060041154, 39.500307491847444, 2.2701751547200337, 0.3337695300579071, 0.06007361611617463, 0.18715435665632996, 0.07416788089488234, 0.08259867850158896, 0.10561148542910814, 4.0142044850758145, 29.874561514173234, 33.460127285548616, 35.875724111284526, 51.95349434443882, 57.2451868057251, 24.812269040516444, 23.75370751108442, 26.763481276375906, 45.307733467647004, 60.66438838413784, 66.86309174128941, 79.68945244380406, 78.74172510419572, 92.11343601771763, 86.55233410426548, 19.268554994038173, 0.5117703271763665, 0.052225442603230476, 0.06269735497023378, 0.03476392065307923, 0.04265448564131345, 0.015239930445594447, 0.09010985081217118, 0.045098053091870885, 0.04200318701831358, 0.025946193541000997, 0.03405940452856677, 0.032947533298283815, 0.004387374351998525, 0.009516306055177535, 0.058201544785073826, 0.00783433479123882, 0.0462765632463353, 0.06306461204907723, 0.05443815208439316, 0.01923379265437169, 0.051221777352371385, 0.08208438966955457, 0.029718212118106227, 0.039629997219890356, 0.014375663428966488, 0.057632566030536375, 0.030767267969037806, 0.09664040431380272, 0.06151084828057459, 0.04886135079764894, 0.03076660300471953, 0.2253090050071478, 0.1486678911106927, 0.15784377445067677, 0.07263899222016335, 0.24648549939904893, 0.1477754275713648, 0.1538747517125947, 0.11024963869048016, 0.17436446010002069, 0.14283699542284012, 0.1138563169432538, 0.11397690618676798, 0.11531123173023973, 0.1576668939420155, 0.24058118622217858, 0.09755487274378538, 0.15381875900285585, 0.21142772558544362, 0.15498136090380804, 0.13445715579603398, 0.2653399791036333, 0.1668555608817509, 0.2956964416163308, 0.12884005292185716, 0.10712877794035844, 0.1532369287950652, 0.16977963969111443, 4.872673528535025, 133.27984510149275, 128.31920651027133, 141.20087487357003, 115.28659548078264, 91.50303677150181, 71.88354042598179, 45.925619397844585, 39.869409697396414, 91.44922992161342, 122.68997056143624, 68.15553310939244, 66.72177233014787, 52.999712399074006, 16.181564160755702, 1.0812842015709196, 0.11371164649192776, 0.1711897168840681, 0.23188285582831927, 0.6885227827089173, 0.7657552127327237, 1.5059005596808024, 5.417491768087659, 36.88507502419608, 111.32189083099365, 134.43712316240584, 104.77792453765869, 92.71738733564104, 104.57755238669259, 101.92318071637834, 98.02328886304582, 98.51203904833112, 103.58140305110386, 96.32547569274902, 93.44595459529332, 88.56282315935407, 87.25096157618931, 89.45020539419991, 96.26498467581612, 102.23310511452812, 102.68333448682512, 96.85949339185441, 87.09128502437046, 79.99961308070591, 73.39411354064941, 78.5270813533238, 99.51881912776402, 101.6487546648298, 103.06165000370571, 101.19232055119106, 99.95225470406669, 95.57610552651542, 85.72845145634243, 86.48777144295829, 80.21750164031982, 86.95470428466797, 93.71778896876744, 93.67833014896938, 62.00778784070696, 76.19308417184013, 98.31209768567766, 52.88172503880092, 93.40464755467006, 101.68920012882778, 99.7069068636213, 97.96827997480119, 89.28288582393101, 88.48503112792969, 93.97931916373116, 95.96086202348981, 101.81563649858747, 86.25444398607526, 99.76340961456299, 96.63726220812116, 87.85605239868164, 85.16243730272565, 88.30999210902623, 85.33068098340715, 81.93128177097866, 78.58371612003872, 78.3379305430821, 94.28506769452775, 100.9418727329799, 97.88476957593645, 99.3312177658081, 92.32833685193742, 93.4836207798549, 84.31907190595354, 78.39806720188686, 90.03006035940987, 96.74164499555314, 95.21516050611223, 96.84515925816127, 37.5468145098005, 4.12633798803602, 0.5968008073312896, 0.10565204146717276, 0.3165167458355427, 0.18516848821725163, 0.219753323122859, 0.3047806955873966, 6.048358236040388, 37.473469325474326, 46.78040763310024, 49.98562901360648, 72.74214322226388, 107.3476254599435, 67.52553299495152, 42.81853437423706, 25.802159786224365, 47.75464235033308, 65.39127567836216, 74.21785722460065, 90.61753749847412, 87.16956342969621, 98.25583117348808, 105.23929187229702, 30.30666651044573, 0.5384181886911392, 0.15182093477674893, 0.15730375557073525, 0.121312873970185, 0.18766971757369383, 0.1070517845717924, 0.24404350614973477, 0.16030745367918695, 0.151274388389928, 0.12036078077341829, 0.18679596803018025, 0.17705083452165127, 0.07662887991006885, 0.19534549569444998, 0.1614229381084442, 0.10556288875107254, 0.21612957971436636, 0.13589001819491386, 0.20396542815225466, 0.14832984496440205, 0.1418453843465873, 0.1587838168655123, 0.11373945964234215, 0.1523027489227908, 0.12412504878427301, 0.13986681694430964, 0.16661892857934746, 0.17672177217900753, 0.18024832223142895, 0.17624267217304024, 0.12234715132841043], [0.02715582131142063, 0.044650549069046974, 0.055478990876248906, 0.040539332532456944, 0.029314931615122726, 0.04209029734400766, 0.08957870038492338, 0.006052906832857323, 0.04346898889967373, 0.039287289538021596, 0.04268436153818454, 0.024075962736138275, 0.0399884740555925, 0.03955440163346274, 0.04962268405194793, 0.09478836333645241, 0.02211180572131915, 0.03681815828063658, 0.010510365794678884, 0.06982052060110228, 0.04487352246152503, 0.024758568964898586, 0.021588986007762805, 0.0761360124285732, 0.0413068065286747, 0.08350134042224713, 0.32147963238613947, 69.77683966500419, 106.50639316013881, 106.01701068878174, 88.35527351924351, 74.47049372536796, 63.78937544141497, 23.94299554824829, 37.036076750074116, 72.01486137935093, 75.80342919485909, 47.7312581879752, 35.738271372658865, 27.166409049715313, 6.047363775117057, 0.6603759016309465, 0.09883653718445982, 0.03022401247705732, 0.12274969901357378, 0.03442811367235013, 1.069056240575654, 0.2241457924246788, 0.9779905442680631, 66.66314343043736, 116.19037546430314, 96.05734470912388, 81.62401853288922, 91.46941443852016, 94.88899816785539, 89.8697098323277, 89.89669663565499, 91.10755225590297, 91.48354707445417, 83.57979052407401, 81.3887664249965, 73.03001403808594, 72.38238634381975, 65.242764881679, 75.40551280975342, 86.14344651358468, 92.9144868850708, 90.08803612845284, 86.6197177342006, 69.92424569811139, 66.41318893432617, 61.732604435511995, 74.9599665233067, 86.76002965654645, 90.5651272365025, 88.03139019012451, 86.10211168016706, 75.25486196790422, 72.77503599439348, 77.76245989118303, 79.53696727752686, 69.7228035245623, 74.34437002454484, 79.38363443102155, 93.52048097337995, 68.01036439623151, 31.01891245160784, 47.789907932281494, 55.1364745412554, 93.46137264796666, 75.75680678231376, 89.45757048470634, 81.58236408233643, 83.65411540440151, 71.9630069732666, 79.9041726248605, 84.67752252306256, 91.47043582371303, 85.96373830522809, 83.08348764692033, 87.43063504355294, 87.34891033172607, 79.20769214630127, 78.99536909375871, 77.52126012529645, 73.98714923858643, 67.27602318355015, 75.11025605882917, 88.27606405530656, 93.23265879494804, 87.79109369005475, 93.04768385205949, 93.17827524457658, 84.22944014413017, 79.47095244271415, 81.95324502672467, 76.65789086478097, 77.05996922084263, 88.7474228995187, 86.26092665536063, 65.40059321267265, 16.11379837989807, 0.953008621931076, 0.2722713771675314, 0.03121340474379914, 0.14301437804741518, 0.12935956647353514, 0.06470121815800667, 0.048574201563107114, 1.471328929066658, 18.905073881149292, 25.22951184000288, 45.302393777029856, 69.45491572788784, 115.94499288286481, 75.12286009107316, 31.243874277387345, 13.141412002699715, 17.901109559195383, 29.888951233455114, 53.221790722438264, 74.07311235155377, 70.09546320778983, 75.71571513584682, 85.23482363564628, 30.790750980377197, 0.7654518261551857, 0.010149975490224148, 0.0790826864540577, 0.040460351056286266, 0.07857257739773818, 0.0444640808605722, 0.016749438463843296, 0.0445131287643952, 0.016872316066707884, 0.03338801787633981, 0.019887130275102596, 0.04294482399044292, 0.03125562997800963, 0.044864077254065444, 0.027373463114989654, 0.08141935071242706, 0.050247319641390016, 0.013319877358818693, 0.010722670072157468, 0.032029081867741685, 0.10178694315254688, 0.03979981757168259, 0.029784104653767178, 0.040562362010989866, 0.016623463348618576, 0.03111383312248758, 0.1332626627492053, 0.07167691777327231, 0.06940425293786184, 0.0641072489587324, 0.07196930529815809, 0.039747665370149274, 0.04360850587753313, 0.03046912985986897, 0.07096641696989536, 0.029683980026415417, 0.022815292168940817, 0.054603246439780505, 0.020697947391974073, 0.07416708700891052, 0.016029451740905643, 0.0761923851179225, 0.004261783881312502, 0.056304364265607934, 0.035148571977125745, 0.02447415253014437, 0.04481711923809988, 0.04822299523012979, 0.019316477235406637, 0.055969704009060345, 0.05276780242898634, 0.02278692940516131, 0.017618884399001087, 0.05251260880114777, 0.05652723927050829, 0.04481326176651886, 0.29077763270054546, 87.60584776742118, 124.46948759896415, 114.02665083748954, 109.69365692138672, 84.02516310555595, 86.51079082489014, 38.107381275721956, 24.36272927692958, 21.747481175831386, 54.26959296635219, 48.31866931915283, 39.16674532209124, 37.18583822250366, 8.22687384060451, 0.5135689878037998, 0.14916008684251988, 0.07938356245202677, 0.1544704104640654, 0.2542130633124283, 2.85304086123194, 0.2943697156650679, 2.99771169253758, 75.53932121821812, 123.16532461983817, 97.88195555550712, 89.15748473576137, 95.19847093309674, 101.45508057730538, 92.9861228125436, 95.36634635925293, 94.52052824837821, 94.53163841792515, 84.89105456215995, 84.43663542611259, 76.73746163504464, 74.5911283493042, 69.68278190067836, 80.86499731881278, 88.37638909476144, 96.26385906764439, 94.01896558489118, 90.9343684060233, 72.94502367292131, 70.86908953530448, 65.37173734392438, 80.12716811043876, 91.17519296918596, 93.08402293069022, 88.6286712374006, 90.28625433785575, 78.75129972185407, 75.49642998831612, 81.33534172603062, 83.04291711534772, 73.0665476662772, 77.28861359187535, 84.29667091369629, 99.01274013519287, 71.01771845136369, 39.377633571624756, 53.31326028278896, 60.585852895464214, 96.82509980882917, 81.51140907832554, 94.16104234967912, 84.88389791761125, 87.63013866969517, 75.90414333343506, 82.80740097590855, 88.60823658534459, 94.00055285862514, 87.75720037732805, 84.20790072849819, 90.79849638257707, 87.4671686717442, 83.22591182163784, 84.195129939488, 83.15642983572823, 77.53550393240792, 69.88855975014823, 78.6010240827288, 91.55766350882394, 97.34887586321149, 88.91499260493687, 95.14258657182965, 96.83962849208287, 88.22527272360665, 84.46738120487758, 86.52425643375942, 82.60902295793805, 80.17443670545305, 93.12840107509068, 92.38092776707241, 71.95152854919434, 20.59474549974714, 1.014623075723648, 0.9384678878954479, 0.02995174690814955, 0.22980778717568942, 0.09162603731134109, 0.03509376331099442, 0.023137681119676148, 1.5095623689038413, 21.74002228464399, 32.745247977120535, 36.07648883547102, 76.51445920126778, 109.72184576307023, 34.381993430001394, 22.210694994245255, 27.480071578707012, 38.62049879346575, 43.20313801084246, 60.6566550391061, 83.86897454942975, 78.98093073708671, 84.63483279091972, 101.19719123840332, 40.914297172001426, 0.6665310284921101, 0.023714797205424736, 0.060850966189588816, 0.03480052422466023, 0.1385813323514802, 0.0453185362608305, 0.07909589753087078, 0.032274840466145954, 0.057748215539114814, 0.04109757686299937, 0.019148857033412372, 0.028516757301986217, 0.056232076537396224, 0.005926081428437361, 0.02670135043029274, 0.04617149209869759, 0.007815752261584359, 0.05901658069342375, 0.032713577816528935, 0.019177508174574802, 0.09881869171346937, 0.02925556319366608, 0.03431056426571948, 0.06725850129233939, 0.008683946299632745, 0.037352871016732285, 0.1785074592168842, 0.0435979784067188, 0.09384221410644905, 0.05659777298569679, 0.10769126311476741, 0.09159115382603236, 0.19443080334791116, 0.12147522025874682, 0.22220999986997672, 0.14550472370215825, 0.15966121692742619, 0.11593665102762835, 0.11127083389354603, 0.1968368206705366, 0.1202787458896637, 0.0815202488697001, 0.10456639222268548, 0.11056122197104351, 0.15765390678175858, 0.15083775110542774, 0.09973459185234138, 0.1480577659926244, 0.13334141352346965, 0.15034940945250647, 0.1619731078722647, 0.15968896900968893, 0.09979016387036868, 0.14597266859241895, 0.21962278655597142, 0.20796916474189076, 0.5310862106936318, 120.70873342241559, 135.0492455618722, 127.91498810904366, 115.82927758353097, 97.1146103995187, 92.15038653782436, 35.70294673102242, 57.77447625568935, 99.95926543644497, 104.8418549128941, 71.30493613651821, 55.09653629575457, 44.73549025399344, 10.081522618021284, 1.078950149672372, 0.3636780780340944, 0.18946145714393683, 0.2736989605639662, 0.11471971204238278, 2.4875373882906775, 1.4055159177098955, 2.904176780155727, 73.37128870827812, 131.0911625453404, 104.75895595550537, 88.13774626595634, 98.26858806610107, 104.59470054081508, 98.11536639077323, 99.50265066964286, 97.54997062683105, 99.63364505767822, 89.2769798551287, 89.2931900024414, 80.64249515533447, 79.65150833129883, 72.07826369149345, 83.884003502982, 94.60103702545166, 101.39704922267369, 99.92562225886753, 95.67314406803676, 78.09117916652134, 74.82560225895473, 67.75837407793317, 83.73764664786202, 94.98636327471051, 98.90816279820034, 94.73215648106166, 97.63758741106305, 83.04939283643449, 82.02160140446254, 86.09007740020752, 86.4113551548549, 75.95282936096191, 81.88422857012067, 87.5142913545881, 106.08053806849888, 72.12671348026821, 45.75967904499599, 63.409288133893696, 62.883198329380576, 99.98415388379777, 86.58542837415422, 99.51510184151786, 88.93555927276611, 92.38834149496896, 80.02873992919922, 86.36428110940116, 94.27722317831856, 98.64796665736607, 90.02320943559918, 85.81815270015171, 94.08258329119, 91.93313026428223, 88.329224722726, 89.13783523014614, 87.60776547023228, 80.28870677947998, 73.00178350721086, 81.16003867558071, 97.63256386348179, 100.55678967067173, 94.3027091707502, 100.09431757245744, 101.21635437011719, 90.80880750928605, 88.84321771349225, 93.29054423740932, 86.24054064069475, 82.75980581556047, 98.98047964913505, 94.771253994533, 73.69209398542131, 20.933642148971558, 3.5438711515494754, 1.4017227441072464, 0.12503271150801862, 0.35963859621967587, 0.19428077925528797, 0.22602651507726737, 0.18111759344381945, 3.030857422522136, 30.125346320016043, 44.307335308619905, 64.72643729618618, 81.05330739702497, 133.82466724940707, 102.67961025238037, 46.32801389694214, 21.063743693487986, 30.180945805140905, 45.43206105913435, 69.85913412911552, 94.39060388292584, 91.92963532039097, 89.66529382978166, 112.17119693756104, 52.43906225476946, 0.711350003523486, 0.07923661890838828, 0.2646448606891291, 0.1833470966666937, 0.28057143464684486, 0.15328521334699222, 0.18192201027912752, 0.1549578428800617, 0.118680225951331, 0.1366738618484565, 0.09497241596026079, 0.129903018740671, 0.11102091587547745, 0.1690024456807545, 0.13222349993884563, 0.1814506591430732, 0.15955505333840847, 0.09012712631374598, 0.13880173409623758, 0.16745181674403803, 0.1676992784653391, 0.1145535252456154, 0.14837935087936266, 0.09682821602161441, 0.06321535538882017, 0.17393269469695433, 0.2892795359449727, 0.15224002514566692, 0.1560207815574748, 0.20814361609518528], [0.02835158321873418, 0.05210987791152937, 0.037960007188043425, 0.02162146069375532, 0.010682091133535972, 0.06535982460315738, 0.06413905868040663, 0.0735199274495244, 0.01814240469996418, 0.01573316433600017, 0.02733288672087448, 0.03386894314150725, 0.03443191346845456, 0.011483072037143367, 0.062135819744850905, 0.025133223771782856, 0.11238067291144814, 0.022065877382244383, 0.12349622324109077, 0.09429698863199779, 0.07836348683174167, 0.023186108163957084, 0.11954094762248652, 0.07624955847859383, 0.19126543748591626, 0.31699538443769726, 53.12379680361067, 104.36910642896379, 103.49901131221226, 77.89977019173759, 52.52460847582136, 62.62173066820417, 26.749433755874634, 31.779469217572892, 56.02262347085135, 83.16056401388985, 53.29835639681135, 41.32781226294381, 27.952397959572927, 4.957395085266658, 0.5504975776587213, 0.11237661527203661, 0.14194238771285328, 0.0663176921329328, 0.09732583324824061, 3.7587196571486334, 1.0786023054804121, 0.88787007438285, 79.9085499899728, 111.41273852757045, 84.74412795475551, 88.41498633793422, 93.00511223929269, 84.8697235924857, 79.72809832436698, 86.64884458269391, 84.22473621368408, 84.96342005048479, 81.91006892068046, 76.93862588065011, 70.73780332292829, 67.96490233285087, 68.62099988119942, 69.33439922332764, 65.77439934866769, 79.05964687892369, 88.64313043866838, 91.55067362104143, 86.90866552080426, 70.26920986175537, 63.97032042912075, 66.2798182623727, 80.52780818939209, 93.80718449183873, 90.72798606327602, 89.58992671966553, 78.54718249184745, 66.57750688280377, 77.64352757590157, 85.60728876931327, 84.49595914568219, 80.77126611982072, 66.55086054120744, 79.91358048575265, 80.87953989846366, 100.27578367505754, 41.69152614048549, 19.479187897273473, 84.07762200491769, 86.99823474884033, 86.15662029811314, 75.77141189575195, 76.14802510397774, 74.42266927446637, 77.63830947875977, 75.54319831303188, 82.93176678248814, 86.92798846108573, 92.59362602233887, 81.67539351327079, 84.85232530321393, 83.36415318080357, 80.7769775390625, 77.84162071772984, 75.75144277300153, 68.71306351252964, 66.20104653494698, 77.13066714150565, 86.11202675955636, 86.15609223502022, 87.00016634804862, 86.31960419246128, 85.09025246756417, 88.85092326572963, 88.54087380000523, 83.55964769635881, 85.74500901358468, 89.64952836717877, 81.9500002179827, 92.40960993085588, 79.21031856536865, 38.53071417127337, 3.4130068251064847, 0.8035529788051332, 0.348205064024244, 0.09895580328468766, 0.11507412445332323, 0.09692344841148172, 0.05633647932804056, 0.13067120180598327, 0.4239205340189593, 15.462225845881871, 24.147814546312603, 36.925044536590576, 24.236800125667028, 59.97657925742013, 69.8023465020316, 28.400094713483536, 18.279155833380564, 15.602298055376325, 32.54364946910313, 43.755419049944194, 74.65182086399624, 75.27023833138603, 73.26961571829659, 85.39940561567033, 22.022721903664724, 0.3367103008287293, 0.16693973993616446, 0.1355445488755192, 0.02134253699997706, 0.02506169261011694, 0.05186239583417773, 0.0231165176124445, 0.028770702425390482, 0.028565384514097656, 0.014570825367367693, 0.0335020863983248, 0.04762669187039137, 0.03189869457855821, 0.004786398319993168, 0.0048855161710110095, 0.05086468472810728, 0.06354392240090029, 0.034943352453410625, 0.04386869691578405, 0.04681349139926689, 0.04036596683519227, 0.0463242574727961, 0.02438742048772318, 0.04517900910494583, 0.08943664229341916, 0.04883888450318149, 0.007988978011001433, 0.023855713661760092, 0.03133167000487447, 0.008965640112624636, 0.05938803790403264, 0.03538277173148734, 0.022264886614201323, 0.04187296936288476, 0.06858058606407472, 0.03349956564073052, 0.11027004223849092, 0.036111026403627226, 0.02320075943134725, 0.027588909857773354, 0.010022589870329415, 0.03085144023810114, 0.045201807881572416, 0.020000340450288992, 0.017143058324498788, 0.05590002864067044, 0.04341924210478153, 0.0647373026502984, 0.052917802772883854, 0.048865706992468665, 0.04323486378416419, 0.12513495316462858, 0.10578772811485188, 0.25062594722424236, 0.19878888449498586, 69.89845398494175, 121.7123590196882, 112.9022238595145, 95.56718403952462, 75.48271424429757, 91.22658879416329, 46.51430899756295, 31.26117181777954, 31.60455526624407, 80.52557781764439, 46.80593531472342, 47.39155033656529, 38.669097968510215, 7.174051523208618, 0.5727683997579983, 0.16324187336223467, 0.07460070481257779, 0.08243655612958328, 0.12897832478795732, 7.964247567313058, 0.7351773849555424, 2.7093406064169745, 87.60711928776333, 115.90717383793422, 85.62848772321428, 94.69239888872418, 95.48085962023053, 87.9604490825108, 81.54103619711739, 89.75185448782784, 86.91691998073033, 89.66323716299874, 84.56623322623116, 81.692750113351, 73.48894255501884, 73.13036687033517, 72.2809704371861, 74.0498845236642, 68.2797599520002, 83.20481014251709, 93.94990743909563, 96.32800483703613, 90.45974390847343, 75.18872901371547, 67.47501264299665, 68.46713897160122, 83.78920922960553, 97.88762528555733, 91.44280978611538, 94.49353449685233, 80.3991344996861, 70.94741657802037, 77.5480523790632, 88.3641185760498, 87.03421252114433, 84.13927337101528, 68.47968741825649, 83.38933345249721, 82.9387983594622, 103.25824233463833, 48.90261329923357, 23.921600307737076, 88.5182991027832, 91.08249010358537, 90.69351605006626, 79.86770153045654, 80.39978763035366, 76.96502903529576, 78.39393302372524, 77.59641184125627, 85.96457903725761, 91.20172119140625, 93.41154016767229, 83.98078496115548, 87.22512817382812, 87.66069684709821, 83.80546801430839, 81.72875567844936, 76.33233301980155, 72.2054921558925, 70.72500474112374, 81.2943195615496, 90.2252699988229, 88.92320537567139, 89.73549842834473, 87.64274270193917, 88.09782191685268, 92.33841868809291, 93.21827602386475, 87.8458593913487, 87.28931563241142, 93.4747896194458, 86.09571238926479, 95.95104421888078, 83.03650392804826, 43.47076177597046, 4.8738264952387125, 1.379694131868226, 1.2479541152715683, 0.21244574524462223, 0.20506542841238634, 0.0942666649020144, 0.023233481782621572, 0.17623680963047914, 0.37444699874946047, 17.825561795915874, 32.0417810848781, 39.18508161817278, 40.01395307268415, 63.50276919773647, 47.485076563698904, 15.524737051555089, 23.592700379235403, 31.722323758261545, 57.136732373918804, 60.3931793485369, 80.38548823765346, 89.38221032278878, 79.41062818254743, 103.39376694815499, 32.221416337149485, 0.31209432599799974, 0.06754293638680663, 0.054527108025337966, 0.008273667556100657, 0.051754512158887725, 0.014376375890736069, 0.007969308128979589, 0.056746161808925014, 0.03448259324899741, 0.03507303745884981, 0.012398442918700832, 0.07777069149804966, 0.01783571026421019, 0.014964837081996458, 0.031901720844741376, 0.012785426706873944, 0.011157502453508121, 0.044087975685085566, 0.05323302639382226, 0.01931018551944622, 0.03447921753727964, 0.022746663440817168, 0.03244526471410479, 0.04795621222417269, 0.03436601414744343, 0.027082541225744144, 0.023903606359713843, 0.022046089604763047, 0.019907367582033788, 0.08523801687572684, 0.11812359653413296, 0.12196360262376921, 0.05213906170268144, 0.08479992074093648, 0.11353592627814837, 0.0720528940271054, 0.20177441143563815, 0.16245212645402976, 0.18519106986267225, 0.08179654832929373, 0.08396250674767153, 0.12276226548211915, 0.12636569355215344, 0.15690495339887484, 0.09690964022385222, 0.1814603486231395, 0.16394993822489465, 0.24661374251757348, 0.14212966337800026, 0.16670674458146095, 0.10936972126364708, 0.19055259573672498, 0.20830167404242925, 0.2828453140599387, 0.16080956959298678, 95.4154770714896, 136.51081303187777, 125.06366974966866, 106.34375667572021, 71.86059052603585, 88.31521715436662, 42.531285422188894, 52.581510748182026, 85.81945896148682, 117.69635581970215, 77.31526688167027, 64.48561968122209, 50.233665806906565, 9.762523872511727, 0.9474992432764598, 0.5665428138204983, 0.20762729165809496, 0.30315750411578585, 0.2047309513602938, 5.5823981421334405, 3.004444714103426, 2.3533272870949338, 87.69174834660122, 122.79195622035435, 90.86044652121407, 97.0245200565883, 103.22728810991559, 93.40247971670968, 86.86225850241524, 93.81896863664899, 91.12896660396031, 93.93883895874023, 90.41146782466343, 86.06427873883928, 78.89487034933907, 76.08129460471017, 77.15386022840227, 78.29555347987584, 73.50053909846714, 89.06494167872837, 100.19021660940987, 99.32202529907227, 96.83631420135498, 78.03588540213448, 72.88089179992676, 75.6849068232945, 90.90934794289726, 105.69134862082345, 95.88682201930455, 98.5276655469622, 85.71497889927456, 75.08572196960449, 82.97504711151123, 93.03749084472656, 91.40385818481445, 87.10336794172014, 71.89036355699811, 86.18156433105469, 88.20890276772636, 106.18846443721226, 52.729927744184224, 31.206145559038433, 89.18662548065186, 96.21262999943325, 92.71422590528215, 84.76592445373535, 83.37144878932408, 82.55841227940151, 84.17962156023297, 82.06479835510254, 91.05200835636684, 98.608049256461, 99.68352617536272, 87.99778870173863, 90.91810962132045, 91.42894118172782, 87.74269948686872, 83.50403431483677, 81.31621333530971, 75.65629414149693, 74.52230644226074, 85.92384869711739, 94.9036727632795, 91.25260284968785, 90.91401018415178, 92.41679436819894, 92.29412392207554, 95.26126875196184, 96.03382505689348, 91.91426590510777, 92.5210451398577, 96.45731081281389, 91.38441017695835, 103.8038774217878, 85.40688187735421, 45.5692150252206, 5.732843143599374, 3.470450622694833, 1.8995875545910426, 0.23378617369702884, 0.42044640758207863, 0.21514666745705263, 0.14942569259021962, 0.2203127345336335, 1.2219256205218179, 26.576001507895334, 41.09763928822109, 54.2140907560076, 38.51318734032767, 79.96023763929094, 96.50394017355782, 42.18556390489851, 27.704138823917933, 24.509796585355485, 47.932481493268696, 61.30798612322126, 92.90033340454102, 99.48280661446708, 88.99023464747837, 113.86800261906215, 42.66583033970424, 0.4268672216151442, 0.2591148817113468, 0.24303447029420308, 0.14488892603133405, 0.1767191258924348, 0.1368903416608061, 0.08722911681979895, 0.16059287264943123, 0.17153693682381085, 0.16886692866683006, 0.12203972068216119, 0.1717679372855595, 0.07626504943306957, 0.10014805716595479, 0.1807165385356971, 0.15028868056833744, 0.12373972231788294, 0.15924000952925, 0.12820805183478765, 0.139611294226987, 0.1755171553897006, 0.15455814504197665, 0.08960711743150439, 0.11541333767984595, 0.2455463255090373, 0.16772613488137722, 0.13141649109976633, 0.08573685546538659, 0.11012280013944421], [0.005624766927212477, 0.0297104937822691, 0.047877135753099404, 0.05281000391447118, 0.029167832008429935, 0.09753674228808709, 0.01581315852568618, 0.051890928231711896, 0.04207783604839018, 0.07835345808416605, 0.03808538688878928, 0.1074968289051737, 0.07482505563114371, 0.08363419757889849, 0.038430554260100634, 0.054154025723359416, 0.09935470045145069, 0.08288219078843083, 0.030385904147156646, 0.10537473777575151, 0.08873387000390462, 0.038528602570295334, 0.04999424982815981, 0.11857322097889014, 0.18436381353863648, 48.62066234861101, 100.83278601510185, 100.21427822113037, 85.66495881761823, 82.47276183537075, 49.541791984013145, 14.08476892539433, 28.586961303438457, 53.24183280127389, 55.2994966506958, 31.529215948922293, 40.04672425133841, 23.147395542689733, 3.0616952649184634, 0.5980423635670117, 0.17283540857689722, 0.2151308711618185, 0.1608431570764099, 0.21027192260537828, 1.4592673991407668, 11.299861448151724, 1.2551656940153666, 71.5009239741734, 110.72891766684396, 85.42314066205705, 95.731981413705, 77.74155276162284, 78.7737215587071, 77.7648709160941, 81.38311753954206, 81.70214407784599, 81.31653990064348, 78.41807801382882, 73.09736292702812, 70.10441248757499, 71.30788912091936, 72.16629736764091, 66.3010311126709, 61.88887637002127, 62.45407063620431, 71.31605325426374, 83.85314655303955, 89.61851855686733, 83.98865727015904, 67.31795556204659, 62.467737742832725, 66.66953577314104, 81.4982978275844, 83.06144101279122, 81.52294308798653, 82.55837753840855, 66.21827111925397, 67.06667396000454, 79.06328773498535, 87.66037028176444, 85.93413897923061, 76.0181702205113, 67.53505897521973, 75.77436488015312, 79.20373167310441, 92.23252814156669, 67.06880705697196, 19.042316436767578, 88.86232525961739, 73.5277829851423, 81.96400778634208, 78.53285530635289, 84.76881490434918, 80.03900936671666, 77.91186700548444, 69.96683815547398, 76.2130880355835, 79.88569041660854, 89.47247437068394, 85.56842054639543, 83.33025291987828, 84.52028478894914, 84.06353800637382, 78.28160149710519, 73.292982510158, 66.35234355926514, 67.41122817993164, 74.52973406655448, 81.71107251303536, 84.50965404510498, 85.58379690987724, 88.13024221147809, 88.51934828077043, 78.0398736681257, 85.5760496684483, 85.14093957628522, 84.84315368107387, 83.73706299918038, 89.56325953347343, 81.62909766605922, 83.33014869689941, 63.550183704921174, 17.18201095717294, 0.9562176040240696, 0.4546447353703635, 0.4843925791127341, 0.18965960294008255, 0.04608880921400019, 0.06943763686077935, 0.04713082865678838, 0.06600622420332261, 0.09407442236053092, 12.893364787101746, 29.416987895965576, 57.605874742780415, 17.910043205533707, 60.31179509844099, 91.1809252330235, 50.770765032087056, 25.112523283277238, 13.42930279459272, 16.222596747534617, 37.95122051239014, 57.50416006360735, 78.09447261265346, 68.86279719216483, 88.18983691079276, 14.5928498676845, 0.5076956429651805, 0.05368230817839503, 0.16569150691585882, 0.10784121935388871, 0.0298032189852425, 0.018591650861448476, 0.021919826112155403, 0.04540494091010519, 0.05857089175177472, 0.04102817290861692, 0.04641932362158384, 0.046895617885249, 0.09277197439223528, 0.033580932167491744, 0.06110159666942699, 0.12136711605957576, 0.04863999231851526, 0.08782341171588216, 0.041603119378643375, 0.04670004712949906, 0.06415542494505644, 0.057454979845455716, 0.047551666253379414, 0.009203989108625268, 0.028412149254498736, 0.036829998716712, 0.05174967081152967, 0.060333515384367535, 0.02267598723327475, 0.11393551555063043, 0.03926840251577752, 0.07519190558897597, 0.02898473951167294, 0.054586595190422874, 0.023214621901778237, 0.0868326352377023, 0.049735124089888165, 0.14806546057973588, 0.01384542987216264, 0.022995794358264123, 0.04003751856674041, 0.02431380791988756, 0.0037134249578230083, 0.0710718205996922, 0.02011686866171658, 0.08266903579767261, 0.03048016283927219, 0.09040398895740509, 0.14356021875781672, 0.0046225070920107615, 0.12995491309889726, 0.0692161630306925, 0.2349517068692616, 64.27244894845145, 122.62207276480538, 109.12673950195312, 104.47540691920689, 87.14843395778111, 60.26078837258475, 37.844141823904856, 28.9703038419996, 31.441755499158585, 63.451929228646414, 37.82018790926252, 47.63170787266323, 33.93489422116961, 4.340177050658634, 0.5964743505631174, 0.12860932387411594, 0.2813385049147265, 0.2227659507521561, 1.6496160136801856, 4.189081524099622, 1.362649332199778, 2.3264407983848026, 80.0786349432809, 112.88721575055803, 88.58391789027623, 98.71647589547294, 80.59122439793178, 82.33541679382324, 83.16711616516113, 85.91552475520542, 84.30245181492397, 82.57979883466447, 82.43217045920235, 76.62770094190324, 73.3745265688215, 74.65582997458321, 75.29209041595459, 70.77187728881836, 66.90635817391532, 66.84808363233293, 74.51601832253593, 87.53528881072998, 91.33982358660016, 88.74351106371198, 71.77755955287388, 65.35089274815151, 69.47874110085624, 86.50315475463867, 89.325012751988, 86.21276869092668, 86.07477051871163, 69.33879048483712, 70.85825729370117, 82.83233806065151, 90.55630997249058, 91.65778705051967, 80.35984243665422, 72.33087934766496, 79.15420491354806, 84.44705077580043, 93.42076737540108, 72.34098202841622, 22.05343120438712, 91.441559110369, 78.7295310156686, 85.98604897090367, 82.0825093133109, 90.59209319523403, 85.41923577444894, 82.12709590366909, 72.10693195887974, 77.38297012874058, 84.28062752314976, 92.16579069410051, 86.37430735996791, 85.539856501988, 87.71981906890869, 87.06508336748395, 82.91555663517543, 76.61695902688163, 69.25927530016217, 70.14148112705776, 77.82911396026611, 85.39284651620048, 86.84306757790702, 87.96381895882743, 92.12121105194092, 90.40301186697823, 80.10120964050293, 87.36785112108502, 87.15376322610038, 87.91534832545689, 84.50859097072056, 91.68432222093854, 82.90687833513532, 86.44114903041294, 69.46465015411377, 21.609658445630753, 1.061682356255395, 1.116016617843083, 0.9058267708335603, 0.5864830581205231, 0.035535072309098074, 0.049589279772979875, 0.042298963825617514, 0.04706927535257169, 0.1642677911690303, 14.96947523525783, 34.16267006737845, 30.779779774802073, 22.118389913014003, 56.18877574375698, 56.844842025211875, 35.4367265020098, 18.25424654143197, 24.072678463799612, 34.86125932421003, 61.06823853084019, 65.89476299285889, 88.88457339150565, 74.55544240134103, 106.5150784083775, 21.84139129093715, 0.7134284919926098, 0.026787687226065567, 0.08907740549849612, 0.10986724349537066, 0.026429805804842284, 0.07676135030175958, 0.03506379241922072, 0.06093454813318593, 0.044464409950056245, 0.09880915151110717, 0.02117366829354848, 0.05132794433406421, 0.06877441637750183, 0.06747525251869645, 0.03694780935932483, 0.03676250823108213, 0.04632801655679941, 0.025846294526542937, 0.11327861222837653, 0.04101624765566417, 0.03007640057642545, 0.032153752499393055, 0.06976977975240775, 0.006012961052225104, 0.12882469088903495, 0.03813747802217092, 0.05048661180106657, 0.050148752251906056, 0.07151627460760729, 0.17025278215961798, 0.13266411343855516, 0.15799179007964476, 0.09724693319627217, 0.12599483345236095, 0.1493850347719022, 0.15476580389908381, 0.1615575458854437, 0.23371370615703718, 0.15264203000281537, 0.26252899851117817, 0.1843018497207335, 0.15978238971105643, 0.11538011660533291, 0.16427961124905519, 0.2111079998846565, 0.17070327512919903, 0.1238138454833201, 0.23743370654327528, 0.2082753333130053, 0.1872395399425711, 0.30638179395880016, 0.21249301199402126, 0.2022709905036858, 82.9371724809919, 137.9261749812535, 125.43923377990723, 111.28097983769008, 102.45330742427281, 64.71345111301967, 20.788603714534215, 49.255022457667756, 85.27330275944301, 78.99857221330915, 47.310607297079905, 65.12444400787354, 42.53657994951521, 7.567970088550022, 0.9846725400005067, 0.3970879481307098, 0.4578951352408954, 0.41803459557039396, 0.6366798845785004, 3.0593265805925642, 22.00383496284485, 4.478935616356986, 80.25998292650495, 120.02266829354423, 92.27180630820138, 102.91325732639858, 84.9782405580793, 84.94989190782819, 83.37283842904228, 90.32189164842877, 90.32806859697614, 88.26936599186489, 86.710572378976, 80.83385549272809, 76.86728177751813, 78.47004359109062, 79.94856466565813, 75.80192838396344, 71.55837862832206, 71.37645394461495, 78.42891025543213, 94.23080226353237, 98.19804300580705, 93.92524133409772, 75.28676114763532, 69.1354375566755, 74.48425810677665, 90.59148175375802, 92.08380889892578, 90.06252929142543, 90.22061470576695, 74.64959744044712, 74.29241834368024, 86.83181844438825, 93.58888598850795, 93.21596227373395, 83.10581220899309, 77.33863367353166, 81.1968641281128, 88.76712799072266, 100.44918986729213, 72.88931996481759, 26.83293546949114, 94.87312153407505, 82.50222914559501, 90.16022096361432, 87.27790669032505, 94.42474038260323, 88.57642773219517, 85.90342099325997, 75.93791852678571, 83.42621449061802, 87.63183403015137, 98.48614311218262, 89.60126617976597, 88.82906423296247, 92.44927024841309, 92.0678071975708, 88.12919998168945, 81.91125011444092, 74.43137536730084, 73.34370435987199, 81.35207298823765, 90.12137358529228, 95.05213492257255, 96.48864024026054, 96.83962849208287, 94.58950996398926, 82.22150802612305, 91.05209868294853, 92.17401041303361, 92.18029158455985, 88.78613826206752, 97.55834320613316, 86.96860763004848, 92.263336454119, 70.81130831582206, 21.977275473730906, 3.53610480257443, 3.3472773006984164, 1.782581844500133, 0.5596961783511298, 0.13491869531571865, 0.21642459316977433, 0.20587787910231523, 0.20584150962531567, 0.6432445751769202, 22.437175001416886, 46.33053609303066, 80.6098803111485, 28.357828821454728, 76.4920095716204, 122.96436882019043, 78.15335859571184, 35.92566428865705, 22.24580771582467, 27.36749165398734, 57.03218630381993, 71.40173843928746, 99.48284135546002, 84.00976589747837, 119.19271986825126, 27.24132626397269, 0.9667052584035056, 0.14906718182776654, 0.3029457469071661, 0.20614553402577127, 0.12480419448443822, 0.13217797023909433, 0.16023470115448746, 0.15884187232170785, 0.12658965082040854, 0.14267791967306817, 0.09597581318978753, 0.13127289951911994, 0.13580689765512943, 0.16814933717250824, 0.1546195796025651, 0.18620828885052884, 0.13775406245674404, 0.13384631143084594, 0.17372453372393334, 0.08041186870208808, 0.14943331932382925, 0.22547223339123385, 0.1518669394510133, 0.10522446941052165, 0.20410243794322014, 0.1186879612505436, 0.12089154443570546, 0.16770980932882854], [0.011101638665422797, 0.03721046008701835, 0.0321041787309306, 0.05469534060518656, 0.032610308179365735, 0.02981757339356201, 0.10396811432604279, 0.07177510179047074, 0.022354895980762582, 0.05896714941731521, 0.02712988431033279, 0.016872431417661052, 0.06384998240641185, 0.04877664248592087, 0.040595138645065684, 0.016442367441153953, 0.012343401006156845, 0.028269512711891105, 0.010219959592047547, 0.05581927279542599, 0.13208839004593237, 0.030830453149974346, 0.18682442578886235, 0.31760454603603905, 27.97287082672119, 108.84367683955601, 93.17075034550258, 104.45033087049211, 62.08234895978655, 71.40572670527867, 76.30306025913784, 36.95304230281285, 58.651265961783274, 79.87902014596122, 46.264236382075715, 47.756011145455496, 24.42598393985203, 1.0107111313513346, 0.49683533715350287, 0.3255842264209475, 0.22712971802268708, 0.18932474590837955, 0.43995694922549383, 0.5924690397722381, 12.955803905214582, 0.6289518049785069, 43.616149357386995, 117.16958509172711, 87.94427367619106, 102.24257550920758, 70.65209034511021, 83.44047914232526, 81.8081180027553, 82.5668612888881, 71.98317064557756, 78.59729290008545, 71.83420821598598, 71.51112392970494, 67.1669920512608, 69.58881446293422, 68.4788327898298, 68.84396062578473, 67.23242323739188, 65.02074214390346, 60.06402233668736, 64.11281408582414, 74.77606160300118, 87.46139471871513, 79.49825886317662, 63.07482269832066, 59.34155559539795, 67.94015979766846, 86.57090663909912, 84.30306325639997, 85.60995687757219, 81.52241502489362, 63.14932823181152, 70.49017647334507, 85.64821365901402, 80.05682454790387, 82.36120850699288, 80.78662858690534, 69.47241824013847, 69.44605677468437, 80.21707780020577, 84.38315514155796, 89.0134972163609, 30.606206825801305, 71.23132692064557, 87.2955481665475, 80.91236318860734, 85.73140444074357, 81.27731731959751, 84.98345865522111, 79.77724988119942, 77.41586984906877, 68.12532234191895, 78.73289394378662, 83.7141478402274, 88.03063978467668, 82.7726182937622, 84.573897089277, 83.38787433079311, 78.68381881713867, 70.59433691842216, 64.2988590512957, 68.20030035291398, 74.05294173104423, 76.42960780007499, 73.01584666115897, 74.23654093061174, 79.5810466493879, 84.80255535670689, 86.3990707397461, 82.24301964896065, 79.78412164960588, 80.04365771157401, 79.75134004865373, 78.34027208600725, 80.61276381356376, 79.253237588065, 75.38404287610734, 52.17837626593453, 6.251030240740095, 1.053312599658966, 0.8028907829097339, 0.20965981616505555, 0.1634175053664616, 0.013592803651200873, 0.10657994489052466, 0.07033850066363811, 0.043750211130827665, 0.43921780745897976, 8.217938457216535, 34.99276787894112, 62.407128606523784, 28.25992522920881, 59.89991283416748, 104.3348309653146, 94.81163692474365, 37.118715150015696, 19.64855544907706, 14.856325558253697, 45.31785004479544, 63.43867206573486, 75.51180635179792, 76.59620475769043, 67.30455248696464, 1.7339002681629998, 0.017464303943727697, 0.020288519361721616, 0.07783591228404216, 0.058885304523365836, 0.05270475634772863, 0.03623747818970254, 0.06352994457951613, 0.04853603396830814, 0.06473565381020308, 0.07237787837428705, 0.04224937648645469, 0.05827897920140198, 0.03248909468363438, 0.036955161286251884, 0.006876445209075297, 0.011084140095460628, 0.018280496754284416, 0.05580549514187234, 0.054805236136806865, 0.03107276139780879, 0.07354039206568684, 0.054399037933243174, 0.05517374511275973, 0.039946316674883874, 0.010216242068314126, 0.027735612521480237, 0.02719354276944484, 0.01881932480526822, 0.040149388635264974, 0.016286640261699046, 0.02685652460370745, 0.03616571971880538, 0.01949691666024072, 0.1050047529861331, 0.012507902491571648, 0.07808075486017124, 0.0576102625844734, 0.011959885380097797, 0.1114785470334547, 0.03386497371164816, 0.010422911112462836, 0.03946767468005419, 0.012949895961875362, 0.1146290326224906, 0.05411646541740213, 0.04246611753478646, 0.05896064226648637, 0.08393605745264462, 0.10479819335575614, 0.20660264949713433, 0.10599512234330177, 40.26307725906372, 130.63217844281877, 100.96150834219796, 121.99706840515137, 70.08995328630719, 99.91817378997803, 84.4918110711234, 22.861682142530167, 30.981069087982178, 80.26053878239223, 49.663722446986604, 46.02530172892979, 35.01044062205723, 1.2629203179052897, 0.5320362682853426, 0.10336077798690115, 0.16611446493438312, 0.08478592256350176, 0.5773115988288606, 5.778219223022461, 12.67687542097909, 1.5660366756575448, 55.61703280040196, 117.25670160566057, 93.04073565346854, 104.85095010484967, 75.79187434060233, 88.07043906620571, 84.89804444994245, 85.7540625163487, 75.30226952689034, 82.44303049360002, 76.08693654196603, 74.37251022883824, 70.63561616625104, 75.47729464939663, 71.67116873604911, 74.3427927834647, 71.05828203473772, 69.66141619001115, 64.95704800742013, 68.58186762673515, 80.97074890136719, 90.67294938223702, 84.75270898001534, 67.15525654384068, 62.45657198769705, 70.25508417401994, 88.40514074053083, 90.29049968719482, 89.14544350760323, 85.67960562024797, 65.54826327732631, 73.59620189666748, 87.85567024775914, 83.88467053004673, 83.86520862579346, 82.07902826581682, 73.26746872493199, 73.61661570412772, 84.47835935865129, 86.48150416782924, 93.48171697344098, 33.60277380262102, 71.3961659840175, 90.8242255619594, 85.51899800981793, 91.17241368974958, 83.4137077331543, 88.95598002842495, 82.15688283102853, 79.62145737239292, 71.2383029120309, 82.83985601152692, 87.80544866834367, 92.0841771534511, 86.31437219892229, 86.30585370744977, 85.80777903965541, 80.75378445216587, 72.7257524217878, 66.69614737374442, 71.8728471483503, 76.45890835353306, 80.00738116673061, 75.9047269821167, 77.5236155646188, 81.78871863228935, 85.78874792371477, 87.45446736471993, 84.18265792301723, 80.68032809666225, 81.66057995387486, 82.61508873530796, 80.31690951756069, 80.80054582868303, 82.32771818978446, 77.52233014787946, 59.62741143362862, 9.660780532019478, 0.14157933076577528, 0.7869172543287277, 1.1823629034417016, 0.5160464548638889, 0.34746765930737766, 0.03137165268084832, 0.10125750941889626, 0.04169675721121686, 0.5696881764701435, 10.778329661914281, 36.43770483561924, 37.51261895043509, 34.69747986112322, 56.617924281529014, 64.72858428955078, 55.17442560195923, 33.27602086748396, 26.326404844011577, 31.733552047184535, 63.93892151968819, 72.24057361057827, 87.06096308571952, 83.6840899331229, 88.96672889164516, 4.016012753759112, 0.1806107142141887, 0.0024903335683380385, 0.08147205931267568, 0.09511189561869417, 0.04301643657631107, 0.021496432134881616, 0.049162691592105796, 0.018576811300590634, 0.018159563154248253, 0.06676639377006463, 0.034640121938926835, 0.015718582618449415, 0.004512918173402015, 0.014167009669888233, 0.01920181669161788, 0.05118414580023714, 0.04535146556528551, 0.015350604596148645, 0.10905055874692542, 0.019228296520720636, 0.030337619595229626, 0.07072981180889265, 0.02624093388606395, 0.04139298386871815, 0.03140508410121713, 0.08833559708935873, 0.06659443942563874, 0.0964228320600731, 0.1560334973037243, 0.12409733741411141, 0.14759135459150585, 0.09053474944084883, 0.08468290059162037, 0.2093416510948113, 0.09524534988616194, 0.19409209223730223, 0.1568978423518794, 0.10521857294120959, 0.23217590153217316, 0.0999463829877121, 0.08600179624876805, 0.0949170407173889, 0.11024619851793561, 0.20510880037077836, 0.18302184769085475, 0.11672273384673254, 0.2826143407395908, 0.24232249706983566, 0.23072584505592073, 0.3990406904901777, 0.3764871635607311, 51.8290764263698, 143.42211668831962, 117.04329463413784, 131.4921152932303, 86.89665903363908, 91.47308308737618, 94.35293769836426, 53.85173872538975, 88.32913439614433, 108.23366669246128, 65.06965746198381, 75.60294587271554, 41.81566613061087, 2.892406531742641, 1.065470210143498, 0.4427338402186121, 0.4857431894966534, 0.36935445772750036, 0.7059644439390728, 4.030639580317906, 22.75283166340419, 5.653667986392975, 52.58658293315342, 127.88919639587402, 94.56571933201381, 112.04000799996513, 78.31735692705426, 93.64275537218366, 88.33131613050188, 91.63699804033551, 79.33626161302838, 88.69877856118339, 78.46250479561942, 79.75725296565464, 74.69981207166398, 78.88322516850063, 77.3902587890625, 79.28229495457241, 74.34406430380685, 74.7052664075579, 68.34754657745361, 74.16377939496721, 84.50375502450126, 96.29315267290387, 90.51357855115617, 73.00536182948521, 66.54770605904716, 73.99116529737199, 93.98992906297956, 94.22149167742047, 94.28743703024728, 92.26965236663818, 68.50408949170793, 77.65977246420724, 90.74630846296037, 86.76764488220215, 85.94385950905937, 88.71330724443708, 74.89332635062081, 77.47599955967495, 87.41370228358677, 93.39230755397251, 95.63402570996965, 40.002922807421, 78.20690836225236, 92.96803665161133, 88.55667400360107, 96.17796543666294, 90.07206221989223, 93.91030270712716, 87.43066283634731, 83.39570495060512, 75.63515772138322, 88.80711487361363, 93.7160449709211, 96.72468444279262, 87.42373548235211, 90.50310066768101, 89.55501202174595, 82.90504401070731, 77.99541214534214, 69.9207090650286, 75.5347215107509, 82.84211417606899, 85.00072492871965, 79.23636041368756, 81.59935937608991, 86.73157678331647, 91.47636958530971, 90.48933628627232, 87.04202924455915, 82.74431828090123, 86.3901562009539, 84.01633194514683, 84.71483434949602, 85.77964578356061, 86.44883373805455, 81.89595712934221, 61.029259136744905, 9.645857538495745, 3.962392636707851, 3.1438168925898413, 1.835157994713102, 0.45167785457202364, 0.2770783363708428, 0.1825087937925543, 0.2024878231542451, 0.12278912189815726, 2.1774872711726596, 16.414200271878922, 56.975461210523335, 89.89997618538993, 44.5549760546003, 72.56897326878139, 126.2158339364188, 128.77227074759347, 52.49192762374878, 27.88924925667899, 25.130720615386963, 62.69190747397286, 81.3833954674857, 99.16701793670654, 91.21233109065464, 100.0688385282244, 5.400118666035788, 0.34432381657617434, 0.15417280500488623, 0.24570898392370769, 0.2253678339932646, 0.17668275641543524, 0.09722558648458549, 0.18311441343809876, 0.20026787370443344, 0.15255136415362358, 0.13719676807522774, 0.1982565059193543, 0.13623437471687794, 0.1202088160706418, 0.11866977651204381, 0.04365122304963214, 0.1053784154355526, 0.13703702736113751, 0.09865226742944547, 0.15571792423725128, 0.12184511683881283, 0.12852951458522252, 0.17067945855004446, 0.13446391400481972, 0.1074529073334166, 0.11260080324219805, 0.15064793771931104, 0.08767887697155986], [0.023142181503187333, 0.04887796472758055, 0.039053300129515786, 0.10874026468289749, 0.03839047998189926, 0.09074714447238616, 0.05757979636213609, 0.060426060775560994, 0.040600336223308525, 0.038207129641835175, 0.029393105634621212, 0.04167150892317295, 0.025955370727128217, 0.019638116404946362, 0.04034417907574347, 0.0791546790195363, 0.0031839592058011995, 0.0958445913025311, 0.05847173064414944, 0.028635266835668256, 0.05134531143786652, 0.038255244560007534, 0.48383585470063345, 28.676975216184342, 116.86000115530831, 97.18530137198312, 107.24002565656389, 68.85908685411725, 79.97958142416817, 31.271121638161794, 14.097993084362574, 117.93227495465959, 130.44252041407992, 52.01936674118042, 44.746023723057334, 22.718575307301112, 0.4562091114265578, 0.2078417358653886, 0.10895626273538385, 0.26221869087644983, 0.0042788087490147775, 0.36043185793927734, 0.03421092139823096, 16.24172513825553, 2.8951953649520874, 11.06381985119411, 119.77586827959333, 85.6640625, 102.70108713422502, 75.6806058883667, 83.38654027666364, 73.96760395595005, 81.34287357330322, 78.58642591748918, 79.72117097037179, 68.56749875204903, 70.21339498247418, 65.50471891675676, 69.03458445412772, 66.34001050676618, 73.6994799205235, 70.20441790989467, 69.91750594547817, 59.03719670431954, 66.44840240478516, 61.277775355747764, 66.52917521340507, 67.55804361615861, 64.86316394805908, 58.53790610177176, 62.937686102730886, 66.63503796713692, 83.86208193642753, 79.80982998439244, 82.47350529261998, 66.90794931139264, 60.38568224225725, 70.76633262634277, 84.43207740783691, 75.3852310180664, 82.9025912966047, 76.7731545312064, 72.65906361171177, 68.85485540117536, 80.30268655504499, 72.17212690625871, 94.18306119101388, 39.37457636424473, 50.73509298052107, 85.83243124825614, 74.95121874128068, 88.99195780072893, 81.48283808571952, 84.96471241542271, 77.76424557822091, 80.0320611681257, 73.48427336556571, 67.86099897112165, 77.70063482012067, 84.99725777762276, 81.36323874337333, 80.93957233428955, 81.79174109867641, 77.49958174569267, 66.65679972512382, 62.08257825034005, 65.26052447727749, 67.5971758706229, 67.32139492034912, 69.64490032196045, 72.39421217782157, 81.91760771615165, 85.91901275089809, 78.02899973733085, 75.80756337302071, 82.48475442613874, 79.64749922071184, 75.52623081207275, 81.57286589486259, 78.37392915998186, 78.01385266440255, 77.8828374317714, 73.44473116738456, 46.293821811676025, 0.6505451234323638, 0.8913096498165811, 1.2200518867799213, 0.27578939124941826, 0.05600920492517097, 0.012985249332684492, 0.11220738185303551, 0.09302240131156785, 0.12298980541527271, 0.2134494749563081, 5.819753382887159, 21.052039452961512, 36.62267630440848, 28.1005665574755, 86.84871646336147, 99.42352458408901, 59.59490081242153, 57.14617844990322, 23.945630652563914, 16.106973511832102, 47.706453119005474, 64.34408487592424, 71.29374258858817, 88.44744832175118, 27.42926287651062, 0.5112499722412654, 0.10668950793998581, 0.044482798249061616, 0.01876685199593859, 0.07332247375909771, 0.04542944280962859, 0.014903787590031112, 0.047734850352363925, 0.024780806253797243, 0.0710948636489255, 0.012379607634751924, 0.06379866480295147, 0.049322805500456264, 0.08274224972618477, 0.022937009476923516, 0.05172582369829927, 0.06121287641248532, 0.09561958909034729, 0.035661049120660336, 0.02729131796929453, 0.04568282474896737, 0.019165632115410905, 0.04930611014632242, 0.016092009276949933, 0.03352765699050256, 0.013403845219207662, 0.04692364138151918, 0.007298728933424822, 0.014970245006095086, 0.044760196935385466, 0.09814681990870408, 0.03509763435327581, 0.08217201568186283, 0.007466060758036162, 0.03837086692718523, 0.022086452260347347, 0.04853420192375779, 0.03602280328050256, 0.04317482700571418, 0.004252754700636225, 0.020474186898874383, 0.025191801699942777, 0.024177505501679013, 0.026759977552241514, 0.1278656902057784, 0.0377126201055944, 0.05296482524967619, 0.0511324583951916, 0.08879252257091658, 0.41703052659119877, 40.99765471049717, 136.04792404174805, 106.57037912096295, 119.11622020176479, 82.25970227377755, 98.94398771013532, 50.84315136500767, 30.408912726811, 64.14003712790353, 116.05734525408063, 58.3891590663365, 51.15738017218453, 32.89035415649414, 1.1679815437112535, 0.25192849018744057, 0.02753795527054795, 0.1231243046266692, 0.055874352875564776, 0.46632867412907736, 0.039411695541015694, 5.597586035728455, 2.6681497309889113, 15.027706350599017, 124.87852805001395, 87.28147111620221, 105.25293118613106, 78.59059483664376, 88.57159873417446, 77.18691280909947, 86.03092043740409, 82.05163846697126, 86.05687195914132, 72.03760283333915, 75.64460032326835, 68.8818005153111, 72.55998229980469, 70.46752534593854, 77.53642109462193, 72.32410485403878, 74.21937888009208, 62.70936829703194, 68.77721623011998, 65.0642170224871, 69.79975482395717, 70.40881306784493, 69.6447057723999, 61.06179755074637, 66.52496460505894, 69.7377838407244, 86.48777839115688, 82.81434917449951, 87.1293750490461, 69.36150414603097, 62.39826965332031, 73.00850936344692, 89.03979614802769, 78.59127576010567, 87.59871891566685, 79.36975193023682, 78.95323521750313, 72.35526057652065, 85.65751729692731, 74.90754236493791, 98.22236170087541, 42.28298112324306, 53.18706709997994, 87.41336182185582, 78.20635250636509, 91.19105570656913, 84.42266954694475, 87.6244203022548, 81.69223594665527, 84.57810769762311, 77.8754653930664, 72.16476876395089, 79.32567255837577, 89.13180419376918, 82.32026972089494, 85.29674598148891, 84.22814777919224, 80.48120662144252, 70.40958431788853, 65.46166787828717, 67.12278761182512, 71.00332178388322, 70.13948699406215, 73.48441927773612, 75.5771541595459, 86.84927231924874, 88.89891447339738, 81.36589295523507, 76.18703229086739, 86.25044182368687, 81.7394767488752, 79.05466502053397, 83.13238212040493, 79.87023762294224, 80.0286009652274, 79.49594511304582, 77.03046022142682, 54.104271003178184, 2.2683547266892026, 0.28376350764717373, 1.297026310648237, 1.163696567927088, 0.4624203124216625, 0.0621860788336822, 0.03339904407039285, 0.031062305173171417, 0.08018571976572275, 0.2024085431226662, 6.554521041257041, 25.34346750804356, 33.17468139103481, 33.8623446055821, 87.1289234161377, 93.87424155644008, 27.76282157216753, 20.993532146726334, 23.073053291865758, 30.626655374254497, 63.866583824157715, 71.56838403429303, 80.12399278368268, 102.18525981903076, 42.57281480516706, 0.4684472233057022, 0.08909421959625823, 0.08518937270023993, 0.06128400723849024, 0.05163425200485757, 0.04097540324021663, 0.06373029561447245, 0.022846287648592676, 0.06773882266134024, 0.0033439002997641054, 0.02266228591491069, 0.061015348083206584, 0.07613805481897933, 0.07878851438207285, 0.055254327931574414, 0.04959037899971008, 0.0741207634231874, 0.03487963122980935, 0.06238144263625145, 0.03884683549404144, 0.04959652991965413, 0.051655327302536795, 0.055875889757382016, 0.04936719526137624, 0.03963929654232093, 0.026628910031701838, 0.10030129751456635, 0.15965817709054264, 0.12175460026732512, 0.10559024049767426, 0.22711753153375216, 0.1284333797437804, 0.19236455565052374, 0.12286640703678131, 0.18557541923863546, 0.1394903657159635, 0.08751931946192469, 0.1532677071435111, 0.17424233736736433, 0.10956784670374223, 0.22673394211700984, 0.12693449588758604, 0.172061077984316, 0.0981160822723593, 0.24969513288566045, 0.28669374755450655, 0.17267783917486668, 0.27753569611481255, 0.22407145212803567, 0.9540560628686632, 46.31073372704642, 156.15355110168457, 119.59864752633231, 137.30511719839913, 90.40109416416713, 103.21431582314628, 45.2093573978969, 23.418498618262156, 162.89340100969588, 153.4525500706264, 69.61251476832798, 73.18743937356132, 38.90132761001587, 1.6852912136486597, 0.4974200172083718, 0.19590196226324352, 0.45711666558470043, 0.21896354907325336, 0.6147120690771511, 0.1377311958266156, 40.06824629647391, 8.31607220854078, 11.945709535053798, 133.98686599731445, 87.25962597983224, 112.40444101606096, 80.82981164114815, 94.61947754451207, 80.3945973260062, 89.0706808907645, 85.74480056762695, 91.24436923435756, 75.48903015681675, 81.18600409371513, 71.58250277382987, 75.88017899649483, 73.44443239484514, 81.40981946672711, 78.01993233816964, 79.55963230133057, 66.22095312391008, 75.06767749786377, 68.7951773234776, 74.33031381879533, 75.22610337393624, 75.12232507978166, 65.2327664239066, 70.35787582397461, 73.53770501273019, 90.58269228254045, 86.73092365264893, 92.10935047694615, 73.2140440259661, 66.03119087219238, 77.95730127607072, 93.63648809705461, 82.44731058393205, 90.21689047132219, 83.43339892796108, 85.67386640821184, 76.14909512656075, 89.18617384774345, 81.71126011439732, 101.66371413639614, 48.9254971912929, 58.02575090953282, 88.67666244506836, 82.54074301038469, 95.07171494620187, 88.10061509268624, 90.6668141228812, 86.76103714534214, 87.63443960462297, 81.88670212881905, 73.48661490849086, 83.56213515145438, 92.7041927065168, 85.93770340510777, 86.79786259787423, 88.3315315246582, 85.87107712881905, 74.56578826904297, 68.75002792903355, 72.46323558262416, 74.45559678758893, 75.2195234298706, 78.01292160579136, 81.39390114375523, 90.06172330038888, 94.28993838174003, 83.55590956551688, 79.81688935416085, 88.33743054526192, 84.68140656607491, 82.05496665409633, 86.27413518088204, 82.29430430276054, 83.38551194327218, 82.93954876491001, 79.21299362182617, 53.259908539908274, 2.21361095564706, 3.9133978486061096, 4.009365499019623, 1.3524936714342661, 0.5201961036239351, 0.09174075044159379, 0.2064516076019832, 0.2154516146651336, 0.38078682284270016, 0.6614346876740456, 12.773233907563345, 36.663441385541645, 53.46989699772426, 45.771661213466096, 99.5004550388881, 115.42489242553711, 88.67083290645054, 83.21130670819963, 34.9872544833592, 27.608762638909475, 64.34910147530692, 81.85241971697126, 88.42155933380127, 113.05585547855922, 49.49845954350063, 0.7121669054031372, 0.24710806884935924, 0.15300557549510682, 0.09818880765565804, 0.26812848661627087, 0.17097846179136209, 0.23309471937162535, 0.08572683350316115, 0.152582780324987, 0.1568123876516308, 0.11389271356165409, 0.09159483827118363, 0.11035146644072873, 0.2023038315985884, 0.1657880488783121, 0.2253277190029621, 0.1365117055496999, 0.14564849170190947, 0.1911747037832226, 0.06648294255137444, 0.16638321908456938, 0.05404345844207065, 0.2531939851386206, 0.1657107365982873, 0.19903220715267317, 0.09243596385100059, 0.0899613873500909], [0.06466483511030674, 0.03610947595110961, 0.014442475379577704, 0.06478878988751344, 0.061912642791867256, 0.02423526918781655, 0.07689903862774372, 0.007153481727332941, 0.0541986122594348, 0.029557921790650914, 0.04795413251434054, 0.07224911278379814, 0.07454701912190233, 0.02290143388589578, 0.08995296673050948, 0.04367653579850282, 0.03744888711454613, 0.014388859238741654, 0.1132018156349659, 0.07266873919538089, 0.14107821908380302, 0.26205869231905254, 9.461677295821053, 106.61730030604771, 101.68374579293388, 104.46405356270927, 77.92739622933524, 57.08850840159825, 19.232509476797922, 40.04006092888968, 64.50626277923584, 58.72478485107422, 61.89783954620361, 61.485443115234375, 27.83233482497079, 1.915089637041092, 0.23502303447042192, 0.04544647743127175, 0.10107699874788523, 0.12954810421381677, 0.12979761511087418, 0.05669667285733989, 1.0739762165716715, 3.2332777721541266, 0.3964104444852897, 74.85939134870256, 103.1997662952968, 92.03694329942975, 84.70768465314592, 78.10951546260289, 70.37053544180733, 75.50272505623954, 81.17666571480888, 78.7888547352382, 74.7157095500401, 74.02038942064557, 71.36505889892578, 67.76266806466239, 70.52806500026158, 71.54346779414585, 70.94866030556815, 69.40338093893868, 68.96498434884208, 63.72358294895717, 61.266046796526226, 59.89581339699881, 62.7999450138637, 61.098289489746094, 60.410139901297434, 60.81353146689278, 61.14851106916155, 69.74796989985875, 80.9648985181536, 78.80330004010881, 76.54371111733573, 64.06478118896484, 62.01987770625523, 71.1420703615461, 84.7765760421753, 76.57603413718087, 79.51492064339774, 80.26458958217076, 74.13508333478654, 66.70479093279157, 75.04861858912876, 71.20311028616769, 91.34195668356759, 51.46437243052891, 43.1824289049421, 83.04577282496861, 70.45323984963554, 75.51631573268345, 75.4654757635934, 87.35328769683838, 77.53095981052944, 81.90609455108643, 78.43824168613979, 76.6485594340733, 65.92134680066789, 81.68735831124442, 77.8550307410104, 82.7118285042899, 81.42710658482143, 74.0607167652675, 61.424542154584614, 62.1758508682251, 61.41691303253174, 64.76166466304234, 59.257197516305105, 67.49097960335868, 72.21717207772392, 80.78298078264508, 81.3765514918736, 75.01244626726422, 77.23964963640485, 77.6673390524728, 81.76514339447021, 82.61061409541539, 74.14699254717145, 78.91103880746024, 75.23556682041713, 78.65744345528739, 74.7358454295567, 83.42506108965192, 38.313305037362234, 0.43271708914211815, 1.3333733145679747, 0.8404907967363084, 0.40974116059286253, 0.16326478070446424, 0.07567848983619894, 0.04984793392941356, 0.05277497793680855, 0.028753521918718303, 0.08686023125691072, 3.370252387864249, 20.015239681516373, 44.40497486931937, 23.845380306243896, 41.93718317576817, 116.22157287597656, 127.9333313533238, 81.04988193511963, 34.4966630254473, 20.606692927224294, 48.17725958142962, 71.16099725450788, 79.31912040710449, 63.70601095472063, 1.3106204611914498, 0.02211917800429676, 0.06450437514909677, 0.008689447522296436, 0.029482031041490178, 0.026096716356862868, 0.02871595143473574, 0.07850797407861267, 0.024260239276502813, 0.02959149909604873, 0.055490006892276664, 0.05555000635130065, 0.08191533266965832, 0.02997848458055939, 0.05858835045780454, 0.03969749449087041, 0.04106725313301597, 0.024757154219384705, 0.025476231705397367, 0.11604346601026398, 0.013650916782873017, 0.013146917934396436, 0.0707775331767542, 0.03094592284677284, 0.0025710311019793153, 0.058792379152561934, 0.059751705532627444, 0.03694853199911969, 0.02835331517936928, 0.10645516230059521, 0.02183861904112356, 0.10289910276021276, 0.021981187730229328, 0.023175029383440102, 0.038270270717995505, 0.07753125684601919, 0.04866363926391516, 0.029624648924384798, 0.01312849231596504, 0.02313994912297598, 0.013322416776125985, 0.02718370401167444, 0.039008866263819594, 0.031110359023192098, 0.08717771779213633, 0.09788923444492476, 0.08008046541363001, 0.22843532796416963, 0.329441670860563, 16.59073315347944, 129.21416228158134, 112.3164073399135, 117.53368459429059, 91.02207551683698, 72.77816963195801, 39.77278109959194, 41.67993654523577, 25.656011377062114, 76.59152862003872, 79.19331632341657, 56.54809488568987, 36.757113524845664, 2.462076800210135, 0.2886080305491175, 0.09472161584666797, 0.30698129321847645, 0.11702294488038335, 0.15484281762370042, 0.09270449408463069, 0.34055707869785173, 1.0453230398041862, 1.5539795969213759, 84.28757572174072, 105.99779891967773, 96.60829516819545, 88.08207035064697, 79.8718843460083, 73.47105094364711, 80.02425139290946, 84.6469851902553, 83.04490430014474, 77.9452600479126, 76.84783376966203, 75.18296200888497, 70.91428756713867, 73.20322568075997, 72.96634074619838, 75.71977983202252, 74.01504625592912, 72.38437352861676, 66.763795035226, 63.428847312927246, 63.54643862588065, 65.7871423448835, 63.85418823787144, 64.3092952455793, 63.685124669756206, 63.89501585279192, 72.78519426073346, 83.68898841312954, 81.89280264718192, 80.25698825291225, 66.29240839821952, 64.30645343235561, 75.7836685180664, 87.71592807769775, 79.83551052638462, 79.57076331547329, 83.48125117165702, 77.25938252040318, 71.18293966565813, 78.23610469273159, 75.3457999910627, 93.35833086286272, 57.57946463993618, 45.1345739364624, 83.28694479806083, 71.95880331311906, 77.48792961665562, 76.47596618107387, 87.65999507904053, 81.3970000403268, 84.3789792742048, 80.51669107164655, 80.04761818477085, 69.36759771619523, 84.97538484845842, 82.10504926953996, 85.25027642931256, 85.44483988625663, 77.4827184677124, 64.69810254233224, 65.33343887329102, 63.61428083692278, 68.37436662401471, 62.84340599605015, 70.83138860974992, 76.77949128832135, 83.91545799800328, 82.60512501852853, 76.55758666992188, 79.87784590039934, 81.12157344818115, 84.28100272587368, 84.4301666532244, 79.7991714477539, 81.44128090994698, 79.37786047799247, 80.6267157963344, 79.52969251360211, 86.45628915514264, 48.595092977796284, 0.5050724265830857, 0.5588743910193443, 0.8280176946095058, 0.7257204524108342, 0.23704118760568754, 0.16755036717014654, 0.08220552174108368, 0.133674682783229, 0.0729752266779542, 0.13760489331824438, 3.710974242006029, 26.541043383734568, 44.331956250326975, 36.30861077989851, 55.19362347466605, 89.3805844443185, 99.53939969199044, 34.91768911906651, 34.702816077641074, 37.91763292040144, 56.603847231183735, 78.0420970916748, 86.48394298553467, 86.73280661446708, 3.942945497376578, 0.3811020159295627, 0.0609593146613666, 0.06933579553983041, 0.06314613803156785, 0.03858034086546727, 0.05226063821464777, 0.15555905204798492, 0.05006344343668648, 0.06172750451202903, 0.04415777997512903, 0.06811391681964908, 0.07571038098207541, 0.04296101722866297, 0.05911066635910954, 0.10980093026799814, 0.024557094954486405, 0.033618536578225236, 0.058285615273884366, 0.062455966137349606, 0.00924590730573982, 0.042228481000555415, 0.05646881740540266, 0.03504695796540805, 0.022626289632171392, 0.03899220144376159, 0.052091286052018404, 0.10163794364780188, 0.08821576780506543, 0.15606373282415525, 0.15151031501591206, 0.17304384096392564, 0.18822184151836804, 0.11591716350189277, 0.10905648235763822, 0.210739758930036, 0.10845231477703367, 0.0903534245278154, 0.13581315374800138, 0.1427327317318746, 0.08317750958459717, 0.1989399671022381, 0.18740654098136084, 0.09293829011065619, 0.19823217365358556, 0.19289222519312585, 0.2653728201985359, 0.32442840987018173, 0.49734364130667275, 19.219092505318777, 146.66682815551758, 121.97512599400112, 133.7303524017334, 98.2757099696568, 82.24526391710553, 31.84359414236886, 57.35527059010097, 86.78914260864258, 78.7658006123134, 78.49591173444475, 89.58176258632115, 47.06631905691964, 4.4435527835573465, 0.42939359747937744, 0.6099830056939806, 0.5167641820652145, 0.3208463692239353, 0.42890868921365055, 0.2999025987727301, 3.319572010210582, 11.61480244568416, 1.849104983466012, 86.48031602587018, 109.14222008841378, 103.39984662192208, 91.0581922531128, 85.80842522212437, 77.22926902770996, 84.53763444083077, 89.10870143345424, 88.36168670654297, 83.6063812800816, 80.93320083618164, 78.29772826603481, 74.03648839678083, 77.27155576433454, 78.99891962323869, 78.77836990356445, 78.6094661440168, 76.68644101279122, 70.33939361572266, 67.93534469604492, 67.82518795558384, 68.4591485432216, 69.01243359701974, 66.61167117527553, 65.96926157815116, 68.50877952575684, 78.13418851579938, 88.23755713871547, 86.38340950012207, 83.98406451089042, 70.96016652243478, 68.90721007755825, 80.55573299952916, 92.29351942879813, 82.53078624180385, 81.13196100507463, 88.20888887132917, 80.1607140132359, 75.23613657270158, 80.8238639831543, 79.33107825687954, 98.32357610974992, 63.702634130205425, 50.420964922223774, 83.32953030722481, 73.83501148223877, 80.18389320373535, 80.56828144618443, 91.09635870797294, 86.2530335017613, 89.4862595966884, 85.18434497288295, 82.87839766911098, 74.60489967891148, 91.01686436789376, 85.5961924961635, 86.57982117789132, 90.22751426696777, 80.4264200755528, 68.6290111541748, 68.99903747013637, 66.79658358437675, 72.05130468096051, 65.88987840924943, 75.72055108206612, 79.77892439705985, 85.73217569078717, 88.15877151489258, 78.9225102833339, 83.18971170697893, 83.48086902073452, 90.10557338169643, 89.77622182028634, 83.48258522578648, 85.5235629762922, 83.1932622364589, 85.39085933140346, 81.83106095450265, 90.15651062556675, 47.611492088862825, 1.277869041476931, 5.610877505370548, 3.49021629350526, 1.8370602812085832, 0.6530335556183542, 0.23289702140859195, 0.14750801692051546, 0.2696531819445746, 0.18356026522815228, 0.49319616385868614, 8.206823945045471, 34.78746945517403, 63.71942792619978, 35.82731948580061, 52.365234170641216, 142.1977607182094, 155.83929797581263, 110.27948038918632, 47.27541814531599, 36.434807436806814, 64.09646497453961, 92.54030554635185, 95.04523536137172, 94.84406416756767, 4.763184683663504, 0.5246122809393066, 0.1941904662443059, 0.24372863875968115, 0.15111590975097247, 0.12260454680238451, 0.14241209679416247, 0.20124185644090176, 0.14341536510203565, 0.14383693890912191, 0.1346337784613882, 0.135432400607637, 0.21702356317213603, 0.10710189438291959, 0.1449458822607994, 0.1172497384250164, 0.1333324568612235, 0.11277071519621781, 0.0858812341466546, 0.23958637246063777, 0.19787985113050255, 0.17167123247470173, 0.16620218594159397, 0.1536630623574768, 0.12911868654191494, 0.1334673496229308, 0.11323843616992235], [0.06323915161192417, 0.06214232689567974, 0.02326377497852913, 0.03504050509738071, 0.03136372060648032, 0.017831389692478945, 0.05031031143984624, 0.039934981747397354, 0.012265388138725289, 0.05233854082013879, 0.0598161867154496, 0.057074355626744885, 0.03881666443443724, 0.021989552370671715, 0.055281791636454206, 0.08660473568098885, 0.04008163691365293, 0.016217003909072707, 0.030110269651881287, 0.026928980269336274, 0.061694195227963586, 0.2145640772900411, 53.98585285459246, 108.46071297781808, 115.27872317177909, 78.54815523965019, 77.40673296792167, 56.18116399220058, 25.89301095690046, 47.16613687787737, 86.8983404976981, 29.939714772360666, 44.29708324159895, 28.979668276650564, 3.5207405984401703, 0.1545124389231205, 0.03075511540685381, 0.16062453309340136, 0.04327635959322963, 0.11231879730309759, 0.08008254851613726, 0.07828111946582794, 0.4475645752889769, 1.7076407458101, 24.945203713008336, 109.44143036433628, 90.93977410452706, 94.78610229492188, 74.45167105538505, 72.94520432608468, 71.75993892124721, 75.41333648136684, 72.42330428532192, 78.43678256443569, 76.021470614842, 74.07817758832658, 70.3659496307373, 73.42811802455357, 71.80969497135708, 75.98975903647286, 72.01403454371861, 72.26799815041679, 65.65523079463414, 60.953308377947124, 58.292884826660156, 62.23516069139753, 60.218821253095356, 60.18463611602783, 61.056322370256694, 58.534258297511506, 58.96861103602818, 67.51488835471017, 74.22857829502651, 71.24502876826695, 65.42073604038784, 59.31643090929304, 59.64740834917341, 73.91612475258964, 79.96323231288365, 79.34717723301479, 77.00286892482212, 75.96665627615792, 77.07434504372733, 65.79049137660435, 69.25131961277553, 66.19732230050224, 84.74739360809326, 63.90783527919224, 41.407129423958914, 77.93405260358537, 68.49515410831997, 77.6307428904942, 69.65547548021588, 77.70494270324707, 79.0770104272025, 80.39073412758964, 79.89369474138532, 77.74529784066337, 72.27767004285539, 69.92070211683, 79.42833914075578, 81.05694825308663, 78.86456230708531, 70.51787894112724, 61.849605151585166, 61.27276570456368, 62.24187959943499, 60.77721323285784, 61.42922524043492, 73.13778059823173, 75.22901466914585, 83.95541708809989, 78.16728278568813, 69.20997783115932, 78.00334698813302, 78.48179299490792, 79.04812676565987, 77.41145774296352, 79.49134540557861, 76.64658614567348, 78.31545312064034, 78.37127494812012, 81.95733056749616, 78.75931794302804, 84.4962718146188, 37.46517317635672, 0.5771180263587407, 1.6356767330850874, 0.3887459843286446, 0.19837705445076736, 0.2547326854297093, 0.20731520626161778, 0.09461108249213014, 0.09217071094151054, 0.030293467321566174, 0.08786177608583655, 0.9050956900630678, 23.987347636904033, 29.356941563742502, 56.95992156437465, 96.27672018323625, 103.88236427307129, 133.0274726322719, 42.61153711591448, 29.85895586013794, 40.70419406890869, 65.23625441959926, 71.2509069442749, 84.9705627986363, 17.627866438456945, 1.1265230540718352, 0.12470314704946109, 0.12331037249948297, 0.11405675618776254, 0.10174513861004796, 0.0784681983558195, 0.06263752175228936, 0.023299124956663166, 0.035936541123581786, 0.042939741763153245, 0.050377506762742996, 0.012514792166517248, 0.04152338133592691, 0.010636273056401737, 0.0920468783006072, 0.012186106410808861, 0.11628955709082739, 0.060300999986273904, 0.0706985109884824, 0.06177829285817487, 0.044960799028298686, 0.06817189085164241, 0.059028360061347485, 0.05302663300452488, 0.060158168364848406, 0.08574390544423036, 0.025642340470637594, 0.007368518804599131, 0.019370030611753464, 0.04218410141766071, 0.010411341242226107, 0.030025547769452845, 0.01923339062237314, 0.038341920623289685, 0.032540887261607816, 0.03300478808315737, 0.07068969681859016, 0.013598622937154557, 0.04686804900744131, 0.023204508337325284, 0.0580879987350532, 0.016553642095199654, 0.044298677771751366, 0.017107547194297825, 0.09501989984086581, 0.05375739147088357, 0.0793117123789021, 0.19522722704069956, 75.88639068603516, 121.35348456246513, 127.14964403424943, 91.32946382250104, 91.3013722555978, 75.21490287780762, 35.65508753912789, 27.940860475812638, 73.09757832118443, 32.78691632407052, 40.22633865901402, 40.962138993399485, 3.8893866113254, 0.19661512970924377, 0.0520896304265729, 0.12054319812783174, 0.08643675076642207, 0.293043315410614, 0.06778970600238868, 0.11255241012466805, 0.46235913570438114, 0.9365438882793699, 30.08380651473999, 111.10623264312744, 93.85426548549107, 98.41757828848702, 78.03016703469413, 77.21219035557338, 75.19344684055874, 77.19264507293701, 77.27483531406948, 80.58880642482212, 78.11831188201904, 75.85441507611955, 74.02049364362443, 76.87175641741071, 74.74340506962368, 76.38395813533238, 74.8934097290039, 75.72385147639683, 69.60786642347063, 64.28474725995744, 60.676631110055105, 63.863436290196006, 62.31687150682722, 63.48281397138323, 64.81654153551374, 61.69395855494908, 62.58157702854702, 70.71455465044293, 76.10944175720215, 74.71156842367989, 69.68344892774309, 62.49928951263428, 63.12525967189244, 77.83085795811245, 83.74286474500383, 83.25926317487443, 81.0014043535505, 79.3477817262922, 79.85392325265067, 69.78088351658413, 71.47555610111782, 68.32074042728969, 88.87829221997941, 69.90529101235526, 42.78863974979946, 77.73551477704729, 70.3718694959368, 79.13228334699357, 73.26541205814907, 81.30332442692348, 81.72239112854004, 84.0881346293858, 84.26564025878906, 79.82620688847133, 75.14923545292446, 72.35878331320626, 83.02582454681396, 84.58533382415771, 82.08819988795689, 73.2858258656093, 64.29617009844098, 64.94985662187848, 65.04111426217216, 62.99104131971087, 63.753494943891255, 76.79754965645927, 77.99589157104492, 84.79648957933698, 79.58102580479213, 71.04066835130963, 78.12658718654087, 82.7099802834647, 82.09241049630302, 81.85821451459611, 82.75724193028041, 79.47189739772251, 81.42725944519043, 81.842928477696, 85.48894010271344, 81.7929778780256, 88.68532684871128, 47.3316707611084, 0.5577660990612847, 0.45788297589336124, 0.8546409117324012, 0.22805133142641612, 0.5362278233681406, 0.1346621819372688, 0.10746223718992301, 0.06904802883842162, 0.11004086703594242, 0.10729649822626795, 0.4758446663618088, 28.309594426836284, 28.54448175430298, 51.218739713941304, 100.06412070138114, 102.00635760171073, 114.54896082196916, 30.84720856802804, 30.59159129006522, 44.98321090425764, 75.09738104684013, 77.82041481563023, 97.94278703417096, 30.71579381397792, 1.1888719541685921, 0.25393909801329884, 0.18227248718695982, 0.18475310264953546, 0.08321915806404181, 0.07624683076781885, 0.036712975174720795, 0.01241994314893548, 0.08379825377570731, 0.023046894830518534, 0.009690560633316636, 0.0314875837814595, 0.02508072551739003, 0.011974853014440408, 0.06789628349776779, 0.003639771677886269, 0.10280350396143538, 0.013663977733813226, 0.04315054902274694, 0.0326078145631722, 0.04316012993721025, 0.02129700730022575, 0.04982661096645253, 0.0047284136858901805, 0.024983691617048213, 0.003969973111192563, 0.14135118015110493, 0.19889394885727338, 0.1157201983566795, 0.15023004157202585, 0.1357970181852579, 0.17411351070872375, 0.1369314066001347, 0.16775871813297272, 0.13400051529918397, 0.17578337181891712, 0.1665120864553111, 0.11662218852766923, 0.13502945937216282, 0.15863409132829734, 0.23102830882583344, 0.16859852735485348, 0.11574256287089416, 0.09233524889818259, 0.16710323973425797, 0.06212138051965407, 0.11969664426786558, 0.3472735711506435, 94.4660335268293, 137.19940730503626, 138.72282763889856, 103.19841139657157, 99.88857446398053, 75.34566102709088, 37.382760592869346, 68.59993989127022, 119.10602024623326, 51.05404308864048, 65.76881994519914, 46.934233801705496, 6.865268800939832, 0.5885101950594357, 0.3059160203805992, 0.3807879627815315, 0.3649553523531982, 0.6959471500345639, 0.27250506462795393, 0.5333659797906876, 2.4206792158739905, 3.457455102886472, 29.33072601045881, 113.93497630528041, 99.98480701446533, 101.95529529026577, 81.35690198625836, 79.19565786634172, 80.56274373190743, 82.39620658329555, 80.94320624215263, 85.60253620147705, 83.31842013767788, 81.11151245662144, 78.79079328264508, 81.75638171604702, 78.55346366337368, 81.16750104086739, 80.71058750152588, 78.40561294555664, 74.77869497026715, 67.69195624760219, 64.30551542554582, 68.2770779473441, 66.32883085523332, 66.88581929888043, 69.3381095613752, 63.82949434007917, 65.95202309744698, 73.93251555306571, 80.42820576259068, 77.54000636509487, 72.2523091179984, 63.839777673993794, 67.67941474914551, 81.47511863708496, 91.33455685206822, 83.36808586120605, 82.09063870566231, 84.01018278939384, 84.17935058048793, 74.08096381596157, 76.23696899414062, 72.22316142490932, 91.43889100211007, 74.35998957497733, 47.069883482796804, 77.81207697732108, 73.10287979670933, 80.44584029061454, 75.5597002846854, 86.10518973214286, 85.771043913705, 86.67271859305245, 86.91225773947579, 83.23160239628383, 79.45310946873256, 75.55214759281704, 87.80058492933, 88.42108685629708, 86.92868328094482, 76.5415015901838, 68.87585285731724, 66.67300987243652, 68.33916010175432, 66.36017417907715, 67.66011960165841, 82.01865536825997, 82.6151373726981, 90.46469102587018, 81.00110558101109, 69.84487642560686, 82.50412600381034, 87.72133377620152, 86.3896837234497, 86.20133890424455, 85.9918646131243, 82.26467718396867, 84.723158291408, 84.73805522918701, 89.99487468174526, 86.00640719277519, 91.56367370060512, 46.51361417770386, 1.2217629892485482, 5.050396723406656, 2.122194375310625, 0.571865622486387, 1.061288588813373, 0.4278453162738255, 0.2516311290008681, 0.23255949094891548, 0.19331036561301776, 0.4548215073134218, 2.5434929685933247, 36.920531681605745, 51.94792536326817, 63.722881180899485, 100.08987072535923, 101.62848676953996, 162.9188175201416, 63.446280343191965, 42.875238622937886, 53.66746555055891, 89.77672903878349, 84.9615787778582, 112.34297725132534, 31.765749999455043, 1.2880914700882775, 0.22394711737121853, 0.2452009240431445, 0.22731106329177106, 0.1541919939752136, 0.20031299628317356, 0.12703421339392662, 0.1381850271884884, 0.19500857591629028, 0.12706282043031283, 0.12842370383441448, 0.06224205797272069, 0.2042515120868172, 0.1011957898736, 0.12182246733989034, 0.1391625925898552, 0.183997974597982, 0.07708820740559272, 0.13490238333387033, 0.0920891035348177, 0.17925380702529634, 0.26339119938867434, 0.20060022015656742, 0.22259909899107047, 0.09325926431587764, 0.12722158405397618], [0.03263077958087836, 0.015890258763517653, 0.043068632882620604, 0.07607621992272989, 0.028041938851986612, 0.10832483840308019, 0.02215161876353834, 0.05432939649160419, 0.04411646058516843, 0.017161551796432053, 0.010725144180469215, 0.01850793999619782, 0.05099477346188255, 0.07567384865667139, 0.041090180831296105, 0.09463807461517197, 0.03248666552826762, 0.039943514325256856, 0.1229924245604447, 0.1016409902700356, 0.3331796388540949, 14.027312534196035, 95.51254340580532, 102.20754269191197, 91.15408434186662, 79.9645663670131, 137.1068434034075, 69.73131506783622, 58.32569422040667, 77.91670989990234, 25.762292759759085, 70.56953879765102, 42.81724200929914, 6.367789941174643, 0.2911601636026587, 0.14829366547720774, 0.0451255575088518, 0.09764815095279898, 0.09778279944189958, 0.04435979002820594, 0.15480750666132995, 0.05589931278622576, 0.22924123757651874, 4.64352193900517, 88.89521803174699, 97.82320853642055, 95.90333788735526, 87.8191227231707, 79.9067781993321, 69.46476827348981, 67.76451628548759, 68.07061917441231, 76.94303103855678, 75.59510830470494, 77.16399765014648, 75.18518543243408, 74.06554576328823, 71.78978838239397, 76.07282475062779, 73.68307522365025, 70.40495681762695, 69.79200063432965, 64.15997150966099, 60.780930519104004, 61.26631777627127, 58.243087087358745, 62.79270499093192, 60.75517354692732, 60.987472670418875, 60.57365185873849, 59.725547790527344, 63.445912088666645, 69.47828251974923, 66.39891038622174, 63.874497822352815, 56.46378544398716, 70.53884860447475, 73.8936264855521, 84.52583639962333, 77.25998701368059, 72.72755200522286, 80.82357215881348, 74.9015530177525, 67.33151844569615, 63.10308102199009, 65.3213142667498, 78.69374084472656, 70.68587248665946, 41.76291193280901, 74.66028376988002, 72.08491311754499, 75.73412091391427, 74.3258808680943, 72.1074252809797, 70.56544630868095, 77.08383628300258, 77.70590850285122, 78.0889001573835, 76.79338073730469, 71.43107373373849, 65.40979262760708, 73.45347200121198, 74.3805353982108, 65.00616482325962, 60.76981340135847, 61.60780784061977, 60.59699085780552, 60.509193420410156, 62.926381383623394, 71.65873840876988, 77.7931570325579, 79.83396802629743, 73.07597637176514, 75.26037188938686, 77.35787323543003, 77.85052136012486, 78.52125876290458, 77.85999870300293, 76.84251839773995, 74.49656336648124, 75.78525965554374, 79.41681902749198, 74.72989082336426, 78.76436233520508, 77.95213181631905, 88.29608876364571, 36.5213611466544, 0.3161524539547307, 0.5008864626288414, 0.24802406398313387, 0.09080432461840765, 0.051910286835793934, 0.03158158463026796, 0.01938624250968652, 0.08583828966532435, 0.04459499740707023, 0.088181949619736, 0.12341580327068057, 22.479472160339355, 63.43077196393694, 79.95524188450405, 96.28263310023716, 65.9565463747297, 82.37563296726772, 54.29151105880737, 44.17187670298985, 67.54717663356236, 73.88752596718925, 72.66425391605922, 57.53847026824951, 1.0293374061584473, 0.054183562352721176, 0.02539983205497265, 0.006119744652616126, 0.05679062281602195, 0.0282855295310063, 0.03214302146807313, 0.07887225917407445, 0.057449714413711, 0.03972831355141742, 0.012027967887531434, 0.031335123748119385, 0.03359899476968816, 0.03907832110832844, 0.07065581756510905, 0.08614339972180979, 0.12700156228882925, 0.018715782057760016, 0.05048717498513205, 0.07367281495992627, 0.041387928782829216, 0.03922036223645721, 0.01347205410378852, 0.05457744175302131, 0.015852542394506078, 0.07470665127038956, 0.06446213634418589, 0.06258387677371502, 0.02748574878621314, 0.07806394076240913, 0.045169387478381395, 0.06941993388214282, 0.10530711497579302, 0.043659816695643325, 0.03698087437078357, 0.023664919792541435, 0.032432230056396553, 0.08849247438567025, 0.03834933361836842, 0.06730485201946326, 0.027011844662151167, 0.09432280688945736, 0.06219176495713847, 0.12292461177068097, 0.12691149355045386, 0.18551536888948508, 0.5460294517023223, 22.747816801071167, 119.08649580819267, 112.82724584851945, 102.99296011243547, 86.77564225878034, 129.09637641906738, 73.68059471675328, 44.96061188834054, 58.739049502781455, 34.729889733450754, 50.35312965938023, 55.440673623766216, 7.244930965559823, 0.3191937021911144, 0.14083203300833702, 0.18137384897896222, 0.061837590033454556, 0.1604254509189299, 0.03979092876293829, 0.24211098413382257, 0.22006103875381605, 0.3750600687095097, 7.779860615730286, 96.35679122379848, 96.90011950901577, 100.71932888031006, 90.88316018240792, 83.96381746019635, 73.24434512002128, 70.0135578427996, 70.78828198569161, 80.77430943080357, 77.42226219177246, 79.5885784966605, 77.9091294152396, 76.35694353921073, 75.25038037981305, 78.31321580069405, 77.67877578735352, 75.09995188031877, 74.34562764848981, 69.4303399494716, 62.87271349770682, 64.63936247144426, 62.532439368111746, 64.37008503505162, 64.04231766292027, 63.934849875313894, 63.61833163670131, 63.93647575378418, 66.66487353188651, 70.54854828970772, 67.90410559517997, 65.96473135266984, 59.268807956150596, 72.09264646257672, 77.99292469024658, 87.22861616952079, 81.08574158804757, 73.71280656542096, 81.6971413748605, 78.3717543738229, 70.19554506029401, 66.16818155561174, 69.07546765463692, 82.04811573028564, 76.58271135602678, 43.6200716154916, 74.31133828844342, 73.174161366054, 77.13968590327671, 75.53622926984514, 75.79659911564418, 74.09289387294224, 78.66412762233189, 78.68104648590088, 82.14042254856655, 81.46258408682687, 72.89547606876918, 68.56232929229736, 75.54673494611467, 77.08342633928571, 68.22345869881767, 63.30090318407331, 63.89299392700195, 62.5459258215768, 63.40466063363211, 64.86408805847168, 75.47789219447544, 82.69871725354875, 80.03921086447579, 73.86602824074882, 80.24184117998395, 81.47157505580357, 79.68506118229458, 80.67287267957414, 81.43314456939697, 79.21132605416435, 78.95408984592983, 79.9098562513079, 81.77267524174282, 77.46183913094657, 82.0131801877703, 81.28637082236153, 92.90084757123674, 46.966390064784456, 0.7238687032035419, 0.692028094615255, 0.3345555450235094, 0.08941549914223806, 0.29824230500629967, 0.06505371710019452, 0.037285767296063047, 0.1772776823490858, 0.07334213770393815, 0.1498277245887688, 0.07004224548914603, 20.269159861973353, 56.0977578163147, 82.33399936131069, 97.74601405007499, 74.43583611079625, 59.98011589050293, 55.33596427100045, 52.2913817678179, 73.93864386422294, 81.11554936000279, 79.45640291486467, 79.70544024876186, 3.000832519360951, 0.22485464438796043, 0.03895222894581301, 0.08959978925330297, 0.05473883809255702, 0.046277570870837996, 0.0868875558621117, 0.07890326822442667, 0.0697463635089142, 0.06428639577435595, 0.03563531907275319, 0.029515689771090235, 0.023121406457253864, 0.0177534463748868, 0.023748593338366066, 0.06983975028353077, 0.03172382253355213, 0.05308898358738848, 0.04168351220765284, 0.08300609128283602, 0.01830143464862236, 0.0190706253384373, 0.047152765693941286, 0.10249506908335856, 0.0610540449353201, 0.0182413961738348, 0.1324047909251281, 0.1816281231918505, 0.14824383386543818, 0.16897480216409477, 0.13362343981862068, 0.18110688616122517, 0.19464505756539957, 0.11573188272970063, 0.1268403966511999, 0.11848209372588567, 0.0696535874158144, 0.2558835351041385, 0.16318791625755175, 0.09962492702262742, 0.13378662749060563, 0.28390572858708246, 0.1475773360580206, 0.21461624306227478, 0.22446646807449205, 0.31452383420297075, 0.5897677104387964, 26.484050784792217, 135.22782816205705, 123.82152639116559, 121.32184246608189, 98.98753901890346, 150.09852954319544, 80.22271278926304, 85.44348498753139, 101.58025932312012, 45.10100718906948, 98.69596481323242, 69.72331769125802, 12.730238454682485, 0.5422312297991344, 0.24821266957691737, 0.45873868997607914, 0.3605543470808438, 0.6420092614633697, 0.16274658351072244, 0.5433070063591003, 0.8780903220176697, 0.8032794477684158, 8.062257988112313, 98.44544056483677, 102.24943338121686, 102.65116432734898, 94.92776911599296, 87.87072699410575, 75.99806213378906, 72.84574781145368, 75.05841554914201, 84.89527211870465, 81.43527071816581, 83.52246788569859, 82.7553381238665, 80.9307689666748, 78.23703575134277, 83.35494681767055, 83.8650210244315, 79.92970030648368, 78.86158847808838, 72.18409170423234, 66.94979136330741, 68.26992130279541, 66.39670780726841, 67.26996435437883, 66.11777237483433, 68.58808626447404, 67.59796796526227, 68.00077588217599, 70.57409681592668, 74.94076170240129, 72.41323634556362, 70.54138469696045, 62.19613265991211, 75.0286147253854, 82.4930783680507, 90.65965053013393, 81.7329523903983, 76.82114573887416, 86.59014620099748, 82.53417001451764, 74.08393069675991, 68.24651282174247, 73.369218145098, 85.97249998365129, 82.18546077183315, 49.658768381391255, 74.90948786054338, 76.23922715868268, 77.8614786693028, 81.54630987984794, 78.50167179107666, 78.05384649549211, 82.7540249143328, 82.34283052171979, 85.50384398869106, 85.8922552381243, 77.43888228280204, 73.76623126438686, 79.43580150604248, 81.79511097499302, 72.63269519805908, 67.77138805389404, 67.59211758204869, 66.36672633034843, 67.52342074257987, 70.40341431753976, 78.32561138698033, 85.85424859183175, 85.3989748273577, 75.78802503858293, 81.93106637682233, 85.25668961661202, 83.28094850267682, 85.14588669368199, 84.27597223009381, 84.15344074794224, 82.94567012786865, 82.90927546364921, 87.7125026157924, 81.13140514918736, 85.23404543740409, 85.39868300301688, 96.3988903590611, 46.13617065974644, 0.5197688436933926, 1.9964767098426819, 0.7323423570820263, 0.5369051098823547, 0.5737545554127012, 0.3296852649322578, 0.13021928391286305, 0.6352015467626708, 0.1832303207899843, 0.28250642653022495, 0.2356582246720791, 36.56196641921997, 84.5569156919207, 86.31426102774483, 98.09113107408795, 75.08410998753139, 103.25281579153878, 69.24565683092389, 59.916011810302734, 82.83120550428117, 92.21141256604875, 90.95321192060197, 87.29622214181083, 3.1361248024872372, 0.2736546929393496, 0.1152483451047114, 0.15939723966377123, 0.22970017152173178, 0.12161285430192947, 0.13926677485661848, 0.25592272728681564, 0.14309854353112833, 0.18643059049333843, 0.0853945209777781, 0.1821201289338725, 0.11601867234068257, 0.1416123482797827, 0.1779383040432419, 0.1641483690057482, 0.24642752536705562, 0.13526548099304947, 0.152462489636881, 0.20569779590836593, 0.10092426051518746, 0.17315398076815264, 0.269627397613866, 0.24949518218636513, 0.12276283545153481, 0.12861525427017892], [0.11807527127010481, 0.03575341809274895, 0.03569336095824838, 0.06504567646022354, 0.010192601060095643, 0.05268608645669051, 0.05490638195936169, 0.019417628146974102, 0.043184737009661536, 0.05257904416482363, 0.07033183744975499, 0.012020932327556823, 0.06096755207649299, 0.01696189965254494, 0.053832681716552803, 0.06292424350976944, 0.03187443016629134, 0.029396257429782833, 0.08937603554555348, 0.029804362316748927, 0.1091361152274268, 52.90029409953526, 111.2231638772147, 94.06651210784912, 95.67409597124372, 80.6340114048549, 111.94029440198625, 78.52306529453823, 101.81735965183803, 65.39310305459159, 55.23059136526925, 51.04036208561489, 7.118920172963824, 0.1801141622875418, 0.06755877339414187, 0.11709725803562573, 0.038480039819010665, 0.1088047187243189, 0.07306687640292303, 0.08773004529731614, 0.2967916242778301, 0.22120259249848978, 0.39541459935052053, 50.76159340994698, 102.4687602179391, 91.04918738773891, 95.22237968444824, 85.07130473000663, 83.5463557924543, 69.27485316140312, 64.5075273513794, 63.84421757289341, 68.95292227608817, 72.12608119419643, 77.16545677185059, 74.65002822875977, 78.06597110203334, 78.48883846827916, 76.31255149841309, 74.1102157320295, 74.42755385807583, 68.77252619607108, 61.44364970070975, 58.95308876037598, 60.19735131944929, 59.70318848746163, 59.168100765773225, 59.11542647225516, 61.34144169943673, 60.333494322640554, 60.39668124062674, 61.974262782505576, 61.401626995631624, 62.23306233542306, 57.61731147766113, 62.35715021405901, 72.68623801640102, 83.23881462642125, 78.8405840737479, 70.07570947919572, 75.97675200871059, 76.36982549939836, 75.89063603537423, 70.9776690346854, 64.12679386138916, 66.49412849971226, 75.73470456259591, 75.2451205934797, 40.88561848231724, 66.03811127798897, 72.7656559262957, 72.24386705671037, 74.68067673274449, 72.30175249917167, 74.05185781206403, 69.44158908299038, 70.90882628304618, 74.3672295979091, 76.97197028568813, 74.42970085144043, 67.44262014116559, 61.98203781672886, 65.12012917654855, 59.32357365744454, 62.22345297677176, 57.93574047088623, 59.717161314828054, 57.44695207050869, 65.43240901402065, 72.88772882734025, 78.91000352587018, 71.72917924608502, 74.91983372824532, 78.01918888092041, 76.22041143689836, 75.04892430986676, 73.47410815102714, 74.08591788155692, 77.69333921160016, 76.42764145987374, 76.26091943468366, 75.23104354313442, 74.37408052171979, 76.02675124577114, 77.40516962323869, 75.42587797982353, 79.5289421081543, 39.23890583855765, 0.4051198757120541, 0.2592460832425526, 0.1985876445791551, 0.0556704157830349, 0.054842087373669655, 0.04360413611201303, 0.043447842355817556, 0.38176567746060236, 0.1179236186934369, 0.044977555450584204, 0.09619069165949311, 10.44678246974945, 42.05888087408883, 63.04542487008231, 45.64692715236119, 47.11666570390974, 28.779435089656285, 22.775472368512833, 48.35860756465367, 68.17361232212612, 67.78606264931815, 80.62901565006801, 18.28222346305847, 1.072383993438312, 0.07715345533298594, 0.08889740372874907, 0.08123596305293695, 0.1016333092536245, 0.05212523315900138, 0.030701025987842252, 0.06362466806811945, 0.03581033700278827, 0.026061702253563062, 0.0403401485777327, 0.05303412063845566, 0.04967311277453389, 0.027455138375184367, 0.042077228759548495, 0.014878177982089775, 0.04499233055061527, 0.062227055563458374, 0.004675262341541904, 0.05574615725449153, 0.0590245874066438, 0.030422826630196402, 0.03805079856621368, 0.051774844460721524, 0.05953675242406981, 0.027886583170454417, 0.04781218638111438, 0.05422399625448244, 0.01743318632777248, 0.01557708771101066, 0.025878826888012033, 0.022828881529026797, 0.06991010757961444, 0.02922526660508343, 0.1024990181571671, 0.04649021356765713, 0.09874274328883205, 0.04770054701449616, 0.04070448117064578, 0.030430572107434273, 0.0348037472659988, 0.012359031060311412, 0.047340587579778264, 0.06159602478146553, 0.053675594074385505, 0.10893989647073404, 70.72966003417969, 122.6614134652274, 105.12481335231236, 107.16496426718575, 91.248642376491, 126.3135256086077, 59.597888537815635, 63.25231443132673, 77.62462152753557, 51.694670472826274, 56.20496504647391, 10.003341487475804, 0.24838018630232128, 0.02901241695508361, 0.10810658761433192, 0.033672246017626355, 0.023057440961045877, 0.20393740465598448, 0.041706684178539684, 0.6340516741786684, 0.18001751175948552, 0.6733357576387269, 60.22160053253174, 104.42396245683942, 92.69287409101213, 97.24545192718506, 89.52981090545654, 85.76830632346017, 73.69373376028878, 68.66107709067208, 68.52007034846714, 73.04509162902832, 75.30541706085205, 79.77941077096122, 79.46556064060756, 80.66176945822579, 82.15971074785504, 79.01294803619385, 79.10297584533691, 76.59936618804932, 71.86588505336216, 64.44281182970319, 62.11098248617989, 62.91646630423409, 61.945518084934776, 61.235210691179546, 61.85665757315499, 64.19082845960344, 62.8894864491054, 62.47173295702253, 65.35661111559186, 64.74459988730294, 64.16400841304234, 59.96696295057024, 66.42718260628837, 76.30360221862793, 85.57033130100795, 81.12695830208915, 73.18060234614781, 79.44936438969204, 79.6617430278233, 78.10190718514579, 73.65455286843437, 65.40457453046525, 69.25684343065534, 78.15412984575543, 79.33845029558454, 43.70335272380284, 68.3813009262085, 73.06866686684745, 74.97551659175328, 77.15950216565813, 76.73393195016044, 77.26415593283517, 74.73803411211286, 72.80020236968994, 76.55366788591657, 80.68018913269043, 78.18231173924038, 70.07347910744804, 64.21467467716762, 66.00316878727504, 61.62293406895229, 65.53358173370361, 60.48381859915597, 60.88757841927664, 61.80919442858015, 67.92350496564592, 77.6059934071132, 80.90059988839286, 72.02946649278913, 78.3280224118914, 83.19898060389927, 79.0323543548584, 79.39127050127301, 76.58435113089425, 79.7153205871582, 81.77656623295375, 77.91146400996617, 79.51413549695695, 79.58580616542271, 78.65310083116803, 79.13502788543701, 77.99781622205461, 79.77701364244733, 86.3580207824707, 49.00332743780953, 1.0428392759391238, 0.08769750954317194, 0.20701788578714642, 0.2702138418597834, 0.20911856235138007, 0.14617291784712247, 0.07512338712279286, 0.05407652684620448, 0.048675469521965296, 0.02497918444818684, 0.04824920703790017, 11.76182632786887, 45.89288643428257, 66.34274114881242, 56.65181759425572, 46.37721061706543, 29.328370571136475, 31.591756684439524, 57.31125375202724, 75.20194448743547, 75.62552056993756, 92.75022452218192, 36.8748368535723, 0.6939979631985936, 0.027618453272485306, 0.04704851896635123, 0.07728433116738286, 0.07859192243111984, 0.02334338240325451, 0.048415621143898795, 0.05584439555449145, 0.05776698381773063, 0.023069359428648437, 0.05615664379937308, 0.006882190280261317, 0.025900463673419187, 0.02871082170999476, 0.03492898108171565, 0.03635638466637049, 0.043015021830797195, 0.1068530755915812, 0.0791241517290473, 0.021494856237300804, 0.026294227722766142, 0.03854449725310717, 0.027094283274241855, 0.03869334069479789, 0.02120948476450784, 0.1653848226581301, 0.11970245252762522, 0.19444536470941134, 0.1337291012917246, 0.14968444513423101, 0.1944366523197719, 0.10619318671524525, 0.151473999821714, 0.1808102713631732, 0.14267779753676482, 0.12605187110602856, 0.14972127601504326, 0.14817792097372667, 0.1659474910369941, 0.1348684701536383, 0.10981454846582242, 0.15215968659945897, 0.14721317988421234, 0.15948398358055524, 0.17579800103391918, 0.3307538761624268, 84.93917083740234, 138.8758269718715, 116.00307287488664, 120.73105103628976, 98.44721930367606, 121.36546325683594, 91.02618885040283, 125.87130056108747, 85.6756590434483, 81.72752584729875, 71.98762444087437, 14.249178068978445, 0.6253361904195377, 0.1785237711987325, 0.5960217948470796, 0.12746836724025862, 0.38309283767427715, 0.5690316259860992, 0.38265808671712875, 1.3987469609294618, 1.0624394927706038, 1.317653340952737, 61.256340163094656, 110.31622246333531, 98.53967203412736, 104.59343596867153, 92.2647260938372, 90.51575333731515, 76.29189450400216, 71.43317903791154, 72.82050500597272, 77.21412890298026, 77.35536493573869, 83.93663610730852, 81.98270538875035, 86.31469876425606, 86.86302280426025, 83.04268087659563, 81.81598336356026, 83.08528723035539, 75.52168669019426, 68.35805920192173, 65.5312888281686, 65.65063108716691, 66.08371230534145, 64.93338244301933, 65.57403414590019, 67.1952156339373, 67.72747543879917, 64.60069574628557, 68.8361508505685, 66.85389927455357, 67.6728903906686, 63.493264062064036, 70.13522774832589, 82.32982349395752, 88.62615598951066, 83.07399640764508, 77.41020011901855, 81.67805467333112, 83.95704991476876, 82.65734767913818, 77.27204908643449, 70.67581844329834, 73.96143395560128, 82.67082718440464, 82.86264610290527, 48.9849841935294, 68.6671359198434, 76.19484901428223, 78.2902033669608, 80.0960054397583, 79.94538933890206, 80.19267572675432, 77.75459453037807, 78.49969155447823, 80.93646648951939, 81.77413436344692, 81.91532870701381, 72.80141135624477, 68.29033511025565, 70.3513514654977, 65.12877968379429, 69.06906141553605, 63.249340602329795, 63.431015150887625, 64.81742395673479, 72.60728563581193, 82.93856906890869, 84.6097081048148, 75.16401427132743, 79.95002378736223, 85.06144523620605, 81.9812810080392, 82.90004130772182, 80.76987648010254, 83.39790058135986, 85.27697140829903, 83.03521156311035, 83.42315033503941, 84.58112321581159, 82.02957793644497, 82.72134058816093, 81.82937949044364, 81.12673595973423, 88.83560943603516, 49.334548064640586, 1.0872231743165424, 0.6837659265313829, 1.1691188769681113, 0.8465547284909657, 0.6404199153184891, 0.3310372866690159, 0.29568827205470627, 0.8140723343406404, 0.3128537695322718, 0.07547524824206318, 0.2198597038430827, 17.858273914882115, 53.96171828678676, 70.71293572017125, 60.195169585091726, 63.99564661298479, 39.12628596169608, 33.78326368331909, 63.607047762189595, 89.42083535875592, 85.30563272748674, 109.51317746298653, 36.014434473855154, 1.0451335928269794, 0.15656176395714283, 0.11845526445124831, 0.24347000835197313, 0.22060681161071571, 0.1413851204727377, 0.11028515321335622, 0.1605474515152829, 0.20036425281848225, 0.06154227802263839, 0.15898481250873633, 0.12118467156376157, 0.15051461915884698, 0.11464298330247402, 0.11063100251236133, 0.10834796966186591, 0.11632982135883399, 0.20791002362966537, 0.21802942348378046, 0.1345660470958267, 0.19455811008810997, 0.12543504206197603, 0.13246952316590718, 0.09859107035611357, 0.17285281978547573], [0.07751280069351196, 0.04307360993698239, 0.04489007193062987, 0.01637950286801372, 0.06382945672209774, 0.03549626689138157, 0.05141660511227591, 0.04288592715082424, 0.05294769224045532, 0.04280855719532285, 0.03742950476173844, 0.07040198439998285, 0.04680897235604269, 0.03788490014682923, 0.039752974906670194, 0.049958562278853993, 0.051434674499822516, 0.12907388965998376, 0.14475230979067938, 0.2688604087701866, 3.468790654625211, 89.21346637180874, 93.4063776561192, 81.11145687103271, 48.436375277382986, 41.7829783303397, 23.801976646695817, 32.428997244153706, 88.42000988551548, 57.758922713143484, 48.57987642288208, 19.31667995452881, 0.11281186834509883, 0.03023243648931384, 0.020022623540301408, 0.08604381113712277, 0.08353838843426534, 0.017935672043157474, 0.2932124606200627, 0.3066918844623225, 0.5274998545646667, 0.8338355624250003, 24.72204147066389, 106.88228375571114, 90.9453535079956, 95.27243450709751, 81.36635848454067, 87.75297587258476, 76.5762425831386, 74.91051619393485, 63.445404870169504, 67.19962774004254, 65.44838292258126, 67.47645092010498, 70.46612875802177, 74.8440636226109, 75.64753941127232, 76.43914072854179, 74.0636419568743, 76.53993824550084, 70.70218685695103, 65.21517358507428, 58.48065294538225, 59.88300091879708, 59.61283411298479, 59.267272404261995, 59.551662172589985, 61.375467027936665, 60.75008051736014, 58.180779116494314, 59.23285797664097, 60.68335696629116, 61.20817525046212, 57.620521545410156, 58.30923393794468, 73.0879967553275, 80.86870070866176, 74.86714553833008, 66.73106901986259, 73.0822366986956, 75.54969487871442, 77.9328783580235, 68.86268602098737, 68.84800447736467, 60.144274030412944, 68.07652514321464, 70.31529031481061, 77.17234938485282, 40.127104486737935, 63.15936837877546, 73.47471959250313, 72.97382395608085, 74.26969078608921, 69.79554421561105, 72.1322581427438, 71.2912620816912, 69.60467720031738, 67.2121136529105, 77.96445792061942, 75.90071787152971, 69.38843536376953, 61.34893880571638, 62.977124077933176, 63.45791857583182, 61.459220613752095, 60.13073893955776, 59.69539955684117, 58.871572494506836, 63.51820114680699, 74.23123945508684, 74.60991627829415, 73.14395754677909, 75.5872220993042, 77.18294538770402, 74.74934577941895, 70.46108436584473, 74.64974335261753, 76.11786297389439, 74.29824788229806, 74.03851727076939, 73.71598189217704, 71.17086369650704, 80.5889731815883, 73.40044334956578, 73.22470951080322, 77.66876343318394, 76.12250437055314, 77.54701014927456, 29.649950572422572, 0.20811461550848825, 0.1779283567198685, 0.7900879670466695, 0.03524840483441949, 0.07044075589094843, 0.068673016104315, 0.026341374032199383, 0.045628229821366925, 0.0987929209534611, 0.05787073860743216, 0.07447863636272294, 17.552077225276403, 26.047662224088395, 31.810826437813894, 39.243095602308, 47.65967089789254, 29.552012239183696, 31.72231333596366, 60.59662955147879, 70.56726673671177, 71.42801652635846, 75.73239081246513, 6.158972689083644, 0.2521556908530848, 0.07847127890480415, 0.09982388706079551, 0.04926851252093911, 0.11824186518788338, 0.0623423590191773, 0.04009724661175694, 0.06921676014150892, 0.019533048649983745, 0.03117605478369764, 0.020047617377713323, 0.022424912312999368, 0.045321613417140076, 0.032011867434318574, 0.019492066831194928, 0.04053056586001601, 0.009190147842413612, 0.012236535981563585, 0.07564938746924911, 0.019823744926335554, 0.024999284351776754, 0.017561135979901468, 0.024707268324813673, 0.032287230515586476, 0.08918905843581472, 0.06443553777145487, 0.052031147493315597, 0.020016645646787116, 0.027217054007841007, 0.03196839030299868, 0.045117116533219814, 0.036926428720887215, 0.09160352351942233, 0.037104880038116655, 0.11233810840972833, 0.07358197269162961, 0.05603284847789577, 0.05975390398608787, 0.012931715464219451, 0.06018439374331917, 0.06538897446755852, 0.06093192220266376, 0.1515334259186472, 0.37021307594009806, 6.845515072345734, 109.78608185904366, 101.28216075897217, 92.29842485700334, 59.63160119737898, 63.813659395490376, 48.9114270891462, 38.310372897556846, 77.8096034186227, 59.860127449035645, 49.874527318137034, 24.466446774346487, 0.19483746295528753, 0.07026638596185616, 0.10417391399719886, 0.17351634560951165, 0.2689470441213676, 0.08156096775616918, 0.1875010473387582, 0.3402058689721993, 0.7239298256380218, 0.4655301741191319, 32.19884858812605, 116.95102255684989, 93.42687484196254, 99.5738627570016, 85.06325871603829, 90.6739638192313, 79.33111994607108, 78.97195366450718, 65.72287150791713, 70.46552426474435, 66.83311026436942, 69.10116209302629, 72.20084381103516, 78.43333625793457, 77.77883679526192, 80.9980136326381, 77.55101231166294, 79.95334502628872, 74.33805411202567, 67.4741302217756, 61.958587646484375, 63.775395665849956, 62.19875907897949, 62.55641760144915, 64.02982480185372, 64.6947465624128, 64.21880885532924, 61.061811447143555, 64.61662101745605, 63.86824444362095, 63.87173938751221, 60.11646039145333, 61.802941049848286, 77.80238424028668, 85.08076122828892, 81.45523984091622, 68.8064820425851, 76.15271513802665, 77.58441925048828, 79.52178546360561, 71.52087920052665, 71.2881075995309, 61.694521359034944, 70.08381107875279, 75.2601078578404, 82.2714238848005, 44.36151041303362, 65.62365123203823, 73.17794118608747, 75.29647472926548, 76.80099596296037, 72.04675361088344, 75.15325151171002, 72.24157415117536, 72.57194014957973, 70.86074474879673, 79.94616058894566, 78.09064415522984, 73.23515265328544, 64.95281655447823, 65.07156821659633, 65.28512110028947, 64.24902657100132, 61.97456850324358, 62.01519462040493, 62.41671712057931, 66.10183320726667, 77.78484698704311, 77.68112427847726, 74.67654950278146, 77.84018938882011, 80.13555458613804, 77.96410356249127, 74.71088055201939, 77.3082492010934, 78.50438853672573, 77.66920116969517, 78.92515754699707, 76.96370887756348, 78.16519832611084, 82.5615737097604, 74.64729063851493, 78.23559052603585, 79.86174692426408, 78.68500695909772, 81.44586672101701, 40.981715542929514, 0.3705346743975367, 0.14122360199689865, 0.7335739795650754, 0.10888570866414479, 0.41152432348046986, 0.0768702280308519, 0.05689606037256973, 0.06268104977373566, 0.11035276244261435, 0.11978972570172378, 0.14828658157161304, 20.69628299985613, 27.391766922814504, 33.77866397585188, 37.3073969568525, 39.3742949622018, 36.37134953907558, 45.47643572943551, 68.15006487710136, 78.29041181291852, 77.27095127105713, 96.02083887372697, 15.115512473242623, 0.5779384566204888, 0.23141265820179666, 0.05527237017772027, 0.10230631421187095, 0.062145977414080074, 0.05539797718769737, 0.11888267365949494, 0.05234648307253208, 0.032481973458613665, 0.004556719729277704, 0.044393021280744245, 0.023117923876270652, 0.0455620251595974, 0.021926784488771642, 0.03358503730435457, 0.03226761406819735, 0.052569565030613115, 0.03218092104153974, 0.009270223456301858, 0.03340180231524365, 0.051443312250609906, 0.03655556183574455, 0.06103691192609923, 0.012871214737450438, 0.17272696511021682, 0.13435321780187742, 0.17973233706184796, 0.13373797652976854, 0.12607306854001113, 0.11775732333106653, 0.10389727527009589, 0.10222318010138613, 0.14398917502590589, 0.11858808089579854, 0.20428452960082463, 0.16790153618369782, 0.08531290678573505, 0.15807060870741094, 0.13458909014506, 0.17249474328543457, 0.12420325673052243, 0.22486316678779467, 0.29257735184260775, 0.5123499589306968, 8.33777403831482, 127.74069949558803, 112.2035824911935, 108.55478463854108, 70.64058412824357, 65.55386352539062, 34.432534626552034, 45.89654466084072, 113.39958981105259, 72.76368958609444, 69.48794746398926, 33.485116481781006, 0.8081581688352993, 0.18359571189752646, 0.2994411678186485, 0.28432161627071245, 0.763539660189833, 0.21660501563123294, 0.7494639669145856, 0.460766749722617, 2.3250854653971533, 1.0203356891870499, 31.674745968409947, 119.3011256626674, 97.99588516780308, 103.61431666782924, 89.00333200182233, 96.22138472965786, 83.35866410391671, 83.33434540884835, 69.47460692269462, 75.75037275041852, 70.68025139399937, 74.20664978027344, 77.08095278058732, 81.48093427930559, 82.60346439906529, 85.00340693337577, 80.54226739065987, 85.70647430419922, 78.57686519622803, 71.63477407182965, 66.12495681217739, 65.97789818899972, 66.76537227630615, 66.34477002280099, 66.77884483337402, 65.36417075565883, 68.36790479932512, 65.53080940246582, 66.94576140812465, 67.29016276768276, 65.63965293339321, 64.571471623012, 64.98763397761753, 82.16892405918666, 87.01910713740757, 84.05408150809151, 72.30785301753453, 77.12298938206264, 81.68143844604492, 84.56678213391984, 74.01390675136021, 74.37160001482282, 64.39206218719482, 75.92005470820835, 79.02894973754883, 85.72865295410156, 50.16257183892386, 66.35147503444126, 75.1549607685634, 78.37227548871721, 80.05228737422398, 74.92580917903355, 78.1291024344308, 75.4934492111206, 77.1392412185669, 74.41669382367814, 85.70899650028774, 81.66082314082554, 77.96851566859654, 65.94781943729946, 67.81525203159877, 69.24559429713658, 66.59503023965019, 64.88614858899797, 65.91418320792062, 64.19632448468889, 70.63258675166539, 80.96571840558732, 79.48348004477364, 76.00288418361119, 81.51785005841936, 83.8684047971453, 82.47491577693394, 77.54844147818429, 80.64535781315395, 82.08187702723912, 83.2379252570016, 83.361054284232, 80.19824123382568, 81.99321106501988, 85.53990513937813, 79.38734476906913, 82.07749966212681, 82.43687438964844, 81.82429340907505, 82.08451734270368, 40.095907075064524, 0.38821667273129734, 0.6687412613204547, 1.9789692035743167, 0.16279310387160095, 0.27348712193114416, 0.35802753695419853, 0.10167792293110064, 0.1619993807481868, 0.2136022403304066, 0.26958413422107697, 0.38815788445728167, 32.2280136517116, 38.96299287251064, 47.802894115448, 55.098790986197336, 65.36456680297852, 41.370644433157786, 47.904678276606965, 76.07311657496861, 91.6941886629377, 87.65843868255615, 105.64180796486991, 12.788428749356951, 0.845644297344344, 0.30870349652000834, 0.21659280200089726, 0.2220195350902421, 0.21858689428440162, 0.17727388255298138, 0.23424814747912542, 0.16711062219526085, 0.09588598193866865, 0.14391744030373438, 0.10374261678329535, 0.13974070442574366, 0.11028859338590077, 0.11697765945323876, 0.19173232386154787, 0.1252338428582464, 0.08752071045871292, 0.11782000639608928, 0.13313186833901064, 0.07101784313895873, 0.12429521179624967, 0.11522224864789418, 0.17223711710955414, 0.17289604246616364], [0.0673468533371176, 0.0965444255354149, 0.06496151097651039, 0.048952691789184294, 0.03165548387914896, 0.061784698228750906, 0.035778194798954895, 0.014007855888589152, 0.0507518172131053, 0.05008721251838973, 0.07143547465758664, 0.07614256707685334, 0.04662993749869721, 0.02439203961486263, 0.038750232463436465, 0.031141683592328002, 0.0095213187326278, 0.06899899789797408, 0.1949022359081677, 0.46545477530785967, 19.205967358180455, 101.733446257455, 87.88622147696358, 81.4547117778233, 54.06028890609741, 30.40411846978324, 25.30402258464268, 23.565591982432775, 55.83244432721819, 59.48603643689837, 33.0573228427342, 0.7974217906594276, 0.24200041006718362, 0.18496399133333138, 0.05629250008080687, 0.30112187191843987, 0.4144005248589175, 0.22325953069542134, 0.23909679587398255, 0.634271465241909, 1.4861760352339064, 14.3079137972423, 98.78155272347587, 90.09779139927456, 92.1279855455671, 82.52318491254533, 82.7602505002703, 78.22163159506661, 76.31597696031842, 71.88520799364362, 70.39015020642961, 67.84473323822021, 62.49986621311733, 62.02552659170968, 63.57689952850342, 69.38735144478935, 73.29024491991315, 78.84763649531773, 78.6021010535104, 71.97818183898926, 66.54200853620256, 58.66381440843855, 56.10035991668701, 57.09226737703596, 59.48315988268171, 58.79853997911726, 57.35542345046997, 58.529603004455566, 56.9525008882795, 58.11242273875645, 59.61086082458496, 64.77764551980155, 58.85544572557722, 57.3474816594805, 68.71760763440813, 78.61799158368791, 75.73623316628593, 65.25407654898507, 69.87230096544538, 75.98377663748605, 70.93522248949323, 68.49729415348598, 64.38558646610805, 63.58674512590681, 60.5962404523577, 66.31690079825265, 72.97349739074707, 77.545592716762, 39.9754843711853, 58.92845739637102, 72.97649901253837, 69.43259811401367, 73.39169556753976, 70.71807043892997, 70.84586865561349, 72.10978072030204, 74.6673778806414, 73.19478361947196, 72.26678221566337, 74.39101328168596, 68.32448550633022, 59.76829310825893, 62.29563781193325, 59.49734115600586, 59.585138593401226, 56.4255564553397, 60.22224671500069, 57.020075593675884, 65.84499304635185, 71.90601090022496, 77.47739614759172, 74.02414839608329, 73.90527861458915, 70.7329604285104, 69.07990060533795, 68.80752427237374, 71.04249572753906, 70.49151052747453, 75.35045528411865, 72.6541998726981, 71.62857627868652, 75.72682530539376, 77.21272536686489, 71.68310574122837, 73.1276501246861, 69.80802318028041, 80.90328189304897, 70.98800795418876, 73.7014045715332, 23.865964344569615, 0.21927587874233723, 0.4445357849555356, 0.9589550857033048, 0.07588110717811755, 0.07491723461342709, 0.0974498898057001, 0.04860426066443324, 0.05482031318492123, 0.0978757112420031, 0.0396968464899276, 1.314479751246316, 25.95546657698495, 38.27538871765137, 55.581006390707834, 45.409052099500386, 31.951378073011124, 22.121832745415823, 36.84769024167742, 50.40939269747053, 74.4300204685756, 71.44673497336251, 49.241852147238596, 0.38868461762155804, 0.01634774064379079, 0.017485701545540775, 0.07234328665903636, 0.07460369036665984, 0.029200113311942135, 0.04455019034711378, 0.08820284849831037, 0.04759644617193511, 0.09388719419283525, 0.061886376701295376, 0.030180206256253377, 0.02552346622438303, 0.05696467722633055, 0.03888717440090009, 0.05297941035990204, 0.02767323479721589, 0.07549605891108513, 0.041043463695262156, 0.014578891452401876, 0.11523488296994142, 0.03671072583113398, 0.04408159406323518, 0.0029462584227855715, 0.035335817108196874, 0.043062990863940546, 0.0753689082339406, 0.0378173418076975, 0.015841877520350472, 0.1273359443460192, 0.01182875085422503, 0.04157213746969189, 0.0806021299213171, 0.03563965830419745, 0.04279287625104189, 0.029931665664272647, 0.03949479233207447, 0.04617583133014185, 0.09212596834238086, 0.0750670347894941, 0.08956884805645261, 0.08493565488606691, 0.20257767476141453, 0.7806258233530181, 30.038261072976248, 117.97841099330357, 97.20566654205322, 92.29810523986816, 63.0289090020316, 43.8155973979405, 37.56232636315482, 32.54338196345738, 58.858468191964285, 50.73522499629429, 36.662162917000906, 1.1876593849488666, 0.32437144007001606, 0.061698978899845054, 0.28501035645604134, 0.2906162499317101, 0.4256531053355762, 0.8299027191741126, 0.9176015790019716, 0.19670674550746167, 1.2494554689952304, 19.997577360698156, 108.30045277731759, 93.85435581207275, 94.10044710976737, 84.5053322655814, 83.74290643419538, 80.6626171384539, 80.79805837358747, 75.48094940185547, 72.93910380772182, 70.5779252733503, 67.11871596745083, 65.13580431256975, 66.95655196053642, 73.53173651014055, 76.16071251460484, 81.0333035332816, 81.75975854056222, 75.58321298871721, 68.37879262651715, 61.67940902709961, 60.58553327832903, 60.17116355895996, 61.07297025408064, 59.411774090358186, 59.30125604357038, 61.13186318533761, 59.559944425310405, 62.29741655077253, 64.19264888763428, 68.81129019601005, 61.11006668635777, 60.8192081451416, 71.61917536599296, 82.05350753239223, 80.57717514038086, 66.91173607962472, 71.77125753675188, 77.38472802298409, 74.20201533181327, 70.534512928554, 67.16462966373989, 66.06244386945451, 63.69129467010498, 69.00311606270927, 75.75060204097203, 79.44013718196324, 42.72384432383946, 59.666439465114046, 74.82576901572091, 71.55082593645368, 77.62232167380196, 73.92549787248883, 75.50586564200265, 74.7508326939174, 79.08259677886963, 76.95245974404472, 74.76869651249477, 75.14681053161621, 71.03897299085344, 62.99519634246826, 64.20535714285714, 62.25531741550991, 62.00302832467215, 58.63481262751988, 62.57524027143206, 59.151369503566194, 68.61461448669434, 74.60414232526506, 78.879702431815, 76.97257477896554, 76.98196874346051, 72.65230301448277, 72.10770320892334, 71.82746846335274, 73.06235790252686, 74.58176912580217, 77.73142228807721, 71.84071867806571, 74.46073845454625, 79.02148042406354, 79.19977119990757, 77.3722699029105, 74.9541300364903, 73.401339667184, 85.73863751547677, 75.66963468279157, 77.88632542746407, 32.03218214852469, 0.15131942954446587, 0.892323164003236, 1.362194985151291, 0.6240539763654981, 0.45271365184869083, 0.3329397902957031, 0.13069915744875157, 0.189158151990601, 0.17011589450495584, 0.03785361289711935, 0.725277993295874, 27.995770352227346, 40.3366447857448, 60.19816425868443, 36.64047758919852, 35.88403763089861, 37.91386004856655, 47.94368198939732, 58.71240316118513, 82.20192105429513, 76.54412106105259, 71.4233820778983, 0.4361096556697573, 0.11919421622795717, 0.025903118441679647, 0.0791392627039126, 0.022755686260227646, 0.06312532736254589, 0.07271180581301451, 0.013644021170746003, 0.05935001280158758, 0.03904569035928164, 0.04835869884118438, 0.05513268695878131, 0.04376947474000709, 0.0403385404497385, 0.038956412114202976, 0.02864375870142664, 0.03739582906876292, 0.14108971346701893, 0.04615357877420528, 0.03565156998644982, 0.005315679807348975, 0.017092465057170818, 0.010343079771181303, 0.02230731031990477, 0.16562976022916182, 0.29883748878325733, 0.14322291900004658, 0.11775661765464715, 0.09155413295541491, 0.19844215310045651, 0.08779117451714617, 0.16344772731619223, 0.13819566661758081, 0.15484300761350564, 0.20536042829709394, 0.13952949004513876, 0.19876869129283087, 0.09563409616904599, 0.17221336838390144, 0.1799183235104595, 0.22324251303715364, 0.2929443307220936, 0.2694840095937252, 0.8584269742880548, 35.58463280541556, 133.25585991995675, 108.64525018419538, 106.56637001037598, 72.83739607674735, 51.072601727076936, 35.124210425785606, 36.18758705684117, 73.47560201372418, 85.25260407584054, 55.06191689627511, 1.3883586440767561, 0.40873899151171955, 0.5410034071121896, 0.2174883053771087, 0.8409933469125203, 0.6377494728990963, 1.073866456747055, 0.8728748847331319, 1.3227879511458533, 2.896321624517441, 19.703545229775564, 112.26544230324882, 99.24725573403495, 98.21931144169399, 89.35680076054165, 89.46130166734967, 84.50820881979806, 85.1139041355678, 79.53533445085797, 77.50176348005022, 75.3651715687343, 69.25834424155099, 67.7510576248169, 69.24694224766323, 77.3080963407244, 80.20280620029995, 85.68034907749721, 84.98292364392961, 78.43474674224854, 73.10246985299247, 64.43767016274589, 62.61309405735561, 64.3890814099993, 64.5364179611206, 63.23968955448696, 63.74986103602818, 67.00789219992501, 62.816516467503135, 65.32684503282819, 66.84349087306431, 72.13267503465924, 64.96110575539726, 62.431843348911826, 76.4065328325544, 85.46943650926862, 83.66453075408936, 69.12668977464948, 72.53792871747697, 82.31544072287423, 76.41511385781425, 73.73365810939244, 71.48985549381801, 69.33846391950334, 65.88604995182583, 71.87855856759208, 80.04940387180874, 84.42615754263741, 50.857766900743755, 61.836417470659526, 78.71238980974469, 74.28298268999372, 79.66510595594133, 77.634738104684, 76.73930985586983, 77.47645814078194, 81.28228528159005, 78.35765647888184, 77.94963046482631, 77.65883445739746, 74.19402490343366, 66.16585390908378, 67.40568351745605, 65.18517126355852, 64.87410736083984, 62.08645534515381, 65.30948148454938, 62.24306774139404, 72.08548286982945, 80.9276214327131, 82.2455974306379, 80.00868742806571, 81.20849541255406, 78.17710059029716, 75.4845277241298, 77.92192104884556, 77.32973303113664, 78.01693071637834, 80.73653207506452, 76.9467830657959, 78.81500080653599, 79.89965629577637, 82.68033232007707, 80.90272603716168, 79.2753745487758, 77.37017849513462, 89.94192246028355, 79.27207415444511, 81.10628046308244, 32.58184371675764, 0.5407753650631223, 2.2643319368362427, 2.2746649937970296, 0.49382486726556507, 0.41710980662277763, 0.505665194775377, 0.424957986921072, 0.25547991533364567, 0.25598517964993206, 0.22854476209197724, 2.167599550315312, 43.02989510127476, 56.16927562441145, 77.20082310267857, 66.73063128335136, 43.33587987082345, 34.110374450683594, 51.69196762357439, 69.3115188053676, 92.72936603001186, 91.00562218257359, 77.78463854108537, 0.5503482999546188, 0.22399314918688365, 0.0851782922233854, 0.29181478704724995, 0.08633919778679099, 0.10187817218580417, 0.14978828813348496, 0.1610151385622365, 0.17196882436318056, 0.15103991382888385, 0.20569023702825817, 0.13422296621969768, 0.11818323976227216, 0.16578731606049196, 0.13918233795889787, 0.1469351840870721, 0.11587556930524961, 0.26039888709783554, 0.15096766342009815, 0.057329844417316575, 0.14882214926183224, 0.10886358842253685, 0.1248370355793408, 0.08842406448509012], [0.03342819393479398, 0.005357827434116709, 0.029681309991117035, 0.0691272070897477, 0.02929578335689647, 0.05708002817950078, 0.05525654674108539, 0.013754726703544813, 0.06743867269584111, 0.05722310407353299, 0.02185723973837282, 0.05751489448760237, 0.02113217587715813, 0.06323801845844303, 0.07217108804200377, 0.08417130554361002, 0.017176499922892878, 0.011636068961316985, 0.0921799661591649, 0.15547819781516278, 47.52822140284947, 102.77153491973877, 80.92368180411202, 88.62518324170793, 51.922411578042166, 40.355734961373464, 41.078427519117085, 48.202419008527485, 45.011212144579204, 39.5926525252206, 9.519284810338702, 0.5991195514798164, 0.5068392774888447, 0.21495222646210874, 0.29577094476137844, 0.0755565706640482, 0.2862266983304705, 0.4143403523734638, 0.3356435352138111, 0.9494144490786961, 7.729888302939279, 97.21077346801758, 92.95140961238316, 91.54941599709647, 85.59046023232597, 80.52238164629254, 75.56512682778495, 74.25764260973249, 71.56040750231061, 75.49909114837646, 71.32969951629639, 67.62671266283307, 66.14224393027169, 61.39752755846296, 60.80717386518206, 61.65219988141741, 68.90043558393205, 70.47936507633754, 76.51969814300537, 68.20257936205182, 61.42302049909319, 59.12996210370745, 57.50070333480835, 57.699546882084434, 54.46870749337332, 56.241870403289795, 54.936237880161826, 56.729043347494944, 55.619516781398225, 58.1601950781686, 61.62364278520857, 64.49562508719308, 55.97898530960083, 68.23786926269531, 73.64231709071568, 83.36600834982735, 70.76206643240792, 68.4360944202968, 74.1681776046753, 72.17585114070347, 70.32492746625627, 64.87906837463379, 63.913268770490376, 63.420023100716726, 62.12524018968855, 68.67609909602574, 71.01560619899205, 72.10270745413644, 38.4124037197658, 65.32921436854771, 72.7912461417062, 71.05803189958844, 73.84875501905168, 68.69015530177525, 71.59356430598667, 73.06540816170829, 72.67731652941022, 72.32044315338135, 71.16854994637626, 67.67266804831368, 61.207230295453755, 58.25797012874058, 62.1789219720023, 65.92951093401227, 62.737807273864746, 57.59375013623919, 57.303906032017295, 57.27904537745884, 63.50163664136614, 72.48688725062779, 72.75954845973423, 70.3917760848999, 71.43326936449323, 68.40536948612758, 66.17565086909703, 66.68287631443569, 66.48107978275844, 71.9742213657924, 69.50507477351597, 69.18258108411516, 74.66588401794434, 74.5884393964495, 72.06516633714948, 70.78639902387346, 65.66827951158795, 72.33191462925502, 71.06685611179897, 77.72348049708775, 76.65447929927281, 80.2086774281093, 12.68895399570465, 0.27527519741228645, 1.1362721366541726, 0.4466785171202251, 0.07675695339483873, 0.03567988186010292, 0.06538006530276366, 0.2552725007491452, 0.05853342304804495, 0.06367207052452223, 0.06943489557930402, 6.336601649011884, 26.164798430034093, 40.91719804491316, 57.57422569819859, 37.00794349397932, 22.122063773018972, 19.001313379832677, 44.37262405667986, 63.29472623552595, 74.06769275665283, 74.99866798945835, 9.416877916881017, 0.7474769992487771, 0.09902930219790765, 0.13924970291554928, 0.029859791842422316, 0.043079150175409656, 0.06989866069384984, 0.01685918980677213, 0.030123277168188776, 0.024587874999269843, 0.04575396575299757, 0.056884976503040106, 0.027217878427888666, 0.09142078725355011, 0.036456685712827105, 0.06442331057041883, 0.0504120441951922, 0.07893766994987216, 0.023132118828860775, 0.030912637311433042, 0.009007250424474478, 0.032019317748823335, 0.09860455284693412, 0.062076013668307235, 0.010620615860846425, 0.023868402266608815, 0.043136954573648315, 0.022264791619298712, 0.026354320480355194, 0.014151436443041478, 0.013229775541861142, 0.056422191871596236, 0.007921942992002835, 0.05143926818189876, 0.01797253854705819, 0.09382248230810676, 0.01972804095463029, 0.02742371881114585, 0.05422700894996524, 0.06626545850719724, 0.05214971470247422, 0.07425737966384206, 0.08222224762929337, 0.03907333726861647, 64.04981476919991, 113.39390618460519, 91.02184622628349, 100.16318811689104, 59.86127390180315, 49.35718182155064, 40.01905305044991, 42.575132029397146, 48.08382020677839, 48.33473355429513, 9.657089301518031, 0.6768890012587819, 0.4332000975097929, 0.5978543279426438, 0.18069257267883845, 0.7556721280728067, 0.9576790056058339, 1.1083364699568068, 1.6700569625411714, 1.6024106038468224, 11.822843670845032, 106.8124474116734, 95.5969431740897, 97.48672117505754, 89.17118658338273, 83.34542083740234, 78.5713483265468, 78.77843243735177, 74.46547712598527, 78.37669454302106, 74.71583461761475, 72.13198716299874, 67.36277144295829, 63.14561789376395, 63.208610262189595, 64.104781968253, 71.52933515821184, 74.88708686828613, 78.9584046772548, 75.08101109095982, 63.15285096849714, 61.45348140171596, 59.31966182163784, 60.69356387002127, 57.56398057937622, 59.07507133483887, 56.54995700291225, 59.15746307373047, 58.67908654894148, 61.006872040884836, 64.38666343688965, 67.72776726314, 57.6191075869969, 72.04679530007499, 76.17342771802629, 85.4002741404942, 72.39453179495675, 69.17391668047223, 77.00364017486572, 75.51307092394147, 70.79790524074009, 68.18486145564488, 66.37894126347133, 66.48141329629081, 66.17956965310233, 71.18074403490338, 70.60169506072998, 78.31358405521938, 44.4005697114127, 65.35065650939941, 75.71920313153947, 72.74971675872803, 79.0491064616612, 70.83592578342983, 75.36261463165283, 73.85898971557617, 74.87721347808838, 72.8296696799142, 74.11073684692383, 69.5430188860212, 62.50375025612967, 61.620828764779226, 63.33232293810163, 68.61593464442662, 64.21871852874756, 59.03598771776472, 59.0333126613072, 60.10283497401646, 67.60718127659389, 75.82093170710972, 74.88149356842041, 73.57715688432965, 72.59967735835484, 72.63874013083321, 69.4370310647147, 70.99560928344727, 70.04570715767997, 76.03710406167167, 71.41612121037075, 75.08639594486782, 77.90627370561872, 75.60630880083356, 75.14848504747663, 74.8920270374843, 68.76715523856026, 75.5671557017735, 73.41377694266183, 81.87136745452881, 78.87895897456578, 86.86396775926862, 19.238768066678727, 0.18868325890174933, 0.4532939892794405, 0.836125373840332, 0.7732462936214038, 0.2166810929775238, 0.3692020316209112, 0.3896356794450964, 0.17339536281568663, 0.04954289851178016, 0.05116165914971914, 5.267925713743482, 28.68274222101484, 37.70627566746303, 36.95710352488926, 26.305476869855607, 27.234160934175762, 34.53359964915684, 56.221470492226736, 72.11760439191545, 81.48310906546456, 90.71134512765067, 22.47050551005772, 0.9091521352529526, 0.16152313058929785, 0.11803702903645379, 0.08048695538725172, 0.1451681431915079, 0.012857582120757018, 0.06901449563780002, 0.03192101838067174, 0.022822376074535505, 0.0158537620612021, 0.13597138811435017, 0.04115668744114893, 0.08588651314909969, 0.06129881965794733, 0.06509415100195579, 0.04092843843890088, 0.023450197385890142, 0.01030718781320112, 0.020170084466891627, 0.05373849766328931, 0.09048016129859857, 0.05156710757208722, 0.051700443095926724, 0.09985255516533341, 0.16277633048593998, 0.09238708897360734, 0.19275442830153874, 0.12639648547129972, 0.20489515683480672, 0.09447338059544563, 0.10730386033122029, 0.1214567641062396, 0.1339788564613887, 0.09176747115062815, 0.18690675922802516, 0.15398638429386274, 0.09882603346237115, 0.18618779709296568, 0.2952957259757178, 0.1178191921540669, 0.1193284440253462, 0.18190522332276615, 0.18490476879690373, 71.56235299791608, 131.42620468139648, 102.68001324789864, 115.77573476518903, 70.56466116224016, 57.81407751355852, 56.629638944353374, 69.86615180969238, 63.467923981802805, 62.29056562696184, 14.299592460904803, 0.6040679716638157, 1.0650309537138258, 0.4859697659100805, 0.4380422591098717, 0.9713974637644631, 1.1955987874950682, 1.8394168061869485, 3.6296957348074232, 2.740371261324201, 11.356002024241857, 111.85742323739188, 98.25974300929478, 101.9662525994437, 92.46019281659807, 86.74440315791539, 82.29260199410575, 82.42156750815255, 78.11955560956682, 81.72161293029785, 76.23588507516044, 75.22323376791817, 72.84332983834403, 68.19740990230015, 67.44278689793178, 68.99610533033098, 74.64487961360386, 78.34479536328996, 83.62864330836705, 76.63653905051095, 67.45209748404366, 65.1964829308646, 65.68750517708915, 65.37203611646379, 60.87956019810268, 62.69621535709926, 60.149915967668804, 60.68126555851528, 62.52283695765904, 65.55779620579311, 67.91404151916504, 70.92891352517265, 60.63039084843227, 75.72191987718854, 82.21035616738456, 89.22218636104039, 72.28147765568325, 69.62807873317173, 80.53421442849296, 79.41813223702567, 75.71443666730607, 72.98758833748954, 69.26359013148716, 70.53621523720878, 69.89349297114781, 76.6134432383946, 77.14525835854667, 82.13652460915702, 50.853177615574424, 67.5403743471418, 78.90350696018764, 74.87095315115792, 80.84265886034284, 73.94692611694336, 77.06271375928605, 77.3728882925851, 78.13764177049909, 77.77951771872384, 78.11806869506836, 75.24026380266461, 67.44407926286969, 62.53417641775948, 65.32765102386475, 71.06460489545549, 68.46624265398297, 63.94633524758475, 62.31635039193289, 63.49078355516706, 70.37741415841239, 80.90076664515904, 76.42022773197719, 77.42139366694859, 77.6767052241734, 76.17092636653355, 74.24027906145368, 74.44123486110142, 74.78104346139091, 79.8590440750122, 75.33485657828194, 81.48995998927525, 79.7964060647147, 79.92344692775181, 78.8744843346732, 80.72198949541364, 72.93511554173061, 81.1400626046317, 76.00173078264508, 85.32604653494698, 81.74549388885498, 90.47125707353864, 16.928665740149363, 1.2220037877559662, 4.634674276624407, 2.767847695520946, 0.5489396612559045, 0.22482070406632765, 0.5074782403452056, 1.0249285570212772, 0.28415266105106896, 0.4200496274445738, 0.16520119751138346, 9.719055073601858, 40.77641017096383, 53.95409263883318, 79.11733082362584, 51.943596635546, 29.35903297151838, 31.68242720195225, 61.41401563371931, 83.52663680485317, 91.83042199271065, 104.18482630593437, 22.547154562813894, 1.3756642852510725, 0.4631643124989101, 0.34251307802540915, 0.14402110688388348, 0.2066576379750456, 0.13645681206669125, 0.16927073842712811, 0.09910815475242478, 0.09608497590358768, 0.11034863694970097, 0.20285010657140187, 0.08713773172348738, 0.1480986409421478, 0.13580993749201298, 0.17434961375381264, 0.10969248680131775, 0.17115698435476848, 0.07824773554291044, 0.10072206386498042, 0.20881227164396218, 0.17583532045994485, 0.19427528312163694, 0.1573523251073701], [0.03673985533948455, 0.05385412681581719, 0.03235837151961667, 0.05391461821272969, 0.010792351377728795, 0.05009497156632798, 0.040928265412471125, 0.055263349054647345, 0.04286834291581597, 0.00956788404645132, 0.04104882412190948, 0.017397044160004174, 0.04660477063485554, 0.04413338324853352, 0.01630043487862817, 0.04447865579277277, 0.02664373262918421, 0.08085352714572634, 0.0371971811567034, 0.7793759075658662, 77.01757826123918, 88.23648711613247, 84.99972438812256, 59.76448549543108, 56.040935448237825, 34.67607593536377, 63.41553456442696, 62.07083579472133, 42.65983057022095, 27.59607696533203, 0.062085764216525216, 0.021424180029758384, 0.04209784943876522, 0.2988009293164526, 0.3097508560333933, 0.12205667048692703, 0.1019937199141298, 1.0961189312594277, 3.686588670526232, 2.5808762311935425, 85.59899262019566, 96.48394325801304, 93.11275373186383, 86.9417667388916, 86.01682949066162, 80.20122895921979, 78.94225706372941, 75.53027466365269, 77.15676457541329, 78.83107893807548, 75.05532360076904, 67.40146596091134, 61.577326093401226, 59.15933908735003, 58.227325098855154, 58.53623158591134, 59.97055516924177, 68.65385791233608, 71.99104295458112, 67.07647092001778, 60.86238425118582, 56.76523303985596, 53.930315903254915, 54.4375239780971, 53.95985964366368, 55.69329275403704, 53.426936285836355, 54.770908968789236, 55.181283473968506, 58.20355531147548, 62.08887331826346, 61.541994503566194, 59.38681616101946, 73.15175342559814, 73.60089887891496, 73.57965128762382, 71.21312958853585, 71.33120032719204, 72.8413496017456, 69.3818554197039, 61.27412060328892, 58.994986397879465, 63.476129804338726, 68.9405961717878, 70.38052000318254, 70.0601246697562, 69.55115522657121, 77.38531861986432, 43.28007888793945, 60.67592934199742, 74.22217205592564, 68.14629200526646, 77.0745187486921, 70.20941366468156, 70.76519312177385, 67.76851844787598, 68.59077521732875, 62.554340090070454, 64.85912009647915, 58.92587961469378, 56.2713794027056, 56.57133660997663, 62.574740001133506, 65.86134910583496, 62.422762053353445, 54.91439274379185, 56.33897842679705, 55.83779444013323, 64.02439131055559, 69.95192037309918, 72.8352838243757, 72.8883124760219, 70.0099378313337, 64.53938484191895, 62.72348008837019, 66.3910311290196, 69.41249002729143, 67.75945799691337, 71.17962537493024, 74.15090438297817, 72.60104615347726, 69.35204764774868, 73.47315624782017, 67.30182879311698, 64.92041710444859, 64.66495963505336, 70.90529659816197, 71.86837250845772, 73.76533494676862, 74.47604533604213, 72.88274696895054, 6.9196918691907605, 0.39274600254637854, 1.2928620598145892, 0.9001386931964329, 0.1665787457355431, 0.06408768000879458, 0.16606666892766953, 0.21979902924171515, 0.04387386056727596, 0.02241321776195296, 0.023503070530880774, 15.034675393785749, 28.092129707336426, 64.40048340388707, 47.847181933266775, 36.43682588849749, 26.96278861590794, 37.79935720988682, 59.445396423339844, 63.021154812404085, 74.07512732914516, 50.21579851422991, 0.5337651755128587, 0.027408902999013662, 0.12374595126935414, 0.01607383810915053, 0.10030579620173999, 0.046006082224526575, 0.09299904613622598, 0.051061605768544335, 0.03997348860970565, 0.021464758120211105, 0.023201139410957694, 0.060835414166961393, 0.05352678116677063, 0.031088723934122493, 0.05038323359830039, 0.013615580375439354, 0.05218786533389773, 0.11423035258693354, 0.010169740367148603, 0.04800110410100647, 0.0309531221033207, 0.04808956810406276, 0.06753616460732051, 0.032081298530101776, 0.021105024298386912, 0.008153560920618474, 0.09799930639564991, 0.02006780549085566, 0.008127705343732876, 0.04675944269235645, 0.009953512460924685, 0.03380869940987655, 0.00985920287868274, 0.07780864196164267, 0.023982202767261436, 0.025935024854594042, 0.0396430284849235, 0.005771617596370301, 0.03991073090583086, 0.07196541050715105, 0.05954166501760483, 0.12927682591336115, 1.8364062820162093, 97.06074796404157, 94.143463407244, 93.41208907536098, 71.67657443455288, 65.67188562665666, 35.343617166791645, 30.49223552431379, 53.46575934546334, 52.146789755140034, 31.618403026035853, 0.06332658763442721, 0.10321046890957014, 0.4360223960663591, 0.44277308668409077, 0.3435798164989267, 0.8445328569837979, 1.1486163714102335, 1.0629350947482246, 2.756513229438237, 5.370445081165858, 98.92523452213833, 99.81568091256278, 99.98265307290214, 89.5598201751709, 90.01891544886998, 83.02650547027588, 81.80698544638497, 78.41835594177246, 80.62966878073556, 81.29639707292829, 79.45164339882987, 72.11699989863804, 66.0042804990496, 62.854043688092915, 62.82841873168945, 61.15005356924874, 63.4692302431379, 71.91038131713867, 74.28940977369035, 68.68975925445557, 63.529596192496165, 60.63171795436314, 59.02210521697998, 56.58120652607509, 59.36961242130825, 58.74429539271763, 56.004311493464876, 57.31485986709595, 58.96706853594099, 60.47820445469448, 65.34725884028843, 63.59629889896938, 62.13789285932268, 75.8670677457537, 77.18448788779122, 75.42496081760952, 70.95444120679582, 72.77841976710728, 73.7958653313773, 70.87436321803501, 62.79976436070034, 63.72904423304966, 65.34236730848039, 73.05515956878662, 74.05364349910191, 73.12106323242188, 72.12429550715855, 79.8333009992327, 45.88595560618809, 62.75187042781285, 76.59828921726772, 69.55522687094552, 77.29048960549491, 72.41431331634521, 75.32772077832902, 69.54866777147565, 71.20253358568463, 66.34410994393485, 67.3312405177525, 60.172073772975374, 59.99340084620884, 58.48213291168213, 63.52266189030239, 68.52477427891323, 66.37208339146206, 57.88335452760969, 58.30686460222517, 58.0673497744969, 68.46592998504639, 72.96272073473249, 76.6669374193464, 75.35408224378313, 73.08999783652169, 66.1267841884068, 66.85328783307756, 69.58301966530937, 72.95671054295131, 70.23749133518764, 75.92268112727574, 76.91084698268345, 75.0276072365897, 74.30102716173444, 75.98017052241734, 70.74590492248535, 67.64985711233956, 68.2297259739467, 73.51008592333112, 72.92256709507534, 77.31539194924491, 78.13021414620536, 81.0342206954956, 11.662256905010768, 0.4915114428315844, 1.4190767386129923, 1.5512713193893433, 1.551539150731904, 0.6351309248379299, 0.5698021703532764, 0.2287381174308913, 0.13661952476416314, 0.16011613394532884, 0.030214472274695123, 16.08682026181902, 34.626378944941926, 52.654147216251914, 28.680584805352346, 29.918623515537806, 35.54150881086077, 45.44142723083496, 66.45366219111851, 68.16019535064697, 82.99876131330217, 72.04805292401994, 1.5070642743791853, 0.1348511539399624, 0.1433047910353967, 0.03202424052038363, 0.040933897253125906, 0.05361078040940421, 0.04134670778044632, 0.016046259053317562, 0.0632006311789155, 0.034868299694997926, 0.011249693310154336, 0.05252654251775571, 0.07538273677762065, 0.03207749534132225, 0.016043541520567875, 0.03532447539536016, 0.006453752667377037, 0.06624250366751637, 0.030124942971659557, 0.02683104052474456, 0.022406383217977624, 0.07619757591081516, 0.07065717463514634, 0.10477133015436785, 0.07593987509608269, 0.10552127419837884, 0.22978895104357175, 0.0852486766608698, 0.1502383875527552, 0.13228098542562552, 0.14644718170166016, 0.10617872713399784, 0.134847937683974, 0.1893122744347368, 0.08864339414451804, 0.16021859273314476, 0.16447819130761282, 0.09711446958993163, 0.12652523070573807, 0.1541418909494366, 0.23726781830191612, 0.18798216937908105, 2.115222943680627, 112.36189024788993, 107.96584837777274, 109.54037271227155, 83.36829430716378, 74.81457546779087, 49.88532829284668, 86.48385265895298, 87.47674328940255, 64.55290603637695, 43.50537422725132, 0.2546054194016116, 0.2590240394430501, 0.34098298155835693, 1.0296079516410828, 0.8184545849050794, 0.9896334452288491, 1.3926743439265659, 6.522122459752219, 10.904856358255659, 4.647280045918055, 105.36133698054722, 101.48218550000871, 103.78115681239537, 94.87925679343087, 95.31720175061906, 89.35596697671073, 84.82125990731376, 82.63355704716274, 87.05161775861467, 83.49480710710797, 84.14661066872733, 76.4388211114066, 70.03108814784459, 66.41937283107212, 66.61158084869385, 64.49379076276506, 66.76908261435372, 76.06257615770612, 78.7276063646589, 74.07377937861851, 67.04109069279262, 65.1787997654506, 61.641520500183105, 61.131467138017925, 61.347278186253135, 62.442835399082725, 60.539001192365376, 61.83201926095145, 63.93585736410958, 65.58860451834542, 68.15707560947963, 69.18417916979108, 65.44983509608677, 79.78152997153146, 79.92728928157261, 82.18732288905552, 73.71610695975167, 74.83128588540214, 78.82773685455322, 74.89582075391496, 68.86422157287598, 66.87930188860211, 70.08171967097691, 74.6953513281686, 78.82588168552944, 76.76217637743268, 75.08197689056396, 81.75592313494, 50.165243421282085, 66.87044293539864, 80.07877390725272, 72.73365947178432, 79.00950867789132, 74.88114615849086, 77.11918871743339, 76.4226804460798, 75.58740275246757, 69.52361256735665, 70.51233427865165, 63.31116567339216, 61.75103105817522, 61.688796043395996, 66.23739950997489, 72.55985723223004, 68.83631760733468, 60.099812507629395, 61.54223074231829, 59.768980979919434, 70.21659810202462, 76.12817410060337, 79.4365519114903, 81.05861582074846, 76.10346630641392, 70.6280495779855, 69.77695083618164, 75.336809022086, 76.43231759752545, 74.56997803279332, 78.65510886056083, 79.00957815987724, 77.05051272256034, 76.43447153908866, 79.80951036725725, 74.97528730119977, 71.83791160583496, 72.07908357892717, 79.64355959211076, 78.00967679704938, 80.12575067792619, 81.50390502384731, 83.29169041769845, 9.924806867327009, 1.488548953618322, 5.973928698471614, 2.125093945435115, 1.3349771542208535, 0.6611865067056247, 1.4157692875180925, 0.9831093038831438, 0.235204637582813, 0.35969681452427593, 0.07608854890401874, 25.892854622432164, 47.55485037394932, 89.06308650970459, 68.5482313973563, 50.838346685682026, 38.356731278555735, 53.452481337956016, 77.29350512368339, 78.29865237644741, 92.70408848353794, 77.28905827658517, 1.1946410217455454, 0.1717220547475985, 0.2639039818729673, 0.07588989420660905, 0.28334118745156694, 0.18747983633407525, 0.10282501352152654, 0.11871116714818136, 0.16253387635307653, 0.14569244720041752, 0.05559412469821317, 0.15131021503891262, 0.15485139430633613, 0.18832911790481635, 0.09021750039287976, 0.0932153088173696, 0.12046421665166106, 0.16137643131826604, 0.10616999438830785, 0.14063721203378268, 0.14831759062196526, 0.23718913538115366, 0.11121935344168118], [0.0343501635694078, 0.028047696221619844, 0.07130890752055816, 0.040749715707663975, 0.06218003987201622, 0.098526792733797, 0.021425822084503512, 0.0010140218156655984, 0.027774706316579665, 0.04756207837324057, 0.047617480757513216, 0.017889614782429168, 0.010842981964482792, 0.12703349414680684, 0.03636711569769042, 0.04179070038454873, 0.07047417374061686, 0.09239476999001843, 0.26780544966459274, 8.207018494606018, 93.93259252820695, 84.91149616241455, 76.43323475973946, 55.24234076908657, 33.925288336617605, 44.66755771636963, 84.82688794817243, 58.01916054316929, 42.94972331183297, 4.300016462802887, 0.41210088825651575, 0.2569712810218334, 0.4937670017991747, 0.5302198571818215, 0.7022526945386613, 0.10979833147887673, 1.3521642833948135, 2.705039454357965, 1.572355410882405, 70.94734014783586, 95.26998179299491, 86.57157366616386, 93.11868749346051, 90.84523691449846, 89.24918011256626, 87.64147812979562, 82.43128108978271, 82.9812240600586, 84.65034117017473, 75.68241936819894, 70.73542703901018, 71.95662157876151, 66.90464891706193, 59.65915775299072, 54.896723474775044, 57.69182048525129, 56.84542914799282, 61.85973562513079, 64.42668506077358, 61.491265705653596, 57.34643595559256, 55.71954999651228, 55.76281990323748, 55.9152182170323, 54.24784857886178, 52.869461468287874, 52.51161881855556, 53.865746293749126, 55.894651549203054, 55.52321127482823, 59.72406087602888, 57.393610749925884, 61.461576053074424, 75.47418185642788, 70.1333725793021, 68.32791791643415, 67.26357201167515, 73.79715769631522, 69.31119918823242, 65.65935802459717, 56.358311789376394, 64.63399846213204, 64.68563052586147, 69.8144919531686, 69.16505077907017, 75.7097396850586, 67.98558017185756, 74.5602366583688, 38.39935152871268, 58.4807710647583, 75.17825807843889, 65.68190492902482, 69.44155434199742, 70.71772302900041, 72.02775723593575, 67.65310886928013, 66.4850263595581, 61.46558516366141, 58.158218315669465, 56.39647477013724, 56.49372175761631, 58.271324566432405, 58.67025538853237, 64.48589066096714, 64.01467078072685, 52.81191301345825, 53.46126038687569, 54.61171531677246, 60.17196954999651, 68.6599931716919, 71.84142739432198, 70.3368922642299, 67.9816335950579, 60.9919125693185, 64.52674606868199, 63.98193781716483, 68.33697836739677, 69.02231393541608, 70.18842315673828, 68.47938169751848, 69.20361328125, 70.66928018842424, 68.64590222494942, 63.77870300837925, 60.197122028895784, 63.962197984967915, 66.53154454912458, 68.77215794154576, 73.66066033499581, 75.97034576960972, 77.11077444893974, 60.08291448865618, 3.7212801575660706, 1.4490628838539124, 1.830582171678543, 0.7820610063416618, 0.1251552685030869, 0.751098422067506, 0.2227650957980326, 0.10624930156128747, 0.09303326465721641, 0.049069209822586606, 2.000456073454448, 22.92539712360927, 32.78118058613369, 75.80063601902553, 47.95458023888724, 30.757594176701136, 32.56785699299404, 54.88364001682827, 59.77167688097273, 72.38452638898576, 76.89392811911446, 9.294984800474984, 0.5742273586136954, 0.09654966382575886, 0.0747691307749067, 0.040595172571816614, 0.12316699805004255, 0.009105457342229784, 0.01856362057982811, 0.010124207274722201, 0.02815726605643119, 0.014084633822286767, 0.08996766379901341, 0.030849458915846686, 0.02980158371584756, 0.01336150717855032, 0.027720908667626123, 0.05744926658059869, 0.019223229560468878, 0.035874743546758375, 0.08481592059667621, 0.08885249149586473, 0.007234133247818265, 0.014288832998967596, 0.04222564472417746, 0.03535926727844136, 0.04060783403526459, 0.028966307107891356, 0.03799106373584696, 0.08868807567549603, 0.037501130918306966, 0.04189734234075461, 0.045955531365637264, 0.04702421044930816, 0.047791212863687954, 0.02909660618752241, 0.025993009064612643, 0.028103873832151294, 0.05593110554452453, 0.06091199362916606, 0.04083323319043432, 0.11107881526861872, 0.41015571834785597, 14.833816868918282, 113.30585861206055, 90.10412120819092, 88.48766449519566, 68.80897644587925, 47.165410791124614, 32.88586214610508, 58.585563795907156, 57.19781746183123, 49.69903319222586, 4.625186077186039, 0.522147244640759, 0.16193505562841892, 0.9205279648303986, 0.5603814444371632, 1.314740960087095, 1.3762400086436952, 2.8814676787172044, 2.5997644748006548, 3.9420674187796454, 81.74577876499721, 94.09894629887172, 92.71978446415493, 95.42005593436105, 94.55840287889752, 94.43514878409249, 91.25198446001325, 86.35261508396694, 85.41010584150041, 88.13115242549351, 79.8152356828962, 75.15846266065324, 73.43681716918945, 68.17629432678223, 63.082083565848215, 57.89611142022269, 61.49036938803536, 62.14420877184187, 64.37424700600761, 67.67621162959507, 66.5236930847168, 60.50732435498919, 59.523473330906455, 58.544798714774, 59.01964555467878, 57.59790863309588, 56.15782846723284, 55.83403893879482, 56.482945101601736, 60.857610838753835, 59.839984621320454, 62.48513603210449, 59.76298468453543, 64.7161887032645, 79.07428673335484, 74.07514817374093, 70.78962993621826, 70.36940288543701, 75.90382371629987, 71.85936069488525, 67.43922942025321, 59.34817028045654, 65.90480313982282, 68.60875715528215, 73.754898752485, 71.50109767913818, 78.56574807848249, 69.02120917184013, 74.59587396894182, 40.42091948645455, 61.57982744489397, 77.90528011322021, 68.83001559121269, 71.16192136492047, 71.76050867353166, 74.95578370775495, 70.74512672424316, 70.88469518933977, 63.794982637677876, 61.67143249511719, 58.51572050367083, 58.591358593532014, 60.82138293130057, 59.84487615312849, 67.17742129734584, 67.4692108971732, 55.56236089978899, 56.7190066746303, 57.42433220999581, 61.53032152993338, 72.0889013835362, 74.50724969591413, 73.88469805036272, 70.49964686802456, 65.27300344194684, 65.82648999350411, 66.51472990853446, 70.49486650739397, 71.8813864844186, 72.77195794241769, 70.73114694867814, 72.80423927307129, 73.84093829563686, 71.46245874677385, 67.12198162078857, 63.78196171351841, 67.94488457271031, 68.57844911302838, 73.44087491716657, 76.27724770137242, 78.5703477859497, 77.10433346884591, 71.62314973558698, 7.053900233336857, 0.9056083911231586, 0.881056931402002, 1.3245107786996024, 1.4428687819412775, 0.5516573839953968, 0.3080650764916624, 0.6504776499101094, 0.356706972100905, 0.18214819314224379, 1.3266862162521906, 23.93537163734436, 36.27409560339791, 61.29844624655587, 37.13979598454067, 32.304200649261475, 42.34785645348685, 59.66374356406075, 71.11549350193569, 77.49098682403564, 91.02000495365688, 18.203555958611624, 0.5902050126876149, 0.13666316813656262, 0.1358459677015032, 0.035572652971105914, 0.049468018779797215, 0.056476925898875506, 0.0387999147975019, 0.0336435032742364, 0.08595353883824178, 0.01902823386314724, 0.013205120971958553, 0.0603714862040111, 0.04086026602557727, 0.009368657683288413, 0.01519280279587422, 0.06347635388374329, 0.044406788756272624, 0.08486238667475325, 0.048980644039277516, 0.02210551400535873, 0.03474694709958775, 0.025591245087395822, 0.09265843512756483, 0.1309028808027506, 0.1578456607780286, 0.08494693892342703, 0.12991855719259807, 0.2015045987708228, 0.11476406109120164, 0.09185737025524889, 0.09001806538019862, 0.11861439448382173, 0.1491472761013678, 0.10988085490784474, 0.09616130430783544, 0.291293237890516, 0.166322259498494, 0.11221413327647106, 0.18624136064733776, 0.2579853923193046, 0.5596884159105164, 17.16670060157776, 129.22676631382532, 103.2328953061785, 102.44153717585972, 72.93194021497453, 55.739064012254985, 62.5499974659511, 120.5464096069336, 76.42293752942766, 65.55755996704102, 7.115180305072239, 0.7046244187014443, 0.5443488561681339, 1.363237432071141, 2.081168519599097, 2.58381792477199, 2.433930733374187, 6.146117218903132, 10.441745025771004, 3.283308276108333, 85.00049563816616, 95.93784264155796, 98.75973537990025, 100.47774001530239, 96.92205497196743, 98.7955186026437, 93.94008268628801, 88.46330411093575, 89.3763599395752, 88.5501149041312, 85.22069099971226, 78.73863315582275, 78.9135262625558, 74.10483782632011, 66.00670542035783, 62.02923692975725, 64.08033125741142, 64.25775350843156, 67.67108385903495, 71.68044458116803, 70.60345295497349, 65.72079399653843, 62.54564094543457, 63.49424375806536, 60.94946602412632, 61.34813976287842, 61.0006742477417, 59.54072570800781, 59.21025548662458, 64.8687641961234, 63.314334051949636, 66.16003826686314, 62.47646468026297, 67.7212220600673, 82.17398234776088, 77.49806009020124, 72.62128625597272, 74.83452374594552, 77.58237648010254, 75.05816541399274, 71.64710017613002, 62.87244251796177, 69.12223597935268, 70.21264457702637, 76.2941665649414, 74.2061356135777, 82.67035470690045, 72.60811247144426, 77.23687730516706, 45.60275745391846, 64.69537190028599, 80.03089387076241, 71.64521721431187, 74.79673249380929, 75.60430077144078, 80.51655210767473, 74.41309465680803, 72.0649162020002, 67.77424376351493, 65.07203374590192, 62.652893338884624, 61.29751518794468, 64.49009432111467, 60.71843147277832, 69.25666277749198, 69.64815207890102, 59.396543639046804, 59.119275774274556, 61.32940741947719, 64.67989826202393, 75.32856845855713, 77.86698859078544, 78.5698822566441, 74.3409445626395, 68.45288821629116, 70.33694090162004, 69.7684462411063, 75.50824887411935, 75.70412554059709, 76.27389172145298, 76.44200338636125, 75.41277367728097, 76.64750330788749, 75.54954201834542, 72.74591609409877, 68.85778754098075, 71.54070935930524, 72.27461978367397, 76.5518821988787, 79.25775391714913, 81.80084323883057, 82.25399780273438, 73.37903594970703, 5.665161609649658, 3.2417619568961005, 6.227114975452423, 1.6890926382371356, 1.9220510806356157, 2.1999848868165697, 2.0913387281554083, 0.8209345489740372, 0.5056190001113074, 0.5379230209759304, 3.0813604039805274, 33.40622663497925, 46.14498792375837, 102.00665637425014, 66.25976576123918, 39.97212144306728, 47.75353063855852, 69.60271086011613, 79.90028163364956, 86.28731591360909, 104.02328763689313, 18.663632665361675, 0.8146240647350038, 0.32819560915231705, 0.2873017963554178, 0.10941481670098645, 0.1894637777337006, 0.16054139898291656, 0.13099938205310277, 0.11353188220943723, 0.13929139210709504, 0.25373692171914236, 0.1999037718134267, 0.15710882603057794, 0.21758701865162167, 0.13477241673639842, 0.11850331830126898, 0.10481960792094469, 0.19402244740298816, 0.20071724030588353, 0.16808596200176648, 0.1691316251776048, 0.07393544872424432, 0.09109717354710613], [0.04240232167233314, 0.012637841099474047, 0.054998560941645076, 0.035739905067852566, 0.11351942430649485, 0.01722424673581762, 0.08072882597999913, 0.04900212645796793, 0.04281727637031248, 0.03436054515519312, 0.04887393083689468, 0.06157666617738349, 0.07620896851377827, 0.13990918467087404, 0.12495812693876879, 0.03428834902920893, 0.05509305712101715, 0.2937480147395815, 0.661932678094932, 27.98160297530038, 96.06398023877824, 79.4529218673706, 69.86457456861223, 55.1914313180106, 58.78887503487723, 64.87833186558315, 48.093968050820486, 48.36208166394915, 18.297141245433263, 0.1766624410769769, 0.11263138481548854, 0.18746014524783405, 1.0537026758704866, 0.37035532402140753, 0.30662840072597775, 0.7246436444776398, 0.6274896977203233, 0.5461842662521771, 70.12670925685337, 93.32043538774762, 92.98495551518032, 86.97541686466762, 84.95406777518136, 91.01811504364014, 87.62786660875592, 85.26235934666225, 87.08419091360909, 92.10998276301792, 78.37232412610734, 76.79235240391323, 77.6432010105678, 68.43266201019287, 64.83437756129673, 58.053679193769185, 57.48569175175258, 57.77495220729283, 55.16743918827602, 58.2202935218811, 57.86762033190046, 57.37904732567923, 57.190747669764924, 55.953124114445274, 54.454432419368196, 53.37841354097639, 52.77082136699131, 54.256440026419504, 51.22361734935215, 53.24184669767107, 54.57900319780622, 58.49785668509347, 59.439163889203755, 56.300721645355225, 64.76622268131801, 72.92456122807094, 68.21605886731828, 70.7063627243042, 71.66850757598877, 68.19854940686906, 65.60392529623849, 61.82622446332659, 59.62746007101876, 64.57271535055978, 68.6047202519008, 73.33808326721191, 68.39869921548026, 72.93184988839286, 67.72882338932583, 69.95258740016392, 38.40659155164446, 59.84837109701974, 70.30870342254639, 64.01342010498047, 68.2896819795881, 68.35886519295829, 69.52730206080845, 69.46614401681083, 68.97387109483991, 66.51296506609235, 59.50011348724365, 55.7232221194676, 55.85837500435965, 55.343961647578645, 56.74681336539132, 55.06094067437308, 64.04228292192731, 56.12820134844099, 52.46033069065639, 53.31144332885742, 54.30123853683472, 65.95020961761475, 70.04850728171212, 69.12915638514927, 64.35331208365304, 59.686318261282786, 61.15278421129499, 63.925428118024556, 62.55523640768868, 64.19558102743966, 62.70596367972237, 67.15433938162667, 69.74908855983189, 69.25140993935722, 62.794754709516255, 56.14051355634417, 58.202235153743196, 61.37013775961739, 64.7351016998291, 67.89575386047363, 68.53712817600795, 73.58038084847587, 75.46122346605573, 76.93101760319301, 52.7864339692252, 0.6301923298410007, 0.9964117386511394, 1.7089169344731738, 1.1542419152600425, 0.37732732562082155, 0.08687627861010176, 0.24799852392503194, 0.15653535537421703, 0.007566851197874972, 0.13680175212877138, 8.00892014162881, 26.52131049973624, 45.180272238595144, 45.11150591714041, 33.30169446127755, 22.370163100106375, 42.54916313716343, 49.31144183022635, 60.274344308035715, 74.95078100476945, 33.77303940909249, 0.20673728441553457, 0.05126548857827272, 0.016635758403156484, 0.08162985263126236, 0.08013187122664281, 0.02994429659364479, 0.02739391416045172, 0.0501718224425401, 0.012111637192512197, 0.04721544536628893, 0.017690003350643174, 0.014847469183483293, 0.048207405888076336, 0.02620622851619763, 0.014966930362528988, 0.06567228319389479, 0.03732539713382721, 0.0033193360598358724, 0.05468080299241202, 0.03718526947445103, 0.06690734584948846, 0.02412362812486078, 0.05878908825772149, 0.026319302984380295, 0.03577483265793749, 0.05580080307221838, 0.062025367814515314, 0.03378661648769464, 0.018776848513100828, 0.050272812202040634, 0.055540683280144415, 0.04882621286170823, 0.050858191147978814, 0.0464406771186207, 0.0524704717764897, 0.03249203274026513, 0.09187962620386056, 0.09194744577897446, 0.05449864687398076, 0.2743855022958347, 0.5872703215905598, 43.07615968159267, 111.01785850524902, 86.1224421092442, 82.28463241032192, 66.55338968549455, 66.10886478424072, 48.579588072640554, 50.21085834503174, 51.364339215414866, 20.510314464569092, 0.24648758928690637, 0.1741462703794241, 1.4745908911739076, 1.4260648893458503, 0.8379079667585236, 1.2452919781208038, 1.4829023480415344, 1.5468605160713196, 1.9700622643743242, 82.79538059234619, 95.31927926199776, 96.71381746019635, 89.02868597848075, 91.1933069229126, 93.0721970966884, 90.07450103759766, 89.38090406145368, 90.65599577767509, 92.39900003160749, 81.59418296813965, 80.6021956035069, 81.45947129385812, 72.3492295401437, 69.326749256679, 60.94745799473354, 61.21959808894566, 60.68782465798514, 59.99843829018729, 61.114617756434846, 62.553131103515625, 60.70923900604248, 60.74729428972517, 59.021292277744834, 58.35481412070138, 55.46355751582554, 55.146174226488384, 56.427383831569124, 54.43071126937866, 55.2702898979187, 58.513747215270996, 61.15542452675955, 61.55953870500837, 59.483764375959126, 68.78960486820766, 76.38012272971017, 72.41507761819022, 73.06895869118827, 75.2634916305542, 72.92308820996965, 69.26702948978969, 62.893599782671245, 63.40078353881836, 69.52450193677629, 72.00955295562744, 76.2078560420445, 71.7384342466082, 72.75697762625558, 69.65768500736782, 70.55991554260254, 42.214013304029194, 62.68659905024937, 72.47939014434814, 69.06859588623047, 71.19394561222622, 72.7883973802839, 73.15012754712785, 72.56478350503104, 73.62096527644566, 70.09823553902763, 61.83624376569475, 58.02967316763741, 57.625176838466096, 59.128329277038574, 60.65368815830776, 58.125110149383545, 67.44925567081997, 58.00271415710449, 55.16967650822231, 56.44198547090803, 57.799621786390034, 66.79294967651367, 71.1877339226859, 70.10884543827602, 67.92554773603166, 63.06269114358084, 61.725934164864675, 66.59336267198834, 67.72165284837995, 68.07465607779366, 67.92108699253627, 71.46547426496232, 72.96304035186768, 73.83863844190324, 64.05331666128976, 58.0453656741551, 61.86247321537563, 63.358288356236045, 67.3813648223877, 71.35552597045898, 74.02349526541573, 76.16844585963658, 78.0537005833217, 78.82930714743478, 65.7465718133109, 1.8163596434252602, 0.47045210429600304, 0.9330513328313828, 1.5637806824275424, 1.423661464026996, 0.5387611474309648, 0.8639078544718879, 1.5534925716263908, 0.2673084906169346, 0.15043597695018562, 8.605038234165736, 31.867412567138672, 42.68487882614136, 39.926694120679585, 28.426096609660558, 31.836305482046946, 55.10239362716675, 54.166203771318706, 66.41253580365861, 82.80187715802873, 54.43543951851981, 0.26601102309567587, 0.06529172682868582, 0.01729339623956808, 0.08371217482324157, 0.046076090075075626, 0.01942644570954144, 0.020360098020838838, 0.025680207813690816, 0.030916918867400715, 0.060020554677716324, 0.049682178002383025, 0.017284446362672106, 0.057076146959194114, 0.04934865089931658, 0.042965390386858156, 0.05215808103925415, 0.03681580715679696, 0.006618483158360634, 0.126657599317176, 0.03346007490264518, 0.055029254473213635, 0.05176681399877582, 0.14778635198516504, 0.12488555083317415, 0.13774536363780499, 0.12255179749003478, 0.20088106580078602, 0.149882455223373, 0.15311868728271552, 0.16951465819563183, 0.18074272998741694, 0.1617761291563511, 0.11041059398225375, 0.16433850808867387, 0.1175197817917381, 0.1972617328699146, 0.24456557099308285, 0.1464427983654397, 0.13302180995898588, 0.436348771410329, 0.6622147315314838, 47.1538941519601, 126.26688929966518, 96.94584560394287, 95.85588863917759, 70.73070226396833, 73.66842147282192, 87.6252749306815, 67.75571986607143, 68.4682923725673, 30.633245740618023, 0.34115587228110855, 0.37629915507776396, 1.3579873080764497, 4.705888535295214, 2.486037228788648, 1.300953128508159, 4.4643226861953735, 6.197777509689331, 1.937726216656821, 85.95146778651646, 95.138181413923, 102.82911464146206, 90.90426880972726, 97.75975063868931, 96.87517547607422, 96.92792619977678, 93.41652202606201, 96.02008846827916, 96.10943535396031, 88.34973580496651, 85.30129010336739, 88.52674811226981, 77.57298251560756, 75.02120099748883, 63.79314136505127, 64.3528812953404, 65.35244914463588, 64.43486309051514, 64.14453956059047, 65.80329690660749, 63.353410720825195, 64.68965353284563, 61.53995868137905, 63.03467600686209, 58.81446525028774, 60.35032285962786, 60.78211866106306, 57.88637351989746, 59.563050270080566, 64.05403927394322, 64.03195095062256, 66.19575895581926, 61.76895046234131, 70.99214213235038, 79.63379042489188, 75.4493350982666, 73.71974781581334, 77.95975399017334, 76.56561183929443, 73.54792581285749, 66.72335651942662, 67.06588186536516, 71.77703843797956, 74.90320668901715, 79.0144349506923, 74.33501080104283, 76.87416744232178, 71.56075491224016, 73.47953469412667, 46.69251639502389, 65.58237198420933, 75.15605163574219, 71.10008934565953, 75.77224567958287, 74.9024771281651, 74.82373319353376, 78.73393617357526, 76.92175565447126, 72.43082223619733, 65.90414306095668, 62.2472505569458, 61.372618266514365, 63.63121359688895, 65.07074138096401, 60.60373755863735, 69.198075566973, 61.25320652553013, 58.108569962637766, 59.956408636910574, 59.689952169145855, 73.59384645734514, 76.28884424482072, 74.80724511827741, 71.89087077549526, 66.22954109736851, 67.5464540209089, 70.73407908848354, 69.9004133769444, 70.88330554962158, 71.7985292162214, 75.37849821363176, 76.15096419198173, 77.59413283211845, 68.46488775525773, 61.9539531980242, 66.59073625292096, 69.27941812787736, 71.70266492026192, 74.69244698115757, 78.31195817674909, 79.79330716814313, 80.97434112003872, 82.41641889299665, 67.31195231846401, 1.093779125383922, 5.14399026121412, 8.695194584982735, 1.9564550859587533, 1.244323030114174, 1.2137369513511658, 3.15152222769601, 1.1401797384023666, 0.21904855594038963, 0.2836484009666102, 15.804266554968697, 44.600632667541504, 58.62468215397426, 68.07491316114152, 44.266629287174766, 32.135689462934224, 58.656428473336355, 66.25462409428188, 75.36874294281006, 96.42366763523647, 55.946985380990164, 0.30977045212473187, 0.17588227508323534, 0.13194551771240576, 0.16752595348017557, 0.21075094118714333, 0.1275291232658284, 0.19614794477820396, 0.07631837550018515, 0.17935907494808945, 0.13330414838024549, 0.10626882979912416, 0.09790287978414978, 0.12365641178829329, 0.14095506497791835, 0.1633054656641824, 0.11189149666045393, 0.09170786863459007, 0.10548895557544061, 0.19684944142188343, 0.08129065297544003, 0.20614459764744553, 0.16167620808950492], [0.051710604157830985, 0.02368564055567341, 0.045386396548045535, 0.026406862839524235, 0.04290235109095063, 0.04781648490045752, 0.007273432299760836, 0.06270167045295238, 0.057923996821045876, 0.09168346851531949, 0.046513599277074845, 0.04355738504922815, 0.028196955266009485, 0.08923984678196055, 0.02132992133764284, 0.041178064686911445, 0.025141032013509954, 0.09080760194254772, 0.20356634099568638, 61.28782939910889, 88.69809763772147, 79.57576601845878, 59.78633063180106, 47.14579602650234, 36.298806871686665, 80.20837865556989, 75.53622926984514, 43.88455826895577, 2.9299706646374295, 0.13431530126503535, 0.12690682522952557, 0.2654975620763642, 0.5391436240502766, 0.3335858370576586, 0.4822333721177918, 1.9744279044015067, 1.7331694045237132, 37.84369713919503, 107.68719087328229, 88.32932199750627, 94.64662415640694, 85.55247443062919, 91.69314643314907, 83.70234979901994, 89.11127921513149, 84.76233918326241, 86.21161528996059, 76.32416193825858, 80.2599412373134, 77.51504148755754, 72.91381236485073, 70.63993099757603, 63.8037234715053, 55.57490587234497, 56.69499717439924, 56.09730270930699, 56.421290261404856, 55.27999305725098, 55.40324020385742, 54.21605709620884, 55.028030531747, 53.223173413957866, 53.10369913918631, 53.61292219161987, 52.616355964115684, 50.163158961704795, 50.9073874609811, 52.51325511932373, 55.92242349897112, 58.657859802246094, 58.80986554282052, 54.76451315198626, 65.25058160509381, 71.55855233328683, 71.16278988974435, 70.99264935084751, 71.22923551286969, 69.65033381325858, 64.92072282518659, 60.317270278930664, 61.08317020961216, 65.86068207877022, 66.3177137374878, 63.64961242675781, 66.29037257603237, 67.43075261797223, 68.95222745622907, 67.90614836556571, 40.02395500455584, 62.175496510096956, 71.72642081124442, 63.169985226222444, 66.13824871608189, 68.07460049220494, 70.2698838370187, 68.15323325565883, 70.74138164520264, 66.19594655718122, 58.033671855926514, 51.11309582846505, 55.254069328308105, 56.31200899396624, 55.287358147757395, 53.68336302893502, 59.848920004708425, 60.65094361986433, 51.44494874136788, 52.1903202193124, 52.01018817084176, 53.22187410082136, 55.159639835357666, 56.417764050619944, 56.68451234272548, 55.68427051816668, 58.47098800114223, 59.68010657174246, 63.83098125457764, 65.53377628326416, 65.06840678623745, 68.60159356253487, 67.45772552490234, 66.49904087611607, 56.09860897064209, 54.54088190623692, 55.88379498890468, 60.94478293827602, 64.19692202976772, 68.2982907976423, 71.89337907518659, 71.58576147896903, 76.11818953922817, 73.09156812940324, 78.78946617671421, 37.474181515829905, 0.6002971625753811, 1.5483452592577254, 1.28720047218459, 0.3201911486685276, 0.3008584374827998, 0.14312864334455558, 0.7126544192433357, 0.35850837400981356, 0.05634083552286029, 0.2865983455308846, 14.92215279170445, 29.580350467136928, 59.414379664829795, 50.970188753945486, 25.90650088446481, 38.306402002062114, 60.84359632219587, 61.85628931862967, 67.37586879730225, 79.28453922271729, 3.9036265100751604, 0.41776806701506886, 0.13272557514054434, 0.02671491095264043, 0.04488211950021131, 0.06824176638786282, 0.030348164029419422, 0.059673287240522246, 0.019204780193311826, 0.029990626964718103, 0.02165517540249441, 0.059565576591662, 0.06043757551482745, 0.02855318784713745, 0.01153242782623108, 0.0423930528839784, 0.06235117318906954, 0.00923446296448154, 0.023007399003420557, 0.0551963471142309, 0.05797200995896544, 0.0500549515709281, 0.005918466145106192, 0.005671787707667265, 0.010514099433618997, 0.021334026474505663, 0.030624558483915668, 0.012374168328408684, 0.04032746675823416, 0.028099614328571727, 0.021465892970029796, 0.038268197793513536, 0.014861696366486805, 0.1132429823545473, 0.031269329600036144, 0.02826882739152227, 0.044199598088328323, 0.06393152874495302, 0.0347472219062703, 0.019249987588929277, 0.5193518974951336, 83.36664758409772, 98.83729812077114, 85.71094199589321, 71.30054487500871, 61.56072684696743, 52.420698165893555, 75.2030006136213, 73.03669820513043, 47.51812219619751, 3.4503077949796404, 0.09716580076409237, 0.09829915102039065, 1.2321890869310923, 0.5369618354099137, 0.39238021788852556, 1.933451337473733, 0.6711924012218202, 1.1542701423168182, 48.614342961992534, 111.32297474997384, 91.84574277060372, 96.38741193498883, 87.33270018441337, 96.04458781651088, 88.66608033861432, 92.51818248203823, 88.10533986772809, 91.17511653900146, 79.60924938746861, 82.46345124925885, 80.98038605281285, 76.11256844656808, 73.39113971165249, 66.93164266858781, 58.644852774483816, 59.500294140407014, 58.78025232042585, 59.56937313079834, 58.76150608062744, 58.679503440856934, 56.14680862426758, 58.18035875047956, 58.601169449942454, 55.92252772194998, 55.72910376957485, 55.731191703251426, 54.71856818880354, 55.590112004961284, 56.24811683382307, 59.74245970589774, 61.87937123434884, 61.99228640965053, 56.56265830993652, 67.55290194920131, 73.06427560533795, 72.32971899850028, 74.23840999603271, 74.1803925377982, 72.9532642364502, 66.37327848161969, 63.3567875453404, 64.11329351152692, 69.5847567149571, 69.57058933803013, 67.10616752079555, 67.34711715153286, 71.08216299329484, 70.40374783107212, 70.85458169664655, 44.35407584054129, 64.2525006702968, 75.5614720753261, 65.60919203077043, 69.78061948503766, 72.71901961735317, 72.02315752846854, 71.47304780142647, 72.33905042920793, 68.66520432063511, 60.725921630859375, 52.48587574277605, 58.404806409563335, 60.777630124773296, 60.37833104814802, 57.438794885362896, 60.40644345964704, 63.05208124433245, 53.65330164773123, 56.651199204581125, 55.430306911468506, 55.93026801518032, 57.307192529950825, 59.09885501861572, 58.320830481392996, 58.54321452549526, 60.360522815159385, 63.106075695582796, 65.92834363664899, 68.94866303035191, 67.71181419917515, 72.43009962354387, 69.98361110687256, 68.38392039707729, 57.62161936078753, 56.51960032326834, 59.47004863194057, 63.85734966823033, 66.38893277304513, 70.82532978057861, 75.29412623814174, 75.82634435381208, 77.35972840445382, 76.18074417114258, 81.0956288746425, 52.50246804101126, 1.1208024067538125, 0.3278883956372738, 0.816894497190203, 0.8489397519401142, 1.606214091181755, 0.483875861125333, 1.1919667252472468, 0.4683236756495067, 0.3380397952028683, 0.11291255615651608, 16.434468167168752, 33.91880219323294, 47.43228415080479, 29.52155133656093, 32.38100256238665, 51.445945807865684, 68.27274921962193, 70.84214442116874, 72.71233545030866, 91.79370076315743, 11.745957510811941, 0.5781891888805798, 0.12042681580143315, 0.08706131510968719, 0.0740157804851021, 0.05481159740260669, 0.024286264487143074, 0.06364794181925909, 0.07416074270648615, 0.038375989866576025, 0.031156146566250494, 0.07353768471096243, 0.049542545673570464, 0.06092616144035544, 0.03791088803804346, 0.04201340914836951, 0.02985406500686492, 0.01598303485661745, 0.06193668328757797, 0.05690431475107159, 0.05074107939643519, 0.01828145348866071, 0.11237756522106272, 0.11493003075676304, 0.2134941497019359, 0.13481071325285093, 0.0784521306465779, 0.21732822539550917, 0.1069253734978182, 0.11332191633326666, 0.16657337173819542, 0.26677863619157244, 0.11014340046261038, 0.263418585062027, 0.14561995251902513, 0.20357113145291805, 0.20867823383637837, 0.13385127830718244, 0.2081069616334779, 0.14149600666548523, 0.648886458149978, 93.26599625178746, 112.58420481000627, 100.48858615330288, 84.30447374071393, 63.978609630039756, 49.323760986328125, 103.44679559980119, 90.41932623726981, 65.91469042641776, 5.251300845827375, 0.3563598064439637, 0.27185497379728724, 2.2208535841533115, 2.0880930508886064, 0.8498693449156625, 3.7604176231792996, 7.052124100072043, 4.006699996335166, 46.879266602652415, 116.68226623535156, 95.3004218510219, 102.23307732173375, 90.48907920292446, 100.50335107530866, 91.50022969927106, 96.43416636330741, 90.44414520263672, 93.75249522072929, 86.49845082419259, 87.16793755122593, 84.49217932564872, 78.86527797154018, 76.98995222364152, 71.61433247157505, 62.41685608455113, 63.75573921203613, 62.31987312861851, 63.25601087297712, 60.76575565338135, 61.320680482046946, 60.01152869633266, 62.17548956189837, 61.49845014299665, 60.532643590654644, 59.843389238630024, 60.677214758736746, 59.797065598624094, 60.54332297188895, 58.980311802455354, 64.12874630519322, 64.9259339741298, 65.20138835906982, 60.379929133823936, 72.70727716173444, 76.95145920344761, 77.7388916015625, 77.91367353711809, 77.87257494245256, 76.35840266091483, 70.11272253308977, 68.66330051422119, 68.5501629965646, 73.75317559923444, 72.23177024296352, 69.74685818808419, 71.8395722252982, 74.38186250414167, 76.09655284881592, 73.68363802773612, 50.19388042177473, 68.37557561056954, 80.35078198569161, 70.13740948268345, 72.389737537929, 76.86710112435478, 73.42192023141044, 74.62793295724052, 75.24866417476109, 74.7842048917498, 65.18897887638637, 55.13110705784389, 60.99657481057303, 64.53135967254639, 61.21505396706717, 60.68095983777727, 63.81639003753662, 65.59768581390381, 57.65828847885132, 58.54959992000035, 58.24948637826102, 59.392471994672505, 61.8560391834804, 63.19117028372628, 63.644220624651226, 63.45765454428536, 63.199862480163574, 65.6081428527832, 70.91205719539097, 72.9106092453003, 72.68652289254325, 77.12823527199882, 73.76732907976422, 73.35480758122036, 60.9143637248448, 61.84966768537249, 61.79443645477295, 68.54129014696393, 69.58233179364885, 74.77949401310512, 77.1449943270002, 78.30650384085519, 81.83481992994035, 79.76890509469169, 84.67709868294853, 55.85294151306152, 1.3443046765668052, 5.318290165492466, 5.698636293411255, 0.7998360182557787, 1.5084845295974185, 2.273692245994295, 2.469419091939926, 0.8553710154124669, 0.5144897869655064, 0.2723145862775189, 25.03335550853184, 44.82943684714181, 78.54784257071358, 67.17307867322648, 35.5609255518232, 52.85836172103882, 76.33187443869454, 82.83509649549211, 82.91421563284737, 104.22013010297502, 10.76723859991346, 0.8017108919365066, 0.27031703346541947, 0.18354049271770886, 0.09817940316029958, 0.15154063196054526, 0.12974155454763345, 0.16861771632518086, 0.20395031039203915, 0.1738765255681106, 0.14342671020754746, 0.16088116860815457, 0.1107926634805543, 0.14584298697965487, 0.08889184652694634, 0.19772506372204848, 0.10372250500534262, 0.23410269671252795, 0.13185694175107138, 0.11592759937047958, 0.1731930508145264, 0.11568177970392363], [0.04010182333045772, 0.1152790691703558, 0.01894023804925382, 0.056645870940493684, 0.08073284969265972, 0.030218448489904404, 0.051818901739482365, 0.055485783011785576, 0.0134423190029338, 0.018311270013717667, 0.09829491017652409, 0.04091289659429874, 0.08158517110028438, 0.01128943171352148, 0.04100682619693024, 0.09112614020705223, 0.2736344454543931, 0.4547831022313663, 7.144881248474121, 91.28628076825822, 78.53004823412213, 70.52149895259312, 39.489100047520225, 25.824611152921403, 32.09582069941929, 61.56959274836949, 60.90970843178885, 14.799226999282837, 0.13750559650361538, 0.015063830252204622, 0.34358635757650646, 0.9333687786545072, 0.11253790304596935, 0.7283243983983994, 0.6506781162960189, 2.1287662855216434, 8.027464015143257, 102.36896324157715, 86.10632923671177, 94.60887459346226, 88.0233233315604, 91.40947232927594, 85.8269352231707, 91.01129886082241, 85.3266440800258, 87.68356336866105, 80.53488145555768, 79.70887960706438, 75.41788755144391, 72.99832330431256, 72.77205521719796, 65.04588072640556, 55.02289581298828, 56.315893036978586, 56.10869428089687, 55.25813055038452, 53.9589216368539, 56.14435591016497, 55.383896418980186, 56.72146981103079, 54.35019901820591, 55.28751795632498, 51.98299639565604, 51.87252698625837, 50.744163853781565, 51.822357518332346, 50.40459844044277, 55.14082063947405, 55.54005023411342, 65.06623894827706, 59.75741917746407, 56.00580883026123, 63.020050048828125, 71.0083453314645, 68.36749485560826, 66.93652030399868, 72.65189307076591, 71.06409072875977, 65.99207946232387, 62.028104373386924, 56.214348588671, 61.05792045593262, 59.60243960789272, 58.41358198438372, 57.3343391418457, 62.14921842302595, 66.9597064426967, 67.9391175678798, 37.63419852937971, 60.24905981336321, 67.9424388068063, 61.70360960279192, 61.3773569379534, 62.49253586360386, 67.08489908490861, 66.55995573316301, 65.59758159092495, 59.526725087847026, 53.97445780890328, 53.48901149204799, 54.433945655822754, 59.86088480268206, 61.016154834202354, 56.27571507862636, 53.60311828340803, 60.59515653337751, 58.38630335671561, 52.353321484157014, 52.91536821637835, 51.894618783678325, 51.5095774105617, 50.50462818145752, 53.10628734316145, 51.237673555101665, 52.11024570465088, 53.739553110940115, 54.44194303240095, 59.91157191140311, 63.48439121246338, 65.11972618103027, 65.27737385886056, 59.39730099269322, 52.40375845772879, 52.37559046064104, 55.17764956610543, 62.082480975559776, 64.81409576960972, 69.70468262263707, 69.57145091465541, 72.20032269614083, 71.14772619519914, 72.77623108455113, 72.79964651380266, 76.54271752493722, 27.93387927327837, 0.9615633743149894, 1.400328653199332, 2.7445827381951466, 0.4594947951180594, 0.8320392902408327, 1.3240355870553424, 1.970785528421402, 0.40247063072664396, 0.12374969678265707, 4.31848520892007, 26.32800814083644, 47.19494410923549, 74.36025360652378, 32.48612185886928, 24.4997946534838, 39.71005276271275, 56.29684107644217, 59.75334753308977, 73.804091998509, 38.21577664784023, 0.6091571471520832, 0.04260211970124926, 0.0778388978381242, 0.024726971285417676, 0.03183657130492585, 0.039453357591160705, 0.052772728593221734, 0.03281188057735562, 0.021271818383995975, 0.04299606356237616, 0.03694891197873013, 0.003401090411768694, 0.056957505111183436, 0.04073289143187659, 0.015598059532099535, 0.04658806510269642, 0.04095932535294976, 0.005898176251711058, 0.011020195803471973, 0.0323841626356755, 0.043098644486495426, 0.02627978171221912, 0.050920959029878886, 0.035478502844593356, 0.050419782887079885, 0.005995893351999777, 0.055838756928486485, 0.015867229284984723, 0.03036999928631953, 0.02130031176576657, 0.0868547215525593, 0.07879627003733601, 0.023656153120100498, 0.06093326570200069, 0.004425505899624633, 0.03810066071205905, 0.06549943318324429, 0.2636204628007752, 0.6530799674136298, 14.180867723056249, 107.80253791809082, 83.86183180127824, 81.0611936024257, 46.77796881539481, 39.337851660592214, 30.65257910319737, 58.04341670445034, 64.25821208953857, 16.452476160866873, 0.07468534527080399, 0.5320743748119899, 0.2599382703857762, 2.581746927329472, 0.4074259176850319, 1.8354489505290985, 1.0962065437010355, 1.5309613006455558, 13.82102312360491, 110.66149234771729, 86.90583065577916, 97.29866818019322, 91.789733341762, 95.92650318145752, 89.05495016915458, 93.2651902607509, 86.94793673924038, 90.43297249930245, 82.07364341190883, 84.8870940889631, 77.43517194475446, 78.3751311983381, 75.51762894221714, 68.48135498591832, 58.84379359654018, 60.278422900608604, 59.79322324480329, 57.9499842779977, 55.99997581754412, 59.76764692578997, 56.02418334143502, 59.439316749572754, 56.410767214638845, 59.6316567829677, 54.4930157661438, 55.0842136655535, 52.90743337358747, 54.54465477807181, 52.69118111474173, 58.640572684151785, 57.89932843617031, 66.81038270677838, 62.05113765171596, 59.92828927721296, 64.63095515114921, 75.62231050218854, 71.85126604352678, 68.65444156101772, 73.36554254804338, 74.12532111576625, 68.72762693677629, 65.27109963553292, 59.057971818106516, 64.05542891366142, 63.53435570853097, 62.0732398714338, 60.25379153660366, 65.22734682900565, 68.67181205749512, 70.29952485220772, 39.4365473474775, 63.41363770621163, 70.91740730830601, 64.78168937138149, 65.41612938472203, 64.96609456198556, 70.25698798043388, 69.41916724613735, 67.92458888462612, 62.200065340314595, 56.04904747009277, 55.16539294379098, 57.227382046835764, 61.42873191833496, 63.70828301565987, 59.06584412711007, 56.32752432141985, 63.00128296443394, 59.76773030417306, 54.208761487688335, 54.16839940207345, 54.29551669529506, 53.11302362169538, 52.365387031010215, 55.144666467394146, 53.331256117139546, 53.332746505737305, 56.0287378856114, 57.06343930108206, 63.694977215358186, 66.53327465057373, 66.42305537632534, 68.68178967067173, 62.236425263541086, 54.602321352277485, 54.898335456848145, 57.36171851839338, 65.13708972930908, 68.0089191709246, 72.43557480403355, 71.72252287183488, 75.30366611480713, 74.34763567788261, 76.41548906053815, 75.45260075160435, 81.19269520895821, 42.34580673490252, 1.1743201464414597, 1.5420093706675937, 1.3122414542096001, 1.2513003242867333, 3.16374780024801, 2.201264658144542, 2.1960713139602115, 0.0582974964220609, 0.22794911691120692, 3.601011399711881, 30.508240699768066, 44.31343930108206, 55.15427930014474, 30.904951572418213, 37.55580200467791, 48.138148171561106, 63.04745374407087, 68.35307039533342, 79.71605709620884, 60.19743469783238, 0.9843282784734453, 0.0225359189457127, 0.0830114313534328, 0.015682917121531706, 0.024806724595172063, 0.035702056384512355, 0.030609403404274156, 0.0167721761723182, 0.007191167562268674, 0.03998830442183784, 0.08796392274754387, 0.049681472325963635, 0.06147671118378639, 0.03962017542549542, 0.01005758361757866, 0.07480877079069614, 0.051172016986778805, 0.007618674309924245, 0.0019119698263239115, 0.04514835289280329, 0.021780209050380757, 0.06957658726189818, 0.2051788523261036, 0.15563154672937735, 0.1880986602710826, 0.13677148946693965, 0.1605258198188884, 0.0974401935402836, 0.13083185175699846, 0.15713938724781784, 0.13535797888679163, 0.1863900955234255, 0.155141128759299, 0.14839023458106176, 0.11391563447458403, 0.15371844438569887, 0.19800304594848836, 0.4834807366132736, 0.9926112911530903, 15.788172789982386, 121.94164957318986, 98.70037691933769, 93.66772024972099, 57.417529923575266, 40.82993909290859, 46.41004432950701, 77.88068349020821, 74.01717240469796, 27.47745384488787, 0.23422670577253613, 0.5026838204690388, 1.836481192282268, 4.554836869239807, 0.6297552447233881, 2.4730907806328366, 5.2896327546664645, 5.784099570342472, 12.05018699169159, 115.5660103389195, 89.68436663491386, 102.78592463902065, 95.29491887773786, 99.39249392918178, 91.29049137660435, 97.84426852634975, 90.00716604505266, 94.92170333862305, 89.20139735085624, 88.1265457698277, 81.87869085584367, 82.59904534476144, 79.81567341940743, 73.79237733568463, 60.48844609941755, 64.95137827736991, 62.64481953212193, 62.39308629717146, 60.16050502232143, 63.56533772604806, 60.6917781829834, 64.20045866285051, 60.017240115574424, 63.046751976013184, 56.76188053403582, 58.80009637560163, 57.094313621520996, 60.09000859941755, 56.260349137442454, 62.08755316053118, 62.07319818224226, 69.87412139347622, 64.39723859514508, 63.37530449458531, 66.94098104749406, 76.95338385445731, 74.2258129119873, 70.87196608952114, 76.10741983141217, 77.01067870003837, 72.27886513301304, 67.75899941580636, 61.79699339185442, 68.61311367579869, 65.86874893733433, 65.46636486053467, 63.26814242771694, 67.23177010672433, 73.40076296670097, 74.72373471941266, 46.198523793901714, 67.36554377419608, 74.71206174577985, 67.86779430934361, 68.31610597882951, 69.76148414611816, 73.26949065072196, 73.87897968292236, 72.79801368713379, 64.8408602305821, 60.515022959027974, 57.143378325871055, 61.56536824362618, 66.82170827048165, 66.81958212171281, 62.51338740757534, 59.139495032174246, 66.02918979099819, 62.77145045144217, 56.33403478349958, 57.59923573902675, 57.68357992172241, 58.032824175698416, 54.819007873535156, 58.54144968305315, 56.45407881055559, 57.05128342764718, 60.67745099748884, 60.29366030011858, 68.54875946044922, 71.13044602530343, 71.315080506461, 72.47661086491176, 67.8009317943028, 57.05514662606375, 57.592461245400564, 60.196489742824006, 69.44423634665353, 73.15406022753034, 75.65857315063477, 76.5388960157122, 80.61484827314104, 77.81327206747872, 79.26644611358643, 77.91425718579973, 86.47602203914097, 40.921954086848665, 1.7404966056346893, 9.400077172688075, 7.319508586611066, 0.7466827875801495, 3.475408596651895, 5.272580138274601, 4.2638862643923074, 0.8896659665874073, 0.23923787687505993, 6.606445363589695, 41.8991904258728, 64.03479276384626, 100.17324216025216, 41.86531448364258, 35.918118544987266, 53.671200207301546, 73.67322267804826, 75.71412399836949, 95.12977409362793, 60.557427815028596, 0.6056369617581367, 0.23770137503743172, 0.14159564274762357, 0.11971895449927875, 0.14637460559606552, 0.14627399242350034, 0.11350531756345715, 0.15696655080786773, 0.0947750640500869, 0.144217027085168, 0.13340938916163786, 0.2178469654172659, 0.14941582669104847, 0.12435296869703702, 0.0809112840465137, 0.1670614012650081, 0.20386013308806078, 0.07763368170708418, 0.0919344246919666, 0.13851848643805298, 0.11189006495156459], [0.07072926898087774, 0.01224380818062595, 0.047229419794998, 0.009683235847790326, 0.011480402850013758, 0.010027370149535792, 0.023099130152591636, 0.0564270773237305, 0.06547420525125094, 0.062333823048642704, 0.08109568950853177, 0.03179523155891469, 0.1051304583836879, 0.05243518117016979, 0.12245225640279905, 0.011273501407621163, 0.1535932682454586, 0.17170638058866772, 46.65361343111311, 86.60345200129917, 74.78697722298759, 66.84469291142055, 58.12506151199341, 40.3503292628697, 56.96130425589425, 73.31805855887276, 37.27806166240147, 3.2803114312035695, 0.10768201468246323, 0.12009256945124694, 0.20160257922751562, 1.1063956426722663, 0.13561844133905002, 0.2488449013658932, 0.6920900855745588, 0.16389237131391252, 62.54752390725272, 102.23097201756069, 81.89378234318325, 86.74418081556047, 85.8847998210362, 89.96152332850865, 84.89425768171037, 85.55356529780796, 77.12437902178083, 73.44275093078613, 72.65217099870954, 72.47963333129883, 69.1537252153669, 67.67316831861223, 61.69629314967564, 58.03678812299456, 55.42991781234741, 57.302637985774446, 57.053861209324424, 56.52118798664638, 55.943754468645366, 55.375047888074604, 54.36056225640433, 55.72258983339582, 52.852990763528005, 52.741145610809326, 50.832350390298025, 50.52726541246687, 49.132935660226, 50.1349527495248, 52.30370092391968, 55.89362668991089, 57.389222962515696, 61.94779709407261, 62.475241797310964, 55.22835751942226, 60.159177916390554, 71.04525416237968, 69.40090043204171, 69.01725564684186, 66.4103957584926, 70.9032677241734, 65.86602524348667, 67.72355665479387, 59.5407326562064, 60.62720857347761, 57.373134408678325, 59.337692396981375, 58.24861437933785, 64.65400927407401, 65.32091127123151, 64.80651528494698, 33.04128292628697, 61.59498841421944, 69.74396078927177, 62.709500312805176, 59.915935380118235, 57.4394827570234, 58.81013652256557, 54.49033376148769, 51.540882519313264, 49.072371687207905, 49.01574386869158, 50.02197504043579, 53.31289897646223, 58.252578326633994, 61.36409282684326, 60.659816469464985, 54.116638796670095, 59.74090330941336, 62.45140947614397, 53.76493488039289, 49.5478959764753, 49.59099565233503, 51.66924006598336, 50.41437455586025, 52.64266184398106, 50.294959340776714, 51.342341218675884, 49.08827611378261, 50.8751790864127, 51.29808119365147, 56.748519148145405, 58.44302845001221, 58.486211504255024, 52.45306634902954, 52.06281035287039, 53.493711948394775, 57.40462017059326, 60.568565777369905, 66.47089372362409, 69.73106493268693, 70.2362892968314, 70.6491026197161, 70.16576508113316, 67.24466596330915, 72.71201583317348, 71.28869124821254, 78.56101635524205, 23.3949841771807, 0.9666593351534435, 2.7835940505777086, 2.7081676636423384, 0.13363725479160035, 0.8935864876423563, 0.319746165403298, 0.6948228446500642, 0.17980092338153295, 0.07600215782544442, 13.36313509941101, 28.83000234195164, 43.823695523398264, 48.94734580176217, 14.661529336656843, 32.875102860586985, 56.01280566624233, 66.03485257284981, 61.461492674691335, 78.98407132284981, 12.48286781992231, 0.6113830134272575, 0.0929975805005857, 0.08740421956671135, 0.10274044770215239, 0.03940711882231491, 0.08634042593517474, 0.11272776392953736, 0.01960171469753342, 0.025005431879045706, 0.02628400220003511, 0.024610224246446575, 0.033558540511876345, 0.03719242801889777, 0.05071159365719982, 0.03480859539870705, 0.0012514323129185609, 0.007566140432442937, 0.059953617198126655, 0.05213201850918787, 0.02765606955758163, 0.016061731348080293, 0.07100067620298692, 0.004634365339630416, 0.009208320706550564, 0.06654903186219079, 0.011089171432623906, 0.03432651323133281, 0.04418658378667065, 0.033478039117263894, 0.020683306302609186, 0.047394168097525835, 0.06885915183063064, 0.04563815339601465, 0.0972422988020948, 0.036518062597938945, 0.04781738735203232, 0.028475641472531215, 0.18656213129205362, 67.28346470424107, 96.26026684897286, 83.00564002990723, 79.18146964481899, 66.1277916772025, 46.70962633405413, 34.723938601357595, 74.03994165148053, 41.94941200528826, 4.600911242621286, 0.09931651928595134, 0.6934085605399949, 1.6448072088616235, 1.4164322976555144, 0.5986393115350178, 1.1048757242304938, 0.47886197588273455, 0.476778439113072, 71.76388549804688, 102.01709256853376, 86.95624678475517, 89.36856406075614, 90.96683733803886, 93.06299768175397, 89.46651281629289, 89.11601788657052, 80.95117582593645, 78.17371681758335, 76.66526290348598, 76.86541966029576, 71.91959462847028, 72.03752640315464, 63.83137730189732, 60.240555218287874, 57.43337181636265, 59.269065039498464, 59.31577777862549, 60.578446115766255, 58.79025077819824, 58.70530210222517, 56.43733017785208, 59.274915422712056, 56.843678201947895, 55.323304653167725, 54.63970613479614, 54.446129322052, 52.794309752328054, 54.31828941617693, 55.04306990759713, 60.28607981545584, 60.038070814950125, 62.780649866376606, 66.12902150835309, 58.45842565808977, 63.46144131251744, 73.19104548863002, 71.23352949959892, 72.24709102085659, 67.2227999823434, 71.83108847481864, 69.55088424682617, 71.44334425245012, 63.033272470746724, 61.8209160396031, 60.93344347817557, 62.81450843811035, 61.2404704775129, 67.23675196511405, 67.77093642098563, 68.02304485866001, 38.03539793831961, 64.93168013436454, 73.36739771706718, 66.0904312133789, 63.2637859072004, 58.46399811335972, 61.76704665592739, 55.33776038033621, 54.58523920604161, 51.11063616616385, 50.13373681477138, 51.29900530406407, 58.10597481046404, 60.88806479317801, 64.81968212127686, 64.59514413561139, 57.71695906775338, 62.53135544913155, 65.505920955113, 56.455544880458284, 52.97960778645107, 52.08311298915318, 54.251475538526265, 52.06721898487636, 55.99029002870832, 51.59334141867501, 53.54579217093331, 51.55835029057094, 53.01312589645386, 55.20617192132132, 59.11881719316755, 60.274351256234304, 60.80398464202881, 54.876254081726074, 54.280956745147705, 55.16397203717913, 59.76365171160017, 63.33790234157017, 69.80505629948208, 71.39864649091447, 74.37293406895229, 72.27573844364711, 74.4311043875558, 69.77783325740269, 74.82244777679443, 73.46004499707902, 83.33365753718785, 35.59174428667341, 1.5181922486850192, 0.8732617582593645, 1.0401836527245385, 0.5282653506313051, 3.3690922558307648, 1.6057555100747516, 1.7301035118954522, 0.26976712154490606, 0.11682163711105074, 12.4328225510461, 34.27038104193551, 37.84953710011074, 34.96337699890137, 18.626569237027848, 50.22719703401838, 67.32626560756138, 72.59379918234688, 68.556305204119, 88.93290506090436, 24.82258016722543, 0.6077166987316949, 0.05965012205498559, 0.10007344545530421, 0.0923512623246227, 0.02072978764772415, 0.032832986409110684, 0.11500806228390761, 0.0701512046424406, 0.041515920843396864, 0.06134737562388182, 0.06128878412502153, 0.02076472371949681, 0.015486720417227064, 0.040537873682166846, 0.036715431471488306, 0.01922337883817298, 0.012110596489427345, 0.10379346619759287, 0.028611904874976193, 0.011050568727244223, 0.15329555422067642, 0.10857214406132698, 0.12818103257034505, 0.11926401033997536, 0.1716031211295298, 0.1531590601163251, 0.2079675905406475, 0.09909661287175757, 0.16372625237064703, 0.12119292254958834, 0.168454786496503, 0.1094676067254373, 0.23891771691186087, 0.14805383048951626, 0.14264297511960777, 0.11843075576637473, 0.1745695812361581, 0.20762695239058562, 73.50267914363316, 113.67603778839111, 93.71390492575509, 89.1235636302403, 77.1074115208217, 58.83367007119315, 73.07897799355644, 92.98203032357353, 54.04950530188424, 7.401348812239511, 0.31763190456799095, 1.481716268828937, 2.2963431562696184, 3.159744117941175, 1.0646664989846093, 1.5044684708118439, 4.756506596292768, 0.5962118932179042, 74.97581536429269, 108.38521385192871, 92.85162653241838, 94.28222588130406, 92.25051007952008, 97.40822737557548, 93.35791397094727, 94.08703013828823, 85.33434963226318, 80.75388867514474, 79.19438634599958, 81.17104462214878, 77.30319091251918, 75.27004378182548, 68.09365245274135, 64.1286837714059, 60.983915192740305, 62.95082514626639, 64.33103615897042, 63.62268120901925, 63.03155626569475, 61.49236352103097, 59.7333436693464, 62.14482021331787, 60.47812107631138, 59.087939398629324, 57.862871238163535, 57.26214041028704, 55.92713785171509, 58.03112881524222, 57.34331274032593, 62.39139788491385, 62.285139083862305, 65.36226000104631, 67.36839253561837, 62.173148018973215, 66.79432541983468, 77.24845995221818, 75.76873683929443, 74.13223457336426, 69.31761932373047, 73.41667434147426, 71.4948581968035, 73.94679410117013, 65.17424869537354, 65.97443798610142, 63.616539001464844, 66.21406051090786, 63.735110010419575, 71.05551665169853, 71.28407069614956, 72.14335441589355, 43.89910084860665, 68.25624029976981, 76.26462977273124, 70.17204625265938, 65.82953330448696, 63.467930930001394, 64.9779759815761, 59.94649355752127, 57.80120250156948, 54.32350403921944, 54.46237073625837, 55.7388972554888, 60.82313387734549, 65.34839834485734, 66.68705912998745, 67.26027161734444, 60.114014625549316, 64.28700542449951, 68.9835638318743, 59.939628737313406, 55.00774874005999, 54.46923903056553, 56.20154653276716, 54.95706163133894, 58.85329873221261, 54.58189017432076, 57.302294049944194, 54.95396968296596, 57.284861019679475, 57.92155572346279, 63.72062301635742, 66.08624144962856, 65.86134215763637, 57.017341477530344, 59.22684778485979, 59.854193687438965, 63.91943877083914, 66.58827659061977, 73.90656403132847, 74.63968236105782, 76.1218512398856, 74.787428855896, 78.61615031106132, 73.70389202662876, 79.54432541983468, 76.97263731275285, 89.3296263558524, 34.62005955832345, 2.2710410739694322, 9.695815086364746, 6.610974720546177, 0.44381561502814293, 3.1351045029503957, 3.320160001516342, 1.7778370933873313, 0.4496701237346445, 0.23771364295056888, 21.986714601516724, 43.98026623044695, 60.59559426988874, 66.93110070909772, 20.806220872061594, 49.78891856329781, 73.20941652570451, 85.50993061065674, 75.00351783207485, 105.15614972795758, 21.146126747131348, 0.9677669214350837, 0.38051806869251387, 0.2769388567124094, 0.19433111298297132, 0.2279689572751522, 0.19298504878367695, 0.21212221974773066, 0.16553230902978353, 0.15890327974089555, 0.11135259057794299, 0.11783648122634206, 0.2142224891909531, 0.08527176042220422, 0.11862799232559544, 0.12088162425373282, 0.10674307149435792, 0.14863799485777104, 0.20587064591901644, 0.13228146040013858, 0.13319137586014612], [0.01864322291554085, 0.0424295987800828, 0.07575348831181015, 0.015352029519687806, 0.0595752660717283, 0.07325881360364811, 0.029794513380953243, 0.12134730283703123, 0.01239610112471772, 0.05578971241733857, 0.02822269718827946, 0.11399453452655248, 0.02504980976560286, 0.059807847520070415, 0.07990059935088668, 0.11736648716032505, 0.36127231855477604, 14.140547326632909, 94.53422314780099, 69.52052756718227, 77.06440911974225, 45.66202211380005, 41.767459528786794, 41.32784005573818, 72.81335530962262, 67.54917771475655, 22.32389678273882, 0.14958661395524228, 0.13717983184116228, 0.5905397204416138, 0.7726657933422497, 1.3973442933389117, 0.42954178952745026, 0.10099983574556452, 1.2936478576489856, 13.727310163634163, 103.69995321546281, 81.27980477469308, 81.1413688659668, 77.18240342821393, 89.49317305428642, 85.65947668892997, 88.39611503056118, 82.74730600629533, 75.59284319196428, 68.71834414345878, 67.1705356325422, 63.31896850040981, 64.3030696596418, 57.58979313714163, 58.728571619306294, 54.75213146209717, 54.488860743386404, 53.19175713402884, 57.853789942605154, 54.16986894607544, 56.08066177368164, 55.38528953279768, 53.787189960479736, 52.75133861814226, 54.108287061963765, 52.182795320238384, 49.91990947723389, 50.157673358917236, 49.96074056625366, 51.44861739022391, 51.832210063934326, 56.46742630004883, 58.267878259931294, 58.85759966714041, 64.36009352547782, 60.68141147068569, 53.433436325618196, 63.12831687927246, 67.04225104195731, 68.96485233306885, 68.45166533333915, 65.3214601789202, 67.9125337600708, 67.33020523616246, 69.32770810808454, 63.76259708404541, 63.39540563310896, 63.28351184300014, 66.68550273350307, 64.11881038120815, 67.0796115057809, 61.96789823259626, 36.511178561619346, 61.5258468900408, 65.31066267830985, 65.34973239898682, 57.37775843484061, 54.08800874437605, 50.736145632607595, 48.95128543036324, 48.09976632254464, 49.57825265611921, 51.428898402622764, 49.77500132152012, 54.13955742972237, 56.14561700820923, 59.30636991773333, 59.47251524244036, 56.151238100869314, 54.829263414655415, 72.31418282645089, 59.018540791102815, 49.82911041804722, 47.66251618521554, 48.37010335922241, 49.7388950075422, 50.06588418143136, 50.095962933131624, 48.530968053000315, 50.394930022103445, 48.731017112731934, 48.31489644731794, 49.69372476850237, 51.73786742346627, 50.32154662268502, 51.88499205453055, 49.91732127325875, 52.12563249043056, 55.969567026410786, 60.84507628849575, 65.1150986807687, 71.01434857504708, 68.14477729797363, 69.15038313184465, 67.48583793640137, 69.30935791560582, 64.9147960117885, 74.25480774470738, 68.60815961020333, 79.76775169372559, 18.96218981061663, 0.6963456400803157, 2.5590323976108005, 3.1318201763289313, 1.404129860656602, 1.49898319372109, 0.5078482862029756, 0.14778420781450613, 0.06841615667300564, 1.2008108049631119, 22.087784835270472, 31.370692798069545, 59.675270625523154, 45.91341488701956, 23.061309099197388, 33.589398520333425, 51.548164231436594, 64.30801677703857, 62.242623056684224, 57.788414342062815, 1.7667414716311862, 0.09098674875817128, 0.042218859373990975, 0.024911897523062568, 0.14714766054281167, 0.04270744190684386, 0.038056501653045416, 0.020666057942435145, 0.03256274965990867, 0.022269449762201736, 0.0014903107782759304, 0.03924636709104691, 0.01735671203849571, 0.03385725198313594, 0.015184967412746378, 0.030194659052150588, 0.011522691696882248, 0.051063095152910264, 0.02895180681454284, 0.05843088962137699, 0.07036372859563146, 0.053534930372344594, 0.0034430512293641058, 0.021053944182183062, 0.04095414473808237, 0.01976318228324609, 0.030433052152927433, 0.06244965576167617, 0.018985927204734514, 0.04866305233112403, 0.03470981087801712, 0.08795342581080538, 0.04877399619934814, 0.07749163718628031, 0.11001559839184795, 0.2071311061403581, 0.5464733764529228, 23.32209583691188, 109.68708392551967, 75.35711860656738, 86.49856894356864, 56.68768072128296, 64.98520905630929, 38.03185783113752, 59.4013101032802, 73.958738054548, 24.74206965310233, 0.12089968685592924, 0.4774358038391386, 1.5496717137949807, 2.1578438452311923, 3.263381711074284, 2.028009372098105, 0.17581875063478947, 1.0987419847931181, 19.70713918549674, 107.68835122244698, 84.64057200295585, 86.71188558850969, 79.90919617244175, 95.23412908826555, 88.49866349356515, 92.05163179125104, 85.14332280840192, 77.84644276755196, 71.39390087127686, 70.1667378289359, 65.12367970602853, 66.84668704441616, 60.93989140646798, 59.34660693577358, 58.801701409476145, 58.327132497514995, 57.51392923082624, 60.832270758492605, 57.48972518103463, 59.5640994480678, 57.2637072290693, 55.713150705610005, 57.73127235685076, 56.110386167253765, 55.63162749154227, 54.21723134177071, 54.107095445905415, 52.929601601191926, 54.687249183654785, 54.67433943067278, 58.85785675048828, 60.414093426295686, 61.00860909053257, 65.51414762224469, 63.226084981645855, 55.98466198784964, 63.59527056557791, 70.0315328325544, 71.5339765548706, 70.34423651014055, 66.45568411690849, 68.86459677559989, 72.00049945286342, 70.2693418775286, 66.25085122244698, 65.11530017852783, 67.50670337677002, 68.25836644853864, 67.51326942443848, 69.26018551417759, 64.26435429709298, 39.97682884761265, 65.27913175310407, 69.76570170266288, 67.9658750806536, 60.52356924329485, 55.58883353642055, 53.269754137311665, 50.31712409428188, 51.521469252450125, 53.22657455716814, 53.038069929395405, 52.171966552734375, 56.19929184232439, 58.33909034729004, 63.70807456970215, 63.323199953351704, 59.3114629473005, 56.39319174630301, 74.20831039973667, 61.381914956229075, 53.498005935123985, 51.097316469464985, 50.7024816104344, 52.565422194344656, 52.393172877175466, 53.339107581547324, 50.22069352013724, 53.192000320979524, 51.03901413508824, 52.304527759552, 53.13093955176217, 55.381565298352925, 51.786365849631174, 54.92217125211443, 52.65647833687918, 56.07106631142752, 57.62511430467878, 64.63096904754639, 67.29763902936662, 72.36929593767438, 69.80347211020333, 73.39374528612409, 71.05962998526437, 71.50930350167411, 66.5670359475272, 76.6638593673706, 70.99313572474888, 85.333418573652, 32.29460866110665, 0.8038211358445031, 2.4159318591867174, 0.6699826547077724, 1.9914622817720686, 4.427109003067017, 0.9549905955791473, 0.8770716509648732, 0.021621543814295104, 1.14266936480999, 25.492447308131627, 37.28985970360892, 40.25232144764492, 34.903236865997314, 34.76867110388619, 42.254159995487754, 59.11874771118164, 71.26152379172188, 67.41632815769741, 74.71484102521623, 4.892194058213915, 0.14828632372830594, 0.16568705572613648, 0.15977379945772036, 0.05375245512862291, 0.08330092153378896, 0.03744933834033353, 0.026985483576676676, 0.018696145254320333, 0.029095021808253865, 0.08210453537425824, 0.047086968153182945, 0.029195088760129044, 0.05325882429523127, 0.05235232865171773, 0.030043936068458215, 0.03809070999601057, 0.01587610113035355, 0.023797763378492424, 0.036880407083247385, 0.14256860768156393, 0.23941212466784886, 0.14843898053680146, 0.1319534701428243, 0.16676714776882104, 0.23907008873564856, 0.17541426233947277, 0.24080350143568857, 0.09470057447573968, 0.19543565942772798, 0.1327586876494544, 0.25186924050961224, 0.3150443791278771, 0.18842361069151334, 0.22387019864150456, 0.3664460395063673, 0.8022314097200121, 22.785548993519374, 124.57390512738908, 87.17576817103794, 100.37298202514648, 65.67260129111153, 59.189007895333425, 58.12396369661604, 96.96539088657924, 78.89152826581682, 38.24025862557547, 0.21182305365800858, 0.283553026084389, 1.796075246163777, 2.598268440791539, 5.96937849691936, 3.266221570117133, 2.9474241052355086, 2.317081792013986, 18.544365099498204, 111.98823697226388, 88.43861021314348, 91.33621052333287, 83.54540388924735, 99.5311313356672, 91.58127348763603, 96.5290926524571, 88.78028093065534, 84.53830146789551, 74.03571714673723, 75.77866581508091, 70.03424957820347, 70.18857601710728, 64.7415635245187, 64.97363335745675, 61.77718407767159, 61.20439543042864, 59.66045706612723, 63.989004135131836, 60.45519202096121, 62.628206389290945, 61.92000429970877, 59.457069396972656, 59.559291294642854, 59.80824525015694, 59.367715563092915, 58.59804970877511, 55.77200889587402, 55.65313564028059, 57.990933486393516, 59.225117683410645, 61.61665984562465, 61.847117696489605, 61.16873032706124, 68.00659152439663, 63.12780966077532, 58.75126443590437, 65.82121631077358, 73.21981797899518, 75.6042034966605, 73.7753473009382, 67.33221326555524, 73.30559349060059, 74.08651542663574, 71.43132386888776, 69.61200060163225, 69.04616015298026, 70.11743341173444, 71.76439271654401, 69.31222752162388, 72.40826143537248, 70.65861470358712, 44.81472403662545, 69.23068346296037, 73.19691671643938, 71.65914835248674, 63.51993819645473, 59.94930757795061, 55.89765664509365, 54.92315442221505, 54.20654501233782, 55.98227180753435, 56.81102514266968, 55.764935629708425, 59.59637383052281, 61.83188724517822, 66.05259827205113, 66.1074959891183, 63.25191838400704, 59.13700062888009, 76.01556464603969, 62.704157148088726, 56.95332424981253, 55.27693584987095, 55.10249090194702, 54.17552130562918, 55.47013051169259, 55.634351185389924, 53.820725440979004, 56.32423087528774, 53.79056331089565, 54.88666943141392, 57.40410252979824, 58.411434991019114, 54.95706163133894, 58.74968024662563, 54.53348207473755, 59.00295598166329, 61.33258274623326, 66.67592811584473, 71.94613674708775, 77.99127101898193, 72.41066551208496, 77.89804703848702, 74.45356791360038, 74.71611254555839, 70.34985065460205, 81.20611218043736, 74.85170664106096, 89.91494260515485, 32.025678634643555, 1.1458430630820138, 12.412635428564888, 6.588920269693647, 2.592106908559799, 5.487839238984244, 2.011232078075409, 0.9246981867722103, 0.13070350007287093, 2.2588411228997365, 37.98725734438215, 45.391830989292686, 85.19080679757255, 60.68452426365444, 31.280161244528635, 47.06210844857352, 68.50472872597831, 82.84833976200649, 79.28975731985909, 82.60618809291294, 3.7931080290249417, 0.4804895914026669, 0.15752817424280302, 0.21181507408618927, 0.2037473198558603, 0.1833940241485834, 0.0991581492125988, 0.12204486397760254, 0.11165794490703515, 0.1324256762330021, 0.21729744704706327, 0.12085555493831635, 0.13423953604485306, 0.1416385533022029, 0.09035491051950625, 0.0703157154577119, 0.09026064843471561, 0.10333591646381787, 0.11203505431434937, 0.11148103725697313], [0.03141033596226147, 0.02586376341059804, 0.0259050997639341, 0.04893512451755149, 0.029017560250524963, 0.04073419761178749, 0.031650740919368606, 0.0423275403279279, 0.10208657064608165, 0.05632481870374509, 0.030613966552274566, 0.03829652663054211, 0.04705052064465625, 0.07217110161270414, 0.03159473463892937, 0.047534828406891654, 0.014545164869299956, 52.81777729306902, 79.47067451477051, 76.42912837437221, 59.86148929595947, 44.211432797568186, 18.861831767218455, 50.41735880715506, 85.95186383383614, 35.10967826843262, 7.329340287617274, 0.21283902414143085, 0.3226901117180075, 1.533218379531588, 1.6192657394068581, 1.308255359530449, 0.9173970414059502, 0.8110200124127525, 0.17841701049889835, 68.72537572043282, 96.91163962227958, 77.08148779187883, 77.25072506495884, 77.64463233947754, 88.36092935289655, 84.02727535792759, 89.55745083945138, 79.53190898895264, 75.82929039001465, 65.98187255859375, 63.952394076756065, 58.36400658743722, 57.05250631059919, 55.03215428761074, 56.43511370250157, 52.65988295418875, 55.45997224535261, 54.05340324129377, 53.03503009251186, 54.80612243924822, 54.39811726978847, 54.1423019681658, 54.24186617987496, 54.99607924052647, 52.310266971588135, 50.91151816504342, 51.414810929979595, 49.7748623575483, 51.72006613867623, 51.49847418921334, 55.56399720055716, 56.72852570669991, 58.167643547058105, 57.94892120361328, 61.99523939405169, 64.01410102844238, 55.558522020067485, 51.79566253934588, 60.17281723022461, 65.96318190438407, 67.76722608293805, 65.21627834865025, 64.55856187002999, 62.12833908626011, 70.5707755770002, 69.93788501194545, 66.15593882969448, 66.96261773790631, 65.97308308737618, 68.14117813110352, 64.16040924617222, 51.57795115879604, 42.51464448656355, 65.52939891815186, 65.63532420567104, 60.45838124411446, 55.78717333929879, 52.41909660611834, 54.93013736179897, 55.84139360700335, 53.20797075544085, 50.11716883523123, 49.94422122410366, 48.34478759765625, 51.71969788415091, 54.49544416155134, 60.266402517046245, 59.07315363202776, 58.937677655901226, 54.16617597852434, 73.37826469966343, 67.99475874219621, 52.31345966884068, 50.646704946245464, 46.70833396911621, 49.49099717821394, 51.22115421295166, 48.721824645996094, 50.78009646279471, 48.50720521381923, 50.8233767918178, 49.04298428126744, 50.622539111546104, 48.771028314317974, 51.442225047520225, 50.324381487710134, 49.812066486903596, 49.500161852155415, 49.992351395743235, 56.74893604006086, 65.14523301805768, 66.83499322618756, 69.25721863337925, 67.56355353764125, 67.57029329027448, 64.43208381107875, 65.35696547372001, 63.80754498073033, 72.24448544638497, 67.39731788635254, 78.1525456564767, 16.317932980401174, 0.8117449592266763, 1.2225676774978638, 4.082653360707419, 1.8724737295082636, 1.3235761374235153, 0.28313833262239185, 0.13121720536478929, 0.13799118330436094, 8.314641748155866, 24.46280939238412, 44.95610250745501, 53.86928292683193, 17.185401678085327, 49.01017141342163, 53.390757015773225, 59.94500664302281, 54.96666751589094, 73.56239891052246, 22.363277435302734, 0.615684871162687, 0.06270298681088857, 0.0964028559891241, 0.023848066572099924, 0.02919077667008553, 0.07308998052030802, 0.02844121939103518, 0.023758157289453914, 0.06003700915191855, 0.045635632638420374, 0.028724358483616794, 0.029497342184185982, 0.012510233259360706, 0.021864271057503562, 0.07056241721979209, 0.023581376864707897, 0.02950993918680719, 0.11150753404945135, 0.026848784215482216, 0.017409052533496703, 0.04737294012946742, 0.038626236974128654, 0.025741781473958066, 0.05403948901221156, 0.02347265010965722, 0.06546029528336865, 0.010772874030018491, 0.022841856814920902, 0.05973177017377956, 0.0437764500799988, 0.01576867207352604, 0.06692914039428745, 0.05293631320819259, 0.030272822893623794, 0.01203068542028112, 0.0751582095399499, 72.3087910243443, 86.45965903145927, 84.85286726270402, 72.55165835789272, 53.23651742935181, 36.35491704940796, 46.15547970363072, 79.77503340584892, 42.02181223460606, 9.037805046354022, 0.2379125351352351, 1.6000476734978812, 4.56562785591398, 4.796245515346527, 2.4014761320182254, 1.1924895771912165, 0.348487524581807, 0.6832120248249599, 78.35065964290074, 98.67904594966343, 83.30235590253557, 80.52363232203892, 81.55293151310512, 89.86139283861432, 86.75921671731132, 91.65097086770194, 83.64802183423723, 81.90455205099923, 71.21864645821708, 66.80362905774797, 61.44182232448033, 60.68289838518415, 58.63791847229004, 57.225342750549316, 57.203577518463135, 58.85254832676479, 58.520744051252095, 57.29749631881714, 58.653607504708425, 58.31311103275844, 57.002215249197825, 57.32205125263759, 57.559620584760395, 55.05386046000889, 53.620308126722065, 54.47252205439976, 51.12594652175903, 55.178118569510325, 56.007295744759695, 59.84186063494001, 59.66059603009905, 59.155753816877095, 59.73186370304653, 63.57685783931187, 63.699444907052175, 56.87724494934082, 53.15809658595494, 62.84157861982073, 67.6256912776402, 71.35057190486363, 69.44109576089042, 66.00022275107247, 65.42597498212541, 74.27610397338867, 70.34538991110665, 70.35890415736607, 69.74084104810441, 70.2410557610648, 71.14927564348493, 65.18737384251186, 55.67839581625802, 45.13444539478847, 68.605804170881, 70.70709923335484, 63.589684213910786, 57.009476116725374, 55.66934578759329, 58.28987625667027, 57.99082926341465, 56.213855266571045, 53.67345142364502, 52.505834443228586, 51.90859161104475, 54.50805861609322, 57.3123585156032, 63.561057635716026, 61.11746651785714, 61.402898515973774, 56.88521800722395, 73.03033365522111, 71.94665786198208, 56.22173452377319, 53.51256588527134, 49.98265865870884, 51.03591176441738, 52.76778153010777, 52.254768235342844, 53.041908809116904, 50.22395569937569, 52.667209829602925, 51.814433097839355, 53.366087436676025, 50.874994959150044, 55.44088206972395, 51.74369348798479, 53.15620667593819, 52.79441397530692, 54.22425249644688, 59.40570831298828, 67.79198946271623, 68.03032657078334, 72.26634447915214, 70.0487504686628, 72.11430399758476, 65.59913103921073, 67.90351499829973, 66.70642375946045, 77.135162625994, 68.66405091966901, 85.17825835091728, 32.01538140433175, 0.7662661767431668, 1.468196051461356, 0.6463694732104028, 4.116260494504656, 5.617852628231049, 1.4840329502310072, 0.49895578622817993, 0.20000373359237397, 7.2631165725844244, 29.76134409223284, 43.407668658665244, 37.7634037562779, 16.232994726725988, 67.68652970450265, 61.687413351876394, 68.01760441916329, 61.77737862723214, 81.84753513336182, 38.44526522500174, 0.48458533734083176, 0.06359583711517708, 0.021802370004089813, 0.010805316485597618, 0.030670044078890766, 0.02377470675855875, 0.025920626341498325, 0.030677219586712972, 0.06610875762999058, 0.07599827660513775, 0.01951956276648811, 0.011463118018582463, 0.07388852802770478, 0.02541691417406712, 0.01956801695216979, 0.03519919408219201, 0.018103120915059532, 0.01720598226945315, 0.01175118497173701, 0.1298443390322583, 0.17808375480983937, 0.08385889445032392, 0.223831427150539, 0.12705121748149395, 0.14130487692143234, 0.17077329994312354, 0.10938166347997529, 0.1683593573314803, 0.19779010808893613, 0.10563172612871442, 0.0848233505551304, 0.21776896103152207, 0.19323080059673103, 0.0960056483745575, 0.13693957616175922, 0.158645504287311, 79.35060964311872, 99.93677411760602, 100.29199382237026, 79.6625142778669, 65.93441636221749, 30.519152845655167, 69.57294477735246, 106.36349650791713, 49.97276789801461, 15.08484833581107, 0.4311557800642082, 4.362618429320199, 7.593831283705575, 6.189470938273838, 5.884643043790545, 5.273784782205309, 3.9146268112318854, 0.5649140583617347, 79.93049240112305, 104.8543894631522, 86.35850715637207, 86.41835893903459, 84.89916310991559, 96.51077025277274, 88.29558154514858, 93.86931528363908, 87.95021438598633, 84.7386805670602, 75.0434352329799, 70.78605161394391, 65.33789266858781, 64.01786695207868, 62.51857771192278, 62.98184885297503, 58.96608189174107, 63.58092253548758, 61.42546626499721, 61.50533580780029, 61.71763106754848, 60.074507168361116, 59.86351816994803, 61.40874195098877, 61.00173732212612, 60.04940332685198, 57.271013259887695, 57.76916435786656, 55.96991096224104, 59.5150660106114, 57.57446541104998, 61.463396481105256, 61.97524247850691, 60.736983163016184, 61.41824013846261, 66.2393866947719, 67.37566729954311, 60.0169552394322, 56.381028924669536, 66.0610681261335, 72.72584274836949, 75.54207965305874, 73.96335860661098, 67.31760120391846, 66.40515681675502, 75.91350255693708, 71.80174623216901, 74.35765498025077, 72.86029039110456, 74.18014240264893, 73.31516810825893, 73.30422469547817, 56.97484629494803, 48.52078546796526, 71.47953741891044, 74.52146571023124, 64.94436754499162, 59.97447395324707, 58.37022522517613, 61.4642858505249, 60.49413667406355, 59.27545738220215, 57.84597321919033, 56.64459841591971, 55.67750644683838, 57.22539138793945, 60.17915398733956, 66.370589528765, 65.26209477015904, 63.10565880366734, 60.04995918273926, 75.64489909580776, 72.65522820608956, 57.376837798527305, 56.76952007838658, 52.380582741328645, 54.58021565846035, 56.16684375490461, 55.48176874433245, 57.966795444488525, 52.73572601590838, 56.138564586639404, 54.73632778440203, 57.36823245457241, 53.959310735974995, 58.72973196847098, 56.20627130780901, 56.762735162462505, 54.136448110852925, 56.46281617028372, 64.27400534493583, 72.1950351170131, 71.88187285831997, 75.63768686567033, 73.33770111628941, 76.21939005170549, 69.64037704467773, 72.783707346235, 69.88222299303327, 81.07231072017125, 73.72850254603794, 90.34495966775077, 30.2840188571385, 2.0070145215306963, 8.514969604355947, 6.964031798498971, 5.148190447262355, 5.855516629559653, 1.4103413330657142, 0.49350128748587196, 0.21786135035966123, 14.033017005239214, 40.139006750924246, 63.74704006740025, 76.59336989266532, 22.780329159327916, 65.50710909707206, 68.36690425872803, 77.97096838269914, 70.7263457434518, 94.83799839019775, 40.87639127458845, 0.7076180066381181, 0.15408416119004997, 0.19272070511111192, 0.13976243111704076, 0.13601805775293282, 0.12431788843657289, 0.08784842930201973, 0.14223552841160977, 0.14847554000360624, 0.13643336189644678, 0.12866463804883616, 0.15392813884786197, 0.13343840331903525, 0.14910112214939936, 0.14071126734571798, 0.17829163079815252, 0.09560273428048406, 0.18192220026893274, 0.11517143994569778], [0.04781085645247783, 0.0166810845424022, 0.022175856034404466, 0.01886700715736619, 0.0321331962810031, 0.03790080840034144, 0.05577814678794571, 0.05654814832710794, 0.06385260155158383, 0.042070792854896615, 0.03213452620963965, 0.05034799727478197, 0.012574348033272793, 0.03187157014118774, 0.03216867009177804, 0.21175830784652913, 4.451448542731149, 82.82512583051408, 70.13417162214006, 78.45324979509626, 51.154896191188264, 50.29610579354422, 30.394543852124894, 47.38689851760864, 41.811073371342246, 27.21093831743513, 1.470192355769021, 0.173315254971385, 0.6994841630969728, 1.511220165661403, 2.409586633954729, 2.180304331438882, 0.5051206297108105, 1.6904426515102386, 27.450692858014786, 105.30438954489571, 80.07409082140241, 82.52157293047223, 64.48687035696847, 79.88774708339146, 84.6557399204799, 88.01058033534459, 82.33410358428955, 81.26596396309989, 74.89481326511928, 71.89049557277134, 65.58770820072719, 63.12446757725307, 57.6746688570295, 55.76185410363333, 56.00687190464565, 55.29643596921648, 53.46655491420201, 52.71852575029646, 53.69570302963257, 54.24324539729527, 51.364731788635254, 53.48747246606009, 53.70890460695539, 53.34855365753174, 51.883487769535606, 47.939030170440674, 49.4202367237636, 50.512135710035054, 50.81150926862444, 53.80789559228079, 56.405166966574534, 55.29064117159162, 56.14573165348598, 54.73607417515346, 62.824388776506694, 59.7060580934797, 55.27807535443987, 50.70942286082676, 51.86770841053554, 58.86110850742885, 64.37180818830217, 64.35374287196568, 69.49116447993687, 63.27220712389265, 67.54972662244523, 69.50163541521344, 63.94035979679653, 68.09586892809186, 68.015672819955, 62.575288908822195, 54.7303592818124, 55.951720578329905, 44.108623777117046, 65.53986290522984, 60.91795594351632, 59.56489849090576, 56.17296511786324, 57.34260402406965, 57.60868876320975, 59.05345548902239, 55.126451764787944, 52.82554190499442, 49.462509563991, 51.97174726213728, 51.76370777402605, 56.12233359473092, 57.644753387996126, 60.69056919642857, 52.74661036900112, 51.896008423396516, 63.98947661263602, 75.97069317953927, 63.58831541878836, 52.03771693365914, 48.734696183885845, 45.33949368340628, 45.70368698665074, 49.66078683308193, 47.52353484289986, 49.77930573054722, 49.89317280905587, 49.14296538489205, 49.3154752595084, 49.74776438304356, 49.69697305134365, 49.05591140474592, 49.172460487910676, 50.455469676426475, 48.37852110181536, 49.45185102735247, 50.25650800977434, 56.15403822490147, 60.15777438027518, 64.05277470179966, 61.18278653281075, 62.01887716565813, 57.022194794246126, 61.25613866533552, 62.938790866306846, 74.8457589830671, 65.4229177747454, 74.17749513898576, 16.57713552883693, 0.5879161240799087, 1.553610039608819, 4.41642701625824, 0.845390688095774, 1.496244192123413, 0.04163344310862677, 0.047985775994935205, 0.18839288662586892, 20.55226595061166, 25.892592327935354, 60.32504531315395, 59.33927658626011, 13.671719363757543, 36.654436520167756, 45.033303941999165, 61.106425830296104, 58.07415553501674, 59.402908188956125, 2.529197918517249, 0.06527330460292952, 0.02825356204994023, 0.012119395392281669, 0.019126394131620015, 0.04568620724603534, 0.028447660384699702, 0.03788892725216491, 0.04469474205481155, 0.07000683953187295, 0.011042463626446468, 0.047063867428473065, 0.06705481865044151, 0.030774999875575304, 0.013882618680197214, 0.01704175304621458, 0.048597047837185006, 0.038954047419662984, 0.05388863032151546, 0.014914238725655844, 0.05275256931781769, 0.03204863385430404, 0.022019182298598543, 0.024712598217385154, 0.0658063210014786, 0.08612268404769045, 0.04942503697904093, 0.10136078923408474, 0.0381076665861266, 0.02711605915932783, 0.013147248720218028, 0.044492769321160655, 0.04714599052178008, 0.15046831592917442, 0.3539147190749645, 9.2233966418675, 97.86789934975761, 78.37580517360142, 87.52747903551374, 59.84656456538609, 63.76700919015067, 30.29656035559518, 38.21582875932966, 47.007995877947124, 31.220024585723877, 1.6075332718236106, 0.35425347089767456, 2.513699527297701, 3.3142273255756924, 4.102325882230486, 3.019404402800969, 0.7269180938601494, 0.8858305609651974, 36.03723498753139, 108.94786507742745, 81.99555260794503, 84.73900018419538, 68.60382393428257, 84.04556996481759, 89.5638918195452, 89.01291356767926, 84.11482960837228, 84.8026178904942, 77.32352828979492, 75.72861794063023, 68.506041935512, 67.7243765422276, 61.27478068215506, 58.00658082962036, 58.70367622375488, 58.26521362577166, 56.33298213141305, 56.21999747412545, 56.44179439544678, 56.61749349321638, 53.91650635855538, 58.52190440041678, 56.20234557560512, 55.85640866415841, 54.32478598185948, 50.48094177246094, 50.624873706272666, 53.006504263196675, 53.57248714991978, 57.27674204962594, 58.453513281685964, 57.27180882862636, 57.64430522918701, 57.15750401360648, 62.9268399647304, 60.537222453526084, 57.87834140232631, 54.09903900963919, 55.61851971490042, 61.846492358616416, 66.11127580915178, 68.30847685677665, 71.1512211390904, 64.33044556209019, 70.98741735730852, 72.17813014984131, 66.75997352600098, 70.15855285099575, 68.09810624803815, 64.9977366583688, 59.72703470502581, 58.31077643803188, 45.96568618501936, 67.61222566877092, 63.681282315935405, 63.50734111240932, 58.7550025667463, 62.92253902980259, 59.83932454245431, 63.693080357142854, 56.91366393225533, 56.189988204411094, 51.110889775412424, 53.979470934186665, 53.34931795937674, 58.2292914390564, 61.276225907461985, 63.144930022103445, 56.43234484536307, 53.77195256096976, 66.17808968680245, 77.7154483795166, 66.1301749093192, 54.6096065385001, 52.07338203702654, 48.06405258178711, 47.76324422018868, 52.644895689828054, 50.48774405888149, 50.80388362067086, 51.66712086541312, 51.17844363621303, 51.74356147221157, 50.672406332833425, 51.526298250470845, 51.971504075186594, 52.221246651240754, 53.02081755229405, 51.3973640033177, 52.546978201184956, 53.22858606066023, 58.209284101213726, 61.163039752415244, 65.35691683632987, 62.93434401920864, 64.48416750771659, 57.84613650185721, 63.111133984157014, 65.08738231658936, 77.26139749799455, 68.72369425637382, 82.31483622959682, 34.021406241825645, 0.3683449061853545, 0.3234595161463533, 0.40251563116908073, 4.679330783230918, 5.9802993280547, 1.2614008337259293, 0.39352284371852875, 0.1533920011882271, 22.470524617603846, 33.594508920397075, 47.28855718885149, 41.67083093098232, 15.931010382516043, 44.887009620666504, 49.81440108163016, 69.16847624097551, 62.468682697841096, 80.61528600965227, 10.914848736354283, 0.3017636031976768, 0.06488245486148767, 0.017641807008268576, 0.01679711911960372, 0.05344235783975039, 0.007464651949703693, 0.015754583990201354, 0.06964444076376301, 0.04513448363702212, 0.037495285339121304, 0.07531885949096509, 0.08078113424458674, 0.058325011017067094, 0.03352856283475246, 0.03764769448233502, 0.024920750708718385, 0.012354802938976457, 0.025292620129351105, 0.17533465661108494, 0.12428392097353935, 0.21804585760193212, 0.09851713039513145, 0.17572360645447457, 0.1875295593802418, 0.22336682065257005, 0.11579980408506733, 0.18834990821778774, 0.1011888145336083, 0.08273450764162199, 0.08437270152249507, 0.14788066835275718, 0.1132796300309045, 0.26261685522539274, 0.530704385467938, 9.803303718566895, 112.03316402435303, 86.9176356451852, 98.8402441569737, 68.44681549072266, 68.52896404266357, 42.13918120520455, 65.36868013654436, 56.9559645652771, 45.71316432952881, 2.1804548033646176, 0.28954142332077026, 2.917068294116429, 7.82327904020037, 8.66733751978193, 7.115329257079533, 3.2778669680867876, 3.091575558696474, 34.22187566757202, 114.93823364802769, 86.57725729261125, 92.11362361907959, 72.3296286719186, 87.06818226405552, 93.51975836072648, 88.8194270815168, 86.19990757533482, 91.06974015917096, 80.2494147164481, 79.53672409057617, 72.03130776541573, 71.64730862208775, 64.14895861489433, 60.774885586329866, 61.7399834224156, 61.69010925292969, 59.535924502781455, 60.39751502445766, 59.049230984279085, 61.344193186078755, 57.633750915527344, 60.07227679661342, 58.78007861546108, 58.949948174612864, 57.97229494367327, 54.251423427036826, 54.49897732053484, 57.038127013615195, 56.85111972263881, 60.036820139203755, 61.87236745016915, 58.88903331756592, 59.443666321890696, 58.2588004384722, 67.45225034441266, 64.1282182421003, 59.76800128391811, 56.91471658434187, 57.38689531598772, 65.02513340541294, 71.29059505462646, 72.02392183031354, 72.67243194580078, 67.13182026999337, 72.09227820805141, 72.24518721444267, 70.64350237165178, 74.34452288491386, 72.73947511400495, 70.9957412992205, 65.18206541878837, 59.57174941471645, 50.14661530085972, 71.95894922528947, 67.69151851109096, 66.31136308397565, 61.71317032405308, 64.59165613991874, 64.04261643545968, 66.03561687469482, 61.317790031433105, 58.90659141540527, 56.08203404290335, 57.12172079086304, 57.43684591565813, 61.91308389391218, 65.23649760654995, 68.12894930158342, 60.31916018894741, 55.82591996874128, 68.942597252982, 79.40654264177594, 67.54846205030168, 59.06835242680141, 54.80328410012381, 50.77397162573678, 49.567020893096924, 56.49122388022286, 53.48057637895857, 56.670671531132285, 54.36273009436471, 54.72648566109793, 55.118221623556956, 54.08249534879412, 55.63804415294102, 54.407764843532014, 56.58117525918143, 56.85916573660714, 54.722261156354634, 56.07582235336304, 57.486841678619385, 63.79248823438372, 65.91052150726318, 71.52111543927873, 66.39260837009975, 68.83428178514752, 62.37223475319998, 67.89521884918213, 69.10663727351597, 83.14989158085415, 73.22760690961564, 88.0290833881923, 30.575315134865896, 1.0246341271059853, 7.444411141531808, 7.925868323871067, 3.1836750166756764, 5.1375718627657205, 1.1975324494498116, 0.5104931614228657, 0.44290195405483246, 33.69327756336757, 39.412593432835166, 81.67799908774239, 75.95710945129395, 20.44531580380031, 51.938646044049946, 57.9902525629316, 81.8153441292899, 69.86988299233573, 91.14018099648612, 9.207856995718819, 0.363908128546817, 0.19366997560220106, 0.0848812363775713, 0.06266938575676509, 0.14104414305516652, 0.11067706825477736, 0.1319082932812827, 0.09675422856318099, 0.1693653804915292, 0.13781584985554218, 0.12747197704655783, 0.13704751751252583, 0.16034564163003648, 0.12467759342065879, 0.08517479098268918, 0.10959747154265642, 0.10752302714224372, 0.2311369287116187], [0.07131846129362072, 0.020862251254064695, 0.0056881196214817464, 0.02468903099984995, 0.011015688634610601, 0.02765316712403936, 0.09760578322623457, 0.06334059259721211, 0.03938562961827431, 0.03911986441484519, 0.10224605351686478, 0.0043893633077719384, 0.08939468168786593, 0.07872366000499044, 0.23893801867961884, 0.35773394842232975, 25.749040807996476, 83.4003324508667, 70.24137537819999, 65.22478294372559, 52.40295941489083, 40.6849753516061, 46.627925940922324, 55.88604620524815, 37.066482067108154, 13.451284289360046, 0.3051852381655148, 0.3129255585372448, 0.45279005489179064, 1.4921657081161226, 2.214685755116599, 0.697499692440033, 2.0206206142902374, 4.888892361095973, 92.40539237431118, 86.04660946982247, 84.46756185804094, 72.83372047969273, 65.87885161808559, 76.27500343322754, 82.91249247959682, 79.4084256035941, 81.19987964630127, 82.01107488359723, 79.16467584882463, 73.00088024139404, 65.59418392181396, 61.97367218562535, 54.82666826248169, 55.60057599203927, 52.09649174554007, 55.78311211722237, 54.43359824589321, 53.338749749319895, 52.50623049054827, 53.118693351745605, 54.45030518940517, 53.037785053253174, 52.82577814374651, 49.798236097608296, 49.267001152038574, 47.79968057359968, 50.06930269513811, 52.484291553497314, 52.34378160749163, 55.915944303785054, 56.058507442474365, 55.57541309084211, 55.916809354509624, 56.29031324386597, 58.84835161481585, 54.85039288657052, 57.06043767929077, 55.14442328044346, 55.03260244641985, 51.5074269430978, 60.84162998199463, 65.97232573372978, 64.70790645054409, 68.11253070831299, 60.954037938799175, 63.36207512446812, 65.66890484946114, 64.04626423971993, 58.202189990452354, 53.29702581678118, 62.09735706874302, 55.7845573425293, 47.121737888881135, 68.27927357809884, 59.80123451777867, 61.08740861075265, 57.36404616492135, 62.14211041586739, 58.68248421805245, 54.788943018232075, 52.001405647822786, 50.54924256461007, 50.14311688286917, 47.672736985342844, 49.69049038205828, 54.103656087602886, 56.102395738874165, 60.1792026247297, 54.492557185036794, 50.61996132986886, 62.74214989798409, 64.58663954053605, 69.97793442862374, 56.405107906886506, 49.2941130229405, 48.75264685494559, 45.134671211242676, 43.484383719308035, 47.32922499520438, 47.46529851640974, 48.71606806346348, 48.340993881225586, 48.50274794442313, 48.96732882090977, 50.14710514886038, 48.46347325188773, 48.68803555624825, 48.86680228369576, 48.69301394053868, 49.597016266414094, 47.70886761801583, 46.92263725825718, 48.308611801692415, 48.38531296593802, 50.73895270483834, 51.19246162687029, 52.9555218560355, 52.01225873402187, 58.05157388959612, 62.193603515625, 73.24657549176897, 61.96195752280099, 77.99304975782121, 17.091451610837662, 0.7514937637107713, 3.869663281100137, 5.943530329636165, 1.15900034563882, 1.3397109402077538, 0.43309690590415684, 0.14422149184559072, 4.745919712952205, 25.48404172488621, 32.16428130013602, 56.62377119064331, 30.991564341953822, 25.969567946025304, 37.49943821770804, 50.11915602002825, 59.17712647574288, 68.72027574266706, 47.037358965192524, 0.2198934406042099, 0.06127557304820844, 0.04600919670026217, 0.04578341417280691, 0.059841896407306194, 0.05215823710230844, 0.0617806880867907, 0.031157395070684806, 0.05358887729900224, 0.07493683749011584, 0.010229317438123482, 0.025761518361313, 0.016009538434445858, 0.056142791506967375, 0.034768208994397094, 0.04773133893364242, 0.030995075923523734, 0.027050957116963606, 0.05729879465486322, 0.022807024219738584, 0.04683562181890011, 0.04247232613020709, 0.06318477381552969, 0.011271140953925039, 0.030375899148306677, 0.07974433273609195, 0.026217315778402344, 0.02291265346242913, 0.10747333123747792, 0.027510732445599775, 0.06059777084738016, 0.16720815481884138, 0.30821131435888155, 0.3693990239075252, 38.04467725753784, 94.76809256417411, 76.3323677607945, 76.05730247497559, 57.931140763419016, 57.94617319107056, 41.57597412381853, 44.8777129309518, 46.46207244055611, 15.905352422169276, 0.5089562524642263, 1.1621835976839066, 2.2288822276251654, 3.7789984089987616, 3.1179174823420386, 0.2825169302523136, 1.3357567638158798, 8.346614752496992, 99.66712147848946, 86.55478681836809, 88.96052415030343, 75.9533018384661, 68.97081388745988, 78.41584069388253, 85.94301182883126, 82.57141235896519, 82.65465872628349, 87.15331159319196, 82.72890022822789, 75.14431612832206, 70.54516451699394, 66.31854057312012, 59.01458031790597, 59.03086689540318, 55.389267376491, 57.101136752537315, 57.33952944619315, 55.79061269760132, 56.33218308857509, 57.08909205027989, 58.34621919904436, 55.90786354882376, 57.78295653206961, 52.84241907937186, 51.75754124777657, 51.371961389269146, 52.897299425942556, 54.34848976135254, 55.49949707303728, 59.1408360345023, 57.46906818662371, 56.4270954813276, 56.27611460004534, 57.521905762808665, 61.980960845947266, 55.243872846875874, 60.689075333731516, 56.94628572463989, 57.95986114229475, 53.036815779549734, 62.905620166233604, 69.03064482552665, 67.62013966696603, 66.52235208238874, 63.7546830858503, 65.72814519064767, 67.41878087180001, 64.53570924486432, 63.5835211617606, 59.2372978755406, 65.52507019042969, 58.00595549174717, 50.73613521030971, 68.91018390655518, 62.11099638257708, 63.5472446169172, 59.95543588910784, 63.63185977935791, 59.807425362723215, 57.88139166150774, 55.68081031526838, 53.70726483208792, 51.77119793210711, 49.76220621381487, 53.69254159927368, 56.34729194641113, 60.28044482639858, 61.130001068115234, 58.377958570207866, 53.05623599461147, 63.20512921469552, 65.65262522016252, 71.79333196367536, 60.87411281040737, 53.83924239022391, 52.44857433864048, 47.23428133555821, 47.39580610820225, 48.721164567129954, 50.94513007572719, 50.80657952172415, 51.477514948163716, 50.51582520348685, 50.30104596274239, 52.10849128450666, 50.8262220791408, 52.0780269077846, 52.80490575517927, 51.682983602796284, 50.900470529283794, 50.25172070094517, 49.59111029761178, 51.19088438579014, 50.70526783806937, 54.09696844645909, 53.26099245888846, 56.46972615378243, 53.64403969900948, 60.562124797276084, 63.616907255990164, 76.21891757420131, 65.93238054003034, 84.8811811719622, 30.762919970921107, 0.3411131245749337, 0.4158713716481413, 1.9863583956445967, 5.724126194204603, 3.608387129647391, 0.9603042304515839, 0.3129054196178913, 4.6342665042196, 33.62151656832014, 35.703071798597065, 46.29523924418858, 24.218010459627422, 40.275153228214805, 50.21281426293509, 56.94468763896397, 64.67622961316789, 72.58335603986467, 65.80446420397077, 0.813520821077483, 0.11712708643504552, 0.02177615649998188, 0.01649912180645125, 0.06884124529148851, 0.03575160979692425, 0.04491654158170734, 0.03408195563991155, 0.023488190257921815, 0.05768629243331296, 0.05656530508505447, 0.011771127115935087, 0.04906291301761355, 0.0020921883031925453, 0.03346559478502188, 0.006798174074252269, 0.06953794469258615, 0.024217013203139817, 0.15329266366149696, 0.10108062891023499, 0.10271568117397172, 0.17402177277420247, 0.17580072874469416, 0.15694016936634267, 0.18260320515504905, 0.15202334177281174, 0.1841999473316329, 0.11481474765709468, 0.2095054087362119, 0.1918937744838851, 0.3096472573067461, 0.2449993991426059, 0.49290162537779125, 0.49193441442080904, 43.392333984375, 108.21107115064348, 89.01153782435826, 87.02575656345913, 68.32914774758476, 56.798744201660156, 63.867313385009766, 80.37170301164899, 55.888401644570486, 25.926947695868357, 0.6907208019069263, 1.3257919613804137, 2.0250279435089658, 8.757476500102452, 7.536187291145325, 2.0630804044859747, 3.9691831980432783, 7.269819847175053, 102.36409255436489, 91.156557900565, 90.82150881631034, 80.24926880427769, 72.03907585144043, 83.89101423536027, 90.45845849173409, 88.37468678610665, 85.40383161817277, 90.23985426766532, 87.69745976584298, 78.71708679199219, 72.64215864453996, 72.17678914751325, 61.73603684561593, 61.7400598526001, 57.5858222416469, 61.07897349766323, 59.91087014334542, 60.368096351623535, 59.9081950868879, 60.59528160095215, 60.9039831161499, 58.38339900970459, 61.3548378263201, 54.81509256362915, 54.77876738139561, 54.443061692374094, 56.837157317570274, 58.84787218911307, 58.27973188672747, 60.928218432835166, 59.39322934831892, 59.06619153703962, 58.500503948756624, 58.46506813594273, 64.56879656655448, 59.76800128391811, 65.5770844050816, 61.60663359505789, 60.499855041503906, 57.38565158843994, 66.90804658617292, 72.78333909170968, 71.42381286621094, 71.41402285439628, 64.82823535374233, 67.03637286594936, 69.98921135493687, 69.51068196977887, 66.59972722189767, 62.94004849025181, 68.05240099770683, 59.37211377280099, 54.94267191205706, 73.37948063441685, 64.78309985569545, 66.82422351837158, 62.58430072239467, 66.89228112357003, 63.94828074319022, 61.978799956185476, 57.998670305524556, 58.83203724452427, 55.750879423958914, 53.495862415858674, 55.9563341821943, 58.5814574105399, 63.066443170819966, 66.12689535958427, 62.25656809125628, 56.30960144315447, 66.30161476135254, 68.64807006290981, 72.42461749485561, 60.90102318355015, 57.22160461970738, 55.35295956475394, 49.4947943687439, 49.38571112496512, 52.3016859463283, 53.17802054541451, 53.4519602230617, 54.507169246673584, 53.78651251111712, 53.62297623498099, 56.90240437643868, 53.74307237352644, 54.96395424434117, 55.8418904032026, 54.52121850422451, 55.61970785685948, 53.53185061046055, 51.56820283617292, 54.7368871143886, 53.41999503544399, 57.13082293101719, 56.50789260864258, 60.41578878675188, 57.7042612348284, 64.94814736502511, 69.84083257402692, 80.44311659676688, 72.55969047546387, 89.81090722765241, 28.56834360531398, 1.3906739141259874, 12.066366740635463, 10.641822746821813, 4.97966753584998, 3.7017674446105957, 1.6685583229575838, 0.41697532098208157, 7.5820940392357965, 43.323727471487864, 43.451609066554475, 77.23811408451625, 45.59112964357649, 36.867548193250386, 53.335435458592, 68.0332865033831, 75.14906174795968, 83.57593427385602, 69.45338017599923, 0.6236660171832357, 0.20309612979846342, 0.07753327209502459, 0.14012444312019007, 0.1666941238301141, 0.15270935424736568, 0.2159916064036744, 0.2180470653942653, 0.21026296594313212, 0.17608487206910337, 0.2804887076573712, 0.09341189398297242, 0.08538679924926587, 0.19419442888881477, 0.09845029469579458, 0.15908708130674704, 0.19459114117281778, 0.12174478865095548], [0.04882989052150931, 0.06122057778494699, 0.04940009063908032, 0.026766277749889662, 0.020536099826650958, 0.016258360618459325, 0.058199821306126456, 0.05352789396420121, 0.05498240841552615, 0.01746644132903644, 0.006819701021803277, 0.04099192896059581, 0.02530811956551458, 0.015258948085829616, 0.01838587493901806, 0.549855032137462, 63.82068402426583, 74.30676637377057, 72.29415811811174, 54.2300785609654, 53.9191049848284, 26.079406806400844, 35.42462274006435, 47.36501169204712, 27.098573786871775, 2.3820993431976865, 0.037694391262318404, 0.2558572622282164, 2.8107026645115445, 1.580069974064827, 1.6104042891945158, 1.418645516037941, 0.1970087614442621, 56.3226432119097, 95.95216287885393, 82.71660886492047, 80.88628659929547, 66.86819866725376, 63.03157711029053, 69.00522831508091, 80.62266499655587, 83.66378034864152, 82.20191410609654, 83.35150745936802, 79.26957975115094, 73.82374845232282, 65.4293657030378, 58.21745865685599, 54.43524496895926, 53.09621245520455, 55.54619244166783, 52.665570054735454, 53.0306179864066, 54.53944362912859, 55.03239400046212, 53.847548961639404, 54.9978996685573, 53.29879413332258, 51.38730648585728, 49.32880885260445, 50.37765680040632, 50.04025575092861, 50.821330547332764, 50.12509672982352, 53.947338989802766, 59.14032881600516, 54.902751037052695, 54.65082672664097, 55.00475754056658, 57.81319161823818, 54.333179405757356, 56.66711057935442, 61.68328612191336, 61.00575338091169, 58.496279444013325, 56.21683256966727, 54.48236417770386, 61.80132211957659, 64.10091182163784, 66.99942929404122, 58.49304158346993, 55.101671014513286, 63.82290049961635, 58.37384523664202, 61.81819929395403, 63.454229082380024, 64.55693599155971, 58.06344836098807, 46.386767864227295, 64.92437062944684, 59.35039370400565, 60.80208083561489, 58.80132620675223, 59.89565358843122, 53.70240804127285, 53.458852836063926, 48.07277604511806, 49.149024214063374, 47.19493021283831, 48.50397777557373, 48.6909225327628, 52.71282475335257, 53.27273491450718, 57.61145414624895, 50.483710629599436, 48.725152833121165, 54.34427915300642, 61.432164328438894, 62.32823181152344, 67.8750273840768, 53.59473875590733, 47.98750080381121, 46.40126180648804, 44.649888447352815, 41.724311215536936, 47.31960868835449, 49.27657229559762, 47.40364020211356, 47.35743815558297, 48.365336894989014, 47.3674887248448, 49.550685678209575, 46.72981432506016, 49.30994449343, 48.901810782296316, 49.02532543454851, 47.84491682052612, 49.10521929604666, 47.80093819754464, 47.97119338171822, 46.955578667776926, 52.11707578386579, 51.123066493443076, 55.43316956928798, 52.02312224251883, 56.158116817474365, 57.35608352933611, 74.3892206464495, 65.6336635862078, 80.55995055607387, 9.022037846701485, 0.6258321723767689, 11.003580706460134, 9.228574786867414, 0.9774884283542633, 0.4034191412585122, 0.020605675111125623, 0.16289387989257062, 20.363109929221018, 25.031976291111537, 50.501577922276084, 50.58585262298584, 11.69696228844779, 20.39485103743417, 38.26727669579642, 56.12704447337559, 60.30912699018206, 66.94164112636021, 22.400941882814678, 0.49599487653800417, 0.04654355659814818, 0.0820206141631518, 0.0691977475902864, 0.014601428993046284, 0.026426119663353478, 0.036658858614308495, 0.0302738746229027, 0.025395087398854748, 0.056248748142804415, 0.02023126118417297, 0.02748857488456581, 0.021299339764352356, 0.07458203831421477, 0.02041626036433237, 0.0432031320940171, 0.005633113756110626, 0.015954946899520497, 0.048854426347783635, 0.07533023173787765, 0.006845599855296314, 0.014791376389829176, 0.038845247722097805, 0.010184085445611604, 0.05566536408982106, 0.056403481268457005, 0.03997824853286147, 0.026931594325495616, 0.09985494360859905, 0.036957973813904185, 0.020616982897211398, 0.05764120378132377, 1.1069169746977943, 82.13783781869071, 81.07294995444161, 81.6590860911778, 62.16929871695382, 66.01177760532924, 38.783569540296284, 31.43362958090646, 49.84943042482649, 33.72411366871425, 2.325911432504654, 0.06332873859043632, 1.7493632669959749, 3.419048935174942, 2.5889109543391635, 2.2688530428068976, 0.17342409198837622, 0.34853670479995863, 63.78478963034493, 97.20408930097307, 86.39517280033657, 82.72796222141811, 70.24470356532505, 65.96090289524624, 72.38370650155204, 82.00491183144706, 86.7230304990496, 84.73401137760708, 85.35158116476876, 82.62976333073208, 77.84900665283203, 67.88733959197998, 61.93845871516636, 56.713847637176514, 56.2887533732823, 58.73784746442522, 55.92817660740444, 56.692933559417725, 57.28464215142386, 58.92915916442871, 55.3182498386928, 57.91778979982649, 55.75556598390852, 53.33918401173183, 51.8779604775565, 53.892510754721506, 52.479684897831504, 53.43899141039167, 53.25451673780169, 55.946902002607075, 59.582428795950754, 55.88007770265852, 56.974346024649485, 56.05623190743582, 59.37219020298549, 55.844238894326345, 59.871591976710725, 63.97671972002302, 63.254676818847656, 62.94825431278774, 59.32120432172503, 55.93016726630074, 65.3824862071446, 67.19565337044853, 68.96989672524589, 61.97695173536028, 59.48195784432547, 64.17132486615861, 62.40484959738595, 66.2441462108067, 66.25366524287632, 68.72812720707485, 60.85763168334961, 47.77070311137608, 69.67645903996059, 61.72738633837019, 64.49373517717633, 62.161363874162944, 62.4148063659668, 56.399233204977854, 56.15761654717581, 50.74185357775007, 51.633401257651194, 51.11116075515747, 51.48007188524519, 51.71397951671055, 55.72894048690796, 57.527005740574424, 61.2938882282802, 52.768952301570344, 51.353506973811555, 56.15015070778983, 64.42464229038784, 63.63024779728481, 69.1203669139317, 56.49099806376866, 50.6942514692034, 49.821814809526714, 47.48992640631539, 45.454232760838096, 49.19306884493147, 50.716652461460654, 48.403496401650564, 49.89319365365164, 49.75167621885027, 51.163188866206575, 52.834185464041575, 50.16242592675345, 51.35184288024902, 51.003758975437705, 52.40916763033186, 50.00631032671247, 51.89844376700265, 50.36613668714251, 51.70289713995797, 50.266475200653076, 54.636131286621094, 53.31017180851528, 57.870323181152344, 55.80673599243164, 57.950244835444856, 58.2026937348502, 76.69723156520298, 68.67190933227539, 84.64463669913155, 18.4147082396916, 1.0001053575958525, 3.8227012753486633, 5.304676038878305, 6.389110488551004, 2.155454967703138, 0.0659068798912423, 0.0853776525972145, 27.770445483071462, 37.10489865711757, 52.06570080348423, 52.45066574641636, 15.619632073811122, 34.98912354878017, 45.60588761738369, 63.129914964948384, 65.14008440290178, 74.91482407706124, 39.476822580610005, 0.8114001548716, 0.02349791705741414, 0.08270169368812016, 0.04033150064892002, 0.023838017468473742, 0.01803828859036522, 0.06150357438517468, 0.05090703549129622, 0.05781793501228094, 0.045358854811638594, 0.06226210868252175, 0.02114823680104954, 0.03214182046109012, 0.09666243634585824, 0.00910032507298248, 0.05229484655761293, 0.024960677405553203, 0.1843353964920555, 0.1331629588135651, 0.1589533556252718, 0.06546852591314486, 0.10953364175345216, 0.20427066034504346, 0.13816688316208975, 0.1783009810107095, 0.15199225129825727, 0.1262225905167205, 0.12459619635982172, 0.11074612276362521, 0.1425700733172042, 0.20688592429671968, 0.1623528567808015, 0.9377619943448475, 98.1927137374878, 92.33821024213518, 95.2985805783953, 72.95113113948277, 73.45372213636125, 33.65155015672956, 52.95299965994698, 65.65689836229596, 43.656917912619456, 4.754957148006984, 0.12558161919670446, 2.7915716682161604, 7.4761756999152045, 5.436015231268747, 6.32775615794318, 4.622365542820521, 0.39605364363108364, 64.20642716544015, 102.64975384303501, 90.53491646902901, 87.04372460501534, 75.03529889242989, 69.17902360643659, 75.86168984004429, 88.54502187456403, 93.15426227024624, 88.20569269997733, 89.55869456699916, 85.2301891871861, 81.89446326664516, 72.844893183027, 65.85390063694545, 58.88980456760952, 59.815040588378906, 62.869169916425435, 59.464879172188894, 60.26470715659005, 61.15047740936279, 59.86103766305106, 59.348420415605815, 61.09408582959856, 58.25771304539272, 57.22674976076399, 56.36678511755807, 54.69658408846174, 56.57445287704468, 54.93276378086635, 55.431498527526855, 59.117642947605674, 62.993834495544434, 58.48477322714669, 58.70146669660296, 56.665578501565115, 61.78659888676235, 61.38460390908377, 62.093389647347585, 66.6917005266462, 65.1008687700544, 65.27013383592877, 62.384602546691895, 59.10365622384207, 68.71635001046317, 71.2302360534668, 73.23101847512382, 64.11249446868896, 60.503377778189524, 65.7663880756923, 64.2513542175293, 69.1060744694301, 67.88999380384172, 71.7912961414882, 62.32890578678676, 52.34454243523734, 72.01463208879743, 64.96653924669538, 65.96138232094901, 64.29837962559291, 64.37275314331055, 58.804341724940706, 60.43334688459124, 54.15228305544172, 54.806254455021445, 54.345356123788015, 57.069265365600586, 53.655431270599365, 59.76404775891985, 58.98987947191511, 66.84274741581508, 57.0681779725211, 53.76916980743408, 59.778896059308735, 66.87299292428153, 64.21454960959298, 72.64409719194684, 58.39720508030483, 52.156687464032856, 52.423407963344026, 50.025476932525635, 48.460933685302734, 51.95260150091988, 54.89471891948155, 51.39416783196585, 51.34805611201695, 52.16417762211391, 52.23812729971749, 55.77370425633022, 52.12507316044399, 53.8069680077689, 54.08263431276594, 56.872068541390554, 53.782180309295654, 56.12558535167149, 53.34008032935006, 54.74270275660923, 52.56073563439505, 58.5587020601545, 54.91272865022932, 60.584164483206614, 58.00995070593697, 62.49543326241629, 63.26998370034354, 81.78419535500663, 72.90505763462612, 91.18802629198346, 14.873697791780744, 1.8393970472472054, 23.7835830279759, 14.2446209192276, 4.269667165619986, 2.0738503294331685, 0.11298948167158024, 0.337445859930345, 34.32922880990164, 39.93604987008231, 66.3944982801165, 73.13369505746024, 17.251216752188547, 36.12101984024048, 53.11610514777047, 73.15462303161621, 75.08787591116769, 85.9558173588344, 36.747160230364116, 0.5436968111566135, 0.1076712938291686, 0.2494070811995438, 0.08378251854862485, 0.1516106432037694, 0.17949588117854937, 0.08854391412543398, 0.0810218784692032, 0.1106738316427384, 0.1678600912647588, 0.20524541661143303, 0.11623000885759081, 0.13117843387382372, 0.21153209784201213, 0.16063730312245234, 0.1428170736346926, 0.1395478919148445], [0.02349009524498667, 0.10131148687962975, 0.04298857253577028, 0.07156038616916963, 0.03967161177258406, 0.05127214500680566, 0.06959830716784511, 0.03411499011729445, 0.0333728594040232, 0.05262008196275149, 0.018721887176590304, 0.07357792862291847, 0.0848895280754992, 0.1254029202141932, 0.367421528590577, 12.477945021220616, 76.22955526624406, 62.743928636823384, 62.49584320613316, 55.03998143332345, 39.30774164199829, 30.429607936314174, 65.7265054157802, 31.505880423954554, 20.56538588660104, 0.04586555762216449, 0.2271604828004326, 0.8101376997573035, 2.0172199053423743, 0.7749098443559238, 2.1048110680920735, 1.7784816473722458, 11.401625633239746, 97.6758233479091, 80.84263106754848, 82.19247150421143, 70.82330090659005, 64.88780920846122, 62.21835994720459, 60.8537198475429, 64.8348639351981, 71.19913591657365, 76.7789284842355, 74.32734693799699, 71.43417957850865, 65.36455985477993, 58.14700044904436, 53.02588626316616, 53.842428139277864, 53.74596629823957, 53.866944858006065, 52.89791781561715, 55.3091025352478, 52.057213578905376, 53.213935783931184, 57.00995554242815, 52.71482583454677, 50.30432551247733, 49.98180055618286, 49.48570612498692, 50.389055320194785, 50.17966093335833, 52.57239123753139, 50.88357251031058, 55.15486642292568, 53.66436665398734, 55.120528425489155, 53.33322245734078, 55.91803918566023, 57.4303354535784, 50.516707624707905, 57.446076597486226, 63.05294976915632, 64.84140913827079, 63.47958305903843, 55.788441385541645, 51.99849087851388, 54.558193343026296, 62.54443890707833, 62.99252823420933, 63.80168764931815, 57.84502131598336, 63.401825768607004, 61.32939352308001, 65.63039098467145, 58.06524099622454, 67.55575765882219, 57.71803951263428, 44.45100321088518, 66.46810054779053, 59.904297147478374, 60.019678933279856, 57.35305411475045, 56.81028863361904, 51.07085425513131, 49.217318058013916, 45.5549955368042, 46.327555315835134, 46.49478455952236, 46.382994992392405, 46.454641342163086, 51.97008316857474, 53.94066177095686, 56.215036460331504, 46.51812008449009, 48.29435409818377, 52.575917448316304, 61.84017644609724, 61.682952608381, 61.28192343030657, 61.21443557739258, 49.17173440115792, 48.742259298052105, 43.13257558005196, 43.482969760894775, 42.88464648383004, 46.65496138163975, 48.18384647369385, 47.26610408510481, 46.95601293018886, 48.6762375150408, 47.61503914424351, 48.05231360026768, 47.97492109026228, 48.66008990151541, 47.83760036740984, 47.984454018729075, 47.492271423339844, 48.3087021282741, 51.290882859911235, 53.08898285457066, 56.26936789921352, 60.572734696524485, 55.58811787196568, 61.05792045593262, 56.684085028512136, 54.57136017935616, 56.45976938520159, 70.28345366886684, 68.059328351702, 68.60871546609062, 0.8973578938416072, 0.797633167888437, 10.280387878417969, 3.0739842397826056, 0.2314555144735745, 0.031038695547197546, 0.18388376358364308, 5.966952707086291, 29.771537099565776, 25.043107305254253, 58.83838789803641, 69.86410903930664, 28.020365238189697, 28.31107439313616, 48.10182646342686, 56.5123290334429, 63.610202244349885, 63.91208757672991, 16.98537172589983, 0.509903215936252, 0.0399398264874305, 0.05153783896405782, 0.034657109063118696, 0.11720302807433264, 0.04219958219411118, 0.05211863101326993, 0.05038060427510312, 0.03621452335002167, 0.05484098136158926, 0.05401757572378431, 0.03893116382615907, 0.014585252718201705, 0.030550530313381126, 0.020525930283058966, 0.04724237981385418, 0.03941311028652957, 0.0983674523553678, 0.005799862464690315, 0.09930282644927502, 0.036333470538790734, 0.06530964015317814, 0.0764118233429534, 0.02120314385475857, 0.01890396695983197, 0.07493184347237859, 0.09669290935354573, 0.017549677219774042, 0.09968408170555319, 0.15533035860529967, 0.4123377784022263, 21.385513033185685, 90.86971541813442, 69.54075377328056, 72.6909488950457, 64.67655617850167, 57.98198420660836, 26.22726447241647, 43.5797894341605, 38.921991552625386, 22.729925189699443, 0.07896343392453023, 0.30097829390849384, 3.307543158531189, 4.593801064150674, 2.710412148918424, 2.2245278784206937, 1.9783440828323364, 15.633558000837054, 99.6833941595895, 83.18759945460728, 85.95098836081368, 73.14991215297154, 68.37874398912702, 65.68871416364397, 63.628990173339844, 67.28816168648856, 76.03435952322823, 77.8993671962193, 77.47260189056396, 74.88030542646135, 69.23800686427525, 60.8503360748291, 55.68958241598946, 56.71060282843453, 56.902657985687256, 56.64886460985456, 55.811842918395996, 55.66053894587925, 55.377524920872276, 55.42159734453474, 60.04890305655343, 55.40772526604788, 53.611112185886924, 52.7816675049918, 52.77065461022513, 52.83673545292446, 52.1008552142552, 55.764258180345806, 55.80250801358904, 58.16916520254952, 56.85319375991821, 57.89852244513375, 53.829473223005024, 56.91388974870954, 58.10818781171526, 52.18540436880929, 58.82864652361189, 66.84212902614048, 66.83560466766357, 66.34981441497803, 58.679753576006206, 54.13455472673689, 57.0937751361302, 67.19454165867397, 67.61227430616105, 68.02392033168248, 61.84526252746582, 65.90653324127197, 64.72674996512276, 66.48523480551583, 60.43640409197126, 68.98311914716447, 58.969208581107004, 46.30855546678816, 68.65797124590192, 63.404500825064524, 61.34567315237862, 59.76579870496477, 59.468172618321006, 52.27262510572161, 49.55557721001761, 48.004398822784424, 48.575120380946565, 49.859255177634104, 50.318600586482454, 50.00407995496477, 54.662767205919536, 57.878883361816406, 58.85807909284319, 52.26539550508772, 50.03450959069388, 54.21799564361572, 62.62475313459124, 62.92540863582066, 62.888034275599885, 64.55126626150948, 52.9608268056597, 51.550676005227224, 47.03767510822841, 47.14891924176897, 44.99183709280831, 48.28592593329293, 50.74522692816598, 49.78086560113089, 50.560311044965474, 51.118821144104004, 48.951778752463206, 50.66979381016323, 51.94551433835711, 52.17034762246268, 50.864430223192485, 51.091313225882395, 51.17857912608555, 52.85371337618147, 53.92849547522408, 56.43661798749651, 60.36573396410261, 64.03040845053536, 58.61191831316267, 64.18436663491386, 59.53560488564627, 57.55987766810826, 58.72181102207729, 72.44979776654924, 69.68094757625035, 77.48285743168422, 3.4743409625121524, 1.1696632249014718, 0.6671500695603234, 4.647262241159167, 4.431065567902156, 0.4340450364564146, 0.1852520837315491, 3.040191024541855, 40.86488158362252, 31.22214378629412, 56.36463812419346, 53.294621740068706, 30.68100070953369, 38.703800746372764, 53.9292563029698, 60.674185344151084, 68.6754459653582, 74.40479155949184, 32.80308825629098, 0.9712412378617695, 0.055731989443302155, 0.014643474415476834, 0.06690111689801727, 0.02752561611123383, 0.0647474874609283, 0.04073536129934447, 0.03448272556332605, 0.0067513420113495416, 0.07342309371701308, 0.0733942152666194, 0.033114140786762745, 0.022868373963449682, 0.027202616478981714, 0.03352775877075536, 0.02350916886436088, 0.1646910070308617, 0.2382165188235896, 0.13608249143830367, 0.25962744706443375, 0.10287975094148091, 0.1703597464199577, 0.1651370216693197, 0.13905587260212215, 0.14554904560957635, 0.18612652538078173, 0.17875908714319977, 0.3273087910243443, 0.23693647608160973, 0.2177863043865987, 0.6482208424380848, 24.37288406917027, 104.11021654946464, 80.97157573699951, 83.24754851205009, 72.64343711308071, 52.63342768805367, 41.130737032209126, 92.49050780705043, 48.59037862505232, 34.29599905014038, 0.15742650255560875, 0.448335662484169, 3.406652480363846, 9.81284533228193, 3.9791673251560757, 8.520357063838414, 3.1456627249717712, 14.463263358388629, 105.26939841679165, 88.69756262642997, 89.5181587764195, 81.08382388523647, 71.9022102355957, 68.8440648487636, 66.86978285653251, 70.89619445800781, 79.24100181034633, 84.25521796090263, 80.14228044237409, 79.25107669830322, 73.63542447771344, 65.24084023066929, 59.27838952200753, 59.886273520333425, 61.14061096736363, 60.55331448146275, 59.84334060123989, 60.25525065830776, 57.31336600439889, 59.91151632581438, 63.578997884477886, 58.89720439910889, 55.84144919259207, 57.64544473375593, 55.016930784497944, 56.566184520721436, 55.66919640132359, 60.24470329284668, 58.91499178750174, 61.890391077314106, 59.49236624581473, 58.158329486846924, 53.65897832598005, 57.82354096003941, 61.80629702976772, 55.4688138280596, 62.20619365147182, 70.04146875653947, 70.64819240570068, 67.99858025142125, 61.81191117422921, 56.89712374550955, 60.973736081804546, 70.89955738612584, 69.51806095668248, 69.38437066759381, 64.73342718396867, 69.53643199375698, 66.42681435176304, 71.1503734588623, 64.42574705396379, 73.6956375667027, 64.14416435786656, 52.475964137486045, 70.85545716966901, 66.29709148406982, 63.891847474234446, 62.77709238869803, 63.014637402125764, 55.80941799708775, 52.68694618770054, 52.89485018593924, 51.19317381722586, 52.24793120792934, 53.119728633335654, 53.550701073237825, 58.504269872392925, 61.25268541063581, 61.650275230407715, 54.58534690311977, 52.75236695153372, 59.52384158543178, 66.13306535993303, 67.74494321005685, 64.02050031934465, 65.17613165719169, 54.74785484586443, 54.228681973048616, 50.10571125575474, 50.039943081992014, 48.223013469151084, 51.36860193525042, 54.17138365336827, 53.58008847917829, 52.66004623685564, 53.582728794642854, 51.52065978731428, 53.02030685969761, 54.977114132472444, 54.12395177568708, 53.85231195177351, 53.48667689732143, 53.709238120487754, 54.42469065529959, 56.194612230573384, 60.91095910753523, 62.62796320234026, 67.46818951198033, 60.929170336042134, 68.0735582624163, 62.18810749053955, 59.28970118931362, 62.775932039533345, 77.44259262084961, 74.63158770969936, 79.96420506068638, 2.081329630953925, 3.197093508073262, 22.897493158067974, 6.955876784665244, 2.511755117348262, 0.8119746297597885, 0.3935674641813551, 8.4137247971126, 49.45117357798985, 36.226139136723106, 72.95461913517543, 88.79915918622697, 39.097350188664024, 43.20855760574341, 64.35424314226422, 70.55887331281389, 80.52455643245152, 89.65218257904053, 28.875163895743235, 0.5730230946625982, 0.1903618595429829, 0.10816273638712508, 0.13571685605815478, 0.18032201113445417, 0.1625629990760769, 0.14729449552084717, 0.10172480970088925, 0.08081109835101025, 0.18657735761787209, 0.15140472139630998, 0.18855650856026582, 0.1054440297718559, 0.20003367055739674, 0.1314393984419959, 0.13118490709790162], [0.06804134071405445, 0.07040611667824642, 0.0750686429174883, 0.026490722982478992, 0.01690277211101992, 0.021132701741797582, 0.03219467833904283, 0.020644460172791566, 0.027498763087870817, 0.043158101117504497, 0.02780719457327255, 0.018060615785153847, 0.06807868049613067, 0.0288111057930759, 0.08553328138909169, 51.6167950630188, 78.8149938583374, 68.99572317940849, 60.282293047223774, 41.3012249810355, 25.037472316196986, 47.462685993739534, 45.38314574105399, 31.449148382459367, 5.529922306537628, 0.1733310241252184, 0.41967654174992014, 1.6977292490856988, 2.456583163567952, 1.8089574234826225, 0.35519568462456974, 0.2676965855062008, 50.95492703574044, 91.44120475224086, 78.3838164465768, 75.86109229496547, 62.461574690682546, 63.837540354047505, 60.1338586807251, 58.254638467516216, 55.611964089529856, 56.57636363165719, 56.87030022484915, 58.48281383514404, 56.12609257016863, 53.155532700674875, 53.7754579271589, 52.33956752504621, 54.7049879346575, 50.9066162109375, 51.87939875466483, 52.607441425323486, 51.61112533296858, 50.86733109610421, 53.139676911490305, 51.316024916512625, 55.33843435559954, 50.30198744365147, 49.32314607075283, 47.7893624986921, 49.848638330187114, 51.27889721734183, 50.17664194107056, 53.38484409877232, 54.410227979932515, 56.3865145274571, 55.4397668838501, 52.65409857886178, 58.82025309971401, 50.86594145638602, 51.913594314030235, 60.16538265773228, 63.148411069597515, 63.52803284781319, 65.04865305764335, 58.909523555210654, 56.57134703227452, 48.758698735918315, 57.266872133527485, 57.69315801348005, 62.762202399117605, 59.25751713344029, 60.616209575108115, 58.94457026890346, 61.91179847717285, 60.0011967250279, 67.89419746398926, 54.66946874346052, 43.46498782294137, 65.37703881944928, 58.350999559674946, 58.83618531908308, 51.63092075075422, 51.091004031045095, 48.549446787152974, 47.29573120389666, 51.42718914576939, 53.57542623792376, 53.30970975330898, 52.85835129874093, 50.69078779220581, 49.644076415470664, 51.69661944253104, 51.22024747303554, 46.51937076023647, 45.066342626299175, 54.53906495230538, 59.62490313393729, 61.551027161734446, 58.48933124542236, 64.8475513458252, 54.88856976372855, 49.1493855203901, 46.13117143086025, 45.35674606050764, 43.76415293557303, 42.80085468292236, 47.86045299257551, 46.93524823869978, 50.48759119851248, 48.34741401672363, 48.575575487954275, 48.913702624184744, 47.471802030290874, 48.63229710715157, 47.86746025085449, 49.46870040893555, 52.89038249424526, 55.60072190420968, 57.47152437482561, 58.401909010750906, 61.12312235151018, 64.55008506774902, 62.54769761221749, 64.05985491616386, 60.79563985552107, 60.198136465890066, 56.92539596557617, 66.11485413142613, 63.774450710841585, 78.40358407156808, 37.849352972848074, 0.2512689270079136, 2.430789061955043, 15.266425609588623, 2.0028573274612427, 0.49362917776618687, 0.03208383285839643, 1.8904819403375899, 19.242329018456594, 20.8251599243709, 51.61443267549787, 87.17670617784772, 39.74730552945818, 19.864524568830216, 35.429076535361155, 49.37960365840367, 57.59063734327044, 55.58997998918806, 61.000507490975515, 18.573076793125697, 0.3142552971839905, 0.042022616868572574, 0.04493354906194976, 0.07795802144599812, 0.0477819542533585, 0.08550709672272205, 0.02488627264808331, 0.03211245346548302, 0.038255437942487855, 0.04386158926146371, 0.008169118880427309, 0.014391025461788689, 0.017051971783595424, 0.03683609874652965, 0.06310632159667355, 0.06100445081080709, 0.02817368321120739, 0.11853260387267385, 0.03663914717201676, 0.03029377944767475, 0.05070619251845138, 0.02566093233014856, 0.025338000551398312, 0.009043656372731286, 0.006593937578145415, 0.01852595340460539, 0.0490438597542899, 0.0526313727854618, 0.013102865744648235, 0.16463945194014482, 67.90632901872907, 86.73312623160226, 76.22592830657959, 72.4322327205113, 57.99287550789969, 44.35062605994088, 40.520473275865825, 45.55154228210449, 39.7294590813773, 6.475517851965768, 0.520634220114776, 2.5128622693674902, 4.178421684673854, 2.937206562076296, 2.643836464200701, 0.3145551825208323, 0.577252919120448, 55.30732379640852, 95.3910402570452, 81.67886066436768, 78.83899293627057, 66.06762722560337, 67.44666399274553, 61.459338733128135, 61.66893114362444, 59.32734652927944, 59.63147612980434, 59.755174909319194, 60.24774660382952, 57.96951219013759, 55.84862668173653, 56.94493777411324, 55.790428570338655, 56.99504123415266, 52.52072095870972, 55.674880027770996, 54.864438670022146, 54.78901597431728, 55.290074893406455, 54.548604828970774, 53.1071697643825, 57.79978506905692, 54.932207924979075, 52.17971726826259, 51.88190705435616, 54.0742895262582, 53.744156292506624, 52.842460768563406, 55.77260644095284, 55.80289363861084, 55.588791847229004, 54.953458990369526, 55.11317375728062, 60.739873613630024, 53.91707958493914, 54.318952969142366, 62.7254672731672, 65.9822199685233, 65.51550946916852, 67.72351496560233, 62.86238152640206, 60.4130859375, 51.293842792510986, 59.57007489885603, 63.33009951455252, 63.7430031640189, 61.31319032396589, 61.09837981632778, 60.74494579860142, 63.78828457423619, 61.156140191214426, 70.43093613215855, 57.66930137361799, 45.940662247794016, 69.3951473236084, 62.490798813956125, 60.850732122148784, 55.210420744759695, 53.865833146231516, 50.3131115095956, 50.34909275599888, 55.56079408100673, 57.54230914797102, 55.52559103284563, 55.68108129501343, 52.395708969661165, 51.359725611550466, 53.60076631818499, 53.58914545604161, 48.2342973436628, 47.972669873918804, 56.5454615184239, 63.44556467873709, 64.41931997026715, 62.12530272347586, 65.47406346457345, 58.92587266649519, 49.91568149839129, 50.27770348957607, 47.306285517556326, 47.19004910332816, 44.78641012736729, 49.673147678375244, 49.64006035668509, 50.911653654915945, 49.86513335364205, 51.34874745777675, 51.434526443481445, 50.42513036727905, 50.977810927799766, 51.290452071598594, 51.80481331689017, 56.255478450230186, 58.337242126464844, 63.49309035709926, 61.433470589774, 65.30656324114118, 66.53159318651471, 67.28865500858852, 66.27945695604596, 62.16690853663853, 60.59765788487026, 60.11419527871268, 66.25971712384904, 67.02652032034737, 79.29024369376046, 49.84015110560826, 0.28989993408322334, 1.2582912977252687, 5.147550778729575, 5.881102068083627, 3.897175976208278, 0.19916601425835065, 0.5053586055125509, 15.044918775558472, 30.04710612978254, 53.47840506689889, 79.6599087033953, 40.126024041857036, 28.812730857304164, 45.944581031799316, 61.05738544464111, 60.65882287706648, 64.0859454018729, 73.3710663659232, 32.462772437504356, 0.5921996885112354, 0.026188462773071866, 0.08677533974072763, 0.0269455840212426, 0.07304941091154303, 0.015056944818102887, 0.056984314029770236, 0.026632165303453803, 0.057252504995891025, 0.05045780120417476, 0.03652071566986186, 0.020875343587249517, 0.0729165333988411, 0.01447176095098257, 0.051582551029111655, 0.1329088881611824, 0.20647718837218626, 0.1924310927944524, 0.14212067957435334, 0.12521829083561897, 0.11479627793388707, 0.1381495940898146, 0.08107184578797647, 0.09430430323949882, 0.10458365415355989, 0.09751849648143564, 0.11573599465191364, 0.16890765433864935, 0.05447249274168696, 0.2261750599635499, 81.72401700701032, 100.30635574885777, 89.63693823133195, 79.70143808637346, 60.61909307752337, 34.38710035596575, 69.07812881469727, 65.4097717830113, 50.49779462814331, 9.596449766840253, 0.6044969686440059, 2.21344832437379, 5.922713960920062, 6.977870873042515, 5.835009455680847, 3.4942345236028944, 1.093050541622298, 59.74985258919852, 98.33469322749546, 88.06579072134835, 83.08106967381069, 68.99941962105888, 69.55223914555141, 67.48469148363385, 64.25828157152448, 62.707276889256065, 63.48582948957171, 63.75965799604143, 65.5261332648141, 61.52552727290562, 59.87907518659319, 61.03255953107561, 57.86883626665388, 60.57922431400844, 55.99811370032174, 58.59518010275704, 59.4038461957659, 58.711951528276714, 57.38916737692696, 56.83290502003261, 54.76108769008091, 60.73120920998709, 57.37841156550816, 56.75752401351929, 53.33065162386213, 56.73333733422415, 56.43359899520874, 54.667328698294504, 57.89476694379534, 58.06943770817348, 58.27905443736485, 56.4653765814645, 55.47955574308123, 63.162766047886436, 57.08174780436924, 58.026160853249685, 66.08747128077916, 70.68644223894391, 69.94855049678257, 71.32919924599784, 65.0737360545567, 62.25062738146101, 53.60479279926845, 62.92602007729666, 66.18778242383684, 67.88012736184257, 64.98268686022077, 65.20095757075718, 64.78656700679234, 68.0949934550694, 65.10425254276821, 73.8522847039359, 59.5056095123291, 49.79301105226789, 71.05365453447614, 63.90314524514334, 61.93351854596819, 56.95606878825596, 57.287751470293315, 54.34170831952776, 53.44743694577898, 58.20422233854021, 59.74067401885986, 58.754425866263254, 59.9724520274571, 55.15399442400251, 53.368984835488455, 57.38659654344831, 56.256148951394216, 52.35428033556257, 49.74334532873971, 58.402791431971956, 66.05889333997453, 65.51539829799107, 65.28309222630092, 67.38018362862724, 59.4365166255406, 53.87987545558384, 51.361980301993235, 50.58317756652832, 49.638135705675396, 49.360068798065186, 53.50604847499302, 52.305045400347026, 54.66052641187395, 52.49680525915963, 53.770055702754426, 54.758621079581125, 52.66071326392037, 53.99958944320679, 53.535008566720144, 56.391208035605295, 58.74077960423061, 61.74235275813511, 65.49249703543526, 62.40963690621512, 67.7120087487357, 70.07002585274833, 69.87205777849469, 70.7487119947161, 65.73150811876569, 65.13901438031877, 62.25219072614397, 71.28485584259033, 69.19164848327637, 84.60738740648542, 47.030737331935335, 0.5610045567154884, 7.681680832590375, 26.34963093485151, 5.247958328042712, 2.3908671012946536, 0.2702025238956724, 3.55861696600914, 28.240544966288976, 37.243011474609375, 66.96812071119035, 106.68502439771379, 52.582639830453054, 28.788651875087194, 53.25575699125017, 68.10431098937988, 73.76406342642647, 73.05413818359375, 87.30448354993547, 29.061353036335536, 0.5191159301570484, 0.10955612840397017, 0.15297550282308034, 0.16058350886617387, 0.17607835813292436, 0.21049912327102252, 0.18657016514667443, 0.08864766891513552, 0.09429174355630364, 0.14317232742905617, 0.08879395427980594, 0.09361695405095816, 0.14148470227207455, 0.12610452542347567, 0.17419805617204734], [0.05475347748558436, 0.05020457872056535, 0.151830542832613, 0.023020024843780056, 0.06735458863633019, 0.04283167149073311, 0.031021206307091882, 0.03518357081338763, 0.08274834297065224, 0.03738384614033358, 0.1050047054886818, 0.03506417918418135, 0.11834593888904367, 0.2208185823900359, 8.913877844810486, 78.1354044505528, 64.82865224565778, 68.13165215083531, 51.66546719414847, 31.87905079977853, 20.669726984841482, 39.61248615809849, 35.222510065351216, 25.5222498689379, 0.179600185581616, 0.11763066798448563, 0.4794253227966172, 4.2602071932383945, 0.42732810974121094, 1.527974118079458, 1.1480116610016142, 0.9998348121132169, 77.9585519518171, 84.53913525172642, 79.60492065974644, 70.56072153363908, 68.97281496865409, 63.40923949650356, 60.83451502663748, 59.621609687805176, 57.90626968656267, 53.89270877838135, 53.140472480228965, 53.45671626499721, 53.559500966753276, 54.52597107206072, 54.13666697910854, 53.81428793498448, 51.96752275739397, 53.0065598487854, 51.79427637372698, 50.08520712171282, 53.6975998878479, 53.2811769757952, 55.05410712105887, 52.73476716450283, 53.0866482598441, 48.51436880656651, 49.4652749470302, 50.663283348083496, 51.073289598737446, 51.346697739192415, 53.4617189679827, 55.24117694582258, 53.52195290156773, 52.60963358197893, 55.49393504006522, 58.13980906350272, 51.62906905582973, 49.8666341645377, 55.830603054591585, 59.77137116023472, 64.21629360743931, 60.93930080958775, 66.21226787567139, 61.36704581124442, 58.233835560934885, 54.036682401384624, 49.23756858280727, 54.43789223262242, 57.312070165361675, 58.81907885415213, 57.80470091956002, 54.79615524836949, 57.46808154242379, 56.15836347852434, 65.96499538421631, 54.4425926889692, 42.992941107068745, 67.41775948660714, 56.879701137542725, 55.065106119428364, 47.878764969961985, 50.80605493273054, 51.43647541318621, 56.55669675554548, 57.75095312935965, 61.06648063659668, 57.131014006478445, 54.48336124420166, 49.35273844855172, 48.83977031707764, 49.37899916512625, 49.647560937064036, 44.62559059688023, 47.95578575134277, 54.73516048703875, 60.630453382219585, 59.73439284733364, 58.49249962397984, 60.9889109475272, 63.0286727632795, 49.80782461166382, 48.75339726039341, 44.88004057747977, 46.79936579295567, 41.90239354542324, 44.60766077041626, 48.02412823268345, 48.258876596178325, 48.02679981504168, 49.102245467049734, 47.141290119716096, 48.338162490299766, 47.37289442334856, 50.7709630557469, 52.82933562142508, 57.56609630584717, 59.64381613050188, 63.23590278625488, 62.06335258483887, 64.17983640943254, 63.69334438868931, 67.36366081237793, 66.12247630528041, 63.419071197509766, 63.101059096200125, 64.43048572540283, 60.52269377027239, 68.72734206063407, 66.37301445007324, 74.81433922903878, 8.571695566177368, 0.9925322553941182, 5.493991000311715, 9.038337452071053, 0.3425585398716586, 0.5904148699981826, 0.052806156620915444, 10.987567714282445, 28.167015654700144, 17.62254932948521, 42.83396632330758, 31.64057125364031, 25.119395051683696, 26.690127406801494, 33.48278883525303, 40.27623019899641, 59.70450864519392, 56.78079005650112, 63.183707918439595, 6.69794054542269, 0.15879695330347332, 0.026783264874081527, 0.07719158900103398, 0.018316287780180573, 0.03381701146385499, 0.04267738959086793, 0.054739662512604675, 0.07443886742527996, 0.010043591377325356, 0.06166417683873858, 0.061638161806123595, 0.07858544920704194, 0.015404271627111095, 0.04089062028963651, 0.039455864778054614, 0.012535869160534015, 0.02397908829152584, 0.025827392237260938, 0.029407894305352653, 0.0348591225088707, 0.06999932136386633, 0.05932887643575668, 0.049826264913593016, 0.02360019433711256, 0.020400497995849167, 0.11208144575357437, 0.262996183442218, 0.2581669682902949, 14.190100141933986, 92.90711484636579, 69.7609143938337, 77.04773344312395, 60.399960790361675, 47.0825708934239, 22.126265696116857, 27.684452840260096, 40.451314381190706, 29.85032967158726, 0.21713360798146042, 0.1967586941484894, 4.258306860923767, 6.418147010462625, 7.30915663923536, 4.144494065216609, 1.4092500316245216, 2.5229056732995168, 85.57166535513741, 88.130005972726, 82.45336941310337, 74.24923528943742, 71.371492930821, 66.3424562726702, 64.16990048544747, 61.005301748003276, 60.880796977451865, 59.83649662562779, 56.564836570194785, 57.25162778581892, 56.9991580418178, 56.874229431152344, 57.05970117024013, 55.19969620023455, 55.88799517495291, 57.46017101832798, 55.5182398387364, 52.388944898332866, 56.41984156199864, 56.358957971845356, 57.42630549839565, 55.65525484085083, 54.97124637876238, 51.80427483149937, 51.200757775987896, 52.28758110318865, 52.226607186453684, 53.52396787915911, 56.30138519832066, 56.23225062234061, 54.52156244005476, 53.327121938977925, 57.51948084150042, 61.301058769226074, 53.622295311519075, 53.491342612675254, 58.593067850385395, 62.54788521357945, 65.47252791268485, 63.66464832850865, 68.05019841875348, 64.60073048727853, 60.68965898241316, 56.79636444364275, 51.53396906171526, 55.56168345042637, 60.0961924961635, 61.07321344103132, 60.177889415196006, 57.62220300946917, 58.570958682468955, 60.67353221348354, 69.48246533530099, 55.96629095077515, 46.69738013403756, 70.16245773860386, 60.07733508518764, 57.10556622913906, 48.71902452196394, 51.84055485044207, 53.88871703829084, 59.2124719619751, 60.68585136958531, 65.59479536328996, 59.14191995348249, 58.44522408076695, 51.62904821123396, 51.24524014336722, 52.080503940582275, 52.03778294154576, 47.75242587498256, 51.59107630593436, 58.46861866542271, 64.16204902103969, 62.29680510929653, 61.70226165226528, 60.19578102656773, 65.79561219896588, 51.01516096932547, 51.36513825825283, 48.16304704121181, 48.937336921691895, 43.42031438010079, 47.70684221812657, 49.509156295231406, 50.36455944606236, 50.816341740744456, 50.83042573928833, 50.24604402269636, 50.902332646506174, 49.29945618765694, 51.267324992588584, 56.78231866019112, 60.9804619380406, 62.80327320098877, 65.99280902317592, 65.14965207236153, 67.1894416809082, 66.2024153300694, 69.41399778638566, 69.5032821382795, 66.35364982060024, 67.01274899074009, 68.06372656141008, 65.04631151471818, 71.73462663378034, 69.55905532836914, 79.79765674046108, 13.919873407908849, 0.5093280353716442, 2.7181808863367354, 4.369702117783683, 5.215468117168971, 2.1205159510884966, 0.034414336018796475, 4.478883504867554, 32.53199734006609, 21.902827262878418, 47.526692799159456, 29.368360928126744, 39.89913756506783, 45.59275204794747, 41.77094752447945, 47.758609771728516, 64.77719388689313, 63.43576771872384, 74.10097462790353, 16.175722462790354, 0.3019254745117256, 0.08634558280131646, 0.07157340725617749, 0.05423647790615048, 0.031207572735313858, 0.01195496939388769, 0.036414362091038904, 0.008631742359804255, 0.024214273618002023, 0.03292812041140028, 0.0497955985234252, 0.024433956115639636, 0.06887365212397915, 0.01020718617032149, 0.11108058624501739, 0.13370497258646147, 0.20193183155996458, 0.12089054020387785, 0.1397872112159218, 0.11079866173011915, 0.14096520229109696, 0.16267403454652854, 0.2167488243430853, 0.19230762656245912, 0.26233534461685587, 0.2905994765460491, 0.4251770180250917, 0.46402290357010706, 15.842050858906337, 107.06951686314174, 80.72961166926792, 88.17371709006173, 71.0392370223999, 45.48244244711739, 28.74664827755519, 53.503279617854524, 49.340797969273154, 43.11461101259504, 0.43105573686105864, 0.3990451959627015, 4.055852421692439, 11.317816461835589, 6.097264000347682, 8.192314369337899, 4.687911808490753, 2.1435920042651038, 90.89904376438686, 92.43253898620605, 86.44321264539445, 77.08487156459263, 75.75635514940534, 70.2702659879412, 67.52886813027519, 66.82856614249093, 64.58372129712785, 61.60710607256208, 58.9647547858102, 59.91440677642822, 60.7344331741333, 60.358605112348286, 61.1616918018886, 60.44032287597656, 58.785157748631065, 59.54755578722273, 59.254814284188406, 55.3508368900844, 61.549012184143066, 59.987418447222026, 60.687505040849956, 59.026051793779644, 59.044506209237234, 54.44908578055245, 56.20369700023106, 55.808678013937815, 56.77062136786324, 57.29158340181623, 58.95966870444161, 58.76919773646763, 55.16124834333147, 54.48996550696236, 58.76982307434082, 63.1615640095302, 57.29850728171212, 54.69596222468785, 60.92592552730015, 65.40749277387346, 70.89522865840367, 68.32968275887626, 72.02099663870675, 66.73449448176792, 63.20911053248814, 61.101325852530344, 53.27661200932094, 61.47882843017578, 64.00062152317592, 64.27622182028634, 61.78556360517229, 60.44343566894531, 62.59557070050921, 63.58284023829869, 73.28531169891357, 60.474730355399, 52.186363220214844, 72.89237717219761, 63.40158258165632, 60.620976039341514, 53.62908022744315, 56.10875334058489, 57.77035597392491, 61.92755004337856, 64.55364949362618, 68.77133110591343, 63.15461581093924, 59.99759060995919, 55.00011961800711, 55.03714656829834, 55.33872965403965, 55.186393874032156, 50.75715351104736, 55.17207363673619, 60.2793539592198, 66.84331716809953, 65.79058170318604, 64.14056519099644, 63.01344926016671, 66.73895522526333, 54.93056467601231, 55.695578711373464, 50.80591944285801, 51.74335650035313, 46.74828263691494, 50.0211968421936, 52.80109814235142, 53.091501576559885, 53.62521702902657, 54.687231813158306, 51.77636044366019, 53.23605190004621, 52.44800806045532, 55.763247217450825, 59.92277240753174, 62.86852373395647, 66.84492220197404, 68.76325035095215, 67.11461653028215, 68.39111873081752, 69.95441477639335, 73.07490634918213, 73.36947522844586, 68.64293534415108, 69.11508628300258, 70.53713934762138, 67.15635435921806, 76.25563185555595, 72.66748482840401, 80.15199402400425, 12.974336487906319, 1.9440256272043501, 14.375208837645394, 17.316064289637975, 2.7088472843170166, 2.2788871100970676, 0.10290297719516925, 15.315882887159075, 42.633458682468955, 29.573773997170584, 57.74321631022862, 43.84714221954346, 36.27737167903355, 40.24182619367327, 48.53398357118879, 57.1911541393825, 78.12500994546073, 73.92320496695382, 87.67164025987897, 15.277471508298602, 0.38474536900009426, 0.20265376567840576, 0.1818366777151823, 0.13929208421281405, 0.10594357403793506, 0.09882361787770476, 0.119987016543746, 0.19990104410265172, 0.1311982199549675, 0.20229520063315118, 0.10765290553016321, 0.1654951660228627, 0.14905779090310844, 0.1248992300991501], [0.06541899964213371, 0.024148832308128476, 0.03640540882146784, 0.036163514479994774, 0.06158161269766944, 0.047106574422546794, 0.10787653710160937, 0.02487590124032327, 0.06952731883419411, 0.025657582063493983, 0.08699768209563834, 0.054347744078508446, 0.09737069798367363, 0.09898104478738137, 49.95247220993042, 78.14361722128731, 72.72101375034877, 60.35836887359619, 45.87497397831508, 28.99123876435416, 60.29744012015206, 56.7862548146929, 38.19731181008475, 9.311868923051016, 0.028464540639626126, 0.4184866355998175, 5.244607125009809, 3.7355765104293823, 6.468126705714634, 12.611755166734968, 2.9191353831972395, 26.4543194430215, 92.5820642198835, 83.60828508649553, 76.82680852072579, 79.71909345899309, 68.98752430507115, 70.23827648162842, 65.72805486406598, 64.89905139378139, 60.16570227486746, 57.304659911564414, 52.72097846439907, 55.16538946969168, 51.23802096503121, 52.21542406082153, 51.80646351405552, 54.30931234359741, 53.613196645464214, 55.00413915089199, 51.231885705675396, 52.0223023550851, 51.90753895895821, 52.762598173958914, 52.81692961284092, 52.576792921338765, 49.27672168186733, 49.7070757320949, 48.693337031773154, 49.85782037462507, 50.4406943321228, 51.55494914736067, 51.83145618438721, 52.69882413319179, 52.64030987875802, 53.4994546345302, 56.678519521440776, 50.474292346409385, 53.16701112474714, 58.330175808497835, 60.83418846130371, 62.619965825762065, 63.227585792541504, 57.979031222207205, 63.244018282209126, 63.86135183061872, 59.482784679957796, 57.1708653994969, 54.30168669564383, 48.789687701633994, 53.06332663127354, 55.07475369317191, 56.95466177804129, 54.87510762895857, 53.85327775137765, 56.60372911180769, 64.23704092843192, 50.2116573878697, 44.292716298784526, 67.27083982740129, 56.244458607264924, 54.04406138828823, 47.97445208685738, 57.93188074656895, 56.54020173209054, 62.91305473872593, 57.300237383161274, 62.6378504889352, 58.70819255283901, 55.8538795198713, 47.10329042162214, 46.48520646776472, 46.42271089553833, 46.57059635434832, 44.015858377729145, 51.98270457131522, 58.79513536180769, 59.60541343688965, 58.216753414699006, 58.077970096043174, 51.994982038225444, 64.32257325308663, 53.90326656614031, 47.22749989373343, 48.15101276125227, 45.90936408724104, 45.0807010786874, 41.70649256025042, 46.746830463409424, 48.37846551622663, 47.2906242779323, 48.15797485624041, 46.4976715360369, 47.20601258959089, 47.22357068743025, 53.183460984911235, 59.52609280177525, 62.32096399579729, 68.15560259137834, 64.91755444662911, 64.5890783582415, 65.44280351911272, 62.632965905325754, 64.4040756225586, 66.34158774784633, 67.66764450073242, 67.22954668317522, 66.26910414014543, 67.87769549233573, 68.01433876582554, 69.37842995779855, 70.45827034541539, 41.27677427019392, 0.09142771509609052, 0.7962803319096565, 11.20690757887704, 6.223087625844138, 0.6326570404427392, 0.19645735674670764, 0.1663969119212457, 32.57930415017264, 34.227666991097585, 28.763940606798442, 52.901919978005544, 13.050766672406878, 13.218659469059535, 16.1332984992436, 26.391997575759888, 42.679129191807334, 53.29402766908918, 62.43686689649309, 42.57238054275513, 0.6907569542527199, 0.006769992394505867, 0.006160234109432037, 0.07873512724680559, 0.042636470536568334, 0.01492336841433176, 0.07178761397621461, 0.026574773115238974, 0.030846191769731895, 0.036349897871592214, 0.05506278428116015, 0.12573010980018548, 0.025196008617058396, 0.033774969434099536, 0.0185406063683331, 0.009019914432428777, 0.04600352754018136, 0.0013075032662267663, 0.01475593141679253, 0.027991018191512142, 0.08260037483913557, 0.02254886709020606, 0.06736177432217769, 0.005430768252283866, 0.06692939823759453, 0.05328211161707129, 0.04754658741876483, 0.02437781752087176, 65.18517126355852, 87.2388300214495, 80.81698526654924, 71.5611092703683, 64.03470243726457, 34.78660093035017, 25.564319474356516, 46.75815602711269, 44.74388367789132, 11.458945666040693, 0.10226477429802928, 1.4853221667664391, 6.558428968702044, 3.99166887147086, 15.683585030691964, 10.287941438811165, 2.354239455291203, 28.133393321718486, 92.20458248683384, 85.73334993634904, 81.52350589207241, 85.14316994803292, 72.98091806684221, 72.84431648254395, 68.89661407470703, 69.81256035396031, 63.743906429835725, 61.581786836896626, 56.543641090393066, 57.224165030888145, 53.963906969342915, 53.8212639263698, 55.32130009787423, 57.444950989314485, 57.07195431845528, 58.837936265128, 54.87338100160871, 54.77898972375052, 55.22279896054949, 55.00501809801374, 53.92754357201712, 56.59153502328055, 51.15124143872942, 51.92895678111485, 52.99186788286482, 53.824876989637104, 52.571818011147634, 52.65009989057268, 55.038101945604595, 53.23771251950945, 55.13305255344936, 53.719462394714355, 57.134290082114084, 51.73671749659947, 54.53480223246983, 61.35890947069441, 64.44077600751604, 65.47751671927315, 66.41326536451066, 60.655640602111816, 64.13932146344865, 66.24932956695557, 62.5436954498291, 59.426017897469656, 55.70228024891445, 50.66434294836861, 55.43116501399449, 57.674251965114046, 58.371767725263325, 57.409049647195, 56.26662336077009, 59.207545689174104, 67.74189989907401, 53.7922100339617, 47.80407878330776, 68.44951833997453, 56.572701930999756, 54.60523264748709, 52.014027050563264, 62.59724521636963, 61.968370710100444, 64.73854800633022, 60.748454638889854, 63.90440286908831, 60.74355615888323, 58.08721814836775, 49.782901423318044, 49.59866993767874, 48.731729303087505, 48.15140880857195, 45.45659514835903, 53.95701435634068, 61.939612116132466, 63.554713930402485, 62.031126839774, 61.25490883418492, 53.77027457101004, 66.40537915910993, 56.703317642211914, 51.19289936338152, 51.139787333352224, 48.64066621235439, 47.64324883052281, 43.72719199316842, 48.83040067127773, 50.899271965026855, 49.09113529750279, 49.52022130148751, 49.455175740378245, 50.498159408569336, 48.821982928684776, 55.64733042035784, 62.5392347063337, 64.86231626783098, 70.39767510550362, 67.74085766928536, 64.89244365692139, 66.80968788691929, 64.14324024745396, 66.95001370566231, 66.96213136400495, 69.2096026284354, 70.4123705455235, 71.86692033495221, 69.82633863176618, 70.34978117261613, 73.09357615879604, 72.54061767033168, 47.59071697507586, 1.3257926127740314, 0.30777292645403315, 2.7761071494647434, 6.27309033700398, 3.845054498740605, 0.3873466822717871, 0.1836427343743188, 30.09093189239502, 44.47394963673183, 33.461259841918945, 47.771498680114746, 15.16004695211138, 18.999847309929983, 29.446007047380718, 40.40114491326468, 52.4274274962289, 61.07149028778076, 67.47782666342599, 59.21880177089146, 1.1331416474921363, 0.06271763638194118, 0.06196486284690244, 0.03166680523593511, 0.02659185862700854, 0.06835797229515654, 0.06884839705058507, 0.07895865025264875, 0.025889089730169092, 0.01566210645250976, 0.05030092051518815, 0.07291921361216477, 0.005156582853357706, 0.048718288474317105, 0.1389560058180775, 0.10286487066852194, 0.24745973997882434, 0.15358140745333262, 0.17724075647337095, 0.14723703717546804, 0.14462323885943207, 0.15472351759672165, 0.16277513626430715, 0.07167150984917368, 0.18804943934082985, 0.09732037104134049, 0.1641348118760756, 0.1588609255850315, 74.21499456678117, 97.7144900730678, 91.5929742540632, 80.26792471749442, 66.24372237069267, 39.7723503112793, 85.40405396052769, 76.43684087480817, 59.28614371163504, 15.798487390790667, 0.22814176657370158, 1.2746675504105431, 14.819149221692767, 9.150232979229518, 9.944005608558655, 17.98747566768101, 4.970213208879743, 33.92620897293091, 96.90191214425224, 90.56326511928013, 83.74663761683873, 90.44979408809117, 76.86322402954102, 78.25426728384835, 74.73801326751709, 74.52637808663505, 68.0222944532122, 65.44647216796875, 59.52901104518345, 62.719318117414204, 56.56980800628662, 56.538777351379395, 58.44305624280657, 60.77512182508196, 61.50505093165806, 63.05347783224923, 56.99225500651768, 59.329778398786274, 58.07027844020298, 56.88352959496634, 56.777725900922505, 59.03942707606724, 53.98637744358608, 56.106741837092805, 55.52552155085972, 57.7613650049482, 55.40337569372994, 57.417891229902, 56.975596700395855, 55.387849943978445, 55.25327723366873, 53.20159925733294, 57.97459132330758, 56.00972761426653, 55.94398028509957, 64.3289794921875, 67.5449115208217, 69.09557574135917, 68.09546593257359, 63.368543897356304, 68.50531932285854, 69.2655564716884, 64.77823611668178, 63.932021958487375, 60.218543325151714, 52.89353697640555, 57.856937476566856, 60.27472645895821, 62.398359979902, 59.380284854343955, 60.822640555245535, 63.30972739628383, 69.20487090519497, 56.74702875954764, 51.854409558432444, 72.10031032562256, 60.334661620003835, 58.66254983629499, 53.81431572777884, 64.92078535897392, 65.6906179700579, 68.60062081473214, 62.34319823128836, 68.46910531180245, 64.73239190237862, 60.660372325352256, 52.60824394226074, 52.96688910893032, 51.724933351789204, 51.24697024481637, 48.23833772114345, 58.701584815979004, 65.45470578329903, 64.68303189958844, 65.42974090576172, 64.45698615482875, 56.62598071779524, 66.87102658408028, 58.23687539781843, 53.783622060503276, 53.66694096156529, 52.28333575384957, 50.64505474908011, 47.16823523385184, 51.666783877781455, 54.383567741939, 51.38616698128836, 51.851074423108784, 51.38278668267386, 52.24561398369925, 50.93532269341605, 58.1822486604963, 64.18204593658447, 68.71419606889997, 71.79263714381626, 72.22389098576137, 68.69609601157052, 72.44548988342285, 66.84733322688511, 70.13799313136509, 70.29475143977574, 73.79600429534912, 72.1789778300694, 73.69130883898053, 73.79694925035749, 73.15031514848981, 76.09403760092599, 73.93107727595738, 49.0517702783857, 1.3128888309001923, 3.9787938594818115, 21.005891254970006, 11.496387771197728, 2.33185344508716, 0.7340182300124849, 0.24427545656050953, 40.199469975062776, 51.544957637786865, 44.773687975747244, 69.59879902430943, 19.09443313734872, 19.242342914853776, 28.002320766448975, 45.53722899300711, 61.258577483040945, 70.98727839333671, 79.41682597569057, 67.94219561985561, 1.5274107711655753, 0.11590874966766153, 0.09260556367891175, 0.1661383765084403, 0.11138494991298233, 0.16172073355742864, 0.15929683005171164, 0.1679506078362465, 0.10968464972185236, 0.10549555093582187, 0.09438671131751367, 0.25901874686990467, 0.1526165170861142, 0.16569916079086916], [0.07043593150696584, 0.050817994733474085, 0.05875196560685124, 0.1257434497986521, 0.026195612835830877, 0.04159775895199605, 0.08721837561045374, 0.05573248477386577, 0.07081532079194273, 0.07858926257384674, 0.08971172717532941, 0.09760699101856776, 0.16654382832348347, 4.815212360450199, 78.167081287929, 66.78183255876813, 64.03159659249442, 46.015007972717285, 30.883429527282715, 42.974375520433696, 77.47133037022182, 36.95364679609026, 28.120903934751237, 0.7373048907944134, 0.09197283655937229, 0.13664355847452367, 5.0703771369797845, 3.1945899852684567, 16.202457393918717, 0.33906807431152886, 3.195706908191953, 53.084768772125244, 65.51977566310337, 92.69647325788225, 77.01074818202427, 79.88127136230469, 78.34671306610107, 75.12855761391776, 68.2159754889352, 69.42866543361119, 69.46599115644182, 69.15412126268659, 63.76138809749058, 54.301269803728374, 54.148305211748394, 54.408428396497456, 55.50320046288626, 54.058979170663015, 56.261662346976145, 57.6234849521092, 53.449976512363975, 51.35850967679705, 51.9329172543117, 53.05776112420218, 52.03886686052595, 51.32383469172886, 48.2113161768232, 46.388303416115896, 49.07005793707711, 51.97757680075509, 50.709989139011924, 49.57579646791731, 51.572896344321116, 50.79850224086216, 52.51103516987392, 54.08272116524832, 49.81127439226423, 54.53675815037319, 62.61321217673165, 61.875723430088584, 66.67099489484514, 64.54762540544782, 61.7365996497018, 57.4839060647147, 59.23458112989153, 60.262706075395855, 65.15864998953683, 62.382879393441335, 56.69208935328892, 50.88714735848563, 49.84483071735927, 52.347731658390586, 56.70484972000122, 56.69192259652274, 58.11081770488194, 52.455581596919465, 65.40510954175676, 46.7037273134504, 38.884182929992676, 67.36513383047921, 53.2846371786935, 52.74140269415719, 54.27121189662388, 62.42412390027727, 60.13110024588448, 59.92752497536795, 58.202877862112864, 59.58079596928188, 54.62998907906668, 46.538582529340474, 43.61930383954729, 44.068911348070415, 44.085427216121126, 43.10091611317226, 47.429390226091655, 54.612490040915354, 57.694290569850374, 59.19899245670864, 57.487630299159456, 55.70106431416103, 48.55507482801165, 63.21834468841553, 59.317841393607004, 46.341694899967735, 52.03082432065691, 45.92063406535557, 47.08268206460135, 43.0366279057094, 42.16826983860561, 47.32753658294678, 47.62112576620919, 47.539022377559114, 47.817384583609446, 48.69046395165579, 50.26147597176688, 59.430228505815776, 60.79362487792969, 67.3628409249442, 65.58768040793282, 61.965549741472515, 61.97288009098598, 63.74986798422677, 62.90206963675362, 65.48003196716309, 65.20605060032436, 67.05830832890102, 66.70140716007778, 67.0527845110212, 69.25450188773019, 65.21320029667446, 69.00855650220598, 66.70320674351284, 64.25355679648263, 11.779221143041338, 1.5975741147994995, 1.7365059512002128, 13.438742790903364, 2.5271842437131062, 0.1492070686072111, 0.08939502774072544, 5.529993959835597, 50.55359213692801, 23.451287167412893, 31.012054579598562, 58.69196156093052, 31.154781000954763, 12.494048339979988, 13.634005410330635, 27.00049648966108, 48.68648958206177, 51.763214451926096, 64.07815647125244, 10.440872158323016, 0.21399589920682566, 0.08345124418182032, 0.024995971404548203, 0.09477093177182333, 0.06467161367514304, 0.026016905371631895, 0.04169292688103659, 0.006425355128677828, 0.07873239275068045, 0.05150601567168321, 0.07379922603390046, 0.041568157861807516, 0.03421519956152354, 0.021420068107545376, 0.06472503473716122, 0.031516492765929015, 0.059877363432730944, 0.026234458965648497, 0.03739695882956896, 0.04408612667715975, 0.031020561698824167, 0.053508016280829906, 0.07687699302498784, 0.12188695530806269, 0.1511558483221701, 0.22838777623006276, 7.994006701878138, 92.77662072862897, 72.38878563472203, 71.90987409864152, 57.57092877796718, 49.03614377975464, 37.68924910681588, 62.15315110342843, 42.62491587230137, 39.16866997310093, 1.1174224338361194, 0.15861521448407853, 2.2720987200737, 5.422420646463122, 3.4890739662306647, 4.317393038954053, 0.6606248425585883, 4.833654182297843, 65.3775668825422, 71.83522960117885, 93.69059371948242, 80.57062993730817, 82.85670539311, 82.35954788752964, 76.22820731571743, 72.1140330178397, 73.7595887865339, 73.55208778381348, 71.93884113856724, 67.85145909445626, 58.689793722970144, 56.07587793895176, 57.293841566358296, 56.74128607341221, 59.51749093191964, 60.28122302464077, 60.84604903629848, 57.15441901343209, 54.61373724256243, 53.940453324999126, 54.90339721952166, 53.84344605037144, 56.319975103650776, 50.03067071097237, 49.9907602582659, 52.39308949879238, 52.62228972571236, 53.5987548146929, 52.85120160239083, 53.57968200956072, 53.82012094770159, 53.235711438315256, 56.47132076535906, 52.43207584108625, 58.20533405031477, 65.53301892961774, 64.87749113355363, 69.53404181344169, 66.26578290121896, 64.1372161592756, 57.98221697126116, 60.58777059827532, 62.24860545567104, 66.78113079071045, 63.164593424115864, 59.7308840070452, 53.91885832377842, 53.527824129377095, 55.624807834625244, 59.82352433885847, 60.149839537484304, 58.259853090558735, 54.782905033656526, 66.78475775037492, 49.436405181884766, 43.223854064941406, 69.57741941724504, 57.038033212934224, 54.495062010628835, 57.853098596845356, 65.06631537846157, 61.302531787327354, 62.58668395451137, 60.76306670052664, 63.09755720411028, 57.84731422151838, 49.8021514075143, 45.67860051563808, 47.85682255881173, 47.72621726989746, 46.253431933266775, 49.249714033944265, 58.54283932277134, 60.74723175593785, 60.45175266265869, 61.35255881718227, 58.124526500701904, 51.99064983640398, 63.065539905003135, 60.84650761740548, 48.243604455675396, 53.30259479795183, 48.134621960776194, 48.35761397225516, 45.5577574457441, 44.64764070510864, 50.427635192871094, 48.18899161475045, 48.65051875795637, 50.5439966746739, 50.5255492074149, 52.58804900305611, 62.57621301923479, 64.0897113255092, 68.356780733381, 65.4515860421317, 63.42370564596993, 64.25956698826381, 66.32720497676304, 66.25073310307094, 66.65591730390275, 68.4407844543457, 68.20558793204171, 69.78569861820766, 68.31847531454903, 71.6285901750837, 68.12015983036586, 71.22341987064907, 66.56824493408203, 65.71652780260358, 17.154522146497452, 0.5713841883199555, 1.2407691351005008, 6.103657645838601, 6.856985245432172, 1.7461129214082445, 0.1950551098478692, 3.8780006851468767, 55.24734694617135, 33.03500870295933, 32.83501522881644, 31.422206742422922, 18.473992007119314, 15.02339151927403, 25.967966386250087, 35.83791201455252, 57.41482360022408, 55.34233924320766, 74.98666845049176, 18.731401920318604, 0.32205446011253763, 0.10894526368273155, 0.020140666581158127, 0.05261976305129273, 0.005335169453506491, 0.04118239713300552, 0.02520049542986921, 0.07191764164183821, 0.02218520624696144, 0.09007037364478622, 0.030420183736298765, 0.009421278922153371, 0.022036802156695297, 0.1401489246636629, 0.13812003710440227, 0.1541120625500168, 0.24947754027588026, 0.07329129507499081, 0.1866627037525177, 0.13499630615115166, 0.1703330935644252, 0.27961573164377895, 0.20336748952312128, 0.33456819291625706, 0.2672271206974983, 0.31235827612025396, 8.618962424142019, 104.95360279083252, 85.25222192491803, 81.41364792415074, 63.102810042245046, 47.06492246900286, 51.4050487109593, 99.94702965872628, 51.94707768304007, 46.347632135663716, 2.0741139267172133, 0.1719147451221943, 2.2782077065535953, 12.478377546582903, 12.715026242392403, 27.217858723231725, 1.028436311653682, 4.553502380847931, 71.79660456521171, 78.53459930419922, 96.44956357138497, 86.17153808048793, 87.33072689601353, 86.53378241402763, 80.26536083221436, 74.34628772735596, 78.3766667502267, 76.87913540431431, 77.68302113669259, 70.77058492388043, 62.03317655835833, 59.497167451041086, 59.5181371143886, 59.17752947126116, 63.734422138759065, 62.660911560058594, 66.28234045846122, 59.7541743687221, 59.01139109475272, 56.88852187565395, 57.40699298041207, 58.20127282823835, 58.94306945800781, 53.39184788295201, 51.058941568647114, 55.14072683879307, 56.25437021255493, 55.70702586855207, 55.69519656045096, 54.138428347451345, 53.71222237178257, 53.685305050441194, 57.36055816922869, 56.6106390953064, 60.88325663975307, 68.21572535378593, 67.75230135236467, 71.15225642068046, 71.94498334612165, 67.65169838496617, 57.60441909517561, 63.155734470912385, 64.59074592590332, 69.76730673653739, 66.49035562787736, 61.12353229522705, 56.6459915297372, 57.316291196005686, 58.532069614955354, 63.26352187565395, 64.51619175502232, 62.24449907030378, 58.5766909463065, 68.54163755689348, 57.327925954546245, 49.563675335475374, 72.0616158076695, 59.72446387154715, 57.42906740733555, 60.90376077379499, 67.95521654401506, 63.75894233158657, 63.71158340999058, 64.04658385685512, 66.02426351819719, 61.03166321345738, 52.630492074149, 48.65289504187447, 49.88319519587925, 50.02937487193516, 47.86339208057949, 51.80854449953352, 61.05093056815011, 63.499427114214214, 62.18188190460205, 63.924114908490864, 60.729763984680176, 53.399734088352744, 66.79420730045864, 63.2737009865897, 51.15588978358677, 56.41289683750698, 49.61410188674927, 51.77830246516636, 48.39783361979893, 48.96560566765921, 53.21271637507847, 51.69897835595267, 50.43330144882202, 52.486282212393625, 52.7050392968314, 55.583021368299214, 63.699382373264854, 67.65847982679094, 69.13629913330078, 71.29299218314034, 67.26442664010185, 68.81860664912632, 67.67537089756557, 69.33448954990932, 69.31424944741386, 71.57902867453438, 72.39273915972028, 73.16735907963344, 71.25014959062848, 75.79493154798234, 70.26291479383195, 74.03639807019914, 68.80193097250802, 66.87543174198696, 15.744725704193115, 3.5654613758836473, 5.880742064544132, 25.587821756090435, 5.792570727212088, 1.5229317886488778, 0.3526820109358856, 7.874796458653041, 63.47981234959194, 36.5454158101763, 45.86560433251517, 76.32917158944267, 43.66285514831543, 19.556107929774694, 24.736929723194667, 40.8300815309797, 68.0933814729963, 63.93236242021833, 90.2611504963466, 21.02916772024972, 0.4248608207064015, 0.21000516334814684, 0.17603352053889207, 0.09061411768198013, 0.14382965144302162, 0.10461439178990466, 0.1759503185749054, 0.19836306305868284, 0.14725303703120776, 0.21989520479525837, 0.19379283115267754, 0.12481083055692059, 0.09249952222619738], [0.020912028583032743, 0.03659904235973954, 0.012338747952266462, 0.11267313507518598, 0.02989296881215913, 0.09630227674330984, 0.0573291251701968, 0.07624653899776083, 0.06594575316246067, 0.0718378187822444, 0.05978197497980935, 0.15297642563070568, 0.3259000437600272, 34.649464334760395, 90.8112463269915, 62.92993886130196, 62.31814997536795, 25.778025218418666, 51.692064898354666, 58.38933277130127, 50.23709126881191, 32.487855434417725, 16.716462544032506, 0.17851569663201058, 0.08068870420434646, 1.7490973898342677, 3.0464732817241122, 1.2399902854646956, 4.6276357514517645, 0.2829470671713352, 48.9912862096514, 71.81237697601318, 67.76951898847307, 83.15089212145124, 82.25567926679338, 80.82742840903146, 73.76931626456124, 75.61782891409737, 74.03356320517403, 73.33503995622907, 75.77194690704346, 74.60146726880754, 69.00621495928083, 64.68258721487862, 59.50630433218819, 56.99687903267996, 58.08330978666033, 57.21946804864066, 61.2861270904541, 59.30690492902483, 56.778101103646414, 54.067796434674946, 50.24229894365583, 51.29240798950195, 52.43692568370274, 49.03474371773856, 48.29695619855608, 47.573554924556184, 51.882039070129395, 50.85706513268607, 49.8356625693185, 50.148060526166645, 54.11339398792812, 49.25897250856672, 56.31684841428484, 51.231892653873985, 49.785475730895996, 62.26160553523472, 69.73636640821184, 67.60674354008266, 60.44422081538609, 62.10281835283552, 62.39070306505476, 62.73149830954415, 62.169666971479145, 61.64277812412807, 64.48655768803188, 62.71619142804827, 63.204913820539204, 54.21800259181431, 49.0560052054269, 48.87327800478254, 57.8360720361982, 56.13898842675345, 59.60745620727539, 55.65620674405779, 67.57191916874477, 40.82409913199288, 39.83607224055699, 65.17078154427665, 52.47699594497681, 54.957332611083984, 58.984883717128206, 59.319738251822336, 47.970578466142925, 57.886453424181255, 56.26624468394688, 55.96491868155343, 45.971446241651265, 44.390498297555105, 43.14600992202759, 44.05221830095564, 42.3203763280596, 45.85621036802019, 50.9906234060015, 57.11525201797485, 58.439741952078684, 57.645337036677766, 56.368466581617085, 53.54094927651541, 50.64224420275007, 50.17673226765224, 62.34475462777274, 51.502330439431326, 48.03433166231428, 50.5225510597229, 45.458710874829976, 46.40879017966134, 38.38860613959176, 47.831840310777935, 48.322334493909565, 45.8529759815761, 47.74748223168509, 47.50566407612392, 52.06187929425921, 60.93028204781668, 65.25700868879045, 63.71323708125523, 57.83830935614449, 64.62922504970005, 65.36697087969098, 64.40512480054582, 64.97188935961042, 64.61503682817731, 66.55819089072091, 67.64185973576137, 65.42955330439976, 69.27166393824986, 64.93781539372036, 67.97283717564174, 67.31471770150321, 64.50317777906145, 68.1601814542498, 42.38890988486153, 1.051021648304803, 0.34077790113432066, 6.804771270070757, 7.420944469315665, 0.6169186106749943, 0.3215069909180914, 0.5258289213691438, 33.11353724343436, 56.8803334236145, 25.701905965805054, 52.3698581968035, 73.60060705457414, 74.7915005002703, 21.15099743434361, 21.589262008666992, 33.723418848855154, 51.46065167018345, 58.398323740277974, 41.8276378767831, 1.2116802845682417, 0.07758705956595284, 0.08157866394945554, 0.08524105671261038, 0.05059974055205073, 0.04682726566014545, 0.039681104477494955, 0.044355623823191435, 0.028298248669930866, 0.03688030869566968, 0.09004794806241989, 0.023032498013760363, 0.02044328471778759, 0.06010665398623262, 0.06944460541542087, 0.0818730192258954, 0.20642152135925634, 0.045442351938358376, 0.05940605300877776, 0.05255396890320948, 0.05304438348061272, 0.043029220176062415, 0.08122432617736713, 0.08507828294698681, 0.26318867025630815, 0.3142771188701902, 43.60269069671631, 97.73948969159807, 68.91487394060407, 67.50498717171806, 36.07066624505179, 58.848316873822895, 52.495832511356895, 52.81926768166678, 38.888271944863455, 21.510035174233572, 0.19959111644753388, 0.33401507831045557, 2.6520629142011916, 2.687146757330213, 1.9308878864560808, 2.088916846684047, 0.300611423594611, 59.19521263667515, 83.22150666373116, 76.47461823054722, 80.08905029296875, 85.06692041669572, 82.98926312582833, 77.47681944710868, 77.17376681736538, 76.70116424560547, 75.9041085924421, 78.8516595023019, 77.48914555140904, 74.22133827209473, 67.1805201939174, 62.818600927080425, 60.39967591421944, 60.095414297921316, 60.82118143354143, 65.93950244358608, 62.20132991245815, 62.09609249659947, 56.88972043991089, 53.78215251650129, 54.23611307144165, 55.04958036967686, 51.996319566454204, 52.547843251909526, 49.18288973399571, 53.43370035716465, 52.681634289877756, 52.87491233008248, 53.0406859261649, 55.573057651519775, 49.720148767743794, 55.885750906808035, 51.29337726320539, 53.30051728657314, 67.27581473759243, 69.56929697309221, 70.0500636781965, 63.104609625680105, 64.41560963221959, 64.65365491594586, 64.74522522517613, 63.62368174961635, 65.182190486363, 64.93445941380092, 64.49634075164795, 64.58044869559151, 57.128794057028635, 52.273924418858115, 51.1442654473441, 56.78254100254604, 60.56118679046631, 59.79294531685965, 59.712068285260884, 65.32471193586076, 54.97534234183175, 55.44397054399763, 63.38628959655762, 57.50376401628767, 54.48489679609026, 60.40243434906006, 61.774383953639436, 49.63986580712454, 62.16789518083845, 58.811046736580984, 58.39863640921456, 49.779198033469065, 46.863754749298096, 45.573634079524446, 47.22223663330078, 46.885182993752615, 48.08040516717093, 53.461159637996126, 61.63005597250802, 62.3108891078404, 57.20879561560494, 61.33270781380789, 56.23316431045532, 53.15426812853132, 51.49861315318516, 64.5458744594029, 53.89542899812971, 49.76137590408325, 52.90919821602957, 48.36829335348946, 48.075822830200195, 42.86291946683611, 49.441275869097026, 49.91529934746878, 48.722793919699534, 51.415008953639436, 49.8936904498509, 55.86197764532906, 65.24801077161516, 68.09170695713588, 67.60844584873745, 61.146072251456125, 67.13095869336809, 68.32592378343854, 68.2502509525844, 68.22858646937779, 68.52546215057373, 68.68267209189278, 69.56614943913051, 69.18000330243791, 69.850921358381, 68.65569918496269, 68.14768164498466, 68.74773502349854, 67.94079208374023, 68.32978003365653, 48.24964591435024, 2.675138098852975, 0.5095214992761612, 2.3228724641459326, 4.729853740760258, 3.081384939806802, 0.5801469523991857, 0.08199767967952148, 34.446854863848, 67.44207123347691, 32.747162205832346, 44.97553314481463, 64.0634262902396, 57.802484444209504, 27.52191710472107, 35.11262777873448, 41.89407307761056, 57.61379221507481, 67.96047633034843, 55.02877746309553, 1.5891504010983875, 0.06579572228448731, 0.10608599175299917, 0.04104604891368321, 0.05611520566578422, 0.027596370350303392, 0.09549411439469882, 0.08488097853426423, 0.06780878640711308, 0.027246146196765558, 0.03366160998120904, 0.0690731889169131, 0.02660593144329531, 0.10542867452438388, 0.205774063244462, 0.1167575426931892, 0.21491481204118046, 0.09633446644459452, 0.16223514452576637, 0.11617013492754527, 0.1904014724173716, 0.18838432351393358, 0.23400319633739336, 0.23666506207415036, 0.32468967299376217, 0.34984755303178516, 48.68101440157209, 111.53960568564278, 78.69609628404889, 84.16928264072963, 37.994994163513184, 61.53640120370047, 66.78007466452462, 61.40980502537319, 51.35253422600882, 28.77371151106698, 0.5973693653941154, 0.3263817493404661, 6.705122377191271, 9.481062769889832, 7.538723383631025, 9.728886774608068, 0.35841584897467066, 57.847546986171174, 84.14121886662075, 76.03634670802525, 83.9806876863752, 88.1478350503104, 88.64655590057373, 80.27456024714878, 82.40281432015556, 80.19573988233293, 79.54296357291085, 82.1111706324986, 81.36923503875732, 76.31870065416608, 70.53832748958042, 66.84647165025983, 64.30075590951103, 65.3375938960484, 65.58629771641323, 70.43570259639195, 66.46605777740479, 64.38621875217983, 61.02306134360177, 55.977668625967844, 56.14235830307007, 57.48453140258789, 55.262771947043284, 56.01285777773176, 53.19988652638027, 58.148949418749126, 55.9850024495806, 55.20564733232771, 55.94843408039638, 56.78214495522635, 51.825324399130686, 56.86358479091099, 55.231987953186035, 55.988386222294395, 68.40631444113595, 72.65856334141323, 72.96492331368583, 63.10775715964181, 64.46705409458706, 67.9083023071289, 67.04609339577812, 66.79817472185407, 68.92291300637382, 67.65237930842808, 68.62728800092424, 68.4926666532244, 59.928247588021414, 52.33989756447928, 54.367350646427695, 60.22687421526228, 62.7914890561785, 63.774297850472585, 62.56620761326381, 69.17006043025425, 54.061046259743826, 52.87071214403425, 67.96309580121721, 58.09651483808245, 57.97297586713518, 63.28221252986363, 64.32426166534424, 51.12277814320156, 64.26903738294328, 62.56600611550467, 61.217590059552876, 50.734954016549246, 48.98279551097325, 48.488504137311665, 49.42594119480678, 47.99771465573992, 51.29980782100132, 56.76997518539429, 64.1549688066755, 64.17319393157959, 59.4194518498012, 64.3121509552002, 58.41588878631592, 55.368068422589985, 54.81118420192173, 66.76888111659459, 55.03799424852644, 53.05132361820766, 55.73881040300642, 50.695078304835725, 51.486113343920024, 46.145616735730854, 51.71296507971627, 53.188682556152344, 51.70424509048462, 53.51050574438912, 52.812833649771555, 58.222582953316824, 68.6324713570731, 70.9042057309832, 68.74627590179443, 62.25568567003523, 69.94462476457868, 69.97739941733224, 70.2409723826817, 71.93984167916435, 70.49055862426758, 72.59905202048165, 72.83597864423479, 72.81624576023647, 73.73379012516567, 71.39208044324602, 71.68026392800468, 71.58859634399414, 69.47502381461007, 69.80145713261196, 48.902925968170166, 2.519572926419122, 2.8559588875089372, 12.81341186591557, 13.145123209272112, 2.230470108134406, 0.6977656238845417, 0.6384573749133519, 43.61122308458601, 73.6331454685756, 40.761110237666536, 73.54775210789272, 93.71591295514787, 91.61774458203996, 33.31825201851981, 35.065814290727886, 51.64696414130074, 68.04986490522111, 78.29886777060372, 63.08950424194336, 1.6443978079727717, 0.14254076060439858, 0.201449881706919, 0.23706295500908578, 0.11566873826086521, 0.09213685204407998, 0.1936559434980154, 0.1844717413187027, 0.1945747206253665, 0.10495000878082854, 0.17874183878302574, 0.18172082464609826, 0.10377340870244162], [0.0612642482987472, 0.10363976444516863, 0.028420983780441538, 0.014516042146299566, 0.09266657754778862, 0.11970424386007444, 0.11880551065717425, 0.055576645636132786, 0.0630187498671668, 0.021013479746345962, 0.058882726090294976, 0.024775678225393807, 1.124372803739139, 68.20433725629533, 76.86970669882638, 67.14999675750732, 55.614267417362754, 36.956839493342805, 24.147303853716167, 48.65774835859026, 45.533681937626426, 35.95111206599644, 12.450296401977539, 0.17776447694216455, 0.1450139528938702, 4.424634141581399, 4.112871076379504, 0.8420354138527597, 0.5500209203788212, 31.777398654392787, 101.51535620008195, 82.98943683079311, 96.17253194536481, 74.06890174320766, 81.87691906520298, 77.90339715140206, 80.38451548985073, 75.10965851375035, 80.55134173801967, 71.24787752968925, 74.79500239236015, 71.74782126290458, 74.47006293705532, 66.82008239201137, 68.9077867780413, 62.469016211373464, 62.98605946132115, 62.67791380201067, 64.37467084612165, 62.56570734296526, 60.84617410387312, 54.504716532570974, 53.59494720186506, 49.311240332467214, 54.047059535980225, 48.69079051698957, 48.84970276696341, 45.67676271711077, 51.41869149889265, 50.75634057181222, 48.17330258233206, 50.432874134608674, 54.479789870125906, 49.437134742736816, 54.29479060854231, 48.27721636635916, 57.06271668842861, 59.97598171234131, 69.53590393066406, 59.066802978515625, 64.11161204746791, 62.954604966299875, 62.554604121616904, 60.46663570404053, 63.877902439662385, 58.00780371257237, 61.79786191667829, 61.31205081939697, 64.66176346370152, 56.49466323852539, 54.36825738634382, 49.634077957698274, 57.619284766060964, 53.373032161167686, 60.67068345206124, 49.30867297308785, 68.25123759678432, 33.51659182139805, 36.70864289147513, 63.18072019304548, 53.354820932660786, 58.6709988457816, 57.60939053126744, 52.98894269125802, 44.766837051936555, 56.64412593841553, 54.61879205703735, 52.751752035958425, 41.54081971304757, 42.906286648341585, 42.68495525632586, 44.617714813777376, 44.61845827102661, 52.745029653821675, 56.43534994125366, 58.26262889589582, 54.62065417425973, 54.10295779364449, 56.65023340497698, 53.73736442838396, 52.83947651726859, 50.3785913331168, 49.542531967163086, 58.603656905038015, 51.076725482940674, 50.75452709197998, 46.825310366494314, 45.20341321400234, 41.38496814455305, 44.24717780521938, 47.90466090611049, 45.758053166525706, 46.607036181858604, 46.46437576838902, 54.65029171534947, 61.06538282121931, 63.38724149976458, 59.6044476372855, 61.982239314488, 64.16981015886579, 63.55636065346854, 63.40879481179373, 63.03223024095808, 63.111092294965474, 65.32098075321743, 64.46952765328544, 63.51906967163086, 63.81869683946882, 67.29434558323452, 65.33887236458915, 66.61133071354458, 66.92206805092948, 65.65993472508022, 62.74841717311314, 14.770037617002215, 0.17368251883557864, 0.602445838706834, 12.20472274507795, 1.6976457621370042, 0.06012650792087827, 0.06098895985633135, 9.746992043086461, 67.3658355985369, 35.95776496614729, 35.95319652557373, 92.21191283634731, 116.11929539271763, 74.70569719587053, 13.330240590231758, 25.52231240272522, 45.09557369777134, 58.36786978585379, 58.40916987827846, 9.635225926126752, 0.625367131616388, 0.21658517526728766, 0.12543776977275098, 0.11306955558913094, 0.03120240569114685, 0.06419568921306304, 0.06265573363218989, 0.0088574078399688, 0.07935927089835916, 0.10074656576450382, 0.08891984966716596, 0.10902388553534235, 0.0307654630658882, 0.023194957956937805, 0.05500495952687093, 0.057387818449309895, 0.10379502682813577, 0.05874932610562869, 0.039420448642756255, 0.033895914908498526, 0.04706245268295918, 0.024857475621891872, 0.1009302180526512, 0.028197608355964934, 1.4025174443210875, 82.00352913992745, 83.92063440595354, 75.4398855481829, 63.767933300563264, 45.46995306015015, 34.167554650987896, 49.21461868286133, 47.53821291242327, 40.27136645998274, 8.693839686257498, 0.3552048312766211, 0.5464100284235818, 6.654349284512656, 2.707681941134589, 0.5273298408303941, 0.4435392070029463, 40.647805963243755, 101.79604952675956, 83.30779634203229, 95.40355396270752, 75.93471540723527, 83.00591795785087, 80.96928977966309, 81.7663801738194, 79.3290354864938, 80.17211600712368, 74.03316020965576, 77.38778523036412, 75.08941841125488, 79.85702214922223, 70.63609559195382, 72.52260099138532, 67.0974405833653, 65.59724807739258, 65.16709899902344, 67.98346097128731, 66.64503642490932, 63.66636453356062, 57.400128160204204, 54.35130030768258, 52.6297937801906, 57.23927388872419, 52.21127251216343, 50.66746268953596, 47.93204723085676, 53.27465609141758, 52.630370480673655, 51.49160589490618, 51.67612573078701, 54.87174122674124, 50.12869242259434, 56.19307320458548, 50.43776914051601, 60.79377773829869, 66.17937510354179, 69.84358406066895, 60.32621261051723, 67.37323543003627, 67.00197928292411, 63.00140803200858, 63.058070591517854, 64.91221823011125, 62.54239613669259, 64.49723706926618, 63.04662690843855, 67.2025876726423, 61.11208166394915, 54.51641729899815, 51.34247670854841, 57.3547043119158, 58.45667471204485, 60.686636516026084, 55.79223162787301, 65.54475443703788, 57.01493392671858, 57.319101742335725, 61.983489990234375, 58.71396650586809, 60.312656675066265, 60.87902518681118, 53.93441881452288, 50.44641269956316, 58.571104594639365, 58.61742128644671, 53.5289705821446, 44.66490350450788, 44.239916937691824, 45.46369620731899, 44.76922723225185, 48.27807446888515, 53.873490061078755, 59.79433495657784, 60.08242116655622, 55.40185751233782, 56.34852525166103, 57.92436626979283, 57.84870038713728, 55.7001610483442, 54.262947014399934, 51.09310586111886, 59.90186527797154, 55.300907135009766, 52.843798296792166, 51.20438126155308, 47.50824185780117, 45.28101764406477, 45.85665505273001, 50.70549018042428, 48.03832687650408, 50.30046231406075, 49.293293135506765, 58.42076642172677, 64.32554013388497, 68.44888605390275, 63.416687965393066, 65.94116306304932, 66.78563322339738, 66.7521151133946, 65.61750207628522, 65.57568086896623, 65.40283053261894, 66.26901381356376, 65.46125098637172, 66.1399371283395, 66.6794855935233, 69.89915575299943, 67.37294360569545, 68.30753884996686, 69.05498436519078, 66.6105316707066, 64.18866062164307, 19.008919920240128, 0.18159411501671585, 0.8434675027217183, 3.735022391591753, 4.21525582245418, 1.6709856327090944, 0.16553931151117596, 8.493438005447388, 74.50431755610875, 43.61205686841692, 43.99041754858834, 91.6102683203561, 111.62649985722133, 68.03811550140381, 23.09387878009251, 36.59894125802176, 51.694302218300955, 63.7532309123448, 70.63761724744523, 12.751364452498299, 0.4402116441300937, 0.20197483710944653, 0.1299465535474675, 0.05237918846043093, 0.05720351476754461, 0.08659992486770664, 0.05611980613321066, 0.03378425179315465, 0.08797524071165494, 0.103617291365351, 0.1248061622359923, 0.037374441644975116, 0.1637930337871824, 0.18875856271811894, 0.18088011975799287, 0.0644571151850479, 0.2350331853543009, 0.2054509041564805, 0.18663119258625166, 0.11220666260591575, 0.1739832048437425, 0.15273939977799142, 0.18318344759089605, 0.11112725588360003, 1.8135779755456107, 92.65534687042236, 93.49464062282017, 88.2202422278268, 72.4444546018328, 53.319847175053184, 36.787890570504324, 68.44853169577462, 60.631655420575825, 54.6964624949864, 15.248822348458425, 0.4727843105792999, 0.4778009099619729, 13.079665098871503, 9.505635074206761, 5.551826068333217, 1.2530623440231596, 39.25733246122088, 106.96962261199951, 87.35735239301408, 100.37070301600865, 79.6595960344587, 85.83395985194615, 81.97629914964948, 85.50822135380336, 81.55637781960624, 83.87204565320695, 76.98661708831787, 79.89361136300224, 77.52110031672886, 81.2893238067627, 75.3547284262521, 75.83407769884381, 70.76076017107282, 68.31816264561245, 68.08157648359025, 70.54651246752057, 70.06392533438546, 67.23550128936768, 60.60127789633614, 59.35870374952044, 55.64754581451416, 59.38862269265311, 54.23387575149536, 54.756797177451, 51.470834255218506, 56.32560314450945, 55.23202269417899, 54.340238775525776, 54.39610229219709, 58.65644236973354, 51.355445521218435, 59.26138728005545, 54.74081284659249, 63.41253294263567, 66.0928213936942, 74.5104250226702, 62.27051312582833, 68.76354912349156, 70.89766747610909, 67.85010419573102, 67.5012629372733, 69.26389585222516, 65.06824002947126, 68.64898027692522, 66.78550120762416, 68.8522915158953, 62.78743130820138, 59.45178181784493, 54.47073289326259, 61.37564073290144, 58.70560782296317, 64.75256252288818, 57.39597313744681, 72.0919030053275, 43.218604700905935, 42.403952734810964, 67.1609332220895, 61.213164057050435, 64.27006571633476, 65.5465748650687, 55.33025285175869, 49.4404490334647, 61.1238797051566, 60.935576575142996, 57.56110749925886, 46.08244718824114, 46.971358026777, 47.71020862034389, 48.608846936907085, 50.27381249836513, 57.71259559903826, 64.7040571485247, 64.29582963671002, 58.341744559151785, 58.300507000514436, 61.826057706560405, 59.6513340813773, 59.81516565595354, 56.53334386008126, 55.49013784953526, 61.975652422223774, 58.100343295506065, 57.44821316855294, 53.63389185496739, 51.67462839399065, 48.60988221849714, 50.349342891148154, 53.78816270828247, 50.175558022090364, 51.565135206495015, 51.55404935564314, 62.48439952305385, 66.23256356375558, 69.4391780580793, 64.53956549508231, 67.96623638698033, 71.48905645098004, 69.96512195042202, 67.66141196659633, 68.13575853620256, 69.01350361960274, 69.10398306165422, 68.34150164467948, 67.67773328508649, 71.10798249925885, 72.81915010724748, 69.80225617544991, 70.66207490648542, 69.09021173204694, 67.62343311309814, 64.32357379368374, 19.545001234327042, 0.984831480043275, 8.119010005678449, 22.56598765509469, 5.521902348314013, 2.0189037578446523, 0.44666353506701334, 15.228531871523176, 82.28834274836949, 48.54589625767299, 50.18274245943342, 94.23526995522636, 123.2666849408831, 88.14140101841518, 23.91030079977853, 40.81443418775286, 61.55548095703125, 76.44747856685093, 81.89307362692696, 16.41401788166591, 0.6326687655278614, 0.3494930591966425, 0.1826621155653681, 0.1592618447861501, 0.19249887844281538, 0.154681068445955, 0.13775964001459734, 0.07878386641719512, 0.16729066467710904, 0.1774755431605237, 0.21751057489642076, 0.23902696104986326], [0.09727386425116233, 0.06742941747818675, 0.02837451091701431, 0.14613425492175988, 0.09018094092607498, 0.09403489769569465, 0.02312033946093704, 0.030923022289893458, 0.026278319469253932, 0.031221625195550065, 0.11120142654648849, 0.4525798718844141, 9.073497942515782, 92.71637289864677, 64.55258641924176, 65.49970926557268, 48.35619306564331, 33.675424167088096, 28.578864915030344, 34.964360169001985, 39.418947560446604, 41.60084172657558, 1.84062340429851, 0.25803145127637045, 1.4065789920943124, 2.3931476303509305, 1.443446459514754, 1.87491688983781, 14.849599702017647, 95.10693536485944, 81.83612619127545, 78.16585145677838, 75.99608884538922, 84.32795170375279, 75.14975656781877, 78.38121782030377, 81.7641498020717, 78.82005214691162, 80.60091713496617, 71.63526044573102, 71.22148132324219, 72.0545425415039, 70.83736406053815, 71.69959381648472, 67.9194472176688, 68.04243728092739, 69.08588300432477, 67.63597461155483, 68.63686956678117, 63.178580147879465, 62.311583927699495, 56.51099497931344, 52.404137134552, 48.80870492117745, 51.06847102301461, 47.93481608799526, 47.25681781768799, 46.07253558295113, 48.5566520690918, 49.68876722880772, 49.638649872371126, 53.145155566079275, 51.73368808201381, 51.836306027003694, 48.74356555938721, 50.21725763593401, 61.09667750767299, 61.08815206800188, 59.821967942374094, 62.680498531886506, 63.15956292833601, 59.202925137111116, 58.260349886757986, 54.50481728145054, 58.174459729875835, 59.34275068555559, 62.92606176648821, 60.548707825796946, 63.29919392721993, 57.66766159875052, 60.94420623779297, 53.71485226494925, 59.20483589172363, 53.1362966128758, 63.685270581926616, 50.186834948403494, 63.368397985185894, 23.509238617760793, 22.665392058236257, 58.706087248665945, 50.56905882699149, 62.840821266174316, 56.78759581702096, 55.3022655078343, 50.001366683415, 61.03816672733852, 53.185114656175884, 49.41665492738996, 42.39733804975237, 44.084218229566304, 41.71418421609061, 48.314083508082796, 46.67599010467529, 56.85608073643276, 58.628628730773926, 55.4803443636213, 52.02748223713466, 54.497591154915945, 53.89300407682146, 55.38484484808785, 54.93857594898769, 53.6408817427499, 49.5545905658177, 55.487084116254536, 51.21189226422991, 48.138294083731516, 47.616748401096885, 43.67950650623867, 41.26584127971104, 40.89158698490688, 45.71813923971993, 45.90557384490967, 46.10521990912301, 46.699957915714805, 52.55019521713257, 60.93483311789376, 58.704252924237935, 60.23858192988804, 60.143537521362305, 60.78699629647391, 63.375853402274, 62.290558678763254, 61.35501153128487, 61.65505559103829, 61.591646330697195, 61.72537136077881, 60.729145595005576, 63.13197857992989, 64.6357285635812, 67.2215632029942, 65.68214116777692, 64.18042700631278, 64.00337995801652, 63.15161418914795, 44.64374623979841, 4.851938366889954, 0.17984561169786112, 3.277180616344724, 6.229653239250183, 0.3418823390134743, 0.3641572323228632, 0.5615632895912442, 47.63244438171387, 62.960100991385325, 38.20571913037981, 96.84680598122733, 87.86218070983887, 81.5810856137957, 24.657120977129253, 24.52159810066223, 49.61720773151943, 50.39613206045968, 62.573718615940635, 25.837123121534074, 0.48099431289093836, 0.06143539518650089, 0.05433188671512263, 0.008760039761130298, 0.06699229164847306, 0.044511775087032995, 0.013143297950071948, 0.05819435231387615, 0.0689261910904731, 0.045378881772714, 0.04093818559444376, 0.029070984705218246, 0.04429427068680525, 0.06929807577814374, 0.05900174791791609, 0.06285240022199494, 0.11780441366136074, 0.11217160270150218, 0.03223624200161014, 0.021094707173428366, 0.0714858490973711, 0.10504538366304976, 0.1552768764751298, 0.7239363395742008, 12.853370087487356, 106.12008721487862, 71.84080900464738, 74.3848432813372, 59.44846057891846, 42.51350498199463, 32.13312210355486, 40.98569686072213, 46.150556904929026, 46.64361497334072, 1.2640053225415093, 0.14750618487596512, 3.2802256643772125, 2.278850632054465, 1.9311317248003823, 1.1633764079638889, 21.911684479032242, 100.78344685690743, 82.17498983655656, 85.31900106157575, 79.36647932870048, 86.22763088771275, 76.68368952614921, 80.99721458980015, 83.1256354195731, 82.47540215083531, 81.51578644343785, 75.41926329476493, 73.25442695617676, 71.97990499223981, 73.34078611646379, 75.16936438424247, 71.4728671482631, 72.40004866463798, 71.67945098876953, 70.43386827196393, 71.12857001168388, 66.925048828125, 64.10150936671666, 59.30814170837402, 55.492639201028005, 51.623232569013325, 52.11410195486886, 50.58915649141584, 49.991607938494, 49.17010852268764, 51.854624952588765, 53.34431178229195, 51.06346832002912, 56.13992295946394, 52.235962935856406, 50.962646484375, 51.59119095121111, 52.309134415217805, 63.478436606270925, 65.00735991341728, 62.39746366228376, 64.13606275830949, 66.08731147221157, 62.69069848741804, 60.82748344966343, 56.850657667432515, 63.31450080871582, 61.91531426565987, 65.43727275303432, 61.674774578639436, 64.76613235473633, 59.0971805027553, 61.46953868865967, 56.02258178165981, 60.96148640768868, 56.224975858415874, 67.28323541368756, 53.596885749271934, 67.14859322139195, 38.12813554491316, 35.587526730128694, 59.434626715523855, 52.9579050881522, 65.26160144805908, 57.60510696683611, 56.133290903908865, 55.45027256011963, 61.48178836277553, 56.48438685280936, 51.36712891714913, 43.95587805339268, 46.46803399494716, 45.74100228718349, 49.98266560690743, 51.10872541155134, 59.2522087097168, 62.12453147343227, 57.075946058545796, 54.11874062674386, 57.55652168818882, 54.70965712411063, 58.49837779998779, 59.216807637895855, 56.79730939865112, 52.01028197152274, 57.92923695700509, 54.04161562238421, 49.628727844783235, 51.055734974997385, 46.39792667116438, 44.65628773825509, 44.11014543260847, 47.999107769557405, 48.612244606018066, 48.47575766699654, 49.825942039489746, 56.40747724260603, 63.299471855163574, 63.940707206726074, 63.31465366908482, 62.89232131413051, 63.95427703857422, 65.27925682067871, 64.80861364092145, 62.212120464869905, 63.91128158569336, 63.59277616228376, 63.49230521065848, 61.873736245291575, 66.32673249925885, 67.02897303444999, 68.64612456730434, 66.53032166617257, 63.96213545118059, 64.40648664746965, 62.74859087807791, 50.37362684522356, 7.388818604605539, 0.2363942451775074, 1.6356622938598906, 2.5082000281129564, 2.1559252738952637, 0.7169587739876339, 0.2354176432958671, 48.14974124091012, 71.13917296273368, 44.33494050162179, 92.79647173200334, 93.17394651685441, 72.42857101985386, 27.63569038254874, 34.255956581660676, 56.38679245540074, 56.12881278991699, 69.78095994676862, 35.15771811349051, 0.5280579360468047, 0.09262667968869209, 0.07654653290020567, 0.04631912096270493, 0.02931054149355207, 0.014077172481587954, 0.032779860509825606, 0.029683393093624284, 0.12074226673160281, 0.06815553137234279, 0.01235721428279898, 0.09772313585770981, 0.24135097063013486, 0.15408485329576901, 0.15956323647073337, 0.2449265516230038, 0.1929312545273985, 0.30853158288768356, 0.23599390951650484, 0.1491933214877333, 0.173778735101223, 0.24724011176398822, 0.3176084815391472, 1.0090880755867278, 15.504976374762398, 123.17551067897251, 81.39563124520438, 84.92643478938511, 65.82701805659703, 46.22623668398176, 41.02508619853428, 50.03796979359218, 58.453110286167686, 57.89320707321167, 2.380940079689026, 0.2729964596884591, 4.190660502229418, 5.664969231401171, 8.551942706108093, 3.950142962591989, 21.529231309890747, 104.80507114955357, 87.92823028564453, 88.27093628474644, 82.51953016008649, 90.14023099626813, 77.69955784933907, 84.17088767460415, 86.63314165387834, 85.89983572278703, 89.18570831843785, 77.16412966591972, 75.24436323983329, 74.68010003226144, 73.88534423283168, 78.0521719796317, 74.34584304264614, 74.64074543544224, 76.17074571337018, 75.47461264474052, 74.99415860857282, 71.73259775979179, 68.11388560703823, 61.992939540318076, 57.649968011038645, 53.92745671953474, 57.131212030138286, 54.367086614881245, 54.832890374319895, 51.8101669039045, 53.58943380628313, 54.65210172108242, 54.47687857491629, 58.63842569078718, 54.91404185976301, 52.669061524527415, 56.85948187964303, 55.28040647506714, 66.55136775970459, 66.29947471618652, 65.73031302860805, 68.46703474862235, 70.25308309282575, 66.25100408281598, 62.060135568891255, 58.93095874786377, 64.72722244262695, 63.33456025804792, 68.8045573915754, 65.75743879590715, 67.53166825430733, 59.400017738342285, 65.5613328388759, 59.39388942718506, 65.666257585798, 58.50224099840437, 72.70540809631348, 54.271215370723176, 74.04709134783063, 26.70556456702096, 25.065510034561157, 70.53249795096261, 54.22971378053938, 70.39274883270264, 61.3992646081107, 57.090915952410015, 54.373920168195454, 66.3803378513881, 59.81419290815081, 56.448266642434255, 47.53580188751221, 49.74093777792794, 47.03590679168701, 54.94996404647827, 52.25204106739589, 61.976611273629324, 64.39236095973423, 59.73610210418701, 57.21749128614153, 60.994351387023926, 58.962586947849815, 61.806199754987446, 62.383463042122976, 60.919053758893696, 52.68614019666399, 61.853412764413015, 57.73932531901768, 52.55565997532436, 53.604417596544536, 50.211782455444336, 46.591500009809224, 48.03448452268328, 50.21008014678955, 50.50051137379238, 50.5132474218096, 53.18229716164725, 58.534800257001606, 66.93928568703788, 65.49206624712262, 67.24357509613037, 65.14472579956055, 65.8934428351266, 69.0860983984811, 67.38281004769462, 65.94935498918805, 66.79774393354143, 68.05428395952497, 66.29252651759556, 65.43033845084054, 70.10617733001709, 68.38934694017682, 72.78882122039795, 70.17437389918736, 68.50848075321743, 67.23518862043107, 66.12908404214042, 50.818474837711875, 7.809055209159851, 1.6028965434857776, 12.782976150512695, 12.210186634744916, 3.1023163880620683, 1.95327085682324, 1.2880750766822269, 60.516377857753206, 76.14679527282715, 55.35239676066807, 102.4044268471854, 92.73346546718052, 89.09067780630929, 39.0545597076416, 36.786844866616384, 67.32543182373047, 65.61833586011613, 80.79770401545933, 40.42387247085571, 0.5436660870909691, 0.2044347029711519, 0.2711081781557628, 0.18927745201757976, 0.18506174108811788, 0.12378403065460068, 0.16905233157532557, 0.0883541414514184, 0.2191260310688189, 0.15714792321835244, 0.06897516096276896, 0.12292659309293542], [0.1348065199064357, 0.07725254858710937, 0.03451057603316648, 0.09459737608475344, 0.117846849241427, 0.038331277801522186, 0.06920267375452177, 0.02326868417938905, 0.037603945937007666, 0.16396057765398706, 0.3193201539771897, 0.8272828683257103, 34.695391927446636, 75.47409847804478, 64.21611295427594, 48.4583454813276, 24.061010701315745, 35.91053458622524, 69.68868092128209, 42.327463490622385, 38.32354320798601, 26.253513029643468, 0.70871473635946, 0.6302913959537233, 2.3464980764048438, 2.106497743300029, 1.2988101520708628, 0.9420158118009567, 66.47144957951137, 88.21762275695801, 77.63639872414726, 80.00342764173234, 77.93439306531633, 82.10612624032157, 80.00182260785783, 78.983473777771, 73.79900591714042, 75.55435711996896, 76.07870292663574, 75.10432229723249, 74.29266847882951, 75.68590041569301, 69.28235026768276, 73.81088733673096, 70.31503323146275, 69.55795751299176, 67.14076954977853, 71.61859866550991, 66.5438984462193, 66.77519008091518, 66.79065677097866, 57.94296312332153, 52.55062600544521, 51.37482404708862, 49.467626912253245, 45.365111691611155, 47.242459365299766, 47.168610436575754, 48.64100667408535, 48.29257883344378, 48.74515322276524, 51.805487292153494, 55.147341523851665, 50.22831221989223, 47.489356654030935, 54.04543365750994, 63.91615922110421, 59.411190441676546, 60.544976643153596, 61.05165318080357, 57.67283453260149, 55.07931865964617, 53.15267699105399, 51.753813539232524, 55.013234342847554, 55.02803747994559, 58.56951345716204, 59.52161121368408, 59.79412651062012, 60.76124627249581, 61.7748703275408, 54.13132381439209, 56.473613670894075, 54.75716543197632, 59.45178876604353, 53.24739136014666, 47.02804837908064, 14.18364873954228, 12.23566915307726, 46.859742164611816, 48.75087506430489, 62.938714436122346, 53.11799505778721, 57.264193602970664, 53.94803033556257, 57.20671463012695, 46.878081934792654, 43.66000638689314, 42.49128464290074, 44.18294518334525, 43.989034857068745, 50.54519523893084, 51.31048025403704, 57.45649889537266, 57.314953667776926, 53.28595733642578, 54.98504202706473, 55.305565902165, 55.470728056771414, 54.794105529785156, 57.17187983649117, 58.86686161586216, 55.65002979551043, 54.51793895448957, 54.09892783846174, 47.10265118735177, 46.42145674569266, 45.2235803604126, 42.97347225461687, 41.11608675548008, 43.50464119229998, 47.46784503119332, 43.93977212905884, 46.87525054386684, 50.63619579587664, 60.64244597298758, 57.070807865687776, 59.63174016135079, 58.81047698429653, 59.90138585226876, 58.72989872523716, 59.25234767368862, 58.33992413112095, 60.34439604622977, 58.36848817552839, 60.64866461072649, 58.80524499075753, 63.99324253627232, 64.36954307556152, 63.760422297886436, 61.88645839691162, 62.60505499158587, 65.52015086582729, 63.09837014334542, 61.61520072392055, 35.26585987636021, 2.427121933017458, 0.6692914175135749, 7.4795725005013605, 1.457475198166711, 0.07201921833412987, 0.09357192646712065, 11.33481696673802, 73.35743400028774, 38.07124716894967, 50.172882965632844, 91.75919600895473, 52.01754283905029, 25.375967706952775, 20.387683970587595, 32.48144224711827, 53.19024242673601, 50.915607179914204, 53.52175487790789, 2.1566604801586697, 0.0771683898887464, 0.06764744435037885, 0.060833846751068316, 0.1352574878505298, 0.03392750071361661, 0.054295191541314125, 0.08995035437068769, 0.07301853078284434, 0.07402877443070922, 0.034270143934658596, 0.009578753329281296, 0.06115096687738385, 0.07364086953124829, 0.07443776819854975, 0.04010788943352444, 0.11666912958025932, 0.029014265963009427, 0.1332107683909791, 0.06713513005524874, 0.1292365209332534, 0.13851559587887355, 0.35824914649128914, 0.7560978680849075, 42.151962416512625, 87.6398730959211, 71.2419159752982, 59.63784762791225, 36.37068598611014, 44.56480080740792, 38.62006105695452, 41.16343872887747, 54.58489179611206, 30.0728075163705, 0.6169668138027191, 1.0808444023132324, 3.3498474827834537, 1.3140306153467722, 1.5210618547030856, 3.2214158943721225, 75.02086748395647, 88.92060674939836, 82.9201077052525, 79.85040746416364, 81.15422998155866, 81.8204927444458, 83.25788048335484, 81.34299169267926, 75.93635518210274, 79.8235387802124, 78.32627841404506, 76.45439897264752, 75.94538089207241, 76.44736739567348, 68.66177885872978, 75.53005926949638, 73.70587226322719, 71.69897542681012, 70.81182248251778, 73.40735680716378, 69.04127556937081, 70.55562850407192, 67.54068701607841, 61.05330685206822, 55.372716767447336, 53.025024686540874, 52.33628102711269, 48.44515085220337, 48.796496936253135, 48.99353395189558, 52.13961921419416, 51.17054353441511, 50.69619001661028, 52.38410200391497, 56.45083052771432, 53.13444491795131, 50.114726543426514, 57.98001439230782, 66.12608242034912, 62.05776623317173, 63.87549141475132, 65.13929230826241, 60.79034532819475, 58.484564781188965, 57.85026373182024, 54.07962574277605, 58.86935601915632, 55.6781769480024, 62.23854446411133, 60.51455742972237, 61.38577120644705, 61.484018734523225, 63.2946845463344, 56.851814542497905, 58.5851469039917, 56.77555111476353, 62.54283387320382, 55.76983758381435, 51.0741685458592, 19.229646818978445, 17.921189853123256, 51.8572861126491, 51.39245162691389, 65.85265690939767, 56.28724908828735, 58.67618220193045, 55.668800354003906, 56.49705689293997, 49.211005619594026, 48.0559891973223, 42.05624403272356, 46.51183196476528, 47.77295085362026, 51.31403078351702, 54.82207202911377, 62.042487144470215, 58.845245770045686, 56.80969108854021, 59.383432388305664, 58.89257689884731, 59.581442151750835, 57.58490507943289, 59.09270586286272, 62.79839556557791, 58.57120186941964, 58.72229739597866, 55.81972564969744, 49.681534154074534, 48.65900598253523, 48.59202882221767, 43.28948327473232, 43.82860095160348, 46.25668021610805, 48.93335560389927, 45.89773975099836, 48.657338414873394, 52.64803280149187, 62.20594351632254, 59.689285142081125, 64.51281493050712, 59.53664711543492, 62.80820642198835, 61.61285918099539, 62.91397884913853, 60.288629804338726, 62.08197375706264, 61.4350825718471, 63.54675824301583, 59.866936683654785, 66.67711625780377, 65.6933764048985, 67.03770692007882, 62.45210429600307, 63.41651426042829, 65.09343419756208, 66.26319817134312, 63.943931170872276, 47.26140710285732, 5.400299319199153, 0.9088402805583817, 0.6667004993983677, 3.1485573010785237, 1.2561089119740894, 0.17747205549052783, 10.17745726449149, 76.73547445024762, 47.87077106748308, 48.951184681483674, 87.1807986668178, 60.59009824480329, 27.34563783236912, 26.882830483572825, 42.8563951083592, 60.634990555899485, 56.30214255196707, 64.35252693721226, 3.431453206709453, 0.12285517049687249, 0.08509185364735977, 0.05293673389990415, 0.07512589091701166, 0.02927471145189234, 0.017396321520209312, 0.05344910587051085, 0.053595710146640024, 0.020723232999444008, 0.08492324448057584, 0.025535372817622762, 0.2711421049066952, 0.30811802936451776, 0.14195173792541027, 0.2317123535488333, 0.2650359682738781, 0.1679484365241868, 0.18404358572193555, 0.09583720884152822, 0.24140156220112527, 0.38168770021625925, 0.5280445281948362, 1.1100422527108873, 49.567142486572266, 99.0449241910662, 79.06114768981934, 71.11982222965786, 40.216739722660606, 49.50199270248413, 83.31264618464878, 58.45789759499686, 63.81529917035784, 37.07120336805071, 0.7350290843418666, 1.694808834365436, 6.385999432631901, 9.226002216339111, 6.539292761257716, 2.949604319674628, 74.79396711077008, 95.60066740853446, 84.57241712297711, 84.34824739183698, 85.51334912436349, 87.29570797511509, 84.57496711186, 82.39352457863944, 79.99657671792167, 81.9470750263759, 83.19323444366455, 78.04088810511998, 80.54622091565813, 79.69129371643066, 72.64565358843122, 76.33231912340436, 75.42813614436558, 73.5715079988752, 74.76613957541329, 79.48816313062395, 73.88910320826939, 75.03427750723702, 72.74205984388078, 65.46283517565045, 58.11193983895438, 57.11243452344622, 56.089225428445, 53.1435227394104, 54.244829586574006, 53.30164984294346, 55.22164208548409, 53.66375868661063, 54.645306382860454, 56.631904057094026, 59.99429021562849, 55.15341077532087, 53.64116661889212, 60.41235637664795, 72.37831469944545, 62.47114930834089, 67.89404460362026, 67.8182258605957, 63.13748155321394, 61.48340729304722, 59.912565503801616, 55.554596287863596, 62.56353950500488, 58.44327858516148, 65.34415299551827, 64.16320937020438, 64.72766712733677, 64.01979160308838, 68.1022960117885, 59.56244577680315, 64.4617943082537, 58.33078030177525, 67.59154088156563, 57.22027403967721, 62.47918142591204, 20.109229700905935, 17.7471479007176, 61.09152889251709, 50.42549514770508, 72.43193394797188, 57.92444964817592, 61.60711302076067, 57.59199571609497, 63.02230126517159, 53.45559760502407, 49.58974845068795, 44.960584095546174, 51.04908902304513, 48.6934620993478, 55.18686635153634, 57.20032923562186, 65.90495600019182, 61.73059640611921, 58.920800481523784, 61.713920729500906, 63.48393957955496, 60.86374609810965, 60.28801836286272, 62.58186190468924, 65.39744567871094, 60.60183375222342, 61.54728208269392, 57.28141818727766, 51.67321443557739, 50.3662930216108, 51.291782651628765, 47.73431886945452, 46.92725086212158, 49.912575653621126, 50.53544691630772, 48.91623176847185, 52.8535327230181, 55.14250905173165, 66.47063664027623, 61.616833550589426, 66.16592339106968, 60.80718081338065, 64.33756746564592, 65.35752827780587, 65.76311547415597, 63.512309074401855, 65.9515575681414, 64.23517881120954, 66.4076234272548, 61.77462019239153, 69.80172116415841, 68.65687343052456, 70.44977964673723, 63.84601715632847, 64.34159047263009, 67.40945638929094, 67.6789561680385, 63.33802740914481, 50.06474815096174, 5.074529554162707, 2.4197266612734114, 17.268401384353638, 4.472488990851811, 1.1449175413165773, 0.19440804528338568, 15.39569684437343, 87.14723191942487, 53.20655679702759, 61.24979496002197, 92.50311878749302, 65.38528633117676, 36.88623537336077, 31.711331708090647, 50.013119561331614, 71.32817091260637, 65.44395692007882, 75.14986079079765, 3.8265392865453447, 0.18654260305421694, 0.34221902808972765, 0.12182317301630974, 0.17252457168485436, 0.11222640797495842, 0.11626252425568444, 0.16408393532037735, 0.22088860720396042, 0.24746500541056904, 0.13177207059093884, 0.1217139967318092], [0.08697582648268767, 0.07580186785863978, 0.10613775718957186, 0.022808333792324578, 0.0806414917377489, 0.046358794905245304, 0.04657151563359158, 0.06420602330139705, 0.01536369014398328, 0.0733596303367189, 0.09977507325155394, 0.15283648456845964, 58.13128709793091, 68.10096890585763, 60.97621658870152, 43.73360170636858, 50.50552797317505, 39.79079777853829, 78.72090830121721, 44.40313707079206, 47.17688921519688, 13.01564005443028, 0.5145935213991574, 1.9473696649074554, 2.622968852519989, 0.6501337683626583, 2.8910511987549916, 27.221294607434952, 93.01375579833984, 77.99668366568429, 81.04395512172154, 65.13324042728969, 72.17223807743618, 76.95659392220634, 76.21698597499302, 77.11922345842633, 75.871903691973, 74.07972703661237, 74.28248936789376, 70.7274227142334, 73.06395598820278, 73.09419454847063, 69.65180683135986, 71.76986789703369, 72.37054661342076, 74.03667599814278, 70.69564860207694, 66.2725921358381, 67.86109624590192, 68.64939716884068, 64.26478508540562, 54.9461738041469, 50.8412093435015, 51.71041856493269, 49.25224665233067, 45.784883635384695, 46.63329689843314, 47.392054080963135, 49.74791029521397, 48.71561295645577, 48.4858603477478, 48.389450618198936, 55.11284024374825, 46.21692609786987, 48.45378746305193, 58.3827736718314, 63.31984397343227, 59.76294299534389, 60.11066559382847, 58.99192919049944, 56.13826234000069, 50.96305295399257, 57.36735003335135, 54.17676503317696, 55.09818301882063, 55.79136657714844, 57.828279631478445, 56.80160338538033, 60.91706657409668, 58.18243278775896, 62.6378504889352, 55.18414265768868, 54.68388972963606, 50.656276089804514, 57.32353121893746, 53.14185169764927, 36.06293984821865, 13.93668110030038, 12.622546587671552, 37.58642618996756, 53.24326760428292, 58.887358801705496, 54.61033262525286, 50.313792433057515, 45.469702925000874, 46.890679018838064, 42.005060127803254, 43.32138940266201, 43.29800871440342, 47.10235936301095, 47.114622933524, 50.27519518988473, 53.99001829964774, 56.008042676108225, 55.42220531191145, 54.52894490105765, 55.604091780526296, 56.14313302721296, 59.25671114240374, 56.244621889931814, 55.422597885131836, 57.18904536111014, 60.939057622637065, 60.24390425000872, 54.2399172101702, 49.558342593056814, 46.392177036830354, 46.092775685446604, 43.94314547947475, 43.05458205086844, 40.37809773853847, 47.116637911115376, 44.48005362919399, 46.217992646353586, 48.95251873561314, 55.51321629115513, 56.33384370803833, 59.819814000810894, 58.98997674669538, 58.7012026650565, 60.21174103873116, 58.4985237121582, 58.00656345912388, 61.51103333064488, 60.6528821672712, 63.205177852085654, 61.14416149684361, 66.57875755855015, 61.2108850479126, 61.5612827028547, 64.01015445164272, 65.70303440093994, 66.7724038532802, 69.75627299717495, 68.16950593675885, 55.28351926803589, 41.51342991420201, 2.069139667919704, 0.392183605581522, 2.3586795713220323, 0.07116165185081107, 0.10073741232710225, 1.1867551420416151, 47.618370805467876, 66.86376571655273, 38.12481778008597, 28.4946596963065, 32.28172322681972, 35.94986833844866, 23.13236485208784, 23.40136957168579, 45.609795979091096, 46.62054695401873, 61.38347830091204, 17.11023085457938, 0.49527161249092644, 0.1708240815039192, 0.061457203302000246, 0.08038826925413949, 0.05397453285487635, 0.05095904180780053, 0.04915484772729022, 0.01873145791302834, 0.018236549737464105, 0.026363616410110677, 0.027874741038041453, 0.02333212211462004, 0.02948849069486771, 0.06261660251766443, 0.0924738532464419, 0.04649593361786433, 0.014679251870672618, 0.047447765578648875, 0.06033586311553206, 0.028102649076442634, 0.00968288809859327, 0.042806151788681746, 0.16424406958477838, 69.94224153246198, 77.08223124912807, 68.81987122126988, 52.48526430130005, 62.46936362130301, 41.01767594473702, 58.724916866847444, 47.343225615365164, 54.25100653512137, 12.553715995379857, 0.47427426491464886, 3.8382239852632796, 6.220255366393498, 0.5590893509132522, 2.192488431930542, 35.46424136843, 97.14509909493583, 81.33001940590995, 83.45946856907436, 67.10898848942348, 76.1426819392613, 80.86676910945347, 79.0373431614467, 77.37830788748605, 78.34603214263916, 75.9091807774135, 78.15659645625523, 73.62741320473808, 75.50091852460588, 76.72139045170375, 74.21856594085693, 73.09558418818882, 71.8009124483381, 74.48969159807477, 72.20615223475865, 70.08704199109758, 72.36172934940883, 71.87079048156738, 66.90604550497872, 58.09089721952166, 53.394265856061665, 53.02043540137154, 50.03465550286429, 49.335020542144775, 50.54066153935024, 50.486555916922434, 51.87706068583897, 51.69036258969988, 48.68024662562779, 50.239161831992014, 57.207694326128276, 48.00673689161028, 51.31036908285958, 61.86738559177944, 64.84414672851562, 61.59745502471924, 64.6529323032924, 61.27393300192696, 58.05533633913313, 54.568601744515554, 60.13004411969866, 57.95867647443499, 59.18398434775216, 57.03314862932478, 59.84600176130022, 58.364944594247, 62.311438015529085, 61.45812279837472, 63.902735301426475, 57.13526977811541, 57.19560098648071, 54.364915302821565, 61.232243810381206, 56.02521167482649, 43.503661496298655, 18.956499235970632, 19.550127267837524, 41.99368940080915, 55.255722999572754, 62.58138247898647, 56.12316737856184, 52.498861925942556, 48.18390553338187, 47.571866512298584, 44.72157301221575, 46.51784215654646, 45.02741881779262, 48.29109539304461, 51.44115155083792, 53.959453174046104, 56.84229898452759, 58.05339084352766, 57.86915588378906, 58.19715254647391, 57.162579672677175, 58.93705231802804, 59.835739271981375, 60.38309751238142, 57.4308774130685, 58.83351721082415, 63.10082285744803, 62.43799945286342, 58.006962980542866, 52.0325995853969, 48.687629086630686, 50.17625284194946, 45.937573773520334, 45.04279865537371, 42.75815800258091, 49.61785043988909, 46.45665979385376, 48.87501505443028, 52.004751205444336, 57.98129980904715, 59.31548595428467, 62.80328709738595, 60.90523379189627, 62.419281005859375, 62.175058773585725, 60.98001030513218, 60.48417295728411, 63.929715156555176, 62.18473761422293, 64.38705253601074, 65.12483310699463, 69.20749037606376, 63.28214304787772, 62.79704066685268, 65.84290858677456, 66.98141261509487, 67.05356965746198, 70.43707139151437, 69.34038162231445, 62.98920004708426, 53.480232443128315, 5.3687814218657355, 0.1515686283154147, 0.7265953826052802, 1.8428303258759635, 0.22730876984340803, 0.7629501489656312, 47.79380587169102, 75.71272046225411, 47.38692283630371, 31.515625272478374, 33.224833488464355, 36.78058453968593, 33.062829290117534, 31.966309751783097, 54.790555000305176, 52.44165045874459, 70.42539146968296, 23.442202397755214, 0.37402253438319477, 0.1393662616610527, 0.07280464975961617, 0.06629357699837003, 0.018062805756926537, 0.004720670753158629, 0.07586657974336829, 0.07453290559351444, 0.05431787496698754, 0.02080761731070067, 0.050501176555241854, 0.1402148511260748, 0.13931054036532128, 0.20844454637595586, 0.15258738079241344, 0.19649975161467279, 0.1783006146017994, 0.09775564447045326, 0.13528247150991643, 0.14395435260874884, 0.08239007648080587, 0.15292450413107872, 0.21865400139774593, 77.51764011383057, 86.2069183077131, 78.91843169076103, 59.26441669464111, 64.54745864868164, 51.64400768280029, 104.07587160382951, 62.75640760149275, 64.24209921700614, 17.349627562931605, 0.4876550297651972, 6.121142787592752, 11.16294893196651, 5.261274550642286, 5.216084335531507, 38.63177571977888, 100.91467748369489, 84.77409553527832, 85.58802836281913, 72.16729096003941, 78.12321036202567, 84.69987487792969, 82.09175736563546, 81.67619950430733, 81.5776184626988, 78.71885163443429, 80.37337752750942, 75.68521254403251, 80.80348491668701, 80.15539169311523, 75.9871882029942, 76.37422370910645, 75.46899850027901, 78.1890514918736, 72.9045990535191, 72.63665567125592, 76.51418127332414, 75.06670475006104, 70.97493839263916, 60.24803842817034, 57.326914991651265, 55.45070334843227, 54.728966167994905, 53.503074645996094, 52.920228481292725, 52.71761206218174, 55.80517264774868, 53.8997368812561, 52.265065465654644, 51.69535487038748, 59.506582260131836, 51.60461139678955, 53.660541670663015, 63.482320649283274, 68.2797669001988, 66.25454071589878, 66.01848261696952, 64.19168308803013, 62.16214207240513, 56.6047956602914, 64.24890150342668, 59.05904878888811, 58.72575759887695, 59.86186449868338, 64.76167161124093, 61.24998256138393, 65.82323823656354, 63.25493390219552, 66.81020205361503, 58.475879532950266, 61.98322595868792, 55.84212664195469, 63.769170079912456, 57.4117386000497, 50.39148024150303, 19.93711587360927, 19.70012845311846, 49.995353017534526, 56.099324635096956, 67.29356043679374, 60.161630630493164, 54.96571213858468, 50.537819726126536, 51.697946548461914, 46.271969727107454, 51.134454590933665, 47.14890187127249, 51.72634036200387, 52.501168727874756, 57.283884797777446, 58.87119729178292, 61.31324590955462, 61.70672239576067, 60.77659484318325, 60.793854168483186, 63.945723806108745, 65.80937658037458, 64.00122601645333, 61.58936732155936, 62.15247712816511, 64.50650596618652, 64.92072282518659, 61.2628367287772, 54.177188873291016, 52.233562333243235, 52.27118682861328, 49.54452610015869, 46.95426893234253, 45.16384669712612, 52.6487033026559, 47.852525097983225, 51.55747481754848, 54.0423903465271, 60.697253363473074, 62.707853589739116, 67.14335427965436, 63.9444522857666, 66.04055704389299, 63.76402146475655, 64.09323406219482, 63.08825356619698, 67.54421670096261, 66.62057181767055, 67.38959148951939, 66.48766667502267, 72.18088163648332, 66.40637969970703, 63.98744773864746, 66.31968702588762, 70.01028524126325, 70.27097470419747, 75.99404607500348, 73.64684731619698, 67.01824501582554, 51.375081130436485, 3.731443635054997, 4.724217448915754, 8.124930739402771, 1.1580408428396498, 0.24366092096482003, 1.9103442345346724, 60.71547154017857, 79.84623854500907, 55.08613831656319, 39.92892796652657, 45.201366969517295, 48.55517210279192, 34.4864387512207, 35.73245573043823, 63.46233068193708, 61.66383811405727, 80.86991664341518, 27.561881405966624, 0.6216945743986538, 0.3774502490247999, 0.18912057472126825, 0.10615227105362074, 0.1299957066242184, 0.0813866046124271, 0.27543820866516655, 0.16603742406836577, 0.09897877848041908, 0.10061058056141649, 0.15596397460571357], [0.0047507748074297395, 0.03228162920900753, 0.059563364567501206, 0.03319858446983354, 0.015852654352784157, 0.02962565654888749, 0.04538618620218975, 0.0344510719047061, 0.07572462343211685, 0.06550428470862762, 0.11749439101134028, 1.6003108365195138, 72.91529927934918, 60.14022323063442, 54.240414006369456, 30.449281760624476, 26.438229152134486, 51.264507498059956, 47.02906976427351, 34.69233472006661, 57.656992639814106, 2.2957499538149153, 0.0746335391221302, 1.0940237236874444, 1.887662491628102, 0.8055480346083641, 2.546284841639655, 73.81204073769706, 82.7022191456386, 81.4780090876988, 72.92825072152274, 63.8846560886928, 63.01385225568499, 68.8664311000279, 71.33390317644391, 72.76448168073381, 72.39364242553711, 72.1884343283517, 69.83689294542584, 71.30805587768555, 69.4335708618164, 67.85182734898159, 69.0473552431379, 68.71914318629673, 67.96992588043213, 69.7170295715332, 68.96764550890241, 68.792877469744, 67.32206889561245, 66.54729611533028, 60.07737677437918, 50.76068319593157, 50.51075301851545, 51.9924806867327, 47.109957218170166, 45.45905133656093, 45.7204703603472, 47.733106408800396, 50.368988922664094, 50.69001654216221, 46.276395729609895, 48.7013726234436, 50.88905463899885, 44.10258231844221, 51.9671162877764, 59.65205669403076, 62.71852602277483, 60.47293772016253, 61.48725659506661, 54.98757464545113, 51.10869067055838, 56.63265446254185, 60.46589224679129, 58.892778396606445, 58.69201019832066, 59.19215542929513, 58.35978208269392, 60.73326587677002, 58.64465822492327, 58.438901220049175, 58.01880965914045, 56.72229664666312, 51.571478911808555, 53.06359066282, 54.07848276410784, 51.828537940979004, 38.63179656437465, 22.571355138506206, 21.2192165851593, 40.426120213099885, 53.06408745901925, 56.95425878252302, 48.45785215922764, 45.98427609034947, 41.667499269757954, 42.97823177065168, 40.501153809683665, 41.800859519413535, 41.224700995853965, 45.953627586364746, 49.345748560769216, 51.26715128762381, 53.6581688608442, 55.65460865838187, 52.894408975328716, 52.965110370091026, 52.33302927017212, 56.31664344242641, 53.552844592503135, 57.41467073985508, 54.08897106988089, 57.16839531489781, 54.30292000089373, 60.29772499629429, 60.587860924857004, 54.62134204592024, 46.25605835233416, 45.976855414254324, 43.022731508527485, 42.914134638650076, 40.235006536756245, 43.9722341128758, 46.633543559483115, 46.944909708840505, 48.27768536976406, 54.9464829989842, 57.657531125204905, 57.552571637289866, 59.712401798793245, 61.77088206154959, 55.74551888874599, 61.316476821899414, 60.76577649797712, 62.34449059622628, 61.57598509107317, 67.18175002506801, 61.59590557643345, 60.14356531415667, 61.22594179425921, 67.11164964948381, 62.50478553771973, 66.55168042864118, 62.42244938441685, 68.47020312717983, 62.94344615936279, 72.77816963195801, 61.891579219273154, 53.89316388538906, 1.0807845826659883, 1.5537707167012351, 2.486226784331458, 0.3912647877420698, 0.49771786694015774, 16.593595811298915, 61.2877390725272, 65.47992079598563, 31.081689425877162, 30.947047233581543, 33.58665745598929, 19.621921266828263, 18.663518020084926, 33.36411360331944, 57.877879347120015, 48.99445458820888, 40.67694670813424, 0.5417078893099512, 0.045373317785561085, 0.037671924967850955, 0.036458517757377455, 0.053691366620893986, 0.041083612612315586, 0.05615322398287909, 0.045642163537974866, 0.08195597013192517, 0.029558634252420495, 0.0582047678264124, 0.02836879595581974, 0.010682533029466867, 0.0899637486519558, 0.03017479833215475, 0.07432821193443877, 0.04765039649126785, 0.061564262557242594, 0.07439955989164965, 0.0032171734949640396, 0.07721809257886239, 0.1262244361319712, 2.724887635026659, 85.82135581970215, 66.01680810110909, 64.38643414633614, 37.19547189985003, 42.50693893432617, 52.610210282461985, 51.06892613002232, 41.381987367357524, 62.66747760772705, 1.6328958251646586, 0.024727919538106238, 3.227646040064948, 2.300954588821956, 0.6201347580977848, 6.298523349421365, 83.70487894330705, 83.41266550336564, 85.7781171798706, 73.55854266030448, 66.49988160814557, 64.16498116084507, 73.48452350071499, 74.89770371573312, 76.39208057948521, 73.44941425323486, 74.44868332999093, 71.81687246050153, 73.62764249529157, 70.79969092777797, 71.01885100773403, 70.17816761561802, 71.34470067705426, 71.25328322819301, 71.76535156794957, 71.53808294023786, 72.92720849173409, 69.67203998565674, 69.09697927747453, 63.28294209071568, 52.04024607794625, 52.93695626940046, 54.262450218200684, 49.2603690964835, 47.9276316506522, 50.499427454812185, 51.700083119528635, 51.60092885153634, 50.70275953837803, 48.204948152814595, 50.689537116459434, 51.67868266786848, 47.1091616494315, 53.61417981556484, 62.81909424918038, 64.32405321938651, 63.08594676426479, 63.4623167855399, 55.81826652799334, 53.30244888578142, 59.56318228585379, 63.34838022504534, 62.08528804779053, 61.06193651471819, 60.484735761369976, 62.899540492466514, 63.06329563685826, 61.24688366481236, 61.11438846588135, 60.47475814819336, 60.14344719478062, 54.11300836290632, 56.09619099753243, 59.389657974243164, 55.38462597983224, 45.96863916942051, 28.20612359046936, 25.91467891420637, 47.01609052930559, 55.24788195746285, 57.661911964416504, 51.10891996111189, 48.21692337308611, 44.68165213721139, 45.31782225200108, 43.48426907403128, 44.144212450299946, 43.30275433404105, 48.606102398463655, 51.23884432656424, 54.100859437670024, 56.3668407031468, 56.94310344968523, 57.213860852377756, 56.13408647264753, 57.0378178187779, 59.16951125008719, 56.800241538456504, 59.148694447108674, 56.72425256456648, 57.92152098246983, 55.441368443625315, 62.134661946977886, 61.8883969443185, 56.494958536965505, 48.61892877306257, 49.13340466363089, 45.86960302080427, 46.2483423777989, 42.17277227129255, 47.11293452126639, 47.79636280877249, 47.829147883823936, 50.50521877833775, 57.715902941567556, 58.998397963387625, 60.434938022068565, 63.15128762381417, 64.06768553597587, 58.782190867832725, 64.32824298313686, 61.97720881870815, 64.39972605024064, 64.66519587380546, 69.05913243974958, 63.22850295475551, 61.94009849003383, 62.679407664707725, 70.37744889940534, 64.68413666316441, 67.1489336831229, 64.0399900163923, 70.50366292681012, 64.7928273337228, 74.62105424063546, 63.51079436710903, 64.49001094273159, 2.936396445546831, 1.2030822145087379, 2.2684348481042043, 0.6448503147278513, 0.4594087025948933, 14.824443749019078, 67.23882947649274, 71.31804043906075, 42.10271011080061, 29.43919086456299, 32.23590680531093, 26.492503268378123, 30.74364219393049, 40.705611501421245, 64.9760513305664, 55.893699645996094, 51.547014304569785, 0.5805318717445646, 0.0872774827959282, 0.030581776850989888, 0.07316601715449776, 0.10928399514939104, 0.07996669544705323, 0.01407166532174285, 0.051100214411105425, 0.1014417384618095, 0.04008287184738687, 0.034399767871946096, 0.2314449836100851, 0.11000798522893872, 0.20891212485730648, 0.07935967123402016, 0.1246561517140695, 0.13963131101003715, 0.15934636310807296, 0.15663648423339638, 0.18260651640594006, 0.14456326993448393, 0.3133628879274641, 2.9443045811993733, 94.7243675504412, 74.94121333530971, 73.76208318982805, 44.90411261149815, 39.98427731650216, 66.5389791216169, 62.224203382219585, 50.399147578648154, 74.74346760341099, 2.9385073951312473, 0.18196895133171762, 4.884227514266968, 5.928580411842891, 3.459682434797287, 7.152563350541251, 87.5919930594308, 86.96980966840471, 89.60264192308698, 78.07833194732666, 69.18199743543352, 67.03662994929722, 76.03802817208427, 78.13598809923444, 80.42099353245327, 77.02999469212124, 78.47544234139579, 74.8167085647583, 77.63178512028286, 72.86279174259731, 74.24773447854179, 74.14469269343785, 74.6755975995745, 75.57735565730503, 74.92983913421631, 74.00606223515102, 74.05729130336216, 72.80439213344029, 73.85170105525425, 65.17024653298515, 55.70595237186977, 55.606259618486675, 58.46664537702288, 52.755618708474294, 52.01981837408883, 51.547538893563406, 53.63169622421265, 55.17931365966797, 54.10853719711304, 50.415218761989046, 52.10758454459054, 55.481834752219065, 49.73932926995413, 56.360146113804404, 64.90622193472726, 69.23365034375871, 67.36336203983852, 67.37566729954311, 60.25971835000174, 55.73918907982962, 63.605553899492534, 66.96783583504813, 64.79647513798305, 64.27230998447963, 63.897086415972026, 65.52604293823242, 66.25474221365792, 62.94210515703474, 64.76285280500139, 63.390472412109375, 61.19424411228725, 55.45993750435965, 58.42261464255196, 61.89267703465053, 57.713919230869834, 51.375529289245605, 30.09143911089216, 29.262571130480083, 51.48910801751273, 57.22838258743286, 62.13183403015137, 53.8404027393886, 51.77207340512957, 46.17413214274815, 48.82406044006348, 45.857131004333496, 46.51989187513079, 46.200375488826204, 51.82780490602766, 55.19268546785627, 57.21731063297817, 58.64553369794573, 60.88766179765974, 60.00014754704067, 59.487801279340474, 58.8794378553118, 62.54490443638393, 60.02066557747977, 64.29332828521729, 60.40503992353167, 63.37408855983189, 58.813895498003276, 64.21737057822091, 63.5657685143607, 58.27123771395002, 51.12177760260445, 52.04542943409511, 49.77823223386492, 48.56842231750488, 45.58557455880301, 49.4422173500061, 50.17895221710205, 51.208303519657676, 55.18689761843, 60.52052593231201, 64.33360004425049, 65.15309143066406, 65.03519439697266, 65.39688287462506, 62.82455553327288, 66.8473401750837, 64.99486705235073, 67.12072399684361, 67.67246655055455, 72.6823400769915, 64.15801211765834, 64.24875559125627, 65.26986980438232, 71.94801276070731, 68.99618870871407, 71.55095795222691, 66.52441569737026, 74.7859627859933, 67.7679556437901, 79.1756956917899, 64.66551549094063, 63.703655515398296, 1.7446917976651872, 8.381435649735586, 7.056301270212446, 0.5327006897756031, 0.45907725180898395, 22.405694450650895, 73.61583055768693, 77.40312685285295, 46.17231866291591, 44.412527561187744, 47.78299447468349, 26.92432165145874, 30.86352641241891, 48.18068156923567, 75.10852595738002, 63.76651586805071, 59.4522681917463, 0.7887415364384651, 0.21538232266902924, 0.13342746533453465, 0.23070380623851502, 0.1652879821402686, 0.1658296295042549, 0.21659973662878784, 0.18829282985201903, 0.17305301475737775, 0.06821220940245049, 0.13886358934853757], [0.0187317293270358, 0.02939779431160007, 0.03861865434529526, 0.06407178193330765, 0.012320659905006843, 0.033759237599692175, 0.03539436789495604, 0.052043208453272066, 0.12487780196326119, 0.20464476384222507, 0.4451581101332392, 7.978401047842843, 70.46979740687779, 63.0575772694179, 59.76617390768868, 30.292672838483536, 28.38219267981393, 74.36405427115304, 37.351743834359304, 47.698959486825125, 50.464981760297505, 0.11242466233670712, 1.6183632335492542, 1.896778745310647, 1.0234304602657045, 0.873339056968689, 34.49131291253226, 93.71382154737199, 79.8428339276995, 80.70428548540387, 69.21861444200788, 62.635564531598774, 59.45686789921352, 61.35721411023821, 65.59828335898263, 70.52571650913784, 68.93993609292167, 66.17165565490723, 66.75424126216343, 66.43479783194405, 63.925511496407644, 62.83400508335659, 65.21479143415178, 66.65105356488908, 67.16605404445103, 67.25428227015904, 68.63709190913609, 66.98735332489014, 67.07713794708252, 64.35122067587716, 55.72815186636788, 47.129231521061485, 48.959185532161165, 50.1365647315979, 45.235635484967915, 44.76540224892752, 45.70044217790876, 48.4252963747297, 51.33500392096383, 48.667190960475374, 45.21242502757481, 50.47362184524536, 47.00032159260341, 45.61632033756801, 53.71882316044399, 59.09544345310756, 61.54655252184187, 58.107659748622346, 56.12510940006801, 49.00785766329084, 54.94291509900774, 58.95304012298584, 61.22332232339041, 58.739779063633506, 61.61745888846261, 58.02443075180054, 60.397765159606934, 59.269426345825195, 57.96195602416992, 56.20606286185128, 59.42830385480608, 56.755898135049, 55.25173125948225, 52.61317368916103, 54.35321453639439, 49.98854030881609, 43.04703630719866, 38.892885548727854, 32.58919143676758, 41.41510943004063, 52.82766457966396, 53.700354848589214, 48.57450546537127, 45.154306820460725, 43.20305463245937, 47.81121110916138, 43.93199709483555, 46.046101161411826, 44.26305443899972, 49.504296030317036, 51.684296812329976, 54.63792392185756, 55.78613110951015, 54.88327176230294, 55.09106111526489, 53.818995339529856, 54.728538853781565, 55.46156685692923, 53.58032124383109, 54.34479679380144, 53.35943453652518, 53.48676722390311, 54.16822222300938, 54.2153240612575, 56.43118797029768, 63.741780281066895, 52.403265135628835, 47.96811532974243, 41.85721288408552, 43.72439881733486, 38.69556018284389, 41.43810101917812, 45.180477210453574, 44.34238549641201, 45.161553791591096, 52.59303780964443, 55.77406556265694, 57.87876871653965, 57.04154552732195, 62.00939287458147, 62.47873674120222, 58.437282289777485, 59.492671966552734, 62.45038114275251, 63.6597706930978, 63.26220171792166, 57.6223315511431, 60.272489139011924, 63.82777118682861, 66.33049842289516, 62.82406915937151, 63.34670570918492, 62.250905309404644, 66.3875709261213, 63.12695503234863, 66.32022898537772, 65.91085502079555, 71.5146883555821, 36.58894974844796, 0.2306169266147273, 3.6452699048178534, 0.9746546489851815, 0.013621937400395316, 1.320525226848466, 51.62894746235439, 59.32397665296282, 58.23420034136091, 31.506196566990443, 52.22520365033831, 23.692882980619157, 13.513855423246111, 22.371311289923533, 47.4013785634722, 49.961334637233186, 59.47623947688511, 6.11495932510921, 0.45917344093322754, 0.09732675605586597, 0.11350524970995528, 0.05298142560890742, 0.022699646053037474, 0.03468231663906148, 0.12801089669976914, 0.09606481662818364, 0.03383564742814217, 0.028600189967879226, 0.04741994903555938, 0.07306748029908963, 0.051271707351718626, 0.06172249013824122, 0.025632827409676144, 0.11958536452480725, 0.04403913473444326, 0.054414393180715184, 0.10188307799398899, 0.30156015125768526, 0.5116995966860226, 9.963026302201406, 82.64755071912492, 70.70799555097307, 69.11958176749093, 40.032518659319194, 27.324070623942784, 65.68537902832031, 42.646959032331196, 56.85296099526541, 52.03090075084141, 0.12645068684858934, 1.4072465619870593, 4.78374787739345, 1.2554533928632736, 0.8904676149998392, 44.63924033301217, 93.5126017161778, 83.92553288596017, 82.65074689047677, 72.02738203321184, 66.05367524283272, 64.1978600365775, 62.56063515799386, 67.83452633449009, 70.5670860835484, 71.5206082207816, 69.56722640991211, 70.6483313696725, 66.97414479936872, 66.32967853546143, 65.05018166133335, 68.77989823477608, 67.9136107308524, 69.3034588950021, 69.4534079687936, 72.87503446851457, 69.88364737374442, 69.45098999568394, 67.41841956547329, 56.22796705790928, 49.409032753535676, 51.027650356292725, 53.19358451025826, 49.90962266921997, 46.61311585562569, 48.18630961009434, 50.40654741014753, 52.85665941238403, 50.926411628723145, 46.9871825490679, 51.8855687550136, 50.59474284308297, 46.35345820018223, 56.56484004429409, 61.08965982709612, 62.81829520634243, 60.131822858537944, 58.90112318311419, 51.009428705487935, 58.58554989950997, 60.87605830601284, 65.1179335457938, 60.375788007463726, 64.81663881029401, 61.63726125444685, 61.23762171609061, 61.44993782043457, 58.765897342136924, 58.434648922511506, 63.75124372754778, 59.82020309993199, 57.38651663916451, 54.97039869853428, 57.00748198372977, 52.31422744478498, 48.43287685939244, 44.25370911189488, 38.80819395610264, 46.24322850363595, 53.90539966310774, 56.562331744602744, 49.94429070608956, 48.89807612555367, 47.302582127707346, 50.03287328992571, 47.22367491040911, 48.31545925140381, 48.83152975354876, 52.20565141950335, 53.6311160496303, 57.7718949999128, 55.91348464148385, 57.50137036187308, 56.740660735539024, 57.3871419770377, 56.32111113412039, 56.840023449489046, 56.35969795499529, 56.558913230895996, 55.691642556871685, 56.43472807747977, 57.76572847366333, 56.69836357661656, 57.62590639931815, 64.2371312550136, 55.68877295085362, 50.004500320979524, 45.98260504858834, 45.1082889011928, 41.402567931583945, 43.65809563228062, 49.29884474618094, 46.50596421105521, 47.9599928855896, 54.352766377585276, 58.435051918029785, 61.89169039045061, 61.42281205313546, 64.77330289568219, 64.5188876560756, 60.938036237444194, 63.152468817574636, 62.62371090480259, 65.5793147768293, 64.25143064771379, 60.96022183554513, 63.21481500353132, 66.46817697797502, 67.97476182665143, 66.07312325068882, 65.82560757228306, 65.95781094687325, 69.80554962158203, 66.40688691820417, 66.9746242250715, 68.76008892059326, 72.38565199715751, 46.229050704411094, 0.5054227677839143, 0.9078438654541969, 1.513298002736909, 0.09302760567516088, 1.1676338080848967, 52.562392779758994, 64.71770341055733, 64.32330281393868, 38.27324172428676, 35.92586926051548, 22.986459629876272, 20.31982265199934, 29.531952789851598, 55.21548250743321, 56.095054967062815, 69.185930115836, 8.238592846052986, 0.5469126871653965, 0.09080629236996174, 0.09947329480201006, 0.08504682606352226, 0.06069446887288775, 0.09299547025667769, 0.06820339523255825, 0.08760817362261669, 0.01827391835727862, 0.024663684324228337, 0.18194259703159332, 0.09465818639312472, 0.19738097861409187, 0.22222168424299785, 0.11981020388858658, 0.19910646602511406, 0.1808006361659084, 0.18078040225165232, 0.2459673157760075, 0.46415529932294575, 0.7588277501719338, 12.127325023923602, 94.60765171051025, 77.94915103912354, 79.33839470999581, 43.58699819019863, 40.48166411263602, 80.98051806858608, 55.32419402258736, 65.08608995165143, 59.014913831438335, 0.36571189175759045, 2.6720476703984395, 8.242013096809387, 5.744288129465921, 1.490434195314135, 48.15636287416731, 94.36296394893101, 86.41556576320103, 85.67233085632324, 76.90330818721226, 68.45143604278564, 66.91913591112409, 65.69238976069859, 72.98253004891532, 74.95145498003278, 74.32981354849679, 71.72241170065743, 73.45363875797817, 70.90946551731655, 69.12779453822544, 68.42538724626813, 72.13899789537702, 72.65339388166154, 73.03121607644218, 72.69696603502545, 76.18750476837158, 74.01428195408413, 71.5545779636928, 71.65998908451625, 61.12338638305664, 52.08223751613072, 54.764666012355256, 56.34722246442522, 53.627982412065776, 50.29944787706648, 50.96305295399257, 54.88575226919991, 55.68481247765677, 53.131828921181814, 48.01866694859096, 53.276629379817415, 54.29104552950178, 50.45847824641636, 60.901856967381065, 63.57714966365269, 69.07147938864571, 63.83446230207171, 62.41206182752337, 53.67755086081368, 60.764887128557476, 62.88618605477469, 66.3874944959368, 61.099567958286826, 67.64625794546944, 62.23422268458775, 64.41442843845913, 65.46071597508022, 62.56292806352888, 60.28217492784773, 66.54706682477678, 62.63672488076346, 60.031039237976074, 57.18703038351876, 59.90156650543213, 55.598894527980256, 52.61942706789289, 47.39402042116438, 42.413589886256624, 49.15066051483154, 58.6211177280971, 60.77995082310268, 54.0140312739781, 51.70524910518101, 49.52949367250715, 54.83077464784895, 48.49796410969326, 51.757287638528005, 52.12958601542881, 54.86634595053536, 57.11518253598894, 61.22435065678188, 59.063975061689106, 61.37245150974819, 60.149874278477256, 59.03074182782854, 59.454804284232004, 61.43478379930769, 59.54658998761858, 61.083385603768484, 59.877685546875, 59.941275460379465, 60.77270385197231, 60.56150640760149, 59.98854405539376, 64.42530236925397, 58.8110328401838, 53.25892536980765, 49.113571030753, 47.77625124795096, 44.34186438151768, 47.02283375603812, 50.53973742893764, 48.186674390520366, 49.634130069187705, 57.26518024717058, 60.83778762817383, 63.22235379900251, 65.44047587258476, 68.40532084873745, 65.58112130846295, 62.25096089499337, 64.93022796085903, 66.30938284737724, 68.59960637773786, 68.43316228049142, 63.55419281550816, 63.6176507132394, 70.87871973855155, 71.57850061144147, 69.2154460634504, 67.89175864628383, 70.78575978960309, 72.66992364610944, 69.9552971976144, 71.62794399261475, 74.77754851749965, 77.85837282453264, 44.77774224962507, 0.4841643199324608, 10.764386364391871, 3.0425451610769545, 0.11543444011892591, 2.6668408640793393, 64.91965975080217, 69.14972305297852, 73.1920599256243, 45.43894672393799, 69.1047612598964, 31.663548946380615, 23.124489068984985, 34.39438206808907, 65.32217584337506, 62.84007086072649, 81.27306502205985, 10.037243485450745, 0.7380577389683042, 0.11304892133921385, 0.24823601118155889, 0.2293419593146869, 0.14914815819689206, 0.16121321650488035, 0.13203266875020095, 0.17590906364577158, 0.054918473453394005, 0.14128131818558487], [0.03469944964828236, 0.07824010880930082, 0.021942087149779712, 0.09288799030972378, 0.010589807826493467, 0.07974068221769162, 0.052646175026893616, 0.051294265248413594, 0.08728525202189173, 0.18620957806706429, 0.34613447370273726, 11.029450586863927, 64.54469326564244, 55.21690341404506, 49.7306718145098, 28.438447032655986, 53.86557953698294, 54.268179007938926, 28.858639342444285, 69.8146448135376, 25.965722118105205, 0.27495009771415163, 0.813580966421536, 2.0992077801908766, 0.8043417621936116, 2.6575485169887543, 81.45396137237549, 79.6181708744594, 84.50974437168666, 70.85443578447614, 68.09312438964844, 65.30521529061454, 68.556458064488, 58.51480334145682, 59.12050560542515, 58.20818281173706, 63.54814093453543, 60.46575328281948, 66.30913966042655, 62.892870221819194, 61.25684043339321, 57.47454684121268, 60.264241627284456, 59.18305328914097, 59.67590291159493, 60.39612538473946, 61.97860540662493, 60.914155278887065, 59.043734959193635, 53.594443457467214, 50.409997190747944, 48.1441444669451, 49.40414122172764, 47.270339012145996, 44.202400139399934, 44.169027941567556, 46.23659297398159, 49.28270755495344, 50.19991145815168, 46.227337973458425, 45.51507813589913, 47.11222233091082, 46.55453559330532, 43.856376375470845, 53.92532362256731, 56.714354855673655, 56.90407541819981, 55.68809897559029, 53.3573431287493, 47.25778709139143, 56.06551122665405, 58.995875767299104, 61.354775292532786, 54.768147059849326, 58.5158177784511, 57.701256138937815, 59.5159067426409, 56.690164702279226, 57.048229694366455, 55.658603872571675, 59.19173158918108, 54.06727531978062, 53.19797229766846, 52.89506210599627, 58.12279292515346, 47.75052901676723, 45.28556524004255, 45.11725207737514, 42.28085844857352, 42.08275835854666, 50.90786688668387, 54.750422205243794, 50.881717341286794, 48.93727091380528, 46.905617645808626, 47.91673687526158, 45.93411009652274, 45.726119245801655, 48.70857443128313, 47.785370758601594, 52.1482697214399, 54.56341144016811, 54.29320641926357, 55.95806080954415, 54.63740280696324, 52.20908382960728, 54.51934943880354, 52.87088932309832, 51.58983605248587, 49.55184255327497, 53.707080704825266, 51.142233099256245, 52.62501341956002, 56.18666001728603, 48.26584563936506, 58.62740584782192, 63.041436604091096, 48.64089550290789, 46.55935416902815, 41.970631803785054, 40.94312872205462, 39.784996032714844, 45.247270243508474, 44.49946689605713, 47.60426943642752, 48.08989640644619, 58.07287359237671, 56.62737730571202, 61.042516299656455, 55.872167178562705, 63.41351958683559, 61.134948185511995, 63.486670221601216, 61.648552077157156, 62.51719502040318, 61.49012620108468, 68.03933143615723, 63.8721284866333, 66.98902089255196, 62.738029616219656, 67.69743142809186, 60.11170087541853, 63.79563576834542, 60.106983048575266, 65.51569012233189, 58.80783666883196, 72.00680146898542, 62.894475255693706, 71.18683065686906, 10.368930510112218, 0.670406277690615, 2.640778822558267, 0.19610884759042943, 0.2973594766642366, 21.649039098194667, 64.19891616276333, 61.58508028302874, 41.88972350529262, 45.37177848815918, 57.52769013813564, 25.099653482437134, 15.699209792273384, 31.275895050593785, 44.96014983313424, 57.69333866664341, 20.54839059284755, 0.7474189709339822, 0.07721233860190425, 0.06872338375874928, 0.08539425634912082, 0.03315689867096288, 0.07600594405084848, 0.040670924221298525, 0.15691891764955862, 0.027595099793480973, 0.006861591653432697, 0.06372794788330793, 0.07259746587702207, 0.04323454487270542, 0.0849120147260172, 0.041102879614170106, 0.058869718573987484, 0.044571754190006425, 0.13592650980821677, 0.08730978784816605, 0.256668464413711, 0.40435356540339334, 17.012308154787334, 76.84315068381173, 62.73547962733677, 58.762409346444265, 35.101632254464285, 40.07876239504133, 43.01482793263027, 34.89184182030814, 79.42989553724016, 27.233559914997645, 0.22207773982414178, 1.0370669513940811, 1.9876134140150887, 0.7695184765117509, 5.555925939764295, 88.25884641919816, 82.32104791913713, 87.88078103746686, 72.55682781764439, 72.2066455568586, 68.31431334359306, 71.85469150543213, 60.92749582018171, 61.413779394967214, 61.29612554822649, 66.00509343828473, 63.79797731127058, 66.51096398489815, 63.73260171072823, 64.03723158155168, 60.65548079354422, 61.785084179469514, 61.451167651585166, 64.61646815708706, 62.85871287754604, 63.34997831072126, 63.6556156703404, 63.13641847882952, 54.93159300940377, 53.0905635697501, 48.98650584902082, 52.800733361925396, 50.573001929691856, 46.74136570521763, 46.29460348401751, 50.186313833509175, 52.37636865888323, 51.47065012795584, 47.51842791693551, 47.95838437761579, 48.30775369916643, 46.825268677302766, 44.652434962136404, 55.88707453863961, 58.673236165727886, 58.13980906350272, 56.42660910742623, 55.26012468338013, 48.9745306287493, 57.15929317474365, 63.23199095044817, 61.572566577366416, 57.154870646340505, 59.26702921731131, 61.15667520250593, 62.753753389631, 60.07996845245361, 60.30351284572056, 59.50319848741804, 60.78538431440081, 56.4519978250776, 55.15218789236886, 55.363350595746724, 62.027576310294016, 52.24918188367571, 48.567918573107036, 50.252710819244385, 47.87145546504429, 45.75140026637486, 56.018023763384136, 58.205236775534495, 52.6826765196664, 49.419427258627756, 50.59577465057373, 50.059349400656565, 49.766746861594065, 49.377939564841135, 49.890150342668804, 49.3500633920942, 55.35036093848092, 56.603333064488, 57.442209924970356, 56.42903055463518, 57.30432639803205, 56.72303662981306, 55.30262334006173, 56.38186618259975, 54.775658062526155, 52.36829137802124, 55.617776257651194, 55.17465489251273, 57.14514316831316, 58.3846218926566, 49.85475274494716, 60.60551629747663, 64.77820832388741, 52.22543294089181, 49.29075356892177, 44.54331350326538, 44.551547118595664, 39.994102069309776, 45.60854182924543, 44.75954491751534, 49.7245226587568, 50.789962904793875, 59.35568823133196, 59.11780970437186, 63.706809997558594, 59.28109931945801, 65.15080547332764, 64.48942729404995, 65.2056337084089, 63.61965874263218, 64.98892634255546, 63.313243184770855, 70.38126346043178, 65.7845437186105, 68.43485069274902, 64.49695219312395, 69.46125943320138, 62.41786357334682, 66.01878138950893, 60.89755603245327, 67.06021213531494, 60.376156261989046, 75.2686402457101, 64.91919422149658, 76.50469698224748, 16.113796642848424, 0.27136208595974104, 0.9273960420063564, 0.3765532528715474, 0.3525425041360514, 21.082939829145158, 70.29826028006417, 66.60766901288713, 51.39202431270054, 42.99630750928606, 34.89209542955671, 24.992197854178293, 23.956231866564067, 42.52722767421177, 51.31797736031668, 64.23655455453056, 26.87693841116769, 0.6734233157975333, 0.1489695134971823, 0.08341753456209387, 0.10187874215521983, 0.07871543616056442, 0.1049530418323619, 0.03603868099993893, 0.08194298975701843, 0.04173568815791181, 0.03374613508848207, 0.08875499958438532, 0.18611873579876764, 0.16872295710657323, 0.15433774329721928, 0.17180411677275384, 0.24525094564471925, 0.1300895751586982, 0.17717169517917292, 0.15687190874346665, 0.40736664086580276, 0.6192833323563848, 20.076283080237253, 90.00279562813895, 69.28407342093331, 68.01879950932094, 41.44962460654122, 65.56757926940918, 66.76752621786935, 42.051838874816895, 87.40800476074219, 31.490854944501603, 0.2577412282781941, 1.618966424039432, 7.195394217967987, 3.308945174728121, 5.97859137398856, 90.43577262333461, 84.61390481676374, 90.84943362644741, 76.7132124219622, 73.85567542484829, 70.6500962121146, 75.70409774780273, 64.06724779946464, 65.52843311854771, 65.13294860294887, 70.69866412026542, 66.84348392486572, 72.0355531147548, 68.5085015978132, 67.59991346086774, 64.3763245173863, 66.85501098632812, 66.05257742745536, 68.00785609654018, 66.69834300449916, 68.7426072529384, 67.91704314095634, 65.16262435913086, 57.43334402356829, 54.95502928325108, 51.573358399527415, 55.14443717684065, 54.02705914633614, 50.39489875520979, 48.94883966445923, 52.735819816589355, 54.85476677758353, 52.36839212690081, 50.093805517469136, 49.45191356113979, 48.73777076176235, 50.20798526491438, 47.42934853690011, 60.52064405168806, 63.596027919224326, 62.241191727774485, 60.21109485626221, 58.45962074824742, 51.455586433410645, 59.5517247063773, 65.36385113852364, 65.25493117741176, 61.39424800872803, 61.30716623578753, 64.02026408059257, 65.60286917005266, 60.96941430228097, 63.658388001578196, 60.01744161333357, 64.52732971736363, 57.6085775920323, 57.0334404536656, 57.958047662462505, 63.39689254760742, 57.37689685821533, 53.08766269683838, 53.26947968346732, 53.04389251981463, 49.94436018807547, 61.16498524802071, 61.322368894304546, 55.49038451058524, 53.163147926330566, 52.899338722229004, 52.70718976429531, 51.80333335059029, 51.466168539864675, 53.517568588256836, 52.081368991306846, 57.97438635144915, 57.841606276375906, 60.34946128300258, 59.74245275769915, 61.18256419045584, 59.26468072618757, 58.77787603650774, 57.243956974574495, 57.99944155556815, 55.22906970977783, 59.96020930153983, 57.73329428264073, 62.48011943272182, 60.08264350891113, 52.72242021560669, 63.03802503858294, 66.469740322658, 55.670547825949534, 52.006919043404714, 49.63579763684954, 47.55283192225865, 45.05332865033831, 48.97915118081229, 48.39264331545149, 53.87786047799246, 54.720631803785054, 63.67539024353027, 61.2573823928833, 65.83823939732143, 64.61382089342389, 70.61072771889823, 64.78237724304199, 67.13183416639055, 67.44829681941441, 67.82361766270229, 66.88144193376813, 72.94466931479317, 68.91294928959438, 72.35817187173026, 68.28032275608608, 73.20518507276262, 65.0300874710083, 68.81753662654332, 64.90347044808524, 72.09338991982597, 64.82998629978725, 77.72455051967076, 68.49648816244942, 78.89917823246547, 14.126395583152771, 1.6481355045522963, 7.324943814958845, 0.30322579188006266, 0.37451105245522087, 28.903646298817225, 75.64391245160783, 75.00502559116909, 56.96031413759504, 65.34124864850725, 73.56545611790249, 37.06152105331421, 27.67066761425563, 47.45744705200195, 59.51839419773647, 73.74558121817452, 34.26236629486084, 1.0161707869597842, 0.24200974670904024, 0.15121332023824963, 0.2391162562583174, 0.18024741299450397, 0.20942857143070015, 0.1119267533400229, 0.3520217692213399, 0.09287485387176275, 0.11424070703131811], [0.04509682155081204, 0.05030944291502237, 0.00610857002902776, 0.006675999179216368, 0.04864575647349868, 0.07743621444595711, 0.031178582326642106, 0.03166081716439553, 0.04562299831637314, 0.09279620487775121, 0.2997370905109814, 23.821867602212087, 56.70213644845145, 58.574252128601074, 42.412596293858115, 31.94886977331979, 37.36147826058524, 40.74874939237322, 38.08433757509504, 80.80934224809918, 6.615667360169547, 0.03976048968200173, 0.5009728265660149, 1.7487707159348895, 0.6514723279646465, 30.995368480682373, 98.46781376429966, 75.54821491241455, 83.67930262429374, 64.8100449698312, 67.93486527034214, 65.97252028329032, 73.73086493355888, 65.40939658028739, 58.640134947640554, 52.279875550951274, 57.320310728890554, 53.38237401417324, 58.08942767551967, 53.938275064740864, 56.90089661734444, 53.026285784585134, 55.50028221947806, 50.06758301598685, 53.15778044291905, 50.680844920022146, 52.73337057658604, 50.940922941480366, 47.97919423239571, 46.64795759746006, 50.84971046447754, 47.30235978535244, 49.95079769407, 45.519455501011436, 43.28320557730538, 43.55048540660313, 47.02595002310616, 55.794065952301025, 51.993637561798096, 44.114627020699636, 48.79499612535749, 48.38724109104702, 43.537137917109895, 42.52963522502354, 51.04632364000593, 54.23505694525582, 54.810638768332346, 53.27585812977382, 52.295106002262656, 49.87037924357823, 54.46856505530221, 56.7741163117545, 59.6668633052281, 57.23939895629883, 55.99881894247872, 56.61369282858712, 57.78747980935233, 57.45937544958932, 56.993999004364014, 57.46407243183681, 54.90688521521432, 50.95043502535139, 52.75212376458304, 56.50489446095058, 57.388708795819966, 44.5672778402056, 48.02099806921822, 45.501466614859446, 46.455388273511616, 40.60168729509626, 46.043811729976106, 52.57192570822579, 51.29581955501011, 48.773831912449424, 50.40337208339146, 50.13790225982666, 50.88157490321568, 47.87932429994856, 46.792084080832346, 49.907711914607454, 54.229804107121055, 55.72530657904488, 55.149210589272634, 57.06889016287667, 56.599247523716514, 52.59266260692051, 54.06451341084072, 56.23638480050223, 53.449233055114746, 52.33015966415405, 51.313659054892405, 53.84593003136771, 50.62350838524954, 54.341583251953125, 50.10518666676113, 48.39626332691738, 64.43491867610386, 52.00293772561209, 46.488760471343994, 41.11626740864345, 40.09705005373274, 37.81231907435826, 43.46854877471924, 44.9780136517116, 45.306990010397776, 43.805275848933626, 48.633440085819785, 55.993670327322825, 57.80597243990217, 60.848237718854634, 58.01412657329014, 58.49132537841797, 62.39612265995571, 61.99760178157261, 64.69149480547223, 67.32937840053013, 64.26229068211147, 63.62325096130371, 62.42383902413504, 61.05319568089077, 61.21062101636614, 60.554245540073936, 60.18219035012381, 61.54973479679653, 60.121970312935964, 60.80973775046212, 65.06221594129289, 67.41561249324253, 70.92262540544782, 49.521770749773296, 1.1109980642795563, 0.29940406552382876, 0.841976951275553, 0.17246537628982747, 3.309895558016641, 59.32182271139962, 56.681072984422954, 58.560814312526155, 33.86893149784633, 59.58672278267996, 23.502061128616333, 12.14564047540937, 17.95857810974121, 46.62271131787981, 54.96786955424717, 48.10515117645264, 0.5419306116444724, 0.0455938009545207, 0.03041324232305799, 0.043531085031905344, 0.04972912584032331, 0.007864914668191756, 0.040335083313818486, 0.03788061519818647, 0.02236565754615835, 0.05587969633883663, 0.01917593736600663, 0.06005547208977597, 0.09965972229838371, 0.06501122045197658, 0.0168877697017576, 0.0893551909497806, 0.025783840467088988, 0.0888154027717454, 0.06869021696703774, 0.13110471782939775, 0.30965002572962214, 32.68912042890276, 67.9173002243042, 69.42121001652309, 60.62336621965681, 43.95178209032331, 31.950210775647843, 37.77863073348999, 46.226601464407786, 88.65048858097622, 6.189811834267207, 0.03251234468604837, 0.76072694254773, 0.6911444791725704, 0.6072752709899629, 37.07863794054304, 100.3536729812622, 77.08347497667584, 86.50109808785575, 66.80141258239746, 69.85404109954834, 69.06176580701555, 77.9332674571446, 67.88664477212089, 62.97012029375349, 53.654531478881836, 60.73710823059082, 55.557441575186594, 60.461987359183176, 55.1355573790414, 60.710586956569124, 58.28752776554653, 57.72541502543858, 53.70511436462402, 56.198944432394846, 53.500246729169575, 55.399488176618306, 54.45310531343733, 51.60476425715855, 48.968499592372346, 53.28875051225935, 50.599123682294575, 51.84656504222325, 47.18887138366699, 46.06142888750349, 48.14574950081961, 51.14238943372454, 57.74345254898071, 53.554355825696675, 45.7239305632455, 48.88342932292393, 49.39804417746407, 47.730594635009766, 45.85278490611485, 54.30222865513393, 56.445212909153526, 57.70647076198033, 55.99357305254255, 53.60217332839966, 51.93113851547241, 55.94458130427769, 59.158540044512065, 61.29321425301688, 60.2936464037214, 58.58887808663504, 59.001295362200054, 57.98753234318325, 60.886834962027415, 59.14727701459612, 57.84167923246111, 57.67750372205462, 53.30122252873012, 56.03209039143154, 58.90520177568708, 58.520862170628135, 48.73333433696202, 52.94377245221819, 51.28182240894863, 50.36664390563965, 44.571408544267925, 50.14379433223179, 53.8998133114406, 54.21549776622227, 53.519257000514436, 52.92461626870291, 51.747160639081685, 54.08895717348371, 51.6589150428772, 50.48087229047503, 53.10459198270525, 56.36791072572981, 56.92981849397932, 59.589467321123394, 57.9847217968532, 58.20665420804705, 56.67072016852242, 55.81189850398472, 58.12876837594168, 56.56725106920515, 54.884932381766184, 53.16662549972534, 53.74415281840733, 55.27356597355434, 57.450610297066824, 52.78671884536743, 50.73600319453648, 64.50834723881313, 54.75815207617623, 47.859848499298096, 44.371022496904644, 42.33960894175938, 40.613044125693186, 44.624378136226106, 47.956282547542024, 47.65465777260916, 46.46520260402134, 52.20305626732962, 57.54925387246268, 60.84764017377581, 63.82456806727818, 60.53726414271763, 62.62757410321917, 64.53204754420689, 67.07936831883022, 64.82581738063267, 67.34984084538051, 64.84846155984062, 65.20104094914028, 66.24502168382917, 63.98914309910366, 61.804671151297434, 61.53965296064104, 62.1431804384504, 64.06718526567731, 62.774507658822195, 64.41403239113944, 66.25541618892125, 69.08215182168144, 73.37726415906633, 56.334423882620676, 2.2852277755737305, 1.090125784277916, 1.7432923870427268, 0.21286723762750626, 2.9734299097742354, 61.94329466138567, 64.06944343021938, 65.0585264478411, 43.24262114933559, 46.35112360545567, 20.700429337365286, 23.456411463873728, 28.151896374566213, 53.480986322675435, 62.17642756870815, 56.371346609933035, 0.6773514364446912, 0.08940910055701222, 0.05129590391048363, 0.0752461612490671, 0.04928948264569044, 0.022354495645101582, 0.019050372764468193, 0.025900197348424366, 0.00525200565711462, 0.08782485699547188, 0.14331346271293505, 0.21858727426401206, 0.21930884197354317, 0.1149046535470656, 0.11517461548958506, 0.1979287735053471, 0.1314212679862976, 0.15715188586286136, 0.30107076466083527, 0.18741982669702598, 0.581206769815513, 38.29346098218645, 80.87926197052002, 77.20392199925014, 59.502892766680034, 46.47966180528913, 47.620906897953574, 56.068283557891846, 55.26783718381609, 97.44430242265973, 8.799599954060145, 0.19295017208371842, 2.591323499168668, 7.036208816937037, 1.9111174387591225, 39.036442279815674, 103.37290845598493, 81.16407557896206, 89.71020003727504, 70.7378797531128, 75.92961542946952, 71.83015741620744, 80.77248900277274, 71.32559313092912, 64.11178575243268, 56.75479337147304, 62.037060601370676, 57.300862721034456, 64.7316414969308, 57.56029108592442, 61.51838452475411, 60.55583667755127, 61.044857842581614, 56.01187113353184, 59.32338605608259, 57.98528807503836, 57.42329345430647, 57.77740144729614, 54.19025496074131, 51.99602426801409, 57.37218597957066, 53.273884841373985, 57.48487186431885, 49.96698004858834, 49.03468118395124, 50.88287074225289, 53.43468352726528, 60.03333909170968, 55.2971134185791, 48.37358440671648, 51.65679931640625, 52.157705375126426, 48.48338678904942, 47.70145736421858, 57.227941376822336, 59.351276125226704, 59.03250667027065, 60.18449020385742, 58.29624080657959, 55.6001695224217, 58.90289497375488, 63.26304939814976, 64.64934008462089, 63.870057923453196, 60.60428646632603, 60.00952761513846, 61.87790516444615, 63.099669456481934, 61.90080642700195, 64.19043936048234, 61.24126952035086, 56.47708429609026, 58.09273501804897, 60.5491247177124, 65.58399786267961, 53.30714239392962, 55.49831587927682, 53.91766670772007, 54.3169310433524, 49.662763595581055, 53.50270291737148, 57.452215330941335, 55.72964225496565, 55.47004018511091, 55.68151208332607, 55.03187983376639, 57.1914563860212, 53.82499163491385, 53.05156333105904, 55.251991816929404, 61.17096764700753, 59.32963943481445, 61.55020032610212, 62.98168904440743, 61.013465881347656, 60.190750530787874, 59.43156950814383, 63.45773792266846, 58.96918773651123, 57.87977967943464, 55.55019460405622, 57.107747963496614, 56.63489873068673, 62.86351408277239, 54.110583441598074, 52.977193287440706, 66.64885793413434, 56.189904826028005, 50.98661082131522, 47.1198479788644, 45.9811007635934, 42.97078330176217, 47.384567396981375, 49.15332514899117, 50.49120773587908, 47.7438656943185, 54.92229284558977, 60.75076838902065, 62.13636425563267, 67.73133168901715, 63.95590986524309, 66.67530277797154, 68.28736822945731, 69.35443087986538, 65.42087500435966, 69.45495046888078, 68.43447549002511, 68.28108705793107, 67.75454562050956, 67.02690941946847, 65.96120861598423, 65.0826575415475, 65.10241821834019, 69.54343577793666, 66.29366602216447, 68.18919713156563, 71.986679485866, 73.30452346801758, 76.2893375669207, 57.43246507644653, 2.0216843400682722, 3.3046279549598694, 2.5367032757827213, 0.34720129360045704, 5.333860644272395, 71.85385772160122, 68.33569295065743, 72.4343797138759, 51.19344827107021, 81.36557333809989, 32.271554538181846, 21.087624652045115, 28.988945858819143, 63.463011605399, 69.89578587668282, 67.57509449550084, 0.9250421226024628, 0.20092046154396875, 0.1607669983059168, 0.16685832930462702, 0.18680978300315992, 0.07193608422364507, 0.1466376329106944, 0.1297229491174221, 0.11011837609112263, 0.16383086889982224], [0.06413981185427733, 0.02154977516537266, 0.010726866811247808, 0.0055947235170086575, 0.11493765749037266, 0.020316398669300333, 0.029349217989615033, 0.008814180070268256, 0.06895338677402053, 0.03896338066884449, 0.041819232782082896, 30.2030063356672, 55.26216745376587, 41.7942795753479, 27.46151988846915, 14.699859074183873, 36.68988275527954, 38.31596619742257, 53.011684145246235, 64.40199811117989, 0.8998052882296699, 0.01628785823205752, 0.8055565027253968, 1.8310511750834328, 2.3498197495937347, 73.95336014883858, 80.8431521824428, 77.76554489135742, 71.35873603820801, 64.40051814488002, 66.46386214665004, 68.41269983564104, 70.04615184238979, 72.95873941693986, 66.31385748726981, 54.65032993044172, 51.76326308931623, 52.932776927948, 51.4799850327628, 52.75944021769932, 51.83578838620867, 51.83151176997593, 52.33631576810564, 52.180464199611116, 49.42957162857056, 49.96689319610596, 49.65953268323626, 49.22604846954346, 48.39833041599819, 51.8652035849435, 49.756901264190674, 47.34963880266462, 49.72150019236973, 44.08673347745623, 43.63818209511893, 45.958901269095286, 46.93220492771694, 52.588531902858186, 48.210034234183176, 47.09968778065273, 46.378259795052664, 47.17024673734392, 44.02705887385777, 42.24986948285784, 48.86263336454119, 53.521400519779746, 51.82921539034162, 52.65787492479597, 50.15128101621355, 48.21250431878226, 48.68368598393032, 52.26945672716413, 58.30086135864258, 58.96751322065081, 57.46770633969988, 52.39058814729963, 54.693030084882466, 55.98314380645752, 53.82073238917759, 54.10801608221871, 53.987016677856445, 53.54456581388201, 51.7976462500436, 55.360296862465994, 50.74649844850813, 40.460670130593435, 40.50946385519845, 45.58001947402954, 48.913171086992534, 41.78128644398281, 42.2787184034075, 54.04434626443045, 52.05124855041504, 52.42367894308907, 52.31044067655291, 52.51615251813616, 49.102082184382844, 42.20994860785348, 42.476901871817454, 46.04922785077776, 48.628708362579346, 49.43326807022095, 53.15432024002075, 51.24649429321289, 56.26460490907942, 53.82990401131766, 54.286866188049316, 55.04719366346087, 56.03344529015677, 53.2169235093253, 52.82190452303205, 50.878399576459614, 54.77834701538086, 53.22118970326015, 49.276322160448345, 46.80043928963797, 55.17642668315342, 54.060994148254395, 47.09490394592285, 42.131409645080566, 38.77858073370797, 37.90147488457816, 39.153373513902935, 44.641442911965505, 43.153218678065706, 45.587860516139436, 42.46637882505144, 52.97476141793387, 56.49835620607649, 58.62368161337716, 59.24123750414167, 59.2037867137364, 58.788340023585725, 61.272216796875, 62.28873825073242, 60.4910238810948, 61.732013838631765, 61.71005753108433, 59.86493560246059, 60.87737846374512, 58.54455552782331, 61.47990540095738, 58.11868306568691, 60.06357765197754, 55.9657107761928, 61.17681108202253, 60.867206301007954, 70.90047454833984, 66.0269524710519, 77.42422158377511, 13.89435180595943, 0.49321120019469944, 1.659130485994475, 0.05477901415101119, 0.12308062054216862, 32.82724714279175, 63.09595911843436, 58.607499258858816, 46.99912997654506, 37.677558762686594, 36.48388603755406, 13.728447062628609, 19.53261433328901, 35.153656891414094, 47.808998107910156, 48.260224546704976, 2.70711327450616, 0.3327126439128603, 0.0349054596652942, 0.0623445167605366, 0.06044954487255641, 0.03052704282371061, 0.0415424617406513, 0.020105910321165408, 0.026985704100557735, 0.05820199940353632, 0.03722767452044146, 0.03243026230484247, 0.052395361342600415, 0.0654365736991167, 0.04740800342655607, 0.028286184317299297, 0.057855525852314064, 0.02086917231125491, 0.07565178948321513, 0.08526732958853245, 0.09434240976614611, 39.76490879058838, 64.22471482413155, 52.05299254826137, 36.074762208121165, 20.69871313231332, 41.296972683497835, 41.66989639827183, 63.04070009504046, 66.11717482975551, 0.9719487598964146, 0.07506020194185631, 1.2305666825601032, 0.8638275702084813, 3.5023498024259294, 79.32180935995919, 83.43471213749477, 81.43524987357003, 73.23167160579136, 67.9748729978289, 69.26657785688127, 72.13751098087856, 73.52504539489746, 78.02421242850167, 69.29669829777309, 56.15002564021519, 55.81067214693342, 56.59193801879883, 55.89313684191023, 56.36679901395525, 54.03052977153233, 55.08699989318848, 53.58667884554182, 54.727260385240825, 52.208729471479145, 51.66901772362845, 50.00688355309622, 51.56710502079555, 52.43397964750017, 53.0529078074864, 51.76455545425415, 52.135693481990266, 51.60066481998989, 47.912696497780935, 46.14485590798514, 47.49073934555054, 48.682532582964214, 54.10393748964582, 49.3363858631679, 48.74338838032314, 47.744056769779746, 48.12864998408726, 45.84846660069057, 45.68643113545009, 50.90959351403372, 55.67119748251778, 55.00903763089861, 54.37168632234846, 52.30774824959891, 51.26968738010952, 51.1463360105242, 55.31151008605957, 59.304952485220774, 59.978559494018555, 59.584415980747764, 54.07746137891497, 58.61992263793945, 57.191623142787385, 55.70746013096401, 56.597044944763184, 56.06697729655674, 54.84050907407488, 52.734009810856406, 58.73146206992013, 52.88897895812988, 43.37577295303345, 45.04777703966413, 49.23963567188808, 53.4317444392613, 45.16902657917568, 44.83500235421317, 54.54290383202689, 54.77387932368687, 53.72208186558315, 55.644453866141184, 55.22588396072388, 50.338375159672324, 44.50066546031407, 44.56653438295637, 48.06097452981131, 50.85353544780186, 51.048032896859304, 54.914465699877056, 54.099532331739155, 57.8982584135873, 55.65010969979422, 56.84735727310181, 57.37794951030186, 59.476267269679475, 55.748145307813374, 54.94485017231533, 53.314292090279714, 55.483429363795686, 56.61491223743984, 52.19632346289498, 48.52497175761631, 57.66302367619106, 58.44746140071324, 49.1048128264291, 45.26343175343105, 41.8017315183367, 40.82368571417672, 41.87916224343436, 47.327842303684776, 46.092383112226216, 47.26837614604405, 44.881794997623985, 54.52112817764282, 58.11057799203055, 59.205996240888325, 61.49981198992048, 61.78750215257917, 61.893184253147666, 62.71868583134243, 64.54299095698765, 63.08173615591866, 63.53043692452567, 65.43508407047817, 60.79182529449463, 63.61398206438337, 60.79826627458845, 62.4078859601702, 60.5608810697283, 61.945295742579866, 57.622765813555034, 63.15307331085205, 63.07411398206438, 73.17896951947893, 68.41900879996163, 82.34627682822091, 18.96587930406843, 0.15117270313203335, 0.643362640270165, 0.07779946138284036, 0.10499176582587616, 32.52525063923427, 70.26851504189628, 64.25993524278913, 54.67738274165562, 40.91050345557076, 31.08906146458217, 20.734890665326798, 25.83081415721348, 42.342537607465474, 54.31188317707607, 56.861017431531636, 4.005481890269688, 0.3860318442540509, 0.1007778055167624, 0.06181776324020965, 0.022987324544893842, 0.045787461634193144, 0.034353179657565694, 0.052705383992620876, 0.036588440250073156, 0.05352367347638522, 0.13245188125542232, 0.22576667687722615, 0.14142064856631414, 0.1482727937400341, 0.24862364466701234, 0.10302221615399633, 0.215463964002473, 0.12086424018655505, 0.2155255206993648, 0.10519136368696179, 0.19133441735591206, 49.190623079027446, 76.4977696282523, 58.254353591373985, 39.02566909790039, 24.988101891108922, 53.681671142578125, 56.25458560671125, 68.30617700304303, 75.2289799281529, 2.015452674457005, 0.1913809919995921, 3.398895685161863, 5.795331333364759, 4.303104068551745, 83.13361195155552, 86.00250925336564, 83.44134071895054, 76.6936115537371, 71.46925408499581, 71.32803889683315, 75.37002141135079, 76.81434345245361, 80.13545036315918, 72.7531213760376, 60.51742703574044, 60.00216947283064, 58.24671752112252, 58.14024332591465, 59.461321694510325, 57.28526054109846, 58.79817867279053, 57.6728310585022, 57.89480515888759, 54.287970951625276, 54.37204415457589, 53.99429838997977, 55.11488996233259, 54.6803947857448, 57.506769112178254, 55.92796468734741, 52.0605765070234, 54.15672990253994, 49.29508229664394, 49.368222509111675, 50.48326941898891, 52.82653202329363, 56.26986122131348, 51.3890609060015, 50.840872355869834, 48.33276721409389, 50.00165850775582, 49.16830546515328, 48.726987157549175, 53.33919095993042, 59.30785683223179, 58.57019438062395, 58.434690611703054, 56.65854345049177, 53.70949867793492, 54.178912026541575, 58.39903245653425, 63.38649804251534, 63.00675119672503, 60.843881198338096, 56.50331721987043, 61.13961737496512, 60.5476655960083, 58.880000659397666, 58.72936371394566, 58.95556231907436, 58.059296812329976, 58.689564432416645, 61.053939138139995, 56.555077825273784, 48.2677320752825, 50.33212178094046, 51.623958655766074, 55.78148276465279, 49.84637321744646, 49.422102315085276, 58.619220869881765, 56.212601116725374, 56.30007546288626, 57.5831298146929, 59.03158255985805, 53.47454186848232, 47.55354411261422, 46.92484678540911, 50.96239634922573, 53.75197301592146, 55.15099280221121, 59.46596309116909, 55.01287303652082, 62.02800015040806, 57.85994604655674, 60.41441304343087, 60.33369582039969, 62.39949948447091, 59.19620622907366, 58.04768984658377, 57.326675278799875, 59.12600857870919, 58.64126055581229, 55.29997955049787, 49.68317740304129, 60.24482141222273, 58.457980973379954, 51.91220814841134, 46.62226663316999, 45.632641656058176, 43.197329316820415, 44.56785454068865, 47.88701595578875, 49.40548917225429, 49.23560919080462, 47.55015339170183, 57.381065777369905, 61.49596963609968, 63.21715654645647, 66.07004519871303, 63.98500197274344, 65.12921047210693, 64.4093770980835, 68.07105691092355, 65.46845626831055, 65.66723033360073, 68.67168698992047, 64.0859523500715, 66.85562242780412, 65.5086863381522, 65.6296614238194, 64.4133723122733, 64.91926370348249, 60.138771057128906, 66.94370474134172, 67.24941158294678, 76.85178034646171, 70.65584932054792, 83.49209730965751, 19.516246114458355, 0.6773408512984003, 4.956498333386012, 0.18525173089333943, 0.18017675035766192, 41.50200360161917, 75.5347215107509, 71.96394498007638, 61.26936803545271, 52.41161339623587, 47.993476254599436, 23.083984545298986, 30.90443045752389, 50.44637795857021, 61.839787346976145, 69.98124871935163, 5.860578392233167, 0.8890508338809013, 0.18746995686420373, 0.23430924277220452, 0.22453881347818033, 0.17464336513408593, 0.1955201913203512, 0.12918316093938692, 0.09579640174550669, 0.12323097033160073], [0.01677766891329416, 0.05641305200489504, 0.032571753819606135, 0.029310093660439764, 0.019107975298538804, 0.0447475252939122, 0.040541127257581265, 0.015578180152390684, 0.06184691310461078, 0.06428853994501488, 0.7467010808842522, 19.63590451649257, 58.8652218409947, 46.16086803163801, 54.872984954289024, 30.94970839364188, 34.91702904020037, 31.141819136483328, 72.8867004939488, 41.44077260153634, 0.022713788419163654, 0.18702212375189575, 0.38846341520547867, 0.8347993535654885, 20.580103908266338, 88.7846235547747, 73.86229705810547, 80.54058592660087, 62.216664586748394, 66.24988542284284, 69.88261904035295, 74.68084348951066, 65.47388281141008, 73.67264597756522, 67.34247575487409, 61.352114132472444, 51.03694357190813, 54.60649721963065, 50.42519984926496, 54.00518274307251, 52.0585788999285, 52.8955727985927, 50.63449348722185, 52.064227785382954, 48.02804354258946, 51.00504091807774, 49.5109315599714, 51.34389761516026, 48.72849491664341, 50.280864919934956, 47.904841559273855, 48.33270468030657, 46.656833921160015, 44.74150391987392, 44.89037602288382, 43.57191365105765, 47.18961484091622, 51.12821510859898, 46.629367692129954, 45.76511253629412, 45.657335553850444, 48.81368677956717, 43.05374479293823, 41.281408718654085, 46.751788003104075, 49.079771518707275, 48.54734148297991, 50.91524587358747, 47.98876537595476, 49.377800600869314, 46.07987982886178, 52.229719979422434, 51.510115895952495, 59.42250210898263, 50.39521837234497, 45.1202780178615, 57.558213574545725, 54.49229662758963, 53.32149737221854, 52.033502851213726, 53.49420179639544, 52.21847432000296, 52.49979298455374, 56.1291949408395, 52.02889966964722, 38.29921061652047, 40.03455448150635, 46.642815930502756, 47.09563003267561, 44.313175269535606, 40.96162830080305, 47.430161476135254, 49.05184670857021, 52.62386696679251, 53.909040519169395, 52.36865963254656, 45.95967251913888, 43.41480098451887, 43.31642491476876, 46.635926791599815, 49.41220113209316, 47.3839351109096, 45.660465717315674, 47.21686914988926, 52.03592777252197, 51.54003136498587, 52.037095069885254, 55.0482428414481, 54.31840058735439, 52.77555309023176, 51.62452145985195, 51.114808559417725, 50.6945606640407, 55.38133948189871, 49.48780100686209, 47.069876534598215, 51.238267626081196, 54.09458868844168, 49.17473602294922, 45.06730147770473, 38.7718687738691, 40.63368722370693, 36.18829924719674, 43.85082129069737, 45.108292375292095, 43.76001875741141, 44.956606251852854, 44.77000195639474, 51.17824213845389, 56.68734720775059, 57.91298859460013, 58.85526507241385, 59.87995065961565, 62.11440099988665, 61.62667219979422, 64.82222516196114, 59.723602294921875, 61.19450119563511, 57.88143335069929, 57.41478191103254, 58.27234247752598, 58.50684070587158, 57.10151195526123, 59.62498651232038, 53.352830273764475, 56.13244322368077, 61.65345055716378, 67.19517394474575, 71.01047148023332, 77.9484145300729, 39.60130303246634, 0.3621945562107222, 0.7887734004429409, 0.2773033385830266, 0.16373902239969798, 7.773321492331369, 64.09591606685093, 56.80959381375994, 55.14438853945051, 42.59572649002075, 42.90929521833147, 25.53699220929827, 37.58187164579119, 44.45139578410557, 44.821991852351594, 52.084061418260845, 11.782501561301094, 0.3988718166947365, 0.06464346125721931, 0.044451405826423845, 0.06732604266809565, 0.017031999105321508, 0.058980129792221954, 0.06780692722116198, 0.06456829993320362, 0.01989584945009223, 0.027295351859980395, 0.04376456553914717, 0.05042503474812422, 0.06010541905249868, 0.04459467510293637, 0.04807534601007189, 0.05895450830991779, 0.012582449741395456, 0.042246292544794936, 0.05744724454624312, 0.9173157257693154, 29.746728556496755, 71.04587950025285, 52.0462076323373, 53.06468152999878, 27.27701394898551, 35.148966857365195, 39.45560278211321, 82.6393518447876, 42.817801339285715, 0.05717359137322221, 0.666388427572591, 0.36998497960822924, 0.7240999479378972, 22.982916048594884, 99.08386884416852, 76.15816947392055, 84.32177475520542, 65.04973002842495, 70.40718024117606, 71.52347782679966, 77.09314686911446, 69.6602280480521, 75.99567195347377, 70.20190266200474, 64.32968820844377, 54.43930966513497, 56.6347667149135, 54.24930770056588, 57.09362574986049, 55.370451654706685, 54.86366741997855, 53.14966147286551, 54.53080701828003, 50.69893108095442, 53.83076558794294, 53.155977385384695, 55.33318151746477, 50.3350886617388, 54.261251653943745, 50.1228072983878, 50.56969458716256, 48.465373584202354, 47.426166261945454, 46.05147211892264, 47.70401777539934, 49.14330237252371, 53.21281017575945, 47.98108761651175, 46.20374189104353, 47.71018430164882, 49.25050612858364, 45.889228207724436, 45.841959612710134, 46.51176248277937, 51.14422375815255, 51.508521284375874, 53.64899376460484, 51.839686325618196, 51.399048941476, 47.75181443350655, 55.27344785417829, 54.646088055201936, 61.7320624760219, 53.92085593087332, 47.6457154410226, 57.225735323769705, 57.409202507564, 54.7684006690979, 53.56335374287197, 56.25855997630528, 54.257975578308105, 53.9888961655753, 58.88777569362095, 53.4054594039917, 43.28975078037807, 46.311967032296316, 47.988011496407644, 49.168694564274375, 45.61614315850394, 44.576699597494944, 50.42519290106637, 51.14663130896432, 55.2670624596732, 55.89818818228585, 54.237839698791504, 50.36693572998047, 46.63428354263306, 47.451728684561594, 49.702312741960796, 53.91079146521432, 51.31933920724051, 48.09417997087751, 50.08167396272932, 53.27266195842198, 53.14800432750157, 55.903166566576274, 56.70997749056135, 56.9671824319022, 55.15456417628697, 54.2279246194022, 55.25358642850603, 55.27878407069615, 59.61325100490025, 51.58319010053362, 48.782194069453645, 55.84397486277989, 56.836181095668245, 51.41905280521938, 46.890783241816926, 42.628942353384836, 43.53357696533203, 40.696342604500906, 46.07518284661429, 47.93002183096749, 46.075763021196636, 47.35182053702218, 46.6941249029977, 52.12982225418091, 59.02818489074707, 60.46195261819022, 60.58282348087856, 61.739670753479004, 62.8054757799421, 64.43331364222935, 65.40390055520194, 61.70020498548235, 63.20129380907331, 59.97641944885254, 60.345646721976145, 59.511383465358186, 59.458646638052805, 60.15305655343192, 60.80511719839913, 55.778957094464985, 58.362283434186665, 65.84415926252092, 70.15537057604108, 73.24952847617013, 78.7639593396868, 48.47068548202515, 0.9457094307456697, 1.640060720699174, 0.672600117112909, 0.21886510721274785, 6.477428606578282, 69.24363490513393, 62.46226256234305, 62.12463569641113, 49.183970178876606, 37.73765025820051, 22.174814496721538, 45.65982648304531, 56.41837201799665, 50.92243031093052, 62.45588411603655, 15.22466346195766, 0.5959616495030267, 0.11494259722530842, 0.07578971529645578, 0.023086555202358534, 0.04167046397924423, 0.029636509716510773, 0.06774921781782593, 0.06797023702945028, 0.03982000398848738, 0.08310444493378912, 0.14780081835176262, 0.12612811130072388, 0.1461781154253653, 0.11215288870568786, 0.1535691259694951, 0.12530232061232838, 0.10884046394910131, 0.13270137858177933, 0.5557549755488123, 1.2468121136937822, 43.71119376591274, 82.50038092476981, 61.62450436183384, 71.72666399819511, 40.92095702035086, 49.755692277635845, 48.63608387538365, 87.81605856759208, 51.48709651402065, 0.1288363074085542, 0.5399103143385479, 2.87930765748024, 1.9417225165026528, 25.037628650665283, 101.03120572226388, 79.61566952296666, 87.94213363102504, 69.04513876778739, 73.59497206551688, 74.80327074868339, 78.5062506539481, 73.57296017238072, 77.35793576921735, 74.18568706512451, 66.55995573316301, 58.184854234967915, 60.15786470685686, 57.19730676923479, 59.369779178074424, 59.700749669756206, 56.843970026288716, 55.67445618765694, 58.23711511066982, 53.076767921447754, 57.37529877253941, 55.94330283573696, 57.13347019468035, 54.425996916634695, 55.55984912599836, 52.984544481549946, 53.16244963237217, 51.8115530695234, 49.82995809827532, 50.48030253819057, 50.38806867599487, 52.288161277770996, 55.164903095790315, 50.41563217980521, 48.237542152404785, 48.03901474816458, 52.28359978539603, 48.55313975470406, 48.348994731903076, 49.81880276543753, 56.65578154155186, 54.36005851200649, 56.43044103894915, 54.11726066044399, 54.30292000089373, 50.463609491075786, 57.383570602961946, 56.83388124193464, 64.69072355542863, 56.6849570274353, 48.93961593082973, 58.576885495867046, 57.81822211401803, 57.09755843026297, 56.76633085523333, 59.64305182865688, 58.10924046380179, 58.44532830374581, 62.95410469600132, 59.16123594556536, 45.94550166811262, 49.83347736086164, 55.46030575888497, 52.65358788626534, 50.65808262143816, 47.48542397362845, 54.00809751238142, 54.39737728663853, 56.96000146865845, 60.902906145368306, 58.044382504054475, 51.74485731124878, 50.787895815713064, 49.753847530909944, 50.97662973403931, 55.78884090696062, 53.07235581534249, 52.25322573525565, 52.467991079602925, 55.428993701934814, 56.26859317507063, 57.58338689804077, 58.785887309483115, 59.25359834943499, 57.57232189178467, 57.87522860935756, 58.79254368373326, 57.46069213322231, 61.872742652893066, 55.10106652123587, 50.23335313796997, 56.81488834108625, 59.60818576812744, 54.17314502171108, 49.62908220291138, 46.08855465480259, 45.451265880039756, 43.97383219855172, 47.588503973824636, 50.96167721067156, 48.99938780920846, 51.08787734167916, 50.54015779495239, 56.58022335597447, 61.09241131373814, 62.946774346487864, 62.73541014535086, 65.05041095188686, 66.32259137289864, 67.65803514208112, 70.05630316053117, 67.04398114340646, 67.16096101488385, 64.81260190691266, 63.98336219787598, 63.07801192147391, 64.16564818790981, 63.95896707262312, 65.45449733734131, 58.95465210505894, 62.47021130153111, 68.81705720084054, 74.27935573032924, 76.00051484789167, 81.85114819662911, 51.32739911760603, 0.9746184966393879, 5.9316892964499335, 2.0630083169255937, 0.2984556635575635, 10.634593146187918, 77.83391516549247, 67.57885347093854, 69.2583372933524, 58.411622592381065, 55.87387990951538, 37.38209356580462, 48.23972388676235, 57.72936160223824, 60.99440002441406, 73.84932477133614, 20.71672807421003, 0.7228881929601941, 0.2291703170963696, 0.34596494851367815, 0.15255272122366087, 0.16470544625605854, 0.19813910579042776, 0.1640359628945589, 0.13135850349707262, 0.20851320054914269], [0.017639954607667666, 0.03068732636581574, 0.03596578937556062, 0.13339869544974395, 0.08392399310001306, 0.06594860300953899, 0.044447633171720166, 0.02317132967125092, 0.09741290286183357, 0.037050573487899134, 1.111512990934508, 13.998305542128426, 50.517888818468364, 42.33409554617745, 36.20316144398281, 24.811200754983084, 47.02251761300223, 36.08020612171718, 84.62791238512311, 18.183208159038, 0.15851210430264473, 0.18776909581252507, 0.40953556448221207, 0.6902956590056419, 50.43088000161307, 85.77068260737828, 77.94758769444057, 73.8296822139195, 60.257508822849815, 64.82478904724121, 71.27725451333183, 81.05894238608224, 70.65969167436872, 75.24462032318115, 74.4603076662336, 62.605388505118235, 53.280926840645925, 52.38842378343855, 50.81932599203927, 51.78692517961775, 50.74835361753191, 50.41541678564889, 51.07612098966326, 49.48148856844221, 48.97118854522705, 50.34878356116158, 48.96528605052403, 49.289443833487375, 48.93150738307408, 48.608631542750764, 49.04733385358538, 53.686635630471365, 47.622564043317524, 43.62086371013096, 46.04899508612496, 42.681832041059224, 48.15217311041695, 52.75652544839041, 46.25931010927473, 45.07570879799979, 43.76388890402657, 45.63348586218697, 44.48525088174002, 42.76060029438564, 43.331641469682964, 46.386038303375244, 47.89687544958932, 49.89463540485927, 48.22520215170724, 45.6727431842259, 47.05372544697353, 50.315129961286274, 51.45082344327654, 57.75567095620291, 58.765925134931294, 54.213580063411165, 50.50251245498657, 55.45805106844221, 52.18901743207659, 50.32326977593558, 55.550528117588584, 59.2272299357823, 51.80151639665876, 56.51634509222848, 46.414414746420725, 40.57195247922625, 44.98133141653878, 37.33739233016968, 40.54690422330584, 40.442010743277415, 42.225331919533865, 42.580249377659385, 45.61105707713536, 55.796080929892405, 54.452431338174, 49.135937282017295, 50.49408776419503, 51.307117325919016, 52.2570298739842, 55.25100517272949, 56.346958432878765, 55.317937169756206, 54.797961780003135, 54.60328367778233, 49.22035442079817, 49.3010264805385, 54.3521271433149, 53.76955195835659, 52.11787135260445, 51.783534458705354, 54.21645661762783, 52.79814168385097, 54.240618978227886, 55.32748052052089, 48.95480816704886, 45.32697650364467, 50.5008796283177, 53.427672794886995, 50.48041023526873, 44.30538633891514, 41.501673562186106, 39.56574215207781, 39.12884289877755, 38.706666878291536, 45.508060455322266, 42.77812017713274, 45.11214862551008, 43.07853249141148, 44.88942411967686, 47.713109493255615, 57.302123819078716, 54.62884610039847, 57.707669326237266, 57.928239890507285, 60.88268688746861, 58.77631964002337, 60.200589179992676, 56.80319104875837, 58.684665952410015, 55.61053276062012, 57.88041543960571, 52.534405435834614, 54.76617724554879, 49.70577641895839, 54.84899629865374, 53.16142129898071, 66.62257984706334, 63.42853464399065, 77.7350492477417, 66.66129520961216, 57.62901224408831, 7.571561438696725, 0.2908886138881956, 0.33611598557659556, 0.0425346258229443, 0.40452249348163605, 43.990938663482666, 62.87654890332903, 57.1343526159014, 45.259412220546174, 45.26151752471924, 35.63072715486799, 12.677024807248797, 37.154078006744385, 44.04967178617205, 48.04524728230068, 19.477209397724696, 0.1895175991313798, 0.08851840799408299, 0.07768582033791713, 0.12834111255194458, 0.04744671045669487, 0.012473186943680048, 0.05704856451068606, 0.060976325534284115, 0.021611367485352924, 0.03343165446338909, 0.023281895256202136, 0.01733732290033783, 0.034805660734751394, 0.08238493997071471, 0.03418863830821855, 0.07660663753215756, 0.027472383342683315, 0.0374274114812059, 0.12423337011465005, 0.8782587072678975, 29.96903269631522, 62.41746752602713, 50.56631081444876, 44.430613722120015, 22.28833590235029, 47.95514651707241, 43.605671473911826, 92.45409229823521, 18.990116357803345, 0.28301611489483286, 0.38930194878152435, 2.179802541221891, 0.05410427214311702, 56.74187667029244, 89.6408222743443, 80.01032720293317, 78.979158946446, 61.473575592041016, 68.9423749106271, 74.91451835632324, 83.59770992824009, 73.10133729662213, 78.32713999067033, 74.89597361428397, 64.71324961526054, 56.05214636666434, 55.84494413648333, 53.13871111188616, 55.04597772870745, 53.445415019989014, 52.35741049902779, 52.563584395817344, 52.90070056915283, 51.57656151907784, 51.82311487197876, 50.929190908159526, 50.60150344031197, 50.57746614728655, 50.616143294743125, 51.54100063868931, 55.23863043103899, 50.6505195072719, 45.52188042231968, 47.13480050223214, 45.28699656895229, 50.83548750196184, 53.79784849711827, 45.979943888528005, 46.26404183251517, 43.966199602399556, 47.65217726571219, 45.90402092252459, 44.22042376654488, 44.95454263687134, 48.722255434308735, 51.448395047869, 53.35797541482108, 51.17984369822911, 48.23179946626936, 48.052410875047954, 51.795454093388145, 53.54627159663609, 59.96683093479702, 62.24274812425886, 57.91964149475098, 51.040230069841655, 57.71597589765276, 54.88635676247733, 53.13718250819615, 57.9916422026498, 61.68016638074602, 54.56360946382795, 59.78763689313616, 48.643730367933, 43.99070937292916, 46.52774681363787, 40.349509375435964, 41.52879932948521, 44.12476791654314, 45.806732245853965, 43.79138987404959, 47.925498553684776, 56.140708105904714, 56.49461807523455, 52.40047195979527, 55.074666840689524, 53.97670207704817, 56.44084596633911, 57.67586047308785, 57.601500851767405, 58.26735019683838, 58.340347971235005, 57.3928290775844, 53.593613147735596, 52.20886148725237, 55.521759101322715, 56.576429639543804, 54.32195111683437, 53.52712236131941, 56.71423326219831, 55.2633764403207, 57.27044003350394, 56.54588883263724, 51.32792370659964, 47.60411310195923, 52.730897017887656, 57.561041491372244, 52.83895540237427, 47.31819820404053, 43.290351799556184, 43.31047030857631, 41.89806134360177, 41.70214646203177, 47.34768635886056, 46.41050638471331, 47.27260412488665, 46.43292127336775, 46.117059639522004, 49.336656842912944, 57.570414611271445, 57.9187764440264, 62.04963684082031, 61.041376795087544, 61.960602624075754, 60.867470332554404, 62.7654333114624, 58.628184046064106, 59.17577852521624, 57.05131469454084, 58.40691866193499, 54.837580408368794, 55.53402614593506, 52.931085041591096, 55.11508798599243, 57.19017791748047, 66.4156972340175, 68.40787778581891, 77.99518285478864, 69.76008061000279, 62.92533915383475, 11.430318219321114, 0.6537599680679185, 1.6291214334113258, 0.025902511152837957, 0.25179392312254223, 45.94832263674055, 70.92927483149937, 60.68363489423479, 53.99136972427368, 40.972582135881694, 22.7633547101702, 18.7920457976205, 41.000135217394146, 49.688273906707764, 59.17905112675258, 24.550478288105555, 0.2689179756811687, 0.04832330306193658, 0.06977796967008285, 0.04530795789988978, 0.046024477308882136, 0.025449699289830666, 0.006779453717172146, 0.040183159323143106, 0.049961391769881756, 0.09221533140433685, 0.09003428236714431, 0.08756404849035399, 0.18279770043279442, 0.193434849647539, 0.17941470124891826, 0.15103795964803013, 0.20480716441358837, 0.14549142441579274, 0.16157707412328037, 1.210535351719175, 44.628383772713796, 70.94848660060337, 59.438552447727744, 51.64666536876133, 38.625296524592805, 69.44652230398995, 51.40592418398176, 100.89946092878068, 23.22898476464408, 0.4319608211517334, 0.5631908508283752, 4.26974446432931, 1.5877488191638673, 61.79691001347133, 93.39836638314384, 85.74033982413155, 81.9350893838065, 66.93847969600132, 72.26895700182233, 77.32627977643693, 82.58250168391636, 77.65059389386857, 79.71894754682268, 79.74342605045864, 66.71090534755162, 58.649535860334126, 58.99694578988211, 55.76245859691075, 58.46595055716378, 56.08880158833095, 54.46046345574515, 56.15914167676653, 54.49112238202776, 53.31421913419451, 55.89712510790144, 54.19428491592407, 53.10962247848511, 53.743506635938374, 52.15731280190604, 53.03765651157924, 56.288485867636545, 52.48202991485596, 48.414241790771484, 50.4917288507734, 48.324519702366416, 53.936996596200125, 57.51370688847133, 49.284392493111746, 48.37903874261038, 45.55880662373134, 49.24573966435024, 50.37228236879621, 47.122245107378276, 48.90040029798235, 52.64817871366228, 54.17948872702462, 56.158905438014436, 53.63414546421596, 51.67226948056902, 51.80205488204956, 55.47338226863316, 56.21989325114659, 63.86559023175921, 64.81693063463483, 57.595994404384065, 53.79304034369332, 61.32223687853132, 57.80322790145874, 54.32026965277535, 62.640073912484304, 62.73463889530727, 57.47544315883091, 62.06505489349365, 54.914920806884766, 49.7073084967477, 49.908073220934185, 42.993670667920796, 44.69919981275286, 46.31137296131679, 50.58038786479405, 48.34087576184954, 49.86342757088797, 58.11659860610962, 58.9197860445295, 54.719269956861226, 55.84424931662423, 55.31495291846139, 59.06676128932408, 60.162325450352256, 59.15325246538435, 59.77749947139195, 58.37582547324044, 57.74481439590454, 57.32372576849801, 54.463659627096995, 59.40743146623884, 60.02728026253836, 57.41476454053606, 55.19693429129464, 59.68059989384243, 58.40753705160958, 61.22936030796596, 59.57258319854736, 54.26684842790876, 49.449592862810405, 55.176273822784424, 60.67570005144392, 55.394145011901855, 48.24222523825509, 46.85849148886544, 45.07254041944231, 45.35655151094709, 44.24980075018746, 51.059122221810476, 47.61208963394165, 49.77203444072178, 48.18325587681362, 48.369009017944336, 51.72243547439575, 61.10741942269461, 60.53374835423061, 64.84569617680141, 64.56661483219692, 66.95321682521275, 64.22774423871721, 65.77535820007324, 63.252814701625276, 63.020849091666086, 61.394553729466026, 64.52862903050014, 58.72502108982631, 59.25864968981062, 55.46945653642927, 59.1941773550851, 59.46405928475516, 68.45887756347656, 71.92890521458217, 81.486465045384, 73.40524455479213, 68.08305644989014, 10.97244496004922, 1.1914057667766298, 2.9703803019864217, 0.13814636426312582, 0.8025617748498917, 55.813771043504985, 76.53662395477295, 69.27361638205392, 60.9432612827846, 60.69202136993408, 50.229892935071675, 19.064870289393834, 50.364333629608154, 57.22438389914376, 69.84640502929688, 32.64623267310006, 0.28481596974389894, 0.11297537492854254, 0.1749030269150223, 0.20263199827500752, 0.22017750250441687, 0.1250061672180891, 0.15875577979854175, 0.17689526001257555, 0.1561630160680839], [0.04762207783226456, 0.05188096733763814, 0.04199104802682996, 0.034249621643019576, 0.04076250948544059, 0.04114574945664831, 0.08307355123439006, 0.026329362266031758, 0.07273811940103769, 0.08480853135032312, 0.7271940133401326, 36.3578075000218, 46.73764841897147, 47.28940486907959, 29.788164138793945, 42.1331466947283, 43.36331830705915, 43.534855433872764, 77.83970301491874, 6.546686513083322, 0.1299830994435719, 0.6209168647016797, 1.2387315758637019, 4.03018490757261, 69.28751972743443, 77.5757965360369, 78.85076318468366, 66.27009773254395, 60.061111041477744, 67.34681143079484, 70.15931715284074, 77.07702010018485, 71.85366317204067, 68.3610121863229, 71.49086298261369, 65.6849273954119, 55.541509355817524, 52.442918504987446, 53.442336968013215, 50.43632044110979, 50.124203886304585, 50.79139770780291, 49.24895320619856, 48.228856904166086, 47.13427938733782, 47.780920437404085, 49.7686402457101, 49.26082420349121, 48.13517781666347, 48.009554386138916, 49.70307009560721, 52.335374287196565, 47.55864061628069, 42.897927965436665, 46.6544645854405, 43.69659907477242, 46.766785689762656, 50.40424060821533, 46.72927931376866, 41.89364576339722, 45.716023513248985, 43.524026666368755, 45.450546741485596, 41.6643100466047, 39.8177741595677, 43.78472307750157, 43.91349056788853, 47.575538635253906, 48.46583216530936, 46.68013817923409, 46.22799457822527, 45.988920961107524, 50.85544967651367, 53.866069384983604, 57.98997810908726, 58.17219461713518, 53.02135256358555, 54.71581322806222, 55.77329778671265, 52.558922154562815, 56.694552489689414, 53.781228406088694, 59.93573774610247, 52.717990739004954, 42.9386374609811, 43.70704569135393, 42.40692656380789, 38.33120707103184, 38.99367959158761, 39.561878953661235, 41.58306476048061, 34.47175373349871, 39.67951542990548, 44.612114565713064, 54.42685154506138, 58.92473316192627, 53.53555052621024, 55.392387117658345, 50.781628540584016, 51.48487309047154, 44.89490277426583, 52.13802807671683, 53.11745309829712, 48.59497485842024, 49.83478709629604, 52.282536711011616, 51.65766784123012, 53.43519769396101, 55.22438314982823, 55.08366128376552, 53.390777860369, 53.23719140461513, 54.80846398217337, 54.31390510286604, 47.595490387507844, 48.6342009135655, 46.474860600062776, 53.31212077822004, 52.02461610521589, 45.770306314740864, 43.44915982655117, 39.9863999911717, 38.43478386742728, 37.646062578473774, 44.490416867392405, 43.37325075694493, 43.66808366775513, 43.28393166405814, 45.96834734507969, 44.71383619308472, 49.86106170926775, 53.95118134362357, 57.95972217832293, 59.480366706848145, 60.54964583260672, 56.759337493351524, 54.04570116315569, 52.08120918273926, 50.87915693010603, 50.309189251491, 51.496490478515625, 47.44339084625244, 50.140031882694785, 49.43125656672886, 53.77270644051688, 52.51884841918945, 64.88086100987026, 63.56847831181118, 75.39324923924038, 62.6037973676409, 63.92688029153006, 25.896693502153667, 0.10221518017351627, 0.1664720800306116, 0.664303967995303, 0.07332433294504881, 15.037374768938337, 62.53605243137905, 56.70889357158116, 49.10108164378575, 44.601730482918875, 52.465451513017925, 28.86698239190238, 36.198071888514924, 42.740777083805625, 48.56835283551897, 20.771208899361746, 0.19148313866129943, 0.028117977182513902, 0.030120060912200382, 0.04780128910871489, 0.04577280867046543, 0.059400957210787704, 0.061508310559604845, 0.02913730132526585, 0.06797092234981911, 0.049493942210184674, 0.03245462171201195, 0.01893474191560277, 0.037155912656869204, 0.010984643961169889, 0.026290114104215587, 0.048728218834315024, 0.030441364206905876, 0.03941864713228174, 0.030754681144441878, 1.403835973569325, 49.77292381014143, 57.125604833875386, 57.091096605573384, 34.86527190889631, 36.76552779333932, 44.789029598236084, 55.57055977412632, 81.34411035265241, 6.662049625601087, 0.5599048414400646, 1.9013107078416007, 1.7688464501074381, 4.449944691998618, 78.91691698346818, 80.37804671696254, 82.58775452205113, 67.78043460845947, 64.6472417286464, 68.52560806274414, 73.39129952022007, 78.21063259669712, 74.78865868704659, 71.91179180145264, 76.53270517076764, 70.31167725154332, 57.85619054521833, 55.62181316103254, 56.499245575496126, 52.75157138279506, 52.38037429537092, 53.59439829417637, 52.91212688173567, 50.86173432213919, 49.95878117425101, 51.341166973114014, 52.078349999019075, 50.530562332698274, 51.44096394947597, 50.59652158192226, 51.61452647617885, 52.2651002066476, 48.741661752973286, 45.83079038347517, 47.42890385219029, 46.23176745006016, 50.03528431483677, 52.42454399381365, 49.071607385362896, 43.09263733455113, 47.23175913946969, 44.3616042137146, 48.243534973689485, 43.57129526138306, 43.300471850803916, 45.23299169540405, 46.27052797589983, 49.88028737476894, 51.45334563936506, 49.262807914188926, 49.81295585632324, 49.17901611328125, 52.380659171513145, 56.43579115186419, 58.73376192365374, 59.824524879455566, 56.91264949526106, 54.86311503819057, 58.969208581107004, 56.74649027415684, 59.733857836042134, 54.22734791891915, 61.2878224509103, 54.325862952641074, 44.920169898441856, 46.09652076448713, 45.23419720785958, 41.39676965985979, 41.46780456815447, 40.225866181509836, 43.42770378930228, 38.449969155447825, 40.61835602351597, 47.05001163482666, 57.47346987043108, 61.637608664376394, 56.69069971357073, 56.86055537632534, 53.40969433103289, 52.389681407383506, 46.211106981549946, 52.689753259931294, 53.17202425003052, 53.15899985177176, 53.591691970825195, 54.41665506362915, 53.58843673978533, 57.46244307926723, 57.88001939228603, 58.55438722882952, 54.40654196058001, 55.384969915662495, 56.700250012534006, 57.86327770778111, 47.315974780491416, 52.09063441412789, 51.67052548272269, 55.4550598689488, 54.958197661808555, 48.01715224129813, 44.459785733904155, 42.47120434897286, 41.62788758959089, 40.48294605527605, 45.35294886997768, 46.14229897090367, 46.07558931623186, 45.44230270385742, 47.75175884791783, 46.97448819024222, 50.38953474589756, 55.89411653791155, 60.39760535103934, 61.692610604422434, 62.407566343035015, 58.390013694763184, 55.51440790721348, 54.66642543247768, 52.515933649880544, 50.61159569876534, 52.30405180794852, 49.94434976577759, 52.412978717258994, 52.69125059672764, 54.94600009918213, 55.524607862745015, 68.67679391588483, 66.18651785169328, 76.40701920645577, 64.78970064435686, 68.20677607400077, 29.771061147962296, 0.36585530691913193, 2.224010020494461, 0.6486346402338573, 0.07315196469426155, 14.177749718938555, 72.07617923191616, 61.945149830409456, 59.45847988128662, 46.2276645387922, 41.56118140901838, 29.27294479097639, 41.969346387045725, 50.272718157087056, 58.909224782671245, 26.37737682887486, 0.3447347916662693, 0.03067763688574944, 0.05557052185758948, 0.08945933928979294, 0.0616912232445819, 0.023013108875602484, 0.05016717787033745, 0.005131092413129019, 0.07163271121680737, 0.135917566716671, 0.11123571970633098, 0.12763572111725807, 0.10711928523544754, 0.08403469608830554, 0.11334054890487875, 0.1887746439980609, 0.2214828681732927, 0.1707314479031733, 0.12279176818472998, 2.226737839835031, 62.224043573652, 67.79479653494698, 64.80806473323277, 39.6766597202846, 60.618509428841726, 59.86651979173933, 59.92236941201346, 90.94745881216866, 8.658701777458191, 0.5931788416845458, 4.146688827446528, 4.528431977544512, 7.378362434250968, 82.33885615212577, 84.28253827776227, 86.19682257516044, 71.09984615870884, 67.52811077662876, 71.71984086717877, 76.8856041772025, 79.86331026894706, 77.65037849971226, 76.44672121320451, 76.41045161655971, 74.28347601209367, 59.0669766834804, 60.08768095288958, 59.47416196550642, 56.00176845278059, 53.863165037972585, 57.48820699964251, 55.451064654758994, 55.709926741463796, 53.56307928902762, 53.389676570892334, 55.126503876277376, 54.85049016135079, 53.42794030053275, 52.72398703438895, 54.17871400288173, 57.0315922328404, 53.11162008558001, 48.21833038330078, 51.57424776894705, 49.246976443699424, 50.92814520427159, 54.130656787327354, 51.28232962744576, 43.363637924194336, 49.44264466421944, 46.23247964041573, 50.38629688535418, 46.884119919368196, 45.84856734957014, 49.22557599203927, 48.87494209834507, 53.32240411213466, 55.03614255360195, 52.94332776750837, 52.4748489516122, 50.402493136269705, 54.56456136703491, 58.921391078404014, 62.068049567086355, 62.32878071921212, 61.02781391143799, 58.109021595546174, 60.54839515686035, 57.91123417445591, 62.12420490809849, 58.870766503470286, 62.516653060913086, 60.096664973667686, 49.270106996808735, 51.158936568668906, 48.15584175927298, 44.058492524283274, 41.95289305278233, 43.05026374544416, 47.15275117329189, 44.16390364510672, 42.5355099269322, 52.27425793239048, 60.30351979391915, 60.53680556161063, 58.47949954441616, 59.822766985212056, 57.24870606831142, 55.87228877203805, 49.62870700018746, 56.32335192816598, 56.1537846156529, 58.8652982711792, 54.302822726113455, 56.131428786686485, 56.327972480228965, 60.069782393319265, 59.45067010607038, 59.71407631465367, 57.49895933696202, 59.68147536686489, 59.64685944148472, 60.955462319510325, 49.72158357075283, 54.92807722091675, 55.07866552897862, 57.41699838638306, 57.383525439671104, 50.02634545734951, 48.45993661880493, 46.36577388218471, 43.698204108646934, 44.00080163138253, 47.65705142702375, 48.57875428880964, 48.04388543537685, 48.10543952669416, 50.64673968723842, 50.21079233714512, 54.28488595145089, 59.59951441628592, 62.25995881216866, 65.20612008231026, 65.55862998962402, 60.09000859941755, 59.5758627482823, 58.8613725389753, 56.087773254939485, 55.41027178083147, 55.123863560812815, 53.250622272491455, 56.29564251218523, 56.553733348846436, 58.80940696171352, 58.464540072849815, 72.10921096801758, 71.11791842324394, 79.36590262821743, 68.53697531563895, 71.37731552124023, 32.05361386707851, 0.8243912777730397, 2.669990135090692, 1.2212522966521127, 0.3848104269376823, 20.28593455042158, 76.77775423867362, 68.80201435089111, 64.36845915658134, 60.610011781964985, 71.86605875832694, 38.51769324711391, 51.776339599064414, 57.07184662137713, 72.39381613050188, 36.48262841360909, 0.5826427670461791, 0.13355551846325397, 0.10754671479974474, 0.1535478335406099, 0.23364430559532984, 0.1384709889867476, 0.12192941802952971, 0.12971992285123893, 0.16975177904324873], [0.024011978580217277, 0.06905807115669761, 0.046152696678681035, 0.0499195499079568, 0.016921116305249076, 0.04049150599166751, 0.0185642278686698, 0.05070571754393833, 0.0636462794084634, 0.05467662660937224, 0.046015792060643435, 35.4185083253043, 42.65754113878523, 46.53167601994106, 34.072114195142476, 30.837307385035924, 35.97256810324532, 65.25523689814976, 58.78765215192522, 1.142589460526194, 0.23497792546238216, 2.3893565194947377, 6.112837518964495, 11.906609416007996, 92.45906720842633, 68.86778599875313, 82.75211415972028, 60.790414810180664, 64.52344567435128, 65.35739626203264, 74.85026141575405, 68.91138594491142, 75.31657586778913, 67.74847984313965, 72.74954305376325, 64.66150638035366, 57.93842942374093, 49.99702058519636, 55.87338311331612, 49.76144191196987, 54.994599274226594, 49.259045464651926, 50.33679097039359, 49.7694080216544, 51.28536946432931, 45.80358471189226, 48.2175417627607, 48.93547133037022, 50.493055956704275, 47.53522866112845, 50.17917455945696, 47.41964190346854, 45.168397767203196, 43.46521363939558, 46.36905343191964, 44.0799172946385, 51.04984985079084, 48.99583033152989, 46.55622400556292, 42.91252613067627, 44.88747862407139, 42.79196793692452, 43.988708291734966, 41.91245453698294, 42.215034689222065, 41.801349367414204, 44.01160955429077, 47.20514406476702, 48.27367973327637, 46.184429373059956, 46.803315843854634, 45.80815315246582, 49.971864632197786, 52.89638226372855, 54.80386774880545, 58.665773800441194, 54.39656434740339, 48.34045539583479, 57.09939275469099, 51.76258911405291, 60.34603582109724, 47.72137784957886, 53.47295420510428, 42.54389292853219, 37.400270053318565, 40.13832235336304, 43.475104400089805, 41.06393705095564, 41.76479489462716, 40.54184593473162, 40.867546217782156, 35.4065192086356, 36.37962831769671, 44.27380677631923, 62.90847587585449, 48.94504247392927, 45.13351086207798, 47.56898648398263, 47.626885822841096, 45.63841560908726, 40.831401688711985, 50.90648419516427, 50.80027750560215, 55.5614333152771, 53.029596601213726, 50.66159493582589, 51.55960096631731, 55.148901394435335, 54.60531949996948, 54.150167328970774, 56.58216190338135, 52.903462478092735, 53.09580945968628, 50.1059752873012, 49.62950951712472, 47.90869433539254, 48.30776759556362, 57.14568860190255, 51.12392807006836, 47.3418915612357, 45.02369458334786, 41.45374836240496, 41.14208344050816, 36.48614420209612, 42.83932685852051, 44.27491848809378, 42.83538375582014, 45.96349055426461, 44.664517879486084, 42.778370312282014, 44.364463397434776, 46.751701150621685, 48.37381369726998, 49.210731165749685, 47.45780488422939, 46.16251128060477, 44.11558934620449, 47.224470479147776, 44.18837867464338, 46.227331025259836, 47.31807313646589, 45.942614691598074, 48.60540757860456, 48.207862922123496, 49.6938602583749, 57.253149441310335, 64.9623772757394, 65.7044448852539, 67.2634608404977, 65.13827092306954, 59.839220319475444, 45.84455476488386, 0.8481625850711549, 1.1308801174163818, 0.5624996136341776, 0.1086216839030385, 1.9522364437580109, 54.40392943790981, 59.95034285954067, 57.13468960353306, 38.222589356558665, 35.98223304748535, 29.137006759643555, 27.144827944891794, 40.4401764188494, 47.46748719896589, 18.07315216745649, 1.0791463277169635, 0.17638861148485116, 0.07541050921593394, 0.10412149038165808, 0.042408598121255636, 0.062384428190333505, 0.02111710561439395, 0.058856473570423465, 0.05080857666741524, 0.04991263224344168, 0.08743759670427867, 0.034029545595071146, 0.03585446552772607, 0.030022372225565568, 0.06251809280365705, 0.026833254245242903, 0.1345929985067674, 0.033160874886172156, 0.0121291442441621, 0.6839390343853405, 48.51553610392979, 53.08968809672764, 56.7480605670384, 42.33520725795201, 36.10834632601057, 42.01280736923218, 75.76152460915702, 59.618510791233604, 1.3535529460225786, 0.4485173470207623, 4.525028663022177, 6.969754074301038, 15.203910929816109, 99.37624904087612, 70.82089682987758, 87.25866018022809, 62.295540537152974, 68.21165370941162, 67.6511425290789, 77.32326425824846, 71.96278463091168, 78.61760248456682, 69.61231327056885, 77.38653455461774, 68.55965423583984, 61.58842236655099, 50.8408966745649, 57.99998351505825, 52.47097880499703, 56.514302321842735, 53.085953439985005, 54.140693460192, 52.09152030944824, 53.823504720415386, 48.14069816044399, 51.055081844329834, 51.42440291813442, 52.204775946480886, 48.658144405909944, 52.22645780018398, 48.45128958565848, 48.76099511555263, 46.056374073028564, 47.91071973528181, 46.27356781278338, 51.99012177331107, 49.911787033081055, 48.29861681801932, 44.82097046715872, 46.58674396787371, 43.18098715373448, 47.27520622525896, 43.39709350040981, 44.38191032409668, 43.442503452301025, 46.49448578698294, 50.10096911021641, 51.23310164042881, 49.141141482761924, 48.38905457087925, 49.30935042245047, 51.80453191484724, 55.84065709795271, 59.44913455418178, 59.91285037994385, 57.5629939351763, 51.651167801448274, 58.172614983149934, 55.28845943723406, 60.56015150887625, 50.90816913332258, 56.559521198272705, 44.0144305229187, 42.32362461090088, 44.34266342435564, 44.24121625082833, 44.756393909454346, 44.92838961737496, 43.197784423828125, 43.04721001216343, 38.691412108285085, 41.383592401232036, 45.028714656829834, 60.589181082589285, 49.732249055589946, 46.571159158434185, 48.9371006829398, 48.860528060368125, 48.36328370230538, 44.32774911608015, 55.53957428250994, 53.581307888031006, 59.357460021972656, 55.12306451797485, 52.46635477883475, 54.47775404793875, 56.73859017235892, 55.342033522469656, 56.13160943984985, 58.28005150386265, 55.556694643838064, 55.543996810913086, 52.09840597425188, 50.5332339150565, 54.3607429095677, 51.17441020693098, 58.32246330806187, 53.12636416299002, 49.25484527860369, 45.911177567073274, 44.30462203707014, 43.92258923394339, 40.258758953639436, 43.44282306943621, 47.38864598955427, 45.13627277101789, 46.806539808000835, 45.59805352347237, 44.614765303475515, 46.557825565338135, 48.74684163502285, 49.64971487862723, 50.04122849873134, 49.531004905700684, 48.196645055498394, 47.42892469678606, 48.7281231880188, 47.35940102168492, 48.86628464290074, 48.645915576389854, 48.75964716502598, 49.198863642556326, 51.01603991644723, 50.71163586207798, 58.695317540849956, 66.83725139072963, 67.3911131450108, 69.16263280596051, 66.5910211290632, 60.54089110238211, 49.71265166146414, 1.6716066279581614, 1.1468070170709064, 1.6096712542431695, 0.0423988747144384, 1.3268125866140639, 57.95618207114083, 67.92161505562919, 63.46121897016253, 46.17912094933646, 33.80075229917254, 28.131767443248204, 39.567357608250205, 46.21092285428728, 58.65596294403076, 24.557826008115494, 1.236113299216543, 0.20137870338346275, 0.08297759281205279, 0.031898111038442166, 0.058749054691621234, 0.019593519690845693, 0.0105483858081113, 0.09318353980779648, 0.01675624417008034, 0.2058523797563144, 0.1336476228066853, 0.16396120190620422, 0.14844701439142227, 0.09643040451088122, 0.14005747171384947, 0.08983612978564841, 0.2515573043908392, 0.2221959541950907, 0.12664413718240602, 1.5844424537249973, 65.00255870819092, 57.92107629776001, 66.8916140965053, 43.721768924168174, 47.94578729357038, 54.27053444726126, 80.24783747536796, 69.46014772142682, 1.675524434873036, 0.252961057637419, 5.391660537038531, 8.478578414235797, 21.875553846359253, 103.59732832227434, 75.11747523716518, 90.65438379560197, 66.54815074375698, 71.79110854012626, 70.45777702331543, 80.28800501142229, 74.7869633265904, 80.20457104274205, 73.2301777430943, 79.20803955623082, 72.98897102900914, 64.39336150033134, 55.71151787894112, 62.93612275804792, 55.70123454502651, 60.454559734889436, 54.88617958341326, 56.86148296083723, 55.65843711580549, 58.69248962402344, 50.17361600058419, 53.56079680579049, 54.62496900558472, 54.51398542949131, 51.83077873502459, 56.64037391117641, 52.116158621651785, 51.4742180279323, 49.446094444819856, 53.1005585534232, 50.85692964281355, 54.642784186771934, 54.12974309921265, 49.67862980706351, 43.91409158706665, 46.662312575748985, 44.73145682471139, 48.50117417744228, 47.85439068930489, 48.02015038899013, 48.0283214705331, 50.472433703286306, 53.92618867329189, 54.47596836090088, 52.61900322777884, 50.66732372556414, 52.294042927878245, 55.61165142059326, 58.75541945866176, 58.390117917742046, 62.35514218466622, 61.74752916608538, 55.86131409236363, 59.75482055119106, 58.238928590502056, 65.1222344807216, 55.43035207475935, 56.68820183617728, 48.22781120027815, 48.57090629850115, 47.27884013312203, 48.78335094451904, 48.21055882317679, 45.86983578545706, 45.13571344103132, 46.12215266908918, 43.06339236668178, 44.48195743560791, 46.63796956198556, 64.49685491834367, 52.20393868855068, 48.08363955361502, 49.55149514334542, 50.292791502816335, 49.99888270241873, 46.418733051845, 56.79230669566563, 57.16759974615914, 59.8764557157244, 56.12007890428816, 55.43312093189785, 56.67287063598633, 58.73708316258022, 58.34984615870884, 57.80777549743652, 60.96555805206299, 58.97610119410923, 59.03027629852295, 54.40137597492763, 51.510244437626426, 56.98822157723563, 55.35802480152675, 61.69533429827009, 57.22165673119681, 51.721931729997905, 49.20288664954049, 47.56630447932652, 47.18767629350935, 43.741279465811594, 47.57356187275478, 49.71369736535208, 47.40863248280117, 48.84354666301182, 48.52061871119908, 47.29120445251465, 48.95378678185599, 50.55964054380144, 53.82892778941563, 54.59947953905378, 51.344109535217285, 52.28183494295393, 49.50477198192051, 52.441681725638254, 49.492581367492676, 53.59126813071114, 53.16570486341204, 50.6900269644601, 54.12321874073574, 53.44663095474243, 53.944208826337544, 63.44959463391985, 71.32402978624616, 71.27176543644497, 73.01820904867989, 69.39311150142125, 61.578938075474326, 52.76304980686733, 1.2568182796239853, 6.091322422027588, 2.307054238659995, 0.18797017287995132, 3.2482250843729292, 67.66688019888741, 72.85882432120187, 71.64395264216832, 54.08726528712681, 49.97489404678345, 42.953204359327046, 41.42737300055367, 54.90414762496948, 69.27276175362724, 35.368637629917686, 1.8905785637242454, 0.46892909173454556, 0.2773222561393465, 0.18218471189694746, 0.14711207816643374, 0.11552008480897971, 0.15392386407724448, 0.17334223352372646, 0.22424814264689172], [0.06116234590964658, 0.025346477150118778, 0.008714454930408724, 0.027152803526925187, 0.0018040096038021147, 0.000498205484681031, 0.061590460794312615, 0.03068702102505735, 0.033257311675697565, 0.047764878919614215, 0.8942156253116471, 37.018574237823486, 47.66796357291085, 51.535396916525706, 26.247214487620763, 35.039230482918875, 35.322546754564556, 77.06209536961147, 38.12491852896554, 0.08385247550904751, 0.03419113531708717, 0.21782188676297665, 0.433571419013398, 33.01270498548235, 88.57753944396973, 71.27926254272461, 80.15530831473214, 61.05640574863979, 64.47897025517055, 63.226738112313406, 74.16276495797294, 65.21388816833496, 70.28990159715924, 66.88924476078579, 69.0260590144566, 69.24161992754254, 63.9148599079677, 56.04225213187081, 57.18270512989589, 57.499824387686594, 55.61120673588344, 56.24561895642962, 56.267012459891184, 53.369936738695415, 53.27471515110561, 47.628633294786724, 47.922781808035715, 49.66230501447405, 47.617769786289756, 47.497871671404155, 48.24724531173706, 46.445782388959614, 42.93977696555001, 43.63517699922834, 43.82073559079851, 42.98496110098702, 50.057779107775005, 45.807461806706016, 45.05374206815447, 45.90519169398716, 43.338151931762695, 41.88434559958321, 41.55888850348336, 40.760467529296875, 39.98579897199358, 40.29966299874442, 42.889753409794395, 44.54801743371146, 45.902363777160645, 45.002071789332796, 47.00971555709839, 48.42835358210972, 50.43221752984183, 51.12174980981009, 56.73348672049386, 58.09299904959542, 50.26433515548706, 51.711856842041016, 51.39602994918823, 57.43960782459804, 55.402350834437776, 57.92413697923933, 47.01655258451189, 38.67308276040213, 41.04483297892979, 40.09058475494385, 42.80692393439156, 46.701253754752024, 46.749710491725374, 46.460790497916086, 37.90644979476929, 37.44128179550171, 37.06454699380057, 41.727670669555664, 34.84484420503889, 39.47901126316616, 49.54680510929653, 52.07414633887154, 53.90447555269514, 53.39544357572283, 53.3298282623291, 53.47026525224958, 54.449794496808735, 54.64285714285714, 52.32373258045742, 52.56099271774292, 52.981428214481895, 53.59695870535714, 55.314918177468435, 53.049037660871235, 54.11868156705584, 55.35311589922224, 55.643741675785606, 54.84183965410505, 50.5002612386431, 50.49363265718733, 53.901143891470774, 54.560010296957834, 48.88822705405099, 48.03440809249878, 47.745290075029644, 42.213242053985596, 41.08714403424944, 37.7458803994315, 38.78474725995745, 45.43745633534023, 44.02982773099627, 43.85018900462559, 42.325618743896484, 44.77672781263079, 44.86768320628575, 43.611622606004985, 43.315118653433665, 44.166960852486746, 41.39226722717285, 44.750123160226, 42.95125886372158, 45.54983302525112, 42.537709031786235, 46.889470032283235, 45.76833650044033, 48.627294404166086, 46.91758244378226, 51.65037570680891, 53.35144410814558, 62.37473610469273, 63.411671366010395, 67.57398973192487, 64.25288976941789, 63.28989028930664, 58.851179531642366, 59.96716444832938, 9.835485168865748, 2.425925974334989, 1.4967782263244902, 0.3951215536466667, 0.16429429474685872, 29.691827365330287, 64.93497358049665, 60.67713138035366, 43.24866608210972, 41.45122964041573, 30.575217860085623, 23.22691593851362, 37.36213139125279, 50.769802706582205, 12.502531221934728, 2.8961031905242374, 0.18525873337473187, 0.17599225203905786, 0.03457510471343994, 0.09233530996633427, 0.05587129268263068, 0.0883312001824379, 0.12060905673674174, 0.040059988253882954, 0.04165576012539012, 0.014509823372853654, 0.017498742988599197, 0.017990307682859044, 0.03974271206451314, 0.08155963104218245, 0.028043133073619435, 0.021695885807275772, 0.02362341889446335, 0.035618620325944254, 2.035104134253093, 51.7914970942906, 56.22133847645351, 62.07278823852539, 26.909454243523733, 35.16838707242693, 43.47028235026768, 84.18971034458706, 39.64410393578665, 0.10532423441431352, 0.1232438896383558, 0.9674516469240189, 2.851766518184117, 46.506485325949534, 88.32907881055559, 75.9818172454834, 82.40943595341274, 63.180275508335654, 66.13875593457902, 66.71130834306989, 76.61807768685478, 69.7229494367327, 74.34964370727539, 70.25678648267473, 72.77306965419224, 70.380784034729, 67.62050792149135, 60.3658937726702, 61.193132400512695, 60.73924132755825, 58.928485189165386, 57.725328172956196, 59.99941103799002, 56.67845698765346, 55.9103753226144, 50.126097270420615, 51.20867872238159, 49.043060711451936, 50.052967480250764, 50.17551980699812, 50.04916334152222, 48.84278583526611, 47.15369265420096, 45.36328431538173, 46.66916349955967, 45.264817919049946, 51.297476700374055, 47.97435481207711, 46.15744604383196, 46.182942458561485, 43.76751586369106, 42.87533589771816, 43.697835854121614, 43.16752849306379, 44.51767117636544, 43.613936356135774, 43.63232476370675, 47.1785637310573, 48.05361986160278, 48.33992385864258, 48.84215702329363, 51.84928526197161, 52.15870244162423, 54.09622498920986, 59.21796103886196, 60.34782150813511, 51.988301345280235, 54.9467887197222, 53.794304915836875, 59.87785925183977, 58.91051714760916, 59.56605189187186, 47.51204947062901, 41.56419692720686, 45.24218763623919, 45.522516182490754, 46.17406266076224, 50.885653495788574, 48.1306962285723, 46.95739214760916, 40.08492544719151, 38.795006275177, 39.90329258782523, 41.873370919908794, 35.935697487422395, 38.96770027705601, 52.35490219933646, 54.27420309611729, 58.795218740190776, 55.81649126325335, 56.3578462600708, 56.36790030343192, 57.19558014188494, 57.11474132537842, 54.27367155892508, 56.02895327976772, 54.918367113385884, 56.79717738287789, 55.9314318384443, 54.477576868874685, 54.94988414219448, 56.90964092527117, 57.14632436207363, 55.45084578650338, 53.035085678100586, 54.30907957894461, 54.85023307800293, 56.93318142209734, 51.716734477451865, 49.10403462818691, 50.571706090654644, 45.343836307525635, 44.23233992712838, 40.777435030256, 41.69607721056257, 47.467223167419434, 45.882922717503135, 45.484863894326345, 44.685254778180806, 46.70963675635201, 46.8238581929888, 45.434854234967915, 44.61971589497158, 45.20306232997349, 44.564171995435444, 46.906826632363455, 46.18906382152012, 47.74179513113839, 46.49429818562099, 49.4276191847665, 46.88238634381975, 50.3273275239127, 49.6352869442531, 53.61996071679251, 54.94707012176514, 65.63781860896519, 64.44199194226945, 71.30437333243233, 65.3359124319894, 64.91014071873256, 59.234859057835166, 62.870309420994346, 13.099391034671239, 1.029706637774195, 1.2522984764405658, 0.2300719272877489, 0.16060470630015644, 30.06260756083897, 74.3521728515625, 65.54533808571952, 54.269860471997944, 39.64541367122105, 21.190154007502965, 30.018066133771622, 42.377851826804026, 61.22478839329311, 21.83230652127947, 2.9551459423133304, 0.1752561501094273, 0.19091513699718884, 0.030979663000575135, 0.053447209365133724, 0.07492331428719418, 0.024936273893607513, 0.08469379786401987, 0.08780094542141471, 0.2439411830689226, 0.08103145938366652, 0.1524020457374198, 0.1688200147556407, 0.15614221218441213, 0.09657565850232329, 0.13244899069624289, 0.12627243569919042, 0.0950625321960875, 0.18513457503701958, 3.4068689601761952, 66.8394261768886, 65.27201679774693, 71.17064135415214, 32.48624692644392, 54.789818491254536, 49.903563840048655, 89.57532855442592, 45.93012877873012, 0.25320413602249964, 0.2721704382981573, 2.3384520624365126, 6.092131452901023, 49.60421460015433, 93.0715856552124, 78.43785953521729, 85.56835801260812, 68.00746699741909, 68.5406161717006, 70.06120858873639, 81.19879572732108, 68.95345728737968, 75.97295829227993, 74.0378085545131, 76.62572070530483, 75.4174359185355, 70.99590110778809, 62.53542709350586, 63.02581010546003, 64.61295236860002, 62.95265947069441, 63.42458111899239, 64.06905433109829, 60.060881750924246, 58.17224325452532, 53.0342241014753, 54.48227037702288, 54.29719468525478, 53.6691643851144, 54.599628925323486, 53.27471515110561, 52.159216608319966, 49.0580792427063, 49.019888469151084, 50.27738734654018, 47.88764476776123, 53.75392893382481, 49.17018495287214, 46.54381799697876, 47.33512054170881, 43.4093952860151, 45.23002134050642, 44.888315882001606, 46.12079777036394, 46.30513000488281, 44.733367579323904, 45.93255370003836, 48.626846245356965, 49.34085355486189, 50.58439350128174, 51.61841746738979, 54.47542987551008, 55.17013161523001, 55.552588258470806, 62.08957508632115, 61.797604833330425, 53.0562082018171, 57.63820471082415, 58.13319090434483, 63.65829767499651, 60.272739274161204, 62.95737034933907, 49.614793232509065, 45.15671437127249, 49.75231892721993, 46.98689767292568, 49.7600349017552, 52.791051047188894, 50.54503543036324, 50.062778336661204, 42.59225239072527, 41.58957174846104, 43.40011249269758, 46.95597471509661, 42.18657834189278, 40.92426436288016, 53.376384666987825, 55.10023273740496, 59.033771242414204, 58.2172224181039, 57.74715593882969, 58.9353916985648, 59.00728470938546, 60.838058607918875, 54.77479996000017, 58.25024373190743, 56.1487124306815, 58.96485900878906, 58.42870821271624, 56.59113550186157, 59.93177032470703, 59.72110094342913, 58.85826669420515, 55.36608818599156, 56.26014763968331, 57.03225925990513, 57.84671320234026, 58.81135245731899, 54.72587769372122, 52.69398123877389, 52.355440684727256, 48.93298734937395, 45.54211357661656, 42.45587314878191, 44.89426006589617, 49.82489286150251, 47.79447289875576, 48.9380213192531, 47.27722815104893, 51.21623836244856, 48.8512522152492, 48.39150728498186, 47.88734599522182, 49.65698964255196, 47.08768824168614, 50.69468920571463, 49.68950721195766, 51.28557096208845, 50.44805942262922, 53.64868456976754, 49.766361236572266, 54.98937770298549, 54.41895144326346, 56.678922516959055, 58.186712878090994, 68.15766620635986, 68.17893464224679, 73.26892784663609, 70.20550182887486, 68.85584204537528, 61.06486170632498, 65.74855204990932, 12.636211957250323, 5.182490229606628, 5.174258351325989, 0.7882717187915529, 0.21140893016542706, 38.88751111711775, 77.98237037658691, 73.94607843671525, 57.85930681228638, 57.38470663343157, 45.076410566057476, 35.84563841138567, 55.445346287318635, 70.84201240539551, 35.47171763011387, 3.6133136195795874, 0.35210083212171284, 0.2716632740838187, 0.06719963159412146, 0.12833094809736523, 0.20046346820890903, 0.1641094075249774, 0.21022441158337252, 0.1658547217292445], [0.03996496620987143, 0.02700027055107057, 0.0797541036403605, 0.07716794205563408, 0.07159934764994041, 0.04302996317190783, 0.10161462918456111, 0.03141465483765517, 0.033239574770310094, 0.07955695529069219, 3.8033014706202914, 39.675603594098774, 41.49273817879813, 29.579867567334855, 43.588478156498496, 52.91299540655953, 42.05722720282418, 83.95511136736188, 17.94526709829058, 0.3995961392564433, 0.21484668712530816, 2.2336856041635786, 4.408414006233215, 68.20690808977399, 75.0854857308524, 79.00405434199742, 75.56766986846924, 62.760041509355815, 57.634410994393484, 66.45000049046108, 71.49889510018485, 70.47894123622349, 67.73251288277763, 67.9146043232509, 68.75011825561523, 66.68226487295968, 65.42493970053536, 64.70473807198661, 61.25152506147112, 61.77073614937918, 60.04779134477888, 61.33117226191929, 59.18100357055664, 56.9638785634722, 54.281463963644846, 53.76973955971854, 47.270672525678364, 48.08128758839199, 48.9000563621521, 47.117655822208945, 46.776586123875205, 46.58058786392212, 43.26915979385376, 41.93606798989432, 43.19108288628714, 46.49975599561419, 49.02385241644723, 46.358040537152974, 45.08966078077044, 45.20258290427071, 43.23191744940621, 42.30482278551374, 41.962974888937815, 43.27578837530953, 38.7287586757115, 39.71243946892874, 39.92107302801949, 43.962715080806184, 44.358126640319824, 43.15021358217512, 43.9968307358878, 49.38023941857474, 49.94700745173863, 54.19389581680298, 55.051866327013286, 58.53399426596505, 48.93438046319144, 50.63143975394112, 57.88671050752912, 56.9061598777771, 57.358522347041536, 56.42037309919085, 44.93403850282942, 38.813769885471885, 36.17446538380214, 42.4322075843811, 44.72768742697579, 45.66142456872122, 42.09370871952602, 42.557834489004954, 38.723533630371094, 38.41389758246285, 35.38572325025286, 38.18707363946097, 32.3468347958156, 38.889901297433035, 56.90989106042044, 52.37375613621303, 53.26901762826102, 53.556360380990164, 54.85589585985456, 52.60072946548462, 53.45250218255179, 52.03058808190482, 52.293049335479736, 54.32548080171858, 53.90632029942104, 53.64131947926113, 52.689649036952424, 52.125788824898855, 54.617044585091726, 57.72487654004778, 52.63733604976109, 52.03189434323992, 49.98118911470686, 54.64869015557425, 50.60490805762154, 50.125225271497456, 43.291185583387104, 46.892944131578716, 49.91552168982369, 42.34155443736485, 41.43120493207659, 42.40355668749128, 37.766030175345286, 42.76126732145037, 42.608514649527415, 45.36486503056118, 45.44371318817139, 45.56964233943394, 44.44551065989903, 45.3769896371024, 43.74286018099104, 42.01220635005406, 43.13899918964931, 43.024221897125244, 43.55348702839443, 44.37051180430821, 44.82891573224749, 45.02034207752773, 45.43364177431379, 47.022455079214915, 50.583274841308594, 58.243927819388254, 58.010871342250276, 64.35865524836949, 62.20410224369594, 68.79422542027065, 62.88119724818638, 57.20886509759085, 57.3226592200143, 64.54901504516602, 34.453768321446006, 0.04217096497969968, 1.4899751799447196, 0.9794553113835198, 0.23388654259698732, 8.726540514401027, 63.03585720062256, 58.65312807900565, 49.59380619866507, 36.76716756820679, 35.195523262023926, 25.66324097769601, 36.22839035306658, 43.96987172535488, 15.93826082774571, 1.4456540324858256, 0.0781129581321563, 0.05868137760886124, 0.017248063314972178, 0.05325550965166517, 0.037828211938696246, 0.018028743298990384, 0.07636288739740849, 0.011633487983739801, 0.020066536630370786, 0.040620617635015926, 0.012049764976836741, 0.09211026704204933, 0.03668994569618787, 0.05270595056936145, 0.03843046944322331, 0.20553692882614477, 0.08733525326741592, 0.07905504972274814, 6.3529316527502875, 54.6637191091265, 48.99513898577009, 37.87887934276036, 29.17681646347046, 50.79250247137887, 52.302109786442344, 89.17233998434884, 18.606773819242203, 0.5941431756530489, 0.26469944204602924, 3.04890775680542, 10.257641213280813, 78.22689138139997, 75.97782897949219, 81.88784163338798, 77.72388349260602, 66.56616742270333, 58.354480607169016, 70.418443271092, 72.39768627711705, 74.12379946027482, 71.83162348611015, 71.31448296138218, 72.44032042367118, 68.38312830243791, 65.5349783216204, 66.86230659484863, 64.53266593388149, 64.42095974513462, 62.89522566114153, 63.78566510336739, 61.14583601270403, 60.051849092756, 58.06662368774414, 56.625237260546, 49.50189890180315, 50.54980884279524, 50.81426770346505, 49.66052280153547, 49.253066539764404, 48.76451437813895, 45.241534505571636, 44.7253771509443, 46.69577162606375, 47.91907146998814, 51.040007727486746, 49.271058900015696, 45.81373603003365, 46.408025877816335, 43.330595765795024, 44.65850073950631, 43.25218187059675, 44.89510774612427, 41.276496342250276, 43.12665918895176, 42.581982953207834, 45.91022566386631, 47.826660428728374, 46.39022806712559, 45.5973413331168, 51.07112176077706, 52.061003821236746, 54.403752258845735, 58.18523291179112, 59.474029949733186, 50.40284749439785, 51.6961087499346, 60.33464077540806, 59.8645465033395, 59.93413271222796, 59.31383923121861, 47.863416399274556, 42.20168719972883, 39.857441425323486, 46.04349211284092, 45.54101228713989, 47.41846070970808, 43.986957345690044, 45.79055336543492, 40.33563034875052, 40.196485723767964, 38.8112998008728, 42.7934444291251, 36.27245582853045, 41.70478330339704, 59.067574228559224, 54.127589157649446, 57.03182847159249, 53.76922539302281, 56.033587728227886, 54.40867158344814, 54.52505390984671, 54.395622866494314, 54.85907118661063, 54.57553257261004, 57.41095345360892, 56.374376024518696, 55.638749395098, 53.995771408081055, 57.714805126190186, 58.19214636938912, 54.66098846708025, 53.983542578560964, 54.52665546962193, 55.673059599740164, 51.75593621390206, 50.14116791316441, 44.450836454119, 49.81074285507202, 50.81910364968436, 45.851933751787456, 44.22881371634347, 43.2473007610866, 41.3438834462847, 45.11783572605678, 46.24088001251221, 46.773612294878276, 47.41311059679304, 47.799322741372244, 46.12166976928711, 46.840037073407856, 46.35636254719326, 44.927243164607454, 45.85007858276367, 46.78532348360334, 45.86389854976109, 48.097973687308176, 48.27300923211234, 48.42795753479004, 49.43126351492745, 50.33103438786098, 52.980486733572825, 59.16014507838658, 60.77531637464251, 66.94875608171735, 64.77164922441754, 71.69795404161725, 63.566185406276155, 59.0635164805821, 58.85856546674456, 65.36658872876848, 39.56829214096069, 0.7412566244602203, 1.0826220554964883, 1.0938626123326165, 0.32013993284532, 8.631200807435171, 69.59171186174665, 65.1897918156215, 57.31756271634783, 43.29093892233712, 31.75649152483259, 31.914354596819194, 47.15920604978289, 52.11368158885411, 27.01171088218689, 1.7645405211618967, 0.06125833147338458, 0.06790528087211506, 0.10182242374867201, 0.0466540424552347, 0.010736420584310378, 0.04948438165177192, 0.02129286145126181, 0.013249529392591544, 0.12020821895982538, 0.12993328140250274, 0.13683171623519488, 0.2534194758960179, 0.2308842965534755, 0.23552420043519565, 0.21393104482974323, 0.28462519283805576, 0.288778261414596, 0.4058628986988749, 9.262793796403066, 66.20025444030762, 61.639359610421316, 41.365242208753315, 63.630532673427034, 85.65982409885952, 54.001034668513704, 99.68936961037772, 22.358156612941197, 0.5071955355150359, 0.42655419984034126, 5.382081142493656, 15.746631247656685, 84.50853538513184, 79.58147743770054, 86.30720860617501, 79.41016265324184, 70.75534752437046, 59.33845669882638, 73.9289024897984, 72.93694291796002, 77.46339552743095, 72.45089558192662, 76.39971664973667, 76.07732718331474, 73.80879592895508, 70.58959129878453, 69.21904523032052, 66.04848493848527, 66.74981525966099, 64.05071803501674, 65.87673241751534, 63.56528908865792, 63.60041223253523, 59.825629643031526, 59.95895167759487, 52.54669679914202, 53.23284878049578, 54.41270153863089, 52.55377006530762, 50.894436018807546, 51.70923042297363, 47.95674112864903, 47.25041505268642, 50.87218441282, 51.22973871231079, 52.64654588699341, 51.762391090393066, 45.951320784432546, 47.27053356170654, 43.99284594399588, 45.182415757860454, 45.19819164276123, 47.6769232749939, 44.990805285317556, 44.23989609309605, 44.94082341875349, 49.07440750939505, 50.71382801873343, 48.81385701043265, 47.33776085717337, 54.28559814180647, 55.5110901423863, 56.57278878348214, 61.50026362282889, 63.40799576895577, 54.10881165095738, 55.18791552952358, 63.59498568943569, 63.1234461920602, 61.590367862156455, 60.72583825247628, 49.15675755909511, 48.1806572505406, 44.52630083901541, 51.63430452346802, 50.140869140625, 50.83939586366926, 48.67451088769095, 48.60365315846035, 41.30200317927769, 45.04217331750052, 43.024659633636475, 45.19948053359985, 37.16411815370832, 41.230197020939414, 61.258653913225444, 59.60881110600063, 59.77836799621582, 57.42492628097534, 59.88431412833077, 57.83062464850289, 57.500408036368235, 58.39303616115025, 57.611937046051025, 58.197604179382324, 59.73123141697475, 58.7766809463501, 58.05590261731829, 57.05738394601004, 59.45878560202462, 60.83386189596993, 56.032045228140696, 58.55636051722935, 55.29685980933053, 59.78619861602783, 56.683296407972065, 55.1360159601484, 47.35331439971924, 52.00774587903704, 53.74996498652867, 48.3840206010001, 47.227479049137656, 48.41148335593087, 44.9943071774074, 48.874778815678184, 49.34573119027274, 49.96934591020857, 49.83211203983852, 49.665601934705464, 50.2351735660008, 50.45905842099871, 49.629749229976106, 45.8766519682748, 48.66529410226004, 48.97197369166783, 49.42955078397478, 50.83757890973772, 49.96444395610264, 50.33352184295654, 51.388640539986746, 53.11094611031668, 55.4012564931597, 63.52010495322091, 62.69597911834717, 69.32472733088902, 67.39124516078404, 73.77266529628209, 66.51138087681362, 62.77704375130789, 59.627473967415945, 66.5179191316877, 39.90505395616804, 0.636739758508546, 5.72574599300112, 2.855746098927089, 0.5553089337689536, 12.870068345751081, 76.77771949768066, 70.30906472887311, 63.399261883326936, 53.72786624091012, 52.78892489842006, 38.12058285304478, 57.4045159476144, 64.68346268790108, 38.90515259334019, 2.32433288863727, 0.1857596414961985, 0.18594176029520376, 0.20920825111014502, 0.14024964640183107, 0.15049374742167337, 0.1527035052755049, 0.12374395637639932, 0.13501925420548233], [0.059742429958922524, 0.03699524574247854, 0.02734834883761193, 0.03115376490833504, 0.06652088622961726, 0.06728674870516572, 0.09479196635740143, 0.06491684301623277, 0.17077038224254334, 0.11212126897381884, 6.21085228238787, 45.367272581372944, 47.522044454302105, 24.44075754710606, 31.398020063127788, 45.27876990182059, 46.15207508632115, 76.01272283281598, 5.796420897756304, 0.15503082610666752, 0.3173030050737517, 2.2498898889337267, 16.938308102743967, 55.794656549181255, 70.76977893284389, 79.30684294019426, 71.69384765625, 63.38288497924805, 58.517520087105886, 69.1031631742205, 70.94558225359235, 71.13636589050293, 65.1607483455113, 64.29447473798479, 64.2894789831979, 71.32263319832938, 67.12122426714215, 65.04241357530866, 64.04080990382603, 66.22521931784493, 62.73778642926897, 64.84928144727434, 60.68045261928013, 59.6772369657244, 56.22679281234741, 51.91133267538888, 52.94555466515677, 48.67625835963658, 47.345567158290315, 45.95413133076259, 49.4751935005188, 44.83923033305577, 42.08647911889212, 43.45195647648403, 43.72719546726772, 46.616204329899375, 47.195176873888286, 45.87643657411848, 45.4098094531468, 47.71564211164202, 46.32769775390625, 44.58918898446219, 42.37259898866926, 42.26683350971767, 39.56630148206438, 40.14751482009888, 39.53578846795218, 43.48690938949585, 42.3993947165353, 44.30613327026367, 44.452438013894216, 47.72668627330235, 52.777213709695, 54.18425866535732, 53.34676102229527, 58.27620915004185, 53.81798437663487, 48.89883695329939, 54.14885411943708, 56.720861843654085, 54.2632840020316, 60.443387031555176, 45.704996722085134, 38.00316524505615, 35.80468225479126, 40.27574382509504, 42.07906886509487, 40.35951478140694, 41.91669641222273, 43.29650442940848, 44.96922765459333, 38.74734510694231, 36.13679225104195, 41.38544062205723, 40.90890189579555, 46.05171530587332, 54.74177169799805, 53.67763423919678, 51.81566640308925, 52.54605061667306, 53.187775816236226, 51.777576378413606, 50.20694650922503, 51.50079836164202, 50.76438658578055, 53.849306855882915, 51.36600678307669, 54.51037584032331, 54.12297207968575, 57.37244653701782, 54.13091734477452, 53.110477106911794, 51.801380906786235, 54.111295631953645, 55.08328260694231, 50.38492809023176, 47.301922048841206, 42.57787309374128, 45.254628385816304, 51.577773979731965, 52.096144335610525, 45.289504868643625, 41.199954986572266, 42.03230054037911, 37.63863148008074, 40.16505207334246, 44.93054355893816, 43.45415905543736, 44.522934436798096, 43.425619329724995, 43.50183064596993, 43.85122081211635, 43.80130842753819, 43.9328829901559, 41.7768361227853, 44.327360016959055, 44.4538311277117, 45.673792362213135, 47.31167731966291, 47.250633920942036, 50.29370171683175, 53.78250340053013, 56.80553606578282, 59.54495716094971, 63.79636532919747, 64.2940786906651, 66.53158623831612, 64.84423010689872, 57.84297159739903, 57.2838465826852, 66.92298521314348, 63.87583882468087, 62.17931801932198, 6.564868211746216, 1.569862853203501, 0.12908931954630784, 0.03307097578155143, 0.7632916963526181, 49.12030383518764, 62.499560492379324, 54.9148930140904, 38.56849152701241, 32.572543552943635, 37.25442041669573, 30.062551975250244, 33.43549592154366, 17.910774503435405, 1.4548316257340568, 0.050510438558246405, 0.021679071709513664, 0.0528632621280849, 0.042282543278166225, 0.04667005927434989, 0.004442754683883062, 0.06826546761606421, 0.04287569823541811, 0.035565063556922336, 0.022779965939532434, 0.033526082789259296, 0.04460949770041874, 0.054420099660222016, 0.07176496447729212, 0.08362948854586907, 0.0772184386317219, 0.19727622637791292, 0.17538766376674175, 10.668270196233477, 58.889005524771555, 54.15545490809849, 27.55461880138942, 26.814432416643413, 51.02366556440081, 53.17551919392177, 83.52517768314907, 5.912986048630305, 0.21606974649642194, 0.06185635831207037, 4.371622860431671, 27.09302565029689, 67.52583176749093, 71.96828065599713, 81.43006651742118, 75.75531986781529, 65.46446800231934, 61.759299414498464, 73.13206223079136, 72.08653204781669, 74.32930632999965, 67.81675284249442, 65.95672702789307, 67.60829993656704, 75.9829706464495, 69.66309765407017, 69.74147333417619, 67.46269348689488, 68.9844115121024, 65.52156135014125, 66.66951492854527, 65.32004969460624, 61.77393232073103, 58.76770387377058, 55.731980323791504, 53.81171710150582, 50.972075189862935, 49.17791829790388, 48.87960433959961, 50.98078128269741, 46.68371997560774, 44.69860226767403, 45.45337118421282, 45.88267258235386, 48.868237086704795, 49.69257831573486, 48.16823039736067, 46.79256698063442, 47.856315340314595, 44.76367562157767, 45.79216187340872, 42.500956535339355, 44.75619241169521, 41.01507731846401, 42.322950635637554, 42.20158297674996, 44.339349133627756, 45.00378452028547, 46.10996205466134, 47.14712313243321, 49.98479175567627, 54.93082523345947, 56.697950158800396, 56.64724220548357, 59.98888451712472, 57.08437769753592, 50.45656749180385, 57.46180037089756, 59.368486813136506, 57.54156569072178, 61.304247992379324, 47.32766512462071, 40.527445793151855, 41.27003104346139, 44.21558434622628, 44.1753716468811, 42.44376243863787, 45.148911544254844, 44.86628314426967, 47.70821796144758, 42.0459919657026, 38.26286806379046, 44.123329639434814, 44.13241440909249, 46.92452369417463, 57.2338855607169, 56.08065135138375, 54.81638145446777, 53.51022434234619, 55.971915517534526, 52.38390398025513, 52.288008417402, 52.848488330841064, 54.33098724910191, 55.641066619328086, 54.625952175685335, 55.37019109725952, 56.343237672533306, 59.239875657217844, 55.983432156699045, 55.02428892680577, 55.14957536969866, 55.75595160893032, 56.50896610532488, 51.989934171949116, 48.70454100200108, 44.10042837687901, 47.708374295915874, 53.93403318950108, 52.95845399584089, 47.74869121823992, 43.568342276981895, 43.13891928536551, 40.643484183720176, 42.301668303353445, 46.302104064396445, 45.923378603799, 44.72573150907244, 46.205687386649, 45.57694142205374, 45.49206222806658, 45.6279307774135, 46.51197440283639, 44.91059875488281, 47.601580483572825, 47.46035834721157, 48.975437368665425, 48.52224806376866, 49.14481707981655, 53.17670733588082, 57.23493126460484, 61.09941509791783, 62.16525486537388, 66.51199231828961, 66.42455618722099, 69.2921541758946, 64.41815267290387, 60.07083851950509, 60.24022170475551, 68.19790322440011, 63.240919385637554, 67.04311261858258, 9.35359719821385, 1.1184957133872169, 0.4096623419650963, 0.09598827109272991, 0.6672451187457357, 49.37964882169451, 71.04116167340959, 58.818884304591585, 47.93971109390259, 31.648221220288956, 35.06613738196236, 43.289240087781636, 45.48303304399763, 27.57898439679827, 2.1039112763745442, 0.02480071616758193, 0.04660734228257622, 0.07545968943408557, 0.014325292381857122, 0.038934688815580945, 0.02212125771412892, 0.023512895717950802, 0.06102462365691151, 0.16379278951457568, 0.15159340841429575, 0.11712570222360746, 0.12675601403628076, 0.18855192166353973, 0.3253942908985274, 0.2544364370405674, 0.12164237057524067, 0.35191089659929276, 0.3410742038062641, 13.436957103865486, 74.1583389554705, 66.76706763676235, 35.22594247545515, 52.88348988124302, 69.49487481798444, 55.652670110974995, 90.85526316506522, 7.254819989204407, 0.304926689182009, 0.4918212890625, 7.228903642722538, 30.734790188925608, 73.1895307813372, 75.77935368674142, 85.4802131652832, 78.77430520738874, 69.6745274407523, 63.69889599936349, 77.0015070778983, 76.406539780753, 76.66489464896065, 69.41851411546979, 67.25627640315464, 71.01960836138043, 78.59850188664028, 73.82044805799211, 73.55251162392753, 69.68109348842076, 72.88532475062779, 69.14357389722551, 70.97117941720145, 66.60827350616455, 65.27083560398647, 62.21626159123012, 58.17146158218384, 58.7104993547712, 54.73260007585798, 53.34315838132586, 51.53594582421439, 54.06975930077689, 50.27599423272269, 47.25156845365252, 49.92283814293997, 48.98342432294573, 52.37781735828945, 51.63030930927822, 49.80799136843, 47.8253367968968, 48.865881647382466, 47.6002151625497, 46.146200384412495, 45.37876837594168, 47.643811634608674, 44.23241983141218, 46.40020915440151, 45.345465660095215, 49.03220067705427, 47.30219997678484, 49.39734935760498, 50.96686404091971, 52.25519902365548, 58.63301304408482, 59.310955728803364, 57.243057182856965, 62.061455726623535, 58.383746419634136, 53.87906946454729, 59.172123772757395, 61.61597892216274, 60.23998546600342, 64.28222506386894, 49.10447931289673, 46.817344256809776, 44.00362607410976, 49.41490398134504, 46.19288533074515, 46.09665278026036, 46.9718131337847, 46.55097811562674, 47.28564936774117, 43.718649183000835, 42.812371322086875, 49.390606130872456, 48.049975531441824, 50.08215338843209, 61.23052065713065, 59.198415756225586, 57.37411410467965, 56.83739703042166, 60.17624964032854, 57.58078132356916, 55.81608131953648, 56.20515264783587, 53.44204861777169, 57.88429600851876, 54.99783713476998, 57.92850739615304, 59.26106766292027, 60.330972126552034, 57.906485080718994, 58.61569118499756, 58.45834922790527, 57.81585277829851, 59.302353858947754, 54.431253228868755, 52.833789416721885, 48.76291629246303, 50.12618064880371, 55.74305575234549, 54.19916255133492, 49.42460714067732, 46.57956995282854, 47.05867256437029, 43.732215540749685, 44.92126423971993, 49.42435353142874, 48.36800152914864, 48.130866459437776, 48.30734722954886, 47.607357910701204, 47.7668433870588, 48.54921054840088, 50.535245418548584, 47.49970252173287, 50.38680757795061, 49.299525669642854, 51.24168961388724, 52.76748275756836, 51.051368032182964, 55.81247867856707, 59.144615854535786, 62.54502255575997, 65.2251511982509, 69.77822930472237, 68.6290181023734, 72.27002007620675, 66.95549583435059, 63.536989075796946, 62.30877685546875, 69.46138450077602, 66.13671316419328, 66.36420413425991, 9.27377802985055, 3.606625327042171, 1.131588182279042, 0.09864148550799914, 0.934145565543856, 61.320604051862446, 74.61322362082345, 69.54754216330392, 52.938227789742605, 48.84523854936872, 51.513735907418386, 50.83927427019392, 59.033917154584614, 40.78905936649868, 2.852986144168036, 0.1776064054242202, 0.11206389883799212, 0.2350428748343672, 0.09553727600723505, 0.10860214887985162, 0.1105844753661326, 0.18293545661228044, 0.10643563406275851], [0.08425494177000863, 0.03168796195781656, 0.050981762552899976, 0.028702550368117433, 0.035814058767365556, 0.035895544037755044, 0.048938496836594174, 0.08835002952920538, 0.10389274265617132, 0.21883503454072134, 11.354663627488272, 47.36158275604248, 37.35342182431902, 31.539721625191824, 28.195565802710398, 40.43824134554182, 56.520236083439414, 64.68342099870954, 0.7497226244636944, 0.05486671819484659, 0.5210766792297363, 2.9832722502095357, 47.34326730455671, 72.38541575840541, 75.39418029785156, 77.85899816240583, 71.68820571899414, 60.370257241385325, 62.98503112792969, 68.56843675885881, 73.73559665679932, 72.06559712546212, 64.58682714189801, 65.36581747872489, 62.93663692474365, 62.423825127737864, 65.67597811562675, 68.92073822021484, 66.05787890298026, 65.87894194466728, 64.75026961735317, 62.16881234305245, 59.5923855645316, 57.58682625634329, 57.029226371220176, 55.197524888174875, 52.34091547557286, 48.25227928161621, 47.43643569946289, 47.4560261453901, 46.53354508536202, 44.77484137671334, 43.31128672191075, 43.317929199763704, 44.276867457798545, 46.39620699201311, 48.50030565261841, 48.67595263889858, 44.19687284742083, 46.462510177067344, 42.81282295499529, 42.76765966415405, 42.57610477719988, 43.54676464625767, 38.49345793042864, 39.270700795309885, 38.654280935014995, 41.155576842171804, 39.3452410697937, 44.184445994240896, 44.74360922404698, 48.11068194253104, 52.02470643179757, 51.97866071973528, 54.808870451790945, 55.357673917497905, 55.59963798522949, 55.63932262148176, 52.24537427084786, 55.50625767026629, 56.371339661734446, 56.71112394332886, 46.230971881321494, 40.09065423692976, 37.512726647513254, 39.33447483607701, 45.36124154499599, 42.20535932268415, 41.0991644178118, 45.05754273278372, 45.08586706433977, 44.519613197871614, 37.067562511989046, 41.69801228387015, 40.39149733952114, 48.030176639556885, 53.3520416532244, 52.45291001456124, 50.505145822252544, 47.957105909075054, 49.09331008366176, 49.12875631877354, 48.26876735687256, 50.88365241459438, 51.10011311939785, 51.32337611062186, 55.85842364174979, 56.139679772513254, 55.061743191310335, 51.57714516775948, 50.21184498923165, 54.73210327965872, 55.60874707358224, 51.32875749043056, 48.3555121421814, 44.16920164653233, 42.034412792750764, 43.64509902681623, 42.24886546816145, 42.868120193481445, 49.449311460767476, 48.97279357910156, 38.73092998777117, 41.568807056971956, 37.20977129255022, 39.00422348294939, 42.00359753199986, 43.185034479413716, 43.36329051426479, 45.01704168319702, 44.578697204589844, 43.75174345288958, 43.24118982042585, 42.12438154220581, 43.89331647327968, 44.57710954121181, 48.57278578622, 50.09302384512765, 51.44318389892578, 54.10415288380214, 56.006010328020366, 57.617648465292795, 62.86502184186663, 61.32043729509626, 66.72343989780971, 63.71807302747454, 65.40044730050224, 57.96357495444161, 62.68818323952811, 65.94892420087541, 67.63709327152797, 63.06560243879046, 72.79085009438651, 32.220377581460134, 0.3664339344416346, 0.16530874531183923, 0.3553610843207155, 0.08461563062987157, 25.48490677561079, 67.74779197147915, 50.410570417131694, 44.186690262385774, 31.03791924885341, 23.2409565108163, 19.982155833925518, 25.87511239733015, 21.964086055755615, 2.645393294947488, 0.1483992590968098, 0.029021173449499265, 0.013245598978496023, 0.03544819947066052, 0.014758743944444826, 0.034618622556860955, 0.07179764272379023, 0.037399584760091135, 0.04809462658262678, 0.08532909663128001, 0.028851346312356845, 0.01194827225325363, 0.06199917636279549, 0.007441591937094927, 0.06165008366640125, 0.055974983011505434, 0.1519224571862391, 0.23674768049802097, 18.76912890161787, 61.048248563494, 51.35923228945051, 43.02781758989607, 31.278299127306255, 50.44128492900303, 64.20808778490338, 68.84849779946464, 0.7917578145861626, 0.0185435681736895, 1.2561888162578856, 4.597608242716108, 59.05103751591274, 77.16834027426583, 78.75886631011963, 81.31287819998605, 74.97145189557756, 61.135385922023225, 66.8606459753854, 73.08412660871232, 74.85810593196324, 74.82531043461391, 65.6919172831944, 66.40337807791573, 65.02837821415493, 66.35937513623918, 68.78942421504429, 71.48687471662248, 70.05209950038365, 69.90950856889997, 67.73277691432408, 64.8096558707101, 62.66206496102469, 61.00913715362549, 61.68729523250035, 58.62813540867397, 54.75748157501221, 51.257594040461946, 49.14822517122541, 50.842057023729595, 48.58425031389509, 47.42594739368984, 44.695044789995464, 45.79613971710205, 46.34030178615025, 48.32504429136004, 50.27963856288365, 49.14406320026943, 44.18091630935669, 47.34935392652239, 42.80345678329468, 41.34160096304757, 43.14693055834089, 45.700417859213694, 41.20459638323103, 41.664504596165244, 39.73944016865322, 42.552414894104004, 42.20161771774292, 45.49189894539969, 46.625431537628174, 50.44516202381679, 54.14254862921578, 55.16587584359305, 56.99090358189174, 58.47199548993792, 58.09335688182286, 58.52021598815918, 55.64245278494698, 57.010077135903494, 59.79701696123396, 58.539976664951865, 46.68813902991158, 43.128059250967844, 40.64266082218715, 44.80584076472691, 47.66871050425938, 43.372889450618196, 43.287541253226145, 46.14106566565377, 47.348398549216135, 45.757375717163086, 43.61366537639073, 45.455302783421104, 45.256497451237266, 50.6203921181815, 56.62710632596697, 54.48050206048148, 52.39402750560215, 49.5221529006958, 49.999674797058105, 50.82642010280064, 50.36308990206037, 52.984131063733784, 51.44305535725185, 55.682391030447825, 56.62979875292097, 58.1333646093096, 55.682391030447825, 53.552108083452495, 53.14499575751168, 58.04769679478237, 56.063833236694336, 51.85737991333008, 49.15398522785732, 44.75132519858224, 43.49956553322928, 44.74529416220528, 44.327134200504844, 41.427581446511404, 49.87021943501064, 50.32899856567383, 42.28506210872105, 44.852959973471506, 39.78958184378487, 42.107740606580464, 44.476197378976, 46.20181029183524, 47.31797586168562, 46.79548869814192, 46.31120620455061, 46.12325395856585, 46.42029987062727, 45.59279373713902, 47.07568522862026, 48.3654967035566, 51.935533251081196, 51.85219308308193, 53.463327475956504, 56.94015046528408, 58.94190216064453, 60.99528244563511, 63.93826144082205, 64.36221967424665, 66.93028776986259, 66.78425053187779, 66.21196910313198, 59.89725167410714, 64.48883669716972, 68.32260254451207, 69.72069822038922, 66.8620912006923, 74.16878904615129, 37.462963649204795, 0.2409066387585231, 0.17052600107022695, 0.6323728156941277, 0.11097134889236518, 25.93400706563677, 76.10630117143903, 55.582243170057026, 53.3573431287493, 33.25673614229475, 25.3268369947161, 33.51944753101894, 35.394519669669016, 27.730093819754465, 4.052808242184775, 0.11151087922709328, 0.05833895491170032, 0.12065519711800984, 0.04724339083103197, 0.06359083631208964, 0.01577454649044999, 0.028455857087724974, 0.054755262032683404, 0.17036053352057934, 0.11846523891602244, 0.18761356201555046, 0.09006998009447541, 0.27829006420714514, 0.07416897333626236, 0.16591432424528257, 0.15311125053891114, 0.2329227514564991, 0.536823359983308, 22.476307255881174, 75.4450272151402, 53.09400987625122, 46.4014424596514, 41.38043097087315, 58.73829909733364, 68.22774573734829, 78.91657652173723, 1.10230966763837, 0.12730355108422892, 1.924426713160106, 7.79726585320064, 62.36059652056013, 80.5151902607509, 83.17650318145752, 84.27931431361607, 78.58587006160191, 65.50824165344238, 70.76027379717145, 75.99127374376569, 74.27713925497872, 75.29383441380092, 68.97846385410854, 66.90260614667619, 66.39891733442033, 67.96899482182094, 70.6633186340332, 74.78715787615094, 73.23805700029645, 72.49885204860142, 70.79104042053223, 66.82133306775773, 65.9717629296439, 62.67432158333914, 63.35894843510219, 60.80975859505789, 58.798595564705984, 54.33266176496233, 52.466104643685476, 53.51279517582485, 50.794312477111816, 50.70861339569092, 48.62045737675258, 49.33536100387573, 50.10425213405064, 51.62891272136143, 52.37026466642107, 50.824634415762766, 44.934104510716026, 47.453743662152974, 43.533750670296804, 41.903744970049175, 43.89791965484619, 47.18795074735369, 43.40629291534424, 42.76295920780727, 42.18016862869263, 47.96241780689785, 42.95816189902169, 48.862313747406006, 48.81049060821533, 51.95578030177525, 55.539998122623985, 56.489170687539236, 58.55654117039272, 62.03071689605713, 60.53112193516323, 60.09214169638497, 56.76906844547817, 59.86502592904227, 62.6139486857823, 60.03772340502058, 48.71866321563721, 48.728307315281455, 45.709068366459434, 46.86110053743635, 49.36260141645159, 45.692778314862935, 46.219489983149934, 47.36542163576399, 50.81808921269008, 47.10899141856602, 45.84182759693691, 48.78291668210711, 46.647794314793174, 54.4588896887643, 57.31991468157087, 59.675194195338655, 56.23368195125035, 52.76543303898403, 54.09030164991106, 53.23984214237758, 52.407562596457346, 57.39476415089199, 54.587775298527305, 57.920308521815706, 58.955326080322266, 60.13861819675991, 59.34573841094971, 56.065942014966694, 55.83790213721139, 60.051842144557405, 60.53065640585763, 55.15489421572004, 53.06031806128365, 47.79457712173462, 46.80145372663225, 47.12482288905552, 44.10630655288696, 43.29407603400094, 51.022435733250205, 51.53707143238613, 43.854865142277305, 46.97444302695138, 42.10555192402431, 46.04053912843977, 46.32080166680472, 49.996047837393625, 49.32751996176583, 49.07620709283011, 49.54477970940726, 47.81385142462594, 48.38744953700474, 46.68266384942191, 49.07871886662075, 50.126878942762104, 54.954435212271555, 55.368513107299805, 55.21534701756069, 58.88688632420131, 62.00965690612793, 63.13293743133545, 67.35601084572929, 66.48820168631417, 69.25223677498954, 68.56446933746338, 68.49710655212402, 62.73574365888323, 67.64823818206787, 70.2770335333688, 73.26683643886021, 68.42683941977364, 78.25164086478097, 37.03181403023856, 0.6098913763250623, 1.9787064748150962, 1.4584514200687408, 0.35602645576000214, 32.21618086951119, 79.12541852678571, 62.79001603807722, 57.19562530517578, 51.05253880364554, 37.43711287634713, 38.21282366343907, 53.603173868996755, 39.73214456013271, 5.011629249368395, 0.3015990177435534, 0.20584121106990746, 0.3058378802878516, 0.1333845140678542, 0.13984051692698682, 0.1022759090576853, 0.1859281895948308, 0.17572945542633533], [0.034737956510590653, 0.061941561954362054, 0.06791560138974871, 0.03795167138533933, 0.027578769151919653, 0.06482471831675087, 0.06389848408954484, 0.13936046697199345, 0.22738437221518584, 0.10321067925542593, 16.67762385095869, 55.12323474884033, 35.517916202545166, 18.300625767026627, 36.32079792022705, 43.86590582983834, 64.40226909092495, 45.02002246039254, 0.04979039755250726, 0.4306463359722069, 1.0182395045246397, 5.647216584001269, 78.06990378243583, 77.96383953094482, 76.1524441582816, 76.69505677904401, 61.75362968444824, 58.66455091748919, 70.83090918404716, 71.29675115857805, 72.39289202008928, 66.65586171831403, 70.3656508581979, 67.80971431732178, 70.68285696847099, 67.02954278673444, 65.59390599387032, 64.79742009299142, 64.61339010511125, 62.509850774492534, 62.862249510628835, 62.16731153215681, 61.341670989990234, 60.44135815756661, 56.02808128084455, 54.20320292881557, 51.68652023587908, 47.228542123522075, 46.44549751281738, 45.8154696055821, 47.64950915745327, 44.80215127127511, 41.67352335793631, 42.256890637534006, 45.22112417221069, 44.26291200092861, 47.11621059690203, 48.45982197352818, 43.98996244158064, 43.82751703262329, 44.342632157461985, 43.64814233779907, 42.94494989940098, 40.503804547446116, 39.38963311059134, 38.77053819383894, 37.71612473896572, 39.270263058798655, 39.30257565634591, 44.552912439618794, 45.00728988647461, 44.7306821005685, 50.79383305140904, 52.40546076638358, 55.32715048108782, 56.52636439459664, 54.46233252116612, 56.14962611879621, 54.57634203774588, 51.45084776197161, 54.91445180347988, 56.11315155029297, 45.64826120649065, 40.94654723576137, 41.26761654445103, 43.97171299798148, 44.65775033405849, 42.597658089229036, 41.76116793496268, 40.211125578199116, 38.722161361149375, 42.85761799131121, 39.66673074449812, 44.3639040674482, 44.360040869031636, 47.59308978489467, 50.64665978295462, 53.33196830749512, 50.66719170979091, 47.53275510243007, 46.92121982574463, 48.065994603293284, 50.2733712877546, 50.13378197806222, 50.741940430232454, 52.03800528390067, 53.86265434537615, 51.04348530088152, 52.7141101700919, 51.521913937159944, 55.538688387189595, 54.80824858801705, 50.467715876443044, 47.13068716866629, 42.54320853097098, 41.591204575129915, 44.32951395852225, 44.07136753627232, 42.33134753363473, 40.550642354147776, 43.9160544531686, 47.26506532941546, 39.88933365685599, 41.24333953857422, 40.58668960843767, 38.65579216820853, 41.06238412857056, 42.01412057876587, 42.85036407198225, 43.89872564588274, 45.16752576828003, 42.946537562779014, 44.55573688234602, 44.17609773363386, 44.33925880704607, 48.524082388196675, 51.67200892312186, 53.53747865131923, 55.878093991960796, 58.08121143068586, 58.62491839272635, 62.23828738076346, 62.7539826801845, 62.987421308244976, 63.4409510748727, 64.32960483006069, 62.345602308000835, 61.150949886866975, 67.0898323059082, 66.30305303846086, 64.70598874773297, 68.43150166102818, 66.32196603502545, 70.93264470781598, 5.672804193837302, 1.620883258325713, 0.7620448746851513, 0.4269918277859688, 9.276266353470938, 61.464862551007954, 58.32157393864223, 45.608809334891184, 33.69788074493408, 18.2008444241115, 16.617207527160645, 21.230090515954153, 16.121151311056956, 3.0588897126061574, 0.13802734922085488, 0.03568408199186836, 0.03719466379178422, 0.038340746757707427, 0.06383523105510644, 0.0363341422884592, 0.04312170449910419, 0.04036621789314917, 0.0498461052775383, 0.06740255427679845, 0.04809653326602919, 0.019362507354734198, 0.04317534947767854, 0.017974872707522342, 0.04088811988809279, 0.07983056775161199, 0.1696019856525319, 0.07928451669535466, 23.80133741242545, 64.56060464041573, 47.80683026994978, 22.867989369801112, 37.060100146702354, 51.93025262015206, 70.55159854888916, 47.9173378944397, 0.23513439563768251, 0.17994184153420584, 2.69379574911935, 9.83372380052294, 80.7121091570173, 77.76380784170968, 79.93094403403146, 79.41247640337262, 64.39251382010323, 62.204491342817036, 72.71802602495465, 73.8226853779384, 76.12467915671212, 70.06792054857526, 70.30040727342877, 69.186082976205, 71.62378896985734, 69.52606528145927, 65.60339028494698, 67.27505043574742, 67.06750079563686, 67.07711710248674, 67.02570043291364, 66.62980597359794, 65.3976263318743, 64.21159662519182, 58.40009553091866, 55.49341739927019, 54.0390864780971, 48.4298335484096, 49.64494841439383, 48.916037218911306, 50.78482471193586, 47.399255888802664, 44.15629536764962, 45.21801832744053, 46.41467530386788, 47.17827190671648, 49.73348930903843, 49.41568565368652, 45.27081421443394, 44.92579099110195, 44.31478377750942, 42.40420981815883, 43.320194312504356, 40.333629267556326, 44.05813816615513, 39.80759852273123, 39.342482634953086, 42.557115350450786, 43.33578954424177, 45.04179116657802, 45.83732863834926, 46.51764760698591, 53.053050245557515, 55.424390520368306, 56.335389682224815, 57.852306502205984, 57.247601304735454, 59.1229305267334, 57.38548830577305, 53.8898218018668, 57.751050404139924, 57.694874218532014, 45.631953784397666, 43.465939726148335, 43.87176316125052, 45.881765842437744, 47.50733511788504, 43.065271854400635, 41.74831029347011, 39.299751213618684, 40.15757928575788, 43.76761313847133, 42.28506210872105, 46.615339279174805, 48.92954799107143, 52.907082489558626, 54.42060164042881, 55.66359615325928, 50.44543647766113, 51.26393774577549, 49.63287244524275, 50.173268590654644, 52.69575997761318, 51.61219882965088, 51.82425785064697, 54.56535346167428, 54.90572139195034, 53.69686337879726, 55.09875277110508, 55.00001539502825, 56.314621516636436, 55.966099875313894, 52.49883413314819, 47.74518237795149, 43.38947132655552, 43.05672557013375, 45.68647977284023, 43.816636153629844, 41.70244870867048, 41.437701497759136, 43.63219274793352, 48.63048015322004, 42.66383968080793, 44.14238854816982, 41.955616746629985, 41.00966814586094, 43.268468448093955, 45.502494948250906, 44.18674584797451, 46.955585615975515, 46.77381379263741, 45.957424776894705, 46.13268961225237, 46.873690673283164, 47.61212090083531, 52.319622720990864, 54.363133089882986, 56.81485707419259, 59.45014204297747, 61.08358015332903, 61.6113931110927, 66.27275889260429, 65.00786018371582, 66.29513904026577, 66.17362199510846, 65.82787963322231, 63.123953410557334, 64.06432260785783, 70.31002358027867, 67.88000229426792, 67.6503573826381, 71.92076192583356, 66.56814765930176, 75.90854154314313, 8.229420355388097, 1.716832778283528, 1.2419530430010386, 0.672931079353605, 8.679504684039525, 65.84702886853898, 63.95964799608503, 54.15993649618966, 41.74243906566075, 15.478413411549159, 25.287989616394043, 35.0447473526001, 16.8500486101423, 4.024267647947584, 0.15412358407463345, 0.025145152417410697, 0.013832972817389029, 0.04490559341918145, 0.04396506924448269, 0.03344202587114913, 0.09952517558953591, 0.06910659998123135, 0.10276372145329203, 0.23887103370257787, 0.29776570200920105, 0.09722545077758175, 0.1361642006252493, 0.12150681284921509, 0.149081607482263, 0.21225500905088016, 0.40440551404442104, 0.26493516511150766, 30.141403606959752, 77.94600350516183, 47.60278599602835, 27.715907335281372, 50.50065033776419, 60.06944193158831, 75.78402982439313, 54.69297797339303, 0.35303484914558275, 0.6415538830416543, 4.737751671246119, 11.072267123631068, 85.67307431357247, 81.7738425391061, 82.3357572555542, 82.98904078347343, 68.2176569529942, 66.49713012150356, 78.30451665605817, 76.11748082297188, 76.26467146192277, 72.89290523529053, 72.6185417175293, 71.40013340541294, 75.45624160766602, 73.57245990208217, 70.49693012237549, 72.6439790725708, 71.8277255467006, 70.9174906866891, 69.76746654510498, 69.12323651994977, 67.27821881430489, 67.23591818128313, 59.65443297794887, 59.440629959106445, 55.34905120304653, 52.325889996119905, 52.10885259083339, 51.431653363364084, 54.20168127332415, 50.42891018731253, 48.09734834943499, 48.37580435616629, 52.0619661467416, 48.597896575927734, 52.572915826525005, 51.23301131384713, 44.988720825740266, 44.925530433654785, 46.281909125191824, 43.60136359078543, 44.48577894483294, 41.84598459516253, 45.209979261670796, 43.25078180858067, 41.70124667031424, 46.259803431374685, 45.27421883174351, 50.12637172426496, 48.52898434230259, 49.07482092721121, 56.53556728363037, 57.04794829232352, 59.055449622017996, 61.31847790309361, 58.17076676232474, 60.51936558314732, 60.269223485674175, 57.2723890032087, 59.75072806222098, 61.298599106924875, 50.38138798304966, 47.453434467315674, 44.91684865951538, 49.07493209838867, 50.25068194525582, 43.63472189222063, 42.20612709862845, 39.68724182673863, 40.99597324643816, 45.60530744280134, 44.07769039699009, 52.54713453565325, 49.96882479531424, 54.98496559688023, 57.42360612324306, 58.73753479548863, 53.77849428994315, 54.44629955291748, 51.419844899858745, 53.22154058728899, 55.7545029095241, 54.7547960962568, 54.75959382738386, 56.72593402862549, 56.92448227746146, 56.54154620851789, 59.02045849391392, 56.56149101257324, 58.91045461382185, 58.37506117139544, 55.67063467843192, 49.66693598883492, 45.40383052825928, 45.41489553451538, 47.184903962271555, 45.34660516466413, 42.13925763538906, 41.147885186331614, 45.08776044845581, 50.4318596976144, 44.70981318610055, 46.89267315183367, 44.74045821598598, 44.356198515210835, 44.373544692993164, 45.87381362915039, 46.36945642743792, 48.78672776903425, 49.980192048209055, 47.98662880488804, 49.12752301352364, 49.77147511073521, 49.19955151421683, 55.576597758701865, 58.241089480263845, 58.39432157788958, 60.78836509159633, 62.72118023463658, 64.23280947549003, 67.16279533931187, 66.94346155439104, 68.06039142608643, 67.88369873591832, 67.58994279588971, 66.43129593985421, 65.51117379324776, 73.57234178270612, 69.41738850729806, 70.79479939596993, 74.34414768218994, 70.24213968004499, 75.5263489314488, 7.350228309631348, 3.263141129698072, 3.0741740124566213, 0.7369797910962785, 12.89356802191053, 74.72018418993268, 69.77593639918736, 61.97897366115025, 52.31366811479841, 32.285412720271516, 37.48227269308907, 55.24638114656721, 26.95593421799796, 6.405623751027243, 0.31511679238506723, 0.16942152247897216, 0.13939717571650231, 0.14908445732934134, 0.1411306019872427, 0.11691490853471415, 0.2079518349575145, 0.11806989727275712], [0.02384392581214862, 0.03981805659298386, 0.08241441553192479, 0.043463530085448704, 0.05802792124450207, 0.008027819899975188, 0.04328644262360675, 0.050861729708101065, 0.08325045888445207, 0.1392978246190718, 19.246391977582658, 49.771839891161235, 32.038626602717805, 47.65449448994228, 49.614921774183, 39.176639556884766, 70.21195670536586, 30.233731269836426, 0.5794395389301437, 0.262007476495845, 2.6671963078635077, 19.67242077418736, 87.38075392586845, 70.10961668831962, 77.94651072365897, 64.69810254233224, 59.96817193712507, 64.53328432355607, 72.42771639142717, 72.22505828312465, 67.86720371246338, 67.19650105067662, 70.85305309295654, 70.32572650909424, 68.72069958278111, 63.44275065830776, 63.089636257716585, 66.06790515354702, 64.30187456948417, 62.42176846095494, 61.31840147290911, 61.32274409702846, 60.54085636138916, 58.49646009717669, 58.83187048775809, 53.144794259752544, 49.111267702920095, 47.67921270642962, 48.63556623458862, 48.591198512486045, 45.279659271240234, 43.76100540161133, 43.80235413142613, 42.247875349862234, 43.59461688995361, 44.06165395464216, 48.33441046306065, 46.286043303353445, 42.961667265210835, 43.338210991450715, 43.326138496398926, 42.70653288705008, 41.61904600688389, 41.30042246409825, 40.973464557102744, 39.86079045704433, 38.61060455867222, 39.07387569972447, 40.46221957887922, 37.641164098467144, 41.408237661634175, 44.3793568611145, 46.37778731754848, 54.11397763660976, 54.89825555256435, 52.50742558070591, 57.64001471655709, 56.87060941968645, 53.325676713671, 51.83850513185774, 54.27921969549996, 54.736341680799214, 43.5966214452471, 35.247051102774485, 40.75257090159825, 42.88828386579241, 48.3158483505249, 49.99554756709507, 44.22474207196917, 38.1141140801566, 36.90614196232387, 40.94135693141392, 41.44070659364973, 41.25787517002651, 46.666884490421836, 49.87175498689924, 53.6696194921221, 52.0296813419887, 49.46602187837873, 44.98205402919224, 49.30463259560721, 48.6159792627607, 48.9311842918396, 51.60651520320347, 52.29055840628487, 49.73267636980329, 51.0912298474993, 51.85174492427281, 53.942673274448936, 54.716386454445974, 51.67154686791556, 48.29234606879098, 47.089821338653564, 40.45643172945295, 42.03057738712856, 42.41413531984602, 41.11833797182356, 40.78359808240618, 42.85350465774536, 42.13718359810965, 43.19784000941685, 45.75346735545567, 42.433426993233816, 40.26325791222708, 41.26386799131121, 40.08728436061314, 40.828726632254465, 44.19397892270769, 44.134373801095144, 44.584245341164724, 43.843754972730366, 44.62012583868844, 45.72392014094761, 43.47720970426287, 45.451144286564414, 48.27951274599348, 51.14187526702881, 55.834983893803184, 57.7257832799639, 62.518153871808735, 63.55390099116734, 64.42048031943185, 60.352539334978374, 64.46596322740827, 62.52551201411656, 64.10633836473737, 63.40268734523228, 64.80991990225655, 62.42048304421561, 67.9927785055978, 62.114192553928916, 67.73746694837297, 64.71192250932965, 77.13478742327008, 43.83096333912441, 0.49004667571612764, 0.17762636792446884, 0.09992361813783646, 0.8047619110771588, 47.9027293069022, 60.65222903660366, 49.520655563899446, 37.861248288835796, 32.89938334056309, 19.262412786483765, 16.17311688831874, 8.842965398515974, 4.263837192739759, 0.12028815038502216, 0.033178906954292736, 0.02028997821201171, 0.014594631768496973, 0.11572447312729699, 0.011382054288073309, 0.04511664495138185, 0.07988238747098617, 0.03442731639370322, 0.05270211684650608, 0.045140539562063556, 0.021432259685492942, 0.03369984542950988, 0.04117951335917626, 0.06829937401094607, 0.026429503856758987, 0.09526574664882251, 0.06517602982265608, 29.844024181365967, 59.44837025233677, 37.35295629501343, 48.34356818880354, 54.32875687735421, 48.19947297232491, 79.32595743451799, 32.13406358446394, 0.6681247715439115, 0.37874291251812664, 3.20950168796948, 23.89609694480896, 90.22839668818882, 75.50901317596436, 80.17214379991803, 66.79518699645996, 62.86226340702602, 69.03004728044782, 74.1361950465611, 76.88796656472343, 69.234053339277, 69.60455908094133, 73.02144690922329, 72.4285362788609, 71.15461186000279, 65.64594105311802, 66.4389875956944, 70.0816571371896, 66.86811528887067, 64.80661950792584, 65.74413299560547, 64.00214317866734, 65.1868735722133, 61.7542758669172, 60.981392996651785, 55.58209030968802, 50.1352584702628, 49.907996790749685, 50.10484620503017, 50.063275132860454, 48.44990689413888, 46.138936042785645, 46.400403703962056, 44.063884326389854, 46.73687022072928, 45.68016038622175, 51.250055244990754, 48.982097217014854, 44.20265374864851, 44.296593393598286, 42.87442568370274, 41.997076647622244, 43.11702898570469, 42.776063510349815, 42.32412140710013, 43.40754359109061, 41.65367235456194, 42.37086541312081, 43.637365681784495, 41.102034023829866, 42.967788628169465, 47.12786272593907, 49.04192120688302, 54.47006934029715, 55.27706091744559, 57.069324425288606, 57.67702777045113, 58.275733198438374, 56.52399853297642, 54.238107204437256, 56.13860280173165, 56.42806128093174, 45.78146512167794, 38.10139192853655, 41.433549949101035, 45.08375481196812, 50.432207107543945, 50.73343236105782, 42.960312366485596, 38.04267965044294, 37.492093971797395, 41.12841285978045, 42.1247741154262, 44.19370794296265, 50.61701529366629, 51.966014998299734, 55.05429472242083, 54.96306487492153, 51.6599885395595, 45.637237889426096, 49.289391721997944, 49.80574362618582, 51.37846837724958, 54.15341213771275, 54.10965585708618, 51.95921966007778, 52.80421093532017, 54.71681029456002, 56.72917536326817, 56.67621271950858, 53.71138163975307, 51.263777937207905, 48.08832958766392, 42.58585657392229, 43.914018630981445, 43.37174647194998, 41.26213788986206, 41.06760222571236, 42.04111433029175, 42.54306609289986, 42.53918204988752, 46.515788963862825, 44.75285380227225, 43.96729394367763, 42.832601002284456, 43.03501244953701, 43.575717789786204, 45.79990216663906, 46.64070020403181, 46.843730040958945, 47.14115462984358, 47.64749070576259, 46.471688747406006, 45.79210976191929, 47.32049805777413, 50.94884736197335, 54.76221329825265, 58.80593981061663, 61.3768983568464, 63.387283188956125, 66.6532005582537, 67.30008479527065, 61.43449892316546, 66.1086424418858, 65.83297266278947, 65.80309540884835, 65.8180409840175, 66.79810523986816, 65.15368202754429, 69.66160379137311, 63.68429783412388, 70.63301753997803, 68.29442759922573, 77.36176422664097, 50.39314086096627, 0.2176739118461098, 0.33656653282897814, 0.13684319704771042, 0.5274733645575387, 51.22625766481672, 66.74571582249233, 57.96107707704817, 47.106920855385916, 29.317465373447963, 30.16140399660383, 31.973869391850062, 7.186190460409437, 4.9997647660119195, 0.08330509452415363, 0.04664968965309007, 0.009963822800533047, 0.02503712285709168, 0.07613740342536143, 0.008899107209539838, 0.05615201958322099, 0.04987341970471399, 0.11936843687934534, 0.11088267115077802, 0.1780115451131548, 0.1499307126338993, 0.15099741039531572, 0.19362543656357697, 0.25799619459680145, 0.10178640032453196, 0.2285938337445259, 0.18604100282703126, 36.976638385227744, 69.70154898507255, 42.85461984361921, 69.25753130231584, 67.83401216779436, 53.15148537499564, 83.61842250823975, 37.25272853033883, 0.6475432302270616, 0.4684497745973723, 6.397033171994345, 25.866414989743912, 94.0832850592477, 77.73309680393764, 84.61167444501604, 70.56292411259243, 64.89191559382847, 74.03307683127267, 76.61565971374512, 75.84822423117501, 72.60673672812325, 72.20144135611397, 76.03679139273507, 74.9279144832066, 73.71771199362618, 71.56847436087472, 70.72576209477016, 75.86626870291573, 70.44561072758266, 67.48036970411027, 68.46533243996757, 68.18527139936174, 66.65859236036027, 63.132409368242534, 65.50287069593156, 59.99396365029471, 53.79392623901367, 52.03379120145525, 53.08492163249424, 53.37434884480068, 50.47202723366873, 48.71810041155134, 50.834271567208425, 46.46979883738926, 49.97888926097325, 47.78189318520682, 53.50593730381557, 49.18092686789376, 42.683648994990754, 44.11405726841518, 43.68223714828491, 41.8482323374067, 42.86494834082467, 43.97252593721662, 44.22769505637032, 46.391440527779714, 42.651263441358296, 44.84708874566214, 44.88258361816406, 44.092639446258545, 46.227706227983745, 51.4522374016898, 52.28538547243391, 59.53268664223807, 59.22343621935163, 58.9202515738351, 60.98570782797677, 61.94541386195591, 59.8949796131679, 55.87822948183332, 57.824121134621755, 58.984842027936665, 49.586111068725586, 42.61704008919852, 42.873546736580984, 47.688797746385845, 51.61080224173409, 49.636575835091726, 44.54461976460048, 38.53983020782471, 37.86056736537388, 43.24720696040562, 44.82892268044608, 47.730302810668945, 52.96065310069493, 55.36510501589094, 59.18877860477993, 57.76170894077846, 54.44330835342407, 49.192269802093506, 54.94087927682059, 53.67516415459769, 52.851885999952046, 54.26979793821062, 57.011331285749165, 54.66498020717076, 55.99216604232788, 56.90818875176566, 57.520936489105225, 59.23686708722796, 56.79598924091884, 55.1422415460859, 50.77091441835676, 44.00585297175816, 45.415249892643516, 44.61447695323399, 41.05301100867135, 41.491817542484824, 42.94841357639858, 42.854665006910054, 44.13761166163853, 48.74976682662964, 47.53723669052124, 46.802534171513145, 46.08080741337368, 46.53159611565726, 46.014545917510986, 48.586140223911826, 49.133074624197825, 50.5668944631304, 49.3616703578404, 50.2360976764134, 49.322645800454275, 48.81155368259975, 50.632780756269185, 53.89293112073626, 56.58451386860439, 62.59496620723179, 62.08992249625069, 66.21609633309501, 69.24251624516079, 69.43430042266846, 63.29234300340925, 68.13422993251255, 67.62048707689557, 68.43830394744873, 68.28829233986991, 69.01592854091099, 66.4232290812901, 73.88250241960797, 66.72603157588414, 73.02883979252407, 71.08709621429443, 80.84992667606899, 46.5979722567967, 0.830277107656002, 1.3055873598371233, 0.2310894855431148, 1.0339645807232176, 61.55893421173096, 74.42134911673409, 65.40520681653703, 54.83492272240775, 57.24751445225307, 36.935908045087544, 46.3504114151001, 23.64641863959176, 6.701432015214648, 0.2177636277462755, 0.1801094939666135, 0.1688630474465234, 0.13141445549471037, 0.2077413805361305, 0.1326988408608096, 0.1704212081219469, 0.14755406230688095], [0.009812474716454744, 0.042477737446980815, 0.0691170154937676, 0.030455406489116803, 0.048151019628026655, 0.042928942878331454, 0.03427704802847334, 0.008764501128877913, 0.1610598811613662, 0.033012336785239835, 30.43950911930629, 50.7766501562936, 43.18383591515677, 26.726881640298025, 43.917878355298726, 43.67420155661446, 74.71939209529332, 15.805906329836164, 0.3176215094115053, 0.7956420204469136, 1.1421824480806078, 44.46332931518555, 86.96387590680803, 72.41787774222237, 70.00695705413818, 60.97946834564209, 69.55471965244838, 71.46339675358364, 70.94073935917446, 67.81049946376255, 72.49266815185547, 68.72802993229458, 68.29649121420724, 66.24826649257115, 65.72348294939313, 64.17131096976144, 61.445087977818076, 64.27146925245012, 64.58479826790946, 64.79709352765764, 65.47950390407017, 63.462726729256765, 59.006673267909456, 54.27521753311157, 49.72100339617048, 46.701357977730886, 45.61854376111712, 47.354252406529014, 47.948549202510286, 45.718538761138916, 47.54720735549927, 42.95764773232596, 41.45292500087193, 44.538376808166504, 45.40870121547154, 45.895599705832346, 46.109420095171245, 48.34553452900478, 44.193364007132395, 43.855407101767405, 43.47539969852993, 42.87372044154576, 40.92673444747925, 40.70117507662092, 42.156034060886924, 40.19043036869594, 39.1308787209647, 37.7020720073155, 38.77841050284249, 37.54831532069615, 40.41521501541138, 43.13419451032366, 41.56399195534842, 46.160287857055664, 55.82710116250174, 55.464683123997276, 54.13765362330845, 53.63741111755371, 54.707263469696045, 49.605319363730295, 52.01286670139858, 54.01988165719168, 47.911984307425364, 49.71482297352382, 39.87913370132446, 43.93449149812971, 51.26927743639265, 58.977275439671104, 55.30670888083321, 44.487071309770855, 39.89597960880825, 40.266655581338064, 41.425274644579204, 38.54515947614397, 43.57750000272478, 47.21909604753767, 51.415471008845735, 51.65728916440691, 48.76163782392229, 42.78772258758545, 48.22779035568237, 51.356053488595144, 50.57226889474051, 53.701522145952495, 52.32518127986363, 51.14015211377825, 52.754496574401855, 56.54803582600185, 54.97140966142927, 50.03775092533657, 46.68483516148159, 45.72280495507376, 42.64144563674927, 44.20747232437134, 42.84377370561872, 40.80014174325125, 42.00422286987305, 39.44971418380737, 40.658912658691406, 39.36470992224557, 42.42264338902065, 45.99423285893032, 42.89900146211897, 41.29875489643642, 39.97273983274187, 38.00584724971226, 40.23696592875889, 43.24460138593401, 44.443766662052695, 44.10008444104876, 43.78614398411342, 44.37941939490182, 46.10241283689226, 44.198759283338276, 44.024835450308665, 47.06269557135445, 51.5862820489066, 57.68524748938424, 60.33966432298933, 60.4170047215053, 61.00177206311907, 59.824378967285156, 62.13314029148647, 62.402515002659385, 64.45100375584194, 62.15812601361956, 64.41852787562779, 62.64199161529541, 64.44097055707658, 60.17615931374686, 63.59340844835554, 63.804439135960166, 71.38728618621826, 66.79064287458147, 76.02803666251046, 5.285399998937335, 0.9994845794779914, 0.6274848665509904, 0.2303548221077238, 24.128128562654766, 64.86558192116874, 51.118498052869526, 42.573193481990266, 21.132384947368077, 17.79713671548026, 11.598404697009496, 8.889165707996913, 1.8078706817967551, 0.06300767617566244, 0.08820707577147655, 0.04749524945925389, 0.04541949887893029, 0.03502737205209477, 0.04503099347597786, 0.027816095256379673, 0.10617300029844046, 0.005265086115936616, 0.030719919795436517, 0.010914717534823077, 0.0512184559234551, 0.03412561597568648, 0.04400777963123151, 0.05396551512447851, 0.01668746616425259, 0.07948628586849996, 0.10803545678832702, 41.084618364061626, 57.0127660887582, 49.81811489377703, 30.678377764565603, 48.14574950081961, 52.171983923230854, 82.15187317984444, 16.88483476638794, 0.5509583843605859, 0.5305682442017964, 0.9976620887007032, 50.60882684162685, 86.50799764905656, 77.1920475278582, 69.8911166872297, 63.94992746625628, 69.34473119463239, 73.06160749707902, 74.70338344573975, 69.88445336478097, 73.51944514683315, 71.26279531206403, 71.06793308258057, 68.58135346003941, 68.37367875235421, 65.74737085614885, 63.18329797472273, 65.82861614227295, 67.50029713766915, 66.3582078388759, 66.24881540025983, 67.2792054585048, 58.711145537240164, 57.457016536167686, 51.452147075108115, 49.50009931836809, 46.621488434927805, 48.06265599387032, 50.249837739127024, 47.46034097671509, 49.115426199776785, 45.89103821345738, 43.683519090924946, 46.72994634083339, 47.31555094037737, 47.73337391444615, 49.958221844264436, 49.0766031401498, 44.44998182569231, 45.14960636411394, 43.87420197895595, 43.602155685424805, 40.71669387817383, 41.55389969689505, 43.00128589357649, 42.756514753614155, 40.76271179744175, 39.57170370646885, 40.682425362723215, 40.40431676592146, 43.174827575683594, 44.927211897713796, 44.7982394354684, 48.11069236482893, 57.19693851470947, 57.86639744894845, 56.4433924811227, 56.094179494040354, 56.741126264844624, 52.40863956723894, 52.729267665318076, 58.95103209359305, 50.27015079770769, 51.90418297903878, 42.33679839542934, 48.72440242767334, 54.43883718763079, 58.85632814679827, 55.56775270189558, 43.91523109163557, 39.14472648075649, 40.11964212145124, 41.76087611062186, 39.922285488673616, 44.253851549965994, 51.63670860018049, 53.86033364704677, 54.19106789997646, 51.70143801825387, 46.67619855063302, 49.55183560507638, 51.850105149405344, 52.87133400780814, 53.98761074883597, 51.71439640862601, 52.27289261136736, 55.484568868364605, 58.489546639578684, 55.519573892865864, 52.03586523873465, 48.760498319353374, 45.75820255279541, 42.97593191691807, 46.973817689078196, 44.1476274899074, 41.49987050465175, 41.41080502101353, 39.25791610990252, 39.90665899004255, 39.91682767868042, 40.638759408678325, 45.0410338129316, 45.77762624195644, 45.39398840495518, 42.48790781838553, 40.67179461887905, 42.59694242477417, 46.249666009630474, 44.93158578872681, 45.48038925443377, 44.83698606491089, 46.609148434230256, 48.246289934430806, 47.144281319209504, 48.78409440176827, 48.46160766056606, 54.13485697337559, 58.718461990356445, 62.925346102033345, 61.39394228799002, 63.5290333884103, 63.52250902993338, 64.35575090135846, 65.39674391065324, 67.02687467847551, 65.2279999596732, 66.62052318028041, 65.65452207837785, 67.6014073235648, 62.90172222682408, 66.61153221130371, 67.63413333892822, 74.46975026811872, 68.12803213936942, 84.17033876691545, 7.093587040901184, 1.4311223093952452, 0.3052269273570606, 0.3028387283640248, 26.55704508508955, 74.07505089896065, 56.932611669812886, 52.99201726913452, 24.936546257564, 26.45631878716605, 28.451396737779888, 6.310419533933912, 3.472241520881653, 0.1284706720284053, 0.1106817162196551, 0.008895929969315017, 0.0526529094869537, 0.039321694656142166, 0.022335435596427748, 0.0471289117953607, 0.06698172007288251, 0.1879445921097483, 0.09500778120543275, 0.12758346035012177, 0.13679295831492969, 0.15052110595362528, 0.10982769847448383, 0.11677442464445319, 0.07111137919127941, 0.24590844607778958, 0.18498603015073709, 49.44118554251534, 65.78789275033134, 54.749032565525596, 43.031920501164024, 58.83538627624512, 58.18602500643049, 88.9022912979126, 20.802449737276348, 0.4586202991860253, 1.5241351297923496, 1.5722938541855132, 54.07041243144444, 90.85932091304234, 80.6560719353812, 72.46038682120187, 66.76601845877511, 73.18752970014299, 78.03044496263776, 77.38130256107875, 72.97034985678536, 78.14426340375627, 72.73641095842633, 74.24156447819301, 74.79213973454067, 70.71867493220738, 69.80124173845563, 65.63687365395683, 69.34689208439418, 70.22492899213518, 69.86078780038017, 69.23722171783447, 71.33169364929199, 61.50575964791434, 61.74235275813511, 54.563706738608225, 52.28789724622454, 50.91472475869315, 51.553326742989675, 52.63775988987514, 51.3007493019104, 51.8446820804051, 49.26041078567505, 46.458601815359934, 50.00902359826224, 50.07545185089111, 50.30968257359096, 50.034891741616384, 50.10217114857265, 44.74704858234951, 44.535177162715364, 43.71770422799246, 42.762646538870676, 40.2313483101981, 41.37372248513358, 44.449874128614155, 44.72712809698922, 44.61064154761178, 42.93797390801566, 43.059338092803955, 42.344285079411094, 47.66830403464181, 49.2991852079119, 46.88130242483956, 49.60294655391148, 60.59125859396798, 58.71961539132254, 60.57097680228097, 59.248408045087544, 59.83141054425921, 53.843320982796804, 56.303104877471924, 60.22911153520857, 54.33797366278512, 53.214290142059326, 42.21735886165074, 50.467483111790244, 57.077283586774556, 58.68282467978341, 53.34264768872942, 44.1301770891462, 39.59121077401297, 41.454217365809846, 45.52651139668056, 45.21338735307966, 48.36149106706892, 53.08854511805943, 55.193098885672434, 55.438245228358674, 53.85558107921055, 47.865910802568706, 52.81206239972796, 54.34005117416382, 56.24119642802647, 56.11278329576765, 54.90606880187988, 54.982603209359304, 56.96955524172102, 60.821507998875205, 59.39538328988211, 54.656850814819336, 49.788880348205566, 49.37257208142962, 45.703780787331716, 48.911500045231406, 45.22808974129813, 42.15097229821341, 42.70003979546683, 39.19060543605259, 41.598409857068745, 40.05782747268677, 41.79110772269112, 48.721824645996094, 47.653004101344514, 48.26691913604736, 44.89050109045846, 42.833903789520264, 44.00243098395211, 47.968827520098, 47.825451442173545, 48.41488102504185, 46.97777468817574, 49.574319975716726, 50.398626463753835, 50.20530673435756, 49.264548437935964, 52.50557735988072, 56.04513216018677, 61.95630168914795, 65.61355549948556, 64.24979087284633, 64.60180745806012, 64.76417296273368, 67.92403997693742, 67.69709791455949, 69.06967285701207, 68.87655462537492, 69.3128250667027, 69.17036615099225, 69.32921586717877, 65.1097138268607, 69.05009283338273, 70.09639426640102, 77.38935552324567, 72.7870146887643, 82.24368667602539, 5.48109210389001, 2.1906951453004564, 1.0829874873161316, 0.3679949992469379, 33.96160657065255, 78.37939044407436, 64.74467631748745, 60.14395441327776, 38.18323475973946, 34.97219426291329, 40.034078529902864, 24.257436275482178, 4.968789262431009, 0.24173778987356595, 0.1882300382213933, 0.09511857240327767, 0.1672815858785595, 0.1574033373700721, 0.17613105316247257, 0.20465908093111856, 0.27559495025447434], [0.06598890798964671, 0.024047196244022677, 0.031158039678952525, 0.08732378602560077, 0.004460518306586891, 0.06269285628306014, 0.010088970951203789, 0.057490799709090164, 0.0464855079273028, 0.17787420962538036, 38.80800288064139, 46.244548661368235, 29.343152863638743, 33.48092671803066, 48.2130115372794, 46.01660605839321, 78.08235495431083, 6.226183482578822, 0.18188422944928917, 0.4094552530774048, 0.3449186475149223, 67.91755730765206, 76.5896109172276, 73.59124088287354, 64.16343171255929, 62.16799245561872, 68.60934080396379, 72.79693671635219, 70.01669148036412, 69.73619965144566, 72.17049407958984, 70.5931487764631, 66.56084510258266, 67.32898235321045, 62.29878534589495, 59.14205196925572, 57.80030965805054, 55.87246595110212, 57.31184434890747, 57.94399840491158, 55.65409101758684, 53.32382501874651, 47.635279246738975, 46.39281974520002, 45.60293115888323, 46.500673157828196, 46.506151812417166, 45.034262793404714, 46.126262528555735, 45.59513875416347, 45.29066869190761, 42.50013664790562, 41.138591970716206, 43.922036852155415, 43.936475208827424, 42.65989310400826, 43.6469715663365, 47.530552523476736, 43.222617285592214, 43.16549614497593, 41.63840021405901, 42.21662930079869, 43.01130519594465, 45.81323575973511, 43.11294344493321, 43.52759109224592, 41.4781608581543, 36.85499627249581, 37.70611933299473, 39.11194140570504, 37.27795396532331, 40.50526019505092, 44.10749469484602, 41.598785059792654, 43.10760375431606, 53.95147664206368, 53.881807054792134, 55.0742186818804, 50.85087081364223, 52.168475082942415, 49.05624491827828, 52.90215621675764, 48.63609777178083, 58.78660992213658, 47.75536496298653, 47.72056838444301, 48.401189599718364, 49.649127755846294, 50.70864813668387, 51.34034013748169, 45.59812647955758, 42.669408661978586, 41.81725379398891, 30.750559125627788, 35.019761630467, 51.35386480603899, 50.832871505192344, 48.84339727674212, 47.768993854522705, 44.09934793199812, 48.394116333552766, 51.42028611046927, 51.66155535834176, 50.392564160483225, 55.28923068727766, 51.33930485589163, 54.47401591709682, 55.38705437523978, 49.38531855174473, 46.342726707458496, 41.89388200214931, 40.25556973048619, 43.50544023513794, 39.546401841299875, 41.379458223070415, 42.7182023865836, 41.62221785954067, 39.8375244140625, 38.39938626970564, 39.969217096056255, 40.75905704498291, 43.99265834263393, 43.78560549872262, 40.209176608494346, 40.326872144426616, 39.34367077691214, 38.724923270089285, 42.29354585920061, 41.77270194462368, 42.755493368421284, 43.47127941676548, 42.94103111539568, 42.742072922842844, 44.57820388248989, 45.199327673230854, 44.90940366472517, 46.02287680762154, 49.41990668433053, 55.5843380519322, 58.53497396196638, 60.24718379974365, 61.07390826089041, 61.915529659816194, 60.14476040431431, 61.34427656446184, 59.34726006644112, 60.1072609765189, 62.37810598100935, 60.39058767046247, 57.68755429131644, 59.954178265162874, 59.64657456534249, 68.51524135044643, 69.16937950679234, 68.72630677904401, 22.46812227794102, 0.5161878072789737, 0.6524887191397803, 0.1208557720695223, 6.397263765335083, 62.04573195321219, 57.34441750390189, 45.89907380512783, 28.89607276235308, 13.992882473128182, 11.39171576499939, 2.69591777239527, 0.525698262665953, 0.08935930965734379, 0.0308386091408985, 0.009791059303097427, 0.0164425184151956, 0.03231712676850813, 0.06768593085663659, 0.029212883340993097, 0.04060344730636903, 0.07193140233201639, 0.0413990330084094, 0.026904741302132607, 0.07008434180170298, 0.03818945719727448, 0.05447063694841095, 0.027745788850422417, 0.05677541345357895, 0.05359697561444981, 1.2490920999220438, 51.1087532043457, 51.823351110730854, 32.86247798374721, 29.87926197052002, 52.666445527757915, 52.89454446520124, 84.26933670043945, 6.683557340076991, 0.2668430970183441, 0.22140825646264212, 0.9796803678785051, 75.91254370553153, 78.03053528921944, 75.89242172241211, 66.0098043169294, 66.12340041569301, 69.82853426252092, 74.4220369883946, 70.29868412017822, 71.9662309374128, 73.72734914507184, 71.83652891431535, 69.62012999398368, 70.01949160439628, 64.84860747201103, 62.416133471897666, 59.7158203125, 58.70856775556292, 58.55521406446184, 60.05946431841169, 57.525661264147075, 55.954437323978965, 49.986528805324006, 48.82876437050955, 47.94247300284249, 47.485573359898154, 48.026316915239605, 48.55930280685425, 47.962879862104145, 47.974438190460205, 46.198944159916465, 45.497162205832346, 44.717692443302695, 45.640965597970144, 45.33660323279244, 46.22117839540754, 46.52848332268851, 48.12875073296683, 42.86298547472273, 44.27284097671509, 41.197071484157014, 41.7023549079895, 41.76587881360735, 47.287428106580464, 44.76925502504621, 46.70446382250105, 45.14202240535191, 40.824790477752686, 40.12253604616438, 40.99338156836373, 40.40804100036621, 44.938367230551584, 45.698493208204, 44.260070187704905, 46.22030292238508, 54.591482162475586, 54.841388021196636, 57.10897432054792, 51.65559032985142, 54.956742014203755, 50.708946909223286, 55.14758471080235, 51.41081918988909, 61.082030705043245, 50.77165787560599, 49.068296568734304, 52.69835860388619, 54.81686088017055, 49.0502347264971, 51.228884083884104, 47.65833336966378, 41.533916677747456, 43.453161988939556, 33.52996015548706, 38.26353856495449, 53.5224358013698, 52.919603143419536, 52.91020223072597, 49.34772879736764, 45.97588266645159, 50.75930050441197, 53.17087779726301, 54.88483510698591, 53.18389177322388, 58.20570925303868, 54.07985503332955, 57.25437232426235, 57.90710694449288, 51.376258850097656, 45.788357734680176, 43.2124034336635, 41.568918228149414, 44.9224419593811, 40.514754908425466, 41.022834982190815, 43.778685092926025, 42.0262382371085, 40.91786854607718, 39.494314670562744, 40.82543666022164, 40.66890069416591, 45.64846270424979, 45.072001934051514, 42.25692537852696, 42.81872197559902, 41.94788340159825, 40.500827244349885, 45.58856923239571, 44.146300383976524, 44.57881532396589, 44.858660970415386, 46.274509293692454, 45.2609304019383, 46.76870339257376, 46.37551525660923, 46.888844694410054, 46.39622436250959, 51.33341973168509, 57.015024253300254, 59.16953904288155, 60.77749810900007, 63.28893838609968, 62.54731546129499, 62.458399363926475, 63.535898208618164, 61.27800464630127, 60.9907591683524, 64.5399476460048, 62.11948708125523, 60.59580271584647, 62.536914008004324, 62.29573508671352, 71.53729084559849, 72.35284955160958, 72.20820195334298, 26.976174320493424, 0.7516297964113099, 0.2578737325966358, 0.23818723325218472, 5.536842712334224, 67.98787307739258, 63.29590048108782, 55.4880325453622, 36.14815255573818, 16.66068066869463, 27.409752334867203, 10.179721508707319, 1.4272007026842661, 0.10020075898085322, 0.025013765985412256, 0.13192939572036266, 0.017760433589241335, 0.023139123006590774, 0.07589758879372052, 0.025390727811359932, 0.03794085892981716, 0.12581807508000306, 0.1127798075654677, 0.11733530169086796, 0.1619114154683692, 0.11636058613657951, 0.15102637026991161, 0.08818572227443967, 0.20665611805660383, 0.1976032666862011, 1.3165279499122073, 59.2339141028268, 60.87465476989746, 39.25367076056344, 48.16050052642822, 64.97168786185128, 58.584987095424104, 92.03531047276088, 8.460896117346627, 0.42254921474627083, 2.0650128722190857, 1.8775693646499088, 77.11675684792655, 81.79203292301723, 79.76717499324253, 68.78576946258545, 68.86627129146031, 74.22229017530168, 76.6146661213466, 73.23884214673723, 73.3389448438372, 76.49318381718227, 75.23633807046073, 73.19577026367188, 72.88636698041643, 66.73713479723249, 65.18245451790946, 64.84326430729458, 61.306770188467844, 63.027894565037315, 64.18246977669853, 61.372361183166504, 58.455528259277344, 52.44519404002598, 51.89188119343349, 51.32864284515381, 50.69869484220232, 50.39242172241211, 50.36658484595162, 50.91881724766323, 51.27779940196446, 46.90906047821045, 48.30334159306118, 46.41501576559884, 50.19462387902396, 48.71543230329241, 47.111669949122835, 48.3190028326852, 48.25890786307198, 42.821959836142405, 43.801134722573416, 41.33511134556362, 42.52601521355765, 44.28565692901611, 47.25916978291103, 44.15982157843453, 47.24791022709438, 49.50457395826067, 43.06088406699044, 44.69663940157209, 43.90610463278634, 43.83134201594761, 46.80877365384783, 48.54627840859549, 47.50119638442993, 48.18913057872227, 58.94235379355294, 58.63151223318917, 60.25327042170933, 56.192941188812256, 57.41579634802682, 53.45816149030413, 57.20061411176409, 52.6150392804827, 62.2480912889753, 53.11379139763968, 53.52870307649885, 55.60508189882551, 58.11870738438198, 50.95591715403965, 53.36853667667934, 47.53456163406372, 42.989456585475374, 44.19142198562622, 36.289527552468435, 41.25619370596749, 56.57701676232474, 55.29051957811628, 55.27427121571132, 51.3925975390843, 47.519233907972065, 52.46801192419869, 55.15095111301967, 55.79209961209978, 53.50651747839791, 60.394027028764995, 57.17500305175781, 58.942284311567036, 61.05238968985421, 53.61323138645717, 49.13332823344639, 45.094687802451, 44.28421517780849, 47.996998991285054, 41.215911524636404, 42.52294063568115, 43.702803816114155, 43.176578521728516, 41.93115561349051, 38.44398675646101, 40.30984558377947, 39.93285717282976, 46.40839065824236, 49.04550647735596, 46.33773790087019, 46.37042222704206, 44.230998924800325, 43.070667130606516, 46.026420388902935, 46.371572153908865, 48.16402326311384, 48.75389058249337, 47.59054674421038, 47.029771532331196, 49.45293494633266, 49.455901827131, 49.98756756101336, 49.42120599746704, 54.57948957170759, 60.95578193664551, 63.520765032087056, 64.6498611995152, 66.17979894365583, 65.70389597756522, 65.72348294939313, 66.70486736297607, 65.0138773236956, 63.95845985412598, 68.1495646068028, 65.47864927564348, 62.86065142495291, 66.31218297140938, 66.34044129507882, 74.05391447884696, 76.4129112788609, 74.51235662187848, 26.911206926618302, 1.7004618453127998, 1.3437290617397852, 0.31756600524697987, 9.21041306427547, 77.64614704677037, 71.6873094013759, 63.355905124119346, 51.014288970402305, 35.97924184799194, 36.837462493351524, 31.419590745653423, 3.0654559774058203, 0.3178250699170998, 0.08346765794392143, 0.14144536081169332, 0.08745169666196619, 0.08715449832379818, 0.0908969242924026, 0.1505208888224193, 0.11150797509721347], [0.008953910786658525, 0.053604782159839354, 0.018873380297528844, 0.1236355264804193, 0.030469991599342654, 0.05555499358368771, 0.09720942378044128, 0.12846364240561212, 0.12353969019438539, 2.615107834339142, 51.12793370655605, 39.948671272822786, 35.88574341365269, 37.211497919900076, 44.40181343896048, 53.3458959715707, 70.70704364776611, 1.7269058206251688, 0.021324033350018517, 0.30970680553998264, 9.547567452703204, 88.29047461918422, 70.68785967145647, 72.7937822341919, 58.324492182050435, 66.84074633462089, 70.70576517922538, 71.67183576311383, 73.36088030678886, 71.03765283312116, 66.05594035557338, 68.55879265921456, 63.9243928364345, 61.553056035723, 57.911227226257324, 57.097381251198904, 50.79484054020473, 49.42220653806414, 48.10614129475185, 48.69728708267212, 45.93469027110508, 48.12048585074288, 46.50901099613735, 46.44023077828543, 45.394318444388254, 45.8608969279698, 45.210062640053884, 46.473394530160085, 43.53984771456037, 46.009956632341655, 45.103543281555176, 43.24271147591727, 39.91108846664429, 42.17058706283569, 42.6607894216265, 44.724588530404226, 43.18937362943377, 45.96844809395926, 43.6621082169669, 43.202457087380544, 42.565439292362754, 42.33862577165876, 44.32515396390642, 46.341764381953645, 42.39423220498221, 45.63622692653111, 45.03987346376692, 42.36847175870623, 36.649677004132954, 36.939475945064, 36.5287366594587, 41.40641723360334, 40.816549914223806, 43.58734212602888, 39.13192442485264, 43.47818940026419, 45.82653113773891, 50.268000330243794, 46.03775290080479, 49.352057525089805, 48.16419349397932, 48.90610129492623, 50.443998200552805, 55.11014781679426, 39.73846394675118, 43.39619370869228, 40.752296447753906, 42.63840232576643, 42.205376693180625, 32.60340745108468, 55.19096578870501, 39.640984194619314, 45.3667688369751, 39.98719903400966, 50.86452749797276, 52.40325471333095, 48.638397625514436, 45.07617085320609, 44.5081000328064, 44.68007837023054, 50.13489368983677, 50.94000925336565, 52.574906485421316, 51.66016571862357, 53.601568835122244, 53.00384310313633, 52.52393797465733, 46.146926471165244, 42.70325681141445, 40.67604691641671, 40.34175865990775, 42.134616238730295, 41.87808179855347, 45.62267793927874, 40.29838800430298, 43.79878623144967, 45.410094329289024, 41.288878032139365, 40.16329765319824, 40.73268863133022, 40.07288421903338, 44.02368204934256, 43.14688886914934, 38.749825613839285, 41.95702028274536, 37.91324165889195, 39.5209401675633, 42.12613248825073, 43.83783163343157, 42.891094412122456, 43.112248625074116, 43.0570764541626, 43.2691285269601, 43.672026770455496, 44.43451166152954, 42.57858180999756, 45.238352230616975, 44.80774804524013, 47.13584620612008, 48.013848372868125, 53.06132207598005, 55.99239533288138, 54.83845240729195, 53.64708300999233, 55.06017289842878, 55.32169961929321, 58.37794467381069, 58.72237382616316, 58.277456351688926, 55.09222493852888, 60.109553882053916, 58.37806279318673, 68.83258642469133, 65.34799534933907, 75.67011410849435, 44.306504998888286, 0.06320712475904397, 0.3587277850934437, 0.03762530282671962, 0.7276765331625938, 49.16460902350289, 61.457351548331125, 48.856275762830464, 35.993263312748496, 21.360364028385707, 13.758564897945949, 3.9975505215781073, 1.5030770940440041, 0.1471808680466243, 0.023646860583020107, 0.03648544541959252, 0.029356288324509348, 0.09691318896199975, 0.12009326155696597, 0.04344293315495763, 0.06473881578338997, 0.027667984632509093, 0.03851877399055021, 0.07435765356889792, 0.05442183670986976, 0.030481211175876002, 0.12539711195443357, 0.04000535600685647, 0.21960882230528764, 0.16487993832145417, 4.224331472601209, 61.57331698281424, 44.37173816135952, 43.8755464553833, 32.2183313369751, 53.24240950175694, 59.14757578713553, 76.38449314662388, 1.7974149457045963, 0.06972965119140488, 0.3181916688169752, 13.730063387325831, 93.50275611877441, 72.14421599251884, 77.53942271641323, 60.35435976300921, 70.40847260611397, 71.67307949066162, 74.95657580239433, 72.90361935751778, 73.06137125832694, 69.47872720445905, 71.14259147644043, 65.38454982212612, 65.58215659005302, 58.806363650730674, 59.795933042253765, 50.94661699022566, 50.993760517665315, 49.8568754196167, 49.887287684849326, 46.96656376974923, 50.11221824373518, 49.273039136614116, 48.77637842723301, 46.905172961098806, 47.69709389550345, 47.28114693505423, 49.63446705681937, 46.21993466785976, 48.760043212345664, 46.776002475193565, 44.7385960987636, 42.52907936913626, 46.29927614756993, 45.67832258769444, 46.73082876205444, 44.476301601954866, 47.16854442868914, 44.58705241339547, 42.05558047975813, 43.45956127984183, 43.01225015095302, 42.380224636622835, 46.49787303379604, 43.18645191192627, 45.28346340996878, 46.77892419270107, 44.629078592572895, 37.95338487625122, 39.5922669001988, 40.92806502750942, 42.98377990722656, 42.96127469199044, 47.61993762425014, 42.13382414409092, 44.775240898132324, 48.525770800454275, 50.87876088278634, 48.78726972852434, 50.20093631744385, 51.19867679050991, 52.24581895555769, 53.29241221291678, 57.83713511058262, 43.06416014262608, 45.33558532169887, 44.671466078077046, 47.03654950005667, 44.96848767144339, 32.71547842025757, 55.52021312713623, 39.7751122202192, 44.76907784598214, 42.439419814518516, 54.661179542541504, 55.10055930273873, 50.8515864780971, 46.56978341511318, 47.59554597309658, 46.7974967275347, 53.24208293642317, 53.13295105525425, 54.95748894555228, 54.01732472011021, 54.77315671103341, 54.51690714699881, 52.00445590700422, 47.667918409620015, 44.72249364852905, 43.83623702185494, 42.662366662706646, 44.3014988218035, 43.577562536512104, 46.59601981299264, 42.93864093508039, 45.034203733716694, 48.56207513809204, 42.222458839416504, 39.821234362465994, 39.55208199364798, 40.178368295942036, 45.70131417683193, 45.3784487588065, 40.23494747706822, 43.40038694654192, 41.59420619692121, 42.523225511823384, 44.20415455954415, 44.77382346561977, 46.24868631362915, 44.159251826150076, 45.34602846418108, 44.578749316079275, 45.08912576947893, 45.717069217136924, 45.24174295152937, 45.53989710126604, 47.059891973223, 49.40792451586042, 49.230599539620535, 53.791800090244834, 55.9919958114624, 56.30571045194353, 55.3300895690918, 57.4916741507394, 55.29508454459054, 60.38276399884905, 61.373743874686106, 59.06890133449009, 57.058724948338096, 61.57021113804409, 60.439683641706196, 71.13288484300885, 67.0879215512957, 79.9220781326294, 50.32009792327881, 0.12711869100374834, 0.7838945165276527, 0.009246709673399372, 0.7006877213716507, 53.19595384597778, 68.92106478554862, 56.79179947716849, 44.670194557734895, 23.88782685143607, 30.04447971071516, 10.607162526675634, 1.8403233289718628, 0.09088288540286676, 0.03584830103708165, 0.034030458224671226, 0.07026515102812222, 0.034474094597888846, 0.03904930016558085, 0.005801015974222017, 0.007996508901539658, 0.07023394520261458, 0.1294596911008869, 0.1824629655373948, 0.197551996580192, 0.13109010218509606, 0.16605759012912, 0.2774205894342491, 0.305619907698461, 0.21497818721192224, 4.625525236129761, 75.67785440172467, 50.45836360113961, 53.753616264888215, 54.645282064165386, 64.4919216973441, 63.458807945251465, 85.54727022988456, 2.885912571634565, 0.10786078830382653, 1.2752050587109156, 14.160110848290579, 97.33584104265485, 75.06894207000732, 79.59788908277238, 62.4573849269322, 73.85876042502267, 74.95488044193813, 76.91753114972795, 77.20507540021623, 76.16976601736886, 71.08882631574357, 76.41941479274205, 68.77873788561139, 66.76846422467912, 64.17992673601422, 61.595634596688406, 55.55423845563616, 55.675932679857524, 52.645350796835764, 52.37529168810163, 50.74122476577759, 53.42218024390084, 52.809564522334504, 50.14919655663626, 50.77083798817226, 51.59426900318691, 49.76127862930298, 51.44612993512835, 48.31766530445644, 50.98552342823574, 50.559025628226145, 47.297325815473286, 45.74918031692505, 47.4482615334647, 48.44173928669521, 49.50953844615391, 46.641106673649375, 48.68167100633894, 44.284388882773264, 43.11603191920689, 42.07157175881522, 42.22129154205322, 44.54900407791138, 46.65005595343453, 43.275552136557444, 47.526925563812256, 48.983674458095, 46.56816101074219, 41.185325554439, 41.43086099624634, 42.320258208683555, 45.85801689965384, 45.68013606752668, 49.73765475409371, 43.56053597586495, 46.37143666403634, 51.68618672234671, 55.16246427808489, 52.42874417986189, 53.58033514022827, 53.15861075265067, 53.6288092476981, 57.30834245681763, 57.759249278477256, 47.922858238220215, 51.205277579171316, 49.21248211179461, 53.36209569658552, 44.45502274377005, 35.45064721788679, 58.090139865875244, 45.55659709657942, 48.06584869112287, 43.35656118392944, 55.48665680204119, 57.813090869358604, 53.39607238769531, 48.84686095373971, 49.6622667993818, 49.74471064976284, 55.76758984157017, 55.10044813156128, 58.2340544291905, 56.49791499546596, 59.50898633684431, 56.408220699855256, 55.1595390864781, 49.84723479407174, 47.62784814834595, 45.52483688082014, 45.00561189651489, 46.89851311274937, 46.292981079646516, 46.552603994097026, 45.63681752341134, 46.71735967908587, 47.883969170706614, 43.037454741341726, 41.23179510661534, 40.84294612067086, 40.55876479830061, 47.180589130946565, 47.30569839477539, 42.847529206957134, 47.342780930655344, 44.0225043296814, 45.232196126665386, 47.66710894448416, 46.56333201272147, 47.59864834376744, 45.810282775333945, 48.16984237943377, 45.77285630362374, 48.98961516789028, 48.67796066829136, 47.00510195323399, 49.158334800175254, 49.40164334433419, 53.25762953077044, 53.234964506966726, 59.178314617701936, 61.06575107574463, 59.055817876543315, 59.01182188306536, 60.24035372052874, 59.191425868443076, 63.48651041303362, 65.40705503736223, 62.131583895002095, 60.71891784667969, 65.90131514413017, 66.37791987827846, 73.97278731209892, 71.71062060764858, 81.65625122615269, 54.88185085569109, 0.39108994283846443, 1.8042917081287928, 0.17487138004175254, 1.0830743397985185, 62.08712237221854, 76.1017917905535, 64.3395824432373, 57.04747928891863, 43.639953885759624, 40.900852407727925, 31.812518324170792, 2.4996296422822133, 0.2542256840637752, 0.10243467946669885, 0.09121329124484744, 0.12330176867544651, 0.12776819829429897, 0.189634076452681, 0.11770370549389295, 0.14472762468670095], [0.06749750168195792, 0.03255335194990039, 0.046889531426131725, 0.020742810431069562, 0.037823815031775405, 0.06894630286842585, 0.07263893793736186, 0.04488597018644214, 0.32224168149488314, 4.56435546704701, 49.73240539005825, 42.07147795813424, 30.13678652899606, 35.43114709854126, 47.731442315237864, 56.39508860451834, 61.26500456673758, 0.3671181420130389, 0.09720774101359503, 0.4004533461162022, 35.622017587934224, 81.72278022766113, 66.4001749583653, 68.04297229221889, 60.923563139779226, 69.29009056091309, 68.95287363869804, 74.90015642983573, 69.37145396641323, 69.85773754119873, 65.6183636529105, 64.29509312765938, 59.346732003348215, 57.64275230680193, 54.48943049567086, 50.138788155147004, 48.58274255480085, 48.858377592904226, 48.4313691002982, 47.17574276242937, 47.84814773287092, 45.585682255881174, 46.83006988252912, 44.15201180321829, 46.83940131323678, 46.13487482070923, 45.27593503679548, 43.27346420288086, 45.07045943396432, 44.75587279456002, 42.035281317574636, 39.55370439801897, 41.59686040878296, 42.18179450716291, 43.080828871045796, 43.146489347730366, 44.562928267887656, 46.36901869092669, 44.63012082236153, 43.97291851043701, 44.17087268829346, 44.19791507720947, 45.29409762791225, 46.78315217154366, 42.71384586606707, 43.51720700945173, 42.06107303074428, 44.944790840148926, 38.20828996385847, 38.23339033126831, 37.744324002947124, 38.26322589601789, 39.670236110687256, 40.9588976587568, 45.637981346675325, 40.47857563836234, 41.52276481900896, 43.94312463487898, 45.83942699432373, 44.636787618909565, 43.45791803087507, 47.91942582811628, 51.6376188141959, 53.92778328486851, 43.83794627870832, 37.04863561902727, 32.27567829404558, 36.20280013765608, 51.54467623574393, 26.140415464128765, 33.82734652927944, 32.81674146652222, 27.63207905633109, 44.56395660127912, 55.08073609215872, 51.29715013504028, 48.510731424604145, 43.6699457849775, 41.851581369127544, 41.55195420128958, 44.888784885406494, 46.93825680868966, 46.40287726266043, 48.07009056636265, 47.489443506513325, 47.70987510681152, 40.67549453462873, 38.89792646680559, 40.88143914086478, 40.10494668143136, 42.67136457988194, 44.7103898865836, 46.44077968597412, 47.813319887433735, 44.23284019742693, 42.637766565595356, 47.03951985495431, 43.3066349029541, 42.14286722455706, 42.796147278376985, 41.390356472560335, 45.09757130486624, 42.44301898138863, 39.17090381894793, 39.70621735709054, 39.599916866847444, 39.79753405707223, 42.309102875845774, 44.34206935337612, 42.81583847318377, 43.68143115724836, 44.43187134606497, 43.27801179885864, 42.14571598597935, 43.3357652255467, 42.55510037285941, 43.84627716881888, 44.02412673405239, 44.575028555733816, 44.10640035356794, 43.33926364353725, 45.03681973048619, 46.17872837611607, 46.32491847446987, 48.380431856427876, 48.46251440048218, 52.607156549181255, 55.77384669440133, 56.28086369378226, 55.69862897055489, 54.87833506720406, 56.07513795580183, 64.04677145821708, 68.59268597194126, 71.48980685642788, 64.38535717555455, 0.628697327205113, 0.21743337118199893, 0.12533182331493922, 0.17121850033955915, 42.07674469266619, 63.66759436471121, 52.67974785396031, 38.93839624949864, 17.469364132199967, 17.29610558918544, 5.241230734757014, 1.8982930183410645, 0.13088301329740457, 0.04733304566304598, 0.08886573649942875, 0.01748572359792888, 0.03459386620670557, 0.07402578209127698, 0.07642793176429612, 0.02268406010365912, 0.021398621311943446, 0.004354109172709286, 0.0450926757018481, 0.019767256886033074, 0.02375429472886026, 0.09200349955686501, 0.04003137103947146, 0.15008080458002432, 0.2735269383660385, 6.965797943728311, 60.48666041237967, 51.10796110970633, 34.5170316696167, 34.76715292249407, 58.79560089111328, 62.68051242828369, 67.79606110709054, 0.35977913439273834, 0.09957856951015336, 0.18015148171356746, 44.016688687460764, 86.81481620243618, 70.89798709324428, 70.4850070135934, 64.06585815974644, 70.80859851837158, 73.17809404645647, 77.12114116123745, 70.12512506757463, 73.34521906716483, 66.93920925685337, 64.83412742614746, 61.6341415132795, 60.09732505253383, 56.47293274743216, 53.5183676310948, 50.83041879108974, 51.4238783291408, 49.29814297812325, 49.34844446182251, 49.341725553785054, 49.217359747205464, 48.7431834084647, 47.84804350989205, 48.774992261614116, 49.909779003688264, 48.52239745003836, 46.62377091816494, 46.56798035757882, 48.05309179850987, 46.507430280957905, 42.72793333871024, 45.25066443852016, 45.82885878426688, 46.15340566635132, 44.39859989711216, 44.324563367026194, 47.97212096623012, 47.511344228472026, 43.612532820020405, 44.94889027731759, 43.93852840151106, 46.41414376667568, 47.02497380120413, 43.46769067219326, 46.20639957700457, 44.82607044492449, 47.05602877480643, 39.40368584224156, 40.93946702139718, 39.93736655371529, 41.02190044948033, 43.63049043927874, 45.24162483215332, 46.442412512642996, 42.68709182739258, 42.76342126301357, 44.55789082390921, 46.36579820087978, 46.23188556943621, 47.162068707602366, 47.94945594242641, 53.3517359324864, 56.37989984239851, 49.87332875388009, 41.78049087524414, 36.26690074375698, 44.14687361036028, 55.158024379185264, 28.47451686859131, 32.80971336364746, 38.149195534842356, 29.702697822025844, 48.902856486184255, 57.08799423490252, 52.40131964002337, 49.71226256234305, 45.35781608309065, 42.64665331159319, 43.38896410805838, 46.438709122794016, 49.81407104219709, 48.89742646898542, 48.299044132232666, 48.71910442624773, 47.966437339782715, 43.05879960741316, 42.513845443725586, 42.08618382045201, 42.93878337315151, 44.14158950533186, 43.891885144369944, 48.508997849055696, 46.80508416039603, 44.80686214991978, 44.13552720206124, 46.68829536437988, 42.48381880351475, 42.38172892161778, 42.9598503112793, 43.24517113821847, 46.26460116250174, 44.46604258673531, 42.614424092429026, 42.915333202907014, 42.01236268452236, 41.88680178778512, 45.160052980695454, 45.284769671303884, 44.88613414764404, 45.199876580919536, 45.92909697123936, 46.54526669638497, 44.06063256944929, 47.10746281487601, 44.67237629209246, 46.58339146205357, 46.46135677610125, 46.03232288360596, 47.96432508741106, 46.52147259031023, 47.46446820667812, 48.35771472113473, 48.10089193071638, 50.43490995679583, 49.905252252306255, 53.60811056409563, 58.2200642313276, 57.701495851789204, 56.79265063149588, 56.81082017081124, 59.194351060049875, 67.35765062059674, 71.41276523045131, 74.45930712563651, 68.38212776184082, 0.7802976295351982, 0.937003337911197, 0.04320947978911655, 0.13270106645567076, 44.66940941129412, 71.53900010245187, 58.6037472316197, 47.20774269104004, 22.87170318194798, 34.67402969087873, 22.204653535570415, 1.3195485706840242, 0.166915163397789, 0.052908717188984156, 0.031394034158438444, 0.02129983000590333, 0.047957450550581725, 0.024676727463624308, 0.03117580372574074, 0.08178495216582503, 0.28501592044319424, 0.17908289762479918, 0.12380518737648215, 0.13135192170739174, 0.16335708860840115, 0.20803750678896904, 0.23386708221265248, 0.28749830009681837, 0.3867743786956583, 8.044368982315063, 73.73879977634975, 52.35771969386509, 41.29959562846592, 47.69931384495327, 68.7736587524414, 67.62965869903564, 77.77987902505058, 0.8014451233404023, 0.34094313798206194, 0.38964675313660074, 43.48003414699009, 89.59939711434501, 73.67513343266079, 74.56230722154889, 68.59554862976074, 74.83824103219169, 74.84655802590507, 78.98284149169922, 74.04887008666992, 76.14307103838239, 69.29232788085938, 68.18928050994873, 65.33238969530377, 62.60399191720145, 58.96485900878906, 57.46552460534232, 55.45964568001883, 54.519467558179585, 53.51930563790457, 51.10396589551653, 52.58417190824236, 50.890027386801584, 52.16909694671631, 48.916815417153494, 52.00963231495449, 50.568207672664094, 51.206562995910645, 47.95780072893415, 49.53175531114851, 49.51760877881731, 47.361680030822754, 44.425510270254954, 46.32824318749564, 47.505118642534526, 49.130913734436035, 47.967027936662944, 47.31150014059884, 50.27305861881801, 47.469891275678364, 44.307276248931885, 44.72827107565743, 45.51666579927717, 47.41761997767857, 47.985541411808555, 44.65740292412894, 46.15082093647548, 45.863165514809744, 51.56657695770264, 43.798320702144075, 44.942379815237864, 44.09012419836861, 45.6657498223441, 46.42147411618914, 46.39217356273106, 50.71834782191685, 44.595445837293354, 45.63809251785278, 45.66867848805019, 50.335366589682444, 48.29001842226301, 49.192130838121685, 49.93594591958182, 55.690906047821045, 58.87754794529506, 49.38944925580706, 43.26413972037179, 44.78141437258039, 48.32820572171892, 58.42713791983468, 27.29391544205802, 38.63476691927229, 38.86037492752075, 30.998887743268693, 50.06421661376953, 58.82606874193464, 56.35672412599836, 52.03822067805699, 46.77177449635097, 45.65493147713797, 45.679614952632356, 49.0923616545541, 51.32990394319807, 53.389957972935264, 52.77064766202654, 52.74014507021223, 52.023504393441335, 46.09307098388672, 43.82556458881923, 45.462629658835276, 46.406257561274934, 46.710487910679404, 46.83875513076782, 48.71149614879063, 47.970449924468994, 46.217905793871196, 45.38203750337873, 48.728317737579346, 43.98402173178536, 43.29086249215262, 44.37755727767944, 43.965324129377095, 49.04380416870117, 45.676380566188264, 44.37082099914551, 44.79606464930943, 44.26175512586321, 43.98540442330496, 46.997851508004324, 47.40659318651472, 47.202312673841206, 48.059452874319895, 47.76966435568673, 48.97214044843401, 44.83114262989589, 48.07459299904959, 46.60355860846383, 48.51779426847185, 49.51671246119908, 48.55810424259731, 49.61803109305245, 48.8623172215053, 50.44480071749006, 50.71865701675415, 50.52750859941755, 54.24149097715105, 53.35026638848441, 56.200931617191856, 63.734602791922434, 62.14309706006731, 61.498561314174104, 60.484436988830566, 63.38594913482666, 69.3195161819458, 75.95817947387695, 76.75654138837541, 72.89188385009766, 0.9193465539387294, 1.8501724004745483, 0.3046509868332318, 0.3413228190370968, 53.57638508932931, 76.52779974256242, 65.24695464542934, 59.18737506866455, 31.504494258335658, 38.33407320295061, 42.822011947631836, 2.7825322789805274, 0.332313991018704, 0.27270428250942913, 0.21735927515796252, 0.06538841128349304, 0.10746531773890768, 0.22992596083453723, 0.12720513636512415, 0.20381004363298416], [0.11341967965875353, 0.027523304003157785, 0.01940174024951245, 0.013588013193969215, 0.10824216569640807, 0.0601856829598546, 0.07536996674856969, 0.03293061402759381, 0.26969386690429276, 5.78349768263953, 55.462188720703125, 39.04254627227783, 33.218083313533235, 32.04842356273106, 46.36064958572388, 65.89462402888707, 49.04665987832205, 0.015820490096562674, 0.13211224733718804, 1.3950906885521752, 66.50119481767926, 77.04632295880998, 71.73518248966762, 66.19297272818429, 65.60625989096505, 72.30908284868512, 74.87958976200649, 73.54472269330705, 70.60655879974365, 66.00929709843227, 65.67098930903843, 57.593534742082866, 55.15147222791399, 50.570934840611045, 49.705752100263325, 51.59074626650129, 49.01563964571272, 47.43929488318307, 49.24265466417585, 46.98422956466675, 47.035625389644075, 47.37211969920567, 47.459333487919395, 45.41923815863473, 46.15998213631766, 44.64941249574934, 47.66618135997227, 45.2650819505964, 45.79734870365688, 44.11470692498343, 44.17418350492205, 42.878195081438335, 40.516467639378135, 41.49046611785889, 44.55354472569057, 42.96681588036673, 44.61118350710188, 47.595320156642366, 42.82542698723929, 45.4976590020316, 47.03095620019095, 40.70492015566145, 41.229126998356406, 42.93646614892142, 45.091383934020996, 43.48613119125366, 39.82746342250279, 41.01595973968506, 41.15494803019932, 37.72581400190081, 37.69152116775513, 37.48798411233084, 35.173431464603965, 38.57733310971941, 41.38393981116158, 42.513689109257285, 43.117015089307515, 41.32970912115914, 43.71535226276943, 42.652329989842, 44.662596702575684, 45.08897638320923, 52.1157625743321, 51.78326347896031, 53.673208236694336, 33.55630772454398, 23.586217709950038, 38.81577444076538, 46.760904039655415, 35.48125750677926, 24.085020201546804, 41.67316205160958, 35.946699959891184, 53.35689844403948, 52.07921504974365, 48.42448690959385, 44.371366432734895, 42.16273212432861, 43.536898204258506, 41.36572510855538, 40.2124457359314, 43.31483030319214, 42.04474128995623, 41.25773968015398, 39.7510575566973, 42.054180417742046, 41.459199224199565, 40.27788734436035, 36.85541663851057, 40.82756975718907, 44.34408780506679, 41.62058503287179, 47.21821362631661, 45.82750735964094, 46.2279702595302, 45.383472306387766, 47.765314783368794, 42.624429498400005, 42.389503955841064, 44.01963472366333, 43.43185881205967, 44.36937229973929, 42.49359491893223, 38.84595046724592, 39.811809131077354, 38.74347496032715, 39.04684720720564, 42.354724747794016, 43.95339754649571, 42.5430452483041, 43.23820209503174, 41.74023996080671, 43.83876964024135, 44.703827313014436, 44.970002378736226, 45.0250494820731, 43.378274304526194, 44.60717787061419, 45.15052005222866, 44.30929817472185, 46.662434169224326, 45.38595976148333, 47.1362943649292, 47.278579575674875, 48.204628535679404, 48.54214423043387, 47.804047516414094, 50.88129002707345, 53.84957088742937, 49.058006286621094, 55.86652176720755, 53.58552891867501, 63.927929469517295, 67.26895686558315, 72.39568519592285, 64.49557644980294, 2.311121540410178, 1.5688796831028802, 0.3991013786622456, 0.17718521159674439, 17.922067063195364, 71.12497779301235, 52.94978264399937, 42.70480973379952, 22.449197122028895, 21.736230305262975, 11.587752240044729, 4.098397978714534, 0.1979407835751772, 0.06606594885566405, 0.060615847020276954, 0.03320289655987706, 0.06740485451051167, 0.004413452997271503, 0.045346023714435954, 0.047728468730513535, 0.06698911610458579, 0.035568371415138245, 0.020323708187788725, 0.04556570960474866, 0.05130946782550641, 0.10608324368617364, 0.05135829520544835, 0.2778679611427443, 0.3802910308752741, 12.205566082681928, 64.20332132066999, 49.502013547079905, 37.380641392299104, 34.587337017059326, 55.256890296936035, 73.24965354374477, 53.8065823827471, 0.07479249273559876, 0.05494315516469734, 2.0871628608022417, 74.82493523189, 77.46798828669957, 75.33255672454834, 68.29020309448242, 69.80567468915666, 70.91553824288505, 76.77064623151506, 73.55215726579938, 73.94279193878174, 68.74250302995954, 67.01698044368199, 61.14343888419015, 56.337467193603516, 53.027418340955464, 55.453569480351035, 53.23756660733904, 50.40973663330078, 48.10001993179321, 51.197731835501536, 48.236871651240754, 49.391967977796284, 49.78622613634382, 48.76011616843087, 47.29886136736189, 48.167566844395225, 45.97101545333862, 47.92534916741507, 47.67127091544015, 49.30150243214199, 46.19266298839024, 46.97146224975586, 45.29179082598005, 42.86162710189819, 44.4352377482823, 47.38225712094988, 45.133055755070274, 47.110572133745464, 47.9235634803772, 43.740900788988384, 46.53091866629464, 49.65411308833531, 43.17173562731062, 43.10920531409127, 44.18911518369402, 46.24020256314959, 43.88396767207554, 39.966903345925466, 42.368339742933, 44.49628462110247, 39.57063020978655, 39.083787305014475, 39.38304621832711, 39.91904067993164, 41.95522764750889, 43.07886253084455, 45.13127701623099, 43.89322962079729, 43.539385659354075, 46.58329766137259, 44.04506860460554, 45.121129172188894, 46.21640498297555, 55.100375175476074, 53.813881465366904, 56.698780468532014, 37.86922134671892, 29.450512954166957, 44.48856169836861, 47.758943285260884, 41.26661252975464, 26.05748871394566, 43.67449338095528, 42.36360454559326, 56.24547304425921, 54.000944341932026, 52.23722055980137, 47.24852514266968, 44.5695811680385, 44.133404527391704, 44.6339874948774, 44.0301126071385, 45.58962188448225, 43.391812869480674, 43.80344499860491, 41.85387427466256, 43.01682553972517, 43.68520055498396, 42.39377709797451, 38.81475305557251, 40.83355910437447, 45.23924160003662, 44.277975695473806, 46.83318267549787, 44.88528299331665, 46.687465054648264, 44.94099364961897, 47.94467558179583, 43.915040016174316, 41.91589042118618, 43.26549114499773, 45.030472551073345, 45.56028659003121, 43.21081577028547, 42.21552106312343, 41.494492598942344, 41.62706075395857, 41.915150438036235, 43.040883677346365, 45.886122362954275, 45.10408524104527, 45.70783506120954, 43.66267449515206, 45.735999584198, 46.19682495934622, 47.346904686519075, 47.76430034637451, 46.02126829964774, 46.00511026382446, 46.686197008405415, 47.79474040440151, 49.12254115513393, 48.61166443143572, 49.537060260772705, 49.88042286464146, 50.95593105043684, 50.53504392078945, 49.001969064985005, 53.18808501107352, 56.38391590118408, 53.77799054554531, 57.29211493900844, 58.208168915339876, 66.04966613224575, 70.4776975086757, 76.64597470419747, 68.90928758893693, 2.84667044878006, 1.2671681642532349, 0.05884601056043591, 0.28273503854870796, 17.22680251938956, 78.23725809369768, 57.803394658224924, 51.6737494468689, 26.097208091190883, 39.23034218379429, 27.4501439503261, 3.1269525289535522, 0.38987436092325617, 0.05449118298877563, 0.051645145884581974, 0.022885128689397658, 0.061183081939816475, 0.03439324375774179, 0.06379882086600576, 0.020018111282427396, 0.1978989586766277, 0.11873577082795755, 0.08442804962396622, 0.08816867747477122, 0.14560065498309477, 0.2353325007217271, 0.253246612314667, 0.4380150091435228, 0.4380495330052716, 13.385211263384138, 79.35158933912004, 50.20345156533377, 44.982349327632356, 46.79176098959786, 62.15726443699428, 80.00029400416783, 60.65541131155831, 0.15571512867297443, 0.2595076449215412, 2.2249432504177094, 76.75927203042167, 81.12442915780204, 80.22362300327846, 71.91513388497489, 73.00289521898542, 75.34937136513847, 80.45692266736711, 76.15447998046875, 76.87292371477399, 70.68148817334855, 70.52658503396171, 63.30867821829659, 59.609603200639995, 55.12900175367083, 58.393383571079795, 56.13560117994036, 53.39011778150286, 50.39099734170096, 54.767966406685964, 50.868359429495676, 52.5583940914699, 53.2286833354405, 52.009406498500276, 49.53479167393276, 51.40848459516253, 47.614458969661165, 51.81349161693028, 50.12189013617379, 52.07717227935791, 48.005941322871614, 48.79716048921858, 48.99354437419346, 45.46900463104248, 47.030462878090994, 51.43144491740635, 48.32542296818325, 49.85837275641305, 48.245852197919575, 42.58359146118164, 46.67110552106585, 49.67700392859322, 48.13995122909546, 42.595438139779226, 44.92348766326904, 48.388960770198274, 45.0716302054269, 40.45454181943621, 45.958925587790354, 47.92965357644217, 42.87459244046892, 42.140737601688926, 41.599952357155935, 41.39146818433489, 45.674959659576416, 46.34371682575771, 47.68630681719099, 47.65701668603079, 45.50372477940151, 48.975221974509104, 47.05168962478638, 48.33377817698887, 49.905551024845664, 57.70546327318464, 58.58885724203927, 59.52373736245291, 41.0813318661281, 34.54105854034424, 48.72525010790144, 51.62452493395124, 42.64347798483712, 28.394788026809692, 47.502905641283306, 42.29816293716431, 57.35587855747768, 57.37840461730957, 52.81297261374337, 49.68984072549002, 45.44337272644043, 46.860287598201204, 46.592590876988, 47.78411660875593, 49.66375023978097, 45.38265241895403, 46.099800314222065, 45.49772500991821, 45.50625392368862, 45.70681367601667, 46.706836632319856, 42.27274990081787, 43.65616750717163, 47.05768592017037, 45.47743974413191, 47.781222684042795, 47.56367458615984, 46.88106966018677, 47.037702901022776, 49.03695671898978, 44.91041462762015, 43.76727615083967, 43.275388853890554, 46.075804710388184, 48.06955208097185, 45.406314509255544, 43.3120128086635, 44.390901293073384, 44.752277101789204, 43.97914062227522, 45.6553761618478, 48.039223194122314, 47.754756995609824, 46.86670078550066, 45.335765974862234, 49.015980107443674, 48.765831061771934, 50.80556508472988, 49.869983196258545, 48.54198442186628, 47.338733604976106, 49.390088490077424, 50.009860856192454, 51.81127861567906, 51.25738212040493, 52.23247146606445, 51.47065360205514, 52.447288921901155, 52.32513264247349, 53.1137775012425, 56.393504415239605, 59.913857868739534, 55.331236021859304, 60.43364565713065, 60.783195631844656, 69.1627231325422, 75.19710159301758, 79.29656655447823, 73.01520047869, 3.4942186730248586, 3.164144281830106, 1.3839289503438132, 0.24143158059035028, 23.177382230758667, 86.08666583469936, 64.43555791037423, 60.151382037571494, 37.72960771833147, 43.82877813066755, 46.1010753086635, 6.993833925042834, 0.7090878763369152, 0.09143433759787253, 0.22146732972136565, 0.08424232101866178, 0.19522169019494737, 0.10465258652610437, 0.1885367360498224, 0.14332077732043608], [0.040200129483959506, 0.03299180092290044, 0.05728443685386862, 0.025217131412188922, 0.02504848492597895, 0.03621899828846965, 0.11533048855406897, 0.14796179399958678, 0.34572689128773554, 17.005253996167863, 54.99919203349522, 31.119994844709122, 30.101090158735, 43.61220278058733, 44.141405378069194, 75.11562701633999, 34.13171236855643, 0.047544185404798815, 0.9073743735040937, 6.44333553314209, 86.8525310243879, 70.94356727600098, 70.56541156768799, 66.24569565909249, 67.77507754734584, 71.01473072596959, 72.65908445630754, 69.41344887869698, 68.7570664542062, 65.60569708687919, 61.54020186832973, 56.68849713461739, 57.83158697400774, 59.392840249197825, 59.629926681518555, 51.383186204092844, 48.02250582831246, 48.497620173863, 46.40024389539446, 46.65374197278704, 44.452615192958284, 44.76057325090681, 44.779580048152376, 45.73506852558681, 45.46949795314244, 44.95468854904175, 44.45272289003645, 45.30571501595633, 43.431261266980854, 44.19346128191267, 43.74812691552298, 41.23289292199271, 39.54027700424194, 42.193564755576, 42.18299307141985, 42.409441811697825, 43.904089655194966, 46.58519104548863, 46.692867279052734, 43.6010092326573, 46.35841226577759, 42.97186027254377, 43.101895809173584, 40.87180198941912, 46.274700369153706, 39.99832657405308, 39.55623006820679, 40.07695933750698, 41.96256841932024, 39.59777682168143, 38.3536810193743, 37.775538785117014, 37.712442193712505, 37.948361328669954, 38.29920366832188, 38.34110477992466, 43.75678089686802, 44.05786371231079, 48.055374281747, 45.13869421822684, 46.77442870821272, 45.06702354976109, 49.424023491995676, 49.5313002041408, 53.85180125917707, 33.16965784345354, 25.983749219349452, 36.86732585089547, 42.317454610552105, 41.08931187220982, 29.674119881221227, 34.39276661191668, 48.96345867429461, 51.03321238926479, 50.00809948784964, 47.22512708391462, 44.98243270601545, 41.69041442871094, 40.62029109682356, 41.27444314956665, 41.67899853842599, 43.245365687779014, 41.29120567866734, 40.925282273973735, 39.66844694955008, 38.20866169248308, 37.72403873716082, 39.18703406197684, 38.239397048950195, 43.768360069819856, 37.02344839913504, 44.195309502737864, 47.02957698277065, 46.69443409783499, 44.997809069497244, 45.31382703781128, 46.977298736572266, 40.89669738497053, 37.3816454069955, 42.08583641052246, 42.1932555607387, 42.79011624200003, 41.58127212524414, 40.26268815994263, 38.95290061405727, 38.92834915433611, 39.94516243253435, 42.86481285095215, 40.70782102857317, 42.33811507906233, 43.49352754865374, 43.33523716245379, 43.35990326745169, 42.73766776493618, 43.79049355643136, 42.962532315935405, 43.98288917541504, 43.41511712755476, 43.86707660130092, 44.321520056043354, 43.980724811553955, 44.86688068934849, 47.367950780051096, 44.51519066946847, 47.3205258505685, 48.129570620400564, 50.45201642172677, 51.386212144579204, 52.6423978124346, 52.512219837733674, 53.57224743706839, 55.359612464904785, 62.797242164611816, 66.77887262616838, 69.8128799710955, 59.848767144339426, 3.0086978801659177, 0.5973147568958146, 0.09178615800504174, 0.08076335662709815, 4.677050905568259, 64.45888996124268, 58.17908375603812, 46.643576758248464, 31.35823815209525, 21.215947457722255, 20.792946338653564, 6.111100903579167, 0.05174705505903278, 0.06118590464549405, 0.07416070199438504, 0.0666059066674539, 0.043256047647446394, 0.04911650710606149, 0.01466613239608705, 0.024844842996182184, 0.10989494808018208, 0.06060393873069968, 0.014041290701633053, 0.05603229547185557, 0.02765619508656008, 0.06326532949294363, 0.11136253790131637, 0.16767554331038678, 0.3908367949937071, 26.299176590783254, 64.35196413312639, 38.67981209073748, 27.856274843215942, 44.92434229169573, 53.441162722451345, 80.71807071140834, 36.63627392905099, 0.026063554654163972, 0.417024202644825, 9.34239409651075, 92.5657776423863, 70.76578371865409, 77.63099997384208, 66.31346143995012, 73.11568532671247, 72.3191785812378, 76.08201721736363, 69.99791744777134, 71.01689856392997, 67.0350318636213, 64.15256472996303, 58.729523522513254, 60.0418575831822, 61.073352405003135, 62.38556834629604, 54.23045376368931, 52.67909124919346, 51.3816819190979, 49.04964760371617, 48.92562920706612, 47.55107750211443, 47.466712474823, 49.05741221564156, 47.67690937859671, 45.72091851915632, 47.05317306518555, 46.98505987439837, 47.041183948516846, 46.79217093331473, 46.3773843220302, 47.71923780441284, 42.63645683016096, 43.65228346415928, 45.85693645477295, 45.49306276866368, 44.67049333027431, 44.12997211728777, 48.05678824016026, 46.49396814618792, 43.12382779802595, 46.59521382195609, 43.07878957475935, 45.827931199754985, 42.33449159349714, 48.3248427936009, 40.7904177393232, 40.358514240809846, 40.0662591116769, 45.295650550297324, 42.12633746010916, 38.82916709354946, 39.78605215890067, 39.41578613008772, 40.77364478792463, 40.77848768234253, 39.84445524215698, 44.92360578264509, 46.35913140433175, 51.31708104269845, 46.31950235366821, 49.003202370234895, 46.7775102342878, 50.51455020904541, 53.39740296772548, 55.17999458312988, 34.302374022347585, 31.762981142316544, 41.232041767665315, 43.72022989818028, 45.11212430681501, 33.01785707473755, 36.04250519616263, 50.207863671439036, 52.82758814947945, 53.49749524252755, 49.8225165775844, 45.41788673400879, 44.37275259835379, 41.88345970426287, 42.29988261631557, 43.50590229034424, 45.25965888159615, 43.09036527361189, 42.59439243589129, 41.998191833496094, 40.917899812970845, 38.159586565835134, 39.879366465977256, 40.322599002293174, 43.13360391344343, 39.719078472682405, 45.03482559749058, 48.029568672180176, 45.50470100130354, 45.54181480407715, 44.957825660705566, 46.911061559404644, 41.432177679879324, 38.964247022356304, 43.106860297066824, 44.5310777255467, 45.103018692561555, 43.804393427712576, 42.06344584056309, 41.51348549979073, 40.677311488560264, 41.79968179975237, 44.17748042515346, 42.61253765651158, 44.03856856482369, 44.183348178863525, 43.41688544409615, 45.20113073076521, 43.529960427965435, 45.05874129704067, 45.65830135345459, 45.86468022210257, 45.83521638597761, 47.112031255449565, 47.34911073957171, 46.63252912248884, 46.91414655957903, 50.05477748598371, 48.30436992645264, 48.778000831604004, 50.40180179050991, 52.38211134501866, 55.76701314108712, 55.93266861779349, 55.983859470912385, 55.761968748910085, 59.088731493268696, 64.89037309374127, 71.86444677625383, 72.54650974273682, 66.78443118504116, 3.655425565583365, 1.5417124437434333, 0.5330526594604764, 0.09436997185860362, 4.722871669701167, 69.48320879255022, 64.01092570168632, 55.943420955113, 33.59989724840437, 27.205160890306743, 39.37292616707938, 9.544827256883893, 0.2192369308322668, 0.10580446078841176, 0.043888421928776164, 0.03748467644410474, 0.05176654937011855, 0.01727223612501153, 0.06784262494849307, 0.019316307601651976, 0.2095338257827929, 0.10810184465455157, 0.10103826796902077, 0.20613395821835312, 0.10534269735217094, 0.1601186716662986, 0.2468679760183607, 0.3302382709724562, 0.550175626363073, 28.91494754382542, 77.61646434238979, 40.58202389308384, 43.23116704395839, 59.66450786590576, 59.14094720567976, 88.44364070892334, 41.76696968078613, 0.23574700419391903, 0.7559846341609955, 7.776017393384661, 95.64888095855713, 74.2117567062378, 81.15124920436314, 69.04115744999477, 75.71968950544084, 73.24119758605957, 80.00517163957868, 71.60171454293388, 75.13691629682268, 70.89146968296596, 68.75054209572929, 60.81383718763079, 64.20814337049211, 64.1887926374163, 66.90817165374756, 56.173670360020225, 55.23998185566494, 52.919644832611084, 51.80470214571272, 51.584162848336355, 49.529434612819124, 48.54160227094378, 51.13883195604597, 49.156271185193745, 48.85864857264927, 48.782572746276855, 48.85857909066336, 49.671184812273296, 49.61231967381069, 48.588412284851074, 48.879899638039724, 44.59991005488804, 46.05301114491054, 49.68656464985439, 49.096252645765034, 46.9649726322719, 48.831467219761436, 51.21068327767508, 47.71108061926705, 44.42022269112723, 48.233758858272004, 45.232811042240684, 48.277132987976074, 44.482895442417686, 52.79237467902047, 41.63886226926531, 40.31910058430263, 40.84901189804077, 48.09410006659371, 45.8997026171003, 41.87845352717808, 43.38109527315412, 43.41407142366682, 43.37436246871948, 42.840549741472515, 42.08622898374285, 48.582759925297324, 47.99324001584734, 52.99320193699428, 49.02743421282087, 52.0299141066415, 48.95491239002773, 52.380763394492014, 56.532836641584126, 60.430873325892854, 40.1379645211356, 36.88729149954659, 44.87226206915719, 50.50820302963257, 49.34833329064505, 36.28373275484358, 41.041640281677246, 53.66517611912319, 56.068530218941824, 55.71468278339931, 52.07747105189732, 49.503059250967844, 45.3054336139134, 44.85366521562849, 44.71560798372541, 45.59221356255667, 46.394845145089285, 46.25656904493059, 45.38699156897408, 42.484131472451345, 43.28623499189104, 41.93742636271885, 43.19351822989327, 42.85250064304897, 44.30408355167934, 41.66699205126081, 45.102230072021484, 48.21309838976179, 46.36838640485491, 47.08984913144793, 45.67301763807024, 47.656624112810405, 44.13727119990757, 42.43014396939959, 42.90510198048183, 46.07658985682896, 46.45110470908028, 45.35035719190325, 45.16449287959507, 43.961533887045725, 42.49278892789568, 44.61852427891323, 47.02988965170724, 45.09450714928763, 45.83876691545759, 45.78713137762887, 47.3067684173584, 48.24013383047921, 47.29048183986119, 47.86642844336373, 47.53471449443272, 48.805237770080566, 48.223923683166504, 49.484511034829275, 49.62231813158308, 48.63776533944266, 50.11624819891793, 53.958761828286306, 49.98374605178833, 51.616603987557546, 53.15450784138271, 55.33372000285557, 58.00356183733259, 57.60084772109985, 59.13729245322091, 59.833835465567454, 62.20872279575893, 68.1042901447841, 73.67441082000732, 78.0417983191354, 71.41111155918666, 4.748309893267495, 2.7773623849664415, 1.351058542728424, 0.2124077608542783, 7.572692258017404, 78.72803715297154, 71.17009939466203, 64.84764862060547, 57.05713381086077, 42.48395429338728, 49.55561195101057, 20.113824197224208, 0.4455355927348137, 0.14462113540087426, 0.13421297818422318, 0.17528847551771573, 0.18887322156557015, 0.11659436859190464, 0.16483641708535807, 0.07916199362703732], [0.05144449968689254, 0.04323185108868139, 0.014158192107320895, 0.05505837719621403, 0.0163004433603159, 0.06699159275740385, 0.03394869475492409, 0.04638439263882382, 0.08573655690997839, 29.3902199608939, 55.64840391704014, 34.28585468019758, 19.58943670136588, 42.58998727798462, 47.513067381722585, 77.54095132010323, 24.911723818097794, 0.24866514386875288, 3.6646540760993958, 45.31641524178641, 80.61375740596226, 69.48213182176862, 73.22356305803571, 67.99640546526227, 71.37860788617814, 69.61632932935441, 72.14434106009347, 69.83330767495292, 67.52175317491803, 61.96113068716866, 55.73273767743792, 56.53480298178536, 60.67060702187674, 56.8289167540414, 58.37602697099958, 63.050997325352256, 56.07805619921003, 52.39146362032209, 53.61131715774536, 53.81568799700056, 53.61960983276367, 53.525423526763916, 50.522134167807444, 48.4648767880031, 44.48255845478603, 45.300222464970176, 46.914219515664236, 44.64183895928519, 46.59959813526699, 43.92211675643921, 46.06981536320278, 43.08813142776489, 40.70281832558768, 43.05446393149239, 41.41985852377755, 41.86088500704084, 42.238804476601736, 46.67482280731201, 46.218204566410606, 42.64098705564226, 49.73659862790789, 39.60606949669974, 36.93665845053536, 41.80728660311018, 44.20316096714565, 37.67174312046596, 40.58344827379499, 39.60615982328142, 40.50200843811035, 41.360500063214985, 40.05954715183803, 37.68198129108974, 38.062558446611675, 36.06650079999651, 37.7069913319179, 36.21351425988333, 41.22358233588082, 47.38860082626343, 52.338375908987864, 48.500052043369834, 48.766484192439485, 48.392295905521934, 51.11560065405709, 50.08884102957589, 53.82885830742972, 34.18643638065883, 33.35547699247088, 38.74288783754621, 36.2749467577253, 38.10096114022391, 36.18691655567714, 35.093551499503, 39.676083019801546, 54.43300764901297, 49.82168626785278, 49.19332592827933, 44.69704587118966, 47.54961838041033, 40.703329018184114, 41.92341532026018, 42.31346981866019, 42.22055850710188, 41.18177155085972, 36.94909920011248, 36.411447593144004, 35.168929031917024, 39.74474164417812, 40.906494344983784, 38.614363534109934, 44.049404280526296, 40.49295493534633, 44.737373215811594, 46.75733961377825, 45.40879849025181, 43.48537731170654, 46.96677221570696, 46.26988179343087, 46.8276275907244, 37.18491063799177, 42.572130407605854, 47.12385708945138, 42.294626304081504, 41.184724535260884, 39.52298641204834, 39.93417385646275, 38.41081258228847, 39.80686548777989, 41.826397623334614, 40.95753581183297, 42.329468045915874, 42.72146803992135, 42.52962827682495, 43.55505037307739, 43.286801270076204, 44.05384765352522, 43.19255243028913, 44.57425035749163, 44.50830847876412, 44.87477036884853, 44.26225539616176, 46.962068285260884, 45.70174149104527, 47.3181391443525, 47.27781874792916, 48.71404961177281, 50.24028744016375, 53.27670233590262, 56.12416444505964, 55.92039809908186, 53.37547792707171, 54.7972217968532, 57.53454106194632, 64.40103231157575, 67.8857831954956, 70.81230190822056, 49.21993405478341, 4.229649015835353, 0.9848411423819405, 0.17621072674436228, 0.08190748201949255, 1.3056120042290007, 53.08513355255127, 63.83045319148472, 46.694923945835654, 25.63114377430507, 24.150237730571202, 18.258340767451696, 9.459254111562457, 0.20345937673534664, 0.04073735958497439, 0.08279073783861739, 0.04978755109810403, 0.025260138658008406, 0.020389317435079386, 0.059811253765864034, 0.04853501616578017, 0.05898726119526795, 0.06100991301770721, 0.015667733204151903, 0.07533521897026471, 0.09515066710965973, 0.052906976746661324, 0.07005993489708219, 0.04452607860522611, 0.022527060671044246, 40.3839168548584, 61.64063113076346, 37.982956409454346, 18.95660867009844, 46.96296807697841, 55.796442236219136, 84.92201573508126, 26.96625576700483, 0.4945820580635752, 7.839028869356428, 54.55093594959804, 83.40364674159459, 71.70247731889997, 75.40476935250419, 69.06850555964878, 74.14414378574916, 73.50154658726284, 74.12657873971122, 70.5369656426566, 68.79931844983781, 64.32809707096645, 60.11635616847447, 59.9221123286656, 61.92718178885323, 60.33555793762207, 63.019973618643625, 63.2222843170166, 58.76987171173096, 54.97634983062744, 56.76265178407942, 56.27142456599644, 57.71736553737095, 55.06367826461792, 53.922832693372456, 49.98103625433785, 47.24554436547415, 47.9688309941973, 48.71561643055507, 46.84299005780901, 50.05830717086792, 45.13576555252075, 47.423935890197754, 43.2914148739406, 43.95554453986031, 46.340110710689, 43.87136016573225, 42.69252879279, 45.0706331389291, 47.01191118785313, 47.73192521503994, 43.044889313834055, 49.46051890509469, 42.17201491764614, 40.37867096492222, 43.4994717325483, 45.08497074672154, 38.90925203050886, 41.31515611921038, 39.036365849631174, 40.893622807094026, 42.87994602748326, 42.49012776783535, 40.40725237982613, 40.137606688908164, 38.87008850915091, 40.971810885838096, 38.08116919653756, 44.27070093154907, 49.106240681239534, 55.54196098872593, 48.443215778895784, 51.00265768596104, 52.1129937171936, 54.136875425066265, 53.8460898399353, 56.08717918395996, 35.99178334644863, 38.406139918736045, 42.95902000154768, 38.78864867346627, 41.37749883106777, 40.32935612542288, 39.15279681341988, 42.135429177965435, 58.010579517909456, 53.21871961866106, 52.565943309238975, 48.995955399104524, 50.16504192352295, 42.2710406439645, 43.54252624511719, 43.422044481549946, 44.17327676500593, 41.70352567945208, 39.714020184108186, 37.99025896617344, 37.972415992191856, 42.59740447998047, 42.24357441493443, 40.395944186619346, 42.62996373857771, 42.74311167853219, 44.844736780439106, 46.203036648886545, 46.2522611618042, 44.742903981889995, 47.32789788927351, 46.66205201830183, 46.07214648383004, 39.436853068215505, 43.15592152731759, 47.48382936205183, 44.71509034293038, 43.07674333027431, 43.1873517036438, 42.93390573774065, 40.21764298847744, 41.5080554825919, 43.87921510423933, 43.27696262087141, 44.87996414729527, 45.380588803972515, 46.21211794444493, 44.419850962502615, 46.90505831582205, 45.72657782690865, 46.49289812360491, 47.02462291717529, 47.41768251146589, 48.610698631831575, 47.572338989802766, 47.372929164341514, 48.58636951446533, 48.66438736234392, 50.34513575690133, 50.929868357522146, 53.22296149390084, 55.426891871861045, 60.220217841012136, 58.1011631829398, 57.04018368039812, 56.996597630637034, 60.00321865081787, 65.0299346106393, 69.15529550824846, 73.29340635027204, 56.98783942631313, 5.448502446923937, 1.1099076313631875, 0.6218985148838588, 0.007080636752237166, 1.6514677086046763, 56.90334933144705, 69.30430657523019, 55.6146183013916, 28.602926526750835, 35.6983504976545, 32.711059365953716, 21.506437744413102, 0.17862913411642822, 0.04762319062969514, 0.09365940998707499, 0.03492025851405092, 0.08746865325208221, 0.02167710565429713, 0.031322645489126444, 0.01377627273489322, 0.3223976359835693, 0.13705507639263356, 0.11611370795539447, 0.1336740313896111, 0.15232356637716293, 0.1700727939605713, 0.20019753676440033, 0.20039300913257257, 0.14730816121612275, 45.23258522578648, 72.67432880401611, 44.527746064322336, 28.548004490988596, 58.45755018506731, 60.10278633662632, 93.45006098066057, 31.104222433907644, 0.47336139104196, 7.349647266524179, 55.62164640426636, 86.61213030133928, 74.71170043945312, 80.64266886029924, 73.16198117392403, 77.61601965767997, 74.44322204589844, 76.4997707094465, 75.20179857526506, 73.4288614818028, 67.82379136766706, 60.9959077835083, 63.042610849652974, 63.632429531642366, 62.531570843287874, 67.42151846204484, 65.46592712402344, 62.56827122824532, 57.838295459747314, 59.998771803719656, 57.808616229466026, 60.053697313581196, 58.583069392613, 57.25496292114258, 53.13992357254028, 50.195325647081646, 50.54186357770647, 52.278152397700715, 48.76052263804844, 52.43403870718819, 47.90395566395351, 51.15618160792759, 48.01446328844343, 48.076972757067, 49.315589904785156, 46.352078982761924, 45.59606981277466, 46.41703074319022, 50.358931405203684, 49.97533178329468, 44.537570817129954, 50.470436096191406, 44.10964168821062, 43.29992989131382, 45.85449416296822, 46.01044648034232, 39.44850867135184, 41.88229240689959, 40.559765338897705, 42.71587126595633, 46.804448400224956, 44.36550562722342, 42.65830544063023, 42.900860105242046, 40.320351260049, 43.21828508377075, 40.02797801154, 47.039714404514854, 54.07332720075335, 58.675397055489675, 52.03607715879168, 54.555018016270225, 53.30893155506679, 55.62452643258231, 56.90157059260777, 59.97984491075788, 38.53366020747593, 42.871830531529014, 48.00817516871861, 47.411185945783345, 47.31165994916643, 44.734611306871685, 41.16944544655936, 45.79814427239554, 59.9944361277989, 55.524503639766145, 53.80547761917114, 50.83824593680245, 52.61228779384068, 44.60158109664917, 47.220225129808696, 47.215156418936594, 46.8007241657802, 44.79491472244263, 42.70637307848249, 42.82962369918823, 40.4606979233878, 45.73537424632481, 43.87281928743635, 39.59977790287563, 45.65175267628261, 44.07918425968715, 47.28522205352783, 47.65913936070034, 46.27923059463501, 45.17309822354998, 47.033335958208355, 47.8151125226702, 47.40342133385794, 40.54237052372524, 46.07100697926113, 47.53887299128941, 46.54796607153756, 45.337662833077566, 44.879936354500906, 44.9101471219744, 43.079814434051514, 44.63957037244524, 45.8151638848441, 45.19461679458618, 45.79885993685041, 47.390278816223145, 47.36523403440203, 47.065784045628135, 49.48899957111904, 48.655094146728516, 46.93657534463065, 50.33873299189976, 48.02434710093907, 50.706879820142476, 50.107566424778526, 50.610980783190044, 49.88230235236031, 51.923224517277305, 54.625524861471995, 53.50776815414429, 55.26112869807652, 58.19573163986206, 62.32819707053048, 62.512956619262695, 59.09343542371477, 60.680473463875906, 64.10966655186245, 69.21896185193742, 72.95725945064, 76.77956077030727, 63.60091250283377, 7.167979666164943, 1.7550397281135832, 1.743203906076295, 0.13250577050660337, 2.5260143407753537, 64.14262880597795, 75.013231413705, 65.57153279440743, 43.772588048662456, 46.02817480904715, 43.25910227639334, 35.21804584775652, 0.5471715075629098, 0.13232966352786335, 0.19941583728151663, 0.055868927988090684, 0.20875750029725687, 0.09517525043338537, 0.12825655351792062, 0.16854864146028245], [0.05962905354265656, 0.027092802371563654, 0.05304594411115561, 0.0802790726135884, 0.041790011671504805, 0.03710204376173871, 0.02102134905622474, 0.06342635263821908, 0.05863085389137268, 36.647404943193706, 51.802117415836875, 32.73875141143799, 31.693933418818883, 45.15867723737444, 52.501450129917686, 72.28382614680699, 14.359712617737905, 0.3033776208758354, 4.297283215182168, 43.78732170377459, 80.1949269430978, 67.39055728912354, 68.94005421229771, 64.52022865840367, 73.60130882263184, 71.4418225969587, 71.08453232901437, 65.27852031162807, 65.66668837411063, 59.15174470629011, 55.96487004416329, 60.37361322130476, 76.55789239065987, 87.18821934291294, 70.42095851898193, 58.65981919424874, 61.052292415073936, 61.53102329799107, 59.743307386125835, 60.78628063201904, 58.818884304591585, 58.21412352153233, 58.984300068446565, 58.414214270455496, 52.04903554916382, 46.681145668029785, 45.241996560777935, 45.158107485089985, 44.357098306928364, 44.83503014700753, 42.483249051230295, 41.46702289581299, 40.61569486345564, 42.65961517606463, 42.084877559116904, 42.31257350104195, 42.82550689152309, 45.1836907523019, 48.29316248212542, 43.808107239859446, 44.235880034310476, 43.459766251700266, 37.48342956815447, 43.18420764378139, 42.42620434079851, 39.053482736860005, 41.00305693490164, 39.50884682791573, 42.45703002384731, 41.12656116485596, 38.65119593484061, 39.28896066120693, 37.30412435531616, 36.601063932691304, 38.75024250575474, 36.89817237854004, 39.48180443899972, 43.87937143870762, 44.94862624577114, 46.700541564396445, 47.63884367261614, 51.00418976375035, 51.331581933157786, 48.94300665174212, 44.40685435703823, 35.997800486428396, 34.82797050476074, 35.5658518246242, 34.204084805079866, 36.67634766442435, 35.9871141569955, 40.27107463564192, 42.79922185625349, 51.037655762263704, 51.77505418232509, 51.120801380702424, 48.655264377593994, 51.373007093157085, 42.241034848349436, 36.76203284944807, 40.623615809849326, 37.86434718540737, 39.15548924037388, 34.83482837677002, 38.119325229099815, 40.7014217376709, 41.04730306352888, 38.71711002077375, 42.92362935202462, 41.13804306302752, 40.95295694896153, 46.002907684871126, 47.81103045599801, 47.504559312547954, 48.54567738941738, 47.75365570613316, 47.60031591142927, 43.394335065569194, 40.72288472311837, 43.526111125946045, 43.5962427684239, 41.427796840667725, 39.848266329084126, 39.34106867653983, 38.661159651620046, 38.695417744772776, 40.635500703539165, 41.144602162497385, 44.003226552690776, 41.98847825186593, 44.72441135134016, 43.82792002814156, 43.02307544435774, 41.93451506750924, 43.50357116971697, 41.16846227645874, 44.759034224918906, 42.46290472575596, 44.65813248498099, 45.35253545216152, 44.09376505443028, 45.444182191576274, 49.68111726215908, 50.27557386670794, 53.70096629006522, 53.71583890914917, 56.8677259172712, 56.654499598911826, 57.21732105527605, 56.50979988915579, 55.04851382119315, 55.811106409345356, 61.87980897086007, 64.50557490757534, 72.90900421142578, 45.64698968614851, 4.944431483745575, 0.9837430013077599, 0.579176158777305, 0.22137214482894965, 0.16336300543376378, 43.29213053839547, 66.90742819649833, 47.676356996808735, 31.754827431270055, 14.55307229927608, 19.675585678645543, 17.417301280157908, 1.2671513365847724, 0.19639569148421288, 0.06046515117798533, 0.07659334503114223, 0.044685476659131904, 0.02877480416957821, 0.005784063200865473, 0.016489929353286113, 0.05725034725453172, 0.04923105738790972, 0.07470944683466639, 0.06679736210831574, 0.04856271735791649, 0.04788809070097549, 0.027007663190098743, 0.016541272401809692, 0.0204116514152182, 46.500155517033164, 58.10135773250035, 37.06783349173409, 28.153642109462194, 53.71825688225882, 59.5634115764073, 78.28433213915143, 14.616074221474783, 0.39840949007443016, 3.1291620561054776, 43.030405793871196, 84.11808136531285, 68.14138657706124, 72.63974067143032, 66.52993256705147, 75.20887184143066, 73.53028433663505, 76.326142174857, 67.47395651681083, 67.5956472669329, 60.539807183401926, 58.010596888405935, 62.24908488137381, 74.3832174028669, 80.36329569135393, 69.61792741503034, 60.98471423557827, 65.7264984675816, 65.84713309151786, 60.689923013959614, 63.023975781032014, 62.0770822252546, 61.69958659580776, 62.54250035967146, 60.73477363586426, 55.799697467258994, 49.557373319353374, 47.213808468409944, 47.34324993406023, 47.052297592163086, 47.02918093545096, 45.2431777545384, 43.074669292994905, 42.647650378090994, 45.08683633804321, 43.6771753856114, 44.452660356249126, 44.906037262507844, 46.71197829927717, 49.4307667187282, 43.63068151473999, 43.37843063899449, 45.85918419701712, 41.46159635271345, 44.204647881644114, 45.064807074410574, 40.05263716833932, 41.54899774278913, 40.49744347163609, 43.212163720812114, 44.10544845036098, 40.35584265845162, 39.70604017802647, 40.40816606794085, 37.62310920442854, 39.965590136391775, 38.798615864345, 41.27221972601754, 46.15102243423462, 47.264318398066926, 48.58850608553205, 49.877973624638145, 53.09537172317505, 54.16957017353603, 51.85256828580584, 45.74151297977993, 39.86791583469936, 39.31632266725813, 39.05372939790998, 36.03816952024187, 41.52826084409441, 39.31659712110247, 42.16011960165841, 42.77455922535488, 51.934192248753135, 54.860016141619, 52.00106518609183, 50.973214694431846, 53.769951479775564, 43.61240775244576, 38.280078751700266, 41.61232362474714, 39.42422819137573, 41.58615323475429, 37.77798107692173, 40.225487504686626, 45.300146034785676, 43.2896535055978, 37.75069202695574, 42.25001539502825, 41.57197543552944, 42.41449662617275, 46.37879828044346, 47.98857430049351, 46.79731607437134, 48.84775032315935, 49.01415967941284, 46.88241761071341, 44.154714652470176, 42.85544320515224, 44.73757471357073, 44.599114486149375, 44.14457375662667, 42.83881616592407, 41.58705302647182, 40.548352922712056, 41.50073902947562, 42.98260218756539, 44.75748825073242, 45.77007702418736, 44.234473024095806, 46.14254910605294, 46.18437031337193, 44.93360424041748, 44.99243116378784, 45.610859053475515, 43.781856945582796, 45.60527270180838, 43.89093324116298, 47.38097170421055, 47.099323000226704, 48.06186737333025, 47.72392783846174, 52.39195694242205, 55.383201599121094, 55.40172202246529, 57.92057602746146, 58.83124514988491, 58.925483567374094, 59.41564423697335, 61.2217172895159, 56.421797479902, 58.90228353227888, 63.570097242082866, 69.05084323883057, 75.27376106807164, 56.11760187149048, 5.734743910176413, 0.5787412992545536, 0.5246810572487968, 0.2263516147754022, 0.18109518821750367, 45.5931133542742, 73.42554719107491, 55.63413231713431, 37.479163374219624, 18.116696528026036, 33.86590903145926, 32.86362443651472, 0.9347212889364788, 0.39483879453369547, 0.022386609011196663, 0.08035525852548224, 0.040528235092226944, 0.05609288186367069, 0.03641213310350265, 0.04689279517957142, 0.15368245488830976, 0.13790391013026237, 0.17308681937200682, 0.2579156660607883, 0.1411951713796173, 0.13150993894253457, 0.07173557034028427, 0.17458321979003294, 0.13144949504307338, 55.053641591753276, 66.05036095210484, 41.8503862789699, 43.689598764692036, 64.34589835575649, 64.98500061035156, 85.3713071005685, 17.888316188539775, 0.4900249625955309, 8.350707241467067, 50.260874952588765, 86.36521911621094, 71.556731905256, 74.2986091886248, 69.42961733681815, 80.85067013331822, 75.29006849016461, 78.69116306304932, 69.757155418396, 72.29992512294224, 64.61676692962646, 60.50130026681082, 65.72022424425397, 78.99157537732805, 80.37879712241036, 68.54132488795689, 65.17847320011684, 67.12340600149972, 67.97331660134452, 63.297602789742605, 66.37853131975446, 65.50366973876953, 64.74236256735665, 64.19512244633266, 64.31862667628697, 57.57479545048305, 53.93376220975603, 50.09101928983416, 49.145501477377756, 47.845055784497944, 50.4914995602199, 47.984273365565706, 46.023884296417236, 46.00550283704485, 49.43254198346819, 47.19783108575003, 48.86579826899937, 48.07769536972046, 46.98574774605887, 52.57083831514631, 45.52595206669399, 46.31742484228951, 46.96587242398943, 46.044815744672505, 47.01088980266026, 46.54228591918945, 41.82564721788679, 42.51119818006243, 41.668075970241, 44.514624391283306, 46.25188595908028, 43.27623653411865, 42.96686799185616, 43.182425430842805, 39.80966213771275, 42.68201616832188, 41.059365136282786, 43.78072091511318, 48.49077272415161, 49.51297780445644, 52.005088193076, 53.330679416656494, 57.6048846244812, 54.96141120365688, 53.4665653364999, 49.2118706703186, 42.76246241160801, 43.77050706318447, 45.493389333997456, 45.23883513041905, 49.591957977839876, 45.115084239414756, 45.203381947108674, 44.53209563664028, 55.48169231414795, 58.70534379141671, 56.236621039254324, 54.66400745936802, 56.71548741204398, 45.75825466428484, 42.02722488130842, 44.20513425554548, 42.522891998291016, 45.204215730939595, 39.78203957421439, 43.274103437151226, 48.37696123123169, 45.48445742470877, 39.31176117488316, 44.31381797790527, 42.61610555648804, 44.86862816129412, 47.61228765760149, 50.30649682453701, 49.51308897563389, 50.028495924813406, 47.36470249720982, 46.592281682150706, 43.710564953940256, 44.999712875911165, 46.711887972695486, 44.71959972381592, 45.129550388881135, 45.33645732062203, 43.45086560930525, 43.137164865221294, 44.111823422568186, 44.550675119672505, 44.95849616186959, 48.57814979553223, 46.21226385661534, 48.82546050207955, 48.592254638671875, 47.138212067740305, 46.67427737372262, 46.486762864249094, 44.80563579286848, 48.383645398276194, 46.1450400352478, 50.89021151406424, 50.25666434424264, 50.25180755342756, 50.88503163201468, 55.52099132537842, 58.44892052241734, 57.94204943520682, 60.020526613507954, 61.177637917654856, 61.11133125850132, 60.2652838570731, 64.97218118395124, 58.557110922677175, 61.7938597542899, 65.87012468065534, 74.03019332885742, 79.65810911996024, 62.62203638894217, 8.526991724967957, 1.9414552279881068, 3.241117945739201, 0.3279868374977793, 0.5363938201751027, 54.86516128267561, 79.01733234950474, 64.48903819492885, 50.03913361685616, 24.184190102985927, 44.90622138977051, 50.62791354315621, 1.9039282245295388, 0.6002058589032718, 0.1660851657922779, 0.1970601672572749, 0.17306992385004247, 0.13819546305707522, 0.19228222221136093, 0.19122338188546045], [0.03352956028122987, 0.11164357353534017, 0.019785925080733638, 0.04710381957037108, 0.03941523070846285, 0.05297597697270768, 0.047231133095920086, 0.08378599264792033, 0.05511133006906935, 39.20448793683733, 49.57862091064453, 32.102598667144775, 22.606493915830338, 50.9109970501491, 55.7135363306318, 76.31169686998639, 6.868041132177625, 0.16781226811664446, 0.19106813307319367, 29.56370258331299, 86.28257029397147, 67.17048004695347, 70.8558601651873, 65.7995935167585, 69.34296635219029, 68.16022314344133, 69.93823937007359, 66.34549263545445, 55.94396986280169, 50.550656523023335, 57.56948355266026, 61.02732058933803, 64.78034142085484, 61.4286207471575, 80.00173922947475, 81.60179124559674, 63.99444457462856, 59.226882525852744, 58.78030790601458, 60.86166858673096, 62.68093626839774, 63.416257177080425, 61.86943531036377, 60.06676687513079, 57.48211342947823, 50.16202293123518, 44.319880281175884, 43.466547693525044, 44.086215836661204, 44.24949502944946, 45.485826219831196, 42.58365052086966, 40.54353434698922, 41.702382700783865, 40.505294936043875, 42.810161794934956, 42.179369585854666, 42.951401301792686, 48.44059978212629, 45.32170976911272, 41.66775287900652, 49.65138592038836, 49.339248520987375, 44.550237383161274, 42.68918323516846, 42.86493444442749, 41.75456714630127, 39.31578418186733, 44.293025493621826, 38.427064418792725, 37.771345547267366, 36.02364431108747, 38.468798773629324, 37.52906881059919, 36.01221105030605, 37.35622194835118, 39.49735798154558, 39.5649014200483, 42.9573837007795, 42.29998336519514, 44.89725126538958, 46.71285029820034, 44.7926287651062, 43.90471846716744, 38.46703045708792, 37.34664038249424, 33.63426998683384, 30.973540714808873, 31.97334827695574, 33.7339106287275, 33.76248509543282, 37.213589327675955, 38.48652710233416, 40.00750514439174, 45.296244621276855, 46.963965143476216, 47.12465960638863, 50.21154621669224, 43.62945168358939, 37.9178135735648, 38.264452253069194, 38.4021829196385, 35.5095887865339, 36.14910445894514, 38.984639985220774, 44.65161854880196, 39.89236307144165, 38.426703112465994, 40.09300620215279, 40.09442016056606, 43.97011143820626, 41.61963312966483, 42.60466187340872, 45.08951834269932, 46.44652237210955, 45.7636673109872, 47.99129104614258, 43.74979795728411, 41.08488239560808, 41.111077104296, 43.988305296216694, 42.5006890296936, 41.84472002301897, 39.414351327078684, 38.08899286815098, 39.22446748188564, 41.72603089468819, 43.44801337378365, 41.71628257206508, 43.134566238948274, 44.86032853807722, 44.73857178006853, 44.5098614011492, 46.437326431274414, 45.83689437593733, 47.28104618617466, 47.791203771318706, 47.77689048222133, 48.70872729165213, 48.771851675851, 51.771152768816265, 55.24505404063633, 55.5048645564488, 57.17308534894671, 56.50323731558663, 59.98157501220703, 57.626163482666016, 59.65799740382603, 59.51305798121861, 57.15774025235857, 53.82813222067696, 58.022096157073975, 58.547737802777974, 67.27387619018555, 65.95606694902692, 61.56811973026821, 7.191706895828247, 1.3230919348342078, 1.2039795092173984, 0.07719486632517406, 0.11525652823703629, 29.53037554877145, 70.8569232395717, 51.51437514168875, 34.553575720105854, 31.49207435335432, 25.573220116751536, 19.535652433122905, 1.2992544025182724, 0.09587764952863966, 0.07717811329556362, 0.07677202365760293, 0.07113389298319817, 0.05401159443759492, 0.0341297720026757, 0.04063636643279876, 0.025284691447658197, 0.04904859932139516, 0.04086777740823371, 0.025314560559179102, 0.07305902575275727, 0.09601925300168139, 0.04685483453795314, 0.10754842470799174, 0.07731611374765635, 47.79183953148978, 53.92937094824654, 38.447405270167756, 26.38971335547311, 57.35627113069807, 61.569703919546946, 83.32921069008964, 7.3970061881201605, 0.2768157704600266, 0.16682886731411728, 33.46811771392822, 89.59173325129917, 68.92919417790004, 74.07461316244942, 66.5991713660104, 71.47873142787388, 69.83843544551304, 73.675112588065, 67.9820921761649, 60.29437596457345, 51.66863557270595, 59.86023167201451, 60.55999864850725, 70.08590248652867, 63.71986566271101, 77.30553940364292, 77.88296249934605, 65.90028681073869, 60.779499190194265, 62.70234366825649, 62.80760192871094, 65.60550253731864, 63.37067699432373, 63.932105336870464, 61.544259616306846, 60.05469785417829, 53.63248137065342, 46.82235390799386, 46.4360305922372, 48.16817133767264, 45.76776327405657, 47.597421986716135, 44.86796808242798, 46.21943439756121, 43.69793660300118, 43.13112688064575, 45.03180660520281, 44.59145757130214, 44.33805676868984, 48.7537898336138, 46.137949398585725, 42.57914808818272, 49.55911036900112, 52.029368673052105, 46.00133739198957, 43.79882097244263, 43.61661836079189, 44.71066781452724, 40.64671857016427, 44.0926741872515, 40.54339190891811, 40.076844692230225, 39.090082372937886, 39.05111687523978, 39.12644577026367, 37.93602132797241, 36.79437323978969, 40.657443114689414, 41.2888537134443, 45.51244476863316, 43.7282828603472, 45.690245696476524, 46.23651654379708, 46.157921995435444, 45.66984231131417, 39.84426416669573, 40.81881502696446, 37.58350794655936, 34.19954068320138, 34.013613837105886, 36.49283184323992, 39.4702912739345, 38.765021324157715, 41.09912620271955, 41.88272666931152, 46.65797689982823, 48.895515714372905, 50.4841970035008, 52.06988361903599, 45.49342407499041, 40.63837725775582, 40.61715745925903, 41.88860831941877, 37.353303704942974, 37.2027188709804, 41.8510776247297, 46.447755677359446, 41.01551505497524, 39.09667273930141, 39.83161497116089, 40.85583850315639, 44.65414769308907, 42.789553437914165, 44.51008026940482, 45.44302879061018, 47.05046674183437, 47.80455820901053, 48.02020597457886, 44.7123874936785, 42.75231109346662, 42.34893689836775, 46.87145682743618, 43.83529554094587, 43.2545234135219, 41.49953351702009, 41.074043205806184, 40.016947746276855, 43.37556103297642, 45.38250650678362, 45.0969946043832, 46.75781556538173, 46.47054576873779, 47.59263815198626, 45.165875571114675, 50.05474969318935, 48.50349834987095, 49.93337161200387, 47.66345419202532, 51.22947815486363, 49.736956460135325, 52.52251706804548, 54.74375888279506, 59.592684337071006, 57.35730641228812, 60.282001222882954, 57.861544132232666, 63.96170466286795, 58.74363531385149, 63.485760007585796, 60.48545837402344, 60.90977791377476, 55.65901729038784, 64.52350125994, 59.02770546504429, 72.73406941550118, 67.88210759844098, 74.27452673230852, 12.408476931708199, 1.6692759415933063, 1.4820467425244195, 0.026817546159561192, 0.010290306710105921, 33.05410582678658, 77.01452105385917, 58.24567529133388, 37.50865847723824, 30.727435520717076, 43.201505184173584, 32.03615999221802, 2.0314611068793704, 0.28686226851173807, 0.05283957786325898, 0.08513399745736804, 0.027678900564621602, 0.12797771633735724, 0.010624365614993232, 0.10232971009931394, 0.17116036345916136, 0.189204943765487, 0.0879255108801382, 0.16715225710400514, 0.11404941443886076, 0.1486360678183181, 0.24376365116664342, 0.17648575055812085, 0.2974090911448002, 59.90563814980643, 60.645426750183105, 42.25196783883231, 32.565529346466064, 71.11482647487095, 64.57167312077114, 91.21122632707868, 8.482300911630903, 0.4121422788926533, 0.3449276584599699, 36.11388751438686, 93.47406005859375, 71.83847440992082, 78.24797221592495, 70.08717400687081, 75.29029778071812, 73.12625353676933, 75.52413245609829, 71.20611885615757, 64.36508233206612, 55.7020057950701, 63.98071493421282, 62.930550302777974, 77.21743624550956, 72.96716063363212, 78.32473591395787, 74.94818237849644, 67.8914737701416, 65.22083636692592, 65.89351231711251, 64.76526382991246, 68.0727036339896, 65.39230401175362, 66.92502103533063, 65.0390020098005, 63.28956372397286, 55.06815637860979, 50.90368059703282, 48.73660693849836, 49.13331086294991, 48.14607606615339, 48.85945803778512, 48.49195391791207, 48.369686467306956, 47.893943309783936, 46.47862652369908, 47.600284644535606, 47.78714949744088, 47.38230228424072, 50.944417885371614, 48.44665513719831, 41.89606721060616, 50.09294741494315, 54.08467360905239, 48.22735609327044, 44.9045399257115, 45.783236912318635, 43.68607602800642, 41.78336048126221, 46.565089906964985, 41.03186764035906, 41.61650991439819, 39.89566693987165, 40.86711890356881, 42.53273064749581, 42.05855083465576, 40.772866589682444, 44.18968146187918, 44.41863850184849, 50.107952049800325, 45.4622996194022, 50.14602470397949, 51.39772530964443, 49.73201976503645, 49.70243086133684, 43.09970017841884, 43.171346528189524, 42.729889256613596, 41.013281209128245, 46.00926528658186, 44.16208669117519, 42.57455880301339, 40.361703463963096, 42.45755461284092, 44.184015205928254, 47.47674914768764, 52.26788990838187, 53.22240216391427, 54.454140595027376, 47.684031282152446, 43.06967353820801, 42.790248257773264, 43.41425207683018, 39.58270617893764, 39.85349832262312, 43.1152537209647, 48.21564143044608, 41.620550291878835, 39.40360246385847, 40.90710578645979, 42.36245461872646, 46.20963396344866, 43.92574719020298, 46.79094110216413, 46.173082964760916, 47.86917298180716, 46.866436753954204, 47.661758831569124, 46.09280000414167, 43.09341205869402, 44.44993666240147, 46.459004810878206, 46.33026858738491, 45.07826920918056, 44.819250788007466, 42.65719025475638, 43.45590305328369, 46.31625754492623, 47.6565511567252, 46.464657170431956, 46.99944264548165, 48.42472662244524, 48.75011076245989, 47.60130950382778, 50.95075811658587, 49.84754398890904, 51.95494304384504, 49.95960800988333, 53.169321400778635, 53.6862986428397, 53.98265668324062, 55.54549067361014, 61.696605818612234, 61.069940839494976, 63.67873232705252, 61.917502948216026, 66.28195135934013, 62.8139317376273, 66.47876603262765, 62.857163429260254, 63.07491997310093, 58.39757333483015, 66.98725605010986, 62.896559715270996, 74.80466733660016, 70.2880950655256, 80.68086310795375, 14.348799603325979, 3.139871184315, 5.439792445727757, 0.16461809165775776, 0.1728409861347505, 38.65807465144566, 81.3566449029105, 65.19259888785226, 51.4357145854405, 52.11170482635498, 49.382997853415354, 48.92839459010533, 5.753674711499896, 0.5261663432632173, 0.16775271988340787, 0.21083590734217847, 0.13065816036292485, 0.2350582368671894, 0.14245869857924326, 0.19045275609408105], [0.0472919739383672, 0.019150392218892063, 0.0074175455042028, 0.051501829110618146, 0.017633187917194197, 0.014808392351759332, 0.052279481132115634, 0.08170561106609446, 0.25003258192113464, 33.703164849962505, 50.50517014094761, 34.1506427356175, 35.05799756731306, 52.121039731161936, 60.42128481183733, 67.30940927777971, 3.227036987032209, 0.08002216568482773, 0.06123522057064942, 32.01860884257725, 83.77790451049805, 65.2167786189488, 66.22059876578194, 61.0263408933367, 66.00638580322266, 63.13076959337507, 62.07704748426165, 53.641632148197715, 53.45971441268921, 54.103680406297954, 60.01948438371931, 61.85284301212856, 64.90542984008789, 49.930085114070344, 38.1476217678615, 57.05420514515468, 77.8109096799578, 70.76950795309884, 62.378953661237446, 63.27707086290632, 60.05997153690883, 59.62222807747977, 58.575794628688264, 58.241905893598286, 59.449231828962056, 52.66001149586269, 43.66438375200544, 44.49835518428257, 44.81283065250942, 43.73234755652291, 44.93675524847848, 41.776714529309956, 39.38323381968907, 41.24879387446812, 42.066030570438926, 40.670436246054514, 41.566020829336985, 41.62822110312325, 42.70186022349766, 44.73547983169556, 47.71290104729788, 43.55956670216152, 52.36493539810181, 53.344718251909526, 45.88076530184065, 45.664676325661794, 42.82024015699114, 42.0612849508013, 45.83856541769845, 39.97706856046404, 36.53428479603359, 37.619496141161235, 37.95099469593593, 39.0170498575483, 37.36553600856236, 36.78992291859218, 37.87481812068394, 39.03977394104004, 39.08933891568865, 40.628264154706685, 38.90757056644985, 39.63966751098633, 38.465053694588796, 41.62041480200631, 39.86569241115025, 35.757094042641775, 27.332241705485753, 30.28669043949672, 32.81704371316092, 28.551654032298497, 32.45305190767561, 32.789702551705496, 36.98380197797503, 38.433821541922434, 43.96964938299996, 44.88046441759382, 43.43039969035557, 42.117499351501465, 40.79451717649187, 38.184798104422434, 38.186340604509624, 35.401582513536724, 37.0818202154977, 36.63892466681344, 37.59791156223842, 40.190819467817036, 42.52088049479893, 38.687090328761506, 39.306185245513916, 37.68231133052281, 42.65582145963396, 39.63182299477713, 38.06063379560198, 45.31590454918997, 43.2069490977696, 43.32237952096121, 42.545032433101106, 44.98974915913173, 43.436600957598, 39.75884301321847, 41.331744943346294, 40.9960218838283, 38.962138244083945, 39.65872989382063, 40.52348531995501, 40.6615286554609, 41.110180786677766, 43.281590121132986, 42.622115748269216, 45.230514662606375, 48.231941904340474, 50.91899790082659, 49.88449450901577, 52.37586144038609, 52.36258690697806, 54.39151995522635, 50.97643518447876, 53.32024669647217, 55.318024022238596, 60.004198346819194, 56.89735303606306, 57.755938461848665, 57.357407161167686, 56.928453172956196, 55.743128708430696, 57.45997299466814, 57.00616182599749, 60.144204548427034, 59.956693513052805, 59.08113016401018, 52.943640436444966, 56.767109053475515, 56.6234724181039, 66.29069219316754, 66.31911727360317, 70.7765256336757, 40.279829365866526, 1.1921620347670145, 2.801854350737163, 0.05112626676314643, 0.15082314903182642, 21.088698148727417, 74.74326610565186, 48.75621822902134, 37.26780959538051, 16.89895350592477, 21.872058902467998, 20.544742788587296, 1.5921852439641953, 0.18231713479118689, 0.01570511539466679, 0.02797850430943072, 0.06797999436301844, 0.013500155631585844, 0.032803575308727365, 0.0316538045049778, 0.008456257088775081, 0.062205322086811066, 0.04564289635579501, 0.04984554548614791, 0.010125158071917082, 0.029481057343738418, 0.013605029155899371, 0.08707447190369878, 0.3608008181410176, 45.90524727957589, 56.87446219580514, 37.22967093331473, 34.83406754902431, 59.440185274396626, 64.1113063267299, 74.17191573551723, 3.6243688549314226, 0.06294396852276155, 0.1307434250733682, 31.647123404911586, 85.25534861428397, 67.83969579424176, 70.6163557597569, 63.30282783508301, 69.90384578704834, 67.43925026484898, 65.64387048993791, 54.56928614207676, 54.987765720912385, 56.24763740812029, 64.6642370223999, 65.31249700273786, 67.95464679173061, 52.79080786023821, 44.71567051751273, 60.31130872453962, 78.15271936144147, 69.77021803174699, 63.9283880506243, 63.68133095332554, 61.433442796979634, 60.879317011152, 61.31520530155727, 60.70726571764265, 61.01147869655064, 55.923156533922466, 47.16945811680385, 45.5970390864781, 46.17783553259713, 46.412090573992046, 47.2123076575143, 44.38839994158064, 42.72291326522827, 43.02849851335798, 43.382151399339946, 43.19609253747122, 43.031177043914795, 42.17235885347639, 44.9197530065264, 45.8173942565918, 47.621011120932444, 42.602434975760325, 53.01205587387085, 55.896256583077566, 46.857014996664866, 46.327940940856934, 42.63320854731968, 43.700948647090364, 46.01916994367327, 41.87233911241804, 38.98611300332205, 42.30619852883475, 40.527737617492676, 41.510049615587505, 40.442292145320344, 39.8505870274135, 39.647418226514546, 41.274172169821604, 41.4241247177124, 43.690196309770855, 40.761068548474995, 42.093514169965474, 40.26950434276036, 42.36625875745501, 42.81247207096645, 40.58241299220494, 33.45041022981916, 34.098909923008506, 35.15993111474173, 31.809235300336564, 36.754164014543804, 36.52592958722796, 39.392124039786204, 40.890749726976665, 45.61136974607195, 45.643908160073416, 47.01901919501168, 42.22039869853428, 43.47353063310896, 40.160521847861155, 39.97461584636143, 38.78648778370449, 39.91994047164917, 37.374245575496126, 40.86647272109985, 40.84942878995623, 43.15903432028634, 40.20776959827968, 39.66986438206264, 37.89070517676217, 43.33467435836792, 40.67675910677229, 40.65006412778582, 44.84069640295846, 42.722426891326904, 44.11785445894514, 43.85430233819144, 45.10701738085066, 43.575262682778494, 39.8358325277056, 41.8636017526899, 45.14103923525129, 42.46828957966396, 41.43710395268032, 41.899235589163645, 42.62921333312988, 43.037479060036794, 45.62431076594761, 45.65005384172712, 46.71962826592581, 51.01946537835257, 52.884264605385916, 52.65167365755354, 55.78091648646763, 56.18909536089216, 56.00687885284424, 55.51294878550938, 56.728202615465435, 56.23565523965018, 60.558344977242605, 60.86004270826067, 58.88992963518415, 60.03112261635916, 60.38340323311942, 59.3141519001552, 60.31180899483817, 60.55617019108364, 62.61958367483956, 62.36521012442452, 60.68811648232596, 55.42920214789254, 58.76616137368338, 60.94153118133545, 67.97894464220319, 69.36353302001953, 74.74150821140834, 58.86529132298061, 1.5145887391907829, 2.938929498195648, 0.36459898576140404, 0.42898761640701977, 23.928281000682286, 80.41073104313442, 57.557869638715474, 41.633362770080566, 23.05992467062814, 31.373211520058767, 39.04985925129482, 4.2425348843847, 0.31486557157976286, 0.03254100600523608, 0.07406540853636605, 0.04569146928510495, 0.041980473058564324, 0.04443981305563024, 0.020087951195559332, 0.13539240775363787, 0.1815548414098365, 0.14209173327045782, 0.1681484007941825, 0.07703511882573366, 0.1453906755362238, 0.14319845102727413, 0.19250487669238023, 0.6162885501980782, 58.956604548863, 63.65146064758301, 40.82890381131853, 44.84848880767822, 68.49495261056083, 71.66718741825649, 82.1091695513044, 4.667190977505275, 0.2928992217140538, 0.2841288580426148, 36.23607158660889, 90.29673222133091, 70.10614258902413, 73.61344732557023, 67.34831918988908, 72.38379682813371, 69.0895586013794, 67.4357761655535, 57.52467114584786, 57.52722460883004, 57.552053996494834, 65.81431674957275, 66.53902081080845, 68.79737990243095, 54.526582513536724, 55.2570709500994, 66.18763651166643, 74.0623426437378, 67.81987258366176, 68.41759831564767, 64.89028276715959, 63.0668739591326, 61.293735367911204, 64.41458129882812, 62.27650247301374, 64.97625282832554, 57.12061950138637, 48.93399831226894, 46.54945993423462, 49.89981528690883, 50.00654656546456, 48.81314134597778, 46.56083066122872, 44.65838262013027, 45.563291685921804, 45.97212369101388, 44.55866207395281, 45.24627317701067, 45.58168009349278, 46.5570056779044, 45.6317001751491, 48.96264573505947, 42.99506030763899, 55.532890115465435, 58.140820026397705, 48.25809144973755, 47.13395977020264, 44.47352927071707, 44.20100007738386, 47.309919425419395, 42.21145289284842, 39.93539326531546, 43.730356897626606, 42.38534198488508, 42.92603342873709, 42.48402030127389, 41.7038904598781, 42.86978081294468, 44.15824433735439, 44.446827343532014, 45.39368268421718, 44.84240913391113, 45.10976191929409, 44.07680450166975, 44.96408946173531, 46.636048385075156, 43.43492644173758, 41.09312990733555, 40.70393351146153, 45.693625995091026, 41.78972155707223, 41.01818316323416, 38.773397377559114, 41.303250380924766, 46.361709186008994, 49.24301597050258, 50.333181381225586, 49.290694509233745, 46.48626954214913, 46.0621132850647, 42.89064277921404, 43.422120911734446, 39.84658833912441, 42.68458005360195, 40.120990071977886, 42.210316862378804, 44.60652126584734, 45.0318135534014, 40.350864274161204, 39.426545415605815, 38.88756322860718, 43.55436250141689, 43.298429080418174, 43.51271847316197, 45.70446865899222, 43.57257372992379, 45.51056528091431, 43.804768630436485, 45.949278014046804, 44.136003153664724, 41.06979785646711, 43.991407666887554, 45.8396806035723, 44.407983439309255, 42.96903582981655, 45.40869426727295, 44.23033537183489, 43.84289339610508, 46.273043223789756, 48.110139983040945, 49.79122883932931, 51.93751696177891, 53.53190967014858, 53.66946315765381, 56.88445370537894, 59.24746309007917, 58.73160798209054, 57.1555689402989, 59.15334974016462, 60.7010748726981, 62.62559386662075, 61.424576895577566, 62.0370397567749, 62.40876143319266, 63.349637848990305, 62.26484339577811, 64.40069879804338, 63.428194182259695, 65.95229407719204, 64.98998246874127, 64.22927284240723, 57.5564626285008, 61.20726503644671, 64.97510637555803, 71.33232593536377, 73.93977642059326, 78.51937580108643, 60.95451736450195, 2.8290700103555406, 6.560023146016257, 0.35566528514027596, 0.39498731227857725, 28.51512908935547, 86.86941514696393, 63.91482516697475, 55.319000244140625, 32.18875632967268, 38.972386837005615, 58.2069981438773, 8.818940264838082, 0.6284369326063565, 0.17588075516479357, 0.12375444652778761, 0.13856397542570317, 0.1941490891788687, 0.1013999678460615, 0.1466185932180711], [0.06662707017468554, 0.05477033908079777, 0.018458583358941332, 0.03542731755546161, 0.018350428269643868, 0.06702370781983648, 0.0318682249635458, 0.04534643762079733, 0.11241208908281156, 41.74413790021624, 49.33771644319807, 44.925905636378694, 38.6941670690264, 51.05549873624529, 61.401981353759766, 66.26239218030656, 2.184759646654129, 0.08987336778747183, 0.3217368514410087, 22.524116073335918, 84.31259618486676, 69.00887611934117, 68.22318771907261, 57.997829573495046, 56.59092705590384, 53.12437697819301, 52.9055677822658, 54.440456117902485, 58.31346539088658, 62.66241237095424, 64.37717914581299, 61.66125338418143, 65.63238511766706, 66.13807501111711, 56.98067930766514, 45.04373666218349, 43.57550934382847, 68.53068024771554, 70.27804797036308, 55.0196544783456, 57.73435388292585, 55.378136362348286, 58.81524344852993, 58.601461274283274, 57.75774499348232, 54.82798147201538, 45.38915245873587, 42.86187376294817, 45.071616309029714, 44.182069710322786, 43.640315192086355, 41.064260142190115, 40.741651807512554, 41.29003838130406, 41.667697293417795, 40.11646332059588, 41.46096406664167, 40.372671195438926, 43.87625864573887, 45.37529080254691, 43.23716333934239, 43.70370013373238, 49.268606185913086, 56.637796129499165, 55.60482134137835, 46.819393975394114, 44.35412447793143, 48.22852686473301, 49.14281252452305, 47.17142793110439, 42.93175527027675, 38.53047793252127, 39.836621148245676, 38.46502242769514, 37.658357415880474, 37.91900518962315, 37.34826626096453, 38.191068853650776, 38.83901269095284, 39.80322115761893, 39.85201835632324, 38.82819781984602, 38.738496576036724, 39.90032570702689, 37.76318836212158, 34.67631564821516, 27.24406906536647, 28.233011381966726, 30.883050850459508, 31.87590673991612, 31.10903753553118, 34.69874095916748, 37.92083951405117, 35.881682191576274, 40.45530959538051, 40.21694122041975, 41.59469257082258, 41.55267333984375, 40.44926813670567, 37.50036232812064, 37.2607467515128, 36.53493792670113, 39.044547353472026, 35.92828723362514, 36.46139471871512, 36.22063616343907, 41.446609088352744, 40.54934304101126, 40.800659384046284, 42.182465008326936, 42.22382416043963, 38.92067486899239, 42.96037837437221, 45.49660634994507, 41.47799757548741, 43.53482069287981, 42.60401569093977, 40.651981830596924, 44.85793488366263, 39.05742583956037, 39.656402247292654, 40.68726478304182, 37.00507736206055, 36.13554852349417, 38.28509535108294, 38.5652745110648, 42.495415346963064, 43.45996427536011, 41.257621560777935, 47.90191289356777, 53.41237980978829, 53.78301756722586, 54.657305921827046, 55.27285030909947, 53.77375214440482, 58.81160954066685, 55.66321052823748, 58.47806126730782, 58.080930028642925, 56.259852341243196, 58.655622482299805, 64.33330821990967, 64.80060236794608, 63.73884119306292, 63.03823348454067, 59.84527220044817, 58.9901157106672, 61.38373538425991, 57.71722309929984, 56.38284240450178, 55.310269832611084, 55.95581306729998, 58.71541173117501, 62.54095785958426, 69.8220932824271, 68.68916865757534, 74.88418252127511, 18.778276205062866, 1.9094898232391901, 0.2602218437407698, 0.4183935677366597, 18.70183559826442, 68.2831506729126, 53.41492632457188, 34.19828653335571, 24.901951176779612, 22.740866865430558, 25.362474305289133, 1.3434057533740997, 0.14213985497398035, 0.06417812194143023, 0.0314007821891989, 0.047331739483135085, 0.09561737706618649, 0.05068674570481692, 0.09304099317107882, 0.04963720470134701, 0.03298347869089671, 0.02139042460891817, 0.021467458689585328, 0.050040559843182564, 0.06692634483001061, 0.006876245465329183, 0.006234357274869191, 0.5995760155575616, 56.33535841533116, 53.2762576511928, 40.69864245823452, 35.4720025062561, 59.70496722630092, 64.88095133645194, 72.54232692718506, 2.1875586850302557, 0.06360214070550033, 0.32281675349388805, 23.725824390138897, 87.18878214699882, 71.23135471343994, 72.36236163548061, 59.98568139757429, 60.081872258867534, 54.23160369055611, 54.75583485194615, 56.143581186022075, 61.458782877240864, 64.73158591134208, 67.87809153965541, 65.06224373408726, 69.23788874489921, 67.59340299878801, 55.88044595718384, 47.493275438036235, 47.86137015478951, 69.90214347839355, 68.49858651842389, 55.25844669342041, 60.177229336329866, 58.40529973166329, 60.66631998334612, 60.119371686662944, 58.93254293714251, 53.96753740310669, 47.13005140849522, 45.563249996730256, 47.177983556474956, 46.01550129481724, 45.06310476575579, 43.3741192817688, 42.68377406256539, 43.56352022715977, 44.11059706551688, 43.856341634477886, 43.35954196112496, 43.22006034851074, 44.729810101645334, 45.99519518443516, 42.82089328765869, 44.98397173200335, 49.33510044642857, 58.84999833788191, 55.84291526249477, 49.05443491254534, 44.68129777908325, 48.29136984688895, 51.73501866204398, 48.01752744402204, 45.72558423451015, 41.47605902808053, 42.599975313459126, 39.87517670222691, 41.4458760534014, 42.684326444353374, 39.39590733391898, 41.28483418055943, 41.077757017953054, 43.5502005304609, 42.48853663035801, 40.58485875810896, 41.62074484143938, 41.8656827381679, 41.091358116694856, 38.19131204060146, 34.580381870269775, 33.276396070207866, 35.68814706802368, 35.29900973183768, 34.80281802586147, 36.66838502883911, 39.529413495744976, 38.630664008004324, 43.38081039701189, 42.28693464824131, 43.011326040540425, 41.53511871610369, 43.808604036058696, 41.2999187197004, 38.243666716984336, 37.491426944732666, 40.63309662682669, 38.21631513323103, 38.57049608230591, 38.698263032095774, 42.73136922291347, 41.7216465813773, 43.20806428364345, 43.374449321201865, 41.8723703793117, 41.10459443501064, 43.002630370003835, 46.5344865662711, 40.72888101850237, 44.07515777860369, 44.07673849378313, 42.910643168858115, 45.253051144736155, 41.55356270926339, 41.19709927695138, 42.2372967175075, 39.77076612200056, 37.85753100258963, 42.06192071097237, 40.34889098576137, 44.1406306539263, 43.42847503934588, 45.05794225420271, 50.56402485711234, 55.05541338239397, 56.337630476270405, 55.9250533921378, 57.53519766671317, 56.33245406832014, 59.41672815595354, 57.80473566055298, 60.16231850215367, 59.89386095319475, 58.63527815682547, 61.193354742867605, 65.30069896153041, 65.20826707567487, 66.28435543605259, 64.77719388689313, 63.07950578417097, 62.60265786307198, 62.90998363494873, 59.831889969961985, 58.64868818010603, 57.52976417541504, 57.99695062637329, 60.096338408333914, 64.316451890128, 72.976012638637, 71.32114628383091, 79.15906865256173, 34.00366401672363, 2.3607097480978285, 0.39907594716974665, 0.3265794744449002, 21.83273036139352, 73.66648292541504, 60.802685328892295, 40.166952405657085, 30.521039281572612, 38.72361006055559, 39.03483377184187, 5.232132502964564, 0.3279876245984009, 0.04084511773128595, 0.0737850514373609, 0.027026534945304905, 0.08536308445036411, 0.046828900929540396, 0.09331954536693436, 0.2527623011597565, 0.12689873709210328, 0.13354954735508986, 0.07159841127161469, 0.16453479469886848, 0.1923440231808594, 0.07923839667013713, 0.1098693265978779, 0.6818893700838089, 68.60129478999546, 59.89544514247349, 58.25410345622471, 53.792769363948274, 66.48463726043701, 69.9648301260812, 78.43897819519043, 2.8165115756647925, 0.16951207976256097, 0.2930080315896443, 26.870700665882655, 92.00245244162423, 73.27843298230852, 75.87600312914167, 62.31717722756522, 62.38418565477644, 55.937931878226145, 58.67751625605992, 58.715196337018696, 64.46507385798863, 68.0257546561105, 69.73488644191197, 66.60236058916364, 71.32443972996303, 68.21704551151821, 55.26172971725464, 51.917214325496126, 54.842089789254324, 67.0702314376831, 65.97397940499442, 57.73158502578735, 61.97107355935233, 59.04650729043143, 63.4464054107666, 63.476602281842915, 60.9920654296875, 58.94058895111084, 49.84592158453805, 47.70354529789516, 50.579706941332134, 48.93736818858555, 48.222937038966585, 46.672543798174175, 46.131442410605295, 45.714164870125906, 46.94889450073242, 46.18927574157715, 46.451604979378835, 44.874627930777415, 46.423968519483296, 47.182440825871055, 44.340565068381174, 44.29895230701992, 52.44220631463187, 60.77182837894985, 57.567499841962544, 50.4030350957598, 46.209477628980366, 49.4341470173427, 53.877638135637554, 50.81837408883231, 47.09043972832816, 42.549878801618306, 44.82278742109026, 43.18838351113455, 43.0715217590332, 44.23164163316999, 41.475569180079866, 44.35056700025286, 44.16572059903826, 46.31794943128313, 45.56042207990374, 42.736337184906006, 44.377248082842144, 43.239657742636545, 43.21219846180507, 40.55882038388933, 39.44535766329084, 41.833397933415, 46.71183933530535, 41.90308141708374, 39.89981501443045, 40.58511584145682, 41.651181425367085, 41.20627784729004, 46.071990149361746, 45.183951309749055, 45.65105438232422, 45.08343866893223, 46.00418267931257, 44.1536237852914, 42.31359141213553, 41.766643115452354, 43.1731322152274, 41.8022734778268, 41.708695139203755, 40.17736428124564, 45.99951001576015, 41.729504993983674, 43.63140065329415, 44.231290749141145, 43.54395409992763, 41.65261970247541, 45.58854143960135, 48.45117841448103, 41.97201796940395, 45.50414514541626, 44.98001820700509, 42.88922187260219, 46.9792685508728, 41.964833532060894, 42.3864780153547, 46.00626366479056, 42.28807415281023, 40.53303909301758, 44.26017788478306, 43.72330100195748, 45.703728675842285, 45.807256834847585, 46.113561221531455, 53.67141212735857, 58.38288484300886, 60.23159899030413, 58.940199851989746, 60.86777605329241, 61.00173037392752, 62.21375329153878, 59.399649483816965, 61.17393452780587, 62.27798938751221, 61.57278197152274, 61.81692777361189, 66.29494449070522, 67.59099197387695, 67.40208435058594, 67.24020521981376, 65.9786833354405, 66.05688531058175, 65.25418077196393, 62.282985142299104, 61.78010926927839, 60.89499909537179, 62.5593705858503, 61.432595116751536, 68.0139079775129, 75.85736806052071, 75.00123882293701, 83.01186561584473, 36.008459023066926, 4.049526955400195, 0.44699618007455555, 0.31406378746032715, 26.05062563078744, 80.46875544956752, 69.63101087297711, 48.34897041320801, 49.113796847207205, 49.518373080662315, 57.3934439931597, 13.270910790988378, 0.5375556349754333, 0.218410583745156, 0.16506850320313657, 0.10444823891988822, 0.19060751636113438, 0.0965508987594928, 0.19867775402963161], [0.0550892641102629, 0.07992170178996665, 0.024678074355636324, 0.03381353397188442, 0.032546064483800104, 0.03660113564027207, 0.06225335558078118, 0.12880856889699185, 1.0107533633708954, 50.64430781773159, 44.49453020095825, 32.723149231501985, 34.8867244720459, 53.18937042781285, 64.46866607666016, 54.13639947346279, 0.8703221817101751, 0.03469115455767938, 0.09673286149544374, 19.70049670764378, 80.10275908878872, 65.80716010502407, 71.2083214351109, 60.05716446467808, 56.053397042410715, 51.268450600760325, 55.59594849177769, 63.83614376613072, 64.31928675515312, 66.85323224748883, 64.03944110870361, 65.20119380950928, 64.82512950897217, 57.33886589322771, 56.877849442618235, 64.3591068812779, 51.94971799850464, 44.47271285738264, 68.03521115439278, 60.058915410723, 59.35048403058733, 60.083887236458914, 57.39518451690674, 56.435224873679026, 57.799156257084434, 53.21066665649414, 45.538879190172466, 43.18937015533447, 43.08198922021048, 43.07339082445417, 43.553671155657085, 41.83929695401873, 38.57828848702567, 42.98326226643154, 40.84949132374355, 40.398515020098, 40.437018462589805, 42.9470135143825, 41.69873489652361, 45.90482691356114, 46.24902677536011, 43.75524534497942, 43.615180083683555, 46.13079622813633, 49.762525830950054, 48.77603101730347, 47.677513871874126, 49.01848145893642, 49.50639091219221, 46.307884965624126, 46.03596026556832, 44.23772130693708, 43.374560492379324, 41.58071974345616, 40.32753917149135, 40.31350033623831, 40.84173018591744, 40.63560492651803, 39.46863065447126, 40.07260629108974, 37.87255648204258, 40.068166392190115, 38.25185864312308, 39.21156815120152, 38.72059454236712, 36.278789111546104, 27.892203978129796, 31.894055434635707, 33.793272563389365, 35.14734097889492, 33.27372101375035, 32.57968282699585, 39.250318254743306, 35.81010184969221, 37.9776862008231, 39.724775995527, 43.65663651057652, 40.961597033909385, 39.100174631391255, 37.9626225062779, 39.13668046678816, 38.63270330429077, 38.3760472706386, 36.21539722170149, 37.54979876109532, 43.0493083681379, 48.003954138074604, 47.57564633233206, 48.77143130983625, 48.222791126796174, 45.64271306991577, 40.24162469591413, 40.02827678407942, 44.58660772868565, 49.19660547801426, 49.75886413029262, 45.017927578517366, 40.43001467841012, 44.751960958753315, 39.218724795750205, 41.011763027736116, 38.33249248777117, 38.91670049939837, 36.76929024287632, 36.74080262865339, 38.13436460494995, 44.0070550101144, 39.71229703085763, 45.40115199770246, 53.42722463607788, 53.25895663670131, 53.485290731702534, 53.79492677961077, 55.07225234167916, 52.42745181492397, 52.24069465909685, 54.76641695840018, 55.11258316040039, 57.21288463047573, 65.80001735687256, 61.27512114388602, 56.00525297437395, 55.48148039409092, 59.390679359436035, 58.543450764247346, 59.796065058027, 56.43638174874442, 58.62089538574219, 56.087043694087434, 58.00237022127424, 53.778674943106516, 57.27366052355085, 54.74228586469378, 59.096214703151155, 65.100875718253, 69.00428336007255, 72.78449944087437, 55.63461521693638, 0.5401005212749753, 0.08144290944827454, 0.28641473395483835, 19.361336026872905, 70.47542544773647, 52.3865373475211, 39.38350132533482, 24.070142371313914, 24.026455572673253, 22.41493902887617, 1.171012043952942, 0.24023296205060823, 0.06361999974719115, 0.012402571804289306, 0.15759762908731187, 0.04374423662998846, 0.034552682523748705, 0.03937759576365352, 0.06987654723759208, 0.0716535286711795, 0.0482038605426039, 0.056439793069979975, 0.04414104051621897, 0.050278630639825544, 0.09374501396502767, 0.07467381696083716, 1.8384744567530495, 60.096373149326865, 51.14090946742466, 40.812193393707275, 36.25633948189871, 60.03883511679513, 67.99672508239746, 54.193138463156565, 0.2797927478594439, 0.07613045522677046, 0.15975066141358443, 20.60724183491298, 83.19098322732108, 69.97737162453788, 73.91558974129813, 61.7989319392613, 61.85237748282296, 54.221674714769634, 58.79398890904018, 64.93045725141252, 67.91392339978898, 68.26321629115513, 68.04408400399345, 67.26671954563686, 66.67182867867606, 58.16337735312325, 56.480516706194194, 63.569805417742046, 54.427258014678955, 49.319731031145366, 69.97588471003941, 63.32751478467669, 64.0877171925136, 60.96010371616909, 59.72472790309361, 59.44600091661726, 59.579385484967915, 56.14097213745117, 45.85707194464547, 44.92955344063895, 46.193472453526084, 44.23863499505179, 46.08609846660069, 44.25902100971767, 41.86319875717163, 42.644280501774375, 41.33880431311471, 42.15010724748884, 42.416275365012034, 43.46681867327009, 42.480247429439, 46.34684698922293, 47.187936850956504, 45.4085031918117, 44.524793079921174, 46.97232035228184, 49.50584895270211, 50.26305668694632, 50.529012884412495, 51.20145954404558, 51.61815343584333, 51.01006099155971, 47.908041204724995, 46.95118393216814, 46.726816177368164, 44.18731907435826, 43.66673571722848, 42.16604988915579, 42.64263377870832, 42.69602026258196, 41.64006083352225, 41.64548390252249, 40.37697907856533, 41.724849700927734, 41.27708693913051, 42.149509702410015, 41.74117449351719, 37.07493107659476, 33.49823120662144, 35.93207400185721, 36.206364563533235, 37.45046731403896, 36.9693740436009, 36.050339290073936, 40.41018451963152, 38.61071572984968, 40.21554115840367, 42.35025705610003, 43.16588176999773, 42.730393001011436, 41.37721048082624, 39.81373725618635, 40.681765283857075, 39.54963970184326, 40.866594314575195, 39.72349405288696, 41.10944080352783, 45.37175416946411, 49.20555475779942, 47.73959602628435, 49.67399535860334, 50.145381995609824, 46.94726514816284, 41.43737145832607, 40.31455993652344, 46.07071515492031, 51.17501817430769, 50.38409778050014, 45.51793384552002, 41.400212492261616, 44.02063179016113, 41.149865422930034, 41.647005558013916, 40.028599875313894, 41.39626244136265, 40.31610591070992, 39.708798612867085, 40.8479140826634, 45.70272813524519, 41.01843677248274, 48.25074372972761, 54.858803680964876, 55.30265460695539, 56.98039790562221, 56.14497429983956, 58.8491576058524, 54.93138803754534, 54.931898730141775, 56.52098648888724, 57.38275071552822, 60.4036294392177, 65.78473826817104, 59.46216242653983, 57.884688581739155, 59.45276846204485, 61.961478097098215, 59.770954268319265, 60.27187769753592, 58.14639942986624, 61.77830968584333, 57.695124353681294, 61.945003918239046, 56.63694497517177, 59.34974752153669, 56.58246415002005, 61.629875319344656, 65.2217743737357, 74.17768968854631, 71.93078817640031, 67.15859167916435, 1.0207646318844386, 0.07790933655841009, 0.21934358296649797, 21.06659071786063, 77.26510088784354, 58.77454090118408, 49.61897952216012, 23.760904107775005, 39.08380467551095, 39.06923082896641, 10.096199819019862, 0.33015141849006924, 0.06262384927166359, 0.08777520180280719, 0.05305549788421818, 0.032859547662415674, 0.04177518228867224, 0.03277893430952515, 0.1517012140580586, 0.21795247761266573, 0.12769355944224767, 0.19043267145752907, 0.14373467011111124, 0.13609938696026802, 0.19991313559668406, 0.17686830860163483, 1.9501146376132965, 74.12127726418632, 54.0622170312064, 47.22332750047956, 47.556080205099924, 69.60661574772426, 73.4891162599836, 67.15527044023786, 1.2026223306144987, 0.11041416986180203, 0.2574251666665077, 23.51270750590733, 88.50951657976422, 71.2640459878104, 79.01827035631452, 63.2893830708095, 63.66175787789481, 54.91148144858224, 62.00999736785889, 66.76829746791294, 70.2775685446603, 72.49557944706508, 68.26513399396623, 69.67333929879325, 70.57142175946916, 59.685005051749094, 60.09914548056466, 63.71997683388846, 57.553221293858115, 56.66134704862322, 64.94520132882255, 64.04012203216553, 65.89440168653215, 64.71086638314384, 62.44767829350063, 61.11318642752511, 63.810331208365305, 59.0561374936785, 48.31678635733468, 48.99634797232491, 47.708794661930625, 47.7081241607666, 48.17725263323103, 46.45891795839582, 43.9954445702689, 46.30604716709682, 44.68715858459473, 45.98603745869228, 44.67773682730538, 47.899533135550364, 45.39784812927246, 49.879029750823975, 47.54780837467739, 48.217903069087434, 44.35256808144705, 48.20997517449515, 51.56151172092983, 52.474327836717876, 49.77342755453927, 53.447996275765554, 54.23040165219988, 52.329516955784385, 50.0826084954398, 48.845103059496196, 49.40288707188198, 47.25202356066023, 46.37100240162441, 44.45918818882534, 45.67431695120675, 44.83380378995623, 45.04053701673235, 45.363902705056326, 42.54722111565726, 45.13563701084682, 43.9975985118321, 42.966989585331504, 44.22951201030186, 40.842890535082134, 37.969330992017476, 41.94804668426514, 45.89147594996861, 46.49900211606707, 41.017252104622976, 39.379561696733745, 44.8190666607448, 39.83736113139561, 43.51081119264875, 45.579644271305625, 47.40647506713867, 46.0012401172093, 43.510161536080496, 43.67035920279366, 44.45008952277047, 42.24687828336443, 42.38062415804182, 42.57059138161795, 41.85696274893624, 47.39111260005406, 51.4218042918614, 50.86261674336025, 50.53760085787092, 51.974530015672954, 47.16728333064488, 41.526968479156494, 40.710662841796875, 46.888132504054475, 52.592322145189556, 51.296979904174805, 48.25555188315255, 41.19443811689104, 48.25973469870431, 40.751584257398335, 44.205207211630686, 42.71142789295742, 44.56410946164812, 42.507130009787424, 41.17146042415074, 43.18321405138288, 47.481303691864014, 42.64470086778913, 49.89885990960257, 57.7951124055045, 57.53119897842407, 58.233227593558176, 58.17736060278756, 61.55100631713867, 57.635807582310264, 56.79541254043579, 59.88574545724051, 60.18692207336426, 62.89482266562325, 67.88458115713937, 60.071575028555735, 61.00521142142159, 62.46865490504673, 67.15237998962402, 63.625696727207725, 63.85047789982387, 62.28374249594552, 65.57605607169015, 62.02716636657715, 65.7222809110369, 59.37776265825544, 63.835977009364534, 59.519839423043386, 65.3770318712507, 69.20619106292725, 78.87060723985944, 76.57523509434291, 73.30241121564592, 1.4477813754762923, 0.10358034513358559, 0.3630711963134152, 24.863211495535715, 87.02581214904785, 65.98071220942906, 59.74801826477051, 43.80495970589774, 47.58898687362671, 54.29289027622768, 19.181540966033936, 0.720120258629322, 0.24188929317252977, 0.16527831980160304, 0.2789869468126978, 0.20524941996804305, 0.10090613684483937, 0.12224766452397619], [0.023239805728995373, 0.028209219786471555, 0.013562263638180281, 0.16158034466207027, 0.023835832585713694, 0.062183941448373456, 0.139048625848123, 0.18288098382098333, 2.238854846784047, 54.50203105381557, 44.89245353426252, 29.59162391935076, 24.716156346457346, 50.02652611051287, 68.80868462153843, 21.318299634116038, 0.44327075140816824, 0.14041903588388646, 0.4958604723215103, 18.15823633330209, 79.35688386644635, 69.84424413953508, 69.82252407073975, 61.471122877938406, 54.44864804404122, 56.16459948675973, 65.63282980237688, 64.88960879189628, 66.18513516017369, 68.15336527143205, 66.94066837855748, 64.25105544498989, 59.640328134809224, 61.84405354091099, 61.46745422908238, 55.2365529196603, 59.87260641370501, 48.79364122663225, 50.75307839257376, 68.32673672267369, 56.495635986328125, 59.42142513820103, 54.98582369940621, 60.28871318272182, 55.456494671957834, 53.97402354649135, 45.71994229725429, 43.91487325940813, 42.56488343647548, 43.502546310424805, 43.40512909208025, 41.058121408735005, 38.952132838112966, 37.89142778941563, 38.057962213243755, 39.72361217226301, 39.63188205446516, 40.89300789151873, 40.90167576926095, 44.93861736570086, 48.14850793566023, 46.22121313640049, 50.10369280406407, 59.73963178907122, 52.5826815196446, 47.37430143356323, 45.105342864990234, 48.22265216282436, 48.21160452706473, 49.8690938268389, 47.70564712796892, 46.8154821395874, 44.41568899154663, 44.29447419302804, 43.06549072265625, 44.34959077835083, 40.447857652391704, 40.428659779684885, 39.4484669821603, 39.69222715922764, 38.057097162519185, 37.68379129682268, 39.98843581335885, 38.720677920750205, 36.98214135851179, 37.3027138710022, 28.381166083472117, 36.44274575369698, 31.99467577253069, 34.22116347721645, 33.61238316127232, 30.805470739092144, 37.825996603284565, 37.949598108019146, 41.06211314882551, 39.10397182192121, 42.67084346498762, 40.80591917037964, 40.00011920928955, 41.135169982910156, 39.79844774518694, 40.69016913005284, 39.57491030011858, 39.408108370644705, 44.31621858051845, 49.50573083332607, 49.714103834969656, 47.4479523386274, 47.36660630362374, 45.40524448667254, 45.58586638314383, 41.186267035348074, 41.13456548963274, 50.68377011162894, 50.03200476510184, 47.40519312449864, 42.27550138745989, 42.00483431134905, 39.259722641536165, 39.61965669904436, 38.22356557846069, 39.169743469783235, 37.77164084570748, 37.06209775379726, 35.94404227393014, 38.37779474258423, 41.42626476287842, 41.51416642325265, 47.20547063010079, 53.12580483300345, 54.440977232796804, 53.04782172611782, 53.16687910897391, 56.42042868477957, 55.977446283612935, 59.113779749189106, 54.835926737104145, 61.269124848502024, 59.135951450892854, 49.28797776358468, 45.37902545928955, 49.84251696722848, 55.77083117621285, 59.94042778015137, 56.15434047154018, 58.564656666346956, 54.13743475505284, 57.41548367909023, 54.69780349731445, 57.453208923339844, 52.38759347370693, 57.31406429835728, 53.97770956584385, 59.00734724317278, 56.67315203802926, 72.7980762209211, 65.4415181023734, 76.90317617143903, 5.671625171388898, 0.2847230647291456, 0.11605816307876791, 12.205908281462532, 71.30774320874895, 52.07063055038452, 41.41130181721279, 23.266430343900407, 25.947655064719065, 23.503247533525737, 3.0075507760047913, 0.14864038330103668, 0.11192071437835693, 0.06761113594153098, 0.016319735807233622, 0.021057872899941037, 0.07308932234133993, 0.030031902249902487, 0.030866374793861593, 0.0191954062320292, 0.018566670594736934, 0.10145227611064911, 0.042974347049104314, 0.050068247464618514, 0.06091660088194268, 0.2165545326258455, 3.3933012996401106, 65.89673628125871, 49.86418839863369, 34.87043789454869, 29.366922651018413, 56.71262475422451, 73.60681874411446, 21.119574206215994, 0.5384769226823534, 0.2897512806313378, 0.665298863181046, 19.678988558905466, 81.09958239964077, 71.23260538918632, 72.20624950953892, 63.77948815482003, 56.1833769934518, 59.123208454677034, 68.44454342978341, 69.44061633518764, 68.02653285435268, 68.73474884033203, 69.4199662889753, 65.37225151062012, 60.56490407671247, 63.96680464063372, 62.69730622427804, 56.93681532996041, 63.77273450578962, 51.70545755113874, 56.6363856451852, 69.55120386396135, 60.18724863869803, 62.282616887773784, 57.13291086469378, 62.020183426993235, 58.17480366570609, 56.00185530526297, 47.67696843828474, 45.48215757097517, 44.699950218200684, 44.05461195537022, 44.720833029065815, 44.705557414463584, 43.42050892966134, 41.39756522859846, 40.506965977805, 41.581650802067344, 41.60702562332153, 44.092750617435996, 42.47265999657767, 47.21830742699759, 48.793068000248496, 45.90364919389997, 51.45602764402117, 59.80263805389404, 53.59708029883248, 47.99724565233503, 47.1037038394383, 50.372035707746235, 49.48163448061262, 51.58714015143258, 49.93287828990391, 49.71454504558018, 47.34409066608974, 46.68510266712734, 45.438317911965505, 45.4372444152832, 44.18043688365391, 42.46866825648716, 41.60114049911499, 41.66765907832554, 40.84224087851388, 41.17451068333217, 41.50341061183384, 41.0729523386274, 39.06725754056658, 38.54779631750924, 34.767646244594026, 38.11692115238735, 35.04295819146292, 38.348181520189556, 37.079218115125386, 33.36393642425537, 39.02817392349243, 41.85218933650425, 43.126627922058105, 42.48400640487671, 44.80986029761178, 42.973885672433035, 42.12588930130005, 43.825915472848074, 42.03053569793701, 41.99975517817906, 41.357995237622944, 41.98908969334194, 45.46925476619175, 51.63781336375645, 50.054520402635845, 48.96445574079241, 48.760807514190674, 47.78179938452584, 46.797673906598774, 42.76202814919608, 42.13341767447335, 51.6058794430324, 52.572325229644775, 48.50718436922346, 44.50356980732509, 41.613518714904785, 40.84734433037894, 40.10118423189436, 40.48064620154244, 41.58034454073225, 41.31417294910976, 38.71158272879464, 38.69462217603411, 42.12407234736851, 42.05172422954014, 42.5304342678615, 47.532095023563926, 54.99514470781599, 55.58584581102644, 55.0518593788147, 56.526993206569124, 57.59196444920131, 56.25066682270595, 60.772724696568076, 57.50382655007498, 62.38135773794991, 59.886940547398154, 50.051956517355784, 47.22843442644392, 51.05694396155221, 58.79462119511196, 64.1711928503854, 58.6424834387643, 62.2921359198434, 57.41532734462193, 60.0636818749564, 58.080509662628174, 60.01512786320278, 55.97151599611555, 61.48340034484863, 55.612349714551655, 62.107056753976, 58.000820772988455, 77.01230457850865, 66.70291491917202, 84.28268418993268, 9.112036994525365, 0.30183962626116617, 0.14230080348040375, 12.316697307995387, 79.55913203103202, 60.02738448551723, 51.367844581604004, 23.563215698514664, 32.115331241062705, 38.04599741527012, 11.255786418914795, 0.807208816920008, 0.07950449096305029, 0.05961602567029851, 0.07678566221147776, 0.04508906928822398, 0.08436051503356014, 0.02346575110485511, 0.15282397238271578, 0.195560754143766, 0.16200472760413373, 0.30179961983646664, 0.16967752017080784, 0.1697639383907829, 0.3152504095009395, 0.3199340653206621, 4.285565512520926, 78.09427806309291, 55.81548030035836, 39.39844342640468, 36.804475920540945, 65.41872106279645, 78.33601978846959, 28.55636317389352, 0.6067715808749199, 0.3317730629018375, 0.8936256255422319, 22.669833694185527, 84.89899635314941, 75.38025610787528, 75.39475699833461, 67.60620158059257, 59.59805529458182, 61.94966615949358, 71.07080963679722, 74.04406888144356, 70.14305141993931, 72.67340469360352, 71.88201877049038, 66.96124199458531, 61.50912952423096, 66.04561533246721, 63.661132540021626, 60.48895331791469, 64.02125072479248, 56.269583293369834, 59.118372508457725, 66.17476149967739, 63.69429629189627, 64.75233323233468, 60.844944272722515, 65.53731291634696, 60.07862745012556, 58.6752233505249, 50.99634872164045, 47.184028489249094, 45.646128109523225, 46.47919280188424, 47.484329632350374, 46.17898198536464, 44.4496066229684, 43.82240663255964, 43.15889883041382, 44.77128389903477, 43.33225638525826, 46.314332893916536, 44.59032848903111, 49.32525484902518, 49.99580117634365, 46.018190247671946, 53.369801248822895, 62.09351471492222, 54.96986716134207, 49.19937433515276, 50.351211956569124, 52.103047370910645, 51.62007113865444, 53.93122959136963, 52.02457789012364, 51.47800827026367, 49.692251750401084, 48.88542693001883, 46.54817451749529, 48.72628538949149, 46.31334277561733, 44.18204539162772, 43.03111103602818, 41.893437317439485, 42.19579512732369, 42.364764894757954, 43.94581011363438, 42.20118692943028, 41.467141015189036, 43.45003877367292, 38.34345327104841, 43.635976042066304, 44.25770085198538, 44.396345206669395, 41.09413044793265, 35.93542650767735, 41.97303935459682, 44.48867286954607, 44.874832902635845, 44.122395106724326, 45.868935993739534, 46.109566007341655, 42.99013403483799, 45.71450185775757, 44.14757537841797, 44.994671957833425, 43.6309038570949, 42.89357144492013, 47.0748097555978, 54.377050331660676, 52.93149845940726, 50.9088465826852, 52.08630221230643, 49.77416753768921, 48.218566622052876, 44.05192647661482, 43.07641329084124, 53.740831579480854, 53.49297891344343, 50.033324922834126, 44.25022111620222, 42.41027559552874, 39.90526587622506, 42.25977413994925, 41.11339085442679, 43.58504922049386, 44.67144175938198, 41.6069005557469, 40.401613916669575, 44.024613107953755, 45.08227831976754, 45.3822911126273, 51.594289847782676, 57.62980433872768, 57.26812628337315, 58.3603309903826, 58.40931579044887, 60.484805243355886, 58.158603940691265, 61.743075370788574, 58.421398707798545, 63.94512626102993, 58.66487748282296, 52.75352035249983, 51.1848464012146, 56.34325156893049, 59.69682393755232, 67.08492687770298, 60.79617486681257, 63.472836358206614, 60.12584740774972, 63.707067080906455, 60.47735677446638, 65.55187634059361, 58.28597831726074, 64.71244362422398, 59.54219872610909, 66.73187501089913, 60.807076590401785, 81.80029433114188, 70.4456593649728, 90.26504843575614, 10.148345180920192, 0.4112330419676644, 0.14519672308649334, 16.37629611151559, 87.62763731820243, 66.81772695268903, 61.01785714285714, 42.92883702686855, 52.483252797807964, 54.48592165538243, 22.446266719273158, 1.2364714571407862, 0.3078250108020646, 0.18009505474141665, 0.17688582837581635, 0.16722336757395947, 0.26108963574681965, 0.12938765782330716], [0.01883048840266253, 0.012647150599929904, 0.07039370627275535, 0.08066495547869376, 0.029943679126777818, 0.0429164205145623, 0.033471718563565185, 0.13560326929603303, 2.5071699576718465, 56.000694956098286, 40.39511735098702, 36.81347036361694, 42.333386829921174, 51.263861315590994, 67.5400060926165, 9.60473028251103, 0.27242798304983545, 0.24477898382714816, 0.44877440322722706, 14.310887626239232, 83.0631502696446, 68.39093112945557, 67.96960626329694, 60.153681891305105, 54.84909357343401, 60.7611003603254, 66.36934580121721, 67.66146755218506, 66.62856224605015, 64.24198804582868, 61.22515664781843, 58.59811224256243, 61.400890486580984, 60.02857262747628, 60.68269688742501, 63.762979234967915, 55.21042421885899, 57.66239833831787, 49.04141051428658, 57.678497314453125, 60.19574628557478, 57.89270680291312, 56.68920585087368, 56.43618025098528, 59.2015563419887, 54.293793542044504, 46.77256659099034, 43.59344611849104, 43.467044489724294, 43.106783866882324, 43.68014921460833, 42.95948205675398, 39.255067348480225, 37.801014355250764, 39.20711088180542, 39.86726270403181, 40.30152859006609, 39.82149491991316, 41.2335912159511, 46.76948159081595, 55.38537291118077, 45.93353339603969, 56.419393403189524, 55.90111337389265, 54.43993500300816, 46.465932164873394, 44.728917258126394, 42.861988408224924, 45.97578886577061, 46.88185828072684, 52.84895733424595, 54.426149777003694, 47.75308247974941, 42.836186272757395, 44.558022839682444, 40.057490485055105, 40.75508962358747, 38.52158423832485, 39.679136753082275, 41.770839827401296, 39.5337804385594, 39.59897886003767, 38.7531225340707, 35.280666487557546, 38.23502663203648, 35.55896963391985, 31.59552260807582, 38.60425043106079, 27.896907908575876, 36.6452579498291, 40.293274130140034, 30.96230547768729, 37.38505697250366, 39.57081086294991, 39.78555188860212, 41.54582241603306, 41.23492179598127, 39.93034539903913, 43.236586638859336, 41.41381359100342, 42.864493233816965, 44.3286315373012, 46.48714848927089, 47.991871220724924, 51.13014323370797, 50.1581632069179, 48.788075719560894, 46.35154744556972, 46.17010218756539, 46.78441674368722, 46.040424483163015, 44.25603328432356, 38.37413304192679, 43.461677006312776, 48.916137967790874, 48.206250940050396, 45.31343446459089, 42.21438503265381, 46.74080637523106, 38.52890069144112, 39.29135431562151, 37.93484360831124, 36.56436702183315, 36.2673419543675, 36.181642872946604, 38.73024211611067, 42.1560514313834, 40.204246861594065, 47.06458895547049, 54.150295870644705, 52.641800267355784, 48.33723143168858, 48.040227208818706, 54.49479797908238, 54.72492579051426, 58.001258509499685, 61.901126044137136, 61.001494135175435, 43.40138748713902, 47.36895132064819, 52.927030767713276, 58.752487318856375, 57.12375313895089, 63.124418939862935, 57.358546665736604, 59.535917554582866, 55.20650543485369, 57.07197168895176, 54.75110312870571, 59.13786220550537, 51.77209424972534, 57.48793601989746, 53.53939288003104, 57.309325626918245, 54.58322075435093, 72.26366247449602, 64.5534063066755, 84.45014967237199, 15.154378959110804, 0.30139567436916487, 0.12927833226110252, 7.1561091031347, 70.30912726266044, 51.667221614292686, 44.169705390930176, 14.344481297901698, 26.976558208465576, 25.006184577941895, 2.558047490460532, 0.3201943242124149, 0.04685486167935388, 0.012581084189670426, 0.01993034447410277, 0.06296657052423273, 0.042878548082496436, 0.04174116054283721, 0.05989015381783247, 0.010605066382725323, 0.03439446851345045, 0.05117145041003823, 0.02018437271804682, 0.08143657193120037, 0.018097280424886515, 0.11271753840680633, 3.288943265165601, 65.87568323952812, 44.68357678822109, 37.44080931799752, 46.65096269335066, 57.48325293404715, 71.29632037026542, 10.813375507082258, 0.40303837454744745, 0.2740285928760256, 0.6380953629102025, 14.864995173045568, 86.2627957207816, 69.14138521466936, 73.80240358625139, 59.6736239024571, 57.035264355795725, 64.99474893297467, 69.70132664271763, 69.7902010508946, 68.5705212184361, 66.60112380981445, 63.05995355333601, 61.00959573473249, 65.47170802525112, 63.660486357552664, 62.18005452837263, 65.59488568987165, 58.84757341657366, 59.002087456839426, 53.2592762538365, 64.42389188494, 60.81462928227016, 60.23627512795584, 59.1103195462908, 57.77099173409598, 61.41940743582589, 55.205275603703086, 49.392381395612446, 44.91776234763009, 45.64303616115025, 44.61291013445173, 46.17297874178205, 43.36771651676723, 42.30865124293736, 40.22705084936959, 41.51783159800938, 41.44002219608852, 42.85102415084839, 41.2318228994097, 42.74572767530169, 49.56616279057094, 55.24275418690273, 48.740296431950156, 57.58862583977835, 57.89206409454346, 55.74554320744106, 46.74432563781738, 45.417574065072195, 44.92755235944475, 48.54528481619698, 48.917690890175955, 53.75455774579729, 58.3301271711077, 52.18195111410958, 46.59404305049351, 46.511140619005474, 44.121568271092, 42.00611277988979, 40.980576038360596, 41.30057879856655, 44.31783403669085, 43.63473926271711, 42.51289701461792, 41.289951528821675, 38.35185711724417, 41.37694297518049, 37.24124663216727, 35.13586255482265, 41.214403765542166, 34.78525297982352, 39.57831144332886, 41.81452315194266, 33.879385062626426, 37.6161401612418, 40.90267283575875, 41.19795043127877, 42.762782028743196, 43.444723401750835, 41.31399229594639, 43.96838133675711, 44.05761010306222, 44.19967644555228, 45.6718225479126, 47.51895945412772, 49.79147550037929, 52.477662972041536, 52.730879647391184, 51.93203135899135, 48.64044039590018, 47.74396991729736, 47.721933705466135, 47.94311918531145, 45.90640762874058, 39.2219591821943, 44.001406124659944, 48.57964365822928, 49.54726716450283, 44.99944884436471, 42.79677261625017, 47.59494147981916, 40.457960333142964, 40.42601946422032, 40.01165321895054, 39.351341588156565, 39.98711565562657, 39.37076527731759, 41.43134389604841, 44.329958643232075, 41.31473922729492, 50.098082133701865, 56.426973887852256, 55.52022007533482, 53.68401615960257, 50.421805654253276, 56.88695853097098, 58.39101423536028, 59.11680221557617, 63.314514705113, 60.75492341177804, 47.17908137185233, 50.47799573625837, 52.5351836340768, 59.25985867636544, 59.56619085584368, 63.088496753147666, 60.30941186632429, 64.05591528756278, 57.33997760500227, 59.35590362548828, 57.55698374339512, 61.1485527583531, 54.82755763190133, 60.8495648247855, 56.182984420231406, 60.67226069314139, 58.05848387309483, 76.11864117213658, 65.27564375741142, 88.70808914729527, 18.713025672095164, 0.36054490187338417, 0.07314070101295199, 7.324318477085658, 78.11007131849016, 58.28497082846505, 55.35495369774954, 18.532567058290752, 42.41547979627337, 39.692359175000874, 12.68447848728725, 0.22757413131850107, 0.06729651282408408, 0.027899743357141103, 0.04406671379027622, 0.046179593806820254, 0.01887945657862084, 0.016392013357420052, 0.20548568586153643, 0.14269545301795006, 0.1872990746051073, 0.15650794255946363, 0.06746479629405908, 0.12554161277200493, 0.18154401199093886, 0.24122897003378185, 4.510185573782239, 78.44523852212089, 49.83006232125418, 49.404332297188894, 54.87123053414481, 64.58510398864746, 78.66649000985282, 13.81036284991673, 0.5037027629358428, 0.3651905597320625, 0.8770124284284455, 17.35609459877014, 88.04735020228794, 72.84668581826347, 75.76609652382987, 62.66876997266497, 59.674686976841514, 66.47502790178571, 71.1137911932809, 72.1082660130092, 72.17369719914028, 68.03605188642229, 64.4843064716884, 61.30952167510986, 66.40154375348772, 65.194641658238, 64.33130713871547, 67.48560169764927, 61.342622893197195, 60.74144390651158, 56.861118180411204, 62.46052551269531, 63.42533847263881, 61.01472350529262, 61.54855360303606, 61.19378553118025, 64.93506390707833, 57.833254541669575, 53.07215779168265, 48.81462131227766, 46.87234967095511, 47.33857727050781, 48.52559362139021, 47.15540885925293, 44.28165476662772, 42.893012114933555, 44.83366482598441, 43.79089307785034, 46.06363146645682, 44.61637381144932, 45.83725915636335, 51.529358931950156, 59.38849067687988, 54.7323568889073, 59.626779147556846, 59.46354511805943, 57.99470635822841, 46.588644300188335, 48.01263243811471, 46.482819761548726, 50.27422939028059, 51.06228017807007, 56.613046646118164, 60.80593013763428, 53.9772162437439, 47.52178389685494, 50.3525390625, 45.78025960922241, 43.556492124285015, 42.99452182224819, 44.68860380990164, 45.67805855614798, 45.05932147162301, 43.87378856113979, 44.02524886812483, 40.451984882354736, 43.438796588352744, 40.44840656008039, 37.739276136670796, 46.81643056869507, 44.170073645455496, 49.2291647366115, 45.9865585735866, 35.57474551882063, 38.4392272404262, 43.74312768663679, 44.12186704363142, 45.93438107626778, 44.48924957002912, 43.4807984488351, 47.08545092173985, 46.846707344055176, 45.948121138981406, 48.47286721638271, 49.77170787538801, 51.662361349378315, 56.13517386572701, 55.4801915032523, 54.86391060692923, 50.297662190028596, 49.83216415132795, 51.45718451908657, 48.834830147879465, 47.19596202032906, 39.66585527147566, 46.17971502031599, 50.216385637010845, 49.34142330714634, 47.225439752851216, 42.76299742289952, 50.42819799695696, 43.626182556152344, 43.123994554792134, 42.8374855858939, 41.66113124574934, 42.715669768197195, 41.09241771697998, 43.77682644980294, 46.19953128269741, 42.51611750466483, 53.56750529153006, 59.80008806501116, 55.887251717703684, 56.789405822753906, 51.79931034360613, 58.02031741823469, 61.443475995744976, 63.25079277583531, 65.27011299133301, 61.88479082924979, 49.68921191351754, 53.717746189662385, 53.65505606787545, 60.619503021240234, 61.14455754416329, 65.53652776990617, 61.36526012420654, 66.42657811301095, 60.80096217564174, 63.32318605695452, 61.864439555576865, 64.69103622436523, 56.92649378095354, 63.45334666115897, 59.01341996874128, 64.23709651402065, 59.087974139622276, 78.9817019871303, 68.52966581072126, 95.70727361951555, 21.7830194745745, 0.5526226407715252, 0.187419718131423, 10.1678991488048, 86.58403873443604, 66.23029845101493, 65.69588470458984, 29.696326323917933, 53.25093494142805, 51.80342715127127, 25.450304746627808, 0.4995917635304587, 0.23054896454725946, 0.1747854503669909, 0.14514295597161564, 0.25356945927653995, 0.25776304996439386, 0.13098686986735888], [0.037081962517861805, 0.047448271087237766, 0.031510433448212485, 0.01929211273922452, 0.041250481336776695, 0.01413043069520167, 0.019977862281458716, 0.12281117428626333, 2.729554218905313, 52.453285217285156, 36.0361510685512, 48.55213574000767, 42.68990584782192, 50.673142841884065, 70.65281295776367, 9.903487188475472, 0.4780869260430336, 0.557557327406747, 0.633239494902747, 14.16210411276136, 83.79819325038365, 64.1480553490775, 68.31610597882951, 54.52233716419765, 56.866047927311485, 63.09338133675711, 66.01750986916679, 67.1480929510934, 62.48709542410714, 61.696751730782644, 62.308019501822336, 61.97951562064034, 59.5773218699864, 62.19873128618513, 60.61110264914376, 59.129350662231445, 57.81510237285069, 59.23218400137765, 52.75428465434483, 50.658110414232524, 58.810344968523296, 59.17625100272042, 58.65213448660714, 54.82568161828177, 58.44444588252476, 56.19449063709804, 47.03087282180786, 40.84709766932896, 44.89190115247454, 42.35864005770002, 43.56028931481497, 41.30840941837856, 39.28998899459839, 37.6550327028547, 38.66752420152937, 39.09648513793945, 38.68593692779541, 38.99719190597534, 41.58490603310721, 43.067578656332834, 52.67886890683855, 46.5942827633449, 52.962021895817344, 46.1679447719029, 45.6222436768668, 46.74232803072248, 41.79826784133911, 39.29279954092843, 41.072045598711284, 41.952632495335166, 43.61889042173113, 46.11740010125296, 51.339367389678955, 48.13648407799857, 45.07023361751011, 41.82689094543457, 39.99414375850132, 39.29940380368914, 38.28629044124058, 38.60598400660923, 40.02758196422032, 39.110103607177734, 36.065003463200156, 36.525363309042795, 38.72557292665754, 31.411329337528773, 37.43180097852434, 44.86009924752371, 27.44278928211757, 33.23590891701834, 46.0399763243539, 36.666321413857595, 35.66635056904384, 37.26744828905378, 39.349788665771484, 39.25955935886928, 43.871888228825156, 44.05654355457851, 43.91047157560076, 43.30643687929426, 45.998422622680664, 49.052294867379324, 47.37198073523385, 47.680077757154194, 48.69589744295393, 48.72807107652937, 48.42050559180123, 50.03819561004639, 51.17266968318394, 45.76316704068865, 46.47266844340733, 42.71264035361153, 41.39854492459978, 45.33120100838797, 49.28717524664742, 53.06747123173305, 45.871621472494944, 47.827643598829, 46.639487743377686, 40.288796016148154, 37.15452963965279, 36.95193406513759, 37.021412576947895, 35.22216265542166, 36.86798940386091, 40.44064542225429, 43.744882106781006, 40.78231266566685, 47.75587565558297, 53.282174042293, 52.92183698926653, 48.20829718453543, 50.2835955619812, 55.66808468954903, 53.87047106879098, 62.45036029815674, 53.30800397055489, 48.11461114883423, 52.582761423928396, 57.56058291026524, 56.961422375270296, 56.3837456703186, 58.2603429385594, 60.623275893075125, 58.459009306771414, 60.044358934674946, 57.57300281524658, 58.136293275015696, 57.2040638923645, 55.00322546277727, 54.418958391462056, 56.81363071714129, 55.93460021700178, 64.05863203321184, 57.94549226760864, 71.93944563184465, 62.788383211408345, 86.68543379647392, 22.965682779039653, 0.2797941049294812, 0.08444714359939098, 4.087034634181431, 65.7045213154384, 52.6467091696603, 47.85065950666155, 18.033550909587316, 19.153583151953562, 26.216519083295548, 6.226580398423331, 0.1943646733249937, 0.02854481472500733, 0.09147395725761141, 0.013811697351879306, 0.04650172830692359, 0.056017113250813315, 0.06200685737920659, 0.03016173992572086, 0.03701906571430819, 0.04627764890236514, 0.025554980783324157, 0.05287508560078485, 0.01693040714599192, 0.012608146710720445, 0.13584599484290394, 4.312761630330767, 63.812971523829866, 40.73737171718052, 44.974212987082346, 49.24682010923113, 56.46993112564087, 76.50161893027169, 11.971337097031729, 0.6695412812488419, 0.6510901770421437, 0.5293435699173382, 15.5103178024292, 86.83303437914167, 67.05944088527134, 71.32450226375035, 58.06325381142752, 62.02129513876778, 64.73587989807129, 68.80320249285016, 68.53671128409249, 63.53965718405587, 63.048801694597515, 63.05109460013253, 62.08931105477469, 63.64745153699602, 64.54381779261998, 63.62842736925398, 63.49629347664969, 60.2915688923427, 60.955552646092, 54.04342562811715, 56.411812918526785, 60.308737891060964, 61.43037864140102, 60.03549998147147, 57.94476270675659, 58.22008160182408, 58.144832611083984, 49.843750272478374, 44.12083176204136, 46.18720865249634, 43.50864682878767, 44.943991797310964, 43.533827100481304, 42.37978342601231, 40.80596433367048, 39.55422551291329, 40.749055113111226, 41.170317445482524, 41.50141647883824, 43.03725324358259, 46.45728860582624, 53.441916601998464, 50.92051260811942, 54.46798835481916, 46.638886724199565, 47.567263330732075, 47.89591659818377, 44.00049591064453, 41.12375756672451, 42.153365952628, 42.99208995274135, 46.633192675454275, 48.4371326310294, 52.7268705368042, 50.65378168651036, 46.323268277304514, 44.50866631099156, 43.75847973142351, 42.653764792851035, 41.38820253099714, 41.759913785117014, 42.54718637466431, 39.42000368663243, 37.58405338014875, 39.28456939969744, 40.496446405138286, 34.501026494162424, 38.7914731161935, 46.10570975712368, 33.064375264304026, 36.84982681274414, 47.57323183332171, 37.94055502755301, 35.3932238306318, 38.70297738483974, 41.2351267678397, 40.227631023951936, 45.73802498408726, 46.39870139530727, 46.01994466781616, 46.054734298161094, 49.31340817042759, 49.73846421922956, 50.164308888571604, 49.9213581766401, 50.27688012804304, 51.06211689540318, 51.35693938391549, 51.87804733003889, 51.178787572043284, 47.81670018604824, 47.240854331425254, 43.8497999055045, 42.49394927706037, 46.89973599570138, 53.54571574074881, 55.23831081390381, 47.53719847542899, 50.45753329140799, 49.463551793779644, 41.961918762751985, 39.094574383326936, 39.15047264099121, 39.04793460028512, 38.44327456610543, 38.62002979006086, 41.17089762006487, 44.70203120367867, 43.81964124952044, 51.32489776611328, 55.13276072910854, 55.629754952022004, 52.40633623940604, 51.95870201928275, 59.24279390062605, 56.07221623829433, 64.2588860648019, 55.53017336981637, 49.82567800794329, 54.24773393358503, 58.5491760798863, 58.814590317862375, 60.95607376098633, 61.48517213548933, 62.38182326725551, 61.389981814793174, 63.04303468976702, 60.99455288478306, 61.34157371520996, 59.106359073093955, 57.290881633758545, 57.220444270542686, 59.14281627110073, 59.73706095559256, 67.37115791865757, 60.39283193860735, 74.88443960462297, 63.990178380693706, 88.86711256844657, 25.83928574834551, 0.400711786534105, 0.11820058311734881, 5.704768512930189, 73.74564375196184, 59.4637952532087, 58.470063890729634, 21.130687849862234, 25.777823720659526, 41.93568236487252, 17.98948196002415, 0.20097787917724677, 0.03149306295173509, 0.028089383716828058, 0.05655104906431266, 0.041265093588403294, 0.059014796146324704, 0.01073984379347946, 0.0714470436796546, 0.1683400190834488, 0.2553393228777817, 0.10025838017463684, 0.10513058051999126, 0.09661221796912806, 0.16122657007404737, 0.23288016659872873, 5.701533257961273, 73.37274782998222, 43.842879499707905, 59.61123602730887, 54.77296910967146, 63.278050558907644, 82.8538566316877, 13.934186697006226, 0.6680418274232319, 0.802913310272353, 0.5647458359599113, 17.86584050314767, 89.16528061458042, 68.54207529340471, 75.03233201163155, 59.95751340048653, 63.76907280513218, 66.6747886112758, 72.42392962319511, 73.03289059230259, 65.64122322627476, 64.05802059173584, 66.82279913766044, 63.9542145047869, 65.76498453957694, 65.96913651057652, 63.88132790156773, 66.36895670209611, 61.841913495744976, 61.661670276096885, 56.49687276567732, 54.31913709640503, 63.13273593357631, 63.83404541015625, 63.20034190586635, 59.406604630606516, 63.97777584620884, 60.93684809548514, 52.40787179129464, 46.45307452338082, 48.086061000823975, 46.171238218035015, 45.16642100470406, 46.8153258051191, 44.51901912689209, 41.9071078981672, 42.522916316986084, 44.17680297579084, 44.20969922201974, 43.681948798043386, 46.10341337748936, 47.869186878204346, 56.24936750956944, 54.77306638445173, 55.979992798396516, 47.81479637963431, 48.716860158102854, 50.93383925301688, 46.03245142527989, 43.64887189865112, 44.81959819793701, 46.688819953373496, 49.98161990301949, 52.0098477091108, 55.43842240742275, 52.10479136875698, 50.03575331824166, 45.356860705784385, 45.33522401537214, 46.116006987435476, 43.7662547656468, 44.07827751977103, 44.23971891403198, 42.16869715281895, 38.7870888028826, 40.41342238017491, 43.59457172666277, 36.65434966768537, 41.80082130432129, 51.261717796325684, 41.657167298453196, 46.573003905160085, 50.704812731061665, 40.19288655689785, 36.9563044820513, 40.253999437604634, 43.065838132585796, 41.99160494123186, 45.705632482256206, 48.86220605032784, 49.65656580243792, 48.930955001286094, 52.04978248051235, 53.26035669871739, 53.7558570589338, 52.13864646639143, 55.236882959093364, 53.24538680485317, 52.92712804249355, 53.64350468771798, 53.64540154593331, 50.21818174634661, 48.259838921683176, 45.50274855749947, 43.87160335268293, 48.58302395684378, 53.097487449645996, 57.017529078892295, 48.50453363146101, 50.6658923966544, 50.52036585126604, 44.80852276938302, 40.10657603400094, 40.500306129455566, 40.8676678112575, 40.292030402592246, 42.14634827205113, 43.898968832833425, 47.37131370816912, 45.914224352155415, 52.08790029798235, 57.89554861613682, 57.896007197243826, 58.15566485268729, 56.240883759089876, 60.16923195975167, 59.334871428353445, 65.3012478692191, 56.476538862500874, 53.89587715693882, 56.28930228097098, 61.194383076259065, 60.27576174054827, 63.811950138636995, 64.30534866877964, 65.10716383797782, 62.56355340140206, 65.03229699816022, 63.38986791883196, 63.15161418914795, 63.86927972521101, 61.267769949776785, 60.02340316772461, 62.44918605259487, 63.26919160570417, 70.02976104191372, 63.39441204071045, 78.45258276803153, 67.53850528172084, 94.4478987285069, 29.13906168937683, 0.5191798752972058, 0.19647242022412165, 8.012417691094534, 82.0200172151838, 67.2484666279384, 66.52039963858468, 28.910372155053274, 34.203431674412315, 56.82611663000924, 31.935859271458217, 0.3793113891567503, 0.09215326580618109, 0.11816698206322533, 0.14089154052947248, 0.09153748849140746, 0.14720609597861767, 0.11333215542669807], [0.015340095785047327, 0.03096364957413503, 0.055693150098834715, 0.06095515524170228, 0.041706127779824395, 0.020108307246118784, 0.1650171381022249, 0.1740296437804188, 3.3023645792688643, 53.08790588378906, 43.25097288404192, 24.883330004555837, 31.994887692587717, 54.46789802823748, 69.47214726039341, 14.777300221579415, 0.43369132972189356, 0.8032551290733474, 0.6285862103104591, 12.641930324690682, 80.65960856846401, 67.35279382978166, 67.58612128666469, 55.03991542543684, 58.04442419324602, 65.11756529126848, 65.96337645394462, 63.51843738555908, 62.47970254080636, 65.08502687726701, 63.263223103114534, 60.9594783782959, 57.31730215890067, 59.11937304905483, 60.870756830487935, 58.79031331198556, 57.84647001538958, 56.193618638174875, 55.637550830841064, 50.2732948575701, 57.092725958142964, 58.96615137372698, 56.43511022840227, 56.569158349718364, 56.43042366845267, 54.528204917907715, 45.98273359026228, 42.432457719530376, 43.850126470838276, 42.22234419413975, 42.70658847263881, 41.9696729523795, 39.39985391071865, 38.16990116664341, 36.65144532067435, 39.58748306546892, 38.96767248426165, 39.03643185751778, 38.65802948815482, 39.92167057309832, 48.37290000915527, 47.155120509011404, 49.29785462788173, 45.850561482565745, 45.499184131622314, 43.669563634055, 43.89974355697632, 42.0781239100865, 41.57721437726702, 42.379418645586284, 43.12464073726109, 46.226309640066965, 48.90050452096121, 47.648470401763916, 48.146986280168804, 49.02835832323347, 48.966012137276785, 47.91889429092407, 45.95079966953823, 40.64790323802403, 38.43253265108381, 37.44847665514265, 37.386019298008506, 37.91390521185738, 34.72064168112618, 36.1431359563555, 41.316980021340505, 44.70034279142107, 29.035528319222585, 29.511372225625173, 50.21443319320679, 44.604318686894004, 36.43542235238211, 37.363524505070274, 36.178651673453196, 35.84664590018136, 39.15508624485561, 41.43151412691389, 47.355367592402864, 44.828731604984824, 46.607477392469136, 46.233358587537495, 49.289141586848665, 49.43425818852016, 48.860486371176584, 51.220403807503835, 51.894987038203645, 48.04621308190482, 47.54924317768642, 43.157335485730854, 41.27113233293806, 36.55031776428223, 40.21509299959455, 46.016404560634065, 47.26601723262242, 50.89937618800572, 50.85309076309204, 53.056284632001606, 48.98973328726632, 39.87440892628261, 36.280720710754395, 34.957123620169504, 35.68955060413906, 35.5708441053118, 36.918766839163645, 38.5434502192906, 41.45453003474644, 39.54241010120937, 46.79093067986624, 53.70757402692522, 55.05527094432286, 45.369176387786865, 49.47710772923061, 51.88870586667742, 57.89206409454346, 53.65881156921387, 42.645576340811594, 58.29885332924979, 52.7195645059858, 56.7296895299639, 55.99820402690342, 60.0497715813773, 58.84159796578543, 60.53704180036272, 58.30777481624058, 62.892724309648784, 57.78777510779244, 62.81503650120327, 57.77534130641392, 58.23060117449079, 53.55126387732369, 58.680962562561035, 57.38599899836949, 64.25366101946149, 59.72954995291573, 71.96428544180733, 63.18623011452811, 85.68076596941266, 28.287549529756816, 0.20173072735113756, 0.03587073679747326, 5.24068660395486, 61.52955722808838, 48.32042721339634, 51.35302059991019, 29.207155772617885, 32.183555603027344, 25.03998408998762, 11.138000556400844, 0.32185239238398416, 0.036823386392955265, 0.019346765342301557, 0.035234142028327496, 0.03690848486231906, 0.047396451367863586, 0.02479417678633971, 0.00786600456506546, 0.044608985406479666, 0.07261214937482562, 0.03704758454114199, 0.12283279241195746, 0.02399189394366528, 0.08681307307311467, 0.19447237040315354, 5.3248575159481595, 63.006799834115164, 47.08576359067644, 28.277042116437638, 38.70665993009295, 61.02052525111607, 75.6945856639317, 17.6616016796657, 0.5218951010278293, 0.6387502306274006, 0.7594147101044655, 13.264063341276985, 84.27354036058698, 70.23754692077637, 70.17440169198173, 57.949987752096995, 61.39214965275356, 67.38363688332694, 68.31432029179165, 64.7951966694423, 62.8873325075422, 66.00766427176339, 64.86544295719692, 64.48681477137974, 60.706591742379324, 61.798049518040244, 62.94922011239188, 63.165614809308735, 60.0363198689052, 58.84899084908621, 57.86826651436942, 57.0252103124346, 58.054613726479666, 59.075814792088096, 58.61969334738595, 59.077718598502024, 58.148897307259695, 58.19530085154942, 47.36570303780692, 45.80952542168753, 45.285183089120046, 44.50808266230992, 44.466775621686665, 43.77368238994053, 41.8945038659232, 40.23157065255301, 40.18464251926967, 41.16582543509347, 41.00871276855469, 41.470715863364084, 42.205404485974995, 41.997566495622905, 49.062046664101736, 48.92686946051461, 51.31024054118565, 47.05749831880842, 45.94148908342634, 43.95154932567051, 46.33448266983032, 44.14965636389596, 42.922514166150776, 44.84180811473301, 47.14010197775704, 47.37376989637102, 50.90772097451346, 50.23107065473284, 51.78023753847395, 51.66519274030413, 50.763507638658794, 48.16049010413033, 47.09704399108887, 43.45098720278059, 40.95354754584176, 38.7971567426409, 40.454941340855186, 38.70367220469883, 36.60938787460327, 37.33882365907942, 42.7964425768171, 46.492755685533794, 34.716504028865266, 35.29670292990548, 50.31668635777065, 46.25682612827846, 37.83471311841692, 36.59077017647879, 37.444391114371165, 37.66409315381731, 40.52153287615095, 44.087226799556184, 48.26130846568516, 46.51500381742205, 48.61151157106672, 48.613974707467214, 52.77201993124825, 52.67306021281651, 51.29999194826399, 52.83177791322981, 51.74292918613979, 49.148551736559185, 48.49092558452061, 43.14980363845825, 43.67866230010986, 40.10123634338379, 41.508729457855225, 45.504947662353516, 48.3929386138916, 52.26600694656372, 51.19600520815168, 54.7280524798802, 49.44564628601074, 42.8061283656529, 38.81556599480765, 37.272218227386475, 37.71779925482613, 37.8073650087629, 38.5290778705052, 40.07985326222011, 42.84249871117728, 40.45507335662842, 49.57277052743094, 55.79735939843314, 56.45694146837507, 49.43635654449463, 53.11921794073922, 55.40153094700405, 61.031774384634836, 57.760843890053884, 47.269060543605256, 61.134760584150044, 54.12244749069214, 59.36943871634347, 58.18213054112026, 62.62022985730852, 61.826419012887136, 62.92405373709542, 61.5288485118321, 64.63005883353097, 60.319389479500906, 62.523253849574495, 61.23839296613421, 61.161344391959055, 56.459672110421316, 60.1672864641462, 58.97182805197579, 67.07843031202043, 63.14762592315674, 74.17982973371232, 64.54298400878906, 87.52847957611084, 31.55264527457101, 0.24622909458620207, 0.06466311841670956, 6.586314695222037, 72.7948522567749, 54.33659097126552, 61.15722411019461, 32.93597602844238, 41.75664465767996, 39.139654295785085, 23.578456572123937, 0.29550981734480175, 0.06800008578492062, 0.003060314222238958, 0.01918682615671839, 0.008619479535679733, 0.03824650842164244, 0.027456061182809726, 0.1391927602567843, 0.19037804938852787, 0.12747732390250477, 0.10201725150857653, 0.39900024980306625, 0.11034139698105198, 0.3118656054139137, 0.29744385927915573, 7.423915692738124, 73.27072048187256, 54.56467253821236, 37.958071436200825, 45.924580642155235, 68.54129709516252, 83.50787666865757, 19.265871252332413, 0.5223537907004356, 1.0192614325455256, 0.8880565358059747, 16.058228424617223, 84.46713106972831, 73.83425412859235, 73.17608601706368, 60.15394592285156, 63.59550680433001, 70.03194972446987, 70.35838999067033, 67.62539250510079, 63.94705786023821, 67.96537481035504, 67.8942391531808, 66.61715330396379, 62.10404123578753, 64.96732439313615, 66.46193054744175, 63.72157491956438, 61.35435145241873, 59.73025866917202, 59.65980393545968, 54.893568992614746, 60.54019628252302, 63.4692302431379, 59.0409209387643, 62.544313839503694, 61.17723492213658, 61.48230947766985, 50.705986976623535, 46.276037897382466, 46.74412761415754, 48.27701486860003, 46.200344221932546, 47.27262496948242, 43.93512031010219, 43.65054988861084, 43.28739881515503, 43.87057849339077, 42.67314679282052, 45.50632340567452, 43.889991760253906, 44.85659040723528, 53.03021846498762, 51.59021472930908, 54.869514329092844, 47.59595244271414, 49.30386829376221, 46.15730707986014, 49.48129749298096, 48.194793360573904, 44.19081401824951, 46.42134210041591, 47.1813325881958, 51.0382741519383, 54.7193602834429, 53.27805028642927, 52.58934484209333, 52.983880928584504, 54.965621812003, 51.15494135447911, 49.18861852373396, 44.26646947860718, 41.36787557601929, 39.265048435756135, 41.17896795272827, 38.6210754939488, 38.06059905460903, 40.06968804768154, 44.826879910060335, 53.084021840776714, 40.6554594039917, 41.71379164287022, 53.04571989604405, 48.17787102290562, 39.40933125359671, 37.890309129442485, 38.974547726767405, 36.96320404325213, 41.998646940503804, 44.54509571620396, 51.48219108581543, 47.93053947176252, 51.10300357001168, 50.04956633704049, 53.1898637499128, 54.37637288229806, 53.92765474319458, 55.597101892743794, 55.5844144821167, 52.08462074824742, 52.273952211652485, 47.16299976621355, 46.993050302777974, 41.28644963673183, 42.951866831098286, 50.33771855490548, 50.98348413194929, 54.14050585883004, 53.26050955908639, 57.522541522979736, 52.31871598107474, 46.11327287128994, 40.37378290721348, 39.62264442443848, 40.390038217817036, 41.1850128855024, 42.412443433489116, 41.69322844914028, 45.78785399028233, 42.410237380436485, 52.90048517499651, 58.60458101545061, 59.59993825639997, 53.47625112533569, 55.81788090297154, 58.38840866088867, 62.40108367374965, 55.66737249919346, 50.60374423435756, 63.653857776096885, 56.32522794178554, 63.14039979662214, 61.4972620010376, 65.34642505645752, 65.17760467529297, 64.12027645111084, 63.394689968654085, 67.5104831968035, 63.02582400185721, 66.58316271645683, 63.84055587223598, 63.715300696236746, 60.01878956386021, 63.32087230682373, 62.73622308458601, 71.82185431889125, 66.55713476453508, 78.64886937822614, 68.18259634290422, 90.55962426321847, 34.63251767839704, 0.3277837112545967, 0.23492983090026037, 9.238880702427455, 80.10705307551792, 62.842467989240376, 71.75416496821812, 46.6228016444615, 58.25609411512102, 52.271489075251985, 36.763273102896555, 0.6930558851787022, 0.13973001071384974, 0.09125973018152372, 0.10101987288466521, 0.141307373930301, 0.17978921186711105, 0.11010304119970117], [0.08010871961180653, 0.05518880859017372, 0.02235033961811236, 0.06453607630516801, 0.03074365834306393, 0.006600498587691358, 0.03372097161731549, 0.2738550507596561, 4.421276858874729, 55.37424884523664, 49.09929248264858, 30.78861788340977, 36.05834708895002, 53.85611956460135, 68.1415046964373, 20.61786563055856, 0.5926611466067178, 0.7007802735481943, 0.9700768717697689, 10.093368428094045, 78.76743343898228, 68.90809944697789, 67.5092464174543, 56.00504800251552, 57.80255045209612, 60.5365206854684, 62.936664717538015, 64.67939104352678, 63.510002272469656, 62.763668469020296, 63.70661544799805, 61.98097474234444, 60.82733753749302, 62.029007639203755, 60.87336240495954, 57.8218560218811, 56.90282474245344, 58.980819020952495, 58.93744836534773, 48.951323645455496, 55.98849391937256, 56.1498623575483, 53.79385675702776, 52.67376545497349, 51.28251722880772, 49.856323037828716, 43.87535885402134, 42.318330083574565, 42.50942986352103, 39.53289801733834, 41.68727036884853, 43.07292876924787, 40.13342734745571, 37.986975942339214, 37.363448074885774, 37.795365469796316, 37.18178742272513, 38.57266392026629, 39.17481565475464, 38.909675870622905, 39.620945589882986, 42.29230213165283, 43.15261765888759, 43.47014686039516, 42.820021288735525, 43.330321311950684, 42.67416817801339, 43.45853642054966, 45.01480783735003, 47.83654771532331, 46.139071532658164, 50.84010805402483, 48.50552722385952, 49.69970716748919, 50.953450543539866, 49.428987979888916, 48.85168995176043, 51.66568258830479, 52.84796026774815, 49.26791484015328, 48.14249774387905, 42.406457560403005, 40.980798380715505, 37.51803159713745, 35.83237777437483, 41.81492962156023, 40.500108105795725, 40.973450660705566, 33.090913908822195, 29.424613543919154, 43.80689130510603, 46.17296831948416, 41.22162989207676, 37.804290430886404, 37.533751896449495, 36.165668964385986, 37.37202910014561, 37.887505531311035, 41.194903646196636, 47.40112495422363, 47.73167160579136, 47.0379113469805, 48.3445200920105, 45.70868274143764, 47.67172254834856, 46.57050255366734, 46.05270542417254, 42.88617161342076, 41.066935198647634, 39.78093481063843, 39.92162193570818, 39.32014765058245, 42.063668182918, 41.24830402646746, 42.17844894954136, 47.62385293415615, 51.09720529828753, 50.04593242917742, 42.63984407697405, 37.097891398838584, 35.70470462526594, 35.65376043319702, 35.89722531182425, 33.568793637411936, 36.624910150255474, 40.007032666887554, 40.64318193708147, 40.437841824122835, 47.04104845864432, 54.15912703105381, 53.47881848471505, 48.64210448946272, 48.036419595990864, 54.1270124571664, 58.19202825001308, 42.165108408246724, 51.18550648008074, 56.65270348957607, 53.90767867224557, 55.77891193117414, 53.08882304600307, 57.04201453072684, 55.76440756661551, 59.922049794878276, 59.04383223397391, 60.51090267726353, 60.34149864741734, 64.64281572614397, 59.73907593318394, 60.79226997920445, 56.11095939363752, 61.38385350363595, 56.437823499952046, 62.73844650813511, 59.69237014225551, 72.13766384124756, 63.90397208077567, 87.05198601314, 28.999891008649552, 0.322107195854187, 0.09796715740646635, 4.382371289389474, 58.947898456028526, 50.10702446528843, 48.50120891843523, 25.937229292733328, 29.69363042286464, 28.687454836709158, 11.194673538208008, 0.43058537638613154, 0.015787991661844508, 0.03312031884810754, 0.03655491383480174, 0.058922813939196725, 0.06151828502437898, 0.07174372633120843, 0.03906219572361026, 0.053790364880114794, 0.029220642388931344, 0.04066519060039094, 0.08580202196857759, 0.0725864532536694, 0.14380715122180326, 0.25574283408267157, 5.905328265258244, 65.23665741511753, 54.19673415592739, 34.79878112248012, 39.96514197758266, 60.95075144086565, 73.75949845995221, 23.442690508706228, 0.7576063871383667, 0.6499375360352653, 1.0519900534834181, 10.58785695689065, 83.33533205304826, 69.42879744938442, 70.12074075426374, 58.01774311065674, 61.05420316968645, 63.636751311165945, 65.45022419520787, 67.20102432795933, 65.51039559500558, 64.36114965166364, 65.23159912654332, 64.71871089935303, 62.79408073425293, 63.8695923941476, 61.75579057421003, 62.07118320465088, 60.250477245875764, 59.22848061152867, 61.76007761274065, 54.903737681252615, 58.359024729047505, 58.02966969353812, 54.92518677030291, 56.204610688345774, 53.22950669697353, 51.26628623689924, 45.584782464163645, 44.816402026585166, 44.53802939823696, 44.151636600494385, 43.18102189472744, 44.30338525772095, 42.05246768678938, 40.84794882365635, 39.76944596426827, 39.37092508588518, 38.49319042478289, 39.9940047945295, 39.86743640899658, 40.188578673771445, 41.1917074748448, 43.36537497384207, 44.3245564188276, 44.29178524017334, 44.28717858450753, 44.740690980638774, 45.41859197616577, 46.25197628566197, 46.421213558741975, 48.69765533719744, 48.60920129503523, 52.75560481207711, 50.52272476468767, 52.372950145176475, 51.05788891656058, 53.392994335719514, 51.546055453164236, 52.95532383237566, 55.40797192709786, 51.71190895353045, 51.0281263078962, 44.1280300957816, 41.02286972318377, 38.01599161965506, 37.715426445007324, 42.590918336595806, 41.61026348386492, 43.40442732402256, 37.067750113351, 34.96389463969639, 44.49394655227661, 47.619715281895225, 40.28836522783552, 37.86903027125767, 37.83878476279122, 36.089426381247385, 38.775686808994834, 38.45409985951015, 42.82350581032889, 47.28180353982108, 48.05527353286743, 49.56712859017508, 52.390470027923584, 47.425096239362446, 48.876349108559744, 47.934135164533345, 47.7108165877206, 45.24195139748709, 42.609998089926584, 42.56097160066877, 41.72316823686872, 40.98772920880999, 44.68898248672485, 42.82096971784319, 44.55679995673043, 49.61340011869158, 52.03289835793631, 51.386934757232666, 44.35827950068882, 38.952320439474924, 38.15348604747227, 37.56827054704939, 37.94437306267874, 36.158738136291504, 38.57897635868618, 40.64926855904715, 42.945363317217144, 41.851497990744456, 50.61288111550467, 54.81276491710118, 54.72941085270473, 52.73794943945748, 51.60786315373012, 56.1723119871957, 59.53183896200997, 45.30874790464129, 53.618136814662385, 57.68222502299717, 56.647287368774414, 58.256705556597026, 55.384070123944966, 58.83907576969692, 58.392647062029155, 61.646467617579866, 61.73726667676653, 63.8293901171003, 63.555228097098215, 64.99718080248151, 62.175315856933594, 64.66028349740165, 59.267119543892996, 63.65244729178292, 59.74207060677664, 64.90351908547538, 61.677560806274414, 73.3676061630249, 65.51319571903774, 87.16570023127964, 30.45831789289202, 0.41072623059153557, 0.2291429042816162, 6.492691627570561, 66.62885407039097, 58.466694014413015, 57.000002247946604, 34.36414350782122, 43.15798166819981, 46.60947847366333, 18.32842377253941, 0.6176800355315208, 0.04092634176569326, 0.014404672497351254, 0.006485919044020453, 0.04534590497080769, 0.07025569903531245, 0.03084060742652842, 0.1869261246174574, 0.1730130219033786, 0.11073265384350504, 0.20985581779054233, 0.18639017694762774, 0.1239474897405931, 0.32605268699782236, 0.38777087522404535, 8.424322537013463, 76.54932526179722, 60.8955271584647, 42.026252133505686, 49.58688926696777, 68.82319246019635, 79.41586712428501, 25.27140600340707, 0.7636207044124603, 1.1296323729412896, 1.289030236857278, 12.733232259750366, 84.49006012507847, 73.87809031350272, 71.98958383287702, 62.23205484662737, 64.04872390202114, 65.05046653747559, 67.74670110430036, 69.38020869663784, 68.96094744546073, 67.46493080684117, 68.31207602364677, 66.89456013270787, 63.21475941794259, 67.04728848593575, 63.08218778882708, 65.68779700142997, 61.58835288456508, 64.14614459446499, 62.70627634865897, 54.9877552986145, 61.644341468811035, 61.43141392299107, 56.38009091785976, 58.8799798148019, 57.94102110181536, 54.640640667506624, 49.94314425332205, 46.88572147914341, 47.68000132696969, 44.424732072012766, 45.29450409752982, 48.14143814359392, 44.75829076766968, 42.97061654499599, 43.16981792449951, 41.47548232759748, 41.61971650804792, 43.2696670123509, 44.004272256578716, 44.651451792035786, 45.71179206030709, 46.844932079315186, 47.47259759902954, 45.72215877260481, 44.98990896769932, 46.80788081032889, 48.24478564943586, 48.886392729622976, 48.809257302965435, 52.76659686224801, 49.945350306374685, 55.47494213921683, 53.53829506465367, 55.92419876371111, 55.80948747907366, 55.639256613595144, 53.052466596875874, 58.347233636038645, 57.041951996939524, 53.49519191469465, 51.87331560679844, 46.870407649448936, 43.567511967250276, 40.52881458827427, 39.66405916213989, 44.629009110586985, 44.482023443494526, 48.09438146863665, 41.28026573998587, 39.22128868103027, 46.89224236352103, 48.22250277655465, 40.805443218776155, 38.95752116612026, 38.931757245744976, 37.05575404848371, 40.16965872900826, 39.214566298893516, 43.71262509482247, 49.61320556913103, 51.13404812131609, 50.78435918263027, 54.58606604167393, 49.202216148376465, 51.29640320369175, 51.39171164376395, 51.17092915943691, 46.95139585222517, 45.63807167325701, 44.81770133972168, 43.438205991472515, 41.85266181400844, 45.55525956835066, 43.91459880556379, 45.01450906481062, 51.68313646316528, 55.814354692186626, 55.56301403045654, 45.47706454140799, 42.457471234457834, 39.37803309304373, 40.56574773788452, 41.113703523363384, 38.12938969475882, 41.68907690048218, 43.678099496024, 45.07069219861712, 45.49645001547677, 53.37304605756487, 57.72363976069859, 58.35616207122803, 58.824880599975586, 55.69542932510376, 59.96191855839321, 57.91458668027605, 47.30270024708339, 56.383499009268625, 59.11615603310721, 60.930309840611045, 58.95980766841343, 59.05489376613072, 61.16514505658831, 59.817284856523784, 63.799200194222585, 64.10512242998395, 64.22532626560756, 65.9395580291748, 68.19576317923409, 64.33266203744071, 66.775481905256, 61.33828721727644, 66.73179858071464, 63.99015753609793, 68.250257900783, 67.60206740243095, 78.71122251238141, 70.07347910744804, 92.45728846958706, 33.87331581115723, 0.636466498885836, 0.502024447279317, 10.051971060889107, 74.63574273245675, 65.57456915719169, 66.58131449563163, 43.63563905443464, 48.721737793513704, 56.244837284088135, 33.42580318450928, 0.5238460249134472, 0.3302651681005955, 0.08801168482750654, 0.11313295790127345, 0.2031603327819279, 0.1686051498566355, 0.09149755670556001], [0.010679924062320163, 0.0032941840389477356, 0.03534757612007005, 0.044712825013058524, 0.04732973441215498, 0.04195154032536915, 0.12811855306582792, 0.3472944428878171, 3.7785676206861223, 52.520599365234375, 46.27381794793265, 26.957726853234426, 32.92178085872105, 53.95042398997715, 69.35020637512207, 26.067068542752946, 0.47612916252442766, 0.5740772123847688, 0.4410061543541295, 6.474309299673353, 75.74664156777519, 64.85219969068254, 66.36503096989223, 61.28386197771345, 57.13435609000069, 57.39511503492083, 58.69966016496931, 63.767926352364675, 61.45100089481899, 63.17830916813442, 61.570919854300364, 65.05250930786133, 60.711643082754954, 58.406960351126536, 56.8542811529977, 63.15171841212681, 57.12220369066511, 59.27322006225586, 58.99760586874825, 46.5186550957816, 56.052340916224885, 52.189990179879324, 51.87924589429583, 50.557917390550884, 46.59853506088257, 44.18679795946394, 42.79766198566982, 41.8058865410941, 41.21601922171456, 41.2504996572222, 40.5603038242885, 42.14287764685494, 41.932646002088276, 38.42587627683367, 37.8627039364406, 37.42758689607893, 37.82647950308663, 36.461839403424946, 36.8175767489842, 36.883240699768066, 38.212719440460205, 41.347472190856934, 41.39438990184239, 42.410084520067485, 44.6571284702846, 46.92542348589216, 42.322995798928396, 46.51563262939453, 48.17415721075875, 45.68390546526228, 46.210881165095735, 47.8394763810294, 46.39938579286848, 48.91421331678118, 48.788086141858784, 49.71912390845162, 50.880963461739675, 50.470915521894185, 52.52699518203735, 49.67480134963989, 48.569666045052664, 47.96563829694475, 40.29766191755022, 39.85556888580322, 39.64151920591082, 40.71973371505737, 34.91453811100551, 36.43008266176496, 34.13057286398751, 32.929118156433105, 36.4704065322876, 39.82904413768223, 43.69129065104893, 34.956300258636475, 40.70593111855643, 36.82804421016148, 40.803136416843955, 47.075494153159006, 48.91294527053833, 48.15599461964199, 48.15256220953805, 48.99947118759155, 47.502759729112896, 47.50331905909947, 44.69277272905622, 46.19931936264038, 46.43727779388428, 44.93205826623099, 44.871584619794575, 43.09140750340053, 42.662436144692556, 40.75327614375523, 41.73311458315168, 41.05816657202584, 43.382304259708945, 45.68517698560442, 48.004805292402, 42.53436694826399, 36.51070261001587, 33.66851418358939, 35.599679129464285, 36.34703779220581, 34.66084895815168, 35.35359130586897, 37.08541938236782, 41.833495208195274, 40.45127616609846, 40.765953132084434, 46.57458809443882, 53.39704860959734, 53.14670154026577, 50.326295716421946, 46.65841463633946, 58.22597714832851, 48.82914652143206, 44.56490503038679, 57.61916317258562, 52.926009382520405, 53.22263840266636, 51.47930758340018, 53.61147696631295, 54.949588843754356, 56.06387145178658, 57.85274076461792, 59.76686177934919, 60.515134130205425, 59.896049635750906, 62.034538405282156, 62.72259766714913, 63.963886397225515, 61.345075607299805, 62.57340594700405, 59.56545434679304, 62.60862636566162, 59.823982919965474, 71.85733182089669, 64.90504768916539, 86.32529476710728, 28.197242055620464, 0.489443159529141, 0.12751946092716285, 3.9680528129850114, 60.10754585266113, 51.36220611844744, 51.86147935049874, 21.610596452440532, 15.013981921332222, 28.936942066465104, 11.96224798474993, 0.4077179048742567, 0.035971465320991616, 0.026523158652707934, 0.06834085285663605, 0.05505983265382903, 0.05412243652556624, 0.027359926341367618, 0.04622627701610327, 0.08479975789253201, 0.05062363516273243, 0.015258176252245903, 0.1094072578208787, 0.08559762007955994, 0.15027335924761637, 0.2764121778309345, 5.169874472277505, 62.904035976954866, 51.741817474365234, 32.221920081547324, 38.13895389011928, 60.45062705448696, 75.21442345210484, 27.903328044073923, 0.481424232678754, 0.4100323606814657, 0.6790643302457673, 6.21954882144928, 80.63219792502267, 67.8140013558524, 69.08646665300641, 64.49281106676374, 61.6821813583374, 60.181405203683035, 62.14782878330776, 66.04644911629813, 63.651724679129465, 65.28890092032296, 63.66704545702253, 66.04315567016602, 63.54279776981899, 60.62135819026402, 60.621372086661204, 65.52363886151994, 59.430853843688965, 59.61649581364223, 62.73090771266392, 51.67826925005232, 57.051693371364046, 55.45265926633562, 53.25340502602713, 51.3849857875279, 49.41202742712838, 46.777548449380056, 45.12090335573469, 43.58504574639456, 43.81491300037929, 44.98956503186907, 44.75679690497262, 44.67833437238421, 42.58568286895752, 41.72138949802944, 40.01705891745431, 39.98381873539516, 39.802241461617605, 39.19872440610613, 40.274253436497276, 39.23964582170759, 39.33756331035069, 43.74674422400338, 44.417269706726074, 45.03021894182478, 44.63796533857073, 48.178037779671804, 45.16324915204729, 48.68865047182356, 51.34143100466047, 47.57949216025216, 49.80725833347866, 49.61843408857073, 49.38962990897042, 51.423874855041504, 52.01249497277396, 52.46844618661063, 51.812272208077566, 51.63000011444092, 54.23065873554775, 52.006620270865305, 51.54372085843767, 52.11449452808925, 41.69289493560791, 40.548950467790874, 39.73870365960257, 40.6203327860151, 37.55498211724417, 40.83985069819859, 37.09075212478638, 36.43924386160714, 39.254622663770405, 43.586504868098665, 41.552735873631065, 35.55374806267874, 39.657347202301025, 36.94488164356777, 43.38200201307024, 50.285766874040874, 50.364177295139854, 51.13911683218819, 50.44323737280709, 51.46712391717093, 49.31639589582171, 49.54615545272827, 48.27843230111258, 48.78252758298601, 47.73086908885411, 46.039250237601145, 47.18959052222115, 45.26849351610456, 45.25903006962368, 42.51123292105538, 42.55730642591204, 42.33071872166225, 43.5698778288705, 44.656207833971294, 47.953833307538716, 44.06329720360892, 38.01669338771275, 36.4837783404759, 36.92654882158552, 39.15987702778408, 36.80435085296631, 37.34548698152815, 38.23040607997349, 43.49638673237392, 42.34653629575457, 43.78179093769619, 48.747887338910786, 55.87229919433594, 54.13796281814575, 53.24725587027413, 49.29775387900216, 59.33876241956438, 50.44108690534319, 48.69198560714722, 57.38335868290493, 55.35899754932949, 55.62761838095528, 53.761547633579795, 55.36764110837664, 57.44218560627529, 56.56096642357962, 59.737484795706614, 61.53918743133545, 61.80597046443394, 61.019733156476704, 64.83161217825753, 64.03520965576172, 65.65359101976667, 65.87236894880022, 66.41014562334333, 61.54134137289864, 65.48279735020229, 62.50387532370431, 73.469133240836, 69.2099222455706, 86.94281591687883, 29.872157437460764, 0.4539780882852418, 0.3158543328089373, 4.820073493889399, 68.42720072610038, 57.49027408872332, 61.744319098336355, 29.51930012021746, 24.895650897707256, 41.56665311540876, 26.233406679970876, 0.41343358531594276, 0.09677949042192527, 0.07275878079235554, 0.0420288797467947, 0.05649258309443082, 0.03464720584452152, 0.03640234862853374, 0.11535278521478176, 0.1353767743068082, 0.16258140094578266, 0.09492117299565248, 0.2610853745469025, 0.12452963207449232, 0.2601838457797255, 0.5924474352172443, 7.280792789799826, 74.55494907924107, 58.04619598388672, 40.1611020224435, 47.81383752822876, 68.07480198996407, 80.76093414851597, 32.06386593409947, 0.6247159551296915, 0.7662093426500047, 0.8613545000553131, 8.923966629164559, 81.70213712964738, 71.12084361485073, 69.80047743661063, 68.0215093067714, 62.83547115325928, 62.91902324131557, 63.023892402648926, 68.23351274217877, 65.66521535600934, 69.06585829598563, 67.1200430733817, 69.43726035526821, 64.72108023507255, 64.2189130783081, 62.55572278159005, 67.32309028080532, 62.796144349234446, 61.843643597194124, 61.92857142857143, 55.86171708788191, 58.70731013161795, 56.998272146497456, 56.72801154000418, 56.735373156411306, 52.094431604657856, 50.50736229760306, 46.59723227364676, 46.50093024117606, 45.69130877086094, 48.50610045024327, 45.38715485164097, 46.268311500549316, 45.27281182152884, 45.62538773672921, 42.946686949048726, 43.40650830950056, 43.06957973752703, 41.42456592832293, 42.701564925057546, 41.062186104910715, 40.016225133623394, 47.34524754115513, 45.38128014973232, 47.43449020385742, 48.6767065184457, 50.57533652441842, 47.08301905223301, 51.83188697269985, 54.92361995152065, 50.02848897661482, 52.55797372545515, 53.3651077406747, 53.9025092124939, 56.122608048575266, 54.70677014759609, 55.421524388449534, 56.597225597926546, 53.67225980758667, 57.59054354258946, 54.253139632088796, 54.02289717538016, 51.86957400185721, 43.809013979775564, 43.066095215933665, 41.11712203707014, 42.820688315800254, 40.58417088644845, 43.74321106501988, 38.63079602377755, 39.24973113196236, 42.159424781799316, 45.545250688280376, 43.81037582669939, 36.78413854326521, 40.97037608282906, 38.60080759865897, 43.291244643075125, 53.08283717291695, 53.24424730028425, 52.16520248140608, 53.26547057288033, 54.616777079445974, 52.32201637540545, 52.84794289725167, 52.356006962912424, 51.80329166139875, 49.65582581928798, 49.40430450439453, 49.238986015319824, 47.0308380808149, 48.18161262784685, 42.971707412174766, 46.10086686270577, 45.31132568631853, 46.31142159870693, 47.756824084690635, 51.78944042750767, 48.09229700905936, 42.76309469767979, 38.28204161780221, 39.96470076697213, 40.45775883538382, 38.992630413600374, 40.227881159101216, 41.75161068780081, 47.14952026094709, 44.062084742954795, 45.79868623188564, 51.172760009765625, 57.58640241622925, 57.98855025427682, 56.457115173339844, 51.099116052900044, 60.87630844116211, 51.87604972294399, 52.380145004817415, 58.72035884857178, 57.904008047921316, 57.12788036891392, 57.15208789280483, 58.20281185422625, 60.87226458958217, 58.51364994049072, 63.11205809456961, 65.64044502803257, 65.07271466936383, 63.07514926365444, 66.88563169751848, 65.96521077837262, 69.37836742401123, 68.45710577283586, 70.51948397500175, 64.8865863255092, 68.34996455056327, 66.15519537244523, 77.69370746612549, 71.9597065789359, 87.57822867802211, 34.5994998386928, 0.5998862417680877, 0.689303097980363, 7.067980757781437, 76.04454558236259, 66.38620907919747, 71.71589429037911, 37.95900249481201, 28.063720260347637, 52.45846162523542, 35.89617960793631, 0.6368818166000503, 0.22433039466185228, 0.0758330872548478, 0.14319822032536778, 0.17536903119512967, 0.1091736178579075, 0.14599324177418435], [0.05769924566681896, 0.04073086939752102, 0.0678044573536941, 0.03271546753655587, 0.027068239403888583, 0.02692289720289409, 0.217963076329657, 0.1807318598564182, 3.57973775267601, 51.32760408946446, 46.194014413016184, 38.09189721516201, 38.457643440791536, 50.67151696341378, 67.78814710889543, 32.50397525514875, 0.23120041244796344, 0.37585314043930595, 0.5441058320658547, 3.5549928290503363, 69.53800923483712, 71.00658048902238, 67.90641239711216, 61.64720412663051, 58.8079617364066, 57.26660115378243, 57.1540264402117, 60.765651430402485, 59.8009010042463, 60.74514034816197, 62.314474378313335, 62.10585471561977, 58.69975049155099, 58.62671102796282, 58.05938713891165, 60.487549781799316, 54.49666357040405, 63.84409250531878, 50.93337719781058, 47.703677313668386, 54.78276606968471, 48.98220838819231, 48.71244805199759, 44.58385624204363, 44.02757651465279, 40.07090745653425, 40.8612824167524, 41.214462825230186, 40.043152877262656, 41.52889660426548, 40.87767669132778, 43.05603769847325, 38.55629743848528, 37.67077384676252, 36.77425473076956, 36.975585733141216, 38.45351273672921, 39.383490903036936, 37.829251834324424, 37.51428304399763, 37.7717068535941, 38.03584262302944, 43.49037306649344, 42.45845440455845, 45.12357841219221, 45.25565324510847, 46.42945064817156, 46.293373652866904, 47.121404375348774, 47.022694792066304, 47.48449986321585, 46.68580443518502, 48.8590133530753, 49.311976841517854, 49.72947325025286, 49.843732901981895, 49.382706029074534, 49.24626772744315, 48.005555697849815, 49.44519117900303, 49.48389959335327, 51.7219352040972, 46.63296685900007, 37.30871711458479, 39.027430466243196, 37.266663142613, 30.650852475847515, 33.33968721117292, 36.32830197470528, 35.05562128339495, 29.731432097298757, 32.0600756917681, 37.624460629054475, 36.397068296160015, 37.69158717564174, 36.730154514312744, 46.239035265786306, 49.382379463740754, 48.79556587764195, 49.565940448216026, 49.82807513645717, 46.144338267190115, 46.918739318847656, 45.11696720123291, 46.46970851080758, 46.64050565447126, 45.498968737465994, 43.61796978541783, 43.999530111040386, 44.254306656973704, 42.691580363682334, 43.96334736687796, 40.8946441922869, 40.0138384274074, 38.64209379468645, 41.265716212136404, 38.12189258847918, 34.34910760607038, 34.8401472227914, 35.73764950888497, 34.805472237723215, 35.865166323525564, 35.61198091506958, 36.96965544564383, 37.27411508560181, 42.56727014269148, 41.80552176066807, 42.13241365977696, 46.20521143504551, 53.39710072108677, 52.603376729147776, 49.624816008976524, 47.8387086050851, 53.455740043095176, 43.388703550611226, 50.54406615665981, 56.53014421463013, 54.28119993209839, 53.22471591404506, 52.275991507938926, 50.22649874005999, 51.69264159883772, 51.60773113795689, 55.36292675563267, 55.72253772190639, 58.976747376578196, 60.3688120160784, 60.22733974456787, 62.436526434762136, 65.43024812425885, 65.48620891571045, 65.07413210187639, 63.58102675846645, 66.33048452649797, 60.64494732448033, 70.13595730917794, 64.10253075190953, 99.80757931300572, 25.377746445792063, 0.2712018702711378, 0.2886087905083384, 3.977786804948534, 64.59617246900285, 48.74990579060146, 53.88541316986084, 21.279549530574254, 29.651270730154856, 24.691822017942155, 24.299365179879324, 1.2505581698247363, 0.1261588353663683, 0.02822445289764021, 0.0064654332236386836, 0.020099493076226542, 0.028071874120671834, 0.07612724575613226, 0.039925292267331054, 0.023180398291775157, 0.0858889219484159, 0.03138323527361665, 0.05664303805679083, 0.064774147101811, 0.13547824243349688, 0.34353557601571083, 5.992430882794516, 62.905905042375835, 49.35148777280535, 46.98688725062779, 47.2252174104963, 56.93376507077898, 74.25017329624721, 36.581143447331016, 0.22131837771407195, 0.5111580714583397, 0.42063808015414644, 4.04182140316282, 71.48372718266079, 74.5366405759539, 69.98437540871757, 63.44689873286656, 61.773835045950754, 59.83044474465506, 59.09292820521763, 61.39326136452811, 61.90023667471749, 62.885581561497276, 62.630811963762554, 62.554631914411274, 59.452351570129395, 60.264679363795686, 59.6576360974993, 61.996232986450195, 56.35451807294573, 64.9674494607108, 55.75102186203003, 50.59116104670933, 56.66219820295061, 51.647130898066926, 49.95222554888044, 46.72505480902535, 46.466328212193076, 42.405453545706614, 43.2642821584429, 43.18990864072527, 41.92745917184012, 42.74741261345999, 42.441299302237375, 44.24899475915091, 42.67442873546055, 40.073790958949495, 40.3427939414978, 38.85377066476004, 40.58300706318447, 40.90528883252825, 39.83893142427717, 40.61000081471035, 40.348164899008616, 39.61580044882638, 45.04228796277727, 43.82779148646763, 46.40302664893014, 46.25838252476284, 48.554703099387034, 48.407408237457275, 49.78740733010428, 48.66329302106585, 49.927340575626914, 51.618917737688335, 52.235233375004356, 52.46549320220947, 51.50149665560041, 52.463460854121614, 53.191618170057026, 52.88782555716378, 50.36462197984968, 52.834261894226074, 52.83223649433681, 53.38413538251604, 46.27242136001587, 37.58702026094709, 39.4863555090768, 38.84259448732649, 33.431521551949636, 36.228293078286306, 38.37105846405029, 36.61842748097011, 32.78148978097098, 35.738486766815186, 38.543849740709575, 35.48121929168701, 37.29745061056954, 37.78818103245327, 48.10075644084385, 50.184486457279746, 50.27997555051531, 51.19636651447841, 53.26851735796247, 48.64815289633614, 49.333384241376606, 48.008154324122835, 47.56269836425781, 48.205597809382844, 47.18254852294922, 46.86481434958321, 46.238597529275076, 45.96379280090332, 45.01286581584385, 44.80060877118792, 43.61460338320051, 40.921217577798025, 41.73936448778425, 43.90342957632882, 40.30978304999215, 36.473397731781006, 36.55836377825056, 36.63339390073504, 36.76288400377546, 38.79210540226528, 37.871375288282124, 38.23492240905762, 39.559589522225515, 44.47080557686942, 43.451101848057334, 43.86801808220999, 47.50734901428223, 56.576492173331125, 55.32175867898123, 52.81386545726231, 50.527435643332346, 54.118500913892476, 44.96116427012852, 53.08329227992466, 57.85496766226632, 55.94089528492519, 55.24289662497384, 54.48413249424526, 54.28100538253784, 53.718114444187705, 53.73616239002773, 57.19323859895979, 57.38866710662842, 61.230340003967285, 61.79187256949288, 61.01440388815743, 61.97108050755092, 67.311340876988, 66.4625836781093, 67.61749240330288, 65.83261830466134, 69.73877048492432, 61.87649468013218, 74.16887937273297, 65.51227160862514, 99.99615342276437, 26.957673004695348, 0.314353630478893, 0.8441575999770845, 4.838846657957349, 71.75261551993233, 55.86527803965977, 62.68302072797503, 27.395670073372976, 34.1317366872515, 37.953370979854036, 39.08853987285069, 3.4155344494751523, 0.19607630505093507, 0.014929565135389566, 0.02886984996231539, 0.02540690408620451, 0.08466810174286366, 0.01232710768402155, 0.10562720030014004, 0.0735460306916918, 0.1770892667451075, 0.10426865105650254, 0.17205282699848923, 0.17737209371158055, 0.30597024889928953, 0.4522237495652267, 7.9218670300074985, 75.61119338444301, 57.512251240866526, 49.42971406664167, 54.17306511742728, 65.82359954289028, 79.6171703338623, 40.75108746119908, 0.4121959645833288, 1.0270095424992698, 0.94341022840568, 5.260007372924259, 74.29719870431083, 76.41562107631138, 73.36044951847622, 67.32586261204311, 64.90324115753174, 62.907252992902485, 61.083600997924805, 64.9329447065081, 65.261976650783, 65.01859515053886, 65.49898665291923, 66.11732769012451, 62.72335502079555, 62.68351405007498, 62.86866269792829, 66.59751074654716, 59.3834045955113, 65.4646486554827, 58.379396847316194, 54.59576572690691, 59.11064611162458, 54.765221868242534, 54.50662728718349, 50.344388825552805, 48.62005090713501, 44.388045583452495, 45.24572079522269, 47.3760141645159, 43.76434748513358, 46.76024743488857, 44.40297031402588, 46.854989596775596, 45.684089592524934, 42.50360032490322, 41.07797588620867, 42.54472323826381, 43.05986615589687, 45.54790142604283, 42.78799704142979, 42.22951473508562, 42.571668352399556, 42.43098817552839, 46.619515146527974, 46.37091554914202, 49.00762489863804, 47.63669320515224, 51.362716811043875, 51.44971867970058, 53.00861651556832, 52.23963853291103, 52.75178330285208, 53.93164995738438, 56.89271511350359, 56.08751617159162, 55.76608208247593, 55.97823143005371, 57.272058963775635, 56.81140034539359, 53.943111010960166, 55.55326918193272, 54.1749723979405, 56.593477044786724, 50.3908166885376, 39.00599179949079, 42.23487179619925, 40.34416273662022, 34.62543051583426, 37.573926380702424, 40.467416831425254, 38.291293144226074, 34.731192520686555, 37.39028549194336, 37.822581563677105, 37.023333753858296, 38.33558791024344, 38.55709300722395, 48.245390142713276, 54.35871403557913, 51.27967194148472, 53.63721309389387, 55.85351126534598, 49.99500560760498, 51.77369580950056, 52.235483510153635, 50.63623053686959, 52.98904691423689, 51.091528620038716, 48.93283796310425, 49.33042778287615, 48.624317101069856, 47.075431619371685, 47.38620369774954, 44.59173549924578, 45.474212305886404, 43.58645623070853, 47.79979174477713, 42.26608657836914, 38.574102197374614, 39.21952731268746, 39.74246610913958, 38.806877272469656, 40.89918484006609, 40.20612634931292, 41.754261425563264, 41.952427523476736, 47.18007843835013, 46.83297075544085, 46.59494284221104, 50.55863305500576, 57.6869706426348, 57.73040730612618, 56.43473155157906, 53.0425306728908, 54.890695912497385, 50.3370862688337, 54.774973664964946, 61.2985782623291, 59.55841582162039, 57.94135808944702, 57.50461517061506, 57.61435154506138, 57.513151032584055, 57.710010869162424, 60.010201590401785, 61.35317720685686, 62.62020206451416, 64.52023560660226, 63.822122301374165, 66.82525879996163, 69.64799227033342, 70.02335480281285, 69.43881675175258, 68.99765477861676, 74.3681606565203, 63.78490080152239, 77.44840131487165, 68.81020627702985, 98.44612843649728, 30.738549164363317, 0.5312098669154304, 1.6540035839591707, 6.966890547956739, 80.73190457480294, 62.59416021619524, 72.97661713191441, 36.289673464638845, 49.030995164598735, 47.12535095214844, 59.63692351749965, 4.836973684174674, 0.4005887545645237, 0.1294009435389723, 0.11988685120429311, 0.1651339139789343, 0.2697009508098875, 0.08600517535316092], [0.022054812172427773, 0.009788192492643637, 0.13893347845545836, 0.06054956093430519, 0.03995482889669282, 0.04469572253791349, 0.13413843432707445, 0.19308127862002167, 3.443136819771358, 51.5871262550354, 39.34550510134016, 35.852485861097065, 42.180689743586946, 45.8381415775844, 64.71067878178188, 37.65770081111363, 0.16657487808593682, 0.05933779238590172, 0.5532206743955612, 2.754525827510016, 58.12651368549892, 69.31770965031215, 64.51464925493512, 64.89209624699184, 60.385932377406526, 57.934680870601106, 56.584270681653706, 56.24563980102539, 59.15639999934605, 59.54989038194929, 59.860933440072195, 61.712968826293945, 59.81584657941546, 58.26272964477539, 58.771316937037874, 58.869418552943635, 59.18361609322684, 57.41648769378662, 42.01992579868862, 52.06770535877773, 53.5491828918457, 46.9422242300851, 43.549436228615896, 41.75096797943115, 39.81740590504238, 41.61755909238543, 40.64291443143572, 40.44198295048305, 40.29623058864048, 39.67553758621216, 39.7429906981332, 41.56307479313442, 39.70480687277657, 39.850211824689595, 38.64268439156668, 37.09552901131766, 37.764758655003135, 38.205899783543174, 37.275150367191856, 37.4193046433585, 37.10446439470564, 38.178648948669434, 39.14389269692557, 41.99645825794765, 41.99250473294939, 44.96427011489868, 44.441838536943706, 44.41665826525007, 46.421529701777864, 45.00445849554879, 46.13651806967599, 47.87302228382656, 49.15718834740775, 48.124390738351, 48.625696318490164, 48.931788785117014, 49.92008318219866, 50.61516012464251, 48.962746483939036, 49.84784276144845, 49.86594976697649, 50.85280588694981, 50.01813268661499, 39.003282002040315, 39.43586294991629, 36.241480759211946, 34.00011696134295, 36.5996013368879, 40.02466024671282, 40.20274952479771, 33.89071062632969, 30.779449735369, 35.81388166972569, 36.77136428015572, 34.36772183009556, 40.306506974356516, 49.12908983230591, 47.170625414167134, 48.37098578044346, 48.48126064028059, 46.36617340360369, 46.58271401269095, 46.69334670475551, 44.55047362191336, 43.679204259599956, 46.45185511452811, 43.84696156638009, 44.13151114327567, 44.55430555343628, 44.5605901990618, 41.297650132860454, 43.17557798113142, 41.086539540972026, 42.26029872894287, 38.945424352373394, 41.248877252851216, 38.448708057403564, 36.13340847832816, 33.51068237849644, 34.19261680330549, 33.6112436567034, 35.851832730429514, 35.952248096466064, 36.965809617723735, 37.311628409794395, 42.7186609676906, 40.870075362069265, 40.84333174569266, 44.785232407706125, 52.596557072230745, 52.902520997183665, 53.04540375300816, 52.480185168130056, 51.506349972316194, 38.82424776894705, 50.33806596483503, 52.50700521469116, 54.92513813291277, 53.18769938605172, 53.403166498456685, 51.77674954278128, 51.587223529815674, 50.026369776044575, 55.747947284153526, 54.98794984817505, 60.96145861489432, 59.63324792044503, 64.89860670907157, 61.231882504054475, 63.60944489070347, 61.84782641274588, 65.41018867492676, 63.41339451926095, 69.72891793932233, 63.81819656917027, 67.38643700735909, 71.2275471006121, 100.75623076302665, 16.47267631122044, 0.11839224211871624, 0.4032185934484005, 6.442475693566458, 65.88461862291608, 51.694149357931956, 51.67890848432268, 26.566261870520457, 29.199974809374126, 28.441686630249023, 22.985396555491857, 5.17231285572052, 0.16959065411772045, 0.05535176556025233, 0.036014827101358345, 0.004568301897961646, 0.07627927152706043, 0.044677018720124445, 0.07451306522956916, 0.04175797464059932, 0.040680291397230964, 0.09136541879602841, 0.017868475023923174, 0.04681546254349606, 0.16924411271299633, 0.1851858722844294, 5.290247670241764, 63.83082839420864, 44.18720095498221, 43.034605979919434, 43.98538705280849, 52.23530980518886, 70.330062185015, 42.39756039210728, 0.4447018360452992, 0.04646749282255769, 0.4491877667605877, 3.3686284635748183, 59.693725040980745, 73.53252165658134, 67.99981703077043, 66.71336500985282, 62.18434156690325, 62.29381043570382, 58.34991564069475, 58.90476403917585, 61.65810585021973, 63.632533754621235, 62.30783884865897, 62.93576839991978, 61.14373765672956, 58.85784980228969, 61.674809319632395, 62.909240177699495, 60.243445668901714, 61.65523624420166, 46.02328675133841, 56.22898496900286, 54.46747766222273, 49.932478768484934, 45.92128719602312, 44.16343464170183, 42.01517670495169, 43.77753169195992, 41.27846268245152, 44.58618041447231, 44.061424664088655, 43.58814811706543, 43.53154114314488, 42.958853244781494, 42.51587431771414, 44.63609627314976, 41.806056771959575, 38.90701471056257, 39.730939047677175, 40.44822938101632, 38.930874824523926, 39.644159521375386, 39.20295933314732, 42.09033536911011, 41.350216729300364, 42.781406675066265, 45.31670706612723, 48.00375264031546, 47.49792030879429, 48.2638897214617, 48.71156563077654, 47.60034023012434, 48.545118059430806, 50.981246812003, 51.58513559613909, 52.80460350854056, 52.44284554890224, 51.77015570231846, 52.87681613649641, 51.59880270276751, 52.75051525660923, 51.78280142375401, 52.41588306427002, 51.72232430321829, 50.66840764454433, 39.133581570216585, 39.701009682246614, 38.02496174403599, 36.92017732347761, 39.568431104932515, 40.90450716018677, 39.75945445469448, 36.00541223798479, 33.60806485584804, 36.74518346786499, 36.934646947043284, 35.55434908185686, 42.107184750693186, 50.70784909384591, 51.5621474811009, 48.91592604773385, 50.33328560420445, 48.94553232192993, 48.18445096697126, 49.65112883704049, 48.59278270176479, 46.98348958151681, 48.996882983616416, 46.36730595997402, 46.451983656202046, 46.693586417606895, 46.475253173283164, 44.59864200864519, 44.48222494125366, 43.35827044078282, 43.45960644313267, 40.22104760578701, 42.35686131886074, 41.59864956992013, 38.862254415239605, 35.77891138621739, 35.77979380743844, 37.00745364597866, 37.73744876044137, 38.14324787684849, 39.55447564806257, 39.21410076958792, 44.433184555598665, 42.779280526297434, 42.40421676635742, 46.728900636945454, 54.294880935123985, 54.88494627816336, 55.710809162684846, 53.95635775157383, 52.65546389988491, 41.85143893105643, 52.08157743726458, 54.50026968547276, 58.01597479411534, 54.31578459058489, 55.15856981277466, 54.74873726708548, 54.07065909249442, 53.91307394845145, 55.339959485190256, 57.02899013246809, 63.20361450740269, 61.060970715114046, 64.38602420261928, 62.78327628544399, 66.4255428314209, 64.25653757367814, 67.47030871255058, 66.72085516793388, 73.24942425319126, 66.53007847922188, 73.33557496752057, 70.72615814208984, 104.0173191343035, 17.10953082357134, 0.3246379414839404, 0.8560454249382019, 8.969609345708575, 72.5830294745309, 58.16221700395857, 60.32684489658901, 34.56040927342006, 30.68721239907401, 41.04584046772548, 33.660033907209126, 6.581458338669368, 0.08860256669244596, 0.07043405196496419, 0.07332418366734471, 0.09727103476013456, 0.13311816193163395, 0.03888577322608658, 0.23637885600328445, 0.1400733222918851, 0.36225991270371843, 0.31017304052199635, 0.1655865918312754, 0.2517066092363426, 0.39924943500331467, 0.4366998182875769, 7.273371245179858, 77.23464693341936, 50.01705571583339, 50.48316519601004, 54.39018242699759, 60.80772277287075, 75.07643917628697, 47.56381702423096, 1.1647609450987406, 0.30674402309315546, 0.5840070024132729, 4.359520401273455, 61.74562535967146, 75.50376033782959, 68.56689425877163, 70.81310789925712, 65.95931870596749, 65.45771435328892, 60.47086715698242, 62.83516543252127, 63.520368984767366, 67.13778877258301, 63.5560827255249, 66.71052319662911, 61.86669772011893, 60.75654929024832, 63.24153082711356, 65.22285829271588, 61.714914321899414, 64.68604741777692, 50.88955838339669, 58.01636389323643, 57.41328457423619, 53.41255004065377, 46.62243338993618, 46.069725036621094, 44.78296034676688, 45.84409270967756, 45.72148132324219, 48.41147640773228, 47.6457953453064, 45.39522865840367, 44.17647988455636, 45.141202517918174, 44.39467069080898, 45.89154890605381, 45.76831912994385, 41.8427780015128, 41.82301732472011, 42.28212302071707, 41.97838599341256, 40.99529579707554, 41.616245882851736, 43.130056858062744, 42.21595185143607, 43.73144429070609, 46.79676716668265, 49.223561014447895, 49.18167379924229, 50.32450655528477, 53.03257737840925, 48.871144907815115, 52.28289106913975, 54.978719166346956, 54.593358176095144, 55.3668976511274, 54.696726526532856, 55.95491327558245, 56.40600075040545, 54.54305321829659, 55.43601485661098, 53.85103348323277, 54.883636542728965, 53.93438754762922, 53.194463457380024, 40.439300945826936, 43.589225087847026, 38.23496062414986, 36.66442455564226, 40.87447009767805, 42.498510769435335, 41.795398235321045, 37.640712465558735, 35.88003894260952, 37.48316553660801, 37.485097135816304, 34.91317973818098, 44.26242562702724, 53.4664055279323, 54.33186967032296, 51.85160248620169, 53.65027570724487, 51.76317623683384, 51.48592226845877, 52.77676207678658, 51.55460173743111, 48.54743875776018, 53.0614332471575, 49.90907376153128, 49.588657583509175, 50.66726466587612, 50.65218012673514, 45.24449443817139, 48.22250277655465, 44.92022548403059, 47.126334122249055, 43.68599959782192, 46.070652621132986, 43.388915470668245, 41.347618103027344, 38.886291708265034, 37.01153918675014, 38.36735507420131, 40.03123671667916, 41.72659717287336, 42.48210607256208, 41.257545130593435, 47.23007072721209, 44.63787848608834, 43.54722670146397, 49.20883430753435, 56.78937455586025, 57.85520390101841, 56.59781272070748, 56.22820329666138, 57.80006994519915, 46.85138348170689, 53.72093888691494, 57.74591221128191, 58.54758494240897, 57.90548801422119, 59.28184972490583, 56.52197313308716, 57.21422215870449, 54.89476408277239, 58.40343066624233, 61.33252716064453, 67.05375725882394, 63.033084869384766, 67.57102285112653, 65.97586236681256, 67.77322932652065, 66.26845100947789, 69.52036081041608, 67.71720600128174, 76.33930901118687, 70.34544549669538, 76.46546745300293, 71.90680299486432, 107.79191412244523, 21.70743349620274, 0.41264805889555384, 1.4153735658952167, 11.2997841494424, 80.97636999402727, 65.86722033364433, 71.28880936758858, 44.80363818577358, 45.938508306230815, 54.64730746405465, 53.92739418574742, 8.816967844963074, 0.2958073956625802, 0.1294715247516121, 0.13521419731634005, 0.16230238734611444, 0.15357460853244576, 0.1084537532712732], [0.10004516411572695, 0.011261161400138267, 0.04631749926401036, 0.02850077101694686, 0.07792101414608103, 0.04706059010433299, 0.12345955520868301, 0.2594079545566014, 2.8138169773987363, 47.040256364004954, 44.372224535260884, 23.297228234154836, 30.16379417691912, 50.46126447405134, 60.392922265189036, 46.793720381600515, 0.31616694746272905, 0.1417047240372215, 0.19189359806478024, 0.9241423308849335, 48.544148785727366, 73.02310058048793, 66.14816379547119, 64.15029266902378, 59.590037073407856, 56.345037255968364, 54.745645318712505, 57.73265504837036, 60.56637709481375, 61.24841226850237, 60.39470100402832, 59.92932455880301, 59.210908617292134, 58.577364921569824, 59.58955069950649, 57.6247946875436, 56.70795556477138, 44.445687838963096, 50.34427765437535, 53.17638077054705, 47.925456864493235, 45.30998815808977, 41.34393555777413, 40.37931367329189, 40.23956108093262, 41.49485737936837, 39.953225816999165, 41.552197388240266, 41.818518366132466, 41.23455006735665, 39.00692285810198, 41.668638774326865, 41.330424785614014, 39.69819218771798, 38.24570948737008, 37.57537508010864, 37.17011097499302, 39.543209144047324, 39.432625089372905, 37.56091587884085, 35.34294319152832, 37.45932279314314, 40.16444410596575, 41.643479347229004, 39.29231664112636, 44.203292982918875, 42.48411062785557, 45.60531439099993, 45.32559381212507, 45.72232552937099, 46.39922945840018, 44.68166603360857, 47.59724480765206, 47.905126435416086, 49.47462027413504, 48.83721685409546, 48.284807273319785, 47.26294265474592, 50.873779024396626, 49.13409948348999, 49.33691045216152, 50.9313656943185, 52.169315814971924, 42.09669644492013, 35.42275020054409, 41.169132777622764, 36.348927702222554, 39.25517157145909, 41.27469328471592, 38.801697390420095, 39.58814314433506, 35.32441234588623, 37.759728159223286, 37.472465310777935, 35.027807644435335, 44.22911248888288, 48.03618335723877, 47.989991733006065, 47.97492109026228, 49.12442064285278, 48.512110642024446, 46.73861769267491, 47.74744749069214, 44.423314639500205, 46.02165739876883, 46.066869327000205, 43.82701676232474, 44.25044693265642, 42.67747204644339, 44.05956254686628, 42.109345640454976, 41.55326393672398, 40.39342546463013, 38.602940695626394, 35.21059043066842, 37.5001608303615, 35.89547783987862, 35.79684121268136, 33.77569709505354, 34.803387778145925, 35.22203063964844, 35.984637124197825, 35.436483315059114, 36.45382465635027, 39.70372295379639, 41.460338728768484, 40.77391576766968, 40.35391453334263, 42.40647840499878, 50.05685152326311, 53.01219483784267, 52.987817083086284, 55.98375524793352, 51.26866946901594, 41.82954863139561, 52.90814903804234, 52.79101630619594, 55.735377992902485, 52.95349645614624, 57.05750901358468, 51.097014222826274, 51.66704443522862, 49.648811612810405, 52.32079349245344, 51.74626432146345, 58.68640995025635, 57.72863898958479, 62.57241930280413, 59.88442529950823, 64.63060774121965, 63.202127592904226, 64.59312915802002, 63.37306717463902, 70.04196207863944, 67.17009094783238, 70.79640442984444, 75.19532980237688, 74.28941672188895, 5.832649673734393, 0.08540794918579714, 0.4033701510301658, 7.478058661733355, 71.08894443511963, 49.087324210575645, 51.528955936431885, 22.048722062792095, 22.535794258117676, 26.36791511944362, 16.539563144956315, 6.38173280443464, 0.027924201151888286, 0.020083310016031777, 0.03405549616685935, 0.011058927430505199, 0.02244955500853913, 0.0928796986117959, 0.038744193501770496, 0.02948446698220713, 0.02833979536912271, 0.06566130449729306, 0.07084752406392779, 0.13927256954567774, 0.11523697285779885, 0.24441917027745927, 4.347064018249512, 58.063076632363455, 47.90723521368844, 27.66269108227321, 41.85643121174404, 55.82752500261579, 67.5416875566755, 50.27931547164917, 0.41060167870351244, 0.08669500119451966, 0.21649440085249289, 1.09750639966556, 53.013817242213655, 73.54094982147217, 68.15206595829555, 66.70514529091972, 63.54851613725935, 58.37848663330078, 56.45705263955252, 59.445973123822895, 61.43883459908621, 62.020106996808735, 62.57549040658133, 61.60234655652727, 59.5181371143886, 59.20590591430664, 61.82033239092146, 59.557422229221885, 58.93941470554897, 47.991082600184846, 52.88601555143084, 55.06363310132708, 51.37268400192261, 47.782980578286306, 44.033023902348106, 43.38223130362374, 41.723074436187744, 43.73993846348354, 42.361033712114605, 43.675688471112935, 43.48769106183733, 42.80344288689749, 41.98217623574393, 42.89166416440691, 43.50769492558071, 43.1440018926348, 41.777138369424, 40.73373433521816, 38.966682365962434, 40.21998105730329, 41.026177065713064, 39.754649775368826, 38.47778279440743, 40.44837876728603, 42.16908277784075, 44.572009563446045, 41.25912931987217, 46.19793667112078, 45.906803676060264, 48.20956175667899, 47.479059423719136, 49.72741310937064, 52.09072126661028, 47.383907318115234, 48.90283564158848, 51.093620027814595, 52.81060675212315, 51.618480001177105, 52.325744083949495, 50.27605676651001, 52.788205759865896, 51.33305147715977, 50.273086411612375, 52.502495833805625, 55.016451358795166, 43.075485706329346, 37.46126134055001, 42.22500882829939, 37.34830100195748, 41.18903589248657, 41.62790148598807, 38.0381737436567, 42.36040490014212, 36.8185008593968, 37.32692486899239, 37.28513840266636, 34.425933837890625, 46.15723064967564, 52.34658867972237, 49.4527473449707, 50.34828676496233, 49.60111222948347, 51.150532722473145, 50.746762480054585, 49.04189688818795, 47.32772765840803, 49.25684288569859, 48.3804874420166, 45.85894101006644, 47.192286423274446, 46.81859493255615, 46.12104095731463, 44.27263600485665, 42.65821163994925, 43.57140643256051, 41.275322096688406, 38.2818991797311, 40.12831694739205, 37.618620668138774, 37.182808807918, 35.521414620535715, 36.50542892728533, 38.40193278448922, 37.54309722355434, 37.89513117926461, 39.23857232502529, 42.17287996837071, 42.35677099227905, 40.98631525039673, 43.7234399659293, 44.35235268729073, 50.91766037259783, 54.096898964473176, 53.63946778433663, 57.903337546757285, 52.38774285997663, 45.216656480516704, 55.43155411311558, 54.3379146030971, 57.93973568507603, 55.51015213557652, 59.710094996861045, 53.08961861474173, 55.11979191643851, 51.335424286978586, 54.07302495411464, 53.37310511725289, 61.42002582550049, 59.174423626491, 64.85206767490932, 61.452675410679404, 67.49733025687081, 66.2165618624006, 67.63574532100132, 66.61980056762695, 72.60267203194755, 68.43935312543596, 74.29261289324079, 76.69832243238176, 81.26824992043632, 4.986793347767421, 0.037675032658236365, 0.5387678242155484, 8.529307212148394, 78.85652324131557, 55.457265922001426, 59.08374268668038, 31.309527805873326, 32.56328855242048, 36.96912738255092, 35.39462736674717, 6.730752110481262, 0.02270367824738579, 0.050210261451346536, 0.05514564019228731, 0.047273799377892695, 0.04013580436419163, 0.021714408116947328, 0.19895551912486553, 0.1418568787298032, 0.15375399962067604, 0.25698056338088854, 0.1830987799912691, 0.17050986550748348, 0.2983313016593456, 0.4366516151598522, 6.559676170349121, 70.15630858285087, 56.689435141427175, 33.56293283190046, 43.7771669115339, 64.98293699537004, 72.18612057822091, 57.02798611777169, 0.7885095317448888, 0.4426221804959433, 0.46066296100616455, 1.9646044543811252, 52.1078451020377, 74.38516984667096, 70.9510087966919, 69.00751427241734, 64.5725485937936, 62.03248173849923, 59.559367724827354, 63.49461201259068, 64.24362087249756, 64.05686719076974, 63.94271523611886, 63.54542418888637, 62.470440592084614, 61.094620840890066, 62.87823036738804, 63.86473560333252, 60.03290135519845, 51.93794427599226, 55.69746862139021, 59.1064007622855, 52.86696706499372, 51.05455725533621, 46.741469928196494, 46.586330550057546, 44.34580053601946, 46.65625374657767, 45.346674646650044, 45.98753479548863, 46.71624796731131, 45.73311955588204, 44.18013463701521, 45.253273487091064, 45.86779301507132, 44.77689456939697, 43.03259795052664, 42.905171462467735, 40.95455156053816, 43.484675543648855, 42.88659545353481, 42.913040297372, 39.44001797267369, 43.34035798481533, 43.913365500313894, 47.30290869304112, 42.4137601171221, 47.7490143094744, 49.11682973589216, 52.294960090092246, 49.790235246930806, 52.36729083742414, 54.25393520082746, 50.77201918193272, 52.26715339933123, 55.26530803952898, 54.69268267495291, 54.8630907194955, 55.306608131953645, 53.860899925231934, 55.69181973593575, 54.4756452696664, 53.80263580594744, 55.03664282390049, 55.54255158560616, 45.1197395324707, 38.283865519932334, 42.52746043886457, 38.07106304168701, 40.826496260506765, 43.54647282191685, 39.86745377949306, 42.76143060411726, 37.93973861421858, 39.22571120943342, 39.10543441772461, 35.37226111548287, 46.99654524666922, 53.996011120932444, 52.06623581477574, 52.16490370886666, 52.756810324532644, 53.91768755231585, 54.48207582746233, 53.746285915374756, 50.09682450975691, 52.596223558698384, 53.4609511920384, 49.64129018783569, 50.051563944135395, 48.93069791793823, 49.98505578722273, 47.49163566316877, 43.89223950249808, 45.79846388953072, 43.21341092245919, 38.884026595524375, 41.06890501294817, 40.08069052015032, 40.290150914873394, 37.36126634052822, 40.15328529902867, 40.10920940126692, 39.768059798649375, 40.33922256742205, 41.76819256373814, 44.06173038482666, 45.167084557669504, 44.439503942217144, 45.99191910879952, 47.09162439618792, 53.79103578839983, 56.63473197392055, 56.21234055927822, 59.50670037950788, 56.134552001953125, 48.242294720241, 56.88593367167881, 57.6845109803336, 61.8544202532087, 57.51153905051095, 62.44387068067278, 55.957953112465994, 58.43731703077044, 54.24808134351458, 57.00554691042219, 56.093046937670024, 65.56470966339111, 61.151679447719026, 68.38786697387695, 63.84357139042446, 69.40901592799595, 68.85915633610317, 70.13671466282436, 68.82566601889474, 75.0727983202253, 71.8811502456665, 76.97495801108224, 74.86733313969204, 89.87584509168352, 7.341074057987758, 0.11781111758734499, 1.2173378552709306, 10.286179201943533, 89.39967809404645, 60.61229773930141, 71.11384677886963, 36.29438434328352, 43.7563396862575, 54.39113433020455, 53.69179466792515, 8.601505075182233, 0.08593743720224925, 0.2214653483991112, 0.1784339060208627, 0.09079367840396506, 0.11321404283600194, 0.1031105342720236], [0.1508831586688757, 0.06641565223357507, 0.10664374753832817, 0.034346390914704115, 0.03802066143336041, 0.016080633637362292, 0.020512642871056284, 0.2994421991918768, 2.1482425204345157, 44.32450430733817, 39.73524693080357, 32.563642910548616, 24.131620032446726, 47.190903731754844, 53.06302091053554, 58.45959990365164, 2.831484943628311, 0.10468633685793195, 0.22756072346653256, 0.7306682754840169, 40.371361460004536, 69.4636982509068, 62.772089685712544, 64.15616389683315, 58.92597688947405, 59.290562765938894, 59.42421136583601, 61.9842403956822, 58.85354886736189, 60.81727654593331, 60.40119756971087, 61.20267922537667, 60.41489246913365, 57.64686564036778, 58.3076844896589, 57.68598747253418, 46.749317918504985, 49.05440017155239, 54.76021916525704, 48.93441867828369, 44.50868715558733, 40.79262031827654, 41.71883603504726, 39.971259866442, 39.34106172834124, 40.827604498182026, 41.07542242322649, 43.00400958742414, 40.541463783809114, 39.95826326097761, 39.34688779285976, 40.9047885622297, 40.962851183755056, 39.74445676803589, 39.65939344678606, 38.22365937914167, 39.28846386500767, 37.691983222961426, 37.67476558685303, 37.18358700616019, 36.81356763839722, 37.911077295030864, 38.41219179970877, 41.298098291669575, 40.16823434829712, 43.337113176073345, 42.14400325502668, 44.33703538349697, 45.1929874420166, 44.74524205071585, 46.768835408346995, 46.45733724321638, 47.09703009469168, 47.98275865827288, 47.854324681418284, 47.27298280170986, 46.918384960719514, 48.153111117226736, 49.5143118585859, 49.94685806546892, 48.02091121673584, 49.814665113176616, 50.35782316752842, 44.370946066720144, 35.84427309036255, 43.039563519614084, 36.760973249162944, 42.56151703425816, 40.00813743046352, 38.43028143474034, 40.02477836608887, 38.51445886066982, 35.23619106837681, 38.689345019204275, 35.93244225638253, 47.39687613078526, 49.55732468196324, 49.22883817127773, 48.17844077519008, 47.54048844746181, 46.119435923440115, 49.21461173466274, 46.480888162340435, 47.31219148635864, 45.39912659781319, 45.00889144624983, 45.92954165594918, 45.4945844241551, 45.241395541599815, 43.98609924316406, 44.23442786080496, 42.21899168831961, 42.54873929704939, 38.47372852052961, 34.82069574083601, 37.848717212677, 37.29213523864746, 36.57499776567732, 34.29484217507498, 35.375943660736084, 35.91271979468209, 36.27682971954346, 35.42123549325125, 38.66581494467599, 37.60965401785714, 41.57983384813581, 40.270181792122976, 39.95818683079311, 40.82914005007063, 44.24762943812779, 46.529803480420796, 49.10068212236677, 52.40156282697405, 51.033045632498606, 48.46440431049892, 57.03923872538975, 55.035753454480854, 55.37968928473336, 53.818943228040425, 54.37960032054356, 55.23860263824463, 53.25171661376953, 49.978031158447266, 52.204484122140066, 51.5715970311846, 54.55625479561942, 54.65008674349104, 59.63715280805315, 61.28910786764962, 62.091305187770296, 61.35139846801758, 63.1564153943743, 63.812464305332725, 68.35821206229073, 65.91443334306989, 73.95285293034145, 67.45409856523786, 50.3659143447876, 0.3064001686871052, 0.10919269147728171, 0.3941061667033604, 9.873659440449305, 72.26474639347622, 50.752755301339285, 57.84650823048183, 26.124905347824097, 24.415030104773386, 30.32811212539673, 22.561349732535227, 7.170983025005885, 0.1612575112708977, 0.02810493404311793, 0.0821064691990614, 0.06191033577280385, 0.06304612875516925, 0.030813520308583975, 0.14359384695334093, 0.03418441442772746, 0.08589665724762849, 0.01556934223377279, 0.06503545093749251, 0.05616620775046093, 0.0898663110232779, 0.3061914513153689, 4.157078555652073, 56.411882400512695, 46.9422277041844, 35.0828651700701, 30.062218461717876, 54.813741139003206, 59.758586474827354, 65.52146407536098, 3.6465114610535756, 0.07897585790072169, 0.09861777749444757, 1.0588451027870178, 43.510658332279746, 71.51017897469657, 66.32656574249268, 66.31868648529053, 62.440632820129395, 62.45978900364467, 61.38160923549107, 63.50043460300991, 63.44415419442313, 61.29268618992397, 60.97461155482701, 61.685836110796245, 63.39894226619175, 60.83933012826102, 60.38021400996617, 60.35739612579346, 49.969436236790244, 52.18822186333792, 56.185461453029085, 50.08927876608712, 47.44914048058646, 44.435790130070274, 43.57449490683419, 41.141517162323, 42.76703780038016, 43.25524950027466, 43.126353468213765, 43.45814037322998, 43.07481173106602, 42.31746850694929, 42.099284648895264, 42.91043472290039, 43.13026877811977, 42.38292053767613, 41.38067415782383, 40.95666381290981, 40.54530266353062, 40.69566168103899, 39.84612280981881, 41.06079299109322, 39.72502613067627, 39.18996967588152, 40.56790862764631, 42.58808694566999, 41.83572905404227, 45.822383063180105, 45.13433769771031, 44.94119167327881, 48.74157837459019, 47.13608591897147, 49.0756790297372, 48.675851890019004, 50.04155853816441, 49.53142874581473, 52.28650413240705, 49.695527826036724, 49.64952727726528, 50.55420010430472, 49.64691475459507, 52.417929308755056, 51.448666027614046, 52.52740512575422, 53.31922183718, 45.1631622995649, 35.110380036490305, 44.557011876787456, 37.022510392325266, 42.910379137311665, 41.94979763031006, 40.01684004919869, 40.46110439300537, 40.34001466206142, 36.236686502184185, 39.01398222787039, 36.22206401824951, 47.71306780406407, 52.48680680138724, 51.629576274326865, 49.877768652779714, 50.943955830165315, 48.57177134922573, 50.23551402773176, 47.79787751606533, 48.88017061778477, 48.659030301230295, 47.7179662840707, 48.67587620871407, 48.33512960161482, 49.263245650700156, 45.166980334690635, 45.55588143212454, 44.79875360216413, 43.67399311065674, 40.912264823913574, 37.97478532791138, 39.28061934879848, 39.44070931843349, 39.01806082044329, 36.301429816654746, 37.5518137386867, 36.8789849281311, 37.79066153935024, 37.70801619121006, 40.45934302466256, 40.91577366420201, 43.23520394733974, 42.09052644457136, 43.5695721081325, 42.12250205448696, 46.05245181492397, 49.069557666778564, 51.922804151262554, 56.37104088919503, 52.79805135726929, 52.835366657802034, 60.12549999782017, 55.716847147260395, 57.070300647190635, 56.333169732775005, 57.98361703327724, 57.314248425619944, 54.30070352554321, 53.55637080328805, 53.03237935474941, 54.37610190255301, 57.90026296888079, 58.62433474404471, 62.88691561562674, 64.78079305376325, 64.58566679273332, 62.226399012974326, 65.79488958631242, 65.88523701259068, 71.00348159245083, 66.97076102665493, 75.95973587036133, 76.37878867558071, 53.49610212871006, 0.34242427136216846, 0.08253020074750696, 0.44850111646311625, 11.0010906457901, 80.40924412863595, 56.690369674137656, 66.63289792197091, 30.23887641089303, 34.237606389181956, 44.70228133882795, 38.98901735033308, 9.809023823056902, 0.21394886315933295, 0.15328727609344892, 0.03532394613804562, 0.03463224075468523, 0.10088519725416388, 0.03654314464490328, 0.4047875292599201, 0.11102648664798055, 0.1394196352256196, 0.06452925702823059, 0.20453629323414393, 0.09800250229558774, 0.3128267638385296, 0.5343133232423237, 6.315979395593915, 68.89721856798444, 53.668087414332796, 42.9558550970895, 31.81164632524763, 65.83263220105852, 63.22671726771763, 71.57850755964006, 4.050582647323608, 0.262875675622906, 0.3533333774123873, 1.8710773587226868, 45.221475056239534, 73.27278409685407, 69.20279339381626, 69.1051573072161, 65.42428656986782, 64.20342554364885, 64.72884137289864, 67.04970645904541, 64.38575322287423, 63.20824200766427, 62.22032628740583, 63.41553456442696, 65.88109588623047, 63.43662234715053, 63.46010031018938, 63.09538241795131, 53.18829345703125, 56.243635245731895, 59.345898219517295, 55.34709528514317, 49.57577909742083, 47.84229040145874, 46.67690379279, 46.121503012520925, 43.91752747126988, 46.31948498317173, 44.852459703172954, 47.45044674192156, 46.09589890071324, 44.574239935193745, 44.46948194503784, 43.478210244859966, 45.151558807918, 42.30941901888166, 43.317484515053884, 41.069961139133994, 43.90572943006243, 43.800089018685476, 43.214084897722515, 44.13323777062552, 42.249574184417725, 42.07640423093523, 43.45148399897984, 45.308480398995535, 43.93421357018607, 48.78717940194266, 46.55089126314436, 48.382523264203755, 52.3893062046596, 48.10625941412789, 52.066732610974995, 52.31238269805908, 52.562034947531565, 53.289004121507915, 55.23392302649361, 53.007317202431814, 52.833292620522634, 53.44585970469883, 52.96556200299944, 55.79073429107666, 54.21531711305891, 56.92811965942383, 54.61924368994576, 45.98814623696463, 37.49279226575579, 45.280885628291536, 38.28728403363909, 44.023282527923584, 42.539303643362864, 40.103060245513916, 41.939691475459504, 40.6307099206107, 36.226309367588584, 41.73189170019967, 37.1737448828561, 50.12348127365112, 54.9430262701852, 54.483965737479075, 52.49795518602644, 52.20750311442784, 52.84133516039167, 53.779640742710654, 50.7561251776559, 51.681489740099224, 53.00945724759783, 52.45611660821097, 51.79828895841326, 52.37264442443848, 52.1611898967198, 48.45338099343436, 49.77135699135916, 46.49022306714739, 46.186228956495015, 43.04306541170393, 39.726214272635325, 40.64546094621931, 41.28022057669503, 43.240387303488596, 41.623465061187744, 39.878817558288574, 38.77662134170532, 39.91089391708374, 39.070297377450125, 42.41608428955078, 41.699363708496094, 45.82694108145577, 43.084299496241975, 45.526737213134766, 44.32753719602312, 49.4525145803179, 51.538725103650776, 54.52072865622384, 57.3183548109872, 53.918354579380576, 53.93372399466378, 63.52499648502895, 60.65479292188372, 59.961967195783345, 59.60097353799002, 58.8939665385655, 61.038924080984934, 58.61608028411865, 57.34494209289551, 57.49560335704258, 58.04304150172642, 60.081246920994346, 61.46523775373186, 66.28594657352993, 66.89340673174176, 67.82267270769391, 65.31610311780656, 67.3878961290632, 69.60382257189069, 74.15345437186105, 70.54028688158307, 78.40923990522111, 75.26103891645158, 62.073760986328125, 0.8741144325051988, 0.21058066960956368, 1.111848567213331, 11.17539576121739, 90.35144233703613, 62.154763085501536, 77.45383480616978, 37.08891780035836, 39.58474200112479, 59.88150010790144, 54.6166033744812, 13.552367550986153, 0.33519217371940613, 0.24338304730398314, 0.17740371344344957, 0.1299070899507829, 0.27021343473877224, 0.11307625951511519], [0.0903978617861867, 0.060669688774006705, 0.07840345254434006, 0.056655051519296, 0.023332569947732345, 0.08869427748556648, 0.03366082966593759, 0.1334531953824418, 2.4486622171742574, 46.41428620474679, 44.25128419058663, 38.35386862073626, 38.18922063282558, 42.92248984745571, 49.881378241947715, 65.96490505763462, 5.861426506723676, 0.1201077550649643, 0.13863302314920084, 1.098396203347615, 32.37879998343331, 60.71640954698835, 63.491839681352886, 62.140303884233745, 61.255867685590474, 61.28899669647217, 58.18645232064383, 59.93653678894043, 63.62293829236712, 59.91437898363386, 58.36850207192557, 59.74417591094971, 58.50557613372803, 56.12914282935006, 54.716945784432546, 50.22991377966744, 49.74344607761928, 47.68655347824097, 48.49251324789864, 46.53030375071934, 42.23110587256295, 40.99082810538155, 40.69971595491682, 39.81191335405622, 40.438460213797434, 41.05472721372332, 39.94187593460083, 42.47774607794625, 39.03360741479056, 41.30729423250471, 40.63812712260655, 40.712893213544575, 39.6913343157087, 40.207272802080425, 42.77978079659598, 40.34579903738839, 38.226765223911826, 37.86600085667202, 38.26211071014404, 36.8478604725429, 36.871835231781006, 37.74998678479876, 37.48393678665161, 39.54737458910261, 40.6092643056597, 40.72158193588257, 43.47256483350481, 43.90554182870047, 44.81746162687029, 46.40423216138567, 46.409596170697895, 45.32251576014927, 44.29884113584246, 46.15264136450631, 48.24570975984846, 49.42923811503819, 49.50775275911604, 46.154937744140625, 47.868241923195974, 46.95061417988369, 50.258130414145334, 48.777385916028706, 51.33127621241978, 45.721547331128804, 36.54746205466134, 39.43969488143921, 40.10096536363874, 48.610177516937256, 40.73383508409773, 37.51837205886841, 39.00848967688424, 43.44366380146572, 37.27797480991909, 32.76352868761335, 37.926325116838726, 48.36927999768938, 49.16771139417376, 49.2859662600926, 46.79044083186558, 49.21551847457886, 46.59096499851772, 47.66562550408499, 46.427456515175955, 44.55391992841448, 46.001955781664165, 45.63211359296526, 45.164298330034526, 45.59798404148647, 46.26442398343767, 43.48185804912022, 44.36409166881016, 42.82329389027187, 42.11355972290039, 36.58578484398978, 37.93004935128348, 36.524755341666086, 36.28022391455514, 34.97197192055838, 34.71028886522566, 35.54041794368199, 36.318810735430034, 36.42434344972883, 37.68860987254551, 37.567179679870605, 38.82337924412319, 41.44806126185826, 39.790099484579905, 40.26829188210623, 39.10996464320591, 39.39406606129238, 44.34414686475481, 45.823196002415244, 47.66511481148856, 49.419357776641846, 52.46167516708374, 53.153225898742676, 51.345078808920725, 51.41833019256592, 52.78360605239868, 52.14966630935669, 53.48633296149117, 51.7708956854684, 51.38451678412301, 51.18134798322405, 52.41858243942261, 51.62126275471279, 54.579124791281565, 54.851754733494346, 60.48343644823347, 57.92570032392229, 61.04073756081717, 60.87256336212158, 64.35074819837297, 62.60311644417899, 67.28614670889718, 65.45729746137346, 65.76828493390764, 25.471567971365793, 0.6011372432112694, 0.7457728449787412, 0.4928813236100333, 9.747367245810372, 68.44442531040737, 52.20519978659493, 51.56221348898751, 29.60681962966919, 25.87546501840864, 30.980009487697057, 29.604432923453196, 4.096617068563189, 0.14913456035511835, 0.04031728534027934, 0.019169146926807504, 0.011909907883299249, 0.06050253167216267, 0.017788122907014828, 0.012847767111712267, 0.0418128579455827, 0.055792904924601316, 0.010919289164511221, 0.10531223791518382, 0.01885997923091054, 0.09300228953361511, 0.20025325806013175, 5.372195158685956, 60.46832411629813, 52.424745491572786, 40.29200608389718, 44.31776455470494, 50.84918587548392, 50.95260633741106, 73.4698350088937, 6.833989313670567, 0.18325961993208953, 0.13366031141153403, 1.3450838518994195, 35.21661104474749, 64.39688423701695, 64.85140759604317, 66.53841631753104, 62.40721893310547, 62.327953883579795, 60.79466015951974, 62.925172397068565, 67.05798176356724, 61.09168175288609, 60.26615933009556, 60.72886071886335, 59.582831791469026, 57.73903349467686, 56.762144565582275, 53.50221306937081, 51.9408277784075, 49.7961551121303, 50.03613894326346, 47.0634320804051, 46.01758228029524, 43.544402258736746, 43.89647095543997, 43.01709304537092, 43.066300187792095, 43.89954553331648, 42.93848807471139, 43.75696849822998, 41.961731161390034, 42.7435633114406, 43.777073110852925, 42.1841846874782, 41.87754678726196, 42.46030957358224, 45.55635390962873, 43.445230620247976, 41.3767796925136, 40.619415623801096, 41.349806785583496, 40.732417651585166, 39.30695302145821, 39.97847209657942, 40.60862159729004, 42.312413692474365, 40.85038764136178, 43.059303351810996, 44.93528570447649, 45.383910042899, 47.651419912065776, 47.43501826695034, 48.781603472573416, 47.19652829851423, 47.63855879647391, 48.83847795213972, 49.78191825321743, 52.55250549316406, 50.17343187332153, 50.33270195552281, 50.39420740944998, 49.65169164112636, 51.63582270486014, 51.78645270211356, 53.152951444898335, 45.65204102652413, 38.0884439604623, 39.423255443573, 39.78884880883353, 49.4631279536656, 41.60481262207031, 37.44607605252947, 38.38338804244995, 45.52942616598946, 38.422450814928325, 34.11941058295113, 38.51524748120989, 49.997222082955496, 51.37296540396554, 51.037933690207346, 49.779403005327495, 50.3058054787772, 50.50176204953875, 49.498452595302034, 49.69198077065604, 48.57608618055071, 50.11106136866978, 49.76543017796108, 48.949617862701416, 47.5330399785723, 47.31518963405064, 46.79132325308663, 46.28993429456438, 44.27700294767107, 44.47294562203543, 38.25204971858433, 39.92335203715733, 38.55206945964268, 38.64155183519636, 36.477785519191194, 35.176648480551584, 38.62365674972534, 38.12293134416853, 38.173427377428325, 40.06551912852696, 40.69169773374285, 40.36859607696533, 44.1042012487139, 41.004158224378315, 42.71385628836495, 41.711860043661936, 42.68979467664446, 47.201711654663086, 47.36298976625715, 50.054391860961914, 51.556696619306294, 54.66669988632202, 54.292139870779856, 54.396439279828755, 55.63972561700003, 53.92372553689139, 54.08772734233311, 54.22907107216971, 54.704220158713206, 54.72203533990042, 54.990228857312886, 54.49455826623099, 54.80482660021101, 58.13451453617641, 57.10969345910208, 62.39351708548409, 59.12402139391218, 62.987275396074565, 62.21597671508789, 65.29685660770961, 66.68752465929303, 69.59204537527901, 68.5859740121024, 77.33021940503801, 24.94931878362383, 0.7186666737709726, 1.0100829707724708, 0.7774812749453953, 10.453583887645177, 77.66179438999721, 57.98890808650425, 61.04715769631522, 33.96260016305106, 32.23872777393886, 46.378492559705464, 47.8263373374939, 8.007942182677132, 0.22988809858049664, 0.06453726374145065, 0.07441046394939933, 0.03829021625486868, 0.0368282413110137, 0.03832094371318817, 0.15354640861707075, 0.1370349781853812, 0.334209356456995, 0.12062112108937331, 0.18143327507589543, 0.12047615886798926, 0.28159401406134876, 0.33393340983561104, 7.46423522063664, 76.16326945168632, 55.4652806690761, 53.61759485517229, 48.12485974175589, 58.72323540278843, 58.463650703430176, 80.17927959987095, 7.756266270365034, 0.33306835911103655, 0.2372780777513981, 1.7780140553201949, 38.13315561839512, 63.69443525586809, 67.56202493395124, 67.75365625108991, 64.9102588381086, 65.67955643790108, 62.63621766226632, 64.52472414289201, 71.07898071834019, 63.88232149396624, 60.9872225352696, 62.89116096496582, 61.73480006626674, 58.99981539590018, 58.61107758113316, 57.56159387316023, 54.59668983731951, 52.37819603511265, 53.51451138087681, 50.7618088041033, 48.86701767785208, 44.699189390454976, 46.5850625038147, 46.61224038260323, 45.55481488364083, 46.58668490818569, 46.606859002794536, 48.574331760406494, 44.72389023644583, 47.455261843545095, 47.51342173985073, 45.425119808741975, 43.359375204358784, 44.29399129322597, 49.08023009981428, 44.765294551849365, 43.00371776308332, 43.17002289635794, 43.58722748075213, 42.13398742675781, 41.705127239227295, 42.711132594517295, 42.79285383224487, 44.32469538279942, 45.249399866376606, 45.977181979588096, 47.790474210466655, 47.31335530962263, 49.80895021983555, 51.73041895457676, 51.506950991494314, 50.62895924704415, 48.10229894093105, 52.2999141556876, 53.4711719921657, 56.48399427958897, 53.631446089063374, 52.32577187674386, 52.42231362206595, 50.10199049540928, 55.15851075308663, 53.18641744341169, 55.08276149204799, 47.519053254808696, 38.70711503710066, 41.810576575142996, 42.24600281034197, 51.366413252694265, 42.130103383745464, 39.012036732264924, 38.73392813546317, 45.889388016292024, 39.114880493709016, 36.201024872916086, 40.39956767218453, 51.51760605403355, 53.63799476623535, 53.54770292554583, 51.46308701378958, 53.3856257711138, 51.722678661346436, 52.45795440673828, 52.23507009233747, 49.46524020603725, 52.341738837105886, 52.53234876905169, 51.70263310841152, 50.62142045157296, 51.52445002964565, 49.92848008019583, 48.21288994380406, 45.52399614879063, 47.27597747530256, 41.83783088411604, 41.31317935671125, 41.16850743974958, 41.36313690458025, 39.516472475869314, 38.32228558404105, 41.53728655406407, 40.18442365101406, 40.04290969031197, 42.99755123683384, 42.116220882960725, 42.535530771527974, 46.861531325748985, 43.455024106161936, 45.3214943749564, 44.187617846897666, 44.855951172964915, 49.829200744628906, 50.55054535184588, 52.75573335375105, 52.81345551354544, 57.86819008418492, 58.33070387159075, 55.539723668779644, 57.82119246891567, 58.62037427084786, 57.559439931597026, 59.38220950535366, 58.35284778050014, 57.870507308415, 57.12556314468384, 58.375033378601074, 57.285760811397004, 61.50911562783377, 61.356762477329795, 67.8342136655535, 61.639470781598774, 65.92367444719586, 67.56715965270996, 69.55182225363595, 70.77232892172677, 73.59244292122978, 69.5907460621425, 74.57796151297433, 30.97256449290684, 0.8311630029763494, 1.6352993590491158, 0.9784253495080131, 11.538483432361058, 86.84137916564941, 63.57816410064697, 73.0854606628418, 42.95190157209124, 45.1999043737139, 55.26950822557722, 65.21126869746617, 13.472626549857003, 0.30589327588677406, 0.23765493610075542, 0.19752497731574944, 0.1394196352256196, 0.17108371614345483, 0.1543077113372939], [0.047488677847598276, 0.13513803854584694, 0.03625539829954505, 0.01010541185470564, 0.06645352805831603, 0.038915537164679596, 0.15114739377583775, 0.14422257750162057, 3.519921579531261, 44.6067852973938, 41.31013257162911, 42.56386552538191, 29.128172125135148, 46.49028560093471, 49.32591840199062, 67.5198563167027, 9.897984215191432, 0.12529221044055053, 0.14815764634736947, 0.4383482512618814, 25.612956864493235, 47.54977124077933, 65.55952630724225, 62.63363988058907, 64.35839121682304, 63.9377681187221, 65.48092828478131, 62.64319365365164, 59.82739448547363, 58.97811617170061, 58.512399264744346, 55.0230382510594, 55.02780818939209, 53.57142407553536, 49.192492144448416, 49.22039263589041, 48.83724117279053, 45.43733821596418, 44.874294417245046, 41.61844151360648, 42.13083641869681, 41.24596248354231, 40.99943344933646, 38.91153451374599, 40.242104121616904, 40.638474532536094, 41.26069613865444, 39.134234700884136, 39.442633969443186, 40.62610673904419, 39.366443497794016, 39.407886028289795, 40.11482007162911, 39.66064064843314, 40.01135097231184, 39.60922050476074, 41.16187538419451, 38.59523514338902, 37.860511779785156, 36.875399657658164, 37.11188159670149, 36.81192438943045, 38.789298330034526, 38.685186522347585, 37.83271203722273, 39.04984882899693, 38.817216191973, 42.604870319366455, 44.49504089355469, 44.06035464150565, 42.38849994114467, 45.12753888538906, 44.73553541728428, 45.240745885031565, 46.00359903063093, 45.71056917735508, 47.13141325541905, 48.472099440438406, 48.71707902635847, 49.009952545166016, 49.66971179417202, 47.06742034639631, 50.65137413569859, 46.627165113176616, 35.03757333755493, 37.01516267231533, 41.60887731824602, 48.67189836502075, 41.52900430134365, 37.103456905909944, 42.961417130061555, 45.267329692840576, 38.50661434446062, 38.664279392787385, 38.23218134471348, 49.42013944898333, 48.975847312382285, 50.35833386012486, 47.79017196382795, 48.22932938167027, 47.07672051021031, 47.536107608250205, 48.219542843954905, 45.07546213694981, 45.315435545785085, 43.476434980119976, 44.13330725261143, 43.146128041403635, 45.245599201747346, 45.61133847917829, 43.03514446531023, 41.34681906018938, 37.37493692125593, 37.53397076470511, 36.66013404301235, 36.91405596051897, 36.040879317692344, 34.687724590301514, 35.66820226396833, 35.912587778908865, 38.45772334507534, 37.349009718213765, 39.122881344386506, 39.37787675857544, 39.31145545414516, 37.69016974312918, 39.06208460671561, 38.964170592171804, 40.52350269045149, 38.715379919324604, 41.36422777175903, 42.105176721300396, 44.14749200003487, 45.862470694950645, 49.30999313082014, 46.59135757173811, 47.048583780016216, 47.02099943161011, 48.5082300731114, 48.93600286756243, 48.314767905644004, 50.990581716809956, 49.76517309461321, 50.46968569074358, 52.67101396833147, 51.52145535605294, 54.40380089623587, 53.58610561915806, 55.00622361046927, 56.40637247903006, 56.91226039613996, 56.69651882989066, 60.63039084843227, 60.50922121320452, 64.52674606868199, 65.66017096383231, 58.23687539781843, 5.68039379801069, 0.4629870248692376, 1.568006924220494, 0.4813714155129024, 12.119137440408979, 72.47285188947404, 50.26482847758702, 51.5344797543117, 31.92245967047555, 37.44799028124128, 34.53937707628523, 45.95567383084978, 9.393660511289324, 0.2725942241294043, 0.09604290673243147, 0.031214185059070587, 0.07615792910967555, 0.00475719035603106, 0.07152351457625628, 0.031087777377771478, 0.07566964173955576, 0.03306746097015483, 0.03970385914934533, 0.0568788086197206, 0.04081497720575758, 0.13946266791650228, 0.14239486200468882, 5.856168023177555, 59.96289130619594, 45.46324110031128, 44.93217291150774, 30.904541628701345, 53.49821090698242, 53.12158032826015, 76.50338377271379, 10.390428236552648, 0.27793396902935846, 0.16833771206438541, 0.5629825677190508, 26.342139039720806, 54.3616600717817, 67.11594363621303, 65.23677553449357, 66.14236899784633, 67.07668631417411, 68.7632781437465, 64.04571533203125, 60.77924905504499, 62.48965930938721, 60.66805008479527, 58.21395329066685, 56.72675044195992, 56.01604005268642, 52.23170369012015, 52.13493612834385, 49.60586827141898, 49.33389145987374, 48.45286682673863, 45.19858769008091, 44.387076309749055, 42.14685896464756, 43.20046295438494, 41.50576605115618, 42.81279168810163, 43.86506509780884, 45.49803073065621, 41.72120884486607, 42.10461739131382, 42.55325910023281, 40.212435313633506, 41.35576833997454, 42.57642439433506, 41.71232557296753, 42.59619549342564, 40.859545367104666, 42.87267473765782, 41.11809131077358, 39.97139188221523, 39.844938141959055, 39.03765821456909, 39.15766750063215, 40.908995696476524, 41.15159552437918, 41.29441574641636, 40.66207756314959, 41.36259494509016, 45.59029933384487, 46.28110660825457, 45.72479213987078, 44.78343282427107, 47.970508984157014, 46.68919515609741, 47.86887073516846, 50.662477357046946, 47.5884553364345, 49.14659234455654, 51.23385899407523, 52.162325927189414, 49.72213247844151, 50.96429320744106, 50.91810853140694, 53.63773768288748, 47.95774861744472, 37.2130161012922, 37.592286995479036, 42.648310456957134, 48.26796136583601, 40.85256242752075, 38.56938437053135, 42.8943635395595, 46.48837832042149, 39.03059537070138, 39.15466935294015, 40.070455823625835, 51.93791995729719, 51.33843285696847, 50.40029055731637, 49.42307506288801, 49.36493253707886, 50.531069551195415, 50.23752553122384, 50.65358713694981, 48.60363926206316, 47.91171332768032, 46.48950045449393, 47.17576708112444, 46.15187358856201, 47.912321295057026, 47.520741667066304, 45.12373127256121, 44.49702113015311, 39.804169586726594, 39.32718270165579, 39.506887435913086, 38.400223527635845, 38.25112908227103, 36.14600208827427, 37.3523656981332, 38.81203283582415, 40.43929747172764, 38.203902176448274, 40.25481585093907, 39.8157765524728, 40.96515451158796, 40.70930446897234, 41.82752323150635, 41.0323748588562, 41.886912958962576, 41.171356201171875, 42.407666546957834, 43.26457050868443, 47.38558183397566, 48.22585875647408, 51.40669195992606, 48.85510846546718, 47.358490807669504, 48.57437344959804, 49.76121956961495, 51.27042041506086, 51.30555745533535, 51.94015727724348, 51.65756709235055, 53.89987237112862, 55.314164297921316, 53.31087705067226, 56.99260589054653, 56.84823274612427, 57.7768177986145, 59.37739440373012, 59.32576928819929, 58.99271433694022, 62.85827514103481, 63.31749548230852, 66.69737025669643, 72.27146530151367, 68.35016604832241, 4.649045322622571, 0.6200236954859325, 1.9075632180486406, 0.3977822794445923, 13.166567955698286, 81.17112105233329, 54.572537899017334, 61.95662130628313, 35.2954557282584, 33.86463403701782, 47.33945274353027, 60.18043940407889, 15.503783021654401, 0.2686963661440781, 0.01732920083616461, 0.016635361460170577, 0.034394974022039344, 0.0628426836005279, 0.08208668990326778, 0.12565259395965508, 0.26669067091175486, 0.20139398399208272, 0.16310807982725756, 0.13980215255703243, 0.06065220292657614, 0.2993153402847903, 0.38021584919520784, 7.7279045922415595, 75.91731711796352, 53.628892626081196, 55.26727090563093, 36.64792605808803, 64.02827535356793, 58.598056656973704, 82.61297648293632, 11.290021930422101, 0.5716824180313519, 0.23567605657236917, 0.7963466654930795, 30.51110335758754, 54.07747874941145, 67.77477877480644, 70.89246327536446, 68.72069958278111, 70.55312020438058, 71.62515081678117, 67.38682610648019, 64.63392898014614, 64.33829007829938, 63.596979822431294, 61.312669209071565, 58.662216322762625, 59.75450093405587, 55.58513362067086, 56.04646274021694, 52.347749028887065, 51.694062505449565, 50.84521150588989, 47.70306934629168, 48.1260860988072, 46.538255964006694, 46.32679796218872, 43.924315861293245, 45.45234979901995, 46.67520843233381, 47.319789341517854, 45.13770409992763, 44.16839565549578, 46.43015936442784, 43.75578383037022, 43.441937174115864, 45.616004194532124, 44.03642504555838, 43.50782694135393, 42.93227291107178, 46.67617770603725, 44.48831156321934, 41.54475586754935, 43.067331995282856, 40.981482778276714, 41.98272514343262, 43.46200009754726, 44.0291085924421, 41.22716760635376, 43.096896580287385, 43.302657059260774, 48.51898241043091, 49.137507574898855, 48.53903143746512, 46.86218098231724, 51.33936391557966, 48.10068001065935, 50.17169829777309, 52.22946637017386, 50.5425375529698, 51.3221150125776, 54.7660174369812, 54.23150641577584, 52.23311070033482, 55.233839648110525, 52.828467096601216, 57.326518944331575, 50.20303814751761, 36.33288083757673, 38.61349848338536, 42.220291001456125, 51.834763526916504, 42.77296461377825, 38.94835301807949, 43.603458472660606, 47.543441431862966, 40.40040840421404, 40.6514572416033, 40.27787692206246, 53.582360540117534, 55.4900336265564, 54.18183026994978, 51.21331664494106, 51.70043747765677, 52.96749012810843, 54.850736822400776, 53.47696678979056, 49.29975496019636, 50.69141660417829, 49.23555360521589, 49.66220426559448, 48.59465176718575, 50.54388550349644, 50.41180372238159, 47.04006181444441, 47.12220341818673, 41.09210157394409, 43.09421457563128, 41.391815594264436, 40.451706954411094, 41.64915949957711, 39.21596983500889, 38.918190887996126, 40.77386365618025, 43.25166422980172, 40.038598333086284, 41.68982730593, 43.54051126752581, 43.76961769376482, 42.16168989453997, 44.0792224747794, 43.417906829289024, 43.9869191305978, 43.93538434164864, 45.337687151772634, 46.584030696323936, 48.62762791769845, 51.231371538979666, 54.8089850970677, 52.38102395193917, 52.05270072392055, 50.86468383244106, 53.17427199227469, 54.106779302869526, 52.80691725867135, 55.7543500491551, 53.66406093324934, 54.98804364885603, 58.610903876168386, 56.13571235111782, 60.610199383326936, 59.84207602909633, 61.34891101292202, 63.25175857543945, 64.35452801840646, 62.5930415562221, 66.27054241725376, 66.78589725494385, 70.49110058375767, 72.52386556352887, 66.17442103794643, 7.0808822597776135, 0.7771211085574967, 4.624549882752555, 0.5881645221795354, 15.185089996882848, 89.91433811187744, 60.92969839913504, 71.08645698002407, 45.504346643175396, 58.70988096509661, 57.589633328574045, 69.82766573769706, 19.355734041758947, 0.42629008686968256, 0.2772325266684805, 0.09710058676345007, 0.08632576957877193, 0.12046859998788152, 0.14290748164057732], [0.06515567377209663, 0.06619497907481023, 0.029573945395116295, 0.040955691797924895, 0.05596270492034299, 0.03688021370076707, 0.15076149734003202, 0.16453370904283865, 3.2594574987888336, 43.46218422480992, 37.93286337171282, 38.052705901009695, 44.36605453491211, 45.1056798526219, 50.078592436654226, 68.50105312892369, 11.698304159300667, 0.43293826441679684, 0.6011561336261886, 0.39253177547029083, 14.9204226902553, 48.314941610608784, 51.71376412255423, 61.33210332053048, 59.44044235774449, 56.41268491744995, 52.85064227240426, 55.603438649858745, 61.03062098366873, 58.25526033129011, 56.59471035003662, 53.62794419697353, 51.99694837842669, 48.81862347466605, 47.87745523452759, 44.46847445624215, 45.80004807880947, 42.9702274458749, 44.67018413543701, 41.578214917864116, 40.70492710386004, 40.409159660339355, 39.2699990272522, 40.93118824277605, 42.82323135648455, 41.73183264051165, 40.22051954269409, 38.53974335534232, 39.35115051269531, 39.520005634852815, 38.76581341879708, 40.489560740334646, 41.05311175755092, 45.95863723754883, 44.356771741594585, 42.371257986341206, 40.52207136154175, 37.95253719602312, 39.69977290289742, 37.38084289005825, 38.209957531520296, 38.044798851013184, 37.931300027029856, 38.53489351272583, 38.19936152866909, 38.62125267301287, 38.14861536026001, 39.25248956680298, 44.35386044638497, 42.83569989885603, 43.14870582308088, 43.73117331096104, 44.83150393622262, 47.40861163820539, 46.26428154536656, 46.473839214869905, 47.346529483795166, 46.296649728502544, 47.60206685747419, 45.244202613830566, 45.871812547956196, 48.378284863063264, 51.49647658211844, 49.32515410014561, 43.471703256879536, 41.96495859963553, 43.56737995147705, 48.44936840874808, 32.08158731460571, 21.750104120799474, 36.08215856552124, 45.574971607753206, 45.17810092653547, 39.24745907102312, 39.46422202246529, 51.807863576071604, 48.13102626800537, 48.90171698161534, 48.33722448348999, 50.619044167654856, 45.19223703656878, 45.96155548095703, 47.075494153159006, 45.665353775024414, 43.63970375061035, 45.82087182998657, 46.23198284421648, 45.622848170144216, 42.81962176731655, 42.39843239103045, 41.34273699351719, 39.21617828096662, 35.9871176310948, 37.62011800493513, 38.479964528764995, 38.212299074445454, 36.695298876081196, 35.80907351630074, 36.051232133592876, 36.888503960200715, 38.99731002535139, 37.73337016786848, 37.857114110674175, 38.67882892063686, 39.41305201394217, 37.77497598103115, 39.451027393341064, 38.4059488432748, 39.24570117677961, 40.81566054480416, 38.903818539210725, 40.48941830226353, 41.841266768319265, 42.60587433406285, 44.45124292373657, 42.27043962478638, 43.46311180932181, 43.18653529030936, 42.49449471064976, 45.57354722704206, 47.13151747839791, 47.13456426348005, 47.79072781971523, 47.93074444362095, 51.39203820909773, 53.18550028119768, 52.9761996950422, 52.55120618002755, 53.99693523134504, 52.613267489842, 53.10274723597935, 50.964220251355854, 56.52836547579084, 61.50199372427804, 63.36550753457205, 67.13067381722587, 45.06474454062325, 1.2131387548787254, 0.18505488788442953, 1.036940906729017, 0.33245748760444777, 17.72465831892831, 71.29363141741071, 52.34046384266445, 52.869986057281494, 38.548428603581016, 42.52189840589251, 33.73155518940517, 49.42456892558506, 14.690505061830793, 0.13231335154601506, 0.03181055287963577, 0.013149858535533505, 0.06443143263459206, 0.024098429030605724, 0.08467739767261914, 0.05681354712162699, 0.026835600280069878, 0.043748246771948676, 0.020114315673708916, 0.07025077965642725, 0.059126143742884905, 0.11467169890446322, 0.15798637537019594, 6.57000640460423, 59.24279390062605, 41.78024768829346, 37.49298334121704, 45.358028003147666, 53.55061422075544, 52.666608810424805, 76.06847517830985, 12.57936613900321, 0.30682384595274925, 0.42721997840063913, 0.3905690722167492, 17.104376997266495, 50.41900553022112, 55.52958624703543, 62.88712406158447, 60.57406875065395, 59.293383734566824, 55.01065656117031, 58.33664458138602, 62.05993407113211, 60.44465855189732, 58.778411047799246, 56.81349522726876, 55.384070123944966, 52.983290331704275, 48.29352726255144, 46.83849457332066, 47.712199279240195, 45.393408230372835, 46.46357672555106, 44.15818527766636, 42.2362197467259, 42.571897642953054, 41.37092930930001, 44.37143244062151, 45.11168309620449, 46.52130235944475, 44.37299231120518, 41.21999706540789, 42.44300855909075, 40.4214996610369, 40.40064811706543, 42.100219181605745, 44.87561110087803, 47.5897650718689, 48.02413518088204, 43.77975511550903, 41.36439452852522, 41.095012869153706, 41.26855802536011, 40.27242953436715, 40.73337302889143, 39.49941117422921, 40.34050451006208, 40.6804381779262, 39.67908116749355, 40.87693670817784, 40.711760657174246, 40.32100091661726, 45.789924553462434, 44.730143615177695, 43.074669292994905, 46.467922823769705, 47.01410681860787, 49.9534831728254, 46.913719245365684, 49.32371582303728, 50.169540882110596, 47.77947521209717, 49.505400793892996, 48.20727232524327, 47.47158663613455, 50.0344157900129, 53.54260294778006, 50.2511613709586, 46.35276338032314, 44.68080793108259, 45.714901379176546, 51.650636264256065, 34.79927791867937, 23.4236124924251, 39.16582815987723, 46.61977570397513, 46.46640811647688, 42.76606852667672, 40.39319964817592, 52.33067383084978, 49.23926394326346, 50.129182270595, 52.105461869921, 51.52090992246355, 49.6146125793457, 49.228886808667866, 49.34725979396275, 47.84474311556135, 46.024130957467214, 47.367658955710276, 47.9334750856672, 47.82951613834926, 43.81918266841343, 45.18339892796108, 43.62284394672939, 39.514450550079346, 37.90682847159249, 40.09494127546038, 40.50154638290405, 38.29453100476946, 39.4500025340489, 38.989211899893625, 39.11216722215925, 40.14823048455374, 41.704988275255474, 40.09081057139805, 41.70267105102539, 40.97224167415074, 40.91169159752982, 40.769298689705984, 41.24101536614554, 40.71893119812012, 41.07590879712786, 40.7727449962071, 40.81992326463972, 42.616730894361226, 44.72766310828072, 44.24952629634312, 45.770136083875386, 45.053429399217876, 46.71936076028006, 45.24087790080479, 44.90775694165911, 47.11556441443307, 49.07845483507429, 49.86711359024048, 49.97247607367379, 53.28384508405413, 53.067686625889365, 55.09491389138358, 53.462712560381206, 54.803398745400564, 56.07649980272566, 53.69147505078997, 54.16944858006069, 53.606293610164094, 57.5631502696446, 64.22944654737199, 65.7952161516462, 72.27758666447231, 55.064171586717876, 0.9579270780086517, 0.5310460957033294, 1.4117835185357501, 0.28840428005371777, 20.00500324794224, 81.90767874036516, 57.84507690157209, 61.77824715205601, 40.73706947054182, 46.6979672568185, 42.39819962637765, 59.117893082754954, 22.183279139654978, 0.036373398931963105, 0.034762034325727394, 0.060433578943567615, 0.06878147992704596, 0.055648180190473795, 0.027605874929577112, 0.15129281740103448, 0.1738766205630132, 0.09425803393657718, 0.1369707752019167, 0.10984818344669682, 0.10449129875217165, 0.23813455179333687, 0.28178308105894495, 9.99509310722351, 75.73284244537354, 49.22018071583339, 51.62133918489729, 54.93569939477103, 63.04812771933419, 57.98994336809431, 86.6733786719186, 13.752702355384827, 0.8699691263692719, 0.7676571735313961, 0.5521382753338132, 20.734303542545863, 53.08138152531215, 55.972214290073936, 63.218678201947895, 61.193938391549246, 61.22908238002232, 55.37365130015782, 59.66975375584194, 63.902297564915244, 65.00469875335693, 63.16036197117397, 60.500091280256, 56.51688010351998, 54.072055680411204, 51.04183162961687, 50.24036734444754, 51.20719528198242, 48.42709943226406, 49.96546186719622, 47.533165046146934, 45.20681783131191, 45.242135524749756, 43.459988594055176, 45.94499792371477, 48.17445945739746, 47.32427787780762, 46.91872194835118, 43.41572162083217, 45.01749679020473, 43.95616292953491, 42.766471522195, 45.26444966452462, 46.07923017229353, 50.361297266823904, 49.33832441057478, 46.92117813655308, 44.30766882215227, 42.96077789579119, 44.37962089266096, 41.418517521449495, 44.70630781991141, 43.03688498905727, 43.134868485586985, 43.18208844321114, 42.12518058504377, 43.73908730915615, 41.76046616690499, 42.974993910108296, 48.740477085113525, 47.46342945098877, 47.061503955296104, 48.63115760258266, 48.583145550319124, 52.743073735918315, 50.35591241291591, 51.688017572675435, 54.24764708110264, 48.82175016403198, 52.64592054912022, 51.048915318080354, 49.49929680143084, 53.048752784729004, 56.69628953933716, 53.173076902117046, 48.322247641427175, 45.943920952933176, 47.61092233657837, 53.51102338518415, 35.777983801705496, 28.665243182863506, 41.181945255824495, 47.60419648034232, 47.1822566986084, 42.91823754991804, 42.654230322156636, 55.040169034685405, 51.30038104738508, 53.483345236097065, 52.891157218388145, 57.38771172932216, 49.99643693651472, 51.3045916557312, 52.7163405418396, 51.69708149773734, 47.55612884249006, 50.44074296951294, 51.42084196635655, 51.78045293263027, 46.52078471864973, 46.83136224746704, 45.586401394435335, 42.28929008756365, 41.0462886265346, 42.901082447596956, 43.10643298285348, 41.683115346091135, 41.703789710998535, 41.30463307244437, 42.136089256831575, 42.12271050044468, 43.991897514888215, 41.74403715133667, 42.45665829522269, 43.36460024969918, 43.21703788212368, 43.55509206226894, 42.53125415529524, 43.029922894069124, 43.36286667415074, 42.936806610652376, 42.54651934759957, 45.37796933310372, 46.20302970068795, 47.04983098166329, 49.08353396824428, 46.84366750717163, 50.34597301483154, 48.73289312635149, 48.04190519877842, 49.90533215659005, 51.676379340035574, 54.129680565425325, 53.443605014256065, 55.31935460226876, 56.747060026441304, 58.45030321393694, 58.70241165161133, 58.23184837613787, 59.90485995156424, 56.9222970690046, 58.34066064017159, 57.68654680252075, 62.95811380658831, 66.91306318555559, 69.16139602661133, 73.05644498552594, 50.42405687059675, 1.7059643843344279, 0.6289273777178356, 3.748545757361821, 0.34606219615255085, 22.53549027442932, 87.75363595145089, 65.24797603062221, 72.57113415854317, 53.514455795288086, 62.36949021475655, 54.633473600660054, 75.43368775503976, 29.448939187186106, 0.250083824885743, 0.1900501541261162, 0.16810052336326667, 0.12294662344668593, 0.1588706150650978, 0.14122803961592062], [0.053940399150763235, 0.03287974086457065, 0.07523566431232862, 0.08954311800854546, 0.03460434618006859, 0.04755646688863635, 0.10177534698907818, 0.15146413392254285, 3.7862193243844167, 40.095907075064524, 41.38862984521048, 35.5317257472447, 23.661426748548234, 46.787581648145405, 42.72953837258475, 70.61575126647949, 15.74805736541748, 0.21391714843256132, 1.1082260587385722, 0.12712567991444043, 6.026368490287235, 38.458313941955566, 50.91397087914603, 50.388565472194124, 56.69902712958199, 52.73841149466378, 55.82464497429984, 59.64367716653006, 59.85319314684187, 51.49503830501011, 54.69063295636858, 48.23595448902675, 44.280522210257395, 42.461612360818044, 43.61847700391497, 44.374239512852256, 40.7975674356733, 41.78496898923601, 41.72397770200457, 40.076441696711946, 41.235772950308665, 39.50714104516165, 43.29500709261213, 41.080640520368306, 44.29996674401419, 43.14749683652605, 40.10015937260219, 39.49091700145176, 41.418965680258616, 38.00249474389212, 40.52429478509085, 46.01547350202288, 52.87495749337332, 52.21823460715157, 53.34791789736067, 46.95155218669346, 43.837098598480225, 39.11194487980434, 39.097430092947825, 38.38633755275181, 39.66573020390102, 38.3858859198434, 35.15216997691563, 37.35495042800903, 38.701539107731406, 38.416249547685894, 40.35846560341971, 35.56529596873692, 42.038494859422954, 40.13253797803606, 41.198315211704795, 42.6853790964399, 40.096011298043386, 42.477485520499094, 43.80133274623326, 45.49652297156197, 45.47887454714094, 44.70637035369873, 45.86001798084804, 44.7105462210519, 43.888421467372346, 47.885435240609304, 48.83450705664498, 48.52277960096087, 46.70309502737862, 39.799427441188264, 47.03125844682966, 42.30391951969692, 18.72827696800232, 13.34627616405487, 25.568637779780797, 46.132616656167166, 45.670919282095774, 40.77476692199707, 46.254699979509624, 52.067521231515066, 49.26821708679199, 48.74807841437203, 46.76226588657924, 48.30860137939453, 45.49787439618792, 46.811292375837056, 46.15658099310738, 44.98194285801479, 45.125892162323, 45.46382474899292, 44.440448897225515, 42.337590490068706, 40.272478171757285, 42.49920906339373, 39.996624265398296, 38.480280671800884, 37.92931284223284, 38.60621329716274, 35.95291512353079, 37.91474594388689, 36.6873779296875, 36.70547103881836, 35.21655893325806, 36.565812247140066, 38.09571525028774, 36.905353341783794, 40.479200976235525, 39.64704997198922, 37.742979526519775, 38.48894507544381, 37.9171257019043, 38.12478998729161, 37.702794619968955, 39.111416816711426, 38.35428898675101, 38.42750562940325, 40.14222029277256, 41.14306313650948, 41.53998940331595, 42.09632471629551, 43.34512792314802, 41.89137717655727, 39.416178703308105, 41.3185190473284, 41.287474496024, 42.176951612745015, 43.560181617736816, 46.92206403187343, 48.281291484832764, 48.43133435930525, 51.8319217136928, 50.211292607443674, 49.6470502444676, 48.5000833102635, 48.692902769361226, 48.60259703227452, 53.75748641150338, 60.41620567866734, 64.33269677843366, 63.490192958286826, 43.17668969290597, 1.6622944133622306, 0.46623107365199495, 0.9257491018090929, 0.21846584363707475, 25.984053203037806, 70.88834299360002, 51.96931191853115, 49.21515716825213, 36.87037263597761, 23.674194063459122, 40.70719221660069, 56.06166539873396, 25.871409007481166, 0.08265916989850146, 0.0627509049539055, 0.04640257737732359, 0.0492981373598533, 0.026382023368829062, 0.006381602342506605, 0.03270523862114974, 0.06725762598216534, 0.09423417664532151, 0.021669438208586404, 0.031201635553900684, 0.02247565146535635, 0.09835192068879094, 0.16383187313164982, 5.269973695278168, 52.504573345184326, 47.347213881356375, 41.099313804081504, 28.94017471585955, 53.00209910529, 48.693337031773154, 78.60982050214494, 17.531237840652466, 0.3848998578531401, 1.442452324288232, 0.21502522325941495, 7.611345955303737, 39.23518507821219, 53.4644843510219, 51.943565368652344, 59.21089472089495, 54.343417576381135, 57.86230148587908, 61.7976256779262, 61.07010759626116, 54.56609691892351, 55.215583256312776, 49.747691426958355, 46.13540635790144, 46.160253116062705, 44.83671855926514, 47.38470983505249, 43.91298334939139, 44.69052498681204, 43.616878918239046, 42.797717571258545, 43.97522183826992, 43.192448207310264, 45.41036878313337, 45.4785201890128, 47.820511272975374, 45.14100449425833, 42.898681844983784, 41.36498165130615, 42.65846872329712, 39.683142389569966, 43.37251772199358, 48.542456899370464, 54.52888931546892, 53.92822102137974, 54.01933969770159, 49.954747744968955, 46.03153426306588, 41.38109104973929, 41.02821636199951, 39.35752895900181, 42.37701456887381, 41.16954272133963, 38.46779823303223, 38.75935854230608, 38.93202127729143, 40.612321513039724, 41.50252819061279, 38.06360762459891, 43.53571701049805, 43.7868527003697, 43.30042321341378, 43.9192784173148, 42.133080686841694, 45.086433342524934, 45.69929919924055, 47.72437947137015, 47.26515218189785, 46.225048542022705, 47.086639063698904, 47.05854402269636, 47.41756091799055, 49.479855741773335, 49.855885301317485, 49.73784930365426, 49.912891796657014, 42.295588629586355, 48.542588915143696, 47.17122643334525, 22.763382502964564, 16.34385323524475, 28.316057988575526, 46.39860759462629, 47.64067799704415, 41.512509277888704, 46.376227446964805, 53.53242383684431, 51.7564503805978, 53.328202383858816, 49.03184631892613, 49.72051007407052, 48.659784180777415, 49.77026265008109, 47.86594206946236, 48.84950474330357, 48.856439045497346, 45.73554447719029, 46.850303036826, 45.394137791224885, 43.7751658303397, 44.76830659593855, 41.16797937665667, 40.1769300188337, 40.74107163293021, 41.4899936403547, 40.128056389944895, 38.85151250021798, 38.705569062914165, 37.952401706150596, 37.47393832887922, 39.752454144614084, 39.54252127238682, 39.88403218133109, 42.53615958350045, 42.06038168498448, 39.929702690669465, 39.70779112407139, 41.12101650238037, 40.45620938709804, 38.534417561122346, 41.30555370875767, 41.40747683388846, 40.06544964654105, 41.37256908416748, 42.907009260995046, 43.77451964787075, 44.54690224783761, 44.99368878773281, 43.88603823525565, 42.98620135443551, 44.78711189542498, 43.76800571169172, 44.697969981602256, 46.28904839924404, 48.738462107522146, 50.112916537693565, 49.64464269365583, 52.80771630150931, 52.30925253459385, 51.64475808824812, 50.70259625571114, 49.28634146281651, 53.372097628457205, 57.76165335518973, 64.69412122453961, 66.77972030639648, 66.40721348353794, 50.51136793409075, 1.6037669139248985, 0.6736478294645036, 1.798734343477658, 0.15684410237840243, 28.995916639055523, 79.9979385648455, 58.520528657095774, 59.62247821262905, 42.85936893735613, 32.8014623778207, 52.21919693265642, 66.0028144291469, 33.953018597194124, 0.12931794513549122, 0.0447898523083755, 0.0473379073664546, 0.023386893461325338, 0.10286000557243824, 0.07376099737094981, 0.07007149034844977, 0.1652118640818766, 0.3036246619054249, 0.16840384208730289, 0.11732019750135285, 0.17149690325771058, 0.18656818382441998, 0.2849767282605171, 8.239173020635333, 68.74936090196881, 54.102773666381836, 49.569664682660786, 29.914145401545934, 63.10444981711251, 53.26348338808332, 88.12034797668457, 18.947645493916102, 0.7980262296540397, 2.8114767372608185, 0.22308209378804478, 10.054389902523585, 41.893016951424734, 55.637516089848106, 55.50235973085676, 61.856754847935264, 56.60034186499459, 59.803332873753135, 65.22872952052525, 65.64791434151786, 57.58950826099941, 58.84087535313198, 52.73866510391235, 49.25900724955967, 48.831321307591026, 47.71522521972656, 48.68932097298758, 44.874412536621094, 45.688387053353445, 46.94343669073922, 46.159172671181814, 46.56756346566336, 45.26576287405831, 48.32258115495954, 47.634928362710134, 50.646482603890554, 48.31691837310791, 45.063212462833945, 43.08685643332345, 47.269616399492534, 41.564836161477224, 44.629728249141145, 50.581645488739014, 59.051016671316965, 56.41120147705078, 56.57332032067435, 51.12571028300694, 48.76174899509975, 44.11076382228306, 44.49846288136074, 42.54568556376866, 45.99927030290876, 43.890092509133474, 39.08658742904663, 42.166498047964915, 41.85179328918457, 43.44785703931536, 44.839692388262065, 39.339918749673025, 46.182292801993235, 44.67165715353829, 44.889799322400776, 47.04051692145211, 44.68152012143816, 48.045507839747835, 48.73580094746181, 50.41660840170724, 49.33311326163155, 49.04448856626238, 50.51819453920637, 51.23030151639666, 48.97347102846418, 52.94162198475429, 53.776958738054546, 53.4017699105399, 52.96457883289882, 43.92747381755284, 50.2773699760437, 49.535146032060894, 26.70880937576294, 21.31791227204459, 32.17483908789498, 47.49172598975045, 50.061406067439485, 42.704521383558, 49.53755010877337, 54.861058371407644, 52.64387430463518, 54.546812193734304, 51.48303181784493, 54.5619557925633, 50.5401473726545, 50.494247572762625, 51.821051256997244, 51.09724003928048, 50.950834546770366, 50.093409470149446, 48.393251282828196, 47.77481297084263, 45.348835536411826, 47.58310522351946, 44.8887015070234, 42.217101778302876, 42.22170843396868, 43.70097643988473, 41.62395143508911, 42.164698464529856, 42.57017796380179, 40.73186526979719, 39.5949558530535, 41.64008862631661, 43.83653579439436, 41.107846191951204, 44.360065187726704, 43.78906570162092, 41.17856495720999, 42.983508927481516, 44.3237886428833, 44.13003465107509, 43.04356568200247, 43.57363680430821, 43.500830105372835, 40.972231251852854, 44.0572418485369, 46.364669118608745, 46.4766080720084, 47.97781848907471, 49.105795996529714, 46.73158958980015, 44.20399127687727, 47.94022873469761, 46.210231508527485, 46.95958430426461, 47.77896799360003, 51.74816117967878, 53.295160225459504, 53.33683552060808, 56.64050940104893, 55.8983862059457, 53.92569187709263, 53.56918675558907, 53.341501235961914, 55.308838503701345, 58.996452467782156, 67.58468300955636, 69.75928851536342, 67.15343611580985, 47.3810898235866, 2.443197024720056, 0.6942602034126009, 3.6272740704672675, 0.3395307809114456, 32.86388846806118, 86.47009522574288, 65.7162846156529, 68.35259096963065, 50.031831060137065, 35.570635659354075, 60.96348054068429, 78.9472736631121, 40.58068636485508, 0.16739468409546784, 0.12999182540391171, 0.2642236261495522, 0.18746216728218965, 0.23158153199723788, 0.10421018847929579], [0.06555503912802253, 0.02096665743738413, 0.06445757658886057, 0.035140887568039555, 0.11085199458258492, 0.050325174749429734, 0.03566486927281533, 0.09888762408601386, 1.1625383900744575, 37.11126320702689, 40.587763105119976, 39.03707456588745, 25.939692429133824, 41.43055874960763, 37.296074867248535, 68.73949445996965, 20.712338549750193, 0.26643871728863033, 1.534051077706473, 0.0726362034412367, 0.47823082974978853, 20.973243406840734, 50.57039982931954, 59.290416853768484, 63.0628023147583, 60.33434200286865, 61.50593335287911, 57.47350113732474, 52.76017325265067, 48.47623361860003, 47.658131871904644, 43.60024840491158, 43.31284311839512, 42.499181270599365, 42.874644551958355, 41.48909732273647, 43.02054630007063, 39.662978717258994, 40.265165192740305, 41.57612351008824, 41.2807034764971, 42.06912251881191, 42.771168504442485, 44.14463629041399, 42.945637771061485, 41.49800838742937, 40.21772984095982, 38.40499346596854, 40.23087930679321, 42.148370197841096, 50.85108968189785, 51.24507686070034, 51.548747880118235, 53.39644759041922, 52.33873374121529, 50.73430783408028, 45.151350361960276, 39.867481572287424, 39.214722633361816, 38.53717252186367, 40.12080247061593, 38.06329148156302, 38.45978348595755, 36.45006915501186, 36.32108627046858, 37.01274469920567, 40.71557869229998, 36.34959125518799, 39.354829583849224, 43.164116927555625, 40.22903803416661, 42.44666331154959, 42.562472411564414, 44.19407967158726, 43.05574934823172, 43.21998391832624, 45.06748213086809, 44.01579931804112, 43.99734837668282, 45.46447440556118, 46.025444167000906, 46.85585117340088, 45.10182012830462, 45.69442851202828, 44.851990699768066, 41.015268393925254, 48.459742069244385, 44.59004361288888, 32.46897370474679, 34.511077063424246, 36.037981918879915, 48.01554373332432, 46.20101819719587, 44.389153821127756, 45.143040316445486, 48.398438113076345, 45.992669514247346, 46.71070677893502, 46.75913224901472, 44.26953363418579, 44.53565658841814, 46.38841806139265, 46.39359099524361, 43.60424361910139, 44.48228400094168, 44.05680758612496, 42.696468421391074, 39.06666694368635, 40.15469578334263, 39.67816053118025, 39.23961802891323, 39.28963811056954, 38.30929592677525, 35.644432476588655, 36.577540806361604, 35.541359424591064, 35.28952891486031, 34.983551093510215, 38.357683181762695, 39.14059925079346, 38.436246463230674, 37.95139421735491, 39.43629373822893, 41.17589684895107, 40.64356756210327, 37.202527795519146, 36.053340911865234, 38.77605506352016, 36.28177683694022, 36.463406222207205, 40.22869757243565, 38.57400492259434, 40.20061642783028, 39.80110543114798, 41.96561173030308, 40.52135917118618, 41.99813972200666, 40.668428216661724, 41.14648165021624, 41.608630657196045, 42.09793322426932, 41.71381596156529, 41.43114239828927, 41.186558859688894, 43.75998749051775, 42.3403628213065, 44.05412905556815, 44.547850676945274, 45.634208474840435, 47.06436661311558, 50.509262629917686, 51.72066020965576, 61.035262380327495, 60.28960950034005, 67.28045613425118, 64.56451647622245, 39.96947417940412, 1.2986266762018204, 0.672202604157584, 0.8535558528133801, 0.1480791534164122, 31.549674919673375, 66.81788676125663, 47.852386134011404, 46.23979261943272, 36.0432208606175, 23.374004091535294, 33.2018175806318, 54.22051089150565, 27.62090461594718, 0.1933488114071744, 0.042300931577171595, 0.035843222202467065, 0.025587679385872822, 0.03137268405407667, 0.034147648007742, 0.06738160790077277, 0.09461563546210527, 0.11437485340450491, 0.06329648103564978, 0.12620854484183447, 0.09226015542766877, 0.02815281317037131, 0.026716620860887424, 2.4793178864887784, 49.869889395577566, 46.65335634776524, 41.21831907544817, 27.744212559291295, 51.534959180014475, 40.66288008008684, 76.90767165592739, 22.94763830729893, 0.2526902135993753, 2.464725149529321, 0.14233109328363622, 0.8230812166418348, 21.23871496745518, 52.5443239893232, 60.40913936070034, 64.83805315835136, 63.773491859436035, 61.349362645830425, 60.27429567064558, 55.34854398454939, 50.281069891793386, 48.81056703839983, 44.395532267434255, 45.5460775239127, 45.25716100420271, 44.66102293559483, 42.7959805216108, 45.877951281411306, 43.45951611655099, 44.12555306298392, 44.51881068093436, 43.731513772692, 45.49578298841204, 43.99491303307669, 46.80470200947353, 45.221752984183176, 43.177426201956614, 43.53599146434239, 41.16911540712629, 42.234969070979524, 44.27671112333025, 53.357707909175325, 53.20166179112026, 55.63302755355835, 55.216774872371126, 53.472308022635325, 53.678565297807964, 46.6274847303118, 42.93213047300066, 41.88740628106253, 40.583903380802695, 40.760304246629985, 40.11749512808663, 38.395398003714426, 37.88616105488369, 38.822243213653564, 38.0453269141061, 40.55451944896153, 38.187584332057405, 40.69705132075718, 45.32105663844517, 43.638883863176616, 42.66526753561837, 44.872988155909944, 46.155007226126536, 43.605911186763215, 46.749248436519075, 47.48882859093802, 46.11816092899868, 46.84542192731585, 47.566071714673726, 48.00920697620937, 49.10343708310808, 47.92702368327549, 49.56031935555594, 46.13987404959542, 45.72166197640555, 50.12515231541225, 44.93984372275216, 35.26883370535714, 37.32941232408796, 37.86248506818499, 49.907472201756065, 49.881267070770264, 46.36319957460676, 49.670858246939524, 51.6523003578186, 48.15119341441563, 47.71438101359776, 48.14054530007498, 46.85850885936192, 47.28326613562447, 47.29864944730486, 48.37674931117466, 46.14768729891096, 45.810428687504356, 46.19029712677002, 44.02779885700771, 41.191387857709614, 41.17306545802525, 42.2898667880467, 42.057077816554475, 41.31461068562099, 40.40639080320086, 37.66539246695382, 38.03266382217407, 37.43143967219761, 37.60175044195992, 37.19967903409685, 41.43687466212681, 41.676604884011404, 40.40603991917202, 40.89450175421578, 42.39175864628383, 41.781324659075054, 42.35072953360421, 39.97865274974278, 38.59229605538504, 41.11775779724121, 38.593011719839915, 39.553218024117605, 40.715679441179546, 41.256120749882285, 42.72316687447684, 41.367163385663716, 42.24506132943289, 43.24172135761806, 44.469339506966726, 42.34392377308437, 43.9328829901559, 43.64168746130807, 42.863301617758616, 43.99393333707537, 44.14677633558001, 44.036643913814, 44.451937743595664, 46.54574612208775, 47.317645822252544, 47.10446119308472, 48.390350409916465, 49.143062659672324, 53.24400063923427, 54.793598311288015, 63.182714326041086, 64.50239263262067, 69.12648827689034, 67.10326317378453, 45.8879462650844, 1.5619573231254305, 0.9769487487418311, 1.4610459208488464, 0.18676077920411313, 34.942108563014436, 72.9421888078962, 55.18824904305594, 53.965456417628694, 46.26414605549404, 28.168068306786672, 44.00406381062099, 64.34571770259312, 34.19493055343628, 0.25949106152568546, 0.06542232446372509, 0.06883699087692158, 0.02273850405721792, 0.006256691255008003, 0.033097981475293636, 0.15794646394039902, 0.20370055522237504, 0.2540778991367136, 0.183836021859731, 0.2412624896637031, 0.1910531103078808, 0.2004344540515116, 0.21344243176281452, 4.203773055757795, 67.03596987043107, 55.42093031747, 51.06877326965332, 35.830703258514404, 60.95059163229806, 46.89483404159546, 85.82637241908482, 25.493968963623047, 0.7829705689634595, 4.048122550759997, 0.3335563614964485, 1.7545204588345118, 26.069576842444285, 54.45612777982439, 65.9852076939174, 70.038453238351, 65.8639268875122, 65.99840927124023, 61.73317418779646, 57.56540496008736, 53.40870768683297, 52.097551345825195, 48.054710728781565, 49.27509232929775, 46.77742338180542, 46.9967919077192, 46.84630782263619, 48.96080098833357, 44.84569215774536, 47.040607248033794, 46.98789473942348, 47.227360929761616, 46.95139932632446, 46.954505171094624, 49.49515567507063, 47.341210637773784, 46.24397890908377, 45.5356239591326, 43.23257058007376, 45.93912322180611, 46.397641795022146, 56.39429303577968, 55.84631640570504, 56.896818024771555, 58.79683767046247, 55.57605927331107, 54.42322111129761, 49.04519380841936, 46.0766350201198, 43.3579751423427, 43.65233210154942, 44.005328382764546, 41.12585939679827, 42.41656371525356, 40.67865596498762, 41.84971925190517, 39.484444754464285, 44.82573345729283, 40.07077891486031, 43.072602203914094, 49.00537715639387, 46.44117225919451, 45.19151094981602, 46.53941978727068, 49.639111927577424, 45.91786868231637, 47.53259529386248, 49.0492376599993, 49.32937165669033, 48.592786175864084, 50.733057158333914, 51.51889494487217, 52.382007122039795, 50.232258796691895, 50.526841572352815, 50.414430141448975, 48.197596958705354, 54.91082484381539, 47.25312485013689, 36.34847606931414, 39.42569078717913, 39.128155027117046, 50.83281939370291, 51.87004995346069, 50.7434412411281, 50.63034193856375, 53.42111022131783, 49.68383400780814, 50.97746351787022, 52.245488916124614, 48.3536639213562, 49.521770749773296, 50.98681926727295, 52.191244329724995, 49.18364013944353, 48.99978038242885, 50.20464318139212, 48.106943811689106, 43.97568736757551, 45.755701201302664, 45.55720158985683, 44.38533926010132, 43.005819593157085, 43.153802326747346, 39.593229225703645, 40.721286637442454, 39.468717506953645, 40.20831503186907, 38.72632680620466, 43.154205322265625, 43.520486559186665, 42.483634676252095, 42.907641547066824, 46.52169145856585, 44.28753989083426, 44.40555851800101, 41.09415129252842, 40.00319378716605, 44.61622095108032, 41.430524008614675, 41.9691344669887, 45.19628436224801, 44.25474786758423, 45.13278824942452, 45.05192858832223, 45.88801574707031, 45.226081711905344, 48.42935412270682, 45.19431802204677, 47.34169353757586, 46.933657101222444, 47.16724511555263, 45.52139057431902, 46.90901531491961, 47.32722391401018, 48.861163820539204, 48.66727433885847, 49.95752355030605, 50.04678705760411, 50.846747057778494, 52.07157550539289, 57.10739360536848, 56.73586647851126, 67.55026858193534, 67.43176010676792, 74.18667370932442, 71.090806552342, 47.86188084738595, 2.3049128907067433, 1.25354665517807, 3.6405014864036014, 0.2575246127588408, 38.72895322527204, 81.04255853380475, 60.68764400482178, 62.63414709908621, 54.509972844805034, 35.19210474831717, 51.26379183360508, 73.44211864471436, 44.23079742704119, 0.39332142738359316, 0.14936261597488606, 0.13901631401053496, 0.1488518283835479, 0.07942922785878181, 0.18801350412624224], [0.04646375409460493, 0.052483153595988236, 0.07266020322484629, 0.014435379599620188, 0.09391679189034871, 0.01978158245661429, 0.11296110533710037, 0.15286344955010073, 4.043173696313586, 40.44003398077828, 33.839321749550955, 38.13289506094796, 23.322787182671682, 42.75197410583496, 40.9926381111145, 67.44885267530168, 33.076746531895225, 0.0624317695785846, 0.7589752908263887, 0.0762741689437202, 0.13816423687551702, 5.59617120879037, 50.40319837842669, 61.01172188350132, 59.601918492998394, 56.87105410439627, 51.94912740162441, 50.501185349055696, 46.168219225747244, 41.8369345664978, 41.84271894182478, 41.5623209135873, 42.39027173178536, 42.58532851082938, 40.17779854365757, 42.287535667419434, 41.59565142222813, 44.835766656058176, 44.16843387058803, 44.57936075755528, 43.054311071123394, 43.913212639944895, 44.07070050920759, 42.00400052751814, 41.55100229808262, 37.35169519696917, 37.713341985430034, 39.72355658667428, 43.059834889003206, 50.90080404281616, 50.21487440381731, 53.2031626020159, 52.210049629211426, 49.51817505700247, 55.470481395721436, 54.55747767857143, 47.77319751467024, 42.92946931294033, 38.181747845241, 37.48459339141846, 39.31791727883475, 41.949408531188965, 38.90645885467529, 36.731613636016846, 38.164391245160786, 36.48204129082816, 38.61548914228167, 41.96783167975289, 38.734692437308176, 40.1265903200422, 40.28199372972761, 39.945190225328716, 41.1400580406189, 41.68499830790928, 43.715922015053884, 42.571727412087576, 45.37171248027256, 44.11964362008231, 44.62660155977522, 45.27621643883841, 45.39578798839024, 46.003887380872456, 46.890713759831016, 49.461828640529085, 50.360303674425396, 50.515411785670686, 49.69907488141741, 41.509278365543906, 34.48217255728585, 39.08969327381679, 37.671162945883616, 45.52198117119925, 49.29621137891497, 39.70923982347761, 44.9251378604344, 48.79226548331124, 45.924410411289756, 44.49478728430611, 44.70384815761021, 46.123132365090505, 43.08265972137451, 41.49413129261562, 41.96638298034668, 42.865580626896445, 41.995447295052664, 41.62110614776611, 41.425893034253804, 39.77152000154768, 37.601205008370535, 41.35181481497628, 39.92425530297415, 36.23205205372402, 35.79767499651228, 36.761101790836875, 35.05177198137556, 36.08070291791643, 36.84105471202305, 37.867421763283865, 41.79184423174177, 37.97104024887085, 38.44155141285488, 37.62642002105713, 41.18770183835711, 45.98191022872925, 46.92605577196394, 47.823155062539236, 41.99685777936663, 36.668079308101106, 36.59052004132952, 36.93858310154506, 37.989241055079866, 38.293943881988525, 37.61309337615967, 38.45204666682652, 39.59969105039324, 40.786029951913015, 38.74179349626814, 39.65644046238491, 39.54806246076311, 39.69080972671509, 40.882029737745015, 40.673128673008506, 42.59732110159737, 42.23070287704468, 42.56190960747855, 41.12166615894863, 44.12042876652309, 44.145299843379426, 46.3938376562936, 45.16620908464704, 51.44227368491036, 55.99150596346174, 63.24524811335972, 64.06797041211809, 69.99575655800956, 65.09408732822963, 65.32248156411308, 2.643795209271567, 0.6745192312768528, 1.024895878774779, 0.1722622500466449, 39.28523642676217, 66.5871023450579, 53.560838494982036, 48.9602381842477, 24.147321224212646, 33.636201586042134, 44.336594172886436, 55.09002583367484, 27.960139989852905, 0.19054382906428405, 0.028715924293334995, 0.04525273532739707, 0.05400607794789331, 0.012075588323308952, 0.027400014190269367, 0.05161780770868063, 0.06921284499445132, 0.06652119835572583, 0.018893154504309808, 0.01680775685235858, 0.08321531077048608, 0.12058205104299954, 0.13013505057564803, 6.066763145583017, 54.35248497554234, 41.43602350779942, 51.26722771780831, 30.03386286326817, 48.81655291148594, 47.61636972427368, 71.77956758226667, 36.93556758335659, 0.06924644604857479, 1.1229197617088045, 0.04680561021502529, 0.11201170592435769, 5.532905689307621, 51.98084592819214, 62.894218172345845, 60.49287905011858, 59.20726081303188, 56.45592703138079, 53.027032715933665, 49.37156459263393, 44.69054583140782, 45.11436857495989, 43.804942335401265, 44.66157531738281, 44.20346321378435, 43.98542526790074, 43.83920390265328, 44.58730602264404, 47.27984414781843, 45.3633850642613, 45.711427279881065, 47.13417169025966, 46.168792452131, 46.81850808007376, 44.393833432878765, 44.9680186680385, 40.902592931474956, 38.757895946502686, 40.44661392484392, 45.12825454984392, 53.05315794263567, 52.0422819001334, 54.64675160816738, 54.91452823366438, 52.414747033800396, 55.617571285792756, 56.09709078924996, 48.86539874758039, 43.442374910627095, 40.94854484285627, 39.36510944366455, 41.98463937214443, 43.28100299835205, 39.28753628049578, 39.13037150246756, 40.37443603788103, 38.977872439793174, 40.437087944575715, 42.67894506454468, 40.873709269932334, 41.73758922304426, 43.94246803011213, 42.83676297324044, 42.859466212136404, 44.56810814993722, 45.276675019945415, 45.64450570515224, 45.305068833487375, 44.98404468808855, 46.020340715135845, 46.82262141363961, 46.84102371760777, 47.47620371409825, 49.29216405323574, 51.001195090157644, 51.275489125932964, 50.800485951559885, 52.052190031324116, 41.566364765167236, 33.91785029002598, 37.66073022569929, 36.263287680489675, 46.84979581832886, 51.25023589815412, 42.3677248273577, 46.23302507400513, 51.12345559256417, 48.63602134159633, 46.048272473471506, 46.34981734412057, 48.82814250673567, 43.84721864972796, 44.97942761012486, 44.955696037837434, 45.740901538303916, 43.6797879082816, 44.192120279584614, 43.25160864421299, 42.59962442943028, 40.49354900632586, 41.35732821055821, 40.54520886284964, 39.4380064691816, 38.116427830287385, 37.195478848048616, 37.59416995729719, 38.19709989002773, 37.88890559332711, 38.773237568991526, 44.28825555528913, 40.211921146937776, 40.10932057244437, 40.292871134621755, 44.59170075825283, 49.010904448372976, 50.52371835708618, 49.744297231946675, 45.166612080165315, 39.938999380384175, 38.32719448634556, 39.11080884933472, 39.84549052374703, 39.45786094665527, 39.52538354056222, 40.748735495976035, 42.18661308288574, 43.12238952091762, 42.45823901040213, 41.8673711504255, 43.36192519324166, 42.091415813991, 43.19670397894723, 44.540648869105745, 46.0580346924918, 45.27405207497733, 45.39776822498867, 44.99981362479073, 46.75263568333217, 45.98457138878958, 48.9135810307094, 50.17537042072841, 54.36302191870553, 57.824214935302734, 67.5230941772461, 67.05475779942104, 71.7271295275007, 67.13123662131173, 69.75998333522251, 3.252207270690373, 0.8696764877864293, 2.5274230880396704, 0.25780072222862926, 45.35994223185948, 70.86832523345947, 59.39809308733259, 58.98338985443115, 34.50936780657087, 45.0469536781311, 57.334221022469656, 62.85446058000837, 38.26266656603132, 0.04723957407155207, 0.0864524995642049, 0.09989554035876479, 0.08648054341652564, 0.05261897934334619, 0.030637515110096762, 0.13601196450846537, 0.19137834571301937, 0.08933727083993809, 0.09843009470828942, 0.15563825065536158, 0.20028698125055858, 0.2585444508918694, 0.27981562806027277, 8.390200802258082, 69.39436912536621, 47.92757953916277, 53.13399675914219, 31.860940320151194, 59.900267192295615, 54.38065644672939, 81.45614310673305, 41.259671279362266, 0.3876592426427773, 1.866914084979466, 0.37097542360424995, 0.19010470834161552, 7.930363808359418, 58.39113930293492, 67.99963637760708, 64.63062163761684, 60.86206463405064, 58.76392405373709, 54.629589557647705, 51.70266784940447, 46.09581552233015, 47.60987663269043, 47.16474723815918, 47.939672878810335, 46.45009027208601, 46.405503681727815, 45.67738110678536, 46.51237045015608, 49.70745440891811, 48.36625058310372, 50.315112590789795, 47.4602541242327, 49.86373329162598, 48.70448889051165, 47.90789876665388, 46.606654030936106, 41.758774280548096, 41.34260497774397, 42.7115147454398, 48.17278494153704, 54.01306894847325, 54.950061321258545, 58.593943323407856, 57.87517997196743, 55.51182665143694, 58.66876152583531, 60.21749414716448, 52.960847650255474, 47.190167222704204, 43.551982743399485, 40.3981363432748, 44.16851724897112, 46.330754961286274, 42.41721337182181, 42.238741942814414, 42.33532885142735, 41.71213797160557, 42.814195224217, 44.79013088771275, 44.67764302662441, 44.668968200683594, 46.11997788293021, 45.09156111308506, 44.379384653908865, 47.48379462105887, 49.029664584568565, 49.52998699460711, 49.20943880081177, 47.51054865973336, 50.24088151114327, 48.94520228249686, 50.1887526512146, 50.404063429151265, 50.68409667696272, 54.09906332833426, 53.108778272356304, 53.77823373249599, 54.3070923941476, 42.48850883756365, 33.95732995441982, 39.02177810668945, 36.76917907169887, 47.710674149649485, 53.618539810180664, 44.86167648860386, 49.905321734292166, 54.414421217782156, 50.34278379167829, 48.52440200533186, 50.87572104590279, 51.118202754429404, 47.611485140664236, 46.6201057434082, 47.36400767735073, 47.16439635413033, 46.12158291680472, 46.32726696559361, 45.426759583609446, 45.83367735998971, 42.1025641986302, 46.584468432835166, 44.78622252600533, 42.34147105898176, 39.016924789973665, 40.154654094151084, 39.434657437460764, 39.97831923621041, 40.69646767207554, 42.8151193346296, 46.98236397334507, 43.265435559409006, 43.12356376647949, 42.1244649205889, 47.8175721849714, 51.44755778993879, 52.20855924061367, 52.58845547267369, 46.765910216740195, 41.948182174137656, 41.10161713191441, 41.63960920061384, 42.63485179628645, 43.15320478166853, 41.507899148123606, 43.01485572542463, 44.71780014038086, 45.826902866363525, 45.060495717184885, 46.98176295416695, 45.32717105320522, 44.54977880205427, 45.3378643308367, 46.57252447945731, 48.98444223403931, 48.334775243486675, 48.967926365988596, 48.49993739809309, 49.40198033196585, 49.89987782069615, 52.98413453783308, 51.89787401471819, 58.573592049734934, 62.697278431483674, 70.13631166730607, 69.23418535505022, 77.31660788399833, 69.2994636808123, 73.29523372650146, 3.7876180836132596, 1.0328242076294762, 3.8377163325037276, 0.6386547471795763, 49.333929674965994, 79.14654105050224, 66.2454524721418, 67.19213758196149, 37.67266723087856, 45.58940649032593, 60.62231009347098, 72.93117591312954, 48.243913650512695, 0.4205960924071925, 0.12252154839890343, 0.1365192915712084, 0.19102200626262597, 0.15736168889062746, 0.1106384935389672], [0.02962150052189827, 0.07201411575078964, 0.04258056603638189, 0.012160681703660105, 0.07699456278766904, 0.01778948676240231, 0.10079486388713121, 0.16819876166326658, 6.362179270812443, 43.438386644635884, 44.12788418361119, 29.76820543834141, 27.690886872155325, 42.374009472983225, 35.89083991731916, 60.67013454437256, 51.56576401846749, 1.400435590318271, 0.06936252981956516, 0.13549006251352175, 0.17641468080026762, 1.1733848537717546, 48.87664440699986, 66.66012791224888, 53.47523668834141, 53.846520628247944, 48.16229663576399, 46.76626457486834, 43.166194438934326, 42.60860497610909, 43.57316085270473, 44.92445346287319, 44.727082933698384, 45.82865033830915, 45.12109095709664, 45.6510717528207, 44.06335278919765, 47.0356114932469, 46.810458592006135, 47.801820618765696, 45.43345069885254, 45.04602261951992, 41.420473439352854, 41.13662215641567, 39.009601388658794, 40.62998035975865, 38.82432072503226, 42.22517558506557, 48.64716625213623, 51.52236557006836, 51.607203074863975, 47.13900416237967, 42.536378451756065, 52.5328803062439, 52.59850604193551, 53.3729453086853, 45.63249226978847, 44.63525206702096, 41.22764008385794, 38.261349882398335, 40.63376365389143, 44.77460861206055, 38.71073504856655, 35.99067510877337, 34.668867179325645, 37.30698353903634, 34.51683017185756, 36.643409729003906, 37.59816517148699, 39.38118757520403, 43.06874942779541, 41.960539545331685, 41.19571658543178, 41.54758725847517, 43.38010515485491, 42.64600712912423, 43.088391985212056, 45.86405488422939, 44.93780790056501, 41.369758537837434, 43.37936864580427, 47.40062468392508, 48.50595801217215, 46.24445833478655, 47.59101227351597, 47.18392079217093, 49.040649686540874, 38.85727603094918, 32.16209956577846, 32.539862700871055, 31.039968967437744, 43.5322915485927, 48.36275911331177, 46.73104068211147, 45.002457414354595, 47.1224605015346, 43.67976358958653, 44.52253491537911, 43.99476017270769, 45.088656766074045, 44.4946413721357, 43.74613973072597, 42.5737875529698, 40.701564175742014, 39.7555183001927, 41.15059845788138, 41.040455613817485, 40.49400411333357, 36.574917861393516, 37.65392099108015, 35.42387580871582, 36.4389694077628, 34.65215328761509, 36.31516293116978, 36.204238414764404, 37.286434241703574, 35.075889178684776, 37.69275099890572, 41.830292088644846, 37.5610339982169, 38.571256910051616, 39.239350523267476, 45.43969712938581, 49.35875906263079, 53.684585911887034, 53.22519881384713, 48.42058549608503, 44.359655244009836, 38.497665064675466, 37.27428879056658, 36.139960629599436, 37.12075444630214, 38.66353940963745, 39.535955224718364, 39.7799516405378, 38.721285888126914, 40.909805161612375, 39.72235107421875, 40.04031106403896, 41.82138449805123, 43.87064102717808, 42.26997756958008, 42.64517681939261, 43.85301692145211, 42.13666943141392, 41.36645119530814, 44.82293333326067, 42.5991484778268, 47.512330872671946, 46.33109194891793, 51.48438324247088, 56.94506631578718, 67.7056997844151, 62.330698422023225, 71.89928504398891, 63.64523506164551, 77.66248226165771, 5.019700450556619, 0.4123207607439586, 1.0256762483290263, 0.0924685335318957, 50.44492925916399, 67.62396812438965, 55.479090213775635, 41.63816050120762, 19.249768802097865, 21.084715093885148, 43.10454307283674, 54.11915751865932, 31.31127527781895, 0.6142529451421329, 0.04916243374879871, 0.04878030996769667, 0.018902771041861603, 0.08056542117680822, 0.03307864322726216, 0.011539534632382649, 0.04697976301291159, 0.03535711971510734, 0.03935404720583132, 0.08992011885025672, 0.052258680641118965, 0.07572889820273433, 0.17672036082616874, 8.295275381633214, 54.33078575134277, 49.8714006287711, 35.01458522251674, 28.917813675744192, 49.14572729383196, 44.47591250283377, 67.55953053065709, 56.16831677300589, 1.5665679957185472, 0.3398412785359791, 0.3814172904406275, 0.29866875069481985, 1.1379977869135993, 52.371768951416016, 68.595034463065, 56.12535606111799, 55.55640629359654, 49.385356766836985, 49.69522557939802, 43.912559509277344, 46.3952168737139, 46.23353229250227, 48.10607876096453, 46.88316106796265, 47.68931538718087, 46.80880839484078, 49.23617546898978, 45.70176928383963, 49.15188339778355, 48.53931631360735, 50.57157754898071, 48.16074023927961, 47.51984534944807, 44.78731686728341, 44.471576826913015, 41.37256908416748, 43.096417154584614, 39.198557649339946, 44.58783408573696, 52.283724852970664, 54.01396526609148, 53.24455302102225, 52.2181408064706, 46.59239980152675, 54.42693839754377, 52.979277747017996, 54.534131731305806, 48.78662702015468, 45.74874258041382, 41.34170518602644, 41.35207537242344, 42.630123547145296, 45.97184228897095, 41.88791002546038, 37.891785621643066, 36.45219530378069, 38.822587149483816, 36.756095613752095, 38.28710685457502, 39.78701795850481, 40.88679967607771, 44.22248043332781, 44.449856758117676, 44.482537610190256, 43.42986467906407, 46.51516015189034, 45.03159815924508, 45.3082719530378, 47.627504212515696, 46.34277534484863, 44.70068325315203, 46.93290669577462, 49.12044627325875, 49.929633481161936, 48.40401404244559, 48.62542881284441, 50.21373837334769, 53.393081188201904, 40.880452496664866, 31.914906978607178, 33.28662034443447, 32.01646184921265, 43.881938798086985, 49.264607497623985, 48.1891826902117, 48.028623717171804, 49.76824767248971, 45.90092897415161, 47.10518380573818, 46.727253913879395, 46.162414005824495, 46.60438544409615, 45.22308356421334, 42.375121184757774, 44.61538369315011, 42.301720414842876, 44.970002378736226, 44.22199405942644, 42.74112449373518, 39.84641463415963, 38.600178786686485, 37.945516041346956, 38.70940794263567, 37.90537977218628, 38.474485874176025, 36.25675637381417, 37.99330922535488, 36.931801659720286, 40.18229750224522, 43.88642733437674, 40.46655872889927, 40.0109201839992, 42.40660694667271, 47.92029435294015, 52.04817049843924, 55.406252247946604, 55.08171926225935, 50.4132524217878, 46.60394075938633, 40.36406585148403, 39.35904714039394, 39.221399852207725, 40.609705516270225, 40.614405972617014, 42.5024538721357, 41.94779307501656, 41.57619299207415, 42.066923413957866, 42.54693276541573, 42.868266105651855, 44.01525388445173, 44.929251194000244, 45.79035881587437, 45.58323996407645, 46.11862645830427, 44.780729975019185, 43.089420318603516, 47.39618131092617, 44.225958006722585, 49.90743398666382, 48.550072125026155, 56.14947673252651, 60.573394775390625, 71.74719592503139, 63.93344633919852, 74.9077925000872, 65.21406882149833, 81.7072093146188, 5.439081992421832, 0.6660385749169758, 1.0203393804175513, 0.1066780746249216, 55.97740806852068, 72.18384851728166, 60.83070741380964, 50.58102362496512, 26.35780201639448, 25.342586823872157, 50.05576760428292, 59.170338085719514, 43.17567525591169, 0.85699939089162, 0.08488600647875241, 0.025884443461628895, 0.04204498816813741, 0.13790091100547994, 0.037193500104227235, 0.08809300046414137, 0.1215317557965006, 0.1308107900300196, 0.11809298103409153, 0.1695772869778531, 0.1764721255749464, 0.24943563395312854, 0.3260213386799608, 10.973333460944039, 66.11240836552211, 60.67723560333252, 39.37249537876674, 34.94983843394688, 58.385240282331196, 48.565274783543174, 72.73417363848004, 61.69512585231236, 1.7798949543918883, 0.887389997286456, 0.7635976885046277, 0.35956792001213345, 2.3900070445878163, 56.95970617021833, 72.52697835649762, 59.49895313807896, 59.07946259634835, 53.272522994450156, 54.049751962934224, 46.464605058942524, 48.1890298298427, 49.57013021196638, 50.39859867095947, 49.88562706538609, 50.29137059620449, 49.797648974827354, 52.43917690004621, 48.819478103092735, 53.502338136945454, 51.82189198902675, 53.24930558885847, 50.18587957109724, 51.568796907152446, 48.15307985033308, 46.25171225411551, 43.365882192339214, 46.186934198652, 42.92021778651646, 47.91474969046456, 53.674931389944895, 56.36983190264021, 54.469360624040874, 52.0783291544233, 47.72061354773385, 54.48972579411098, 56.590468474796836, 58.64681216648647, 50.12143155506679, 49.41998658861433, 44.92701734815325, 44.168006556374685, 44.335138525281636, 50.55401250294277, 43.78180135999407, 40.04102325439453, 38.44502551215035, 41.40499980109078, 39.51396417617798, 40.182405199323384, 42.58027022225516, 44.06471116202218, 47.40663487570626, 48.587359632764546, 49.11035054070609, 45.11291987555367, 48.430233069828574, 48.14358513695853, 48.97197369166783, 50.039255210331504, 47.510691097804475, 45.89410236903599, 48.264365673065186, 54.51838363919939, 53.17738478524344, 50.332073143550325, 51.4125006539481, 50.32151882989066, 55.817474433353965, 41.09214326313564, 32.37271336146763, 33.72573607308524, 32.59191860471453, 43.593838691711426, 53.29563617706299, 50.56375387736729, 50.548356669289724, 51.31912381308419, 49.05380262647356, 49.58583314078194, 49.25097165788923, 49.99062476839338, 49.35231460843767, 47.99787793840681, 45.60600226266043, 46.03991379056658, 46.10091550009591, 47.08316843850272, 47.180297306605745, 44.37329455784389, 41.497063432421, 40.79928016662598, 39.185078144073486, 39.153144223349436, 39.07305581229073, 40.55467925752912, 40.24102367673601, 40.88350970404488, 39.06598254612514, 43.783726011003765, 47.16870771135603, 41.8130327633449, 42.92239604677473, 44.33797686440604, 49.03049142020089, 54.004630361284526, 57.18700606482369, 57.0899327823094, 52.57717159816197, 50.09873179027012, 43.6551912852696, 42.12177249363491, 39.66708162852696, 43.64439378465925, 42.88870423180716, 45.834705693381174, 45.33297627312796, 43.5083897454398, 44.53135565349034, 44.90986571993147, 45.55500943320138, 48.09070587158203, 48.85392379760742, 48.299933501652305, 47.66834919793265, 49.11603764125279, 47.082789761679514, 45.53901468004499, 49.896052837371826, 48.71637725830078, 52.52084255218506, 51.14450863429478, 57.50264188221523, 63.73357445853097, 75.27127361297607, 67.95168685913086, 80.24131311689104, 69.09302575247628, 84.7444406236921, 6.618063620158604, 0.6645255503909928, 2.221371876341956, 0.4219117175255503, 62.519911766052246, 80.14658832550049, 69.33651147569928, 57.82264116832188, 30.27317271913801, 31.080021858215332, 62.39918681553432, 70.86471911839077, 61.203825678144185, 0.9558049461671284, 0.1834916789084673, 0.11271422037056514, 0.10913435103637831, 0.19171158783137798, 0.19557498980845722], [0.0547231876823519, 0.15345262150679315, 0.03966457536444068, 0.09049387449132544, 0.056189505250326226, 0.10119969144995723, 0.1437131062682186, 0.09888200581605945, 9.812320743288312, 57.23507022857666, 41.44666119984218, 45.44296973092215, 37.57397501809256, 34.015997069222585, 40.15326445443289, 51.624768120901926, 64.68055834089006, 4.495255197797503, 0.08908540542636599, 0.7467720285058022, 0.11629962655050413, 0.6095654623849052, 41.36555140359061, 65.84807109832764, 51.03513356617519, 57.51305028370449, 48.450924805232454, 57.81079796382359, 52.9455303464617, 51.05434880937849, 49.25148582458496, 49.92072589056832, 47.92677354812622, 49.41834681374686, 46.377592767987935, 49.94893210274832, 46.51586191994803, 51.60919025966099, 46.44812740598406, 49.09542581013271, 45.891319615500315, 44.519658361162456, 39.673362800053184, 39.76177167892456, 39.95770740509033, 40.23268583842686, 41.27854258673531, 50.03823035103934, 47.480292728969026, 53.904683998652864, 46.283812931605745, 65.5131470816476, 75.98037202017647, 50.6755816595895, 51.64061001368931, 49.22407865524292, 49.44766126360212, 43.483595098767964, 40.84627430779593, 38.72917209352766, 45.72452463422503, 48.6863888331822, 38.19659614562988, 36.908143043518066, 37.20614085878645, 38.569276673453196, 37.04209041595459, 36.47506529944283, 35.575429916381836, 39.66996513094221, 37.34579965046474, 40.52622985839844, 40.34074422291347, 41.54435287203108, 41.43501601900373, 40.645346300942556, 43.59388732910156, 43.80843727929251, 40.9650468145098, 43.02620560782296, 43.426842212677, 46.90078169958932, 46.9666610445295, 47.37685489654541, 49.4155466897147, 50.19208778653826, 52.15276868002755, 41.91661998203823, 32.12193202972412, 27.70047538621085, 27.596639769417898, 40.872125080653596, 47.00895472935268, 50.821153368268696, 49.597033636910574, 47.377956186022075, 46.46044308798653, 44.98487152372088, 42.78152479444231, 44.06642041887556, 45.60691942487444, 43.136428356170654, 42.05285331181118, 42.13406038284302, 39.146043164389475, 37.944880281175884, 41.72404023579189, 39.69322075162615, 38.71793685640608, 35.50029904501778, 37.29046072278704, 37.72427150181362, 37.76259776524135, 35.9767370223999, 35.502668380737305, 36.729306834084646, 37.60324083055769, 39.31638867514474, 40.73690618787493, 37.96433176313128, 38.34785842895508, 44.54742683683123, 51.08212423324585, 51.24014016560146, 50.772040026528494, 48.64414725984846, 50.87440436226981, 49.54137856619698, 43.44771112714495, 39.530622482299805, 38.31230797086443, 40.03528751645769, 38.72936316898891, 38.81294999803816, 41.127759729112896, 39.99647487912859, 39.46001836231777, 43.08471291405814, 41.56938375745501, 40.34493398666382, 45.23160205568586, 43.30161482947213, 47.62983880724226, 45.354126589638845, 46.37808609008789, 43.15576171875, 47.51871974127633, 43.168970244271414, 45.42269836153303, 46.39879172188895, 52.695343085697715, 53.305606842041016, 63.59103216443743, 60.1094913482666, 67.70858328683036, 57.68206868852888, 78.98921298980713, 6.052643537521362, 0.3261001030249255, 0.38908579466598375, 0.9637655190059117, 59.55754729679653, 62.38199002402169, 54.38877889088222, 42.349200929914204, 28.537081922803605, 39.3256436756679, 50.59519100189209, 49.966340814317974, 27.720663377216884, 0.6287497101085526, 0.11199578070747, 0.109325582560684, 0.09960085938551597, 0.1420677402721984, 0.032551679361079416, 0.0397355535200664, 0.18014266075832502, 0.05533291585743427, 0.16215243110699312, 0.04011587239801884, 0.08039767374949795, 0.29626529823456493, 0.3071667232683727, 14.678635801587786, 65.43496595110211, 49.670104367392405, 40.95341205596924, 36.76381853648594, 43.56713676452637, 44.9355844770159, 59.86901419503348, 67.26287719181606, 5.362200175012861, 0.03998539350660784, 1.6601959488221576, 0.17121855462236063, 0.7954703239457948, 43.528838293892996, 69.25224372318813, 53.79664993286133, 59.07883031027657, 52.095303603581016, 60.30900192260742, 54.59620693751744, 54.40935945510864, 51.15779359000069, 53.45400646754673, 48.88719524656023, 51.87717185701643, 49.365540504455566, 52.369017464774, 49.75832217080252, 54.990055152348106, 49.51411036082676, 51.055220808301655, 46.654673031398225, 47.88723134994507, 43.60539354596819, 43.215801102774485, 43.09382547651018, 42.091130937848774, 45.07832479476929, 51.239028453826904, 51.32292447771345, 56.876494543892996, 50.49828100204468, 61.95083345685686, 65.48761245182583, 53.47343710490635, 52.683562414986746, 52.74817023958479, 48.98141976765224, 45.24836458478655, 42.50657762799944, 42.30884231839861, 48.6682505607605, 50.529766763959614, 41.056474685668945, 39.493776185171946, 39.301029682159424, 38.91823257718767, 38.89313568387713, 38.11055660247803, 37.986520835331504, 40.21226160866873, 39.97119733265468, 42.09505319595337, 41.30865607942854, 42.76984487261091, 43.428353445870535, 42.89194209235055, 46.08167593819754, 44.76379721505301, 43.10786083766392, 46.40839065824236, 45.587791034153526, 47.951825278145925, 50.22488675798689, 50.22873258590698, 51.74840784072876, 51.31470128468105, 53.41281754629952, 42.45831196648734, 32.54680742536272, 26.904046807970317, 27.439198800495692, 41.5909092766898, 49.37929098946707, 52.992990016937256, 50.69795485905239, 50.50196354729788, 49.8569518498012, 48.72257852554321, 44.57760981151036, 47.47250727244786, 46.703817640032085, 45.743131910051616, 45.05978352682931, 43.70003495897566, 42.523423535483225, 40.36957924706595, 42.990290369306294, 43.36003875732422, 41.53596639633179, 38.69910723822457, 39.72994198117937, 38.35681465693882, 38.62862818581717, 37.964012145996094, 37.65454632895333, 38.40351349966866, 38.62046752657209, 41.341830253601074, 42.30560098375593, 41.46481336866106, 39.79047816140311, 45.63371862683977, 52.371032442365376, 53.890725067683626, 52.958884784153526, 50.60283054624285, 53.07051454271589, 50.60972315924508, 45.996202673230854, 41.94529172352382, 41.57856232779366, 40.59826530729021, 41.162017822265625, 40.525107724326, 42.1442221232823, 42.435226576668875, 41.46671717507498, 42.097766467503135, 44.05762052536011, 43.55343839100429, 47.41905130658831, 47.06355019978115, 50.84975562776838, 47.433027608054026, 49.45508541379656, 44.94266816547939, 49.152831826891216, 44.51643787111555, 48.76232916968209, 46.88592297690255, 56.13540663037981, 56.1713079724993, 66.8068321772984, 62.36644690377371, 72.04171616690499, 60.36270454951695, 84.08819716317313, 6.659849217959812, 0.6916522404977253, 0.4515941504921232, 1.0676215461322238, 65.66367285592216, 68.76291683741978, 59.81502669198172, 50.49524463926043, 29.239756720406668, 33.15259306771414, 52.38102395193917, 59.56598935808454, 37.52102974482945, 0.9363145977258682, 0.11171617678233556, 0.08886015894157545, 0.10842840998832669, 0.1460404542407819, 0.06877662840166263, 0.12927221187523433, 0.2665734743433339, 0.07468987109937839, 0.26232359239033287, 0.34262069367936676, 0.25199675081031664, 0.31121038485850605, 0.27317909417407854, 18.618731669017247, 80.11544649941581, 53.56618513379778, 63.49308340890067, 51.09417240960257, 49.3083290372576, 54.29972382954189, 63.51384462629046, 76.07728549412319, 5.619027742317744, 0.27377959766558235, 2.074046398912157, 0.24925438367894717, 1.2768075955765588, 45.85485199519566, 72.43392808096749, 56.87792934690203, 62.40766361781529, 54.60910974230085, 63.538941519601, 56.746518066951204, 57.62583691733224, 54.08457286017281, 55.35833747046334, 52.359085014888215, 54.464535100119456, 52.008840220315115, 53.63286699567522, 53.43360308238438, 57.5221836907523, 53.692124707358225, 54.004560879298616, 52.399002415793284, 50.90159961155483, 45.87837512152535, 45.99764442443848, 44.96076822280884, 43.654447828020366, 46.94730336325509, 52.74229206357683, 54.138153893607004, 58.92674119131905, 53.22731106621878, 62.43248953138079, 62.67537076132638, 58.13893706457955, 53.58342361450195, 54.832966804504395, 50.90297882897513, 48.06957292556763, 44.1297150339399, 43.823952606746126, 51.83412776674543, 53.1802648135594, 41.789009366716655, 40.898038387298584, 41.76707737786429, 40.272856848580496, 41.896456309727256, 41.341204915727886, 38.148851599012104, 43.73876421792166, 42.76321281705584, 46.07209089824131, 43.710589272635325, 46.212871823992046, 44.55907549176897, 44.60329382760184, 47.819878986903596, 48.65766150610787, 47.28344678878784, 48.53861801964896, 48.4900118964059, 50.648292609623496, 53.44577285221645, 52.75297144481114, 54.40535034452166, 54.19467748914446, 57.170090675354004, 44.67001043047224, 32.737306186131065, 26.818121910095215, 27.431519304003032, 42.78409562792097, 52.1853209904262, 54.51210246767317, 53.9317124911717, 52.95204775674002, 53.59942184175764, 51.519360474177766, 46.19572714396885, 49.78428064073835, 50.58976445879255, 49.07566860743931, 46.703560556684224, 47.941903250558035, 45.55057648250035, 43.407960483006065, 46.87279782976423, 45.29811021259853, 43.71388619286673, 39.13932425635201, 42.312198298318044, 40.12786878858294, 41.682128701891216, 38.82827772412981, 40.883794580187114, 39.81997326442173, 42.1412969316755, 43.7225992338998, 44.36648184912545, 43.57408496311733, 42.720137459891184, 49.424106870378765, 54.34265674863543, 55.36638695853097, 55.03044850485665, 52.52443477085659, 55.82263694490705, 53.3176828111921, 47.69959872109549, 46.22829335076468, 43.02087981360299, 44.254949365343364, 45.591661180768696, 42.17942517144339, 44.16218744005476, 44.19783517292568, 44.242070879255024, 45.973805155072895, 46.47514200210571, 45.79211671011788, 51.253366061619346, 49.514464718954905, 53.20929091317313, 49.236380440848215, 52.08723327091762, 48.58742216655186, 52.46036890574864, 47.692150252205984, 51.57750994818551, 49.96686887741089, 59.43336909157889, 58.293767247881206, 70.80376952035087, 66.70955739702497, 74.41146877833775, 62.70574828556606, 89.37285109928676, 7.817558935710362, 0.857170435999121, 0.9619481308119637, 1.3620496158088957, 72.76479434967041, 75.47793388366699, 66.65021283285958, 58.870474679129465, 41.99153198514666, 50.95454488481794, 70.61749526432583, 68.73672907693046, 49.71333953312465, 1.244281883750643, 0.16110930565212453, 0.15953714001391614, 0.1494469035949026, 0.20682081207633018, 0.10385102632322482], [0.07820265367627144, 0.06092308767672096, 0.1463759219540017, 0.029412793328187296, 0.05450803440596376, 0.040632050950080156, 0.10105282933052097, 0.20649469457566738, 12.559276291302272, 57.738154547555105, 40.49616847719465, 36.87456239972796, 24.08327099255153, 41.72683341162545, 37.21916873114449, 48.259338651384624, 66.18511431557792, 18.630663463047572, 0.09244329881455217, 0.9705274190221513, 0.006489335467839348, 0.11093309308801379, 27.505955355507986, 72.7588814326695, 54.198009150368826, 63.83383696419852, 55.06696476255144, 62.75222478594099, 55.46377638408116, 58.3213654926845, 53.70162636893136, 56.16400194168091, 50.91964060919625, 52.352602345602854, 49.67773001534598, 52.49074642998831, 47.31671823774065, 49.01897478103638, 46.087373461042134, 48.201456683022634, 41.68753787449428, 42.071846212659565, 38.05896970203945, 40.339476176670615, 38.65049416678292, 44.33168874468122, 47.384629930768696, 53.81960678100586, 47.36271183831351, 54.01023408344814, 45.1837671824864, 52.32696349280221, 67.21940231323242, 51.24461827959333, 50.90228748321533, 52.4663165637425, 46.237645626068115, 46.692412172045024, 43.14297703334263, 43.89235414777483, 50.5575213432312, 50.761690684727256, 41.94489220210484, 35.26007897513253, 38.11775493621826, 38.469948700496126, 35.607832840510774, 36.67934581211635, 34.76150056294033, 36.97654458454677, 36.878206729888916, 39.13290064675467, 41.05048533848354, 39.6235476902553, 41.35487897055489, 38.97711508614676, 43.792029108319966, 42.073353971753804, 41.75780153274536, 43.08730459213257, 42.12991925648281, 46.35452127456665, 47.888763427734375, 48.18399933406285, 46.770687103271484, 50.91100399834769, 49.534298351832796, 42.60062844412667, 32.10121944972447, 30.677821908678325, 28.42671847343445, 39.83716310773577, 48.281267166137695, 47.44890076773507, 49.31419331686837, 48.109841210501536, 47.55952303750174, 45.993947982788086, 44.477135385785786, 43.421974999564036, 43.56485080718994, 42.986576557159424, 42.13442168916975, 40.22790200369698, 38.5485189301627, 42.40613794326782, 38.29916197913033, 41.014514514378135, 38.51077631541661, 36.07241371699742, 34.95053672790527, 39.141558102199006, 37.0525335584368, 35.94137069157192, 37.10630219323294, 38.5513642174857, 39.60874455315726, 45.248229094914024, 44.67364086423601, 40.02137027468, 38.88669122968401, 44.474543707711355, 49.42291872841971, 50.75120932715279, 51.46539381572178, 47.91256448200771, 51.69241925648281, 52.21855075018746, 47.24807698386056, 41.906402656010215, 40.299079350062776, 37.44884490966797, 38.73818390710013, 37.508060932159424, 40.16351304735456, 40.528790269579204, 43.22966275896345, 42.68295070103237, 42.17113249642508, 39.97978183201381, 42.95126233782087, 41.32288599014282, 45.641782011304585, 46.910884380340576, 46.20666013445173, 44.576056889125276, 47.29885441916329, 43.91736418860299, 47.978957993643625, 43.94219357626778, 51.18917860303606, 48.557447637830464, 58.5304993220738, 55.64451987402779, 65.1537445613316, 58.89107608795166, 78.33895192827497, 4.247495898178645, 0.34574599883386065, 0.36414683716637747, 3.74201922757285, 66.33106122698102, 55.03343275615147, 60.33494649614607, 36.83290794917515, 45.66692754200527, 29.462335314069474, 50.63761670248849, 51.37486226218087, 37.628636496407644, 1.156088290469987, 0.19871705477791174, 0.044890740287623236, 0.06085652339139155, 0.1164571280990328, 0.03407633397728205, 0.07542627836976733, 0.030416129489562342, 0.07654945738613605, 0.023694537846105437, 0.06816889851221017, 0.05122653388285211, 0.15147379626120838, 0.14441401937178203, 16.427549498421804, 64.01626191820417, 48.6612537247794, 44.80599709919521, 32.44399493081229, 45.916496413094656, 43.7728590284075, 54.25392477852957, 71.80819416046143, 20.782633474894933, 0.14306068127708776, 1.4273330441543033, 0.010330300412273832, 0.092554632840412, 29.07826668875558, 74.66731534685407, 55.65255893979754, 65.66328375680106, 58.18735211236136, 63.37547819955008, 56.239184924534385, 61.021636962890625, 57.86017533711025, 59.92881734030587, 53.63571228299822, 54.45733676637922, 53.359055859701975, 53.687879358019146, 50.31288569314139, 51.470274925231934, 49.46333639962332, 49.681224959237234, 44.88592222758702, 43.986606461661204, 39.718557357788086, 41.98796755926949, 40.99273191179548, 47.22077056339809, 51.205656255994526, 53.41050379616873, 50.66498218263899, 55.43620940617153, 48.003061294555664, 50.15289299828665, 62.47378267560686, 55.22972284044538, 53.1217714037214, 52.42161880220686, 48.27628878184727, 48.70149769101824, 42.306059564862935, 47.112621852329795, 50.9587277003697, 54.291451999119346, 46.27766030175345, 37.31932701383318, 39.60861253738403, 40.09694930485317, 36.879783970969065, 38.69019269943237, 37.536729199545725, 38.070027760096956, 38.919458934238975, 41.280825069972444, 44.19552142279488, 42.1087897845677, 42.333911418914795, 41.96470846448626, 44.683330127171104, 44.8769416809082, 42.703166484832764, 44.22735806873867, 44.93572691508702, 48.23695502962385, 48.2870272227696, 50.45655359540667, 49.05133949007307, 53.66534634998867, 52.55755335944039, 44.53428431919643, 32.553668771471294, 29.783828462873185, 28.02026101521083, 39.67193494524275, 50.65385464259556, 50.12176506859915, 50.52199520383562, 50.40867703301566, 49.418259961264475, 46.593858923230854, 44.951916217803955, 44.72323015757969, 45.00317307880947, 44.75479929787772, 44.20684003829956, 42.318955421447754, 40.02947187423706, 43.55699239458357, 39.6502183505467, 42.7107469694955, 38.88599640982491, 38.145301069532124, 35.122376101357595, 39.348590101514546, 39.95793669564383, 38.56538915634155, 38.91005802154541, 39.48573017120361, 40.55488075528826, 47.529169831957134, 44.73570564814976, 41.63297019686018, 42.28124407359532, 46.71742916107178, 52.8137195450919, 53.176651750292095, 52.958533900124685, 50.575687408447266, 52.704844747270855, 54.78570863178798, 50.505524499075754, 45.19001013892037, 41.93266684668404, 40.81181819098336, 39.805441107068745, 39.50587994711739, 41.36712169647217, 43.843831402914866, 45.386970724378315, 44.40382146835327, 44.476034096309114, 42.267642974853516, 46.33004624502999, 44.756463391440256, 50.61341960089547, 51.23159735543387, 49.98861673900059, 48.19867392948696, 50.01975509098598, 47.08910914829799, 51.727660519736155, 46.741473402295796, 53.97063282557896, 52.34132194519043, 60.77564293997628, 57.12747389929635, 68.48036139351981, 62.00369535173689, 84.9854736328125, 4.683845375265394, 0.266641300703798, 0.32725464392985615, 4.836462557315826, 73.25618485042027, 63.754342624119346, 67.0367967060634, 46.12041909354073, 46.785042081560405, 37.02731507165091, 63.56802667890276, 55.24801744733538, 52.49460962840489, 1.7461974940129688, 0.12484966990138803, 0.05290642713329621, 0.0593152650232826, 0.0983635847057615, 0.017672512414199964, 0.23082341839160236, 0.07307403494736978, 0.19812071749142238, 0.08482518259968076, 0.15085696721715586, 0.17151002612497124, 0.23127933964133263, 0.37497253769210404, 20.439993483679636, 75.37598991394043, 54.01391315460205, 50.54601165226528, 33.05707270758492, 54.18298019681658, 54.08200550079346, 59.999001094273154, 81.02272837502616, 24.084676265716553, 0.2760827626500811, 2.6347225989614214, 0.09453684397573982, 0.3146639109722206, 33.54318952560425, 78.6816440309797, 58.96224648611886, 69.40020561218262, 60.3274632862636, 68.40142985752651, 60.13787473951067, 64.42739377702985, 60.814552852085654, 62.1764623097011, 55.969709464481895, 55.53641285215105, 54.42661183220999, 56.788693632398335, 52.12918301991054, 54.75634554454258, 53.14492974962507, 53.69179119382586, 46.67437812260219, 46.43662813731602, 42.488960470472065, 45.08283764975411, 42.43867288316999, 50.22128759111677, 51.66799633843558, 59.74683012281145, 51.99012872150966, 58.5671580178397, 47.086725916181294, 55.04834706442696, 66.28172206878662, 54.66602938515799, 55.1996614592416, 54.73604985645839, 50.98517949240548, 51.45074353899275, 45.3599978174482, 50.1601573399135, 53.995906897953574, 56.26014763968331, 47.25622027260916, 38.37630087988717, 41.92250510624477, 42.5298957824707, 39.25732898712158, 40.970883301326204, 40.49216978890555, 40.145069054194856, 38.48361928122384, 44.19725499834333, 46.21463319233486, 44.06635441098894, 45.23505878448486, 43.20908914293562, 48.57353271756853, 47.94525923047747, 46.39561639513288, 47.68966627120972, 45.91109071459089, 50.54971156801496, 52.3690904208592, 51.73385483877999, 52.318775040762766, 55.73237984521048, 56.28426136289324, 45.116133417402, 32.51151057652065, 31.782679285321915, 27.590547936303274, 41.838970388684956, 54.490448406764436, 52.055035318647114, 53.01432793481009, 51.97228227342878, 52.40162536076137, 48.770034721919465, 46.58958578109741, 47.00125959941319, 48.082854407174246, 46.324220180511475, 47.14486149379185, 46.98359727859497, 41.847877979278564, 46.6286381312779, 41.824570247105186, 45.44599914550781, 42.21153974533081, 40.119840145111084, 38.688316685812815, 43.245223249707905, 41.463444573538645, 40.07101515361241, 40.85119710649763, 42.51265035356794, 42.335825647626606, 49.432305744716096, 47.2779403414045, 43.599643911634175, 42.99838154656546, 49.91630336216518, 54.51997825077602, 54.69861643654959, 53.98601613725935, 51.362751552036826, 56.01292378561837, 57.155291012355256, 52.62039286749703, 46.68995598384312, 43.823730264391216, 43.37469598225185, 43.079790115356445, 43.10873631068638, 45.641174043927876, 46.247480801173616, 48.42116567066738, 47.40990400314331, 46.13462815965925, 45.280826568603516, 49.12688030515398, 47.20563391276768, 52.43837785720825, 53.987906047276084, 51.762776715414866, 51.483886446271626, 53.63884244646345, 50.63503197261265, 53.49582420076643, 49.80849163872855, 57.897070271628245, 54.555695465632844, 64.162417275565, 61.24486173902239, 71.71140575408936, 65.83669689723423, 90.2525416782924, 6.164106105055128, 0.6142598390579224, 0.5270721060889108, 5.042498792920794, 82.63907391684396, 66.52459635053361, 75.42106287819999, 51.48230225699288, 63.45841189793178, 38.426644052777974, 68.11036981855119, 69.1802464893886, 64.73054368155343, 2.9906282212053026, 0.29956400979842457, 0.19632018410733768, 0.17103174036102636, 0.19359221548906394, 0.18855479865201882], [0.05423022181327854, 0.02761284857323127, 0.046163770370185375, 0.04317711027605193, 0.07461848921541657, 0.08824749610253743, 0.04179928045985954, 0.1454819520669324, 22.63727617263794, 56.0238150869097, 49.082394463675364, 43.714653968811035, 21.096593039376394, 40.30478729520525, 33.43690293175833, 45.13758945465088, 61.06493813650948, 38.39722537994385, 0.1496406253427267, 0.02143152347499771, 0.08977737543838364, 0.25549438170024324, 10.895464130810328, 63.85213157108852, 57.50570603779384, 65.80727822440011, 58.6364871433803, 60.11279174259731, 56.84042297090803, 59.17289502280099, 53.698871408190044, 57.30145331791469, 55.52254772186279, 52.509631633758545, 48.88154288700649, 51.14045088631766, 48.06968757084438, 46.60325288772583, 44.95569951193673, 42.941204820360454, 41.227608816964285, 40.27219329561506, 40.383218560900005, 37.42667668206351, 40.697165966033936, 47.41555636269705, 51.45420026779175, 49.91680015836443, 47.342978954315186, 45.26109021050589, 42.43798153741019, 35.59931434903826, 34.213791438511436, 56.449586800166536, 49.72079495021275, 50.757872649601524, 43.379656996045796, 47.88199935640608, 40.562294483184814, 49.56162561689104, 48.29795673915318, 50.77092136655535, 40.96756206239973, 37.07568148204258, 35.60474784033639, 35.60029057094029, 35.293732575007844, 34.99031516483852, 34.00583185468401, 36.52991437911987, 36.76721967969622, 39.92865351268223, 40.10187905175345, 38.398003578186035, 42.39603526251656, 41.05547761917114, 43.449354376111714, 43.52503762926374, 41.3673996244158, 42.92101682935442, 44.3806665965489, 45.618707043784006, 46.02904333387102, 49.01744270324707, 50.60264989307949, 49.20862586157662, 48.68241446358817, 44.79910101209368, 33.705162457057405, 33.245139598846436, 29.62072992324829, 42.044164589473176, 52.02347660064697, 48.112137590135845, 51.32596778869629, 47.78724677222115, 46.55932985033308, 45.13441412789481, 44.30422946384975, 39.49854612350464, 42.424147674015586, 41.54965434755598, 40.98883049828665, 43.15742581231253, 40.08886854989188, 39.63641227994646, 38.96070344107491, 38.07297032220023, 35.12199395043509, 36.151456424168174, 35.43784863608224, 35.75133746010916, 32.959217752729145, 36.82441030229841, 37.289988245282856, 38.0131185395377, 40.340761593409944, 47.968667711530415, 46.873589924403596, 38.43480471202305, 40.48743806566511, 42.18514701298305, 49.860026427677695, 52.26574986321585, 52.16240930557251, 50.8906284059797, 50.26232017789568, 51.5174914087568, 51.35657112939017, 49.264360836574006, 44.97863898958479, 39.7803407396589, 37.82025391714913, 37.85803474698748, 40.794760363442556, 39.7768041065761, 41.76864767074585, 41.130733558109824, 42.199880668095176, 41.94416611535208, 41.17029660088675, 42.782820633479524, 45.116199425288606, 45.93470416750227, 46.49915497643607, 47.34430258614676, 45.38362864085606, 43.31256866455078, 48.785400663103374, 44.249779905591694, 51.037245818546836, 46.6683019229344, 51.80045679637364, 49.716771943228586, 62.93093940189907, 59.76537486485073, 75.0585823059082, 1.7538277017218726, 0.21699138704155171, 0.26436828981552807, 7.541971666472299, 68.72898183550153, 48.833562101636616, 53.03236198425293, 38.47112989425659, 53.82728801454817, 33.90264763150896, 36.47907093593052, 59.8636154447283, 40.189943994794575, 0.5327174631612641, 0.0807261864787766, 0.0677666018850037, 0.021547422345195497, 0.027588012495211194, 0.05573211157960551, 0.056465455264385254, 0.02840432744207127, 0.07668380053447825, 0.08254915901592799, 0.009548756992444396, 0.06711528290595327, 0.032400786743632386, 0.09571382403373718, 29.405759607042583, 65.67237200055803, 55.37308154787336, 55.15563072477068, 25.75560859271458, 46.431076526641846, 41.02319628851754, 54.719294275556294, 65.86172430855888, 41.02626739229475, 0.10329166240990162, 0.35237512311765123, 0.2251425739377737, 0.26662094465323855, 11.94297455038343, 65.93304061889648, 58.5428740637643, 66.69756480625698, 58.530047689165386, 63.82010037558419, 58.42107909066336, 61.09862995147705, 55.066572189331055, 60.178723199026926, 57.4965934753418, 54.59479645320347, 52.21295745032174, 53.51179116112845, 51.000305720738, 50.7045521736145, 47.85514456885201, 45.73947715759277, 43.0074975831168, 42.67330660138811, 42.77993713106428, 38.97211585726057, 44.21896464484078, 49.347541196005686, 53.64925084795271, 52.988914898463655, 50.665572779519216, 46.721379211970735, 45.10604810714722, 37.21745252609253, 36.939733028411865, 59.570491790771484, 51.78527845655169, 52.90398359298706, 45.92097452708653, 49.27243116923741, 44.1148806299482, 51.067824840545654, 51.40187338420323, 51.56769214357649, 42.95393739427839, 40.14307492119925, 38.197318758283345, 37.29013415745327, 37.05755363191877, 38.019528252737864, 36.30643946783883, 37.762813159397666, 37.296304157802034, 41.065100874219624, 42.22536666052682, 40.80362279074532, 42.95413541793823, 44.4047976902553, 46.0992305619376, 46.62567125047956, 43.05608286176409, 43.85149526596069, 46.390471254076274, 46.613994802747456, 48.94373621259417, 51.070645809173584, 50.78636373792376, 50.50470808574131, 51.40446853637695, 48.034310817718506, 33.91505364009312, 33.942856856754844, 30.617820739746094, 43.258410930633545, 51.4387092590332, 50.81527171816145, 54.3588981628418, 49.37253039223807, 49.421595096588135, 46.416113580976216, 46.2364296913147, 41.80692529678345, 44.55938121250698, 43.80297599520002, 43.276709011622835, 43.88662535803658, 41.43855265208653, 40.48766735621861, 41.323445320129395, 42.064203194209504, 37.878611837114605, 38.98339973177229, 36.57202393668038, 38.307353905269075, 36.76850857053484, 39.977596623556956, 39.680199827466694, 39.96795947211129, 41.730894633701865, 49.349330357142854, 47.811363969530376, 41.708907059260774, 41.8310946055821, 44.3204847744533, 52.32193994522095, 54.260351862226216, 52.69759430204119, 50.98095498766218, 53.52257129124233, 54.04603815078735, 53.34175484521048, 49.82947867257254, 46.83134140287127, 42.76312596457345, 40.42678724016462, 39.57296480451311, 42.72167648587908, 42.28491619655064, 44.47591597693307, 44.609748704092844, 46.27674661363874, 44.08919661385672, 43.360764844076975, 44.9267463684082, 48.133395603724885, 47.95998246329171, 50.07004615238735, 50.029051780700684, 49.999681745256694, 47.07189498628889, 50.78672504425049, 46.85532658440726, 53.57689230782645, 48.4331374168396, 53.50966501235962, 51.73747137614659, 67.49670491899762, 62.73059504372733, 78.4033339364188, 2.153699027640479, 0.25535085797309875, 0.07566278853586741, 8.903503315789358, 76.87159660884312, 56.280485016959055, 58.12098291942051, 44.77720723833357, 58.98013809749058, 32.35057987485613, 49.504903997693745, 66.55462646484375, 52.28349208831787, 1.1083727308682032, 0.07529117526220423, 0.06327344477176666, 0.03065500095752733, 0.0596329483336636, 0.03504478665334838, 0.11110109835863113, 0.09451252528067146, 0.17902035026678018, 0.14532846744571412, 0.21641829636480125, 0.24197956547141075, 0.09902165510824748, 0.16406850543405327, 36.510237080710276, 76.8937474659511, 62.73509747641427, 56.08030046735491, 30.3599522454398, 55.133125509534565, 46.81004864828927, 58.96929890768868, 72.12246118273053, 46.63238321031843, 0.28306857922247475, 0.877847569329398, 0.4759105114000184, 0.3369094915688038, 14.155221922057015, 69.16283430371965, 61.05581515175955, 72.05870451245988, 60.973631858825684, 65.98934187207902, 61.690748487200054, 64.38173021589006, 58.532361439296174, 61.96529265812465, 60.40390041896275, 57.04719788687569, 54.36078459875924, 56.692530563899446, 54.06458289282662, 52.81877783366612, 49.175614970070974, 48.67914186205183, 46.10125943592617, 45.168557575770784, 45.08937243052891, 40.78314297539847, 46.308802127838135, 51.579625674656455, 55.92788825716291, 56.50895915712629, 50.21579851422991, 49.21271487644741, 45.78037772859846, 39.1310385295323, 44.53103951045445, 59.389254978724885, 53.78310094560896, 55.076647077287944, 47.65504339763096, 52.42562443869454, 47.2094658442906, 53.7955938066755, 52.711876324244905, 56.889699595315115, 45.45675148282732, 42.73966884613037, 39.08373866762434, 39.59177357809884, 39.00216334206717, 39.48461498532976, 38.09218209130423, 40.40025554384504, 38.78645651681082, 44.50752680642264, 44.8613395009722, 43.6276764188494, 45.6572139603751, 48.01992457253592, 48.82782983779907, 48.307044982910156, 44.412544931684224, 47.2485077721732, 48.610323429107666, 47.78043406350272, 51.563419001443044, 53.487562792641775, 56.201831408909385, 53.41656262534005, 54.42730665206909, 48.01507820401873, 35.40725571768624, 34.555496897016255, 31.017088549477712, 44.70100287028721, 57.07532072067261, 54.860519886016846, 58.78565801892962, 53.28500543321882, 53.397138936179026, 48.11580623899187, 48.497602803366526, 43.54992607661656, 46.717470850263325, 46.2883049419948, 47.87393944604056, 47.798044272831504, 43.64625937598092, 43.14759758540562, 43.81057732445853, 42.21384654726301, 39.29318169185093, 40.616486958095, 40.80615540913173, 40.40915271214077, 38.174455710819785, 43.19030121394566, 41.789283820560996, 42.01258502687727, 43.483275481632774, 50.71251480919974, 49.24687916891915, 43.57142380305699, 43.769638538360596, 47.19659778050014, 54.51880747931344, 56.031315667288645, 55.61772067206246, 53.40828037261963, 55.40445613861084, 55.873362268720356, 55.46950169972011, 53.622451645987375, 48.22324970790318, 44.611044543130056, 41.81212254932949, 41.70523493630545, 46.129048756190706, 45.63639715739659, 46.74078205653599, 46.596217836652485, 48.52069861548287, 46.99557597296578, 46.88350847789219, 47.5216623033796, 50.288219588143484, 51.819303785051616, 52.30842917306082, 54.8281204359872, 52.900412218911306, 49.183223247528076, 54.26127249853951, 49.52425125667027, 56.78590045656477, 51.05785070146833, 57.77598401478359, 54.750978061131065, 70.1846433367048, 65.89811202457973, 84.35901015145438, 4.101624982697623, 0.5015582665801048, 0.25452641078404015, 9.69999269076756, 84.25224413190568, 61.32887935638428, 67.45842729296002, 52.092586857931956, 68.64573546818325, 42.647410665239605, 51.07964025224958, 77.11196259089878, 66.60674490247453, 2.4121170810290744, 0.25088881169046673, 0.18534500231700285, 0.07692527079156466, 0.17525543086230755, 0.16602816885071142], [0.05847348804984774, 0.05308980122208595, 0.05063501758767026, 0.02355490890996797, 0.05385405896231532, 0.07912592270544597, 0.045127386160727055, 0.08670052446957145, 26.80670428276062, 60.45241274152483, 36.361910411289756, 34.00506407873971, 29.98399911608015, 51.88323416028704, 34.05914885657174, 43.1810496875218, 56.28276055199759, 56.99265800203596, 3.5925141870975494, 0.043904906937054226, 0.6363286205700466, 0.3740159390228135, 2.7534284463950565, 50.90798500605992, 61.9328167779105, 60.20545986720494, 59.87793568202427, 55.48268938064575, 58.172111238752095, 56.800918987819124, 57.31244189398629, 56.112102372305735, 56.787776470184326, 51.92344338553292, 52.12341948917934, 48.700448513031006, 46.26994432721819, 42.74088478088379, 41.030071531023296, 39.90546389988491, 40.673660210200715, 39.38931001935686, 39.18462651116507, 38.71909720557076, 47.18643604006086, 49.383067335401265, 52.16540050506592, 48.53352499008179, 47.29632874897548, 45.19497810091291, 43.76658133098057, 40.512326513017925, 34.48777975354876, 53.41868877410889, 51.28922918864659, 49.55377762658255, 43.69900662558419, 46.452060086386545, 42.91278321402413, 50.02308675221035, 46.39879172188895, 46.66657529558454, 42.56675597599575, 37.9863714490618, 36.03973286492484, 36.38525635855538, 36.838021823338096, 35.87686708995274, 35.91460623059954, 36.93418141773769, 36.999414580208914, 37.483450412750244, 37.88329144886562, 41.255856718335835, 38.354629448481965, 40.077171257564, 39.8140811920166, 41.991556303841726, 42.49854898452759, 41.05369193213326, 42.175065176827566, 43.685464586530415, 46.5790627343314, 47.26193864004952, 47.140980924878804, 46.95879915782383, 49.361722469329834, 48.24840913500105, 35.16085522515433, 32.064592020852224, 33.766629695892334, 46.98690809522356, 48.64798961366926, 48.21032953262329, 48.987725257873535, 46.58112982341221, 45.620325974055696, 42.84688302448818, 43.29712976728167, 42.774152755737305, 42.894179412296836, 43.14065286091396, 43.16846302577427, 40.31948273522513, 40.279759883880615, 39.49220241819109, 39.31689589364188, 35.688115801130024, 37.016576630728586, 34.26226207188198, 33.97342545645577, 34.23838806152344, 33.42802313395909, 34.0837003162929, 37.31935133252825, 37.63001571382795, 41.481596742357524, 48.30673231397356, 51.558530943734304, 44.485417638506206, 40.87321247373308, 44.41908666065761, 44.825465951647075, 49.43372665132795, 52.03578880855015, 53.334341117313926, 51.43011086327689, 52.107532433101106, 49.96245329720633, 49.87275205339704, 48.39928926740374, 44.44901255198887, 40.744670799800325, 37.81907272338867, 39.01534407479422, 41.21297591073172, 43.136171272822786, 43.01688807351248, 45.55615588596889, 43.66652032307216, 41.69187702451433, 40.57301207951137, 43.92307908194405, 44.2431652205331, 44.72747550691877, 44.33968959535871, 46.56483629771641, 45.718184403010774, 48.54456567764282, 44.74746547426496, 47.66280800955636, 45.550343717847554, 48.56324938365391, 52.21981184823172, 64.93632847922188, 65.07124165126255, 60.82902594975063, 0.32983845099806786, 0.04976734771792378, 0.24108463206461497, 18.619846854891094, 71.55416107177734, 54.339352880205425, 54.281418800354004, 41.38412046432495, 45.70339863640921, 62.04813602992466, 45.83885029384068, 48.38881138392857, 44.8508894102914, 3.500547613416399, 0.24453272989818028, 0.05509831576741167, 0.195107316332204, 0.01186955370940268, 0.049354608436780315, 0.05810483318886586, 0.03911165753379464, 0.06068522722593375, 0.013093842077068985, 0.03593752499935882, 0.05227927417893495, 0.03444042229758842, 0.07514744118920394, 36.01710953031267, 65.28324508666992, 47.53309556416103, 38.27600710732596, 14.741805349077497, 54.622978346688406, 39.901079586574006, 50.51731906618391, 60.47359085083008, 64.01202351706368, 3.9416830965450833, 0.07583968940057925, 0.808597913810185, 0.36693322764975683, 2.902013284819467, 51.13091100965227, 63.55649961744036, 62.43126664842878, 62.18877451760428, 58.4931458064488, 59.81738907950265, 57.653296198163716, 60.11755820683071, 58.001341887882774, 59.76704938071114, 53.90322487694876, 54.18243128912789, 52.440319878714426, 49.522069522312705, 43.705454553876606, 42.55613912854876, 42.60308115822928, 42.34764800752912, 41.40669168744768, 41.601665088108604, 40.73564508983067, 48.61766767501831, 52.01670905521938, 53.489209515707834, 49.972472599574495, 49.498598507472444, 45.62982068743025, 44.38232026781355, 39.76433209010533, 35.499340193612234, 54.895212241581504, 52.73191840308053, 51.28787428992135, 47.17499583108084, 48.22372565950666, 44.91490663800921, 51.423173086983816, 49.572853905814036, 49.756953375680105, 44.74073961802891, 39.48837743486677, 36.422064440590994, 38.54277624402727, 38.16812590190342, 37.61296830858503, 38.57988657270159, 37.59606334141323, 39.01623344421387, 39.758096081869944, 40.03494010652815, 43.50571468898228, 40.54574734824044, 41.93579701014927, 42.27181189400809, 44.11356047221592, 43.94082130704607, 44.4755095073155, 45.54980870655605, 46.64537286758423, 47.78182717732021, 49.48142950875418, 49.987359115055625, 49.92271654946463, 51.15019226074219, 49.02191039494106, 36.669211864471436, 32.39466272081648, 33.950645787375315, 50.49062408719744, 50.16125862939017, 49.84829439435686, 51.02061530521938, 48.31851298468453, 49.15125111171177, 45.878173623766216, 45.76990679332188, 43.884228229522705, 44.481422424316406, 43.96604674203055, 45.96304586955479, 42.830850056239534, 41.348837511880056, 41.43411275318691, 42.599707807813374, 38.66675989968436, 39.157618863242014, 35.742481981004985, 36.0857264654977, 36.83474574770246, 35.86156368255615, 37.64065687997, 38.94674103600638, 40.094639028821675, 44.13474552971976, 50.17116328648159, 53.47528532573155, 47.30190467834473, 43.15004335130964, 45.94410855429513, 47.107254368918284, 52.42515196119036, 53.29653596878052, 54.47301190240042, 54.262519700186594, 52.37805012294224, 52.429074219294954, 52.34122119631086, 51.527361324855256, 46.870563983917236, 43.175400802067344, 41.103381974356516, 40.725695269448416, 42.948476110185894, 45.859507288251606, 46.50165980202811, 47.80974503925869, 46.94770288467407, 44.260737214769634, 43.1230982371739, 46.57103409085955, 46.53077622822353, 47.20894125529698, 47.251971449170796, 48.304383822849815, 47.295762470790315, 51.733500480651855, 47.57278714861189, 48.99478462764195, 48.477004868643625, 50.54520566122872, 54.62015390396118, 68.49649511064801, 67.74727085658482, 65.00089808872768, 0.4329788679523127, 0.12071503033595425, 0.3218472626592432, 22.764565433774674, 79.29765742165702, 60.203257288251606, 59.85053893498012, 50.02191250664847, 51.147600582667756, 41.74331453868321, 55.32398557662964, 57.200836454119, 56.68299763543265, 4.793262132576533, 0.38260241970419884, 0.0605425788089633, 0.1411415399717433, 0.02902493253350258, 0.04138658867616739, 0.17048104133989128, 0.21340421667056425, 0.12472125036375863, 0.24184613834534371, 0.2943836392036506, 0.14667918639523642, 0.11628294815974576, 0.3635223406766142, 45.60514416013445, 73.98863615308488, 51.58471523012434, 43.67758532932827, 37.965186391557964, 66.13396862574986, 47.8181141444615, 54.561417307172505, 63.56971509116036, 71.1547577721732, 4.964564323425293, 0.17863659800163337, 1.5780560821294785, 0.7044345374618257, 4.148884458201272, 55.87785427910941, 67.06936291285923, 66.00993633270264, 64.92850480760846, 62.26412773132324, 64.49913392748151, 60.78926835741316, 62.56162180219378, 62.089686257498606, 61.19541835784912, 56.70876502990723, 57.31561027254377, 55.533105509621755, 53.34528800419399, 46.98971169335501, 45.42136778150286, 45.820958682468955, 45.024048941476, 43.15267671857561, 43.76715455736433, 44.114435945238384, 52.4702388218471, 54.72265025547573, 57.30677216393607, 51.67023713248116, 51.77423776899065, 49.022702489580425, 43.9681624685015, 43.163929326193674, 40.316741670881, 55.01869215284075, 55.17090286527361, 53.287888935634065, 50.29864188602993, 51.254755701337544, 47.446239607674734, 54.49694149834769, 53.31262452261788, 53.97823068073818, 47.722103936331614, 41.91343770708357, 39.29438720430647, 39.15650020326887, 39.72036041532244, 38.70765004839216, 39.92961236408779, 41.02521126610892, 40.99107129233224, 42.238905225481304, 42.724261215754915, 45.15369190488543, 42.66420793533325, 44.58342892783028, 45.39669125420706, 46.852804388318745, 47.21757091794695, 46.89352083206177, 47.71318244934082, 48.518808705466135, 52.11985853740147, 52.700272832598, 52.46964127676827, 50.98692349025181, 54.26142535890852, 53.19344554628645, 36.2135385785784, 31.138942582266672, 34.150764329092844, 53.34523589270455, 54.65012148448399, 54.848770482199534, 53.10294525963919, 50.78672851834978, 51.15952021735055, 47.31135075432913, 46.81509304046631, 47.67963307244437, 45.83479601996285, 48.53150306429182, 49.31428711754935, 45.50186961037772, 45.1147472517831, 43.92403098515102, 44.67050722667149, 40.44380685261318, 42.20306641714913, 38.65471172332764, 37.02944469451904, 37.67228160585676, 37.37684767586844, 38.587130069732666, 41.77192374638149, 41.87141152790615, 47.27725594384329, 53.68178926195417, 55.46309546061924, 48.34133434295654, 43.714747769492014, 48.394904954092844, 50.035218306950156, 53.73483875819615, 56.9182254246303, 55.85472025190081, 56.01364292417254, 55.15941054480416, 55.115827969142366, 53.513872146606445, 53.27867215020316, 50.649880273001536, 44.43843044553484, 44.111608028411865, 43.305995668683735, 46.403360162462505, 48.96606077466692, 50.60437304633004, 49.80434356416975, 48.514195101601736, 46.05142000743321, 46.61744110924857, 48.461284569331575, 50.33894143785749, 49.69364486421858, 51.03630781173706, 53.53510584150042, 51.6133313860212, 57.62899487359183, 50.07348551068987, 53.415881701878135, 49.73687308175223, 55.09741176877703, 56.82448727743966, 72.64012977055141, 69.20227227892194, 68.76607826777867, 1.3955880275794437, 0.7544397999133382, 0.30890485857214245, 24.416237354278564, 87.10887786320278, 66.496018409729, 67.1588557107108, 53.76375368663243, 65.30943979535783, 80.99653366633824, 66.12884780338833, 66.29241534641811, 72.49304335457938, 7.103889048099518, 0.42485094123653, 0.131255108330931, 0.3127309004110949, 0.15001407744629042, 0.12632950049425873], [0.03010963522163885, 0.07555108131574732, 0.04242608057601111, 0.07819079288414546, 0.04395589545103056, 0.04267748797844563, 0.021282786902572428, 0.3121485545166901, 23.28880180631365, 52.57769618715559, 46.04248462404524, 42.67361232212612, 49.46601493018014, 86.6792221069336, 31.10481650488717, 52.629307406289236, 49.38018383298601, 66.70519392830985, 10.907354235649109, 0.04789357326392617, 0.5611807044063295, 0.07138385849871806, 0.07769710437527724, 37.10032674244472, 66.769027028765, 53.914623396737234, 56.20961339133126, 48.40421554020473, 49.817228998456685, 49.031533649989534, 50.503217697143555, 48.87555006572178, 47.57171017783028, 46.882052830287385, 45.10538455418178, 42.62437391281128, 41.27943195615496, 39.09326812199184, 39.648832184927805, 38.68237945011684, 40.51552268436977, 39.88934407915388, 40.772265570504324, 39.84904452732631, 48.75600978306362, 49.38002749851772, 50.64267846516201, 49.844660486493794, 48.12772239957537, 44.03411129542759, 45.76778064455305, 41.77851063864571, 40.54236357552664, 54.325932434626985, 51.73655421393258, 49.928233419145855, 45.47053323473249, 43.93354306902204, 44.39171423230852, 48.70747314180647, 44.57007449013846, 44.8840913772583, 45.01226132256644, 42.45120395932879, 37.16376379558018, 34.7092535836356, 35.30233097076416, 34.32853399004255, 36.422022751399446, 36.02006251471383, 36.737401485443115, 37.67374767575945, 39.2058219909668, 39.491691725594656, 41.167941161564414, 38.194112164633616, 39.656384876796174, 39.814272267477854, 42.43458734239851, 42.003903252737864, 40.46391841343471, 45.16135229383196, 46.40741096224104, 48.20110927309309, 49.11063194274902, 49.13345330102103, 48.78959390095302, 49.088578360421316, 39.17703907830374, 31.06820297241211, 39.79900360107422, 49.72533907209124, 48.624181611197336, 48.84916080747332, 48.897746086120605, 46.88856676646641, 49.240504196711946, 43.01518923895699, 42.274757930210654, 40.76778745651245, 42.373210430145264, 41.29727145603725, 40.21117074148995, 39.88846165793282, 37.583497524261475, 39.937950202396934, 37.10997084208897, 36.123691422598704, 34.177049364362446, 34.71375254222325, 35.492419787815635, 34.59190198353359, 34.4141913822719, 35.557951722826274, 36.92930378232683, 38.96162755148751, 44.67785494668143, 47.44150441033499, 47.40724631718227, 49.7394369670323, 41.39616169248308, 40.98656191144671, 44.51641355242048, 49.420532022203716, 50.786242144448416, 51.235735007694785, 52.164274896894185, 49.613174302237375, 51.877606119428364, 53.718416690826416, 50.107156481061665, 49.27253539221627, 44.99858379364014, 40.480899810791016, 39.70172882080078, 39.57392018181937, 44.478486810411724, 45.238970620291575, 46.07447065625872, 46.553872040339876, 43.973915576934814, 43.92512880052839, 43.30529390062605, 43.72701481410435, 42.64101832253592, 41.7495505469186, 42.518132482256206, 44.02923713411604, 46.05076340266636, 45.1474107333592, 45.26962259837559, 49.04558638163975, 48.70935262952532, 60.519303049360005, 58.98313971928188, 73.45014381408691, 41.68838208062308, 0.8225520136100906, 0.3384422207517283, 0.19879382422992162, 33.3373178754534, 70.52206870487758, 55.59274884632656, 52.559290409088135, 33.14319562911987, 70.13615185873849, 67.08681678771973, 45.498190539223806, 49.57714441844395, 48.90068517412458, 3.4750898480415344, 0.20873851488743508, 0.017376184297193373, 0.07204068718211991, 0.09138833970895835, 0.04403571831062436, 0.0784312996215054, 0.02070661398049976, 0.052380470891616175, 0.1113280343956181, 0.027099187386089137, 0.030011267999985387, 0.040312803616481166, 0.3483249475913388, 31.191342421940394, 60.64214720044817, 51.515382630484446, 31.73308651787894, 37.67016935348511, 89.33706787654332, 34.566926683698384, 55.37778547831944, 53.179566519601, 72.28145681108747, 11.674431017466954, 0.07149585748889617, 0.48541103303432465, 0.018497409132708396, 0.11231338937899896, 38.28737088612148, 66.8466523034232, 55.84967238562447, 58.667858260018484, 50.25134549822126, 52.05259302684239, 51.10928821563721, 52.75342655181885, 52.63116257531302, 49.5261481148856, 49.00854900905064, 47.293671063014436, 44.36322314398629, 43.31674105780465, 40.4686918258667, 41.86469956806728, 40.84647927965437, 42.110398292541504, 42.797571659088135, 41.99486017227173, 42.56749248504639, 50.48933867045811, 50.661754744393484, 54.163705893925254, 51.999647753579275, 49.81901468549456, 43.22659512928554, 45.41904360907418, 44.35420438221523, 43.01965693065098, 56.633609839848106, 52.548298358917236, 52.80207436425345, 47.66370780127389, 44.99839966637747, 45.778348854609895, 50.25889471599034, 48.93308115005493, 49.329215322222026, 46.78933259419033, 41.68351834160941, 39.4657575743539, 37.10550315039498, 36.57386868340628, 37.175884928022114, 37.45300340652466, 35.642650263650076, 38.54923112051827, 39.659282275608604, 41.14974730355399, 42.07280158996582, 43.3333020891462, 42.962765080588206, 41.92498213904244, 42.5718629019601, 43.73240314211164, 43.77317517144339, 44.30052954810006, 46.56037902832031, 48.888039452689036, 49.105049065181184, 50.82601710728237, 50.92140545163836, 49.442408425467356, 50.99542808532715, 39.011790071214946, 30.524683611733572, 39.643179825374055, 50.18509789875576, 51.73828778948103, 50.2207213129316, 52.32284321103777, 49.62897103173392, 49.067233494349885, 46.158950328826904, 46.255276679992676, 43.62134313583374, 44.852827957698274, 42.97207914079939, 42.30320732934134, 41.77292081287929, 40.29052264349801, 42.016104289463584, 40.921141147613525, 37.28278643744332, 36.5926844051906, 37.072579111371724, 37.195478848048616, 36.26853009632656, 36.380621910095215, 37.16205453872681, 39.11449139458792, 40.673754010881694, 46.161618437085835, 50.58258696964809, 49.87550354003906, 51.15758514404297, 43.65609802518572, 44.387316022600444, 46.301204272678916, 49.98613623210362, 52.941066128867014, 54.149541991097585, 53.91353947775704, 51.531888076237266, 52.215347630637034, 55.87779521942139, 52.57366623197283, 51.088714599609375, 48.80230910437447, 41.14809710638863, 40.667736870901926, 42.79968738555908, 47.09301403590611, 47.330913407461985, 49.10707793916975, 49.91018894740513, 47.27145767211914, 47.31567253385271, 46.169671399252756, 46.093557357788086, 45.52389887401036, 43.32966123308454, 45.47665112359183, 46.55351768221174, 47.38843059539795, 48.60167987006051, 47.24187224251883, 53.250990527016775, 52.40315049035208, 64.56481524876186, 62.23146424974714, 77.33344336918422, 44.42272056852068, 0.7084237262606621, 0.3241066485643387, 0.10891941828387124, 37.143461159297395, 77.2900310243879, 60.5589633669172, 60.428886141095845, 43.55559580666678, 85.79243741716657, 63.08288260868618, 47.7020514351981, 62.37604236602783, 58.3903819492885, 6.169869201523917, 0.31772736087441444, 0.06516263554138796, 0.1041670132960592, 0.10761728244168417, 0.041345147149903436, 0.1414904562490327, 0.15838489255734853, 0.11824365652033261, 0.19919497413294657, 0.06771696704838957, 0.12638219552380697, 0.10811539499887399, 0.6036419059549059, 41.53913130078997, 70.12921755654472, 60.714498792375835, 55.475136688777376, 55.67976461138044, 95.56778158460344, 42.55611828395298, 65.50618498665946, 58.9165620803833, 81.16538878849575, 13.898803864206586, 0.18221071335886205, 1.7821332514286041, 0.25621957278677393, 0.22866866258638247, 42.37677485602242, 72.39205823625836, 58.973565101623535, 62.154471261160715, 52.65841688428606, 54.941587993076865, 53.9048090662275, 54.63400166375296, 54.6067647252764, 52.89410672869001, 51.34577710287911, 50.43922478812081, 47.546731403895784, 45.6533716065543, 42.80211925506592, 44.691848618643625, 42.962025097438264, 44.60656990323748, 46.19574104036604, 44.53713655471802, 43.735842500414165, 53.14960241317749, 54.56774711608887, 56.56007358006069, 54.48887116568429, 53.08970546722412, 44.3670585496085, 46.11171647480556, 47.533957140786306, 46.025367736816406, 58.45104667118618, 55.57890803473336, 54.22451305389404, 49.73145696095058, 46.95226090294974, 48.529561042785645, 53.82554749080113, 53.3778646332877, 53.1173141343253, 49.93633501870291, 45.79566029139927, 41.792198589869905, 38.26181888580322, 40.047714369637625, 37.29954201834542, 39.54466479165213, 37.98553419113159, 41.07845878601074, 42.79458393369402, 44.05090856552124, 44.10141849517822, 45.54335035596575, 45.21933848517281, 45.61346115384783, 46.80098819732666, 48.64786802019392, 47.38629402433123, 46.527649538857595, 48.88273797716413, 50.857193674360005, 51.30798585074288, 53.10160425731114, 53.62902464185442, 53.15709604535784, 54.54837901251656, 41.21832602364676, 31.939910071236746, 41.3161358152117, 54.52224336351667, 54.22559002467564, 53.93284852164132, 54.26617445264544, 51.7984869820731, 53.79092114312308, 46.72536400386265, 49.389351981026785, 46.27598925999233, 46.64466067722866, 45.03230340140206, 45.2365665435791, 44.789998871939524, 42.01057004928589, 45.20385789871216, 42.59270402363369, 41.35667507989066, 38.71979897362845, 40.20087003707886, 39.47004113878523, 38.829636096954346, 38.70578793116978, 40.05397817066738, 41.2730986731393, 41.88234799248831, 49.76738262176514, 52.97841269629342, 53.43947778429304, 52.04524878093174, 45.29739454814366, 45.88495853969029, 49.81348739351545, 53.18151548930577, 55.52836683818272, 54.84736347198486, 54.57716192517962, 51.083072662353516, 54.173627921513145, 60.75729969569615, 53.05537789208548, 52.88434450966971, 50.10934863771711, 43.224899768829346, 43.842139516557964, 44.291403089250835, 49.882218973977224, 49.6791752406529, 50.66600704193115, 52.380343028477256, 50.05880396706717, 49.727440902165, 48.56815481185913, 50.69247620446341, 49.20179230826241, 47.66482646124703, 48.551058769226074, 50.06118025098528, 51.46009234019688, 51.764260155814036, 51.14670426504952, 55.416070052555625, 55.90756825038365, 65.61996173858643, 65.79289545331682, 78.47776998792375, 51.21213892527989, 0.9118558530296598, 0.9442933010203498, 0.23714074226362364, 39.89975595474243, 85.58905669621059, 66.78750923701695, 65.73742798396519, 46.44812045778547, 83.6897040775844, 90.1293362208775, 64.18112877437046, 65.58617264883858, 76.01519639151437, 10.244905165263585, 0.3885287988398756, 0.14485278725624084, 0.19877155471060956, 0.21808453409799508, 0.1332361184592758], [0.0856102951137083, 0.1183660506669964, 0.04913805737825377, 0.022417292364739945, 0.053047633663352044, 0.014574141707271338, 0.056252062786370516, 0.7458911814859935, 32.20563350405012, 51.95982762745449, 40.20450741904122, 39.55611194883074, 63.1283655166626, 82.36951855250767, 34.096217496054514, 51.479040077754426, 52.344472953251426, 64.24592767442975, 21.222240788596018, 0.1000531165461455, 0.3803515290575368, 0.04660140510116305, 0.2710543567580836, 21.44556631360735, 70.27638735089982, 51.60534790584019, 57.250217301504954, 42.561600412641255, 44.08956834248134, 41.44090461730957, 44.28006362915039, 40.854733739580425, 43.42542478016445, 39.0757725579398, 40.88865484510149, 38.57949052538191, 40.32834168842861, 38.893913882119314, 42.12237351281302, 39.93236037663051, 42.375267096928184, 38.22208213806152, 41.92895303453718, 43.14065980911255, 49.816044330596924, 48.00828633989607, 51.249231883457725, 45.980895791734966, 47.15023939950125, 47.897653647831504, 49.79575211661202, 47.3368193762643, 50.10993576049805, 51.13603183201381, 54.66619961602347, 50.3427768434797, 43.54334613255092, 44.36069399969918, 45.39951917103359, 47.84282193865095, 43.329105377197266, 44.78028876440865, 45.91259152548653, 42.648567540305, 39.73695271355765, 34.977342878069194, 37.42981379372733, 33.91966029575893, 35.238793168749126, 34.888829776218955, 36.272111892700195, 36.10659190586635, 36.52053778512137, 39.26443004608154, 38.891815526144846, 42.278336252485005, 40.648045676095144, 40.280770846775596, 40.090334619794575, 41.41407067435128, 42.68400682721819, 44.96315492902483, 48.47118575232369, 47.30142872674124, 49.9720070702689, 48.11364187513079, 48.0523031779698, 50.65130812781197, 37.481442383357454, 31.86590133394514, 42.90851354598999, 49.72504377365112, 49.80755015781948, 46.136097703661235, 46.73091908863613, 47.370837756565635, 48.123508317129954, 44.171831539699006, 40.97297818320138, 42.77650472096035, 41.77243096487862, 39.89507981709072, 40.49641861234392, 38.47943646567208, 38.22587585449219, 38.31717865807669, 36.55392387935093, 35.03219543184553, 33.73439700262887, 34.681637968335835, 35.498054776872905, 34.40903581891741, 36.005988938467844, 35.79778616768973, 36.19996527263096, 40.23026091711861, 43.7599527495248, 45.49626588821411, 45.63681057521275, 49.95914942877633, 44.42374542781285, 44.58737203053066, 43.079814434051514, 46.084097385406494, 51.981707504817415, 52.49827132906233, 49.87683412006923, 54.06250538144793, 21.61772530419486, 32.163756711142405, 53.882665157318115, 48.42580359322684, 51.46943071910313, 43.16572543552944, 41.092619214739116, 40.116042954581125, 43.66877848761422, 44.12259660448347, 49.75894056047712, 47.960100582667756, 45.854153701237266, 44.71685518537249, 44.316315855298726, 44.39878749847412, 42.216538974217, 41.910116468157085, 40.84237289428711, 43.61553791591099, 44.615390641348704, 45.992850167410715, 44.94123683656965, 52.6742205619812, 56.507802282060894, 64.79439067840576, 59.45292132241385, 78.34627532958984, 18.151182174682617, 1.3179753465311868, 0.6540390902331897, 0.017000679625198245, 45.54393400464739, 65.60023580278668, 59.231489181518555, 58.63453469957624, 31.201271397726877, 43.64094400405884, 41.39956283569336, 42.662144320351736, 49.87676811218262, 53.69550500597273, 10.423406992639814, 0.14127416642648832, 0.030409530736505985, 0.02407564891369215, 0.01411144104453602, 0.073858699628285, 0.034970442964030166, 0.014371638019968356, 0.02663818221273167, 0.0279387523353632, 0.020391059573739767, 0.0791135597974062, 0.008744541173135596, 0.9097383352262634, 41.47981800351824, 61.86677415030343, 47.437245164598735, 45.20081806182861, 59.12383379255022, 86.16029589516776, 38.57676683153425, 54.536497592926025, 57.525671686444966, 67.73392336709159, 23.76682918412345, 0.13864751665719918, 0.589800877230508, 0.3236483388713428, 0.23702465849263327, 23.227381467819214, 71.69960076468331, 53.595044476645334, 60.076598576136995, 43.18700081961495, 45.65434088025774, 43.10588754926409, 46.59921251024519, 41.81285905838013, 46.719656058720176, 42.480855396815706, 43.0802834374564, 40.20035587038313, 41.206034660339355, 41.33147396360125, 44.22435644694737, 42.83087090083531, 44.09184387751988, 40.4072766985212, 44.58952597209385, 44.592239243643625, 53.21059717450823, 49.81914322716849, 53.69091919490269, 47.01906783240182, 48.65913799830845, 48.800443513052805, 51.9034812109811, 49.4708126613072, 52.422000953129356, 52.154411928994314, 55.587489059993196, 51.987856660570415, 45.940832478659495, 45.46426248550415, 46.90063926151821, 51.03842006410871, 47.030379499707905, 48.79334592819214, 47.43598059245518, 44.76504789079939, 41.67677858897618, 36.522782053266255, 38.06356940950666, 36.0232378414699, 37.17670828955514, 37.5765562738691, 38.26796804155622, 38.16456495012556, 39.013426371983115, 41.67433977127075, 40.42461592810494, 42.56124952861241, 42.35223381859915, 41.325887611934114, 41.113474232809885, 44.6941727910723, 45.67402512686593, 45.05515602656773, 49.83626011439732, 49.17994369779314, 50.25456946236746, 51.31452063151768, 50.40507091794695, 52.80305058615548, 39.741239752088276, 31.847704001835414, 43.23652063097273, 51.184311389923096, 51.20131015777588, 49.02624954496111, 49.13600328990391, 49.56876489094326, 47.8593100139073, 47.67709697995867, 42.90139511653355, 44.17066771643502, 44.930091926029746, 40.99988855634417, 42.02340684618269, 41.01786354609898, 39.72927495411464, 40.65661627905709, 39.188413279397146, 36.39342049189976, 36.047810145786826, 36.62939868654524, 38.248888288225444, 36.037759576525005, 38.26202385766165, 37.89876856122698, 38.090754236493794, 41.08892624718802, 45.6210173198155, 50.1121244430542, 49.05574117388044, 52.54391404560634, 47.58981718335833, 46.00689942496163, 45.28525257110596, 44.697619097573416, 52.049400329589844, 54.24205725533621, 51.981287138802664, 55.93455852781023, 21.369540861674718, 34.63271222795759, 56.786008153642925, 49.20604460580008, 53.37731225149972, 44.73236009052822, 43.36250189372471, 41.38327278409685, 46.08505971091134, 46.41686398642403, 52.58398083278111, 52.52978835787092, 48.10958065305437, 47.49871587753296, 45.75889389855521, 45.42081887381417, 43.92182493209839, 45.6654371534075, 43.89329562868391, 47.27973992483956, 47.45276744025094, 49.036793436322895, 48.52276223046439, 55.10267502920968, 60.336676597595215, 67.32236071995327, 63.78153092520577, 80.73546205248151, 18.043664012636455, 1.211196733372552, 1.3248762105192458, 0.05042852581079517, 50.58433444159371, 69.758378301348, 65.80419322422573, 65.33980342320034, 39.20706224441528, 51.67357574190412, 50.05612543651036, 47.688950606754844, 59.80683476584298, 65.79839842660087, 13.598117964608328, 0.28897072108728544, 0.08622496641640152, 0.040358407955084524, 0.03608586632513574, 0.02558494997876031, 0.18316413648426533, 0.16641230109546865, 0.08978569427771227, 0.13914733912263597, 0.12154866488916533, 0.1394865523491587, 0.19302728080323764, 1.456018682037081, 52.47550555637905, 71.52035113743374, 56.02134152821132, 51.94793231146676, 69.50716618129185, 88.826507295881, 46.20064994267055, 65.5591858455113, 64.39696066720145, 76.64032581874302, 27.68214430127825, 0.2074128067387002, 1.2568443353687013, 0.7234592480318887, 0.3907228825347764, 25.470550060272217, 75.30328396388462, 57.882388728005544, 63.301153319222585, 45.64931385857718, 47.91689320972988, 44.61373002188546, 49.67291838782174, 45.38842289788382, 49.43472024372646, 45.2215758051191, 45.9877085004534, 43.35176692690168, 44.844358103615896, 42.32239130565098, 46.25132315499442, 44.11883762904576, 47.53236252920968, 42.07906886509487, 47.38947977338518, 47.56986195700509, 56.28585250037057, 51.71178388595581, 55.96951144082205, 50.24360867909023, 49.723998069763184, 50.157756737300325, 54.279789447784424, 50.62291431427002, 54.622471128191265, 52.433569703783306, 58.426234654017854, 55.23046282359532, 49.17725474493844, 48.59536395754133, 49.6220714705331, 54.95699214935303, 51.36317886625017, 53.64486306054251, 51.64347267150879, 49.47283111299787, 43.9750794001988, 38.17118658338274, 42.37344666889736, 37.655331475394114, 39.716719559260774, 39.370317118508474, 41.459894044058665, 39.96263367789132, 41.801863534109934, 43.19066946847098, 43.42231893539429, 44.83947352000645, 44.58525630405971, 45.638307912009104, 44.636853626796174, 47.025824955531526, 48.48622860227312, 48.748769760131836, 52.40181991032192, 53.902172224862234, 54.91953788484846, 54.87512499945504, 52.118868419102256, 55.712240491594585, 41.79721171515328, 33.49748427527291, 44.70696095057896, 52.94323396682739, 55.405025890895296, 49.45526259286063, 51.199006829942974, 51.410377979278564, 51.2122848374503, 50.35590199061802, 46.98105076381138, 46.67770978382656, 47.31950099127633, 45.15374401637486, 45.361269337790354, 43.57438720975603, 43.0838165964399, 43.70839016778128, 41.22799791608538, 37.64697279248919, 38.46334096363613, 39.857750620160786, 39.60328674316406, 37.89772285733904, 41.08735942840576, 39.662843227386475, 41.1035487311227, 44.03116178512573, 49.11629819869995, 54.298570428575786, 52.04348046439034, 55.733363015311106, 48.901765619005474, 48.04295785086495, 47.38841322490147, 48.66513776779175, 55.404150417872835, 57.410352434430806, 54.503500597817556, 56.758541924612864, 22.748033932277135, 35.01378270557949, 57.1219778742109, 51.97529779161726, 57.39870377949306, 46.17563990184239, 45.48264047077724, 44.56865358352661, 47.98277255467006, 48.4142278943743, 56.02536106109619, 54.08065060206822, 49.62371471949986, 49.30893700463431, 47.591529914310996, 49.13565935407366, 47.38839585440499, 47.644190311431885, 45.68763664790562, 49.62410381862095, 49.41712045669556, 52.41522298540388, 50.40412596293858, 58.29035568237305, 63.85780824933733, 70.53519385201591, 65.8534073148455, 84.0795397077288, 22.188182830810547, 1.1380373047930854, 3.0654852901186262, 0.19664461884115422, 55.60106931413923, 76.54558713095528, 72.86175646100725, 72.60875865391323, 46.53632436479841, 57.49711111613682, 46.19971193586077, 60.528717858450754, 65.9263425554548, 80.94910526275635, 17.64733702795846, 0.4594884440302849, 0.21568226228867257, 0.14767238524343285, 0.17078760346131666, 0.16520176748079912], [0.05091372923925519, 0.027311840260933553, 0.07379850000143051, 0.059184287408632894, 0.07543405438108103, 0.02132433360176427, 0.09630322669233594, 0.4451199493237904, 21.251803636550903, 50.66375582558768, 47.78343221119472, 25.241605179650442, 50.497523648398264, 66.6843284879412, 25.69888871056693, 54.972656863076345, 52.19894640786307, 65.62586770738874, 31.214653628213064, 0.06980749272874423, 0.07975504680403642, 0.177754706037896, 0.41014578459518297, 6.522630112511771, 68.16583033970424, 54.78929042816162, 57.64233194078718, 51.88112538201468, 49.181309018816265, 45.80249384471348, 46.60506289345877, 45.52921077183315, 44.75659193311419, 41.21496656962803, 40.7461507661002, 41.70875072479248, 39.08873789651053, 42.42190340587071, 45.93197005135672, 41.83328676223755, 42.1647436278207, 38.596638679504395, 40.35955647059849, 45.098877566201345, 50.33508518763951, 50.808090754917686, 47.881860392434255, 45.499166761125835, 51.76832137789045, 52.44625016621181, 51.83940839767456, 47.81705454417637, 52.60867820467268, 50.37992538724627, 51.70944929122925, 46.50517906461443, 44.017717020852224, 44.02327210562569, 46.72319964000157, 46.099473748888286, 42.42341463906424, 43.153784956250874, 45.1707740511213, 40.778022153036936, 42.18198905672346, 39.177282265254426, 36.33107083184378, 36.21283333642142, 33.9134520803179, 35.22231898988996, 33.343658106667654, 35.33414677211216, 36.40886981146676, 39.234966209956575, 38.55713469641549, 41.34272657121931, 41.63054527555193, 40.17472049168178, 42.1609707559858, 42.479337215423584, 44.19040754863194, 44.218488693237305, 43.10955619812012, 45.008227893284385, 49.93888848168509, 47.43965966360909, 47.90777717317854, 49.417050974709646, 41.574372564043315, 31.920986652374268, 43.37094048091343, 48.61178255081177, 47.12275232587542, 50.3013482093811, 48.75221954073225, 48.16573599406651, 44.853661741529194, 42.06482853208269, 41.607953207833425, 42.84420101983206, 38.6805659702846, 38.328723090035574, 40.41016714913504, 40.89024945667812, 39.356375558035715, 38.17482049124581, 36.498925413404194, 33.20761237825666, 33.459484577178955, 35.278161661965505, 35.12987668173653, 33.299384185246055, 36.446966784340994, 34.15859147480556, 37.820180961063926, 41.65751123428345, 43.366698605673655, 44.44433988843645, 44.74432141440255, 48.66329302106585, 46.86194821766445, 42.47707905088152, 46.29011147362845, 43.6689487184797, 48.23487751824515, 51.32754155567714, 53.31704010282244, 45.923389026096885, 16.91786997658866, 40.46130241666521, 51.01592179707119, 51.42514637538365, 51.41425159999302, 47.86674806049892, 44.38617999213082, 39.08025762013027, 40.386675289699006, 44.72210454940796, 47.286726338522776, 51.20810202189854, 51.376738275800435, 47.640855176108225, 43.31904091153826, 46.15438188825335, 42.87838963099888, 42.042722838265554, 41.482746669224326, 45.21519388471331, 45.3055100440979, 47.32657773154122, 48.24018941606794, 57.721638679504395, 61.65004593985421, 66.6699526650565, 65.88257585253034, 66.04307229178292, 1.2366852228130614, 0.8210779098527772, 0.07625645917973348, 0.6484177261590958, 55.47518185206822, 57.65724972316197, 62.648717471531455, 50.126708711896626, 33.81608697346279, 43.45862327303205, 18.555530854633876, 36.62675142288208, 55.04272944586617, 57.04428311756679, 9.422321830477033, 0.47677317368132727, 0.060797626551772864, 0.08069736909653459, 0.05395434983074665, 0.0413863308328603, 0.06115328746714762, 0.018504618567281535, 0.06252768050347056, 0.015624520701489278, 0.08817181909190756, 0.013046539704581457, 0.08307200417454753, 0.3603893002229077, 30.577819960457937, 60.664833068847656, 51.84957708631243, 34.89832101549421, 69.83680261884416, 73.71968528202602, 34.51200464793614, 61.85171045575823, 57.901041167122976, 71.05848353249687, 34.888916628701345, 0.013117980112188628, 0.09692217276564666, 0.4269516042300633, 0.5456347614526749, 7.169140883854457, 70.62445041111538, 55.29055084500994, 62.47001675197056, 54.04112230028425, 52.109658581869944, 48.37536661965506, 49.117517607552664, 47.42957435335432, 46.26178714207241, 42.656029905591694, 42.006689480372835, 43.16427673612322, 40.387078285217285, 44.97465072359358, 45.84584712982178, 44.46461820602417, 43.86914021628243, 40.61999927248274, 42.52443102427891, 47.60232741492135, 53.10352543422154, 53.341167722429546, 50.87639502116612, 47.65613079071045, 55.057654176439556, 53.38010195323399, 54.83641311100551, 49.409744943891255, 55.27442407608032, 52.82652507509504, 55.66593074798584, 47.45114850997925, 45.59836966650826, 45.2742292540414, 49.18022857393537, 48.1585967200143, 44.652334213256836, 47.767809186662944, 46.762891224452424, 43.76668207986014, 44.945690631866455, 42.532973834446494, 37.805773871285574, 36.883469990321565, 35.865586689540315, 37.914704254695344, 37.26773663929531, 37.82376970563616, 38.51129743031093, 39.96561445508684, 41.258351121629985, 43.96687010356358, 42.696763719831196, 42.1629753112793, 44.06651074545724, 44.24921710150582, 45.46592310496739, 46.96859959193638, 46.76144599914551, 47.98170600618635, 50.63946144921439, 49.10175909314837, 51.18249791009085, 50.65932634898594, 42.87633991241455, 31.328440802437918, 45.56291995729719, 52.04801763807024, 50.92094687053135, 50.82962669645037, 50.04689475468227, 50.07418033054897, 46.91965300696236, 44.984656129564556, 44.68624837057931, 44.87177916935512, 42.024028709956575, 42.03790773664202, 41.86955288478306, 41.400066580091206, 43.07627780096871, 38.31554235730852, 38.98206567764282, 36.25699608666556, 35.47373955590384, 38.18539564950125, 37.37783432006836, 35.90092175347464, 37.253850664411274, 37.3616623878479, 39.34653343473162, 42.0924927847726, 47.112562792641775, 47.02251761300223, 47.79629332678658, 49.55931534085955, 49.374010358537944, 44.90193782533918, 49.22068793433053, 46.612980365753174, 50.56253446851458, 52.94600977216448, 55.21563536780221, 46.92327649252755, 24.31842929976327, 45.72673763547625, 51.70998082842146, 54.512477670397075, 53.37716286523001, 51.512561661856516, 46.44160999570574, 40.64543662752424, 43.673242705208914, 48.16694498062134, 50.76706164223807, 54.98667137963431, 53.71645729882376, 50.63977064405169, 46.12711715698242, 48.32640961238316, 44.39990963254656, 44.45887899398804, 43.005826541355674, 48.51070015771048, 48.07708740234375, 51.35165180478777, 50.12683377947126, 61.5200868334089, 64.40570844922746, 70.99927793230329, 67.865647315979, 68.34303719656808, 1.4427669474056788, 0.9357522279024124, 0.02765997452661395, 0.9035038469093186, 61.50116688864571, 64.5217433656965, 68.93199430193219, 55.52546943937029, 36.37605346952166, 47.96182026181902, 25.156903164727346, 47.74443892070225, 57.37962402616228, 71.2903379712786, 15.566059725625173, 0.5469705526317868, 0.10442393379552023, 0.06377093307673931, 0.058058767446449826, 0.0757157074819718, 0.1789999535041196, 0.11148138330983264, 0.19335600387837204, 0.15507516158478601, 0.15158123549606117, 0.13836542250854628, 0.26793176574366434, 0.5859090717775481, 44.12179061344692, 72.72342477525983, 65.19491263798305, 36.950631277901785, 58.01783343723842, 76.37532152448381, 40.49566125869751, 67.7564285823277, 63.60246195111956, 77.12065478733608, 40.62630476270403, 0.14456842680062565, 0.44650448645864216, 1.1888703256845474, 0.5582272314599582, 8.134139708110265, 74.51261370522636, 57.79310785021101, 65.23034150259835, 56.75976480756487, 54.49137599127633, 50.74078355516706, 53.464658055986675, 50.529766763959614, 48.995434284210205, 45.965578487941194, 44.58779239654541, 45.3478558404105, 43.34356457846505, 47.45992061070034, 50.448980058942524, 46.49353040967669, 47.34432690484183, 41.53223521368844, 44.20485632760184, 49.6930125781468, 55.23336022240775, 55.970824650355745, 53.47197103500366, 46.515274797167095, 55.33005830219814, 54.88158335004534, 55.47262144088745, 52.61715153285435, 58.04354177202497, 53.17017602920532, 56.16434587751116, 51.9063195501055, 47.23099136352539, 49.025353227342876, 52.60830647604806, 52.501596042088096, 49.013812269483296, 51.98772464479719, 53.051042216164724, 46.647033487047466, 49.96226569584438, 44.068001134055, 40.905379159109934, 40.740234375, 36.44484410967146, 38.314249992370605, 38.62072113582066, 39.50225993565151, 40.7445387840271, 42.58630820683071, 42.91492325919015, 45.838787760053364, 46.60182155881609, 44.442908559526714, 46.327034200940815, 46.7874287877764, 49.033739703042166, 48.696529729025706, 48.18357201984951, 51.17278780255999, 53.70025757380894, 52.387187004089355, 53.26163516725813, 52.86754376547677, 44.371290002550396, 31.54097577503749, 47.28987039838518, 53.53530386516026, 53.26845135007586, 54.25319869177682, 54.46055378232683, 52.51006589617048, 49.112389836992534, 46.02389471871512, 47.59695298331124, 47.04903541292463, 44.633587973458425, 43.64216341291155, 45.691809041159495, 45.82170213971819, 45.699886322021484, 40.877878189086914, 41.28165537970406, 37.41519825799124, 37.80387006487165, 41.54908806937081, 39.75762013026646, 37.85941743850708, 41.23926789419991, 38.105717182159424, 42.717743805476594, 45.60193756648472, 50.833250182015554, 51.44620289121355, 51.821197169167654, 54.54683303833008, 50.67168719427926, 46.85847411836897, 50.192539419446675, 49.94129950659615, 52.567110606602256, 53.950820037296836, 56.039882796151296, 49.557793685368125, 21.09578357424055, 41.62734563010079, 55.034534045628135, 56.00420727048601, 56.69388893672398, 52.64994008200509, 49.63618326187134, 42.881769929613384, 47.03069216864449, 49.547666685921804, 52.4712358883449, 59.044540950230186, 55.276671818324495, 53.72464575086321, 47.12354094641549, 52.561649322509766, 48.24295479910714, 47.34379536764962, 46.85341582979475, 52.13969217027937, 51.94033793040684, 53.910826206207275, 53.201700006212505, 64.88454355512346, 66.78957980019706, 72.8220614024571, 70.46145956856864, 73.6859587260655, 2.968661491359983, 1.3962792647736413, 0.256087421306542, 1.197495971407209, 66.6344404220581, 70.34138774871826, 73.65049512045724, 61.26008524213518, 45.127768175942556, 61.685843058994834, 28.1854179586683, 51.635089669908794, 72.85667037963867, 82.34007208687919, 24.123933587755474, 0.8098968469670841, 0.323576631290572, 0.20978904994470732, 0.1891467526022877, 0.20873828418552876], [0.04677284375897475, 0.024971198091017346, 0.0437047594626035, 0.05057395961401718, 0.059199832645910125, 0.13474887157125132, 0.14261189821575368, 0.5753029180424554, 27.34252851349967, 54.03981256484985, 57.32774530138288, 42.914614064352854, 12.229780554771423, 28.665368250438146, 31.205266611916677, 42.67920562199184, 60.02212469918387, 55.3798907824925, 54.834193161555696, 0.9077564158609935, 0.09276200671281133, 0.06191906851849385, 0.15935415269008704, 0.14230411473129476, 46.13733795710972, 68.1515726361956, 52.008023806980674, 56.8853291784014, 55.863874503544395, 54.8700840813773, 50.30585759026663, 50.743569782802034, 45.64718076160976, 42.9420177595956, 40.29173163005284, 38.5040956224714, 41.45673261369978, 44.32820422308785, 44.09866006033761, 45.50545140675136, 41.89316981179373, 39.28479521615164, 41.833213806152344, 48.8692306791033, 51.26375709261213, 49.11753497804914, 46.537741797310964, 49.388580730983186, 53.22622019904, 51.87485115868704, 51.40652172906058, 54.58092437471662, 50.91935225895473, 52.14622695105416, 50.32628876822335, 45.25319010870797, 44.28321116311209, 44.04598576681954, 47.330663272312705, 43.55106905528477, 43.544770513262065, 43.41474887302944, 44.5846518107823, 40.82222311837332, 40.175561223711284, 45.37345995221819, 37.59971114567348, 34.542024339948384, 33.89729404449463, 35.569287708827424, 36.31292561122349, 36.45304993220738, 34.607643127441406, 38.205979687826975, 39.67501299721854, 40.16010843004499, 39.053524426051546, 39.41690131596157, 41.5240398134504, 42.21144247055054, 42.67801400593349, 46.12026970727103, 42.971439906529014, 43.90793548311506, 45.74538312639509, 46.509924684252056, 48.188123089926584, 48.86187948499407, 44.54185438156128, 34.31649276188442, 47.182520730154856, 50.97374275752476, 50.020050389426096, 49.81547457831246, 46.58846364702497, 47.05101217542376, 42.453757422310964, 43.56014340264456, 42.761239528656006, 42.86740452902657, 41.3846242087228, 42.42067704881941, 41.65615633555821, 39.279274872371126, 40.43737629481724, 37.59678942816598, 34.85754551206316, 34.84753663199288, 33.82351459775652, 36.17609821047102, 34.314672333853586, 34.687210423605784, 34.56504372188023, 36.77183328356062, 40.75177880695888, 38.84596783774239, 46.29211950302124, 44.01870019095284, 44.80199146270752, 44.9842392376491, 50.16994040352957, 46.525377477918354, 44.7910133089338, 43.22605316979544, 49.992684909275596, 52.68931204932076, 50.32391595840454, 51.552673612322124, 43.20855065754482, 39.89787299292428, 43.21858038221087, 51.70661442620413, 51.47465229034424, 51.89673798424857, 47.22771528788975, 42.42165674482073, 42.56739173616682, 44.86563001360212, 49.573076248168945, 52.71867513656616, 54.12067570005144, 50.93138306481497, 49.142746516636436, 47.721770422799246, 46.92365516935076, 44.524407454899375, 42.87044784000942, 44.95866639273507, 45.45510128566197, 45.564604895455496, 51.17018917628697, 59.897772789001465, 63.40104757036482, 65.25153350830078, 73.49316705976213, 29.200231892721995, 0.8187105283141136, 0.31491529462592943, 0.3029279964310782, 4.893482080527714, 63.826186997549875, 58.06920146942139, 66.1837385722569, 51.45850120271955, 31.537362711770193, 51.18016331536429, 29.314366476876394, 29.29625599724906, 48.495963028499055, 56.47146667752947, 22.56385976927621, 0.383689812783684, 0.02476010754305337, 0.04684604750946164, 0.04268328945285507, 0.03205433015578559, 0.06310753617435694, 0.06183239924056189, 0.022917591501027346, 0.03946170357189008, 0.048848400956818035, 0.022812289651483297, 0.18339698256126472, 0.6185421549848148, 38.48616579600743, 59.961126463753835, 65.46898433140346, 41.613087926592144, 18.841445752552577, 39.087629658835276, 38.76123455592564, 50.461403438023154, 65.82669149126325, 61.709237643650596, 57.03291933877127, 1.1782602093049457, 0.2733389841658728, 0.30901043862104416, 0.14291752395885332, 0.178821023819702, 48.74889830180577, 68.98901121956962, 57.70120055334908, 60.29129096439907, 58.21233088629586, 58.353820528302876, 53.20714044570923, 52.70995167323521, 46.105998107365195, 45.93815394810268, 42.12825863701956, 41.79192066192627, 44.088112694876536, 46.66730833053589, 44.88780171530587, 46.209029470171245, 42.817457403455464, 43.45396103177752, 41.73562288284302, 51.97689240319388, 53.31943028313773, 51.071719305855886, 50.033401353018625, 51.45900494711739, 55.39349882943289, 53.34892191205706, 53.032212597983225, 55.323554788317, 51.76099797657558, 53.39930330004011, 51.50171899795532, 47.82305431365967, 47.37812989098685, 46.34224728175572, 49.86338240759713, 48.39610351834978, 45.5489957673209, 47.24779905591692, 48.916266509464805, 42.53521810259138, 43.56587219238281, 45.75156354904175, 39.46692139761788, 36.71378108433315, 38.75699268068586, 37.32640027999878, 37.664704595293315, 38.43777854101998, 37.49717310496739, 40.65597357068743, 40.92321865899222, 41.006214891161235, 40.15439701080322, 41.86676318304879, 41.92366892950875, 43.317793709891184, 45.2499418258667, 47.397157532828196, 46.02535036631993, 46.3691611289978, 48.445946420942036, 48.76842621394566, 48.637994629996165, 51.14985179901123, 44.88894469397408, 33.40977716445923, 47.300435134342735, 52.33136517660958, 50.28801809038435, 49.82521595273699, 49.519026211329866, 50.081086839948384, 46.10752323695591, 46.760723386492046, 44.51472861426217, 44.65590558733259, 44.162142276763916, 43.217260224478586, 42.10766765049526, 42.652889319828574, 40.89517225537981, 40.493948527744834, 36.552648884909495, 35.968565940856934, 34.90476546968733, 37.56387233734131, 37.06880276543753, 36.74875831604004, 36.334718636104036, 38.730179582323345, 41.59698895045689, 41.72039590563093, 48.006226199013845, 46.968415464673726, 47.24254969188145, 48.4608086177281, 52.80205699375698, 48.266971247536794, 48.396895612989155, 43.27723012651716, 51.119766099112375, 53.23508610044207, 53.93512405667986, 55.87799324308123, 53.40397596359253, 37.50239815030779, 42.42943525314331, 53.323623520987375, 53.4037675176348, 54.58461734226772, 49.119233812604634, 45.184031214032856, 44.83238288334438, 47.30871043886457, 52.69492966788155, 54.49932125636509, 56.84193420410156, 55.60533550807408, 51.68536336081368, 49.07057557787214, 49.793202127729145, 47.330166476113455, 46.664817401341026, 48.93778508050101, 49.359332289014546, 48.44895151683262, 53.566035747528076, 62.385033335004536, 66.79447828020368, 68.02838802337646, 74.67781407492501, 28.99052483694894, 0.9072755788053785, 1.0909301468304224, 0.3112677074968815, 5.388077872140067, 68.71391119275773, 64.0728827885219, 72.94308512551444, 54.018589292253765, 27.468547991343907, 56.34273392813546, 32.01131323405674, 35.18905796323504, 56.89159297943115, 66.07289396013532, 27.39165575163705, 0.4369198264820235, 0.062404553538986614, 0.08898676000535488, 0.03170678112655878, 0.0384933764248022, 0.13186342854584965, 0.12656659420047486, 0.10806478985718318, 0.11522181438548224, 0.16304763592779636, 0.20951880301748002, 0.24914766369121416, 0.5350138427955764, 52.01827587400164, 71.95890753609794, 71.77955368586949, 59.31936999729702, 21.98585649899074, 39.203254631587434, 47.62354026521955, 52.314734663282124, 70.36822863987514, 65.73324516841343, 65.67112132481166, 1.3664942915950502, 0.48079987189599444, 0.9832044073513576, 0.25766683369874954, 0.2896526759224278, 51.257594040461946, 72.26955454690116, 59.61174324580601, 62.67616980416434, 61.64030456542969, 60.39510399954659, 55.138510363442556, 56.46832956586565, 50.98476260049002, 46.93628004619053, 44.541249888283865, 43.28133998598371, 47.667438983917236, 50.06390741893223, 47.8010493687221, 49.039242676326204, 46.094773292541504, 45.277206557137625, 45.339101110185894, 53.83955158506121, 56.166117668151855, 52.308613300323486, 51.75187151772635, 50.97318342753819, 59.05401829310826, 55.64019462040493, 56.563731806618826, 57.49354321616036, 54.09421695981707, 56.71029363359724, 55.02991349356515, 50.947985785348074, 50.86331851141793, 50.06850365230015, 52.74150344303676, 51.9438294001988, 50.479506969451904, 52.44085489000593, 53.51146806989397, 45.81007432937622, 46.11637871606009, 50.593040534428184, 41.84314625603812, 38.03736775262015, 40.56884316035679, 39.787921224321636, 40.10855974469866, 39.29341098240444, 38.745778288160054, 42.79893698011126, 43.81091431209019, 44.75805105481829, 43.98103748049055, 44.37876279013497, 44.04869556427002, 47.29982021876744, 48.02588612692696, 52.22538430350167, 49.42552777699062, 48.13459069388253, 50.02526501246861, 50.828268323625835, 51.774317673274446, 54.546787875039236, 46.950860840933665, 34.83927869796753, 49.046069281441824, 57.20318841934204, 53.161681856427876, 53.34549992425101, 52.31439767565046, 54.049039772578645, 49.0543098449707, 49.43209729875837, 48.03201443808419, 47.76177815028599, 47.23848499570574, 47.318830490112305, 48.10553332737514, 45.48972068514143, 44.769949844905305, 41.72382831573486, 40.49682855606079, 39.50173882075718, 37.72223915372576, 40.176325525556294, 38.46285111563546, 38.8464264188494, 39.89397505351475, 39.99041952405657, 46.19446952002389, 43.8560220173427, 51.713784967150005, 50.20400742122105, 51.19170427322388, 53.3884710584368, 55.40580756323678, 51.3533228465489, 49.8926933833531, 46.6298679624285, 53.08046783719744, 54.75523730686733, 54.03956242970058, 56.31899193355015, 39.9585724558149, 36.98033135277884, 43.457483768463135, 54.550275870731895, 55.19557591847011, 57.08273097446987, 50.79191187449864, 48.137331758226665, 47.94022873469761, 50.07650102887835, 53.94149555478777, 58.3804668698992, 60.7500388281686, 56.441895144326345, 54.31080273219517, 52.27945865903582, 51.8059458732605, 50.889725140162874, 48.78824247632708, 52.3104476247515, 51.35144683292934, 51.54264388765608, 56.282138688223704, 66.40413543156215, 72.51718834468296, 70.82999897003174, 79.28749220711845, 34.26978349685669, 0.7609269746712276, 2.521066354853766, 0.3490765472607953, 6.233639333929334, 76.00787993839809, 71.1612126486642, 78.52658803122384, 65.84185246058873, 40.10970967156546, 68.80030509403774, 39.79630422592163, 42.414955207279746, 65.71080248696464, 81.52001094818115, 36.93490055629185, 0.5379070618322918, 0.24917312232511385, 0.21761987331722463, 0.1299798424754824, 0.15372578613460064], [0.029043062989200865, 0.05699181862707649, 0.022736904410911456, 0.06327090026544673, 0.10719669251037495, 0.03547727808888469, 0.2511620984545776, 0.33011542899268015, 28.209194694246563, 58.41457557678223, 40.08119773864746, 46.48407391139439, 31.563856192997523, 27.400250673294067, 36.86310134615217, 46.959153515951975, 63.50431864602225, 48.953981331416536, 66.49276665278843, 7.486173289162772, 0.22039284237793513, 1.2642719596624374, 0.05820292899651187, 0.1103080062727843, 12.61638787814549, 76.89771488734654, 49.389414514814106, 58.58056109292166, 56.691286836351665, 57.91552816118513, 50.724569933755056, 52.02433122907366, 45.20601531437465, 44.28852653503418, 42.09442090988159, 43.16282108851841, 44.62554890768868, 46.9594418661935, 46.56286300931658, 44.92178882871355, 40.61597279139927, 40.011114733559744, 43.412841592516216, 49.46114771706717, 50.83662700653076, 52.14014032908848, 49.703118732997346, 54.685699735369, 52.67830262865339, 53.235725334712434, 50.505208356039866, 49.71458673477173, 49.755522046770366, 50.3508471761431, 45.495254925319124, 44.963012490953716, 43.39994921003069, 44.07930932726179, 43.21773965018136, 41.73973969050816, 43.327413490840364, 42.52827337809971, 42.25667176927839, 39.080528599875315, 40.243966238839285, 39.78020524978638, 39.57340601512364, 36.50680467060634, 35.08719389779227, 36.647662026541575, 36.40131711959839, 35.364503451756065, 34.75804383414132, 38.90474612372262, 38.83820669991629, 37.27165194920131, 38.41092722756522, 38.38180037907192, 39.56980684825352, 39.53627831595284, 43.885266985212056, 45.457474095480784, 43.59601695196969, 43.96607106072562, 46.057746342250276, 47.30107436861311, 45.79320410319737, 49.940531730651855, 46.28888859067644, 36.06736585072109, 51.733371938977925, 50.4114875793457, 49.22798701695034, 48.79469387871878, 47.933593205043245, 43.61114318030221, 45.5788973399571, 45.433377742767334, 43.23247677939278, 42.44646528788975, 41.589269501822336, 39.935209138052805, 37.424745082855225, 40.25908899307251, 39.34809330531529, 37.110113280160085, 34.24201849528721, 32.47545289993286, 35.28207697187151, 35.66965443747384, 34.47155918393816, 34.89367961883545, 35.09082085745675, 40.14489187513079, 40.501657554081504, 39.339498383658274, 45.422309262411936, 43.26027304785592, 44.033958435058594, 41.73275327682495, 47.7531623840332, 45.14962373461042, 45.2629280090332, 46.47618423189436, 47.720064640045166, 52.205839020865305, 51.472925662994385, 53.8596944127764, 49.35994373049055, 45.350200857434956, 43.31714057922363, 50.007682595934185, 53.813197067805696, 52.236640385219026, 50.648626123155864, 43.10758638381958, 42.711827414376394, 41.51147052219936, 49.47185836519514, 52.48631347928728, 57.84656729016985, 53.9125736781529, 53.796861852918354, 50.326945372990195, 50.83923258100237, 47.16069643838065, 48.16456869670323, 47.52084936414446, 47.978287492479595, 47.45629712513515, 51.05075659070696, 59.35661234174456, 62.92521408626011, 62.314919063023154, 63.34190450395857, 5.5970931478909085, 1.400241692151342, 0.9556911694152015, 0.6131479644349643, 8.411097509520394, 63.89242417471749, 49.54498815536499, 65.68782479422433, 48.0222487449646, 40.078585215977256, 42.695221219744, 24.65571744101388, 43.70080620901925, 53.23141050338745, 62.26729610988072, 39.3732944216047, 0.5816026000039918, 0.06145775970071554, 0.09475670289248228, 0.055571268246109994, 0.06841389036604337, 0.0713349429092237, 0.009565545645143305, 0.04213319432788661, 0.011780155872526978, 0.12818435739193643, 0.04555877836953316, 0.21993869888995374, 0.4416802924658571, 38.47346101488386, 66.05024978092739, 51.267224243709016, 41.535622460501536, 32.42010007585798, 33.23947334289551, 39.95928117207119, 50.22002649307251, 69.65398856571743, 54.091274397713796, 72.55224895477295, 8.530775887625557, 0.17422132992318698, 1.757023655942508, 0.2514551712998322, 0.1687231199549777, 14.651659420558385, 77.20317159380231, 60.50887380327497, 68.96031515938895, 57.18451166152954, 61.26581055777413, 51.02506215231759, 55.944664682660786, 45.44706221989223, 47.36930567877633, 42.85933767046247, 46.33322851998465, 45.03867837360927, 50.39792122159685, 47.70963886805943, 47.729701791490825, 43.27814381463187, 41.19882590430123, 46.69640391213553, 52.57405533109392, 52.09005076544625, 52.69568007332938, 49.98251969473702, 56.446911743709016, 53.27056360244751, 57.086851256234304, 53.46273340497698, 52.385627133505686, 48.63107769829886, 50.6870288167681, 47.818419865199495, 48.744764123644146, 47.246722085135325, 47.76949759892055, 47.99823577063424, 45.71679823739188, 44.81627695901053, 44.342698165348594, 44.664646421160015, 43.15506342479161, 41.98891598837716, 43.66612080165318, 41.930071694510325, 38.16841425214495, 37.56088808604649, 38.318752425057546, 36.554243496486116, 36.44016449792044, 36.785507338387625, 39.5273950440543, 40.41776500429426, 39.245350292750764, 39.89743873051235, 42.32891566412789, 41.74928651537214, 42.99375752040318, 46.02198396410261, 45.20704712186541, 44.8435104233878, 46.6998884337289, 45.90220396859305, 48.48298379353115, 47.49406753267561, 52.76613480704171, 45.69942079271589, 33.8702620778765, 52.67825051716396, 53.58097437449864, 50.900515692574636, 50.28507900238037, 47.60153184618269, 45.033130237034385, 47.06303603308541, 46.69303403581892, 45.81008127757481, 44.58889021192278, 43.7451148714338, 43.57744094303676, 41.80890205928257, 41.55137402670724, 41.43538079942976, 38.66807310921805, 36.318254879542756, 34.23046016693115, 35.55722563607352, 35.94788115365164, 34.683472292763845, 35.65786681856428, 36.06887708391462, 42.16818298612322, 43.088544845581055, 43.1986460004534, 46.43609312602452, 47.052141257694785, 47.022079876491, 45.406731401171, 49.86787094388689, 46.63043424061367, 47.20747865949358, 47.78539160319737, 48.288368225097656, 52.64365891047886, 53.908432551792686, 56.470792702266145, 51.82118327277047, 46.19764832087925, 44.18595027923584, 49.98778295516968, 56.13818938391549, 54.96962397439139, 51.57946586608887, 47.48086248125349, 45.354039737156455, 44.94618395396641, 52.20626286097935, 54.8434168951852, 59.7922157560076, 56.73081166403634, 56.96419470650809, 54.025561809539795, 54.55039051600865, 50.1732998575483, 50.09092896325247, 48.977365493774414, 51.84048884255545, 49.2220185143607, 54.455471175057546, 61.90436390468052, 64.43417521885463, 65.85226781027657, 65.9422469820295, 5.4175959910665235, 1.4082314691373279, 2.134058424404689, 0.5095878871423858, 9.18050628049033, 70.59232194083077, 58.07661519731794, 72.55764075687954, 50.77589280264718, 39.41123158591134, 51.99948794501168, 30.32983180454799, 44.02181645802089, 56.565180506025044, 71.76744992392403, 48.074544361659456, 0.473194851406983, 0.0663015701408897, 0.08784296709511961, 0.14254779022719177, 0.09677556848951749, 0.17867007691945347, 0.11037440770970923, 0.12853108878646577, 0.3368889998112406, 0.24426891548292978, 0.17039075547030993, 0.32342520941581043, 0.3943871616252831, 48.924569606781006, 77.59935787745884, 56.36274126597813, 58.98459884098598, 42.40464755467006, 39.69067076274327, 52.36382021222796, 59.75998306274414, 74.81603458949498, 58.56548350197928, 78.8275284085955, 9.89263583932604, 0.3128868820411818, 3.2967120025839125, 0.49069611515317646, 0.2742155428443636, 15.312302827835083, 80.3418049131121, 53.630546297345845, 65.71842466081891, 61.72397477286202, 62.863493238176616, 54.57308333260672, 57.80572577885219, 48.57117033004761, 50.10186195373535, 47.40684332166399, 50.201200348990305, 47.98022951398577, 52.92273678098406, 51.7415360723223, 51.62397255216326, 45.84606947217669, 44.51822008405413, 49.269634519304546, 54.519964354378835, 53.97684104101998, 56.011541094098774, 49.006058079855784, 59.762137004307334, 55.18519878387451, 60.48515265328543, 56.53429923738752, 54.494683333805625, 51.73220464161464, 54.40240430831909, 47.82396452767508, 51.50905629566738, 47.839240142277305, 49.36342477798462, 50.595170157296316, 47.68170363562447, 49.44311714172363, 47.89424555642264, 48.46445642198835, 47.62370007378714, 46.001757758004324, 47.19737250464303, 44.479664530072895, 40.608548641204834, 39.33350556237357, 39.990252767290386, 39.118910448891775, 38.38916894367763, 38.19310120173863, 42.67015906742641, 42.919870376586914, 40.95154993874686, 42.931397438049316, 43.84447758538382, 44.495655809129985, 45.969063009534565, 50.09355885641915, 48.46339682170323, 47.3607211794172, 48.5420434815543, 49.52596746172224, 52.51906033924648, 48.260366984776084, 54.119230474744526, 47.79164150782994, 34.72365025111607, 55.743309361594065, 56.65877621514456, 54.95363964353289, 54.07893092291695, 52.767760685511995, 47.77957943507603, 50.783521924700054, 50.290554182870046, 47.361534118652344, 47.35301562717983, 45.38011980056763, 46.385214941842214, 43.59955358505249, 44.24597576686314, 45.243087427956716, 41.237607274736675, 38.87036991119385, 35.787037304469514, 38.39361926487514, 39.79520641054426, 37.38646050861904, 39.442470686776296, 39.01998894555228, 46.43229940959385, 46.906295095171245, 46.11954362051827, 51.14193432671683, 50.21812616075788, 51.93116978236607, 49.80210624422346, 52.86878054482596, 48.883088861192974, 48.851078510284424, 50.64413411276681, 50.74476139886038, 54.45721517290388, 55.4290006501334, 57.56659657614571, 47.40188578196934, 44.506418568747385, 44.99508537564959, 50.38109268460955, 58.402166094098774, 58.04452494212559, 54.743932587759836, 48.09320374897548, 47.39852632795061, 45.87024572917393, 54.703626087733674, 57.54646417072841, 60.85711751665388, 57.74195868628365, 59.1554411479405, 57.42206014905657, 56.62889896120344, 54.78906808580671, 52.89739670072283, 52.13941076823643, 55.281052657536094, 52.47588075910296, 58.77722290584019, 68.03063923971993, 68.69952842167446, 66.97444357190813, 68.14753573281425, 7.823589103562491, 1.451155268720218, 3.164227660213198, 0.7414612706218446, 11.14863303729466, 75.33006232125419, 63.009141377040315, 75.73323154449463, 61.62224619729178, 51.11269630704607, 60.19515568869454, 36.249214104243684, 57.86770371028355, 69.61289691925049, 79.52462032863072, 55.510603768484934, 0.5874716565012932, 0.2024578047650201, 0.16802105334188255, 0.2388240247964859, 0.1444340090134314], [0.022178807661735585, 0.022256001198132123, 0.06131170503795147, 0.06323415080883674, 0.062146818797503195, 0.047849041010652266, 0.05413832442302789, 0.41925734281539917, 34.56219148635864, 58.186771937779014, 48.78992394038609, 41.94674737112862, 18.722508226122173, 29.583449363708496, 35.58541100365775, 45.04048490524292, 63.844905444553916, 49.39336803981236, 60.83796828133719, 26.493790422167095, 0.4346957786806992, 0.785051988703864, 0.6347473625625882, 0.14118739536830358, 0.3884298955755574, 49.37125539779663, 53.117501735687256, 52.182711941855295, 59.884772709437776, 56.69832536152431, 52.17704916000366, 49.67181362424578, 45.19888298852103, 43.14989396503994, 44.24071945462908, 45.305256434849326, 48.035877636500764, 47.43747098105294, 46.45303978238787, 41.56771271569388, 40.49176679338728, 38.61534323011126, 45.54628944396973, 49.967740876334055, 50.77487489155361, 55.29279163905552, 58.39457171303885, 51.26463603973389, 51.61918524333409, 50.753759316035676, 50.33003037316458, 50.281445094517295, 49.730293137686594, 48.78934376580374, 46.56093488420759, 46.43119812011719, 44.842753069741384, 43.95749350956508, 44.48291628701346, 42.37069518225533, 43.72076143537249, 41.44708503995623, 42.4015417098999, 40.27493783405849, 38.06191226414272, 38.20902647290911, 38.78282955714634, 38.16082681928362, 34.962077685764854, 35.94241292136056, 34.90508508682251, 35.94765533719744, 35.96612712315151, 36.21115187236241, 39.950925963265554, 38.84664181300572, 38.6982421875, 38.6764144216265, 39.29970605032784, 40.07067469188145, 42.637679713112966, 42.22188908713204, 44.91924926212856, 42.299542154584614, 44.46278388159615, 45.94080468586513, 46.44796412331717, 50.51283400399344, 47.736681256975444, 41.774491105760845, 50.65264218194144, 48.745962687901084, 46.599295888628276, 46.82960087912423, 46.411343642643516, 43.09778594970703, 43.869914940425325, 43.3356922694615, 41.60900238582066, 42.44878946031843, 41.53443431854248, 40.694362367902485, 39.244836126055034, 36.041421277182444, 38.28835753032139, 36.583297388894216, 34.879216943468364, 34.94501291002546, 34.727162565503804, 33.3603059904916, 33.30908039637974, 36.02532924924578, 39.1358015196664, 39.209636551993235, 39.22181327002389, 40.2807743208749, 44.46224887030465, 42.666250705718994, 44.71095963886806, 41.84997286115374, 47.82890469687325, 45.11707837241036, 47.48473957606724, 44.33431168964931, 45.59705645697457, 55.17097234725952, 52.913103103637695, 50.643077986580984, 55.52982248578753, 55.87649243218558, 54.83141040802002, 51.758573055267334, 52.792440686907085, 53.1180853843689, 50.92189877373831, 46.79247317995344, 41.78688669204712, 39.643687043871196, 46.65026787349156, 51.1214406149728, 54.48079735892159, 54.30876343590872, 57.90101684842791, 54.94591324669974, 55.9146797316415, 53.180424622126985, 54.18245908192226, 49.146015644073486, 49.994126660483225, 47.42157350267683, 50.136860030038015, 56.14749649592808, 57.772669724055696, 63.06528282165527, 57.20747545787266, 0.5225557227219854, 0.965727299451828, 1.391718532357897, 0.5820533643875803, 13.212343556540352, 65.76362269265312, 45.72030707768032, 62.17916515895298, 52.58753136226109, 41.00084393365042, 38.19572067260742, 27.120682954788208, 24.549601078033447, 53.30883080618722, 61.709050042288645, 30.212848458971294, 0.39524415135383606, 0.037306493148207664, 0.07198479625263385, 0.03455515578389168, 0.05119023225935442, 0.023334820987656713, 0.06600631919822522, 0.05014064036575811, 0.02992458515135305, 0.03887944249436259, 0.01890417730568775, 0.05811062787792512, 0.36517335208398954, 43.771427699497764, 66.63716411590576, 50.38874612535749, 46.16760083607265, 32.91666351045881, 34.711504799979075, 42.545358998434885, 51.87125546591622, 70.36784648895264, 56.34603779656546, 69.03558499472481, 29.354047639029368, 0.3062225010778223, 0.7344212255307606, 0.8215146692735809, 0.16828631982207298, 0.7377575007932526, 49.75179781232561, 63.31787763323103, 65.29000568389893, 59.44291591644287, 58.45459720066616, 52.54968105043684, 53.55114228384835, 46.05600234440395, 45.97667476109096, 45.134250845227925, 46.77427237374442, 48.118311064583914, 49.47532204219273, 49.62810945510864, 45.529943806784495, 43.720288957868306, 41.35267291750227, 45.16975266592843, 51.71825960704258, 52.14211361748831, 53.43367256437029, 59.1632022857666, 54.12742587498256, 54.24469757080078, 54.26688664300101, 51.901813643319265, 51.31316573279244, 49.98903363091605, 51.90000711168562, 49.25504330226353, 49.23270831789289, 46.5201871735709, 46.18602051053728, 49.608783040727886, 45.61769608088902, 45.51322296687535, 46.344380378723145, 46.315666948046, 43.20036915370396, 41.468700885772705, 40.126812662397114, 45.12536409923008, 39.2902842930385, 37.773669719696045, 38.379017625536235, 36.503049169267925, 38.7832464490618, 37.37593398775373, 38.207831382751465, 40.52246740886143, 39.23426791599819, 40.018782070704866, 41.384089197431294, 41.68244137082781, 42.771133763449534, 44.38077776772635, 44.24932827268328, 45.98703105109078, 44.633459431784495, 46.12551212310791, 48.213591711861746, 48.21140302930559, 51.998987674713135, 48.01020056860787, 40.59706326893398, 52.636853149959016, 50.64097268240792, 49.21581029891968, 50.14815432684762, 47.86701904024397, 44.63080521992275, 46.91991009031023, 45.61593471254621, 45.5442327771868, 43.664901392800466, 42.88719647271292, 42.490270205906455, 41.51217576435634, 38.48707601002285, 40.32428741455078, 37.2460617337908, 37.02624157496861, 35.938886710575645, 35.58473355429513, 36.04023660932268, 35.12668398448399, 37.00304848807198, 42.06468609401158, 42.7747711454119, 41.75587688173567, 44.42878981998989, 47.7504734311785, 45.488876479012625, 47.57283231190273, 46.327221802302766, 51.46074547086443, 45.942368030548096, 48.17160374777657, 46.31924874441964, 49.196779182979036, 56.62077651705061, 52.03286361694336, 53.78344488143921, 57.4739909853254, 56.03239958626883, 55.484499386378694, 53.804004601069856, 54.11287982123238, 55.26627036503383, 53.243118218013215, 50.305009910038535, 45.67327472141811, 42.32734884534563, 48.05659021650042, 53.72359657287598, 54.24779994147164, 56.591086864471436, 58.70072323935372, 58.46979291098458, 58.031305994306294, 58.853125027247835, 55.55309200286865, 53.51539727619716, 51.19434111458914, 50.11083207811628, 52.33906725474766, 57.812938008989605, 60.575993401663645, 66.27079950060163, 59.76137965066092, 0.6973245761224202, 0.8873941770621708, 1.9348568277699607, 0.5695431328245572, 15.502280473709106, 71.21300452096122, 50.00023065294538, 69.86426884787423, 56.173406328473774, 46.049095835004536, 46.406181131090435, 32.01881728853498, 30.094645704541886, 58.75303622654506, 69.26711981637138, 38.50943183898926, 0.5780787776623453, 0.09179367617304836, 0.07110359639461551, 0.10602911016238586, 0.08489500385309968, 0.09984845002847058, 0.2859768888780049, 0.14708163908549718, 0.1464037283190659, 0.1666834708303213, 0.08074659681213753, 0.12751198347125733, 0.7606573519962174, 55.524976117270334, 73.51100308554513, 63.631338664463584, 54.66616487503052, 25.79446813038417, 43.50367886679513, 50.07712289265224, 56.65695926121303, 74.99823025294712, 60.82419000353132, 73.01936939784459, 33.61458574022566, 0.5293685400060245, 1.9191004846777235, 1.4071728459426334, 0.19711249587791307, 0.6434387990406581, 56.951576777866904, 51.92760535648891, 55.870735849652974, 64.776380947658, 61.00031988961356, 55.57147693634033, 54.93460157939366, 49.36809049333845, 48.22566073281424, 48.71365009035383, 49.43607861655099, 51.62605701174055, 53.58202355248587, 53.27162667683193, 46.91946540560041, 43.52428027561733, 43.06273576191494, 50.319965907505576, 54.06070927211216, 54.169323512486045, 52.85772596086775, 59.110826764787944, 57.84884282520839, 54.964200905391145, 55.48283876691546, 54.389897550855366, 53.366379261016846, 53.23041691098894, 54.910022326878135, 49.735671043395996, 51.880906513759065, 49.45065246309553, 48.828302315303254, 50.06563752038138, 49.29152829306466, 50.19081279209682, 49.97261503764561, 49.04088592529297, 46.50522770200457, 46.39633553368704, 43.33074515206473, 45.82919577189854, 42.20265647343227, 39.05534832818167, 40.58617196764265, 38.713552543095176, 40.46732650484358, 39.02589838845389, 39.21771730695452, 43.75131961277553, 42.78772953578404, 44.12401403699602, 44.35011536734444, 43.01481403623308, 46.60513584954398, 46.605399881090435, 45.25116123471941, 46.51399632862636, 45.60924012320382, 48.509908063071116, 51.144908155713765, 51.40818234852382, 54.74601009913853, 49.665970189230784, 42.74082919529506, 54.83914722715105, 51.89845418930054, 50.184323174612864, 52.055156912122456, 51.33990587506975, 45.6476080758231, 47.46263040815081, 48.52998488289969, 48.18917574201311, 45.547727721078054, 46.18698631014143, 45.53597484316145, 45.719386441367014, 41.03240959984915, 41.92589235305786, 42.4870879309518, 39.59938185555594, 39.5552191053118, 37.977835587092805, 37.201516832624165, 37.126347746167866, 40.782402992248535, 45.188332148960654, 46.92455843516758, 45.409701756068635, 47.744261741638184, 51.10544238771711, 49.00949396405901, 51.84478282928467, 48.7793105670384, 54.469569069998606, 49.9980593408857, 52.70629344667707, 48.429520879473, 50.356377942221506, 60.344771248953684, 55.57308891841343, 55.134925092969624, 59.69462830679757, 57.49623564311436, 56.57548815863473, 54.83748313358852, 55.111110142299104, 58.991512298583984, 55.70806115014212, 52.26074021203177, 46.590641907283235, 43.58903053828648, 49.54071848733084, 57.22548171452114, 59.82324641091483, 59.98785618373326, 61.33883612496512, 61.134065764290945, 62.45832988194057, 60.308883803231375, 60.08907754080636, 55.49400799615042, 54.11522831235613, 52.02399771554129, 55.703544821058, 61.78266620635986, 63.87898635864258, 68.42614459991455, 64.01128700801304, 1.4333626691784178, 1.5139116155249732, 3.730897767203195, 0.6441930585673877, 18.886584724698746, 77.44713674272809, 59.06965173993792, 75.28649016789028, 64.9159494127546, 51.6760527747018, 58.907869883946006, 40.504617486681255, 35.98095110484532, 70.04986218043736, 78.16350991385323, 50.21323115485055, 0.6280309515339988, 0.1563940979540348, 0.2291783509509904, 0.36914025779281345, 0.13867905496486596], [0.11312066963208572, 0.039141397723662, 0.03810634344284024, 0.026689857743414383, 0.03502517020595925, 0.014555848403168576, 0.020416910061612725, 0.32386840134859085, 42.02512305123465, 56.94480923243931, 44.3934999193464, 42.70527178900582, 22.372629710606166, 29.77973597390311, 40.40001930509295, 38.10739517211914, 58.2481940133231, 54.34049238477434, 55.01220600945609, 50.30848053523472, 0.2464993686548301, 0.11910329253545829, 0.4961445342217173, 0.13777299358376435, 0.17428279162517615, 18.19266986846924, 47.754347051892964, 43.01847573689052, 60.25935704367501, 50.9393561226981, 57.048219272068565, 44.6360684803554, 45.25035176958357, 39.84211369923183, 47.031466892787385, 47.09012358529227, 49.94113622392927, 47.51339394705636, 49.48449713843209, 42.80078172683716, 42.370243549346924, 36.99591963631766, 46.164428983415874, 48.206688676561626, 55.52430214200701, 58.74430234091622, 47.04557868412563, 53.44337919780186, 52.46125480106899, 48.02456596919468, 47.908041204724995, 46.218496390751426, 48.32414102554321, 45.398813928876606, 43.84824350902012, 46.9648962020874, 44.06036506380354, 43.331481661115376, 45.70346464429583, 42.45752682004656, 42.98562812805176, 42.771297046116416, 42.181520053318565, 40.28004823412214, 38.42649119240897, 36.877484117235454, 41.5092123576573, 42.01800462177822, 39.50307982308524, 34.046457971845356, 34.9383739062718, 36.45186526434762, 37.05311025891985, 37.137169565473286, 38.69552544185093, 37.340407848358154, 38.3174010004316, 38.460610321589876, 37.358931745801655, 39.782605852399556, 43.053772585732595, 43.49480601719448, 43.67767913000924, 38.674673897879465, 44.45034660611834, 47.26626736777169, 47.736990451812744, 49.82167584555489, 51.20400605882917, 48.05119146619524, 51.354323387145996, 48.90436771937779, 47.5624794960022, 48.18395069667271, 47.48189081464495, 46.46288537979126, 45.712921142578125, 42.28077507019043, 42.0961058480399, 41.16659321103777, 41.668579714638845, 38.07594067709786, 39.035243715558735, 37.07995809827532, 37.81933675493513, 34.55833176204136, 32.13530731201172, 32.4919444492885, 35.716103145054404, 35.61330802100045, 36.03787074770246, 38.27365861620222, 39.524181502205984, 37.60031563895089, 39.053086689540315, 41.1847870690482, 43.74945054735456, 42.867237772260395, 44.089141028267996, 43.34428024291992, 47.15888295854841, 44.74086468560355, 47.25405938284737, 46.54842465264456, 45.31557450975691, 52.72235768181937, 53.36223118645804, 52.006463936397004, 51.749807902744834, 51.66839238575527, 52.94997024536133, 54.67782742636544, 52.54711716515677, 51.243992941720144, 51.71042551313128, 49.701180185590474, 45.777233668736045, 41.58621229444231, 41.7277957371303, 45.1006041935512, 51.13647999082293, 54.183935574122835, 55.77365214484078, 58.18616049630301, 56.6208564213344, 55.828949383326936, 56.533562728336875, 54.35362795421055, 53.20071683611189, 53.00576775414603, 49.52686030524117, 55.45076240812029, 53.95530162538801, 65.9887512751988, 45.158809253147666, 0.02939509034955076, 1.653426666344915, 0.27615482306906153, 0.3067685046366283, 21.691761834280832, 69.86107267652238, 51.944638865334646, 60.23242582593645, 62.30168274470738, 35.74142932891846, 38.41968195778983, 35.12253590992519, 30.85925327028547, 48.35505356107439, 66.04925618852887, 35.65404878343855, 0.28563857131770676, 0.07575588354042598, 0.05780815053731203, 0.05535399115511349, 0.01094160957394966, 0.06223217171749898, 0.025898572257054702, 0.11989118025771209, 0.01265930401028267, 0.012828163386854743, 0.06356773219470467, 0.0412692564007427, 0.3851958348282746, 51.80781841278076, 67.33779266902378, 50.967263562338694, 51.10266310828072, 22.974843978881836, 34.56243814740862, 46.277656827654155, 44.469252654484336, 65.98524938310895, 59.72660391671317, 60.523666518075125, 53.566181659698486, 0.3792902188641684, 0.16727664614362375, 0.7490793732660157, 0.34824517901454655, 0.1824602513973202, 19.383342708860123, 54.9392603465489, 55.74490049907139, 62.329225403921946, 52.88362537111555, 58.68578461238316, 45.55598218100411, 47.58470330919538, 43.452050277165, 50.11017894744873, 49.08546209335327, 50.82225465774536, 49.0294075012207, 51.87470177241734, 44.557189055851524, 42.80948087147304, 40.55109746115548, 47.96247339248657, 49.96226222174508, 55.99649824414934, 60.23177964346749, 51.45989779063633, 55.593533992767334, 53.86898762839181, 51.0491168158395, 49.393072741372244, 48.713472911289756, 49.09553350721087, 48.16380092075893, 46.635106904166086, 50.315105642591206, 46.52266073226929, 46.37619270597185, 49.68925707680838, 44.57933643886021, 47.46997465406145, 45.348425592694966, 46.00232056209019, 42.99008887154715, 42.359671865190776, 41.37948948996407, 43.40147433962141, 42.51138578142439, 39.85187244415283, 37.59772048677717, 37.70999642780849, 36.80501440593174, 39.0136695589338, 38.402874265398296, 38.55769402640206, 39.794025216783794, 39.53190442493984, 41.026666913713726, 40.46216399329049, 41.48726647240775, 44.09968491962978, 45.4568452835083, 45.147292613983154, 41.13688618796212, 47.813385895320344, 48.22793626785278, 49.43348346437727, 49.053444794246126, 53.59845951625279, 48.70705277579171, 53.40944072178432, 49.7293620790754, 49.44909259251186, 50.15669366291591, 49.47720152991158, 47.815102100372314, 47.58535991396223, 47.094862256731304, 43.63889428547451, 41.50223289217268, 45.25584432056972, 41.35972881317139, 41.2390490259443, 38.6022493498666, 38.04118578774588, 37.87742369515555, 34.56106240408761, 35.62038128716605, 38.10499109540667, 37.12832798276629, 38.74461099079677, 39.778360503060476, 42.28672272818429, 40.80722195761544, 41.53398963383266, 45.48738261631557, 46.994936738695415, 45.92789493288313, 47.5710084097726, 46.841756752559114, 49.526408672332764, 46.49004936218262, 47.66258219310215, 48.29789073126656, 45.75892863954817, 54.38979680197579, 53.72099447250366, 53.6677052634103, 54.26301302228655, 53.07003164291382, 55.44195556640625, 56.1770715032305, 53.74780757086617, 52.77135290418352, 53.18321084976196, 51.3327179636274, 48.39298030308315, 43.620610100882395, 43.423972606658936, 48.355991567884175, 53.39642674582345, 56.11787632533482, 57.24797650745937, 59.92697606767927, 58.58656433650425, 59.088085310799734, 60.176312174115864, 58.322150639125276, 55.872330461229595, 56.71576533998762, 52.966381890433176, 58.11171749659947, 57.83683981214251, 67.91263798304966, 48.58376046589443, 0.0477795929514936, 2.088430255651474, 0.7338700379644121, 0.385380396353347, 25.773142371858867, 75.44117791312081, 57.32959699630737, 64.89181137084961, 71.4149191720145, 48.95120900017874, 49.643402440207346, 34.84924588884626, 28.82496837207249, 53.27452060154506, 70.86619908469063, 45.25882509776524, 0.3310709962887423, 0.05652755478929196, 0.12221117291067328, 0.041232147320572815, 0.05940746436161654, 0.23617594689130783, 0.09906827724937882, 0.3026645891368389, 0.12119791656732559, 0.169542898823108, 0.2639358730188438, 0.1560302810477359, 0.7182980392660413, 64.18406091417584, 75.43548733847481, 60.186060496738975, 54.17314502171108, 28.19540252004351, 43.790938241141184, 53.54882505961827, 52.434625829969136, 66.24589715685163, 65.29996245247978, 63.003138133457725, 59.65788623264858, 0.4367449815784182, 0.38331393152475357, 1.3055785660232817, 0.7476753486054284, 0.3402768165937492, 24.141602856772288, 48.78801318577358, 43.52585056849888, 67.75464984348842, 54.42640686035156, 64.49867534637451, 48.17861795425415, 52.06627402986799, 45.87851755959647, 53.544819423130576, 53.513486521584646, 56.05104507718767, 51.65692785808018, 54.79659298488072, 47.3943852015904, 44.99811826433454, 42.342683519635884, 49.75953810555594, 54.03860010419573, 55.0327969959804, 58.63785593850272, 56.4664500781468, 55.51424809864589, 56.71185350418091, 52.24074329648699, 51.186857904706685, 51.54109443937029, 54.225218296051025, 51.01161043984549, 47.30194289343697, 53.577149391174316, 50.52952357700893, 47.01386710575649, 53.143946579524446, 49.59347268513271, 50.946255683898926, 48.88798039300101, 51.009188992636545, 47.08374513898577, 45.61889811924526, 45.44613463538033, 47.08204977852957, 46.03080817631313, 41.748723711286274, 38.26992743355887, 38.55633217947823, 39.496597153799875, 41.166749545506065, 40.5705315726144, 40.854966504233225, 42.29806913648333, 42.34176983152117, 44.16069705145699, 43.25072969709124, 43.431396756853374, 46.23974398204258, 47.71590266908918, 48.44226387568882, 40.88707412992205, 49.290781361716135, 50.94115570613316, 53.34239060538155, 52.778763157980784, 55.402246611458914, 50.7499760219029, 54.46182877676827, 51.36618743624006, 52.01779644829886, 52.971054553985596, 51.720086983272004, 50.95150852203369, 49.54124307632446, 49.26392657416207, 46.1243691444397, 45.474549293518066, 47.656367029462544, 43.867566449301584, 43.920758383614675, 40.79784883771624, 42.41259281975882, 40.513785634722026, 36.913270814078196, 36.71974263872419, 40.49438279015677, 38.52911261149815, 41.9257811818804, 43.472516196114675, 44.85207060405186, 44.727246216365266, 45.18912771769932, 48.29319027491978, 50.32344695499965, 52.28015695299421, 50.39524616513933, 51.59294537135533, 53.69732195990426, 50.6043313571385, 51.55302449635097, 51.14443915230887, 48.6265926361084, 56.58434016363961, 56.161090646471294, 55.06971624919346, 55.24091986247471, 53.27165446962629, 58.243243421827046, 60.500515120370046, 55.6001695224217, 53.38369417190552, 55.82839700153896, 53.315337794167654, 49.76650367464338, 47.24479396002633, 46.0799423626491, 50.717340333121165, 57.26034082685198, 59.755647386823384, 59.995950835091726, 62.79835387638637, 60.83037390027727, 61.26913179670061, 63.21621853964669, 61.22912406921387, 59.58192157745361, 59.30962862287249, 56.19794389179775, 61.05948380061558, 60.61295781816755, 70.56244468688965, 52.41285712378365, 0.24352697815213883, 2.7864942720958163, 1.4058302151305335, 0.5615339225956372, 28.9328339440482, 81.51047801971436, 64.74120221819196, 72.59872545514787, 74.98738411494664, 48.83455916813442, 54.55017859595162, 53.502838407244, 40.61237015042986, 64.83589226858956, 79.18932110922677, 58.68604169573103, 0.3512103227632386, 0.1948657307241644, 0.10775144917092153, 0.18696121844862187, 0.1478296560900552], [0.05549589318356343, 0.024432285223156214, 0.06475772655435971, 0.025251261723626937, 0.014236121006043894, 0.06893243361264467, 0.04748017919648971, 0.9254599916083472, 49.94523218699864, 54.76357167107718, 46.50064189093453, 27.39051624706813, 28.050166061946324, 28.785773583820887, 48.8359557560512, 33.340340341840474, 43.75338322775704, 65.46768501826695, 46.27454056058611, 67.75561564309257, 6.342614012105124, 0.26369569876364296, 0.3276272139378956, 0.31539637595415115, 0.20262832061520644, 6.3597838793482095, 45.70256832667759, 33.598358222416465, 61.97340815407889, 51.89664418356759, 52.302627427237375, 43.51329517364502, 44.963259152003694, 42.8560094833374, 49.435522760663716, 46.092542920793804, 52.477020263671875, 47.12119592939104, 48.53521340233939, 40.828295843941824, 42.07324627467564, 38.47845676967076, 49.74174724306379, 50.55889013835362, 64.76901585715157, 40.982410362788606, 44.78264767783028, 53.448065757751465, 51.110205377851216, 51.002386706215994, 49.30689770834786, 45.90665428979056, 44.83389064243862, 42.477169377463206, 43.318669182913645, 46.49387434550694, 43.14547838483538, 46.77978924342564, 46.130111830575125, 44.728170326777864, 43.26479632513863, 43.3397604397365, 41.8184940474374, 41.478786196027485, 39.678664275578086, 39.00842366899763, 38.674458503723145, 40.48572186061314, 38.86926167351859, 37.92786761692592, 39.16155849184309, 36.09555469240461, 36.99170902797154, 35.773498739515034, 38.498068060193745, 37.92023849487305, 40.47792945589338, 36.76864406040737, 37.943605286734446, 39.772141865321565, 41.711668968200684, 41.47689976011004, 40.93632296153477, 37.723298754010884, 42.06752790723528, 48.03680869511196, 46.32052721296038, 49.81134040015084, 52.28703219549996, 50.3364713532584, 51.80459097453526, 49.76788984026228, 49.272104603903635, 47.05142559323992, 48.14478022711617, 44.74390452248709, 45.5849665914263, 42.810835770198274, 44.69365167617798, 41.094634192330496, 41.56932817186628, 38.22579942430769, 38.06866243907383, 37.46360635757446, 36.832987853458945, 34.96400581087385, 34.09769051415579, 33.30323348726545, 33.749703884124756, 33.56527784892491, 38.95006922313145, 39.92508561270577, 38.542373248508994, 37.36666856493269, 36.01503896713257, 39.91490650177002, 40.683530126299175, 42.80457544326782, 42.75920370646885, 41.561844961983816, 46.02496474129813, 45.381763049534385, 43.00062928880964, 48.963121686662944, 44.00508519581386, 45.37991482870919, 50.557465757642476, 48.56237391063145, 53.18601444789341, 54.112271853855674, 51.34408174242292, 53.13688373565674, 52.542232581547324, 51.28905200958252, 51.39204863139561, 50.78604064668928, 47.390389987400596, 42.02786758967808, 41.66966363361904, 41.91444866997855, 44.78941174915859, 50.996960163116455, 52.729291984013145, 54.73731442860195, 57.243067605154856, 56.596110412052695, 55.769007274082725, 58.08432422365461, 54.91068240574428, 56.61345658983503, 50.77422523498535, 55.491388525281636, 55.40900373458862, 66.88727147238595, 38.84522785459246, 0.19423814011471613, 1.2609397556100572, 0.16224851166563375, 0.07880794762500695, 28.27781857763018, 69.88206318446568, 48.82471357073103, 65.11199283599854, 49.910689217703684, 18.90103350366865, 38.903227942330496, 44.89141130447388, 41.677720069885254, 47.497135162353516, 60.6216013772147, 37.8134377343314, 0.2627115787139961, 0.04439948093412178, 0.056884450638400655, 0.03031760620485459, 0.0848238051735929, 0.05746157520583697, 0.05466016534981983, 0.09041811605649334, 0.015763316735891358, 0.0341065796757383, 0.06973317957350186, 0.025840376004842774, 1.0945459242377962, 61.24772439684187, 61.441718101501465, 50.70631006785801, 37.90924991880144, 24.565425600324357, 34.77672406605312, 62.84107140132359, 36.64475073133196, 50.44859095982143, 70.78242465427944, 52.39267955507551, 72.44180733816964, 6.600852932248797, 0.20138799931321824, 0.7447187272565705, 0.37581826373934746, 0.20687879967902387, 7.250795679433005, 50.17197275161743, 46.67174128123692, 67.25005776541573, 53.65761995315552, 54.03336811065674, 44.37228012084961, 48.270514828818186, 45.25926283427647, 51.31216171809605, 49.673224108559744, 55.3166378566197, 48.966164997645784, 52.35077149527413, 42.4471218926566, 44.39356940133231, 41.344936098371235, 53.40233618872506, 50.54401057107108, 66.806227684021, 45.10937976837158, 47.653639861515586, 56.94191183362688, 52.147811140332905, 52.035201685769216, 48.98333747046334, 47.34762035097395, 46.288402216775076, 47.82565293993269, 44.74077088492257, 48.62374040058681, 44.83996336800711, 49.132477079119, 49.8634796823774, 48.15063408442906, 46.21679755619594, 46.40450661523001, 46.120558057512554, 43.81193222318377, 42.33408164978027, 41.15307549067906, 41.26797785077776, 43.19402892248971, 40.961444173540386, 41.18800755909511, 38.58836684908186, 36.765545163835796, 37.16968018668038, 37.422455651419504, 39.854026385716026, 39.260820456913535, 41.94202607018607, 38.256444454193115, 39.4940436908177, 39.82172768456595, 44.12656055177961, 44.28395809446062, 43.92576803479876, 38.581898076193674, 45.89760773522513, 47.976032802036826, 47.19702162061419, 51.90335266930716, 53.92853716441563, 52.052436692374094, 53.356259209769114, 51.07997029168265, 49.08937392915998, 47.853494371686665, 49.334968430655344, 44.932645389011924, 47.79977090018136, 45.08812175478254, 45.38247523988996, 42.76992130279541, 42.71423149108887, 39.50306940078735, 41.3368136542184, 39.244752747671946, 39.11797939028059, 36.25371306283133, 35.947908946446006, 36.08004631314959, 36.09695822851998, 36.458424363817485, 39.68826668603079, 39.50197853360857, 41.26198502949306, 41.364648137773784, 40.06623479298183, 42.644728660583496, 43.97190407344273, 46.34646136420113, 47.174134254455566, 43.7692494392395, 48.53181920732771, 47.50077601841518, 45.94914947237287, 51.27741725104195, 44.95908328465053, 47.33527340207781, 51.63533980505807, 50.867553438459126, 55.716124534606934, 54.97826058523995, 53.59821285520281, 54.53247111184256, 54.16775321960449, 53.433366843632285, 54.04539891651699, 52.68870408194405, 50.639923504420686, 44.94727482114519, 44.44740751811436, 45.284015791756765, 46.852856499808176, 53.38568483080183, 55.22760016577584, 57.44934919902256, 58.32932812826974, 59.85729258401053, 58.34417642865862, 61.89854826245989, 58.12695837020874, 59.50697135925293, 55.55893196378435, 59.16178485325405, 57.20102405548096, 70.29907321929932, 40.89150013242449, 0.1887667187090431, 2.265083427940096, 0.21637983699994429, 0.1930869376020772, 33.59031220844814, 75.61101273127964, 55.038240909576416, 69.85818222590855, 59.75969818660191, 26.03038031714303, 42.298864705221995, 44.92141015189034, 32.764713355473106, 58.191354274749756, 65.26426260811942, 50.17950112479073, 0.357809130102396, 0.01828077495364206, 0.03901374153792858, 0.036665033282978196, 0.037400945222803524, 0.13560236005910806, 0.17909387632140092, 0.11534658340471131, 0.10424789467028209, 0.09170358029327222, 0.12633195679102624, 0.16322857407586916, 1.7935589126178195, 73.18009512765067, 68.8979411806379, 62.382226262773784, 38.01761054992676, 37.12211281912667, 43.27931458609444, 61.277803148542134, 44.98951639447893, 54.90608964647566, 76.88258171081543, 56.27139677320208, 77.52219118390764, 7.519680976867676, 0.3149034338338034, 1.4132219042096819, 0.8656046262809208, 0.31885853303330286, 9.066400357655116, 50.40593249457223, 33.09775441033499, 70.59130750383649, 55.46011815752302, 58.89398043496268, 47.45179121834891, 50.0070537839617, 46.53923218590872, 55.755357537950786, 52.768302645002095, 58.97464207240513, 51.07319232395717, 54.0611435345241, 44.64434378487723, 48.06028665815081, 42.681814670562744, 57.749723298209055, 53.64514446258545, 63.525795527866904, 50.474431310381206, 49.791468552180696, 58.705712045942036, 55.96218456540789, 53.87219074794224, 54.18308789389474, 50.34826244626726, 50.44010720934187, 48.65477105549404, 47.46785545349121, 50.648636545453755, 47.82314464024135, 51.42555979319981, 52.835790497916086, 53.408464499882285, 48.03440809249878, 48.39821924482073, 50.625492095947266, 47.54057877404349, 46.65364122390747, 45.43382242747715, 45.22744703292847, 47.39348888397217, 44.1626911844526, 44.80687257221767, 40.65747438158308, 39.871831144605366, 40.80532162530081, 39.16817665100098, 42.879532609667095, 41.37521982192993, 45.41523947034563, 39.89772708075387, 41.21928140095302, 42.0253141266959, 46.188379423958914, 46.69417701448713, 45.582559040614534, 41.445855208805625, 49.3838837487357, 51.543422085898264, 49.29171936852591, 54.264899458204, 56.83896732330322, 54.92124366760254, 55.962139402117046, 55.260155950273784, 54.040149552481516, 50.65555347715105, 53.070997442517964, 48.57811852863857, 50.40489026478359, 47.127612590789795, 47.91593088422503, 46.007059233529226, 45.76573092596871, 42.562990052359446, 43.46552630833217, 42.09853424344744, 42.34688023158482, 38.84647158214024, 37.65727002280099, 38.649907044001985, 38.950451374053955, 39.098691190992085, 43.595843247004915, 42.96940408434187, 42.870065689086914, 44.97633566175188, 44.1322546005249, 46.37276724406651, 49.728125299726216, 49.92426252365112, 51.8610520362854, 49.709594454084126, 51.03268085207258, 49.027451583317344, 48.04535150527954, 53.567244734082905, 47.16069991247994, 49.43059301376343, 54.33974545342581, 52.07046726771763, 56.24151951926095, 59.695441246032715, 55.49701656614031, 56.92634786878313, 54.19562939235142, 54.33382558822632, 55.585578305380686, 55.41338457380022, 52.00935786111014, 47.60198695319039, 46.79715626580374, 48.32190717969622, 49.61517538343157, 56.50328595297677, 59.67169230324881, 59.93365328652518, 61.726955550057546, 60.29839202335903, 61.00352300916399, 63.972495215279714, 59.13721602303641, 61.75513744354248, 57.639444964272634, 61.38380486624581, 61.05791350773403, 73.45743942260742, 44.34879868371146, 0.31504104073558536, 4.128403774329594, 0.7843410468527249, 0.25210151661719593, 36.68452916826521, 82.62473283495221, 60.67059312547956, 77.59193720136369, 60.71968214852469, 31.396439347948345, 53.615555558885845, 62.35335649762835, 52.783178738185335, 65.39272090366909, 75.91446835654122, 65.52937807355607, 0.405337929725647, 0.23725188629967825, 0.10417244157620839, 0.14984105101653508, 0.14263707186494554], [0.020499111186446886, 0.0974931667691895, 0.05324341815763286, 0.04408706305548549, 0.020134478341788054, 0.017200492921152284, 0.05328965353380356, 0.553757097039904, 49.56171941757202, 54.49793856484549, 48.18218585423061, 35.20825931004116, 56.98066193716866, 43.24977431978498, 30.552452087402344, 33.36458955492292, 38.76805421284267, 62.933030809674946, 49.1321678842817, 65.12737614767892, 21.350179706301006, 0.2084163057484797, 0.24120112295661653, 0.3224982220147337, 0.09592629370412656, 1.0432947086436408, 37.23403092793056, 30.79781382424491, 57.745168754032676, 55.36163786479405, 49.15733078547886, 43.88255023956299, 45.223483085632324, 47.882235595158164, 51.12909752982003, 49.47744124276297, 51.01718289511544, 50.3303221975054, 44.255362783159526, 42.77049800327846, 39.56443241664341, 47.30485071454729, 46.716508524758474, 61.96158926827567, 46.9143966947283, 35.236503737313406, 54.27062477384295, 48.22652925763811, 52.081824098314556, 46.92206055777413, 49.21958664485386, 41.88476596559797, 44.39450740814209, 43.27205719266619, 42.98583309991019, 45.30448865890503, 44.97366060529436, 44.5139399937221, 46.59544658660889, 40.95040348597935, 48.07928998129708, 43.182074546813965, 44.12937804630825, 42.45533118929182, 38.67036254065377, 38.90671246392386, 39.390074321201865, 39.85178211757115, 40.13208634512765, 39.06094857624599, 39.82773787634713, 37.17492607661656, 37.371587889535085, 35.45020253317696, 37.843933377947124, 38.57005487169538, 40.43786266871861, 40.64240721293858, 38.61298779078892, 40.272624083927695, 43.1925767489842, 40.518559047154014, 42.96152482713972, 41.933278288160054, 45.07541349955967, 47.76770496368408, 47.94642652784075, 49.65349817276001, 53.35846526282174, 52.23450034005301, 54.23598105566842, 46.863907609667095, 47.40462684631348, 48.43102863856724, 45.021728243146626, 37.982973779950825, 44.325824465070454, 44.85861928122384, 42.368888650621685, 39.57407651628767, 42.077845982142854, 39.90999065126692, 39.285868712833945, 36.27525247846331, 35.627899238041465, 34.368927342551096, 34.2988269669669, 32.631446906498496, 36.22980431147984, 36.81479746954781, 38.57002360480172, 38.98860740661621, 37.795143127441406, 35.62735727855137, 35.83884654726301, 38.28769050325666, 42.23925610951015, 42.03942939213344, 43.6216835975647, 44.04017012459891, 46.311623096466064, 45.50162989752633, 41.93773208345686, 47.70810331617083, 45.50675419398716, 42.00146443503243, 42.2289137159075, 43.80283008302961, 46.81627423422677, 46.77240678242275, 51.40207140786307, 53.420495305742534, 54.187420095716206, 55.217177867889404, 54.42288064956665, 51.68014178957258, 49.54384170259748, 46.13770273753575, 41.25197614942278, 42.9821331841605, 40.98737137658255, 45.429049015045166, 47.25364596503121, 52.551803725106375, 54.359745843069895, 59.522139276777, 55.2370844568525, 60.471777370997835, 56.2032036781311, 56.915536471775596, 52.322245665958945, 61.02645206451416, 52.11700630187988, 66.94839477539062, 28.119609832763672, 0.4466635079256126, 2.157226106950215, 0.003924090997315943, 0.12176342122256756, 26.643795081547328, 68.24957697732108, 45.92621694292341, 65.74152742113385, 38.27740369524275, 26.58134640966143, 53.174800055367605, 34.14913150242397, 34.68586942127773, 47.8885897227696, 64.5147395815168, 34.186533655439106, 0.4601489028760365, 0.13990132723535809, 0.03331140109470912, 0.06034951524010726, 0.035795684039060555, 0.028476184300546135, 0.08530975159789835, 0.0479251319276435, 0.01606011134572327, 0.033287615049630404, 0.01775113765948585, 0.020961473429841653, 0.7395406908222607, 60.56205531529018, 60.82214723314558, 53.51966347013201, 33.57386582238333, 37.78176784515381, 46.03510911124093, 48.76956224441528, 41.041654178074424, 42.864406381334575, 69.7918130329677, 55.03118848800659, 70.68850585392543, 24.131135395595006, 0.19100158235856465, 0.4521067701280117, 0.6570412005696977, 0.13903470230954035, 1.3628266198294503, 39.681950773511616, 40.34108815874372, 68.15146146501813, 56.808544635772705, 53.118109703063965, 44.6891006061009, 47.86750888824463, 50.17103474480765, 52.297833170209614, 53.41834831237793, 54.19109221867153, 51.28773185185024, 46.35644939967564, 44.05428191593715, 39.63797215053013, 49.66960409709385, 49.10154022489275, 63.12079892839704, 52.18009941918509, 37.76736422947475, 55.65536601202828, 50.91528408867972, 54.181628772190635, 48.61881760188511, 51.11328342982701, 43.41690281459263, 47.24800055367606, 46.12238890784127, 44.05173887525286, 48.950086866106304, 46.97965070179531, 46.49686207090105, 50.76071446282523, 45.84574638094221, 50.36705037525722, 46.91129779815674, 46.464577266148154, 44.79387944085257, 42.32172427858625, 40.64090640204293, 43.14144148145403, 41.611486366816926, 42.80993945258004, 41.69316938945225, 40.79235281263079, 40.24782248905727, 38.68243156160627, 38.40827301570347, 39.36367116655622, 40.02650499343872, 43.721633434295654, 41.2315171786717, 41.89931896754673, 40.911048889160156, 45.524517263684956, 43.02925934110369, 44.335513728005544, 42.0489935874939, 47.62793500082833, 48.36043841498238, 50.086756569998606, 49.030317715236116, 53.66374479021345, 51.60667153767177, 54.70625945499965, 48.9440141405378, 48.60519218444824, 48.6953033719744, 46.069718088422505, 41.20110491343907, 45.70735216140747, 45.472027097429546, 43.821020466940745, 42.27258661815098, 41.97952549798148, 40.841469628470286, 40.199574198041645, 39.474727698734824, 37.4237653868539, 35.88119234357561, 34.86400386265346, 35.982260840279714, 37.67994199480329, 38.358892168317524, 42.18947574070522, 42.89442259924752, 41.17772422518049, 40.61340890611921, 39.67228582927159, 44.64961051940918, 46.45517635345459, 45.181088651929585, 47.424116543361116, 45.58403900691441, 50.061440808432444, 46.61715970720564, 44.376650537763325, 50.27794667652675, 47.70358003888811, 43.38583394459316, 44.21247155325753, 46.55401447841099, 48.42196123940604, 50.10615941456386, 50.72344432558332, 56.41903557096209, 55.4691230228969, 55.24068709782192, 54.835162435259136, 53.23782021658761, 51.35504947389875, 49.55648742403303, 43.0049649647304, 43.55093009131295, 43.348115648542134, 47.76265709740775, 49.504619121551514, 55.103668621608186, 56.838428837912424, 60.09876332964216, 56.38502761295864, 62.174259730747764, 57.754826750074116, 60.50827625819615, 54.85173041479928, 62.617297717503135, 55.52083499091012, 73.30286979675293, 29.68201650891985, 0.2466764391532966, 3.8028246504919867, 0.027791288016097884, 0.15413309713559492, 31.109256403786794, 75.28442655290876, 53.16668108531407, 74.65683051518032, 41.04359967367989, 20.69138625689915, 57.1109892981393, 42.3654909815107, 38.03567934036255, 53.87511593954903, 71.9833651951381, 46.87962096078055, 0.4325650430151394, 0.13859163251306328, 0.07611898119960513, 0.04603379698736327, 0.020842125905411582, 0.1084662043888654, 0.1318025096718754, 0.09661618739898716, 0.10018812465880599, 0.19069409742951393, 0.08851557171770505, 0.2374912734542574, 1.2676517154489244, 71.29081044878278, 70.13787501198905, 62.34780488695417, 45.11569915499006, 74.3893735068185, 59.89710576193673, 42.97865561076573, 45.66108758108956, 52.40512030465262, 74.04755687713623, 59.54996681213379, 76.58889525277274, 26.835025140217372, 0.34808043071201866, 0.9766547530889511, 0.7895455190113613, 0.1579207338924919, 1.559642378773008, 42.54858991077968, 30.64645426613944, 63.50694506508963, 59.77971594674246, 54.01740115029471, 47.0959392275129, 49.18817036492484, 51.039285114833284, 57.20318841934204, 53.883196694510325, 56.86049631663731, 53.61164024897984, 47.31795849118914, 48.21341800689697, 42.70066860743931, 51.2549398286002, 51.06354822431292, 59.43072182791573, 53.97287014552525, 41.898797852652415, 56.54191098894392, 52.026915958949495, 56.01569264275687, 51.23730877467564, 54.88132626669747, 45.840861797332764, 49.52908025469099, 48.676737785339355, 46.27050365720476, 51.30211809703282, 50.00985738209316, 49.91790839603969, 55.7760979107448, 48.818536622183665, 54.25530399594988, 52.82820653915405, 50.559967109135215, 52.318111487797324, 44.873210498264854, 44.178467069353374, 46.71069983073643, 45.65232937676566, 45.27201277869088, 44.797311850956504, 43.49459062303816, 42.36376435416085, 41.48767294202532, 41.65438801901681, 43.19774273463658, 43.3203124318804, 44.80891534260341, 43.30884095600673, 42.82220997129168, 43.49041475568499, 48.63894305910383, 45.04561267580305, 45.74959026064192, 45.52152606419155, 49.718039989471436, 53.234318324497764, 52.40350832257952, 51.40254735946655, 56.411065987178254, 53.628461837768555, 59.55961785997663, 50.97273874282837, 50.52523306437901, 51.182852268218994, 50.205480439322336, 43.71264941351754, 46.610270568302695, 48.1343857220241, 45.14700773784092, 44.30038363592965, 46.438879353659495, 43.84603745596749, 43.14218493870327, 41.067536217825754, 39.555823598589214, 39.08705990655081, 38.04272133963448, 38.7205285344805, 41.02128553390503, 42.16161693845476, 44.06878975459507, 45.59512485776629, 44.526061126164024, 43.52859858104161, 42.75290169034685, 48.10973003932408, 48.70464522497994, 49.26606314522879, 52.99032538277762, 50.991769858769004, 54.1613678250994, 49.48906905310494, 46.808325495038716, 51.576891558510916, 50.732216426304404, 44.263756207057405, 47.437415395464214, 47.806062494005474, 51.42154720851353, 52.24646166392735, 52.97809655325753, 58.50358894893101, 57.91815110615322, 57.021645886557444, 57.74308429445539, 55.272006102970664, 54.740698201315745, 51.240564005715505, 46.1730169568743, 46.876657554081504, 45.30672597885132, 50.97518450873238, 52.523875440870015, 56.97399166652134, 59.73669964926583, 65.61384037562779, 58.30917140415737, 64.87327357700893, 61.01205539703369, 62.966111183166504, 58.95021220615932, 65.55207783835274, 59.03700910295759, 75.58201095036098, 32.5415997505188, 0.5922243329031127, 5.715273320674896, 0.1734529161559684, 0.24468711018562317, 35.51357357842581, 82.18393216814313, 57.72433110645839, 80.61791242871965, 51.46096086502075, 40.10457495280674, 69.19656085968018, 49.16423382077898, 42.96957778930664, 63.44497408185686, 78.95755004882812, 64.22634765080043, 0.5476461563791547, 0.24925248378089496, 0.15877380168863706, 0.1249427106231451, 0.1644891428628138], [0.023634697842810835, 0.02365795463057501, 0.07240894170744078, 0.025481578561344316, 0.05889579467475414, 0.018429455546928302, 0.04960694203951529, 0.537130709205355, 48.095520973205566, 54.55011258806501, 51.48307350703648, 50.48197705405099, 106.3111001423427, 69.54360253470284, 26.931478296007427, 18.17560335568019, 47.19339118685041, 55.0612324987139, 53.80406018665859, 57.97041893005371, 42.4119987487793, 0.03812125424987503, 0.5052329408270972, 0.3055354436593396, 0.08527179434895515, 0.07007342417325292, 23.829071147101267, 29.53646911893572, 47.54734284537179, 61.72013936723982, 47.89799063546317, 48.27766105106899, 47.11336530957903, 55.74906594412667, 54.62349598748343, 52.416900975363596, 49.25043664659773, 48.87045703615461, 40.83874593462263, 40.871395519801546, 43.586876596723286, 49.05948625292097, 49.331727096012656, 61.892086437770296, 34.36063119343349, 47.12875556945801, 51.59662791660854, 52.842853341783794, 49.676896231515066, 49.55517768859863, 44.94397095271519, 45.41470793315342, 45.2002135685512, 46.83932835715157, 45.80195883342198, 44.79590136664254, 43.98198938369751, 46.57313939503261, 44.92563118253435, 45.11895786012922, 44.515308788844514, 43.372597626277376, 44.65671852656773, 41.45165000643049, 38.10834012712751, 38.67100524902344, 37.726470606667654, 38.223739283425466, 37.5256780896868, 40.09155402864729, 40.82348769051688, 38.014435223170686, 37.83926766259329, 37.8608591897147, 36.50711733954293, 36.59243427004133, 37.47083943230765, 39.780976499829976, 40.49755116871425, 40.72483369282314, 42.28003508704049, 41.1689521244594, 41.8453939982823, 45.378584248679026, 46.70446382250105, 46.08771392277309, 46.23648527690342, 51.35722426005772, 50.64777496882847, 51.67254046031407, 51.55647080285208, 50.59898124422346, 45.75793504714966, 48.91632904325213, 45.23358924048287, 42.19337715421404, 43.13575438090733, 42.46355785642351, 41.771447794778005, 40.24976451056344, 39.59944091524397, 38.16917507989066, 39.098896162850515, 37.2197002683367, 36.31025055476597, 36.275891712733674, 33.69101939882551, 36.50041927610125, 38.910902227674214, 39.58266796384539, 37.798443521772114, 37.507751737322124, 38.83963802882603, 36.1569698197501, 38.10705123628889, 37.91154629843575, 40.6726006099156, 41.453658035823274, 43.62225334984915, 41.67711557660784, 45.818703992026194, 45.537437438964844, 42.135001863752095, 46.73771790095738, 44.39660576411656, 44.38579784120832, 42.91579178401402, 43.66199009759085, 43.20312064034598, 45.2094338280814, 51.596846784864155, 51.972070353371755, 54.34797559465681, 50.90382998330252, 65.55078547341483, 57.3905257497515, 49.2470702443804, 50.15322303771973, 44.679234164101736, 44.366120542798726, 40.73322016852242, 41.38619450160435, 41.45375183650425, 47.31004796709333, 49.30814143589565, 56.56539242608206, 51.627801009586875, 58.94120734078543, 54.414198875427246, 60.17482525961739, 52.58626331601824, 60.30131026676723, 51.39031852994646, 69.63900130135673, 18.43206136567252, 0.4543034593973841, 2.089517431599753, 0.17364841566554137, 0.07774620316922665, 32.96813576562064, 64.25724628993443, 50.183458123888286, 58.164881638118196, 42.61233615875244, 33.520093713487896, 35.12004150663103, 36.169028418404714, 19.788549491337367, 51.58240147999355, 57.813462597983225, 29.536514282226562, 0.4333903044462204, 0.21504973194428853, 0.06179364810564688, 0.08555764079626117, 0.12106850636856896, 0.0494978980693434, 0.04234578613457935, 0.07348032136048589, 0.011941201918359314, 0.07084376497992448, 0.04557379434949585, 0.10897448818598475, 0.7313251516648701, 59.25614833831787, 59.20914377485003, 60.68484388078962, 50.31271546227591, 84.18253285544259, 71.03586019788469, 28.18980574607849, 26.48217477117266, 50.650849546704976, 59.73225975036621, 58.695171628679546, 64.2501938683646, 44.72739560263497, 0.013435917873201626, 0.42400575801730156, 0.6449444411056382, 0.09092340072883026, 0.07010470463761262, 25.05600142478943, 37.45898927961077, 58.28888266427176, 62.90123585292271, 49.447800227573936, 51.61852169036865, 50.573689801352366, 57.15759434018816, 54.22797325679234, 53.37367834363665, 50.71327911104475, 51.24354478291103, 41.895282064165386, 42.85481786727905, 45.00080721718924, 51.54248060498919, 51.988551480429514, 63.712299074445454, 36.753899982997346, 48.784629413059776, 53.73428290230887, 53.46690927233015, 50.97764417103359, 50.197264194488525, 46.90736511775425, 47.29121140071324, 46.70664208275931, 48.52091748373849, 47.60630873271397, 47.93296439307076, 45.58763122558594, 48.3368353843689, 48.268155915396555, 47.47304923193795, 46.96680000850132, 47.57970060620989, 46.34092017582485, 44.90962948117937, 39.39191211972918, 42.88211039134434, 41.434880529131206, 41.60042830875942, 40.118495668683735, 41.78838055474417, 42.57080330167498, 40.625509193965364, 39.913923331669395, 39.606521129608154, 36.94112614222935, 38.9132194519043, 39.65643351418631, 41.11790023531233, 42.52217285973685, 41.50309794289725, 45.58614083698818, 42.1345328603472, 42.75504868371146, 46.412055832999094, 49.96151876449585, 46.7366235596793, 47.27092613492693, 53.29119627816336, 53.12334169660296, 53.63067831311907, 53.497140884399414, 50.48130307878767, 47.80887304033552, 52.81955255780901, 48.098710196358816, 42.7720057623727, 44.46832159587315, 45.24566173553467, 43.62312534877232, 42.70824909210205, 41.38417257581438, 38.86182362692696, 38.990823881966726, 39.53287717274257, 38.09179646628243, 37.72547006607056, 36.80641794204712, 37.40644700186593, 39.552943570273264, 41.556314195905415, 39.308328764779226, 40.643612725394114, 41.21510900769915, 40.0476518358503, 40.950261047908235, 42.47720759255545, 43.94832536152431, 44.734979561397004, 46.92570488793509, 46.73238515853882, 49.398631300245015, 46.157380035945344, 43.74756063733782, 47.686636856624055, 45.931553159441265, 43.858881201062886, 45.615625517708914, 46.987005370003835, 46.51333972385952, 46.84895508629935, 52.58458532605852, 53.8799101965768, 56.425080503736226, 52.23210668563843, 61.15707124982561, 60.53056607927595, 51.929238183157786, 55.06089898518154, 46.681204727717805, 46.52244186401367, 43.13630676269531, 43.60745716094971, 44.61950397491455, 50.713550090789795, 50.6618971824646, 57.797596386500764, 54.95135368619646, 62.144180979047505, 56.25176811218262, 61.665366717747276, 55.891299043382915, 65.35085105895996, 55.67648158754621, 74.63185174124581, 18.1510796887534, 0.2730094332780157, 2.6280340892927985, 0.09364009888044425, 0.23012626437204226, 37.46125091825213, 72.8108470099313, 57.45145102909633, 64.73631068638393, 44.28972857339041, 31.088429178510392, 40.84038570949009, 43.5325243132455, 22.138564007622854, 54.0243250301906, 67.88759667532784, 38.25963020324707, 0.5565597180809293, 0.07870337859328304, 0.12365329052720751, 0.1590550544538668, 0.08379092559750591, 0.15348306058772973, 0.10861557030252048, 0.1941441223025322, 0.11313730052539281, 0.31121494461383137, 0.14078412843602045, 0.23973198607563972, 1.4202070151056563, 71.29515307290214, 69.291230065482, 61.27829647064209, 60.929024423871724, 109.51242705753872, 80.88852391924176, 41.39923974445888, 27.807067700794764, 61.312891551426475, 64.22396441868374, 65.11458451407296, 66.57961218697685, 50.68038633891514, 0.1333417392202786, 0.7535493448376656, 1.2280292872871672, 0.2116949598171881, 0.13495965168944427, 30.36306503840855, 31.084430490221294, 49.27330664225987, 66.32021508898053, 50.36596993037632, 54.444889068603516, 51.37816265651158, 61.559309414454866, 57.91633415222168, 57.60729912349156, 54.048087869371685, 54.24743168694632, 44.10214458193098, 45.231098311288015, 46.50101014545986, 53.379427977970664, 51.014083998543875, 62.76437023707798, 40.99692862374442, 48.66743762152535, 55.67030463899885, 54.61417497907366, 53.14718096596854, 53.92092193875994, 50.90750905445644, 50.518997056143625, 49.00156259536743, 50.78150347300938, 52.08594785417829, 48.563252857753206, 49.598656041281565, 50.09681061335972, 51.05182661328997, 51.06436811174665, 51.109003339494976, 51.44846452985491, 50.45257575171334, 48.132443700517925, 42.742072922842844, 45.910621711185996, 45.43036222457886, 47.48137664794922, 44.83880649294172, 46.55144017083304, 46.00645474025181, 43.36718150547573, 42.10820960998535, 41.42654269082205, 38.98188155038016, 40.06384808676583, 40.75731652123587, 44.54858718599592, 44.73347527640206, 43.68221977778843, 48.9568509374346, 44.304291997637065, 47.423421723502024, 49.76682676587786, 51.93870857783726, 50.23688282285418, 48.99866172245571, 57.29431404386248, 53.43416588647025, 55.166094711848665, 54.763533455984934, 53.37641245978219, 50.36202335357666, 53.10762487139021, 51.024315220969065, 46.41102402550833, 45.9861729485648, 46.00090312957764, 45.91710785457066, 44.903303146362305, 44.82855095182146, 42.60019418171474, 43.00495106833321, 41.585055419376914, 40.18691805430821, 38.885527406420024, 38.24120705468314, 40.56179421288626, 44.40804597309658, 46.796774114881245, 43.669059889657156, 45.61238070896694, 46.18986286435808, 42.861807755061555, 44.21851996013096, 45.35507154464722, 46.99934537070138, 46.89566087722778, 51.34733349936349, 51.65194599969046, 52.555517537253245, 50.17398425510952, 46.04908888680594, 49.87514223371233, 48.35363612856184, 45.57952267783028, 47.40350471224104, 48.43825823920113, 47.5122857093811, 48.117018699645996, 54.88678060259138, 55.43938473292759, 58.6065126146589, 52.79039444242205, 59.74050726209368, 63.33285794939314, 54.06999206542969, 56.820300987788606, 47.12769249507359, 48.0891112600054, 45.68713985170637, 45.504211153302876, 47.62961993898664, 53.29161317007882, 52.46082053865705, 61.821180071149556, 57.64573655809675, 63.42410864148821, 58.33968094417027, 66.05502319335938, 57.95254468917847, 67.86731488364083, 58.63729313441685, 79.28846495492118, 21.57873375075204, 0.3034919947385788, 3.565997907093593, 0.23150711027639254, 0.44491307756730486, 41.68460920878819, 79.77731936318534, 63.86536094120571, 71.63603169577462, 56.77315051215035, 43.63307516915457, 49.316180501665386, 51.69599757875715, 26.589588710239955, 69.58586147853306, 75.52353491101945, 52.75809921537127, 0.6373616222824369, 0.3945845610329083, 0.23821252903767995, 0.3217764236032963, 0.2917356698640755], [0.12214397080242634, 0.08135520879711423, 0.0009311230720153876, 0.021021993664492453, 0.07503751173083271, 0.04635302735758679, 0.06524342192070824, 0.9323232918977737, 52.2048419543675, 54.21492106573922, 24.641423259462627, 34.19035863876343, 101.13982691083635, 63.746727398463655, 47.562889439719065, 14.80993938446045, 46.873992919921875, 57.459333760397776, 53.21931716373989, 50.16721670968192, 54.88702726364136, 1.773456145610128, 0.06079125510794776, 0.4191594166415078, 0.3046742470136711, 0.25185716258628027, 9.738259894507271, 32.57614271981375, 35.30954320090157, 64.58670902252197, 47.91624355316162, 52.879223687308176, 51.12993826184954, 55.166542870657786, 52.55146326337542, 53.020935671670095, 47.87703486851284, 43.98366042545864, 38.9853104863848, 43.9697014944894, 49.54604428155081, 50.44160802023751, 56.650306361062185, 47.61870084490095, 36.373176915305, 48.303734166281565, 52.65649223327637, 53.16062920434134, 49.560444423130576, 50.26103476115635, 47.666657311575754, 48.76958656311035, 45.79036576407296, 48.912417207445415, 44.75845405033657, 45.70936713899885, 43.48434550421578, 44.65545742852347, 43.839335918426514, 44.16204847608294, 44.91438552311489, 43.23804576056344, 42.79248557771955, 42.8228075163705, 38.48379646028791, 36.390491826193674, 37.912185532706125, 38.558958598545615, 37.15828514099121, 35.97198792866298, 38.76692860467093, 38.27618776048933, 39.12967668260847, 40.841184752328054, 36.3687926019941, 36.61300093787057, 34.504980019160676, 38.65050458908081, 39.101116112300325, 42.51085077013288, 41.141572747911724, 43.5041617665972, 40.84812947681972, 44.378398009708945, 42.13827099118914, 46.029988288879395, 48.23458569390433, 50.06599187850952, 49.994046756199424, 50.614472252982004, 53.87980597359793, 50.76058939525059, 49.56059380940029, 47.83394908905029, 43.15923234394619, 42.00750241960798, 44.376410824911936, 42.665503774370464, 42.23244687489101, 41.59155545915876, 40.95758097512381, 39.34613043921334, 38.74525369916643, 37.926325116838726, 36.055484431130544, 36.21595655168806, 36.21190922600882, 35.73178175517491, 38.08778040749686, 41.18762540817261, 37.245102882385254, 39.31768104008266, 39.38050665174212, 34.81079455784389, 36.88708305358887, 40.505347047533306, 40.64061805180141, 41.95429311479841, 42.047913142613, 42.93983602523804, 45.144874640873496, 42.53315448760986, 43.40693909781319, 46.38924837112427, 44.1464011328561, 47.07131133760725, 46.222397804260254, 49.320554392678396, 44.82028954369681, 47.6162759235927, 46.979063579014365, 55.833340644836426, 52.23003959655762, 60.24298013959612, 69.25032602037702, 51.492047105516704, 50.77199486323765, 50.10955013547625, 47.570733955928254, 54.528642654418945, 48.49230132784162, 45.306628704071045, 40.02071019581386, 44.04026045118059, 42.915732724326, 48.95814677647182, 48.24166243416922, 54.89456605911255, 50.91332122257778, 54.46148484093802, 52.997575828007285, 61.64014475686209, 53.82319899967739, 63.6457005909511, 6.228780371802194, 0.1768194269388914, 2.1927231507641927, 0.04092965980193444, 0.5780631984983171, 44.9127631187439, 57.27587005070278, 55.65265621457781, 51.50646461759295, 53.99404130663191, 29.08929000582014, 35.446044036320274, 33.83615337099348, 32.18192972455706, 52.02968481608799, 58.4010682787214, 33.96947193145752, 0.36078054351466043, 0.07194100360253028, 0.08502885845622846, 0.052501056742455275, 0.1029166021783437, 0.04838227114773222, 0.05614973292020815, 0.09073337699685778, 0.039942279391522915, 0.0393031027966312, 0.03673084100176181, 0.0801721897774509, 1.2361034197466714, 63.821719305855886, 61.14339024680001, 35.75268193653652, 39.53696271351406, 96.84055955069405, 66.45471136910575, 40.02653626033238, 15.967193126678467, 57.08179644175938, 60.684718813214985, 59.256398473467144, 56.04963459287371, 60.13519968305315, 2.059206783771515, 0.048232925590127707, 0.681009934416839, 0.46976086710180553, 0.37281884040151325, 10.524152398109436, 36.741080556597026, 46.32499837875366, 65.75555583408901, 49.286973748888286, 55.30290126800537, 52.04192754200527, 59.18023926871163, 54.634185791015625, 54.64194345474243, 49.204144273485454, 46.57793365206037, 40.10444988523211, 44.79185404096331, 49.44347497395107, 52.76464441844395, 57.61362893240792, 51.98262814113072, 36.40400259835379, 51.023644719805034, 52.22832686560494, 55.68527453286307, 52.84675822939192, 51.45948437282017, 47.35047606059483, 51.0937624658857, 48.242447580610005, 51.43485995701381, 45.86014652252197, 48.6153678212847, 46.61179569789341, 44.73750523158482, 47.25528226579939, 47.59368732997349, 47.90148210525513, 46.149365288870676, 45.5287869317191, 45.84899466378348, 41.91427843911307, 38.891909326825825, 41.39094359534127, 40.99249914714268, 41.44656392506191, 39.93470886775425, 41.58050434929984, 40.160733767918174, 40.366824286324636, 41.37123155593872, 39.766961983272004, 38.41682277406965, 37.87099313735962, 40.85562310900007, 40.07103599820818, 44.43350417273385, 42.67401531764439, 43.70925521850586, 43.44224636895316, 45.7824204989842, 44.42921366010393, 46.45507213047573, 48.985442774636404, 51.408199719020296, 51.0441940171378, 51.98789487566267, 54.67079584939139, 52.20363644191197, 47.897208963121685, 47.522371019635884, 44.081765515463694, 42.65737438201904, 46.21270159312657, 46.159207412174766, 43.77766718183245, 43.146788120269775, 40.44323362622942, 41.17107827322823, 40.147160461970735, 39.06942537852696, 39.085638999938965, 38.00100435529436, 38.115458556583945, 38.3951860836574, 42.086569445473806, 43.81799452645438, 40.10898011071341, 40.798241410936626, 41.9024213382176, 38.41800396783011, 41.85744217463902, 43.46932002476284, 44.677663871220176, 44.857417242867605, 45.19816037586757, 45.60538387298584, 47.02140242712838, 43.15597711290632, 45.8730354309082, 47.27010972159249, 45.47697074072701, 49.37440987995693, 49.593545641217915, 51.40241881779262, 46.63553769247872, 49.43793725967407, 49.533871037619456, 56.15087332044329, 55.27208948135376, 57.61886787414551, 67.71757425580705, 54.06251580374581, 52.89011498859951, 53.7679260798863, 52.02739191055298, 53.71290329524449, 50.62028442110334, 46.66902800968715, 42.526605810437886, 47.04886518205915, 44.48345477240426, 50.46471425465175, 52.77848175593785, 57.378682545253206, 52.186345849718364, 60.34011595589774, 53.90331867762974, 63.342578479221885, 56.444768224443706, 71.07372788020542, 6.427676464830126, 0.13362008785562857, 2.90006713782038, 0.07239108945110015, 0.9463493164096559, 50.36509445735386, 65.79072066715786, 61.07336630140032, 58.17013100215367, 59.069915771484375, 33.90227937698364, 39.707443714141846, 42.906449931008474, 27.922249725886754, 56.28650563103812, 66.37800325666154, 41.86548124040876, 0.41123985445925165, 0.10481808800250292, 0.09146955356534038, 0.04965676347325955, 0.10082032930638109, 0.27191699189799173, 0.1358270501451833, 0.2107094826975039, 0.1484634213681732, 0.21277123849306787, 0.1112108106857964, 0.1896625884941646, 2.4984247812203, 74.20872729165214, 70.18472671508789, 34.06674671173096, 45.50701822553362, 108.22056933811733, 67.22889355250767, 60.809084619794575, 23.128355741500854, 60.654848507472444, 67.20048236846924, 65.50575419834682, 59.12476485116141, 65.97919055393764, 2.3102834139551436, 0.1908078741814409, 1.2407741291182381, 0.9539760500192642, 0.58797366384949, 12.582029904638018, 35.12063905170986, 37.41647325243269, 69.80477837153843, 51.18766042164394, 58.65157168252127, 54.23064136505127, 62.27351474761963, 57.922785554613384, 57.94743428911482, 49.86321565083095, 49.38200773511614, 40.8320756639753, 48.27044882093157, 51.42557716369629, 55.3448440687997, 57.04499878202166, 52.566690240587505, 38.80330242429461, 50.196604115622385, 56.06913818631853, 57.1410402570452, 54.191936424800325, 54.720520632607595, 52.15677431651524, 53.06928471156529, 50.11691870008196, 55.447215352739605, 47.655679157802034, 50.77493395124163, 48.603427342006135, 48.25135517120361, 47.83651644842965, 50.27530983516148, 53.4102988243103, 51.82206221989223, 49.9395763533456, 49.50259024756295, 44.590814862932476, 43.09523596082415, 46.309514318193706, 45.509245123182026, 43.92722020830427, 42.33334861482893, 45.282018184661865, 43.61792114802769, 43.10780872617449, 44.81854901994978, 43.45946053096226, 41.07228878566197, 40.66511045183454, 42.944171701158794, 43.21896948133196, 46.80797461100987, 46.38388436181204, 47.43474381310599, 46.84859725407192, 48.97901569093977, 45.67308712005615, 50.959512846810476, 53.648458753313335, 52.926822321755544, 53.57400533131191, 52.97664785385132, 58.732240268162315, 54.27630145209176, 51.63888686043875, 50.10974815913609, 47.635716983250205, 44.891657965523855, 48.72892917905535, 47.36834682737078, 46.33916922977993, 46.27813972745623, 45.54053633553641, 43.142945766448975, 42.40654788698469, 41.03012364251273, 40.929638794490266, 39.61575528553554, 41.64903443200247, 42.01159838267735, 44.46991273335048, 47.67548499788557, 43.732594217572895, 46.16373068945748, 46.35434062140328, 41.22912352425711, 45.56808941704886, 46.19373301097325, 48.517863750457764, 47.95947871889387, 49.95273276737758, 49.36933422088623, 50.25117874145508, 46.73208638599941, 47.14218643733433, 50.37593364715576, 49.02549566541399, 52.755087171282085, 51.38942221232823, 52.106907095227925, 49.43742656707764, 51.11025401524135, 52.58904954365322, 58.083323683057515, 57.39645256314959, 54.361031259809224, 68.64465154920305, 59.53813402993338, 54.91302047457014, 57.182138851710725, 53.24240255355835, 59.177362714494976, 52.581149441855295, 51.403551374162944, 44.65965761457171, 49.840338706970215, 46.137150355747764, 54.32055452891758, 52.90546008518764, 60.47684955596924, 54.47548198699951, 61.822437695094514, 56.71550825663975, 66.81879002707345, 57.6932726587568, 75.92443207332066, 8.607973848070417, 0.2200496665069035, 4.121814276490893, 0.18410800583660603, 1.2626007007701057, 54.93584878104073, 71.32220241001674, 66.25409603118896, 64.26862049102783, 65.65460545676095, 40.45234966278076, 50.096831457955496, 48.996976784297395, 41.144060203007285, 68.01759052276611, 75.20527962275914, 54.20422083990914, 0.4251494695033346, 0.290864105203322, 0.218529381656221, 0.10793953907809087, 0.23999865033796855], [0.1405379016484533, 0.0068689728421824315, 0.10795975263629641, 0.025920319304402386, 0.13506174406835011, 0.04666238843596407, 0.20546101432825836, 0.2851332255772182, 53.524617535727366, 51.18406125477382, 45.52085903712681, 56.77471038273403, 99.528365952628, 59.48222187587193, 49.42051812580654, 32.97940921783447, 22.18725003514971, 64.5985209601266, 44.295853410448345, 54.57591472353254, 55.828827789851594, 8.6057573727199, 0.5562116024749619, 1.278829304235322, 0.37799779964344843, 0.035194949845650365, 0.7845961760197366, 29.91405507496425, 31.009376049041748, 59.02790696280343, 48.274447509220664, 55.4822655405317, 51.614707129342214, 58.23949139458792, 51.11929014750889, 51.51021664483206, 41.65083401543753, 41.58702870777675, 39.29601308277675, 48.66308804920742, 51.256360735212056, 53.82496731621878, 52.38218082700457, 42.75375631877354, 42.468807220458984, 49.65131991250174, 54.262297357831685, 51.65313066755022, 51.099536418914795, 51.80172136851719, 51.11051457268851, 51.79104893548148, 47.59509086608887, 50.11525808061872, 45.532017844063894, 45.49578993661063, 41.83901902607509, 44.17839411326817, 45.54372903278896, 44.33465562547956, 45.54775898797171, 46.31300231388637, 43.79231398446219, 43.50317859649658, 39.23660251072475, 38.653481892177034, 37.518333843776155, 37.77059514181954, 35.09600073950631, 35.85531725202288, 37.41328750337873, 37.26307092394148, 37.55997439793178, 39.286014625004356, 38.11813708714077, 37.53833075932094, 37.3145431791033, 37.48444053104946, 37.27638367244175, 41.990687779017854, 41.69320413044521, 41.03850664411272, 39.499167987278526, 45.19030196326119, 40.68902267728533, 48.059143679482595, 49.33828966958182, 53.06058209283011, 46.06063331876482, 44.399614334106445, 52.94962978363037, 51.712148666381836, 47.70884677342006, 44.51852927889143, 46.10066883904593, 44.65648923601423, 45.579199586595806, 42.378973960876465, 41.12287514550345, 40.34629583358765, 38.135361671447754, 40.05151850836617, 37.078540665762766, 35.772150788988384, 35.80475868497576, 40.097897733960835, 38.62795421055385, 38.858405113220215, 37.211084502083914, 38.43857063565935, 36.18506833485195, 38.020240443093435, 41.00992175510952, 37.53934519631522, 37.06280299595424, 42.31824670519148, 41.89694268362862, 42.039276531764436, 42.462703227996826, 43.8710857118879, 46.09884146281651, 42.504844052451, 44.208987031664165, 45.14183827808925, 46.50698907034737, 51.94694219316755, 51.78008120400565, 50.48985283715384, 51.967998708997456, 49.67824418204171, 49.50561271395002, 53.157846450805664, 52.08533293860299, 65.46450969151088, 39.366578987666536, 50.5266227040972, 54.19586215700422, 55.85274348940168, 53.430288791656494, 52.63559900011335, 53.89926092965262, 52.04900428227016, 41.966713019779746, 44.705877031598774, 39.929282324654714, 43.72498594011579, 43.26660285677229, 46.86003051485334, 45.4082704271589, 52.39921086175101, 51.96455587659563, 56.773101874760215, 56.024336201804026, 56.89771086829049, 1.2693761714867182, 0.3386876332972731, 1.3149915294987815, 0.13093129784933158, 1.5491015272481101, 56.75871910367693, 52.79803051267351, 58.35065214974539, 55.134393555777415, 71.35496316637311, 30.10832323346819, 29.993823868887766, 42.61464296068464, 33.95713540485927, 50.507591588156565, 58.80069392068045, 26.38774527822222, 0.585198347057615, 0.11622535410736289, 0.052808443283928294, 0.10789379903248378, 0.023020964614780884, 0.09987898410430976, 0.01489443059212395, 0.11718621397657053, 0.033231381459959915, 0.046115502781633816, 0.04165754806516426, 0.06532672566494771, 0.5111473777464458, 60.30147702353341, 59.136535099574495, 40.26154170717512, 53.66871970040457, 103.43123163495744, 63.528164863586426, 54.67722988128662, 32.34855447496687, 29.996043818337576, 67.24320684160504, 49.09367833818708, 57.347665786743164, 62.41029698508126, 10.260949424334935, 0.5186856303896222, 1.8106386704104287, 0.6837851426431111, 0.019855274752314602, 0.8882737755775452, 32.30315841947283, 37.47309412275042, 66.59319591522217, 50.97776229040963, 57.27582836151123, 54.149986675807405, 60.27370507376534, 53.6700051171439, 53.68050037111555, 44.27692304338728, 45.06383432660784, 41.79034342084612, 50.123842579977854, 52.94239323479788, 54.67350217274257, 53.50462409428188, 43.577072688511436, 42.09240245819092, 51.2225056375776, 54.6885415485927, 53.55140284129551, 52.048476219177246, 55.36417743137905, 52.7470064163208, 53.987840039389475, 50.11967018672398, 53.16925886699131, 48.48627029146467, 46.70974097933088, 45.32630947657994, 46.55619968686785, 47.98380436216082, 49.74914012636457, 47.50872475760323, 47.80233131136213, 46.49471507753645, 47.6060551234654, 43.710297448294504, 41.476548876081196, 39.54628719602312, 40.84245974676949, 38.44732189178467, 39.2719202041626, 41.6255008833749, 38.65174136843, 39.53081703186035, 42.20574842180525, 40.40086351122175, 38.56423922947475, 38.90184872491019, 39.23901006153652, 40.25228670665196, 45.023590360369, 43.00035483496529, 43.749665941510884, 41.2989181791033, 46.15797063282558, 44.80183860233852, 48.20443398611886, 49.35454498018537, 53.9554614339556, 46.351797580718994, 45.049458503723145, 55.610779421670095, 52.55175161361694, 47.53416558674404, 47.45359427588326, 47.09004020690918, 45.65382671356201, 46.130174364362446, 44.87013244628906, 42.76299047470093, 41.19975001471383, 39.15919263022286, 41.03084972926548, 38.29890489578247, 38.20695243562971, 38.85430915015084, 41.00249065671648, 41.55519206183297, 40.67696060453142, 39.85509640829903, 41.72447449820382, 39.066951819828574, 41.1446646962847, 43.0683707509722, 40.35127421787807, 41.362709590366904, 46.30907310758318, 45.87543603352138, 48.09217888968331, 45.70608064106533, 47.27157579149519, 48.1477575302124, 44.45039176940918, 47.00644295556204, 46.848729269845144, 48.547303267887656, 53.75227178846087, 54.675982679639546, 53.55132988521031, 52.82923834664481, 51.47036872591291, 51.459803989955354, 54.45913634981428, 52.67565189089094, 64.19235706329346, 44.00677013397217, 51.774696350097656, 55.66376291002546, 55.89325843538557, 56.69662652696882, 56.36656972340175, 55.383597646440776, 54.09934820447649, 45.478405543736045, 45.54966974258423, 42.90993792670113, 47.41350317001343, 46.284184660230366, 49.27701003210885, 49.4090119089399, 54.26045955930437, 55.027870723179404, 60.46706649235317, 60.041253089904785, 61.93142018999372, 1.1861985261951173, 0.5061623709542411, 2.3653431109019687, 0.10878890207303421, 2.0847922222954884, 62.60680593763079, 59.07944175175258, 63.31286103384835, 60.72594942365374, 75.61425754002163, 36.882726533072336, 34.59323256356375, 50.64697592599051, 32.64239031927926, 56.12583896092006, 65.10954707009452, 33.57977179118565, 0.6064563606466565, 0.18406999430486135, 0.08117655052670411, 0.19319396971591882, 0.09190083042319332, 0.37207226189119474, 0.12253909531448569, 0.20784055521445616, 0.10133373604289123, 0.18062233073370798, 0.13326662539371423, 0.19140240656478064, 0.8512935627784047, 74.3195858001709, 67.5256233215332, 56.753921372549875, 69.76197052001953, 103.687363079616, 68.11661624908447, 58.83361448560442, 42.551654066358296, 35.780384404318674, 73.22450801304409, 54.478459290095735, 62.60370009286063, 67.00977516174316, 11.459310446466718, 0.6555520061935697, 2.623755084616797, 0.8112880608865193, 0.07113526362393584, 1.1198007805006844, 35.047926153455464, 31.86237164906093, 64.76167855943952, 53.95571851730347, 61.63990156991141, 55.32102911812918, 61.112046922956196, 56.435165813991, 57.312660762241904, 45.85242012568882, 47.31708301816668, 44.126355579921174, 54.75530678885323, 54.55439615249634, 58.41277599334717, 54.533228465488975, 44.48410790307181, 43.58136667524065, 52.57464940207345, 58.19643340791975, 56.30551242828369, 56.24894714355469, 57.86876678466797, 55.70731769289289, 56.83976289204189, 52.819264207567485, 54.36389739172799, 50.75552763257708, 50.64190026691982, 47.611175945826936, 48.806446756635395, 50.822626386369976, 54.020955153873985, 53.966985021318706, 51.58756399154663, 49.005425793784006, 50.87395620346069, 47.696687425885884, 45.37080226625715, 43.04872819355556, 42.71391882215227, 42.74563734872, 42.74955265862601, 44.77458429336548, 44.377807412828716, 41.774723870413645, 45.52956165586199, 43.76635898862566, 43.34106322697231, 40.72103302819388, 42.23063686915806, 43.11336728504726, 46.059031758989605, 45.27815498624529, 45.33483491625105, 44.042893818446565, 49.418617793491904, 44.32123517990112, 50.450171675000874, 52.40698937007359, 55.53930330276489, 46.13440234320504, 45.56258644376482, 58.18692479814802, 55.469442640032085, 51.46881580352783, 48.131655079977854, 49.93884679249355, 48.943913391658235, 50.42330299104963, 46.58558014460972, 44.83492592402867, 43.06538649967739, 40.75881733213152, 44.19204732349941, 39.69780656269619, 39.96817486626761, 39.862138407570974, 43.97729240145002, 43.88181373051235, 45.048788002559114, 41.574157169886995, 44.66088744572231, 43.462080001831055, 44.887301445007324, 50.500268186841694, 43.81783471788679, 43.75479023797171, 48.937173639025005, 50.87383460998535, 50.22812114443098, 49.23135689326695, 51.64027302605765, 53.32047598702567, 45.934718063899446, 49.10294723510742, 48.535341944013325, 51.25319930485317, 57.01538208552769, 56.74846356255667, 53.6222744669233, 55.43702234540667, 54.90007945469448, 53.81764391490391, 57.58780247824532, 55.17454024723598, 62.920072419302805, 49.30385439736502, 53.42031812667847, 58.540150369916645, 59.29712186540876, 56.3702974319458, 58.44270188467843, 59.637243134634836, 56.653443472726, 47.44750417981829, 48.183457374572754, 44.2187944139753, 48.16192143304007, 49.13964067186628, 51.88961260659354, 49.77285432815552, 58.74386460440499, 55.87896946498326, 62.85717732565743, 61.658355985369, 69.35407652173723, 2.053829095193318, 1.1138356434447425, 3.5630234267030443, 0.19442602646137985, 2.931329905986786, 66.40649087088448, 65.02088805607387, 69.72923755645752, 66.27794224875313, 82.9307940346854, 43.547591481889995, 43.576808656964985, 59.83396053314209, 46.44479921885899, 66.20046288626534, 74.20516981397355, 43.51221820286342, 0.7270230225154332, 0.3876836970448494, 0.2041167143200125, 0.20760513070438588, 0.22928173254643167], [0.005469433298068387, 0.057425117519284995, 0.0487068483739027, 0.03781027486547828, 0.09470730554312468, 0.028212120523676276, 0.21732262069625513, 0.13514486460813455, 52.50752632958548, 57.502405643463135, 50.735537665230886, 35.398865767887656, 65.88789817265102, 46.41552298409598, 42.43003279822213, 30.63251617976597, 25.70856581415449, 60.00332982199532, 46.565131596156526, 50.1593930380685, 56.34566954204014, 19.187400034495763, 0.4253702919398035, 0.7789407766291073, 0.4505743666418961, 0.05516579268234117, 0.12021760988448348, 18.15664519582476, 33.48080859865461, 52.25914907455444, 57.574566159929546, 53.0234682900565, 56.38476358141218, 52.044109276362825, 51.73310095923287, 50.8933937890189, 43.46589803695679, 43.36223438807896, 43.03817735399519, 49.708771092551096, 51.854176793779644, 54.21343762534005, 48.31926686423165, 43.37440415791103, 47.089564255305696, 44.54056201662336, 53.18366248267037, 51.54404047557286, 54.040139130183626, 51.79435975211007, 52.67874731336321, 51.595054149627686, 48.274447509220664, 48.22528553009033, 48.39028787612915, 43.604615347726, 45.225348676954, 43.397757053375244, 51.21791287830898, 43.85515349251883, 44.83963680267334, 44.56611054284232, 46.4977514403207, 45.05498579570225, 41.612486907414024, 36.2361410685948, 38.871363503592356, 39.17466279438564, 35.063455377306255, 36.8299480165754, 37.58436952318464, 36.595276083265034, 38.5312283379691, 37.797901562282014, 37.327511991773335, 39.28554562159947, 39.14138787133353, 37.23180055618286, 38.483369146074565, 36.48951060431344, 43.553653785160606, 41.34280300140381, 41.41722515651158, 40.473489556993755, 45.56961107254028, 47.54836770466396, 51.006718908037456, 46.70919901984078, 36.78755358287266, 37.96068395887102, 45.072439670562744, 51.87806122643607, 48.82349763597761, 45.600311688014436, 43.54083783285958, 42.55606617246355, 43.05685411180769, 44.831392765045166, 42.036094256809776, 42.42895930153983, 39.115273066929404, 37.43445519038609, 37.626416546957834, 38.34095886775425, 39.53162997109549, 41.433661120278494, 38.94817236491612, 34.8790397644043, 35.32280731201172, 37.075931617191856, 38.73981325966971, 37.12721279689244, 35.57555845805577, 35.7486172403608, 37.47903135844639, 40.298290729522705, 43.23235171181815, 44.31191417149135, 43.69904831477574, 42.98363746915545, 46.30757924488613, 40.83480978012085, 44.840060642787385, 43.91387619291033, 50.07424981253487, 46.39155864715576, 48.34066731589181, 49.756241185324534, 52.43437916891915, 50.961517402103965, 52.394757066454204, 51.91980252947126, 59.5299004146031, 51.23162167412894, 38.716752188546316, 56.65471499306815, 47.77112695149013, 52.4557900428772, 48.06816244125366, 57.77792951038906, 54.144139766693115, 54.201736858912874, 49.76392936706543, 45.78701325825283, 42.13583217348371, 45.20733894620623, 41.95848287854876, 47.05538259233747, 46.27449887139456, 51.907601492745535, 55.40003708430699, 56.826877457754954, 58.39394637516567, 33.813460554395405, 0.3374471627175808, 0.4947309015052659, 0.3368830287030765, 0.04872424940445593, 6.373736730643681, 67.07847200121198, 47.92676659992763, 64.06446852002824, 49.74519007546561, 72.47114263262067, 30.456883089882986, 32.9042192867824, 40.10939005443028, 27.21763116972787, 46.65163319451468, 57.2718539919172, 15.711117267608643, 0.689359823507922, 0.24908645983253205, 0.03339395166507789, 0.007295321839462433, 0.07276324555277824, 0.07502639054187707, 0.02931336759190474, 0.0869697400235704, 0.04210520136569228, 0.03719814128375479, 0.04978762573695608, 0.22977861016988754, 0.3666666176702295, 60.414753505161826, 64.36008657727922, 52.10305084500994, 45.84398848669869, 75.38839939662388, 53.69294112069266, 47.834636960710796, 34.38066979816982, 26.60417124203273, 66.71593584333147, 51.11340849740164, 56.061036586761475, 62.560009820120676, 22.01414261545454, 0.5359859934874943, 0.985285718526159, 0.4735952956335885, 0.0315190610209746, 0.09292100782373122, 19.594521045684814, 38.80781180518014, 56.21085017068045, 59.14724922180176, 56.76091820853097, 57.494078227451865, 54.74623244149344, 55.088122027260916, 53.73901115145002, 46.2345814704895, 44.505147048405235, 43.68423822947911, 50.935948031289236, 51.67877994264875, 53.970611980983186, 48.70734460013253, 44.56226471492222, 46.50614833831787, 46.76280437197004, 55.173265252794536, 52.751811095646445, 56.49768917901175, 52.66960000991821, 52.68965598515102, 51.80008159364973, 51.24380881445748, 52.39010524749756, 50.319330147334504, 45.41919994354248, 48.14184808731079, 45.96878508159092, 52.86023773465838, 47.64228303091866, 49.210814544132774, 50.25055340358189, 49.38052429471697, 48.74457304818289, 45.95131731033325, 41.72975165503365, 41.851272174290244, 40.92737020765032, 38.944826807294575, 40.38953447341919, 40.184163093566895, 40.27950280053275, 40.82351895741054, 41.33780377251761, 38.889404501233784, 41.199670110430034, 40.24070405960083, 38.902404580797466, 39.93927730832781, 40.35504361561367, 45.444654669080464, 42.56888212476458, 43.08688422611782, 42.56712075642177, 46.857466629573274, 48.82472051892962, 52.623672417231965, 46.948425497327534, 38.098522322518484, 37.625155448913574, 47.60968903132847, 52.49951158251081, 51.37177031380789, 46.88438047681536, 45.51334456035069, 44.84930174691336, 44.95751646586827, 45.509877409253804, 44.47728477205549, 43.94616099766323, 40.82348769051688, 39.6371487889971, 40.4177372114999, 39.760944843292236, 40.784570830208914, 43.40453502110073, 41.73201676777431, 38.6562750680106, 40.497276714869905, 39.624718461717876, 42.79195751462664, 41.15224518094744, 39.862874916621614, 40.31663744790213, 41.54375185285296, 44.08780697413853, 48.220209871019634, 48.169703415461946, 47.97879123687744, 47.21580260140555, 49.3600618498666, 43.35387570517403, 47.4318186214992, 44.07505008152553, 52.39212369918823, 49.49216447557722, 50.43596955708095, 51.99910926818848, 54.48049858638218, 52.552387373788015, 53.47555977957589, 52.683364391326904, 59.29472473689488, 50.50375965663365, 40.04309729167393, 56.039677824292866, 50.71225077765328, 54.90963322775704, 49.70540816443307, 55.917393003191265, 58.32839706965855, 55.22217014857701, 52.69111510685512, 47.83949375152588, 44.328704493386404, 48.230454989842, 44.3131023134504, 48.43699366705758, 49.98769957678658, 54.570668833596365, 57.692654269082205, 60.498687744140625, 60.234989711216514, 37.416796343667166, 0.41628248244524, 1.2018891870975494, 1.1105738984686988, 0.07078017946332693, 7.918582269123622, 73.67705113547188, 55.56606081553868, 73.33209392002651, 53.00142165592739, 77.13559341430664, 36.35187373842512, 39.91557352883475, 48.768189975193565, 27.721469368253434, 53.22989232199532, 66.42755086081368, 21.594992535454885, 0.7708944369639669, 0.34490143986684935, 0.06523197503494364, 0.02424731318439756, 0.0478720195990588, 0.11910015770367213, 0.19184721341090544, 0.20990436018577643, 0.1679216751030513, 0.21758567515228475, 0.125255732397948, 0.3268236384860107, 0.45290035754442215, 68.55174023764474, 75.89606257847377, 65.03114359719413, 52.248466219220845, 75.71252591269356, 59.76083074297224, 56.76311036518642, 42.401861327035085, 37.1649797303336, 71.40075874328613, 57.695989404405864, 59.696546009608674, 68.50461060660226, 24.173382180077688, 0.6761206282036645, 1.7467263170651026, 0.581397356731551, 0.13145439406590803, 0.2132747657597065, 22.54758882522583, 36.77726330075945, 55.031011308942524, 63.6714506149292, 57.760329723358154, 61.86720493861607, 56.96155439104353, 56.443927492414204, 55.61180428096226, 48.504957471575054, 46.856507778167725, 46.60472590582711, 53.26414694104876, 55.40023510796683, 55.61474336896624, 51.52324104309082, 45.00053971154349, 47.449560846601216, 46.99291828700474, 57.612843785967144, 56.87432670593262, 58.90459728240967, 54.537029130118235, 56.99876894269671, 55.79875251225063, 52.83663470404488, 54.09106247765677, 55.32265499659947, 47.75021634783064, 49.66185685566494, 48.74001502990723, 57.53475298200335, 51.802829606192454, 53.27178301130022, 53.23270634242466, 52.6613837650844, 51.48192358016968, 50.128567355019705, 46.69250249862671, 47.53506537846157, 45.07981170926775, 43.11590337753296, 43.57143422535488, 43.725920472826274, 44.329520906720845, 46.043915952954976, 46.009011677333284, 41.88299070085798, 44.34102017538888, 42.556396211896626, 41.47735139301845, 43.56428452900478, 40.76164524895804, 47.879098483494346, 45.54635892595564, 45.66926213673183, 44.75471591949463, 49.99732978003365, 52.248594760894775, 55.95630986349923, 47.095532757895334, 38.39614840916225, 37.37020172391619, 46.93600559234619, 55.172254289899556, 51.44076592581612, 50.27759231839861, 49.12404891422817, 48.18616369792393, 47.83139910016741, 48.597955635615754, 46.439633233206614, 47.083731242588584, 42.495870453970774, 41.03771802357265, 42.24271283830915, 41.021615573338096, 43.826061385018484, 45.76564754758562, 46.931138379233225, 42.81086703709194, 43.689699513571604, 43.426519121442524, 45.16210617337908, 44.69337722233364, 43.53239924567086, 43.984876360212056, 43.93578038896833, 47.38132953643799, 51.59345258985247, 51.87303420475551, 52.67166709899902, 52.15156316757202, 53.65328080313546, 45.57132380349295, 49.66639402934483, 48.47474323000227, 54.06651449203491, 51.45529113497053, 52.37594829286848, 53.642799445560996, 56.59209435326712, 54.35615709849766, 54.46037312916347, 56.139867373875205, 60.4396002633231, 53.91460255214146, 43.32237604686192, 56.494451318468364, 53.144957542419434, 57.265162876674104, 54.79321616036551, 59.20740672520229, 57.93979821886335, 58.42969485691616, 55.29556049619402, 49.14726979391915, 45.437063762119834, 50.853264468056814, 44.724793502262656, 52.366734981536865, 53.39889683042254, 56.090073108673096, 60.30791800362723, 63.64565890175955, 64.74530860355922, 44.59668261664254, 0.43934949753539904, 1.8852382217134749, 1.6975292712450027, 0.18930436271641934, 9.384156244141714, 79.3703842163086, 58.08890308652605, 77.84245450156075, 60.13458129337856, 81.98517199925014, 41.62139449800764, 47.975688866206575, 52.247649805886404, 40.555853503090994, 61.76861000061035, 74.76787662506104, 30.16550690787179, 1.2400027705090386, 0.46263071256024496, 0.21290784116302217, 0.18214170634746552, 0.13431265497846262], [0.13783047907054424, 0.03936028972800289, 0.05310947534495166, 0.024201149054403816, 0.10843926654862505, 0.01833225370916937, 0.2823859458523137, 0.20412952506116458, 25.622901473726543, 70.10901914324079, 36.2442808832441, 34.815710408346995, 25.3398631300245, 35.46996668406895, 43.303386620112825, 25.51254497255598, 44.41106496538435, 62.204095295497346, 50.40538706098284, 49.824319635118755, 54.20108372824532, 28.23499161856515, 0.17355846906346933, 0.1632755965526615, 1.0526301562786102, 0.09586464201233216, 0.25353941374591416, 4.265102633408137, 35.675338063921245, 47.294383253370015, 59.198408808027, 53.33732189450945, 54.731342451913015, 58.09004259109497, 53.04865550994873, 48.04850946153913, 42.82274498258318, 41.29626744134085, 46.6262583732605, 50.60376507895333, 52.037522384098594, 54.33908884865897, 39.08011170795986, 48.35921900612967, 48.627825941358296, 45.15063122340611, 52.44068118504116, 48.04095676967076, 51.74385677065168, 50.48710829871041, 50.723180294036865, 51.38868917737688, 48.06839868000576, 50.118266650608604, 46.83719526018415, 45.52733128411429, 44.666275773729595, 42.90080451965332, 49.92775746754238, 45.37088564464024, 44.78267547062465, 42.39495481763567, 46.676497323172434, 46.651268414088655, 42.861738273075645, 38.56668152127947, 39.06781687055315, 36.876594747815815, 40.596424034663606, 37.784630502973286, 37.55438109806606, 34.151723180498394, 33.04404830932617, 35.66805982589722, 34.03814445223127, 37.626527718135286, 36.89343023300171, 37.34064408711025, 38.728345257895334, 36.930815015520366, 40.375374044690815, 38.49942643301827, 41.49618795939854, 42.545067174094065, 45.03658696583339, 49.03153017589024, 51.60838079452515, 46.04433631896973, 42.760714939662385, 38.1208746773856, 39.16652992793492, 49.16032893317086, 49.74052436011178, 46.05689866202218, 44.18264293670654, 45.282445498875205, 42.61501121520996, 43.707108225141255, 41.11378342764718, 41.38687195096697, 41.373017242976594, 38.2844352722168, 37.903958865574424, 40.62515483583723, 40.412487847464426, 38.19825676509312, 38.29087277821132, 31.60939121246338, 33.84905617577689, 34.57516029902867, 34.29793412344796, 36.3106882912772, 39.135391575949534, 37.83007866995675, 39.68098497390747, 40.86331129074097, 41.700162751334055, 46.395196029118125, 44.16805171966553, 43.079213414873394, 47.370538984026226, 43.401839120047434, 45.08024249758039, 45.319910185677664, 50.23579542977469, 50.74051257542202, 48.245626381465364, 49.81132650375366, 52.615459646497456, 51.04382576261248, 52.29133660452706, 50.825826031821116, 54.353509834834504, 34.39529228210449, 37.9647729737418, 50.36100891658238, 51.13279744556972, 50.588385241372244, 48.81660154887608, 40.82233081545149, 50.536874771118164, 58.31955896105085, 52.22054488318307, 50.565695898873464, 44.31123672212873, 44.522076334272114, 43.24064786093575, 49.14088092531477, 50.852149282182964, 54.37373604093279, 53.904617990766255, 55.180692877088276, 47.01529148646763, 17.986594983509608, 0.7301333184753145, 2.1091267679418837, 0.17573275310652597, 0.05314691351460559, 15.28291368484497, 67.69244956970215, 43.97705963679722, 47.79347930635725, 56.365576131003245, 74.82666533333915, 22.797857727323258, 34.06805297306606, 37.32463891165597, 31.0576034954616, 49.61839587347848, 57.07413605281285, 6.407778126852853, 0.6068137043288776, 0.2795828091246741, 0.06930548538054739, 0.1726257141147341, 0.06671370552586657, 0.16746180477951253, 0.0941327220893332, 0.11358810562108244, 0.06181930351470198, 0.1440608554652759, 0.045308721251785755, 0.23956354654261044, 0.19187731322433266, 32.148946625845774, 80.15348788670131, 40.32805333818708, 44.92323752811977, 38.67159237180437, 46.594921997615266, 50.407158851623535, 31.2457537651062, 46.32723222460066, 69.66472353254045, 53.90464578356062, 55.83937862941197, 58.62129838126046, 30.722724642072404, 0.1341566869190761, 1.04929903788226, 1.120505696960858, 0.09400692848222596, 0.28061119679893765, 4.628682323864528, 39.16478245598929, 50.94394540786743, 62.27577986036028, 54.46547310692923, 54.70498446055821, 58.048825877053396, 55.83050230571202, 49.976158618927, 46.249506201062886, 42.507703236171174, 46.0930848802839, 51.51730033329555, 54.25850016730172, 53.526100976126536, 40.14704581669399, 48.45808144978115, 49.54110063825335, 46.232062748500276, 54.65728507723127, 50.60529368264334, 50.759710448128835, 50.91578435897827, 52.19880396979195, 52.16114125932966, 50.887258529663086, 53.125252451215474, 49.705442905426025, 45.67205878666469, 46.223273277282715, 46.71256194795881, 50.96251099450247, 49.19466693060738, 47.22294534955706, 45.73957095827375, 47.09923962184361, 48.94047403335571, 46.44361455099923, 40.952210017613, 41.51110921587263, 41.43536690303257, 43.953456606183735, 40.799519879477366, 40.5053505216326, 38.25169883455549, 39.49153886522566, 38.926292487553184, 37.463411808013916, 40.00422559465681, 39.75627217973982, 38.82893432889666, 40.19704852785383, 38.585045610155376, 42.895475251334055, 41.76025077274868, 42.80027103424072, 43.190245628356934, 46.172773769923616, 51.96734210423061, 53.3650347845895, 49.33075434820992, 41.795842920030864, 38.94397912706648, 39.79507092067173, 50.267520904541016, 51.12180886949812, 47.72237491607666, 46.81886938640049, 46.843584128788535, 46.01781504494803, 46.487054688589915, 42.85938630785261, 42.341175760541645, 42.27687018258231, 38.7153069632394, 38.974471296582905, 42.11681842803955, 43.131377015795024, 39.98399938855852, 40.10562065669468, 36.01972900118147, 36.94348505565098, 37.40819794791085, 37.60615907396589, 40.32463135038103, 43.4540513583592, 40.068604128701345, 43.352979387555806, 43.801614148276194, 46.125289780753, 50.05850172042847, 48.27468722207205, 47.99200323649815, 50.03432546343122, 45.15579720905849, 46.98036636625017, 47.033638204847065, 51.46588713782174, 52.27814892360142, 52.41206850324358, 50.815869263240266, 55.96721853528704, 51.99865416118077, 54.014955384390696, 53.801739488329204, 55.918379647391184, 36.5809245790754, 40.81357608522688, 48.82499149867466, 53.472523416791645, 53.2084675516401, 54.802995749882285, 45.39038923808506, 50.95843587602888, 60.92272240774972, 54.906833103724885, 53.79663603646414, 46.0455835206168, 45.93253285544259, 46.372763769967214, 51.0554153578622, 52.965735707964214, 55.27324983051845, 56.752573422023225, 59.3891716003418, 51.81591306413923, 22.250244140625, 0.6677166191594941, 3.857304607118879, 0.13943537723805222, 0.02733533114327916, 19.128340346472605, 75.13134384155273, 50.88757814679827, 54.865414891924175, 60.983512197222026, 84.63473551613944, 28.371275322777883, 42.727221148354666, 39.9931640625, 25.579650674547466, 58.87737424033028, 66.36164024897984, 9.460390142032079, 0.7157860483442033, 0.2092829713863986, 0.08825139767889466, 0.20670748315751553, 0.06422272204820599, 0.37015681181635174, 0.17794222597564968, 0.20613390393555164, 0.15260724829775946, 0.2610371714191777, 0.12806144755865845, 0.30240959567683084, 0.27104369018759045, 37.081719466618125, 92.1173825945173, 48.7292731148856, 49.17578172683716, 37.442014830453054, 51.378433636256624, 57.64748403004238, 35.8708291053772, 55.0201929637364, 73.83859675271171, 59.247713225228445, 61.99159158979143, 65.48324203491211, 35.449149881090435, 0.27828612870403696, 2.3974413999489377, 1.496277630329132, 0.3957917833966868, 0.407668941787311, 6.031972212450845, 38.70184135437012, 48.22602898733956, 67.57334354945591, 56.014730317252024, 58.22429568426949, 59.994269371032715, 58.9767404283796, 51.21667957305908, 47.92437294551304, 44.10126216070992, 50.89657258987427, 54.47422088895525, 56.98193345751081, 56.21017966951643, 42.73538180759975, 51.208553654806956, 49.40399530955723, 48.136449337005615, 54.656256743839805, 53.61492327281407, 52.03734173093523, 52.17058386121477, 54.226538453783306, 55.284082072121755, 53.17504671641758, 54.18272658756801, 53.00826563153948, 50.32201215199062, 48.989208698272705, 48.06032487324306, 54.760865347726, 52.06014919281006, 52.7885080065046, 48.27565996987479, 53.33771794182913, 51.81030239377703, 49.974626541137695, 42.75134529386248, 45.511815956660676, 44.89336027417864, 48.504839352199006, 45.182064873831614, 44.25482777186802, 41.59829521179199, 45.42101689747402, 45.131436824798584, 40.94825301851545, 42.736483097076416, 41.176869596753804, 42.49466494151524, 43.90859208788191, 39.76803895405361, 44.008361271449495, 44.7790241922651, 46.03498404366629, 46.524845940726145, 49.559346607753206, 52.69137913840157, 54.99078818729946, 49.2074933052063, 43.21466507230486, 39.73444788796561, 39.403675419943674, 52.99916696548462, 54.40421778815133, 50.58233683449881, 48.81435380663191, 50.38244063513619, 48.23209823880877, 47.43085282189505, 46.099036012377056, 45.65960414069039, 44.95497342518398, 41.13284581048148, 41.09503023965018, 44.35731022698538, 45.612867082868306, 42.573249067579, 44.988352571214946, 38.49145337513515, 40.48313365663801, 43.54650756290981, 41.07074628557478, 43.52649327686855, 47.75346463067191, 43.94753326688494, 46.89054005486624, 47.559519563402446, 49.67335959843227, 54.00327893665859, 51.83314112254551, 51.96780415943691, 52.153272424425396, 47.63439335141863, 49.47478355680193, 49.74725716454642, 54.22586795261928, 55.0834458896092, 52.985381739480154, 53.4414267539978, 56.250392368861604, 53.77497502735683, 55.39093147005354, 56.875893524714876, 55.990248339516775, 39.815936361040386, 41.654440130506245, 50.05416257040841, 55.02219751902989, 53.63981172016689, 55.83234357833862, 49.58281762259347, 56.9926302092416, 63.04851681845528, 57.33373464856829, 56.82112782342093, 48.61421094621931, 48.524071965898784, 48.578087261744905, 53.37938628877912, 55.13295527866909, 59.23271901266915, 60.07013675144741, 64.67627825055803, 53.965216704777305, 28.926241840635026, 0.9702430857079369, 4.63763507774898, 0.6557813510298729, 0.11992806542132582, 21.508126156670706, 80.46037592206682, 54.829777581351145, 59.668447494506836, 67.25279535566057, 88.16933972494942, 34.055063315800254, 49.64319052015032, 51.25046171460833, 45.79054641723633, 63.018695150102886, 81.9646748134068, 14.742960487093244, 0.9035598667604583, 0.4934730604290962, 0.1499044397579772, 0.522130471255098, 0.14270921370812825], [0.09927226523203508, 0.04483012675440737, 0.07661802334977047, 0.05267893809026905, 0.12432231248489448, 0.10751200094819069, 0.10572846486632313, 0.09684535581618547, 9.644123094422476, 68.96512331281389, 45.045609201703755, 50.137537479400635, 21.529365062713623, 27.137530599321636, 36.546808923993794, 21.85384246281215, 56.60158906664167, 56.60624435969761, 54.56517628261021, 50.55884150096348, 51.601133823394775, 41.46686308724539, 0.11249660061938421, 0.2841511411326272, 0.9029153670583452, 0.2996828348508903, 0.021206982666626573, 0.4891406957592283, 25.55727400098528, 46.60712998253958, 55.86360699789864, 54.10414593560355, 54.41906956263951, 56.11257484980992, 51.56305422101702, 51.97219542094639, 43.86511026109968, 43.49205800465175, 46.79600286483765, 50.01959180831909, 51.786786215645925, 51.36009039197649, 43.440050738198416, 45.78620726721627, 48.053560801914756, 45.497572149549214, 45.07933575766427, 53.2444418498448, 54.01643535069057, 47.601726395743235, 52.33106292997088, 49.568615504673545, 52.704528604234966, 52.32016468048096, 46.41093717302595, 44.665900571005686, 47.3262164252145, 43.19517190115792, 48.44559553691319, 44.65011773790632, 44.36735037394932, 45.15649550301688, 47.351295948028564, 42.55789702279227, 42.449803897312705, 38.19682196208409, 38.212625639779226, 40.33789198739188, 38.67382621765137, 37.15195185797555, 35.3035295350211, 30.515696116856166, 27.164840493883403, 28.225187710353307, 34.24538837160383, 33.756408895765034, 36.499720982142854, 37.12228652409145, 37.02683217184884, 40.1520276750837, 39.63036387307303, 39.88389669145857, 39.56789609364101, 41.25146198272705, 39.96312352589199, 46.203995500292095, 41.47013916288103, 37.6700998714992, 39.50309371948242, 39.425979137420654, 38.66049262455532, 44.910095010484966, 52.80228975840977, 49.930224078042166, 46.1927741595677, 44.542827129364014, 44.560364382607595, 40.567071369716096, 41.84633547919137, 39.952506678445, 38.698478426252095, 39.89650419780186, 40.369002546582905, 40.49486916405814, 36.0272330556597, 36.59264966419765, 38.80084276199341, 38.49394083023071, 31.895170620509557, 30.42852749143328, 35.41047273363386, 37.298947947365896, 40.11179065704346, 38.54383931841169, 44.03528206689017, 44.180450780051096, 45.48245634351458, 41.65707697187151, 43.16862283434187, 44.68353162493025, 47.92409154347011, 41.99701411383492, 45.99222135543823, 42.96802486692156, 48.37690217154366, 50.491058349609375, 51.364346163613455, 52.47910819734846, 50.709631306784495, 53.3497348512922, 53.69143336159842, 52.23188434328352, 42.55688605989729, 33.03642960957119, 47.213339465005056, 52.24660062789917, 53.516394342694966, 52.328867299216135, 56.569887910570415, 56.375873361315044, 40.64995643070766, 51.229398250579834, 56.19983032771519, 50.40521683011736, 48.70761557987758, 44.32734612056187, 47.438353402274, 50.05946752003261, 54.63383143288748, 52.301741531917024, 56.03416790281023, 56.44932624271938, 63.56371879577637, 10.5891831942967, 0.433790422976017, 3.6647352831704274, 0.27450343168207575, 0.11552714157317366, 30.315678324018204, 64.90510327475411, 40.17068706239973, 57.786468846457346, 53.30766003472464, 57.09711374555315, 16.683821644101823, 47.974813393184114, 30.670144149235316, 40.8382282938276, 46.48704079219273, 52.203233446393696, 2.342375840459551, 0.2023326421954802, 0.0652679441762822, 0.03882078314200044, 0.13239328297121183, 0.030996036050575118, 0.0938864681603653, 0.05708673210548503, 0.09379159539405789, 0.027929461494620358, 0.06723273731768131, 0.027502220223790834, 0.2087130155414343, 0.20501732027956418, 11.846557872635977, 79.47679587772915, 50.61642817088536, 49.31967544555664, 29.9664340700422, 36.64910725184849, 45.71456439154488, 30.741901670183452, 61.82327842712402, 62.25578989301409, 60.70992687770298, 56.09200470788138, 57.55971785954067, 47.1017861366272, 0.13401769580585615, 0.45650750398635864, 1.8310457468032837, 0.2526267570044313, 0.04453144920989871, 0.5097159945539066, 29.893262590680802, 51.09010771342686, 56.73332691192627, 56.6686635017395, 54.432351044246126, 59.131956236703054, 54.694951261792866, 54.31856734412057, 45.84522526604788, 45.828111852918354, 48.09215457098824, 52.66531991958618, 53.613471099308555, 54.02615935461861, 45.885260786329, 47.32841205596924, 51.98243359157017, 46.514579977308, 46.72714621680123, 49.76990829195295, 54.78117840630667, 50.46661458696638, 52.85833045414516, 50.652871472494944, 54.34980991908482, 51.95757641111101, 48.78796454838344, 47.256918566567556, 50.446054867335725, 47.01415545599801, 51.84209387642996, 47.46114696775164, 47.29267052241734, 47.51020472390311, 48.42513656616211, 45.95204339708601, 46.95187527792794, 41.64534146445138, 41.68554374149868, 42.86711965288435, 40.89377566746303, 40.84385633468628, 38.7981607573373, 35.36423594611031, 31.435008798326763, 31.815113476344518, 38.81284230095999, 36.06008413859776, 38.84863247190203, 38.59147964205061, 39.91916922160557, 42.52286420549665, 41.464181082589285, 42.00154086521694, 41.38830327987671, 43.88875845500401, 41.80898891176496, 49.81694064821516, 44.3905782018389, 39.19186305999756, 41.11400229590279, 38.83864096232823, 39.36389698301043, 44.340495586395264, 51.734108448028564, 50.897486277988975, 47.59743588311331, 45.04666185379028, 42.93220690318516, 43.06132527760097, 43.07921688897269, 41.07465117318289, 40.84294959477016, 41.152241706848145, 41.85671261378697, 42.506796496255056, 39.02531473977225, 39.83119460514614, 39.142836570739746, 40.85620675768171, 34.43751995904105, 33.90946728842599, 40.13305561883109, 40.89573505946568, 43.24697419575283, 42.35764993940081, 45.20016493116106, 46.64718287331717, 47.545901094164165, 44.7532776423863, 46.51501423971993, 47.95255136489868, 50.378198759896414, 44.18210792541504, 48.10061052867344, 44.630468232291086, 50.63862419128418, 52.6158834866115, 52.82099430901663, 53.99438871656145, 51.35203742980957, 55.19583995001656, 53.2644978250776, 50.426075322287424, 41.98583793640137, 35.441750049591064, 48.315379347120015, 54.607619353703086, 52.71371412277222, 51.78882203783308, 56.5014203616551, 61.88744504111153, 46.2388858795166, 51.52314376831055, 60.082344736371724, 53.66341822487967, 50.52067852020264, 46.19329527446202, 50.006782804216655, 52.0258389881679, 58.75591278076172, 57.041264125279014, 59.17600781576974, 58.04451104572841, 69.68295560564313, 13.429588539259774, 0.4159186791096415, 4.534345328807831, 0.05040172367755856, 0.11993713064917497, 35.4341904095241, 74.07546779087612, 44.22818143027169, 60.41161986759731, 62.475533621651785, 63.07715034484863, 20.410322938646587, 52.89769894736153, 40.685381821223665, 44.06079585211617, 52.38666936329433, 63.869766099112375, 3.434454394238336, 0.4492861543382917, 0.15010270769042627, 0.056774616174932034, 0.01860385770643396, 0.04129027741562043, 0.24286643788218498, 0.07468204759061337, 0.21523356065154076, 0.17544315436056682, 0.21354020865900175, 0.19014103710651398, 0.31937381252646446, 0.19000546580978803, 13.685521960258484, 95.08703572409493, 59.307509422302246, 65.97771753583635, 29.985037871769496, 39.3384040423802, 50.60774987084525, 31.933590684618267, 70.06053461347307, 67.86796801430839, 66.10184710366386, 60.62062862941197, 63.829369272504536, 51.302580152239116, 0.2098141693110977, 0.9975701336349759, 3.607132979801723, 0.7857712358236313, 0.15155448764562607, 0.7388442967619214, 32.05187681743077, 50.7604261125837, 57.67442914417812, 56.884408542088096, 56.64446292604719, 62.12209265572684, 57.812201499938965, 55.95937054497855, 47.667310442243306, 47.1332962172372, 52.17481531415667, 55.403782163347515, 56.1487124306815, 54.4136187008449, 47.61167621612549, 52.43686662401472, 50.86539602279663, 48.30366121019636, 48.7539461680821, 49.37138393947056, 53.98377186911446, 52.966173444475444, 54.93268040248326, 53.340052536555696, 56.449329716818674, 55.62097590310233, 51.904686723436626, 50.02920811516898, 52.53960268838065, 49.584495612553184, 55.453440938677105, 51.56146655763899, 52.49070821489607, 49.6644172668457, 53.56631020137242, 48.60369137355259, 50.39644125529698, 45.298405511038645, 45.84630571092878, 46.721167291913716, 46.318793637411936, 44.39015436172485, 43.677394253867014, 38.62993097305298, 36.09922334126064, 38.03122207096645, 42.47711031777518, 39.08573974881853, 43.488319873809814, 40.07754298618862, 43.460801533290315, 43.94735608782087, 44.739370822906494, 44.656878335135325, 44.61392109734671, 45.61962420599801, 42.44856711796352, 51.49405860900879, 44.02077422823225, 38.543960911887034, 41.349674769810264, 39.985903194972444, 40.5957396371024, 45.19755935668945, 55.680838108062744, 53.10838222503662, 50.387863704136436, 46.85944339207241, 45.753189427512034, 44.17209904534476, 46.31557662146432, 42.90757206508091, 42.35114295142037, 44.20100007738386, 45.29467780249459, 44.60308190754482, 42.17658335821969, 44.47428662436349, 45.00610521861485, 44.04464823859078, 39.41882944107056, 39.17955085209438, 44.56489808218819, 44.98526062284197, 49.6392891066415, 46.30616876057216, 49.73791183744158, 51.33627891540527, 51.746618679591585, 47.582233224596294, 50.0920615196228, 53.02470506940569, 54.25334807804653, 46.388834953308105, 51.05837181636265, 47.7080477305821, 52.36122158595494, 53.59818853650774, 55.20518527712141, 55.61622680936541, 55.46848031452724, 57.23969425473894, 54.40522180284773, 49.47337654658726, 44.5472149167742, 39.54332378932408, 50.122084685734336, 56.92199829646519, 55.22620357785906, 53.467548506600515, 54.72717353275844, 56.23937599999564, 48.43806021554129, 55.441333702632356, 59.70389025551932, 55.48329039982387, 54.85541990825108, 47.91085869925362, 51.46112067358834, 53.647215025765554, 60.99660260336739, 59.151001249040874, 62.42435319083077, 60.96848324366978, 68.09451402936662, 18.279397283281597, 0.6134791438068662, 6.036124195371356, 0.4414990964744772, 0.21856155778680528, 37.2243903023856, 78.05752209254673, 51.05334479468209, 72.38743768419538, 64.15314143044608, 69.77494280678886, 27.33419414928981, 66.540438243321, 42.83680118833269, 55.58502244949341, 57.9793438911438, 77.36340400150844, 6.540567755699158, 0.6724374315568379, 0.2650105910641806, 0.20888140079166206, 0.19926296334181512, 0.1540002128375428], [0.03700754079701645, 0.1278027357267482, 0.09579988941550255, 0.04209347628057003, 0.014966421461265002, 0.11048832695399012, 0.08417190943977662, 0.03600973808871848, 0.9502868822642735, 50.232859815870015, 49.53033787863595, 44.332546847207205, 32.44239684513637, 28.06197452545166, 35.36300264086042, 17.161545038223267, 49.260004316057476, 57.84134919302804, 55.467820235661094, 50.42595025471279, 50.10536731992449, 44.302669593266074, 1.9246672945363181, 0.25718371676547186, 0.9333105874913079, 0.42027392398033825, 0.03684939803289516, 0.0916339558150087, 14.654226779937744, 44.32781859806606, 54.12791224888393, 57.71416589191982, 54.186895506722585, 54.187270709446494, 52.777922425951274, 48.34200831821987, 43.59873717171805, 43.39783000946045, 47.09807579857962, 49.58177191870553, 54.193343435014995, 52.29011024747576, 52.4683906010219, 41.97863960266113, 49.31061152049473, 48.05465514319283, 53.2846371786935, 51.062200273786274, 43.81624010631016, 52.79625524793352, 49.69814729690552, 53.351784569876536, 51.89104046140398, 51.80089800698416, 45.77700090408325, 45.21548570905413, 47.386780398232595, 41.431038175310405, 47.69508239201137, 46.199982915605815, 45.31681476320539, 46.2882285118103, 44.278899805886404, 43.41395330429077, 43.71394872665405, 38.68375171933855, 36.91317006519863, 37.45066186359951, 39.21702248709542, 36.511932441166465, 32.513417857033865, 27.98346335547311, 27.725049427577428, 26.98239643233163, 33.266936097826274, 36.680804933820454, 37.262938908168245, 35.884513582502095, 36.782839230128694, 40.92816230228969, 39.72251088278634, 36.95938948222569, 38.94370467322213, 39.56046846934727, 43.232171058654785, 47.394214970724924, 36.77168042319161, 33.980939933231895, 32.41694906779698, 39.142989431108745, 36.74255357469831, 38.46740913391113, 51.199719020298545, 45.56778369631086, 45.707706519535606, 42.2076279095241, 41.41010325295584, 39.7934068271092, 42.843756335122244, 41.23437288829258, 40.39002084732056, 37.142783709934776, 40.0005395753043, 38.3055682182312, 39.7969399860927, 31.098549229758127, 34.882920333317344, 33.43186896187918, 26.691249540873937, 33.456517696380615, 35.96676983152117, 35.80529717036656, 38.13431249346052, 40.20478882108416, 42.94093036651611, 43.18759489059448, 43.4412909916469, 35.87649188722883, 41.724693366459434, 46.279689175742014, 44.03871100289481, 42.63927779878889, 46.55265263148716, 41.87260661806379, 43.28696802684239, 50.961743218558176, 51.152196816035676, 51.41812522070748, 48.37015547071184, 52.48869323730469, 43.75271272659302, 41.31782422746931, 44.40576001576015, 45.21823719569615, 53.24509845461164, 51.008674825940815, 54.271385601588655, 50.497523648398264, 49.100383349827354, 53.90715755735125, 62.276752608163015, 43.01023169926235, 58.87818023136684, 56.384287629808696, 51.136667592184885, 44.96597242355347, 44.53878327778408, 47.77572318485805, 61.78652940477644, 52.97068977355957, 58.920793533325195, 53.62910107203892, 50.74278811046055, 10.033885768481664, 0.24620814142482622, 2.2966317236423492, 0.10042090288230351, 0.8805785913552556, 53.37507145745413, 49.91870396477835, 52.50215884617397, 56.452956676483154, 64.34124306270054, 42.269272327423096, 25.249051911490305, 54.516260964529856, 20.626085349491664, 33.04257181712559, 53.52739681516375, 45.41207109178816, 0.4952205866575241, 0.09709251219672815, 0.03671199808429394, 0.05144670492570315, 0.03479594411328435, 0.07758413508002247, 0.05813807461942945, 0.08445359646741833, 0.08070631218808037, 0.07658774711723838, 0.018638305232993195, 0.037256800636116943, 0.01535619402836476, 0.09283961076289415, 1.2036379618304116, 59.45148999350411, 58.519604546683176, 43.9647786957877, 37.0225625038147, 36.39602606637137, 39.317007064819336, 19.541608776365006, 58.789000102451865, 64.6945937020438, 61.465133530753, 57.13570751462664, 55.23472901753017, 50.83508103234427, 2.1264603521142686, 0.47859495878219604, 1.703064488513129, 0.5576655673129218, 0.07580283137836627, 0.07435194030404091, 17.81582042149135, 50.007022517068044, 53.75097942352295, 59.486314364842, 56.19935090201241, 56.4650673866272, 54.13513142721993, 52.13942119053432, 45.580029896327424, 45.89281695229666, 48.415332657950266, 52.015941279275076, 55.18368755068098, 55.03571176528931, 54.79579741614205, 46.30845819200788, 50.38116564069475, 49.66592155184065, 48.32817792892456, 51.57579026903425, 49.17836645671299, 53.342814445495605, 52.55604560034615, 53.26621055603027, 53.80709654944283, 51.52267476490566, 47.483214446476524, 47.36224978310721, 50.69244146347046, 43.06495918546404, 50.78031185695103, 48.343436173030305, 48.036221572331016, 47.667230537959504, 47.10503441946847, 45.97876616886684, 45.749750069209504, 41.767084326062886, 40.447419915880474, 40.57901879719326, 41.633275917598176, 38.77532202856881, 37.72279500961304, 32.02220800944737, 33.27509675707136, 30.7610057422093, 39.242091587611604, 39.67608649390084, 40.35111788340977, 37.26459605353219, 39.29399810518537, 40.80032934461321, 41.6661547933306, 39.52221168790545, 41.19295815059117, 40.59806033543178, 43.10202087674822, 49.147009236471995, 39.49978985105242, 34.29880959647042, 32.846639565059114, 39.81132970537458, 36.69133840288435, 38.35676949364798, 52.04526267732893, 45.81544876098633, 47.926638058253694, 43.882591928754536, 43.197919913700645, 41.84745413916451, 44.4672064099993, 42.14028944287981, 40.382634912218364, 39.28107098170689, 42.25907932009016, 39.610061236790244, 41.80167245864868, 36.032777718135286, 38.4262375831604, 36.871772697993684, 31.804315975734166, 36.93384790420532, 38.77849040712629, 40.12096922738211, 41.06025797980172, 42.97256898880005, 46.36829260417393, 45.168498516082764, 47.18407712663923, 41.27173335211617, 43.46929570606777, 49.09290361404419, 47.880710465567454, 44.625878947121755, 47.80407878330776, 44.0082813671657, 45.63353797367641, 52.926822321755544, 53.07891838891165, 52.20593629564558, 50.00687313079834, 54.443711348942344, 46.23932014192854, 39.23088066918509, 43.786675521305625, 46.25244876316616, 54.356330803462434, 52.79515395845686, 56.3466978754316, 53.275396074567524, 52.340050424848286, 50.64115680967058, 65.10211944580078, 47.250623498644146, 59.14408084324428, 59.0476051058088, 53.3628044128418, 46.70066663197109, 46.877689361572266, 51.253477232796804, 62.09448051452637, 54.51131732123238, 61.885277203151155, 55.10263681411743, 53.11826603753226, 12.596181648118154, 0.28517372054713114, 2.664223998785019, 0.061869426896529536, 1.2689286640712192, 59.163959639413015, 56.52574600492205, 56.03919492449079, 62.434337752205984, 69.95308072226388, 49.04948779514858, 25.531605618340627, 62.97970185961042, 25.573339973177227, 34.76075710569109, 62.4518472126552, 51.43973411832537, 0.4553101882338524, 0.09872715055410351, 0.017111516624156917, 0.10936936842543737, 0.06227029860019684, 0.06061807261513812, 0.1831636479390519, 0.20708329656294414, 0.24314566861305917, 0.16719769180885383, 0.09883049822279386, 0.33524398665343014, 0.18650539219379425, 0.20059112778731755, 1.5207077137061527, 72.15586117335728, 69.13531943729946, 60.437613078526084, 45.43598679133824, 42.87563814435686, 49.86028003692627, 25.661047083990915, 65.00277410234723, 70.96999822344098, 66.40301677158901, 60.221030780247276, 61.32606533595494, 54.78419392449515, 2.915844108377184, 0.4545966408082417, 2.922184773853847, 1.0331439333302634, 0.2824476925390107, 0.21724775114229747, 19.108301741736277, 52.81685665675572, 53.804477078574045, 62.09758635929653, 59.036626952035085, 59.339005606515066, 55.69343866620745, 52.928983211517334, 46.78032078061785, 48.799689633505686, 51.71931225912911, 53.71679081235613, 57.630638122558594, 55.56751298904419, 56.65297794342041, 49.75606400626046, 51.55644995825631, 50.82148688180106, 48.12982770374843, 51.17071723937988, 52.18282311303275, 55.305941104888916, 53.37322671072823, 55.538962841033936, 57.22709369659424, 55.93277978897095, 49.71263081686837, 47.468383516584126, 53.31438936505999, 45.45025839124407, 53.03324440547398, 52.61344466890608, 52.28229352406093, 51.69974960599627, 50.30245297295706, 49.43879883629935, 51.3493241582598, 44.7027816091265, 43.89609227861677, 44.84435115541731, 45.664815289633616, 42.16156135286604, 41.85782779966082, 37.5846335547311, 38.83431223460606, 35.161675112588064, 42.95894704546247, 44.66806493486677, 44.53311007363455, 39.407156467437744, 42.664468492780415, 43.788561957223074, 45.5423880304609, 41.968686308179585, 43.371336528233115, 42.77078635351998, 46.290132318224224, 52.13435247966221, 40.10632937295096, 35.722905431474956, 33.146009649549214, 40.37248706817627, 38.24402107511248, 38.838501998356406, 52.48660182952881, 46.4693854195731, 51.93425825663975, 45.621851103646414, 45.37894555500576, 42.36263527188982, 47.65802417482649, 45.41744899749756, 42.415656975337434, 41.89714070728847, 44.84664058685303, 43.36534718104771, 45.30907446997506, 40.67040497916085, 43.57232359477452, 41.60949223382132, 37.329575606754844, 40.727178709847585, 46.14118031093052, 43.40192249843052, 48.22806133542742, 46.82545975276402, 48.57046161379133, 48.587641034807476, 49.671483584812705, 42.13418892451695, 46.96098436628069, 52.947291714804514, 50.15266718183245, 47.92224332264492, 53.250330448150635, 45.53512021473476, 47.49160092217581, 54.121182918548584, 56.28679050718035, 54.80781432560512, 51.816885811941965, 57.72979586465018, 48.31480612073626, 39.43811764035906, 47.31533554622105, 49.85254669189453, 55.868696553366526, 55.39931794575283, 58.90186664036342, 55.13411562783377, 53.04633133752005, 52.912140778132844, 59.192996161324636, 46.560663904462544, 63.77240099225725, 60.35683332170759, 56.10975040708269, 49.49861587796892, 48.36076845441546, 53.82673563276018, 65.9053589957101, 55.99189853668213, 64.96118913378034, 56.96075187410627, 47.32963146482195, 15.391249997275215, 0.37454259076288765, 4.232780916350229, 0.2443500411297594, 1.2833970934152603, 63.739466530936106, 63.539997645786826, 61.334861755371094, 68.2257307597569, 74.8788810457502, 54.39574098587036, 36.259653772626606, 73.13527924673897, 29.2918438911438, 45.731827190944124, 68.06241335187639, 69.4471823828561, 1.3829162503991808, 0.368702521281583, 0.20534235212419713, 0.22698098314659937, 0.10536498722753354, 0.20226698714707578], [0.09935922628002507, 0.13807050404804094, 0.03384232421272567, 0.07310748672378914, 0.05716728099754878, 0.17326265493673937, 0.09064201904194695, 0.19215970592839376, 0.1931512898632458, 26.58556570325579, 56.7360714503697, 36.4423497063773, 32.98680904933384, 31.016654287065776, 36.75689813068935, 24.712338311331614, 41.0901769229344, 57.803144523075645, 54.42864418029785, 48.89061376026699, 48.29242249897548, 51.59192746026175, 4.993879641805377, 0.3121213859745434, 1.0845650540930885, 0.33415013392056736, 0.044668306330485005, 0.08959020155348948, 7.801770022937229, 49.56037841524397, 56.47951963969639, 55.54051923751831, 51.95994227273123, 50.15701675415039, 47.099656513759065, 46.797913619450156, 47.71524953842163, 50.462879930223735, 52.494967460632324, 52.27760001591274, 54.47641999380929, 52.891886779240195, 53.742794445582796, 50.007745129721506, 47.91796670641218, 51.505596092769075, 47.673226833343506, 39.91826942988804, 50.349791049957275, 52.45237152917044, 50.373057092939106, 47.22903197152274, 49.06416239057268, 44.25341381345476, 44.87856755937849, 44.38844163077218, 48.66941090992519, 43.14179931368147, 46.18068081992013, 45.25967625209263, 43.02557332175118, 43.85451773234776, 43.10650941303798, 43.77236223220825, 42.24089935847691, 43.34706647055489, 38.488121713910786, 36.41051653453282, 34.045262881687705, 34.26056671142578, 27.826060601643153, 18.372492722102574, 17.24863202231271, 24.50738729749407, 35.38757841927664, 38.57474837984358, 36.000253200531006, 34.79205526624407, 36.85743509020124, 37.528915950230186, 39.747847488948274, 38.53460168838501, 40.01651348386492, 45.12330048424857, 52.31971304757254, 46.417826311928884, 39.18431731632778, 40.05035468510219, 37.115102086748394, 31.42703226634434, 39.00748566218785, 37.52945096152169, 41.58285978862217, 47.32004989896502, 42.93701505661011, 41.35382979256766, 39.15671559742519, 39.922671113695415, 42.205918652670725, 40.09049442836216, 40.67884356634957, 40.06272595269339, 38.059438705444336, 35.40301384244646, 30.135323933192662, 26.164643832615443, 28.73024879183088, 29.02293470927647, 32.8369641985212, 33.982235772269114, 36.43296616418021, 36.333982127053396, 40.0986133984157, 39.72755527496338, 42.322634492601665, 41.79699632099697, 44.31893880026681, 42.97911071777344, 43.458588532039094, 43.737850529806956, 46.79816722869873, 42.15409203938076, 46.29172345570156, 40.79171705245972, 42.316339424678254, 45.054947580610005, 47.618009499141145, 48.97194937297276, 48.80699913842337, 52.11233711242676, 49.52781915664673, 39.22255325317383, 40.13183968407767, 48.92908246176583, 52.059982436043875, 49.4822598184858, 53.21189301354544, 53.02652549743652, 54.932722091674805, 48.134229387555806, 53.29344402040754, 55.21490928104946, 51.66177422659737, 55.54194014413016, 55.159407070704866, 49.00071491513933, 48.89086389541626, 48.65494476045881, 54.222842012132915, 53.743325982775005, 57.96334566388811, 40.41445071356637, 16.707330874034337, 8.276622942515782, 0.3729151652327606, 0.6645052486232349, 0.12464866068746362, 2.8009074415479387, 57.37674747194563, 48.89692619868687, 56.40971108845302, 57.19177252905709, 57.77746398108346, 20.412061725343975, 39.24761193139212, 47.69193138395037, 33.751670224326, 38.77025331769671, 51.933910846710205, 28.293608358928136, 0.29299446088927134, 0.04758134537509509, 0.033406989715461216, 0.02068173379770347, 0.08994102451418128, 0.037757827501211844, 0.01792950415983796, 0.14043553785554, 0.02341133768537215, 0.07704771922102996, 0.05065101744340999, 0.1306053296263729, 0.009077579730988612, 0.16903315617569856, 0.12133061087557248, 32.08610364368984, 69.3102055958339, 38.19246891566685, 36.221775668007986, 39.41085638318743, 43.401366642543245, 26.559028795787267, 45.04960788999285, 64.77881281716483, 58.98794787270682, 54.616693701062886, 54.03697769982474, 57.37788002831595, 5.5398721269198825, 0.3306319841316768, 1.3757457094533103, 0.7068854602319854, 0.16708654777279922, 0.031628104991146495, 9.202259353228978, 52.46846008300781, 56.34053829738072, 59.89493792397635, 53.29857873916626, 53.17225701468331, 49.60884557451521, 48.500045095171245, 49.724196093423025, 53.05980736868722, 55.34253379276821, 54.62201254708426, 55.558101654052734, 54.55091857910156, 55.858190877096995, 51.51440988268171, 50.03894601549421, 51.51349966866629, 50.07724101202828, 44.73574038914272, 52.309950828552246, 53.984504904065815, 52.69844198226929, 49.59185722896031, 50.18364919934954, 46.851619720458984, 45.89959839412144, 47.85474852153233, 49.56317506517683, 46.02700056348528, 48.463799817221506, 48.25560399464199, 45.141796588897705, 47.581309114183696, 45.796973500932964, 46.66036013194493, 45.24212857655117, 46.57249321256365, 42.11841303961617, 38.94262422834124, 39.56457485471453, 37.20235061645508, 32.046783787863596, 23.041376454489573, 21.92202513558524, 30.400164944784983, 39.388316426958355, 41.58248111179897, 40.11261401857649, 38.02744572503226, 40.03121239798409, 40.971821308135986, 41.62551825387137, 40.511145319257466, 41.61999096189226, 46.06305129187447, 54.52120460782732, 47.65405327933175, 39.22307436806815, 41.76735183170864, 37.876846994672505, 31.15909583227975, 39.55636903217861, 39.4118013381958, 44.03952741622925, 48.811640535082134, 45.74901008605957, 43.603656496320454, 41.22618791035244, 41.235147612435476, 42.30815444673811, 42.209708895002095, 43.53533138547625, 41.7643849509103, 39.72234065192086, 38.045837606702534, 33.59071520396641, 32.36055401393345, 34.02508531297956, 33.36338751656668, 38.083524635859895, 37.62063911982945, 40.9322304725647, 39.523504052843364, 42.54226705006191, 43.78949301583426, 44.8386675289699, 45.41000747680664, 46.74075773784092, 45.91723987034389, 45.88729313441685, 46.98149197442191, 49.417916025434224, 45.10781294958932, 47.749861989702495, 42.678076539720806, 44.53233882359096, 45.931563581739155, 49.43391077859061, 50.2591552734375, 50.23186274937221, 53.829660824366975, 53.868754863739014, 42.70172125952584, 42.951984950474326, 50.26583249228341, 55.047655718667166, 51.99521827697754, 56.06163413184029, 54.13842487335205, 56.703890868595664, 51.50223663875035, 52.515238830021445, 57.655464036124094, 54.41983386448452, 57.10206781114851, 57.16088431222098, 51.94712284633091, 51.19962174551827, 51.20252261843, 56.19335460662842, 56.24177312850952, 59.47090326036726, 46.77296263831002, 24.018501622336252, 8.584067702293396, 0.22614639864436217, 1.877334645816258, 0.024443279186795865, 3.7574707184519087, 64.57586288452148, 54.829416275024414, 58.54562555040632, 65.34019252232143, 62.08418328421456, 24.701997654778616, 42.809720584324424, 55.19451631818499, 29.160609790257045, 38.31180770056588, 61.070781571524485, 35.4411837714059, 0.1699838244489261, 0.0714172695630363, 0.05451919969969562, 0.03485554662932243, 0.1115546515211463, 0.06269916665873357, 0.19701974014086382, 0.2565458124237401, 0.11827792253877435, 0.22171787199165138, 0.17585001752844878, 0.2577193523091929, 0.17901595335985931, 0.4167207075016839, 0.3153774583978312, 41.84018284933907, 80.23310034615653, 48.87923608507429, 43.29763698577881, 44.57863467080252, 53.16826180049351, 30.69629716873169, 52.76311928885323, 68.69842365809849, 64.58939797537667, 59.587375913347515, 60.34065096718924, 62.70286478315081, 7.566141843795776, 0.36076887271233965, 2.362162572996957, 0.8320244710360254, 0.14447620032089098, 0.1771607029118708, 9.696336201259069, 51.60630675724575, 59.013010025024414, 62.97942393166678, 55.117335728236604, 55.89597865513393, 51.503487314496724, 49.95609222139631, 51.317438874925884, 55.78574548448835, 56.66062791006905, 56.25682987485613, 57.4536258152553, 54.1001854624067, 57.94974456514631, 52.85421712057931, 50.98759746551514, 53.69741228648594, 52.59311771392822, 49.78424589974539, 52.676374503544395, 56.05843448638916, 53.209058148520334, 51.06453834261213, 52.96431827545166, 49.52723203386579, 49.542264461517334, 49.71734169551304, 53.37853513445173, 49.47777475629534, 50.006629943847656, 53.44748905726841, 50.39609384536743, 50.666198117392405, 49.26089021137783, 51.08914886202131, 49.602283000946045, 50.22608879634312, 45.73670482635498, 42.89502361842564, 41.700513635362896, 42.74909060341971, 39.48534107208252, 29.461067267826625, 29.44931091581072, 35.0497396332877, 44.182250363486155, 45.61372171129499, 42.66493402208601, 41.514218534742085, 43.05024290084839, 42.70726244790213, 43.284376348767964, 42.85259791782924, 44.780292238507954, 48.231410367148264, 57.60180309840611, 49.21890919549124, 40.26070097514561, 42.55332510811942, 39.052357128688264, 31.372791154044016, 40.96756553649902, 40.520730359213694, 45.40569264548165, 51.001083918980186, 48.71162469046456, 44.86523049218314, 42.1709692137582, 44.63961206163679, 45.90445518493652, 42.829668862479075, 45.44376529966082, 44.14692572184971, 41.40106364658901, 41.36437020983015, 38.00383227212088, 36.044551440647666, 37.14578185762678, 37.21371439525059, 42.54185363224575, 41.573403290339876, 45.531416824885774, 46.31524658203125, 47.44624655587332, 45.75723327909197, 47.60720157623291, 46.885176045554026, 49.496868406023296, 47.03847067696707, 50.66175127029419, 49.20804916109358, 53.02238784517561, 47.3108400617327, 50.66436726706368, 46.57880217688424, 47.79422971180507, 48.60854121616909, 53.8317174911499, 55.282477038247244, 51.71154069900513, 57.27966376713344, 55.397841453552246, 45.73135123934065, 46.88759401866368, 54.16727726800101, 56.87627567563738, 53.15771443503243, 56.69274248395647, 54.25140953063965, 57.630613803863525, 51.90548924037388, 54.03930187225342, 53.30982787268502, 54.99970620019095, 58.05844913210188, 60.60478673662458, 53.76958669934954, 52.813441617148264, 51.89524759565081, 60.568121092660085, 59.34431403023856, 63.5147339957101, 45.6738166809082, 24.982763937541417, 13.350299171039037, 0.6147025695868901, 2.0241209864616394, 0.16018670158726828, 3.812168674809592, 68.68053899492536, 59.4279008592878, 64.4507188796997, 68.52526760101318, 69.48586995261056, 32.14540651866368, 51.68816001074654, 61.28705814906529, 47.979916845049175, 57.864948749542236, 65.10690675462995, 51.22155026027134, 0.36012076320392744, 0.20359485303717, 0.19059037656656333, 0.14083929333303655, 0.14256602924849304, 0.17427247789289269], [0.044191333531801186, 0.080258791201881, 0.02177158317395619, 0.11325981002300978, 0.003799755392330033, 0.1347157997744424, 0.06106394476124218, 0.06857122228081737, 0.3925905366029058, 11.272277968270437, 58.8599967956543, 40.77701466424124, 41.68357045309884, 34.10659463065011, 31.666967460087367, 25.88108437401908, 54.79294865471976, 56.66485241481236, 55.23269319534302, 57.42055238996233, 44.53112636293684, 53.62210423605782, 12.556572573525564, 0.6216913717133659, 0.39243251936776297, 0.4287024417093822, 0.14070993741708143, 0.2850883879831859, 2.7333212281976427, 43.632682595934185, 57.998666831425254, 53.0676623071943, 53.35661704199654, 53.13027599879673, 49.41287510735648, 48.34853267669678, 50.78067316327776, 50.28086839403425, 52.700179031917024, 52.31484236036028, 52.93283946173531, 53.59854984283447, 54.199339730399, 51.83998162405831, 51.12186098098755, 47.29852090563093, 44.67891107286726, 53.82650981630598, 54.94637530190604, 48.479009423937114, 48.935964652470176, 46.895688670022146, 44.68580368586949, 44.77794374738421, 45.11268016270229, 44.24879673549107, 49.45389379773821, 43.003196648189, 44.6047112601144, 45.1677759034293, 46.02351604189192, 44.26094913482666, 44.12365273066929, 43.624021666390554, 44.576769079480854, 45.86709819521223, 43.81271389552525, 42.92327151979719, 40.068305356161936, 36.48545633043562, 34.10710532324654, 27.569670336587087, 23.818897247314453, 20.62970014980861, 22.833821603230067, 31.916591916765483, 36.596888065338135, 35.13187428883144, 35.692104067121235, 37.77138376235962, 39.07619292395455, 38.514649936131065, 40.42279897417341, 52.43309722627912, 52.54830183301653, 47.79231548309326, 38.66936547415597, 37.16484771456037, 40.753873688834055, 44.97264616830008, 38.91426168169294, 40.28795875821795, 39.15915094103132, 49.32755817685808, 50.06894138881138, 43.18945005961827, 41.21971218926566, 40.378108160836355, 40.70561497552054, 40.8011839730399, 39.961671352386475, 37.076018469674246, 40.2274295261928, 34.30412496839251, 25.824953351702007, 19.911831378936768, 18.92861785207476, 20.757691179003032, 21.6481670992715, 31.715368611471995, 39.48603241784232, 39.04186882291521, 40.826444149017334, 43.969750131879536, 43.42288868767874, 44.265232699257986, 43.955075536455425, 43.328685011182515, 43.416690894535606, 44.8744090625218, 44.16471311024257, 43.935901982443674, 45.97171722139631, 41.5543270111084, 43.91896227427891, 44.53555931363787, 45.34779330662319, 47.96426255362374, 49.92811182567051, 49.00945574896676, 51.5591528075082, 50.654090881347656, 51.05814947400774, 49.64173834664481, 52.03747374670846, 49.55998584202358, 51.11564929144723, 52.52566807610648, 50.51137488228934, 54.73107494626726, 54.81611394882202, 50.883714948381694, 55.74296889986311, 52.880019256046836, 56.14237914766584, 52.30664348602295, 52.14652224949428, 48.903207370213096, 56.8940873827253, 53.757715702056885, 62.5400059563773, 36.17327724184309, 26.518795251846313, 2.4142538692270006, 0.3538162229316575, 1.981119019644601, 0.16816879755684308, 8.276463133948189, 55.779016154153005, 46.875424248831614, 57.530559744153706, 58.64334501538958, 52.06328977857317, 19.013245173863, 52.50249235970633, 37.39628873552595, 33.91576583044869, 37.32183531352452, 51.799758502415244, 21.823987790516444, 0.2566241425062929, 0.09270076892737832, 0.04441156564280391, 0.07309333926865033, 0.057454823782401424, 0.03439271789310234, 0.05591166212356516, 0.0899793142452836, 0.005776754530545856, 0.1496433937656028, 0.05511565572981324, 0.1897114294448069, 0.09318018784480435, 0.17756972382111208, 0.45728776497500284, 14.653981855937413, 70.26498535701207, 46.16008288519723, 38.41364744731358, 37.2933338029044, 38.06614719118391, 28.299802677971975, 62.89903327396938, 61.92374243055071, 61.09377316066197, 61.02331147875105, 50.44253213065011, 57.83773960386004, 15.233404295785085, 0.7011771893927029, 0.617421920810427, 0.7234845981001854, 0.17184542598468916, 0.39281467029026573, 3.14383903997285, 46.70684010641915, 60.37042399815151, 54.437426703316824, 56.8169241632734, 53.43291868482317, 51.83218227113996, 51.810642855507986, 53.34503786904471, 52.18051631110055, 53.99161638532366, 54.04659400667463, 54.767959458487375, 54.03369467599051, 56.70801115036011, 53.41812597002302, 52.936237130846294, 49.55879075186593, 47.66999592099871, 55.111565249306814, 53.766394002096995, 50.13874299185616, 51.421338762555806, 48.867653438023154, 46.619334493364605, 46.42784908839634, 46.416342871529714, 46.34631197793143, 51.469830240522114, 45.51736756733486, 46.68813555581229, 48.11202989305769, 47.43171092442104, 46.937047822134836, 47.00148541586739, 47.666271686553955, 47.514182567596436, 48.33273594720023, 47.51573201588222, 45.08571072987148, 41.56072282791138, 39.19113349914551, 38.86681590761457, 31.174242905208043, 29.026523453848704, 26.385014636175974, 28.912585156304495, 37.00599799837385, 38.48683282307216, 38.3001833643232, 38.84986925125122, 39.98526743480137, 41.608432633536204, 39.39872482844761, 42.831006390707834, 52.67669064658028, 54.36216729027884, 46.54977260317121, 39.934205123356406, 38.83034828730992, 42.67622831889561, 43.8953766141619, 39.72029440743582, 43.04948902130127, 41.56656973702567, 50.386474064418245, 51.05438355037144, 43.102910246167866, 42.26422446114676, 43.73493228639875, 42.04211139678955, 41.212767464774, 41.71928071975708, 39.78507941109793, 41.792344502040315, 37.80463089261736, 30.615520886012487, 24.65741801261902, 23.590518644877843, 24.843141623905726, 27.548580816813878, 35.575471605573384, 40.664023058755056, 41.07451915740967, 44.46738011496407, 46.28156866346087, 46.46284021650042, 46.81598588398525, 45.41782072612217, 46.423357078007285, 46.71586234228951, 48.2691182409014, 46.614112922123496, 47.21021972383772, 48.791466440473286, 43.48321294784546, 45.28840357916695, 47.03012241636004, 48.11838402066912, 49.721889291490825, 52.48645939145769, 49.71273851394653, 55.736319473811555, 50.95874159676688, 53.015523024967735, 51.22993673597063, 52.01467323303223, 50.16719586508614, 52.74451896122524, 55.49308735983712, 51.56028536387852, 55.05967262813023, 56.1251927784511, 51.6571432522365, 58.09288093021938, 53.13197830745152, 59.26622322627476, 54.94168874195644, 55.345531940460205, 51.49372162137713, 58.53731550489153, 55.38705437523978, 64.161041532244, 40.840430872780935, 30.571959154946462, 3.53851061633655, 0.5938237756490707, 2.5973677805491855, 0.22488695622554847, 9.072769250188555, 62.222591400146484, 50.30906418391636, 63.91036442347935, 65.31181607927594, 57.67294222967965, 24.968824114118302, 56.03378227778843, 46.71315254483904, 36.84848928451538, 39.32412896837507, 63.99341624123709, 27.36023599760873, 0.23067044945699827, 0.11255912762135267, 0.01626799411938659, 0.02637461037375033, 0.10806316137313843, 0.07382437932704176, 0.11117318591901235, 0.14553073873477324, 0.15958341610218796, 0.25164741384131567, 0.13848745024630002, 0.5350360444613865, 0.16322349863392965, 0.44638674706220627, 0.48653669548886164, 19.172225168773107, 86.16691752842495, 54.0245543207441, 61.683168002537315, 48.76620626449585, 48.099703788757324, 33.04174150739397, 67.16742978777204, 69.19434438432965, 68.60148239135742, 68.69121142796108, 58.18849161693028, 64.04770251682827, 17.439167261123657, 0.6660362407565117, 1.2947097378117698, 1.4020965354783195, 0.5789467596582004, 0.3478720118956906, 3.940200958933149, 48.44100277764456, 59.06546892438616, 57.041510786329, 59.07857322692871, 55.87866374424526, 53.28764574868338, 52.8293251991272, 55.50097009113857, 56.01030431474958, 56.1125123160226, 55.58422688075474, 56.461172921316965, 55.85247598375593, 58.65574754987444, 54.57142966134207, 54.94967222213745, 52.34605714253017, 51.54558992385864, 56.01014103208269, 57.367871148245676, 52.59123822620937, 53.95549617494856, 50.146069867270334, 50.102396965026855, 49.90484230858939, 49.3366950580052, 48.14411667415074, 53.65206139428275, 48.22287450517927, 49.91915559768677, 50.33576611110142, 53.06965296609061, 49.8926864351545, 49.92594051361084, 49.72925090789795, 51.73921537399292, 51.294475078582764, 51.5111893926348, 49.67768485205514, 45.983963421412874, 44.58935226712908, 44.3777414049421, 38.34851155962263, 34.1293534551348, 32.1120343208313, 35.80221217019217, 39.83703804016113, 43.1500746182033, 42.089998381478445, 41.687857491629465, 41.74744871684483, 44.05890941619873, 42.05961390904018, 44.77654715946743, 56.545242650168284, 56.64165585381644, 50.25793586458479, 42.778224400111604, 40.907599108559744, 43.992446422576904, 48.404364926474436, 42.164799213409424, 43.45478439331055, 43.03729145867484, 51.391676902770996, 53.497321537562776, 46.04408270972115, 44.86153752463204, 46.58883537564959, 43.25841440473284, 42.52784606388637, 44.02831302370344, 40.00009836469378, 44.826897280556814, 40.176471437726704, 37.54119341714041, 30.70188352039882, 29.440146241869243, 32.7190636907305, 34.80452380861555, 39.44734832218715, 46.69681732995169, 43.798852239336284, 47.28927285330636, 50.467733246939524, 49.65133728299822, 50.904160022735596, 51.022901262555806, 49.61690201078142, 50.20017548969814, 51.98035955429077, 49.822339398520334, 50.52284288406372, 51.14127424785069, 46.33181456157139, 49.083509649549214, 50.51134361539568, 49.768581186022075, 51.64201702390398, 55.19772638593401, 53.005097252982004, 57.06282785960606, 52.24338361195156, 55.94449445179531, 53.39649622780936, 55.64596509933472, 53.577163287571494, 56.42736646107265, 58.34952654157366, 54.1344644001552, 57.67676373890468, 58.47279453277588, 50.35573870795113, 58.160577229091096, 56.656549317496165, 61.88795920780727, 56.377579144069124, 57.439847537449424, 52.69245263508388, 59.8075921194894, 57.842797892434255, 67.2230362210955, 38.313947745731895, 33.993710722242085, 5.487721988133021, 0.9236359809126172, 3.5374712092535834, 0.26203600210802896, 10.530797481536865, 67.32841260092599, 56.02497891017369, 67.95151315416608, 68.91094820840019, 63.58348642076765, 29.676117488316127, 66.46990707942417, 53.167323793683735, 48.09247766222273, 50.15788875307356, 71.49757494245256, 40.03648260661534, 0.35685198860509054, 0.14592526613601617, 0.16066232749394008, 0.2634622555758272, 0.21465234112526688, 0.18284557786371025], [0.04767333097489817, 0.0394278073550335, 0.030467189249715636, 0.027103755623102188, 0.023857354020167674, 0.08974596605237041, 0.018621521669306924, 0.0834378973980035, 0.09931326231786183, 2.342316563640322, 54.52545690536499, 41.46825967516218, 44.20169489724295, 29.15850101198469, 35.819186619349885, 20.237931183406285, 43.960700103214805, 61.312919344220845, 51.207285608564106, 58.293002946036204, 44.55810621806553, 58.227540493011475, 17.12174575669425, 0.2951395543558257, 0.11258183140307665, 0.31141942792705124, 0.4103755365524973, 0.05430130174915705, 0.8023512661457062, 39.20349087033953, 55.843356473105295, 57.95831516810826, 54.150021416800364, 51.181490421295166, 54.24024724960327, 53.086380754198345, 55.37980045591082, 54.67557273592268, 57.583869797842844, 52.57741478511265, 53.93036106654576, 51.50116661616734, 53.39851120540074, 48.468118122645784, 51.721056256975444, 49.965826647622244, 54.81911209651402, 52.50332266943795, 51.896546908787315, 49.105393001011436, 49.50450447627476, 47.44422810418265, 51.41745819364275, 50.43176589693342, 48.54943983895438, 47.08801480701992, 48.63451705660139, 43.60040473937988, 41.972459180014475, 48.10944863728115, 44.25522034508841, 46.10947568075997, 45.50317587171282, 45.540525913238525, 43.8603299004691, 44.347280502319336, 44.851688453129356, 40.29031767163958, 38.52048989704677, 33.048432622637065, 30.792213576180593, 32.29368107659476, 28.32854563849313, 19.258768456322805, 21.475162165505544, 31.117896488734655, 37.01251540865217, 35.59579161235264, 36.53062309537615, 38.090205328805105, 36.58839041846139, 39.44371094022478, 41.929960523332866, 52.728333132607595, 50.04085329600743, 53.76404898507254, 43.969663279397146, 39.845219544001985, 39.18978902271816, 41.615731716156006, 36.54517609732491, 36.869295665196006, 38.48309121813093, 49.03675174713135, 53.499225343976704, 51.595867088862825, 43.55698544638497, 40.422253540584016, 40.27242953436715, 40.217271259852815, 35.6722217968532, 37.96581867762974, 37.965488638196675, 32.63011980056763, 16.675956283296856, 10.201393808637347, 9.411185605185372, 10.69272003855024, 16.260188238961355, 34.919968128204346, 38.40919712611607, 40.21758392878941, 40.44115611485073, 44.127387387411936, 42.58611365727016, 45.424331188201904, 40.328063760484966, 43.90415913718087, 42.661275795527864, 45.996470178876606, 45.489553928375244, 42.203764711107524, 44.47802128110613, 42.034107072012766, 45.191292081560405, 48.02762317657471, 49.91750887462071, 52.01206765856062, 52.29191330501011, 52.761920724596294, 51.12891687665667, 51.03214931488037, 50.277210167476106, 50.79783868789673, 48.17179829733712, 46.519349915640696, 46.915334701538086, 50.43929079600743, 51.603867939540315, 52.446997097560335, 54.92397083554949, 54.6079181262425, 54.00977897644043, 53.44344520568848, 56.33357620239258, 54.61397000721523, 54.813449314662385, 56.7811096736363, 54.259278365543906, 62.141471181597026, 53.93851825169155, 38.73379611968994, 33.03343493597848, 0.3163829387298652, 0.5307840183377266, 1.4824674342359816, 0.3359381822603089, 18.557453768593923, 57.82855061122349, 48.68908820833479, 57.522694383348735, 57.83867761066982, 43.46088491167341, 14.187699539320809, 56.404096943991526, 32.32825878688267, 31.123468944004603, 38.35489695412772, 51.3893666267395, 8.267838682447161, 0.2721526063978672, 0.08886613004973956, 0.03501998619841678, 0.05444835725107363, 0.03030357410066894, 0.06547545375568525, 0.0997342729408826, 0.04159373863201056, 0.042030966241977046, 0.07945589428501469, 0.038965911604464054, 0.08303180097469262, 0.03753000597602554, 0.15319819801620074, 0.10248016166899886, 3.3549389924321855, 66.69766902923584, 49.297048636845176, 45.25750841413225, 37.90949310575213, 42.682012694222585, 19.437722785132273, 54.44745990208217, 66.07150432041713, 58.99343694959368, 62.957502365112305, 51.69144650868007, 61.2132682800293, 19.977170501436504, 0.2483839860984257, 0.22838044805186136, 0.5806623675993511, 1.0303121081420352, 0.21987936778792314, 1.4132369948284966, 40.28959158488682, 58.11571271078927, 58.172444752284456, 55.22388287952968, 52.67109039851597, 57.144785336085725, 53.74583428246634, 57.85454729625157, 56.26368774686541, 59.53399290357317, 55.083028997693745, 57.62605231148856, 53.36300938470023, 54.27528006689889, 50.88463905879429, 54.78801890781948, 53.67391347885132, 57.341071946280344, 54.95911829812186, 54.03130102157593, 50.388937200818745, 50.464655194963726, 49.122843401772634, 54.177119391305105, 50.59392990384783, 50.95320388248989, 48.510130405426025, 48.78313207626343, 46.204134464263916, 45.03361661093575, 49.09523473467146, 47.01907130650112, 48.00390897478376, 49.112313406808035, 47.769216196877615, 48.29952008383614, 47.61878422328404, 48.18434674399239, 45.26972682135445, 43.62057883398873, 37.139021260397776, 35.836782932281494, 37.05792188644409, 32.59168931416103, 24.85003423690796, 27.592307567596436, 34.78244590759277, 40.40076623644148, 37.432488850184846, 39.58616290773664, 39.4815126146589, 39.7181647845677, 40.431546756199424, 43.75104863303048, 53.25941869190761, 52.554016726357595, 54.70835433687483, 46.081971236637656, 39.77115522112165, 43.00794226782662, 42.33753490447998, 38.8672571182251, 37.70284325735909, 42.01460347856794, 49.59350047792707, 56.051225730351035, 51.21094730922154, 44.54394578933716, 42.209364959171836, 41.52812188012259, 42.695888246808735, 37.6198296546936, 39.64337090083531, 40.92804070881435, 37.62642002105713, 21.54161821092878, 12.961541380201067, 13.588914207049779, 13.947963237762451, 19.870043175561086, 38.9888471194676, 41.708000319344656, 43.906403405325754, 44.37503855569022, 48.48456103461129, 47.20481749943325, 48.07808099474226, 44.778621196746826, 47.35196644919259, 47.54954195022583, 48.09580932344709, 46.95946618488857, 44.70412608555385, 48.19784361975533, 43.6744065284729, 46.990555899483816, 49.92080579485212, 50.645138127463206, 52.56021451950073, 54.592451436179026, 54.58534342902047, 53.806499004364014, 52.95027249200003, 51.22413499014718, 50.637967586517334, 49.385054520198274, 48.311957359313965, 48.08815935679844, 52.204741205487935, 53.68904665538243, 54.49460342952183, 55.677322319575715, 55.704420294080464, 54.65629495893206, 54.17998552322388, 57.733798027038574, 57.23912450245449, 56.799213205065044, 59.9718336377825, 56.053025313786094, 62.40944235665457, 58.05206026349749, 41.46094669614519, 35.340785775865825, 0.39561791558350834, 1.1087429395743778, 1.5898922298635756, 0.32983929238149096, 21.02693908555167, 63.69583879198347, 53.713879517146516, 62.75127288273403, 64.03979546683175, 49.49779946463448, 17.17844479424613, 60.53671523502895, 42.676523617335725, 33.15710939679827, 40.578355244227815, 62.68403516496931, 10.844288042613439, 0.3212420094226088, 0.06595770894948925, 0.013265062755505954, 0.06484224487628255, 0.052399422374687026, 0.07407376130244561, 0.1629849121506725, 0.10595563160521643, 0.12173845113388129, 0.13882483142827237, 0.1809667143970728, 0.22898822543876513, 0.1480413590158735, 0.4322968045515673, 0.12459857123238699, 4.574819019862583, 83.41827964782715, 54.00688852582659, 64.05027335030692, 43.36102540152413, 51.886774267469136, 29.132810047694615, 57.89917210170201, 73.54624434879848, 64.28357301439557, 70.39241531917027, 56.44386148452759, 68.94976779392788, 23.057914904185704, 0.2790346342538084, 0.4890782705375126, 1.1150636289800917, 1.9940014140946525, 0.30806963624698774, 1.6278119151081358, 43.021803924015586, 58.00077560969761, 57.64495141165597, 57.09350068228585, 57.71610791342599, 58.5851469039917, 54.959319795881, 58.57221630641392, 57.37036207744053, 61.12592942374093, 55.19811201095581, 58.01769099916731, 55.686900411333355, 55.08342851911272, 51.50989702769688, 55.48950208936419, 55.58116619927542, 56.47382211685181, 58.16196686880929, 55.33765615735735, 52.03259263719831, 51.467867374420166, 52.48485088348389, 55.97249221801758, 53.82520702907017, 53.759480544498985, 52.332209382738384, 52.88707515171596, 49.516893114362446, 46.15554223741804, 54.60447529384068, 50.893894059317454, 53.30258090155465, 53.65211350577218, 53.08345208849226, 51.211339882441926, 50.499976362500874, 50.793315410614014, 48.25469378062657, 45.857318605695454, 41.46788099833897, 41.50638096673148, 41.52371324811663, 39.52915988649641, 32.47549111502511, 34.64122029713222, 41.834586075374055, 44.214774881090435, 40.370485986982075, 43.630837849208284, 43.49411467143467, 41.009602137974326, 44.194545200892854, 47.096981457301546, 55.91700390407017, 55.4386100087847, 55.4667432648795, 50.412620135716026, 43.24688386917114, 44.85345676967076, 45.18902696881975, 40.288427761622835, 39.20285858426775, 43.31477819170271, 50.81570945467268, 57.433239800589426, 55.81863825661795, 47.51087869916643, 43.569398403167725, 44.89566012791225, 42.88235010419573, 40.20005362374442, 43.10527958188738, 45.44704484939575, 42.00823892865862, 28.50842581476484, 18.930403539112636, 18.91274642944336, 19.616588524409703, 25.64813038281032, 44.711553709847585, 45.843383993421284, 48.14677783421108, 48.628270626068115, 51.31157112121582, 48.93317495073591, 52.14944396700178, 47.32109212875366, 51.306137629917686, 52.57512187957764, 51.91037034988403, 49.67704561778477, 47.13926819392613, 48.75735425949097, 46.48894807270595, 50.46375887734549, 52.29919501713344, 55.01501655578613, 57.00171497889927, 59.215153966631206, 56.363620213099885, 55.00561216899327, 57.145410673958914, 52.82926613943917, 54.054820673806326, 53.27534048897879, 50.73265068871634, 49.533749444144114, 53.80248294557844, 55.45788083757673, 54.9085944720677, 57.14083528518677, 56.8516651562282, 55.24519647870745, 57.075122697012766, 60.41612230028425, 58.33187116895403, 57.96194907597133, 61.21710368565151, 60.296321460178916, 61.49586541312081, 56.67701871054513, 40.54920060294015, 42.438193457467214, 0.8989825238074575, 1.7873796841927936, 2.371956927435739, 0.44557988750083105, 22.624190977641515, 70.3637192589896, 57.832882813044954, 69.31311689104352, 67.877334186009, 54.15092120851789, 22.92727140017918, 71.744875226702, 45.93788644245693, 45.631995473589214, 52.351323877062114, 74.96800558907645, 20.360810075487407, 0.5004986662949834, 0.29992211343986647, 0.14180881130908216, 0.17083614585655077, 0.2319846632225173, 0.1685751314674105], [0.029541002519960915, 0.03040471313787358, 0.0360257447298084, 0.01492832341630544, 0.0665373271331191, 0.05652202472888997, 0.06987296457269362, 0.04595453052648476, 0.06919721154762165, 0.610454723238945, 46.34728819983346, 50.90060601915632, 34.006280013493125, 31.430617536817277, 39.2349488394601, 15.467572484697614, 39.00577640533447, 59.281370299203054, 51.18898057937622, 59.62222807747977, 49.0546989440918, 51.95955317361014, 27.037975072860718, 0.3411503625767571, 0.05945137914802347, 0.8168834234986986, 0.5995513168828828, 0.380012858659029, 0.13228846288153104, 36.71292993000576, 53.86565596716744, 50.88580288205828, 62.69671562739781, 60.031511715480256, 57.42415503093174, 52.97186401912144, 53.60767977578299, 50.19269575391497, 51.051500047956196, 50.96638461521694, 52.416487557547434, 53.57266780308315, 52.20843069893973, 49.84939915793282, 53.719445024217876, 51.78023406437465, 50.9863919530596, 53.01189953940255, 52.57605988638741, 51.281047684805735, 50.85966375895909, 56.45490564618792, 52.21223136356899, 51.431840964726035, 51.715834685734336, 48.18600041525704, 45.81400006158011, 46.17333657400948, 42.807149750845774, 47.95874220984322, 46.21824972970145, 47.96253592627389, 47.27713435036795, 48.63551412309919, 45.810147285461426, 47.818145411355154, 45.636310304914204, 43.31876993179321, 39.53128603526524, 34.79069341932024, 30.95597219467163, 28.18078351020813, 23.846148082188197, 19.59916765349252, 27.14406190599714, 33.178346565791536, 35.22824927738735, 35.80069746289934, 35.916704586574006, 35.02801956449236, 37.01583317347935, 38.571934359414236, 46.87363856179373, 53.04276691164289, 50.03357853208269, 50.76421635491507, 54.577269622257774, 47.04494987215315, 44.966649872916086, 46.55216973168509, 40.76336145401001, 44.724671908787315, 48.330693176814485, 54.170525550842285, 51.90942539487566, 55.45607083184378, 45.499072960444856, 41.266754967825754, 40.605057171412874, 41.50703409739903, 37.54452855246407, 37.44871636799404, 31.665025438581193, 24.023801360811504, 21.373376267296926, 14.805940696171351, 12.072581904275076, 19.4497674873897, 30.43597248622349, 37.34849555151803, 38.441752910614014, 43.47859934398106, 44.06613206863403, 43.48186499731881, 44.4018030166626, 46.27597883769444, 45.83000176293509, 43.63967595781599, 42.65553310939244, 47.616842201777864, 43.238625935145784, 43.05011783327375, 44.16277803693499, 41.69544839859009, 48.013806683676584, 49.18988656997681, 50.0212732723781, 44.814651080540244, 41.4425721849714, 44.676513944353374, 50.08663150242397, 52.49262244360787, 50.55655901772635, 47.265072277614046, 45.49186767850603, 44.32761710030692, 45.37412697928292, 47.85468251364571, 47.953239236559185, 53.09593105316162, 52.14756447928292, 53.336116382053916, 54.803537709372385, 58.51556764330183, 51.421748706272666, 57.69068098068237, 53.089257308415, 56.607498509543284, 65.20864922659737, 65.19283512660435, 45.924264499119346, 55.191743986947195, 23.67047677721296, 0.10922016536018678, 1.1588307661669595, 1.0703850835561752, 0.092857761574643, 29.371432031903947, 59.66761371067592, 48.6540310723441, 51.03606462478638, 65.36146790640694, 34.45713472366333, 29.159178461347306, 62.41113771711077, 27.022522279194423, 38.699798583984375, 34.50155108315604, 38.75242076601301, 2.6736225230353217, 0.09723435994237661, 0.06489506882748433, 0.0970849058191691, 0.05614072536783559, 0.0381507399891104, 0.035786449177456756, 0.08936747243361813, 0.012144625020612563, 0.006475809720411364, 0.03682626338143434, 0.03293850878253579, 0.07371751684695482, 0.07789764540003878, 0.04765731754845806, 0.08052169638020651, 0.832855106464454, 53.75873013905117, 58.319218499319895, 37.2775752885001, 38.90250185557774, 49.73202323913574, 15.1746346950531, 45.80566917146955, 66.64016573769706, 56.185951301029746, 64.09419291360038, 51.41574198859078, 58.2869302204677, 30.85453544344221, 0.3513999325888497, 0.23522255090730532, 1.0290501415729523, 1.1265112204211098, 0.8730799108743668, 0.13358322983341558, 38.07410287857056, 56.939212458474294, 55.865719250270296, 62.09088134765625, 57.89212315423148, 57.196014404296875, 58.247005871364046, 56.93256650652204, 53.632689816611155, 53.98683255059378, 51.31214782169887, 54.1469155720302, 55.16511501584734, 54.97206279209682, 52.232148374829976, 53.21047905513218, 54.95842000416347, 53.119558402470176, 54.23897572926113, 54.93097114562988, 52.52280541828701, 53.96668972287859, 55.03930050986153, 53.97161252158028, 53.75594738551548, 52.64715038027082, 49.19376366479056, 46.50530760628836, 46.533816065107075, 44.320602893829346, 49.813591616494314, 47.64022983823504, 50.14178630283901, 49.88636704853603, 50.997644560677664, 48.508056368146626, 49.51345028196062, 49.31967544555664, 46.24857861655099, 43.746501037052695, 39.306279046194895, 36.265969685145784, 32.49749605996268, 29.826556410108292, 25.156566177095684, 32.440194266183035, 37.491374833243235, 38.84990746634347, 39.511928353990825, 36.24553850718907, 38.127173219408306, 39.37050819396973, 39.7875633920942, 47.31371314185006, 54.53665740149361, 51.28213855198452, 52.051158223833355, 54.138866083962576, 47.702527386801584, 47.434663908822195, 47.95445169721331, 42.60236201967512, 45.46357808794294, 47.48996809550694, 53.36857489177159, 54.05234711510794, 57.43849958692278, 48.41839681352888, 41.96103286743164, 42.20490074157715, 42.80807386125837, 39.61284399032593, 38.76698071616036, 34.71550348826817, 27.598185743604386, 26.68111559322902, 19.16177681514195, 16.98107600212097, 24.90506223269871, 34.95453194209507, 40.46530110495431, 41.288151945386616, 45.623841762542725, 46.508687904902864, 45.90014730181013, 47.59351362500872, 48.52945334570748, 48.97037213189261, 46.16701718739101, 47.11462640762329, 49.5093925339835, 45.69589805603027, 47.0162399155753, 47.4261280468532, 44.17027514321463, 51.86362286976406, 51.164210251399446, 52.761674063546316, 49.49461718967983, 44.845094612666536, 45.422152927943635, 50.79841538837978, 54.20804582323347, 51.996819836752756, 50.176433495112825, 47.76589148385184, 45.45059190477644, 45.883985791887554, 49.34704787390572, 50.6616644178118, 53.57561036518642, 53.64296620232718, 56.4022660936628, 56.50775017057146, 57.172876902988975, 53.243976320539204, 58.09503834588187, 55.6659620148795, 58.1240679195949, 62.96180330004011, 67.18171528407505, 47.12804685320173, 55.052234581538606, 27.43715081896101, 0.12694434821605682, 1.6466095064367567, 1.195894520197596, 0.12027903087437153, 32.623317514147075, 65.71495056152344, 54.25615515027727, 57.508064951215474, 69.42628914969308, 40.08115604945591, 32.68116821561541, 68.5168046951294, 33.627651827675955, 40.499593939099995, 40.55616964612688, 53.13720335279192, 3.8022453444344655, 0.2345749299441065, 0.11756546076919351, 0.02719863347842225, 0.036346810537257364, 0.0723998968356422, 0.06463284896952765, 0.14029425329395703, 0.13595027210456984, 0.20924508199095726, 0.08690198830195836, 0.13469570156719002, 0.19991884886154107, 0.17624162722911152, 0.08908679642315422, 0.17935125822467463, 1.1303961319582803, 65.2356846673148, 68.61198111942836, 44.7646518434797, 43.262774399348665, 56.00750766481672, 24.497897795268468, 52.78878246034895, 72.09307030269078, 62.829224722726, 70.62774385724748, 58.32644462585449, 63.20403834751674, 36.820939677102224, 0.46875766664743423, 0.5033873255763734, 1.2738477715424128, 1.0917697932038988, 0.5220958931105477, 0.5377188090767179, 40.153174127851216, 57.97748524802071, 56.379177229745046, 59.88646112169538, 57.80837999071394, 58.74251665387835, 60.848425320216585, 59.29555852072579, 56.07445008414132, 54.668933732169016, 53.71984454563686, 54.602029527936665, 57.57495525905064, 56.93231289727347, 52.75831460952759, 55.49515792301723, 56.15911040987287, 55.84348154067993, 55.788295473371235, 57.12637260981968, 54.15361016137259, 57.221132142203196, 57.15490886143276, 55.02108580725533, 56.05506461007254, 54.604610783713206, 51.58027185712542, 49.410696847098215, 51.260373319898335, 46.40560095650809, 52.447434834071565, 52.45451504843575, 54.630016871861045, 51.69216912133353, 53.528338296072825, 52.953930718558176, 52.58786487579346, 51.96953773498535, 48.58675166538784, 46.84852777208601, 42.18653665270124, 40.2784675189427, 37.55654198782784, 35.88531609943935, 30.873691626957484, 38.5685783794948, 42.04730517523629, 44.36265339170183, 41.719558647700715, 40.69155182157244, 40.94771453312465, 42.86486496244158, 42.819336891174316, 50.34118570600237, 54.833182198660715, 54.91148144858224, 54.41115556444441, 57.441330977848594, 51.14914655685425, 48.63861301967076, 50.7742669241769, 45.79665388379778, 48.25840411867414, 51.11833477020264, 56.30391434260777, 54.271781648908345, 58.64172608511788, 49.16828809465681, 45.37061813899449, 45.32764005661011, 46.430732590811594, 43.20591729027884, 42.578946590423584, 39.92440121514456, 33.0630898475647, 32.81540741239275, 25.94021006992885, 24.19444043295724, 30.691120760781423, 38.455506869724815, 45.48150444030762, 45.97640378134591, 51.08550105776106, 50.87200723375593, 48.70650039400373, 51.306189741407124, 52.45727000917707, 52.906592641557964, 51.09232766287667, 49.34406362261091, 54.37562942504883, 49.408483845846995, 50.51556117194039, 49.95306280681065, 45.50116784232003, 52.762883050101145, 53.64181627546038, 53.81672327859061, 51.42081764766148, 45.872170380183626, 47.11401149204799, 52.37350600106375, 54.77194425037929, 53.21219178608486, 51.75046798161098, 51.30799627304077, 47.78224754333496, 48.2036349432809, 52.34886074066162, 54.46981920514788, 56.64082554408482, 57.274501255580354, 58.88548278808594, 57.47824675696236, 57.64103957584926, 54.528486319950645, 60.806263651166645, 58.43917914799282, 60.73945672171456, 60.26985577174595, 65.0928783416748, 49.681885038103374, 57.07215234211513, 32.09982633590698, 0.35049210701669964, 2.510986690010343, 1.7877036439520972, 0.1765438060143164, 34.320105825151714, 69.73008523668561, 57.843322481427876, 63.093700953892295, 74.04231793539864, 47.349572794778005, 39.08743510927473, 76.43793869018555, 39.009653500148225, 55.16489267349243, 47.6662404196603, 71.91486985342843, 8.938708969524928, 0.499713194157396, 0.33561186119914055, 0.1741704533674887, 0.1753193081489631, 0.2217962834984064, 0.2059916422835418], [0.01977733991641019, 0.06444765640688793, 0.0807337114321334, 0.05533906677737832, 0.04104598106018134, 0.02320582639159901, 0.17795633950403758, 0.05593712415013995, 0.14203439706138202, 0.14142823458782264, 39.56437335695539, 49.46613999775478, 36.50823252541678, 33.28684268678938, 33.64244106837681, 25.32416193825858, 22.184950181416102, 61.82300744737898, 49.915542534419465, 56.63243906838553, 49.99489791052682, 53.11183547973633, 39.18025262015206, 0.5220864479030881, 0.19321542499320848, 1.0417344037975584, 2.222387398992266, 0.5706387226070676, 0.08302314965320484, 31.66134636742728, 57.58278587886265, 47.53407873426165, 53.784702505384175, 60.67437294551304, 64.01834637778146, 64.86303888048444, 61.92245701381138, 61.44277422768729, 56.96125214440482, 53.80778789520264, 55.10645137514387, 53.435829980032786, 51.05384159088135, 52.144232818058555, 52.109557832990376, 50.67680106844221, 52.988317353384836, 51.87557029724121, 49.54346649987357, 55.01540565490723, 49.22994293485369, 58.83482347215925, 71.13877691541398, 49.617245946611675, 50.75913722174508, 47.162145137786865, 44.2002010345459, 45.69119759968349, 41.065760953085764, 44.25746808733259, 45.94446986062186, 44.65164634159633, 45.809914520808626, 46.00022568021502, 46.24379130772182, 44.54143054144723, 45.05442646571568, 46.913910320826936, 43.874736990247456, 38.813623973301475, 36.85700082778931, 36.97024951662336, 32.63109949656895, 31.084378378731863, 31.45922327041626, 32.30855369567871, 32.37323795046125, 34.248855522700715, 34.598610469273154, 36.0117837360927, 36.222734519413535, 42.298135144369944, 54.04878963742937, 51.854058674403596, 49.002372060503276, 50.72500419616699, 54.68824972425188, 51.36801828656878, 49.08247089385986, 46.93385165078299, 50.00818634033203, 54.73254449026925, 52.59831149237496, 50.274493421827046, 53.221088954380576, 55.810519286564414, 51.525037152426584, 40.85883665084839, 38.22756079265049, 41.10156502042498, 36.89891930988857, 37.615893500191824, 37.23829364776611, 25.8826425075531, 21.947459016527446, 19.557667800358363, 17.727168355669292, 24.943536145346506, 35.971560614449636, 38.25482552392142, 39.920364311763215, 43.364211150578086, 45.58563014439174, 47.23518460137503, 42.799148900168284, 46.360382080078125, 42.45397629056658, 42.817877769470215, 42.47824287414551, 46.021834577832905, 41.05894129616873, 44.13036469050816, 43.40512909208025, 43.139162472316194, 48.0570626940046, 48.810723372868125, 50.06557846069336, 46.175921303885325, 45.068274225507466, 41.55505657196045, 39.51673650741577, 49.89117520196097, 48.551590306418284, 49.45790638242449, 42.86384357724871, 42.31388323647635, 42.0154059955052, 44.6542831829616, 44.66594920839582, 48.26313931601388, 49.527009691510884, 54.17503840582711, 55.43501084191458, 59.235255105154856, 51.4092766898019, 51.59787164415632, 59.62214469909668, 75.8535326548985, 62.99843420301165, 47.24457161767142, 47.094487054007395, 62.106292452131, 13.216319663184029, 0.4107373042830399, 1.3403400778770447, 0.47961308700697763, 0.3626006187072822, 39.204800605773926, 58.39685072217669, 50.13767991747175, 53.84490169797625, 59.15310655321394, 37.12860243661063, 17.738450493131364, 40.1287407875061, 35.557816232953755, 43.731023924691335, 35.08170134680611, 34.21750177655901, 0.5548012810094016, 0.12675796821713448, 0.08483426818358046, 0.015079709667978542, 0.04196888368044581, 0.09415716970605509, 0.03388217457437089, 0.04899236573172467, 0.06808978132903576, 0.09052661380597524, 0.009919327866685177, 0.028903104963579347, 0.048112051361905675, 0.21911620588174888, 0.03709644584783486, 0.19522474360253128, 0.18772865512541362, 46.789148466927664, 60.847174644470215, 37.86321810313633, 38.219115257263184, 46.88159772327968, 25.260040487561906, 27.998476675578527, 72.18401527404785, 55.11024856567383, 64.22135189601353, 55.2208708354405, 57.595924922398154, 42.96070841380528, 0.6529023540871484, 0.1611340178975037, 0.919008806347847, 3.3267890172345296, 1.8221828852381026, 0.07966748185987983, 33.94528177806309, 58.935037340436665, 49.44013636452811, 57.547099930899485, 61.82840619768415, 63.079040254865376, 61.98399026053292, 57.964676243918284, 59.6064487184797, 58.534001214163645, 55.70850236075265, 56.808235440935405, 55.49470976420811, 53.67921495437622, 53.350238595690044, 54.66684579849243, 54.38092395237514, 54.46650491441999, 55.370795590536936, 51.973116057259695, 56.74469416482108, 54.04827894483294, 60.17706952776228, 65.6790909085955, 50.57628147942679, 52.80856398173741, 51.22510426385062, 46.41895192010062, 48.420887742723735, 43.24303804125105, 47.921256678445, 47.91028547286987, 48.498561654772075, 49.16006142752511, 49.166690008980886, 49.61647817066738, 47.31519658224923, 48.178013460976736, 49.118848187582834, 46.79632943017142, 40.69501549857003, 41.1062342098781, 40.71189962114607, 38.59837572915213, 34.97756174632481, 37.653497150966096, 36.977249826703755, 35.96102714538574, 36.57635613850185, 37.505549158368794, 38.71447317940848, 38.54689652579171, 43.60299989155361, 54.47254637309483, 53.66344254357474, 50.171649660382954, 50.82880333491734, 55.64810861860003, 52.98086888449532, 51.08233962740217, 48.49417386736189, 50.14899505887713, 55.08368212836129, 54.16224329812186, 51.96504919869559, 56.68642657143729, 57.41207211358206, 52.30139759608677, 41.775623662131174, 41.669625418526785, 41.472036021096365, 38.2741310937064, 40.73323406491961, 38.83777938570295, 30.32931763785226, 27.71057459286281, 24.873512199946813, 23.23178141457694, 29.929021494729177, 37.85911519186837, 41.5383426802499, 44.62425306865147, 46.59646449770246, 47.71506888525826, 47.363806179591585, 46.111719948904856, 48.899948665073936, 46.57165595463344, 45.821646554129465, 46.41914299556187, 46.918162618364605, 44.67351232256208, 44.870521545410156, 45.30116394587925, 45.876936844417024, 51.372722217014854, 52.450703961508616, 50.969518252781455, 45.30525990894863, 44.70726319721767, 41.560163497924805, 41.55951384135655, 51.914171014513286, 51.4135741506304, 50.99790511812483, 44.64599745614188, 44.05269077845982, 44.267108712877544, 44.884386675698416, 46.119804177965435, 49.74378306525094, 51.26197835377285, 58.30594049181257, 57.237491675785606, 60.77968679155622, 53.4438099861145, 52.922656876700266, 60.88773822784424, 68.61207839420864, 60.9532527923584, 52.10493033272879, 48.57718052182879, 62.322569029671804, 13.716295531817845, 0.47194162436894005, 0.7975434927003724, 0.6027820120964731, 0.4772819663797106, 44.35090398788452, 61.221800667899, 57.98362398147583, 60.00995145525251, 66.52652100154332, 42.928909982953755, 21.30839150292533, 48.08185734067644, 45.49830865859985, 46.986883776528494, 40.53316763469151, 49.41210733141218, 2.6105137722832814, 0.0700251871187772, 0.07083342410624027, 0.01856563752517104, 0.030455175787210464, 0.005265462702871966, 0.03358516622600811, 0.10575390314417225, 0.1297070306858846, 0.3199468489204134, 0.17258367208497866, 0.12306979112327099, 0.1973850769656045, 0.370515729699816, 0.23348764543022427, 0.25447777339390343, 0.2056248669645616, 58.126524107796804, 69.29445402962821, 50.56571674346924, 45.877916540418354, 48.3442108971732, 37.350569588797434, 30.392039026532853, 76.37008258274624, 59.929123061043875, 68.85056141444615, 60.70788410731724, 65.55374540601457, 47.80969292776925, 0.8033186399510929, 0.35214395980749813, 1.94862077491624, 4.598233146326883, 1.4661734742777688, 0.10509731873337712, 35.911104338509695, 59.227903911045615, 52.96730947494507, 61.73664828709194, 63.45566735948835, 60.98802852630615, 59.55628967285156, 59.333440099443706, 61.90187644958496, 57.904317242758616, 58.81720978873116, 58.936440876552034, 59.65924807957241, 54.91199908937727, 55.490408829280305, 54.983864307403564, 54.630016871861045, 53.98793036597115, 55.368384565625874, 53.5382707459586, 59.50971589769636, 54.60508326121739, 60.214360509599956, 62.866091864449636, 52.311861583164756, 55.073398794446675, 53.2053165435791, 47.83581468037197, 51.928515570504324, 45.63609491075788, 51.00401258468628, 52.93661233357021, 50.76951435634068, 53.131596156529014, 54.09158706665039, 53.00436421803066, 49.29391499928066, 51.45299475533621, 54.92103174754551, 49.495263372148784, 45.19511011668614, 45.19511706488473, 43.310282707214355, 43.9444135257176, 40.89988660812378, 43.54568420137678, 42.76752070018223, 41.97239664622715, 39.830419881003245, 40.28462709699358, 42.158924511500764, 41.44065795625959, 45.07824489048549, 58.52615669795445, 55.14592409133911, 52.23972538539341, 52.36512994766235, 58.74214839935303, 54.598367827279226, 53.38895395823887, 47.55132416316441, 53.323467186519075, 57.8370760508946, 57.51786191122872, 54.38378661019461, 58.98916380746024, 58.77711173466274, 53.61269637516567, 44.647668497903005, 42.7020651953561, 44.22996016911098, 39.627779143197195, 41.7491579736982, 43.4194666998727, 34.39488581248692, 36.168368339538574, 31.623812198638916, 29.655467442103795, 35.65971156529018, 42.28085150037493, 46.0745644569397, 46.42867939812796, 49.18260138375418, 50.84364121300833, 52.59118958881923, 47.70416716166905, 51.4888196672712, 49.56910187857491, 49.53001478740147, 51.23698568344116, 49.35647310529436, 46.46311814444405, 48.378868511744905, 48.36255761555263, 47.585245268685476, 54.08626822062901, 54.57989951542446, 53.05909865243094, 44.885560921260286, 44.18427923747471, 43.322365624564036, 42.85638121196202, 54.20144850867135, 54.15018817356655, 53.13950320652553, 46.97745507104056, 46.52906002317156, 46.75994866234915, 46.90918901988438, 48.72124099731445, 53.00726161684309, 53.68175452096121, 58.48056261880057, 58.16331481933594, 61.52948079790388, 53.21617657797677, 54.616252490452354, 60.18715831211635, 67.25613743918282, 65.36114134107316, 56.95921284811837, 48.27185583114624, 64.64963190896171, 17.054966620036534, 0.5075271491493497, 3.852146003927503, 1.029593512415886, 0.6192376262375286, 46.744078976767405, 69.3290491104126, 60.514397621154785, 65.83744035448346, 68.67369501931327, 49.39535175051008, 25.34367769105094, 54.526214259011404, 49.76990481785366, 59.44575078146798, 50.099207741873606, 63.74106461661202, 6.004829074655261, 0.5234454178384372, 0.11624583229422569, 0.11046147732330219, 0.08921764511615038, 0.2597170951110976, 0.131252489185759], [0.03375567868351936, 0.006825952449746962, 0.053695047673370154, 0.05073286573003445, 0.033907063238854916, 0.08452919883919613, 0.04852613414238606, 0.15491941065660544, 0.09078725267733846, 0.24315036407538823, 20.437686681747437, 55.31910099302019, 38.46847915649414, 32.1520003591265, 27.49405309132167, 38.37673166819981, 12.010359917368207, 30.27397871017456, 58.49190207890102, 53.79449251719883, 50.007734707423616, 49.67820249285017, 50.81696013041905, 3.7129562156541005, 0.4413986461503165, 1.1290296167135239, 2.358743190765381, 2.1008015232426778, 0.3282458750264985, 22.994344098227366, 67.15218544006348, 53.63367298671177, 50.41846704483032, 45.35882704598563, 46.78150544847761, 45.633524077279226, 47.135373728615896, 44.525223868233816, 45.85441773278372, 52.99805872780936, 54.10223865509033, 51.6214781488691, 50.29401438576834, 52.2667121887207, 53.69145768029349, 55.111249106270925, 41.379142080034526, 45.05210229328701, 54.525203296116416, 52.56745106833321, 55.81428173610142, 37.541975089481895, 48.259699957711355, 53.17711727959769, 48.33823544638497, 51.559861523764475, 43.6245254107884, 45.796167509896414, 41.93305247170584, 46.13229703903198, 47.239492484501426, 45.251550333840505, 44.80912726266043, 43.89967060089111, 46.99982827050345, 45.89873334339687, 44.82365942001343, 44.979312964848106, 44.22845588411604, 44.92587089538574, 38.24560873849051, 37.342603479112896, 35.64541564668928, 35.78823239462716, 32.99026925223214, 32.56619637353079, 34.5411627633231, 34.12917627607073, 36.082085609436035, 36.096843583243235, 36.73520932878767, 43.71719353539603, 52.08536073139736, 52.56195156914847, 41.53998940331595, 43.79565259388515, 49.29938323157174, 50.885938371930806, 46.069106646946494, 44.92722579411098, 51.35637657982962, 50.76661000932966, 52.595803192683626, 45.64571121760777, 49.775793416159495, 55.827184540884836, 53.55943843296596, 44.58463096618652, 39.144187995365684, 39.26775128500802, 36.67533322743007, 36.455749307359966, 34.20265000207083, 30.416392462594168, 25.863310882023402, 21.636838061468943, 25.247622319630214, 35.06919458934239, 39.93665436335972, 37.26196616036551, 42.002395493643625, 44.38951860155378, 45.15390035084316, 47.46530893870762, 46.2361934525626, 43.79432896205357, 41.669076510838096, 43.815128394535606, 45.0797769682748, 44.525984695979524, 37.34469141278948, 44.14430625098092, 42.4200621332441, 43.317897932870046, 47.80084787096296, 48.49495553970337, 47.75628907339913, 45.06534555980137, 42.84559760774885, 44.44093527112688, 45.83664771488735, 46.371620791299, 49.8012238230024, 46.58740752083914, 41.402269159044536, 39.84636599676949, 40.268559387751985, 38.89699540819441, 40.01780932290213, 41.5411045891898, 43.3598233631679, 49.05093649455479, 54.308586256844656, 54.617277349744526, 57.17062221254621, 48.50842114857265, 49.41725942066738, 49.691525663648335, 34.12593494142805, 54.299067224775044, 55.395489488329204, 57.51629509244646, 3.1318544830594743, 0.2515131453318255, 1.3995024689606257, 0.3271074832550117, 1.285169318318367, 49.93101964678083, 49.42829663412911, 55.04779815673828, 49.842061860220774, 62.94584328787667, 29.435595171792166, 32.96448796136038, 35.22285052708217, 26.21623420715332, 56.27696228027344, 37.24293157032558, 32.327216557094026, 1.6539501696825027, 0.1266912817955017, 0.007091250736266375, 0.1735383572855166, 0.047980072908103466, 0.10315576541636672, 0.08063756301999092, 0.026003964012488723, 0.057661566617233415, 0.04510341351851821, 0.03958887121241007, 0.040076228989554305, 0.014774072050516094, 0.08862420517419066, 0.07416866121015378, 0.07923325337469578, 0.22007228886442526, 26.03392563547407, 65.05735220227922, 45.242340496608186, 34.417710644858225, 34.05310044969831, 43.37930958611624, 14.907914195741926, 40.21027094977242, 66.72330093383789, 60.48051125662667, 54.688586711883545, 54.481811795915874, 54.72023923056466, 3.5952126937253133, 0.4273388034531048, 1.3584743333714349, 2.2601693144866397, 3.2248554698058536, 0.32744262527142254, 26.249196461268834, 67.3407734462193, 55.04672813415527, 50.970421518598286, 49.61777400970459, 50.220356532505576, 49.270603793007986, 46.53783907209124, 43.16535370690482, 46.412278175354004, 54.42938068934849, 56.653915950230186, 53.69614424024309, 50.435681206839426, 54.41478252410889, 55.451273100716726, 57.34206553867885, 44.40328993116106, 48.29027550561087, 54.29411315917969, 53.65907212666103, 55.71694094794137, 39.56208392551967, 50.539754799434114, 53.016801493508474, 52.79029369354248, 52.738633837018696, 46.737485136304585, 48.15680408477783, 43.078744411468506, 50.00964546203613, 49.48352786472866, 47.394576277051655, 47.594350882938926, 45.80673571995327, 49.12619590759277, 46.90008340563093, 47.32694946016584, 47.867640904017854, 48.15838132585798, 48.05697236742292, 40.060252393995015, 39.63812848499843, 39.79789883749825, 39.54060704367501, 36.15094920567104, 36.458295822143555, 36.500777108328684, 38.993130683898926, 37.609188488551546, 38.68895244598389, 37.99594259262085, 46.66184704644339, 53.27872773579189, 53.61945002419608, 44.61259399141584, 44.18070438929966, 51.329754556928364, 50.46001032420567, 47.36875329698835, 44.231179577963694, 53.27624028069632, 52.308790479387554, 50.93103218078613, 45.73809099197388, 51.801030022757395, 58.442597661699565, 55.74578639439174, 45.608642578125, 40.01490844999041, 42.25747776031494, 38.17449392591204, 39.719158376966206, 37.77207858221871, 35.09315892628261, 31.93553270612444, 25.805831909179688, 29.103556394577026, 38.18533311571394, 42.95518112182617, 40.731774943215505, 44.953083515167236, 47.384800161634175, 47.37934235164097, 49.45529385975429, 47.35855334145682, 47.81600536618914, 42.94764232635498, 45.86200169154576, 46.23055498940604, 46.40413836070469, 40.30137920379639, 45.26005145481655, 44.401337487357004, 45.28851475034441, 49.23729065486363, 51.27366522380284, 49.62513910021101, 45.764372553144185, 42.91350930077689, 44.832970006125315, 48.4320569719587, 48.316261768341064, 51.01763800212315, 49.01644563674927, 44.56006213596889, 41.08504915237427, 41.10176999228341, 40.89786468233381, 40.85002286093575, 43.88395724977766, 45.04799590791975, 50.51239626748221, 56.276128496442524, 57.30957228796822, 57.61603648321969, 50.38300691332136, 42.31028754370553, 50.12907109941755, 39.37538235528128, 56.281600202832905, 56.23050315039498, 56.0477168900626, 4.511701583862305, 0.8034192259822572, 1.593622978244509, 0.3057158796914986, 2.121855216366904, 54.25246565682547, 56.13537883758545, 60.21464538574219, 57.82127932139805, 67.76575306483677, 33.69002233232771, 36.689431122371126, 40.483574867248535, 34.183872495378765, 52.178483963012695, 45.28764622552054, 47.51895598002842, 1.911508057798658, 0.20242789494139807, 0.06699950447572128, 0.054489540934030495, 0.04822797906984176, 0.0841146342988525, 0.06673962556357894, 0.1233885804457324, 0.13369427887456758, 0.18255435063370637, 0.11319773085415363, 0.18695220750357422, 0.1681603565812111, 0.23935575197849954, 0.20388654167098658, 0.19462027746651853, 0.3109554185398987, 33.11076143809727, 78.43735926491874, 53.99920729228428, 44.172731331416536, 42.22691263471331, 51.11076123373849, 20.18284239087786, 43.2162492615836, 69.70402949196952, 65.59512192862374, 60.619357109069824, 58.775513648986816, 60.027231625148225, 4.415246691022601, 0.7384351672870773, 2.08665303673063, 6.754528846059527, 5.293677909033639, 0.44343463118587223, 30.425247941698345, 69.58183847154889, 57.49426930291312, 53.795857838221956, 52.19702523095267, 55.791258880070274, 54.292754786355154, 50.01918881280081, 47.37470095498221, 47.284152030944824, 57.25670344488961, 57.96900149754116, 57.59195402690342, 53.29666798455374, 56.260769503457205, 58.70269652775356, 57.91190814971924, 44.83867447716849, 50.68794250488281, 56.646377154758994, 54.551005431583945, 55.27810662133353, 43.2446882384164, 52.82868596485683, 52.41078656060355, 54.187281131744385, 54.10024452209473, 49.15716750281197, 49.703667640686035, 47.935215609414236, 52.29944862638201, 52.551873207092285, 50.9266027041844, 51.82102346420288, 50.2930451120649, 52.793180670057026, 49.912395000457764, 50.761819226401194, 50.51892410005842, 51.17850617000035, 51.26748480115618, 45.08504370280674, 45.86523607798985, 45.026991503579275, 42.84538916179112, 40.04744338989258, 40.863474573407856, 41.860013008117676, 42.391209738595144, 41.949846267700195, 41.4823054586138, 38.35326065335955, 48.5263648714338, 55.8926157270159, 54.359051023210796, 44.3917350769043, 45.370899541037424, 53.508914606911794, 55.42123256410871, 50.147904191698345, 46.232354572841096, 56.441228117261616, 54.59544958387102, 53.54947819028582, 45.99332611901419, 53.311009066445486, 58.23934200831822, 57.25689104625157, 49.89592776979719, 41.81601701463972, 44.89479855128697, 40.061701093401226, 40.73544706617083, 43.13126931871687, 38.42182200295584, 37.887960638318745, 32.044758387974326, 35.86873074940273, 43.35666193280901, 47.723337241581504, 43.87736688341413, 48.561863218035015, 50.85152741840908, 49.86111729485648, 53.496154240199495, 52.68277032034737, 49.36371660232544, 46.11562136241368, 49.88068342208862, 51.43945619038173, 49.8436529976981, 42.04172229766846, 50.203635692596436, 47.12095621653965, 47.68856150763375, 48.820815631321494, 52.59324625560215, 49.38257053920201, 47.69487394605364, 43.471185616084504, 45.117064476013184, 47.195545128413606, 49.558009079524446, 51.442596776144846, 52.33718776702881, 46.159165722983225, 42.69012819017683, 43.528563840048655, 43.570572648729595, 44.40598235811506, 45.67370898383004, 46.868847778865266, 55.11631434304373, 58.72457640511649, 58.86244950975691, 57.3692364692688, 50.446134771619526, 46.836364950452534, 59.24986021859305, 47.112708704812185, 57.16688060760498, 56.21603005273001, 61.90778936658587, 5.863038488796779, 0.7098623833486012, 4.295453667640686, 0.5816994948046548, 2.2105096706322263, 60.455178124564036, 63.27361066000802, 62.86960070473807, 63.11649799346924, 72.76148005894252, 40.6927364894322, 41.62224217823574, 46.644288948604036, 38.26908322743007, 68.95844609396798, 53.1923268863133, 64.63637474605015, 4.253344110080174, 0.46273363275187357, 0.1355682976011719, 0.2985096478036472, 0.11183037422597408, 0.20307874573128565, 0.26660588117582457], [0.08097867614456586, 0.05291774170473218, 0.07738193842981543, 0.018416568470586623, 0.11963146419397422, 0.10989186074584723, 0.09171387366950512, 0.014259009688560451, 0.11622863821685314, 0.4095602902982916, 7.255579948425293, 50.54170029503958, 36.50573117392403, 37.70164816720145, 29.212036882128032, 44.280306816101074, 51.92256791251046, 10.774226750646319, 51.27418286459786, 47.80964776447841, 56.01750612258911, 49.10833208901541, 56.032851219177246, 13.688978689057485, 0.6685209817120007, 1.8025516186441695, 3.011297809226172, 3.729257558073316, 0.23162940942815372, 13.987736463546753, 65.75020572117397, 52.53888702392578, 54.20858430862427, 48.76899249213082, 48.03212560926165, 47.014951024736675, 45.958324568612234, 44.32066542761666, 41.59012760434832, 52.54018633706229, 56.01838159561157, 51.061206681387766, 50.78327873774937, 54.4176139150347, 50.712865693228586, 30.310422011784144, 40.93973800114223, 52.070133754185264, 50.7626564843314, 52.490989616939, 46.2038391658238, 46.77652359008789, 39.094376359667095, 48.551649366106304, 50.762368134089876, 52.97338220051357, 42.46722303118025, 44.4512985093253, 42.73716402053833, 42.632868085588726, 48.09571899686541, 45.96395260947091, 45.87140260423933, 46.878662109375, 47.44309554781233, 46.035519054957796, 46.45073645455496, 45.36704676491873, 46.92738287789481, 46.52752447128296, 42.28348139354161, 36.91048111234392, 36.57445580618722, 36.26120669501168, 35.92111669267927, 34.62092808314732, 34.71043130329677, 34.99604395457676, 33.71482045309884, 36.11672932761056, 38.02455527441842, 44.334304741450715, 49.42419024876186, 49.25934771129063, 37.31975432804653, 43.97989797592163, 48.717426436288015, 50.19349479675293, 46.43742023195539, 44.83775036675589, 49.01339190346854, 48.75999110085623, 46.679627486637656, 40.147118772779194, 46.383971214294434, 49.68958364214216, 55.392095293317524, 49.33105312074934, 39.927027634211946, 40.020953382764546, 38.25908129555838, 35.65765837260655, 35.621486050742014, 33.36673307418823, 32.62974807194301, 32.38734974179949, 38.143630027770996, 40.84356798444475, 38.445584842136924, 42.7248101234436, 45.59110879898071, 47.331316402980256, 45.314122336251394, 45.85908692223685, 45.66792460850307, 44.06906073434012, 44.564505508967805, 45.29332637786865, 44.19723415374756, 44.85728175299508, 40.94274309703282, 43.78184652328491, 42.867373262132915, 41.34075675691877, 47.84415251868111, 49.830847467694966, 50.002127511160715, 46.962179456438335, 45.47941303253174, 41.21651601791382, 46.872707503182546, 49.597009318215505, 45.835209437779014, 43.190228257860454, 40.29916272844587, 37.98290777206421, 38.05110781533377, 46.95486300332205, 49.08780363627842, 45.11041852406093, 45.51691246032715, 44.24347788946969, 49.77249649592808, 53.35318463189261, 52.62868206841605, 54.99307761873518, 29.926509720938547, 30.915009089878627, 58.56148828778948, 50.09873179027012, 58.1482059614999, 36.21532079151699, 0.9036917196852821, 0.34627297627074377, 0.8355124124458858, 0.3154428148908274, 11.222347344670977, 62.4286402293614, 43.738663469042095, 61.40621975490025, 49.85276556015015, 63.69070407322475, 25.21858058656965, 26.679069348743983, 45.806502955300466, 25.675443751471384, 29.95108549935477, 41.49085521697998, 29.869482381003245, 0.13711348468703882, 0.16442411206662655, 0.09803566908729927, 0.09598065114447049, 0.011239360918157866, 0.057378149325294156, 0.11114671626793486, 0.07522856005068336, 0.03805914115426796, 0.04213595935808761, 0.037784792482852936, 0.07522090617567301, 0.10317526651280266, 0.20719685618366512, 0.04315566856946264, 0.1569774616509676, 0.2917834658707891, 10.615697520119802, 66.55388995579311, 42.086722305842805, 35.96382032121931, 39.14718614305769, 47.98736531393868, 50.94288580758231, 15.516084807259695, 57.98573275974819, 58.57819175720215, 63.99283954075405, 55.45110634395054, 60.67021097455706, 15.141118322099958, 0.5216797068715096, 2.3964862397738864, 2.368667389665331, 5.412100834505899, 0.35766104661992615, 16.723704304013932, 66.93457480839321, 54.93299307141985, 58.42121805463518, 49.78199120930263, 52.58684696469988, 49.508746351514546, 49.54217413493565, 45.53557532174246, 43.45106363296509, 54.959389277866904, 56.09562471934727, 54.388421058654785, 55.04138844353812, 54.00418567657471, 52.03602852140154, 33.36380788258144, 42.68631362915039, 53.99685880116054, 52.18030786514282, 52.50334351403372, 48.57514469964163, 46.77225739615304, 41.54723637444632, 50.82154941558838, 53.08716590063912, 54.768490995679585, 44.24440547398159, 46.83041034426008, 44.17902987343924, 43.79342222213745, 50.36477484021868, 47.440451758248464, 48.87494557244437, 49.99505771909441, 49.90948370524815, 47.719328130994526, 49.67348119190761, 45.98262936728341, 51.114492416381836, 49.25757244655064, 45.652200835091726, 39.8425201688494, 40.81810631070818, 39.53565992627825, 40.46104185921805, 36.86333758490426, 36.77318123408726, 37.063549927302766, 36.028577532087056, 38.48231301988874, 42.07352072851998, 45.172778606414795, 50.520101819719585, 52.10006659371512, 41.0277612549918, 44.62655292238508, 51.660037176949636, 51.250135149274556, 49.302398749760215, 47.214916706085205, 49.50012016296387, 52.619437490190776, 48.839947496141704, 41.02285235268729, 47.82717112132481, 52.30810260772705, 59.03173542022705, 50.87181268419538, 42.60406085423061, 43.21449831553868, 39.48625476019723, 36.7816024507795, 38.45053195953369, 36.891564641680034, 35.23518705368042, 36.85588216781616, 40.890450954437256, 44.63228866032192, 42.394409384046284, 44.21762711661202, 47.15506492342268, 49.42126158305577, 47.42749684197562, 45.41025413785662, 47.40311908721924, 46.73158264160156, 46.56790740149361, 46.50858020782471, 47.36003678185599, 46.25316790172032, 41.1212284224374, 44.946753706250874, 44.34660652705601, 43.343495096479145, 48.64927155630929, 51.06065429959978, 52.1797068459647, 49.94937678745815, 45.69100652422224, 41.12027651923043, 48.05688898903983, 50.69395964486258, 47.597849300929475, 43.70908498764038, 41.09319591522217, 41.152061053684776, 39.96858133588518, 48.389923095703125, 52.2732469694955, 47.51769835608346, 48.17667940684727, 46.76908554349627, 52.975296429225374, 56.07711124420166, 55.26460974557059, 55.45013359614781, 35.87099586214338, 34.523090498788015, 60.000793729509624, 51.03431020464216, 58.873483249119346, 37.74559552328927, 0.9886280191796166, 0.32857075759342735, 1.6546280533075333, 0.620009527674743, 14.183699982506887, 68.28105231693813, 49.80739382335118, 67.07041903904506, 57.325337750571116, 74.5260237285069, 31.295384747641428, 33.871849741254536, 53.4087632724217, 32.2895781653268, 30.801412991115026, 51.576221057346885, 38.80520275660923, 0.4106412780072008, 0.15185354516974517, 0.007493240326376898, 0.0650332931961332, 0.10627891961485147, 0.0659963379481009, 0.01905784852403615, 0.1657018070774419, 0.20385231636464596, 0.17970362145985874, 0.08946710173040628, 0.18154763536793844, 0.1652471071907452, 0.34697387580360683, 0.09913407479013715, 0.2454441109938281, 0.5238671952060291, 14.5153375012534, 81.21344947814941, 52.44495780127389, 54.12144695009504, 44.395976952144075, 60.23609447479248, 62.93746376037598, 19.752844435828074, 64.44746712275914, 60.69645432063511, 65.77480929238456, 59.785781724112375, 66.283737046378, 18.575024025780813, 0.6649111754127911, 3.8191008056913103, 7.393090009689331, 7.765669788633074, 0.5431457321558679, 19.19265287263053, 67.32270812988281, 55.5411411012922, 59.126460211617605, 53.84689235687256, 52.91910287312099, 52.924345288957866, 51.98165539332798, 49.52305269241333, 46.19671031406948, 58.10094084058489, 59.87717832837786, 56.60976014818464, 54.89636216844831, 58.625015667506624, 51.60377761295864, 37.235156536102295, 45.809511525290354, 53.8334093775068, 53.129761832101, 54.43917417526245, 49.373325960976736, 48.312978744506836, 44.54121862139021, 53.19623524802071, 54.595623288835796, 56.94513232367379, 45.84069504056658, 49.47531509399414, 46.041768959590364, 47.06705209187099, 51.857359068734304, 52.0718742779323, 50.87993860244751, 54.92777497427804, 53.80237872259957, 51.95614160810198, 53.652377537318635, 48.785470145089285, 53.04617847715105, 52.846876348767964, 49.20123645237514, 44.209588050842285, 44.86533471516201, 43.58550780160086, 44.40608310699463, 38.776263509477886, 39.84540714536394, 41.42908225740705, 38.42022391727993, 41.56122309820992, 45.30771262305123, 49.7568804195949, 53.520389556884766, 54.39857585089547, 40.50909560067313, 47.66654961449759, 53.495400360652376, 54.96694196973528, 50.771887166159495, 48.51129770278931, 53.7588552066258, 52.03664691107613, 49.888951778411865, 42.12875543321882, 48.54009798594883, 52.837958335876465, 61.2581536429269, 54.068043095724924, 44.30801623208182, 46.24538591929844, 43.24356263024466, 40.58619281223842, 42.21453441892351, 41.582682609558105, 41.21864216668265, 41.98278420312064, 46.4823750768389, 49.27787855693272, 45.558181285858154, 48.4930864742824, 52.09254169464111, 53.85426092147827, 50.62020451681954, 49.00797230856759, 50.3161096572876, 51.34087862287249, 49.646661145346506, 49.58393280846732, 49.72000632967268, 49.08131054469517, 45.529113497052876, 47.7167329788208, 48.51075226919991, 45.68337740216936, 50.781739711761475, 55.27989925657, 54.50488676343645, 50.2522348676409, 47.27706139428275, 42.888040678841726, 50.90871804101126, 53.154219491141184, 49.942921910967144, 46.82373659951346, 43.1758211680821, 42.41578551701137, 40.84225477491106, 49.348003251211985, 54.08874177932739, 48.714535985674175, 50.043101038251606, 47.3254451751709, 54.78374923978533, 56.884116717747276, 56.311783177512034, 55.68648699351719, 40.68084117344448, 39.28726877485003, 58.03844179425921, 50.41030638558524, 58.68028163909912, 40.56653635842459, 1.8578679646764482, 0.7516392416187695, 2.2288618172918047, 0.8405096328684262, 13.434069258826119, 71.94587966373989, 54.37483385631016, 72.09705856868199, 59.65654523032052, 76.36336367470878, 35.941846643175396, 35.622121810913086, 63.446064949035645, 40.02632086617606, 44.67348105566842, 59.86112798963274, 53.628760610307964, 1.1912624601806914, 0.2804667502641678, 0.12443275084452969, 0.14306925795972347, 0.15995617610003265, 0.11325143011552946, 0.12709339521825314], [0.059651207711015425, 0.10084774212113448, 0.030389693765235797, 0.0974896994552442, 0.05577150732278824, 0.1113972585382206, 0.014421817380934954, 0.03058721191648926, 0.07176203320601157, 0.03799995932994144, 0.9322304683072227, 39.0305050441197, 48.15961463110787, 32.19379724775042, 26.884579692568096, 44.38679143360683, 84.38001455579484, 20.186465876443044, 44.94496801921299, 47.36176340920584, 38.285703318459646, 58.11690432684762, 45.651238509586875, 48.27070937837873, 1.289891162088939, 2.8291188648768832, 1.2945914013045174, 5.637758348669324, 0.17396198026835918, 6.978695971625192, 58.33594281332833, 53.944226196834016, 41.434331621442524, 51.11268588474819, 55.14359991891043, 52.40922669001988, 52.543340819222585, 53.74791874204363, 53.858183179582866, 57.89992945534842, 50.97536516189575, 52.07504265648978, 48.68133749280657, 56.15029661996024, 40.417639936719624, 49.64093235560826, 57.45235082081386, 54.431201117379324, 53.2953200340271, 55.31419209071568, 50.04966013772147, 48.6977595601763, 37.66086571557181, 44.3489967073713, 54.79481424604143, 50.74078355516706, 45.90555647441319, 42.97433383124215, 42.600718770708355, 39.933545044490266, 49.23597049713135, 45.28580495289394, 47.096397808619905, 46.643406527382986, 47.791665826525005, 45.95140068871634, 44.246802602495464, 44.6053261756897, 44.305348123822895, 47.229956081935335, 45.761172907693044, 39.13339049475533, 36.6758508682251, 35.98308767591204, 34.93733862468174, 35.417792660849436, 33.390624455043245, 35.11761311122349, 34.64859928403582, 37.92186784744263, 38.97718456813267, 48.58619928359985, 45.89910854612078, 51.32154526029314, 42.00464670998709, 40.823744773864746, 50.283477442605154, 47.71691710608346, 46.74799428667341, 44.948195457458496, 47.92205572128296, 47.256567682538716, 43.28231968198504, 40.04664087295532, 41.08945083618164, 47.945446831839426, 57.074539048331125, 49.99996314729963, 42.43127999986921, 38.69293376377651, 39.10877997534615, 37.39393677030291, 35.76301738194057, 37.14385025841849, 37.46961654935564, 38.08130816050938, 41.45034721919468, 41.100731236594065, 39.09101343154907, 44.60835906437465, 47.288595403943745, 46.83472864968436, 46.797493253435405, 44.04844542912075, 44.627737590244834, 44.22616992677961, 45.97550746372768, 42.339237213134766, 47.203948974609375, 42.661706583840505, 40.3680020059858, 43.95244216918945, 42.76949398858206, 42.388895988464355, 44.060045446668354, 47.91491992133004, 48.28557504926409, 47.453802721840994, 50.06754132679531, 49.57497658048357, 47.025772844042095, 50.54795714787075, 47.69910887309483, 45.5416966847011, 38.425716468266074, 36.98636238915579, 42.23840495518276, 52.30496549606323, 50.91673278808594, 53.25769206455776, 50.740029675619944, 46.072882992880686, 47.59338160923549, 50.85359798158918, 55.21185902186802, 52.71428040095738, 68.31301403045654, 51.163352148873464, 46.009348664964946, 54.654568331582205, 56.618980407714844, 22.3418960911887, 0.06374666866447244, 0.1462679806032351, 1.059960505792073, 1.053740239569119, 28.9701874596732, 45.6470695904323, 50.39314086096627, 59.22432558877127, 52.00522715704781, 46.229849747249055, 11.868493335587637, 20.91350105830601, 31.658337797437394, 20.70170259475708, 29.570098400115967, 43.299665859767366, 24.312776940209524, 0.28671890763299807, 0.025134535040706396, 0.1300053418214832, 0.01220724277663976, 0.01495819931317653, 0.02750450179779104, 0.01917122833297721, 0.022961553784885576, 0.024071292718872428, 0.022642494744754264, 0.08528997908745493, 0.01901857152448169, 0.09160489416015999, 0.16801026463508606, 0.04817700751924089, 0.03060283518529364, 0.025812773200284158, 1.7359054748501097, 52.68456642968314, 53.587825298309326, 36.78824840273176, 38.99199117933001, 51.70212936401367, 86.124450138637, 21.292692048209055, 48.517846379961284, 49.66049500874111, 46.86973367418562, 63.35708631787981, 49.83335229328701, 53.62480361121041, 1.20044179047857, 3.1998356580734253, 1.0508922381060464, 4.011043923241751, 0.1418130589382989, 7.866333552769252, 63.22027628762381, 53.82538768223354, 46.55171462467739, 56.95003080368042, 56.49292966297695, 54.157893725803916, 53.637775897979736, 55.19591638020107, 56.00989089693342, 57.1517265864781, 51.73281955718994, 52.29447371619088, 50.381870882851736, 57.70093304770333, 45.86495467594692, 51.134711674281526, 56.27733053479876, 56.37086371013096, 54.851619243621826, 55.89851474761963, 53.00730330603463, 48.58457687922886, 38.40588630948748, 48.52165399278913, 56.2185001373291, 52.91410711833409, 47.06588479450771, 45.108962876456125, 43.9072128704616, 39.95051949364798, 49.82035916192191, 49.75002602168492, 48.04644237245832, 49.52039500645229, 50.584313596997944, 48.77138614654541, 47.64992257526943, 46.63867480414254, 48.11822073800223, 49.127818311963765, 48.5358178956168, 41.4370379447937, 40.19431788580758, 38.99515955788748, 38.612956523895264, 36.93481717790876, 34.97869430269514, 36.321572644369944, 36.918825898851665, 38.17019299098423, 40.73010042735508, 50.9412772996085, 49.06937006541661, 52.503920214516775, 40.93895285470145, 41.52256679534912, 51.7962566103254, 50.142203194754465, 48.73252139772688, 46.22809532710484, 50.67637722832816, 48.50991153717041, 42.5532660484314, 39.336590562547954, 41.5105950491769, 48.19424792698452, 59.78495488848005, 53.01536321640015, 44.57734925406319, 41.41028043201992, 42.28458963121687, 39.646806785038535, 37.30654232842581, 38.934175218854634, 40.928763321467805, 41.511981214795796, 44.76913343157087, 43.479426179613384, 43.645786898476736, 46.40894998822893, 48.97079944610596, 51.15420484542847, 49.25232655661446, 46.78979812349592, 47.97061668123518, 48.24136018753052, 48.14656591415405, 45.01665605817522, 49.93389620099749, 44.238339696611675, 41.839439392089844, 45.728036948612754, 43.91264983585903, 44.849715164729524, 45.996751580919536, 50.32869979313442, 49.138973644801546, 49.356500898088726, 51.01003319876534, 49.580194677625386, 47.99280227933611, 51.50112492697579, 49.042581285749165, 46.874722480773926, 40.53934458323887, 38.74730689185006, 43.29964501517159, 54.02915055411202, 52.052780628204346, 53.692055225372314, 53.294364656720845, 48.560893944331575, 50.19271312441145, 52.93441322871617, 56.24305854524885, 55.41345752988543, 68.49498735155377, 56.06077602931431, 47.448032242911204, 54.93650538580758, 59.32094723837716, 23.531215769904, 0.23335777382765496, 0.39021832389490946, 1.1783506444522311, 2.2874918026583533, 34.68477160590035, 52.54550518308367, 55.90266282217843, 67.02437332698277, 63.05217851911272, 52.81762095860073, 15.784617049353463, 20.652036871228898, 39.80926956449236, 27.224964993340627, 33.97045510155814, 54.135117530822754, 31.252781867980957, 0.3252952790686062, 0.04476119098918779, 0.039008900190570524, 0.03223805029743484, 0.013870355007903916, 0.02851547147812588, 0.04626246668132288, 0.16616645428751195, 0.21297728243683064, 0.1729676550520318, 0.23374079327498162, 0.15649302835975373, 0.2646154665521213, 0.32602622413209503, 0.20524935211454118, 0.14456404346440518, 0.2654662680413042, 4.190783832754407, 67.54727390834263, 61.05417537689209, 49.17904043197632, 38.234415190560476, 61.25698634556362, 85.22460283551897, 31.074494566236222, 54.81988334655762, 60.83438301086426, 47.306077071598594, 69.82137761797223, 52.30503497804914, 59.76174095698765, 2.2101867965289523, 4.3503005760056634, 3.6247090995311737, 10.404867461749486, 0.16482473271233694, 9.574856502669197, 64.27508926391602, 52.74951819011143, 51.750068460192, 55.999062129429404, 59.41784681592669, 54.17338820866176, 56.815687383924214, 53.91758680343628, 58.125718116760254, 60.80342183794294, 55.716965266636436, 54.32883678163801, 51.6947295325143, 59.71717521122524, 52.57059860229492, 56.95487022399902, 55.02709599903652, 58.445161546979634, 57.24661118643624, 59.27932058061872, 52.016455445970806, 51.777704920087544, 37.998683656964985, 48.62831926345825, 58.654086930411204, 56.35548039845058, 50.44704498563494, 47.59146738052368, 47.51459945951189, 41.90034730093819, 52.11083630153111, 52.82949195589338, 50.69103792735508, 53.60878106525966, 54.49010099683489, 51.76825884410313, 50.866316659109934, 49.87353719983782, 51.20653172901699, 52.77641814095633, 51.88786513464791, 44.912898608616416, 44.46422215870449, 44.94836221422468, 42.518594537462505, 41.821613788604736, 39.33175809042794, 39.8914771761213, 40.766102518354145, 43.85105405535017, 45.3627666745867, 54.58521836144583, 50.995278699057444, 54.980272088732036, 43.76367698396955, 42.93477773666382, 54.636680194309776, 52.95213460922241, 53.28725317546299, 49.390998704092844, 53.420693329402376, 49.924582140786306, 43.319697516305105, 40.52263763972691, 41.005210876464844, 50.087878704071045, 61.43367903573172, 56.42456981113979, 48.37691259384155, 43.59105593817574, 45.41922773633684, 43.0986544745309, 40.05204309735979, 42.48123754773821, 43.754553999219624, 46.33633436475481, 47.81524453844343, 48.102576868874685, 44.942800181252615, 49.92105940410069, 53.28729139055525, 53.34890801565987, 51.85628209795271, 50.283143929072786, 52.31376886367798, 51.17658846718924, 51.327645778656006, 49.04534666878836, 53.22354514258248, 47.285670212336946, 44.728712286267964, 49.21609517506191, 47.02536637442452, 48.10680137361799, 48.76799195153372, 53.28538063594273, 51.66920532499041, 51.678960595812114, 53.004103660583496, 52.040645599365234, 49.75031784602574, 53.208123615809846, 50.154782908303396, 49.0282541002546, 41.16244166237967, 41.5732295853751, 44.967917919158936, 58.92744295937674, 54.41691214697701, 57.7800487109593, 54.792097500392366, 50.351118155888145, 50.540109157562256, 54.08764048985073, 56.073640619005474, 55.92049189976284, 63.920154435294016, 57.871542590005056, 54.30529628481184, 54.22325542994908, 58.71695423126221, 27.8591913495745, 0.323593513241836, 1.4396615368979317, 2.7466685005596707, 3.084317513874599, 35.814232553754536, 56.73521334784371, 59.41277463095528, 68.63592461177281, 63.83149542127337, 59.46701226915632, 19.61776624407087, 29.8917270387922, 46.41383804593767, 34.34483098983765, 45.851829528808594, 63.191392626081196, 45.01876483644758, 0.5413949489593506, 0.16731560762439454, 0.2552582515137536, 0.13320394232869148, 0.06281955234174218, 0.1580388532685382, 0.1215219713215317], [0.04585218369694693, 0.03979681505422507, 0.11302648897149734, 0.04256732103281787, 0.043936197579439194, 0.02996440837159753, 0.051700107221092494, 0.0016332761983254126, 0.05355149001947471, 0.09507695785058395, 0.4318827624831881, 36.84969479697091, 51.884033203125, 34.16515404837472, 26.636136429650442, 29.5201894896371, 45.041509764535085, 21.756373132978165, 39.09539427076067, 62.950137274605886, 39.583453110286165, 58.10371664592198, 45.26693364552089, 57.2814598764692, 28.36200816290719, 1.2597646415233612, 1.570818230509758, 6.024068202291216, 0.1609931540276323, 3.8349044833864485, 46.732708249773296, 45.44090959003994, 55.88651520865304, 58.28389733178275, 55.74837807246617, 53.939004625592915, 51.511529854365754, 50.098047392708914, 49.81991447721209, 48.78345169339861, 49.53402737208775, 48.18555573054722, 51.01777696609497, 53.762978962489534, 67.34532451629639, 67.50263173239571, 49.86743320737566, 56.22964852196829, 48.46670763833182, 56.6106390953064, 47.90444551195417, 50.13823229925973, 39.959194319588796, 48.24801308768136, 53.21520383017403, 49.35527106693813, 47.630787236349924, 44.23715155465262, 44.6224639075143, 39.18748916898455, 46.32785408837454, 48.41322387967791, 46.53088739940098, 46.644007546561106, 45.466590132032124, 47.11319855281285, 45.65263509750366, 46.12526198795864, 44.12589005061558, 47.09361505508423, 44.88249329158238, 40.46142748423985, 36.62365600040981, 34.907833099365234, 34.77801295689174, 34.157625675201416, 35.59102862221854, 36.380055631910054, 34.98893594741821, 38.571659905569895, 41.26055370058332, 44.0759985106332, 48.786310877118794, 50.80031224659511, 44.30559478487287, 42.159945896693635, 45.69390392303467, 49.222581318446565, 43.617865562438965, 45.52806084496634, 49.731519494737896, 46.283573218754356, 42.299017565590994, 39.27762467520577, 40.002703939165386, 46.055095604487825, 55.77946431296212, 50.91502700533186, 42.72371925626482, 39.35933549063546, 38.599622930799214, 36.32966382162911, 36.69733122416905, 36.57796812057495, 35.86101824896676, 38.18967226573399, 39.390470368521555, 38.42354168210711, 40.67010620662144, 47.26553780691964, 44.32808262961251, 46.92700072697231, 44.04446063722883, 45.09456620897566, 44.73369761875698, 46.7926538331168, 44.044780254364014, 42.398310797555105, 46.19714805058071, 41.765187467847554, 40.169002124241416, 44.652796268463135, 40.56715474809919, 42.16831847599575, 40.84090335028512, 44.73514631816319, 48.570558888571604, 49.82308632986886, 48.49002579280308, 51.08261408124651, 48.34460347039359, 51.506864139011924, 46.648166043417795, 43.504700251988, 39.11846229008266, 36.86850357055664, 42.7576334135873, 53.68911613736834, 52.44546849387032, 54.20874064309256, 51.367538860866, 53.459985392434255, 47.119681222098215, 49.31141056333269, 49.25521353312901, 57.732828753335134, 55.35725702558245, 68.60777745928083, 49.576772689819336, 52.35528435025896, 48.79072298322405, 10.40127784865243, 0.22228105605712958, 1.5789506626980645, 0.5375131315418652, 9.825616989816938, 53.17594650813511, 51.69678619929722, 54.57038048335484, 53.353542464120046, 32.03284222739083, 33.78957264763968, 18.851947954722814, 48.87001929964338, 31.89053964614868, 18.640099116734095, 28.373778411320277, 45.854685238429475, 14.393532974379402, 0.5176979548164776, 0.058616027901215215, 0.04419452943173902, 0.01168540439435414, 0.041034839515175135, 0.05018746606739504, 0.03951767931825348, 0.071058969146439, 0.02879316532718284, 0.06819524602698428, 0.0423660946876875, 0.062430690707904954, 0.03017937844353063, 0.10193712330822434, 0.009408288369221347, 0.030700252457920994, 0.08702911862305232, 0.860867474760328, 45.23457588468279, 60.83576570238386, 35.60655089787075, 35.93950162615095, 39.2263400214059, 50.88211338860648, 24.791453974587576, 43.13933965138027, 66.74761962890625, 38.686902727399556, 67.80844279697963, 47.61442770276751, 66.14304992130825, 30.816862310682023, 2.1897260887282233, 0.4118762660239424, 5.839471936225891, 0.27484234635319027, 3.0840862691402435, 54.351213455200195, 47.17899799346924, 59.188062940325054, 58.28749302455357, 56.98782900401524, 54.80312081745693, 55.69123608725411, 52.73082058770316, 51.408508913857595, 51.57215983527047, 52.171931811741416, 49.32267706734793, 52.864250319344656, 54.491219656808035, 67.0259644644601, 61.754616328648154, 52.89533308574131, 57.04092018944876, 51.82026958465576, 56.24365956442696, 50.19749695914132, 50.67653703689575, 43.70372097832816, 48.79840769086565, 55.19155291148594, 51.019830158778596, 48.999360016414094, 46.50190298897879, 47.677993297576904, 41.44912781034197, 48.56251287460327, 50.47959729603359, 48.57121549333845, 48.592786175864084, 48.51925686427525, 51.99410656520298, 49.18769441332136, 49.23502901622227, 47.06032970973423, 50.46852534157889, 49.00144795009068, 42.68935694013323, 40.08934450149536, 37.743260928562705, 38.88873052597046, 38.31253726141793, 38.29904385975429, 40.436066559382844, 37.404508454459055, 38.816740240369526, 43.775700841631206, 48.65476063319615, 49.688600472041536, 51.34505101612636, 44.92660740443638, 41.98138414110456, 45.90563290459769, 49.65967859540667, 43.47494806562151, 45.36188077926636, 51.85599374771118, 48.24617876325335, 40.0312888281686, 41.03967046737671, 39.295790740421836, 46.88309506007603, 57.512188707079204, 53.26213196345738, 45.29865217208862, 42.560544286455425, 39.819837774549214, 39.47059004647391, 38.190189906529014, 39.207336698259624, 39.41278798239571, 42.745025907244, 41.46272196088518, 40.354456492832725, 43.7092204775129, 50.41987405504499, 47.688342639378135, 47.53864370073591, 46.900670528411865, 49.01653943743025, 47.61327430180141, 50.10800763538906, 46.73657144818987, 46.25936222076416, 47.92209046227591, 44.149277687072754, 43.32983841214861, 47.96253592627389, 42.74398715155465, 43.04097400392805, 43.34182752881731, 46.139321667807444, 49.11334868839809, 52.7080374445234, 49.66856186730521, 53.89827081135341, 50.87647492544991, 52.60706622259957, 47.10048334939139, 46.804472718920024, 41.29788984571184, 37.37431158338274, 44.14371565410069, 55.98512404305594, 52.60540560313633, 54.8562467438834, 53.09848799024309, 55.25866208757673, 48.37295906884329, 52.71029560906546, 52.82231446674892, 59.88958086286272, 54.73085607801165, 67.03715801239014, 55.077744892665315, 50.413829122270855, 52.01830019269671, 13.060107656887599, 0.28489193852458683, 1.881536134651729, 0.6085219840918268, 13.495128290993826, 59.33313437870571, 52.985065596444265, 62.32735633850098, 58.01066984449114, 35.40250314985003, 34.17505523136684, 20.67649453026908, 47.8739846093314, 45.731149741581504, 23.902866227286204, 35.34471845626831, 56.79645824432373, 18.488320929663523, 0.4844195033822741, 0.049330344024513445, 0.02561057824641466, 0.045596647408923933, 0.059079134836792946, 0.05442781799605914, 0.0692444850823709, 0.18274685101849691, 0.1680284222321851, 0.14874444343149662, 0.10448077467403241, 0.23883659126503126, 0.1273025604231017, 0.1607234634991203, 0.06925225430833441, 0.16062508949211665, 0.16831308124320848, 1.0991531227316176, 59.5578738621303, 68.30621174403599, 46.07436990737915, 37.04518583842686, 44.879463876996724, 53.84550271715437, 30.800679956163677, 48.62366049630301, 74.18090670449394, 47.09800631659371, 70.99915981292725, 51.23642635345459, 68.20444147927421, 37.68064028876168, 2.6525660072054182, 4.395880324499948, 11.606263978140694, 0.22701743404780114, 4.652802561010633, 58.657317842756, 49.63449832371303, 55.19708367756435, 57.13772249221802, 61.07347052437918, 54.91554961885725, 56.38148055757795, 53.759928703308105, 54.15409653527396, 52.230817794799805, 54.65028476715088, 50.34889473233904, 54.693089144570486, 56.89130115509033, 70.65596049172538, 61.10578659602574, 56.97709403719221, 60.80604130881173, 52.80493007387434, 58.78128065381731, 52.907151971544536, 49.50427865982056, 44.611909593854634, 53.355494907924104, 57.29973711286272, 54.967991147722515, 50.828483717782156, 48.69236775806972, 49.889518056597026, 43.67660215922764, 51.41761800221035, 53.41118471963065, 53.232914788382395, 52.637923172542024, 51.66788169315883, 55.7201440674918, 51.784795556749614, 53.39805262429373, 50.61053957257952, 53.09224155970982, 52.53077152797154, 45.86952659061977, 44.26307528359549, 41.153561864580425, 41.97138915743147, 40.73522819791521, 42.122550691877095, 43.46447365624564, 40.21511731828962, 44.14552913393293, 47.22730534417288, 51.240546635219026, 53.449771540505544, 56.29517698287964, 47.83561665671212, 44.17595182146345, 49.70794078281948, 52.63367782320295, 44.46164437702724, 49.84728690556118, 55.075028147016255, 49.61764546803066, 42.227055072784424, 40.647823333740234, 41.27750383104597, 49.61210080555507, 59.02115331377302, 56.98904493876866, 47.4365051814488, 44.53666755131313, 43.54465586798531, 40.37293175288609, 40.55179922921317, 41.809676783425466, 41.29717765535627, 46.57969849450247, 46.32571404320853, 43.786376748766216, 45.8064022064209, 52.57506629398891, 49.33796657834734, 53.19806957244873, 49.83176810400826, 51.3747615133013, 49.735479967934744, 52.786308901650564, 48.89341735839844, 47.979541642325266, 51.99405792781285, 45.56927408490862, 46.82251371656145, 49.23993444442749, 46.27624634334019, 45.315668310437886, 46.354215553828645, 47.827476842062815, 52.09322261810303, 55.084210191454204, 52.44754947934832, 56.17347581045968, 52.17682681764875, 54.727798870631624, 50.77205739702497, 48.203026975904194, 43.59595789228167, 39.44956479753767, 46.326794488089426, 57.720189980098176, 55.12847369057791, 58.1827141898019, 55.686035360608784, 56.611125469207764, 50.00506312506539, 52.695798192705425, 54.62829024451119, 60.48654924120222, 59.41745771680559, 65.16971846989223, 59.02851840427944, 55.74168348312378, 52.14612967627389, 15.777752229145594, 0.15230593803737844, 4.61222551550184, 0.9514912004981722, 15.044415031160627, 62.386944089617046, 61.4420724596296, 62.41607788630894, 64.36397062029157, 42.50491006033761, 44.16159336907523, 27.00187397003174, 63.21364075796944, 48.788058349064414, 29.649106366293772, 45.15211813790457, 66.85359355381557, 26.973513160433086, 0.7491188368627003, 0.3803068000291075, 0.14276554568537644, 0.16276839162622178, 0.11979344407362597, 0.2036323081701994, 0.14024801791778632], [0.056595418469182084, 0.04881053191742726, 0.04983830212482384, 0.06039530956851585, 0.006696716125588864, 0.04462165026260274, 0.06505780188100678, 0.02442834632737296, 0.06197019613214901, 0.05688234039449266, 0.06980112807026931, 30.313229084014893, 56.249714919498985, 37.093322958265034, 27.70325119154794, 27.714899846485682, 45.03423152651106, 19.468871559415543, 44.50198214394705, 57.941608224596294, 55.31877442768642, 48.51830496106829, 53.6814592225211, 40.35732957295009, 48.00580930709839, 1.5938872269221713, 0.6093748754688671, 1.4140792467764445, 0.3681746210370745, 0.9681995553629739, 37.592620509011404, 47.54363598142351, 54.26832839420864, 50.356770515441895, 55.770584515162874, 53.23190382548741, 55.964446204049246, 52.366554328373496, 51.24369764328003, 47.75406564985003, 46.496896811894004, 44.84897518157959, 49.317483288901194, 52.08550316946847, 61.45063264029366, 49.192429610661094, 53.94993414197649, 50.59628881726946, 50.70503854751587, 51.23607199532645, 54.252083505902974, 49.797572544642854, 36.627449716840474, 51.5539208139692, 52.593496390751426, 51.35828038624355, 43.80071783065796, 45.233130659375874, 46.667947564806255, 40.543652466365266, 43.57921620777675, 50.27691486903599, 48.08966711589268, 45.747891426086426, 46.608950410570415, 45.46340090887887, 45.15846184321812, 47.563976832798545, 47.79223905290876, 49.2549147605896, 47.88540744781494, 40.93046563012259, 35.60530022212437, 34.524111883980886, 34.89603853225708, 33.56928695951189, 35.05879661015102, 33.54181030818394, 37.82002115249634, 42.81649855204991, 43.21775007247925, 44.9375820841108, 48.59773676736014, 49.33806037902832, 48.42272206715175, 45.334049769810264, 43.13513251713344, 49.011606216430664, 44.22428349086216, 42.7020651953561, 47.32946818215506, 44.82277699879238, 39.16687733786446, 39.09450142724173, 41.002820696149556, 47.54962532860892, 53.47401033129011, 49.85590614591326, 45.00701195853097, 38.717499119894846, 39.77740512575422, 35.95911291667393, 36.820957047598704, 37.72517129353115, 37.714887959616526, 37.76363999502999, 38.65106391906738, 38.05732297897339, 46.15327712467739, 47.474463190351216, 47.343715463365825, 46.79100363595145, 45.82754210063389, 44.15305750710623, 46.91252415520804, 44.00716618129185, 44.16455330167498, 43.59943546567644, 45.35276474271502, 40.151850496019634, 42.09729746409825, 40.600822244371685, 38.684912068503245, 44.56433875220162, 45.26302528381348, 46.29193537575858, 46.72291823795864, 48.288152830941335, 50.51118033272879, 49.70439372743879, 50.62710060392107, 48.90125840050833, 50.818328925541465, 48.51797144753592, 41.63761854171753, 36.62636579786028, 40.05282824380057, 50.59345742634365, 53.61782761982509, 55.500209263392854, 52.59903063092913, 51.27232422147478, 52.44701099395752, 50.681668281555176, 48.7150536264692, 53.37257358006069, 56.875525270189556, 60.25846767425537, 69.45098304748535, 41.91839872087751, 48.79594455446516, 6.385404058865138, 3.0400314331054688, 0.02195666717099292, 0.2682504600712231, 27.398491042000906, 55.01845938818795, 56.39612736020769, 53.945692266736714, 48.992919036320274, 39.09147548675537, 55.980652877262656, 26.808253731046403, 35.286537715366904, 21.139142070497783, 16.867921113967896, 30.29702241080148, 48.664130278996055, 6.955014339515141, 0.4516152393605028, 0.06564744202686207, 0.04620207027931299, 0.08021257618176085, 0.017133769180093492, 0.06042903954429286, 0.014494569905634438, 0.048793083389422724, 0.036795685200818946, 0.03591778641566634, 0.12364833722157137, 0.052992282169205804, 0.04656773619353771, 0.034161127105887444, 0.033486215464238606, 0.06078413727560213, 0.03903033850448472, 0.0977230408628072, 35.681796414511545, 65.58098234449113, 39.0829986844744, 30.565702302115305, 35.845968450818745, 46.4344915662493, 22.748165948050364, 48.228485175541465, 64.15776198250907, 56.02214404514858, 52.76474864142281, 58.919883319309776, 46.79407821382795, 56.376578603472026, 3.339494449751718, 0.5441119117396218, 2.0324712012495314, 1.128133407660893, 1.0937543724264418, 41.1638035093035, 51.75233704703194, 54.70736421857561, 53.76046371459961, 58.71244485037667, 56.708754607609336, 56.652588844299316, 53.04738746370588, 51.235960824149, 50.77716432298933, 47.757279191698345, 47.70018931797573, 50.16535806655884, 53.62053394317627, 57.75494834354946, 51.75906637736729, 56.693972315107075, 53.156526293073384, 52.98417970112392, 54.400948660714285, 55.387342725481304, 49.60580226353237, 40.471252237047466, 53.23007297515869, 54.44317633765084, 52.40224722453526, 47.95409386498587, 47.48608405249459, 50.276807171957834, 42.82281446456909, 46.37472316196987, 51.30137463978359, 49.04294259207589, 47.84271076747349, 48.23028128487723, 48.98206942422049, 49.069043500082834, 50.45827674865723, 48.17505700247628, 50.42639493942261, 50.94436577388218, 44.173314980098176, 39.34335115977696, 38.74258211680821, 37.290276595524375, 36.23590135574341, 37.564435141427175, 37.88357979910714, 38.92692129952567, 44.51119545527867, 45.76778064455305, 46.37447302682059, 51.49891887392317, 52.16507393973214, 48.72066082273211, 45.30386332103184, 45.53580461229597, 49.6641879762922, 44.941959449223106, 43.43135159356253, 49.20713894707816, 44.865546635219026, 39.47994579587664, 38.38381535666329, 40.34609086172921, 48.51063762392317, 55.48255736487252, 53.673663343702046, 47.64043828419277, 40.40150274549212, 41.64126982007708, 38.70269250869751, 39.076731409345356, 40.30004167556763, 39.26665694372994, 39.9575753893171, 39.98219633102417, 40.86713974816458, 47.78827510561262, 50.96721839904785, 50.36845391137259, 48.26182263238089, 49.535892963409424, 48.505020005362375, 49.34239258084978, 47.661143915993826, 46.9878009387425, 46.00657633372715, 47.585450240543906, 39.38273354939052, 45.63275630133492, 43.94663347516741, 40.64779554094587, 45.5483078956604, 49.097419943128315, 47.56874329703194, 49.07587010519845, 49.97658940723964, 52.16977439607893, 50.64745882579258, 50.762010301862446, 51.11046246119908, 52.44721596581595, 49.915431363242014, 43.89401824133736, 37.29432739530291, 42.36043964113508, 52.0564284324646, 54.057863984789165, 54.75017554419381, 54.93104062761579, 51.632192271096365, 54.063849857875276, 51.909661633627756, 51.91290296827044, 53.371840545109336, 60.4492860521589, 56.96398278645107, 69.97475910186768, 47.483259609767366, 50.632172788892476, 7.152854740619659, 7.286168524197169, 0.6355784322534288, 0.5189804945673261, 37.312660217285156, 55.50273840767996, 62.597085407802034, 58.25522559029715, 53.362450054713655, 41.45874759129116, 58.58529281616211, 29.96316146850586, 41.88954980032784, 30.598192078726633, 21.295214244297572, 34.65539114815848, 60.032567841666086, 8.7181453534535, 0.3510882950254849, 0.11590443418494292, 0.03852090459050877, 0.013110645148637039, 0.022141973388248255, 0.057388320565223694, 0.023339563947437064, 0.214712527181421, 0.1954258613820587, 0.11816623567470483, 0.16680221445858479, 0.09371851717254945, 0.17025233432650566, 0.1717603105519499, 0.13288789428770542, 0.1413678042590618, 0.22247728838452271, 0.3008098272340638, 46.0547308240618, 76.29231834411621, 52.34773860658918, 40.18486833572388, 40.36432293483189, 58.06285776410784, 27.764133044651576, 55.587676661355154, 69.69953400748116, 63.49781513214111, 59.45424842834473, 64.1141550881522, 49.98839439664568, 60.040044103349956, 6.0333084378923685, 1.2042384381805147, 3.381315657070705, 1.2637288059507097, 1.1930799569402422, 48.495174407958984, 52.424453667231965, 55.76097515651158, 55.83399377550398, 59.99018383026123, 59.27853543417794, 60.606975419180735, 55.696103300367085, 54.61103786740984, 52.73594488416399, 51.117476667676655, 49.50492136819022, 52.46364845548357, 54.76961660385132, 58.64157322474888, 54.316646167210166, 57.531080859048025, 53.16364472252982, 55.168839250292095, 56.933653899601524, 57.02814940043858, 52.33313001905169, 44.71364859172276, 54.198849882398335, 56.76958608627319, 55.76552970068795, 50.5099470274789, 49.272934913635254, 52.01491641998291, 45.24011359895979, 48.930802140917095, 53.87242351259504, 52.95801625932966, 51.50354290008545, 52.205085141318186, 51.30887174606323, 51.37980243137905, 52.21572630746024, 53.01779856000628, 55.13089861188616, 54.6741691998073, 47.31792722429548, 43.50197308404105, 41.3823174067906, 41.23419223512922, 40.67416742869786, 40.34682389668056, 40.162922450474326, 44.507676192692344, 48.0881141935076, 48.92109203338623, 49.10432645252773, 55.51210110528128, 56.0683148247855, 51.12060335704258, 48.560004574911936, 47.866921765463694, 54.0073436328343, 47.282745020730154, 44.554309027535574, 51.50262573787144, 46.528566701071604, 39.80988795416695, 38.88643067223685, 41.91875307900565, 49.91522291728428, 58.10219499043056, 56.09678159441267, 52.53143508093697, 43.612720421382356, 43.30855260576521, 42.73867872783116, 41.7965863772801, 42.556326729910715, 43.6524988583156, 42.56775304249355, 45.039665017809185, 44.42666367122105, 52.473170961652485, 52.91043152127947, 53.21157339641026, 50.18923207691738, 53.24254846572876, 50.050222941807334, 53.16282483509609, 51.60258947099958, 51.87495885576521, 48.04198162896292, 51.380518095833914, 43.06248562676566, 49.11643716267177, 45.4965056010655, 43.12684679031372, 46.64987530027117, 50.80776071548462, 49.170726912362234, 52.19126170022147, 52.247590746198384, 54.32500485011509, 51.627741949898855, 54.391669341496055, 54.291771616254536, 55.76082577024187, 52.80468341282436, 45.28421034131731, 37.87536702837263, 44.2435473714556, 54.89965214048113, 58.10720464161464, 55.100142410823274, 55.65092263902937, 53.2432085445949, 56.177359853472026, 52.64707395008632, 53.114302090236116, 53.96826001576015, 61.28491810389927, 58.6927467073713, 66.98644311087472, 49.68339627129691, 53.101809229169575, 8.695053015436445, 8.03334219115121, 1.8262551810060228, 0.5630435273051262, 39.832330635615754, 61.10770429883684, 67.90782982962472, 63.02223178318569, 60.292694500514436, 44.43129117148263, 68.72843292781285, 34.288310868399485, 51.62912116731916, 32.091252258845735, 32.45924622671944, 46.9003370148795, 69.82687364305768, 15.29927669252668, 0.6694421065705163, 0.21927999066455023, 0.16439258732966014, 0.1499138306826353, 0.249609718897513, 0.1761964639382703, 0.19837938861123153], [0.022685049068448798, 0.07382901372121912, 0.05332511716655322, 0.02533322196852948, 0.04245501330920628, 0.037558277137577534, 0.04348428307899407, 0.06402000971138477, 0.048888868785330226, 0.01668576304135578, 0.14948821280683788, 15.90674901008606, 60.516120774405344, 36.459376267024446, 38.04025820323399, 26.980047941207886, 49.88631493704659, 22.152689695358276, 46.41001306261335, 58.878715242658345, 54.03486892155239, 53.317672388894216, 56.04889808382307, 49.93946518216814, 57.127439158303396, 14.704927785055977, 0.365659373147147, 4.626749421869006, 2.067466671977724, 0.13598238038165228, 30.825954028538295, 50.41588578905378, 47.04130901609148, 58.11030353818621, 53.41497148786272, 51.36805302756173, 48.13797099249703, 47.58024603979928, 43.767005171094624, 46.29169218880789, 44.39554268973214, 45.68559387751988, 45.75415175301688, 49.82844686508179, 49.463218280247276, 52.93207515989031, 48.92783178601946, 49.6239127431597, 50.57454442977905, 49.38784769603184, 49.07808658054897, 42.48890141078404, 42.249463013240266, 53.51549455097744, 51.0309715952192, 52.1134557723999, 47.67640910829817, 42.02727699279785, 45.13424737112862, 40.893793037959504, 38.85576479775565, 48.25194576808384, 46.47443675994873, 46.951906544821604, 45.54132495607649, 46.3071345601763, 46.725152083805625, 46.33935335704258, 47.27179118565151, 46.4623191016061, 44.98799821308681, 42.64196675164359, 37.73376621518816, 35.04801300593785, 36.508399282182964, 36.04276922770909, 36.81962994166783, 37.119656630924766, 42.0398462840489, 44.473359039851594, 45.359674726213726, 43.01331669943673, 45.68194259916033, 48.014320850372314, 50.71107653209141, 46.23959806987217, 48.20785249982561, 48.73556818280901, 44.986000605991904, 40.25151545660836, 49.94719852719988, 44.86308349881853, 38.864682810647146, 39.4526115826198, 43.93592630113874, 50.098905495234895, 50.71726737703596, 50.59413487570626, 46.59513391767229, 42.56526211329869, 36.962269510541645, 36.74691704341343, 37.174127033778596, 36.508169991629465, 38.06414958408901, 35.34416260038103, 36.66638394764492, 39.41786364146641, 46.14251783915928, 47.943157400403706, 47.31499508449009, 45.53506462914603, 46.50938272476196, 46.36145557676043, 44.735778604234966, 45.489383697509766, 44.96996763774327, 45.547703402382986, 44.502551896231516, 38.776246138981406, 42.27354199545724, 40.71143756593977, 44.15284211294991, 46.372079372406006, 46.602012634277344, 48.999068192073274, 51.37577247619629, 48.61403029305594, 48.88732378823416, 48.20089735303606, 46.469972542354036, 48.60324668884277, 47.226019927433555, 46.6304863521031, 47.32301677976336, 42.25719288417271, 36.99622883115496, 45.873174394880024, 52.77454560143607, 50.881057262420654, 53.25405468259539, 55.31449433735439, 54.212704590388704, 55.45923226220267, 54.056946822575156, 51.5135726247515, 55.05059133257185, 53.94096054349627, 64.88808713640485, 61.44517135620117, 40.615555899483816, 7.029856860637665, 9.975193466459002, 0.7948392863784517, 0.6617464338030133, 36.90785469327654, 62.38314342498779, 50.94724580219814, 51.692509583064485, 58.69512299128941, 55.700407709394185, 54.52059316635132, 31.765788214547293, 37.30562169211251, 24.10960292816162, 25.11510280200413, 32.113927704947336, 42.399193218776155, 0.9871592351368496, 0.23624909296631813, 0.0499331070376294, 0.05205754250554102, 0.04718481290287205, 0.042648297401943376, 0.017683828681973473, 0.02766744010815663, 0.005460757379686194, 0.047757808584719896, 0.04329799468229924, 0.012389433669990726, 0.012083321078015226, 0.10253407127623047, 0.047729869905327044, 0.03460488561540842, 0.05435966254611101, 0.06012064537831715, 0.18781968738351548, 21.105009044919694, 71.35692255837577, 39.20093393325806, 41.06234243937901, 36.703820841653005, 55.5933290209089, 25.190660987581524, 55.598404679979595, 64.29847690037319, 60.67214952196394, 56.61825084686279, 60.969900676182334, 51.776711327689036, 62.683791978018625, 15.850816011428833, 0.4157320005553109, 2.0753187877791266, 2.8971404262951443, 0.3685684156204973, 33.5006422315325, 54.05926752090454, 47.90654386792864, 61.15734222957066, 55.12223768234253, 55.360435826437815, 48.638817991529194, 49.9068329674857, 45.1953706741333, 50.35601316179548, 46.958903380802695, 47.36531741278512, 47.361954484667095, 51.22632714680263, 52.05652570724487, 54.032301562173025, 49.86502913066319, 53.11735234941755, 52.51156670706612, 51.415933064052034, 51.6138733455113, 46.66595343181065, 42.55436733790806, 55.174043451036724, 52.79856204986572, 54.75983701433454, 49.70303535461426, 45.11122104099819, 46.387806619916645, 42.38129465920584, 40.43640354701451, 51.887132099696565, 48.90297113146101, 49.55114425931658, 47.545088154929026, 50.31114169529506, 49.83296319416591, 50.2201863016401, 48.881605420793804, 50.75304365158081, 49.642141342163086, 45.55738919121878, 39.47293506349836, 35.98305640901838, 38.35435152053833, 37.42541905811855, 38.768933159964426, 41.06313453401838, 43.37274701254708, 46.453164849962505, 47.60566602434431, 46.37470579147339, 47.495436327798025, 51.31602144241333, 50.656328201293945, 49.77142994744437, 48.5236029624939, 52.99119390760149, 47.077422278267996, 41.55480991091047, 52.115679195949006, 45.53564827782767, 41.85688631875174, 39.3320985521589, 42.199442931583945, 50.34213413511004, 53.13884660175869, 54.32032871246338, 49.556921686444966, 45.467295374189106, 41.04593774250576, 38.97230345862252, 39.14949989318848, 39.580917017800466, 39.70937531335013, 37.38453933170864, 38.748616627284456, 42.92121137891497, 46.07756607873099, 48.320326464516775, 49.11256006785801, 47.977147987910676, 49.52062429700579, 49.39964573723929, 48.57764605113438, 46.610690934317454, 46.41435916083199, 49.99524532045637, 46.48512656348092, 40.38666486740112, 44.84498691558838, 43.93934481484549, 47.38589102881295, 48.511165687016074, 49.834686347416465, 48.99485758372715, 52.200367314474924, 50.81806836809431, 51.05234772818429, 50.99439280373709, 46.72888674054827, 50.71251828329903, 50.67443173272269, 50.330676555633545, 49.77775975636074, 45.55295624051775, 38.84139939716884, 48.7016852923802, 55.232853003910606, 54.62892253058297, 54.42551749093192, 57.05883264541626, 55.81082500730242, 57.0230598449707, 56.6286175591605, 54.27906336103167, 56.33537925992693, 57.281678744724815, 61.670042855399, 64.05296925136021, 43.752375738961355, 13.658597690718514, 13.419252225330897, 0.7468469387718609, 3.3926336211817603, 44.36155210222517, 66.27252960205078, 60.398341860089985, 55.01634018761771, 63.69253839765276, 58.939838545663015, 62.60101808820452, 37.53402635029384, 42.396545955113, 33.121982778821675, 26.680097682135447, 38.16055931363787, 51.046858651297434, 1.5165038364274162, 0.2083459145256451, 0.03777771196993334, 0.0631976727662342, 0.039153641888073513, 0.04584287080381598, 0.012324164538378162, 0.0268989958068622, 0.10993793327361345, 0.22004286758601665, 0.0871895853696125, 0.09617952297308616, 0.15743875689804554, 0.2719029055110046, 0.18507419899106026, 0.08860397804528475, 0.19019217150551931, 0.1533992343715259, 0.2792991543454783, 27.49686016355242, 82.2807205745152, 48.33167634691511, 50.76738125937325, 41.89824547086443, 65.244599206107, 29.837868077414377, 59.93379919869559, 70.59881155831474, 66.56069919041225, 61.77637113843645, 66.03100327083042, 56.85680334908621, 67.33735493251255, 18.535002401896886, 0.34782926418951576, 8.570448364530291, 6.09964028426579, 0.6022965067199298, 40.25911678586687, 53.76757866995675, 51.602315017155235, 62.2978195462908, 56.95282745361328, 57.155763489859446, 52.46527780805315, 52.753450870513916, 47.90197542735508, 51.658730915614534, 48.49008137839181, 49.856726033346995, 50.84031997408186, 52.724285806928364, 53.17218058449881, 56.22593123572213, 53.44908019474575, 54.67976597377232, 52.72761399405343, 54.472518580300466, 54.589345591408865, 50.34220361709595, 44.63220875603812, 57.05167600086757, 54.22824771063668, 57.27988263538906, 52.81766264779227, 46.66980273383004, 48.40400014604841, 45.38218341554914, 41.92120579310826, 54.72923714773995, 53.09555237633841, 54.280974115644185, 50.115053108760286, 52.426093442099436, 52.58235842841012, 52.54631812231881, 52.662155015128, 53.75106627600533, 53.319986139025005, 48.88623986925398, 44.49588509968349, 41.34013489314488, 42.18676246915545, 41.90601008278983, 42.75634799684797, 45.81941270828247, 46.76693160193307, 49.75062704086304, 49.29948745455061, 48.48429005486624, 50.46079199654715, 53.78173909868513, 55.29700919560024, 52.55495820726667, 51.29206057957241, 54.03881549835205, 49.14058215277535, 42.852545806339805, 53.81367996760777, 47.14094965798514, 42.26056970868792, 39.1458694594247, 44.352432591574534, 53.13485138756888, 56.25656931740897, 56.24023757662092, 53.12992858886719, 50.193411418369834, 42.86016798019409, 38.26478576660156, 41.65876538412911, 43.53534180777413, 41.664608819144114, 39.762740952628, 39.63435908726284, 45.37135117394583, 51.58716447012765, 51.89772810254778, 52.318695136478965, 51.0612553187779, 53.51863513674055, 53.30766698292324, 52.28630263464791, 49.477986676352366, 50.678854261125835, 53.58525446483067, 49.0028132711138, 43.95236226490566, 47.81807245526995, 46.17787027359009, 50.6399895123073, 51.13298852103097, 51.47540269579206, 52.669857093266074, 53.320406505039756, 51.615547861371724, 53.88478435788836, 52.178490911211284, 50.13610962459019, 52.27005427224295, 53.11266578946795, 52.88683543886457, 52.500661509377615, 46.51538944244385, 40.82137196404593, 49.93555334636143, 58.28168085643223, 55.89572851998465, 55.70412152154105, 59.64627579280308, 58.03272690091814, 59.24018832615444, 57.88974339621407, 54.8464150428772, 58.517012868608745, 60.391532625470845, 60.42809404645647, 56.46239927836827, 46.797288281576975, 13.476623501096453, 16.755620854241506, 1.5664340257644653, 2.613982226167406, 47.6251939364842, 70.71930721827916, 61.29544462476458, 60.850648743765696, 68.09218638283866, 65.8956801550729, 67.56694425855363, 42.82489892414638, 51.75554364068167, 38.55384472438267, 41.31155695234026, 46.489771434238975, 65.24446719033378, 3.491810687950679, 0.35801931310977253, 0.22133800094681128, 0.17784796389085905, 0.11167319837425436, 0.12740804547710077, 0.07919477365378823, 0.09863366878458432], [0.026058038164462363, 0.07224513656858887, 0.08357530752463, 0.03817013930529356, 0.033204949128308466, 0.056114014836826494, 0.07440422821257796, 0.06253763461219412, 0.038247393909841776, 0.012856342098010438, 0.18887601712984697, 5.386569244521005, 56.14837891714913, 38.2487701688494, 34.3664676802499, 21.092656884874614, 46.79736818586077, 20.059878383363994, 31.414216314043315, 60.201686995370046, 53.22990621839251, 50.50390209470476, 51.59625966208321, 51.51114770344326, 55.63900300434658, 29.41524042401995, 0.9850000824247087, 0.5216456715549741, 0.5956317186355591, 0.21209338200943811, 27.183607578277588, 51.83455508095877, 45.85132925851004, 59.35728631700788, 51.56421457018171, 54.76644127709525, 51.21846873419625, 52.26292542048863, 48.20992306300572, 51.35144683292934, 45.85616520472935, 46.72896664483206, 42.47561992917742, 45.90283625466483, 44.87003864560808, 47.576153550829204, 45.040411949157715, 52.40701368876866, 50.53239665712629, 52.4771522794451, 48.909314836774556, 40.4924372945513, 44.290135043007986, 51.835750171116416, 53.47553893498012, 53.117484365190776, 50.507129532950266, 47.592978613717214, 44.03144318716866, 44.319633620125906, 38.15707131794521, 42.976046562194824, 48.302817004067556, 45.24946240016392, 46.303698675973074, 46.23660339627947, 46.16129534585135, 47.723073210035054, 46.79651703153338, 44.889566557747976, 43.808954920087544, 42.195628370557515, 37.16684532165527, 34.90503992353167, 35.07362754004342, 35.54390941347395, 40.115407194410054, 40.83416359765189, 44.72900063650948, 45.03244236537388, 45.288594654628206, 46.248988560267854, 46.32912908281599, 49.46093232291085, 49.11459936414446, 49.29269559042794, 48.43211603164673, 46.83730295726231, 42.69586740221296, 44.202014514378135, 48.88034432274954, 46.22188711166382, 43.30180590493338, 42.180467401232036, 46.718926497868125, 51.67041431154524, 50.46527705873762, 50.37610387802124, 46.75734656197684, 43.74163382393973, 42.1286928994315, 36.95965003967285, 36.83525991439819, 35.46244873319353, 35.77136564254761, 36.94052859715053, 39.02095821925572, 40.11977413722447, 45.02450404848371, 48.39752095086234, 47.781288691929404, 47.48814071927752, 46.052222524370464, 45.277738094329834, 44.235629899161204, 45.31297935758318, 43.70133427211216, 45.10698611395699, 39.18596403939383, 41.33545528139387, 40.814712115696494, 42.4095390864781, 46.3141313961574, 49.50413274765015, 48.73651661191668, 57.90651287351336, 54.93128381456648, 50.7246915272304, 51.5672196660723, 45.04002979823521, 45.02937126159668, 43.81023686272757, 51.085831097194124, 52.62876544679914, 51.702723434993196, 48.19918809618269, 41.372565610068186, 38.04673045022147, 47.8923521723066, 52.26345348358154, 53.39680194854736, 53.00995751789638, 55.81478895459856, 56.426126207624165, 56.80707161767142, 54.23348665237427, 56.68292815344674, 59.45327568054199, 55.39803600311279, 63.96364321027483, 26.812464339392527, 18.974583659853252, 8.262762154851641, 0.35841476331864086, 11.535733682768685, 47.707561356680735, 45.39826154708862, 44.47395658493042, 53.33602605547224, 52.36247226170131, 52.82934604372297, 54.9883702141898, 32.15677377155849, 33.83085536956787, 21.67248579433986, 22.79168598992484, 34.418495791299, 29.925689833504812, 0.0854819230735302, 0.09340250305831432, 0.05243398355586188, 0.059263309596904686, 0.08404446020722389, 0.047455283746655495, 0.011299212795815297, 0.038046937701957564, 0.057194829519305906, 0.08318964179073061, 0.04348035775391119, 0.04042368980922869, 0.01755987560110433, 0.04236170795879193, 0.030267862802637473, 0.056931747921875546, 0.018402097014976398, 0.03511646030736821, 0.16626509970852307, 7.127209808145251, 67.36439732142857, 38.889112676892964, 37.32666083744594, 34.20944881439209, 51.86995267868042, 24.451183319091797, 35.30363375799996, 67.40234838213239, 58.27863754544939, 56.88116373334612, 57.3667768069676, 55.683426312037874, 59.72813252040318, 33.83264453070504, 1.6163623694862639, 1.9437911255019051, 2.3846975352082933, 0.2845054992607662, 29.70244073867798, 54.47182376044137, 47.53091035570417, 62.14895439147949, 52.70767266409737, 58.10578373500279, 52.659705775124685, 54.837931292397634, 50.60169104167393, 52.62551021575928, 46.96558059964861, 48.912073271615164, 45.58225679397583, 48.094343253544395, 45.9267589024135, 50.640600953783306, 47.51509625571114, 52.94106265476772, 52.92530761446272, 55.579866886138916, 50.779415539332796, 42.795626163482666, 45.19164643968855, 53.78759295599801, 54.74783400126866, 53.969496795109336, 51.82298633030483, 50.02862794058663, 46.73704392569405, 44.548597608293804, 39.538974217006135, 46.638303075517925, 49.41464342389788, 48.2792626108442, 48.46007210867745, 50.08890356336321, 47.62916830607823, 50.6695054599217, 48.85566432135445, 46.86788197926113, 45.61407954352242, 43.51560892377581, 39.92811155319214, 38.52978311266218, 36.321339879717144, 37.63733564104353, 41.232736587524414, 44.34056159428188, 47.02329233714512, 47.43282263619559, 46.93719026020595, 50.03861945016043, 49.7697172164917, 51.59016261781965, 51.768793855394634, 51.76332909720284, 50.31005777631487, 50.34011568341936, 46.39781549998692, 45.18700851712908, 51.82361166817801, 48.27656323569161, 45.173737457820344, 43.473176274980815, 48.151196888514924, 51.60109213420323, 53.731837136404856, 53.610608441489084, 51.484185218811035, 48.37768036978585, 45.0037636756897, 38.41460977281843, 39.73585489818028, 37.30809872491019, 39.297513893672395, 39.674095835004536, 38.370426177978516, 40.53209413800921, 48.170561517987935, 50.863693714141846, 49.53109175818307, 47.708280495234895, 47.40575245448521, 48.63368674686977, 46.80118274688721, 48.05149023873465, 45.0766224861145, 48.271042891911094, 39.86636291231428, 40.850061076028005, 43.05080223083496, 43.44462612697056, 49.587608405521934, 51.37281601769583, 50.63333313805716, 55.462633405412944, 56.48232323782784, 51.24408674240112, 52.892932483128135, 46.91833284923008, 44.6142372403826, 44.72984831673758, 51.30367796761649, 54.11704874038696, 53.275524616241455, 50.56108924320766, 41.99869557789394, 39.41327783039638, 48.54241868427822, 55.651829378945486, 54.00179897035871, 54.36031559535435, 56.32268142700195, 58.43881089346749, 57.417331899915425, 57.86581032616751, 57.28379447119576, 63.394029889787944, 54.0768985748291, 65.0841236114502, 28.62233110836574, 22.159401655197144, 7.451398423739842, 0.27018043079546517, 20.957722868238175, 48.69247892924717, 53.522203036717, 48.29857860292707, 60.25082465580532, 55.21718829018729, 59.61454336983817, 60.94983427865164, 35.61940506526402, 41.14946937561035, 36.08132825578962, 26.697793006896973, 40.70522935049874, 37.043844836098806, 0.5449518838099071, 0.00877921176808221, 0.1122981630531805, 0.0205905743142856, 0.031761023215949535, 0.017503328188987713, 0.08273587828235966, 0.05402186745777726, 0.10948867523776633, 0.24377524054476193, 0.13084969722798892, 0.20255763083696365, 0.03802794889946069, 0.1501714704292161, 0.132635072139757, 0.15004497793103966, 0.15352666324802808, 0.20596781213368687, 0.3119945813502584, 10.797557064465114, 77.95335469927106, 51.43842090879168, 49.26487500326974, 31.792643002101354, 62.66338511875698, 28.31465792655945, 41.61172260556902, 72.61104461124965, 64.70570387159074, 59.42280088152204, 62.43750613076346, 59.21309035164969, 64.3913187299456, 37.15607213973999, 2.4168774655887058, 3.4583030002457753, 3.06262697492327, 0.3421093768307141, 34.02293831961495, 54.15261656897408, 49.648022992270334, 63.76288196018764, 56.031468527657644, 59.94290828704834, 56.418913977486746, 56.47488866533552, 52.180703912462505, 56.50511680330549, 49.33748367854527, 52.15201827457973, 48.152388504573274, 50.34473276138306, 47.61647047315325, 53.9766777583531, 48.889436040605815, 57.22299773352486, 55.62054858888899, 57.3068242754255, 53.1763390813555, 43.98769038064139, 47.19366564069475, 56.134173325129915, 57.612159388405935, 57.37319694246565, 56.66782971790859, 54.14520631517683, 48.94161006382534, 48.32594755717686, 41.54879624502999, 48.22155087334769, 51.855962480817524, 51.81957129069737, 51.3301089150565, 51.32313639777047, 51.34035750797817, 54.573052065713064, 51.69166885103498, 51.132199900490896, 48.081370966775076, 45.906421525137766, 42.225074836185996, 41.965865339551655, 40.86339119502476, 42.25273214067732, 46.32817717960903, 49.3194774218968, 52.016042028154644, 49.205895219530376, 50.10816049575806, 54.53793934413365, 52.30646630695888, 54.34969874790737, 53.243212018694194, 55.20804098674229, 51.50728450502668, 52.78342192513602, 46.02719163894653, 47.20001629420689, 54.133925914764404, 49.86035646711077, 48.599584988185335, 45.59095941271101, 49.7414345741272, 54.62089736121041, 55.557208810533794, 57.578450202941895, 53.107492855616975, 50.30006626674107, 48.647187096732004, 41.30765206473214, 39.96739319392613, 39.55515309742519, 40.26295566558838, 41.27659361703055, 41.5759984425136, 45.920217173440115, 49.67837272371565, 53.98040894099644, 52.49989373343331, 50.21868896484375, 50.25718893323626, 50.69490807397025, 49.92505809238979, 52.037970542907715, 47.94680173056466, 50.56334740774972, 43.55156585148403, 45.146966048649375, 45.51433120455061, 46.19310072490147, 51.668798855372835, 54.02850784574236, 51.837636607033865, 55.84782416479928, 59.982985496520996, 55.038136686597554, 53.34770597730364, 47.312066418784006, 45.175575256347656, 45.03445386886597, 54.13317550931658, 56.09989438738142, 55.31243072237287, 51.49971791676113, 44.225287505558555, 41.83233833312988, 49.34980978284563, 58.180702686309814, 54.45617989131382, 55.34923185620989, 56.89905187061855, 60.47116592952183, 58.88448919568743, 59.85504831586565, 59.51155022212437, 64.83454431806291, 54.30180134092058, 65.79184627532959, 35.168845653533936, 26.43108640398298, 11.597825390951973, 0.2480545166347708, 20.933134930474417, 55.406544072287424, 58.14821638379778, 53.21082646506173, 64.34910147530692, 62.71780341012137, 64.82269069126674, 68.39541271754673, 43.51964930125645, 49.841512952532085, 36.25616577693394, 38.04911020823887, 50.49190602983747, 51.03568594796317, 1.1629319403852736, 0.2224883756467274, 0.22420090303889342, 0.11937843848552022, 0.0984139930722969, 0.17331775198025362, 0.20743837393820286, 0.23025030057345117], [0.08795303904584476, 0.047870893230927844, 0.0676191562254514, 0.12802856575165475, 0.12755298055708408, 0.05342140128569944, 0.12517396892820085, 0.03984663988064442, 0.08455515280365944, 0.030447348885770355, 0.1790281127073935, 0.4392629978912217, 44.46554231643677, 47.69723285947527, 39.13791029793875, 21.864516632897512, 43.351614066532676, 23.418943302971975, 22.593632800238474, 62.342489515032085, 52.490225315093994, 58.50285938807896, 51.19658538273403, 52.07185690743582, 50.21861253465925, 51.18430444172451, 1.408858978322574, 1.2623895406723022, 1.2633403582232339, 1.4893465851034438, 31.911571843283518, 45.824526582445415, 49.27925777435303, 59.41435882023403, 56.37900005068098, 53.80834027699062, 53.18029955455235, 50.81027943747384, 53.42798546382359, 50.26535654067993, 47.9890467779977, 44.483652796064106, 42.39337757655552, 41.339290687016074, 44.52456726346697, 43.57039546966553, 46.410787786756245, 49.926270553043906, 53.05357136045183, 52.79019641876221, 50.464905330113, 37.934068884168354, 42.673007828848704, 46.87644215992519, 49.78886297770909, 53.1196174621582, 52.148394789014546, 48.43101126807076, 43.881928375789094, 45.64514146532331, 39.13615240369524, 39.19638286318098, 48.70829997743879, 47.01293952124459, 47.33370658329555, 47.7752229145595, 49.192936829158235, 47.39354794366019, 45.925542967660085, 45.209583214351106, 45.51959099088396, 37.38201713562012, 33.41536004202706, 36.27373429707119, 35.619085448128835, 39.37309987204415, 42.923413957868306, 44.68939937864031, 46.31890480858939, 46.69793946402413, 47.742444787706646, 46.8250914982387, 47.64249842507498, 46.08838094983782, 49.98273856299264, 48.87146799904959, 47.89529473440987, 48.072727407727925, 44.64960357121059, 41.407799925122944, 48.533340862819124, 46.40942593983242, 44.40452323641096, 42.90029035295759, 49.34396634783064, 53.97518389565604, 51.06339883804321, 49.58454424994332, 46.78069945744106, 50.285381249019075, 44.69291169302804, 42.137572697230745, 39.063814708164756, 36.19296496255057, 37.13683605194092, 37.690336499895366, 37.832882268088206, 38.23076043810163, 41.482798780713765, 48.45652157919747, 47.869357109069824, 47.331111431121826, 46.93478618349348, 44.94357143129621, 45.6038761138916, 43.73538391930716, 46.03598805836269, 42.1834898676191, 37.42580468314034, 39.34464005061558, 41.034532274518696, 42.14580978666033, 50.05744559424264, 41.32078416006905, 49.257284096309114, 48.15947219303676, 38.26448351996285, 50.94010305404663, 47.69729886736189, 47.08734083175659, 46.03794745036534, 46.58833857945034, 38.013097694941926, 40.46652398790632, 49.68560579844883, 50.40551560265677, 48.17130497523716, 40.63935695375715, 39.649575642177034, 49.82967322213309, 52.522982597351074, 55.47554315839495, 55.40323672975813, 52.05823843819754, 57.12932906832014, 54.92422444479806, 57.598954336983816, 54.362556389399934, 52.56256301062447, 45.61537538255964, 6.766487564359393, 10.724131975855146, 0.6460856284414018, 1.1873451960938317, 39.223133427756174, 67.17920698438371, 41.714885984148296, 56.25729193006243, 50.23028203419277, 51.50333445412772, 57.23509802137102, 44.31780276979719, 30.108173847198486, 36.29865748541695, 19.68497269494193, 19.12642785481044, 39.750508649008616, 17.438613142286027, 0.16560894277478966, 0.04633482226303645, 0.08455152264130966, 0.05528143879824451, 0.11075051967054605, 0.04057763583425965, 0.05282628536224365, 0.021979701738538485, 0.032373455353081226, 0.052061634071703465, 0.03958501713350415, 0.023541158397815058, 0.03954868497593062, 0.0660882115896259, 0.08271353412419558, 0.05889711781804051, 0.09181198983320168, 0.019661539433790103, 0.14669297422681535, 1.1210143268108368, 51.465268748147146, 55.305777822222026, 32.18034553527832, 34.19876595905849, 53.985661779131206, 27.69708640234811, 29.941837447030203, 65.54455988747733, 59.444326400756836, 64.04764693123954, 56.10848930903843, 56.56324890681675, 54.13910927091326, 57.20392492839268, 2.1682502925395966, 1.2708716626678194, 1.935214442866189, 1.3057003766298294, 34.670267241341726, 50.05626440048218, 51.68685374941145, 60.670926639011924, 58.06101996558053, 54.59114170074463, 56.26219041006905, 54.458771569388254, 54.19043561390468, 51.760546343667166, 51.370915685381206, 46.63305023738316, 46.08992344992501, 44.4952597618103, 46.35507018225533, 46.74467999594552, 47.72687040056501, 51.781227656773154, 56.84822232382638, 55.53862932750157, 51.51216908863613, 41.10534831455776, 44.157476561410085, 47.63085324423653, 51.248238291059224, 54.97590514591762, 54.15416949135916, 50.33007901055472, 45.55996349879673, 46.887781620025635, 40.183923380715505, 43.631473609379356, 52.05462537493025, 51.16963332039969, 49.35317618506295, 49.779583658490864, 51.848090171813965, 50.527664933885845, 49.43692977087838, 47.3257508959089, 48.96404579707554, 42.90649856839861, 37.22409847804478, 39.934677600860596, 37.1783515385219, 42.087451866694856, 45.28540890557425, 47.49747214998518, 49.12353822163173, 48.66734034674508, 50.53421013695853, 48.37427922657558, 51.611945220402305, 48.43439851488386, 52.58416496004377, 50.1395594051906, 49.07320547103882, 50.805175985608784, 45.13234009061541, 43.73918110983712, 52.116766589028494, 48.09616368157523, 45.29962144579206, 44.67757701873779, 50.94300045285906, 55.3224778175354, 53.714563914707725, 52.27011680603027, 49.57862785884312, 51.545687198638916, 49.307981627328054, 44.599955218178884, 39.95424025399344, 36.06584072113037, 37.69943516595023, 39.32306589399065, 39.30478865759713, 40.729124205453054, 44.33922059195382, 48.813169138772146, 48.97854668753487, 48.743906021118164, 49.08110557283674, 47.477051394326345, 48.687583923339844, 46.86350114004952, 48.433054038456504, 46.461026736668174, 38.380956172943115, 41.97058664049421, 43.12843445369175, 44.80350269590105, 52.18396609170096, 46.562404428209575, 49.108523164476665, 51.110709122249055, 40.72721692493984, 50.66201530184065, 48.56027902875628, 48.472700459616526, 46.427671909332275, 46.2377359526498, 38.212125369480674, 42.37975215911865, 50.50978027071272, 53.37036405290876, 48.943246364593506, 41.67222057070051, 42.216302735464915, 52.31132657187325, 53.517259393419536, 58.0001676423209, 56.73292391640799, 54.79587732042585, 57.78546135766165, 59.354062352861675, 59.120533398219514, 58.50274821690151, 54.81773982729231, 47.42926515851702, 8.504182526043483, 11.018828528267996, 0.6023695170879364, 3.658152299267905, 44.14396578924996, 65.83809348515102, 47.312802927834646, 59.1378413609096, 56.32689898354666, 56.35688393456595, 63.546327454703196, 51.317706380571636, 34.687391076769146, 46.98640087672642, 25.546516452516826, 16.553376163755143, 51.337213448115754, 20.845902034214564, 0.2538351464484419, 0.048053028993308544, 0.04092178201036794, 0.05445375499714698, 0.034065365458705595, 0.03655420815838235, 0.06406602795634951, 0.08940282410808972, 0.1300988710884537, 0.1283549139542239, 0.21011047198304109, 0.15295345043497427, 0.17734487088663237, 0.1424860842525959, 0.1671177332422563, 0.16213770689708845, 0.18210849884365285, 0.13354984591049807, 0.22450013698211738, 1.4700275531836917, 66.17010620662144, 62.77218001229422, 55.54600831440517, 33.26876694815499, 58.157419272831504, 32.97213792800903, 32.444147791181294, 72.94629519326347, 63.36265877314976, 68.7838795525687, 59.823878696986604, 61.299564906529014, 57.00876045227051, 61.818741253444124, 2.735175962959017, 2.687529993908746, 4.398172361510141, 1.3979659399815967, 38.13782480784825, 52.297138350350515, 53.3157616342817, 63.475101470947266, 59.541740145002095, 55.882217747824534, 57.494568075452534, 55.87093039921352, 58.51552595411028, 55.04782942363194, 52.12738691057478, 49.51447861535208, 47.00011314664568, 44.917967319488525, 48.49155439649309, 48.71788501739502, 50.01526655469622, 56.10869428089687, 58.87356662750244, 58.28998047964913, 52.7996563911438, 41.42892244883946, 44.850298813411165, 49.323246819632395, 52.99097156524658, 59.55606038229806, 57.07900326592581, 52.22383485521589, 49.505734307425364, 50.03337703432356, 43.604650088718955, 45.449671268463135, 55.66567019053868, 54.42564950670515, 52.04387303761074, 52.36852066857474, 55.312302180698936, 54.46736649104527, 51.99662528719221, 52.081250871930806, 52.711799894060405, 45.81745331627982, 40.00253023420061, 44.513946941920686, 41.768136978149414, 47.40188578196934, 47.56564440046038, 51.75869117464338, 53.27197756086077, 53.04326718194144, 54.35017817361014, 53.28762142998831, 54.88270895821707, 51.14085735593523, 55.89680896486555, 53.99322836739676, 54.003025327410015, 53.408412388392854, 47.380777154650005, 45.6816577230181, 53.01276111602783, 50.11790534428188, 47.74850014277867, 45.72543484824044, 53.81769255229405, 57.26535047803606, 56.94314513887678, 55.72933306012835, 53.06211764471871, 55.979947635105674, 50.885174070085796, 46.684539863041465, 41.13937364305769, 38.15242644718715, 40.82850776399885, 41.32353564671108, 41.509518078395296, 43.487729276929585, 44.39443792615618, 53.268388816288535, 51.197200298309326, 50.90662663323538, 53.823539461408345, 49.43103075027466, 50.127924646650044, 51.14840309960501, 52.16087375368391, 48.87035281317574, 41.707941259656636, 45.52707767486572, 44.79246548243931, 49.01789781025478, 51.81312336240496, 50.379049914223806, 52.70208631243025, 51.123090812138145, 44.9293588910784, 51.94485773359026, 49.94636474336897, 50.60004779270717, 48.21933787209647, 48.76593181065151, 39.336361271994456, 46.62558787209647, 53.9912029675075, 53.68829277583531, 51.238934653145925, 42.456415108272004, 42.460514545440674, 54.0306305204119, 55.970817702157156, 58.448086738586426, 56.96163429532732, 56.5731327193124, 61.145745686122346, 61.65545163835798, 61.09166785648891, 59.99538108280727, 54.29514844076974, 50.01882403237479, 20.638044936316355, 16.37931510380336, 0.9409778160708291, 2.8473917586462836, 51.32615886415754, 72.91158199310303, 50.79733146939959, 64.55577564239502, 61.53409440176827, 60.467566762651714, 69.80839838300432, 55.610564027513774, 41.83239391871861, 52.977426052093506, 28.922573191779, 32.46031624930245, 58.65662997109549, 35.11029665810721, 0.2983854758952345, 0.1674777367817504, 0.13126150013080665, 0.19726345634886197, 0.15327078769249575, 0.14612645176904543, 0.109801106687103, 0.16525302401610784], [0.025684721767902374, 0.07842925044574908, 0.039550092936094315, 0.049878888696964295, 0.030408665604357208, 0.05041667180401938, 0.06199292705527373, 0.07489993197045156, 0.08559642585792712, 0.05076732173828142, 0.10841348900326661, 0.15639598428138665, 29.454080854143413, 50.4241749899728, 38.551850591387065, 26.775595460619243, 31.815554686955043, 30.024031162261963, 11.575161235673086, 58.295636313302175, 51.26503903525216, 48.66137184415545, 49.397078377859934, 54.59207623345511, 46.17756455285208, 46.103100708552766, 9.300874267305646, 0.968773541705949, 2.8286481244223456, 5.462149577481406, 50.88038328715733, 37.994070053100586, 56.418253898620605, 50.60441126142229, 59.80791868482317, 54.42035150527954, 57.61442102704729, 52.2863894871303, 56.79397773742676, 52.322349888937815, 50.42302853720528, 44.07112087522234, 42.76595040730068, 43.2470679964338, 46.61306721823556, 44.38306719916207, 47.94653075081961, 49.137670857565745, 52.393693992069785, 50.02553946631295, 50.11230162211827, 42.10611472811018, 41.68062094279698, 49.28713008335659, 48.78287499291556, 51.4033568246024, 50.41407578332083, 48.87985100064959, 44.530952657972065, 47.09257282529558, 40.3117424419948, 39.057029792240684, 42.914718287331716, 51.68864985874721, 46.59250055040632, 46.585983140128, 45.102813720703125, 47.308078152792795, 48.4796382359096, 46.58479847226824, 43.30713169915335, 38.856647218976704, 36.65931762967791, 38.02693850653512, 40.261958599090576, 42.2538195337568, 43.8265060697283, 47.38100297110421, 44.20640230178833, 46.838859353746685, 46.94786616734096, 49.23895822252546, 47.79679012298584, 48.39172962733677, 50.307163851601736, 47.78493997028896, 47.990318298339844, 48.37516164779663, 43.13007075445992, 41.348191329411094, 48.33988216945103, 46.9654346874782, 43.59645816258022, 41.6853700365339, 47.17459978376116, 51.2603177343096, 50.8116134916033, 48.81605611528669, 47.85673918042864, 48.7660151890346, 48.91031537737165, 48.08149603434971, 40.31110668182373, 40.58551188877651, 38.1108067376273, 37.09284700666155, 36.08368369511196, 36.308589935302734, 41.78376347678048, 48.31566769736153, 47.49673564093453, 45.5888853754316, 47.63458095278059, 46.075763021196636, 45.96727384839739, 43.586720262254985, 44.12786681311471, 40.4178865977696, 37.02698155811855, 39.68479953493391, 39.68807561056954, 45.01740993772234, 49.55892276763916, 42.50367675508772, 45.78609609603882, 37.00203405107771, 39.33972420011248, 46.8996456691197, 48.0791232245309, 50.052224023001536, 47.62430109296526, 49.30576515197754, 41.69847433907645, 52.52862800870623, 54.756991727011545, 49.46800558907645, 48.289782183510916, 44.10387120928083, 37.73953669411795, 42.96082305908203, 50.28752824238369, 54.46462195260184, 54.60535076686314, 52.770189080919536, 51.50522436414446, 55.03330421447754, 59.06616374424526, 52.556024755750386, 49.4984769139971, 29.495947224753245, 5.6499897837638855, 5.0696397594043185, 0.13935464514153345, 12.395456876073565, 46.780206135341096, 44.02554416656494, 62.93595600128174, 49.339752265385215, 52.40685040610177, 50.51591553006853, 57.745880944388254, 43.475483076913015, 39.1434132712228, 23.356847252164567, 28.140820946012223, 31.576161452702113, 38.55393852506365, 5.954350846154349, 0.48837460258177345, 0.02074927686979728, 0.06921272285814796, 0.04872971161135605, 0.11285443963216883, 0.03550027024799159, 0.008599818983514394, 0.009014861891046166, 0.040402390594993315, 0.012188961346899825, 0.042825398434485705, 0.03811426194650786, 0.017551526227699857, 0.06031086588544505, 0.06277930164443594, 0.028307856725794927, 0.05716860414083515, 0.03534953369359885, 0.10517208650708199, 0.11609379973794733, 34.27704436438424, 59.09832695552281, 37.35093436922346, 30.3065344946725, 43.547306605747764, 29.68425382886614, 14.437828608921595, 66.763795035226, 54.40684420721871, 58.16465582166399, 57.31949084145682, 60.36749185834612, 49.329093728746685, 53.59918212890625, 11.78019302231925, 0.23210036701389722, 1.8257577334131514, 4.992817001683371, 55.954816000802175, 38.468552112579346, 59.339227948869976, 50.71824359893799, 63.65747083936419, 55.825072288513184, 60.415524755205425, 53.765938895089285, 58.51739501953125, 52.30851602554321, 52.66080011640276, 45.87485238483974, 44.105979987553184, 45.67219427653721, 47.5434935433524, 47.467327390398296, 51.78535141263689, 51.84987585885184, 54.26944358008248, 53.136056900024414, 53.26068673815046, 46.58211299351284, 46.07203531265259, 50.373706749507356, 50.629925046648296, 52.87928622109549, 52.64287723813738, 51.32736437661307, 45.93086528778076, 46.55820076806204, 42.55284915651594, 40.16015706743513, 45.97600425992693, 52.41750546864101, 50.27526467187064, 47.75306510925293, 48.67644248689924, 50.46251514979771, 49.46432999202183, 49.29307426725115, 46.06800535746983, 40.90819317953927, 38.130362442561555, 41.48741238457816, 43.80420930044991, 44.643020153045654, 46.04001801354544, 50.84127535138811, 48.24150262560163, 50.76650578635079, 49.5332978112357, 52.402535574776785, 51.59535639626639, 49.715896470206125, 53.19416121074131, 50.93071256365095, 50.90567125592913, 51.88485656465803, 45.28638860157558, 43.22767557416643, 48.344721589769634, 49.44894320624215, 44.88605424336025, 43.10265316282, 50.17701019559588, 55.074357645852224, 53.51672090802874, 52.49413367680141, 49.64388534000942, 51.785149914877756, 51.66897256033761, 49.370564052036826, 41.8971962928772, 42.65129818235125, 40.41563190732683, 39.04084743772234, 37.950626441410606, 39.73372874941145, 42.601087025233674, 49.25632177080427, 50.574339457920615, 48.52054228101458, 49.32079757962908, 48.027921949114116, 47.78002411978585, 45.77544103349958, 46.83513511930193, 44.0671569279262, 38.933035714285715, 42.80209493637085, 43.23026030404227, 48.58368056161063, 48.916850158146445, 44.756487710135325, 46.55710990088326, 39.554006644657676, 40.42356327601841, 49.00057595116751, 49.142909799303325, 51.88662140710013, 48.717864172799246, 50.60798610959734, 42.67294182096209, 52.640198707580566, 54.87322119304112, 51.29911994934082, 48.87111016682216, 46.75378213609968, 38.657796723502024, 45.150902203151155, 52.11254555838448, 56.26364605767386, 54.23471648352486, 56.953876631600515, 52.62133434840611, 57.95745011738369, 56.582339082445415, 56.06848505565098, 49.90444278717041, 33.6050945009504, 0.8592623866030148, 3.5220952800342014, 0.1262040122279099, 16.130420207977295, 49.81510632378714, 47.949542794908794, 66.72965158735002, 53.0110171181815, 61.031746591840474, 54.87605605806623, 64.17713356018066, 50.26881326947893, 41.83490569250924, 34.62444734573364, 28.41748431750706, 30.934561320713588, 49.25540460859026, 8.148829068456378, 0.3457357665257794, 0.04487158524404679, 0.04262527470876064, 0.03847677606557097, 0.08475260649408613, 0.054408557779554806, 0.03822110067786915, 0.03436968502189432, 0.15265414863824844, 0.0844839880509036, 0.13481694220432214, 0.15043542055147036, 0.10305813779788357, 0.2022077510399478, 0.1717195034559284, 0.13215196877717972, 0.16616580289389404, 0.15871974958905152, 0.2840334288775921, 0.21555140002497605, 45.11264542170933, 67.71654592241559, 51.81506538391113, 35.96803092956543, 45.4540034702846, 43.290584564208984, 16.949249778475078, 71.544892174857, 61.25874423980713, 60.56498050689697, 57.68460825511387, 65.35008675711495, 52.946603843144004, 57.70124919073922, 12.007638829095022, 2.4666217906134467, 6.602841854095459, 5.916745024068015, 58.229666641780305, 43.743492467062815, 59.34631511143276, 53.40364245006016, 67.0357197352818, 59.15909590039934, 62.36623150961739, 56.24351365225655, 60.80508940560477, 55.18361806869507, 55.34270749773298, 49.08796344484602, 47.37095935004098, 45.70977013451712, 50.40482773099627, 50.070101737976074, 55.836040019989014, 53.80316734313965, 59.23922252655029, 53.874810218811035, 56.23473807743618, 46.62393420083182, 46.92237670081002, 52.792159284864155, 52.452562604631694, 57.070328439985005, 54.668812138693674, 54.4429018838065, 48.484036445617676, 51.87232896259853, 45.030097348349436, 44.099671023232595, 48.36943285805838, 57.037623269217356, 54.85850143432617, 51.75443540300642, 51.82223245075771, 53.24546670913696, 55.09358678545271, 51.851880414145334, 51.14744077410017, 46.043304511478965, 43.02040386199951, 45.82891436985561, 47.929604939052034, 48.76623753138951, 49.83703831263951, 54.46884298324585, 51.01544237136841, 54.859807695661274, 51.790215151650564, 56.723693234579905, 56.114589827401296, 51.41508885792324, 54.810920170375276, 53.10583918435233, 53.04312474387032, 54.34772545950753, 47.024820940835134, 42.925050258636475, 52.28939805712019, 51.77338661466326, 46.29239395686558, 43.52935593468802, 51.72226871762957, 58.353021485464915, 56.05316775185721, 55.17869526999337, 51.34145532335554, 52.776147161211284, 54.36564833777291, 53.86090339933123, 44.39504589353289, 44.7653431892395, 41.58564601625715, 40.806697368621826, 38.89926399503435, 41.49990177154541, 45.44934122903006, 50.649518966674805, 52.59732832227434, 50.89948388508388, 51.42017841339111, 50.15773936680385, 52.52218355451311, 49.11760793413435, 48.60304866518293, 45.07767513820103, 42.91266162054879, 44.4864216532026, 45.868275914873394, 50.50136252811977, 52.858247075762065, 48.33070707321167, 49.56540543692452, 42.58255270549229, 41.324466705322266, 49.99221937997, 50.96447038650513, 53.29819311414446, 51.010912145887104, 51.214494364602224, 44.51196323122297, 54.00001675742013, 56.532843589782715, 52.976224013737266, 50.2706093788147, 47.63697113309588, 40.57673978805542, 46.86931330817086, 53.925636291503906, 59.31342233930315, 57.41838455200195, 56.73523071834019, 52.77949966703142, 57.39822435379028, 57.89797701154436, 55.700560569763184, 50.17450884410313, 41.196258544921875, 11.512754252978734, 5.772792679922921, 0.24285058730414935, 16.105189561843872, 60.85556806836809, 49.62314149311611, 72.67315455845424, 57.48348222460066, 66.28945541381836, 60.7289718900408, 70.60518305642265, 53.01954255785261, 53.42868723188128, 35.879000186920166, 45.616699014391216, 47.99558850697109, 61.54668453761509, 15.550280366625104, 0.707228310406208, 0.11020257550158671, 0.20487370155751705, 0.11395976639219693, 0.15757458603807858, 0.11645203908639294, 0.17277941586715834, 0.23094897451145308], [0.020271437242627144, 0.01641354666623686, 0.023071759746276906, 0.12162787706724235, 0.03884192968585661, 0.037573805411479304, 0.017383904329368045, 0.036059165972151926, 0.06774520767586571, 0.03718922533360975, 0.06923354709787027, 0.1732172066611903, 9.008705122130257, 58.89287567138672, 33.20840447289603, 39.16268410001482, 27.832039526530675, 54.41159677505493, 16.755659069333756, 39.982199805123464, 63.37931360517229, 42.82937356403896, 48.301059109824045, 52.28323153087071, 51.91473381859915, 48.40097767966134, 27.42041608265468, 0.9338415818555015, 1.1527111402579715, 2.158359097582953, 47.844315801348, 29.167749064309255, 50.157937390463694, 54.955032757350374, 54.13242162976946, 55.03583683286394, 54.50326088496617, 54.4966253553118, 50.97926310130528, 48.739344528743196, 44.27796179907662, 42.533404622759136, 41.89797796521868, 44.870931489127024, 45.95167514256069, 48.3924001285008, 47.899276052202495, 49.27188573564802, 51.58709846224104, 51.94263431004116, 52.50069972446987, 56.054904801504954, 50.30216809681484, 51.52949442182268, 50.434503487178254, 51.6096453666687, 49.60743161610195, 48.553424630846294, 44.124952043805806, 46.143567017146516, 41.50018317358834, 38.671251910073416, 38.126426288059776, 49.53914819444929, 47.79400042125157, 47.68985039847237, 46.71105418886457, 45.16051156180245, 48.12499175752912, 45.39203943525042, 40.058466706957134, 35.265175478799, 36.422349316733225, 36.849333490644185, 41.54813616616385, 45.26455736160278, 44.748754365103586, 48.653155599321636, 46.970256737300325, 46.79686444146292, 47.79213482992989, 47.27137081963675, 47.39194985798427, 48.57105915887015, 48.858179569244385, 46.11154624394008, 45.671509878976, 48.06124898365566, 43.35895831244332, 42.789244243076865, 46.46495246887207, 47.210525444575715, 42.698021343776155, 43.39127785818917, 47.52907255717686, 51.40008074896676, 52.02127054759434, 46.69491004943848, 48.410795484270366, 50.957160881587434, 49.244381291525706, 47.542496476854595, 42.51900100708008, 38.87021357672555, 38.76876987729754, 36.36187219619751, 36.07595729827881, 37.098332609449116, 38.431268078940256, 43.74773434230259, 48.33943401064192, 46.08061286381313, 45.29141214915684, 46.20927613122122, 44.42537130628313, 45.21556908743722, 44.149176938193186, 38.77338000706264, 37.77604947771345, 42.063167912619456, 39.21122074127197, 44.874989237104145, 45.98152807780674, 50.63635560444423, 41.624847752707346, 39.02268484660557, 44.11276837757656, 46.49048015049526, 46.10835007258824, 47.90316356931414, 48.91500541142055, 46.89151627676827, 51.42190504074097, 52.60979686464582, 55.29143674033028, 50.40682533809117, 49.118469510759624, 44.81434883390154, 39.62121309552874, 40.63827998297555, 43.07270990099226, 53.552337374006, 51.362056732177734, 58.225577626909526, 53.18120976856777, 55.610393796648296, 45.92250313077654, 54.42347124644688, 43.100971698760986, 23.779565232140676, 2.089623825890677, 2.634103775024414, 1.1996160405022758, 32.82760150091988, 61.22703960963658, 47.685240268707275, 51.329289027622764, 49.00116654804775, 51.99138287135533, 52.99746118273054, 53.04995829718453, 40.5595395224435, 40.90796388898577, 23.11724383490426, 32.21896709714617, 23.354028020586284, 33.2603040422712, 0.8597394781453269, 0.1547434665262699, 0.09779318102768489, 0.03617637271859816, 0.061861888372472355, 0.06469383569700377, 0.024206024328512803, 0.014087053647797023, 0.0031246605462261607, 0.02290632781971778, 0.05853788780846766, 0.026668497461027334, 0.057794817324195585, 0.025682865974626372, 0.044848610048315356, 0.052371368344341, 0.0035064728373462068, 0.09403324885559933, 0.048546463051544766, 0.05087889664407287, 0.15377913255776676, 12.20880481175014, 69.74172346932548, 34.63712780816214, 33.6685836655753, 43.112022808619905, 53.791140011378694, 18.353953191212245, 46.65190764835903, 68.71197959354946, 44.788661343710764, 52.12962770462036, 55.52949939455305, 55.35060065133231, 50.16657747541155, 33.13914482934134, 1.344505414366722, 1.1309780435902732, 2.2161262035369873, 53.06272561209542, 33.479557922908235, 53.68946702139718, 55.433812277657644, 54.89621278217861, 56.864804199763704, 57.801952907017295, 55.80329316002982, 55.27840191977364, 51.300752776009695, 46.55198907852173, 46.21487290518624, 45.27198845999581, 46.32368516921997, 49.16362932750157, 49.38545751571655, 48.73977184295654, 51.45111526761736, 53.68593386241368, 55.33803136008126, 55.14028215408325, 57.543222836085725, 53.22108548028128, 52.49140303475516, 54.777759892599924, 53.06441055025373, 51.28531387874058, 50.903857776096885, 46.85133831841605, 47.901489053453716, 44.50366013390677, 40.65751607077462, 41.825925145830425, 51.56773035866873, 51.22430869511196, 50.63122088568551, 48.19307368142264, 49.322930676596506, 50.34411089760916, 48.74882187162127, 44.41498374938965, 37.25218309674944, 39.95109619413103, 39.660821301596506, 44.460984298161094, 48.57790660858154, 48.79750442504883, 51.19723851340157, 48.179496901375906, 50.6588260786874, 51.66239956447056, 50.397528648376465, 50.26689904076712, 51.91148900985718, 51.690522398267476, 50.83700915745327, 49.327155181339805, 49.687426226479666, 45.79938799994332, 43.97217157908848, 49.07343823569161, 49.683267729622976, 43.32482181276594, 45.40831906454903, 50.449390002659385, 52.948406900678364, 54.06824459348406, 50.170225279671804, 51.195431981767925, 53.19892420087542, 52.79605027607509, 50.213641098567415, 45.15583542415074, 40.75405434199742, 40.666208267211914, 38.267704010009766, 38.42198181152344, 38.025771209171836, 41.619897161211284, 46.911954402923584, 48.45494433811733, 48.56590012141636, 47.73454121180943, 48.84892804282052, 46.9910318510873, 45.98251819610596, 46.54071910040719, 41.05077716282436, 38.4174759047372, 45.31370544433594, 40.28923722675869, 46.11132737568447, 47.693942887442454, 53.243580273219514, 44.587007250104634, 39.94754566465105, 44.97135380336216, 47.614896706172395, 49.51863016401018, 48.55255263192313, 51.01690149307251, 48.894556862967356, 51.65658392224993, 52.519063813345774, 53.78600876671927, 52.52852031162807, 51.50455733707973, 45.96559585843767, 42.06042684827532, 43.20240844999041, 46.05597455160958, 53.53706523350307, 53.77731309618269, 58.93699673243931, 54.99899400983538, 56.50627367837088, 46.27672924314226, 56.406111921582905, 43.92979451588222, 28.556031397410802, 2.090208560228348, 5.683732841696058, 2.9530345584665025, 40.82162209919521, 63.16678210667202, 53.7626176561628, 56.46209355763027, 53.464237689971924, 56.52225453513009, 60.34108870370047, 59.751839773995535, 45.25641754695347, 45.69204180581229, 36.12295838764736, 26.639640058789933, 26.458675963538035, 46.24614674704415, 2.204150549003056, 0.2617604083248547, 0.07978777254798583, 0.06302960642746516, 0.04642962717584201, 0.037443937201585085, 0.0519239593164197, 0.05945515180272715, 0.04843166171173964, 0.11357806330280644, 0.1786104336913143, 0.12859325616487435, 0.1566625399781125, 0.1832254489085504, 0.1272733969880002, 0.14301918207534722, 0.08727387977497918, 0.23055821976491384, 0.09604727649795157, 0.1769045288009303, 0.32724522586379734, 17.80403627668108, 84.56034810202462, 45.19636426653181, 52.53596878051758, 41.81654855183193, 68.68260260990688, 23.13192711557661, 50.49336862564087, 76.04659530094692, 53.61412075587681, 57.867356300354004, 62.24004527500698, 57.47005483082363, 58.87519250597273, 36.4682525907244, 1.5716382265090942, 2.739911594561168, 2.3922363306794847, 57.5876704624721, 39.54812152045113, 52.75932904652187, 54.747802734375, 60.145080021449495, 58.22796433312552, 59.457514081682476, 57.978055000305176, 56.75496360233852, 52.893731525966096, 48.017596926007954, 47.57179703031267, 45.780631337847026, 48.699771063668386, 51.92642763682774, 50.975632667541504, 52.46614980697632, 54.52675969260079, 56.43359204701015, 57.397001470838276, 57.98617049625942, 58.47168282100132, 52.78928967884609, 54.69447531018938, 55.459503241947715, 55.61173479897635, 54.177894115448, 53.98637744358608, 48.6214405468532, 52.31070123400007, 48.026007720402305, 43.84350483758109, 43.421398299080984, 54.001079831804546, 54.20193140847342, 55.40818732125418, 51.49710191999163, 51.84899691173008, 55.82809822899954, 53.63596589224679, 48.69602945872715, 41.85136597497122, 42.438846588134766, 43.53547729764666, 46.7632942199707, 52.21084172385079, 51.833606651851106, 55.0758376121521, 51.88365452630179, 52.72952127456665, 54.7108278955732, 53.485558237348286, 54.00764240537371, 55.524305616106304, 53.59358882904053, 51.645664828164236, 50.37349830354963, 50.68594142368862, 47.72090537207467, 45.5505347933088, 49.45370619637625, 51.03449433190482, 44.708955083574565, 46.93240989957537, 50.43409006936209, 55.74293415887015, 56.45376961571829, 50.72981234959194, 53.31759248461042, 55.78683982576643, 54.856229373386924, 52.26375920431954, 48.363467829568044, 43.45456552505493, 41.727069650377544, 41.26282228742327, 40.25956841877529, 41.73258304595947, 43.06019966942923, 48.84322704587664, 50.60783324922834, 51.26722076960972, 50.290432589394705, 53.47974954332624, 50.102198941367014, 50.67106185640608, 49.572784423828125, 43.362901415143696, 43.155372619628906, 48.22017165592739, 43.04488236563546, 47.077637672424316, 50.75349875858852, 55.548582621983115, 46.804260798863, 40.41913727351597, 46.68623522349766, 49.664914063044954, 51.724613734654014, 52.788865838732036, 53.992648192814414, 51.54155649457659, 53.708855969565256, 55.006383419036865, 57.66553544998169, 53.90766824994768, 54.84154782976423, 47.465242930821006, 43.083330222538535, 44.16887855529785, 48.51970154898507, 56.282552106039866, 54.51016739436558, 59.71768242972237, 54.377168451036724, 55.76624883924212, 48.79899481364659, 56.29396799632481, 46.45631585802351, 37.83329568590437, 5.057998486927577, 5.26320788690022, 3.3020875198500494, 42.25334358215332, 73.6664342880249, 57.44910601207188, 63.01104518345424, 58.067012786865234, 62.61844417027065, 62.67377267565046, 64.5000580378941, 50.40599850245884, 54.098125321524485, 37.87686089106968, 49.046069281441824, 36.2839481489999, 60.43900966644287, 5.608344886984144, 0.5902635838304247, 0.1383494497942073, 0.14945605024695396, 0.1345209652291877, 0.12085601634212903, 0.12328750586935452, 0.11551544362945215, 0.12616197019815445], [0.054678265271442275, 0.05798774518604789, 0.057315927664084096, 0.04755104539383735, 0.032158536171274524, 0.0395148091151246, 0.02410897346479552, 0.03641590236553124, 0.03329054292823587, 0.02559606607870332, 0.07208500230418784, 0.11279212297605616, 1.1906091123819351, 42.065644945417134, 45.101903506687705, 35.84903260639736, 17.640279395239695, 45.73636436462402, 27.681303569248744, 25.670651231493267, 66.38259601593018, 53.0535956791469, 62.551046643938335, 51.45391886574881, 50.813142095293315, 52.96919938496181, 42.190431118011475, 0.5868183087025369, 1.0271329815898622, 0.0553275282893862, 20.39721516200474, 34.14960397992815, 50.853240149361746, 58.12112883159092, 57.70743308748518, 57.79611989430019, 53.26864242553711, 51.845543657030376, 45.14468356541225, 42.22489765712193, 42.649495124816895, 43.453832490103586, 45.10985571997506, 46.709299768720356, 46.5664621761867, 44.069828510284424, 47.93198817116873, 51.59315381731306, 49.653776100703645, 53.077719824654714, 50.77748394012451, 51.79553747177124, 56.57137482506888, 54.44247109549386, 52.09865958350045, 50.723711831229075, 48.51024852480207, 45.609528473445344, 44.107602391924175, 46.09904990877424, 43.58533757073538, 38.260054043361116, 37.14537538800921, 42.88017879213606, 49.39877373831612, 46.476952007838655, 51.46003328050886, 48.94660929271153, 46.180903162275044, 45.03494719096592, 39.665511335645405, 35.09390933173043, 36.90074668611799, 40.42863546098982, 43.946466718401226, 45.67672102791922, 45.92800610406058, 46.811066559382844, 46.935272557394846, 49.25946930476597, 49.44614655630929, 48.97557633263724, 49.69840785435268, 49.29259136744908, 47.816036633082796, 44.791551794324604, 42.949584347861155, 48.42648451668875, 44.34309073856899, 41.94596222468785, 43.9610926764352, 47.001780714307515, 40.399512086595806, 41.42164421081543, 45.99535846710205, 50.597716672079905, 51.589863845280235, 49.890820843832834, 49.85538503101894, 48.38637951442173, 49.63762501307896, 50.29507051195417, 48.13881867272513, 44.53495829445975, 42.59495176587786, 36.72005878176008, 35.053658417293, 36.6486382484436, 36.24352352959769, 42.059950896671836, 46.55204813820975, 48.32688556398664, 45.69584941864014, 45.64355032784598, 43.8687059538705, 47.399780477796284, 42.00904491969517, 36.73990283693586, 38.20123059409005, 43.55748919078282, 39.66622352600098, 45.25158507483346, 47.384911332811626, 47.30439560753958, 41.34801762444632, 38.43766736984253, 46.18890053885323, 42.92666571480887, 47.13274730954851, 46.49635485240391, 46.773775577545166, 45.570246832711355, 46.14209052494594, 45.044191769191194, 44.34963941574097, 44.32682153156826, 42.04226425715855, 42.20105838775635, 41.397054536002024, 42.09178754261562, 40.765963554382324, 45.79922819137573, 49.31983525412423, 55.72362164088658, 55.20343085697719, 56.10285431998116, 54.51350947788784, 54.933802536555696, 35.81922483444214, 20.173069749559673, 0.6912642813154629, 1.7233168589217323, 6.818921276501246, 56.64753402982439, 47.45642914090838, 49.49554477419172, 48.82756928035191, 52.35281426565987, 48.854768003736226, 52.72832271030971, 29.793646267482213, 50.91528408867972, 32.94738844462803, 19.33912263597761, 27.29187788282122, 33.66917078835623, 26.202938829149517, 0.21930809558502265, 0.11218834216041224, 0.016211039586258785, 0.05662285503266113, 0.006131878555087107, 0.033435084457908354, 0.056466971790151935, 0.060475132428109646, 0.06598652633173124, 0.031672650815120766, 0.07825441232749394, 0.06667657608964614, 0.044060447519379, 0.06761601460831505, 0.03669699906770672, 0.04797587277633803, 0.030682902317494154, 0.05422518029808998, 0.03214149476428117, 0.0300403296548341, 0.1342453985874142, 2.877562139715467, 52.2093756539481, 48.57558938435146, 31.543831484658376, 29.960569790431432, 54.85026781899588, 28.16553395135062, 31.951965195792063, 73.17521749223981, 54.37512220655169, 65.91323130471366, 55.93347808292934, 56.74109499795096, 55.32793910162789, 44.93125227519444, 1.9207226719175066, 0.8497560567089489, 0.11536091406430517, 23.51223850250244, 38.93443577630179, 51.37375055040632, 58.92297526768276, 59.87475340706961, 60.13495649610247, 53.96599490301949, 51.376703534807476, 47.949525424412315, 44.89556285313198, 45.39951222283499, 45.051303250449045, 45.95537158421108, 49.08832475117275, 48.08030789239066, 45.95126519884382, 50.71942479269845, 52.652872221810476, 53.37019729614258, 54.88771513530186, 54.25925404684884, 53.37766660962786, 58.10877840859549, 56.64142656326294, 53.93231003625052, 51.69679662159511, 50.73078509739467, 49.01571607589722, 47.216973372868125, 47.19835567474365, 46.98133563995361, 40.95060150963919, 38.347101075308665, 45.55987317221505, 53.25508649008614, 50.538625717163086, 53.66757672173636, 51.6229372705732, 49.556713240487234, 47.28864404133388, 42.43941634041922, 36.6092072214399, 39.36795473098755, 42.75215475899832, 45.25921072278704, 48.63605260848999, 48.41855314799717, 51.24476071766445, 50.93427004132952, 52.42601006371634, 50.68522923333304, 51.38227251597813, 51.850886821746826, 53.04462555476597, 52.552182401929585, 47.327210017613, 46.38111203057425, 51.62658507483346, 46.07309143883841, 43.19069031306675, 46.275676591055735, 47.39391272408621, 42.376323223114014, 42.93818930217198, 49.611930574689595, 52.42277915137154, 52.888721874782014, 52.45474781308855, 51.544759614127024, 51.33450365066528, 49.584353174482075, 52.54254872458321, 50.07110227857317, 47.95681408473423, 44.26639999662127, 38.99350241252354, 37.9168929372515, 38.27447850363595, 38.94940914426531, 44.49211917604719, 49.686533382960725, 49.9208196912493, 48.07844924926758, 46.99177530833653, 46.09964050565447, 50.44906343732561, 44.44918973105294, 37.96371684755598, 40.17180919647217, 44.77393463679722, 42.1033285004752, 46.543675558907644, 49.3636679649353, 48.41959190368652, 43.88998828615461, 39.270384652274, 47.180168764931814, 44.96321746281215, 47.344597884586875, 49.147954191480366, 48.139989444187705, 48.42855507986886, 48.12019402640206, 45.81544876098633, 47.06217793055943, 45.19157000950405, 44.28718900680542, 44.13430779320853, 44.19430201394217, 43.3276948928833, 42.12642431259155, 45.07650784083775, 53.11569520405361, 56.00531203406197, 58.158520562308176, 54.975022724696565, 56.70159101486206, 54.426090717315674, 40.10231678826468, 24.37762447765895, 1.9389836234705788, 2.049553781747818, 9.963318995067052, 65.56757926940918, 51.74320363998413, 56.11700780051095, 53.478387696402415, 58.8744421005249, 54.42670215879168, 56.93711410249983, 36.083294595990864, 56.07514142990112, 41.8397798538208, 27.113027776990617, 30.877158778054373, 41.96011223111834, 36.76859542301723, 0.6314773123179163, 0.09955267661384173, 0.05003097553604415, 0.06713382726801292, 0.04129545803048781, 0.022003072180918286, 0.06808051932603121, 0.07992761182997908, 0.02564257795789412, 0.13255036382802896, 0.14045980226780685, 0.12453750308070864, 0.14265765861741134, 0.16318806553525583, 0.08435585349798203, 0.12958285877747194, 0.1460563726723194, 0.2336037020598139, 0.0985945648114596, 0.22365935066980974, 0.17194138440702642, 4.187396151678903, 67.3949554988316, 57.79419871738979, 48.94508416312081, 26.514737503869192, 64.16535636356899, 34.91699777330671, 33.517752170562744, 79.25565556117466, 61.33363887241909, 69.21218735831124, 60.59890161241804, 59.876900400434224, 60.998784337724956, 52.26395375388009, 1.9761517090456826, 2.180799173457282, 0.10023098093058382, 31.524876798902238, 47.72058228084019, 52.871726581028526, 57.902524607522146, 62.94701058523995, 62.16695022583008, 56.732062339782715, 53.62213202885219, 50.45181144986834, 48.287937436785015, 46.70008645738874, 48.152843611580984, 49.75746406827654, 52.480424880981445, 50.870072160448345, 47.87309523991176, 53.55651324135916, 55.158017430986675, 54.91079357692173, 58.23290797642299, 57.14447266714913, 55.91671902792794, 58.386636870247976, 59.047063146318706, 55.00605337960379, 53.53151362282889, 53.0452196257455, 50.6708151953561, 50.42330993924822, 51.5812098639352, 48.501820359911235, 41.89177322387695, 40.9328419140407, 47.049198695591514, 56.07396023614066, 53.8291779245649, 57.66567441395351, 54.85066386631557, 53.210232394082205, 51.34139626366751, 46.63831697191511, 41.40869624274117, 42.99746438435146, 46.67203310557774, 50.51000261306763, 52.54898623057774, 52.90021766935076, 53.989375591278076, 53.07866825376238, 55.020335401807515, 54.320915835244314, 55.150978905814036, 55.70376368931362, 55.585286481039866, 53.573004790714805, 48.210058552878245, 46.73019300188337, 53.16759129932949, 48.49543843950544, 44.5400721686227, 46.82239212308611, 49.30977078846523, 43.22709539958409, 44.16896193368094, 49.792601108551025, 54.99353272574288, 56.049245493752615, 54.36323731286185, 54.335072789873394, 52.229171071733745, 52.25236068453108, 54.29070159367153, 52.687060832977295, 49.181034564971924, 46.85657378605434, 40.10266072409493, 39.99082251957485, 40.78186798095703, 41.98320804323469, 47.67674262183053, 51.510623114449636, 53.66721888950893, 51.38304724012102, 50.33068002973284, 48.08541481835501, 53.47998925617763, 47.12823792866298, 41.14277131216866, 42.029774870191304, 48.205451897212434, 46.012468406132285, 49.01517759050642, 52.07188817432949, 51.012437275477815, 48.50904301234654, 44.56890024457659, 49.918870721544536, 47.62947402681623, 49.84831523895264, 51.69530970709664, 52.189090388161794, 50.35568312236241, 50.95805025100708, 48.83429513658796, 48.81017099108015, 46.30933713912964, 45.666222299848286, 46.69090093885149, 45.461222648620605, 45.13879844120571, 43.23073278154646, 48.69841269084385, 52.442598887852256, 57.43974331447056, 58.16218226296561, 55.47044665472848, 54.13000365665981, 51.72792107718331, 43.51703330448696, 28.99125960894993, 3.28697692496436, 4.5700699261256625, 10.596624714987618, 68.9667283466884, 57.74703434535435, 59.637840679713655, 58.507535525730674, 65.36991691589355, 59.51806763240269, 63.2823098046439, 40.662779331207275, 61.26709597451346, 47.55192518234253, 31.582876886640275, 40.412546907152446, 52.62640305927822, 53.16657338823591, 1.6629098717655455, 0.2093840188213757, 0.11564289964735508, 0.11287662772727863, 0.11268606116729123, 0.10224874730088881, 0.1257132278489215, 0.21011427177914552, 0.16118842283529894], [0.06277461975280728, 0.04709384171292186, 0.0076146429637447, 0.019723245408385992, 0.045453296708209176, 0.013649138172955384, 0.031683052756956646, 0.0192664420631315, 0.025628042041457126, 0.06442017573863268, 0.06509662765477385, 0.0724633059331349, 0.062174211256206036, 24.725135156086512, 46.593584469386506, 39.04701396397182, 29.430853026253835, 33.212305886404856, 44.15744529451643, 16.850764274597168, 58.32144887106759, 50.40751320975167, 53.674167088099885, 51.94335692269461, 54.39272199358259, 47.7879832812718, 55.98133727482387, 10.977653503417969, 0.9036958994609969, 0.2658063769340515, 0.8221473896077701, 22.013399158205303, 42.62878949301583, 60.31043325151716, 53.97250883919852, 57.261185032980784, 51.346159253801616, 48.68311970574515, 45.10956736973354, 48.80782944815499, 48.32316132954189, 50.016961915152415, 49.72369234902518, 48.75748974936349, 46.40413836070469, 49.08140434537615, 49.7428936958313, 49.98541014535086, 49.79411581584385, 52.29132618222918, 52.11398730959211, 52.26109109606062, 48.94741528374808, 50.86575732912336, 50.65710987363543, 49.3986382484436, 50.21293585641043, 48.48577002116612, 42.47169419697353, 44.2127286366054, 45.41235249383109, 42.3354434967041, 39.050481115068706, 38.83194637298584, 46.70448466709682, 51.59887913295201, 48.37009293692452, 46.25608614512852, 46.207657200949534, 41.83886616570609, 35.123731000082834, 37.08726412909371, 37.07628597532, 41.88430043629238, 45.8804144178118, 43.424795968191965, 46.56364120755877, 45.95482962472098, 47.98828247615269, 47.99975047792707, 49.86115550994873, 48.06298950740269, 47.85900429316929, 49.067035470690044, 46.90635762895857, 38.06598390851702, 40.27265535082136, 46.64847871235439, 42.36363928658621, 42.66104303087507, 45.37077447346279, 46.97061456952776, 40.85338578905378, 40.12395347867693, 43.18007346561977, 51.675246783665244, 53.67915589468819, 50.23721286228725, 51.16013165882656, 49.30771064758301, 50.51731906618391, 48.66062491280692, 49.882177284785676, 47.12930795124599, 46.575626850128174, 42.22047165461949, 37.20070736748831, 35.773762771061485, 36.816927092415945, 37.78691646030971, 41.24784891945975, 46.993668692452566, 46.24155746187483, 45.57138286318098, 46.12092283793858, 47.341829027448384, 38.69390998567854, 35.42536619731358, 40.95262343542916, 43.12556832177298, 41.356254713875906, 42.34216240474156, 45.45096710750035, 46.17749159676688, 47.8875926562718, 35.02827664784023, 39.2530871118818, 49.82035916192191, 46.554035323006765, 46.00360597882952, 40.19951513835362, 37.39777217592512, 39.02492911475045, 39.79628685542515, 40.99923195157732, 42.00301388331822, 41.99948419843401, 42.92007882254464, 44.802192960466655, 44.11674969536917, 45.89484235218593, 46.25466176441738, 48.682285921914236, 53.54074083055769, 54.71206814902169, 53.11230795724051, 54.7560259274074, 46.22546195983887, 29.974830968039377, 22.656800610678538, 1.586636130298887, 1.0410178708178657, 11.471757275717598, 47.653785773685996, 49.889910629817415, 50.101306097848074, 49.439361640385215, 50.61930125100272, 50.3647574697222, 47.11705132893154, 41.28707844870431, 50.80002042225429, 21.78316364969526, 38.36062574386597, 38.7132294518607, 33.66997330529349, 17.009259632655553, 0.22472349713955606, 0.058450723199972084, 0.08546959409224135, 0.04090020798945001, 0.03455039246806076, 0.010592858689571065, 0.027675178800044314, 0.026697713482592787, 0.029107869868831973, 0.0925838980557663, 0.08635523156928164, 0.04256873577833176, 0.0339435718155333, 0.03110405204019376, 0.06605007792157785, 0.03265231288969517, 0.07740441829498325, 0.03362481641982283, 0.05587114001225148, 0.06474498366670949, 0.025793204250346338, 0.10224653527672802, 29.875238963535853, 57.091277258736746, 33.82541840417044, 31.473199571881974, 44.863420486450195, 44.34190607070923, 19.342054775782994, 63.969271251133506, 56.72491611753191, 58.12014218739101, 56.64568928309849, 58.134584018162315, 52.72583178111485, 58.322081157139365, 13.303302424294607, 0.5721228686826569, 0.8516632286565644, 0.5923070598925863, 27.289268834250315, 44.44359643118722, 63.60883344922747, 55.47032853535244, 60.114535740443635, 53.819370542253765, 52.31831298555647, 46.06628220421927, 50.95627498626709, 49.93996197836739, 52.03525032315935, 52.25615440096174, 51.096347195761545, 49.45853519439697, 50.9086902482169, 51.42270408357893, 52.284044470105854, 52.605072089603965, 55.62489468710763, 54.525967597961426, 54.82682807104928, 51.059730189187185, 52.26524959291731, 52.04412317276001, 50.64169529506138, 52.30669559751238, 49.58851861953735, 46.25216041292463, 46.78524010522025, 48.0007266998291, 43.76766177586147, 41.550790378025596, 39.57398966380528, 49.51648664474487, 53.69286469050816, 51.93920537403652, 49.58306775774275, 49.28295769010271, 45.543867996760774, 37.04524837221418, 38.86493641989571, 41.378131117139546, 43.02463184084211, 47.91514573778425, 46.840248993464876, 49.76669127600533, 50.109077657972065, 51.47867182322911, 50.93622248513358, 51.857873235430034, 50.63516051428658, 49.9106753213065, 52.28880398614066, 49.301551069532124, 41.36496080671038, 43.50657626560756, 49.483312470572336, 46.037843227386475, 42.851903097970144, 47.77902010508946, 49.04560375213623, 42.21729285376412, 41.61496046611241, 45.36098793574742, 53.34307152884347, 55.377250467027935, 52.643704073769705, 54.17456940242222, 51.899079527173726, 52.27314969471523, 51.708452224731445, 51.01399367196219, 49.185665539332796, 46.30965328216553, 42.36121089117867, 39.67251511982509, 36.98475735528128, 39.606948443821494, 41.280811173575266, 43.39925439017159, 48.392143045152935, 48.82844475337437, 47.919880935123985, 46.80005019051688, 50.4981872013637, 40.64341470173427, 37.519150257110596, 42.52359029224941, 45.11012669972011, 43.37095785140991, 44.45900058746338, 48.134972844805034, 48.1466041292463, 48.835643087114605, 36.03043964930943, 41.382279191698345, 51.077548844473704, 49.77971567426409, 47.853570801871165, 41.003703117370605, 41.15503488268171, 40.223677498953684, 41.40173067365374, 43.416795117514475, 43.35041202817644, 43.81704262324742, 45.47660248620169, 45.88578190122332, 46.17282935551235, 47.13290364401681, 48.176238196236746, 50.024952343532014, 56.08416713987078, 58.08588409423828, 55.88064398084368, 55.32081719807216, 46.59591211591448, 34.93661601202828, 25.99971444266183, 0.9807789432150977, 1.2111220402376992, 15.74062626702445, 53.99294696535383, 54.96383612496512, 54.12417759214129, 56.732517446790425, 57.16910055705479, 55.39468697139195, 51.203012466430664, 45.28665958132063, 54.914139134543284, 29.40458188738142, 45.96268456322806, 45.26266050338745, 42.48443719318935, 24.643245424543107, 0.1472983903118542, 0.11020454325314079, 0.03296766882496221, 0.05908501095005444, 0.06968031491019896, 0.02623860990362508, 0.021540123004732386, 0.052950175678623576, 0.03600940221388425, 0.2570466526917049, 0.15698769395904882, 0.11827267067773001, 0.13534340395459107, 0.13851738721132278, 0.13404308658625397, 0.17355186013238771, 0.14408703334629536, 0.1050263371850763, 0.1269534948681082, 0.18723791145852633, 0.18558723931866034, 0.24456709091152462, 43.43027809688023, 64.04262338365827, 54.48632117680141, 39.31119837079729, 47.2646484375, 56.64320182800293, 22.884897811072214, 70.82432923998151, 60.25896099635533, 64.25486305781773, 59.326811517987935, 63.865819522312705, 55.06528329849243, 67.12574059622628, 16.73795853342329, 2.8226103569780077, 0.6090212230171476, 1.2031705869095666, 34.04177141189575, 49.58021552222115, 62.258145332336426, 59.21917002541678, 61.33461162022182, 56.400907720838276, 53.93838276181902, 49.70049926212856, 52.2900025503976, 52.10645546231951, 55.256073883601594, 54.554597650255474, 51.30024208341326, 53.561832087380544, 53.98011711665562, 55.04587697982788, 55.811592783246724, 54.2485260282244, 57.73865481785366, 57.38768393652779, 58.627127919878276, 53.65121371405465, 56.89360448292324, 55.42052384785244, 54.707725524902344, 55.82110486711775, 53.144898482731406, 47.54186766488211, 50.381158692496165, 51.44071381432669, 46.24386773790632, 44.10800191334316, 42.72710997717721, 52.062323978969026, 56.77614171164376, 54.81221948351179, 51.333312034606934, 52.91906118392944, 48.45257500239781, 41.28983340944563, 43.37336540222168, 45.53092002868652, 46.81207404817854, 53.26860073634556, 51.94415596553257, 51.87514645712716, 54.41426488331386, 54.46392018454415, 52.90942055838448, 57.62165757587978, 54.26341601780483, 54.33441965920584, 54.87617417744228, 52.36813851765224, 40.794339997427805, 44.93595273154122, 52.277502741132466, 47.35505839756557, 45.598637172154014, 49.65643031256539, 50.10539163861956, 43.83645241601126, 42.372154303959434, 45.91283471243722, 56.256079469408306, 59.01929119655064, 53.48687144688198, 57.16797494888306, 53.70814377920968, 56.77331379481724, 52.02440071105957, 53.29558406557356, 50.031813689640586, 49.58560732432774, 44.84033509663173, 42.331114768981934, 38.789183684757774, 42.54330927985055, 44.29716314588274, 46.32342113767351, 51.24911723818098, 53.03413724899292, 51.09324829918997, 51.173986366816926, 50.99737010683332, 44.97788511003767, 39.86257266998291, 46.4170446395874, 48.157526697431294, 45.292968545641216, 46.3756229536874, 50.059665543692454, 50.728068351745605, 50.688991682870046, 38.797994000571116, 41.90963356835501, 52.491024357931956, 50.55038554327828, 49.27915007727486, 43.56917953491211, 42.68777969905308, 43.106175899505615, 42.66102566037859, 45.02722774233137, 45.364656584603445, 45.61333608627319, 46.46847520555769, 48.708876677921836, 47.895134925842285, 49.25162478855678, 50.29846470696585, 51.5492342540196, 58.78074564252581, 60.1601437159947, 55.84931802749634, 56.32276133128575, 47.05840853282383, 41.052889415196006, 31.35462508882795, 2.891529755932944, 3.0995848774909973, 14.919387408665248, 61.544801575796946, 59.1608954838344, 60.786753109523225, 61.00338404519217, 61.893003599984304, 60.66951615469796, 56.44021020616804, 50.075941698891775, 64.41110719953264, 33.7731853212629, 55.697715282440186, 48.355407919202534, 51.715129443577354, 36.08654635293143, 0.2039087297660964, 0.1211295338081462, 0.141319601131337, 0.060230452700385025, 0.12843601245965275, 0.1324090656957456, 0.15280871891549655, 0.11290243919938803, 0.13768918093826088], [0.028728168457746506, 0.04405230509915522, 0.008417961420491338, 0.047203645642314634, 0.023049067838915756, 0.027503872456561242, 0.06568663420953921, 0.03783045449693288, 0.007338539431137698, 0.008751766722915428, 0.040234958686466725, 0.12189045654875891, 0.06342637977961983, 9.449143614087786, 47.1352139200483, 41.212114334106445, 38.95515530450003, 21.947184562683105, 49.65100376946585, 25.839964934757777, 43.360076972416465, 53.16472169331142, 47.57558379854475, 59.374531745910645, 48.79255035945347, 53.29128313064575, 46.26584489004952, 51.09181349618094, 0.1603026632219553, 0.46839598034109386, 0.17272028832563333, 14.228144134793963, 36.481030327933176, 52.88821118218558, 57.038839203970774, 55.62524904523577, 53.33612333025251, 53.459377425057546, 54.60354423522949, 53.834507192884175, 53.91733666828701, 50.22177049091884, 52.16939224515642, 49.82052591868809, 51.850080830710276, 49.41458436420986, 49.94952964782715, 51.72345685958862, 53.54221384865897, 51.822013582502095, 50.853094237191335, 50.175464221409385, 53.557235854012625, 51.75176729474749, 50.43784557070051, 49.76566294261387, 49.99569347926548, 46.05929579053606, 46.89952754974365, 43.230197770254954, 43.31640059607369, 43.85721363340105, 38.89135694503784, 39.06596864972796, 40.17042997905186, 47.61638362067086, 49.18353591646467, 45.194206850869314, 42.71199764524187, 38.38856445040022, 36.75594275338309, 37.400666100638254, 41.475680351257324, 45.64800412314278, 44.23744337899344, 46.226000445229666, 45.33223976407732, 46.21286834989275, 46.54733031136649, 48.05927569525582, 47.37429101126534, 49.652139799935476, 48.237017563411165, 49.674408776419504, 41.913392543792725, 36.59823601586478, 41.41248648507254, 40.11607769557408, 43.48436982291085, 42.84258556365967, 42.29341384342739, 42.94524867194039, 39.15980407169887, 39.36069733755929, 39.088828223092214, 47.59100532531738, 50.81388555254255, 47.93051862716675, 48.9351030758449, 48.317085129874094, 49.69825846808297, 48.986165387289866, 51.01185015269688, 48.49927731922695, 49.03466728755406, 46.48164551598685, 37.328849520002095, 35.5025954246521, 36.36489118848528, 35.281479426792686, 38.575252124241416, 45.589969294411794, 46.381372588021414, 46.949127265385215, 48.13090467453003, 41.98413215364729, 36.47342899867466, 38.36384275981358, 41.612764835357666, 43.68932778494698, 40.200626850128174, 43.52201863697597, 44.69006640570504, 46.11972427368164, 47.78787211009434, 38.73351124354771, 46.14650610515049, 48.52301236561367, 47.42433193751744, 44.57723808288574, 39.58558620725359, 41.17085593087332, 47.38893781389509, 47.24060072217669, 47.7003630229405, 47.23535483224051, 48.84948737280709, 48.59810502188546, 50.82651390348162, 52.59173502240862, 51.644591331481934, 50.74323626926967, 51.84597097124372, 51.45489856175014, 58.83240549904959, 53.5283591406686, 48.4258313860212, 38.54107393537249, 23.915225335529872, 7.8922911541802545, 0.21276416815817356, 1.010021305509976, 29.456808022090367, 54.03701938901629, 46.195918219430105, 50.07811648505074, 45.1430333682469, 40.522641113826204, 53.048968178885325, 46.33819995607649, 53.90665033885411, 43.69662339346749, 27.484004259109497, 41.852404730660574, 33.79864699499947, 50.02135665076119, 10.589437672070094, 0.26544118938701494, 0.11462029309145041, 0.056136820398803265, 0.05924177968076297, 0.05862664018890687, 0.023240297666883895, 0.055810075253248215, 0.025079405766778758, 0.028886840479182344, 0.033350844335343154, 0.04019697429612279, 0.029047785592930656, 0.05376312169911606, 0.027279857512829558, 0.06405563279986382, 0.01673112141101488, 0.042403899266251495, 0.04483106991808329, 0.03072009960721646, 0.020996401019926583, 0.09625167160161904, 0.09888601595801966, 14.100979941231863, 58.69556072780064, 45.1466429574149, 45.16697686059134, 35.10187544141497, 50.829067366463796, 27.409915617534093, 49.12945808683123, 59.13141427721296, 54.523591314043315, 66.61217839377267, 52.36143698011126, 57.45048175539289, 49.60907139096941, 53.16388096128191, 0.4678014208163534, 1.8006359785795212, 0.19340138430041925, 17.571089233670914, 40.02384730747768, 54.100251470293315, 59.22279698508126, 58.495661054338726, 55.331013679504395, 54.28314195360456, 57.068980489458355, 55.916510581970215, 57.28093876157488, 54.49990490504673, 55.67226750510079, 53.04631396702358, 55.24282366888863, 51.38449246542794, 53.13259322302682, 53.912917613983154, 56.621478285108296, 54.51746995108468, 53.59142446517944, 51.41701698303223, 56.34184455871582, 54.611058712005615, 52.26382868630545, 52.287859031132285, 50.88222108568464, 49.11965765271868, 49.57386139460972, 44.57737704685756, 47.59194333212716, 45.375040667397634, 42.39182812826974, 41.105018275124685, 42.29728051594326, 50.55711139951433, 49.57028307233538, 49.059121472494944, 45.857968262263704, 40.956205231802805, 39.46887036732265, 40.369318689618794, 43.66363334655762, 48.62424067088536, 48.02553871699742, 49.20212582179478, 49.49942881720406, 50.08033990859985, 52.30774130140032, 51.424885817936485, 51.340565953935894, 51.21855558667864, 50.3284044946943, 52.43465709686279, 44.283273696899414, 37.06465816497803, 43.89470611299787, 45.87654774529593, 46.17721019472395, 45.527070726667134, 46.18040984017508, 44.992663928440635, 42.377775396619526, 40.47600827898298, 40.97579567773001, 49.590620449611116, 55.364055837903706, 49.559509890420095, 51.681336879730225, 51.23927164077759, 50.659826619284495, 51.094759532383506, 52.65426533562796, 50.86898824146816, 50.593103068215505, 45.62634311403547, 38.82857649666922, 37.87070478711809, 37.75717122214181, 38.03076696395874, 39.88552256992885, 47.17538145610264, 48.70621204376221, 47.51501982552664, 48.82086079461234, 43.1350109236581, 38.83047682898385, 39.63013458251953, 43.21811832700457, 44.949849128723145, 43.81183842250279, 45.44644035611834, 47.94744791303362, 48.10957717895508, 48.72395774296352, 41.726308822631836, 49.30453184672764, 50.24895531790597, 48.282038416181294, 45.44069766998291, 40.21472821916853, 42.790282998766216, 49.644093785967144, 49.87757757731846, 50.064835003444124, 50.3198755809239, 51.52949789592198, 53.7158145904541, 52.65040561131069, 54.77889244897025, 54.21314927509853, 54.80827638081142, 54.79090241023472, 56.06058495385306, 60.544462476457866, 52.7440047945295, 50.7576642036438, 41.50265325818743, 27.953184843063354, 8.70902497427804, 0.5293499752879143, 1.4947270963873183, 35.20247146061489, 56.94016783578055, 51.9926300730024, 56.98511225836617, 50.89649963378906, 45.46742738996233, 58.41704913548061, 52.450186320713584, 59.48491082872663, 49.61756556374686, 33.37548433031355, 47.57760572433472, 38.51867641721453, 57.99145460128784, 15.972980976104736, 0.3115896045097283, 0.14109804587704794, 0.0796976698828595, 0.0286566305107304, 0.05556709525574531, 0.06187358631619385, 0.07341622015727417, 0.0486504146164017, 0.08611411415040493, 0.07700052711048297, 0.11046314651944808, 0.16872895535613808, 0.17956653024469102, 0.1481708234974316, 0.12829966763300554, 0.15530135801860265, 0.12794448169214384, 0.13958460065935338, 0.25050666076796396, 0.1362411600670644, 0.3577179078544889, 0.389613287789481, 21.65997208867754, 69.57480689457485, 55.89550617762974, 53.75544016701834, 35.3444196837289, 61.867031233651296, 31.329594203404017, 55.55350889478411, 63.75234849112374, 58.4102121080671, 70.14383656638009, 57.881693908146445, 61.767790113176616, 56.15759570258004, 60.14875561850411, 0.9365726581641606, 2.4212066275732855, 0.41221708059310913, 20.411368642534526, 47.05104691641671, 51.53290946143014, 61.437250409807476, 60.00222505841936, 57.70151669638497, 56.68891750063215, 61.819755690438406, 57.68390996115548, 61.70782715933663, 55.525017806461875, 57.79764154979161, 53.81483336857387, 57.73009811128889, 52.58179562432425, 56.6205472264971, 56.491331577301025, 60.54667200360979, 55.74743659155709, 57.00029754638672, 54.97897277559553, 59.68781907217843, 56.30395255770002, 54.38737882886614, 55.94087444032942, 55.20277772630964, 51.66830553327288, 53.32136535644531, 46.73712035587856, 49.62760918481009, 47.730747495378765, 43.11505569730486, 45.002328872680664, 45.49654034205845, 52.302780287606375, 54.581181458064485, 50.128042766026084, 47.71570117133004, 43.604969705854145, 44.28833545957293, 44.33030257906233, 48.09940849031721, 52.443019253867014, 51.99850477491106, 52.77640771865845, 53.664915561676025, 52.03160946709769, 54.57807213919503, 54.393882342747276, 55.01092059271676, 55.334845611027305, 52.715819426945274, 54.57501840591431, 44.66194357190813, 36.97779178619385, 47.15039573396955, 47.366835594177246, 50.12178938729422, 47.019161633082796, 48.52818182536534, 45.877228668757844, 42.73191813060215, 41.597353730882915, 40.32600014550345, 50.47054031917027, 56.4759065764291, 50.7532069342477, 54.155826636723106, 51.47204671587263, 52.65729475021362, 52.78392914363316, 54.610610553196494, 53.38396167755127, 53.07508645738874, 49.89848123277937, 42.94960171835763, 38.55715554101126, 40.503391129629954, 41.688746861049104, 42.265412603105815, 51.33866562162127, 52.16514342171805, 51.303024836948936, 53.05048983437674, 45.09611218316214, 41.20934547696795, 42.95340585708618, 46.26291275024414, 47.99145432880947, 45.95673343113491, 48.91584266935076, 49.780646732875276, 51.330098492758616, 51.01802710124424, 43.04510818208967, 48.77695165361677, 52.80198403767177, 51.32160431998116, 47.12262725830078, 43.40374640056065, 44.72872270856585, 52.27782235826765, 51.31427049636841, 52.492737088884624, 51.59756244931902, 51.43459939956665, 54.987380095890586, 54.60834544045584, 57.710969720567974, 55.25956882749285, 54.18031208855765, 55.5582058770316, 56.350602763039724, 62.80920001438686, 55.461587701525005, 50.22535923549107, 43.372083459581646, 38.53494562421526, 11.47408492224557, 0.5471386664680072, 3.309197698320661, 37.45350020272391, 64.97057615007672, 56.82088811056954, 62.346623693193706, 55.086054938180105, 52.13865688868931, 62.76053483145577, 57.67571456091744, 64.760073525565, 55.224372727530344, 41.43806627818516, 57.45235429491316, 42.509839807237896, 71.14234828948975, 23.558881759643555, 0.40517130866646767, 0.264801059450422, 0.18425102744783672, 0.08940957553152527, 0.2394742513341563, 0.1679176174636398, 0.12424394169024058, 0.10910018679818936, 0.153091233755861], [0.03204309700855187, 0.01084138740718897, 0.02261496827538524, 0.04761414575789656, 0.06330646907112428, 0.010633016088312226, 0.04923771381644266, 0.10141337569803, 0.03227576327377132, 0.07188465126923152, 0.09959488827735186, 0.07384879980236292, 0.1228890565357038, 2.419566635574613, 39.41257953643799, 39.965718678065706, 31.62114061628069, 23.810017449515207, 44.461140632629395, 45.73619760785784, 35.51269115720476, 56.42577532359532, 35.43318292072841, 55.48289782660348, 51.615752833230154, 53.71344872883388, 40.289699281964985, 53.67468472889492, 8.690196224621364, 1.5429656164986747, 0.2563750387302467, 5.111310277666364, 30.596489770071848, 53.08919824872698, 56.37592894690377, 56.45732361929757, 59.35459041595459, 56.619032519204275, 57.187593187604634, 55.609903948647634, 54.84776994160244, 53.14711148398263, 55.72809975487845, 55.02290276118687, 53.61352321079799, 52.402372292109895, 51.59537724086216, 53.092547280447825, 51.67115429469517, 49.9339656829834, 55.63417053222656, 51.96457324709211, 52.1296763420105, 50.16486474445888, 51.26630360739571, 49.24086897713797, 49.058728899274556, 46.80062689099993, 45.9887090410505, 42.211671761104036, 44.04485321044922, 45.85302809306553, 41.83841453279768, 38.59770175388881, 37.36329174041748, 40.59490237917219, 46.91204125540597, 45.18419797079903, 41.381389822278706, 38.100332328251426, 39.16621378489903, 39.773805958884104, 46.05351141520909, 44.6489018031529, 46.01681103025164, 47.03844288417271, 47.10244968959263, 47.67116321836199, 47.36929178237915, 47.335141386304585, 49.03681428091866, 48.328268255506245, 48.3274553162711, 41.35160289491926, 35.16717113767351, 41.16072545732771, 37.59671647208077, 37.63726963315691, 39.268890789576936, 40.01575265611921, 39.201618330819265, 41.680662631988525, 40.10616609028408, 38.76577867780413, 36.56695522580828, 43.60137748718262, 49.28845024108887, 50.86817182813372, 51.79834801810128, 49.886877741132466, 49.832636628832134, 50.52657406670706, 50.007981368473594, 48.13588653291975, 48.30898700441633, 50.30025386810303, 42.134418215070454, 35.23686504364014, 36.04823398590088, 35.431459767477854, 37.42194843292236, 41.404009682791575, 45.99541752679007, 45.98954977308001, 46.47020183290754, 36.99516575677054, 36.096225193568635, 37.42012800489153, 43.78970840999058, 40.502216884068076, 40.56577205657959, 40.77126850400652, 47.626774651663645, 47.049594742911204, 45.15889957972935, 37.33190325328282, 44.55368716376168, 47.81756523677281, 46.034146785736084, 43.87989255360195, 38.70726094927107, 44.21570593970162, 52.36565801075527, 48.550989287240164, 50.378765038081575, 51.53518499646868, 55.9271274294172, 54.023477349962505, 55.659503664289204, 50.94282674789429, 55.85459518432617, 53.52911996841431, 56.23863254274641, 52.07882942472185, 55.963494300842285, 46.546051842825754, 51.269531045641216, 29.818861280168804, 16.86166947228568, 1.029859498143196, 0.8284862094691822, 3.1151735952922275, 43.85036618368966, 49.02693394252232, 49.21984372820173, 49.818462303706575, 47.22195175715855, 47.849464416503906, 47.3104544367109, 53.680410044533865, 53.993516717638286, 31.367826666150773, 29.218516077314103, 41.110146045684814, 37.61056423187256, 31.360069002423966, 1.6674569249153137, 0.05080378621018358, 0.020750097897169844, 0.0958768759987184, 0.0659440296835133, 0.024076173081994057, 0.03785617436681475, 0.01692935372037547, 0.0270802800077945, 0.054284022854907174, 0.06609778571873903, 0.0800389526411891, 0.030451925604471138, 0.03808028430544904, 0.020865034943978702, 0.05242187849112919, 0.035653473277177126, 0.015716214531234333, 0.02890050956713302, 0.05956193285861185, 0.07831681040780884, 0.1262944202337946, 0.20990586653351784, 3.9626284411975314, 51.48692280905587, 45.013126373291016, 32.25436816896711, 31.532297474997385, 53.42298970903669, 45.50460720062256, 41.655020305088584, 60.14270373753139, 42.584435667310444, 63.248902865818565, 53.8915935925075, 58.54082434517996, 44.597940240587505, 58.23950181688581, 10.639060837881905, 1.746224201151303, 0.44724199974111145, 6.5368370073182245, 34.36164215632847, 53.34879337038313, 58.451060567583355, 60.60920579092843, 61.38910634177071, 58.84922013963972, 59.559576170785085, 56.25510672160557, 57.748701913016184, 58.2907725742885, 57.779041222163606, 56.41566916874477, 56.35594245365688, 56.32549892153059, 53.52910607201712, 55.2423095021929, 54.53865500858852, 53.62150321687971, 55.70849888665335, 54.16269493103027, 52.95104374204363, 51.15728289740426, 51.86880622591291, 51.645088127681184, 52.448560442243306, 48.932414122990195, 48.02122041157314, 44.759138447897776, 44.091517312186106, 49.16331665856497, 42.72971207754952, 40.37533235549927, 39.919061524527415, 41.89272165298462, 50.65355587005615, 47.40936899185181, 42.701068128858296, 41.191429546901155, 41.04000398090908, 42.83238908222744, 48.04509442193167, 46.438577107020784, 48.47522265570504, 49.04561764853341, 47.940659523010254, 49.434473582676475, 52.27541133335659, 51.531384331839426, 52.61515392575945, 51.05261523383004, 51.89167274747576, 45.511850697653635, 36.199934005737305, 45.783202171325684, 41.902560302189414, 40.42537328175136, 41.780563831329346, 42.22611359187535, 41.81251859664917, 42.736952100481304, 41.7174985068185, 40.187852587018696, 38.64372662135533, 47.06813253675188, 53.671714373997276, 53.02443061556135, 53.19135413851057, 52.345400537763325, 52.95828029087612, 52.707957540239605, 51.82893398829869, 49.055220058986116, 49.19121020180838, 51.4643828528268, 44.73536171231951, 37.86737659999302, 37.83727700369698, 37.70476443426949, 39.48537233897618, 43.78608839852469, 48.906448704855784, 49.558540616716655, 48.59554808480399, 39.66732134137835, 39.529778276171, 38.218764373234336, 43.63536460059029, 43.388557638440815, 43.50200087683541, 42.31531803948538, 49.086872577667236, 47.874752385275706, 47.02066591807774, 40.33876051221575, 45.97244330814907, 48.910940715244834, 48.97287348338536, 46.176692553928916, 41.393403257642476, 45.93027469090053, 54.42110538482666, 50.976490770067485, 52.8175618989127, 52.6503187588283, 56.31437485558646, 53.523811544690815, 57.49226474761963, 54.83552026748657, 58.015794140951975, 54.4560478755406, 57.27704429626465, 54.97550215039934, 56.44840560640608, 47.78070156914847, 51.65133803231375, 32.392550468444824, 19.883963891438075, 0.5410469962017876, 2.1788241480078017, 5.261610669749124, 48.72548982075283, 52.78581557955061, 56.481169836861746, 53.20182159968785, 52.3550237928118, 51.67352363041469, 53.28131941386631, 59.7712391444615, 59.31155327388218, 36.73900999341692, 38.123792920793804, 40.61777237483433, 36.30245467594692, 42.28742797034127, 2.271675314222063, 0.12359476009649889, 0.03149512909086687, 0.05761849321424961, 0.012068575663891221, 0.08004862855055503, 0.047663051169365644, 0.04809309309348464, 0.05057539471558162, 0.01400702553136008, 0.12452132680586406, 0.11986003550035612, 0.1702172133539404, 0.20431191527417727, 0.15557959808834962, 0.1859568916261196, 0.20670979017657892, 0.22513272160930292, 0.1257521350468908, 0.2239906657487154, 0.18981220546577657, 0.35464045298951014, 0.4432837792805263, 6.500082339559283, 66.04298891339982, 52.88805832181658, 43.29666076387678, 35.448326519557405, 59.08267266409737, 54.80232177461897, 44.82311051232474, 66.80658204214913, 45.045341696058, 64.72186538151333, 59.28831154959542, 62.167110034397666, 48.936666420527864, 65.02486242566789, 10.629236085074288, 8.762759736606053, 0.5398362183145115, 8.005525946617126, 43.015064171382356, 55.14142165865217, 61.326801845005576, 60.60072898864746, 65.62317180633545, 60.39658396584647, 62.57007081168038, 59.47098663875035, 60.603758403233115, 58.48605864388602, 59.976106779915945, 60.245127132960725, 59.898509298052105, 57.39755385262625, 58.09752927507673, 57.501839365277974, 57.05730751582554, 57.19256462369646, 60.25503526415144, 55.738487311771934, 56.90376969746181, 53.33899641036987, 54.79218087877546, 54.26708814076015, 54.99899400983538, 51.858317920139854, 52.027298109872, 45.99443783078875, 47.819955417088096, 51.597875118255615, 45.63324614933559, 43.7858486856733, 42.32294716153826, 42.9394017628261, 54.24639293125698, 50.73494012015206, 48.254794529506135, 43.999307768685476, 43.79385301045009, 45.150850091661724, 51.047150475638254, 50.749368054526194, 52.606385299137656, 52.5265782901219, 51.903529848371235, 53.22502858298165, 54.65973779133388, 52.438499450683594, 55.66015679495675, 53.611629826681956, 54.20093086787632, 44.9435818535941, 38.532572814396445, 47.75903013774327, 44.84049490519932, 42.51850768498012, 43.40751927239554, 43.2643585886274, 44.524563789367676, 45.94317749568394, 42.81210381644112, 40.253971644810264, 37.47822189331055, 45.43850551332746, 55.53834792545864, 55.12066738946097, 54.84568200792585, 54.11436326163155, 53.30378988810948, 55.676533699035645, 52.75498989650181, 52.31268147059849, 51.49965190887451, 53.7812249319894, 47.61230502809797, 40.12753527505057, 41.67356504712786, 40.00028944015503, 41.95634283338274, 46.55221489497593, 50.03734792981829, 51.788398197719026, 50.382909638541086, 42.43985060283116, 41.63170562471662, 41.2849314553397, 46.8346973827907, 43.990500926971436, 46.01708548409598, 45.508067403520855, 54.40256759098598, 50.4328567641122, 48.180782318115234, 43.063555649348665, 47.27342401232038, 50.18925986971174, 47.56079455784389, 47.740996088300435, 42.41641432898385, 48.01309101922171, 55.33312593187605, 54.55917303902762, 53.08163513456072, 53.92504916872297, 57.4770690373012, 55.932081495012554, 59.33341230664934, 55.85237176077706, 58.467361041477744, 55.79966620036534, 58.93564878191267, 56.84296601159232, 55.98729188101632, 51.860996450696675, 51.26983329227993, 38.25500617708479, 25.453697204589844, 1.5643644396747862, 1.6040255171912057, 5.020256306443896, 53.2527414730617, 60.202937671116416, 61.38224152156285, 58.892118317740305, 57.048118523189, 56.90775448935372, 57.38978924070086, 64.03543894631522, 65.44659028734479, 43.738389015197754, 42.30172388894217, 53.27572611400059, 45.62253550120762, 57.089286599840435, 3.6595432417733327, 0.24717896218810761, 0.1091114097673978, 0.18769107785608086, 0.0919552082195878, 0.1594885704772813, 0.15050098060497216, 0.18227258218186243, 0.15080786842320645, 0.13756566042346613], [0.019054549147507975, 0.034530993151877604, 0.046037023421376944, 0.012330178054980934, 0.04128983636785831, 0.023643242295033166, 0.1278353732611452, 0.06321319764746086, 0.03610373554485185, 0.03796118783897587, 0.043308091283376725, 0.03226820100098848, 0.021336345367931893, 0.20167860229100498, 29.916257653917583, 44.50781863076346, 43.965692383902415, 38.39320584705898, 29.566700731004985, 56.19275706154959, 36.0991712297712, 52.13967479978289, 48.87258318492344, 46.987554277692524, 53.97718497685024, 51.775766372680664, 50.55169527871268, 51.660593032836914, 29.315287113189697, 1.7150833521570479, 0.49880873411893845, 1.3424936937434333, 22.17344743864877, 40.545153277260916, 50.93383925301688, 56.14150020054409, 54.375525202069966, 48.96218715395246, 51.5421644619533, 50.968274525233674, 55.010326521737234, 52.89460699898856, 55.51649931498936, 54.80230787822178, 53.37283066340855, 53.03808035169329, 53.776170117514475, 52.69862610953194, 54.11733709062849, 50.343495982033865, 51.344846044267925, 50.90435804639544, 53.44877447400774, 47.991562025887625, 54.30400391987392, 50.85054077420916, 50.843019349234446, 50.62202841894967, 48.077254159109934, 43.96916995729719, 42.856551442827495, 44.97061382021223, 43.67953429903303, 39.32767602375576, 39.3706818989345, 36.5584853717259, 38.24153709411621, 40.63915198189871, 38.28981665202549, 39.33861943653652, 38.469142709459575, 43.9948296546936, 44.9123010635376, 44.0592359815325, 48.71186440331595, 46.59035703114101, 47.04639857155936, 47.91991567611694, 47.95314196177891, 49.69543749945504, 47.93691444396973, 50.2647624697004, 42.82316882269723, 38.27175828388759, 38.64381347383772, 36.35384007862636, 34.874287196568076, 36.102152006966726, 35.78826366152082, 37.2424556187221, 37.465468474796836, 38.24060256140572, 39.20144809995379, 40.63741493225098, 40.157263142721995, 40.17855589730399, 46.61043037687029, 51.700604234422954, 49.76781688417707, 50.736600739615305, 51.25151089259556, 50.27928420475551, 46.877251625061035, 49.17300592150007, 48.19035693577358, 48.65232528959002, 45.40269797188895, 39.93658140727452, 38.61007649557931, 37.0626779283796, 37.83645364216396, 38.48815992900303, 41.59710706983294, 46.67075463703701, 39.23229810169765, 33.94454179491316, 35.97203309195382, 37.45026581627982, 41.325151102883474, 40.847017765045166, 40.44337259020124, 40.87825686591012, 47.07063736234392, 44.69497878210885, 49.74497815540859, 33.80128036226545, 41.56098338535854, 53.309397084372385, 47.718219893319265, 46.114401953560964, 38.53624146325247, 46.12089157104492, 49.89704295567104, 50.36011259896414, 48.92099128450666, 52.025904996054514, 50.94207286834717, 51.87206840515137, 51.77513408660889, 54.83089624132429, 54.38054180145264, 56.853770460401265, 55.32025786808559, 55.73942184448242, 52.13867425918579, 50.8081567628043, 40.364722456250874, 24.465203046798706, 6.399215340614319, 0.28177974266665323, 0.9698437814201627, 8.847236803599767, 47.816790512629915, 47.85143423080444, 49.12812055860247, 48.286315032414024, 51.442673206329346, 51.62559495653425, 53.191034521375386, 42.96776778357369, 54.041031973702566, 31.074303490774973, 41.29385641642979, 36.05489730834961, 50.88075501578194, 24.40378097125462, 0.30945213777678354, 0.03355420806578227, 0.09312701784074306, 0.10252096197967019, 0.04988432376246367, 0.03792204993910023, 0.020656665321439505, 0.05522358011720436, 0.03548421271677528, 0.03595622203179768, 0.02454502720917974, 0.030457343706595044, 0.003609886875243059, 0.023599800786801746, 0.09546858112194709, 0.012619385795135583, 0.09048693986343485, 0.015870128325851898, 0.045189438188182454, 0.06993596654917512, 0.009974895643868616, 0.02215380873531103, 0.055779880444918356, 0.5698065672601972, 38.808385031563894, 52.42334542955671, 33.220383167266846, 46.91049875531878, 38.62186064038958, 59.04969651358468, 41.18598563330514, 55.669776575905935, 45.10279982430594, 53.01281670161656, 57.52186407361712, 56.63178941181728, 54.074689047677175, 57.21129696709769, 33.40224184308733, 0.607943709407534, 0.823109932243824, 1.8020449429750443, 26.07974205698286, 44.55964524405343, 53.70223433630807, 56.9850948878697, 55.588114397866384, 49.49070187977382, 52.66205079214913, 51.529091426304404, 56.67156784875052, 55.926001821245464, 55.47028684616089, 57.13533231190273, 57.897344725472585, 54.150080476488384, 56.89817639759609, 54.38607604163033, 54.78272785459246, 52.18704414367676, 51.302211897713796, 52.60908120019095, 54.219583306993755, 53.297321115221294, 55.36993401391165, 51.888650281088694, 53.40219027655465, 52.421306133270264, 50.56402485711234, 47.52201318740845, 46.794800826481406, 48.327351093292236, 46.870133195604595, 40.65033858163016, 41.82352106911795, 38.72513519014631, 41.824212414877756, 42.559154646737234, 40.525326592581614, 41.75929192134312, 40.804911681583945, 46.14741284506661, 46.43277188709804, 48.05951540810721, 50.98417200360979, 50.340383189065115, 49.54435239519392, 51.74482604435512, 49.75648437227522, 53.059188979012625, 50.59593445914132, 53.07816103526524, 47.791905539376394, 39.50648096629551, 40.99888801574707, 41.40720585414341, 40.110998562404085, 41.021042346954346, 38.85117203848702, 39.68473700114659, 40.19088200160435, 40.783611978803364, 41.4621695790972, 41.92471463339669, 41.24947827202933, 42.635577883039204, 50.0497122492109, 53.12799004146031, 53.989604881831575, 54.755164350782124, 52.48400667735508, 52.30710554122925, 51.19215243203299, 53.781426429748535, 49.67917176655361, 50.14020906175886, 46.996576513562886, 41.21370547158377, 39.71291542053223, 37.729951654161724, 39.14568880626133, 41.1558130809239, 43.73923669542585, 48.072115966251914, 41.27720158440726, 36.27245582853045, 39.085020610264365, 39.73013653073992, 43.874299253736226, 43.666930266789024, 42.941093649183, 42.520661626543315, 48.50344623838152, 45.36245400565011, 52.47590160369873, 37.26513106482369, 42.1004832131522, 53.27559062412807, 48.60430976322719, 48.89657531465803, 41.504108905792236, 48.79181385040283, 51.50369923455374, 53.1828738621303, 52.077373777117046, 53.376968315669465, 50.25298874718802, 53.46121522358486, 54.12115512575422, 55.8714793069022, 56.72759812218802, 57.84094272341047, 58.60795783996582, 58.49994114467076, 53.93084396634783, 51.85500710351126, 42.52456651415144, 28.556483030319214, 8.082359995160784, 0.6543283089995384, 0.32150120979973246, 11.901674457958766, 53.16195978437151, 52.399363722120015, 56.65023340497698, 52.049382959093364, 58.503456933157786, 55.06935494286673, 60.573109899248394, 48.646791049412315, 61.565166745867046, 35.740776198250906, 53.004944392613, 38.1762170791626, 54.06795971734183, 31.266334329332622, 0.3421173564025334, 0.06097421529037612, 0.08377478324941226, 0.005492171006543296, 0.055070692606802495, 0.03267335765329855, 0.04792427018816982, 0.01883672413948391, 0.06505149150533335, 0.02783129783347249, 0.1498506319309984, 0.11269494997603552, 0.10936412334974323, 0.09296362660825253, 0.19376943526523455, 0.12966082245111465, 0.26655561530164307, 0.2614204894219126, 0.1553535780736378, 0.19550233227866037, 0.14424492844513484, 0.13517336307891778, 0.2070226762443781, 0.777262949517795, 51.13886669703892, 63.87560258592878, 60.16929449353899, 51.23114224842617, 41.92325551169259, 64.74063246590751, 44.49717051642281, 63.10820879255022, 56.835246562957764, 56.465320995875764, 60.8760860988072, 61.63209179469517, 57.42832742418562, 62.53772694723946, 36.58288744517735, 5.042414111750467, 1.9635665672166007, 2.519891675029482, 32.77683448791504, 49.45197262082781, 54.625576972961426, 57.85317155293056, 56.56471497671944, 49.668318680354524, 53.49710961750576, 53.126034123556956, 56.751829964774, 57.47151047842843, 59.47627421787807, 60.1830449785505, 58.313437598092214, 55.599665778023855, 57.40654829570225, 57.94749334880284, 57.45592219488961, 51.811945642743794, 52.05738033567156, 54.2349978855678, 56.3689911706107, 54.76734454291207, 60.49131570543562, 55.59490973608834, 57.19005284990583, 55.95982912608555, 54.540346894945415, 49.360093116760254, 48.78486565181187, 49.56777129854475, 47.781445026397705, 42.037751402173726, 45.22499431882586, 41.53559466770717, 45.364819867270334, 45.486131940569194, 44.18707588740757, 43.76302037920271, 43.15613692147391, 48.99447543280465, 49.4233113016401, 52.155426365988596, 55.98491907119751, 54.53738348824637, 51.92136240005493, 54.54082632064819, 52.63004044124058, 55.1988068308149, 52.4669314793178, 56.281308378492085, 46.27941124779837, 40.93977274213518, 45.34246056420462, 43.58059889929635, 44.46884618486677, 42.617460455213276, 42.14563955579485, 41.46198892593384, 41.81827865328108, 43.35376453399658, 42.7638555254255, 44.186554772513254, 42.446760586329866, 40.92418793269566, 50.889408997126985, 55.91911268234253, 55.868710449763704, 57.38632556370327, 53.12774338041033, 54.948713370731895, 52.078349999019075, 55.333466393607004, 50.73327602658953, 52.31417533329555, 49.12527527127947, 43.85470185961042, 43.49159942354475, 41.248668806893484, 41.98192957469395, 42.52523354121617, 45.69877808434622, 50.74315289088658, 43.294882025037495, 39.90241016660418, 40.57502358300345, 43.472276483263286, 44.877501010894775, 46.82076277051653, 45.59956823076521, 47.467369079589844, 52.60179601396833, 48.59139306204659, 53.58825608662197, 34.56643336159842, 44.71503128324236, 57.04520027978079, 50.38593905312674, 50.793273721422466, 43.32217107500349, 52.11926794052124, 52.33782352719988, 55.29054389681135, 53.05964061192104, 54.33636168071202, 52.327467237200054, 54.32309756960188, 53.96456010001046, 57.47694744382586, 56.333975723811555, 60.06901809147426, 59.71939863477434, 59.03525120871407, 53.765389987400596, 52.36144045421055, 42.97946160180228, 37.97996868406023, 10.013745546340942, 0.6994808518460819, 2.174906232527324, 12.737924899373736, 59.832105364118306, 57.983102866581504, 61.533712250845774, 57.768174239567344, 64.17368030548096, 61.79588862827846, 62.927729334150044, 53.02497604915074, 65.88858604431152, 43.04032434735979, 53.8955888066973, 46.655718735286165, 63.02259308951241, 44.389855589185444, 0.407961010400738, 0.1339356880635023, 0.19697494325893267, 0.16801958770624228, 0.14384391424911364, 0.20811295988304274, 0.21587611974350043, 0.1052353870389717, 0.1330551260284015, 0.06539071151720625], [0.03707735187241009, 0.07366153770791632, 0.05008264937038932, 0.07426052806632859, 0.058275118337145874, 0.017202906809481125, 0.04630144851814423, 0.05999480427375861, 0.05898818400289331, 0.053450652930353365, 0.0329332331727658, 0.011292102596988636, 0.025940665176936557, 0.035730581996696334, 5.637536874839237, 42.90314258847918, 34.72349739074707, 30.113190446581157, 35.498346601213726, 44.338240895952495, 43.3436062676566, 42.5122959954398, 72.63181972503662, 49.91553211212158, 57.23523003714425, 49.43667963572911, 52.35023648398263, 46.05795478820801, 49.63104854311262, 2.2122367322444916, 0.774344380412783, 0.5489628942949432, 7.910837633269174, 35.812523296901155, 54.02672563280378, 55.393554415021626, 55.75953687940325, 53.00791474751064, 52.76900093896048, 54.13201863425118, 55.148894446236746, 53.74311406271798, 51.26435463769095, 52.77230133329119, 53.47532006672451, 54.277757099696565, 53.58474029813494, 51.379833698272705, 48.85682119641985, 49.03944764818464, 52.146480560302734, 51.502914088112966, 51.85937057222639, 53.60757555280413, 50.8492032459804, 51.20096969604492, 52.095630168914795, 52.48811306272234, 50.674042633601594, 51.245219298771445, 44.23696742738996, 43.14408527101789, 43.84890358788626, 40.98548494066511, 37.81187091554914, 36.21899291447231, 35.86526012420654, 37.765283243996755, 37.992440700531006, 41.115041051592144, 41.407327447618755, 45.602257183619905, 46.718078817640034, 46.47918585368565, 47.5956015586853, 47.63035297393799, 47.61495576586042, 47.49518619264875, 48.6401173046657, 48.63913066046578, 47.92411586216518, 42.78423111779349, 37.328488213675364, 37.789018290383474, 34.90659284591675, 34.494404860905235, 34.79471295220511, 36.37673439298357, 36.41408443450928, 35.52326284136091, 36.610787936619346, 35.834844384874614, 36.025436946323936, 38.84832327706473, 39.460456098829, 40.227057797568186, 42.87925468172346, 47.79729734148298, 51.763607025146484, 50.99663012368338, 49.975053855351035, 50.085596220833914, 48.98118352890015, 50.15358434404646, 49.58582966668265, 49.676996980394634, 47.14134223120553, 44.65903227669852, 40.88216175351824, 38.42604303359985, 37.087601116725374, 37.594284602573936, 39.66711984361921, 38.24635566983904, 35.78380291802542, 36.88293497903006, 36.0359982081822, 39.6247809955052, 41.40433972222464, 39.94820574351719, 43.154333863939556, 44.36231640407017, 46.818014757973806, 44.61533852985927, 50.13097143173218, 37.398359298706055, 34.41603265489851, 52.179769379752024, 44.65553385870797, 47.061490058898926, 40.377670424325125, 39.10294696262905, 42.928284645080566, 51.45567328589303, 49.566284384046284, 52.463898590632844, 51.58286006110055, 52.509544781276155, 50.96388326372419, 50.69031878880092, 51.55642563956124, 54.5042336327689, 52.03179359436035, 55.718629360198975, 52.868922982897075, 55.91046217509678, 38.954790524074006, 12.952965566090175, 0.8155528977513313, 0.41653530459318844, 2.0992998438222066, 11.165267024721418, 53.10544661113194, 45.337996346609934, 51.34001704624721, 52.747610909598215, 47.05564314978463, 53.32788276672363, 40.55729872839791, 40.25874853134155, 49.74111843109131, 22.962130512510026, 41.35428837367466, 26.515305519104004, 44.67495059967041, 7.893638236182077, 0.2822241016796657, 0.11234794716749873, 0.04572908387386373, 0.04458897540877972, 0.012598360539413989, 0.021029868063383868, 0.04428694250860384, 0.03993258312610643, 0.0460550690601979, 0.029316152978156294, 0.010251604768979763, 0.060395173861512115, 0.04030702589079738, 0.08740463347307273, 0.09945291161004986, 0.05020528778965984, 0.05936392955482006, 0.10401508252003364, 0.0634288564324379, 0.046951973611222844, 0.06548860376434666, 0.05601451446169189, 0.05340178144563522, 0.05312698833378298, 9.995271154812404, 56.03673178809029, 36.42562886646816, 41.4198967388698, 47.303266525268555, 46.924860681806294, 46.75534200668335, 49.07488693509783, 73.86271395002092, 52.86716856275286, 62.61196150098528, 53.95606940133231, 59.28844356536865, 50.297988755362375, 54.04606246948242, 3.0614214624677385, 0.7660222298332623, 0.09916565380990505, 10.569859385490417, 39.1369549206325, 56.17854452133179, 57.70632137571062, 57.92537028448922, 56.41988672528948, 56.3844370160784, 57.19887358801705, 56.44497319630214, 55.69420644215175, 52.62800809315273, 54.69405494417463, 54.48595987047468, 56.143615927015034, 55.0522380556379, 52.31348051343645, 50.31570666176932, 51.88163954871041, 52.76469652993338, 54.246354716164724, 54.38013533183506, 55.57993289402553, 52.423717158181326, 52.05948911394392, 54.15232474463326, 54.15141453061785, 52.17846311841692, 51.4577751159668, 45.83620650427682, 45.10081263950893, 45.958814416612896, 43.07281412397112, 41.512186186654226, 38.48208720343453, 39.435070855276926, 39.03883940832955, 40.35771172387259, 43.90826204844883, 42.431728158678325, 47.407308850969585, 50.19432858058384, 46.959375858306885, 50.63887085233416, 48.44840260914394, 52.23410776683262, 51.02983556474958, 50.87805216653006, 51.90616321563721, 50.45590393883841, 46.67784874779837, 39.05928795678275, 40.0438094820295, 38.76978431429182, 38.51836722237723, 38.44632829938616, 39.687377316611155, 39.82344388961792, 36.788328307015554, 38.54794570377895, 38.58159235545567, 38.91841670445034, 41.183188983372276, 41.373559202466694, 39.936143670763286, 44.02616603033883, 52.46939808981759, 52.58178520202637, 52.73704269954136, 53.520243644714355, 52.443491731371196, 52.16707502092634, 52.460111822400776, 50.91405425752912, 51.33256162915911, 49.11843824386597, 45.68254361833845, 41.90371370315552, 39.56641265324184, 38.28065545218331, 39.36378928593227, 41.4525636945452, 40.52869299479893, 37.37059429713658, 38.32653093338013, 38.637681688581196, 41.94778265271868, 43.646255901881624, 41.08243315560477, 44.81701694216047, 44.07239934376308, 47.655501978737966, 46.22316905430385, 52.70618574959891, 42.06276144300188, 35.30735451834542, 51.92062241690499, 47.84303733280727, 48.818897928510395, 42.83607162748064, 40.20625836508614, 44.87109129769461, 53.24716206959316, 50.770087582724436, 54.04247719900948, 53.72667809895107, 52.866925375802175, 52.22018010275704, 53.14624990735735, 53.92806121281215, 58.03004837036133, 54.815301009586875, 57.37816490445818, 54.28919383457729, 56.126690115247456, 42.42318534851074, 15.374586480004446, 0.8000245967081615, 1.183956755059106, 1.3534138734851564, 13.756726230893817, 59.78121675763811, 50.780541147504536, 56.24375336510794, 58.57091004507882, 54.01276322773525, 58.627385003226145, 45.07979433877127, 45.37787553242275, 54.925655773707796, 30.075010095323833, 52.063164710998535, 28.154349088668823, 51.235460553850444, 11.107182690075465, 0.30493928279195515, 0.1228917163929769, 0.06952092703431845, 0.050505841483495066, 0.026009338009836416, 0.022941357190055505, 0.08007422289145844, 0.055421895547104735, 0.01554462150670588, 0.029670962332082645, 0.11029281387371676, 0.1508162279746362, 0.10545505596590893, 0.1936326561761754, 0.23152209232960427, 0.155250576457807, 0.11756997981241771, 0.2396473591881139, 0.17658861646694796, 0.1799666080623865, 0.09928528631904296, 0.161844349067126, 0.26033971884420937, 0.32512165552803446, 16.391879183905466, 68.48425238473075, 50.137676443372456, 41.88494661876133, 49.59807934079851, 57.728430543627056, 49.44163022722517, 53.33051265989031, 82.03778375898088, 59.0984103339059, 65.56548091343471, 58.75568349020821, 63.144930022103445, 53.90806777136666, 58.93455791473389, 3.050103498356683, 1.5837652214935847, 0.7716839260288647, 14.541029334068298, 43.80991724559239, 54.21903092520577, 59.33477415357317, 59.12714113507952, 57.798763683864046, 57.34019299915859, 58.214196477617534, 57.932304586683, 57.96984917776925, 53.40858261925833, 55.42210108893258, 54.17806087221418, 58.54442351205008, 56.163828236716135, 55.380356311798096, 51.622405733381, 53.418268408094136, 55.911528723580496, 54.62733834130423, 56.70184115001133, 57.802734579358784, 55.39485025405884, 55.563194683619905, 57.392189843314036, 56.95875426701137, 56.594404629298616, 56.92379787990025, 48.696904931749614, 45.89128140040806, 47.86582742418562, 48.894640241350444, 43.75581162316458, 39.88859714780535, 41.22750806808472, 42.98684058870588, 44.32665824890137, 48.15248925345284, 46.140145029340474, 49.73595939363752, 53.38790825435093, 50.35114942278181, 55.794941425323486, 53.175932611737935, 54.60728236607143, 52.55161612374442, 51.31255429131644, 54.850048950740266, 52.45998675482613, 46.31994356427874, 39.666359015873496, 42.50319732938494, 42.04750319889614, 42.16546276637486, 40.09851959773472, 42.07734571184431, 42.60548176084246, 38.62342051097325, 43.14986617224557, 40.04605375017439, 40.69278165272304, 41.7564640045166, 41.690977232796804, 40.85344137464251, 41.892461095537456, 52.48215498243059, 54.62401015417916, 52.4932165145874, 55.38829115458897, 54.82154744012015, 53.876258918217246, 54.128996167864116, 54.705307551792686, 53.095333508082796, 50.4944212777274, 47.51353291102818, 44.628244808741975, 42.17652082443237, 40.57885898862566, 42.12745612008231, 43.663657665252686, 41.881201539720806, 39.62055996486119, 41.01579645701817, 40.62698916026524, 44.78776502609253, 46.47452013833182, 44.72761099679129, 48.985477515629356, 47.567492621285574, 50.70116145270211, 47.42699657167707, 54.784266880580354, 39.350893429347444, 36.198134422302246, 56.108739444187705, 50.49061713899885, 51.64847537449428, 45.24220153263637, 43.70667743682861, 46.57953173773629, 55.00932250704084, 52.30311727523804, 56.42672027860369, 55.07296453203474, 56.17002602985927, 53.986863817487446, 54.438576630183626, 55.20361498423985, 58.89859403882708, 56.858776637486045, 58.606776646205354, 55.723069259098594, 57.301755564553396, 43.708574295043945, 21.707716635295323, 1.5646203288010188, 0.5851535094635827, 4.151996382645198, 15.093898364475795, 66.3100915636335, 54.54118415287563, 63.182867186410085, 63.17484201703753, 58.402054922921316, 63.891333307538716, 50.344312395368306, 49.84613350459507, 59.634797368730815, 36.940598079136436, 52.41329486029488, 36.956915923527305, 63.67338916233608, 21.178771121161326, 0.3350523140813623, 0.2625358652855669, 0.10866730859769241, 0.1562569388853652, 0.08337332122027874, 0.084808090302561, 0.1868101901241711, 0.11547223451946463, 0.14032727080796445, 0.1899767502077988], [0.034162518102675676, 0.038844277417021136, 0.04424220330214926, 0.014786353534353631, 0.030332975023026978, 0.05901935590165002, 0.08636508389775242, 0.02682215001966272, 0.07250497476863009, 0.02541311607430024, 0.05092714726924896, 0.03890726582280227, 0.0773744745446103, 0.043558816758117506, 0.7252807074359485, 29.320484365735734, 42.29365355627877, 25.656235456466675, 23.464427947998047, 38.99917909077236, 51.0387362071446, 37.372359139578684, 54.67734800066267, 55.51291404451643, 53.1592777797154, 49.72300795146397, 50.98873002188546, 47.49732971191406, 52.56712102890015, 8.541511722973414, 1.3078292395387376, 0.6403279602527618, 1.0769433145012175, 33.87277037756783, 57.132205622536794, 56.32653420312064, 54.93509142739432, 59.61950438363211, 58.52963079724993, 56.30791303089687, 58.87687397003174, 56.829535143715994, 55.54538297653198, 56.34309523446219, 56.38470452172415, 53.13903072902134, 54.824059213910786, 53.7942111151559, 53.0477557182312, 52.536309242248535, 49.864914485386436, 49.054775374276296, 51.188039098467144, 50.96261869158064, 52.60187591825213, 51.88601343972342, 50.63903413500105, 50.93736546380179, 51.12872232709612, 52.6337889943804, 49.23419870649065, 44.04145206723894, 44.10814435141427, 42.37601055417742, 39.41361481802804, 36.689587456839426, 37.754840101514546, 36.01774181638445, 36.090034348624094, 37.728520325251985, 43.98288222721645, 47.15583964756557, 46.93771832329886, 47.06293875830514, 47.185015133449006, 47.923903942108154, 48.80578667776925, 48.3542788369315, 49.77525840486799, 45.88659484045846, 41.63376229149954, 38.94852672304426, 36.46887445449829, 33.68190336227417, 34.24730954851423, 33.7639615876334, 34.66303069250924, 34.78451647077288, 34.77187074933733, 35.205469608306885, 36.01774181638445, 34.24007647378104, 36.76958901541573, 33.659578800201416, 38.19899327414376, 40.39157724380493, 39.707158837999614, 42.083328110831125, 49.60522903714861, 52.42683342524937, 50.21892867769514, 49.306310585566926, 50.506295749119346, 48.16764327457973, 47.41066483088902, 48.40955523082188, 47.04915005820138, 46.21464361463274, 44.13776452200753, 41.00861896787371, 39.23106827054705, 36.46585546221052, 36.85617051805769, 35.79401676995413, 35.36995083945138, 36.9793655531747, 36.860120568956646, 39.10440608433315, 40.07479149954659, 41.688371658325195, 47.66422891616821, 46.814985343388145, 48.22900629043579, 45.262525013514924, 48.7520249911717, 43.113961356026785, 30.83846426010132, 51.44903775623867, 47.45091574532645, 46.84078400475638, 44.486473764692036, 43.977010999407085, 36.53308970587594, 44.15559707369123, 42.01108769008091, 46.114144870213096, 47.862061500549316, 49.89485774721418, 50.14790766579764, 52.3823892729623, 50.20494542803083, 52.460726737976074, 53.240168707711355, 50.891580309186665, 53.410788672310964, 49.699293749673025, 28.786390236445836, 2.2342208325862885, 0.22385833784937859, 0.861191814499242, 0.47404177167585915, 19.66690390450614, 47.42580148151943, 50.683794430324006, 50.604987961905344, 49.89121689115252, 48.805109228406636, 54.24564252580915, 46.85018144335066, 56.98854466847011, 32.26903929029192, 28.44799038342067, 40.41578129359654, 31.354295049394878, 38.2507712500436, 0.7153566713844026, 0.01823519097108926, 0.16629692300089768, 0.03731458467830505, 0.055433698663754125, 0.022642406535201838, 0.07917578145861626, 0.04430815351328679, 0.046529185226453204, 0.017020499633092965, 0.0641978605251227, 0.01091388548125646, 0.03950986598751374, 0.020641065801360776, 0.03833830403164029, 0.041112755691366534, 0.03441396282453622, 0.03650319928835545, 0.051433490456214974, 0.013222819709751223, 0.006381444583114768, 0.09838940974857126, 0.05613216904125043, 0.08452893421053886, 0.0498203005907791, 1.787224109683718, 43.155594961983816, 43.148955958230154, 25.5425420829228, 38.44389295578003, 43.24123150961739, 53.15133251462664, 40.92842633383614, 62.32647391727993, 58.814666748046875, 58.053008692605154, 54.49638564246041, 57.0500397000994, 52.214868204934255, 59.142941338675364, 10.28767740726471, 3.017784604004451, 0.9369329874004636, 2.0159501220498766, 37.00417062214443, 59.04149069104876, 58.539024761744905, 58.91693033490862, 63.32972431182861, 61.02484008244106, 57.11157989501953, 62.566353525434224, 57.77505643027169, 57.9429874420166, 59.01741518293108, 56.509389945438926, 53.5390385219029, 57.49714238303048, 55.55580874851772, 55.51883390971592, 54.85782745906285, 52.254691805158345, 50.32795633588518, 51.857213156563894, 51.7047175679888, 54.04247719900948, 53.393216678074424, 53.760734694344656, 53.06981972285679, 52.986309323992046, 54.0393956729344, 52.15524223872593, 45.390510831560405, 46.09514849526541, 43.43536417824881, 40.41301243645804, 39.091941016060964, 39.63865654809134, 39.02332408087594, 38.50923381532942, 40.79892928259713, 44.958596910749165, 49.376952920641216, 47.41777283804757, 49.191901547568186, 49.9447979245867, 51.287221159253804, 51.819929122924805, 51.186684199741904, 51.719180243355886, 49.80777250017439, 43.73307711737496, 40.94218029294695, 39.18915673664638, 36.06092487062727, 37.66549321583339, 38.3254782812936, 37.3136260168893, 37.81719323566982, 38.06067895889282, 39.576070649283274, 38.57554742268154, 37.57565648215157, 39.45912899289812, 37.548673152923584, 41.284959248134065, 41.99862609590803, 40.796921253204346, 44.400805950164795, 51.1032259123666, 52.353675842285156, 51.81350551332746, 52.41956908362252, 51.929981640407014, 50.041256291525706, 49.83126783370972, 50.39816093444824, 49.75807203565325, 47.66974231175014, 44.84091179711478, 41.80770002092634, 40.64680194854736, 40.32268238067627, 37.97501114436558, 37.39156743458339, 36.51261336462838, 38.60969434465681, 38.20749092102051, 41.3008463042123, 42.87942838668823, 43.88880014419556, 48.111015456063406, 49.007294859204976, 49.150267941611155, 50.08392865317208, 50.01381090709141, 46.40132086617606, 35.17429651532854, 52.03116478238787, 49.59023829868862, 48.48700680051531, 46.857174805232454, 45.73143809182303, 37.679865564618794, 45.21585396357945, 44.94877215794155, 47.51850087302071, 49.91165501730782, 51.151998792375835, 51.83405828475952, 53.58288165501186, 52.938981669289724, 53.99190126146589, 55.746783460889546, 52.6799840927124, 56.6899527822222, 52.84094606127058, 29.780573231833323, 2.5767731027943745, 0.43514344894460266, 2.3277097131524767, 0.1873789517475026, 22.509856632777623, 53.581099442073274, 57.53119897842407, 54.63013846533639, 56.671932629176546, 54.03405598231724, 60.66427721296038, 50.53005511420113, 63.78441442762102, 38.73308045523507, 38.38230412346976, 42.26564189365932, 32.178316661289756, 45.819645472935264, 0.9255723570074353, 0.03954107520569648, 0.03035690016778452, 0.044719413588089604, 0.03858578271631684, 0.031686659170580764, 0.027449494660166756, 0.04628668359613844, 0.01913831090288503, 0.05738036813480513, 0.08773535822651216, 0.10131749191454478, 0.10472877922334842, 0.20640363517616475, 0.09680368698069028, 0.17941293705786976, 0.17494627673711094, 0.2033833401011569, 0.11788777847375188, 0.14625168219208717, 0.10510392087910857, 0.23805125483444758, 0.1430424422557865, 0.1822453322155135, 0.2708506876868861, 3.983978952680315, 58.52046612330845, 57.79942723682949, 40.658335958208355, 35.81278038024902, 50.35926144463675, 58.67268030984061, 45.33387606484549, 66.17870807647705, 65.55542687007359, 61.739886147635325, 58.824234417506624, 59.601473808288574, 55.77223471232823, 62.74261542728969, 10.22541286264147, 3.020572134426662, 0.7587114764111382, 3.066634999854224, 42.84731033870152, 55.91226870673043, 59.8557778767177, 57.64303023474557, 67.5442236491612, 62.8527443749564, 59.919381686619346, 63.31618227277483, 60.05214786529541, 59.06630965641567, 62.133348737444194, 58.138968331473215, 58.12587097712925, 61.68168108803885, 56.63797330856323, 57.43623794828142, 57.83294187273298, 55.085096086774556, 52.50098460061209, 54.32805163519723, 52.97775261742728, 55.34195014408657, 54.0388571875436, 54.980226925441194, 55.36742224012102, 55.46896321432931, 59.04638222285679, 53.35971941266741, 49.897536277770996, 48.66884810583932, 48.608496052878245, 44.85945653915405, 42.52232224600655, 42.9903563771929, 41.738113812037874, 42.32749475751604, 42.6629398890904, 48.04805435453142, 53.160993984767366, 52.26479796000889, 53.54348884310041, 52.16731125967843, 53.78922230856759, 54.80668871743338, 52.90852771486555, 55.39237322126116, 51.67871740886143, 44.66138424192156, 42.24888631275722, 41.275012901851106, 39.173742158072336, 40.4641546521868, 41.143348012651714, 38.79421418053763, 40.06573799678257, 42.16674470901489, 41.30226721082415, 41.302986349378315, 39.697427885872976, 41.64392055783953, 38.42706094469343, 44.3058796610151, 42.98734780720302, 41.40061896187918, 43.86169522149222, 51.918346881866455, 56.64650222233364, 54.9563181740897, 53.60297237123762, 55.936490127018516, 51.48310824802944, 51.325415406908306, 53.449542249952046, 50.97329112461635, 50.317846706935335, 47.448223318372456, 44.2518504687718, 44.36110046931675, 41.50925057274954, 38.10494245801653, 39.65945945467268, 39.07285778863089, 39.97696781158447, 40.820819582257954, 43.72588225773403, 45.42155885696411, 46.00955016272408, 52.20958409990583, 51.93476894923619, 52.82319688796997, 52.15143462589809, 53.49917670658657, 45.50366571971348, 33.79097270965576, 56.09351594107491, 51.34975494657244, 51.98616130011422, 48.85108545848301, 49.44289479936872, 39.33361325945173, 47.01498923982893, 47.04695790154593, 48.86931753158569, 53.00001811981201, 53.85266283580235, 53.14812592097691, 55.20306955065046, 53.99465274810791, 56.19742625100272, 57.83814607347761, 53.212806701660156, 58.63727228982108, 51.042769636426655, 34.797839641571045, 4.756906986236572, 1.0589196873562676, 5.376114811216082, 1.7256801149674823, 25.61393482344491, 61.2311737877982, 60.82054219927107, 60.90446949005127, 60.45876339503697, 60.05252306801932, 64.99736840384347, 56.98118305206299, 68.0886150087629, 45.253582681928364, 40.82080915996006, 51.60896096910749, 43.98280232293265, 58.71089540209089, 2.1718286148139407, 0.2327303189252104, 0.28462408004062517, 0.13673687061028822, 0.10472074536872761, 0.1364329004926341, 0.22701880468853883, 0.27638555211680277, 0.1284579291407551, 0.12519694412393229, 0.1320524684020451], [0.06195866782218218, 0.05205186656011002, 0.036992674094757864, 0.06085486776594605, 0.05057894006105406, 0.01997472914601011, 0.008845655613445809, 0.020605904116694416, 0.02334718728837158, 0.04250070246468697, 0.09727625269442797, 0.011385658157191106, 0.04772879442732249, 0.04606708591537816, 0.03794205993680017, 18.593275206429617, 45.52000788279942, 32.65657506670271, 29.275585106440953, 34.41063043049404, 54.31766060420445, 46.93201732635498, 42.9340238571167, 61.53332315172468, 50.548339298793245, 54.438885825020925, 50.81518833977835, 49.887829644339426, 52.93597657339913, 15.292601210730416, 2.2608528435230255, 0.25453132337757517, 0.14439544108297142, 23.757139921188354, 55.272301401410786, 55.09767927442278, 53.28150701522827, 53.775867870875764, 51.65638242449079, 49.19275617599487, 51.99107020241873, 56.75057234082903, 53.66481481279646, 52.465958731515066, 51.92466974258423, 54.48170409883772, 52.35422822407314, 51.126342569078716, 50.56547008241926, 53.49302060263497, 49.52998699460711, 47.92406375067574, 47.516763823372976, 47.025265625544954, 50.28533261162894, 49.05425773348127, 51.6831225667681, 53.62428944451468, 51.48342786516462, 51.97161177226475, 51.28855521338326, 46.373423848833355, 41.39497355052403, 43.00358574731009, 40.874730655125205, 36.675889083317344, 37.40015540804182, 36.405086517333984, 36.23711381639753, 37.00837428229195, 45.6258602142334, 46.014862060546875, 45.556663104466026, 47.986708709171836, 46.40110547201974, 47.347891330718994, 47.82472882952009, 50.83693272726876, 47.52095358712332, 39.79264252526419, 38.97096940449306, 36.213698387145996, 34.33508614131382, 33.567087854657856, 32.94243090493338, 32.77884946550642, 33.185927050454275, 34.31083345413208, 34.1797001021249, 34.03615379333496, 34.18237863268171, 33.69170727048601, 34.90798943383353, 34.13005174909319, 35.43298142296927, 36.64696025848389, 39.77168328421456, 39.57928419113159, 43.27769218172346, 50.60866008486067, 53.328372614724294, 50.870982374463765, 51.524668897901265, 48.74978072302682, 48.92712654386248, 47.28699731826782, 49.71846382958548, 47.083964007241384, 46.80035243715559, 41.67507628032139, 38.7196113722665, 35.32898773465838, 35.42991379329136, 35.14577416011265, 35.6034311567034, 36.82924624851772, 38.21376861844744, 40.25602831159319, 40.71655491420201, 45.74117251804897, 48.83548675264631, 48.065994603293284, 47.487960066114155, 48.352430616106304, 48.22826978138515, 43.20783846718924, 31.49506902694702, 47.47390038626534, 46.304223264966694, 47.02737440381731, 45.67042595999581, 49.27895900181362, 46.62298229762486, 41.67392635345459, 39.58532564980643, 41.478706291743684, 37.85035351344517, 41.60816512789045, 44.505893979753765, 45.903544970921104, 46.851293155125205, 48.80187136786324, 47.76012447902134, 51.5247140611921, 53.49306576592581, 48.31385074343, 24.14469654219491, 2.4163602590560913, 0.1359120434416192, 3.604214519262314, 0.5387190239770072, 27.595995323998586, 52.199182646615164, 47.87761156899588, 50.538931437901084, 54.28129373277937, 49.966462407793315, 54.132279191698345, 49.32329545702253, 51.70278944287981, 25.19990382875715, 39.2553174836295, 36.61606856754848, 35.482671465192524, 17.69195314816066, 0.31113878584333826, 0.016291768290102482, 0.08103740335042987, 0.05347289191558957, 0.04365991508322103, 0.09689568954386882, 0.04614094105948295, 0.021921602177566717, 0.05280985124409199, 0.04152080290285604, 0.10035028774291277, 0.033393425800438435, 0.054070793225296905, 0.033498507126101425, 0.04994569725490042, 0.07635184084730488, 0.04057311339836035, 0.011183046752453914, 0.09993585890957288, 0.037698024817343266, 0.037673461849668195, 0.07457266774560724, 0.057884804638368745, 0.004877354242905442, 0.015387496545112558, 0.145264169467347, 25.452550751822336, 56.46320179530552, 25.239140306200298, 40.03499569211687, 44.21053300585066, 58.6497026171003, 48.08431700297764, 49.36567252022879, 66.56277670179094, 54.28899581091744, 57.992451667785645, 54.3898662839617, 54.71309648241316, 57.875572545187815, 16.591407128742762, 1.984044211251395, 2.0955219779695784, 0.44824061329875675, 27.24947476387024, 58.153632504599436, 59.79553699493408, 55.63104731695992, 55.945408139910015, 51.33161320005144, 52.15718078613281, 54.60641384124756, 57.66372891834804, 54.642718178885325, 55.280086857931956, 53.946901253291536, 55.84528112411499, 54.02559655053275, 53.283970151628765, 50.698632308415, 55.08399827139718, 51.201650619506836, 51.068606512887136, 48.44184003557478, 48.860913685389924, 52.342697688511436, 51.23770482199532, 53.51199265888759, 56.38589266368321, 51.86331714902605, 52.818096910204204, 53.342366286686485, 49.17895705359322, 43.63568074362618, 43.94620268685477, 41.74338402066912, 38.17731489453997, 40.83651556287493, 37.964630535670686, 38.877279894692556, 40.33947965076992, 46.51136643545968, 50.660375526973176, 48.45866162436349, 49.446625982012065, 49.17950248718262, 50.158434186662944, 49.2791292326791, 52.16008513314383, 48.926188537052695, 40.958442551749094, 40.00053610120501, 38.97611454554966, 37.041141986846924, 36.731568472726, 36.52123607907976, 35.88196359361921, 37.43316282544817, 37.16531324386597, 38.425306524549214, 38.45919983727591, 37.4580443246024, 36.13963059016636, 37.63325704847063, 36.65149743216378, 39.302565234048025, 37.96994243349348, 42.66001122338431, 41.31259570802961, 45.23809167316982, 53.981579712459016, 53.855893748147146, 52.304350580487935, 53.29779011862618, 49.05483443396432, 51.0862375668117, 49.31017030988421, 51.306592736925396, 48.65424646650042, 47.8794389452253, 42.98806347165789, 40.1442665372576, 38.040237358638215, 37.253079414367676, 36.9996577671596, 37.5334392275129, 38.87285736628941, 39.46698045730591, 41.51150873729161, 40.87872586931501, 46.85206093106951, 50.48637873785836, 49.62226602009365, 47.85357775006975, 49.74080228805542, 49.69695568084717, 45.85355615615845, 36.746284757341655, 47.893470832279746, 49.73154033933367, 50.15248652866909, 49.828634466443745, 50.93699720927647, 48.13921472004482, 44.48756463187081, 40.8438389641898, 42.902180262974326, 42.01951585497175, 42.521707330431255, 45.987215178353445, 47.218484606061665, 48.65382262638637, 50.55379363468715, 50.59419393539429, 53.27085542678833, 54.9750783102853, 50.88804715020316, 27.678649357387, 3.985370763710567, 0.587058455816337, 1.93244298015322, 1.0126090752226966, 29.97974681854248, 59.95612376076834, 52.3757016318185, 56.40558385848999, 59.64191927228655, 57.1801620892116, 59.223651613507954, 55.621608189174104, 58.11706413541521, 33.88335943222046, 50.196020466940745, 35.57171263013567, 42.435389859335764, 21.490165063313075, 0.27117277468953815, 0.04308076169607895, 0.07694703140961272, 0.080040404706129, 0.0790109924439873, 0.06715286017528602, 0.0821960765336241, 0.08821610707257475, 0.07069140672683716, 0.0732007852888533, 0.0426688671910337, 0.14444578838135513, 0.13986855399395737, 0.07372399007103272, 0.17115142036761555, 0.14004318176635674, 0.15584565166916164, 0.0670453802283321, 0.20312195484127316, 0.25125106796622276, 0.10340860792036567, 0.13954202937228338, 0.11693979719919817, 0.19104692206851073, 0.11746659821697644, 0.29953220007675035, 38.214657987867085, 66.98471300942558, 49.65468284061977, 43.908477442605154, 47.95711285727364, 66.42936434064592, 53.3859349659511, 53.497637680598665, 71.86471775599888, 60.610129901341026, 62.60306085859026, 60.51327201298305, 59.24010494777134, 61.597948346819194, 18.37316496031625, 3.447532206773758, 1.467441086258207, 1.4735579980271203, 30.581294059753418, 58.44008241380964, 58.29335730416434, 60.06528690883091, 58.402464866638184, 54.89804015840803, 54.65816402435303, 57.05345821380615, 59.66803060259138, 57.866817814963206, 59.02319608415876, 56.14659670421055, 58.24362557274954, 56.951569829668315, 54.43297290802002, 54.19148826599121, 58.29205799102783, 53.9052745955331, 54.49503074373518, 51.51393393107823, 50.29408386775425, 54.083186694553916, 53.745410442352295, 57.08317218508039, 59.20352268218994, 56.23869855063302, 56.76110233579363, 56.39037772587368, 50.997689723968506, 45.447586808885845, 46.431382247379844, 45.75069155011858, 39.896010875701904, 42.606173106602256, 42.59917974472046, 42.107174328395296, 43.78241280147007, 48.82614837374006, 52.796522753579275, 50.480820178985596, 53.31886747905186, 49.91273546218872, 52.576636586870464, 54.448814800807405, 57.14106804983956, 52.033450739724294, 41.04845993859427, 42.32488570894514, 41.31260960442679, 40.92894744873047, 37.63637331553868, 37.397827761513845, 39.43243053981236, 39.303524085453574, 40.90496226719448, 39.97969845363072, 40.75968585695539, 39.91285330908639, 37.499149867466514, 39.53165428979056, 39.21387495313372, 39.70575530188424, 39.45503650392805, 43.25347076143537, 41.85103246143886, 42.80218178885323, 53.06926039287022, 57.45626960481916, 55.39093147005354, 55.14274876458304, 51.559792041778564, 53.546799659729004, 51.18555164337158, 53.62495647157942, 50.00821760722569, 53.03046860013689, 46.75558866773333, 42.28836945125035, 39.67087534495762, 37.9062865121024, 38.84932729176113, 39.940764222826274, 40.905274936131065, 41.336386340005056, 43.87795400619507, 45.32742466245379, 48.95211574009487, 53.410555907658164, 51.15162011555263, 50.985314982278005, 52.82827602113996, 52.075615882873535, 46.85254035677229, 32.62470367976597, 49.21358687537057, 51.32533202852522, 51.89899614879063, 49.389414514814106, 52.92068706239973, 51.071726254054475, 47.41649089540754, 42.42616612570626, 45.397577149527415, 43.64268800190517, 44.72554390771048, 47.478302070072715, 47.93028933661324, 51.6153324672154, 51.870317459106445, 52.705598626817974, 56.040911129542756, 56.03669357299805, 52.858083793095176, 29.808282647814067, 5.41688380071095, 2.0317123276846747, 9.157038739749364, 1.6397700905799866, 33.8807156426566, 65.46637875693185, 56.08461529867989, 60.16340936933245, 63.9563684463501, 59.41841656821114, 65.50876276833671, 61.06645284380232, 64.4604741505214, 39.39843995230538, 52.442418234688894, 45.94519247327532, 51.92735522133963, 31.96025092261178, 0.2656836706612791, 0.1411516365728208, 0.15456190412597998, 0.09226046076842717, 0.17450217556740555, 0.13105084214891705, 0.159573156652706, 0.18233177757688931, 0.11673023844403879, 0.2605303871844496, 0.15013463954840386], [0.03339343258578863, 0.0623165543324181, 0.08189588585602385, 0.043549103529325554, 0.015778509134958898, 0.029865756165236235, 0.005345759264725659, 0.02642141402299915, 0.059880430411015234, 0.07347237571541752, 0.018033749191090465, 0.12748632127685205, 0.045408499826278, 0.016788199776783586, 0.12478277991924967, 4.984441816806793, 38.97983183179583, 38.425365584237234, 26.884687389646256, 26.789505754198345, 40.43388482502529, 59.76215784890311, 42.384598527635845, 54.54431431634085, 54.48242671149117, 52.64689677102225, 52.994661058698384, 51.2852999823434, 53.089264256613596, 18.999327932085308, 2.228384345769882, 2.155869254044124, 0.07909514435700007, 11.429209113121033, 55.110811369759695, 57.2596321105957, 57.85704517364502, 53.060734953199116, 48.49718591145107, 45.996570927756174, 51.02811588559832, 48.969347272600444, 52.0468955039978, 49.909789425986155, 50.77640349524361, 51.09579481397356, 53.18297461100987, 50.40587343488421, 52.51190022059849, 52.59518827710833, 54.490757601601736, 52.942316804613384, 52.537115233285085, 49.97095094408308, 51.28308350699288, 46.69798462731497, 47.905776091984336, 50.3184095110212, 52.88120739800589, 51.36655569076538, 51.29032005582537, 48.54875544139317, 44.760913712637766, 41.162771701812744, 41.601383686065674, 35.9444591658456, 35.81431940623692, 34.80183138166155, 35.43635824748448, 35.99364198957171, 42.99032858439854, 45.71176426751273, 47.71351248877389, 50.44070822851998, 47.68259995324271, 48.393689019339426, 46.58212341581072, 42.9705296925136, 40.321556772504536, 40.80704825265067, 36.549525669642854, 32.91224793025425, 35.94929163796561, 34.758967944553916, 34.420437812805176, 33.67865507943289, 32.13138852800642, 32.93883521216256, 36.040042059762136, 33.40939153943743, 34.427118505750386, 32.81517812183925, 34.86908994402204, 34.4008960042681, 34.489020006997244, 34.13295957020351, 36.821464266095845, 40.46595076152256, 39.94716351372855, 41.82662691388811, 48.981259959084646, 49.8378894669669, 51.03459160668509, 49.15902962003435, 50.038536071777344, 49.44874170848301, 48.046553543635774, 46.98963873726981, 45.45920072283064, 44.70522737503052, 38.73631831577846, 34.63474805014474, 33.99942214148385, 32.355190004621235, 35.11812380381993, 33.81407199587141, 36.02127497536795, 39.003942080906455, 40.79979433332171, 43.6510397366115, 49.032951082502095, 45.04341009684971, 48.48978955405099, 47.39495495387486, 47.74643652779715, 47.74229192733765, 42.51387323651995, 45.57888344355992, 46.912374768938335, 48.84683663504464, 50.83896507535662, 50.125874928065706, 48.08884028026036, 52.51586069379534, 46.79435961587088, 45.951584815979004, 46.07303932734898, 44.930178778512136, 44.529757567814414, 44.97569990158081, 45.115726947784424, 48.91650969641549, 50.858093466077534, 50.75098698479788, 48.55667291368757, 34.85664572034563, 29.558376789093018, 3.331108191183635, 0.0744692182966641, 1.0343583481652396, 0.63730788230896, 31.93416738510132, 49.876552718026296, 48.911072731018066, 50.440968785967144, 46.278104986463276, 46.61685398646763, 52.63482427597046, 52.548631872449604, 40.71194478443691, 23.69308795247759, 49.29828541619437, 28.73645874432155, 38.82881620952061, 3.87924701826913, 0.44824463022606714, 0.05112312514601009, 0.07028249438319888, 0.018133122340909073, 0.06823648738541774, 0.021433016252038733, 0.0644753881331001, 0.03818558615499309, 0.03742448699527553, 0.02025088950592492, 0.029339749033429792, 0.059832749755254815, 0.04345714167824813, 0.04959365971652525, 0.06290019622870854, 0.0641865629170622, 0.07004646597696201, 0.05190009863248893, 0.07171685634446995, 0.0015020497521618381, 0.039789972028562, 0.006869328648982835, 0.08895255505506482, 0.07208403199911118, 0.05560914067817586, 0.21614279757652963, 8.67517682484218, 52.84989881515503, 35.83850261143276, 31.694885322025844, 44.18832308905465, 43.468906606946675, 63.502387046813965, 44.38291086469378, 61.16471426827567, 57.90172209058489, 57.80699382509504, 56.85409355163574, 53.87367071424212, 58.85826669420515, 22.025075605937413, 2.3183711171150208, 3.0868101801191057, 0.2941420264542103, 13.342197571481977, 58.323074749537874, 61.31712300436837, 59.70056206839425, 58.494417326790945, 51.69357960564749, 50.32277645383562, 54.51049395969936, 54.24462808881487, 52.51900127955845, 53.55572462081909, 53.55262572424752, 52.741993291037424, 54.81047201156616, 52.523145880017964, 56.03486967086792, 54.25020054408482, 55.714085238320486, 55.723347187042236, 54.85106686183384, 53.382558141435894, 50.92494903291975, 49.33746978214809, 50.36892638887678, 51.06980855124337, 54.03943388802664, 51.22380147661482, 52.31588806424822, 48.763388769967214, 47.44306428091866, 44.05068622316633, 42.91691739218575, 37.78711448396955, 39.01994030816214, 37.34460456030709, 38.42591449192592, 38.57104846409389, 44.42774759020124, 48.17114864076887, 51.38764694758824, 51.36735820770264, 50.32869284493582, 49.743730953761506, 50.18046345029558, 46.3890711920602, 42.356531279427664, 42.23678255081177, 40.37754883084978, 35.52694191251482, 38.88103887013027, 36.71387141091483, 38.27132054737636, 36.885794162750244, 35.154070309230256, 35.81986059461321, 39.07539735521589, 34.78586094720023, 39.93518829345703, 35.85147142410278, 37.245908873421804, 37.756990568978445, 36.717317717415945, 36.16062804630825, 40.09945413044521, 41.63326896939959, 40.46340077263968, 42.628442083086284, 51.37183632169451, 51.211878367832725, 52.160637514931814, 50.23810917990548, 51.6712863104684, 48.64564112254551, 49.37193284715925, 49.29548529216221, 48.095896175929475, 45.66619103295462, 41.2807034764971, 37.009972367967876, 35.838926451546804, 34.2662399155753, 36.696806635175435, 35.595895835331504, 38.43259171077183, 40.813847064971924, 43.68814311708723, 47.04403270993914, 49.026760237557546, 48.2911752973284, 50.85044002532959, 49.3557574408395, 49.0832907812936, 49.964489119393484, 48.41471774237496, 46.09783397402082, 47.95044953482491, 49.83934164047241, 51.316083976200645, 52.95140157427107, 51.105008125305176, 53.32612834657942, 49.86404596056257, 48.57898357936314, 47.29863902500698, 46.6753682409014, 45.59386028562273, 49.098979813711985, 48.86749710355486, 49.0647668838501, 53.90031705583845, 53.13105072293963, 52.83942093167986, 41.39312185559954, 30.85813113621303, 4.501116871833801, 0.19714545910911901, 1.408912066902433, 0.616536731166499, 34.410745075770784, 55.74594620295933, 54.62368706294468, 56.21705143792288, 51.79345301219395, 54.49207081113543, 57.619809355054585, 58.35328551701137, 45.09066826956612, 33.7924040385655, 50.24456058229719, 28.268200533730642, 48.46747888837542, 5.065746162618909, 0.3166979146855218, 0.10915159939655236, 0.04177131124639085, 0.032823894039860795, 0.07148270748023476, 0.008012734370173087, 0.03987030718209488, 0.042222397934113226, 0.030832923017442226, 0.017111813483227576, 0.058071449265948365, 0.10345273983797856, 0.16594126208552293, 0.15281374007463455, 0.1522301592464958, 0.13415120435612543, 0.11789259607238428, 0.12679517907755716, 0.2346945149557931, 0.11173823595579181, 0.17319875050868305, 0.1152443824602025, 0.23675297307116644, 0.2877440926219736, 0.2795527907354491, 0.38954814842769075, 15.10885957309178, 66.54904011317662, 52.44489874158587, 38.7593446459089, 39.15297746658325, 53.51631096431187, 68.20842279706682, 50.43142543520246, 64.50089876992362, 64.16206986563546, 61.044079644339426, 62.76527350289481, 58.124356269836426, 64.03443840571812, 22.84656286239624, 4.078882660184588, 5.673205886568342, 0.7440792758549962, 15.705694198608398, 60.42864990234375, 61.05348055703299, 64.11877564021519, 59.96214784894671, 54.33285978862217, 49.937179224831716, 56.130410875592915, 56.14690589904785, 57.02691262108939, 55.1968126978193, 54.7537955556597, 56.62314237867083, 58.91418579646519, 54.55141190120152, 57.52996914727347, 57.478823457445415, 58.935183252607075, 58.8059606552124, 56.20657008034842, 53.28496026992798, 53.89976119995117, 49.774070262908936, 52.92271246228899, 53.86646543230329, 56.74677515029907, 54.60224839619228, 56.54274477277483, 52.42228930337088, 50.187838963099885, 46.869240352085654, 45.6745844568525, 40.73530462809971, 41.15471179144723, 40.282365458352224, 41.22420767375401, 41.69947835377285, 46.68837179456438, 48.848816871643066, 53.03780589784895, 54.99285180228097, 52.27752358572823, 51.204409054347444, 50.84964098249163, 47.51104545593262, 42.39990540913173, 45.25056021554129, 42.26201145989554, 37.42570046016148, 39.97434834071568, 40.46209798540388, 40.62128816332136, 38.271278858184814, 37.38553639820644, 38.2378580229623, 41.99355738503592, 36.6328067779541, 41.75234719685146, 36.83760493142264, 39.65558235985892, 40.19566931043352, 39.10340901783535, 37.79469844273159, 42.130885056086946, 43.11651134490967, 40.58537292480469, 42.1331501688276, 53.1582042830331, 52.11771501813616, 53.717388357434956, 52.60769850867135, 53.504995822906494, 52.978332792009624, 51.30107239314488, 50.02329519816807, 49.80172061920166, 48.06393446241106, 44.23367050715855, 37.75568430764334, 39.380975655147004, 36.76983567646572, 39.09301103864397, 37.44281039919172, 40.857794421059744, 44.95610250745501, 46.17987482888358, 48.912632601601736, 53.26611328125, 49.2565267426627, 53.31627927507673, 50.9829352242606, 52.15116712025234, 51.998449189322336, 42.8606230872018, 50.03599303109305, 48.160521371024, 51.21734312602452, 54.69914102554321, 55.16249207087925, 52.30760581152779, 55.86299555642264, 52.63906615121024, 48.805227347782676, 50.191716057913645, 49.13695171901158, 49.03919403893607, 49.405113969530376, 48.548956939152305, 51.13750485011509, 54.593573570251465, 54.46910354069301, 54.60710866110665, 42.01166091646467, 36.67874131883894, 5.922652295657566, 1.130345648952893, 4.332143196037837, 1.1995792367628642, 39.20883750915527, 61.08537973676409, 60.25141525268555, 60.08270604269845, 58.38818631853376, 57.18686362675258, 63.98305647713797, 62.38034330095564, 52.940756934029714, 35.02589341572353, 58.24001945768084, 37.2405344418117, 61.42361109597342, 9.679824675832476, 0.5466247169034821, 0.23491020766752108, 0.1764594776821988, 0.08532087957220418, 0.19362824569855416, 0.07069451441722256, 0.22849460478339875, 0.1373408753424883, 0.09285649271415812, 0.13654852285981178, 0.17119210532733373], [0.0909620432981423, 0.027618560141750743, 0.09559511433222465, 0.046073375935001035, 0.06139072722622326, 0.008480283165616649, 0.058306826278567314, 0.036007400535579236, 0.019770378147118857, 0.049307151697576046, 0.09482302969055516, 0.03470678800450904, 0.012875398754009178, 0.03254081940810595, 0.06485982571861573, 0.649655102619103, 26.83725551196507, 39.526165212903706, 33.187007495335166, 27.98254793030875, 35.01741313934326, 53.13040106637137, 60.85148252759661, 50.54566076823643, 57.387805530003135, 51.8120880808149, 54.69259582247053, 48.77374158586775, 53.571017605917795, 20.504502296447754, 1.0321598947048187, 4.139381493840899, 0.22512107794838293, 7.382770197732108, 53.213397298540386, 57.02596419198172, 56.6517515863691, 50.416135924203054, 46.21585260118757, 45.5858907018389, 47.52665458406721, 48.600675855364116, 50.61294364929199, 50.51766995021275, 54.083023411887034, 52.70501497813633, 54.63724299839565, 54.22035803113665, 52.5252685546875, 53.26345559528896, 51.19770751680647, 51.26566784722464, 52.368270533425466, 50.48794903073992, 51.74892200742449, 52.650607109069824, 50.84734460285732, 49.642457485198975, 50.67038093294416, 51.56678192956107, 51.49800518580845, 51.09665986469814, 49.090301513671875, 41.14624888556344, 40.1622554234096, 38.365013531276155, 35.24545301709856, 35.07388462339129, 37.22301108496529, 37.113465785980225, 38.94343021937779, 42.26437037331717, 45.382812227521626, 46.02333191462925, 47.50137703759329, 45.31154802867344, 40.44105189187186, 41.645685400281636, 39.877907344273154, 36.1658114024571, 33.409009388514924, 34.03925963810512, 33.00934205736433, 33.28584909439087, 33.60098464148385, 33.57995244434902, 33.298140457698274, 35.178389004298616, 33.64049904687064, 34.402077198028564, 31.75276381628854, 33.28389665058681, 33.86005170004708, 34.95749534879412, 33.79812240600586, 34.23501818520682, 32.99192987169538, 37.21013259887695, 39.73853342873709, 40.32109471729824, 41.4426451410566, 45.09851278577532, 49.190365995679585, 47.06617314474923, 49.7325165612357, 48.06296171460833, 48.2469048500061, 48.82151045118059, 44.840936115809846, 42.99542161396572, 36.76405477523804, 33.29283550807408, 32.54315962110247, 33.81652470997402, 34.82330131530762, 34.385835783822195, 37.61642851148333, 38.46175677435738, 37.985579354422434, 44.6180031640189, 46.7197185925075, 46.55955914088658, 46.64630740029471, 45.08445658002581, 46.62953444889614, 50.607972213200156, 49.59602962221418, 46.27945293698992, 49.32520273753575, 49.552572114127024, 49.74302223750523, 49.033892563411165, 50.06502260480608, 46.83086197716849, 54.654345989227295, 51.03498417990548, 51.3143538747515, 50.177625111171174, 50.392779554639546, 46.846405097416465, 49.76099722726004, 48.32057659966605, 52.289943490709575, 49.976641518729075, 50.75456878117153, 44.82489619936262, 23.433918407985143, 2.605850011110306, 0.32991672679781914, 0.4768923244306019, 1.1955189917768752, 30.64461646761213, 53.86479091644287, 47.130065304892405, 50.369589941842214, 46.303306102752686, 53.68942880630493, 49.55324608939034, 55.909538064684185, 32.19648967470442, 34.36190618787493, 45.94563715798514, 35.12394986833845, 32.145284925188335, 0.35243089869618416, 0.010065711618933295, 0.02683836531027087, 0.086643819298063, 0.03114251819040094, 0.039794694632291794, 0.035551669275654216, 0.018731537640893033, 0.12246631564838545, 0.04733568177159343, 0.05201222315164549, 0.03354964831045695, 0.01716833884295608, 0.10017247764127594, 0.03279866950054254, 0.023335204359942248, 0.038716095366648266, 0.0008979186428145372, 0.12718163191207818, 0.04808818389262472, 0.05462055926078132, 0.055789892229118516, 0.05006544850766659, 0.0031579146993213464, 0.08620011167866842, 0.0608273803123406, 0.04314694260912282, 1.8589136685643877, 37.28473540714809, 46.41511998857771, 24.290480170931133, 34.79592193875994, 40.544340338025776, 59.42970739092146, 64.5451796395438, 56.53672415869576, 62.672146797180176, 58.13603966576712, 57.982588699885774, 53.93368230547224, 58.147646631513325, 22.41587703568595, 0.7791681672845567, 4.109203730310712, 0.39190342490162167, 8.797954099518911, 56.11265475409371, 61.78149890899658, 59.44088704245431, 55.29132556915283, 49.81154884610857, 48.98266349520002, 49.87961687360491, 50.11449725287301, 54.98159572056362, 53.274916648864746, 56.74338790348598, 54.41445595877511, 56.35470220020839, 56.003307478768484, 53.21877520424979, 55.177284785679404, 55.69937590190342, 54.70198283876692, 52.683645793369834, 52.0242200578962, 53.174344948359895, 53.682588304792134, 54.24832453046526, 51.74585437774658, 52.32322188786098, 54.101811340876985, 53.37863935743059, 54.60471153259277, 50.86271401814052, 42.41574035372053, 40.40200996398926, 40.328355584825786, 39.311236585889546, 37.31638445172991, 38.835809571402415, 38.25776808602469, 42.94945928028652, 45.72722053527832, 48.64235462461199, 47.856673172542024, 50.692222595214844, 49.76752853393555, 42.225262437547954, 42.18921518325806, 42.69300127029419, 41.99037858418056, 36.968123367854524, 37.31340020043509, 36.64886406489781, 36.685519286564414, 36.40971401759556, 36.90983840397426, 37.41411086491176, 37.29546342577253, 35.45468759536743, 36.54004485266549, 36.88148627962385, 35.34378392355782, 36.853756019047324, 38.762773581913535, 37.50695269448416, 35.589097023010254, 37.31843417031424, 39.13985579354422, 42.08467606135777, 42.331451756613596, 40.15548092978341, 49.04712888172695, 52.23749153954642, 50.32264791216169, 50.84882804325649, 50.659131799425396, 50.58344854627337, 49.61614465713501, 45.32359273093087, 44.11944212232317, 38.38906819479806, 35.0073903628758, 34.167064802987234, 36.15711573192051, 36.38544743401663, 36.44037641797747, 38.552031244550435, 39.666675158909385, 40.151173046657014, 45.914231300354004, 48.868004322052, 48.04313850402832, 48.27997132710048, 48.99887364251273, 49.50745051247733, 52.78574957166399, 52.543570109776084, 48.21422399793352, 51.353291579655235, 49.44897099903652, 49.152550424848286, 50.38532761165074, 51.84868424279349, 50.29668596812657, 54.52261856624058, 53.06972939627511, 53.78542511803763, 51.57754468917847, 52.05821759360177, 48.76298924854824, 51.44036293029785, 51.98127671650478, 54.69411400386265, 52.08390160969326, 52.09002644675118, 51.34456116812569, 31.01822805404663, 3.7221261007445197, 0.10757067387125321, 1.3738725185394287, 1.3343486679451806, 33.50028787340437, 58.59525653294155, 53.00609431947981, 54.57117257799421, 50.22396959577288, 58.49381978171212, 56.02768523352486, 61.79015636444092, 37.67084680284773, 41.89668560028076, 38.55154834474836, 41.88893141065325, 37.50282893862043, 0.6171455670680318, 0.06693856524569647, 0.036389768589287996, 0.0784037307436977, 0.06996201550854103, 0.04306972871667572, 0.03345709613391331, 0.031405989945467026, 0.019706662012530223, 0.013921928758333837, 0.0053893844014965, 0.013503245510427015, 0.11450180730649404, 0.15500994079879352, 0.2480862992150443, 0.07030313541846615, 0.1250823124178818, 0.09003485912191016, 0.17256343817072256, 0.12398065653230463, 0.10930091781275612, 0.1467531874243702, 0.19716878714306013, 0.10214851410793406, 0.1728213086192097, 0.1823111501123224, 0.11440853588283062, 2.7346717842987607, 52.03652531760079, 57.20563071114676, 49.799108096531455, 40.60745082582746, 46.416231700352256, 64.28798512050084, 70.05073765345982, 61.076611110142295, 68.28929982866559, 60.77004964011056, 63.02262783050537, 59.15711566380092, 62.14673096793038, 24.730903897966655, 5.255249159676688, 17.079262733459473, 1.18365016579628, 10.778904625347682, 57.606378487178254, 63.617636816842214, 62.215747424534385, 57.047465392521445, 51.98711320332119, 49.13334560394287, 49.99059697559902, 52.975786277226035, 56.25605862481253, 55.76615851266043, 61.31950623648507, 57.74351855686733, 59.72493634905134, 59.7415633882795, 57.0908534186227, 58.165566035679404, 58.31954506465367, 56.72867161887032, 57.04283789225987, 54.578068665095735, 55.88327039991106, 56.96183926718575, 55.06053420475551, 54.82720674787249, 55.26081255504063, 57.19131047385079, 54.25121150697981, 56.77418231964111, 54.73910011563982, 45.10335220609392, 43.09336689540318, 41.787234101976665, 41.14610297339303, 41.955453463963096, 42.816891125270296, 40.852291447775706, 44.80170658656529, 48.69685629435948, 50.34879745755877, 50.60226774215698, 53.44289629799979, 51.64770759854998, 41.77279574530465, 43.49814462661743, 46.332359995160786, 43.86311265400478, 40.26718364443098, 38.97334916251046, 39.04046181270054, 39.55333614349365, 38.83196374348232, 37.43576839991978, 39.54359129496983, 40.46832357134138, 38.016029834747314, 39.43021059036255, 37.274139404296875, 38.19918087550572, 39.879984855651855, 40.680188042776926, 39.16680090767996, 37.793135098048616, 37.7541834967477, 41.42021288190569, 42.93968663896833, 42.09260743004935, 38.51878064019339, 46.355924810682026, 51.95467553819929, 50.66073683329991, 55.14917237418038, 51.69064399174282, 53.141955920628135, 51.31441988263811, 47.92535958971296, 46.98985065732683, 41.476462023598806, 36.38982479912894, 36.38972405024937, 39.311698641095845, 38.477949551173616, 38.31642825262887, 42.207548005240305, 42.677802085876465, 43.141889640263145, 48.436458655766074, 50.94347987856184, 51.28157227379935, 50.78905269077846, 51.198047978537424, 51.23601988383702, 54.30141918999808, 50.18338169370379, 50.99527522495815, 53.08568940843855, 52.178268568856375, 51.51151248386928, 51.42259291240147, 54.33338437761579, 51.04398904527937, 56.420988014766145, 53.00579902103969, 55.16110590526036, 51.1470308303833, 53.34759133202689, 49.744519574301584, 54.47760466166905, 53.472460883004324, 55.41075815473284, 52.69268887383597, 52.57597303390503, 48.352267333439414, 30.276073592049734, 5.137964870248522, 0.5971631993140493, 3.751702845096588, 2.6312778123787472, 37.506869316101074, 64.36488083430699, 57.46872772489275, 59.35033117021833, 56.52100733348301, 62.704087666102815, 61.49579593113491, 65.38254179273332, 43.13767555781773, 45.31934043339321, 54.89530256816319, 47.15686103275844, 50.73365122931344, 0.7888820746115276, 0.13125718464808805, 0.100906923945461, 0.225736834907106, 0.11649933297719274, 0.35290191056472914, 0.14549287648073264, 0.10081061268491404, 0.21653135386960848, 0.11698329129389354, 0.12022883285369192, 0.12587026799363749], [0.047087287064641714, 0.034477697618837864, 0.050634023533867936, 0.032192659697362354, 0.02393732955014067, 0.03778501979208418, 0.040498620431338034, 0.055018146854958365, 0.015158621594309807, 0.18219835045082228, 0.015439333227862204, 0.024296440816085254, 0.16643538485680306, 0.05896848613130195, 0.06318734546325036, 0.09544109366834164, 11.836309279714312, 48.15224954060146, 39.138931683131624, 31.133519513266428, 32.190872056143625, 43.26793691090175, 57.336079665592735, 56.51424673625401, 55.75113303320748, 52.891997950417654, 52.88186400277274, 52.940697874341694, 50.391174520765034, 22.60222772189549, 2.1122586684567586, 3.3865680609430586, 0.5312371168817792, 8.72112352507455, 57.833612373897004, 57.936970302036826, 57.34426464353289, 53.29837029320853, 47.719873564583914, 46.925718784332275, 49.44227293559483, 50.53221252986363, 51.56262690680367, 54.3603572845459, 55.938001360212056, 52.88384076527187, 55.85013444083077, 54.684890270233154, 54.23416757583618, 53.11456959588187, 52.46163347789219, 51.99387032645089, 50.94734655107771, 51.216491971697124, 50.65409435544695, 51.881340776171, 50.79300274167742, 52.148016112191335, 52.590557302747456, 49.5731075150626, 54.742181641714915, 52.043456145695274, 49.20915739876883, 42.91433613640921, 38.51955883843558, 37.324003151484895, 35.05540936333792, 34.39056403296334, 35.31983348301479, 36.90325151171003, 38.7540396962847, 41.566611426217214, 46.1221352985927, 47.78362676075527, 47.32396173477173, 40.73210845674787, 41.30610956464495, 40.55763919012887, 36.27439437593733, 34.738832065037315, 34.628557205200195, 33.29472541809082, 33.74363463265555, 34.401906967163086, 35.568919454302105, 33.038965702056885, 33.06840521948678, 33.09463119506836, 33.758767809186665, 33.345426423209055, 34.35810899734497, 32.73853949138096, 34.81641912460327, 32.04396629333496, 33.360483169555664, 33.91271904536656, 33.83786957604544, 33.33803701400757, 35.67551176888602, 40.72594887869698, 40.975927693503245, 40.58996568407331, 43.674503803253174, 50.36171415873936, 49.89694915499006, 49.49352284840175, 49.041532107761924, 48.26021065030779, 46.23503657749721, 38.523158005305696, 35.91039909635271, 34.61661672592163, 32.867737770080566, 33.84348719460623, 34.09635993412563, 35.17827435902187, 36.531071254185264, 40.10369253158569, 39.21307591029576, 40.192532198769705, 46.168187958853586, 47.68227686200823, 46.310361998421804, 46.16016626358032, 47.008801868983674, 45.948815958840505, 45.869373730250764, 45.239578587668284, 47.26013558251517, 46.95123951775687, 50.477714334215435, 47.275671754564556, 44.248577867235454, 39.89868245806013, 42.1649694442749, 47.91569117137364, 51.47734819139753, 52.53573254176548, 48.96320506504604, 50.6873380116054, 50.67893763950893, 52.16339594977242, 52.80343621117728, 53.91752079554966, 54.76167481286185, 54.06958906991141, 35.02654307229178, 3.295209888901029, 0.19165824140821183, 0.7774761180792535, 0.5712425102080617, 32.52784579140799, 51.49278014046805, 47.22531468527657, 51.52023594720023, 52.01188005719866, 53.82862206867763, 52.38459880011422, 46.17545230048043, 29.785082612718853, 58.749263354710166, 31.267894199916295, 37.81285408564976, 11.67022214617048, 0.34934285868491444, 0.008657499549112149, 0.10696128157100507, 0.06577339848237378, 0.08440203459135123, 0.0398563429314111, 0.030365853437355587, 0.08306664374790021, 0.036635055605854304, 0.00943246711644211, 0.024910011195710728, 0.03715459290625794, 0.031886209534215074, 0.019501009922740713, 0.06283967769039528, 0.030541750070239817, 0.005804153774598879, 0.060809962318411896, 0.07424837550414459, 0.06383242870547942, 0.025945591341171945, 0.05452212757830109, 0.03738718113995024, 0.008139310837058085, 0.009599193348549306, 0.01432686997577548, 0.13614757651729242, 0.04984622402116656, 17.129242862973893, 60.32362788064139, 36.46090834481375, 41.66056496756417, 43.075030599321636, 47.15565552030291, 64.130907194955, 60.58154501233782, 60.279152461460654, 57.75183555058071, 57.4639265196664, 55.21417277199881, 53.54215131487165, 24.40943854195731, 1.466118865779468, 2.611384685550417, 1.1873049182551247, 10.855720434870038, 60.71815354483468, 60.90876347678048, 59.592135429382324, 57.39173821040562, 49.86260420935494, 48.576072284153526, 52.591019357953755, 52.98979384558541, 55.32935306004116, 56.298182078770225, 57.1175970349993, 55.82086168016706, 57.37890141350882, 55.59384666170393, 56.63295323508126, 55.95345067977905, 55.33638116291591, 54.49536773136684, 53.52938747406006, 54.03672061647688, 52.36016893386841, 54.350928579057964, 51.376283168792725, 54.54803507668631, 54.5211455481393, 52.59473664419991, 55.57889066423689, 53.29610170636858, 51.06592450823103, 45.92312152045113, 40.63451405933925, 38.67283262525286, 37.749660219464985, 37.49853842599051, 37.762538705553325, 39.6783516066415, 39.18075636454991, 44.65208407810756, 47.90621035439627, 48.93409211294991, 48.30335896355765, 40.80030155181885, 41.784506934029714, 43.89996589933123, 41.85309260232108, 37.51693378176008, 37.94906309672764, 36.11333860669817, 37.36887461798531, 37.58007206235613, 39.287216663360596, 35.9602176802499, 36.54361622674124, 36.36400876726423, 36.641360010419575, 37.13119758878435, 36.54612452643258, 35.26080158778599, 36.96371820994786, 36.30829463686262, 36.13643094471523, 37.37415177481515, 36.563950129917686, 36.85788672310965, 37.20547383172171, 42.2744973727635, 42.11507443019322, 40.39697252001081, 44.49458231244768, 51.50706563677107, 52.629168442317415, 49.2744322504316, 49.755410875592915, 51.303865568978445, 48.555724484579905, 41.61845193590437, 39.31139292035784, 36.40940482275826, 34.852702617645264, 35.65639727456229, 36.64476810182844, 37.184452056884766, 38.02586153575352, 42.346577984946116, 42.75461094720023, 44.22254991531372, 47.180085386548726, 49.57343408039638, 47.49356031417847, 49.26852628162929, 48.77063921519688, 46.26875965935843, 46.51449312482561, 48.193011147635325, 47.683454581669395, 50.05122695650373, 51.16900450842721, 47.61576175689697, 45.88497591018677, 40.2357291494097, 43.61527735846383, 49.787765162331716, 52.861505780901226, 55.02376781191145, 48.71227087293352, 51.60682092394148, 52.122238295418875, 54.71911014829363, 54.2695095879691, 54.64382989065987, 56.36946712221418, 53.424080576215474, 37.859045709882466, 5.393313339778355, 0.13007566519081593, 0.35445743852428024, 0.9505220353603363, 36.072900090898784, 58.04424354008266, 53.169165066310335, 56.69451774869646, 58.72509057181222, 59.2971635546003, 57.99841322217669, 51.84889963694981, 34.21677221570696, 61.507670402526855, 30.49505649294172, 46.47580208097185, 13.902238879884992, 0.40218654168503626, 0.05455689231998154, 0.10015092058373348, 0.03302891678842051, 0.052665513274925094, 0.0508970067437206, 0.04278543272188731, 0.030221162629978995, 0.03767353988119534, 0.018460259340437393, 0.038699345729712925, 0.10492113711578505, 0.12770461956305162, 0.09114261503730502, 0.14281444091882023, 0.14511494604604586, 0.08532560217593398, 0.11559344801519598, 0.16059599391051702, 0.1178491155483893, 0.13077309062438353, 0.28971727245620316, 0.12640966262136186, 0.14014824612864427, 0.37213856833321707, 0.10141463098781449, 0.2879423605544226, 0.18871840701571532, 25.036859137671335, 73.70330142974854, 51.50929600851876, 46.15322501318795, 44.57072762080601, 54.97683620452881, 66.56029619489397, 68.83119678497314, 65.45389979226249, 64.30811405181885, 61.319256101335796, 60.52213096618652, 58.11694254193987, 28.60892629623413, 4.450187010424478, 8.769299728529793, 2.4152407305581227, 13.372337119919912, 63.34604563031878, 62.98821340288435, 62.3398630959647, 60.11524445669991, 53.18759863717215, 50.409910338265554, 55.53574582508632, 55.652437346322195, 58.79330103737967, 58.72565337589809, 61.890773228236604, 57.504556110927034, 58.46210125514439, 57.912821837833945, 59.78858879634312, 57.02450507027762, 57.17931093488421, 56.73009252548218, 56.10269798551287, 56.782106740134104, 54.78595529283796, 58.730836732046946, 55.09279121671404, 56.90203612191336, 55.86003909792219, 52.864945139203755, 59.15430859157017, 55.79166187558855, 53.343627384730745, 48.81931829452515, 43.26533133643014, 40.79109518868582, 40.06259741101946, 39.96919277736119, 41.817976406642366, 41.79957757677351, 42.50552845001221, 47.21622296742031, 51.1794650214059, 51.907250608716694, 49.17801209858486, 40.7862731388637, 43.5804043497358, 44.72787502833775, 43.39862905229841, 40.105262824467246, 40.77238021578108, 37.673382895333425, 39.44544798987252, 39.84586225237165, 44.03834274836949, 37.95131083897182, 39.17462110519409, 38.570475237710134, 39.037269115448, 39.31090307235718, 38.12815291540963, 37.63380595615932, 39.628303732190815, 36.944638456617085, 38.2264004434858, 39.23885720116751, 39.48444822856358, 38.07615607125418, 40.527761936187744, 44.12667172295706, 42.46224464688982, 40.377729484013145, 43.74579232079642, 52.38340023585728, 53.919570514133994, 50.30064991542271, 52.12155042375837, 52.40801770346505, 50.02807903289795, 42.46874816077096, 41.62650837217058, 39.08704253605434, 38.17675903865269, 38.78137738364083, 40.84613881792341, 39.388841015951975, 40.46916430337088, 45.0633271081107, 44.893672943115234, 46.79178878239223, 51.59202126094273, 53.85072776249477, 50.87900406973702, 51.45888335364205, 51.055870464869905, 48.95026057107108, 50.07818596703665, 50.87744072505406, 49.38766704286848, 50.9423507962908, 52.405432973589214, 50.39969996043614, 47.814348220825195, 43.11885983603341, 47.150447845458984, 51.002970354897634, 55.180915219443186, 55.9215202331543, 51.04938779558454, 53.47485106331961, 54.21523026057652, 56.1761473928179, 54.82682112285069, 55.45708179473877, 58.20052242279053, 54.83753524507795, 37.724525111062185, 5.703711083957127, 0.3276935475213187, 4.689697929791041, 2.2688749730587006, 40.51290321350098, 60.20306968688965, 55.976758411952424, 62.16907637459891, 61.56943988800049, 63.42228821345738, 61.845644678388325, 56.63561092104231, 42.24672542299543, 73.09811333247593, 39.97793013708932, 55.500285693577354, 24.018668379102433, 0.5577816782253129, 0.18135806625442846, 0.16341393627226353, 0.12668541925294058, 0.18591921936188424, 0.16647682977574213, 0.1416778676211834, 0.22258764531995567, 0.13664867462856428, 0.09932919432009969, 0.20799352414906025, 0.2392262060727392], [0.027801041956990957, 0.030393927823752165, 0.0752549482775586, 0.045801741403660605, 0.06480951234698296, 0.046493494284472296, 0.029444908390619924, 0.007235193458784903, 0.02231665713978665, 0.07454547884741, 0.026856382111353532, 0.03286328978304352, 0.04651593683021409, 0.045278115929769616, 0.052157755342445204, 0.0654505311644503, 2.7524376767022267, 39.38247994014195, 34.15004519053868, 21.267529147011892, 31.023981162479945, 44.936480794634136, 56.776732308524, 55.22224310466221, 57.35813672201974, 53.81860971450806, 54.029049805232454, 53.368446350097656, 52.80588892527989, 26.62042655263628, 0.39888036623597145, 0.791461104793208, 0.07049376304660525, 13.851123588425772, 59.046993664332796, 58.22115509850638, 55.091165338243755, 50.83193349838257, 46.471164158412385, 46.72720180238996, 47.98114320210048, 51.886336530957905, 54.08907529285976, 54.487214020320344, 54.57534497124808, 57.083335467747276, 53.970851693834575, 53.7280399458749, 50.80614178521292, 51.72414820534842, 53.61180700574602, 53.754800932747976, 50.87878172738211, 49.707878249032156, 46.46101631437029, 50.38186046055385, 49.061532497406006, 53.46906321389334, 52.37234912599836, 52.5201199395316, 54.22357504708426, 51.63889033453805, 49.97310488564627, 44.544338362557546, 39.474084990365164, 36.76033748899187, 34.715586866651265, 35.07112618855068, 33.79499919073922, 36.09326526096889, 38.63856758390154, 43.13229765210833, 48.32775408881051, 50.835164410727366, 44.04401247841971, 41.653675828661235, 43.73714876174927, 38.665113176618306, 34.77150249481201, 35.48141731534685, 33.3517666544233, 33.35398660387312, 33.78147452218192, 32.98869548525129, 33.37470613207136, 33.7851014818464, 34.616689682006836, 32.569072927747456, 34.7267039843968, 33.398017338344026, 33.36499602454049, 33.14673573630196, 34.37394741603306, 35.166247027260916, 33.928262165614534, 31.34769426073347, 34.55748755591256, 35.25737959997994, 34.52642910821097, 34.222633021218435, 36.88124309267317, 42.78652402332851, 40.78006839752197, 42.02955947603498, 46.27479069573538, 47.24941451208932, 43.35256249564034, 43.739257540021626, 40.771949427468435, 37.12779644557408, 35.820162841251914, 32.89966821670532, 33.372771058763774, 33.734233719961985, 33.33642503193447, 35.702172006879536, 35.59020178658621, 38.458407742636545, 39.04640599659511, 38.41390800476074, 42.487080982753206, 45.08588790893555, 43.251285552978516, 43.986220836639404, 44.07230206898281, 43.58676542554583, 44.415108816964285, 44.875784805842805, 44.62467690876552, 46.61954641342163, 47.87311608450753, 51.88724674497332, 50.00376033782959, 50.85339648383004, 52.75099120821272, 51.42691816602434, 51.05117348262242, 49.698119504111155, 50.02625513076782, 47.0753447668893, 48.69623095648629, 54.14210394450596, 50.33756569453648, 54.3573556627546, 53.611011437007356, 50.6845691544669, 31.596457140786306, 5.675639493124826, 0.2058990222534963, 0.38126453863722937, 0.35555842944553917, 25.417835814612253, 54.41434826169695, 47.17760140555245, 52.32454204559326, 46.314701148441856, 40.448535101754324, 59.86036368778774, 38.7533483505249, 46.097483089991975, 51.169348444257466, 27.778166668755667, 35.78236811501639, 1.2087071069649287, 0.028997930232435465, 0.08202652420316424, 0.09149579251451151, 0.03993978238265429, 0.08642301043229443, 0.02327838383748063, 0.02339203845310424, 0.012964188453874417, 0.023079174437693188, 0.12042745362435069, 0.07058840511100632, 0.009542260019640838, 0.06427410071981804, 0.060613865698022504, 0.013136787406568016, 0.026641059201210737, 0.09394801128655672, 0.05792362362678562, 0.04708601820415684, 0.06012720002659729, 0.08924781278307949, 0.02328649233095348, 0.024645572528243065, 0.01622454073679234, 0.05913560252104487, 0.04925277050850647, 0.06629129712070737, 0.06815299365137305, 4.985032847949436, 51.75501210348946, 36.48157576152256, 21.519986731665476, 46.811445236206055, 47.1952428817749, 61.63271018436977, 57.90688460213797, 63.84727478027344, 57.88992057527815, 58.412567547389436, 57.81657886505127, 56.035171917506624, 28.229153394699097, 0.5539087089044707, 1.9058255170072829, 0.6947986888034003, 16.030281032834733, 63.32559708186558, 61.37694699423653, 59.28289195469448, 53.23055240086147, 49.464076382773264, 49.56472798756191, 50.39474589484078, 54.08415944235665, 56.5342367036002, 57.790196555001394, 58.497231347220286, 59.30140890393938, 57.04998064041138, 56.038944789341514, 52.38781581606184, 53.498245647975374, 56.08353137969971, 55.06225388390677, 53.76536219460623, 52.83859409604754, 50.498767375946045, 52.75232178824288, 51.18283142362322, 54.292841638837544, 53.59680584498814, 55.26028101784842, 55.59656340735299, 54.11296319961548, 50.543718746730256, 45.773763043539866, 40.11349296569824, 38.85197802952358, 37.94720792770386, 37.03320366995675, 36.08767543520246, 37.76687090737479, 40.44031538282122, 44.99408483505249, 50.541290351322715, 53.7187363079616, 43.37267753056118, 43.230711936950684, 43.403940950121196, 41.519273349217, 37.272885254451204, 37.95327717917306, 37.36175618852888, 35.846698011670796, 36.051186970302034, 37.14809560775757, 36.50115578515189, 36.707003116607666, 37.230098247528076, 35.69532108306885, 36.848114081791465, 36.34154176712036, 36.233438219342915, 36.81190701893398, 37.02559539249965, 37.819479193006245, 36.28089788981846, 34.59949289049421, 37.60924754823957, 38.21793058940342, 36.75604002816336, 36.800842012677876, 40.11702612468174, 43.29931844983782, 39.71772357395717, 41.01275314603533, 47.023476464407786, 50.568430015019004, 46.983892577035085, 46.271507671901155, 41.06385367257254, 39.22714948654175, 37.17134428024292, 36.24568789345877, 36.18455416815621, 35.511020115443635, 36.28225973674229, 38.54296384538923, 36.72247328077044, 40.31377479008266, 40.44926813670567, 41.69986745289394, 43.328660692487446, 46.65621553148542, 45.51652683530535, 45.73319598606655, 45.544444697243826, 45.15459169660296, 45.91055222920009, 45.09202664239066, 45.97611543110439, 48.184485707964214, 49.94834150586809, 52.83505746296474, 51.45597553253174, 48.986978326525005, 52.193096024649485, 54.12982995169503, 51.782568659101216, 51.14759363446917, 52.57792895180838, 49.67769180025373, 51.165874344961985, 56.37079075404576, 53.98014143535069, 56.52314737864903, 55.70989547457014, 55.32842894962856, 34.701162406376426, 7.473569256918771, 0.14423700315611704, 0.4137903047459466, 0.2706285896045821, 28.37120062964303, 60.48713288988386, 53.07659074238369, 59.03240244729178, 53.720577580588206, 45.477147919791086, 64.96389198303223, 45.805196693965364, 59.104893003191265, 50.590014593941824, 30.092769690922328, 44.03365618841988, 1.4833340048789978, 0.05876895612371819, 0.13390866879905972, 0.03244569558384163, 0.044148752066705904, 0.06747589034161397, 0.032139045252863846, 0.017284186823027473, 0.0280872531168695, 0.10919106977858714, 0.050518577585795095, 0.024229126749560237, 0.032135862923626385, 0.13871019972222193, 0.12117556562381131, 0.1574891856206315, 0.13730909276221478, 0.27139989393098013, 0.160182725372059, 0.11733475886285305, 0.12017051955418927, 0.13787440742765153, 0.10068333308611598, 0.19504337119204657, 0.20538862821246895, 0.1968879279281412, 0.1425106879323721, 0.16069294299398149, 0.3885537146457604, 6.798011541366577, 64.10530308314732, 46.255464281354634, 31.096530778067454, 42.82785538264683, 57.768990652901785, 65.94369220733643, 67.08140414101737, 66.04479544503349, 63.704864501953125, 65.38275718688965, 62.44947092873709, 60.90797138214111, 32.593989167894634, 1.7290525968585695, 5.5559059636933465, 2.1132539979049136, 17.97193602153233, 65.69109739576066, 63.508612632751465, 61.63539913722447, 55.44594035829817, 51.67826577595302, 52.5869060243879, 53.13570601599557, 56.87158216748919, 58.555387769426616, 60.36346885136196, 60.03542355128697, 60.98258113861084, 60.03522900172642, 57.62334598813738, 55.00396892002651, 57.29825367246355, 59.33750479561942, 57.696566104888916, 56.23303576878139, 55.70279441561018, 53.43244273321969, 54.1649808883667, 54.92156328473772, 58.2199878011431, 57.158351693834575, 58.01926129204886, 58.90078966958182, 55.96845531463623, 54.4326046534947, 47.33843830653599, 43.85528203419277, 41.217078821999685, 39.59998982293265, 40.659468514578684, 37.63327094486782, 39.98988103866577, 42.24594027655465, 48.43249470846993, 54.02462032863072, 54.83659723826817, 43.89544609614781, 43.54646239961897, 45.93543372835432, 41.904352937425884, 39.42245987483433, 42.56349032265799, 40.8403822353908, 38.94240883418492, 38.36014631816319, 40.6499981198992, 38.02511460440499, 40.39110476630074, 41.091538769858225, 37.29172876902989, 38.34750059672764, 37.40943472726004, 39.24554484231131, 39.42469719478062, 38.207970346723286, 40.44160427365984, 38.74296774183001, 36.000791685921804, 40.19160461425781, 39.359634263174875, 40.10531841005598, 38.80604001453945, 40.497287137167795, 44.929987703050884, 40.39830657414028, 40.11282941273281, 46.787477425166536, 50.92878096444266, 46.808169160570415, 46.86162860052926, 43.40276323046003, 41.975776944841655, 39.58993230547224, 38.16740676334926, 37.56404256820679, 38.43675020762852, 39.30691828046526, 40.22783599581037, 39.826407296316965, 43.113943985530305, 43.35939604895455, 44.728368350437705, 46.01578269686018, 50.3346266065325, 48.6115254674639, 47.89049700328282, 49.06658731188093, 47.97431659698486, 48.564368043627056, 47.08375208718436, 49.14816263743809, 49.8992212159293, 51.70276165008545, 55.17322703770229, 53.426137242998394, 51.21572419575283, 54.13990136555263, 57.1758576801845, 53.46514790398734, 52.51583637510027, 53.81304768153599, 50.592432567051475, 51.07377249853951, 56.86216735839844, 54.77075958251953, 57.87612492697579, 58.740842138017925, 57.040503297533306, 36.627578258514404, 7.732272403580802, 0.5304628270012992, 2.3090765987123762, 1.3397714112486159, 30.819242068699428, 62.19251959664481, 57.08481543404715, 62.22864328111921, 57.057036536080496, 52.277200494493755, 67.98107079097203, 52.595733710697715, 56.79852533340454, 58.18814768110003, 38.14708675657, 54.402560642787385, 1.81794350700719, 0.22021609757627758, 0.18542578869632312, 0.11017183786524193, 0.22367194427975587, 0.20544291101396084, 0.08545198610850743, 0.1670394167304039, 0.11098565241055829, 0.17679717099027975, 0.17054737492331437, 0.1646837331354618, 0.1269037989633424], [0.027402144790227925, 0.03604008896010263, 0.05011117158989821, 0.015327968667926533, 0.043143560112054856, 0.03091062545510275, 0.02307437889144889, 0.053795545494982173, 0.025285536223756414, 0.012719768265794431, 0.05976617868457522, 0.03375106803806765, 0.06191712790834052, 0.08159016511802163, 0.09689285326749086, 0.07274964771100453, 0.14846502271081718, 15.310049874441964, 48.932362011500764, 34.89889076777867, 22.10025337764195, 33.74077197483608, 48.79471819741385, 60.72986820765904, 50.31788839612688, 53.693368434906006, 49.76109102794102, 54.27030863080706, 50.73220600400652, 29.082027401242936, 0.44160606073481695, 0.5451630439077104, 0.3100069894322327, 20.798402411597117, 61.757659639631, 56.71342032296317, 55.163360595703125, 51.29463488715035, 47.97600153514317, 47.66898495810372, 46.685415336063926, 50.85133981704712, 51.50029809134347, 54.10563632420131, 54.910050119672505, 53.23339768818447, 51.87730387278965, 50.530770778656006, 53.17208678381783, 57.81872238431658, 53.81223126820156, 53.10804871150425, 49.18830238069807, 48.96946539197649, 48.150151184626985, 48.19683960505894, 49.1365521975926, 50.46927227292742, 49.99311917168753, 54.20850093024117, 52.53750433240618, 52.65455715996878, 49.73163761411394, 43.446352754320415, 37.4399025780814, 36.75374712262835, 34.89103582927159, 34.91003220421927, 35.27683455603463, 38.729658467429026, 42.27943754196167, 44.38263293675014, 47.74183334623064, 54.15016038077218, 45.77727535792759, 45.05397483280727, 38.42346177782331, 34.81460564477103, 33.915425368717735, 32.76338972364153, 31.904307501656668, 34.131761005946565, 32.81258644376482, 34.590095451899934, 34.39735589708601, 34.027093342372346, 33.82162121364048, 34.98591695513044, 33.669678006853374, 33.07602391924177, 34.662735394069124, 35.198719433375764, 34.149548394339426, 33.62156867980957, 34.260879380362375, 34.42807388305664, 34.12270055498396, 35.424865927015034, 35.460871492113384, 33.35508441925049, 32.189909730638774, 37.763876233782085, 42.88461521693638, 45.001668793814524, 43.095277650015696, 49.45120831898281, 47.64014298575265, 45.842404297419954, 42.27498027256557, 36.042519092559814, 33.48196547372, 33.1527042388916, 32.116960593632285, 33.21173960821969, 34.699842248644146, 32.160550117492676, 35.2227463041033, 37.8853759084429, 38.69249255316598, 40.10047551563808, 38.12432098388672, 41.04510048457554, 41.025989464351106, 41.443180152348106, 42.519143445151194, 41.90092747552054, 41.032343591962544, 43.18663951328823, 44.32321541649954, 47.045394556862966, 49.40807042803083, 49.52508851460048, 51.91635969706944, 51.45733390535627, 55.08581175122942, 57.79537991115025, 49.04904311043875, 50.90313516344343, 46.56279352733067, 48.86428356170654, 46.43405382973807, 49.46283265522548, 51.47579179491316, 51.628238746098106, 49.232906341552734, 50.23891864504133, 36.874645778111045, 13.4742237670081, 0.148614924667137, 0.7266253467117036, 1.0766551813908984, 29.609522478921072, 54.273622921534944, 53.707970074244905, 45.74546997887747, 44.19465637207031, 56.49685192108154, 57.39704316002982, 31.73724501473563, 30.06987885066441, 21.2983044556209, 36.93652296066284, 17.45259118080139, 0.43489993629711016, 0.07506831722067935, 0.04880768207034894, 0.04773337114602327, 0.061269527301192284, 0.045453496876039674, 0.08502825456006186, 0.05200466427153774, 0.06057524348476103, 0.029416087615702833, 0.025978849735110998, 0.030622332889054502, 0.026658193906769156, 0.06061825581959315, 0.04680226503738335, 0.03951151143493397, 0.026799034027914916, 0.033885943836399486, 0.03959960224373, 0.061350286539111815, 0.05567040221233453, 0.03760217835328408, 0.020194286114669273, 0.04758294332506401, 0.024079000876684273, 0.05638534402740853, 0.05639742534341557, 0.035931445325591733, 0.06882316233324152, 0.09577292443386146, 21.426689795085363, 59.136917250497, 28.766054596219742, 29.454341411590576, 42.03821693147932, 54.53385727746146, 66.31237057277134, 52.856548241206575, 58.78627640860421, 55.30060141427176, 58.10194485528128, 55.79493795122419, 33.84625605174473, 0.16547206869082792, 0.8294476664492062, 0.4565859969173159, 22.65184828213283, 64.6013627733503, 58.99792548588344, 58.64213602883475, 52.91227626800537, 51.230256353105815, 50.27947875431606, 49.24043818882534, 53.85988548823765, 55.32192196164812, 56.42474699020386, 57.390629972730366, 55.603369167872835, 54.415988036564414, 52.8845842225211, 55.24973017828805, 56.932448387145996, 54.901559420994346, 55.359150409698486, 50.844422885349815, 51.08690111977713, 51.23654794692993, 51.221835136413574, 49.7091497693743, 53.45786271776472, 51.66693673815046, 56.10627630778721, 53.93261923108782, 54.5757166998727, 51.671988078526084, 43.04096705572945, 39.111913612910676, 39.61449071339199, 36.979469776153564, 37.57492344720023, 37.172897202628, 39.22268179484776, 44.32741560254778, 46.74649000167847, 47.845569951193674, 55.28418282100132, 44.532752241407124, 46.19091204234532, 40.92250994273594, 37.73129613058907, 37.07163763046265, 37.60763904026577, 35.14113276345389, 37.491340092250276, 37.36703681945801, 38.1912772996085, 36.539433411189485, 37.46947758538382, 36.2735710144043, 36.21466071265084, 37.11180516651699, 36.21579326902117, 38.869963441576274, 37.59612587520054, 36.9252564566476, 37.69439772197178, 37.319476400102886, 37.0307822227478, 36.86271572113037, 38.18456881386893, 38.647978918892996, 37.26123659951346, 36.16447040012905, 40.238171441214426, 43.39016267231533, 42.916646412440706, 43.36496850422451, 49.52560268129621, 48.44516822269985, 46.13893951688494, 42.17969615118844, 37.82519408634731, 36.245055607386995, 36.46423653193882, 33.04265519550869, 35.837665353502544, 36.64159624917166, 34.2224315234593, 37.253385135105674, 39.41231550489153, 40.90948207037789, 42.02934060777937, 41.073751381465364, 43.23120525905064, 44.42599664415632, 44.324375765664236, 42.896375043051584, 44.90938976832798, 44.051582540784565, 43.556648458753315, 44.48324285234724, 49.45742695672171, 51.5515375818525, 52.188329560416086, 52.07386493682861, 54.40064641407558, 54.847193241119385, 55.55626732962472, 50.691503456660676, 53.1027055467878, 47.79431309018816, 51.218131746564595, 48.63139731543404, 50.31942047391619, 52.91259241104126, 53.34050069536482, 52.54539748600551, 55.36898211070469, 42.22248663221087, 17.604854004723684, 0.07274090817996434, 0.3762405567935535, 0.6439814642071724, 32.1043496131897, 59.715841157095774, 57.576664515904014, 50.68420784814017, 48.259425503867014, 61.42705045427595, 63.66807379041399, 38.91796507154192, 39.190410886492046, 24.01765741620745, 42.62787927900042, 21.76132025037493, 0.37036715767213274, 0.10166416224092245, 0.12551806760685785, 0.014073458350529628, 0.06629770249128342, 0.06427334754594735, 0.09008945404951062, 0.042989858359630616, 0.08250936293708426, 0.03300304085548435, 0.04098902822339109, 0.013331557490995951, 0.02291210215272648, 0.0755207711564643, 0.14593138652188437, 0.25912839812891825, 0.12937093872044766, 0.1581852404134614, 0.10229341526116643, 0.17719874158501625, 0.1250601921762739, 0.22144181680466446, 0.06429377145000867, 0.13715909581099237, 0.14455351260091576, 0.15248329352055276, 0.29142443942172186, 0.23174394613930158, 0.1514242903462478, 0.18079330798770699, 33.67313820975167, 72.33379064287458, 47.18630402428763, 36.206458364214214, 45.93515232631138, 60.9113621030535, 70.76055172511509, 60.6173004422869, 64.57170786176408, 59.6254311970302, 62.56224019186837, 59.26718207768032, 36.67485727582659, 1.3150506977524077, 4.813394537993839, 1.2595376308475221, 25.03604793548584, 70.51423808506557, 61.01052679334368, 61.89250332968575, 55.18016133989607, 54.8231246812003, 50.987854548863, 52.87403685706002, 55.731389726911274, 57.43104069573538, 59.12141581944057, 59.244822774614605, 58.86570821489607, 56.074147837502615, 55.71157693862915, 60.276581627982004, 58.18464926310948, 58.605852535792756, 58.07668467930385, 54.98651157106672, 54.09932388578142, 53.697235107421875, 53.031104360307964, 53.48856333323887, 55.756917408534456, 55.34985719408308, 59.982763154166086, 55.71717371259417, 57.84380190713065, 54.62694229398455, 48.10447372709002, 40.97077560424805, 42.66014323915754, 38.68812213625227, 40.398320470537456, 39.44897072655814, 43.78503227233887, 46.2430339540754, 49.32664448874337, 53.25967230115618, 56.60731438228062, 47.20575550624302, 50.00296476909092, 41.65836933680943, 40.0456542287554, 39.2554668698992, 40.46042346954346, 36.662840366363525, 41.00957781927926, 38.13155058452061, 41.29904324667794, 39.38457482201712, 39.673904759543284, 38.136664458683555, 39.90867396763393, 38.52298082624163, 38.222349643707275, 40.577052456992014, 38.5754953111921, 38.543266092027935, 38.036412375313894, 39.32126978465489, 38.94480248859951, 37.4458189691816, 38.2367011478969, 40.42296225684029, 38.40368373053414, 37.600972243717735, 41.15982566561018, 43.2874231338501, 44.642558097839355, 41.630121435437886, 51.34753499712263, 50.28200442450387, 47.973475864955354, 45.32540273666382, 40.03809111458914, 38.296841280800955, 38.95905671800886, 35.70059476579939, 37.453045095716206, 39.802147660936626, 36.04961320332119, 37.76356356484549, 40.98208727155413, 43.99681336539132, 46.209477628980366, 42.65358761378697, 45.228190490177695, 44.869343825748985, 46.92888716288975, 45.29030738558088, 46.24709517615182, 46.36589894975935, 45.807625089372905, 46.43643706185477, 52.7139573097229, 52.092510427747456, 53.210531166621614, 52.02602311543056, 56.35770034790039, 57.13855627604893, 57.59133563722883, 52.152542863573345, 55.06076002120972, 49.87074749810355, 52.050199372427805, 50.337801933288574, 52.38635669435774, 56.17547689165388, 56.837313652038574, 54.079309599740164, 57.46070950371878, 43.905218737465994, 17.31810358592442, 0.49976308005196707, 1.3572892312492644, 2.4059451264994483, 34.83457129342215, 64.64518506186349, 61.159954752240864, 55.66822712762015, 53.378469126565115, 65.82927622113908, 67.4582188470023, 42.733780247824534, 37.59857858930315, 32.68686573845999, 50.42675624574934, 31.46290581566947, 0.38064237630793024, 0.18968519728098596, 0.08596565747367484, 0.10056680148201329, 0.1867707400981869, 0.34703407543046133, 0.17128959723881312, 0.18113055346267565, 0.14991138795656817, 0.16097935262535298, 0.1538400107196399, 0.1276322334472622, 0.09571643639355898], [0.021222733160746948, 0.028167018300986717, 0.01881093641610018, 0.016668419686279128, 0.02421241782472602, 0.014332233795097895, 0.02028683659487537, 0.07033344557774918, 0.04209732357412577, 0.02564418947856341, 0.07336499076336622, 0.04607902473903128, 0.0957447923719883, 0.01518328464590013, 0.002876085815452305, 0.028930232793624912, 0.03278946178033948, 2.771667033433914, 31.869437967027935, 35.53017282485962, 38.36996064867292, 32.56798900876726, 43.96428884778704, 54.993202686309814, 57.9207740511213, 56.199913706098286, 52.482867172786165, 53.15352119718279, 58.898350851876394, 32.92933007649013, 0.30250108933874537, 0.3423283265105316, 0.42790695439491955, 26.515510490962438, 61.69577203478132, 56.21038464137486, 53.93164995738438, 50.69971970149449, 46.506905691964285, 47.252113887241904, 46.55080093656267, 51.75827775682722, 54.18406064169747, 56.369460174015586, 53.65715789794922, 54.75833967753819, 52.87496444157192, 53.55443920407976, 54.84542145047869, 52.19133118220738, 52.79475791113717, 55.138604164123535, 51.430159500667024, 49.58496809005737, 47.531539167676655, 45.3341783114842, 44.02635710580008, 47.33614540100098, 48.67442056110927, 50.63272169658116, 48.90281479699271, 50.3795918737139, 45.25158854893276, 38.66909449441092, 38.06332622255598, 34.4598445211138, 35.63460424968174, 36.22600712094988, 36.247741086142405, 37.03825501033238, 39.60903637749808, 44.24325902121407, 46.0388993535723, 50.56529985155378, 46.938017095838276, 40.784185205187114, 35.68755994524275, 35.16116441999163, 34.79507425853184, 34.32299280166626, 33.053553444998606, 35.22689437866211, 32.28881386348179, 34.08251564843314, 33.644365719386506, 34.67419644764492, 34.59145382472447, 34.23471246446882, 32.8642497743879, 32.968260833195274, 32.38797855377197, 33.42860678264073, 33.5741993359157, 34.15796961103167, 33.449381896427695, 34.417477880205425, 36.376022202628, 34.829103061131065, 33.87455953870501, 35.926661355154856, 35.940696716308594, 35.47004311425345, 35.22608838762556, 45.16438170841762, 49.60574320384434, 51.706881931849885, 51.394223417554585, 45.2303409576416, 40.95403739384243, 37.70433712005615, 35.18603549684797, 35.07078225272042, 34.20406396048409, 34.24163634436471, 33.976652894701274, 33.925375189099995, 36.439695494515554, 36.334513664245605, 38.24986798422677, 38.92306157520839, 36.335243225097656, 38.68648583548409, 39.88270507540022, 39.34364645821707, 41.519457476479666, 41.680506297520225, 42.23530953271048, 43.884964738573345, 44.49255691255842, 47.72194760186331, 48.09418344497681, 49.86183990750994, 49.60356494358608, 52.71553455080305, 46.97502320153372, 49.17444767270769, 47.84171370097569, 46.65234191077096, 46.594578061785015, 47.37615312848772, 47.17396749768938, 49.60504143578665, 50.485440731048584, 52.27687392915998, 48.37474822998047, 44.631805760519846, 37.93015704836164, 20.69838830402919, 1.407517216035298, 0.42258365718381746, 0.44985452241131235, 32.578873361860005, 52.95331927708217, 48.931566442762104, 43.829219341278076, 52.52122470310756, 51.58131756101336, 46.58343662534441, 25.554289749690465, 24.413214887891495, 26.3939847605569, 44.86858647210257, 4.947779646941593, 0.5664261600800923, 0.02594337083532342, 0.041744828024613004, 0.010326698239493583, 0.044969195899154456, 0.013832448649087122, 0.055670595594814846, 0.03797967791823404, 0.06987386702426843, 0.04152723202215774, 0.037716711671756845, 0.027930226542853882, 0.028938683947282176, 0.04875088529661298, 0.09499195776879787, 0.0934148659663541, 0.043375659800533733, 0.06000071431377104, 0.0663128202514989, 0.024983091113556708, 0.027513524617201517, 0.003467503723056455, 0.0309028189097132, 0.06422175174312932, 0.06933834004615035, 0.03093851663704429, 0.03204772801005414, 0.035790354146489074, 0.03669477686552065, 0.0521929509538625, 5.382852826799665, 46.08314895629883, 38.15294061388288, 32.39499276024954, 46.073730673108784, 47.54016188212803, 64.55708190373012, 62.76102120535714, 61.45062569209507, 57.626309394836426, 57.84982252120972, 60.80665275028774, 36.812337807246614, 0.32502201944589615, 0.13006700708397798, 0.565522839980466, 28.808278799057007, 65.04012761797223, 60.11800289154053, 57.74950442995344, 52.98936653137207, 50.63283634185791, 49.64939178739275, 48.34447145462036, 52.89624677385603, 56.616882051740376, 58.377527781895225, 56.51880128043038, 57.50353125163487, 56.46127019609724, 56.71550130844116, 55.465523856026785, 52.50311074938093, 55.21183122907366, 55.80851125717163, 53.44647114617484, 50.70316253389631, 49.649350098201204, 47.71832411629813, 47.11671781539917, 50.31119728088379, 50.14860943385533, 53.57350853511265, 52.17109455381121, 53.2919362613133, 46.406111649104524, 40.58995526177542, 39.94459615434919, 36.871970721653526, 37.53986978530884, 40.429774965558735, 40.98184061050415, 39.368388993399485, 40.88607358932495, 44.952798639025005, 49.06957156317574, 53.772081102643696, 49.57299634388515, 44.66669266564505, 38.725215094430105, 39.314054080418174, 39.57266255787441, 37.88184969765799, 37.119941507067, 38.049902302878245, 36.26613644191197, 37.11321912493025, 37.6002322605678, 38.10917043685913, 37.297669478825156, 36.603224822453086, 34.77586596352713, 35.42415721075875, 36.062884262629915, 36.90167079653059, 37.63849251610892, 37.96928582872663, 37.23468058449881, 37.49756220408848, 37.50273166384016, 38.9145951952253, 36.86736059188843, 37.561860833849224, 37.23214101791382, 38.64033242634365, 38.22743919917515, 46.97400181634085, 48.85656411307198, 52.84444447926113, 53.55359499795096, 45.91523878914969, 42.030066694532124, 38.790806089128765, 38.593164580208914, 36.67190081732613, 36.43860115323748, 36.350060258592876, 35.555433000837056, 35.336213861192974, 37.28966515404837, 37.68208203996931, 40.53227826527187, 41.567358357565745, 38.72688961029053, 40.918007510049, 40.387943335941856, 41.95731905528477, 44.062855992998394, 43.16839006968907, 44.41050216129848, 44.805330072130474, 46.77779858452933, 49.32796812057495, 49.29293877737862, 53.000407218933105, 51.02777542386736, 54.80372183663504, 49.51309939793178, 51.44959708622524, 48.75253220966884, 48.124512331826345, 48.613905225481304, 48.876383849552695, 50.477106366838726, 52.077012470790315, 51.85092503683907, 54.8549474307469, 51.37524093900408, 49.483534812927246, 41.57066222599575, 23.514786754335674, 1.914809103522982, 0.352142901292869, 0.5090631895831653, 35.53182302202497, 58.27877303532192, 53.43445771081107, 49.23002978733608, 56.52228580202375, 57.172414847782676, 52.359797205243794, 32.826257024492534, 25.740390300750732, 30.212664331708634, 51.880229064396445, 6.383636176586151, 0.5243290332811219, 0.02560785223197724, 0.07055393553205899, 0.03006107925570437, 0.03724621209715094, 0.08214102698756115, 0.047099860318537266, 0.03068514826840588, 0.03142166071172271, 0.01550113080468561, 0.04741779129420008, 0.09135619750512497, 0.032923584404800615, 0.0864048528351954, 0.14064490662089416, 0.1784024898494993, 0.13870355007903917, 0.08033088554761239, 0.22986790537834167, 0.10666107053735427, 0.1456309040742261, 0.11999612248369626, 0.08078683393874339, 0.15507900209299155, 0.16401802242866584, 0.17883813647287233, 0.22464861401489802, 0.16570760176650115, 0.1947631633707455, 0.15205679354923113, 7.5804794515882215, 57.821598938533235, 50.182092802865164, 49.81311566489083, 45.872924259730745, 54.87849834987095, 66.4852625983102, 68.15854862758091, 65.12916878291539, 63.00989178248814, 60.7764002936227, 68.62077753884452, 39.51968254361834, 1.8927676805428095, 1.2443510400397437, 0.9159278231007713, 32.15024593898228, 69.09806319645473, 60.980399404253276, 60.164416858128135, 57.01742485591343, 52.33515541894095, 51.367452008383616, 51.20902613231114, 55.64915084838867, 61.11138684409005, 60.68617793491909, 58.48193836212158, 57.59294414520264, 58.40163803100586, 60.952898434230256, 55.785603046417236, 55.43310703550066, 57.216268403189524, 60.210552896772114, 56.27540935788836, 52.39094597952706, 53.73025989532471, 49.152341978890554, 49.45319202968052, 52.778513022831504, 51.88760110310146, 56.37339285441807, 55.47733926773071, 55.16503511156355, 49.307835715157644, 41.11368267876761, 42.233478682381765, 38.71949325289045, 40.031601497105186, 42.77510118484497, 43.458418301173616, 42.49783679417202, 43.91711057935442, 48.45355817249843, 51.60814455577305, 53.97278676714216, 51.740643228803364, 45.612571784428184, 41.775957175663535, 40.759300231933594, 41.58123738425118, 41.00158044270107, 39.21247141701834, 40.856509004320415, 37.392957074301584, 40.19603756495884, 40.206904547555105, 40.85865947178432, 39.63831261226109, 40.39161893299648, 37.79750204086304, 37.78891406740461, 37.296700205121724, 38.32103838239397, 38.690981319972444, 39.48810298102242, 38.36219603674752, 39.76105948856899, 40.7596789087568, 40.55012123925345, 38.48773261478969, 40.82357801709856, 40.40430981772286, 41.89267648969378, 38.5373010635376, 48.84197984422956, 53.44718681062971, 52.59354502814156, 52.77183927808489, 47.22113881792341, 44.20996672766549, 42.26390831811087, 39.511261326926096, 38.16955375671387, 37.93821695872715, 39.03275626046317, 38.156887190682546, 37.90469537462507, 40.72480590002877, 39.35298136302403, 42.38096809387207, 44.7086250441415, 41.99432863507952, 42.88901342664446, 45.040686403002056, 44.811910016196116, 46.65170962469918, 46.819307122911724, 47.373634406498496, 47.700227533067974, 48.78772483553205, 52.17804275240217, 50.511235918317524, 54.76295675550188, 54.13275514330183, 54.967459610530305, 51.5860527583531, 55.57763998849051, 51.24477808816092, 51.30208683013916, 49.442877428872244, 49.88130875996181, 51.242801325661794, 53.01226084572928, 53.260551248277935, 58.10159397125244, 53.169217177799766, 52.44430814470564, 45.37231697354998, 26.23563357761928, 2.3311036910329546, 0.462690532207489, 0.7477852712784494, 39.01340205328805, 63.35413333347866, 58.32653495243618, 54.918092659541536, 62.30794307163784, 60.51924746377127, 57.79994140352522, 35.66602052961077, 36.75346572058541, 38.77177497318813, 62.11893817356655, 10.398095573697772, 0.8043640181422234, 0.17188339680433273, 0.14521895189370426, 0.08777531715376036, 0.1289406253823212, 0.14345101533191545, 0.12178871700806276, 0.11920333573860781, 0.12375939983342375, 0.11097302487386124, 0.14276866694646223, 0.12743017928940908, 0.08457075232373816], [0.03361646365374327, 0.057269977272621224, 0.004613108533833708, 0.03122177447325417, 0.041258511798722405, 0.027066229243895838, 0.03281120882768716, 0.020133699722854153, 0.014479691329013025, 0.014599837828427553, 0.0512319621630013, 0.04622337627889855, 0.03655782475003174, 0.028938765371484414, 0.028377094439097812, 0.03977631311863661, 0.01440756136019315, 0.0324780413481806, 17.108789103371755, 48.72823783329555, 26.64700514929635, 21.427653857639857, 35.24001257760184, 53.275594098227366, 52.871743951525005, 48.710995878492085, 55.29139157703945, 53.04734230041504, 54.290166582380024, 33.95685747691563, 0.18781172138239655, 0.31938597187399864, 0.5935871569173676, 26.28975657054356, 62.95306246621268, 58.30997044699532, 56.44173533575875, 54.04610068457467, 50.428364753723145, 47.59809596197945, 47.10409641265869, 49.569379806518555, 51.60755048479353, 55.00413915089199, 55.728756359645296, 55.098207337515696, 54.23679052080427, 56.9876309803554, 56.35620648520333, 53.19281326021467, 53.92724479947771, 53.49318388530186, 51.46125268936157, 50.96840654100691, 45.685625144413535, 41.61871944155012, 43.326367786952424, 42.34237085069929, 44.35864775521414, 47.5434900692531, 46.249513149261475, 43.69459104537964, 40.242034639631, 40.10870565686907, 37.00210353306362, 35.71105875287737, 35.024559361594065, 39.073486600603374, 38.90285621370588, 40.172021116529194, 38.9986058643886, 44.60708406993321, 46.08137021745954, 45.34192555291312, 37.777459962027415, 35.42725610733032, 33.30797215870449, 34.1351934160505, 33.18466247831072, 34.41424349376133, 36.405155999319895, 35.10268143245152, 34.92623540333339, 34.29834754126412, 33.94020611899239, 33.631733894348145, 34.70931264332363, 35.99467727116176, 33.668548924582346, 34.79630756378174, 34.9679593358721, 33.30975089754377, 34.264513288225444, 33.64353193555559, 34.953177043369834, 34.411082063402446, 33.43490532466343, 35.41524962016514, 35.80270201819283, 35.11148132596697, 34.72258717673165, 35.22120380401611, 36.117201805114746, 33.61479418618338, 40.23755305153983, 45.45282227652413, 45.750719342912944, 44.686411653246196, 41.23934779848371, 37.26463426862444, 37.06945242200579, 36.71286392211914, 34.07325022561209, 34.11350808824812, 31.599472658974783, 33.26408733640398, 35.84547512871878, 36.548264571598594, 34.442098821912495, 36.677751200539724, 37.58895533425467, 38.622784750802175, 37.69150032315935, 39.07576213564192, 39.06882088524954, 40.82950830459595, 42.61492436272757, 44.265180587768555, 46.54698984963553, 49.583081654139924, 49.35333251953125, 49.97092662538801, 49.855541365487234, 52.87295641217913, 53.3257600920541, 49.64317314965384, 49.722205434526714, 49.25548103877476, 49.48964922768729, 51.76014334814889, 54.847690037318635, 54.72212219238281, 55.726185526166645, 53.19796534946987, 51.33183901650565, 43.53042943137032, 37.56558506829398, 25.416159561702184, 5.1502653530665805, 0.13438683242670127, 1.332234569958278, 37.8501798084804, 55.62040615081787, 45.929770946502686, 48.104935782296316, 48.71495982578823, 54.06971066338675, 39.751356329236714, 25.426173652921403, 34.242553506578716, 38.96331248964582, 25.474955218178884, 0.3272720144263336, 0.03353873746735709, 0.056430514103599956, 0.03602248436904379, 0.03753563442400523, 0.013556017723333622, 0.033420906468693695, 0.06413132338119404, 0.023118217342666218, 0.024118293143276657, 0.06426082857485328, 0.019426291342824697, 0.04378139999295984, 0.04322832949193461, 0.0368486720004252, 0.021905391975971203, 0.02700681332498789, 0.06583754039768662, 0.041110984714967866, 0.0721055076324514, 0.025444990256801248, 0.005175415592800293, 0.020233335804992487, 0.07519768670733486, 0.02111696481837758, 0.06893953108893973, 0.04542296280020049, 0.012158704622249519, 0.009409893952709223, 0.08293352196259157, 0.00901968712319753, 0.08318382674562079, 24.411517790385656, 57.95280524662563, 29.67038175037929, 38.2482316834586, 41.57039124625069, 57.494071279253276, 61.74327686854771, 54.75581748144967, 60.27763775416783, 57.891949449266704, 58.585709708077566, 39.155527455466135, 0.15586893899100168, 0.1919914021023682, 0.6149782176528658, 28.99176161629813, 66.61020510537284, 60.88117218017578, 60.26749338422503, 55.079030309404644, 51.46812793186733, 50.20294087273734, 52.736316612788606, 52.70516436440604, 55.140087604522705, 56.85144281387329, 56.784027917044504, 57.864302567073274, 56.43555491311209, 58.454354013715474, 56.270844391414094, 55.65789515631539, 57.116513116019114, 55.34827300480434, 54.38762548991612, 51.331477710178916, 47.3985332761492, 45.10692010607038, 45.64390121187483, 44.80634798322405, 48.02813386917114, 49.51924160548619, 48.80966029848371, 47.75225911821638, 44.44473940985543, 42.13492543356759, 40.13816254479544, 38.44049876076834, 38.809715611594065, 40.76931606020246, 42.50862387248448, 41.07020780018398, 40.79312753677368, 46.48854160308838, 48.547272000994, 46.39773906980242, 41.44620609283447, 38.33084576470511, 36.27391842433384, 36.5586382320949, 36.906819411686485, 37.35339403152466, 40.36727244513375, 38.17765188217163, 36.85180704934256, 37.855262415749685, 34.885803835732595, 36.822912965502056, 37.882839815957205, 38.32252877099173, 35.60883338110787, 37.89199754170009, 36.69925587517874, 35.925605228969026, 36.70350122451782, 36.23484870365688, 37.37356117793492, 37.205213274274556, 36.840999126434326, 37.97782516479492, 37.89691686630249, 37.10459641047886, 36.78005647659302, 37.803022384643555, 36.97068725313459, 38.55095427376883, 43.6102294921875, 48.95965453556606, 48.76895775113787, 45.63758182525635, 41.55477864401681, 38.87668929781233, 38.470754691532676, 39.297472204480854, 35.911705357687815, 36.690803391592844, 33.05928223473685, 34.850395815713064, 35.96063109806606, 37.53776100703648, 38.153336661202566, 38.688118662152974, 39.99606840951102, 39.880259309496196, 40.41393654687064, 39.820841789245605, 41.95369904381888, 41.87316247395107, 44.800424643925254, 46.84963600976126, 49.446907384055, 50.98873002188546, 50.188019616263254, 53.1010935647147, 52.575438022613525, 53.90872785023281, 55.53552000863211, 49.88223287037441, 51.34319584710257, 51.7138648714338, 50.18402787617275, 53.883915833064485, 55.59584774289812, 57.8298533984593, 57.11584956305367, 56.61414098739624, 55.48335640771048, 48.86230679920742, 42.876864501408164, 29.436828477042063, 6.49485946553094, 0.06036003253289631, 1.7390144680227553, 42.18791239602225, 60.2923401423863, 50.5570592880249, 53.334632941654746, 54.48682492119925, 60.62181677137102, 45.66884177071707, 30.557024002075195, 31.925346646990093, 44.05503579548427, 29.743462903159006, 0.36946541177374975, 0.025804783450439572, 0.057250767946243286, 0.0164474886842072, 0.010301127647315817, 0.043762370478361845, 0.02119403112945812, 0.05226316575759223, 0.04996226029470563, 0.05418620524661882, 0.022638973148007478, 0.022603836908404316, 0.06485172401049308, 0.025398396953408207, 0.12114915704088551, 0.11688301738883768, 0.08663795675550189, 0.14593169864799294, 0.18983178798641476, 0.25394202928457943, 0.1142210837985788, 0.10254914153899465, 0.08912249415048532, 0.11760862916707993, 0.2116684562393597, 0.1570512048367943, 0.19805267399975232, 0.17138045307781014, 0.14435635746589728, 0.1194904510463987, 0.14236260444990226, 0.20240098424255848, 34.366919313158306, 71.16779259272984, 38.35547712871006, 35.62129150118147, 45.50670903069632, 64.49450642721993, 63.918472971235005, 61.55204854692732, 62.397720745631624, 63.379452569144114, 60.822425161089214, 43.53481374468122, 0.6827239138739449, 0.942675022142274, 0.7987963940416063, 32.19157729830061, 70.49537372589111, 61.42937115260533, 63.10218470437186, 57.57458700452532, 56.2430932862418, 52.45147521155221, 53.2415965625218, 54.65207045418875, 59.61475876399449, 59.03751632145473, 59.909452710832866, 58.463219915117534, 61.210092953273225, 58.10499511446272, 59.75482055119106, 58.23577063424246, 58.57398114885603, 60.16183907645089, 57.7675211088998, 56.1950569152832, 50.16135590417044, 47.93629605429513, 48.92658111027309, 48.12602703911917, 50.67341034752982, 50.27924598966326, 51.91064827782767, 49.57599449157715, 45.658211026872905, 44.26987409591675, 41.043137618473594, 40.64539841243199, 40.773502349853516, 43.64225026539394, 45.51629407065255, 45.40594278063093, 43.5975455556597, 48.71949005126953, 52.449922289167134, 50.5039507320949, 43.60921505519322, 40.625776699611116, 38.02308573041643, 40.29705395017351, 39.98061561584473, 41.019857679094585, 43.57789952414376, 40.95685141427176, 41.13709115982056, 40.205584389822825, 37.573266301836284, 38.731458050864084, 41.44382286071777, 40.776622091020855, 39.34468173980713, 40.0219851902553, 39.82498638970511, 38.75956351416451, 39.30882903507778, 38.88733046395438, 40.79480900083269, 40.809309891292024, 39.14354876109532, 39.6827254976545, 39.173978396824424, 38.69183942249843, 38.5419876234872, 39.223519052777974, 38.27737937654768, 38.296386173793245, 43.30452959878104, 48.77624988555908, 50.63535506384713, 48.02707774298531, 44.67770903451102, 40.84277241570609, 40.97900227137974, 42.05188403810774, 38.246206283569336, 39.43806900296892, 35.26390743255615, 37.64443670000349, 38.31612253189087, 39.64217233657837, 40.60293449674334, 40.55321666172573, 41.94405494417463, 43.12433154242379, 43.706274441310335, 44.359644821711946, 44.26943983350481, 44.31900828225272, 48.559719698769705, 49.53123767035348, 52.405426025390625, 54.17168937410627, 52.31057269232613, 55.86436435154506, 54.99256692613874, 55.71322018759591, 57.10297802516392, 52.635616370609824, 53.30673939841134, 54.75938538142613, 51.5204895564488, 55.56263187953404, 57.40186173575265, 58.8701411655971, 57.47118043899536, 58.79995741162981, 57.913551398685996, 52.85081945146833, 45.39770916530064, 32.37159470149449, 7.87035482270377, 0.26347436064055985, 2.1563873291015625, 45.68874488558088, 64.3004571369716, 55.51225396565029, 59.76968274797712, 58.11382280077253, 64.34990746634347, 50.04214913504464, 39.53588921683175, 47.37867532457624, 49.889156750270296, 41.95952163423811, 0.3281390464731625, 0.10601978030587945, 0.1848627674792494, 0.1058373222393649, 0.13002900912293366, 0.08548397224928651, 0.07997536712459155, 0.15619768920753682, 0.09404512321842567, 0.09269838048411266, 0.22154025866517, 0.11161012175892081, 0.11310726178011724, 0.11264163747962032], [0.03972259350121021, 0.017519935333569134, 0.023035151085683277, 0.028803160148007528, 0.0373036636571799, 0.05816024914383888, 0.01763106749526092, 0.024410768877714872, 0.053222407320780415, 0.07721187719809157, 0.01925507320889405, 0.059764713048934937, 0.032147129997611046, 0.03256379460383739, 0.01758128677361778, 0.049269808522824726, 0.04513746579842908, 0.01667017030662724, 2.0815539274896895, 34.32076242991856, 30.076469217027935, 28.70199567931039, 32.31394897188459, 46.515472820826936, 58.169932978493826, 49.481801237378804, 51.69416325432913, 55.07923528126308, 52.00288214002337, 37.209979738507954, 0.1761607187134879, 0.05889564539705004, 0.8913436308503151, 36.457086835588726, 65.49986907414028, 59.010328020368306, 59.54492241995675, 52.20581122807094, 53.80575207301548, 51.30932685307094, 50.96147918701172, 51.769137791224885, 52.32949611118862, 52.00869083404541, 53.20337104797363, 54.59737770898001, 55.197566577366416, 56.37263550077166, 53.224528312683105, 52.790384020124165, 53.499329566955566, 54.732235295431956, 53.182818276541575, 50.23531600407192, 44.572016511644634, 41.89515004839216, 37.868759291512625, 40.63868645259312, 41.593160493033274, 42.913412025996614, 41.637330191476, 41.198263100215364, 42.9706825528826, 39.49130610057286, 36.70114925929478, 34.912196568080354, 35.20615747996739, 39.31811530249459, 40.40347603389195, 42.10367938450405, 37.36837434768677, 41.286237716674805, 42.842505659375874, 40.16115760803223, 36.580664021628245, 35.57539517538888, 33.46468530382429, 34.2127492087228, 33.492481572287424, 35.6486257144383, 33.60542801448277, 33.323265143803184, 32.930747509002686, 35.36121000562395, 33.793873582567485, 35.06992762429373, 33.725631850106375, 35.92167254856655, 34.79624850409371, 36.91564014979771, 36.608387334006174, 32.92524453571865, 33.75788191386631, 33.301767417362754, 34.24875824792044, 34.92611380985805, 34.56064551217215, 35.87026630129133, 35.06969485964094, 35.68308877944946, 36.90816388811384, 36.035609109061106, 36.21770402363369, 36.964479037693565, 36.24768202645438, 38.24572338376726, 44.337778840746196, 41.55430964061192, 41.475656032562256, 35.852878434317454, 39.85470036097935, 36.72885867527553, 36.68102380207607, 34.256564549037385, 33.37259387969971, 31.57603985922677, 34.20563425336565, 35.61423560551235, 34.94307088851929, 34.51299129213606, 37.41794627053397, 37.12046957015991, 37.95893996102469, 37.82830340521676, 39.07565443856375, 40.43969004494803, 43.40302031380789, 46.67221375874111, 46.818845067705425, 47.658236094883506, 49.16798932211739, 50.057931968144004, 51.233146803719656, 51.28095735822405, 50.98718752179827, 50.81314556939261, 49.50636659349714, 51.427091870989116, 53.514153548649375, 55.574197156088694, 56.69724839074271, 57.477176734379356, 58.07846341814314, 56.824709619794575, 52.014919894082205, 35.93618038722447, 31.586013998304093, 27.779787336077007, 8.860034516879491, 0.10664385610393115, 2.069119691848755, 37.57003191539219, 54.90314013617379, 45.088184288569856, 56.71997594833374, 49.952673707689556, 57.54050956453596, 27.92388776370457, 31.097586904253276, 31.813438960484095, 38.171659060886924, 3.300475103514535, 0.3753766460078103, 0.03718392597511411, 0.06881462636270694, 0.11306926381907292, 0.04118636656286461, 0.11665064628635134, 0.051854243235928674, 0.059294963255524635, 0.02126368783813502, 0.014996148080431988, 0.022819314185263853, 0.03605028394875782, 0.06834734643676452, 0.0637639102392963, 0.05932870680200202, 0.021405980024220686, 0.01547547200295542, 0.009656979087074953, 0.042434955814055035, 0.045807485202593465, 0.03234919433348945, 0.08165914498801742, 0.14500104715781553, 0.026670963935820118, 0.026729431602039506, 0.030090765162770237, 0.019275508987318193, 0.03370542298736317, 0.07915809883603028, 0.05208411732954638, 0.03015275951474905, 0.08087047016514198, 3.5633143825190405, 49.253334045410156, 28.004054341997417, 25.161447286605835, 43.57044758115496, 48.46213572365897, 61.381039483206614, 52.62980072838919, 58.46803501674107, 59.02218859536307, 57.92576633180891, 40.89851433890206, 0.11079371520983321, 0.16104979813098907, 1.324018433690071, 40.6245572907584, 69.15608065468925, 60.14029966081892, 61.83879375457764, 56.015647479466026, 56.60664735521589, 53.585483755384175, 51.53948245729719, 53.199247292109895, 53.4274400302342, 54.85678175517491, 57.02337598800659, 55.38853086744036, 58.40526499067034, 58.398427963256836, 56.253119536808555, 55.83106858389718, 56.432831219264436, 56.45456518445696, 55.07173122678484, 52.80759123393467, 47.65127052579607, 43.3715032849993, 41.34360204424177, 41.3481114251273, 44.0332601411002, 44.64809233801705, 45.47533096585955, 43.69653306688581, 45.331770760672434, 42.26246656690325, 38.55302831104824, 39.28301995141165, 38.68542276109968, 41.559631960732595, 40.82025677817208, 43.267738887241904, 40.40548753738403, 44.51238359723772, 46.79326180049351, 44.48667178835188, 39.03112343379429, 37.20095750263759, 38.315535409109934, 35.5258024079459, 37.37854651042393, 38.254592759268625, 37.70974629265921, 37.20191982814244, 35.59962354387556, 37.01460681642805, 37.666024753025596, 38.18869604383196, 37.7385778427124, 38.78941992350987, 37.440520967756, 39.61479296003069, 39.61294821330479, 37.079148633139475, 35.63273171016148, 36.76726484298706, 36.407952649252756, 36.60415588106428, 37.114949226379395, 37.90612670353481, 36.2010109765189, 37.65420239312308, 38.831119537353516, 37.085877963474815, 37.91711180550711, 37.37090001787458, 37.60273708615984, 40.22611631665911, 45.976316928863525, 44.24237312589373, 43.22494840621948, 38.45944649832589, 41.6391784123012, 39.07264586857387, 37.836592606135774, 36.091114793504985, 34.53373513902937, 34.15767778669085, 36.531717436654226, 37.746735027858186, 35.90148803165981, 37.20744364602225, 39.33134119851248, 39.103937080928254, 39.415869508470806, 39.27962575639997, 40.8356157711574, 43.15528924124581, 44.747798987797324, 46.96105037416731, 48.369144507816856, 50.2110389981951, 51.14559602737427, 51.98583473478045, 53.11174167905535, 51.71088409423828, 53.18943296160017, 52.981876373291016, 50.47200986317226, 52.92441824504307, 56.03906290871756, 56.90888704572405, 57.88464689254761, 59.46060603005545, 59.19257926940918, 58.93118109021868, 54.035817350660054, 42.175228459494456, 36.931721755436485, 31.75814172199794, 11.558665343693324, 0.12499159228588853, 2.2819734130586897, 41.16870893750872, 58.91788223811558, 50.46182727813721, 60.31438677651541, 55.85183327538626, 60.94892406463623, 35.252265725817, 34.06925848552159, 33.16135127203805, 46.83138656616211, 3.9110159192766463, 0.36045937931963373, 0.005918870297526675, 0.047909376344510486, 0.07128631230443716, 0.09222614725253411, 0.08107466849365405, 0.06561173072883061, 0.057717878238431046, 0.04440772852727345, 0.07478983966367585, 0.03252228522407157, 0.018307141128129194, 0.040041318362844844, 0.0619507221771138, 0.1176451886338847, 0.18342812731862068, 0.12557202471154078, 0.184830442070961, 0.14239444131297724, 0.14455282049519674, 0.12172877522451536, 0.11345294144536767, 0.22200745716691017, 0.12061654776334763, 0.14255040937236377, 0.19587795569428376, 0.06795012525149755, 0.11445004865527153, 0.2642494376216616, 0.11801607587507792, 0.12360381175364767, 0.1280486775296075, 6.264688662120274, 62.493703160967144, 42.420538084847585, 40.31648111343384, 43.854945046561106, 57.16817992074149, 67.28034496307373, 60.14076519012451, 58.98685700552804, 64.6061292375837, 60.40998009272984, 47.945908887045725, 0.16120145070765698, 0.396395136735269, 1.4887252641575677, 43.9733110836574, 70.38646071297782, 62.95130457196917, 65.12301962716239, 58.559938839503694, 59.849587031773154, 57.23984016690935, 55.35983828135899, 55.388826165880474, 54.30796786717006, 57.89299167905535, 59.203842299325125, 58.83727618626186, 60.652103969029014, 60.117752756391255, 57.02425840922764, 57.40955686569214, 60.219710622514995, 59.68809005192348, 58.7539255959647, 54.88989339556013, 49.40389803477696, 45.93693453924996, 42.55141435350691, 43.33416713987078, 46.12810032708304, 48.517839431762695, 47.17361661366054, 45.62804194859096, 47.86108180454799, 44.85416896002633, 40.24254880632673, 42.03436068126133, 40.6818972996303, 44.54926463535854, 45.20030736923218, 47.470902238573345, 42.425801345280235, 46.87894698551723, 50.245376995631624, 46.32131930759975, 40.99708843231201, 39.971815722329275, 39.49839326313564, 38.187438419886995, 40.34091445377895, 41.71376037597656, 40.85930218015398, 39.39179400035313, 38.52387366976057, 38.92634459904262, 40.933738231658936, 40.27806799752371, 40.88174833570208, 40.93525641305106, 41.32549851281302, 42.30858176095145, 42.10612167630877, 37.14033099583217, 38.286002090999055, 38.59215014321463, 39.054062911442344, 39.01049770627703, 39.83044072559902, 40.96125309807913, 37.5136889730181, 39.3154993057251, 39.41325698580061, 40.18040411812918, 39.39378465924944, 38.28196518761771, 39.52479294368199, 40.714057036808555, 46.76688296454293, 44.70980971200125, 44.75176988329206, 40.003322328839985, 44.20543997628348, 39.92899397441319, 39.94022226333618, 38.88610063280378, 37.66216155460903, 36.80575091498238, 38.85294730322701, 38.609201022556846, 38.348473344530376, 38.918114457811626, 42.48144599369594, 41.93750279290335, 42.76490122931344, 42.69191040311541, 44.12744297300066, 46.337459972926546, 48.04183224269322, 50.80171578271048, 51.377030100141255, 52.43955905096871, 54.68181569235665, 53.68431493214199, 54.88633244378226, 53.65938132149832, 54.15595517839704, 54.663819858006065, 52.31617988858904, 54.948279108319966, 58.161716733660015, 59.44964872087751, 58.26654420580183, 60.40894481113979, 61.0403276171003, 61.85040419442313, 57.635647773742676, 48.02366965157645, 42.354141099112375, 34.65481097357613, 13.572591151509966, 0.23623785642640932, 2.5947081404072896, 45.50756365912301, 63.62307030814034, 54.731127057756694, 65.49760396139962, 58.64022527422224, 68.5750514439174, 38.996910503932405, 47.20642600740705, 42.23832852499825, 57.732957295009065, 8.210983310426984, 0.6116925882441657, 0.1315518045531852, 0.11315048446080514, 0.17020856881780283, 0.18363562332732336, 0.24964207144720213, 0.12307093106210232, 0.12117262078183037, 0.11495016967611653, 0.0794733597763947, 0.13049870463354246, 0.09547502041927405, 0.18538313598505088, 0.15339920723012515], [0.016736100161714212, 0.04241492885297962, 0.05478807259351015, 0.0242549483996949, 0.12162224522658757, 0.02648202416353992, 0.08515470634613719, 0.0798630899350558, 0.10394015189792428, 0.02606038928830198, 0.0184105312052582, 0.006672446624309356, 0.027566467312031558, 0.018915228944803988, 0.04105260016928826, 0.08703832634325538, 0.06507258715906314, 0.11009682581893035, 0.2113608763154064, 25.89385690007891, 48.54647295815604, 37.1917268208095, 33.569471086774556, 39.413149288722444, 62.363181250435964, 57.54937546593802, 44.01583405903408, 60.41576099395752, 48.879375049046104, 47.80038928985596, 1.773109604205404, 0.14568475261330605, 2.9989914638655524, 52.26868200302124, 65.77939510345459, 59.07032571520124, 62.627289227076936, 58.37018353598458, 55.46063927241734, 51.3680009160723, 52.44651767185756, 50.1606958253043, 52.776046412331716, 50.95556627001081, 52.802373136792866, 51.53031430925642, 54.80293321609497, 52.97006096158709, 52.40385920660836, 52.00052670070103, 53.314205237797324, 50.156196866716655, 49.24181045804705, 42.583518505096436, 41.03133610316685, 39.59992381504604, 39.49475588117327, 39.34915290560041, 40.10978610174996, 38.01546355656215, 39.04499898638044, 38.74099792752947, 38.30926465988159, 36.63227524076189, 36.92371048246111, 36.319154671260286, 36.43161473955427, 37.20605748040335, 42.00663389478411, 42.52444839477539, 36.31470087596348, 39.90581825801304, 39.43241316931588, 35.281590597970144, 34.597300733838765, 33.64278500420706, 32.610008239746094, 34.73352364131382, 33.707615171160015, 35.856335163116455, 36.480530057634624, 34.857205050332205, 34.28264808654785, 35.03981760569981, 36.018044063023154, 36.87662948880877, 36.209873403821675, 38.65000779288155, 34.33161204201834, 34.34065512248448, 38.274169308798655, 35.616879395076204, 35.6497026852199, 34.068615777151926, 32.64382859638759, 35.63097381591797, 35.37395995003836, 34.94305351802281, 34.46033089501517, 33.806032930101665, 34.32063388824463, 35.004475593566895, 35.90266922542027, 34.82114389964512, 36.208070346287315, 36.53916243144444, 41.39301415852138, 41.90223721095494, 36.75025912693569, 35.06082895823887, 40.90420838764736, 38.15773139681135, 36.3644187109811, 34.97194760186331, 34.4570826121739, 34.68806505203247, 34.83528000967843, 34.869579792022705, 33.437403202056885, 34.69589567184448, 35.68717432022095, 37.03197383880615, 36.24681350163051, 35.24554334368025, 39.144893237522666, 40.58115884235927, 42.93736941473824, 46.43082291739327, 47.042031628744944, 46.34762518746512, 47.74302496228899, 49.879842690059114, 50.07808174405779, 51.43573890413557, 51.538457598005024, 50.467955589294434, 50.3950411932809, 54.274199622017996, 52.83517210824149, 58.000605378832134, 55.928412846156526, 55.25428819656372, 56.41275092533657, 56.18913357598441, 52.08592006138393, 41.40724059513637, 23.712186813354492, 24.558550357818604, 12.18357503414154, 0.15749382680015905, 2.1652788519859314, 40.55890028817313, 51.85322489057268, 55.14189761025565, 49.381410190037315, 50.676575251988, 40.06276764188494, 23.9349582195282, 29.50385080065046, 33.327468803950715, 22.13101131575448, 0.28966206684708595, 0.08603132609277964, 0.134452026071293, 0.03493477237809982, 0.09335169435611793, 0.014280066326526659, 0.07148015618856464, 0.05030567704566887, 0.07640209993613617, 0.04076675032930715, 0.012141161947511137, 0.02634826285897621, 0.04877914288746459, 0.0337261895516089, 0.10593680225844894, 0.07123497434492622, 0.045272952278277705, 0.02553355264743524, 0.03046717567901526, 0.13843119969325407, 0.06332457238542182, 0.03669870897595372, 0.03280132596514054, 0.03307778488046356, 0.030330963166696683, 0.0553541370401425, 0.03349537229431527, 0.010350464776690518, 0.04551962350628205, 0.11188194288739137, 0.1466727810246604, 0.07128547092101403, 0.09931791706808976, 0.04972613350089107, 33.38613939285278, 56.79551328931536, 32.24455036435808, 44.34947265897478, 44.41292360850743, 67.23919078281948, 62.331824030194966, 49.96748726708548, 64.70473807198661, 53.79756709507534, 52.00273275375366, 2.095322868653706, 0.20851359409945353, 3.924672169344766, 55.690228598458425, 65.4214517048427, 62.16376795087542, 64.01704011644635, 60.276651109967915, 59.98960712977818, 53.630973611559185, 54.230095931461875, 52.60976559775216, 54.13143845966884, 53.90747717448643, 55.861585072108674, 54.56122275761196, 57.52726629802159, 54.966740471976145, 55.44651705878121, 55.258234773363384, 55.99748488834926, 53.23598936625889, 52.13548503603254, 45.52367305755615, 42.30807454245431, 41.4361937386649, 41.51462153026036, 41.395571095602854, 40.598008223942344, 39.78267880848476, 41.84910086223057, 40.19485289709908, 41.56930385317121, 39.70682185036795, 39.40584325790405, 38.9126809665135, 38.399024963378906, 40.139211722782676, 44.140807832990376, 43.658175536564414, 39.9116929599217, 43.25859158379691, 42.04565497807094, 38.349314076559885, 37.276359353746685, 36.96841171809605, 36.459376267024446, 37.95200218473162, 38.54180349622454, 39.648300647735596, 39.43459837777274, 38.46867370605469, 37.85137142453875, 37.33128138950893, 38.477015018463135, 39.19316584723336, 39.025398118155344, 41.01859310695103, 37.67979955673218, 38.354997703007285, 40.1681718145098, 38.86212239946638, 39.20171907969883, 37.23661913190569, 36.90901156834194, 38.25975179672241, 36.8314905166626, 37.76940699986049, 37.45703336170742, 36.280418464115684, 34.95486545562744, 37.74190255573818, 37.89977257592337, 37.16529934746878, 37.64583328792027, 38.24534470694405, 41.57563713618687, 43.45975235530308, 39.68834311621529, 37.5393625668117, 42.67973368508475, 40.255166734967915, 37.704159940992085, 35.867174352918354, 34.41048799242292, 34.96122305733817, 34.70715522766113, 36.71183211462838, 36.13067783628191, 37.334251744406565, 38.652008874075754, 39.42067766189575, 38.163890974862234, 39.073076656886506, 42.207454204559326, 42.87393930980137, 44.74731608799526, 47.98817825317383, 50.56404570170811, 48.659836292266846, 49.76847348894392, 52.14618526186262, 50.47960424423218, 53.184944425310405, 53.11656025477818, 53.03420673097883, 52.41017164502825, 55.4439879144941, 54.76381138392857, 59.88804531097412, 56.83391945702689, 57.33655561719622, 57.88369498934065, 59.38561412266323, 56.225191252572195, 47.886018889290945, 33.394348689488, 28.190432821001323, 14.212925842830114, 0.0485837485508195, 2.4128787772996083, 46.91530690874372, 56.76109538759504, 62.20859772818429, 55.1896664755685, 55.272763456617085, 46.45409590857369, 32.34923192432949, 32.272763524736675, 38.628298146384104, 27.154974051884242, 0.427646885492972, 0.05194647650101355, 0.04942122021956103, 0.012710373948461242, 0.023787132431087748, 0.07179320510476828, 0.08180227516485111, 0.03471600590273738, 0.03055322409740516, 0.037325610872358084, 0.052985415394817076, 0.004431509238202125, 0.04336590585964067, 0.07964162967566933, 0.03537263102563364, 0.13009393135351793, 0.09614963350551468, 0.16387669715498174, 0.08115191292017698, 0.25705764495900696, 0.13831640513879911, 0.1461880627487387, 0.12944128923118114, 0.28995199128985405, 0.1036613690001624, 0.12299390376678535, 0.08045213975544487, 0.13203433794634684, 0.10042734217963048, 0.14990578325731413, 0.24140663764306478, 0.10621617548167706, 0.19219933237348283, 0.5368088664753097, 46.24061598096575, 66.13943685804094, 51.41225399289812, 49.27293838773455, 51.04210955756051, 71.6413540158953, 66.241457257952, 56.05165999276297, 69.8050285066877, 58.934384209769114, 57.437704018184114, 3.0319778195449283, 0.38481284252234865, 4.9899942960057935, 55.635980537959504, 67.2393992287772, 65.29475825173515, 66.93602698189872, 63.902144704546245, 61.78985759190151, 55.776195185525076, 57.288633891514365, 55.42789241245815, 57.906648363385884, 56.23125008174351, 58.0514349256243, 55.30570139203753, 57.88098866598946, 57.69162940979004, 59.05041912623814, 56.13390581948416, 58.136505195072715, 55.569309098379954, 55.37828574861799, 48.956562587193076, 44.59967034203665, 43.22723436355591, 43.37820482254028, 44.98228331974575, 43.922662190028596, 41.64846120561872, 43.54740735462734, 42.04967451095581, 43.97249467032296, 42.034621238708496, 43.02411420004708, 42.93299204962594, 40.639051233019146, 41.71251664842878, 47.72520978110177, 46.53880139759609, 43.329035895211355, 46.95233733313424, 45.362196922302246, 40.80411958694458, 40.86402695519583, 39.26133462360927, 39.964165755680625, 41.289135115487234, 40.87426512581961, 42.925786767687114, 42.71215050561087, 39.24241815294538, 40.960002422332764, 40.5358635357448, 40.72600793838501, 42.56443180356707, 40.63848842893328, 43.848639556339805, 39.77237115587507, 39.97629731042044, 43.33769335065569, 39.90495320728847, 41.17746366773333, 39.57621308735439, 39.312247548784526, 42.886126450129915, 39.97614097595215, 38.308555943625315, 38.13266577039446, 37.60627024514334, 35.503696714128765, 38.437302589416504, 40.907144001552034, 39.16733939307076, 40.35041264125279, 40.159441402980256, 44.366985593523296, 45.96528318950108, 41.67871366228376, 38.712155955178396, 45.49780491420201, 41.75322961807251, 39.925262791769846, 39.466758114951, 38.28937544141497, 37.96802473068237, 38.29636880329677, 39.14513642447335, 38.40528876440865, 39.56472076688494, 41.36228922435215, 42.85410567692348, 40.29121398925781, 39.804847036089214, 45.195099694388254, 44.539099420819966, 47.8235650062561, 50.836175373622346, 51.65979746409825, 49.505313941410606, 50.92715508597237, 54.53749465942383, 51.26233271190098, 56.53642191205706, 54.52922282900129, 55.47736358642578, 54.91505977085659, 58.075871740068706, 54.37954820905413, 59.45983478001186, 58.51435170854841, 58.815396308898926, 61.97121947152274, 61.886194365365164, 60.21101842607771, 52.680671964372905, 38.072838306427, 30.347660882132395, 16.699642692293438, 0.3219536026673657, 3.174413719347545, 50.087201254708425, 61.69534819466727, 63.52851227351597, 59.667537280491416, 58.326757294791086, 50.79917969022478, 37.12176888329642, 45.19022553307669, 45.23329741614205, 39.258697782244, 0.3140605033508369, 0.29798899431313786, 0.12927856296300888, 0.08411638491920062, 0.18084445595741272, 0.12782651159380162, 0.14774645412606852, 0.19437040016055107, 0.15657576891992772, 0.12556116815124238, 0.1217936703136989, 0.04078863647633365, 0.2215644959360361, 0.13643341617924826, 0.2677652803914887], [0.02372514147178403, 0.026344486811597432, 0.024297891184687614, 0.04798630185957466, 0.034079808076577525, 0.017110312224498818, 0.05517045761059437, 0.01916039382506694, 0.04193494675148811, 0.03562126661251698, 0.07042904437652656, 0.06016945918755872, 0.04887355764263442, 0.009695348546041973, 0.04666019676785384, 0.032286965886929204, 0.039233709020274024, 0.03872036335191556, 0.08120844845793077, 2.5520650914737155, 34.28593111038208, 31.601407732282365, 30.55488395690918, 32.04436928885323, 39.86620657784598, 65.61152662549699, 51.41216366631644, 60.26465157100132, 47.0436019216265, 51.36303642817906, 4.1502441338130405, 0.749254760997636, 6.983101998056684, 63.379959787641255, 63.35526588984898, 58.0708065032959, 58.19779178074428, 56.61746917452131, 56.77762862614223, 53.0495240347726, 52.84512192862374, 50.41970035008022, 51.37750605174473, 51.15295764378139, 50.49500840050833, 48.69333355767386, 50.94317415782383, 48.58901677812849, 47.50646659306118, 44.62982899802071, 43.6471209526062, 40.64666993277413, 38.862247467041016, 40.26367827824184, 39.055737427302766, 36.6306528363909, 37.6364289011274, 39.51197004318237, 38.36341544560024, 39.623936789376394, 39.04209463936942, 39.473699365343364, 37.85750668389456, 36.416481563023154, 35.792835576193674, 38.06579283305577, 38.549766131809776, 38.05740635735648, 42.23526784351894, 41.86916725976126, 37.58410896573748, 39.39030361175537, 40.32728903634207, 36.51036562238421, 34.10941907337734, 36.80136660167149, 34.10876246861049, 34.43982328687395, 34.029646805354524, 36.08404152733939, 34.81167350496565, 33.785511425563264, 35.393300260816304, 35.36407961164202, 36.20147997992379, 40.29905155726841, 37.28216109957014, 40.06043652125767, 36.0810364314488, 33.08908305849348, 40.20873539788382, 40.8320756639753, 36.941532611846924, 34.685914584568565, 34.717282227107454, 35.3960656438555, 35.37195192064558, 33.6689692905971, 34.903400148664204, 35.720570836748394, 37.062330518450054, 35.7085018157959, 36.31903655188424, 35.460736002240864, 35.90185628618513, 35.958372933524, 38.46537331172398, 40.384497029440745, 37.11655078615461, 34.12876980645316, 38.72295345578875, 40.82904972348894, 36.04822356360299, 35.30934170314244, 34.643888405391145, 34.09605768748692, 33.95443950380598, 35.156092235020225, 35.23706306729998, 32.948069368089946, 34.95087024143764, 34.703246865953716, 35.58044304166521, 35.65469149180821, 38.72593770708357, 40.08925764901297, 43.346486295972554, 47.12220689228603, 47.83836119515555, 48.63068165097918, 47.486751079559326, 50.19918189729963, 48.37755877631051, 50.077803816114155, 50.50531952721732, 50.62640578406197, 52.088143484933035, 53.72632026672363, 51.692005838666645, 53.79370737075806, 56.44984040941511, 57.298000063214985, 56.10630757468087, 55.2518424306597, 50.13452890941075, 53.48813254492623, 38.89264930997576, 28.845755645206996, 11.522868224552699, 0.3263497496289866, 2.228025210755212, 43.7766284261431, 54.94467646735055, 41.464198453085764, 50.7029401915414, 44.49179261071341, 29.484295095716202, 24.968360321862356, 25.624845232282365, 36.38238327843802, 6.062393597194126, 0.4913441432373864, 0.07599394755171877, 0.13561992054539068, 0.04578004863911441, 0.07245909223066908, 0.07873506617865392, 0.06023839156010321, 0.03954951957400356, 0.05021216134939875, 0.06714620374675308, 0.03576174032475267, 0.06366945137935025, 0.03362554245229278, 0.04916817754773157, 0.02266470998126481, 0.03772239100986293, 0.007672053811672542, 0.03967941153262343, 0.027083104409809624, 0.08048255169498068, 0.046609930893672366, 0.022949550500405685, 0.06721434223332576, 0.05404083929689867, 0.05821601115167141, 0.03652688016050628, 0.06114686852587121, 0.016962786837081825, 0.06178051166768585, 0.07508005587650196, 0.08440724574029446, 0.035110784361937215, 0.11574606411159039, 0.05488565271454198, 5.190811565944126, 45.66490561621529, 31.570012296949113, 33.51181493486677, 43.44035645893642, 44.74916083472115, 71.05028465815953, 53.23646184376308, 67.2966593333653, 51.93890312739781, 56.70365115574428, 4.829583840710776, 0.6903986877628735, 7.993773937225342, 66.36931106022426, 64.90262276785714, 61.47666754041399, 62.61654731205532, 57.88608169555664, 57.99921921321324, 55.10411330631801, 54.615071296691895, 52.5721549987793, 53.984133175441194, 53.776666913713726, 53.770913805280415, 51.159023421151296, 54.7341217313494, 52.32192952292306, 49.49944966179984, 48.92358991077968, 45.93960959570748, 43.78014421463013, 40.29079014914376, 41.8847451210022, 41.91080781391689, 41.31797708783831, 41.53054680143084, 40.968739782060894, 40.33818728583199, 40.44198989868164, 41.77188205718994, 41.369744641440256, 40.2572477204459, 39.08946745736258, 38.451529026031494, 38.44495255606515, 41.88452277864729, 40.03885541643415, 43.83069583347866, 45.81765133993966, 39.78870289666312, 41.51623698643276, 43.05714593614851, 38.961273193359375, 37.03234209333147, 38.526055404118125, 36.69079991749355, 37.100396224430625, 38.0337164742606, 39.23958328792027, 38.798678398132324, 36.48979548045567, 37.49452236720494, 39.136624881199424, 38.90122338703701, 41.06407948902675, 40.34515632901873, 43.672429765973774, 38.97056293487549, 36.37997920172555, 41.875618662152974, 41.57919808796474, 39.27811104910714, 39.280535970415386, 38.434971468789236, 37.935263974326, 38.36508648736136, 37.42016969408308, 37.92391061782837, 38.9960697719029, 38.62262841633388, 38.094426359449116, 37.131840297154014, 36.57172169004168, 37.72070360183716, 37.94532149178641, 39.31592661993844, 40.640329701559885, 38.40700496946062, 36.95251771381923, 40.02141196387154, 41.81126792090279, 37.83668640681675, 37.16418068749564, 35.18488209588187, 36.71883589880807, 36.395362513405935, 36.46437897000994, 35.06320524215698, 35.9282351221357, 36.81843832560948, 36.2844796861921, 38.10264607838222, 38.47295727048601, 39.13101768493652, 41.93860755647932, 46.17586571829659, 49.54869154521397, 49.99578033174787, 50.62852498463222, 49.65040275028774, 52.34728697368077, 49.53040041242327, 51.74859891619001, 51.918913160051616, 53.6669340133667, 52.362010206495015, 52.930115767887656, 52.744855948856895, 55.584994656699045, 56.36036845615932, 59.073688643319265, 56.96086304528372, 57.02979612350464, 53.37332051140921, 55.67611333302089, 44.47565541948591, 34.25039454868862, 13.200842550822667, 0.21257339125233038, 2.5924647407872334, 48.57468611853463, 59.70193086351667, 49.759267125810894, 53.47887059620449, 50.413374015263145, 35.65895768574306, 30.45941570826939, 29.199526650565012, 44.02207701546805, 7.760336177689688, 0.5433776825666428, 0.03647311304562858, 0.058571278516735346, 0.014947960219745125, 0.06463198044470378, 0.10264563600399665, 0.05144588729100568, 0.0400535387785307, 0.027347051139388765, 0.07451787604285137, 0.028594578483275006, 0.005697496551355081, 0.07830407430550881, 0.10228080129516975, 0.04542469306449805, 0.07920815436435596, 0.17267555929720402, 0.22719649943922246, 0.11088108337883439, 0.16578120924532413, 0.15426743349858693, 0.14844351315072604, 0.15970058552920818, 0.15591357302452835, 0.1638845953025988, 0.22301721226956162, 0.16769826066281113, 0.08493361928101097, 0.16595125012099743, 0.1070763271834169, 0.1317134044532265, 0.11758619679936341, 0.19068834345255578, 0.2758984182562147, 7.642128212111337, 58.818140847342356, 43.12481096812657, 44.19733142852783, 43.31582736968994, 51.183161463056294, 75.56129837036133, 60.16422230856759, 70.29400798252651, 57.010455812726704, 62.559433119637625, 5.67921564408711, 0.8816265208380563, 9.55496381010328, 67.27050631386894, 67.63279233660016, 64.44693211146763, 64.05962562561035, 61.93099634987967, 60.46509320395333, 58.0415163721357, 56.06322874341692, 56.323900835854666, 57.37423917225429, 56.759354863848, 56.866975511823384, 53.66063894544329, 57.11140966415405, 55.46386671066284, 52.871459075382774, 49.78226566314697, 49.061702728271484, 46.330001081739155, 44.08509022848946, 45.364031246730256, 44.342079775674, 42.62974834442139, 42.30896391187395, 44.26995052610125, 43.32814652579171, 43.41205644607544, 44.80819967814854, 43.8334299496242, 43.17932653427124, 42.06695120675223, 40.65690810339791, 41.33268642425537, 44.36539445604597, 42.46341889245169, 46.586483410426546, 48.90860959461757, 43.71247223445347, 45.90050513403756, 46.67804329735892, 42.88838114057268, 40.02237776347569, 42.82437433515276, 39.35855729239327, 39.82674775804792, 39.91539634977068, 42.321262223379954, 40.67348303113665, 39.23335075378418, 41.309132031032014, 41.921855449676514, 40.599932874952046, 45.071762221200125, 41.98499720437186, 45.33979940414429, 40.27563612801688, 36.23893771852766, 44.404123714991975, 45.34583044052124, 40.99347536904471, 41.082370621817454, 40.34506600243704, 40.072213717869346, 40.84143141337803, 37.049486773354666, 38.78597709110805, 40.28412682669503, 39.872428689684185, 38.70881734575544, 39.42487089974539, 38.33744307926723, 39.821870122637065, 39.81099271774292, 41.819425106048584, 42.74619320460728, 39.602946281433105, 39.513359682900564, 42.22998373849051, 44.78799084254673, 38.04734883989607, 38.71036679404122, 37.339806829180034, 38.719538416181294, 38.753469944000244, 38.85292993273054, 36.947039059230256, 36.39704745156424, 39.30494499206543, 39.11079147883824, 39.86802005767822, 41.84647791726248, 42.74506759643555, 44.99634647369385, 48.216565540858674, 54.055994919368196, 52.7328633580889, 53.16686521257673, 51.41176067079817, 54.91541412898472, 52.113320282527376, 52.954667227608816, 52.39256838389805, 55.56632832118443, 54.380583490644185, 54.06933198656355, 54.06332179478237, 55.937706061771934, 59.18935530526297, 63.72659846714565, 60.0631468636649, 60.657655579703196, 56.76424292155674, 59.48599474770682, 48.62172542299543, 36.5914580481393, 14.983517544610159, 0.40723997194852146, 2.9695022233894894, 54.47381441933768, 62.50091539110456, 52.13637440545218, 58.194748469761436, 56.47172723497663, 39.43355962208339, 38.43169886725289, 37.188558442252024, 52.88630042757307, 14.381273746490479, 0.6930657646485737, 0.2355543002486229, 0.25630417253289905, 0.18606093818587915, 0.20688270804073128, 0.2165588888206652, 0.2544267475605011, 0.13670341883386883, 0.10874373878219298, 0.14998313624944004, 0.1226543512727533, 0.12247111967631749, 0.14830259499805315, 0.23040514226470674, 0.11345420352050237], [0.04631472405578409, 0.028784320623214756, 0.042314437816717794, 0.05367756521861468, 0.060001698189548085, 0.04415742713691933, 0.032066947514457364, 0.012784140034844833, 0.0572328885485019, 0.08279306521373135, 0.07247342967561313, 0.02937623725405761, 0.03643341874703765, 0.03944608708843589, 0.09893094854695456, 0.019286903286618844, 0.11516538741333143, 0.04782650347000786, 0.141916942649654, 0.05530593730509281, 10.580139245305743, 48.798880168369834, 23.24783001627241, 30.669504914964946, 33.12825700214931, 58.12375177655901, 57.45353896277291, 59.83197334834507, 52.99686711175101, 57.997346673692974, 12.169006398745946, 1.8477381425244468, 11.303152288709368, 66.73832988739014, 60.488988058907644, 56.31035532270159, 55.25077240807669, 54.95643629346575, 56.505943638937815, 53.4811635017395, 52.71459306989397, 52.34479604448591, 50.662637165614534, 52.77298920495169, 50.2550801549639, 45.6748172215053, 44.949849128723145, 42.95672014781407, 41.0939428465707, 38.91148935045515, 39.82548318590437, 38.91346263885498, 39.574809551239014, 39.16771806989397, 37.91553109032767, 39.08708422524588, 37.86527476991926, 38.54546867098127, 37.3279983656747, 39.052273750305176, 38.581064292362754, 40.09106765474592, 38.20378058297293, 37.929625511169434, 37.57424947193691, 38.443948541368755, 39.216650758470806, 36.83491250446865, 40.65177685873849, 39.39328786305019, 37.50705344336373, 37.57598304748535, 37.12773043768746, 36.28585542951311, 35.37304278782436, 35.62925066266741, 34.33595814023699, 36.42818580354963, 34.045408793858115, 35.24675233023507, 36.258896418980186, 36.92507927758353, 36.25741992677961, 38.32894195829119, 39.502451011112754, 44.21433367047991, 45.505076204027446, 46.52345282690865, 41.21764162608555, 31.15808834348406, 42.115331513541086, 45.707734312329976, 41.96582365036011, 41.395699637276785, 38.72711195264544, 35.62461621420724, 36.83032669339861, 34.481133801596506, 35.825954164777485, 35.10910504204886, 34.52749913079398, 34.21333980560303, 35.317752497536794, 36.38950865609305, 35.91182000296456, 34.47731924057007, 34.767079966408865, 35.7979598726545, 37.12461069652012, 38.286241803850444, 39.16439683096749, 38.12620047160557, 37.035430567605154, 35.71897275107247, 35.67595297949654, 34.9468993459429, 34.61974688938686, 34.01559059960501, 35.47855813162667, 34.69092770985195, 35.114896365574424, 36.59541852133614, 35.61136599949428, 34.66284656524658, 36.8719915662493, 36.90679856709072, 37.95853696550642, 43.78347587585449, 48.36532647269112, 52.15242821829659, 49.54758678163801, 50.839375019073486, 48.3092371395656, 49.45334141595023, 50.31112779889788, 51.34103495734078, 49.979806423187256, 51.85124465397426, 51.613199370247976, 54.80614675794329, 54.704452923366, 54.7796220098223, 49.44608402252197, 50.28888314110892, 53.33901725496565, 60.111353465488975, 52.185706615448, 43.83282893044608, 10.904963186808995, 0.11512083480400698, 3.995317109993526, 44.71811628341675, 39.488596303122385, 40.4426326070513, 50.99562610898699, 48.79420403071812, 24.839870759419032, 25.422748191016062, 25.580251693725586, 35.84693772452218, 0.19456955018852437, 0.2850123649196965, 0.005574393759681178, 0.017977003307480897, 0.023425787088594267, 0.04972767038270831, 0.05150820394711835, 0.0373762601188251, 0.021663484063797762, 0.028808252553322485, 0.025061087017612796, 0.03223228953512652, 0.10979911179414817, 0.06056658537792308, 0.02523130431239094, 0.020912601945123503, 0.07804776448756456, 0.02619793851460729, 0.03336392988317779, 0.05560805502214602, 0.09322171418794564, 0.06484246200748853, 0.07302615073110376, 0.016485194875193492, 0.0464649279601872, 0.032444860985768695, 0.016705460912947143, 0.060654428521437306, 0.06819339362638337, 0.03437248058617115, 0.05977390719843762, 0.00361233002539458, 0.11036576317357165, 0.022843125675405775, 0.05445161082648805, 0.05365364007385714, 16.223355838230678, 59.51118196759905, 22.024398156574794, 42.836092472076416, 40.26312242235456, 64.86654772077287, 62.64344378880092, 64.26291601998466, 57.74771179471697, 63.059856278555735, 14.03136420249939, 1.8452626296452113, 11.339345455169678, 69.24856117793492, 62.71346773420061, 60.74393136160714, 57.76712506158011, 58.01848309380667, 58.60984774998256, 56.298946380615234, 54.853196484701975, 54.58335624422346, 53.13783911296299, 55.48582649230957, 50.88659150259835, 48.13596296310425, 48.108878884996685, 45.43940877914429, 44.905978202819824, 42.164757524217876, 41.93528979165213, 41.52569695881435, 41.58361366816929, 41.14516496658325, 41.47633695602417, 40.753501960209434, 41.17362478801182, 40.64369262967791, 39.26025765282767, 40.315706389290945, 40.606009074619834, 42.578355993543354, 40.25137301853725, 39.66340255737305, 38.95336266926357, 40.54314872196743, 42.18473359516689, 40.565389905657085, 42.271089281354634, 41.37561934334891, 40.30610745293753, 38.03999069758824, 41.07238258634295, 38.94546256746565, 39.21772078105381, 38.21835790361677, 37.24688162122454, 38.20426000867571, 37.83039828709194, 37.79755762645176, 39.66065454483032, 40.22219058445522, 38.848559515816824, 40.3388022014073, 42.281782558986116, 47.33120175770351, 46.05162845339094, 49.630450998033794, 44.09729126521519, 34.50228411810738, 43.53134659358433, 47.59418412617275, 44.00653389522007, 41.384148257119314, 40.70755352292742, 39.646514960697715, 39.43110343388149, 36.75097131729126, 39.32060970578875, 37.96381064823696, 35.75385965619768, 36.18190690449306, 37.032088484082905, 38.20316914149693, 37.50363840375628, 36.7336425100054, 37.292781421116416, 38.12357752663748, 39.2229562486921, 40.22549792698452, 41.74932125636509, 40.57969624655587, 38.989955357142854, 36.832723821912495, 35.885705198560444, 35.67126294544765, 34.62158121381487, 36.647662026541575, 37.139104638780864, 37.04390042168753, 37.62509291512625, 37.39714683805193, 37.30959606170654, 36.77452571051461, 37.14048385620117, 39.591453960963655, 41.81469338280814, 45.10926512309483, 49.28358997617449, 53.25391224452427, 51.71945469720023, 53.39355366570609, 51.15294027328491, 51.144459996904644, 52.74532495226179, 52.14606019428798, 51.4644592830113, 53.63258906773159, 53.87416403634207, 56.240380014692036, 55.551688466753276, 56.55023145675659, 51.286964075905935, 51.498838969639365, 56.498463903154644, 61.09748349870954, 55.59526062011719, 44.62355824879238, 10.471484184265137, 0.047277595781322033, 5.08352530002594, 49.954233578273225, 46.106289931706016, 41.72790343420846, 60.01109095982143, 54.252392700740266, 32.602514607565745, 32.415747029440745, 30.3408169065203, 43.06050886426653, 0.25553297677210396, 0.12405146844685078, 0.03824465602104153, 0.027871002310088704, 0.037022980861365795, 0.05473338945635727, 0.003189876243206007, 0.04922327798392091, 0.08523454277643136, 0.04111097114426749, 0.023094436386600137, 0.03588961364169206, 0.0815326457044908, 0.07929607214672224, 0.012231647984922996, 0.05116194752710206, 0.12257038934954576, 0.06751876018409218, 0.15074302761682443, 0.10324777476489544, 0.1271012390830687, 0.11753874006015913, 0.1553957693810974, 0.08994335867464542, 0.17375577347619192, 0.15131657969738754, 0.13601333514920302, 0.11509967808212553, 0.1318681240081787, 0.08386922853865794, 0.16655878323529447, 0.052999708734984906, 0.18657439920519078, 0.1148680533681597, 0.24376880803278514, 0.13602538593113422, 26.04926552091326, 68.82682636805943, 34.467574392046245, 47.25635576248169, 42.590136664254324, 69.3966759272984, 66.4612009865897, 68.30173710414341, 61.607905115400044, 70.49148273468018, 14.570534859384809, 1.9006866727556502, 12.917620079857961, 71.22973578316825, 65.33647523607526, 64.00699996948242, 59.812740734645296, 60.60667664664132, 61.20398548671177, 58.6544690813337, 58.093829359327046, 57.86571652548653, 55.76344871520996, 59.216501917157856, 53.603326729365754, 49.997760568346294, 50.25437143870762, 47.970363071986604, 46.99459975106375, 45.73120880126953, 44.07128068378994, 42.931018761226106, 44.93056092943464, 43.618532589503694, 44.424996103559224, 41.740028040749685, 44.93644257954189, 41.64780112675258, 42.38791629246303, 43.13537917818342, 42.78865017209734, 45.67670713152204, 44.083162103380474, 43.78865228380476, 42.43598740441458, 42.95246090207781, 46.46621356691633, 44.30132164273943, 45.29279484067644, 43.93162884031023, 44.562209129333496, 41.10690123694283, 43.662302766527446, 42.09688057218279, 42.840011256081716, 41.674520424434114, 40.794854164123535, 42.44341502870832, 39.17575018746512, 40.56162050792149, 42.45516095842634, 44.54614836829049, 43.09536797659737, 43.69228771754673, 44.92635032108852, 51.062200273786274, 48.50528056280953, 53.450431619371685, 44.835335867745535, 34.7293929372515, 46.0250620160784, 49.75807898385184, 46.4159711429051, 45.67426831381661, 43.03341088976179, 40.45010192053658, 41.094102655138286, 38.346732820783345, 41.89787721633911, 39.19930110658918, 37.51504039764404, 37.718848432813374, 39.2367901120867, 39.87209170205252, 38.87001207896641, 38.10178450175694, 38.11586850030081, 39.666855812072754, 41.273856026785715, 43.41435629980904, 43.29806429999215, 44.71583380017962, 41.22300216129848, 40.512920583997456, 37.95796026502337, 39.550775732312886, 37.05613619940621, 38.394220284053254, 39.383035796029226, 39.6218558038984, 40.88842902864729, 40.61909253256661, 39.342190810612266, 39.72303547177996, 40.212376253945486, 41.89072404588972, 44.2158796446664, 50.01748303004673, 51.51585858208792, 56.79545770372663, 52.60821614946638, 55.77180044991629, 52.013787337711875, 53.9987348147801, 54.29547153200422, 55.2691399710519, 52.2501893724714, 56.8239175251552, 54.81621469770159, 57.871250765664236, 56.960744925907676, 59.57103375026158, 53.08331659861973, 53.55856990814209, 58.92938845498221, 66.39282376425606, 57.86352436883109, 47.698608602796284, 13.234771473067147, 0.22482922646616185, 5.7214190023286005, 53.99378422328404, 48.63408974238804, 49.43013790675572, 61.95882388523647, 59.72153173174177, 35.44900744301932, 40.669081347329275, 38.07270629065377, 53.49043239865984, 1.4320810522351946, 0.46532992486442837, 0.08947324247232505, 0.11189501825720072, 0.07241937079067741, 0.12406252856765475, 0.15628543735614844, 0.10630941297858953, 0.18182401625173433, 0.1582193300127983, 0.08457681842680488, 0.14288511712636265, 0.15940802837056772, 0.13099677647863114, 0.09459775606436388, 0.15258039188172134], [0.038447507457541566, 0.04903765455154436, 0.0028055141447111964, 0.032995142707867284, 0.04208709805139473, 0.050345724182469506, 0.0033091622754000127, 0.013696774723939598, 0.021901973855814764, 0.10014252710555281, 0.016561774337398152, 0.0382459248815264, 0.037852344036634476, 0.03281383475820933, 0.0022137361894627766, 0.02995778926249061, 0.039540817362389395, 0.1089812396094203, 0.01759930866371308, 0.06334940676710435, 2.1797992842538014, 33.31892599378313, 34.82186998639788, 27.350461619240896, 25.08556948389326, 36.87860972540719, 61.16736848013741, 60.15193789345877, 56.09772307532174, 55.536569186619346, 30.34379768371582, 0.628019280731678, 5.032968470028468, 63.50279699053083, 58.20441688810076, 59.26036589486258, 50.987319537571494, 47.49713168825422, 50.41890825544085, 49.33431529998779, 49.90949412754604, 47.32119287763323, 46.66013084139143, 47.41650479180472, 42.647410665239605, 41.00090994153704, 39.920176710401265, 41.308062008449006, 40.615135533469065, 40.46456459590367, 39.48574754170009, 39.50219392776489, 38.19160386494228, 39.34373678479876, 38.534580843789236, 37.90242678778512, 38.299415588378906, 38.68642677579607, 38.152770383017405, 39.410304001399446, 39.902229513440815, 39.03979478563581, 38.06616108758109, 37.99979884283883, 37.7407352583749, 38.947904859270366, 39.78486749104091, 36.653053828648154, 38.96585553033011, 39.324868951525005, 36.894833769117085, 37.30190440586635, 36.56003829411098, 36.51665374210903, 35.80286182676043, 35.504572187151226, 36.41739872523716, 36.337650775909424, 36.05096115384783, 37.562666824885774, 37.28565256936209, 37.38635975973946, 38.3216359274728, 39.79828446252005, 43.67401742935181, 48.97593763896397, 52.78484630584717, 51.07553039278303, 51.584538051060264, 32.41791834150042, 37.95973900386265, 52.65796872547695, 50.37310225622994, 53.17015865870884, 48.78515747615269, 44.41664784295218, 40.202968393053325, 38.817313466753276, 36.15106037684849, 36.8748368535723, 35.03035763331822, 36.41574852807181, 35.15398693084717, 37.368113790239605, 34.15936272484915, 36.05070059640067, 35.78249665669033, 34.9114739554269, 34.46348190307617, 35.284884044102256, 36.26917627879551, 36.75170087814331, 35.45261008398873, 35.71548822947911, 36.545565196446006, 32.79642840794155, 34.38642985480172, 33.275176661355154, 34.31273031234741, 35.15724563598633, 34.97223942620413, 34.91857154028756, 35.86053534916469, 35.345684255872456, 36.660248688289094, 37.31806244168963, 37.543166705540244, 37.05484383446829, 41.975116865975515, 46.697206429072786, 48.814822810036794, 51.36017377035958, 49.78353370938982, 48.3960896219526, 49.57601881027222, 49.882271085466655, 50.12053871154785, 51.889765466962544, 56.59868471963065, 52.629616601126536, 52.947187491825645, 44.331150259290425, 46.35587617329189, 50.99404886790684, 55.93060152871268, 56.12375102724348, 55.89190353666033, 39.36449452808925, 4.994279163224356, 0.2524699882737228, 7.7900475433894565, 43.65475007465908, 52.5401029586792, 55.32266889299665, 57.821154253823416, 25.16922926902771, 25.545314414160593, 28.584406103406632, 32.74807936804635, 17.136823347636632, 0.39242785104683464, 0.038686551951936314, 0.10873119945504836, 0.04064823401027492, 0.04231479065492749, 0.02560873602383903, 0.06569086148270539, 0.045431084864373715, 0.013753077863449497, 0.044038320492420874, 0.03354422342298286, 0.0668024511209556, 0.028382887431819524, 0.14811918698251247, 0.06612464892012732, 0.10648200514593295, 0.01176357247667121, 0.04487339693254658, 0.011653972107784023, 0.049346883315593004, 0.016916958581922308, 0.06621861923485994, 0.08368140326014586, 0.034731951475675614, 0.05899810418486595, 0.08615487374897514, 0.03302824503875204, 0.01953042611213667, 0.06592814517872674, 0.005922641255892813, 0.01829187917922224, 0.03288219037598797, 0.06259034999779292, 0.022109536021681767, 0.008087339295473481, 0.051256009444062195, 3.8426786490849087, 47.28535754340035, 37.221169812338694, 31.245107582637242, 33.75804172243391, 42.14279426847185, 69.71365969521659, 63.480159759521484, 61.774606295994346, 58.76128373827253, 34.003424303872244, 0.6321385854056903, 5.69186440535954, 67.69376277923584, 61.19238199506487, 61.77396706172398, 54.15877614702497, 49.218697275434224, 53.008717264447895, 52.95117923191616, 52.3017623765128, 48.80951091221401, 48.668938432421, 50.15030132021223, 47.394746507917134, 44.753882135663716, 43.099880831582205, 43.71801342282976, 40.98153141566685, 41.13687229156494, 42.781476157052175, 43.185941219329834, 39.57853378568377, 40.77501358304705, 39.99810075759888, 39.77214533942086, 39.495697362082346, 41.46990292412894, 40.37414421354021, 41.8126471383231, 41.13380118778774, 41.19775240761893, 40.7655987739563, 41.65269960675921, 38.83945737566267, 41.28304501942226, 41.7042760848999, 40.60713815689087, 42.46639272144863, 42.89864362989153, 40.10820886066982, 40.26257004056658, 39.77087034497942, 39.92872646876744, 38.984820638384136, 39.12823493140084, 38.22391993658883, 38.950211661202566, 38.71094002042498, 38.62179463250296, 41.61398771830967, 41.60285670416695, 42.706126417432515, 43.32988010134016, 45.787312030792236, 50.63645287922451, 54.6422769682748, 54.68892369951521, 54.4816380909511, 35.33517163140433, 40.903054986681255, 54.9092823437282, 52.13959836959839, 52.73785563877651, 49.085851192474365, 44.523816858019146, 42.92346954345703, 41.26394442149571, 37.39731012071882, 38.623309339795796, 38.43036828722273, 37.85168409347534, 35.490192890167236, 39.256773131234304, 35.244400365012034, 38.4818058013916, 37.397483825683594, 36.77172211238316, 37.03669513974871, 37.87067004612514, 39.06367574419294, 38.018593720027376, 36.710140228271484, 37.66943979263306, 37.406950746263774, 35.345416750226704, 36.872332027980256, 35.451456683022634, 37.81030409676688, 39.06989785603115, 37.575187478746685, 37.312066146305625, 38.355015073503765, 37.99878787994385, 38.17169032778059, 38.35788467952183, 38.77658660071236, 40.09672348839896, 45.6214724268232, 48.97449936185564, 50.904743671417236, 53.041498865400044, 51.180538518088206, 49.711942945207866, 52.935490199497764, 51.84203481674194, 52.4992892401559, 52.874505860464915, 57.985677174159456, 54.85659415381295, 54.00062125069754, 46.5782185282026, 47.48610837118966, 52.513060569763184, 57.1900771686009, 58.38631725311279, 57.889642647334504, 39.540096351078574, 4.012903869152069, 0.3166136677776064, 9.749273657798767, 49.95912511008126, 54.228167806352886, 57.59583112171718, 63.109438623700825, 30.76457016808646, 34.409084456307546, 32.533963680267334, 39.78594446182251, 20.191678762435913, 0.44808528306228773, 0.0733754944854549, 0.04624060767569712, 0.03379166478823338, 0.1467389381889786, 0.010059765955832387, 0.11354842489319188, 0.02032768270666046, 0.0127518756947081, 0.021386499283835292, 0.08199997312788453, 0.03079382243699261, 0.025216876961556927, 0.05374061469254749, 0.09290705035839762, 0.01166265650785395, 0.14913776304040635, 0.1221874648971217, 0.10497248186064617, 0.09733882040849753, 0.09558273106813431, 0.12284682451614312, 0.17377835512161255, 0.10763087349810771, 0.17382594756782055, 0.14649139504347528, 0.08291638216802052, 0.13710279097514494, 0.15131337701209954, 0.1324986866010087, 0.16724300437739917, 0.08312667374100004, 0.1350754097636257, 0.26954372067536625, 0.19781262188085488, 0.18182921382997716, 5.973093177591052, 62.02412305559431, 45.2803749356951, 44.3561464037214, 37.312427452632356, 49.06561803817749, 71.02095631190709, 69.93402181352887, 66.3602019718715, 64.62069266183036, 36.84497349602835, 0.7496414173926625, 6.854393567357745, 70.08383192334855, 62.02269867488316, 65.71395002092633, 55.49962908881051, 54.48307984215872, 55.23447888238089, 56.843532289777485, 54.21163804190499, 51.08871807370867, 51.35603264399937, 53.14238323484148, 48.978334767477854, 46.64776652199881, 44.440587861197336, 48.78001580919538, 44.397839069366455, 45.06062078475952, 44.37078973225185, 47.21608052934919, 43.31869002750942, 44.11985206604004, 42.969932147434776, 41.938656193869456, 42.6364290373666, 44.319470337459016, 45.492871693202424, 46.00709744862148, 45.53384174619402, 44.09442513329642, 43.7103773525783, 43.97771971566336, 42.64516292299543, 44.21889863695417, 45.45282575062343, 43.93491881234305, 45.12889378411429, 45.47610221590315, 42.8795291355678, 43.39122574669974, 41.73989602497646, 43.742436340876985, 43.88621541431972, 43.00885943004063, 43.194765431540354, 43.48434897831508, 43.3581349509103, 43.67472614560808, 44.27746500287737, 44.342006819588796, 45.04425082887922, 45.97511141640799, 48.62630081176758, 53.644838741847444, 55.67086049488613, 57.60180309840611, 54.97590514591762, 33.18848746163504, 41.62683841160366, 57.47455031531197, 54.39233636856079, 55.30642400469099, 51.302305698394775, 48.27550710950579, 44.37736620221819, 43.02849503925869, 38.53802020209176, 40.88090065547398, 40.38805798121861, 40.17331000736782, 37.139618805476594, 40.59208835874285, 37.21052169799805, 39.90863575254168, 39.26141800199236, 38.62592533656529, 37.376097270420615, 39.49681602205549, 41.425198214394705, 40.04875659942627, 38.24571296146938, 38.411663736615864, 41.08043902260916, 39.31505809511457, 39.251131193978445, 37.34966284888131, 39.09012753622872, 41.458608627319336, 39.520554542541504, 39.74117374420166, 40.622372082301546, 40.377583571842735, 41.01639747619629, 41.750325271061485, 40.955989837646484, 41.47470760345459, 47.21432958330427, 51.89241967882429, 52.953329699380056, 56.36460338320051, 53.00523969105312, 52.29121848515102, 55.37811204365322, 54.5771028654916, 54.93621356146676, 56.11059808731079, 60.549437386649, 55.32704278400966, 59.130121912275044, 47.549434253147666, 49.63414396558489, 53.338603837149485, 59.3969327381679, 61.79902226584298, 62.02196911403111, 42.21773059027535, 6.409877351352146, 0.2565886415541172, 11.666172214916774, 54.323413712637766, 61.212691579546245, 65.89201845441545, 67.9948490687779, 36.18778508050101, 40.22574806213379, 42.49333436148507, 48.269038336617605, 32.51779522214617, 0.3770021716398852, 0.12392538306968552, 0.16868907106774195, 0.08342621302498238, 0.22687563379960402, 0.09373382492257015, 0.1283603829464742, 0.19715928765279905, 0.09067635291389056, 0.07353729116065161, 0.17223478294909, 0.20821326092949935, 0.11731814832559653, 0.2059818170964718, 0.23870802244969777, 0.14591730013489723], [0.027977496684928025, 0.01567376877314278, 0.0965666136305247, 0.06163915925260101, 0.03443198132195643, 0.03711569927898901, 0.047021923786295314, 0.016769906472680823, 0.0904761782980391, 0.06563312493796859, 0.0133325506966295, 0.09781452095402138, 0.01267317750690771, 0.028648484697831527, 0.011602348315396478, 0.11696343735924788, 0.03776169515081814, 0.04995381931907364, 0.07734128061149802, 0.09734498829181705, 0.025072201421218257, 23.104519946234568, 42.391108989715576, 48.775343145642964, 42.08716699055263, 18.93862325804574, 51.94704294204712, 62.0076071875436, 53.877460956573486, 53.720876353127615, 36.03736005510603, 0.05867356088544641, 0.34019178258521215, 51.83543055398123, 60.063695771353586, 58.40976047515869, 58.221349648066926, 46.422766481127056, 43.01732928412301, 43.71472692489624, 44.01790809631348, 42.52811704363142, 43.66711439405169, 40.785720757075715, 41.938579763684956, 39.26716068812779, 41.51427412033081, 41.1345967565264, 41.177967412131174, 39.576088019779746, 39.206367424556184, 40.412119592939106, 40.09888785226004, 38.20812668119158, 39.1796863419669, 40.153969696589876, 38.74193940843855, 38.94813067572457, 38.26917355401175, 39.872043064662385, 39.56474508558001, 39.753791672842844, 37.542054993765696, 37.33794471195766, 38.07667718614851, 39.111552306583945, 38.45177568708147, 35.00971106120518, 38.58277007511684, 35.314938477107454, 37.85858712877546, 36.02443640572684, 35.3390348298209, 35.29156126294817, 36.94407912663051, 34.36357375553676, 36.905766759599956, 36.80255821772984, 37.424060685294016, 38.449076311928884, 38.50359187807356, 37.209507261003765, 40.335265568324495, 43.75858048030308, 47.37301254272461, 47.64399923597063, 53.93260186059134, 50.91944258553641, 57.35523237500872, 32.408173492976594, 30.087207657950266, 57.89843906675066, 54.60191835675921, 53.86207069669451, 49.084795066288535, 46.526457922799246, 40.72325645174299, 40.6477746963501, 38.4030305998666, 37.84899166652134, 37.83093329838344, 36.59697839191982, 35.58082519258772, 36.247730663844514, 36.03223923274449, 37.42916413715908, 34.17561108725411, 36.002987316676546, 35.222061906542095, 33.644296237400596, 35.67327444893973, 36.80355528422764, 36.3444322177342, 35.786651679447715, 36.32799972806658, 34.450759751456125, 34.73836306163243, 34.97454275403704, 35.84925494875227, 35.68486751828875, 34.65727063587734, 34.66410766329084, 37.73468337740217, 34.754191058022634, 34.74638475690569, 35.71352883747646, 38.155883175986155, 36.748438698904856, 36.720430510384695, 35.909971782139365, 41.1747955594744, 44.44014317648751, 47.09405973979405, 48.560904366629465, 53.94726603371756, 51.37970863069807, 55.52261025565011, 51.42926665714809, 51.00427314213344, 44.82690075465611, 44.364772592272075, 41.927320207868306, 52.37703916004726, 53.78179815837315, 59.16968495505196, 55.86455890110561, 60.63463619777134, 21.655252524784633, 0.09502866651330676, 0.10977693726973874, 7.971648267337254, 53.832499163491384, 51.76342984608242, 52.307814257485525, 51.753427914210725, 26.375843014035905, 27.214697292872838, 23.506278685161046, 27.587652274540492, 1.9896236147199358, 0.2603926717170647, 0.0627550779442702, 0.09549596679529973, 0.08642223690237318, 0.06380485304232154, 0.06617728966687407, 0.06670725944318942, 0.08180235658905335, 0.01045160975107657, 0.006740102078765631, 0.03578004380688071, 0.033037045637943914, 0.014983773298029388, 0.014028129666777594, 0.07881997805088758, 0.07940547234777894, 0.02185741446114012, 0.040968821450535736, 0.057404971814581325, 0.0905084562088762, 0.08434727002999612, 0.06779594173921005, 0.06375911978206464, 0.025949433545715044, 0.09739086404442787, 0.03918069168659193, 0.026315738979194845, 0.025258009754387394, 0.07056568097323179, 0.02778918286120253, 0.03163943313328283, 0.0752850209495851, 0.06056052606020655, 0.0340631534345448, 0.028354390657373836, 0.13577295733349665, 0.10817416970218931, 29.854877267565044, 52.39740433011736, 46.604920455387656, 51.41105195454189, 26.49761540549142, 63.00605637686593, 69.27653462546212, 58.12845223290579, 59.417631421770366, 40.588155678340364, 0.348806300333568, 0.3421858070152146, 57.56140627179827, 61.418066433497835, 62.770408221653526, 60.321265493120464, 49.99557188579014, 44.51104259490967, 46.36730595997402, 46.2823885508946, 45.978477818625315, 43.37810059956142, 45.18070650100708, 43.90324892316546, 42.72800976889474, 41.775290148598806, 42.72657149178641, 43.20666422162737, 41.82358707700457, 42.83566863196236, 43.56793580736433, 42.105795110974995, 40.921450342450825, 40.98789249147688, 42.90018612997872, 41.44359357016427, 42.5661758014134, 40.36728981563023, 42.68566744668143, 43.39112499782017, 41.02777862548828, 40.867879731314524, 39.35841832842146, 39.31172643389021, 42.144100529806956, 41.459508419036865, 37.24549198150635, 40.33178104673113, 37.87589856556484, 39.69717080252511, 39.354892117636545, 38.36662203924996, 38.11098044259207, 39.21727957044329, 37.33492571966988, 39.53474971226284, 39.39147438321795, 39.8014771597726, 42.56867020470755, 41.32803807939802, 41.567570277622764, 44.53297805786133, 44.98974915913173, 48.666454451424734, 49.95008202961513, 56.242693764822825, 54.57580007825579, 61.085574286324636, 37.995560441698345, 33.35657133374895, 62.042264802115305, 58.07368653161185, 56.31502798625401, 52.73726504189627, 48.3358278955732, 43.35523407799857, 42.98147310529436, 39.98964479991368, 39.17608022689819, 39.176973070417134, 40.048794814518516, 36.86749260766165, 37.815317222050254, 37.94815288271223, 39.1580114364624, 35.545208726610454, 37.41190481185913, 37.128053528921946, 35.66432169505528, 37.111614091055735, 39.311062880924766, 37.91600009373256, 38.18542691639492, 37.32001835959298, 36.2962395123073, 36.94207109723772, 35.9684339250837, 38.8963075365339, 36.80709886550903, 36.87205062593733, 37.050240652901785, 38.116094316755024, 35.99636568341936, 36.49094888142177, 37.97655364445278, 40.71739912033081, 37.107299259730745, 38.25566973005022, 39.75162730898176, 43.60487590517317, 45.00235666547503, 49.03959356035505, 49.79821525301252, 55.5406790460859, 53.734355858394075, 56.86622858047485, 53.5159843989781, 53.03719098227364, 45.58536958694458, 46.85687255859375, 44.84694283349173, 55.55650356837681, 56.33621651785714, 61.03866004943848, 56.72619111197335, 62.18862860543387, 20.5603814465659, 0.18162836746445724, 0.10108227096498013, 11.278687681470599, 59.939260482788086, 56.77367510114397, 57.99515104293823, 56.31513915743147, 33.996507372174946, 37.265117168426514, 27.98650666645595, 35.62325436728341, 2.264897563627788, 0.3522504898054259, 0.061288146302103996, 0.08027285044746739, 0.05721835432840245, 0.09802989475429058, 0.04846707784703799, 0.05948139075189829, 0.01954069234696882, 0.06893274573875324, 0.016990879883191416, 0.06425513566604682, 0.04972863729510989, 0.02074660174548626, 0.0385052745363542, 0.043923776995922835, 0.017055720689573457, 0.0833334776439837, 0.11246973741799593, 0.17368075464453014, 0.2252636652972017, 0.1801294293254614, 0.12129283004573413, 0.16895022562571935, 0.08820640402180807, 0.13082407574568475, 0.16565899151776517, 0.10361133382788726, 0.29361108637281824, 0.1349928184811558, 0.12300462462008, 0.11600332387856074, 0.2590472453406879, 0.09385887214115687, 0.0955426703606333, 0.17660412777747425, 0.2999272160232067, 0.1515110885458333, 42.6960688999721, 62.20231655665806, 56.177179200308665, 55.337875025612966, 28.454252447400773, 65.34871796199253, 74.16086809975761, 64.6673150743757, 63.881744793483186, 47.535218238830566, 0.3226469297494207, 0.713033313197749, 60.618919372558594, 64.98040785108293, 65.74022115979875, 63.42891679491316, 52.95238821847098, 47.8737587928772, 49.737890992845806, 49.97630453109741, 48.94348955154419, 47.66860280718122, 47.57664687292916, 46.267519405909944, 46.23468221936907, 44.870681353977744, 45.58038772855486, 47.83841330664498, 45.425515856061665, 45.046877247946604, 46.68577316829136, 46.797646113804404, 43.82502610342843, 43.146923610142295, 46.59458153588431, 44.16217006955828, 46.53292669568743, 44.63042654309954, 46.00466905321394, 46.06685195650373, 43.37794426509312, 43.73472384044102, 43.47440610613142, 43.912774903433665, 44.237446853092735, 43.008873326437815, 39.62300225666591, 44.942216532570974, 40.78978892735073, 43.13634497778756, 42.587961878095356, 42.01741055079869, 40.82143102373396, 41.8814377784729, 41.251225743974956, 43.124362809317454, 43.11075128827776, 42.4883941922869, 45.739008154187886, 44.247969899858745, 42.76045438221523, 46.35233954020909, 48.21818099703108, 52.423338481358115, 53.05365126473563, 60.188367298671174, 54.09608949933733, 63.40103367396763, 31.959660325731548, 31.279820782797678, 63.34483664376395, 59.09693731580462, 59.47780976976667, 54.80327020372663, 50.25194999149868, 46.694402830941335, 44.348409584590364, 41.6832959992545, 40.530412673950195, 40.36904770987374, 40.78026294708252, 38.92920725686209, 41.6043609891619, 40.23874814169747, 41.32863562447684, 37.95082793916975, 38.97351244517735, 39.21378115245274, 37.26068769182478, 40.68542698451451, 40.46297345842634, 41.40666389465332, 41.327277251652305, 40.48404734475272, 38.95723976407732, 40.02164472852434, 39.67784786224365, 42.24603060313633, 39.09284428187779, 39.24944625582014, 38.48658616202218, 42.17445720945086, 39.07359777178083, 37.068549156188965, 40.153611864362446, 43.965984208243235, 40.50790745871407, 40.0687917300633, 41.1148465020316, 44.662280559539795, 47.31663833345686, 51.02057709012713, 52.610029629298616, 57.68330546787807, 54.31621190479824, 61.308243206569124, 56.97405072620937, 55.83450446810041, 48.757430689675466, 47.576893533979145, 46.98730066844395, 57.565269470214844, 58.74543489728655, 63.259811537606375, 59.60724081311907, 65.69323049272809, 24.79178053992135, 1.090504678232329, 0.2920271413666861, 11.081313678196498, 65.42801775251115, 61.85461480276925, 62.49387686593192, 62.29193442208426, 39.18250731059483, 42.84539610998971, 38.83434002740042, 50.4078745160784, 6.524579516478947, 0.6337916595595223, 0.2459145528929574, 0.3236422320561749, 0.18494909070432186, 0.25533508881926537, 0.16340398894889013, 0.17328256315418653, 0.17354208922811917, 0.10128524793045861, 0.10332634233470474, 0.17949869031352655, 0.1164579830531563, 0.11861344453479562, 0.19415955218885625, 0.13107528298028878, 0.1384728888847998], [0.07608535300408091, 0.03538609994575381, 0.06218164121466024, 0.010016246416073824, 0.02972274812470589, 0.02482085339059787, 0.03752993133717349, 0.03451178382549967, 0.054999029130807946, 0.010790238589314478, 0.11134556774049997, 0.044601857396108766, 0.029252248550099984, 0.09219882943268333, 0.019148780698222772, 0.044012844895145724, 0.03130612994677254, 0.11245271975972823, 0.06549908713038478, 0.04950704472139478, 0.042232742200472524, 1.4314197791474206, 37.17369277136666, 51.33123452322823, 38.74440949303763, 24.101999861853464, 33.00072281701224, 58.46169131142752, 58.90690408434187, 46.688562870025635, 43.368824754442485, 3.1832131786005835, 0.29183818293469294, 29.77393422807966, 64.37113421303886, 55.218129771096365, 58.912414005824495, 54.10414940970284, 49.00344903128487, 42.64452716282436, 43.79030248097011, 43.408332211630686, 46.4459456716265, 46.67969696862357, 46.51712301799229, 44.73277003424508, 45.070046016148154, 39.99746152332851, 39.55977017538888, 39.532105922698975, 40.64750024250576, 39.87329026630947, 37.988598346710205, 39.005665234157014, 39.83127103533064, 38.12797226224627, 38.91714171000889, 38.14090633392334, 38.26835366657802, 37.480448790958945, 39.72111776896885, 38.764507157461985, 38.829653467450825, 38.58232886450631, 38.42942680631365, 39.42841795512608, 39.07242005211966, 39.46297134671892, 39.373336110796245, 38.485297271183555, 35.76092597416469, 34.738105978284565, 36.54177495411464, 37.15417528152466, 37.67866005216326, 38.02809190750122, 36.87845686503819, 38.202849524361746, 40.42681850705828, 39.17725099836077, 39.11965043204171, 39.85401248931885, 41.13309941973005, 43.84474509102957, 48.741686071668354, 50.06195150102888, 51.93976470402309, 51.8915685244969, 55.22115223748343, 35.99393381391253, 16.497319834572927, 52.84443405696324, 54.867131096976145, 52.36477558953421, 46.873402323041645, 45.227238586970735, 44.16091591971261, 43.52928645270211, 38.919486727033345, 38.07857404436384, 39.93118960516793, 39.482645171029226, 35.696835790361675, 36.660557883126394, 36.413834299360005, 35.798519202641074, 37.06968518665859, 36.43946967806135, 34.0156044960022, 36.174816267830984, 35.671044077192036, 36.30977112906319, 36.01730407987322, 37.36057499476841, 34.69115700040545, 34.7790412902832, 35.30178901127407, 35.83240556716919, 36.91169009889875, 36.103281089237754, 36.629096439906526, 35.92130429404122, 35.1454302242824, 34.917188848767964, 34.19799470901489, 36.91389267785208, 34.467188767024446, 37.28166430337088, 35.61535426548549, 36.98635196685791, 35.9321608543396, 36.85233858653477, 39.20288985116141, 40.18519490105765, 42.881255762917654, 44.48117923736572, 42.64053194863455, 41.04376295634678, 43.05636773790632, 42.26249783379691, 43.25174413408552, 49.789186068943565, 56.89671727589199, 54.374938079289024, 58.30036803654262, 55.4570574760437, 46.97748981203352, 1.3073949771268027, 0.17457667871245316, 0.15956033234085354, 14.66315347807748, 57.553367206028526, 45.572372981480186, 57.08463478088379, 40.2037570135934, 24.240927355630056, 16.19183533532279, 28.393264634268625, 13.597863486834935, 0.24726939733539308, 0.09423782716372184, 0.10266851620482546, 0.05976256887827601, 0.04498733314020293, 0.02063752893757607, 0.01733497516917331, 0.05700319765933922, 0.021400668791362217, 0.1273330809282405, 0.00753270901207413, 0.06569846786026444, 0.10661248743001904, 0.08994702276374612, 0.010354740395476776, 0.05485370050051382, 0.03140526730567217, 0.042910201741116386, 0.06098449509590864, 0.04964619868301919, 0.0021031063557269847, 0.009744259046523698, 0.0740770318412355, 0.04341826840702977, 0.03014709035466824, 0.07999817268656832, 0.00871708510177476, 0.04717970692685672, 0.05455657001584768, 0.041691305182342014, 0.022754307137802243, 0.09868931544146367, 0.06848049536347389, 0.08046328808580126, 0.17331416931535515, 0.04025738766150815, 0.11277210619300604, 0.08659050001629762, 2.4299198857375552, 50.44227157320295, 54.745072092328755, 39.78645168031965, 32.834052903311594, 36.08545201165335, 66.54748371669224, 62.59636279514858, 52.49210480281285, 48.64889635358538, 4.051295271941593, 0.4287174509039947, 32.98487050192696, 67.76493317740304, 60.7284368787493, 62.831045150756836, 58.117828437260215, 52.40264327185494, 45.13814183643886, 45.771233899252756, 45.736357416425435, 48.54857131413051, 48.98812825339181, 48.982065950121196, 46.88566589355469, 47.46422849382673, 42.38216665812901, 41.80641460418701, 41.75633198874337, 44.30781473432268, 41.665706634521484, 40.04863500595093, 40.952953474862234, 41.07719421386719, 39.780222620282856, 40.62170158113752, 40.55179575511387, 39.76754215785435, 40.46758358819144, 40.54929092952183, 41.76838711329869, 42.171667507716585, 40.215506417410715, 40.06001615524292, 41.387622356414795, 42.68704319000244, 41.70636749267578, 41.02887296676636, 41.581042834690635, 37.86135598591396, 39.44956827163696, 41.00752115249634, 40.59587860107422, 39.51652111325945, 40.673514298030305, 39.314029761723106, 40.31530686787197, 44.384838989802766, 42.46949509211949, 42.26089627402169, 41.275613921029226, 46.18646172114781, 46.644615513937815, 52.17126131057739, 53.10271944318499, 57.21270745141165, 56.02550002506801, 60.07265894753592, 42.30450316837856, 21.78068314279829, 55.056334018707275, 56.87774174554007, 56.00253275462559, 48.4488959312439, 47.895298208509175, 45.792610032217844, 44.617072105407715, 40.93234164374215, 42.6853026662554, 40.890930380140034, 41.117552825382774, 37.79456295285906, 38.327034677777974, 37.99814517157418, 37.75013617106846, 37.96696513039725, 38.34775768007551, 35.657331807272776, 37.77275603158133, 38.57499156679426, 39.19097369057791, 36.84865951538086, 39.13792766843523, 36.11714621952602, 37.10402665819441, 36.997298853737966, 36.86608559744698, 37.523770809173584, 39.04076405933925, 38.11197403499058, 38.51653637204851, 37.149867398398264, 36.38326569965908, 35.29182876859392, 38.36638232639858, 37.949313231876914, 39.20092003686087, 37.55477714538574, 39.59485510417393, 37.476342405591694, 38.932347842625205, 41.9235577583313, 41.739020551954, 46.220511368342805, 47.03671625682286, 44.04120888028826, 43.77397074018206, 45.17701700755528, 43.812039920261924, 44.69492319652012, 52.91099432536534, 58.10551275525774, 57.01219286237444, 60.90911783490862, 56.68613474709647, 46.34343542371477, 1.3613835658345903, 0.22118385136127472, 0.19535826572350093, 17.35883218901498, 65.24931703295026, 49.22898060934884, 65.53893184661865, 44.18347324643816, 34.60438789640154, 21.35944860322135, 34.27067286627633, 19.673600230898174, 0.24319704728467123, 0.05296668782830238, 0.03280678138669048, 0.05764176018003907, 0.029678616207093, 0.02323176508902439, 0.03216255309858492, 0.05969241514269795, 0.05960152537694999, 0.0788711260205933, 0.04653925468612995, 0.023775102005207112, 0.05985599636499371, 0.10651427627141986, 0.05501070332580379, 0.0393583253691239, 0.030210971033998897, 0.14215124079159328, 0.11936807047043528, 0.11599423150931086, 0.10185506806841918, 0.17233652248978615, 0.20419465085225447, 0.10353687139494078, 0.11159482757960047, 0.25173518913132803, 0.12592657282948494, 0.2317368893751076, 0.14622603356838226, 0.1428232075912612, 0.2553875260055065, 0.16611004088606152, 0.0808380361912506, 0.10913163011095353, 0.1944071767585618, 0.09306644501962832, 0.19647848632718834, 0.25060713823352543, 3.855500246797289, 64.79479367392403, 62.10739026750837, 52.07935053961617, 36.57221501214163, 45.24132258551461, 67.88412952423096, 70.9770506450108, 57.422963414873394, 57.80853285108294, 4.391086935997009, 0.277048507971423, 37.87863615580967, 69.10572705950055, 63.32383223942348, 66.05101408277238, 61.40819999149868, 54.22500985009329, 47.997839723314556, 49.07400451387678, 48.78527906962803, 53.820555210113525, 52.85254955291748, 53.98250729697091, 49.98301649093628, 50.64173003605434, 45.847354888916016, 44.610238552093506, 45.23232119424002, 47.58513757160732, 45.683412143162315, 43.603194441114155, 43.56328051430838, 44.92318194253104, 42.56413303102766, 44.37816524505615, 43.697613511766704, 43.164888177599224, 42.1439893586295, 44.90234776905605, 44.714141913822715, 45.176791191101074, 44.97966732297625, 44.18339334215437, 44.51038251604353, 44.82687643596104, 45.2531692641122, 45.2796835899353, 45.567509242466514, 41.80765833173479, 42.0813478742327, 43.238386222294395, 43.62294122150966, 43.10405322483608, 44.19510105678013, 42.205025809151785, 43.607644762311665, 49.48465347290039, 46.012409346444265, 45.832391943250386, 44.8392824445452, 49.82104703358242, 49.98512874330793, 53.53887523923601, 54.917363098689485, 58.837776456560405, 56.851095403943745, 59.4036933353969, 34.770623547690256, 16.863925899778092, 57.51617349897112, 58.24874986921038, 56.530606269836426, 48.79935611997332, 48.44576576777867, 47.45847538539341, 46.50127417700631, 41.57992764881679, 41.25170864377703, 41.28278793607439, 43.23867457253592, 38.452130045209614, 38.34665291649954, 39.69648987906319, 36.719495977674214, 39.73651845114571, 39.90501921517508, 38.09790393284389, 40.51387248720442, 41.36483921323504, 40.75092070443289, 39.06638554164341, 42.06272670200893, 37.69239316667829, 39.09955276761736, 40.16004242215838, 39.80494778496878, 40.908321721213206, 41.965861865452354, 41.01587636130196, 42.40433488573347, 39.750550338200156, 39.11064209256853, 37.64199788229806, 42.824902398245676, 40.40634911400931, 40.95491286686489, 41.14721815926688, 42.57970741816929, 40.41079943520682, 41.25809751238142, 44.408362116132466, 44.08710520608084, 49.47071191242763, 51.15706055504935, 46.001201902117046, 44.86871501377651, 46.66015863418579, 45.873903955732075, 46.97259480612618, 54.622832434517996, 60.359862736293245, 59.235922132219585, 62.45075634547642, 58.55804198128836, 49.99831295013428, 2.547839501074382, 0.30624269427997725, 0.5538815675037247, 19.370045593806676, 68.65971524374825, 53.75628089904785, 69.93654400961739, 51.74677848815918, 38.42344440732683, 29.49266767501831, 48.77950859069824, 30.22670316696167, 0.28392109061990467, 0.1410539818129369, 0.1944431798266513, 0.10086056643298694, 0.19841450958379678, 0.15030358119734696, 0.0798512427136302, 0.21238227507897786, 0.1634186181638922, 0.15817415315125669, 0.1005890370745744, 0.1539843486888068, 0.15284833178988524, 0.2708092156265463, 0.13315956613847188, 0.07494445065302507, 0.10651259350457362], [0.06671843491494656, 0.08713304304650851, 0.04403504995363099, 0.012992546976810055, 0.04563276922064168, 0.06891757369573627, 0.10405698884278536, 0.07274083354111228, 0.028289359861186573, 0.05076535398672734, 0.10564552074564354, 0.031891821018819294, 0.0414532513490745, 0.0324287932765271, 0.06542377652866499, 0.014419452686394964, 0.03732814859332783, 0.05923971693430628, 0.09816397327397551, 0.10847521533391305, 0.17256950427378925, 0.04358612439994301, 13.630837900297982, 36.820401191711426, 31.90908091408866, 30.4063002041408, 28.937966925757273, 55.50904737200056, 51.80492448806763, 54.16878155299595, 49.82295431409563, 8.43786370754242, 0.7871898625578199, 2.7383547638143813, 49.373770645686555, 63.128233500889365, 60.88363184247698, 61.78215898786272, 54.29805973597935, 49.56085784094674, 48.172680718558176, 50.27611582619803, 49.250339371817454, 52.371348585401265, 52.02894830703735, 53.5371208190918, 49.01289858136858, 50.564274992261616, 46.06070974894932, 44.40474557876587, 43.58398962020874, 40.536937032427105, 41.6607004574367, 39.27939993994576, 39.17296395983015, 40.13830498286656, 39.24184840066092, 39.114460127694265, 39.378370080675396, 40.55806303024292, 40.943222522735596, 39.69844927106585, 36.516417503356934, 38.909992013658794, 40.194237981523784, 38.4923357963562, 40.86945697239467, 38.5881028175354, 38.4270053591047, 38.512148584638325, 37.67956679207938, 37.7863119670323, 37.50583750861031, 38.01607499803816, 39.66736650466919, 37.74673850195748, 38.637094565800254, 40.87532820020403, 39.53044877733503, 39.5949558530535, 39.28783505303519, 40.64221961157662, 43.61361673900059, 49.15105308805193, 52.101563930511475, 54.084548541477744, 52.01391935348511, 55.36317341668265, 54.120644433157786, 45.764268330165315, 12.070559109960284, 36.03058556147984, 62.53008392878941, 49.89012949807303, 52.20500871113369, 48.03421354293823, 49.41725942066738, 45.799349784851074, 44.946875299726216, 37.39860595975603, 39.94784096309117, 39.667036465236116, 38.25143480300903, 36.67703553608486, 37.79951354435512, 37.63380248206002, 36.38395357131958, 36.7739177431379, 37.05781071526663, 36.013833454677034, 36.709393296922954, 36.33100829805647, 37.18487589699881, 37.043570382254465, 35.14444705418178, 35.54679291588919, 35.892066274370464, 36.701951776232036, 37.64570127214704, 35.654757499694824, 37.11070735113961, 36.98169319970267, 35.90899208613804, 35.99624061584473, 35.124092306409565, 35.93784448078701, 35.71070439474923, 37.82124750954764, 35.36432974679129, 36.91107518332345, 37.95904070990426, 36.959670884268625, 36.669305665152415, 36.717189175742014, 35.25028548921858, 37.85344546181815, 37.54441738128662, 40.141157218388145, 39.37857852663313, 44.25621393748692, 44.30923216683524, 54.60954400471279, 54.26241200310843, 60.14111260005406, 55.504249640873496, 65.3801029750279, 14.144459162439619, 0.382176896823304, 0.5010317234056336, 0.10736315750649997, 26.551460470472062, 58.59312343597412, 48.94212770462036, 53.168581417628694, 28.527559416634695, 18.864187206540787, 23.192548411233084, 31.03190905707223, 2.6701512464455197, 0.314435461802142, 0.037174996454268694, 0.06959618335323674, 0.014583590307406016, 0.03963756627802338, 0.07324853379811559, 0.07077469690037624, 0.049815601735774956, 0.09238278027623892, 0.05870480063770499, 0.050351349237774096, 0.06463785655796528, 0.019340997794643044, 0.011442690721846052, 0.06704936322889157, 0.042056292561548095, 0.11180648300796747, 0.021544360455923846, 0.09426973188029868, 0.08068723856870617, 0.08511665410229138, 0.09039390592702798, 0.05090946125398789, 0.0693406742066145, 0.06192879871066127, 0.025069366841177856, 0.03692786721512675, 0.05829430052212306, 0.05581778341106006, 0.031252905659909756, 0.012765931547619402, 0.18953549888517174, 0.02550243672781757, 0.059970716280596595, 0.026463135444958295, 0.07416560101721968, 0.03437491991956319, 0.10654713093702282, 0.021270980393247943, 18.487612213407242, 48.099592617579866, 31.041104997907365, 38.40208217075893, 36.55169350760323, 59.33037594386509, 61.44558129991804, 58.83166898999895, 56.893566267830984, 9.624254720551626, 0.8982323354908398, 2.3425790752683366, 53.29714046205793, 66.15306922367641, 63.267864499773296, 64.59387261526925, 57.63020038604736, 51.728268487112864, 49.815349510737825, 53.08558171136038, 52.62989452907017, 55.39276232038225, 56.11544098172869, 55.459531034742085, 51.411131858825684, 51.39753770828247, 48.38685546602522, 45.82035766329084, 46.774376596723286, 43.72638600213187, 43.235144887651714, 41.410078934260774, 40.77810205732073, 41.87262051446097, 41.80966288702828, 42.35943910053798, 41.34287248338972, 43.33692210061209, 43.948103019169395, 42.036618845803396, 39.59047079086304, 40.93640981401716, 41.19967358452933, 41.36151450020926, 42.38121822902134, 41.28509473800659, 41.0077817099435, 40.3552451133728, 40.07135908944266, 41.42541013445173, 40.174286229269846, 40.55320276532854, 41.469763960157124, 39.952256543295725, 41.22498934609549, 44.50038753237043, 42.99963222231184, 43.84490489959717, 42.11750977379935, 43.349119663238525, 46.81859145845686, 51.95809057780674, 55.239318302699495, 55.97603232519967, 55.01438079561506, 58.05168506077358, 56.2905182157244, 54.766090393066406, 16.29548508780343, 40.59049374716622, 66.05390453338623, 51.72582272120884, 54.91814129693167, 49.66623074667794, 51.01899637494768, 47.05965920857021, 45.335029465811594, 39.28114741189139, 41.04785891941616, 41.106699739183696, 40.416114807128906, 39.61798218318394, 39.98291546957833, 39.32262120928083, 38.40240526199341, 38.47451366697039, 38.053272179194856, 38.45141438075474, 39.83512033735003, 39.3052785055978, 39.34703023093087, 39.01849855695452, 36.91790178843907, 36.66437244415283, 37.25477824892317, 38.563579150608604, 39.04680551801409, 38.332026958465576, 37.1762045451573, 40.169405119759695, 37.59747729982649, 38.73357377733503, 37.72180141721453, 38.27375589098249, 38.20529529026577, 38.9212828363691, 37.65237501689366, 38.80935777936663, 39.594198499407085, 39.6005665234157, 37.872170857020784, 38.59505796432495, 37.91194929395403, 41.49506235122681, 39.934083529881065, 43.65186309814453, 41.8252546446664, 46.256714957101, 45.216375078473774, 56.56261314664568, 56.103722844805034, 63.24609579358782, 56.92674044200352, 65.40674236842564, 14.050787023135594, 0.6476373566048486, 0.7757682725787163, 0.6646292305418423, 27.778253521238053, 65.14118916647774, 55.100059032440186, 58.75201484135219, 37.24399464470999, 27.652465070996964, 24.840001038142614, 41.227626187460764, 4.235523283481598, 0.4792281133787972, 0.06440070178359747, 0.09629318437405995, 0.007925428117492368, 0.024790446540074687, 0.05966888354825122, 0.019739760950739895, 0.026924159278028777, 0.013739029644057155, 0.043865036219358444, 0.04453803439225469, 0.026391119130754044, 0.05210898903065494, 0.027771347568237355, 0.0964561684855393, 0.06254524777510337, 0.05619097767131669, 0.11311187581824404, 0.19621521473995276, 0.12439980118402413, 0.16241518700761454, 0.16265616193413734, 0.2245684111756938, 0.25136715173721313, 0.1233061384409666, 0.09532146115920373, 0.1709710657596588, 0.2767511196434498, 0.0978120578719037, 0.12470065004059247, 0.12712050947759831, 0.2895128977085863, 0.12588754349521228, 0.11222615691700152, 0.1483368474457945, 0.13653050096971647, 0.19578216012035096, 0.1491857897490263, 0.12545968645385333, 30.404250485556467, 58.81252670288086, 45.757459095546174, 45.249243531908306, 43.23368229184832, 66.57622146606445, 65.64148030962262, 66.50267478397915, 63.28259468078613, 13.458584240504674, 1.3467467512403215, 4.5624447124344965, 58.18070616040911, 69.47780309404645, 69.14469255719865, 68.19465841565813, 61.54461397443499, 54.24256099973406, 54.35492031914847, 55.1819817679269, 56.48275055204119, 58.528359276907786, 59.3655685697283, 60.54416370391846, 54.19451420647757, 54.02838972636631, 52.693748474121094, 49.01913806370327, 50.336311544690815, 47.726151262010845, 47.82330444880894, 44.17759159633091, 43.321017674037385, 45.59709814616612, 43.765056201389854, 45.033592292240684, 45.21364443642752, 46.237669944763184, 46.057402406420024, 43.2630558013916, 41.12369155883789, 45.22047104154314, 45.88016428266253, 43.12880965641567, 46.598180702754426, 44.50804444721767, 42.31780549458095, 43.78588342666626, 43.435770647866384, 44.66838107790266, 42.940648964473176, 44.82446888514927, 46.496726581028526, 42.47927468163626, 45.02918366023472, 47.72898612703596, 44.95731496810913, 47.049799714769634, 45.7170865876334, 46.524158069065635, 49.5190018926348, 54.56892483575003, 56.862806592668804, 57.80452026639666, 56.27776827130999, 60.292437417166575, 57.22744458062308, 48.19597455433437, 9.702636480331421, 41.16358116694859, 69.67676476069859, 53.81839779445103, 57.44748360770089, 51.50386599131993, 52.91301277705601, 50.001001902988975, 48.38964169366019, 41.07977546964373, 42.027537550245015, 42.750646999904085, 41.61770153045654, 40.09619542530605, 42.560818740299766, 41.03974689756121, 39.575462681906565, 41.20765706471035, 40.031420843941824, 40.35262564250401, 42.64639622824532, 41.84061016355242, 41.819692611694336, 41.88673577989851, 39.36544990539551, 39.588521821158274, 39.829957825796946, 41.1977732522147, 42.225536891392295, 40.770987101963584, 41.653040068490164, 42.72155489240374, 41.12608521325247, 41.07036413465227, 39.02110760552542, 41.69816861833845, 41.587046078273225, 41.47606250217983, 41.21699891771589, 40.82927553994315, 42.67982401166643, 41.20288365227835, 40.87867375782558, 40.724649565560476, 40.02478878838675, 43.102000032152446, 41.65663923536028, 46.48158645629883, 42.465833391462056, 49.45064204079764, 47.218321323394775, 58.69804123469761, 58.3129095349993, 63.96280247824532, 58.95189367021833, 65.92980970655168, 17.977805512292043, 0.7987334802746773, 0.7009960476841245, 1.1815824253218514, 32.0831332887922, 71.21338667188371, 57.95314918245588, 64.90820911952427, 40.07948153359549, 33.49981539590018, 37.929524762289866, 52.55456910814558, 10.695156250681196, 0.8543254200901303, 0.15961586364677974, 0.22875722497701645, 0.07518959856991257, 0.15021872360791477, 0.1371400561183691, 0.14014346924211296, 0.22829411125608853, 0.09432344471237489, 0.19495755008288793, 0.18133803590067796, 0.16189186008913176, 0.2234961629978248, 0.1185878501938922, 0.18870850040444306, 0.21569672865527018, 0.21540464647114277], [0.14799760707787105, 0.037409871350973845, 0.02952545728268368, 0.007180380551809711, 0.04655374480145318, 0.10258317007017986, 0.047300326704446755, 0.036589841424886665, 0.04590581849749599, 0.07216228744281189, 0.05021058375548039, 0.03464699889134083, 0.07961775881371327, 0.013662721595859953, 0.025388717651367188, 0.12850387953221798, 0.11366796919277736, 0.05947415078324931, 0.04715689457952976, 0.03398888438407864, 0.047018914483487606, 0.026964038477412293, 0.4406694109950747, 35.898500306265696, 38.192653042929514, 32.84386723382132, 31.230387823922293, 34.50537954057966, 64.46556718008858, 48.21657943725586, 62.80928339276995, 19.645776169640676, 0.10066689218261413, 0.3424427275146757, 10.11501293522971, 68.67939949035645, 58.268760681152344, 63.698423521859304, 56.80921861103603, 55.19437040601458, 50.51093019757952, 54.032301562173025, 51.832981313977925, 54.271618366241455, 53.91087484359741, 54.32705109460013, 51.98438603537423, 54.39342376164028, 51.240793296269004, 51.254755701337544, 49.68243047169277, 45.89020095552717, 42.180793966565815, 41.441637652260916, 41.16937249047415, 42.14984669004168, 39.43089498792376, 40.449386256081716, 40.05069167273385, 40.52812671661377, 40.126777921404155, 41.775307519095286, 40.13651234763009, 38.2364683832441, 40.91975845609392, 38.57406050818307, 40.667007310049875, 40.49522352218628, 39.27170133590698, 39.13620451518467, 35.99155405589512, 37.392185824257986, 38.500861236027305, 38.16248743874686, 38.356738226754324, 38.462924071720664, 39.01708459854126, 40.981785024915425, 40.321528979710166, 41.89145360674177, 40.654580456869944, 43.50069808959961, 42.74749946594238, 51.19653327124459, 53.13232224328177, 54.05264936174665, 50.22203452246529, 55.862245150974815, 52.6726850100926, 50.174418517521445, 18.28720358439854, 22.51637578010559, 61.783972467694966, 51.14138889312744, 57.524716309138704, 51.73820093699864, 54.030911922454834, 51.881128856113975, 51.637219292776926, 48.32963705062866, 42.127813952309744, 40.363127844674246, 40.477700165339876, 37.56345891952515, 37.39066416876656, 39.56800031661987, 38.38486453465053, 38.249242646353586, 36.50581455230713, 36.630889075142996, 37.25808211735317, 37.54248925617763, 38.23486682346889, 36.039913518088206, 36.889344692230225, 35.053595883505686, 36.82348271778652, 36.472796712602886, 37.43866579873221, 35.427353382110596, 35.81774486814226, 34.97351789474487, 36.51744931084769, 36.48211424691336, 34.314627170562744, 35.073530265263145, 37.45338903154646, 35.08236837387085, 37.51100696836199, 35.41871329716274, 36.08589669636318, 35.137933118002756, 38.458046436309814, 36.297896657671245, 37.38405295780727, 39.0529477255685, 38.02021612439837, 38.931045055389404, 40.97504179818289, 41.61660371507917, 48.693955421447754, 53.88159166063581, 56.59281696592058, 61.203276770455496, 58.150971344539094, 49.65590572357178, 0.31572074283446583, 0.05826927615063531, 0.4038762024470738, 0.5150391831994057, 34.587910243443076, 51.22955111094883, 45.21405438014439, 49.29473836081368, 15.699624947139196, 26.786948817116873, 25.926040955952235, 26.140109743390763, 0.272817000746727, 0.21356364525854588, 0.032888398971408606, 0.07546981996191399, 0.023484214042712535, 0.10641434841922351, 0.02206105469459934, 0.07596591048474823, 0.06176242870943887, 0.02099203464708158, 0.040617849212139845, 0.03647418852363314, 0.08389688562601805, 0.02894202233957393, 0.02455917466431856, 0.09412742951618773, 0.0643345649753298, 0.07421697968883173, 0.1218653100409678, 0.04463439315025296, 0.01747705870574074, 0.051838643715849946, 0.03463949429403458, 0.0242763103784195, 0.03589175781235099, 0.037867044497813494, 0.043065569297011407, 0.04784723271482757, 0.020709959158141698, 0.029156256201011792, 0.044902631613825045, 0.009752321738882788, 0.02240596422260361, 0.11429351062646934, 0.10422349455101149, 0.051246323356670995, 0.03255778278357216, 0.03426532633602619, 0.06807256011026246, 0.04442194044323904, 0.9038544595241547, 47.28949172156197, 44.0669241632734, 35.029436997004915, 36.843767983572825, 39.84509447642735, 67.9753246307373, 53.67570611408779, 68.33813176836286, 21.49829271861485, 0.08166031885359969, 0.26977705529757906, 11.354006154196602, 71.03322683061872, 60.88434055873326, 67.16164888654436, 58.450991085597444, 59.379916599818635, 52.65405688967024, 56.47781038284302, 54.277225562504356, 57.167380877903526, 56.90364810398647, 56.97391523633684, 55.967687538691926, 57.16278811863491, 52.268153939928325, 53.397812911442344, 50.59254373822893, 48.771594592503135, 43.11959287098476, 44.78111212594168, 43.37082930973598, 44.39513622011457, 41.31516306740897, 44.09056888307844, 42.18360103879656, 42.20523772920881, 42.5757052557809, 44.202153478349956, 42.641570704323904, 40.397153173174175, 41.467491899217876, 42.13615526471819, 43.210680280412944, 44.31136178970337, 41.75474432536534, 42.39241872514997, 38.253623485565186, 39.30888114656721, 41.14073896408081, 40.91218491962978, 41.13463497161865, 41.39096096583775, 42.40635681152344, 43.26533133643014, 42.44646528788975, 43.86752476011004, 43.36302648271833, 45.15554359980992, 46.02489178521292, 54.229376792907715, 56.865988867623464, 58.08242736543928, 52.00651952198574, 58.7021267754691, 56.19559192657471, 59.365915979657856, 24.116660560880387, 24.528733900615148, 65.10750429970878, 52.95634521756853, 58.50379739488874, 51.59776742117745, 55.23636531829834, 53.244320256369456, 52.66735226767403, 46.89094999858311, 43.73764555794852, 41.057801791599815, 43.04590375082833, 39.1536305972508, 40.33197907039097, 39.891022069113596, 40.4925971031189, 38.81073004858834, 37.80943904604231, 38.6908666746957, 39.525699683598106, 37.414274147578645, 40.63990586144583, 39.58455787386213, 38.722171783447266, 38.147281306130544, 39.49726070676531, 38.37534897668021, 40.1192113331386, 37.52425370897566, 39.47599227087838, 36.92166076387678, 39.361871583121165, 38.45386709485735, 38.321100916181294, 37.92394535882132, 39.46795320510864, 37.549222060612266, 39.27418531690325, 39.30534103938511, 38.70496456963675, 37.47368819372994, 39.882625171116416, 38.128166811806814, 38.05502312523978, 39.8911714553833, 40.02635213306972, 40.43383618763515, 43.88005583626883, 41.95010335104806, 49.011359555380686, 57.216449056352886, 57.279184341430664, 62.89069543566023, 57.210848808288574, 48.528008120400564, 0.09817257031266179, 0.17332978919148445, 1.8283837182181222, 0.9084504214780671, 39.92716659818377, 55.19659730366298, 52.51677090781075, 57.00823933737618, 24.886208295822144, 28.52737181527274, 29.970867020743235, 33.19365692138672, 0.5711482752646718, 0.13449493662587234, 0.012227074658897306, 0.06264326215854712, 0.05365736523110952, 0.03252078226900526, 0.03490709154201405, 0.05818646095160927, 0.004218906405315335, 0.035995241188045056, 0.031338974434350214, 0.013941162681606199, 0.04252562844859702, 0.03408592167709555, 0.04792286562068122, 0.03502250017066087, 0.04022084515807884, 0.02995562134310603, 0.290950849120106, 0.14740676592503274, 0.12462050148418971, 0.13274580905480043, 0.1948293341057641, 0.39681580130543026, 0.14417524289871964, 0.21429149620234966, 0.07997266655521733, 0.14208303445151874, 0.11922841439289705, 0.09308657036828143, 0.12101749410586697, 0.11538872042936937, 0.15675809127943857, 0.19805139835391725, 0.31813657177346094, 0.21939695653106484, 0.09404857017632041, 0.224026709528906, 0.16225039799298557, 0.2528517320752144, 2.625801546233041, 64.66598796844482, 54.11293193272182, 48.03398425238473, 46.96387134279524, 43.48342834200178, 78.56253801073346, 60.23182133265904, 74.6804335457938, 25.301352739334106, 0.13574965644095624, 0.2017446101776191, 13.251421962465558, 72.14400059836251, 63.82965414864676, 72.94956084660122, 63.45821040017264, 61.72627462659563, 54.71729666846139, 61.02176203046526, 56.657740933554514, 63.305148533412385, 61.744166237967356, 60.58971609388079, 59.047577313014436, 61.43764645712716, 55.935006686619346, 59.40182426997593, 55.583056109292166, 53.49190541676113, 48.303226947784424, 47.386360032217844, 48.01074947629656, 47.31578370503017, 44.82393734795706, 47.71231739861624, 45.366192136492046, 45.46533250808716, 46.489250319344656, 47.30535445894514, 46.13296406609671, 43.391840662275044, 46.83579172406878, 44.254334449768066, 46.37138455254691, 47.017170974186485, 45.0654810496739, 44.77364976065499, 39.01407602855137, 42.54400062561035, 44.162305559430806, 43.82345233644758, 44.504848275865825, 44.37907198497227, 42.41487182889666, 47.05371502467564, 46.2544845853533, 48.27686200823103, 45.519799436841694, 49.681131158556255, 47.76320947919573, 55.35809080941336, 57.00873613357544, 58.473586627415244, 52.77038015638079, 61.990750857761924, 56.87193305151803, 56.757770674569265, 13.054579496383667, 20.31684708595276, 69.5151288168771, 53.84414781842913, 61.48418549128941, 53.368460246494834, 58.6294972555978, 55.61229065486363, 54.05814191273281, 48.150957175663535, 45.44000285012381, 43.11319358008248, 44.800820691244944, 40.746223722185405, 40.45922490528652, 43.222985540117534, 41.55354533876692, 41.914719649723594, 39.63028049468994, 41.8321715763637, 41.606431552342, 39.75558083398001, 42.970713819776265, 40.195189884730745, 41.020309312003, 41.1276798248291, 42.859657287597656, 41.8194911139352, 42.58651665278843, 38.623906884874614, 40.80814259392874, 40.26594686508179, 44.007847104753765, 41.04302297319685, 39.04481833321707, 40.449323722294395, 42.69599594388689, 40.249660287584575, 44.63742337908064, 41.55580002920968, 42.86314875738961, 40.01827137810843, 44.176445143563406, 40.19309500285557, 41.419358253479004, 41.88504389354161, 42.080521038600374, 42.8700726372855, 44.256641251700266, 43.08185373033796, 52.02675615038191, 59.45622171674456, 59.79712118421282, 65.34713377271379, 57.392137731824604, 52.39961385726929, 0.6800464146903583, 0.1633779060627733, 0.7900407952921731, 2.290483219282968, 40.918851716177805, 60.7195987701416, 57.19720254625593, 62.12094620295933, 25.070432833262853, 40.86124767575945, 39.917578084128245, 47.577286107199534, 1.2740512234824044, 0.36576419323682785, 0.11054699309170246, 0.25397272620882305, 0.13114734339926923, 0.19286420169685567, 0.14026297282959732, 0.08906251165483679, 0.16284708811768464, 0.0847498584272606, 0.08893800726426498, 0.20859337624694618, 0.12172854452260903, 0.0969233059191278, 0.12691731538091386, 0.19029638091368334, 0.12579063512384892, 0.14773174348686421], [0.07787959636854273, 0.05698723851570061, 0.07400060844208513, 0.015870411614222184, 0.06828530798000948, 0.09818732844931738, 0.06710722190993172, 0.041997514465557675, 0.05322847003117204, 0.10484558902680874, 0.02388275837126587, 0.06740190966853074, 0.02056262206419238, 0.033834459991859536, 0.04718773738880243, 0.1172305630253894, 0.05464171937533787, 0.046776514633425643, 0.04338308297363775, 0.15006708460194723, 0.10802192680005517, 0.2283948872770582, 0.08431182336062193, 8.398195573261805, 43.648906639644075, 36.824584007263184, 60.444853101457866, 26.047530208315166, 57.631652559552876, 60.81730433872768, 49.67764663696289, 48.44525507518223, 0.646976897759097, 0.09318324125238828, 0.12566891951220377, 29.475703648158483, 71.93772942679269, 55.47267355237688, 62.548989977155415, 56.810121876852854, 60.81095368521554, 56.58137675694057, 57.61627272197178, 52.03847081320626, 55.40154831750052, 54.67498908724104, 54.54088885443551, 52.65256997517177, 55.623313971928184, 50.27681412015642, 47.90384101867676, 48.181063720158164, 45.71917799540928, 40.94601569856916, 40.05678871699742, 41.649663243974956, 41.316827160971506, 41.75883681433541, 40.6121095929827, 41.16201434816633, 41.907090527670725, 41.70623547690255, 41.44413900375366, 39.49597181592669, 41.66810723713466, 40.31210027422224, 40.13809306280953, 39.888569355010986, 39.47880629130772, 39.539867060525076, 39.05017539433071, 38.84545367104666, 39.33107021876744, 39.83103827067784, 40.38482359477452, 41.709688731602256, 39.304194586617605, 41.4509517124721, 39.86172846385411, 40.35416119439261, 40.503974778311594, 41.882667609623496, 45.436712878090994, 46.86238248007638, 51.887218952178955, 55.69302872249058, 52.09374025889805, 54.802241870335166, 53.92516728809902, 51.40991244997297, 30.980429853711808, 20.58606025150844, 56.60437529427664, 56.3261798449925, 56.37684958321707, 53.71133995056152, 55.133476393563406, 54.30618565423148, 54.158091749463765, 52.74576963697161, 49.48462568010603, 41.5079790524074, 41.40945012228829, 39.73777954918997, 37.851600715092246, 38.55108628954206, 36.41634259905134, 36.985695362091064, 37.547248772212434, 36.12629699707031, 38.424448422023225, 37.616459778376985, 38.04934644699097, 37.409782137189595, 36.63854251589094, 37.2963354246957, 37.960506779806956, 37.377615451812744, 37.4250681740897, 37.184021268572124, 37.27823884146554, 37.08722938810076, 38.11471857343401, 35.37210825511387, 37.69871950149536, 34.62704249790737, 37.38747841971261, 35.72112321853638, 38.23888635635376, 37.41153308323452, 38.383554799216135, 35.921610014779226, 37.34941618783133, 36.882757799965994, 39.25975390842983, 36.52286195755005, 43.265511989593506, 39.28516347067696, 44.00568274089268, 41.75516469138009, 49.41837460654122, 50.02105787822178, 58.93048627035958, 53.92475734438215, 67.65967491694859, 14.676474911825997, 0.27029912014092716, 0.36627534723707605, 1.8220408814293998, 1.5545141739504678, 36.69971445628575, 52.04779182161604, 51.898495878492085, 25.14724690573556, 20.344426223209926, 26.533688715526036, 36.89915554864066, 10.701665844236102, 0.7464847639203072, 0.2501853337245328, 0.11041415629110166, 0.040288386533835104, 0.06029110694570201, 0.022363715239667466, 0.012470538112601, 0.028939623718283007, 0.04142433897192989, 0.17326969813023294, 0.03514751685517175, 0.09817265852221421, 0.08196857052722148, 0.028917897026985884, 0.032219750207981894, 0.028621417935937643, 0.016425232735595534, 0.03744941297918558, 0.033054273642067394, 0.06382044577705008, 0.02673069367717419, 0.01883976736904255, 0.07227551458137375, 0.05929624568670988, 0.0774802513686674, 0.03334391649280276, 0.016327564405011277, 0.07195556496403047, 0.055155292352927585, 0.06166157126426697, 0.058210745719926696, 0.009771643023538803, 0.05955560212688787, 0.12364161972488676, 0.06791317223438195, 0.04756724541740758, 0.04149218908111964, 0.10194454648132835, 0.09170270498309817, 0.21696512773633003, 0.16896081077201025, 11.870522209576198, 53.157839502607075, 38.398243291037424, 70.55199459620884, 35.68979379108974, 61.32462011064802, 65.95740100315639, 56.17105436325073, 55.03991542543684, 0.852801973266261, 0.13100829800324781, 0.17201424549732888, 32.00539684295654, 74.89219379425049, 58.90554223741804, 66.87079034532819, 59.60849148886544, 64.35078293936593, 60.14977700369698, 61.33231176648821, 53.89774969645909, 58.07905401502337, 57.343420437404085, 57.882833412715364, 55.398758615766255, 58.188154629298616, 51.87336424418858, 52.24559313910348, 50.22872563770839, 48.82684319359915, 43.851186071123394, 42.60368912560599, 44.551019055502756, 44.384734766823904, 42.60386977876936, 44.064683369227815, 43.179090295519146, 45.14746631894793, 43.22131797245571, 43.142935344151084, 41.88816710880825, 44.14359753472464, 42.829453468322754, 43.11868265696934, 41.98857205254691, 41.980098724365234, 40.948958260672434, 40.29410443987165, 41.12418835503714, 40.75404739379883, 42.45407009124756, 42.275487491062705, 44.441557134900776, 41.453008379255024, 43.80894797188895, 43.37118714196341, 41.94366237095424, 43.818765776497976, 43.798080989292686, 47.85248340879168, 52.68618188585554, 56.27348470687866, 57.411686488560264, 55.313441685267854, 57.82202972684588, 56.936853545052664, 55.84664991923741, 44.92496068137032, 25.024588618959697, 59.11710098811558, 56.63408579145159, 57.58439091273716, 55.63724511010306, 55.55647577558245, 54.254991327013286, 56.684262207576204, 55.0701470375061, 49.6589629309518, 41.3029967716762, 43.05866411754063, 42.43553924560547, 40.324290888650076, 40.205480166843955, 41.00090299333845, 39.16940300805228, 38.76484761919294, 37.64725766863142, 38.74250568662371, 39.86320495605469, 40.46740640912737, 39.743501390729634, 39.27169091360909, 38.45020539419991, 39.63040903636387, 38.97752155576433, 40.69640513828823, 39.613604818071636, 38.519419874463765, 38.543412004198345, 40.11422600064959, 37.168398244040354, 40.66857760293143, 37.965016160692485, 39.93279116494315, 38.54355444226946, 40.527119227818076, 38.919670854296, 41.881510734558105, 37.805819034576416, 39.59889548165457, 39.1558644430978, 41.35446555273873, 36.75072465624128, 44.24831730978829, 41.163348402295796, 45.09869343893868, 42.26263679776873, 51.93556104387556, 51.18242842810494, 60.538417543683735, 55.792804854256765, 66.78596673692975, 14.732189042227608, 0.4385368839970657, 1.2676993757486343, 2.6027042141982486, 0.6691893658467701, 42.12078932353428, 56.33052594321114, 56.31622307641165, 30.6567063331604, 26.027199779238018, 26.945855855941772, 46.334159578595845, 13.847993424960546, 0.7093075045517513, 0.26186153718403404, 0.15229890841458524, 0.058039476695869646, 0.05743409453758171, 0.06921171184097018, 0.04695254358063851, 0.06183061469346285, 0.01931482839531132, 0.013255983956956437, 0.029154006857424974, 0.03991993184068373, 0.03081718779035977, 0.03831770710114922, 0.019305836109976684, 0.06833769766879932, 0.045834066811949015, 0.03422291450468557, 0.19303702456610544, 0.23505981106843266, 0.18884095044008323, 0.16410240504358495, 0.18462243037564413, 0.3559157731277602, 0.38760767398136003, 0.15887984314135142, 0.12374529987573624, 0.19498382295880998, 0.16597814724913665, 0.17188806512526103, 0.2219957320817879, 0.13277646526694298, 0.17976912723055907, 0.343925055116415, 0.16442584911627428, 0.16860623551266535, 0.3056651252721037, 0.2432676963508129, 0.3472744668168681, 0.4586952637348856, 0.3119805763874735, 21.35934611729213, 68.14891842433384, 52.74518946238926, 76.37286186218262, 39.37572281701224, 68.81844684055874, 73.53163923536027, 62.3191157749721, 56.94088002613613, 1.3762799607855933, 0.3428025139229638, 0.3150794729590416, 34.78023985454014, 77.37516730172294, 62.76990795135498, 69.15819985525948, 63.20577539716448, 68.78371279580253, 63.35662078857422, 63.26363999502999, 58.42772156851632, 63.57817104884556, 59.549063546316965, 61.19824627467564, 59.22534697396414, 63.001894405909944, 54.27316781452724, 54.68314279828753, 54.330959456307546, 54.13346038545881, 47.890590803963796, 46.13768884113857, 48.69611978530884, 48.422739437648225, 46.98696368081229, 46.90487766265869, 46.56925882611956, 48.79774066380092, 46.53818995612008, 48.03383486611502, 44.903355257851736, 48.732201780591694, 46.959289005824495, 45.089025020599365, 45.75741045815604, 44.69267545427595, 43.73677355902535, 43.46568611689976, 44.57367713110787, 44.569779191698345, 45.53794813156128, 45.77018124716622, 49.088731220790315, 43.83122042247227, 45.80113894598824, 45.79214450291225, 44.21478877748762, 45.258401257651194, 47.73276594706944, 51.88500247682844, 51.412445068359375, 55.65157576969692, 58.82020446232387, 53.00997141429356, 59.48932293483189, 57.03773096629551, 58.25436053957258, 28.707592453275407, 15.408511059624807, 61.70388058253697, 58.1419734273638, 60.99826322283064, 55.31250715255737, 57.456898416791645, 56.170533248356406, 57.654633726392476, 54.66209323065621, 52.87423488071987, 42.965592997414724, 46.51627533776419, 43.13195719037737, 41.42953041621617, 44.00949035372053, 41.7746821812221, 39.81052371433803, 42.81908328192574, 40.082410199301584, 43.48299060549055, 40.20144326346261, 43.680430616651265, 41.6800650869097, 42.037466526031494, 40.30349840436663, 42.81155490875244, 42.92238909857613, 43.034710202898296, 42.240089893341064, 42.770765508924214, 40.93274811335972, 44.557988098689485, 40.719195229666575, 43.56336736679077, 39.15269953863961, 42.85982404436384, 39.48945440564837, 42.645868165152415, 41.710143838609966, 45.63388885770525, 41.53144311904907, 41.71361793790545, 42.81813832691738, 43.576214585985454, 39.75766181945801, 48.80110706601824, 43.67396184376308, 47.4390412739345, 44.11712489809309, 52.84708826882498, 53.93910884857178, 65.06015927450997, 56.8822580746242, 66.60602228982108, 17.049140555518015, 0.4452673542712416, 0.7328772055251258, 5.525639610631125, 3.3583866017205373, 44.84801633017403, 61.47966916220528, 64.6580948148455, 35.38493810381208, 33.283246994018555, 39.00884403501238, 53.56852667672293, 24.047105618885585, 0.780189226780619, 0.3014560639858246, 0.24791091148342403, 0.1804813990103347, 0.19506397151521274, 0.2552017702588013, 0.15212022300277436, 0.19458141098065035, 0.15371317895395414, 0.34888289336647305, 0.2268850790070636, 0.28180606982537676, 0.11429516625191484, 0.11716908775269985, 0.17062390010271752, 0.17955528013408184, 0.10064874137086527, 0.12458871890391622], [0.12982825775231632, 0.02141356943840427, 0.01434263404059623, 0.028639114129223993, 0.05617563599454505, 0.11665492105696883, 0.08490470690386635, 0.035850421459014924, 0.05974837392568588, 0.11855472411428179, 0.015806804045236537, 0.01436728352148618, 0.03950616457898702, 0.022458579524287155, 0.05675934235166226, 0.041836833980466635, 0.05370709166995116, 0.05236450156995228, 0.10869846692574875, 0.033741744966911416, 0.11346915164696318, 0.022249482172940458, 0.08635367772408895, 0.611586899629661, 31.88279935291835, 37.10161910738264, 22.611067567552837, 31.61157989501953, 29.234788758414133, 61.331707273210796, 53.726271629333496, 57.11377552577427, 7.143651417323521, 0.472145673419748, 0.24850962364247867, 0.5236865963254655, 56.98326751164028, 63.329015595572336, 61.53608853476388, 60.42787865230015, 59.702042034694124, 58.57246644156319, 58.95595836639404, 54.381524971553254, 54.146498680114746, 56.564322403499055, 55.18765844617571, 54.66191952569144, 52.314192703792024, 50.994816643851145, 50.01579114368984, 45.89818443570818, 41.667610440935405, 40.608909947531565, 41.227702617645264, 40.46124683107649, 40.34988110406058, 40.68591683251517, 40.174748284476145, 40.94391386849539, 42.32747391292027, 41.61827475684029, 44.65752451760428, 41.07177461896624, 40.3027514730181, 40.11850956508091, 37.996109349387034, 39.758662360055105, 39.7679659979684, 40.90503869737898, 38.743832792554585, 38.43952601296561, 39.80160570144653, 39.789474146706716, 38.915772914886475, 39.97885077340262, 41.92858130591256, 42.03350257873535, 45.59225525174822, 44.61760016850063, 42.013286794934956, 41.07755552019392, 43.181379726954866, 42.388965470450266, 49.97974041530064, 54.09532867159162, 53.045605250767295, 53.28614493778774, 55.33468232836042, 54.179356711251394, 40.94865253993443, 16.80994881902422, 19.333503280367168, 60.14431571960449, 54.54766682216099, 56.11916521617344, 55.422681263514924, 57.72050959723336, 56.1044419833592, 58.24440377099173, 51.16710417611258, 43.70790726797921, 43.185986382620676, 40.43376670564924, 37.96740286690848, 38.04557357515608, 37.515599727630615, 39.00334800992693, 36.71764080865042, 38.15442058018276, 38.95547839573452, 39.48058155604771, 35.76930897576468, 36.20688220432827, 36.61268132073538, 34.61038071768624, 37.465718609946116, 38.568786825452534, 37.95562219619751, 37.45884684153965, 36.499269349234446, 36.14461939675467, 37.905067103249685, 36.27480779375349, 38.11849839346749, 36.59852089200701, 34.19931486674717, 35.16732747214181, 37.68542064939226, 38.091028690338135, 36.35929788861956, 38.143817629132954, 40.50115728378296, 39.44222402572632, 39.4579929624285, 45.4050429889134, 49.35460751397269, 47.289401394980295, 48.007855551583425, 42.793788364955354, 46.59639154161726, 53.282469340733115, 56.07419647489275, 59.441137177603586, 52.63508135931832, 0.8559027154530797, 0.38550511108977453, 1.4652678200176783, 4.598615297249385, 0.7440563142299652, 48.54072332382202, 52.31968525477818, 44.88907323564802, 18.399455206734793, 27.72841235569545, 25.54700803756714, 37.295644078935894, 1.4347894383328301, 0.19019688053854875, 0.08580405078828335, 0.057768123756561957, 0.0545059580888067, 0.03227249612765653, 0.04372991614841989, 0.021232734766921828, 0.0172661004721054, 0.08022046075867754, 0.13067943922110967, 0.042847718843924146, 0.05324813736868756, 0.09405387632016625, 0.021671612913321172, 0.02156995140415217, 0.03848285913201315, 0.022654075641185045, 0.061911462140934806, 0.09547868450837475, 0.029576513650161878, 0.047977450370256386, 0.061699094250798225, 0.047980575024017265, 0.12323532652642046, 0.11397374421358109, 0.06685184847031321, 0.025234298348160725, 0.03523697830470545, 0.10814476877983127, 0.03987602723230209, 0.023873116388650875, 0.03323539499459522, 0.07709139652018036, 0.01749049369910998, 0.0821978407246726, 0.056778134379003725, 0.0827517288603953, 0.030487219603466134, 0.06740223536533968, 0.012788387664061571, 0.04073479811527899, 1.1809580645390918, 47.61765514101301, 39.588358538491384, 33.58394071034023, 44.25444562094552, 36.62349271774292, 72.18872615269252, 56.85037279129028, 60.93170642852783, 7.6023775679724555, 0.5624044016003609, 0.16627303856824124, 0.6721940817577499, 60.17703478676932, 66.81970718928746, 63.48405769893101, 64.21117278507778, 62.72830213819231, 62.94522489820208, 60.94251782553536, 58.359392983572825, 57.50597006934029, 57.340154784066335, 59.22842502593994, 56.67106410435268, 55.18710953848702, 51.75947632108416, 53.76663718904768, 48.72719212940761, 44.73279087884085, 44.76015288489205, 44.09178481783186, 42.04911518096924, 43.3615916797093, 42.88181856700352, 43.18898800441197, 42.03335666656494, 44.66835675920759, 44.39334011077881, 46.6361734526498, 43.24709926332746, 41.92293242045811, 41.32813535417829, 41.5976733480181, 42.526029109954834, 43.284060205732075, 42.232783862522666, 41.52890355246407, 39.696997097560335, 41.97968878064837, 41.08800908497402, 41.41714525222778, 40.1471882547651, 45.21629864828927, 43.16094854899815, 47.49531473432268, 45.876054423195974, 45.834431239536826, 41.59717655181885, 45.83320835658482, 47.16609518868582, 53.193348271506174, 57.037338393075125, 59.192641803196494, 53.99048382895333, 59.45552689688546, 54.632702350616455, 56.12814923695156, 22.47016852242606, 25.06424719946725, 64.24007034301758, 53.67035252707345, 60.692424365452354, 56.524766308920725, 58.24787092208862, 56.81209863935198, 61.52339417593819, 52.32787718091692, 44.89327342169625, 42.93924542835781, 41.02823373249599, 39.60070548738752, 40.27311740602766, 39.983297620500835, 40.471432890210835, 38.74800171170916, 39.68982308251517, 40.30824402400425, 40.22918394633702, 38.045827184404644, 38.68359885896955, 38.12219483511788, 38.33036981310163, 38.72505875996181, 41.008393151419504, 40.63012627192906, 39.28392669132778, 39.523788928985596, 36.813515526907786, 38.83239800589425, 39.447390011378694, 40.15756886345999, 38.95407485961914, 36.43388680049351, 37.53927571432931, 39.22481836591448, 40.604904311043875, 38.16475602558681, 40.521098613739014, 42.57904386520386, 40.36293676921299, 41.59532833099365, 45.81999635696411, 51.01709951673235, 49.98195341655186, 49.59623111997332, 44.66600479398455, 47.735979488917756, 54.50379242215838, 57.64094230106899, 60.77064718518938, 53.36847761699131, 0.6286963501146862, 0.550696849822998, 4.757108049733298, 2.3237019053527286, 1.5764748241220201, 51.45210191181728, 57.26844937460763, 51.16506140572684, 26.980155638286046, 31.582661492483957, 29.484180450439453, 43.920091356549946, 1.5361706039735248, 0.1085380951740912, 0.030548783085708107, 0.04808722376557333, 0.14811989265893186, 0.041037743645054955, 0.09850710843290601, 0.012919445006575967, 0.03419530152210167, 0.01289815257769078, 0.04469636036083102, 0.03926478931680322, 0.16159964219800063, 0.07971816164042268, 0.07813912922782557, 0.0401947113818356, 0.03211269434541464, 0.04443768584834678, 0.029122098748173033, 0.20955173910728522, 0.10610256836350475, 0.12064257636666298, 0.09438306758446352, 0.17643727601638862, 0.13002444936760835, 0.4184442678732531, 0.16037453365113052, 0.09171988548977034, 0.1720491221972874, 0.24674841814807483, 0.1440404722733157, 0.06290907825210265, 0.11700929275580815, 0.16218631714582443, 0.1262917196644204, 0.1603523998388222, 0.14026704403970922, 0.15454036742448807, 0.22629364074340888, 0.16782701946794987, 0.1284174613122429, 0.2485487615423543, 2.781856132405145, 67.52926417759487, 52.142245633261545, 40.032209464481895, 45.05622257505144, 41.041192122868125, 74.9273933683123, 64.71395138331822, 68.7198657989502, 7.898308294160025, 0.5021845272609166, 0.2168646367000682, 0.949394798704556, 64.64537961142403, 70.85075323922294, 69.28170408521379, 66.42493833814348, 66.6892339161464, 64.64543519701276, 64.36365100315639, 61.3353203364781, 62.97601236615862, 60.897785323006765, 63.09370790209089, 60.935576575142996, 58.10891042436872, 54.78187322616577, 58.348810877118794, 53.78822176797049, 49.02492938722883, 48.02215494428362, 47.26699692862374, 45.39618056161063, 45.18164103371756, 45.15377180916922, 46.01300341742379, 45.87304237910679, 48.217239516122, 49.31474569865635, 49.4027168410165, 44.66918012074062, 46.564204011644634, 45.23055287769863, 43.19905941826956, 46.04863725389753, 45.72964545658657, 46.72699335643223, 45.92225994382586, 43.57255288532802, 46.561667919158936, 42.66713660103934, 42.52268007823399, 43.184440408434185, 47.62561430249895, 47.18017223903111, 51.98808247702462, 49.280557087489534, 48.873288427080425, 46.31112630026681, 48.88532965523856, 48.59028482437134, 52.80212647574288, 56.02302646636963, 60.10663563864571, 56.72313737869263, 60.29205526624407, 57.36210414341518, 48.668306146349224, 13.876096282686506, 22.516419206346782, 64.81618022918701, 56.27505847385952, 61.00913715362549, 58.09265511376517, 58.94038050515311, 59.04867512839181, 61.90433611188616, 52.174308095659526, 45.479770864759175, 44.16037743432181, 42.14991617202759, 41.51744597298758, 43.445136819567, 41.316893168858115, 42.0632825578962, 41.0621200970241, 41.653932912009104, 44.446827343532014, 41.54751777648926, 40.888734749385286, 40.33123908724104, 40.28309849330357, 39.778548104422434, 43.56003223146711, 44.23771783283779, 43.449635778154644, 41.86603362219674, 42.29222917556763, 40.18796723229544, 42.84479856491089, 41.956061431339805, 44.64302710124424, 40.63391998835972, 38.88782031195504, 40.64268166678292, 43.159093379974365, 44.00241013935634, 42.05668524333409, 43.93985898154122, 45.59289796011788, 43.55583899361746, 42.73712927954537, 49.53115429197039, 54.25683954783848, 51.765972886766704, 53.34930406297956, 45.03733389718192, 49.66677965436663, 55.50457968030657, 62.763001441955566, 62.861116954258506, 55.87769447054182, 1.2161096526043755, 0.9059682860970497, 8.848853996821813, 11.90547251701355, 1.9463984370231628, 56.427224023001536, 61.74891185760498, 58.4421112877982, 30.067714486803325, 43.45392976488386, 37.77548319952828, 56.108364241463796, 5.093100351946695, 0.4441162331828049, 0.24794988653489522, 0.2386737157191549, 0.2292650948677744, 0.2083680076258523, 0.1414449265492814, 0.1359381398984364, 0.1545403538537877, 0.11477806605398655, 0.22273895862911428, 0.16837363370827266, 0.23468957522085734, 0.14801254841898168, 0.21543176073048795, 0.14188300232802117, 0.15377884757305893, 0.10370288177260331, 0.297256556472608], [0.05654340876000268, 0.09388370652283941, 0.21959431522658893, 0.13301351826105798, 0.019289188253294145, 0.06315470792885337, 0.1163901159805911, 0.05860787869564124, 0.1060866838587182, 0.01805913827515074, 0.031854576231645684, 0.10274186584034137, 0.03329643600487283, 0.024335733082677637, 0.022487797242190157, 0.027842334205550805, 0.12081056806657996, 0.0358312562374132, 0.09118496919316904, 0.11147474723735026, 0.06096879379557712, 0.08730657159217767, 0.019584732662354196, 0.04099471095417227, 7.570905702454703, 42.96924774987357, 32.3132506779262, 26.802017722811016, 17.49632661683219, 48.35453592027937, 55.73037528991699, 61.66825022016253, 23.19092426981245, 1.2936381953103202, 0.8263251025761876, 0.3438436309141772, 8.255177327564784, 70.18988922664097, 61.80736705235073, 65.72791590009416, 62.02100331442696, 59.85141440800258, 57.34976414271763, 54.081369740622385, 52.82757077898298, 54.45566919871739, 53.544906275612966, 50.55073642730713, 51.42068215778896, 47.39970057351248, 46.14741979326521, 42.55399213518415, 42.92641905375889, 42.053030490875244, 42.85188225337437, 43.87770734514509, 44.5230073928833, 41.62569890703474, 40.88256127493722, 43.03905282701765, 40.783441747937886, 42.210796288081575, 41.73022065843855, 43.69159289768764, 40.06848948342459, 40.591758319309776, 41.342198508126394, 39.38862214769636, 41.195271900721956, 39.22261231286185, 39.0472536768232, 39.98199830736433, 38.906014169965474, 41.19340978349958, 40.963459151131765, 42.41132129941668, 48.623254026685444, 53.397753851754324, 54.22335965292794, 52.38129840578352, 51.13671622957502, 50.47627605710711, 44.672209535326274, 45.660722800663535, 44.74583264759609, 45.50690705435616, 47.37643105643136, 54.64651536941528, 53.001967089516775, 58.22284351076399, 52.088056632450645, 35.72097383226667, 10.823269741875784, 37.26780612128121, 60.278332574026926, 51.40017802374703, 55.23669883183071, 54.677542550223215, 57.09319148744856, 53.83797434398106, 49.07928514480591, 40.785668645586284, 40.37068748474121, 41.36213983808245, 40.37154558726719, 37.00402818407331, 38.1939697265625, 39.021239621298655, 38.683848994118826, 36.26148809705462, 38.52174752099173, 38.75716291155134, 37.031546524592805, 36.99690628051758, 38.24896124431065, 37.60406766619001, 36.345849650246755, 37.532185077667236, 38.866371222904746, 38.09279005868094, 35.651328563690186, 37.71533611842564, 35.86251558576311, 39.01608405794416, 38.333301952907014, 36.498977524893625, 36.787445885794504, 39.16490057536534, 37.52089772905622, 38.849066734313965, 40.64167765208653, 46.652845655168804, 41.633171694619314, 46.031172956739155, 43.737336363111226, 50.97186326980591, 49.80221741540091, 55.59858880724226, 47.10109479086739, 53.50349153791155, 44.00054802213396, 54.50178786686489, 50.19249078205654, 64.33075128282819, 30.077344690050396, 0.12600608356297016, 0.2047394330480269, 2.0944050550460815, 1.4918508678674698, 3.712538455213819, 56.15158551079886, 53.05422101702009, 28.666843005589076, 21.622418812343053, 28.76073748724801, 34.64790793827602, 24.946687153407506, 0.5882813930511475, 0.13577662142259733, 0.045234998422009606, 0.04505246910931809, 0.24833548441529274, 0.06668262862201248, 0.08304307822670255, 0.07151641031461102, 0.03240702587312885, 0.14214943588844367, 0.045238004332142215, 0.07187069380389792, 0.06695437511163098, 0.08907483385077544, 0.06475869007408619, 0.04903228394687176, 0.00863492299270417, 0.07337788292872054, 0.011320445004717579, 0.10486829280853271, 0.12050568871200085, 0.08247158210724592, 0.10239642366234745, 0.03103149968332478, 0.025225774251988957, 0.09251202084124088, 0.08328692335635424, 0.08191088826528617, 0.03200694127008319, 0.012390868771555168, 0.07677522634289094, 0.030857312958687544, 0.01916269745145525, 0.0035962389915117194, 0.06892291376633303, 0.13120424534593308, 0.04499252393309559, 0.10097823119057076, 0.026066480836431895, 0.034108564390667846, 0.06682490384472267, 0.046875594316848686, 0.03360492516575115, 14.244958775384085, 56.82930932726179, 28.11055632999965, 35.328053201947895, 26.383790016174316, 54.85218899590628, 63.64845207759312, 66.60242312295097, 24.546222516468593, 0.4969687642795699, 0.7119154674666268, 0.350871950920139, 8.96667286327907, 73.53107643127441, 65.22549165998186, 66.99673339298793, 65.56254877362932, 63.59928662436349, 59.80552155630929, 56.78176627840315, 56.109597546713694, 59.441290037972585, 55.82423850468227, 53.72112648827689, 53.02786649976458, 51.24205092021397, 49.31715324946812, 45.619829177856445, 46.46651233945574, 45.46527692249843, 45.0348881312779, 45.698625223977224, 47.80100767953055, 43.60252741404942, 43.01793725149972, 44.92695134026663, 44.036678654806956, 45.72545569283621, 44.352467332567485, 46.36780970437186, 42.37225157873971, 43.3151672908238, 43.7046103477478, 42.24842078345162, 41.3303553036281, 42.48688643319266, 41.81198011125837, 42.923876013074604, 40.36550760269165, 44.38883767809187, 42.5009252684457, 44.8044684955052, 50.424421651022776, 55.08844859259469, 56.07507542201451, 53.60700927461897, 52.31131962367466, 50.75884192330496, 47.503513608660015, 47.777422019413535, 48.113193716321675, 50.596146379198345, 51.63556214741298, 56.56546538216727, 55.41358954565865, 58.74273204803467, 55.52271795272827, 36.56392233712332, 11.546264546258108, 41.29827199663435, 62.60730620792934, 54.355587346213206, 56.77401556287493, 57.036977086748394, 57.58916432516915, 56.92403064455305, 51.83950219835554, 42.97708184378487, 42.02636677878243, 43.8604028565543, 42.23405885696411, 38.66294881275722, 38.856098311288015, 41.01264197485787, 41.317657470703125, 39.3469364302499, 39.37833186558315, 41.61649601800101, 39.0001448903765, 38.52872003827776, 39.3289475440979, 37.92302124840872, 37.73991189684187, 40.91012477874756, 40.45053965704781, 40.42528642926897, 37.47560937064034, 40.175700187683105, 38.786074365888325, 41.95740590776716, 40.10881682804653, 40.304043837956016, 37.77412135260445, 40.255663531167166, 39.69227927071707, 40.6229487827846, 42.97667190006801, 48.425424916403635, 44.60880722318377, 48.36830030168806, 46.42853001185826, 52.917192118508474, 50.26119109562465, 57.67748635155814, 50.36940581457955, 57.986483165196006, 46.17775910241263, 54.95778424399239, 53.139162744794575, 67.72489070892334, 31.593834195818218, 0.20161591922598227, 2.097962098462241, 5.541394216673715, 1.432879877941949, 4.967502542904445, 60.759613445826936, 59.315604073660715, 34.632114682878765, 28.330517189843313, 30.70609760284424, 39.505709716251914, 29.996627467019216, 0.8622468007462365, 0.19982468177165302, 0.02924182964488864, 0.06507357103484017, 0.10265791070248399, 0.07511020318738051, 0.05725207751882928, 0.022678643697872758, 0.011310952299806689, 0.06828341486730746, 0.04751990402915648, 0.03583884904427188, 0.01816798377382968, 0.017096753398488675, 0.05996598010616643, 0.04141508714695062, 0.04609721287020615, 0.019691527288939272, 0.04859061532520822, 0.1963343790599278, 0.261878744832107, 0.3633856294410569, 0.19878060636775835, 0.1875398052590234, 0.14089342685682432, 0.3057285004428455, 0.1918955251042332, 0.2051485353814704, 0.1842137894460133, 0.1790342466639621, 0.14311446196266583, 0.11882524245551654, 0.20241565416966165, 0.13493637793830462, 0.1531684510409832, 0.30671544319816996, 0.08471323789230414, 0.18251946036304745, 0.2787413171359471, 0.16907757307801927, 0.23664318610514912, 0.1547491933618273, 0.1775883428220238, 26.052543333598546, 72.21947193145752, 45.70865842274257, 43.854729652404785, 27.3204836164202, 64.19970825740269, 66.31484413146973, 74.22015707833427, 26.357838494437082, 1.4488153542791093, 1.4090296434504646, 0.50851721316576, 10.853200844355992, 75.52870437077114, 66.82912199837821, 70.42838614327567, 69.35439613887242, 65.98161547524589, 63.623862402779714, 60.53759765625, 60.03934233529227, 63.742002623421804, 60.35025337764195, 55.587436948503765, 56.407869815826416, 54.05400773457119, 50.44843462535313, 48.58688368116106, 50.22501529966082, 48.10492188589913, 47.52433735983712, 48.07194920948574, 51.47216830934797, 47.56781571252005, 45.590955938611714, 50.389597279684885, 45.315692629132954, 48.767314502171104, 46.73321894236973, 49.70811448778425, 46.1843182018825, 47.09059258869716, 48.023711340767996, 44.48421907424927, 45.646652698516846, 45.77307864597866, 45.13045712879726, 44.48525435583932, 44.47584302084786, 46.534622056143625, 46.69483361925398, 48.23164313180106, 54.47450576509748, 59.38257081168038, 61.10009602137974, 56.157293455941335, 55.44709375926426, 56.005513531821116, 49.530914579119, 50.77579205376761, 51.12913921901158, 50.04090540749686, 52.18199280330113, 58.58279146466936, 58.269320011138916, 59.82260717664446, 57.31491892678397, 37.906970909663606, 12.505416461399623, 39.26064327784947, 64.34818431309291, 55.09924956730434, 57.3765355518886, 58.96102360316685, 59.21829455239432, 58.19583586284092, 52.130530970437185, 43.1391589982169, 43.3789587020874, 46.204735483442036, 43.59140682220459, 40.660111222948345, 41.41061047145298, 43.280853612082346, 42.55223076684134, 40.811387402670725, 42.13944523675101, 44.04583985464913, 41.83743483679635, 41.58209548677717, 43.43544408253261, 39.546770095825195, 38.518947396959575, 42.87712853295462, 44.63746854237148, 42.879695892333984, 40.22102676119123, 42.867373262132915, 41.079608712877544, 44.5605137688773, 44.58781671524048, 41.07992833001273, 40.559480462755474, 43.849018233163015, 43.369853087833945, 44.3293958391462, 46.58233186176845, 52.890455450330464, 47.78968906402588, 51.04464565004621, 49.062946455819265, 55.06048904146467, 53.11005326679775, 60.532122475760325, 50.931872912815635, 58.8474622453962, 48.283709457942415, 57.75070299421038, 54.36647169930594, 67.33643777029855, 33.01260076250349, 0.31451832449861933, 1.9049498268536158, 8.834953257015773, 7.827684198107038, 4.26679973091398, 67.4145633152553, 63.085710525512695, 37.80630540847778, 35.66119153159005, 45.06563738414219, 48.08241319656372, 43.190572193690706, 0.6715484421168054, 0.3665471412241459, 0.14983881185097353, 0.15825298534972326, 0.3764032152082239, 0.15269644851131098, 0.16846579233450548, 0.2772480786911079, 0.17226124581481728, 0.21340522090239183, 0.15126586599009378, 0.23708884790539742, 0.10988028493842908, 0.11522493564656802, 0.13496836407908372, 0.19227623753249645, 0.20112092792987823, 0.14899896191699163, 0.11008553499622004], [0.05985898870442595, 0.05523114578266229, 0.20977984900985444, 0.05308867824663009, 0.16856035297470434, 0.08626601099967957, 0.029402214967246567, 0.38705979766590254, 0.08338757724102054, 0.05867501295038632, 0.04072030121460557, 0.014494100020134022, 0.07200046362621443, 0.06225060072860547, 0.09656056109815836, 0.03250044657449637, 0.05385852372273803, 0.060960536024400165, 0.010890531154083354, 0.18256820631878717, 0.08521355568830456, 0.10141715513808386, 0.053468919093055386, 0.1361995522997209, 1.2458834435258592, 28.411557504108973, 41.49908535821097, 30.98733983721052, 23.368294409343175, 42.28571176528931, 46.492842538016184, 51.49577133996146, 41.701330048697336, 1.293805060642106, 0.26876047413264004, 0.15036623712096894, 0.12767454689102514, 27.061218534197124, 72.84016840798515, 57.609133447919575, 67.68783596583775, 58.88825511932373, 58.920876911708284, 53.92989206314087, 52.648428848811555, 51.16298042024885, 49.625107833317344, 47.03379801341465, 49.09424114227295, 43.91340371540615, 46.51141159875052, 44.611506598336355, 44.98583732332502, 44.041351318359375, 41.88761820111956, 44.1239515032087, 42.11782591683524, 42.83345215661185, 41.09948403494698, 42.65905932017735, 40.33488689150129, 44.66307265417916, 42.31683969497681, 39.6276992389134, 42.027450697762625, 41.126971108572825, 40.87149626868111, 40.98256322315761, 40.23249128886631, 38.60764810017177, 38.74300595692226, 39.62591355187552, 38.121770995003835, 41.948602540152415, 43.45064326695034, 44.182524817330496, 53.13139465876988, 57.57434034347534, 51.91461917332241, 54.01806470326015, 53.33572728293282, 52.094608783721924, 51.25590215410505, 50.31280926295689, 45.709189959934776, 46.95939670290266, 46.82727670669556, 48.85474368504116, 50.742134979793, 55.19702809197562, 53.082204886845176, 59.664681570870535, 41.01801640646798, 39.70185736247471, 55.3390805380685, 51.02563885280064, 55.13213539123535, 54.3923294203622, 54.62816865103585, 51.79158394677298, 45.03301559175764, 41.57262509209769, 40.08800349916731, 42.41206475666591, 40.92142949785505, 39.054650034223286, 38.9629442351205, 38.53121096747262, 38.352204527173726, 38.19793714795794, 36.32230915342058, 38.38453796931675, 37.64415529796055, 40.32969658715384, 39.2440197127206, 39.06112575531006, 35.91941785812378, 38.18378019332886, 37.758929116385325, 37.087378774370464, 37.45206192561558, 36.609624113355366, 34.85932772500174, 37.77950620651245, 37.487369196755544, 37.96111127308437, 36.5768529347011, 38.64203126089913, 35.8047274180821, 40.33139542170933, 45.41745594569615, 50.269310065678184, 47.434431144169395, 48.72469425201416, 49.19226632799421, 52.8923453603472, 51.98710625512259, 55.933085509708945, 52.25778375353132, 53.91171210152762, 45.800867966243196, 55.98080573763166, 49.9410354750497, 69.15420464106968, 22.307332277297974, 0.3406359244670187, 0.44211783898728235, 1.076611755149705, 0.18792662450245448, 11.386945826666695, 68.30716364724296, 35.99384348733084, 15.038582018443517, 30.606839111873082, 27.015904120036534, 45.17146192278181, 6.300170072487422, 0.47675460896321703, 0.17694951567266667, 0.14349395302789553, 0.09233597493065254, 0.07003692577459983, 0.10229638724454812, 0.0540027225922261, 0.10562148024993283, 0.06626756196575505, 0.033514076112104316, 0.0613517521747521, 0.10058202102248158, 0.04823872706453715, 0.041574105221245966, 0.06270443887582847, 0.11871002720935003, 0.06722139221216951, 0.0336352726444602, 0.012812334861207222, 0.07577579175787312, 0.039140586874314716, 0.1949285359254905, 0.03400872474802392, 0.10282164120248385, 0.054132024225379737, 0.0548650116792747, 0.2252106445708445, 0.04172537103295326, 0.08960368404431002, 0.052348929191274304, 0.0321313879851784, 0.05025161137538297, 0.02904146843190704, 0.0716637202671596, 0.02037615215938006, 0.07679290218012673, 0.05747183465531894, 0.016716907798711742, 0.08452584687620401, 0.07686844348375287, 0.0399817463808826, 0.03535063970567925, 0.03196340646328671, 2.528022804430553, 45.79956865310669, 46.91028683526175, 31.986754826137, 30.98508514676775, 49.6724910736084, 55.28340114865984, 56.12117671966553, 46.252900396074565, 0.7873759982841355, 1.093278855085373, 0.32056086882948875, 0.21173263208142348, 30.71917063849313, 77.70957715170724, 61.18931089128767, 69.98577894483293, 61.928856304713655, 61.411034856523784, 56.768790517534526, 55.384876114981516, 52.21294355392456, 53.58648082188198, 50.05562516621181, 51.40445811407906, 47.49949407577515, 48.702230725969585, 46.25882026127407, 49.69701474053519, 46.48148570741926, 43.908307211739675, 44.40316138948713, 43.64506775992257, 46.01117951529366, 44.53143555777413, 45.41411733627319, 44.380774293627056, 47.03797040666853, 45.725653716496055, 42.68206133161272, 44.45493589128767, 44.22020142418997, 42.95968355451311, 42.7066718510219, 43.58729348863874, 42.54016521998814, 42.4781699180603, 42.192790031433105, 40.58433069501604, 42.748993328639436, 43.136136531829834, 46.3292680467878, 53.83176612854004, 58.959175382341655, 56.26272889545986, 57.225068296704976, 55.75240455354963, 54.38708005632673, 52.397939341408865, 50.235955238342285, 46.6981201171875, 48.649827412196565, 50.405828271593364, 54.36027043206351, 51.22056014197213, 56.710616724831716, 54.62245028359549, 63.7694480078561, 45.048419748033794, 41.25686420713152, 58.126360825129915, 51.579351220812114, 56.10819053649902, 56.202904905591694, 55.802528858184814, 54.2170159476144, 47.25653294154576, 43.43773351396833, 42.01114327566964, 42.15642663410732, 41.72669792175293, 41.36661447797503, 39.49629838126046, 40.47941984449114, 39.910991191864014, 39.495634828295024, 37.99453558240618, 40.34974561418806, 38.89105122429984, 41.85967254638672, 39.85440158843994, 41.94982194900513, 38.617552757263184, 40.041943890707834, 38.803993770054404, 40.71815994807652, 38.020695550101145, 39.71972118105207, 37.84238392966134, 40.626523630959646, 39.65940734318325, 40.11558437347412, 39.03102963311331, 40.429107938494, 37.984078543526785, 41.22991909299578, 46.16096183231899, 52.989008699144634, 49.97333417619978, 51.95107984542847, 50.95757777350289, 53.91484921319144, 53.11435072762625, 56.41313655035836, 53.77671207700457, 57.038443156651084, 47.376173973083496, 58.061190196446006, 52.52913522720337, 69.5207290649414, 23.433268751416886, 0.49929033113377436, 2.937130783285413, 3.4444302703653062, 0.781497659427779, 14.366844075066702, 73.09411117008754, 41.621648107256206, 23.238347462245397, 37.14169979095459, 27.80026194027492, 52.55939810616629, 7.84675179209028, 0.6148983133690697, 0.09927806670644454, 0.11424084273832184, 0.16140821389853954, 0.10518266486802272, 0.135940053367189, 0.014431281248107553, 0.05929890554398298, 0.02042907110548445, 0.025201874552294612, 0.031301264850688834, 0.0237531938057925, 0.03403545902775867, 0.0584470998229725, 0.018228907736816576, 0.028232293369780694, 0.039042891402329714, 0.03050943823265178, 0.014629683191222804, 0.13093262777796813, 0.16811729674892767, 0.3110939753907067, 0.19341780484787055, 0.2329757043293544, 0.15647966121988638, 0.09521419834345579, 0.4939662196806499, 0.2043161764740944, 0.18321869069976465, 0.11222249961325101, 0.12066213174590043, 0.19745412468910217, 0.18124912067183427, 0.19583997130393982, 0.13544076015906675, 0.12962739781609603, 0.23475639734949383, 0.06250579774911914, 0.18571491246776922, 0.2495465608579772, 0.2573706938752106, 0.1800918249147279, 0.11850171695862498, 3.052655875682831, 65.32082094464982, 57.77140167781285, 50.046074867248535, 39.931144441877095, 55.67897946493966, 58.18188040597098, 64.48692594255719, 49.6417487689427, 4.441153483731406, 2.2845718222005025, 0.34887314960360527, 0.41165918910077637, 33.051931040627615, 79.15187726702008, 64.00412341526577, 72.36248670305524, 63.31119346618652, 65.36483778272355, 59.54469312940325, 58.88471848624093, 55.81146771567208, 56.97974477495466, 52.33045496259417, 54.71595914023263, 49.295325483594624, 52.72220482145037, 49.78127554484776, 54.94745227268764, 51.97116361345564, 48.475031580243794, 48.742853369031636, 46.125387055533274, 48.79856749943325, 46.917314938136506, 47.73873792375837, 46.70896625518799, 51.637980120522634, 48.54914454051426, 44.618340151650564, 48.71669340133667, 47.90274320329939, 47.76769454138619, 45.76549816131592, 44.907624925885884, 43.283751010894775, 45.72380549567086, 45.81887422289167, 43.44173220225743, 46.58047669274466, 47.050744669778005, 49.62707764761788, 58.26823609215872, 61.14786488669259, 57.57785613196236, 59.778277669634136, 59.11358519962856, 57.592273644038606, 57.78835528237479, 54.467356068747385, 49.36834757668631, 51.73463303702218, 51.35099172592163, 54.10609837940761, 53.907702990940635, 58.39427294049944, 56.00950179781233, 65.20785018375942, 37.578446183885845, 38.343748569488525, 60.53382478441511, 53.08318110874721, 58.35621765681675, 56.79871988296509, 57.2803099496024, 56.087147917066304, 47.917945861816406, 44.82061958312988, 42.54264572688511, 45.06170122964041, 43.88135862350464, 42.63187101909092, 42.20733608518328, 43.93883064814976, 41.795679637363975, 42.26192113331386, 40.72979123251778, 43.37881973811558, 42.121793338230674, 43.64278180258614, 42.90928132193429, 42.87245239530291, 40.14302280970982, 41.32250383922032, 41.206659998212544, 42.329238755362375, 41.647842815944124, 43.71190595626831, 38.80029385430472, 42.65291363852364, 43.54675769805908, 43.29916558946882, 40.33508838926043, 43.661288329533164, 41.37327085222517, 45.55103158950806, 49.892596108572825, 55.20865590231759, 52.71525662285941, 53.97209194728306, 55.24307380403791, 57.08451666150774, 55.170871598379954, 58.65768609728132, 55.96533557346889, 59.153808321271626, 50.28594057900565, 58.42005770547049, 54.04857424327305, 72.31343242100307, 25.9426679951804, 0.42458517264042583, 3.6958497507231574, 6.3736160056931634, 5.172751895018986, 13.833353570529393, 79.24537917545864, 43.79523917606899, 23.718605211802892, 44.14958340781075, 39.917036124638145, 62.47804192134312, 14.074336205210004, 1.050487179841314, 0.4075833920921598, 0.1966502099697079, 0.31359918096235817, 0.24523010104894638, 0.22149118701262133, 0.13172333820589952, 0.24895634395735605, 0.12336210400930472, 0.0876114373760564, 0.1399818557713713, 0.2775401201631342, 0.0830169003456831, 0.1726685432451112, 0.12468608867909227, 0.2691619225910732, 0.11196056474000216, 0.11562151222356729, 0.09617169267897095], [0.026652115929339613, 0.03670187434181571, 0.036540864767240624, 0.03764357916744692, 0.027142186150220887, 0.04952932781140719, 0.0429052246867546, 0.02459531513574932, 0.07497767172753811, 0.026763629766979387, 0.01796635370036321, 0.046955922685031376, 0.02195048232429794, 0.05476002874118941, 0.14718763982611044, 0.009987609693780541, 0.01224144094157964, 0.10753367335668632, 0.061135564132460525, 0.056629355398139784, 0.09313209328268256, 0.003852253222638475, 0.052268115670553277, 0.07058615237474442, 0.0875218707535948, 17.267359154564993, 49.533895356314524, 30.51335457393101, 34.13133021763393, 19.63070031574794, 52.26360981804984, 61.30322660718645, 59.999758447919575, 2.244348917688642, 0.5532310966934476, 0.3548440406365054, 0.23677400765674456, 3.725793012550899, 60.41474655696324, 63.90487534659249, 61.28692613329206, 60.960444177900044, 56.28327819279262, 52.07587991441999, 49.850559507097515, 49.451083251408164, 44.09163543156215, 44.802637645176475, 46.41260821478707, 49.33643797465733, 49.91373947688511, 54.33271040235247, 56.2280330657959, 55.56820086070469, 52.033363887241904, 49.39706795556204, 43.856220041002544, 43.478397846221924, 42.12074416024344, 45.22046061924526, 41.78108147212437, 41.49554525102888, 41.13856765202114, 41.152224336351665, 40.432595934186665, 42.646972928728374, 40.78589793613979, 40.33582837241036, 39.46672337395804, 41.47522177015032, 39.34445244925362, 40.099301270076204, 39.60592358452933, 40.541533265795024, 42.11002308981759, 45.210208552224294, 51.02114684241158, 52.47841337748936, 56.63829639979771, 55.65779788153512, 56.77762862614223, 54.332845892224995, 55.269855635506765, 53.4697893006461, 54.319793701171875, 52.960788590567454, 50.84795257023403, 49.669948032924104, 49.9740880557469, 54.34977865219116, 57.18121474129813, 54.21141569955008, 52.9805075781686, 51.19791596276419, 54.19228730882917, 54.99630158288138, 57.01597268240792, 52.75259624208723, 50.57229668753487, 44.39020299911499, 40.79161630358015, 42.69868837084089, 41.44493804659162, 39.906214305332725, 40.98891387666975, 42.26012849807739, 40.54979814801897, 39.052582945142476, 39.37888772147042, 37.74760355268206, 37.11991024017334, 37.83608538763863, 38.95868846348354, 38.33800935745239, 37.413315296173096, 38.61382852281843, 35.885041645595, 37.228774615696494, 37.37428379058838, 37.777435643332346, 35.676453249795095, 37.55474240439278, 36.585395744868684, 36.20657648359026, 36.71259989057268, 38.81346763883318, 37.15859433582851, 38.219681535448345, 36.153672899518696, 38.847281047276084, 48.802072865622385, 55.4442971093314, 50.026943002428325, 50.973079204559326, 54.12691865648542, 54.58442279270717, 55.72958319527762, 59.35766846793038, 53.066665240696494, 59.62461825779506, 50.97916235242571, 57.46064696993147, 52.842835971287315, 66.16351236615861, 14.603756802422659, 0.604323263679232, 1.9927042722702026, 3.506479637963431, 0.6681300369756562, 25.890580824443273, 61.43672929491316, 15.070774759565081, 18.289593764713832, 27.931440455572947, 34.60201161248343, 31.451872076307023, 0.5124793691294534, 0.08290237041988543, 0.11052686095769916, 0.05100586750943746, 0.1368181048227208, 0.06569776896919523, 0.1047012781990426, 0.07378938049077988, 0.05246482975780964, 0.01613718274581645, 0.0796188512550933, 0.03951133501582912, 0.09639988400574241, 0.020400248634229814, 0.05031222830127392, 0.03842620824330619, 0.05248300771095923, 0.023077327126104916, 0.08301168241138969, 0.031220461507993083, 0.0636858922828521, 0.07411231566220522, 0.05821084750017949, 0.0441495086332517, 0.04105725831219128, 0.027166038352463926, 0.03494102507829666, 0.023800789644675593, 0.058829759646739276, 0.01700532928641353, 0.0488174902940435, 0.02601641682641847, 0.029318086802959442, 0.036021934755678685, 0.04456078567142997, 0.03420609701424837, 0.010801454773172736, 0.04119624603273613, 0.02470055591714169, 0.03284142738474267, 0.08351668209901877, 0.0582389592060021, 0.05462033873690026, 0.10274122123207365, 0.08248877618461847, 23.406815222331456, 60.23740768432617, 30.08981670652117, 42.77856486184256, 27.264321327209473, 57.25093991415841, 64.7712184361049, 64.88545376913888, 2.601705410650798, 1.4057370658431734, 1.6920461654663086, 0.22897226629512651, 4.775654528822217, 65.36230169023786, 66.80094705309186, 65.30595874786377, 64.15009811946324, 60.09140518733433, 55.075729915073936, 52.35452004841396, 51.86419609614781, 47.629939556121826, 46.729637145996094, 48.22499023165022, 51.335146359034944, 51.699336188180105, 56.35927758898054, 59.43683624267578, 56.667037623269216, 52.755389417920796, 49.3755007471357, 47.485583782196045, 43.32113231931414, 44.70711381094796, 46.0531952721732, 44.4740503856114, 44.00286177226475, 43.63245677947998, 43.521153586251394, 43.594686371939524, 44.058544635772705, 43.10039847237723, 42.3804817199707, 41.73108918326241, 43.13761649812971, 43.48951496396746, 42.892567430223735, 42.57365206309727, 43.63855382374355, 44.03864846910749, 46.153436933244976, 54.049845763615195, 56.33551474979946, 59.46396895817348, 56.77735417229788, 58.34815079825265, 56.88539171218872, 58.06622764042446, 54.56122970581055, 57.012505531311035, 55.696447236197336, 52.15187236240932, 51.646734850747244, 54.03159632001604, 56.63656629834856, 60.645357268197195, 54.16650949205671, 55.87486655371529, 56.5692069871085, 54.47130264554705, 57.481696537562776, 58.76997593470982, 55.96856648581368, 52.68241943631853, 47.33317504610334, 42.28777538027082, 44.48895079748971, 43.0574620791844, 41.86921937125069, 40.888390813555034, 41.52831295558384, 41.58226571764265, 40.62721150262015, 42.36039447784424, 39.69968605041504, 38.00806719916207, 39.50707851137434, 40.82720845086234, 40.69698531287057, 38.9710145677839, 40.74852705001831, 37.35504770278931, 39.145897252219065, 40.127976485661094, 40.591126033238, 38.07562105996268, 39.946854318891255, 39.15987702778408, 38.15529605320522, 40.201648235321045, 40.75848034449986, 39.55707080023629, 41.36525610515049, 38.97946010317121, 40.472753047943115, 50.83635950088501, 57.190612179892405, 51.8741910798209, 53.63694906234741, 56.78763403211321, 55.792151723589214, 56.96785640716553, 61.01430661337716, 54.96667793818882, 60.126799310956685, 53.02364199502127, 60.380116735185894, 54.839303561619346, 66.37179851531982, 16.69386179106576, 0.9240021726914814, 8.464030623435974, 0.4247375444642135, 0.08426288741507701, 30.707112039838517, 66.94013336726597, 21.018726314817155, 23.85830569267273, 29.667209897722515, 39.112684862954275, 38.168462889535085, 0.6982353872486523, 0.04024690429547003, 0.05043034767732024, 0.037973496464214156, 0.10599535304520812, 0.029597117366003137, 0.07957236482096569, 0.018900614996839846, 0.022888288966247013, 0.025926052925309966, 0.09393755506191935, 0.039497265592217445, 0.0110786812812356, 0.03245942234726889, 0.013802852647911226, 0.061258928584201, 0.055162101451839717, 0.05382096002410565, 0.020658746727609208, 0.05599778178813202, 0.14547775872051716, 0.14338955362992628, 0.10266610062015907, 0.11955322910632406, 0.0991346040474517, 0.1433835689510618, 0.12263077896620546, 0.08086711141679968, 0.2065835962338107, 0.06664395212594952, 0.15070732310414314, 0.1359599344432354, 0.08586461003869772, 0.10186008922755718, 0.25341206629361424, 0.07801218211118664, 0.06734743687723364, 0.24932788259216718, 0.0893062889309866, 0.14410116044538362, 0.1310993166906493, 0.13471144357962267, 0.13217649103275367, 0.13063576870730945, 0.13593162596225739, 30.15948976789202, 73.01425552368164, 43.319322313581196, 54.4535083089556, 29.973180770874023, 64.15485068729946, 69.38759463174003, 70.5460330418178, 3.1390124303953986, 3.8770288058689664, 1.5624828892094749, 0.3402641958424023, 6.37892312662942, 66.99557304382324, 68.18552848270961, 69.29994310651506, 67.87834862300328, 62.29688153948103, 57.587340423039024, 55.80635731560843, 56.14290026256016, 51.78714404787336, 51.253331320626394, 51.38010467801775, 54.94046238490513, 54.22252239499773, 60.528829029628206, 64.93322958265031, 62.57250962938581, 58.99785600389753, 52.87483589989798, 48.68756307874407, 49.28411109106881, 48.3713436126709, 50.575909750802175, 46.60433333260672, 47.245283808027, 46.56031649453299, 45.493403230394634, 46.94230760846819, 47.067903246198384, 47.26572888238089, 46.0912436076573, 43.73011023657662, 47.181919710976736, 45.8291506086077, 44.868582998003276, 44.59715856824602, 45.802573748997276, 46.00701754433768, 48.4211483001709, 55.32867908477783, 56.6119453566415, 61.67342662811279, 59.61694049835205, 61.487089838300435, 60.52246447971889, 62.17295346941267, 57.494825158800396, 59.73421219417027, 56.34763240814209, 55.72790173121861, 54.4445138658796, 55.72723470415388, 57.62814024516514, 62.660209792000906, 56.588436126708984, 56.49667821611677, 59.50546360015869, 56.60996512004307, 58.32144887106759, 60.86542061397007, 55.75784846714565, 53.73396675927298, 48.267197063991, 43.153364590236116, 46.351154872349326, 46.40637568065098, 45.02392734800066, 43.879871709006174, 43.37858002526419, 43.739907196589876, 43.95451620646885, 44.99868106842041, 40.957442011152, 41.06439215796334, 41.952066217150005, 44.85146958487374, 41.84982347488403, 41.01447629928589, 41.602749007088796, 39.98599699565342, 41.873207637241904, 42.525052888052805, 44.18210792541504, 39.813150133405415, 43.15301718030657, 42.055844511304585, 39.926600319998606, 41.695052351270405, 43.05797971997942, 42.52485833849226, 43.8253561428615, 41.34184067589896, 43.44554328918457, 53.25209181649344, 60.14242580958775, 54.597777230399, 57.20119081224714, 60.5633476802281, 58.83065455300467, 60.78036076681954, 64.16482135227749, 56.21529354367937, 64.12000547136579, 55.725112029484336, 62.05222157069615, 56.73895842688424, 66.97434629712785, 16.95896683420454, 0.8287911702479634, 5.806447582585471, 10.704503314835684, 1.8206410365445274, 30.557607650756836, 74.45406123570034, 21.171029090881348, 28.966301679611206, 39.96412754058838, 45.10594735826765, 52.708704471588135, 0.9607319789273399, 0.2802151223378522, 0.18195177082504543, 0.09540927716131721, 0.21338312780218466, 0.19098231196403503, 0.20387573939348969, 0.17883439095956938, 0.13182848399238928, 0.07062759729368345, 0.23383060417004994, 0.15500665668930325, 0.1527007097112281, 0.06053133548370429, 0.12515068160636084, 0.10634223371744156, 0.15908727129655226, 0.15435777365096978, 0.15724346094897815, 0.12406715617648192], [0.02761424974804478, 0.08553745437945638, 0.027649640438279936, 0.03614525170996785, 0.0713030042658959, 0.02766588456662638, 0.01784544554539025, 0.01808144511388881, 0.04123231695432748, 0.011252675471561295, 0.08159678761980363, 0.04420981343303408, 0.040869388928903, 0.03818826636831675, 0.04140282262648855, 0.07935715386910097, 0.042252124553280215, 0.035723925568163395, 0.03968854122129934, 0.037245486064680984, 0.009127929573878646, 0.017698256032807485, 0.10535330285451242, 0.07445197672184024, 0.10781273445380585, 0.179303679349167, 42.13852112633841, 46.42311041695731, 35.32586104529244, 26.315815789358957, 33.11605943952288, 58.22178043637957, 65.12988444737026, 13.843610848699297, 1.2516712929521288, 1.247147798538208, 0.027442161392952715, 0.12526584256972584, 27.19817795072283, 75.57698740277971, 59.83569063459124, 68.33023861476353, 56.06130756650652, 58.393744877406526, 49.02272680827549, 50.220665727342876, 45.61081389018467, 49.26812328611101, 51.935710430145264, 58.68663229261126, 59.714993476867676, 61.91334792545864, 58.9944235937936, 61.11368669782366, 59.20765686035156, 57.09905924115862, 48.33334738867623, 41.886353628976, 41.356605597904746, 41.081078256879536, 41.97018364497593, 42.70835678918021, 43.98308025087629, 41.374768189021516, 41.81099346705845, 41.320402009146555, 42.47773565564837, 42.50956187929426, 41.42324229649135, 39.44734137398856, 40.10511343819754, 40.71880265644619, 41.20732702527727, 39.58155972617013, 41.74673305238996, 44.00946603502546, 53.49745355333601, 54.36039202553885, 54.60870327268328, 53.195158277239116, 55.722617626190186, 55.30117116655622, 53.339930943080354, 54.01430572782244, 55.53943184443882, 53.75567987986973, 56.57267761230469, 55.01116377966744, 53.239793504987446, 54.16503994805472, 57.117465019226074, 55.65845101220267, 51.83489554268973, 53.17139196395874, 56.42921815599714, 54.70515816552298, 54.27557536533901, 51.10500465120588, 46.73980236053467, 41.915157386234824, 39.80604212624686, 42.043212686266216, 42.538935388837544, 40.77304376874651, 42.045682770865305, 39.61659254346575, 41.07562739508492, 39.35103586741856, 39.51716382162911, 36.907601084027974, 37.28557613917759, 37.25437525340489, 37.804266112191335, 37.71005548749651, 38.6889454977853, 39.3859783581325, 37.9775333404541, 39.01909957613264, 38.132797786167686, 38.48476573399135, 37.77396501813616, 37.45121077128819, 37.140674931662424, 37.88079009737287, 38.02632359095982, 38.53056131090437, 37.894092423575266, 39.52636671066284, 39.683302198137554, 39.512623173849924, 45.93718467439924, 53.56037296567644, 56.241467407771516, 55.28075041089739, 52.88022075380598, 57.905713830675396, 54.99833740506853, 57.117294788360596, 58.35643999917166, 56.58562905447823, 54.39785671234131, 57.145789350782124, 54.89523308617728, 60.89886229378836, 3.328332168715341, 0.30540988753948894, 2.496771978480475, 0.533837154507637, 1.2790354703153883, 45.57408571243286, 48.914261954171316, 12.393188289233617, 32.10681274959019, 22.51562363760812, 45.256608622414724, 10.691570111683436, 0.6816929206252098, 0.16362899116107396, 0.046697645115533044, 0.005704433299667601, 0.11044194230011531, 0.07294996481920991, 0.032883292995393276, 0.09780390188097954, 0.03027843777090311, 0.0342012624522405, 0.03914407793698566, 0.057478871063462326, 0.0359715738865946, 0.010726798957745944, 0.0245201962201723, 0.01421106101146766, 0.0669646617025137, 0.034048588680369515, 0.029488745145499706, 0.03758336936256715, 0.07150967924722604, 0.04079321658770953, 0.02826903434470296, 0.020241661429671303, 0.05582748306915164, 0.05508070099832756, 0.03042902165491666, 0.021639665788305656, 0.03278677478166563, 0.03890826326927968, 0.11217989439943007, 0.043188238250357766, 0.020828076837850467, 0.061302639810102325, 0.08097030302243573, 0.08772297496242182, 0.06544737597661358, 0.0457302543467709, 0.05320542698193874, 0.034190877473780086, 0.0154466647987387, 0.01820500803712223, 0.07253160726811204, 0.01704615673848561, 0.09690655288951737, 0.5535141272204263, 55.96193790435791, 49.114251954214915, 37.00802339826311, 36.049317904881065, 37.22839593887329, 64.78824152265275, 69.66055461338588, 14.636276108877999, 2.061689244849341, 3.162148194653647, 0.23126913447465214, 0.1416130539562021, 29.29984474182129, 79.39233357565743, 62.613087109157014, 71.0301765714373, 56.82022455760411, 58.37098952702114, 52.14803695678711, 52.67043726784842, 48.798598766326904, 52.67709016799927, 54.17660869870867, 59.48019995008196, 61.146301542009624, 62.94575296129499, 59.042922019958496, 64.15932532719204, 62.4006598336356, 58.23269258226667, 50.49047122682844, 45.202575956072124, 43.967828954969136, 43.5057007925851, 42.721877983638215, 44.66454219818115, 47.22008269173758, 45.49730464390346, 43.10629054478237, 43.62758609226772, 44.02409199305943, 45.2902135848999, 44.25136062077114, 41.99001727785383, 42.76592608860561, 43.2466094153268, 43.096743719918386, 44.23831190381731, 45.06105504717146, 47.3389698437282, 54.673689774104524, 57.455053670065745, 57.926499366760254, 56.01125969205584, 57.22094454084124, 58.01200042452131, 55.56627968379429, 57.37320041656494, 57.99912541253226, 58.46390778677804, 58.73349094390869, 57.22945955821446, 54.86641543252127, 57.437036991119385, 58.1795597076416, 59.04690333775112, 54.09300797326224, 54.71299920763288, 57.93044594355992, 57.79251377923148, 57.06613867623465, 53.561901569366455, 51.400355202811106, 43.723151615687776, 41.50073555537632, 42.88931219918387, 43.93404333932059, 43.17911114011492, 42.21918971197945, 40.15052686418806, 42.327925545828684, 40.256160327366416, 41.72585718972342, 39.008712019239155, 38.6865587915693, 38.5592052595956, 38.9742420060294, 39.910080977848594, 41.307210854121614, 40.67962176459176, 40.87797546386719, 40.92497655323574, 39.998031275612966, 39.865174770355225, 40.060405254364014, 39.44786596298218, 39.42050743103027, 39.75273902075631, 40.32924842834473, 40.05413103103638, 41.26388883590698, 41.61313656398228, 42.45627614430019, 43.17193712506975, 49.461752210344585, 55.7448205947876, 57.255741119384766, 57.48740100860596, 55.38359069824219, 59.48174245016915, 58.60067612784249, 59.46152319226946, 60.83596025194441, 58.464866638183594, 56.63904333114624, 60.699296133858816, 56.524832316807334, 61.73561995370047, 3.1860128683703284, 0.22954570981008665, 7.342396821294512, 1.085162490606308, 1.6578131509678704, 50.15968138831002, 56.64032874788557, 15.840883561543055, 37.12257487433297, 21.547548498426163, 52.372821603502544, 14.705085856573922, 0.8879219687410763, 0.12639677045600756, 0.05535541607865265, 0.0398315899739308, 0.04802707502884524, 0.1309772753821952, 0.05023336556873151, 0.02017169598756092, 0.020063303411006927, 0.03177761000448039, 0.005322250146751425, 0.0839509784377047, 0.03921211803598063, 0.012412366457283497, 0.022838231741583774, 0.04235268344304391, 0.026157840487680266, 0.02823964529670775, 0.02742082316295377, 0.04358041113508599, 0.17647215271634714, 0.1184698258127485, 0.09106942146484341, 0.08303672035357781, 0.17849057726562023, 0.08142920304089785, 0.10802410489746503, 0.1654668575418847, 0.11475861924035208, 0.17762885136263712, 0.2106776458344289, 0.22671643591352872, 0.12801651496972355, 0.1568812182439225, 0.10853368469646998, 0.2759981086211545, 0.12171171685414654, 0.23154836520552635, 0.1164377084267991, 0.12382608625505652, 0.0978755551789488, 0.1423520464450121, 0.14726358146539756, 0.10057405502136264, 0.20829895990235464, 0.9895049035549164, 68.50222737448556, 59.26725850786482, 51.237218448093955, 39.8266852242606, 44.04573563167027, 66.60222162519182, 78.79414926256452, 15.614363602229528, 5.145120212009974, 5.22015597990581, 0.37851470762065476, 0.30913279205560684, 31.869969504220144, 83.51471369607108, 66.09667764391217, 76.44582489558628, 60.24311910356794, 64.89772428785051, 55.70521933691842, 57.54045397894723, 51.119515963963096, 56.35329866409302, 56.79017012459891, 63.80035359518868, 63.90746007646833, 68.0800061907087, 62.95354189191546, 68.55557564326695, 64.55804770333427, 63.16347476414272, 54.20190708977835, 47.02839578901018, 46.625243936266216, 45.136755670819966, 45.899747780391145, 48.50676052910941, 49.10942643029349, 47.45395905630929, 47.30854715619768, 48.050302096775596, 47.945512839726035, 48.535394055502756, 45.02018921715872, 44.93260717391968, 45.52391971860613, 46.74157762527466, 46.10043260029384, 45.616553102220806, 45.979249068668906, 49.92327240535191, 58.01042318344116, 59.936231068202424, 58.843995094299316, 59.16161114828927, 60.08928598676409, 59.4157623563494, 58.59257452828543, 58.79177243368966, 59.56983866010393, 59.257600511823384, 61.25321347372872, 60.77895723070417, 56.776308468409944, 58.15472684587751, 60.10862282344273, 60.01530156816755, 55.83602612359183, 55.96360894611904, 58.95215770176479, 58.97211987631661, 59.28930514199393, 54.214677878788535, 50.26137522288731, 44.91246434620449, 43.50669091088431, 45.28800753184727, 44.60802902494158, 44.533026695251465, 43.82097182955061, 41.69061592647007, 44.26023694447109, 42.52072416033064, 44.07582480566842, 41.768102237156455, 39.87028864451817, 40.88797739573887, 38.908407824380056, 41.83081667763846, 43.1224034173148, 43.587536675589426, 42.63613026482718, 43.36993299211775, 42.17891100474766, 43.11511475699288, 42.59259632655552, 43.055394990103586, 42.38933025087629, 42.8584691456386, 42.44785840170724, 43.386969975062776, 42.71850463322231, 44.3982698576791, 45.26302875791277, 45.7190112386431, 50.94449084145682, 58.42702674865723, 61.57109355926514, 59.01214844839913, 57.4042831829616, 62.764516149248394, 59.65307807922363, 61.16679177965437, 62.27915668487549, 60.10440526689802, 60.47840595245361, 61.99243232182094, 58.67423670632498, 63.55602713993618, 4.612711889403207, 0.33223424958331244, 8.148281029292516, 9.031693237168447, 1.9466021060943604, 56.13061237335205, 60.66747338431222, 18.667945759637014, 47.9763628414699, 33.65494782584054, 59.81753499167306, 24.002941131591797, 0.9880986532994679, 0.19910335833472864, 0.12912074928837164, 0.2198116635637624, 0.19135712113763603, 0.2621944807469845, 0.13226216286420822, 0.2480294651218823, 0.23740428526486668, 0.11290146889431135, 0.08843228154416595, 0.14532207564583846, 0.12221140361257962, 0.1128036037885717, 0.12272639812103339, 0.13339344358869962, 0.12783264555037022, 0.06145471307848181, 0.05671770744291799, 0.10721828349466835], [0.04219889008839216, 0.05787283528063979, 0.0578466709703207, 0.02014382346533239, 0.05161740058766944, 0.05027686644877706, 0.02335129921058459, 0.10100229882768222, 0.015874535410798023, 0.06128864163266761, 0.03928144056616085, 0.0711254384368658, 0.035488080366381576, 0.0616994063769068, 0.019174327541674887, 0.036924583105636496, 0.04383179818146995, 0.02428398630581796, 0.0319239496519523, 0.028872357149209295, 0.06887133831956557, 0.03303219071988549, 0.025814294815063477, 0.08246042699153934, 0.029338045910532986, 0.13841046366308415, 6.17583292722702, 48.120524065835134, 33.63729245322091, 33.35064452035086, 21.585555144718715, 42.20428582600185, 70.9795172555106, 34.26120247159685, 0.3606211692094803, 0.9468023606709072, 0.1452781744301319, 0.13444849768919603, 2.6471874501023973, 63.10247652871268, 67.43326786586216, 64.73105090005058, 62.32490362439837, 55.33540494101388, 52.95883962086269, 50.69398396355765, 54.60621929168701, 59.161055292402, 61.069496154785156, 64.59777055467877, 62.527568680899485, 60.32493414197649, 62.4466221673148, 61.096997124808176, 59.39924648829869, 57.137222221919465, 50.86913415363857, 43.47515651157924, 42.20964636121477, 44.03751938683646, 43.53968095779419, 42.229473045894075, 42.19860567365374, 42.39649384362357, 42.02627992630005, 44.42548247746059, 41.91503231866019, 42.25865200587681, 42.56150313786098, 41.98888124738421, 39.67369631358555, 39.439621925354004, 39.54458488736834, 39.69895648956299, 41.24121686390468, 40.54907553536551, 46.938024044036865, 53.158798354012625, 55.20623792920794, 55.066443647657124, 58.20621647153582, 55.817210401807515, 57.801001003810335, 53.32434960774013, 58.43240465436663, 55.32967962537493, 55.25829035895211, 57.099219049726216, 55.94987235750471, 58.88904026576451, 57.21859952381679, 52.36500488008772, 56.84125675473894, 57.979316098349436, 55.33316414696829, 53.74742194584438, 54.713687079293386, 45.743020738874165, 41.42718539919172, 41.275252614702495, 41.36600998469761, 41.44116170065743, 44.0268052646092, 42.799048151288716, 42.25866937637329, 40.779005323137554, 40.14215081078665, 39.54593283789498, 39.0963704926627, 38.16323437009539, 38.723960944584434, 39.30186694008963, 39.30625125340053, 38.97934545789446, 37.80521106719971, 38.714462757110596, 37.41809565680367, 39.2348758833749, 39.379492214747835, 38.19415037972586, 38.02237006596157, 37.6140661239624, 39.730185168130056, 35.8385443006243, 39.073993819100515, 38.130810601370676, 40.11291626521519, 39.60968255996704, 38.955422810145784, 38.253185749053955, 43.06671360560826, 52.31356389181954, 54.44519131524222, 57.503124782017295, 58.52076489584786, 51.98620298930577, 56.75868436268398, 54.8590156010219, 58.42214216504778, 56.579973220825195, 58.487934657505576, 55.225171770368306, 64.7223448072161, 31.25773593357631, 0.10836635796087128, 0.45292163640260696, 13.102185947554451, 1.2178183666297366, 2.224208261285509, 72.2613000869751, 18.896023852484568, 16.344079051698955, 26.559688874653407, 24.941408259528025, 40.22518525804792, 0.8416821956634521, 0.18373763428202697, 0.06561033294669219, 0.08384410917226758, 0.012710152576411409, 0.07002638134041003, 0.05308638479826706, 0.044734755264861245, 0.09004102700522967, 0.05883050603525979, 0.05660919612273574, 0.011852170490393681, 0.019443325964467864, 0.04091394832357764, 0.053000197280198336, 0.055531797864075215, 0.02331447341878499, 0.05855658144823142, 0.031081494143498794, 0.04898623516783118, 0.07202172212834869, 0.042255398484745195, 0.011805637406983545, 0.024067662556522658, 0.009869844004112695, 0.0518105523660779, 0.008121677408260959, 0.010047608304635754, 0.019255069816218953, 0.03725758773673858, 0.016457020404881666, 0.03654334142005869, 0.0421811972877809, 0.029278616420924664, 0.04388602330748524, 0.024124411832807318, 0.026063006737136414, 0.1021296236930149, 0.028590110330177203, 0.02019998411248837, 0.02457494042547686, 0.04446520383602806, 0.11397753043898515, 0.0477390810182052, 0.06480654036360127, 0.04011497333911913, 0.16921760913516792, 8.321774074009486, 59.203112738473074, 34.56893123899187, 37.92056506020682, 27.034242153167725, 52.551873207092285, 76.47733497619629, 38.18150813238961, 0.44428589407886776, 2.6429247302668433, 1.067815552864756, 0.0869186802634171, 3.5355296220098222, 66.21021815708706, 70.760315486363, 69.62650844029018, 66.04606696537563, 57.012290137154714, 58.15626239776611, 54.58257804598127, 54.36719083786011, 62.84674807957241, 65.5909252166748, 66.09291866847447, 64.3133738381522, 63.549961362566265, 63.78446306501116, 62.01907866341727, 61.549859864371165, 58.53115940093994, 54.925527232033865, 46.294419356754844, 44.03478874479021, 45.35528693880354, 46.04815435409546, 42.89101103373936, 44.39187404087612, 44.80113336018154, 45.186344964163645, 46.02876540592739, 46.16818448475429, 43.9425687789917, 43.86355039051601, 43.4863326890128, 41.92602089473179, 42.64232110977173, 41.7825197492327, 42.16711296354021, 43.22096014022827, 43.40962110246931, 51.48772880009243, 56.38234560830252, 58.98647485460554, 57.307345390319824, 59.83347415924072, 57.98123380116054, 59.116385323660715, 57.8547487940107, 60.23350279671805, 57.83105196271624, 59.46488612038748, 58.93541949135916, 59.47510692051479, 59.72786848885672, 59.803840092250276, 55.16604607445853, 57.73515292576381, 60.29643957955496, 58.59297752380371, 56.06152296066284, 56.620060852595735, 48.19227811268398, 44.73800550188337, 42.826034954616, 41.99851492473057, 42.12687594549996, 44.75792251314436, 43.38352714266096, 43.257716110774446, 41.830024582999094, 41.32503298350743, 41.3215970993042, 40.94966697692871, 40.8449923651559, 40.6960438319615, 41.12454271316528, 40.96588754653931, 40.45723424639021, 40.3255033493042, 40.18290546962193, 40.704437255859375, 41.144977365221294, 42.21257850102016, 39.60028164727347, 39.216744559151785, 39.8330671446664, 40.87856953484671, 39.763335023607524, 41.983847277505056, 41.110344069344656, 42.379411697387695, 42.61616461617606, 43.063986437661306, 39.71653890609741, 45.865267344883506, 55.70234278270176, 55.20590788977486, 58.13921846662249, 58.34453773498535, 53.83776937212263, 59.40543038504464, 57.19099085671561, 59.35134560721261, 60.31105164119175, 60.82314082554409, 57.674870354788645, 64.88358470371791, 31.549327509743826, 0.11307835618832282, 0.46465855517557686, 5.7903121284076144, 0.16712648634399685, 3.279374292918614, 74.2963718686785, 25.24328143256051, 20.729898384639196, 34.17910255704607, 28.18494895526341, 46.81045511790684, 0.9493674401726041, 0.13829087865139755, 0.00925780796179814, 0.06768950673618487, 0.032000922664467774, 0.032732844818383455, 0.029245914425700903, 0.011169329318883163, 0.015472734114155173, 0.02369109936989844, 0.036963283350425105, 0.005319793001815144, 0.022834469264905368, 0.08553517450179372, 0.02176235000868993, 0.07917325730834689, 0.049487655583236895, 0.013801537986312593, 0.025571421686826006, 0.06728507950901985, 0.03320341563916632, 0.2846007112945829, 0.15514904047761643, 0.0961773448756763, 0.14616207485752447, 0.1336264389434031, 0.15847029297479562, 0.07737393171659537, 0.14837875376854623, 0.17096837876098497, 0.07081076103661742, 0.08604883908161096, 0.13247416434543474, 0.14581220863120897, 0.1621309079762016, 0.13348005179847988, 0.12236733095986502, 0.2160227240196296, 0.10531333714191403, 0.1397284772247076, 0.14497328150485242, 0.16162081249058247, 0.1831509457635028, 0.17334386200777122, 0.23213201388716698, 0.21404921848859104, 0.4303688422909805, 16.70682191848755, 73.92478915623256, 49.70606476919991, 49.424329212733674, 32.84251233509609, 53.14697599411011, 81.9778277533395, 40.655970096588135, 1.7819114519017083, 5.850933858326503, 0.8648934130157743, 0.14064494733299526, 4.089734443596431, 70.55413464137486, 72.30911064147949, 74.03016553606305, 66.74775164467948, 61.691908836364746, 59.92953300476074, 56.696560519082205, 59.26661927359444, 65.56850337982178, 66.95989404405866, 70.13196904318673, 65.44562448774064, 64.6923633302961, 67.32731478554862, 66.24917670658657, 64.55836732046944, 60.963668142046245, 58.567873682294575, 50.68453093937465, 47.344924449920654, 49.92347042901175, 49.00503669466291, 46.142761026109966, 48.31075184685843, 47.64118521554129, 47.818454606192454, 50.22134665080479, 49.06253998620169, 46.89377096721104, 46.76538215364729, 47.55472878047398, 46.65220642089844, 44.92739255087716, 43.83784205572945, 45.18771375928606, 47.20872586114066, 44.60357870374407, 53.26304912567139, 58.826527323041645, 61.627978461129324, 57.66137000492641, 62.55695261274065, 59.95540114811489, 62.106681551252095, 59.03049864087786, 63.401533944266184, 59.326373781476704, 59.920993668692454, 60.816699845450266, 60.93988445826939, 62.57806818825858, 62.103165762765066, 55.39342934744698, 60.085707664489746, 60.79437528337751, 60.80279650006975, 56.44587993621826, 59.18986252376011, 48.55921942847115, 46.83036518096924, 45.59233168193272, 45.55142068862915, 43.78012684413365, 46.496872493198936, 44.07255220413208, 45.52014684677124, 43.86780963625227, 44.19287415913173, 43.509115832192556, 42.562559264046804, 42.77321127482823, 42.99495608466012, 43.24797821044922, 43.66346658979143, 43.74732787268502, 42.789501326424734, 42.145882742745535, 42.86656379699707, 43.36960990088326, 45.75218193871634, 41.978340830121724, 41.993414946964805, 43.322115489414756, 46.86261177062988, 41.18645116261074, 44.92757320404053, 43.53407376153128, 44.88917398452759, 44.10044922147478, 44.97081184387207, 40.87949364525931, 47.135988644191194, 58.76483426775251, 58.04369810649327, 62.194249698093955, 61.85764421735491, 53.79766089575631, 60.0582275390625, 57.45973328181675, 60.892991065979004, 61.03550556727818, 62.25963919503348, 59.49535397120884, 67.51934909820557, 33.270111424582346, 0.10544449796101876, 0.5957180282899311, 27.761543103626796, 3.7651597687176297, 2.5596622952393124, 87.43586703709194, 26.584202119282313, 26.467903171266826, 41.974508898598806, 35.875508717128206, 60.22658239092146, 3.447660965578897, 0.6083450764417648, 0.2023758784468685, 0.22439286059566907, 0.09507358553154127, 0.15040830629212515, 0.1324621271342039, 0.13473965706569807, 0.21799502175833496, 0.17445089189069612, 0.13234896106379374, 0.06165356455104692, 0.0770802346191236, 0.11728545650839806, 0.12158553648207869, 0.24883252488715307, 0.12113397142716817, 0.08965631122035639, 0.08985619406614985, 0.19434536221836293, 0.1652516262339694], [0.059885261580348015, 0.08242422714829445, 0.050173400036458454, 0.024310837632843425, 0.03647523346756186, 0.07754826771893672, 0.04048385550933225, 0.06480078638664313, 0.015794685409803475, 0.0267641505426062, 0.08341362620038645, 0.09376007744244166, 0.06070600396820477, 0.1184856899614845, 0.03522036437477384, 0.04693164470206414, 0.03675153971250568, 0.07761141897312232, 0.05800495283412082, 0.09645299294165202, 0.04245862990085568, 0.06148437184414693, 0.06844633112528495, 0.14928827567824296, 0.09379437060228416, 0.07326867950281926, 0.301481875457934, 13.464128034455435, 42.30359295436314, 29.32111665180751, 27.46171964917864, 23.710508823394775, 56.602037225450786, 62.173516273498535, 1.8686081426484245, 3.0479955886091505, 2.638534120150975, 0.09132076440645115, 0.07848256294216428, 20.485438176563807, 83.27107511247907, 57.536139147622244, 69.84680802481515, 57.44192157472883, 58.901130131312776, 56.785254274095806, 65.41720635550362, 62.544591767447336, 65.10791424342564, 61.890773228236604, 61.57872268131801, 62.02544321332659, 60.48390197753906, 60.926495279584614, 61.18854658944266, 53.93817431586129, 45.83373989377703, 42.239113671439036, 43.50982107434954, 43.4754969733102, 42.94897290638515, 44.44693851470947, 47.576678139822825, 49.77816275187901, 44.23616491045271, 41.78106757572719, 41.6105865750994, 42.729142325265066, 42.180047035217285, 42.112910066332134, 41.74850484303066, 38.99994339261736, 40.79876947402954, 40.908919266292024, 41.33678238732474, 40.144210951668875, 43.310206277029856, 49.87659788131714, 51.54767090933663, 52.07498707090105, 54.25984811782837, 54.94488838740757, 54.26342296600342, 56.36508280890328, 56.54733058384487, 57.122224535260884, 55.76043667112078, 57.604589326041086, 54.19560854775565, 54.5883207321167, 55.158927645002095, 57.88962180273873, 56.72555882590157, 56.59062480926514, 55.0470929145813, 53.501240321568076, 47.75588607788086, 41.61391476222447, 42.485889366694856, 43.17558145523071, 44.15930393763951, 48.251466342381065, 48.008230754307334, 48.08861793790545, 45.13065167835781, 41.84632853099278, 39.80390208108084, 38.4218567439488, 39.73471539361136, 39.722055775778635, 38.30698912484305, 38.817768573760986, 41.15257869447981, 42.29007175990513, 43.21925435747419, 42.96467236110142, 41.743269375392366, 39.45881632396153, 40.98018346514021, 40.568950857434956, 40.06173930849348, 38.85783536093575, 39.76017706734793, 38.445894036974224, 38.15019607543945, 38.220119271959575, 39.12577526909964, 38.52475956508091, 41.63883100237165, 41.35201631273542, 40.0729398046221, 44.74104881286621, 56.30207306998116, 53.78323643548148, 57.85838270187378, 56.927654130118235, 57.165025438581196, 54.73167596544538, 60.521866934640066, 54.80973550251552, 60.72986820765904, 54.50587340763637, 65.16429192679269, 2.615795054606029, 0.1042056151532701, 0.23764798790216446, 4.571219852992466, 0.3927053447280611, 12.019924112728663, 56.33603586469378, 8.156167234693255, 38.135980061122346, 15.56744589124407, 35.363492488861084, 18.97589339528765, 0.24792600210223878, 0.1662689402167286, 0.10509499814361334, 0.03318635048344731, 0.07002635419900928, 0.04165044041084392, 0.059296143906457086, 0.03488230126510773, 0.07781347313097545, 0.02185960952192545, 0.023367748595774174, 0.03076791257730552, 0.011085302086680062, 0.038308828470430205, 0.012142715792703842, 0.056204019114375114, 0.033448088581540754, 0.00485675604016121, 0.05877348195229258, 0.03211402427405119, 0.040698309894651175, 0.04129773451547537, 0.048275988815086227, 0.023554447506155287, 0.0436754399644477, 0.03937224212235638, 0.023810630098783543, 0.07264332127358232, 0.06898054174546685, 0.011396309460646339, 0.10566418045865637, 0.051024730782955885, 0.07152717866535697, 0.05680909253922956, 0.08531013157750879, 0.03571989167747753, 0.042975341102906635, 0.02011958958714136, 0.11902425677648612, 0.06513577233999968, 0.05527185109843101, 0.011394535939741348, 0.024175651404740553, 0.019861237378790975, 0.12792841398290225, 0.03617974503764084, 0.07509813883474895, 0.3567518096949373, 20.926695687430247, 51.71003293991089, 36.383279596056255, 36.7902946472168, 30.901922157832555, 64.97293853759766, 65.13643659864152, 2.7247942686080933, 2.0144569107464383, 3.5541898778506686, 0.38877602985927034, 0.06392743717879057, 23.682118483952113, 86.67802701677594, 59.75236783708845, 71.29213755471366, 60.637665612357004, 62.060427393232075, 58.10155575616019, 68.77296393258231, 64.43351513998849, 67.54329259055001, 64.60116127559117, 64.5160527910505, 64.92050048283168, 64.44755744934082, 64.73587989807129, 64.90391513279506, 56.731513432094026, 49.47615582602364, 44.81589828218733, 46.43096882956368, 45.154324190957205, 44.783901827675955, 46.381063393184114, 48.78872537612915, 50.72374309812273, 45.900109086717876, 44.173391410282676, 44.22892836162022, 46.13456562587193, 44.452111448560444, 44.25143357685634, 45.29881198065621, 42.077342237745015, 43.539823395865305, 42.57499653952462, 43.420265742710654, 44.14918041229248, 47.469033173152376, 51.61473839623587, 56.050499643598286, 56.4229474067688, 57.159484250204905, 59.82554626464844, 55.98007270268032, 57.216004371643066, 57.89208493913923, 59.90574932098389, 56.97447109222412, 59.383355958121165, 56.38308211735317, 56.43538120814732, 56.66186121531895, 58.96745763506208, 58.26100649152483, 56.193462303706575, 57.07983010155814, 56.12830557141985, 50.559779507773264, 43.21683291026524, 43.954252174922395, 44.73126227515084, 46.37392064503261, 48.16889047622681, 48.95951904569353, 46.829701628003804, 46.09422091075352, 42.73644140788487, 42.78970282418387, 40.24040528706142, 41.25207689830235, 41.67825508117676, 39.53100115912301, 39.63762126650129, 40.51525865282331, 42.87919909613473, 44.621890681130544, 43.586438860212056, 43.58222477776663, 42.034492697034565, 43.076309067862375, 42.98303644997733, 42.450259004320415, 40.53856291089739, 42.587607519967214, 40.31270129340035, 41.18111842019217, 40.29795026779175, 39.96588543483189, 40.53376865386963, 42.81322595051357, 43.846138204847065, 43.44396257400513, 47.1084703036717, 56.59951155526297, 56.64182955878121, 58.3292794908796, 57.31403303146362, 58.35424436841692, 54.57183265686035, 60.729694502694265, 56.17959022521973, 61.58720643179757, 55.27769667761666, 64.83285590580532, 2.495471579687936, 0.2782940539930548, 1.8116236861263002, 4.431257511888232, 0.18566809355148248, 13.819375532014028, 65.12042100088937, 13.069135972431727, 35.891235964638845, 16.18197063037327, 44.30028983524868, 25.789548805781774, 0.22192022470491274, 0.055227206886879036, 0.09310010035655328, 0.027394777596262947, 0.02342166329201843, 0.015372831707022019, 0.07139768025704793, 0.03817934024014643, 0.06364902747528893, 0.06029473032270159, 0.018436464813670943, 0.0061102438901018885, 0.01106668817478099, 0.05779239495417901, 0.02029459225013852, 0.04508346798164504, 0.029922885421131338, 0.041601735167205334, 0.022794644348323345, 0.03175209030242903, 0.03902830629210387, 0.12884763894336565, 0.18478526520941937, 0.10564763777490173, 0.1844772645937545, 0.11761932287897382, 0.1911916264465877, 0.14177913218736649, 0.1504061214093651, 0.11566354068262236, 0.13129735392119202, 0.13478220121136733, 0.19568381325474807, 0.18660369834729604, 0.30215044958250864, 0.19349286439163343, 0.18310301404978546, 0.11724150100989, 0.17990047803946904, 0.15648157468863896, 0.23804729218993867, 0.16557952149638108, 0.1349349394440651, 0.2115411494991609, 0.33121139875480105, 0.16831776313483715, 0.1333109744425331, 0.2881978697010449, 34.30206830160958, 62.421407154628206, 47.94028432028634, 44.52624525342669, 33.42162731715611, 68.41182436261857, 74.79454381125313, 2.487835726567677, 10.129091722624642, 7.581418326922825, 0.21625338521386894, 0.09837642937366452, 24.406473398208618, 89.8754768371582, 61.08842999594552, 78.47487258911133, 62.34123189108712, 66.5148480279105, 61.104508127485005, 71.98143359592983, 66.62542166028703, 72.79043320247105, 68.11077976226807, 66.32278592245919, 67.27597454616001, 66.70678506578717, 65.861161504473, 69.90332467215401, 59.28570597512381, 52.23257221494402, 46.39468533652169, 50.501828057425364, 47.590810775756836, 47.67080886023385, 49.076950550079346, 52.61039440972464, 55.419175897325786, 53.184659549168174, 47.17276198523385, 47.79557418823242, 47.97779417037964, 48.035134179251536, 46.03150299617222, 47.76428992407662, 44.567138876233784, 47.88170058386666, 44.3602979523795, 47.000245162418906, 46.219132150922505, 50.12489175796509, 55.37185866492135, 58.101451533181326, 57.39733845846993, 59.48636300223214, 61.44958346230643, 58.23484999792916, 61.559747150966096, 60.523729051862446, 61.60114451817104, 60.20954540797642, 61.00821304321289, 56.98420899254935, 58.764862060546875, 57.739999294281006, 60.41586521693638, 57.88307312556675, 57.29632554735456, 58.72585487365723, 56.83735186713082, 50.59469073159354, 44.893134457724436, 45.46704176494053, 46.82823208400181, 49.15544087546212, 51.477014677865164, 51.20538180215018, 47.803251947675435, 47.955744062151226, 44.15334585734776, 42.803779874529155, 42.02915300641741, 43.760487760816304, 44.3639874458313, 40.81125886099679, 41.32494960512434, 44.63142013549805, 46.38512461526053, 47.21169621603829, 47.20806230817522, 48.36674737930298, 45.62711088997977, 45.47576175417219, 46.251733098711284, 45.420996052878245, 43.749975136348176, 45.23885597501482, 44.09430006572178, 45.41878652572632, 43.01331669943673, 43.1575300352914, 43.02875559670584, 47.19758789879935, 46.546555587223594, 45.35135078430176, 50.33217389242989, 59.93219416482108, 58.82428305489676, 60.759467533656526, 58.154952662331716, 61.7967779976981, 57.43770054408482, 63.89550917489188, 56.00782380785261, 65.23917266300747, 56.21221201760428, 68.92116900852749, 3.9730142610413686, 0.27704668949757305, 1.8918487812791551, 13.429751821926661, 1.1243242749146052, 13.915217246328082, 69.84533500671387, 14.656542267118182, 53.7942910194397, 27.530199357441493, 51.07630859102522, 36.65540926797049, 0.29532433301210403, 0.3083315779055868, 0.22099718637764454, 0.16199148260056973, 0.16912165071283067, 0.0851089052323784, 0.16135272330471448, 0.10903570561536721, 0.2056584544479847, 0.16660903553877557, 0.09742591716349125, 0.2293971377824034, 0.1165408186082329, 0.12522922882011958, 0.13708532548376492, 0.1636490893683263, 0.09419001758630786, 0.06956696563533374, 0.15124534709112986, 0.11759271073554244, 0.1451973066266094], [0.12074856353657586, 0.09580696653574705, 0.0072611838945054585, 0.04151427200330155, 0.039678593897925954, 0.018566685861774852, 0.05756767772670303, 0.036131043186677356, 0.013511769606598785, 0.02020573808944651, 0.04094465881852167, 0.059976965588118346, 0.030825584661215544, 0.08002592476883105, 0.04531206642942769, 0.062357632842447074, 0.025528049728434, 0.054013606293925216, 0.16268076561391354, 0.024501283752865026, 0.05660134207989488, 0.012467078432174665, 0.06769302833293166, 0.043506413498627286, 0.058563156452562125, 0.04064827472237604, 0.29616590642503327, 5.627385122435434, 45.89502647944859, 26.458041940416607, 27.972393138068064, 26.353900602885656, 35.6696857043675, 77.79752050127301, 8.167318224906921, 1.0998886546918323, 1.7748010562998908, 0.6432807275227138, 0.16528293383972986, 0.7955340519547462, 58.30444662911551, 75.07290254320417, 67.44226578303746, 63.932841845921104, 60.36783232007708, 70.12955107007707, 62.588698932102744, 67.33625016893659, 66.43838310241699, 59.27859796796526, 65.5457341330392, 62.34191281454903, 61.23067351749965, 59.58529840196882, 52.23720318930489, 46.261811460767476, 45.03560379573277, 42.31978920527867, 43.90588576453072, 45.05231073924473, 47.889131682259695, 58.89903177533831, 60.54123156411307, 58.67101274217878, 55.23385354450771, 47.00170775822231, 42.64466960089547, 42.263192653656006, 42.30671616962978, 40.27533735547747, 40.930333614349365, 40.366445609501426, 41.91154432296753, 40.7242465700422, 41.78128644398281, 41.5627794946943, 41.14382743835449, 44.72300781522478, 49.86698852266584, 51.26463951383318, 52.217525890895296, 53.267221518925254, 54.023324489593506, 55.196538243974956, 57.35861962182181, 56.78055034364973, 56.8701890536717, 59.24952670506069, 57.63791636058262, 52.87757001604353, 55.01969269343785, 55.78920568738665, 58.27136625562395, 56.201171330043245, 52.7323248726981, 48.713643142155235, 42.59501082556588, 42.993163449423655, 45.29608481270926, 44.93238483156477, 49.01462173461914, 52.000050749097554, 53.937958921704976, 54.7899956703186, 52.6256457056318, 45.99074486323765, 40.99734204156058, 39.28099455152239, 40.5715321132115, 39.12769297191075, 38.1792881829398, 39.84518132890974, 45.82846621104649, 51.556053910936626, 52.15589189529419, 49.16774960926601, 45.72232552937099, 42.600795200892854, 41.60546227863857, 40.319111006600515, 41.57386881964547, 40.295014653887065, 39.47412667955671, 38.94781105858939, 37.72006089346749, 39.27452230453491, 40.95572928019932, 41.785674231392996, 41.88975477218628, 41.117556299482075, 42.3381324495588, 40.525899818965364, 45.851228509630474, 57.15286956514631, 56.02047995158604, 58.547550201416016, 57.669141565050396, 58.497446741376606, 55.75585780824934, 58.709860120500835, 54.77630077089582, 61.3656005859375, 17.22437412398202, 0.3102232521133763, 0.08767945372632571, 0.9074874445796013, 1.5214119787727083, 0.3917630767183644, 28.499313252312795, 32.616793155670166, 12.922642758914403, 41.74096604755947, 24.941823414393834, 40.25040027073452, 9.05176658289773, 0.4214404613843986, 0.0954924180571522, 0.04170017363503575, 0.01770140104261892, 0.007822819203803582, 0.019612761247637014, 0.0736751559057406, 0.08228649811020919, 0.08194037061184645, 0.07158785326672451, 0.026145248574071696, 0.09183707527284111, 0.039911154990217516, 0.008396559577834393, 0.02641357694353376, 0.04628451567675386, 0.07907383157206432, 0.05795861567769732, 0.05616328326453056, 0.020060075280655707, 0.04663076191874487, 0.06022316523428474, 0.03561750752851367, 0.025533503453646387, 0.038106278982013464, 0.023302985820919275, 0.028702404483088424, 0.027275150176137686, 0.08227061360542264, 0.04472711496055126, 0.02582946346540536, 0.009999694402462669, 0.020865197792383175, 0.014783418870397975, 0.030262851821524755, 0.04586777982435056, 0.023843583151964203, 0.01123760944964098, 0.04884229753432529, 0.09170606373144047, 0.026929231327293173, 0.040017240547708104, 0.06535733437963895, 0.1645180620253086, 0.04834253274436508, 0.093249744469566, 0.07207647990435362, 0.251872253205095, 6.5615743313516885, 60.80962657928467, 30.83492762701852, 40.232619830540244, 35.84400905881609, 44.7169246673584, 81.92397226606096, 9.302129285676138, 1.2227805746453149, 2.5353603192738126, 2.093967752797263, 0.2798493376799992, 1.1348319053649902, 64.36265741075788, 76.27898475102016, 71.09929725102016, 66.9430238178798, 62.46724442073277, 71.85272516523088, 64.30996227264404, 70.55687223161969, 66.59405749184745, 59.67137963431222, 66.58107130868095, 65.38731520516532, 65.7901509148734, 59.84557097298758, 54.9245788029262, 49.28065088817051, 47.674255166734966, 46.35854775565011, 46.77056898389544, 46.72146953855242, 49.344675064086914, 58.73526273454939, 62.28916209084647, 61.56123406546456, 56.355115618024556, 47.74018314906529, 43.72668824877058, 45.782378809792654, 44.5954840523856, 42.737014634268625, 44.79543236323765, 43.7209038734436, 43.45237684249878, 42.867390632629395, 44.57336793627058, 45.10700001035418, 43.97439500263759, 48.060866832733154, 50.324148723057334, 54.0964994430542, 54.18738535472325, 56.02134847640991, 57.33075039727347, 58.69009249550955, 61.451056480407715, 58.56365612574986, 58.499760491507395, 60.831103461129324, 59.98202664511544, 55.06694391795567, 57.13480772290911, 57.74426201411656, 61.61469350542341, 58.601641927446636, 56.55280923843384, 51.461801597050254, 45.92588690349034, 43.694493770599365, 46.96956539154053, 45.78503996985299, 49.66866609028408, 52.32586220332554, 55.047954491206575, 55.18221453257969, 54.40397112710135, 45.741217681339805, 42.15625292914254, 41.46956246239798, 41.62858240944998, 42.0456862449646, 40.52061223983765, 42.04822581154959, 45.82319252831595, 52.5384840284075, 54.29455784388951, 50.505659988948274, 47.960031100681846, 43.882004805973594, 43.964862074170796, 42.58334132603237, 41.98886387688773, 42.43254109791347, 42.450130462646484, 42.225262437547954, 41.015560218266074, 42.56952483313424, 42.185150487082346, 43.94613320486886, 43.43547534942627, 43.56075137002127, 43.85152653285435, 44.12861374446324, 48.775256293160574, 57.03095299857003, 58.065838541303364, 59.61921950748989, 57.57295070375715, 61.16406808580671, 56.502504280635286, 59.40893227713448, 56.64622776848929, 63.55644403185163, 18.423706156866892, 0.5039460041693279, 0.1356712177928005, 2.9120384497301917, 2.005725630692073, 0.313905797366585, 29.29458495548793, 41.62983308519636, 15.781259332384382, 51.70575632367815, 26.396237713950022, 49.83829246248518, 12.525144134249006, 0.6380524794970239, 0.07307946322751896, 0.07406318294150488, 0.04651870186041508, 0.04930032902796354, 0.046812565198966434, 0.061946332055543146, 0.06846756927136864, 0.057498250023594925, 0.07238004290099655, 0.025167745937194144, 0.015470630655597364, 0.061595305534345765, 0.027227579782317792, 0.03568543227655547, 0.03999247062685234, 0.033814137868051014, 0.04164985008537769, 0.0321298341399857, 0.01584552973508835, 0.009897440023321127, 0.2119197856102671, 0.18156838496880873, 0.11562784974064146, 0.13106502353080682, 0.09684628540916101, 0.08853609740201916, 0.11321175617298909, 0.25113685695188387, 0.2290600687265396, 0.07782004813530616, 0.111785326286086, 0.1908535124467952, 0.055596173873969486, 0.1784478702715465, 0.0987436660964574, 0.11451966634818486, 0.1480983288160392, 0.14232430793344975, 0.20671407851789678, 0.154249316613589, 0.1779165637812444, 0.21974717559559004, 0.19101030831890448, 0.12442580264593874, 0.17884425685874053, 0.26687653522406307, 0.4896930775472096, 12.654483982494899, 77.50958715166364, 41.064628396715435, 45.50394712175642, 39.52582822527204, 44.60966879980904, 89.02967262268066, 10.229523590632848, 4.220260262489319, 6.788439963545118, 1.6987617079700743, 0.23584881158811705, 1.3501984860215868, 68.67285428728376, 79.18012864249093, 75.26481873648507, 69.25966439928327, 67.01731395721436, 75.99733257293701, 68.70655305044991, 72.25699915204729, 69.64803395952497, 61.8784054347447, 68.27812017713273, 67.6442985534668, 69.03911467960903, 65.29104096548897, 56.3324818611145, 51.55778748648507, 52.146779332842144, 47.856155531747, 51.55291679927281, 50.610424927302766, 53.45375285829817, 62.34090532575335, 66.11204011099679, 64.71584129333496, 60.5028566632952, 52.75095646721976, 47.267326968056814, 49.39839506149292, 48.28545692988804, 44.59746428898403, 47.444509506225586, 46.274905341012136, 47.72500133514404, 46.81751101357596, 48.26585258756365, 47.42970984322684, 46.26838098253523, 48.52441937582833, 54.411186831338064, 56.88157367706299, 56.68598188672747, 58.51435170854841, 58.977775709969656, 59.499119894845144, 63.29854774475098, 59.692585536411826, 61.11007363455636, 64.61837196350098, 61.737218039376394, 55.69872277123587, 59.18305328914097, 59.349768366132466, 62.91613279070173, 59.96740068708147, 57.3965950012207, 53.03647184371948, 46.60430553981236, 46.65001426424299, 50.51706198283604, 49.74870586395264, 51.63505492891584, 55.818238735198975, 57.816564968654085, 58.57116712842669, 55.77042123249599, 48.423545428684776, 44.458997113364084, 43.52640642438616, 43.23786858149937, 43.568950244358604, 42.59597315107073, 44.284656388419016, 50.25209937776838, 55.83915976115635, 57.2372658593314, 52.517872197287424, 49.61648859296526, 46.3695502281189, 48.66827835355486, 44.74684361049107, 45.919557094573975, 45.91045495441982, 46.16495704650879, 44.457128047943115, 43.1919583593096, 44.62943295070103, 45.76206922531128, 46.720625332423616, 47.08256047112601, 46.337348801749094, 46.10208279745919, 46.66423027856009, 51.071229457855225, 61.755373682294575, 60.70458371298653, 63.35910824366978, 59.413135937282014, 63.05737577165876, 56.96155439104353, 61.818657875061035, 57.35784142357962, 64.85066413879395, 22.153308085032872, 0.4069086568696158, 0.27477614847677095, 3.5331248939037323, 7.323284064020429, 0.8381154356258256, 34.49623918533325, 45.16187688282558, 20.74874016216823, 59.83212620871407, 33.43963704790388, 58.776284899030415, 20.126026970999582, 0.6269128886716706, 0.19603116890149458, 0.18830778476383003, 0.16002124760832104, 0.1100870074172105, 0.15083065362913267, 0.2058753278106451, 0.15012888557144574, 0.1243482053812061, 0.29491615348628586, 0.13557277593229497, 0.1826499697885343, 0.13559226345803055, 0.11336128493504864, 0.15091697685420513, 0.14229209109076432, 0.14760651306382247, 0.19037971858467373, 0.11869044468871184, 0.09338772456560816, 0.23386501946619578], [0.02667386976203748, 0.05977508784937007, 0.041847819462418556, 0.030438873983387436, 0.04295440151223114, 0.03051585717392819, 0.027898013092843548, 0.019741983152925968, 0.04172051272221974, 0.03882630641705223, 0.025283629540354013, 0.0534858315783952, 0.01961338719619172, 0.003991089545057288, 0.09224614367953368, 0.05038700286032898, 0.060888434893318584, 0.033406368855919154, 0.017652110562526753, 0.03392940739701901, 0.07038530600922448, 0.08347958658954927, 0.028809864073991776, 0.05194963508152536, 0.07437110213296753, 0.08134747349790164, 0.05966550444385835, 0.18272775704307215, 27.148672035762242, 40.56331934247698, 26.069592475891113, 30.428353786468506, 16.71689680644444, 63.55910519191197, 32.248024463653564, 0.6770644975560052, 0.45962827652692795, 1.3585244906800134, 0.13014284015766212, 0.3301456373717104, 5.446458373750959, 73.3021193913051, 68.28546442304338, 70.69227177756173, 68.71485614776611, 65.977536882673, 67.40036814553397, 65.27263518742153, 65.7360452924456, 68.7160234451294, 63.18855776105608, 62.646653856549946, 58.97447531563895, 52.373106479644775, 49.056119850703645, 44.71678917748587, 43.23441880089896, 44.159654821668354, 46.672081742967876, 48.39905302865164, 58.29366997310093, 62.10446507590157, 61.50109045846121, 59.16892760140555, 57.05321502685547, 53.198885985783164, 49.057905537741526, 45.17324760981968, 41.940591267177034, 42.34229442051479, 41.39656121390206, 41.59573827471052, 40.47634526661464, 38.94381584439959, 41.10301719393049, 40.265738419124055, 40.84995685304914, 42.949181352342876, 49.73013680321829, 48.965626512254985, 50.410330704280305, 50.62161847523281, 52.49869864327567, 54.82406268801008, 53.340076855250764, 56.930964946746826, 57.39540685926165, 56.26695687430245, 57.458527769361226, 56.931572914123535, 55.91333872931344, 59.32170459202358, 54.260334491729736, 50.82785490580967, 50.01567302431379, 45.20366334915161, 44.50009570802961, 46.74649347577776, 49.438566071646555, 53.9912029675075, 54.44196735109602, 55.67648506164551, 55.40743691580636, 56.240703105926514, 57.75356912612915, 52.10365533828735, 41.349952697753906, 39.39972536904471, 38.99540621893746, 38.96330206734793, 39.56626674107143, 40.61907516207014, 52.97064808436802, 56.442711557660786, 53.66802488054548, 51.27966151918684, 49.92207384109497, 44.84231185913086, 43.99453435625349, 42.47006137030465, 41.606848444257466, 40.54712656566075, 40.740821497780935, 39.18597446169172, 40.065258571079795, 40.33377170562744, 42.850694111415315, 43.7518824168614, 44.46508026123047, 43.63332183020455, 43.379511083875386, 40.69684982299805, 43.171106815338135, 46.83194242204939, 57.466792651585166, 55.24752759933472, 59.0388434273856, 56.03124965940203, 64.37355913434709, 54.03384753635952, 65.70124176570347, 24.151570047651017, 0.4302496372589043, 0.3658110664359161, 0.05422776212383594, 0.7018324913723128, 1.7439359639372145, 0.2661363349429199, 36.81075014386858, 23.522005932671682, 30.25866140638079, 58.799401555742534, 40.794569287981304, 36.91858271190098, 4.42897242307663, 0.42851861300212996, 0.008820977294817567, 0.04682067029976419, 0.04860025052247303, 0.025081173350502337, 0.05830046162009239, 0.07262770139745303, 0.07962411668683801, 0.08205937886876719, 0.044213165396026204, 0.08781794950898204, 0.05485548844028797, 0.03706079222527998, 0.008508019132672675, 0.014013564064433532, 0.11051367023693663, 0.027877436518403034, 0.036496997478285005, 0.04897857111479555, 0.11698877385684422, 0.08299469189452273, 0.028764670249074697, 0.018620261290509785, 0.04365363184894834, 0.019545832249735082, 0.036475107938583405, 0.020925621335793818, 0.01838786813563534, 0.0212910853858505, 0.030066622886806726, 0.01287335975627814, 0.03332785217623625, 0.026106568685333644, 0.05494695835347686, 0.05377803250615086, 0.021494162435244237, 0.014870259478422148, 0.09454305935651064, 0.032736956740596464, 0.015471258300489612, 0.005333889566827565, 0.043666758108884096, 0.05131181894934603, 0.02634801180101931, 0.04440348089805671, 0.01927025373359876, 0.10284721518733672, 0.12721200313951286, 0.3130588228149073, 36.28441367830549, 48.638053689684185, 30.285603046417236, 36.165891306740896, 25.51741565976824, 74.86733313969204, 32.22329929896763, 0.4049644911927836, 1.7311721231256212, 5.512165750776019, 1.2489018929856164, 0.23878618968384607, 6.244409910270146, 75.722183908735, 70.61338193075997, 74.9149283000401, 69.9431517464774, 67.6625862121582, 70.83245863233293, 68.3384096963065, 66.70071928841728, 71.57367856161935, 66.46841321672711, 63.85108239310128, 60.57305431365967, 55.9813094820295, 52.04978942871094, 47.34465347017561, 45.5553012575422, 47.57080691201346, 50.32916879653931, 49.86519936152867, 59.735184941973, 63.12446757725307, 63.296949659075054, 62.0986772264753, 59.202084405081614, 54.74738584245954, 50.63022729328701, 47.610154560634065, 45.31199966158186, 45.605276175907676, 42.91979047230312, 42.55747665677752, 43.3280006136213, 43.312759740012034, 43.44632148742676, 43.693232672555105, 44.30131469454084, 46.046299185071675, 53.77335957118443, 52.64261668069022, 54.35646629333496, 53.6036011832101, 56.55679750442505, 55.55881037030901, 56.030037198747905, 59.2684188570295, 61.30956336430141, 60.32874870300293, 60.50287055969238, 57.911150796072825, 57.85093770708357, 60.63819367544991, 57.571307454790386, 53.451418263571604, 52.058328764779226, 46.676935059683665, 45.962083544049946, 48.1189398765564, 51.30495643615723, 53.46135766165597, 55.56663056782314, 57.826024941035676, 56.51966980525425, 58.10018001283918, 58.663925579616, 52.902632168361116, 43.23119831085205, 40.96686029434204, 42.444634437561035, 39.195608139038086, 39.26148053577968, 42.28367594310215, 53.68577405384609, 58.37533215114048, 54.37236724581037, 54.03205490112305, 52.93679993493216, 47.50361435753958, 46.50480386189052, 45.06380653381348, 44.65100015912737, 43.008400848933626, 43.029377460479736, 41.4057606288365, 42.74696792875017, 42.95737327848162, 43.42013372693743, 44.22099699292864, 47.3827018056597, 47.032529967171804, 45.87769767216274, 43.29582698004586, 45.151270457676475, 49.194576604025706, 57.56985528128487, 58.66187586103167, 61.33201994214739, 58.18336384637015, 64.25179195404053, 56.776885168892996, 66.77069459642682, 26.141803366797312, 0.7669684333460671, 0.333410910729851, 0.34770066823278156, 3.647077739238739, 1.9834221303462982, 0.179615941164749, 42.41332932880947, 28.504741532461985, 36.08247818265642, 74.63040651593889, 44.22812931878226, 47.51031936917986, 6.144919088908604, 0.48078315279313494, 0.09376001637428999, 0.07683516812643834, 0.026904776925221086, 0.04330731436078038, 0.03522986386503492, 0.07937800525022404, 0.034647697782410045, 0.05146616531003799, 0.01246118450736893, 0.02088331807005618, 0.04369795036369136, 0.04428332591695445, 0.03474223467388323, 0.004662887559139303, 0.05239981592499784, 0.0714169235101768, 0.07022821836705719, 0.06775634243552174, 0.054254516759621244, 0.025378023939473287, 0.1039016857477171, 0.16017127170094422, 0.2580282485910824, 0.09653835943234818, 0.19478833701993736, 0.16469009779393673, 0.08635246314640556, 0.06515356352818863, 0.13674441591969558, 0.11723793191569191, 0.10863098661814417, 0.12229817467076437, 0.16011396263326916, 0.10203596550439085, 0.13244504162243434, 0.12696979327925614, 0.14998955519071647, 0.10598088667861053, 0.11935969734830515, 0.12418507199202265, 0.12510243776653493, 0.1599898857197591, 0.09605135449341365, 0.13923496513494424, 0.10838291421532631, 0.17968804229583057, 0.2123390252568892, 0.39613460642950876, 51.27014248711722, 65.18896497998918, 40.146347522735596, 48.034533160073416, 27.8435092653547, 78.86667455945695, 40.55498150416783, 1.0015753358602524, 6.572785249778202, 11.665678024291992, 1.931981576340539, 0.3150252987231527, 7.009871670178004, 79.5337780543736, 73.03940105438232, 78.354918888637, 73.78847939627511, 71.40183571406773, 72.55873162405831, 69.81285217830113, 67.83096190861293, 75.52760655539376, 69.84316716875348, 66.96844032832554, 62.90277140481131, 58.43751852852957, 53.88564593451363, 50.44181299209595, 47.754312310900005, 51.514576639447895, 52.30844306945801, 55.6033170563834, 62.16829122815813, 66.2021929877145, 64.81739616394043, 64.08488232748849, 64.5201244354248, 58.47743592943464, 53.57304300580706, 50.5934157371521, 49.272549288613455, 48.93353278296334, 45.68960298810686, 46.05047157832554, 46.21585954938616, 45.92380244391305, 45.98492922101702, 43.46295200075422, 46.02016701017107, 49.71157121658325, 56.94726889474051, 55.36563655308315, 57.26459312438965, 55.50295727593558, 58.12288325173514, 60.480295862470356, 58.51897920880999, 62.02925777435303, 62.809922627040315, 61.551916531154085, 62.59878076825823, 59.01874923706055, 58.471488271440776, 63.916061946323936, 58.32324150630406, 54.29521792275565, 52.907485485076904, 48.19025271279471, 48.017287731170654, 50.2030485698155, 54.1061053276062, 56.41365419115339, 57.65296963282994, 60.34533405303955, 58.041863782065256, 58.15086364746094, 62.20993178231375, 54.78824472427368, 44.39652933393206, 43.19128090994698, 44.14047084535871, 41.94729280471802, 42.36849955150059, 44.667665413447786, 56.7167763028826, 59.955929211207796, 56.971987111227854, 57.03857864652361, 57.883281571524485, 48.98034627096993, 48.210194042750764, 47.96691676548549, 48.31854772567749, 44.66541419710432, 46.62412180219378, 44.836669921875, 46.12552254540579, 45.50520821980068, 47.629998615809846, 48.58423294339861, 50.33254909515381, 49.7777076448713, 48.5728691646031, 45.958237716129844, 47.67745133808681, 51.448530537741526, 61.98265620640346, 59.96234934670584, 64.04078905923026, 59.248373304094585, 68.38786697387695, 57.01643473761422, 68.5044230052403, 28.62479077066694, 0.3332442896706717, 0.4090273417532444, 0.20978586083011969, 7.127612803663526, 6.785821795463562, 0.3646060696669987, 45.6249361038208, 33.12348358971732, 44.18448420933315, 68.50438131604875, 48.55560289110456, 60.05628899165562, 11.230491501944405, 0.7067050784826279, 0.1891866097492831, 0.25051203476531164, 0.12709823995828629, 0.07549870519765786, 0.11616740721677031, 0.15984970038490637, 0.19106532393821649, 0.10360484703310899, 0.10339947483901467, 0.12862370881651128, 0.1318886021950415, 0.13572478134717259, 0.04345392881493483, 0.11887379842145102, 0.17205919165696415, 0.2156657874584198, 0.13254754112235137, 0.2599891062293734, 0.17182957540665353, 0.15203142991023405], [0.0446284966809409, 0.031729050645870824, 0.019000198492514234, 0.03399767141257014, 0.05350302904844284, 0.025898171921393702, 0.056654946346368106, 0.0388655325264803, 0.0548244963533112, 0.07756366367850985, 0.040498718818915744, 0.023773091845214367, 0.0582232918324215, 0.051407770586333106, 0.03720185626298189, 0.054246493083025725, 0.042484220849084, 0.08618740271776915, 0.1232056338340044, 0.04030111924346004, 0.08704957645386457, 0.1007123811702643, 0.03840447476665888, 0.11540172116032668, 0.06992991401680879, 0.07675108406692743, 0.0927745256839054, 0.5478339748723167, 7.229284490857806, 35.60434831891741, 27.410935265677317, 56.59912245614188, 35.000456060682026, 22.254666669028147, 68.63190855298723, 0.2797583325632981, 1.8057793825864792, 2.2071606389113834, 1.0971953592130115, 0.08567908499389887, 0.1547314157443387, 13.568730558667864, 85.79639789036342, 64.14913926805768, 74.10978494371686, 67.19854382106236, 71.19862869807652, 65.27001571655273, 69.61358479091099, 63.348428862435476, 62.96953664507185, 58.52305085318429, 53.14708716528756, 47.06311246326992, 44.64104339054653, 46.87010540281023, 46.67419746943882, 46.27669450214931, 49.16381345476423, 54.12010942186628, 58.858836446489605, 64.59502601623535, 63.4972106388637, 62.473629815237864, 56.12236833572388, 55.08296298980713, 52.39287063053676, 47.441181319100515, 42.90831552233015, 41.42697695323399, 42.1085570199149, 41.619358675820486, 41.734556334359304, 41.470955576215474, 39.164066791534424, 42.503537791115896, 41.803176743643625, 43.55671099254063, 47.22592612675258, 51.575494970594136, 52.41823502949306, 54.00148630142212, 51.41691623415266, 52.319167613983154, 50.87581484658377, 53.32888330732073, 53.17629739216396, 55.67760372161865, 56.35843685695103, 57.2517945425851, 57.46466302871704, 57.970860140664236, 53.59549610955374, 51.92664303098406, 49.50158970696585, 49.5213816506522, 50.96329961504255, 52.68183926173619, 53.58560882295881, 53.84392895017351, 54.305327551705496, 55.81938171386719, 55.63368763242449, 47.517364842551096, 55.56286464418684, 54.312289646693635, 42.68674441746303, 39.4028833253043, 41.04066405977522, 39.321026597704204, 40.41950552804129, 43.96328135899135, 52.88491426195417, 55.386564527239116, 54.957589694431846, 53.90287051882063, 50.8079274722508, 47.909653186798096, 46.53689759118216, 45.65374680927822, 41.98018210274832, 42.199401242392405, 41.44806126185826, 41.755067416599815, 39.641269070761545, 42.667869635990684, 46.382532937186106, 46.38781704221453, 44.22535351344517, 47.35564204624721, 46.80739791052682, 44.622456959315706, 42.757105350494385, 45.54969753537859, 46.474579198019846, 54.2421441078186, 54.34625938960484, 60.17553397587368, 59.43892070225307, 61.200608662196565, 50.75032690593174, 1.02867092192173, 0.2024990596941539, 0.07149990155760731, 0.7758810722402164, 4.039422971861703, 0.9787766677992684, 2.590278229543141, 28.01365848949977, 23.156021731240408, 32.08633293424334, 22.66765890802656, 39.78549630301339, 31.400375502450125, 0.39296177668230875, 0.19948267298085348, 0.08674576918461493, 0.10523957360003676, 0.08585746506495134, 0.035896314175001214, 0.019001833761909177, 0.0171064038627914, 0.022999982615666728, 0.04999296400429947, 0.07305261359683105, 0.08875626165952001, 0.051649393513798714, 0.10152890985565526, 0.013987007051972406, 0.05145529857171433, 0.04166209085711411, 0.025879305255200182, 0.021792449822117175, 0.082732397397714, 0.023502928038526858, 0.019589757214167287, 0.051425741586302004, 0.024469926953315735, 0.027860398504084775, 0.01969826514167445, 0.07713358782763992, 0.013311272686613458, 0.023976818591888462, 0.07874661484467131, 0.051368653042508025, 0.06171873105423791, 0.0481819201127759, 0.021490232021148716, 0.04318393633833953, 0.04865655875099557, 0.02151085778937808, 0.050930204069507976, 0.042107121619795046, 0.04642801904784782, 0.08435075769999198, 0.03536880408812847, 0.049645774598632536, 0.07021765357681684, 0.035355403021510155, 0.07179034847233977, 0.037001956453812976, 0.043543729531977854, 0.07327229609446866, 0.3572411962917873, 6.2905168533325195, 49.72720466341291, 29.821227141789027, 52.20975085667202, 36.32640164239066, 36.78586169651577, 70.63831901550293, 0.3307376727461815, 0.5827988301004682, 1.5683844068220683, 2.612694420984813, 0.6320647607956613, 0.1491526908108166, 17.576394183295115, 88.04478631700788, 63.94965648651123, 76.7516429083688, 67.71396814073834, 72.9906108038766, 66.60122803279332, 72.80605275290353, 65.71476296016148, 66.31774153028215, 63.409288133893696, 58.438095229012625, 49.534822940826416, 47.57548999786377, 47.6181206703186, 49.74387686593192, 48.319485732487266, 51.95503684452602, 56.019764287131174, 62.45081193106515, 64.44774505070278, 67.4504507609776, 64.84063788822719, 61.20525005885533, 56.06717879431588, 53.27984986986433, 49.05086006437029, 46.321614606039866, 42.73218216214861, 44.954573903764995, 42.76604420798165, 44.14863150460379, 43.62292732511248, 42.90345525741577, 44.857931409563335, 44.98737982341221, 45.96932009288243, 51.121916566576274, 53.65341976710728, 53.44516141074044, 57.04119464329311, 56.11169242858887, 56.23443235669817, 53.01222610473633, 56.051218782152446, 57.134331771305625, 56.7793413570949, 60.857180050441194, 61.03726346152169, 60.30685492924282, 60.63880511692592, 56.83153622491019, 54.69155706678118, 50.67701646259853, 52.13337973185948, 52.17528779166085, 52.72169065475464, 53.40918711253575, 57.43765885489327, 56.68326166697911, 57.96629864828927, 56.2057397706168, 51.79668392453875, 57.642324992588584, 56.67923518589565, 45.49216297694615, 40.602514130728586, 43.10222584860665, 41.88488755907331, 40.65510504586356, 46.16317483357021, 55.093319279806956, 57.688256059374126, 56.12145812170846, 55.625530447278706, 53.15265614645821, 50.11022411073957, 49.518675327301025, 46.92330428532192, 45.32059458323887, 44.97803797040667, 43.920869554792134, 44.13937302998134, 43.1134923526219, 44.316152572631836, 48.90601444244385, 48.35256610597883, 47.32297509057181, 48.65277344839913, 49.2081047466823, 48.43449578966413, 45.40093312944685, 46.5790627343314, 51.20309584481375, 55.67511279242379, 57.48651163918631, 63.55257388523647, 62.63801029750279, 61.08331612178257, 53.44839927128383, 1.0510785366807665, 0.5251488664320537, 2.7839816297803606, 2.670153417757579, 1.4419652989932468, 0.632344480071749, 2.5407230257987976, 35.251852308000835, 29.17412403651646, 39.480706623622346, 21.53809200014387, 45.15683943884713, 39.41799565723964, 0.41759734760437695, 0.1498197585876499, 0.03685478220826813, 0.06587065290659666, 0.048864733294716904, 0.09847846068441868, 0.028635392364646708, 0.026747862309483544, 0.07152919391436235, 0.08008178855691638, 0.06403040486787047, 0.03213276880394135, 0.00862576870713383, 0.058078872439052374, 0.011815415944771042, 0.0698249785761748, 0.006924309493375144, 0.04608765570446849, 0.043242225889116526, 0.0694476995351059, 0.08536202593573503, 0.014880091450842363, 0.1626916764570134, 0.09552412599857364, 0.11168162577918597, 0.13501839925135883, 0.18678105383047036, 0.0708735730232937, 0.13841804968459265, 0.11255651526153088, 0.2332287436085088, 0.13113735536379473, 0.15095321062420095, 0.12062025256454945, 0.2081640807113477, 0.20042445244533674, 0.17088353474225315, 0.10159151828182594, 0.13322575044419083, 0.11781630159488746, 0.2611701100000313, 0.11358964589557477, 0.20243803225457668, 0.220125730282494, 0.24183769736971172, 0.2021017231579338, 0.1159713648791824, 0.2552650368639401, 0.16514007507690362, 0.6261479354330471, 13.623327766145978, 71.55294513702393, 45.260468346732004, 75.61936446598598, 47.18790210996355, 33.11918960298811, 82.65901524680001, 0.3823253060025828, 6.886329659393855, 11.744881408555166, 3.840373149939946, 1.0541028486830848, 0.15355630165764264, 19.317166328430176, 92.41455010005406, 67.14233984266008, 78.72739791870117, 70.04303904942104, 75.23909650530133, 67.80398900168282, 76.77226516178676, 69.81964751652309, 69.55691528320312, 65.36814512525285, 59.131803376334055, 52.83579397201538, 49.435811110905235, 50.89058324268886, 54.28081430707659, 52.54593597139631, 55.86036218915667, 60.097575187683105, 63.85377829415457, 68.14271368299211, 70.11088126046317, 68.5338555744716, 62.49693407331194, 58.52553136008126, 57.59607778276716, 53.2363680430821, 49.58236598968506, 47.45678002493722, 48.44124596459525, 45.933217253003804, 47.632392270224436, 46.02302966799055, 44.604603563036235, 46.588216985974995, 47.49842405319214, 48.5129131589617, 51.97597524097988, 55.845816135406494, 56.995593615940635, 58.55972344534737, 59.384419032505576, 58.15410498210362, 54.707829747881206, 59.08536161695208, 60.085999488830566, 57.81165954044887, 62.93508052825928, 61.39840303148542, 62.69099725995745, 61.577103751046316, 58.598313740321565, 56.80014773777553, 53.28434188025338, 53.17678376606533, 55.51008265359061, 54.63298722675869, 56.29925904955183, 58.40384060995919, 58.27627168382917, 58.8723645891462, 59.86028725760323, 53.37672512871878, 60.0694488797869, 59.201389585222515, 48.32148333958217, 43.21833372116089, 44.567944867270334, 44.6023245538984, 44.639323711395264, 49.161954811641145, 58.07084124428885, 60.40547071184431, 59.16049248831612, 57.21730368477957, 54.65585027422224, 52.46000065122332, 53.613102844783235, 53.03582566125052, 46.65068129130772, 47.791169030325754, 47.5563268661499, 49.52490438733782, 44.18330301557268, 47.3939995765686, 52.153296743120464, 52.91546549115862, 49.57806505475725, 51.8228543145316, 53.00444064821516, 50.743701798575266, 48.647367749895366, 50.37798336574009, 51.312637669699534, 57.56786462238857, 59.416908809116904, 66.85728304726737, 64.13549995422363, 63.44987951006208, 53.79872744424002, 2.3447139092854092, 0.44599732224430355, 1.1727130498204912, 3.135444530418941, 12.699796659605843, 3.001693878855024, 3.19809296301433, 36.953073569706504, 33.09881401062012, 44.13069125584194, 31.36974436896188, 53.84508582523891, 51.21359804698399, 1.41246683044093, 0.5378168438162122, 0.21903759081448826, 0.21199335237698896, 0.10937801296157496, 0.18238508328795433, 0.11989188593413148, 0.07840590205575738, 0.09994484949856997, 0.10126188596976654, 0.22405820712447166, 0.19472570823771612, 0.14162815814571722, 0.1421352137944528, 0.11034955975732633, 0.16536777785846166, 0.15013625446174825, 0.12588077171572618, 0.0767046654863017, 0.24135311480079377, 0.10309217311441898, 0.09181381509240184], [0.033778263721615076, 0.060900709591805935, 0.03299745651228087, 0.02825317358864205, 0.03006684680336288, 0.082953185907432, 0.0703565293390836, 0.007771397275584084, 0.04445096477866173, 0.01643251341634563, 0.02086274658462831, 0.0277557107287326, 0.04597234546339937, 0.040658089731420786, 0.02525950931677861, 0.01920739424947117, 0.07987128663808107, 0.10455370361783675, 0.016958142264879177, 0.05063291752178754, 0.022901289697204317, 0.05999666345970971, 0.06793185230344534, 0.03282661496528557, 0.036613447658185444, 0.012771486204915812, 0.1543801517358848, 0.15764091962150165, 0.8036582874400275, 20.18797537258693, 29.210549967629568, 28.332724979945592, 65.39618110656738, 11.347043190683637, 48.03711094175066, 14.243470992360797, 2.787412954228265, 0.6913187812481607, 1.8872128129005432, 0.35999710698212894, 0.3601623166884695, 0.04044583040688719, 22.93037724494934, 87.6089119229998, 62.85779571533203, 74.31331157684326, 67.80758816855294, 72.06841809409005, 63.550406047276084, 67.66480268750871, 57.76664563587734, 51.21307693208967, 45.463536398751394, 50.44793088095528, 50.042079653058735, 48.38305480139596, 48.2203106198992, 48.59760127748762, 52.55012573514666, 57.37688643591744, 60.524535042899, 62.782011713300435, 62.46399961199079, 61.736078534807476, 59.72192777906145, 55.42598860604422, 51.39824295043945, 51.52777821677071, 48.524749415261404, 42.69487728391375, 44.02155590057373, 40.98865679332188, 41.7912049974714, 41.187941551208496, 41.955231121608186, 41.1309871673584, 42.87704168047224, 43.83229391915457, 42.964891229357036, 48.59279659816197, 49.77898611341204, 51.0816239629473, 50.63675512586321, 50.40304899215698, 50.63837405613491, 50.58748197555542, 50.83090169089181, 53.992425850459504, 58.06155150277274, 58.53423745291573, 59.960285731724326, 57.85579102379935, 53.47263806206839, 54.46791192463466, 53.72343329020909, 52.46175159726824, 55.22419554846627, 56.661718777247835, 57.71793876375471, 57.03071675981794, 56.83191837583269, 60.34034524645124, 53.79950564248221, 46.495826789310996, 57.290197236197336, 54.88852112633841, 44.04029171807425, 38.833082403455464, 41.363182067871094, 39.64499677930559, 40.196596894945415, 43.62596368789673, 54.70596415655953, 55.945706912449424, 56.70958144324166, 52.93716818945748, 53.4008458001273, 50.510617528642925, 47.34901346479143, 47.73180709566389, 44.28422212600708, 43.025104318346294, 40.895860127040315, 41.53517082759312, 42.44414806365967, 45.937195096697124, 45.338767596653526, 48.74163743427822, 47.78716686793736, 49.939211572919575, 47.01164368220738, 46.62643902642386, 46.86999075753348, 48.90667104721069, 49.091190883091514, 53.35426507677351, 54.10768256868635, 59.464365005493164, 57.72611679349627, 64.81735447474888, 34.669520309993196, 0.06940826307982206, 0.4558057359286717, 1.0279261618852615, 1.5108404031821658, 1.7031870590788978, 0.2378956260425704, 3.160437200750623, 20.046569108963013, 28.642779656818934, 29.77665444782802, 29.89430829456874, 47.60630178451538, 9.902264305523463, 0.3407444086458002, 0.03327951334150774, 0.06453259542052235, 0.05955264371420656, 0.04886242966832859, 0.028956207114138773, 0.02893616658236299, 0.04312944997634206, 0.03596231188359005, 0.06326583839420762, 0.0253536933700421, 0.07496393817876067, 0.02174262499569782, 0.01256231845556093, 0.04777935207156198, 0.045829839538782835, 0.08865601489586489, 0.04764910388205733, 0.04128879142392959, 0.01134071369389338, 0.04231645306572318, 0.03450000106490084, 0.025008561621819223, 0.05837145673909357, 0.021791620313056877, 0.0369678057863244, 0.020259472973910824, 0.056489665393850634, 0.031886983064136336, 0.03625571042565363, 0.024414170034495846, 0.054139752739242146, 0.03817996788503868, 0.06173534159149442, 0.026724837919963256, 0.017491776130295227, 0.034616268040346246, 0.044835042740617476, 0.07586297672241926, 0.02775626882378544, 0.01294180443177798, 0.053597023111901114, 0.07066421782863991, 0.05681173882580229, 0.02381344771544848, 0.027399529037731032, 0.07671592238226108, 0.05288270894171936, 0.085296676228089, 0.07558244998965945, 0.4539792282240731, 32.53315421513149, 37.76834739957537, 39.088011809757774, 73.11129406520298, 16.721611159188406, 64.73912470681327, 11.078188725880214, 1.6878759435244968, 2.3402536000524248, 3.846871452672141, 1.318594279033797, 0.6055028289556503, 0.04708007763006857, 27.140546117510112, 88.33886187417167, 62.73157473972866, 74.7799734388079, 71.59732328142438, 73.53056226457868, 65.4075414112636, 71.1191690989903, 60.22048882075718, 53.82281684875488, 48.01042638506208, 54.25640181132725, 50.05483654567173, 48.94248901094709, 48.48830263955252, 51.4055107661656, 54.802943638392854, 59.598583357674734, 61.72257818494524, 66.1154864174979, 63.357107162475586, 63.86253302437918, 60.76651995522635, 58.80899006979806, 54.75530678885323, 56.02267210824149, 49.93530321121216, 44.52079439163208, 45.880848680223735, 44.54966763087681, 43.68591969353812, 45.162179129464285, 44.838587624686106, 44.73851619447981, 44.05972235543387, 46.45588159561157, 46.59753104618618, 51.34569719859532, 53.54460750307356, 54.23970876421247, 53.517335823604036, 53.97267212186541, 53.83538614000593, 52.74817023958479, 54.432093960898264, 56.10517154421125, 60.01081303187779, 59.885099274771555, 61.22437150137765, 58.11554247992379, 55.91458593096052, 55.809782777513774, 53.20206478663853, 54.847412109375, 56.61330025536673, 57.21573339189802, 57.589289392743794, 59.01225961957659, 57.349194390433176, 60.12784848894392, 55.89013522011893, 48.91580792835781, 57.36570678438459, 58.68574292319161, 46.091333934238975, 40.67870112827846, 42.44508259637015, 41.667766775403706, 41.249888215746196, 44.87429094314575, 57.17560407093593, 57.862298011779785, 58.41677120753697, 56.003738267081125, 56.83907502038138, 51.588175433022634, 48.410222257886616, 49.55364213671003, 46.87520885467529, 44.81252145767212, 43.889123235430034, 44.13034037181309, 46.6055075781686, 48.60606418337141, 49.29160124914986, 50.26532874788557, 50.101743834359304, 52.140084743499756, 49.88031169346401, 47.268872942243306, 50.873483725956504, 50.58386891228812, 50.260659558432444, 57.071596486227854, 55.076431683131624, 60.652527809143066, 59.675701413835796, 67.21848515101841, 36.90323761531285, 0.2101211114121335, 0.860557031418596, 3.9584473626954213, 4.492355627673013, 0.6591360824448722, 0.20858462314520562, 4.323946927274976, 26.05746613230024, 36.1752679007394, 35.41801152910505, 27.352907385144913, 55.99265241622925, 11.331394110407148, 0.24797040543385915, 0.020248395889731388, 0.0529988605662116, 0.026509375910141637, 0.0571131542591112, 0.04369002507467355, 0.012837227766535111, 0.04253078870741384, 0.08038318702684981, 0.04625688233811941, 0.06757359938429934, 0.10137872291462761, 0.022099858415978293, 0.034213384480348656, 0.017354265919753482, 0.05878028765852962, 0.047310620080679655, 0.0614698783361486, 0.014053333001876516, 0.02112559917648988, 0.027832259656861424, 0.07104724406131677, 0.12293888814747334, 0.16189382784068584, 0.15817267394491605, 0.0727232526987791, 0.05785940707262073, 0.15898608815457138, 0.2342777316059385, 0.1224301497318915, 0.14984523079224996, 0.11693428749484674, 0.13818590928401264, 0.10600300692021847, 0.18502519519201346, 0.22570829572422163, 0.19791596276419504, 0.07471351804477827, 0.12285830532865864, 0.1968011704406568, 0.1578694637864828, 0.13917988166213036, 0.08660964827452387, 0.2938513420522213, 0.22430706662791117, 0.23496959305235318, 0.1978119026337351, 0.19266374888164656, 0.1592864484659263, 0.4040707248662199, 1.4141871609858103, 51.84213556562151, 53.59870965140206, 41.02239029748099, 84.72171306610107, 19.728963477270945, 62.37853676932198, 16.866668701171875, 4.499935678073338, 7.330883656229291, 6.147592842578888, 1.1655504341636385, 0.60970317785229, 0.09342282518212285, 27.593685047967092, 89.6023223059518, 64.2794805254255, 74.78517069135393, 75.1687320981707, 77.808901650565, 68.53104155404228, 74.08730057307652, 63.86363778795515, 56.813234669821604, 50.12755639212472, 57.1725503376552, 55.75478778566633, 54.30373641422817, 51.89331252234322, 54.85049710954939, 57.95323256083897, 61.27397469111851, 66.05573190961564, 68.21668420519147, 65.54915264674595, 64.53502137320382, 66.15447970799038, 63.15860407693045, 57.3924469266619, 58.04836729594639, 54.73383685520717, 47.99898965018136, 49.79687425068447, 47.50886024747576, 47.08242498125349, 47.51401581083025, 47.856964996882844, 46.569977964673726, 47.01291520254952, 48.67845399039132, 49.11408519744873, 52.714158807482036, 55.02317721503121, 57.391210147312705, 55.387429577963694, 56.711808340890066, 55.77274540492466, 55.56076281411307, 55.805203914642334, 58.19647857121059, 59.88211849757603, 62.199585914611816, 63.59263025011335, 60.48143536703927, 57.30414227076939, 58.22176653998238, 55.72793994631086, 55.450449739183696, 58.62564100537981, 59.55383695874895, 60.527620043073384, 60.67772197723389, 59.17313126155308, 64.11867836543492, 54.99664551871163, 48.96358721596854, 60.65702329363142, 58.765897342136924, 47.31761455535889, 42.944703238351, 44.9418899672372, 45.2460230418614, 42.814000674656455, 48.25142117909023, 58.81507669176374, 60.484006200517925, 60.1416198185512, 57.853824683598106, 59.34584958212716, 54.00881665093558, 51.385986328125, 53.32181698935372, 50.510770389011924, 48.09189748764038, 45.9934789793832, 46.3921457699367, 50.36679676600865, 51.285327775137766, 51.47882120949881, 53.26611328125, 54.03774200166975, 54.56238658087594, 53.28867755617414, 51.00517293385097, 53.621249607631135, 53.99568802969796, 54.73539672579084, 58.87057890210833, 57.1139874458313, 62.96827902112688, 62.686904770987375, 67.93349647521973, 41.44678626741682, 0.3735905789903232, 0.5425124147108623, 7.844828878130231, 6.804292278630393, 6.213030976908548, 1.168833240866661, 4.430068067141941, 31.76407895769392, 40.13705083302089, 43.90662227358137, 45.507219723292756, 64.12770407540458, 18.977924006325857, 0.7690475732088089, 0.09699543419161014, 0.09020787198096514, 0.1122477546866451, 0.18428175151348114, 0.09756918983267886, 0.21605378735278333, 0.13697958258645876, 0.12119911078895841, 0.14484955742955208, 0.07895891488130603, 0.21599029004573822, 0.10149456919836146, 0.1671983567731721, 0.11388400117201464, 0.22700538326586994, 0.14681151429457323, 0.15430848486721516, 0.1979475553546633, 0.13149923165994032, 0.10272943507879972, 0.14215867753539765], [0.016775014145033698, 0.04214653432635324, 0.05509811220690608, 0.06272245398057358, 0.019515232016731585, 0.048331625293940306, 0.12582084350287914, 0.05093451276687639, 0.043587305050875456, 0.049472259623663764, 0.016266749007627368, 0.12697120463209494, 0.04223520528259022, 0.06324113293417863, 0.09891274345240422, 0.019445646554231644, 0.015246035564424736, 0.13691137624638422, 0.01736503596683698, 0.07455493762556996, 0.033084828073957136, 0.019736894140286104, 0.022402693683813726, 0.019119566372994865, 0.058296465048832555, 0.032545732001640966, 0.03336705792961376, 0.057514785921999385, 0.2259281546409641, 4.608806133270264, 34.36609942572457, 25.219753095081874, 45.03215748923165, 37.19079576219831, 18.708896705082484, 38.4887227330889, 0.7180504011256355, 1.0587596616574695, 2.6945739473615373, 0.6456382838743073, 0.622839344399316, 0.4828627812010901, 0.1483220010995865, 42.09716544832502, 81.09745625087193, 67.73642471858433, 69.85048362186977, 65.95134217398507, 66.40349619729179, 55.536517075129915, 50.08291074207851, 51.268544401441304, 57.99508850915091, 56.80664430345808, 56.30694375719343, 57.161884852818076, 59.582317624773296, 56.13467706952776, 57.31760093144008, 60.977397782461985, 64.25732272011894, 63.83075891222273, 65.34987136295864, 62.8276891708374, 58.34438487461635, 58.454868180411204, 54.653633798871724, 52.738401072365896, 49.69812992640904, 43.983597891671316, 41.06085899897984, 42.84917593002319, 42.6642496245248, 43.37177773884365, 43.39633614676339, 43.42725215639387, 43.18921382086617, 44.781466484069824, 44.0075135912214, 44.2814393724714, 50.845899377550396, 52.07780803952898, 52.33847318376814, 50.79802628925869, 54.497504302433555, 56.19208656038557, 54.871265275137766, 55.5925612449646, 57.721329484667095, 61.11892563956124, 61.02371447426932, 57.1524908883231, 56.06628942489624, 57.07622398648943, 54.90139613832746, 58.710596629551475, 59.62083148956299, 56.76693534851074, 58.47562939780099, 59.06077194213867, 58.36447211674282, 57.14699138913836, 48.607888085501536, 54.469739300864084, 56.30882324491228, 52.596925326756065, 44.51954024178641, 40.32271017347063, 41.49476705278669, 39.90027706963675, 41.39551898411342, 42.7610137122018, 52.92158685411726, 57.09153086798531, 55.53450904573713, 57.38051686968122, 53.654976163591655, 51.63858461380005, 49.44982215336391, 46.638706071036204, 43.61891821452549, 43.91227810723441, 41.915056637355256, 41.821551254817415, 45.779300757816856, 47.89049700328282, 48.561144079480854, 50.84811585290091, 48.12039205006191, 48.37875386646816, 52.2914581980024, 50.918549742017476, 48.91468926838466, 50.52875232696533, 50.23592744554792, 53.425709928785054, 55.41027525493077, 61.423631940569194, 57.50908981050764, 66.96293040684291, 7.441774300166538, 0.4003759116998741, 3.6119300595351627, 7.985195517539978, 4.088700899056025, 0.39334542038185255, 0.010722092469222844, 8.245857187679835, 33.11334269387381, 34.407976218632285, 24.834409475326538, 43.412994452885215, 33.226181438991, 0.2140391083168132, 0.19801327825656959, 0.04056715925357171, 0.043883370235562325, 0.0696543405896851, 0.057556034065783024, 0.035936385060527494, 0.026218465895258954, 0.009875930463229972, 0.020235400247786726, 0.07407051111970629, 0.06700187934828655, 0.04239150921681097, 0.009299485278981072, 0.04078678068305765, 0.01095610308194799, 0.027720621986580745, 0.07253759194697652, 0.06720340424882514, 0.09680396518004791, 0.12297394126653671, 0.03935749416372605, 0.04116140665220363, 0.07088670267590455, 0.031169540847518613, 0.02856553379180176, 0.020135823537462523, 0.059750640232648165, 0.05844866045351539, 0.025878609756806066, 0.05326887679153255, 0.010751702041099114, 0.08485101442784071, 0.04786968543859465, 0.09719062836042472, 0.03179600848151105, 0.03961261993806277, 0.008808340428264012, 0.04043306716318641, 0.0313016312595989, 0.024705846793949604, 0.027047462661617568, 0.049186392820307186, 0.007364401793373483, 0.06180530533726726, 0.021876338802810227, 0.04208960184561355, 0.057104285806417465, 0.056273874294544966, 0.026472404233313034, 0.005289115161368889, 0.36030926023210796, 14.039743730000087, 49.838691983904155, 25.317493404660905, 57.32612984521048, 35.32023647853306, 28.84212347439357, 43.549728052956716, 0.6652001770479339, 1.2634171141045434, 3.88859885931015, 2.6797575652599335, 1.3853912204504013, 0.6106602922081947, 0.14047008885868958, 48.43042414528983, 81.10441139766148, 69.40797369820731, 72.64929444449288, 69.0966249193464, 68.70535101209367, 58.72775173187256, 53.30401917866298, 53.00635140282767, 57.52156530107771, 58.38771384102957, 58.109101499829976, 57.75687646865845, 61.042363439287456, 56.67994042805263, 57.12477452414376, 63.793377603803364, 67.10445131574357, 65.53233800615583, 67.32681451525006, 65.39918272835868, 62.67557225908552, 61.16256032671247, 57.652941840035574, 56.015074253082275, 50.843404974256245, 47.04358802522932, 43.86652421951294, 45.54163762501308, 45.89185810089111, 46.569460323878694, 46.54421751839774, 45.853656905038015, 44.95500469207764, 46.52513081686837, 45.822178091321675, 47.59593159811837, 52.65928888320923, 54.32123892647879, 55.81597709655762, 53.97402354649135, 56.36142805644444, 58.0012446131025, 56.482448305402485, 58.325075830732075, 60.64629527500698, 63.02970804486956, 63.283539635794504, 60.54683876037598, 57.908586910792756, 58.80190290723528, 55.455455916268484, 60.50379467010498, 59.395112310137065, 58.13217299325125, 58.64488751547677, 59.6768478666033, 58.88145283290318, 56.98469189235142, 50.59440585545131, 57.46189417157854, 60.092523847307476, 53.79864059175764, 45.063754422324045, 41.893447739737375, 43.24554634094238, 40.85808277130127, 43.742874077388215, 45.072491782052175, 55.232786996024, 56.225628989083425, 54.49658366612026, 57.89860929761614, 56.4801276070731, 54.24773393358503, 52.71040678024292, 47.74211822237287, 46.58682039805821, 45.68506234032767, 45.26084702355521, 45.32134846278599, 46.54800428662981, 51.394803592136924, 50.996505056108745, 53.27363123212542, 49.97637748718262, 51.93625586373465, 53.275396074567524, 54.109291076660156, 50.628396442958284, 52.46800150190081, 52.50356585638863, 57.57925966807774, 56.53309372493199, 65.22994545527867, 58.81321457454136, 69.22537503923688, 8.55690632547651, 0.6330283348049436, 2.734301575592586, 2.4979455726487294, 1.6470461572919572, 0.34194728838545935, 0.11319399212620088, 10.77347113404955, 38.082426820482524, 41.72382484163557, 29.669850213187082, 45.45528193882534, 39.84033843449184, 0.4299690494579928, 0.14179445350808756, 0.04275076976045966, 0.036655316661511145, 0.04409398750535079, 0.04796682790453945, 0.019572681880423, 0.05170612582670791, 0.02833892684429884, 0.038275719354195256, 0.08999995528055088, 0.014793259324505925, 0.015197048728753413, 0.04284153738990426, 0.0411548418258982, 0.00541665345164282, 0.020649133582732508, 0.024617398057931235, 0.03608108604592936, 0.0915808943765504, 0.0555167445646865, 0.06278167651700121, 0.013591228601788836, 0.16283556659306797, 0.11672491872949259, 0.24998836857931955, 0.17797343858650752, 0.11902144764150892, 0.21047454673264707, 0.1906781518565757, 0.13586694800427981, 0.11786096276981489, 0.17613961627440794, 0.19117986064936432, 0.2270268385431596, 0.0830942058403577, 0.11240343776132379, 0.30203656426497866, 0.1427254035536732, 0.12865184087838444, 0.17423457492675098, 0.18009118709181035, 0.11566187148647648, 0.13091068395546504, 0.13529558080647672, 0.10891124872224671, 0.13718592508562974, 0.13388456723519734, 0.15091430342623166, 0.11038005990641457, 0.24654605186411313, 0.32424287125468254, 29.10250547954014, 68.64841747283936, 42.34322895322527, 68.70440605708531, 51.18566281454903, 29.549410138811382, 47.419186796460835, 0.9079177443470273, 5.656875014305115, 10.223350984709603, 5.723872584956033, 0.7176370375922748, 0.7707984649709293, 0.1786485809300627, 47.25131484440395, 82.89652551923479, 72.07900714874268, 76.36765766143799, 70.98130989074707, 73.74032838003976, 61.28401483808245, 55.307938711983816, 55.58243424551827, 64.2644237790789, 63.35716274806431, 63.82276848384312, 63.10946641649519, 65.22311537606376, 61.946497780936106, 62.99258381979806, 65.64974171774728, 69.85972472599575, 67.84565734863281, 70.69888646262032, 67.87381144932338, 64.05499117715019, 66.5829473223005, 62.50363908495222, 58.799387659345356, 56.09263351985386, 49.19115809031895, 46.257666860307964, 48.51786027635847, 46.98822130475725, 50.81898900440761, 49.675284249441965, 48.693628856113975, 49.01905121122088, 50.28211906978062, 49.1163364137922, 49.222939150674, 54.61539786202567, 56.35707153592791, 57.696520941598074, 57.14416694641113, 62.262328147888184, 62.29326152801514, 57.839976923806326, 60.820625577654155, 62.31343214852469, 65.42940739222935, 63.61261326926095, 62.343983377729145, 60.32152952466692, 61.18975557599749, 56.67206811904907, 63.260541098458425, 61.351586069379536, 60.115529332842144, 62.292531967163086, 61.47674397059849, 58.97981153215681, 56.209397997174946, 53.516828605106895, 55.57728910446167, 61.5449891771589, 54.533836432865684, 47.826507568359375, 45.005518095833914, 45.991057532174246, 42.491343702588765, 45.558990750994, 46.41890328271048, 58.026459625789094, 61.31316253117153, 56.658453123910085, 61.31904765537807, 58.282386098589214, 57.072023800441194, 54.8521021434239, 50.00226994923183, 48.5358943258013, 49.50006457737514, 48.06492110661098, 48.28633935110909, 51.017926352364675, 53.595096588134766, 54.35470839909145, 56.44920117514474, 52.779492718832834, 53.02083144869123, 57.82617432730538, 56.992842129298616, 53.95259182793753, 56.10883671896798, 56.43050009863717, 59.24169608524868, 61.06484086172921, 66.05180617741176, 61.66810430799212, 69.64144706726074, 10.395435282162257, 0.5615867940442902, 8.856282489640371, 19.009889193943568, 8.51545684678214, 1.9645551655973708, 0.2814857198723725, 12.41452099595751, 47.27066557747977, 46.49316562925066, 38.78233276094709, 56.85308953693935, 52.78629847935268, 1.185486444405147, 0.43587998513664516, 0.12212239338883332, 0.11499329736190182, 0.16618782814059938, 0.12947527026491507, 0.11630312779120036, 0.12587789472724709, 0.09947965946048498, 0.1460310768868242, 0.19543800715889248, 0.12680777268750326, 0.11912539920636586, 0.0669032610686762, 0.13185584252434118, 0.12828160503080913, 0.09069889384721007, 0.1783157323620149, 0.14666902194065706, 0.15780223453683512, 0.18981884153825895, 0.08808391488024167, 0.11114696054054157], [0.01705247220317168, 0.05303936232147472, 0.046413461079022715, 0.028049187302323322, 0.060709389857947826, 0.016400461118402224, 0.008865009128515209, 0.025508402746969035, 0.048901343651648076, 0.083850819883602, 0.018657331354916096, 0.06545042259884731, 0.033689619906778843, 0.015166655448930604, 0.04210103516067777, 0.048299652723861594, 0.09784890910876648, 0.0762692970622863, 0.05993016024253198, 0.10403785415525947, 0.05206621079040425, 0.10520321769373757, 0.02361699825684939, 0.01933324383571744, 0.002449634825877313, 0.16115562245249748, 0.15387733014566557, 0.17075926783893788, 0.2839038829718317, 5.005857901913779, 36.05873966217041, 51.64495958600725, 43.60347236905779, 62.15358189174107, 16.966159956795828, 25.79058756147112, 3.9665428825787137, 2.3900665385382514, 3.1488864719867706, 3.211286289351327, 1.5263998082705905, 0.31477451218026026, 0.1230060224022184, 3.5265838163239613, 80.11966405596051, 68.46731962476457, 77.31425244467599, 65.59996482304165, 59.444778033665244, 52.140039580208914, 61.29426343100411, 59.93181896209717, 63.32345008850098, 61.93403271266392, 65.92033931187221, 58.54254749843052, 59.79418904440743, 59.89062309265137, 65.49957030160087, 62.15554128374372, 67.58339064461845, 64.86781924111503, 64.34053434644426, 62.69519397190639, 58.639481816973, 55.472683974674766, 55.072318349565776, 54.118327208927695, 52.398839133126394, 45.877280780247276, 44.16332694462368, 41.87610503605434, 43.11606666019985, 42.377789293016704, 44.49398476736886, 42.60831662586757, 43.98893758228847, 42.27212108884539, 43.34160171236311, 44.374934332711355, 44.51262331008911, 46.87040417534964, 50.13359090260097, 52.54099580219814, 56.33665772846767, 58.17360162734985, 58.6926702771868, 55.828178133283345, 60.16123458317348, 55.05112634386335, 48.54864427021572, 60.26964732578823, 58.961850438799175, 59.972111565726145, 59.712624141148154, 58.61637210845947, 59.6683988571167, 60.05024405888149, 59.77061380658831, 60.09268365587507, 56.55743326459612, 54.608397551945274, 61.11379092080252, 59.46686635698591, 56.098174708230154, 53.80338273729597, 40.08272981643677, 39.41746759414673, 40.03195238113403, 41.29359933308193, 40.62836142948696, 42.997064862932476, 52.904407433101106, 57.32620627539498, 57.60910912922451, 56.81706312724522, 57.01541335242135, 55.1520037651062, 52.54054069519043, 48.31724146434239, 45.20809282575335, 43.220842020852224, 42.78466190610613, 42.77907902853829, 48.789809295109336, 49.68612691334316, 49.595508507319856, 50.00226647513253, 51.425257546561106, 53.07275881086077, 52.0820221219744, 50.48910937990461, 54.65844890049526, 49.17883546011788, 53.362700189862935, 56.04039348874773, 60.28582273210798, 56.828979287828716, 71.26674188886369, 28.88190017427717, 0.2435990385711193, 0.9945917448827198, 0.7377190685697964, 1.2017503316913332, 2.1978815368243625, 0.3626007544142859, 0.03760053969121405, 14.637493780681066, 39.70209012712751, 22.126154524939402, 29.552978038787842, 48.33264562061855, 7.699645400047302, 0.40551179753882544, 0.04809558670967817, 0.028449007276711718, 0.02463579483862434, 0.05276690337008663, 0.013750300958885677, 0.012291185191965528, 0.05976022793246167, 0.014208512264303863, 0.011382195084089679, 0.06304474454373121, 0.06098770456654685, 0.025409382435360124, 0.061700234189629555, 0.04362656847972955, 0.017394601433937038, 0.021997553994879127, 0.031225526771907295, 0.02572001576689737, 0.05131518787571362, 0.08964590249317032, 0.032807582058012486, 0.03862484937001552, 0.02233783930673131, 0.05145327314468367, 0.045820567357753, 0.009153478961837078, 0.026493789960763285, 0.01857902841376407, 0.0268603142217866, 0.07785615976899862, 0.0337341725161033, 0.016235967266506383, 0.056440369824745824, 0.0153896848205477, 0.08694706338324718, 0.02792491700633296, 0.09716210953359093, 0.03610234794073871, 0.04468508650149618, 0.06429481639393739, 0.05900300320770059, 0.033967249295009036, 0.026891221491886035, 0.05905766598880291, 0.06887656982455935, 0.07585342973470688, 0.045716717573148866, 0.06906782849026577, 0.047024597214268785, 0.2620182516319411, 0.3556751917515482, 9.048207368169512, 54.24243245806013, 56.55368818555559, 54.083058152879985, 65.37095914568219, 21.820119380950928, 38.22775534221104, 2.7772657615797858, 2.424531774861472, 0.9406010934284755, 3.403129960809435, 5.213431860719409, 1.5202747540814536, 0.35545483071889195, 5.784085239682879, 81.37987967899868, 69.94116456168038, 80.68922873905727, 67.62421825953892, 62.65445668356759, 56.38477747780936, 62.888840266636436, 61.15137372698103, 65.24145862034389, 66.02274881090436, 67.81241021837506, 62.44942923954555, 62.24160167149135, 63.45479883466448, 69.96239825657436, 65.76345593588692, 67.04762199946812, 67.30414254324776, 64.94789722987584, 63.40220097133091, 61.05997017451695, 57.19588933672224, 58.360935483660015, 57.74844135556902, 55.178271429879324, 47.690281186785015, 46.10289921079363, 45.40613385609218, 45.78712442943028, 44.66699491228376, 46.95089905602591, 45.43853678022112, 46.75321933201381, 43.83015039988926, 46.582179001399446, 45.46986968176705, 48.504436356680735, 50.13212830679757, 51.987717696598594, 54.03599452972412, 58.68529823848179, 61.008970396859304, 62.255324363708496, 59.98242964063372, 61.61759785243443, 57.48307228088379, 53.944775104522705, 59.677646909441265, 60.94834736415318, 59.419903482709614, 60.43710586002895, 60.14714363643101, 61.652185985020225, 60.00438594818115, 60.630960600716726, 60.75288758959089, 58.03832367488316, 54.79136446544102, 61.94729682377407, 62.81463350568499, 56.981078829084126, 55.08062492098127, 41.62519863673619, 41.644080366407124, 42.406224795750205, 42.19355085917881, 42.0005715915135, 45.31508118765694, 55.44384200232369, 59.00162192753383, 60.19922038487026, 59.83029188428606, 60.44120529719761, 57.12552840369088, 54.27023220062256, 50.42478295734951, 48.12919889177595, 44.18368864059448, 46.626296588352744, 44.826452595846995, 51.50443574360439, 52.15793119158064, 51.58578177860805, 52.8418493270874, 55.1602269581386, 56.17427485329764, 55.351920809064595, 53.33612680435181, 57.44143520082746, 50.64191763741629, 55.604414871760774, 57.61205516542707, 63.617449215480256, 57.47602333341326, 73.10927908761161, 29.016061203820364, 0.303315168512719, 1.797184135232653, 3.7059302840914046, 2.068966180086136, 2.079329635415758, 0.04124374009136643, 0.06945550268782036, 18.688350881849015, 46.75062765393938, 31.201646600450786, 25.514438356672013, 57.89456197193691, 9.289579101971217, 0.48271844323192326, 0.029365397657134702, 0.05206272651308349, 0.06181088289512055, 0.08759473184389727, 0.024928496185956255, 0.03225693731967892, 0.004079804606070476, 0.04001079107235585, 0.03592659040753331, 0.03761608153581619, 0.02344256895594299, 0.007401017239317298, 0.026690280131463493, 0.07579415291547775, 0.03007864992001227, 0.07195551068122898, 0.0199157949869654, 0.03779041075280734, 0.04545266227796674, 0.09030860728983368, 0.06986818090081215, 0.01369491299348218, 0.0917176463242088, 0.19460194345031465, 0.11329813368086304, 0.07152303281639304, 0.12557399246309484, 0.11300263846559183, 0.14651692153087684, 0.1425662599503994, 0.12056472125862326, 0.10920366338853325, 0.18082536198198795, 0.25671506619879175, 0.17125184355037554, 0.13726926275662013, 0.19818266773862497, 0.1114630289375782, 0.17637871844427927, 0.18181774658816202, 0.1498104626578944, 0.35164607795221464, 0.19209931631173405, 0.31412086582609583, 0.2195557744375297, 0.17086829484573432, 0.15947494549410685, 0.23703953198024205, 0.2598491651671273, 0.38953862179602894, 0.7910063777651105, 15.801449060440063, 71.66673578534807, 65.6135971886771, 60.55132729666573, 84.2600816999163, 27.30614253452846, 36.33196367536272, 5.120492322104318, 4.6337944609778265, 10.356440254620143, 7.779129317828587, 4.101634536470685, 0.3963419124484062, 0.28730081926499096, 5.7245504685810635, 83.21192509787423, 73.5138657433646, 84.86568668910435, 71.2668183190482, 66.39044053213937, 57.94422422136579, 68.25546210152763, 65.25801617758614, 67.99150698525565, 66.70555523463658, 71.42842647007534, 66.11338806152344, 65.4895440510341, 66.02270017351422, 71.50218854631696, 66.75906331198556, 73.21439838409424, 68.72604274749756, 67.83013507298061, 66.96464661189488, 65.13602665492466, 59.98985726492745, 62.04624611990792, 62.12859616960798, 60.50215489523751, 50.904364994594026, 49.67274120875767, 47.18061692374093, 50.09704337801252, 46.70216049466814, 50.0002897126334, 47.15467235020229, 49.25098555428641, 46.69098779133388, 49.192509514944895, 48.6289758682251, 49.91170712879726, 50.80373770850045, 54.23434822899954, 55.52547638756888, 62.039374351501465, 63.241273743765696, 65.17099693843296, 61.51211724962507, 62.639705657958984, 59.890921865190776, 52.0199990272522, 63.1448883329119, 62.32755783626011, 64.00367178235734, 62.43761035374233, 62.52527577536446, 63.29676900591169, 61.39573492322649, 62.29983452388218, 61.816566467285156, 58.75132002149309, 58.662952831813264, 64.9412339074271, 62.474616459437776, 60.6504989351545, 57.50730759756905, 44.520276750837056, 42.993917328970774, 44.89553853443691, 45.49232278551374, 44.21412522452218, 46.96140473229544, 57.053715297154014, 61.175886971609934, 62.56285163334438, 62.59615434919085, 64.05942412785122, 58.64744445255825, 56.25420345578875, 53.852256366184776, 50.90824556350708, 46.83713272639683, 48.361598764147075, 48.51482738767351, 54.535920892442974, 56.94127607345581, 54.533985819135395, 57.83070455278669, 58.17361552374703, 61.02201911381313, 56.883817945207866, 57.233041354588096, 59.152244976588655, 52.97956262316023, 58.15493876593453, 59.65081296648298, 64.16582189287458, 60.33912236349923, 73.10886914389474, 32.629723753247944, 0.15311785946999276, 2.784306023802076, 7.612318703106471, 8.098494580813817, 6.448654813425882, 0.9080121964216232, 0.17444587073155812, 25.753284420285905, 54.23075253622872, 34.84225252696446, 43.22030006136213, 66.13080024719238, 16.846140248434885, 0.8606709710189274, 0.1889476025743144, 0.2863661508475031, 0.14727484514670713, 0.1474582395915474, 0.10195015796593257, 0.06202789196478469, 0.1574449451374156, 0.10517442745289632, 0.11381329782307148, 0.13554843009582587, 0.08592995296099357, 0.12979483311729773, 0.13291996185268673, 0.17494367116263934, 0.11030941762562309, 0.16120408342352935, 0.11784041672945023, 0.12498404697648116, 0.11813608157847609, 0.13748287915119103, 0.12456283957830497, 0.08127689907061202], [0.023979361401870847, 0.06970301869192294, 0.02407651743851602, 0.0213019538205117, 0.037442776906703196, 0.018148328310676982, 0.012795737046482307, 0.028769911932093755, 0.002217864226882479, 0.06227565224149397, 0.037696922197937965, 0.07503381371498108, 0.034895515734595914, 0.0187841173194881, 0.05020452104508877, 0.05410444516954677, 0.04420469727899347, 0.023145964335916296, 0.08041511209947722, 0.012364279528680657, 0.03352224567372884, 0.04162681042881949, 0.04854504491335579, 0.04673341748171619, 0.02415853875157024, 0.08448345879358904, 0.040262310433068445, 0.024379978654906154, 0.049125273778502426, 0.585252195596695, 31.253883157457622, 56.23467206954956, 49.889559745788574, 42.882190295628135, 42.27978842599051, 19.373596123286656, 22.337807076317922, 1.396341472864151, 0.8553898515445846, 3.115544021129608, 10.638390336717878, 3.0712151655129025, 0.2136925533413887, 0.2800502654697214, 34.18100983755929, 84.73196860722133, 64.35697378431047, 72.02697903769356, 65.09167630331856, 61.60059561048235, 58.48598221370152, 67.10188743046352, 67.05313886914934, 65.98507567814418, 61.84626306806292, 64.16861506870815, 65.99536596025739, 66.83917604173932, 66.51110989706856, 67.21553216661725, 66.18691389901298, 66.13000815255302, 64.4099815913609, 63.387178965977256, 61.27295330592564, 57.99505376815796, 54.88946260724749, 52.82695238930838, 49.47250802176339, 47.771804400852744, 44.224689960479736, 44.00732251576015, 45.22605391911098, 44.280376298086985, 43.42239189147949, 43.643351554870605, 45.18511860711234, 43.85903058733259, 45.94247572762625, 45.61780030386788, 46.70610359736851, 48.731051853724885, 56.21584245136806, 57.46978037697928, 61.19751671382359, 59.952524593898225, 59.86036368778774, 56.864498479025706, 61.2965007509504, 43.43126821517944, 41.4090644972665, 62.07367760794503, 57.15244572503226, 60.92999717167446, 56.507100514003206, 61.65611866542271, 59.346655573163716, 60.14250223977225, 59.729237283979145, 56.594283035823274, 54.774039132254465, 61.836306299482075, 57.45250368118286, 53.96850667681013, 51.11871692112514, 46.72461012431553, 39.633018084934776, 42.2333779335022, 41.004456996917725, 43.52756329945156, 42.4288272857666, 42.76634298052107, 53.27193587166922, 57.475728034973145, 58.121104512895855, 57.268327781132285, 59.328062193734304, 57.70644644328526, 53.28838225773403, 51.501652990068706, 46.59525898524693, 44.076123578207834, 41.96954093660627, 48.73459196090698, 53.541088240487234, 51.96018198558262, 52.718060220990864, 53.67435121536255, 51.63563510349819, 50.80526283809117, 53.14401953560965, 55.94181244713919, 52.25407688958304, 56.14120142800467, 56.51096371241978, 57.359491620744976, 62.902861731392996, 65.32749816349575, 56.38292925698416, 1.2668906705720084, 0.17319488285907678, 0.8177946146045412, 2.661018056528909, 1.0015074823583876, 0.683501623570919, 0.05987761449068785, 0.9266712580408368, 35.08994191033499, 33.36452007293701, 18.798144578933716, 47.759655475616455, 32.00594227654593, 0.05589525175413915, 0.03676306462979742, 0.05030739373926606, 0.06009247260434287, 0.017403308734563843, 0.03893456667927759, 0.022804795232202326, 0.06288138045264141, 0.043706014752388, 0.03850417530962399, 0.034383340539144616, 0.024631801660039594, 0.02559704995448036, 0.08956196092601333, 0.017396007697763186, 0.009317868488973804, 0.038267821206578186, 0.014443103024469954, 0.012535955673748893, 0.005641721396906567, 0.025586464808189442, 0.039760180948568244, 0.041282789781689644, 0.021304935981918658, 0.09427331454519715, 0.002964692734946896, 0.046417260875127146, 0.05240672341148768, 0.05904172720121486, 0.046947804013533254, 0.08921145009143011, 0.037233849189111164, 0.020852892559819987, 0.025438975043860928, 0.014744174101256897, 0.014222876002479876, 0.05589383700862527, 0.0460734403958278, 0.09897484976266112, 0.04508987335222108, 0.020799252670258284, 0.05130136951005884, 0.13207338085131987, 0.03589971024276955, 0.029382109974644015, 0.018859244716752852, 0.03168560404862676, 0.053244741300919225, 0.011460346203031284, 0.05700565395610673, 0.085913668120546, 0.054331913856523376, 0.07598929280149085, 1.599079702581678, 43.17370891571045, 65.16806479862758, 52.56666939599173, 66.92949567522321, 41.31459331512451, 30.38364212853568, 26.59946731158665, 1.3137011187417167, 0.44292860691036495, 2.8429381804806844, 5.996063053607941, 7.021661460399628, 1.2734712660312653, 0.591417310493333, 41.55138444900513, 86.66263675689697, 69.50836821964809, 75.1341370173863, 69.16803850446428, 62.37364523751395, 64.24375983646938, 68.54688344682965, 69.71094294956752, 65.77398940495083, 65.89889022282192, 65.94304602486747, 67.9128394808088, 66.93270574297223, 69.21311146872384, 69.04930768694196, 70.16711303165981, 66.72002138410295, 68.27304104396275, 65.65070056915283, 64.14852782658168, 59.87057753971645, 57.37268624986921, 56.59525578362601, 54.134707587105886, 49.795019081660676, 46.78991624287197, 46.58127573558262, 47.51818125588553, 45.77068499156407, 46.271267959049766, 45.10478006090437, 45.93657670702253, 44.90333441325596, 46.817302567618235, 47.57425669261387, 49.469905921391074, 48.948561736515586, 58.50328322819301, 58.99331883021763, 62.964304651532856, 60.50678934369768, 62.93338516780308, 58.322484152657644, 65.71417236328125, 47.84198120662144, 42.58097199031285, 62.661488260541645, 58.05584008353097, 62.55072007860456, 58.22835690634591, 63.01160798754011, 59.167225292750764, 61.27757385798863, 59.95264271327427, 57.17006983075823, 56.484206199645996, 62.667609623500276, 60.31571388244629, 57.312893526894705, 53.251539434705464, 47.285319328308105, 41.976325852530344, 42.66095617839268, 44.016747747148784, 45.43398918424334, 42.9497024672372, 43.62449066979544, 53.26645374298096, 58.761742319379536, 60.29532091958182, 57.092409815107075, 60.831763539995464, 57.83029808316912, 56.64639105115618, 52.663881642477854, 48.728015490940635, 46.7649096761431, 44.364310537065776, 50.29937144688198, 54.679609639304026, 52.825354303632466, 55.0927460534232, 56.267234802246094, 54.818260942186626, 52.37744910376412, 56.23470333644322, 57.74316419873919, 54.876399993896484, 57.208173751831055, 60.48142841884068, 59.840533529009136, 64.33407252175468, 66.35986845833915, 57.31090981619698, 1.109328868133681, 0.32955362913864, 2.3185274515833174, 1.439653285912105, 0.8808592877217701, 0.1474768314510584, 0.08077304610716445, 1.8399913353579385, 39.97584915161133, 43.60400390625, 18.970960174288066, 49.487846170152935, 41.15002523149763, 0.12581646016665868, 0.03204240829550794, 0.03301164807219591, 0.02456121875106224, 0.07010283866631133, 0.020398506495569433, 0.033316802233457565, 0.03541566710919142, 0.05354373775688665, 0.018605138441281657, 0.03312081417867115, 0.06940947087215525, 0.0643707105357732, 0.05849664645003421, 0.03203784175483244, 0.021740711526945233, 0.014099598912123059, 0.043630313993032487, 0.0225766598845699, 0.03082548627363784, 0.04944544731240187, 0.003146962932078168, 0.032468579177345545, 0.02157461972508047, 0.1569653701569353, 0.09700279629656247, 0.17391043874834264, 0.10997085579271827, 0.10713254380971193, 0.08252017878528152, 0.14721057430974074, 0.19035716408065387, 0.09975916839071683, 0.1057304326178772, 0.10494764747896365, 0.1673132191811289, 0.1664090576980795, 0.09942013158329896, 0.2976953514984676, 0.1365906327430691, 0.2040792049041816, 0.1685445566794702, 0.2279121774647917, 0.11829724721610546, 0.17000637895294599, 0.1447334736585617, 0.19808784925511905, 0.10198881410594497, 0.1356421493526016, 0.18640879594853946, 0.21115743794611522, 0.10870177817663976, 0.13813097508890287, 1.9618998680795943, 62.94632271357945, 71.72160570962089, 63.04839175088065, 61.5646664755685, 57.87321015766689, 31.431013584136963, 28.460507563182286, 1.8310694141047341, 6.245577641895839, 7.402919105121067, 23.68801055635725, 7.120204286915915, 0.4368709719606808, 0.3188904513205801, 38.56190116064889, 91.31055082593645, 70.219377381461, 78.42028059278215, 72.26412105560303, 66.48289326259068, 65.43707820347377, 72.40589209965297, 72.9689393724714, 69.78223841530937, 67.55213069915771, 68.81085940769741, 74.0050755909511, 71.93191378457206, 72.37127617427281, 73.2538572038923, 73.65018939971924, 69.19002260480607, 69.9584516797747, 70.89156000954765, 66.53362206050328, 62.56125354766846, 61.79259518214634, 59.40614604949951, 56.15994071960449, 53.430948870522634, 50.232481139046804, 49.43687418528965, 50.87807648522513, 47.061806201934814, 48.90741450445992, 47.55381509235927, 48.9753018787929, 46.35098811558315, 49.69868925639561, 49.4040196282523, 50.732139996119905, 50.23982885905674, 62.05437551225935, 62.08835220336914, 66.99349553244454, 63.91827842167446, 65.56921904427665, 61.620689800807405, 67.30339908599854, 51.50078099114554, 44.759162766592844, 62.778864179338726, 59.00306715284075, 62.682186944144114, 59.72430406297956, 64.63186536516461, 61.37335477556501, 62.00811440604073, 62.15228952680315, 58.53988633837019, 60.550326756068635, 63.29633821759905, 61.56547246660505, 59.715514591761995, 55.19282790592739, 50.24821880885533, 44.77645683288574, 45.94922590255737, 45.78154502596174, 49.410773277282715, 45.73562438147408, 47.03923150471279, 57.66910334995815, 61.170314516339985, 63.00113705226353, 59.63511003766741, 64.31672286987305, 61.4434620993478, 60.14268984113421, 56.758437701633994, 50.74249281202044, 48.49552181788853, 48.02037967954363, 53.80613769803728, 57.39492743355887, 57.663447516305105, 60.54953466142927, 60.36548382895333, 57.65172243118286, 55.30732379640852, 57.97034249986921, 61.81025750296456, 56.49778992789132, 62.62104974474226, 61.52356093270438, 61.912180628095356, 66.90786593300956, 70.8719938823155, 58.15070036479405, 2.4839264963354384, 0.39849243419510977, 2.007689799581255, 7.949497410229274, 6.215421591486249, 1.8650528362819125, 0.2253731129957097, 2.2189903812749043, 52.08927256720406, 43.90800149100167, 31.555139677865164, 59.86714512961251, 50.30498906544277, 0.5027207327740533, 0.26215960404702593, 0.21025360215987476, 0.17358525762600557, 0.23396202283246176, 0.11464406895850386, 0.10770799578832728, 0.11247259405042444, 0.1622291055641004, 0.11009069186236177, 0.13653949834406376, 0.15635615427579197, 0.11442667990922928, 0.14455466611044748, 0.1356094575354031, 0.11181384511291981, 0.0994512899113553, 0.071830999505307, 0.13792231199996813, 0.1910007138337408, 0.15363722374396666, 0.15410790991570267, 0.13877243495413236, 0.08541031048766204], [0.08172184840909072, 0.05546595961121576, 0.0508343508200986, 0.04954654563750539, 0.042666407501591105, 0.034336175569998365, 0.0498037341582988, 0.026630526641383767, 0.011237987732913877, 0.07286615895905665, 0.035216069248105795, 0.051758800500205586, 0.042232185801757235, 0.033102656581572125, 0.024483836921198026, 0.02749854595666485, 0.04188541030245168, 0.03968973883560725, 0.009923365150046135, 0.051060516719839404, 0.024213484821042845, 0.01206628984904715, 0.041132138044174225, 0.025003360650901283, 0.09771378564515285, 0.10447750413524252, 0.11816035956144333, 0.050595669341938834, 0.0450723434000143, 0.4392138719558716, 10.030323948178973, 61.68320274353027, 51.18274804524013, 24.137927259717667, 56.66761432375227, 34.75097056797573, 13.259781513895307, 0.08022340560065848, 0.6909586148602622, 2.228313995259149, 3.525705954858235, 16.747152737208776, 0.9396241115672248, 0.03132034186273813, 3.428672407354627, 82.13373143332345, 70.52969782693046, 77.23739842006138, 68.02140508379254, 67.32857935769218, 63.56961781638009, 65.9268775667463, 62.18015875135149, 69.99430438450405, 67.29224722726005, 63.1213686806815, 65.46142469133649, 68.5495376586914, 67.60821655818394, 66.3690470286778, 62.811715262276785, 63.74333667755127, 66.3486888068063, 63.72357600075858, 60.101869174412315, 56.204798289707725, 54.88532842908587, 53.86804267338344, 51.724891662597656, 48.13087340763637, 44.948494229997905, 44.740013531276155, 43.0109577860151, 43.25835534504482, 43.62404598508562, 42.791912351335796, 43.881122384752544, 43.02536487579346, 45.072286810193745, 43.37736061641148, 50.535957608904155, 55.32520151138306, 56.99928310939244, 58.78552600315639, 59.13902255467006, 58.8194123676845, 62.74430383954729, 54.71445138113839, 58.93843500954764, 42.44825097492763, 47.74699585778372, 61.06622355324881, 58.04486887795584, 60.36884675707136, 60.30415207999093, 60.719397272382466, 59.18232372828892, 61.111247880118235, 58.80471692766462, 58.41352639879499, 61.66461631229946, 55.985881396702354, 55.49098552976336, 53.36877638953072, 49.617940766470774, 41.90862260546003, 41.509997504098074, 42.87644760949271, 41.40682370322091, 41.721184526171, 42.86505603790283, 43.67126246861049, 52.50006396429879, 58.56895065307617, 60.48874487195696, 57.77879803521292, 57.6600672176906, 57.024442536490305, 55.96610334941319, 52.401583671569824, 49.00986916678292, 44.67475952420916, 45.85994849886213, 53.094096728733604, 54.440306731632774, 54.596092292240684, 51.33614689963204, 52.96927234104702, 54.23583514349801, 54.56580856868199, 51.13760559899466, 55.26030533654349, 56.594053745269775, 56.20814037322998, 55.47274998256138, 63.20209980010986, 58.268281255449565, 68.88720621381486, 15.95353296824864, 0.9022960545761245, 0.20133655278810433, 1.8018774262496402, 2.2774879166058133, 0.5795123321669442, 0.3005443571933678, 0.045848132842885594, 7.54261611189161, 48.43487446648734, 20.184204237801687, 36.10471589224679, 47.961934907095774, 5.38221663236618, 0.2794391768319266, 0.04573233744927815, 0.015553203278354235, 0.032884110630090745, 0.07678977413369076, 0.07693512990538563, 0.08878432586789131, 0.02941748539784125, 0.06206954722957952, 0.024717573575409393, 0.035538831393101385, 0.04889000193881137, 0.04068616751049246, 0.04296795524922865, 0.03719250944310001, 0.04623272649145552, 0.041679128871432373, 0.07715743154819522, 0.04942542713667665, 0.04166597207742078, 0.06388902531138488, 0.03157194943300315, 0.009470852690615823, 0.015778729658839957, 0.028111995896324515, 0.06579279779855694, 0.029431052705539123, 0.041782507074198554, 0.03876656819401043, 0.03519967244938016, 0.026223600709012578, 0.0347780443594924, 0.013035002064758112, 0.07517033496073314, 0.03899443721664803, 0.03726338581847293, 0.03820772335997649, 0.012256632492478405, 0.05627654093716826, 0.049319663883319924, 0.023953397259382263, 0.042380069116396565, 0.0034063766236483517, 0.0694434858326401, 0.024779013225010464, 0.03309010707640222, 0.04017689644492098, 0.0979036736701216, 0.03453501686453819, 0.0029083130482052055, 0.08502905523138386, 0.055299918699477396, 0.10566606678600822, 0.24591319582292012, 14.535656639507838, 76.92297158922467, 46.96529572350638, 32.17138235909598, 70.39782101767403, 32.697440896715435, 22.746067592075892, 0.18269558091248783, 0.5164569414087704, 3.0878417704786574, 3.6984779068401883, 8.614690150533404, 3.0400396840912953, 0.3938835529344422, 5.19922366312572, 82.94088976723808, 74.59293488093785, 77.68624510083879, 69.11719158717564, 70.0589017868042, 67.62703227996826, 68.29797812870571, 66.53119019099644, 71.73238931383405, 69.63489491598946, 66.89285087585449, 66.12376867021833, 72.05435494014195, 70.76005145481655, 70.02748203277588, 65.32871409824916, 66.12135764530727, 67.18885108402797, 65.77063342503139, 63.59644481113979, 57.93317311150687, 57.93550770623343, 56.7708853994097, 54.379648957933696, 50.46418619155884, 48.72420787811279, 46.399594238826204, 45.81566762924194, 45.852489607674734, 45.53034332820347, 46.07130227770124, 46.15378781727382, 44.806942054203574, 47.469349316188264, 46.3720828465053, 51.12338611057827, 56.19845805849348, 58.00426707948957, 59.54715973990304, 60.40202440534319, 61.11859907422747, 64.41485922677177, 57.34814868654524, 61.73046439034598, 43.46320908410208, 46.49741097858974, 61.46435533251081, 58.342543601989746, 61.423479080200195, 59.808933121817454, 62.671528407505576, 59.745322363717214, 61.98592185974121, 60.38607134137835, 58.053258827754426, 62.028611591884065, 59.88680853162493, 55.55576358522688, 55.56802020754133, 51.20897054672241, 45.531100681849885, 43.28810405731201, 46.16274751935686, 42.75654949460711, 44.51932484763009, 44.05880171912057, 46.29766069139753, 53.472460883004324, 59.38990810939244, 60.76370593479702, 60.72041865757534, 58.585424831935335, 59.271483012608115, 57.267153535570415, 56.37124933515276, 51.30226053510393, 47.57557685034615, 46.85843937737601, 55.92172867911202, 56.33421196256365, 58.552281924656455, 53.97438137871878, 53.633478437151226, 56.03458826882498, 60.48502063751221, 52.4975209236145, 57.903285435267854, 59.57293060847691, 61.41569709777832, 55.96434892926897, 66.65938445499965, 59.79565511431013, 70.25222151620048, 16.342265571866715, 1.0993489750794, 0.6391651683620044, 1.9160799724715096, 2.4958528620856146, 1.0950313210487366, 0.4758179049406733, 0.04400559474847146, 10.49715517248426, 59.88899721418108, 30.677151407514298, 30.717742783682688, 58.529457092285156, 7.900290267808097, 0.19422759568052633, 0.07151326869747468, 0.019319534035665647, 0.05646596755832434, 0.017401994072965214, 0.013864075166306325, 0.025418885318296294, 0.04529041098430753, 0.01989461960537093, 0.03999342396855354, 0.04070756171963044, 0.004241342165706945, 0.026261992220367705, 0.03439758298918605, 0.02283365841555808, 0.05027285969949194, 0.05861398551080908, 0.013449028017930686, 0.012297340352753443, 0.041589725097375255, 0.025049275419275676, 0.022523734153115323, 0.009411523284922754, 0.018170105892100503, 0.14557496564728872, 0.15671689063310623, 0.20030235685408115, 0.11474521138838359, 0.15543534154338495, 0.17038392940802233, 0.20207938578511986, 0.16693979421896593, 0.04284443473443389, 0.15227932589394705, 0.11272962990083865, 0.18787991415177072, 0.12392458239836351, 0.14126401554260934, 0.2300631877567087, 0.23309898057154246, 0.09328884844269071, 0.15513450625751699, 0.08008410914668015, 0.12969882041215897, 0.09343914394932133, 0.19919387490621634, 0.16779470763036183, 0.1761501742792981, 0.1232192859585796, 0.24400254977600916, 0.2461533157953194, 0.22653187438845634, 0.21197940169700555, 0.6011574364134243, 21.104404551642283, 88.1745856148856, 64.27770873478481, 39.44666045052664, 76.74838420322963, 50.009690625326975, 21.893045936311992, 0.29371015248554094, 2.5117935495717183, 7.000408657959529, 14.627019371305193, 31.112025260925293, 2.4934144786426, 0.5583882885319846, 4.956851822989328, 86.26107951572963, 75.40989017486572, 84.78576156071254, 73.35574558803013, 73.4669862474714, 68.49256937844413, 72.27527291434151, 68.82426943097795, 77.54751736777169, 72.87395749773297, 68.637772832598, 71.43426295689174, 73.5363918031965, 73.60788876669747, 72.18887206486293, 66.58914511544364, 66.470810345241, 70.1899448122297, 68.16759518214634, 66.37506416865757, 62.20142718723842, 61.04429503849575, 59.8145820072719, 58.98760741097586, 54.554830414908274, 52.10951614379883, 49.85337005342756, 48.65651157924107, 48.781982149396626, 49.451607840401785, 50.07401009968349, 48.26428576878139, 47.009899684361045, 50.04070043563843, 48.886066164289204, 54.20136513028826, 59.54143442426409, 61.36150114876883, 62.316850662231445, 62.26040349687849, 63.076080322265625, 67.81708635602678, 59.92331436702183, 64.49135194505963, 45.70061935697283, 48.936676842825754, 60.901627676827566, 61.84346294403076, 63.545931407383506, 61.89536598750523, 65.11228466033936, 62.06062889099121, 66.07686138153076, 62.799562862941194, 60.59007045200893, 63.02059200831822, 60.41325964246477, 58.63192217690604, 57.1493364061628, 52.28472191946847, 47.27872896194458, 47.49990054539272, 49.11240373338972, 46.127961363111226, 47.630547523498535, 47.01000738143921, 47.97642190115792, 55.32406548091343, 61.489424433027, 64.27845914023263, 60.66116441999163, 62.56251811981201, 62.25766590663365, 59.15864426749093, 57.941222599574495, 54.780983856746126, 50.41422864368984, 50.6379154750279, 58.39380046299526, 58.4211277280535, 61.210231917245046, 56.206299100603374, 56.23737839290074, 61.50435611179897, 61.124289648873464, 55.71196256365095, 60.644398416791645, 62.01686218806675, 61.953939301627024, 59.04055963243757, 69.52196584429059, 62.74358817509243, 68.11049488612584, 18.21508649417332, 1.178498727934701, 0.44726148726684706, 5.4942246334893365, 7.716591187885829, 2.5430072460855757, 1.4182264528104236, 0.21716111579111644, 14.510770797729492, 64.80670288630894, 29.098753452301025, 50.02217653819493, 66.5814187186105, 15.083740098135811, 0.7502932995557785, 0.24278783638562473, 0.19413114871297563, 0.10824091719197375, 0.1233140230178833, 0.15334899563874516, 0.16168908668415888, 0.17187828065029212, 0.14696902941380227, 0.08102202096155711, 0.16599198936351708, 0.1824823852096285, 0.12218276943479266, 0.09078105765261821, 0.1095531564205885, 0.10511932362403188, 0.15916001025055135, 0.15870121201234205, 0.16118507087230682, 0.11286334879696369, 0.17438268555062159, 0.15609968160944326, 0.057344656836773665, 0.13099370950034686], [0.01001034485774913, 0.12784245716673986, 0.050359715574554036, 0.03934379793437464, 0.0290807963215879, 0.06931748866502728, 0.046742000949702094, 0.0013312315298078048, 0.0760869068492736, 0.10532009535069976, 0.027556464009519135, 0.03670045620362673, 0.03501720420484032, 0.036171992775052786, 0.040107824972697666, 0.05714956444821187, 0.05690853863156267, 0.007198053844539183, 0.02567050645926169, 0.04527608711006386, 0.07363665582878248, 0.017872105186272944, 0.040617360666926415, 0.06376455484756402, 0.08431097519184862, 0.04648751299828291, 0.06647552616362061, 0.052573493748371086, 0.08131383173167706, 0.016474496074286953, 0.18138727040163108, 36.24475336074829, 61.73591177804129, 36.54487385068621, 31.588362489427837, 55.583354881831575, 12.77653169631958, 0.694126124892916, 1.2059445466314043, 0.4258069699364049, 1.144693244780813, 6.734104182038989, 3.9689803974969045, 0.28268878960183685, 0.03815246686073286, 18.71133725983756, 92.00888647351945, 67.00157628740583, 83.56018270765031, 67.8641048158918, 64.75525842394147, 65.70113059452602, 69.1945389338902, 63.79889447348458, 66.29599366869245, 68.43691430773053, 72.50889914376395, 70.09460163116455, 68.59507615225655, 65.07149873461042, 63.42446299961635, 68.13502202715192, 64.99774360656738, 63.588405745370046, 58.495376178196494, 58.88767841884068, 56.1690810748509, 53.75513792037964, 51.28482403073992, 48.41440159933907, 46.19832577024187, 44.11850411551339, 43.92208548954555, 43.34204292297363, 43.50788252694266, 45.19391850062779, 45.631095681871685, 44.067389692579, 46.76246738433838, 46.5886720929827, 54.39524071557181, 55.40927471433367, 62.01273495810372, 61.00972775050572, 61.087012563432964, 58.45841176169259, 61.557627950395855, 54.9085145677839, 57.54771484647478, 39.80033070700509, 48.89068324225289, 67.73470851353237, 58.44324384416853, 61.079355648585725, 59.03396579197475, 57.295939922332764, 57.107654162815635, 57.78487076078142, 55.43532351085118, 59.89126232692173, 56.379340512411936, 56.093321391514365, 52.04025650024414, 49.7743238721575, 45.56086676461356, 41.288655689784456, 42.13050290516445, 43.50250462123326, 43.669369084494456, 41.70959145682198, 43.325638226100374, 42.34492431368147, 52.475998878479004, 58.199396814618794, 60.21495805467878, 59.485244342258994, 59.35891914367676, 60.62025342668806, 59.73410102299282, 54.9641626902989, 50.61563260214669, 44.724671908787315, 49.01525749479021, 58.2376640183585, 59.30647414071219, 57.716663769313264, 56.185023716517854, 56.50769458498274, 56.423388617379324, 54.653675488063264, 58.22248567853655, 55.23511116845267, 55.76778786523001, 57.19192886352539, 63.68859876905169, 57.9645859173366, 69.91637338910783, 40.52040031978062, 0.2510188732828413, 0.08088767781321492, 2.9557447901793887, 3.953830284731729, 0.598180893276419, 0.662683897784778, 0.23585928816880497, 0.1637434871601207, 37.12450647354126, 38.81769214357649, 13.935070855276924, 46.78915194102696, 25.846445866993495, 0.38495115510054995, 0.13111771856035503, 0.116258032353861, 0.030009527557662556, 0.03759819196004953, 0.06961961316743068, 0.05589268010641847, 0.031222894056034938, 0.08246897653277431, 0.09374700207263231, 0.03904046563963805, 0.015765235293656588, 0.015429060207679868, 0.038771056703158786, 0.04130053686510239, 0.021603158907964826, 0.020462036033027937, 0.05478069691785744, 0.05144671510372843, 0.07141046385679926, 0.021525037474930286, 0.033613722372267923, 0.030840699028755938, 0.08454255240836314, 0.023961945104279687, 0.02564438116470618, 0.024998931513567055, 0.05141158056046281, 0.08311222094510283, 0.03172753072742905, 0.006528184990332062, 0.07561365581516709, 0.04924615479207464, 0.08961522592497723, 0.06608790624886751, 0.056880898507578034, 0.08419307294700827, 0.004051627591252327, 0.011047964849110161, 0.031843485576765876, 0.03553734200873545, 0.07259005627461843, 0.06661531794816256, 0.013931030457440232, 0.03646420727350882, 0.03050879362438406, 0.06360350456088781, 0.043103041393416267, 0.050951021523880105, 0.0329750037885138, 0.05739997101149388, 0.04420061928353139, 0.015710168784218173, 0.030139473799083914, 0.03597146871366671, 0.4730060558233942, 47.97299991335188, 68.68898800441197, 25.941582339150564, 53.4211380141122, 61.64371613093785, 15.390650715146746, 1.2982123898608344, 0.7838173263839313, 1.2768805516617638, 2.9835017578942433, 5.287400211606707, 6.387892816747938, 1.1160220461232322, 0.08787030527102095, 25.141914163316997, 93.16954135894775, 69.14449105943952, 86.31334386553083, 69.58632700783866, 69.01679011753627, 68.00723770686558, 70.46806730542863, 65.41716466631208, 67.85637147086007, 72.9227408000401, 75.58433164869035, 72.16461590358189, 69.48569624764579, 67.84792940957206, 64.40120601654053, 67.92795876094273, 67.77297224317277, 65.36953476497105, 63.45446532113211, 60.00070340292794, 58.25369698660714, 55.63539341517857, 54.55131115232195, 50.322873728615896, 48.83827298028128, 47.662328583853586, 46.49785566329956, 45.871750014168875, 44.250019618443076, 46.56812974384853, 48.61658375603812, 44.93810667310442, 49.20689228602818, 47.75832836968558, 55.2901999609811, 55.3071049281529, 61.61802864074707, 60.51270226069859, 63.895696776253835, 59.47756658281599, 63.110765729631694, 58.96649183545794, 61.76609475272042, 43.75497783933367, 50.81632089614868, 68.4806740624564, 60.10459981645857, 63.76479271480015, 60.41990906851632, 58.4783878326416, 60.33063861301967, 58.16324881144932, 56.70358167375837, 60.06079837254116, 58.723992756434846, 58.064490590776714, 54.858907903943745, 53.09777579988752, 48.12117372240339, 43.19814225605556, 44.30883959361485, 45.14975227628435, 45.5887359891619, 44.7986215863909, 45.26130560466221, 44.65399135862078, 53.05670847211565, 59.49319308144705, 61.68528025490897, 58.79482964106968, 59.30830846514021, 62.29955659593855, 62.45089530944824, 56.69372565405709, 50.85721104485648, 47.36873592649187, 50.45477138246809, 60.91300187792097, 59.91062000819615, 59.578468322753906, 58.990928649902344, 59.783474922180176, 58.20680706841605, 56.290097849709646, 59.343514987400596, 59.373795236860005, 57.00838872364589, 59.49126148223877, 66.54481560843331, 61.57390757969448, 69.48646749768938, 43.79090697424752, 0.2235719689301082, 0.19744694578860486, 3.8133338008608137, 1.2534973663943154, 0.404491090880973, 0.7389766382319587, 0.2787462840122836, 0.28456719166466166, 39.25796127319336, 57.056383405412944, 14.374157054083687, 45.022242409842356, 36.78758832386562, 0.6010656984789031, 0.12226491288415023, 0.023442248348146677, 0.06429413107356854, 0.03368809320298689, 0.0056609947600268894, 0.04949701936649425, 0.049345872298415215, 0.09367578303707497, 0.11958440100508076, 0.033209061050521474, 0.06779835053852626, 0.03947995616389172, 0.0028513203474826044, 0.027563369799671427, 0.006569494202267379, 0.02481676691344806, 0.055417440964707305, 0.058908334001898766, 0.04244269111326762, 0.0522720681370369, 0.01722111868938165, 0.050693103577941656, 0.051013616379350424, 0.015465884303141917, 0.1185526613678251, 0.17734282171087606, 0.10276573670229741, 0.10389279015362263, 0.1419711033148425, 0.149973419627973, 0.14045180912528718, 0.09841816606266157, 0.337349073695285, 0.17966179656130926, 0.15552250615188054, 0.1332127090011324, 0.09582267462142877, 0.06467789690941572, 0.10565093545509235, 0.16885413149637835, 0.2322988249361515, 0.08278183545917273, 0.07769242248364858, 0.1360784066574914, 0.14385061817509787, 0.13972257397004537, 0.07752537394740752, 0.21885887826127665, 0.18889217983399118, 0.1695455586803811, 0.1112531784123608, 0.144975303539208, 0.13497215030448778, 0.1060861749574542, 0.636966769184385, 62.581653458731516, 77.48405947004045, 52.945919445582796, 48.84998069490705, 75.55589267185756, 23.655562468937465, 1.725515095250947, 2.140360006264278, 3.4946655290467397, 5.5046056764466424, 17.74982816832406, 14.414476581982203, 0.8090585576636451, 0.08773504610040359, 22.655608994620188, 98.49154881068638, 70.5832336970738, 92.46910735539028, 71.80216312408447, 71.59812232426235, 71.04831136975969, 74.14785412379673, 68.8110886982509, 70.71460328783307, 77.22430106571743, 79.57336888994489, 76.16929353986467, 72.99277864183698, 69.3799307686942, 64.65523910522461, 69.66734300340924, 70.05260671888078, 68.64927904946464, 65.12243597848075, 64.09709726061139, 62.84000832693917, 59.09240709032331, 57.226944310324534, 53.597340856279644, 52.89508989879063, 49.02720839636666, 48.426908356802805, 48.191294942583355, 45.64175769260952, 49.19953761781965, 50.990168298993794, 46.664146900177, 51.79101072038923, 50.7040901184082, 58.67563329424177, 59.56787926810128, 66.0547730582101, 65.5926900591169, 65.494539805821, 61.726302419389995, 63.94670350211007, 59.7669312613351, 64.83679553440639, 44.83561379568917, 53.736680030822754, 72.11379677908761, 62.57294041769845, 66.08055087498256, 64.20688574654716, 59.58074733189174, 62.40894208635603, 60.19944272722517, 60.093586921691895, 60.950848715645925, 59.98988505772182, 61.33209637233189, 57.620066438402446, 55.05406890596662, 49.4304575238909, 45.88942623138428, 47.249150480542866, 48.216412680489675, 49.128898756844656, 46.26662308829171, 49.458941664014546, 46.75593955176217, 58.07293265206473, 63.00103977748326, 66.91384138379777, 59.617697851998464, 60.6654167175293, 64.07629435403007, 66.44774232591901, 58.822942052568706, 54.04706648417881, 51.10150623321533, 54.21204451152256, 63.6931220463344, 63.49676595415388, 62.29300444466727, 61.67702579498291, 63.1866192136492, 62.8419051851545, 60.395493098667686, 63.40918391091483, 60.55179977416992, 59.91335759844099, 62.42236600603376, 69.65006978171212, 62.55911350250244, 71.8527112688337, 45.13578987121582, 0.45139574685267037, 0.16493237550769532, 9.752506307193212, 10.38637135710035, 1.9462329830442155, 2.3594842595713477, 0.8198658834610666, 0.3159596143024308, 53.5323543548584, 50.59301968983242, 24.43226511137826, 59.30186748504639, 45.773933274405344, 0.5307661592960358, 0.24497402193290846, 0.19588987076921122, 0.13533351091401918, 0.18007843063345977, 0.14943714626133442, 0.15523397949125084, 0.15027407849473612, 0.18194228490548475, 0.2649308496287891, 0.2438168211707047, 0.13842630067041942, 0.18476847825305803, 0.10465678665786982, 0.16042165112282547, 0.06769435826156821, 0.14052051758127554, 0.1680670715868473, 0.18052601947316102, 0.1867798324674368, 0.09683785800422941, 0.16604482010006905, 0.17995796352624893, 0.16508814000657626, 0.11829499447984354], [0.04043425459946905, 0.04775873478502035, 0.009707574050740471, 0.06200904904731682, 0.03386236474450145, 0.030828855200005428, 0.047312360523002486, 0.05801688826509884, 0.0028593308774621357, 0.021437297808006406, 0.022306277250338877, 0.13825916392462595, 0.02010328778331833, 0.02571206333647881, 0.02884304104372859, 0.012340851410824274, 0.0026889312263977316, 0.013067151902110448, 0.06080175204468625, 0.03232879078547869, 0.05737755899982793, 0.002766591467661783, 0.02049338265455195, 0.013613000246030944, 0.08007292688957282, 0.063376792440457, 0.10618571604468993, 0.06289159919002227, 0.07699644911502089, 0.14077171124517918, 0.3529575504362583, 6.679202990872519, 64.65931074959892, 50.54294402258736, 24.96396906035287, 40.43467691966465, 52.91670227050781, 1.3149563542434146, 0.283295779888119, 1.927626141480037, 1.4714859149285724, 2.1859501770564487, 4.755216836929321, 0.371060240481581, 0.17382022073226316, 0.03196427159543548, 29.280327251979283, 88.9226495197841, 66.23967157091413, 76.67496953691754, 70.75106743403843, 66.98396955217633, 61.78055395398821, 66.44427517482212, 71.02904401506696, 72.02012811388288, 69.29283509935651, 73.36218656812395, 68.2148985181536, 64.7328018460955, 64.76647976466587, 69.40923827035087, 67.38629804338727, 64.17878723144531, 61.8644117627825, 54.78143201555525, 56.470726694379536, 57.99880232129778, 55.658715043749126, 47.0671980040414, 48.43932131358555, 44.807525702885215, 45.01843479701451, 44.889205251421245, 45.56938873018537, 44.47207014901297, 45.999958174569265, 43.26387916292463, 45.861504895346506, 44.07361875261579, 51.05137498038155, 53.96306276321411, 59.618135588509695, 58.207956995282856, 62.31584317343575, 60.9400303704398, 65.19358553205217, 51.96378810065133, 60.80082321166992, 37.0206413269043, 42.46987724304199, 67.2288796561105, 54.99657951082502, 66.61504799979073, 53.06847872052874, 58.570520945957725, 52.17466592788696, 56.664300033024375, 56.928039755140034, 57.008843830653596, 54.533384799957275, 54.76667751584734, 51.42321825027466, 50.17222983496529, 41.86252130780901, 43.87411860057286, 42.0965644291469, 43.92214454923357, 41.36075714656285, 43.90941544941494, 42.29493202481951, 44.23697437558855, 49.44842209134783, 60.28729575020926, 57.2265100479126, 61.257847922188894, 59.870647021702354, 58.156227656773154, 59.26845359802246, 58.854403495788574, 53.0928703716823, 46.87765462057931, 51.34603418622698, 62.38362285069057, 60.8892251423427, 61.36447497776577, 56.723245075770784, 59.31181035723005, 58.464088439941406, 61.9509585244315, 55.57838691983904, 56.503723689488, 59.23465061187744, 58.30954660688128, 61.65691770826067, 65.35167789459229, 53.050819873809814, 0.8871544099279812, 0.10240663561437811, 0.5568507281797273, 1.5081119324479784, 0.310799952596426, 1.069919337119375, 0.5686008919562612, 0.1844022050499916, 15.833761657987322, 51.2297282900129, 14.86440805026463, 29.62066044126238, 55.02946533475603, 15.930937426430837, 0.6513071996825082, 0.09843008792293922, 0.10365379654935428, 0.01602228980378381, 0.07001547049731016, 0.040732782866273604, 0.01861038351697581, 0.07713492454162665, 0.012713170360906847, 0.01983575160349054, 0.0793182331004313, 0.00462106944594, 0.007728855674421149, 0.015911642794630358, 0.03664378495886922, 0.04928163878087487, 0.04561328848025628, 0.056531381726797135, 0.037645404426647086, 0.02206002501770854, 0.04658067924901843, 0.02761347621812352, 0.028356405906379223, 0.0445163925178349, 0.07623743305781058, 0.017583095069442476, 0.042792194323348146, 0.017641547468623946, 0.03860616251560194, 0.03275784544114556, 0.014378258825412818, 0.0474012112910194, 0.017052138024674993, 0.03659641303654228, 0.047958872081445794, 0.0282789036365492, 0.06354084185191564, 0.050570699253252575, 0.03624209562050445, 0.03356856247410178, 0.046695083645837646, 0.033598234810467274, 0.02406538267886, 0.057098185776599815, 0.02713664760813117, 0.03802900402141469, 0.030994662017162358, 0.06980997616691248, 0.027140650964741195, 0.027784979336762, 0.009888170386797615, 0.11065575546984162, 0.026507618504443338, 0.07134527021220752, 0.033022681051599126, 0.30728606400745256, 8.521239485059466, 79.93991415841239, 45.36986773354666, 27.711615085601807, 58.426589012145996, 52.072732380458284, 3.6372236737183163, 0.3330099236752306, 0.37799663256321636, 1.4118950154100145, 1.9822157493659427, 4.098239038671766, 1.3190008572169711, 0.39693164080381393, 0.017726415236081396, 38.458105495997835, 94.26307664598737, 69.55128724234444, 83.03980432237897, 72.73539652143205, 69.6414053780692, 64.18973759242466, 71.35300377437046, 73.45582049233573, 73.93104948316301, 70.972291128976, 74.29920673370361, 69.87062644958496, 65.08071899414062, 66.44884708949498, 69.94015707288469, 70.89288016727993, 65.74709987640381, 62.245256423950195, 59.40072645459856, 60.31509549277169, 60.126695087977815, 57.716066224234446, 49.59381662096296, 50.754617418561665, 47.173790318625315, 46.274801118033274, 47.50624425070626, 47.691688196999685, 46.09982115881783, 48.62618269239153, 45.057921409606934, 47.705862522125244, 46.09391519001552, 54.5081524167742, 56.76251629420689, 61.93095466068813, 59.55005019051688, 63.454083170209614, 61.65891184125628, 66.62461566925049, 54.435703550066265, 62.100386483328684, 37.83036354609898, 43.96418115070888, 67.4178776059832, 58.05447823660714, 66.23844173976353, 57.60799046925136, 60.003969056265696, 56.70196621758597, 57.93624768938337, 58.734477588108604, 59.08843272072928, 56.16097252709525, 57.31463057654244, 52.13184070587158, 50.26483195168631, 44.1524703843253, 46.114540917532786, 44.94156340190342, 46.970541613442556, 43.277608803340364, 44.55517407826015, 44.126623085566926, 44.33034426825387, 52.63090896606445, 61.15024811880929, 59.30395194462368, 61.60862077985491, 60.311927114214214, 61.89793682098389, 58.826249395098, 61.29338795798165, 54.44337088721139, 47.77266597747803, 54.00121184757778, 63.998342514038086, 62.84592124394008, 63.509119851248606, 58.10297666277204, 59.9009689603533, 60.03714670453753, 63.98245198386056, 57.99120099203927, 58.45850903647286, 64.03459126608712, 61.83786964416504, 61.74993324279785, 65.33292470659528, 56.49640376227242, 0.9555561138050896, 0.14220042100974492, 1.1401798469679696, 1.0081726504223687, 0.15877486020326614, 0.2888322728020804, 0.21102608713720525, 0.29979517310857773, 18.558742659432546, 67.53318296160016, 25.17956645148141, 20.72482098851885, 62.182632310049875, 19.12538388797215, 0.5320085840565818, 0.014188090904748865, 0.029548547829368284, 0.02756392619838672, 0.05997296901685851, 0.020906707172148993, 0.043358828739396164, 0.06433862261474133, 0.009166646782042724, 0.023643973416515758, 0.01938899905819978, 0.03429618610867432, 0.02977537869342736, 0.03178532494764243, 0.05343805253505707, 0.011860322240473968, 0.010949101448724312, 0.030201183166354895, 0.08266773301043681, 0.05333407043612429, 0.05159275958846722, 0.02613790343249483, 0.05663028499111533, 0.023218357237055898, 0.04081346067999091, 0.2121541244643075, 0.17263978693102086, 0.13320496013121946, 0.15834807524723665, 0.1081457119435072, 0.1402446659547942, 0.15385651269129344, 0.16549906081386975, 0.07608682542507138, 0.17163893420781406, 0.08668332360684872, 0.15776526794901916, 0.14956989485238278, 0.1747415762926851, 0.08630679095430033, 0.1739951063479696, 0.20060572986091885, 0.16773639433085918, 0.12879103555211, 0.08196389542094298, 0.1506487112492323, 0.11401235285614218, 0.19124744273722172, 0.13079641865832464, 0.15352455978947027, 0.10812613620821919, 0.15680211463144847, 0.15985667572489806, 0.20567085806812557, 0.57356858253479, 0.5273194728153092, 11.580980351993016, 90.05220426831926, 63.3002153124128, 44.10772398539952, 57.32967342649187, 76.22024468013218, 4.894100035939898, 0.767603759254728, 5.244559790406909, 5.0746724264962335, 8.004497613225665, 11.805601716041565, 1.5560234529631478, 0.367830685206822, 0.11077319631086928, 36.164355754852295, 96.57404054914201, 73.16737992422921, 84.78159958975655, 76.99062619890485, 74.15461472102574, 68.07136957986015, 73.22116592952183, 76.80991050175258, 78.83216285705566, 72.66685254233224, 76.09419046129499, 70.97973959786552, 67.14293043954032, 66.7184510912214, 72.51128932407924, 73.36165850503104, 67.26001453399658, 67.7871743610927, 61.67801938738142, 61.80790206364223, 64.19336455208915, 62.33697959354946, 53.07698678970337, 53.9193377494812, 50.72604295185634, 50.6558244568961, 50.16270385469709, 50.68035159792219, 49.29586049488613, 52.24089615685599, 46.21122510092599, 50.573071411677766, 49.65624271120344, 55.831787722451345, 60.22502599443708, 64.49412427629743, 61.62425422668457, 67.63651657104492, 66.52595819745744, 68.75423158918107, 54.56209823063442, 63.307677677699495, 41.62651532036917, 44.31286607469831, 69.95571408952985, 60.1055725642613, 69.89557048252651, 57.119525160108296, 63.40700912475586, 58.07004567555019, 60.790157726832796, 59.245732988630024, 60.90083558218819, 57.75356912612915, 59.923856326511924, 56.130171162741526, 54.95835747037615, 46.692328793661936, 49.57968051092965, 47.75520168031965, 49.91020284380232, 46.04948493412563, 48.81680999483381, 46.607689312526155, 48.157193183898926, 54.08672680173601, 63.22108227866036, 61.93531812940325, 65.5172187260219, 63.42268426077706, 62.75130762372698, 61.36727510179792, 65.29982348850795, 58.07440914426531, 50.97428124291556, 57.09812470844814, 67.67219557080949, 64.94233172280448, 67.02069078172956, 60.21531936100551, 62.75093936920166, 63.048280579703196, 66.79224096025739, 59.88284805842808, 62.514165605817524, 67.12467752184186, 63.77798039572579, 64.4380384172712, 68.86224133627755, 56.27634736469814, 1.6699883490800858, 0.29678785162312643, 1.6490678659507205, 6.868335996355329, 2.2748208940029144, 3.2179750161511556, 1.8128939036812102, 0.6738981817449842, 26.653873443603516, 67.48606722695487, 23.524163348334177, 43.89708587101528, 70.37853976658413, 26.92167959894453, 0.898130283824035, 0.16419868916273117, 0.16900490197752202, 0.07755725152258362, 0.12391909983541284, 0.13074897548982076, 0.10727901237883739, 0.3066045977175236, 0.07154323958924838, 0.2148590771747487, 0.16523931760873112, 0.08304081191974026, 0.14651146610932692, 0.08734653051942587, 0.19189811710800442, 0.1459501548005002, 0.1372910708721195, 0.11151104207549777, 0.14850485271641187, 0.09631018846162728, 0.1407318948102849, 0.1501590803797756, 0.13185044138559274, 0.09701661126954214, 0.2113660467522485], [0.05364241710464869, 0.015333844781188028, 0.056169522394027026, 0.03672714637858527, 0.012768000231257506, 0.020877674355038574, 0.04249931486057384, 0.020112834771030715, 0.015635957409228598, 0.02695482057918395, 0.018420673607449447, 0.012399114668369293, 0.042158194950648716, 0.06149468557643039, 0.062385025301149914, 0.049144805409014225, 0.03647861935730491, 0.08245343129549708, 0.045416031564985, 0.05361003741355879, 0.04788006702437997, 0.013095942142951702, 0.047201871273240874, 0.05089874040069325, 0.011895103097361113, 0.02303942585630076, 0.03912658869688, 0.01839349149460239, 0.04277783652235355, 0.06928232019501072, 0.03241482563316822, 0.27190779096313883, 25.881678444998606, 66.53023133959088, 44.10828331538609, 25.15891293116978, 56.901198863983154, 22.294773408344813, 0.22941306978464127, 0.6154657857758659, 1.5858444699219294, 2.1284948715141843, 2.912136810166495, 1.7223792863743645, 0.14745457550244673, 0.3239871178354536, 0.06513738046799387, 28.375220162527903, 83.32222080230713, 71.57646478925432, 73.1082785470145, 69.97128500257219, 69.33013302939278, 67.64062295641217, 66.79506192888532, 74.80957276480538, 75.31470680236816, 71.26106521061489, 65.32557351248605, 68.56526143210274, 67.46698747362409, 71.6058417728969, 69.66031837463379, 64.7433978489467, 60.92547389439174, 60.56568922315325, 57.528558662959504, 54.59047467367989, 51.08015441894531, 47.79786709376744, 47.02255582809448, 48.066192626953125, 47.01825141906738, 47.155370644160676, 47.86601849964687, 45.276813983917236, 46.56933178220476, 45.829706464494976, 47.412645067487446, 45.702029841286794, 52.42600311551775, 53.023704528808594, 57.434643336704795, 57.71922765459333, 63.18767533983503, 57.875416210719514, 65.90743650708879, 57.18962206159319, 64.65260573795864, 33.91700260979788, 37.78371334075928, 72.63234083993095, 56.79243523733956, 60.702346393040244, 50.35419968196324, 54.524046421051025, 51.110288756234304, 56.05372360774449, 50.38118301119123, 54.010796887534006, 52.93417004176548, 52.94209793635777, 47.16605697359358, 43.73847586768014, 42.84215130124773, 43.1060334614345, 43.09890808377947, 45.38502870287214, 42.486427852085654, 45.132552010672434, 42.395455087934224, 43.47136279514858, 48.15640803745815, 61.75536673409598, 56.43679864065987, 62.02661745888846, 60.59710202898298, 60.809091567993164, 60.80363723209926, 60.78493268149239, 56.42341988427298, 48.08062750952584, 53.80954926354544, 62.69345692225865, 61.29953711373465, 61.26927770887102, 62.575149944850374, 65.38084643227714, 57.87823370524815, 59.23403917040144, 61.20516668047224, 59.94879341125488, 52.458454677036826, 68.35994911193848, 59.276395389011924, 69.77900055476597, 5.731763132980891, 0.1181254828614848, 0.1544740202703646, 0.8664768966180938, 1.0224682433264596, 0.23825503247124807, 0.019114178804946796, 0.28126188474042074, 5.320365071296692, 50.2666072164263, 39.81119768960135, 49.85922391074044, 43.50537075315203, 46.05240665163313, 1.6641971341201236, 0.3648908372436251, 0.05077003587835601, 0.05530827146555696, 0.03813646021964295, 0.04880130723384874, 0.03613633575982281, 0.012823720678820141, 0.0675885339400598, 0.08254339825361967, 0.01921974358681057, 0.040405013132840395, 0.01795256756512182, 0.03908488932730896, 0.033277643977531364, 0.015335681914751018, 0.01532026390278978, 0.07126601732202939, 0.01749428840620177, 0.027609421971387098, 0.0473944870089846, 0.05166152911260724, 0.021724078937300613, 0.05162867444700428, 0.0830985281084265, 0.07585280548248972, 0.015140533547050186, 0.06752218000058617, 0.033992931845464876, 0.0774301958403417, 0.0367840585032744, 0.06201161390968731, 0.012455661232317132, 0.032867686689964364, 0.018440946537469114, 0.018464450990515094, 0.019360235958759273, 0.023938099687386836, 0.024835720092856457, 0.07839138819170849, 0.041438479641718526, 0.030367654947830097, 0.08167310245335102, 0.04640294039355857, 0.019299367974911417, 0.006194120148263339, 0.011451794117289995, 0.02674962310785694, 0.03373108518176845, 0.06006273241447551, 0.06659982699368681, 0.012348095620317119, 0.04987489551837955, 0.005171164146824074, 0.020365300688094327, 0.039285321786467514, 0.03795423285503473, 0.2968338020145893, 33.39229897090367, 76.23796953473772, 30.824946539742605, 38.951660360608784, 76.40881184169224, 24.5347284589495, 0.08729752672037908, 0.28670308419636314, 0.6899338098508971, 1.8873613306454249, 2.5679397710732053, 1.7379900429930006, 0.3068145364522934, 0.16262176020869187, 0.03211445514378803, 39.60677126475743, 89.78397600991386, 71.16541630881173, 78.76079096112932, 73.84232098715646, 72.70698533739362, 67.18785749162946, 71.6893869127546, 77.26119600023542, 79.59255981445312, 71.32671179090227, 66.98700591496059, 70.27240603310722, 69.23060703277588, 72.60335295540946, 70.6137501852853, 67.33989797319684, 64.46373285566057, 60.70372213636126, 60.612950869968955, 56.98350027629307, 54.320769923073904, 49.92937987191336, 50.80868482589722, 50.03240081242153, 49.188357966286794, 47.90510559082031, 48.8777665410723, 46.914236886160715, 47.020902156829834, 47.64600031716483, 50.16091121946062, 48.143248149326865, 54.41333729880196, 54.776165281023296, 59.34393187931606, 59.174465315682546, 63.874310220990864, 58.86588191986084, 66.49906866891044, 57.4837532043457, 65.99415697370256, 35.79441281727382, 40.44705860955374, 73.13737760271344, 57.43646376473563, 65.57195663452148, 52.42008672441755, 58.50000367845808, 51.75923660823277, 57.43532773426601, 52.554968629564556, 56.814697265625, 54.16503994805472, 55.7018529347011, 49.75659901755196, 46.74286304201399, 44.537185192108154, 45.79056378773281, 45.020852770124165, 46.7907326562064, 44.837805952344624, 47.50216218403408, 45.02922534942627, 46.316031728472026, 50.56869404656546, 64.2583371571132, 59.03001226697649, 63.261235918317524, 58.76927416665213, 62.098079681396484, 60.316971506391255, 62.05155454363142, 58.79988098144531, 51.07567630495344, 55.54874243055071, 65.9952756336757, 61.70033005305699, 61.16833427974156, 63.434162684849326, 67.82382610866001, 59.99560342516218, 60.25613307952881, 61.94876289367676, 64.91782542637416, 54.87358249936785, 70.29573113577706, 59.253132820129395, 71.54140417916435, 6.428147639547076, 0.1588213805641447, 0.5214507420148168, 1.0474652562822615, 0.46047405685697285, 0.1695179830172232, 0.19736511446535587, 0.3697386442550591, 7.97808403628213, 57.893648283822195, 48.2512856892177, 33.175602027348106, 41.54108721869332, 55.83438982282366, 2.9892713682992116, 0.3573422980095659, 0.012669300527444907, 0.06099088689578431, 0.04329326529321926, 0.032102906477770636, 0.028122479262362634, 0.03060394459004913, 0.05185428734070488, 0.0386842992156744, 0.027999966372070566, 0.01869541752551283, 0.035381458766226254, 0.07008676417171955, 0.028500251937657595, 0.006030602538625577, 0.02728557586669922, 0.00985737083413239, 0.029409906161682944, 0.01801682822406292, 0.019164578689794456, 0.08565775185291256, 0.026334444493321434, 0.047651007172784636, 0.042709504653300555, 0.07374306369040694, 0.15046326762863568, 0.1514580813901765, 0.17149405341063226, 0.12570211344531604, 0.20016769479428018, 0.17923133394547872, 0.08953230216034821, 0.0771684916689992, 0.06695742173386471, 0.13055111467838287, 0.07224049538906131, 0.06688656910721745, 0.11457750467317444, 0.20074759796261787, 0.11559793991701943, 0.07836715092084237, 0.14208772991384777, 0.31278385328395025, 0.13882084164236272, 0.11077479086816311, 0.1035852577271206, 0.11270327560071434, 0.18714974261820316, 0.15254970852817806, 0.17285522179944174, 0.14915665345532553, 0.1288192490381854, 0.11575240162866456, 0.11995561394308295, 0.1263856424817017, 0.15599452225225313, 0.35810771265200203, 44.89641053336007, 86.66460309709821, 62.26321751730782, 43.374237401144846, 76.64437661852155, 36.70845529011318, 0.3582038203520434, 1.9926966726779938, 5.718363966260638, 5.400961135114942, 9.16636756488255, 7.652412414550781, 0.23542451007025583, 0.31247007154992645, 0.09862056627337422, 37.337885652269634, 96.1069826398577, 76.83304800306047, 80.47071484157017, 75.39418724605015, 76.13841574532645, 72.58443301064628, 70.95318358285087, 79.51538617270333, 80.86490004403251, 72.38970279693604, 70.52771064213344, 72.55623722076416, 67.76499571119035, 73.51885454995292, 76.03933443341936, 72.53252301897321, 66.74698039463588, 64.57889229910714, 64.87215491703579, 61.044816153390066, 57.785051413944785, 53.31455264772688, 53.57005180631365, 54.37287793840681, 52.304472173963276, 50.79262753895351, 53.3867826461792, 49.92631571633475, 51.11025401524135, 50.40986170087542, 54.00398070471627, 50.40279885700771, 56.624598026275635, 57.229216371263774, 61.72240447998047, 62.80350249154227, 66.48434543609619, 63.162870270865305, 69.81620815822056, 62.18079103742327, 68.41276236942836, 37.85121856416975, 43.424132415226524, 76.55311897822789, 62.248667989458355, 66.24551500592912, 55.740623882838655, 60.20083931514195, 56.78575801849365, 59.553420066833496, 56.40828323364258, 59.27911908285958, 55.8076114654541, 58.711430413382395, 53.047415256500244, 49.26417670931135, 48.121260574885774, 48.559695380074636, 47.896607943943565, 50.62060056413923, 47.99012027468, 50.64672231674194, 48.02506971359253, 48.72875199999128, 54.80942630767822, 69.5599308013916, 61.73820468357631, 65.45782552446637, 60.24058301108224, 64.42860276358468, 66.89074557168144, 64.63371358598981, 61.83617428370884, 53.13600826263428, 58.909773690359934, 68.26011044638497, 64.09211540222168, 63.70371804918562, 67.23700904846191, 70.36177376338414, 63.084098543439595, 63.896030289786204, 66.01644679478237, 66.97731317792619, 57.37411410467965, 74.88386985233852, 61.10040174211775, 74.44458389282227, 7.699826921735491, 0.20921918909464562, 0.6346002561705453, 6.53854409285954, 3.480683365038463, 0.7494791118162019, 0.3191581198147365, 0.6169884726405144, 9.910444940839495, 67.60012190682548, 47.465843949999126, 57.65918827056885, 53.28262220110212, 66.67097405024937, 4.661528195653643, 0.566303969493934, 0.13558769013200486, 0.15489963814616203, 0.18269079045525619, 0.14391203916498593, 0.12100610828825406, 0.08090892952999898, 0.15441975103957312, 0.2171009297349623, 0.1154861037752458, 0.1775780562311411, 0.13607700887535298, 0.2389640472829342, 0.17399548632758005, 0.12061774198498044, 0.12165606341191701, 0.17296305458460534, 0.0799649516120553, 0.12629815217639717, 0.15424861093716963, 0.15932722842054708, 0.0853059585871441, 0.10214873802449022, 0.10914437299860374, 0.1404368949255773], [0.006149920377148581, 0.03500624247161405, 0.026874672022781203, 0.02359115794700171, 0.03311832734782781, 0.05849582542266164, 0.0175730680182044, 0.04026356233017785, 0.030359624485884393, 0.04568550496229103, 0.011220095612640892, 0.03342894371598959, 0.07522675514753376, 0.048675079364329576, 0.05351298315716641, 0.046384799759835005, 0.02301226240316672, 0.026446604635566473, 0.038383399468979666, 0.041121138991521936, 0.024304245665137256, 0.07681060515876327, 0.027276546261938553, 0.020693502987601926, 0.09397908819041081, 0.03352484107017517, 0.04130139521190098, 0.10584135273737566, 0.0953866955158966, 0.033429106564394066, 0.009138702165468462, 0.1024729081296495, 1.1107802816799708, 57.25457729612078, 55.73362009865897, 26.17500533376421, 32.50723048618862, 66.05168110983712, 4.570379555225372, 0.1918003402118172, 0.43445397594145363, 0.24183186196855136, 1.527553100671087, 1.4342380336352756, 1.1922713603292192, 0.0455344121770135, 0.2342019256736551, 0.08120586323950972, 27.483999047960552, 86.10088879721505, 72.61094733646938, 80.1445038659232, 65.50354467119489, 70.22872270856584, 76.7318752833775, 75.62035805838448, 70.50224549429757, 68.72861358097622, 69.74173041752407, 69.94842542920793, 70.74441105978829, 70.83691937582833, 65.30134514399937, 65.45722797938755, 62.66945089612688, 57.21225929260254, 56.673211097717285, 53.63843597684588, 51.02515942709786, 46.53723110471453, 49.366815498897004, 45.86701134272984, 48.09104980741228, 43.92067847933088, 49.46072040285383, 44.493595668247764, 47.68526806150164, 42.93789400373186, 48.88438817432949, 47.07962485722133, 51.17294413702828, 49.507176058632986, 54.56219550541469, 51.954001562935964, 60.65072127750942, 57.87812948226929, 68.83788095201764, 57.04475212097168, 66.33073466164726, 37.85582174573626, 36.91495227813721, 72.51991898672921, 53.01688139779227, 60.404101916721885, 48.30929619925362, 50.52884612764631, 49.25505372456142, 53.209409032549175, 51.16576664788382, 51.67988470622471, 49.897550174168174, 48.041665485927034, 44.30527169363839, 44.74676023210798, 43.5797164780753, 44.53252642495291, 45.63381242752075, 44.76889024462019, 43.38273504802159, 42.95390265328543, 43.44601924078805, 43.946654319763184, 47.12237364905221, 58.939254896981375, 61.76030690329415, 58.445634024483816, 65.05158519744873, 59.87949207850865, 62.001249585832866, 63.402993065970286, 63.712917464120046, 54.03018236160278, 53.761471203395296, 60.29102693285261, 63.691426685878206, 63.64391490391323, 62.026520184108186, 62.132980482918875, 65.85501234872001, 63.83569213322231, 57.157632555280415, 56.17994458334786, 65.7836057118007, 53.4516510282244, 68.80763544355119, 18.979718378611974, 0.5590586811304092, 0.3148527608386108, 0.6742426604032516, 2.0995436821665083, 0.2656556064529078, 0.11567469579832894, 0.02747976071467357, 2.2546667754650116, 45.23421457835606, 50.27254792622158, 87.05116612570626, 57.395326954977854, 44.560492924281526, 32.70133188792637, 0.6849049968378884, 0.05697650409170559, 0.07711662445217371, 0.023782735524166907, 0.022016300221106837, 0.08288184473557131, 0.060198147648147175, 0.06450192563767944, 0.04964604601264, 0.03938989760354161, 0.05069268967158028, 0.128324244171381, 0.07274256380540983, 0.025598276406526566, 0.05220150049509747, 0.04960512017299022, 0.019969511211716702, 0.06363807592008795, 0.012877902548227991, 0.05975208551223789, 0.008522730620045747, 0.047222529271883626, 0.03100704528125269, 0.03887737635523081, 0.022891907254233956, 0.04271217808127403, 0.03203940577805042, 0.07513167882072073, 0.006952838922318603, 0.05318253321040954, 0.027029093022325208, 0.019222104888675467, 0.01987749507783779, 0.02369169139170221, 0.032339986613286395, 0.10428059327283076, 0.03811395660574947, 0.03337173982124243, 0.043369963499052186, 0.027839701489678452, 0.08468957059085369, 0.04716281479756747, 0.14846985388014997, 0.05140413363863315, 0.02861333658386554, 0.020708729313420396, 0.025737801866073693, 0.07251927150147301, 0.0027169135864824057, 0.03715624513902834, 0.06358340635363545, 0.026874563457178216, 0.047819073511553664, 0.09268397518566676, 0.13986388567302907, 0.04581261153465935, 0.09508905612996646, 0.1552936362900904, 3.028852650097438, 72.31737204960415, 58.01891040802002, 22.846165078026907, 59.0768153326852, 67.94648960658482, 6.6353559494018555, 0.3734776707632201, 0.176736998504826, 0.3891966130052294, 0.5879317032439368, 1.1509999292237418, 1.4121475390025546, 0.10433640956346478, 0.24695721694401332, 0.0593478957723294, 36.106011731284006, 94.30899729047502, 77.09655148642403, 81.30712509155273, 66.2828129359654, 74.83126504080636, 77.69404097965786, 75.88206890651158, 70.605363709586, 71.39588110787528, 72.14190224238804, 69.49543762207031, 69.62757846287319, 72.18298694065639, 68.20570605141776, 66.48317813873291, 64.48736367906842, 60.4636618750436, 59.13656289236886, 55.746627126421245, 55.17794486454555, 48.00982883998326, 51.43027067184448, 47.35252577917916, 50.91794177464077, 45.990011828286306, 51.56440911974226, 47.65625933238438, 48.33149569375174, 45.41816118785313, 50.72626182011196, 48.553633076804026, 53.55885478428432, 52.54138490131923, 57.59141206741333, 53.706865310668945, 61.96685600280762, 59.38614913395473, 71.35196154458183, 57.91014330727713, 66.91384138379777, 39.17483302525112, 36.37710959570748, 71.72394725254604, 55.255476338522776, 62.4536954334804, 49.451600892203196, 53.73628050940377, 52.98444720676967, 56.37002992630005, 53.82035023825509, 54.44365923745291, 52.47465787615095, 49.30390650885445, 48.09275559016636, 45.71031209400722, 45.047384466443745, 48.48389400754656, 48.97070564542498, 45.89222288131714, 45.182047503335134, 44.98551770618984, 45.46659360613142, 46.65134137017386, 50.45334005355835, 60.25616782052176, 63.57289041791643, 62.76869896480015, 63.92166914258684, 60.67276096343994, 64.50107942308698, 62.984753199986045, 62.82501411437988, 53.56343017305647, 55.737750802721294, 61.542057037353516, 65.08524921962193, 65.93699414389474, 63.48389094216483, 62.191206387111116, 67.53255762372697, 67.69581249782017, 61.907289096287315, 58.23573241915022, 69.63085801260812, 57.216438634055, 69.88049983978271, 22.324232033320836, 0.435119917350156, 0.7892907155411584, 1.110243859035628, 0.8445660237755094, 0.21672279573976994, 0.049049956391432455, 0.07395013900739805, 4.659908831119537, 47.63755478177752, 57.0595691544669, 76.32953984396798, 52.861373765128, 51.09727825437273, 39.90305287497384, 0.7092654896633965, 0.02700481503935797, 0.05586630205756851, 0.04959619065214481, 0.006619494599622807, 0.08448916527309588, 0.044296896617327414, 0.06812216102012567, 0.034906820128006597, 0.06510947910802704, 0.022775833661268865, 0.08234451963965382, 0.07666170064892087, 0.03779522156608956, 0.06133069044777325, 0.08338120579719543, 0.013068117966343249, 0.09192746292267527, 0.0714946361258626, 0.09489158208348922, 0.021306337156732167, 0.03955908013241632, 0.03865444706752896, 0.03268265697572913, 0.06108056886919907, 0.025987324637493918, 0.16721920136894497, 0.1575572019709008, 0.14126451765852316, 0.11962090618908405, 0.14016531806971344, 0.16011538755680832, 0.10509374285382883, 0.0774491201820118, 0.12373442974473749, 0.11514807119965553, 0.12787950517875807, 0.14629281498491764, 0.13598242109375341, 0.25168853306344574, 0.1570206843316555, 0.11419299244880676, 0.2032471988350153, 0.10527143760451249, 0.14994644107563154, 0.14132355020514556, 0.3078133671411446, 0.20537584461271763, 0.12090905063918658, 0.09923846061740603, 0.1815469568329198, 0.1306759108390127, 0.14090722825910362, 0.19917186323021138, 0.32430499792099, 0.12148003785737924, 0.12549140118062496, 0.31861901017171995, 3.7810859084129333, 87.19076933179582, 72.63424464634487, 43.8595621245248, 49.67266477857317, 87.58352320534843, 10.224671142441885, 0.8833736128040722, 1.050260060599872, 4.330102596964155, 2.6503058884825026, 5.657853841781616, 6.392552018165588, 0.1715298936303173, 0.32727833837270737, 0.534502173108714, 34.97095053536551, 98.90147168295724, 79.19277436392647, 87.61877141680036, 69.89632783617292, 76.31667872837612, 81.28013828822544, 80.7174106325422, 72.46798120226178, 70.53645147596086, 73.7852623803275, 70.09163475036621, 73.57118838174003, 73.50690364837646, 69.18966824667794, 71.12346308571952, 67.86035973685128, 63.34869984218052, 60.98179599217006, 59.02375194004604, 57.091200828552246, 51.18244232450213, 54.72833040782383, 50.28653812408447, 54.00789254052298, 47.80364799499512, 55.96305309023176, 50.77837678364345, 51.95575598308018, 48.131776673453196, 56.223905835832866, 52.73387084688459, 55.9068386895316, 57.10613250732422, 59.447585105895996, 56.657139914376394, 65.70773138318742, 62.31724670955113, 74.06499685559953, 61.487680435180664, 66.45322445460728, 41.04163680757795, 38.738319396972656, 74.75955963134766, 58.366167477199006, 65.28775446755546, 51.65486076899937, 55.10503394263131, 56.21494265965053, 58.01743738991873, 57.16996908187866, 57.13249397277832, 56.045601163591655, 51.04091099330357, 51.56670897347586, 49.82684530530657, 47.64827585220337, 51.55279867989676, 52.459524699619834, 49.39408370426723, 49.17753962108067, 48.49042878832136, 48.74623366764614, 48.55914994648525, 52.152087756565635, 63.83014052254813, 67.83151081630162, 67.760653087071, 66.58504567827497, 62.28415938786098, 65.92116614750454, 67.26729624611991, 68.9436811719622, 57.92260490145002, 56.338811670030864, 64.51524680001395, 66.73481409890312, 67.65178871154785, 65.02534879956926, 64.30424390520368, 69.99258123125348, 69.29204300471714, 64.41802065713065, 62.64554214477539, 73.33487319946289, 59.97873319898333, 71.02242238180978, 25.047870295388357, 0.7436158635786602, 1.5488069887672151, 1.6431019689355577, 4.526157745293208, 0.7165187033159393, 0.32993884703942705, 0.13761374141488755, 4.717419505119324, 62.66847814832415, 61.52124718257359, 86.81202997480119, 67.55579934801374, 60.85503305707659, 46.191631180899485, 0.8387929392712457, 0.13414296694099903, 0.12834320243980202, 0.06921633266444717, 0.09273219188409192, 0.15662602122340882, 0.19856228094015801, 0.18535186909139156, 0.12151161687714712, 0.21938535358224595, 0.10982586642993347, 0.20410333360944474, 0.1506231033376285, 0.11530633270740509, 0.19924758773829254, 0.15614707049514565, 0.07618170497672898, 0.21577154392642633, 0.17673726991883346, 0.17196155046778067, 0.07879308770809855, 0.12162786349654198, 0.17341016844979354, 0.1331482074622597, 0.18877711386552878, 0.08644741733691522], [0.061089450892593176, 0.04343005795297878, 0.039888122119009495, 0.01863248849154583, 0.022626593276592236, 0.017298810949016894, 0.050368526351771185, 0.050523703917860985, 0.09570134577474423, 0.0783238128892013, 0.044505956649248085, 0.040439716806369166, 0.027989320157627975, 0.026139555665265237, 0.013498784990848174, 0.013800733074146723, 0.05080770474991628, 0.024162984852279936, 0.04472207005268761, 0.022835339486066784, 0.07175552605518273, 0.04296042011784656, 0.02387665325243558, 0.07503594431493964, 0.04632503778806754, 0.026566036976873875, 0.08503685838409833, 0.18518139395330632, 0.13337791870747293, 0.12361667677760124, 0.21342835894652776, 0.18630815563457354, 0.5945960570658956, 16.285375458853586, 68.85769026620048, 46.75608893803188, 24.23903397151402, 49.62842559814453, 50.897128445761545, 1.6814434315477098, 0.17419333356831754, 1.1051005635942732, 0.5187818737966674, 0.5669100912553924, 1.8285604630197798, 0.8249391540884972, 0.4886654498321669, 0.06920925554420267, 0.14167581844542707, 40.01349449157715, 88.25346851348877, 68.14790398733956, 84.0776914869036, 66.85265554700578, 71.64231286730084, 75.38370241437639, 80.33310576847622, 71.98009259360177, 70.02256965637207, 71.20338126591274, 67.35293279375348, 68.22356292179653, 68.79815810067313, 65.6314332144601, 63.23002461024693, 56.83022996357509, 53.10099976403372, 49.0485463142395, 52.48775175639561, 49.809957708631245, 50.914749077388215, 51.789805207933696, 50.52228702817644, 47.67104509898594, 49.27775001525879, 46.50315713882446, 46.69733149664742, 47.549976212637766, 46.94628545216152, 46.207177775246755, 51.24029650006975, 51.656194823128835, 53.781871114458355, 52.128001826150076, 57.412280559539795, 59.636951310294016, 66.2604397365025, 61.659620557512554, 65.20684269496373, 25.812326737812587, 39.54966402053833, 76.33532074519566, 56.666985511779785, 64.87213407244, 55.223222800663535, 53.30149350847517, 48.0390043258667, 49.733603954315186, 47.52240228652954, 49.99370282036917, 44.711115973336355, 46.216953890664236, 43.43672602517264, 46.94289820534842, 43.58620262145996, 46.366836956569124, 44.834366594042095, 45.91899429048811, 45.246377399989534, 47.43021011352539, 44.64961051940918, 43.836508001599995, 43.650306701660156, 51.98845420564924, 62.974754742213655, 60.790268898010254, 59.10672732761928, 63.22827366420201, 60.53935555049351, 62.74942466190883, 62.008253370012554, 58.076017652239116, 54.622995717184885, 63.36112322126116, 62.99172224317278, 65.1483736038208, 64.95774977547782, 68.90734904153007, 58.51269803728376, 62.09941373552595, 64.37680394308907, 61.61483941759382, 48.94558095932007, 72.88681861332485, 23.740934985024587, 0.3935134527938706, 0.17426253056951932, 0.23845210618206433, 0.24544592946767807, 0.3311172995184149, 0.02442013266097222, 0.08648572742406811, 4.030881464481354, 40.12483242579869, 50.532476561410085, 17.100128173828125, 36.30159657342093, 32.736708641052246, 60.81657477787563, 4.013724625110626, 0.1907501444220543, 0.10703419015875884, 0.004291433317121118, 0.08509758726826736, 0.03786793677136302, 0.05085999605112842, 0.030937088320830038, 0.05570861391190972, 0.02687562197180731, 0.04107385867142251, 0.04763621850205319, 0.04837675465803061, 0.01992795433449958, 0.026278061625946845, 0.05001951168690409, 0.0617993613705039, 0.03205449978954025, 0.06726299319416285, 0.04440934344061783, 0.03757202086438026, 0.04679413279518485, 0.02286248088681272, 0.03515230052705322, 0.03140744201040693, 0.018456191523000598, 0.018564088768990974, 0.07067139672913722, 0.020452790993398855, 0.020326742935659628, 0.03977769733007465, 0.046945429140967984, 0.06596695059644324, 0.04512683315468686, 0.06861042124884469, 0.01378558817253049, 0.046499044700924835, 0.023465311753430536, 0.07812915476305143, 0.03130600441779409, 0.02477056546402829, 0.031128167174756527, 0.07944089866110257, 0.03232751174696854, 0.033465564250946045, 0.014485492803422468, 0.03928142021011029, 0.038217141426035335, 0.037386638311935325, 0.0490276461600193, 0.10042734217963048, 0.005854500224813819, 0.02586106793023646, 0.03599596382783992, 0.10527174294527088, 0.0877204779535532, 0.15431218966841698, 0.1408980544656515, 0.2151675256235259, 0.4178850193108831, 24.23728997366769, 81.29640402112688, 37.72932979038784, 26.777023315429688, 88.29216997964042, 48.1763528415135, 3.7445996148245673, 0.47266667974846704, 0.08753141774130718, 0.4448089360126427, 0.6446605420538357, 0.6178269247923578, 1.5153861535446984, 0.7640795569334711, 0.06525620552045958, 0.3820622515465532, 48.327212129320415, 89.27857794080461, 73.33034297398159, 85.70514719826835, 65.6217543738229, 76.17461585998535, 78.59962749481201, 80.52082524980817, 69.981429372515, 70.43914890289307, 69.46326051439557, 69.82501152583531, 69.72665282658168, 72.30317687988281, 67.67644092014858, 66.73527268001011, 59.69128622327532, 54.8463386126927, 52.47548123768398, 55.369996547698975, 51.39364324297224, 53.31660236631121, 53.18028565815517, 53.33085312162127, 48.19332729067121, 50.354234422956196, 47.66599375861031, 48.76677254268101, 48.25426646641323, 50.030354567936485, 48.98287541525704, 54.36022179467337, 52.49913985388619, 56.417868273598806, 55.52318000793457, 60.986048289707725, 61.80688067844936, 68.95783465249198, 61.66670077187674, 66.24746050153459, 28.824744292667933, 41.170831612178254, 77.41113117762974, 60.35686111450195, 65.30405494144985, 56.466359751565115, 53.700709206717356, 49.41985804694039, 52.56568969999041, 49.02615574428013, 50.784887245723176, 47.01166105270386, 47.69260883331299, 45.43822063718523, 47.406495911734446, 45.016683850969585, 47.40083660398211, 46.15477098737444, 47.439972332545686, 45.87645047051566, 48.63805021558489, 46.31484358651297, 45.69802073069981, 45.923468930380686, 53.458613123212544, 63.67456340789795, 62.54718344552176, 62.07679040091378, 61.0892151423863, 62.11403274536133, 63.818425859723774, 62.615748269217356, 60.09072426387242, 55.407555035182405, 63.000789642333984, 62.99153464181082, 63.633499554225374, 64.96617794036865, 70.47520310538155, 64.27135808127267, 63.77800818852016, 67.1830632346017, 65.78328609466553, 52.28859554018293, 75.58250427246094, 28.874071291514806, 0.3251799823982375, 0.31814129437719074, 0.26486416320715633, 0.22146350278386048, 0.19026826242251055, 0.03252748280231442, 0.06969062185713223, 9.196382914270673, 36.860745906829834, 75.45236451285226, 29.291506903512136, 42.57297113963536, 36.83519390651158, 66.13050147465297, 6.772920727729797, 0.3067578652075359, 0.049728596583008766, 0.07089869917503425, 0.05116159129621727, 0.04996014326544745, 0.07706210416342531, 0.02085620381071099, 0.02350406628102064, 0.021478172757529786, 0.04759757932541626, 0.03655000802661691, 0.019990450802392194, 0.02550706942565739, 0.008579071078981673, 0.032376518938690424, 0.029198481435222284, 0.024242059627015675, 0.07585287333599158, 0.009808113432622381, 0.02273877038221274, 0.05872027123613017, 0.022820455820432732, 0.034266693584088764, 0.023681837366893888, 0.08800383417734078, 0.055534308443644216, 0.11922895722091198, 0.09011951315083674, 0.07730248876448188, 0.18482487808380807, 0.13493766715484007, 0.13887042898152555, 0.1503053182469947, 0.1312576053397996, 0.16079066560736724, 0.10362096223980188, 0.18375687753515585, 0.15008685711239064, 0.09631250226604086, 0.11988957891506807, 0.1481653002223798, 0.23643023467489652, 0.09778235160878726, 0.1510082669556141, 0.11564321177346365, 0.095206164488835, 0.107055299383189, 0.157856408772724, 0.09998235891440085, 0.1515994473759617, 0.25341431902987616, 0.13469211890229157, 0.1575285949345146, 0.29901398931230816, 0.22159178661448614, 0.34948429252420155, 0.3543693646788597, 0.4299789289278643, 0.7451013667242867, 31.63785798209054, 93.61603260040283, 64.53751577649797, 40.52407591683524, 63.74574075426374, 74.78034169333321, 6.021458285195487, 0.45188513344952036, 2.001630101885114, 4.050801515579224, 1.3727318197488785, 5.630587807723454, 6.009189069271088, 0.28808884269424845, 0.15857870930007525, 0.5474909618496895, 48.50357130595616, 93.60873699188232, 74.73196138654436, 89.27069173540387, 68.9588143484933, 76.02773094177246, 80.00157247270856, 80.86362852369035, 73.24096829550606, 73.03719152723039, 72.82311058044434, 68.37448474339077, 70.63369151524135, 76.17638765062604, 69.65605912889752, 69.69287068503243, 61.90280055999756, 58.1870880808149, 56.97935567583357, 59.5029969896589, 54.35430540357317, 57.34370878764561, 58.650710105895996, 57.169534819466726, 51.63975885936192, 53.577833788735525, 51.95430380957467, 52.217105524880544, 51.82099914550781, 52.72592905589512, 50.69147218976702, 56.27619103022984, 56.774432454790386, 60.295439038957866, 59.48833629063198, 62.76675346919468, 64.08132484980992, 70.11472361428397, 66.33819702693394, 65.22943128858293, 30.210124765123638, 46.281044074467246, 78.42338643755231, 63.69401141575405, 68.95472185952323, 62.149135044642854, 56.80932978221348, 51.43069451195853, 53.749423027038574, 52.31480761936733, 54.17914131709507, 49.15529843739101, 49.77638748713902, 48.02580622264317, 50.334824630192344, 48.34064299719674, 51.69974613189697, 48.95630202974592, 51.072782380240305, 50.567214080265586, 52.935997417994905, 50.46077115195138, 48.504127161843435, 50.22498403276716, 57.05254452569144, 67.87535394941057, 65.6027579988752, 63.57482896532331, 61.17296872820173, 68.18371500287736, 67.62260627746582, 66.4947816303798, 63.228162493024556, 60.93332535879952, 65.86835289001465, 65.79589012690953, 65.45631081717355, 68.36760602678571, 71.79534694126674, 63.60269124167306, 65.54210022517613, 70.6801541192191, 69.69034848894391, 55.53686448505947, 76.48992511204311, 29.308425767081125, 0.33164606828774723, 0.4047933375196797, 0.6131328738161496, 0.6524996299828801, 0.9004837146827153, 0.1867262010595628, 0.14525461569428444, 8.719548889568873, 56.45477015631539, 63.434343338012695, 27.731952462877544, 49.65349122456142, 44.45041956220354, 78.9551807131086, 7.7056677511760165, 0.515968559043748, 0.30859218963554924, 0.11496071411030633, 0.17842785348849638, 0.14705358844782623, 0.15678652189671993, 0.2109798789024353, 0.11307154369673558, 0.10124638822994061, 0.1356315506356103, 0.10255902100886617, 0.13548806762056692, 0.12405355833470821, 0.05955094737665994, 0.1566974845315729, 0.17666782864502498, 0.12876704255385057, 0.13411408849060535, 0.1035308935014265, 0.10592545036758695, 0.1585120635905436, 0.13982183007257326, 0.16745909063943795, 0.11014891016696181, 0.260227272020919, 0.11942003268216338], [0.032252133291746886, 0.06752887714122023, 0.01528951948109482, 0.03754752914288214, 0.054119657924664874, 0.03336051685203399, 0.03741846838966012, 0.05133133700915745, 0.06861148654882397, 0.04323148467977132, 0.042214951012283564, 0.01844324168216969, 0.01637041728411402, 0.07806714344769716, 0.05343189822243793, 0.030334698501974344, 0.060527997091412544, 0.048499633957232745, 0.020333029562607408, 0.035036067478358746, 0.104949479523514, 0.04319097274648292, 0.023813685202705007, 0.035721825502280674, 0.04099241750580924, 0.03212775103747845, 0.017601815850606987, 0.09524352462696177, 0.08009892156613724, 0.055806672400129695, 0.18667220324277878, 0.08001915977469512, 0.11744037962385587, 0.09343625339014189, 50.05156741823469, 64.39934389931815, 40.87944153376988, 13.571796451296125, 60.15869154248919, 52.957290172576904, 2.8880052821976796, 0.07564538411263909, 0.6682082042098045, 0.4128715140478951, 0.16750604526272841, 2.6476230153015683, 3.1417411182607924, 0.1303134781441518, 0.03459989499034626, 0.954251263822828, 70.22403267451695, 91.72151592799595, 70.05320426395961, 80.00697122301374, 79.14363670349121, 76.8942894254412, 72.12431635175432, 72.80298859732491, 72.83149705614362, 72.56997380937848, 73.11829090118408, 72.25683239528111, 70.02514743804932, 65.45713765280587, 61.24188791002546, 53.37484564099993, 55.915520463671, 53.879458563668386, 54.407063075474326, 57.78355407714844, 60.667070388793945, 59.41902106148856, 60.40563746861049, 56.003359590257915, 56.5612165587289, 50.93056665148054, 47.920044217790874, 43.71548080444336, 48.581887926374165, 44.76563848767962, 49.928542613983154, 51.09630898066929, 55.76638432911464, 55.274503980364116, 61.31525393894741, 59.230759620666504, 70.51055553981236, 61.920789446149556, 72.30442060743059, 33.939445291246685, 35.51420586449759, 78.60710375649589, 57.125663893563406, 65.1690514428275, 57.23882572991507, 59.01867280687605, 53.307260513305664, 51.09026404789516, 46.98058870860508, 47.55957167489188, 45.90303427832467, 47.76312262671334, 44.821418625967844, 47.09043972832816, 46.23343849182129, 49.122228486197336, 47.99247223990304, 47.28269290924072, 48.96010964257376, 51.26679345539638, 49.09726013456072, 45.7579003061567, 41.93426840645926, 46.510987758636475, 57.449418681008474, 63.179247174944194, 61.35763100215367, 62.61126668112618, 66.190888268607, 65.61188793182373, 62.963109561375205, 63.77820273808071, 59.47803211212158, 62.14337498801095, 66.65371472494942, 70.68558066231864, 63.10683304922921, 64.31811250959123, 73.67102009909493, 72.07255227225167, 48.78097466060093, 50.88093219484602, 66.6468915939331, 18.54744836262294, 0.029068942314812114, 0.3772450057523591, 0.08023778375770364, 0.3637100506041731, 0.23177857856665338, 0.16144394555262156, 0.06644832369472299, 6.710435143538883, 38.58919368471418, 59.82879802158901, 5.075840592384338, 11.678029315812246, 29.37182460512434, 61.73968464987618, 15.810980251857213, 0.3722259907850197, 0.027773461204820445, 0.08070413409067051, 0.06057200687272208, 0.08728958786066089, 0.03703295532613993, 0.06796761109892811, 0.019081105311800326, 0.07995956404400723, 0.11147583967873029, 0.058250738573925834, 0.07561489753425121, 0.03907784613381539, 0.1038797012131129, 0.08141255179154021, 0.13486752020461218, 0.0186266293416598, 0.005393162145212824, 0.06308864575943776, 0.03273283803303327, 0.023542988746027862, 0.02761752367950976, 0.035321445736501894, 0.029558888703052486, 0.037929863269839964, 0.028157863167247603, 0.06177668473018067, 0.015268902194553187, 0.04755231086164713, 0.03561053218852196, 0.08877888401704175, 0.07118401636502572, 0.019479888823947737, 0.04428205366379448, 0.09124109760991164, 0.0408242052820112, 0.037225659271436076, 0.07112647659544434, 0.05313025547989777, 0.004551604847490255, 0.08266928007027932, 0.06478682892130953, 0.03650877684620874, 0.016200668178498745, 0.06266173188175474, 0.04044789993869407, 0.04009719232895544, 0.024488888614411865, 0.016679708812651888, 0.057821870515389104, 0.0408949934478317, 0.03275256983137556, 0.03977180425343769, 0.06770895354981933, 0.0515877011099032, 0.01751309061156852, 0.05061465135908552, 0.19740554158176693, 0.01389080096435334, 0.15602055085556849, 0.4656336914215769, 63.890311922345845, 71.02975967952183, 26.559742723192485, 23.942748887198313, 96.38840552738735, 48.50589200428554, 8.180783833776202, 0.07866375214819397, 0.7617671095899173, 0.29992132633924484, 0.18160666791456087, 1.3094808480569293, 0.9347605896847588, 0.93158016034535, 0.022013845620676875, 1.802848328437124, 79.94763360704694, 86.8795803615025, 73.94345201764787, 85.37277317047119, 78.94206946236747, 76.14110469818115, 70.77497618538993, 74.23394925253731, 75.68665776933942, 73.36862060001918, 72.60675757271903, 73.05974537985665, 70.62892505100795, 65.98809814453125, 62.99860790797642, 56.72718470437186, 57.58640936442784, 55.307775429316926, 55.57577439716884, 59.51564965929304, 61.49157837459019, 59.44380528586251, 59.12987872532436, 57.77977078301566, 56.3021251814706, 52.45022106170654, 49.63440452303205, 47.21125153132847, 52.08599649156843, 47.3252124105181, 51.81661135809762, 53.11512197766985, 58.35996968405587, 56.76380865914481, 62.63876070295061, 60.994643211364746, 71.7881555557251, 63.857752663748606, 71.92255456107003, 31.174027511051722, 37.221513748168945, 80.76169150216239, 59.16364002227783, 65.61075537545341, 58.99108151027134, 60.73931080954415, 55.246384620666504, 53.24757548740932, 49.99734715053013, 50.419311250959126, 47.60437365940639, 49.341030733925955, 46.07542255946568, 48.97412415913173, 47.132594449179514, 50.418341977255686, 50.52344390324184, 49.5458254132952, 48.6427298273359, 51.37497343335833, 50.36694962637765, 47.740137985774446, 46.36603443963187, 48.75780936649868, 60.272635051182334, 64.09807695661272, 62.075261797223774, 64.44781453268868, 63.11346163068499, 65.05744947705949, 61.553410393851145, 63.23401982443673, 60.12615312848772, 63.02929810115269, 67.03989560263497, 72.02140658242362, 65.14419078826904, 64.84163842882428, 72.81031894683838, 73.54098456246513, 54.07149635042463, 51.2972091947283, 72.65517956869942, 25.34951765196664, 0.031669692402439456, 0.22108057833143643, 0.07312913877623421, 0.3981005666511399, 0.37127726312194553, 0.06009112910500594, 0.059827905015221665, 13.856362530163356, 35.6905129296439, 89.30523817879813, 16.34702856200082, 10.48546482835497, 31.02471419743129, 65.96827493395124, 23.256178276879446, 0.512482300400734, 0.08841043950191566, 0.17967596437249864, 0.03614169618647013, 0.07489611860364676, 0.037218979094177485, 0.029169287466044937, 0.04552148608490825, 0.0811608424410224, 0.09984165110758372, 0.05189073484923158, 0.05898098474634545, 0.018375512012945752, 0.07146129291504622, 0.01869462533587856, 0.04707461542316845, 0.010056094233212727, 0.02159482310526073, 0.031292657633977275, 0.0250786067917943, 0.04659545095637441, 0.04869718264256205, 0.02667894520397697, 0.06209248849856002, 0.058695307932794094, 0.0441474526721452, 0.06682359427213669, 0.08341539039143495, 0.11178224573710135, 0.1121524680139763, 0.24555449507066182, 0.1286167741886207, 0.0926652340484517, 0.2030903079680034, 0.2106589318386146, 0.1570552217641047, 0.18386271542736463, 0.19573236922068254, 0.15538363717496395, 0.1299753641443593, 0.1398513192044837, 0.1681657170078584, 0.08049220724829606, 0.10803663743925945, 0.16743154211768083, 0.1841108828250851, 0.15792010964027473, 0.19564000703394413, 0.14497884549200535, 0.12726431818945066, 0.1679624957697732, 0.09025211246418101, 0.10805231159819023, 0.10693325807473489, 0.2155903343643461, 0.17575181994054997, 0.12228693813085556, 0.27897362038493156, 0.11125501045691115, 0.1939919947513512, 0.5026734524539539, 77.15850857325962, 80.94278935023716, 60.68093204498291, 23.331338678087505, 75.3141370500837, 73.33005114964077, 9.377568483352661, 0.2026517300733498, 1.0683931218726295, 1.161966357912336, 0.6372724899223873, 6.561956916536603, 9.27249869278499, 0.81796631110566, 0.1292798114674432, 1.6066099213702338, 77.76513494764055, 93.46599320002964, 76.70200497763497, 85.91366958618164, 83.50074086870465, 79.1742296218872, 74.20220293317522, 74.67324216025216, 76.69639083317348, 74.52311938149589, 75.68822806222099, 75.24248027801514, 73.91067736489433, 69.26186003003801, 67.62173080444336, 60.34661252158028, 61.67239829472133, 58.84749003819057, 60.318659918648855, 65.01446097237724, 66.4988602229527, 65.33979647500175, 67.13500949314663, 66.0872003010341, 62.59497315543038, 55.858559131622314, 54.29058000019619, 49.319953373500276, 54.97088507243565, 50.95087276186262, 55.82582269396101, 57.31856673104422, 61.71503938947405, 60.359779357910156, 66.5536676134382, 64.7108107975551, 75.79537623269218, 67.0487892968314, 72.8899175098964, 35.80624907357352, 38.10145793642317, 80.88362543923515, 62.081779207502095, 67.55366625104631, 62.88629027775356, 64.00585351671491, 58.346580505371094, 56.63255023956299, 52.19529512950352, 53.001032556806294, 49.99187197004046, 53.427957671029226, 48.531405789511545, 52.0797882761274, 50.71632937022618, 53.94694294248308, 53.825088909694124, 53.463928495134624, 53.504832540239605, 55.60391807556152, 54.2592054094587, 50.86632013320923, 48.50270625523159, 52.47194807870047, 63.429000173296245, 68.32647269112724, 69.01111343928746, 69.66574491773332, 63.05299840654646, 67.43887506212506, 68.26597472599575, 67.29893834250313, 62.56123270307268, 66.63676112038749, 71.67867279052734, 72.69707025800432, 64.185485294887, 67.40277917044503, 73.8760266985212, 74.06226621355329, 57.56498459407261, 58.13916982923235, 73.85698863438198, 24.255188533238, 0.12476110751075403, 0.7762919930475098, 0.46569133975676125, 1.2128652781248093, 0.6066250173108918, 0.203568254464439, 0.1485836442027773, 13.24275495324816, 53.7756142616272, 74.27388054983956, 11.300471152578082, 20.221206869397843, 42.08733722141811, 76.83449322836739, 28.21796679496765, 0.7086832523345947, 0.17614418960043363, 0.33930965991956846, 0.18983743339776993, 0.2409764735826424, 0.10033853551638977, 0.11857141607574054, 0.14240506717136928, 0.11162632517516613, 0.16432037763297558, 0.22324480648551667, 0.14837834664753505, 0.08984161913394928, 0.17628590842442854, 0.25370459631085396, 0.1040529040619731, 0.1888282754059349, 0.0884334621950984, 0.11671661346086434, 0.15641609605933937, 0.08452925312199763, 0.09410823376051017, 0.1320254627083029, 0.14746095373162202, 0.16947875012244495, 0.12632868625223637, 0.15321050664143904], [0.0389167924544641, 0.02866748028567859, 0.060491742965366156, 0.04527938479025449, 0.05753515554325921, 0.011272895815117019, 0.03639156670708742, 0.04024290772421019, 0.04279587198314922, 0.017609267861449292, 0.036876461402113946, 0.07468091443713222, 0.015944882528856397, 0.019147632277703712, 0.03882633355845298, 0.04183940902086241, 0.020532176197905625, 0.04656416031398943, 0.03169797374201672, 0.048950785105781894, 0.022331601873572384, 0.0687690559508545, 0.025816896996859993, 0.030833720296089138, 0.02844219478512449, 0.011390200949140956, 0.06150305869856051, 0.030192548808242594, 0.04289732653913753, 0.041881430694567304, 0.07975116558372974, 0.12281762036894049, 0.048225536343774626, 0.25250706342714174, 2.609802450452532, 63.25008405957903, 54.492480754852295, 45.57416214261736, 12.000218152999878, 52.062504632132395, 54.25942080361502, 7.690245355878558, 0.48725995953593937, 0.3042508140206337, 0.35441808349319864, 0.48260265801634106, 0.6832608793463025, 1.7486773495163237, 0.40363138701234547, 0.07030413965029375, 2.073622775929315, 60.24890695299421, 92.99270275660923, 75.67520713806152, 70.77562236785889, 78.652676991054, 84.08509131840297, 78.56279509408134, 75.95069626399449, 69.72705582209996, 69.25317478179932, 72.15842505863735, 74.44456304822648, 67.01864801134381, 62.82265172685896, 62.636481693812776, 60.897715841020855, 60.32526765550886, 63.103803634643555, 60.44277559007917, 65.97268009185791, 65.2461347579956, 66.60034561157227, 65.71518680027553, 63.175029618399485, 62.591770035879954, 60.86972849709647, 50.011372089385986, 49.45373746326992, 46.98571647916521, 50.444717339106965, 53.06299311774117, 57.00001267024449, 54.062512329646516, 61.732896259852815, 55.857298033578054, 68.86185223715646, 62.611683573041645, 76.09155014583042, 37.0510709626334, 29.70835712977818, 78.73146261487688, 59.17336055210659, 70.04601287841797, 58.458925928388325, 62.64298520769392, 55.237682001931326, 55.96500205993652, 44.808710370744976, 48.92075157165527, 44.25452899932861, 45.96636710848127, 44.318525382450645, 49.22167110443115, 53.03595420292446, 55.82449211393084, 51.321701594761436, 52.70724882398333, 52.30542407717024, 54.89215850830078, 53.11861344746181, 51.374858788081575, 47.89740003858294, 45.55418954576765, 53.22992011478969, 64.07669734954834, 64.52730192456926, 65.8055967603411, 66.32525948115757, 66.7176103591919, 64.82227379935128, 65.99109281812395, 63.5922828401838, 68.15730490003313, 65.69833741869245, 68.77891159057617, 74.09736851283482, 72.7296781539917, 58.291682788303916, 50.68692111968994, 62.66095324925014, 58.17630795070103, 7.457153269222804, 0.16655498343919004, 0.17532370505588396, 0.4408184444265706, 0.34366748322333607, 0.22327440418303013, 0.5533281000597137, 1.426012235028403, 13.858870829854693, 43.12956006186349, 62.59992027282715, 5.450139616216932, 26.240903786250524, 41.47918224334717, 55.8818599155971, 22.640593937465123, 0.23647995772106306, 0.023070455262703553, 0.13846786772566183, 0.05374910316563078, 0.06236825870083911, 0.04875747387164405, 0.09902236078466688, 0.018439421530014703, 0.03887459436165435, 0.024919780403641716, 0.03601916294012751, 0.04542663706732648, 0.04529869928956032, 0.015324976328494293, 0.04249640055266874, 0.08006496767380408, 0.040232288651168346, 0.06210365718496697, 0.04248625984681504, 0.030281552246638706, 0.028356536524370313, 0.05658520990982652, 0.016549053502136042, 0.037514633765178065, 0.02792399250237005, 0.04604002933150955, 0.01018263422884047, 0.09567687101662159, 0.039758420150194845, 0.05417997968782272, 0.05470004963821598, 0.023162707187501446, 0.05132672975638083, 0.07773165537842683, 0.04325545732198017, 0.1274327712931803, 0.0548430169666452, 0.09298499367598977, 0.08199508767575026, 0.033552925634597025, 0.020468102136094655, 0.007470530607471508, 0.03409605220492397, 0.06896899307944945, 0.023482858669012785, 0.014909826551697083, 0.08656151300030095, 0.049152791766183715, 0.011228261781590325, 0.024724498025274703, 0.016323810410020605, 0.06496860166745526, 0.03211543901956507, 0.014290113733815295, 0.044101858511567116, 0.01805967601415302, 0.08372652583888598, 0.10342868577156748, 0.03371275116556457, 0.09041625008519207, 0.041703579880829365, 0.20761114252465113, 5.987138092517853, 79.75027697426933, 51.614252022334504, 19.408813067844935, 27.496596132005962, 90.9795594896589, 47.80958523069109, 14.26955713544573, 0.7120589369109699, 0.6383970124380929, 0.13203858557556356, 0.4603553946529116, 0.9737904667854309, 0.46199620089360643, 0.4079839720257691, 0.36426492940102306, 3.839247976030622, 71.42487594059536, 93.99244431086949, 75.63057885851178, 72.39114802224296, 83.47663756779262, 83.99586255209786, 76.50500965118408, 72.78488159179688, 70.98413780757359, 69.47052138192313, 73.30039623805455, 73.45670291355678, 68.7294682094029, 64.96608761378697, 63.42374733516148, 62.673939432416645, 62.77229118347168, 63.53580788203648, 63.51940318516323, 67.24425601959229, 65.88345827375139, 68.67536953517369, 65.51201452527727, 64.82881900242397, 62.22243159157889, 59.05627645765032, 49.668078967503135, 52.24066686630249, 49.963735239846365, 53.33048486709595, 53.57207373210362, 58.59737573351179, 56.32085405077253, 64.38851165771484, 57.07352113723755, 70.90968091147286, 63.001887457711355, 77.08944347926548, 37.89496094839913, 33.0772294316973, 77.81367506299699, 61.042696952819824, 69.76190103803361, 59.43520341600691, 61.948846272059846, 55.80996690477644, 57.1527236529759, 46.60915190832955, 50.0484094619751, 47.38881969451904, 46.899392059871126, 46.646776403699604, 50.51545000076294, 53.322362422943115, 53.658696923937114, 51.82234362193516, 52.633021218436106, 54.392193930489675, 58.13504259926932, 55.891438007354736, 51.45574276787894, 47.81370898655483, 47.72091926847185, 56.5329339163644, 65.97817611694336, 65.67982046944755, 64.43755204336983, 65.0954144341605, 66.15420178004673, 65.39423561096191, 66.40504564557756, 65.54547704969133, 69.58158833639962, 68.53937939235142, 68.06638077327183, 72.98760918208531, 74.76832825796944, 60.90070356641497, 51.778792313167024, 64.875990322658, 69.60080705370221, 11.040169051715306, 0.24551741991724285, 0.08368853466319186, 0.22533727277602467, 0.12448103539645672, 0.48273575944559916, 0.46736688699041096, 1.6986549879823412, 24.18642394883292, 37.14751890727452, 91.4455543245588, 17.574525117874146, 6.443715947014945, 33.4464601789202, 61.32056931086949, 32.237546580178396, 0.3617628722318581, 0.00726434841219868, 0.07777127503816571, 0.045991001783737114, 0.03489860985428095, 0.018152219709008932, 0.07622420841029712, 0.06474993018699543, 0.07579888230455772, 0.06353164770241294, 0.018710075578253185, 0.0581536130713565, 0.10150441474148206, 0.11821374669671059, 0.10575648157724313, 0.05077611894479819, 0.02663917457019644, 0.04887762885274632, 0.03045867702790669, 0.029417149523007016, 0.031017715244420936, 0.01466960140636989, 0.0432185450169657, 0.053161118645220995, 0.08156869627003159, 0.08717209952218191, 0.058168052296553335, 0.05760006420314312, 0.11398008173065526, 0.12868299920644077, 0.14564744675798075, 0.10937452529157911, 0.1656250919082335, 0.14413774705358914, 0.1641627268067428, 0.22261085121759347, 0.20872818758445127, 0.17503804181303295, 0.24157152165259632, 0.11980127436774117, 0.08597211034170218, 0.08912758994847536, 0.08363739347883634, 0.20590573975018092, 0.052668322409902296, 0.06758106326950447, 0.17773163584726198, 0.2536728408719812, 0.08173355313816241, 0.15613622750554765, 0.14599416458180972, 0.09786826771284853, 0.12266215442546777, 0.16026713512837887, 0.2181552510176386, 0.11979856022766658, 0.1891984705414091, 0.26840245191540035, 0.16745040539119924, 0.1646621557218688, 0.12069932903562273, 0.32934474891849924, 6.486529443945203, 96.39715330941337, 68.11758204868862, 66.95676735469273, 23.94021279471261, 66.51440334320068, 76.72967270442417, 18.370194605418614, 0.8281101382204464, 0.6417526666607175, 0.5222977165664945, 1.1210752321141106, 2.1838083948407854, 4.259161489350455, 0.7896191807729858, 0.5120972182069505, 3.5923070439270566, 66.59159088134766, 96.30171285356793, 80.55318301064628, 73.52845001220703, 84.29783821105957, 87.25824328831264, 79.04562541416713, 77.45653765542167, 71.56763362884521, 69.20165388924735, 74.25140312739781, 79.16289016178676, 74.46172509874616, 70.35199069976807, 67.80057743617466, 67.85915769849504, 69.06512873513358, 70.05176598685128, 64.91332299368722, 70.94522789546421, 72.70460210527692, 73.22759301321847, 70.06193814958844, 69.61568314688546, 70.41184248243059, 67.6063266481672, 56.051159722464426, 55.96160091672625, 52.01652840205601, 56.68451929092407, 59.671643665858674, 63.276216234479634, 59.63301862989153, 67.52804824284145, 59.62691116333008, 73.80935178484235, 67.13473156520298, 78.7034752709525, 40.952543531145366, 36.36577360970633, 78.48043114798409, 62.934427397591726, 73.37687505994523, 63.058570861816406, 67.83847291128976, 59.24132783072335, 59.962231227329795, 48.59954677309309, 53.937375273023335, 49.384008816310335, 48.84593684332711, 50.02778720855713, 54.32758610589163, 59.448502268110005, 60.60651683807373, 57.5058901650565, 57.556719711848665, 59.1330748966762, 62.138539041791645, 63.37506825583321, 58.69886112213135, 54.43458489009312, 51.20042078835623, 59.293161392211914, 69.58079624176025, 69.6596930367606, 70.63164874485561, 73.49464702606201, 66.11802945818219, 67.76516941615513, 71.78074877602714, 69.38947759355817, 73.1769962310791, 69.10317012241909, 69.53197125026158, 74.9715074811663, 73.90717547280448, 63.97346796308245, 59.33118193490164, 70.76989705221993, 65.58852808816093, 10.005496297563825, 0.17765703770731175, 0.5311929306813649, 0.3812588932258742, 0.9653113846267972, 0.5506345331668854, 0.7188918388315609, 2.066205356802259, 25.912450279508317, 59.88867064884731, 76.12438038417271, 13.360605086599078, 37.76562023162842, 57.41145372390747, 71.30159405299595, 42.626788411821636, 0.31007305160164833, 0.13049555623105594, 0.18278996513358184, 0.15176064015499183, 0.20448973216116428, 0.1490847287433488, 0.22730961122683116, 0.19351917797965662, 0.19470779491322382, 0.2597557987485613, 0.1169313019407647, 0.1817193047276565, 0.10647992882877588, 0.16945592420441763, 0.18880915428910935, 0.2347280074443136, 0.1474437460835491, 0.1730175002345017, 0.12671786679753236, 0.10617168394050427, 0.17571087713752473, 0.21255524722593172, 0.1320190301963261, 0.16141693985887937, 0.12836241855153016, 0.22840283970747674, 0.1748919803649187, 0.1605609000793525], [0.056987381008054526, 0.051209000537970235, 0.04966528248041868, 0.04804834031632968, 0.02643366836543594, 0.09183014064495053, 0.04392440464081509, 0.030957817565649748, 0.004293886645297919, 0.03209369197221739, 0.02940581798819559, 0.07687141546713454, 0.008617220014067633, 0.021336457326209972, 0.05727595516613551, 0.0790320745270167, 0.029230264015495777, 0.015201783206846033, 0.06963525339961052, 0.07029651291668415, 0.021657674107700586, 0.065913855231234, 0.019917952728324702, 0.03198264293106539, 0.014910016541502305, 0.04298917303926178, 0.02334335186917867, 0.03187890849741442, 0.053528776059725454, 0.042242828623524735, 0.056490822296057425, 0.03145841356100781, 0.26174602338245934, 0.08921782832060542, 0.44832600014550344, 10.570370078086853, 76.57422065734863, 48.69271169389997, 48.957052435193745, 20.849306651524135, 51.833564962659565, 70.40218448638916, 17.73684893335615, 2.7980849530015672, 0.043682116749031205, 0.7776385865041188, 0.27564052066632677, 0.843075363763741, 0.34211844205856323, 0.11252623902899878, 0.1613586944128786, 0.7127818209784371, 33.640599795750205, 86.18809563773019, 91.22370529174805, 79.85717500959123, 65.91835907527378, 72.26749093191964, 73.19478361947196, 78.28854274749756, 76.19213921683175, 74.85104656219482, 67.62226581573486, 69.23864609854562, 71.894289289202, 67.01424285343715, 66.2824238368443, 65.33871950422014, 69.17213099343437, 66.48982756478446, 66.89818014417375, 66.13858917781285, 66.74684837886265, 65.5989990234375, 66.95865031651088, 63.84514168330601, 65.21321419307164, 60.93575722830636, 56.47275556836809, 50.03009401048933, 48.816299302237375, 51.69966275351388, 59.04324858529227, 58.228124141693115, 63.26155553545271, 60.1237907409668, 70.4310611997332, 60.5094644001552, 72.3265575681414, 33.7934810093471, 25.596673761095317, 81.41847692217145, 58.66325855255127, 69.85188020978654, 60.13363633837019, 64.0628912789481, 54.95010995864868, 57.712540013449534, 51.86564132145473, 51.510741233825684, 44.944516386304585, 51.135621888296946, 50.13186774935041, 61.7717227935791, 61.78110980987549, 62.049741063799175, 54.55350678307669, 53.65791872569493, 54.23694338117327, 58.69072478158133, 54.35607372011457, 56.81426647731236, 51.47724396841866, 49.70886836733137, 50.25384337561471, 60.83089501517159, 66.77673952920097, 69.67289461408342, 69.2303568976266, 70.74533517020089, 68.02168301173619, 73.48425946916852, 69.0848616191319, 68.47520583016532, 72.08223111288888, 78.19860526493618, 62.847637448992046, 55.115039348602295, 69.5391765322004, 71.327531678336, 33.80059249060494, 1.9762648344039917, 0.1582178236650569, 0.09720221095319305, 0.23754482343792915, 0.26221999366368565, 0.019863561361229846, 0.2576422978724752, 4.996905582291739, 18.14268105370658, 48.06704378128052, 63.77768857138497, 7.224610524518149, 31.653908320835658, 41.399034772600444, 49.91952732631138, 29.652813230242046, 0.32459934641207966, 0.1301105147493737, 0.03497170503916485, 0.05885916056909731, 0.012410961889794894, 0.16658044207308972, 0.02981078465070043, 0.051710152932043583, 0.05928495486399957, 0.115762823926551, 0.055285058782569, 0.07584726185138736, 0.04706820665991732, 0.049202199293566604, 0.041089186777493784, 0.042613091612500806, 0.046543549812797985, 0.012934064043552747, 0.08164815272071532, 0.03624673340735691, 0.08283096139452287, 0.06012981917176928, 0.06720742796148572, 0.015996149242190377, 0.04917079669290355, 0.03351063933223486, 0.0465849099148597, 0.03735707114849772, 0.12425417399832181, 0.011890752839722803, 0.022438513547448174, 0.00789488386362791, 0.00212832644215918, 0.03392269668568458, 0.045456808126930676, 0.04146592299054776, 0.019757757395771996, 0.03271615964227489, 0.0386078927798995, 0.042134697282952924, 0.06647841672280005, 0.03824233543127775, 0.05887533684394189, 0.05638719303533435, 0.08398379239120654, 0.0528449348972312, 0.035475880306746276, 0.011683808140722769, 0.06636895545359169, 0.05300189022506986, 0.07057788781821728, 0.02984861297799008, 0.02661681853766952, 0.028520658878343444, 0.047816752921789885, 0.03570932688723717, 0.08438013826629945, 0.05328824557363987, 0.07651787158101797, 0.05400515853294304, 0.14361793494650296, 0.20530706830322742, 0.09587432470704828, 0.3087792210280895, 18.461056198392594, 88.40069389343262, 44.40742063522339, 21.30985757282802, 31.79895544052124, 97.63730948311942, 63.245234216962544, 21.097633532115392, 4.984863485608782, 0.1213591636291572, 0.5315442489726203, 0.4555311192359243, 0.47124908438750673, 0.6823550079550061, 0.0799909055765186, 0.22480121654059204, 1.1196723473923547, 42.28452362333025, 94.58147089821952, 91.67763110569545, 75.30691092354911, 67.44101510729108, 73.34360708509172, 74.98898914882115, 76.22864505222866, 74.48617580958775, 74.90931415557861, 73.28938334328788, 71.37575912475586, 71.58831146785191, 68.75561428070068, 68.29940250941685, 67.63042300088065, 71.42214529854911, 68.54967662266323, 69.22245679582868, 66.37475844791958, 66.74920381818498, 67.88633905138288, 68.79448250361851, 67.30248887198312, 66.65581308092389, 61.55571024758475, 56.2675335747855, 51.90985270908901, 51.68991790499006, 52.284687178475515, 60.65370205470494, 58.79202951703753, 64.2558080128261, 61.41705894470215, 70.39492361886161, 62.62699045453753, 73.3103391102382, 33.946949345724924, 26.472238847187587, 82.20983505249023, 60.76157978602818, 73.21252237047467, 63.62315368652344, 66.41230651310512, 58.21572160720825, 61.49562917436872, 53.01955298015049, 52.466875893729075, 45.9474332673209, 52.068052768707275, 51.106918879917686, 61.23029831477574, 62.97844423566546, 65.09658173152378, 57.288154465811594, 56.397423199244905, 55.67485570907593, 57.465719154902864, 56.107599939618794, 59.493985176086426, 53.915721212114605, 50.784553732190815, 49.08624723979405, 60.721314975193565, 64.12396594456264, 71.52304009028843, 67.4935712814331, 68.68704945700509, 65.39540985652378, 69.54704884120396, 68.66891465868268, 68.73633302961076, 69.95765263693673, 78.15844467708042, 65.74577277047294, 55.40308039528983, 66.93410233088902, 79.96970803397042, 42.428393023354666, 3.4739321044513156, 0.29680872336030006, 0.1834219933620521, 0.3439407971288477, 0.48270780380283085, 0.030268951851342405, 0.3626137008624417, 8.682765994753156, 33.91088472093855, 40.01801429476057, 94.96802003043038, 20.11883905955723, 10.313240698405675, 34.065954617091585, 53.543422835213796, 38.76083503450666, 0.4725013886179243, 0.0750538779954825, 0.029215414276612655, 0.05746074739311423, 0.08904178919536726, 0.13868850017232554, 0.056853339807795625, 0.05118158772321684, 0.015913885352866988, 0.0918121323255556, 0.03519950620830059, 0.020562890085524747, 0.05658909113013318, 0.03073768044954964, 0.027764348479519998, 0.0669185213212456, 0.013329109675916178, 0.08729914163372346, 0.053002908027597835, 0.04843150904136045, 0.03185909188219479, 0.01797998886156295, 0.0351893621097718, 0.047151042214993916, 0.03332676652020641, 0.043550715049994845, 0.03364795785663383, 0.008508987741411796, 0.03660593627552901, 0.1093341660286699, 0.15253130665847234, 0.07685294574392693, 0.1833905093371868, 0.15546366359506333, 0.17453561377312454, 0.16645962212766918, 0.1038780388023172, 0.12368774653545447, 0.12828711473516055, 0.06014736608735152, 0.1462074959916728, 0.18394713875438484, 0.13104941722537788, 0.16728729914341653, 0.11915583828730242, 0.1332088956343276, 0.09694506653717586, 0.14226477327091352, 0.17716368846595287, 0.15703459429953778, 0.11097170173057488, 0.1100811380892992, 0.10868843139282294, 0.14179179365081446, 0.06719359941780567, 0.139278147103531, 0.15900719059365137, 0.13343520063374723, 0.20255365462175437, 0.15186543310327189, 0.2208852959530694, 0.3017479426094464, 0.225165508421404, 0.5032107979059219, 21.340926442827495, 106.03959233420235, 62.933843748910085, 68.84530857631138, 33.37460190909249, 66.52112919943673, 89.61030578613281, 32.983321053641184, 5.017017577375684, 0.13898278080991336, 0.9401443579367229, 0.48617788617100033, 2.345459972109113, 1.1885350751025336, 0.16817463295800344, 0.5407235249876976, 1.133436728801046, 37.00146777289254, 91.1047590800694, 95.116183417184, 79.38642760685512, 67.27013805934361, 71.96621009281704, 73.69730513436454, 76.4115355355399, 77.31448173522949, 78.28199059622628, 73.90791198185512, 72.53519807543073, 76.71406705038888, 74.26985754285539, 75.01373863220215, 72.98964500427246, 75.95649800981793, 74.70959513528007, 72.38318538665771, 70.52733543940953, 69.72151810782296, 74.37060642242432, 74.21118000575474, 73.34574018205915, 72.45449474879673, 69.8645328794207, 63.396517344883506, 57.073201520102366, 55.55625343322754, 54.859078134809224, 63.56897858210972, 63.35669027056013, 68.3646877833775, 65.4092298235212, 74.2162869317191, 65.9118138722011, 76.55066626412528, 36.56091376713344, 29.25968415396554, 83.0957373210362, 64.13497189113072, 73.95921748025077, 65.7548679624285, 70.04103796822685, 61.686788014003206, 63.94665486471993, 57.61116232190813, 56.769801480429514, 49.344744546072825, 57.660042898995535, 56.04996463230678, 67.73445143018449, 68.07683781215123, 68.63573006221226, 62.32101958138602, 60.2379982812064, 59.82568522862026, 64.29418986184257, 59.32202420915876, 62.556827545166016, 60.10020855494908, 56.43747609002249, 57.239232199532644, 65.66582679748535, 71.395325251988, 77.23987197875977, 72.84924275534493, 73.85330608912876, 68.67215946742466, 73.47387886047363, 72.0889013835362, 72.12067549569267, 72.91157504490444, 80.27812467302594, 67.77784293038505, 63.68576390402657, 73.44174344199044, 76.85300322941372, 38.319659164973665, 3.843967539923532, 0.20689857218946728, 0.3894456624984741, 0.46459851839712685, 0.7811991583023752, 0.1275283225945064, 0.28021254390478134, 7.802356277193342, 32.34980167661394, 61.70794527871268, 75.62508283342633, 15.48680509839739, 46.29994664873396, 55.832524231501985, 62.468314443315776, 50.4352399962289, 0.41397171786853243, 0.21017319576016494, 0.2113359197974205, 0.1429962475917169, 0.21305596535759314, 0.28637958584087236, 0.231216805854014, 0.16771708322422846, 0.10934645429785762, 0.19904693136257784, 0.13621726206370763, 0.15712489373981953, 0.17309334687888622, 0.11304166779986449, 0.12511153013578483, 0.1202993733542306, 0.11297317647508212, 0.1947367140757186, 0.16465171985328197, 0.2775660402008465, 0.1469586749694177, 0.14948621791388306, 0.17976342753640243, 0.1544503936810153, 0.12338813261262008, 0.09992511770022766, 0.13567180133291654, 0.16505155339837074, 0.16710273761834415], [0.09719921861376081, 0.05149219391335334, 0.057467566670051644, 0.07087797671556473, 0.027110172868041054, 0.06065755656787327, 0.0969834512631808, 0.03294805916292327, 0.032225195451506546, 0.09947486221790314, 0.03626555257609912, 0.022817923188475624, 0.026235398736649325, 0.022937657477866327, 0.08361429614680153, 0.04501531592437199, 0.017372834030538797, 0.04536898194679192, 0.02538885675104601, 0.022789825053353394, 0.07253508136740752, 0.0441671776851373, 0.032910637956644805, 0.09596180144165244, 0.08865801657416991, 0.03939392470887729, 0.038142404186406305, 0.04624012591583388, 0.07717840506562165, 0.03195689252710768, 0.0383056156071169, 0.09247898975653307, 0.14066952387137072, 0.1608863254742963, 0.04119623924738594, 0.24773389526775905, 18.226120233535767, 77.75200980050224, 57.15085111345564, 60.612916128976, 9.672781808035714, 40.0672527040754, 88.12421117510114, 39.21693216051374, 9.922177842685155, 1.7106919820819582, 0.8008621260523796, 0.2719542570412159, 0.3507941908070019, 0.17786739713379315, 0.15174200758337975, 0.08921250860605921, 0.049351636453398635, 5.219858944416046, 26.006912776402064, 66.07654871259416, 93.2319153376988, 86.77958188738141, 83.92408766065324, 78.29260049547467, 69.58377007075718, 75.41571971348354, 80.56144441877092, 74.86207335335868, 70.47726672036308, 71.20581313541958, 72.92042010171073, 66.90879004342216, 65.256897517613, 69.75834356035504, 73.52412128448486, 70.71256051744733, 70.50248173304966, 69.16917106083461, 71.8699289049421, 68.87367807115827, 69.44586917332241, 65.08866773332868, 66.70949486323765, 57.74337611879621, 54.30872869491577, 53.82977894374302, 61.47693157196045, 62.51377650669643, 68.57931068965367, 64.25660010746547, 68.82812568119594, 64.97846930367606, 74.16155597141811, 36.060938767024446, 30.9250214440482, 78.0764489855085, 64.77994537353516, 66.50567640577043, 64.43375832693917, 64.91275324140275, 60.76216343470982, 60.82730279650007, 56.3559250831604, 54.053337233407156, 50.86506250926426, 50.76853118624006, 58.40834999084473, 64.58843217577252, 64.2913133076259, 65.31025968279157, 59.59278161185128, 54.88678060259138, 57.17108079365322, 58.85040133340018, 58.532285009111675, 59.03598076956612, 55.68174484797886, 55.85857997621809, 51.631625992911204, 53.820906094142366, 61.34780624934605, 69.17953777313232, 72.20108004978725, 72.22111865452358, 65.68770667484829, 72.86795425415039, 72.26780360085624, 80.36470617566789, 73.28064945765904, 64.84057535443986, 71.26057188851493, 74.58833517347063, 39.150093964168, 5.465020486286708, 0.14020913786121778, 0.22504212361361298, 0.03712410632787006, 0.1062615355476737, 0.13732169994286128, 0.1895311019782509, 0.011215393364961659, 10.62031807218279, 17.98994401523045, 50.57506207057408, 55.54771409715925, 5.613547784941537, 34.71707725524902, 42.23504202706473, 52.725571223667686, 39.147808006831575, 0.33700540927903994, 0.13023745508066245, 0.07314450080905642, 0.05479610984080604, 0.07940746724073376, 0.13990611769258976, 0.053080247449023385, 0.06807437858411244, 0.016306509463382617, 0.058672414161264896, 0.09825957207275288, 0.06000641400792769, 0.09526467456349305, 0.02305548169117953, 0.01911940861360303, 0.026799492039052502, 0.043544031480061154, 0.06416529084422759, 0.014978545185710703, 0.015335142479411193, 0.08359079169375555, 0.05836167226412466, 0.08057901223323174, 0.06472738925367594, 0.0587773360311985, 0.03318095613004906, 0.011556932270260794, 0.022152931728799428, 0.011156847667215126, 0.007541418857207256, 0.044512860743062835, 0.02976648649200797, 0.017989902258185402, 0.06326836254447699, 0.04029198955478413, 0.05353434343955346, 0.04681791884026357, 0.09953734172242028, 0.022686226326706152, 0.03750368220997708, 0.03503880875983408, 0.05499527683215482, 0.02817036008595356, 0.06745415007961647, 0.04331902926787734, 0.018556423019617796, 0.0333455483695226, 0.028868475928902626, 0.07237293185400111, 0.04415563580447009, 0.034934144733207564, 0.012421614889587675, 0.052354781555810144, 0.07073162349739245, 0.06505668229822602, 0.028683839764978205, 0.11779357067176274, 0.021612018878970827, 0.04371315633345928, 0.035089664959481785, 0.032785587345383, 0.16537547244557313, 0.12521075909691198, 0.3027114894773279, 0.08104761530246053, 0.24288185419780867, 29.633014338357107, 85.22306728363037, 54.57753017970494, 34.8934885433742, 17.75817816598075, 83.38469205583844, 90.83503001076835, 35.63738700321743, 16.313720635005406, 1.269124842115811, 1.3184340362037932, 0.026947860506230166, 0.389514900211777, 0.5052513969796044, 0.1836084954972778, 0.09140276536345482, 0.17847900145820209, 8.736471227237157, 36.12256234032767, 77.21583815983364, 90.52560588291713, 80.7485385622297, 74.63676411764962, 72.2901142665318, 69.9153242111206, 77.19892624446324, 80.2127490724836, 77.02085781097412, 75.73592744554792, 71.11719581059047, 73.44271618979317, 68.91534641810826, 68.53197956085205, 73.97697707584926, 72.58132021767753, 71.99194622039795, 75.69575990949357, 70.09996564047677, 73.83619267599923, 68.82456820351737, 69.29068115779332, 67.32684230804443, 68.03540570395333, 58.906000818525044, 55.18369449887957, 55.478565624782014, 63.871746335710796, 62.8606653213501, 69.71959345681327, 63.750896317618235, 72.48274612426758, 65.34082480839321, 74.21621050153459, 37.60433864593506, 31.13216461454119, 77.94246687207902, 64.06558718000139, 69.83819225856236, 64.57014451708112, 66.24529266357422, 60.85401167188372, 61.883227484566824, 56.76575762884957, 54.50555379050118, 50.699066570826936, 50.811273029872346, 58.276264735630576, 65.28905378069196, 64.63865375518799, 65.33918503352574, 59.113856179373606, 55.045314175742014, 59.020340374537874, 61.6256160736084, 60.328213691711426, 59.11698981693813, 54.211867332458496, 56.5833500453404, 51.48347997665405, 56.88832037789481, 64.1795654296875, 68.25879723685128, 68.75623267037528, 69.28444862365723, 64.56678853716168, 70.90188503265381, 68.81856495993478, 76.47641086578369, 71.71923637390137, 63.27004623413086, 64.76374217442104, 82.47265761239188, 51.69594546726772, 8.919630084718976, 0.2713550291955471, 0.19598576133804663, 0.05302564573607274, 0.21015891938337258, 0.6623260112745422, 0.13013931177556515, 0.17597944129790577, 20.634661163602555, 29.355225358690532, 38.123775550297324, 85.96391895839146, 17.900998388017925, 11.429880482809883, 36.49279015404837, 54.34477942330496, 48.664661816188264, 0.9377041288784572, 0.130723951118333, 0.04710520378180912, 0.1138477266899177, 0.04685789133821215, 0.0842377884047372, 0.12411032457436834, 0.062249657564929554, 0.027277089089953473, 0.0242807276413909, 0.11131812099899564, 0.027888898671205555, 0.1160413489810058, 0.04845019250309893, 0.09051981488508837, 0.018694365796233927, 0.013572248280979693, 0.02721443316633148, 0.02665950856836779, 0.07758049813232251, 0.03868733565988285, 0.010473474693883742, 0.055196689774415324, 0.03983855852857232, 0.05075489776208997, 0.05671550898945757, 0.037982843284096034, 0.022336731598313366, 0.06211557225989444, 0.019026651180216243, 0.21328654512763023, 0.12890482587473734, 0.2166595155639308, 0.14775608932333334, 0.14490302598902158, 0.15121731002415928, 0.13446727953851223, 0.1897273478763444, 0.11145557183772326, 0.1646613007677453, 0.16886361741593905, 0.15663491003215313, 0.12653060470308575, 0.09594973030367068, 0.20037353517753737, 0.13963105316673005, 0.10151790401765279, 0.08842945883848838, 0.19273338014526026, 0.11533922808510916, 0.13121309344257626, 0.16460378813956464, 0.2382358977837222, 0.1376958984349455, 0.1523970788610833, 0.13481752574443817, 0.17518320759492262, 0.18771344237029552, 0.12198782632393496, 0.08731862915945904, 0.1741473696061543, 0.3024751421596323, 0.2771458641758987, 0.26807976780193193, 0.2841472870537213, 0.35242642036506105, 33.494368008204866, 107.62492111751011, 72.2446938923427, 77.19914163861955, 19.329079014914377, 54.906173024858745, 106.11156872340611, 57.95923580442156, 18.512677839824132, 2.369355478457042, 0.9671131393739155, 0.4567794608218329, 0.8583161288074085, 0.6307265268904823, 0.41372983370508465, 0.47618344532591955, 0.20225243935627596, 6.49882949250085, 29.19452394757952, 73.37573555537632, 94.92707429613385, 86.75458226885114, 80.13565186091832, 77.03327424185616, 69.81470039912632, 76.62724930899483, 85.06269591195243, 83.31722504752022, 79.3038969039917, 76.09899166652134, 80.09197548457554, 75.84437492915562, 71.33474390847343, 74.52450207301548, 78.30444717407227, 77.80148792266846, 79.41309479304722, 73.86276953560966, 79.21621063777378, 75.43156160627092, 74.68975802830288, 74.21846866607666, 74.69018186841691, 65.0458459854126, 61.398215430123464, 61.33413914271763, 68.7702888761248, 69.30684961591447, 75.63549123491559, 70.01211956569126, 74.03416075025285, 70.41196755000523, 76.29326329912458, 44.64119277681623, 41.42657743181501, 78.51943833487374, 69.21853801182338, 71.96849605015346, 71.23903942108154, 70.25595269884381, 65.09673459189278, 65.84866864340646, 60.83758613041469, 58.44063826969692, 55.8377423286438, 54.4186144556318, 64.21379225594657, 67.57039056505475, 68.92893014635358, 69.49998869214738, 64.31242888314384, 58.715571539742605, 64.44306891305106, 65.69312626974923, 67.2004337310791, 65.63943753923688, 59.551154954092844, 60.98178904397147, 56.53820759909493, 60.18786702837263, 66.36767823355538, 74.17657797677177, 76.61614608764648, 72.41250678471157, 64.09899411882672, 73.3530774797712, 73.94509874071393, 79.68485968453544, 73.28222669873918, 67.70325401851109, 73.13753046308244, 79.52648939405168, 43.70005232947213, 7.55534781728472, 0.3615180567971298, 0.38190963545015877, 0.16239721940032073, 0.3264193944633007, 0.562413575393813, 0.17682462451713427, 0.2662687306957585, 16.05521638052804, 33.22890860693795, 66.23698956625802, 68.74100221906389, 15.020054646900721, 51.69758871623448, 56.01681825092861, 64.2221439906529, 61.25382491520473, 1.1779202904020036, 0.20017625790621552, 0.19523998349905014, 0.13591679318674973, 0.17005802903856548, 0.21864846455199377, 0.19463208397584303, 0.2924433818885258, 0.11608862930110522, 0.09271813263850552, 0.15954478031822614, 0.09182364706482206, 0.15058639459311962, 0.116781549262149, 0.27051288581320215, 0.13345147190349443, 0.16843840666115284, 0.0922586830066783, 0.09525273913251502, 0.11230004259518214, 0.17540177729512962, 0.10838147572108678, 0.16037935124976294, 0.19127600906150682, 0.1417165169758456, 0.12495443570826735, 0.1327017449906894, 0.09623656062675373, 0.15356111925627502, 0.08934134205004998], [0.01336780228718583, 0.18341214103358133, 0.14924248813518456, 0.03317479842475482, 0.13883780501782894, 0.06001633418990033, 0.05839209777436086, 0.08561135362833738, 0.08211357346070663, 0.0973481774064047, 0.08527221504066672, 0.10461966400699955, 0.11609621532261372, 0.11819370277225971, 0.10188002458640508, 0.07821192924997636, 0.06500444867249046, 0.11979269768510546, 0.1028300007539136, 0.08773992476718766, 0.09700487939906971, 0.13915679790079594, 0.05389344113479767, 0.1931310152368886, 0.15342974130596432, 0.05964180321565696, 0.1470762922295502, 0.10689992843461887, 0.054390223763350926, 0.07190101753388133, 0.13155059676085198, 0.1027216115700347, 0.27386083187801497, 0.22292232593255384, 0.2432159919823919, 0.10082628684384481, 0.40341045601027353, 18.812711477279663, 68.26866367885044, 58.091084820883616, 59.26948887961251, 14.794484853744507, 16.64308782986232, 80.43369483947754, 54.71692841393607, 19.353960514068604, 8.942592144012451, 0.18147634847887925, 0.3639777462397303, 0.38662393391132355, 0.4262928824339594, 0.2759817694979054, 0.3748055637947151, 0.11266663470970732, 0.2553040661982128, 0.5619934807930673, 17.502559150968278, 42.78094114576067, 64.54604121616909, 86.43786253247941, 91.33769048963273, 78.55201843806675, 74.56877599443708, 73.30366883959088, 78.8586424418858, 74.42669228145054, 71.74707780565534, 72.52344172341483, 78.28868171146938, 74.05387278965541, 73.11538655417306, 71.78164509364537, 73.0836958203997, 71.88151155199323, 70.31212888445172, 72.68520968300956, 71.0517646244594, 68.70484379359654, 66.46777398245675, 64.65642724718366, 62.02456079210554, 58.711208071027485, 61.740990911211284, 68.3381039755685, 71.2373023714338, 69.24464934212821, 71.50320298331124, 69.47364807128906, 66.77710778372628, 46.88398790359497, 29.944762638637, 70.0578248160226, 68.83168315887451, 66.15774536132812, 63.99422223227364, 62.679115840366904, 62.06436007363455, 62.15155301775251, 60.12519427708217, 55.25352389471871, 49.73234633037022, 51.234199455806184, 61.51480620247977, 64.47025721413749, 67.63725308009556, 63.407648359026226, 60.80519362858364, 55.2434663772583, 58.37491525922503, 58.879305839538574, 58.7413979939052, 59.89973218100411, 60.303471156529014, 57.07426459448678, 58.559640066964285, 56.51947178159441, 63.32563877105713, 66.95947715214321, 68.06972285679409, 70.22799314771379, 74.91281604766846, 74.82298278808594, 74.22122015271867, 65.8198961530413, 70.53768130711147, 91.27401024954659, 57.7649051121303, 6.350441592080252, 0.5173285603523254, 0.27435312260474476, 0.046838179895920415, 0.16577924149377005, 0.330168219017131, 0.11838431682969842, 0.385749383696488, 1.5973723999091556, 13.21201525415693, 19.937911442347936, 59.53717517852783, 58.55756255558559, 5.667801490851811, 44.36459541320801, 48.11203684125628, 50.626193864004954, 33.93785762786865, 0.061486203888697286, 0.11413200572133064, 0.12666640670171805, 0.16160154209605285, 0.06168821054909911, 0.18710912551198686, 0.16086474806070328, 0.12793430366686412, 0.014696415413969328, 0.1505699876163687, 0.04951363329642585, 0.10657072359962122, 0.09037273563444614, 0.14734396072370665, 0.14553543419710227, 0.11351659481546708, 0.10490068607032299, 0.1659074439001935, 0.10802457308662788, 0.10753437903310571, 0.05472216309447374, 0.1437632500060967, 0.1261702347546816, 0.08651405626109668, 0.05699229360158954, 0.097675950532513, 0.03998196690476366, 0.16759684681892395, 0.1439643542149237, 0.05924724867301328, 0.10989858502788202, 0.08675446121820382, 0.08898404586528029, 0.03140372024582965, 0.04198032378086022, 0.16328809516770498, 0.06132938766053744, 0.022537060580881577, 0.016760714019515684, 0.022751625228141035, 0.05138544678421957, 0.04400171692083989, 0.07239694520831108, 0.06479566344725234, 0.06937833968549967, 0.06968193660889353, 0.06461026053875685, 0.027639302957270826, 0.0805586018998708, 0.09450813515910081, 0.08013415788965565, 0.059167262965015004, 0.06115675478109291, 0.1408359142286437, 0.09261631167360715, 0.08010134393615381, 0.08655227135334696, 0.02442168820250247, 0.08707428191389356, 0.07713586770530258, 0.03898121935448476, 0.09743254645062344, 0.04407227438475404, 0.21604796552232333, 0.15073702936725958, 0.2184041105210781, 0.14153434389403888, 0.19615477084049157, 33.45602090018136, 76.70454107012067, 51.22110210146223, 21.505737713405065, 14.448550547872271, 53.92175572259085, 93.07961082458496, 47.835613182612825, 30.300027506692068, 14.333048905645098, 0.1960713653159993, 0.44056347810796326, 0.4787230119109154, 0.22709855969463075, 0.19087526627949306, 0.22673367070300238, 0.20443257237119333, 0.5191171786614827, 1.5729529559612274, 27.179912873676844, 56.96140847887312, 76.67994444710868, 89.43420369284493, 82.54965060097831, 74.47478076389858, 75.87085451398576, 75.77833924974713, 78.36564690726144, 75.69518320901054, 76.39612443106515, 76.32710102626255, 79.56653186253139, 74.10217666625977, 77.7407398223877, 74.31207479749406, 71.21039199829102, 73.14201205117362, 71.57204573495048, 72.42171314784459, 72.91080379486084, 70.60225091661725, 68.45655686514718, 64.02345330374581, 59.87820666176932, 56.7901805468968, 62.712613105773926, 68.5014283316476, 71.30729157584054, 68.31173556191581, 73.45955862317766, 71.17056492396763, 68.78524834769112, 45.69143731253487, 35.462931632995605, 69.15130029405866, 68.69865989685059, 68.00110244750977, 68.67986501966203, 65.16101932525635, 64.49808474949428, 63.12871987479073, 61.77473136356899, 59.03785678318569, 51.55709614072527, 53.14962673187256, 63.97571917942592, 68.65612997327531, 70.431200163705, 68.03557246071952, 64.28764465876988, 57.48627887453352, 58.51171139308384, 60.080364499773296, 59.191057613917756, 60.9196652003697, 63.10877159663609, 58.23695182800293, 56.705092906951904, 52.48846394675118, 60.29147856576102, 67.14293738773891, 71.70112936837333, 68.95236642020089, 71.41702447618756, 70.24164635794503, 71.92854390825543, 68.89354297092983, 64.72637476239885, 88.00576523372105, 72.38758359636579, 11.335457069533211, 0.5558518703494753, 0.27583585732749527, 0.3617741901959692, 0.059629888140729496, 0.20492710226348468, 0.4804771606411253, 0.5241758472153119, 2.4793901911803653, 26.00447048459734, 25.315587861197336, 43.77505465916225, 87.50044359479631, 14.57395771571568, 14.760688815798078, 44.260205677577424, 54.81378282819475, 44.70405660356794, 0.36408158923898426, 0.12143057265451976, 0.09386012064559118, 0.12150033962513719, 0.03028311626985669, 0.10195231570729188, 0.13398812524974346, 0.1789605441902365, 0.057451777160167694, 0.1473543830215931, 0.06009763625583478, 0.059506116567977836, 0.12163481169513293, 0.042580389617277045, 0.031445273730371676, 0.12801948695310525, 0.053505580340112956, 0.11141329232071127, 0.03605861296611173, 0.052777105144092014, 0.0667243381696088, 0.050268751169954023, 0.07123139168002776, 0.0869225954104747, 0.06861312181821891, 0.03834591380187443, 0.028875698934176137, 0.1308556276240519, 0.05505650104688747, 0.06863154404397522, 0.11122056801936456, 0.2023185422377927, 0.17445292749575206, 0.1789555773139, 0.09898797941527196, 0.2945949621498585, 0.16848674549588136, 0.15780965770993913, 0.18071592785418034, 0.2693624161183834, 0.2440539827304227, 0.1853257454931736, 0.2012759188988379, 0.1763155332633427, 0.18922296565558228, 0.16536236314901284, 0.22779720649123192, 0.18328195730490343, 0.1736202293208667, 0.20164743039224828, 0.11002345582736389, 0.18758585064538888, 0.22986825821655138, 0.19638354570737906, 0.36805034056305885, 0.17268786792244228, 0.24977389723062515, 0.18994755963129656, 0.15172667269195828, 0.15512146481445857, 0.14786863114152635, 0.14533595847232, 0.09887728999767985, 0.27624566533735817, 0.26626740076712196, 0.3004703154521329, 0.14531818085483142, 0.3931378429489476, 35.72359677723476, 100.16320201328823, 72.81309127807617, 79.75646087101528, 24.837689025061472, 27.96772915976388, 91.72266238076347, 71.48928574153355, 33.286891324179514, 12.036749175616674, 0.2707784372781004, 0.5703390815428325, 0.3880948621247496, 0.4350873476692608, 0.2558966444006988, 0.45800842344760895, 0.35538651581321445, 0.47578338107892443, 0.7139077005641801, 19.303172656467982, 46.81722961153303, 68.89250768933977, 87.74943923950195, 90.68298952920097, 79.96997206551688, 75.23783193315778, 76.73540496826172, 85.4086606161935, 81.48224748883928, 80.28750474112374, 79.07748985290527, 84.79869910648891, 82.84943757738385, 82.09813581194196, 76.8025176184518, 77.27992834363664, 79.59625625610352, 76.71926430293492, 77.01024096352714, 78.70850576673234, 76.91804531642369, 73.36556339263916, 70.28038951328823, 66.7361342566354, 60.93264443533761, 65.11025578635079, 72.22161892482212, 75.25319440024239, 72.92465155465263, 77.30090495518276, 74.93133299691337, 69.19835349491665, 52.15486356190273, 38.80996227264404, 69.25606523241315, 72.13676752362932, 70.399078641619, 72.30568517957414, 67.87324864523751, 69.68322658538818, 67.17297445024762, 67.47411632537842, 63.162578446524485, 57.2281949860709, 55.711486612047466, 69.24551091875348, 72.20689569200788, 73.75184154510498, 71.21916757311139, 68.62530776432583, 62.1904490334647, 65.66081714630127, 63.729037284851074, 63.85070719037737, 66.53417791639055, 69.69949231828961, 66.60512597220284, 64.7480948311942, 59.22690337044852, 66.55983761378697, 72.66974299294608, 75.8981192452567, 75.55659443991524, 78.16039712088448, 73.26730196816581, 71.58083520616803, 71.94464288439069, 73.12355068751744, 92.4138274874006, 65.41835280827114, 8.182031035423279, 0.6543988766414779, 0.385732393179621, 0.4154800740735871, 0.17356653005949088, 0.35014686839921133, 0.3718434327415058, 0.4310453145631722, 3.0570540853909085, 23.76115597997393, 34.24284880501883, 74.8284579685756, 72.32795415605817, 13.480883615357534, 62.925860268729075, 61.94007069723946, 65.05107797895158, 54.69264445986067, 0.7692228523748261, 0.1951118353754282, 0.2346147463790008, 0.18733294707323822, 0.1417552748961108, 0.24291046123419488, 0.15097510016390256, 0.2897378999207701, 0.13180966143097195, 0.19691376654165132, 0.10596584355724709, 0.20367644008781227, 0.24901551221098217, 0.22591185622981616, 0.21580377433981213, 0.23390014043876103, 0.17700100290988172, 0.20432905506874832, 0.24724670712436947, 0.21393238832908018, 0.16661230607756547, 0.16002565808594227, 0.25264160335063934, 0.20990957133471966, 0.18124043542359555, 0.13663226765181335, 0.10513376284922872, 0.22042903543582984, 0.21652819189642156, 0.19454778278512613, 0.18449359014630318], [0.16999136975833348, 0.12132567114063672, 0.14431025779673032, 0.24726801312395505, 0.1755898536315986, 0.07323952285306794, 0.1455553559852498, 0.14074423057692392, 0.01982864734184529, 0.21362577192485332, 0.1701552088239363, 0.12602797310267175, 0.10426185892096587, 0.1406058772866215, 0.0596169824046748, 0.18576422839292459, 0.06185261279876743, 0.1618374144392354, 0.0486903294388737, 0.2623352360512529, 0.150482782295772, 0.13257472323519842, 0.1280309541949204, 0.09111248129712683, 0.137216717004776, 0.04499032208696008, 0.030672228961650814, 0.010171718296727963, 0.2357243411242962, 0.09492784978023597, 0.14352412069482462, 0.14459573104977608, 0.2867860554584435, 0.27707616505878313, 0.15125195602221148, 0.2918121543313776, 0.3776729985007218, 0.3561684867101056, 17.50592381613595, 80.3873850958688, 55.68825878415789, 61.12163543701172, 34.30502128601074, 20.82739724431719, 70.12381185804094, 65.92024203709194, 26.410309553146362, 12.048154643603734, 3.86145441872733, 0.39247890402163776, 0.22670115530490875, 0.36079780544553486, 0.31466575658747126, 0.6598943588989121, 0.8099075949617794, 0.5718309900590351, 0.2303426084773881, 0.3506561496428081, 1.0042091373886382, 8.044895308358328, 36.64683519090925, 74.87238448006767, 91.64243153163365, 85.18276078360421, 72.72916398729596, 76.16327639988491, 79.83270345415387, 75.97375733511788, 70.82701124463762, 73.05600030081612, 77.7754738671439, 78.55285222189767, 75.07805115836007, 74.23849337441581, 75.86031409672329, 75.58296285356793, 71.19429997035435, 67.65948036738804, 69.38771275111607, 68.09364550454276, 63.4092811856951, 61.172878401620046, 61.674302101135254, 68.7439274106707, 70.30595888410295, 70.30973175593785, 71.5598794392177, 68.99698775155204, 72.85631602151054, 50.751647063664024, 29.766020229884557, 71.63838713509696, 70.42751067025321, 69.43169484819684, 67.6952496937343, 68.8827246257237, 64.88320255279541, 65.30306134905133, 63.14105292728969, 57.71993637084961, 53.33994483947754, 52.9264679636274, 65.6915420804705, 64.04532623291016, 65.52957957131522, 66.05389758518764, 63.83539336068289, 56.85413176672799, 57.97545289993286, 60.01373127528599, 62.181722096034456, 62.73452772412981, 60.540335246494834, 63.08085373469761, 62.66107136862618, 64.43309129987443, 65.4911699295044, 70.00211415972028, 75.1568854195731, 71.17510904584611, 71.81777572631836, 72.74019077845982, 75.94836166926792, 70.30265154157365, 72.08673354557583, 25.4775173664093, 0.6293446496129036, 0.09716529864817858, 1.8845681548118591, 0.05391434679872223, 0.35598213385258404, 0.4029410183429718, 0.10778052439647061, 0.19066429617149488, 4.543403608458383, 16.300084795270646, 33.138651507241384, 70.19712924957275, 47.691757678985596, 9.672911218234471, 44.539099420819966, 50.79984324319022, 52.414729663303916, 18.913597583770752, 0.25772195788366453, 0.053026348019817045, 0.054603643382766416, 0.04229308431968093, 0.1402913084519761, 0.12273652186351162, 0.21247412157910212, 0.20439800779734338, 0.15462453290820122, 0.04788859620956438, 0.18157726020685264, 0.1551362025950636, 0.1484331451356411, 0.03250594949349761, 0.08288860294435706, 0.03117667225056461, 0.20212883741727897, 0.19264055655470916, 0.1738739607057401, 0.2226953288274152, 0.2007924219859498, 0.04322723026520439, 0.06648251507431269, 0.08072584721126727, 0.07257995288819075, 0.1467167500938688, 0.1170231755822897, 0.17670882573085173, 0.09473787354571478, 0.043227691669017076, 0.2388437565948282, 0.15051529769386562, 0.16351429160152162, 0.1137868824547955, 0.11826741881668568, 0.12897253009889806, 0.24310625929917606, 0.042161991354078054, 0.021305163291149905, 0.2098369002342224, 0.05534969942112054, 0.1472393170531307, 0.08089995251170226, 0.08320185542106628, 0.050270121810691695, 0.12504934918667587, 0.12101775194917407, 0.10723475832492113, 0.054035957237439494, 0.19514565356075764, 0.08896957271333251, 0.14354970146502766, 0.13347129869673932, 0.09791900856154305, 0.08293741675359861, 0.09207665920257568, 0.12883792232189858, 0.01292551280598023, 0.07257894187101296, 0.06178717488156898, 0.22608797677925654, 0.1060496765588011, 0.1395762682493244, 0.14031847699412278, 0.24636789570961679, 0.17020309982555254, 0.14032204608832086, 0.14131254436714308, 0.23724154542599404, 0.29155667232615606, 30.21236903326852, 87.17502471378872, 54.821630818503245, 30.456007616860525, 3.0037197130067006, 43.6565774508885, 90.61064488547188, 57.516684191567556, 31.14398350034441, 26.991238015038626, 3.2225760264056067, 1.2802239379712512, 0.17801630842898572, 0.3343295928622995, 0.4699767498033387, 0.7940284641725677, 0.5999779254198074, 0.5422910494463784, 0.5824531029377664, 0.49945100822619026, 2.71299210190773, 14.661772523607526, 52.89010109220232, 86.12843145642961, 85.05724157605852, 77.64740467071533, 76.97807080405099, 79.36154610770089, 79.12179156712124, 75.86571979522705, 75.44692407335553, 78.72014399937221, 76.69098513466972, 78.83057866777692, 79.85287407466343, 74.69305842263358, 77.78520134517125, 76.4068385532924, 74.04144941057477, 69.77553340366909, 71.12959834507534, 70.71566636221749, 65.60093062264579, 62.70916679927281, 63.283025469098774, 69.32786096845354, 72.2336254119873, 70.98663221086774, 72.48790168762207, 70.21042810167584, 67.6280745097569, 56.55199629919869, 33.6784987449646, 69.89846093314034, 71.56360367366246, 69.57360485621861, 66.20047678266252, 64.982818875994, 65.24163927350725, 64.96694224221366, 61.47643824986049, 58.51625551496233, 53.488070011138916, 52.54851722717285, 65.76533889770508, 64.22384629930768, 65.21933555603027, 64.8056537083217, 64.96526772635323, 59.83498191833496, 59.779931340898784, 62.793844495500835, 64.07786464691162, 62.546537263052805, 61.097407068525044, 61.861729758126394, 63.611404282706125, 65.72286455971854, 67.85938698904855, 68.10732650756836, 69.03012371063232, 69.94438852582658, 69.97688525063651, 68.97252314431327, 69.07448101043701, 67.24095562526158, 79.45987006596157, 38.17469889777047, 1.9994468476091112, 0.15064801914351328, 1.5804245493241718, 0.29309615971786634, 0.14101128838956356, 0.7350542715617588, 0.06900299446923391, 0.35498886715088573, 10.83030652999878, 32.486371994018555, 27.596940279006958, 64.0027824129377, 83.51433154514858, 14.32997259071895, 19.912534884044103, 47.759047508239746, 55.30315487725394, 29.564258439200266, 0.230253096137728, 0.06199533585458994, 0.08508570612009082, 0.07557418543313231, 0.15003986177699907, 0.07563422221158232, 0.08356522449425288, 0.16167753801814147, 0.07857699466070958, 0.11673820444515773, 0.17375711697552884, 0.036729392329497, 0.1267968618444034, 0.06570023883666311, 0.05795068360332932, 0.04858091566711664, 0.18105249479413033, 0.06957305209445101, 0.08489865437150002, 0.203774488398007, 0.15853070973285607, 0.08462490620357649, 0.08144360155399356, 0.07159337654177632, 0.05209760660571711, 0.09737630946827786, 0.053350005831037245, 0.19773452250020845, 0.052825803602380414, 0.049936845765582154, 0.13919103677783692, 0.1133866553593959, 0.22402107768825122, 0.14719540226672376, 0.2165792855833258, 0.3908906163913863, 0.25470641255378723, 0.14037129415997437, 0.1295089934553419, 0.26381620658295496, 0.14913757305060113, 0.3113073610833713, 0.23120296373963356, 0.19695683994463511, 0.15436345977442606, 0.13311111873814038, 0.19318657368421555, 0.18870257000838006, 0.12415696707155023, 0.2437620498239994, 0.12308125836508614, 0.3091440557369164, 0.29125472424285753, 0.16076589907918656, 0.1811944307493312, 0.1680919738220317, 0.17320502017225536, 0.08582389115222863, 0.13504650417183126, 0.11705660021730832, 0.23536927731973784, 0.19846265842872007, 0.14705935599548475, 0.14849848805793694, 0.346430097839662, 0.21061517990061215, 0.1673675019826208, 0.31742853405220167, 0.35389604579125133, 0.33455614213432583, 32.5978558404105, 106.17630508967808, 72.98171016148159, 79.02457237243652, 47.416827883039204, 41.11565249306815, 81.77899810246059, 76.47788388388497, 38.79380423682076, 18.316038608551025, 3.865696293967111, 1.0449843151228768, 0.44601244000451906, 0.37836154869624544, 0.4960937255195209, 1.5926562015499388, 1.4617578940732139, 0.8035813687103135, 0.5479319553290094, 0.7493389536227498, 1.5209716366870063, 9.606150320598058, 43.717610427311485, 81.77602427346366, 93.98195253099713, 88.07832527160645, 77.78459685189384, 81.6820707321167, 85.89083780561174, 82.93385124206543, 78.68645218440464, 79.73663071223667, 82.637051991054, 87.83497156415666, 85.8515179497855, 79.82295513153076, 84.76849528721401, 85.33853244781494, 77.41480677468437, 74.68765967232841, 75.26385293688092, 76.5714761189052, 71.61356122153146, 69.04570157187325, 67.81498800005231, 75.91002150944301, 74.94724437168666, 76.07738971710205, 75.83673191070557, 73.75419003622872, 70.82051467895508, 62.61196150098528, 40.90470518384661, 74.17687674931118, 75.461167880467, 74.19392762865338, 73.31932313101632, 73.49207619258335, 69.19107178279332, 68.66326577322823, 66.47512517656598, 63.345538411821636, 57.16744341169085, 57.01587193352835, 71.58452469961983, 68.66414819444928, 68.73375524793352, 70.63356644766671, 70.55583695002964, 64.64869390215192, 65.93586158752441, 69.73385810852051, 71.30233751024518, 70.00849260602678, 65.8993557521275, 68.61706025259835, 67.95976761409214, 72.87353365761894, 75.62487438746861, 78.90167263575962, 78.93833827972412, 74.86932727268764, 74.07329995291573, 76.46311896187919, 82.99007606506348, 81.93290764944894, 75.69586413247245, 29.69920982633318, 1.5847376435995102, 0.25275958701968193, 3.8002134306090216, 1.26551753282547, 0.2840765565633774, 0.7425312932048524, 0.07952041617993798, 0.2880191435771329, 8.806849530764989, 33.73731524603707, 47.20006840569632, 85.7400757925851, 64.02531542096818, 19.287567002432688, 64.04372814723423, 62.72138173239571, 68.85918412889752, 41.811493737357004, 0.5491595066019467, 0.24452684021421842, 0.15584129547434195, 0.2161248978227377, 0.12406175503773348, 0.19916730347488606, 0.2006033414176532, 0.33778154477477074, 0.2452488557568618, 0.15630998675312313, 0.22311927750706673, 0.2787371373602322, 0.1623746377549001, 0.32335827872157097, 0.13947150244244508, 0.18099898552255972, 0.2781382623527731, 0.27426892997963087, 0.2799928885485445, 0.3559533368263926, 0.2590714011873518, 0.19195624041770185, 0.16395637073687144, 0.1891333990331207, 0.13694952348513262, 0.21576992901308195, 0.2205135537577527, 0.2642270731074469, 0.13400856272450515, 0.0888640537325825, 0.244988813996315, 0.20599643274077348], [0.27079493924975395, 0.23961196680154118, 0.1694006236003978, 0.10471013986638614, 0.3515741532402379, 0.05735402062003102, 0.16870657727122307, 0.22620796891195433, 0.187321113422513, 0.1779569908976555, 0.20766811232481683, 0.12938955772135938, 0.11528774084789412, 0.12656755772020134, 0.11323677375912666, 0.1256993721638407, 0.04386098536529711, 0.1248157974332571, 0.09179584748510804, 0.07622786571404763, 0.13919980345027788, 0.13613419580672467, 0.15392834240836756, 0.03746792341449431, 0.21725795630897793, 0.1949930510350636, 0.10664710628667048, 0.16310597636869975, 0.15986130333372525, 0.14152610647891248, 0.1544539084924119, 0.22399089645062173, 0.1957589949348143, 0.2800141674067293, 0.27795522074614254, 0.2656616047024727, 0.2358568725841386, 0.19127123217497552, 0.14294075699789183, 13.211382968085152, 68.10663168770927, 63.422913551330566, 73.68522221701485, 40.999235425676616, 28.992426906313213, 57.525233949933735, 97.01832921164376, 46.61951167242867, 33.214928831372944, 14.87057283946446, 0.2705303377338818, 0.2373779852475439, 0.1831920649856329, 0.32657676030482563, 0.34261583536863327, 0.30601777349199566, 1.3142314617122923, 1.3619377932378223, 0.10762008479131119, 0.10360340853886944, 0.12770672302160943, 3.0679421297141483, 23.178561687469482, 58.475149972098215, 83.21304375784737, 85.03653594425747, 76.7084459577288, 70.9468607221331, 84.49960694994245, 72.03163433074951, 76.88159506661552, 83.98036112104143, 75.86888122558594, 82.18554415021623, 82.12651920318604, 75.36277444022042, 75.29883016858781, 75.28069537026542, 72.95106165749687, 73.76428576878139, 70.37251567840576, 66.93048231942313, 64.21618243626186, 70.31573499952043, 70.79019968850272, 70.81060654776437, 71.08256598881313, 69.03515420641217, 64.42052895682198, 54.13895641054426, 26.405718530927384, 59.705696787152974, 68.90544523511613, 63.088531494140625, 67.8490550177438, 66.4197688783918, 64.75118677956718, 62.320838928222656, 62.772506577628, 55.84102535247803, 54.3664265360151, 53.553000926971436, 61.485880851745605, 64.57051971980503, 64.58495112827846, 63.49061679840088, 66.04218987056187, 61.20643820081438, 59.524168150765554, 59.719211033412385, 62.24260221208845, 63.99532699584961, 65.39650767190116, 65.5847065789359, 69.54772281646729, 69.60200214385986, 73.87778459276471, 73.0175142288208, 72.25363622392926, 75.02586323874337, 76.02034500667027, 64.8602318082537, 40.7795854977199, 16.917777912957327, 2.792762632880892, 0.10003039240837097, 0.13260840571352414, 0.9757053468908582, 4.734428695269993, 0.41956292784639765, 0.11349762297634568, 0.19177500371422085, 0.3169403688183853, 11.21820534978594, 20.405000618525914, 38.19773217609951, 58.076041970934185, 29.409713132040842, 11.732042006083898, 48.827069010053364, 49.32366371154785, 51.327652726854595, 20.302971533366613, 0.39882005804351395, 0.12133320287934371, 0.08841575921646186, 0.06859094050845929, 0.07312463330371038, 0.1277132233870881, 0.06233401982379811, 0.12900280633143016, 0.18188646861485072, 0.18041932662682875, 0.11456348613968917, 0.11197472576584135, 0.10678683700306074, 0.19213412515819073, 0.12267592868634633, 0.16449865592377527, 0.14186413905450276, 0.0702980939032776, 0.19800753785031183, 0.07009629080338137, 0.13291107304394245, 0.1684947929212025, 0.16191064193844795, 0.10256879191313471, 0.07702215202152729, 0.019861848060307757, 0.0571211338309305, 0.15051900249506744, 0.08433390967547894, 0.1526246052235365, 0.14338750445416995, 0.13050010241568089, 0.1631132231226989, 0.20609840298337595, 0.183035174118621, 0.11569906877619879, 0.11559893057814666, 0.2228254582732916, 0.12174305160130773, 0.06318214788500752, 0.09051817961569343, 0.1837578546255827, 0.14866124146750995, 0.10428718863321201, 0.07562633763466563, 0.12214470362024647, 0.09630395951015608, 0.11059678399137088, 0.13663245764161858, 0.0649011077891503, 0.11820489860006742, 0.08903458993881941, 0.12803027565990174, 0.06972349687878575, 0.2182566105787243, 0.16334610991179943, 0.04697267232196672, 0.140626708311694, 0.19078434258699417, 0.08407551675502743, 0.09388432398970638, 0.12669016899807112, 0.06693988160363265, 0.11134486884943076, 0.17629240878990718, 0.13841469772160053, 0.1943819895386696, 0.21512276945369585, 0.25072018216763226, 0.18212767424327986, 0.1787138967109578, 0.06346403168780462, 24.399407080241613, 78.90756470816476, 66.68350860050747, 57.26733766283308, 24.960507120404923, 39.48212405613491, 74.70622525896344, 76.05766378130231, 24.337432622909546, 39.61654390607561, 19.751880373273575, 0.3561411824609552, 0.5689640981810433, 0.11158239003270864, 0.32906587102583473, 0.4357769563794136, 0.4385135423924242, 0.8312944759215627, 1.7700922404016768, 0.24615901548947605, 0.3379087836614677, 0.29790496453642845, 8.991836633001055, 41.50892400741577, 75.69434247698102, 84.05978597913469, 82.61643668583461, 79.84632887159074, 74.34844861711774, 86.44560282570976, 73.26316084180559, 80.8501420702253, 84.45278303963798, 74.32745810917446, 81.84964738573346, 77.48807552882603, 75.76304626464844, 73.51622813088554, 74.29774066380092, 69.8520678111485, 68.45065784454346, 66.80950723375592, 64.20659392220634, 64.11437048230852, 69.43680872235979, 72.86653682163784, 72.2545394897461, 70.96043055398124, 70.37790053231376, 71.42271505083356, 55.796146937779014, 34.265569414411274, 65.12712601252964, 67.10283933367047, 69.6281065259661, 73.00357614244733, 70.7688548224313, 69.70968532562256, 67.31054183415004, 65.97291633061, 60.295918464660645, 57.83482830865042, 56.967578479221885, 63.80719062260219, 67.21965939658028, 66.05537755148751, 68.7923355102539, 67.96147687094552, 63.33527592250279, 63.211980138506206, 63.109876360212056, 63.09925256456648, 64.6109721320016, 66.8886889048985, 66.36778245653424, 66.69659205845424, 65.02081162588937, 65.94518607003349, 72.54810088021415, 76.99472563607353, 73.24011366707938, 78.56683894566127, 73.63386808122907, 57.5005886895316, 30.74362482343401, 6.302617575441088, 0.19210162333079747, 0.12945614914808953, 1.2840985357761383, 6.145459745611463, 0.5508847768817628, 0.38363840697067125, 0.16629511809774808, 0.33294060453772545, 19.827735594340734, 24.931977816990443, 32.017601353781565, 74.42639350891113, 55.28729213987078, 11.01372594492776, 28.353460141590663, 48.74860300336565, 56.73742287499564, 28.214796679360525, 0.5764447024890355, 0.07166707223015172, 0.1290481188999755, 0.08678405891571726, 0.06045208937887635, 0.06196282045649631, 0.02625553256699017, 0.1208692342042923, 0.16288486894752296, 0.1747577389968293, 0.14805133348064764, 0.10489236044564418, 0.15009771367268904, 0.18059130811265536, 0.17872339620121888, 0.1307299222264971, 0.09345158149621316, 0.04944065346249512, 0.13842642280672277, 0.07113646463091884, 0.07030962899859462, 0.10984937088297946, 0.07340108204100813, 0.059058351309171746, 0.055359952085252316, 0.005640820641669312, 0.06058225953685386, 0.07878374428089176, 0.07348070134009634, 0.2975752779415676, 0.028295353021738783, 0.14048379526606627, 0.13170277859483445, 0.32146845012903214, 0.26214274923716274, 0.2147613274199622, 0.12387092384908881, 0.41579491432224003, 0.1956034204257386, 0.21885416922824724, 0.25908980305705753, 0.29782549451504436, 0.27064392449600355, 0.304459205695561, 0.17028892093471118, 0.2474750205874443, 0.1627147195062467, 0.20160572763000215, 0.24473612755537033, 0.18265819363296032, 0.2463290835065501, 0.2112521750054189, 0.2608390934765339, 0.17822593503764697, 0.3827129394880363, 0.25705064247761455, 0.2160449663975409, 0.3732474845434938, 0.42672597776566235, 0.1985577211848327, 0.2263470007372754, 0.2007105363798993, 0.1410560988421951, 0.2732778074485915, 0.28835767826863695, 0.1889397179973977, 0.3410110186253275, 0.31118131641830715, 0.35803964201893124, 0.18230433762073517, 0.32008168739931925, 0.22221052912729128, 23.599639892578125, 94.00243582044328, 83.18000507354736, 91.5749158859253, 55.15170499256679, 43.17164530072893, 70.61623069218227, 107.81964438302177, 57.07743297304426, 44.08703224999564, 18.703975643430436, 0.18921130842396192, 0.8219092509576252, 0.2574501910379955, 0.3925015670912606, 0.5330864233630044, 0.8665235798273767, 1.3325724261147636, 1.4503193135772432, 0.22971518071634428, 0.24719847685524396, 0.33491261729172295, 4.752096661499568, 31.440501349312918, 66.6436606815883, 89.52498190743583, 92.93981306893485, 86.27442005702427, 76.04549053737095, 95.45728438241142, 84.67548670087541, 84.58506284441266, 88.6650172642299, 78.64087894984654, 92.58277988433838, 86.96487644740513, 81.2109272820609, 83.77199159349713, 81.57281030927385, 76.16483974456787, 75.7880528313773, 72.69464533669608, 68.55840356009347, 69.52514811924526, 75.9174838747297, 76.5534108025687, 76.30127457209996, 74.58907863071987, 74.84842014312744, 69.41708973475865, 65.50902679988316, 38.501764501844136, 63.75523894173758, 71.3122386932373, 72.44794259752545, 77.31712205069405, 73.13760689326695, 73.98767730167934, 72.02243491581508, 72.94662175859723, 64.41067641122001, 65.38413987840924, 62.95956598009382, 69.8104828425816, 72.47736127035958, 68.56792954036167, 71.99908202035087, 74.75243077959333, 69.01381628853935, 70.5693164552961, 66.45575359889439, 68.00228364127022, 70.11814907618931, 77.04983179909843, 75.54362215314592, 78.48632322038922, 74.16651003701347, 76.00527436392647, 80.57706396920341, 86.64422403063092, 87.28529262542725, 84.98245116642543, 72.32950360434396, 48.004134791237966, 21.515067407063075, 3.178909203835896, 0.3424786627292633, 0.5474399902990886, 2.348393414701734, 9.4883496931621, 0.8845467727099146, 0.23251291630523546, 0.21790327025311335, 0.9016756564378738, 19.254387617111206, 38.01033926010132, 52.18588032041277, 70.66414546966553, 43.105276107788086, 22.403959138052805, 66.94496236528668, 61.58262062072754, 68.81111649104527, 35.612328324999126, 0.4688847969685282, 0.2114786971360445, 0.2412701706801142, 0.20573698809104307, 0.07746750169566699, 0.2017057165503502, 0.08873057232371398, 0.14607393315860204, 0.2670226645256792, 0.2548680938780308, 0.20104586838611535, 0.1019720814323851, 0.22999563281025204, 0.23154084703751973, 0.2187870621149029, 0.15886321903339454, 0.185732079403741, 0.06753944871681077, 0.26495326842580524, 0.14475306974990026, 0.09959811131869044, 0.2727850010352475, 0.20635111656572136, 0.12299691646226815, 0.3128488840801375, 0.14392674980419023, 0.1697729764772313, 0.17722026471580776, 0.1949584186077118, 0.2355339713394642, 0.3195260486432484, 0.22567937656172685, 0.17082953692546912], [0.2452821582555771, 0.12730595309819492, 0.18384026948894772, 0.2361096404492855, 0.16363345592149667, 0.06387684560780015, 0.10853897726961545, 0.10119656340352126, 0.04149218229576945, 0.060385294391640594, 0.14746026162590298, 0.1254290845245123, 0.12132952521954264, 0.08984636887907982, 0.05946438666433096, 0.06191239173391035, 0.05007413375590529, 0.14826674120766775, 0.0922769627400807, 0.23802167070763453, 0.19391111337712832, 0.08529606554657221, 0.2298818017755236, 0.07573563605546951, 0.07199574102248464, 0.012863419218254941, 0.034250663194273195, 0.07439673718597208, 0.09839786429490362, 0.2470834787402834, 0.2588367094951016, 0.28800541002835545, 0.07675756407635552, 0.19012157672217914, 0.20424665377608367, 0.2924843654036522, 0.19403314111488207, 0.0751335583627224, 0.09408277512661048, 0.2500443070062569, 4.35541445016861, 41.695514406476704, 63.02578926086426, 57.14277730669294, 49.0656875201634, 37.82674353463309, 39.9113073348999, 85.06865051814488, 71.44610963548932, 40.107236112867085, 21.54134896823338, 5.859401975359235, 0.09880850011748926, 0.3165281723652567, 0.3540021686681679, 0.4359541083020823, 1.0091942527464457, 1.5397061514002937, 0.5271837658115796, 1.2207603859049934, 0.3697982739124979, 0.0728752648990069, 0.09303390926548413, 1.6770261142935072, 11.391978059496198, 39.96416228158133, 73.34160600389752, 82.36571093967983, 72.78115735735211, 72.3998749596732, 80.43276378086635, 78.19244221278599, 64.1907798222133, 70.93334647587368, 78.24213572910854, 69.81058706556047, 80.39294365474156, 72.38425540924072, 79.25084045955113, 72.1009773526873, 70.30757086617606, 70.82736560276577, 66.35071073259626, 68.21311977931431, 67.01451383318219, 68.94939259120396, 61.17138453892299, 71.06759262084961, 68.76944814409528, 67.97630432673863, 8.337653313364301, 25.26355627604893, 83.32528495788574, 55.521192823137554, 74.25404344286237, 64.12321553911481, 69.64058549063546, 64.2504301071167, 72.28463908604213, 64.06919329507011, 65.08720861162458, 57.84527145113264, 66.65575054713658, 67.40974821363176, 74.53220067705426, 68.97937406812395, 68.06886822836739, 64.3610315322876, 65.13380323137555, 66.54275894165039, 69.3569530759539, 66.10475839887346, 64.0514475958688, 68.09247820717948, 73.35573863983154, 83.71317509242466, 90.27851404462541, 77.25668661934989, 48.74645948410034, 21.17756560870579, 8.316095658711024, 2.0476067662239075, 0.5784703195095062, 0.2978209890425205, 0.06933749187737703, 0.3306659651654107, 0.13127479941717216, 0.16248432972601481, 0.12983743154576846, 0.22248312378568308, 0.044340363570622036, 3.481396641050066, 17.0781249659402, 39.854200090680806, 67.398193359375, 52.41155086244856, 22.20718789100647, 23.483545916421072, 52.19147709437779, 50.98841735294887, 48.230937889644075, 9.974229403904506, 0.18511849375707762, 0.0315814624939646, 0.07083345803299121, 0.08142837522817509, 0.1602917252374547, 0.15402683855167457, 0.15798043140343257, 0.23497010873896734, 0.1050319147429296, 0.058884347788989544, 0.0831787513036813, 0.27770267001220156, 0.15420612107430184, 0.12220422471208231, 0.13812803024692194, 0.293026650590556, 0.19944035953709058, 0.07131677852677447, 0.11271036629165922, 0.21840454478349003, 0.08981677796691656, 0.11845834500023297, 0.05610529226916177, 0.1696869246661663, 0.12539628414171083, 0.09288261631237608, 0.06986672205052205, 0.05104816059714981, 0.12324443246637072, 0.0830467219597527, 0.11361369996198586, 0.1040795569175056, 0.16105091092841967, 0.06580782056386981, 0.24689503599490437, 0.1675863838089364, 0.1540518764938627, 0.16136286061789307, 0.06483522203883954, 0.048785470226513486, 0.0796061015820929, 0.07843658540930067, 0.10477673807846648, 0.07172127360744135, 0.12070204317569733, 0.09225406218320131, 0.17433488954390797, 0.1157020814716816, 0.0966273085879428, 0.0717286764244948, 0.03362665185704827, 0.09479460585862398, 0.049481219678585014, 0.08756807898836476, 0.24766921730978148, 0.08100222809506313, 0.219539666016187, 0.12147029409451143, 0.02706568641588092, 0.006785598699934781, 0.03054777206853032, 0.03493935927482588, 0.045458290725946426, 0.16922301027391637, 0.25059014771665844, 0.22952182537743024, 0.10023307081844125, 0.13759905791708402, 0.16141577277864727, 0.19692644157579967, 0.16991622879036836, 0.24420380326254026, 0.056906319822051694, 0.15569678108607019, 9.441905328205653, 55.347804001399446, 69.1173791885376, 55.12630932671683, 34.68821096420288, 35.783677850450786, 68.41547216687883, 99.80583531515938, 62.9711069379534, 40.01648221697126, 29.29221909386771, 7.812887140682765, 0.27241058541195734, 0.4092171958514622, 0.26816197910479134, 0.6414411376629556, 1.2898568553583962, 0.5343999043107033, 2.2695576335702623, 2.7239511481353214, 0.836655988224915, 0.35788471890347345, 0.2602990067430905, 5.217228616986956, 27.876117161342076, 60.86642810276577, 78.42111437661308, 76.78806536538261, 75.91535077776227, 75.37426676068986, 85.11987958635602, 84.16625322614397, 71.59244564601353, 80.30832154410226, 83.70987469809396, 72.65976537976945, 81.19729491642543, 76.25268581935337, 79.27673639569963, 78.24358095441545, 71.18456554412842, 70.23407976967948, 65.39198439461845, 69.0554290499006, 69.5643845966884, 75.05388532366071, 69.6135778427124, 71.63589968000139, 62.8183924811227, 71.57374804360526, 13.126543726239886, 34.14647729056222, 82.32401479993547, 58.7424749646868, 71.50917148590088, 65.5580254963466, 69.33183533804757, 64.36846610477993, 69.41866697583879, 64.19464996882847, 61.525464739118306, 55.740179198128835, 65.33250781467983, 64.21305574689592, 68.63165841783795, 64.00806304386684, 67.61356667109898, 63.11985397338867, 65.32359327588762, 66.88975892748151, 69.09863294873918, 65.00371210915702, 65.75731372833252, 65.4152261189052, 67.554673739842, 77.03720692225865, 82.39883995056152, 79.97934518541608, 64.80878734588623, 39.68560552597046, 22.22747141974313, 7.400415148053851, 1.80103691135134, 0.6830325658832277, 0.30123407446912354, 0.09642045040215765, 0.30462104986820904, 0.341894444078207, 0.038772213605365584, 0.19525029723133358, 0.17422959447971412, 5.398813707487924, 26.393776314599172, 36.71567446844918, 63.900164467947825, 75.35935592651367, 35.382829325539724, 10.113117814064026, 34.566523688180105, 54.67341879435948, 52.970179080963135, 14.875235080718994, 0.3555651605129242, 0.12049602637333529, 0.059029723916734965, 0.02116897113488189, 0.05210578634536692, 0.18047161453536578, 0.009586200251110961, 0.11818197768713747, 0.05981176266712802, 0.06407693201409918, 0.08861471925462995, 0.29815800381558283, 0.15821574734789984, 0.2147381758051259, 0.07669131870248488, 0.2846320867538452, 0.17289003064589842, 0.02869636212874736, 0.11033170750098568, 0.11374813810523067, 0.04247327268655811, 0.10901359894445964, 0.052592611472521505, 0.0933465917727777, 0.08371119094746453, 0.0795876793563366, 0.05629550599093948, 0.0458955726187144, 0.10038241637604577, 0.08228854050061532, 0.1338497041059392, 0.08512073209775345, 0.21479959679501398, 0.12824740686586925, 0.5040413247687476, 0.23486208596399852, 0.27675204245107515, 0.2644246896462781, 0.13095591509980814, 0.10860631508486611, 0.1623757505523307, 0.17725254941199506, 0.08652533351310662, 0.12209876679948398, 0.2394866549542972, 0.20922232392643178, 0.2097186722925731, 0.32367784157395363, 0.1677860359528235, 0.17513585942132132, 0.20300946730588162, 0.14808792008885316, 0.15693440181868418, 0.304864725364106, 0.2969524913600513, 0.19105756149760314, 0.25047824372138294, 0.15584749728441238, 0.11697694020611898, 0.19907012368951524, 0.12177539058029652, 0.14222092633800848, 0.2840246079223496, 0.36671579788838116, 0.37411391947950634, 0.29605948499270845, 0.0943700804242066, 0.1903246079704591, 0.21873393282294273, 0.2698689289391041, 0.2190725760800498, 0.2748856097459793, 0.11899254204971449, 0.47616260073014666, 8.538549184799194, 67.08902631487165, 85.28116812024797, 68.59468010493687, 61.288281032017295, 48.35692957469395, 53.544433798108784, 90.34758608681815, 82.27828175680978, 51.640637806483674, 31.769939763205393, 7.021370938846043, 0.3534735898886408, 1.0089879781007767, 0.348205064024244, 0.7451035380363464, 3.6242628949029103, 7.520731891904559, 3.303292598043169, 2.1696408007826125, 0.43505781782524927, 0.15017516165971756, 0.3140221796929836, 2.7838033650602614, 18.397485392434255, 50.532552991594585, 80.85911219460624, 91.81923539297921, 80.89132404327393, 79.21632180895124, 89.337616784232, 93.41558401925224, 72.24912684304374, 85.37096663883754, 92.36500944410051, 80.16222177233014, 91.36090442112514, 85.32490008217948, 90.19894327436174, 85.48592458452497, 82.23748888288225, 79.40438175201416, 73.90818296160016, 75.4384125300816, 74.66511971609933, 82.61201068333217, 73.72220052991594, 78.20299652644566, 65.32940196990967, 83.65062046051025, 12.235503264835902, 29.061907155173166, 91.54819311414445, 62.312931878226145, 78.050858770098, 71.95767770494733, 75.29207651955741, 69.61945601872036, 76.52096271514893, 68.93197345733643, 68.11902032579694, 61.153694425310405, 73.56517818995884, 72.77474417005266, 75.11658586774553, 69.2074556350708, 73.32825156620571, 69.39165932791573, 74.45067051478794, 77.30876336778913, 77.09704480852399, 70.379866872515, 68.45324952261788, 72.77821132114956, 74.97597517286027, 90.40440150669643, 99.16487789154053, 94.88778223310197, 60.20945508139474, 27.775347437177384, 11.700786403247289, 2.891863052334104, 0.7305756690246719, 0.4874639000211443, 0.25210070237517357, 0.5581826652799333, 1.466104426554271, 0.7392098914299692, 0.1886911570493664, 0.33722452180726187, 0.15836867557040282, 5.658850908279419, 29.85477304458618, 54.53778648376465, 80.5569280896868, 63.48218863351004, 35.56434753962925, 35.1069267817906, 65.68185629163469, 65.4169145311628, 70.6327257156372, 19.419381277901785, 0.43139687712703434, 0.33679856466395514, 0.13910881190427712, 0.13261597816433224, 0.22519159130752087, 0.2838510386645794, 0.17671247624925204, 0.34370664826461245, 0.17936505962695393, 0.10698262149734156, 0.15398436225950718, 0.42826904782227104, 0.20645890863878386, 0.2786307159279074, 0.20493272053343908, 0.39912656588213785, 0.20471161311226233, 0.11350782135767595, 0.17732824677867548, 0.21830190957656928, 0.18101949085082325, 0.18747439448322567, 0.14134007931819983, 0.21329352046762193, 0.26287350431084633, 0.12281004791813237, 0.09872039913066796, 0.19511335529386997, 0.13287360434021267, 0.11685580813458987, 0.1882049459964037, 0.3174711460513728, 0.3189313534115042, 0.18956793285906315], [0.19997188315859862, 0.2049114823873554, 0.2053596411964723, 0.16603975822882994, 0.1882152325872864, 0.1471966914832592, 0.07372541499457189, 0.03762647669230189, 0.034114213194698095, 0.04932743650195854, 0.1443020339523043, 0.06102609607790198, 0.10924126101391655, 0.06498957518488169, 0.04807045037991234, 0.049519288885806284, 0.027400205876412134, 0.0649824437818357, 0.09719229077122041, 0.1391058127794947, 0.07758900017610618, 0.0769073303256716, 0.07733784043895346, 0.0838741614882435, 0.023113513398649435, 0.09736041139279093, 0.10283897098686014, 0.08685305914176361, 0.05726007744669914, 0.25722394032137735, 0.07253818905779294, 0.22242946523640836, 0.17269431400511945, 0.012696093330825014, 0.3504769078322819, 0.2364746651479176, 0.1774707662739924, 0.27632052132061546, 0.08938001854611294, 0.32129550512347904, 0.14962397409336908, 0.842000564294202, 38.062506335122244, 81.56875950949532, 71.56603554316929, 54.260786124638145, 29.786142213003977, 27.056961025510514, 57.0402774810791, 76.42461899348667, 68.20722075871059, 51.6149503162929, 17.27600792476109, 2.496598490646907, 0.20316831235374722, 0.49905371240207125, 0.4134753830730915, 1.739269922886576, 4.829763191086905, 3.127614562000547, 1.9779758283070155, 0.4974441187722342, 0.561301049377237, 0.07788414255316768, 0.20585190478180135, 0.8615564863596643, 8.495512042726789, 33.89353854315621, 70.80649321419853, 84.37777723584855, 72.94730268205915, 69.77134363991874, 72.59322248186383, 84.03419576372418, 80.65489768981934, 77.17567757197789, 84.05574212755475, 78.51724965231759, 81.7377883366176, 76.95451641082764, 74.23581136975969, 70.71675028119768, 69.91946533748082, 65.65377862112862, 63.83246122087751, 61.62600517272949, 54.43730163574219, 55.916517530168804, 64.87155737195695, 25.955979006631033, 0.07286203346614327, 4.377745960439954, 72.13241795131138, 67.21764441898891, 72.35999924795968, 72.54839965275356, 72.68317386082241, 72.36874008178711, 70.22584615434918, 67.72813551766532, 70.25969777788434, 66.79192134312221, 69.45766721452985, 74.59752764020647, 76.47111633845738, 75.01964460100446, 73.35900429316929, 72.04234150477818, 66.11850193568638, 61.09255027770996, 57.560287611825125, 63.38118267059326, 61.96839155469622, 64.15348189217704, 63.37139960697719, 52.48008789334978, 35.18199164526803, 9.52797179562705, 0.2870203400296824, 0.3067530340382031, 0.2306890141751085, 0.06699554183121238, 0.4659461975097656, 0.5855946115085057, 0.4771398540054049, 0.16225963963993958, 0.3007230833172798, 0.28561544684427126, 0.30444121094686644, 1.7314815350941248, 9.575590406145368, 31.938197340284074, 46.25036430358887, 56.27843877247402, 28.715211153030396, 14.186295134680611, 43.8268187386649, 59.113203048706055, 54.32582821164812, 45.182992458343506, 3.0905394085815976, 0.4967435449361801, 0.1208031177520752, 0.1299540445740734, 0.12894849638853753, 0.08735883914466415, 0.03664364925186549, 0.07841958810708352, 0.12704827263951302, 0.08096102744873081, 0.04420153869848166, 0.16084773040243558, 0.05276776850223541, 0.0829638389072248, 0.06590268654482705, 0.1307057799505336, 0.14105048057224068, 0.3024288932127612, 0.3362912918840136, 0.1881185956299305, 0.22499709602977547, 0.2982358182115214, 0.26024551104222027, 0.1073121859558991, 0.11741287181419985, 0.1804342001144375, 0.013671434833668172, 0.023293703461864164, 0.045181003997900655, 0.015862069026167904, 0.10897427784012896, 0.11122349250529494, 0.14762750693729945, 0.08075715481702771, 0.10832564585975238, 0.10698473174124956, 0.21617869207901613, 0.12111810727843217, 0.07725649087556771, 0.16847981086799077, 0.11338381229766778, 0.0578949148101466, 0.057644094340503216, 0.05375322526586907, 0.035657157722328386, 0.054688348301819394, 0.07713818150971617, 0.040953479773764095, 0.04372214013710618, 0.053858703534517965, 0.05104428616219333, 0.029506437946110964, 0.09396692205752645, 0.015338399447500706, 0.053051433459456475, 0.16922353953123093, 0.1401839777827263, 0.0761861154543502, 0.05487677747649806, 0.032608347213161845, 0.020012208027765155, 0.11518331430852413, 0.046113199155245505, 0.027869268653116057, 0.025483244364815097, 0.16171283540981157, 0.08610258584043809, 0.10411618423781224, 0.07716425082513265, 0.11255562638065644, 0.23437074518629483, 0.1543908454477787, 0.09684622434100934, 0.23126367905310222, 0.13036265836230346, 0.1194282022437879, 0.242074831788029, 1.3554292853389467, 50.627882276262554, 84.70947728838239, 69.30858666556222, 48.60490036010742, 16.085831880569458, 36.43875401360648, 83.03013937813895, 76.95783764975411, 58.2611072404044, 46.81052112579346, 18.254903146198817, 2.8995640448161533, 0.2802412323653698, 0.10160395582871777, 0.3918602972158364, 1.7547616916043418, 0.8688268533774784, 2.2853471977370123, 2.2159425105367387, 1.7792011116232191, 0.9809249639511108, 0.24035688968641417, 0.1818128747067281, 2.5945965349674225, 22.224497590746196, 57.23477145603725, 78.88376712799072, 78.17776066916329, 74.54860537392753, 75.53308173588344, 66.99116788591657, 74.9702012198312, 79.40181786673409, 73.92159298488072, 79.21273653847831, 76.49260016850063, 79.35118634360177, 77.36215332576207, 73.76953860691616, 73.5677490234375, 73.08409186771938, 73.7600404194423, 70.00373308999198, 68.44737134660993, 59.71892615727016, 67.70905576433454, 77.28906522478376, 48.89781904220581, 0.4396627093000071, 8.062165055956159, 80.64866515568325, 63.94661317552839, 78.28267846788678, 68.66281414031982, 73.12575326647077, 68.56039769308907, 73.48610768999372, 66.81362751552037, 69.73300348009381, 64.88942119053432, 71.66431086403983, 73.34130723135812, 77.72150720868791, 71.99644865308488, 72.17715045383999, 72.5793399810791, 72.03965950012207, 69.27185153961182, 64.35071345738002, 67.83666637965611, 66.8113762991769, 74.22449275425502, 75.17187963213239, 69.1126961026873, 55.794785090855186, 26.174753461565288, 5.013154813221522, 0.6838115783674377, 0.0936780289879867, 0.1211479085364512, 0.5680979075176376, 1.0417522085564477, 0.4637367789234434, 0.397797804325819, 0.12852899889860833, 0.07181918621063232, 0.18986044930560247, 3.106785382543291, 18.047754764556885, 34.67601687567574, 46.18253598894392, 78.87227480752128, 56.299821853637695, 17.85755477632795, 24.886918749128068, 52.78673621586391, 61.35765879494803, 53.6045252936227, 5.969302500997271, 0.6049882279975074, 0.06461809083287205, 0.17233839524643763, 0.09700316949082272, 0.09890553741050617, 0.06063097156584263, 0.07130833755114249, 0.033560074001018486, 0.06706048441784722, 0.03579231850536806, 0.08304620627313852, 0.013155866963123637, 0.10958873201161623, 0.11525291843073708, 0.18144528514572553, 0.08173429952668292, 0.12422524126512663, 0.15458261301474913, 0.11397468059190682, 0.16995424032211304, 0.1790605466812849, 0.06805167480238847, 0.0885449590693627, 0.1147493775933981, 0.11540876435382025, 0.08709071603204523, 0.06328686619443552, 0.02104842769248145, 0.06002862924443824, 0.09997066097067935, 0.09098416353975024, 0.0664476655157549, 0.07056388964078256, 0.049819496526782, 0.047838435508310795, 0.23953206251774514, 0.14620005924786839, 0.30030138737389017, 0.20670570539576666, 0.2144296730735472, 0.13081921743495123, 0.10083375072904996, 0.11602823968444552, 0.15329347790351935, 0.137964734009334, 0.3436925347362246, 0.21586246761892522, 0.12498053216508456, 0.14462384954094887, 0.1550668698868581, 0.08387084345200232, 0.17870078741439752, 0.15703141875565052, 0.1917103664683444, 0.29143790155649185, 0.23797862444605145, 0.20423889133547032, 0.17470446042716503, 0.14127939114613192, 0.1638025197067431, 0.170455379145486, 0.15110783518425056, 0.15237243446920598, 0.05355249085862722, 0.3011880155120577, 0.09402425826660224, 0.20694201200136117, 0.15937783356223786, 0.1398006190678903, 0.30739555241806166, 0.17667781668049948, 0.2920773800994669, 0.2549075846161161, 0.18408174653138432, 0.2557920957250254, 0.2608113278235708, 1.2252467508826936, 57.113733836582725, 100.38478006635393, 84.45474243164062, 64.80853026253837, 40.6202563558306, 35.804015227726524, 65.48203999655587, 80.12304088047573, 75.60336971282959, 66.10130514417375, 25.05383358682905, 2.5818891482693807, 0.5278600752353668, 0.8884913953287261, 0.4789144130689757, 3.124080751623426, 13.184187718800136, 14.9240357535226, 7.719433869634356, 1.2334096900054385, 0.7423922749502319, 0.15584525811885083, 0.41492362107549396, 1.1015935689210892, 13.638499157769338, 47.24054513658796, 82.26995086669922, 94.70378003801618, 82.41670376913888, 79.71866267068046, 79.12493215288434, 90.58631229400635, 85.96337699890137, 85.4772115434919, 89.49296460832868, 84.73242718832833, 88.30855383191789, 85.37764385768345, 81.07561806270054, 82.00185462406704, 80.98893928527832, 80.61823899405343, 79.26472296033586, 75.0939416885376, 66.0134243283953, 68.22268744877407, 84.04689012254987, 40.97149126870291, 0.17982005806905882, 5.447901427745819, 77.28332601274762, 74.14376163482666, 81.10947663443429, 73.28350516727993, 80.26473549434117, 78.161390713283, 82.58951241629464, 75.4320410319737, 80.23868669782365, 74.46552576337541, 79.12384128570557, 81.4206656047276, 84.75906658172607, 78.37582601819719, 79.66417489733014, 81.8202565056937, 79.23899378095354, 70.66067137037004, 66.22749832698277, 75.91713646480015, 78.77707753862653, 85.62096282414028, 78.56221839359829, 58.219720295497346, 39.167214325496126, 12.808499489511762, 1.3987077687467848, 0.4634438689265932, 0.20446008018084935, 0.2507986750985895, 1.2360607534646988, 1.4270763950688499, 1.7099236633096422, 0.8645441031881741, 1.0097493486745017, 0.6052418915288789, 0.5321231750505311, 2.92534425003188, 17.91567645754133, 50.64108732768467, 59.5157538822719, 69.84760011945451, 43.680868353162495, 26.213331597191946, 59.348573275974815, 72.28382614680699, 75.15696184975761, 63.875484466552734, 9.04649029459272, 0.4767194879906518, 0.16405836812087468, 0.22651607809322222, 0.23149098828434944, 0.1551163758018187, 0.0957342954352498, 0.1680637060531548, 0.12748204650623457, 0.11148097618882145, 0.26221149840525215, 0.12248348258435726, 0.2013851087540388, 0.11514428497425147, 0.1705605656440769, 0.19765357327248367, 0.17431684051241192, 0.38938087597489357, 0.2858671833361898, 0.1870325460497822, 0.2305590882897377, 0.35388524351375444, 0.3102184480854443, 0.1254570401672806, 0.1867946381015437, 0.18098223927829946, 0.21954024955630302, 0.11147167347371578, 0.10843803161489111, 0.11335045551615101, 0.24521596037915774, 0.18903115737651074, 0.22092841006815434, 0.13174901397100516, 0.10596312263182231, 0.15014051566166536], [0.15088974045855658, 0.19575550726481847, 0.1783019309597356, 0.1836611091026238, 0.301725442388228, 0.25104188919067383, 0.11783234216272831, 0.11333181615918875, 0.054132102256906886, 0.0364850009791553, 0.19294660298952035, 0.06665521580725908, 0.0941812644845673, 0.09043772571853229, 0.1570188794285059, 0.1681114477770669, 0.028598809149116278, 0.17503368561821325, 0.13731142692267895, 0.13379167579114437, 0.15358204527625016, 0.11588377957897526, 0.01843918743543327, 0.055312977105911286, 0.07313327783984797, 0.02820573720548834, 0.04632328038236924, 0.05236310039513877, 0.05925564893654414, 0.21600913974855626, 0.34507840179971283, 0.2932720902775015, 0.3046751969626972, 0.39467182063630646, 0.26404302726898876, 0.344147044633116, 0.4551548851387841, 0.3364245833030769, 0.33242556931717054, 0.3497285922723157, 0.08355630175875765, 0.24403327384165355, 0.08754939891930137, 13.203985742160253, 57.5204153742109, 77.3473675591605, 72.02237933022636, 63.87756197793143, 27.908240420477732, 36.65432187489101, 57.431992598942344, 69.02693448747907, 68.46731962476457, 47.04840660095215, 13.602692484855652, 2.3260879601751054, 0.29842977066125187, 0.5655255541205406, 0.4584629333445004, 0.5887249378221375, 2.23979697908674, 0.45814005924122675, 0.7058822054948125, 0.6441624973501477, 0.41631293509687695, 0.19300222929034913, 0.03487616730853915, 0.41668322522725376, 6.060862387929644, 25.104122911180767, 64.24149472372872, 85.90210083552769, 84.69800581250871, 77.69345733097622, 70.60769830431256, 77.47977937970842, 77.10435431344169, 81.26255239759172, 82.51339490073067, 84.34535694122314, 86.13984734671456, 77.10567447117397, 69.03445243835449, 60.38406331198556, 51.69038690839495, 43.1575265611921, 40.142178603581016, 34.190476758139475, 12.265663657869611, 0.14844465308955737, 0.4668341555765697, 0.45482728843178066, 52.82375274385725, 88.27402823311942, 63.07126522064209, 77.0311758858817, 71.62731170654297, 74.06916577475411, 73.52852644239152, 76.55231993538993, 72.8112152644566, 71.74953051975795, 76.66613142830985, 79.18782029833112, 79.57615511757987, 76.56313828059605, 68.30434962681362, 66.15656416756767, 55.4645128931318, 54.1245493207659, 43.87884337561471, 26.706975051334926, 11.827631848199026, 9.2566967521395, 3.700651390211923, 0.8335750592606408, 0.3689333860363279, 0.3339512145945004, 0.14468143002263137, 0.45208055153489113, 0.15485123145793164, 0.08174830448946782, 0.9028479478188923, 1.0104923716613223, 0.29879436109747204, 0.34659281053713387, 0.2304504955453532, 0.2027597799897194, 5.2302599634443006, 13.502781731741768, 41.56791768755232, 63.76618235451834, 39.80025775091988, 19.37543044771467, 21.18065060888018, 50.99373619897025, 56.66116292136056, 52.352456433432444, 17.395390135901316, 0.6615842910749572, 0.142757525401456, 0.09163932302700621, 0.16531890976641858, 0.17292535517896923, 0.14044659797634396, 0.3286053900207792, 0.1598726212978363, 0.0556781985796988, 0.08445422071963549, 0.17743172336901936, 0.2025671981807266, 0.19165193103253841, 0.20034125048135007, 0.11720277023102556, 0.13668760896793433, 0.1746170108339616, 0.20481736958026886, 0.20795692397015436, 0.26657947259289877, 0.40400439128279686, 0.347164761275053, 0.3188378241445337, 0.2269577636782612, 0.29289387485810686, 0.4220058981861387, 0.12688056592430386, 0.20122352242469788, 0.10273022217942135, 0.12275264385555472, 0.047146421391516924, 0.12413077561983041, 0.056899045926651785, 0.01717139225054, 0.21233065213475907, 0.0945408676884004, 0.06723502398069416, 0.12889684630291803, 0.20900496201855795, 0.10640176837997777, 0.09544371281351362, 0.19996132515370846, 0.35171957686543465, 0.060352127599929056, 0.05291134990485651, 0.014645398062254702, 0.09013096682195153, 0.11093906419617788, 0.07300245628825255, 0.1064454321084278, 0.09286179207265377, 0.15544926508196763, 0.09138941179428782, 0.09924561237650258, 0.1495453861675092, 0.024124298178191696, 0.14216869271227292, 0.11571274804217474, 0.024893337893964987, 0.06974745595029422, 0.10913770299937044, 0.06708829078291144, 0.06930545145379645, 0.020795430821765746, 0.07719819793211562, 0.03135245692517076, 0.081104612244027, 0.1549139688057559, 0.18149903868990286, 0.18046744833035128, 0.1727663879948003, 0.18373266740569047, 0.24210422592503683, 0.29532954416104723, 0.21963432165128843, 0.2515031301549503, 0.26916857223425594, 0.19292236571865423, 0.18326656813068049, 0.12259161392492907, 23.44063557897295, 72.73280484335763, 79.28224631718227, 68.60978548867362, 33.47472892488752, 24.76773108754839, 56.505471161433626, 82.49872725350517, 86.20673070635114, 70.13926465170724, 43.89286831447056, 16.87500306538173, 3.258995009320123, 0.48769264774663107, 0.2112985732299941, 0.37091763956206186, 1.5082011733736311, 0.9932170872177396, 1.1793249121734073, 1.59295497408935, 2.233983073915754, 1.6173327288457324, 0.26627880015543526, 0.25968995371035164, 2.046733030251094, 18.50073388644627, 51.16364049911499, 74.50613798413957, 80.52844047546387, 80.8790535245623, 85.75743934086391, 76.00836631229946, 79.14583928244454, 80.95631749289376, 78.41852269853864, 80.21743910653251, 75.80965478079659, 75.34633500235421, 68.82194873264858, 68.26535633632115, 62.892425537109375, 64.72540896279472, 59.81341470990862, 59.53517409733364, 53.844512598855154, 30.528088229043142, 0.4600775752748762, 0.055938393010624816, 1.2632570884057452, 63.18859945024763, 82.34744412558419, 64.06974220275879, 77.1952714920044, 73.3127223423549, 76.79550688607353, 73.77110195159912, 81.08988271440778, 75.92710018157959, 72.775876726423, 74.40976646968296, 75.2602537700108, 77.10123457227434, 76.81425312587193, 70.31064891815186, 70.6362692969186, 61.551402364458355, 63.871127946036204, 62.417418888636995, 54.09636395318167, 38.21642630440848, 27.3799341406141, 12.763286692755562, 5.127344982964652, 1.601424176778112, 0.5591812516961778, 0.42364741010325296, 0.3257021558071886, 0.22411631686346872, 0.3304058148392609, 0.5554668967212949, 1.9225598190511977, 0.27297575079968994, 0.17313089700681822, 0.16333162997450146, 0.8000453327383313, 12.006275245121547, 26.08640537943159, 39.66422939300537, 82.01201983860561, 67.2757591520037, 27.77194803101676, 8.583140117781502, 31.80532693862915, 56.661798681531636, 57.02103444508144, 22.129757165908813, 0.8005526055182729, 0.25935649446078707, 0.07865175564906426, 0.14922336701835903, 0.026152217128713216, 0.132276127114892, 0.1242220928626401, 0.09520547238311597, 0.2063955877508436, 0.08651810032980782, 0.07180834322103433, 0.06150257693869727, 0.1552263663283416, 0.11329828974391733, 0.06543459237686225, 0.11074052484972136, 0.10736984786178384, 0.08596952512328114, 0.143850658887199, 0.1992790446217571, 0.2478167036814349, 0.20775681042245456, 0.22057079497192586, 0.21613591723144054, 0.22947134237204278, 0.24345014084662708, 0.04285158649353044, 0.15745728090405464, 0.0502452161828322, 0.09787944318460566, 0.018396344734355807, 0.046733454801142216, 0.05656804297385471, 0.0944930716816868, 0.05600971721911004, 0.16276589461735316, 0.09975705136145864, 0.15234610731048243, 0.2030780536255666, 0.15899655116455896, 0.15108315008027212, 0.2993837094732693, 0.43244002972330364, 0.1941879420940365, 0.1872367172368935, 0.1349566254232611, 0.2176361038748707, 0.21537051615970476, 0.2422242180577346, 0.17203812992998532, 0.17747751091207775, 0.2572093111063753, 0.22411996738186904, 0.2219886210347925, 0.21693981838013443, 0.14150705321558885, 0.18816419318318367, 0.21364839428237506, 0.1385127188903945, 0.15708215960434505, 0.19654927110033377, 0.2241990031408412, 0.049253907054662704, 0.10425921263439314, 0.13802150024899415, 0.11398754561586039, 0.2332400344312191, 0.3256165789706366, 0.3382568449846336, 0.20590728681002343, 0.22425049037805625, 0.3317698873579502, 0.27921732302222935, 0.4051232412457466, 0.25551842898130417, 0.4176411809665816, 0.40453313291072845, 0.19465465205056326, 0.17305619030126504, 0.18925552176577704, 21.389626366751536, 80.68292672293526, 94.81269305092948, 82.8254176548549, 73.3346369607108, 39.77450425284249, 50.609188147953574, 65.30470807211739, 79.08713395254952, 82.16672842843192, 64.0877936226981, 21.34073884146554, 3.269425992454801, 0.5489839017391205, 0.49931095859834124, 0.443237123212644, 4.716058960982731, 14.2026173216956, 13.197641168321882, 4.497875102928706, 2.022332693849291, 0.6046052085501807, 0.3564117822263922, 0.2876857657517706, 0.6643282324075699, 8.665209633963448, 34.96357502256121, 72.93289906638009, 94.84077766963414, 94.37221894945417, 91.73981748308454, 85.03477110181535, 91.92782184055874, 90.25856576647077, 89.53763457706997, 93.21797725132534, 90.45741626194545, 89.43275151933942, 83.90111691611153, 80.85793794904436, 76.11535467420305, 76.91726016998291, 68.96839591435024, 70.36652633122036, 62.99213218688965, 20.90591709954398, 0.2441781817802361, 0.3869120941630432, 1.3256432265043259, 60.774413108825684, 92.55060972486223, 70.85437325068882, 85.42070879255022, 78.34514277321952, 80.920318875994, 78.84576048169816, 89.31087316785539, 83.34075164794922, 80.64458656311035, 85.37642792293003, 84.5575201851981, 84.1944351196289, 80.85640239715576, 74.16953945159912, 73.31755134037563, 65.76160076686314, 74.43437698909214, 71.28092316218785, 52.29244484220232, 30.03171934400286, 17.18976514680045, 4.8930569376264295, 1.2936982320887702, 0.3443345102880682, 0.3606620170176029, 0.3652993696076529, 0.9910284046615873, 0.3551418903682913, 0.4208121650985309, 4.421191309179578, 5.947646703038897, 1.3857995356832231, 0.575922773352691, 0.625604836004121, 0.37507676067096846, 9.974991100175039, 27.36567643710545, 58.48098645891462, 80.03511142730713, 52.62841803686959, 34.41707488468715, 31.85110514504569, 65.61309691837856, 71.57867431640625, 72.96534020560128, 31.85004554476057, 1.9290444425174167, 0.24778483967695916, 0.2598514993275915, 0.3291015891092164, 0.1631647917841162, 0.23969803218330654, 0.3158624480877604, 0.2951002264661448, 0.3289135806262493, 0.15609502685921534, 0.22133614176086017, 0.18133950153631823, 0.20169244440538542, 0.17133751538183006, 0.22766749773706707, 0.1608020378542798, 0.2180598082819155, 0.14029890804418496, 0.17193409694092615, 0.36519091257027214, 0.5478603020310402, 0.2635142042168549, 0.23102537755455288, 0.23738422776971543, 0.35061937304479734, 0.37276341766119003, 0.1580683695418494, 0.16633987426757812, 0.08829785018627133, 0.2565474137663841, 0.08608875729675804, 0.14169336536100932, 0.1573717040675027, 0.24290484296424047, 0.38231653933014187, 0.2901811732777527, 0.20665169400828226], [0.06505014122064624, 0.10115441280816283, 0.07748340655650411, 0.09910792405051844, 0.09526002659861531, 0.024517142812588384, 0.046422159897961786, 0.039186642438705475, 0.030133054857807498, 0.053012712858617306, 0.09749319391059023, 0.10273820853659085, 0.1216938171003546, 0.06723795525197472, 0.06463737479810204, 0.0809494855680636, 0.020176191282059466, 0.05351309850811958, 0.07552186359784432, 0.11850580173943724, 0.0450348882669849, 0.04425738552319152, 0.014353539794683456, 0.05002264312601515, 0.02680044707709125, 0.10877783516688005, 0.04792029058028545, 0.05658412764647177, 0.18482310032205923, 0.09626099467277527, 0.13631377688476018, 0.18978123712752545, 0.32735465999160496, 0.21819432106401238, 0.16243361601872103, 0.25348067975469996, 0.21360734291374683, 0.15598738406385693, 0.27502902490752085, 0.16376615022974356, 0.13316530654472963, 0.14873765808131012, 0.07194786359156881, 0.1954428790403264, 0.6593675443104335, 29.32330186026437, 65.53630542755127, 71.24817630222866, 68.51165607997349, 45.98825740814209, 31.056252070835658, 32.026783398219514, 46.27325166974749, 78.18583447592599, 71.03649943215507, 48.00389160428728, 16.37773265157427, 1.1045577355793543, 0.37785210460424423, 0.18554560440991605, 0.4628983267715999, 1.022211594241006, 2.276005996125085, 1.4404591683830534, 2.4940092010157446, 0.8022381407873971, 0.2060077642755849, 0.6644805499485561, 0.49414459296635216, 0.1775546467729977, 1.0922868911709105, 12.269115175519671, 34.32842281886509, 46.43813937050955, 49.432708740234375, 52.20340020315987, 54.90934835161482, 65.08594403948102, 63.92848532540457, 70.12512506757463, 71.34220627376011, 68.46226133619035, 54.807077816554475, 32.82814693450928, 14.79170731135777, 11.36542204448155, 9.220293402671814, 1.122542713369642, 0.34184412392122404, 0.3908640721014568, 0.8821181601711682, 0.376863207668066, 8.575070653642927, 81.96464007241386, 85.5716028213501, 79.86403982979911, 82.31291852678571, 81.95867156982422, 84.8063143321446, 83.68486813136509, 80.27341379438127, 85.69086865016392, 84.56755338396344, 91.149033001491, 87.10218674795968, 81.64524527958461, 71.97832080296108, 63.43771321432931, 42.031438963753835, 17.327098029000418, 1.209427331175123, 0.5918893537351063, 0.13047214677291258, 0.510260559618473, 0.4219113646873406, 0.2349344449383872, 0.06552681885659695, 0.5719335845538548, 0.1238498892635107, 0.31000666373542374, 0.7004766698394502, 0.381328456635986, 0.46564650216272896, 0.34691668887223515, 0.04249488402690206, 0.02505817949505789, 3.421181380748749, 24.525214638028825, 43.408064705984934, 58.058866024017334, 64.9604526247297, 26.718022687094553, 21.396635362080165, 48.52471467426845, 65.1361517224993, 61.1643043245588, 37.87885849816458, 6.479192146233149, 0.1679977388786418, 0.056660992093384266, 0.08622455929539033, 0.18317055542554173, 0.09809713078928844, 0.10910919774323702, 0.11156738762344633, 0.07214400770940951, 0.0271642436273396, 0.04493318943838988, 0.09700618897165571, 0.05792191371853862, 0.07721463205026728, 0.06950033349650246, 0.07202489767223597, 0.050165152443306785, 0.04530934550400291, 0.11172256179686103, 0.19329386364136422, 0.17319503213678086, 0.175979522722108, 0.1962121884737696, 0.16180948593786784, 0.2069885866450412, 0.173213339011584, 0.17232607305049896, 0.07275689446500369, 0.039769402239471674, 0.04849192240674581, 0.04729545482301286, 0.0478602198750845, 0.029684125911444426, 0.05419925347502742, 0.04925051098689437, 0.03055480169132352, 0.012259297438764145, 0.03192768498722996, 0.1499558048588889, 0.12500909848936967, 0.07669410069606133, 0.16187412318374428, 0.20817298309079238, 0.05844235686319215, 0.04965367953159979, 0.03155796482626881, 0.04699404278237905, 0.04220215384183185, 0.06615987167294536, 0.05291347711213997, 0.015514572583405035, 0.11885478587022849, 0.03694801291983042, 0.09992272247161184, 0.21969912174556935, 0.08906314269240413, 0.022656996734440327, 0.06021345539816788, 0.08240900082247597, 0.038271380122751, 0.03573006291740707, 0.014077828964218497, 0.04548286387164678, 0.012168819883040019, 0.040869914793542454, 0.053005510209394355, 0.04352942601378475, 0.13857191428542137, 0.09971239697188139, 0.08427029701748065, 0.17917152786893503, 0.3635135197213718, 0.21307708136737347, 0.32830992873225895, 0.28222917712160517, 0.3104958603424685, 0.12504579366317817, 0.3114056943782738, 0.19535532088152, 0.2682377036128725, 0.2142743021249771, 0.3211261156414236, 0.13989044353365898, 3.1187616884708405, 46.77858025687081, 81.06216635022844, 88.77964864458356, 65.84506947653634, 30.763618264879497, 29.22309841428484, 47.98624665396554, 78.3675924028669, 100.73203713553292, 70.40948009490967, 52.19918612071446, 21.056144101279124, 2.884136872632163, 0.1153666680412633, 0.022469690535217524, 0.6240510450942176, 1.0611601557050432, 0.07768727918820721, 0.8073014233793531, 3.8155910968780518, 2.0315284175532202, 0.7211218305996486, 0.5813958368131092, 0.4227439814380237, 0.8270305618643761, 10.236358880996704, 34.98023680278233, 57.90455000741141, 62.9951685496739, 65.68957574026925, 69.78549712044853, 71.83884961264474, 78.56898593902588, 77.89500372750419, 82.53501074654716, 85.35388796670097, 79.49884946005685, 76.6796178817749, 64.0937134878976, 51.68288285391671, 40.86687224251883, 25.28427927834647, 4.359026644911085, 0.7806715294718742, 0.24644845138703073, 2.338487671954291, 0.228194176618542, 19.39966402735029, 92.95115947723389, 75.21140793391636, 75.27147511073521, 70.98257446289062, 71.78650188446045, 72.17462825775146, 72.8704833984375, 74.663681438991, 77.79571396963937, 77.75176661355155, 83.53392546517509, 79.55087757110596, 71.949631690979, 69.55945137568882, 69.22971071515764, 63.63538946424212, 46.06269345964704, 17.38669272831508, 4.065568174634661, 0.7191963653479303, 1.59001610321658, 0.6812328195997647, 0.2860253634197371, 0.10070959239133767, 0.5891970896295139, 0.27094440694366184, 0.634327865072659, 0.619181172123977, 2.2793478625161305, 0.6006969554083688, 0.45499447946037563, 0.26667796873620575, 0.11279744947595255, 4.876785559313638, 25.77913866724287, 39.33084092821394, 46.98328460965838, 79.98463971274239, 43.41202517918178, 12.543616788727896, 22.928060020719254, 53.83298206329346, 64.59148243495396, 42.1915602002825, 9.175615617207118, 0.3614988135440009, 0.06119327353579657, 0.10965068225881883, 0.29664603780422893, 0.19043524989059993, 0.12993584626487323, 0.10741199845714228, 0.21337069704064301, 0.11646476840334279, 0.07534260821661778, 0.13045734113880567, 0.14905245761786187, 0.11860599422029086, 0.1156931926629373, 0.18260065386337893, 0.18673262000083923, 0.08364432810672692, 0.07327600768102066, 0.1855968473745244, 0.1509806505803551, 0.17863463025007928, 0.2440984132034438, 0.19728768004902772, 0.17984771515641892, 0.355511230549642, 0.13898021594754287, 0.11773480953914778, 0.19688723582242215, 0.1560472444232021, 0.016798170848882625, 0.0076879561280033416, 0.012009916311529065, 0.04354636224785021, 0.04636629271720137, 0.02430830160821123, 0.046060500733022175, 0.04385989631659218, 0.10482998950673, 0.28949655858533724, 0.21498913876712322, 0.21050627503011907, 0.3046279437839985, 0.1823546713484185, 0.08790590121809926, 0.1412704209131854, 0.1590629526014839, 0.17851862790329115, 0.12635580051158155, 0.22618644578116281, 0.14145724874522003, 0.19671172595449857, 0.14938491263559886, 0.15302907994815282, 0.38749159021036966, 0.1954516185713666, 0.13135542294808797, 0.21229724107044085, 0.20477068637098583, 0.12237569051129477, 0.07268408765750271, 0.09673739410936832, 0.1223858685365745, 0.11979125919086592, 0.19666178577712604, 0.21254061801092966, 0.1990115661174059, 0.1732682596359934, 0.14211807399988174, 0.16923370398581028, 0.22107315515833242, 0.38731063849159647, 0.2625105966414724, 0.2975377142429352, 0.2739078407841069, 0.46814166541610447, 0.23046460907374108, 0.6380891746708325, 0.268179431025471, 0.32015442635331837, 0.261115555784532, 0.46922460730586735, 0.31961699947714806, 2.6646532671792165, 48.27746997560774, 93.14474323817662, 98.89815044403076, 88.75938769749233, 65.26429040091378, 46.76806763240269, 50.81102636882237, 64.35339546203613, 94.62778759002686, 91.72504561288017, 72.19080366407121, 29.06824564933777, 2.866934869970594, 0.5077683276363781, 0.20417859671371325, 0.45676795286791666, 4.29039147070476, 13.183146357536316, 13.631998249462672, 10.036638123648506, 1.588059425354004, 1.1076300335781915, 1.3202166834047862, 0.31881554105452126, 0.2806529131318842, 3.203218562262399, 17.641726357596262, 42.537135805402485, 55.92271184921265, 61.50343200138637, 68.65557411738804, 73.102358681815, 90.3284021105085, 84.70095184871128, 90.07921191624233, 94.31998934064592, 96.44085053035191, 91.75142097473145, 76.06192997523716, 56.051382064819336, 41.76310995646885, 19.15778681210109, 1.2471719001020705, 0.4427140812788691, 1.2578972045864378, 3.3363675432545796, 0.4907103372471673, 11.50315271105085, 89.7781742640904, 90.7572796685355, 81.16134493691581, 80.58477646963937, 81.02770328521729, 83.09396553039551, 84.39475863320487, 85.0515718460083, 93.00054727281842, 89.35534858703613, 97.9439890725272, 90.27112116132463, 80.88445922306606, 77.17402390071324, 80.0408992767334, 70.84257520948137, 41.64989948272705, 10.887509311948504, 1.5118671080895831, 0.2212401833385229, 0.9854826565299715, 0.5352701119014195, 0.39126239929880413, 0.12549005768128804, 1.5927920171192713, 0.41591694205999374, 0.8348687812685966, 1.45767528457301, 3.2008746308939795, 2.8980158993176053, 0.8117289458002362, 0.2901917855654444, 0.1518597062677145, 6.846918608461108, 36.812647002083914, 58.1266040120806, 66.43486731392997, 76.81118202209473, 38.54865094593593, 30.34806387765067, 60.31916018894741, 76.40499033246721, 78.28615951538086, 54.09837545667376, 11.896435516221182, 0.38542767667344635, 0.11639527284673282, 0.163589405428086, 0.35553560352751185, 0.2358244386102472, 0.34875693012561115, 0.17471657906259808, 0.2440999059804848, 0.27891811622040613, 0.2124470616025584, 0.1693293231406382, 0.21378449483641557, 0.27960636786052157, 0.13050783771489347, 0.21832921382571968, 0.27425286227038925, 0.18803495940353188, 0.18889193556138448, 0.23443458176084928, 0.17748589760490827, 0.2815747708082199, 0.3286909397159304, 0.3246133785162653, 0.20053814777306148, 0.40037794730493, 0.2502614382122244, 0.1573167291602918, 0.2406362018414906, 0.3050555836941515, 0.12226023099252156, 0.2270999439060688, 0.07773481056626354, 0.14023969907845768, 0.10930944699794054, 0.08781690456505332, 0.16487920550363405, 0.10052433197519609, 0.20790646810616764], [0.0362293188061033, 0.1320980523845979, 0.045559663857732496, 0.021765683311969042, 0.040454603864678314, 0.03874759974756411, 0.02982752750228558, 0.04011144156434706, 0.04303227358364633, 0.06316632444837264, 0.03900592142183866, 0.01961530914663204, 0.05441036607537951, 0.017840383674151132, 0.026196708669885993, 0.036196050234138966, 0.041708685856844695, 0.03814855510635035, 0.008445277544004577, 0.08150198949234826, 0.00756864422666175, 0.03507169395951288, 0.044181962963193655, 0.027830673581255332, 0.05195536530975785, 0.03732888480382306, 0.032912324116166146, 0.0317143026872405, 0.03426294128543564, 0.02191049455931144, 0.039827606973371336, 0.03202909204576697, 0.048746593562620025, 0.042917146547032256, 0.038371063702340634, 0.02240292608205761, 0.06946406579975571, 0.057252538922641955, 0.03889085206070116, 0.025601048222077743, 0.10745993017085961, 0.06375499428915125, 0.11607269729886736, 0.10860834390457187, 0.10224983295691864, 0.08110533827649695, 7.448226571083069, 37.775889669145855, 65.57463863917759, 83.67930957249233, 75.82289109911237, 60.89326899392264, 35.59562832968575, 33.7312981060573, 63.55643013545445, 70.97095012664795, 70.60197298867362, 38.45218563079834, 14.605816943304879, 1.5541560160262244, 0.12473093984382493, 0.4347771757415363, 0.3066903645438807, 1.1787107565573283, 4.847708650997706, 3.6592596684183394, 2.8596399128437042, 42.800924164908274, 25.060201610837662, 0.6705065380249704, 0.34614579166684833, 0.3671947350459439, 0.18763189603175434, 0.2174633624298232, 0.13997842238417693, 0.531623339014394, 1.5833212967429842, 6.340867842946734, 3.0074289653982436, 5.650481368814196, 12.352432761873517, 15.737859146935598, 13.353437151227679, 6.249039147581373, 3.3320177538054327, 0.4219765311905316, 0.43864118840013233, 0.4868140806044851, 0.20317203072564943, 0.3778419537203652, 2.2835176501955305, 0.14177592950207846, 0.025557662692985365, 8.672647680555071, 55.763083934783936, 82.65484632764543, 86.80258042471749, 80.23778343200684, 76.5485748563494, 81.93048272814069, 82.87481239863804, 84.61648954663957, 82.79457460130963, 81.3526496887207, 79.95131615230015, 75.24892820630754, 54.048893860408235, 22.941765342439922, 3.794761266027178, 0.07870483744357314, 0.191070982920272, 0.32223182916641235, 0.21539180858858994, 0.4122623253081526, 0.30003613446440014, 0.2071435504726001, 0.1537172637347664, 0.29127155191132, 0.3605474531650543, 0.6625505249415125, 1.8006782105990817, 1.9992889932223727, 0.32299347115414484, 0.026303028321958015, 2.5581769006592885, 27.372322389057704, 49.87553480693272, 56.80214534487043, 55.608045305524556, 44.585120814187185, 16.42190408706665, 36.90009355545044, 66.35823563167027, 61.15551485334124, 41.21933003834316, 13.883848735264369, 0.15982479814972195, 0.5177768820098468, 0.12067226905907903, 0.07983725132154566, 0.0482331800407597, 0.08175157502825771, 0.020008739017482315, 0.08330660087189504, 0.06988614850810596, 0.03337573978517737, 0.09276598292802062, 0.047578210543308935, 0.015453007404825516, 0.05468038230070046, 0.10971707691039358, 0.011847143394074269, 0.14974904166800634, 0.029687450733035803, 0.011537255602888763, 0.04976922047457524, 0.05553650689710464, 0.03619551079879914, 0.07080715801566839, 0.02340130215244634, 0.04086614213883877, 0.05054790047662599, 0.10637936993901219, 0.02866237091698817, 0.028142881114035845, 0.016576956558440412, 0.017298819430704628, 0.04734969012705343, 0.044567224968756945, 0.0861512775133763, 0.05429572419130376, 0.02307167662573712, 0.018811653966882398, 0.06584137412054197, 0.01250432152301073, 0.006363809882064483, 0.07581473288259336, 0.055811160909278054, 0.0629946483033044, 0.033388581060405285, 0.04889497220782297, 0.009855505710999881, 0.023252838690366064, 0.05421683092468551, 0.0673856587548341, 0.04111727473459073, 0.08427712307976824, 0.027944815045754825, 0.05184450625841107, 0.04435099960703935, 0.015956254775768945, 0.008687279602911855, 0.009901328877146755, 0.02612159145064652, 0.022187216406954185, 0.06787455002112047, 0.022544953639486005, 0.07292856382472174, 0.03137684686641608, 0.05261750013700553, 0.01622657973452338, 0.09958846255072526, 0.023630467176969563, 0.035629826331777234, 0.01898548615697239, 0.03936781128868461, 0.07763860787131957, 0.048686695883848836, 0.04327776076804314, 0.03305799201396959, 0.0445855725556612, 0.031886905032609186, 0.04394649434834719, 0.052311178895511797, 0.06317662460995571, 0.07865892776421138, 0.10501156547772032, 0.01926141411864332, 0.06684796725000654, 0.12379175238311291, 0.10259375521647078, 0.07064768193023545, 12.906872085162572, 46.519864082336426, 79.24662290300641, 92.86816324506486, 60.558720179966514, 40.68348496300833, 27.279581308364868, 44.84393078940255, 90.55639335087368, 89.94238798958915, 68.22979545593262, 31.51258543559483, 11.935298527990069, 0.3423440142401627, 0.2998678306383746, 0.4165102259388992, 0.32919530836599215, 0.1171342246234417, 2.710514634847641, 2.089848122426442, 3.3818484970501492, 31.726551737104142, 12.495823604719979, 0.5965499665055956, 0.8111905146922384, 0.3371412248483726, 1.4710165858268738, 2.1639836643423354, 4.518279790878296, 5.809473088809422, 12.811628784452166, 24.124949761799403, 14.739356109074183, 18.845779691423687, 29.712369714464458, 31.213225773402623, 30.74361092703683, 18.345688308988297, 8.004779883793422, 1.9014112395899636, 1.3590601533651352, 0.4071439728140831, 0.051793351503355164, 1.3165093851940972, 4.235118985176086, 0.7323039791413716, 0.28070974722504616, 22.797428676060267, 73.44090270996094, 84.15996510641915, 91.68872737884521, 87.2276920591082, 85.50885363987514, 87.88096863882882, 87.75343445369175, 87.94132763998849, 91.516419001988, 85.96466936383928, 87.47249794006348, 83.15171200888497, 73.19829940795898, 51.93792690549578, 22.673111506870814, 0.7444345025079591, 1.5725934952497482, 2.188344265733446, 0.3140959771616118, 0.16818847507238388, 0.19946623886270182, 0.1906794546438115, 0.7049800253340176, 0.7487908601760864, 1.3322058000734873, 0.5929371203695024, 1.1595410023416792, 1.8531507892268044, 0.046465128128017695, 0.10887521851275649, 0.628112430019038, 18.736682551247732, 47.207791328430176, 65.30387428828648, 70.05338491712297, 63.73918860299246, 22.16601981435503, 17.28186525617327, 51.09631940296718, 69.81403337206159, 52.22269882474627, 19.635954890932354, 1.0002519211598804, 0.4855613963944571, 0.09232581726142339, 0.030464624387345145, 0.03259849827736616, 0.08138691673853568, 0.023422603063019257, 0.06586960796266794, 0.08273933881095477, 0.03781626293701785, 0.07096005231142044, 0.023758406651073267, 0.04474571021273732, 0.1028214240712779, 0.06485445850661822, 0.016202946359823858, 0.11931359767913818, 0.01439313740203423, 0.05797893101615565, 0.021306946141911403, 0.07909656928053924, 0.043410142950181446, 0.04630708035879901, 0.06600349649254765, 0.11645547247358731, 0.0666198166353362, 0.05957188018198524, 0.07271920863006796, 0.013486117590218782, 0.02747919244159545, 0.04379670435030546, 0.02853104385680386, 0.10080172387616974, 0.06121566519141197, 0.03773098126319902, 0.0637203279350485, 0.019344656794731106, 0.04022928274103573, 0.046480883711150715, 0.04793785445924316, 0.12300465176148073, 0.14574468082615308, 0.15047397491122994, 0.050715454521455934, 0.1611969316644328, 0.08151376886027199, 0.08808087504335813, 0.1786871895726238, 0.14879849553108215, 0.15086129627057485, 0.13623362832835742, 0.1277388177279915, 0.16478190358195985, 0.1834247482142278, 0.06824629900178739, 0.07303828972258739, 0.09356901555189065, 0.08060141067419734, 0.15154691519481794, 0.1342204420694283, 0.11383231715964419, 0.17321983937706265, 0.11210121826401778, 0.09582253212907485, 0.1610511009182249, 0.2316201813519001, 0.10853118090225117, 0.10324062979114906, 0.11757558451167174, 0.10767932089843921, 0.1522954207445894, 0.22009226493537426, 0.11535670714718954, 0.15328464337757655, 0.09030360648674624, 0.16327542013355664, 0.24762136702026638, 0.22542480379343033, 0.11386146023869514, 0.1483756053660597, 0.20970060969037668, 0.18251806258090905, 0.17636069655418396, 0.16883545821266516, 0.1562065915869815, 0.18957365969462053, 13.18765834399632, 53.94340283530099, 93.59393038068498, 103.32945442199707, 92.95021452222551, 74.62716865539551, 51.19584192548479, 46.409808090754915, 78.94857992444719, 80.27796486445835, 88.57036195482526, 52.35239042554583, 25.170801298958914, 2.643670358828136, 0.3889198792832238, 1.1647028625011444, 0.7607680889112609, 1.8140292827572142, 14.340612019811358, 8.33690811906542, 6.474471713815417, 81.55250767299107, 42.640354769570486, 0.44549539632030893, 0.891861868756158, 0.3601245901414326, 0.24993340724280902, 0.29291805784617153, 0.7469060527426856, 1.0427661027227129, 3.712073794433049, 10.762470398630414, 4.2288912279265265, 6.400986262730189, 14.196073855672564, 16.858282225472585, 18.589634350367955, 11.40473929473332, 4.351410116468157, 0.5987704587834222, 0.6430375948548317, 0.5590735003352165, 0.20766340329178742, 0.874467379280499, 3.7018273728234425, 0.7616047497306551, 0.17898545999612125, 10.824082681110927, 61.60116536276681, 90.19385024479458, 104.25620515005929, 103.27468872070312, 99.58993394034249, 103.3933014188494, 106.426620892116, 104.24475451878139, 103.75444098881313, 92.25969559805733, 91.9353745324271, 83.9400337764195, 73.28363718305314, 45.44968516486031, 16.51687901360648, 0.28140201579247204, 1.3935645818710327, 2.3590940747942244, 0.6738104064549718, 0.9341059390987668, 0.25823989723409924, 0.47076754165547235, 0.7110715870346341, 0.6978060102888516, 1.4165963402816226, 0.9247087176356996, 4.988852620124817, 5.323388406208583, 0.6308946407267025, 0.1542792942907129, 4.067333451339176, 38.12686055047171, 66.02497223445347, 69.14877114977155, 65.53714615958077, 59.20291818891253, 27.467259100505284, 49.84162759780884, 79.90688937050956, 79.66138866969517, 62.78993960789272, 24.896206753594534, 1.2205049310411726, 0.5504494830965996, 0.18157716521195003, 0.22480219363101892, 0.1268744319677353, 0.20435610147459166, 0.08877296719167914, 0.21466931807143347, 0.14630696922540665, 0.11362293482358966, 0.1231871098279953, 0.10109641842011895, 0.10580821987241507, 0.1698551063558885, 0.13439477128641947, 0.10606208696429219, 0.27584256125347956, 0.2331859687609332, 0.12944636467312062, 0.14259374061865465, 0.09284560222710882, 0.12677950491862638, 0.12798478667225155, 0.08098249629672084, 0.19537839107215405, 0.15035212359258107, 0.14605948036270483, 0.22971675491758756, 0.10254333327923502, 0.1577177569270134, 0.09821527052138533, 0.09780209019247975, 0.2631815863507134, 0.14510635579270975, 0.11844792270234653, 0.15845045261085033, 0.15367119120700018, 0.1513262963188546, 0.09908758835600955, 0.07454583168561969], [0.02974672076691474, 0.01514831804005163, 0.0443990704204355, 0.07507517720971789, 0.1610770888094391, 0.02354234753043524, 0.033419149062995396, 0.08464783390185662, 0.046945150941610336, 0.14815589572702134, 0.09302945129041161, 0.04730928336669292, 0.07709949144295283, 0.04446446084018264, 0.06398205246244158, 0.041510614699551036, 0.06367139877485377, 0.05132033456383007, 0.030226808041334152, 0.04975278635642358, 0.11437644117644855, 0.05459453405014106, 0.035126271923737865, 0.08132341264614038, 0.021150267317092845, 0.04090288141742349, 0.11235923799020903, 0.08036700396665505, 0.06934456221227135, 0.1086189765483141, 0.050912446808069944, 0.009204548051846879, 0.08421346292431865, 0.10772457918418304, 0.09129267305667911, 0.041558023941304, 0.05382500748549189, 0.016226574645510743, 0.07626070680895022, 0.007291694221618984, 0.048377175349742174, 0.06874782459012099, 0.06294392102531024, 0.1698696541466883, 0.015103329471977693, 0.12014787005526678, 0.46795797241585596, 0.21968612101461205, 7.677874956812177, 29.852410657065256, 56.6559031350272, 69.68368516649518, 76.40078667231968, 56.506878171648296, 28.913187912532262, 35.246029717581614, 50.36000142778669, 78.18462548937116, 69.02876881190709, 42.77647692816598, 14.46740448474884, 0.3947987066847937, 0.41439878780926975, 0.5056351221033505, 0.24384971654840878, 0.2919563837349415, 2.417738825082779, 8.13086884362357, 2.3337570343698775, 1.219787746667862, 0.12877910690648214, 0.15316452910857542, 0.329246279916593, 0.10487950899239097, 0.06974719810698714, 0.15647820915494645, 0.08337131954197373, 0.1580652211393629, 0.3355349153280258, 0.19583609008363315, 0.7828890904784203, 0.8694468715361187, 1.2087702921458652, 0.4351874994380133, 1.3402498598609651, 0.4695125232849802, 0.3838173502257892, 0.156660775787064, 0.3217084886772292, 1.137425754751478, 3.250345153467996, 1.6795708920274461, 0.1881482204688447, 0.13687720522284508, 0.9471299030951091, 9.078966174806867, 21.216677018574305, 20.76271993773324, 19.036436523709977, 14.877548830849783, 11.001834971564156, 7.555141976901463, 5.19192110640662, 2.489092481987817, 2.494222423860005, 1.5674737585442406, 0.4889271472181593, 0.24981732347181865, 0.16062690796596663, 0.09339298321200268, 0.09381471986749343, 0.2072447743266821, 0.08233172925455229, 0.15496674525950635, 0.14325335808098316, 0.5590906537004879, 0.81813659625394, 0.9873004789863313, 1.4659662225416727, 0.5261291595441955, 0.7809561342000961, 0.14273708792669432, 3.9265785813331604, 23.974882568631852, 58.204566274370464, 56.03636353356497, 38.21873658043997, 37.29777022770473, 29.13511684962681, 27.380377088274273, 53.5492627961295, 65.33466175624302, 43.552632399967735, 19.57570879799979, 2.9951838510377065, 0.2959832176566124, 0.11401478201150894, 0.21918594571096556, 0.04367339757404157, 0.09398503894252436, 0.07497077102639846, 0.056844773303185187, 0.1193264898444925, 0.09364501825932946, 0.05475870220522795, 0.05402636953762599, 0.06010329523789031, 0.10412351920136384, 0.05384284956380725, 0.021855975966900587, 0.005348437357627387, 0.039872838117714436, 0.014643421829012888, 0.07298267020710877, 0.04892082778470857, 0.06275875560407128, 0.09277428819664887, 0.016008378139563968, 0.05455751996487379, 0.07007573797766652, 0.020153058326936195, 0.05659513009179916, 0.05209868547639676, 0.02266529861039349, 0.014107671782507427, 0.032950132087405236, 0.0999807236450059, 0.05992799571582249, 0.010245572592663978, 0.017423242397074188, 0.06740382992263351, 0.0649574872638498, 0.019541163928806782, 0.059435006098023484, 0.05531120612951262, 0.05199480515771678, 0.07265606416123253, 0.030797690086598908, 0.050583102873393467, 0.11582865539406027, 0.0756720844656229, 0.05668938199856451, 0.08470561115869454, 0.15014420689216681, 0.045280005649796555, 0.2597525417804718, 0.02963086769783071, 0.08141246358198778, 0.07025248277932405, 0.05889703639383827, 0.10031081736087799, 0.107356718209173, 0.09732636250555515, 0.030955680180341005, 0.04904898947903088, 0.06710779187934739, 0.0982431515253016, 0.057757531824920855, 0.05546424970296877, 0.031978025500263484, 0.08693252237779753, 0.037054824509790966, 0.13420456434999192, 0.02050944188210581, 0.09534206826772008, 0.05304061082590904, 0.0506744031528277, 0.026127879773931842, 0.06613663184855666, 0.07174517839614834, 0.01921159607757415, 0.04303407848679593, 0.07059972307511739, 0.009098324242846241, 0.13334825315645762, 0.10722764727792569, 0.045056991545217376, 0.07205370826912777, 0.026995327423459718, 0.36073614018304007, 0.011179043395843889, 0.06294839935643332, 0.5473206767014095, 0.4112040006688663, 14.443203909056527, 42.534450326647075, 76.84205981663295, 81.5861508505685, 66.42109598432268, 38.10675246374947, 29.513137068067277, 45.979130949292866, 78.71279280526298, 97.49159186226981, 82.31104946136475, 42.11953517368862, 11.425553492137364, 0.3427583820053509, 0.44400481773274286, 0.6130971014499664, 0.147738976670163, 0.7930801979133061, 0.30464523285627365, 18.078802789960587, 10.106404985700335, 2.8053308384759084, 0.18857676961592265, 0.1362501574414117, 0.44242011276738985, 0.4604508238179343, 0.13817658621285642, 0.19507009190108093, 0.08542840701660939, 0.7828000666839736, 0.8176984797630991, 0.7371383511594364, 2.4357489900929585, 2.7694132115159715, 3.615968699966158, 2.142684178692954, 1.9454324202878135, 0.5853511531438146, 0.2956362691308771, 0.1393602905528886, 0.6804715575916427, 3.2921780858721053, 4.394035143511636, 4.447497623307364, 1.2938360018389565, 0.23014683755380766, 4.658471422536032, 25.021541833877563, 42.585599490574424, 41.61660371507917, 39.058422906058176, 36.722358635493684, 30.26648507799421, 23.989208017076763, 19.611485072544642, 13.213084408215114, 11.847380365644183, 8.828425424439565, 6.63563083750861, 1.4979062229394913, 0.40436548047832077, 0.6418480958257402, 0.22054583845394, 0.1909761101539646, 0.06161111540028027, 0.2920994189168726, 0.09546264394053391, 0.18256703923855508, 0.3107573405972549, 0.6365185560924667, 0.601767900799002, 1.3383184777838844, 0.16713898495904037, 0.4453961673591818, 1.0797240052904402, 12.232519882065908, 51.10970163345337, 76.03883416312081, 59.61755888802664, 51.08327068601336, 33.36695541654314, 21.828090701784404, 36.49583346503121, 71.81064687456403, 57.649005685533794, 29.29258734839303, 5.63582284109933, 0.3318083467228072, 0.1026404859232051, 0.274049166057791, 0.11975924590868608, 0.06712253644530262, 0.061061610600778034, 0.13404033173407826, 0.0791194291253175, 0.14859939978591033, 0.035753930386688025, 0.06768890962536846, 0.061359344981610775, 0.09627986473164388, 0.03322972244183932, 0.013448315556161106, 0.026097740944741026, 0.006610032004703368, 0.039940464310348034, 0.03886207199788519, 0.02423567630882774, 0.062252744899264405, 0.04391329362988472, 0.015251049938212548, 0.0709590684356434, 0.1079137751034328, 0.04207592597231269, 0.03481676496033158, 0.03551601904577442, 0.054943324798452, 0.04176398306818945, 0.07452159441475358, 0.09396053025765078, 0.11015872178333146, 0.021936311120433465, 0.048536006826907396, 0.07604833891881363, 0.08810541765498263, 0.017399924541158334, 0.05157833732664585, 0.07240800532911505, 0.03310224946056094, 0.19300260926995957, 0.1397635167730706, 0.13483953742044313, 0.29403264660920414, 0.2999534346163273, 0.12969782975103172, 0.18835980125835963, 0.160337947042925, 0.09265555135373559, 0.4435716952596392, 0.1815004771841424, 0.21610813800777706, 0.16673775363181317, 0.1549726485141686, 0.19063127865748747, 0.20306305800165447, 0.1916379396404539, 0.14206455115761074, 0.20135301404765674, 0.16351659862058504, 0.285985845540251, 0.17034240306488105, 0.12914190601025308, 0.24581499823502131, 0.2211931472910302, 0.09746945197028772, 0.1636979981724705, 0.1972901906285967, 0.17938617563673429, 0.19708087614604405, 0.14687702006527356, 0.12085129373839923, 0.2689866434250559, 0.17113375131572994, 0.21949394632663044, 0.13608831326876367, 0.23097408030714306, 0.1283174588211945, 0.1687898470887116, 0.3011182349707399, 0.12979122331099852, 0.1485081911087036, 0.1388878266194037, 0.3348842273865427, 0.10553114688290016, 0.2081067580729723, 0.6516096091696194, 0.31652830807226046, 14.25377082824707, 48.62977491106306, 85.55849851880754, 93.6919972555978, 91.1588716506958, 71.91036047254289, 42.75269324438912, 48.809267725263325, 67.00050626482282, 89.90823759351457, 92.5833774294172, 61.877578599112375, 23.981844663619995, 0.8746986240148544, 0.6475429588130542, 0.8600678348115512, 0.18024655804038048, 2.299243594918932, 10.308853779520307, 8.036196163722447, 5.055108036313738, 4.369754663535526, 0.24548528449875967, 0.4066901414522103, 1.0160989165306091, 0.35587723233870094, 0.39597251798425404, 0.3376616340662752, 0.09261701056467635, 0.21134442862655434, 0.42519446994577137, 0.300751690353666, 0.8156765539731298, 0.7455781868525914, 1.3442533250365938, 0.8918531835079193, 2.173384359904698, 0.5704473214490073, 0.41165419508303913, 0.1329540785934244, 1.8534102610179355, 5.8497035929134915, 11.650865333420889, 6.467686797891345, 0.6768272817134857, 0.21927321888506413, 1.1362877701010023, 11.57944653715406, 26.859887531825475, 26.075380325317383, 23.601253611700876, 19.29932509149824, 13.357824938637869, 8.578811390059334, 6.142492864813123, 3.287849575281143, 2.829533585480281, 1.8271371679646629, 1.6092191870723451, 0.42472967345799717, 0.4769646291221891, 0.9941607394388744, 0.20280976087919303, 0.36650542489119936, 0.19746392273477145, 0.1795819058482136, 0.17768753107104981, 2.215620504958289, 2.3053990474769046, 4.40628308057785, 1.677835687994957, 2.774948103087289, 0.9052239060401917, 0.3268453787480082, 5.844751264367785, 34.83791337694441, 77.35216876438686, 73.2569283076695, 47.49652024677822, 48.24372257505144, 42.006029401506694, 40.17267424719674, 63.85580021994454, 83.5737247467041, 69.89152663094657, 37.749260698046, 7.111795663833618, 0.4746408366731235, 0.27259351845298496, 0.34961410984396935, 0.49431189256055014, 0.2251730944429125, 0.16779174921768053, 0.23104418654526981, 0.2732904553413391, 0.28117709500449045, 0.14171240505363258, 0.18494850716420583, 0.21233430265315942, 0.21547612335000718, 0.11177241376468114, 0.1554274976785694, 0.10249865174825702, 0.11872879548796586, 0.1370269443307604, 0.18886228358106955, 0.17298840465290205, 0.16982405659343514, 0.23566566141588347, 0.2419101106269019, 0.1686231717467308, 0.21545350099248545, 0.2048637949462448, 0.11753076048833982, 0.16782722302845546, 0.17448587715625763, 0.12764725621257508, 0.1702840897653784, 0.2277420008821147, 0.36107196073446957, 0.12265863961407117, 0.19706875751061098, 0.1935187844293458, 0.2541287349803107, 0.15053133826170648, 0.12181075582546846, 0.12308831512928009, 0.12428111183856215], [0.06099975534847804, 0.07988704900656428, 0.014862193393387964, 0.016294149948017936, 0.03827493225357362, 0.0017812818613102926, 0.021750188964818205, 0.017075552571831003, 0.07144303353769438, 0.02334412370276238, 0.03187729697674513, 0.030724320095032454, 0.06253379410398857, 0.10542943448360477, 0.03894959622994065, 0.05473246325605682, 0.05033873527177742, 0.0029571260092779994, 0.06722434383950063, 0.05255970252411706, 0.02587632818280586, 0.047681069666785855, 0.033670675209058185, 0.008361831307411194, 0.05738990155181714, 0.016669395080368434, 0.027497193975640193, 0.03149001632950135, 0.003741100280811744, 0.05029438283028347, 0.025930780618052398, 0.05695344068642173, 0.029303254027451788, 0.014581592021776097, 0.017472948479865278, 0.07005058468452521, 0.09120829044175999, 0.022005533566698432, 0.04652077139222196, 0.033379566722682545, 0.06186466358069863, 0.01755535146886749, 0.15366288593837193, 0.05204877583310008, 0.018227036676502655, 0.19822781745876583, 0.12166989195559706, 0.05902008193411997, 0.49452842665570124, 0.1986102940780776, 7.678658366203308, 41.34571429661342, 59.46951362064907, 74.77576283046177, 71.18626090458461, 56.11712939398629, 33.97415501730782, 22.698642662593297, 34.78704561505999, 60.93402017865862, 76.1286187853132, 45.34165457316807, 13.617552076067243, 1.9492791167327335, 0.15230331889220647, 0.04190306578363691, 0.21904434902327402, 0.4396054138030325, 0.5818401958261217, 0.6647431701421738, 1.1428908386400767, 1.3564531675406863, 1.1997037615094865, 0.333848918655089, 0.16885314083525113, 0.190193325015051, 0.18783598579466343, 0.3018718702452523, 0.4034864247909614, 0.7387648810233388, 0.4400047723736082, 0.45526119800550596, 0.14682576352996485, 0.09299307502806187, 0.12448904210967676, 0.08050522154995374, 0.13892610956515583, 0.0662662795345698, 0.3707142419048718, 2.0123830905982425, 2.6669448699269975, 3.144815913268498, 1.6208218101944243, 0.2303496923829828, 0.05073073852275099, 0.5436859003135136, 0.8883460259863308, 0.8613970034888813, 0.7614597060850689, 0.6729230454989842, 0.39003824070096016, 0.44252865122897284, 0.07109606465590851, 0.23705323838761874, 0.1511443675096546, 0.13612287784261362, 0.018297232820519378, 0.13967585004866123, 0.7860523664525577, 0.13633592426776886, 0.03996545475508485, 0.43982354924082756, 0.024371066097436205, 0.10780170825975281, 0.3825911560228893, 0.45007713618023054, 0.22132630300308975, 0.06861210401569094, 0.26250299704926355, 0.8496592704738889, 9.41638720035553, 25.1441045829228, 51.9552070753915, 55.92488316127232, 37.54254136766706, 27.35319573538644, 39.96792473111834, 62.33392933436802, 63.69634601048061, 68.56442764827183, 56.60033144269671, 29.048778533935547, 3.684858569077083, 0.33381347198571476, 0.09756520683211939, 0.11435246174888951, 0.08896921987512282, 0.11177149774240595, 0.09934078369821821, 0.033741018934441466, 0.0279095600625234, 0.055047049054077694, 0.018845092172601392, 0.0306566735463483, 0.04851176616336618, 0.017492122183154737, 0.010988352155046803, 0.013805720306533788, 0.06173021186675344, 0.09042977328811373, 0.038123116828501225, 0.05729404490973268, 0.04295172129890748, 0.048258625103959014, 0.01852128847635218, 0.051551460554557185, 0.0379622768876808, 0.05640722678175994, 0.04764120573444026, 0.0532072997385902, 0.009562046948953398, 0.058914237256561, 0.02939448306070907, 0.060008056062672815, 0.03777092322707176, 0.0261269722333444, 0.05495542986318469, 0.04585777821817568, 0.06067996857953923, 0.03074039119694914, 0.02287310335252966, 0.04873647660549198, 0.03565137321129441, 0.04550404094957879, 0.05875596896346126, 0.052586531798754416, 0.04196088375257594, 0.047812766528555324, 0.01939350113804851, 0.020568277653572813, 0.027250895941896097, 0.00902500853408128, 0.027561296875189458, 0.059608480360891135, 0.13275532211576188, 0.018551120268447057, 0.03625647038487451, 0.028941913773970943, 0.07317251751997642, 0.0664922995492816, 0.07609269475298268, 0.06273440976760217, 0.0626332334109715, 0.04901859111019543, 0.008533481159247458, 0.06204693165740796, 0.03330421540886164, 0.029189514594950845, 0.06409297936729022, 0.038649008609354496, 0.014505709754303098, 0.007820801410291876, 0.027011369687638113, 0.0823298700686012, 0.08422186318784952, 0.019746980563338314, 0.09438853657671384, 0.04571894656068512, 0.01209233541573797, 0.023375779057719877, 0.01708028874626117, 0.06714847005371537, 0.11601909303239413, 0.06184290296265057, 0.018309931603393385, 0.020001985897709216, 0.0741681455235396, 0.04812548974795001, 0.1459970279995884, 0.0418101471981832, 0.040928543611828766, 0.1112022747152618, 0.19167825819126197, 0.05169336597568222, 0.36469750904611176, 1.0447508990764618, 11.936590024403163, 52.40463045665196, 74.36297035217285, 81.91709354945591, 58.41521481105259, 37.797988414764404, 28.761849199022564, 37.20468521118164, 62.32768290383475, 83.11698491232735, 88.2891127722604, 37.375180108206614, 10.063521572521754, 0.8645355265055383, 0.15753774158656597, 0.028178488935476968, 0.1574095120387418, 0.3458476705210549, 0.5813855773636273, 1.257474558694022, 0.2691116024340902, 0.8178564969982419, 1.6593231899397713, 0.46298811052526745, 0.2517353248383318, 0.9720272528273719, 0.40173914283514023, 0.12771639893097536, 0.3624338076582977, 0.5159480401447841, 0.26085784818444935, 0.689804236803736, 0.08415529211716992, 0.0870981595611998, 0.053166896370904784, 0.06035162548401526, 0.04542583978867956, 0.03249414637684822, 0.3361033648252487, 3.5917453254972185, 7.430859548704965, 5.261846474238804, 3.0410489099366322, 0.9479246033089501, 0.03810815852401512, 1.134392214672906, 2.584018119743892, 3.068251541682652, 2.328561953135899, 2.2792512391294752, 1.1144832372665405, 0.8999675395233291, 0.09488006734422275, 0.21977728897971766, 0.127222886841212, 0.2503035345247814, 0.06175062220011439, 0.2181539618011032, 0.8695073968597821, 0.20642228131847723, 0.1425851232239178, 0.3709582973803793, 0.21862041391432285, 0.05680269056132861, 0.1170743778347969, 0.14176238594310625, 0.20977351149278028, 0.1441954089594739, 0.1501616452421461, 1.0736887348549706, 0.31555021341357914, 14.803868395941597, 47.45365680967058, 69.21442467825753, 64.65496812547956, 40.72920410973685, 30.364777769361222, 43.310796873910085, 50.4120260647365, 65.25386115482875, 70.3998498916626, 37.45860365458897, 7.481916649000985, 0.3184662312269211, 0.2129267451486417, 0.05602262295516474, 0.07138909000371184, 0.16798708587884903, 0.07848117194537606, 0.017256088687905242, 0.03763688202681286, 0.026218952744134834, 0.05490742011794022, 0.0657353326678276, 0.07174525982035057, 0.042778779686029465, 0.03738118628306048, 0.037555037132863484, 0.019599122693762183, 0.03652295822809849, 0.033723858783819845, 0.04286308087674635, 0.044667010328599384, 0.0213645809063954, 0.03362771037167736, 0.036639303235071044, 0.04731583801497306, 0.0667781052844865, 0.04302909803975906, 0.028517992235720158, 0.01664678629354707, 0.04207624827644654, 0.041939408119235716, 0.022681330696546605, 0.08373798629535095, 0.03781962847071035, 0.04500860521303756, 0.02832055720500648, 0.008896876525666033, 0.034265390796852965, 0.0524102789349854, 0.05395769500838859, 0.04869555415851729, 0.04463360944230642, 0.012301708421935993, 0.011710194671260459, 0.2381420699613435, 0.18412017875484057, 0.07132517879030534, 0.13624949247709342, 0.07333977640207325, 0.10083898223404374, 0.13458389256681713, 0.11597527324088983, 0.14079350578997815, 0.09534905717841216, 0.12187703512609005, 0.11081357592982904, 0.22795202104108675, 0.1509485151618719, 0.2017630934715271, 0.13326560759118625, 0.1579364351928234, 0.09064910294754164, 0.1347158404865435, 0.10070256276854447, 0.14303847961127758, 0.09726398478129081, 0.09696898489658322, 0.04936167198632445, 0.12786341032811574, 0.09361996674644095, 0.12851317546197347, 0.16664208019418375, 0.2120236421802214, 0.14670342366610253, 0.2985613521720682, 0.11679498425551824, 0.0869020154433591, 0.12068434698241097, 0.18422282753246172, 0.17367053590714931, 0.1969010779368026, 0.22284799920661108, 0.12440962637109415, 0.1574100005839552, 0.17871693654784135, 0.10123658339892115, 0.261850436351129, 0.2305505930313042, 0.14775888488761016, 0.287323672324419, 0.2814334455345358, 0.13427214643784932, 0.7868739909359387, 0.7599606865218708, 13.141391158103943, 60.4977080481393, 86.26280961717877, 94.89357008252824, 85.73173100607735, 72.23617540087018, 47.323152269635884, 36.248477595193044, 46.35960040773664, 78.62512043544224, 94.5505931036813, 61.1314879826137, 20.609520844050817, 3.656909440244947, 0.38266199507883614, 0.2769501475351197, 0.4318735072655337, 2.417482827390943, 4.767023997647422, 7.67535970892225, 9.355574829237801, 3.8578470008713857, 5.790952231202807, 0.4016232490539551, 1.3086644347224916, 0.7612671107053757, 0.792132203068052, 0.5060001739433834, 1.5355137820754732, 0.8217775608812059, 0.71957949336086, 0.7597413840038436, 0.18353724932031973, 0.21211274739887032, 0.08503425280962672, 0.10998528823256493, 0.16428997926414013, 0.12535147368907928, 2.0969821853297095, 7.235071906021663, 13.799146720341273, 13.575972318649292, 7.12103807074683, 1.0565342839275087, 0.08576274836169821, 0.736409278852599, 0.828192973775523, 0.9255203540836061, 0.6313739035810743, 0.8525496668049267, 0.5755016473787171, 0.37919601106217926, 0.13213250839284488, 0.29712291221533504, 0.1815106552094221, 0.5497455437268529, 0.2713134214282036, 0.33557019914899555, 1.3433155353580202, 0.41442117946488516, 0.27908745141966, 0.7155595804963792, 0.9041519292763301, 0.11849099610533033, 0.30859710222908426, 0.8093993993742126, 0.8262531235814095, 0.32102243549057413, 0.27157123759388924, 1.119269134742873, 13.48362728527614, 39.07496656690325, 69.57887159075055, 72.15086541857038, 47.539143971034456, 36.13118158067976, 48.95446423121861, 75.14977046421596, 71.51302078792027, 83.40575204576764, 78.4468366077968, 46.59355320249285, 10.628447464534215, 0.2886064292064735, 0.299978893250227, 0.4098989064139979, 0.2249720852289881, 0.19947796394782408, 0.3431454455213887, 0.17560548707842827, 0.16014588092054638, 0.25846158819539206, 0.10520036784665925, 0.21482306053595884, 0.19636563238288673, 0.12986804704580987, 0.1632211780441659, 0.16070126183331013, 0.11642877890595368, 0.1576595657638141, 0.08951160684227943, 0.17872155058596814, 0.24580416881612369, 0.14360929041036538, 0.13383305285658154, 0.2973854238433497, 0.17812464333006314, 0.14136556509350026, 0.11113127959626061, 0.10254796767341239, 0.10266291829092161, 0.15504211692937783, 0.10521461029670068, 0.2242622018924781, 0.14673379489353724, 0.12059237834598337, 0.15870820092303412, 0.13204756937921047, 0.14472567050584725, 0.10653142285134111, 0.11753416673413344, 0.15285281012100832, 0.1365054358861276, 0.09491426550916263, 0.11929959271635328, 0.11037748147334371], [0.04799793873514448, 0.06230328218745334, 0.015144672610663941, 0.06291718674557549, 0.049012525007128716, 0.03450883898351874, 0.0856028108724526, 0.00881750658819718, 0.06200543245566743, 0.014060447441547044, 0.025143194843881896, 0.032699298047061474, 0.008909690659493208, 0.032383555346833806, 0.10231754396642957, 0.05995652132800647, 0.06984127698732273, 0.046964750425623994, 0.04167977687237518, 0.04059633965204869, 0.0480465252351548, 0.05932648120714085, 0.04123919729941657, 0.06829070911875793, 0.018620761710086038, 0.03138901639197554, 0.030429058974342685, 0.01374203640235854, 0.0466969122977129, 0.03649389657324978, 0.02978208940476179, 0.07536557662699904, 0.02345306928535657, 0.04445377052096384, 0.03164160105266741, 0.07809294134910617, 0.03285572751026068, 0.06816570939762251, 0.05307163344696164, 0.0951875794146742, 0.07059969593371664, 0.05445231989558254, 0.02319883239189429, 0.0458736830790128, 0.07662183671657528, 0.1006294981177364, 0.1532997339963913, 0.10265119999114956, 0.18920621941132204, 0.041342877450266054, 0.23035379073449544, 0.4042107473526682, 8.979926552091326, 46.623246329171316, 70.98437404632568, 70.42043740408761, 68.39202894483293, 52.51664236613682, 37.896861280713765, 34.46704980305263, 39.42214373179844, 58.41323457445417, 75.82451002938407, 52.23214142663138, 23.573556355067662, 3.575817448752267, 0.7821906879544258, 0.09053079358169011, 0.3390375945184912, 0.2102576055164848, 0.3049193067210061, 0.2146999200007745, 0.8595300008143697, 0.48082929317440304, 0.6106576323509216, 0.7439727729984692, 0.5703915730118752, 0.3959194565457957, 0.3850353205842631, 0.6630469411611557, 0.3419963871794087, 0.6774662988526481, 0.2338611382458891, 0.14954717749995844, 0.6132315599492618, 0.5748132871729987, 0.16981834332857812, 0.5573382963027272, 0.6440216334802764, 2.405608355998993, 1.9261318445205688, 1.8848389174257005, 2.2823822711195265, 0.4425947948225907, 1.1117000494684492, 1.134505557162421, 0.8291292978184563, 1.0489211210182734, 0.6014590316585132, 0.5821670325739043, 0.3480988325817244, 0.40799724417073385, 0.11865313883338656, 0.20517854019999504, 0.2731314610157694, 0.5173787176609039, 0.18858042013432297, 0.08857239224016666, 0.5007306167057582, 0.7215367683342525, 0.3293598123959133, 0.8260997203843934, 0.4398999251425266, 0.18043234092848642, 0.5283723963158471, 0.31292363149779184, 0.6163175914968763, 3.741829889161246, 14.380394799368721, 36.46803372246878, 57.82607010432652, 48.56522614615304, 32.716333048684255, 40.03180994306292, 36.7245751108442, 49.87834187916347, 57.352835246494834, 51.42509078979492, 55.1892808505467, 33.78849567685808, 8.90449343408857, 0.38018015825322693, 0.14729541832847254, 0.18404999109251158, 0.18702671064862184, 0.05444327163110886, 0.020620614755898714, 0.13370083352284773, 0.008569943086643304, 0.0354852067705776, 0.029373635072261095, 0.08172512573323079, 0.04294987229098167, 0.023301744101835147, 0.056722165417990515, 0.03347760146217687, 0.07605138554104737, 0.0353283226889159, 0.02517638199164399, 0.06109353567340544, 0.03293898036437375, 0.08641252706625632, 0.05276295768895319, 0.032901006152055094, 0.024614670347156267, 0.01185036389090653, 0.08246932258563382, 0.017524549371695945, 0.09524370783141681, 0.02847090529810105, 0.03739265691755073, 0.04484332426052008, 0.04763144840087209, 0.03404609506417598, 0.03466727012502296, 0.039914147329649756, 0.015984524240983383, 0.045557699498853514, 0.01333887379483453, 0.046788718085736036, 0.05948795218552862, 0.009286673689660217, 0.0452910284511745, 0.06642439176461526, 0.0205670545942017, 0.0048708513329204705, 0.05455976591578551, 0.10364912822842598, 0.05639151191072805, 0.07005901208945683, 0.048962442337402275, 0.011463683747154261, 0.025812695168757012, 0.008887852858086782, 0.03784193530944841, 0.02967833461506026, 0.07545277516224555, 0.03221322948645268, 0.025153949623927474, 0.011923783076261836, 0.08805989474058151, 0.057583759006644995, 0.026567748581458415, 0.12995184612061295, 0.024088378230641996, 0.0037040162216206746, 0.049316257637526305, 0.024719190185091326, 0.013454292601506625, 0.09455107964043107, 0.036292917893401215, 0.031974327484411855, 0.08446858530598027, 0.0484153666932668, 0.07159522215702704, 0.08169276639819145, 0.042424380845789395, 0.03383704860295568, 0.10594717705888407, 0.026870914635115435, 0.10070793676589217, 0.05920873502535479, 0.049098407184439044, 0.0914650752342173, 0.053172660525888205, 0.1445621842784541, 0.15572621593517916, 0.021494043691615974, 0.008260185065280114, 0.05530919088050723, 0.033945356362632344, 0.129372078659279, 0.2858777684824807, 0.08462195457624537, 0.1232797841408423, 0.18561683701617376, 0.19835910041417393, 1.529770661677633, 15.894247463771276, 58.05168158667428, 86.42955943516323, 78.8820926121303, 60.65644659314837, 30.010065283094132, 22.98621470587594, 41.25416135787964, 63.912685121808735, 96.15795462472099, 82.87321431296212, 52.586329323904856, 15.750454493931361, 3.3778563226972307, 0.49705398827791214, 0.20752867337848457, 0.5529759675264359, 0.21921592338808946, 0.3137346165520804, 0.4391193655984742, 0.5277726799249649, 0.21924796381167003, 0.378725026335035, 0.08723247556814126, 0.2040537055581808, 0.2729523820536477, 0.8429765690650258, 0.5437026736991746, 0.23153932711907796, 1.4008675728525435, 0.366676605705704, 0.10653862889323916, 1.1600947954824992, 0.549932385129588, 0.054446270755891285, 1.1150595034871782, 1.2819804208619254, 1.1824440019471305, 2.8133208325931003, 2.096654534339905, 2.743993661233357, 1.5270535903317588, 2.1336675882339478, 1.361765825322696, 0.4086231520133359, 0.12047777378133365, 0.7445394854460443, 0.8081297246473176, 0.2504200796995844, 0.26423670830471174, 0.1329195818730763, 0.1837719138711691, 0.25341277197003365, 1.2231012774365289, 0.4589106578912054, 0.12247154036802904, 0.2912244615810258, 0.33823277056217194, 0.3800685799547604, 0.8573798047644752, 0.2307628659265382, 0.4128466253834111, 0.34193751748119083, 0.13959587791136333, 0.572968106184687, 0.3921591783208506, 3.665786632469722, 19.96039755003793, 51.13863740648542, 58.34177930014474, 55.906710147857666, 49.32592535018921, 30.718517507825577, 31.373152460370743, 53.196648665836875, 60.62153884342739, 71.1925629207066, 48.098571232386995, 16.09609089578901, 1.134031668305397, 0.29126821351902826, 0.03202213366915073, 0.1843074815613883, 0.059056234279913564, 0.014107502148752766, 0.15602481205548557, 0.011654334275850227, 0.09489305450447968, 0.051064557395875454, 0.0698232211704765, 0.02414823858998716, 0.03480684817103403, 0.04963214283010789, 0.0025420608373159276, 0.040331867057830095, 0.013456972814830286, 0.01461286230811051, 0.054897140312407694, 0.017352452534916143, 0.019024437459717904, 0.052105301192828586, 0.05282809026539326, 0.034567142104996104, 0.025466810246663432, 0.08864071393119437, 0.012951634707860649, 0.06868511438369751, 0.033653182576277425, 0.07827952490853411, 0.011194099239738924, 0.05314794149515884, 0.044297870315079174, 0.013502832452234412, 0.016383587648825984, 0.15105233101972512, 0.06445759694491114, 0.010516054462641478, 0.061682368362588544, 0.042475416857217035, 0.00753568353996213, 0.05800905118563345, 0.03522033044802291, 0.012165221951103635, 0.023537141470504657, 0.11969185381063394, 0.23646692984870502, 0.0892040269183261, 0.1537146038774933, 0.14960840850004128, 0.1023968511394092, 0.18268237662102493, 0.14096984347062452, 0.09689643593238932, 0.11705073767474719, 0.14696227120501654, 0.10184482897498778, 0.20245948753186635, 0.10686636130724635, 0.2169533890805074, 0.2156662895743336, 0.12473729093159948, 0.21526288693504675, 0.18906900605985097, 0.15290028043091297, 0.13683956010001047, 0.1346985785556691, 0.13163557648658752, 0.2618143654295376, 0.12626065633126668, 0.23373042525989668, 0.13554529526403972, 0.12453297046678406, 0.2384056401039873, 0.24079386623842375, 0.08834831962095839, 0.23576578604323523, 0.14632902161351272, 0.22473718997623238, 0.13264740790639604, 0.18927442575139658, 0.18333486946565763, 0.11766310195837702, 0.1412223670631647, 0.1955523674509355, 0.2639421426824161, 0.12396650229181562, 0.19295106774994306, 0.1659049197499241, 0.22087833418377809, 0.1501099273030247, 0.3284710943698883, 0.19966034059013638, 0.32558414499674526, 0.1550354401447943, 0.2941086696726935, 1.184991168124335, 17.77949697630746, 67.34435176849365, 96.25323527199882, 94.20068877083915, 83.09235354832241, 70.98093468802315, 54.21291651044573, 48.55053765433175, 53.52903311593192, 80.14560862949916, 98.29823602948869, 70.45751299176897, 34.16694320951189, 7.428835885865348, 1.5952440798282623, 0.19941996277443, 0.8384347270642007, 0.6019015450562749, 1.298976474574634, 1.4864093427147185, 1.7246708891221454, 3.215347945690155, 2.303145659821374, 0.797145274068628, 1.4109486490488052, 0.5451102267418588, 0.8707004242709705, 1.6356542600052697, 0.40357881411910057, 3.660932012966701, 0.6269681485635894, 0.20640653930604458, 1.3045880134616579, 0.8635616930467742, 0.26565625784652575, 1.2986967010157449, 5.4377036435263495, 9.00228932925633, 3.286754799740655, 5.867061495780945, 8.075813923563276, 3.6464506643159047, 2.785842878477914, 2.9682786890438626, 1.5152202653033393, 1.9397500966276442, 0.7924350468175752, 0.818821265229157, 0.44159913967762676, 0.4890404354248728, 0.2015285917690822, 0.35561955188001904, 0.3430720551737717, 1.4344212923731123, 0.47674125539405005, 0.24791832108582768, 1.0060308682067054, 1.4723148133073534, 1.537585648042815, 3.0194311099393025, 0.7537288037793977, 0.2727696661438261, 0.30887082325560705, 0.3881834516567843, 1.1905272539172853, 5.835095873900822, 20.958577496664866, 52.76217085974557, 77.6864743913923, 62.97355270385742, 44.11523151397705, 48.1553692817688, 50.8372106552124, 65.2681952885219, 73.84683731624058, 69.95296955108643, 78.36960043225969, 54.71354464122227, 19.52492962564741, 1.2072526535817554, 0.4473902460719858, 0.27058003363864763, 0.269754202238151, 0.2786503934434482, 0.2594286634453705, 0.4339419262749808, 0.13500495068728924, 0.20252956662859234, 0.13435960960175308, 0.27945863721626146, 0.136800137215427, 0.143191896378994, 0.15079246567828314, 0.10367273446172476, 0.11837905139795371, 0.06888415584606783, 0.13401180612189428, 0.13795159757137299, 0.1898867493229253, 0.17352999773408684, 0.19217679144016334, 0.20759371774537222, 0.107219362365348, 0.16945551708340645, 0.1496421316904681, 0.12091723377151148, 0.17528947974954331, 0.16744577778237207, 0.17162427785141127, 0.13597064172582968, 0.1937231184648616, 0.13498354969280107, 0.19708728151662008, 0.16921523426260265, 0.20182987488806248, 0.13872520891683443, 0.11781550092356545, 0.12230420006172997, 0.2249198651739529, 0.06551672225551945, 0.1770483646541834, 0.1496920311557395, 0.1404205286609275, 0.11674792106662478], [0.02658527174831501, 0.06940580678305455, 0.03204336163720914, 0.03323915068592344, 0.043685780838131905, 0.012466183614118822, 0.028021374151908925, 0.04892759617151959, 0.04175559976803405, 0.029329218169940368, 0.03457615305004375, 0.02038123777934483, 0.03035934628652675, 0.030791067584816898, 0.04921649263373443, 0.044669575190969875, 0.04640581738203764, 0.05143214695687805, 0.03053400120032685, 0.026071537618658373, 0.08541837148368359, 0.1527511112924133, 0.08615801536611148, 0.0553255741085325, 0.13293341041675635, 0.04191345754744751, 0.022082328463771513, 0.007379606066803847, 0.03438141010701656, 0.019259197005469884, 0.020761819589616995, 0.03760549978220037, 0.03135566978848406, 0.06006611830421856, 0.009856828006117471, 0.027599350815372806, 0.019524281977542808, 0.07148221893502132, 0.030900589922176938, 0.01164782203600875, 0.06299810204654932, 0.030264765290277343, 0.15766917381967815, 0.05595324953485813, 0.01981027770255293, 0.1550068331084081, 0.13796541254435266, 0.05225151191864695, 0.21331976620214327, 0.12066376022994518, 0.08684842474758625, 0.10954176381762538, 0.3443849118692534, 0.8219904037458556, 17.577052525111608, 45.275202001844136, 63.80867753710066, 62.23147119794573, 64.27783380235944, 51.5459303855896, 43.01669004985264, 17.397564922060283, 37.118954862867085, 52.16028315680367, 65.77121012551444, 65.07252706800188, 39.778155531202046, 24.706456661224365, 13.551882914134435, 6.595319126333509, 2.298890756709235, 0.36560528033546036, 0.05686543130182794, 0.07363523769059352, 0.07811200139778, 0.27828148752450943, 0.1034899235570005, 0.04260098994044321, 0.05295988551474043, 0.11071594152599573, 0.35690570143716677, 0.7830817944237164, 0.27620031205671175, 0.5499296167067119, 0.8738625603062766, 0.5221736260822841, 0.4993189924529621, 0.9688641939844403, 1.0008723735809326, 0.34128441395504133, 1.936978633914675, 1.213180661201477, 0.3396896666714123, 1.3805328011512756, 2.095417320728302, 2.147947004863194, 0.8603150929723467, 0.3575858920812607, 0.3611843804163592, 0.504352908049311, 0.08544227627239057, 0.39346128702163696, 0.32476322618978365, 0.15119590902967112, 0.7422099390200206, 0.7168822352375303, 0.26106800405042513, 0.4336092812674386, 0.5498393444078309, 0.5343033352068493, 0.08859990683517285, 0.21830763641212667, 1.0001112201384135, 2.911316922732762, 8.756597552980695, 15.305625608989171, 26.782434225082397, 46.65678528376988, 65.432589667184, 49.92450223650251, 33.35101624897548, 29.31934486116682, 40.357802050454275, 51.00985254560198, 54.23379932131086, 52.17280033656529, 50.93332856042044, 52.25054373059954, 15.495507717132568, 0.5704833109463964, 0.10045990507517542, 0.10417571890034846, 0.22673056301261696, 0.11012404185852834, 0.04791557136923075, 0.025713140510820916, 0.04113242302888206, 0.09742188666548048, 0.02217165081362639, 0.06510616107178585, 0.09089964521782738, 0.0641389704708542, 0.057490317949226925, 0.03957603332985725, 0.10711662537817444, 0.012710560545591372, 0.022634620345862846, 0.027391998995361582, 0.011743103619664907, 0.022540215768718293, 0.021311950337673937, 0.03759953885206154, 0.031356151548347304, 0.04792838550305792, 0.09936709050089121, 0.046157911220299344, 0.037050889006682804, 0.1024495190275567, 0.04353596709136452, 0.0037160916004462963, 0.06334572910730328, 0.07119248448205845, 0.020553149715332047, 0.04243781244648354, 0.057975965818124156, 0.04709189771009343, 0.08644279651343822, 0.05645114496084196, 0.06680451386741229, 0.023640911527244107, 0.026338827829541903, 0.03999966309805002, 0.020034418175263063, 0.0374433299127434, 0.012593056091905704, 0.025837505801713893, 0.06555030973894255, 0.06616704378809247, 0.015667270104001676, 0.01071814593992063, 0.04732608389375465, 0.05945032063339438, 0.01286371098831296, 0.030874707203890597, 0.05687008605205587, 0.030611951303269182, 0.11267135731343712, 0.07000407789434705, 0.05321846503232207, 0.08534848237676279, 0.08935038013649838, 0.015830646069454293, 0.0333619146341724, 0.02740414477219539, 0.02374256625106292, 0.015718355309218168, 0.11912826262414455, 0.07982595371348516, 0.019452523506645645, 0.03607163405311959, 0.02048178988375834, 0.037093080314142365, 0.05063029498394046, 0.029015884269028902, 0.044221996529293914, 0.018060822738334537, 0.03632461226412228, 0.037902369030884335, 0.027598041242786815, 0.04256829133789454, 0.03564280331400888, 0.07188066148332187, 0.04828771390020847, 0.05802869477442332, 0.03821937380624669, 0.06329343441341605, 0.07593887764960527, 0.07811183176402535, 0.12929324646081242, 0.10218457145882504, 0.010173874341749718, 0.044076752715877125, 0.08914709104491131, 0.060143444154943736, 0.2853409929999283, 0.08550252339669637, 0.09205409112785544, 0.1928067026393754, 0.2487833175276007, 1.974372753075191, 24.991581201553345, 59.20475251334054, 78.42566544669015, 72.04382147107805, 57.42401606695992, 47.62752158301217, 28.036629234041484, 23.768953595842632, 62.117451259068076, 74.81337342943463, 84.8468987601144, 56.111862659454346, 36.254428727286204, 18.498025826045446, 6.864928339208875, 2.7354467255728583, 1.3019002548285892, 0.4041861029607909, 0.057692134619823525, 0.11176433241260902, 0.10661420412361622, 0.4981709654842104, 0.2876724393240043, 0.098475088365376, 0.09985680279455014, 0.8223033440964562, 0.1014178404584527, 0.6286852764231818, 0.23721926233598165, 0.46088139499936787, 1.3606619302715575, 0.6090769171714783, 0.3315049601452691, 0.7592928994979177, 1.1712976800543922, 1.5856254931007112, 3.148640896592821, 2.9037787786551883, 3.137293185506548, 4.017121859959193, 1.828458411352975, 1.9966310901301247, 1.3445337499891008, 0.4363632377769266, 0.17525773788137095, 0.36009872438652174, 0.21242696339530603, 0.19040091601865633, 0.17259581786181244, 0.05181546835228801, 1.844750199999128, 0.8633597610252244, 0.26106542561735424, 0.07658438836889607, 0.5048267426235336, 0.4236863851547241, 0.3598233477345535, 0.29086407806192127, 0.5166071419204984, 2.277233873094831, 3.5034741078104292, 1.4283289164304733, 11.705291441508702, 33.79986987795149, 56.62181874683925, 69.10672065189907, 59.207983425685335, 42.133320399693076, 29.565078326633998, 40.329950196402415, 46.401234013693674, 59.67203276497977, 62.84852681841169, 61.188699449811665, 23.750660726002284, 2.124735461814063, 0.14899205443050179, 0.1284787601658276, 0.21025540706302437, 0.06818984488823585, 0.042502805923244784, 0.18811862277133123, 0.09974251714135919, 0.13848985226026603, 0.045153482617544274, 0.036746762825974395, 0.08366553911140986, 0.05306152666785887, 0.047718314453959465, 0.059415566069739204, 0.021978512605918304, 0.057995738328567574, 0.05856468994170427, 0.037798722806785784, 0.01817328143598778, 0.02907349189211215, 0.018462915805035403, 0.016992226775203432, 0.049660631122865846, 0.01597323002559798, 0.017856838148353354, 0.03951187784384404, 0.015457397526396173, 0.07104387852762427, 0.05088929519323366, 0.03332528052851558, 0.02832885059927191, 0.08803416469267436, 0.021722954265507202, 0.07992199356002466, 0.04079686032075967, 0.02716165331990591, 0.05813118748899017, 0.08664305933884212, 0.09274021895336253, 0.02789734473585018, 0.033130398485809565, 0.02718183464769806, 0.003417287042663832, 0.05882512525256191, 0.03723949460046632, 0.09645239583083562, 0.09355433883943728, 0.12433152699044772, 0.16580066962965898, 0.09914938932550804, 0.14631118971322263, 0.10349040531686374, 0.12050053184585911, 0.10840493267668144, 0.13720166709806236, 0.09935000498912164, 0.1357230714389256, 0.1228974839406354, 0.15155494904943875, 0.1509473616523402, 0.15626725261764868, 0.09937015747917549, 0.16476840073508875, 0.1308865145381008, 0.16287258746368544, 0.07991619208561522, 0.18888696868504795, 0.25173057509320124, 0.1199604586831161, 0.2368681611759322, 0.29560551792383194, 0.1683822918151106, 0.11041716220123426, 0.14125324040651321, 0.08260471746325493, 0.12857646920851298, 0.13499712039317402, 0.13069706756089414, 0.14206183701753616, 0.147189661860466, 0.1500636783561536, 0.124882416001388, 0.2297241645199912, 0.2583141289651394, 0.07951356976159982, 0.22070382854768208, 0.15057460165449552, 0.11644952850682394, 0.2506058354462896, 0.15267240123025008, 0.08918141813150474, 0.25521911361387795, 0.3388695349650723, 0.15322808069842203, 0.44124546008450644, 0.2379891010267394, 0.26778270517076763, 0.21901351639202662, 0.5481234107698713, 1.6119508062090193, 28.408574989863805, 68.58094351632255, 93.5748575755528, 82.97139930725098, 80.76142747061593, 69.95255960736955, 60.65192331586565, 27.365601743970597, 54.710212979997905, 69.72119849068778, 85.85996695927211, 85.62842518942696, 56.35358354023525, 37.50444786889212, 21.076724665505544, 11.828630651746478, 3.8826833367347717, 0.7114940157958439, 0.22126746044627257, 0.2960783211248261, 0.3527720389621598, 0.5406631082296371, 1.0462664748941148, 0.21835913722004208, 0.2027010867106063, 1.1226241375718797, 1.245770426733153, 1.4895492770842143, 1.0510743026222502, 0.6910754314490727, 3.49966236948967, 2.032338099820273, 0.800141087600163, 2.383188907589231, 5.538704829556601, 6.22886244739805, 8.379648225648062, 6.9875258292470654, 6.015263966151646, 11.386856368609838, 12.997880458831787, 8.712910754340035, 2.9448395924908772, 1.179153487086296, 0.32871124148368835, 0.9104574194976262, 0.21488887843276772, 0.44700861083609716, 0.32412437189902576, 1.2574438346283776, 3.331903977053506, 3.6261137213025774, 1.1531920858791895, 0.9482950291463307, 1.0447265803813934, 0.5083200580307415, 0.5099959852440017, 0.2583220271127564, 0.8255774112684386, 3.80987012386322, 10.925689663205828, 26.47436499595642, 42.134366103581016, 63.5051246370588, 87.95327854156494, 66.14374474116734, 46.09493310110909, 39.23643922805786, 52.46053566251482, 68.15770789555141, 66.13348225184849, 67.41957991463798, 71.12727069854736, 73.01258100782121, 26.37766170501709, 2.265377857855388, 0.15137406518416746, 0.24833491444587708, 0.339119235851935, 0.2207465898245573, 0.09897856813456331, 0.31699299599443165, 0.22355778754821845, 0.19299666530319623, 0.2378061951271125, 0.13292349023478373, 0.209377952718309, 0.14444908606154577, 0.12631970244858945, 0.14759223668703012, 0.23216729770813668, 0.17774749999599798, 0.16325130499899387, 0.1033124052254217, 0.10335605538317136, 0.17159157246351242, 0.14884640010339872, 0.15733773660446915, 0.11426906979509763, 0.1619257325572627, 0.19053289107978344, 0.14367365624223435, 0.11638718470931053, 0.18328893264489515, 0.18028380961290427, 0.10942190739193133, 0.1925228985824755, 0.21023262185709818, 0.13202137792749064, 0.1496582943946123, 0.09625542390027217, 0.11632748719836984, 0.1002319919477616, 0.1981573040996279, 0.16750797230218137, 0.11064233404717275, 0.1739906415875469, 0.1700504972998585, 0.25437466321246965, 0.2922825148063046, 0.12823576320494923, 0.2587369919887611], [0.05676446529105306, 0.02455745797072138, 0.028991874307394028, 0.043811231785054715, 0.024072761747187803, 0.05683787599472063, 0.02341336480874036, 0.01876702162969325, 0.025218474911525846, 0.050092942746622224, 0.030342131853103638, 0.023450563794800212, 0.12044656117047582, 0.0595171291913305, 0.006140031577420554, 0.08048749142991644, 0.022543985030746887, 0.04038917612550514, 0.01955264643765986, 0.08004461162324462, 0.02581529226154089, 0.12028414702841214, 0.017297766005088176, 0.07083763780870608, 0.02393581472071154, 0.02345905396422105, 0.061668824803616316, 0.060354353194790225, 0.003502470116862761, 0.0792271669155785, 0.03186683396675757, 0.024796607638044015, 0.02398918828527842, 0.0715241998966251, 0.06673260272613593, 0.035959492570587566, 0.06790342168616396, 0.0026667399506550282, 0.060258611903658936, 0.03171536120186959, 0.04769964795559645, 0.05278410762548447, 0.07621921439255987, 0.05947400829089539, 0.05618535600868719, 0.059347624358321936, 0.09406599495559931, 0.14340035590742314, 0.10560996551066637, 0.11989090884370462, 0.09909326090876545, 0.030004723529730524, 0.2775149058018412, 0.04938634012692741, 0.4232944633279528, 1.4120698060308183, 12.531880412782941, 42.641838209969656, 70.08808422088623, 58.56273896353585, 61.25572177342006, 56.3432411466326, 35.99324941635132, 27.791880675724574, 19.4764016696385, 40.45465299061367, 42.95244353158133, 62.758290563310894, 77.37067181723458, 61.84038489205496, 51.5478515625, 36.78428098133632, 27.501861129488262, 19.174794265202113, 10.843369143349783, 5.766949244907924, 1.5915491580963135, 0.5629042919192995, 0.3232308769864695, 0.0650648722159011, 0.3083801067301205, 0.1906856293124812, 0.5138767712882587, 0.43152216183287756, 0.1289518212101289, 0.15105318597384862, 0.0640073957453881, 0.10793809379850115, 0.35643325107438223, 0.6455247242535863, 1.690426800932203, 2.5361404716968536, 3.0373722272259847, 1.443720587662288, 1.2476777072463716, 0.5099814374532018, 0.7594755068421364, 0.30694858783057755, 0.5507582979542869, 0.4236194001776831, 0.5720248882259641, 0.4741504458444459, 0.2275221012532711, 0.47302999453885214, 0.4937470257282257, 0.5178342046482223, 0.05033319503335016, 0.22057809600872652, 0.8270819133945874, 4.421670734882355, 6.347701396260943, 16.83941786629813, 24.883762529918126, 33.79597193854195, 38.56256818771362, 35.80251441683088, 58.64321994781494, 62.40634346008301, 22.151744740349905, 24.152978794915335, 48.82070793424334, 54.551325048719136, 56.94221060616629, 49.153276511601035, 51.663028376443044, 35.601360593523296, 13.707377518926348, 0.7909576318093708, 0.22954847823296273, 0.2175922298005649, 0.1635683165597064, 0.03065124187352402, 0.0734975832913603, 0.025612997223756144, 0.03724560820098434, 0.03617318360401051, 0.022181216461051787, 0.11401373706758022, 0.016408639161714485, 0.07793655938335828, 0.08332764902817351, 0.06923076510429382, 0.06925986747124366, 0.032932958366083245, 0.05639323199700032, 0.06236135121434927, 0.041422588351581774, 0.06395139625029904, 0.057989997922309806, 0.1136476674250194, 0.0333277300399329, 0.07655489245163542, 0.17467868966715677, 0.058387680511389456, 0.01918510946312121, 0.024148737313225865, 0.02732441181849156, 0.016563731910926954, 0.04589835800496595, 0.06664618450616087, 0.04697480631460037, 0.013266799805153693, 0.06322803720831871, 0.03502702260656016, 0.030930442070322375, 0.04549042953710471, 0.07254443836531468, 0.044027192518115044, 0.08671057357319764, 0.06101572806281703, 0.06034635326692036, 0.04205688288701432, 0.06268468672143561, 0.069604888957526, 0.0033868899460815427, 0.11375649765666042, 0.06831394215779645, 0.07542096544057131, 0.03370501247367688, 0.08370916891310896, 0.014832468470558524, 0.04137595942510026, 0.07581801020673343, 0.021413114819941775, 0.040955746080726385, 0.012984302776333476, 0.03595508548564144, 0.04431122049157109, 0.03361918457916804, 0.08223879031304802, 0.025302189169451594, 0.0751580059794443, 0.02322657938514437, 0.053756187071225474, 0.09540923644921609, 0.0181941565658365, 0.047655529608683925, 0.14833287123058522, 0.05005560974989619, 0.12506798175828798, 0.08043733412133795, 0.018391766319317476, 0.0353970515009548, 0.0383170116027551, 0.04835726034694484, 0.04871418673012938, 0.010508202964306941, 0.025852414912411144, 0.08745249054793801, 0.08926848095974751, 0.09005573764443398, 0.03888184450832861, 0.09219579638114997, 0.060369525237807205, 0.07744805488203253, 0.04147176856973341, 0.04314623014735324, 0.030478921120188067, 0.03979618401665773, 0.06900692318699189, 0.09313506526606423, 0.022798876710502163, 0.2223552877881697, 0.1290046383759805, 0.004556519561447203, 0.20271992284272397, 0.10332617948630027, 0.028107963701976196, 0.14460554266614573, 0.22324377511228832, 0.31022493488022257, 3.5650323246206557, 22.56023802076067, 59.361274582999094, 83.48934582301548, 66.87726606641496, 62.08512823922293, 29.376775196620397, 26.151754924229213, 27.808420862470353, 36.47314759663173, 79.32740265982491, 71.06034564971924, 78.61517756325858, 72.45195170811245, 48.852176325661794, 35.44851412091936, 18.48479298182896, 10.461095758846827, 6.738809849534716, 4.437578201293945, 3.3519625578607832, 0.43998278783900396, 0.058003426130328856, 0.26105608897549765, 0.27803735062479973, 0.33626947019781384, 0.4959579642329897, 0.4943468506847109, 0.4115561603435448, 0.17594434746674129, 0.03879455776352968, 0.17340715575431073, 0.1428405780877386, 0.2348592903997217, 0.23203121072479657, 0.3212691508233547, 1.068969713790076, 1.2824588694742747, 0.11266935563513211, 0.2013560945966414, 0.6092092586415154, 0.30703101626464296, 0.35316974190729006, 0.5712769255042076, 0.5887128870402063, 0.4907123457108225, 0.3514860251120159, 0.1929917119975601, 0.2270635472876685, 0.39664874598383904, 0.14106304704078607, 0.05557837250775524, 0.14287928172520228, 0.6831337490252086, 1.0285079649516513, 0.9106843216078622, 2.3414291484015326, 10.832916447094508, 19.249741009303502, 32.229924406324116, 37.84084490367344, 58.90161650521414, 65.18155820029122, 55.0092009135655, 35.250667640141074, 37.063549927302766, 36.33135223388672, 47.276564598083496, 56.81804282324654, 64.00619397844586, 52.47396305629185, 23.58458662033081, 4.448182455130985, 0.019901762882779752, 0.143772138814841, 0.08012921815471989, 0.08623944635369948, 0.0695307454360383, 0.007679893435644252, 0.1083357221047793, 0.0695312407666019, 0.048851186343069584, 0.18165933580270835, 0.04033550400553005, 0.04546443825321538, 0.027102089819631407, 0.06791822053492069, 0.03250909111063395, 0.02340040309354663, 0.019802354109872664, 0.037589001203221936, 0.010925475707543748, 0.016705282797504748, 0.05032868956082633, 0.06766640940415007, 0.05692215343671186, 0.046476018615067005, 0.050149926117488315, 0.018757181175585304, 0.01796279987320304, 0.0646642040727394, 0.027803664494838034, 0.0119506725708821, 0.030452139343002012, 0.009458295551926961, 0.0649770222870367, 0.0161392912933869, 0.09450950579983847, 0.030534225116883005, 0.020924065794263567, 0.08366075543952839, 0.011643854302487202, 0.014686035524521555, 0.06736476666160993, 0.013124208215491047, 0.0076532227685675025, 0.048895437004310746, 0.049331168444561105, 0.0607998182198831, 0.020803013450599143, 0.12581171042152814, 0.22851542223777088, 0.14430702797004155, 0.24462658486195973, 0.20998659863003663, 0.13464592423822197, 0.14607541236494268, 0.23655994342906134, 0.16132114428494657, 0.23371101915836334, 0.15278099397463457, 0.09679214510002307, 0.2525112432028566, 0.17506782950035163, 0.21536804629223688, 0.12617480808070727, 0.1759433296642133, 0.07234018575400114, 0.12742237613669463, 0.12042890568929059, 0.23712380602955818, 0.16395139028983458, 0.3539629222026893, 0.19487122685781547, 0.3726327589579991, 0.18458319748086588, 0.18998159494783196, 0.16793441799070152, 0.17706409309591564, 0.22963809913822583, 0.1704561391047069, 0.169753936784608, 0.14287135643618448, 0.23688789297427448, 0.26504440924951006, 0.22094473562070302, 0.11715573418353285, 0.2408677451312542, 0.18309694794671877, 0.15335869868951185, 0.10384855645575694, 0.13765640769686016, 0.08631696219422988, 0.13131070749035903, 0.11424732953310013, 0.23727156381521905, 0.16080612263509206, 0.5277647003531456, 0.297468612236636, 0.28909405161227497, 0.3961626977792808, 0.3540195934474468, 0.16051390474396093, 0.4993766950709479, 0.3786922666643347, 0.4972604257719857, 3.774245406900133, 27.62075001852853, 79.86759730747768, 98.85605130876813, 81.1106925691877, 80.79051957811627, 74.96952724456787, 56.65681682314192, 41.77670063291277, 29.00489718573434, 58.65973581586565, 59.28688716888428, 84.2714489528111, 98.315828868321, 85.00803443363735, 75.60433551243374, 60.57092121669224, 50.19604478563581, 44.184529372623985, 30.035488741738455, 19.612192051751272, 10.724368214607239, 2.328488997050694, 0.563685801412378, 0.40423954437885967, 1.0949153729847498, 1.4251302480697632, 1.1682944297790527, 0.9311156081301826, 0.2954858514879431, 0.20560376452548162, 0.6590251283986228, 0.5339645562427384, 2.513595087187631, 3.443758032151631, 3.596849645887102, 7.2528462665421625, 9.880852563040596, 7.476566536085946, 4.81725252526147, 3.8290054627827237, 3.090762402330126, 0.397869593330792, 1.4196697239364897, 1.6888563994850432, 1.4742244822638375, 0.5960340627602169, 1.4075307867356708, 1.3192871447120393, 1.877689655338015, 0.7888307773641178, 0.1255767201738698, 0.45335193617003305, 1.5441028411899294, 6.070034444332123, 10.817341191428048, 24.58037117549351, 42.29943445750645, 50.458297593253, 62.7879524230957, 57.77579641342163, 75.98120580400739, 73.02356610979352, 30.645297391074045, 32.34582730701992, 60.7969947542463, 77.6056182043893, 69.50859751020158, 64.10296154022217, 73.9040835244315, 68.51085703713554, 27.78289144379752, 3.636309551341193, 0.23721342693482125, 0.29295187603150097, 0.5916323246700423, 0.21982986187296255, 0.13660815251725061, 0.13125305915517466, 0.2557782807520458, 0.1843584802533899, 0.10283972416073084, 0.3400401435792446, 0.16068146218146595, 0.17301877588033676, 0.20038288539009436, 0.14634146594575473, 0.12280894869140216, 0.11191057706517832, 0.12153556916330542, 0.22089742815920285, 0.16002978357885564, 0.1415410613907235, 0.22312162523823126, 0.2111190871468612, 0.19936501500861986, 0.23020614151443752, 0.24898286110588483, 0.24881018751433917, 0.2079755701124668, 0.09098696588937726, 0.13896623812615871, 0.1523583209408181, 0.12104128354362079, 0.09186800968434129, 0.19042418976979597, 0.1075956371745893, 0.162117459412132, 0.16079713883144514, 0.1307093897568328, 0.21081453348909104, 0.1363475407872881, 0.23759804772479193, 0.20362401647227152, 0.1410083978303841, 0.12094086036086082, 0.14211094938218594, 0.3272095892046179, 0.22638178244233131, 0.24828448572329112, 0.31186218559741974], [0.08379224195544209, 0.11534183365958077, 0.0595148221722671, 0.08215554085161005, 0.05533122630523784, 0.056287441602242846, 0.07469009501593453, 0.18435826312218392, 0.13873818250639097, 0.011473556431675596, 0.05020675003262503, 0.03560151785079922, 0.08289719319769315, 0.008403607860340603, 0.04020698947299804, 0.0391120273353798, 0.06860939666096653, 0.11817986065787928, 0.07396503285105739, 0.008846371467890484, 0.03339173285556691, 0.027907504101416895, 0.014461888266461236, 0.11778293124267034, 0.05256829956280334, 0.09064098766871861, 0.07603955189032213, 0.11891721109194414, 0.09202536874051605, 0.047561454121023417, 0.0040014104867753175, 0.06334422275956188, 0.0826232550399644, 0.014522651077381201, 0.0495624063935663, 0.04360076718564544, 0.09741714370570012, 0.0984271362956081, 0.1675490236708096, 0.022657001823452965, 0.05370514766712274, 0.10026733683688299, 0.021285679158089415, 0.04407075446631227, 0.17690138039844377, 0.04000973595040185, 0.05969842017761298, 0.09536327248705284, 0.09394548035093717, 0.02199491110098149, 0.054197906583015404, 0.09075162280350924, 0.1683850602379867, 0.07872243864195687, 0.4327886067330837, 0.08480996984456267, 0.221522684608187, 3.006174598421369, 28.364726645605906, 61.3937268938337, 65.19598266056606, 60.46655232565743, 60.53991140638079, 48.48262596130371, 39.69416570663452, 24.479116814477102, 31.417586190359934, 26.475382907049998, 28.558711665017263, 52.65173619134085, 56.9697254725865, 50.0982141494751, 51.864366327013286, 50.89993551799229, 37.68275601523263, 24.87343576976231, 18.041758469172887, 8.848569989204407, 5.830258624894278, 4.275120632989066, 4.996413562979017, 4.716784179210663, 5.239412043775831, 3.8993989654949734, 2.643730721303395, 0.8165542525904519, 0.34400954629693714, 0.13397150114178658, 0.10135160865528242, 0.05977077915200165, 0.0959542832736458, 0.33751933170216425, 0.33121777698397636, 0.1353275126644543, 0.19644113975976193, 0.0533124760591558, 0.19098997940974577, 0.1870075488196952, 0.22358534964067595, 0.15976733980434282, 0.2136802040040493, 0.7826416151864188, 0.9156371929815837, 2.040569543838501, 6.608871587685176, 11.47499600478581, 22.214829172406876, 37.58926452909197, 38.66000625065395, 38.831779616219656, 40.401374203818186, 40.80947664805821, 35.174942697797505, 27.69470838138035, 38.042690072740825, 22.11527364594596, 34.35442992619106, 62.548371587480815, 41.01539693559919, 76.40410791124616, 61.072768756321494, 52.56777763366699, 56.17446592875889, 45.59409652437483, 14.612336090632848, 1.6827342765671867, 0.10831190552562475, 0.09666895028203726, 0.18780455605259963, 0.17353757018489496, 0.11943038712654795, 0.1244913355580398, 0.10858833390687193, 0.06774394560073103, 0.0630951529102666, 0.015938814729452133, 0.017355711199343204, 0.10834632082177059, 0.12030219605990819, 0.05147430094491158, 0.12332665733993053, 0.021303280356473157, 0.04755700971665127, 0.077043681937669, 0.04410681860255344, 0.15306957491806575, 0.09973746205547027, 0.10689549081559692, 0.12947839152600082, 0.05304944535185184, 0.01994883794603603, 0.12870164534875325, 0.08635417305465255, 0.16423112313662255, 0.16153623988585813, 0.1002980609025274, 0.20978177604930742, 0.045395275178764544, 0.11528290967856135, 0.09219609493655817, 0.057265783926205974, 0.14205625945968287, 0.1414557695388794, 0.026278441605557288, 0.1047192458063364, 0.07383501875613417, 0.02000306307205132, 0.10494384089750902, 0.12359752851937499, 0.08219645651323454, 0.01695843573127474, 0.09115969376372439, 0.09262505120464734, 0.05910557734646967, 0.1615617528025593, 0.036173879102404626, 0.15839110793811934, 0.06080822526876416, 0.12598722028945172, 0.051865371210234504, 0.062104749626346996, 0.0780529145683561, 0.16079783093716415, 0.07848562313509838, 0.1576115254844938, 0.03757485714075821, 0.07652632612735033, 0.10631079719002758, 0.02330153714865446, 0.06085287287299122, 0.06104160738842828, 0.07162227534822055, 0.03552611903952701, 0.10586715742413487, 0.03491126453237874, 0.018977652470182096, 0.04304393081526671, 0.05982536729425192, 0.03986139462462493, 0.06541938640709434, 0.06350785826465913, 0.1330397775662797, 0.11130839080682822, 0.056472132048968754, 0.10207181929477624, 0.13855244033038616, 0.03280462025265608, 0.1362055776906865, 0.10385813737022025, 0.08779141878975288, 0.11961801562990461, 0.055013410680528195, 0.08566465255405221, 0.11545512186629431, 0.31367395552141325, 0.12796802685729095, 0.124065012005823, 0.10896673253072159, 0.08663369555558477, 0.09605259621249777, 0.0625517006431307, 0.036529156645493846, 0.11272035432713372, 0.06748710652547223, 0.1488984301686287, 0.0630385223776102, 0.16849437222949096, 0.017330644419416785, 0.09672277846506663, 0.15995789957898005, 0.4326621549470084, 0.0678017499989697, 0.2020409128495625, 6.004580242293222, 44.59546668188912, 79.41178158351353, 77.4159323828561, 69.47743483952114, 58.685284342084614, 42.91387755530221, 21.861040796552384, 21.589427028383525, 31.103086403438024, 48.54845666885376, 69.15051514761788, 80.52430629730225, 75.85558932168144, 66.3870359148298, 56.7186210496085, 41.54936252321516, 34.63890307290213, 24.542621612548828, 12.147883006504603, 7.463440520422799, 6.16476184129715, 2.2182595176356177, 1.3823608287743159, 1.2502953324999129, 1.2202382939202445, 1.5785752428429467, 1.7967746257781982, 0.36659746138112886, 0.20653681802962506, 0.08177686402840273, 0.02911168323563678, 0.057584749667772224, 0.10527329679046359, 0.14403802954724856, 0.39429667219519615, 0.1891083882323333, 0.12257101360176291, 0.1297590878925153, 0.21393569957997116, 0.33641185398612705, 0.14815299159714154, 0.26094299075858934, 0.08965459452675921, 0.17898555499102387, 0.5288352657641683, 1.7075373913560594, 3.8204761147499084, 3.3292619245392934, 1.2156568254743303, 5.844989240169525, 12.081552028656006, 22.21215237889971, 29.841571467263357, 39.24927602495466, 53.2954728943961, 46.99582263401577, 59.62526444026402, 46.73949663979666, 65.13164234161377, 72.29209450313023, 25.23143822806222, 39.17127207347325, 53.7400290625436, 56.81189366749355, 68.24591527666364, 61.85892963409424, 30.299398694719585, 3.509585265602384, 0.02170200619314398, 0.19879725761711597, 0.1999537255614996, 0.15349880260016235, 0.08627768180200032, 0.12987728869276388, 0.15117567511541502, 0.08623650151171855, 0.10944670784686293, 0.060488730269883356, 0.06902307232043572, 0.20756212515490396, 0.040951406849282126, 0.06548242231032678, 0.07937977622662272, 0.07066002448222466, 0.07753615586885385, 0.1360472754708358, 0.10238208621740341, 0.09421899103160415, 0.044458537229469845, 0.0841952171176672, 0.0540953969050731, 0.09305760370833532, 0.05279851292393037, 0.17790781067950384, 0.24804935976862907, 0.09701102014098849, 0.15197455510497093, 0.04816283631537642, 0.09779358814869608, 0.04481549753940531, 0.08519680944404431, 0.06420127355626651, 0.06133432061012302, 0.08507109726113932, 0.07553186520401921, 0.0609451061380761, 0.046642381830939224, 0.07106403101767812, 0.09848767518997192, 0.1933917219617537, 0.10647672614348785, 0.06684080192020961, 0.09175090132547276, 0.08283428621611424, 0.04127092559688857, 0.029376827579523836, 0.10876919063074247, 0.10953280037002903, 0.17832282983830997, 0.26240870782307213, 0.29866413665669306, 0.20161034166812897, 0.19998501959655965, 0.2013126276433468, 0.2579682932368347, 0.23284732550382614, 0.15413338212030275, 0.12594920875770704, 0.1880627657685961, 0.1846644724053996, 0.30946568133575575, 0.2629716476159436, 0.27515943933810505, 0.22702911842082227, 0.22614900421883377, 0.2606943483863558, 0.29272500106266564, 0.12098955203379903, 0.11042095521198851, 0.14103750698268414, 0.0987205755497728, 0.18387750749077114, 0.11865247386906828, 0.1965150729353939, 0.1965903631810631, 0.20899501469518456, 0.22965826519898005, 0.26045992810811314, 0.27810409132923397, 0.3881879842707089, 0.31104902923107147, 0.18428179222558225, 0.33275512020502773, 0.3544117324054241, 0.3447929828294686, 0.36178966079439434, 0.5176599025726318, 0.2830677106976509, 0.19719971476921014, 0.31428998389414375, 0.15956436283886433, 0.25108922379357473, 0.23130574822425842, 0.25929645768233706, 0.27448003579463276, 0.2823487621332918, 0.2414958785687174, 0.1799769625067711, 0.5418150435600961, 0.45210690583501545, 0.29670797448073116, 0.2377369845552104, 0.9172195366450718, 0.3028080585811819, 0.42358047940901344, 6.266899926321847, 56.14387648446219, 99.39611394064767, 97.54368945530483, 86.42048508780343, 82.56669453212193, 68.87564441135952, 62.05283996037075, 37.68661573954991, 42.360040119716096, 38.895758628845215, 48.82518604823521, 75.57740429469517, 79.97770541054862, 78.15244143349784, 83.17355019705636, 80.56468227931431, 76.66051033564976, 70.30552809579032, 67.39282240186418, 55.30952637536185, 43.47655657359532, 36.73284346716744, 25.657487869262695, 18.773772035326274, 11.290664638791766, 5.7797995039394925, 3.2261921295097897, 1.3046817055770328, 0.40100982625569614, 0.3378787381308419, 0.20063019783369132, 0.15509918172444614, 0.13453533660088265, 0.3875759728252888, 0.47565451370818274, 0.22063946271581308, 0.2382829338312149, 0.2762820619557585, 0.3325544095465115, 0.6630243052329335, 0.5125033078449113, 0.5006807308111871, 0.8906704698290143, 1.1192308110850198, 4.467871478625706, 8.466358269963946, 16.098003387451172, 24.417180572237285, 36.73631756646292, 49.9992926461356, 57.054368427821565, 60.89775058201381, 64.76506928035191, 63.11518478393555, 55.65553624289376, 43.85283974238804, 55.94954579217093, 34.493369579315186, 47.443873746054514, 73.59888390132359, 67.24269267490932, 104.6536351612636, 79.2294955934797, 64.92413439069475, 73.88205078669957, 77.97212873186383, 39.4849728175572, 4.3041350075176785, 0.1533637469900506, 0.2681249039513724, 0.3555433116853237, 0.4388665163091251, 0.21033646485635213, 0.18543488106557302, 0.49882740740265163, 0.26394130129899296, 0.2523643539420196, 0.19419674947857857, 0.23377963261944906, 0.4703123260821615, 0.1770161206700972, 0.31618727637188776, 0.4037418525133814, 0.10774663157228913, 0.24879973807505198, 0.25801307654806543, 0.18941550675247396, 0.3055881251181875, 0.2954514090503965, 0.25413017347455025, 0.22995847623263085, 0.20136910889829907, 0.12708580919674464, 0.2981899763856615, 0.34215283021330833, 0.3971269503235817, 0.31515910582883017, 0.33169229009321755, 0.376754886337689, 0.25095150832618984, 0.3675119365964617, 0.2449553215077945, 0.16795408193554195, 0.32354493013450075, 0.24296626395412854, 0.13078648490565165, 0.1773482092789241, 0.20173154159315995, 0.2823832317122391, 0.31970686465501785, 0.23575349098869733, 0.2915787382849625, 0.2879746588213103, 0.21871312893927097, 0.2651782434965883, 0.1940430612968547, 0.3204716821866376, 0.22324559358613832], [0.2384248562157154, 0.1930534993963582, 0.22475237558994973, 0.15682515768068178, 0.11461642544184412, 0.18047268662069524, 0.1300201474555901, 0.18058392565165246, 0.08348091651818582, 0.08885075444621698, 0.1622268392571381, 0.09838973544538021, 0.1746034129921879, 0.1081908413075975, 0.14918044289307936, 0.2805660606494972, 0.1561659744807652, 0.08462861100477831, 0.07653754909655877, 0.02783120283856988, 0.05442911060526967, 0.13654177822172642, 0.041640873067080975, 0.05666942289099097, 0.08239017147570848, 0.23991394202624047, 0.14017681245292934, 0.14392958608056816, 0.3223580638212817, 0.20160936457770212, 0.1941121904445546, 0.239225798951728, 0.1580603356872286, 0.2408471176666873, 0.16477548464068345, 0.13971862489623682, 0.13413103829537118, 0.18047917341547354, 0.25215316670281546, 0.2093416510948113, 0.25488280451723505, 0.09152710690562214, 0.11773909788046565, 0.34210807404347826, 0.09675635237778936, 0.13405824505857059, 0.15935897028871945, 0.019108653833557452, 0.11438923834690026, 0.20316979156008788, 0.19147514551877975, 0.22607995649533613, 0.20629163618598664, 0.07388738130352326, 0.17616972965853556, 0.05920818541198969, 0.421414351356881, 0.2654672179903303, 0.23587242460676602, 2.527986977781568, 37.49920197895595, 58.17825692040579, 65.57161617279053, 56.501576696123394, 56.53279495239258, 65.66964830671037, 53.468792234148296, 40.447708266122, 34.23058523450579, 16.231136083602905, 22.889579159872874, 18.573450258799962, 21.17986719948905, 28.05138373374939, 19.13472400392805, 19.043471574783325, 25.027866431644984, 26.523749317441666, 23.25547477177211, 21.939477273396083, 28.228123324257986, 31.578298023768834, 33.59206315449306, 37.84359639031546, 36.264607838221956, 33.52195930480957, 28.557367188589915, 23.001123803002493, 15.755299125398908, 12.046474916594368, 9.33832940033504, 7.701020274843488, 9.155770693506513, 8.699629272733416, 10.490785411426, 11.001472796712603, 8.513831836836678, 9.365802577563695, 10.0965941292899, 12.284501961299352, 15.66120662008013, 18.927447080612183, 19.804328850337438, 28.435254335403442, 45.56103004728045, 57.68553931372506, 63.30341843196324, 70.37296731131417, 65.66611862182617, 32.517843859536306, 33.099435874394004, 25.434518439429148, 19.14429862158639, 21.892444917133876, 22.39097990308489, 30.427103110722133, 36.73792954853603, 57.46320390701294, 68.04512623378209, 59.13802201407296, 62.74021829877581, 61.43873732430594, 29.26803241457258, 3.7199269958904813, 0.15491922066680022, 0.2756914107927254, 0.1280715713011367, 0.16895876159625395, 0.03658743262557047, 0.09491303736077887, 0.3671317941376141, 0.19653176489685262, 0.015023696602189114, 0.1892251776797431, 0.21907571091183595, 0.11715847546500818, 0.2370728887617588, 0.21527757043285028, 0.09251327613102538, 0.1280152800359896, 0.10061700628804308, 0.24769245034882, 0.0837774770334363, 0.1989776257957731, 0.11842653527855873, 0.17866475720490727, 0.2811094586338316, 0.15395438458238328, 0.13339737909180777, 0.03919532768694418, 0.058151380691145144, 0.21234662484909805, 0.21374361988689217, 0.2712490148842335, 0.3747017750782626, 0.24932348568524632, 0.26068693878395216, 0.2396667381482465, 0.3192748006965433, 0.2813525641603129, 0.25217425557119505, 0.20229184867015906, 0.1492728322212185, 0.16696610780698912, 0.11484487461192266, 0.15616091260952608, 0.12897099660975592, 0.1970598687018667, 0.16893043954457554, 0.12379789991038186, 0.2803979739546776, 0.20423114246555737, 0.1002374134425606, 0.10049246797072035, 0.1817590125969478, 0.260412294949804, 0.09779643121042422, 0.17407164509807313, 0.13665924620415482, 0.016001862507047396, 0.019729067238845995, 0.03139980170609696, 0.09549290660236563, 0.09348979658846344, 0.1087020088785461, 0.16715921887329646, 0.050254145703677616, 0.04494426312989422, 0.07649990397372416, 0.02837139304860362, 0.07217509818396398, 0.024965009851647273, 0.10319431299077612, 0.034513324099992, 0.07157288478421313, 0.0522686042157667, 0.06769522678639207, 0.13736865456615174, 0.05871335696429014, 0.010891034118165928, 0.05985417789114373, 0.0983101704290935, 0.07870727338429008, 0.07857225848627941, 0.12043892086616584, 0.11713468602725438, 0.06755602532731635, 0.13381933287850448, 0.11106338538229465, 0.0711031010640519, 0.14981019124388695, 0.2060429123895509, 0.02899266140801566, 0.16121981186526163, 0.05707101723445313, 0.12635323564921105, 0.0706438957048314, 0.0633130847875561, 0.06068079639226198, 0.19144340365060739, 0.12497138551303319, 0.10087392678750412, 0.1922519595495292, 0.05581967652376209, 0.16199539096227714, 0.06888068853212254, 0.04321103702698435, 0.13947245239147119, 0.16952328916106904, 0.19839525275996753, 0.1311053963644164, 0.15356658824852534, 0.2163626564932721, 0.3934033672724451, 0.2502163292041847, 9.155317323548452, 53.821986539023264, 74.47485719408307, 76.94187763759068, 65.27866622379848, 50.63413565499442, 37.95902681350708, 29.777995450156077, 19.940131391797745, 16.03961593764169, 27.729841947555542, 34.195903301239014, 35.350784233638215, 35.01829556056431, 36.2791747365679, 36.11174052102225, 29.209577219826834, 22.83375906944275, 16.23281581061227, 14.784350906099592, 9.792801516396658, 11.51088171345847, 12.511141777038574, 14.306102922984532, 11.78263705117362, 12.178613151822772, 4.51440921000072, 2.2581465201718465, 3.0154884415013448, 0.9318522257464272, 1.649272837809154, 1.303526133298874, 1.7806401486907686, 2.8807389863899777, 2.099198660680226, 1.4581650240080697, 2.587111370904105, 3.401004897696631, 3.5981055327824185, 1.935748802764075, 3.4849237203598022, 2.681972303560802, 1.9447944888046809, 4.536299509661538, 12.150847281728472, 22.88112493923732, 39.06352635792324, 54.81216042382376, 72.25412954602922, 70.53764656611851, 63.36887046269008, 58.15293768474034, 49.79731546129499, 47.55826888765608, 40.24790586744036, 39.80511106763567, 24.94197801181248, 31.944530623299734, 49.98468753269741, 49.420702253069194, 63.863359860011506, 69.956679889134, 72.46930830819267, 47.34337500163487, 8.545042276382446, 0.02533074701204896, 0.34372122319681303, 0.07581273120428834, 0.26085206706609043, 0.051011652020471435, 0.06223919455494199, 0.18769223136561258, 0.24240310703005108, 0.09999925443636519, 0.11782558395394258, 0.06752305531076022, 0.13192190469375678, 0.27196568357092993, 0.14522778641964706, 0.04077871968703611, 0.1252936896468912, 0.17314921745232173, 0.020676800848117897, 0.0714820832280176, 0.10022263494985444, 0.09396947334919657, 0.05135638852204595, 0.10626878908702306, 0.10810284888637917, 0.03277358066822801, 0.12191132828593254, 0.14963873901537486, 0.03703069580452783, 0.15325777339083807, 0.15325026879353182, 0.31990510544606615, 0.2102244794368744, 0.17671881376632623, 0.07521256019494363, 0.023339689476415515, 0.12419211518551622, 0.10948646321360554, 0.06702779260064874, 0.04926153378827231, 0.09436820088220493, 0.12616197019815445, 0.05496661551296711, 0.0718103584700397, 0.12825598354850495, 0.10420214105397463, 0.11614910034196717, 0.06626773159950972, 0.045709192619792054, 0.08314766082912683, 0.1289616735385997, 0.1069389781249421, 0.24039249920419284, 0.45189482292958666, 0.3145766242274216, 0.3375757315329143, 0.2116286533751658, 0.5188461446336338, 0.3803567944892815, 0.34966581421239035, 0.6349889753120286, 0.353924815676042, 0.6662638485431671, 0.4379481870148863, 0.5623905594859804, 0.5849165107522691, 0.34705475717782974, 0.3856515660881996, 0.5225987147007669, 0.3438478378312928, 0.3262590973504952, 0.217410450269069, 0.20360192337206431, 0.19919947960547038, 0.3635374041540282, 0.23544855735131673, 0.34307485073804855, 0.4846144329224314, 0.4201526290604046, 0.465078595493521, 0.5133579362715993, 0.7111199530107635, 0.5541106409260205, 0.4776825191719191, 0.6456772589257785, 0.4361575331006731, 0.5345634041087968, 0.4475694607411112, 0.677560208099229, 0.6074365994759968, 0.3237360327371529, 0.5349609713469232, 0.6086474859288761, 0.43781644265566555, 0.42849912547639435, 0.24011077146445, 0.5621206111141613, 0.3372993506491184, 0.3850411559854235, 0.345752051366227, 0.4168032445013523, 0.4616694727114269, 0.46883648527520044, 0.41280851885676384, 0.43619306119424955, 0.7332454057676452, 0.6957054287195206, 0.37870209185140474, 0.3440067507326603, 0.9301931262016296, 0.7111865037253925, 0.2540463608290468, 11.372317263058253, 66.22125884464809, 97.3019129889352, 101.84791782924107, 82.4939329964774, 79.63885566166469, 89.38632365635463, 79.68278217315674, 60.673810141427175, 52.78884499413626, 33.50574220929827, 38.42586932863508, 35.30718081338065, 33.23557192938668, 46.466988291059224, 45.72888462884085, 48.05101081303188, 54.07583550044468, 52.05991642815726, 58.97022301810128, 48.96297230039324, 58.91100352151053, 60.79770347050258, 61.32102789197649, 62.32862091064453, 58.559341294424875, 49.57532399041312, 43.229287556239534, 33.90286649976458, 24.709645884377615, 19.271733794893535, 14.709350313459124, 12.911437051636831, 14.130428143909999, 15.95628445489066, 17.625568321772985, 22.94012209347316, 23.656583854130336, 32.69763197217669, 36.989093031202046, 44.358727659497944, 49.420778683253694, 58.02502134868077, 68.31086008889335, 76.32002776009696, 95.2004303250994, 97.81002085549491, 96.06200000217983, 93.68620245797294, 86.7013521194458, 49.31973450524466, 45.125701086861746, 37.78394610541207, 30.757708821977886, 33.371193817683626, 33.88484634671892, 48.44634941646031, 60.181703976222444, 70.2424384525844, 91.77614961351667, 67.33604172297886, 76.63062613351005, 87.42213739667619, 54.10004997253418, 9.235915558678762, 0.1694140721644674, 0.4101115864302431, 0.4329148956707546, 0.47891994991472786, 0.16093328009758676, 0.32988678983279635, 0.7937769176704543, 0.5640861913561821, 0.35749966385109083, 0.7181905593190874, 0.658101669379643, 0.5451360110725675, 0.5638576607619012, 0.7203444465994835, 0.33338789482201847, 0.34727994937981876, 0.662814665053572, 0.5612790648426328, 0.5167534883533205, 0.5482821336814335, 0.3653468127761568, 0.6165551330362047, 0.48477896409375326, 0.44492146426013535, 0.3341295064560005, 0.39934871824724333, 0.37791705397622927, 0.47811336176736013, 0.3944023336683001, 0.43590226822665756, 0.7412352370364326, 0.5998594260641507, 0.6759674421378544, 0.5953045561909676, 0.521639917578016, 0.740741317825658, 0.31485455217106, 0.4831319696136883, 0.4338076849068914, 0.4260360433587006, 0.3791760078498295, 0.5548208771007401, 0.25133105367422104, 0.6455048567482403, 0.32847638694303377, 0.46804455348423546, 0.45466297439166475, 0.47197576825107845, 0.4538981297186443, 0.44791885199291365, 0.4579182597143309, 0.6039746595280511], [0.07998268851744277, 0.10120872953640563, 0.08162869233638048, 0.05726016565625157, 0.06826482300779649, 0.08365749847143888, 0.11075107606926135, 0.09991024421261889, 0.045607327550117455, 0.198658483635102, 0.20359207104359353, 0.3633113977100168, 0.22927874699234962, 0.17238556700093405, 0.25486670966659275, 0.13420550072831766, 0.13232188751654966, 0.08829888155949966, 0.06265456655195781, 0.0657832779522453, 0.15087344204740866, 0.1031446238713605, 0.17761211868907723, 0.11739654626165118, 0.10539999284914561, 0.19087901179279598, 0.13873493910900184, 0.2463779923106943, 0.24378286727837153, 0.2031881527176925, 0.13695193906979902, 0.2750707412404673, 0.30275833553501535, 0.2772785313427448, 0.16470734615411076, 0.17069990959550652, 0.29781021390642437, 0.25349140060799463, 0.3222954757511616, 0.2868918254971504, 0.16329318418034486, 0.15272893676800386, 0.2602833461548601, 0.1630944005612816, 0.23231831246188708, 0.10417464681501899, 0.02870976658804076, 0.0631148304258074, 0.383553182972329, 0.0772767790726253, 0.17815591022372246, 0.12223344242998532, 0.24904930325491087, 0.13439371277179035, 0.05793509765395096, 0.31615750225526945, 0.22891290805169515, 0.10170448757708073, 0.07242988129811627, 0.24048445426992007, 0.37662276199885775, 7.534714273044041, 28.260343858173915, 56.25228227887835, 75.57370785304478, 65.11065878186906, 59.16805212838309, 65.41410745893205, 72.95547376360211, 65.60855279650006, 57.24998801095145, 59.819292885916575, 50.42359134129116, 36.12726279667446, 29.44719171524048, 12.360087071146284, 12.431850671768188, 5.337937934058053, 6.190892279148102, 10.851834654808044, 14.29054503781455, 10.499177098274231, 20.91457281793867, 28.768528154918126, 38.521125657217844, 33.94229057856968, 55.0788357598441, 56.62343767711094, 55.07759550639561, 56.78982966286795, 55.8827805519104, 56.20894636426653, 45.21472488130842, 52.807987281254356, 51.91222204480852, 41.25912931987217, 32.303318228040425, 21.15518719809396, 33.15343032564436, 32.45045675550188, 32.62293883732387, 36.34731224605015, 23.01131681033543, 37.28699357169015, 34.277951104300364, 26.866809674671718, 22.449450731277466, 39.19185611179897, 31.941591535295757, 19.248078652790614, 37.3595883505685, 27.988323620387487, 45.97117178780692, 61.64909403664725, 59.275033542088096, 71.12571430206299, 63.92874935695103, 66.05780247279576, 67.14718273707798, 53.70815767560686, 27.8393611907959, 7.038225531578064, 0.027220309279592972, 0.3278253733047417, 0.24929477008325712, 0.13862190874559538, 0.11981149310512201, 0.10265606508723327, 0.06531540091548647, 0.23294033908418246, 0.11901418731680938, 0.0521423458121717, 0.3567099847963878, 0.16373287487242902, 0.14734838477202825, 0.3052517074559416, 0.16673753650060721, 0.10062976274639368, 0.32636264179434094, 0.11262767322893653, 0.12871425252939972, 0.24652621150016785, 0.20363297313451767, 0.20773175890956605, 0.1898337285965681, 0.19260410565350736, 0.2589665539562702, 0.1546740795352629, 0.09876801193292652, 0.11243860623134033, 0.05921527610293456, 0.1620386814964669, 0.1717442021306072, 0.36472443331565174, 0.3190522954932281, 0.4511811397969723, 0.1819502916187048, 0.34888349047728945, 0.4048486516944, 0.2542600179357188, 0.1701141031725066, 0.1579581754548209, 0.03326626155259354, 0.0018195433908009104, 0.05501796365050333, 0.15761756444615976, 0.14244584712599004, 0.1500460635870695, 0.2578660787216255, 0.11669036772634302, 0.18030675766723497, 0.32582825475505417, 0.18390520529023238, 0.14350071123668126, 0.23716967499681882, 0.1689918198223625, 0.17305684169488295, 0.388908642743315, 0.26129208345498356, 0.152415806427598, 0.19839523918926716, 0.18695114898894513, 0.22231616345899446, 0.055991423915007284, 0.20363784501595156, 0.21350092148142202, 0.1822804803294795, 0.2134223606969629, 0.2624125619019781, 0.19446578861347266, 0.21945963959608758, 0.1502204742282629, 0.16626541183463164, 0.10558661712067467, 0.04484457955030458, 0.07433273776301316, 0.08176482681717191, 0.06454975557114397, 0.06658293825707265, 0.03793620757226433, 0.13273265904613904, 0.18259089652981075, 0.11722281415547643, 0.24434998684695788, 0.2825997658073902, 0.2293951836015497, 0.3843472860753536, 0.4448595547250339, 0.3780350105038711, 0.2774043045938015, 0.2961069553026131, 0.28667464000838144, 0.29201107365744455, 0.36839959610785755, 0.3477388561836311, 0.35552713541047914, 0.16944371057408197, 0.06860826350748539, 0.17484180948563985, 0.17963962203689984, 0.16008774404014858, 0.14785116565014633, 0.1793145359094654, 0.1940312140754291, 0.21618686164064066, 0.19159080859805855, 0.31474704508270535, 0.24951127703700746, 0.08855082161192383, 0.28890737305794445, 0.4528815214123045, 0.1172913054802588, 0.18216888846031257, 0.3444988786109856, 0.36440674321992056, 0.3566022605768272, 0.530400890324797, 19.184923001698085, 47.41333988734654, 78.35166713169643, 94.02985341208321, 77.56767409188407, 62.234743799482075, 53.24034588677542, 52.81975405556815, 33.307833194732666, 31.942345414842876, 30.085015501294816, 25.170886414391653, 31.848009722573416, 25.847455092838832, 19.252669675009592, 21.331798246928624, 12.810705542564392, 13.65872015271868, 16.728566305977957, 13.127994162695748, 12.908323390143257, 22.6983699457986, 34.98998512540545, 40.47182893753052, 41.32718692507063, 47.61426442010062, 46.9508330481393, 45.85401126316616, 43.446516036987305, 44.15510375159127, 38.28167683737618, 38.53985105242048, 38.8125331061227, 35.16793196541922, 31.480345794132777, 23.842076437813894, 18.28870960644313, 13.19426086970738, 24.12672676358904, 22.738732031413488, 28.489518029349192, 23.885771921702794, 31.119178431374685, 45.097043241773335, 50.853754316057476, 49.424409117017476, 67.92864663260323, 62.69429765428816, 36.75706141335623, 47.19725438526699, 25.838005542755127, 24.436491353171213, 26.998985256467545, 26.109893764768326, 33.49646636417934, 48.858023234776084, 68.15874317714146, 77.4308362688337, 74.75989314488002, 47.60329321452549, 16.650548458099365, 0.504917177770819, 0.08693271915295295, 0.21366208711905138, 0.34057919893945965, 0.11624809860118798, 0.06628120051962988, 0.28822159128529684, 0.38035386321800096, 0.0797818625079734, 0.1540306926305805, 0.27346850293023245, 0.1071198619902134, 0.3299594202211925, 0.15271799878350326, 0.11086992147777762, 0.21180835658950464, 0.20845297378088745, 0.24590157930340084, 0.1377026702144316, 0.12047873730106012, 0.12768228219023772, 0.041858533530363014, 0.16018184327653476, 0.1592309307307005, 0.11627693633948054, 0.19913820789328643, 0.18817336697663578, 0.1940397500459637, 0.3062223925122193, 0.2052619457244873, 0.28246267459222246, 0.36533079934971674, 0.4061003045311996, 0.431475967168808, 0.2576645809624876, 0.1249104802097593, 0.3721046415822846, 0.16160706537110464, 0.34485133684107233, 0.29671180141823633, 0.16489414684474468, 0.14107942687613623, 0.18141042201646737, 0.3280719257891178, 0.2809877837342875, 0.3283934156809534, 0.12557786011270114, 0.14260108236755642, 0.24991055418338093, 0.20137968047388963, 0.09787207429430314, 0.12066737003624439, 0.276434026658535, 0.23606122019035475, 0.16541231689708574, 0.3950581784759249, 0.4065323956310749, 0.24393276923469134, 0.2304449858410018, 0.4563141486474446, 0.47656668190445217, 0.5135845126850265, 0.3438520718898092, 0.5684011312467712, 0.40544209842170986, 0.4270455949008465, 0.3897203877568245, 0.3590236263615744, 0.3040662796369621, 0.3096996673515865, 0.178198210096785, 0.32317510140793665, 0.17048841023019382, 0.21489218968365872, 0.3854105504495757, 0.223190130133714, 0.2828271564628397, 0.14746308433158056, 0.40983895105975016, 0.36805959578071323, 0.5531305106622832, 0.5578114252005304, 0.5067818462848663, 0.46027749883277075, 0.6534548987235341, 0.6919734318341527, 0.6198791403855596, 0.5449652916618756, 0.5461251522813524, 0.42868384984987123, 0.479169813649995, 0.4677160882524082, 0.5273391231894493, 0.5034858488610813, 0.29155949503183365, 0.3102776977632727, 0.6324625451649938, 0.2249069187257971, 0.4238084671752793, 0.47652027010917664, 0.24985920265316963, 0.28691584563681055, 0.6875950896314212, 0.303943111960377, 0.43384883127042223, 0.3948437071272305, 0.4907524064183235, 0.3445441233260291, 0.6839997225574085, 0.8197449413793427, 0.5217190619025911, 0.4662489326936858, 0.7225741669535637, 0.3356650040618011, 0.3194022024316447, 18.209651265825542, 52.42158753531319, 93.5146097455706, 109.43453080313546, 97.49247428349086, 85.64447552817208, 86.62547084263393, 99.88170964377267, 85.47180584498814, 77.9912918635777, 81.79261657169887, 74.72686835697719, 60.54680401938302, 53.45588248116629, 27.678345373698644, 28.134011711393082, 19.989630358559744, 26.24192864554269, 34.11488035746983, 30.27458667755127, 17.132048198154994, 31.557158129555837, 41.134218079703196, 56.5625193459647, 49.96497201919556, 74.81236594063895, 81.1107759475708, 82.12675544193813, 81.61686188834054, 84.04370089939663, 82.94105652400425, 70.93387453896659, 77.485171181815, 82.83232416425432, 68.79552473340715, 62.208347593035015, 50.54869018282209, 58.179142815726145, 58.29451765332903, 61.30429662976946, 67.04051399230957, 45.341004916599815, 59.587883131844656, 52.50547661100115, 43.919420855385916, 32.47992753982544, 53.22881882531302, 47.229452337537495, 33.77737855911255, 67.71316909790039, 45.75165734972273, 84.67746693747384, 105.37511525835309, 83.72309712001255, 86.57811886923653, 74.03947612217495, 79.3162646974836, 79.19009235927037, 81.69100611550468, 50.279173033578054, 15.17161396571568, 0.30952140263148714, 0.36700580375535147, 0.4881960664476667, 0.3451566775994641, 0.3237858643489224, 0.37065702783209936, 0.8463413427983011, 0.530456964458738, 0.25364450524960247, 0.25229082788739887, 0.9777728702340807, 0.3545131598200117, 0.3498069223548685, 0.6365262642502785, 0.352795733405011, 0.4076725244522095, 0.5439537316560745, 0.3743229354066508, 0.17604536776031765, 0.6001031015600476, 0.4846858148063932, 0.6746668804969106, 0.493434411074434, 0.43413544446229935, 0.3435902659382139, 0.35124028686966213, 0.5099877885409764, 0.48955992183515, 0.4481475182941982, 0.41156348852174623, 0.3366738770689283, 0.4711391074316842, 0.5056490185005325, 0.6217792012861797, 0.4056705747331892, 0.4182042293250561, 0.5644879926528249, 0.41396289691329, 0.5190261464033807, 0.4093304026339735, 0.2646185878132071, 0.21393185907176562, 0.2342720590531826, 0.44594184522117886, 0.5105923361011914, 0.35902848467230797, 0.36947089433670044, 0.30478596101914135, 0.3958589312221323, 0.41450347219194683, 0.2662993733372007, 0.2278969239975725, 0.3796985340969903, 0.3646334824817521], [0.2779165713914803, 0.28334316877382143, 0.10183204537523644, 0.12712903187743255, 0.1599606815725565, 0.11677438393235207, 0.14190501400402614, 0.0336788006659065, 0.3066633588501385, 0.22783194748418673, 0.34270635194012095, 0.3669934815594128, 0.28835984958069666, 0.2748320054795061, 0.3932778111525944, 0.2840282991528511, 0.1486167838530881, 0.17335399932094983, 0.1317561250180006, 0.19036586289959295, 0.21525656298867293, 0.10492474692208426, 0.0762049855132188, 0.1842490461255823, 0.23032735501016888, 0.19925611013812677, 0.20895675889083318, 0.2380178709115301, 0.3611485537673746, 0.36744704150727814, 0.3397967666387558, 0.4234792691256319, 0.32139394698398455, 0.4073102410350527, 0.409619431410517, 0.4324481450021267, 0.5536792012197631, 0.7789292686751911, 0.4076409318617412, 0.29602295266730444, 0.34379431498902185, 0.15033697869096482, 0.08687830064445734, 0.3705239806856428, 0.20360100056443894, 0.14164455155176775, 0.10975859646818467, 0.11984471417963505, 0.23263464548758098, 0.20860221077288899, 0.1642198051725115, 0.2499563688678401, 0.21241702964263304, 0.22411505478833402, 0.23594198801687785, 0.1514544715838773, 0.25775257338370594, 0.4072461873292923, 0.321358744587217, 0.30461811859692844, 0.4291871599853039, 0.31189024980579105, 0.48172593648944584, 4.281306266784668, 18.53272339275905, 45.03384242738996, 57.68271139689854, 68.3985185623169, 63.88739367893764, 61.3672889981951, 58.14672599520002, 53.00823436464582, 55.89180973597935, 50.99574770246233, 49.7813207081386, 53.11135605403355, 38.56871039526803, 42.52549409866333, 41.937308243342805, 33.520607880183626, 52.14090115683419, 36.20069483348301, 35.05654191970825, 27.939651489257812, 29.07278629711696, 22.127302714756556, 26.843924045562744, 43.73817014694214, 33.07260887963431, 23.843733583177837, 25.537996223994664, 48.65081058229719, 63.51684624808175, 70.05080018724713, 56.30823612213135, 41.47801147188459, 24.200033732822963, 15.285979577473231, 53.19410215105329, 88.53669098445347, 31.78362771442958, 25.89686894416809, 33.56207125527518, 38.58883237838745, 34.87614236559187, 42.878125599452424, 51.0494190624782, 44.41713421685355, 57.83483873094831, 73.77055304391044, 54.66319104603359, 68.94450800759452, 66.10024206978935, 64.17767551967076, 71.51089463915143, 73.6655935559954, 73.768114226205, 47.52280180794852, 28.92517008100237, 2.565675961119788, 0.04564413128952895, 0.2921641782990524, 0.23562429792114667, 0.010953471214244408, 0.04422565383304443, 0.21784689756376402, 0.16653986567897455, 0.05241084551172597, 0.18588066500212463, 0.21704695905957902, 0.1900554738406624, 0.3023538743810994, 0.1945528175149645, 0.2526832382593836, 0.22472630627453327, 0.24245600562010491, 0.2883347437850067, 0.2007726901876075, 0.2872729721878256, 0.2777410479528563, 0.3162919336131641, 0.28542325858558926, 0.40733816953642027, 0.17496560141444206, 0.34991627505847384, 0.31642237518514904, 0.27504970665488926, 0.28964534774422646, 0.05097112990915775, 0.17589760997465678, 0.31541817049895016, 0.23981151037982532, 0.34064507111907005, 0.466444405061858, 0.50899495610169, 0.3344726823270321, 0.2830965891480446, 0.4535957745143345, 0.27282465462173733, 0.3339682051113674, 0.22370532820267336, 0.2925768904387951, 0.1780435312539339, 0.1720991845109633, 0.22855575435927936, 0.18545031095189707, 0.2657421332384859, 0.24892635270953178, 0.22922549556408608, 0.15736877279622213, 0.23722409350531443, 0.2961348838039807, 0.06931803827839238, 0.027331056372661675, 0.09199028169470173, 0.1328679724995579, 0.39099657641989843, 0.48068240391356604, 0.20403425874454634, 0.14134252204426698, 0.19732220391077654, 0.1787861335490431, 0.15668125397392682, 0.16984856527830872, 0.43585338656391415, 0.2774548147405897, 0.4249753031347479, 0.310165386646986, 0.3120450914970466, 0.3606366669493062, 0.2722510482583727, 0.4076868008290018, 0.13141999234046253, 0.06432341664497342, 0.1413753902805703, 0.08492586362574782, 0.10419876873493195, 0.13378366907792433, 0.03536012562523995, 0.14992890773074968, 0.3596571066549846, 0.45807453989982605, 0.3006667377693312, 0.4610193818807602, 0.5187730799828256, 0.4610046169587544, 0.36179574046816143, 0.43752016712512287, 0.44846254853265627, 0.3944180756807327, 0.38238564133644104, 0.41511540221316473, 0.3193358417068209, 0.468171086694513, 0.4310890936425754, 0.1936533243528434, 0.30391537344881464, 0.17235569788941316, 0.11257936832095895, 0.23631900921463966, 0.25942423939704895, 0.23977685081107275, 0.32584806797759874, 0.2693557121923992, 0.2946270432855402, 0.3318008285548006, 0.30321203118988443, 0.2711126836282866, 0.3544299714267254, 0.26133561826178003, 0.23626315221190453, 0.4441849823508944, 0.5249326580337116, 0.3418688768787043, 0.13399364852479526, 0.45813729081835064, 0.46918112678187235, 0.31899236728038105, 0.8296214256967817, 12.144052812031337, 38.17222533907209, 71.2458347593035, 82.55236039842877, 85.38579409463065, 74.71021352495465, 74.88899067470005, 67.82210295540946, 61.8815529687064, 57.45640509469168, 42.32502119881766, 34.63082231794085, 15.968525443758283, 13.661208476339068, 14.700769288199288, 21.09199854305812, 20.391104221343994, 25.29504724911281, 13.656019909041268, 22.466558933258057, 30.313764095306396, 36.88387993403843, 34.06436695371355, 51.21030112675258, 59.86241340637207, 54.864608900887625, 50.91910212380545, 52.58530099051339, 66.35726288386753, 63.07093865530831, 68.44458511897496, 62.23074858529227, 47.25571305411202, 32.94806241989136, 22.429047346115112, 35.79155363355364, 62.392655508858816, 36.05818380628313, 31.77419900894165, 29.78045163835798, 41.74225493839809, 38.575071471078054, 35.91823319026402, 27.46471084867205, 35.96765225274222, 32.99768992832729, 22.336129086358206, 34.88330248423985, 34.38379648753575, 41.75651611600603, 53.29641784940447, 65.15294551849365, 74.56101485661098, 80.40852846418107, 63.442653383527485, 43.97009754180908, 7.502957531384059, 0.26307711909924236, 0.14474807573216303, 0.10736320500395127, 0.13618005120328494, 0.10008747077413968, 0.10110516473650932, 0.29989651909896303, 0.28578529773013933, 0.20238301663526467, 0.12989788901593002, 0.40041456105453627, 0.3745193305824484, 0.11876310221850872, 0.35763499087521006, 0.342316845698016, 0.1879048299576555, 0.39016797659652575, 0.2426321804523468, 0.21677435083048685, 0.3209302904350417, 0.25038452446460724, 0.34765707914318356, 0.14777097638164247, 0.23866809744920048, 0.15021461168570177, 0.2305387050977775, 0.21343916122402462, 0.2158694022468158, 0.3436117076448032, 0.3168253707034247, 0.4367714173027447, 0.21194867763136113, 0.3705080486834049, 0.37416537957532064, 0.33190136030316353, 0.26651539174573763, 0.4327136150428227, 0.2346527986228466, 0.23395149196897233, 0.2301410021526473, 0.23651621863245964, 0.3905591384640762, 0.34925589763692444, 0.34761188871094156, 0.34513770576034275, 0.2580224946141243, 0.27048512016023907, 0.21311754919588566, 0.2126483286597899, 0.09429071218307529, 0.050611740443855524, 0.1780901737511158, 0.1465527888919626, 0.29828782113535063, 0.2284741944500378, 0.2537330947816372, 0.526914197419371, 0.5947543999978474, 0.22553738632372447, 0.3598988008286272, 0.6630905845335552, 0.38924864307045937, 0.3338907164122377, 0.3315545474844319, 0.5423494577407837, 0.36864685426865307, 0.6866037771105766, 0.4295943081378937, 0.43672858817236765, 0.3978408234460013, 0.37378404289484024, 0.6204286994678634, 0.29654124485594885, 0.44648269191384315, 0.2720934110028403, 0.31403428475771633, 0.46625930070877075, 0.3269071254347052, 0.1945444851049355, 0.45914190262556076, 0.5242777903165136, 0.6817297786474228, 0.45361919754317825, 0.6899804930601801, 0.6594381119523729, 0.5845875569752285, 0.5423158024038587, 0.6870884682450975, 0.5597726085356304, 0.6570261099508831, 0.533379713339465, 0.5461877403514726, 0.6784210790480886, 0.8170617967844009, 0.4917989788310868, 0.5391894387347358, 0.5198206837688173, 0.2309172733553818, 0.19749434824500764, 0.6103151621563094, 0.46635402419737404, 0.36599804354565485, 0.41904971109969275, 0.5738475961344582, 0.40077548740165575, 0.6376999127013343, 0.6004784128495625, 0.37212114355393816, 0.42105991180453983, 0.38574229979089325, 0.4543583664510931, 0.36647225809948786, 0.7201678646462304, 0.5388398032103265, 0.21419138514569827, 0.43210551195910996, 0.6874948292970657, 0.37219703091042383, 0.40682028446878704, 11.288780808448792, 38.10923991884504, 79.85543101174491, 95.60091059548515, 100.81024605887276, 89.84059688023159, 88.88592829023088, 86.42228467123849, 82.81922680991036, 82.10347202845982, 75.16381972176688, 78.55741718837193, 95.85014942714146, 79.80200631277901, 75.43548733847481, 69.67601435525077, 65.24473122188023, 86.85610239846366, 67.95314598083496, 58.02210310527256, 46.191492216927664, 45.87330641065325, 34.952895641326904, 41.658928666796, 61.82179151262556, 44.38754183905465, 35.11582395008632, 37.25406605856759, 60.81178746904646, 73.90226309640067, 80.53124059949602, 70.49987615857805, 53.08865976333618, 38.54178612572806, 22.869516236441477, 73.61810956682477, 113.75214835575649, 52.437943594796316, 41.28403513772147, 57.457624503544395, 60.17328970772879, 52.54473393304007, 66.65260996137346, 75.74235452924455, 68.98969214303153, 82.03860364641461, 108.8328445979527, 76.52256080082485, 87.60318660736084, 75.90581090109688, 74.18073994772774, 80.61637687683105, 83.4303834097726, 88.61426067352295, 67.15774399893624, 42.925039836338584, 5.036248019763401, 0.32445924250142916, 0.3598282331866877, 0.3440022181187357, 0.11414193947400365, 0.40077385891761097, 0.5884139516523906, 0.5294528411967414, 0.2665684531841959, 0.3489604906312057, 0.2603001466819218, 0.6680220684834889, 0.6390832013317517, 0.1951085241245372, 0.5235229336789676, 0.5119163479123796, 0.31544105069977896, 0.515297352203301, 0.572941507611956, 0.381129863006728, 0.6573315049920763, 0.5230889426810401, 0.41968281141349245, 0.5924247450062207, 0.2888357469013759, 0.5910582297614643, 0.3997608332761696, 0.66904709062406, 0.7427443532007081, 0.43680398698363987, 0.39954809897712296, 0.7936428391507694, 0.3674536097262587, 0.48833063351256506, 0.5490149515015739, 0.4432297950344426, 0.32565905526280403, 0.3633147089609078, 0.5549686891692025, 0.28073555869715555, 0.32554321576442036, 0.39475500902959276, 0.60612610408238, 0.4762820771762303, 0.617816122514861, 0.48137081840208595, 0.36059191077947617, 0.2647059016994068, 0.3377601573509829, 0.25239624508789604, 0.21769490571958677, 0.3043431762073721, 0.41981650995356695, 0.2974598727055958, 0.34148661739059855, 0.3567263239196369, 0.38031524100473946], [0.233137168522392, 0.15603262877890042, 0.15822441902543816, 0.11308544009391751, 0.17201094781713827, 0.25397815448897226, 0.2887268013187817, 0.2765337441648756, 0.3374858663550445, 0.32872494789106504, 0.4357649598802839, 0.5157682012234415, 0.20150159964604036, 0.21253468761486666, 0.26973479613661766, 0.3901166793491159, 0.15510300866195134, 0.21167738576020512, 0.11938618735543319, 0.27969368174672127, 0.22047049392546925, 0.22989721809114727, 0.17643545754253864, 0.1605973102684532, 0.17896503609205994, 0.21535073007856095, 0.09666674504322664, 0.2940105263675962, 0.2986146578831332, 0.2377602175942489, 0.31982457691005295, 0.5686065916504178, 0.5277084633708, 0.35692703457815306, 0.3075529454009873, 0.3559339850076607, 0.4998365789651871, 0.47137051501444405, 0.22096058619873865, 0.23135291997875485, 0.23485532775521278, 0.3028729536703655, 0.1719989241766078, 0.20180676398532732, 0.17804993662450994, 0.1665384407554354, 0.06624882761389017, 0.13100711735231535, 0.10818659367838077, 0.09956077153661422, 0.1785535453153508, 0.34268898144364357, 0.2356841175683907, 0.13594116616461957, 0.4056446546954768, 0.3439894345189844, 0.26224906210388454, 0.25018620224935667, 0.34801170868533, 0.5279928509678159, 0.37240669823118616, 0.17389160261622497, 0.4494658846940313, 0.4005584104784897, 0.3288557694426605, 0.7022614883525031, 7.895056537219456, 24.00653682436262, 44.27656173706055, 49.89849860327584, 48.33385460717337, 55.24619354520525, 58.866778237479075, 53.51680081231253, 40.25873116084507, 36.64998967306954, 37.84334972926548, 38.19743340356009, 40.115278652736116, 48.01983424595424, 44.61958735329764, 44.179780278887065, 53.17182275227138, 56.71411861692156, 64.47829627990723, 65.54348986489433, 46.0303669657026, 34.37862007958548, 56.301166330065044, 59.43703079223633, 44.18934794834682, 30.946515696389334, 37.45146785463606, 58.81509753635952, 92.131911277771, 72.96982179369245, 63.8690504346575, 65.12748731885637, 81.37842750549316, 40.965012073516846, 45.91629491533552, 58.4125953401838, 67.6296170098441, 72.02030181884766, 67.67891447884696, 85.50390652247837, 74.9169363294329, 80.7044244493757, 74.86777087620327, 73.12246676853725, 71.1011107308524, 72.67017378125871, 63.373629978724885, 65.26791736057827, 58.14780644008091, 35.2983774457659, 17.281860045024327, 0.9031716904469899, 0.22279700051460946, 0.11328309734484979, 0.18383577758712427, 0.08680950397891657, 0.08970153557934932, 0.14047211089304515, 0.2648947244243962, 0.05078073976827519, 0.2735868937202862, 0.1026446046307683, 0.38685186739478794, 0.2509638305221285, 0.2142225977565561, 0.2083703689277172, 0.4741906151175499, 0.3597677621458258, 0.21576399861701898, 0.32809228183967726, 0.3190538154116699, 0.19296546626303876, 0.4679858737758228, 0.24380420041935785, 0.22315662407449313, 0.5411098556859153, 0.26389285389866146, 0.28153829276561737, 0.3026723244360515, 0.2634295773293291, 0.17030540933566435, 0.2322340655539717, 0.1954281141183206, 0.10834879747458867, 0.1655294048999037, 0.4823311354432787, 0.3885046701346125, 0.2944922590894358, 0.4897218474320003, 0.46341911596911295, 0.44595289177128244, 0.4033936826246125, 0.46231017261743546, 0.45641994582755224, 0.15715941760156835, 0.4001235238143376, 0.21552320010960102, 0.18442423029669694, 0.23778996456946644, 0.35241477670414106, 0.24585915729403496, 0.2834056482783386, 0.25620792912585394, 0.22437789211315767, 0.2842535727790424, 0.22543319048626081, 0.1396781299263239, 0.14298119768500328, 0.1701629576938493, 0.16089613709066594, 0.1409101595303842, 0.11296077285494123, 0.15586268289812974, 0.14424157648214272, 0.29700216012341635, 0.3124140516987869, 0.2584276614444596, 0.1744109397487981, 0.3044191992708615, 0.2394351405756814, 0.16526191282485211, 0.3259512053004333, 0.17484969406255654, 0.1066182821190783, 0.199147761666349, 0.16745401519749845, 0.08840359986892768, 0.1394659655966929, 0.12715131496744497, 0.17513771860727242, 0.09779236000031233, 0.09606252996517078, 0.104595847427845, 0.10805423185229301, 0.20186080251421246, 0.18910731614700385, 0.05126638763717242, 0.312165870730366, 0.23989722292338098, 0.21046350018254348, 0.2776862494647503, 0.4622202802981649, 0.37931478183184353, 0.24971027778727667, 0.41456128337553566, 0.3496943941073758, 0.3418196423777512, 0.2943456412426063, 0.23139713332057, 0.20621858510587895, 0.22072953145418847, 0.13984130402760847, 0.07208847640348331, 0.11789309818829809, 0.20322946192962782, 0.16666703671216965, 0.030085007793137004, 0.13744804316333362, 0.25368331745266914, 0.047775538704757176, 0.13492086662777833, 0.319532399731023, 0.20816767694694654, 0.16053682565689087, 0.3469783269933292, 0.2087317838200501, 0.19122012491737092, 0.30971163670931545, 0.4593081165637289, 0.17427862542016165, 0.2733454709606511, 0.1274738498032093, 0.2391392450247492, 0.19350739861173288, 0.2761504261621407, 2.0509164971964697, 15.063755341938563, 40.77298123495919, 63.160632950919016, 67.38599232264927, 69.29623971666608, 74.12035315377372, 72.64984335218156, 63.998856680733816, 57.16516440255301, 54.01359353746687, 45.98847280229841, 46.66619314466204, 51.009522506168906, 45.58921194076538, 43.73802770887102, 24.481083154678345, 30.062374796186173, 21.452818495886667, 23.368407317570277, 20.10232492855617, 27.255912269864762, 32.88137360981533, 37.691347462790354, 32.19831705093384, 28.016715696879796, 36.896212986537385, 47.29937205995832, 70.12750135149274, 67.96628502437046, 52.298983097076416, 30.30825764792306, 16.87034603527614, 59.536987577165874, 71.74853692735944, 35.043156215122764, 28.1027934551239, 31.999730587005615, 32.19123683656965, 36.45163944789341, 36.74732003893171, 40.56179421288626, 48.398643084934776, 64.95403943743024, 72.43797888074602, 73.91708360399518, 87.17558056967599, 81.68206378391811, 82.3546633039202, 74.95939677102226, 50.381596429007395, 27.15033265522548, 3.345218462603433, 0.4835044581975256, 0.1974247305520943, 0.05176088360271283, 0.11631057810570512, 0.12893259152770042, 0.130542714414852, 0.1512707243008273, 0.062019444203802516, 0.10675607222531523, 0.09780538108732019, 0.2731990973864283, 0.3418513706752232, 0.24867714036788258, 0.18429613645587647, 0.4949366876057216, 0.2572961093059608, 0.17325318258787903, 0.35310397829328266, 0.2521256724638598, 0.12822496092745236, 0.3721102327108383, 0.24511559147919926, 0.18570720430995735, 0.2749014331826142, 0.21396598938320363, 0.14498362237853663, 0.1688339790063245, 0.20752522642058985, 0.12000582553446293, 0.11525685393384524, 0.154863105820758, 0.22932046332529613, 0.2643030961709363, 0.3216721463416304, 0.3556033484637737, 0.2098699448896306, 0.26278494192021234, 0.4028486561562334, 0.21196640096604824, 0.2203448699521167, 0.24784471360700472, 0.2649890679333891, 0.10286939649709634, 0.23570417506354197, 0.07898668053426913, 0.08813859123204436, 0.3061498435480254, 0.2980083461318697, 0.11625033776674952, 0.24433218208806856, 0.2804001181253365, 0.21239755568759783, 0.16496084683707782, 0.1502232969339405, 0.08166141129497971, 0.044622579855578284, 0.025701875133173804, 0.15883010652448448, 0.28925147173660143, 0.2609948308340141, 0.25928367408258574, 0.2787892759910652, 0.5118140248315675, 0.5030047403914588, 0.6792967692017555, 0.46316056698560715, 0.4123341143131256, 0.47892776663814274, 0.4236743343727929, 0.5761396331446511, 0.2639408941779818, 0.24611377077443258, 0.28343010268041063, 0.3554576262831688, 0.21524761989712715, 0.21239575078444822, 0.2773230703813689, 0.35779308953455513, 0.4102665095457009, 0.29190353942768915, 0.3661144801548549, 0.2849966229072639, 0.21162452788225242, 0.2905526304883616, 0.20932514912315778, 0.44456973884786877, 0.41698058641382624, 0.3701301318194185, 0.41924358212522095, 0.6032019981316158, 0.6740872487425804, 0.2713192839707647, 0.5194807105830738, 0.660877203302724, 0.5726012630122048, 0.27697894456131117, 0.3157719043748719, 0.282502681016922, 0.26014850767595427, 0.22917555538671358, 0.3469572924077511, 0.17657710851303168, 0.37000606847660883, 0.23093266252960476, 0.1260599728141512, 0.178438682907394, 0.3965337207274777, 0.27820155609931263, 0.1726070408310209, 0.4372365123459271, 0.39005159427012714, 0.17418905879770005, 0.41334106028079987, 0.586120069026947, 0.39672067069581574, 0.3101079554430076, 0.5066917368343898, 0.5013224078076226, 0.19641893809395178, 0.14445131165640696, 0.4729498731238501, 0.43267835836325375, 0.2782740236393043, 1.506691785795348, 13.084268280438014, 35.92060252598354, 61.90213353293282, 71.92418738773891, 79.2785290309361, 93.78912612370083, 96.72986779894147, 92.69893986838204, 80.65924726213727, 72.12387861524309, 74.89052622658866, 76.23354353223527, 78.71498148781913, 78.48966530391148, 75.93499333517892, 79.655684198652, 98.51748643602643, 103.01932852608817, 115.07992131369454, 116.08348437717983, 83.34981209891183, 55.69260140827724, 90.33442619868687, 84.15845039912632, 70.04362269810268, 49.607608795166016, 55.5314553124564, 79.6164824622018, 112.07970305851528, 102.6730511529105, 97.91942719050816, 113.95325006757463, 108.13587079729352, 59.46469851902553, 78.16025815691266, 91.641236441476, 108.47458158220563, 108.85102803366524, 102.59577328818185, 112.43474905831474, 95.36532497406006, 99.35983044760567, 94.27793189457485, 92.98723452431815, 92.19796085357666, 101.56026240757534, 95.79379258837018, 96.06582845960344, 85.3166595186506, 53.56920065198626, 25.259936264583043, 2.8242820501327515, 0.3281006956739085, 0.26427744754723137, 0.15416901877948216, 0.19137701578438282, 0.3314015514084271, 0.2888111839337008, 0.42346618697047234, 0.11799893608050686, 0.4216376979436193, 0.27332793761576923, 0.43073820961373194, 0.45801173469849993, 0.32760856779558317, 0.29137194795267923, 0.6889967801315444, 0.4183993488550186, 0.25947705656290054, 0.6265684100134032, 0.32299200551850454, 0.23493056371808052, 0.550656789115497, 0.42861309221812655, 0.3117626580808844, 0.7020857749240739, 0.30078819553766933, 0.5090078211256436, 0.3168713482362883, 0.32942476176789826, 0.35546530729957987, 0.3194799082619803, 0.5214461822594915, 0.6818638028843063, 0.3671217518193381, 0.4802741972463471, 0.4416671560278961, 0.2965165190398693, 0.4514825721936566, 0.4723201926265444, 0.34353215619921684, 0.3529333403067929, 0.3003450036048889, 0.37618233848895344, 0.18244313874414989, 0.38539331566010204, 0.23958080847348484, 0.23839361646345683, 0.335313224366733, 0.40884226454155786, 0.2916794328817299, 0.3049255221017769, 0.2899498742605959, 0.36254283466509407, 0.2324785552918911, 0.20283745867865427, 0.1939206128673894, 0.20747451271329606, 0.17989427622939858, 0.3256598695048264], [0.16573325039020606, 0.2573617643543652, 0.10033571959606238, 0.10832791216671467, 0.16116396843322686, 0.12809643282421998, 0.12988005711563996, 0.3078581233109747, 0.26791176253131455, 0.47910651990345543, 0.6813582128712109, 0.7171125028814588, 0.32225188666156357, 0.497111473764692, 0.5090318684067044, 0.3737107068300247, 0.23153550018157276, 0.15328106071267808, 0.20074248180857726, 0.18246876022645406, 0.23425976399864468, 0.37803427768605097, 0.2512529135814735, 0.2565874473324844, 0.3025619403592178, 0.1962965846593891, 0.1970707116914647, 0.32726218923926353, 0.4499211816915444, 0.32078065989272936, 0.602441876062325, 0.46422749544892994, 0.5100592789905412, 0.3210431443793433, 0.4119519633906228, 0.2616837610091482, 0.32319952866860796, 0.3679951892367431, 0.41536950000694817, 0.46451003743069513, 0.2412845284811088, 0.3792592505259173, 0.121853964935456, 0.4758687679256712, 0.25728799402713776, 0.12072136785302844, 0.17820798100105353, 0.21654907720429556, 0.18624117065753254, 0.2251968974513667, 0.28607044528637615, 0.27966320195368355, 0.30936422677976744, 0.345069092299257, 0.4097762272826263, 0.27642873408538954, 0.31825078278779984, 0.45832407793828417, 0.3250562718936375, 0.47483500625405994, 0.5701123965638024, 0.6064219453505107, 0.22635616096002714, 0.35571829229593277, 0.276909842555012, 0.7350819557905197, 0.22979128520403588, 0.07537992764264345, 0.1157570970909936, 0.5058493763208389, 3.4316581785678864, 2.3200408560889105, 10.179015398025513, 23.040228264672415, 19.097167253494263, 24.881777082170757, 30.8309463092259, 24.20900559425354, 27.12644648551941, 36.52649586541312, 50.19434247698103, 50.30614594050816, 49.786604813167024, 54.59000219617571, 65.67576966966901, 70.37420409066337, 75.53294972011021, 76.76594230106899, 76.61515944344657, 77.7517318725586, 77.71961035047258, 76.81777586255754, 68.95035144260952, 57.94292490822928, 66.66801411764962, 73.22548770904541, 69.79528713226318, 80.96955381120954, 67.97753415788922, 74.55348300933838, 82.72291088104248, 83.08487728663853, 87.97157314845494, 85.16772488185337, 86.24839210510254, 85.52285426003593, 88.74797875540597, 87.21134294782365, 72.26580251966203, 58.66586412702288, 32.444352763039724, 12.474914738110133, 7.783749869891575, 6.052728652954102, 1.5936154872179031, 0.5172687407050813, 0.753780372440815, 0.11326539436621325, 0.026277076053832258, 0.10949960643691675, 0.19249430511678967, 0.0655639957902687, 0.11245848730738674, 0.1120943311335785, 0.04712408062602792, 0.2109228412487677, 0.3203319311141968, 0.16369394053305897, 0.08858067036739417, 0.10120451583393983, 0.2037197034806013, 0.2768412290939263, 0.37035250131572994, 0.3857062831521034, 0.26572074581469807, 0.28984461990850313, 0.39022310078144073, 0.31276642850467135, 0.5601009652018547, 0.2761765361896583, 0.4470193588307926, 0.4546486980148724, 0.4731763409716742, 0.40459056411470684, 0.2902289964258671, 0.29854048043489456, 0.3243832194379398, 0.2854565882257053, 0.2826682978442737, 0.23562646923320635, 0.4032076011810984, 0.36840768424527987, 0.27375926875642365, 0.3774902011666979, 0.486577461872782, 0.6813446421708379, 0.5050600501043456, 0.41643463713782175, 0.45370716282299584, 0.4291118425982339, 0.443634744733572, 0.26964544664536205, 0.30411839112639427, 0.1767403504678181, 0.15902100556663104, 0.2211373581417969, 0.24363918070282253, 0.2991737707384995, 0.3614444764597075, 0.37542061507701874, 0.3759079932102135, 0.33847389476639883, 0.20798341397728237, 0.24852189155561583, 0.23462771996855736, 0.19027896970510483, 0.15949663147330284, 0.1530280757163252, 0.11860756842153412, 0.12053356293056693, 0.17757124373955385, 0.10778414098812, 0.1495682392269373, 0.26781443346823963, 0.2592983032975878, 0.28865164678011623, 0.5428322489772524, 0.5644048314009393, 0.20778703237218515, 0.30261888301798273, 0.529315397143364, 0.24134784936904907, 0.25673213813986095, 0.1693730615079403, 0.25648699700832367, 0.12256173124270779, 0.2744632081261703, 0.22100454169724668, 0.21385914725916727, 0.20931407543165342, 0.16692473074155195, 0.17009863257408142, 0.2109101933560201, 0.3899334477526801, 0.4238231506730829, 0.21548920550516673, 0.3869386655943734, 0.48570334592035835, 0.37353621476462906, 0.41285525634884834, 0.34514041990041733, 0.24416708094733103, 0.3410971925726959, 0.37470500490495134, 0.33610355481505394, 0.3263898646192891, 0.3733966808233942, 0.37174428520458086, 0.14408437348902225, 0.4437173088746411, 0.15824909055871622, 0.06916041459356036, 0.32315743235605104, 0.14876120324645722, 0.16664734562592848, 0.2852505307112421, 0.2584318683615753, 0.21862238166587694, 0.2285961407635893, 0.3225818989532334, 0.49353222868272234, 0.23040679789015225, 0.3515414207109383, 0.5053894924265998, 0.2261671211038317, 0.541642749948161, 0.5299693420529366, 0.42764658693756374, 0.08413574352328267, 0.41699613843645367, 0.37171426681535585, 0.26902947255543297, 0.13060594030788966, 0.27011795129094807, 0.41314661928585594, 2.5626002975872586, 9.515412058149066, 15.427867003849574, 29.68110282080514, 48.64844472067696, 44.85636806488037, 55.454368523189, 60.89402634756905, 56.23287943431309, 56.22046995162964, 63.23178250449044, 63.995382581438335, 56.79953282220023, 58.30516229357038, 55.72791562761579, 61.225733348301475, 60.27269063677107, 56.570051193237305, 55.13912180491856, 54.34524842670986, 55.21334941046578, 55.320560114724294, 49.953434535435264, 47.842165333884104, 52.671566350119456, 72.07947962624687, 58.19751385280064, 49.66027266638619, 55.105537687029155, 61.481378419058665, 57.81683594839913, 59.522438049316406, 65.42076383318219, 72.9891516821725, 72.20736122131348, 75.98948805672782, 87.77124963487897, 91.33007526397705, 96.37799712589809, 92.88870212009975, 84.36400590624127, 56.68365771429879, 32.33454690660749, 18.48002651759556, 13.841734835079738, 4.4146352495465955, 0.48257665655442644, 0.05342579819262028, 0.1731636838189193, 0.03350362328014203, 0.06933859788945743, 0.21468527721507208, 0.1134903762223465, 0.19655393942126206, 0.07086777833423444, 0.08229555655270815, 0.05217089178040624, 0.25882647718702045, 0.16609336249530315, 0.059163503881011686, 0.061490539727466445, 0.17239323444664478, 0.29614481755665367, 0.24333875253796577, 0.2805477673453944, 0.39072125405073166, 0.22129187413624354, 0.23894081424389566, 0.34235709639532225, 0.46051856875419617, 0.38572479358741213, 0.3612458828304495, 0.4599780206169401, 0.3798786715737411, 0.37826400250196457, 0.29445143842271393, 0.18650976195931435, 0.2003825596932854, 0.2265924947070224, 0.22906989391360963, 0.15257804415055684, 0.33569800800510813, 0.3028631827660969, 0.29819353190915926, 0.19442219952387468, 0.5008447191544941, 0.5568004623055458, 0.34496239945292473, 0.34244533308914726, 0.4802304453083447, 0.2827623156564576, 0.33908506482839584, 0.2769684408392225, 0.1389707707400833, 0.08432110571967703, 0.22825755178928375, 0.23207515265260423, 0.2275446421865906, 0.39610800785677774, 0.3518509955278465, 0.33769960488591877, 0.3304860448198659, 0.3523735760578087, 0.13280307741037436, 0.15384827527616704, 0.16032566555908748, 0.13320924847253732, 0.16049482433923654, 0.2331430853477546, 0.1496711458478655, 0.17972195547606262, 0.2205465712717601, 0.19004716857203416, 0.18268366583756038, 0.37944932175534113, 0.35154405342681067, 0.4142194917159421, 0.6797059529594013, 0.6627136447599956, 0.3506058837686266, 0.48882943817547386, 0.5721520185470581, 0.4135064056941441, 0.3374965600669384, 0.2090410329401493, 0.2854562353874956, 0.2892256331230913, 0.37832401213901384, 0.3782532273658684, 0.25150880270770615, 0.2521102561482361, 0.33230503435645786, 0.2642846943012306, 0.23380159001265252, 0.45582560343401773, 0.5080755682928222, 0.25731114564197405, 0.49842842881168636, 0.5758987260716302, 0.5555397985236985, 0.3308016450277397, 0.46203637016671045, 0.21171532943844795, 0.38115358459098, 0.35691715510828154, 0.36164657132966177, 0.3056151850947312, 0.3136393773768629, 0.44032202820692745, 0.22490702729140008, 0.45771024801901405, 0.24765141255089215, 0.18225409888795444, 0.3831647081034524, 0.29186220307435307, 0.26306596398353577, 0.3536410523312432, 0.4003404107476984, 0.2852387513433184, 0.21514370904437133, 0.3341485325779234, 0.592396192252636, 0.34714019830737797, 0.18150703183242253, 0.6433136771832193, 0.2975966382239546, 0.3922294202659811, 0.5283711478114128, 0.4737056525690215, 0.21199355593749455, 0.33212429976889063, 0.3239689330969538, 0.566050360245364, 0.3797743671706745, 0.4875816937003817, 0.22926145792007446, 0.8638646453619003, 6.3556014980588635, 11.4293680531638, 25.489574228014263, 41.876174518040244, 51.25990431649344, 71.48474856785366, 84.63282476152692, 83.66051469530377, 85.46228681291852, 90.0603336606707, 98.13327884674072, 90.29808017185756, 85.41162749699184, 86.9198590687343, 86.33549472263881, 93.93492712293352, 101.67854159218925, 102.511109488351, 95.42950548444475, 99.6537253516061, 98.12833867754254, 95.46173122950962, 84.46824972970145, 73.23120607648576, 83.10604149954659, 90.53102547781808, 92.64357662200928, 105.15428066253662, 80.48121356964111, 93.85222271510533, 112.46331310272217, 104.74182864597866, 105.01545565468925, 98.3860751560756, 99.17969839913505, 101.67633206503731, 110.99514484405518, 109.17126355852399, 103.47504697527204, 90.74732984815324, 59.113863127572195, 32.05052539280483, 17.07813365118844, 11.485766581126622, 2.9318336503846303, 0.572085902094841, 0.7137220533830779, 0.3097774546061243, 0.15869110184056417, 0.24090490170887538, 0.31306444108486176, 0.2664705812931061, 0.2519180678895542, 0.1379840722573655, 0.12633323243686131, 0.23250501815761837, 0.3182625892971243, 0.17070963978767395, 0.13174734477485928, 0.1592559279607875, 0.23988538927265576, 0.21577579155564308, 0.41283392320786205, 0.35553782912237303, 0.3997488910598414, 0.21107777793492588, 0.2839890798287732, 0.48110852390527725, 0.5535180898649352, 0.436988249953304, 0.43548258074692314, 0.4763793519565037, 0.42953698549951824, 0.32088838411229, 0.31582702855978695, 0.2479903543634074, 0.278334196124758, 0.34087129469428745, 0.3198554095413004, 0.19877633159714087, 0.41435139892356737, 0.38254428282380104, 0.3243495641010148, 0.3145718201994896, 0.3657554265643869, 0.6162563604967934, 0.3066360003181866, 0.33947788232139176, 0.5256096731339182, 0.39358263622437206, 0.3542540951498917, 0.29483318222420557, 0.23302189899342401, 0.16900016580309185, 0.22338087989815644, 0.2912976076560361, 0.25174140451209887, 0.32364122782434734, 0.447857919548239, 0.3580572296466146, 0.311995477016483, 0.3891621705676828, 0.11656340025365353, 0.16839111277035304, 0.2687902482492583, 0.32125468445675714], [0.04652644055230277, 0.011913660181952375, 0.01809346366540662, 0.03950999490916729, 0.05852019840053149, 0.020438853884115815, 0.10066530441067048, 0.08028184103646449, 0.11819738043206078, 0.1596587063478572, 0.10822311243308441, 0.05713640086885009, 0.10570030566304922, 0.11547287234238215, 0.051601709465363195, 0.06347519358886139, 0.0483992005964475, 0.051832730283162425, 0.034540648705192974, 0.03160694148391485, 0.018760714646694914, 0.10571454132774047, 0.10307575256696769, 0.03067587948005114, 0.2207952950681959, 0.07465346769562789, 0.10303136280604772, 0.17043388315609523, 0.11021840572357178, 0.08199770682092224, 0.1430284780051027, 0.08005348686128855, 0.05436841564785157, 0.12010254391602107, 0.13282902458948748, 0.06698441385690655, 0.11328602183078017, 0.09008492822093622, 0.051386905634509664, 0.07545806095004082, 0.0819862260084067, 0.02453549888118037, 0.12081382503466946, 0.05457053765920656, 0.09594603228781905, 0.06340394062655312, 0.02941790608955281, 0.047243401009057245, 0.07540191896259785, 0.14832316817981855, 0.004852840469019222, 0.03228583612612315, 0.031027584536267177, 0.07787496875971556, 0.1041058162227273, 0.11053193639963865, 0.12756317215306417, 0.1173913079713072, 0.14869378400700434, 0.18060246322836193, 0.08908782779638257, 0.09881205564098698, 0.14718917331525258, 0.11267983221582004, 0.059370585983353, 0.10066882600741726, 0.07730839201914412, 0.3825672444488321, 0.13330465049615928, 0.2558294151510511, 0.4306235914783818, 0.2572695107332298, 0.17391574489218847, 0.5330193298203605, 0.31029911232846125, 0.3559199800448758, 0.20082910358905792, 1.8239887654781342, 1.6220292768308093, 6.186918343816485, 24.313508238111222, 25.398365225110734, 19.259704726082937, 27.432669230869838, 52.41584137507847, 59.567226137433735, 69.55807563236782, 61.4270087650844, 75.09871510096959, 71.49806131635393, 76.56182507106236, 85.68177345820835, 89.54975918361119, 90.92054149082729, 88.98016670772007, 83.52656732286725, 88.22068691253662, 85.72434507097516, 84.95579092843192, 86.40359401702881, 81.77795587267194, 65.84399250575474, 47.828668458121165, 49.2926469530378, 48.090785775865825, 34.25580024719238, 30.870064667293004, 19.036624125071935, 5.652965349810464, 1.176161527633667, 0.22787160107067653, 0.4591017876352583, 0.24965040385723114, 0.346782203231539, 0.23261616219367298, 0.10937405031706605, 0.05228815620232906, 0.1419098994561604, 0.18683422383453163, 0.05895699853343623, 0.061848419452352185, 0.03939205873757601, 0.06304250537816967, 0.0342613569061671, 0.06149520804839475, 0.11025995920811381, 0.07692658714950085, 0.04694507969543338, 0.08083229578499283, 0.100654407138271, 0.09030463785997458, 0.041192751577390094, 0.04738521822062986, 0.08843223404671464, 0.09488660163645234, 0.05377328276102032, 0.04247761870335255, 0.017407234059646726, 0.09165256803057023, 0.0813927792810968, 0.08765149129820721, 0.07407638723296778, 0.07726446366203682, 0.10147588234394789, 0.12877823838165828, 0.16444123829049723, 0.024308062424617152, 0.0508236571082047, 0.1260511382882084, 0.15487753147525446, 0.0826244085494961, 0.07108545915356704, 0.1276314870587417, 0.19009438103863172, 0.10916904453188181, 0.153453707162823, 0.15251988012875828, 0.20712426650737012, 0.20333019723849638, 0.12168590538203716, 0.1892767734825611, 0.060242048863853724, 0.13948092050850391, 0.08101036372993674, 0.018738014257646034, 0.015195459260472229, 0.04867751530504652, 0.06365165340581111, 0.056907877059919496, 0.03077919322199055, 0.11511673645249434, 0.0399369189648756, 0.08317957233105387, 0.060982106652642996, 0.03421350661665201, 0.053815711555736404, 0.07507840025105647, 0.07377371311719928, 0.04033247773934688, 0.06648418427045856, 0.05068355659022927, 0.07149289907621485, 0.11325657341097083, 0.12494357914796897, 0.15002995516572679, 0.167381737647312, 0.15980885257678373, 0.10732605521168027, 0.15224780115698064, 0.10071902402809688, 0.07944308354386262, 0.05819498335144349, 0.10886836530906813, 0.10677159710654191, 0.021827821852639318, 0.07945773990026542, 0.08324946822332484, 0.1595525291881391, 0.2091581073722669, 0.05919211091739791, 0.2401990352996758, 0.15562290219323976, 0.22174285565103802, 0.17685875482857227, 0.17848675032811506, 0.12343161313661508, 0.18373737643871987, 0.09515822598976748, 0.11286784069878714, 0.2139697756086077, 0.0849590032760586, 0.1486971631113972, 0.13566486670502595, 0.17977705251957687, 0.1599593109318188, 0.17944211406367166, 0.11811157289360251, 0.16278991475701332, 0.11709731231842722, 0.060070745913045745, 0.08045251294970512, 0.07572136646402733, 0.03886860968278987, 0.0800932761547821, 0.10537285823374987, 0.18097402900457382, 0.05012157353173409, 0.06042592506855726, 0.16026231752974646, 0.1721681508102587, 0.060921588114329746, 0.11915146852178232, 0.2680552048342568, 0.217350196359413, 0.0983384856954217, 0.2624818810394832, 0.23614541281546864, 0.11531299592128821, 0.2631241280053343, 0.1904517790036542, 0.15458270800965174, 0.2099213507026434, 0.20335816645196506, 0.399743164224284, 0.29097611776420046, 0.4096874477607863, 0.2057872675359249, 0.41557349477495464, 0.14568605540054186, 0.5006190655486924, 0.6008874337588037, 1.777997987610953, 5.365982166358402, 10.432206886155264, 14.822864770889282, 29.080062798091344, 47.13492556980678, 49.52213205610003, 47.327790192195344, 60.831388337271555, 86.62749971662248, 87.6380318232945, 95.36961201259068, 87.10195745740617, 95.84969084603446, 91.72129358564104, 91.86091068812779, 99.10677705492292, 99.35756533486503, 98.79499748774937, 95.14456680842808, 97.80844361441476, 97.85512856074742, 98.94881670815604, 99.38769272395542, 98.01420061928886, 97.63493319920131, 91.07907853807721, 84.30170140947614, 85.12147072383335, 78.39192499433244, 63.09214455740792, 55.43197447913033, 39.555524826049805, 17.66804439680917, 6.194410673209599, 1.6604700769696916, 0.6313456765242985, 0.10807303405765976, 0.31340118444391657, 0.24660709287439073, 0.3243139274418354, 0.026465228725490824, 0.07087364087679557, 0.17189316770860127, 0.0767429145053029, 0.06556034527186837, 0.07189300403531108, 0.0607002160644957, 0.055256987788847516, 0.03433627395757607, 0.07942574697413615, 0.08592563747827496, 0.07619374897331, 0.057636046915182045, 0.145721719201122, 0.048768744338303804, 0.061925772444478104, 0.08971363385873181, 0.13211942623768533, 0.05095692817121744, 0.07601703809840338, 0.1474161297082901, 0.13589750922151975, 0.18755647007908138, 0.14440340708409036, 0.04130687777485166, 0.12495013379624911, 0.10445511247962713, 0.18543976651770727, 0.17144857799368246, 0.16408834579799855, 0.17345887369343213, 0.12252173838870865, 0.23844952774899347, 0.157550878024527, 0.1861078113849674, 0.13859194463917188, 0.19156586565077305, 0.30925954239709036, 0.22017267133508409, 0.2225878488804613, 0.35628096067479675, 0.2381693199276924, 0.16772234865597316, 0.19753656669386796, 0.2653451631111758, 0.10813043133488723, 0.198325336511646, 0.11146927145974976, 0.07910560058163744, 0.04998269098411713, 0.03474210914490478, 0.13473302099321569, 0.049158420214163404, 0.12462706970317022, 0.14407386976693357, 0.1589831161711897, 0.07242538261094264, 0.13747428889785493, 0.019956727611965368, 0.08847105303513152, 0.17444501577743463, 0.09331838507205248, 0.15044152736663818, 0.08499590879572289, 0.13865401702267782, 0.1620867760585887, 0.2915269524923393, 0.24934126330273493, 0.1683182788214513, 0.2869726525885718, 0.18354437393801554, 0.2324047035404614, 0.2139206768146583, 0.21585877638842377, 0.11947446476135935, 0.21434974164835044, 0.1482339408248663, 0.23347901446478708, 0.12945568774427685, 0.07352758810988494, 0.208468457950013, 0.22283351926931314, 0.30977077782154083, 0.1307042193199907, 0.37775078575525967, 0.18313475591795786, 0.230675714888743, 0.24384306690522603, 0.1694550828209945, 0.16303900496235915, 0.18246699603540556, 0.11087321915796824, 0.12231493448572499, 0.19430557292486939, 0.1713080941034215, 0.13662168250552245, 0.17208304894821985, 0.2101656911628587, 0.14095742627978325, 0.16245277784764767, 0.16635714976915292, 0.12109518636550222, 0.2671233048396451, 0.15013561663883074, 0.23182029489959988, 0.20343241175370558, 0.14981234898524626, 0.14028604302023137, 0.15210551236357006, 0.21968898443239077, 0.12246996616678578, 0.11837179107325417, 0.2754191554018429, 0.25989261854972157, 0.1928612704255751, 0.1798450824405466, 0.3080939549420561, 0.18842281002019132, 0.2033308350614139, 0.3480130657553673, 0.2107004446110555, 0.15788485296070576, 0.222364977268236, 0.3543935476669243, 0.17623640250946793, 0.21609433660549776, 0.17403199151158333, 0.40489403211644714, 0.30948546741689953, 0.43201659673026627, 0.6883846329791206, 0.4216983861156872, 0.5210583316428321, 0.37254210667950766, 0.4552125334739685, 0.8543746545910835, 2.90708373274122, 7.82541561126709, 12.032433475766863, 27.43224365370614, 39.94140345709664, 44.066323144095286, 45.64792421885899, 63.49265956878662, 88.8222758429391, 90.63109343392509, 101.92709950038365, 86.92859295436314, 104.83368383135114, 98.35049343109131, 103.74633938925606, 115.69016075134277, 120.43172264099121, 127.33873231070382, 121.76783343723842, 121.11816297258649, 122.29799488612584, 114.0013177054269, 118.92714582170758, 113.05489662715367, 106.26149000440324, 93.27096421377999, 81.26575551714215, 84.13360364096505, 72.74542972019741, 55.80969592503139, 44.045440333230154, 29.210754939488, 11.684155021395002, 2.647021561861038, 0.7944544755986759, 0.5236195027828217, 0.21709615284843103, 0.2788651633475508, 0.22693301072078093, 0.44034276423709734, 0.21713614570243017, 0.30216749438217705, 0.42465625596897943, 0.09340193987424884, 0.1535045972892216, 0.13195044387664112, 0.18130007865173475, 0.10664832764970404, 0.08177068935973303, 0.21223151816853456, 0.26666863209434916, 0.10573624766298703, 0.11635685419397694, 0.3309805340000561, 0.13555605682943547, 0.09938070191336529, 0.19457789616925375, 0.19253805705479213, 0.13364706640797003, 0.1638889243560178, 0.17660608195832797, 0.20790431036480836, 0.22145021706819534, 0.16523243726364203, 0.1672190385205405, 0.14291656043912682, 0.15974726873849118, 0.2247936033776828, 0.18621864329491342, 0.22168466448783875, 0.16511795483529568, 0.24411369381206377, 0.28670395272118704, 0.22351309923189028, 0.2361804795052324, 0.17470508467938217, 0.21654963360301085, 0.2565936898546559, 0.2449206347976412, 0.2616906277835369, 0.3266364713864667, 0.24755964747497014, 0.2678976490029267, 0.17611981662256376, 0.2476704115314143, 0.1736698302307299, 0.26920097906674656, 0.1554187988596303, 0.12591361281062874, 0.1581860546554838, 0.15886971939887318, 0.22422349825501442, 0.14364902542105742, 0.2150314793522869, 0.16451168379613332, 0.17787499672600202, 0.10494491298283849, 0.14139942399093083, 0.11726936165775571, 0.1920078226498195], [0.03226006875878998, 0.017685494485444257, 0.0969761230849794, 0.031867970512913804, 0.06195793500436204, 0.029786856113267795, 0.028455144625955393, 0.057522399084908624, 0.03881456436855452, 0.06671604647168092, 0.09069045287157808, 0.07887179098491158, 0.018239365657791495, 0.01498955102371318, 0.0291070047366832, 0.0776495865679213, 0.022960590265159096, 0.03999538154208234, 0.037884666052247794, 0.06441244722477027, 0.07900027837604284, 0.058183882518538406, 0.03281167023149984, 0.15785738586315087, 0.12400146041597639, 0.012557980072285448, 0.06228125015539782, 0.09878794729177441, 0.10223956672208649, 0.07720683568290301, 0.07664790603199176, 0.10718519812715904, 0.07762947478996855, 0.12059549960706915, 0.14713783535574163, 0.007437595365835088, 0.04984621723581638, 0.027596634978960668, 0.0746522124058434, 0.0886708680274231, 0.04175091787640538, 0.035599913115480115, 0.031103186908044984, 0.006932459123033498, 0.05455100263601967, 0.05740539250629289, 0.06899576807128531, 0.0317042128715132, 0.006119919375383428, 0.01338852135398026, 0.10609925032726356, 0.05489225486027343, 0.06834296988589422, 0.04951781646481582, 0.03728405738781605, 0.041171554143407514, 0.06699297696884189, 0.06732323353311845, 0.037135787308216095, 0.03152465554220336, 0.03816571864964707, 0.02885468809732369, 0.09184236106063638, 0.05077259734805141, 0.049102413933724165, 0.06594604493251868, 0.038354656725589714, 0.26265786588191986, 0.16058965639344283, 0.16408055621598447, 0.12635102362505027, 0.11853713648659842, 0.04140091933576124, 0.04976869460993579, 0.01679318192015801, 0.05375950510746666, 0.07434140944055148, 0.1199262198060751, 0.14572530186602048, 0.40519269609025543, 0.18818191651787075, 0.09960688477648155, 0.07724151560770613, 0.689213368509497, 0.29890827355640276, 0.8114715910383633, 2.0004324061529974, 2.538582763501576, 7.357455304690769, 7.3711302280426025, 13.213883451053075, 15.542903116771154, 15.565705367497035, 12.027257936341421, 16.683818170002528, 13.626279882022313, 12.618604353496007, 15.164441687720162, 9.12512913772038, 8.387154017175947, 5.457600678716387, 2.323807648250035, 0.36063821400914875, 0.7476038038730621, 0.5308798274823597, 0.10695563615964991, 0.09314213560095855, 0.1029316656557577, 0.08868264060999666, 0.03681520665330546, 0.05161053042060562, 0.13802912698260375, 0.06405213155916759, 0.17936876442815575, 0.05343646137043834, 0.03182447302554335, 0.1586170329579285, 0.004226570458350969, 0.13231362296002253, 0.043646062790815315, 0.03514534215043698, 0.06175189784594944, 0.031227484345436096, 0.03472467079492552, 0.09527344123593398, 0.02612818341835269, 0.052295762579888105, 0.009222028810264809, 0.08926413155027799, 0.031406919538442574, 0.05207962203504784, 0.023627549476389374, 0.028611982906503335, 0.0746908617605056, 0.037888282643897195, 0.11833937067006316, 0.007261325538690601, 0.05788283688681466, 0.04571698898715632, 0.06289014033973217, 0.028504760802856514, 0.03010946898055928, 0.05895307660102844, 0.06022170638399465, 0.012886310445277818, 0.04409937507339886, 0.09436262332435165, 0.043575834416385205, 0.06329057099563734, 0.1457983800875289, 0.003023059044997873, 0.043202728365681, 0.03650518739596009, 0.0472478454134294, 0.09043469945234911, 0.02638262217598302, 0.034063869288989475, 0.05862061479794128, 0.06190410003598247, 0.09661124087870121, 0.10943131867263999, 0.13091289597962583, 0.08318550951246705, 0.1156727144760745, 0.0916431499645114, 0.03433372266590595, 0.09267643666160957, 0.0351872518658638, 0.030871314528797354, 0.08890289986240012, 0.009291594764882964, 0.030224341566541364, 0.07966496449496065, 0.04685240538258638, 0.04885393101722002, 0.030922445535127605, 0.006236260989680886, 0.10950111278465816, 0.06771291619432823, 0.053208280221692154, 0.09675861189940146, 0.032532470034701486, 0.026831198284136396, 0.023890347785449455, 0.11033881176263094, 0.03467767206685884, 0.11844968689339501, 0.07537719993186848, 0.0484438821274255, 0.040950429758855274, 0.11543506437114306, 0.059507161511906555, 0.03646544559991785, 0.12662026632044995, 0.031103990972042084, 0.1009755509772471, 0.07289403317762272, 0.07905043568462133, 0.0422932980582118, 0.08618272761149065, 0.16774008556136064, 0.136525208396571, 0.11706272060317652, 0.081859468881573, 0.08766363028969083, 0.13109619542956352, 0.07609818410128355, 0.0792777177744678, 0.07758759560861758, 0.08034514156835419, 0.13733943684824876, 0.07169962155499629, 0.030304717432175363, 0.1462042254528829, 0.07579624280333519, 0.09815709292888641, 0.06399206085396664, 0.03655461188671844, 0.11622608692518302, 0.041632343881896565, 0.09270583758396761, 0.08025136802877698, 0.09862199798226357, 0.03250643803871103, 0.029442774397986274, 0.07322452722915582, 0.015485955368993538, 0.0545938114103462, 0.04106012512264507, 0.09369185753166676, 0.08088749460875988, 0.05707099009305239, 0.06083805366818394, 0.07801929315818207, 0.1346661038696766, 0.02516856526822916, 0.07260492297687701, 0.07338215091398784, 0.07175749380673681, 0.04058786474966577, 0.016686180340392247, 0.05805154783385141, 0.04799430857279471, 0.2619169056415558, 0.09027622759874378, 0.1514017901250294, 0.07849042037768023, 0.07770011028540985, 0.05103173665702343, 0.03973360612456288, 0.05665999464690685, 0.10074639613074915, 0.13251783485923493, 0.4554558832730566, 0.5613679800714765, 1.094119695680482, 0.6328427419066429, 0.9410735709326608, 1.264996960759163, 2.953138347182955, 3.2896500272410254, 7.375917536871774, 11.686056222234454, 12.153643931661334, 18.836389201028005, 21.238952943256923, 29.371723856244767, 33.19923285075596, 36.284948689596995, 33.3953492300851, 39.19884252548218, 32.157812527247835, 32.255657059805735, 34.80704253060477, 25.206654003688268, 26.1075313772474, 20.696494919913157, 12.485375251088824, 3.297410079411098, 3.7225959726742337, 3.1087152447019304, 0.5446687447173255, 0.3380520631160055, 0.23298783653548785, 0.0712676118793232, 0.17840924805828504, 0.11370706638055188, 0.06555784826299974, 0.06152712633567197, 0.18310845590063504, 0.0942037511350853, 0.12767464188592775, 0.0570171686953732, 0.03219804387273533, 0.13283586422247545, 0.039674797494496615, 0.021362207730167677, 0.016433403993557607, 0.03893894323014787, 0.03938582639342972, 0.04616211474473987, 0.1313236675092152, 0.02643188551467444, 0.032409875720207176, 0.06299554396952901, 0.06759461361382689, 0.04984019863020096, 0.029721370698618035, 0.079518197370427, 0.019371706593249525, 0.022385273993547474, 0.066558863834611, 0.07468957932932035, 0.026769124204292893, 0.038835442891078334, 0.0517301765004439, 0.05127196180235062, 0.02248629428712385, 0.0354594020838184, 0.10746512096375227, 0.02297295656587396, 0.05841682359044041, 0.04916181288925665, 0.16645413956471852, 0.06137245427817106, 0.03591575420328549, 0.034615966092262945, 0.026400713615917733, 0.04203207564673253, 0.1726372627807515, 0.05490009533241391, 0.10931366748575654, 0.054483481616313965, 0.14972183241375855, 0.11605284336422171, 0.13498410609151634, 0.1270142916057791, 0.24198564514517784, 0.049343833300684176, 0.11599880483533655, 0.1256776861846447, 0.06842369519706283, 0.14429879055491515, 0.07309803473097937, 0.05682065138327224, 0.038587852248123715, 0.011429399917168277, 0.044671481874372275, 0.056734694567109854, 0.010192948809292699, 0.04724873090162873, 0.03677246912515589, 0.10063357611319848, 0.29045427005205837, 0.1387319942670209, 0.18681583553552628, 0.15865113612796578, 0.06355649565479585, 0.10296575525509459, 0.12014445023877279, 0.1672726563577141, 0.11420673956828457, 0.2080969735980034, 0.19264386780560017, 0.18664037995040417, 0.18867867200502328, 0.18610668501683644, 0.24972219286220415, 0.13371156794684275, 0.15943381270127638, 0.1547393546040569, 0.2761350912707192, 0.10878543475908892, 0.16208589396306447, 0.14013278910091945, 0.3157689188207899, 0.2846165347312178, 0.20299132327948297, 0.2324579278273242, 0.22273585093872889, 0.2665069507701056, 0.1729594176369054, 0.15908410932336534, 0.20093154880617345, 0.18121257477572986, 0.2005493300301688, 0.3390841420207705, 0.2527872712484428, 0.16978088819554873, 0.2824253280247961, 0.18764263045574936, 0.18489060098571436, 0.0950813072600535, 0.18650372299764836, 0.2842232015516077, 0.11246397665568761, 0.20479648427239486, 0.2431462114410741, 0.30674638439502033, 0.16989975396011556, 0.14644437256668294, 0.15717609599232674, 0.19354057897414478, 0.13105244349156106, 0.23956351940120968, 0.21022500869418892, 0.13849076149719103, 0.12929499708116055, 0.2030306783105646, 0.17038827203214169, 0.19820355304649898, 0.12217540054449014, 0.18261385815484182, 0.11677542887628078, 0.1677248320941414, 0.19278042976345333, 0.15550639773053782, 0.17673427079405102, 0.2231955448431628, 0.3959685010569436, 0.3330296283321721, 0.38580893192972454, 0.2256250259067331, 0.2335116927112852, 0.1356655859521457, 0.1194290571979114, 0.08994865124779088, 0.26082530564495493, 0.17148988720561775, 0.2220020695988621, 0.25113433280161446, 0.6091370082327298, 0.212556712861572, 0.1956611637558256, 0.3247254453599453, 0.9812155940702983, 1.0042211881705692, 3.2436264625617435, 5.283296866076333, 6.630220362118312, 9.906948259898595, 12.879418884004865, 18.83601920945304, 21.521569183894567, 23.117231675556727, 20.713474580219813, 25.22562779699053, 20.47209416116987, 18.82262134552002, 21.424841574260167, 13.113304802349635, 12.807961872645787, 10.239655801228114, 6.152103091989245, 1.28401309464659, 1.2962849161454608, 0.8851861155458859, 0.1709609827292817, 0.13181321695446968, 0.21857187151908875, 0.27121508813330103, 0.21736629121005535, 0.17251579144171306, 0.23798581691724913, 0.26842715059007916, 0.25654296257666176, 0.20539643136518343, 0.14473434218338557, 0.24761314317584038, 0.13514987219657215, 0.3106163681617805, 0.07445946096309594, 0.15856603426592691, 0.14705232637269156, 0.12506237705903395, 0.11149975803813764, 0.28197499790361946, 0.17894248158804008, 0.10812112861978156, 0.2150301087115492, 0.1935896777680942, 0.1852920494441475, 0.1801845942224775, 0.15400276412921293, 0.16898150609007903, 0.2019078792738063, 0.17440633928137167, 0.3105007457946028, 0.18822494920875343, 0.17106616922787257, 0.15802221558988094, 0.11190021583544356, 0.10650959437979118, 0.11587700779948916, 0.17296888998576573, 0.2558025180229119, 0.0886480285386954, 0.1321988555469683, 0.18162114785185882, 0.2595053921852793, 0.14952764926212175, 0.31180925986596514, 0.11682399841291563, 0.10303459263273648, 0.1593779149864401, 0.23178829518812044, 0.2116250299981662, 0.1452553892242057, 0.23308416136673518, 0.19952791769589695, 0.19725335974778446, 0.2255491249795471, 0.2190038404826607, 0.39354032278060913, 0.33550587402922766, 0.25402160787156647, 0.2189106640538999, 0.1596251324351345, 0.18708719526018414, 0.17348440018083366, 0.23901273895587238, 0.15765184403530189, 0.1928863219384636, 0.08497598700757537, 0.21703617035278253, 0.13809806614049844, 0.1965331762496914, 0.12163253181747027], [0.08379071525165013, 0.0066160858093228725, 0.030643201233553033, 0.01834657758341304, 0.024935871861608963, 0.013788583056469048, 0.061982565825538974, 0.010617610798882586, 0.10315217596611806, 0.02234360685438982, 0.027572558860161474, 0.045426297799817154, 0.02875818345429642, 0.01189363406904574, 0.028590778687170575, 0.08678473745073591, 0.013514147871839148, 0.007662735829528953, 0.044752023981085846, 0.03393214189314416, 0.027025674902168766, 0.04365499909701092, 0.04510988674259611, 0.05027295130171946, 0.024668730928429534, 0.027578940482011864, 0.06359960976988077, 0.024510014802217484, 0.05128213643495526, 0.020841421925329735, 0.044883401931396553, 0.07500170543789864, 0.050477359976087294, 0.0244694672458406, 0.021487623054002012, 0.07291687945170061, 0.0683897752314806, 0.032958416999982934, 0.07111054459320647, 0.034455886110663414, 0.038033584132790565, 0.010818483457634491, 0.057106097494917255, 0.02701592435395079, 0.02963969883109842, 0.015580485475116541, 0.013327162280412657, 0.06318571697920561, 0.049760901635246615, 0.0781149190983602, 0.08201146751110043, 0.04426812333986163, 0.06728765115674053, 0.04122119915804692, 0.1649883682174342, 0.0857246011229498, 0.02793170235651944, 0.034719605531011305, 0.06681436619588307, 0.046076008650873385, 0.039329416384654384, 0.07936057368559496, 0.036983958312443325, 0.052754096021609645, 0.07736583000847272, 0.04434797673353127, 0.04846844509510057, 0.07087030248450381, 0.021389786786000644, 0.053715576750359366, 0.02814180902870638, 0.05396246171689459, 0.0755756985662239, 0.14245286317808287, 0.05141451861709356, 0.044071606027760675, 0.07391814608126879, 0.016728800821251104, 0.0655734274270279, 0.10277932775872094, 0.021656291592600088, 0.04943376972473093, 0.010986435293619121, 0.11495261240218367, 0.08267621469816991, 0.0691102844263826, 0.15807998606136867, 0.18003607647759573, 0.3187479589666639, 0.31732748661722454, 0.46913514924900873, 0.38136846306068556, 0.2757914268544742, 0.04368671043110745, 0.14762163082403795, 0.09946283857737269, 0.0863920488793935, 0.1532533357718161, 0.1990480984428099, 0.23940175665276392, 0.15806228986808232, 0.11195897018270833, 0.027615842609001056, 0.1371773076908929, 0.10193130826311451, 0.09132575163883822, 0.05110174111489739, 0.09265267436525651, 0.017893821699544787, 0.03615053749776312, 0.047540836834481785, 0.06317574929978166, 0.0517301765004439, 0.10213846500430789, 0.038461444566824605, 0.03452644696725266, 0.03214485690529857, 0.02730680553109518, 0.05531097882028137, 0.040053681270884614, 0.06432250740804843, 0.05898307463420289, 0.06711423796202455, 0.0634400454748954, 0.06174050524298634, 0.03913666833458202, 0.010544542755399431, 0.04258745995217136, 0.04215059196576476, 0.01003054908609816, 0.022509846237621138, 0.04169034844796572, 0.027252302205722247, 0.07956115542245762, 0.04615237098187208, 0.08300012017467193, 0.03265209236581411, 0.03988587956077286, 0.07225090411624738, 0.09276602364012174, 0.09868158014225108, 0.02662499658098178, 0.04500050689758999, 0.09917338910911765, 0.03545042506552168, 0.06454931452338185, 0.042852000399891815, 0.12625358599637235, 0.030854405436132635, 0.03016516992024013, 0.024711488812629665, 0.01876036180848522, 0.015355281398764678, 0.05283727762954576, 0.06662132298307759, 0.015138190904898303, 0.051972868120563884, 0.026146057727081434, 0.07113643748951809, 0.062476749664970806, 0.07419042182820183, 0.08551638586712734, 0.04466131063444274, 0.03330826287024787, 0.015511500516108103, 0.08839977293142251, 0.02521948592870363, 0.030654950067400932, 0.02529331562774522, 0.030177987446742396, 0.03409154333972505, 0.02441070611322565, 0.03702698421797582, 0.03777069252516542, 0.023485759406217506, 0.04361913512860026, 0.023131506451006447, 0.033430056513420174, 0.033442066583250246, 0.06695797813258, 0.03487623516204102, 0.035041472009782276, 0.03259140419374619, 0.052954155286507945, 0.040180648743574104, 0.018635964287178855, 0.022111349406519105, 0.12477181479334831, 0.03650718228891492, 0.011235135341329234, 0.010777935901257609, 0.019321223587862084, 0.07052674663386174, 0.04328127897211483, 0.024958385653527718, 0.03114759023966534, 0.07747162718858037, 0.015087158286145754, 0.01905469672887453, 0.0944217372951763, 0.07803515730691807, 0.036421137263200114, 0.03912024439445563, 0.014961162814870477, 0.058499157029603205, 0.018900055205449462, 0.028487057824219977, 0.036170676417116604, 0.05602900118434003, 0.008413612859190574, 0.06019254294889314, 0.04351099021732807, 0.0836545264880572, 0.0357101139878588, 0.028735252363341193, 0.04526665208062955, 0.02024562916319285, 0.03588107427848237, 0.03319653529407723, 0.016788683232984374, 0.013794577913358808, 0.01612655519108687, 0.04406873921730688, 0.022759165448535765, 0.033851406403950283, 0.021151280030608177, 0.05658144064779792, 0.01752064609900117, 0.029931567276694944, 0.021379335650375912, 0.04196113141785775, 0.05980241245457104, 0.03269006657813277, 0.009651722137017973, 0.039643802014844756, 0.022463224096489803, 0.022628501656332185, 0.04869392906714763, 0.009744519434337105, 0.014684734433623297, 0.056264181421803575, 0.054876156616955996, 0.013155608271647776, 0.07563648173319441, 0.04568332686488118, 0.06329657603055239, 0.028282089358461753, 0.14071128091641835, 0.07273631449788809, 0.01608725274646921, 0.0807464068223323, 0.051668606232851744, 0.021590336292449917, 0.04809609900361725, 0.10086257489664213, 0.07269744122666971, 0.06044691215668406, 0.0848271707072854, 0.13914303721061774, 0.022739374278379337, 0.16086159965821675, 0.11514683626592159, 0.20546638832560607, 0.3470859155058861, 0.18352755984025343, 0.10976377369037696, 0.3572200802820069, 0.2878210927758898, 0.4230827604021345, 0.05509540145950658, 0.3293841853737831, 0.31708535818117006, 0.16948218350963934, 0.4532999875290053, 0.23309197809015, 0.08484344197703259, 0.18925442253904684, 0.10923909648720707, 0.13432557428521769, 0.07065514581544058, 0.06901142187416553, 0.09591177305472748, 0.12151657018278327, 0.011465821980631776, 0.08298941967742783, 0.05889131634363106, 0.02171990933961102, 0.048753144818225076, 0.08451829478144646, 0.045212396420538425, 0.07820998185447284, 0.04738999171448605, 0.05100168434104749, 0.020859328464471867, 0.04017288291028567, 0.019047536488090242, 0.023119871271774173, 0.036403702305895944, 0.048864485629435093, 0.011997019057162106, 0.08801545748221022, 0.037328565892364295, 0.06446329663906779, 0.0685525761385049, 0.00930983548252178, 0.010138638018231307, 0.054821677040308714, 0.02359089331834444, 0.012735193063105856, 0.048431129061750004, 0.07002792161490236, 0.020797985506110957, 0.027716240346697823, 0.02663364790246955, 0.12243489947702203, 0.06965663403804813, 0.06388196176184074, 0.04618843851078834, 0.040700457457985194, 0.01248897475722645, 0.015161549472915275, 0.01443337622497763, 0.05376197836760964, 0.10880783998540469, 0.028540862258523703, 0.06349668957825218, 0.04657706944271922, 0.04034678804289017, 0.05076509953609534, 0.012622348448660756, 0.054203952330031564, 0.06779207408960376, 0.05295768366860492, 0.047069794431860955, 0.024476264470389912, 0.06296754761465959, 0.03606700644429241, 0.02969489765486547, 0.029887136803673844, 0.024772178681035126, 0.042500353019152365, 0.014422017548765455, 0.05412975113306727, 0.011059270090689617, 0.04842376356412258, 0.03302718313144786, 0.014229318692481943, 0.017757280097742165, 0.08248591276683978, 0.015695424218262945, 0.01123479607381991, 0.02842892942550991, 0.16248807523931774, 0.07775976029889924, 0.17023553379944392, 0.1175868481929813, 0.1110766643126096, 0.09304095924432788, 0.16935361469430582, 0.09436977508344821, 0.2158485169389418, 0.0663625161562647, 0.11273238475301436, 0.24112368854028837, 0.1480051523872784, 0.06992150696792773, 0.07120830113334314, 0.21688212933284895, 0.08626367005386523, 0.1517428761082036, 0.16122887709311076, 0.06466799029814345, 0.18433260092777864, 0.2787532050694738, 0.1789350448442357, 0.15476820591304982, 0.1615505569747516, 0.24550702476075717, 0.14634582214057446, 0.09452961079244103, 0.11064867834959712, 0.12100306845137052, 0.11779397779277392, 0.18614684071924004, 0.16404189329062188, 0.07882978288190705, 0.1570212407303708, 0.2567426690033504, 0.20274779706129006, 0.12840874892260346, 0.23671758068459375, 0.11800516503197805, 0.07451875135302544, 0.14010453490274294, 0.16847530539546693, 0.13481021113693714, 0.04973782465926238, 0.09840060557637896, 0.08763836843094655, 0.09115614502557687, 0.1840152365288564, 0.1382845411343234, 0.23072060676557676, 0.129474686724799, 0.13611953945032187, 0.11287170156304326, 0.2831254133156368, 0.20848000661603042, 0.14173139046345437, 0.0816761694316353, 0.2141276571367468, 0.18459798954427242, 0.12438825251800673, 0.13540893686669214, 0.19509628335280077, 0.13444026027406963, 0.20074525023145334, 0.14557702839374542, 0.11293791301016297, 0.26936029908912523, 0.17869313353938715, 0.14370317251554557, 0.15620276464947633, 0.233975457825831, 0.27782969176769257, 0.23414465731808118, 0.2061675185603755, 0.1532495224050113, 0.18158723467162677, 0.10337709675409965, 0.2527006630386625, 0.2935663844857897, 0.16807699176881993, 0.26294418051838875, 0.24234776571393013, 0.1516641117632389, 0.15197098601077283, 0.15023580911968434, 0.3044407766844545, 0.49710067148719517, 0.390570266438382, 0.3747914231249264, 0.7308641821146011, 0.5564125031232834, 0.3627334487225328, 0.10899727339191095, 0.19233216238873346, 0.24475127245698655, 0.14506891423038074, 0.21363790413098677, 0.31674196517893244, 0.28342719855053083, 0.30018166665519985, 0.2195919674954244, 0.15401727120791162, 0.19147111502076897, 0.18903232445674284, 0.11489813961088657, 0.17275300728423254, 0.12044839321502618, 0.3117333725094795, 0.10961592090981347, 0.15707764056112083, 0.23747067313109124, 0.1608162870896714, 0.174782980499523, 0.17223106457718781, 0.19311538179005894, 0.12585607304104737, 0.0832696207133787, 0.16781044964279446, 0.08038056109632764, 0.1012758162936994, 0.1133209935256413, 0.18189261614211968, 0.09305674875421183, 0.1775605228862592, 0.16098415665328503, 0.09968288069857018, 0.17978368859205926, 0.1753913549972432, 0.11218000975038324, 0.09429170284420252, 0.1595161325697388, 0.12088486765112195, 0.22508126151348862, 0.14930730180016585, 0.16944432125559875, 0.17984790514622415, 0.1792399241988148, 0.4029011204838753, 0.18712853161352022, 0.2992161384650639, 0.2180159477783101, 0.14672405113066944, 0.1294976890619312, 0.08884384017437696, 0.15151342270629747, 0.11800033386264529, 0.24096982393945965, 0.10234882443078927, 0.11631280370056629, 0.20078999283058302, 0.09603523928672075, 0.17959813640585967, 0.1232682897576264, 0.16460068044917925, 0.14413268518235, 0.12846246175467968, 0.08174557677869286, 0.17438682461423533, 0.16665685868688992, 0.24048928543925285, 0.13713967613875866, 0.1293654018746955, 0.15684640939746583, 0.08733291910695178, 0.15291181552622998, 0.10617656260728836, 0.09117186668195895, 0.10147996712476015, 0.12293721895132746, 0.14808394387364388, 0.10638031310268811, 0.2263091384832348, 0.05803415019597326, 0.1196828835776874, 0.09299950075468846], [0.0232698139401951, 0.05373329669237137, 0.07750400687967028, 0.013863461092114449, 0.04001747803496463, 0.03862190452803459, 0.012890939750442547, 0.05528030225208827, 0.0007758407040715351, 0.037711792292871645, 0.032660390849092176, 0.03692630658458386, 0.0767646547673004, 0.023293411691806147, 0.014038120246758419, 0.012774877183671509, 0.09260579438081809, 0.016282472360346998, 0.03482412027993372, 0.07709582056850195, 0.03942205337807536, 0.012094150496912854, 0.03708373010158539, 0.030116739483284097, 0.04413445533386298, 0.012177295633591712, 0.021153454735342945, 0.07253646557884556, 0.01556066207454673, 0.03250538630943213, 0.02640407406059759, 0.09866663880114045, 0.05812790337949991, 0.015369644288771918, 0.01235487503332219, 0.004919690587225237, 0.03497522324323654, 0.04331507340871862, 0.0799011964617031, 0.038064990126128705, 0.02820451244977968, 0.011615103077409523, 0.040334167291543314, 0.059397740954799313, 0.05446377695937242, 0.015991672607404844, 0.05465928664697068, 0.04793353558384946, 0.024211169320291707, 0.028799177147448063, 0.03888142381661704, 0.015245431668258138, 0.058199183483208926, 0.049102376614298136, 0.03707286336326173, 0.035309513698198965, 0.015741700306534767, 0.04922940515513931, 0.025191370830205933, 0.05335296085104346, 0.03200359269976616, 0.06017108088625329, 0.09901902239237513, 0.02806516001666231, 0.09173769024865967, 0.014783912504624044, 0.07340467149125678, 0.031295127501445155, 0.034910222981125116, 0.03505622675376279, 0.02674958748476846, 0.031513486855796406, 0.062297005738530836, 0.03325836340497647, 0.07570687974137918, 0.053110985085368156, 0.06634277757257223, 0.009327809875165778, 0.016697160733331527, 0.13113348771418842, 0.06796975526958704, 0.059048485410000594, 0.04066120759983148, 0.10517055301793984, 0.050030853399740796, 0.015722428215667605, 0.071693535095879, 0.06736852574561324, 0.07681014375495059, 0.012620313691773584, 0.10162731100405965, 0.08596153876611165, 0.10731908665703875, 0.10153397851224456, 0.05221018235066107, 0.08553385135850736, 0.04202529029654605, 0.06426451302000455, 0.05980260922972645, 0.07026582277779068, 0.03526333599750485, 0.018168820068240166, 0.04959604476711579, 0.03914004743897489, 0.033506568122122965, 0.05264835651697857, 0.040924204380384514, 0.033910242175417285, 0.038391813303210905, 0.058495906846863885, 0.03536702632637961, 0.050405771138944795, 0.10140286519059113, 0.038063460029661655, 0.03925328136288694, 0.05538227928004094, 0.03992926848254033, 0.007073722056312752, 0.09890919471425669, 0.08978884268019881, 0.07012598349579743, 0.038867944718471596, 0.021018950434933816, 0.08848457623805318, 0.05432376125827432, 0.0257192490223263, 0.021059043372848203, 0.0757166642163481, 0.027448685507157018, 0.059336998499929905, 0.03273163363337517, 0.031528580867286236, 0.01728262279980949, 0.07503578146653515, 0.06844041429992233, 0.006082801813525813, 0.024058217349063073, 0.047015806793102195, 0.057864706431116374, 0.012289169942960143, 0.02995840672935758, 0.02803069383039006, 0.016517790001151816, 0.013877259101718664, 0.01707700633310846, 0.041432864764439206, 0.016545782963346158, 0.046831913625023196, 0.016417368514729396, 0.04984069735343967, 0.015291660259078656, 0.047811144829860756, 0.004314623947720975, 0.04663839204502957, 0.04516944515385798, 0.012383944321689861, 0.09578767578516688, 0.012297632122811462, 0.070292869183634, 0.024320783259879266, 0.007361438291679535, 0.04399939633107611, 0.02670614597653704, 0.009293702464284641, 0.015068861589367901, 0.010498970647209456, 0.03281125293246337, 0.019376174746347324, 0.02295426801512284, 0.01506681410994913, 0.05970902567995446, 0.04216142138466239, 0.06056598826710667, 0.033832363318651915, 0.0617235554382205, 0.045386976695486476, 0.0136763788094478, 0.016661171235942414, 0.05303668210815106, 0.0487914854394538, 0.06316192075610161, 0.027678327202530842, 0.029901616740971804, 0.0610223709206496, 0.0695336020684668, 0.032437037477003675, 0.07469732819923333, 0.04220347698511822, 0.006552148302684405, 0.00034341998460669335, 0.05408651827435408, 0.05220625702557819, 0.0107921096496284, 0.027271458945636238, 0.011322847866852368, 0.023419987310522368, 0.06040865635233266, 0.011807530519685574, 0.014734002861327358, 0.019947796394782405, 0.03956230317375489, 0.02743906557693013, 0.033040468847112994, 0.08272531349211931, 0.006334298697765917, 0.04339019062795809, 0.023657138692215085, 0.04583275384668793, 0.029107282936040844, 0.06811490069542613, 0.016864090525944318, 0.02289656370079943, 0.0220786202698946, 0.07697237469255924, 0.002922120811750314, 0.05720569286495447, 0.023629839532077312, 0.008479659761568266, 0.049722157285681794, 0.07237684700105872, 0.0232036211527884, 0.025844937456505637, 0.10718109299029623, 0.03811443158026252, 0.05676201917231083, 0.09014123305678368, 0.059969929179974964, 0.06160754630608218, 0.06164612102189234, 0.04625205456146172, 0.058353936964912076, 0.035567346827260087, 0.04418567115707057, 0.04416052804195455, 0.062188881183309216, 0.03766129910945892, 0.052458142795200856, 0.045280226173677614, 0.05434392731902855, 0.08495351392775774, 0.05324216286784836, 0.04013430819447551, 0.0392608809550958, 0.016659045724996498, 0.04045136046728917, 0.016241955338045955, 0.04722020189676966, 0.03973117018384593, 0.020106734741213064, 0.08284499349870852, 0.0988229936254876, 0.012916417044055249, 0.02629461109505168, 0.05810227511184556, 0.07138178896691118, 0.02035599118763847, 0.012644332983264965, 0.060086928973240514, 0.12130591220089368, 0.01578090775624982, 0.10581833004419293, 0.06462518152381692, 0.11998271463172776, 0.07613819052598306, 0.053390585617827516, 0.08111947894628559, 0.07398833374359778, 0.13034393079578876, 0.12195027619600296, 0.053253779387367625, 0.025062942810888802, 0.05290436438683953, 0.03452142241543957, 0.014300284973744835, 0.10018024686723948, 0.08665835351816245, 0.13682197247232708, 0.02351964544504881, 0.07776306476444006, 0.04008524671995214, 0.04546035347240312, 0.11094793264887162, 0.027664083056151867, 0.07997666312647717, 0.05912291391619614, 0.056602152929242165, 0.02925444021821022, 0.041619828303477595, 0.04156860908759492, 0.03782913474632161, 0.05689147686851876, 0.057503244041332176, 0.019422915631106923, 0.021010631595605185, 0.05299352728096502, 0.02836145251058042, 0.03554398825924311, 0.05712544931364911, 0.03197004592844418, 0.0635182127090437, 0.09082740159439188, 0.09144285321235657, 0.049703921657055616, 0.06008079501667193, 0.02510826725379697, 0.027073540458721772, 0.01459905072780592, 0.0422274801614029, 0.04485092046005385, 0.02159105723590723, 0.01610441120075328, 0.031812072798077545, 0.03292177610897592, 0.05995194800198078, 0.040936102491936514, 0.018628091584624987, 0.05239435711077281, 0.039194028292383463, 0.07700291555374861, 0.04603750178856509, 0.052608774176665714, 0.03418309467711619, 0.009259879189942564, 0.024476937916395918, 0.02667051779904536, 0.07049275881477765, 0.051175104321113656, 0.04538456450349518, 0.03508311031120164, 0.02946580048384411, 0.04262237736423101, 0.036840787423508506, 0.07529583001243216, 0.04100344030718718, 0.058473942668310235, 0.02453423341337059, 0.02986206832740988, 0.0487068483739027, 0.014126701297105422, 0.030052865589303628, 0.06282036658376455, 0.033870507164725235, 0.01333549723494798, 0.02619456110655197, 0.034998123800115924, 0.016078292691547955, 0.019771453625123416, 0.025619897924895798, 0.03561863050396953, 0.017774820227974227, 0.024600304064473937, 0.0265989815483668, 0.16763721965253353, 0.22396604849823884, 0.17096874516989502, 0.10240827766912323, 0.12306056304701737, 0.1605170802878482, 0.08249678968318871, 0.10701322342668261, 0.12281082144805364, 0.1348298072282757, 0.17955206387809344, 0.14173046765582903, 0.18549067021480628, 0.1109484958329371, 0.24201311224273273, 0.08586413506418467, 0.13304440517510685, 0.20536916782813414, 0.11222298137311425, 0.10334585700184107, 0.24761789292097092, 0.06971818394958973, 0.09803668010447707, 0.13258038221725396, 0.09584428596177272, 0.07318642070250851, 0.17136449393417152, 0.18662803061306477, 0.06514774848307882, 0.14912350023431437, 0.15269484716866696, 0.16369588114321232, 0.12346231006085873, 0.19049082190862723, 0.05224055697077087, 0.03775966972378748, 0.05942351171480758, 0.12921752195273126, 0.20588207244873047, 0.18307406774588994, 0.09080077588026013, 0.11967396762754236, 0.1531729158014059, 0.18552005078111375, 0.0955179716859545, 0.11430603638291359, 0.09292131316448961, 0.09685278577463967, 0.16430383494922093, 0.20909223519265652, 0.09568282855408532, 0.11018914050821747, 0.16272947085755213, 0.17731606028974056, 0.15338379091450147, 0.1019772586545774, 0.16312671239886964, 0.1309042243020875, 0.11260095251990215, 0.22829104427780422, 0.14759207383862563, 0.09311559131102902, 0.18981173049126351, 0.17261958015816553, 0.17582215688058309, 0.13505779499454157, 0.10816973886851754, 0.136199009471706, 0.11273951615606036, 0.1182806095374482, 0.09761802399797098, 0.25348662372146336, 0.14560452263270104, 0.2108171662049634, 0.12555929539459093, 0.12850225104817323, 0.14355153350957803, 0.13276152392583235, 0.17762305667357786, 0.20981718200658048, 0.10533030730273042, 0.10363328443574053, 0.14670718275010586, 0.11957412798489843, 0.23300420280013764, 0.16363095891262802, 0.20257729478180408, 0.22254876526338713, 0.25560408724205835, 0.22610238886305264, 0.2752961777150631, 0.2435269510107381, 0.2452253241624151, 0.19859702193311282, 0.08826625081045286, 0.11951155348547868, 0.1634554083326033, 0.10755732030208622, 0.1925792848425252, 0.18057739814477308, 0.1796571146696806, 0.09637333971581288, 0.21131428810102598, 0.2457188633935792, 0.12885489926806518, 0.21902750778411115, 0.1309324920709644, 0.17865286927138055, 0.1599513449306999, 0.18567642596151146, 0.1338203371103321, 0.1823424305766821, 0.15495544086609567, 0.14120068108396872, 0.14491608100278036, 0.2670644080000264, 0.17773964256048203, 0.08013677703482763, 0.12690670309322222, 0.14542063964264734, 0.1261669099330902, 0.12981854113084929, 0.11117968628449099, 0.2038597666791507, 0.19559571226792677, 0.26459616901619093, 0.22233930150313036, 0.10501668163176094, 0.15176971895354135, 0.26435865461826324, 0.0734845350629517, 0.1366326612021242, 0.11767983463193689, 0.17416936771145888, 0.1392716738794531, 0.12688583135604858, 0.0944227415270039, 0.11950856793139662, 0.15988479421607085, 0.0784046942634242, 0.10151028406939336, 0.11778419331780501, 0.14199582913092204, 0.13301365396806172, 0.1712286647941385, 0.1187797806092671, 0.248776342187609, 0.15845902929348604, 0.1288264143679823, 0.2198588488889592, 0.09337433028434004, 0.17894430006189005, 0.11122569095875535, 0.15569797530770302, 0.14068025829536573, 0.13260228532765592, 0.2188634787287031, 0.188714647931712, 0.15978699017848286, 0.1569859976215022, 0.06672859936952591, 0.10807822485055242, 0.13777996892375605, 0.1902323407786233, 0.1206823792308569, 0.15039421990513802, 0.14288631134799548, 0.059534065425395966, 0.1355373156922204, 0.14409869057791574, 0.19059361996395247, 0.11839479341038636, 0.14515951222607068, 0.12431145592459611, 0.12764836901000567, 0.15666106077177183], [0.059219849428960254, 0.03945063666573592, 0.061802150149430544, 0.017335392468209778, 0.049134888619716675, 0.03350325347855687, 0.037337285067353926, 0.03369670720504863, 0.11653406039944716, 0.039895904915673394, 0.05448333912396005, 0.04710836914767112, 0.04875618465510862, 0.024425370951316187, 0.018656668086935366, 0.025412293350590125, 0.03801767248660326, 0.04655540381957378, 0.0360164080879518, 0.05151772040075489, 0.04751162929460406, 0.05203977167340262, 0.026270460337400436, 0.050092308316379786, 0.07049765783761229, 0.009688798138605697, 0.03706237660454852, 0.013660033749017333, 0.017273316692028726, 0.049846173131040165, 0.049415652839733024, 0.03181311434933117, 0.02533113886602223, 0.03902874733986599, 0.0281442585401237, 0.043380263660635264, 0.03129653885428395, 0.0477543412707746, 0.07680554328752415, 0.014105608187881964, 0.03517774559025254, 0.024639051806713854, 0.0903707475268415, 0.026422511553391814, 0.06541867394532476, 0.03828836724694286, 0.03113217731671674, 0.027364799919139062, 0.038127452667270384, 0.06497513595968485, 0.017599698821348802, 0.0461020576102393, 0.0716768159930195, 0.01522588646704597, 0.02978515299037099, 0.05609789963013359, 0.03278054243751934, 0.029791554968271936, 0.02806551455120955, 0.05907611535595996, 0.04014427248122437, 0.024927011890602962, 0.03736826019095523, 0.019323617120140364, 0.047379654233476946, 0.026406983279490044, 0.025818608601444533, 0.032806438726506064, 0.08028711325355939, 0.05435452264334474, 0.0601277496399624, 0.08156923231269632, 0.04548181892771806, 0.032478082060281716, 0.013481404316345496, 0.04770996508055499, 0.011717186974627631, 0.055102325909371884, 0.010584604311069208, 0.0496247569764299, 0.08711831205125366, 0.030428702743457894, 0.019780490015234267, 0.03117691652317132, 0.05633468799559133, 0.0024379330653963344, 0.026742900522159677, 0.023283113226560608, 0.12302059733441897, 0.06167628190347126, 0.10025476358298745, 0.14995641554040567, 0.10669214744120836, 0.05440464263249721, 0.0026037945894391407, 0.014709750323423317, 0.03480866664488401, 0.06227093642311437, 0.03613035786630852, 0.05059821045558367, 0.05641304861221995, 0.03311605764819043, 0.0006054545706969552, 0.0863329688353198, 0.05019864832450237, 0.03607933542558125, 0.03772158016051565, 0.05220668110996485, 0.03339973617611187, 0.026837605351049985, 0.09364754240959883, 0.026120443030127456, 0.040816330883119784, 0.07650519654686962, 0.04296931910461613, 0.07985428255051374, 0.05261498616476144, 0.030656914426279918, 0.04336671331631286, 0.05730566821460213, 0.008999566015388285, 0.04763238138652273, 0.04631987752925072, 0.08011504355818033, 0.02408220186563475, 0.0445055970256882, 0.09437090823692934, 0.030014823523483107, 0.029056918674281666, 0.05746914765664509, 0.01927307983195143, 0.03952952653967908, 0.09263925294258765, 0.038611200638115406, 0.01272474107931235, 0.045868824768279276, 0.06759322261703865, 0.009598043231692697, 0.04291170469618269, 0.021221550813476955, 0.029695857781916857, 0.007403687274615679, 0.059232164839548726, 0.036299503075757196, 0.018255289178341627, 0.03986073983833194, 0.04001346110765423, 0.070487459456282, 0.06340040545910597, 0.04322583248306598, 0.011844335107265838, 0.0170903395462249, 0.029540072926985364, 0.06173397773610694, 0.02202360125790749, 0.05980179498770407, 0.03696115275046655, 0.048958924133330584, 0.029937494280082837, 0.013899053646517652, 0.04287273303738662, 0.03940790253026145, 0.01534032987962876, 0.011245764592396361, 0.02204180635245783, 0.04363331651049001, 0.035380491853824685, 0.021543783701157997, 0.028379460829975348, 0.011717840912751853, 0.05152176446946604, 0.005116324946616909, 0.036711892911366055, 0.04525668440120561, 0.04036227221201573, 0.061439262836107185, 0.05201880154865129, 0.052676237520894835, 0.07354491110891104, 0.0601370387843677, 0.011916965495661964, 0.06920993407922131, 0.06295169703662395, 0.04864172936816301, 0.019494392509971346, 0.008956442570446857, 0.023982028044494133, 0.08277989484901939, 0.04789870298866715, 0.03640920861757227, 0.058784582785197666, 0.0307858971479748, 0.017134254332631826, 0.0030429738357530107, 0.008862086338922381, 0.02120866034446018, 0.009396280843897589, 0.010729523275845816, 0.022111459668459635, 0.040747568144329956, 0.054767350134040625, 0.013481462839990854, 0.008854353584216108, 0.06300149472164256, 0.06453125870653562, 0.04998358665034175, 0.01573978683778218, 0.021852603647857904, 0.037939050633992465, 0.025017304545534507, 0.0544296500406095, 0.03916938390050616, 0.022966980368697217, 0.023428552118795257, 0.017534550977870822, 0.019477113615721464, 0.05104860503758703, 0.04577256439785872, 0.06654765443610293, 0.03984930652326771, 0.05369706292237554, 0.04326329440144556, 0.07226096000522375, 0.06149930639990738, 0.03879734314978123, 0.08011937261159931, 0.0358755374327302, 0.028570069798401425, 0.07132378100816693, 0.03747694114489215, 0.02578480907582811, 0.03754146982516561, 0.018629692927268997, 0.020566194551065564, 0.03287828879963074, 0.0591278536511319, 0.023827562940173914, 0.011773649569866913, 0.013183796312659979, 0.008417560236661561, 0.008762458738471781, 0.06425063019352299, 0.013749048213607498, 0.015470647618972828, 0.022820935883958424, 0.025707690178283622, 0.12088836889181818, 0.13724098141704286, 0.023437624131994586, 0.03858677677011915, 0.08762350172868796, 0.03331037311415587, 0.0367834071096565, 0.03451069816946983, 0.013831574187081839, 0.06102256091045482, 0.04239960074690836, 0.08538892984922443, 0.050717887069497786, 0.05185666899862034, 0.08265549902405057, 0.024011686810159256, 0.08382151395614658, 0.02441079432277807, 0.046608017424919775, 0.02053518041170069, 0.009121539470340525, 0.07777668296226434, 0.036036472368453226, 0.059857272010828765, 0.05052024678194097, 0.023297715300161923, 0.027394986245781183, 0.02157168336478727, 0.03142496517726353, 0.08394277494932924, 0.041427144714232, 0.04083994050909366, 0.03993867976324899, 0.047165240560259135, 0.013394285508963679, 0.086319805255958, 0.07066541883562293, 0.027744294377043843, 0.05251775888193931, 0.06255241989025048, 0.02638868149369955, 0.017086951960144297, 0.06150551499532802, 0.03295374528637954, 0.050542709683733325, 0.06111252108322723, 0.013711012084968388, 0.049967732679631026, 0.03314660190205489, 0.03951652241604669, 0.041871890492205105, 0.03968629187771252, 0.033510795395289145, 0.035997276793101, 0.06697126384824514, 0.04968932976147958, 0.09869298631591455, 0.03078212110059602, 0.030912087698067938, 0.027370426670781205, 0.009634085315545755, 0.014032250918847109, 0.03889678245676415, 0.012289927357674708, 0.022769299369039278, 0.05674748155953629, 0.03979228583297559, 0.02829564139912171, 0.027518846028085266, 0.019091924552672675, 0.030469285922923257, 0.011803090356157293, 0.05271429655009082, 0.016484251711517572, 0.02430866123177111, 0.024281870972897326, 0.00584019925112703, 0.010467691879187311, 0.013705276767723262, 0.07197297617260899, 0.020185794248910885, 0.036336713936179876, 0.04319036885031632, 0.10306156439972775, 0.05142001135806952, 0.03991493782294648, 0.07438933436891862, 0.016485188089843308, 0.05710754277450698, 0.013821067920486842, 0.04135506733187607, 0.039138605552060265, 0.016740125570712344, 0.005403994956785547, 0.050129346150372706, 0.0031848118274605697, 0.02340457947658641, 0.03448828276512878, 0.04576524979035769, 0.026205833269549266, 0.06292436564607279, 0.06955773077372994, 0.019294280658609102, 0.007686286083688694, 0.023155379009300044, 0.006491093297622034, 0.1454681913767542, 0.1644209229520389, 0.17289354545729502, 0.14534342235752515, 0.17817131296864577, 0.1784790421703032, 0.11618629763168947, 0.12205433632646288, 0.21478107278900488, 0.07548641692847013, 0.13303466141223907, 0.15063334921641008, 0.12784120866230556, 0.15363680305225508, 0.11192353029868432, 0.09029073467744247, 0.09474121193800654, 0.061058618261345794, 0.12502869458070823, 0.14196188880928926, 0.14740250472511562, 0.11393080651760101, 0.08683407373194184, 0.07051031930106026, 0.10705231382910695, 0.11413645691105298, 0.10725647823086806, 0.1259036926286561, 0.15396454903696263, 0.09290168314640011, 0.11898836227399961, 0.12156214059463569, 0.14303107000887394, 0.15035643907529966, 0.1272364439708846, 0.19829915863062653, 0.1058901801173176, 0.1492044630327395, 0.15602653553443296, 0.12546582041042192, 0.23811362577336176, 0.1783645868833576, 0.1805025828736169, 0.14707085037870066, 0.16566135281963007, 0.1970274890107768, 0.1382429605083806, 0.11248111645025866, 0.10448154141860348, 0.22584051505795547, 0.11982619017362595, 0.11004748275237423, 0.217526303338153, 0.11699220724403858, 0.3123600131699017, 0.1269225808126586, 0.12942575077925408, 0.15644182610724652, 0.11817209821726594, 0.12652181088924408, 0.0911691796832851, 0.08074120245873928, 0.09322628072862114, 0.1547581228826727, 0.15701886585780553, 0.11083330772817135, 0.10339376157415764, 0.11621423970375742, 0.14635458881301538, 0.16766194546861307, 0.2212451095027583, 0.2041537623320307, 0.16445969444300446, 0.12398791685700417, 0.1439163275063038, 0.17151002612497124, 0.0726018152864916, 0.1273975417550121, 0.0963058051254068, 0.12753299091543469, 0.10422361668731485, 0.1613748978291239, 0.22381124751908438, 0.14565552132470266, 0.20980530764375413, 0.11889076179691724, 0.13191879700337136, 0.12095200190586702, 0.30211956266845974, 0.12663889889206204, 0.1508249675056764, 0.3174592852592468, 0.13427191573594296, 0.13808805096362317, 0.18558966847402708, 0.09007315563836268, 0.07186730112880468, 0.11617155985108443, 0.22357627084212645, 0.17939578369259834, 0.16466294282249042, 0.15881025258983883, 0.17243051316056932, 0.12939204115952763, 0.10172029744301524, 0.16051144844719342, 0.15332152854119027, 0.19808007324380533, 0.12916553259960242, 0.12105790765157767, 0.16173899972013064, 0.14975276003990853, 0.13839420596403734, 0.15618745689945562, 0.1403376388230494, 0.2780975502516542, 0.1494269139532532, 0.12308883081589427, 0.12996646176491464, 0.1341171283274889, 0.17181270702608994, 0.15386289092046873, 0.13898957973080023, 0.13859383096652372, 0.15369530634156295, 0.10142355372330972, 0.25248168621744427, 0.11884861120155879, 0.08814646902361087, 0.11142665267522846, 0.19655950340841497, 0.08509703086955206, 0.28139498616967884, 0.14017545538289206, 0.1107762022210019, 0.15237962694040366, 0.11491044823612485, 0.1720501942826169, 0.10863914260906832, 0.10972312265740973, 0.09915986590619598, 0.05708766169846058, 0.13645219802856445, 0.20467038532452925, 0.1393807144569499, 0.10680613453899111, 0.15317147730716638, 0.13813611838434423, 0.10158089242343392, 0.13324362305658205, 0.153942876628467, 0.08819016667881183, 0.08592077238219124, 0.1479630967868226, 0.15541231206485204, 0.1730385348200798, 0.14205442741513252, 0.08315175918063947, 0.10377885055329118, 0.12031150556036405, 0.13652002438902855, 0.15743308434528963, 0.08072457156543221, 0.06220633988933904, 0.13972843651260647, 0.10879224725067616, 0.10645019542425871, 0.1054269103333354, 0.13757819975061075, 0.1705609049115862, 0.18022849543818406, 0.14645437417285784, 0.09893980342894793, 0.14336269721388817, 0.10661674862993614, 0.1938737803804023], [0.024883354947503124, 0.03384845816929426, 0.017236102438930954, 0.03178980327876551, 0.03690911929256149, 0.0413707652395325, 0.006174675879135195, 0.022921642355088676, 0.005376342534353691, 0.027592222805001905, 0.019626557560903684, 0.01578016815307949, 0.01998403186111578, 0.022695998927312236, 0.04191304364108613, 0.01178193448244461, 0.018574266794270704, 0.029950505189065422, 0.05490154739735382, 0.042710108549467156, 0.023990073773477758, 0.020394087536260486, 0.07831786213708775, 0.040561666512595754, 0.05411287935982857, 0.023303521863584007, 0.025199482716353874, 0.040315158132995875, 0.010509697437685515, 0.031275371954377205, 0.02286808388972921, 0.03175051610118576, 0.031939420250377486, 0.014044294067259346, 0.03642520508063691, 0.005420369279038693, 0.07023947526301656, 0.034458128668900044, 0.04538627101906708, 0.04561562603339553, 0.06369008562926735, 0.03183141443878412, 0.06741320727659122, 0.0531970097550324, 0.03808071856786098, 0.05665161134675145, 0.03663658570232136, 0.05991010953273092, 0.06559777326349701, 0.04675865898440991, 0.06828858530414955, 0.06884722997035299, 0.03949428003813539, 0.020481489632012587, 0.05000621918588877, 0.02134274734583284, 0.04980197335992541, 0.05339612585625478, 0.038757713312017064, 0.04486805346927472, 0.02453096117824316, 0.029283925957445587, 0.018047313106113246, 0.020504262963575975, 0.03222201651494418, 0.02482114516065589, 0.039667391284768067, 0.09094771263854844, 0.11794886019613061, 0.008330131847677487, 0.009786305317123021, 0.021032862099153653, 0.027698040341160128, 0.03529884373503072, 0.0630125141303454, 0.0531888300153826, 0.05688503757119179, 0.02280536520161799, 0.027014686027541757, 0.0700799652508327, 0.05873763494725738, 0.03666027335982237, 0.08085789691124644, 0.03614234079473785, 0.02618090558930167, 0.045395149649786096, 0.007089590021808232, 0.039720201665269475, 0.07530346353139196, 0.07347807540957417, 0.08798589371144772, 0.13129793746130808, 0.03587385805855904, 0.053269752101706605, 0.04041571363008448, 0.028740836706544672, 0.030289491106356894, 0.025552108883857727, 0.01945024702165808, 0.06815814373216458, 0.05316698118778212, 0.00762378198227712, 0.01807264281835939, 0.040781762916594744, 0.010374780927252556, 0.051075892323361974, 0.04667790653184056, 0.07425953740520136, 0.01861171344561236, 0.051844743745667596, 0.06990330865872757, 0.0065688898820163944, 0.0761855590556349, 0.05160951940342784, 0.09214197498347078, 0.04720448024038758, 0.028235918443117822, 0.03709036956674286, 0.08523214754781552, 0.014397215397496308, 0.07274997340781347, 0.08722585985170943, 0.010958331221315478, 0.0038100072082930376, 0.005909788954470838, 0.07717051370335476, 0.07257410391633, 0.04825670824253133, 0.05836648986275707, 0.03958082039441381, 0.0196795138264341, 0.049610212578305175, 0.026538208559421555, 0.007389626332691738, 0.05691819079220295, 0.005393243145330676, 0.005309754076214241, 0.02928940512772117, 0.021239384410104582, 0.018478422026549066, 0.011037449252658656, 0.03428988930370126, 0.09278699715754815, 0.07324280017720801, 0.006402514367696962, 0.013405477944096285, 0.05344331796680178, 0.03816787639100637, 0.033813808778566976, 0.022771511393200074, 0.10463035093354327, 0.027275501318009834, 0.0252957854952131, 0.03418040428576725, 0.03684487559699586, 0.018723149251724993, 0.015782202061797892, 0.019522232801786492, 0.0334582564287952, 0.013893496444714921, 0.047488844088677845, 0.013937485021805125, 0.022786886996722648, 0.016846375672944953, 0.07745092508516141, 0.04706156040940966, 0.03498039707275374, 0.011002815128969294, 0.028704253491014242, 0.013578114216215909, 0.04287462954276374, 0.03001937988613333, 0.013482388192122536, 0.04707169432991317, 0.023542992138702954, 0.03089673923594611, 0.024819048487448266, 0.015600034069003803, 0.04890221556914704, 0.03404128425089376, 0.014432814737249697, 0.02605150217589523, 0.04264937966529812, 0.0017509500737235481, 0.044398001727781126, 0.021702640623386418, 0.06529631372541189, 0.014623768062197735, 0.03470209254217999, 0.05907779812280621, 0.022987327937568938, 0.04215475817077926, 0.03222406569070049, 0.010918217079181756, 0.06103270500898361, 0.013831407097833497, 0.038635332736053636, 0.03175449910174523, 0.03134988867012518, 0.014465487894735165, 0.021909514076209495, 0.04070621482761843, 0.020454134492735778, 0.022758225677534938, 0.05115284497982689, 0.04285489095907126, 0.04528266889974475, 0.028110815245392065, 0.06172583531588316, 0.058261873333581855, 0.06083945823567254, 0.01050483827878322, 0.05165766824835113, 0.035258593037724495, 0.10487060661294631, 0.04288009514233895, 0.038174071415726624, 0.07202566441680704, 0.08552306265171085, 0.0327844813333026, 0.03477400368345635, 0.02785149442830256, 0.07616053468414716, 0.057589187286794186, 0.017816277021276097, 0.028801270427980592, 0.03442461921700409, 0.07684722569371973, 0.05439522456643837, 0.023150756489485502, 0.023587420915386507, 0.04919191270268389, 0.031207582913339138, 0.06917956285178661, 0.014864681920568858, 0.06572060167257275, 0.09922328857438904, 0.016547078965231776, 0.0409716000514371, 0.04827456728422216, 0.0063747567723372155, 0.04875128563227398, 0.03096216358244419, 0.057248840906790326, 0.03662995302251407, 0.06316850933113269, 0.006977431575900742, 0.014161300645875079, 0.08191312064549752, 0.02208184331123318, 0.05319589695760182, 0.058448612956064086, 0.018815375731459687, 0.09829081182501145, 0.040677896168615134, 0.019376987292032157, 0.029203159934175865, 0.03416474709021194, 0.051790674682706594, 0.02369034449969019, 0.09247438250375645, 0.03668759117967316, 0.009067331307700701, 0.034480242125157795, 0.06330543091254574, 0.03318448790482112, 0.06325276980974845, 0.03287232108414173, 0.041268778033554554, 0.051100536715239286, 0.025330367032438517, 0.013931515609978564, 0.06639513333461114, 0.05785524765295642, 0.025526802920337235, 0.05305302123140011, 0.07865935524127313, 0.03317439130374363, 0.03040583272065435, 0.03409037286681788, 0.0865212758736951, 0.05227994253592832, 0.02168744313530624, 0.028111821173557212, 0.017466806041608964, 0.0107502024787079, 0.10039570887706109, 0.010142898369979645, 0.05691461151997958, 0.03371648650084223, 0.02655040013736912, 0.020381587224879434, 0.03668092118043985, 0.03219727712816425, 0.045365592664373774, 0.026595831449542726, 0.03929308422708085, 0.044488894886204174, 0.03756242637921657, 0.038622104695865085, 0.03802544849791697, 0.03921317315793463, 0.0283130661784006, 0.03875974213172283, 0.0444941026424723, 0.02918975886755756, 0.017936757699187313, 0.022805828301768218, 0.068088553180652, 0.04490923715223159, 0.0495224983564445, 0.05225415141986949, 0.047427148292107243, 0.038693975125040324, 0.049077155467654975, 0.043404779130859036, 0.053879154579980035, 0.01657932803833059, 0.009388005261176398, 0.01997844921424985, 0.06130644639155694, 0.021999905118718743, 0.027648585316325937, 0.013107495897981738, 0.02792026904145522, 0.043061864495809586, 0.036106724491608996, 0.02784638336327459, 0.011473568306038422, 0.04549737095034548, 0.029610803417329277, 0.07471917702683381, 0.02713451361549752, 0.02503899561374315, 0.06094150311712708, 0.009521220345050097, 0.06659641396254301, 0.0012723698891932145, 0.016156261454203298, 0.021712170647723333, 0.043263063699539216, 0.07416792160698346, 0.023126095134232725, 0.0339814713889999, 0.02144201871539865, 0.030209379869380167, 0.012586353862259005, 0.048306458430098634, 0.027006979566067457, 0.07117652533841984, 0.037362387470368824, 0.009831889299675822, 0.09425373880990914, 0.09758043994328805, 0.07498928824705736, 0.12675335417900765, 0.12380657158792019, 0.10334615555724927, 0.14321582152375154, 0.08415893585022007, 0.08722455706447363, 0.09385650405394179, 0.1657759438135794, 0.1240579823830298, 0.11467214673757553, 0.15782592897968634, 0.0982760808297566, 0.06830956560692616, 0.11356443153428179, 0.20461143420210906, 0.09832037559577397, 0.12465616528476987, 0.18491702313934053, 0.12208070419728756, 0.22528090008667537, 0.2301419521016734, 0.10724714837436165, 0.09132519524012293, 0.10310734515743596, 0.17343311650412424, 0.10920972949159996, 0.17427456778075012, 0.11476445464151246, 0.10269419875528131, 0.15295316545026644, 0.10385593891675983, 0.20251063550157206, 0.10033649312598364, 0.16883004350321634, 0.15471996207322392, 0.1881650345666068, 0.10074662683265549, 0.1287831916872944, 0.15793065407446452, 0.22559739596077374, 0.17416494366313728, 0.10685359806354557, 0.1533746306917497, 0.16325266206903116, 0.21761656206633362, 0.16209007373877934, 0.1071982259995171, 0.13994663980390343, 0.1282361296138593, 0.3285680705947535, 0.11276160247091736, 0.12124730034598283, 0.08509928360581398, 0.16992879525891372, 0.16555552849812166, 0.14340468496084213, 0.16993491564478191, 0.1858520715364388, 0.18399728249226296, 0.0772318939811417, 0.10537206434777804, 0.07695914325969559, 0.24992548195379122, 0.13822698779404163, 0.15029675513505936, 0.30117829889059067, 0.06354570016264915, 0.0672985619998404, 0.07132209824132067, 0.1630934506122555, 0.13196318676429136, 0.12905187798397882, 0.12495948400880609, 0.05834943149238825, 0.1853575145027467, 0.08753922767937183, 0.23127817256110056, 0.15170152618416718, 0.1085241377087576, 0.19640234112739563, 0.07546540269894259, 0.1605035231581756, 0.13835770078003407, 0.07246405232165541, 0.10927370177315814, 0.17453866718070848, 0.24099297555429594, 0.2602132127753326, 0.2623019606939384, 0.09080327967447893, 0.1631320456841162, 0.08912548648991755, 0.11393426704619612, 0.15955696680716105, 0.17429744798157895, 0.14213499666324683, 0.11762647463807038, 0.16886302030512265, 0.12073179015091487, 0.09231513033487967, 0.12591093938265527, 0.1655686106532812, 0.22389971491481575, 0.1625061378415142, 0.24488692517791474, 0.17689128379736627, 0.14388591556676797, 0.30494321829506327, 0.15091013722121716, 0.1414002925157547, 0.1380032476569925, 0.1611216821308647, 0.18338737450540066, 0.14387751530323709, 0.11642617333148207, 0.15751150942274503, 0.11576340746666704, 0.23460597970655986, 0.22797726254378045, 0.16090436093509197, 0.11834114843181201, 0.0996984870039991, 0.2230151088110038, 0.13401834719947406, 0.06697203059281621, 0.13948377035558224, 0.15585905952113016, 0.1010244529960411, 0.09712549578398466, 0.08713131956756115, 0.14855283871293068, 0.16647801042667457, 0.1288698406091758, 0.09995715133845806, 0.14022777043282986, 0.10374193824827671, 0.09487651182072503, 0.1462953934179885, 0.0748655234596559, 0.11920686412070479, 0.211676652942385, 0.17964921652206353, 0.11723775549658708, 0.11224438236760241, 0.15921172818967275, 0.11074905403490577, 0.12057597136923245, 0.2132157196423837, 0.12245696543582849, 0.10354048120123999, 0.09553710637348038, 0.1279034981770175, 0.16979772943471158, 0.14919195084699563, 0.12232716168676104, 0.19740206748247147, 0.11144567879715137, 0.15628463668482645, 0.08152595534920692, 0.13016220554709435, 0.10617813002318144, 0.20565124840608665, 0.17324049398303032, 0.11258399592978613, 0.11971345836562769, 0.12965383354042256, 0.06744694403771843, 0.0868405673120703, 0.09985525573470763, 0.06538979549493108, 0.1409952478217227, 0.11239810447607722, 0.09467901063284703], [0.038109607196279933, 0.047754154673644474, 0.007287802823287035, 0.06720409635454416, 0.05492419011092611, 0.010870327773903097, 0.10732395853847265, 0.03274182862203036, 0.06626923116190092, 0.04544779039653284, 0.020819160887705426, 0.0578274412878922, 0.048596783208527734, 0.028291230921500495, 0.04094896751589008, 0.012268377933651209, 0.10034014364438397, 0.05145331046410969, 0.035816023126244545, 0.02268194137806339, 0.03500859698812876, 0.01983035894642983, 0.031134236670498337, 0.08712507026003939, 0.04229230061173439, 0.03849525935947895, 0.008528366701544395, 0.07444640594933714, 0.04058679944968649, 0.028271061468071172, 0.0687217213479536, 0.002407029824098572, 0.05026876134797931, 0.05317059438675642, 0.027233381256727234, 0.02199325886821108, 0.03823693429252931, 0.014563975556354438, 0.04293297676901732, 0.028788924483316283, 0.03214754729664751, 0.05692169203289917, 0.042824390809983015, 0.022532628050872257, 0.021606502389269214, 0.04033259987565024, 0.08809927012771368, 0.02536576790069895, 0.02599377411284617, 0.02324293038275625, 0.021086814114823937, 0.011345331124695284, 0.06593786180019379, 0.04604818532243371, 0.003825272125790694, 0.0488044895630862, 0.02055448473298124, 0.07174878141709737, 0.08659219635384423, 0.04311107185536197, 0.04690383494432483, 0.03247053675087435, 0.035371640364506414, 0.06573103754115955, 0.04710131577615227, 0.07420073556048529, 0.021419666075546826, 0.025669254562152282, 0.028574113867112567, 0.04704193378399525, 0.025025957563359822, 0.01947583118453622, 0.06837302220187016, 0.01509041864691036, 0.04195907884942634, 0.09643421787768602, 0.04353595691333924, 0.07429909599678856, 0.0463027207713042, 0.032276336635862074, 0.05875229808901038, 0.02267715092083173, 0.11462361791304179, 0.05152335224140968, 0.01876089785114995, 0.04090788561318602, 0.054547742275255065, 0.03258242717544947, 0.06079176400921174, 0.03352210657405002, 0.03626708606524127, 0.04245955949383123, 0.07849206243242536, 0.01609654019453696, 0.030906065699777434, 0.010489388884577368, 0.06468677214745965, 0.0774960612346019, 0.04676445367346917, 0.07160898284720522, 0.054707408350493224, 0.011250090253140246, 0.012642085336015692, 0.017705847143328617, 0.04174788482487202, 0.03964812767558864, 0.0028628204558377285, 0.07307750904666525, 0.05158531266663756, 0.07065055891871452, 0.0838073461449572, 0.013178906619681843, 0.023391911227788244, 0.011495753856641906, 0.07838374110204832, 0.037517999298870564, 0.031161004876984016, 0.029396647587418556, 0.05036598863080144, 0.037865103887660165, 0.01566794015733259, 0.020725453505292535, 0.04251786940065878, 0.0633128812270505, 0.0047009130856687465, 0.04693460990009563, 0.019639600700299655, 0.04767059647877302, 0.02577619337742882, 0.025137225432055335, 0.021214056394195983, 0.047800043996955664, 0.034039496311119626, 0.027275204458939176, 0.0901807780776705, 0.06391165445425681, 0.04802329558879137, 0.028140024481607333, 0.01703630101733974, 0.03833868061857564, 0.032505189534276724, 0.017569125729746053, 0.03116800735837647, 0.06881625484675169, 0.024520209790872674, 0.018147831283775822, 0.009845504952993776, 0.06324707690094199, 0.06329165665166718, 0.03236427138160382, 0.029633412204150642, 0.07607049308717251, 0.028709800514791693, 0.05075123367298927, 0.004741280830265688, 0.016296699543350508, 0.041387647190796475, 0.05843342734234674, 0.02322761924006045, 0.027274302007364373, 0.05119108721347792, 0.023126610820846896, 0.014624553466481822, 0.04417702662093299, 0.039801354453499825, 0.043590633265141926, 0.025841945117073398, 0.05516821505235774, 0.015772911221055046, 0.005142739042639732, 0.04037519830412098, 0.053605891564594846, 0.023919501042525684, 0.06851341788257871, 0.011508276220411062, 0.0006503082269253874, 0.004332575015723705, 0.019069573609158397, 0.03753374809665339, 0.0367887302168778, 0.04298784989597542, 0.055660997716976066, 0.028888136481067965, 0.07340608284409557, 0.07858533385608878, 0.015254205126049263, 0.06545458880386182, 0.005517648724240384, 0.024574619817680547, 0.030386860881532942, 0.05980047184441771, 0.031354804656335285, 0.05169475018712027, 0.04898952945534672, 0.02821899238707764, 0.021869416049282466, 0.08159952890127897, 0.01915719622879156, 0.002944628454445462, 0.04169235351894583, 0.017537994543090463, 0.04259284073486924, 0.021236249578318427, 0.034532550389745405, 0.04147387542096632, 0.005117602712873901, 0.04125544821311321, 0.03405808817063059, 0.04946422916171806, 0.027512425390471305, 0.029113416892609427, 0.06953294388949871, 0.04243922719199743, 0.03932703472673893, 0.09432769912694182, 0.006023694203966963, 0.022142310959420035, 0.012176497506776025, 0.053156684418874126, 0.027449642241533314, 0.03574078716337681, 0.02950130482869489, 0.0460564736276865, 0.019714734882914593, 0.03645828366279602, 0.03573800177712526, 0.04183486962158765, 0.02518413764690714, 0.036875138258827586, 0.025087585506428565, 0.041493118674095185, 0.0647611395855035, 0.043186460488608906, 0.029996981445167745, 0.028174432992402996, 0.06738804719809975, 0.04334643529728055, 0.02147411342178072, 0.05049582291394472, 0.04213453443454845, 0.024403729076896395, 0.04771082003467849, 0.058424586031053743, 0.04793314203353865, 0.0402717692112284, 0.019738977242793356, 0.049811547489038537, 0.008908360730856657, 0.06579791395259754, 0.061133487815303464, 0.015469587408006191, 0.10160277517778532, 0.05581747467762657, 0.07051019037940673, 0.01861949115326362, 0.03575863941971745, 0.047096752628151856, 0.03564180247485638, 0.057373284229210446, 0.07033400876181466, 0.031101470214447806, 0.019768768322787116, 0.043820833055568595, 0.013925643737560936, 0.03444409995738949, 0.039084183650889566, 0.02990485674568585, 0.06859276576765946, 0.037390210798808506, 0.07068767478423459, 0.013523145246186426, 0.03562917833083442, 0.040229306489761384, 0.0350533090531826, 0.034814081354332824, 0.02806626263606761, 0.053416213885481865, 0.026830093968393545, 0.06239034501569612, 0.011941150180064142, 0.04054329517696585, 0.053034392052463124, 0.09538988463048424, 0.030652341100254228, 0.10334660339036159, 0.020101062188457166, 0.05763877462595701, 0.020354985259473324, 0.01768731974464442, 0.03788323434335845, 0.050817580827112706, 0.029124256489532332, 0.01939080565768693, 0.06951125112495252, 0.041282436943479946, 0.03428318877039211, 0.006509113491379789, 0.011323899596131273, 0.027858254333425845, 0.06286249682307243, 0.037364487536251545, 0.02357208602396505, 0.02691676833533815, 0.056221454071679285, 0.020760189409234693, 0.03433062515354582, 0.11191308085939713, 0.04027004912495613, 0.008210886103500212, 0.05068343445392592, 0.0366838049542691, 0.009323812455737164, 0.0009255789108075467, 0.01620174026382821, 0.034156438428908587, 0.04852945896397744, 0.05408444534987211, 0.04198358753429992, 0.019598822442016432, 0.028438520517998507, 0.05277217558718153, 0.036038664036563466, 0.07292388871844326, 0.08549990425152437, 0.03314762309725795, 0.02933403237589768, 0.019021036302936927, 0.03134080647890057, 0.013439671020023525, 0.04078105045482516, 0.009967597999743052, 0.10711335483938456, 0.047693245977695496, 0.02799809700809419, 0.038659410551190376, 0.022429366895396794, 0.0483022582983332, 0.015602827936943089, 0.04578100537349071, 0.05177514980147992, 0.03989430357302938, 0.037230500618794134, 0.0670376584998199, 0.04604998683290822, 0.03781659881185208, 0.0322266746578472, 0.04122129754562463, 0.026420998420300226, 0.05639526420938117, 0.02364887752836304, 0.023380917264148593, 0.025443550066224167, 0.15935986595494406, 0.20914312531905516, 0.13798464222678117, 0.1379689680678504, 0.13374805956014565, 0.11779758759907313, 0.18785008575235093, 0.15815245360136032, 0.16620888986757823, 0.21186715843422071, 0.09368214769554989, 0.11248838356030838, 0.11935380766434328, 0.08329600215490375, 0.15023724761392387, 0.08009664168847458, 0.1580121868423053, 0.13817100865500315, 0.08786322815077645, 0.10140228843582527, 0.17750253528356552, 0.1359105370938778, 0.07495520543307066, 0.18996863492897578, 0.13680152142686502, 0.16497728095522948, 0.13432047170187744, 0.14809561467596463, 0.11983528254287583, 0.046792629840118546, 0.1029448156644191, 0.08886532259306737, 0.18707433023623057, 0.07866420676665646, 0.11481089357818876, 0.18757758608886174, 0.10776891466230154, 0.15884738202605928, 0.19956377148628235, 0.1078670308259981, 0.13461625868720667, 0.1539645761783634, 0.09835612760590655, 0.08694504813424178, 0.09416846731411559, 0.06479092727282218, 0.23370227962732315, 0.16627447706248077, 0.07679551453994853, 0.1168594586529902, 0.10153047727154833, 0.09443929778145892, 0.13356968627444335, 0.12083613526608263, 0.07361733115145139, 0.14539040412221635, 0.0759907720078315, 0.13584123152707303, 0.15394413870360169, 0.15432297837521347, 0.131018530311329, 0.0901623083544629, 0.17479067508663448, 0.17228069262845175, 0.10923931361841303, 0.23133641800710134, 0.18391961737402848, 0.185520132205316, 0.2006219739892653, 0.16445085991706165, 0.1508873655859913, 0.18949184194207191, 0.1891585998237133, 0.1495718897453376, 0.20789102464914322, 0.20251554809510708, 0.1566765992236989, 0.10745486829962049, 0.10353562967585665, 0.14803797991148063, 0.21792325989476272, 0.15560015769941465, 0.17820988089910575, 0.1412903562720333, 0.13004358405513422, 0.11370939375566584, 0.13810296516333306, 0.19239051640033722, 0.1213019359856844, 0.10636501892336778, 0.17809968681207725, 0.17060186128531182, 0.23018244707158633, 0.16736348505531037, 0.10111653019807168, 0.14029157986598356, 0.1582945388342653, 0.13939423087452138, 0.09185232195471014, 0.09804813377559185, 0.15239388974649565, 0.07431024432714496, 0.08494877775332757, 0.13737366215458938, 0.1702172133539404, 0.2084339883710657, 0.1769431917262929, 0.12738847652716295, 0.2030180711299181, 0.1075579784810543, 0.24006023417626107, 0.13214692047664098, 0.1794345551835639, 0.09159844129213265, 0.1351020626191582, 0.15320296133203165, 0.2283032579081399, 0.15565783317599977, 0.18747423163482121, 0.10306598844804934, 0.0923334914924843, 0.048397025891712735, 0.11876359076372214, 0.14811723280165875, 0.14846472415540898, 0.20467824276004518, 0.10697475049112525, 0.12335706927946635, 0.08398102396833045, 0.10253042075783014, 0.10454670792179448, 0.11290615757129022, 0.12546932165111813, 0.10690829477139882, 0.1393444671162537, 0.17805228435567447, 0.17939040969525064, 0.15181286021002702, 0.10064228171748774, 0.147462663639869, 0.13392867201140948, 0.13089116928832872, 0.10993774328380823, 0.16225981605904444, 0.08739694567131144, 0.2443592149232115, 0.1162253405366625, 0.15010251770062105, 0.1524539672370468, 0.10258234225745712, 0.08739821453179632, 0.13825589338583605, 0.05463808582031301, 0.10628811376435415, 0.11140966894371168, 0.36053228112203733, 0.1410413339201893, 0.11222709329532725, 0.09589604461299521, 0.07012803267155375, 0.18760685808956623, 0.19156419645462716, 0.1649030763655901, 0.1534973912473236, 0.0790033114275762, 0.1824421752244234, 0.11046763163592134, 0.1799518024282796, 0.14788418316415378, 0.11537115994308676, 0.1693686374596187, 0.14120914920100144, 0.16931385254221304, 0.136938694066235, 0.11945138100002493, 0.07712825454239335], [0.044943265683416805, 0.06231109891086817, 0.024703300591292124, 0.11003314530743019, 0.017140303472323076, 0.016193909969713007, 0.01179677149879613, 0.05263153563386627, 0.03714733597423349, 0.03550703863480261, 0.06864922666656119, 0.01673517226507621, 0.052789284847676754, 0.016144660201721957, 0.026094568793528845, 0.023446233045043688, 0.012713979513916587, 0.025684182332562547, 0.08090039355946438, 0.06222873833030462, 0.01861945553017514, 0.036596636953098435, 0.019517993654257486, 0.043812001922300885, 0.08437053021043539, 0.06012706431959357, 0.03649410352643047, 0.0810839304966586, 0.009517869230226746, 0.029697218244629245, 0.024531746582527245, 0.019723367544689348, 0.06753557428185429, 0.022951754042878747, 0.09866855226989303, 0.025955849094316363, 0.07641733983265502, 0.025284759301160063, 0.01255007938016206, 0.022928174950980713, 0.0022271067220052438, 0.07500907432820116, 0.03587170370987483, 0.11542789904134614, 0.042178808844515255, 0.01778850967197546, 0.025219993133630072, 0.0176176477689296, 0.008044075054515685, 0.056047983201486726, 0.041399847250431776, 0.025599991403786198, 0.046506321988999844, 0.041011284172002754, 0.07746454328298569, 0.03279064582394702, 0.0313173970207572, 0.07715381495654583, 0.09142385423183441, 0.09982132219842502, 0.03181447141936847, 0.03024745246927653, 0.03152585315651127, 0.034722319671085904, 0.009871603954317314, 0.031778475136629174, 0.08053797443530389, 0.022963511358414377, 0.04744167233418141, 0.04886843470324363, 0.05395052628591657, 0.01417416991067252, 0.046777288163346906, 0.04280472347246749, 0.03572187978508217, 0.02320787726369287, 0.017777427498783385, 0.043069684611899514, 0.027947892202064395, 0.0402015374441232, 0.024892328573124747, 0.03309929444055472, 0.0172167251751359, 0.10947401888136353, 0.01777698814735881, 0.038530644960701466, 0.018151848211086223, 0.07168607121067387, 0.07537999549614531, 0.07356244445379291, 0.037289634945669344, 0.03334400470235518, 0.02553990712788488, 0.0029656335661586907, 0.023486297145219784, 0.020861342017139708, 0.004073040036018938, 0.02546957358052688, 0.07148396955536944, 0.06893784832209349, 0.08765377117586987, 0.04612937882276518, 0.025090311520865986, 0.05532058348347034, 0.018835244933143258, 0.04622768497626696, 0.025649795874154994, 0.02178422428135361, 0.08309574611485004, 0.030810914734112363, 0.07388573246342794, 0.08850565832108259, 0.0783052888831922, 0.053848284629306624, 0.06249737034418753, 0.03769768215715885, 0.024976936800937568, 0.019243704354656593, 0.01653650399696614, 0.010381820728071034, 0.03637974323438747, 0.04779550459768091, 0.04267593413325293, 0.04403776070103049, 0.042566191272011826, 0.07012719128813062, 0.0609782390030367, 0.0358834695070982, 0.04269222575905068, 0.02895850734785199, 0.05638244329020381, 0.044190641426082165, 0.07123758670474802, 0.047177084389009645, 0.030417961534112692, 0.00945996050722897, 0.005585331320097404, 0.0010672592491443667, 0.04644650912710598, 0.023837527226922766, 0.08095859150801386, 0.03252509096637368, 0.029995549736278396, 0.03285570376153503, 0.024968253249036412, 0.04170132714456745, 0.019897852824734788, 0.007586090210159975, 0.026292219259110943, 0.06510948589337723, 0.02485903285975967, 0.03542462716411267, 0.030937067964779477, 0.023143022886610458, 0.018784621131739447, 0.024451611596824865, 0.05138998618349433, 0.01764186129107007, 0.06091309964124646, 0.07397628296166658, 0.04637156832697136, 0.04573185229673982, 0.033764869440346956, 0.03591848530673555, 0.017392728677285568, 0.03905014833435416, 0.03157371362405164, 0.047175890167376826, 0.034025107976049185, 0.04357100663972752, 0.07651597168296576, 0.057717803599578996, 0.045093846174755266, 0.059260710807783265, 0.04159486839281661, 0.012304898384692413, 0.02279437463065343, 0.07403293385037354, 0.023840931776378835, 0.008476761568869864, 0.042314105334558656, 0.002530536344108571, 0.01485031224521143, 0.05258366838097572, 0.03437655179628304, 0.012432509617480849, 0.062268704042903016, 0.06197253707796335, 0.011854830347666783, 0.01970105561693864, 0.0322628202182906, 0.00821072155875819, 0.05543636191370232, 0.013761813153645821, 0.03368796088865825, 0.04964101806815181, 0.006207892288719969, 0.04056012284542833, 0.0122470956827913, 0.03237464618203895, 0.05226913347308125, 0.061058597905295234, 0.01631677569821477, 0.026782370904194455, 0.018310552462935448, 0.02662710003953959, 0.037847611254879406, 0.0010212918943060295, 0.048258570821157525, 0.04825459799862333, 0.04562893889046141, 0.01914470609543579, 0.029056331741490533, 0.07897478581539222, 0.025691172939592173, 0.006828058028726706, 0.009154567162373235, 0.03650243254378438, 0.02275821889218475, 0.038774832750537565, 0.03282842665378537, 0.03992976042042885, 0.03199188118534429, 0.022632689913734794, 0.028127539437264204, 0.02954970473157508, 0.03362144749345524, 0.05649283075971263, 0.033549186906644275, 0.06311331729271583, 0.027445158821397593, 0.02097864036581346, 0.028871095074074607, 0.04209927775497947, 0.022304781080622758, 0.08132052208696093, 0.02480210716437016, 0.02654071744265301, 0.05331952943067465, 0.03464165882074407, 0.046554742247930596, 0.0679003954199808, 0.07737194360899073, 0.03291959461889096, 0.06061533133366278, 0.021647105924785137, 0.03353473750342216, 0.051655703889472146, 0.019640854293746606, 0.07414964865893126, 0.028851753433368037, 0.018105670510392104, 0.006902489927597344, 0.015805151812466126, 0.024869404267519712, 0.032030995336494276, 0.04399289596559746, 0.057690037946615896, 0.10885980898248297, 0.04237231346113341, 0.05399993381329945, 0.0298402194998094, 0.048045232625944276, 0.03441041408638869, 0.05609942294125046, 0.014173091888161642, 0.016662667405658534, 0.031179630663245916, 0.04461140438382115, 0.014269869641533919, 0.03484218627480524, 0.10836648009717464, 0.047988446030233584, 0.007343549564081643, 0.02800152700261346, 0.022573637011061822, 0.03676308159317289, 0.005848451085122568, 0.04193562528650675, 0.04246461118704506, 0.04109615193946021, 0.040906918700784445, 0.0891082856271948, 0.049199732818773816, 0.026835663044559102, 0.05572981473856738, 0.05716488576893296, 0.07252267774726663, 0.05034609737672976, 0.0280237965219255, 0.04865600574495537, 0.05691694228776863, 0.03864938519628985, 0.08124541504574673, 0.004313135411523814, 0.018951584851103168, 0.02957763323294265, 0.02718696097976395, 0.040325858630239964, 0.006145279621705413, 0.06589672222201313, 0.05436848350135343, 0.034448720780866485, 0.06488926735307489, 0.04611702609275069, 0.04996660631150007, 0.012917326280980237, 0.0747463387836303, 0.0502803100139967, 0.01088647690734693, 0.05522270141435521, 0.03280530557302492, 0.034974649881145785, 0.04214168958632009, 0.015467299048655798, 0.035609999538532326, 0.02465061065075653, 0.050380801050258536, 0.06724482881171362, 0.08380318672529288, 0.024904002768120596, 0.018431489455646703, 0.03177352183099304, 0.03317646083555051, 0.02715227087693555, 0.02383943391032517, 0.022658559061320763, 0.03774322882028563, 0.009892279764504304, 0.031130114570260048, 0.054367733720157824, 0.011134946253150702, 0.052402658986725976, 0.05014365306124091, 0.008545604035524386, 0.024781533982604742, 0.06201645864972046, 0.03370508371985384, 0.013448363901781184, 0.022340777363362055, 0.021254559845796654, 0.024637670987950902, 0.043247817017670186, 0.0347098719461688, 0.023567321011796594, 0.10328141653112002, 0.061738700339836736, 0.03973671042227319, 0.0629839070939592, 0.08453425392508507, 0.047854469290801456, 0.015476957994646259, 0.11324071604758501, 0.17017442493566445, 0.09277861725006785, 0.22341575659811497, 0.07238742536199944, 0.11880969043288912, 0.12533714302948543, 0.08833039951111589, 0.10276986898056098, 0.11895852030387946, 0.2059014378381627, 0.12431516072579793, 0.14214497112802096, 0.25086148029991556, 0.10781700243907315, 0.0873518909460732, 0.11037436021225792, 0.10118487903050014, 0.19283123846564973, 0.17323214800230094, 0.07168853429279157, 0.1550872123667172, 0.07161378008978707, 0.1794651299715042, 0.2518405520490238, 0.18785730536494935, 0.10047175229660102, 0.16161024091499193, 0.11147596181503364, 0.13615221769681998, 0.10357835702598095, 0.09585831806595836, 0.20408098266593047, 0.20497542752751283, 0.1326436081102916, 0.15718913743538515, 0.2472627748336111, 0.15080059452780656, 0.20292802953294345, 0.09533766457544905, 0.09047126570450408, 0.12079099911664214, 0.07710344730211155, 0.1602092289498874, 0.1329164741826909, 0.15855992745075906, 0.07465352876377956, 0.08626581422452416, 0.11184273713401385, 0.1330560759774276, 0.08533279464713164, 0.16583980752953462, 0.16761657861726625, 0.13475252208965166, 0.13730728785906518, 0.14096679006304058, 0.1916674016309636, 0.1637735055493457, 0.18251852398472174, 0.22131482219057425, 0.15092965188835347, 0.10476090107113123, 0.11584150684731347, 0.15427390672266483, 0.06027992468859468, 0.08718624697732073, 0.1924192320023264, 0.10375220448310886, 0.1392730445201908, 0.09829186355429036, 0.1190923952630588, 0.17764229992670671, 0.16216619179717132, 0.09266439266502857, 0.1163349917956761, 0.0965692734877978, 0.09556279570928641, 0.09706315198647124, 0.13222822254257544, 0.20390511995979718, 0.15008902842445032, 0.13308104606611387, 0.13742263881223543, 0.2098548814122166, 0.21007243330989564, 0.1653369316565139, 0.11677648739090987, 0.11918269470334053, 0.12371435867888586, 0.1431355644017458, 0.16098581227873052, 0.2098834884486028, 0.11537019642336027, 0.08820151856967381, 0.11533232059861932, 0.22708555896367344, 0.1178113618599517, 0.09814787163798298, 0.1678751411714724, 0.13054521142372064, 0.1755292604544333, 0.13413137756288052, 0.2105676145958049, 0.14733466479395116, 0.11633237265050411, 0.1490771020097392, 0.1595168382461582, 0.10236658847757749, 0.1903909279831818, 0.11981199522103582, 0.13709496068102972, 0.16777456871100835, 0.17788191778319223, 0.09505739568599633, 0.07000213049884353, 0.10193161360387291, 0.2544714223061289, 0.14258591032453946, 0.12593961427254335, 0.17388659502778733, 0.10075899652604546, 0.13829953675823553, 0.14770359785429069, 0.12859389398779186, 0.17751367682857172, 0.1469724356595959, 0.14183466349329266, 0.17348620508398327, 0.1275654656014272, 0.14116169246179716, 0.10869837871619634, 0.21996354684233665, 0.13833039653088364, 0.11234013044408389, 0.20262401870318822, 0.10212627173002277, 0.14710911975375243, 0.16215498239866324, 0.12488812926624503, 0.11776481435767241, 0.21989605974938187, 0.1353446931711265, 0.1357345793928419, 0.17989013716578484, 0.15482099593750068, 0.08370536233165435, 0.16053815558552742, 0.12151161687714712, 0.08895920469824757, 0.1387842550341572, 0.10324537275092942, 0.09870733733155898, 0.13777067299400056, 0.11819332279264927, 0.1471939366310835, 0.10964184094752584, 0.12429951370826789, 0.1319314313254186, 0.24232192710042, 0.14093669024961336, 0.21130575213049138, 0.09584097471088171, 0.15332293989402906, 0.15449642549668038, 0.07550886286688702, 0.23788791788475855, 0.08172686956822872, 0.15835908108523913, 0.11833605941917215, 0.14036556732441696, 0.1243089996278286, 0.13068076914974622, 0.18078645478401864, 0.19899502343365125, 0.27682518852608545, 0.09126184042543173], [0.03240309715537088, 0.05421115158657942, 0.033551130909472704, 0.02897443256473967, 0.032292563800833056, 0.01717201989543225, 0.03216973199908223, 0.011579811622920846, 0.007675464298310024, 0.011427676438220909, 0.06634057233376162, 0.03441474653248276, 0.06538176842566047, 0.01167901513898479, 0.028873130679130554, 0.013165804108471742, 0.05824987683445215, 0.04477133848039167, 0.01601496841093259, 0.04093379208019801, 0.02256240725650319, 0.029756284718002592, 0.050665656836437326, 0.028333622396790555, 0.047824647676731856, 0.07589354472500937, 0.023122044280171394, 0.08915190864354372, 0.03169290169275232, 0.014393342658877373, 0.06386632831501109, 0.02990333004189389, 0.0320347476351474, 0.03172999380954674, 0.022006033986274685, 0.029612537074301924, 0.012788688763976097, 0.03226037070687328, 0.0007591192687479113, 0.005910308457844491, 0.07023406055356775, 0.03666086707796369, 0.010407370116029466, 0.03963522872488413, 0.006506328529212624, 0.011744120574024106, 0.02805661047542734, 0.024804860320208327, 0.015184287181390184, 0.038905752689710686, 0.08699801457779748, 0.013509488880767353, 0.037431703215198855, 0.07632961204009396, 0.03493078937754035, 0.06978842589472022, 0.06047254042433841, 0.025237767358443568, 0.05406225386208721, 0.026393383741378784, 0.017566976470074484, 0.0474960976280272, 0.03670763510412403, 0.014757519188736166, 0.03443193043183003, 0.05487129830622247, 0.015481366775929928, 0.008112836945136743, 0.028319680198494877, 0.044484070502221584, 0.02950085699558258, 0.04589223761909774, 0.04125608264335564, 0.04864686248557908, 0.027865964187575237, 0.021060960234275887, 0.029157996643334627, 0.035222335519003015, 0.04110713402873703, 0.02034997597469815, 0.020915124399055327, 0.03762518747576645, 0.03069960106430309, 0.029720420749591928, 0.03161688541461315, 0.04501225233876279, 0.04953155340626836, 0.019965229655749032, 0.03924970209066357, 0.012805812443340463, 0.05780796054750681, 0.08080165314355067, 0.015186307519408209, 0.018321363222120062, 0.036534917407802174, 0.04169989204300301, 0.014835306443274021, 0.04351608601531812, 0.06819040128695113, 0.0059229410835541785, 0.03348396951332688, 0.0676298499373453, 0.013678785912426454, 0.04521579248830676, 0.01530475089592593, 0.06786357810986893, 0.0489942588444267, 0.02154898127940084, 0.0022903642093297094, 0.011148836713151207, 0.04830132531268256, 0.015381910505571535, 0.04985291776912553, 0.020940879892025675, 0.011791461114106434, 0.01761752223995115, 0.047508223048810444, 0.05806182085403374, 0.08571245534611599, 0.05251078014927251, 0.04976644526634898, 0.03664742869191936, 0.039471671251314025, 0.023636701217453395, 0.05975438574595111, 0.03716546982260687, 0.009574692297194685, 0.06793666990207774, 0.07427540833928756, 0.014904327025370938, 0.04285850076537047, 0.02514311172334211, 0.042666482140443156, 0.02331473126209208, 0.0022307417613254593, 0.0437365386502019, 0.006881620310845652, 0.02366038378594177, 0.03752621975062149, 0.07087428548506328, 0.02886943266327892, 0.04095001924516899, 0.016948712324457507, 0.014668475038238933, 0.021539179841056466, 0.06370904389768839, 0.021741495234891772, 0.04622306754546506, 0.05498363317123481, 0.032317628884421926, 0.03187920705282262, 0.03994938026049307, 0.017579171440697143, 0.05881826526352337, 0.04825053696653672, 0.047253277086253674, 0.008708354900591075, 0.016642966141392077, 0.022850659110450318, 0.03877020174903529, 0.031414973749113936, 0.014873479127085634, 0.04841639128114496, 0.01785176440275141, 0.047424641105213335, 0.03108225410271968, 0.06836445908993483, 0.013171116189498986, 0.028582218967910324, 0.039670234346496205, 0.041555791561092646, 0.010033311571792831, 0.05213491924639259, 0.038311182986944914, 0.056961413472890854, 0.0350957310625485, 0.02755707808371101, 0.015358346680711423, 0.02638282743282616, 0.024799274280667305, 0.0613089773271765, 0.02199662270556603, 0.0475106555968523, 0.03936949744820595, 0.08070477869893823, 0.027495199082685367, 0.008088013589648264, 0.08586840304945197, 0.05126196358885084, 0.013754088880627282, 0.025199302904573933, 0.03988950972312263, 0.044276940902428966, 0.005557711128078933, 0.023376594996079803, 0.030411121901124716, 0.04901260643133095, 0.012756254790084702, 0.07209689023771457, 0.0475173323814358, 0.07948132577751364, 0.03337571264377662, 0.028480669417019402, 0.06913218753678457, 0.021167505499241606, 0.036445194722286293, 0.045543446870786805, 0.002481271945206182, 0.028402254517589296, 0.0621137334299939, 0.07520965606506382, 0.035389638505876064, 0.022914209003959383, 0.008728469223050135, 0.0071303547093910825, 0.04410654718854597, 0.04818256472104362, 0.047956215616847785, 0.033957722663347206, 0.04050123279115983, 0.025885904008256536, 0.07848564349114895, 0.029429892410657237, 0.011458255467005074, 0.020785502158105373, 0.04113760364374944, 0.03389656290944133, 0.0388036840595305, 0.030382867702948194, 0.021869239630177617, 0.047312156962496896, 0.04987488534035427, 0.04500453739560076, 0.03847967680277569, 0.08723185131592409, 0.02150747868498521, 0.0369684571799423, 0.029231790719287734, 0.052140137180686, 0.025696094014814923, 0.031863085060779534, 0.032586847831095965, 0.029980035033077, 0.02063663157501391, 0.034294890106788704, 0.05048329037215028, 0.03784473426640034, 0.013923334173991211, 0.04115124559029937, 0.04997147140758378, 0.05645992520398327, 0.06091708264180592, 0.009444804579418684, 0.031244749668985605, 0.07055759962115969, 0.02335929574577936, 0.017005078228456632, 0.030578146688640118, 0.07155112416616508, 0.06032285559922457, 0.041911360874239884, 0.04129935960684504, 0.03409258149830358, 0.031595029801662476, 0.027240414272195528, 0.06602457179022686, 0.01627995160275272, 0.01029928627290896, 0.025209002562665513, 0.04621942720509001, 0.012266212558772947, 0.09415367525070906, 0.028839444808129753, 0.03458323695563844, 0.03509015350469521, 0.038104555503066094, 0.023518347746825645, 0.013157654902897775, 0.023209970544225404, 0.03796667379460164, 0.02421716078450637, 0.005319994017814419, 0.08511176186480693, 0.024896065604739955, 0.02169526325139616, 0.05241594130971602, 0.08690323680639267, 0.010717092514304178, 0.044682633597403765, 0.021999594688947712, 0.08342253536518131, 0.05080340623057314, 0.10193717759102583, 0.040603667830250094, 0.02070416955809508, 0.029144205419080596, 0.10595599122877632, 0.04768859801281776, 0.019872572306277494, 0.03389691914032612, 0.02370853941621525, 0.029990796598472765, 0.013644590291992893, 0.03012725677607315, 0.06828214600682259, 0.017213184918676103, 0.03156300973413246, 0.04351478322808232, 0.08471460174769163, 0.08361469648246254, 0.03708702099642583, 0.04727682225140078, 0.007582233586747731, 0.04421013912984303, 0.03129009955695697, 0.04748300190216728, 0.06364045079265322, 0.03544165500040565, 0.04511770007333585, 0.03527112557951893, 0.006961662846151739, 0.025800635905138085, 0.04548869927280715, 0.019645368247958164, 0.055666884008262835, 0.05864634484584842, 0.028777426707425287, 0.016235222574323416, 0.033465153737259765, 0.031101449858397245, 0.0027904281908247086, 0.04054947663098574, 0.04907078402382987, 0.04881208236994488, 0.018787392947290624, 0.026197867268430333, 0.014834817898060595, 0.017454631427036862, 0.00298635517745944, 0.009649765411657947, 0.03520863250430141, 0.09246003827346222, 0.025778276479936073, 0.044173749296792915, 0.004105750937014818, 0.054227768909186125, 0.04744874266907573, 0.07575593782322747, 0.047483286886875115, 0.026556688460654447, 0.06982717024428503, 0.03559923118778637, 0.14369144743042334, 0.1422618284289326, 0.10744925681501627, 0.08386521839669772, 0.15692296171826975, 0.09273240901529789, 0.11759595413293157, 0.08060559044991221, 0.10708862223795482, 0.08805244442607675, 0.1839990738247122, 0.18517838125782354, 0.2331581488251686, 0.10136807670018502, 0.07849569259477512, 0.1321854612657002, 0.14519741519221238, 0.12883317257676805, 0.11980573912816388, 0.1581571897757905, 0.14273247388856752, 0.10607518947550229, 0.1727483118219035, 0.15359980932303838, 0.14848004547613008, 0.16596814564296178, 0.1299875642039946, 0.1769624621208225, 0.1326372977346182, 0.12999407814017364, 0.17828994803130627, 0.09591088417385306, 0.1471147108823061, 0.12365493258195263, 0.21195382092680248, 0.10398334065186125, 0.10038806857275111, 0.11218777219099657, 0.05261523383004325, 0.0874693589285016, 0.08311984089336225, 0.14336230366357736, 0.11404083775622503, 0.1369038445076772, 0.10623579192906618, 0.14222389832139015, 0.11513998306223325, 0.0601643498188683, 0.10528261307626963, 0.14309772928910597, 0.15077006045196736, 0.12215129898062774, 0.12368704085903508, 0.22764813234763487, 0.13748465691293987, 0.08891142226223435, 0.1279100121131965, 0.20564701434757027, 0.18980176959718975, 0.11389290355145931, 0.18851388299039432, 0.09035641686724764, 0.1548264106469495, 0.09060201940259763, 0.14904960777078355, 0.14562072604894638, 0.11251372005790472, 0.13583614251443318, 0.14684359543025494, 0.10873788302498204, 0.11307403392025403, 0.10996882018766233, 0.12847952012504849, 0.101568197033235, 0.112220898270607, 0.1663213095494679, 0.15436686602021965, 0.1340222827025822, 0.23631121963262558, 0.10966240734394107, 0.1062410573608109, 0.13275133232985223, 0.15845866288457597, 0.16994904274387018, 0.18403764175517218, 0.07318378798663616, 0.1318710417087589, 0.1816054872636284, 0.1253378622766052, 0.1516522645418133, 0.121296209150127, 0.18346160623644078, 0.07459297629871539, 0.1143969465047121, 0.10931526204305035, 0.19680996425449848, 0.09971158272985901, 0.18833925521799497, 0.11069132427551917, 0.11107815708965063, 0.11123352125287056, 0.180588675396783, 0.0961957196039813, 0.13402232341468334, 0.09007481126380817, 0.16735005006194115, 0.11531288735568523, 0.15781382391495363, 0.08422073681971856, 0.13527303987315722, 0.19716204250497477, 0.16503724988017762, 0.10583949355142457, 0.1269773385886635, 0.1192393930894988, 0.12761830990867956, 0.19380048502768787, 0.1266743184200355, 0.23184298511062348, 0.13781400424029144, 0.20380115482423986, 0.14061646243291243, 0.07226534334144422, 0.1428759569036109, 0.19656426672424587, 0.1022819344486509, 0.09612245817801782, 0.15168199794633047, 0.2947248880352293, 0.10616331760372434, 0.11933083246861186, 0.12475042736956052, 0.2412637381681374, 0.18238863881145204, 0.08816100324371032, 0.0852699623044048, 0.1953633547361408, 0.12201656906732491, 0.14229081544492925, 0.21410664969256946, 0.1415178690637861, 0.11648250530873026, 0.11848828196525574, 0.1267901850598199, 0.07379045257610933, 0.11513587114002023, 0.07067860955638544, 0.12985776045492717, 0.14121696592441627, 0.14187146723270416, 0.11678690968879632, 0.11897815710731915, 0.10886725929698773, 0.09716777530099664, 0.12604146237884248, 0.11266441590019635, 0.08070839529058763, 0.15380577184259892, 0.08705357302512441, 0.1470898086471217, 0.08061646736626114, 0.12402945677084581, 0.1710476316511631, 0.12648953976375715, 0.08926002641341516, 0.15313016809523106, 0.13094868191650935, 0.17205479475004332, 0.06644569097885064, 0.12031070488904204, 0.16833089957279818, 0.12354534917644092, 0.10581843860979591, 0.17240143114967005, 0.13957876525819302, 0.0977132021050368], [0.014611171059576529, 0.019635086746088097, 0.005368751423832561, 0.011498831012951476, 0.022545311566708342, 0.0033381420819621, 0.013038520268829805, 0.03216850385069847, 0.021466020195345794, 0.03840894970510687, 0.1036328976707799, 0.03355289510052119, 0.03986739965953997, 0.02875711476164205, 0.07828443071671895, 0.0229362885334662, 0.028644315100141933, 0.025216932940695966, 0.06373877730220556, 0.02145264796646578, 0.04291450704580971, 0.03284386332545962, 0.04692543610664351, 0.007616656516412539, 0.020190654255981957, 0.017284252980191792, 0.052512303460389376, 0.023462149780243635, 0.04055483027228287, 0.023603300331160426, 0.03430518687569669, 0.0696676941588521, 0.024721626125808274, 0.03958962099360568, 0.01000937624901001, 0.02732455261450793, 0.016558159442086304, 0.04703502629750541, 0.00882254640704819, 0.05049677625564592, 0.010336273216775485, 0.030595649499446154, 0.07438689842820168, 0.02924227747800095, 0.04148525106055396, 0.03588845334681017, 0.03148885264194437, 0.023418408020266464, 0.03237069032288023, 0.017159366913672005, 0.011062585582424487, 0.044997914893818755, 0.06448898597487382, 0.02286026207730174, 0.019460942429889525, 0.024370187394587055, 0.06823085554476295, 0.07126305212399789, 0.03923162931044187, 0.02583770766588194, 0.020747763736705695, 0.022694484097883105, 0.01675581669301859, 0.027048258243926933, 0.04036216025373765, 0.024242441302963665, 0.04487000425745334, 0.08717886451631784, 0.02803001190269632, 0.03928868392748492, 0.012691577680275908, 0.060241940298250744, 0.01291836952857141, 0.06127249249922378, 0.024804772110655904, 0.0196975866066558, 0.03335213355187859, 0.02035722442503486, 0.04718173235388739, 0.04994712896378977, 0.03698174289560743, 0.017792267059641223, 0.01590998038383467, 0.03329816287649529, 0.01044529683089682, 0.016352266472365175, 0.03629043445523296, 0.0331778721883893, 0.12114142174167292, 0.06518970230328185, 0.07407365273684263, 0.034518406327281675, 0.014025968532743198, 0.02976900724960225, 0.06645832530089787, 0.008967264355825526, 0.04380474838295153, 0.034437609769936116, 0.062096742913126945, 0.06999794393777847, 0.03457446349784732, 0.049892584926315715, 0.02223944664001465, 0.05797846282699278, 0.0657481841210808, 0.05645195920286434, 0.07164134218224458, 0.046690143910901885, 0.009848271679532315, 0.04226695054343768, 0.04125750417421971, 0.08021141588687897, 0.03554521640762687, 0.034885466630969725, 0.026847517051334892, 0.024756803077512553, 0.087175777181983, 0.058952594841165204, 0.04786941741726228, 0.015587233505877, 0.0688018902604069, 0.02434024873322674, 0.004581851394115282, 0.03982102179101535, 0.01742075726256839, 0.004580200857682419, 0.0760996633076242, 0.058014778021190844, 0.02476134247678731, 0.008050313335843384, 0.0446836717559823, 0.06884358623730284, 0.020912786845916083, 0.013109860592521727, 0.081391876829522, 0.03797663129600031, 0.0470986898456301, 0.05061217809894255, 0.025386079846482192, 0.004832556088721114, 0.010413784816462015, 0.06831981148570776, 0.03557458340323397, 0.018084386563194648, 0.009042161051183939, 0.06882154063454696, 0.08750298712402582, 0.0323805460440261, 0.03601618756407073, 0.10528568683990411, 0.023120280089122907, 0.016457892322380627, 0.028227265425292507, 0.03407277166843414, 0.02266325961266245, 0.006977602481908564, 0.06145332208169358, 0.030211283160107474, 0.02960396039166621, 0.030178703301187073, 0.0619675430602261, 0.030369463243654797, 0.07927826738783292, 0.04215719411149621, 0.04935385187023452, 0.026285866474998847, 0.015410668515999402, 0.013294638400631291, 0.024049978237599134, 0.03068707530785884, 0.0314607748628727, 0.012232350268667298, 0.04233445120709283, 0.002536638070263767, 0.0779995002916881, 0.024464503762179186, 0.014151775710550802, 0.06929632515779563, 0.0224404829953398, 0.03583731555512973, 0.08974215268556561, 0.03469930037057825, 0.0316364374011755, 0.019778754661924074, 0.05735671440405505, 0.04860856257645147, 0.040389094701302905, 0.06907863076776266, 0.05900946964642831, 0.06278044836861746, 0.06784704899681465, 0.022403887905446545, 0.03838114334004266, 0.05563259424109544, 0.08777496431555067, 0.06349272693374328, 0.01749544361207102, 0.06421556350375925, 0.09598830501948084, 0.021903661711673652, 0.03222502242507679, 0.03071642534009048, 0.04223507636093667, 0.05338387151381799, 0.07480864865439278, 0.08283619289951664, 0.10793828378830637, 0.03138558639745627, 0.08007819910666772, 0.06483064871281385, 0.037586453304226906, 0.032325706843818934, 0.02450412681459316, 0.03386905509978533, 0.09291707232062306, 0.03294559947348066, 0.02683736107844327, 0.03147002329517688, 0.043068412358739545, 0.020477847595299994, 0.05282755083005343, 0.043615606746503284, 0.08309106422322136, 0.017930722130196433, 0.03406556562653609, 0.02107033589189606, 0.03447311750746199, 0.00860097334121487, 0.02193027555144259, 0.021914423277069415, 0.007412005265775535, 0.003325568191939965, 0.03764101769775152, 0.02259775553829968, 0.06491630697356802, 0.0235246954419251, 0.040478084568998644, 0.04574680042320064, 0.05027960094490221, 0.048698081701461754, 0.018063480899270092, 0.04117016314661928, 0.04303928963573916, 0.08545063582382031, 0.031388795868094475, 0.02121602414575006, 0.08363322048847165, 0.03298181288742593, 0.02488566535924162, 0.024568014279274002, 0.05280123045668006, 0.023697480991748825, 0.016788366017863154, 0.07134461203323943, 0.04384029683257852, 0.01094566551702363, 0.03578243903549654, 0.0484704399880554, 0.03210003288196666, 0.015779745765030384, 0.02977720055995243, 0.03040460796494569, 0.05424988575811897, 0.04977758002600499, 0.021141992582540427, 0.033069547465337176, 0.035280479184750996, 0.04008751302691443, 0.03579498514799135, 0.021252025517502, 0.08025704058153288, 0.019606053928977678, 0.014666894051645483, 0.017707458663997904, 0.0337126867047378, 0.030499660543033054, 0.029702456534973214, 0.05033059285155364, 0.04172298937503781, 0.025910589112234966, 0.051231992697077136, 0.03384413250855037, 0.061567872363541803, 0.03903322906366416, 0.06044600970510926, 0.05177242209070495, 0.010203504269676549, 0.03222088675413813, 0.03520799468138388, 0.10718057051833187, 0.05848345572927168, 0.006267921857735408, 0.045069296777780564, 0.05820729197668178, 0.055280237791261504, 0.025409502875325934, 0.017740381183102727, 0.02499992387103183, 0.02273268561943301, 0.0327886000408658, 0.010560534129451429, 0.010146257118321955, 0.09623986509229455, 0.008981973298692277, 0.02427129939730678, 0.030195802383657013, 0.02369832237517195, 0.04403389644409929, 0.012649193838504809, 0.041494167010698996, 0.01611276905584548, 0.03451818919607571, 0.04758029364581619, 0.051141934136727026, 0.020146010044429983, 0.027900554206488386, 0.06541944747524601, 0.02492437238938042, 0.06340322816478354, 0.032373224651174884, 0.009667247866413422, 0.05095072975382209, 0.05836900044232607, 0.12933215365878173, 0.025028471535603915, 0.05703956713633878, 0.01051598321646452, 0.04698664675067578, 0.02464667514764837, 0.01854068100718515, 0.032693126771066866, 0.008273666707931884, 0.056540287498916895, 0.02048519273687686, 0.009843140258453786, 0.025794052419119647, 0.01921999973378011, 0.010911889740132859, 0.035771758894303014, 0.018410276754626205, 0.04453198525256344, 0.0317503464674311, 0.004177366491473679, 0.01625300188814955, 0.0461955359870834, 0.013615060447981315, 0.04081995765279446, 0.0903256181627512, 0.012230329082480498, 0.012751287065579422, 0.015134986523272735, 0.024046682253746048, 0.06545353707458292, 0.21350461271192345, 0.09667533529656273, 0.08582665278975453, 0.14140397017555578, 0.13795581805918897, 0.1898543153490339, 0.15585236916584627, 0.12350159723843847, 0.11905381376189844, 0.2011158796293395, 0.15073826430099352, 0.13401595875620842, 0.18457714494849953, 0.1986830873148782, 0.04427232686430216, 0.13843114541045257, 0.12035524392766611, 0.29137504207236425, 0.12471405789256096, 0.11559846917433397, 0.12552725497101033, 0.16318905619638308, 0.1980563923716545, 0.10588753383074488, 0.22189218763794216, 0.16815021926803247, 0.12063313115920339, 0.1632313560694456, 0.17327116376587323, 0.23679848920021737, 0.1861045001340764, 0.1337887038077627, 0.12398415777300086, 0.1166132182947227, 0.11116006983710186, 0.13872212836784975, 0.11717550669397626, 0.16831701674631663, 0.10455417180699961, 0.08778124076447316, 0.12887942152363913, 0.16665001905390195, 0.10241043541048254, 0.12791089420872076, 0.12511201868099825, 0.18686433721865925, 0.07832751769040312, 0.13535956665873528, 0.16744637489318848, 0.10135592413800103, 0.12774812722844736, 0.17098376793520792, 0.11485593473272664, 0.13796196558645793, 0.09900210651436023, 0.09209687954613141, 0.12062008971614496, 0.13562861936432974, 0.07558537447558981, 0.16314507355647428, 0.14813841666494096, 0.175261524106775, 0.11765326320060662, 0.06837680842727423, 0.10740454135728733, 0.10237633224044528, 0.2869344374963215, 0.09353363673601832, 0.08550531896097319, 0.2665102077381951, 0.16829276590475015, 0.16905277940843785, 0.11723660198705536, 0.20479258948138782, 0.1471288651227951, 0.10495571526033537, 0.133128787790026, 0.1410578494625432, 0.132326230140669, 0.09785771649330854, 0.1571345425077847, 0.06624600490821259, 0.13272762431630067, 0.12000340994979654, 0.16256397616650375, 0.14936630720538752, 0.165005535153406, 0.19007131084799767, 0.20478686264583043, 0.1167853626289538, 0.12195225751825742, 0.1245767359754869, 0.11197691743395158, 0.13033734900610788, 0.1372095923870802, 0.08792686795017549, 0.1326245277055672, 0.20826071766870363, 0.1432874205389193, 0.16233210717993124, 0.13313451462558337, 0.1662022673657962, 0.14008633659354278, 0.1757303239511592, 0.10250427680356161, 0.11841596370296818, 0.18982668540307454, 0.08453654058809791, 0.08015511105103151, 0.12418364706848349, 0.10022023972123861, 0.20144621761781828, 0.2413106927914279, 0.1431549840739795, 0.2913471407123974, 0.10594789630600385, 0.20655942681644643, 0.15045067401868956, 0.10066442910049643, 0.09478688413011176, 0.1245272300605263, 0.11443573156637804, 0.16024394280144147, 0.12034278602472373, 0.08635668363422155, 0.27908164315990036, 0.1749713011085987, 0.06296147472624268, 0.15340748535735266, 0.17496383722339356, 0.1736259697271245, 0.1607388255319425, 0.1075984463095665, 0.1132818895525166, 0.09811337491763489, 0.20102999066667898, 0.15525683255067893, 0.07270215704504933, 0.0759875625371933, 0.16080080292054585, 0.2175515584115471, 0.10109972288565976, 0.10993563982525043, 0.13185405119189195, 0.08686951361596584, 0.15358261524566583, 0.2559321182114737, 0.15674899891018867, 0.10644991722490106, 0.08795473538339138, 0.12242002598941326, 0.14057853232536996, 0.1195478822503771, 0.12379856487470013, 0.14928857423365116, 0.17254310926156385, 0.07172321421759469, 0.10852206817695073, 0.15911963741694177, 0.09852928295731544, 0.14823476863758905, 0.1793771239795855, 0.1213486734777689, 0.17944090627133846, 0.1716004612722567, 0.10784606409392186, 0.11551244450466973, 0.12926206099135534, 0.11948861900184836, 0.10171570376093898, 0.12949368570532116, 0.09332495329103299, 0.18435663463813917, 0.1285678246723754, 0.10244144446083478], [0.007010415163157242, 0.037288830881672244, 0.04224789049476385, 0.06291582289018802, 0.004644915286917239, 0.051464340050837824, 0.05469683338222759, 0.07152578766856875, 0.01131386321503669, 0.04459427137460027, 0.06024551617779902, 0.055939458310604095, 0.013232416739421231, 0.051830443620149574, 0.06714548449963331, 0.028747601700680595, 0.06512224235172782, 0.057668446962322505, 0.036606587669146914, 0.027612741703965833, 0.01760166826924043, 0.04926794255152345, 0.025340555235743523, 0.081876534037292, 0.0597374223704849, 0.03373713092878461, 0.14628936802702291, 0.02328116074204445, 0.063533432249512, 0.06570821840848241, 0.03673642534496529, 0.013901944205697094, 0.029120795960937227, 0.03714365152908223, 0.03359487606212497, 0.027968333069501177, 0.030656741399850165, 0.03668985070128526, 0.04528241105643766, 0.007615952536330691, 0.041270538831927946, 0.02087483129331044, 0.026758725655132105, 0.0363587934656867, 0.06775337045214005, 0.059804407347525866, 0.03706691939649837, 0.06357201375067234, 0.048773572114961486, 0.006422342433195029, 0.00301412570739298, 0.080437809095851, 0.046764972752758434, 0.01624631492554077, 0.02799492485688201, 0.028263407593060817, 0.03911229196403708, 0.01654477364250592, 0.04322820396295615, 0.017745068163744042, 0.06604889048529522, 0.04477059209187116, 0.042248104233294725, 0.06293231807649136, 0.04399604776075908, 0.035881739242800643, 0.0231403901707381, 0.04505213662715895, 0.056765377920653136, 0.047775090871644874, 0.025228064307676892, 0.0335803995175021, 0.025066108176750795, 0.02906949192817722, 0.010599813673512211, 0.014060306645530676, 0.050482923963240216, 0.020030404640627757, 0.015303963795304298, 0.018689186877704093, 0.03064600019050496, 0.02171008245620344, 0.037491885878677876, 0.04001692502892443, 0.012202865377600704, 0.028427009171407138, 0.01796053865525339, 0.05592570440577609, 0.03969641562019076, 0.034626439280275784, 0.024782433041504452, 0.07014697736927442, 0.058622141501733234, 0.010473334746036147, 0.012693369860893913, 0.10125218970435006, 0.018121186909931045, 0.05911772990865367, 0.00658479262243158, 0.04891265483040895, 0.024262056054015244, 0.016388571488537958, 0.06806479088429894, 0.03613121621310711, 0.03669344015153391, 0.06661137565970421, 0.014630024155069674, 0.041939017961599996, 0.013903612553674196, 0.03728557052090764, 0.06510597108198063, 0.025470766105822155, 0.07621721271425486, 0.06737308550093855, 0.010597928194329143, 0.019691238911556344, 0.016282226391402737, 0.007815396030699568, 0.0228199452228312, 0.024869411052869897, 0.022528222662263682, 0.04615389768566404, 0.04212869903338807, 0.018042805937251875, 0.07340262231550046, 0.13025945318596704, 0.03777045503790889, 0.039795871890549145, 0.018469175290582434, 0.02234980696812272, 0.10011898194040571, 0.01355080318171531, 0.05680517399949687, 0.02268860798462161, 0.037943976798227856, 0.06450467370450497, 0.018137588797669326, 0.024070178225104297, 0.011767383298969694, 0.031576492224953005, 0.06160118164760726, 0.01664887278872941, 0.04984088055789471, 0.007800609904474446, 0.02906883374920913, 0.020574477767305713, 0.08742527450834002, 0.04619310004636645, 0.029926074535718987, 0.05555392489103334, 0.08332994247653655, 0.052342886836933236, 0.04887480953974383, 0.021336343671594347, 0.05017142889222928, 0.043100530813847265, 0.019376320631376336, 0.010576120078829783, 0.024021157462682043, 0.044383816953216276, 0.027441778020667176, 0.04607506548719747, 0.026605682081675956, 0.026929613003241162, 0.03445798956922122, 0.0865575707118426, 0.0669943747509803, 0.051857177899884324, 0.07201712166092225, 0.026521721854805946, 0.040430943348578045, 0.04410850815474987, 0.013751261085937065, 0.046255284388150485, 0.022915703477337956, 0.0399920906472419, 0.019327187910676003, 0.037170694542250464, 0.03436355106532574, 0.03977123089134693, 0.011433166634690548, 0.06185567977705172, 0.04040934218625937, 0.05682064459792205, 0.028540601022541523, 0.055489426744835715, 0.042555548450244327, 0.025131754743467485, 0.03117489448881575, 0.023724274643297707, 0.023445401839645844, 0.04477333676602159, 0.04218785371631384, 0.025893464584701827, 0.043861670685665946, 0.06887872078056846, 0.024561507128445164, 0.04480977748919811, 0.02085174753197602, 0.08050982201738016, 0.022145608639610664, 0.026255787017622163, 0.05102014388622982, 0.04155265672930649, 0.051765080341803174, 0.10049077841852393, 0.03218213561922312, 0.05137045455298253, 0.02452706638723612, 0.025613692722150257, 0.014914097929639476, 0.011016158520111015, 0.011091033163081323, 0.07234813139906951, 0.028583664247500043, 0.03574429179674812, 0.09755492024123669, 0.037976990919560194, 0.02747585065662861, 0.018869290427703942, 0.04147043864109686, 0.0010835057099549367, 0.035758927797100375, 0.07272356482488768, 0.04815363538052354, 0.07990959672523396, 0.04967707541904279, 0.04161629992138062, 0.02984079286190016, 0.045199799417917214, 0.031138104320104634, 0.02726874141288655, 0.06093989498913288, 0.07465499439941985, 0.0988836343001042, 0.035465312123830826, 0.023065605433657765, 0.014895065022366387, 0.019965931939493333, 0.07401398915265288, 0.027431506696822386, 0.04561435378023556, 0.0374334368721715, 0.06490733674062149, 0.015424539468118122, 0.018782646594835178, 0.03232363731201206, 0.038551109576863904, 0.047540758802954636, 0.019440530400191034, 0.008003206042173718, 0.0534909986225622, 0.03830656555614301, 0.012738947906265301, 0.03297209965863398, 0.0836212375600423, 0.022786792001820037, 0.03401442783485566, 0.016841956713636006, 0.03337086790374347, 0.013742178894712456, 0.030241535643913915, 0.017846522719732354, 0.02929621422663331, 0.04430170403793454, 0.026253322239166925, 0.008238695861239518, 0.029174885379948785, 0.013484640928384448, 0.05552331617634211, 0.04821042197623423, 0.008078944120955254, 0.011466436902992427, 0.007639814068430236, 0.020715855627453754, 0.06978627493871109, 0.0441791300794908, 0.06803667239312615, 0.0398028743719416, 0.0437048103527299, 0.039159141414399655, 0.08696604200771876, 0.025009153643622994, 0.016576239007658193, 0.04676211951300502, 0.012985347720262195, 0.034626534275178394, 0.01669861619094653, 0.03007027679788215, 0.08906929700502328, 0.04015787371567317, 0.0691271595922964, 0.011167948500120213, 0.02882424901638712, 0.04560939368924924, 0.03553734540141054, 0.05365427789677467, 0.022241606077711498, 0.05840370072317975, 0.03813727446166532, 0.0625805180253727, 0.09682423302105495, 0.0762766320258379, 0.08735896128096751, 0.054039553473038335, 0.011815947746591908, 0.053082880164895735, 0.026898581900500824, 0.10058313381991216, 0.03865655731143696, 0.09723242611757346, 0.016800335375592113, 0.024399686704522798, 0.059881332862590037, 0.03474976641259023, 0.009275814584855522, 0.032086774307702265, 0.03556989133358002, 0.04422126031879868, 0.03775342380894082, 0.03919450665957161, 0.0061084992069351885, 0.03559747378208807, 0.030867423130465404, 0.013955860598278897, 0.033306474930473735, 0.027916940827188746, 0.07867657646004643, 0.06502286411289658, 0.06632951899830784, 0.03118165609027658, 0.08120454688157354, 0.08041755482554436, 0.09290639896477972, 0.038969650332416804, 0.03862452706588166, 0.03005512511091573, 0.04563812625461391, 0.08271354769489594, 0.01051804341841489, 0.05636925256944128, 0.03181638828079615, 0.03907872483666454, 0.04372752431247916, 0.03499003905536873, 0.048790013018463335, 0.028399764294070855, 0.04535529250279069, 0.024403795234060714, 0.01001826675409185, 0.03421970842672246, 0.07817057932593993, 0.06832403875887394, 0.077404845772045, 0.13273321544485434, 0.12527231579380377, 0.08145343352641378, 0.1882379770811115, 0.12513008128319467, 0.18284001387655735, 0.09712835920176335, 0.195584150031209, 0.15533748322299548, 0.0864134430885315, 0.09059842995234899, 0.17049497844917433, 0.15209617572171347, 0.1009817256459168, 0.17735768162778445, 0.168962439256055, 0.08088710105844907, 0.2243869709117072, 0.10748696979135275, 0.15043035868023122, 0.0973477770707437, 0.18064222538045474, 0.07432469033769198, 0.1098678270354867, 0.17038297945899622, 0.09407677009169545, 0.14471955011997903, 0.1882118127707924, 0.09160387635763202, 0.13588369424854005, 0.06993462983518839, 0.0976061699911952, 0.14805453616593564, 0.1628227558519159, 0.08225557726940938, 0.15897934351648602, 0.08181155752390623, 0.12327970271664006, 0.18846874684095383, 0.18646511435508728, 0.07894500491342374, 0.12543297931551933, 0.14896058397633688, 0.24732520005532674, 0.11066448143018143, 0.14094196925205843, 0.12405055920992579, 0.13386240628148827, 0.149437458387443, 0.2001380156725645, 0.11031430986310754, 0.08845925331115723, 0.15061538160911628, 0.1483373088496072, 0.10046757930623633, 0.16003270127943584, 0.17040291481784411, 0.07263807619788817, 0.15139576473406383, 0.0925262225791812, 0.12374388852289744, 0.13670706935226917, 0.12579925251858576, 0.1337461189499923, 0.12057792555008616, 0.08883109728672675, 0.14241475665143558, 0.16502344847789832, 0.12052707613578864, 0.1313622218689748, 0.13630564803523676, 0.10796116398913519, 0.06697644785578762, 0.10900073392050606, 0.14661093934306077, 0.10145161114633083, 0.06185249744781426, 0.2183092241840703, 0.10149306963597025, 0.12029739203197615, 0.186350781204445, 0.08944059815257788, 0.12305058858224324, 0.15996376212154115, 0.2809115435395922, 0.11530511134437152, 0.12051658598440033, 0.22635097695248468, 0.15004393298711094, 0.17909975243466242, 0.2142985529665436, 0.10246802946286541, 0.17370472050138883, 0.14995652410600865, 0.09262666611799172, 0.12665511587900774, 0.10484546010515519, 0.13816662531878265, 0.15577201704893792, 0.09442728092627865, 0.09490715446216719, 0.11347188614308834, 0.14088130822139128, 0.17644659908754484, 0.09854087912078414, 0.09724052104034595, 0.10565504059195518, 0.09881884777652365, 0.21100858093372413, 0.12133441067167691, 0.17663301979856832, 0.14702803481902393, 0.14236489789826529, 0.205463511337127, 0.0671266144407647, 0.09909842456025736, 0.1484819453741823, 0.11331620306840964, 0.2079531784568514, 0.09448060020804405, 0.17092119343578815, 0.0870595509186387, 0.17840392834373883, 0.20899339978184017, 0.10442840534129313, 0.19453151151537895, 0.08158477754997355, 0.10716478779379811, 0.18633589414613588, 0.08997337027852025, 0.195431330374309, 0.11762861880872931, 0.18466458097100258, 0.1139350812882185, 0.09229939510779721, 0.10053463892212935, 0.1296157677258764, 0.11795469559729099, 0.09132675587066583, 0.07251629273274116, 0.20447768137923308, 0.0785426472180656, 0.10958519684416906, 0.10974391297038112, 0.1552482694387436, 0.09408424076225076, 0.09104345392967973, 0.16905421790267738, 0.14516404483999523, 0.23800598297800335, 0.13392137097460882, 0.11433631261544568, 0.10075609918151583, 0.1383267053003822, 0.13196519522794656, 0.15764322664056504, 0.12644078023731709, 0.19335520320705005, 0.10461764197264399, 0.10031531604805163, 0.13201689959636756, 0.06844156780945403, 0.2018232795276812, 0.13337991360042775, 0.10325826491628375, 0.156867918957557, 0.17394091854138033, 0.13171876487987383, 0.2063784208148718, 0.14436185359954834, 0.0924706980586052, 0.15279888015772614, 0.0940472266769835, 0.23183210140892438], [0.04995288972609809, 0.05311808595433831, 0.04062493311773453, 0.03430702231292214, 0.042566055565008094, 0.02327525070203202, 0.043351531095270596, 0.013562669062853923, 0.033093584568372796, 0.08302139903285674, 0.09355291391589812, 0.07011341024190187, 0.059001761488616467, 0.03350011186142053, 0.03965162213093468, 0.018052327479901056, 0.011292379948177507, 0.03401468228548765, 0.025611389095761945, 0.018106542427891066, 0.024609140286754285, 0.07195430967424597, 0.011329676473646291, 0.014214690325648656, 0.006539472420367279, 0.022423215975452746, 0.06161464378237724, 0.04772032291761466, 0.025786826021171043, 0.06370861642062664, 0.049607593433133194, 0.011426717159338295, 0.03926215320825577, 0.021116561090041484, 0.04200274936322655, 0.053217745785202296, 0.024490001411842446, 0.013743134780919977, 0.06043102086654731, 0.037330852555377145, 0.0796887403620141, 0.04082699745361294, 0.03565985489902752, 0.08691192883998156, 0.05575941922143102, 0.045466558675148656, 0.06448406659598861, 0.04194723841335092, 0.039875419943460395, 0.08498946949839592, 0.016991146208186234, 0.02853395137935877, 0.048060662512268336, 0.037595169086541445, 0.07677932469440357, 0.03778404948700752, 0.06004718717719827, 0.026390591569777046, 0.08673683287841932, 0.04820195725187659, 0.03409886473257627, 0.1166739607495921, 0.046302914153784513, 0.03168980757306729, 0.04254994714366538, 0.04517293282385383, 0.04868037533015013, 0.04059299786708184, 0.0025506317948124236, 0.03615122621080705, 0.014841084168957812, 0.015608517453074455, 0.050077899625258784, 0.009950152864413602, 0.03319090006074735, 0.015240924499396766, 0.04824675074113267, 0.025885939631345015, 0.022034997253545692, 0.019054347283339927, 0.039606832034353695, 0.03902881858604295, 0.055402418199394426, 0.021019184529515247, 0.053107728117278645, 0.03915178270212241, 0.055123937249715836, 0.019845558130847554, 0.02085890098741012, 0.07597453466483525, 0.021472172811627388, 0.045528885509286604, 0.029602996871939728, 0.06986535140978438, 0.04718627514583724, 0.04217771979581032, 0.023193356614293795, 0.06125071831047535, 0.0615542202389666, 0.03766851532938225, 0.011856848989347262, 0.021098561252334287, 0.022498506221121976, 0.01626905263401568, 0.04621563758701086, 0.0019472021210406507, 0.07988030436847891, 0.03662383263664586, 0.01187548240912812, 0.06542412258152451, 0.03844463725441268, 0.03639397889907871, 0.00723037077113986, 0.10006746077643973, 0.032877060651246987, 0.010161390993744135, 0.03177805444491761, 0.02652082618858133, 0.020274940179660916, 0.047160897936139784, 0.052947047632187605, 0.03388574027589389, 0.011626281941841756, 0.05734818521887064, 0.024989879856418287, 0.04885860612349851, 0.04755489268739309, 0.05179034898589764, 0.07430917902716569, 0.029867065737822225, 0.007098670092610908, 0.13522600382566452, 0.021975177606301646, 0.03918756524633084, 0.03385966078245214, 0.03666099260694214, 0.03737315582111478, 0.02583889849483967, 0.04324013600125909, 0.07016354040907961, 0.04687573341652751, 0.06804528978786298, 0.040149110435907326, 0.01923568407073617, 0.033159524601485045, 0.022162909586248652, 0.0847903194704226, 0.05243445513769984, 0.02428892264807863, 0.03777293508340206, 0.021333622746169567, 0.037611555707241805, 0.03465737708445106, 0.020793844746159654, 0.03257094636293394, 0.018826181401631663, 0.038999529621962986, 0.039953543072832484, 0.009508799761533737, 0.040245601508234224, 0.055280875614179034, 0.032419568592948575, 0.03448970090331776, 0.034315527749380896, 0.033263747580349445, 0.01922387756141169, 0.012178895279898174, 0.04455144902957337, 0.029601286963692734, 0.01877719795863543, 0.03713916641260896, 0.0832050581063543, 0.021267926985664026, 0.01965787704102695, 0.02385570348373481, 0.04142099040161286, 0.017292419149141227, 0.060325562953948975, 0.03656287305057049, 0.018488708617431775, 0.022642131728519286, 0.0038638824646893355, 0.0452482061061476, 0.058784114596034796, 0.039659533849252124, 0.03592263115569949, 0.07628216208623988, 0.06863160511212689, 0.017783977058050886, 0.05122188591797437, 0.07675591523626021, 0.007463247382215091, 0.038458034928355894, 0.052475394548049996, 0.05320055510050484, 0.04774661614958729, 0.02114960744178721, 0.03165593171226127, 0.06299757957458496, 0.049327894513096125, 0.03207593810345445, 0.04700429544651082, 0.041393089041646035, 0.021933371367465173, 0.06081750084246908, 0.04851093156529324, 0.01781337967674647, 0.012461206559757037, 0.04206726447279964, 0.0576933017000556, 0.017507406184449792, 0.05260217881628445, 0.036083108080284934, 0.07053917739540339, 0.06530191163931574, 0.016408462742609636, 0.011018384963140955, 0.028276545727359395, 0.07625546851860625, 0.048268127986895185, 0.0815615580816354, 0.0296297684711005, 0.0050437233959590745, 0.06933363779847111, 0.028398083223562156, 0.09550680299954754, 0.05274567540202822, 0.011604528109143888, 0.046664851518081765, 0.0532888291137559, 0.08440549511994634, 0.01741184131242335, 0.07174687473369495, 0.026400326850957105, 0.05262710140751941, 0.03664559664736901, 0.056970166574631415, 0.01290845189110509, 0.047064800414123704, 0.09077062178403139, 0.017563005343877842, 0.020997890404292514, 0.06446848064661026, 0.0647637994427766, 0.04998459766751953, 0.017091591443334306, 0.07408522854426078, 0.051450287590601614, 0.037855241381164105, 0.04877948554764901, 0.04192577295803598, 0.06834155174770526, 0.03743399666356189, 0.04993127838575414, 0.03531985796455826, 0.02136963090327169, 0.021551293387476887, 0.02266945463738271, 0.01729763369075954, 0.022292061941698194, 0.030704951312925135, 0.022169711899810603, 0.05081579288733857, 0.04258722246491483, 0.0853079670507993, 0.056167334118591886, 0.03623625682666898, 0.062222977567996295, 0.03650739602744579, 0.029701499800596918, 0.03436573934076088, 0.020550905460757867, 0.011556625233164855, 0.006916101340071431, 0.05406204012355634, 0.020878944911860993, 0.04878097493201494, 0.01464742688196046, 0.03697282016011221, 0.05888755725962775, 0.019704860502055714, 0.08156640960701875, 0.024105969251000454, 0.04406625238646354, 0.03970715682953596, 0.033624148062829456, 0.06634639416422163, 0.041964717475431304, 0.009852830586688859, 0.053809350289936574, 0.034061589411326816, 0.026162001603682126, 0.057193893140980175, 0.026689862832427025, 0.03696000263360994, 0.05061403728489365, 0.019608783336090188, 0.05343723829303469, 0.04672309017873236, 0.022195696398349743, 0.07148256498788085, 0.11234919567193304, 0.03429004875943065, 0.04356344097426959, 0.0202487164975277, 0.030018918482320647, 0.04081315194655742, 0.03408614220097661, 0.012203937462930168, 0.0367225628745343, 0.03949807304888964, 0.007288576353208295, 0.027665784482711127, 0.0209332361950406, 0.06948784166680914, 0.045977627858519554, 0.016468969406560063, 0.009745639865286648, 0.02928996831178665, 0.008593672304414213, 0.022751638798841407, 0.013604882422701588, 0.01614388158278806, 0.04899634873228414, 0.04976051487028599, 0.01633340659152184, 0.03976063895970583, 0.02035219139153404, 0.011479155193748218, 0.04083239519968629, 0.06770668724285704, 0.05812046663569553, 0.01859024629395987, 0.08050140139779874, 0.016547148515071188, 0.020244568952226212, 0.04372741913955126, 0.0249752642121166, 0.05133572713072811, 0.026498894240441065, 0.017852169827425053, 0.04130046561892543, 0.02981353271752596, 0.03708352993375488, 0.023770616888733845, 0.03151626545669777, 0.04117410543507763, 0.01947763099867318, 0.06547882607472794, 0.06363949405827693, 0.052447815492217026, 0.02468610990659467, 0.12978422082960606, 0.1320727158870016, 0.14532590258334363, 0.16955716162919998, 0.16653097687023027, 0.14200276375881263, 0.15399445886058466, 0.09448639489710331, 0.0985299547069839, 0.11026645957359246, 0.16534421912261418, 0.1391458192041942, 0.08317366907639162, 0.09626089967787266, 0.10660099983215332, 0.1280448098800012, 0.08639597759715148, 0.12044349419219152, 0.1509972204055105, 0.16607949323952198, 0.09361309997205224, 0.10913084979568209, 0.17150448927921907, 0.0824443796383483, 0.21148759951548918, 0.09074173654828753, 0.14115672558546066, 0.15612309106758662, 0.18615498313946383, 0.10316454565950803, 0.10181811505130359, 0.04666499401043568, 0.10553249716758728, 0.17963388163064206, 0.16485940585178988, 0.0740292426198721, 0.1433896350541285, 0.13265257834323815, 0.17365081767950738, 0.14492677471467427, 0.11433091147669724, 0.15428542824728148, 0.14186358265578747, 0.1939874349960259, 0.19801828584500722, 0.15041851145880564, 0.11697380537433283, 0.09607200909938131, 0.16656540573707648, 0.16931444965302944, 0.12144533757652555, 0.14809585894857133, 0.17781094302024159, 0.09039176854171924, 0.24557713099888392, 0.10240251690681491, 0.15000783492411884, 0.19367579743266106, 0.2635143670652594, 0.16418709978461266, 0.10294896151338305, 0.21237544901669025, 0.1401176577700036, 0.15936768267835888, 0.10478033431406532, 0.17385198974183627, 0.1542238715503897, 0.10086650361440011, 0.1399925494832652, 0.25272522600633757, 0.15770114638975688, 0.10506074569587197, 0.16802973859012127, 0.16400913361992153, 0.12143038266471454, 0.11739786261958735, 0.26353863147752626, 0.10827301189835582, 0.13495068145649775, 0.16042368672788143, 0.12302963542086737, 0.1327716340976102, 0.08382775647831814, 0.12830482449914726, 0.15978181974164077, 0.09240530763885804, 0.1275622629161392, 0.1318516084658248, 0.17187606862613133, 0.12696151515202864, 0.091945172686662, 0.12748652483735765, 0.14440371921019896, 0.13465085040245736, 0.20707509985991887, 0.14753271559519426, 0.13445731864443847, 0.1646541082965476, 0.1708387785724231, 0.11328176741621324, 0.1679762564599514, 0.11335937825164624, 0.09790410793253354, 0.16657657442348345, 0.19886488041707448, 0.23751895768301828, 0.1146229122366224, 0.15293386791433605, 0.10363657533058099, 0.18226978661758558, 0.19167984596320561, 0.12903339469007083, 0.09598639833607844, 0.20724082525287355, 0.06553484592586756, 0.17437271108584745, 0.1360727341047355, 0.11623356438108853, 0.1818070528762681, 0.10437067558190652, 0.09017751432423081, 0.0642308508977294, 0.1471122952976397, 0.15158978503729614, 0.15335772159908498, 0.32499219104647636, 0.11057423627270119, 0.10349782848996775, 0.17388317521129334, 0.09068849869072437, 0.2163183210151536, 0.1616821384855679, 0.08512084066335644, 0.19131801037916116, 0.11045378952154092, 0.09766782846833978, 0.11176380315529448, 0.21341974155179091, 0.18570491086159432, 0.13330371411783354, 0.11041266351406064, 0.140744379854628, 0.1703234040843589, 0.10094142066580908, 0.18781724465744837, 0.07458174654415675, 0.16753067608390534, 0.15158884865897043, 0.1705506183207035, 0.18200418086988585, 0.1219254011022193, 0.16244293908987725, 0.09890131692269019, 0.1228570703949247, 0.1316967396331685, 0.14483600029987947, 0.08022943777697426, 0.10721643787941762, 0.05733553732612303, 0.10167481524071523, 0.17263281159102917, 0.1270154044032097, 0.12480420805513859, 0.12517227259065422, 0.0904986649485571, 0.10903105086513928, 0.1314747365457671, 0.12737748425986084, 0.1372810285538435, 0.17124170623719692, 0.08647438231855631, 0.19541055363203796, 0.18932636082172394, 0.11505037572767053, 0.10174619033932686, 0.08869298826903105], [0.057327747744108946, 0.051073052654308934, 0.06976387649774551, 0.014550219955188888, 0.034391774729426415, 0.06046788567411048, 0.04137566765504224, 0.04097011745242136, 0.015705191729856387, 0.021105346602520773, 0.029315108034227575, 0.010268674165542637, 0.011835154528463525, 0.05983931118888514, 0.09118344927472727, 0.07396431360393763, 0.031348745338618755, 0.02432218104201768, 0.06443555812750544, 0.005741628468967974, 0.05475258860470993, 0.07686608218188797, 0.06831981148570776, 0.027909359894692898, 0.032119669685406346, 0.009230075387417205, 0.04541235729785902, 0.007430345219160829, 0.04825297290725367, 0.05851092961217676, 0.09681671485304832, 0.10306531669838087, 0.012550664616615644, 0.009579900053462811, 0.09142038691788912, 0.012952710185865206, 0.1199375649115869, 0.042671791676964076, 0.0642440009063908, 0.020277374424040318, 0.038223353414131064, 0.012885971177768494, 0.06861498100417, 0.03258976213900106, 0.03680014996124165, 0.025028551263468604, 0.03270841416503702, 0.033550774678587914, 0.012992624160168427, 0.040249143461031575, 0.042258088876094134, 0.06563060757304941, 0.01727715550389673, 0.028433826752007008, 0.034240878719304285, 0.0400836080578821, 0.00699881772743538, 0.042338909182165346, 0.013082105965752686, 0.029159916897437403, 0.04060850239225796, 0.01685503208344536, 0.031659568659961224, 0.04404754178332431, 0.03168334452701466, 0.08154533430933952, 0.011059712834789284, 0.01048411157846983, 0.03125930763781071, 0.03057579217212541, 0.06750188501817839, 0.07180228390331779, 0.018546228030962602, 0.016801734854068075, 0.07119526647563491, 0.06222259758838585, 0.0482765045017004, 0.03693456096308572, 0.05766375149999346, 0.021906450490600297, 0.07033734036875622, 0.028852211444505622, 0.015168090550495046, 0.07219121339065687, 0.07267967039453131, 0.0513969275967351, 0.0381591741793922, 0.038509841077029705, 0.02202304994820484, 0.021580270225448266, 0.1259731746145657, 0.023221989095743214, 0.06802004149981908, 0.056262854885842116, 0.033409537614456246, 0.03235791011580399, 0.02042851470676916, 0.017682281622130955, 0.017953685451565043, 0.01047224909000631, 0.052813030180654356, 0.07495078817009926, 0.031808988856417794, 0.038821302221289704, 0.036336378061345646, 0.03413693054712244, 0.05937363939093692, 0.03927301994657942, 0.04683475668675133, 0.010462934500537813, 0.040307734959891865, 0.03071523451113275, 0.09632899745234422, 0.03421920970348375, 0.010161035611028118, 0.15941074251064233, 0.0360536053776741, 0.01921185222454369, 0.04721888893150857, 0.007786014616223318, 0.05026599292510322, 0.02348464321611183, 0.03516468718381865, 0.025332188898963586, 0.030130998896700994, 0.011114696223687912, 0.041642932420862575, 0.02446548254894359, 0.06403465928243739, 0.033464967140129635, 0.009588499636655408, 0.05143955995195678, 0.09575425115014825, 0.08677242204014744, 0.02237395942211151, 0.04391252349263855, 0.013149180000514855, 0.032283322153879065, 0.04956743773072958, 0.051925106040601215, 0.05926760472357273, 0.01586018269881606, 0.017029732798359225, 0.04777034791186452, 0.03938710543193987, 0.029881728879575218, 0.028828639137957777, 0.005839607229323259, 0.03673962463757821, 0.043326408336205144, 0.04531964905826109, 0.02723147626966238, 0.058695443639797826, 0.04338802270857351, 0.02211154787801206, 0.03114441130310297, 0.06240411249122449, 0.02875081795666899, 0.032492450039301596, 0.061919970970068655, 0.05640501815027424, 0.009161788471309202, 0.011373035709506698, 0.009182524501479097, 0.019935480984193937, 0.057632532103785446, 0.022816762893593738, 0.019162646561328853, 0.06658443103411368, 0.02454158534029765, 0.021918382528903227, 0.055467856116592884, 0.027322537365502546, 0.011983411037363112, 0.06144729669072798, 0.030002175630735498, 0.057889873294958046, 0.03611568454653025, 0.02935435789238129, 0.004967019677029124, 0.041215105913579464, 0.03195232937910727, 0.00943790387827903, 0.04741759791171976, 0.01609407032706908, 0.022059755300038626, 0.06779947690665722, 0.06733422580042056, 0.01778585320737745, 0.07243722304701805, 0.008123093001943613, 0.019388910848647356, 0.041695271219526014, 0.049844449652092795, 0.05817531940660306, 0.02526359579392842, 0.06120705458202532, 0.04878313945872443, 0.015578326037419694, 0.03445720925394978, 0.03608650414805327, 0.017419880256056786, 0.02217190696059593, 0.00563766248524189, 0.10440857854804822, 0.05086979070412261, 0.05976205997701202, 0.06045680519725595, 0.0367526321538857, 0.037330136700932465, 0.029142475154783045, 0.044092182602201185, 0.05876969572688852, 0.02402602255876575, 0.031801674248916764, 0.0025462230135287556, 0.03155708612341966, 0.01472485960195107, 0.04047266307419964, 0.04643713516582336, 0.02061262500605413, 0.01830717166220503, 0.01117941998277924, 0.039357575587928295, 0.06978225122605052, 0.032107038756034205, 0.020204023092186878, 0.032910885621926615, 0.0053604202860567185, 0.11721473958875452, 0.030385524167546203, 0.01489309557447476, 0.006767659506294876, 0.07270782281245504, 0.04235290057424988, 0.02766362334867673, 0.01928178034722805, 0.011986053931260747, 0.018416571863261715, 0.0466017782954233, 0.05561523392264332, 0.08721007712717567, 0.05210514852244939, 0.06317015138587781, 0.028591630248618976, 0.031037436864737953, 0.03330297029710241, 0.03724232409149408, 0.047958515850561004, 0.02976550261623093, 0.022845017091770257, 0.01944057789764234, 0.07064752586718116, 0.08878437336534262, 0.07394507713615894, 0.02007543052812772, 0.05592574511787721, 0.0034939907615937826, 0.030106921081564257, 0.01209975010715425, 0.017401159474892274, 0.0422743737165417, 0.04770611778699926, 0.06292539701930114, 0.047690155250685554, 0.03015275951474905, 0.017470546465899264, 0.009938912931829691, 0.049856402046446285, 0.03649947752377816, 0.030433079294328178, 0.035055409119065316, 0.029543377392526184, 0.05096830041812999, 0.02666641096584499, 0.0716519205431853, 0.0176032136327454, 0.04502349227134671, 0.053269738531006236, 0.03391384519636631, 0.026807125558012297, 0.03383320809475013, 0.054956542660615275, 0.035683067582015476, 0.04500527360609599, 0.0232172512249755, 0.03430590612281646, 0.014492552960291505, 0.06511561306459562, 0.043569927769047875, 0.028488438642982925, 0.05033605166577867, 0.02402442291245929, 0.03318552267072456, 0.04146920031468783, 0.03909158646794302, 0.05499926322538938, 0.028514765801706483, 0.086383370416505, 0.033357039360063415, 0.08289925594414983, 0.02463478042877146, 0.038159818787659915, 0.017267518610294377, 0.024214750288852623, 0.05622570848624621, 0.07280906702258758, 0.029165531774716716, 0.01719818081307624, 0.0499083574728242, 0.0452137670612761, 0.02303631816591535, 0.015497120662725397, 0.055116079814199886, 0.026410457378785526, 0.09464734340352671, 0.05563408362546137, 0.014709399181551166, 0.04265681301642742, 0.06848023073481661, 0.011884731689601071, 0.06891179936272757, 0.0370623867825738, 0.04010866635612079, 0.023920739368934716, 0.05408927991187998, 0.046119190619460175, 0.03820070730788367, 0.06724641658365726, 0.1147376796496766, 0.030922163943094865, 0.031751876563898156, 0.028351740978126014, 0.07052720125232424, 0.03997352932180677, 0.03746001169617687, 0.05503957499084728, 0.022682229755446315, 0.07806000525930099, 0.006032579195951777, 0.03356691024133137, 0.03520754684827157, 0.04683152686006256, 0.04517526359164289, 0.03621454031339713, 0.02521658519149891, 0.043175006817494116, 0.037576237959521155, 0.022599747038579414, 0.02347669248203082, 0.019701274444482157, 0.029844148217567375, 0.10216003563255072, 0.08544248661824635, 0.15442371368408203, 0.12047531748456614, 0.1777388011770589, 0.16033355013600417, 0.07658240704664163, 0.14557143726519176, 0.12960199346499784, 0.1220780171986137, 0.15114985007260526, 0.18940678079213413, 0.07111137919127941, 0.10003480288599219, 0.18430167330162867, 0.16001697283770355, 0.12808934891862528, 0.17839421172227177, 0.12163768868361201, 0.07026824514780726, 0.08839937938111168, 0.12644339938248905, 0.1396410819143057, 0.11553687176534108, 0.10099963218505893, 0.1889705370579447, 0.14942964166402817, 0.0866528031017099, 0.18860026049826825, 0.10732533596456051, 0.19937238389892237, 0.1966648120433092, 0.09520435958568539, 0.07625118696263858, 0.1879545258624213, 0.16277585551142693, 0.2924273684620857, 0.09339208754577807, 0.13456984689193113, 0.08280899043061904, 0.1700849804495062, 0.07357720259044852, 0.16026903502643108, 0.08212014167968716, 0.1718705589217799, 0.09554592054337263, 0.09684300129967076, 0.13494825230113097, 0.1986675760043519, 0.20677142829767295, 0.1648726508553539, 0.08903280539172036, 0.10471606347709894, 0.25785231803144726, 0.1553892825863191, 0.08641454910061189, 0.09771271355982337, 0.15583449655345508, 0.1097848897001573, 0.06876194490385906, 0.10930547756808144, 0.12570847810379096, 0.12785292017672742, 0.14744308111923082, 0.12186038387673241, 0.1831649507262877, 0.11645001705203738, 0.1161761467478105, 0.0653552512771317, 0.10141594734575067, 0.15566270505743368, 0.14985132403671741, 0.10725981662315981, 0.11561081851167337, 0.15805184042879514, 0.11881465730922562, 0.13313265543963226, 0.11884414644113608, 0.13804634820137704, 0.14637202716299466, 0.19203302344041212, 0.16311869211494923, 0.16336338541337422, 0.09743283822068147, 0.1612956720803465, 0.12249617118920599, 0.08647495907332216, 0.11458479213927474, 0.09961333085915872, 0.12581978498825006, 0.19411086051591805, 0.09289477565991026, 0.12452242603259427, 0.21864462404378823, 0.09494778513908386, 0.15291249406124863, 0.14240453791405472, 0.11205033492296934, 0.0900653185588973, 0.11614969745278358, 0.1449418110506875, 0.0871540369199855, 0.1387554851493665, 0.11777457169124059, 0.15813055049095834, 0.13163100316056184, 0.09331469384155103, 0.1484335386859519, 0.15638729903314794, 0.1600387945239033, 0.10107492243072816, 0.11010080881948982, 0.11088449640997819, 0.13349267254982675, 0.0888984486726778, 0.22731851360627583, 0.09129692068589584, 0.08304252861333744, 0.09754609928599425, 0.11142008445624794, 0.149475117080978, 0.10090319878820862, 0.13755563167589052, 0.11399598659149238, 0.18642185096229824, 0.13706277097974504, 0.10206383293760674, 0.17163900206131594, 0.0969455957944904, 0.13598799865160668, 0.15675574354827404, 0.22531676744776113, 0.1567964285079922, 0.14189722442201205, 0.12012929176645619, 0.10932779458484479, 0.07465538116438047, 0.10876514656203133, 0.1808190516063145, 0.14393641214285577, 0.12681344524025917, 0.0860825487013374, 0.15022873878479004, 0.20096217787691525, 0.25441496819257736, 0.12601539306342602, 0.10575712618551084, 0.13827897714717047, 0.0773323035932013, 0.28860550639884813, 0.15997024891631945, 0.14201450241463526, 0.2097734436392784, 0.23058109996574266, 0.12337826671344893, 0.11176582518965006, 0.1408292781561613, 0.32975542545318604, 0.09323641125644956, 0.17296492734125682, 0.16994704785091536, 0.11920621272708688, 0.1796563547104597, 0.060913038573094776, 0.12212130773280348, 0.11127880668001515, 0.14288488642445632, 0.15218708584351198, 0.07806675668273654, 0.09284999234867947, 0.1251504509044545, 0.10961036370801074, 0.13013207859226636, 0.06335511324661118, 0.12965319571750505, 0.0729548909834453], [0.03890837183488267, 0.02258972168367888, 0.0453058849754078, 0.04199887153559497, 0.014364085925210799, 0.0719539432653359, 0.11785838433674403, 0.0835351450368762, 0.02964661649561354, 0.07254926274929728, 0.04701159309063639, 0.038969541766813824, 0.004604170107216175, 0.020307336834126284, 0.04620041126119239, 0.037391126821083684, 0.025444483051874807, 0.016778932684766393, 0.05592960258945823, 0.020610107641134943, 0.021261823563171283, 0.02145328409304576, 0.05785591261727469, 0.03308132004791072, 0.030213522325669016, 0.03293043760848897, 0.04914099882755961, 0.04278141918725201, 0.009753926474201893, 0.03944450270916734, 0.0840505330956408, 0.0648916150842394, 0.016148543118366172, 0.03444035105141146, 0.06324109222207751, 0.022360013831140738, 0.035456630268267224, 0.03322712704539299, 0.02044203451701573, 0.016918709202270423, 0.03506467451474496, 0.035996981630367894, 0.03738003955887897, 0.015068763201790196, 0.026391405811799423, 0.008035686665347644, 0.054690780849861245, 0.03247075727475541, 0.03440014445888145, 0.021763773235891546, 0.07343023869075946, 0.00937368902045169, 0.00908138885694955, 0.031015506612935236, 0.05787991240088429, 0.032749272151184936, 0.016675182984077504, 0.0643281392487032, 0.031843261660209725, 0.006480425878960107, 0.023163736864392246, 0.014722019932898027, 0.023927115901772465, 0.02934271762413638, 0.06251875776797533, 0.04180922778323293, 0.029713153639542203, 0.016788240488884703, 0.025153722314696227, 0.08529434885297503, 0.0216167516607259, 0.016862920053037148, 0.03771503569026079, 0.02633322143395032, 0.014031548635102808, 0.047778120530503135, 0.03159256671954479, 0.051402081070201736, 0.017664856842852066, 0.10115127119102649, 0.12317047214933804, 0.03610904847404786, 0.007564534000786287, 0.02167377065468047, 0.061461186302559714, 0.05544486056481089, 0.034472686637725146, 0.04188473855278321, 0.027656983883519257, 0.03365372879696744, 0.04790975632412093, 0.05945806950330734, 0.03481639515874641, 0.02700130022796137, 0.02449096323523138, 0.08042270490633589, 0.02095443702169827, 0.03302852323810969, 0.016840146721473763, 0.018240734602191618, 0.025522804652739848, 0.03124229676489319, 0.007326352942202772, 0.02962085252095546, 0.07118324962045465, 0.041346368512937, 0.021613245331017033, 0.01891339520391609, 0.025114514864981174, 0.043579858129045794, 0.050604561543358226, 0.08265652361192874, 0.018930660527465597, 0.038047334644943476, 0.010786173316384, 0.04668605913008962, 0.055711429832237105, 0.04831068231058972, 0.0719704113102385, 0.03848089138045907, 0.028889788713838373, 0.017822151438200047, 0.038542034170989475, 0.045968986715057066, 0.03793589544615575, 0.026914909149387052, 0.013037154717104775, 0.009016357212593513, 0.019765786161380153, 0.08802200534514018, 0.05767164286226034, 0.03926897248519318, 0.02862396922760776, 0.016823483597753302, 0.07048633308815104, 0.008879398311754423, 0.0670625539496541, 0.021102322032675147, 0.052711273676582744, 0.031917079484888485, 0.05635374465159007, 0.039861292844372134, 0.011860006721690297, 0.0456811046626951, 0.0308725969599826, 0.07515341908271823, 0.038298178863312514, 0.026134319071258818, 0.042522147563951354, 0.019868652070207254, 0.013913531039309288, 0.029855534035180296, 0.04984307561868003, 0.02667319631603147, 0.023479718748213987, 0.03406007627823523, 0.057996640780142376, 0.018982088392866508, 0.03988833585754037, 0.028066271117755344, 0.019405166851356626, 0.01919974376713591, 0.058038051772330485, 0.033323594368994236, 0.00668014248367399, 0.06603100430220366, 0.017161122623032758, 0.05457285146362015, 0.030002986480082785, 0.012983245109873158, 0.030497180497539893, 0.016128762126235024, 0.03598168745104756, 0.0251310931718243, 0.06097302785409348, 0.06869126869631664, 0.03582224868504064, 0.03480975230091384, 0.01758553270649697, 0.06219633149781397, 0.0705311910382339, 0.08638769268457379, 0.02623269647093756, 0.06856934273881571, 0.028780890628695488, 0.03126464092305728, 0.019837174830692153, 0.03413076266380293, 0.024403857998549938, 0.016830391084243144, 0.02959060003714902, 0.03119843965396285, 0.05246836831793189, 0.04322525233562503, 0.06398860032537154, 0.05046868829854897, 0.008558932159628187, 0.038014927812452824, 0.03734184482267924, 0.05710718993629728, 0.023368028491469364, 0.008220416976005902, 0.011991776525974274, 0.017041459579819014, 0.0031518846434274955, 0.05001897564423936, 0.046470420701163154, 0.0270678797803287, 0.0350899567295398, 0.023851252294012477, 0.04429274059033819, 0.01676420508218663, 0.05670765494661672, 0.03189273025574429, 0.07889928522386722, 0.03273479899923716, 0.05045490725232022, 0.02537073308069791, 0.045229675314788303, 0.07966650476945297, 0.05498770098867161, 0.011601343235400106, 0.029800813578601395, 0.06166037704263415, 0.05274943109335644, 0.04400119444887553, 0.02838436494182263, 0.036399732876036844, 0.030848033992307525, 0.019002161155055677, 0.006251530572106796, 0.043529361552957974, 0.04892199486494064, 0.016742044128477573, 0.02354336533296321, 0.04754907764228327, 0.030511134570198398, 0.03175841424880283, 0.03887748831350889, 0.036012547223695686, 0.011274165523770665, 0.07258290451552186, 0.05280426690088851, 0.04883915252451386, 0.031121218976165568, 0.007593016356362828, 0.03457391049180712, 0.01673137246897178, 0.009837703496616865, 0.048932043968566825, 0.04789068949009691, 0.058980543698583326, 0.019440002839214036, 0.03003263846039772, 0.021969773074878112, 0.027445825482053415, 0.0275726725147771, 0.052627576382032464, 0.03835627842428429, 0.010677519503847828, 0.033472858502396514, 0.06501403637230396, 0.023437507084703872, 0.016885435541293452, 0.03961227388520326, 0.03256818472540804, 0.06124805845320225, 0.029336047624903064, 0.06694950323019709, 0.009848250475312983, 0.027422935103199313, 0.005641444893886468, 0.059341917878815105, 0.05933965835720301, 0.010932887006284935, 0.050161037128418684, 0.017155555243204747, 0.0462274169549346, 0.011876925144211521, 0.024240699164303284, 0.017432692693546414, 0.030872725881636143, 0.007816678461884814, 0.050655913073569536, 0.04489810239257557, 0.012174739252908953, 0.024679619719141295, 0.03104631888813206, 0.060782094885196, 0.01517459939766143, 0.022904180256383758, 0.01800283174296575, 0.024870717232780795, 0.09066102480781929, 0.031942110641726425, 0.058822852160249434, 0.034157707289393456, 0.04103292265374746, 0.019631290342658758, 0.020197251312700764, 0.023002343917531625, 0.015583662715341364, 0.021100189736379043, 0.04223221294315798, 0.008268743088202817, 0.048316585565251965, 0.03206178725564054, 0.05758532642253807, 0.005257517481887979, 0.022206061020759598, 0.062421842611261776, 0.009030880406498909, 0.04413147995780621, 0.01843708397687546, 0.06933804827609233, 0.03333117699782763, 0.022170366686103598, 0.027943513954856565, 0.04323913516210658, 0.03182408626058272, 0.03726326707484467, 0.03110366527523313, 0.051649166204567463, 0.013142193634329098, 0.017554067341344695, 0.04120958263852766, 0.02384686386877937, 0.06277687927441937, 0.11189871627305235, 0.026740227094186202, 0.052138335670211484, 0.007348674199809986, 0.007465596809717161, 0.03865936644641416, 0.05341736739501357, 0.029041495573307787, 0.04838563668142472, 0.022580301921282495, 0.011188786310542907, 0.0860862602878894, 0.03521937371364661, 0.05086449473830206, 0.02798078249075583, 0.11647185230893747, 0.00584788917331025, 0.03024618700146675, 0.022744186787999103, 0.018032658446047987, 0.04691965498828462, 0.055129419812666516, 0.017383461585268378, 0.07680930915687766, 0.25073733553290367, 0.11414924051080431, 0.12299435159989766, 0.16281571265842232, 0.16432037763297558, 0.17876676815961087, 0.26066815693463596, 0.189458770145263, 0.07783556623118264, 0.3019126366291727, 0.08956575393676758, 0.20116102934948035, 0.13042276299425534, 0.13328928846333707, 0.13890746342284338, 0.09652957240385668, 0.11524845367031437, 0.10704261756369046, 0.10015905621860709, 0.11019827358956848, 0.11235481394188744, 0.09598705651504652, 0.141021602121847, 0.08753920053797108, 0.16840525344014168, 0.08340929036161729, 0.13487562191273483, 0.14933345253978456, 0.14053605603320257, 0.12688223512044974, 0.20081197736518724, 0.11181919875421695, 0.12941849045455456, 0.14390666516763823, 0.12586272268423013, 0.14590497793895857, 0.09394541928278548, 0.11842949369124003, 0.14982298841433866, 0.1455307523054736, 0.0820847764345152, 0.07748755240546805, 0.10175870931042091, 0.17802909202873707, 0.1584961994418076, 0.11917799924101148, 0.10175139470291988, 0.10707588613565479, 0.16604720854333468, 0.14472250853266033, 0.10411275763596807, 0.09611048882028886, 0.21975907709981712, 0.05839375339980636, 0.09271029555904013, 0.16559949756733008, 0.16273673118225165, 0.1679171696305275, 0.1295275038906506, 0.10191743222198316, 0.1276374174548047, 0.09020564638610397, 0.09982642478176526, 0.09082700125873089, 0.13783920503088407, 0.12016399204730988, 0.12335956628833498, 0.11102215759456158, 0.08540934018258538, 0.16492188535630703, 0.16813766637018748, 0.08444123355937855, 0.08522787956254822, 0.06692353569503341, 0.164514547213912, 0.10272896688963686, 0.177577798387834, 0.19168011737721308, 0.07678802351334266, 0.14875734916755132, 0.14534492870526655, 0.1616868203771966, 0.16263343101101263, 0.08196072666240589, 0.10071940400770732, 0.20511034743062087, 0.1485583484172821, 0.1278929944549288, 0.10930487367191485, 0.11666387771921498, 0.17556602348174366, 0.16456912857081207, 0.15113759573016847, 0.0777896022690194, 0.12082103107656751, 0.12288536530520235, 0.11165231985173055, 0.1238821196768965, 0.1196628532239369, 0.13275851123034954, 0.12256192123251301, 0.17859043047896453, 0.11287051412676062, 0.06684306144182171, 0.14867911407990114, 0.1887868576283966, 0.07708332873880863, 0.18817614897021226, 0.1854243909141847, 0.1392933598586491, 0.18452458562595503, 0.167461967627917, 0.13044957869819232, 0.08669002074748278, 0.16442721975701197, 0.16447834058531693, 0.1641243217246873, 0.13773180650813238, 0.1310560397271599, 0.1374768130481243, 0.166351585782, 0.05674802099487611, 0.10379220412245818, 0.12676190372024262, 0.12979477883449622, 0.093996268697083, 0.10763240698724985, 0.11921421944030694, 0.09836784590567861, 0.13832101917692594, 0.09512947646102735, 0.10507876080061708, 0.11602891821946416, 0.10477403072374207, 0.12775926877345356, 0.12178061529994011, 0.18527298261012348, 0.1018693173038108, 0.19935225855026925, 0.13600175934178488, 0.1627033201179334, 0.1948972147490297, 0.12730718803192886, 0.1924684936446803, 0.1200616689664977, 0.11878033700798239, 0.09236960312617676, 0.21958436790321553, 0.12784318998456, 0.05957061132150037, 0.09052021522074938, 0.19771073306245462, 0.18741518551749842, 0.11598750044192586, 0.0957968020811677, 0.14876170536237104, 0.13648740042533192, 0.1733177112681525, 0.15851891679423197, 0.1411159456308399, 0.20122857072523662, 0.11641970010740416, 0.13939238525927067, 0.20091060921549797, 0.1744410124208246, 0.14523226475077017, 0.049590589345565865, 0.246369795607669, 0.1025083005162222, 0.08859847512628351, 0.2718219698539802, 0.07463411587689604, 0.1689721830189228, 0.10454581904092006, 0.12413841592414038, 0.15109165890940598], [0.06339412901018347, 0.06878876060779605, 0.031939976649092774, 0.03302431292831898, 0.022205472391630923, 0.03497120292325105, 0.02157836014937077, 0.06189375237694808, 0.044016135789986165, 0.008649536092499537, 0.02349915199114808, 0.07836734769599778, 0.02960493408941797, 0.06572219622986657, 0.019163484552076886, 0.05826077410685165, 0.05596624008779015, 0.0244979317898729, 0.0588187538087368, 0.028745803582881178, 0.04354744451120496, 0.05789553906236376, 0.030801737547985146, 0.036870720995856185, 0.044371660998357196, 0.062379861649657996, 0.05333312387977328, 0.028636030187564235, 0.08675423730164766, 0.055746577946203094, 0.015020736493170261, 0.02343361229369683, 0.03656648624954479, 0.08266223009143557, 0.02359758028095322, 0.00807941994363708, 0.009615028659547014, 0.021475802973977158, 0.02194738481193781, 0.018519985689116374, 0.03815705036478383, 0.08251367163445268, 0.03145219478756189, 0.020873070494937043, 0.023373451682605913, 0.032556863368621895, 0.034381613667522154, 0.03398921686623778, 0.008203024427140397, 0.023087980125897696, 0.08026390735592161, 0.0544867284063782, 0.06432047180299248, 0.03909828360857708, 0.02019744469518108, 0.03204231669328042, 0.0256161575006055, 0.029091072734445333, 0.09404491965792008, 0.03076236555352807, 0.024669784354045987, 0.01294057967606932, 0.048959636595100164, 0.01910618396608957, 0.002516127228903185, 0.03837006625586322, 0.027756982981892567, 0.032723806731935055, 0.030033775006553957, 0.06732957105019263, 0.05314599070698023, 0.05094919626467994, 0.04621645522170833, 0.07449610185410295, 0.05159509374893137, 0.033143304221864255, 0.03112281353345939, 0.034912160198603354, 0.02884197235107422, 0.005449892337700086, 0.04095733045999493, 0.02813804824836552, 0.08470676466822624, 0.04328438666250024, 0.044364977428423505, 0.014791903950806175, 0.018024346392069544, 0.025009966189307824, 0.11158418136515788, 0.03834148296820266, 0.03371507854067853, 0.02904539375698992, 0.019446398031764796, 0.014354242078427757, 0.05037571543029376, 0.03706321459529655, 0.05115774060998644, 0.05523084722725408, 0.03816456174744027, 0.025903606986893073, 0.022468109548624073, 0.0062181559790458, 0.030193359657589878, 0.017617108333589773, 0.01591250453410404, 0.028343847919521586, 0.031231701440576996, 0.06983103789389133, 0.02658307329485459, 0.03253295857991491, 0.017808061658537815, 0.04341874338154282, 0.06065596879592963, 0.07155978905835322, 0.047984917648136616, 0.02780268570807363, 0.027509243061233844, 0.037863570398518016, 0.03102381866691368, 0.020864169811829925, 0.01593676894637091, 0.0646641565752881, 0.033621508561606915, 0.0372992463942085, 0.07563644780644349, 0.012887452080446695, 0.07119591786925282, 0.06287910057497875, 0.04263350873121193, 0.06422904599457979, 0.07024878476347242, 0.06707835024488823, 0.036675747350922654, 0.01203279142334525, 0.048921211156994104, 0.02252632615688656, 0.050385364198258946, 0.053342334992651425, 0.04810699627601674, 0.04570613242685795, 0.029480663793427602, 0.015736312738486698, 0.04198297346010804, 0.06578001419880561, 0.016625064691262584, 0.02726034793470587, 0.03557926868753774, 0.04358244674014194, 0.08404905388930015, 0.050524541908609014, 0.011335494911431201, 0.07485525043947355, 0.02154708307768617, 0.04300792096182704, 0.030062090272882154, 0.04478162846394947, 0.06956770523850407, 0.09104242934180157, 0.03142228496393987, 0.018411316609542285, 0.07022362468498093, 0.05475147580727935, 0.04671077476814389, 0.04998690129390784, 0.09167603855686528, 0.029931031234030212, 0.015975628646888902, 0.0436982828458505, 0.03344288421794772, 0.022320295783824155, 0.030971771638308252, 0.0912390077220542, 0.07790616101452283, 0.054124075187636275, 0.020839615325842584, 0.030289650562086275, 0.020428054999294024, 0.057631853568766794, 0.03380266723356076, 0.07444460104618754, 0.015292287903970905, 0.014251043687441518, 0.024474890436977148, 0.03867649267028485, 0.03614041714795998, 0.04388594527595809, 0.021858808850603442, 0.06375032596822296, 0.027517911346097077, 0.016963763927508677, 0.035468338390014, 0.03912549286282488, 0.03121985761182649, 0.058352179559213777, 0.016544519191873924, 0.04715079115703702, 0.055494512364800484, 0.06690653839281627, 0.03701171718005623, 0.05336505234507578, 0.02396190439217857, 0.011335556827751654, 0.05690436903387308, 0.01614251433472548, 0.03882623517087527, 0.054068021409745724, 0.025769528467208147, 0.03106285139386143, 0.03143661901620882, 0.03351295652932354, 0.0342075355084879, 0.03414550722975816, 0.043380959159029384, 0.008114395879342087, 0.03149981437517064, 0.021563864945034896, 0.0508333974783974, 0.04819358412974647, 0.03549662312226636, 0.05380633080910359, 0.010685693306316222, 0.027154381120843545, 0.06258008376296077, 0.02384513699715691, 0.04485357353197677, 0.008085765094230217, 0.07701749048594918, 0.044983675836452415, 0.053005700199199576, 0.04138782700257642, 0.009818795270153453, 0.03853485527049218, 0.015294713666662574, 0.03687483291806919, 0.01296722998709551, 0.017744543995442133, 0.03307026331978185, 0.07243673450180463, 0.0361927695173238, 0.007495637251330274, 0.010296918185693877, 0.020513519877567887, 0.052584475837647915, 0.039092862113778076, 0.015408179988818509, 0.007380550926817315, 0.04714257409796119, 0.030323682485946586, 0.04636672019426312, 0.0256832272945238, 0.024784762112955962, 0.03652864095887967, 0.012714976112225225, 0.03936980278896434, 0.05387988400512508, 0.10881267115473747, 0.010915729400169636, 0.06548957406942334, 0.07404240619923387, 0.05228531653327601, 0.07453988093350615, 0.013525502307207456, 0.0341345421038568, 0.06871369427868299, 0.06416273955255747, 0.006122531311120838, 0.02261821845812457, 0.030680167821369002, 0.03453529506389584, 0.04108872876635619, 0.11108047089406423, 0.03244188560971192, 0.02106178974333618, 0.04233748086595109, 0.04349117699478354, 0.03498601534270814, 0.038151866357241354, 0.045464777520724704, 0.027038271904789975, 0.005736211639097226, 0.059172820166817734, 0.02141576280285205, 0.11006201697247368, 0.0415917132049799, 0.009658772115861731, 0.06749318619923932, 0.017440931805010353, 0.04109346494078636, 0.03453679123361196, 0.04801197423200522, 0.02843625081836113, 0.02398939014944647, 0.03045673981042845, 0.03204091891114201, 0.029539173868085657, 0.02541480223382158, 0.03772801945784262, 0.051553367237959585, 0.07849196743752275, 0.024610398969213878, 0.032627447973936796, 0.01909165483500276, 0.025516853900626302, 0.014705701165699532, 0.11313409784010478, 0.052865050067859035, 0.03795192583597132, 0.046655311315719566, 0.040012660436332226, 0.01844863603556795, 0.06260162724980287, 0.0168974337367607, 0.02015361811832658, 0.09310536578829799, 0.02627918460140271, 0.04156928762261357, 0.025457449856081178, 0.0488484688103199, 0.03933295833745173, 0.018300381223005906, 0.031687744826610596, 0.03143473947420716, 0.043358859273472, 0.05414377984457782, 0.04785539209842682, 0.013353566622494586, 0.03540710060458098, 0.039717304320739846, 0.054531206376850605, 0.051013806369155645, 0.02782267195704792, 0.024960441614634225, 0.037471119314432144, 0.05752421077340841, 0.0529325405534889, 0.06698881754917757, 0.06224253973258393, 0.056948283820280006, 0.064357458746859, 0.07489943663988795, 0.06494628465069191, 0.038358568479972224, 0.05625073625040906, 0.058414903336337635, 0.06507810364876475, 0.02114169572346977, 0.009975328209943004, 0.0301052417073931, 0.020476685604080558, 0.021957964869216084, 0.03160405771008559, 0.06076907379818814, 0.0949106149907623, 0.07190472912043333, 0.15265546499618463, 0.1273948276149375, 0.0582625043711492, 0.09643278616879668, 0.13503414126379149, 0.14118763964091027, 0.09776445185499531, 0.09957361620451723, 0.0977455817961267, 0.17969402697469505, 0.12221955960350377, 0.13119579079960073, 0.12115043268672057, 0.1066710450021284, 0.0968770162601556, 0.15821646659501962, 0.1924861084137644, 0.11892061733773776, 0.18852735869586468, 0.16246230447930948, 0.26467403769493103, 0.18120538230453218, 0.11866630241274834, 0.14491168409585953, 0.16309274493583611, 0.1420952616525548, 0.21798614652029105, 0.15263487824371882, 0.08632000203111342, 0.1581756052161966, 0.10426308706934963, 0.11197781988552638, 0.0625194227322936, 0.10580737170364175, 0.13081916315214975, 0.05580712701859219, 0.12214337369160992, 0.17422305340213434, 0.11774348121668611, 0.12255928851664066, 0.1528644673526287, 0.15739809907972813, 0.08008109645119735, 0.1430042814463377, 0.07945432008377143, 0.14362712231065544, 0.08813288475253753, 0.14710899761744908, 0.12072334917528288, 0.199845892776336, 0.13287885620125703, 0.1141326299735478, 0.13854626566171646, 0.12259831785091332, 0.07215069127934319, 0.14214657247066498, 0.2581104056111404, 0.1082569102623633, 0.1399384702422789, 0.1412728772099529, 0.13144941361887114, 0.12033557998282568, 0.10430488482649837, 0.08293958128030811, 0.12199246750346251, 0.13875224175197737, 0.12605849360781057, 0.1583005235131298, 0.1199080893503768, 0.12064370273479394, 0.12970441154071263, 0.08680152440709726, 0.12304710091224738, 0.14812129044107028, 0.09299440495669842, 0.11216825752386025, 0.10876751464924642, 0.19111960673970835, 0.12133705695824963, 0.10416815323489052, 0.1453981665628297, 0.18346836444522652, 0.13610887287982873, 0.1033959396715675, 0.07189112449330942, 0.21578162695680345, 0.2247072122991085, 0.17961117784891809, 0.13185137776391848, 0.15322204173675605, 0.10382188324417387, 0.06501806008496455, 0.12183561734855175, 0.1473286258322852, 0.2157390828111342, 0.14152473583817482, 0.20427087747624942, 0.061458852142095566, 0.13334393767373903, 0.13448211231401988, 0.09344074529196535, 0.06515825899051768, 0.11389291712215968, 0.14974106209618704, 0.23444967237966402, 0.10341505400304284, 0.0782004620081612, 0.12438262067735195, 0.07299761833356959, 0.1477256366716964, 0.15893811572875294, 0.18872756723846706, 0.0773456571623683, 0.15400055210505212, 0.08560971157359225, 0.14382730371185712, 0.13477954135409423, 0.11477666827184813, 0.08085937611758709, 0.12567061584975037, 0.10303132887929678, 0.1486673889947789, 0.1626604909875563, 0.08607513231358357, 0.1503242900861161, 0.1025207516338144, 0.15993183026356356, 0.14404184291405336, 0.09196489091430392, 0.13614083187920706, 0.15345007021512302, 0.1610931565186807, 0.16250864842108317, 0.09224919030176741, 0.17232934358928884, 0.14366836366908892, 0.09919068496674299, 0.0967956395553691, 0.19557237066328526, 0.08309153919773442, 0.15693075130028383, 0.14858684688806534, 0.19339837160493645, 0.07983107665287596, 0.08667453657835722, 0.10425695311278105, 0.16541385038622788, 0.11728179241929736, 0.09453134105673858, 0.12624665136848176, 0.33103098986404283, 0.1447486457015787, 0.10690429141478879, 0.16589406318962574, 0.10630516534937279, 0.2311027848294803, 0.1504805702716112, 0.13094713485666684, 0.129095765628985, 0.09510330536535808, 0.106669938990048, 0.18190147780946322, 0.16046175254242762, 0.10104885311531168, 0.21508627784039291, 0.14714685987148965, 0.11175562680831977, 0.10483726340212993, 0.1246639277253832, 0.18638430083436625, 0.18169881297009333, 0.16500565728970937, 0.08091186080127954, 0.1141185707279614], [0.04531107237562537, 0.02715562792894031, 0.016837715869769454, 0.03927742363885045, 0.038607777428946326, 0.06217657255807093, 0.05160409790862884, 0.03533126074554665, 0.06799345649778843, 0.018700355564111044, 0.023778825466121947, 0.019211453585220233, 0.05298709137631314, 0.018995021270321946, 0.03513741686141916, 0.0418509101894285, 0.0817234158249838, 0.07275693517710481, 0.07043433694967202, 0.0488244690267103, 0.008125307570610727, 0.06331516789006335, 0.0020537917028247777, 0.03158579494005867, 0.047171547543257475, 0.01089526987301984, 0.03552758128249219, 0.047331291650022776, 0.012640621396712959, 0.03571830390553389, 0.033979557920247316, 0.0054658162823346046, 0.03993035413857017, 0.03962124411814979, 0.039333613123744726, 0.020917694350438457, 0.08524462580680847, 0.02091785889518048, 0.07560763720955167, 0.00531015610821279, 0.04984552513009735, 0.042319601468209705, 0.08787614745753151, 0.07756617425807885, 0.015320157033524342, 0.050922210926988294, 0.023683793244085143, 0.08203106360243899, 0.024299987857895236, 0.05959029562239136, 0.009466568590141833, 0.06963691581040621, 0.01985311192194266, 0.035446452242987495, 0.015079696097278168, 0.06590453894542796, 0.05990645901433059, 0.014263155537524393, 0.048767492441194396, 0.04008180994008269, 0.05843629754547562, 0.036469442171177695, 0.046263087540864944, 0.03437336946704558, 0.03421453459720526, 0.026078156727765287, 0.014706042129546404, 0.040262164548039436, 0.07857953238167933, 0.03777836675622633, 0.01072553773078003, 0.06908891735864536, 0.023144267998369675, 0.08570438756474427, 0.01676008807096098, 0.023609120465282882, 0.04123918033604111, 0.03190551385549562, 0.021981072379276156, 0.02638019641329135, 0.0633386384163584, 0.044249667187354395, 0.03542666616184371, 0.04715221608057618, 0.008570104238710232, 0.03179362682359559, 0.06528412045112678, 0.04966146232826369, 0.02344417878027473, 0.0518422806635499, 0.02629300975240767, 0.025349245572994863, 0.03591363378135221, 0.0054012002406774885, 0.03434353428227561, 0.040162263837243826, 0.022186524301235164, 0.04407324129715562, 0.0350265510247222, 0.020562140304329138, 0.04613375537363546, 0.01845889039603727, 0.014559347947527255, 0.06503249931016139, 0.030986672267317772, 0.029086451910968338, 0.016841018638972725, 0.012289480372731174, 0.020220326592347453, 0.05005033753280129, 0.03022643823974899, 0.00949900086769568, 0.023425305328731025, 0.07453138567507267, 0.036811623988407, 0.07083072353686605, 0.027234680651287948, 0.040540004282125404, 0.00888890289102814, 0.08108057174831629, 0.06502547647271838, 0.039202934064503224, 0.0590223278850317, 0.03601471175040517, 0.03579088679647871, 0.004113283099806202, 0.01858395118532436, 0.0042003497448084605, 0.014419786864891648, 0.026003667153418064, 0.03792512370273471, 0.03730460682085582, 0.025802990421652794, 0.03117762559226581, 0.01942635410731392, 0.03170517299856458, 0.045925770819719346, 0.035183536886636696, 0.05777383702141898, 0.011123145681007631, 0.03271057190639632, 0.06162651814520359, 0.017988931953108737, 0.06325488005365644, 0.08711299912205764, 0.020945929888901964, 0.033559178334793875, 0.026168244125853692, 0.027435038471594453, 0.08339942446244614, 0.04016118835923927, 0.031169045516955, 0.004779922551408942, 0.041595618174012215, 0.03393601293542555, 0.04386231190125857, 0.053996191692671607, 0.05973665562591382, 0.01818693016788789, 0.050089495788727484, 0.05549427487754396, 0.036155531515500376, 0.01463998674548098, 0.03194816656676786, 0.02578278534513499, 0.027331706069942032, 0.03371612009193216, 0.01202127244323492, 0.039320530968585184, 0.06399585386472088, 0.023863309861293862, 0.028629248230052844, 0.035185294292334995, 0.05418257508426905, 0.027254088449158838, 0.008773660503460892, 0.04436775263664978, 0.05194135356162276, 0.031049002494130815, 0.04062014266050287, 0.04273554343464119, 0.032777461888534684, 0.02793965139426291, 0.019658460581142987, 0.031005216629377434, 0.08115485097680773, 0.031190147956034968, 0.03318667957293136, 0.012506430918749954, 0.03956600118960653, 0.010068848147056997, 0.006331888626196555, 0.041510614699551036, 0.053663339731948714, 0.051666607947221825, 0.006736051224704299, 0.050939798554671664, 0.009928448225504585, 0.015884177393413017, 0.010288111649320593, 0.061006757829870494, 0.045985668498490534, 0.03628097228439791, 0.049561083250279934, 0.023687693124104823, 0.02891783256615911, 0.04148645546021206, 0.08268278291715042, 0.02989008164565478, 0.02116939182659345, 0.045287489891052246, 0.021359839642952596, 0.023978928835796456, 0.04391623168651547, 0.043384572358003685, 0.030861414702875272, 0.041749041727078814, 0.04935128700786403, 0.0867458370381168, 0.05519139041591968, 0.045881231781095266, 0.024088147528735653, 0.036248972572918446, 0.030230173575026647, 0.04957406023251159, 0.029364532524985925, 0.02353510077643607, 0.11028517356940679, 0.03426793869584799, 0.06358747756374733, 0.03155262814834714, 0.018711865214364867, 0.006663350014215601, 0.04957845713943243, 0.024675823315711956, 0.018744107502113496, 0.04504846575270806, 0.032463683547186, 0.025467100320383906, 0.03644868917763233, 0.05401033575513533, 0.02563974168151617, 0.025403228122740984, 0.10686864797025919, 0.0465331037661859, 0.015697907656431198, 0.025831650044502955, 0.02152531228161284, 0.049675555500601015, 0.05580037220248154, 0.04415170030136194, 0.059139911218413284, 0.0777636958020074, 0.06551793683320284, 0.001822744167709191, 0.05141415899353368, 0.049702177822057686, 0.05270430512194123, 0.06592039630881377, 0.05775578120457275, 0.05665772155459438, 0.028992427313434224, 0.0454905313173575, 0.06711008532771043, 0.009233633455421244, 0.029601049476436207, 0.017832991035122956, 0.06428916419723205, 0.019976583242948567, 0.019774383200066428, 0.019895881680505614, 0.056455205992928574, 0.00571129540912807, 0.027716903614678552, 0.058042767590710094, 0.013476847105526497, 0.046779340731778314, 0.03971735181819115, 0.03003016859292984, 0.03564779054639595, 0.050275081901678016, 0.034384816352810176, 0.08089840545185975, 0.004921361903793046, 0.010837193212604948, 0.02542124662016119, 0.11947633751801082, 0.049395038945866485, 0.02518789333823536, 0.06996772198804788, 0.038534495646932294, 0.05854461209050246, 0.04416111497474568, 0.13076061915074075, 0.00954384439890938, 0.08154318335333041, 0.04132060453827892, 0.030841302924922535, 0.03556888710175242, 0.02624040293241186, 0.024594882569674934, 0.036673816918794594, 0.018181717322607125, 0.031566500796803405, 0.017695616531584944, 0.04286256179745708, 0.013530305486970713, 0.037271341641566584, 0.04089981783181429, 0.06976215980414834, 0.025360368458288055, 0.03972719396863665, 0.036218048339443545, 0.0391998365521431, 0.08267566508480481, 0.008896963887049683, 0.023986565747431347, 0.04607918080208557, 0.038343678028987985, 0.05427204331915293, 0.05597031808325222, 0.02630111146053033, 0.032157175708562136, 0.04811630916914769, 0.03196454979479313, 0.045170768297144344, 0.049490030455802164, 0.01901909738912114, 0.03873630553217871, 0.03368290580276932, 0.021647826868242452, 0.01869425892696849, 0.017560479497270923, 0.045175219486866675, 0.01634566263029618, 0.027546976393620883, 0.03007416141086391, 0.026456507854163647, 0.014001497167295643, 0.028720005681472163, 0.00807389836492283, 0.019741832178884318, 0.022629039395334463, 0.061610212948705466, 0.04734482163829463, 0.08399476430245809, 0.010514314020318645, 0.01547321248134332, 0.05910602517958198, 0.04501940070518425, 0.058432728451277526, 0.02088316370333944, 0.08119521702506713, 0.11633567033069474, 0.1730042416602373, 0.1285026038863829, 0.09196592228753225, 0.14775538364691393, 0.1420757605561188, 0.06726498130176749, 0.08214230263339621, 0.1321168885167156, 0.08315726209964071, 0.20790602027305535, 0.10527663518275533, 0.1558200301868575, 0.14638725348881312, 0.10559377566512142, 0.11256027434553419, 0.18106782968555177, 0.1776630902396781, 0.13682981633714267, 0.18101170126880917, 0.12001529788332325, 0.1419503130018711, 0.06338201037475041, 0.143085651365774, 0.16455870627292565, 0.12802921714527266, 0.12088712038738386, 0.16791398051593984, 0.056589980011007616, 0.12119673591639314, 0.1430883247937475, 0.1250313680086817, 0.0974109758223806, 0.12232792164598193, 0.08946802453803164, 0.15184491420430796, 0.1381036436983517, 0.16519002882497652, 0.09357319532760552, 0.16177181367363247, 0.13178170578820364, 0.21437479316123895, 0.27342716657689636, 0.13621291943958827, 0.13229148914771421, 0.11259338685444423, 0.2232480498829058, 0.1572188844106027, 0.10192319298429148, 0.12569945358804294, 0.23958998226693698, 0.09773602123771395, 0.12772041585828575, 0.11790585464664868, 0.1503370058323656, 0.11399350315332413, 0.07838411429630858, 0.14896084181964397, 0.10242243869496243, 0.15817648731172085, 0.16004842972116812, 0.09845904779753514, 0.12709790069077695, 0.16848523914813995, 0.13743151405027934, 0.09788196054952485, 0.10874284311596837, 0.18185126621808323, 0.2024526750402791, 0.07413093466311693, 0.1308462909821953, 0.13249397756797926, 0.14241687368069375, 0.08905394854290144, 0.1567603847278016, 0.24803885604654038, 0.16811212631208555, 0.05903938625540052, 0.08993226462709052, 0.15798786814723695, 0.09610404952296189, 0.14981183329863207, 0.1061357283698661, 0.14831638282963208, 0.11170110651957137, 0.14590043175433362, 0.1595187924270119, 0.12510217992322786, 0.15395206399261951, 0.13451740970568998, 0.1294440712247576, 0.18367348558136395, 0.04998352897486516, 0.1080980652144977, 0.17098535570715154, 0.09248135105839797, 0.10243046576423304, 0.1339649600642068, 0.097680171020329, 0.15213459437446936, 0.20631212794354983, 0.10759831738791295, 0.12589852219181402, 0.08783023099281959, 0.1978018603154591, 0.16859645103769644, 0.09240880209420409, 0.05595877280990992, 0.08926945126482419, 0.2022330875375441, 0.10937011481395789, 0.11688712931105069, 0.13674946422023432, 0.18577273722205842, 0.22213975792484625, 0.12182125954755715, 0.2890777124890259, 0.13819128328136035, 0.24763982317277364, 0.11575894270624433, 0.13338432407804898, 0.12078479730657168, 0.09638452197292022, 0.10103733837604523, 0.13093865316893372, 0.171589374010052, 0.1839788399104561, 0.10645053469176803, 0.15735647774168424, 0.10774582411561694, 0.0750220004203064, 0.15889866570276873, 0.2025941495916673, 0.17878776203308785, 0.09121327767414705, 0.12397045136562415, 0.0980948441262756, 0.1941661611199379, 0.05676276216815625, 0.16402691123741014, 0.10210084023752383, 0.16551211582762854, 0.14382756155516419, 0.17314058648688452, 0.07736321086330072, 0.0852554552257061, 0.11482061019965581, 0.15926477605743067, 0.19996816478669643, 0.11270375736057758, 0.1289708066199507, 0.11573162488639355, 0.17187380231916904, 0.13870857123817715, 0.136601326454963, 0.16236146060483797, 0.1503725882087435, 0.10871534209166255, 0.14569168724119663, 0.09344959338860852, 0.14258634458695138, 0.10755094885826111, 0.10305381552981478, 0.12709844351879188, 0.0631453034334949, 0.16646099276840687, 0.132351227370756, 0.2031024130327361, 0.17307409005505697, 0.11657151553247656, 0.09240209138286964, 0.12177254073321819, 0.13661526356424603, 0.12917941542608397, 0.110375927628151], [0.013445216347463429, 0.03240034230319517, 0.04086814720981887, 0.06246529599385602, 0.06658314860292844, 0.04182127856516412, 0.031102226780993596, 0.03337546158581972, 0.0019040110346395522, 0.017605064337008765, 0.02326131528908653, 0.07442591419177395, 0.04596903760518346, 0.06988692882337741, 0.03668189487819161, 0.0068656391148189345, 0.01377598605384784, 0.03179981167029057, 0.014900886852826391, 0.02091259685611086, 0.004530387905625892, 0.03356230638122984, 0.013045183482712932, 0.01068289774203939, 0.016838996604617153, 0.018661908073616878, 0.04974354810214468, 0.015509240994496005, 0.032423768724714, 0.014124624979948359, 0.02974996416430388, 0.0014704874837272136, 0.02633327741308936, 0.10611016117036343, 0.01199497836309352, 0.12909221010548727, 0.053949230284030945, 0.022160977457783053, 0.04122861893847585, 0.007384980064151543, 0.039596542050795894, 0.07725577162844793, 0.013528767756984701, 0.03530817698421223, 0.036020608219717226, 0.022331625622298037, 0.05120728384437306, 0.07980140431651048, 0.014785471438829387, 0.02152410109660455, 0.013340546383655496, 0.0054460505572413755, 0.03612756908738187, 0.08124992730362074, 0.018238100189981715, 0.028116820280307105, 0.01932365443956639, 0.033222194095807414, 0.023201621170820932, 0.031102331953921487, 0.02982180066672819, 0.02201216115749308, 0.02140819374471903, 0.03601364984310099, 0.02035529399290681, 0.024385624066261307, 0.08743015317512409, 0.03637156688741275, 0.026806716740663563, 0.0200638190976211, 0.1090443976489561, 0.020248131261074116, 0.03666688229090401, 0.031717247529221435, 0.04901384815041508, 0.06611128856561013, 0.007702558201604656, 0.0422793405928782, 0.03241995196523411, 0.052279040084353516, 0.027779332229069302, 0.037382353363292556, 0.01345086599966245, 0.027772828470915556, 0.03207356323088918, 0.033156287989446094, 0.0825661698888455, 0.037445789602185996, 0.009427431538434965, 0.014782881131395698, 0.02573521664765264, 0.017425635929352472, 0.010641713210913752, 0.04534281763647284, 0.006691159771954907, 0.03103328762309892, 0.03495387653154986, 0.011604271962174346, 0.06119563483766147, 0.008530465919258339, 0.056062120478600264, 0.02982056912566934, 0.014853579391326224, 0.05890409315803221, 0.021104381386456744, 0.027655676007270813, 0.04372968205383845, 0.04381272116942065, 0.0590315152491842, 0.07450575062206813, 0.02701495574521167, 0.02412835581760321, 0.004300136376904058, 0.01932944403961301, 0.02044032291243119, 0.02506157217015113, 0.033772760802613835, 0.05065168580040336, 0.01670320817668523, 0.024392014169799428, 0.010185714777825134, 0.04952232533001474, 0.035138322705669064, 0.015013155560674412, 0.031418563199362586, 0.05133173395214336, 0.02309856696852616, 0.026431731147957698, 0.04475096207378166, 0.05537767881261451, 0.051217417764876566, 0.036279934125819376, 0.011797819835399943, 0.009040507970244756, 0.06529100079621587, 0.013761348357158048, 0.04413993111146348, 0.023477201383294802, 0.027883962328944887, 0.02208711043931544, 0.03345278065119471, 0.016248762740620544, 0.029921368895364658, 0.021356231532990932, 0.005432726673981441, 0.035024542561067004, 0.008947197530817772, 0.02643331213455115, 0.021080771760482873, 0.028348287234881094, 0.0240949023448463, 0.039117628641958745, 0.02829754808252411, 0.01966504067448633, 0.03009978628584317, 0.07157477789691516, 0.04608273632558329, 0.0316229820517557, 0.05568904835464699, 0.07637911795505456, 0.016110479000157545, 0.04472084529697895, 0.006738920579664409, 0.037883526113416464, 0.06751068561737027, 0.03139871944274221, 0.062121869064867496, 0.025950234217037047, 0.004858036775008908, 0.021242677001282573, 0.044153773225843906, 0.007317422573188586, 0.012693447892421057, 0.012334602103302521, 0.0323256254196167, 0.059521885721811225, 0.06266494813774313, 0.012873205389561397, 0.008439120686879116, 0.023224197727228914, 0.02964632472555552, 0.0393310143346233, 0.03585213475993701, 0.04076181398704648, 0.036946350509034734, 0.04037351553727474, 0.020839192937793474, 0.024452522530087402, 0.012232660698438329, 0.07888872043362685, 0.04604137622352157, 0.02753712236881256, 0.058625717381281514, 0.0460106894773032, 0.02680055733903178, 0.01892913382367364, 0.08070559972631079, 0.049129674078098366, 0.024471100818897997, 0.029275546049965278, 0.051410878276718516, 0.015232866896050317, 0.024785678135231137, 0.07440279650368861, 0.06888545184795346, 0.029488867281803062, 0.030159076675772667, 0.017310963511200886, 0.0774217141526086, 0.03850791064490165, 0.05133880767971277, 0.08978990798017808, 0.011941359677751149, 0.037736355260546715, 0.008881522974531566, 0.022437013985056962, 0.013193766536590244, 0.09221599636865513, 0.044224334082433155, 0.03211718963991318, 0.04099073473896299, 0.0773557944755469, 0.06124379725328513, 0.04444666965199368, 0.02006688098689275, 0.016713437092091357, 0.01614350499585271, 0.044970356194036346, 0.019388403643720915, 0.04499075634937201, 0.022099948321868266, 0.012141610628792217, 0.024439006112515926, 0.07516586341496025, 0.053947157359548976, 0.03020944433020694, 0.025427862336593013, 0.05006164871156216, 0.09315654768475465, 0.038035507779568434, 0.022611312667972276, 0.013874589914589055, 0.014343862188979983, 0.060357963001089435, 0.03402708251295345, 0.027754686140854443, 0.08501516561955214, 0.05620634648948908, 0.08380153788519756, 0.0261636199097016, 0.04986266492466841, 0.032509287885789356, 0.03508864376427872, 0.061132551436977725, 0.011218485788309147, 0.0007339436581657667, 0.008482987975834735, 0.006254859210457653, 0.033481099310198, 0.057537476133022986, 0.034108469395765235, 0.02350350988230535, 0.046957982038812976, 0.020537026026951413, 0.034188970790377686, 0.022931243625602553, 0.013480578199960291, 0.10280970577150583, 0.026301666162908077, 0.06702026764729194, 0.08047432785055467, 0.016786539062325443, 0.026484762052340165, 0.04409533439736281, 0.02635880050781582, 0.02376811987986522, 0.061390679728771956, 0.038279739674180746, 0.042389962156968455, 0.031156448514333794, 0.04046460547085319, 0.02116035882915769, 0.030375729514552013, 0.01670359494164586, 0.030650882249964134, 0.0664726152483906, 0.02538218505547515, 0.017518252566722885, 0.028790495291884457, 0.03287762383531247, 0.009767272409849932, 0.033014955930411816, 0.047462954585041316, 0.04293247465310352, 0.04442548918138657, 0.009348187129944563, 0.038515042047947645, 0.06752208500568356, 0.018299600907734463, 0.03481861396825739, 0.0727880731491106, 0.012621501976224993, 0.044092745786266666, 0.059776085295847485, 0.04313209965558989, 0.05611825568069305, 0.06259915059698479, 0.02729607280343771, 0.029253758290516477, 0.011426902060130877, 0.07358063597764287, 0.009157226171477564, 0.03668951143377593, 0.017283810236092125, 0.033833784849515984, 0.009202215587720275, 0.051307849519486935, 0.06640490423887968, 0.053688035013952425, 0.042002138681709766, 0.0337822704709002, 0.04598536315773215, 0.03283235876421843, 0.02192866911978594, 0.033269545662083795, 0.0534454146400094, 0.022343231963792017, 0.03564113411786301, 0.07068000733852386, 0.03787543119064399, 0.04053290680583034, 0.05797977918492896, 0.03823996055871248, 0.020428757283038328, 0.03688842058181763, 0.02761458731921656, 0.057587538446698866, 0.05044049516852413, 0.03345349311296429, 0.028846240336341516, 0.03935513625453625, 0.03285351887877498, 0.0586468605324626, 0.06916925590485334, 0.028592183254659176, 0.04354387880968196, 0.018664981837251356, 0.0332684871474547, 0.060580542843256674, 0.03961020435339638, 0.03873773045571787, 0.027910564294350997, 0.16642952231424196, 0.171676117926836, 0.09373103614364352, 0.16006699443927833, 0.1575039369719369, 0.11398306728473731, 0.09990904320563589, 0.18669740403337137, 0.14359548900808605, 0.1663169940667493, 0.07923167917345252, 0.0999915666346039, 0.09290352876165084, 0.13753843759851797, 0.10286331682332925, 0.1244744128946747, 0.12509498745203018, 0.12770685872861318, 0.10255686326750688, 0.0726812310250742, 0.15786890738776752, 0.10672652881060328, 0.12579001087163175, 0.05889164204044001, 0.16782909578510694, 0.09515748638659716, 0.15885639297110693, 0.12301292988870825, 0.13468127591269358, 0.09456795480634485, 0.11574857469115939, 0.05349714614983116, 0.11527084532592978, 0.20651011089129107, 0.1815290299377271, 0.16513286903500557, 0.1107425604547773, 0.10798398990716253, 0.14537937114281313, 0.126777781439679, 0.09514856365110193, 0.18020218185016088, 0.06926398617880684, 0.18662607643221105, 0.125098000147513, 0.18607184902897903, 0.11055415842149939, 0.13697624419416699, 0.11746110208332539, 0.07147598319819995, 0.10427609458565712, 0.15668414453310625, 0.196413197687694, 0.15640119543032988, 0.13994977463568958, 0.11476708735738482, 0.08959978925330297, 0.10985044296830893, 0.16815709961312159, 0.12050362596554415, 0.0783522774332336, 0.11404732455100332, 0.16389847812908037, 0.07210560941270419, 0.09141864986824137, 0.09971260053238698, 0.11363387959344046, 0.13422836735844612, 0.16440628016633646, 0.07722659462264606, 0.21318624408117362, 0.19160224869847298, 0.17044992372393608, 0.11163756850042514, 0.2458412711109434, 0.11884034664503165, 0.0727863564555134, 0.21613371877798013, 0.11048379434006554, 0.06282664303268705, 0.03905674708741052, 0.14860250747629575, 0.0912128501970853, 0.16834613946931704, 0.08415318187326193, 0.13448638708463737, 0.18261592090129852, 0.11682574903326375, 0.11761229325618063, 0.12793528075729096, 0.08716654910572938, 0.2003332166267293, 0.053322565874883106, 0.1681758000382355, 0.13071223960391112, 0.07559199697737183, 0.15695169089095934, 0.07282748246299368, 0.08684050624391862, 0.07838966471276113, 0.21587366344673292, 0.1773480735719204, 0.1026481194421649, 0.12917892688087054, 0.11017283531171934, 0.0604847947667752, 0.18631462885865144, 0.09277143834957055, 0.13410152202206, 0.228863782116345, 0.09083895704575948, 0.08689171528177601, 0.10648220870643854, 0.12826115398534707, 0.08777047241372721, 0.10461515853447573, 0.11411120183765888, 0.09574930462986231, 0.12276105768978596, 0.07080361606287104, 0.08418124608163323, 0.1604380173874753, 0.08144529789154019, 0.09937768243253231, 0.18241419244025434, 0.10220024561775581, 0.10277508691485439, 0.13508284650743008, 0.10423232907695429, 0.10750776010432414, 0.20838305753256592, 0.1492532089884792, 0.14706838051123278, 0.06713398333106722, 0.17035334104938166, 0.13140422318662914, 0.12494246635053839, 0.12622827664017677, 0.11190132863287415, 0.10067040020866053, 0.1797159436557974, 0.15973970985838346, 0.15504286331789835, 0.10159571841359138, 0.11311455603156771, 0.20308929016547544, 0.14602074958384037, 0.056133885734847615, 0.12994812774871076, 0.08512763279889311, 0.14266816233950003, 0.10897405392357282, 0.07543279909129653, 0.21192680166235991, 0.17233323838029588, 0.3036959895065853, 0.10960393798138414, 0.17201784173292772, 0.1423512864857912, 0.10708839832139866, 0.10135532024183444, 0.23026875672595842, 0.09930954394595963, 0.12401997085128512, 0.09204025579882519, 0.15980714266853674, 0.18227541845824036, 0.144117838836142, 0.09760536253452301, 0.12054699792393617, 0.09923932235687971, 0.09837532336158411, 0.1437595316341945, 0.07996328920125961, 0.1407589547868286, 0.11558218433388642], [0.019184885546565056, 0.054323666263371706, 0.04580893048218318, 0.057845232476081164, 0.07103982088821274, 0.021804619347676635, 0.03997483550171767, 0.02799595283743526, 0.0404708751344255, 0.034129924673054896, 0.005083027112829898, 0.05254668482978429, 0.03602163280759539, 0.0395128006514694, 0.031170640074248825, 0.032851188110985925, 0.01412869873456657, 0.03875727904960513, 0.04560145143685596, 0.013412253964426262, 0.003612112046019839, 0.010892870403560144, 0.04110395169949957, 0.10388195394937481, 0.03215046838990279, 0.04808781069836446, 0.02511471164013658, 0.00793722614512912, 0.0488313493717994, 0.02456440786564989, 0.04024794584672366, 0.036227965128741095, 0.018660457705014517, 0.02563164845508124, 0.011268827997680222, 0.09765440704567091, 0.033277287746646574, 0.03463554182755096, 0.02255775929162545, 0.07667842653713056, 0.006788777636497149, 0.03150196193850466, 0.12677403592637607, 0.032296550194067616, 0.05234648307253208, 0.049136686737516096, 0.02247754288172083, 0.007642532449348697, 0.03534837679139205, 0.033845180845154185, 0.052062102260866334, 0.032736027147620916, 0.018808855009930472, 0.023865555812205588, 0.03906849252858332, 0.028380471847153137, 0.01755509532189795, 0.0104001615296251, 0.022282828776431934, 0.021313948623303856, 0.026274377180795585, 0.04297639961753573, 0.038160348044974465, 0.008888437246371592, 0.031210124026983976, 0.07182776289326803, 0.03795774766643133, 0.01774774498439261, 0.05496509559452534, 0.0589911017034735, 0.048994391158755334, 0.019329903747088144, 0.0909426100552082, 0.010752863184149777, 0.009474544769286044, 0.02701286755369178, 0.02969531834657703, 0.024455735393400704, 0.033488386776298285, 0.03837050391095025, 0.023773936621312584, 0.023858622880652547, 0.008368290112619954, 0.10765064600855112, 0.024434356451300637, 0.021394355023013692, 0.009695372294767626, 0.01710120458821101, 0.005643539870756545, 0.029580778242754083, 0.027558676033679928, 0.055157490806388, 0.053226763515600135, 0.03141754539683461, 0.07654029037803411, 0.04927300103008747, 0.04766484250181487, 0.013824394438415766, 0.07329601767872061, 0.02454742243779557, 0.01344877526363624, 0.05580030774165477, 0.055074288842401335, 0.02121780869284911, 0.02752515810009624, 0.03530071988435728, 0.045968667803598304, 0.028074678166636398, 0.012658756941423883, 0.07159748846398932, 0.03220561632354345, 0.032840206021709104, 0.04705722796331559, 0.029566400085708926, 0.0295415623113513, 0.011022161010519733, 0.026817222159089785, 0.006417930683320654, 0.04312381474301219, 0.029593775581036295, 0.017879881197586656, 0.01214019927595343, 0.021014948774661337, 0.022528261678027253, 0.029390045441687107, 0.008995768763790173, 0.07189758414668695, 0.05424204528597849, 0.018428369890898466, 0.016742181531818848, 0.04705865627952984, 0.028359532256477644, 0.035997707662837844, 0.02025309983374817, 0.05182331221710358, 0.06168584246188402, 0.06368291351412024, 0.04594544154990997, 0.04148897961048143, 0.05991505605301686, 0.07009927635746342, 0.03368347916486008, 0.03429605718702078, 0.0646969840994903, 0.04462036783141749, 0.04281550878658891, 0.036298302068774185, 0.021732945693656802, 0.0288904774268823, 0.02204981306567788, 0.052740793342569044, 0.04074842309845345, 0.012186334568208881, 0.08531114259468657, 0.05015743750014475, 0.04348536194967372, 0.02747319758470569, 0.02350629017954426, 0.036929756935153685, 0.05970099861068385, 0.05729367171547242, 0.03263614000752568, 0.017779739606859427, 0.033418192328619103, 0.029133382785533155, 0.05233021180278488, 0.03605082677677274, 0.04247419210150838, 0.01601725846662053, 0.010453289125247725, 0.008252229242186462, 0.0398542835776295, 0.01815326126026256, 0.022403189014377337, 0.04438747764964189, 0.07040482067636081, 0.02625251987150737, 0.031620902341923544, 0.0708344147673675, 0.018425911897793412, 0.018456819167892848, 0.04200401483103633, 0.031234442722052336, 0.01378246521510716, 0.05189961687262569, 0.025069441480029906, 0.005139982918210859, 0.037783649151346514, 0.040179827716201544, 0.10313129065824406, 0.02949439055685486, 0.03565028416258948, 0.024287648698581115, 0.025540049620238797, 0.0434078562871686, 0.07115978587950979, 0.027585853057514344, 0.03152404146801148, 0.034685393795371056, 0.03502185216971806, 0.037553992188934765, 0.015759516939786927, 0.018860549200326204, 0.02998060839516776, 0.024307168454730084, 0.06422052359474556, 0.03804587579465338, 0.043211617174425294, 0.0309478498862258, 0.03570412252364414, 0.008940379950217903, 0.08351364904748541, 0.01718401300188686, 0.03264197201601096, 0.007881854294932314, 0.06399218977562018, 0.02069646479295833, 0.03386328415945172, 0.02806979271450213, 0.04083102455894862, 0.048622360586055687, 0.0021836355278667596, 0.016723197818334614, 0.035286575821893554, 0.01973774061272187, 0.027162104545693313, 0.028165530612958328, 0.019801037751936486, 0.03180863941088319, 0.022864753979125192, 0.024241969721125703, 0.05888317392340728, 0.019877990408401405, 0.01933887228369713, 0.033131463785788844, 0.017753190227917263, 0.04916193502556, 0.0329886593057641, 0.028291074858446206, 0.0483794721907803, 0.015594641411943095, 0.051431807689368725, 0.036270522845110724, 0.027725264862445847, 0.04206636541389993, 0.03248661124546613, 0.025693988859919564, 0.06766176143927233, 0.03817300611574735, 0.032800267450511456, 0.05783566513231822, 0.0871001205274037, 0.07216887601784297, 0.06793057665761028, 0.01522139965423516, 0.04180873245266931, 0.026883816978495036, 0.03111478646418878, 0.030707400824342455, 0.019909058830567768, 0.009480396285653114, 0.035846139903047254, 0.024146364136998142, 0.030708194710314274, 0.00931273028254509, 0.039534866610275846, 0.04389711056968995, 0.08023543602653913, 0.03222349911395993, 0.006086084650762911, 0.030786290698285614, 0.084684596929167, 0.0237410700813468, 0.022714836755767465, 0.08038687147200108, 0.0210685581301472, 0.032873277818518024, 0.035751572477498224, 0.09397288638034038, 0.04987845104187727, 0.006990125693846494, 0.02688673128640013, 0.051724595549915514, 0.06764766148158483, 0.02152620455516236, 0.04887679764734847, 0.028417009261569807, 0.02482178128723587, 0.02231860114261508, 0.017476695689505765, 0.006131945560420198, 0.012477011336678905, 0.06287288519420794, 0.005807705905421504, 0.043261974650834284, 0.03206117318144866, 0.036226428246923854, 0.05814701092562505, 0.036889088938810995, 0.05264227345053639, 0.12225216999650002, 0.03668901949588742, 0.09105871418224913, 0.03691767901182175, 0.0549096389274512, 0.03146454751757639, 0.09444495676351444, 0.03616223883415971, 0.02340574486048094, 0.05026622362700956, 0.019259743226159896, 0.026899621755416905, 0.05794390503849302, 0.04294702583657844, 0.02481227501162461, 0.020814964148615087, 0.011742086665305709, 0.02676549573828067, 0.012910710564548416, 0.04912948748096824, 0.08832402806729078, 0.01963488827459514, 0.0573930838810546, 0.06607322953641415, 0.016898663581482003, 0.005127463098948023, 0.03834104870579072, 0.06694896040218216, 0.03984904528728553, 0.020945158055318252, 0.032601758638130765, 0.06818901707551309, 0.0382040558782007, 0.02512225186053131, 0.051072248590311835, 0.043730153635676415, 0.015956575383565257, 0.0220179507575397, 0.01905133289151958, 0.0195830990892968, 0.01088299008551985, 0.0065097190838839325, 0.004645489073092384, 0.02077915276666837, 0.02057854219206742, 0.02557041745499841, 0.019816009627122964, 0.027744674356654286, 0.029164629323141913, 0.032064067133303197, 0.014948150209550346, 0.07377670545663152, 0.07626636579100575, 0.138676218688488, 0.24998676723667554, 0.1255240658564227, 0.08333083135741097, 0.10591500771364995, 0.10175083151885442, 0.07315271108278207, 0.13018618497465337, 0.15187543470944675, 0.13732817316693918, 0.1263120485735791, 0.10969754188720669, 0.17501782146947725, 0.1387241096901042, 0.11955288983881474, 0.10929387461926256, 0.12921908258327416, 0.15147672753248895, 0.1963969942714487, 0.12303401875708785, 0.09772717314107077, 0.05548234283924103, 0.14721590759498732, 0.10244799232376472, 0.16642965802124568, 0.13336084676640375, 0.07849924811827284, 0.18035288447780268, 0.21940367402774946, 0.16624025175614016, 0.11001173074224166, 0.07092727228466954, 0.10299784996147666, 0.10568882485053369, 0.14812690871102469, 0.13390131347945758, 0.12214601997818265, 0.09334363336009638, 0.24748020459498676, 0.1181067552949701, 0.08559675155473606, 0.20362320223024913, 0.13154655269214086, 0.14131498709321022, 0.13931257597037724, 0.09410828804331166, 0.12022900927279677, 0.281669412872621, 0.10350548236497811, 0.13640449701675347, 0.17841600626707077, 0.11530849044876439, 0.12034664010362965, 0.11780102098626749, 0.10846089824501957, 0.0729112611817462, 0.1095696651775922, 0.12719052072082246, 0.1973079682460853, 0.10648756913308587, 0.08620278510664191, 0.10559026085372482, 0.10340526274272374, 0.07565630174108914, 0.1123538843489119, 0.08612910298896687, 0.1423185132443905, 0.13132190331816673, 0.13177441832210335, 0.13862063309976033, 0.17396967485547066, 0.17390658466943673, 0.1189669341381107, 0.10344275180250406, 0.16329705182995113, 0.10574927553534508, 0.1783995721489191, 0.0869001087599567, 0.1348630961562906, 0.14685534765677793, 0.10685635970107146, 0.058485131710767746, 0.21315766418618814, 0.08985936282468693, 0.1676840249981199, 0.14908694076750958, 0.08311631929661546, 0.09501796601606266, 0.08418114430138043, 0.219208920906697, 0.1367076528923852, 0.12464836213205542, 0.11209606139787606, 0.1810263983373131, 0.11641068916235651, 0.15655592855598244, 0.13466862801994595, 0.11306446657649108, 0.13944331609777041, 0.12975935930652277, 0.16475483003471578, 0.1400209122470447, 0.14768455816166742, 0.06306966713496617, 0.09854630061558314, 0.15910164266824722, 0.1435055016939129, 0.17028662748634815, 0.1722952811313527, 0.17872351833752223, 0.11561611108481884, 0.12970542934324059, 0.14513618419212954, 0.17454851950917924, 0.06843953898974828, 0.20591300007488045, 0.0977393596300057, 0.13127576293689863, 0.12285667684461389, 0.11401375063828059, 0.09354355013264076, 0.15667236516518251, 0.11813910784465925, 0.23291357766304696, 0.1291748828121594, 0.14455598246838364, 0.14480595476925373, 0.10648290081215755, 0.1440489946731499, 0.2159845767808812, 0.1058913879096508, 0.1301168386957475, 0.1248736357582467, 0.12689328167055333, 0.0971175976363676, 0.11922689447445528, 0.14870740899017879, 0.22205149408962044, 0.13880416325160436, 0.12167614804846899, 0.14317641220986843, 0.1139572693833283, 0.11137879560036318, 0.22270680963993073, 0.09726766922644206, 0.09600186214915343, 0.16024881468287536, 0.17085973173379898, 0.08934568467416934, 0.12252080201038293, 0.10191416168319327, 0.12341477189745222, 0.128396833847676, 0.12589234752314432, 0.16848508987043584, 0.10769116133451462, 0.15737999576543057, 0.09834115912339517, 0.11436949297785759, 0.1384012491575309, 0.07850416749715805, 0.09437235351651907, 0.16903483894254479, 0.15353544349116938, 0.14130518904754094, 0.06674654662076916, 0.11760313303342887, 0.08049960327999932, 0.0968565380732928, 0.06181194819509983, 0.12923335896006652, 0.10066987095134598, 0.13057210855185986, 0.12495409644075803, 0.15809388245855058], [0.043627732167286534, 0.03414404498679297, 0.00651650019322655, 0.011734493858447033, 0.019737657492182085, 0.04392618240256395, 0.018942721487422074, 0.01982428096900029, 0.035216968307005506, 0.04805990933839764, 0.03009566418560488, 0.025091936612235646, 0.021165322312819104, 0.04949450200157506, 0.010365987113410873, 0.03684499773329922, 0.03781103482469916, 0.10476075179342713, 0.04245354088821581, 0.012557659464489137, 0.05486513042290296, 0.026458463731354902, 0.10925369856080838, 0.026209814573771188, 0.06629043538123369, 0.04008639344413366, 0.03843242023140192, 0.020464271805914383, 0.04131099987508995, 0.04255103958504541, 0.07857569187347378, 0.020451849526060478, 0.024500722265137092, 0.03760030220395752, 0.04094202270997422, 0.02777442642088447, 0.039600657365683994, 0.09262428446007626, 0.015940787570018853, 0.08611565442489726, 0.022052528902090023, 0.032988018090171475, 0.011658532711278115, 0.04832277719729713, 0.04277329373040369, 0.02331014097269092, 0.026725239951961806, 0.02327008874687765, 0.04876712603228433, 0.022439076731513654, 0.03264069637017591, 0.03790168710319059, 0.0020145151273547007, 0.04658422798716596, 0.008040427080621677, 0.07322445937565394, 0.02916707544188414, 0.03140678722411394, 0.03964311330180083, 0.043434427718498876, 0.05401434250442045, 0.004732117638923228, 0.020560927422983304, 0.07502615305462054, 0.03501125006005168, 0.017067664602239217, 0.016879172663071325, 0.026658836818699325, 0.05574573317010488, 0.050528925244829485, 0.01210157451818564, 0.017118425806984305, 0.0302076563904328, 0.02047266698043261, 0.02475032306808446, 0.027699802835871066, 0.014843396277033856, 0.022076625376939774, 0.0692634569214923, 0.05127010940174971, 0.05849452942077603, 0.02179407491348684, 0.028449044596137743, 0.12037862624440875, 0.02332210184873215, 0.01913772227375635, 0.04274551111406513, 0.03251773903944662, 0.06215430982410908, 0.05585308080273015, 0.018592870528144494, 0.01841829703854663, 0.02599346198673759, 0.08105475349085671, 0.10911677019404513, 0.03607777140236326, 0.03974734306601541, 0.040886230168065855, 0.05642784067562648, 0.05391317293313997, 0.017418723353849988, 0.03239315661734768, 0.011507731696058596, 0.07533272874674626, 0.020548980117642453, 0.06192260368594101, 0.0920472786362682, 0.039705012658877034, 0.015970364911481738, 0.09289843296366078, 0.07172187750360795, 0.03437926254368254, 0.011277773633732327, 0.050664798489638736, 0.029784654267132282, 0.05347186393503632, 0.03044268735019224, 0.054029239740754874, 0.015178221078323466, 0.032814689712332826, 0.06142603140324354, 0.022379689650343995, 0.01912217534014157, 0.042905428247260194, 0.0010132259152929432, 0.09289149155042001, 0.01447756412172956, 0.02094898499282343, 0.030196582698928456, 0.02772129373624921, 0.03892991532172475, 0.055730944499373436, 0.033364747517875264, 0.07328197878918477, 0.08672016127301113, 0.05621723697653838, 0.03402859564604504, 0.019081799113856893, 0.023674644895696213, 0.06787524891218968, 0.018358507925378423, 0.0019990048770393643, 0.03525120718404651, 0.031284579674580267, 0.06666352107588734, 0.019987787552443997, 0.020707635175702826, 0.07762902017150607, 0.04439255648425647, 0.022879188115309392, 0.04903401081849422, 0.05551370133512786, 0.02949722683323281, 0.024966064973601272, 0.028582598947520767, 0.052114519091056924, 0.04323504698861923, 0.026332217202122723, 0.0382343796081841, 0.025100526865571737, 0.019181565813986317, 0.006256622129252979, 0.018339625992146984, 0.07041906312640224, 0.03174228886408465, 0.024045789980196526, 0.015014248002054436, 0.04942282834755523, 0.05679997302857893, 0.012713907419570854, 0.024854912455858927, 0.00854205444920808, 0.04978513890611274, 0.006576176924032292, 0.032510149625263045, 0.01290906681346574, 0.024162172306595103, 0.02821292628401092, 0.009574559134697276, 0.01404336023343993, 0.02256062440574169, 0.0373797206474202, 0.058023293635674884, 0.02246618250917111, 0.014245617103629878, 0.022443432926333377, 0.04467908146658114, 0.044669799107526026, 0.021400921545656662, 0.0344184920457857, 0.016849598714283535, 0.021483840221273046, 0.011251356569118798, 0.05437094997614622, 0.03295719563694937, 0.0318182712154729, 0.019663184881210327, 0.0376023717357644, 0.04381813248619437, 0.05452170010123934, 0.027694693467180644, 0.041127218665289025, 0.056025510121669085, 0.09724134885306869, 0.02692279711897884, 0.05579683703503438, 0.044243994634598494, 0.025410369703812257, 0.032355589526040215, 0.02002685420614268, 0.020169327900345837, 0.035186905813004286, 0.025075812923855016, 0.021577249048277736, 0.021545912604779005, 0.02408699401920395, 0.007193513597095651, 0.024782266800424883, 0.010944925913853305, 0.01669077911148114, 0.012002452426323933, 0.036988857335277965, 0.011147495758320605, 0.04391798569953867, 0.04584322024935058, 0.006567707958830786, 0.03963689113567982, 0.054481256021452804, 0.048217146258269034, 0.03262308160109179, 0.07083265057631902, 0.025948593858629465, 0.014219827683908599, 0.026939056514363204, 0.022089973857094134, 0.022052762996671454, 0.03951154875435999, 0.01909463869274727, 0.033285375884068866, 0.10682553385517427, 0.08399454717125211, 0.044489407180143256, 0.017777939792722464, 0.013609035057015717, 0.0113342777892415, 0.09709666483104229, 0.019952897281785096, 0.08012528265161173, 0.03228114066379411, 0.02580731947507177, 0.034249767528048584, 0.019988778213571225, 0.036379807695214234, 0.053977165570748706, 0.05498632016990866, 0.08516479616186448, 0.036525808075176816, 0.041226444233741076, 0.036448075103440454, 0.042284175154886076, 0.03951962332108191, 0.05710390582680702, 0.06369154447955744, 0.033567520922848156, 0.06394102144986391, 0.03400694020092487, 0.015262247462357794, 0.007263501091594142, 0.039223497068243365, 0.05141185197447028, 0.034961706825665066, 0.05054355106715645, 0.04786326988999333, 0.024863596007760082, 0.020867632036762576, 0.015277874123837267, 0.01623051693396909, 0.10292706518833127, 0.07756550250841038, 0.05504815506615809, 0.06489602556186062, 0.07174724792795521, 0.0253005047062678, 0.015919851372018456, 0.030160620342940092, 0.039002800160752873, 0.05014703895098396, 0.06216665916144848, 0.011738351330028048, 0.049835676194301674, 0.02968761697411537, 0.03551730147695967, 0.03830367160428848, 0.012038292646008943, 0.04461449511083109, 0.03374173478888614, 0.02628327956024025, 0.05319380367706929, 0.010730981277967138, 0.042724025302699635, 0.03429178920175348, 0.044669483588742356, 0.04054735620905246, 0.028861012043697492, 0.044633002153464725, 0.05787067075393029, 0.02988000200795276, 0.07507699568356786, 0.028248929352100407, 0.041249178549540896, 0.04068168917936938, 0.022465376748836467, 0.035294043099773784, 0.02292429712334914, 0.04218933292265449, 0.05003636310409222, 0.022032103301691155, 0.033967262865709405, 0.03778147105393665, 0.016041553412963237, 0.05188648382733975, 0.05375831427850893, 0.04423211348642196, 0.031527569850108454, 0.02029698238974171, 0.005766730023814099, 0.0477368214965931, 0.034453881039683304, 0.012804492692729192, 0.01641233208855348, 0.048203958930181603, 0.03363204621044653, 0.035716912908745665, 0.06990431967590537, 0.04629632897142853, 0.02452415886468121, 0.022256260737776756, 0.042442514694162777, 0.023074516294790164, 0.04857896827161312, 0.022762308762009655, 0.043851641938090324, 0.04267795956028359, 0.044537386391311884, 0.0043710246266398045, 0.025158463578139032, 0.024197500232341032, 0.05606344022921153, 0.016714475250669887, 0.046753135709358115, 0.051953784323164394, 0.018144401289256554, 0.1262999027967453, 0.12392243822770459, 0.07605079521558114, 0.07494028444801058, 0.08002693578600883, 0.08197924388306481, 0.1550165225884744, 0.1073505367551531, 0.1471476334014109, 0.09841124500547137, 0.06922574394515582, 0.1317062119820288, 0.11798689886927605, 0.11631336009928159, 0.10539624055049249, 0.1309976042913539, 0.14360914113266127, 0.17282594979873725, 0.13452153519860335, 0.0927141767793468, 0.12616541715604918, 0.058158885288451395, 0.18855394369789533, 0.12033186161092349, 0.1690490474658353, 0.11992301712078707, 0.18530142679810524, 0.14540881956262247, 0.08323308838797466, 0.15822379477322102, 0.15732717859957898, 0.21186713129281998, 0.11457059718668461, 0.12465863515223775, 0.12376451598746435, 0.10175885180277483, 0.10313178598880768, 0.1745592946452754, 0.11913521082273551, 0.14493290867124284, 0.12126936630478927, 0.08826743146138531, 0.10567122365214995, 0.05648215401119419, 0.09581082061465297, 0.09280934131571225, 0.09733932252441134, 0.10875137230115277, 0.20108864323369094, 0.060361627090190134, 0.14912853496415274, 0.13884976080485753, 0.23741440900734492, 0.12010810790317399, 0.17417816152530058, 0.18035772921783583, 0.08388296208743538, 0.11157370478446994, 0.16565515100955963, 0.10318589915654489, 0.1434178621109043, 0.10136052460542747, 0.08739998550819499, 0.16971501601593836, 0.11984034441411495, 0.09479833780122654, 0.0950576603146536, 0.08204765378364495, 0.10972255268799407, 0.18728991438235554, 0.1848158264266593, 0.1269770807453564, 0.10377494897693396, 0.11324184920106616, 0.07661000985120024, 0.070040752712105, 0.12390558341784136, 0.10891877367560353, 0.2032940313220024, 0.20695478203041212, 0.1250695288181305, 0.14114983166967118, 0.07931108812668494, 0.1693861572338002, 0.23397814482450485, 0.2084601391106844, 0.14517321863344737, 0.09287308289536408, 0.12247102468141488, 0.22882985536541256, 0.13266973170850957, 0.13240006832139833, 0.13849205071372644, 0.1605468408337661, 0.15411389459456715, 0.11294696466731173, 0.08321866951882839, 0.09923560398497752, 0.13179902200187954, 0.11740101102207388, 0.09225296974182129, 0.20528876142842428, 0.22563738881477288, 0.15436690673232079, 0.16547243509973797, 0.18294072204402514, 0.18528740826461995, 0.09583645566765751, 0.1143360547721386, 0.08479743051741805, 0.10574353512908731, 0.11130309823368277, 0.10847543246511902, 0.14353355233158382, 0.16663659763123306, 0.24016331721629414, 0.12350310358617987, 0.07883389480412006, 0.12363642214664392, 0.08607273029961757, 0.10888929811439343, 0.1147546973079443, 0.05841953094516482, 0.2190982247037547, 0.09513028391769954, 0.23106150275894574, 0.13303136373204844, 0.07967212303940739, 0.09793889642293964, 0.18533415932740482, 0.1134464478652392, 0.2321606209235532, 0.08671522832342557, 0.13819292533610547, 0.14552927309913294, 0.14129231045288698, 0.08813255905572857, 0.09131885093769856, 0.1515842346208436, 0.18775144033133984, 0.13718135175960405, 0.19933221462581838, 0.18393815495073795, 0.09683586311127458, 0.1596197448670864, 0.06051627879164048, 0.14420332067779132, 0.2179708116288696, 0.09827299349542175, 0.09541813882866076, 0.13081404699810914, 0.14331796818545886, 0.14054993885968411, 0.11649158410727978, 0.1403208790080888, 0.2134188458855663, 0.11540101548390728, 0.10433661990932055, 0.16386460566094943, 0.10593914320426327, 0.0736300265416503, 0.12648736845169747, 0.07013008863266025, 0.150055142385619, 0.18057039566338062, 0.19719146378338337, 0.12702901581568377, 0.12402877823582717, 0.13534341752529144, 0.13002655282616615, 0.10396848073495285, 0.12023086845874786, 0.18207109799342497, 0.09677691877420459, 0.12750517097967012, 0.09226521051355771], [0.011650888166124267, 0.061383589037827084, 0.04206474032253027, 0.027229142109198228, 0.008869002307099956, 0.04482591983729175, 0.025077073302652155, 0.021945951406710913, 0.04497301944398454, 0.024775983566152196, 0.05926000513136387, 0.02910943728472505, 0.059766748653990884, 0.02402585292501109, 0.05312444722013814, 0.03739215819431203, 0.058569819666445255, 0.06015712342091969, 0.07334733528218099, 0.02748236628914518, 0.01964239456823894, 0.03369400663567441, 0.019994956274916018, 0.09506836759724788, 0.014401174649330122, 0.03883739707193204, 0.0271751883971904, 0.03364119286249791, 0.05226939131638833, 0.02350815954352064, 0.059792600838201385, 0.01670153219518917, 0.0595043795183301, 0.035865769921136756, 0.01835669114786599, 0.016551672647308027, 0.04409720715401428, 0.018188701144286563, 0.05163189409566777, 0.06338505699698414, 0.0642209103597062, 0.08585373312234879, 0.050877519217985015, 0.038670891363705905, 0.015170222846791148, 0.06259484189961638, 0.023614742127912383, 0.017696764952104007, 0.03412402820374284, 0.018922328117436597, 0.022956778594691838, 0.016979880830539123, 0.005056688927912286, 0.03270268054412944, 0.06257297271596533, 0.0969423388264009, 0.023129806720784733, 0.06031111694340195, 0.03213380356984479, 0.05408102214070303, 0.03343338133501155, 0.008033004755686437, 0.016501036971541386, 0.012153605431584375, 0.06709969695657492, 0.025941664319751517, 0.011687793685788555, 0.06163564444120441, 0.02247849283074694, 0.031384792511484454, 0.06227870564907789, 0.009839365907412554, 0.04054650804027915, 0.08090205597026007, 0.034520129806229045, 0.039301582878189426, 0.015753131925261447, 0.029411080027265207, 0.014911007202629532, 0.006721337192824909, 0.04259308161480086, 0.08156006530459438, 0.07544139612998281, 0.03200656468314784, 0.00973036264934178, 0.03534008509346417, 0.00895896417620991, 0.028168841863849332, 0.08584678492375783, 0.037999667559883425, 0.04492000550297754, 0.02037249824830464, 0.016650423241247023, 0.017849652462505868, 0.028681047593376467, 0.012761299697948354, 0.03633963842211025, 0.0226628575806639, 0.08638284115919045, 0.10644936761153595, 0.037186480659459314, 0.03224811636443649, 0.1185375978904111, 0.025681356234209876, 0.06870999626283135, 0.018032443011179566, 0.042263364485864124, 0.0945604502090386, 0.05049004179558583, 0.03309516216229115, 0.06648212152400187, 0.004015069820785097, 0.05718554037490061, 0.07030729483813047, 0.01349194026884756, 0.026163940517497913, 0.037021372733371596, 0.043865185497062545, 0.01568622837242271, 0.026149204433230416, 0.021332420042849014, 0.012444168545438774, 0.026885906866352473, 0.006944999298346894, 0.03497570500309978, 0.041160724724509885, 0.041793119361890216, 0.012632327154278755, 0.017141063431543962, 0.05799816748393433, 0.04579073217298303, 0.034168743661471775, 0.03765399128730808, 0.00368510587473533, 0.04775255672367556, 0.015633348442081894, 0.015923454392967478, 0.06938064670456306, 0.03969566923167024, 0.04835661234600203, 0.06415429857692548, 0.06574769557586738, 0.015208724620086806, 0.08729979302734137, 0.034537812428815026, 0.08482299771692071, 0.029860002188278095, 0.05635000592363732, 0.0018356988855105425, 0.03324481306065406, 0.04180425412154623, 0.017814746924809048, 0.02782503834792546, 0.011269861915414887, 0.07395978099001305, 0.017996948844354068, 0.04566079271691186, 0.013632085739767976, 0.005902794530681733, 0.03810092873339142, 0.06706000944333416, 0.005147414573002607, 0.0346426494818713, 0.021815172263554165, 0.02030723335753594, 0.023871499778968946, 0.008179065355631922, 0.02350308749425624, 0.008362632826901972, 0.035542817786335945, 0.05424424373943891, 0.023279705284429447, 0.013185270429987992, 0.015829689335078, 0.04076914555792298, 0.035389675825302086, 0.033408543560653925, 0.06664502421127898, 0.07045272524867739, 0.03429071372374892, 0.05061404746291893, 0.05778750950204475, 0.059570543467998505, 0.01741765975020826, 0.06555907641138349, 0.03832120494917035, 0.03204445747126426, 0.05547658886228289, 0.036242238112858365, 0.004992013938525426, 0.043064466677606106, 0.02167322443399046, 0.024375327297353318, 0.05001172889024019, 0.05237737337925604, 0.010061414795927703, 0.03744740112285529, 0.042165730082030804, 0.041788644423442226, 0.052800507816885195, 0.027513653538855057, 0.041255237867257426, 0.04042131493666342, 0.03122143859841994, 0.05482722745676126, 0.025935681337224584, 0.021722321531602314, 0.02194310664864523, 0.054383431627814255, 0.031887203588017395, 0.04679638892412186, 0.00438668394261705, 0.02572042288790856, 0.06287460188780512, 0.051336809394082854, 0.01741515765232699, 0.027912671145583903, 0.027791162487119436, 0.038325571322015355, 0.042484003717878034, 0.021311673834653835, 0.05331028439104557, 0.04492251268987145, 0.06021311613065856, 0.049886861483433416, 0.007816343435219355, 0.036750898496913056, 0.023513713352648274, 0.026089347466560345, 0.0524082195812038, 0.019829344536576952, 0.10438391380012035, 0.010731446922623684, 0.05616111534514597, 0.03974051021837762, 0.061908937990665436, 0.03137403433876378, 0.02057627758144268, 0.018237601466743008, 0.044230284834546704, 0.05307570804974862, 0.02994300059175917, 0.024276503760899817, 0.015775482868775725, 0.045855579764715264, 0.03668853773602417, 0.03377248599593129, 0.01636381513838257, 0.03663475026509591, 0.04257243040150829, 0.05549726043162601, 0.007563455130106637, 0.02034127206674644, 0.03814716750223722, 0.0271119065250137, 0.06890342624059745, 0.008957870886661112, 0.0772823498451284, 0.05917467935276883, 0.008372043259441853, 0.049014994874596596, 0.02190559384013925, 0.01866106329751866, 0.03354819624551705, 0.05593130231967994, 0.02150538201177759, 0.04811462640230145, 0.009749088519518929, 0.03478992890034403, 0.027962395888088003, 0.019173550619078533, 0.036298417419727357, 0.06007253046014479, 0.04143037793359586, 0.062289331507469924, 0.028218295192345977, 0.06649924774787255, 0.021805082447826862, 0.04412333753758243, 0.020876614144071937, 0.008335378619709184, 0.016482694473649775, 0.09406150983912603, 0.04912963675867234, 0.04476386441716126, 0.023827805516443083, 0.02229096950031817, 0.02385006655406739, 0.02418775816581079, 0.02979673897581441, 0.07595398862447057, 0.01165799327593829, 0.0425102257036737, 0.03685664139421923, 0.04858581129727619, 0.014537561884416001, 0.01189359335694462, 0.04608365574053355, 0.0961672482745988, 0.010683198841953916, 0.022884227934160402, 0.013915371565547372, 0.04551549462069358, 0.028666825499385595, 0.012752576282114854, 0.033068699296563864, 0.01157385069278202, 0.028923627255218368, 0.02278473604071353, 0.036059461134885035, 0.03856552166065999, 0.03148634545505047, 0.031765976521585665, 0.029054699864770685, 0.023848539850275432, 0.037968933316213746, 0.030879691043602567, 0.015152485941403677, 0.020156008257929767, 0.041059755321059904, 0.04381579154038003, 0.02955572333719049, 0.028370590680944066, 0.08387526071497373, 0.044610325513141494, 0.031116224958428314, 0.043636244389095476, 0.049978582454579215, 0.07070064837379114, 0.04461355533983026, 0.010456008354334958, 0.027050314205033437, 0.022107641212642193, 0.02283367537893355, 0.020404279132240584, 0.07373392382370574, 0.031802681873419454, 0.024395615494410907, 0.014267952780106237, 0.04028214740433863, 0.052796731769506416, 0.04007169637562973, 0.04076184791379741, 0.05569425271824002, 0.0407600464033229, 0.03161426626944116, 0.009214126421803874, 0.03841432709512966, 0.027991253982431123, 0.0473386605403253, 0.022954515680404644, 0.04407864922125425, 0.09003791931484427, 0.12534547543951444, 0.2397762265588556, 0.11993495933711529, 0.14963535991098198, 0.12682204906429562, 0.11555631857897554, 0.14513250653232845, 0.13762925272541388, 0.08399742415973119, 0.23087818973830768, 0.1535227277449199, 0.1750183371560914, 0.09268635684358222, 0.13746097604078905, 0.13022250016885145, 0.21734607086649962, 0.17257709029529775, 0.09270013110446078, 0.1820239398096289, 0.1224294440554721, 0.11906738446227141, 0.17423663767320768, 0.20127205124923161, 0.1118619464603918, 0.11589988800031797, 0.1432283879922969, 0.14194170917783464, 0.16974598435418947, 0.13739359751343727, 0.16831519827246666, 0.08242246295724596, 0.1164184787443706, 0.12872277492923395, 0.15899029507168702, 0.05885310125138078, 0.09960283392242023, 0.12015616175319467, 0.16383020393550396, 0.1815299798867532, 0.08742158327783857, 0.16024133722696984, 0.11172748117574624, 0.19265087028699263, 0.097106551086264, 0.09743384923785925, 0.0806362670181053, 0.14412241216216767, 0.1964859909244946, 0.14710219869656221, 0.10259921063802072, 0.08895945575620447, 0.11671244725584984, 0.07101242164415972, 0.14140904561749526, 0.13716992522989, 0.12375789348568235, 0.17447823685194763, 0.10576152309243168, 0.13093661756387778, 0.09847585510994707, 0.09779630228877068, 0.0769400153575199, 0.1136725153774023, 0.13430018350481987, 0.07944124471396208, 0.10823276798639979, 0.12032637904797282, 0.10700470102684838, 0.08646834335689034, 0.14222777954169682, 0.09590708437774863, 0.1294887595410858, 0.1401752789637872, 0.13325701733785017, 0.07399655080267362, 0.12439739917005811, 0.11488775802510125, 0.10292868688702583, 0.14344262863908494, 0.14803746422486647, 0.11917704929198537, 0.1640880743839911, 0.14625685262892926, 0.12339601718953677, 0.14589972607791424, 0.09720650607986109, 0.080546856458698, 0.14385405156229222, 0.11999367975762912, 0.15139860101044178, 0.13245193553822382, 0.1298033283757312, 0.09096097799816302, 0.15176621771284513, 0.11527699285319873, 0.12123740730541092, 0.11687114302601133, 0.13303225939827307, 0.21888724102505616, 0.152036776766181, 0.10346723334597689, 0.27259818677391323, 0.12778764510793345, 0.11684462587748255, 0.10442562334771667, 0.184074784762093, 0.16189358356807912, 0.24827357488019125, 0.10131223326815025, 0.1582273638674191, 0.0480496363182153, 0.10679759178310633, 0.12851244264415332, 0.13731319111372742, 0.09287958326084272, 0.14220624284020492, 0.22327961533197335, 0.19392783247998782, 0.09722790707434927, 0.0913314852597458, 0.17264256892459734, 0.14718370432300226, 0.08086220560861485, 0.08480325234787804, 0.22564720043114253, 0.09795524911688906, 0.12502337486616202, 0.20204802389655793, 0.1208834427275828, 0.18270376404481276, 0.20050195471516677, 0.08103717264852353, 0.11090505602104322, 0.1832111861024584, 0.14355533330568246, 0.1299144181289843, 0.17545592438961777, 0.09769225572901112, 0.15933115035295486, 0.10353976195412022, 0.1871849721563714, 0.09263535815158061, 0.20797794498503208, 0.09449495800903865, 0.1088556292067681, 0.12333596684038639, 0.08937286000166621, 0.12093632774693625, 0.12332544954759733, 0.11637434682675771, 0.13792897521385125, 0.10615119896829128, 0.11752655357122421, 0.15319210477173328, 0.09779900964349508, 0.05099125525781086, 0.093751175062997, 0.08258611881839377, 0.12340827153197356, 0.149039144760796, 0.07904813545090811, 0.08574366117162363, 0.10565948499632732, 0.15691296011209488, 0.09792000600802046, 0.12379856487470013, 0.1450000564966883, 0.06970557676894323, 0.15317948402038642, 0.08864017788852964, 0.20871623179742269, 0.15012717566319875, 0.10957642338637795, 0.12472614938659327, 0.1164606429104294], [0.020677618482815366, 0.009424410361264433, 0.07051284345132963, 0.024095083852963786, 0.024298564630693624, 0.04300207198996629, 0.0407844465225935, 0.030576555524021387, 0.05040685340229954, 0.03561435912602714, 0.02925240800582937, 0.03147566531385694, 0.013194411993026733, 0.06204893333571298, 0.06170732488057443, 0.023781643082786883, 0.03494651781927262, 0.054549594675855975, 0.023249296737568717, 0.05290986730584076, 0.01807130271169756, 0.03200619827423777, 0.029021906267319406, 0.07367382597710405, 0.04399223439395428, 0.01410164893604815, 0.022892891130010997, 0.06657140994710581, 0.028640152287802527, 0.03705387795343995, 0.05604660238272377, 0.015445336566439696, 0.0465957020143313, 0.05227429373189807, 0.025769168843648264, 0.05091681996626513, 0.02265148363741381, 0.03702643121193562, 0.12701974702732904, 0.05494797954867993, 0.019859558004619818, 0.06597375630268029, 0.03852253646722861, 0.07233027235737868, 0.04054602628041591, 0.019555465750662342, 0.030816030888152973, 0.02217362874320575, 0.06289540577147688, 0.05041568114289215, 0.03295855949233685, 0.04096290123249803, 0.03678012300016625, 0.06031189047332321, 0.0337636412919632, 0.030681470608604804, 0.02831382444128394, 0.031171970002885376, 0.015503534514989172, 0.02126580656373075, 0.014064565300941467, 0.021340482735208104, 0.02515409720529403, 0.014921748411974736, 0.03916699545724051, 0.011815944353916814, 0.029626823629119566, 0.061803724350673814, 0.026219845017684356, 0.042453547673566, 0.0232988314902676, 0.013066299492493272, 0.03404404928109475, 0.061713031360081265, 0.02795105587158884, 0.050209223292768, 0.029976011320416416, 0.03876101777755788, 0.038164480323238034, 0.04628814583910363, 0.05320043974955167, 0.02969904350382941, 0.009961103571445813, 0.02226318688397961, 0.054728588821100335, 0.038216428964265754, 0.06934598713581051, 0.03369775554165244, 0.05985860872481551, 0.02493055214706276, 0.12445586174726486, 0.039518123758690696, 0.0428520614680435, 0.03929101808794907, 0.040642432535865476, 0.0633572642026203, 0.013717691414058208, 0.02331900772904711, 0.02150823694786855, 0.028638496662357023, 0.024132952892354557, 0.06982520927808114, 0.023211069770955613, 0.014624497487342783, 0.01657118052909417, 0.03238446797643389, 0.042330566594111066, 0.053730185609310865, 0.026207382025729333, 0.023603481839277914, 0.0406977433179106, 0.03633987590936678, 0.03487510879391006, 0.006415416286992175, 0.019151089413623725, 0.095017796382308, 0.03606291827080505, 0.05424566866297807, 0.03742982706587229, 0.031967498029449155, 0.011385489371605217, 0.027418714615383318, 0.01032852434686252, 0.011477652238681912, 0.05296093724401934, 0.037659260111727884, 0.015804500418848226, 0.026342522452718446, 0.050725615583360195, 0.05578547835882221, 0.08256612917674439, 0.04360538800912244, 0.01827630171153162, 0.06852046107607228, 0.03422659555716174, 0.0007918284203956968, 0.024893052909257155, 0.0673380663086261, 0.05792076699435711, 0.02390148593778057, 0.035806259007326195, 0.024230577118162597, 0.03235648858493992, 0.009925611100957861, 0.056569115059184175, 0.015193304911788021, 0.033099270691829066, 0.02191189064511231, 0.005291901819873601, 0.008972851243535323, 0.02601696813612112, 0.013722328352741897, 0.013107709636512612, 0.04694972766031112, 0.020230689518419758, 0.049171441301171265, 0.027538264003981437, 0.013110397483355232, 0.017383397124441605, 0.040583834251655, 0.026470326219818423, 0.034443163579063754, 0.0250285292110805, 0.009165728215261229, 0.014878478233835526, 0.04274719048823629, 0.01272577075620315, 0.01142579095903784, 0.0406922743256603, 0.024920248592804586, 0.01543317043355533, 0.011468095072944249, 0.045217610962156735, 0.01561649193588112, 0.03160862764343619, 0.04492267553827592, 0.05077673641166516, 0.054551260479326756, 0.053981576048369916, 0.05181497302172439, 0.034479193788553984, 0.0992617140124951, 0.05918713725571122, 0.034805701446852515, 0.017513731827161143, 0.01068974331220878, 0.025266328593716025, 0.05045559596536415, 0.03480751992070249, 0.06542322012994971, 0.03184967381613595, 0.016511114912905862, 0.014261969797579306, 0.022905271001426235, 0.0046505433108125415, 0.04115342368770923, 0.059663502765553336, 0.029960011464676688, 0.05153190856799483, 0.030896098020353487, 0.05086204522688474, 0.04468907289473074, 0.048334841549928696, 0.004702062354356582, 0.04437939290489469, 0.07149562000163964, 0.010412170751286405, 0.03856349623362933, 0.06081758226667132, 0.064953673897045, 0.007704777011115636, 0.029194037030850137, 0.05387510711859379, 0.04974755145875471, 0.029755867418966124, 0.09895952165658985, 0.03263906788613115, 0.04274887664775763, 0.025837176712229848, 0.0011203953264547245, 0.010716400408585156, 0.06901102153850452, 0.02601069168719862, 0.018628383354683007, 0.0712337801232934, 0.029591716227254698, 0.00645330610651789, 0.037143397078450234, 0.04749450307073338, 0.057961051618414264, 0.039966241855706484, 0.0074661252188629335, 0.007890501375576215, 0.07332739992333309, 0.027680335666186044, 0.06567741291863577, 0.03044677891635469, 0.02227681017081652, 0.06865886864917618, 0.05097522486799529, 0.012652398220130374, 0.0207920635917357, 0.033358053769916296, 0.07288910701338734, 0.016753367181601267, 0.024697246362588236, 0.05215232027694583, 0.032700312456914356, 0.039013035861509185, 0.040721000105674775, 0.02879436294149075, 0.04642216668331197, 0.03816254310575979, 0.04938572605273553, 0.03498180842559252, 0.032788854491497786, 0.03279936160626156, 0.02400814655369946, 0.031028653228921548, 0.04728558213849153, 0.037636719178408384, 0.03750921905572925, 0.06112611213965075, 0.0033471214327229454, 0.03640731889754534, 0.044581328319119554, 0.05661748782066362, 0.027584879359762584, 0.047357442389641485, 0.0521814531779715, 0.017702676688453982, 0.04101298390222447, 0.026600615121424198, 0.045607012031333785, 0.041961616570396085, 0.07823833783290216, 0.028907417053622857, 0.046226494147309234, 0.038388390094041824, 0.07532669657043048, 0.018869960481034856, 0.025635348167270422, 0.04140973350565348, 0.032799107155629566, 0.019406578204195415, 0.02740746789744922, 0.02889162754373891, 0.031945384573191404, 0.07774979940482549, 0.03870857719864164, 0.024821107841229866, 0.0789025489773069, 0.018319129145571163, 0.01163020811509341, 0.016175621754622886, 0.012471516051196625, 0.04548680955278022, 0.029442462271877697, 0.012736752845479973, 0.020598519959353974, 0.04460960965869682, 0.020958713488653302, 0.016226493221308504, 0.05961996117340667, 0.09155441794012274, 0.06381419646952834, 0.0149818089391504, 0.029632784559258392, 0.05157541962606566, 0.039310207058276446, 0.030166798404284885, 0.021503987622314265, 0.034847119224390814, 0.03563004685565829, 0.05650168564170599, 0.01820286047378821, 0.016158095195091197, 0.018939618886049305, 0.027902605078582252, 0.025795345028330172, 0.01973307059545602, 0.06021818478724786, 0.004590228333004883, 0.030707852050129856, 0.038537026582551856, 0.009325542720034719, 0.044578390262488804, 0.04005405446514487, 0.03433916451675551, 0.042717664036899805, 0.030835620194141353, 0.039971066239689074, 0.03142186087955322, 0.04463094619235822, 0.05584527086466551, 0.04607235134712287, 0.0628548361627119, 0.013113057340628334, 0.012012826378590294, 0.019923028170264194, 0.014114931259038193, 0.06460116138415677, 0.06521595482315336, 0.0075409574533945745, 0.030782585897083794, 0.029726666664438586, 0.05493340461647936, 0.023077211775151745, 0.019173262241695608, 0.007306186881448541, 0.05218917490648372, 0.06670430781585829, 0.1204700656235218, 0.10273328237235546, 0.16168367197471006, 0.10746613198093005, 0.12268731450395924, 0.1192072576710156, 0.13871233032218047, 0.13512286650282995, 0.10481630345540387, 0.11504086266670908, 0.12152178133172648, 0.1322191437440259, 0.1289767370160137, 0.30161120423248833, 0.1254805310496262, 0.14760964789560863, 0.15348046858395847, 0.12828863465360232, 0.21277184917458467, 0.11027605405875615, 0.1288230624049902, 0.19080118382615702, 0.11403958925179072, 0.14873930013605527, 0.1442391880388771, 0.11005301959812641, 0.09075477120599576, 0.1519236649785723, 0.17540358219827923, 0.2285889211509909, 0.11626749113202095, 0.13141442835330963, 0.12475462071597576, 0.20674591538097176, 0.1203666433159794, 0.12159526667424611, 0.11024545891476528, 0.17232341319322586, 0.20072150150580065, 0.1578280460089445, 0.17553122820598738, 0.16464330601905072, 0.0697194053126233, 0.21931883000901767, 0.07143999370081083, 0.1463543445404087, 0.11593465613467352, 0.16985577132020677, 0.17085872750197137, 0.09776469612760202, 0.057569014440689764, 0.1799737462507827, 0.1522124766239098, 0.21079997212759086, 0.13627326834414685, 0.09811659795897347, 0.14814801115010465, 0.11465066431888513, 0.07105576646115098, 0.18779660362218106, 0.16029449366033077, 0.13544849545827933, 0.08132162809904132, 0.17233691604009696, 0.11299754266760179, 0.0991368160716125, 0.07977448683232069, 0.16059527466339724, 0.11348337374095406, 0.12450361704187733, 0.16370799977864536, 0.12670369898634298, 0.18490683154336043, 0.14730946400335856, 0.11094840762338468, 0.0971401860671384, 0.09793381419564996, 0.17874513646321638, 0.14062152430415154, 0.18328213372400828, 0.11994835361838341, 0.2695280872285366, 0.08891584631055593, 0.12916486763528415, 0.13313492174659455, 0.15326892850654467, 0.15997670856969698, 0.10802826431712934, 0.12156028140868459, 0.1814612578600645, 0.23673372981803759, 0.17893509912703717, 0.08591510661478553, 0.22661162939454826, 0.14638348083410943, 0.1375536367829357, 0.0896220180605139, 0.15029921143182687, 0.12212503967540604, 0.13984342105686665, 0.11054744771016495, 0.12570815240698202, 0.11105144995131663, 0.1315474890704666, 0.11173366262976613, 0.1546766036855323, 0.10202322261674063, 0.12753698070134434, 0.15037463738449983, 0.14497302366154535, 0.10572043779705252, 0.1742402067674058, 0.1584068906626531, 0.1036939454664077, 0.06448826672775404, 0.14101971579449518, 0.09148566198668309, 0.1138040968882186, 0.0737349959090352, 0.12037235658083643, 0.07374505858336176, 0.10450569726526737, 0.06808166605021272, 0.09553345585508005, 0.1381432158606393, 0.16025684853749617, 0.06559381740433828, 0.10682972041623932, 0.196625144886119, 0.13145261630415916, 0.2730204798281193, 0.11759804402078901, 0.08134411474955933, 0.1447435702596392, 0.05394018880490746, 0.11111389552908284, 0.12090930848249368, 0.15918461393032754, 0.2124368292944772, 0.07178835357938494, 0.10225103396390166, 0.11965233593114785, 0.10936661357326166, 0.05698786276791777, 0.12311327164726597, 0.20311502021338257, 0.07865267845668963, 0.13977226987481117, 0.10677809068667037, 0.17880308335380896, 0.16829029603728227, 0.14519190548786096, 0.07760523751910244, 0.09807803681386368, 0.07221383574817862, 0.12487354076334409, 0.19437482420887264, 0.17902809913669313, 0.09561331942677498, 0.17883991423462117, 0.16350990826530115, 0.10873310613845076, 0.0900333799155695, 0.1523969295833792, 0.08573221428585903, 0.14767835635159696, 0.19586093803601606, 0.030459006117390733, 0.1366374652300562, 0.06497965500290905, 0.19635667572064058, 0.10898619970040661, 0.11150835507682391, 0.1309772753821952, 0.20774554674114498, 0.13614309818616935], [0.04437283825661455, 0.03052458313426801, 0.033114161142813306, 0.10986100097319909, 0.06661603040993214, 0.11373316962271929, 0.006125004147179425, 0.034030349659068246, 0.012956353070746576, 0.00754646970225232, 0.05113317424963627, 0.045513981487601995, 0.040007384826562235, 0.010405737391140844, 0.03577493783086538, 0.02596523323362427, 0.02771741590861763, 0.03156591386401227, 0.05067161776657615, 0.061234976298042705, 0.037816873618534634, 0.014030497753992677, 0.009790392642441605, 0.06943008476602179, 0.05243050606389131, 0.06634201761335135, 0.07978319922196013, 0.031129659951797554, 0.009485172324015625, 0.0333309395105711, 0.013181949849240482, 0.012125743087381124, 0.032008990445839505, 0.04489996497120176, 0.022098621785906807, 0.06631882528641395, 0.04102433240041137, 0.02544012855339263, 0.04031980609787362, 0.022763097558968833, 0.033498361241072416, 0.05476859863847494, 0.008295688561962118, 0.0394005947081106, 0.04114971888650741, 0.04887138972324984, 0.11167372084621872, 0.007432989809396011, 0.11242311527686459, 0.020614224652360593, 0.05518224715654339, 0.018539656419306993, 0.01794725124325071, 0.06501151222203459, 0.02427361489805792, 0.037400405787463696, 0.062003444348062785, 0.018415219882237058, 0.03324370704857366, 0.040407167481524606, 0.00890388579240867, 0.0367710577723171, 0.04180433554574847, 0.07908541416483265, 0.007375768103104616, 0.07188024757696049, 0.02429367578588426, 0.030888830910303762, 0.049316949743245325, 0.007045218920601266, 0.026673440588638186, 0.03379439249900835, 0.030151677251394306, 0.040880503332508464, 0.09537877022687878, 0.028551813813724687, 0.049190263862588575, 0.01938841212540865, 0.02064701316079923, 0.03446648822032979, 0.027505984396806786, 0.007010449938076947, 0.0827755250834993, 0.02382027547407363, 0.028272762894630432, 0.04165533264832837, 0.04252148938498326, 0.025365240339721953, 0.011075150354632309, 0.018900569195726087, 0.07202681114098855, 0.05083260019975049, 0.011310167743691375, 0.057391014349247725, 0.022109154345733777, 0.0428815302439034, 0.03137942190681185, 0.03839368266718728, 0.04024134370099221, 0.051815841546548266, 0.014124853137348379, 0.033814853722495694, 0.030331170119877373, 0.05600614133956177, 0.03135457395442894, 0.051260372424232106, 0.005597072944510728, 0.03435158849294696, 0.0643826120400003, 0.040571325458586216, 0.01807929585421724, 0.08498997839965991, 0.05095697906134384, 0.02009924371460719, 0.05927935016474553, 0.04417514029358115, 0.04119090935481446, 0.005699019862471947, 0.018747196532785892, 0.06160142592021397, 0.05843793281487056, 0.016435967159590552, 0.06708039942064456, 0.04742790146597794, 0.030820027459412813, 0.021010219385581355, 0.027731638002608503, 0.024642123874010782, 0.006167022004124841, 0.0452092446253768, 0.04232637324769582, 0.03976791624778083, 0.03672346193343401, 0.03552223442654524, 0.06614767839866025, 0.03557402700451868, 0.020223654806613922, 0.04649697516911796, 0.08214433145310197, 0.04562148857595665, 0.01291933304829789, 0.05539464558075581, 0.02561224574622299, 0.0426481854436653, 0.08751129239265408, 0.0313927008371268, 0.021881918057001064, 0.023848266739930426, 0.11418129450508527, 0.02638432020986719, 0.047503008507192135, 0.056071830314717123, 0.026182520502646054, 0.024373223838795508, 0.02033717880424644, 0.01555509808739381, 0.03920921390610082, 0.030202248466334174, 0.0060066952054122725, 0.08077605880264725, 0.00997547579130956, 0.07574127468147449, 0.015807411334078227, 0.011958613126937832, 0.05256895774177142, 0.07956393741603408, 0.07490117368953568, 0.02340869139879942, 0.025985618121922016, 0.05418331468743937, 0.01580529430482004, 0.03517853269087417, 0.05868130297000919, 0.03570947277226618, 0.03450423512341721, 0.028242206766403148, 0.006479653197207621, 0.017028823561434234, 0.044876497837581804, 0.04924893678565111, 0.048347357128347666, 0.04388627775811723, 0.026680071572107927, 0.03400536599968161, 0.04388621329729046, 0.016585299146494696, 0.040125575448785505, 0.027221069238813858, 0.038796064111271074, 0.02451521746947297, 0.02709532991450812, 0.04280679978962455, 0.0030705382606746362, 0.024904428548844795, 0.0423897416330874, 0.07656669896095991, 0.025865790533966253, 0.018709237587505152, 0.06023826942379985, 0.07612804642745427, 0.014466795770983611, 0.03956932261852281, 0.03314336868269103, 0.04316370581675853, 0.03867019586531179, 0.00798042507709137, 0.0029918294707645793, 0.08440850103007895, 0.06741916481405497, 0.011965402717968183, 0.03173182924677219, 0.010311057159144963, 0.06693044996687345, 0.0732464167688574, 0.05910814220884016, 0.05056318787059613, 0.025702607950993946, 0.1037156382309539, 0.05148260621353984, 0.02120132707724614, 0.03284962069509285, 0.09705632592418365, 0.07119202986359596, 0.016340253009860004, 0.019982985220849514, 0.049996526313147376, 0.0110308632221339, 0.06481891005699124, 0.018944366934842298, 0.02475602106590356, 0.06464377338332788, 0.10183296139751162, 0.02889099989884666, 0.027658346042569195, 0.03370005238269057, 0.008689003930027996, 0.05261769691216094, 0.03611660735415561, 0.027582404403282062, 0.047268452521945746, 0.04401388983907444, 0.07108799687453679, 0.033638780670506616, 0.0826829457655549, 0.060661437788179944, 0.03870169685355254, 0.03299121059743421, 0.012745234533213079, 0.04270417815340417, 0.13567447476089, 0.025251624739861915, 0.047707128804177046, 0.023252497726519192, 0.05258358695677348, 0.06550302941884313, 0.0056992692240913, 0.14086419556822094, 0.021313035993703773, 0.028679391967930963, 0.050945053808391094, 0.03591547261125275, 0.008334142837806471, 0.03860469348728657, 0.03832709124045713, 0.06114192200558526, 0.06620746411915336, 0.0404398525133729, 0.009314150965240384, 0.06600050415311541, 0.023232647184548632, 0.033756224904209375, 0.024959637550637126, 0.013959405095582562, 0.050407939058329375, 0.04074391423325453, 0.07201582565903664, 0.021304635730172907, 0.0408879638250385, 0.029511316612895046, 0.07318049709179572, 0.07850874760853392, 0.021221113158389926, 0.06816995702683926, 0.0222138404247484, 0.0351129488886467, 0.010875634765917701, 0.11649607600910322, 0.08428992025021996, 0.03736885390909655, 0.05646934327004211, 0.08489432531808104, 0.049530946117426665, 0.05150049239663141, 0.034897982209388695, 0.03163082930924637, 0.02154201272475932, 0.042908953236682076, 0.028964339356337274, 0.0288459485662835, 0.017903131200000644, 0.08671341663492577, 0.020093557591150914, 0.008773015047024404, 0.021027518635881797, 0.02632235299928912, 0.040406322705426385, 0.007795146001236779, 0.05843468941748142, 0.08612739308071987, 0.01645613830935742, 0.042159650408263714, 0.013960748594919485, 0.03509421114410673, 0.038595139714224, 0.0799164092168212, 0.047482991724142005, 0.03141921120030539, 0.04639360375170197, 0.03164844407833048, 0.02470391127280891, 0.008674535018924092, 0.02218413076895688, 0.015547929364921791, 0.035554396986429176, 0.027518669608980417, 0.017883647066940154, 0.037255494456206045, 0.06374088754611355, 0.03094274391021047, 0.029185599447893243, 0.03576495658074107, 0.02179907910924937, 0.024345112132972906, 0.04719119452472244, 0.021943512073318874, 0.021313694172671864, 0.02579050198463457, 0.015379610271858317, 0.06998205264764172, 0.03184657630377582, 0.053484762885740826, 0.09851934241929225, 0.03445685641574008, 0.0044171039397562185, 0.031418597126113515, 0.02277315514428275, 0.0382972356996366, 0.03183915313067181, 0.045296897779085805, 0.0302294441498816, 0.05517098686790892, 0.006699388705393565, 0.08582835591265134, 0.08712117546903235, 0.09881660182561193, 0.24043109427605355, 0.12215241177805833, 0.2846164261656148, 0.07661440675812108, 0.13165779172309808, 0.12854004544871195, 0.08810298849961587, 0.15239564036684378, 0.12148774601519108, 0.11524299824876444, 0.10731152099158082, 0.07720908163381474, 0.18462537521762507, 0.09709760120936803, 0.11987086491925375, 0.16316610814205237, 0.2350838312080928, 0.16608307590442045, 0.1627595435295786, 0.1254486534744501, 0.17414879452969345, 0.17841365853590624, 0.14743956630783422, 0.20822400892419474, 0.13142400926777295, 0.1190534880650895, 0.10335724281945399, 0.1393832386072193, 0.18446981427924974, 0.09829129358487469, 0.10377283194767577, 0.13779732584953308, 0.1107814269406455, 0.12862908281385899, 0.123625837000353, 0.09627837873995304, 0.1403378966663565, 0.07538816505776984, 0.12923430890909263, 0.20542429201304913, 0.11800538216318403, 0.09848337327795369, 0.24579013671193803, 0.1782450968665736, 0.08666343574545213, 0.2142277274812971, 0.13377992356462137, 0.14408577127116068, 0.21592007524200849, 0.1109744022999491, 0.09860698878765106, 0.10315478832593986, 0.18057670603905404, 0.14688048059386866, 0.12214045599102974, 0.1436590813100338, 0.09255475497671536, 0.18180290024195397, 0.12256904585020882, 0.14613296570522444, 0.20208773176584924, 0.06925925000437669, 0.22053792673562253, 0.1405728326312133, 0.13023156539670058, 0.16961947828531265, 0.0973489780777267, 0.16202897844570024, 0.18387279845774174, 0.07842304185032845, 0.2702253498136997, 0.15339654737285205, 0.17672741759036267, 0.11737230899078505, 0.1043874014701162, 0.12206986120768956, 0.17593476655227797, 0.23720710298844747, 0.07452390821916716, 0.17231961339712143, 0.1499349195510149, 0.10013099201023579, 0.0984707660973072, 0.15419734083116055, 0.19999295845627785, 0.1057245157925146, 0.13290177711418696, 0.12384995711701256, 0.13290930885289395, 0.09449742109115634, 0.18914274924567767, 0.09600570944270917, 0.12792237502123627, 0.1650787355112178, 0.16107969438391073, 0.12445568532816001, 0.11135778815618583, 0.1175069303384849, 0.16352487674781255, 0.2569177310381617, 0.17987993199910435, 0.19424128851720265, 0.16153039091399737, 0.33323223888874054, 0.11880840121635369, 0.17673114953296526, 0.1290171912738255, 0.19807414284774236, 0.2168932030243533, 0.15902390969651087, 0.08252456212150198, 0.1560231971421412, 0.12582324551684515, 0.13306900885488304, 0.054787519587469954, 0.15780284521835192, 0.08722799045166799, 0.12640198160495075, 0.11379925893353564, 0.2312224241239684, 0.10243203318012611, 0.14292874692806176, 0.07929052173026971, 0.10058419233454124, 0.08716737691845212, 0.12552378087171487, 0.13464401076946939, 0.06999252922832966, 0.1309581949774708, 0.11493528261780739, 0.14911914403949464, 0.20478588555540356, 0.1057885220008237, 0.10947581021381275, 0.08979497663676739, 0.18472541842077458, 0.14253189893705503, 0.19333131877439363, 0.13846679564033235, 0.10658616027129547, 0.15572457388043404, 0.13340563007763453, 0.10520923629935298, 0.10902453014361006, 0.1476503192846264, 0.19381751625665597, 0.06521993103836264, 0.18704503109412535, 0.18523468609367097, 0.08886713428156716, 0.15920087162937435, 0.07883380659456764, 0.07350236017789159, 0.084847058568682, 0.15776653002415383, 0.15325518138706684, 0.15092870193932736, 0.1493139107312475, 0.1359297532056059, 0.10085690912923642, 0.14982973305242403, 0.1786383350512811, 0.2120862031089408, 0.10457283830536263, 0.11283526423254184, 0.1950177497097424, 0.1098571333235928, 0.11310905311256647, 0.09916751299585615, 0.11664136392729622, 0.13195006389703068, 0.1758229032691036, 0.1204326647732939], [0.0544329104013741, 0.026700220669486692, 0.019023489207029343, 0.02361173282510468, 0.04000602436384984, 0.027017427309017097, 0.05342460397098746, 0.030908776447176933, 0.016010508739522526, 0.02653936037261571, 0.061601473417665274, 0.05509844468906522, 0.01910598379825907, 0.011610020850119846, 0.04139333331425275, 0.009951274143531919, 0.05369371435205851, 0.05097263625689915, 0.026290456764400005, 0.061753302413438044, 0.06552236088152442, 0.014840765257499047, 0.030663506393986087, 0.038199255242943764, 0.03798311809077859, 0.062484362827880044, 0.042383658566645215, 0.04496173540662442, 0.039409208710172346, 0.012668471866553383, 0.05592102590682251, 0.06710572234754052, 0.04420410356085215, 0.027295110980048776, 0.0427968863930021, 0.04563513730785676, 0.010807713410550994, 0.052934175822883844, 0.04059229219066245, 0.03662090815071549, 0.018131492160526768, 0.05640706054068037, 0.015894119627773762, 0.06334614301366465, 0.05353763094171882, 0.03419748979753681, 0.006278568496262389, 0.1147217612181391, 0.034738462019179545, 0.0104304343694821, 0.02196079775291894, 0.02310514366919441, 0.07406802768153803, 0.020722130380038704, 0.05849815958312579, 0.05504571573276605, 0.048129225083227666, 0.02861390316060611, 0.032538977185530324, 0.04371194175577589, 0.0068416732579602724, 0.013463919317083699, 0.039800306116896014, 0.046047656065119166, 0.013921044118303274, 0.02946198033168912, 0.010860366879829338, 0.012489815292480801, 0.06098247306155307, 0.015013491435508643, 0.05863680464348622, 0.03441297894875918, 0.026436633563467433, 0.022337494950209345, 0.03185763981725488, 0.03684524879125612, 0.01935126742215029, 0.029365679249167442, 0.01942601314346705, 0.03635452887309449, 0.03034074085631541, 0.05892536523086684, 0.030982716408159052, 0.008957358592722033, 0.10377755455140557, 0.024963557786707367, 0.023009156409118856, 0.04324685349794371, 0.04571030202454754, 0.032531475980899165, 0.016400486563465426, 0.027025659635130848, 0.03701750847644039, 0.009228751395962067, 0.06501340533473662, 0.07236327630068574, 0.054217570527855835, 0.027062195353209972, 0.008193373114668896, 0.036525190608309846, 0.019985214208385775, 0.02896903481866632, 0.018785811960697174, 0.03305360867774912, 0.03460653445550373, 0.06834204029291868, 0.06891164329967328, 0.05808676380131926, 0.05679283823285784, 0.016912100271188786, 0.055015249510428736, 0.01577394429062094, 0.006038050308624017, 0.03216541990903871, 0.036124977083610635, 0.04576593850340162, 0.021294033620506525, 0.09071677324495145, 0.021273024479991624, 0.023895167080419402, 0.025444930884987116, 0.056586516089737415, 0.04151211426194225, 0.07558831253222056, 0.05721448667879615, 0.02031211880967021, 0.03273345889257533, 0.03574812551960349, 0.07176002474235636, 0.0478907912703497, 0.06606496497988701, 0.012867818669682103, 0.05502996354230812, 0.08957044939909663, 0.03854308929294348, 0.0953770535332816, 0.05612035235390067, 0.018155044111024057, 0.033662872056343725, 0.022717340549986278, 0.01215911259142948, 0.02265390770376793, 0.01923587406054139, 0.021541770148490156, 0.0166676546380456, 0.023671901917883327, 0.02404134557582438, 0.017293962816308652, 0.053923937891210826, 0.03627393248357943, 0.03276253751079951, 0.023043105212439383, 0.03677298481177006, 0.04183523263782263, 0.05707207574908223, 0.040811883086072545, 0.018412717784355794, 0.06516047101467848, 0.012888829506534551, 0.03753235370719007, 0.023926622267546396, 0.046742285934409926, 0.027441922209358642, 0.06970466074666806, 0.06398741288908891, 0.03286777150684169, 0.04887463990598917, 0.02306216356477567, 0.026695011216881018, 0.028705040591635873, 0.05231202027893492, 0.05647177921075906, 0.061139947468681, 0.07218764429645878, 0.012781765162279564, 0.05023017645414386, 0.07371188500630003, 0.033272666923169575, 0.01982909008594496, 0.028899708895811012, 0.03272763366944023, 0.0660482526623777, 0.008032554378067809, 0.028688969489719187, 0.014268639796812619, 0.04735340510628053, 0.0599871300426977, 0.08560577607048409, 0.02322848097953413, 0.061907234867768626, 0.017442967410066297, 0.02045264850104494, 0.03412735641800931, 0.04211694680686508, 0.003417618676654196, 0.025572237625185932, 0.014186607457564344, 0.008195027043776852, 0.01578621898910829, 0.025742300553247333, 0.04431229257690055, 0.06082023533859423, 0.04731416881882718, 0.010616336849385073, 0.031122535334101746, 0.01142477909369128, 0.05506722868553229, 0.010980244509742727, 0.051947070219154866, 0.05419884974669133, 0.018543038916374956, 0.06964091916701623, 0.009546460151406271, 0.014373044283794505, 0.04017384643001216, 0.057934846595994065, 0.03903073544747063, 0.049587369696902375, 0.019751243459592973, 0.0661095447306122, 0.07660597256783928, 0.07436606740312916, 0.015408230878944908, 0.02644276412736092, 0.028906114266387055, 0.025413468912509934, 0.04238262040806668, 0.06459208258560725, 0.05291882057541183, 0.03033615735226444, 0.05053130690274494, 0.03110652869301183, 0.06913554628512689, 0.01595030232731785, 0.03448361783687558, 0.03255648338901145, 0.05613234206768019, 0.02385028198893581, 0.034034403905804665, 0.03348851230527673, 0.02731807090874229, 0.036833303182252815, 0.013137921408217932, 0.016204130403431397, 0.030596090547208275, 0.01985772935274456, 0.048618540433900695, 0.05694563074835709, 0.029149056944463934, 0.020617320468383174, 0.03414007216425879, 0.05796266653175865, 0.018754955580724136, 0.020516301871144345, 0.02695959746571524, 0.01493068302183279, 0.03862402494996786, 0.055535936927688975, 0.017773570027202368, 0.020220148476905057, 0.07760034528161798, 0.0323418424065624, 0.036374572797545364, 0.038281642964908054, 0.04809384287468024, 0.028440316939460378, 0.02844967393736754, 0.05224544242290514, 0.03622855206153222, 0.05528021743521094, 0.08224860192941767, 0.02196638548879751, 0.06352332207773413, 0.03296125666903598, 0.011982759643745209, 0.007896084022442145, 0.009076040304665054, 0.05269304483330675, 0.03794899456469076, 0.03819808816271169, 0.006882474840884762, 0.05758905836514064, 0.022783529944717884, 0.0489690580538341, 0.08044728823006153, 0.01221464983453708, 0.02372069706741188, 0.01848263742535242, 0.07189775378044162, 0.04904112865083984, 0.032800796707826, 0.014250843519611018, 0.018085986209501113, 0.03832675875829799, 0.04744065792432853, 0.0458183621189424, 0.0507667280201401, 0.0071182869640844205, 0.026434004240270172, 0.008411807956040969, 0.040307399085057635, 0.03980690147727728, 0.056636785356593985, 0.06726293891136136, 0.049313004062111886, 0.00871215300035796, 0.028907834352659326, 0.028665587172976563, 0.020774065450366055, 0.0684531300461718, 0.02595215956015246, 0.04628726713625448, 0.016141679736652544, 0.03114722722343036, 0.03414658610043781, 0.04119729097666485, 0.07570274746311562, 0.031203511703227247, 0.02520985242777637, 0.026713031410638775, 0.05563446021239672, 0.06452072784304619, 0.050293341279029846, 0.010352903261913784, 0.04473298428846257, 0.03232938111094492, 0.06404255064470427, 0.03467862880123513, 0.019863968482241035, 0.04548506911045738, 0.053405007879648886, 0.04424153833783098, 0.03375177710716214, 0.037940085399895906, 0.04594823032883661, 0.03706822896908436, 0.019914729686986123, 0.005394657890844558, 0.01450070386220302, 0.03454574789585812, 0.1343806848994323, 0.011572796418996794, 0.07474976538547448, 0.038038242275693586, 0.09085659217089415, 0.013285857309321207, 0.03613971486421568, 0.0777259421135698, 0.06241844993616853, 0.061997703941805024, 0.013818481853897018, 0.01721831633975463, 0.2585106598479407, 0.0691470338829926, 0.07878126762807369, 0.1330628070448126, 0.15548263543418475, 0.11354491686714546, 0.15092613707695687, 0.15484478537525448, 0.04844559882102268, 0.1007083710283041, 0.14071007312408515, 0.17274107863860472, 0.14685764110514096, 0.11730608397296496, 0.13686917136822427, 0.17725586066288607, 0.07464968825557403, 0.16666405115808758, 0.09338346336569105, 0.17714110682053225, 0.23454700144273893, 0.15628348317529472, 0.09307464850800377, 0.13591682032815047, 0.11295024877680199, 0.12764759548008442, 0.18906494842043944, 0.07373751327395439, 0.15441681976829255, 0.11950522953910486, 0.13598886717643055, 0.10924588862274374, 0.11841291029538427, 0.12023834591465336, 0.13168144545384816, 0.15597126207181386, 0.08672461924808365, 0.1073178652940052, 0.16502126359513827, 0.13328075249280247, 0.11302207849387612, 0.12334676911788327, 0.11595503932663373, 0.11064711093370404, 0.12718630023300648, 0.15757603810301848, 0.06780343955116612, 0.2415000040616308, 0.16811116279235908, 0.0901717942740236, 0.1409969170178686, 0.09811877605638333, 0.12010861001908779, 0.07361155681844268, 0.20711518770882062, 0.1274452834789242, 0.13627519538359983, 0.10919267790658133, 0.08975450202290501, 0.19320653618446418, 0.08019787911325693, 0.06635834995125021, 0.13309144122259958, 0.12980288054261888, 0.07163026170539004, 0.23870813101530075, 0.06474842383925404, 0.13410832094294683, 0.14317399662520203, 0.13687183122549737, 0.14839864841529302, 0.14825566751616343, 0.12065732771796839, 0.16544278311942304, 0.17028574539082392, 0.12528963200747967, 0.1437508463859558, 0.12009365510727678, 0.0666335162573627, 0.10997213143855333, 0.09796744917652436, 0.16545340897781508, 0.08833322221679346, 0.09660262348396437, 0.25366429133074625, 0.10539727870907102, 0.12208922659712178, 0.2259050573089293, 0.08820760502879109, 0.181887825684888, 0.10095607702221189, 0.12422270354415689, 0.12016921676695347, 0.142371873238257, 0.16439880271043095, 0.2014978677034378, 0.1726503177945103, 0.1379083070371832, 0.10992745669292552, 0.10284343574728284, 0.10106670537165233, 0.1558182252837079, 0.17757216654717922, 0.08825989972267832, 0.13187819346785545, 0.21248343107955797, 0.1533665018422263, 0.11687936687043735, 0.20043670678777353, 0.04110473540744611, 0.20957510785332747, 0.11080113838293723, 0.13880294188857079, 0.12375283161444323, 0.08222279045730829, 0.15201373371694768, 0.06351683528295585, 0.17601087103996957, 0.10800434595772199, 0.13681395218840667, 0.09479307915483202, 0.11899989736931664, 0.15736645220645837, 0.19666701049676963, 0.14143972897103854, 0.08267434194151844, 0.11547939984926156, 0.17325604600565775, 0.1293701651905264, 0.1165257551308189, 0.13589764492852346, 0.14175253361463547, 0.10573740117251873, 0.386931554547378, 0.10230098092662436, 0.1780667235808713, 0.1333117072603532, 0.1318875029683113, 0.0785893847101501, 0.11585114204457828, 0.0814528703423483, 0.1104022887136255, 0.1720208272870098, 0.09554047190717288, 0.19470334372350148, 0.15265409435544694, 0.07394972510103669, 0.0927704069763422, 0.1349295111639159, 0.07721710870308535, 0.17671802666570458, 0.07167979476175138, 0.2297916380422456, 0.0783383199679, 0.12268435609127794, 0.11272802177284445, 0.10822240675666503, 0.12179396886910711, 0.08261309737073523, 0.09606780896761588, 0.09431167891515152, 0.10837792019758906, 0.05976300314068794, 0.19687586357550962, 0.26964056119322777, 0.07810556888580322, 0.17107136680611543, 0.14528320915997028, 0.18876613516892704, 0.10198327047484261, 0.12679386271962098, 0.1695392890168088, 0.1544642357953957, 0.15224564341562136, 0.09565772954374552, 0.16067162342369556], [0.014510249153577855, 0.06080281055931534, 0.0077891409663217405, 0.029545653877513747, 0.05702900913144861, 0.036484631177570136, 0.04745830662016358, 0.024954726653439657, 0.02002445388851421, 0.053674922324717045, 0.012362957233563066, 0.013101476444197553, 0.05656249595007726, 0.04904421598517469, 0.07411806285381317, 0.027319076836907437, 0.0235349379280316, 0.028410759954048053, 0.015961878134735992, 0.021565722434648445, 0.015935617133176753, 0.1166495606303215, 0.040312260788466246, 0.020806592722822512, 0.028739208222499917, 0.016188658108668666, 0.016549708288429037, 0.08641898671963386, 0.010822807422040828, 0.017684437667152712, 0.013624581990630498, 0.02547761082782277, 0.051035241290394745, 0.010636841329479856, 0.0381792079258178, 0.023274857151721205, 0.010544135634388243, 0.019563321489840746, 0.06219578188444887, 0.003536816287253584, 0.019161645722176348, 0.045766233666134734, 0.012384250510617026, 0.05768748665494578, 0.03899003352437701, 0.05020607149760638, 0.04796067359192031, 0.023336139041930437, 0.06798183319291898, 0.09158260428479739, 0.001916913378019152, 0.021710855986124704, 0.07169189982648407, 0.06359245122543403, 0.01741414493881166, 0.03291285676615579, 0.04699062296588506, 0.12650940726910317, 0.011144685775174626, 0.08995610156229564, 0.04819436105234282, 0.0026033141018290606, 0.02688192556213055, 0.023918356014681712, 0.016179060230829885, 0.008750368092608238, 0.033879412936844995, 0.07090034122977938, 0.03527102379926613, 0.009884391794912517, 0.07836741554949965, 0.05289912948917065, 0.009503264612119113, 0.049485789611935616, 0.02698233856686524, 0.057965224608778954, 0.020229381642171314, 0.035847021998571496, 0.07202966098806687, 0.03968799839328442, 0.025094966271093914, 0.058121450511472564, 0.050949471071362495, 0.04042138618284038, 0.017637430457398295, 0.027445221585886817, 0.010878850173737322, 0.031867895874061754, 0.04695080653099077, 0.03626364250002163, 0.04584670791934643, 0.022551058758316294, 0.019328039472124407, 0.011343769645983619, 0.04015743945326124, 0.02242900218282427, 0.07976778969168663, 0.024406689185915247, 0.02959034897919212, 0.006474247817615313, 0.04047770798206329, 0.013331258087418973, 0.017414226363013898, 0.026888627791777253, 0.039531765705240626, 0.04321347975305148, 0.014483604779733079, 0.025869111962882534, 0.0360553627833724, 0.03225150564685464, 0.017691655583413582, 0.032669537501143556, 0.02407119093861963, 0.037931474790509255, 0.03568979186405029, 0.04147329866620047, 0.06589654580290828, 0.01792961442177849, 0.11746108851262502, 0.021694851041372334, 0.04166466589750988, 0.12566239200532436, 0.038468029749180586, 0.011119213570574564, 0.03052942787430116, 0.037997313043368716, 0.022625071661812917, 0.0768380519002676, 0.05021879402920604, 0.023715168703347445, 0.02531403978355229, 0.017314240835340958, 0.04096091991024358, 0.015205818793869444, 0.046525236152644665, 0.008145890930401427, 0.04323858215606638, 0.0300861138052174, 0.026012150537488715, 0.0111629722939272, 0.050987726875713894, 0.021191664738580585, 0.00877466643162604, 0.025554254750854204, 0.007052750235223877, 0.04220978057544146, 0.020264925002785664, 0.013466823446963514, 0.06735667852418763, 0.06707841131303992, 0.012289129230859024, 0.033164430409669876, 0.01914725569076836, 0.035060477775654623, 0.030676486768892834, 0.03587640256487897, 0.045172939609204016, 0.03607143049261399, 0.01260761236439326, 0.031564794281231504, 0.02704830913405333, 0.07445020574544157, 0.04276468312101705, 0.018532525016260997, 0.057514745209898264, 0.0577181021549872, 0.02917888873655881, 0.09920614877981798, 0.05759558587202004, 0.03413867438212037, 0.06335834307329995, 0.07077103281127554, 0.018524000920089226, 0.055412891387407265, 0.022203731949308088, 0.050885244339172325, 0.021361235728753463, 0.03402066357167704, 0.03415894900847759, 0.03158475678148014, 0.042240989793624194, 0.029129962969039167, 0.05128906088482056, 0.0069693731243855184, 0.02813001778641982, 0.021645343430074196, 0.035775524763656516, 0.08072714999850307, 0.03358221799135208, 0.030763647984713316, 0.03999176495043295, 0.023599739718650068, 0.03388590990964856, 0.03185420982273562, 0.04342144734359213, 0.037082641052880456, 0.02677651005797088, 0.036464841703751256, 0.009319535988782133, 0.03719465361375894, 0.018425406389204518, 0.016019334783777595, 0.03150587708556226, 0.035882305819541216, 0.0321676353258746, 0.008830368219475662, 0.011706373670936694, 0.007699876291943448, 0.022565552266314626, 0.01617811367447887, 0.039548070901738744, 0.049049674799399715, 0.0541166316584817, 0.01872821112296411, 0.01268163968675903, 0.005152333527803421, 0.03479475328432662, 0.014506451053810971, 0.017306907568126917, 0.06223619543015957, 0.014013583572315318, 0.026801816021491374, 0.035842604735600095, 0.025428079467798983, 0.03563313079731805, 0.028066030237823725, 0.06046874062823398, 0.039885954199624915, 0.022821443088884865, 0.03770522068121603, 0.04823939881420561, 0.04447176866233349, 0.06245915525193725, 0.0737967968785337, 0.016025555253561054, 0.062010853950466426, 0.038871754692601304, 0.07625365004475627, 0.06284627983612673, 0.01991962531714567, 0.03288370690175465, 0.007076278012911124, 0.0193103195301124, 0.056741619016975164, 0.008035028486379554, 0.016385314520448446, 0.02978644220690642, 0.0317615931853652, 0.07537633140704461, 0.07949302372123514, 0.0637089896148869, 0.02605145637478147, 0.026309985002236705, 0.022611268563196063, 0.025582622603646347, 0.061292706057429314, 0.033455443901142905, 0.02500831226019987, 0.01569238947039204, 0.03892151166551879, 0.025285086694306562, 0.04932928890255945, 0.010926784431960965, 0.07511063066444226, 0.034744731682751856, 0.044311495298253636, 0.014191106144737984, 0.023710310392613922, 0.02021410781890154, 0.04269491954307471, 0.022382602261911546, 0.05502564127423933, 0.01801198857304241, 0.012745052176926817, 0.0673677386449916, 0.03905618729602013, 0.07237733554627214, 0.036305321513542106, 0.01979664254135319, 0.01668839406089059, 0.02682989040788795, 0.028319446103913442, 0.017701594425099235, 0.019730046025610397, 0.02662066074221262, 0.022360337831612145, 0.0491667560168675, 0.017601330698068653, 0.022689357765817215, 0.006336303768746022, 0.027292325593797222, 0.013511756884067186, 0.04040410050324031, 0.029788664409092495, 0.05514953837596944, 0.01739365827026112, 0.0583299778934036, 0.04391121731272765, 0.012112673654753183, 0.010457683487662246, 0.036525377205439975, 0.04293700726702809, 0.03529895569330879, 0.08232331542032105, 0.03971510925995452, 0.014111787945564305, 0.04584884191198008, 0.05315635872206517, 0.029446496162563562, 0.034781043484274826, 0.040526257162647586, 0.03968683131305235, 0.05903978659106152, 0.003548638699742566, 0.07908143116427319, 0.005800987984652498, 0.02587484219111502, 0.03722197821895991, 0.006213493171214525, 0.02171186700330249, 0.016402954734595757, 0.019170549797958562, 0.044115890615752766, 0.051075726082282405, 0.016242255589791706, 0.07718923448451928, 0.048716622670846324, 0.01327336802413421, 0.01829199622651296, 0.010326350490296525, 0.03148799429514578, 0.031407974660396576, 0.07417204031454665, 0.05340662618566837, 0.07910964465034859, 0.027833677795050398, 0.03575981328529971, 0.08796274888196162, 0.032027751939105134, 0.009816784261991935, 0.024511069924171482, 0.018896640477968112, 0.030036618068282093, 0.06707256912652935, 0.04158670900921736, 0.04937415363799248, 0.023569349831502353, 0.021087197487109473, 0.04287534878988351, 0.05970208426671369, 0.02594973210112325, 0.04135690616177661, 0.23753749525972775, 0.14539818013353006, 0.14255286566913128, 0.08849921223840543, 0.14368836688143866, 0.0931416606264455, 0.0765527482809765, 0.10876618472060987, 0.14889313759548323, 0.12984314481062548, 0.19700954854488373, 0.14414166898599692, 0.15191796528441565, 0.15761744230985641, 0.23114127133573803, 0.10313748568296432, 0.13677846480693134, 0.08920539755906377, 0.07596314206187214, 0.0945148594411356, 0.10367488541773387, 0.1396151211644922, 0.1968257198376315, 0.20744761558515684, 0.17031113617122173, 0.10421262442001275, 0.17693266086280346, 0.18949071557394095, 0.13214198074170522, 0.11868017166852951, 0.09743348961429936, 0.12937738480312483, 0.11783919536641665, 0.16340594312974385, 0.08036277669348887, 0.18526667223445006, 0.08758646050201994, 0.11118565060730491, 0.14286018774977752, 0.07818496426833527, 0.08794182964733668, 0.09804978261568717, 0.08892546793712036, 0.18483201627220425, 0.1289114619472197, 0.07543773204088211, 0.08504164205597979, 0.10406832037759678, 0.1109074308936085, 0.12055522176836218, 0.1174317757998194, 0.1851592194288969, 0.15302264743617602, 0.23224731055753572, 0.10636548711253063, 0.1400487186121089, 0.10458918421396188, 0.27567553307328907, 0.04947484144940972, 0.15447034261056355, 0.11345515346952847, 0.17018195667437144, 0.1553426400891372, 0.14121038413473538, 0.10701008859489645, 0.04887720137568457, 0.13251676277390548, 0.1960163904087884, 0.19677681103348732, 0.1242400197578328, 0.14908680506050587, 0.15693430682378157, 0.17181950594697679, 0.10824406559446029, 0.12734460245285714, 0.15012344372059616, 0.11619468432451997, 0.0858482505593981, 0.1525232456624508, 0.11784969908850533, 0.10670684450971228, 0.1273810262126582, 0.131355314382485, 0.12827080275331224, 0.13276674864547594, 0.15653667173215322, 0.056223642347114425, 0.13651234337261745, 0.1397434321365186, 0.11890521459281445, 0.2163550704717636, 0.12960048711725644, 0.09084038196929864, 0.07724452151783875, 0.10999936783420187, 0.1323310070272003, 0.1633965793464865, 0.07089964912406035, 0.16378215008548327, 0.14321610650845937, 0.16777266881295613, 0.14602084457874298, 0.20368338828640326, 0.14259422916386807, 0.06212133980755295, 0.10423867337937866, 0.06560508108564786, 0.06825854655887399, 0.09543583502194711, 0.15239132488412516, 0.12404271534511022, 0.11422313297433512, 0.0876357832125255, 0.08509414709572281, 0.20224084997815744, 0.11263962901596512, 0.10758126580289432, 0.18030290358832904, 0.26995293157441275, 0.0599133325740695, 0.1031456281031881, 0.16132072359323502, 0.1021996010094881, 0.10282164120248385, 0.10570003424904176, 0.14910872174160822, 0.11792277731001377, 0.17350297846964427, 0.17802763996379717, 0.1361774049167122, 0.0756107856120382, 0.13259649063859666, 0.08594382221677474, 0.14965243185205118, 0.14470211176999978, 0.12434163716222559, 0.13575235701033048, 0.14178096423191683, 0.17771673521825246, 0.09556956070342235, 0.1054403113999537, 0.10406802860753876, 0.09397859285984721, 0.13894346649093287, 0.04185704753867217, 0.12288729234465531, 0.10296840154166732, 0.08656903116830758, 0.18406662877116883, 0.1923678261893136, 0.26290987378784586, 0.0674034363723227, 0.11047274778996195, 0.10770676763994352, 0.1664397410516228, 0.13989375478455, 0.11293562634715013, 0.13218930177390575, 0.23178435968501226, 0.09347722333456789, 0.24827278777956963, 0.19487992567675455, 0.10237343489591565, 0.09146208289478507, 0.23990598959582193, 0.11963275341050965, 0.12767359694199903, 0.1413045105125223, 0.15360303914972714, 0.12197905965149403, 0.21414964167135103, 0.14656762166747025, 0.051060815275247605, 0.19720299887870038, 0.09920414031616279, 0.05486649088561535], [0.032001414602356296, 0.05208326916077307, 0.0492546127310821, 0.010986749116065246, 0.037698693174336634, 0.036395020450332334, 0.034837538309927495, 0.007682366695787225, 0.01463488585847829, 0.06005755519228322, 0.013587762984181089, 0.02345258243648069, 0.014181581209413707, 0.02997284595455442, 0.04331775701471737, 0.08672945720276662, 0.06050722034914153, 0.00294073493569158, 0.024685010679864457, 0.026700183350060667, 0.041467025609953065, 0.05309940588527492, 0.03496569661157472, 0.05523114578266229, 0.050528569013944695, 0.10157695692032576, 0.02620215730608574, 0.042987951676228216, 0.023924345782558833, 0.03568027541041374, 0.019790800354842628, 0.013154614217845457, 0.013862962368875742, 0.03158359648659825, 0.04432972753420472, 0.03865730030728238, 0.028901602008513043, 0.016247459953384738, 0.002349199980796714, 0.030913862067141702, 0.03756089289007442, 0.021082773438787887, 0.05638495047709771, 0.0401131277238684, 0.03307905374094844, 0.05716272124222346, 0.04690781455220921, 0.031230751491550888, 0.059763138847691674, 0.026440097484737635, 0.05156232390020575, 0.012942100442679865, 0.03626342197614057, 0.04065563343465328, 0.08585897141269275, 0.06385690346360207, 0.044850818679801056, 0.015401272502328669, 0.024373827734962106, 0.04704938409850001, 0.04445405889834676, 0.03184319041403277, 0.052582155247884135, 0.026641099913311855, 0.02075934802581157, 0.03674716994698558, 0.025288023054599762, 0.015853992763108442, 0.04057507097188916, 0.01680830816206123, 0.012203198707928615, 0.013717431874413575, 0.02054335336600031, 0.035920449665614536, 0.053143120503851345, 0.03793309988187892, 0.035424342179404836, 0.011419833421574106, 0.03998618060722947, 0.0429696855135262, 0.007179531534867627, 0.004193267111466932, 0.041076053732207844, 0.051512644958815405, 0.07519850773470742, 0.07804874157799141, 0.012914824183098972, 0.03074251501155751, 0.07267671198185001, 0.041822618671825955, 0.054419916455766985, 0.028187981640387858, 0.057638557494751046, 0.03312833573935287, 0.05247659894770809, 0.03407134674489498, 0.07671301825238125, 0.04374415520578623, 0.04964088575382318, 0.048295313492417336, 0.08454767534775393, 0.04460245789960027, 0.05592132106955562, 0.06338758114725351, 0.1017638390351619, 0.09181727562099695, 0.048305600083300045, 0.029792725441179106, 0.033550194531146965, 0.03300647085000362, 0.024450001772493124, 0.014782350177743604, 0.05069369051073279, 0.022579156893438528, 0.034279830022049804, 0.02990016806870699, 0.030036139701093947, 0.029425549786537886, 0.010337548014441771, 0.020749955404815928, 0.05866606307349034, 0.020948625369263545, 0.08285545650869608, 0.011582105071283877, 0.05907708566103663, 0.015275950477059399, 0.046438868822796006, 0.04596976703032851, 0.04520587230633412, 0.03450704425839441, 0.02224924977469657, 0.020187763696802512, 0.01230016560293734, 0.0791004572861961, 0.029283732574965273, 0.028859179999147142, 0.04286909269701157, 0.017415992250399928, 0.03605218384681003, 0.05199628436405744, 0.02156251635668533, 0.03613587774868522, 0.01693815431956734, 0.07337104329573256, 0.014992702818874801, 0.053637056678001366, 0.007495164821323539, 0.07202003257615225, 0.08368187144930873, 0.09546860147799764, 0.04102735188124435, 0.04782523800219808, 0.019808949470253925, 0.029618660852845227, 0.053714993210243325, 0.03661004141239183, 0.017684451237853085, 0.04755398684314319, 0.02961321560932057, 0.03812785300293139, 0.06713392226291554, 0.024317188720617975, 0.02237068209797144, 0.03388954007199832, 0.06264807297182934, 0.06447802084897246, 0.0699644378785576, 0.04247471796614783, 0.053833889508886, 0.07966169395617076, 0.04451457404398492, 0.06894558362130608, 0.015346051626173514, 0.02553229566131319, 0.05547639208712748, 0.06667895774756159, 0.025576403830200434, 0.02955810838778104, 0.028785368959818567, 0.04479042227779116, 0.016523052040221434, 0.029896585403808525, 0.01812865418781127, 0.029273038863071373, 0.03911901285339679, 0.06881810046200242, 0.013772277859970927, 0.016946464677208235, 0.024542212985189896, 0.01244223302429808, 0.043265475891530514, 0.02125908567437104, 0.043188085579978566, 0.05534929230010935, 0.08658629309918199, 0.024144474416971207, 0.05633976683020592, 0.022275503990905623, 0.03263876933072295, 0.01989189189459596, 0.033287900034338236, 0.04846256219648889, 0.09173315084938492, 0.04712403312857662, 0.011652224880111004, 0.04479965374671987, 0.04775918261813266, 0.07560504520578043, 0.05109891840921981, 0.013079876978216427, 0.008995575381309857, 0.02209286271993603, 0.007423144266275423, 0.029315888349499022, 0.04976057593843766, 0.017647170827590992, 0.02492424177138933, 0.013769404264166951, 0.06501869790788208, 0.03155756449060781, 0.057920665214104314, 0.03437480456861002, 0.023691713444090316, 0.05870687695486205, 0.07681101227977447, 0.03707321620147143, 0.059466232279581685, 0.033551972292895825, 0.013737161128249551, 0.02665673166380397, 0.0459702250414661, 0.028557625466159413, 0.014209454579811012, 0.07911177525030715, 0.022499456170148084, 0.008585511224477418, 0.03561322936522109, 0.02586363279260695, 0.04758207480024014, 0.06333238910883665, 0.026287866456966315, 0.037370119376906326, 0.010679947811045816, 0.03558428306132555, 0.02155914912665529, 0.054065948485263755, 0.02574779499056084, 0.01817139171596084, 0.04539963137358427, 0.053387667917247326, 0.08370557267751012, 0.024555122113919685, 0.035734643028782945, 0.026080370448263626, 0.0497550357000104, 0.012146029588101166, 0.05970937851816416, 0.020673062120165144, 0.05047767210219588, 0.06765969190746546, 0.020996767428836653, 0.017160018307289908, 0.036296093437288485, 0.013336258890506412, 0.024384451897016594, 0.028137770049007874, 0.04013619112915226, 0.07155484932341746, 0.037966626297150335, 0.05060018499248794, 0.03028038516640663, 0.04536832716049893, 0.061049430897193294, 0.06754954531788826, 0.03428759924801333, 0.006138430234776544, 0.026301260738234435, 0.00773003208450973, 0.05921594785260303, 0.014763257898656386, 0.09273240901529789, 0.04086726172161954, 0.04531502823478409, 0.054441914561071565, 0.04468590074351855, 0.008331130990492446, 0.03786980952801449, 0.028732813029949154, 0.04032225900196603, 0.05735144218696015, 0.010804943291337361, 0.01372028426599822, 0.017245142221716896, 0.02548181774493839, 0.02289916079358331, 0.035568707289972475, 0.025206013615908365, 0.024461572490898625, 0.014114479185082018, 0.021786429520164217, 0.04303899447300604, 0.09169285943997757, 0.03567342559940048, 0.05739074293524027, 0.010137733870318957, 0.02574362200019615, 0.019793594222781912, 0.019422873222668256, 0.026549750440088764, 0.03963121858292392, 0.012228548776225319, 0.04515465309045144, 0.033680883768413744, 0.0397028684882181, 0.0713841366980757, 0.030851738793509345, 0.025513055800859417, 0.02304240801770772, 0.035941514785268476, 0.11475810355373792, 0.06402392485844237, 0.055339877626725605, 0.023704632750845382, 0.04399645488177027, 0.025163790078035424, 0.05408226725246225, 0.038478279020637274, 0.030757005126880746, 0.019133744362209524, 0.05148099808554564, 0.012843376990141613, 0.05704611499926873, 0.02484702448626714, 0.03373740573546716, 0.05907129097197737, 0.033980375554944785, 0.11007975387786116, 0.007017197544753019, 0.009400145948997565, 0.0385413725993463, 0.0886452194037182, 0.020626619790813754, 0.03069359263671296, 0.1312162418450628, 0.03209183278626629, 0.04856691409700683, 0.05152617833976235, 0.044115514028817415, 0.041077831493956704, 0.024073966146845902, 0.08370274318648235, 0.016315425413527658, 0.13091182389429637, 0.1479342726192304, 0.1665708611586264, 0.08325935447854654, 0.2586976098162787, 0.07577383757701942, 0.08332308927284819, 0.08294550489102091, 0.2028106294040169, 0.2062530546848263, 0.0849731575165476, 0.10757223450179611, 0.12556153456015245, 0.1381823673312153, 0.16698611101933888, 0.17425377746777876, 0.09257853762911898, 0.1439228007303817, 0.1993456089070865, 0.14409390012068407, 0.14111201012773172, 0.1384605938302619, 0.15188778404678616, 0.1060884887618678, 0.12334828903632504, 0.18393971558128083, 0.13579286555094378, 0.22544672047453268, 0.06259560864418745, 0.15093698006655487, 0.10631771146186761, 0.11331696302763053, 0.07989986653306655, 0.1633476705423423, 0.19652872505996907, 0.07397726005209343, 0.11706981807947159, 0.14528569259813853, 0.20710331334599427, 0.08242592348584107, 0.09594053615416799, 0.08977545518428087, 0.12165858756218638, 0.1501643458115203, 0.08799773414752313, 0.11518572989319052, 0.16849529503711633, 0.13599915376731328, 0.19855799259884016, 0.08157010083752018, 0.2047150329287563, 0.06765228230506182, 0.09059372770466975, 0.09612629868622337, 0.24913943984678813, 0.09928711157824312, 0.1340925246477127, 0.13412276016814367, 0.16949793909277233, 0.11150743226919856, 0.08598161661731345, 0.16837995765464647, 0.2012302263506821, 0.159749480762652, 0.17014619787888868, 0.1145676387740033, 0.13662902425442422, 0.17124725665364945, 0.08302134475005524, 0.11830783236239638, 0.0609835112201316, 0.08690918077315603, 0.08402358847005026, 0.1241003501095942, 0.19915304066879408, 0.09795626013406686, 0.1056389660973634, 0.08029896726033517, 0.18457968266946928, 0.09085887883390699, 0.1237949686391013, 0.0956259062513709, 0.26463546976447105, 0.10616770772529499, 0.1363320837595633, 0.14865691241409096, 0.10179360636643, 0.10532385443470307, 0.16601362105991158, 0.21969806323094027, 0.1224003756152732, 0.13312900492123195, 0.15611983409949712, 0.1298048754355737, 0.08988697919994593, 0.14271765468376024, 0.14116702574704373, 0.16037059814802238, 0.1019121939316392, 0.1098963390769703, 0.121217689077769, 0.13569108529814652, 0.2150961301688637, 0.16433649962501867, 0.2432697048144681, 0.24514794402888843, 0.11969805562070437, 0.15343151906771318, 0.14474605369780744, 0.08191729363586221, 0.16415968696985925, 0.08620648312249354, 0.15046573749610356, 0.15208485775760242, 0.13314769177564553, 0.09116428066045046, 0.15020775848201343, 0.07951807523412363, 0.08909231291285583, 0.1654535989676203, 0.11413982244474546, 0.06971861821200166, 0.11558730048792702, 0.08235595295471804, 0.1547115482389927, 0.15129577581371578, 0.09658825889761959, 0.1752156958516155, 0.12036382061030183, 0.19824317949158804, 0.11512217830334391, 0.14938979808773312, 0.13985879666038922, 0.13964626592184815, 0.11200616229325533, 0.08719626215419599, 0.14306553958782128, 0.18036330677568913, 0.11354736637856279, 0.165938100112336, 0.1012627612799406, 0.05234087498060294, 0.11531055319522109, 0.1772761217185429, 0.20977402717939445, 0.13297117767589434, 0.07172049329216991, 0.1926007265491145, 0.21957632047789438, 0.13346416050834314, 0.13098961114883423, 0.16085585925195897, 0.09173711349389382, 0.09789888321288995, 0.08806007794503655, 0.1105062538491828, 0.08207566370921475, 0.0889892570142235, 0.14861656672188214, 0.07219835836440325, 0.2163918742111751, 0.19551605225673743, 0.0862678023321288, 0.09931142348796129, 0.19074368476867676, 0.16375059820711613, 0.18249159971518175, 0.16107654598142418, 0.1171257836478097, 0.17933804036251136, 0.14956704500530446, 0.08817765449306794, 0.06932268624327012, 0.10837466322949954, 0.1132228027230927, 0.11062452928828341], [0.013337967950584633, 0.06163998706532376, 0.05365639492603285, 0.041456270829907486, 0.02799890955377902, 0.02087825789515461, 0.007279534874084804, 0.028916064982435534, 0.06889763155153819, 0.08135822827794723, 0.022456501510792544, 0.02354609134740063, 0.024549844807812145, 0.05147572586845074, 0.021016309237373725, 0.034628875220992734, 0.01403519745716559, 0.031552638326372416, 0.010752395843155682, 0.039284500759094954, 0.05024362501821347, 0.03508481004142335, 0.062388356908091476, 0.0746817286791546, 0.013075268029102256, 0.014423888609079378, 0.03410769247316888, 0.005745230641748224, 0.056423165569348, 0.025984198287395493, 0.03383701128352966, 0.02860923483967781, 0.02390030528684812, 0.035628459083714654, 0.06870076818657772, 0.03942171071789094, 0.024000614814992462, 0.028045633475163152, 0.07402415360723223, 0.02318240505909281, 0.045425534447921176, 0.04004260418670518, 0.01765703333408705, 0.04138733845736299, 0.001829436219330611, 0.03825845403064575, 0.022895055656720485, 0.02954330953902432, 0.008925354640398706, 0.0316561183093914, 0.03515479414324675, 0.07577428541013173, 0.07892728836408683, 0.039091142027505806, 0.018874077492260506, 0.022578539426571557, 0.005928507191129029, 0.025626605243555138, 0.046105870977044106, 0.02501978798370276, 0.01574843137391976, 0.0526876979773598, 0.0545721729286015, 0.07774063239672355, 0.044057136268488, 0.03328806288274271, 0.053670189542961974, 0.03645079602886524, 0.03191559349319764, 0.027483304363808463, 0.04832935220162783, 0.06180996008749519, 0.12497010986719813, 0.021541086524458866, 0.020997961650469472, 0.014542935881763697, 0.10942931699433497, 0.0812077767082623, 0.03521602175065449, 0.02762260421046189, 0.04015832494146057, 0.03829955628940037, 0.0381558120383748, 0.06331763775753123, 0.03675275429018906, 0.020778401289135218, 0.004573387942010803, 0.03461910770939929, 0.013172827794083526, 0.022366000206342766, 0.024055871314236095, 0.045354010071605444, 0.010314508357883563, 0.0656796113720962, 0.07742400760097162, 0.029511381073721817, 0.030291479213961532, 0.04017948505601712, 0.010920992287408029, 0.055081077585262914, 0.01893955442522253, 0.04434666716094528, 0.008294526570742684, 0.02102903346531093, 0.025802747845383625, 0.0026683264503455056, 0.005989129206032625, 0.012748674705757626, 0.04307914339005947, 0.020847420174894587, 0.07474997573133026, 0.03691929392516613, 0.022118584286155443, 0.04000990219148142, 0.07665969897061586, 0.04533782361873558, 0.0546331698341029, 0.021377695291968327, 0.055914277876062055, 0.033680703956633806, 0.10724537739796297, 0.005394713021814823, 0.03372097500999059, 0.0073954982051093665, 0.013580057370875562, 0.017063128595639552, 0.038232893616493256, 0.010967188647815158, 0.06021255294659308, 0.07155148378972497, 0.037775812071881125, 0.013345980600986098, 0.04876858148989933, 0.02837984080958579, 0.01660495630598494, 0.021064805831494074, 0.029594057173069035, 0.08246770767228943, 0.021859492474634732, 0.010929952342329281, 0.12106625363230705, 0.05754854303917714, 0.032498977546180995, 0.03640827902459672, 0.045882466714829206, 0.019593402643554976, 0.04183819783585412, 0.04845643502527049, 0.02652582699166877, 0.06738351458417517, 0.03521099041349121, 0.029723155245717083, 0.02671066841243633, 0.034496655887258906, 0.014602489204012921, 0.019628901899393116, 0.016629025639433945, 0.05420231706063662, 0.017698915908113122, 0.09195795628641333, 0.0190322965915714, 0.012562857890900756, 0.012571457474093353, 0.04578505962022713, 0.032379419675895145, 0.02167124141539846, 0.07770574212606464, 0.023962638906336257, 0.04471464009423341, 0.024899777191291963, 0.010075809068179556, 0.011261883191764355, 0.0156802861019969, 0.01652983739040792, 0.03615323128178716, 0.027276105214176432, 0.016892982547038367, 0.044300550528402836, 0.03709521769945111, 0.06257093711090939, 0.01310601584347231, 0.03990017968629088, 0.01932789189075785, 0.06109495381159442, 0.04696599893005831, 0.03211945255420037, 0.03218433068000844, 0.028133844723924994, 0.013826810871250927, 0.029132103747023002, 0.005806623217982373, 0.04124356367226158, 0.02727027659836624, 0.006150625629483589, 0.04597967703427587, 0.02441682480275631, 0.06823114731482097, 0.010746503614687493, 0.025897035375237465, 0.04931226106626647, 0.015478586478691016, 0.030681263655424118, 0.045641529107732434, 0.03043284859242184, 0.040008806357426305, 0.030563161242753267, 0.02114958199672401, 0.02738592101793204, 0.01076369684389127, 0.01662389252201787, 0.0848324429243803, 0.005195921769232622, 0.0830692086102707, 0.025250384717115333, 0.005888665735255927, 0.018872868003589765, 0.028804686851799488, 0.009670433588325977, 0.013322110587198819, 0.04580125964379736, 0.033155449998698065, 0.018872440526528016, 0.01873341548655714, 0.010679724742658436, 0.015289957136181849, 0.0072068968521697176, 0.008544559091595667, 0.08052192029676267, 0.06070263843451228, 0.06034843636942761, 0.012840129351908607, 0.04776415288714426, 0.04514220536553434, 0.03506167199728744, 0.03392751767699208, 0.04632573667913675, 0.04915265605917998, 0.031076710471617322, 0.021031801888187016, 0.03302842824320708, 0.01857594956111695, 0.02280508360958525, 0.005618188106122294, 0.008676557053279663, 0.020685691353199736, 0.036485601482646804, 0.039043118711560965, 0.06356881785073451, 0.00909501129561769, 0.017190767817997506, 0.06012285061712776, 0.06085503739970071, 0.019001435122585723, 0.03287515736051968, 0.043685238010116985, 0.011218743631616235, 0.039752231910824776, 0.03527813145358648, 0.07743178361228534, 0.08502916379698686, 0.06340288211192403, 0.027512043714523315, 0.0710854320121663, 0.008311317767947912, 0.0320564370070185, 0.031493297046316523, 0.012343194052976156, 0.004774081213067153, 0.07247959077358246, 0.04462120242949043, 0.09942577020930392, 0.06626522101994071, 0.03567252993317587, 0.03689811345455902, 0.028713077838931764, 0.07674571006957974, 0.01539574413826423, 0.02281504450365901, 0.008885628111394388, 0.014621354173868895, 0.0676169984840921, 0.050009469368628094, 0.007675211544015578, 0.04707110061177185, 0.03008157101326755, 0.0346505815562393, 0.11691136658191681, 0.045338020393890996, 0.038734388670751026, 0.02431888336182705, 0.049347164907625744, 0.014533173459182893, 0.055470047784703116, 0.040649950703872104, 0.028238934531275715, 0.02321047774915184, 0.03467283411217587, 0.06781669812543051, 0.062321134443793974, 0.021783896888207113, 0.04501015905823026, 0.04539513607908573, 0.05162061345098274, 0.016120046343920485, 0.061541816618825705, 0.043689519566084654, 0.027947649625795226, 0.04360803429569517, 0.02759726092751537, 0.028488343648080314, 0.02358317158983222, 0.04001287756753819, 0.037374848765986304, 0.03326442950804319, 0.02350970490702561, 0.014528213368196572, 0.05062818813270756, 0.03086590321202363, 0.021471862381856357, 0.012695202753613037, 0.029935838654637337, 0.0353894213746701, 0.016096658938165222, 0.0355172879062593, 0.011974968365393579, 0.04094571054780057, 0.010012695981588746, 0.014160008884833326, 0.044967133152697764, 0.032645008460219414, 0.007233071340514081, 0.02986889099702239, 0.04285244144765394, 0.06305119062640838, 0.06235140389097588, 0.0822798145402755, 0.006621406796122236, 0.04042224452963897, 0.04847446709339108, 0.06176797912589141, 0.050340424823973856, 0.031842196360230446, 0.027130730782768557, 0.06771786271461419, 0.09649930295667478, 0.06455768086016178, 0.032704651688358614, 0.013884320954925247, 0.07064403819718532, 0.09569466220481054, 0.030517119249062877, 0.04266586806625128, 0.0711004344214286, 0.13676241066839012, 0.21066193096339703, 0.126346246738519, 0.15032796774591717, 0.10188525609139885, 0.05754316904182945, 0.11387705297342368, 0.12512837137494767, 0.1787546630948782, 0.1330792275922639, 0.15742329987032072, 0.11769967499588217, 0.16010347248188087, 0.07693829187857253, 0.08462426159530878, 0.06502811597394091, 0.16166148387960025, 0.08987967137779508, 0.09336025068270308, 0.10623174786035504, 0.15189992982361997, 0.15339020985577786, 0.18338406325450965, 0.11268144034381423, 0.3225143440067768, 0.13407953748745577, 0.11285500281623431, 0.12099094981593744, 0.1463487669825554, 0.12743285271738256, 0.17170836191092217, 0.10954187238322836, 0.06406617044870343, 0.14973433102880204, 0.05228862439149192, 0.21686097261096748, 0.12060081932161536, 0.16524167891059602, 0.13368004320987634, 0.14725119141595705, 0.09317202506853, 0.10441212050084557, 0.10484371627015726, 0.12670135125517845, 0.12102027609944344, 0.0722294624096581, 0.12379062601498195, 0.09277569954948765, 0.08855988683977298, 0.09919468832335301, 0.15494208729692868, 0.18399428336748055, 0.13552176366959298, 0.13641696849039622, 0.12079783874963011, 0.10568206664174795, 0.09581050848854439, 0.12858200605426515, 0.09653044771403074, 0.11807436203317982, 0.12561356462538242, 0.1776072603783437, 0.13907037968082087, 0.1254065843032939, 0.10038318312061684, 0.09091669001749583, 0.1709310050521578, 0.11527501153094427, 0.11877451517752238, 0.1424705186592681, 0.15523262242121355, 0.15739942900836468, 0.06958141843123095, 0.16833773920578615, 0.091771868057549, 0.1560126119958503, 0.1345648393034935, 0.12039402898933206, 0.0847501094852175, 0.08893857044833046, 0.07856392607625041, 0.17431582270988397, 0.1914826908281871, 0.13061147715364183, 0.17667362333408423, 0.13188371674290725, 0.12364554165729455, 0.13380394370428153, 0.10934608788894755, 0.09856158122420311, 0.1046847083738872, 0.13678081253809588, 0.13611120704029286, 0.1566234835024391, 0.17603970877826214, 0.11552985571324825, 0.05217255079852683, 0.08601518374468599, 0.1522501353174448, 0.16165188939443656, 0.1443999329847949, 0.17663639890296118, 0.09799903498164245, 0.1353709931884493, 0.10218199981110436, 0.14657608978450298, 0.1322460544428655, 0.11682310274669103, 0.11604031760777746, 0.23106144847614424, 0.137946467846632, 0.07227548065462283, 0.12658437181796345, 0.12571780117494719, 0.15312452268387589, 0.13004988086010727, 0.20935271121561527, 0.11285394430160522, 0.12800061010888644, 0.1502075277801071, 0.12563803259815487, 0.13010130024382047, 0.181047935038805, 0.1331667314682688, 0.08938444259443454, 0.09809343955878701, 0.15131066287202494, 0.16024589698229516, 0.19142870658210345, 0.07605485964034285, 0.11004647173519645, 0.14167968609503337, 0.16879128558295114, 0.08754190789269549, 0.09629238370273795, 0.13018518074282578, 0.29840376919933725, 0.11677720663802964, 0.11128338679139103, 0.23415114411285945, 0.14641803183725902, 0.09621637420994894, 0.1281691174954176, 0.11700283310243062, 0.10148585002337183, 0.09517567112509694, 0.11596064402588777, 0.081519590690732, 0.1568151017917054, 0.09490372107497283, 0.09145109062748295, 0.17294789611228875, 0.11891326201813561, 0.08047834477786507, 0.091594851841884, 0.16770672877984388, 0.1644550125513758, 0.10158804418253047, 0.17078062812132494, 0.07846088374831847, 0.09811834857932158, 0.14869484252163342, 0.10153472490076508, 0.13875786002193177, 0.0895151352243764, 0.14548896811902523, 0.13704774821443216, 0.19187371698873384, 0.1390088094132287, 0.12507271793271812, 0.104165004832404, 0.12098671575742108, 0.1963671658720289, 0.08977700902947358, 0.1278680515076433], [0.03718452647860561, 0.033250499184110334, 0.0369386898486742, 0.049209289984511476, 0.04018492690686669, 0.0274982457049191, 0.03653656624789749, 0.03372771625540086, 0.028338646948603646, 0.054722729671214304, 0.013263195087867123, 0.03002364787140063, 0.05278741209102528, 0.046968529865677865, 0.031197150437427417, 0.03796580187710268, 0.011273190129681357, 0.12642682955733367, 0.025159425401527966, 0.019798929204366038, 0.017857045101534044, 0.03181157407483884, 0.019737686329920377, 0.04038560703130705, 0.05002697217943413, 0.006221231439017824, 0.01799089291931263, 0.04534945370895522, 0.024407603511852876, 0.08210121733801705, 0.01449008478916117, 0.018412846706009338, 0.04012389268193926, 0.035550468268671205, 0.05567590852401086, 0.03402704858620252, 0.09318892059049436, 0.06064483403627362, 0.04831350840894239, 0.02909741025151951, 0.08819075700427804, 0.02012293306844575, 0.04431221115269831, 0.01868943284664835, 0.054072981500732045, 0.025565326746020998, 0.05597345291503838, 0.02537763038916247, 0.03746237639071686, 0.029784929073814834, 0.07131098383771521, 0.042228555639407465, 0.019005102604361515, 0.042341636892940314, 0.037304695030408244, 0.041391989814915826, 0.01419262691134853, 0.0614163147817765, 0.01475429954007268, 0.05786691166992698, 0.06814797249223505, 0.005666556626757873, 0.024271743837743998, 0.020878164596589546, 0.04296329032097544, 0.006945538733686719, 0.05555126842643533, 0.07503844132380826, 0.016453963604622653, 0.008859807309428496, 0.0473849976967488, 0.021716024726629257, 0.02525880024768412, 0.03196319272475583, 0.03729203017428517, 0.0240776081835585, 0.006089045183866152, 0.018219476100057364, 0.033498697115906646, 0.050990027109427113, 0.028166680729814937, 0.06534810630338532, 0.04055967840499111, 0.021816542904291834, 0.08349477220326662, 0.009632875826875014, 0.03907901321404746, 0.07203550317457744, 0.02742437699011394, 0.01571136130951345, 0.014505606277712753, 0.013699827283354742, 0.04761555711073535, 0.035661948179560046, 0.03213533705898693, 0.02865390958530562, 0.07094853078680378, 0.032095456163265874, 0.0173771240681942, 0.01278745213390461, 0.043799991852470806, 0.045383377067212544, 0.05553042722333755, 0.03446489705571106, 0.0661965464907033, 0.07222387128110443, 0.021798003631244813, 0.02531210256607405, 0.020901049886431013, 0.0247134548678462, 0.026330950037975396, 0.008681001457651811, 0.06711467222443648, 0.02023494732566178, 0.027837280815999423, 0.07768574569906507, 0.0232395411003381, 0.019507876697129438, 0.01556397502177528, 0.14367316769702093, 0.002304397373726325, 0.027772392512166073, 0.05104663050068276, 0.07087634144616978, 0.06066763959825039, 0.03348591012348022, 0.03938239300623536, 0.014561330966119255, 0.01803450406129871, 0.04144279173176203, 0.04320940175758941, 0.055215549655258656, 0.015864457469433546, 0.08220029702144009, 0.049231454330895624, 0.07575690812830414, 0.03890970176351922, 0.016267710831016302, 0.023852283667240824, 0.05033256738845791, 0.012896200093174619, 0.02400189046082752, 0.04099063974406038, 0.03477016996060099, 0.06344729222889457, 0.01098659644568605, 0.09154451132885047, 0.05705957713403872, 0.02109213382937014, 0.02360865566879511, 0.11512319610587188, 0.028671103662678173, 0.03192747124869909, 0.0051502631478277695, 0.052310876947428496, 0.03611469727807811, 0.030139042929347073, 0.05492259894630738, 0.038618159014731646, 0.06196916475892067, 0.03221053909510374, 0.03374770589705024, 0.04681962535583547, 0.01100411028268614, 0.04403938239972506, 0.03578161461544888, 0.016452350387615815, 0.015132767713761755, 0.02050264805023159, 0.03279440151527524, 0.05566341669431754, 0.0479294508030372, 0.03082178147243602, 0.031373644181128056, 0.015825343318283558, 0.010294940256114517, 0.022548727990527238, 0.017695979547819922, 0.038850092462130954, 0.011495462086583887, 0.03237208131966846, 0.10218924656510353, 0.06270501563059432, 0.0034971355593630244, 0.013005001487077346, 0.03940459806472063, 0.0298732030870659, 0.03933640190267137, 0.05823384305196149, 0.06584398648036377, 0.014971252630597778, 0.026968861165057336, 0.021026862153251256, 0.056146682905299325, 0.02922403167134949, 0.0576400367010917, 0.020573273367647613, 0.046582820027002265, 0.03345808679504054, 0.015644177860979522, 0.02497982227110437, 0.022133249124245982, 0.13082620634564332, 0.010732776851260235, 0.021715022191139202, 0.034541025292128325, 0.04171956277319363, 0.0507147692010871, 0.025831660222528235, 0.01958033405909581, 0.057850565761327744, 0.03354906137766583, 0.023806514783895442, 0.01468472764827311, 0.02016708025309656, 0.07420265581458807, 0.01301010322224881, 0.020814056608027647, 0.01744258403778076, 0.016436252144298384, 0.07181073844965015, 0.10874576760189873, 0.020753751808245267, 0.04318912034588201, 0.024895383677046214, 0.047936782373913696, 0.03909961353721363, 0.050130581084106646, 0.017605208525700227, 0.028794179737035717, 0.03665738619331803, 0.0440712939016521, 0.05725997566644635, 0.02219057345895895, 0.07734480899359499, 0.02959381290046232, 0.03835574916696974, 0.01826480054296553, 0.003718605572690389, 0.03088873252272606, 0.037276451010257006, 0.01469761472461479, 0.002790777212274926, 0.028262669686228037, 0.04645732158262815, 0.007921075315347739, 0.03961277939379215, 0.027762540183695297, 0.031691320706158876, 0.06094527577183076, 0.08078609433557306, 0.027424166644258157, 0.053168619849852154, 0.014107811730355024, 0.033553298828857284, 0.0850633755326271, 0.03374429965125663, 0.09786384366452694, 0.031506413128226995, 0.005905571011161166, 0.024224858764292936, 0.0624940726639969, 0.03855686355382204, 0.018869008835671202, 0.025328750422756587, 0.03620935630585466, 0.03551715219925557, 0.07512492739728518, 0.03958622492583735, 0.03122921460973365, 0.008493175330970968, 0.016708477001105036, 0.0653442522244794, 0.01786834610226963, 0.03579778071226818, 0.029782727227679322, 0.02012270745555205, 0.03608311825831022, 0.016361709983487214, 0.014568021321403129, 0.03179934008845261, 0.06819660309702158, 0.026462468784302473, 0.09636361630899565, 0.04950438147144658, 0.07302863416927201, 0.005584204103797674, 0.01660609115580363, 0.04009960112827165, 0.04635510367474385, 0.07241750481937613, 0.12783202129815305, 0.08146184057529483, 0.020287644051547562, 0.019176001826833402, 0.02400788871039237, 0.008689495867916515, 0.05275097815319896, 0.044506855708147795, 0.0030156449897081722, 0.04675860470160842, 0.06475805903651885, 0.03295083437114954, 0.07162800896912813, 0.028671955224126577, 0.02904819949929203, 0.05508726243195789, 0.035328672134450505, 0.078962551829006, 0.07132930428321872, 0.03709858662581869, 0.056011539085635116, 0.01513833848626486, 0.034306225034275224, 0.017081873125529716, 0.038175628653594425, 0.034553876745381525, 0.020802604633250406, 0.036061764761273346, 0.00994355495952602, 0.031077748630195856, 0.03888177665482674, 0.019764569887359227, 0.033780502887176614, 0.015097339704100574, 0.012051567335480025, 0.017807849616344486, 0.04027990145342691, 0.02837255334348551, 0.040878223454845805, 0.01873827040461557, 0.05030799763543265, 0.020188978274485896, 0.05832174726362739, 0.019209158440519656, 0.052882936250950606, 0.020783817694921578, 0.035923197732440064, 0.008806301430532975, 0.044425143128527064, 0.07110033264117581, 0.14029167486088617, 0.042048774393541474, 0.0046565029686982074, 0.029201853754264966, 0.03028064300971372, 0.016170536134658114, 0.038371012812214236, 0.041206444414066415, 0.028500292649758712, 0.03314257140404411, 0.005016994205236967, 0.09904601451541696, 0.10455487069806882, 0.18741985383842671, 0.16879310405680112, 0.10549213111932788, 0.28199584249939236, 0.16433014853724412, 0.09838730629001345, 0.13740741248641694, 0.13345371106905596, 0.213794808568699, 0.1329972877034119, 0.15518929117492267, 0.12270004382090909, 0.09737284215433256, 0.11878732591867447, 0.07240191208464758, 0.19518674564148697, 0.1359737901283162, 0.13945088854857854, 0.08425258046814374, 0.15659871697425842, 0.0865569736010262, 0.12021838341440473, 0.18373629078269005, 0.11782194700624261, 0.374969769269228, 0.08858238027564116, 0.1369714265955346, 0.12985892753515924, 0.09711636270263366, 0.13286422698625497, 0.141413401812315, 0.13803269607680185, 0.19088089812014783, 0.14175516633050783, 0.1771765263485057, 0.1305768040141889, 0.12609148398041725, 0.19152641562478884, 0.28630255854555536, 0.053298976604959795, 0.11633010634354182, 0.08909986500761338, 0.11885859923703329, 0.22667245327361993, 0.13309255402003015, 0.1252414153090545, 0.21071774725403103, 0.06185135072363274, 0.21815378538199834, 0.1223893833479711, 0.14851429792387144, 0.12361606609608446, 0.10051513104034321, 0.16012912110558578, 0.09378399580184903, 0.1272131566490446, 0.15643101025904926, 0.14084164106420108, 0.15343116622950348, 0.09275264292955399, 0.12017125237200942, 0.10416357990886484, 0.15589601253824575, 0.10172183093215738, 0.27450763859919136, 0.23245643505028316, 0.1282602854605232, 0.15345323218830995, 0.1305643461112465, 0.06263520794787578, 0.14411127061716147, 0.09978363636348929, 0.15257572356079305, 0.11414401579116072, 0.19296999887696334, 0.11081547582788126, 0.08687549829483032, 0.14454572301890167, 0.17383844618286404, 0.2022304412509714, 0.11779335354055677, 0.09516072299863611, 0.12066095109496798, 0.17184124620897429, 0.10380236179168735, 0.10477062447794847, 0.11368113277213913, 0.11574212860848222, 0.1689595758382763, 0.15915441912199768, 0.22981769378696168, 0.12015719312642302, 0.1644285632563489, 0.09957657461719853, 0.10918076961700406, 0.12553348392248154, 0.13446893516395772, 0.10374242679349013, 0.1384491401591471, 0.11469156640980925, 0.0938481173611113, 0.06439715304544993, 0.15391262753733567, 0.21333702813301766, 0.08812328348202364, 0.18985637809549058, 0.17394346983305045, 0.13677626635347093, 0.12661084825439112, 0.06694828186716352, 0.1629468191947256, 0.13145402765699796, 0.13228076829441957, 0.212516543588468, 0.15173455726887497, 0.09952132151062999, 0.11548053978809289, 0.21988741521324429, 0.0580276023330433, 0.13950591773859092, 0.17198991323156015, 0.1728422482098852, 0.13669728487730026, 0.15091750611151966, 0.13127686216362885, 0.1842302099934646, 0.12458409129508904, 0.22533472148435457, 0.15512227905648096, 0.10530450261597123, 0.18269889216337884, 0.1878378449806145, 0.12511804407196386, 0.1252820731273719, 0.10258669845227684, 0.09657258473868881, 0.10064515870596681, 0.1497978011944464, 0.1067164254241756, 0.1498386218611683, 0.12983842220689568, 0.13774997767593178, 0.1636622936597892, 0.16488037258386612, 0.18033702032906668, 0.10639343596994877, 0.11378559323826007, 0.09352721100939171, 0.18321550158517702, 0.06681663250284535, 0.11715363072497503, 0.09478509279766253, 0.08192692204777684, 0.15758551045187882, 0.09121673820274216, 0.13569568576557295, 0.1331501073603119, 0.09674281560416732, 0.11792382225394249, 0.14781149849295616, 0.17104109057358333, 0.14981701730617455, 0.13281233262802872, 0.1963039128375905, 0.17741868192596094, 0.16363675360168728, 0.11102882759379488, 0.14745324557381018, 0.0952765421409692, 0.11477327559675489, 0.12278765626251698, 0.11537880024739675, 0.10579335995550666, 0.07259726910186665]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.028355808795562813, 0.01854092358345432, 0.032348006897206814, 0.014108406296665115, 0.014527745179033704, 0.041573748990361176, 0.07523854130080768, 0.012241457904955106, 0.03469390601718, 0.05900680300380502, 0.008617128411840116, 0.06267676821776799, 0.052166996989399195, 0.00773412873968482, 0.12472024613193103, 0.05605270919789161, 0.017346052253352742, 0.05271633894049695, 0.041473980593894205, 0.08129556556897503, 0.016594108227374296, 0.07671206151800496, 0.009348528941960206, 0.07580491448087351, 0.09371220679687602, 0.030114992255611078, 0.03871516577367272, 0.04691498327468123, 0.030678057577461004, 0.0659528167120048, 0.010725969448685646, 0.04641133726441434, 0.047821896217231236, 0.027726391230576804, 0.030109998237873827, 0.027417194696941545, 0.10954673747931208, 0.045244324885840924, 0.03622447067339506, 0.06107918465776103, 0.05033992610073515, 0.03144404897466302, 0.034871441312134266, 0.0791605483474476, 0.058985748062176366, 0.0018855574266386352, 0.016638058636869704, 0.03361664007284811, 0.049820449868483205, 0.04031150422192045, 0.052180035039782524, 0.0008781330917762326, 0.03193370698552046, 0.060046182945370674, 0.08846018290413277, 0.12510630541614123, 0.05009285792974489, 0.024527519309361066, 0.04331521590107253, 0.04790942384196179, 0.017008667678705285, 0.03208381589502096, 0.022836487906585847, 0.03698555965508733, 0.05644873955420085, 0.028414815897122025, 0.03579788588519607, 0.06875575666448899, 0.06285588110664062, 0.022059488975043808, 0.008032369477275227, 0.0382315704732069, 0.04772403450416667, 0.012167601912681545, 0.04319112202418702, 0.019845011910157542, 0.07429278562111513, 0.03457349319277065, 0.07222663291863032, 0.017777022074109743, 0.02741132367269269, 0.03466892235779336, 0.018752009042405655, 0.020614183940259472, 0.055103642267308066, 0.03357948688790202, 0.0758554789104632, 0.03209722374698945, 0.0171927287842014, 0.046592624858021736, 0.01551092036866716, 0.03261316481179424, 0.014369366623993431, 0.016403221059590578, 0.03479332836078746, 0.029967980858470713, 0.044409282372466156, 0.018580170048932945, 0.05299850433532681, 0.032393506062882285, 0.059547398638512404, 0.0247397107803928, 0.015126630364518081, 0.02193444684546973, 0.024931871897674034, 0.018675302354884998, 0.03774959347876055, 0.03337682204853211, 0.0014182980687889668, 0.0417454353134547, 0.018892362314675535, 0.06239218384559665, 0.02878822898492217, 0.03971826105511614, 0.03978286437424166, 0.02450823873680617, 0.031534470551248105, 0.027746323196749603, 0.011462838971056044, 0.03100921998598746, 0.0184669327323458, 0.01794571945044611, 0.05686122777738741, 0.0344435910561255, 0.008404095557385256, 0.018333697292421545, 0.007763352394769234, 0.02951733861118555, 0.026314570202625225, 0.0423356691774513, 0.0357290926123304, 0.019084728688799908, 0.12943018839827605, 0.0595279721809285, 0.015899232389139276, 0.04504304086523397, 0.017376314915184463, 0.006872183160989412, 0.011868730985692568, 0.008577677537687123, 0.03803189118791904, 0.0454980121659381, 0.042809741238930395, 0.037294781633785794, 0.022522243072411845, 0.02864459329949958, 0.03372261706473572, 0.02440413280523249, 0.01676538403678153, 0.09396648100976433, 0.09368203912994691, 0.0547413079600249, 0.060444842624877176, 0.02520429522597364, 0.033013106922486, 0.03326139645650983, 0.01381471089553088, 0.06881443637290172, 0.05632676949192371, 0.03344587316470487, 0.017964825300233703, 0.024010151624679565, 0.022905301535502076, 0.037217262400580306, 0.021911166308979903, 0.03447467474532979, 0.015951584758503095, 0.010126877310020583, 0.00959140291836645, 0.025724231165700724, 0.036725046312702556, 0.04125970941303032, 0.03028537579146879, 0.05039782210120133, 0.05416728090494871, 0.04368264939902084, 0.02785897527688316, 0.01199827010610274, 0.004797185330452132, 0.04819297344822969, 0.019557101020057286, 0.019315098112981235, 0.07429024111479521, 0.0128932357433119, 0.03467582305893302, 0.05990132250423942, 0.09567650460771152, 0.059792580482150824, 0.029453016884092773, 0.0057545074877063075, 0.027939111958923082, 0.04282677586057356, 0.04350307171366044, 0.03545014008081385, 0.027532240309353386, 0.02229703221070979, 0.012856783145772559, 0.06365883230630841, 0.010440320624703807, 0.06445283362908022, 0.027573520683550408, 0.008195493536602174, 0.02665304552231516, 0.04964666008683188, 0.026419463234820535, 0.036794823461345265, 0.028681539531264986, 0.022790814018143073, 0.02834179874376527, 0.02679038609910224, 0.04489668764706169, 0.03621420783123799, 0.08078981270747525, 0.03774577332660556, 0.10459349291133029, 0.011792393251588302, 0.051966018309550624, 0.03576837978991015, 0.04353173303284815, 0.016578038821795156, 0.014201210379334432, 0.01411468189741884, 0.029584248949374472, 0.027318109924505864, 0.012490161345340312, 0.033079291228204966, 0.025728604323895912, 0.01212629015623991, 0.022567967850981013, 0.0253814556303301, 0.1190275815980775, 0.062000472364681106, 0.05072185989203198, 0.02807560097426176, 0.03245824848168662, 0.03719508448349578, 0.04614729553993259, 0.05574357882142067, 0.03126630333385297, 0.028118738838072335, 0.047130404572401724, 0.021653017661135112, 0.059456542799515386, 0.06166942869978292, 0.04216865456796118, 0.008299704641103745, 0.0069594830524043316, 0.011752102690349733, 0.013795501569152942, 0.048099104913749864, 0.046027333941310644, 0.01553791418804654, 0.04149268101900816, 0.012898256902449896, 0.06002862245908805, 0.06752401204513651, 0.03996550903788634, 0.08245486978973661, 0.06909463062350239, 0.06279902665742806, 0.10068673933190958, 0.07654875170971666, 0.030845601444265673, 0.061702588706144264, 0.0330839425857578, 0.03866684390231967, 0.03622638414214764, 0.022282129885362725, 0.03479066850351436, 0.020103384474558488, 0.058863116428256035, 0.029423883983067105, 0.03914563517485346, 0.04061710621629443, 0.011029840330593288, 0.013756468842205192, 0.007241158629767597, 0.05976034328341484, 0.011096198510910784, 0.05355705400662763, 0.03995233528049929, 0.01922865105526788, 0.008608748504359807, 0.026503106246569326, 0.037379958134676726, 0.033645905288202424, 0.024126927501388958, 0.05595925796244826, 0.04103054778118219, 0.025063504298616732, 0.08287550721849714, 0.011079515879308539, 0.03778780857101083, 0.04158027988991567, 0.05110997174467359, 0.026661937723734548, 0.06000278384557792, 0.05766435539616006, 0.01724404638766178, 0.020944605049278055, 0.0048371896347297084, 0.020706166147387454, 0.08642140908965043, 0.015856391384399364, 0.0448158537702901, 0.11172856004642588, 0.0083095162574734, 0.050092684903315136, 0.025694596148761253, 0.07670377660542727, 0.009227697122176843, 0.026938471277909617, 0.05190446500533393, 0.021526101078572016, 0.02877730117844684, 0.08718057442456484, 0.015253806486725807, 0.05446082872471639, 0.04003303684294224, 0.05469768833635109, 0.045330872027469535, 0.04922892000260098, 0.03715349367952772, 0.050031508186033795, 0.015648386474432688, 0.09307381390993084, 0.04423604898953012, 0.008970841083542576, 0.06072842276522091, 0.05263948806428483, 0.07441738500658955, 0.04194919937955482, 0.021766614601282135, 0.028391640533560088, 0.03077708637075765, 0.02958266796278102, 0.033758352111492834, 0.01593222445808351, 0.03813499119132757, 0.02919614388208304, 0.04238097156797137, 0.10051531424479825, 0.023077245701902678, 0.04947663278185895, 0.01485186439406659, 0.04383449535816908, 0.004952612258161285, 0.05341345564063106, 0.011832876347138413, 0.0164655614644289, 0.032380841206759214, 0.0457591701165906, 0.11651365006608622, 0.06989564799836703, 0.08936276340058871, 0.14317684647228035, 0.11850861087441444, 0.11267645989677735, 0.13222757114895753, 0.0991847070732287, 0.16853375440197332, 0.17204444030565874, 0.1918870434165001, 0.14814358710178308, 0.10706339430596147, 0.1835910300058978, 0.18829463475516864, 0.22173731880528585, 0.09924639269177403, 0.13255090665604385, 0.13121902383863926, 0.13535141066781112, 0.12516052036413125, 0.11587997978287083, 0.06820289990199463, 0.1559014951011964, 0.13583991516913685, 0.1264537266854729, 0.09815211248184953, 0.15007566128458294, 0.08359499861087118, 0.19348875246942043, 0.1120704331302217, 0.11142096655177218, 0.14864866142826422, 0.17510824304606232, 0.13050506929201738, 0.1596862684403147, 0.3080180947269712, 0.12047546676227025, 0.1083665004532252, 0.12289206923118659, 0.11530464994055883, 0.06734844789441143, 0.11507426016032696, 0.2074318735727242, 0.11560449456529957, 0.07800812447177512, 0.105158224036651, 0.12658511820648397, 0.21351472288370132, 0.1134079477882811, 0.23743870056101254, 0.18587876510407242, 0.13134253078273364, 0.17563792105231965, 0.2412584184535912, 0.1562762228505952, 0.17631406762770244, 0.10286804621240922, 0.08185031544417143, 0.14030814969113894, 0.06348024867475033, 0.1506319378635713, 0.09496865687625748, 0.14062035722391947, 0.10219795895474297, 0.09761153041784253, 0.1218571811914444, 0.3567332721182278, 0.14318293971674784, 0.08819573745131493, 0.10203082899429969, 0.17499743827751704, 0.08913476884897266, 0.10680400393903255, 0.1208762638270855, 0.14012585447302886, 0.12850666152579443, 0.09545617750180618, 0.09973747562617064, 0.1341931378202779, 0.12823967156665667, 0.13389327962483677, 0.11858485106910978, 0.20577822944947652, 0.1480725851974317, 0.21099353102701052, 0.11420545035174914, 0.2009755043046815, 0.11274010648152658, 0.18611531598227365, 0.07130522986075707, 0.1433584631553718, 0.11551578289696149, 0.0738202945462295, 0.12347323447465897, 0.11721009840922696, 0.17565966131431715, 0.1303003959889923, 0.10718173081321375, 0.08873595310641186, 0.14807741636676447, 0.16381780031536305, 0.11599991763276712, 0.1580970308610371, 0.18952002828674658, 0.09234035826687302, 0.12335848063230515, 0.1351138148456812, 0.15199360836829456, 0.1340916696935892, 0.12022777433906283, 0.1695934496819973, 0.10854253279311316, 0.07503187989017793, 0.18577743268438748, 0.08479551026331526, 0.12704443213130745, 0.13834621996751853, 0.1392174725021635, 0.07316174916923046, 0.10412772611847945, 0.08350805791893176, 0.10674676272485938, 0.08402174964014973, 0.10666945044483457, 0.09305836366755621, 0.16929467714258603, 0.15533854173762457, 0.12061622206653867, 0.17216543667018414, 0.062468240835836956, 0.10420889247741018, 0.2157504686287471, 0.15496886228876455, 0.11981207664523806, 0.07049582579306193, 0.11772056030375616, 0.07980825073484864, 0.10592110774346761, 0.17107234389654227, 0.10325543542525598, 0.09995257801243237, 0.10896038822829723, 0.12768236361443996, 0.11358533041285616, 0.09675027270402227, 0.12969602484788212, 0.1540608602975096, 0.08968909803245749, 0.19394301809370518, 0.14999881040837082, 0.09936837293207645, 0.1594251545944384, 0.1243046298623085, 0.13682681721236023, 0.10306993073650769, 0.11790536610143525, 0.13403839112392493, 0.14099165158612387, 0.17233566753566265, 0.12925739267042705, 0.09429320240659372, 0.11323644127696753, 0.1429508535989693, 0.11415418024574008, 0.12897846049496106, 0.07956255998994623, 0.08966807023222957, 0.07524515023188931, 0.09095094925058739, 0.15193278448922293, 0.11133314376430851, 0.07802499963768891, 0.15263567891504082, 0.09451762786401169, 0.18526170535811357], [0.033458880681012354, 0.022104952517630796, 0.03319667778643114, 0.01684056910952287, 0.016111447608896663, 0.06325724814087152, 0.038240825690861256, 0.01500719293419804, 0.05007049680820533, 0.025616776663810015, 0.02912498591467738, 0.012520957505330443, 0.04011547884770802, 0.05705883074551821, 0.019111985440499017, 0.08530975838324853, 0.023653428802000623, 0.01954288231874151, 0.03963106591254473, 0.04121165556300964, 0.046123210939445665, 0.03506190609186888, 0.02260317703309868, 0.025894194009846876, 0.017088841680171232, 0.023529994800420742, 0.02467684620725257, 0.04160492088911789, 0.016376832832715342, 0.031099702630724226, 0.016328756930306554, 0.016318505962512324, 0.004050865511609507, 0.04958382095875485, 0.03959521212215934, 0.004511085704767278, 0.041348139489335675, 0.022238118407715644, 0.0048169383330137604, 0.051702974031546285, 0.02371626114472747, 0.041675631023411236, 0.056034080018954616, 0.07328298302101237, 0.036535945388355424, 0.025560407367135798, 0.029532724392733405, 0.051004693643855195, 0.0862138791541968, 0.0534517894765096, 0.04462900558220489, 0.021610858584088937, 0.025442406734717742, 0.043993968050926924, 0.028152584164802517, 0.04421574043642197, 0.04388310560690505, 0.056742836987333636, 0.029402255679347684, 0.05983209836163691, 0.022690014248447757, 0.07029381234730993, 0.01975409669934639, 0.03338494072003024, 0.031749783283365626, 0.03214706553678427, 0.060943375873778544, 0.03424690750294498, 0.006230333138124219, 0.016704974064071263, 0.0527864485712988, 0.022772339205922823, 0.04166229102494461, 0.04028849849211318, 0.014880288225997771, 0.051076323193098815, 0.013796322596525508, 0.014096413190210504, 0.02135637741801994, 0.05956890819860356, 0.01686824655293354, 0.04821748552577836, 0.03871925055448498, 0.003716734088292079, 0.017263683191101466, 0.05151727596031768, 0.08092926522450787, 0.0379112239128777, 0.06486298769180264, 0.022928821255585978, 0.056831565619047196, 0.04668274787919862, 0.09946074868951525, 0.02282873564399779, 0.10133818723261356, 0.06956782737480742, 0.04900773794257215, 0.03762858354353479, 0.020512366368036185, 0.07410605956933328, 0.06009306971515928, 0.011185670138469763, 0.03465970106688993, 0.014101331720926931, 0.032322460053754706, 0.010108286298678389, 0.021654766585145677, 0.04358667401330812, 0.07638122141361237, 0.02577939606271684, 0.024378190715132014, 0.030094527639448643, 0.034323531069925854, 0.03531899283240948, 0.03345399522887809, 0.04384237993508577, 0.003455862818684961, 0.034764487229819806, 0.042031451394515376, 0.025580961889188205, 0.017946140142157674, 0.027767647856048176, 0.023132142577586428, 0.07588895104293313, 0.020034789673185775, 0.0285641088682626, 0.08324971249593155, 0.021740714919620326, 0.056852888582008224, 0.024719480258811797, 0.012210699064391, 0.04894456972501107, 0.02176272320295019, 0.02591295211043741, 0.06692656874656677, 0.046382947359234095, 0.04088874414030995, 0.05967507178762129, 0.04384789303211229, 0.03610885509156755, 0.042541306000202894, 0.0461958379351667, 0.0038306635105982423, 0.012266455135042114, 0.023762718741116778, 0.016857118578627706, 0.019651413994974325, 0.017355819764946188, 0.031884923710354736, 0.030582621627088104, 0.02541290403210691, 0.046857351902872324, 0.07775133967931781, 0.043191396830869574, 0.03439375605168087, 0.028621160092630556, 0.06447126942553691, 0.026678811193310788, 0.10230801054941756, 0.01930197694205812, 0.04729069150718195, 0.04312005905168397, 0.027330008036057864, 0.038171852606215646, 0.028804547752120664, 0.039660561829805374, 0.04201363645760076, 0.011389400277818953, 0.05094790365546942, 0.019474636962903396, 0.020884149275454025, 0.026824889604800513, 0.02864931251055428, 0.01869787721495543, 0.06167599691876343, 0.0681281660550407, 0.031031482719949315, 0.08084333554974624, 0.0068792950561536205, 0.09840815088578633, 0.03275211860558816, 0.03843767887779644, 0.08431928724582706, 0.042833927619670115, 0.007797542078021381, 0.02189104604933943, 0.07152603194117546, 0.0652746209608657, 0.04398751857557467, 0.0300525297144694, 0.02753474240723465, 0.030567259594265903, 0.013131750980392098, 0.02102449576237372, 0.004217196921152728, 0.02264331577212683, 0.06524275017103978, 0.015342016039150102, 0.059915042482316494, 0.022601146517055373, 0.00951539766642132, 0.023421403752373796, 0.07038134336471558, 0.04101489737097706, 0.03164087502019746, 0.04489800739767296, 0.037819625078035254, 0.02595474986758615, 0.056683499099952836, 0.01882014243996569, 0.05041020875796676, 0.024507639929652214, 0.07382801627474171, 0.013520102864796562, 0.012806156799862427, 0.02164035619768713, 0.07621398967291627, 0.044810781721025705, 0.06489781689430986, 0.018608091764950326, 0.046924964524805546, 0.024869845315281833, 0.03458012587257794, 0.04542262353269117, 0.02457872325820582, 0.040276454495532174, 0.013270811643451452, 0.017115709970572164, 0.042847966509205956, 0.03116347813712699, 0.019410393267337765, 0.01375307107809931, 0.07349165289529733, 0.01811889685424311, 0.026815189946708933, 0.023377024169479097, 0.04441167420840689, 0.06421305292419024, 0.045701111267719946, 0.07618808320590428, 0.04514213751203247, 0.013585458509624004, 0.0249316378030926, 0.03688428830355406, 0.00430141159865473, 0.029037434541221176, 0.06873062372739826, 0.026190813896911483, 0.06697597288127456, 0.012390286079607904, 0.048126680576907735, 0.010271296703389712, 0.02086558286100626, 0.015052980477256435, 0.0449828785578055, 0.0585453991911241, 0.05333142754222665, 0.0477575541340879, 0.013888529568378414, 0.01678694279066154, 0.04125320226220148, 0.04100273802344288, 0.04226818547717162, 0.05092195308368121, 0.03969086181106312, 0.045606469203318865, 0.07607841837619032, 0.047732421196997166, 0.02014267334847578, 0.0628733126712697, 0.07928502559661865, 0.08153733438146965, 0.05776827981961625, 0.01615952011863036, 0.03645167133903929, 0.03924377847995077, 0.06016291132462876, 0.0483417693924691, 0.019582086375781467, 0.041949084028601646, 0.06070772066180195, 0.013144242810085416, 0.0801056729895728, 0.04197464444275413, 0.060801595981631956, 0.11618466914764472, 0.06555909676743404, 0.03774237725883722, 0.039687821974179575, 0.03727952138121639, 0.025218244209619503, 0.013348119682632387, 0.044859680347144604, 0.008286789575192546, 0.04556501071367945, 0.006914262934255281, 0.0004969826903626588, 0.04954933441643204, 0.016778549312480857, 0.038169308099895716, 0.03765642044267484, 0.01885718197029616, 0.03281854379123875, 0.029118417695696865, 0.013855589237729353, 0.044252527212457995, 0.022819731484300325, 0.037637282362473864, 0.05354865035042167, 0.04962950332888535, 0.10167904929923159, 0.03526750559519444, 0.03564541567383068, 0.04659119654180748, 0.03253459384930985, 0.01662802988929408, 0.039488454815000296, 0.06311074564499514, 0.0335548458886998, 0.02534294537534671, 0.030270237675202743, 0.016897764522582293, 0.012869537907785602, 0.00927060004323721, 0.0389842150865921, 0.04560535640588828, 0.036035145832491774, 0.03290157951414585, 0.08177839751754488, 0.01142121254399951, 0.05765130716775145, 0.009731937698753816, 0.017336698648120676, 0.03469477454200387, 0.030900155659765005, 0.03352695470675826, 0.01300422371631222, 0.03531749327001827, 0.04842021143329995, 0.00983052289978202, 0.04077040424038257, 0.012130415649153292, 0.05061144867379751, 0.038921274178262265, 0.030255618638225963, 0.007141184128288711, 0.043831041614924154, 0.017073379563433782, 0.04107889000858579, 0.02930438718093293, 0.031150158494710922, 0.09927202095942837, 0.11123659501650504, 0.14303310561392987, 0.08419717808387109, 0.18023993553859846, 0.06253472369696413, 0.1251163613051176, 0.12729798709707602, 0.18744463393730776, 0.10080503512706075, 0.05542362920407738, 0.11400106203343187, 0.11811728615845953, 0.10055425536951848, 0.15942795015871525, 0.14647264033555984, 0.24995617887803487, 0.0444289904220828, 0.07142094043748719, 0.13988766154008253, 0.10471475390451294, 0.09270338128720011, 0.10100505367985793, 0.1774776873311826, 0.09313196436102901, 0.07429357950708695, 0.061613191717437336, 0.22980545301522526, 0.12486995809844562, 0.0903116606974176, 0.12246273298348699, 0.06400944492114441, 0.10528487938323192, 0.08126115705817938, 0.18395488762429782, 0.1245647801884583, 0.06493135009493146, 0.20173169087086404, 0.09199680241623096, 0.1693641184163945, 0.11882505246571132, 0.09612776432186365, 0.18370047770440578, 0.22274388479334967, 0.16475478932261467, 0.12825860269367695, 0.1234770342707634, 0.08221181176070656, 0.11087171281022684, 0.2610482451106821, 0.18631509026246412, 0.1507134706314121, 0.08381259122065135, 0.09855377128613846, 0.08784013760409184, 0.16888386490089552, 0.055712254252284765, 0.1752725706568786, 0.12163862506193773, 0.1094509894028306, 0.11848931333848409, 0.20117432863584586, 0.12428419238754682, 0.10548841953277588, 0.1522139829716512, 0.16595030017197132, 0.08051089410270963, 0.13786931841501168, 0.09795299638062716, 0.09610870427318982, 0.08126967267266341, 0.16715935458030018, 0.07254074713481323, 0.1938062118632453, 0.15429922964956078, 0.12511705341083662, 0.0860350648207324, 0.10035131233079092, 0.06792670222265379, 0.1076560742887003, 0.15278862070824417, 0.15680233176265443, 0.14518659934401512, 0.12516680359840393, 0.06099077833018132, 0.08840777285929237, 0.09680163101958376, 0.11569070922476904, 0.10463225761694567, 0.17390560757900986, 0.10294108372181654, 0.15537203422614507, 0.1789466885051557, 0.18351654043155058, 0.12834534661046096, 0.22454156833035605, 0.2040319652961833, 0.15987233631312847, 0.08486010679709059, 0.12358608841896057, 0.23230400894369396, 0.12457681739968912, 0.10527392782803092, 0.1262961844248431, 0.16861600641693386, 0.14635798148810863, 0.08450526012373821, 0.1443068922630378, 0.13226585409470967, 0.12219758863959994, 0.20580036326178483, 0.1726285775325128, 0.07696935521172625, 0.1709773082818304, 0.11652180605701037, 0.11118461244872638, 0.08912349838231291, 0.13685371434049948, 0.14795700354235514, 0.14233141898044518, 0.1173432676919869, 0.1062040025634425, 0.10880928526499442, 0.04724015761166811, 0.11295328182833535, 0.1057544866842883, 0.1857663725635835, 0.08432763322655644, 0.10171081152345453, 0.11216827109456062, 0.17221996374428272, 0.1177988632449082, 0.2507354084934507, 0.12374768831900188, 0.13640143003846916, 0.13735925007079328, 0.08521978463977575, 0.17946492641099862, 0.231453858848129, 0.1009951267125351, 0.10050380629088197, 0.11746287984507424, 0.16748787409492902, 0.17427160936806882, 0.09953357585306678, 0.16377362768564904, 0.11915889169488635, 0.05858060158789158, 0.054200006648898125, 0.1082888353349907, 0.18650453723967075, 0.15741298613803728, 0.07065075569386993, 0.21957573693777832, 0.09254351165145636, 0.2073945812880993, 0.08916945555912596, 0.09155435687197105, 0.13488164730370045, 0.19645400478371552, 0.10526267093207155, 0.12424384669533797, 0.16239935000027927, 0.09620267458792243, 0.12720223223524435, 0.12641925710652555, 0.12121414712497167, 0.07534562769745078, 0.17877204716205597, 0.07811208282198225, 0.0825390149173992, 0.11885321166898523, 0.11582180219037191, 0.08226118196866342, 0.08908965984093291, 0.1215020902454853, 0.21060878810073647], [0.011083772838381785, 0.023970184215743626, 0.033053771526153596, 0.07086268253624439, 0.026738744495170455, 0.05120740258800132, 0.041668408018137724, 0.016544559903975044, 0.02036347033988152, 0.03928135235660842, 0.02792116131500474, 0.019704241338851194, 0.031253801326134374, 0.08776466415396758, 0.0392732845752367, 0.042567049618810415, 0.05774450395256281, 0.056470998895487616, 0.03414167689957789, 0.06358335885618414, 0.005667881042297397, 0.05821503406124456, 0.06261890275137764, 0.03461467009037733, 0.057238527174506865, 0.015798005142382214, 0.021991947599287544, 0.08372392704976456, 0.06421616061457566, 0.026734478206240704, 0.07140044189457383, 0.06232570776981967, 0.0032919768917573883, 0.03967349470726081, 0.06812276491629225, 0.024023671434926133, 0.049693855590053966, 0.004479195831143963, 0.05060600682294794, 0.07005384843796492, 0.06133780149476869, 0.04546752219487514, 0.030308703825409924, 0.050708543642291, 0.030743661735739027, 0.005164753687235394, 0.01449656140591417, 0.025940517595570003, 0.045404442186866484, 0.06705351586320571, 0.07022522602762495, 0.01718994339794985, 0.0038200567360036075, 0.02018702239729464, 0.024219749395602515, 0.05808711663952895, 0.012924382197005408, 0.08313343873513596, 0.027210769077230777, 0.02635659696534276, 0.01772963658108243, 0.04742339938612921, 0.010478460229933262, 0.04037871650819268, 0.018833563862634555, 0.050052688656640906, 0.012712272998344685, 0.02039740896517677, 0.023866224169198955, 0.05391925260690706, 0.0620932009603296, 0.03881383155073438, 0.017580767694328512, 0.041998990279223235, 0.024173061097306863, 0.016034586554659263, 0.0374483985693327, 0.03718161217070051, 0.026710469940943376, 0.0328353884230767, 0.06469319787408624, 0.06672121012317282, 0.012040823581628501, 0.08204090236020939, 0.06072848383337259, 0.007121748340848301, 0.10385827986257416, 0.016824185881497603, 0.05746194840009723, 0.015589420084974595, 0.025954953428091745, 0.029530227383864776, 0.04242220614105463, 0.033168240383799584, 0.028674099394785504, 0.029379080315785747, 0.03585030950073685, 0.05976217532796519, 0.019562427519953678, 0.010342567477242222, 0.028779119652296816, 0.03738956958321588, 0.057500713105712614, 0.007820266215795917, 0.04909122149859156, 0.0869884133072836, 0.04660436012116926, 0.055804518051445484, 0.09749283428703036, 0.06710867397487164, 0.04074549521984799, 0.02182705171539315, 0.01094221431828503, 0.041499371374292035, 0.06685163133910724, 0.04051015552665506, 0.040838335773774555, 0.01471926677705986, 0.03648414263235671, 0.008822135045193136, 0.01649607009520488, 0.014602302606882793, 0.06900314374693803, 0.022429229492055516, 0.02437673695385456, 0.07556539161929063, 0.06304105331322976, 0.05430270631664565, 0.0330969433167151, 0.028328295896894166, 0.051573129570377726, 0.025336348318627903, 0.06439414034996714, 0.029174552897789648, 0.01693777773263199, 0.08839777125311749, 0.008259827138057776, 0.013360322286774005, 0.003415535998231332, 0.02848847596240895, 0.03830056391390307, 0.012217555660754442, 0.035862211004963944, 0.13570773654750415, 0.03488611123923745, 0.030345799334879433, 0.045213760275925906, 0.04460953841251986, 0.04824260828484382, 0.04614501566226993, 0.027685555296816995, 0.033644242877406735, 0.08499963395297527, 0.07649554099355425, 0.04223563954500215, 0.051614096122128625, 0.009502039008241678, 0.05256972787901759, 0.10779311122106654, 0.01778044697961637, 0.025666285971445695, 0.010676670486905744, 0.015468338903571879, 0.015041177360607045, 0.03831379195409162, 0.029836653798286403, 0.0652602156624198, 0.08049430392150368, 0.022197318097044314, 0.010227862828677254, 0.021483310963958502, 0.02836412763489144, 0.07416869513690472, 0.0123216972154166, 0.015895015293998376, 0.04518344672396779, 0.03589074340249811, 0.0245246389282069, 0.05604185942294342, 0.06135313638619014, 0.05059983893962843, 0.08927663695067167, 0.05888635625264474, 0.02260049681977502, 0.07178020437381097, 0.02879926874967558, 0.043417715400989564, 0.0722260968759656, 0.03378019415374313, 0.06174126520220723, 0.11368176380970649, 0.034239609858819416, 0.024217622188319052, 0.013940169475972652, 0.02997496976916279, 0.004239394770203424, 0.01711632913377668, 0.06997225460197244, 0.03344735576372061, 0.012390947651251085, 0.04490609892777034, 0.03961765806057623, 0.03242993321535843, 0.06610531745744602, 0.022795553585248332, 0.035157630419624705, 0.01659498014487326, 0.031676124914416244, 0.024047700056274022, 0.06369300332984754, 0.018287599319592118, 0.03309916551890118, 0.03276802346642528, 0.02832179722775306, 0.010816716722079685, 0.030001571734568903, 0.04945176786610058, 0.03431917826778122, 0.05496990301513246, 0.037795245314815214, 0.04290465471733894, 0.06975162894065891, 0.0704339908968125, 0.026137333463079164, 0.020656870578282645, 0.04381049218188439, 0.013805467552239341, 0.04039274521970323, 0.00957709176665438, 0.029579774010926485, 0.017209654840241586, 0.06718361138233117, 0.03559420324329819, 0.05957427541060107, 0.056341744759785276, 0.06200079806149006, 0.027636973885819316, 0.014690976955794861, 0.014622197253629565, 0.020816109176459055, 0.030331336360956942, 0.049282154467489035, 0.0392878934341882, 0.03566577172439013, 0.015359257613973958, 0.07383639618222203, 0.05704483256808349, 0.02832392443503652, 0.010595130933714765, 0.02332353186128395, 0.002615419802688328, 0.03611596953123808, 0.024308167597545043, 0.03392653040853994, 0.03469750903812902, 0.07111990837646381, 0.02152674229416464, 0.03401873653222408, 0.09109464261148657, 0.056667780836245844, 0.009941190264986029, 0.022211029593433653, 0.07614076217370373, 0.0379151899500617, 0.044035874373678646, 0.01134611398447305, 0.04136016991521631, 0.05772426325295653, 0.023147954139858484, 0.0961263868957758, 0.04080852433773024, 0.04733905748331121, 0.06926324657563653, 0.041448949437056265, 0.01456897466310433, 0.0766572698152491, 0.02433628269604274, 0.0373270595446229, 0.03457626161564674, 0.03724816967067974, 0.057437785768083165, 0.012577936635352671, 0.04299883198525224, 0.047334847173520496, 0.0455800979398191, 0.12436284816690854, 0.02457618384089853, 0.01551007219989385, 0.0027695727808999693, 0.03765548067167401, 0.05128117630790387, 0.021610068090792214, 0.03257240182054894, 0.026762985158711672, 0.05855647288262844, 0.03934449343276875, 0.011941461458003946, 0.04389881708526185, 0.04696382083264845, 0.04428996198943683, 0.040142840772335014, 0.018339807500264475, 0.03391237956072603, 0.049949622579983304, 0.06607974347259317, 0.029655294958502054, 0.02915020366864545, 0.04109786863305739, 0.025747135115255202, 0.05212759446086628, 0.00834125218846436, 0.04314933783773865, 0.03190941543185285, 0.04477984730952552, 0.016034620481410196, 0.0431621655422662, 0.047058927693537304, 0.04042816474767668, 0.011719914685402597, 0.03127964672499469, 0.04827422462403774, 0.02722221426665783, 0.07543786774788584, 0.061308570206165314, 0.021152197749220898, 0.017280921373250227, 0.04189638560637832, 0.05722002352454832, 0.12415603069322449, 0.019524704365591918, 0.011837443735982691, 0.06397454107978515, 0.06361053418368101, 0.016855130471023064, 0.028513456229120493, 0.01672214100004307, 0.02736824857337134, 0.020616051607898304, 0.01587000788588609, 0.0027671302668750286, 0.04591230868494936, 0.016353092588750378, 0.009627833463517683, 0.05872113297560385, 0.033473180806530375, 0.0322267764381, 0.016705164053876485, 0.02403564757800528, 0.036848027392157486, 0.025368733098730445, 0.03289049903729132, 0.005009907331051571, 0.13887580297887325, 0.14218729814248426, 0.10736020587916885, 0.20523074668432983, 0.0965687238744327, 0.19366785857294286, 0.13660014580403054, 0.11940956967217581, 0.13171127385326795, 0.14544149780912058, 0.1425640479262386, 0.11199309370879616, 0.10422923495726925, 0.18696177484733717, 0.21916567108460835, 0.12042061399136271, 0.1581036669335195, 0.12384304963052273, 0.14649376991604054, 0.2317317325089659, 0.10414335956530911, 0.19515048473009042, 0.07620673613356692, 0.12366631839956556, 0.14059842697211675, 0.11862622813454696, 0.14642271372888768, 0.15206941430057797, 0.1353109156978982, 0.07569401471742562, 0.13498836729143346, 0.10414051650358097, 0.09489957522600889, 0.11749642661639623, 0.17666951141187123, 0.180446115189365, 0.15481121146253177, 0.11137464975139924, 0.151925727725029, 0.11280237564018794, 0.127616179308721, 0.10180064277457339, 0.19360677685056413, 0.1454656943678856, 0.09071877492325646, 0.1446459697825568, 0.193619289036308, 0.12483153944568974, 0.1136333571214761, 0.1389839750315462, 0.09979774989187717, 0.09210291850779738, 0.10274538065173797, 0.09192038580243077, 0.14223183718110832, 0.17949072431240762, 0.1689229892300708, 0.1760352575885398, 0.20516355814678328, 0.09727872934724603, 0.08103424137724297, 0.10067999469382422, 0.09283614344894886, 0.16276157913463457, 0.14777673035860062, 0.12263345239417893, 0.06060667322682483, 0.17967732144253595, 0.06447985967887299, 0.20499228233737604, 0.13343553990125656, 0.11294570259217705, 0.11001852966312851, 0.08752556876944644, 0.13970869114356382, 0.0971508254962308, 0.08734383673540183, 0.09263419785669871, 0.11826162412762642, 0.09920484599258218, 0.13046091023300374, 0.21671067710433686, 0.16405189489679678, 0.22617256295468124, 0.09175228553691081, 0.07424438571823494, 0.20150784216821194, 0.1089042258848037, 0.09351039012627942, 0.09582885607544865, 0.1096292066254786, 0.12032408559960978, 0.2078843071524586, 0.23555492450084003, 0.14082698470779828, 0.11809421596782547, 0.14904221173908028, 0.11743055443678584, 0.0924431291807975, 0.23161830859524862, 0.08298915504877057, 0.0819721667628203, 0.13362140421356472, 0.08826832712760993, 0.19678586269063608, 0.17955282383731433, 0.12138952128589153, 0.2353050879069737, 0.13314868243677275, 0.18298646887498243, 0.13083262528691972, 0.07247239830238478, 0.0778392506763339, 0.07924746189798627, 0.17703216123793805, 0.12281478409256254, 0.1946147677621671, 0.20465610894773686, 0.13516895260129655, 0.09341522558991398, 0.1269552047763552, 0.12340557096259934, 0.16895967083317892, 0.1288068454180445, 0.11633409612945148, 0.13666410451488836, 0.1418747649128948, 0.0954270547788058, 0.11637611101780619, 0.09585248266479798, 0.0737628090594496, 0.09438555102263178, 0.1217075235077313, 0.1039209154301456, 0.12493796087801456, 0.16444038333637373, 0.18293464237025805, 0.17413674374776228, 0.09463487192988396, 0.1435662034366812, 0.1234327530754464, 0.15247143272842678, 0.13379247646246636, 0.2148840744048357, 0.16773616362895283, 0.12485422965671335, 0.10868645685591868, 0.1497703476675919, 0.08499293002699103, 0.11240236567599432, 0.1477964757276433, 0.1554915513843298, 0.2579501356397356, 0.19958282474960598, 0.13321778444307192, 0.10737998517496244, 0.0775930103180664, 0.14485537926001207, 0.10331581147121531, 0.07542826647737197, 0.08239610865712166, 0.08700545132160187, 0.07858357645039048, 0.1031677144180451, 0.15634658693202905, 0.1125483660559569, 0.11915912239679269, 0.16119272474731716, 0.13592053870005266, 0.12679828676794255, 0.10721136922282831, 0.11724922273840223, 0.23187674901315145, 0.10898360769663538, 0.0950555025732943, 0.08171432345573391], [0.016245244536548853, 0.02147660025262407, 0.03391258990658181, 0.028032429183700254, 0.020400170602702668, 0.049241635748850446, 0.018790085034977113, 0.028600098365651708, 0.04320254855390106, 0.02029443788342178, 0.030970631699476923, 0.022757153592205474, 0.03863647946023515, 0.009463225957006216, 0.017540398253394023, 0.035486770793795586, 0.01197128476841109, 0.02626298288149493, 0.006294971656253827, 0.04452699802017637, 0.03708168092582907, 0.057829965438161574, 0.02759309302616332, 0.019009138191384927, 0.007771276835618275, 0.02946125769189426, 0.010562951410455363, 0.0057526826525905305, 0.08349565429879086, 0.020200681307220032, 0.013563365409416812, 0.045111352378236394, 0.019435650037069405, 0.11314877455255815, 0.024315960572234223, 0.028365932538041046, 0.03166695451363921, 0.10753125777201993, 0.01717101057459201, 0.03904416026281459, 0.046598514541983604, 0.06382760432149683, 0.053799535280891826, 0.0495793765543827, 0.019581258563058715, 0.03873228860486831, 0.033819437226546664, 0.03447004374382751, 0.08076126673924071, 0.03564892369987709, 0.032699922299278636, 0.1047619663711105, 0.02727970484245036, 0.03463060887796538, 0.058416599673884254, 0.0327942183108202, 0.02236895013733634, 0.0174785090743431, 0.04832327252786074, 0.04347581835463643, 0.009164228652870017, 0.02096958361965205, 0.04643333876239402, 0.040419323436383686, 0.053433876152017286, 0.03806403339175241, 0.040801803448370526, 0.048671930961843045, 0.014402575824143631, 0.042817351009164534, 0.0633051594985383, 0.051202713911022456, 0.03190087606864316, 0.03174960007891059, 0.017941605831895555, 0.028472309865589653, 0.026351458758914044, 0.051716032437980175, 0.02425332330832524, 0.027148678034011806, 0.0069887257912861446, 0.059168009353535514, 0.04407761445535081, 0.022727355726861527, 0.026687593132789646, 0.018439774368224398, 0.020703411295211742, 0.013077473267912865, 0.010392835047761244, 0.010965090278269989, 0.024067107854144912, 0.03780927402632577, 0.053403247081275494, 0.03439638876755323, 0.010184686797271882, 0.008090324001386762, 0.03184826585597225, 0.0677934583010418, 0.049087207963956256, 0.09104090263800961, 0.06687869810100112, 0.02891853145722832, 0.038123717331992726, 0.05334032652899623, 0.0296833863082741, 0.011919885740748473, 0.038455833082220385, 0.07800038238721234, 0.030829655871327435, 0.0510480689949223, 0.00864405692222395, 0.03313313298193472, 0.020718817432810153, 0.03485468828252383, 0.03497073473408818, 0.04416805638798645, 0.024309813044965267, 0.04319478611328772, 0.006273805604515863, 0.005369954127153116, 0.0733019005773323, 0.07633341183619839, 0.025386103595207845, 0.03484835076544966, 0.05658422264137438, 0.02909683688942875, 0.03703516735030072, 0.02799381545212652, 0.004821584601553955, 0.005793448188342154, 0.03374314274904983, 0.024003247530864816, 0.013997273286804557, 0.053842523866998296, 0.02502828324213624, 0.07423207709299666, 0.02740706586545067, 0.04533996439671942, 0.02904899338526385, 0.04934247623064688, 0.05108651818175401, 0.046846390169646056, 0.0194388408479946, 0.03188231474320803, 0.031433752205755026, 0.04905561876616307, 0.0581677198143942, 0.03863084422690528, 0.07072358964277164, 0.03224583648677383, 0.02426654625950115, 0.06994503856237445, 0.007056790911259928, 0.045679954545838494, 0.05154131645602839, 0.029029458362076963, 0.01798816181586257, 0.07891784315662724, 0.08152638961161886, 0.09397850465029478, 0.0275011820652123, 0.03193697413163526, 0.014853401275883828, 0.02856963892866458, 0.01782346609979868, 0.05206102678286178, 0.014689706398972442, 0.05240257756252374, 0.03095870983919927, 0.018576550064608455, 0.022301010122256618, 0.028280968079343438, 0.06885867685611759, 0.0710320652329496, 0.05655174456270678, 0.0034573367239707814, 0.025477166387385557, 0.012456345704517193, 0.02809122933207878, 0.04971625742369464, 0.05854610486754349, 0.05090406350791454, 0.017212436833818043, 0.06075515704495566, 0.059794962140066285, 0.016337560922173516, 0.06583002222967999, 0.03261839970946312, 0.011866150008115386, 0.041196829572852166, 0.017378399714029262, 0.05022742499464324, 0.018934597726911306, 0.03397514404995101, 0.047811236432088275, 0.022703013283067515, 0.021327906088637452, 0.04887069083218064, 0.007335205279689814, 0.013979573700843113, 0.03227120012577091, 0.038365245264555724, 0.025258591598165885, 0.024432860281584517, 0.03813384446714606, 0.022103542861129557, 0.05920186825096607, 0.022654667662988816, 0.052903811380799325, 0.052219023661954064, 0.038776362847004614, 0.034788677003234625, 0.02706590185074934, 0.05359503500429647, 0.026686554974211112, 0.057963616480784755, 0.06313620427889483, 0.05609216940190111, 0.06406363272773367, 0.033871365511523824, 0.01746880602357643, 0.014349344751930662, 0.01981251347543938, 0.07546437811106443, 0.021896460758788244, 0.07720926483826977, 0.0246266787206488, 0.018027281056025198, 0.12907034770718642, 0.04755886550992727, 0.008976983521798891, 0.07742942231042044, 0.010602904400522155, 0.0545768446422049, 0.02548083895817399, 0.013616243643420083, 0.024106235575995276, 0.027950221273515905, 0.031437755562365055, 0.05939014136259045, 0.039527236483991146, 0.012339067711894, 0.01189804115399186, 0.025916076764198284, 0.02135446055659226, 0.05442584685182997, 0.008900123315730264, 0.008075015403197279, 0.02526542783847877, 0.04728277978886451, 0.05805483194334166, 0.047291834838688374, 0.051141632188643725, 0.04151310492306948, 0.03661842471254723, 0.026464713038876653, 0.020046258611338477, 0.026056083983608654, 0.03683200039501701, 0.044978474865534475, 0.00909354820448373, 0.027206860715523362, 0.04169895227200218, 0.06816507836005517, 0.018634171258392077, 0.006753852590918541, 0.05847795281027045, 0.0523320608107107, 0.054469561470406394, 0.010462372164641107, 0.03984537780550974, 0.02168054073782904, 0.006788526154455862, 0.017555276830015436, 0.07399885782173701, 0.03675087135551231, 0.035836491135082076, 0.003692952708141612, 0.02832272512439106, 0.04115882482645767, 0.0916857687490327, 0.015366582399500268, 0.02605923917144537, 0.05632995182116117, 0.029770398246390477, 0.02480741330821599, 0.05001267544659121, 0.06139578909746238, 0.03757308616435953, 0.049933710933796, 0.03777402073943189, 0.004423133571565683, 0.07235535779701811, 0.025233283938307847, 0.017899485770612955, 0.024823932243244987, 0.02821625958729003, 0.04066779278218746, 0.03815678234345146, 0.02996441854962281, 0.028224590300981487, 0.00955673401975738, 0.046507204084524086, 0.04349652385073049, 0.02941377381128924, 0.053630169547562084, 0.0030819030861104174, 0.026780116471595, 0.032257184984960725, 0.013439200286354338, 0.06347806379199028, 0.011859161097423306, 0.040065484387534, 0.011901220938723003, 0.016120407663817917, 0.018119946887184466, 0.027167098563430563, 0.015323551404955131, 0.02161167621878641, 0.01835347998089024, 0.027354255484949266, 0.01840032434224018, 0.019553442019969225, 0.0243653969373554, 0.07473272737115622, 0.03434215346351266, 0.05688270680340273, 0.05355348151975444, 0.018135948439261744, 0.014632770525557654, 0.022163482948339412, 0.05030945648572274, 0.02031509588206453, 0.0144978760675128, 0.047695359614278586, 0.018441367229180675, 0.02874466364404985, 0.057142541610768864, 0.018166665719555955, 0.024667857314593027, 0.007794177392497659, 0.06609271027679954, 0.09015277493745089, 0.036822416087878604, 0.015248464719791497, 0.024526594805398157, 0.003281653829617426, 0.037194338094975264, 0.031355534081480334, 0.007924085466324218, 0.037750950548797846, 0.023274931790573255, 0.18513277013386997, 0.11230857178036656, 0.14778214506804943, 0.11545162062559809, 0.09854549315891095, 0.10796343708144766, 0.12497857798423086, 0.17267920981560433, 0.1345089144472565, 0.09197034633585385, 0.2512922686125551, 0.06723095955593245, 0.077498320756214, 0.12413173913955688, 0.09249433821865491, 0.10894897526928357, 0.07340469184730734, 0.12803639604576997, 0.06494572825197663, 0.11604588159493037, 0.10121574558849845, 0.1861313429794141, 0.10490169708750077, 0.07513024711183139, 0.10647339453654629, 0.10578291051621948, 0.13289930724671908, 0.10849145946225949, 0.2069194032145398, 0.1367604157754353, 0.09999102380658899, 0.14063635707965919, 0.18988706144903386, 0.1481220368295908, 0.08960696815380029, 0.10035252012312412, 0.07949066241937024, 0.2326508489038263, 0.08211847248354129, 0.12413532180445534, 0.08991782540189368, 0.11028635422033922, 0.17513351169015678, 0.10346209005053554, 0.061219207144209316, 0.06635501834430865, 0.15106382540294103, 0.11086994861917836, 0.11039065183805567, 0.17462930588849954, 0.12475266653512206, 0.15459831431508064, 0.2352729524884905, 0.14163354571376527, 0.11764740065804549, 0.174440008188997, 0.1085797640095864, 0.14609133079648018, 0.0944718878184046, 0.18064826434212072, 0.12798234394618443, 0.10781303979456425, 0.11926900435771261, 0.11714121353413377, 0.10240933618375234, 0.10475621239415236, 0.10732044372707605, 0.12366884254983493, 0.11793257535568305, 0.14163558131882123, 0.16413996874221734, 0.11737006982522351, 0.10027563532016107, 0.16792527133865015, 0.09973671566694975, 0.13751240899520262, 0.14051561855844089, 0.0863400391702141, 0.08950185629406146, 0.1433340630361012, 0.04875314821090017, 0.1399190912821463, 0.20347669294902257, 0.11988406921071665, 0.1921200794833047, 0.1257794392960412, 0.09389442059078387, 0.13845634620104516, 0.05787782251302685, 0.10558166381503854, 0.09806184696831874, 0.15381855544235024, 0.10438577977142163, 0.08111236789929015, 0.16953212368701184, 0.16316909369613442, 0.23814448554600987, 0.1270677194531475, 0.21048534901014396, 0.1781148181429931, 0.22877782530018262, 0.08798075720135655, 0.0927687513508967, 0.10903185153646128, 0.15189618431031704, 0.09964117115097386, 0.07982077649129288, 0.16541209976587976, 0.09234049397387675, 0.14509446785918304, 0.1683969074594123, 0.16415070316621236, 0.1400811525860003, 0.10868220244135175, 0.1614318269171885, 0.08101425852094378, 0.1670953415866409, 0.10044037005198853, 0.1005955645814538, 0.07523875843201365, 0.28833094398890224, 0.15192880827401364, 0.07166850393904106, 0.1235319548951728, 0.14037592176880154, 0.13749545919043676, 0.10139010194689035, 0.10929051587092024, 0.1613078857106822, 0.1448360410119806, 0.0995870851246374, 0.10462876316159964, 0.14879241585731506, 0.10044323346976723, 0.13151257165840693, 0.11763619125953742, 0.08619372666414295, 0.0899855431967548, 0.10187967174819537, 0.09085022072706904, 0.16696464217134885, 0.16203520739717142, 0.15933140819626196, 0.10138357444001095, 0.15167561971715518, 0.1165698870484318, 0.21106358298233577, 0.12045578924672944, 0.12329324627561228, 0.1795438536043678, 0.18152444304100104, 0.17047163684453281, 0.11059932849769082, 0.10307991198663201, 0.12352352749024119, 0.13017353708190577, 0.08467384214912142, 0.11943118779786996, 0.16819344194872038, 0.12132670251386506, 0.14286618599934237, 0.20436993001827172, 0.10468411126307078, 0.10881591455212661, 0.08998944477311202, 0.1301662360451051, 0.1471509446523019, 0.18704937371824468, 0.14515711021210465, 0.1874447696443115, 0.1289179894540991, 0.0793127166107297, 0.15032547073704855, 0.09653319578085627, 0.25655884029609816, 0.09529131384832518], [0.03280534289245095, 0.02071732804844422, 0.021136186019118344, 0.00893972346758736, 0.007619811704249254, 0.03244620787778071, 0.032378635967948606, 0.02349325891451112, 0.015753130228923898, 0.03143445448949933, 0.04895646444388798, 0.026079262739845684, 0.020575872156769037, 0.02270819729060999, 0.029155346964086806, 0.039281939289399555, 0.03504383670432227, 0.007994662438120161, 0.09949755921427693, 0.026062051699097668, 0.03343938636992659, 0.10167552091713462, 0.04032301896118692, 0.07601548425321068, 0.022189798232700144, 0.02158827524233077, 0.028999741920935254, 0.06873711052217654, 0.01499750345413174, 0.058116008660623004, 0.016846307819443088, 0.04971545335969754, 0.04955828429332801, 0.01481055687846882, 0.022505493435476507, 0.008376754836977592, 0.03129427933267184, 0.010541943966278007, 0.057020547799766064, 0.04015852850196617, 0.05017248062150819, 0.018922925228253007, 0.02650444465689361, 0.026034343721611158, 0.0038610902930875973, 0.095072520231562, 0.026407607531707202, 0.06080701747643096, 0.029371311089822223, 0.01748839532956481, 0.03782802873424121, 0.05560237229136484, 0.02596492280385324, 0.03383942347552095, 0.04065433743276766, 0.059051070628421645, 0.06822725930916411, 0.058035025506147316, 0.0238377613215042, 0.048346831263708215, 0.035939265441681655, 0.03216312985335078, 0.04270902628611241, 0.028363644178690653, 0.03971171997753637, 0.029225541411765983, 0.06065572452332292, 0.022803706183497394, 0.03931595764255949, 0.014875915067802583, 0.041163004602172544, 0.07212072717291967, 0.032420203023191006, 0.04342427004926971, 0.018739639349015694, 0.02404793754353055, 0.021775676436456184, 0.0813758634030819, 0.027227812180561677, 0.04099348619846361, 0.03070905984246305, 0.03662339498155883, 0.02558611536265484, 0.06354341349963631, 0.09273367787578277, 0.026921280593212162, 0.0618089015728661, 0.01936799331035997, 0.034002621325531175, 0.022816481301560998, 0.041808440682611296, 0.06673546614391462, 0.06612819087292467, 0.07945395367486136, 0.01413113806795861, 0.009523208452654737, 0.03556720772758126, 0.023745214233973196, 0.02797917097008654, 0.029853871624384607, 0.0658769089994686, 0.0751443470695189, 0.011484050823907768, 0.018705037455739718, 0.05929556715169123, 0.06742093579045363, 0.05889075994491577, 0.021178426520366753, 0.028938358250473226, 0.029516012075224092, 0.0206937930613224, 0.06450700786496912, 0.03582656416775925, 0.018034680480403558, 0.0460261498977031, 0.02276711618261678, 0.04996757322390165, 0.03732310029278908, 0.06620349468929426, 0.03153021613668118, 0.05165757664612361, 0.022364083344915082, 0.07669925077685288, 0.05321364064833947, 0.026774884966601218, 0.02179004780815116, 0.027160082511337738, 0.014210470686001437, 0.008474535974008697, 0.01995604738060917, 0.07525952838893447, 0.0364120041818491, 0.01731943671724626, 0.033490442737404785, 0.034256987140647004, 0.033246332979095836, 0.008411942814875926, 0.06271832170231001, 0.017360774766919867, 0.02247787536387997, 0.018552166908713322, 0.004796475837273257, 0.014329597686550446, 0.013743849787195879, 0.04215779461498771, 0.055586070487541814, 0.022892919967749288, 0.020736990296947103, 0.03187134283195649, 0.06448251953614609, 0.011136922486392515, 0.019695907232484648, 0.028000018958534514, 0.038763158555541716, 0.017966146747182523, 0.025421036274305413, 0.019271023870844926, 0.04889026656746864, 0.020963431003370454, 0.04475342854857445, 0.015692779628027762, 0.03975871192025287, 0.040139627909021716, 0.027023342438042164, 0.016407672249312912, 0.048132648292396746, 0.10035313758999109, 0.002469995753407212, 0.060845130788428445, 0.01821506053342351, 0.042801788808511834, 0.05518192485240953, 0.0511578627462898, 0.05073263502812811, 0.035371287526296716, 0.038927767758390734, 0.035166665113398006, 0.02217778646653252, 0.03603892187987055, 0.017445885110646486, 0.03679678103487406, 0.04050078156537243, 0.04098235143880759, 0.02885034547320434, 0.011212929434675192, 0.04737838876566716, 0.06002477516553231, 0.056416051129677465, 0.008561565723669316, 0.020473923966554657, 0.015747194743848274, 0.04824733088857361, 0.019814506672056656, 0.021040651681167737, 0.042180735883968215, 0.034898918587714434, 0.012808027012007577, 0.024885694196979915, 0.028242464609710232, 0.0032070124330597794, 0.04450026713311672, 0.025014770217239857, 0.055344237214220424, 0.03512828038739307, 0.01603703945875168, 0.021664778369345834, 0.00861308688763529, 0.02726289753003844, 0.003469574315074299, 0.006310458793970091, 0.05695467562015567, 0.026674611061545353, 0.016937572475788847, 0.0418939835924123, 0.02318027106645916, 0.054699628946504424, 0.016260886465066245, 0.01565607766886907, 0.04530296048947743, 0.0343723075597414, 0.02859470061957836, 0.03693715635953205, 0.0803453383435096, 0.00876528229231813, 0.051760598618005, 0.041748855129948685, 0.022695021836885383, 0.015560563686969025, 0.07184224283056599, 0.07733637480331318, 0.046140014859182496, 0.0755128390820963, 0.010952349086957318, 0.026767134400350705, 0.04771380898143564, 0.09638611653021403, 0.014088213094510138, 0.04638580059898751, 0.04187232136194195, 0.01499500305258802, 0.03964732021891645, 0.057141584876392565, 0.00531512764947755, 0.05399939437795963, 0.040576702848609, 0.03951951475547893, 0.08801234979182482, 0.02475047913113875, 0.03708213893696666, 0.039426789552505524, 0.054245970611061366, 0.06372964422085456, 0.04965382202395371, 0.055630110802927187, 0.038561358848320584, 0.033539236190595796, 0.04363610189674156, 0.035689374565013816, 0.04088361780824406, 0.06139644727643047, 0.06430738286248275, 0.032553253562322686, 0.04557152125718338, 0.034687748311885765, 0.054671266182724915, 0.014575242630339094, 0.03829929505341819, 0.024208137965095893, 0.0036135831947571462, 0.08067457710525819, 0.02992102623518024, 0.008422999543004801, 0.010202963137999177, 0.006869163680156427, 0.022176639742351005, 0.02054469007998705, 0.040750652085989714, 0.043898576205330234, 0.02775352245329746, 0.0716850059106946, 0.06775709560939244, 0.022955038152369003, 0.02338416575055037, 0.024679417854973247, 0.027767006640455554, 0.05027424730360508, 0.032600187829562595, 0.06216338862265859, 0.009279317521889294, 0.04000437891642962, 0.047206288536212275, 0.0399405321638499, 0.023804686132020185, 0.04341854660638741, 0.04681828864184873, 0.05104180272402508, 0.030193546254720007, 0.001975435751124418, 0.028438771575955406, 0.06804547299231802, 0.05935494575117316, 0.08147523485656295, 0.029873518605849574, 0.037547858232366185, 0.03129837429150939, 0.051617047749459743, 0.056457170351807556, 0.05940594444317477, 0.031069721560925245, 0.039178320206701756, 0.045554948039352894, 0.05489186130996261, 0.040810797430042706, 0.03407285987798657, 0.03345853802082794, 0.039981213730892966, 0.0441694405994245, 0.030776865846876587, 0.053081543450909, 0.026083902223035693, 0.0019341888795939407, 0.041885383161050935, 0.021994938242382238, 0.01725786136064146, 0.04594195727258921, 0.04438248363190463, 0.043795031761484485, 0.012977720986652588, 0.028173818918211118, 0.026570018281095793, 0.032542773588959656, 0.005729528917332313, 0.0379839153694255, 0.037697743225310526, 0.04685657498027597, 0.06797717844269105, 0.018727775164214627, 0.06181114073842764, 0.053470072602587085, 0.04075846202405436, 0.04160294974488871, 0.022879350963713865, 0.036990574028875144, 0.028369136919666613, 0.05478724817346249, 0.049747632882956944, 0.040031028379287036, 0.06380232210670199, 0.025834713630112152, 0.04175392717921308, 0.034588807728141546, 0.016777568829378912, 0.14096356023635181, 0.11132312180208308, 0.12890319739069256, 0.10001175983675889, 0.07727896395538535, 0.11200185359588691, 0.09198469735149827, 0.1169356174234833, 0.09527637929256473, 0.15835324568407877, 0.16895539606256144, 0.14437992977244513, 0.1561983541718551, 0.07440834013479096, 0.12022757077855722, 0.14528417267969676, 0.11480870869542871, 0.13565376587212086, 0.19454025104641914, 0.11477634257503919, 0.14528394197779043, 0.22900589449065073, 0.12619658905480588, 0.24043462265815052, 0.19398413731583528, 0.07559840913329806, 0.09856441071523087, 0.16032044083944388, 0.0955147079325148, 0.10161572162594114, 0.09961326979100704, 0.11224038579634257, 0.09633142660771098, 0.10159288213721343, 0.12761746852525643, 0.11564813793769904, 0.06634062661656312, 0.1598446113722665, 0.09210218568997723, 0.11163556003676993, 0.17074318655899592, 0.0975115889949458, 0.08326341890330825, 0.13916639238595963, 0.1686020285955497, 0.14197938144207, 0.11687347718647548, 0.11394874698349408, 0.11518073587545327, 0.14908399592552865, 0.22041251989347593, 0.14661195714558872, 0.1653663936470236, 0.17333083413541317, 0.12656826339662075, 0.1305766547364848, 0.10171033654894147, 0.12707605186317647, 0.08009466715157032, 0.10432049791727747, 0.11446645563202244, 0.13579359836876392, 0.0847918801009655, 0.11471087751643998, 0.11666465124913625, 0.11938071836318288, 0.10413977690041065, 0.19565766251512937, 0.09228987526148558, 0.0798183134091752, 0.1839112171104976, 0.14771475296999725, 0.08660513601664986, 0.13358906523457595, 0.13110015807407244, 0.17617819777556828, 0.10741139456097569, 0.12649620297764028, 0.07627069484442472, 0.14016516879200935, 0.16469043706144604, 0.12243188678153924, 0.10956575681588479, 0.21513786007251057, 0.1536029577255249, 0.1061337674036622, 0.16942313739231654, 0.17728741254125321, 0.10717003965484244, 0.10080672467925719, 0.0927180512143033, 0.1386834518717868, 0.085914869127529, 0.1938827099012477, 0.10785188592438187, 0.05672573111951351, 0.11452447037611689, 0.10925274861178227, 0.06249037464814527, 0.184781139716506, 0.1513708760695798, 0.17334740396056855, 0.11437988813434329, 0.1498294887798173, 0.10281244026763098, 0.12430302851966449, 0.12476507015526295, 0.11101359448262624, 0.10789236053824425, 0.08766627657626357, 0.09073910383241517, 0.22641228937676974, 0.051011858973652124, 0.049299104272254875, 0.1414040108876569, 0.12764555987502846, 0.10877532458731107, 0.13576471991837025, 0.14931901331458772, 0.22287207362907274, 0.11028870195150375, 0.07584808287875992, 0.16565378036882195, 0.24562023154326848, 0.12049891693251473, 0.11706300558788435, 0.12311498155551297, 0.08366376134966101, 0.10408813360014132, 0.1256255746952125, 0.17330125000860008, 0.12505157478153706, 0.17422396263905934, 0.12336162903479167, 0.08527005051395722, 0.19623623575483048, 0.12540446727403573, 0.1048922925921423, 0.12803794310561248, 0.0826708474861724, 0.11079720966517925, 0.1747080430920635, 0.13747035339474678, 0.0837504645543439, 0.1539268767727273, 0.09302721891020026, 0.10932572505303792, 0.06728189717978239, 0.1114785877455558, 0.11347188614308834, 0.11371410957404546, 0.11079159818057503, 0.1201936983104263, 0.1660431373332228, 0.07010715414902993, 0.08831404681716647, 0.18909834591405733, 0.17187937987702234, 0.14677833393216133, 0.21882967411407403, 0.101444595094238, 0.1287678296544722, 0.17795614951423236, 0.19192497352404253, 0.14318141979830606, 0.11115314199456147, 0.14903098876987184, 0.15613286197185516, 0.10892163709338222, 0.11424165698034422, 0.11414641780512673, 0.14654551499656268, 0.12615584981228622, 0.11440856302423136, 0.10182219304676567, 0.09771426740501608], [0.05270939413458109, 0.025207977974787354, 0.00567002860563142, 0.02052107366866299, 0.04491109633818269, 0.0665920034849218, 0.04114729990916593, 0.04485271857785327, 0.08192413326885019, 0.01141562735262726, 0.0669193219925676, 0.019721179269254208, 0.05953008921018668, 0.025563969675983702, 0.02608513376409454, 0.0627719463248338, 0.038345625424491506, 0.017434640089049935, 0.04029349929520062, 0.03851728121350918, 0.04353674401396087, 0.06281236665589468, 0.017544476248856102, 0.045800360584897656, 0.019427097103159343, 0.08509217255881854, 0.03954423717888338, 0.029150471689977815, 0.02728812376569424, 0.02041215862014464, 0.09243090197976146, 0.04285128454544714, 0.010274933651089668, 0.034149497015667815, 0.005975790055734771, 0.026464065037933842, 0.06493757226105247, 0.07932224324239151, 0.011326535704678722, 0.02465392868699772, 0.02116226381622255, 0.005420521525333503, 0.011344329437374004, 0.022099919484129975, 0.031572546543819566, 0.03214463298874242, 0.04822793835774064, 0.04052075085097125, 0.06221834317381893, 0.07693106548062392, 0.032748837888772996, 0.0683579451537558, 0.01135797901744289, 0.03909728955477476, 0.042124373372644186, 0.03216474137402006, 0.0242884341028652, 0.005570847566039967, 0.0038048554311639494, 0.008855269606491285, 0.058163580750780444, 0.010198785058621849, 0.03643555613234639, 0.04400448873639107, 0.07851187565496989, 0.02924518839323095, 0.015243105989481722, 0.021364294225350022, 0.035958406914557726, 0.005278335784428886, 0.027582462078758647, 0.042932030212666304, 0.026834908174350858, 0.07512173828269754, 0.011436429539961475, 0.0459310667855399, 0.04624163904892547, 0.02173337317071855, 0.07069355768284627, 0.04940892177234803, 0.01132454929341163, 0.053643645253032446, 0.07041698002389499, 0.00903896939208997, 0.035224357553358586, 0.03257330087944865, 0.04227916417377336, 0.054149645779814036, 0.04383411877123373, 0.06810263278228895, 0.07304932948734079, 0.04596106142603925, 0.028988939643438374, 0.04885971892092909, 0.05418630702687161, 0.05745679831930569, 0.026017590692000728, 0.031623124544109614, 0.053305633033492734, 0.03247942216694355, 0.010859886816303645, 0.03504641853006823, 0.06449607666581869, 0.031214945018291473, 0.04828711000404187, 0.0717825521049755, 0.024756326406661953, 0.016796935915148685, 0.005451857120663459, 0.037094780044364076, 0.02176073848802064, 0.023245347663760185, 0.034079082044107575, 0.06705162275050368, 0.08843597956001759, 0.03892222073461328, 0.025881008378096988, 0.02938898353438292, 0.0022812351567803747, 0.05176834070256778, 0.003076234774198383, 0.0266179601728384, 0.03019155136176518, 0.022854131513408253, 0.0780245993020279, 0.01979609123165054, 0.048430599804435454, 0.04806260990777186, 0.04357669615585889, 0.015898592869884202, 0.07348361904067652, 0.00834190527841981, 0.016382298432290554, 0.052547098736145666, 0.034552248261336765, 0.032849596946367195, 0.054871308484247754, 0.011698455167269068, 0.011015518152687167, 0.044009628639157326, 0.052700803881245, 0.0429816345152046, 0.04832733355994735, 0.0471917644941381, 0.018550528246643286, 0.03419290290081075, 0.04403150460815855, 0.016913340293935368, 0.02130861533805728, 0.04582674881177289, 0.02275688387453556, 0.07110161507236105, 0.0719182455380048, 0.021340299530753067, 0.031601557308541875, 0.030020974443427155, 0.0033155812166764265, 0.012911560429659272, 0.04025408658864243, 0.05117393384820648, 0.045018881625894985, 0.06583079575960125, 0.01675794050762696, 0.059601050402436934, 0.019372458070782677, 0.061621551268867085, 0.03462603555193969, 0.034568149729498794, 0.01083501087435122, 0.04068181810102292, 0.03597235420186605, 0.01701319350727967, 0.037783160606133084, 0.01683332405186125, 0.060586100045059404, 0.007372802905073124, 0.02038990267153297, 0.08229116643113749, 0.0192843655656491, 0.039226153532841375, 0.014113034753661071, 0.037487451652331014, 0.005215419897077871, 0.013924578437581658, 0.03790065912263734, 0.05185786661292825, 0.012287069028908653, 0.019602164226983274, 0.04400808157931481, 0.04910178628883191, 0.029790849291852543, 0.03811276577679174, 0.014012864325195551, 0.03675017246444311, 0.0406091368225004, 0.03220800815948418, 0.044238084594586065, 0.025730120849662592, 0.045344262916062555, 0.05684517703152128, 0.05687974839072142, 0.018173216975161006, 0.037627813406288624, 0.05097789829596877, 0.07742731206651245, 0.026125815331137607, 0.06249265452580793, 0.05413884010964206, 0.010278473907549466, 0.01786672101089997, 0.012601828701528055, 0.018006243077772002, 0.03368755716032215, 0.06272255576082639, 0.016433068118723373, 0.03254125367051788, 0.043790112382599285, 0.038513281249574254, 0.03540462734443801, 0.05514980639730181, 0.006094716464368892, 0.05545263996879969, 0.016992221686190793, 0.07293880970350333, 0.02072565028044794, 0.04312392330861517, 0.05838336502867086, 0.015565608594832676, 0.022907398208709698, 0.03883506291146789, 0.027637460734695196, 0.03914173020582114, 0.06809405609965324, 0.002294730158090325, 0.018619840598798225, 0.023458646843209863, 0.012491129105910659, 0.05273739727480071, 0.04522111559552806, 0.0294343775271305, 0.06111389172396489, 0.010205356670277459, 0.0480943653466446, 0.019214269505547624, 0.050551764733557186, 0.05601663488362517, 0.04095135256648064, 0.031047241695757424, 0.05156423058360815, 0.09585363617432968, 0.04269407815965159, 0.0574473056143948, 0.05461420138765659, 0.05258743764300432, 0.10313557899956192, 0.028583348728716373, 0.02210230453472052, 0.018446987195472633, 0.037777759467384646, 0.039543768989720514, 0.0715343439951539, 0.06443116122058459, 0.05518287819411073, 0.05183731717988849, 0.04881188559478947, 0.03419009715850864, 0.051572993863373995, 0.013184653811289795, 0.0028346992081164247, 0.06727433829967465, 0.035400861475084505, 0.0916091553600771, 0.0492382973565587, 0.03476301820150443, 0.045093863138130734, 0.019473130615161996, 0.01680779247544706, 0.02793896777023162, 0.07680189276912383, 0.04375437055049198, 0.02215084692995463, 0.03310983208939433, 0.015611650588523065, 0.05288352318374174, 0.0403149952845914, 0.03362417520423021, 0.019673201754423122, 0.03962589208302753, 0.05885886201368911, 0.04576156873788152, 0.03488125292850392, 0.12142381444573402, 0.014092598975236927, 0.03159821213089994, 0.022340485593304038, 0.03320489145283188, 0.07430534530431032, 0.05926991852798632, 0.02039155999331602, 0.025812564550765922, 0.016604562755674124, 0.024367230678243295, 0.024263345270550678, 0.054417460158999474, 0.03360867067905409, 0.05086397905168789, 0.057515681588224, 0.0014241172487215537, 0.007430620025843382, 0.006297849068817283, 0.02901047295225518, 0.019239195489457676, 0.01087725646461227, 0.068063447384962, 0.0513842763113124, 0.031574039320860586, 0.02684608703878309, 0.024000105913728476, 0.06856229954532214, 0.057999687402376106, 0.004254639755734908, 0.0409622634095805, 0.033936830570123026, 0.03291466845465558, 0.008214252485361482, 0.0222469257922577, 0.013037261586370212, 0.023794701489220773, 0.05476633572418775, 0.016943372253860747, 0.02244773314201406, 0.10079898259469441, 0.025779742115576352, 0.0388835544165756, 0.03783912278179612, 0.048017724816288264, 0.06001801695674658, 0.049758808354714086, 0.045465208390461545, 0.06705243699252605, 0.08746867360813276, 0.028382848416055952, 0.030842676958335296, 0.060380483578358374, 0.003878853067622653, 0.03692647621833852, 0.01111904054414481, 0.02887667602460299, 0.03321590407618454, 0.02021994661273701, 0.040147353030209026, 0.06310849969408341, 0.12027597746678761, 0.20909751419510159, 0.1372772151870387, 0.12492555725787367, 0.12265433770205293, 0.11303784764770951, 0.07262341305613518, 0.1111974503312792, 0.18219248790826115, 0.10188296942838601, 0.13427695046578134, 0.07913907271410738, 0.1315810222710882, 0.15660677797027997, 0.1707684552030904, 0.10786285783563342, 0.15764351162527288, 0.0994637885263988, 0.13756027285541805, 0.061686351363148005, 0.08538050244429282, 0.13065851320113453, 0.08273557972695146, 0.18889241053589753, 0.08122293518057891, 0.1270602284265416, 0.07861214956002575, 0.09649696879621063, 0.1056212427626763, 0.12459946689861161, 0.11975038424134254, 0.14408049226871558, 0.10994681529700756, 0.06946877483278513, 0.09062652808747121, 0.11268957597868783, 0.10067169621054615, 0.1350960372281926, 0.07282743496554238, 0.09557021888239042, 0.13336788995989732, 0.08174860304487602, 0.15596496526684078, 0.20117253730339663, 0.14243936033121177, 0.21786873282066413, 0.13688036719603197, 0.12316093194697585, 0.130928475143654, 0.11981565931013652, 0.14128047680216177, 0.1462537177971431, 0.10763791669160128, 0.10593786755842821, 0.1306830354567085, 0.1288554420960801, 0.1823037676513195, 0.12912012503615447, 0.057366973853537014, 0.10972013031797749, 0.11135301126965455, 0.12227845644312245, 0.10386796934264046, 0.11390963622501918, 0.16994191812617437, 0.23690569773316383, 0.1394053181367261, 0.16593332322580473, 0.14687668079776423, 0.09457132034003735, 0.1279432467584099, 0.14067313367766993, 0.11049241852015257, 0.1724692303687334, 0.10723616967775992, 0.19535940566233226, 0.11606724187731743, 0.14987701337252343, 0.16624806847955498, 0.11704111604818276, 0.16592946914689882, 0.08841278044772999, 0.17736673328493321, 0.1674593077706439, 0.11127899666982037, 0.2501312137714454, 0.13768778315612248, 0.15832396011267388, 0.16546455052282127, 0.18001113353031023, 0.18203418568841048, 0.15856307585324558, 0.13616937106209143, 0.10533365248037235, 0.14272594638168812, 0.20090208681566374, 0.11949506508452551, 0.16068839680935654, 0.09027615295989172, 0.14753521260406288, 0.0640986654907465, 0.1188402787915298, 0.20087216342134134, 0.19016093175326074, 0.11868000882012503, 0.1316952739975282, 0.07038899723972593, 0.12130412086844444, 0.10458895351205554, 0.07672361696937255, 0.10644426502819572, 0.11066839657723904, 0.10133767833134957, 0.1855762063392571, 0.18494404240378312, 0.18887155236942427, 0.07526581162320715, 0.08105021409158196, 0.061477165802248886, 0.12418112291821412, 0.11502474067466599, 0.09098726444478546, 0.11055151213492666, 0.11942487742219653, 0.20625708518283709, 0.07860905544034072, 0.09447226779801504, 0.20353332348167896, 0.14137093909084797, 0.09254143533429929, 0.1852731318878276, 0.04539805377966591, 0.13410179343606743, 0.09259814050580774, 0.0813684266592775, 0.07800098628337894, 0.1752372868359089, 0.1767324658909014, 0.1084292513717498, 0.10494243633002043, 0.11641575103359562, 0.12615925605807984, 0.11705090052315167, 0.16160830030483858, 0.11174764045115028, 0.18006620343242372, 0.11862747663898127, 0.09789256605186633, 0.09448558744043112, 0.06216656416654587, 0.13622849860361644, 0.1423777900636196, 0.11203613318502903, 0.19450534720505985, 0.0680405129013317, 0.18262023638401712, 0.10746164007910661, 0.16257723474076816, 0.11973055744809763, 0.15176659769245557, 0.1285142611180033, 0.18832461243229254, 0.10891211046172039, 0.1710472381008523, 0.11242733576468059, 0.17825497633644513, 0.16444302962294646, 0.08616929261812142, 0.12371009747896876, 0.12885240225919656, 0.06768261960574559, 0.11748756494905267, 0.14378459671778338, 0.1471412551722356, 0.10288139299622603, 0.16489198910338537], [0.009139234815458102, 0.04383234779483505, 0.04566073504143527, 0.047376020678452084, 0.058613910871957026, 0.03848029087696757, 0.021911176487005184, 0.02138461295648345, 0.02487766373503421, 0.01902384713425168, 0.005488604032767138, 0.044605857360043695, 0.044423066811369996, 0.02484382688999176, 0.07695752834635121, 0.007842400876273001, 0.015542307702292289, 0.03590010379308036, 0.024352095954652344, 0.057833880585219176, 0.09579658494996172, 0.02943202301061579, 0.0247676223183849, 0.01615919272548386, 0.04995749358619962, 0.02954595921827214, 0.029968873132020235, 0.05465159884520939, 0.040482780031327686, 0.030033198251788105, 0.0435320112322058, 0.020907782650153552, 0.03677206539681979, 0.022473364802343503, 0.020586145176951374, 0.06453160475939512, 0.04685696853058679, 0.020228056802547405, 0.09547316801867314, 0.015212997694366744, 0.04166997204135571, 0.0560005027135568, 0.019625938397699168, 0.0627883125894836, 0.04010408963742001, 0.05426654379282679, 0.02700793121143111, 0.02803836466877588, 0.0270282194084887, 0.024230556762112037, 0.06881719122507743, 0.05770218372344971, 0.028560346391584192, 0.02423716738953122, 0.09153960552066565, 0.038540785666555166, 0.04070108849555254, 0.06691344587930612, 0.023984603084889904, 0.046006682728018077, 0.03347964045990791, 0.03007807655792151, 0.005489751605117428, 0.07452232044722353, 0.007648116792552173, 0.014326071000791021, 0.03944328813148396, 0.03821207955479622, 0.014340859671522464, 0.011013824359646865, 0.031504204496741295, 0.046389196666755846, 0.0352797260108803, 0.05617151728698185, 0.021583880031747476, 0.027883860548692088, 0.01983192127331027, 0.025345849505226527, 0.05085943625973804, 0.11351219790854625, 0.009526009954112982, 0.05300085885184152, 0.023811301848452007, 0.003648052773704486, 0.038055378677589555, 0.07167670064206634, 0.02348500453600926, 0.06968298155282225, 0.016773526457005312, 0.03476787990491305, 0.019730020580547195, 0.01201260500654046, 0.02922827930056623, 0.026349857416270033, 0.025060530618897507, 0.005088708147273532, 0.015517066199598568, 0.0492399529820042, 0.06891767547598907, 0.027797357511839697, 0.024513935038287724, 0.07577743381261826, 0.049215966769094975, 0.002296329804396789, 0.050577260686882904, 0.04782555691365685, 0.011026371320310448, 0.016426447313278913, 0.05607658005984766, 0.04606663468959076, 0.007374253273675484, 0.013775324482204658, 0.05091092688962817, 0.020322647976822088, 0.005216405893276844, 0.024802103771695068, 0.014387101833043354, 0.03815210723717298, 0.028857470090900148, 0.037984607475144525, 0.03844177722930908, 0.0535474764848394, 0.04356998544452446, 0.02059880324772426, 0.01696995895222894, 0.07086412103048392, 0.032016681640275886, 0.0866162572056055, 0.012476444759938334, 0.026846210871423994, 0.03611020876892975, 0.09913986947919641, 0.03671715155776058, 0.07473939058503934, 0.06254784656422478, 0.002581157813048256, 0.02106910604717476, 0.03505768560405288, 0.03720714544345226, 0.023864497297576497, 0.022821809497794936, 0.02266127659407045, 0.07494129546518837, 0.06574215194476501, 0.017543536477855275, 0.05640310128884656, 0.016437380208766887, 0.05287166239161577, 0.17477964210723126, 0.03971208638644644, 0.03798914008906909, 0.033816183651132245, 0.028412641192387258, 0.03935199463739991, 0.07170295316193785, 0.018601202938173498, 0.031373790066157065, 0.01879047179993774, 0.04678857220070703, 0.07862239543880735, 0.018491670422788178, 0.03322263853624463, 0.008763244142755866, 0.052142247424593995, 0.029246158698307614, 0.05126125791243144, 0.016072223195806146, 0.03848555291603718, 0.05249272772510137, 0.04671075101941824, 0.04533864464610815, 0.010713726132442909, 0.05406690521964005, 0.03357284403006945, 0.017220452028725828, 0.02917403381850038, 0.03936538891866803, 0.0770302808710507, 0.042870541369276385, 0.040262632737202306, 0.011510238882952502, 0.011796058188857777, 0.034882667674017806, 0.05827725572245462, 0.021457017731985877, 0.018459019317690815, 0.016696173464879394, 0.014122497772664895, 0.01527440341721688, 0.06950886268168688, 0.03128572300608669, 0.0385248027741909, 0.010039503203837999, 0.009904881856138152, 0.03135274190987859, 0.02434105279722384, 0.06947945497397866, 0.02319057970972998, 0.008439654185037528, 0.02628967644912856, 0.035212120174297264, 0.022733080866081373, 0.05584323525960956, 0.033234841988555024, 0.058506383427551815, 0.029843798772032772, 0.03787466444607292, 0.029311403233025755, 0.04314879161704864, 0.023607486892225485, 0.013625544662188207, 0.006647633446846157, 0.024210085360599414, 0.01236835922048028, 0.030032540072820017, 0.01326865390209215, 0.05203087607930813, 0.07380810805729457, 0.0397022679847266, 0.05337081989273429, 0.032264872786722014, 0.04554707703313657, 0.006783706011317138, 0.02866158720904163, 0.04288870235905051, 0.015086763039497393, 0.0783125695639423, 0.05380579476643886, 0.03906170378572174, 0.04480429831892252, 0.051356904208660126, 0.02834917781209307, 0.01701770067614104, 0.029366920968251567, 0.03836142171972564, 0.012442108343488403, 0.020514374831691384, 0.06351334761296, 0.020059720746108463, 0.03423920273780823, 0.01966897108858185, 0.02780825987325183, 0.022698059977431382, 0.054728439543396235, 0.03179891261139086, 0.03324008367157408, 0.07603707523750407, 0.04248470260894724, 0.07978051222328629, 0.03175041092825787, 0.006771207396273634, 0.06096256484410592, 0.07344305621726172, 0.026183794452143565, 0.1025931920324053, 0.06744735115872962, 0.06675029891942229, 0.03569052807454552, 0.02542679534027619, 0.03417054856462138, 0.047662023188812394, 0.014067870614651059, 0.0072187254138823065, 0.05911889020353556, 0.028518243293677057, 0.0944649124784129, 0.01639773340762726, 0.016466618282720447, 0.03944002777071936, 0.016843137364568453, 0.02267581590318254, 0.0864883465692401, 0.005870602708975119, 0.018665755367172614, 0.04796340808804546, 0.011858368059620261, 0.06591702398977109, 0.02975358414862837, 0.03666231235755341, 0.03281834362340825, 0.018373030271115046, 0.058129572575645785, 0.045931589257504256, 0.025560539681464434, 0.035202786925115755, 0.04066165204026869, 0.04537697848198669, 0.06935669441840478, 0.05207384091668895, 0.033583344359483035, 0.03757994615339807, 0.04300187521481088, 0.02338966866955161, 0.027078059501945972, 0.027171025584850992, 0.021635514850329076, 0.043898711912333965, 0.041367219894060066, 0.038396074503128014, 0.005597013996780983, 0.004951217020529189, 0.047075619654996056, 0.04836343501561454, 0.03547287439661367, 0.015311626152002385, 0.02608636869782848, 0.03183866797813347, 0.09850603634757654, 0.023378447396680713, 0.009549801936373115, 0.023604550531932285, 0.03494641603901982, 0.02509000787644514, 0.061085691808589866, 0.01848333970909672, 0.051047461706080606, 0.05756852589547634, 0.06165124396128314, 0.010176688565739563, 0.03225428085508091, 0.04315084757815514, 0.06799916976264544, 0.04559241674308266, 0.0333082492995475, 0.09363057903413262, 0.029559360284890448, 0.032211465295404196, 0.02454544959722885, 0.05259634680779917, 0.029470000615609542, 0.02937834749796561, 0.05870552667017494, 0.049626918110464296, 0.028445775753685405, 0.08077056945434638, 0.038064226774232726, 0.026194834216896976, 0.017041318783802644, 0.04159520087497575, 0.021568614690165435, 0.01333570249179112, 0.06830826281969037, 0.029990053602627346, 0.016067527733477097, 0.021154794842004776, 0.018206000394587005, 0.011588071090435343, 0.05857873561659029, 0.015240924499396766, 0.04526624835229345, 0.03120532339172704, 0.029328115550535064, 0.12959514026130947, 0.14841407830161707, 0.1252224434699331, 0.09222007436411721, 0.09921794850379229, 0.10485315469226666, 0.17368672575269425, 0.09196818180914436, 0.14519478247634002, 0.09086370321788959, 0.1054118468559214, 0.1417586404298033, 0.09182298210050378, 0.21464859561196395, 0.1497807428240776, 0.15359032340347767, 0.10036716290882655, 0.15715913261686051, 0.19562674845967973, 0.0856135045843465, 0.18215127369122847, 0.08077315467276744, 0.09216704685240984, 0.12598979872252258, 0.08382113397653614, 0.09714890524212803, 0.1277340951242617, 0.14861807306962355, 0.12266378290951252, 0.11772398012025015, 0.15631515718996525, 0.0777766015380621, 0.1558751950838736, 0.11085036609854017, 0.10888988165450947, 0.09038423680301223, 0.09579059348574706, 0.09264191279986075, 0.169452626524227, 0.15319389610418252, 0.09390649851411581, 0.12841044526015008, 0.11559293232858181, 0.08596396113612823, 0.07890381783779178, 0.13318241919789994, 0.16485606745949813, 0.10503080873084919, 0.09140726405062846, 0.06374419201165438, 0.22900964000395366, 0.18264756777456828, 0.1562603179897581, 0.10053433358137097, 0.20645531240318502, 0.20352929298366818, 0.17051314961697372, 0.14601593198520796, 0.08598283119499683, 0.113278266175517, 0.10854624437966517, 0.22049298057598726, 0.1219905676054103, 0.12881234155169555, 0.13039169966110162, 0.09827042863305126, 0.08253649076712982, 0.16279737864221844, 0.08528392655508858, 0.11370943446776696, 0.15132115302341326, 0.11323562024959496, 0.12444314600101539, 0.11313782299735717, 0.06804980204573699, 0.1358304021081754, 0.16681208035775594, 0.07832679844328336, 0.21115950069257192, 0.2007145940193108, 0.10238613028611455, 0.10733411620770182, 0.11438718917114393, 0.09593170162822519, 0.12228727739836488, 0.24227537959814072, 0.12014670297503471, 0.23769524108086312, 0.0796707591840199, 0.3152991554566792, 0.1262388075036662, 0.1325113344937563, 0.1611480771430901, 0.13521011253552778, 0.09956938214600086, 0.2045929916203022, 0.08980609782572303, 0.11429553266082491, 0.17739581529583248, 0.15536923866186822, 0.1629232061760766, 0.2431604606764657, 0.1302052925207785, 0.11271618133676903, 0.11590478702315263, 0.14762571560485022, 0.1357204115816525, 0.1454121172428131, 0.12831034777419908, 0.1575209546302046, 0.13993201058890137, 0.15282717506800378, 0.2292893049972398, 0.17485882714390755, 0.11391232322369303, 0.09691018983721733, 0.14961895293423108, 0.1310066423778023, 0.09612550480025155, 0.20153818625424588, 0.11850634456745215, 0.14734632202557155, 0.09828400611877441, 0.10705549615834441, 0.07183891122362443, 0.13897824819598878, 0.1591996502663408, 0.14161643306059496, 0.07842074840196542, 0.1459776083273547, 0.06284845793353659, 0.19130313689155237, 0.14505836979619094, 0.1396884165172066, 0.17217676820499556, 0.0945848503283092, 0.12471731486065046, 0.11467103394014494, 0.13003297176744255, 0.12165542558899947, 0.15474386007658072, 0.15256934533161776, 0.14364571417016642, 0.09633031381028039, 0.13854645565152168, 0.12919553741812706, 0.12356651946902275, 0.1320399155042001, 0.21269870309957437, 0.1421822498419455, 0.14375413049544605, 0.10833458216594798, 0.09780244981603962, 0.11724224739841052, 0.15857368814093725, 0.13552442352686608, 0.16089123806783132, 0.10429954475590161, 0.15717131910579546, 0.14892395665603025, 0.13608998246490955, 0.1249468225453581, 0.14129444105284555, 0.20600648862974985, 0.07020210833953959, 0.20281309927148478, 0.13586726013038838, 0.12917933400188172, 0.13635622603552683, 0.07797720363097531, 0.16302250299070561, 0.13306569760399206, 0.18144836569471018, 0.1920176614075899, 0.13213153130241803, 0.10587430918323142], [0.017412421459864293, 0.01162027266608285, 0.05550793039479426, 0.021146114682778716, 0.024619620260117308, 0.031610608965690644, 0.04498606088704296, 0.023204501551975096, 0.009139957455252963, 0.004785930554914687, 0.055561734829097986, 0.08094157384974615, 0.014928469301334448, 0.022314511272790175, 0.04757805787292974, 0.029086082109383175, 0.05054683517664671, 0.03136506410581725, 0.044008916177387745, 0.05474111797021968, 0.04206277935632637, 0.01674041394809527, 0.023253082962972776, 0.06806200210537229, 0.09247725270688534, 0.05399716878309846, 0.03490639604361994, 0.10030781145074538, 0.01729991696109729, 0.02839492803572544, 0.08006760038967643, 0.08225685291524444, 0.029639420631740774, 0.03808071856786098, 0.028312808335093514, 0.028501819353550673, 0.028752456618739024, 0.02584557358308562, 0.029921440141541616, 0.03906971389161689, 0.020232635217585733, 0.036371339578181505, 0.03526192464466606, 0.04013332092602338, 0.06683565183941807, 0.07278153207153082, 0.033911724774433036, 0.05379115537341152, 0.0039974983083084226, 0.018195532295586805, 0.06351326618875776, 0.040865103980260234, 0.05760758237114974, 0.02370909751126809, 0.011526303199519004, 0.05425271864182182, 0.03375940044809665, 0.011552504829264112, 0.026504604112622992, 0.0130179403017142, 0.051568970150713406, 0.04924966621079615, 0.038794890245688815, 0.025095677036525946, 0.03828753264886992, 0.05600606330803462, 0.030953040679118464, 0.0524270964254226, 0.0716854062463556, 0.03504582481192691, 0.050051226413675716, 0.013942536715018963, 0.10069999112082378, 0.021378438287813748, 0.02029836151216711, 0.023808709844680767, 0.02656591484057052, 0.043963047210127115, 0.025435494159215262, 0.0018552860710769892, 0.017246277071535587, 0.022066247183829546, 0.010557549423538148, 0.021608585491776466, 0.028343613824940155, 0.02932486536779574, 0.039915429760835, 0.018064052565023303, 0.03635669339980398, 0.07055290415883064, 0.02245962616455342, 0.03404292969831398, 0.08680106300328459, 0.05749964780573334, 0.030315227939614227, 0.03385028003581932, 0.046612641641071866, 0.03603532225159662, 0.05526859413034149, 0.019217923416623046, 0.020259108261338303, 0.07950069795229606, 0.03236013910334025, 0.005214779953738409, 0.03294526020597134, 0.0673899267401014, 0.02040550049527415, 0.05960018187761307, 0.008075771969743073, 0.006858304575351732, 0.03248510489772473, 0.05180562959451761, 0.02450476972652333, 0.05132740829139948, 0.007936947945771473, 0.1094855268352798, 0.039190459198185375, 0.029280282224395444, 0.010901269818922239, 0.032643156059618504, 0.02406505019670086, 0.05627230687865189, 0.012619703858425575, 0.037795791535505226, 0.02123296886150326, 0.006976456605895821, 0.050213772870068035, 0.05077317410281726, 0.02767063261541937, 0.039550466130354574, 0.04671708853649242, 0.04330709044422422, 0.019621502475014756, 0.03824052374277796, 0.03209115085857255, 0.0209481470020754, 0.08399742415973119, 0.014794891201225775, 0.06858487440539257, 0.03459815794069852, 0.030218648657734905, 0.068818304022508, 0.015198650071397424, 0.030668880391333784, 0.05519112239458731, 0.037166579227362356, 0.05374470625870994, 0.053826992200421434, 0.04437986109405756, 0.03752869640343955, 0.04312684440187045, 0.01301081059500575, 0.014693334864984666, 0.03688922803848982, 0.007966785675047763, 0.030543225883905376, 0.05696632606642587, 0.04864582432700055, 0.024287378980911205, 0.06214591634592839, 0.030970217793115547, 0.07402050987418209, 0.05199868977069855, 0.015371798637456127, 0.06517052690365485, 0.04234504992408412, 0.01414429655830775, 0.023981948316629444, 0.0217806144750544, 0.02140005980618298, 0.05783636402338743, 0.039083226916513274, 0.02222171312730227, 0.03175163907664163, 0.039179758700941286, 0.02465881413913199, 0.04633074426757438, 0.025074214973886098, 0.03428358232070293, 0.04328679546181645, 0.036984911654144526, 0.06593844534030982, 0.0573605549122606, 0.07581947584237371, 0.04845816868224314, 0.04470308464286583, 0.008281055106116193, 0.01986194135887282, 0.03081740831424083, 0.010057057752939207, 0.057889215115989955, 0.03748070701424565, 0.05624003575316497, 0.008861604579059141, 0.019078014584790384, 0.04775341846314924, 0.0055051289049775475, 0.010572232073172927, 0.025868017825164964, 0.021053531972159232, 0.06756123647625957, 0.044672526818300994, 0.021366636867501905, 0.008057923106077527, 0.016782074301902736, 0.01954224449582398, 0.04880571771146996, 0.04802085625539933, 0.03790766838937998, 0.05897455223436866, 0.01635938260837325, 0.02556621393055788, 0.006300377459930522, 0.013220771382163678, 0.017999152386827127, 0.03973396235544767, 0.06944804558796541, 0.02966266724147967, 0.039317579341254065, 0.035658450331538916, 0.057024517229625156, 0.05358466020386134, 0.039651374465652874, 0.022378654884440557, 0.0797382869890758, 0.0779446746621813, 0.06512201164982148, 0.028957635430353026, 0.031381070746907165, 0.029035792486476045, 0.02124811545945704, 0.04490674353603806, 0.03271200700796076, 0.025262842620057718, 0.02257612893091781, 0.04171929135918617, 0.04583882334242974, 0.0130132083681279, 0.051783902903220484, 0.06475990465176956, 0.004758084750002516, 0.0575929938682488, 0.014438740044300045, 0.07569273907159056, 0.03212455513754061, 0.05823239777237177, 0.014341892741088356, 0.02301779924891889, 0.017425325499581437, 0.027183644639860307, 0.05503960552492312, 0.018360019362132465, 0.04269520452778254, 0.03575710253790021, 0.020264869023646628, 0.02489394348646913, 0.030730861172612225, 0.0575905375714813, 0.02946205497054117, 0.015082607012508171, 0.022220512120319263, 0.0355590076318809, 0.025903776620647738, 0.032553776034287045, 0.0735914178990892, 0.01943114965355822, 0.046758540240781646, 0.065743169747293, 0.025528472116483108, 0.007948795167197074, 0.025562826344477277, 0.07329904394490377, 0.02917062757270677, 0.03650176418679101, 0.03996364985193525, 0.028378105456275598, 0.07372792557414089, 0.055210362255041084, 0.02551622286305896, 0.03326530142554215, 0.04168204657201256, 0.04639226025236504, 0.03275773687554257, 0.03985571189384375, 0.01764984255922692, 0.057028710576040406, 0.08048152032175235, 0.022526701047484363, 0.0153088322840631, 0.021838781889528036, 0.008945869298518767, 0.06347399936722857, 0.047000353158052476, 0.013328838261908718, 0.024816663436857716, 0.05237739034263151, 0.04412124764972499, 0.024821967884366, 0.04415755945124796, 0.03453363265310015, 0.015921157551929355, 0.020071215129324367, 0.04877481722672071, 0.08214028738439083, 0.04048774012231401, 0.011790597678295203, 0.030914659345788614, 0.03166488158915724, 0.02191260310688189, 0.03648256503843835, 0.0362908653249698, 0.03350470554349678, 0.040093847151313505, 0.049622558522969484, 0.041640163997986486, 0.023640300845727324, 0.007930639266435589, 0.01656633918173611, 0.06790621046509061, 0.020661533810198307, 0.03793481318280101, 0.027825029866237725, 0.03337651670777372, 0.04459502115579588, 0.03626873490533658, 0.04120177270046302, 0.023533012584916184, 0.08231133927724191, 0.0041359101222561935, 0.07763906927513224, 0.011827347134905202, 0.05186278259913836, 0.04633435407387359, 0.05763341419930969, 0.04571520783273237, 0.024384496001792804, 0.026011473698807613, 0.022468681214377284, 0.01684028751749013, 0.017994936988023773, 0.050063833594322205, 0.048967850261500905, 0.008593158314137586, 0.037649590987712145, 0.007062991873161601, 0.00957262106905026, 0.03171173443219491, 0.0353651230356523, 0.01626772609805422, 0.05854484957775899, 0.013605289543712778, 0.03138630225190094, 0.13334889097937516, 0.1060412423685193, 0.13395524344273976, 0.07292530685663223, 0.18924849214298384, 0.09464104659855366, 0.15771109371313027, 0.11296434194913932, 0.15393592842987605, 0.14166524686983653, 0.10622559354773589, 0.17330367916396686, 0.07501929985093218, 0.06196676953030484, 0.14593541701989515, 0.11323503670947892, 0.14905818445341928, 0.1257882331098829, 0.10406391668532576, 0.13995562360755034, 0.10491601417639426, 0.09792550214167152, 0.1396928405655282, 0.2194435176040445, 0.17101674473711423, 0.15974036125200136, 0.22421462301697048, 0.16299210462187017, 0.1035399248025247, 0.09216617154223578, 0.1585523278585502, 0.22523486827101025, 0.12267999989645821, 0.2095676711095231, 0.12572047460292066, 0.1305240818432399, 0.14591333749038832, 0.08398795859622103, 0.08343020959624223, 0.10401276871562004, 0.11474266009671347, 0.10792285390198231, 0.23529083867158207, 0.15853860788047314, 0.11992881180984633, 0.18190425980303968, 0.15592069764222416, 0.08471373322286777, 0.12376953714660235, 0.14802656695246696, 0.15409933323306696, 0.14943671199892247, 0.1806822046637535, 0.08163308924330132, 0.0876338222463216, 0.13715122480477604, 0.11071737323488508, 0.11933533794113568, 0.07063027072165694, 0.1027892886527947, 0.1430827879479953, 0.09447155533624546, 0.18473072456462042, 0.16174265023853096, 0.0900327353073018, 0.2398496711892741, 0.05676207345511232, 0.13148704517100537, 0.12647590120988234, 0.1399217104273183, 0.13623285479843616, 0.1425986396414893, 0.28509142782006947, 0.0919379870008145, 0.10900688823312521, 0.1932725440710783, 0.14221802220812865, 0.13908469676971436, 0.1139591285692794, 0.11052406539342233, 0.07792401327086346, 0.29644681992275373, 0.11234707864267485, 0.15832458436489105, 0.11906690948775836, 0.1661261628781046, 0.13881425985268184, 0.1392005905508995, 0.15796690141516073, 0.1245916908872979, 0.22961720025965146, 0.1789799231503691, 0.16674836591950484, 0.10766918358526059, 0.1558351343763726, 0.1803560871630907, 0.1263192274740764, 0.16728900905166352, 0.2338369552578245, 0.08929675551397459, 0.11724996912692275, 0.1665743352579219, 0.1274381588612284, 0.09123028854706458, 0.19742264066423687, 0.1635102882449116, 0.10008069220930338, 0.1682293907340084, 0.1138262374858771, 0.08026619401893445, 0.19725627744836466, 0.14649435345615658, 0.09007306064346007, 0.0819234750898821, 0.1163100895604917, 0.2084198205598763, 0.12523657056902135, 0.14217580375926836, 0.1587134799254792, 0.13676374059702667, 0.15989840562854493, 0.12097153014370374, 0.11843159714979784, 0.12162319517561368, 0.0953307163768581, 0.1517127084412745, 0.1504755084003721, 0.13189139775931835, 0.12217750400304794, 0.10426853570554938, 0.11789365458701338, 0.09990273961531264, 0.09904872865549155, 0.09219257333981139, 0.15892989188432693, 0.10669305667813335, 0.1359144861676863, 0.09558508558464901, 0.19634136797061988, 0.058847177640667984, 0.10968313658876078, 0.12890853067593916, 0.1424414095069681, 0.07120958356452839, 0.16281677117305143, 0.13332781568169594, 0.15019865254206316, 0.11103666467326027, 0.0962556613875287, 0.09528745976941926, 0.13121335128588335, 0.1695681946086032, 0.14334639880274022, 0.2018117987151657, 0.08146340799118791, 0.21291052816169603, 0.12996384261974267, 0.25161283569676535, 0.18346543317394598, 0.11585863307118416, 0.11467795499733516, 0.12081926688551903, 0.12033319153956004, 0.14375560970178672, 0.14213259464928082, 0.18726389934974058, 0.07844064304871218, 0.09125211701861449, 0.09143341479024716, 0.08242804051509925, 0.22608366129653795, 0.12956852811787808, 0.13150303145604475, 0.10318804332720381, 0.09101759496011905, 0.12122444728655474], [0.035132015722670724, 0.04077935411727854, 0.05456739943474531, 0.06386718326913458, 0.010096046375110745, 0.07142421097627707, 0.041345798543521335, 0.009125086512150509, 0.023416240100881884, 0.017559862030403953, 0.004943085202415074, 0.03478056172441159, 0.013478665579376476, 0.05769416343952928, 0.05008150264620781, 0.05546539642715028, 0.055987512160624774, 0.02917671063914895, 0.03571955919531839, 0.01689421239175967, 0.03237836455394115, 0.04429844028449484, 0.0120234658076827, 0.009316723461129835, 0.06711414296712194, 0.026670879118942788, 0.07259773050567933, 0.05085353979042598, 0.03089110739529133, 0.02593094007378178, 0.028644254031990255, 0.07064978538879327, 0.02373981988057494, 0.06995484339339392, 0.011637930691774403, 0.056071531759308915, 0.04569294849144561, 0.014159036883419114, 0.026224199516166533, 0.05257410103721278, 0.06215682040367808, 0.009989198313892951, 0.04792674344831279, 0.05473931985242026, 0.035702969014112435, 0.030504970079553977, 0.06990305760077067, 0.011360648204572499, 0.02968790874417339, 0.017098431076322283, 0.013642799807712436, 0.033509492608053346, 0.03173810230301959, 0.019189022913841263, 0.044812780006655624, 0.06736981496214867, 0.05623641576884048, 0.022040593471111994, 0.04175548780975597, 0.035404532349535396, 0.03198161834318723, 0.029474855533667972, 0.02624522053104426, 0.056128257286867926, 0.021081840453137244, 0.02282650156744889, 0.058922793583146164, 0.02137934582840119, 0.02195438220431762, 0.055853996825005324, 0.0051687226930101, 0.026565248179914694, 0.015967896740351404, 0.0714191287489874, 0.05406694932441626, 0.03295111596318228, 0.043658313740577014, 0.014038437461879636, 0.05000353557989001, 0.022141355921381285, 0.022522836790553162, 0.061356406924980025, 0.002178003475169784, 0.04839825743277158, 0.04140022383736713, 0.09297973502959524, 0.02721625503285655, 0.008235937616388713, 0.002045632107183337, 0.024857265276036093, 0.03132267263052719, 0.041736634714262824, 0.03746793698519468, 0.018910597943301712, 0.03436069104022213, 0.03323694205443774, 0.04889895520838244, 0.024676922542442168, 0.035448097690407715, 0.0594623578446252, 0.027231686615518162, 0.0037526031457153814, 0.06718815078160592, 0.032388942914881876, 0.06561821752360888, 0.029369672427752187, 0.0613283562873091, 0.014214500335843434, 0.02660389244556427, 0.017487810093111227, 0.10230925905385188, 0.05891603537436042, 0.02513333403372339, 0.08310125581920147, 0.026690215670636723, 0.0508461980415242, 0.022385648884145275, 0.05806490818836859, 0.04056708800739475, 0.02404529125695782, 0.03801291595612254, 0.016762746231896535, 0.010941967501171997, 0.11711829262120382, 0.07292432976620537, 0.020029376660074507, 0.06952912373734371, 0.05311303426112447, 0.056862768051879745, 0.04349212694380965, 0.021123804451365556, 0.050874136720917056, 0.02156025853141078, 0.02399703554276909, 0.01827012704286192, 0.07566061043845755, 0.012474562673430358, 0.030821974854916334, 0.06154439505189657, 0.026774072420916388, 0.04162437788077763, 0.044652442181749005, 0.012523565624308373, 0.0362405112412359, 0.05023739606674228, 0.06018642256302493, 0.011942280789038964, 0.04182477980586035, 0.06520287266799382, 0.03416584970961724, 0.014532338861109955, 0.011559486954606004, 0.06024375877210072, 0.05787450447678566, 0.03298772292743836, 0.02730693106007363, 0.04715563928974526, 0.03507149039900728, 0.029435598890164068, 0.0317966870165297, 0.05986818963927882, 0.06681406085512467, 0.04029567399993539, 0.028426831055964743, 0.061187777402145524, 0.0271043272888554, 0.011216872571302312, 0.056192758825740645, 0.018903279943125587, 0.004702743433881551, 0.032785241292523484, 0.02306983440316149, 0.06703756350491728, 0.025674672664276192, 0.06322526878544263, 0.015192684052245957, 0.0045094746081823745, 0.006232600717339665, 0.04750367007883532, 0.020656390514756953, 0.09331178292632103, 0.04613320915294545, 0.0514242895213621, 0.013703214869435345, 0.049223166025642834, 0.04655983126057046, 0.06801963437880788, 0.044030225569648404, 0.06474161813301699, 0.02523994036684079, 0.03599438962659665, 0.03509371242086802, 0.010198043759113975, 0.02840417986070471, 0.013690601751607443, 0.010371903090604713, 0.007322090894116887, 0.07490732800215483, 0.027540586290082762, 0.036199419160506556, 0.01939381326415709, 0.027879614615812898, 0.15258119255304337, 0.009834756110129612, 0.03810037912002631, 0.024835786250020777, 0.05471768815602575, 0.027405396669304798, 0.11966164543160371, 0.0234170848769801, 0.055390913638153245, 0.018975123230900084, 0.002121200764252405, 0.008755572456201273, 0.06270071371857609, 0.028911495049084936, 0.05294891699616398, 0.007785771191785378, 0.01919423067010939, 0.10025956082556929, 0.07209306330020938, 0.024543507290737968, 0.03961946974907603, 0.0017312761629000306, 0.015556667199624436, 0.05771029221692255, 0.04817985397364412, 0.05094680103606411, 0.0558996961585113, 0.02933911121051226, 0.03155668578775866, 0.015019153810239263, 0.06760551088622638, 0.05105187896905201, 0.06649986521473952, 0.0032867761328816414, 0.08948167666260685, 0.057039478926786354, 0.022411611330296313, 0.03235237327005182, 0.04234680054443223, 0.027320700231939554, 0.0352582401995148, 0.01526858497943197, 0.019464974624237845, 0.02854379013712917, 0.05256006893302713, 0.033980355198894224, 0.03978660310219441, 0.037899600608008246, 0.0772502144266452, 0.02290354752247887, 0.017428984499669502, 0.04836444603279233, 0.01404584282343941, 0.06405017737831388, 0.024068035750782917, 0.023634930241054723, 0.02283545314068241, 0.09525322089237825, 0.01710919433805559, 0.03543713256450636, 0.04314175860158034, 0.028464442252048423, 0.034404982413564406, 0.0287828414168741, 0.04248762030952743, 0.04903446543695671, 0.029796057048120668, 0.0030547903110605796, 0.02068950641634209, 0.012050818402453192, 0.0687886927542942, 0.07354833092540503, 0.06731684173324279, 0.025435908065576638, 0.016147101231451546, 0.03132376507190721, 0.0874909431274448, 0.017233780152829628, 0.026903592881613543, 0.04502397742388504, 0.08372189823005881, 0.044926499083106, 0.025176919730646268, 0.03223177045583725, 0.02920055775237935, 0.024377244158781, 0.036611561330833604, 0.10871457534709147, 0.06317182736737387, 0.0018968792075091706, 0.020735288870387843, 0.02781094517558813, 0.030402653784091984, 0.03890906394060169, 0.026699336877624904, 0.03972261385726077, 0.06078633572906256, 0.0315804107646857, 0.037299029263002534, 0.04300821951723524, 0.035892086901835034, 0.010502326002876674, 0.010362784428122853, 0.03758745753605451, 0.08956373868776218, 0.04569723344008837, 0.03709248998867614, 0.032193433227283616, 0.02909694884770683, 0.0620393320651991, 0.014042269488397454, 0.03690986568108201, 0.05075810044737799, 0.05574335490486451, 0.029038574480052506, 0.04212095694882529, 0.08366293353693825, 0.05710162594914436, 0.030895473768136332, 0.028485626115330627, 0.021572478947096636, 0.03286443989990013, 0.02141226495483092, 0.025517364498227835, 0.019044155687359825, 0.00591383726402585, 0.05765482197914805, 0.019396583383370723, 0.022405244975483844, 0.018349374844027416, 0.07586995206241097, 0.028061974294749752, 0.05423116158427937, 0.047550804513905726, 0.014209215396216937, 0.03130862695564117, 0.017719560336055498, 0.04513238017846431, 0.04337310850886362, 0.006895255047961005, 0.04794842264215861, 0.038816138569797785, 0.029290629883429835, 0.01684166833625308, 0.042180084490350316, 0.050275899536375485, 0.021230831476194516, 0.008984110684001019, 0.08272584953478404, 0.030127945489117076, 0.10956878986741815, 0.1342340941940035, 0.11992368208510534, 0.13328894919582776, 0.11028518035475697, 0.14625375850924424, 0.1596465062882219, 0.10638129697846514, 0.13343301575098718, 0.1040177084505558, 0.09372671387557473, 0.08455865404435567, 0.16876312637967722, 0.15273452789655753, 0.10912856313266925, 0.12701985559293202, 0.06277120672166348, 0.13526478888733046, 0.13880883157253265, 0.17048197771821702, 0.15690968957330498, 0.20787057360368116, 0.19922109773116453, 0.08011617671166148, 0.10191702510097198, 0.12172270912144866, 0.20323240677160875, 0.15607643499970436, 0.11725458316504955, 0.11179729564381496, 0.11781505309045315, 0.16213822258370264, 0.17181903097246373, 0.17459882609546185, 0.11622748470732144, 0.10312622878700495, 0.15816858916410378, 0.1369816181915147, 0.08836656542760984, 0.13479753610278877, 0.1580738385340997, 0.08131516844566379, 0.0775833683354514, 0.10529305573020663, 0.11670180782675743, 0.15281482573066438, 0.12826656869479588, 0.1958691890218428, 0.09178663976490498, 0.17658108472824097, 0.11754910807524409, 0.18706450504916056, 0.10938501544296741, 0.15832539860691341, 0.0853448657851134, 0.14218495041131973, 0.1881745204861675, 0.1524920059101922, 0.08000528373356376, 0.11495373877031462, 0.1379326664443527, 0.11095028038003615, 0.07983791628586394, 0.18942048719951085, 0.09018666776163237, 0.06085962429642677, 0.11529265344142914, 0.11300362234136888, 0.06425980398697512, 0.12048677115568093, 0.12629401311278343, 0.11013421309845788, 0.0883411882179124, 0.10223227925598621, 0.24398270941206388, 0.0950686050845044, 0.1496768862541233, 0.11804382795734064, 0.1722711388553892, 0.1703004560300282, 0.1033255552340831, 0.12644582853785583, 0.078914850817195, 0.15131583330886705, 0.11910934506782464, 0.1313392873853445, 0.12419256301862852, 0.12064632187996592, 0.0949916388573391, 0.11141602681683642, 0.13376011034207685, 0.15507615224591323, 0.06070803278791053, 0.11464402824640274, 0.10161895823798009, 0.14142089283892087, 0.09987754561007023, 0.12839730882218905, 0.1296272078262908, 0.1312576053397996, 0.1502012445458344, 0.07587750415716853, 0.16799036998833927, 0.11623619709696088, 0.13859723721231731, 0.12539909327668802, 0.1615218956555639, 0.17105042721543992, 0.11550811545125075, 0.11432332545518875, 0.17669940766479286, 0.16640673710831574, 0.07828567922115326, 0.2013042409505163, 0.13579830740179333, 0.14591348676809243, 0.11622595121817929, 0.1952002892004592, 0.15902768235121453, 0.14950375125876494, 0.08987274353525468, 0.22003412805497646, 0.08943113258906774, 0.1950018991317068, 0.17621390228824957, 0.12954925772334847, 0.12043478180255208, 0.11444897656994206, 0.11702622898987361, 0.12078791856765747, 0.1520098660673414, 0.11460980294006211, 0.11866569173123155, 0.07050205474453312, 0.16949773553226674, 0.19081680370228632, 0.11309614059116159, 0.12512752999152454, 0.12259234674274921, 0.11658233138067381, 0.19749460608831473, 0.11188743902104241, 0.1424528903194836, 0.16403353373919213, 0.21027740516832896, 0.08156710849808795, 0.11510745409343924, 0.12010565160640649, 0.13080274260469846, 0.1276164778641292, 0.119694730799113, 0.12272333114274911, 0.13428076383258614, 0.21491017086165293, 0.1256119089999369, 0.11267924189035382, 0.2945986533803599, 0.09196974922503744, 0.12077634276023932, 0.1582979450800589, 0.09412398934364319, 0.14263749255665711, 0.17315639635281904, 0.10371104454887764, 0.1483579363141741, 0.09246638257588659, 0.07941664103418589, 0.11941829563251563, 0.11401205430073397, 0.08423242797808987, 0.14016990496643952, 0.0943644078714507, 0.15783757264060633, 0.0974512400903872, 0.27641022365008083, 0.11593542966459479], [0.025794430702392544, 0.04939429255734597, 0.05106081188257251, 0.010625810894582952, 0.020156320384038345, 0.008162849216854997, 0.020045944788892354, 0.0068200572526880675, 0.03883654551048364, 0.0013961851426366983, 0.008721948501520922, 0.046686941225613864, 0.06014438731861966, 0.033564525190740824, 0.029208550894899026, 0.03081868396007589, 0.09245682201747384, 0.037094800400414636, 0.03434276753770454, 0.02271882993435221, 0.027410034456157258, 0.030784882738121917, 0.012232346875992204, 0.08192135127527372, 0.01918479224799999, 0.013728732875149165, 0.014330037037975021, 0.033492800646594593, 0.0333204493591828, 0.016088638654244796, 0.06667024535792214, 0.019402013359857456, 0.04288172023370862, 0.08899909577199391, 0.058690938167274, 0.01983525966560202, 0.07679640342082296, 0.059745144098997116, 0.02219734014943242, 0.05144263371559126, 0.04360714541482074, 0.015293778984674385, 0.053457987893904955, 0.06358044115560395, 0.04104412187423025, 0.04749103914946318, 0.08745466185999767, 0.014062807047074395, 0.023749989424166933, 0.021956472092175057, 0.024069316485630612, 0.014509641864736165, 0.009591569159446018, 0.03963106591254473, 0.0205184070260397, 0.06082504615187645, 0.07466518599539995, 0.11937481510852065, 0.015360229615388172, 0.013350644681070532, 0.01786621380597353, 0.018112998688593507, 0.007755772310442158, 0.022371096004332815, 0.017768789747995988, 0.026579098775982857, 0.014426609534504158, 0.03527692026857819, 0.01238436670973897, 0.029640058454658304, 0.03868682675861886, 0.010413577015112554, 0.0061361745299239245, 0.012064149919232088, 0.025439061557075808, 0.03075563787881817, 0.05637250275218061, 0.030279089164521013, 0.020917521324008703, 0.02412009465375117, 0.0347409454573478, 0.053138933942786286, 0.020296989175091897, 0.05661868882764663, 0.02617101594140487, 0.0368046452557402, 0.025434683309867978, 0.023063230561092496, 0.025721654428967407, 0.03022669947573117, 0.027372011050049747, 0.004953487568335342, 0.0337643944658339, 0.025529707050217048, 0.050397543901843686, 0.044943513348698616, 0.04088139221338289, 0.035217942004757266, 0.04917747687016215, 0.029057169732238566, 0.15243305478777203, 0.02431547541969589, 0.026431273136820112, 0.003595737723766693, 0.017584180725472312, 0.1424265360193593, 0.015586378551753504, 0.01994137236449335, 0.045093805462654145, 0.02383086910205228, 0.01757341407106391, 0.05345317708062274, 0.05513945873826742, 0.01808778602363808, 0.010227253843498017, 0.039085523757551394, 0.05285112652927637, 0.027253196175609316, 0.01894142887821155, 0.010318302216806581, 0.03559900387855513, 0.011706578927779836, 0.04922031617856451, 0.05999415288014071, 0.04722558267946754, 0.0208795199702893, 0.06675925558166844, 0.05541399061413748, 0.043575033745063205, 0.028565153812191317, 0.05762054917535611, 0.013223271783707398, 0.04686968766951135, 0.015086766432172485, 0.026978501451334784, 0.018358272134459445, 0.015019964659586549, 0.043875740109277625, 0.012513694636124586, 0.039670159707644155, 0.08251981916172163, 0.034061178897640536, 0.03755192944247808, 0.010183467978744634, 0.021458949860451475, 0.06504959160728113, 0.028577869558440785, 0.05176800482773355, 0.029587851970323494, 0.03206513582595757, 0.07795996205615145, 0.07907265092113189, 0.016764493459569554, 0.017321099128041948, 0.013946578239223786, 0.07231100196284906, 0.05547489591741136, 0.020897937107032964, 0.036752357347203155, 0.011542670312337577, 0.04578420466610363, 0.03681258072278329, 0.03189239777358515, 0.012522870974083031, 0.025390391936525702, 0.025112465689224855, 0.05736056848296097, 0.071870551311544, 0.03657520881720951, 0.005763674495808248, 0.03444207113768373, 0.03326699437041368, 0.05766832482601915, 0.017699947281341468, 0.02662831631356052, 0.02688398491591215, 0.04162797072370138, 0.013019878367361213, 0.04947397292458585, 0.07005155498960189, 0.04421163529955915, 0.010510578685040985, 0.06880017356680972, 0.042284863867930005, 0.019574222154915333, 0.08526232878544501, 0.03180426964536309, 0.06209093465336731, 0.034406739819262705, 0.010862676443399062, 0.03898864931293896, 0.043663891298430305, 0.04163826749260936, 0.025223450269550085, 0.021660401818475554, 0.025990103238395283, 0.009672512449989361, 0.04911426454782486, 0.039596596333597384, 0.007457350064734263, 0.010868561038348292, 0.00471618733302291, 0.016950652934610844, 0.02486171985843352, 0.019248883273186426, 0.03367429858605776, 0.04557446609916432, 0.0014849259667763753, 0.014355297200381756, 0.0169658097105899, 0.010059162907834564, 0.057931419994149885, 0.05613826907106808, 0.031934762107474465, 0.05399415608761566, 0.05181029113009572, 0.03183520405686327, 0.02449845426183726, 0.025943425118124912, 0.056744278874248266, 0.014671460592320986, 0.04484403672228966, 0.009541193023324013, 0.08050127247614519, 0.0015433143292154583, 0.046572994839932234, 0.009331281429954937, 0.05332090685676251, 0.03388187941163778, 0.016633926358606135, 0.023923219414427876, 0.047311196835445504, 0.029541172153715576, 0.0347713200774576, 0.0149924772059811, 0.05017175119636314, 0.02023054363339075, 0.031894124645207605, 0.03408058160649879, 0.039825035325650654, 0.036708659692002196, 0.028071646811440587, 0.03442599664309195, 0.01583679868573589, 0.028870620099561553, 0.02913358634603875, 0.030505122749933174, 0.027624683920294046, 0.015754770587331483, 0.045727658950324566, 0.05244645502950464, 0.03328392721180405, 0.024495797797239253, 0.03748520230874419, 0.06315324229321309, 0.028760534578136036, 0.01495867598402713, 0.061538118602974076, 0.019524363401745046, 0.007555221107655338, 0.031981791369616985, 0.013620870404078491, 0.017975758195721676, 0.030189719317214828, 0.012522273015097847, 0.022844450515029684, 0.054759757327181954, 0.07411711969013725, 0.08359341083892755, 0.028998646086880138, 0.03112349546115313, 0.01384698286918657, 0.04497347066977194, 0.015549232152157595, 0.016282294244904603, 0.05556417755516512, 0.014512627418818218, 0.038072586325662475, 0.047590274895940504, 0.023370247300980345, 0.021343066257291606, 0.035662619929228506, 0.009409482590854168, 0.009301531062062298, 0.027067866209628325, 0.010196104845298188, 0.031353267774518044, 0.05671771422826818, 0.046777773315885236, 0.05570872926286288, 0.014316072787291237, 0.06457526848784514, 0.020060479008991803, 0.04440786762695227, 0.025444187889141694, 0.05831173208675214, 0.014345897794035929, 0.017187225865200162, 0.012727194831573536, 0.02551529327008341, 0.045265559639249525, 0.047038663245205364, 0.06886139099619218, 0.0175076284046684, 0.039195734807955365, 0.044361499936452935, 0.033133088877158504, 0.030388818455061743, 0.016677584998043518, 0.02130142117052206, 0.04468662338331342, 0.04284974427095481, 0.03602099837735295, 0.03911271265574864, 0.03935889873121466, 0.07871940559042351, 0.04496198646458132, 0.03401572722941637, 0.013651780218684247, 0.02026130162578608, 0.00958069902844727, 0.019596690145720328, 0.0030977292792938116, 0.05832864117941686, 0.01517675374634564, 0.03734883712604642, 0.016526502390791262, 0.03251333873985069, 0.015337756535570537, 0.028516998181917837, 0.03807870331885559, 0.0264758342278323, 0.007431482613485838, 0.06256799905427865, 0.04937876767611929, 0.038028403517923186, 0.022541555875380124, 0.04812837691445436, 0.04498259696577277, 0.049477555589484315, 0.05929395902369704, 0.002781368688114786, 0.046995956251131635, 0.020535892873470272, 0.044712489138224294, 0.05407356843352318, 0.06766119825520686, 0.02783128256643457, 0.04625922328393374, 0.023051819298416376, 0.04344536231032439, 0.013826804085900741, 0.14611423813870975, 0.14595825650862285, 0.10960228235593863, 0.19509350135922432, 0.1584752055683306, 0.08381958013134343, 0.09038946830800601, 0.14810599626174994, 0.1657484902867249, 0.2197268195450306, 0.07874050802950348, 0.1481193769723177, 0.13025156860905035, 0.16693356526749475, 0.12028714615319457, 0.09041823819279671, 0.1807622853666544, 0.1376796000237976, 0.11147619930229016, 0.08723132884395973, 0.1331294391836439, 0.08973691439522163, 0.12854877140905174, 0.10891860404184886, 0.07792237121611834, 0.13146588844912394, 0.06205976953996079, 0.14036577088492258, 0.14640226268342563, 0.10157272964715958, 0.1808034995836871, 0.14909293901707443, 0.09754996015025036, 0.12064314633607864, 0.14768990501761436, 0.12294013665190764, 0.25378588480608805, 0.13912832657141344, 0.10571733689201729, 0.09117357659020595, 0.1095709272527269, 0.10856370308569499, 0.14872062685234205, 0.19320374062018736, 0.21025821619800159, 0.11238579585083894, 0.11041595440890108, 0.143069787217038, 0.12489772375140872, 0.07496942074171134, 0.11741303466260433, 0.1260630533631359, 0.1035811390195574, 0.12090461302016463, 0.07272570221019642, 0.1488714244748865, 0.20699830326650823, 0.17696662832583698, 0.12732143726732048, 0.08837067734982286, 0.09911677214716162, 0.17442517541348934, 0.12940907238849572, 0.11701214260288648, 0.13437256962060928, 0.13045719186110155, 0.10083556920289993, 0.15680624012436184, 0.10928900952317885, 0.15237493147807463, 0.09427678185914244, 0.1392481829971075, 0.056772936800760884, 0.13216496950813703, 0.16152938668216976, 0.14352896543485777, 0.10702190188957111, 0.16180833242833614, 0.17890050741178648, 0.12684754841029644, 0.1219485527170556, 0.17742647150797503, 0.14699295455855982, 0.13124816013234003, 0.10878588937755142, 0.11236789609704699, 0.056636235743228874, 0.08028523371155773, 0.09440108947455883, 0.09996269496956042, 0.2297943521823202, 0.1200312434562615, 0.14270219765603542, 0.1035299299817, 0.12836940746222222, 0.11787804828158446, 0.17845418064721993, 0.166586128196546, 0.10551756939717702, 0.18323051077978952, 0.20837655716708728, 0.24704759780849728, 0.045348530901329856, 0.06415551315460886, 0.05914918679211821, 0.30537438658731325, 0.14720302900033339, 0.08185699222875492, 0.1461678288344826, 0.10428739219371762, 0.08710010695670332, 0.12701126533959592, 0.145994028874806, 0.07110316891755376, 0.1670560408383608, 0.1683538204857281, 0.0963301577472261, 0.19348291706826004, 0.18558893565620693, 0.13562571523444994, 0.08506619145295449, 0.11112477923078196, 0.09660409590495483, 0.17421199328133039, 0.14406875361289295, 0.1440612625862871, 0.11306587114397969, 0.07409544728164162, 0.1354335948292698, 0.10776641086808272, 0.09399212284811906, 0.1968292753611292, 0.10506639789257731, 0.10539289537285056, 0.2203811037221125, 0.13010666067046778, 0.1028214715687292, 0.10264292864927224, 0.18744076628770145, 0.12039717739181859, 0.14061590603419713, 0.10259982810488769, 0.13753201865724154, 0.15183130279183388, 0.09678124782762357, 0.13102015879537376, 0.21146039026124136, 0.19490556072975906, 0.11457859032920428, 0.0733078174026949, 0.17497887355940683, 0.15870924586696283, 0.0778354373095291, 0.09013947565108538, 0.10005379508116416, 0.1419088409415313, 0.11636483376579625, 0.09461554046720266, 0.11779054440557957, 0.14342255757323333, 0.2016082653509719, 0.08126934019050427, 0.19630588058914455, 0.19237165312681878, 0.13094224940453256, 0.160162640735507, 0.17382467192198547, 0.12727716964270386, 0.14852765149303845, 0.12279602938464709, 0.14027400580900057, 0.20465078923319066, 0.15066800878516265, 0.0889294712937304, 0.12249790823885373, 0.1001475482646908], [0.029961599236620323, 0.03208207884537322, 0.024709341249295642, 0.025658148640234555, 0.024174911801570227, 0.0316213264263102, 0.022213095732565438, 0.02052035611788077, 0.0331393687187561, 0.03283948677458933, 0.01509276807441243, 0.0058901725070817125, 0.0068464446313945306, 0.03773260974724378, 0.029523710055010657, 0.01942738039152963, 0.05485690997115203, 0.026844884335462536, 0.06858131209654467, 0.08543027977326087, 0.05233952130324074, 0.05830835298235927, 0.03456762047218425, 0.04839107853227428, 0.021266427423272814, 0.020278159828324403, 0.020392542172755514, 0.06718496845236846, 0.06175346526184252, 0.020947251335850785, 0.04392243688926101, 0.06761892552354506, 0.03717760881409049, 0.027937495349241153, 0.04603291489183903, 0.05548650225890534, 0.019352794125942246, 0.02033898710007114, 0.05913981622351067, 0.03914404061755963, 0.0461294704249927, 0.02012385587607111, 0.042309033285294256, 0.031850148790649006, 0.054981271869369915, 0.04560186195054224, 0.020100643193083148, 0.05981546068297965, 0.045858595852873156, 0.0289608618643667, 0.037919692029910426, 0.05206703181777682, 0.04897775348009808, 0.019658019533380866, 0.05347630833940847, 0.024718431922207986, 0.022819419358191744, 0.03531968154545341, 0.009460343879514506, 0.022512399225628803, 0.009881450345606675, 0.027135943628049324, 0.012870771145181996, 0.047654277711574516, 0.012137189973145723, 0.09035867638885975, 0.014648722883846079, 0.062369778619280884, 0.06692914039428745, 0.06714023263858897, 0.027498406856986027, 0.04900557002318757, 0.013889222522266209, 0.08029151016048022, 0.09175043992166008, 0.042741365265101194, 0.03662655356207064, 0.012703357896368419, 0.0891608042376382, 0.05392131196068866, 0.03519605925040586, 0.02646936270009194, 0.07185170160872595, 0.007771391338402671, 0.02144735030430768, 0.04637126977156315, 0.057359286051775725, 0.020511818451008627, 0.025554568573300327, 0.03298806898029787, 0.04461495990731886, 0.03208946469905121, 0.021567062541310276, 0.041796277942402024, 0.043280369735189846, 0.030007885502917424, 0.06297695889536824, 0.030303387503538812, 0.04334336492632117, 0.02166894287802279, 0.026410581211426427, 0.07329340531889882, 0.0037222145308208254, 0.010448380772556578, 0.05062585057956832, 0.005157541284071547, 0.025807102343865802, 0.0941989878192544, 0.013041525330793644, 0.02053914644888469, 0.03949752004284944, 0.02958633883723191, 0.03333010491249817, 0.07425698611353125, 0.05198185531688588, 0.035675715655088425, 0.06121255071567638, 0.019419958914763162, 0.018859638267063668, 0.01952926072824214, 0.061651366097586494, 0.02344805151889367, 0.018978161371446083, 0.008437141060962208, 0.030292893959475414, 0.032617850096098015, 0.02812420274131, 0.06052039749920368, 0.02409909908393664, 0.053594312364501615, 0.03550322187532272, 0.03823647967406681, 0.04006862261199525, 0.05971612994159971, 0.032517352274485996, 0.02032704488374293, 0.06634616346231528, 0.037801721931568215, 0.04274516845388072, 0.023860246275684664, 0.020885362156799862, 0.030912610170032297, 0.02975853406158941, 0.00879581382365099, 0.012294498987362852, 0.017430911539122462, 0.04219064588791557, 0.007328832139527159, 0.025882552045264413, 0.03573652596345969, 0.02732673240825534, 0.02316181152127683, 0.017603853152000477, 0.04873596770422799, 0.0294908078919564, 0.10032603011599608, 0.01811488501594535, 0.03515318940792765, 0.03881960927641817, 0.09193188697099686, 0.03192548992644463, 0.009275435453413852, 0.02702687251647668, 0.026231680364747132, 0.05728075919406755, 0.06491463099207197, 0.016807921397100602, 0.08866420481353998, 0.035502916534564326, 0.06794590476368155, 0.01564324996434152, 0.040820900816470385, 0.011986607785469719, 0.03893057010801775, 0.023660558508709073, 0.0058443489168504515, 0.06409785124872412, 0.06298867719514029, 0.08168180805764028, 0.007785046007484198, 0.03362911493916597, 0.026555327997942055, 0.04477676336786576, 0.055068450048565865, 0.04505833165187921, 0.04125599443380322, 0.06389085057058505, 0.02323538507334888, 0.019216659645150815, 0.10136163740285806, 0.024569691957107613, 0.023357083721618568, 0.05826942542833941, 0.022996065772271583, 0.03080791900200503, 0.023751599248498678, 0.06406268277870757, 0.05782966009740319, 0.034139257922236405, 0.041979913267173936, 0.03538519749417901, 0.04317991262567895, 0.007737212681344577, 0.0457527952800904, 0.0234897542811398, 0.043785664585552046, 0.036990095661687, 0.009526340739934571, 0.01890846055799297, 0.021074551290699413, 0.045808401224868636, 0.057111206863607676, 0.022577155215133513, 0.07847830852759735, 0.02539196444143142, 0.03966383236859526, 0.009856370843148657, 0.016720293688454797, 0.057051455069865496, 0.0620579103540097, 0.060278533691806455, 0.034050023781933954, 0.005831486437403197, 0.0560281156961407, 0.01810587746357279, 0.029446424916386604, 0.0061062778529178885, 0.050327892282179425, 0.012711335771850176, 0.031000429564820867, 0.02495921855526311, 0.0605917793831655, 0.018966677166255455, 0.04574475803279451, 0.015834020084834526, 0.0050765954490218845, 0.05404766196651118, 0.049297285798404894, 0.018466844522793378, 0.033188372517802885, 0.048678163305989335, 0.01110500335094652, 0.027065813641196916, 0.019557297795212696, 0.07174060507012264, 0.032693801913410425, 0.048450491058507135, 0.028700165317526886, 0.06769855160798345, 0.012443142261223068, 0.05781384344611849, 0.05102284445560404, 0.014617247340668525, 0.02991367770092828, 0.01886819120097373, 0.015696065433855568, 0.031748317647725344, 0.021998022184041992, 0.034353183050240786, 0.014691066861684834, 0.03213144226797989, 0.0015700391730726032, 0.06642519922128745, 0.029699582939169238, 0.024197746201285293, 0.01036387262865901, 0.03082697226532868, 0.0713117912943874, 0.04063993891967194, 0.033771376591175795, 0.08606745129717247, 0.019859218737110496, 0.049296783682491095, 0.03778946080378123, 0.042862348058926206, 0.01393626959595297, 0.012874754145741463, 0.03427344161484923, 0.022924714422385608, 0.015389766244749938, 0.06585968099534512, 0.031333946489862034, 0.02777584795174854, 0.019994040252640843, 0.04023980681917497, 0.018606151154796993, 0.04280057762350355, 0.02582913437592132, 0.012269660364836454, 0.04770691506564617, 0.03628076533121722, 0.03532957458602531, 0.08989907069397823, 0.04371021149147834, 0.021774568728038242, 0.036542832518794706, 0.0319276646311794, 0.025434498409075395, 0.010954137026731457, 0.02472165326720902, 0.06597702684147017, 0.02574687896828566, 0.052818265078323226, 0.06637902491326843, 0.053077906503209045, 0.02111230667547456, 0.021603900207472698, 0.010839646964866136, 0.020337996438943913, 0.05004639524434294, 0.06451336573809385, 0.014932292846164532, 0.023937086973871504, 0.02995013538748026, 0.04875758243724704, 0.03941494233107992, 0.09337293250220162, 0.025269765373585478, 0.048124628008476326, 0.014643891714513302, 0.034025504919035096, 0.024563644513753907, 0.07724433831338372, 0.028426725883036852, 0.010267731850035489, 0.03272660568888698, 0.08602515820946012, 0.04561374309871878, 0.030005822756460736, 0.04792396145473633, 0.005946514238270798, 0.051675174451832256, 0.025915545810546194, 0.0466519831014531, 0.011294685270903366, 0.04441774709682379, 0.030618807899632623, 0.01614427174042378, 0.08840187638998032, 0.021129376920206205, 0.039061001501977444, 0.01481678243726492, 0.06262516562959977, 0.05067418941429683, 0.05362931459343859, 0.07613589029226984, 0.011600260123876589, 0.02336156883809183, 0.032779965682753494, 0.017382247007585, 0.00983008015568235, 0.013003097348181265, 0.15530519852680819, 0.1246744314474719, 0.15630379851375306, 0.12609312603516237, 0.14306373468467168, 0.08016546549541609, 0.15099261993808405, 0.1804567546184574, 0.0938446025497147, 0.14432123649333203, 0.1562102013932807, 0.11318984627723694, 0.15226667800119945, 0.1648231585110937, 0.07483598683029413, 0.12165488276098456, 0.22129715313868864, 0.09050807622926575, 0.09116504061967134, 0.14548299701086112, 0.1448013000190258, 0.11142204542245183, 0.09782176092267036, 0.18353977347058908, 0.06537867430597544, 0.16227896431727068, 0.08361134451947042, 0.18752247547464712, 0.15237756419394696, 0.08248682200376477, 0.14098390271621092, 0.1546703747340611, 0.11859216567661081, 0.08245258991207395, 0.11516879365912505, 0.13326335485492433, 0.1203767399170569, 0.20674582038606915, 0.14291232638061047, 0.15142688235001905, 0.14045540536088602, 0.15838011567081722, 0.11432055703231267, 0.1095986318375383, 0.1558517584843295, 0.09587229588734252, 0.07865647146744387, 0.2016306570065873, 0.13187457009085587, 0.11389518342912197, 0.11232850035386426, 0.10219161465231862, 0.16515756770968437, 0.12523197010159492, 0.13428373581596784, 0.12236361258796283, 0.09830755128392152, 0.21592063164072378, 0.06795568245330028, 0.09052096839462008, 0.17430181774709905, 0.17053909679608686, 0.08905459993651935, 0.10056500336421387, 0.11180274428001472, 0.09337533451616764, 0.17960127123764583, 0.1443452566329922, 0.21066087244876794, 0.09466145014656441, 0.11155560825552259, 0.16251468738274916, 0.1581309168998684, 0.16871014636542114, 0.14466355741024017, 0.16510685400239059, 0.09786219482443162, 0.08845813372837645, 0.13212835575853074, 0.09796463325619698, 0.11074190227580921, 0.14813119705234254, 0.15812614001333714, 0.0890755056004439, 0.1328409125230142, 0.10223896961127009, 0.10347471758723259, 0.1033459452113935, 0.10369277838617563, 0.2565691540283816, 0.08538489256586347, 0.19750120144869598, 0.12561823294631072, 0.13792015425860882, 0.30991419298308237, 0.12414817325770855, 0.13545069391173975, 0.2065578390445028, 0.15136411786079407, 0.17753589206508227, 0.16689205249505384, 0.136126202664205, 0.0994307981537921, 0.1480916113193546, 0.11817551803375993, 0.0781844485817211, 0.11793765079762254, 0.251082682715995, 0.18164907635322639, 0.10467184334993362, 0.1689594401312726, 0.12090244170810495, 0.11347170972398349, 0.19121438451111317, 0.08940234234822647, 0.1028622379526496, 0.17527582762496813, 0.11031480519367115, 0.10292748588004283, 0.14183862613780157, 0.09859363521848406, 0.15679124450044973, 0.13647092559507915, 0.10176341155810015, 0.16393446762646946, 0.10383792381201472, 0.10736391068037067, 0.17588151512401445, 0.18511225123490604, 0.14892088967774594, 0.11187074027423348, 0.0862533427508814, 0.11420625102307115, 0.14128975916121686, 0.10712054052523204, 0.07701440993696451, 0.25859287115080015, 0.18718924692698888, 0.11302321164735726, 0.13098885118961334, 0.17693769559264183, 0.1048661418525236, 0.09083665002669607, 0.13714107392089708, 0.14625941749129975, 0.06659397802182607, 0.1920950279704162, 0.1502856407314539, 0.11787544270711285, 0.11520149904702391, 0.15502328079726013, 0.1375125175608056, 0.19209615433854715, 0.16296280547976494, 0.07187118234911136, 0.09701760193066937, 0.11255222013486282, 0.11877208602215562, 0.12035664170980453, 0.13331079802342824, 0.11712110175618104, 0.055969463129128726, 0.14818748831748962, 0.09655460356069462, 0.08720726799219847, 0.13441505948347704, 0.18022739621145384, 0.1233788909656661, 0.11917424015700817, 0.12981103653354303, 0.07684964127838612, 0.12230356223881245, 0.09023333061486483, 0.1483949436140912, 0.10106974520853587, 0.12655634832169327], [0.038731206341513565, 0.026695459049993327, 0.04126417078077793, 0.03628645824002368, 0.008289185651977147, 0.051677440758794546, 0.0008125472221373846, 0.01973393403126725, 0.057346136043114324, 0.034005915613046715, 0.08279402194810764, 0.04638116620481014, 0.04016755980306438, 0.0458048049892698, 0.06717700923659972, 0.005558997376023659, 0.0031908389147637145, 0.018042359800477113, 0.018084741097741892, 0.03619081533647009, 0.004104053751299424, 0.09085874991225344, 0.02351719593363149, 0.04752324242144823, 0.015561284630426338, 0.02589550188609532, 0.020719066794429506, 0.06719156381274972, 0.03263918662975941, 0.042187548375555446, 0.03209946630522609, 0.029493026701467376, 0.07902150973677635, 0.02463029870497329, 0.04123676135869963, 0.027944748888590505, 0.027142796831737672, 0.034146765912217755, 0.02226782636716962, 0.021824590329613005, 0.01793500198982656, 0.07560176788164036, 0.0044854052747333685, 0.03872599519257035, 0.04044361159737621, 0.04038350357274924, 0.018173537582957318, 0.008153191967202085, 0.04676994302177003, 0.05277931038290262, 0.017860390279175978, 0.032656706403940916, 0.013332353073305317, 0.03329555730202368, 0.03965360006051404, 0.05025621862815959, 0.050929654456142864, 0.052139438289616785, 0.032876239623874426, 0.047451056473489316, 0.045266631724578996, 0.04255894451801266, 0.06395423931202718, 0.012982492784171231, 0.031147325611008064, 0.05625462764874101, 0.03782504318015916, 0.05133973388001323, 0.05365047470799514, 0.059314064016299586, 0.034286730723189454, 0.048789212347141335, 0.031584122351237705, 0.021311212430841157, 0.016915940779394338, 0.03979633668703692, 0.009845597403390067, 0.06987118681094476, 0.051632759227816544, 0.03129992135135191, 0.031038495379367044, 0.043168553949466774, 0.08434959740511008, 0.02287119158011462, 0.02556850228990827, 0.020692588661664298, 0.04413984290191105, 0.022113181451069455, 0.04620085230895451, 0.030154520313122442, 0.06808291455464703, 0.06792282100234713, 0.07853068464568683, 0.020631617201226096, 0.034469076831425936, 0.05872299216155495, 0.08464780676045588, 0.027517173439264297, 0.022064937611243556, 0.020781588707385317, 0.0772617698780128, 0.043117891132299385, 0.03893893305212259, 0.052686357870697975, 0.03052456956356764, 0.017746706825814078, 0.025346913108868257, 0.012042040703818202, 0.012043754004740288, 0.05402100232562848, 0.03963750181719661, 0.034428259557379146, 0.03776478248515299, 0.03278153309864657, 0.10624630922185523, 0.05789143392550094, 0.028580512452338423, 0.08584396221808024, 0.030109577546162263, 0.03600494423881173, 0.03677096617008958, 0.0931164530505027, 0.033791939594915936, 0.07038854262126343, 0.03887733903580478, 0.03434232309726732, 0.010064608151359218, 0.031276345652128966, 0.013329878116824796, 0.03665823096941624, 0.01728131153088595, 0.040622992507581196, 0.006142864885207797, 0.002507230150513351, 0.0495873052360756, 0.09295262755560023, 0.03583143265651805, 0.028881666649665152, 0.0701512046424406, 0.07307965321732418, 0.08505053086472408, 0.006423975158083651, 0.05474443600646087, 0.042789011994110684, 0.031933622168643136, 0.026729731853785257, 0.041830550746193955, 0.03527050132730177, 0.00739003684637802, 0.03707973013765045, 0.03758623278034585, 0.049346455838531256, 0.03668764206979956, 0.027143563576308743, 0.02590254507958889, 0.01963877797658954, 0.04723176074081233, 0.04367770966408508, 0.05000171710604003, 0.03629193741029926, 0.019947928709111044, 0.008455220626534095, 0.03162776233096208, 0.030978953931480646, 0.06824414126042809, 0.034651229557182105, 0.07004683238587209, 0.032163102711950026, 0.054194303562066386, 0.0367216604229595, 0.07645809264587504, 0.06925403885543346, 0.013016120131526674, 0.030238377063402107, 0.06747812950717551, 0.011717572043250715, 0.02711079203124557, 0.011692755473112422, 0.037710821987794976, 0.035884694262806854, 0.055504371478621445, 0.010080400205749487, 0.020953848392569592, 0.05377381880368505, 0.0055504088190251166, 0.04960217193833419, 0.03357448608481458, 0.0256855377062623, 0.05690805687169943, 0.012422168743796647, 0.05166420593325581, 0.0208676218587373, 0.056558733473398855, 0.03619744123092719, 0.02709124343735831, 0.05056956949244652, 0.022852346966309205, 0.0276601000555924, 0.02057127338568015, 0.046863211052758355, 0.05326858162879944, 0.03923978530136602, 0.050477482112390656, 0.07279635806168828, 0.02688475844583341, 0.02560103465137737, 0.015410164703748055, 0.010834966769575008, 0.0346295435779861, 0.0498452028259635, 0.040411262440362146, 0.04910019173153809, 0.03561963134312204, 0.020824982718165432, 0.050073784310370684, 0.021226359930421625, 0.026292304075988274, 0.014828205574303865, 0.03609944720353399, 0.02784522476473025, 0.07814857443528515, 0.03159661418093102, 0.039218014505292685, 0.02567066252231598, 0.06539871823042631, 0.046983064085777314, 0.05328981977488313, 0.014290386844160301, 0.05035307950207165, 0.022751604872090474, 0.04495688388124108, 0.017411371426922933, 0.06586974366967167, 0.08664613988782678, 0.05061082781425544, 0.07515010783182723, 0.033530401664652994, 0.022263604183016077, 0.06452195599142994, 0.0341337889299861, 0.03427706499184881, 0.011912135174497962, 0.03868645017168351, 0.0498133218581123, 0.036929064829434664, 0.039787736255675554, 0.010157332506163843, 0.03628394426777959, 0.056054659986070225, 0.06402718182653189, 0.031390946824103594, 0.1143398681389434, 0.028657980795417513, 0.03424659876951149, 0.031876445415296724, 0.00703290308592841, 0.036733684063489945, 0.011508318628849728, 0.006750222004484385, 0.030710569582879543, 0.07299667516989367, 0.015835439919361045, 0.06588379612990788, 0.0662234639748931, 0.02432719711214304, 0.0417239461094141, 0.0169816738593259, 0.1233312985194581, 0.039106012122439485, 0.0025458915915805846, 0.05318088437031422, 0.042262903082051446, 0.07079143635928631, 0.016305332205125263, 0.03688593714364937, 0.019085553108847568, 0.021940438309684396, 0.022249324413548623, 0.01785293996467122, 0.0026905925769824535, 0.04275082404326115, 0.006897752480914018, 0.022446460888854096, 0.0479864816713546, 0.014944462371723992, 0.00453406641359574, 0.08229255064257554, 0.021099193986239176, 0.08362665905484132, 0.07263808298323836, 0.014335958952350276, 0.08075976039149932, 0.02915355223896248, 0.03573461249470711, 0.05251474279378142, 0.061028389526265006, 0.035005163600934405, 0.07942322282386677, 0.04177868013669338, 0.030378497937428098, 0.013562378989133452, 0.06894939698811088, 0.019980091268994978, 0.030706091251756464, 0.027561670069449713, 0.062000960909894536, 0.026984363993895904, 0.018093484021457176, 0.05230246989854744, 0.02682832468833242, 0.05190701290432896, 0.05955828234021153, 0.04690659997452583, 0.032448823630277596, 0.02947954081797174, 0.0063949436132263926, 0.04388056110058512, 0.0660701896995306, 0.04986796089048896, 0.022978457788537656, 0.054204013398183246, 0.023043454657973986, 0.01567574670272214, 0.028903427267713205, 0.01250829010470105, 0.030599992123565505, 0.07692335732281208, 0.04860171276543822, 0.04383229351203356, 0.05934033689222165, 0.05717852432280779, 0.015908114412533383, 0.024558531752388393, 0.051580810586788824, 0.03436182080102818, 0.06631820781954698, 0.06181962242616074, 0.04607755571071591, 0.03280653711408377, 0.03276402350249035, 0.06735939266426222, 0.09473015860255275, 0.04060628019007189, 0.07382502393530947, 0.05502174648323229, 0.03191847048167672, 0.025035994792623178, 0.032484877588493485, 0.008424581377767026, 0.011169477748418493, 0.02934917388483882, 0.012337715730869343, 0.1989117536161627, 0.16373853385448456, 0.10970105669860329, 0.24099034283842358, 0.11682131141424179, 0.12300769159836428, 0.11264424305409193, 0.2355679523731981, 0.20654536757086003, 0.1130053661763668, 0.11085380627108471, 0.10758680264864649, 0.12627318208771093, 0.05978017686200993, 0.10570692137948104, 0.11796506361237594, 0.08984920515545777, 0.07885234417127711, 0.12344499384718281, 0.23094379050391062, 0.09475360877279725, 0.1629657367510455, 0.059792580482150824, 0.21854882846985543, 0.10331539756485394, 0.09908666554838419, 0.07993847517562763, 0.22317026262836798, 0.14477048095847878, 0.11237589602491685, 0.11160994533981596, 0.10920369731528418, 0.11847639403172902, 0.12885400360184057, 0.16409161633678845, 0.2031888041113104, 0.1740296980632203, 0.09423033613711596, 0.13926855261836732, 0.14281422378761427, 0.1057154777060662, 0.1168362663260528, 0.06504145597240754, 0.09922974822776658, 0.12169872969388962, 0.11839144144739423, 0.09117434333477702, 0.06507483989532505, 0.10229211925928082, 0.15317459856825216, 0.132864810526371, 0.13447998171406134, 0.10735017034624304, 0.10137898754328489, 0.12847135056342396, 0.14327132568827697, 0.09761451597192458, 0.13893417056117738, 0.13907214387186936, 0.13501416519284248, 0.14913009559469564, 0.11021359491028956, 0.13188184398625577, 0.10242410110575811, 0.09172804826604468, 0.17684803397527762, 0.11590725689062051, 0.1350489876099995, 0.10936020141733543, 0.10207745113543101, 0.14071565068193845, 0.08616587958697762, 0.09625760199768202, 0.1744364933776004, 0.10325905201690537, 0.184458143476929, 0.1336293566439833, 0.1608613689563104, 0.1427356494324548, 0.10179146219577108, 0.16869519145361014, 0.1443059016019106, 0.18949306330510549, 0.10998256730714015, 0.17491518626255648, 0.09450266616685049, 0.14050292995359215, 0.13005292069699081, 0.12526790531618254, 0.13539402266698225, 0.19190066839967454, 0.3141958846577576, 0.16335433375622543, 0.10026113502681255, 0.15768089890480042, 0.1605362556874752, 0.25312113761901855, 0.11203648602323872, 0.11665870728237288, 0.08229231315531901, 0.12117057160607406, 0.1111377121082374, 0.08820534550717898, 0.14559780513601644, 0.11644315027764865, 0.10755505399512393, 0.13429174252918788, 0.08475428926093237, 0.21760992599385126, 0.14362512741770062, 0.27625226069773945, 0.10733195846634251, 0.1331109016069344, 0.1351125527705465, 0.1618858618395669, 0.23466031679085322, 0.0967592429369688, 0.2099781305130039, 0.08265017252415419, 0.13115727715194225, 0.167731766722032, 0.17019475384482316, 0.10194418007241828, 0.13169041568679468, 0.08420874032058887, 0.09040273366762058, 0.11489697253065449, 0.13369174115359783, 0.07361993672592299, 0.24267506386552537, 0.0884742285790188, 0.07674108246075255, 0.10076371234442506, 0.13834969406681402, 0.12842982422028268, 0.2186821877424206, 0.1254352999052831, 0.16038471167641027, 0.1140931663768632, 0.21875309465186937, 0.2467870403613363, 0.13402388404522622, 0.1537980365433863, 0.09599829984030553, 0.22272346088928835, 0.0956380588135549, 0.22703062476856367, 0.08624829445034266, 0.0890410699482475, 0.07770634602223124, 0.11885171889194421, 0.11824513572667326, 0.15976153154458317, 0.1625192199966737, 0.17387961968779564, 0.14763464512569563, 0.11049050505139998, 0.11680718431515352, 0.20600902635071958, 0.161841037816235, 0.1183640964861427, 0.12680241226085595, 0.11806004494428635, 0.12112540831523282, 0.15650114363857678, 0.1954301768647773, 0.1354614690478359, 0.22332365225468362, 0.17504257442695753, 0.09415015365396227, 0.1653002771948065, 0.09436410931604249, 0.1949067006685904, 0.16201827116310596, 0.17675754454519066, 0.08290511170136076], [0.014720991952344775, 0.027174935642895953, 0.04211257364866989, 0.033617542524422915, 0.05930799112788268, 0.04639878097389426, 0.03393732929336173, 0.022000069663460766, 0.09925538328077112, 0.03985039896464773, 0.019904636478583728, 0.06328297140342848, 0.029621015369359936, 0.08111220505088568, 0.06991164106875658, 0.07546857145747968, 0.005897635544118072, 0.014543670395921384, 0.09437719825655222, 0.03591468211795602, 0.02098284219391644, 0.05209328094497323, 0.011249022408654647, 0.0032260830838432802, 0.010131565986999443, 0.027850698845993196, 0.03440959305901613, 0.011356414994224906, 0.06210988613643816, 0.015577328590942281, 0.023160985404891626, 0.01957103982567787, 0.020671138473387276, 0.02311455155722797, 0.024040349825684513, 0.04139777093327471, 0.03893172022487436, 0.016153669450432062, 0.020215368197698678, 0.05234510564644422, 0.06887479884816067, 0.011738232586399784, 0.016631790669634938, 0.05673814152500459, 0.08214473857411317, 0.019726176679666554, 0.04815019860065409, 0.013065598056917744, 0.02139295045552509, 0.017722115020400712, 0.04834464638094817, 0.03829975306455578, 0.04834214597940445, 0.04577812159966145, 0.03425100924713271, 0.05737046830888305, 0.07001649508518831, 0.03016097318114979, 0.010495511814951897, 0.018979564242597138, 0.026303191170362488, 0.0363099457296942, 0.06699389299111706, 0.029582335480621884, 0.051179046609572, 0.03899841003918222, 0.05685964339811887, 0.10482413374951907, 0.04967949100370918, 0.022796316937144314, 0.04881982784718275, 0.10025014275951044, 0.01822624448686838, 0.017211797314562967, 0.016556910937651992, 0.04027487350893872, 0.010727595388224083, 0.10318022660378899, 0.014980161795392632, 0.015766475316403166, 0.03379087768761175, 0.021090685157105327, 0.052369414163487296, 0.026068784462820207, 0.050530604619000635, 0.01421477344618844, 0.032631017068134885, 0.04553614244131105, 0.06364444736391306, 0.049339416037712774, 0.01673486183530518, 0.022488184007150785, 0.03859793867117592, 0.026320717729894177, 0.03206347002248679, 0.03172734413029892, 0.15171498831893715, 0.004300899728800037, 0.04573231709322759, 0.016006096565563763, 0.08380655225898538, 0.0489932037224727, 0.016709471054907356, 0.035552731182958396, 0.06013337469526699, 0.04779783197279487, 0.014119043181251203, 0.02056863049178251, 0.03273645801735776, 0.0402002312642123, 0.02186203867729221, 0.019539264030754566, 0.04797763018203633, 0.006325345004110464, 0.013516512566379138, 0.012198884073378784, 0.030486198408263068, 0.01699685099135552, 0.03775789535471371, 0.03500200841309769, 0.08489727694541216, 0.03526464217741575, 0.042821439182651896, 0.026753835113985196, 0.033086191929344616, 0.03579956865204232, 0.05526961871821966, 0.0863270927220583, 0.029551502849374498, 0.043919590434857776, 0.0966361431138856, 0.06918480792748076, 0.09733149223029613, 0.026977419187980037, 0.0268383008494441, 0.03587746786485825, 0.0868741072980421, 0.02326664518165801, 0.020397490389379005, 0.029304692521691322, 0.03662829739706857, 0.0383991957642138, 0.046205150828297646, 0.0073739962785371715, 0.05343089059793523, 0.021294695192149708, 0.026780776346900632, 0.02251149168504136, 0.06305168595697198, 0.03958779912708061, 0.049912320117333105, 0.023021660113175, 0.06517034369919981, 0.029807639640889, 0.03211164940148592, 0.05607116874307394, 0.03335623190339122, 0.02162145560474268, 0.06119374851030963, 0.021967538998329213, 0.008898264129779168, 0.01682210956434054, 0.05885648714112384, 0.05568277869107468, 0.027133451708193337, 0.022955826949328184, 0.03228725426431213, 0.06666880007833242, 0.0635727329977921, 0.026962074118533304, 0.030579191632568836, 0.047564571989434104, 0.03392876618142639, 0.037569595101688585, 0.02552840087030615, 0.018053301177652817, 0.09869600579674755, 0.050947432073631456, 0.04639612790197134, 0.04458911111578345, 0.02272618016494172, 0.004419117916508445, 0.006388585740101657, 0.028829931747168303, 0.10100904346576758, 0.08112608787736722, 0.04662922503692763, 0.08916237165353127, 0.012462785001844168, 0.0889202296467764, 0.05275584664195776, 0.033723631474588595, 0.06192780126418386, 0.025826240424066782, 0.03472194308415055, 0.026960873111550297, 0.027931444513212358, 0.06030087784997054, 0.02654548584749656, 0.06583456841430493, 0.022924047761729786, 0.0364808856642672, 0.01989638040374432, 0.02082704546462212, 0.02280545510750796, 0.041029845497437885, 0.04452662482591612, 0.02963791089132428, 0.04297864217577236, 0.03171544262607183, 0.03757177319909845, 0.046336718768413575, 0.018948624742084315, 0.012322600515160178, 0.037422688877476115, 0.04482017603835889, 0.03760004775332553, 0.02303434193267354, 0.027101016037964394, 0.02366254661631371, 0.07397452555596828, 0.053127256355115345, 0.06269899023962872, 0.01618393211226378, 0.051340368310255666, 0.022356833198240826, 0.1316914199186223, 0.07053978807692017, 0.025987708009779453, 0.03928012420822467, 0.028029679420537183, 0.05552846625713365, 0.05236520046102149, 0.07615676881479365, 0.027902903633990457, 0.06442309343921286, 0.019836862704583576, 0.03241282395486321, 0.02248409074465079, 0.02796115756167897, 0.015194670463513051, 0.023732025209548216, 0.011473089938850274, 0.01853015862538346, 0.038351308155272684, 0.0212562680577061, 0.04848017357289791, 0.10226857409413372, 0.008048188673066241, 0.009953218146360346, 0.0060713807969088, 0.019424997037276626, 0.049939787214887996, 0.048627222289464304, 0.022499379834958484, 0.028665013810885803, 0.027582302623029267, 0.03580852531428848, 0.06613763608038425, 0.024772421257304292, 0.06465146118508917, 0.0033522019636750755, 0.04225018055045179, 0.05921659924622093, 0.05727215537003108, 0.014955539455903428, 0.019174268169860755, 0.04395772749558091, 0.04386638311137046, 0.05380360309832862, 0.027349607520071522, 0.04713376332074404, 0.05189003595816238, 0.04800396412611008, 0.03926410060375929, 0.05374651116185954, 0.04283933215109365, 0.035671318748167584, 0.04041998161535178, 0.05864947967763458, 0.025473612560225383, 0.026458450160654526, 0.026663155694093024, 0.04165859979444316, 0.025550502452201078, 0.03683910465666226, 0.06951862001525504, 0.03191841959155031, 0.03495953890628048, 0.06345279514789581, 0.016442650729524236, 0.013311543252452143, 0.05531377777723329, 0.0225026843004993, 0.017453225163210715, 0.046268624386617115, 0.06106618392680373, 0.038116270410163064, 0.03238574701494404, 0.026857386343181133, 0.04310932123501386, 0.03409307004351701, 0.05105298158845731, 0.04098009191719549, 0.05483018586944256, 0.015418098474453603, 0.04445231167067375, 0.0518657240484442, 0.03917838466752853, 0.02140027184837631, 0.0389803474369858, 0.011381119606085122, 0.05300089617126754, 0.09446081412690026, 0.05549904837140015, 0.06719965195017201, 0.026971025691766824, 0.014329227884965283, 0.02791344128283007, 0.029540781996079853, 0.01926050997073097, 0.03326358812462006, 0.045662723149039915, 0.025095456512644887, 0.048898558265396526, 0.01850457615884287, 0.04193698235654405, 0.009410524990276566, 0.014541582204401493, 0.04677226021885872, 0.020244903130722896, 0.07102295929299933, 0.05124449131212064, 0.007403210603765079, 0.06017972542239087, 0.05378334543534687, 0.029548347661537782, 0.03961273528901594, 0.020458366854914596, 0.03625029571620481, 0.052483401261270046, 0.01215674789688949, 0.013344695625294532, 0.03579206405473607, 0.019470224788944637, 0.03373274080721395, 0.03169686094458614, 0.03017645056492516, 0.08424297241227967, 0.09621773806533643, 0.005106425968863602, 0.023715750547125936, 0.12109194296811308, 0.1699078149561371, 0.13044633530080318, 0.22682893701962062, 0.1303648432450635, 0.11750272342136928, 0.12054013114954744, 0.1306123999612672, 0.1976898748959814, 0.19155149427907808, 0.25490408337541987, 0.3259837478399277, 0.14158219418355397, 0.21235535080943788, 0.09799716222499098, 0.12643368276102201, 0.09786513966641255, 0.0660732498924647, 0.13743231472160133, 0.13370922021567822, 0.14223945034401758, 0.18564731680921145, 0.12410750186869077, 0.12767107279172965, 0.08903141439493213, 0.10518989126597132, 0.09385932675961937, 0.10604484538946833, 0.1289438416383096, 0.1534099280834198, 0.11768960553620543, 0.09997131914964744, 0.1590452835495983, 0.06630824692547321, 0.07506005266415221, 0.14914880959050997, 0.10447303258946963, 0.09125068530972515, 0.087467954361013, 0.11788940695779664, 0.29574065495814594, 0.16494160358394894, 0.16184167563915253, 0.09621591959148645, 0.2227870531912361, 0.16226657426783017, 0.09004108807338135, 0.07097280198442084, 0.10453572922519275, 0.19719690563423292, 0.32224157292928013, 0.1588461742337261, 0.10259116999804974, 0.16387973699186528, 0.13640053437224456, 0.1383821687528065, 0.09747640695422888, 0.1812958445932184, 0.08264286470200334, 0.10376859110380922, 0.09712171634393078, 0.13281614599483355, 0.15600465956543172, 0.08950339656855379, 0.1093951595414962, 0.1437314674258232, 0.0911167221409934, 0.2172724362462759, 0.1629922403288739, 0.0784728666767478, 0.21197849246008055, 0.26172479880707605, 0.09386107059461729, 0.17119399165468557, 0.11971508684967246, 0.1544747395174844, 0.11604546090321881, 0.2202838696539402, 0.10787007744823184, 0.13410544395446777, 0.08627898458923612, 0.20864765904843807, 0.13738511582570417, 0.2095095749412264, 0.14766631914036615, 0.11958069620387894, 0.18637086584099702, 0.1369998436421156, 0.1258160394749471, 0.098298872821033, 0.07057195742215429, 0.10561131579535347, 0.15305095591715404, 0.10341744923165866, 0.10736687587840216, 0.19117813717041696, 0.29009646496602465, 0.16340347326227597, 0.13731665164232254, 0.11779965034552983, 0.1344799410019602, 0.09517552184739284, 0.11034167518040963, 0.1817851226244654, 0.08520423261714832, 0.10750391959611859, 0.12464183462517602, 0.09533517435193062, 0.16281595693102904, 0.10432300849684648, 0.14821975944297655, 0.06280416316751923, 0.08649664505251817, 0.12174811347254685, 0.07892216542469603, 0.10977333424878971, 0.07383474734212671, 0.12131072979952608, 0.11367730583463397, 0.10150855380509581, 0.18462209110813482, 0.13527818316859858, 0.12160218773143631, 0.16339130034404142, 0.11962505882339818, 0.06620151336703982, 0.11857402165021215, 0.10216102629367795, 0.1323468576052359, 0.14561923327190535, 0.18336289296192781, 0.138373089954257, 0.14159055373498372, 0.11158209826265063, 0.11884990041809422, 0.09228625866983618, 0.2683931424149445, 0.12580682496939385, 0.22539022564888, 0.28280120928372654, 0.1301399360277823, 0.07057314485843692, 0.13932432819690022, 0.21197058074176311, 0.22382937797478267, 0.05968006580535855, 0.11926629021763802, 0.09757360031030007, 0.1578343292432172, 0.07993794591831309, 0.11002607497253589, 0.09120364247688226, 0.21505096687802247, 0.13887810999793665, 0.0824182288987296, 0.11241052845226866, 0.14206389976399286, 0.06990739343953983, 0.12052153929003648, 0.11809854502124445, 0.11207447719893285, 0.11469466052949429, 0.11004744204027311, 0.15643890840666635, 0.1096891009115747, 0.09445706861359732, 0.16262554643409594, 0.26629047095775604, 0.12015462826405253, 0.08748361494924341, 0.11112327966839075, 0.13989638750042233, 0.21344749363405363, 0.19663445438657487, 0.19882262125611305, 0.18448886754257338], [0.084044100583664, 0.050590417480894496, 0.03036074067599007, 0.017072407562019568, 0.021678895290408815, 0.020008915436587164, 0.03546941726069365, 0.11670104786753654, 0.07604099716991186, 0.057381270586379936, 0.01830068147475166, 0.03722555749118328, 0.026695581186296682, 0.03518031384529812, 0.005577851743769965, 0.03342523552211268, 0.04529202250497682, 0.029426794898297106, 0.03373477980494499, 0.037095804632242234, 0.018937374631475126, 0.07678416264908654, 0.02834360534325242, 0.03889773240579026, 0.02810218258361731, 0.04630922792213304, 0.03146627099652376, 0.014095829650094467, 0.019467819382303526, 0.038047219293990305, 0.010319166500786585, 0.030914767911391597, 0.031039374082216194, 0.10063821050737586, 0.06029393643672977, 0.020708919303225617, 0.019009435050455586, 0.013742006716451474, 0.032976282827023945, 0.05346783682970064, 0.04871987624626074, 0.03190899134746619, 0.025336782581039836, 0.03922507126948663, 0.04114357814458864, 0.05593151266553572, 0.013142294566413122, 0.06883140653371811, 0.022296402869479995, 0.06478738532002483, 0.04970399968858276, 0.02319737184526665, 0.06328278819897346, 0.04433554597198963, 0.04712968532528196, 0.03911880250754101, 0.03474219056910702, 0.004843799413980118, 0.01804222578981093, 0.04632000305822917, 0.03222173492291144, 0.03485288337937423, 0.0029825280279120697, 0.020270555147102902, 0.03232731157913804, 0.06500862844820533, 0.07585843053779431, 0.03971536710326161, 0.044584134061421664, 0.08152372975434576, 0.02935911442286202, 0.014849742275795766, 0.03760313169498529, 0.07068423461169004, 0.050168521369674375, 0.06348579909120287, 0.026484497423682894, 0.011544746629494642, 0.05169207675914679, 0.025892265274056366, 0.00731056512865637, 0.09151460829057864, 0.032379663948501856, 0.01680728018150798, 0.012222317280247808, 0.05054974609187671, 0.030538703448006084, 0.001088127911706189, 0.03793762231777821, 0.04314105971051114, 0.06356136753622975, 0.030823901894369295, 0.04619552920173321, 0.031146216206252575, 0.04564785983945642, 0.04292227966444833, 0.02964826872838395, 0.05870611699564116, 0.027623873070946763, 0.03892572197530951, 0.02154092876506703, 0.06963996243263994, 0.023242833691516092, 0.010316052025050988, 0.02688402562801327, 0.06354945924665246, 0.04630246292799711, 0.04969508034576263, 0.048693447307284386, 0.05025604220905474, 0.041966702190360854, 0.020003522779526453, 0.010114249773323536, 0.05084344318934849, 0.05267463617825082, 0.05822295256491218, 0.03970351988183601, 0.029144738069070236, 0.03746431700087019, 0.052884395101240704, 0.01000649671602462, 0.033439861344439645, 0.026097810494580438, 0.025807634993855442, 0.10547849256545305, 0.06739990799022572, 0.019182712538167834, 0.027273357147350907, 0.03527372097596526, 0.05279682676440903, 0.008208147366531193, 0.021721766829224567, 0.04371964652091265, 0.010193649396699454, 0.015187003017802323, 0.05450961539255721, 0.033552515120910745, 0.015331276526142443, 0.027805467701650093, 0.021223613559933643, 0.03441621556079813, 0.01811389096214303, 0.06479572451540402, 0.04356029935713325, 0.029188866594008038, 0.03994827764108777, 0.12788373923727445, 0.02433103253133595, 0.04502644729135292, 0.014290855033323169, 0.05370459466108254, 0.03481251054576465, 0.04468748173011201, 0.011657647223078778, 0.030676198391509906, 0.02701348502055875, 0.011438449029810727, 0.02552867228431361, 0.0309915780755026, 0.05478398781269789, 0.008456734607794454, 0.04610831370311124, 0.04472872308854546, 0.04577733789171491, 0.029197144721235548, 0.037825087284935374, 0.020258010730945637, 0.018881444686225483, 0.059128070782337866, 0.009662467587207044, 0.020307837253702537, 0.043352844060531685, 0.04845509831128376, 0.07221212583993163, 0.09939111742590155, 0.13928276114165783, 0.02562415912481291, 0.008390427317603357, 0.021722172253898213, 0.02427098896753575, 0.041239628169153414, 0.009278031698028957, 0.031647707867835245, 0.06988625707370894, 0.03686134364189846, 0.03803899884223938, 0.03657625376113823, 0.027337139439103857, 0.027328857919201255, 0.0269570817971336, 0.07463737284498555, 0.02136562924299921, 0.04260568879544735, 0.05053907612870846, 0.03619637253827282, 0.030034104096038, 0.029166637786797116, 0.05426271006997142, 0.043444022203662565, 0.029767619645489112, 0.0591093296451228, 0.014531631488353014, 0.047900691096271784, 0.009295744854690773, 0.04842891703758921, 0.04458331981939929, 0.023001851979643106, 0.024763695296964476, 0.016965005646592805, 0.060655602387019565, 0.03145355525027428, 0.03415831118556006, 0.03506707992138607, 0.03817240561225584, 0.018652893735894134, 0.02480134041979909, 0.06496919199292149, 0.03819128245647464, 0.017836651731548563, 0.041640123285885365, 0.022911191219463944, 0.06958507573498146, 0.0301053434876459, 0.0246352367435715, 0.023307038371318152, 0.06565022402043853, 0.03834701642127974, 0.0632925998153431, 0.04166065914822476, 0.048356205224990845, 0.02028687561063894, 0.06815380110804524, 0.010503384517505765, 0.0121390211695273, 0.01593276558976088, 0.0016284475734989557, 0.10095670127442904, 0.020993454481608102, 0.005448360544895487, 0.023193858730207597, 0.041616724005767276, 0.06165912175284965, 0.02857288232605372, 0.028573754243552685, 0.043153945090515275, 0.034147888887673616, 0.06294402959091322, 0.02376889849879912, 0.08951551520398685, 0.01846998105091708, 0.029883391290370907, 0.001963851462018543, 0.006200386419160557, 0.011825225864803153, 0.02453446581161448, 0.04985570315537708, 0.006169883725565991, 0.05667248647660017, 0.12587838327246054, 0.03963791572355798, 0.04186477265985949, 0.05689295607485941, 0.059649077111056874, 0.03479708744479077, 0.07772596246962037, 0.028974198470158235, 0.040310130188507695, 0.06174407433718443, 0.01876806657362197, 0.016156308951654604, 0.06902286875993013, 0.010978909492093538, 0.020458723085799387, 0.03960204157712204, 0.009359013156167098, 0.04048140260523983, 0.09008964403931584, 0.018612174849425043, 0.011736411568043488, 0.020638326216222982, 0.02362551217499588, 0.013401489006355405, 0.013868601843049484, 0.02266457088158599, 0.04293824898611222, 0.039457618791077814, 0.023961380223876665, 0.03361234494618007, 0.03097005494471107, 0.046193944822464666, 0.05445216043985315, 0.020933599211275578, 0.01441261644608208, 0.044260421967399974, 0.022102414796661054, 0.1334796039653676, 0.027555955108255148, 0.03491800917046411, 0.032792952843010426, 0.02845726504788867, 0.029726466496608088, 0.05974196855510984, 0.017630034425695027, 0.008761194966999548, 0.05678329463782055, 0.05303094509456839, 0.029720956792256663, 0.008502562862953969, 0.044864752396409, 0.03567298794431346, 0.03967141839010375, 0.01636182703077793, 0.016634799972442642, 0.013702344648273928, 0.053471680730581284, 0.0016307658307986067, 0.013888233557476528, 0.02005661984107324, 0.0136930088545861, 0.037071957519011836, 0.03543427593207785, 0.012172555218317678, 0.047323586884886026, 0.010963641606005175, 0.010784979942919952, 0.04457043783207025, 0.12313664039330822, 0.055009671952575445, 0.030747563312096254, 0.04960649081372789, 0.024686908881579126, 0.05947957227804831, 0.016505206569230983, 0.04305826826021075, 0.04953952619273748, 0.05844498957906451, 0.05050360571060862, 0.04879203505281891, 0.060839756791080744, 0.07346092204430274, 0.025327866630894796, 0.035632204597017596, 0.018706830484526496, 0.010985640559478529, 0.07316241413354874, 0.040002329740673304, 0.03164412181026169, 0.00968296782645796, 0.03055025211402348, 0.03653305143650089, 0.014708715557519878, 0.04371149052998849, 0.12587049869554384, 0.07920213575874056, 0.11322911309876613, 0.12230573355087213, 0.1851657333650759, 0.15797250611441477, 0.08893240256501095, 0.13513191815997871, 0.15264238284102508, 0.12890292597668512, 0.06989479304424354, 0.09208472698394742, 0.1460343881377152, 0.09376702564103262, 0.15464064132954392, 0.09049476337219987, 0.17481991994593823, 0.09649262617209128, 0.14284311580870832, 0.0778998981363007, 0.16587123727159842, 0.18223296930747374, 0.12629245248224052, 0.09870772409651961, 0.13827481094215596, 0.19460316481334822, 0.18593665771186352, 0.08380964637867042, 0.12252838803189141, 0.22181916369923524, 0.10482549760490656, 0.1191158861454044, 0.10143103796456542, 0.14471888515566075, 0.12631588908178465, 0.09528748691082001, 0.23133465381605284, 0.13612282355981214, 0.08158719313463994, 0.13173894451132842, 0.12774702800171717, 0.1635526152593749, 0.10535766583468233, 0.09016804876072065, 0.10216045632426228, 0.21528468147984572, 0.0769796689440097, 0.166737237945199, 0.06993108788239104, 0.19129401738090174, 0.1716275212488004, 0.14235542554940495, 0.22158521839550563, 0.07573546642171484, 0.16356652522725718, 0.11881211958825588, 0.12848044293267386, 0.1483039113559893, 0.08945670657392059, 0.10821464431605168, 0.15628226181226118, 0.17364225456757204, 0.10840707006199019, 0.14028393956167357, 0.18296578712761402, 0.1951527374663523, 0.15867530554533005, 0.07461143245122262, 0.1296100951731205, 0.2318338384585721, 0.08676784192877156, 0.08928472508809396, 0.17457777793918336, 0.166251379730446, 0.1894153439040695, 0.0922950864104288, 0.08186959262405123, 0.10371698851564101, 0.1240369477974517, 0.12968864238687924, 0.07038441034299986, 0.20662683248519897, 0.1624157569770302, 0.17504466431481497, 0.12965300572769983, 0.16938560083508492, 0.14554904560957635, 0.0888923215014594, 0.17683572535003933, 0.19982666309390748, 0.16562547188784393, 0.12339601718953677, 0.11514789478055068, 0.28970288751380785, 0.08689914524023022, 0.1311323477753571, 0.19040888201977524, 0.15666302852332592, 0.1020103847341878, 0.10183114970901183, 0.17279139879558766, 0.11000635674489395, 0.1119301663711667, 0.1556535041225808, 0.15917732646422728, 0.14098117500543594, 0.09274334021444831, 0.17731631813304766, 0.08510154991277627, 0.17237674604569161, 0.12743672036698886, 0.16851656032460077, 0.10656579743538584, 0.203337498275297, 0.20199585812432425, 0.12224864161440305, 0.11214777933699743, 0.08386896391000066, 0.09320598574621336, 0.28929717785545755, 0.05513504486797111, 0.11139576576117959, 0.11420573533645698, 0.125032833644322, 0.14834855896021637, 0.15840680923845085, 0.07386862659560782, 0.0720582137416516, 0.11210363384868417, 0.1525781662868602, 0.15410512792212622, 0.10260842514357396, 0.13588066798235687, 0.10956393834203482, 0.1767637599259615, 0.17648860040519918, 0.11471074180943625, 0.09644805320671626, 0.0934324875207884, 0.1453605214399951, 0.11848201230168343, 0.08709638858480112, 0.2167686375656298, 0.1245187483727932, 0.14757584328097956, 0.10893697198480368, 0.14986741888735974, 0.10445490891912154, 0.16595435781138285, 0.09054362467889275, 0.19917393954736845, 0.21090940625539847, 0.13905496336519718, 0.1340001081781728, 0.08953182718583516, 0.15803886683923857, 0.09591274335980415, 0.11141879523971251, 0.1160086707345077, 0.15756663360766002, 0.12185640766152314, 0.15244438632258347, 0.15180359142167227, 0.14589057942586287, 0.11883893529219286, 0.10338245718074696, 0.11909729428589344, 0.09142930286803416, 0.19797430320509843, 0.15941895278436796, 0.10823529892201934, 0.1678311178194625, 0.14519736090941088, 0.1594772660838706, 0.21380695434553282, 0.3144125816013132], [0.03297283586912921, 0.03852313697072012, 0.010859448313047844, 0.09567121881991625, 0.03244351070108158, 0.03642503883955734, 0.013835354475304484, 0.06031592097133398, 0.017845588037744164, 0.07208530085959605, 0.047297425967242034, 0.07329403635646616, 0.0654896419229252, 0.07328081849430289, 0.012574627928967987, 0.04370391129383019, 0.018397113175264428, 0.004622609296347946, 0.031313424198223014, 0.050653019121715, 0.02397931051174445, 0.07516340711819273, 0.02836687570171697, 0.032136646631572924, 0.06015348647321973, 0.021532140040237988, 0.1323791423014232, 0.03817565918767026, 0.04043169652244874, 0.054405114214335165, 0.06787516748798744, 0.08789691741445235, 0.04589848692661949, 0.04089671353410397, 0.021692574556384767, 0.030299957509019544, 0.060665875407201905, 0.031340568991644044, 0.04239380266517401, 0.015359530724318964, 0.03309000529614942, 0.007458392464156661, 0.0930240840784141, 0.03295154344024403, 0.013232758551436876, 0.04380267206579447, 0.05708287124122892, 0.06529702618718147, 0.07874644521091666, 0.037758672277310064, 0.02819386453899954, 0.038753357117197344, 0.04967711613114391, 0.012021077364417059, 0.028191813666905676, 0.03993349575570651, 0.017060801220525588, 0.04844527651688882, 0.009262471193713801, 0.021815764285357933, 0.04421562847814389, 0.02631278056651354, 0.027226936870387623, 0.03840096334793738, 0.02449148570719574, 0.01859835139475763, 0.06673520151525736, 0.05610775535127946, 0.026242011060406054, 0.02284980076365173, 0.0789247981405684, 0.038660866008805375, 0.03585603294361915, 0.029162722639739513, 0.01669172566783215, 0.03117243479937315, 0.013291417055630257, 0.05385765859058925, 0.031383479546223364, 0.008440345442587776, 0.0254340692356761, 0.04094100830012134, 0.043930043266820054, 0.025854587920808365, 0.052010771086705584, 0.01333978642443461, 0.006190201184446258, 0.04319645870210869, 0.054545258837086816, 0.03050701246996011, 0.032287284798387966, 0.05053828563541174, 0.014878216997853346, 0.053336988136704476, 0.026624272244849374, 0.04782934992441109, 0.08619924993919474, 0.03513009886124304, 0.023278658644163182, 0.012800789587864918, 0.05878072192094155, 0.03357165998646191, 0.02141146597984646, 0.03452557844242879, 0.049295083952269385, 0.023960118148741976, 0.0532182953985674, 0.025783893053552935, 0.06286727370960371, 0.00543300063249522, 0.02703064347484282, 0.020935171716181294, 0.01746308766970677, 0.024590633244120648, 0.03880844059001122, 0.027815230124230896, 0.03770168890644397, 0.1019391453425799, 0.03264771242226873, 0.049384765925684145, 0.06616536780659642, 0.043673923438681025, 0.050701500448797426, 0.08356753829866648, 0.02854867558926344, 0.07304198773843901, 0.03597019646050675, 0.024975978370223726, 0.030981128636215414, 0.008738877102067428, 0.028978340926447084, 0.023898444404559474, 0.013895332730109138, 0.07826820694442306, 0.021238558293719376, 0.03597534993397338, 0.02154443339843835, 0.010716941540262528, 0.03710236606587257, 0.041349876538983414, 0.04701433437211173, 0.018823597879548157, 0.029112517833709717, 0.022680762423468486, 0.026598213107458184, 0.04686630517244339, 0.02622786699794233, 0.03875658015853592, 0.012189132676992034, 0.044048542622476816, 0.07743755794529404, 0.026102631485887935, 0.02639736674193825, 0.04038326608549271, 0.02003852161578834, 0.019164371736613766, 0.030594831864748682, 0.031422919394182305, 0.039925448330385346, 0.03932396096310445, 0.03458238200151494, 0.080957614417587, 0.011071604160991098, 0.061985673515924385, 0.020445284699755054, 0.0057081376767850345, 0.047575479439858875, 0.012176008113393826, 0.04213133853461061, 0.03523752113272037, 0.017237272911838124, 0.03451757512188383, 0.025164874037727714, 0.026859997006665384, 0.048234849236905575, 0.02138592252906944, 0.038745479325630834, 0.057529320142098835, 0.05253414889531476, 0.038189043290913105, 0.016296350097815906, 0.03553639205970934, 0.03503888000601104, 0.01261912625549095, 0.03581966346661959, 0.04274359085996236, 0.03132487108398761, 0.026571714618642415, 0.0526946292125753, 0.015514094216216887, 0.02933473126696689, 0.062489261850714684, 0.010935346695727535, 0.01708272977599076, 0.04535577765532902, 0.0313879307359457, 0.03271609857412321, 0.06412329631192343, 0.042534642786319764, 0.01091112638823688, 0.017898028616660407, 0.057051326148211956, 0.08940187415906362, 0.052994063323629756, 0.013006653719847756, 0.07318675997001783, 0.025601509625890424, 0.027822575265807763, 0.05571877836648907, 0.023494977304445844, 0.019704080186784267, 0.045938886901629825, 0.022678681017298783, 0.019983249849506786, 0.03650227987340518, 0.0497940955683589, 0.018565591724057282, 0.011625487207701164, 0.01666812621988356, 0.007545285658644778, 0.044617473879562955, 0.02339183828527374, 0.019921842430319105, 0.0081937225602035, 0.07856265721576554, 0.03535954547779901, 0.022379167178379636, 0.0503152002846556, 0.031167620593415837, 0.03528367508468883, 0.05084093600245459, 0.045779346355370114, 0.05288831703364849, 0.013083269653309668, 0.039175137877464294, 0.03324853821790644, 0.04511365261194961, 0.02781143202446401, 0.06700679194182158, 0.04855905326881579, 0.04635592470211642, 0.040455262043646405, 0.034349552887891016, 0.021998069681493298, 0.010953063245064445, 0.044382324176175256, 0.07809421699494123, 0.02091723125028823, 0.06311236734368972, 0.0428356952033937, 0.039669579560203214, 0.056361856537738016, 0.05187703522720507, 0.04553265816399029, 0.03370667827714767, 0.02566568037894155, 0.027988953748717904, 0.0402930582474385, 0.08906561255987201, 0.03329638511474643, 0.007893896595175778, 0.01974714171540524, 0.01354645037957068, 0.04648066657994475, 0.049199597111770084, 0.027935061104861752, 0.04202667450798409, 0.05914468131959438, 0.039567996082561355, 0.08865774516016245, 0.03988461070028799, 0.05076127259859017, 0.027491565527660505, 0.04702917393296957, 0.024008545193022916, 0.02671455981076828, 0.04187409233834062, 0.012925187957340052, 0.07968186680227518, 0.03348001026149307, 0.07689920826149838, 0.04606180352025798, 0.023941653514547006, 0.10658411109553916, 0.0485182834922203, 0.04896281213898744, 0.08099686766841582, 0.027136825723573565, 0.02653990320063063, 0.011952195881998964, 0.017136379843577743, 0.044154163383479626, 0.02402485378219613, 0.061915479068245204, 0.04409102909266949, 0.028100747482052872, 0.09011042756693703, 0.04323263818930302, 0.04788212977083666, 0.026990036546651806, 0.03198517047400985, 0.07990490126290492, 0.027369609036083733, 0.032700614404997656, 0.023435907438397408, 0.05464157009763377, 0.006784805662131735, 0.014872917639357703, 0.02462016648080732, 0.016198819170572927, 0.03669316195217626, 0.021881185239180923, 0.05810242438954966, 0.0768044644168445, 0.0025140405216786477, 0.06151934353900807, 0.01630715067897524, 0.02289021261302488, 0.020554974974532212, 0.009740918957894402, 0.026258060109934638, 0.045979537934597046, 0.007545988790557853, 0.023079571380679096, 0.02625808216232274, 0.010504348885401018, 0.016775000574333326, 0.027149526202785115, 0.04077124562380569, 0.016187072033062577, 0.02106797119735607, 0.023766815396291868, 0.03232595790177584, 0.031052812468260527, 0.03576933652428644, 0.029634226446173022, 0.04115732865674155, 0.08170982476856027, 0.02595556410960853, 0.03736103379300662, 0.04660455011097448, 0.014408667372273547, 0.050593521778604815, 0.0107881436124444, 0.014906498337430614, 0.028210890678954974, 0.04105787917173334, 0.03826197562739253, 0.04825322057253548, 0.06291441832269941, 0.04754179356885808, 0.013448090791436178, 0.10495897222842489, 0.09791382455400058, 0.113891655047025, 0.13781270145305566, 0.11611011171979563, 0.10501129406371287, 0.11883588188460895, 0.1420124260974782, 0.19692839575665338, 0.18083174021116324, 0.21506369619497231, 0.1577560534434659, 0.18368461355566978, 0.21747496537864208, 0.13556423996176037, 0.24941196665167809, 0.08157572589282479, 0.12680812552571297, 0.15570291504263878, 0.1113001669624022, 0.1571890152990818, 0.17971271382910864, 0.15068623423576355, 0.07212982632751976, 0.17799341465745652, 0.10169572768998997, 0.1599623914808035, 0.13044776022434235, 0.10837662419570343, 0.10319349196340356, 0.19492255124662602, 0.19170215619461878, 0.1512047571263143, 0.11602230928838253, 0.06847309254642044, 0.2149344895567213, 0.08792095112481288, 0.0716025164084775, 0.10916808101215533, 0.1471745576709509, 0.11964242931987558, 0.09723862114229373, 0.16072112933865615, 0.1527571909661804, 0.09387500770390034, 0.1016508833106075, 0.10785090204860483, 0.15835647551076754, 0.1950935556420258, 0.09736060138259615, 0.17485015546636923, 0.1263666163597788, 0.18309321600411618, 0.1302089023270777, 0.21618165049169744, 0.10201832359390599, 0.1158657848302807, 0.1254928396748645, 0.08432251028716564, 0.13287884263055666, 0.1738717079694782, 0.10035491535173995, 0.09308481296258313, 0.18745306134223938, 0.15768149601561682, 0.20700512932879583, 0.2755779597376074, 0.1477279979735613, 0.06231424731335469, 0.12627947889268398, 0.21029340502406868, 0.158718311094812, 0.24834587957177842, 0.15520575243447507, 0.1540304347872734, 0.15238843432494573, 0.11087648291140795, 0.2169380406183856, 0.14758783978010925, 0.06832431695823159, 0.0684726107865572, 0.08760237893355743, 0.21364132394748075, 0.07217163087001868, 0.1063860874356968, 0.07410010203186955, 0.1202822064182588, 0.09677934114422117, 0.13850047811865807, 0.08947586840284721, 0.18673312211675303, 0.12312544456550054, 0.09194239069308553, 0.1339222394994327, 0.2167660862739597, 0.19423596880265645, 0.12618133558758668, 0.17473291818584713, 0.08806084468960762, 0.07715726191444056, 0.10551086547119276, 0.1141306215098926, 0.18733965099922248, 0.1313406444553818, 0.14939108730426856, 0.13002428651920386, 0.08525498703654323, 0.16363527439534664, 0.2520193053143365, 0.1556655006217105, 0.18411906595740998, 0.12270055950752326, 0.095576861740223, 0.15086956082710198, 0.1104049960683499, 0.16744698557470525, 0.1453926432877779, 0.2005037867597171, 0.12298296578228474, 0.13797341925757273, 0.17750834354332515, 0.11734474689832755, 0.15281574853828975, 0.14671162036912783, 0.062329840048083236, 0.1679515577852726, 0.1353385727852583, 0.12594212485211237, 0.10715711356273719, 0.21584227441677026, 0.17592700411166462, 0.1142629086971283, 0.10796119791588613, 0.17330077503408703, 0.11361175935183253, 0.10212918943060295, 0.17215463439268724, 0.20382867620459624, 0.10160221877907004, 0.15941423018063816, 0.10855781340173312, 0.12854391309831822, 0.1686837106410946, 0.10661711503884622, 0.17195115531129496, 0.13789835971380981, 0.08073606594864811, 0.0769448804536036, 0.07423337988023247, 0.09955342978771244, 0.2307247593998909, 0.15724696218967438, 0.10852628866476671, 0.08864615578204393, 0.0994407929746168, 0.1012764676873173, 0.09497469583792345, 0.10620936299008982, 0.08779715919601065, 0.07730162023965802, 0.23148129880428314, 0.23260012162583216, 0.1175001042761973, 0.08668801906917777, 0.10198179126850196, 0.08709733174847704, 0.11838373328958239, 0.08979889178382498, 0.09730733638363225, 0.10801866983196565, 0.12184780383748667, 0.16695147859198706, 0.07843251419918877, 0.070449000091425, 0.14733082428574562, 0.04139574211356895], [0.032898872159421444, 0.04094331531918474, 0.04019693697669676, 0.012397124864427107, 0.01798272505402565, 0.02903261354991368, 0.014078298001550138, 0.009960042512310403, 0.02658256100091551, 0.041117491865796704, 0.05191154551825353, 0.015019352281732219, 0.008641327515111437, 0.05513135703014476, 0.019618158993710364, 0.01770898367145232, 0.01519093512823539, 0.039727628231048584, 0.023758795112371445, 0.03562323097139597, 0.05938485557479518, 0.053164972724126916, 0.01414494710375688, 0.02573948972193258, 0.04725020671529429, 0.02335165544146938, 0.017062176950275898, 0.03956931583317263, 0.028286209762362496, 0.05460486135312489, 0.05607715002926333, 0.05051499831357172, 0.01763295042993767, 0.04546629743916648, 0.00961328312821154, 0.013854977708043796, 0.027381569912124957, 0.02621822331898979, 0.009381691492827875, 0.010361557127907872, 0.04904765955039433, 0.03773969704551356, 0.0797517423384956, 0.08694649341383151, 0.06218248259808336, 0.013417795051022299, 0.004855418478005699, 0.03810656735939639, 0.03086658174704228, 0.012922852948707129, 0.019337869748207073, 0.03158516390249133, 0.016541959418516074, 0.01838662980922631, 0.023021643149799535, 0.006013662063716245, 0.038827381895056794, 0.07430797123483249, 0.059379691923303266, 0.015483609334166561, 0.018030595699591295, 0.030050843554948057, 0.023481387944359864, 0.03881048298041735, 0.02525949913875333, 0.048599575380129476, 0.05936914748911347, 0.03759844641068152, 0.06832552475056478, 0.02955529246745365, 0.02705209027044475, 0.026296059767316495, 0.05611531423138721, 0.031621173755931, 0.028116097640512244, 0.04661671285118375, 0.060678143320339065, 0.04164131750751819, 0.06088028568774462, 0.01321167137939483, 0.014797562932861703, 0.03615423890628985, 0.06179724434124572, 0.03885517808209572, 0.01889309343615813, 0.05448212115360158, 0.029287949670106173, 0.01496564453866865, 0.04859415727800556, 0.010229448904283345, 0.04389480694330164, 0.025232861550258737, 0.05208798158647759, 0.06611774821898767, 0.04916556518790977, 0.025497537704982927, 0.04998764428975327, 0.02868280839174986, 0.02914657011362059, 0.02022885068851922, 0.014088233450560697, 0.0236675491157387, 0.027209654583462646, 0.020622677502355406, 0.03463056816586426, 0.0655107240059546, 0.03163292598245399, 0.01653706039568143, 0.042552590037563016, 0.05206861958972045, 0.016585234685667923, 0.020871414869491543, 0.110530457193298, 0.0499361197331122, 0.04003668396866747, 0.014197368174791336, 0.0019194411330058106, 0.012029088318480976, 0.03473063851041453, 0.01305393997712859, 0.02725741496708776, 0.08569192966180188, 0.03303355796794806, 0.03677037923729845, 0.032802299662892304, 0.037444293432469876, 0.03053963304098163, 0.04068579092355711, 0.010188523064633566, 0.018389447425891246, 0.022839249544111744, 0.027207993869004504, 0.0337241335905024, 0.033957705699971745, 0.0053477202309295535, 0.04020903864875436, 0.03639434530798878, 0.03964927439977016, 0.009839042755109923, 0.04304672637954354, 0.041389258711465766, 0.039557319334042926, 0.06280911647315536, 0.022602551084543978, 0.037176587618887424, 0.06737238660986934, 0.02053476820167686, 0.0531956051875438, 0.021121938480064273, 0.08304903576416628, 0.054725355601736476, 0.07488588629556553, 0.027431172518325702, 0.04495246661826968, 0.047639122631933005, 0.08967222965189389, 0.03844219452834555, 0.017209631091515933, 0.02028403933426099, 0.021989689774012992, 0.03992914295356188, 0.02271506406499871, 0.05633995342733605, 0.07810856801058565, 0.05925196449139288, 0.02905092042471681, 0.044319892169109414, 0.01420877265211727, 0.020039793868948306, 0.028051916709435836, 0.01354006621321397, 0.03785176728186863, 0.004744207860702383, 0.020359986062560762, 0.010446204371484262, 0.06081389103616987, 0.03349909745156765, 0.07104711513966322, 0.05743010475167206, 0.0286874054665012, 0.01846168765665165, 0.016125488194770048, 0.028866067129586424, 0.010563503568326789, 0.017911533159869056, 0.013353096736994172, 0.026808867696672678, 0.010120165750517376, 0.0874091728723475, 0.027187912625127604, 0.01055972243193537, 0.03760687042293804, 0.06821495068392583, 0.06089405994862318, 0.08515598199197225, 0.07368004814322505, 0.008910973090678453, 0.035466265465532026, 0.0579295065253973, 0.04890217824972101, 0.05241773264216525, 0.017880015208252838, 0.06758847965725831, 0.041745598161859174, 0.01442989703666951, 0.023933041208822812, 0.07178122896168913, 0.0216062835617257, 0.04670510560806308, 0.048225380280720334, 0.02353635267354548, 0.017905679098995667, 0.034344952420464585, 0.024083404568955302, 0.05255071872047015, 0.013073510623403957, 0.059510194563439915, 0.031167929326849322, 0.045834799629769156, 0.06830187101981469, 0.022358283566843187, 0.06761885088469301, 0.055302911038909636, 0.04244622288803969, 0.055403035666261397, 0.06220528816006013, 0.008963811460749378, 0.04816596096913729, 0.016691277834719846, 0.033993756265512536, 0.022883206738957336, 0.02752474249739732, 0.017677531877000417, 0.0398613098077476, 0.08766065830630915, 0.02184046635271183, 0.012623701277854187, 0.037727778577911, 0.024967573017680218, 0.03605655700500522, 0.05998322846634047, 0.03692928535331573, 0.02143717567170305, 0.014111984720719712, 0.04730943603707211, 0.02942595351487398, 0.0051814592193945175, 0.028396648121997714, 0.04402534690286432, 0.01496821957906442, 0.05019783747515508, 0.01142209888036762, 0.05093804793432355, 0.04960685043728777, 0.031240159379584447, 0.08576942514628172, 0.00430473726841488, 0.050295210643006225, 0.07475203847778694, 0.049577398624803336, 0.025140163488686085, 0.07126914536846535, 0.08481902828706162, 0.02470688325619059, 0.0646998950147203, 0.008714967224347805, 0.032913450484297106, 0.018132733879610896, 0.08238968971584525, 0.1065284644386598, 0.14092031041426317, 0.046198433331613026, 0.033601549454033375, 0.03314942121505737, 0.013059341964045805, 0.005933498664359961, 0.018001690107796873, 0.047646939355347834, 0.022062608539792042, 0.02723147118064974, 0.014610589215798038, 0.049709584031786234, 0.03708725169833217, 0.033161563599216085, 0.008002139894025666, 0.06324699547673975, 0.03299120381208403, 0.015400336124002934, 0.028841066506824324, 0.07768947085631744, 0.05282096564769745, 0.013529956889604884, 0.053870588075369596, 0.059226546569594314, 0.08179139824850218, 0.06693875523550169, 0.05134971173746245, 0.03147007757797837, 0.029048389489097253, 0.03942796681076288, 0.057759757419782023, 0.04598033521324396, 0.028155652839424353, 0.038524209056049585, 0.08757265909974064, 0.010374099847727587, 0.012475033407099545, 0.04385359611894403, 0.040005064236798456, 0.054021382305238924, 0.004748815113479006, 0.03161583707800933, 0.05875858132328306, 0.010156644641288688, 0.04873540452016251, 0.01535842301590102, 0.016193056711927056, 0.043402719777077436, 0.06961155217140913, 0.04324129968881607, 0.006893615537722195, 0.04267316910305193, 0.027182552198480283, 0.0965227870536702, 0.07522777295006172, 0.019892027601599693, 0.05478337034583092, 0.01705298788978585, 0.0411632251260536, 0.08749553002417088, 0.04913182503410748, 0.017148773285693357, 0.0029277375974093695, 0.12139649662588324, 0.057297586862530024, 0.03870420404044645, 0.011177045958382743, 0.01835935439781419, 0.027804359993232147, 0.03056240128353238, 0.01793669323836054, 0.026049420769725527, 0.050154601223766804, 0.03231499956122466, 0.0434284905370857, 0.036326084685112746, 0.0694972529475178, 0.008530604170768388, 0.015176791065771664, 0.031155749623264586, 0.0150026688019612, 0.10261671005615167, 0.13526275328227452, 0.14656812378338405, 0.12730786656694754, 0.08231332059949636, 0.07363893570644514, 0.14625321568122931, 0.16109068665121282, 0.09667063983423368, 0.1719381274389369, 0.14568294771015644, 0.08311641429151807, 0.07661625915872199, 0.1057018730789423, 0.09699573953236852, 0.08459828048944473, 0.14465476359639848, 0.16060569696128368, 0.15371032910687582, 0.12233523625348296, 0.151586758771113, 0.19914777523704938, 0.17902277942214692, 0.1323627760367734, 0.1350944765976497, 0.16290776271905216, 0.1177443904536111, 0.22163150805447782, 0.12975549165691647, 0.12750660947390965, 0.18494339101016521, 0.16307173749165876, 0.10234270404492106, 0.14514637578810963, 0.12379386941237108, 0.16759402411324636, 0.0973207645916513, 0.10940141563436814, 0.06541918284658875, 0.11949148241962705, 0.12283101465020861, 0.11310910739536796, 0.1347101272216865, 0.23681246702160152, 0.22469259665480681, 0.16150730715266295, 0.15436260482030256, 0.06991512195340224, 0.11717119121125766, 0.14422675727733544, 0.0926115076456751, 0.0996887975239328, 0.15555559151938983, 0.08735989087394305, 0.12130473154996123, 0.14034548268786498, 0.08357042885784592, 0.07911361408020769, 0.07932853326201439, 0.16315707005560398, 0.12023413899753775, 0.09891196992248297, 0.19726752755897387, 0.08548054564744234, 0.09247580064194542, 0.10637113930923597, 0.18721226283482142, 0.21321584177868708, 0.15444772025304182, 0.15458741704268114, 0.1014545356322612, 0.060105317272245884, 0.09828705952635833, 0.1325680057385138, 0.09060906938144139, 0.1834906203938382, 0.10761585751814501, 0.12971492883350166, 0.17580923757382802, 0.2072540024029357, 0.1798211165836879, 0.13752781174012593, 0.1838669359151806, 0.1465920489281416, 0.1986532589154584, 0.11070038271801812, 0.13071952707001142, 0.12118967915219919, 0.11869150320334093, 0.1845928191074303, 0.09820941476417439, 0.22585715273661272, 0.07335949462971517, 0.1882785263338259, 0.186483624790396, 0.19903112149664334, 0.08839668559708766, 0.19263105706444808, 0.1051125382738454, 0.11392700672149658, 0.08637421697910343, 0.09182484807180506, 0.14632503182760306, 0.097453852450209, 0.09545287982161556, 0.14330164263291018, 0.1595195930983339, 0.16766418463417462, 0.11515520938805171, 0.1263421755284071, 0.16494566122336046, 0.10653983668557235, 0.1098323328686612, 0.20015986450016499, 0.10525661839970521, 0.13795412172164234, 0.0706203980371356, 0.12813668352152618, 0.14158604826245988, 0.11609037992145334, 0.1504684244947774, 0.12405634032828466, 0.1784131292785917, 0.12107740874801363, 0.07185873123151915, 0.1179041311677013, 0.15721994292523178, 0.15176457565809998, 0.13193485114191258, 0.13828768953680992, 0.14621741617364542, 0.12947050694908413, 0.09557707208607878, 0.0890199335824166, 0.14459183625876904, 0.09256019004221473, 0.2260169613042048, 0.16256058349141053, 0.09828035560037408, 0.16742772875087603, 0.11227538463260446, 0.10353824882102863, 0.09269966970064811, 0.1409864675785814, 0.11727864401681082, 0.12298838049173355, 0.17122578780565942, 0.07650568509208304, 0.12958023963229998, 0.1697248683444091, 0.20091761169689043, 0.13827791863254138, 0.13016048206814698, 0.10766334139875003, 0.20539640422378266, 0.2028310125959771, 0.1410996743610927, 0.13191499720726693, 0.14800403958984784, 0.14176387872014726, 0.09666879421898297, 0.2198849589164768, 0.12401195056736469, 0.1760843020996877, 0.15045060616518768, 0.2112721646470683, 0.10724942825202431, 0.11072824336588383, 0.172930403479508, 0.1163255465882165, 0.13312612793275289, 0.10575027298182249, 0.09209351401243891, 0.11069180603538241, 0.0980606527466859, 0.08553575125655957, 0.1535385511815548], [0.021931812433259826, 0.01806842572321849, 0.0018573310059894408, 0.02963715771745358, 0.0350814750418067, 0.06274141903434481, 0.02759410404334111, 0.0838863140504275, 0.05579809571749397, 0.025022878710712706, 0.04463666284989033, 0.04492403260831322, 0.03455361890207444, 0.026519852490829568, 0.03046852257102728, 0.09030119768743004, 0.016197088906275373, 0.01779978522764785, 0.02857336069324187, 0.019705868126558404, 0.012547646832120205, 0.04013601810272251, 0.026888507351811444, 0.020023678662255406, 0.009954917028413286, 0.02072475800689842, 0.07881818671843835, 0.057258340397051403, 0.04421940791819777, 0.044499880368156094, 0.06703719031065702, 0.06679747067391872, 0.023890586969043528, 0.015146128068278943, 0.014291660793657814, 0.015547255918915783, 0.036327112665666, 0.029293673112988472, 0.06952759703355176, 0.022700991248711944, 0.07235881832561322, 0.011967617286635297, 0.00638508704391175, 0.10719192240919385, 0.04906872806272336, 0.05303600696580751, 0.05523651638733489, 0.036168040308569155, 0.041258681432477066, 0.014457759380872761, 0.029459537605621984, 0.07238928454795054, 0.05445655056142381, 0.011245990205290062, 0.020977724343538284, 0.04951832536607981, 0.03509724758831518, 0.02363279285574598, 0.015744143032601902, 0.04992077127099037, 0.034150731949401755, 0.09321393817663193, 0.01048359165101179, 0.04900310015571969, 0.015029057028836437, 0.09849002292113644, 0.05315199913457036, 0.06988913406218801, 0.027763934573158622, 0.05472735728004149, 0.07317123508879117, 0.021631258739424602, 0.04752331706030028, 0.06327871698886156, 0.017869630229792426, 0.03778046682210905, 0.08183267353368656, 0.06232418106602771, 0.021728977960135256, 0.03752732237002679, 0.026280551849465286, 0.0371594783583922, 0.1209412267697709, 0.023342334066650698, 0.013370619055681994, 0.02627885720825621, 0.011254790804481931, 0.019679328925641518, 0.02908502359475408, 0.02498972209702645, 0.034050529290522845, 0.00989183786857341, 0.06597978847899608, 0.058805176323013644, 0.02768494631163776, 0.06113943178206682, 0.05336350867790835, 0.021885412512347102, 0.019497556179495792, 0.029512276739946434, 0.051559843854712586, 0.024237194530931965, 0.028301430999168327, 0.02498126246168145, 0.04185231136424201, 0.01768372011637049, 0.047709110126431496, 0.03467027942783066, 0.015830937839512314, 0.022708726547924534, 0.03864400102091687, 0.029724162870219777, 0.018911515661914433, 0.03088378600244011, 0.0355539355826165, 0.03650219166385276, 0.014050682474459921, 0.04893270554021001, 0.012591073921482478, 0.0464626141557736, 0.012054845507788872, 0.024750854021736553, 0.048552077928824086, 0.05450406836877976, 0.016676361938672404, 0.023779975582978556, 0.056145597249269485, 0.06392730825713702, 0.024084424067820822, 0.03043996642476746, 0.047404380049556494, 0.07682380945022617, 0.03749534301459789, 0.017140953169603432, 0.025283241079055836, 0.07890001125633717, 0.05915749206074646, 0.030657084060034583, 0.013636878741505955, 0.02818330653410937, 0.028181521987010325, 0.05116305693185755, 0.05434984414439116, 0.028693468176892827, 0.0668743894036327, 0.023596903442272117, 0.03830533062240907, 0.008117480669170618, 0.03970996257183807, 0.012988988060637243, 0.01978576901767935, 0.019985902921429703, 0.02952084324455687, 0.03630044963210821, 0.03960390415574823, 0.0043683893662611285, 0.015169715641864708, 0.043419720471969674, 0.0535851317856993, 0.04301221948117018, 0.07306435225265366, 0.026268506156546727, 0.06993163071040596, 0.03376672523362296, 0.05394517264461943, 0.03421910453055586, 0.061677075789443085, 0.010943160874636045, 0.03934533142351678, 0.031560719678444524, 0.05105545484860029, 0.046762187366506884, 0.0023284245107788593, 0.057462830495621474, 0.038419182013188086, 0.036324530839920044, 0.05523662156026278, 0.03442031730498586, 0.025741611840203404, 0.04140387096309236, 0.028135496956695403, 0.04754325920449836, 0.04240779405725854, 0.07726134918630123, 0.018913759916488613, 0.021116783310260092, 0.023979442826073085, 0.04924868233501911, 0.04586669077564563, 0.016744016969044293, 0.03352131608075329, 0.028871210425027778, 0.04188170550124986, 0.04208396661228367, 0.03130415540986827, 0.017639890146840895, 0.07621318221624408, 0.03651163687131234, 0.021383925939777067, 0.049371225759387016, 0.01787190162576735, 0.07378557390932526, 0.05568420700728893, 0.05386790446937084, 0.023638748696872165, 0.04387738894937294, 0.023628820033211793, 0.0314762386759477, 0.07184213426496301, 0.030135694359030043, 0.01856753572688571, 0.05008137711722936, 0.05409813818654843, 0.0741206073601331, 0.03729649832738297, 0.004047544930861997, 0.04133042972534895, 0.06995307920234543, 0.025480284255796244, 0.12198184164507048, 0.059865787625312805, 0.07353761007211038, 0.050213457351284366, 0.02979006219123091, 0.048391417799783606, 0.006497976611301835, 0.02500737418553659, 0.0455997245652335, 0.024727076458345567, 0.059475813194045, 0.01099806877651385, 0.03303485396983368, 0.005100389975788338, 0.039317165434892686, 0.02992754356403436, 0.021769260887854865, 0.027209415399868573, 0.05012110873524632, 0.08357358404568263, 0.037324504860277684, 0.03949290939739772, 0.05276447421471987, 0.01911011946919773, 0.04249301805560078, 0.03832428889083011, 0.03782837139442563, 0.03387576581111976, 0.003119780607188919, 0.026008532249501774, 0.05231984718037503, 0.04301981907337904, 0.07124648908419268, 0.07291872506695134, 0.008789740087065314, 0.017866059439256787, 0.03099199876721416, 0.044435840233096054, 0.03181178442069462, 0.08288037231458084, 0.022197392735896364, 0.016480589318754416, 0.06419104803353548, 0.017283448916194693, 0.013128688242951674, 0.05322216644084879, 0.04563340365088411, 0.03634249844721385, 0.018050999247602055, 0.02150127857125231, 0.07090866006910801, 0.031433172058314085, 0.04433219400899751, 0.06828870065510273, 0.043006940478725095, 0.04266703514648335, 0.01816883703161563, 0.0057184433514651445, 0.026385317656344602, 0.025847344559484293, 0.042995466451559744, 0.03264322730579546, 0.07899651929203953, 0.05303412403113075, 0.04189328809401818, 0.05644544865936041, 0.0014701342214331298, 0.08602837446544852, 0.024975299835205078, 0.03966278742466654, 0.019573523263846124, 0.04133228212594986, 0.02592150674068502, 0.010564099830974425, 0.03767070360481739, 0.04740794914375458, 0.015083711328251021, 0.04460857150011829, 0.022233266882332306, 0.05987756020788636, 0.06396405092839684, 0.023514799008678113, 0.0786098696823631, 0.03959445216293846, 0.03762531979009509, 0.02865886628361685, 0.019416126888245344, 0.04920578535114016, 0.07302876987627574, 0.021099114258374487, 0.007889006054028869, 0.01492523099295795, 0.037421976415706534, 0.04109533769743783, 0.08136200771800109, 0.054421897778021436, 0.04827631451189518, 0.019031409407034516, 0.02396437425964645, 0.06850497690694672, 0.03673994694171207, 0.028347433977095143, 0.04469389049336314, 0.01582909222426159, 0.06775288869227682, 0.040022458482001505, 0.049930338614753315, 0.07010803624455418, 0.009604939691988485, 0.04983844800985285, 0.03948272119409271, 0.021982078307441304, 0.017958855888407146, 0.04919645210195865, 0.005283317079634539, 0.015886813501960466, 0.053796017076820135, 0.1278108510055712, 0.024098093155771494, 0.006531932624056935, 0.04810179191242371, 0.03876391512208751, 0.02742073834607644, 0.047766015465770445, 0.009031143338818635, 0.02362789722558643, 0.034601995056228976, 0.05067268306655543, 0.03041759512520262, 0.02924103575891682, 0.06787528283894062, 0.0524987361526915, 0.018333161249756813, 0.17785210295447282, 0.1327823142388037, 0.05487129830622247, 0.13901411555707455, 0.07585026097616979, 0.14107152872851916, 0.11272211173283202, 0.1719504360641752, 0.1466494665614196, 0.13949491190058844, 0.20670882665685245, 0.1384808820273195, 0.13655357116035052, 0.12957698266421044, 0.07672391552478075, 0.15159381553530693, 0.13893369558666432, 0.12828616478613444, 0.12606446471597466, 0.0843688203021884, 0.1643285879067012, 0.09690743498504162, 0.19177323952317238, 0.11883782249476228, 0.18097533179180963, 0.18396590703300067, 0.19497962961239473, 0.20382877119949885, 0.14314587813402924, 0.12667629974228994, 0.27813201983060154, 0.17412845204983438, 0.14519969506987504, 0.10731210453169686, 0.08286621128874165, 0.10139781689005238, 0.19656316749751568, 0.19368760394198553, 0.1410614185567413, 0.08168503109897886, 0.12541624664195947, 0.1804027703723737, 0.07566975709050894, 0.1385946994913476, 0.18167293364448206, 0.2409565517944949, 0.16857671923935413, 0.12712335932467664, 0.1433322038501501, 0.08819267047303063, 0.1205579223377364, 0.1355518363416195, 0.13215441150324686, 0.09267144264387232, 0.06760526661361967, 0.09539259198520865, 0.07693004767809596, 0.0839626763814262, 0.11690095785473074, 0.1940422063427312, 0.14935866690107755, 0.15263673742966993, 0.16729839997632162, 0.16546341058398994, 0.09850426537117787, 0.20979652740061283, 0.09504181652196816, 0.12924865313938685, 0.20285037798540934, 0.27665213495492935, 0.113143929812525, 0.06957023617412363, 0.1468108357595546, 0.20909832843712398, 0.09775857574173383, 0.11307372857949563, 0.33637049049139023, 0.19733611387865885, 0.09766297015760626, 0.17339187514569077, 0.09921385015227965, 0.1336918090070997, 0.19470404939992086, 0.05848972539284399, 0.10954103778515543, 0.1506671809724399, 0.09874099945383412, 0.055224078840443065, 0.13993116920547827, 0.13273371756076813, 0.10342354247612612, 0.05777662580034562, 0.15430811845830508, 0.16014213540724345, 0.21122198019708904, 0.2068859650088208, 0.17440559289285115, 0.11630244925618172, 0.1948044997240816, 0.10661250100071941, 0.12237022151904446, 0.0745548154892666, 0.08111629661704813, 0.2142546246094363, 0.10708060195403439, 0.33931856229901314, 0.15294728933700494, 0.16664353225912365, 0.13452768272587232, 0.10055044878806386, 0.19452532327600888, 0.22514048404991627, 0.12481738520520073, 0.11480773160500185, 0.11192754044064454, 0.06462796351739339, 0.10792242642492056, 0.15065270103514194, 0.09336918698889868, 0.159535606524774, 0.16072891892067023, 0.10933367748345647, 0.17210180365613528, 0.22245839796960354, 0.17348074966243335, 0.13659558604870523, 0.13845217999603066, 0.17309768950300558, 0.11906506387250763, 0.11193852592259645, 0.11778407118150166, 0.18576322416109697, 0.07042843369500977, 0.10459822908576046, 0.0903127599241478, 0.18581262151045458, 0.17445246609193937, 0.3557124568947724, 0.18739785573312215, 0.14813483400004251, 0.11473442268158708, 0.20809672932539666, 0.12771243628646645, 0.10649997953857694, 0.10264825514916863, 0.11948741120951516, 0.059682732447981834, 0.13895895066005842, 0.1810096385223525, 0.1108125513419509, 0.1329168677330017, 0.1824170829994338, 0.18037181560482296, 0.0998426214126604, 0.147204833903483, 0.07071152529014008, 0.08235859924129077, 0.052234365338725705, 0.15307598028864178, 0.17101994742240223, 0.18854725334261144, 0.09572468737938575, 0.18083955693457807, 0.12324711946504456, 0.13995151168533734, 0.11977380727018629, 0.18034339855824197, 0.04659524400319372, 0.11527623289397784, 0.18091340868600778, 0.1634897557752473, 0.13668524766606943, 0.06940112489142589, 0.13551003858447075, 0.1095057607495359, 0.07279251076813255], [0.028128799816061343, 0.06520714065326111, 0.04109028600422399, 0.05095782044476696, 0.04444632699180927, 0.04008128746811833, 0.08743407510753189, 0.054691734191562445, 0.03629539793889437, 0.046677943851266585, 0.019505157468042204, 0.008306260137552661, 0.03593913312735302, 0.03931581854288067, 0.051811699090259414, 0.039829249028116465, 0.029335911917899336, 0.04736502841114998, 0.06285280734300613, 0.07408819374229227, 0.009956981471207525, 0.02756439438754959, 0.0223845072489764, 0.04730581266007253, 0.011104855769579964, 0.04118675332782524, 0.004995849357718336, 0.03176742180117539, 0.05073298786633781, 0.043414166662842035, 0.035133667955441136, 0.07540881287838731, 0.03834629378148487, 0.021075920235099535, 0.0024818981058030787, 0.033818015695682595, 0.04999987149078931, 0.05888920609972306, 0.02490445738658309, 0.03842827777511307, 0.0230545673652419, 0.04842544972364392, 0.053468668035098484, 0.03026653965935111, 0.0747050770691463, 0.007680660180215324, 0.07538410063300814, 0.011897347351935292, 0.05318532198933618, 0.018657270286764418, 0.019640750817156265, 0.02878461917862296, 0.062046809521104605, 0.06317547110042401, 0.08357240339475018, 0.03602898134184735, 0.07098819794399397, 0.04833760658012969, 0.046539604131664546, 0.010739024462444442, 0.0185926415225757, 0.05103671371138521, 0.02357461695958461, 0.009810789405102176, 0.0539738034297313, 0.024140018138236234, 0.07365207214440618, 0.026485337110768472, 0.05394396485228624, 0.0263153844446476, 0.04202935132863266, 0.041255312506109476, 0.03218058516670551, 0.03345704524378691, 0.0414673580921122, 0.0645540099857109, 0.016106180480814407, 0.05569959618151188, 0.030380482652357647, 0.02617661215897117, 0.015768091926085095, 0.03406123996579221, 0.03967320293720279, 0.026269381466720785, 0.04051513258101685, 0.03386496014094778, 0.030773296752678495, 0.018777537226144756, 0.05297051476580756, 0.03672119223379663, 0.03312212714393224, 0.010905322369321116, 0.025977070277024592, 0.03975987221513476, 0.029723701466407095, 0.03169276937842369, 0.060507233919841905, 0.01711840714727129, 0.01973327076328652, 0.03110640655670847, 0.03500774881935545, 0.030460682098886797, 0.07254373268889529, 0.014429774900366153, 0.06433787622622081, 0.037541778558599095, 0.05329580106107252, 0.025406198409785117, 0.0668212804677231, 0.039254573972097466, 0.015694202855229378, 0.03960233673985515, 0.03070085635408759, 0.03681169862725905, 0.025302711641415954, 0.008588936129984046, 0.030973261022674184, 0.01659064769877919, 0.0695589589221137, 0.03407814905845693, 0.030953033893768276, 0.08791072560208184, 0.08153759222477674, 0.027971778331058364, 0.02825022705032357, 0.05358830393691148, 0.03295790470604386, 0.0684550367295742, 0.040124326944351196, 0.022035786050504873, 0.027878866530954838, 0.03727746542010989, 0.03445721943197506, 0.018351247600678886, 0.025227341667882035, 0.009843439662030764, 0.07039545689310346, 0.014319104142487049, 0.046390560522143326, 0.0662974582186767, 0.01880435293008174, 0.05064813366958073, 0.05082544165530375, 0.01651035325734743, 0.044219323101320436, 0.045417541305401495, 0.04340032454846161, 0.023732890341696993, 0.021674586593040397, 0.0828171871336443, 0.025264630559831858, 0.08151072223803826, 0.02575532503293029, 0.043472629240048785, 0.04927537250997765, 0.038551092613488436, 0.04068686640156167, 0.03985762196992125, 0.021139531196760278, 0.029431453041200126, 0.02666122017295233, 0.045622740473066054, 0.028547050497893776, 0.049655033208961995, 0.051765701201345236, 0.056139982371990166, 0.029843581640826802, 0.019450993410178592, 0.07414295830364738, 0.014669843982639057, 0.02846397745556065, 0.02059193647333554, 0.01665963096145008, 0.020050319643425088, 0.07201360684952565, 0.03430681196706636, 0.03189387019457562, 0.056401252280920744, 0.02973904992852892, 0.05453700785126005, 0.084138084469097, 0.06382566371134349, 0.045929292416466136, 0.03368067342255797, 0.02407312815609787, 0.05397369486412831, 0.020654721318611076, 0.0075772293909851995, 0.07471080390470368, 0.03660797866593514, 0.058165975979396274, 0.05960637690233333, 0.025952736314918314, 0.02655853746858026, 0.02293267872716699, 0.047340811496334415, 0.015070140627878053, 0.03111548874793308, 0.05171458037304027, 0.1046665847035391, 0.006409753488177168, 0.055181351490318775, 0.04759023757651448, 0.009238663096246975, 0.026107610236587267, 0.018645256824259247, 0.05008038306342704, 0.08429146731006247, 0.036084363370069435, 0.01110392956927951, 0.042488926489438326, 0.012920855511245983, 0.039589739737233946, 0.05054547471393432, 0.05695599876344204, 0.06152146735361644, 0.017800762318074703, 0.0003417773732508067, 0.004659868502390704, 0.036316988923187764, 0.053925400134176016, 0.03331089897879532, 0.023342308621587496, 0.04497187950515321, 0.01748407645417111, 0.01036112371366471, 0.04761257155665329, 0.03333944155435477, 0.07557497253375393, 0.04952040846858706, 0.0267514738121203, 0.07731356245598622, 0.10370375029742718, 0.036518982012889216, 0.025354219234681556, 0.06969244033098221, 0.03042003445859466, 0.012799253554216452, 0.015143490263393946, 0.0020732762599696536, 0.019644545524248054, 0.05175890228045838, 0.02326237889272826, 0.04031935826476131, 0.014973627503163047, 0.049707792699337006, 0.012942862098238297, 0.059612612639154704, 0.05535421507166965, 0.057178422542554994, 0.02541823562101594, 0.05250887007319501, 0.03525375169036644, 0.033768927079758475, 0.04483140918559261, 0.023935650175969516, 0.060964539381010194, 0.03451999070655022, 0.04567190372784223, 0.030417975104813064, 0.05210242420434952, 0.03064654301851988, 0.03294574535850968, 0.022721467739237205, 0.031248430721461773, 0.04693054208265884, 0.05184935099844422, 0.029524676967412233, 0.02378800604492426, 0.058822933584451675, 0.006595087695002023, 0.026526410531784807, 0.06028856922473226, 0.10246198371584926, 0.055963631120643446, 0.055089796760252545, 0.005298987845890224, 0.029661975135760646, 0.030013737867453268, 0.048499542355005226, 0.024344705011961714, 0.011990090366452932, 0.060569469151752334, 0.02209828930374767, 0.0368256289511919, 0.08039827086031437, 0.005333043518476188, 0.09700201598129102, 0.06579521338322333, 0.06438757213098661, 0.041911873168178966, 0.07611141553414719, 0.04840909702969449, 0.05497547039496047, 0.04537463753617235, 0.030576630162873437, 0.017470726277679205, 0.01658490389984633, 0.005133044473560793, 0.050189437211624215, 0.06452879562441792, 0.04636077962017485, 0.027586877645392503, 0.0028905398836026764, 0.011103303620724805, 0.02349515541988824, 0.02718802967241832, 0.038331579749605486, 0.011259781429544091, 0.0506142137039985, 0.059158170595765114, 0.025593411310442855, 0.06212662559534822, 0.012020750819439334, 0.042824075291199346, 0.05614264562193837, 0.02813105085598571, 0.054307255893945694, 0.02969496211569224, 0.03242709354630538, 0.012294115615077317, 0.04618789229009833, 0.0341026645286807, 0.04016964629824672, 0.04659833812287875, 0.0039585067175461775, 0.10363257875932114, 0.02611479931510985, 0.016866697796753476, 0.08631342024143253, 0.008500282137122537, 0.020824728267533437, 0.01912769691885582, 0.035466363853109736, 0.0014741550715241048, 0.029366540988641124, 0.07077796065381595, 0.05306109919079712, 0.018916886266587035, 0.018965080912624086, 0.04549144733963268, 0.0642796443509204, 0.021826069535953656, 0.024439197798658694, 0.08810235067669835, 0.033437408440347226, 0.08564916838492666, 0.07644894599382367, 0.051167810069663186, 0.02638773324101099, 0.10809572426868336, 0.038936337655676265, 0.10893814585038594, 0.20077883771487645, 0.14421861485711165, 0.15354188957384654, 0.16542979595916613, 0.12050684222153255, 0.20494402492684977, 0.10657182961170163, 0.12055071629583836, 0.225817648427827, 0.15275208838284016, 0.1158665990723031, 0.1535009060587202, 0.21993643258299145, 0.12809073313006333, 0.11650013364851475, 0.07407636009156704, 0.11336154277835574, 0.1438493560999632, 0.23431268973009928, 0.1343042818563325, 0.08921618626586028, 0.11893414732600961, 0.2515206092170307, 0.07543264302824225, 0.18288954693291867, 0.09600809788597481, 0.13639402043606552, 0.14882693971906388, 0.1267576018082244, 0.10584973943020616, 0.1403346804103681, 0.12494402698108129, 0.0865736927038857, 0.09538617982928242, 0.14219381207866327, 0.19590703770518303, 0.11979766456144196, 0.09262017932321344, 0.12102670861142022, 0.06094471937311547, 0.07835957847003426, 0.13224955568356173, 0.18654199237270014, 0.13375587628356048, 0.0696417876918401, 0.10462920420936175, 0.11384437472692557, 0.0911166610728417, 0.08942755670951945, 0.16573546241436685, 0.12489087054772036, 0.11696315237454005, 0.09234266528593642, 0.17375092873615877, 0.1459794132305043, 0.2146880320672478, 0.08778631620641265, 0.12520560223077024, 0.12348277467702116, 0.1178811424012695, 0.19552935154310294, 0.10218101593532733, 0.1494774648121425, 0.17871283819632872, 0.14552467263170651, 0.11833532660135201, 0.08749890912856374, 0.14267758040555886, 0.08981197393898453, 0.15146925007658346, 0.19178621311272892, 0.22973401684846195, 0.16644131525286607, 0.13488467356988362, 0.13861813609089169, 0.1261568676148142, 0.2628827595285007, 0.11393151219402041, 0.19618123370621884, 0.09934835614902632, 0.178552242528115, 0.12497864583773272, 0.0974889462813735, 0.24389276280999184, 0.20470758261425154, 0.07741013834519045, 0.08425473820950304, 0.23758466701422418, 0.15034094133547374, 0.08414482232183218, 0.15046001066054615, 0.16491553426853248, 0.1221610020313944, 0.09111779422632285, 0.2047010822487729, 0.22734330727585725, 0.15293859051806585, 0.17565419232206686, 0.15267747667218956, 0.13489787786134652, 0.17972728876130922, 0.0861083058906453, 0.1257199996284076, 0.09216821393264191, 0.10040666043226208, 0.19701717527849333, 0.15368560329079628, 0.1457615356360163, 0.20017226812030586, 0.1730558510337557, 0.17545238243682043, 0.1126515848029937, 0.18262565109346593, 0.1334978158452681, 0.11389233358204365, 0.15694776895855153, 0.15356027787285192, 0.1597363578953913, 0.11177731957286596, 0.07157829270831176, 0.12194851200495448, 0.1755500371967043, 0.12622480254088128, 0.1258462749953781, 0.09236663792814527, 0.13035382383636065, 0.25410384631582666, 0.18029919878712722, 0.13109828531742096, 0.14171448137078965, 0.08354034261511904, 0.12540043677602494, 0.13385221468550818, 0.14821277053228446, 0.15681613316493376, 0.14986796171537467, 0.11072165479085275, 0.15519516728818417, 0.15661823164139474, 0.0652916454044836, 0.19486482148723944, 0.14067841268011502, 0.17095301672816277, 0.12668608421725885, 0.11704381661755697, 0.16834259751651967, 0.1165437363088131, 0.06790815107524395, 0.18899070311869892, 0.1339437762009246, 0.2094521573079484, 0.08392995063747678, 0.21223037822970323, 0.1247223224490881, 0.17651065279330524, 0.10806470843298094, 0.09274085677628006, 0.15330767285610947, 0.10097265363271747, 0.13564839187477315, 0.18707464236233914, 0.07901856489479542, 0.14397517006312097, 0.15361176511006697, 0.14866559766232967, 0.15584471529083593, 0.12085498496890068, 0.2015685981937817, 0.10376707797071763, 0.17916414540793213, 0.10066696682146617, 0.18529869908733027, 0.10266743733414582, 0.24888167796390398, 0.08112659677863121], [0.018327125680765936, 0.027101331556748067, 0.02033457831878747, 0.09453092036502701, 0.03190193119059716, 0.1148594224027225, 0.016900193677949052, 0.02016893435003502, 0.08192304761282035, 0.025272944310147847, 0.026415892444284897, 0.029679583119494573, 0.011817210669895368, 0.05128529501546707, 0.060017053437020094, 0.03250297072476574, 0.07886980287730694, 0.032009981106966734, 0.058740003034472466, 0.031119196941809993, 0.01068056867058788, 0.015612849899168526, 0.05153823590704373, 0.049983953059251816, 0.011230456842375653, 0.009563247955936407, 0.020836273540875742, 0.07515324944896357, 0.029855238872447183, 0.012723974334741277, 0.05736145057848521, 0.11584146613521235, 0.06358054972120694, 0.06998153696102755, 0.045255781949630806, 0.04903883520247681, 0.06008387556565659, 0.05201552083183612, 0.034778739857886515, 0.0694118050326194, 0.01740838587284088, 0.01610884881977524, 0.0606310326339943, 0.011231056497698384, 0.024780495824026208, 0.08760070295206138, 0.050325663294643164, 0.08210056594439916, 0.019854319714275852, 0.01695509733898299, 0.050349629151501825, 0.009751330229586788, 0.017193559989599243, 0.02106645467158939, 0.023550391563081315, 0.020817525618310486, 0.018223055372280732, 0.06245197635143995, 0.037647270397948365, 0.04600431803347809, 0.021511558376784836, 0.02468475453289492, 0.034004171778048785, 0.04556485465062516, 0.03717016189226082, 0.04426348216033407, 0.05374408879184297, 0.030182370782962868, 0.05404233546661479, 0.03239348909950682, 0.01087568311153778, 0.03757602082831519, 0.04097615980676242, 0.04785711218469909, 0.009709605414952551, 0.1150683161935636, 0.02818765594357891, 0.014181376800739338, 0.021386668917589953, 0.013481845364107617, 0.03242749048929129, 0.013605462570142533, 0.005968296908706958, 0.03229627538738506, 0.029365557112864087, 0.025337065869410123, 0.0525458264829857, 0.014012564073449798, 0.04814356252817171, 0.00821683176660112, 0.0631043945572206, 0.02483516539047871, 0.041721669624426534, 0.02575913331072245, 0.03876975052324789, 0.09460802229919604, 0.07354389330638306, 0.053834717321608744, 0.1053483427635261, 0.06741393330906119, 0.01994789987137275, 0.09353529914681401, 0.041456101196152825, 0.01538593421823212, 0.059272340898002894, 0.02668688745637025, 0.037335975494767935, 0.028023387704576765, 0.044453787484339306, 0.009212074701541235, 0.036422280594706535, 0.030193956768406287, 0.009431239816227129, 0.08492344804108143, 0.024365388455667665, 0.04376168176531792, 0.0653102101225938, 0.03610562526487878, 0.02701553249997752, 0.032664448488503695, 0.01869351593112307, 0.023590905192707266, 0.06468912666397435, 0.06208801695278712, 0.10098581721207925, 0.052606212706970315, 0.03581913760198014, 0.02770081385304885, 0.07942892930337361, 0.019587492603542547, 0.052593476604670286, 0.07373716043574469, 0.01797224847333772, 0.11268499586731195, 0.06347774488053151, 0.04111856395112617, 0.0930766434009586, 0.021354643761047294, 0.059477998076805046, 0.04785357701725193, 0.045490989328495095, 0.02123693489868726, 0.04072968874658857, 0.024099417995395403, 0.014861721811550004, 0.04365489053140793, 0.023940510183040584, 0.08015863264777831, 0.03218294307589531, 0.015479334563549076, 0.03884251322597265, 0.03653337034795966, 0.02607439425108688, 0.0054290435010833395, 0.022143617139330933, 0.05063431530392595, 0.02910146110558084, 0.06726992782205343, 0.01720990759453603, 0.015602217255426305, 0.030241803665246283, 0.014468970475718379, 0.02958118197109018, 0.0051278401099677596, 0.062241800129413605, 0.006827940981435988, 0.028142653804804598, 0.007350698778671878, 0.018791630398482084, 0.007967058785392769, 0.037626527582428286, 0.0528696369645851, 0.018518189267654504, 0.009518141492402979, 0.013624976389110088, 0.0727546281580414, 0.04177922635738339, 0.0479343701819224, 0.0038166254692311797, 0.10248525068163872, 0.06146109809300729, 0.08553829576287951, 0.028519766604793922, 0.023684147778632383, 0.07487977269504752, 0.07828052914036171, 0.08171013689466886, 0.02604606032504567, 0.022358755148681145, 0.0489190534156348, 0.035205351787486246, 0.01179604122548231, 0.0416872000454792, 0.0510915427335671, 0.01236933546273836, 0.06497904432139226, 0.0407980511497174, 0.016881674760952592, 0.020356617136193172, 0.0315958236876343, 0.009386647342970329, 0.038561413131122074, 0.03504234392728124, 0.07178829929658345, 0.03963380040866988, 0.017401569988578558, 0.05718216805585793, 0.02668258045533938, 0.05659026838839054, 0.023202080878296068, 0.034410261416009495, 0.03516133861350162, 0.05569072772881814, 0.02647849578144295, 0.08019544995789017, 0.04248411567615611, 0.01695910408826811, 0.010138120635279586, 0.03362820909491607, 0.04564475214907101, 0.08313758458409991, 0.03223852527194789, 0.03704813754718218, 0.010285719813379859, 0.006962974963244051, 0.023938801971131136, 0.07156025724751608, 0.08183852250554732, 0.03941686937053289, 0.04140544177166053, 0.028284413340900625, 0.02274652773381344, 0.02754428260959685, 0.0307689778772848, 0.032466801415596686, 0.03805320058017969, 0.03059656891439642, 0.02673795060919864, 0.012678140990569122, 0.01910297279911382, 0.02388156923864569, 0.10798270747597728, 0.0549351450588022, 0.04437295700024281, 0.004243694137715335, 0.07772594889891998, 0.025128560539867197, 0.03593160478132112, 0.08814338168927602, 0.018805207884205238, 0.07119963624115501, 0.06989711363400732, 0.05501156167260238, 0.02933378131794078, 0.004906155085856361, 0.07848445605486631, 0.01067836512811482, 0.03663782402873039, 0.010155608179047704, 0.018891916177900772, 0.02308286906086973, 0.03410931756453855, 0.028557482973805497, 0.01710997804600213, 0.03607526760814445, 0.011175620186674808, 0.009326046532286065, 0.01309708971530199, 0.06116286838161094, 0.08789376901196581, 0.04531806128631745, 0.05404387913378222, 0.026419422522719418, 0.05067635394100632, 0.13657061596001896, 0.013031390562121357, 0.004986530103321586, 0.07833806212459292, 0.04088591464928218, 0.06584851230893816, 0.042501645628362894, 0.033850249501743486, 0.02077543269842863, 0.04340140002646616, 0.012979273135507745, 0.01711432745547167, 0.039644120926303525, 0.07079379087580101, 0.040602823054151874, 0.024775252444669604, 0.0365152738190123, 0.021230750051992278, 0.010927306903925325, 0.028038890533415333, 0.041019572477255545, 0.018105600960552692, 0.036545224354735444, 0.02440484187432698, 0.02549837908840605, 0.015470047115481325, 0.03029985912144184, 0.04132853661264692, 0.03132087790540286, 0.02556188657347645, 0.04685985230441604, 0.010723219685522574, 0.011561790580994316, 0.025920611074460403, 0.04689242198531117, 0.03710173502830522, 0.023114894217412387, 0.1101902804470488, 0.04944395114268575, 0.015396056264372808, 0.03365431912243366, 0.017290137575141022, 0.06337461434304714, 0.040160577677722485, 0.03682227359552469, 0.04222538688087037, 0.06211054431540625, 0.05525844663913761, 0.07861185100461755, 0.03557442394750459, 0.023166318690138202, 0.032801780583603043, 0.05232276488095522, 0.08624781269047942, 0.07033953203686646, 0.011194988968782127, 0.03796140497018184, 0.054996203032455275, 0.016180832903566103, 0.03906456381082535, 0.009469601641675192, 0.019001460567648922, 0.05012589919247797, 0.02010179161360221, 0.034253998193889856, 0.013910760920095657, 0.0305395482241043, 0.024681305878662636, 0.045616942391331704, 0.03721478235508714, 0.04285742189469082, 0.006581349481296326, 0.03198595418195639, 0.025177072401025465, 0.01210046002441751, 0.08020506479910441, 0.039831793534436395, 0.04627409677154251, 0.1276909674384764, 0.07934808864125184, 0.14645406204674924, 0.2403627522289753, 0.12119588096226964, 0.1839147319218942, 0.10846498981118202, 0.1274761161101716, 0.1778158556137766, 0.10293474620474236, 0.1282295613948788, 0.11988765187561512, 0.14332967969988072, 0.09734367193388087, 0.17836214415729046, 0.07767651083746127, 0.16205386711018427, 0.15912844480148383, 0.17478900589048862, 0.12253639474511147, 0.09149947695966278, 0.08672892116010189, 0.11582404135593347, 0.15218282464359487, 0.12824116434369767, 0.08466272774551596, 0.08251790569296905, 0.16189708480877535, 0.12491601705551147, 0.09463385412735598, 0.12495257652231626, 0.17722540801124914, 0.12256793305277824, 0.1740683609885829, 0.15753338539174624, 0.10193209536373615, 0.15163672608988626, 0.24018826016357966, 0.1264143716543913, 0.15530245724533284, 0.06489607984466211, 0.06779953118945871, 0.1461064756980964, 0.13392663640635355, 0.14749645468379768, 0.19875228431607994, 0.1152696782456977, 0.15848694422415324, 0.08938520933900561, 0.13897508622280189, 0.17793811405343668, 0.11367700049387557, 0.10327463796628372, 0.2331364085631711, 0.15601219130413874, 0.09741796473307268, 0.12771941162645817, 0.16039577179721423, 0.09802366580281939, 0.17612375212567194, 0.107934958966715, 0.08107798652989523, 0.14986185490020684, 0.12368628089981419, 0.13879181391426496, 0.1676960214972496, 0.1739403350012643, 0.16717911352004322, 0.07570704258978367, 0.17978260293602943, 0.19452381692826748, 0.13454820162483624, 0.2082331555762461, 0.20760253870061465, 0.12898022468600953, 0.2749333514698914, 0.12338484850312982, 0.08864607435784169, 0.08445905867431845, 0.26892106980085373, 0.08682224008121661, 0.14563956218106405, 0.08457902366561548, 0.08596444968134165, 0.1645403993981225, 0.1808707152626344, 0.1404207322214331, 0.07127985943640981, 0.19247229344078473, 0.09221551460879189, 0.13798065244087152, 0.10128163133880921, 0.13925122283399105, 0.08828588082854237, 0.1328901063118662, 0.18781296988683088, 0.15707295866949217, 0.11861193818705422, 0.22890739834734372, 0.1807308556245906, 0.07673962361046247, 0.1575372801827533, 0.0971793375377144, 0.1951897040541683, 0.13701958901115827, 0.1631227768957615, 0.12419900910130569, 0.13985942091260636, 0.10971566555755478, 0.0673336558310049, 0.16467408436749661, 0.17267498932778835, 0.21568214015236922, 0.1579171647982938, 0.26011145966393606, 0.15270900140915597, 0.10190808200942618, 0.10762022049831492, 0.178002018481493, 0.16524276456662587, 0.11867315561643668, 0.07070801047874348, 0.25837633705564905, 0.14639179967343807, 0.18202710178281578, 0.10525659125830446, 0.12228555391941752, 0.16496641082423075, 0.19486430580062525, 0.08888271344559533, 0.08517306071839162, 0.16686111129820347, 0.16774723732045718, 0.16933963687292167, 0.20246083103120327, 0.19625114995454038, 0.2243716495909861, 0.11627948763115065, 0.15578345714935235, 0.12952051497995853, 0.12485793445791517, 0.07212532085499593, 0.11977801418730191, 0.1162793654948473, 0.1525662104998316, 0.09378810772406203, 0.13856849446892738, 0.11341320643467562, 0.12317404124353613, 0.16469529537217958, 0.145684969744512, 0.16051494968788965, 0.1331383687044893, 0.07913277590913431, 0.14678629993328027, 0.10803538893482514, 0.14075655277286256, 0.13344864919781685, 0.08089042588004045, 0.1106134420260787, 0.1028324638360313, 0.103033228777349, 0.08405810554644891, 0.12792480417660304, 0.10713437585426228, 0.100260205433837, 0.17080141843429633, 0.08914361694561583, 0.09849766322544642, 0.08688018697180919, 0.11428430969161646, 0.1550012691212552, 0.09606144430914096, 0.11167517291115862, 0.09908315752233778, 0.14267094433307648], [0.047986580058932304, 0.023864868795499206, 0.034779811943215985, 0.030522418607558523, 0.010267931169697216, 0.048344249437962256, 0.03633235774136015, 0.04083123151212931, 0.058600910140999725, 0.03582034878698843, 0.03200275810169322, 0.007707000909639257, 0.01584629139064678, 0.036324323886739354, 0.0400814503165228, 0.04161007436258452, 0.032236194504158835, 0.05729217215308121, 0.014872759879965867, 0.0729899780292596, 0.02214990376627871, 0.01610242648582373, 0.015265151592237609, 0.02020633011125028, 0.0714314780863268, 0.037282656213002544, 0.03145251030634556, 0.02027127269788512, 0.012822663860528596, 0.04914212519569056, 0.033458975675914965, 0.05113651942727821, 0.024963147273021083, 0.06511593197605439, 0.031797898201537986, 0.059315651788243225, 0.031854745865400345, 0.03789278472374592, 0.04753349169290491, 0.04412725607731512, 0.026964976552075574, 0.020769951831815497, 0.0548653102346829, 0.03452702032934342, 0.03241253557748028, 0.04679809543969376, 0.03882924108100789, 0.052413247525691986, 0.030788916628807783, 0.010047037487051316, 0.03745886157932026, 0.06760545660342489, 0.007561122665980032, 0.047890665741371255, 0.02206525482636477, 0.008264215563290885, 0.0018313064314757607, 0.01272625760507903, 0.0436751889064908, 0.0394257988913783, 0.04576604367632951, 0.04334121736298714, 0.05709838933710541, 0.00916331263059484, 0.03655447278703962, 0.04776738949918321, 0.04363294331622975, 0.013526336057111621, 0.029343772746090378, 0.015417043352499604, 0.054153761094702144, 0.03536758611776999, 0.03413934273911374, 0.02228244879682149, 0.02572041440622083, 0.08839070091822318, 0.06464610754379205, 0.10296551098248788, 0.01932667731307447, 0.011706705304927059, 0.016478175430425575, 0.053777533782912154, 0.042622048274746964, 0.06899673837636199, 0.0726420252716967, 0.023078283860481212, 0.02022063871845603, 0.035262779598789554, 0.01884329235846443, 0.04580649793414133, 0.0178065112060202, 0.029033434577286243, 0.027424448236290897, 0.05567856838128396, 0.035338303939040215, 0.01305701713343816, 0.06971129681915045, 0.034594639736626825, 0.07274189205574137, 0.046842570017491064, 0.05395782393004213, 0.039862324217600484, 0.051030304948134084, 0.06845964398235083, 0.03166176372074655, 0.03635013535884874, 0.06292726299060242, 0.03419166796707681, 0.042960918841085265, 0.026426036542813693, 0.049189697285848, 0.0868870062487466, 0.04564900995631303, 0.030749171440090452, 0.025990727490612438, 0.04625590524769255, 0.01818798528984189, 0.041326718138796945, 0.021658983680286577, 0.06110960338264704, 0.03180271919284548, 0.03885231805699212, 0.02957643222595964, 0.01973355235531926, 0.037651572309966595, 0.020404715090990067, 0.02347672131976911, 0.019007016073114107, 0.035936670045235326, 0.018094869929232767, 0.03205158548163516, 0.03822828636371663, 0.023054966004565358, 0.0020596029311751147, 0.037115153058298996, 0.020431483297475746, 0.040419581279690774, 0.04138333510075297, 0.0547297626866826, 0.02463748269448323, 0.017251428848664676, 0.05965447824980531, 0.02856151686449136, 0.03290089758645211, 0.09792216374937977, 0.013272323928374265, 0.029786564343209778, 0.025249640024932365, 0.013176996543604349, 0.03665508595960481, 0.031223036548388854, 0.057913425245455334, 0.021186377254447768, 0.054915664318416796, 0.07939032066081252, 0.009140683487722916, 0.02555245324037969, 0.020710091472470334, 0.024642656524000422, 0.10077610239386559, 0.018942334722461443, 0.026179628247129064, 0.02679800774369921, 0.037575318544570885, 0.014398311231551426, 0.027834502215098058, 0.03771343434761677, 0.05691373281713043, 0.009112114618931497, 0.0770824398579342, 0.06349526465471302, 0.04199273079367621, 0.05993602957044329, 0.0605122550789799, 0.011210373902161206, 0.028696684432881217, 0.009349879226647317, 0.05732810736766883, 0.06570043561181851, 0.023654633201658726, 0.030845696439168284, 0.008390926040842064, 0.05764335473733289, 0.01017989803637777, 0.023212472642106668, 0.016111006561134542, 0.041008916084787676, 0.04580683380897556, 0.06489413244915859, 0.024400366935878992, 0.02932538105440991, 0.017719633278570006, 0.08222657668271235, 0.060719696804881096, 0.028823807968625, 0.0635113323639546, 0.07897582397397075, 0.027212823341999735, 0.030647055312458957, 0.060176746653659005, 0.03580892564994948, 0.09918740764260292, 0.012950381962582469, 0.048612576111086776, 0.04345348776717271, 0.02377597731538117, 0.021793976525909135, 0.03769062878564, 0.01333463125463043, 0.06605450875524964, 0.011294228107934552, 0.06548406436507191, 0.009283740722042109, 0.035105620710445304, 0.05288749261360083, 0.017593800655699203, 0.030281481000461748, 0.04571922815271786, 0.008105428190901875, 0.02444171516357788, 0.007146814272605947, 0.022554163056026613, 0.03826101889301624, 0.051161258814058135, 0.02174082348522331, 0.048962242169571776, 0.0028533156645218177, 0.05769125252429928, 0.04190551529505423, 0.0931438115824546, 0.03626860598368304, 0.03189564795632448, 0.02864989944334541, 0.0568222255845155, 0.03133724756272776, 0.04718394098537309, 0.03019153100571462, 0.03578430500679782, 0.08493760906692062, 0.03043590878535594, 0.03490055724978447, 0.017825325285749774, 0.032194963323750665, 0.033442907966673374, 0.03804854582995176, 0.018171525726627027, 0.044002412419234, 0.06790980670068945, 0.02899042224245412, 0.05488836006926639, 0.07160300495369093, 0.04669643393052476, 0.04095203788684947, 0.05960770683096988, 0.06689712032675743, 0.02298738052403288, 0.04235410836658307, 0.11307805084756442, 0.0645892938066806, 0.08224571815558843, 0.022227514601711715, 0.06127853824623993, 0.03827074569250856, 0.022737001102151613, 0.04284858736874802, 0.03924243837328894, 0.04690386887107577, 0.08463635987469129, 0.06826392734157187, 0.12284594242061887, 0.10795931837388448, 0.04324891963707549, 0.019637336089674915, 0.034908831984336884, 0.01714315840841404, 0.06077940110117197, 0.031820452705557854, 0.012539745291828044, 0.04774207675031253, 0.12030321386243616, 0.039022616775972505, 0.01808236283250153, 0.0328484400441604, 0.05026933131739497, 0.07015796285122633, 0.06067128333130053, 0.10010739934763738, 0.043176930464271984, 0.005635606100050998, 0.02774363280540066, 0.040436252885098965, 0.11322536758546319, 0.014547916328800576, 0.011698631586373916, 0.05384430841409734, 0.0411435001130615, 0.011024797119067183, 0.05411671308268394, 0.01960487158170768, 0.027971450937911868, 0.0358191579580307, 0.024037064019856707, 0.034053260393972905, 0.024303969162117158, 0.02072286998320903, 0.030149994484548057, 0.02815606674578573, 0.025706568899165307, 0.002404943328916228, 0.02519782878724592, 0.01452766205849392, 0.01337516778481326, 0.04326180162440453, 0.05638522867645536, 0.050700974584157975, 0.0824788220758949, 0.019018764906962003, 0.023171707954523817, 0.054632518440485, 0.01811151100056512, 0.030508220262293304, 0.016661827718572955, 0.014488946546667388, 0.03581677290744015, 0.022532694208036576, 0.03197508744363274, 0.022063404122101407, 0.011571572511456907, 0.023054324788972735, 0.07073678714888436, 0.08624283902879272, 0.03791161407051342, 0.042289460942681344, 0.018997061964390532, 0.05712558502065284, 0.08059047268969671, 0.09394071024975606, 0.01907319189714534, 0.023401485356901373, 0.02831903559022716, 0.030628636479377747, 0.024423043576202223, 0.044231516375605545, 0.09489794674196414, 0.025737398137737597, 0.04611740607236113, 0.03086524164038045, 0.0871290871873498, 0.09320914093405008, 0.033073581356023035, 0.02182430704124272, 0.07092566415667534, 0.11254120072615997, 0.15155741891690663, 0.12343040534428187, 0.15057241677173547, 0.15466988618884767, 0.1019666124401348, 0.11854048844959054, 0.11567731494350092, 0.1138165480058108, 0.09522042729492698, 0.07934465525405747, 0.07449795425470386, 0.10240837266402585, 0.11668940420661654, 0.08335141810987677, 0.08168429149580853, 0.1334608221160514, 0.1215317557965006, 0.08057167726968016, 0.16462909749576024, 0.22679178044199944, 0.08240826800465584, 0.09869608722094979, 0.15138595311769418, 0.07356446648814849, 0.2199568022042513, 0.06825269080166306, 0.09843704290688038, 0.17694748006761074, 0.14570770066763672, 0.16226908484739916, 0.13486868728484425, 0.08783976440983159, 0.11386169094060149, 0.1663154877190079, 0.09330300268317972, 0.11859042862696306, 0.08387962369514362, 0.12601201395903314, 0.13119307665952615, 0.1631540030773197, 0.1839282347687653, 0.11930025768067155, 0.1395731469882386, 0.09231823802526508, 0.10187192287828241, 0.12469976794506822, 0.14408426492341928, 0.08242280901010547, 0.1336864757218531, 0.11020056025258132, 0.16625334748200007, 0.09060898117188897, 0.17883838074547903, 0.07528728047119719, 0.09845167212188244, 0.09119386478726353, 0.10551173399601664, 0.12111955934337207, 0.13006137524332317, 0.13209607106234345, 0.08486511438552823, 0.21960863231548242, 0.08852481336465903, 0.10554596608770744, 0.20730695527579102, 0.13406645533229622, 0.10457118267991714, 0.13015577303511755, 0.0996425078649606, 0.20307054902826036, 0.17192885865058216, 0.13263906192566666, 0.12288122624158859, 0.0919648502022028, 0.18912327529064246, 0.144106086609619, 0.19935603120497294, 0.1942727861127683, 0.11485559546521731, 0.07902119761066777, 0.20299132327948297, 0.2895975788789136, 0.1465939488261938, 0.17041736761374132, 0.11714369697230202, 0.16343138819294317, 0.1331016599599804, 0.1516557793532099, 0.12345540257436888, 0.12460276457880225, 0.10282398893364839, 0.10595615407718079, 0.220042189050998, 0.27267648971506525, 0.11766144633293152, 0.1833903193473816, 0.13114296006304876, 0.19945805573037692, 0.0926978173000472, 0.13003369101456233, 0.19018516902412685, 0.12485911510884762, 0.20016536063381604, 0.1683532776577132, 0.11884307435580663, 0.09879697859287262, 0.12124960736504622, 0.14998089708387852, 0.16182083104337963, 0.13704711039151463, 0.18884830575968536, 0.1304607338138989, 0.16472669797284262, 0.09872345253825188, 0.145197510187115, 0.07518385137830462, 0.10576926517699446, 0.06977093326193945, 0.28164734691381454, 0.13358443762574876, 0.13085431126611574, 0.14475582460207598, 0.09019191962267671, 0.1865486962986844, 0.17721996616039956, 0.06045613344758749, 0.15171885596854345, 0.13306850673896925, 0.09374284943831818, 0.09276033073131527, 0.10835311295730726, 0.09817328277443137, 0.09531036711164884, 0.08930941019207239, 0.09408496679472071, 0.15853161896978105, 0.20533255407852785, 0.13731593239520276, 0.15663900838366576, 0.09009845142385789, 0.16564805353326456, 0.1413326290036951, 0.08627140535307781, 0.15589365123638085, 0.0651133196162326, 0.13182616340262548, 0.10582970229110547, 0.10228521177279097, 0.1477539858647755, 0.1024758665423308, 0.16385684322033608, 0.19595450801508768, 0.2187341092420476, 0.17863353102334908, 0.10866151390863316, 0.1384995145989316, 0.1924994077001299, 0.1422778418553727, 0.16031779455287115, 0.23874664466295922, 0.1673766350639718, 0.07849864422210626, 0.13383697478898934, 0.14281373524240085, 0.09599502930151564, 0.0835723966094, 0.241415268608502, 0.12255884068352835, 0.18012220971286297, 0.1203295953039612, 0.12481040986520903, 0.16682727954217366, 0.19635713712445327, 0.1107682158638324, 0.13690754930887902], [0.057379343546926975, 0.034764392234917195, 0.036355621314474514, 0.022901740922991718, 0.06830835781459298, 0.039538340709571324, 0.028305846565802182, 0.016796086050037826, 0.0337586710229516, 0.04048499544816358, 0.040699711069464684, 0.033656212235135693, 0.07434462569653988, 0.03936907336381929, 0.01700488823865141, 0.022957131432901536, 0.011995893537199922, 0.018720849018011774, 0.035542963671364954, 0.026421542944652692, 0.01940411512207772, 0.01636177105163889, 0.07227316685020924, 0.05572721594944596, 0.03448708175814577, 0.035177630239299366, 0.03590089089370199, 0.026836311045501913, 0.03731212838153754, 0.04140870552510023, 0.05413105731297817, 0.08455600775778294, 0.034346747145588906, 0.07243586597698075, 0.02840121805534831, 0.026964998604463677, 0.03657403834430235, 0.013714057859033346, 0.04985769804833191, 0.022053450013377836, 0.01936116215905973, 0.03556134179234505, 0.053499673692775626, 0.014228581633817936, 0.055657662717359405, 0.08325562932129417, 0.03227354107158525, 0.05685830668413213, 0.04859079174431307, 0.034228420816361904, 0.0599063029512763, 0.009418536792509258, 0.027231479662337472, 0.03931741988552468, 0.09655091233019318, 0.022455198723556738, 0.03201349252568824, 0.06472568613077913, 0.05071420940969672, 0.021031204777370607, 0.0773887780628034, 0.04013374840308513, 0.022991967420758944, 0.043860395039830885, 0.07141494897327252, 0.03473165292026741, 0.02521408987896783, 0.05246234292696629, 0.0385780711658299, 0.05351823841088584, 0.012174880048925323, 0.01692508064609553, 0.08327608715210642, 0.05758289048182113, 0.06956077061061348, 0.09831878782383033, 0.07282193883189134, 0.00329464692705577, 0.03756711505619543, 0.014373373373278549, 0.02549673194464828, 0.03333583174805556, 0.037272932806185315, 0.02531990402245096, 0.02641010793325092, 0.06169265495347125, 0.03901549894362688, 0.04314100542770965, 0.014528893599552768, 0.07809660543820687, 0.01117681949732027, 0.0621021372665252, 0.05793049040117434, 0.007968029090469437, 0.04061437172016927, 0.057737969660333226, 0.058017288600759845, 0.04385640525392123, 0.02779575447285814, 0.03366105697516884, 0.0626379492293511, 0.09099611932677881, 0.019861578342637846, 0.0642929979200874, 0.06126483862421342, 0.02153707977517375, 0.00030892925445056917, 0.01863352325744927, 0.04850495706445404, 0.05300064850598574, 0.0872707110164421, 0.023428078840619752, 0.03317215892353228, 0.06633462158164807, 0.0847820413431951, 0.061582447295742374, 0.022150153127898062, 0.0508713513346655, 0.023259951433699046, 0.02513303717465273, 0.03484170112226691, 0.018111036026052067, 0.06493045442870685, 0.0451958435587585, 0.05365016258188656, 0.021812476783192584, 0.05025236794192876, 0.019930807574252998, 0.011938625181625997, 0.06201765287135329, 0.021616873797029257, 0.018032271681087356, 0.02360166675810303, 0.08063953755689518, 0.015967735588284473, 0.028029195964336395, 0.030446063061910014, 0.07874422640140567, 0.008789504296146333, 0.0230537158037935, 0.0370872890177582, 0.040519722870418, 0.10306537098118237, 0.02196488931908139, 0.04629877848284585, 0.01242921024095267, 0.046760711552841325, 0.036495983068432124, 0.008779026019120855, 0.08555901143699884, 0.054250323413206, 0.007335647175620709, 0.03854178311303258, 0.011108799754375858, 0.001513042761611619, 0.05690933591020959, 0.043905449765069146, 0.017501918532486473, 0.010294148066480244, 0.028937815422458307, 0.017381646504093493, 0.01897243283955114, 0.017136174586734602, 0.046028233000210354, 0.05737400347633021, 0.07645627417202507, 0.019469517416187694, 0.010504504100286534, 0.027995001192071607, 0.04105357386704002, 0.019783063359292488, 0.02695039483452482, 0.008251616016163357, 0.012767977330700626, 0.04306720117373126, 0.06699677676494632, 0.04408016913969602, 0.0023424748505931348, 0.01810757889013205, 0.051635045890829394, 0.04057039925828576, 0.07953478076628276, 0.057199993170797825, 0.06530344512845788, 0.00366402421579031, 0.07968254533729383, 0.06158668135425874, 0.024408100538754036, 0.05000934723232474, 0.03416374285838433, 0.022149048812155212, 0.020845542329230478, 0.021122058920030082, 0.025942826310970953, 0.06836302738104548, 0.05662686178194625, 0.0189841511393232, 0.011591996415518224, 0.03799930454364844, 0.018773986791659678, 0.04156141661639724, 0.01624774493809257, 0.04749404166692069, 0.042954089386122565, 0.04161885121305074, 0.010774652639936124, 0.06168539462877171, 0.07664098497480154, 0.013569609627925923, 0.03023621253669262, 0.06055081622408969, 0.027152579610369036, 0.017260416044986675, 0.018476128578186035, 0.04010945684941752, 0.026893275756654993, 0.02262072225234338, 0.006834262383303472, 0.0602400539708989, 0.027449384398226227, 0.0475724056762244, 0.016467442702768103, 0.018210678893540586, 0.01241581595968455, 0.07848529065293924, 0.053973270779741664, 0.018417562524388944, 0.055798943886267285, 0.0412522353497999, 0.014203321471411203, 0.017608670750632882, 0.04068677479933415, 0.01828487839416734, 0.03749465769422906, 0.020602830353059938, 0.027940733657617654, 0.04295643711728709, 0.08241790320192065, 0.016626932358901416, 0.03365762698064957, 0.03696196699248893, 0.004690079425927252, 0.011880095599086156, 0.04311453916930726, 0.03662561718374491, 0.003762503819806235, 0.005707151256501675, 0.005646668341276901, 0.06371293868869543, 0.019478309533691833, 0.028184283624536226, 0.07843934704682656, 0.07208589797041245, 0.016959071857854724, 0.025546767116923417, 0.014186962840280362, 0.03438539310757603, 0.06469112155692917, 0.05413479943360601, 0.06721390797091381, 0.01798291504383087, 0.044127018590058596, 0.005411541538446077, 0.0067662774152787665, 0.05724833879087653, 0.05469245343868222, 0.013603821363566177, 0.055171662010252476, 0.029491863013910394, 0.018817740425999676, 0.06079684623650142, 0.050815297556774955, 0.02737769378083093, 0.02975404215976596, 0.08019629812666348, 0.011622505894462978, 0.04103920928069523, 0.0796272379479238, 0.01636536728723773, 0.03589310470436301, 0.009638330400256174, 0.026831610494160225, 0.03753405683008688, 0.014396504632064273, 0.06288126510168825, 0.09415325455899749, 0.05047209454434259, 0.03183564849730049, 0.03578743305323379, 0.008438029941836638, 0.03403551331056016, 0.023176578139620166, 0.02531110342325909, 0.038220551064504046, 0.02084554572190557, 0.02925672009587288, 0.037152472484324656, 0.027706087766481296, 0.03474431777639048, 0.03385492800069707, 0.04930494645876544, 0.02901003190449306, 0.05203054698982409, 0.01925066442761038, 0.03997573795329247, 0.06327860163790838, 0.02945578530696886, 0.04822172636964491, 0.026874982452552234, 0.07533660996705294, 0.0528675267206771, 0.02302175510807761, 0.01069681449527187, 0.06296072155237198, 0.11346702783235482, 0.01993879223508494, 0.09164768257843596, 0.010819965208481466, 0.03625061123498848, 0.0449300681773041, 0.03331377596727439, 0.053346789575048854, 0.02542092601236488, 0.012743844384593623, 0.023316524290878857, 0.06791044452360698, 0.04464021498071296, 0.07857166137546301, 0.024209729129714624, 0.025564414116420915, 0.03133010258898139, 0.06321765562253338, 0.03574122142578874, 0.04604895206700478, 0.0363028618240995, 0.01870004683067756, 0.04913146880322269, 0.009404175598839564, 0.03941673366352916, 0.04890344711020589, 0.02504650699639959, 0.08165662083774805, 0.021922119560518434, 0.040011520497500896, 0.0816855603562934, 0.015981530205213597, 0.04184183478355408, 0.03551601226042424, 0.038954410435897965, 0.04460012373913612, 0.07519285553800208, 0.06380806251295976, 0.19551561799432549, 0.08956521110875265, 0.04883443331345916, 0.09281636415315525, 0.217350196359413, 0.12378724691058908, 0.14857810735702515, 0.09992454094546181, 0.08657591151339666, 0.139934616163373, 0.19232015231890337, 0.13613571572516645, 0.14809405404542172, 0.1740228720009327, 0.07910953608474561, 0.10196020706955876, 0.19188038020261697, 0.07194923423230648, 0.1159547543419259, 0.144748984969088, 0.11885982060006686, 0.07980972994118929, 0.15769360108034952, 0.12358053800250803, 0.14382446743547916, 0.3732596981738295, 0.09460627167884793, 0.08406027685850859, 0.201988353527018, 0.12143958359956741, 0.18143193157655851, 0.1844935222928013, 0.12074867210217885, 0.27354105189442635, 0.10789014851408345, 0.0799537082867963, 0.11842558532953262, 0.11030739559126751, 0.1534991961504732, 0.16321623830923013, 0.07466839546603815, 0.12251884782952921, 0.143162570095488, 0.15357186725097044, 0.19136136876685278, 0.10742995927908591, 0.08995763505143778, 0.06757944835616009, 0.29300523602536743, 0.10710848974330084, 0.13324169601712907, 0.16380053838448866, 0.07961700563984257, 0.15850861663264887, 0.17611258343926497, 0.09637942617493016, 0.06437645094203097, 0.1240344372178827, 0.13756870026034967, 0.09187936836055347, 0.12683821176843985, 0.14339066642735684, 0.1343444511294365, 0.14489197943891796, 0.19897248250033173, 0.16481573533798966, 0.15443121828138828, 0.16759107927126543, 0.1459526518093688, 0.19063864754778997, 0.07960107363760471, 0.13229283264705113, 0.15395190114421503, 0.23190359185848916, 0.17064573535961763, 0.2682017683982849, 0.15937488872025693, 0.09633958259863512, 0.08074513117649726, 0.07412733842751809, 0.11777438170143537, 0.14503202906676702, 0.10392872536821024, 0.13107427874846117, 0.11325976252555847, 0.15755953613136495, 0.12651379060532364, 0.09358086955866643, 0.14507667667099408, 0.11466484570077487, 0.17039023978369577, 0.15301966188209398, 0.18459033566926206, 0.12656842624502523, 0.09987409865217549, 0.1595277762306588, 0.28319630665438517, 0.2656850277313164, 0.11181085955883775, 0.15785160474479198, 0.16958430302994593, 0.14320892760796206, 0.14097576029598713, 0.15269581068839344, 0.1730041873774358, 0.09489129709878139, 0.131417861740504, 0.08482363553983824, 0.31949220331651823, 0.1251830748681511, 0.1736481035394328, 0.0822567239935909, 0.10556377763194696, 0.16442439705133438, 0.08152428615306105, 0.09560137042509657, 0.09215239049600703, 0.15405712835490704, 0.06749075704387256, 0.13465166464447975, 0.09401613620242902, 0.09474254865199327, 0.215278615376779, 0.15132617418255123, 0.20823493333799498, 0.15472562105527946, 0.1427116021513939, 0.054495752922126224, 0.0942383496356862, 0.11665383540093899, 0.169322293517845, 0.14980054247592176, 0.14125560170837811, 0.15627302016530717, 0.1860581019095012, 0.08196479787251779, 0.08116331230849028, 0.1518641167453357, 0.16959794158382074, 0.06919078582099505, 0.2059230831052576, 0.0807989254327757, 0.23178566247224808, 0.1402023389403309, 0.0922427238630397, 0.12439677491784096, 0.12374394280569893, 0.14748095694397176, 0.09199435290481363, 0.14951357644583496, 0.10528389550745487, 0.18111999545778545, 0.12145732050495488, 0.11144156687493835, 0.11805399241192, 0.22957464254328183, 0.15381703552390846, 0.1159706184906619, 0.0817890844440886, 0.19613159208425454, 0.13907521085015365, 0.14308700843581132, 0.10327121814978973, 0.11954538524150848, 0.13027362099715642, 0.17157668540520327, 0.1299737628017153, 0.08087178652307817, 0.1782714511666979, 0.168169448950461, 0.12283382378518581, 0.10234950296580791, 0.10201025581253426, 0.0861744766256639, 0.14830316496746881, 0.15655055455863476], [0.03325468574517539, 0.025408418915633644, 0.08483460745108978, 0.15127813390323094, 0.02266244706697762, 0.0602818720840982, 0.047842683137527535, 0.016222771456731216, 0.044876165355422666, 0.006824212431508515, 0.018292415221886973, 0.0748540765738913, 0.05347768237282123, 0.047464206482150724, 0.06005524817321982, 0.030488705595156977, 0.015499797483373965, 0.029452901533139602, 0.027196815004572272, 0.04064338927024177, 0.04357373774317758, 0.048898632904248576, 0.047457122576556036, 0.006340405512933752, 0.024393586674705148, 0.08234133731041636, 0.040585014902587445, 0.005752370102397565, 0.03294229840061494, 0.022988070933414356, 0.02462216985544988, 0.04055792439196791, 0.032944968435913324, 0.038304540129112344, 0.02638939395546913, 0.035208829279456816, 0.011251793376037052, 0.023235754874934043, 0.04590944526717067, 0.03940369900582092, 0.037508594803512096, 0.08112886987094368, 0.039242726750671864, 0.04211373733622687, 0.024401388131082058, 0.030753300325678926, 0.056517203737582476, 0.019565153534391096, 0.024846310328160013, 0.007301980812501694, 0.05281145597941109, 0.017354014861796583, 0.039661796763539314, 0.018847375442939143, 0.05374889960512519, 0.027876125249479498, 0.020481728815606663, 0.02218233434749501, 0.03489485416295273, 0.04355385327445609, 0.0016114608733914793, 0.0025159614119080027, 0.02141277046341981, 0.027791576393480812, 0.01876167647008385, 0.053669086923556666, 0.02454721718095243, 0.0791470929980278, 0.04059529131544488, 0.02273718430660665, 0.06468782387673855, 0.0314836686344019, 0.04701390689504998, 0.08287353268159287, 0.05779795894133193, 0.05380127911588975, 0.028424057544076016, 0.01982336155405002, 0.058631627421293936, 0.029418174110885178, 0.014420278802780169, 0.016596796922385693, 0.02805138914845884, 0.024436356433268105, 0.02455776840049241, 0.06516252697578498, 0.026909311235483204, 0.07069954914706093, 0.045423380099236965, 0.039916220254131725, 0.026936203274609785, 0.05429316611428346, 0.02944126465756978, 0.04930901088352714, 0.010412811966879027, 0.02976364003760474, 0.06985553979341473, 0.08499814117593424, 0.01921444253197738, 0.0825977489086134, 0.06540602605257716, 0.007176304252685181, 0.03203943631212626, 0.07947091026497738, 0.014363149546885064, 0.04010607774502464, 0.07523584073143345, 0.027199675029675876, 0.01918757933058909, 0.0645753431266972, 0.02002729695024235, 0.03262786188029817, 0.0535890469327569, 0.0075411279353180104, 0.0378585594174053, 0.034678788256964514, 0.01971591723018459, 0.05248584059466209, 0.0706016161878194, 0.009568750026768871, 0.015917215263471007, 0.022768905818728463, 0.02909869946805494, 0.01723963251736547, 0.033958604758871455, 0.015213124919682741, 0.030321222796503986, 0.05662476171606353, 0.08228696629937206, 0.07272542401083879, 0.01407773227297834, 0.046263046828763824, 0.040852798747697046, 0.03975961097915258, 0.029609965426581245, 0.10624134234551873, 0.04195031896233559, 0.017512888747400472, 0.05626700412748115, 0.012822495074942708, 0.02084230910986662, 0.03693703422322869, 0.034755788410880735, 0.07717773331595318, 0.024004624956952672, 0.08778841966497046, 0.030699960687862973, 0.04162977562685098, 0.012826161708549728, 0.03618445746334536, 0.03513934729354722, 0.04684615268238953, 0.024238344647788575, 0.037232023929911, 0.057180648137416155, 0.02707763881023441, 0.01803625128897173, 0.030776231416634152, 0.006715449629284973, 0.047742595829601796, 0.07809682935476303, 0.012151967617683113, 0.041198458056896925, 0.013101279669042145, 0.013017480594239064, 0.03163241708119001, 0.009241231351292558, 0.04023790013577257, 0.013549507179829692, 0.05633936310186982, 0.05271006249157446, 0.016889148824183003, 0.03408863581717014, 0.018273614712857773, 0.09584360742675406, 0.06824672647884913, 0.01721820268513901, 0.039574225034032545, 0.05852631200104952, 0.07818533746259552, 0.005941359916635389, 0.07965576356010777, 0.05223639415843146, 0.05002586277467864, 0.028420116951955215, 0.03968708237100925, 0.02123555407992431, 0.06245996949395963, 0.023547845360423838, 0.051791682307209284, 0.05428143763648612, 0.05007104981424553, 0.04398129640945366, 0.03673148561002953, 0.009078459282006537, 0.03859409137762018, 0.018538781109132936, 0.05648338555225304, 0.024444609115432416, 0.017360825657046268, 0.06986353972128459, 0.062150876436914713, 0.0692444307995694, 0.0313859222722905, 0.014636426132970622, 0.0055425535039311, 0.05171880764620645, 0.06233530904033354, 0.06850051214652401, 0.020005385358152643, 0.025275022323642458, 0.04525411953883512, 0.06274078121142727, 0.02267898466171963, 0.0010656705230108596, 0.033187198652220626, 0.014865713293797203, 0.020048077085188458, 0.009456610240574394, 0.02715501724742353, 0.02055370950672243, 0.04451575130224228, 0.019532622869259546, 0.02924077113025955, 0.04307165236345359, 0.03509674886507647, 0.03355879496250834, 0.030832912839416946, 0.06596975973142044, 0.01936697041881936, 0.06879434495099954, 0.07667982431926898, 0.017931105502481972, 0.029354435923908438, 0.036368757752435546, 0.024826098466292024, 0.014494817570916243, 0.023351346708035896, 0.049226294072078805, 0.025885045661457946, 0.09249541030398437, 0.07756818950708423, 0.027821755934772745, 0.013638546241314282, 0.02821426130166011, 0.02897558268159628, 0.03856437493647848, 0.010432855043161129, 0.06467400890375886, 0.06270785190697227, 0.07223693986556359, 0.08104312340063707, 0.0395610444912953, 0.01422274368815124, 0.052524591729577096, 0.05982472947133439, 0.02605959031331752, 0.018300057222534503, 0.009011894148508353, 0.03332913800009659, 0.06265513652137347, 0.029068406272147383, 0.0851497801819018, 0.06760521233081818, 0.03828027232417038, 0.04213083302602172, 0.0020849722953114125, 0.07624872388052088, 0.027238180195646625, 0.02050750296829002, 0.11966093975518431, 0.043905968844358406, 0.016003248414822986, 0.028768130777669803, 0.11328784708998033, 0.04492726243500199, 0.02715738533463861, 0.03742439878572311, 0.02944019596491541, 0.07149099917816264, 0.06160956834043775, 0.022311052440532615, 0.05865707926984344, 0.039979018670107634, 0.055588669276663234, 0.016534188496215, 0.028848415041076284, 0.014789513811202986, 0.04267428529315761, 0.010287218527602298, 0.02530671839070107, 0.03471155810569014, 0.0487567987293005, 0.05238715785422495, 0.03573545387813023, 0.015009203094190784, 0.0187999305780977, 0.04708648639331971, 0.02315940611463572, 0.0518195361697248, 0.06040833744087389, 0.021935809004519666, 0.019675023620948195, 0.06540167664310761, 0.07062508671411447, 0.013881594092319054, 0.042656456785542626, 0.03264691175094672, 0.06094547254698617, 0.020009797532111406, 0.029589968999581676, 0.0729288827361805, 0.035270677746406624, 0.017540422002119676, 0.05500541075265833, 0.07017949276736804, 0.0789785652554461, 0.053827633416014056, 0.03966571191059692, 0.04866207863337227, 0.014523348272112864, 0.03737451967650226, 0.013702091045810707, 0.03613888705149293, 0.026598640584519932, 0.04304565429421408, 0.026990404651899422, 0.07079372302229915, 0.03541103271501405, 0.008584270353562065, 0.06242459746343749, 0.035063904377498796, 0.03417198366618582, 0.03436813456937671, 0.004930397445735122, 0.08630094198243958, 0.009331446822865732, 0.06024499370583466, 0.03384425125217863, 0.03770848104198064, 0.022944897446515303, 0.060388517432979176, 0.026776321764503206, 0.025777351975973164, 0.028451002169666544, 0.06186302152595349, 0.029739826851125275, 0.03854254985760365, 0.0671318323750581, 0.020503877894952893, 0.017296495448265756, 0.04400579830897706, 0.15328886386539253, 0.1325046034263713, 0.24950989282556943, 0.16349679896874086, 0.10242949545915637, 0.157065019809774, 0.12322019519550459, 0.1169575069631849, 0.1268662488354104, 0.0856965369145785, 0.055577785574964116, 0.15721273688333376, 0.10496011216725622, 0.09653698879161052, 0.1724230899874653, 0.1340180350733655, 0.15162439032324723, 0.11762880879853453, 0.1492657076035227, 0.08869323932698794, 0.11490348646683352, 0.22428078018128872, 0.12538245559803077, 0.07115579609360013, 0.16638841666281223, 0.15971906882311615, 0.14730554207095078, 0.06674253647880894, 0.09501431549766234, 0.10436739825776645, 0.16891633958688804, 0.14517894546900476, 0.13106768338807992, 0.12071599385568074, 0.15535011754504272, 0.14740907294409616, 0.1896418524639947, 0.1172423152519124, 0.05642890597560576, 0.13340591506234237, 0.12084506478692804, 0.2293687750186239, 0.12184006853827409, 0.19915686760629925, 0.11970193684101105, 0.10065575063760791, 0.09006548140730176, 0.156303432104843, 0.10181905821497951, 0.11377494023846728, 0.1419995610735246, 0.10604599211364985, 0.10908000038138457, 0.09855176282248326, 0.14259340135114534, 0.35918392347437994, 0.20684591787202017, 0.09353774865823132, 0.11572013050317764, 0.20467052103153296, 0.1489219753337758, 0.0988202862707632, 0.12270768412521907, 0.14113859512976237, 0.1723133573042495, 0.1752950165952955, 0.1205640970064061, 0.20063770243099757, 0.11403834074735641, 0.134468799456954, 0.1377909883324589, 0.1444310506007501, 0.12453140983624117, 0.2706446573138237, 0.1602673658302852, 0.14896587654948235, 0.12775973017726625, 0.12003250553139619, 0.1352099496871233, 0.262978867228542, 0.13730704358645848, 0.07040624559989997, 0.10563975998333522, 0.1352480562137706, 0.09746327730161802, 0.14513758197426796, 0.23549070794667515, 0.2489709731723581, 0.14588274913174765, 0.0916134233453444, 0.0732534531770008, 0.19688168540596962, 0.16228731029800006, 0.12402553483843803, 0.11809336101370198, 0.16203917004168034, 0.1965383059744324, 0.13849309565765516, 0.20885561646095344, 0.13569172312106403, 0.12361096351274423, 0.1038979266637138, 0.13111324022923196, 0.21253523044288158, 0.16413102565067156, 0.1286173848701375, 0.15166936362428324, 0.1833781599998474, 0.13836158200034074, 0.1302305068820715, 0.20260166775967392, 0.09726372015263353, 0.23488806028451237, 0.1131769133997815, 0.18751427877162183, 0.11983433259384972, 0.16927067057362624, 0.17597751425845282, 0.19245974054293974, 0.11586758973343031, 0.09505371802619525, 0.14101469463535718, 0.07464174939585583, 0.08709432583834444, 0.14762363928769315, 0.07698388264647552, 0.09451392984816007, 0.3234166327331747, 0.16274692277823175, 0.11823552767080919, 0.12086102393056665, 0.10608500787722212, 0.14250137843191624, 0.14397780277899333, 0.1084368848907096, 0.2329697875039918, 0.18171702484999383, 0.0763158377792154, 0.17033736833504268, 0.1494661197066307, 0.09425062433417354, 0.11476053270910468, 0.11777655301349503, 0.22226505620138987, 0.0871188413085682, 0.13347038945981435, 0.10445424395480327, 0.10742535881165947, 0.0753630321206791, 0.13889743467526777, 0.16002622805535793, 0.2306061243372304, 0.10561755831752505, 0.09873665004436459, 0.12691871316305228, 0.09846328864140169, 0.11650272565228598, 0.14761445192354067, 0.1892843052212681, 0.16177850402891636, 0.16097154947263853, 0.18529536069503852, 0.09012583031186036, 0.15155903383025102, 0.12161902897059917, 0.1647602990269661, 0.09496186474072081, 0.18090236213590416, 0.10719106066972017, 0.1755045617797545, 0.11547926414225783, 0.12518430980188505, 0.16874779148825578, 0.08887728516544614, 0.1486498692205974, 0.16381132709128515], [0.06227610007460628, 0.0029761958118927267, 0.05349591460877231, 0.015643502718635967, 0.06506722673241581, 0.0573391674884728, 0.04168671150026577, 0.055615593546203206, 0.027717870527080128, 0.07285293431154319, 0.03123123325141413, 0.02578433070863996, 0.030331421177834272, 0.052702164343957386, 0.006086236048888947, 0.0037527528475038707, 0.045280785965068, 0.011654927145822771, 0.030643598176538944, 0.0025884287398574607, 0.02534631939072694, 0.020639048856017844, 0.05127968013818775, 0.021779080985912254, 0.05550555891490408, 0.017839813704735467, 0.08054706680455379, 0.02198979664327843, 0.04456363891118339, 0.08886995020189456, 0.022231195654187883, 0.09001655224710703, 0.02805660877908979, 0.0030714097540892127, 0.039392238549355946, 0.016861927695572376, 0.05347125664619463, 0.052240794458027394, 0.055098777171224356, 0.01220696372911334, 0.08813654205628804, 0.03797786622973425, 0.0056703627841281036, 0.010884008736216595, 0.028413414722308517, 0.04811658397583025, 0.031448734258966785, 0.055768409810428105, 0.02242565361250724, 0.038445631308215, 0.029078641972903694, 0.029495357469256436, 0.03160487534478307, 0.03733304761616247, 0.03479643265849777, 0.015017238645149129, 0.07282712962478399, 0.003678443084936589, 0.06892819955412831, 0.010034425217392189, 0.015330538619309664, 0.01870530378073454, 0.05185655704034226, 0.02932045828284962, 0.058129104386482916, 0.05490540147625974, 0.0489266326517931, 0.022945855877229145, 0.031443126167037656, 0.037516299568648846, 0.027504856332338283, 0.0626753093674779, 0.06828104678009238, 0.0762972119929535, 0.05918356816151312, 0.04440035285162074, 0.0315114308946899, 0.028787333318697553, 0.03026538614981941, 0.06184736093772309, 0.04729951585509947, 0.040871804513569386, 0.016392396729705588, 0.07881494332104921, 0.03942346812358924, 0.026518754960436906, 0.026608503091015985, 0.027185368118807673, 0.051189149995999675, 0.047535910670246394, 0.03250291304928916, 0.024577839466344033, 0.047315614098416905, 0.04733350706685867, 0.039944094472697804, 0.09180669726005622, 0.07553796523383685, 0.057047288864851, 0.033584525010415485, 0.06644131442798035, 0.02453536487051419, 0.03741261602512427, 0.041471025573887994, 0.03611809673852154, 0.03590564403150763, 0.04848924558609724, 0.051634092549128194, 0.025919498277029822, 0.027179151041699306, 0.05643186778096216, 0.038563007688415904, 0.050879632854568105, 0.05495585394757135, 0.08663173458938088, 0.05961616816265242, 0.01024656240562243, 0.06679004071546452, 0.05848552526107856, 0.013954409381507762, 0.01841937760556383, 0.057113059264208586, 0.048560881920691044, 0.009286635522065418, 0.033304096665233374, 0.04140754183754325, 0.047669524393443546, 0.03168438607826829, 0.031817331444472075, 0.00874048947090549, 0.0770001607015729, 0.03997657255136541, 0.10323074353592736, 0.02438717960779156, 0.038792769823755534, 0.009420532533632857, 0.008772756355548543, 0.05257352428244693, 0.016128818105374063, 0.08252268936485052, 0.03291747758963278, 0.009767697342405362, 0.0057632762805691785, 0.05039307235607079, 0.03106139593624643, 0.02705900284594723, 0.01646572261649583, 0.042477306577243974, 0.06632789051426308, 0.01585110729294164, 0.012072465365885623, 0.08431251546634094, 0.03485780954360962, 0.0262101606266307, 0.03488555484052215, 0.05517056617619736, 0.04005330468394926, 0.007254681832689259, 0.044213725187416585, 0.04290099062823823, 0.021743625834850327, 0.05155499911467944, 0.025407881176631366, 0.022956225588651638, 0.010746471384274108, 0.028958887327462435, 0.02242319901207728, 0.07465954736939498, 0.017456775597695793, 0.013242445486996855, 0.05582325918866055, 0.0262029053909438, 0.0480640450093363, 0.015897532658917562, 0.03991817782766052, 0.0028607089396765722, 0.062295546888240745, 0.0546214752830565, 0.021584207424893975, 0.026709065373454775, 0.014686035524521555, 0.03231536257745964, 0.01787884303900812, 0.03218806601528611, 0.014353824779391289, 0.021805928920262625, 0.07237358324761901, 0.07900936395994254, 0.04501313443428703, 0.020521974423900247, 0.0373322808715914, 0.04214222902165992, 0.03519690063382898, 0.012852072416405593, 0.04477835792515959, 0.07224673112588269, 0.03848426369950175, 0.016598009803731526, 0.053882672784051726, 0.05043335698012795, 0.0535411016483392, 0.017192355589941144, 0.031585034980837784, 0.012035307940095663, 0.01239986699407122, 0.053916830236890485, 0.12716222581054482, 0.012290175022956516, 0.04145552104871188, 0.026376094669103622, 0.019284748937934637, 0.015064111844237362, 0.01427877032464104, 0.019664075458422303, 0.009929925735507692, 0.05285155400633812, 0.029691009649208615, 0.037326357260878594, 0.0636875004108463, 0.0383706803300551, 0.04544236211638365, 0.03268699620717338, 0.010756098099851182, 0.0021044695749878883, 0.008206569772612835, 0.0812309215377484, 0.06386671507997171, 0.030552202902202095, 0.05192289401644042, 0.07232778891921043, 0.06792953171368156, 0.021671872452965806, 0.03336741416049855, 0.02174425856875522, 0.02552401414141059, 0.05412694199809006, 0.10033086128532887, 0.02650195443337517, 0.056759878394326994, 0.025823907959940176, 0.07793615904769727, 0.060561577789485455, 0.034902660708342276, 0.015071041383115309, 0.06285519578627177, 0.05261449422687292, 0.008868950568804783, 0.03736252657004765, 0.00994463891921831, 0.1369335236293929, 0.06837421642350298, 0.07566478342882224, 0.08762040760900293, 0.038822333594518046, 0.0018493478294528487, 0.06818453874439001, 0.011413292343994337, 0.07736350263335875, 0.06346989423036575, 0.061783090100756714, 0.06448375446988003, 0.03171264027644481, 0.09039139534745898, 0.03374659649229475, 0.025316299305164387, 0.025932115635701587, 0.07553446399314062, 0.034623090709958754, 0.05822962934949568, 0.056490245541291575, 0.06684494776917355, 0.15085225818412645, 0.09201157412358693, 0.014815442330603088, 0.11116708588919469, 0.04821665771305561, 0.005446170573122799, 0.06384354989443507, 0.025300977984443307, 0.04715282676209297, 0.030315767374954054, 0.06154003207172666, 0.025819370257002965, 0.014698003185912967, 0.02458725413972778, 0.02186870189117534, 0.05032808566465974, 0.019144375309614197, 0.013156475948302873, 0.0461371005512774, 0.029602409939148595, 0.05510519611250077, 0.008036751965326923, 0.09273197475288596, 0.024972884250538688, 0.017919390595385006, 0.023192472822432007, 0.06134376581758261, 0.03941589567278113, 0.014879635136042322, 0.03664803258808596, 0.029309354057269435, 0.01349377231339791, 0.011716544910866235, 0.06699597609362432, 0.05698503327689, 0.023350145701052885, 0.009850336970495326, 0.07624907671873059, 0.01187476231383958, 0.01760568350021328, 0.04348260031214782, 0.09406593388744763, 0.07589792127587966, 0.022281797403203588, 0.053787352184631994, 0.0357289908320776, 0.03416886579777513, 0.0449186721816659, 0.028583708352276256, 0.03066115527014647, 0.03350764699280262, 0.07955930980720691, 0.029848311029906784, 0.03438901648457561, 0.021911125596878783, 0.02193547991503562, 0.034857086903814755, 0.06275071496410028, 0.046600516220288615, 0.03699848235451749, 0.020061985356733203, 0.05594569065475038, 0.02512915086533342, 0.03572625294327736, 0.04061078905527081, 0.048356507173074145, 0.024928058530869227, 0.03351068004433598, 0.05531870394146868, 0.05303097902131932, 0.03291906196890133, 0.04307547251560858, 0.01505662251396903, 0.02085889080938484, 0.01983277453109622, 0.0498491688631475, 0.013300067528949251, 0.019937401238296713, 0.042321022999073775, 0.06033570705247777, 0.05040805780195764, 0.07404819410294294, 0.10372882216636624, 0.13375099083142622, 0.1508012187800237, 0.0764361284673214, 0.10162218806466886, 0.12663345704121248, 0.07735219145459787, 0.20991884012307438, 0.12147356463330132, 0.12123894079455308, 0.14183053800037929, 0.1027565561234951, 0.09015840677810566, 0.14677822536655835, 0.12311685431216444, 0.08990753881101098, 0.22681046729641302, 0.16322671488991805, 0.13678674293415888, 0.1021730499342084, 0.16902272030711174, 0.12999110615679196, 0.1552074080599206, 0.11223789557282414, 0.12109617702662945, 0.11083415589694466, 0.14187905325421266, 0.09771991281637124, 0.07272449441786323, 0.32895545980760027, 0.08505515847355127, 0.19634123226361616, 0.12227283817316804, 0.15326050110161304, 0.20584091251449926, 0.07902547238128525, 0.13373756940875733, 0.17691929372293608, 0.20268712245992251, 0.08699154135371957, 0.18182082713714667, 0.13565231380718096, 0.25809697061777115, 0.14763635503394262, 0.11852039024233818, 0.07334614784589835, 0.10461744519748858, 0.13397154185388768, 0.11723160796931811, 0.10984365761812244, 0.10529285216970102, 0.2850668919937951, 0.1279772956456457, 0.11187942552247218, 0.14301549084484577, 0.06644778086670808, 0.09518901790891375, 0.24461537546345166, 0.22479653464896338, 0.1222035326063633, 0.10816357098519802, 0.1619876828044653, 0.12424877285957336, 0.15262813360563346, 0.1121416250243783, 0.16606831098241465, 0.10900951416364738, 0.12934504582413606, 0.17805711552500725, 0.10417296404817275, 0.11406367724495274, 0.2928678462547915, 0.26788983227951185, 0.1797702671693904, 0.15827791472630842, 0.15955540617661818, 0.15883448986070497, 0.1157125716230699, 0.1371394454368523, 0.15784289235515253, 0.08928739173071724, 0.16912407986819744, 0.11922460102609225, 0.2095267554478986, 0.08599487519157784, 0.1249274435852255, 0.10088722607386963, 0.10389936515795332, 0.16030575734164032, 0.17142436786421708, 0.1314092172043664, 0.09028211728270565, 0.13191317873341696, 0.2734153057847704, 0.31807626358100344, 0.19413097229387077, 0.15475930353360517, 0.16097815840372018, 0.11556387745908328, 0.20746322189058575, 0.14236488432756492, 0.17489922711891787, 0.120879520795175, 0.1260500933442797, 0.14750124514102936, 0.09644509479403496, 0.12839566676744393, 0.1752563672406333, 0.09777920999165092, 0.12082612008920737, 0.15798340338681424, 0.18573689700237342, 0.14623011834919453, 0.2334797472826072, 0.16406660553600105, 0.08921985714031117, 0.216373350205166, 0.11668933635311467, 0.19459927002234118, 0.0884011300014598, 0.11675024165638856, 0.155249558655279, 0.11414275371602603, 0.1384773536452225, 0.1223835072347096, 0.11125560078237738, 0.07143575285694428, 0.11372094920703343, 0.08024681505880185, 0.11160757725260087, 0.11952878827495234, 0.2137643423463617, 0.0658077798517687, 0.14320928044617176, 0.2072827722877264, 0.11251885656799589, 0.09574224108031817, 0.08921942287789923, 0.14972603933087417, 0.12519950898630278, 0.06990602958415236, 0.12948976377291338, 0.14002313784190587, 0.10741813919906106, 0.0727909297815391, 0.15307338828487055, 0.19190463104418345, 0.13602360816938536, 0.08365791916315045, 0.08105915718312774, 0.14799582931612218, 0.1827129242675645, 0.1139993385544845, 0.1766216339809554, 0.0841549528496606, 0.09969630212123905, 0.11029166036418506, 0.12678307401282446, 0.1783961659031255, 0.17521344311535358, 0.13256537302264146, 0.09750157381807055, 0.18947916690792355, 0.16868546126144274, 0.11568256680454526, 0.11321444995701313, 0.15427111115838799, 0.11745966358908586, 0.08047191226588828, 0.12074511657868113, 0.12867951153644494, 0.1223578043282032, 0.13750692643225193, 0.16153811264250958, 0.13346536830067635, 0.20922122469970159], [0.01802487056037145, 0.01284544906645481, 0.031300776305475404, 0.014951948309317231, 0.01405287838341402, 0.04079887217708996, 0.01648851969678487, 0.011408282211050391, 0.0201173097094787, 0.057022047362157276, 0.023880076461604664, 0.02256806623855872, 0.01581991503813437, 0.03322313047413315, 0.018740244941519837, 0.03861128206231764, 0.04852519097871014, 0.024850289936044385, 0.08842931634613446, 0.04609186262158411, 0.0282408734450915, 0.07266228632735354, 0.023180021704839807, 0.029598691567246403, 0.06456160957791976, 0.008998210641688533, 0.028026373258658817, 0.04097642782809479, 0.022558512465496148, 0.030340092855372598, 0.03387826960533857, 0.05009517173415848, 0.036625834314950874, 0.033448353210198026, 0.04629285826480814, 0.06376961671880313, 0.0192761315431978, 0.008323097984040422, 0.0333050364362342, 0.007155671699105629, 0.01776313246227801, 0.024814429360308816, 0.05018644826486707, 0.03540361632726022, 0.04377490302015628, 0.07086959002273423, 0.1268614719488791, 0.009894017662320818, 0.02269743233253913, 0.04758813072528158, 0.016630387798483883, 0.03536280583856361, 0.04908000870740839, 0.09384053133960281, 0.04064948930005942, 0.014550581275086318, 0.03125867999291845, 0.1012811360082456, 0.02808824377799673, 0.008632743198956763, 0.03618131245353392, 0.008467985566572418, 0.04456486027421696, 0.0801467379289014, 0.10206080667142357, 0.06916213807250772, 0.01843535201624036, 0.010836648688252484, 0.05666159598955086, 0.05686006069715534, 0.03543041506782174, 0.06932895590684243, 0.0835793719493917, 0.07726096920669079, 0.08220498569841896, 0.04177149784352098, 0.010937424709222146, 0.03154996150572385, 0.0429865538940898, 0.04550600530845778, 0.014840095204168131, 0.014734693270708834, 0.0800732390156814, 0.04198249848559499, 0.06050243667726006, 0.059618733025022914, 0.028675761805581193, 0.039256270309644084, 0.02901438470663769, 0.0985282990815384, 0.07445644148226295, 0.04105382492499692, 0.027852586869682585, 0.05628362484276295, 0.020362932600879242, 0.09866287293178694, 0.06430473657591002, 0.10871537601841347, 0.1331576933818204, 0.1387777410979782, 0.01660507165693811, 0.03803246794268489, 0.008983151405118406, 0.09972195753029414, 0.01746765590671982, 0.06462523580661841, 0.028713437462491647, 0.04341216837721212, 0.015318995042304908, 0.0452244098830436, 0.058482003664331775, 0.012698689575440117, 0.015473570408565658, 0.023873725373830115, 0.07793103610830647, 0.04678455188072153, 0.04264493526092597, 0.01782078419013747, 0.05764317153287785, 0.02212123735807836, 0.04751037400481956, 0.013104676584979253, 0.03387259365990758, 0.034366651970360956, 0.04263107279049499, 0.054265481885522604, 0.05391059110739401, 0.05282779510266014, 0.03144966385194233, 0.026626523284773742, 0.01978607096576265, 0.037676586503429074, 0.033664313943258355, 0.027126354231898273, 0.025156735010179024, 0.006579424562265298, 0.0344031775104148, 0.030562896614095995, 0.052471296196537356, 0.036229440942406654, 0.010221767039703471, 0.014459494734182954, 0.03791359878544297, 0.06963158252515964, 0.0227214711319123, 0.06573432843600001, 0.05530716206080147, 0.07504399852561099, 0.032595282021377764, 0.022482043265232017, 0.02747156740432339, 0.02393752632529608, 0.06541576303009476, 0.02860544522159866, 0.04552330795143332, 0.11208848216171775, 0.032372817530163696, 0.03688123489597014, 0.008238361682742834, 0.07567252551338502, 0.018984303809702396, 0.04463981803772705, 0.05109584125291024, 0.0748880101101739, 0.03657702050570931, 0.027622012188658118, 0.05606438000021236, 0.02504757738539151, 0.03759837855717965, 0.017000825510227253, 0.07464154583535024, 0.014932493013995034, 0.026674556778743863, 0.07495445904455014, 0.0058577499834687585, 0.014561140976314033, 0.04640211597351091, 0.032360488548874855, 0.06888988268162523, 0.03592650559065597, 0.05116008494847587, 0.025204934745228717, 0.07815118679510695, 0.04343639886272805, 0.10186012315430812, 0.04243625520861574, 0.049913219176232815, 0.011164213164842554, 0.018308942638603703, 0.05558372614905238, 0.024497317715681026, 0.03961527979533587, 0.04646145725356681, 0.04685513648603644, 0.042068438338381905, 0.01900460897013545, 0.05463125975802541, 0.04077843130965318, 0.013439430988260677, 0.04124358402831214, 0.017501206070716892, 0.023129196039267948, 0.08324511202850512, 0.11952536845845835, 0.03396290327821459, 0.0523923045423414, 0.060894216011677466, 0.020966796537062952, 0.02779635667268719, 0.022415290686434934, 0.044041339973253865, 0.05527295032516122, 0.043874861406428475, 0.02997639469270195, 0.019819838260965686, 0.0466692552103528, 0.01657252572476864, 0.06876616539167506, 0.06199488802147763, 0.027209488342383077, 0.04632443728457604, 0.02424005455603557, 0.04673693568578788, 0.040292712194578986, 0.008535875539694513, 0.07487201703978436, 0.008971126068250408, 0.05123667119603072, 0.04146637760901025, 0.08355525681482893, 0.04961809376254678, 0.023594455627192343, 0.02274371181348605, 0.01428809339579727, 0.04241396872592824, 0.06045633700809308, 0.05440871723528419, 0.02142621563481433, 0.03899178075205002, 0.016572578311232582, 0.09617172660572187, 0.05969049488859517, 0.04216879366764, 0.06340796433921371, 0.07224466159407582, 0.010421952681748994, 0.056605297939053605, 0.07765233463474683, 0.03206147173685687, 0.10197673618261303, 0.05773316563240119, 0.12487117946147919, 0.016244803488786732, 0.05207260598295501, 0.030382128099777868, 0.03978666417034609, 0.04866545434509005, 0.044492039896015606, 0.06060132637087788, 0.05048658465966582, 0.02445959286498172, 0.01566265436953732, 0.021459930343553424, 0.01481056196748146, 0.07381741755775043, 0.07187337401722159, 0.07091944199055433, 0.006441590351252151, 0.10225013151232686, 0.10640982259064913, 0.08271527117384331, 0.0755280993346657, 0.06747825842882905, 0.09249365968363625, 0.056162021189395867, 0.07655051590076514, 0.07506523667169468, 0.06930369404809815, 0.0328151545088206, 0.07667757158300706, 0.06384204354669366, 0.07234241134886231, 0.0635326790756413, 0.03925762398700629, 0.0558719338982233, 0.03499179646106703, 0.07047281667057957, 0.010365198316451694, 0.05491847006071891, 0.012118732972469713, 0.00853263383864292, 0.04993418251563396, 0.026543163561395237, 0.051143630474273644, 0.02700769542051213, 0.061043317296675274, 0.05259039266301053, 0.017955339380673, 0.023139911803549955, 0.025602931156754494, 0.06796341096716267, 0.00960070054445948, 0.016880356706678867, 0.07034841406026057, 0.0723086270902838, 0.02904908498749137, 0.0753662008792162, 0.023905211095032946, 0.03829166831980858, 0.05908777937293053, 0.021544552142066613, 0.014518774946087172, 0.025812383042648435, 0.0497536311325218, 0.015049065330198832, 0.004994152596087328, 0.018940853819783245, 0.015784317394718528, 0.0748979574335473, 0.030010396082486426, 0.037398549994187694, 0.1071004830300808, 0.05670223345181771, 0.038504022639244795, 0.02458834318843271, 0.05549058025436742, 0.05936067258673055, 0.011274729556004916, 0.09697815869003534, 0.06965938210487366, 0.012910741946793028, 0.04359908441879919, 0.06184659419315202, 0.08442844995962721, 0.03026838866727693, 0.09040675738028117, 0.012178662881654288, 0.03031481403325285, 0.026343852381354997, 0.04593081233490791, 0.024022025987505913, 0.013565936208968716, 0.04782997417662825, 0.008541532825412495, 0.002969144984880196, 0.03541679008464728, 0.01040331756563059, 0.06139002833515406, 0.0750973110220262, 0.06798015042607274, 0.02413062042822795, 0.011280635355173476, 0.07927528183375086, 0.16184372481490883, 0.13015312674854482, 0.12481236404606275, 0.15915393057678426, 0.1332713072853429, 0.14369827349271092, 0.12416010190333639, 0.15804903129381792, 0.07445057893970183, 0.08485347072460822, 0.09070122122232403, 0.15302229459796632, 0.0914734076442463, 0.1492740400135517, 0.135619459141578, 0.13508585920291288, 0.16595732979476452, 0.13702180103531905, 0.08116912735360009, 0.09444824087300471, 0.1268022765538522, 0.14229005548570836, 0.12659708756421292, 0.1250907126814127, 0.08679626576070275, 0.19256177863904408, 0.18186736106872559, 0.1138879366751228, 0.11793625301548413, 0.21214244009128638, 0.10366476167525564, 0.14754624558346613, 0.14339739749474184, 0.09882483245538813, 0.14592666391815456, 0.20016830547579698, 0.10322609557104961, 0.1113986223936081, 0.09952677693217993, 0.09572798505957637, 0.09029304848185607, 0.2231810377644641, 0.1066101464842047, 0.16974222527018615, 0.15926511532494, 0.2436250943158354, 0.12857090522136005, 0.07257873152515718, 0.1578986407922847, 0.08160687065018074, 0.14260075667074748, 0.12594204342791013, 0.17011930075074944, 0.11028979439288378, 0.09320342766919307, 0.1806964267577444, 0.14934136425810202, 0.08966038921581847, 0.21248488314449787, 0.17763826942869596, 0.08327836702976908, 0.10490527975239924, 0.0840911976993084, 0.2987228435065065, 0.1957258145724024, 0.12506084356989178, 0.2745988337056977, 0.19629442691802979, 0.21742026188543864, 0.09896460388387952, 0.2347392439842224, 0.2504686899483204, 0.20952173428876059, 0.17846190237573215, 0.1595037289495979, 0.10944919128503118, 0.14137024698512896, 0.1683177902762379, 0.17255149595439434, 0.0630187973646181, 0.11000445006149155, 0.15918061057371752, 0.10850048397800752, 0.27303972308124813, 0.2469315140375069, 0.0937835547540869, 0.14699967205524445, 0.2593700923025608, 0.12630714955074446, 0.14840254320630006, 0.11757342677031245, 0.14106455338852747, 0.1361961324832269, 0.17489928140171937, 0.24340457043477468, 0.19845072978309222, 0.2607253710074084, 0.21903358745787824, 0.24469517118164472, 0.14686532212155207, 0.18425467796623707, 0.10403423077825989, 0.17609336732753686, 0.18418273968355997, 0.174027540321861, 0.16455234161445073, 0.1251457690128258, 0.20660030176596983, 0.1454628309501069, 0.16678073203989438, 0.12304820013897759, 0.10229958992983613, 0.2603035664984158, 0.17003611235746316, 0.18264682138604776, 0.23741177629147256, 0.09425348775195223, 0.15333585920078413, 0.11736708427114145, 0.2531409508415631, 0.05240519331502063, 0.16276239337665693, 0.09492082694279295, 0.1836533738034112, 0.1747612538082259, 0.17926863980080399, 0.11667793696480137, 0.10078014646257673, 0.06565398988979203, 0.12350471849952425, 0.14627809077501297, 0.11815635620483331, 0.1496693952275174, 0.09625964438808815, 0.09406887194407837, 0.10262188049299376, 0.12068084574171475, 0.15543264097401074, 0.09605906943657569, 0.09801716543734074, 0.10956032175038542, 0.1543723621538707, 0.12792264643524373, 0.11567385441490582, 0.21393880727035658, 0.15386854990252427, 0.17333748377859592, 0.12830945210797445, 0.1779166180640459, 0.07818695916129009, 0.13466784091932432, 0.18902393776391233, 0.10994518681296281, 0.09310153206544262, 0.16656125310276235, 0.17733393290213176, 0.1316047167139394, 0.12882634651448044, 0.18284998834133148, 0.14445885696581431, 0.0889953299026404, 0.13612101865666254, 0.19077533164194652, 0.06962814913796526, 0.08777913730591536, 0.1606130794222866, 0.08352103150848832, 0.0654671009896057, 0.11874244761254106, 0.199682230129838, 0.0764393447233098, 0.1273168232291937, 0.19837877792971476, 0.12102719715663365, 0.0717441945203713], [0.009647688246332109, 0.029362181401146308, 0.01988197849797351, 0.05409787355789116, 0.0373338347167841, 0.12332688804183688, 0.05801574154091733, 0.04185493729476418, 0.025004051060282757, 0.07385513731943709, 0.023341842128762176, 0.010983917080531163, 0.051999975594558885, 0.038558461503790956, 0.03914170984977058, 0.02494751552252897, 0.05052780226937362, 0.035721099469810724, 0.05048621485808066, 0.031513412216944356, 0.0239697211155934, 0.0422991232813469, 0.009550838398614099, 0.026934908969061713, 0.06772605263228927, 0.07157032670719282, 0.07286900880613498, 0.04837442049756646, 0.024794658546202948, 0.02588079124689102, 0.05190008845446365, 0.014440056402236223, 0.00888221338391304, 0.028149825919951712, 0.008906666089647582, 0.045701053592243364, 0.020605127194098065, 0.03772676416805812, 0.03934172840256776, 0.024485962432143942, 0.050064264464059045, 0.02260507014580071, 0.015416571770661643, 0.08943768723734788, 0.023984452110848258, 0.0074516673339530826, 0.060200895714972696, 0.0057801798601368705, 0.015047742186912468, 0.02518882802022355, 0.014253065721797091, 0.025969803166974868, 0.029769149741956165, 0.03000071338777031, 0.046882064148251495, 0.027992858717750226, 0.0690209281497768, 0.05419462586620024, 0.05784261333090918, 0.015094072557985783, 0.0519800368430359, 0.04118544375523925, 0.08463609524603401, 0.030656904248254638, 0.09770063563649144, 0.07592557157788958, 0.08497868079159941, 0.07981935835310391, 0.03240834562374013, 0.057591467164456844, 0.016064437006467154, 0.12209284997412137, 0.09437120679233756, 0.04706752133954849, 0.10366039869508573, 0.06671981234103441, 0.07863335377935853, 0.049398909988147874, 0.014144297406476523, 0.015481811216367143, 0.05263245504881654, 0.04580163623073271, 0.042076180422944684, 0.030437513520675044, 0.08488843563411917, 0.07943088348422732, 0.08653610864920275, 0.07204920958195414, 0.20817315950989723, 0.13427408704800264, 0.04897632855655892, 0.02065384091942438, 0.03823424729385546, 0.10621970386377402, 0.046018370493714295, 0.07193308509886265, 0.1711032443812915, 0.11318252488438572, 0.047766900953969786, 0.05734987477106707, 0.03486871699403439, 0.028946979037885155, 0.0656017426933561, 0.08889525955809013, 0.03714227071031928, 0.04313894607392805, 0.026472031039052775, 0.0515692246013454, 0.035477060957678726, 0.055219091608056, 0.08966629247048072, 0.02997923775443009, 0.0684478103316256, 0.07534045726060867, 0.016312173534450785, 0.01972194601382528, 0.0691059757290142, 0.015411050191947391, 0.01839955590133156, 0.021212056412228515, 0.06022904134754624, 0.04285230574065021, 0.04334248622347202, 0.034123828035912344, 0.010134054514180337, 0.024371905784521784, 0.06154902944607394, 0.028138664018894945, 0.05813562510801213, 0.022951786273292134, 0.04345806448587349, 0.025255341415426562, 0.03768843372485467, 0.021321860341621295, 0.07794229300426585, 0.009055607918916004, 0.0396949873039765, 0.06326397242290632, 0.09685270435043744, 0.03478621392111693, 0.044506499477263005, 0.04363422914009009, 0.027534900166626488, 0.05668182311845677, 0.030961233989468644, 0.01575347628178341, 0.04057243147066661, 0.01785235303188009, 0.01832118341034012, 0.03149121055113418, 0.07025639114103147, 0.037367330597979684, 0.034294292995972295, 0.006474046377531652, 0.09936336534363882, 0.089097849758608, 0.015376000465559108, 0.024440361486215676, 0.044621816503682306, 0.04244272843269365, 0.0494383532287819, 0.04842765835512962, 0.015671349795801297, 0.011972703754768839, 0.07459531045917954, 0.0466648820521576, 0.04378066038978951, 0.01260849361174873, 0.04366223228030971, 0.04432727463011231, 0.041205545355166705, 0.029985093511641026, 0.04334003671205469, 0.003939765156246722, 0.037133968834366114, 0.025423280528879592, 0.02827216748015157, 0.02683911339512893, 0.04184532245354993, 0.01978503619985921, 0.02955036630321826, 0.03866312213774238, 0.01663726644723543, 0.07132045618657555, 0.027341705979779363, 0.06841923722199031, 0.04956897461254682, 0.011820900204059268, 0.009229685229781483, 0.04913395902674113, 0.023670702607237866, 0.009544380441574114, 0.03398731696818556, 0.0306047622247466, 0.053250298502721956, 0.03339889818536384, 0.027804212411865592, 0.037642483333391805, 0.024813861087230698, 0.021326957835948894, 0.02663125945920391, 0.021908508148044348, 0.037911159452050924, 0.03723043955064245, 0.0620376764397536, 0.044926821387239864, 0.05201164300420454, 0.037629255293203254, 0.040292169366564067, 0.07189234585634299, 0.035652445296623876, 0.010858662908763757, 0.021740903213088, 0.024781235427196537, 0.05367937690711447, 0.014129524002783, 0.024238612669120942, 0.02655669524600463, 0.05970628439847912, 0.03985477551551802, 0.03991581991847072, 0.08473200617091996, 0.051844703033566475, 0.04307730795283403, 0.03055947340492691, 0.030394521541893482, 0.020205654968906726, 0.03070881896253143, 0.021899320783891847, 0.010157358799395817, 0.018341110287500278, 0.02525447458694024, 0.04902128489421947, 0.04972668650693127, 0.036814646861915074, 0.02732397585974208, 0.06117227966231959, 0.07128291962934391, 0.023383273477000848, 0.015509546335254396, 0.12037303511585508, 0.08691362517752818, 0.027853808232716153, 0.09665784944913217, 0.05646803030478103, 0.044062815606594086, 0.031170256701963286, 0.13209456471460207, 0.11648656294814178, 0.06843985790120703, 0.18436936395508902, 0.28025415167212486, 0.09814800055963652, 0.056793218212468285, 0.005735796460482691, 0.018884038386334265, 0.033474843217326064, 0.0472297692405326, 0.03160339953111751, 0.03997884225100279, 0.06095249538442918, 0.12089476069169384, 0.059217047079333236, 0.13897493694509777, 0.10043712665459939, 0.1045267657775964, 0.04806568706408143, 0.03622302200113024, 0.10781835272376027, 0.17098918264465673, 0.14035986763026032, 0.059438391987766535, 0.1361538597515651, 0.1714629629360778, 0.08072535188070365, 0.08128079386161906, 0.06476038641163281, 0.06538453684853655, 0.030103236636412994, 0.10332251539719955, 0.03126551962590643, 0.06699855452669518, 0.049635348908071, 0.025013163785583208, 0.04828592256775924, 0.04527107612895114, 0.04518803362069385, 0.038801003846206834, 0.07198407700551407, 0.06328512914478779, 0.05903042959315436, 0.013637595444119402, 0.02694243222608098, 0.0643384326249361, 0.019327120057174137, 0.0454529302992991, 0.017567789015759314, 0.026482494049040333, 0.026376308407634497, 0.011836130770721605, 0.06286806759557553, 0.028053826785513332, 0.034961740752415996, 0.018186275381594896, 0.04545174625569156, 0.029796396315629994, 0.026130795778174485, 0.03995024539264185, 0.020841294700013738, 0.04375512711703777, 0.06287678677056517, 0.04901135792689664, 0.03728728721450482, 0.07108766439237765, 0.06827088232551302, 0.029544395195054154, 0.04140086844563484, 0.049550219904631376, 0.013365936315884548, 0.03906963925276484, 0.02573908768993403, 0.025927749262856584, 0.08117112224655491, 0.03067008818366698, 0.023998253513127565, 0.028857548122427294, 0.030658373276570013, 0.0345643804674702, 0.06224579670067344, 0.00773758757194238, 0.0171757840684482, 0.0761432388265218, 0.01934300795463579, 0.03771973793794002, 0.025809490787131444, 0.043362723530403206, 0.01910820260777005, 0.021147369972563217, 0.03547101181798747, 0.06754397454538516, 0.017518759771649326, 0.04659340517329318, 0.053273945448121855, 0.04410385001184685, 0.04770287099693503, 0.025526806313012327, 0.03621662002322929, 0.030126639309206178, 0.0433790422976017, 0.004230677291551339, 0.08705600218049117, 0.09132792973624808, 0.08506803706820522, 0.1275388127458947, 0.1098194271326065, 0.11616077114428792, 0.11537707676844937, 0.22595991007983685, 0.09653601170118366, 0.1246062522487981, 0.14474137180617877, 0.12845606995480402, 0.08361869305372238, 0.09789886285683938, 0.08524503292781965, 0.13832487325583184, 0.11034904407071215, 0.11699215296123709, 0.14691082467990263, 0.10947998998952763, 0.14384335785039834, 0.13250392489135265, 0.10699483512767724, 0.11208713187703065, 0.08241473444338356, 0.18259266072085925, 0.20465009712747165, 0.14049831591546535, 0.16114581083612783, 0.1334732257361923, 0.1793944944760629, 0.19749570531504496, 0.15740088107330458, 0.13430938443967275, 0.15040802130741732, 0.16597221685307367, 0.09035877138376236, 0.1344601684915168, 0.06687593646347523, 0.21949500484125956, 0.11945020034909248, 0.10717138315417937, 0.10686594061553478, 0.08052084142608301, 0.10989652906677552, 0.2497702060001237, 0.15404435832585606, 0.19433696195483208, 0.14742653843547615, 0.12774039192923478, 0.08933478061641965, 0.09891930488603455, 0.08920863417110272, 0.07944840325840882, 0.07769887535167591, 0.05814948757844312, 0.08571890821414334, 0.09121493329959256, 0.1326686596231801, 0.23981376311608724, 0.21645575149783067, 0.050186217562960725, 0.24043340129511698, 0.11807380563446454, 0.11832228515829359, 0.17143663577735424, 0.20742079988121986, 0.322496376399483, 0.1998684744217566, 0.21935373385037693, 0.0971300487539598, 0.13831876644066401, 0.13437263747411116, 0.26914875901171137, 0.2674306540616921, 0.2025371797915016, 0.35958594190222876, 0.39757057651877403, 0.1683541326118367, 0.12757885988269532, 0.1080852137612445, 0.09668769820460252, 0.07733896680708442, 0.19652149187667028, 0.10303048749587365, 0.18673798042748654, 0.32213569432497025, 0.25523320000086513, 0.14166471761252197, 0.2848558947443962, 0.24917081530605042, 0.1373037594769682, 0.18692417043660367, 0.14277674151318415, 0.1250320736851011, 0.2525214212281363, 0.178114668865289, 0.1880032175353595, 0.39174991313900265, 0.27534731211406843, 0.20761639438569546, 0.22543534822762012, 0.1471902182591813, 0.10230935404875449, 0.17465686798095703, 0.20094704654599937, 0.13203622427369865, 0.16750292400164263, 0.11603574428175177, 0.17656375494386467, 0.1803780309855938, 0.1583127100020647, 0.16571472638419696, 0.20212939381599426, 0.22092594020068645, 0.19842881310198987, 0.15591763066393988, 0.0979120603629521, 0.2315242907830647, 0.12491263795111861, 0.165149913834674, 0.14466506375798158, 0.14799844846129417, 0.1324039359710046, 0.232694682266031, 0.08600985045943942, 0.17366959952882358, 0.1346756847841399, 0.11185548680701426, 0.09408552997878619, 0.15060092881321907, 0.11545932878340993, 0.1321840092007603, 0.14570968198989118, 0.12643052078783512, 0.08633118428822074, 0.26531015070421354, 0.08757071848958731, 0.11893330594258648, 0.19688133256775991, 0.20658609324267932, 0.15085987134703568, 0.1469856942338603, 0.12538512902600424, 0.09858991684658186, 0.16560930918369973, 0.12421544321945735, 0.10027563532016107, 0.19027716480195522, 0.07068131691110985, 0.10712117156279938, 0.114962084751044, 0.13987045389200958, 0.13437179609068803, 0.21312232608241694, 0.08077751086758715, 0.18331341418836797, 0.16328521817922592, 0.12731307771589073, 0.12345500902405807, 0.09058906616909163, 0.13032381901783602, 0.1255787829203265, 0.07850034734500305, 0.14538167816187653, 0.17256820148655347, 0.1370209732225963, 0.13969028927385807, 0.14048185465591295, 0.08684987681252615, 0.0625548694016678, 0.1248259890292372, 0.13048871659806796, 0.10407054597245795, 0.11610076150723866, 0.09287674698446478, 0.13639826806528227, 0.18515065631696156], [0.02713284102667655, 0.05855263237442289, 0.043605615318353684, 0.025748502363317778, 0.04351728702230113, 0.042216484501425705, 0.04642267897725105, 0.03388864101309862, 0.040391483144568543, 0.04663001892289945, 0.05814659023391349, 0.021374845444890003, 0.01622789609245956, 0.0748316849182759, 0.043687969113567045, 0.06820580403187446, 0.032831748082701645, 0.05135539786091872, 0.06792467340294804, 0.04239833527909858, 0.052145348329629214, 0.10983764579785721, 0.036260745155492, 0.04116765595972538, 0.007700419119958366, 0.08190060167440347, 0.0430380614873554, 0.01902432380510228, 0.011732546462943512, 0.028694798105529377, 0.04628652074773397, 0.02611990868380027, 0.05110061135409134, 0.02009583237980093, 0.022924768705187098, 0.0351011525573475, 0.06366084755531379, 0.015732658827411275, 0.05968793681157487, 0.01549193326250783, 0.04312303103506565, 0.02097183296323887, 0.03816531492131097, 0.03708973513650043, 0.022734510878633176, 0.050818551132189374, 0.003738830581174365, 0.058715623271252425, 0.03328477877325245, 0.0467640329817576, 0.008861719081843538, 0.0936157734000257, 0.06471273289727313, 0.012768329320741552, 0.0794728644458311, 0.051099468022584915, 0.021724640425028544, 0.06484401585268122, 0.01737083404857133, 0.03906672155218465, 0.037335992458143404, 0.06462119852325746, 0.07164994600628104, 0.05950539053550788, 0.04211154566811664, 0.14937936221914633, 0.0035992393885473056, 0.17746993846126966, 0.04904289284188833, 0.012004945194348693, 0.15112516496862682, 0.07300666999071836, 0.060170042727674754, 0.08935056334095341, 0.023361395811662078, 0.0633403958220567, 0.05716761347970792, 0.07622408627399377, 0.15035840682685375, 0.16371813709182398, 0.04184730038312929, 0.10011730595890965, 0.08893268754971878, 0.21378484767462524, 0.1491322261946542, 0.20664085101868424, 0.3394901230931282, 0.39259371214679306, 0.4981958812900952, 0.19985251527811798, 0.31798984536102837, 0.2667387111910752, 0.019627013875703727, 0.04206898795174701, 0.03151828749105334, 0.04618154459499887, 0.05063137046194502, 0.13202483845608576, 0.1771610557500805, 0.09432030988058873, 0.09764066671154328, 0.03428948557536517, 0.07234879636338779, 0.1053145517195974, 0.04820685627471123, 0.04886195130114045, 0.03291314514353871, 0.023467745997809937, 0.0643650379830173, 0.012525102506125612, 0.08720558522535221, 0.03630538936704397, 0.041104206150131564, 0.04668878684086459, 0.03293740277045539, 0.02533172579881336, 0.0212049097421446, 0.009596595407596656, 0.016582372964226773, 0.03046382710869823, 0.011802985183229404, 0.042038107823048315, 0.05553465110382863, 0.050239462205874066, 0.015594220720231533, 0.018460544325145226, 0.019680972676724195, 0.025758269874911224, 0.035488453560641835, 0.04999962043283241, 0.052423364482820034, 0.027768926894558326, 0.03375310364312359, 0.019514419471046755, 0.040395113306918314, 0.016747967739190375, 0.011335729006012636, 0.01124616916890123, 0.05713104044220277, 0.03321244015491434, 0.01374474460525172, 0.04462481223578964, 0.03973124482269798, 0.030706240529460565, 0.0524317138562245, 0.015782984073406885, 0.01655808141055916, 0.015068445986668979, 0.03202034912205168, 0.05572339240461588, 0.031158877669700553, 0.035716383651431115, 0.02772309355038617, 0.044144429798637114, 0.04871128938559975, 0.035860097368380854, 0.01858455847416605, 0.04944793414324522, 0.020882212057975785, 0.014791578253997224, 0.03251360336850796, 0.020660670374387076, 0.04752141376957297, 0.04581049789807626, 0.08445730805397034, 0.04872468027419277, 0.07212675934923546, 0.021980726326416646, 0.06211019826254674, 0.03545842160071645, 0.016328848532534072, 0.05022768283795033, 0.035456107796302865, 0.06323624069669417, 0.011766111893978502, 0.010622656554915011, 0.020287316658401063, 0.0624307178493057, 0.008867912410226251, 0.006339579820632935, 0.06811231547700507, 0.04436961182260087, 0.05231682430686695, 0.06697823918823685, 0.03303991923374789, 0.0061726631746361295, 0.028996681728001152, 0.012168266028831047, 0.03290984746334808, 0.054509486470903666, 0.020118015385898094, 0.05018669593014887, 0.03170283883810043, 0.01073371322958597, 0.04613427445292473, 0.03411477977143867, 0.03887061814644507, 0.035517820556248934, 0.05403202173433133, 0.06155989957707269, 0.01747090948213424, 0.02258941125390785, 0.015831499327240244, 0.021628390232633268, 0.045659357615347416, 0.09147766205881323, 0.03548157660822783, 0.07474620307662658, 0.011048409289547374, 0.016975397410403405, 0.028170590787859898, 0.05128514573776296, 0.05099131293328745, 0.05362120270729065, 0.0242808039765805, 0.029382266037698303, 0.035106180501835685, 0.022539862930508595, 0.030711553458656584, 0.018275295783366476, 0.044149128653641255, 0.06813030344034944, 0.02788674771519644, 0.05527760846806424, 0.01774725304650409, 0.017908416987795914, 0.06009371432342699, 0.031710438430309296, 0.016268808361408964, 0.05331857269629836, 0.04485402815043926, 0.021536769345402718, 0.019220432299854498, 0.02689644112251699, 0.01972957274743489, 0.009903427246691925, 0.054170687150742323, 0.044768407209111113, 0.026304032553785613, 0.053136759238051515, 0.08546335157006979, 0.059010046401194165, 0.03211110996614609, 0.12641263460474356, 0.08024049111242805, 0.06304629160357372, 0.06074932164379528, 0.06698125866906983, 0.07863057178578206, 0.0842631384730339, 0.10828543587454728, 0.18060833934162343, 0.07046831119805574, 0.05039738105343921, 0.09819567443004676, 0.04603811586275697, 0.053556070130850585, 0.03317894088104367, 0.0186186718222286, 0.10656331399721758, 0.06758538553757326, 0.24787185500775064, 0.047807440028658936, 0.2151187660970858, 0.28868948189275606, 0.24339865360941204, 0.11567228021366255, 0.014814470329188874, 0.06145422453326838, 0.1072423036343285, 0.07251125121755259, 0.057621607689985206, 0.09201443754136562, 0.19506089096622808, 0.1470869995121445, 0.059387698636523316, 0.10618811127330575, 0.08260231544928891, 0.14064023829996586, 0.12794502452015877, 0.07250133103557996, 0.04910793720877596, 0.02159935063017266, 0.05694715745214905, 0.047843059724462886, 0.02361482355211462, 0.05797948741487094, 0.017018346980746304, 0.0401238248284374, 0.031160981128258363, 0.02006312699190208, 0.007775423532750989, 0.0379125775902399, 0.07696932807032551, 0.01524650036091251, 0.04229655163362622, 0.03349724505096674, 0.059789852771375857, 0.013390027701721659, 0.04875273769721389, 0.029382564593106508, 0.034573913884482214, 0.042347367121172805, 0.012459406745620072, 0.0760862622410059, 0.037884801759251525, 0.016589075193873475, 0.03882976355297225, 0.009266417723016014, 0.048478009046188424, 0.037823136496756754, 0.007264455281464117, 0.024788434683744396, 0.036070673926068206, 0.024558104275326644, 0.05631232348137668, 0.028146886166983416, 0.025815590816949095, 0.08040497478629861, 0.03558628473963056, 0.05914943785007511, 0.016742369825286523, 0.021514470988352383, 0.003958619099908641, 0.031435753884060044, 0.06839466746896505, 0.058317452136959345, 0.015950185280027132, 0.034105456700282435, 0.0320229513038482, 0.06649415194988251, 0.06108214985579252, 0.05204222457749503, 0.021157079808680073, 0.03734903050852673, 0.013254416541063359, 0.013111489076566483, 0.028627341546650444, 0.027811141950743537, 0.04955379578417965, 0.06737529073974916, 0.024752034672669003, 0.028613923516656672, 0.012908518048269408, 0.02917680224137647, 0.010941718987721418, 0.029754086264542172, 0.02263012674770185, 0.0949542447924614, 0.0711182120389172, 0.030959636039499725, 0.04302397510036826, 0.14093567244708538, 0.1723807222609009, 0.09529112385851995, 0.08166413222040449, 0.11435594941888537, 0.10731743781694345, 0.1297924853861332, 0.16650463614080632, 0.08807900228670665, 0.11700329450624329, 0.10947716049849987, 0.12347255593964032, 0.09103595611772367, 0.1585278870271785, 0.13394615107348987, 0.12304022056715828, 0.19426311020340237, 0.10974114454750504, 0.2101743221282959, 0.12884869745799474, 0.10592956907515015, 0.2759508011596543, 0.16357188565390451, 0.12592841844473565, 0.07922080904245377, 0.10219808109104633, 0.08871097623237542, 0.15101286742304051, 0.11250561156443187, 0.1791718399950436, 0.19810682109424047, 0.07021360950810568, 0.0901781250057476, 0.13928320897477015, 0.15727353362100466, 0.1408809825245823, 0.16896387775029453, 0.09243959401335035, 0.13129438193781034, 0.07182896390025105, 0.14586517507476465, 0.08746441240821566, 0.09351442062429019, 0.07795274244355303, 0.10539962644023554, 0.1526056198137147, 0.1247640387820346, 0.12683023219662054, 0.14704488962888718, 0.11102153334234442, 0.10256365540304355, 0.13417789792375906, 0.09034889191389084, 0.10243670828640461, 0.15639321585851057, 0.10772805328347854, 0.1044727476047618, 0.16713097824582032, 0.10533568130007812, 0.12035295047930308, 0.14594896057886736, 0.12364398102675166, 0.23095141723752022, 0.28047375274556025, 0.21749251229422434, 0.41339512595108574, 0.172161976141589, 0.36799350646989687, 0.11700822067047868, 0.16543848120740481, 0.3353025035134384, 0.18349081038364343, 0.2551760673522949, 0.15567510867757456, 0.3219512956483023, 0.17967956060809748, 0.11835078362907682, 0.14630570715027197, 0.21202977613679, 0.26357657515576904, 0.3445325882307121, 0.330870937023844, 0.22580381988414697, 0.3278496377170086, 0.2024147313620363, 0.2825231727744852, 0.36276430849518093, 0.5772012961762292, 0.5392487698367664, 0.38561082684567993, 0.48925914083208355, 0.3928753041795322, 0.13852562462644918, 0.17377238401344844, 0.14978828813348496, 0.17737640919429914, 0.21165719255805016, 0.31261937639542986, 0.4361373127571174, 0.32794780816350666, 0.2958298958837986, 0.1892231692160879, 0.3211782271308558, 0.2033171693661383, 0.21914880270404474, 0.16037639283708163, 0.09623200087142841, 0.12555158723677906, 0.18895547358053072, 0.11064444429108075, 0.22551282335604939, 0.0887825752475432, 0.15594215291951383, 0.1856407621609313, 0.17956249974668026, 0.13127182743379048, 0.1244069936552218, 0.1126726668860231, 0.13411118436072553, 0.1303656032042844, 0.1113554472103715, 0.1872292940637895, 0.1130071235820651, 0.15163125709763595, 0.09968473988452128, 0.10803992833409991, 0.08858983059014593, 0.08045308291912079, 0.14756124120737824, 0.13430591034037725, 0.09909707427557025, 0.12324581667780876, 0.10946804777319942, 0.11755013944847242, 0.1384913178959063, 0.09167011494615249, 0.1247802557689803, 0.11944431066513062, 0.1541956580643143, 0.11069018433668784, 0.13228128398103373, 0.09766097526465144, 0.16129928188664572, 0.10953139580254044, 0.19173744001558848, 0.11152717085289103, 0.07787387631833553, 0.11625343188643456, 0.13990340355251515, 0.1354377067514828, 0.10509326109396559, 0.10267362557351589, 0.08308379032782146, 0.12820654548704624, 0.18651984498969146, 0.1274477940584932, 0.13409586304000445, 0.13240035330610617, 0.13944569097033568, 0.09661029771502529, 0.09549456222781114, 0.10560306480952672, 0.13635956442781857, 0.21936020707445486, 0.1316553218556302, 0.16935942295406545, 0.12444801788244929, 0.1422999213848795, 0.18523438753826277, 0.08617337061358349, 0.20089422938014778, 0.12295182102492877, 0.15084370864289148, 0.1941033966307129, 0.07663924113980361, 0.17698794789612293], [0.022467310573639612, 0.01908181098821972, 0.040547637801085196, 0.03968156588130763, 0.03843033034354448, 0.039295387853469164, 0.021408365074811236, 0.0360075701693339, 0.04123940425259726, 0.03690468167353954, 0.0302341633609363, 0.023388006258755922, 0.08396687651319162, 0.031632576536919386, 0.08293559149439846, 0.046326486460332356, 0.013449972029775381, 0.02988303845216121, 0.0013384752091951668, 0.04858193686231971, 0.025557993478806953, 0.03425755032471248, 0.014191855077764817, 0.052755368274769614, 0.037090474739670753, 0.026203480449372103, 0.005216796050912568, 0.04724401508324912, 0.033393578470817635, 0.045853595049785714, 0.024514913825052123, 0.013245222391560674, 0.028974290072385753, 0.06856908489550863, 0.01009802260835256, 0.04600259455453072, 0.026981091758768474, 0.029154468261237656, 0.015305351399417435, 0.041316224594733546, 0.016426206433347294, 0.01678187583040978, 0.034264417099101205, 0.05601895208071385, 0.029499723842101436, 0.0484847943963749, 0.038109217038644214, 0.058850468535508425, 0.011553981491098446, 0.013252928853034973, 0.030389066120343547, 0.05411871136831386, 0.02541219157033733, 0.08965760043689183, 0.03743287368810602, 0.08823748771101236, 0.019789679075724313, 0.046144927452717505, 0.05294424867523568, 0.019276296087939824, 0.10341668248708759, 0.07058694626071624, 0.03424436638930014, 0.07377554516174964, 0.10328812724245445, 0.1981412771024874, 0.08704929146915674, 0.084298035529043, 0.06715543860835688, 0.11486578706119742, 0.30188069120049477, 0.4310616265450205, 0.14229267463088036, 0.029550434156720127, 0.04412960720115474, 0.07956283818930387, 1.39804465004376, 2.410318148987634, 4.928570049149649, 5.846605564866747, 5.447516671248844, 4.331034958362579, 4.567729685987745, 12.062183056558881, 21.180077382496425, 24.942365373883927, 32.64122649601528, 30.903565406799316, 36.076141425541465, 27.015765156064713, 15.111954995564052, 7.339290107999529, 1.0506732612848282, 0.03413940041459032, 0.17522564317498887, 0.01794610282273165, 0.02942159053470407, 0.12705351092985698, 0.2932361007801124, 0.42263034039310043, 0.17384506868464605, 0.0013692938456577913, 0.07727118115872145, 0.08630709629505873, 0.10548465366342238, 0.11225787164377314, 0.032410591574651856, 0.009793813307104366, 0.035911153735859055, 0.057312385711286745, 0.08942482899874449, 0.020360583173377172, 0.03817159137023347, 0.07550894429108926, 0.006461837412124234, 0.04848711498613868, 0.023758623782279234, 0.007255565624551049, 0.026117286145953194, 0.031706150088991435, 0.0546239858626255, 0.028326275558876138, 0.010797964558670563, 0.025485054356977344, 0.020991634311420575, 0.01606522241075124, 0.04098024119489959, 0.03045215630637748, 0.06138533287282501, 0.021212429606488774, 0.04555548408201762, 0.011659125581250658, 0.022583177213424017, 0.04463357212288039, 0.04789439429129873, 0.03166397574490734, 0.012578791589476168, 0.035111998939620595, 0.08144503326288291, 0.06035786122083664, 0.029192221949675252, 0.05040690089975085, 0.05291874932923487, 0.015702006007943834, 0.01638916351034173, 0.03616541777072208, 0.07414906511881522, 0.08200203587434121, 0.03334735327267221, 0.0786985813507012, 0.00986460825827505, 0.016707657670070018, 0.03569642115118248, 0.03176324202546051, 0.0901136573936258, 0.04668666981160641, 0.032083130574652126, 0.03857610680695091, 0.10332383175513574, 0.008865076982017075, 0.0257445007030453, 0.06327070349029132, 0.035232683178037405, 0.050153407002133985, 0.0437592322539006, 0.02778094883875123, 0.023096943573494042, 0.0190570207113134, 0.02768169782523598, 0.027157314088461653, 0.03511994119201388, 0.029328054482383386, 0.06482333410531282, 0.018310511750834327, 0.033663323282131126, 0.004951381141186825, 0.027463608188554645, 0.011663142508561057, 0.02645033997084413, 0.03125390649906226, 0.08260409999638796, 0.032075011903153997, 0.013311036895694477, 0.018993947488654937, 0.010280993816974972, 0.027316793566569686, 0.016235773884026066, 0.011945594584436288, 0.07537065206893853, 0.046545103657990694, 0.05353318993002176, 0.06205673648842743, 0.025151859736070037, 0.03133861141811524, 0.018491816307817186, 0.035140063147991896, 0.014941972148205553, 0.03444514490131821, 0.030851416489375488, 0.03411563811823726, 0.10467897475297962, 0.027228543302044272, 0.0735599406595741, 0.07728865343545165, 0.010170783614739776, 0.037517364868628125, 0.06627713609486818, 0.04189509638984289, 0.026823858231572167, 0.0727842529969556, 0.018294634031397954, 0.05431452300399542, 0.0349552132455366, 0.04510165611281991, 0.0366740679767515, 0.028019521751308014, 0.015539105017004269, 0.0401917970739305, 0.023170328832098415, 0.012421698858296233, 0.027349923038855195, 0.051348985704992495, 0.027535851811990142, 0.041905019964490614, 0.03179406447868262, 0.03355511391003217, 0.052733071614056826, 0.0266020960241024, 0.059476213529706, 0.05443417586918388, 0.07443855529917137, 0.035969870763697794, 0.06761330725359065, 0.06238196510821581, 0.018469202431983182, 0.05443006394697087, 0.03460288393710341, 0.026505431925345744, 0.0062574957430894885, 0.05478842203904476, 0.07533087634614535, 0.0989837928542069, 0.13925062572317465, 0.1852855762200696, 0.13575592610452855, 0.12461162624614579, 0.10855112304644925, 0.3513057790696621, 0.17984232758837088, 0.04560369399509259, 0.054204644435750585, 0.1821846440434456, 0.5694573117153985, 2.005018651485443, 4.066229556288038, 5.604198549474988, 4.489340109484536, 3.72900698866163, 3.5309442452022006, 11.335705467632838, 20.319101776395524, 25.4388975415911, 31.464476108551025, 29.424450261252268, 36.11152165276663, 28.300318581717356, 13.480336444718496, 5.393711124147687, 0.7032909616827965, 0.15169596219701426, 0.2650048370872225, 0.09585959371179342, 0.060822325226451666, 0.02043363425348486, 0.2769647224673203, 0.09064278578651802, 0.17871430383196898, 0.07671742194465228, 0.09942637410547052, 0.15127171496195452, 0.09336360264569521, 0.06505386637789862, 0.04342481287728463, 0.12873451358505658, 0.10565178362386567, 0.06489765404590539, 0.04847324573035751, 0.05255881703591772, 0.11731947825423308, 0.11134855329458203, 0.049256359958755117, 0.05791949134852205, 0.029254742166293517, 0.02124225800590856, 0.023151720009211983, 0.008855719984109913, 0.0007376308068549925, 0.03124626280207719, 0.02293660065957478, 0.021058917843869755, 0.013746128816689764, 0.03881967712992004, 0.05666934146678873, 0.03245642661516156, 0.07449328593377556, 0.04511580356795873, 0.040432724503002, 0.04401184744866831, 0.010685766248830726, 0.025791562195601206, 0.00986430122117911, 0.04223564633035234, 0.02208893739485315, 0.030080861944173063, 0.04873868862965277, 0.0236826092004776, 0.03594165049227221, 0.00487036066728511, 0.02594913329396929, 0.030368384372975146, 0.042329779493489435, 0.0194281725811639, 0.023117316587428962, 0.05555578746965953, 0.04962387148823057, 0.049937646436904154, 0.01956664122241948, 0.015664930854524885, 0.0462557797187141, 0.03680749849549361, 0.04890135722234845, 0.053260530810803175, 0.006860082761184978, 0.05519600784672158, 0.04525501520505973, 0.045612721903515716, 0.03218347233320985, 0.03663824811311705, 0.03397387518946614, 0.053293175130550346, 0.01459348843699055, 0.00840553320345602, 0.03853061103395053, 0.05845303021903549, 0.021277387460161532, 0.08301561112914767, 0.023289420209558945, 0.014268940048558372, 0.015362350037321448, 0.06940536573529243, 0.00731766175678266, 0.023019539691241722, 0.12044227282915797, 0.11298968523208584, 0.12045855766960553, 0.09336043388715812, 0.13971751209880623, 0.14415365191442625, 0.22506157042724745, 0.12019417328493935, 0.09886311540114028, 0.10218465288302728, 0.08451900045786585, 0.10587570696536984, 0.1825084002422435, 0.09628586976655892, 0.18599248757319792, 0.10846038934375558, 0.10314474600766387, 0.1644107856388603, 0.10607458557933569, 0.11096115051103489, 0.08744278749717133, 0.12288267830652849, 0.20566541621727602, 0.14268698490091733, 0.1655020463679518, 0.14060556516051292, 0.12865615636110306, 0.09135923055665833, 0.1738098527171782, 0.14092820856188024, 0.15979221489812645, 0.10660955615873847, 0.14147432068628923, 0.259191664734057, 0.11279073876461812, 0.14627358530248913, 0.08780253997870854, 0.2114619237503835, 0.09906662162393332, 0.08969144576362201, 0.1541319979088647, 0.12003687529691628, 0.12723245418497495, 0.11629991153521196, 0.13557322376540729, 0.16428559592791966, 0.12970716639288835, 0.11319162403898579, 0.12592140239264282, 0.17537049683076994, 0.12791470757552556, 0.1364686864295176, 0.12399158094610487, 0.27592900661485537, 0.1430607491305896, 0.15515005828014442, 0.17055863860462392, 0.21942582141075814, 0.20035752175109728, 0.1455404417855399, 0.1798373335706336, 0.11081329773047141, 0.09295346215367317, 0.15456205340368406, 0.26556253858975, 0.2973106492842947, 0.2805039611245905, 0.32416904664465357, 0.1786135956645012, 0.2647826575807163, 0.4649308919906616, 0.5312203977789197, 0.1948018262961081, 0.0980393671031509, 0.1661589496902057, 0.1886472286922591, 2.5603469099317278, 4.781843202454703, 9.270177125930786, 10.512402994292122, 9.854712571416583, 7.7455973114286145, 7.886795129094805, 19.10577780859811, 33.33132158006941, 38.481896127973286, 48.12712138039725, 46.00338363647461, 54.24976280757359, 45.12820243835449, 25.390416485922678, 13.157953926495143, 1.4646748346941811, 0.6204590978366988, 1.023888715675899, 0.2463287849511419, 0.08364791077162538, 0.20302904982651981, 0.5784106627106667, 0.5280922427773476, 0.28821008333138054, 0.1410491235022034, 0.1596881683383669, 0.2544564945357186, 0.1986520104110241, 0.31748903223446434, 0.1033618568575808, 0.23543227251086915, 0.12459329222994191, 0.1317652173872505, 0.25999285174267633, 0.19181442659880432, 0.18209967788841042, 0.2212726715952158, 0.12812582696122782, 0.18680880591273308, 0.1339063210678952, 0.09617732451962573, 0.08607771074665443, 0.06026866100728512, 0.1393365961100374, 0.14842193573713303, 0.1760675829968282, 0.11044896513755832, 0.09395495948514768, 0.17136116911258015, 0.0769262071698904, 0.11404416257781641, 0.17016647250524589, 0.14576924379382813, 0.08813447930983134, 0.1034361564421228, 0.05857334804854222, 0.10864093394151755, 0.07531615213624068, 0.09313396603933402, 0.12423582641141755, 0.1354947444051504, 0.1858764716557094, 0.14163927254932268, 0.1768960878252983, 0.08590515929141215, 0.2559962533414364, 0.07958247499274355, 0.14487887014235767, 0.10345689925764288, 0.3326353723449366, 0.1226144941257579, 0.1509520299732685, 0.20118964995656693, 0.1566364299505949, 0.10790216536926371, 0.16729184532804148, 0.12753312662243843, 0.17062926052936486, 0.09078110515006951, 0.1445262354931661, 0.16483041883579322, 0.22877706534096173, 0.12925082445144653, 0.07894434673445565, 0.16478324708129677, 0.16738013630466803, 0.10753488114901952, 0.10217579800103392, 0.09372331441513129, 0.1240346814904894, 0.1504379447017397, 0.07122109830379486, 0.12725309522024222, 0.14589646910982473, 0.1123932393799935, 0.1167304420045444, 0.1882717545543398, 0.05906711798161268, 0.11009279532091958], [0.008086586969771555, 0.055187057969825606, 0.02930563229269215, 0.01701299673212426, 0.05019573062392218, 0.07870654735182013, 0.05592024219887597, 0.04488752403163484, 0.062438900981630595, 0.07675206794270448, 0.016903586353042295, 0.047536121016102176, 0.021230115621749843, 0.041380685421505144, 0.051600905401366096, 0.03153184801340103, 0.02047453634440899, 0.04334810449342642, 0.020977907547993318, 0.006934196596765625, 0.057090830456997664, 0.0007514397366321646, 0.01972607320307621, 0.020532557873853614, 0.01723499473051301, 0.01917592209896871, 0.04517519234546593, 0.03593213403863566, 0.06195480017257588, 0.033879243303090334, 0.039371641618864875, 0.05297442652019007, 0.014215631792987031, 0.03854673302599362, 0.025752560002729297, 0.02020633011125028, 0.011646412379507507, 0.03331625601276755, 0.025497851527429054, 0.04842319020203181, 0.03797311309192862, 0.015218122330095087, 0.06814588260437761, 0.03388916687773807, 0.06120733956673315, 0.06095064976917846, 0.056780159806034396, 0.045555697820548496, 0.06085716121430908, 0.029542471548276286, 0.04240394337102771, 0.05053126958331891, 0.018951023363375237, 0.007522479248499232, 0.03448196221143007, 0.0285848415057574, 0.05422729054199798, 0.06406889815947839, 0.03253982196162854, 0.06079722621611186, 0.03362492498542581, 0.04822589596733451, 0.052129355259239674, 0.09719463850238494, 0.35312308583940777, 0.42448113965136663, 0.18637527631861822, 0.12070395664444991, 0.08469220330672604, 3.8194925103868758, 8.570665495736257, 30.356405190059117, 46.03908000673567, 55.015739168439595, 55.63340623038155, 57.30122402736119, 86.16866152627128, 97.1576405933925, 110.30117961338588, 115.7305714743478, 113.98006316593715, 110.6378059387207, 110.69536481584821, 125.48179844447544, 125.3410279410226, 128.86313928876604, 135.42757497514998, 126.2823976789202, 117.1895820072719, 125.05021803719657, 120.07761464800153, 101.43115098135812, 73.78898661477226, 70.44103881290981, 76.96596009390694, 62.31434236254011, 62.49163259778704, 59.770405360630576, 38.968363830021445, 18.410162380763463, 7.9191659178052625, 0.6292253902980259, 0.029942695251000778, 0.23460033429520472, 0.3107939814882619, 0.019991916438032473, 0.030344299772488217, 0.09625387005507946, 0.07675841224512883, 0.028846155519464185, 0.10210832447877952, 0.02306298289581069, 0.02318982144684664, 0.07387022115290165, 0.05129529322896685, 0.026910982127966623, 0.028151530739186064, 0.04072070155026657, 0.023702854989096522, 0.021188575707908188, 0.017890133861718432, 0.031786329179470024, 0.0911974406668118, 0.03802183869161776, 0.00596303995864998, 0.024289324680077176, 0.03865934269768851, 0.08537509452019419, 0.006010405095626733, 0.04073683711301003, 0.024748151756024787, 0.05721771650548492, 0.04285484006894486, 0.04941182250955275, 0.02450021166753556, 0.06251417765659945, 0.041078577882477214, 0.03276406082191637, 0.03657862184835332, 0.04715108971244522, 0.016808415031326667, 0.0050122376747562414, 0.027475711556949785, 0.09397031473261969, 0.10477862440581832, 0.07613984615142856, 0.051609604220305166, 0.0197102887822049, 0.04181891047794904, 0.020738761273345778, 0.05568105181945222, 0.02511616879408913, 0.019275235876973187, 0.052300084847956896, 0.01691551330233259, 0.02536501981584089, 0.07134306497339692, 0.029375426404710327, 0.04238967377958553, 0.023443322129813687, 0.056042911152222326, 0.12182613142899104, 0.049192207865417004, 0.06029560563287564, 0.037274483258702924, 0.017951062913717966, 0.01732511944802744, 0.03814760854999934, 0.021921218805281178, 0.043437474340732606, 0.025932980767850364, 0.016675780094893913, 0.045564284681209495, 0.09152004335607801, 0.011957709827194256, 0.02633071255071887, 0.041893966629036834, 0.03142421878874302, 0.052746727131307125, 0.06459859652178628, 0.005383363251374769, 0.03248976643330284, 0.006818591617047787, 0.06272831652313471, 0.015018139400386384, 0.024258834709014212, 0.03584764964346375, 0.037555922621062825, 0.028473198746464083, 0.10021638564233269, 0.06066605182630675, 0.017329691077715585, 0.02275912812910974, 0.020140768361410925, 0.018000373749860694, 0.024344991693007093, 0.0689348763387118, 0.054337973174239905, 0.05563275369682482, 0.04354319009663803, 0.024107887808765684, 0.03728870874536889, 0.039446887759757895, 0.02680861663871578, 0.05992656400693314, 0.06253745819308928, 0.051092000744704685, 0.008961069331105267, 0.025185959513432214, 0.025639415984707217, 0.04786154301837087, 0.028419720008969307, 0.033862765080162456, 0.00602417002664879, 0.012801513075828552, 0.017514800519815514, 0.028450986902628626, 0.04113939158352358, 0.06670924076544386, 0.011782248304890735, 0.06985931244811841, 0.04605365770735911, 0.028291917938206877, 0.056422185086246045, 0.03990269026585987, 0.1178427916020155, 0.02331832580135337, 0.0418687319116933, 0.006218948592764458, 0.017003324215433428, 0.07275044838232653, 0.012902053305879235, 0.02963857924831765, 0.03389644755848816, 0.01980572133990271, 0.024566653816561614, 0.022402437536844184, 0.020622972665088515, 0.04698902840859123, 0.07220765429415874, 0.42662957151021275, 0.16552677218403133, 0.28049036328281673, 0.14604082064969198, 0.119100225557174, 2.724215179681778, 6.459118800503867, 30.028026376451763, 47.26719495228359, 55.69749641418457, 57.300588267190115, 66.05291094098772, 99.20080702645438, 111.01389803205217, 129.16084180559432, 129.57677486964633, 131.67076737540108, 124.22755132402692, 127.70021929059709, 148.23862184797014, 150.87747819083077, 150.16734450204032, 155.98791994367326, 151.0577005658831, 143.0024038042341, 149.28321402413505, 147.67371940612793, 122.24028314862932, 82.63076387132917, 84.18094866616386, 92.02375561850411, 69.08791882651192, 67.37420122964042, 63.588808740888325, 38.62385129928589, 16.59107882635934, 6.851541331836155, 0.5469037305031503, 0.016205343284777234, 0.22594471089541912, 0.20504919785474027, 0.04500875788341675, 0.07447207492909261, 0.13878277582781656, 0.08475601952522993, 0.04562767681532672, 0.1444904902683837, 0.034388110640325716, 0.040978850198111365, 0.055615498551300595, 0.12994637712836266, 0.043540737192545614, 0.042881896652813466, 0.028123619201193963, 0.021418225884969746, 0.014628963944103037, 0.033704140556177924, 0.03044964572680848, 0.022296268858813813, 0.010719081470077592, 0.05179648294246622, 0.015057440148666501, 0.021357692079618573, 0.03587309470666306, 0.050559510210795064, 0.04450639769701021, 0.05005721787789038, 0.012241954931856265, 0.031072700329657112, 0.007421362263682697, 0.020052906558183686, 0.03068038834525006, 0.08030974918178149, 0.0920605847079839, 0.02285430962885065, 0.04697456543466874, 0.01399663885656212, 0.02425400523601898, 0.07312630928520646, 0.027184899929644804, 0.03160682274028659, 0.04969216603785753, 0.10097448567726783, 0.0053875930690472675, 0.020188530441373587, 0.03778712325064199, 0.024545904215691344, 0.013471949779029404, 0.03399662986131651, 0.055155482342732806, 0.017090385347338657, 0.011230266004401659, 0.050690569249647, 0.054368076380342245, 0.049840911091970544, 0.027962536684104373, 0.047982614021748304, 0.04662217505808387, 0.05357186642608472, 0.019811697537079453, 0.03230556792446545, 0.0654104161741478, 0.027512233704328537, 0.10135138473872628, 0.06381379613386733, 0.03778175264596939, 0.0046907935840343785, 0.027343587218118564, 0.02534029569609889, 0.09287695054497037, 0.047998159259025536, 0.034772063073303015, 0.12114535724478108, 0.20877610572746821, 0.15835173933633737, 0.22638954488294466, 0.12515320575663022, 0.16223351604172162, 0.09594097041657992, 0.17325504177383014, 0.07384425361773797, 0.14487547746726445, 0.11377027191753898, 0.1726894692650863, 0.09557797453765358, 0.20024191295461996, 0.16513489106936113, 0.09032565887485232, 0.14164162028048718, 0.10762634088418313, 0.1296156727309738, 0.07463765782969338, 0.1627675909548998, 0.1426640097051859, 0.18867669068276882, 0.12872143142989703, 0.10389528716249125, 0.10585173432316099, 0.15756485584591115, 0.09666174424013921, 0.12605854789061205, 0.11282530333846807, 0.159613217360207, 0.08342367530401264, 0.17620540702981607, 0.12771220558456012, 0.09124305857611553, 0.10401640566331999, 0.15447416954806872, 0.12048732755439621, 0.09916586415576083, 0.1365543854023729, 0.12966003535049303, 0.08372539268540484, 0.17943048397345202, 0.10711008430059467, 0.11905506226633276, 0.10443737557423965, 0.14148911274969578, 0.12829532500888619, 0.143755473994783, 0.28608113899827003, 0.11937245380665575, 0.15668217678155216, 0.1131670678566609, 0.08917292965842144, 0.14484408843730176, 0.19713684171438217, 0.18796726875007153, 0.22627978505832808, 0.1503129042685032, 0.23780657510672296, 0.1539564880409411, 0.13588429135935648, 0.17023375603769506, 0.2637515829077789, 0.5184351152607373, 0.5419303945132664, 0.3354438287871224, 0.13733847332852228, 0.5140107955251421, 6.316293367317744, 13.552370156560626, 47.059002603803364, 64.28247519901821, 79.07400185721261, 78.06645747593471, 86.95786571502686, 121.68598365783691, 134.89302226475306, 150.66583606175013, 153.55511937822615, 153.62745012555803, 149.41661943708147, 151.57485498700822, 172.76248332432337, 167.80679185049874, 172.57591029575892, 177.1334560939244, 169.8820242200579, 162.30023329598563, 171.9635238647461, 166.90198353358676, 147.85994502476282, 111.72196810586112, 111.81243365151542, 120.20754596165249, 93.84960324423653, 94.59205300467355, 91.36305836268834, 58.73488058362688, 28.493026869637625, 14.054572054318019, 1.9516834105764116, 0.12001978978514671, 0.36118066204445703, 0.6096968810473169, 0.1947484120194401, 0.15937920420297555, 0.15424174416278089, 0.33772006950208117, 0.274415059281247, 0.2105413010077817, 0.11118723837924854, 0.16877411864697933, 0.19423105620912143, 0.2259458236928497, 0.12005563000483171, 0.08619498195392744, 0.15016080385872296, 0.10878252384385892, 0.1366510223597288, 0.0759030170738697, 0.09431091895593063, 0.16754111195249216, 0.10883797372558288, 0.12158348730632237, 0.12619232785488876, 0.11653076271925654, 0.13695081270166806, 0.10755681140082222, 0.12802946141787938, 0.0720309502046023, 0.09448257474494831, 0.1488223663930382, 0.11351545487663575, 0.13347470494253294, 0.20099526324442454, 0.20616561866232327, 0.20609001629054546, 0.13170469206358704, 0.1898842794554574, 0.11203275408063616, 0.09409495483019523, 0.16278270871511527, 0.1456459675516401, 0.1387349119676011, 0.24640117106693132, 0.18333269815359796, 0.1408977559102433, 0.13626284604626043, 0.15866600961557456, 0.10574671745832477, 0.13183212094008923, 0.10918318520167045, 0.1627791803330183, 0.059124589897692204, 0.13946713267692498, 0.1447416975029877, 0.1141338784779821, 0.11453418699758393, 0.068549013829657, 0.18893586391849176, 0.15103373916021415, 0.10795494182301418, 0.22327706404030323, 0.16838050048266137, 0.14993635804525443, 0.10143419993775231, 0.21400096107806477, 0.2044602565999542, 0.17093625691320213, 0.09088348251368318, 0.09346279089472123, 0.11210912998233523, 0.1526343896985054, 0.14770768263510295, 0.06567801681480237], [0.051608796763632975, 0.02839837160094508, 0.06668957682060343, 0.07845035967017923, 0.0897684662735888, 0.006876709837732571, 0.07985652171607528, 0.06765170555029597, 0.011089609935879707, 0.03267334408259817, 0.00951560037875814, 0.015100284546081508, 0.017794540151953697, 0.03022379195317626, 0.020088858736146773, 0.04381408502480813, 0.038640923864607296, 0.030043172716562237, 0.016880534822121263, 0.027809420168133717, 0.016356096802545444, 0.026355233109955276, 0.04149789556062647, 0.04456869399707232, 0.0963850308741842, 0.029919933793800216, 0.07255814477269139, 0.035297710581549575, 0.016074689670598934, 0.03963185979851654, 0.01910670643805393, 0.021495036049080745, 0.05409976667059319, 0.01838005310855806, 0.05092902002590043, 0.016733182461134026, 0.060217248408922126, 0.05033001609678779, 0.053620296863040755, 0.0206539325216519, 0.023074869132999862, 0.0625701771516885, 0.016719508284170712, 0.07109934876539878, 0.039975503858711035, 0.03692924124853952, 0.013844030393686677, 0.023635656273524677, 0.011168446375190147, 0.015783822064154913, 0.014527465283338512, 0.004767976942405636, 0.039161054883152246, 0.007934816497644144, 0.08134522754698992, 0.056822941438960176, 0.058484398892947605, 0.04148690329332437, 0.08871413142021213, 0.12300922508750643, 0.12769798349056924, 0.8015028802411897, 2.3329697166170393, 6.038697634424482, 15.137908254350934, 16.41054204532078, 16.889179127556936, 43.418344565800254, 63.989191736493794, 84.4101002556937, 94.05215018136161, 101.10244560241699, 112.91266005379813, 102.00274453844342, 109.05119868687221, 104.12137535640171, 98.38717297145298, 98.53797667367118, 99.79330076490129, 83.46439484187535, 99.06997244698661, 97.5513950075422, 89.61387716020856, 88.80898393903459, 83.22328540257045, 92.1144574029105, 80.24371719360352, 94.95696544647217, 95.5452902657645, 86.80874347686768, 70.71556213923863, 95.9156778880528, 99.9935895374843, 94.21418912070138, 113.15812601361955, 110.40821661267961, 113.14750916617257, 101.49881253923688, 110.58420058659145, 110.81044782911027, 112.18216814313615, 74.70509270259312, 57.36504670551845, 35.534817695617676, 13.260548421314784, 1.5486391463450022, 0.6724722811153957, 0.09919875274811472, 0.4390388642038618, 0.07024783481444631, 0.21045239934963839, 0.006547742489991444, 0.0015645852358180232, 0.04417297915954675, 0.057439672095435004, 0.029141189330922704, 0.02658162122991468, 0.06280290109238454, 0.04775259065042649, 0.04348985045882208, 0.04052901540749839, 0.0033467919191545142, 0.03744116538603391, 0.039392798340746334, 0.007761063187250069, 0.01462911831081978, 0.014671927085146308, 0.0058830813920524505, 0.03444475135100739, 0.04475874147777047, 0.008099123752409858, 0.0569409556420786, 0.01938189140387944, 0.03418991056137851, 0.024537252894203578, 0.01579763025178441, 0.02138198702596128, 0.02514869097753295, 0.05585563209440027, 0.023455990378611853, 0.015655317709648182, 0.02427554702652352, 0.028966809223805155, 0.00860962042185877, 0.038614827407790084, 0.034495526126452854, 0.036420991378171105, 0.04539723614496844, 0.07942274106400353, 0.032282684330961535, 0.04096127274845328, 0.01077738798423005, 0.038302321319601366, 0.07006282545626163, 0.02190170413814485, 0.01594211410598031, 0.06669758353382349, 0.06553590444049665, 0.11724108031817845, 0.042720354428248744, 0.0755953760817647, 0.05596673541835376, 0.04553152161783405, 0.006168133953386652, 0.037455652108682055, 0.029287607009921755, 0.05705675442836114, 0.0359267939680389, 0.04446381962459002, 0.08316613055233445, 0.03945117949375084, 0.055484283449394364, 0.04040260433352419, 0.009106119762041738, 0.06503908788519246, 0.021341685438528657, 0.023836210868986588, 0.0333293856653784, 0.029202783347240517, 0.029311382876975194, 0.03858331624152405, 0.031967216437416415, 0.04971891388829265, 0.0400384786937918, 0.06069478778434651, 0.04273346033213394, 0.022869646216609647, 0.056719878754977665, 0.049681078775652816, 0.03193943042840276, 0.03165052039548755, 0.02779903688601085, 0.014084372586304588, 0.015319030665393387, 0.04713047581857868, 0.036495335067489316, 0.025533206594575728, 0.09038393146225385, 0.018935808911919594, 0.06212387074317251, 0.05893138383648225, 0.05785248601543052, 0.024898065586707423, 0.04592572332226804, 0.02051494480110705, 0.01619179294045482, 0.07230890528964144, 0.012240370552587723, 0.010901044206028538, 0.03639351070991584, 0.03307622764259577, 0.009219163696148565, 0.0077271695148998076, 0.020020713464223912, 0.04038432120744671, 0.03851775618802224, 0.032168792228081396, 0.023804633545556238, 0.04694199236109853, 0.11503928846546582, 0.041999010635273795, 0.0339051124506763, 0.021428325878722326, 0.019833079871854613, 0.01794225044016327, 0.01879465327199016, 0.03664661444989698, 0.021659039659425616, 0.05539168377539941, 0.034792327521634955, 0.018388439801388552, 0.04872306536084839, 0.1307152658700943, 0.07215267938694783, 0.11242616868444852, 0.07469763353999172, 0.09006558318755456, 0.196595126496894, 1.0485552549362183, 3.7918243493352617, 13.494586331503731, 14.495584641184125, 17.621324709483556, 44.43820462908064, 68.63167926243374, 96.61853681291852, 111.63646357400077, 119.92575481959751, 132.36922809055872, 122.1383947644915, 127.28443908691406, 117.0939608982631, 112.2128027507237, 111.01390498025077, 112.123414175851, 104.66275119781494, 113.12346839904785, 116.34845393044608, 110.15019525800432, 106.20290279388428, 102.9801823752267, 116.57015010288784, 101.06828825814384, 106.67953532082694, 110.23055812290737, 107.7629679271153, 91.66702815464565, 115.10375363486153, 123.58560725620815, 117.3880364554269, 130.6115561894008, 132.5539390019008, 134.00172124590193, 125.08862767900739, 132.17028726850236, 131.89891842433383, 128.30865914481026, 83.27634184701103, 61.410701342991416, 40.03225462777274, 13.849947605814252, 1.2517745388405663, 0.2853564907397543, 0.11392251481967312, 0.35181264472859247, 0.02036899361493332, 0.10110285093209573, 0.02344320508252297, 0.055257693465266905, 0.04381038022360631, 0.059363339229353836, 0.024604500803564276, 0.03533211230699505, 0.04269971339298146, 0.03002575472263353, 0.01605398247816733, 0.014184706711343356, 0.0541490147422467, 0.1098497508625899, 0.03297218108283622, 0.0042879698199353045, 0.007327033173558968, 0.04584910993331245, 0.03905687261638897, 0.0245290341387902, 0.029785034246742725, 0.03528309493724789, 0.022357981618759886, 0.04381156426721385, 0.02833881149334567, 0.04476552004260676, 0.03961257922596165, 0.01577480772643217, 0.0244933652491974, 0.11796581000089645, 0.033915952047599215, 0.06721359584480524, 0.046765423978545835, 0.02416761585378221, 0.009380205501137035, 0.013637875339814594, 0.06159690009163959, 0.0359976296313107, 0.052477844059467316, 0.08057207081999097, 0.019599122693762183, 0.03984643292746373, 0.026152975391596556, 0.04498783864879182, 0.04877991981006094, 0.028037825233436058, 0.0783366643424545, 0.0792338911976133, 0.022501237324572036, 0.020302899215104322, 0.02131062719438757, 0.08199616654642991, 0.05067503758307014, 0.07342084776610136, 0.02613766085622566, 0.00987686260071184, 0.058020416647195816, 0.05131485878622957, 0.011425762121299548, 0.07005219281251941, 0.05223747302911111, 0.04135052453992622, 0.0922586830066783, 0.050649195576884916, 0.017638017390189425, 0.033700452718351565, 0.06341762667787926, 0.12308904794710022, 0.1255644251193319, 0.15876701633845056, 0.20439712570181914, 0.19317889266780444, 0.06373058059918028, 0.1122440363147429, 0.1075559157345976, 0.14427239554268972, 0.07164277389113392, 0.1259838276143585, 0.11351139723722424, 0.10587935069841997, 0.09322431297706706, 0.09193900480334248, 0.13501968846789428, 0.085377598314413, 0.08821612742862531, 0.10274938400834799, 0.1425514950283936, 0.14632769168487617, 0.19828504510223866, 0.05474621376820973, 0.1630039382725954, 0.19000469227986677, 0.26535145991614884, 0.18250826453523977, 0.1817437048469271, 0.08658263579543148, 0.10571777115442924, 0.11188455524721316, 0.11136306715863091, 0.11461979097553662, 0.12943370320967265, 0.10507637914270163, 0.09200728578226906, 0.08675092605075665, 0.10841065951223884, 0.15675534999796323, 0.13567397264497622, 0.09597721097192594, 0.1282980934317623, 0.14552294915275915, 0.2431595650102411, 0.15647012101752417, 0.1831791592495782, 0.12569064620350087, 0.0931887441713895, 0.10661900815154825, 0.0810601342735546, 0.061737987878067155, 0.10294992503310953, 0.18146338846002305, 0.26056447678378647, 0.2399351123188223, 0.1786185625408377, 0.25907900077956064, 0.287091531923839, 0.3020139554781573, 0.18971111731869833, 0.37680574932268684, 1.9053864777088165, 5.0532402736800055, 11.517796908106122, 26.0918162890843, 29.59986448287964, 29.260264328547887, 61.95523861476353, 91.34959970201764, 121.21044894627163, 129.81830814906527, 137.56349291120256, 146.0955750601632, 131.1510282244001, 137.93522153581893, 130.5034978049142, 122.86990111214774, 122.33316666739327, 124.46508244105748, 108.2443460736956, 122.38015038626534, 121.30162320818219, 113.70577607836042, 113.2486263002668, 107.46243054526192, 117.63961683000836, 102.85372516087124, 116.82345363071987, 117.80462265014648, 113.11361585344586, 96.84998825618199, 124.32317243303571, 132.0147726876395, 122.34764671325684, 138.99528040204729, 141.78213337489535, 141.76210866655623, 132.7134974343436, 147.39704213823592, 149.50104004996163, 150.06403868538993, 110.04297760554722, 81.45601109095982, 59.45262949807303, 21.902036905288696, 3.5676059808049883, 1.0659615780626024, 0.21248394676617213, 0.6419619268604687, 0.17246790044009686, 0.34873044011848314, 0.10269994594688926, 0.11868051093603883, 0.20296794096274035, 0.16099727952054568, 0.12706617239330495, 0.120719277965171, 0.12233488341527325, 0.09063707930701119, 0.08403768842773778, 0.08647042645939759, 0.1341108586639166, 0.15463302816663468, 0.1367100141942501, 0.09783266498042004, 0.05617888617728438, 0.1569804743464504, 0.13340059534779616, 0.11549705533044678, 0.11267490605158464, 0.09943816025874444, 0.18388741410204343, 0.11165337158100945, 0.10190984620047466, 0.1395150643906423, 0.09927526435681752, 0.1163560263812542, 0.10037949867546558, 0.19066211128873484, 0.10270869904862982, 0.09953795918928725, 0.12169161864689418, 0.12003230197089058, 0.08439826193664755, 0.14569987037352153, 0.13068520676876816, 0.13649371080100536, 0.19142056416187966, 0.18269321961062296, 0.08213382094566311, 0.1284676729036229, 0.08532522898167372, 0.12233469342546803, 0.13449933353279317, 0.06719980801322631, 0.31133900795664105, 0.2188563948231084, 0.13326967880129814, 0.20416654593178205, 0.11726872383483819, 0.17921846892152513, 0.1223669374095542, 0.10259220815662827, 0.1171525993517467, 0.10985413419881038, 0.13903589653117315, 0.10158017317631415, 0.09559070385460343, 0.11758017140839781, 0.19896269802536282, 0.13261543533631734, 0.18019245165799344, 0.14065752737224102, 0.1037505759990641, 0.13869457984609262, 0.08045747304069144], [0.0635455237435443, 0.0713831799636994, 0.03444322125454034, 0.029961538168468645, 0.033465248732162375, 0.08621730575604097, 0.023137195967137814, 0.05306751813207354, 0.04627419176644512, 0.0223290081734636, 0.07590912388903753, 0.018901705741882324, 0.05651515795450125, 0.03817303664982319, 0.0519763727539352, 0.028686648899955407, 0.010748321240368699, 0.056919150919254334, 0.0727687349010791, 0.02035255271143147, 0.03345853462815285, 0.05151280441454478, 0.009375673735381236, 0.05690258448677404, 0.032060511609805484, 0.05754125557307686, 0.030206560556377684, 0.029990531969815493, 0.020507952497739877, 0.01498316940186279, 0.049809539025383334, 0.02915176090651325, 0.029650362008916478, 0.019408534081386666, 0.056809771074248214, 0.03600918847535338, 0.013739497833220022, 0.060845632904342244, 0.04247024642037494, 0.06469169831169502, 0.04500810309712376, 0.03796785444553409, 0.019708354957401752, 0.07129912304558925, 0.04309927213138767, 0.10206286941788026, 0.03326945745253137, 0.018386271882003972, 0.0037775185275157647, 0.019542807679889456, 0.036446711248052974, 0.006996020890905389, 0.05891041710440602, 0.03906300657295755, 0.05954959030662264, 0.06784383952617645, 0.03698446382103222, 1.7462321264403207, 13.349342925207955, 24.384218318121775, 39.88859714780535, 74.77103110722133, 81.4610207421439, 94.22427790505546, 96.4431712286813, 91.57265077318463, 102.56547219412667, 86.70677171434674, 85.61844757625035, 84.25844192504883, 84.46126679011753, 89.58739757537842, 84.73249667031425, 81.21725014277867, 83.0519358771188, 91.57217829568046, 78.5937910079956, 78.7912449155535, 88.01499938964844, 60.16854408809117, 78.71245929173061, 75.39646625518799, 54.343160493033274, 65.89581911904472, 70.9997226170131, 58.85948262895857, 45.7472174508231, 60.54498359135219, 51.46634571892874, 50.31413289478847, 46.2693224634443, 50.228975772857666, 56.92059128625052, 53.269222600119456, 75.83958067212785, 64.48916326250348, 80.7561468396868, 93.16211373465401, 86.2796242577689, 93.9280345099313, 88.55149064745221, 95.4220917565482, 101.02126285008022, 107.69828714643205, 95.59751987457275, 75.22608252934047, 57.97486230305263, 40.8671293258667, 12.368806191853114, 1.3118038262639726, 0.26882059233529226, 0.10328833758831024, 0.03768419627366321, 0.0702768557571939, 0.10581511378820453, 0.06580834303583417, 0.03979842657489436, 0.026026058809033463, 0.07842137265418257, 0.1354870633887393, 0.030986709586743797, 0.03961256565526128, 0.004378181474748999, 0.017971746357423917, 0.03689168094258223, 0.020761247923863784, 0.037613428463893275, 0.027188769275588647, 0.0673401765525341, 0.05044014233031443, 0.02403406998408692, 0.05714326085788863, 0.02240477848265852, 0.03332438486229096, 0.03912053616451366, 0.03385472104751638, 0.037601228404257975, 0.060279897547193935, 0.04098192396174584, 0.02365028209585164, 0.0369646947032639, 0.04343372204207948, 0.01875905562857432, 0.05621680949947663, 0.04227135084303362, 0.042649790178984404, 0.0998071747432862, 0.041449210673038445, 0.0198552238621882, 0.021841041411140134, 0.05824313898171697, 0.024191566443602954, 0.004934209540286767, 0.05734478575842721, 0.09905977520559515, 0.08200316902782236, 0.04855548756729279, 0.019987010629847646, 0.05891409476420709, 0.01123800893713321, 0.0408861080317625, 0.005353012379990625, 0.04094056046700903, 0.024015875067561865, 0.03745639510452747, 0.046468568300562244, 0.0774593660607934, 0.03381277061998844, 0.04975570744967886, 0.05588743842339941, 0.04257642697276814, 0.02805546375124582, 0.07869420479983091, 0.035452497990003655, 0.012541190571417766, 0.08789532285715852, 0.00998276240924107, 0.029440158645489385, 0.018411196169576476, 0.06506136418985468, 0.012080094644001551, 0.04276940572474684, 0.025966983853972385, 0.059861146445785246, 0.03269983069705112, 0.086169204408569, 0.010724445289400007, 0.04143227443897298, 0.024438385252973864, 0.06246986931988171, 0.033495460503867695, 0.012945940102716642, 0.01986979879438877, 0.02898434256868703, 0.024459513137117028, 0.07950395492038556, 0.04108850145712495, 0.03013953486723559, 0.07393714506179094, 0.02840408995481474, 0.03453125099518469, 0.07921407797506877, 0.021367790377033607, 0.014699314454836505, 0.0450948334432074, 0.03189506780888353, 0.05138007617954697, 0.017168964791510786, 0.06702727012868438, 0.054019143139677386, 0.01079980593307742, 0.015127829675163542, 0.03665410547650286, 0.04529471968167594, 0.025255436410329173, 0.05729121541870492, 0.03158829873427749, 0.04277827078476548, 0.030660626012831926, 0.1015689027096544, 0.03637230649058308, 0.02218716890950288, 0.03522809288863625, 0.028208000119775534, 0.023636445070483854, 0.04483157542667218, 0.01852387878378587, 0.06547048687934875, 0.04986188121672187, 0.0573183839608516, 0.06360535017613854, 0.04348919567252908, 0.02281974335866315, 0.3357747910278184, 9.32679625919887, 18.178797789982386, 36.27594035012381, 71.81167520795549, 85.31411647796631, 103.51408195495605, 108.60212966373989, 108.98883860451835, 111.49220507485526, 107.39658941541398, 101.01475933619908, 102.32996995108468, 95.25213187081474, 108.54999732971191, 103.10001100812639, 105.11496775490897, 108.57592105865479, 131.00025231497628, 112.8401208605085, 121.36376789637974, 144.92883355276925, 87.41537679944719, 123.86709267752511, 120.80304827008928, 95.39814826420375, 114.41367939540318, 118.72079821995327, 99.08408423832485, 91.25446496691022, 111.79042870657784, 106.13554695674351, 84.61778885977608, 84.31476402282715, 96.18021665300641, 90.11371667044503, 99.41093444824219, 121.71927942548479, 94.86922359466553, 101.87901101793561, 115.54242815290178, 110.08486829485211, 111.61231163569859, 107.87312466757638, 109.6171155657087, 119.1727785382952, 124.91058703831264, 114.83066858564104, 89.14794485909599, 70.63488660539899, 45.60526922770909, 13.200623682567052, 1.5980083772114344, 0.13565082103013992, 0.19034959162984574, 0.041719033515879085, 0.06297246699354478, 0.13184909788625582, 0.10243715611951691, 0.05986903102270194, 0.08159671298095159, 0.03887732546510441, 0.014646666922739573, 0.02859786937811545, 0.018745378058935915, 0.009252590875673507, 0.030819060547011237, 0.04629495833069086, 0.04964325723371335, 0.07368982583284378, 0.04688224056735635, 0.03239796403795481, 0.0749179335044963, 0.05556714614587171, 0.10066171496042184, 0.06405972436602626, 0.023939806202958738, 0.11765228611017976, 0.01080913663775261, 0.04598281525873712, 0.02445486856491438, 0.049210222970162115, 0.051846440083214214, 0.07447888742067985, 0.03159820534554975, 0.044471924725387774, 0.06839325611612626, 0.0369765928148159, 0.022331228679312125, 0.0214556759289865, 0.050844745976584296, 0.013218044519557484, 0.006615884793323598, 0.024235472748322145, 0.025992165984851972, 0.019050647571150745, 0.10237202354307685, 0.060969736959253035, 0.05348764326689499, 0.10293300915509462, 0.027135606056877544, 0.053326810111424754, 0.031037229911557267, 0.04191714877794896, 0.043963349158210416, 0.038714388851076365, 0.019446684712810174, 0.06563978136650153, 0.024252671914707338, 0.06941404419818095, 0.04963568478290524, 0.03623360375474606, 0.0653705590271524, 0.024116581538692117, 0.03026273986324668, 0.06284729763865471, 0.04599793301895261, 0.02180339628830552, 0.03836622914033277, 0.17089221999049187, 0.11299371573009662, 0.06645090891314404, 0.1779870092868805, 0.11416454826082502, 0.15680011973849364, 0.132302033581904, 0.15703918119626387, 0.15426068886050157, 0.23848988701190266, 0.12352478956537587, 0.11639040096529893, 0.10961719655564853, 0.10584017208644322, 0.19522542213754995, 0.1327390508460147, 0.1086006018200091, 0.12163333248879228, 0.16305239924362727, 0.08117776510438748, 0.14949326110737665, 0.16961242152111872, 0.12581203611833708, 0.1291189036731209, 0.08933734547879014, 0.13139443871166023, 0.2244602662644216, 0.10127417423895427, 0.11587276017027241, 0.10322551881628377, 0.13587502257100173, 0.11779928393661976, 0.2942143582871982, 0.1301774861557143, 0.1544075102678367, 0.11378915554710797, 0.1308019147919757, 0.19927030509071691, 0.16432185683931622, 0.1237729298216956, 0.1314247285148927, 0.14948457585913794, 0.11249848016138587, 0.2007372842303344, 0.1338769540722881, 0.16544213172580513, 0.20817197885896477, 0.18562508800200053, 0.0815122150150793, 0.12247875998062746, 0.11939504902277674, 0.25088924595287865, 0.09964851968522583, 0.1367627770773002, 0.23360394633242063, 0.4419624816094126, 0.2257212150309767, 7.227847082274301, 28.98712543078831, 46.71342699868338, 65.87199374607631, 101.8413587297712, 112.48897974831718, 127.1484489440918, 127.66007259913853, 121.3863912309919, 133.3574286869594, 117.27409989493233, 111.09817968096051, 104.82759720938546, 105.03348623003278, 109.24528966631208, 105.29245253971645, 104.28251797812325, 108.41705049787248, 119.64927210126604, 105.31744521004813, 103.83244841439384, 115.13600022452218, 82.33400630950928, 104.60745048522949, 104.55479703630719, 76.76886054447719, 91.36301667349679, 93.66113335745675, 81.80636705671037, 69.93760708400181, 85.47835104806083, 77.56712518419538, 76.8676152910505, 68.94218036106655, 75.89414487566266, 82.6175900868007, 78.6374465397426, 105.80224881853376, 92.49970722198486, 108.98602458408901, 119.36486843654087, 115.26663330623082, 119.79793575831822, 115.03946195329938, 122.30937603541783, 130.1318803514753, 140.05097579956055, 132.03219876970564, 106.08455412728446, 89.60688032422746, 63.07723372323172, 22.321520498820714, 3.7961630650929044, 0.2651650799172265, 0.27406412096960203, 0.16888191072004183, 0.1464386321604252, 0.24205822125077248, 0.2599786025072847, 0.14504159641052994, 0.18469446365322384, 0.15490391291677952, 0.2115610170045069, 0.09150848111936025, 0.14690720130290302, 0.11043538765183517, 0.11714965450976576, 0.07343161611684731, 0.1755727952612298, 0.17874885483511857, 0.15661040134727955, 0.15664449094661645, 0.21379636919924191, 0.15655542644006865, 0.24537012353539467, 0.1833819733666522, 0.09885532581912619, 0.24157163021819933, 0.10538488187428031, 0.10947861256343977, 0.17622682159500463, 0.10898461871381317, 0.1711025929876736, 0.14761616183178766, 0.11579733421759945, 0.07935931161046028, 0.2481650092772075, 0.07378536356346947, 0.10652142803051642, 0.16892026151929582, 0.19919239569987568, 0.1335076546030385, 0.07788175410990204, 0.08191410452127457, 0.17502535320818424, 0.08514051139354706, 0.19294904571558746, 0.15895680258316652, 0.13974048729453767, 0.17607876525393554, 0.12608733134610312, 0.18699832074344158, 0.06406819926840918, 0.09464975220284291, 0.061454394167023044, 0.15350302308797836, 0.18806566989847592, 0.10945928788610867, 0.08990960155746766, 0.15971000359526702, 0.11022751844887223, 0.2167436403355428, 0.07389308099767991, 0.12049701703446251, 0.21087841077574662, 0.13608698334012712, 0.15364611255271093, 0.06730588339269161, 0.26944973000458305], [0.0784402834251523, 0.08011935904089894, 0.08183473628014326, 0.13157927165074007, 0.030275201158864156, 0.03024291307000177, 0.017554510085444366, 0.06835468818566628, 0.02828515294407095, 0.020838712874267782, 0.026481138675340583, 0.042725711462220976, 0.036562547353761535, 0.06463566488985505, 0.04602763928206904, 0.009518558791439449, 0.03983616669263158, 0.016718612617946098, 0.08249804497297321, 0.017024073816303695, 0.036256399138697555, 0.03619639967967357, 0.014389223951314176, 0.0532696537141289, 0.011434046185708471, 0.03184761446235435, 0.017614557041919658, 0.028168996230566075, 0.04429975324975593, 0.027291055036974803, 0.015886070506115044, 0.052011724428406785, 0.06311936982508216, 0.045844502680535824, 0.047689035667904785, 0.021456425710182105, 0.04369583333443318, 0.022870460458632027, 0.037557011669767756, 0.04986388628770198, 0.025036846354071583, 0.06862987484782934, 0.05027817941403814, 0.032618050263928514, 0.004321217187680304, 0.07893005678696291, 0.020240414621574537, 0.059546692962093015, 0.04099250232268657, 0.06338415454540934, 0.07873478797929627, 0.15156881830521993, 0.040517110510596206, 0.0798915544790881, 0.10992883411901337, 6.134119416986193, 30.2526581627982, 61.336543219430105, 84.1069781439645, 93.00710637228829, 85.66108867100307, 81.56552164895194, 83.68096324375698, 69.8950424194336, 82.53008447374616, 88.0071826662336, 55.30130318232945, 67.5934168951852, 79.6637441090175, 44.11823660986764, 57.26867519106184, 30.868994644709996, 37.01840053285871, 25.312513283320836, 27.99623761858259, 25.255023888179235, 32.95604937417166, 29.24302237374442, 20.96032496861049, 31.951715060642787, 21.3809689113072, 24.95597689492362, 22.03392587389265, 15.16953124318804, 27.863744156701223, 25.402634893144878, 26.9882207598005, 25.426555803843907, 18.018395151410783, 36.907618454524446, 23.36749710355486, 25.23018060411726, 24.620410169873917, 21.914178882326397, 30.435982908521378, 44.235244274139404, 45.48648977279663, 34.28441640308925, 35.013376235961914, 52.55903679983956, 69.84153434208461, 64.9117249080113, 61.4443028313773, 88.5744822365897, 93.69195556640625, 87.63244547162736, 98.9560775756836, 104.38249560764858, 96.32806737082345, 76.28024237496513, 38.88738604954311, 14.11162805557251, 0.5530601601515497, 0.34778999058263643, 0.04253962662603174, 0.07792231693331685, 0.0592542647251061, 0.025951772795191834, 0.019434830706034387, 0.01606704936628895, 0.09630084503442049, 0.05161745147779584, 0.0503815711875047, 0.020588448803339685, 0.06461110192217998, 0.07466641414378371, 0.03194571705535054, 0.04218069856454219, 0.02190405865465956, 0.02010288575131978, 0.040590202302805016, 0.012231248497430767, 0.05052464368886181, 0.028789399457829337, 0.012087223502541227, 0.040906168919588835, 0.00514157917184223, 0.04336959709014211, 0.055342869966157844, 0.022710602697251097, 0.025001686365742768, 0.040079122941408835, 0.029854872463537113, 0.031153208509619747, 0.06587621689374958, 0.02443160499180002, 0.0035243208528429803, 0.025953043352014253, 0.08085639734885522, 0.04338487769876208, 0.06478488152580601, 0.01836254520873938, 0.0358262859684016, 0.07270873883473021, 0.015826695299308215, 0.0695192917649235, 0.03611069731414318, 0.04479852059323873, 0.006745684301547174, 0.10579756687262229, 0.025356792578739778, 0.014212607223141407, 0.03565597028604575, 0.03427027964166232, 0.01902062239657555, 0.01861397466356201, 0.07062508671411447, 0.06481861150158302, 0.049652173183858395, 0.04344514857179352, 0.02557736904626446, 0.030573888881398097, 0.05404681719041296, 0.05902109295129776, 0.12511195082749638, 0.047788953342075856, 0.052717950461166244, 0.04932213035811271, 0.06693024640636784, 0.03751775163358875, 0.05579967670408743, 0.04842995858884283, 0.0847625063200082, 0.019019236488799964, 0.05959737952798605, 0.06387689310525145, 0.06599019042083196, 0.05399616115859576, 0.021693175059876273, 0.03979159372725657, 0.032764332235923836, 0.05181410110422543, 0.012676150338458163, 0.007852277801638203, 0.11131500652326004, 0.033325836927230866, 0.04268143365957907, 0.04150633992893355, 0.028095553296485117, 0.024086466458226954, 0.03637253040713923, 0.047026374976017644, 0.0605875588953495, 0.027147831561576043, 0.03533323867512601, 0.029637968566800867, 0.10249527942921434, 0.05480153812095523, 0.031917133767689974, 0.04041566273995808, 0.04469689640349575, 0.062902978222285, 0.026917640252837112, 0.020600723501827036, 0.011301954077290637, 0.0790101917726653, 0.048493540712765286, 0.03068111098504492, 0.039347309353096147, 0.017438119277358055, 0.01391623160868351, 0.08984931372106075, 0.042191022474850924, 0.04199255776724645, 0.01390765662238534, 0.04349203194890704, 0.010287402580226106, 0.0795247180919562, 0.04265803098678589, 0.14866563837443078, 0.16307811572083405, 2.707823944943292, 23.1649067401886, 56.36981800624302, 94.29145308903286, 106.3998772757394, 102.61123997824532, 99.07784475599016, 101.11842645917619, 81.00981862204415, 99.96243381500244, 99.30334854125977, 85.44054589952741, 93.49912915910993, 104.53056171962193, 78.06745106833321, 99.70687212262834, 73.48517663138253, 61.75990390777588, 55.78506108692714, 49.465681416647776, 44.55411795207432, 43.749929973057334, 45.77099766050066, 35.494059562683105, 41.30316352844238, 34.41268014907837, 38.27537134715489, 29.503100395202637, 27.132206542151316, 34.03664711543492, 31.613414219447545, 27.66151336261204, 26.581362043108257, 23.89090837751116, 46.39036008289882, 22.011667319706508, 29.306386470794678, 29.8944958959307, 26.100687401635305, 41.76615326745169, 54.017765930720735, 65.81940977913993, 60.79419463021414, 62.72505038125174, 87.16062109810966, 97.16640227181571, 94.84786483219692, 82.6556453704834, 108.21508720942906, 105.1414542879377, 104.21056243351528, 110.73562267848423, 121.300692149571, 114.39462048666817, 87.94560078212193, 43.116928236825125, 16.299971887043544, 0.4425769629223006, 0.20728444148387226, 0.04518082757879581, 0.058924042087580474, 0.04114648227446845, 0.05777688364365271, 0.023347229696810246, 0.058842984294252734, 0.03526646065126572, 0.03706049366987177, 0.040422410770718536, 0.06395345221140555, 0.057802600120859485, 0.07182709792894976, 0.030023250928414718, 0.017504854892779673, 0.020124381740710566, 0.08175688795745373, 0.07760808058083057, 0.04705421866050788, 0.044242406862654855, 0.013727800737667297, 0.03524615888350776, 0.022525649318205457, 0.016008530809943165, 0.011753086566126772, 0.09626902852739606, 0.04163136679146971, 0.06137864251754113, 0.024341013781460266, 0.008450985719848956, 0.03004162565671972, 0.05530050563226853, 0.06609552619712693, 0.07105770707130432, 0.03710114809551409, 0.025426311884075403, 0.05172084664393749, 0.03606506583413907, 0.016423745047567145, 0.04884251805820635, 0.019685873395896385, 0.03954345007826175, 0.05188873656360166, 0.07649999218327658, 0.015002390602603555, 0.038717686531267, 0.031972376696233235, 0.042194466040070565, 0.024819983169436455, 0.07099319196173123, 0.059410069936088154, 0.02959143802789705, 0.03886308640773807, 0.08598794056368725, 0.04345194410000529, 0.03192270454019308, 0.04652539560837405, 0.04850447191191571, 0.05935500003397465, 0.033775301916258674, 0.028369849381436194, 0.032558770052024295, 0.05249269040567534, 0.16307001401271137, 0.12055615814668791, 0.16456481308809348, 0.24645762518048286, 0.1267033325774329, 0.10391755668180329, 0.11550111296985831, 0.14121672165180954, 0.16066554374992847, 0.14736329897173814, 0.1132357966686998, 0.17662261107138225, 0.10202162127409663, 0.18835172669163772, 0.09660570403294903, 0.19037661089428834, 0.20463062317243644, 0.15753996718142713, 0.24060870760253497, 0.1340380111443145, 0.19711440934666566, 0.13528427641306603, 0.1505673820418971, 0.14971037874264376, 0.12602029208626064, 0.09200615941413812, 0.18086212500929832, 0.08773676279400076, 0.16613153687545232, 0.09709535525845629, 0.22692906164697238, 0.1381064664040293, 0.10431002812193972, 0.11335897113063506, 0.1684604590492589, 0.10843552103532211, 0.1390537012900625, 0.12041092451129641, 0.13459839964551584, 0.13313899295670645, 0.13314060787005083, 0.14406779009316648, 0.20255768511976513, 0.08380833680608443, 0.15313399503273623, 0.2899671904742718, 0.16184539401105472, 0.14662905622805866, 0.17448141239583492, 0.16682666886065686, 0.185356469558818, 0.22976780789239065, 0.2333860280258315, 0.17962356789835862, 0.7443963959813118, 14.530775529997689, 57.46626806259155, 94.977997643607, 117.89297594342912, 121.5873887198312, 113.11163561684745, 100.89690399169922, 105.57200636182512, 86.69295174734933, 103.15371363503593, 107.33874566214425, 75.72684614998954, 85.05849920000348, 103.00641182490757, 67.46780736105782, 78.45401409694126, 47.057571274893625, 56.061335359300884, 38.37165600912911, 42.4854724747794, 33.829066208430696, 45.39923429489136, 40.139357634953086, 27.232868569237844, 45.329995495932444, 28.080286502838135, 36.56649317060198, 31.764565331595286, 20.964884723935807, 43.09063277925764, 36.99670130865914, 38.601158482687815, 36.35098784310477, 26.50100438935416, 52.32829407283238, 29.777588980538503, 37.280931268419536, 42.015239238739014, 29.987806728907994, 39.05949640274048, 58.402207783290315, 64.88607910701207, 47.053944315229145, 50.83893033436367, 72.74435274941581, 92.49084826878139, 88.96241406032017, 84.61776106698173, 112.78977421351841, 114.95427703857422, 115.89133194514683, 127.13742910112653, 133.4538140978132, 129.01455443246024, 110.66807229178292, 63.523266383579795, 25.026867628097534, 1.1915859856775828, 0.35817388338702066, 0.14763469940849713, 0.19171175067978247, 0.14286045916378498, 0.10642092342355422, 0.0817259739020041, 0.11847753397056035, 0.19951607047447137, 0.1671021812196289, 0.12293674397681441, 0.10542587217475687, 0.13223023100623063, 0.10756061798227684, 0.18598035536706448, 0.12886032754821436, 0.056752828415483236, 0.13280588654535158, 0.16804159938224725, 0.15159632611487592, 0.10236192015664917, 0.0828406848013401, 0.11112637378807579, 0.12358458207121917, 0.10851005132177047, 0.1378824548529727, 0.24769397026726178, 0.13622772507369518, 0.08539047012371676, 0.1091598571677293, 0.1391638003821884, 0.19037194257336004, 0.1498322029198919, 0.1555680494223322, 0.1509156333548682, 0.12119626094188009, 0.1753177610891206, 0.12987941929272243, 0.10778649550463472, 0.20631850617272512, 0.09442099769200597, 0.1544439611690385, 0.1290754367198263, 0.12268789804407529, 0.17154782052550996, 0.07243254115538937, 0.14349946273224695, 0.09173306942518268, 0.14881638171417372, 0.08918681927025318, 0.13519821103130067, 0.1079300870852811, 0.08050324701304946, 0.10685128425913197, 0.1533182987145015, 0.12662958939160618, 0.07543020030217511, 0.11193484826279537, 0.2047233653387853, 0.14166729604559286, 0.07339631193982703, 0.17096129485539027, 0.15446034100438866, 0.12337760174913065], [0.017698829394898245, 0.10247196496597358, 0.053533956674592834, 0.06105634516903332, 0.023724853094401102, 0.008020394182364856, 0.02493735446062471, 0.10753517291907753, 0.016867525609476224, 0.1132877113829766, 0.012328776880167425, 0.040583294816315174, 0.023393207229673862, 0.08013148446168218, 0.025607884462390627, 0.08319395048809902, 0.055998684239706824, 0.06308203004300594, 0.013137960423981505, 0.03958151250013283, 0.029009360154824596, 0.030623683173741614, 0.015368577292455094, 0.04218569936762963, 0.04481339068817241, 0.07751661406031676, 0.06232943292707205, 0.028657000312315564, 0.040749495183782916, 0.04681668390652963, 0.07232236063906125, 0.03366799499573452, 0.053262552845158746, 0.025356220912986567, 0.02960463214133467, 0.04795142176694103, 0.03725157591647335, 0.0368419952158417, 0.01912658751410033, 0.03909950836428574, 0.08850143104791641, 0.02332344025905643, 0.00636255883312385, 0.07586463234786477, 0.053497814506824524, 0.15879958601934568, 0.009646214977172869, 0.009795411257073283, 0.033928501552769115, 0.08780271639781338, 0.14992897558425153, 0.2065643122685807, 4.51934894493648, 9.735063723155431, 35.73492234093802, 66.74897452763149, 87.47056634085519, 87.7641624723162, 74.46547712598527, 72.59962177276611, 62.842148372105186, 66.85080732618059, 70.83536297934396, 72.69390187944684, 44.23127337864467, 39.52320180620466, 29.43988221032279, 27.87274033682687, 28.00738947732108, 26.083464554377965, 31.50580746786935, 52.27995892933437, 54.94234882082258, 77.64907918657575, 73.90652234213692, 91.80101026807512, 99.77876513344901, 126.592287336077, 183.53755514962333, 102.53907598767961, 122.07365145002092, 117.83222089494977, 121.49189267839704, 140.45916857038225, 133.84861074175154, 122.35763822283063, 126.24233436584473, 139.32142884390694, 159.69329697745187, 124.74056461879185, 128.8692398071289, 129.78144100734164, 92.72234140123639, 123.81931686401367, 118.41443824768066, 86.24123546055385, 71.64300073896135, 72.20059367588588, 59.436203956604004, 38.171950885227744, 31.876674515860422, 17.469251223972865, 23.374188218797954, 24.70164677074977, 44.9587984085083, 62.48180089678083, 82.3427401951381, 89.62963567461286, 94.65664345877511, 91.68733773912702, 100.39429909842355, 99.73089899335588, 66.33106122698102, 16.623985494886124, 1.731146284512111, 0.31409774135266033, 0.007660311763174832, 0.21247243881225586, 0.023569533035957387, 0.05320632943351354, 0.030923225850399052, 0.06691098279718842, 0.0431258164213172, 0.06574254549507584, 0.06714368638183389, 0.07433938062084572, 0.026675703502925377, 0.04042492813563772, 0.0020153374269804253, 0.029312743339687586, 0.0733344770435776, 0.08326453170073883, 0.017754152051306198, 0.0216489566290485, 0.048139087589723725, 0.038938023815197606, 0.01485569472424686, 0.06211078180266278, 0.02953447840575661, 0.052442858793905804, 0.04427481030247041, 0.058458078519574234, 0.038523605159882984, 0.03796250758958714, 0.07483690963791949, 0.02330783734630261, 0.020927677296900322, 0.01628198890414621, 0.08208626921155623, 0.06253009608813695, 0.017455162380688956, 0.041866601311734745, 0.02253462972917727, 0.02074707163098667, 0.11197576392441988, 0.01892221615915852, 0.03723357438242861, 0.006426708381955645, 0.01291461383724319, 0.04180562136960881, 0.015025418384798934, 0.05904058726238353, 0.06465636020792381, 0.03741221908213837, 0.012466257404802101, 0.07674423086323909, 0.0474553821342332, 0.025186439576957906, 0.04996604312743459, 0.03838638163038662, 0.12202036886342935, 0.11717737945062773, 0.02738757833971509, 0.08210395183414221, 0.04867943895182439, 0.06985877640545368, 0.08193895247365747, 0.01666683191433549, 0.05611623364633747, 0.04214658521647964, 0.031039153558335135, 0.059563228860497475, 0.010544379058826183, 0.07418132945895195, 0.1083864833095244, 0.03916876304096409, 0.05220060482887285, 0.08093333643461977, 0.04102774203888007, 0.06416655970471245, 0.041889345805559836, 0.008739230788445898, 0.02464786428026855, 0.053503578661807945, 0.02079410258946674, 0.04965783216591392, 0.005660983733832836, 0.05624130800632494, 0.13496715628675052, 0.07064131048641034, 0.011043031051355814, 0.02016210659140987, 0.07356237660029105, 0.048816767654248645, 0.08434041682630777, 0.03113037919891732, 0.021944499341771007, 0.05804754447724138, 0.028015850876857127, 0.016786031857399002, 0.05020077553178583, 0.03148588065856269, 0.017703696187319498, 0.03388246973710401, 0.01836412280265774, 0.037463679177952666, 0.02479237866854029, 0.04953011151935373, 0.029370462921048914, 0.018529970331915786, 0.06553414024944816, 0.05796671060046979, 0.03619958879426122, 0.014646526126723205, 0.0441416749464614, 0.10494672467133828, 0.10906661967081682, 0.10516159635569368, 0.9912067779472896, 4.272172425474439, 29.19127913883754, 66.40728991372245, 96.79422896248954, 99.22372218540737, 86.29279804229736, 79.85709857940674, 70.41749136788505, 81.130613054548, 92.16683987208775, 92.83553450448173, 72.48115498679024, 79.52931036267961, 45.6651349067688, 45.632127489362446, 51.89853061948504, 29.570869650159562, 28.736655030931743, 31.77575193132673, 40.92307274682181, 40.63648387363979, 44.561615058353965, 42.98448862348284, 66.06794684273856, 73.73579120635986, 86.54033456529889, 66.31176607949394, 55.37119511195591, 59.33141122545515, 55.126083510262625, 52.86483744212559, 65.22103786468506, 67.64203344072614, 66.88479791368756, 79.00850813729423, 73.89471735273088, 87.01902375902448, 67.74188600267682, 70.8965835571289, 59.938127926417756, 56.696782861437114, 65.77301665714809, 67.35627487727574, 54.377581868852886, 35.89735385349819, 32.53156655175345, 30.40750571659633, 38.350394521440776, 32.627750464848106, 42.75988462993077, 59.14750630514962, 78.89505795070103, 87.61625616891044, 108.33923762185233, 99.079970904759, 104.38927010127476, 105.67770235879081, 115.42510781969342, 117.6120741707938, 76.92555631910051, 19.894997630800518, 1.8899914409433092, 0.34546535675014767, 0.035575027843671184, 0.11288331129721232, 0.07285546524716274, 0.009282829788779574, 0.027422064882037894, 0.03563666257209011, 0.0443693471939436, 0.05307252911318626, 0.03760555745767696, 0.038472589504505904, 0.020624736856137003, 0.04329649172723293, 0.015332879565124, 0.01927373631458197, 0.052492544520646334, 0.0633339700954301, 0.020929563624252166, 0.059499609417149, 0.01650403270364872, 0.06484572576092822, 0.036460556755108495, 0.047977487689682415, 0.05111223126628569, 0.04440494992637208, 0.029530912704233612, 0.045830270408519676, 0.0053450535883062655, 0.054683968358274014, 0.04323493842301624, 0.025397921978895153, 0.018424108690981354, 0.03453499311581254, 0.021768578960161124, 0.07779826716120754, 0.059535503919635496, 0.03649792707126055, 0.05396015809050628, 0.04280039102637342, 0.017424302608040825, 0.026084273720958402, 0.01390333435431655, 0.03762934011008058, 0.016820223236988698, 0.03383009022633944, 0.04187389217051012, 0.02062746965592461, 0.0697315510894571, 0.023880056105554104, 0.020521843805909157, 0.06841778515705041, 0.0405779581383935, 0.028227547017325248, 0.026222934048356752, 0.016455222287082245, 0.08081122048731361, 0.007826813230557101, 0.027534900166626488, 0.009553402412815817, 0.011449290323071182, 0.07146733866206237, 0.1328504527253764, 0.1864535114062684, 0.26374759312186924, 0.12981721120221273, 0.13090957115803445, 0.16302573281739438, 0.14814339711197785, 0.30411133436220034, 0.34368154246892246, 0.19022509402462415, 0.0994016822161419, 0.24126884075147764, 0.10591199501816716, 0.2082189199115549, 0.11232962672199522, 0.10638764128088951, 0.16431041673890182, 0.15546568562941893, 0.07391319956098284, 0.27419689670205116, 0.17474439899836267, 0.09569161558257681, 0.25928171990173204, 0.25618784448930193, 0.12249366060963698, 0.12948836599077496, 0.15432311408221722, 0.09210747147777251, 0.12914577365985938, 0.14307830961687223, 0.12341882953686373, 0.11596888144101415, 0.08236720985067741, 0.07533440472824232, 0.10423179981963974, 0.14495828588094029, 0.13630411454609462, 0.16121683988187993, 0.13815871360046522, 0.17451076582074165, 0.1344112596873726, 0.17129801107304438, 0.17782129746462616, 0.15255658887326717, 0.14317751143659863, 0.19455907360783645, 0.11797881073185376, 0.1157267801463604, 0.07671885365354163, 0.23081820724265917, 0.2661011054047516, 0.43667636811733246, 9.185889397348676, 24.616329840251378, 62.268803868974956, 99.1154761995588, 108.37585462842668, 105.92875467027936, 91.63920756748745, 91.81290558406285, 81.80664498465401, 90.7907908303397, 89.99305425371442, 96.82826123918805, 59.05555384499686, 53.87215600694929, 41.286519118717735, 37.88436841964722, 42.781458786555696, 39.845813614981516, 44.247608593532014, 70.55532973153251, 81.29095663343156, 102.45680236816406, 104.61084815434047, 136.42443302699496, 141.70110348292758, 169.849492754255, 241.12166813441684, 140.85075514657157, 169.06656973702567, 166.0602648598807, 173.73977524893624, 188.03854261125838, 182.347717830113, 170.8512979234968, 182.19567734854562, 198.57832063947404, 222.4346408843994, 175.9917003086635, 186.93502971104212, 187.5074917929513, 134.54910033089774, 187.3348846435547, 180.30468341282435, 128.97072519574846, 103.9459958757673, 103.7820531300136, 87.18546785627092, 54.19174534933907, 43.64058269773211, 30.970869132450648, 39.43069349016462, 42.84764385223389, 66.88007313864571, 81.67944431304932, 105.57066535949707, 112.6527348927089, 117.10880225045341, 113.15651403154645, 123.90604427882603, 132.15262494768416, 95.6487489427839, 30.356943675449916, 3.929071681840079, 0.3748098521360329, 0.13107254169881344, 0.3212461349155222, 0.2204395527286189, 0.1317473854869604, 0.07918586448899337, 0.2641209773719311, 0.14525655630443776, 0.1812837395284857, 0.14150423050991126, 0.21043273540479795, 0.11502077803015709, 0.12214607426098414, 0.11496969791395323, 0.10443571316344397, 0.11850452609360218, 0.29245475413543837, 0.11664008828146116, 0.13888432537870748, 0.11178354852433715, 0.108879276152168, 0.09184116005365338, 0.15602572129241057, 0.12534748390316963, 0.13106021950287478, 0.08104710640119654, 0.11813515877085072, 0.0724200764670968, 0.09817379846104554, 0.12009902910462447, 0.09351328068545886, 0.12135517384324755, 0.11345106190336601, 0.1478200616048915, 0.21409345897180693, 0.11542582272418908, 0.18829755245574883, 0.18418154546192714, 0.09663243831268378, 0.2074730470776558, 0.10299778889332499, 0.12228471253599439, 0.10280632666711297, 0.1836593584822757, 0.1605709423976285, 0.08754620980471373, 0.23590133019856044, 0.17803392319806985, 0.14631716082138674, 0.11525799387267657, 0.17293855947043213, 0.14373450726270676, 0.14645997887211187, 0.11921196670404502, 0.19535950065723487, 0.15629235841333866, 0.20844886185867445, 0.14037292264401913, 0.11114677055073635, 0.1274054670440299, 0.09624677257878439], [0.05166016525721975, 0.025890434925843562, 0.0296682244432824, 0.05152483484042542, 0.05080313142389059, 0.04844384141532438, 0.06463977681206805, 0.043027296529284546, 0.052092222430344136, 0.010331249513131167, 0.05784303402262075, 0.055150481539645364, 0.08754070688571249, 0.01086679260645594, 0.06738608623189585, 0.05173966920535479, 0.08879459888807364, 0.03485126507335475, 0.014099246922082134, 0.09589964084859405, 0.02633689739741385, 0.04288319944004927, 0.03547512034752539, 0.0559640043149037, 0.04062345730406897, 0.006878952395969203, 0.01589509841453816, 0.03187032163675342, 0.047959978093526194, 0.016119057379130806, 0.040859624809984646, 0.06314087938517332, 0.0383862934208342, 0.01940965366416744, 0.08244816586375237, 0.014219336594188852, 0.09432461857795715, 0.09638150927743741, 0.027337870560586452, 0.012940543204812067, 0.028568943430270468, 0.07294917771858828, 0.02092337029586945, 0.022448949416034987, 0.007183355927866484, 0.10344663302281074, 0.021619793193946992, 0.06116396082299096, 0.3036033016230379, 3.6098230183124542, 6.982768050261906, 29.952033928462438, 60.31922272273472, 78.86827959333147, 65.27247537885393, 70.03857135772705, 72.26981857844761, 59.170553479875835, 66.2398522240775, 61.68438393729073, 59.651869092668804, 22.171899727412633, 25.73984486716134, 13.329135826655797, 23.36797479220799, 25.936852352959768, 59.44770322527204, 83.97376033238002, 80.12637601579938, 93.54616846357072, 105.75860718318394, 113.02716636657715, 60.46516963413784, 88.6209031513759, 40.42284413746425, 29.62083762032645, 16.645622185298375, 25.429859672273906, 29.90608549118042, 26.176410606929235, 31.377901554107666, 28.56599337714059, 25.43277965273176, 36.04484326498849, 19.91737083026341, 28.84236318724496, 18.551433154514857, 13.393558655466352, 20.72807100840977, 17.95701823915754, 13.713321702820913, 20.50893177304949, 18.74610778263637, 21.724321092878068, 28.76029975073678, 31.79090247835432, 55.63531698499407, 75.40048231397355, 90.24260575430733, 115.32177421024868, 112.64211804526192, 98.64727183750698, 61.31275258745466, 37.25930152620588, 24.489099638802664, 21.896327223096574, 18.751886946814402, 40.14014278139387, 54.790999685014995, 71.1442243031093, 91.30394308907645, 75.6022093636649, 83.84400272369385, 84.21243095397949, 75.9488410949707, 37.98944255283901, 12.052923713411603, 4.924248269626072, 4.074840545654297, 0.5975286311336926, 0.1857450394225972, 0.12195554162774767, 0.01961469846511526, 0.0748240039018648, 0.09696470334061555, 0.04362132679671049, 0.025296170563836182, 0.11309579453830208, 0.03918942443228193, 0.06220914902431624, 0.08485195080616645, 0.02259942134177046, 0.04140445789588349, 0.04341941173853619, 0.02957134321331978, 0.007250158548621195, 0.03409429140655058, 0.043788765490587266, 0.024178628477134874, 0.05972590084586825, 0.03411713768062847, 0.04616343110267605, 0.026490195421501994, 0.05827139996524368, 0.02324840785669429, 0.03879900895325201, 0.12687554476516588, 0.013287759751879742, 0.07592966992940221, 0.03410348555605326, 0.03427625074982643, 0.027830276638269424, 0.0281869316074465, 0.038455758443368335, 0.013663705471636993, 0.05318663834727236, 0.03535516553425363, 0.04968277172052434, 0.016762011717738848, 0.05319231768537845, 0.04133856196754745, 0.04256750423727291, 0.010454976981106614, 0.03561577387154102, 0.09214210390512433, 0.04723010850804193, 0.05727423847253833, 0.017661856021732092, 0.025050381431356072, 0.02352393717904176, 0.03607764248070972, 0.06560100987553596, 0.03162256475271923, 0.06980049703270197, 0.035102119469749074, 0.03499232232570648, 0.0028268943590644214, 0.052743056256856234, 0.04672862023913434, 0.04188224154391459, 0.05157280048089368, 0.016865990423996533, 0.05818377395293542, 0.020400452194735408, 0.030917278490960598, 0.026481650969279662, 0.03503164682271225, 0.006700021015214068, 0.02612311645810093, 0.02773682540282607, 0.0832427100145391, 0.036946238550756655, 0.10873231225247894, 0.01754471712878772, 0.032858987871025286, 0.030311458677585636, 0.008839878735930791, 0.05527212929778865, 0.044737761174993854, 0.02737423325223582, 0.03740744898095727, 0.014908104769087263, 0.05529055491622005, 0.018962848532412733, 0.0234101315893765, 0.058649791803743155, 0.0358342180427696, 0.053186054807156324, 0.07901130457009588, 0.025229626634557332, 0.04031953129119106, 0.05836924471493278, 0.014782552041911652, 0.0498433945301388, 0.0313026863815529, 0.012903814104252627, 0.13535921382052557, 0.02509855741768011, 0.006006148560637874, 0.05019766105605023, 0.042146931269339154, 0.009003364115155168, 0.05552449343459947, 0.04686789294438703, 0.14259247854351997, 0.62702747966562, 2.612777365105493, 17.47443458012172, 56.490584645952495, 77.28151948111397, 75.70582784925188, 82.99870572771344, 83.5556663785662, 70.60677419389997, 79.82295513153076, 88.01420729500907, 77.86646747589111, 49.4148588180542, 52.94191380909511, 42.88351045336042, 28.420951468603953, 23.73168519565037, 55.8638710294451, 33.73670033046177, 38.847565923418315, 53.946567739759175, 64.25247982570103, 67.46994045802525, 55.72055401120867, 65.91669150761196, 41.52817051751273, 34.906915937151226, 22.167593581335886, 27.57083589690072, 35.28591585159302, 28.297876289912633, 30.150585651397705, 29.404373441423687, 27.498975890023367, 31.7866119657244, 21.632201875959122, 23.84511627469744, 19.505165474755422, 15.654887233461652, 19.197839702878678, 16.393008266176494, 18.186838592801774, 25.461218629564556, 23.345627648489817, 27.20055944578988, 34.341586181095664, 31.54967839377267, 43.19714866365705, 58.43929031917027, 64.74449566432408, 78.55281053270612, 75.6607687813895, 58.629184586661204, 36.77144071034023, 20.11980312211173, 23.507176739828928, 41.69112661906651, 48.21929618290493, 71.58623395647321, 91.04390675680978, 88.85613441467285, 107.30884756360734, 85.35550689697266, 100.47457163674491, 100.16120788029262, 85.26156725202287, 41.55314929144723, 13.104850581714086, 4.214019043104989, 3.1242268809250424, 0.5245660862752369, 0.14215419920427458, 0.09486486137445484, 0.08242932973163468, 0.06784814822354487, 0.06795904120164258, 0.043459248529481034, 0.13997610179441317, 0.08196057738470179, 0.06350226713610546, 0.026895691341321384, 0.010418211409289922, 0.046508381342781444, 0.03090293426066637, 0.02374870190396905, 0.03740389685013464, 0.03926225159583347, 0.02461186290851661, 0.010451833667632724, 0.04876064941553133, 0.04809512869854059, 0.033646892556654553, 0.04124666118462171, 0.046366784655089886, 0.04255462224994387, 0.02502831886522472, 0.06638242437371186, 0.07214510015078954, 0.017529745253601244, 0.021740158520905033, 0.009992285648227801, 0.029358313751540015, 0.01546579778992704, 0.0027474917670977967, 0.015271863999909588, 0.013302271919591086, 0.04040458904845374, 0.04635325466681804, 0.04542497804920588, 0.0718928004748055, 0.07018625776150397, 0.022055283754265735, 0.024087158563945974, 0.003567148498924715, 0.014732191172827567, 0.06982246121125561, 0.030003393601093973, 0.035618749247597795, 0.05558525285284434, 0.04291808971070817, 0.046630768704095056, 0.044195842397000105, 0.06992569352899279, 0.0717325508594513, 0.005770579013707382, 0.025925501615607312, 0.0648669231949108, 0.15082937798329762, 0.16743971167930535, 0.12163946644536086, 0.11346176240061011, 0.22407150641083717, 0.17653961266790116, 0.1815350010458912, 0.10674465248095137, 0.12637759505638055, 0.11537934307541166, 0.14095274438815458, 0.12863919298563684, 0.2758532821067742, 0.08224332292697259, 0.25514254772237366, 0.11331395711749792, 0.22555354902786867, 0.20190477158342088, 0.13768996803888253, 0.1377613227814436, 0.14971644484571048, 0.19325304297464235, 0.11720521295709269, 0.10780076509607689, 0.16921524783330305, 0.1122691421104329, 0.16256252410156385, 0.062020448435630114, 0.24066548741289548, 0.10309353018445627, 0.2614521091537816, 0.17832544898348196, 0.23671899203743252, 0.08803039882332087, 0.1698094680905342, 0.2327339830143111, 0.1704533706818308, 0.18449812276022776, 0.16436391243977205, 0.09790669315095459, 0.25871221188988003, 0.1462901279862438, 0.14778864543352807, 0.2288233142878328, 0.11355680480067219, 0.213895123185856, 0.19582825978951796, 0.13125194635774406, 0.32591478154063225, 8.298057266644069, 15.656646864754812, 50.821125575474326, 91.28285530635289, 106.52689729418073, 90.45155198233468, 88.78704847608293, 93.60491548265729, 79.38585785457066, 85.08540262494768, 82.40828255244664, 78.13552256992885, 35.08198274884905, 37.61159256526402, 21.576208080564225, 35.79398897715977, 35.941408906664165, 77.53093896593366, 108.01500688280377, 107.82921205248151, 127.59834480285645, 150.45946066720145, 161.33640698024203, 88.79609503064836, 126.65290342058454, 62.6015739440918, 46.988183089665, 26.98327190535409, 42.32833201544625, 46.50145483016968, 41.97948728288923, 48.96545280729021, 44.134151458740234, 39.69153928756714, 61.306367192949565, 31.669906548091344, 44.241136346544536, 30.574985095432826, 22.21590093203953, 34.07803406034197, 30.002811363765172, 24.25492102759225, 33.276705265045166, 28.802662917545863, 34.102724484034944, 44.4062568119594, 48.09551402500698, 80.73741449628557, 109.69808292388916, 126.49062129429409, 157.27255848475863, 154.5923464638846, 133.97434534345354, 88.97093255179269, 54.649972098214285, 38.982847349984304, 40.069503920418875, 34.06468309674944, 59.48638384682791, 75.12602846963065, 94.3819533756801, 115.18989045279366, 93.9111225945609, 104.8165843146188, 112.71287849971226, 105.42903327941895, 57.95681088311331, 20.85825593130929, 9.372639604977199, 6.986177444458008, 1.5675938321011407, 0.2743457944265434, 0.2914785322334085, 0.13206476345658302, 0.2307154227580343, 0.1930533636893545, 0.2169986337955509, 0.17502141770507607, 0.1502400024660996, 0.21161367132195405, 0.10862150748393365, 0.09210255888423749, 0.12251065112650394, 0.18086992816201278, 0.13161486759781837, 0.0705487108124154, 0.2017220692442996, 0.10940915093358074, 0.16514561192265578, 0.10321352231715407, 0.1629610141473157, 0.2667312201644693, 0.11924866187785353, 0.1476853181208883, 0.1730652962412153, 0.14873419755271503, 0.1821770987340382, 0.20253925610865864, 0.1060450082378728, 0.1028182553127408, 0.10144094457583767, 0.08131977569844041, 0.12916237062641553, 0.1494971966104848, 0.12194254089679037, 0.10869612597993442, 0.13926838976996286, 0.15534633131963865, 0.1227134381021772, 0.12437502108514309, 0.21986807696521282, 0.15953555224197252, 0.13257852303130285, 0.1176010567162718, 0.12948888167738914, 0.23522569930979184, 0.1621203635420118, 0.22145271407706396, 0.12062538228929043, 0.1233808451465198, 0.11645028846604483, 0.15428579465619155, 0.12980278554771627, 0.12050788716546126, 0.25247462945325033, 0.17383068374225072, 0.22213181906512805], [0.044004841574600766, 0.007910141571690994, 0.0463982551092548, 0.042992867662438324, 0.04818223563155957, 0.02854252466931939, 0.014539572044408746, 0.042671588116458485, 0.01940263930841216, 0.04038969520479441, 0.07163479431931462, 0.020481606679303304, 0.016480353527835438, 0.017575841530093124, 0.08113201148808002, 0.03860675284106817, 0.075696029966431, 0.05692311017108815, 0.061701408055211814, 0.008544653238329505, 0.02231804304756224, 0.04081218842683094, 0.035096026225281615, 0.038593704612659555, 0.010770756152591534, 0.07220553726490055, 0.05721001513302326, 0.0343834016072963, 0.024600136127056818, 0.06175597584141152, 0.011989680700935423, 0.028561259021184275, 0.08523889218590089, 0.054021799604275396, 0.01286580935785813, 0.05297888110258749, 0.02394669672607311, 0.0011651360172046615, 0.054676192346960306, 0.07839786820113659, 0.061722836191100736, 0.020624599452795725, 0.04599899831893189, 0.066277020743915, 0.10634224050279174, 0.10208739845880441, 0.9041446553809303, 4.736005067825317, 20.62060843195234, 44.15545810971941, 64.09766006469727, 78.04412596566337, 82.0380825315203, 75.80114323752267, 70.34663363865444, 66.87567492893764, 76.13986097063336, 43.39029816218785, 20.509817668369838, 28.79896821294512, 16.248506580080303, 29.73438855579921, 25.44144058227539, 42.24100010735648, 72.64157499585832, 81.58722087315151, 74.74820627485002, 70.09543541499546, 56.10634926387242, 23.572086811065674, 5.533494983400617, 1.1314043807131904, 0.6739024158035005, 0.7055207363196782, 1.002412919487272, 0.4355900064110756, 0.2523780603493963, 0.42686035484075546, 1.0034797936677933, 0.5911987679345267, 0.7459672316908836, 0.6605736538767815, 0.74185661226511, 1.1306705858026231, 0.7056591031806809, 0.6737997127430779, 0.5242784417101315, 0.29647702830178396, 0.6228040062955448, 0.5335355049797467, 0.5009124098079545, 0.46226946051631657, 0.5552819009338106, 0.7435200001512254, 0.8851960492985589, 0.5139917965446199, 0.722001103418214, 0.987383531672614, 0.6412062016980988, 3.561770362513406, 16.722693341118948, 42.41368021283831, 78.23909936632428, 120.3007629939488, 107.9453511919294, 71.20527117592948, 43.85808910642351, 17.383916922977992, 18.996519122804912, 36.4504200390407, 40.48448508126395, 77.7865423474993, 77.67466245378766, 77.9190444946289, 84.14495699746269, 88.83363614763532, 92.01109600067139, 78.08669063023159, 82.03018242972237, 47.873508657727925, 26.59282830783299, 6.774552685873849, 0.2833169230393001, 0.04148968528690083, 0.07298292126506567, 0.07346225875828948, 0.012837493243361158, 0.025035424823207513, 0.05577871336468628, 0.03657866595312953, 0.03723371348210743, 0.06807233619370631, 0.05114013262625251, 0.02334161481953093, 0.04379921153719936, 0.054773541766085794, 0.0285245977741267, 0.027019751291455965, 0.07078867472176041, 0.04754971885787589, 0.02894044474565557, 0.0415750449922468, 0.04728789594290512, 0.036282756831496954, 0.0457008364610374, 0.0465057927316853, 0.03153479624805706, 0.05067122760894043, 0.015344648755022457, 0.03478401546765651, 0.03357475749882204, 0.04282433991985662, 0.014196461482372667, 0.030735865368374755, 0.05450383088152323, 0.0326493341209633, 0.0470570685075862, 0.03288118275148528, 0.04649823045890246, 0.06598564423620701, 0.010437262976276023, 0.00582036143168807, 0.0061865790796998355, 0.02739474706218711, 0.007521339309667903, 0.02323692025882857, 0.02021955475876374, 0.061008596659771035, 0.0801020021151219, 0.014786835294216871, 0.008653414768299885, 0.029508137676332678, 0.018972500693053007, 0.017447796883061528, 0.034717702240284, 0.03607397160625883, 0.04813237687838929, 0.0390454596573753, 0.03640903898381761, 0.019813778943249157, 0.046058553337518654, 0.09695319538669926, 0.011215451040438243, 0.024758937070146203, 0.003928661778835314, 0.009723003088895763, 0.06084360408463648, 0.03814047036160316, 0.02031915691415114, 0.04561439109966159, 0.01956092456488737, 0.032181697964136086, 0.014888703756566559, 0.027824235980265906, 0.04675458777429802, 0.041888202474053414, 0.007752008137426206, 0.0075616408971005255, 0.060290109499224594, 0.05550491091396127, 0.03396298470241683, 0.07472057480897222, 0.07175313761191708, 0.02080790908075869, 0.104294828937522, 0.048656423043991835, 0.02955733485785978, 0.0492523498167949, 0.055487628627036295, 0.0490564092594598, 0.08517393602856568, 0.024114995463086025, 0.03967909262116466, 0.016626660944893956, 0.007722121214361063, 0.08590550534427166, 0.03132724256387778, 0.0195788565490927, 0.047370480440024815, 0.08819227692271982, 0.09439225494861603, 0.08204603208495037, 0.4435575817312513, 0.322085401309388, 7.774275132587977, 36.69956854411534, 54.60920006888253, 85.59364250728062, 91.75950867789132, 87.87120641980852, 78.19604137965611, 74.17836366380963, 81.92976706368583, 52.977116857256206, 41.02971369879586, 40.14666019167219, 28.746729918888636, 26.49616323198591, 25.578014373779297, 16.191899606159755, 45.08141326904297, 40.41814715521676, 58.18680667877197, 78.12714999062675, 58.79113319941929, 28.300289051873342, 9.474175368036542, 1.8958466010434287, 0.5665357570563043, 0.33807963877916336, 0.5410371710147176, 0.5850494493331228, 0.49339538174016134, 0.6011126531021935, 1.604390514748437, 0.8229203224182129, 0.9668753807033811, 0.6469469879354749, 1.1218019702604838, 1.205011968101774, 1.0760429799556732, 0.5703021149550165, 0.7437300203101975, 0.30920151408229557, 0.6402525614414896, 0.6093687415122986, 0.954945540853909, 0.6308847069740295, 0.6144977605768612, 1.2237087019852229, 1.1273864763123649, 0.5824202075600624, 0.3873756692877838, 0.08827560102300984, 0.3810247172202383, 5.059901859079089, 18.317768710000173, 42.21638263974871, 64.98024109431675, 80.32291970934186, 68.58845451899937, 45.21767439161028, 20.179255383355276, 25.16372629574367, 31.16731902531215, 60.251748766217915, 66.85245404924665, 93.21586499895368, 90.48461845942906, 84.55994510650635, 98.73604202270508, 103.00917720794678, 103.95257581983293, 86.89567238943917, 90.63272626059396, 49.47402620315552, 26.442316429955618, 6.248577092375074, 0.2015069600726877, 0.03893012906025563, 0.014148660386646432, 0.02972973364272288, 0.09123756922781467, 0.012627800477535596, 0.03796859744137951, 0.09902552275785378, 0.050562431304050345, 0.012555494937779648, 0.010933262745051511, 0.02267910510168544, 0.07856216188520193, 0.05206931508811457, 0.015468696830794215, 0.04966832910265241, 0.031212498899549246, 0.009438951366714068, 0.03636209114587732, 0.07565480217869792, 0.03535941994882055, 0.05591381647224937, 0.07959521109504358, 0.012923455996704953, 0.012627616424911788, 0.0685240640970213, 0.03450262699542301, 0.010507614335178264, 0.031227307926331247, 0.07749488736901965, 0.004376052147043603, 0.01784328950036849, 0.03701455684910927, 0.031840995353247435, 0.024738569145223925, 0.008322359229038869, 0.04676868773198553, 0.05237527331337333, 0.006594352332675564, 0.022565676098955528, 0.013921159469256443, 0.01795692036726645, 0.02889167843386531, 0.06996144553912537, 0.04630045107166682, 0.0891124586175595, 0.030140891937272887, 0.05968859499054296, 0.018635180579232316, 0.05233300397438662, 0.03565783625734704, 0.0707857638065304, 0.029103937758398906, 0.04366124840453267, 0.17541682720184326, 0.1091461575457028, 0.10464086822633233, 0.07622669863381556, 0.1607366542198828, 0.16409703104623727, 0.0689698683896235, 0.11958148330450058, 0.10624253656715155, 0.08712545702500002, 0.17524342079247746, 0.12428803289575235, 0.17894013385687554, 0.12272153981029987, 0.21401663523699554, 0.14230506468032086, 0.11559578217566013, 0.18264032102056912, 0.10490437730082444, 0.1083628838615758, 0.09362479113042355, 0.11114575953355857, 0.23454293023262704, 0.12582059923027242, 0.13952589380953992, 0.15906749878610882, 0.11842055059969425, 0.1294085295604808, 0.18446703228567327, 0.14442426525056362, 0.09693526849150658, 0.12179289678377764, 0.19325518714530127, 0.15882406756281853, 0.10484736678855759, 0.08744016835199935, 0.09183648494737488, 0.08042153104075364, 0.12481876941663878, 0.15785288039062703, 0.12233252211340837, 0.11666136713964598, 0.1484833974391222, 0.25417354543294224, 0.208617274250303, 0.14239224285951682, 2.0661163330078125, 10.610726084027972, 37.232325145176475, 67.40861565726144, 95.79172202519008, 102.66519968850272, 101.11768300192696, 95.14327444349016, 91.3617034639631, 86.32947063446045, 95.21531336648124, 61.92163017817906, 35.14628485270909, 41.26157855987549, 30.088037967681885, 41.35190166745867, 39.78416919708252, 61.993571826389854, 101.62069089072091, 127.0334701538086, 109.64838245936802, 103.67801775251115, 83.06869493212018, 36.711307525634766, 10.00237568787166, 1.4359574956553323, 1.1235751722540175, 0.6612053428377423, 1.5007009186914988, 0.6073637519563947, 0.45169929627861294, 0.6214122495480946, 1.3590564621346337, 1.2332546583243778, 1.064388245344162, 0.8679299386484283, 1.1234458706208637, 2.137452619416373, 1.1640684051173074, 1.0985399442059653, 0.900401693369661, 0.38126410437481745, 0.8474973493388721, 0.8487554075462478, 0.8257829802376884, 0.76834173394101, 0.7162899555904525, 1.0502862249101912, 0.9853708339588982, 0.8018002414277622, 0.769715143101556, 1.1168218489204134, 0.9000736081174442, 6.654473917824881, 26.805675949369157, 66.60649476732526, 114.84070178440639, 164.9807232448033, 139.26659366062708, 93.52179418291364, 64.33611529214042, 30.43945700781686, 30.343870639801025, 49.4366066796439, 56.26881899152483, 104.82415785108293, 99.87387207576207, 98.14074121202741, 102.89787401471818, 113.13245936802456, 118.0837595803397, 104.84919221060616, 107.55131190163749, 73.7848732812064, 44.12611239297049, 16.226112536021642, 0.5588210853082793, 0.10312290396541357, 0.12106956488319806, 0.09879976737179927, 0.20974566441561493, 0.15346978844276496, 0.1201708045388971, 0.24179351116929734, 0.15714101573186262, 0.1669356958674533, 0.1051232794831906, 0.14221530806805405, 0.16331713646650314, 0.10489668949906315, 0.11941144242882729, 0.09471960059766259, 0.12961443779723986, 0.1883568971284798, 0.06778083076434475, 0.13814586214721203, 0.15158038054193768, 0.18271174361663206, 0.18549128089632305, 0.12775346051369393, 0.12371787349028246, 0.1862836198082992, 0.10825047775038651, 0.14764882650758537, 0.12625619157084397, 0.16548629078481877, 0.10030168427952699, 0.18684134845222744, 0.099219502348985, 0.10692056946988616, 0.08376290888658591, 0.08462820388376713, 0.11484268972916262, 0.13328595007104532, 0.10562226735055447, 0.056993481037872176, 0.10770023334771395, 0.0995999365778906, 0.18695877572255476, 0.1123337997123599, 0.16479083310280526, 0.14680680526154383, 0.19925616442092828, 0.11199664923229388, 0.11915255417781216, 0.14750933327845164, 0.1454165277204343, 0.14679225747074398, 0.10997898464224168, 0.17679314049226896], [0.048874198858227046, 0.02346612260277782, 0.0205113807959216, 0.01618154197266059, 0.01738862014774765, 0.08493579059307065, 0.026381826593673656, 0.113628987355956, 0.016218162507617047, 0.025722994535629238, 0.005741863411718181, 0.03819342662713357, 0.03387465301368918, 0.0359296031030161, 0.04106526841808643, 0.044484874566218684, 0.05092391065721001, 0.005372495240797954, 0.03254031050684197, 0.045466986152210405, 0.011734862811863422, 0.07667290326207876, 0.021312769668708955, 0.06619058895323958, 0.015945815514507036, 0.05181761930829712, 0.024257006057138954, 0.021386200728427087, 0.018038578664085696, 0.02604854545955147, 0.04511977978316801, 0.08031968971980469, 0.06715213414281607, 0.04379704701048987, 0.0725876067632011, 0.00949302127784384, 0.034940991151545725, 0.05132115898387773, 0.05006561474874616, 0.029547482529389005, 0.046801287946956496, 0.025863705735121454, 0.09963279802884374, 0.06188426645738738, 1.031609684228897, 21.133117982319423, 43.37280607223511, 58.905604771205354, 79.07318196977887, 85.58627741677421, 81.74767562321254, 76.7643928527832, 69.27878584180559, 55.04814904076712, 58.13079030173165, 46.14387968608311, 29.233013493674143, 15.534798043114797, 25.887763329914637, 111.96084717341832, 56.49336392538888, 56.19880199432373, 91.0340542112078, 112.90817151750836, 79.32976504734584, 39.849336351667134, 26.01819143976484, 2.2217761746474674, 0.1367122262184109, 0.3075367962675435, 0.11397390706198555, 0.09201312118342944, 0.2942037731409073, 0.3302024171820709, 0.35577930616480963, 0.18142517336777278, 0.09436589386314154, 0.13810919411480427, 0.3608610991920744, 0.30846272515399115, 0.23697754102093832, 0.25929803188358036, 0.3283384543444429, 0.27827513643673485, 0.30375393639717785, 0.32217293232679367, 0.2604852510350091, 0.10110825207084417, 0.24978543232594216, 0.11522161082497664, 0.15435040476066725, 0.32083724971328464, 0.22286964447370597, 0.24210864997335843, 0.3543928691319057, 0.1283548189593213, 0.40976159806762424, 0.6305292631898607, 0.12517728017909185, 0.3492800806249891, 0.8028572904212135, 0.4833352587052754, 0.8137864811079842, 9.492163385663714, 30.178156103406632, 83.30925546373639, 112.63833127702985, 98.91042096274239, 68.7094921384539, 35.29999985013689, 32.785644803728374, 25.598825965608867, 33.78551489966256, 63.087211336408345, 70.51031930106026, 73.9750246320452, 72.58966500418526, 75.23225947788784, 82.43596417563302, 87.78242928641183, 77.37861360822404, 59.817715644836426, 30.238702705928258, 1.6059850177594592, 0.05813196101891143, 0.06028816210372107, 0.019165638900761093, 0.035220747747059376, 0.03455451117562396, 0.06885282109890666, 0.005536674846163285, 0.06275553934808288, 0.038199760751532655, 0.03153323901018926, 0.05934037760432277, 0.01835985990640308, 0.003925607947167009, 0.01241176510562322, 0.04785663042483585, 0.021431011181058626, 0.03505656262859702, 0.036715482361614704, 0.02610340671214674, 0.021575026846091663, 0.037552272102662494, 0.035130031007741175, 0.03401935739176614, 0.09246658613639218, 0.08036989452583448, 0.06413585599511862, 0.06528680744980063, 0.016819529434932128, 0.03353503605883036, 0.013168500437002097, 0.06934285230402436, 0.10891164227255754, 0.03120281620483313, 0.0174046607155885, 0.005207020481715777, 0.026094986092565314, 0.07225710592631783, 0.09952063619026116, 0.03692169933180724, 0.05552700401416846, 0.025985300906800797, 0.026762489828148057, 0.03876637481153011, 0.036313307870711596, 0.082033065280744, 0.01596238025064979, 0.08690903149545193, 0.028131549579224417, 0.03758535747017179, 0.03242186882666179, 0.020391829710985934, 0.04672712067674313, 0.016096116110150303, 0.0539560325975929, 0.014567624378417219, 0.0847632119964276, 0.02829076273233763, 0.09506380784192256, 0.06737976907087223, 0.053407681307622364, 0.02380341218252267, 0.022967714882854904, 0.0356848148096885, 0.006349373625458351, 0.04443413371752415, 0.02058172961031752, 0.03012119745835662, 0.05992081681532519, 0.038269263093492815, 0.059434056148997376, 0.01778758516801255, 0.046485409539725096, 0.04360265351299729, 0.02453371263774378, 0.0624112371089203, 0.01954520121216774, 0.020695541985332966, 0.03820523992180824, 0.06608854407178504, 0.026075050733717423, 0.038915513415953944, 0.028498375788331032, 0.027595065866730044, 0.062372397764452865, 0.04773668578958937, 0.01929857239260205, 0.026238201086276343, 0.005535735499246844, 0.025272946006485393, 0.008294557952987296, 0.0850242172767009, 0.027546591324997798, 0.013750462959121381, 0.07443477585911751, 0.113583104817995, 0.08932625143123524, 0.7051842915160316, 4.868059056145804, 23.025701318468364, 45.90415988649641, 75.76287950788225, 90.34932313646588, 94.04341629573277, 84.28988252367292, 78.38959734780448, 66.05382115500313, 70.67604773385185, 69.42387812478202, 54.97847945349557, 28.797158207212174, 14.872370685849871, 80.02641923086983, 35.689161505017964, 37.48089000156948, 37.95290892464774, 67.16724913460868, 71.32436329977853, 40.55219875063215, 26.10312100819179, 2.7638034096785953, 0.19242778154356138, 0.2366213644189494, 0.1861145831644535, 0.12450040078588895, 0.042743614608688016, 0.0916285886030112, 0.0805858111541186, 0.1484236592160804, 0.10046521800437144, 0.13845725543797016, 0.5724708214402199, 0.41407550658498493, 0.08856627185429845, 0.13606837790991577, 0.3407503254711628, 0.8176547278250966, 0.8459870389529637, 0.6166152240974563, 0.5200726645333427, 0.404761582080807, 0.09425614760922534, 0.03854569486741509, 0.1933801732957363, 0.18950852033283028, 0.22031330450304917, 0.2338965849152633, 0.31678243300744463, 0.04929859537099089, 0.15254639727728708, 0.14795021819216864, 0.07313459419778415, 0.38142016742910656, 0.9212655595370701, 0.7763216314571244, 0.5622677175062043, 8.17106590952192, 30.11685562133789, 64.21871852874756, 84.3314049584525, 60.771877016339985, 35.979714325496126, 26.410752500806534, 36.28043236051287, 50.413985456739155, 56.90442630222866, 92.81623240879604, 84.0638506753104, 89.90605585915702, 82.50764874049595, 87.52891731262207, 91.06546006883893, 98.69312300000871, 87.56964765276227, 66.33012322017125, 29.675881249564036, 0.8383161734257425, 0.011739228336539651, 0.057654625203992636, 0.05043291932504092, 0.06128196484808411, 0.04436053641672645, 0.028667324222624302, 0.028483325881617408, 0.03617186724607434, 0.012974911851675382, 0.026513294449874332, 0.08759501004325491, 0.061189107330782075, 0.02241695479356817, 0.04282136454379984, 0.0848203446449978, 0.01773408946714231, 0.0287645175786955, 0.03402420552447438, 0.06022498370813472, 0.017859781293996742, 0.05415462961952601, 0.045713497924485376, 0.019429263326206377, 0.1408154631831816, 0.03424773870834282, 0.0628800844507558, 0.05076736245038254, 0.0420550847692149, 0.023650156566873193, 0.041103649751416275, 0.04778124179158892, 0.05135741310992411, 0.015472913925935115, 0.0377799375647945, 0.00751016044523567, 0.006996158294246665, 0.050887096739773235, 0.058359297391559393, 0.009197338617273738, 0.025857139212478484, 0.0470608852670661, 0.054753097505973916, 0.03090220483552132, 0.026809045812115073, 0.04777840551521097, 0.03938340402341314, 0.02984270633065275, 0.07925295124628715, 0.04553984045716269, 0.046259664331695864, 0.021583332114719918, 0.010449458795067455, 0.12326933470155511, 0.1479484811425209, 0.1519532219639846, 0.1333568026976926, 0.06732560162033353, 0.1669977003974574, 0.090158637480012, 0.18758019166333334, 0.06771639707897391, 0.16736566993807042, 0.113924184015819, 0.19424385337957314, 0.12007466969745499, 0.10885797693793263, 0.11342236665742737, 0.19096051741923603, 0.18774647345500334, 0.16535773554018565, 0.18747972776847227, 0.17877740758870328, 0.17970075804208005, 0.16899062560072967, 0.1771965567022562, 0.15371843081499847, 0.10032972813184772, 0.13068789376744203, 0.11655225870864731, 0.13421856931277684, 0.12334461137652397, 0.1040290535560676, 0.15779790548341616, 0.1441033724695444, 0.1855140118194478, 0.12216781452298164, 0.17983323521912098, 0.08333634784711258, 0.078058987456773, 0.24237702414393425, 0.1552520828055484, 0.11831099433558327, 0.1754230290119137, 0.12408390242074217, 0.20328470825084619, 0.31366546026297976, 3.1796965215887343, 33.97820234298706, 63.41985634395054, 81.36300250462124, 103.07329518454415, 109.19658974238804, 97.96971825190953, 95.63796533857072, 91.10086114065987, 77.55855110713414, 78.6748834337507, 69.10912472861153, 46.33230788367135, 30.537732328687394, 41.87197085789272, 127.90913772583008, 75.18754087175641, 84.16198703220913, 127.39041301182338, 160.45338821411133, 110.34870529174805, 55.643706934792654, 42.626368045806885, 3.4853286700589314, 0.34268567019275253, 0.498885272869042, 0.1769551746547222, 0.2003871737314122, 0.33338721628699985, 0.3436694916869913, 0.5722386538982391, 0.32103739040238516, 0.346647066197225, 0.3932244511587279, 0.9026015039001192, 0.88945030101708, 0.8226228526660374, 0.5902553871273994, 1.1128022074699402, 1.1038002733673369, 0.9924589736121041, 0.6351115458777973, 0.5936634785362652, 0.41223545532141415, 0.5290212386420795, 0.39198873032416615, 0.774764746427536, 0.89824107502188, 0.4443969024079186, 0.3543259655790669, 0.46254521714789526, 0.20565055630036763, 0.6094628136072839, 0.6894288712314197, 0.151576607887234, 0.41020270011254717, 1.1588644215038844, 1.0049668167318617, 1.4637238000120436, 13.77760122503553, 46.3609379359654, 121.49582535879952, 159.41766193934848, 127.34085845947266, 92.9396949495588, 52.136971950531006, 49.47178193501064, 39.905383995601106, 47.393975257873535, 87.02591637202671, 93.98091724940709, 94.93381404876709, 90.62183843340192, 94.88521834782192, 98.12542738233293, 106.49194090706962, 98.95172105516706, 87.70171901157924, 46.157088211604524, 3.540903402226312, 0.11519757711461612, 0.1252064843262945, 0.16255689226090908, 0.19103309352483067, 0.09403811395168304, 0.14191230147012643, 0.14621213717120035, 0.1872983282165868, 0.13898955258939946, 0.14777660822229727, 0.20753556729427405, 0.1606249673558133, 0.18271687334137304, 0.24034074055297033, 0.13387493203793252, 0.1693801318428346, 0.08092785387166909, 0.18739339097269944, 0.16429296481822217, 0.10621191428175994, 0.14632885876510823, 0.11834861231701714, 0.11860030809683458, 0.1991352223392044, 0.13868057488330773, 0.13987475580402783, 0.33122032827564646, 0.13261648028024606, 0.142261624868427, 0.0951401430315205, 0.09099665536944355, 0.22904364817908832, 0.11465588903852872, 0.181861118546554, 0.12477613027606692, 0.09452973971409456, 0.1699018981307745, 0.19415823583092007, 0.1396824318383421, 0.19474915840796062, 0.08810916316828557, 0.10583312889294964, 0.10554228842790637, 0.13638214607323917, 0.17194464137511595, 0.08940141275525093, 0.23435551886047634, 0.13396508220051015, 0.18908964709511825, 0.07730347264025893, 0.09703341858195406, 0.09095645216958863], [0.035334789127643616, 0.025852053592513715, 0.04700689762830734, 0.02441542871695544, 0.014103335095569491, 0.028622998922531093, 0.05110527628234454, 0.03655901557898947, 0.03643594289730702, 0.05458099049116884, 0.030502496819411005, 0.02438728478071945, 0.036577346202518256, 0.04940727632492781, 0.009778122184798121, 0.040070634468325546, 0.10595980459558112, 0.06793405075690576, 0.08454464908157076, 0.06053650592054639, 0.01447060065610068, 0.03747284279337951, 0.025815334669979553, 0.031868401382650645, 0.06343853912715401, 0.0651197928403105, 0.016720185122851814, 0.10922139350857053, 0.018495331119213785, 0.06640782872481005, 0.08143000371221985, 0.038725482898631265, 0.04506781078608973, 0.02751722602572824, 0.0270046233532152, 0.05898045548903091, 0.030810036031263213, 0.07576091827026435, 0.04851438530853816, 0.0201321441813239, 0.10204169233994824, 0.053119850145386796, 0.3268013011131968, 6.8542854360171726, 40.98137855529785, 75.76570047651018, 79.31971795218331, 85.43432031358991, 77.69173417772565, 75.48372173309326, 63.32452705928257, 58.354994773864746, 52.822095598493306, 33.83645214353289, 22.12289408275059, 13.630749310765948, 10.883220536368233, 21.95801854133606, 59.44372190747942, 48.67225619724819, 59.73811708177839, 72.1330988747733, 64.9193331854684, 22.193288019725255, 4.456882468291691, 1.0850768323455537, 0.32991553257618633, 0.15958245258246148, 0.08355316014162131, 0.034993448693837435, 0.06269141100347042, 0.09266971237957478, 0.14903400146535464, 0.23163228641663278, 0.19741030489759787, 0.1858034748584032, 0.05974847570593868, 0.05955750881029027, 0.20285157220704214, 0.13769805617630482, 0.07820277581257479, 0.05605895172006317, 0.03694252357152956, 0.01796973789376872, 0.08907301537692547, 0.08025217548544918, 0.06018743358020272, 0.09956263072256531, 0.20368361898830958, 0.12806414812803268, 0.09815522695758513, 0.04780181158067925, 0.17597437942666666, 0.2894576649580683, 0.39435060215847834, 0.2828169512961592, 0.31989275610872675, 0.3994978331029415, 0.2422039434313774, 0.39573779915060314, 0.16018090689820902, 0.4431283404784543, 0.03631865133398345, 0.2555723318031856, 0.17488652494336876, 1.6031970530748367, 12.705316134861537, 63.85474409375872, 92.4963026046753, 84.73151002611432, 61.03789574759347, 30.026598521641322, 25.567428793225968, 18.32794782093593, 22.44201442173549, 31.02872678211757, 62.902430943080354, 64.16102068764823, 63.262257303510395, 68.2246537889753, 71.50432859148297, 75.08652796064104, 69.41954939705985, 40.27275262560163, 3.5589346289634705, 0.39821135784898487, 0.0597165845600622, 0.05851107888988086, 0.027466744716678346, 0.06053661448614938, 0.04253660375252366, 0.05490097064258797, 0.06655598684613194, 0.02986475871875882, 0.025344802864960263, 0.002287087309274024, 0.021466381515243223, 0.0975839818960854, 0.06960497716707842, 0.018355027040732757, 0.03768086466672165, 0.021913123882508705, 0.08809576888701745, 0.027681986202618906, 0.03269780527002045, 0.10453543745513473, 0.10311001180005924, 0.057739279232919216, 0.015619172149204781, 0.0043491791917144185, 0.0048152954300998575, 0.054380459644432576, 0.05654752068221569, 0.029347972877855812, 0.011736859401155795, 0.033693948960197825, 0.006006707503859485, 0.0156321406497487, 0.029202030173369815, 0.06228084981973682, 0.01941160105967096, 0.02651187970436045, 0.028918202367744276, 0.03513370527486716, 0.01838271296583116, 0.026245790500459925, 0.038251298878874095, 0.020365492374237095, 0.05554267478042415, 0.07443869779152529, 0.010232770333199628, 0.0724927679236446, 0.04475978981437428, 0.029189327997820716, 0.025761487827237164, 0.03385112141924245, 0.0423436521419457, 0.03370097858299102, 0.029835361189075878, 0.04711893733058657, 0.09279655093061072, 0.07275797333568335, 0.04977039094748242, 0.11137405942593302, 0.03493364600996886, 0.04138242925650307, 0.03516313333862594, 0.0616678816399404, 0.07307076440857989, 0.01875677066189902, 0.05762174339698894, 0.043507794317390235, 0.056916124653071165, 0.013763015008797603, 0.026660858853054897, 0.040124432117279084, 0.01584907338422324, 0.009125391004740127, 0.058892544492014816, 0.014921722966911537, 0.06768831929990224, 0.07988626190594264, 0.02172987362635987, 0.04107795023758497, 0.04155131662264466, 0.02081960023913, 0.07705906432654176, 0.049528106448373625, 0.07371870428323746, 0.04439722141250968, 0.032472226303070784, 0.023556321959144304, 0.0632772445678711, 0.05999151337891817, 0.03703764739579388, 0.06096612036760364, 0.14921123481222562, 0.09131982802812542, 0.0720073100445526, 2.2157718454088484, 28.032802513667516, 76.20704310280937, 88.48099422454834, 95.30366665976388, 88.24433858054024, 88.14905098506382, 74.61261217934745, 71.711989402771, 69.3720098223005, 46.447078227996826, 36.656166621616904, 23.74306287084307, 10.930097426686968, 15.210822650364467, 43.20608752114432, 55.31597430365426, 52.8220226424081, 51.505238260541645, 59.00653430393764, 28.273425579071045, 8.236907907894679, 1.6981904357671738, 0.1337546142084258, 0.07494466778423105, 0.17593958415091038, 0.038201633508184125, 0.03140056845066803, 0.06103348532425506, 0.19494152308574744, 0.2396353626889842, 0.3494430375950677, 0.5154365875891277, 0.28641239979437416, 0.6178144397480148, 1.048550152352878, 0.8681738312755312, 0.4940668057118143, 0.27693527404751095, 0.4197608700820378, 1.0727260836533137, 0.3586900314050061, 1.5661408986364092, 1.815446389572961, 0.8599397816828319, 0.9985505895955222, 0.6909614375659398, 0.40034459052341326, 0.4925240342106138, 0.7875421579395021, 1.1076622775622775, 1.15785237295287, 1.387217185326985, 0.4059660903045109, 0.5555265535201345, 0.056083711462893655, 0.32186729301299366, 0.32695692990507397, 0.20754461895142282, 0.02004550034845514, 0.23665979664240563, 0.253104744212968, 1.3858101751123155, 12.395209346498762, 54.044992446899414, 69.71055385044643, 59.88615540095738, 48.705034324101035, 29.28859908240182, 31.990506853376115, 34.30796037401472, 43.21992833273751, 57.49276154381888, 85.21688338688442, 80.82376670837402, 76.80706868852887, 77.75382328033447, 80.76781981331962, 86.68808106013707, 78.83952099936349, 39.03410073689052, 2.9158456282956258, 0.1449806775365557, 0.06945482415280171, 0.035552076396665404, 0.02283918677962252, 0.04168585315346718, 0.017029183184994117, 0.03053417083408151, 0.02035681051867349, 0.0625640024830188, 0.04673807562461921, 0.029579784188951765, 0.028195286069863608, 0.009475290309637785, 0.05827895884535142, 0.054837001753704886, 0.020145224640145898, 0.016376252685274397, 0.03782867673518402, 0.045574723942471404, 0.03583958186209202, 0.007128500612452626, 0.07522566949150392, 0.029148649823452746, 0.029881423538816825, 0.03621407212423427, 0.008872124416354512, 0.057208732701838017, 0.06781703060758965, 0.05665227970374482, 0.01961107169544058, 0.05414077393444521, 0.022086959465273788, 0.00354912194390116, 0.0580343808978796, 0.043699928293270726, 0.05811070251677718, 0.07555771060287952, 0.018794439533459287, 0.033303180642958195, 0.02242804205577288, 0.08329117098557097, 0.021344101023195044, 0.0777005445478218, 0.016527058789506555, 0.06390893352883202, 0.028859349632901803, 0.035636370802032094, 0.024826161230781248, 0.06762147002986499, 0.02996300041143383, 0.04064300589795623, 0.16709291243127414, 0.2171664083642619, 0.09308105387857982, 0.1895463690161705, 0.15046518109738827, 0.17498823734266417, 0.09349099759544645, 0.1715154815465212, 0.08669985950525318, 0.1304648593068123, 0.14471296833029815, 0.13539315414215836, 0.19021855294704437, 0.1081166435033083, 0.16090651867645128, 0.11538486635046345, 0.15252190216311387, 0.10913823225668498, 0.13532946684530803, 0.11231212051851408, 0.14361984841525555, 0.14585704622524126, 0.1405421221362693, 0.17293055275721209, 0.117769238405994, 0.1805631760507822, 0.22776835518223898, 0.20347741219614232, 0.10290936220969472, 0.12012859966073718, 0.24660323879548482, 0.16152915598026343, 0.15634862253708498, 0.10826139537883656, 0.12186844487275396, 0.15759296076638357, 0.15906452680272715, 0.19028449298015662, 0.11406921409070492, 0.2005298967872347, 0.27135345499430386, 0.1446527415620429, 0.24953798417534145, 14.958768061229161, 65.41786643436977, 102.16777120317731, 101.58956296103341, 108.37465953826904, 97.30270508357457, 96.45156465257917, 89.40430559430803, 80.03609112330845, 76.35565117427281, 54.1390050479344, 37.46141072681972, 25.136996575764247, 21.84670318875994, 37.51262937273298, 87.91553592681885, 64.67886298043388, 81.04704707009452, 98.6253433227539, 95.33661501748222, 32.24545015607561, 8.92595989363534, 2.746551901102066, 0.43630933495504515, 0.3571355076772826, 0.28488439321517944, 0.257474808288472, 0.1843374049557107, 0.21710388814764364, 0.2520701140165329, 0.3243590093084744, 0.338833246912275, 0.24864492352519715, 0.1464634258300066, 0.18841451832226344, 0.3116019538470677, 0.3857100015240056, 0.19029882363975048, 0.1817794365010091, 0.153382610263569, 0.3467943625790732, 0.16052126006356307, 0.3541827675487314, 0.46489799661295755, 0.2579950275165694, 0.39532183004277094, 0.4092125818133354, 0.26973243483475273, 0.2223384329783065, 0.375731248408556, 0.5202434925096375, 0.4910834772246224, 0.5966257452964783, 0.42304959361042294, 0.548308895102569, 0.2070255260914564, 0.8232154037271227, 1.0004302944455827, 0.8180515351040023, 0.11581982086811747, 0.22357230819761753, 0.436153489031962, 3.2027030927794318, 18.663802896227153, 92.71028627668107, 126.15791375296456, 117.61187962123326, 85.2190442766462, 44.29028442927769, 39.59890590395246, 27.4334283215659, 34.081237179892405, 46.05971615655081, 87.53297506059918, 84.50990418025425, 85.4386351449149, 88.40691253117153, 90.33756678444999, 95.00189944675991, 91.09162698473249, 59.19649110521589, 8.170880913734436, 0.560001790523529, 0.22134892536061151, 0.19935356133750506, 0.11464845229472433, 0.16371866634913854, 0.2282702268234321, 0.13711542529719217, 0.06341669708490372, 0.15305248940629618, 0.16650459542870522, 0.07436853727059704, 0.1550972546849932, 0.16150267954383576, 0.12159770940031324, 0.15993032391582215, 0.0891798846423626, 0.07362320047936269, 0.12473445465522152, 0.12646359258464404, 0.12950634716876916, 0.1560664741056306, 0.31661564909986084, 0.1448614996458803, 0.15420324408582278, 0.15941565510417732, 0.1408768706023693, 0.21315124524491175, 0.1924496168004615, 0.2587318351226193, 0.185744632301586, 0.17241428260292324, 0.11386804202837603, 0.050762653417353115, 0.14748373893754824, 0.15474434862179415, 0.11552966572344303, 0.15954714162009104, 0.11607317227338042, 0.11696385805095945, 0.1089888663430299, 0.16015650677893842, 0.11863760038145951, 0.23658388214451925, 0.12216358046446528, 0.20749128609895706, 0.09295936540833541, 0.1396226529031992, 0.09869319666177034, 0.14727821068039962, 0.1358730819608484, 0.17852867022156715], [0.01922744495927223, 0.07254561901624713, 0.03274684978116836, 0.05686143133789301, 0.042025497249726734, 0.03906138148158789, 0.03307713009417057, 0.024325509256284152, 0.06659247845943485, 0.04700369833569441, 0.030673684419265816, 0.03418798352192555, 0.030181749923420802, 0.06563037008579288, 0.014796568879059382, 0.08336584376437323, 0.014935867029375263, 0.0414920058766646, 0.02719439093821815, 0.07223947758653335, 0.04977561227445092, 0.058118607449744425, 0.04084394047302859, 0.030270990849073445, 0.04585370022271361, 0.018529875337013176, 0.04610204743221402, 0.019616045357127274, 0.038554997582520754, 0.03614072248871837, 0.03445038997701236, 0.07496606199336903, 0.014997422029929501, 0.00541033671470359, 0.02812670823186636, 0.04102173700396504, 0.028120565793610046, 0.027605466112228375, 0.03555367095395923, 0.08476897275873593, 0.11963149133537497, 2.1389516932623724, 29.417912006378174, 72.13731643131801, 82.67653165544782, 82.77115222385952, 75.54997975485665, 61.90473215920584, 66.05158383505685, 65.59072371891567, 40.77629552568708, 19.724843195506505, 15.797829048974172, 15.996969631740026, 33.10118334633963, 46.986935888017925, 66.7872452054705, 63.44461277553013, 39.1324907030378, 49.67557954788208, 38.8138358933585, 24.527312994003296, 3.0272276401519775, 0.18389512225985527, 0.12255893567843096, 0.09466248830514294, 0.14290521533361503, 0.05539876089564391, 0.08916654464389596, 0.1090962037976299, 0.05819832852908543, 0.09478431248239108, 0.11937024178249495, 0.36275380477309227, 0.3133034754012312, 0.300724874649729, 0.11084514816424676, 0.0681772648489901, 0.2080249131790229, 0.7458653428724834, 0.33996222061770304, 0.6134764839495931, 0.6934111661144665, 2.8506398243563513, 2.352664602654321, 3.447723933628627, 3.7226845622062683, 1.6043996342590876, 0.20644776709377766, 0.3188249319791794, 0.18824141046830586, 0.253540499401944, 0.18423813528248242, 0.3257184406476361, 0.2568517231515476, 0.21056371980479785, 0.07001312276614563, 0.2563384249806404, 0.1374144692506109, 0.1317748118724142, 0.06317241090748991, 0.18953192979097366, 0.28098078125289505, 0.19585061073303223, 0.2693172799689429, 0.06681988947093487, 0.12428868428937026, 0.4514620804360935, 10.317810007504054, 36.26599052974156, 69.64741556985038, 84.54534694126674, 65.95733152117047, 49.10495873859951, 27.943167277744838, 24.350896494729177, 14.192394784518651, 28.093588829040527, 35.2731693812779, 41.030912263052805, 57.83349772862026, 67.1100515638079, 76.35970892224992, 86.17221900394985, 44.9004613331386, 8.890938367162432, 0.853552867259298, 0.07432940615607159, 0.06528589142752544, 0.0333935445440667, 0.02130974849153842, 0.07112063440893378, 0.0892731085685747, 0.07527114490845374, 0.021250305431229726, 0.015623957517423799, 0.021741985476442745, 0.07076881400176457, 0.015277592531804527, 0.032383874258292575, 0.038097878718482595, 0.07350476219185761, 0.034651606144117456, 0.041319922610585175, 0.03907955604206238, 0.06200721700276647, 0.05566757611398186, 0.07512455420302493, 0.03731866606644221, 0.06566877516784839, 0.045393989354904206, 0.006017408001103571, 0.07362814699964863, 0.03124232729896903, 0.018181266096819724, 0.019666173827967474, 0.050648089564804516, 0.015562902936445815, 0.03255156401012625, 0.043882532244814296, 0.023513908431466137, 0.04541152609246118, 0.024547620909288526, 0.03807314611705286, 0.025382417453719035, 0.02437064710206219, 0.035572968489889584, 0.015310816998992647, 0.049442292124565156, 0.051631263058100424, 0.05076545237430504, 0.015139088267460465, 0.017778750642069747, 0.02239632393632616, 0.04642179348905172, 0.07244560295449835, 0.015400806009503347, 0.015068082970434, 0.03941082701619182, 0.018275249982252717, 0.02653574038829122, 0.03325916746897357, 0.0488083063225661, 0.007942154853870826, 0.027690318612647907, 0.022057889328737344, 0.04785868977861745, 0.029798733868769238, 0.047348536617521725, 0.03430717159062624, 0.018570166746420518, 0.08258704841136932, 0.03241785868470158, 0.024158406437241604, 0.011649017953979117, 0.040975013082580905, 0.029166705640298978, 0.044470404806946, 0.027343134295993617, 0.04157748771831393, 0.03484598607090967, 0.03784137212538293, 0.05062144688729729, 0.04194611883057015, 0.08106444297092301, 0.04617768373074276, 0.03694954980164766, 0.012793143346373523, 0.05008865440530436, 0.029958009786371673, 0.02236898406408727, 0.04951319224866373, 0.1206394008227757, 0.02443509266179587, 0.030409238966447965, 0.13518257758447103, 0.03370986060638513, 1.1258938078369414, 15.622737918581281, 61.382581983293804, 89.70651749202183, 91.93579837254116, 86.37936564854213, 73.22597408294678, 75.82668481554303, 74.86977890559605, 54.14602967670986, 38.41508572442191, 32.05150161470686, 27.51077914237976, 22.483599390302384, 25.652259349822998, 33.55362919398716, 45.09759562356131, 37.47989640917097, 45.302237442561555, 43.37502949578421, 32.43709536961147, 4.2096273473330905, 0.122562939035041, 0.28374708709972246, 0.11298247240483761, 0.16181568774793828, 0.16678753096078122, 0.09031826962849923, 0.44419174055968014, 0.3892462546271937, 0.3492773664849145, 0.3396467018340315, 0.6294596205864633, 0.5217512516038758, 0.3819793888500759, 0.885035480771746, 1.8757385143211909, 2.5454282590321133, 3.667704335280827, 2.27721346276147, 3.833709393228803, 4.506124351705823, 7.390776259558542, 7.5326550006866455, 6.825830825737544, 7.020617927823748, 6.260965730462756, 2.731923771756036, 2.2978895647185187, 2.8461643159389496, 2.473634042910167, 2.160677190337862, 0.736529135278293, 0.7278464383312634, 0.5739318973251751, 0.6069488685045923, 0.802489633006709, 0.2781630153102534, 0.46292861657483236, 0.6283873181257928, 0.647988132068089, 0.5053995347448758, 0.2477722189256123, 0.3340763635933399, 0.013180709826493902, 0.11879195352750165, 0.7456970661878586, 10.378249781472341, 36.150772026606965, 57.30260671888079, 61.87237439836775, 44.786715848105295, 39.205384254455566, 27.274524756840297, 33.02106019428798, 32.429594789232524, 40.62020077024187, 46.40644516263689, 54.57633508954729, 72.27125685555595, 72.56242111751011, 84.52209826878139, 98.50931535448346, 49.27561344419207, 7.342952677181788, 0.41266865921872004, 0.054548865250710926, 0.020098761954743947, 0.02288557482617242, 0.012808613096629935, 0.029474824999592135, 0.03877517880339708, 0.046692966616579464, 0.035555743878441196, 0.024218965687655976, 0.04264750012329646, 0.0691228441095778, 0.0335659399362547, 0.040976041063134155, 0.04362717916124633, 0.007885969609820416, 0.030924956114696603, 0.004536905234480011, 0.030720720466758524, 0.007153457130438515, 0.03191684539030705, 0.07457147352397442, 0.01858478069438466, 0.018467136292851398, 0.046131383893745284, 0.021170268833105053, 0.025476187600621154, 0.0607438390808446, 0.03659877773108227, 0.04566765609862549, 0.0226894154412938, 0.0328316700511745, 0.06592454215777771, 0.01569594499388976, 0.02758640606355454, 0.00558321683534554, 0.01917844794557563, 0.030600501024829488, 0.02586888295731374, 0.06590600458106824, 0.04223698304433908, 0.03321594139561057, 0.03565838247803705, 0.017968496174684594, 0.043183634390256236, 0.005651991872582585, 0.025131532523248876, 0.028874260439936603, 0.04676201094740203, 0.04963112163490482, 0.23469454209719384, 0.11990103258618287, 0.10574737563729286, 0.15003874897956848, 0.09175252980951752, 0.10639361238905362, 0.15621807239949703, 0.14143924042582512, 0.13937709107995033, 0.12653441806989058, 0.11835790824677263, 0.0947568453848362, 0.143378846347332, 0.09925669285335711, 0.1883491753999676, 0.2023344606693302, 0.09046438535941498, 0.14124800211616925, 0.1398457416466304, 0.1598845770848649, 0.14929540029593877, 0.16995198758585112, 0.15155530188764843, 0.25940676033496857, 0.13210254428642138, 0.08350544555910996, 0.15961886277156218, 0.12272107840648719, 0.2939232939055988, 0.10907954576292209, 0.23042511833565577, 0.0944785171055368, 0.11880574135908059, 0.11464347184768744, 0.10731792636215687, 0.1731486339122057, 0.15262281389108726, 0.11138052586466074, 0.07880135226462569, 0.22672256987009728, 0.25766365815486225, 4.9324115344456265, 52.79862805775234, 102.97308131626674, 105.97843429020473, 98.3204424721854, 94.98351451328823, 80.62469387054443, 88.20634583064488, 86.45284979684013, 59.081526211329866, 38.89716216496059, 30.93821954727173, 31.01366308757237, 49.5230005809239, 67.40522493634904, 90.59940270015171, 93.4604971749442, 55.692448547908235, 75.42891434260777, 59.22842502593994, 43.544075693402974, 5.455239159720285, 0.7048126714570182, 0.43368362156408174, 0.19493889036987508, 0.3632631131580898, 0.23889543382184847, 0.39656976450766834, 0.3574985239122595, 0.3076966048351356, 0.28708667361310547, 0.2316701758120741, 0.9277401949678148, 0.6186344900301525, 0.48182462262255804, 0.5364630307470049, 1.1115582627909524, 1.4175037315913608, 3.4129851119858876, 1.4180570904697691, 3.9659032140459334, 4.046394186360495, 7.599653874124799, 8.9055460861751, 7.632311276027134, 9.741655826568604, 4.309251487255096, 2.3201077325003485, 0.5920808634587696, 0.8404148550970214, 1.3562864107745034, 0.7476331708686692, 0.429495459156377, 0.18987374859196798, 0.26529940270951813, 0.21644872187503747, 0.2827942339437348, 0.24567641424281256, 0.19700008976672376, 0.3332170397043228, 0.4891563834888594, 0.7126969769597054, 0.4452905058860779, 0.6112130539757865, 0.14163274504244328, 0.30763849509613855, 1.0812290502446038, 16.658512830734253, 52.62231404440743, 101.81816564287458, 116.36176667894635, 88.51889664786202, 71.1647562299456, 43.962287766592844, 35.3716253553118, 25.223897695541382, 42.597890853881836, 51.8725026675633, 58.542825426374165, 79.07719108036586, 88.54106834956578, 95.98310320717948, 105.6321221760341, 69.13210242135185, 17.503460679735454, 2.491856127977371, 0.1212584011788879, 0.13030883696462425, 0.09748493613941328, 0.1018898972709264, 0.16685545231614793, 0.1404382384249142, 0.21606321898954256, 0.24204918316432408, 0.10807317655001368, 0.09238792357168027, 0.12083029986492225, 0.10333136349384274, 0.095194011926651, 0.1484340000897646, 0.08142899269504206, 0.11222899997872965, 0.12028065935841628, 0.10942560540778296, 0.1294617945594447, 0.14318270901484148, 0.16245589910873345, 0.10479948257229157, 0.10887103195169143, 0.16405114850827626, 0.17415255361369678, 0.17203575505742005, 0.11443392666322844, 0.19570731770779404, 0.10858743824064732, 0.08673569972493819, 0.1634947226515838, 0.1587182568120105, 0.06624340611909117, 0.0831947715154716, 0.10199591836759023, 0.08656292435313974, 0.10607275353478533, 0.2240472962813718, 0.1280857255416257, 0.10473029914179019, 0.08351797810090439, 0.1458989932600941, 0.13073338275509222, 0.11828729989273207, 0.07581589317747525, 0.09886719339660235, 0.12480351594941956, 0.10268442106566258, 0.2258563113531896], [0.04120062258360641, 0.03770753787830472, 0.023764101256217276, 0.028009817004203796, 0.012063801321866257, 0.038747365652982674, 0.01391532237175852, 0.028013477700629404, 0.029742639378777573, 0.029138213954865932, 0.0386342470800238, 0.017121810000389814, 0.039517753957105536, 0.057615582299019606, 0.10475752196673836, 0.008764485861839992, 0.013721654058567114, 0.02037459152883717, 0.03606674520831023, 0.02917348759781037, 0.025679559812748005, 0.029285428912511895, 0.015175564613725458, 0.04286652783464108, 0.04454083674188171, 0.025379516716514314, 0.025809073488094976, 0.07044995004045111, 0.017788375661309277, 0.03237940949786987, 0.015528189084891762, 0.04774578833686454, 0.09912484671388354, 0.048438202789319415, 0.028365396495376314, 0.02986946775178824, 0.025141055762235607, 0.015691598977095315, 0.10542872202183519, 0.13857103218989714, 8.81879608971732, 60.72168322971889, 91.0701014654977, 86.40446949005127, 79.68246255602155, 58.2996940612793, 45.99184267861502, 50.52356549671718, 49.22061150414603, 29.708138261522564, 19.367716210229055, 13.946415526526314, 25.314972945622035, 42.519925117492676, 53.56925623757498, 47.55526726586478, 40.81917633329119, 37.84569822038923, 32.49374403272356, 18.098172630582535, 2.594938733748027, 0.15985027035432203, 0.09083960165402719, 0.02504247140937618, 0.04720094507294042, 0.24408218264579773, 0.15427677014044353, 0.06646733624594552, 0.16106288028614862, 0.07116450169788939, 0.2943716427045209, 0.19037695016179765, 0.5856767956699643, 0.8542951845696994, 1.8937908027853285, 2.565717650311334, 1.9375646710395813, 4.261278084346226, 5.645520355020251, 4.917938002518245, 2.534608176776341, 4.813562597547259, 4.784704991749354, 7.2806108338492255, 10.014839887619019, 9.945681861468724, 13.843567422458104, 7.16555517911911, 4.472517652170999, 5.798788062163761, 0.6940982778157506, 3.2229262590408325, 5.186421172959464, 4.574744326727731, 4.419756506170545, 4.621417547975268, 1.4917652096067155, 3.0942397585936954, 0.755657037453992, 0.7594892403909138, 0.2607115831758295, 0.12613111042550632, 0.12131876365414687, 0.10581885930150747, 0.17095718293317727, 0.11279903046254601, 0.0603099362924695, 0.055425501960728846, 0.13466742022761277, 0.3311932682991028, 10.043806059019905, 36.85894284929548, 71.189957346235, 71.61425604139055, 68.55168465205601, 62.15340123857771, 50.804856368473594, 60.13576248713902, 57.0510367665972, 26.68381323133196, 28.730231421334402, 56.5169461114066, 65.80940437316895, 71.4637372153146, 79.54982144492013, 67.97923646654401, 35.95605918339321, 9.538011942590986, 0.8327149482710021, 0.06642926364604916, 0.023174479770074998, 0.031819370442203114, 0.08144056171711002, 0.004517151383749608, 0.009704694517755082, 0.03527269299541201, 0.015385937610907214, 0.07676878704556397, 0.057573716688369, 0.03472482007262962, 0.08501574915966817, 0.013852063400138701, 0.0258119233351733, 0.06089549844286271, 0.01397758983408234, 0.060919043608009815, 0.033905041204499345, 0.007327525111447487, 0.018389286273824315, 0.047816345800778697, 0.026692456532535807, 0.03931521464671407, 0.02459791562120829, 0.028428410346220647, 0.03155020917100566, 0.007797327491321734, 0.014604748725625021, 0.04356804483437112, 0.03258034407294222, 0.02926802448928356, 0.07467154386852469, 0.050294966370399506, 0.02145936037413776, 0.01217105395958892, 0.03173499121995909, 0.04285218021167176, 0.04434678590457354, 0.01582014065102807, 0.030978261825761626, 0.004578796714278204, 0.059318610200924535, 0.008710889228885728, 0.020836395677179098, 0.02129261378598, 0.040247284275080474, 0.06561789182679993, 0.03327166269134198, 0.02167005228277828, 0.015419311355799437, 0.014309730181204421, 0.03545576174344335, 0.02539100431438003, 0.01670725903074656, 0.05732008708374841, 0.039644901241574965, 0.06315900305552141, 0.035079873699162684, 0.019502804647865038, 0.006012595067399421, 0.09376494253852538, 0.03416656556406191, 0.04334211642188685, 0.01518063327031476, 0.019066126651263664, 0.012755724684601384, 0.0360315190628171, 0.004664326901547611, 0.021503797632509043, 0.025445979221590927, 0.04599841817149094, 0.03924313047900796, 0.06931595517588512, 0.033854005193071704, 0.023641503549047878, 0.018497604211526256, 0.007279536570422351, 0.08831338863819838, 0.05755036829837731, 0.07599415789757456, 0.0483468380490584, 0.027952565612005334, 0.02386975764030857, 0.08856560010463, 0.046038278711161444, 0.05472416138010366, 0.05811521477465119, 3.5915989790643965, 47.62501675742013, 97.54674666268485, 96.61403438023159, 92.63555145263672, 73.65363570622036, 62.18436935969761, 58.781315394810264, 65.97303444998605, 55.446683815547395, 37.35048621041434, 23.32925942965916, 15.150409800665718, 42.739613260541645, 56.878106525966096, 42.86794996261597, 45.38426440102713, 43.16677808761597, 38.99270684378487, 26.165748596191406, 4.788432700293405, 0.12364639661141805, 0.1144575939646789, 0.02004500332155398, 0.03927766791145716, 0.20695924679083483, 0.24174701794981956, 0.6336593723722866, 0.9788094546113695, 0.6397468085799898, 1.0014522224664688, 2.5774713967527663, 2.082866268498557, 2.248055781636919, 2.458499780723027, 5.594286509922572, 5.372899966580527, 5.7996691805975775, 8.457461970193044, 10.026129841804504, 10.293607694762093, 11.224899939128331, 10.425817149026052, 8.602684531893049, 12.241766197340828, 15.33090489251273, 18.76779658453805, 18.925362621034893, 10.325551169259207, 10.805318202291216, 7.572720919336591, 4.771961561271122, 3.456143847533635, 1.9648723942892892, 3.1675797317709242, 1.3968578108719416, 1.940264480454581, 2.7737740746566226, 1.4179047729287828, 2.4734038838318417, 2.1366021164825986, 1.0811994118349892, 0.7202859840222767, 0.3107413814536163, 0.41872865547026905, 0.16396694231246198, 0.03995191119611263, 0.10080303344875574, 0.08594978653958865, 0.20062962786427566, 8.81660567011152, 32.57009778703962, 54.354315825871055, 48.061648505074636, 49.56615931647164, 42.405325004032676, 33.26166588919503, 56.109924112047466, 66.5886309487479, 42.00361490249634, 43.50694104603359, 68.2722281047276, 73.71232713971818, 80.31460271562848, 91.12340109688895, 73.4886646270752, 37.174811431339805, 8.954649005617414, 0.6211712339094707, 0.0964750996125596, 0.0776394424693925, 0.051099281425454786, 0.12291625221925122, 0.05601022272769894, 0.05498023710346647, 0.03837055819375174, 0.017987303469063978, 0.054552027223897834, 0.0635246384356703, 0.03787189941587193, 0.12622957942741259, 0.02247396530583501, 0.045725789586348195, 0.031751689966768026, 0.022955706509362375, 0.003063525177172518, 0.03603526457612004, 0.020146308599838188, 0.021753279691828147, 0.017049483256414533, 0.027249533782846162, 0.03272331140137144, 0.03350065808211054, 0.01528988589000489, 0.06453613737331969, 0.011809300647915473, 0.009360642488380628, 0.02218101798955883, 0.006221610146375107, 0.03153291331338031, 0.07843012575592313, 0.013009830111903804, 0.04529921497617449, 0.014984065068087407, 0.019650574307888746, 0.043156167292701345, 0.045298393948801925, 0.0368548975592213, 0.05383112108600991, 0.03638013339202319, 0.14294747449457645, 0.015456310174028789, 0.04271102796441742, 0.04409179583724056, 0.020717099042875425, 0.06272776012441941, 0.12383095813649041, 0.1335449061755623, 0.16442259214818478, 0.1367543903844697, 0.11934027767607144, 0.09189591782965831, 0.07561159306871039, 0.10511506920946495, 0.24802466109395027, 0.10908344055392913, 0.17102578282356262, 0.19827295360820635, 0.17234917038253375, 0.2457619910793645, 0.17312829143234662, 0.11688109034938471, 0.1161560621112585, 0.16080476556505474, 0.09169898661119597, 0.11232073112790074, 0.1095056589692831, 0.12572762636201723, 0.08561524163399424, 0.11518814547785691, 0.12441681884229183, 0.1939327043614217, 0.09098750193204198, 0.10709163493343762, 0.08741179880286966, 0.12531951468970093, 0.11361064655440194, 0.15679474574114594, 0.1978095956146717, 0.13072875514626503, 0.0874284907643284, 0.08394276816397905, 0.20239600379552158, 0.16677847930363246, 0.11776458365576607, 0.12689576510872158, 19.046553100858414, 92.92190061296735, 118.78647259303501, 101.0422672544207, 98.15740299224854, 80.0973881312779, 66.15347916739327, 70.36301054273332, 68.2574075971331, 47.97147478376116, 35.069003513881135, 25.755387987409318, 46.00870943069458, 66.42558452061245, 73.6082570212228, 66.10128429957798, 56.47356503350394, 55.63362509863717, 54.6763231413705, 30.648761068071636, 6.155175498553684, 0.2747822552919388, 0.24733366817235947, 0.1110017676172512, 0.14811517005520208, 0.43822356366685455, 0.27020751791340963, 0.41257089589323315, 0.5309192367962429, 0.2778101771005562, 0.7997522056102753, 1.688830018043518, 2.7599141555173055, 5.204981114183154, 7.473154102052961, 8.220362509999957, 6.605795272759028, 12.119107910564967, 12.17919853755406, 14.038216863359724, 10.076022250311715, 12.257553373064313, 17.406072991234915, 19.006665229797363, 24.356194496154785, 27.322509016309464, 28.217377935137065, 29.810346262795584, 20.078638519559586, 14.695028339113508, 14.350230932235718, 13.219020775386266, 16.55569859913417, 14.72504108292716, 11.902047055108206, 12.273129497255598, 5.449213334492274, 6.293719104358128, 2.1563345662185123, 2.842937094824655, 0.9074733853340149, 0.6361348309687206, 0.2529221640101501, 0.18571453248815878, 0.21110094312046254, 0.17021036015025207, 0.14178825169801712, 0.16087100415357522, 0.209878073739154, 0.6700095789773124, 17.13709259033203, 56.38979755129133, 106.81676919119698, 104.666232245309, 95.91269016265869, 88.12920692988804, 69.4782269341605, 72.92284502301897, 71.00045912606376, 40.192327226911274, 42.386512756347656, 78.22743334089006, 85.04438046046666, 89.7452745437622, 98.24998773847307, 87.68536295209611, 50.57634053911482, 20.010745934077672, 2.087566290582929, 0.27315322841916767, 0.16574756747909955, 0.12225044651755265, 0.310549546033144, 0.10883114766329527, 0.10676531387226922, 0.07813360595277377, 0.1313145887106657, 0.12445221122886453, 0.13646571444613592, 0.1459122518343585, 0.25546550324984957, 0.06601688398846559, 0.08301024391715016, 0.18583528458007745, 0.08420046219336134, 0.15377423353493214, 0.12796710404966558, 0.06464601254888944, 0.09075678645500115, 0.1469419558665582, 0.11180893930473498, 0.138815684776221, 0.11588031905038015, 0.12943900935351849, 0.07635688236249344, 0.12951729872397014, 0.10006740649363824, 0.22885216559682572, 0.1232625086392675, 0.08992936728256089, 0.18756553530693054, 0.08032554547701563, 0.09840963009212698, 0.10748780438942568, 0.07754373510501214, 0.11049620474555663, 0.25676052804504124, 0.09705515884395156, 0.11626673117280006, 0.20826580668134348, 0.18980945061360086, 0.13012616176690373, 0.11750850453972816, 0.10594964014100176, 0.09060145621853215, 0.09076784657580511], [0.032672489128474674, 0.012757136037440171, 0.03024873150778668, 0.032852514646947384, 0.023546405169846754, 0.02171030467642205, 0.025567837325589995, 0.055542372832340856, 0.058058577456644604, 0.031724840336080105, 0.03687030030414462, 0.003896552653584097, 0.027637781342491508, 0.01794878133971776, 0.012186281981744936, 0.06451616130237069, 0.023804662383294532, 0.06195481374327626, 0.0130409833509475, 0.05461294949054718, 0.03137691132724285, 0.07381287137312548, 0.014055344010038036, 0.025336794455402663, 0.015332811711622136, 0.031750302362654886, 0.035480426491371224, 0.053368957314108095, 0.009885485932630087, 0.03512789022975734, 0.026571273570880294, 0.016151667772127048, 0.00732246324020837, 0.06519541556813888, 0.026480404161182896, 0.029823442721473317, 0.0672885671790157, 0.029849997189428126, 0.34016282271061626, 21.006084067480906, 83.31675257001604, 93.98648970467704, 87.99086134774345, 67.1398732321603, 61.86750371115548, 37.6988410949707, 19.65560265949794, 9.724097728729248, 9.513813103948321, 14.378070626940046, 18.6727990763528, 49.31483949933733, 40.37871960231236, 38.56414542879377, 34.20289666312081, 40.98202821186611, 34.32190193448748, 15.559601375034877, 2.5192546120711734, 0.20701901215527738, 0.15284967528922216, 0.1458726389599698, 0.07623921760490962, 0.12282420215862137, 0.0348466238938272, 0.060828099559460364, 0.22606335952877998, 0.1862389993454729, 0.46752772693123135, 0.9146722619022641, 0.8959348159176963, 1.8437388028417314, 2.337053737470082, 1.896172080721174, 1.9741625700678145, 1.0856847997222627, 2.3954498725278035, 4.888351704393115, 7.266832556043353, 6.720668971538544, 7.1237469996724805, 5.022407642432621, 5.156464448996952, 13.152797494615827, 15.510635682514735, 6.632128076893943, 7.895100831985474, 9.88341384274619, 3.7079404847962514, 14.699233736310687, 16.229204484394618, 4.864522423063006, 5.484198382922581, 0.5224038394434112, 2.5647307889802113, 4.273731427533286, 6.221387054239001, 7.665043371064322, 4.048617609909602, 5.329569263117654, 1.8169133280004774, 1.5959648468664713, 1.1771014886243003, 0.7980585822037288, 0.7305806087596076, 0.27931234506624086, 0.072359937908394, 0.1617602650076151, 0.08912903522806508, 0.0846575912354248, 0.2022019699215889, 0.13974379854542868, 10.777404682976858, 47.491097177777974, 62.27431379045759, 79.25096552712577, 69.62240205492292, 40.72603920527867, 38.691961015973774, 34.02325446265084, 18.830048969813756, 22.218789645603724, 48.57925803320748, 54.639588015420095, 66.60705062321254, 76.30464444841657, 78.87819467272077, 56.20106363296509, 23.365183353424072, 7.354128854615348, 0.28731528563158854, 0.2092791444488934, 0.06306154507079295, 0.015277243086269923, 0.17912898372326577, 0.01952526076430721, 0.15376860169427736, 0.05635929506804262, 0.024086910898664167, 0.03556288545951247, 0.048600396407502036, 0.03723721472280366, 0.0037771932547912, 0.010448463893096362, 0.061809654746736796, 0.04544654528477362, 0.02117327304690012, 0.03064073475876025, 0.0640162302713309, 0.04500647122040391, 0.028242613887414336, 0.02053101929569883, 0.030291021202823946, 0.041316221202058453, 0.011777701272097017, 0.010026138608476945, 0.014302040683105588, 0.026243793911167553, 0.07297283823468856, 0.06155417952686548, 0.02713215909898281, 0.08810301564101662, 0.020496054386187876, 0.02084602408909372, 0.0520132714882493, 0.015737023503918732, 0.04927493824756571, 0.04828324235443558, 0.014660475110369069, 0.07060327181326491, 0.011821637262723275, 0.041474879652793915, 0.029788545665464232, 0.011138574719162924, 0.03040207702932613, 0.037312837450632026, 0.004041802828266684, 0.027104244168315614, 0.04245562059804797, 0.06186230227883373, 0.008547364833897777, 0.00956967198622546, 0.006102636664374066, 0.08275111139352832, 0.015255231410264969, 0.04076570877805352, 0.023862532938697507, 0.008303814018810434, 0.030102836300751994, 0.024066851707175374, 0.027720654216994132, 0.028454281190144162, 0.05286196612619928, 0.08391933834978513, 0.006104171425769371, 0.04512242946241583, 0.02604183814089213, 0.0384142558489527, 0.013375579994837088, 0.02917962833972914, 0.032226220039384704, 0.03262453705870679, 0.08569490843053375, 0.024113338141302978, 0.063578405550548, 0.03712830985231059, 0.04001761034929326, 0.008881451728354608, 0.039172932638653686, 0.05612302917454924, 0.041109899058938026, 0.05745894927531481, 0.11689935651208673, 0.052176465945584435, 0.23740043118596077, 11.46005824634007, 78.83635262080601, 105.82574067796979, 99.49191570281982, 81.37219497135708, 68.52166148594448, 48.181494508470806, 39.10139404024397, 30.69358389718192, 27.255788939339773, 24.57669905253819, 24.69145028931754, 41.24836308615548, 42.81693976266043, 30.927682604108536, 31.496573311941965, 43.56609106063843, 43.376012665884836, 23.021549769810267, 4.047034289155688, 0.14185986428388528, 0.30392663713012424, 0.10353383155805723, 0.06027959220643554, 0.41088191366621424, 0.21929042653313705, 0.6162891473088945, 1.0394233678068434, 1.564691873533385, 2.1646248527935574, 2.1977998954909186, 2.217150411435536, 2.1511983275413513, 1.4551605795110976, 1.0317991312061037, 0.1698906480201653, 1.0329162712608064, 2.5835871143000464, 0.18722387935434068, 2.1380705748285567, 8.450558066368103, 6.985374927520752, 9.3790180512837, 12.638688990048, 23.271057844161987, 19.50278745378767, 13.681197575160436, 9.139533621924263, 9.077458415712629, 6.267004149300711, 5.596872542585645, 1.1108574718236923, 1.8470971712044306, 1.618123737829072, 1.5899326162678855, 1.5973524238382066, 0.542223358792918, 1.3408128810780389, 3.0551077212606157, 2.661402161632265, 4.084621003695896, 3.3897381765501837, 1.7663407559905733, 0.3042000596012388, 0.8609362510698182, 0.5484948136976787, 0.3831662008804934, 0.16359501012734004, 0.08421066057469163, 0.0646145488800747, 0.02593992557376623, 0.06819796016705887, 0.0799929683229753, 11.610646554401942, 45.458314827510286, 52.28093862533569, 53.90529891422817, 53.1542820249285, 44.200541496276855, 41.207295758383616, 34.96255711146763, 27.36139460972377, 39.64807135718209, 62.48045989445278, 65.76872961861747, 76.58933298928397, 89.79837267739433, 87.56110831669399, 64.31210926600865, 24.01076306615557, 6.2923242534909924, 0.32235477971179144, 0.08941513951867819, 0.03893054975196719, 0.047979394373084815, 0.09411267816488232, 0.0315904496902866, 0.05385595886036754, 0.01882616274191865, 0.009212091664916702, 0.06720216252974101, 0.03357399753960116, 0.03060207183339766, 0.012727993806557996, 0.04024832243365901, 0.01769646130768316, 0.034696599801204035, 0.02067994076891669, 0.03936004206272108, 0.042646217692111216, 0.0466319018575762, 0.018122793341587697, 0.027116532437503338, 0.037124004547617266, 0.011190082312428525, 0.09834389361952033, 0.053631611434476714, 0.03580584849363991, 0.03769773304728525, 0.02292352189709033, 0.03992574010044336, 0.04869724031803863, 0.013556059283603514, 0.07140831290079014, 0.022795461983020817, 0.010898817762998598, 0.01169322366227529, 0.02917441040543573, 0.05433980182611516, 0.06154929407473121, 0.058834570460021496, 0.03862825561580913, 0.009408452065794595, 0.017086543142795563, 0.02026266378483602, 0.06802042147942952, 0.025050932741058723, 0.15063109648014816, 0.14853730026100362, 0.13113709752048763, 0.0809080677905253, 0.1222604074116264, 0.1557600884033101, 0.06551166038428034, 0.13956492314381258, 0.11210659226136548, 0.23817572529826844, 0.12673354095646314, 0.08388790182237114, 0.12383155524730682, 0.1158404890447855, 0.05872842722705432, 0.12433388829231262, 0.12457289546728134, 0.1297105047851801, 0.06328909857464687, 0.15410615929535457, 0.09747167077979871, 0.1876110785773822, 0.06707889307290316, 0.14843051241976873, 0.13661244085856847, 0.19037856507514203, 0.1909326703420707, 0.25950843202216284, 0.14312169514596462, 0.09921719532992158, 0.08939723976488624, 0.14454349742404052, 0.13590323605707713, 0.19119998599801744, 0.0960170409775206, 0.14690888406974928, 0.22556524697159017, 0.15990711801818439, 1.1412695199251175, 44.577113015311106, 118.2732925415039, 115.27542277744838, 106.63426780700684, 88.84953362601144, 83.19498538970947, 53.78272574288504, 32.26803527559553, 20.287965161459788, 18.196232557296753, 24.65341411318098, 29.804172788347515, 72.17504514966691, 58.54665388379778, 56.63401978356497, 48.72748047964913, 62.8339911869594, 56.603107248033794, 30.249986580439977, 4.333135051386697, 0.4825188453708376, 0.5188884852187974, 0.3680121526122093, 0.2625072311077799, 0.29965634484376225, 0.13967494081173623, 0.18101429327258042, 0.4421246514788696, 0.8092645066125053, 1.5107713554586684, 4.378851158278329, 4.34259980065482, 11.28838997227805, 8.647295440946307, 7.557159560067313, 6.314593229975019, 7.97536381653377, 12.628033927508763, 19.79027611868722, 21.06195626940046, 16.92800566128322, 18.38525308881487, 23.33289507457188, 24.026516369410924, 31.215466567448207, 28.665962321417673, 22.119456461497716, 23.672543866293772, 27.584933791841777, 16.739704268319265, 36.71360737936837, 40.786801201956614, 23.2677036012922, 24.25059403691973, 12.216576371874128, 20.06821969577244, 14.66607345853533, 21.35612736429487, 29.92046478816441, 16.222888571875437, 19.15894021306719, 11.822616117341177, 7.518854141235352, 3.7652392387390137, 1.6795685035841805, 1.7059266035045897, 0.6872813893215997, 0.2337237484753132, 0.28813699153917177, 0.10909039553787027, 0.18800198260162557, 0.3165076806076935, 0.5216003454157284, 17.953269686017716, 71.3178458895002, 89.90884903499058, 115.47801835196358, 93.23876626150948, 52.84646987915039, 50.91918897628784, 47.437252112797324, 30.667410033089773, 35.81355857849121, 68.71628052847726, 76.29089396340507, 86.84117071969169, 96.41989476340157, 100.786545753479, 81.58198887961251, 38.720980167388916, 12.720855781010219, 1.2638957798480988, 0.38224570027419497, 0.14811142454189913, 0.1605514684425933, 0.257326534816197, 0.08632408002657549, 0.2958126339529242, 0.1563102581671306, 0.09285748337528535, 0.09195351866739136, 0.12744007232998097, 0.0700225815443056, 0.12735992377357824, 0.14977736371968473, 0.13562790011721, 0.06702855934521981, 0.11479705146380834, 0.11359061620065145, 0.2264433391392231, 0.09551056208355085, 0.12006704296384539, 0.053109634800681045, 0.15644250464226517, 0.13036074489355087, 0.14237745079611028, 0.15625932732863085, 0.17114840767213277, 0.11328559435371842, 0.15408987445490702, 0.11762606751705919, 0.09290118103048631, 0.21044026714350494, 0.2030224816075393, 0.13150565060121672, 0.19463208397584303, 0.1189112128423793, 0.11650143643575055, 0.2039412044520889, 0.10155060940555163, 0.10926033463329077, 0.0810960762734924, 0.06317811060164656, 0.12343732640147209, 0.15781079764877046, 0.17266529984772205, 0.07565843912639789], [0.04479254948507462, 0.04449951395924602, 0.025049380592203567, 0.017317967688930885, 0.030733354788805758, 0.07855873528335776, 0.03379353754488485, 0.041782602069101164, 0.05395637186510222, 0.028929605148732662, 0.028058585012331605, 0.058984580981944285, 0.011690403501104032, 0.008214354265614279, 0.018577506798984747, 0.02420637377404741, 0.04681069922766515, 0.07561889410551105, 0.025975733563037853, 0.05972393987966435, 0.05228183904130544, 0.020843045320361853, 0.06043476637985025, 0.021687158150598407, 0.03769555834255048, 0.0325254811240094, 0.07348717456417424, 0.02889748669362494, 0.027704196350116814, 0.008590209231312786, 0.050702039884137254, 0.05758382007479668, 0.09422802233270236, 0.13751297896461828, 0.06159029116055795, 0.039372822269797325, 0.043050919725958786, 0.6352189172591481, 44.69837645121983, 101.88968345097133, 88.67042296273368, 78.9338983808245, 69.8375460760934, 59.14880561828613, 38.86161518096924, 21.980117286954606, 33.1162748336792, 70.5346588407244, 42.2320681980678, 37.25971146992275, 71.40521253858293, 69.15722710745675, 52.22273703983852, 70.38468197413853, 48.76704699652535, 16.734180450439453, 3.6462721824645996, 0.25624020025134087, 0.0707483154588512, 0.10280691699257918, 0.17398564756980964, 0.041379955996360095, 0.0675256269584809, 0.05358555247741086, 0.14496607546295437, 0.6095198105488504, 0.8963918771062578, 2.075459271669388, 3.6455556494849066, 5.905563201223101, 8.506483248301915, 16.777995790754044, 10.712427735328674, 8.651629379817418, 5.6389113153730115, 8.81997902052743, 9.626168949263436, 3.576618880033493, 6.068435055868966, 7.222424013274057, 12.033266391072955, 11.604513900620596, 6.446224246706281, 6.599985710212162, 5.8771025112697055, 14.307024427822657, 15.223911319460187, 10.526678936822073, 7.530753799847194, 9.05182477406093, 1.228131121822766, 1.6152823588677814, 5.008697543825422, 21.30498514856611, 44.191151005881174, 53.65090104511806, 55.96081577028547, 41.79364381517683, 30.966613360813685, 24.49190149988447, 21.920635495867046, 6.254944247858865, 5.23476630449295, 4.109975848879133, 4.263219237327576, 1.515455526965005, 0.12559095583856106, 0.14000998783324445, 0.18518603513283388, 0.15391072763928346, 0.062231601748083315, 0.0229141004383564, 0.34163225814700127, 0.36997607722878456, 12.798093693596975, 46.216609954833984, 62.44856766292027, 64.11521816253662, 72.9790837424142, 61.73449434552874, 36.48529304776873, 18.267717361450195, 15.451456138065883, 38.0295649256025, 57.32191228866577, 54.474901812417166, 68.42036369868687, 76.84537410736084, 66.95170211791992, 43.66210126876831, 14.757232086999075, 2.0172513893672397, 0.45836316155535833, 0.0789841835254005, 0.06959148789090769, 0.08906977197953633, 0.050657741725444794, 0.03300729187737618, 0.043964784259774854, 0.028140114387497306, 0.022501079565180198, 0.02339839462989143, 0.08149134327790566, 0.021593438893822686, 0.02387089079378971, 0.006853186300889189, 0.02136508811132184, 0.008319693434584354, 0.033723224353577406, 0.05191456160641142, 0.03599308344668575, 0.040528743993490934, 0.028130711588476385, 0.03933309404445546, 0.065752302828644, 0.014285591297916003, 0.09600878320634365, 0.012460031846006001, 0.034609818564994, 0.015867398918739388, 0.0842697134773646, 0.020669452313865935, 0.013960677348742527, 0.04164472036063671, 0.013205173558422496, 0.12501808229301656, 0.019279559841379523, 0.034605655752654584, 0.015982525955353464, 0.026148547950599874, 0.06233104784041643, 0.013868091245447951, 0.015067182215196746, 0.06536320370755025, 0.025276611791923642, 0.040209215067859204, 0.051994479460907836, 0.05937383616609233, 0.026518003482903754, 0.008736626910311835, 0.033362542279064655, 0.03579472730468426, 0.06333546287247113, 0.041928561736962626, 0.0499898868479899, 0.04408147531960692, 0.07606634723820857, 0.037931847984769514, 0.03260401476706777, 0.044189165612416606, 0.012464784983811634, 0.023168881856171147, 0.05960875856024878, 0.018496284460914985, 0.03966429037973285, 0.06989292707294226, 0.036889838720006604, 0.025022422395912663, 0.04186552583373018, 0.04085353495819228, 0.009800825966522098, 0.02368035985689078, 0.04574569101844515, 0.06975094362029008, 0.08032072109303304, 0.01990464496027146, 0.06500299660755054, 0.04533894320151635, 0.06316106580197811, 0.036540176054196696, 0.09388982012335743, 0.04889212575341974, 0.09420744915093694, 0.13743272184261254, 33.485425676618306, 108.07323278699602, 105.35764053889683, 93.19784137180874, 79.73056493486676, 65.68938813890729, 63.215495926993235, 39.130993366241455, 31.59777729851859, 24.527837582996913, 17.54057274545942, 33.479283469063894, 41.52741663796561, 45.680170808519634, 44.27165978295462, 48.31073795046125, 49.719763142721995, 24.00851011276245, 5.989644220897129, 0.22077018927250588, 0.23232580348849297, 0.10068774356373719, 0.1484974973968097, 0.1492299080959388, 0.28565873737846104, 0.4082395354551928, 0.844144192125116, 1.8964358951364244, 2.802903094461986, 0.7391884497233799, 1.2819642445870807, 2.5523868799209595, 7.08847360100065, 13.273447751998901, 13.016574587140765, 10.567815746579852, 7.431341579982212, 9.269624744142805, 10.211312362125941, 6.103638538292476, 1.1420188397169113, 3.2193327375820706, 3.0500635462147847, 7.405833874429975, 11.769602230616979, 8.193981068474905, 7.739739980016436, 7.90452606337411, 3.6993012683732167, 4.18351297719138, 1.5123350258384431, 1.7414278813770838, 0.7638092285820416, 1.152514310819762, 7.309919204030718, 28.535344873155864, 54.594980580466135, 64.32733276912144, 67.4402299608503, 53.3045437676566, 42.33178527014596, 30.491533756256104, 24.810938460486277, 11.144810659544808, 3.819270602294377, 1.2133653312921524, 0.9149595264877591, 1.2674042944397246, 0.14638059027493, 0.2298408725431987, 0.2776971331664494, 0.0905923502785819, 0.045761707837560346, 0.05613025896517294, 0.3615124928099768, 0.3689870988684041, 15.15388216291155, 48.1140969821385, 54.96551411492484, 43.26397296360561, 45.82667704990932, 45.53463384083339, 28.77077416011265, 29.067823546273367, 32.02839190619332, 51.92199468612671, 69.01794351850236, 67.7438245500837, 74.70406436920166, 86.02586214882987, 75.90230206080845, 47.67029121943882, 15.056292976651873, 1.1348307111433573, 0.16045715207500116, 0.07243663272155182, 0.05680923842425857, 0.07455163316002913, 0.026587173342704773, 0.030616568734071085, 0.05002775928005576, 0.024717247878600444, 0.02325139849978898, 0.012228178974640156, 0.1033538772857615, 0.0742009866184422, 0.05927443757121052, 0.04320410579176886, 0.05019520136660763, 0.061863869694726806, 0.03207772943590369, 0.05511218163051775, 0.0056585002956645826, 0.05085889682439821, 0.013887832373646753, 0.015811533434316516, 0.036863365676254034, 0.0561219944086458, 0.041847999274198494, 0.040616241084145646, 0.0465461553872696, 0.0542766268232039, 0.019019813243565813, 0.015684633815128888, 0.057152902840503624, 0.06139663726623569, 0.057763129738824706, 0.05376857712066599, 0.0393687680230609, 0.03401224973744579, 0.04701738438702055, 0.05196061377812709, 0.007000553080745573, 0.06752378134323017, 0.02035270707814821, 0.02792043867520988, 0.052777688684208054, 0.019198057607614567, 0.17696664189653738, 0.11389538698962756, 0.0717584030436618, 0.13985518685409, 0.1429401327456747, 0.16075445897877216, 0.18504652833299978, 0.1403861947889839, 0.2192639908088105, 0.23707033747008868, 0.14710602563406738, 0.20229837617703847, 0.154352250375918, 0.1754119281790086, 0.09024190051215035, 0.09128001159323113, 0.2026661421571459, 0.19749308616987296, 0.05830975076449769, 0.12972844525107316, 0.12119286826678685, 0.12132474833301135, 0.183399248868227, 0.12272163480520248, 0.14991435993994984, 0.146207685981478, 0.23001319329653466, 0.16480107898158686, 0.12548457511833735, 0.20661436101155622, 0.2240944816065686, 0.14283177070319653, 0.3151431195437908, 0.17032956518232822, 0.13772761316171714, 0.12308887152799539, 0.18286245981497423, 2.2728971115180423, 76.01749624524797, 133.4821071624756, 107.66380323682512, 100.61603696005685, 96.64103507995605, 77.23347963605607, 54.94483280181885, 34.099184376852854, 45.57895292554583, 92.67327322278703, 57.2315787587847, 54.136104175022666, 98.51863983699253, 96.92252050127301, 71.86006246294293, 98.99698856898716, 76.72808851514543, 27.98713721547808, 6.522489411490304, 0.6789838288511548, 0.3175011915819985, 0.23560611318264688, 0.440057779529265, 0.1823198896433626, 0.1817671957292727, 0.26131317232336315, 0.3547360178615366, 1.3239504716226032, 4.255282657487052, 9.454073360988072, 14.733778442655291, 19.600131716047013, 18.92594105856759, 25.87481709889003, 18.794522830418178, 14.549213443483625, 10.923112750053406, 14.364965455872671, 16.04927740778242, 12.631458520889282, 16.560133286884852, 27.9378536428724, 31.488023553575786, 32.772158350263325, 23.019284657069615, 14.349320718220302, 18.062672546931676, 38.65846722466605, 40.798901489802766, 26.442161832536968, 28.043709448405675, 24.253171818596975, 11.737023864473615, 5.325454192502158, 7.421104277883257, 24.948577063424246, 50.46760817936489, 60.47507776532854, 62.151212556021555, 46.86514091491699, 37.69073602131435, 30.538305555071148, 34.61883667537144, 15.593058688299996, 19.54343788964408, 13.36993043763297, 10.906074030058724, 2.6382670487676347, 0.42503476994378225, 0.6934243568352291, 0.3435333775622504, 0.18297027902943747, 0.2159543005483491, 0.12253492910947118, 0.620267968092646, 0.8747172430157661, 22.47704029083252, 70.59182861873082, 85.5718321119036, 92.22626086643764, 100.10470512935093, 87.31722654615129, 52.30448259626116, 28.755104235240392, 27.277262347085134, 55.16593837738037, 76.74889142172677, 78.181366784232, 84.51098115103585, 95.35964829581124, 86.54996476854596, 63.89534241812569, 27.170458112444194, 7.052802852221897, 1.189488715359143, 0.2542444116302899, 0.22232119818883284, 0.16942021969173635, 0.1488099763435977, 0.13233730383217335, 0.11761716513761453, 0.09048372360744647, 0.0974625376984477, 0.06159843358078173, 0.24695572416697228, 0.1247685035424573, 0.1366395279765129, 0.1415806199823107, 0.16308659740856715, 0.13402654390249932, 0.16053347369389875, 0.08778455201536417, 0.08659431338310242, 0.14673280423241003, 0.1509753308658089, 0.09810121557010071, 0.145894623494574, 0.11616930711482253, 0.1044183290962662, 0.08889175153204373, 0.1286061890423298, 0.1494669203779527, 0.13168269395828247, 0.10214084666222334, 0.08829558387930904, 0.11596482380160264, 0.11420901944594723, 0.208591367783291, 0.11606527412576334, 0.1460562776774168, 0.13422297979039804, 0.11435046685593468, 0.09361117971794945, 0.1346755897892373, 0.12729570721941336, 0.14634240232408047, 0.12494264276964323, 0.11625503322907857], [0.054328789202762504, 0.10996694064566068, 0.10094720856951815, 0.01969204467189099, 0.01819174607018275, 0.06329657603055239, 0.04390313596065555, 0.03672381477164371, 0.05313060153275728, 0.06556865732584681, 0.02471484925730952, 0.04771687595971993, 0.06468677893280983, 0.020497129864192436, 0.049873311139111004, 0.022001662524417043, 0.024894253916240165, 0.005457206945201116, 0.010488239615889532, 0.08929328141467911, 0.06166446182344641, 0.02022997196763754, 0.04691252697791372, 0.08701436727174691, 0.04732618906668254, 0.015413316498909677, 0.02408000171583678, 0.020877708281789507, 0.033829275984317064, 0.04194516548886895, 0.07048370037227869, 0.11285623096461807, 0.011831307234907789, 0.025577226553910544, 0.08316909575036593, 0.019074459061292664, 1.2634053890194212, 46.696247577667236, 108.15306064060756, 87.28447273799351, 76.98141983577183, 65.96482862745012, 63.57894229888916, 35.72045619147164, 14.096121413367134, 20.831481048039027, 120.15949222019741, 221.23168536594935, 104.39478002275739, 55.53155606133597, 62.29954964773995, 56.66359479086739, 46.53058862686157, 14.208917600767952, 1.4279346061604363, 0.5281744269388062, 0.277070302516222, 0.05434031072737915, 0.03501897857391408, 0.04418919275381735, 0.018895736330055764, 0.13518891510154518, 0.28073572154556004, 0.9341507766927991, 1.2192237483603614, 4.9202300395284375, 6.9651343907628736, 12.579295788492475, 22.65232423373631, 37.82671226773943, 67.94907433646065, 85.57477814810616, 93.46680613926479, 94.26340321132115, 104.65069607325962, 109.39148671286446, 113.15820244380406, 103.38973004477364, 64.13015678950718, 33.66390405382429, 6.450132608413696, 2.3756090743201117, 12.128782408578054, 18.82730790546962, 9.943571346146719, 9.489393660000392, 5.749365959848676, 5.60398576089314, 2.2881075867584775, 0.8357072334204401, 4.3600106835365295, 45.688216822487966, 107.56709820883614, 134.3129449571882, 136.80629212515694, 132.7201121194022, 137.73034695216586, 141.77758925301688, 136.06887980869837, 130.15981210981096, 110.95349734170097, 111.63260037558419, 88.93824822562081, 71.56852299826485, 40.48677798679897, 18.981184448514664, 4.001091497285025, 0.8245659598282405, 0.9370986585106168, 5.75736767905099, 7.383045520101275, 0.25569786078163553, 0.4209521875849792, 0.12582237699202128, 0.2112563954932349, 0.6694920467478889, 16.786239828382218, 48.463007722582134, 60.39751502445766, 59.6916892187936, 64.85611152648926, 45.711017336164204, 26.223993607929774, 15.893062795911517, 32.020662035260884, 40.462504455021445, 69.44496590750558, 72.43133640289307, 70.67640904017857, 73.5482245853969, 55.93970019476754, 40.392650740487234, 18.33274381501334, 2.507486317838941, 0.12719835101493768, 0.07563445291348866, 0.04708733795476811, 0.044000332709401846, 0.0932364926806518, 0.030607150668012242, 0.023259238971929466, 0.043152445528124056, 0.023073055748162524, 0.017938849283382297, 0.06290713764194932, 0.05147698115823524, 0.04887162721050637, 0.02285153272428683, 0.03584945793928845, 0.05865426334951605, 0.05951043205069644, 0.020238647037850957, 0.10113212293280022, 0.06637297916625227, 0.010225431976972945, 0.013805327604391744, 0.011378056868644697, 0.07844930794090033, 0.06603231387478964, 0.02662646900197225, 0.027535573612632494, 0.013925662397273948, 0.02055452035606972, 0.04140680223437292, 0.03663430243198361, 0.01108652599421995, 0.009696568212737995, 0.04718892482508506, 0.046114546047257524, 0.017432326284636344, 0.00795342616869935, 0.034866630498852046, 0.08530255912670068, 0.03361469267734459, 0.05890940608722823, 0.06448220062468733, 0.06962126200752598, 0.06738848146051168, 0.030604870790349584, 0.05315202288329601, 0.005837064419340874, 0.04068217093923262, 0.006760903842015458, 0.07237451284059457, 0.035441312340221236, 0.03840694124145167, 0.03593480746660914, 0.044566532863037925, 0.06311607214489154, 0.009477512511823858, 0.0368330589096461, 0.08257685003003903, 0.023980455539588417, 0.03677758867187159, 0.03137585281261376, 0.06719424402607338, 0.06514101741569382, 0.03727505662079368, 0.06734506200466837, 0.07953757633055959, 0.08677020323063646, 0.04370771108993462, 0.08475922899586813, 0.05273934127762914, 0.01312470100154834, 0.046660047490149736, 0.040107597663466416, 0.03243398406941976, 0.022129413705053072, 0.05781334133020469, 0.06957383240972247, 0.016304779199085066, 1.3046913679156984, 41.92476674488613, 117.16989081246513, 98.74823611123222, 88.76931667327881, 71.54063987731934, 77.94703878675188, 49.24929019383022, 29.73799467086792, 26.82987478801182, 83.39043126787458, 169.02829905918665, 69.07480062757219, 38.3659793308803, 52.73605258124215, 50.98581872667585, 49.842551708221436, 23.060487474714005, 3.113292370523725, 0.26164646872452324, 0.20429364911147527, 0.06559547302978379, 0.05086194683930703, 0.10570916733039276, 0.3261238517505782, 0.8397871830633709, 1.5275005549192429, 2.699144124984741, 2.6272930204868317, 2.9132420080048695, 7.136958565030779, 13.677653993879046, 22.479555538722447, 43.53935786655971, 74.58009460994175, 94.88249465397426, 101.67499106270927, 101.39082363673619, 113.09931646074567, 122.00072315761021, 123.3289408002581, 113.51775087629045, 75.84273515428815, 38.987916060856406, 8.879578062466212, 1.5447826789958137, 1.2836257325751441, 4.673043966293335, 1.0957640303032739, 2.50036267723356, 2.8586602168423787, 1.0114190876483917, 0.8123102060386113, 0.667627866779055, 7.213749187333243, 57.734725611550466, 120.06998552594865, 143.22002138410295, 142.7817429133824, 138.88745825631278, 143.5955159323556, 147.44442885262626, 142.17064884730746, 138.24230412074496, 121.36397634233747, 125.53616115025112, 102.50122914995465, 87.2824855531965, 53.199563435145784, 30.534873144967214, 7.148010109152112, 0.6461564132145473, 0.9168026447296143, 6.373079257352011, 10.092317513057164, 0.2579999943929059, 0.3852253646722862, 0.00665360116233517, 0.12111559669886317, 0.6884904301592282, 21.332166501453944, 51.8128593308585, 58.53201402936663, 47.143475328172954, 44.08057737350464, 26.352757624217443, 26.835653952189855, 30.048791067940847, 49.4111658505031, 59.90679849897112, 88.89118112836564, 86.52040018354143, 80.21108150482178, 82.2998628616333, 62.51700047084263, 41.6155024256025, 18.18396030153547, 2.1724850024495805, 0.116573605420334, 0.057250876511846266, 0.03851775958069733, 0.044535744336566756, 0.052844995965382884, 0.06944429328931229, 0.05059445137158036, 0.027349013801930205, 0.08413282582270247, 0.03894840879365802, 0.030262865392225127, 0.03143030524786029, 0.0384721891688449, 0.011757543693030519, 0.024566312852714742, 0.05877158883959055, 0.01567370431231601, 0.052584774393056116, 0.02389402374891298, 0.05427297630480357, 0.013788202228689832, 0.010703849207077707, 0.012856264914652067, 0.042823362829429765, 0.021998889012528316, 0.05478058835225446, 0.021878313339714493, 0.060063356666692665, 0.03996135301089712, 0.014815784990787506, 0.02260990470780858, 0.04790862656331488, 0.0542538348319275, 0.1251632616456066, 0.018394874009702886, 0.04208801407366991, 0.026884548099977628, 0.039014613455427546, 0.00978197796004159, 0.0715799822605082, 0.04528614299904023, 0.028256500106570975, 0.18859439795570715, 0.1874423540596451, 0.20335822073476656, 0.14411650890750544, 0.11688958560781819, 0.17294081220669405, 0.059779301551835876, 0.20634898596576282, 0.1316377885107483, 0.197387641827975, 0.14199361710676126, 0.14124900634799684, 0.20554013151143277, 0.24465703751359666, 0.11824609924639974, 0.10982799702989203, 0.10347979302917208, 0.23109944643718855, 0.11835667331303869, 0.16893520286040647, 0.11291357395904404, 0.21552923907126698, 0.25754885002970695, 0.22677911897855146, 0.14966474047728948, 0.09470166013176952, 0.16031509398349694, 0.13701869334493363, 0.0940779507426279, 0.09561707851077829, 0.19805160191442284, 0.18053636034684523, 0.07513493578881025, 0.13403437419661454, 0.21021820977330208, 0.09958059154450893, 3.7362569996288846, 82.42736230577741, 129.48812975202287, 103.10019166128976, 100.39400032588414, 85.34336144583565, 81.91412666865757, 52.82123749596732, 21.0605423109872, 33.51144320624215, 136.33139664786202, 220.67124366760254, 122.88481194632394, 82.09445326668876, 89.92854022979736, 81.1368386404855, 73.93516976492745, 24.466865403311594, 3.159239722149713, 0.7500265538692474, 0.5171560496091843, 0.1351021576140608, 0.1301708229418312, 0.1042650616062539, 0.1896035016647407, 0.5091175266674587, 0.5599983707070351, 3.450142992394311, 6.884860549654279, 17.542207309177943, 23.207639898572648, 22.080650772367203, 31.076961176736013, 44.41420555114746, 77.34503296443394, 98.15154566083635, 103.0495115007673, 102.20925889696393, 117.65034484863281, 124.54384722028459, 127.79374204363141, 114.39620467594692, 78.6252246584211, 43.73773241043091, 20.108560936791555, 22.141499621527537, 36.09811857768467, 38.99906097139631, 33.56083795002529, 21.75828215054103, 16.766060522624425, 12.756156972476415, 9.41783503123692, 3.081925379378455, 6.090820848941803, 58.52614280155727, 126.24547495160783, 152.32858167375838, 153.0681757245745, 147.10609327043807, 153.61584663391113, 158.34294237409318, 150.35554340907504, 141.9791703905378, 115.86280958993095, 122.95383535112653, 100.01958969661167, 86.11176272800991, 48.828955445970806, 26.138141666139873, 7.657311763082232, 1.1870447950703757, 1.2206738591194153, 7.218206022466932, 7.788571051188877, 0.3142524201955114, 0.513139502278396, 0.12771224629666122, 0.44658531355006353, 1.6080395132303238, 28.52393593106951, 72.34219796316964, 85.09159346989223, 84.75070789882115, 91.21312318529401, 61.6903315952846, 38.56216171809605, 27.817606381007604, 45.9834874698094, 58.14438445227486, 91.45902688162667, 91.88890498025077, 91.68225860595703, 94.27885600498745, 77.27666963849748, 59.15962396349226, 29.18270853587559, 5.077136431421552, 0.385343212634325, 0.24413459269063814, 0.06921193575752632, 0.16286574783069746, 0.17622232969318116, 0.1497169333909239, 0.06376741826534271, 0.15340869314968586, 0.16567379715187208, 0.1244717123253005, 0.1220145606036697, 0.16259218965257916, 0.06577966814594609, 0.15445346065929957, 0.16259832360914775, 0.3015214747616223, 0.10664063306259257, 0.09909159171261958, 0.11833821716053144, 0.1443112213164568, 0.17442783527076244, 0.05557820287400058, 0.05292553807209645, 0.13096926866897515, 0.21364528659198964, 0.08330932858267001, 0.11153625643679074, 0.09350823238492012, 0.13188284821808338, 0.14697904459067754, 0.10748323106339999, 0.08953483988131795, 0.19002362340688705, 0.14863948763481208, 0.11664341310305254, 0.13201684531356606, 0.09344244162951197, 0.0864264438194888, 0.12328880865659032, 0.10479656487171139, 0.17599565828485148, 0.08787119415189538], [0.13594203468944344, 0.0569877474169646, 0.043907149495290856, 0.05646265630743333, 0.0681131025776267, 0.060343204864433835, 0.09446005416767937, 0.028718098998069763, 0.04793847531878522, 0.06457953647311244, 0.03897251035752041, 0.023511728637718728, 0.04596383663426552, 0.032643162844968696, 0.05063688355897154, 0.053975720291158984, 0.022128412865900567, 0.053514879662543535, 0.04982474838782634, 0.01973231233257268, 0.056267584274922094, 0.03267048405749457, 0.022410345862486532, 0.03120425809174776, 0.05432825316009777, 0.007803660767552043, 0.04534835448222501, 0.015493593976965972, 0.04642744568575706, 0.01588326646015048, 0.2024869274880205, 0.07305453385093383, 0.09923428762704134, 0.07563828663634402, 0.025032211959894215, 1.6456684597900935, 48.52619811466762, 93.64267199380058, 93.85595389774868, 84.26197855813163, 67.13311958312988, 47.19223083768572, 12.548113141741071, 23.898443698883057, 49.32712738854544, 120.1915512084961, 77.45395292554582, 50.28767762865339, 44.56093760899135, 65.2262212208339, 43.04087325504848, 15.074670961924962, 2.3237874550478796, 0.10839641706219741, 0.08522594573774508, 0.03391623363963195, 0.041464928936745436, 0.05212790319429977, 0.010759243109662617, 0.03900256945884653, 0.16849353084606783, 0.4974805425320353, 1.3590331205299921, 2.6604446130139485, 14.606581245149885, 24.779556921550206, 37.2276941708156, 52.84799153464181, 75.89521489824567, 107.98427500043596, 102.18232767922538, 104.29886014120919, 102.45819895608085, 104.32379722595215, 98.12740067073277, 94.90770271846226, 93.68361772809709, 104.69739491598946, 119.04098510742188, 120.5303453717913, 92.04703208378383, 25.47415964944022, 4.700725589479719, 1.4099351891449519, 3.01557485972132, 6.18311333656311, 8.83466751234872, 21.90531645502363, 16.81779507228306, 28.498514209474834, 83.79574748447963, 123.91063008989606, 107.16896642957414, 102.52226829528809, 97.84479658944267, 101.49024541037423, 96.76393481663295, 102.85722705296108, 96.92472308022636, 104.22202696119035, 108.67371695382255, 114.35769775935582, 110.15583024706159, 120.63969612121582, 123.83086477007184, 137.30124010358537, 107.0592404774257, 57.07421595709664, 5.020323617117746, 3.6609793475696017, 18.634926182883127, 0.12831167770283564, 0.02885522074731333, 0.057492971021149836, 0.3315838873386383, 0.1431852195944105, 0.2171630428305694, 2.206803023815155, 24.293778828212194, 57.60320316042219, 52.73890134266445, 82.11999484470913, 61.50466878073556, 30.72004611151559, 13.930861115455627, 9.545124292373657, 11.064905507223946, 30.456417560577393, 55.13522039140974, 66.79097638811383, 68.2354929787772, 66.16862624032157, 52.32455941608974, 28.980844259262085, 4.834696412086487, 0.39634761214256287, 0.032010540898357115, 0.01839113697808768, 0.04753690811672381, 0.027013481627883654, 0.020754087683079497, 0.07731220538594893, 0.030685216121907746, 0.05891356550689254, 0.06957249569573573, 0.06019369645842484, 0.006862172224958028, 0.059896240276949744, 0.013311752750139152, 0.005798040598165244, 0.018290265962215405, 0.01309352316561022, 0.05373803286680153, 0.04058186989277601, 0.01754348898040397, 0.04246097084667001, 0.06226901616901159, 0.03999786837292569, 0.024638861816908633, 0.009300807574098664, 0.08528633535440479, 0.029247933067381382, 0.03013536866222109, 0.061671783216297626, 0.06309820631785051, 0.02474164799787104, 0.041495680143790584, 0.03723505698144436, 0.03632167760016663, 0.04247879256893482, 0.050161769946238825, 0.015396207238414457, 0.06832715323460953, 0.06231409125030041, 0.05104804524619665, 0.038863731016005786, 0.03990077679710729, 0.024960987835324237, 0.017283655869375383, 0.00894615682773292, 0.07728216664067336, 0.03926653315180114, 0.06915174970137221, 0.017113701506916965, 0.07156687296394791, 0.06266956896122013, 0.029050157072820833, 0.03929584925728185, 0.0396760086795049, 0.025713669768135463, 0.04881032157157149, 0.03192956792190671, 0.05604172371593969, 0.06618557457945176, 0.03510940354317427, 0.01734800304153136, 0.01499851786398462, 0.025737067351916006, 0.016477959995557154, 0.014901195586259876, 0.00538913716029908, 0.09362188700054373, 0.07982154323586396, 0.03754908638074994, 0.07328827559415783, 0.01801778665477676, 0.03084941141839538, 0.09161380332495485, 0.03627677554530757, 0.013900437009786921, 0.058107384480535984, 1.2054009586572647, 49.20279632295881, 106.6794102532523, 106.563278062003, 95.65716321127755, 73.71538434709821, 62.84033489227295, 41.87681722640991, 35.66595452172415, 22.354679039546422, 52.966704981667654, 77.20736135755266, 82.11672919137138, 52.09870474679129, 40.22549792698452, 42.44986643110003, 22.902563605989727, 4.2177081022943765, 0.16836615625236714, 0.1251614974545581, 0.06802673864045314, 0.1415739431977272, 0.2265706458794219, 0.7195804161684853, 0.34585081892354147, 1.9021779298782349, 2.6936915261404852, 3.8981226682662964, 4.784101801259177, 13.412590639931814, 25.78447835786002, 39.085020610264365, 56.67695965085711, 87.38114302498954, 114.09478487287248, 107.71149567195347, 107.75692299434117, 107.5334689276559, 107.0663901737758, 101.64005552019391, 97.23129149845668, 96.82509286063058, 107.26335770743233, 123.33818190438407, 126.33424513680595, 100.14175292423793, 32.140612261635916, 2.853871605225972, 1.162493769611631, 1.9869987155709947, 4.9993074876921515, 9.420087116105215, 22.943637881960186, 20.59624457359314, 34.855704239436555, 93.1626626423427, 128.11681938171387, 112.28347287859235, 105.24166120801652, 101.95284257616315, 105.86477565765381, 102.41652366093227, 107.24236719948905, 100.22237287248883, 109.24145426068986, 112.06403487069267, 119.63088716779436, 114.81006717681885, 124.78906304495675, 129.931341443743, 144.7909951891218, 119.10385240827287, 71.76972893306187, 8.732178109032766, 3.0885698114122664, 18.199282816478185, 0.03922311030328274, 0.11770724744669028, 0.07967943764690842, 0.16257707189236367, 0.05754907229649169, 0.0781323845897402, 2.5081846117973328, 25.606729541506084, 52.59734221867153, 41.830865315028596, 55.0444769178118, 44.32494551794869, 27.605133942195348, 25.44853469303676, 17.382932015827723, 22.868830101830618, 41.38076448440552, 66.32698958260673, 75.4838537488665, 78.62080560411725, 76.74787698473249, 59.355271339416504, 29.23843308857509, 5.233917321477618, 0.2716651739818709, 0.050324506392436366, 0.09266541046755654, 0.03740634636155196, 0.04378023969807795, 0.024261910168986236, 0.06998202550624098, 0.03349942993372679, 0.02486231696924993, 0.04948496858456305, 0.028700399412108318, 0.03228443155863455, 0.025326321267389824, 0.05855942450995956, 0.03684283999193992, 0.02932816304798637, 0.053124202947531424, 0.04534167430496641, 0.08711521114621844, 0.019931201124563813, 0.00256664797780104, 0.03194465175537126, 0.06874156849724905, 0.08280631700264555, 0.04794105375185609, 0.08641925134829112, 0.02665917608620865, 0.034679985871272426, 0.13090203941932746, 0.08071396606309073, 0.034414220667843304, 0.06094575074634381, 0.049787842868162055, 0.019437994375558834, 0.014073538926563092, 0.062280110216566494, 0.03529259103483387, 0.016575955719287907, 0.04054079816809722, 0.01939526872177209, 0.06589017435908318, 0.11609631031751633, 0.20449913665652275, 0.13341283611953259, 0.12033677420445851, 0.2175809796899557, 0.09228062004383121, 0.24640049253191265, 0.11499907848026071, 0.14350612594613008, 0.10907297754394156, 0.1388668870287282, 0.15753893580819878, 0.07825952848153454, 0.14255733042955399, 0.12040754540690354, 0.12789095884987287, 0.18842673195259912, 0.1399128759013755, 0.13486562030655996, 0.157810634800366, 0.11191595106252603, 0.09888171404600143, 0.1170580115701471, 0.15307739164148057, 0.1528681857245309, 0.1770540779190404, 0.08557604945131711, 0.13971608717526707, 0.11651453216161047, 0.1416841779968568, 0.30344324878283907, 0.16962776998324053, 0.17048224913222448, 0.16271058044263295, 0.19657890950994833, 5.343760524477277, 86.11978789738247, 121.37758091517857, 112.27888011932373, 111.21272768293107, 82.70237200600761, 67.70335129329136, 27.296371630259923, 36.53475032533918, 69.78406579153878, 135.4533805847168, 87.81862245287213, 59.76613221849714, 60.74147169930594, 100.67459637778146, 70.55299513680595, 27.544078384126934, 5.468031661851065, 0.5128822017993245, 0.16745706860508236, 0.16535343362816743, 0.20797475587044442, 0.26228928565979004, 0.3518403832401548, 0.22455051142190183, 1.739402915750231, 2.662833056279591, 8.662778632981436, 12.093187655721392, 28.355188505990164, 39.62336356299264, 50.71483203342983, 62.83911200932094, 88.02903475080217, 123.0703705378941, 111.74652303968156, 113.11111450195312, 108.45103413718087, 110.13921015603202, 107.29557650429862, 102.90251541137695, 101.27984006064278, 116.20530714307512, 129.6256762913295, 133.00861522129603, 101.1556201662336, 34.016083921704976, 18.942050457000732, 18.061103991099767, 16.035761424473353, 9.15022429398128, 12.085427386420113, 29.323506832122803, 24.28211280277797, 39.27071121760777, 102.14327880314418, 136.45722852434432, 117.05774688720703, 107.11847387041364, 105.16286863599504, 110.70131247384208, 105.4548110961914, 111.07088020869664, 104.7364090510777, 115.54795891898019, 120.77800696236747, 127.09104292733329, 123.914521081107, 136.86724172319686, 141.81863921029228, 155.86957822527205, 118.75695664542062, 66.21340043204171, 8.006892136165074, 6.83092211825507, 23.505121810095652, 0.19130836161119597, 0.19198023341596127, 0.26960427314043045, 0.3991385352398668, 0.24040826835802623, 0.3159399096454893, 4.850147034440722, 40.10040603365217, 83.71992874145508, 73.04528617858887, 114.51153087615967, 87.42908559526715, 44.496916907174246, 22.351734740393503, 16.605607509613037, 21.14014608519418, 47.624620710100444, 73.76321574619838, 86.44085720607212, 89.82180200304303, 83.2765919821603, 72.58758749280656, 44.55369063786098, 14.703034400939941, 0.8927356590117727, 0.2857780238347394, 0.17236989284200327, 0.14974644966423512, 0.15764029536928448, 0.0989554300904274, 0.1562847995332309, 0.07875574114067213, 0.14570238095309052, 0.14542746570493492, 0.21327962407044002, 0.11685736876513277, 0.12240106772099223, 0.2308601135654109, 0.19296664691397122, 0.1266228040414197, 0.12474657329065458, 0.16503999116165297, 0.20752066666526453, 0.08480526759688344, 0.10059502175343887, 0.13294550191078866, 0.12429248408547469, 0.20198357664048672, 0.13299139801945004, 0.23770080506801605, 0.18877602820949896, 0.10220731595265013, 0.13670222461223602, 0.22503883950412273, 0.11606350993471486, 0.10783827451190778, 0.16804807260632515, 0.07529055779533726, 0.11340510472655296, 0.13878403790295124, 0.1463844036417348, 0.1208095909761531, 0.18371164639081272, 0.06747494039258786, 0.14701042004993983], [0.09319590271583625, 0.018454888735764792, 0.01719762950337359, 0.060828384544168196, 0.05388844372438533, 0.036958330044788976, 0.07164048722812108, 0.07868501065032822, 0.09411137537764651, 0.04272408297817622, 0.05019427177363208, 0.0920632513506072, 0.027769680068429028, 0.06334703189453908, 0.04522358546299594, 0.109882429109088, 0.0464559882613165, 0.08663271846515791, 0.040402655223650594, 0.034063363780400584, 0.033150418661534786, 0.05197864245357258, 0.06711603607982397, 0.08500768816364662, 0.16768762123371872, 0.052220353590590615, 0.031049569070871388, 0.08386922175330774, 0.04515773363943611, 0.08558570500463247, 0.09512539168021508, 0.07255796156823635, 0.11742166562804154, 0.045649403506623845, 10.479619656290327, 63.35288265773228, 79.35752310071672, 72.62550381251744, 90.65958104814801, 66.07412379128593, 42.05132123402187, 22.129093612943375, 33.282183919634136, 38.774189472198486, 69.10126631600517, 67.65072563716343, 63.265960693359375, 39.213760307856965, 30.86834498814174, 22.730587005615234, 5.316363777433123, 0.33198870133076397, 0.21619093285075255, 0.08085978323859827, 0.05314695083403161, 0.243689555142607, 0.040200485714844296, 0.24871418837990078, 0.08939063083380461, 0.6912122241088322, 2.298429787158966, 4.499538327966418, 21.893025091716222, 28.281921488898142, 47.613302094595774, 59.548445156642366, 75.15034716469901, 98.0634286063058, 101.92253453390938, 87.80952726091657, 89.61183438982282, 88.10952963147844, 100.12843322753906, 100.8111493246896, 101.82676751273019, 87.17553193228585, 85.82763004302979, 88.1657405580793, 90.14122458866665, 87.17047364371163, 95.77562304905483, 110.46005017416817, 32.95015730176653, 11.669509955814906, 44.76905352728707, 89.15158571515764, 128.63971301487513, 142.63412148611886, 130.52895600455147, 57.34011309487479, 80.95954840523856, 111.51214640481132, 111.20892701830182, 118.92458888462612, 105.6195320401873, 101.31284400394985, 97.46512617383684, 97.15784209115165, 101.89077431815011, 107.68684346335274, 100.57060268947056, 100.0935115814209, 97.4280366897583, 90.48208931514195, 89.33340617588588, 88.80839334215436, 107.42059544154576, 119.01335906982422, 117.0317050388881, 42.302345752716064, 18.945807695388794, 6.595224457127707, 0.12824934747602257, 0.09342685568013362, 0.14630535431206226, 0.08275772032460996, 0.07854565312819821, 0.03807906633509057, 0.5057147549731391, 10.051555906023298, 34.13584654671805, 45.052571296691895, 55.654136180877686, 66.23991475786481, 42.566384247371126, 94.31174182891846, 107.78973933628627, 45.707946232386995, 27.448589290891373, 49.21931219100952, 63.892215728759766, 64.55986813136509, 69.29816436767578, 69.15246064322335, 53.12548868996756, 22.363970518112183, 2.3655515568596974, 0.08964191270726067, 0.025629136179174696, 0.10331600824637072, 0.014186558263775493, 0.03805878831605826, 0.019347487982096415, 0.021151220658794045, 0.014594838721677661, 0.07977942656725645, 0.0077258981099086145, 0.039299224968999624, 0.0714466908414449, 0.12942743354610034, 0.02564294945581683, 0.09083516403500523, 0.13641620853117534, 0.04801308024408562, 0.04001640934231026, 0.05530121809403811, 0.06958417328340666, 0.11289015771555048, 0.0831624868192843, 0.08736283571592399, 0.10180210841021367, 0.04682718423594322, 0.0570665660447308, 0.08362161075430256, 0.1344507775668587, 0.24720127241952078, 0.14585692408893788, 0.07722557682011809, 0.0884150874667934, 0.19384617757584366, 0.18136675150266715, 0.3085874670318195, 0.3258134898330484, 0.07626287812100989, 0.018405282736888955, 0.06958821735211781, 0.12201143934258393, 0.024264166297923242, 0.07533689495176077, 0.023608862621975795, 0.08985619406614985, 0.08562572500003235, 0.030856573355517218, 0.019490236482982124, 0.02936615761635559, 0.017939025702487146, 0.037399058895451684, 0.033886144004229984, 0.07231365503477198, 0.04420782532542944, 0.10244246226336275, 0.11077498764331851, 0.0561676801714514, 0.12870191676276072, 0.03289099097517984, 0.0474830426142684, 0.029527153620230298, 0.027791910571977496, 0.05968476126768759, 0.12470835819840431, 0.161562906312091, 0.08824476160641227, 0.023033088339226584, 0.08290505063320909, 0.010553308579671596, 0.04552872605355723, 0.0823878508859447, 0.044994284731468985, 0.06182397183563028, 0.08892082675759282, 6.801545134612492, 60.054954937526155, 93.07314205169678, 86.9529811314174, 103.30539975847516, 75.15444660186768, 67.48827675410679, 31.549872943333217, 23.65142134257725, 30.82266058240618, 46.55733571733747, 64.71397917611259, 42.21665709359305, 36.57470941543579, 36.55104385103498, 30.498165811811173, 10.22707348210471, 0.2984618789383343, 0.16877672422145093, 0.030415515415370464, 0.03593634095575128, 0.5886689722537994, 0.6247208948646272, 0.9926427751779556, 0.9016266390681267, 1.9682209917477198, 2.0321218371391296, 5.085283628531864, 14.029402204922267, 26.948284251349314, 51.54796620777675, 63.12338365827288, 79.4058061327253, 103.4228868484497, 105.98728629520961, 93.86484759194511, 96.0344295501709, 95.25964287349156, 105.88997677394322, 108.73743888310024, 108.32497991834367, 97.51162351880754, 89.53762762887138, 92.67483656747001, 94.54534026554653, 94.3351503099714, 100.27687454223633, 120.0055479322161, 41.162882872990195, 16.823603766305105, 53.82058300290789, 100.07162475585938, 140.52598244803292, 153.1285138811384, 145.1967977796282, 64.88371671949113, 85.52743312290737, 117.1054254259382, 119.27619552612305, 123.24767466953823, 110.68178108760289, 106.35755579812187, 101.57709789276123, 103.8214007786342, 107.9388268334525, 112.01913561139787, 105.88606493813651, 106.2300910949707, 102.83255399976457, 94.67220047542027, 94.02242578778947, 94.40069961547852, 108.75033473968506, 122.52351951599121, 128.28200585501534, 55.70372894832066, 23.098075492041453, 10.556705577032906, 1.0621393088783537, 0.1379545559840543, 0.3334627779466765, 0.1473771139447178, 0.06515872039433036, 0.06360950959580285, 0.7479878004108156, 13.193432297025408, 34.596984590802876, 46.89109591075352, 42.78221961430141, 40.1723198890686, 24.870550530297415, 50.395496300288606, 70.61234664916992, 54.81060750143868, 38.7860153062003, 51.96972533634731, 74.13049752371651, 71.72485746656145, 77.31960950578961, 77.19674451010567, 57.66999966757638, 21.841441665376934, 2.073989076273782, 0.10975782293826342, 0.0660467938120876, 0.132051409887416, 0.09570013798241105, 0.026090182064633285, 0.02179977630398103, 0.027349403959565928, 0.034624125475862196, 0.030518751125782728, 0.016417801080803787, 0.05095304695091077, 0.03860891397510256, 0.18257534450718335, 0.013720570947043598, 0.13448849054319517, 0.10932761816573994, 0.08554008030997855, 0.05813346736665283, 0.03410127353189247, 0.049100039061158895, 0.08084377659750835, 0.08490135494087424, 0.086447627682771, 0.050274952980024476, 0.04560083396998899, 0.022661726123520305, 0.10364318426166262, 0.1506524703332356, 0.17608895684991563, 0.18229971001190798, 0.015932709610621845, 0.15885996206530503, 0.10667291775877986, 0.04157295510438936, 0.23764136540038244, 0.2928993845624583, 0.046789969982845445, 0.043951203381376605, 0.0495780703744718, 0.1997658527855362, 0.11045843070106846, 0.13570757369909967, 0.1248270475438663, 0.17000549685742172, 0.175615665103708, 0.1364758246179138, 0.10027259548327752, 0.14724842299308094, 0.15453184502465384, 0.11171150846140725, 0.12046201819820063, 0.11534042230674199, 0.22317403528307164, 0.24499380801405224, 0.25309128207819803, 0.1742559080677373, 0.2561343487884317, 0.09494052481438432, 0.1423815084355218, 0.1372159027627536, 0.16551563063902514, 0.11164638267031737, 0.2642161079815456, 0.21280709228345326, 0.11022109950759582, 0.12230685991900307, 0.14770481921732426, 0.17954715128455842, 0.18445426225662231, 0.19306162824588163, 0.16182966556932243, 0.19108808200274194, 0.18282794952392578, 21.951579298291886, 101.6921739578247, 108.33686133793422, 95.46482317788261, 116.6561826978411, 85.87447479793003, 62.99626636505127, 35.836390359061106, 46.4599289212908, 60.07935701097761, 91.48437391008649, 90.65161146436418, 91.45744964054653, 64.10441371372768, 56.30355651038033, 40.36163050787789, 11.209446276937213, 1.258115638579641, 0.2743537468569619, 0.13174817258758204, 0.10535822223339762, 0.5381265271987233, 0.23147815040179662, 0.5538112712757928, 0.6720575062291962, 3.0954394085066657, 8.299474699156624, 16.418341398239136, 39.35352332251412, 37.22118023463658, 63.90114416394915, 67.64124134608677, 84.6431497846331, 107.36539895193917, 113.70966012137276, 97.98146765572685, 101.95109163011823, 99.72769587380546, 112.34174742017473, 113.83190672738212, 115.37027263641357, 99.06619262695312, 96.15620367867606, 96.23992947169712, 101.4386202948434, 99.8853018624442, 106.60729490007672, 123.89535794939313, 43.583485875810894, 16.883761269705637, 61.22943673815046, 111.18182209559849, 143.22555215018136, 151.16040883745467, 153.2286374228341, 84.77114255087716, 92.96103286743164, 120.13310296194894, 122.23102814810616, 130.0342859540667, 115.09768090929303, 114.01277528490338, 109.1495087487357, 112.17878437042236, 113.97305243355888, 116.82117462158203, 109.2476590020316, 108.91333947862897, 104.43090370723179, 99.64213575635637, 97.7435474395752, 99.48176438467843, 118.91170692443848, 132.64689200265067, 131.0094656263079, 51.21724237714495, 25.46819462094988, 11.259379506111145, 1.1933868718998772, 0.2977622279099056, 0.36656983143516947, 0.19272917322814465, 0.1829673070460558, 0.3272270139838968, 1.1034085686717714, 18.452103444508143, 54.39080776487078, 65.36336476462228, 74.81838308061872, 90.79039478302002, 59.955929211207796, 110.19908278329032, 122.38227653503418, 61.22537899017334, 43.04306541170393, 67.70644324166435, 82.89500386374337, 83.77725832802909, 88.53434944152832, 88.03489208221436, 76.2933258329119, 40.33196864809309, 6.322427323886326, 0.2929754619087492, 0.17473760007747582, 0.25269811174699236, 0.15341990254819393, 0.11840806555535112, 0.17922007026416914, 0.11405758400048528, 0.08572107274085283, 0.12349920879517283, 0.11627361151788916, 0.1613184708569731, 0.08996178768575191, 0.1931197244141783, 0.20029593791280473, 0.3394126072525978, 0.18610350947294915, 0.16351718216070107, 0.17344458374593938, 0.1812998615205288, 0.1314843310309308, 0.20932763256132603, 0.1594903753804309, 0.1953853935535465, 0.1867456343024969, 0.18147169372865132, 0.14067742201898778, 0.19930169412067958, 0.22504747046955995, 0.23859055446726934, 0.17940567673317023, 0.1263133649315153, 0.259592488940273, 0.22906430278505596, 0.21148124842771462, 0.27108711642878397, 0.3629778841776507, 0.17294501912380966, 0.06964644244206802, 0.14312602419938358], [0.027676766571987952, 0.07018842228821345, 0.02437070308120123, 0.0701654606631824, 0.03872391548273819, 0.07142591409917388, 0.1246922497770616, 0.08157987852713891, 0.1951497383415699, 0.14641792327165604, 0.0639761695638299, 0.10116038391632692, 0.05550285156017967, 0.0144354491494596, 0.08062431123107672, 0.006653588863887957, 0.03599432177309479, 0.06146267907960074, 0.05966908710875681, 0.10148756671696901, 0.1785770361976964, 0.4299641640058586, 0.2129446177610329, 0.0937862621088113, 0.07166291281048741, 0.03693886287510395, 0.09405855821179492, 0.15974536884043897, 0.005484287277795374, 0.01558898073355002, 0.08006720683936562, 0.06610900190259729, 0.31469167662518366, 9.254261408533369, 88.68336745670864, 99.50521455492292, 96.36873517717633, 74.93020738874162, 55.14872768947056, 37.08103854315621, 12.122060894966125, 37.502179282052175, 88.00515379224504, 70.90053708212716, 47.71930381229946, 32.38862126214163, 39.502006326402935, 34.204633712768555, 11.735071420669556, 0.4176594742706844, 0.24645257687994412, 0.02265875244380108, 0.050005204776035886, 0.06813897511788777, 0.10858084966561624, 0.2049575142030205, 0.3347461319395474, 0.8311275563069752, 2.1347115550722395, 2.115420315946851, 6.0112952419689725, 27.2553060395377, 42.77436467579433, 61.87001895904541, 79.04725129263741, 88.63692569732666, 95.33161926269531, 94.29442691802979, 93.46152550833565, 90.74054145812988, 81.60242353166852, 89.19694355555943, 99.18047659737724, 98.47034290858677, 98.87133734566825, 88.02784660884312, 73.36884294237409, 76.81637232644218, 77.91816902160645, 96.69484887804303, 81.29429176875523, 98.37412425449916, 84.46490069798061, 46.79278237479073, 99.34389822823661, 117.85128675188336, 90.55276639120919, 88.92642933981759, 103.89485713413784, 55.87142024721418, 84.65863731929234, 113.2759952545166, 99.50720173971993, 100.17439556121826, 100.2308566229684, 94.96858978271484, 85.87448174612862, 74.28664439065116, 78.29230867113385, 82.63218130384172, 86.45717157636369, 85.10966573442731, 89.04181112561906, 88.16811684199742, 91.38409750802177, 94.20574011121477, 93.98591995239258, 88.22672489711216, 99.0465361731393, 117.851870400565, 112.23498834882463, 80.77206516265869, 39.25481373923165, 8.318178381238665, 0.05978188677025693, 0.1344129695956196, 0.21799427536981447, 0.03437154420784541, 0.021029893508447067, 0.04230652949107545, 1.7412182411977222, 20.386975254331315, 46.237173148563926, 64.56459290640694, 78.9658670425415, 114.49193695613316, 121.1415228162493, 32.70487199510847, 32.175127438136506, 37.86033807482038, 29.001006194523402, 50.96712459836687, 62.167429651532856, 76.04528903961182, 70.40705517360142, 57.51531539644514, 40.523447104862754, 6.8885973777089795, 0.21860414264457567, 0.19199695251882076, 0.17694841644593648, 0.08278889222336666, 0.03944285047639694, 0.11037445520716054, 0.030606848719928945, 0.10031428467482328, 0.09409898532820599, 0.055204455607703755, 0.05921054671385458, 0.14921343326568604, 0.1969118123607976, 0.22289605305663177, 0.1024001691756504, 0.10548948483275515, 0.22488008945115975, 0.08035933652094432, 0.07325337853814874, 0.14806341140397958, 0.14139613988144056, 0.11738807814461844, 0.022651946737564037, 0.06900749994175774, 0.17991818780345575, 0.28025833144783974, 0.3227247984281608, 0.22586564799504621, 0.07495541577892643, 0.09105800172047955, 0.030914686487189362, 0.04801367735490203, 0.32297221943736076, 0.45568832222904476, 0.4106415222798075, 0.32626653409429957, 0.05728057598961251, 0.04950628476217389, 0.14596660248935223, 0.044580771920404265, 0.1059573075867125, 0.06972670634942395, 0.03230486224804606, 0.02613259050329881, 0.035334470216184855, 0.03419687572334494, 0.053207571152597666, 0.12700697699827806, 0.050906665689711056, 0.06927808613649436, 0.09762987800474678, 0.04097889769556267, 0.05753649904259613, 0.040312674694827626, 0.06945576731647764, 0.07622161640652589, 0.03252390353009105, 0.10240728022264582, 0.11054523568600416, 0.2706321451280798, 0.16262108167367323, 0.043851004115172794, 0.11300346627831459, 0.025821799412369728, 0.037199284615261216, 0.18003364732222898, 0.0890830916219524, 0.030907222601984228, 0.041590586836848936, 0.11044093128293753, 0.152835005362119, 7.317142724990845, 94.43624659946987, 115.58852250235421, 107.9332196371896, 83.07155758993966, 74.89899608067104, 51.56895671572004, 23.885457515716553, 25.695961781910487, 41.65633698872158, 48.70427349635533, 41.33804695946829, 33.80137068884713, 41.81981073107038, 41.16561351503645, 17.34600928851536, 1.1345951237848826, 0.5404151443924222, 0.026232850837654302, 0.06486701140446322, 0.4416066035628319, 0.31852282104747637, 0.7035097213728088, 1.2719816373927253, 2.9365371465682983, 4.257245523588998, 2.1564728787967136, 7.613076056752886, 27.689203671046666, 46.61893844604492, 66.56208188193185, 81.65338856833321, 93.67801053183419, 99.04557732173375, 101.11393792288644, 98.94348743983677, 95.13731288909912, 86.3580902644566, 92.38224792480469, 103.0931670325143, 103.41142926897321, 101.61465290614537, 88.47904178074428, 75.98920318058559, 80.71652821132115, 83.25862394060407, 97.73106152670724, 83.85165269034249, 100.40344987596784, 88.84546198163713, 49.7717148235866, 114.56357983180455, 125.90298434666225, 100.94283853258405, 93.50413881029401, 111.98375538417271, 64.25013133457729, 91.25185939243862, 117.59965079171317, 103.76411982945034, 105.53584098815918, 104.7099781036377, 100.14029380253383, 88.71790000370571, 78.16546930585588, 82.83494363512311, 84.74831077030727, 89.15156487056187, 90.60933862413678, 92.2525806427002, 91.08092675890241, 94.97015312739781, 99.06972926003593, 98.33737523215157, 93.69424847194126, 98.9161879675729, 124.95330456324986, 122.69272204807827, 90.53521524156842, 49.06294298171997, 11.854161807468959, 1.0787939237696784, 0.1560568253376654, 0.5013757678014892, 0.12031036562153272, 0.13784995302557945, 0.23492510829653057, 2.236402132681438, 23.726927416665212, 45.69820485796247, 51.65818548202515, 50.51038128989083, 113.33324841090611, 141.4506904057094, 53.36274535315377, 36.25629779270717, 52.95731101717268, 46.105876513889854, 61.14229243142264, 72.70097514561245, 82.22029209136963, 80.60475948878697, 69.79451588221959, 44.45864970343453, 6.740692377090454, 0.11480165193123476, 0.16016865255577223, 0.20341567908014568, 0.02691735526812928, 0.016844959231093526, 0.061752053909003735, 0.010823636082932353, 0.027206674118393233, 0.0708107203245163, 0.03815725053261433, 0.04880703406940613, 0.15404111492846692, 0.07951439078897238, 0.14786731478359016, 0.08029957115650177, 0.07110200183732168, 0.1362276165080922, 0.09881016931363515, 0.028049228014424443, 0.14453710562416486, 0.14954420551657677, 0.1151831786015204, 0.03730613352464778, 0.08768518056188311, 0.13000701101762907, 0.1762499732098409, 0.2808843749974455, 0.15058483396257671, 0.16186288664383547, 0.08461947113807712, 0.054105123704565425, 0.06581062969884702, 0.3519935150231634, 0.3439236437635762, 0.3797917105257511, 0.3649117632636002, 0.049507244889225276, 0.11451974777238709, 0.23556208983063698, 0.18419641894953592, 0.16874233606670583, 0.2502348667808941, 0.11153503507375717, 0.16962558510048048, 0.20068490132689476, 0.23162859518613133, 0.4782337067382676, 0.33590403837817057, 0.19046894593962602, 0.15724610723555088, 0.3414126027907644, 0.23051069517220768, 0.18056975784046309, 0.14441406008388313, 0.14346601095582756, 0.25342506702457157, 0.20062552951276302, 0.18819892060543808, 0.27251630116786274, 0.4550193138420582, 0.30101498908230234, 0.2570167971508843, 0.2987813060837132, 0.09275663271546364, 0.20944428630173206, 0.34050629713705605, 0.18643581521298203, 0.11168579876955066, 0.20006032341292926, 0.28841426808919224, 0.4550429811435086, 23.722711597170147, 128.94025039672852, 126.48646627153668, 124.27963502066476, 103.84240518297467, 81.72235638754708, 59.395584787641255, 24.497970751353673, 60.06766319274902, 131.76939010620117, 100.78996426718575, 67.27225031171525, 48.17106873648507, 63.98566205160958, 55.71982445035662, 20.803420748029435, 1.6644863528864724, 0.7669039996606963, 0.10432744611586843, 0.17687102274170943, 0.3832064787192004, 0.312700556325061, 0.34095478164298193, 0.7489338953580175, 4.538661028657641, 9.880935072898865, 10.155761514391218, 15.727977071489606, 38.62415354592459, 53.61026450565883, 71.88310268947056, 85.77359390258789, 99.50952243804932, 105.4518928527832, 107.9048501423427, 106.9500981739589, 101.90850612095424, 93.48368331364223, 97.87675830296108, 109.12073625837053, 106.81143992287772, 107.49753979274205, 94.95298412867955, 82.2750299998692, 85.53213010515485, 86.29504231044224, 101.42485591343471, 86.765761920384, 104.79964460645402, 97.20059435708183, 64.89015075138637, 126.67847279139927, 125.12525858197893, 104.29999269757951, 101.43397194998605, 111.4233831678118, 71.23823343004499, 95.48293018341064, 123.48687335423061, 106.41131401062012, 109.80820492335728, 106.67975766318185, 103.14869008745465, 93.35047245025635, 81.81892939976284, 86.63146713801792, 91.39161545889718, 96.590806552342, 97.25723607199532, 99.93345287867955, 97.30397660391671, 102.3771412713187, 105.29628794533866, 100.723678452628, 96.32847731454032, 104.48355020795549, 129.77684129987443, 125.3567864554269, 87.23585619245256, 46.91553272519793, 11.520110658236913, 1.348460350717817, 0.19241312518715858, 0.43679245188832283, 0.22337575017341546, 0.15109172676290783, 0.37654758031879154, 3.538906229393823, 36.36389412198748, 73.2839081627982, 90.49814660208565, 106.92114503043038, 123.88054438999721, 131.15951892307825, 45.60185071400234, 47.088191986083984, 52.28977673394339, 44.61628001076834, 69.73835359300885, 82.37496594020298, 95.44681344713483, 90.99421324048723, 82.8468736921038, 63.62944180624825, 12.38790157863072, 0.37081366085580414, 0.24647293293050357, 0.24574915319681168, 0.16940274062965596, 0.16130183317831584, 0.15568255899207933, 0.12766525096126966, 0.2106679156422615, 0.22930222430399486, 0.10515567953033106, 0.1695259218769414, 0.27906047286731855, 0.31670060168419567, 0.4390151969024113, 0.18939331865736417, 0.24459143674799375, 0.3391821767602648, 0.12744467279740743, 0.1464786385851247, 0.2426495509488242, 0.2541755267551967, 0.27463938295841217, 0.10368836790855442, 0.16310242084520205, 0.3221686711268765, 0.39389397523232866, 0.48509364149400164, 0.2368304617702961, 0.30762362160852974, 0.1197210850992373, 0.13167812063225678, 0.12489179335534573, 0.39346788238201824, 0.45821420954806463, 0.4635783817086901, 0.34381847083568573, 0.1418825409242085, 0.4269732902092593], [0.022007509799940244, 0.055054156708398035, 0.019434399836297547, 0.03677303570189646, 0.05777228317622628, 0.04156416468322277, 0.04088834041197385, 0.018461760599166155, 0.1177162719624383, 0.08429509747241225, 0.1085341800270336, 0.11068409787757055, 0.02348625473678112, 0.05887517399553742, 0.061226650673363886, 0.03557269707588213, 0.09176098435584988, 0.050553976757717986, 0.14036372170916625, 0.04631464263158185, 0.021268912557778612, 0.1456867339355605, 0.23281472868153028, 0.048122151355658255, 0.05973480322531291, 0.07482905898775373, 0.14066965957837446, 0.0278104091329234, 0.0709006329998374, 0.02873076046151774, 0.16241944820753165, 0.4466697233063834, 13.106493830680847, 91.40592874799455, 90.25092274802071, 91.77546869005475, 96.36533750806535, 80.34026936122349, 27.333283935274395, 14.608208860669817, 78.98966462271554, 63.555235045296804, 44.92956386293684, 36.52544321332659, 30.89780535016741, 31.39544575554984, 18.418646131243023, 2.9911584556102753, 0.14197594805487565, 0.29441664314695765, 0.08655051394764866, 0.13680465625865118, 0.04874533148748534, 0.16870261462671415, 0.7591799912708146, 1.1550206563302448, 4.549284824303218, 2.2534004662718092, 3.009709277323314, 11.703386766569954, 35.447590010506765, 62.52388613564627, 75.7147354398455, 89.89786393301827, 88.62010410853794, 95.42958191462925, 91.80075318472726, 97.21065534864152, 93.23809923444475, 83.35008307865688, 78.32946068899972, 82.78370761871338, 91.7220161982945, 100.80153996603829, 95.31443636757987, 76.83522973741803, 72.9946824482509, 82.45213958195278, 80.30207511356899, 79.42928409576416, 84.5100222996303, 99.92378793443952, 83.99806513105119, 23.996802398136683, 79.88021523611886, 84.14050320216587, 84.28310108184814, 67.22147982461112, 90.49519361768449, 62.33415167672293, 88.27767603737968, 104.01269858224052, 95.51577431815011, 108.35910252162388, 106.36279473985944, 104.04677949632917, 96.68575368608747, 84.51626873016357, 84.03422355651855, 83.6880156653268, 80.15348788670131, 80.1714837210519, 83.3262299128941, 83.91764668055943, 81.74408340454102, 79.16229956490653, 81.67609528132847, 93.05035890851701, 102.6790474482945, 95.23547009059361, 97.62834630693708, 107.8387449809483, 102.00171620505196, 72.17419052124023, 24.603166478020803, 1.5552212617227008, 0.1744130974901574, 0.12915703734116896, 0.1475726134542908, 0.15321961258138928, 0.02290632781971778, 0.2749872271503721, 7.760885953903198, 27.802040679114207, 37.88113055910383, 24.550733634403773, 36.24075467245919, 46.0563462802342, 29.510170187268937, 14.739406483513967, 16.666918413979666, 30.76344803401402, 37.48286328996931, 67.60944638933454, 67.89295373644147, 69.3831477846418, 67.24297755105155, 49.91906874520438, 6.843784536634173, 0.1407855533595596, 0.045206893501537185, 0.11848950332828931, 0.11914723446326596, 0.06154626102319785, 0.11042964046022721, 0.04713094400774155, 0.026077566402299062, 0.07310861987727028, 0.08578944871468203, 0.05178050005010196, 0.15912453643977642, 0.08710735371070248, 0.07506836471813065, 0.045591168238648346, 0.04045731461207781, 0.039469778138611994, 0.0569226826940264, 0.11413505912891456, 0.05002635471256716, 0.07092349962996584, 0.024389259317623715, 0.152355661083545, 0.18399694322475366, 0.12886548441435608, 0.12495058162936143, 0.17030399798282556, 0.12585076689720154, 0.13475989097995417, 0.040285115995045216, 0.09606833822493042, 0.21080328337848186, 0.20051085709461144, 0.1273454302655799, 0.38561728649905747, 0.06972379543419395, 0.009466678852082362, 0.054810359076197655, 0.029201487345354896, 0.060148173544023714, 0.07650263846984931, 0.017313830321654677, 0.12304328754544258, 0.06171349954924413, 0.0267484865617007, 0.07602854605231966, 0.09727633411863021, 0.11879617401531764, 0.07016533174152885, 0.03665526577138475, 0.029468965849706104, 0.009765454784168728, 0.05634592453550015, 0.03629745050732579, 0.0027502319883621696, 0.07228254420416695, 0.024099141492375305, 0.0926525318729026, 0.20178123749792576, 0.14907738699444703, 0.13598600375865186, 0.10414761397987604, 0.0720771923661232, 0.06573193999273436, 0.07102226718728032, 0.06766398024878331, 0.058954012979354174, 0.17427802830934525, 0.37010193190404345, 13.668649997029986, 101.40070397513253, 105.10822800227574, 102.7653579711914, 106.90189157213483, 96.02997575487409, 40.59018455232893, 19.82761573791504, 33.70763601575579, 48.63031687055315, 44.37727240153721, 44.42158453805106, 38.04525743212019, 40.373348644801546, 24.74150858606611, 6.3338119472776135, 0.1334769441080945, 0.2919993485723223, 0.04398322005623153, 0.16665052116981574, 0.35762934546385494, 0.5668990718466895, 1.6224294496434075, 2.263935672385352, 2.2276280777794972, 0.4491168462804386, 4.417284250259399, 14.173617277826581, 41.2434333392552, 66.29667459215436, 80.66578551701137, 90.601487159729, 93.04964324406215, 96.60699585505894, 98.43944426945278, 100.96492685590471, 96.55835151672363, 88.95466681889125, 83.01425579616001, 86.93052455357143, 97.11865425109863, 103.93838065011161, 102.66018308912004, 80.9378352846418, 76.8397947038923, 85.19025788988385, 83.42476231711251, 83.98224408285958, 90.9902458190918, 105.77210753304618, 89.1552265712193, 31.162344115121023, 87.59334100995744, 92.94611508505685, 91.95803955623082, 75.56251430511475, 97.04339831215995, 71.30294895172119, 92.60834230695451, 108.92213589804513, 100.1898830958775, 115.15412112644741, 107.55840601239885, 107.07042707715715, 102.01707867213658, 90.96721254076276, 90.49952929360526, 87.78869656154087, 84.2452472959246, 85.13058676038469, 87.08524703979492, 88.6182141985212, 86.10924748011998, 83.50937053135463, 85.73758833748954, 95.95929173060826, 107.77120849064418, 97.85385009220668, 96.86256449563163, 111.8864667075021, 110.81959165845598, 83.69582544054303, 31.840394496917725, 3.717089525290898, 0.17989243061414786, 0.2365843164069312, 0.10633485804178885, 0.19183082000485488, 0.031456907213266404, 0.35340123091425213, 10.73223270688738, 34.478389263153076, 40.92823873247419, 30.28191007886614, 32.586419105529785, 21.006858791623795, 30.785181999206543, 21.123341866901942, 27.8312509059906, 47.670791489737375, 45.315821170806885, 74.06624753134591, 72.15896006992885, 79.38671248299735, 78.77266543252128, 58.59892518179757, 7.5900662285940985, 0.12820778042078018, 0.12656454502471856, 0.03817075337948544, 0.07713952500905309, 0.04721699581880655, 0.18687760936362402, 0.01774692565335759, 0.03221679858065077, 0.10015182303530829, 0.029522997593241077, 0.08152296979512487, 0.07310547826013394, 0.03149077628872224, 0.04216090230537312, 0.042874225814427645, 0.04846860794350505, 0.09078183118253946, 0.08276624272444419, 0.10024729969778232, 0.05309997246201549, 0.08641890529543161, 0.07064447245959725, 0.13024901731738023, 0.16052347208772386, 0.11382412045661892, 0.08277164386319262, 0.14731992701334612, 0.1337242429809911, 0.09291472458945853, 0.07765296567231417, 0.1684049413140331, 0.23758092150092125, 0.17081441916525364, 0.11614800111523696, 0.2295113487967423, 0.060751255468598435, 0.056684995269668956, 0.13480729343635695, 0.0973421995128904, 0.17401231399604253, 0.11097554223878042, 0.08035272758986269, 0.18275009441588605, 0.15756284738225595, 0.07891305269939558, 0.15065431594848633, 0.16061679779418878, 0.22930949819939478, 0.14050560338156565, 0.1912025780017887, 0.35605997538992334, 0.1536441176597561, 0.11882942223123141, 0.19738899889801229, 0.11164997890591621, 0.30981699962701115, 0.19326844571956567, 0.19109641441277095, 0.23086128064564296, 0.3056295428957258, 0.17232211040599005, 0.16394117155245372, 0.14505028165876865, 0.2713721554194178, 0.21278257002787931, 0.228432830955301, 0.17685419507324696, 0.2977824482534613, 0.5144663910780634, 33.17171451023647, 135.27110154288155, 113.79489367348808, 117.30667304992676, 119.49764851161412, 103.96147646222795, 50.39694152559553, 35.04798173904419, 111.45940262930733, 87.50001280648368, 61.29887008666992, 57.427663871220176, 52.36154120309012, 56.85838753836495, 33.28386885779244, 7.548909442765372, 0.5886872112751007, 0.5057151349527496, 0.19045857792454107, 0.4347252542419093, 0.235533564218453, 0.42293673966612133, 1.442399452839579, 4.8140793698174615, 12.773551787648882, 9.87800293309348, 11.071556670325142, 18.49189404078892, 45.9867913382394, 73.4631438936506, 80.50301701681954, 95.23722798483712, 98.38890307290214, 102.14783682141984, 101.14804662976945, 107.88008676256452, 104.00229712894985, 94.40370123726981, 89.3897352218628, 93.8487833568028, 103.44112586975098, 111.96637793949672, 108.63502243586949, 88.11430999210903, 81.068204334804, 90.89705657958984, 86.99080712454659, 87.49129281725202, 94.09584740230015, 110.19835322243827, 90.99786104474748, 38.0560062953404, 91.36897822788784, 104.65464959825788, 99.18929386138916, 83.14782796587262, 101.90801279885429, 81.49813107081822, 97.237656048366, 112.82263919285366, 105.2050233568464, 121.19070216587612, 114.6356326511928, 113.8322193963187, 107.42346504756382, 97.46937152317592, 96.06819084712437, 91.83397947038922, 86.61766801561627, 88.22188200269426, 89.25901181357247, 90.89673001425606, 91.92673792157854, 87.80014719281877, 93.12802587236676, 103.11301803588867, 112.46988609858921, 101.09626865386963, 103.0498936516898, 118.22101429530552, 115.26953765324184, 83.08752455030168, 30.61121995108468, 3.718285918235779, 0.5043271780014038, 0.35548886603542734, 0.35950381202357157, 0.326292128435203, 0.07779380240078483, 0.7049000124846185, 15.226938996996198, 47.65197924205235, 57.01442323412214, 37.870183672223774, 48.14944246837071, 61.093015807015554, 43.666384833199636, 23.9118606703622, 25.02564127104623, 44.579975673130576, 52.56494624274117, 85.10113334655762, 84.33654662540981, 89.26230525970459, 85.36967427389962, 74.65805339813232, 15.297642128808157, 0.34977807104587555, 0.18782089517584868, 0.2865916687463011, 0.2818102224596909, 0.12142906630677835, 0.1664914454200438, 0.12349576183727809, 0.1375377183513982, 0.16034728368478163, 0.303415157433067, 0.21244539240641253, 0.27131621699248043, 0.28083519477929386, 0.2292123862675258, 0.19039019516536168, 0.1933927669056824, 0.18986529404563562, 0.1543670017272234, 0.19510498217173985, 0.213708756757634, 0.1312857781137739, 0.13988388888537884, 0.31013835381184307, 0.2931496011359351, 0.2552055971963065, 0.12789608857461385, 0.26040770805307795, 0.2117220876472337, 0.19077265821397305, 0.16008089083646024, 0.25908746889659334, 0.3588080693568502, 0.2564948951559407, 0.18564144069594996, 0.3907752111554146, 0.21862432227603026, 0.1436117331364325], [0.04229327770216124, 0.06775323474513632, 0.021345088291647177, 0.05610494621630226, 0.10161094473940985, 0.04441905327673469, 0.03741824108042887, 0.16405683463173254, 0.03115031455776521, 0.09346515219658613, 0.12638104201427527, 0.053469770654503784, 0.036562191122876744, 0.014058608611646508, 0.07787063970629658, 0.04573107198146837, 0.043642792252025435, 0.017880883733076707, 0.09210961564843144, 0.06005693772541625, 0.07518912359539952, 0.06482135278305837, 0.1623634554977928, 0.12160340909446989, 0.05032135120459965, 0.13919719787580626, 0.1374447319124426, 0.09381936783237116, 0.07075673607843262, 0.033926442198987515, 0.5022961327007839, 17.04991180556161, 103.90576580592564, 94.28355993543352, 107.08649131229946, 76.85318388257707, 54.03582082475935, 34.41228757585798, 19.065811770302908, 31.80988495690482, 54.8607040132795, 34.156802313668386, 36.353523935590474, 30.039140020098003, 28.670362268175396, 11.58801279749189, 0.5330670444028718, 0.28215603104659487, 0.05874278502804892, 0.1193884943744966, 0.09035123964505536, 0.02100737123484058, 0.23881642520427704, 1.3657844896827425, 0.7087189161351749, 4.636945469038827, 2.9960595411913733, 10.644138234002249, 33.13423245293753, 61.427912030901226, 83.16310705457414, 97.43024621691022, 105.54810455867222, 94.72386033194405, 78.90095002310616, 88.34266253880092, 91.47523008074079, 90.98515278952462, 87.96176924024309, 87.55346529824394, 78.98345988137382, 76.99956158229283, 81.25700773511613, 84.16886574881417, 74.54436697278703, 69.67364501953125, 87.36826801300049, 92.01689079829625, 97.37391717093331, 92.6085854939052, 96.97436795915876, 87.34223311288017, 100.46308626447404, 45.023149149758474, 61.3742094039917, 85.6538416998727, 68.49715518951416, 67.93002237592424, 86.05616324288505, 47.11649547304426, 93.92867374420166, 104.38690076555524, 82.41694695608956, 90.18910462515694, 93.14242253984723, 94.79675388336182, 91.50979042053223, 85.46939482007707, 80.34007481166294, 83.08077090127128, 82.65664591108049, 80.26533303941999, 90.07627977643693, 97.45423139844621, 97.41986560821533, 96.2388733455113, 89.64868763514927, 78.38250323704311, 79.35887799944196, 89.20264107840401, 92.11280373164585, 89.52059759412492, 93.7176708493914, 100.47915744781494, 87.39924308231899, 40.300802503313335, 7.876940846443176, 0.1546652992921216, 0.06433016128305878, 0.11316241310643298, 0.09418492178831782, 0.06619539976652179, 0.016212942876986096, 2.999684112412589, 17.880233696528844, 36.8725300516401, 57.40702077320644, 80.46061216081891, 55.18353121621268, 71.4907031740461, 28.35945122582572, 13.033027052879333, 22.098844630377634, 42.8350259235927, 49.71601458958217, 63.15605408804757, 73.08109024592808, 65.88331236158098, 58.81259618486677, 11.883439779281616, 0.5687248195920671, 0.1106176082310932, 0.028693183192184994, 0.07464230579457112, 0.01507543829003615, 0.02890144255278366, 0.033018324856779406, 0.032786347304603884, 0.0978476470336318, 0.032267698885074685, 0.07804643455892801, 0.05258302377270801, 0.08629036362149886, 0.038452800030687025, 0.03933337902916329, 0.0533059010548251, 0.042378545805279694, 0.06430278239505631, 0.00904122891370207, 0.09473861314888511, 0.11756438868386404, 0.1629287294511284, 0.07680966878043753, 0.16320053700889858, 0.2662637366780213, 0.2035784867725202, 0.17911082612616674, 0.1697637348302773, 0.05823550546275718, 0.18207332358828612, 0.22610731502728804, 0.1872742809355259, 0.08046802426023142, 0.24355292533125195, 0.032393879257142544, 0.031051597890577147, 0.059661514657948694, 0.04866568843967148, 0.08340789936482906, 0.03388497692399791, 0.07315968642277376, 0.03694045064704759, 0.006993449243184711, 0.09089915667261396, 0.03817085176706314, 0.08993544017097779, 0.07119816382016454, 0.04738633780341063, 0.013391678238154521, 0.02847783314064145, 0.04085860361478158, 0.08938596251287631, 0.04232060570003731, 0.023710861702316573, 0.1291442537414176, 0.11963373050093651, 0.1250872385821172, 0.06794400486562933, 0.059810894142304144, 0.03619479155167937, 0.10361862129398755, 0.11459460375564438, 0.05799485623304333, 0.05324647156521678, 0.05139013546119843, 0.037503573644374094, 0.46826922999961035, 17.530777522495814, 117.77145195007324, 112.04519830431256, 115.05140590667725, 90.77429580688477, 80.74680846078056, 65.09567846570695, 37.29421622412545, 31.029723848615372, 58.203298228127615, 38.32567630495344, 42.46934917994908, 36.50354596546718, 36.29517991202218, 15.971884897777013, 1.1803468401942934, 0.3139851859637669, 0.13396931625902653, 0.02415620968011873, 0.25276398392660276, 0.5267138395990644, 1.0522346517869403, 1.8799899433340346, 1.2599363923072815, 1.046700085912432, 2.579337856599263, 11.6122350863048, 35.15470606940133, 65.24279267447335, 88.1910320009504, 101.4353129523141, 108.84101567949567, 99.5548802784511, 88.75550365447998, 94.87818677084786, 95.37506634848458, 96.89544337136405, 95.06138297489711, 90.54840987069267, 81.69188158852714, 80.35722296578544, 85.95346191951207, 87.85491289411272, 78.03938729422433, 74.3085173198155, 90.51792117527553, 94.71901048932756, 101.01757335662842, 97.06438187190464, 101.75022615705217, 91.97711930956159, 104.34553813934326, 49.99548155920846, 65.19154970986503, 96.64324460710797, 74.347170148577, 74.82820088522774, 90.79681491851807, 56.13377380371094, 98.42477662222726, 107.67859595162528, 83.53886563437325, 92.87499332427979, 96.0418015888759, 98.03478813171387, 93.08705234527588, 91.18058477129254, 83.55846650259835, 86.88648687090192, 85.94717379978725, 84.86907741001674, 93.10607651301792, 99.57348755427769, 102.89215564727783, 102.77133342197963, 95.41783945901054, 81.89049584524972, 79.23506110055106, 92.8295590536935, 96.13548415047782, 93.64722306387765, 94.65558038439069, 105.38389778137207, 95.50836753845215, 50.90091173989432, 11.898087450436183, 0.4741940349340439, 0.2397086444709982, 0.14292391575872898, 0.08063510672322341, 0.01773867636386837, 0.16234388654785498, 2.696507283619472, 21.760040044784546, 41.91386154719761, 49.48732852935791, 53.49078328268868, 38.34919595718384, 45.38622726712908, 25.65984157153538, 23.193740027291433, 33.03256641115461, 55.95230075291225, 62.37429141998291, 72.4017231804984, 80.20712797982353, 78.3305585043771, 68.48147310529436, 13.568972877093724, 0.40330756296004566, 0.07344353119177477, 0.01744325239477413, 0.14627463024641785, 0.014370199525728822, 0.08153404348662921, 0.08024332060345582, 0.021953786789838756, 0.048789341268794875, 0.01575979683548212, 0.07074993715754577, 0.11922975789223399, 0.08166706349168505, 0.08175915426441602, 0.009955263081272798, 0.06037187296897173, 0.01871452676797552, 0.005972540297079831, 0.07607943617871829, 0.03484039154968091, 0.045545010894004784, 0.09355674763875348, 0.1226300054362842, 0.15938275972647326, 0.19272744974919728, 0.11819630834673132, 0.1322672383061477, 0.16800719765680178, 0.07833901207361903, 0.1277707495859691, 0.17998856545558997, 0.18170785105654172, 0.08299670035817794, 0.2041569785880191, 0.051922673492559364, 0.07262018322944641, 0.21764131502381392, 0.09288856706448964, 0.13731730303594045, 0.1591763086616993, 0.2119269102279629, 0.15402975625225476, 0.1522601233529193, 0.21430189135883534, 0.3100404819207532, 0.23311450545276913, 0.20792668844972337, 0.17246374780578272, 0.09818694846970694, 0.2313973233103752, 0.17474610890660966, 0.24242867422955378, 0.2036131734826735, 0.17135978490114212, 0.22148494449044975, 0.2054831888526678, 0.2733887886362416, 0.12305870386106627, 0.1566037924161979, 0.17007843937192643, 0.16873399008597645, 0.23432113070573124, 0.2946085328502314, 0.24692008750779287, 0.1627110961292471, 0.15700102038681507, 0.49517813750675743, 39.00136777332851, 149.1380661555699, 117.21690232413155, 131.8488497052874, 101.57272747584751, 76.50561414446149, 53.41539532797677, 34.579412596566335, 53.399150439671104, 78.22555732727051, 51.56369692938668, 60.17465155465262, 52.451815673283164, 47.68330519539969, 19.829095704214915, 1.6340711563825607, 0.7525810482246535, 0.2796462657196181, 0.24165270158222743, 0.2684616201690265, 0.21168160624802113, 0.7619872263499669, 6.28527443749564, 3.656521209648677, 10.830137167658124, 11.831396903310504, 18.44276680265154, 41.92380094528198, 70.8194932937622, 90.44055298396519, 106.76911844526018, 113.99150684901646, 103.27045726776123, 90.78577423095703, 99.60613019125802, 100.19709532601493, 103.1484955378941, 100.28780405861991, 96.4141069139753, 87.07644367218018, 84.550676209586, 91.76694325038365, 91.43358257838658, 82.70941747937883, 79.85357584272111, 94.5655734198434, 98.9504564830235, 104.48012474605015, 101.53296293531145, 106.13449777875627, 95.89809894561768, 106.2500741141183, 52.77195739746094, 76.08143356868199, 106.96178504398891, 81.47363172258649, 80.2876089641026, 95.69913727896554, 63.00542409079415, 99.31176280975342, 113.82843957628522, 86.35391439710344, 97.97201810564313, 97.92171314784459, 102.96545914241246, 98.77296475001744, 96.27128669193813, 87.14161777496338, 92.94995049067906, 90.90535967690604, 91.37364741734096, 98.65746484483991, 106.99056448255266, 108.27571024213518, 106.02258314405168, 99.09082399095807, 85.35666724613735, 85.18697139195034, 97.53100204467773, 99.73437309265137, 95.46355860573905, 97.9821833201817, 109.47373253958565, 98.96877888270787, 51.11541305269514, 12.622421520096914, 0.516910908477647, 0.19058178631322725, 0.14969325251877308, 0.24264385125466756, 0.23058381410581724, 0.2844385414251259, 5.386719933577946, 32.347109249659944, 61.72628157479422, 85.5024196079799, 113.86285400390625, 73.81248542240688, 89.45871693747384, 39.29660715375628, 21.07543751171657, 35.2876980645316, 60.962563378470286, 68.7642161505563, 81.59161908285958, 91.53064891270229, 84.49424294063023, 86.3789279120309, 26.585774149213517, 1.0740426587206977, 0.28815086079495295, 0.11326101102999278, 0.2687170207500458, 0.1272126409624304, 0.1257597617805004, 0.19209418658699307, 0.13332111175571168, 0.166328189894557, 0.1532154870884759, 0.2206631028758628, 0.20243172187890324, 0.26987240303839954, 0.16150565152721746, 0.13033840752073697, 0.12823370045849256, 0.13256025686860085, 0.1756632032671145, 0.14514060824045114, 0.18570444945778164, 0.17714076755302294, 0.2533450541751725, 0.2138505841472319, 0.25483742409518784, 0.4430224618741444, 0.3437525986560753, 0.23982415827257292, 0.23191564264042036, 0.1458317640104464, 0.38711332050817354, 0.341353570244142, 0.27214278121079716, 0.15359907650521823, 0.27408626835261074, 0.08602801484188863, 0.2764755258602755], [0.0461026072236044, 0.028035621690962995, 0.0660813855273383, 0.032095422236514945, 0.13126044161617756, 0.060996342317334244, 0.032248258856790404, 0.018588281935080886, 0.014124277230751301, 0.11106865759938955, 0.0557082203615989, 0.05812522316617625, 0.09001615869679622, 0.05311827255146844, 0.09073811995663814, 0.03693968390247651, 0.056090785190463066, 0.013485884343806123, 0.06178689668221133, 0.07380905122097049, 0.05541767845196383, 0.19458974339067936, 0.04749427576150213, 0.03120096041155713, 0.1099913271942309, 0.09004060631351811, 0.02037143294832536, 0.013989415851288607, 0.06216002308896609, 0.1499507294169494, 34.552307673863, 108.31181308201381, 103.58976173400879, 99.18591703687395, 79.03272260938371, 54.78956488200596, 19.375256742749894, 13.924786652837481, 29.613948481423513, 47.47337927137102, 42.61990622111729, 46.89502164295742, 37.00736331939697, 26.35099972997393, 6.845082112721034, 0.02759873674118093, 0.1054184761430536, 0.03259452884750707, 0.058429044006126266, 0.1704625037631818, 0.05266467189150197, 0.26845136071954456, 1.3153796515294482, 1.7314758896827698, 5.7688838839530945, 8.640317712511335, 34.22337647846767, 55.03713614600045, 94.57500907352993, 95.73171738215855, 99.01604747772217, 93.46088627406529, 89.31875242505754, 90.63861833299909, 101.35750007629395, 90.10360704149518, 86.17042636871338, 89.59972367967877, 89.49931526184082, 81.86701093401227, 78.8977746963501, 69.66956642695835, 74.06865160805839, 66.62925011771065, 75.48431927817208, 84.68123286111015, 95.43511268070766, 90.86317021506173, 93.19645868028913, 86.08565139770508, 90.76408195495605, 90.48076915740967, 101.18486513410295, 72.00419589451381, 28.349048035485403, 85.06123679024833, 73.85517515454973, 84.66468920026506, 82.23643970489502, 50.54947532926287, 97.50580787658691, 88.81707859039307, 89.91453960963658, 86.62359482901437, 89.0048953465053, 90.77162075042725, 87.56178229195731, 86.02405561719621, 87.39444882529122, 80.94046865190778, 76.09746306283134, 81.10563428061349, 88.32888426099504, 95.14702647072929, 93.13039520808628, 91.38148498535156, 87.75250339508057, 82.97387981414795, 76.80154487064907, 72.61968122209821, 74.11446802956718, 79.95038509368896, 86.7329386302403, 89.3831900187901, 93.26904651096889, 81.22501128060478, 47.97664771761213, 9.640171306473867, 0.6351713112422398, 0.11522661841341428, 0.03520334332383104, 0.06375899764576129, 0.1417066782180752, 0.01907326653599739, 0.8110581189393997, 11.951202086039952, 22.48918226787022, 33.61412715911865, 63.21873378753662, 61.345214571271626, 61.27403027670724, 40.30830308369228, 17.247928517205374, 13.803971375737872, 20.096684728349956, 44.58076081957136, 59.35813399723598, 74.60686601911272, 71.4139325278146, 76.56313133239746, 29.602320671081543, 0.7949901925665992, 0.1986888005797352, 0.007990941521711648, 0.0435689099665199, 0.015565123442294342, 0.07130610517093114, 0.06554916980011122, 0.08969426846929959, 0.049290799003626616, 0.09006693347224168, 0.057778600337249894, 0.044433526428682465, 0.024976078454138975, 0.05850784227784191, 0.044875676810209236, 0.10707195741789681, 0.03561005721400891, 0.09043067573968853, 0.06980830018541642, 0.014331173584131258, 0.05935305263847113, 0.13719948221530232, 0.11140410495655877, 0.19096348940261773, 0.2532342629773276, 0.23639139533042908, 0.11123371802802597, 0.13454996581588471, 0.1340705265424081, 0.032413858720766645, 0.192053868036185, 0.13903377950191498, 0.3201571676347937, 0.1159769424370357, 0.039497224880116324, 0.030133675717349564, 0.06357462611049414, 0.09827856426792485, 0.04255479188369853, 0.15756602292614325, 0.024931619143379585, 0.06251343126807894, 0.020260271948895285, 0.028805175397012914, 0.0896825162427766, 0.029433105273970535, 0.08339374512434006, 0.05115606123581529, 0.028426848019340208, 0.09373993852308818, 0.07663078659347125, 0.03703588320474539, 0.05824252151485, 0.04197147229154195, 0.02229908647547875, 0.11301567990865026, 0.2083849845720189, 0.05383411681811724, 0.014920101268216968, 0.11802233196794987, 0.09373908356896468, 0.03663278929889202, 0.024684795244996036, 0.07990800895329032, 0.15701807875718388, 36.675197737557546, 124.05669512067522, 116.43078313555036, 110.02572522844586, 94.6382863180978, 74.55751296452114, 35.496974331992014, 28.610493115016393, 31.696292332240514, 45.659642355782644, 45.79407262802124, 51.638126032693044, 45.02675526482718, 34.30430909565517, 11.1217018195561, 0.37206729501485825, 0.1951270481305463, 0.08857054662491594, 0.03828782441892794, 0.4252245154763971, 0.5256318205169269, 0.8533253137554441, 0.19083782471716404, 0.9939265634332384, 5.062617301940918, 12.718661018780299, 42.586158820560996, 66.79088606153215, 96.435701915196, 101.26239313398088, 102.63796969822475, 97.98847143990653, 95.15043108803886, 96.1528685433524, 102.9496658870152, 91.98499856676374, 90.92450891222272, 95.73720645904541, 92.59080505371094, 85.00895854404995, 84.9953122820173, 74.7788895198277, 79.0876967566354, 72.93633842468262, 77.66559505462646, 89.06581020355225, 99.3129301071167, 94.44168703896659, 97.22765759059361, 90.67729895455497, 96.84111540658134, 93.93212699890137, 103.63058240073067, 75.04185104370117, 33.946845122746055, 91.44284452710832, 80.8172492980957, 94.52669824872697, 87.04961667742047, 55.85391773496355, 98.32768249511719, 95.22941820962089, 93.64666025979179, 90.0783086504255, 91.9312264578683, 95.70225702013288, 91.38133212498256, 92.05929565429688, 92.37951033455985, 85.06544045039585, 79.93213217599052, 84.54636832645961, 93.10914066859654, 100.09086431775773, 94.4972448348999, 95.45342118399483, 90.33366884504045, 87.34927858625139, 80.22554070608956, 75.84259619031633, 75.91084834507534, 83.09019265856061, 91.22451128278459, 94.60478905269078, 95.23776994432721, 86.08789566584996, 56.98755802427019, 14.501409837177821, 1.0212544798851013, 0.44163477633680615, 0.42503718552844866, 0.04121792861925704, 0.17035066762140819, 0.043622229248285294, 0.8924451374581882, 14.741899149758474, 28.077927589416504, 35.69569281169346, 51.31509733200073, 53.08006831577846, 34.283860547201975, 20.00364487511771, 23.246603659221105, 24.500612803867885, 28.971690007618495, 51.62132181440081, 67.64547279902867, 79.27367918831962, 84.1845269884382, 84.4800477709089, 34.25291327067784, 0.7970816546252796, 0.18124321741717203, 0.059360604733228683, 0.014348717107038413, 0.035068263964993615, 0.0690437676385045, 0.041872775980404446, 0.0620779882052115, 0.06709141204399721, 0.06757298870278255, 0.08231762251151459, 0.037269621555294306, 0.03794411589790668, 0.06924264625247036, 0.09620785181011472, 0.05581438734329172, 0.022919913787128668, 0.09739314392209053, 0.01423468251180436, 0.029177528273846422, 0.07348661138010876, 0.04890864808112383, 0.11143564326422555, 0.14769172349146434, 0.12854019472641603, 0.1643782430993659, 0.08109801688364573, 0.059878394805959294, 0.049244085260267766, 0.10613290566418852, 0.09990331637007849, 0.14309531370443956, 0.21717711564685616, 0.06976851767727307, 0.036812105748270235, 0.1487316462610449, 0.16756123730114528, 0.17312717863491603, 0.11638181071196284, 0.3168848646538598, 0.1207056665526969, 0.14336375572851726, 0.18127862337444509, 0.11469953241092817, 0.15861697867512703, 0.22107846130217823, 0.1916825601032802, 0.181924683707101, 0.09999379222946507, 0.24039347629461968, 0.17206920683383942, 0.09522975036608321, 0.14086340846759932, 0.15202750797782624, 0.1777476899858032, 0.28518490280423847, 0.29194555431604385, 0.1596605112510068, 0.12364901575659003, 0.2948268582778317, 0.17358920669981412, 0.12122785353234836, 0.18398071266710758, 0.19643590146941797, 0.37705015763640404, 62.824305398123606, 148.8762719290597, 124.23555564880371, 130.2908273424421, 104.16784490857805, 77.8451156616211, 32.21047292436872, 20.178741216659546, 44.98143563951765, 67.45975439889091, 61.037867954799104, 71.85065460205078, 56.23438024520874, 44.65659345899309, 14.072554860796247, 0.7288850854550089, 0.41214154607483316, 0.23806680685707501, 0.21303149738482066, 0.6059902342302459, 0.32700784717287334, 1.7384717485734393, 5.184280693531036, 8.709422758647374, 9.618097748075213, 12.60923991884504, 43.682789530072895, 67.94383539472307, 100.18740953717912, 104.88601071493966, 107.98417772565568, 104.45867565699986, 101.78666251046317, 103.38921587807792, 106.79197107042584, 94.42204448154995, 95.16608537946428, 98.04573849269322, 98.4144515991211, 91.515960420881, 89.93775354112897, 80.28905418940953, 84.39601625714982, 77.13784463065011, 85.15515559060233, 94.63164384024483, 103.84398242405483, 96.9831018447876, 102.27646882193429, 96.03977271488735, 100.985764503479, 96.74108913966587, 107.18895639692033, 77.54168088095528, 40.761641774858745, 105.23672798701695, 89.21981007712228, 102.83956473214286, 97.78548676627022, 66.61697959899902, 102.80787399836949, 98.18948282514299, 98.97571318490165, 93.7815247944423, 98.45709269387382, 102.60009506770542, 95.11086109706334, 99.06246144430978, 97.97629819597516, 89.26016521453857, 82.70724269321987, 88.06150368281773, 95.57564694540841, 103.34812423161098, 96.70807824816022, 100.67784813472203, 96.58516461508614, 92.08393396650041, 83.35120868682861, 77.37462534223283, 78.04695388248989, 86.85348987579346, 96.52513217926025, 98.53577409471784, 99.85256889888218, 89.90256091526577, 57.85944925035749, 15.496011461530413, 2.2182625574725012, 0.5055132029311997, 0.3594147339463234, 0.21089165577931063, 0.21632277220487595, 0.23531920143536159, 1.5950652722801482, 21.238367557525635, 37.69235495158604, 48.29619884490967, 88.28808443886894, 76.23541259765625, 82.61302512032645, 58.269333907536094, 24.702650785446167, 25.256946802139282, 32.926898206983296, 61.204381534031455, 79.19937515258789, 92.99562100001744, 90.3496219090053, 101.61691801888603, 50.27407652991158, 3.3444902045386176, 0.3777114578655788, 0.1393073241093329, 0.18428803474775382, 0.22401969347681316, 0.17367513637457574, 0.19128678419760295, 0.15184093798909867, 0.2648477969425065, 0.2328383145587785, 0.22563524464411394, 0.21298408135771751, 0.15513760037720203, 0.2055316769651004, 0.18181516815509113, 0.16302958689630032, 0.24067989949669155, 0.2234005709843976, 0.1870050246694258, 0.13856218409325394, 0.18095042955662521, 0.34404553579432623, 0.163947658347232, 0.3270983637443611, 0.21435841332588876, 0.25216310045548845, 0.13221474683710507, 0.17212853793587002, 0.14558945915528707, 0.15840504504740238, 0.1904012281447649, 0.30093809749398914, 0.3587033035499709, 0.23113673872181348, 0.1398179488522666], [0.016314489035201923, 0.0714968888621245, 0.02849676426766174, 0.0598873786096062, 0.00766745419241488, 0.02935622725635767, 0.02476835174352995, 0.06595704398517098, 0.09710682250027146, 0.09475727964724813, 0.14360563989196504, 0.07955151343984262, 0.05124008422717452, 0.0017030406244365232, 0.021615236831296767, 0.056837777607142925, 0.04285264500815954, 0.03917942621878215, 0.08770280211631741, 0.2122269177011081, 0.08743293516870056, 0.142801915162376, 0.05224067910707422, 0.0674861633617963, 0.06566321796604566, 0.0769613010010549, 0.04344031400978565, 0.053992296901664565, 0.48926190925495966, 60.98405415671212, 111.10924816131592, 94.88479450770787, 98.67416831425258, 67.4690580368042, 63.84965106419155, 23.070616211209977, 26.967334474836075, 46.3360355922154, 74.73885399954659, 58.79431547437395, 35.70162309919085, 28.76632383891514, 21.23885566847665, 3.6795909660203114, 0.19243428190904005, 0.08427360148302146, 0.0866324741925512, 0.06784852141780512, 0.09906689303794078, 0.07915078422852925, 0.4096889676792281, 3.0840335062571933, 18.236509527478898, 42.37012890407017, 71.39961229051862, 92.96999604361397, 99.72207478114537, 98.52742236001151, 91.31091213226318, 90.91811656951904, 86.67542839050293, 87.51800169263566, 87.89772769383022, 88.3322193963187, 90.04615238734654, 94.32399845123291, 87.34864630017961, 87.67548261369977, 84.8733297075544, 85.50979164668492, 74.98197146824428, 69.0560404913766, 68.03849765232631, 71.76669257027763, 83.36916283198765, 89.48974759238106, 88.16798482622418, 90.3970503125872, 85.74375138963971, 89.08971200670514, 88.894300869533, 91.38207558223179, 88.29653344835553, 102.56033747536796, 51.07641976220267, 64.19498348236084, 67.11360209328788, 85.27367796216691, 50.70042494365147, 33.09301573889596, 95.00298336574009, 88.48795631953648, 99.71793365478516, 84.15936061314174, 79.44591113499233, 82.53810964311872, 84.79960932050432, 80.90888908931187, 83.46938364846366, 77.93158599308559, 77.9817728315081, 81.7760590144566, 92.2734877722604, 93.2477502822876, 95.45672852652413, 95.52713462284633, 89.3605180467878, 78.21631622314453, 79.99171992710659, 88.72595991407121, 90.77364267621721, 87.40088980538505, 83.27555670057023, 83.89798327854702, 88.75967257363456, 88.48152228764125, 73.16986043112618, 41.36860166277204, 9.217230984142848, 0.4009840419249875, 0.09265130372451884, 0.050086805397378545, 0.034553126964185915, 0.11424331260578972, 0.025657537958717773, 0.2994385079613754, 7.34565726348332, 21.278401340757096, 32.06028413772583, 42.166696071624756, 53.77006959915161, 63.94741916656494, 36.5267460005624, 27.867173092705862, 29.886429037366593, 27.758136749267578, 51.62961448941912, 56.829219000680105, 76.61934920719692, 73.67452199118478, 83.3999502999442, 49.505032539367676, 8.681173120226179, 0.6616229947124208, 0.01973556081897446, 0.046987488134098906, 0.10792658584458487, 0.03135351883247495, 0.02721273004343467, 0.1052214770710894, 0.021837055017905574, 0.02855051102648888, 0.07302344337637935, 0.009252060770190187, 0.03928716740171824, 0.0065533039326380405, 0.045230744007442675, 0.11729449459484645, 0.08942911055471216, 0.09978932248694555, 0.05973069808845009, 0.05334842823711889, 0.07656446658074856, 0.015749301595081176, 0.0813920736046774, 0.1809771502656596, 0.1255362116332565, 0.058605103487414975, 0.07846836798957416, 0.1576513826314892, 0.05236639468265431, 0.11684639006853104, 0.22094808758369514, 0.05158145519505654, 0.050303743220865726, 0.06382573835019555, 0.02612696205531912, 0.06135640013962984, 0.025450649238856773, 0.09918421174266509, 0.04651180115927543, 0.04134144574137671, 0.04288808149950845, 0.019121520553848574, 0.023353239820737923, 0.02514926603596125, 0.0892091973551682, 0.06395318079739809, 0.043810373438256126, 0.04541433522743838, 0.053937688403363736, 0.07187955547124147, 0.03564832658906068, 0.07394689561000892, 0.09590224642306566, 0.2137561727847372, 0.13236946639205727, 0.061299647470670085, 0.0040047772927209735, 0.04917755829436438, 0.10170522718025105, 0.11440082772501878, 0.037910189146974256, 0.025878314594072954, 0.15779504206563744, 70.28214740753174, 128.9640132359096, 106.76874324253627, 110.47277927398682, 85.94989749363491, 84.5608275277274, 47.2427407673427, 36.84295504433768, 32.66990171160017, 44.783408505576, 52.60994277681623, 45.34992292949131, 38.766949449266704, 29.186915670122417, 5.175400027206965, 0.09999529179185629, 0.07356711277472121, 0.06943184895707027, 0.1849288839314665, 0.37362002741013256, 0.9810252785682678, 0.49722345918416977, 2.4400792377335683, 21.138412509645732, 51.023662090301514, 83.36648777553013, 99.93694087437221, 107.34153188977922, 102.204909324646, 98.24722930363247, 93.92312213352749, 90.61580739702497, 92.11736869812012, 93.10559013911656, 92.8435388292585, 96.93565954480852, 98.71138286590576, 91.09803322383335, 92.34509590693882, 89.98129095349992, 89.03996290479387, 79.7024038859776, 72.85666343144008, 69.58023343767438, 74.89554282597133, 86.77168873378209, 92.14693328312465, 91.59122330801827, 94.29977703094482, 89.53849615369523, 93.90698841639927, 91.81353092193604, 93.87596470969063, 91.1581837790353, 104.78894438062395, 56.78191566467285, 70.81493527548653, 76.67637307303292, 92.7365504673549, 57.64587204796927, 39.8408282824925, 102.71708188738141, 91.90034171513149, 103.34583827427456, 88.10835538591657, 83.26509966169084, 86.13278797694615, 88.54948956625802, 85.45145457131522, 86.29871790749687, 81.93632616315568, 82.90753146580288, 86.26091275896344, 95.89510427202497, 95.65749672480992, 96.2125049318586, 100.13819544655937, 94.70041710989815, 82.13919966561454, 82.44469806126186, 93.78111485072544, 96.4757513318743, 91.62683977399553, 85.06439127240861, 85.712644304548, 92.60288102286202, 94.23788942609514, 77.91186005728585, 47.13003751209804, 11.985421964100428, 1.6989085972309113, 0.46684712916612625, 0.2178562342056206, 0.2024279220827988, 0.04751639600311007, 0.08116608073136636, 0.22800833944763454, 8.67304459639958, 28.63273777280535, 33.30321264266968, 37.51079157420567, 49.596946784428184, 53.43570143835885, 26.131929976599558, 25.330443109784806, 32.82590961456299, 42.629532950265066, 57.05269043786185, 65.2480663572039, 81.38718223571777, 84.18729931967599, 94.76752281188965, 57.38478306361607, 11.046473673411779, 0.47571455048663275, 0.03389103624171444, 0.07123477078442063, 0.07705381246549742, 0.08606574138892548, 0.024564760703859583, 0.0751525302018438, 0.07199166302702256, 0.04099746919902308, 0.04830216330343059, 0.050843097136488984, 0.03971615759655833, 0.02830182624581669, 0.024824972098161067, 0.05186243654627885, 0.029268133054886545, 0.09474315254815988, 0.11420686170458794, 0.03618150922868933, 0.02072038993771587, 0.00859601833924119, 0.16623467419828686, 0.17553650720843247, 0.034892706599618704, 0.033944725325065, 0.017015975500856127, 0.12985265787158692, 0.05319050260420356, 0.12380974713180747, 0.17451322211750916, 0.02483740116336516, 0.014892746128940156, 0.07900204256709133, 0.08158115417297397, 0.24718094351036207, 0.11474683987242834, 0.1311233639717102, 0.19010449121040957, 0.15713186907981122, 0.12410911678203515, 0.1327058704836028, 0.14896331168711185, 0.15284013508685998, 0.2711333382342543, 0.1467516810766288, 0.1596714492355074, 0.11629299047802176, 0.0990053770531501, 0.1336153516811984, 0.11082509066909552, 0.20728244659091744, 0.15936133159058435, 0.36471911360110554, 0.24371778219938278, 0.20905632711946964, 0.16488637083343097, 0.10103422390030962, 0.17791447389338697, 0.17572011878447874, 0.17134630919567176, 0.1289934968309743, 1.2096307831151145, 100.35133143833706, 146.21797452654158, 115.9237174987793, 126.7221908569336, 94.5537336894444, 89.45596545083183, 41.297035217285156, 43.78383370808193, 62.19568797520229, 103.12810257502964, 80.3344954081944, 57.19934606552124, 49.14923960821969, 38.84583234786987, 7.500003678458078, 0.5162588634661266, 0.16305035006787094, 0.2247617800853082, 0.4951987106885229, 0.4314771613904408, 0.572723996426378, 1.8219507719789232, 9.177884204047066, 26.212464809417725, 49.54730885369437, 83.51678425925118, 106.22961861746651, 112.52318572998047, 106.7669575554984, 100.0611468723842, 100.19540691375732, 95.74799701145717, 94.61607987540108, 98.66164071219308, 98.80163301740373, 100.62559073311942, 102.99649674551827, 93.47406005859375, 96.67308712005615, 92.65843187059674, 94.94923210144043, 85.76946667262486, 78.60979965754917, 74.53887789590019, 79.53272887638637, 89.43259171077183, 98.03657381875175, 96.83147130693708, 99.53041567121232, 92.93127373286656, 97.68587739127022, 92.89240550994873, 97.45546122959682, 97.91127695356096, 108.79984065464565, 61.54883847917829, 79.04589639391217, 83.53739261627197, 100.66321522848946, 65.9523149217878, 46.6847483089992, 105.15453774588448, 94.33908993857247, 107.39130878448486, 91.42492512294224, 86.42101315089634, 89.87529618399483, 93.00070708138603, 87.30155141013009, 92.25983456202916, 85.86473342350551, 88.49004772731236, 91.37719794682094, 102.49807466779436, 100.19348226274762, 100.81956359318325, 105.32198933192662, 98.2326658793858, 85.19423225947789, 86.1459687096732, 99.67026901245117, 99.8086771283831, 94.1765159879412, 88.58074951171875, 89.52396747044155, 99.98927470615932, 100.32499776567731, 80.49356051853725, 48.988923822130474, 13.61966780253819, 2.346150883606502, 0.6230568555848939, 0.14004152614091123, 0.20378351291375502, 0.25533384031483103, 0.22321318675364765, 0.7303414387362344, 14.583938802991595, 40.92516762869698, 48.73307030541556, 62.85127135685512, 74.27406815120152, 87.38396399361747, 54.16716609682356, 40.26220873423985, 44.62182814734322, 41.4019148009164, 67.39168289729527, 74.34315408979143, 94.37070424216134, 87.70947320120675, 105.61020060947963, 76.70558329990932, 18.26869879450117, 0.8273340570075172, 0.18053519326661313, 0.1855069821966546, 0.24190299957990646, 0.13865557765322073, 0.10717708284833602, 0.19702093436249665, 0.15013359460447515, 0.13808574394455977, 0.34212691017559593, 0.20098402670451573, 0.14344334788620472, 0.07541563215532474, 0.12514433051858628, 0.1213057493524892, 0.16168945309306892, 0.24046032556465693, 0.17524780412869795, 0.07936849897461278, 0.2241577482117074, 0.16940265920545372, 0.32183727462376865, 0.27614754917366163, 0.2365719127867903, 0.1321940515190363, 0.11192953533359937, 0.18487043492496014, 0.20726561892245496, 0.31691697293094223, 0.3160968955074038, 0.17058759847921984, 0.13722468300589494, 0.14992611216647284], [0.07109466008841991, 0.02654999471269548, 0.019046935984598737, 0.033128098252096345, 0.14728533529809543, 0.12617210751133306, 0.09861175888883215, 0.06290187899555479, 0.07979250872241599, 0.045105964810188325, 0.11746872881693499, 0.07155792987240212, 0.06342421525291034, 0.0167222003718572, 0.03900538198649883, 0.009995167725719512, 0.022009738787476505, 0.038085342784013064, 0.02696012841936733, 0.07163062132894993, 0.06852016252066408, 0.10209731185542685, 0.06071779690682888, 0.050505875410245996, 0.13121115283242293, 0.049299796377973895, 0.06343103452984776, 0.5758999745760645, 59.61178493499756, 125.5419420514788, 96.15688460213798, 95.90745816911969, 71.52923788343156, 52.4516384942191, 20.282946825027466, 24.778730085917882, 27.813407932009014, 69.10472651890346, 57.08450623920986, 38.354021481105256, 32.86211320332119, 25.27048363004412, 1.7180091951574599, 0.1653268350554364, 0.1792117649955409, 0.0759616560701813, 0.049073806897337945, 0.0827012729964086, 0.35373767571789877, 0.5655644748892102, 10.710735848971776, 41.15687962940761, 84.20086220332554, 96.4056648526873, 95.11920588357108, 88.52030713217599, 90.9478896004813, 85.31399835859025, 87.9201912198748, 81.8313319342477, 80.5208877835955, 80.88122831072126, 82.5980031149728, 82.10643196105957, 86.79149804796491, 89.23786149706159, 91.21246310642788, 90.95078699929374, 89.75402232578823, 84.82365008762905, 72.2617586680821, 65.183260508946, 65.71878596714565, 77.33972454071045, 84.157164982387, 87.09673241206578, 86.47340256827218, 86.39404719216483, 88.12837314605713, 88.3063304083688, 88.75332192012242, 82.99143096378872, 79.67968327658517, 86.53008597237724, 83.79104355403355, 41.56004190444946, 72.92046873910087, 81.67844377245221, 34.16434805733817, 78.69268471854073, 88.97132165091378, 88.39960997445243, 95.38768427712577, 93.57675443376813, 80.58829920632499, 76.45819268907819, 83.73939064570835, 84.22360365731376, 81.40895094190324, 75.67372717176164, 73.02095358712333, 82.30733912331718, 89.33155795506069, 90.36643654959542, 92.04412773677281, 86.71898664746965, 83.24143409729004, 83.03403731754848, 89.62657846723283, 88.87138571058, 91.72407981327602, 94.49279103960309, 95.50912489209855, 88.58567578451974, 86.71153123038155, 91.15669686453683, 84.49375656672886, 55.67247595105852, 22.241946254457744, 3.877537327153342, 0.600848947252546, 0.14615112330232347, 0.1796592724110399, 0.11246711148747376, 0.06144061990614448, 0.04106173325063927, 0.1470137448715312, 3.094430616923741, 16.859548534665787, 26.756710256849015, 36.85335997172764, 37.93928698131016, 59.445208821977886, 61.65495136805943, 25.25246695109776, 11.765720793179103, 30.62275743484497, 52.12072706222534, 58.480861391339985, 61.71863855634417, 67.08796324048723, 75.55921391078404, 76.44469928741455, 22.39063423020499, 0.8927794652325767, 0.0467855730759246, 0.028409480915537903, 0.05254670518583485, 0.09057341236621141, 0.054368486894028525, 0.05395829551188009, 0.02874874503218702, 0.07086055872163602, 0.09682518975543124, 0.08999553801757948, 0.05257688642346433, 0.013225819682702422, 0.12493680736848287, 0.060815159896654744, 0.06312524593834366, 0.039589814376086, 0.03611488726788333, 0.030062643278922354, 0.11375142900007111, 0.08061376679688692, 0.17935486803097384, 0.10335895951305117, 0.08901465457997151, 0.0943316685568009, 0.08434374164789915, 0.05510733010513442, 0.1241903645651681, 0.15263023706419127, 0.03503089025616646, 0.08555603266826697, 0.12424527161887713, 0.05547563212790659, 0.024879105621948838, 0.05715217002268348, 0.1137634865673525, 0.13831985209669384, 0.05859559042645352, 0.04167285581518497, 0.01940780974525426, 0.03093192127666303, 0.037050909362733364, 0.048987605808568854, 0.07832020308290209, 0.015809033032772795, 0.03195476871249931, 0.06151158788374492, 0.035147693274276595, 0.054862199151622396, 0.03081708261743188, 0.04271289054304361, 0.054906334461910386, 0.06381444074213505, 0.03696846057261739, 0.07502854149788618, 0.07047176494130067, 0.11177706172955887, 0.04607776266389659, 0.10486852351043906, 0.4136146998831204, 71.98319149017334, 144.53432873317172, 108.4822940826416, 111.27914551326207, 90.2852954864502, 63.97563580104283, 45.06007535117013, 31.073004177638463, 18.005466290882655, 49.93693951198033, 47.09254503250122, 45.254003047943115, 36.66702665601458, 32.26859113148281, 2.4331141029085432, 0.07399215389575277, 0.06838919847671475, 0.08796901176018374, 0.052765095074261935, 0.18548226995127542, 0.8007574145283017, 0.9099834220749992, 11.606503690992083, 48.52053533281599, 90.6725046975272, 100.71627167293003, 98.05023397718156, 93.10342924935478, 92.9782782963344, 89.73278863089425, 90.99668679918561, 86.18974930899483, 83.3333935056414, 86.5563918522426, 85.67069802965436, 87.99202864510673, 90.24946362631661, 91.92689078194755, 95.17780004228864, 95.36521380288261, 91.97562544686454, 88.46261623927525, 75.71495083400181, 68.81362479073661, 70.78348772866386, 81.25181048257011, 88.29760347093854, 89.9531785420009, 90.87182767050606, 91.69614110674176, 90.54145472390312, 91.52986376626151, 90.74604443141392, 87.8949762071882, 82.96635491507394, 91.8931781223842, 88.19725063868931, 50.664346422467915, 78.31917040688651, 89.79798357827323, 44.15044151033674, 82.3877089364188, 91.15443175179618, 89.05318532671247, 99.54144941057477, 96.6037232535226, 83.31751687186105, 79.78410080501011, 88.50768225533622, 88.05452769143241, 84.2497010912214, 80.03557695661272, 76.70773724147251, 85.72023868560791, 90.66650840214321, 92.98946489606584, 95.78054932185582, 89.00203268868583, 87.36478001730782, 87.35264846256801, 95.49383885519845, 91.25207478659493, 91.95768519810268, 97.84747164590019, 99.7297386441912, 93.08986636570522, 89.21248667580741, 93.31263950892857, 90.60472502027238, 61.17250319889614, 27.500198772975377, 5.681898083005633, 1.6074617270912444, 0.6832101792097092, 0.7558842109782355, 0.17263096597577843, 0.07557798522923674, 0.025866168817239146, 0.2440005141709532, 2.9373783128602162, 21.4339211327689, 33.07577725819179, 31.752412932259695, 38.57354286738804, 45.87067999158587, 35.497610092163086, 26.91944749014718, 21.223533153533936, 43.70103897367205, 61.67494828360421, 68.51159354618618, 68.71557876041958, 79.2435587474278, 88.08509976523263, 88.2678999219622, 28.869275297437394, 0.7613177565591676, 0.1471219440656049, 0.10119517919208322, 0.04334803663992456, 0.08214944760714259, 0.06032644504947322, 0.061696020487163744, 0.009142374736256897, 0.007931864022144249, 0.05783050148082631, 0.05217680521309376, 0.0046054644127642465, 0.03504281211644411, 0.1151556707918644, 0.05153837500672255, 0.08073852224541561, 0.04263559522639428, 0.03784288865114961, 0.023659472852679234, 0.031037698100720133, 0.06493586235280548, 0.10094600077718496, 0.1067798345216683, 0.053915147470044236, 0.07240276703877108, 0.051365996577910016, 0.06034481977777822, 0.08147944855902876, 0.12944745032915048, 0.024862369555713873, 0.06110147453312363, 0.06295797348554645, 0.21109623408743314, 0.11726686464888708, 0.11209517930235181, 0.13548774192375795, 0.32614149366106304, 0.20343683580202715, 0.15812935626932553, 0.18909591675869056, 0.16540504300168582, 0.09647115053875105, 0.25486695393919945, 0.189754150009581, 0.10571583732962608, 0.07375364883669785, 0.16446552984416485, 0.18921130842396192, 0.14902382344007492, 0.1350231897085905, 0.08273737784475088, 0.1690298177834068, 0.16369736034955296, 0.21065258075084003, 0.24259404678429874, 0.17849768831261567, 0.24304551684430667, 0.19920817842440947, 0.12123472030673708, 0.6139546068651336, 104.57437705993652, 157.96682248796736, 121.69554437909807, 126.71465900966099, 96.54742894853864, 80.69261945996965, 33.562773023332866, 38.632526125226704, 45.84662185396467, 103.81278501238141, 84.27145590100969, 60.09981945582798, 54.02671521050589, 43.10817003250122, 3.5501835899693623, 0.3037671814007418, 0.3452945830566542, 0.327609653451613, 0.2961714432707855, 0.4007647665483611, 1.0482848180191857, 6.110391753060477, 17.97504186630249, 48.08198240825108, 93.21828297206334, 104.19825717381069, 105.66108226776123, 97.81466920035226, 99.46690913609096, 92.99748311723981, 94.35971219199044, 87.96277672903878, 87.43496377127511, 91.52006680624825, 91.39262989589146, 91.90518460954938, 95.15767805916923, 96.78220163072858, 98.87611770629883, 97.12260777609688, 97.09052794320243, 91.58460862295968, 81.43288748604911, 74.6743608202253, 76.52685478755406, 87.19411836351667, 92.6106630052839, 96.84661143166679, 93.96811171940395, 98.35893549237932, 95.23385810852051, 96.48556218828473, 93.59279782431466, 92.34416484832764, 84.77396351950509, 99.08167321341378, 88.51440811157227, 58.37977205004011, 87.53491360800606, 99.61886623927525, 51.38692780903408, 82.60907159532819, 95.28035545349121, 89.45973832266671, 103.38999407632011, 101.07634122031075, 89.7340532030378, 84.64868055071149, 94.48906680515834, 94.60451807294572, 89.15688024248395, 85.19268975939069, 81.31535175868443, 89.89718300955636, 95.13374151502336, 97.20779963902065, 98.99998324257987, 95.15587847573417, 91.83278438023159, 92.90400900159563, 99.45707048688615, 93.90363243647984, 96.83902399880546, 102.49680314745221, 104.4332799911499, 96.87576607295445, 93.42235156467983, 98.73315157209123, 94.31213787623814, 64.99069118499756, 28.9256078175136, 7.163508066109248, 3.1803561661924635, 1.7022983410528727, 0.7087447004658836, 0.19024903274008206, 0.14412005086030277, 0.31272845768502777, 0.3956240766814777, 5.742363478456225, 31.49656288964408, 45.21500628335135, 52.70961121150425, 52.53391211373465, 79.21383435385567, 83.82921695709229, 36.281311307634624, 19.975772176470073, 46.03563717433384, 71.99503816877092, 77.91317326681954, 82.51048360552106, 86.28588458469936, 94.75321647099086, 102.27731650216239, 40.150221143450054, 1.5686717799731662, 0.38870445798550335, 0.14718496639813694, 0.1519755186246974, 0.16519970473434242, 0.10652793518134526, 0.12510659040084907, 0.12293811461755208, 0.18971703414406094, 0.2080010694584676, 0.1906731306974377, 0.10030871390232018, 0.08566220982798509, 0.16299483233264514, 0.19032076746225357, 0.20735468342900276, 0.11529692821204662, 0.14311710824923857, 0.06684811652771064, 0.14693868532776833, 0.16886722722223826, 0.23966223267572268, 0.18617395497858524, 0.16684169162596973, 0.15996616413550718, 0.11807512199240071, 0.1418353013162102, 0.19274068118206092, 0.2733410197709288, 0.08347563751574073, 0.2973409390875271, 0.16889282156314167], [0.07261244114488363, 0.011990390618198683, 0.05547338956966996, 0.19488715886005334, 0.11198702082037926, 0.15529407055250236, 0.05550784557791693, 0.10268795623310975, 0.051723292762679715, 0.03904478790770684, 0.13150626128273352, 0.08771120237984828, 0.08096908844475235, 0.07101278126771961, 0.040292654519102404, 0.043718262309474606, 0.18928971993071692, 0.1099518635975463, 0.07528340603624072, 0.04229813262021967, 0.060718047964785776, 0.044640893515731604, 0.0854697230138949, 0.10387324155973536, 0.05100584376071181, 0.1273995909307684, 0.14396625411297592, 53.55828850609915, 112.35802704947335, 100.87814385550362, 97.01386151994977, 74.78178691864014, 45.47151640483311, 28.758267402648926, 33.99552420207432, 56.08248914991106, 80.16380596160889, 61.82593958718436, 50.278512954711914, 29.151702199663433, 23.01411346026829, 0.5594683534332684, 0.0955692825040647, 0.014602914984737123, 0.10140322481415101, 0.08935423421540431, 0.18807766639760562, 0.389910594693252, 0.6836731572236333, 21.028816836220876, 67.31907422201974, 88.7071441922869, 95.49100399017334, 87.05709988730294, 90.39978790283203, 87.70078100476945, 91.100145476205, 85.44845989772251, 79.10531738826207, 77.34963267190116, 83.96053096226284, 86.94627611977714, 88.1659767968314, 81.34376989092145, 81.49039077758789, 82.56283828190395, 92.70506123134068, 88.37947409493583, 88.41085910797119, 80.27207974025181, 67.0398817062378, 62.17767824445452, 70.61736324855259, 78.64579132625035, 82.599698475429, 78.42635331835065, 81.79656314849854, 73.19935553414481, 79.43069458007812, 77.02770873478481, 79.17780794416154, 67.23004000527519, 78.29655402047294, 79.08980206080845, 98.3370486668178, 60.42911543164934, 46.98184980664934, 54.69929388591221, 56.42992339815412, 95.40784100123814, 85.553683417184, 94.95581204550606, 89.41937623705182, 87.58079951150077, 74.5929765701294, 70.14150197165353, 76.47616073063442, 79.79020132337297, 79.1348819732666, 76.09267575400216, 73.12022250039237, 74.8145615713937, 81.62085015433175, 85.97717612130302, 94.20717144012451, 91.02425030299595, 84.34451620919364, 84.4016442980085, 85.90613773890904, 91.85125269208635, 86.31189169202531, 88.68395110539028, 89.03600937979562, 90.92225074768066, 90.5739028113229, 92.08455235617501, 87.77057565961564, 71.64006859915597, 37.07741853169033, 12.57338808264051, 1.405973955988884, 1.992193579673767, 0.2928568539874894, 0.07689676553543125, 0.239252614655665, 0.01590107461171491, 0.10316154653472559, 0.10167090009365763, 1.3417849774871553, 13.485861131123134, 27.781826632363455, 33.43690640585763, 70.33292484283447, 143.40773391723633, 55.119482721601216, 37.29639448438372, 19.206445046833583, 21.098015683037893, 37.220947469983784, 45.89195190157209, 67.42798723493303, 70.27347605569022, 74.97650323595319, 82.43646444593156, 30.824140548706055, 0.8944941503661019, 0.12207805791071483, 0.03744214926181095, 0.013351827028340526, 0.051094212768865485, 0.007948506789814149, 0.07726092849458967, 0.06306341104209423, 0.02701483021623322, 0.05644417979887553, 0.0352947860956192, 0.06975577478962285, 0.06476372480392456, 0.0209860245231539, 0.060323188081383705, 0.0663508724953447, 0.029465912442122186, 0.03153118983443294, 0.07016850728541613, 0.061366191399948936, 0.07074341643601656, 0.11936234363487788, 0.08081749015088592, 0.10205907640712601, 0.05566316902903574, 0.02795063178720219, 0.06627892742731742, 0.058450166801256795, 0.053436342626810074, 0.06258070122982774, 0.05713336781731673, 0.137610701578004, 0.04338179375710232, 0.05032405177397387, 0.13808093991662773, 0.04730777023360133, 0.1252074342753206, 0.054654377446110756, 0.03824089354436312, 0.013884107216394373, 0.02892498093258057, 0.12362705836338655, 0.004944218355896217, 0.052148886889751465, 0.05736679743443217, 0.03810484388044902, 0.06049781585378306, 0.15598738406385693, 0.012029195187746413, 0.061083574779331684, 0.026346357871911356, 0.0347501328215003, 0.08297575398215226, 0.09029134535895926, 0.16603481849389418, 0.09394024884594337, 0.20043232345155307, 0.05915390261049781, 66.93428993225098, 132.91584287370955, 109.51692254202706, 113.48760959080288, 85.33488464355469, 69.86274024418422, 58.3681755065918, 31.24504852294922, 30.75155966622489, 46.354722772325786, 42.77160276685442, 48.75397743497576, 36.316041878291536, 32.264102595193044, 1.0580232611724307, 0.22008754233164446, 0.14139224509043352, 0.08908438762383801, 0.18989687306540354, 0.20000510423311166, 0.5189990050026349, 0.6278464985745293, 22.17377052988325, 75.81931277683803, 94.13605662754604, 97.59452942439488, 92.36290413992745, 96.69671794346401, 89.76384707859584, 94.22939872741699, 88.64882101331438, 84.3745115825108, 79.66748918805803, 88.72707162584577, 91.07685511452812, 93.04050636291504, 84.1082844052996, 85.5480067389352, 87.09445340292794, 97.386611529759, 92.698974609375, 92.38817473820278, 85.1344221660069, 71.39861869812012, 65.15120152064732, 72.93931225367955, 80.89802210671562, 88.84451702662876, 81.66133035932268, 86.39515890393938, 79.54640987941197, 83.13113839285714, 78.95725127628872, 80.67455414363316, 70.0388353892735, 81.5673907143729, 84.77331038883754, 101.02648094722203, 64.93556417737688, 54.57350022452218, 60.07063702174595, 60.97618184770857, 99.21257727486747, 89.45238018035889, 96.54696341923305, 92.18388380323137, 91.6342465536935, 78.13930238996232, 72.9424945286342, 79.4015051977975, 83.73257446289062, 82.3940179007394, 80.70470932551792, 76.90256472996303, 77.52592931474958, 84.0140459878104, 88.10076795305524, 96.60131917681012, 96.03892503465924, 87.22960976191929, 85.94739614214215, 89.15637302398682, 93.57082067217145, 86.8741260256086, 88.67216696058, 87.08944375174386, 90.65255641937256, 95.16816983904157, 95.29402950831822, 89.35309737069267, 74.08158915383476, 41.094985076359336, 15.043016706194196, 2.847522471632276, 2.4134461411408017, 2.7973736311708177, 1.278456598520279, 0.4955423208219664, 0.0633910484611988, 0.146037400833198, 0.1981244630047253, 1.2790692342179162, 15.562212160655431, 34.26322092328753, 31.35668522971017, 54.38562093462263, 133.30281584603446, 44.728316238948274, 24.405022961752756, 26.68557459967477, 35.44575221197945, 44.675245898110525, 50.591181891305105, 75.02087443215507, 74.88312639508928, 86.23517663138253, 95.77162783486503, 41.52467557362148, 2.364594442503793, 0.05249989305489829, 0.06936062313616276, 0.00853925634042493, 0.03261563128658703, 0.06954749846564871, 0.06518096277224165, 0.01722372426385326, 0.03780156586851392, 0.0150153455324471, 0.04154196301741259, 0.025866085696699362, 0.057512485688286166, 0.06172816947634731, 0.08699551756892886, 0.09922661339598042, 0.04500089366255062, 0.031615199255091805, 0.09983184627656426, 0.041945735458284616, 0.059336828866175244, 0.062494486570358276, 0.07375346563224282, 0.06570452717798096, 0.04973502570231046, 0.061253459591950686, 0.009149897993276162, 0.07337251571672303, 0.06651552580296993, 0.03200626273506454, 0.038527598338467736, 0.25668032520583695, 0.1139522482241903, 0.1718070480440344, 0.23866424337029457, 0.2070403452962637, 0.2963690869510174, 0.12668689845928124, 0.1167899766670806, 0.08742777151720864, 0.08337522111833096, 0.1809472268713372, 0.13189291767776012, 0.2426959898855005, 0.16886947995850018, 0.060004242695868015, 0.08502967948360102, 0.20690230413206986, 0.20639993037496293, 0.191383244735854, 0.12441037275961467, 0.11817010332431112, 0.1075517563149333, 0.23129288320030483, 0.2746552335364478, 0.2563335123871054, 0.24363858359200613, 0.18418975573565277, 93.60902186802456, 148.46089472089494, 120.98624447413853, 124.18066487993512, 97.02905723026821, 70.9862848009382, 45.07001822335379, 52.115182399749756, 80.48728629520961, 111.62177508217948, 88.47537313188825, 73.44043718065534, 49.25350775037493, 39.95341689246041, 1.2611785999366214, 0.36972241369741304, 0.30673965332763536, 0.503203632576125, 0.28043146644319805, 0.5988157849226678, 1.2168844853128706, 4.701079513345446, 29.626830441611155, 76.68867833273751, 96.37425899505615, 105.69703919546944, 98.91662570408413, 100.78860936846051, 94.81448568616594, 99.2221588407244, 94.7201360974993, 88.75719901493618, 83.84314809526715, 92.70653424944196, 93.72185366494315, 96.91325855255127, 87.91409070151192, 89.68512398856026, 92.23553671155656, 100.81447056361607, 94.67683492388043, 96.27606010437012, 89.60968739645821, 75.559707232884, 68.49859346662248, 77.02857031141008, 86.12024647848946, 91.88884244646344, 86.84726428985596, 91.08733299800328, 83.46556908743722, 86.54362106323242, 84.12776020595005, 84.75464752742222, 72.136552129473, 84.7443711417062, 88.2524471282959, 105.75976058415004, 68.0165274483817, 61.35340649741036, 69.783433505467, 62.92269189017159, 104.1024832044329, 96.86283547537667, 101.36653968266079, 96.77021598815918, 95.73161315917969, 82.23639106750488, 76.11549363817487, 83.39403738294328, 88.01602077484131, 86.01665578569684, 83.9162014552525, 82.45887238638741, 82.01550783429826, 90.16247912815639, 92.2993072782244, 102.10566820417131, 99.73182310376848, 92.16208730425153, 90.93124866485596, 92.33962767464774, 100.01136997767857, 88.05036572047642, 89.35963562556675, 89.19763837541852, 92.92450618743896, 99.65231486729213, 99.55505398341587, 92.11711856297084, 76.941175869533, 43.49710239682879, 17.445670775004796, 5.81934300490788, 6.31545524086271, 4.210006892681122, 1.6452095529862811, 0.5277385360428265, 0.1190755268824952, 0.18213853080357822, 0.23991687329752104, 2.8957692427294592, 23.896546840667725, 46.943186555589946, 53.046515464782715, 86.40188476017543, 160.4713979448591, 77.01445157187325, 54.15393672670637, 28.94558388846261, 33.45590625490461, 53.95639249256679, 63.04933670588902, 87.28036635262626, 88.50366619655064, 92.73872525351388, 107.42913477761405, 56.164307662418906, 4.55942268030984, 0.2302668025451047, 0.13192297677908624, 0.1260799488851002, 0.11434563568660192, 0.17486326476292952, 0.16731220137860092, 0.14370438030787877, 0.12887156408812317, 0.14396477490663528, 0.16679931032870496, 0.1183058103280408, 0.13879458233714104, 0.1393599377146789, 0.12928267488522188, 0.1288212032190391, 0.11119987948664597, 0.12943577952682972, 0.2606583317475659, 0.14559619022267206, 0.20481836024139607, 0.1965820850538356, 0.14144698929573807, 0.14749266845839365, 0.12507788836956024, 0.08681487119091408, 0.17497431380408152, 0.19695732848984854, 0.15374239667185716, 0.09955187594251973, 0.11742024070450238], [0.0766971337475947, 0.051701606783483706, 0.024365201858537536, 0.017079406650736928, 0.10466261527368001, 0.06231370448533978, 0.05680319267724242, 0.053186356755239625, 0.10912891597087894, 0.02946799893730453, 0.10425775378410305, 0.059827918585922034, 0.03170397538425667, 0.10399647708982229, 0.13020879376147473, 0.08182852768472262, 0.020254407709996616, 0.03625286736392549, 0.04948453092947602, 0.03453688283583947, 0.035359969562185664, 0.12170198666197912, 0.09077701358390705, 0.18399057856627873, 0.3178665419774396, 0.5742087396127837, 33.66063840048653, 115.86338629041398, 99.33998639242989, 101.50628185272217, 67.62230750492641, 56.69183921813965, 24.213306529181345, 15.88352118219648, 56.51877348763602, 69.50003038133893, 44.14936801365444, 50.56864888327462, 29.22031913484846, 16.83576832498823, 0.32188032088535173, 0.03836745050336633, 0.08410795751426901, 0.05220069982377546, 0.1059721200061696, 0.18008924648165703, 0.3667177249278341, 0.5906696191855839, 18.619648831231252, 82.0125617980957, 93.47830540793282, 95.1357148034232, 86.96402181897844, 96.36137008666992, 84.33176626477922, 81.3344315120152, 80.51971353803361, 80.85371344430106, 79.93359824589321, 85.53062234606061, 88.80454404013497, 93.33226816994804, 80.4827630179269, 84.09062208448137, 80.52755805424282, 79.1378002166748, 85.05870069776262, 90.30681405748639, 86.10135432652065, 79.18459633418492, 62.057064465114046, 62.739572116306846, 66.42104734693254, 76.88365868159703, 75.96756649017334, 76.79355444226945, 69.37865230015346, 65.18918037414551, 65.35011454990932, 65.77095304216657, 62.69174766540527, 74.47194589887346, 68.25196020943778, 80.00789533342633, 78.13443865094865, 96.74270806993756, 34.332105364118306, 31.731599603380474, 90.37595558166504, 81.77364104134696, 79.56474617549351, 72.85473878043038, 78.36453519548688, 71.3759536743164, 72.38286576952252, 65.96681581224713, 74.44166564941406, 78.13437611716134, 78.70146724155971, 74.25207710266113, 71.16085829053605, 72.45734351021903, 71.15395872933524, 77.62873486110142, 83.83821487426758, 83.90309715270996, 77.46583434513637, 84.58898162841797, 87.52077402387346, 82.29661805289132, 85.59559495108468, 85.60238334110805, 85.9172340120588, 83.814222744533, 83.66209888458252, 80.50255843571254, 81.5088243484497, 78.09283978598458, 53.66314377103533, 24.88142967224121, 6.1948727284158975, 0.5279982249651636, 1.185326527271952, 0.5322901489479201, 0.29557978787592476, 0.05496027799589293, 0.1692649301673685, 0.07250559902084724, 0.10310310431356941, 0.2347315086850098, 11.360807572092328, 25.984939098358154, 52.372008664267405, 34.67483568191528, 31.672779628208705, 48.55869831357683, 22.883442163467407, 24.05211353302002, 12.471173133168902, 33.93629775728498, 40.961881910051616, 59.7703150340489, 75.89421435764858, 72.53517723083496, 80.31750011444092, 58.84882409232003, 5.375144234725407, 0.21888992802373, 0.055934009674404345, 0.06327769918633358, 0.05348951941622155, 0.03979178371706179, 0.04007970308884978, 0.10563659122479813, 0.0261032014553036, 0.05437054285513503, 0.012783717646795725, 0.04115982227293508, 0.045585214093859704, 0.05892012015517269, 0.07994281779974699, 0.060161927448851724, 0.025579635353226746, 0.014835338673687406, 0.05963311118206807, 0.050998708964990716, 0.04159615082400186, 0.019106161913701465, 0.06798400450497866, 0.05113752365910581, 0.018320126592048576, 0.02867468972025173, 0.04473363568208047, 0.055973710758345466, 0.062184470705688, 0.043845239960189374, 0.04603213796924267, 0.0350879482658846, 0.09521649179181882, 0.0029816925816703588, 0.08111770118453673, 0.04983457696757146, 0.04011488173689161, 0.028776924591511488, 0.055852164780454974, 0.040739988908171654, 0.06766700651496649, 0.03100946086591908, 0.05685170114572559, 0.06204933367137398, 0.015510918672329612, 0.022894097226006643, 0.029157314715640884, 0.014081740718601006, 0.04620033662234034, 0.1179703561855214, 0.045568478027624745, 0.07499351552022354, 0.028847692401281426, 0.1552675941160747, 0.4465463384985924, 0.5008428735392434, 42.24246965135847, 141.0528504507882, 109.62487670353481, 119.06723540169853, 82.15887001582554, 89.31308964320591, 40.83166224615914, 28.887634175164358, 37.0070332799639, 58.489254815237864, 50.175498962402344, 48.2528976712908, 41.91139146259853, 21.001517363956996, 0.5731842603002275, 0.10889127265129771, 0.2629709962223257, 0.25606831376041683, 0.3367975875735283, 2.4028464470590865, 1.0214986439262117, 0.8727224586265427, 22.771452835627965, 94.28045409066337, 95.67105960845947, 100.74063205718994, 92.42148440224784, 99.57567623683384, 86.49981267111642, 85.49954305376325, 83.51167733328683, 84.75484902518136, 81.87417452675956, 89.63233852386475, 91.59194592067173, 95.61559213910783, 83.49070766993931, 89.0114336013794, 80.36865970066616, 84.25307791573661, 89.55416434151786, 92.68711403438023, 90.64592783791679, 81.8028095790318, 65.27337169647217, 67.93310737609863, 68.92771421160016, 80.99835409436906, 80.87122290475028, 83.17744813646588, 73.36409732273647, 70.3354400907244, 68.41678537641252, 68.92654691423688, 66.17852047511509, 78.09835665566581, 68.77510397774833, 83.35454382215227, 80.21716812678746, 100.87109838213239, 40.400748865945, 37.379571369716096, 92.8344783782959, 84.40966251918248, 82.09540516989571, 75.61357661655971, 80.57313823699951, 76.49909673418317, 75.82696969168526, 68.11740834372384, 77.69083091190883, 82.75019645690918, 82.726197378976, 78.52034854888916, 74.49323517935616, 74.97295270647321, 73.21612848554338, 82.12824235643659, 86.61861297062465, 87.38703509739467, 82.15954399108887, 87.59311866760254, 91.12847328186035, 83.70022365025112, 83.72306932721818, 89.24262796129499, 86.62589468274797, 86.05976935795375, 82.20324121202741, 79.60032095227922, 82.09682260240827, 78.14656325748989, 54.996718474796836, 26.43511288506644, 6.3179722258022855, 0.41202475662742344, 1.729624629020691, 1.6619493918759483, 1.3306289932557513, 0.7518494789089475, 0.16410532274416514, 0.05544311333713787, 0.04657841294205614, 0.028160506061145237, 13.006091492516653, 30.462709154401505, 50.154574462345664, 43.13837385177612, 36.115339687892366, 50.43142543520246, 24.318071467535837, 31.853957380567277, 28.928915160042898, 54.100112506321494, 52.77027245930263, 67.58048629760742, 83.6741748537336, 81.77730969020298, 93.48259939466203, 75.59602546691895, 8.059573377881732, 0.28461604618600433, 0.040240030735731125, 0.07354611890124423, 0.028791675942816904, 0.04973344471571701, 0.042007258228425465, 0.017414865882268975, 0.016516570334455798, 0.013718440347085041, 0.015670986779566323, 0.02300911400068019, 0.026367730028661232, 0.0392026965772467, 0.04599605347695095, 0.05548569480223315, 0.018048363139054606, 0.01369109793033983, 0.09120263824505465, 0.0558573725367231, 0.013795144490099378, 0.047302650686885626, 0.035165396252913136, 0.0359903489505606, 0.07560978816556078, 0.03176430732543979, 0.02214362222834357, 0.060557289448167594, 0.012716960827154773, 0.027698934311047196, 0.06938216662300484, 0.12117049018187181, 0.13886785054845469, 0.10011245443352632, 0.18263618195695536, 0.1310499600533928, 0.19906204912279332, 0.13104058269943508, 0.16537178121507168, 0.06508964552943196, 0.16324583600674356, 0.10910307057201862, 0.14348218723067216, 0.18233849507357391, 0.19077120614903315, 0.12212988441543919, 0.10096678430480616, 0.15028964408806392, 0.17046474292874336, 0.18560528835015638, 0.21119414669062408, 0.2616240770689079, 0.31962077213185175, 0.368757319769689, 0.8132291053022657, 0.5814984855907304, 59.318140166146414, 152.66508293151855, 123.58723313467843, 133.34508868626185, 91.8997858592442, 84.54777881077358, 38.32560682296753, 26.284474202564784, 83.8588718686785, 100.77442114693778, 64.16101373944963, 78.28146948133195, 49.41195099694388, 28.94771351133074, 0.5847485054816518, 0.18495587605450833, 0.43619023848857197, 0.16317748038896493, 0.17203279664473875, 0.8507091541375432, 2.1918539745467047, 3.404131587062563, 24.36998667035784, 95.48912102835519, 99.10385186331612, 104.89256286621094, 96.17128126961845, 103.7304836000715, 90.39299951280866, 89.11496176038469, 88.09340286254883, 88.06579766954694, 87.05433450426374, 93.51784760611397, 95.65887941632951, 100.93812070574079, 88.65098885127476, 93.68168612888881, 87.30556052071708, 87.12378869737897, 93.61591448102678, 95.0122731072562, 93.80899797167096, 88.4500399998256, 70.86751229422433, 72.37276308877128, 73.99702262878418, 86.21903596605573, 85.14835330418178, 87.18735081808907, 77.2997168132237, 72.45605114528111, 73.90343734196254, 74.17042882101876, 70.38348688398088, 82.16938958849225, 73.72598729814801, 87.89791529519218, 85.72120448521206, 105.20783737727574, 47.19450984682356, 44.41883305140904, 97.84910447256905, 93.09008870806012, 86.74561214447021, 82.81918512071881, 86.74340956551688, 82.79982049124581, 80.63187135968889, 72.62424618857247, 81.27997847965786, 86.8793580191476, 87.16428974696568, 81.65222821916852, 77.06917558397565, 79.16345296587262, 76.89112104688371, 86.57977948869977, 90.34334073747907, 93.08876855032784, 88.03532981872559, 91.235274042402, 94.48011752537319, 85.93377767290387, 85.75102615356445, 93.993896484375, 92.0847121647426, 88.65292045048305, 83.6633356639317, 82.42443016597203, 86.07093511308942, 81.9154051371983, 59.6012236731393, 30.12346683229719, 10.147197859627859, 4.382323954786573, 4.191668859549931, 3.052192734820502, 2.359409783567701, 0.647363499871322, 0.48413066459553583, 0.24768159378852161, 0.18213720087494167, 1.544800918017115, 18.372369391577585, 44.804715156555176, 72.91074126107353, 42.59609127044678, 44.62988805770874, 73.73202528272355, 32.89462035042899, 36.89180782863072, 23.64601390702384, 51.92808825629098, 57.07362536021641, 79.81073325020927, 95.00144781385148, 92.20001057216099, 101.18469837733677, 91.40901374816895, 11.520484123911176, 0.37747109362057274, 0.13615280123693602, 0.17534364041473183, 0.09273117408156395, 0.12681883280830725, 0.19759197586349078, 0.1831711253949574, 0.08200387470424175, 0.09744226985744067, 0.08340491381074701, 0.10904825172786202, 0.12970800777631147, 0.10613390989601612, 0.17448130383023194, 0.17903058257486137, 0.09657342612211194, 0.15015773688043865, 0.23604585815753254, 0.11722516188664095, 0.11287029699555465, 0.16332185907023294, 0.12852547051651136, 0.1834367582840579, 0.1733730390135731, 0.11522694411022322, 0.14436707831919193, 0.11773531165506158, 0.17914621851273946, 0.13713800694261277], [0.04204853351360985, 0.10138404262917382, 0.03556283117671098, 0.05438936880922743, 0.033758223189839294, 0.11079477372446231, 0.08742338139563799, 0.1265108593340431, 0.054117561251457245, 0.05641858885064721, 0.04128399418134775, 0.00903098049041416, 0.06867043767124414, 0.07415501587092876, 0.040906335160668404, 0.05065361623253141, 0.03903657763398119, 0.020533149895657386, 0.01981666780609105, 0.025801523089674965, 0.03874883468129805, 0.028335249184497764, 0.05996286563043084, 0.3384056341435228, 0.44230538606643677, 22.818749223436626, 109.09843948909214, 99.92855439867292, 97.356171471732, 64.92659405299595, 40.35769087927682, 17.997449806758336, 30.88502413885934, 64.19016143253872, 68.0180630002703, 50.34872797557286, 50.511534690856934, 26.944447108677455, 8.210283279418945, 0.2904037599052702, 0.11788355798593589, 0.07850572134235076, 0.0622836725254144, 0.07332123204001359, 3.5793831774166653, 3.781507577214922, 0.9101042555911201, 14.292694636753627, 86.58768653869629, 98.71528775351388, 97.24562563214982, 92.13439178466797, 94.59706265585763, 90.73446873256138, 88.39987400599888, 85.20455728258405, 84.3768253326416, 79.82256603240967, 81.08394200461251, 86.21146937779018, 87.88356031690324, 87.44954109191895, 83.06180926731655, 84.51606028420585, 72.47351891653878, 74.87094620295933, 81.32978316715786, 88.34602546691895, 84.63677133832658, 73.69620731898716, 59.40765380859375, 62.90243789127895, 63.62520340510777, 72.65344251905168, 70.98402663639614, 74.26313168661935, 63.11627565111433, 65.16400010245187, 63.739758355276926, 68.95137977600098, 66.63530894688198, 70.36641516004289, 62.99043682643345, 78.29449735369, 71.29445130484444, 94.22575092315674, 50.11444166728428, 26.832902465547832, 93.82122680119106, 71.7099049431937, 74.04120622362409, 67.6927900314331, 78.38822855268205, 75.04856300354004, 79.11658041817802, 66.68252890450614, 68.19321319035122, 75.44868891579765, 76.59610748291016, 73.4639151436942, 71.7533311843872, 65.93985680171421, 65.77117538452148, 71.54223101479667, 86.67544228690011, 84.57045773097447, 82.72405733380998, 81.05255004337856, 83.22027683258057, 86.84916114807129, 88.30599689483643, 85.87691361563546, 84.40789767674038, 83.30307156699044, 79.79323768615723, 76.57507528577531, 75.19130679539272, 75.29659979684013, 70.99428912571499, 50.973454407283235, 14.792089462280273, 1.6065061326537813, 1.535207844206265, 0.8148195913859776, 0.5824942493012973, 0.7525556438735553, 0.14922541619411536, 0.0232284979429096, 0.017631114992712225, 0.06673702677445752, 0.15784118244690554, 10.650518417358398, 16.949362686702184, 38.26874623979841, 38.81094544274466, 32.44662134987967, 58.24440377099173, 24.02243777683803, 18.72238142149789, 9.190801773752485, 22.336431332996913, 40.60573809487479, 53.67442764554705, 62.52587332044329, 70.99584552219936, 80.94979313441685, 65.9275654384068, 1.3793313056230545, 0.13931158530925, 0.0318386544074331, 0.034426831241164885, 0.013135378598235548, 0.03008930291980505, 0.02387655316852033, 0.03715371759608388, 0.0782321903056332, 0.016530202102980444, 0.05762780271470547, 0.06175117181347949, 0.09365978318133525, 0.032747131373201094, 0.060869619117251465, 0.032275610603392124, 0.05214709894997733, 0.04051216399031026, 0.0558888022787869, 0.046205524022557905, 0.026934074370988777, 0.011035768182149954, 0.03874969642077174, 0.03850506758317351, 0.09978221822530031, 0.017743124160915613, 0.16036488488316536, 0.035324010598872385, 0.13342263416520186, 0.09594930961195912, 0.05591241529743586, 0.02402256372650819, 0.09009835642895528, 0.04415474692359567, 0.0422689522217427, 0.028667493856378963, 0.07152729401631014, 0.04804708163387009, 0.08066745927291256, 0.06489444457526718, 0.02112141261542482, 0.04117499431595206, 0.11041958457125084, 0.10166354477405548, 0.019432091120896593, 0.02375863565664206, 0.09839301955487047, 0.07776514108159713, 0.08714371640235186, 0.04576195211016706, 0.06854443371828113, 0.058232126358364306, 0.33963698521256447, 0.36204584847603527, 30.0276129586356, 133.43648529052734, 111.87127794538225, 113.58408532823834, 78.2861247743879, 61.34118461608887, 38.31189802714756, 38.73410184042794, 21.66770543370928, 54.79800346919468, 49.48655380521502, 45.92031792231968, 39.216077532087056, 11.093164699418203, 0.40504439547657967, 0.06019548100552388, 0.05032658949494362, 0.11382228162671838, 0.3518354706466198, 10.375325458390371, 4.511453185762678, 0.5067876545446259, 21.05031977381025, 93.48929745810372, 98.59734903063092, 101.69750322614397, 95.87430136544364, 99.01457445962089, 95.31842463357108, 92.59741279057094, 89.22468771253313, 86.72066811152867, 81.76590769631522, 85.6595322745187, 89.06405925750732, 91.44069753374372, 91.51322283063615, 88.17956747327531, 86.9597556250436, 76.90148775918144, 77.03236402784074, 84.24462890625, 91.49583148956299, 88.59368010929653, 77.98370443071637, 63.513156754629954, 67.15129607064384, 67.68659223828996, 76.5666332244873, 74.54344981057304, 78.01729897090367, 66.4387652533395, 70.00526864188058, 65.40367126464844, 72.17068862915039, 69.9196251460484, 73.98967838287354, 66.10218756539481, 82.37526471274239, 75.28537150791713, 96.06514753614152, 53.5107558795384, 29.543577126094274, 98.44422463008335, 75.8453059877668, 78.1097378049578, 70.25176988329206, 82.78495134626115, 78.69284452710832, 84.46546350206647, 69.04204681941441, 69.0674911226545, 77.6091478892735, 81.81052207946777, 75.73767839159284, 76.52907821110317, 69.16892092568534, 68.860671043396, 75.34771769387382, 89.1867436000279, 87.5890748160226, 86.63558047158378, 87.50623839242118, 84.09393637520927, 90.699720791408, 92.83571515764508, 87.63669776916504, 87.89876297542027, 84.6020998273577, 80.77653285435268, 74.67424270084926, 74.18314402444022, 75.55503804343087, 74.20253644670758, 56.255065032414024, 18.40582844189235, 1.8103537942681993, 0.4955672909106527, 1.203516151223864, 2.02779050384249, 1.2454207369259425, 0.3155520590288298, 0.1868583932518959, 0.0018338969509516443, 0.07970441452094487, 0.023004935921302865, 9.885236876351492, 23.68633082934788, 29.897233486175537, 21.72371312550136, 28.244060754776, 35.439057622637065, 23.899920191083634, 24.98290637561253, 20.513432468686783, 33.12093012673514, 55.462324210575645, 60.68323884691511, 71.88450622558594, 79.98270116533551, 90.9081528527396, 83.12800475529262, 3.3166040437562123, 0.10893230366387538, 0.06501067762396165, 0.02823847482380058, 0.043465121250067434, 0.03788941240470324, 0.01842983891921384, 0.13848336546548776, 0.09079975807773215, 0.04978151892178825, 0.03332930763385125, 0.04031669162213802, 0.024736570859594003, 0.028319269684808593, 0.04203333093651703, 0.05613595526665449, 0.06960507894733123, 0.03241106994184, 0.03849607360150133, 0.06674499277557645, 0.0730966165927904, 0.03204726999891656, 0.05045816422040973, 0.016223399101623466, 0.042769931589386294, 0.02860545539962394, 0.06739926338195801, 0.019659410530169095, 0.050666423581008396, 0.15347073839179107, 0.12101627274283341, 0.17884199055177824, 0.13035774576876843, 0.0992133276803153, 0.222056135269148, 0.26093501118677004, 0.29412099186863216, 0.13106344932956354, 0.1461199921156679, 0.20718104631773063, 0.0909540569409728, 0.12280950509011745, 0.16517187122787746, 0.2231652143278292, 0.15729466320148536, 0.1723821878965412, 0.28459490303482327, 0.10310936040644135, 0.29642839091164724, 0.139569740742445, 0.22962203142898424, 0.24623311151351246, 0.5762401106102126, 0.7108160778880119, 42.70991665976388, 153.8481388092041, 123.3207836151123, 127.12806292942592, 90.6685928617205, 62.53271729605538, 28.944836957114084, 49.624663148607524, 90.31210163661412, 91.26444258008684, 69.09295627049038, 75.25638362339565, 46.817886216299875, 14.99253283228193, 0.9674093063388551, 0.2537178141730172, 0.17650883431945527, 0.3178775613861424, 0.23498813062906265, 5.85857036284038, 6.139715322426387, 3.7655145611081804, 20.502548115594045, 97.61699989863804, 105.5392872946603, 105.39474391937256, 98.9491502216884, 101.9079919542585, 98.7766056060791, 95.58451284681047, 94.11661556788853, 91.56295108795166, 85.55094582693917, 88.22817012241909, 95.41215583256313, 94.73563752855573, 94.8679312297276, 92.05156925746373, 93.22136797223772, 82.3952407836914, 83.97487899235317, 88.84039674486432, 95.24006979806083, 94.09058066776821, 82.18828868865967, 67.3145717893328, 71.3761899130685, 71.36803272792271, 80.1763196672712, 77.76959569113595, 83.3396051951817, 71.78190912519182, 74.20541994912284, 69.18210860661098, 76.27668489728654, 74.56205708639962, 78.1819851739066, 70.20472363063267, 85.35942568097795, 80.60978998456682, 101.91849763052804, 56.86120850699288, 33.05784395762852, 102.94910308292934, 79.88416876111711, 81.40645653860909, 73.64410972595215, 85.21270751953125, 82.85398169926235, 86.88062259129116, 73.89603056226457, 73.43633079528809, 81.13126618521554, 82.39059938703264, 80.24400206974575, 80.49716663360596, 74.00717394692558, 73.46287291390556, 77.57358700888497, 94.12327194213867, 91.9666553224836, 90.58505467006138, 89.53371579306466, 85.73152256011963, 93.06502655574253, 98.32630675179618, 92.7733689716884, 91.08066967555455, 89.37229524339948, 83.45990630558559, 77.50807244437081, 75.55603163582938, 78.78772912706647, 76.32300158909389, 58.9803534916469, 19.517693076814922, 5.073928969247, 6.152543434074946, 4.42564640726362, 3.3279997408390045, 4.215114687170301, 0.23694147009934696, 0.24592274959598268, 0.14218344406357833, 0.1998494075877326, 0.265195261154856, 18.585307359695435, 30.056604317256383, 63.50834165300642, 51.361146518162315, 42.300501005990164, 82.09600271497453, 33.001501015254426, 26.600526911871775, 14.6826605456216, 33.95801782608032, 58.29234981536865, 73.03403704507011, 83.34650475638253, 91.10926846095494, 98.45297241210938, 99.50249780927385, 5.006452407155718, 0.3310422806867531, 0.1575747760278838, 0.1464122235774994, 0.08003572281450033, 0.15813196184379713, 0.1745388435998133, 0.12350884399243764, 0.2730726184589522, 0.09821358096918889, 0.19043104297348432, 0.13037591693656786, 0.25024509908897535, 0.1472648571112326, 0.17398988162832602, 0.21149935174201215, 0.0927300409280828, 0.07469580149544136, 0.11681049556604453, 0.14889279832797392, 0.2225470282137394, 0.14236352725752763, 0.1046389751136303, 0.09871294203081302, 0.22124728081481798, 0.11245888085769755, 0.12494352486516748, 0.09162018155413014, 0.16502499553774083], [0.07876940005059753, 0.06194690202495881, 0.045262923530702076, 0.039019227493554354, 0.042573149648628066, 0.09855493158102036, 0.11958262324333191, 0.08097436066184725, 0.055822516192815134, 0.03276362655950444, 0.042851796839386225, 0.03894183039665222, 0.02092975191771984, 0.05804996006190777, 0.042977872038526196, 0.05301960338173168, 0.1575024306241955, 0.06349212303757668, 0.05235900204362614, 0.014580738763990147, 0.049393804012132544, 0.07268931916249649, 0.1742605356765645, 0.1962999909051827, 6.21771536554609, 115.84178434099469, 99.67344433920724, 98.28786236899239, 75.81599153791154, 47.30531276975359, 47.76088878086635, 37.12408263342721, 47.56288596561977, 84.17835003989083, 54.15415212086269, 53.11575773784092, 37.929052284785676, 7.0916914854730875, 0.29576641214745386, 0.14438618586531707, 0.1936288428093706, 0.10311608468847615, 0.5551827262554849, 0.8862331222210611, 17.678353786468506, 14.394635132380895, 5.1224842837878635, 85.92810099465507, 92.83461039406913, 93.98459284646171, 87.43791675567627, 98.41979476383754, 92.1683406829834, 95.84807191576276, 91.1961487361363, 90.43825313023159, 77.7835476739066, 81.21802139282227, 83.10708372933524, 86.4128281729562, 86.47947529384068, 85.5013495853969, 84.01763125828334, 76.38131781986782, 67.31731632777623, 69.56052139827183, 81.16754273005894, 89.3524511882237, 86.59717082977295, 65.72714465005058, 58.16337735312325, 60.62743091583252, 64.75172873905727, 67.92900099073137, 66.33575820922852, 62.62091078077044, 60.98941816602434, 62.20613806588309, 63.452137674604145, 66.72692789350236, 67.1371078491211, 67.5136307307652, 61.92591026851109, 70.55565629686627, 69.55318410055978, 82.19774518694196, 74.03232642582485, 38.20140082495553, 86.9557534626552, 74.63169193267822, 75.13837541852678, 78.4232405253819, 86.08982726505825, 87.75720732552665, 87.17604609898159, 82.06005273546491, 64.06214087350028, 68.7456853049142, 76.34121281760079, 73.0849256515503, 71.03818784441266, 68.07884584154401, 64.63576330457414, 67.0005271094186, 80.40796566009521, 76.31526824406215, 81.78095749446324, 89.62767628261021, 85.59166921888078, 83.18324988228935, 76.58888830457414, 76.0695799418858, 78.03910936628068, 84.23156629289899, 77.63526616777692, 74.29150812966483, 79.46195452553886, 79.13631330217633, 79.41686071668352, 80.68289893014091, 65.6049883706229, 15.515124218804495, 1.123458898493222, 1.7381349780729838, 1.036246738263539, 1.2748802304267883, 0.8635448110955102, 0.05868787797433989, 0.04788820265925356, 0.052320376437689574, 0.031590595575315614, 0.11242289136030845, 5.2279388308525085, 24.694658620016916, 53.638244901384624, 50.3732898575919, 66.63765048980713, 74.95331709725517, 49.9624776159014, 34.86191940307617, 18.132052046912058, 12.302952902657644, 23.64978677885873, 42.253354004451204, 64.34453650883266, 65.11906610216413, 86.78368132455009, 45.79496199744088, 0.19761083913700922, 0.06263846491596528, 0.02696977209831987, 0.026540921003158604, 0.0303308546010937, 0.08240123159651246, 0.03026796119021518, 0.0583372042913522, 0.018467438240934695, 0.05039990520370858, 0.03292981335627181, 0.05860555810587747, 0.08401438074984721, 0.029713438624250035, 0.03274167255897607, 0.025153089580791335, 0.07515265233814716, 0.04611560456188662, 0.08478113210627011, 0.07415135178182806, 0.04542524267786315, 0.11028282583824225, 0.09854537780795779, 0.07917366442935807, 0.01629194979821997, 0.05329614032858184, 0.07799264030264956, 0.028125544544309378, 0.11285713341619287, 0.0289132694181587, 0.016329640722168342, 0.031202744958656173, 0.11163084421839033, 0.08428955384130989, 0.04798580313633595, 0.058272648469677994, 0.07963738883180277, 0.04092698637396097, 0.013735640361639006, 0.03247082852093237, 0.05986515658774546, 0.05246959307364055, 0.05718343013099261, 0.030275523462998014, 0.07712950304682765, 0.05313820451764124, 0.05617512709328106, 0.10847153767411198, 0.09763526557279484, 0.0391039968734341, 0.19675979337521962, 0.25009837267654283, 10.061503989355904, 144.0437581198556, 106.93817506517682, 114.58507755824498, 86.51231942858014, 72.76243891034807, 61.01076998029436, 37.82136910302298, 39.94370331083025, 73.80427265167236, 58.955541474478586, 51.189498220171245, 47.22781603676932, 10.595013601439339, 0.36314860358834267, 0.4099646700280053, 0.22870416353855813, 0.05917567679924624, 0.4888705845390047, 1.4722475026335036, 27.171298844473704, 2.705102856670107, 7.470247149467468, 94.1622235434396, 96.66661139896938, 98.32407638004848, 89.36058058057512, 102.4982761655535, 95.1029748916626, 96.41305078778947, 92.4896045412336, 95.11056927272251, 83.33091299874442, 84.84785761151994, 85.2007566179548, 90.32345499311174, 88.23928724016461, 89.43781675611223, 86.02753666469029, 80.96222346169608, 71.89830534798759, 72.3664332798549, 84.28737422398159, 92.32147897992814, 89.20464215959821, 72.29338686806815, 60.73926912035261, 64.6006054197039, 69.43409892490932, 71.55944865090507, 71.56012262616838, 68.2019123349871, 63.313826833452495, 66.40972873142788, 65.90807574135917, 70.3152972630092, 69.83346053532192, 70.17298425946916, 65.27746418544224, 75.67328248705182, 74.4614680153983, 86.82526629311698, 79.52614893232072, 42.036559786115376, 90.31809793199811, 81.23399530138288, 79.68034335545131, 82.88430363791329, 90.29676001412528, 91.60502937861851, 91.03470734187535, 85.31825760432652, 67.63343851906913, 71.39445672716413, 79.41078104291643, 76.28220176696777, 73.82369981493268, 69.5643151147025, 66.59835842677525, 70.11033235277448, 82.45952551705497, 79.57309096200126, 85.4854382106236, 90.87450967516217, 89.65573310852051, 84.81264414106096, 77.70775672367641, 78.60647147042411, 81.79768180847168, 88.31200013841901, 77.33378383091518, 74.5991952078683, 79.79045840672084, 83.32618127550397, 84.44065843309674, 86.26565837860107, 74.24755382537842, 21.732693672180176, 1.1307264970881599, 0.4550108185836247, 0.4684009743588311, 1.9627130244459425, 2.2548057394368306, 0.17684948604021752, 0.09194027366382734, 0.07970201929232903, 0.03474939661100507, 0.20056094654968806, 5.845726183482578, 31.8204288482666, 41.34245211737496, 32.00349651064192, 61.22792203085763, 37.91553456442696, 32.09121404375349, 35.442615100315635, 30.549579007284983, 27.2636490889958, 38.75243466241019, 52.28238385064261, 73.1184993471418, 75.85214301518032, 99.28590856279645, 64.353499685015, 0.40602786413260866, 0.016108845427100147, 0.04115762381947466, 0.0859625158565385, 0.0436313114395099, 0.043592356744089296, 0.009527478982428355, 0.022255824779027274, 0.034839448386004994, 0.04124567052349448, 0.12321839029235498, 0.014819591572242123, 0.09616445949567215, 0.018528318099145378, 0.019695824111944864, 0.030047861393541098, 0.11503660146679197, 0.011693808898728873, 0.07804923690855503, 0.06512957731527941, 0.05950690366859947, 0.05748025527490037, 0.06431016485605921, 0.03539239675072687, 0.008885327011479862, 0.03918058990633913, 0.0847184829679983, 0.0666051059961319, 0.20348487608134747, 0.2184316183307341, 0.12267189818833556, 0.14931572920509747, 0.22215294864560875, 0.17116883157619409, 0.21594522174979958, 0.2636505626142025, 0.12779282911547593, 0.1104993802894439, 0.14027325942048005, 0.17870704350726946, 0.15855937105204376, 0.15748557581433228, 0.1798059038285698, 0.14242813736200333, 0.3296761182802064, 0.13376298733055592, 0.14777389408222266, 0.167057031499488, 0.19565258707318986, 0.23959902035338537, 0.38892072066664696, 0.6844261682459286, 14.309442400932312, 159.77771759033203, 121.4147537776402, 126.71371405465263, 98.70517812456403, 72.5939450945173, 64.16319547380719, 51.41428286688668, 66.41435623168945, 116.35294941493443, 76.59973444257463, 78.30929006849016, 59.50117656162807, 13.136535235813685, 0.9119736467088971, 0.6022860301392419, 0.4998303364430155, 0.2625614053436688, 1.6687021723815372, 0.6455021968909672, 28.247548750468663, 22.75623801776341, 5.318707925932748, 102.01177719661167, 95.79115922110421, 105.17625781467983, 91.88078253609794, 110.69447544642857, 94.88478755950928, 101.83570984431675, 94.7694752556937, 99.06339250292096, 85.32286425999233, 89.62275695800781, 89.84276471819196, 94.45659787314278, 91.34233883449009, 97.32606492723737, 92.1566468647548, 86.34759153638566, 75.25923933301652, 78.47071061815534, 90.17302649361747, 97.07368550981793, 93.0574391228812, 75.89723682403564, 64.25387641361782, 67.47364384787423, 74.2637778690883, 77.2576802117484, 75.037980897086, 72.29898016793388, 66.802218573434, 70.92858001164028, 70.52126271384103, 75.78318214416504, 74.23913260868618, 76.40656757354736, 68.72050503322056, 81.2159230368478, 77.40807397024972, 91.86093153272355, 83.15403965541294, 46.94628892626081, 96.18004294804165, 84.77044078281948, 81.34090723310197, 87.57452528817313, 94.19451877049038, 95.84472983224052, 96.38581384931291, 89.1470832824707, 70.68640749795097, 75.5495628629412, 82.57565076010567, 80.37934603009904, 77.56465162549699, 73.34981182643345, 69.81727818080357, 74.13238048553467, 86.41780308314732, 83.44056252070835, 89.86347729819161, 94.77548544747489, 93.02697127205985, 89.29633753640312, 81.98669365474156, 83.19702121189663, 86.8589928490775, 93.3094641821725, 78.60996641431535, 74.71900299617222, 81.81220354352678, 88.17492607661656, 88.58741978236607, 89.64897945949009, 73.66200828552246, 18.55362704821995, 5.30520236492157, 6.6319213679858615, 4.215201539652688, 4.910971999168396, 3.267745179789407, 0.23467090193714413, 0.3372464249176638, 0.3278062386172158, 0.15007097939295427, 0.3202092519828251, 10.592503564698355, 41.52877153669085, 84.07299450465611, 71.65199170793805, 90.51689979008266, 102.8546701158796, 71.19209739140102, 49.74474539075579, 27.7864054952349, 20.99206781387329, 38.616944789886475, 59.711588859558105, 86.81394072941372, 85.22192083086286, 105.23458794185093, 74.05159378051758, 0.5092846634132522, 0.12494532976831708, 0.11495266668498516, 0.11294489513550486, 0.10217405416603599, 0.1294415063623871, 0.06683260521718434, 0.09741757796811205, 0.1722747486616884, 0.10621362419000693, 0.19592576527169772, 0.07701665588787623, 0.15478862981711114, 0.09012312974248614, 0.09807450164641653, 0.14945539885333606, 0.22837556259972708, 0.09415176178195647, 0.15713621170393058, 0.13675899085189613, 0.15598819830587932, 0.08344390243291855, 0.17439101796065057, 0.1651366145483085, 0.13408487077270234, 0.10640254190989903, 0.1435702746467931, 0.11455041755523], [0.06233957024025066, 0.07151647816811289, 0.05903462293956961, 0.10372671192245823, 0.06060050534350531, 0.06630522744464022, 0.05118784381608878, 0.06540576820927006, 0.04215425605486546, 0.09342821275017091, 0.03546471501301442, 0.04806411625551326, 0.029364162723400762, 0.02178371707642717, 0.030336187886340276, 0.019242153902138983, 0.02414821314492396, 0.0855592285682048, 0.08798013973448958, 0.06438738892653159, 0.038262152046497376, 0.10340734584523098, 0.019809343020564744, 0.5716791067804609, 88.73043455396379, 96.07274191720145, 100.74678121294293, 60.76581818716866, 56.064639227730886, 21.991362946374075, 34.787403447287424, 90.19489247458321, 79.1986664363316, 34.87344993863787, 40.42823246547154, 32.27598401478359, 6.402208277157374, 0.024637601438111494, 0.06553323779787336, 0.11343542167118617, 0.02287972076529903, 0.2507832587829658, 0.13290724610643728, 6.388884237834385, 20.870595932006836, 1.3949512903179442, 53.61114692687988, 102.230117389134, 91.86765044076103, 86.3398026057652, 88.52971499306815, 93.98264040265764, 90.8858699798584, 88.86548668997628, 86.69639110565186, 90.45165620531354, 87.24484021323067, 85.60195255279541, 83.67207649775914, 84.74011884416852, 84.73907661437988, 81.83220740727016, 81.0846368244716, 68.7403838293893, 61.255617550441194, 62.04063892364502, 68.80474499293736, 78.71011774880546, 73.5089464187622, 61.09988757542202, 61.62690149034773, 60.447083473205566, 64.20083386557442, 64.53301334381104, 61.44243376595633, 61.59621129717146, 58.47367000579834, 61.744868006025044, 67.40030561174665, 67.57132857186454, 67.9325932094029, 63.94633524758475, 64.45445701054165, 70.43388911655971, 76.83497960226876, 74.85201236179897, 79.43129212515694, 35.82137530190604, 68.92503915514264, 80.55400289808, 78.12992232186454, 85.09086390904018, 77.93908309936523, 81.38755743844169, 82.70517907823834, 81.8306371143886, 67.52699906485421, 62.836214610508506, 66.10059642791748, 72.41557094029018, 69.81478377750942, 68.069333757673, 62.74298368181501, 63.53930977412632, 72.37246431623186, 82.20899432046073, 79.49513912200928, 83.21254348754883, 77.08306503295898, 72.57348959786552, 66.23566940852574, 67.49296678815568, 76.27704620361328, 82.28319413321358, 73.7935654776437, 75.61075564793178, 82.98312091827393, 78.87000969478062, 77.95868396759033, 79.7741926738194, 82.71130044119698, 85.76365103040422, 28.931737865720475, 0.651007124355861, 2.1405052670410702, 0.5639909793223653, 1.550237449152129, 0.527150490454265, 0.0906659441867045, 0.34906034384455, 0.442739512771368, 0.023408969598157064, 0.13954699624861988, 2.4179001535688127, 17.657462290355138, 37.12142842156546, 37.501133578164236, 66.55771146501813, 76.37252834865025, 67.03658131190709, 28.885322162083217, 20.701004300798687, 11.339439255850655, 25.545463800430298, 32.0034305027553, 66.90549659729004, 68.5768232345581, 90.30158206394741, 18.126364946365356, 0.6348040338073457, 0.14732654951512814, 0.07380937013242926, 0.07096149759101016, 0.015137332558099712, 0.06740312424621411, 0.060530446602829864, 0.0715956903461899, 0.11501427766467844, 0.05537813003840191, 0.030031651191945587, 0.04459777940064669, 0.029329727071204355, 0.01727161187279437, 0.013345289343435849, 0.08244389787848506, 0.06216705949710948, 0.12858713577900613, 0.07118783651718072, 0.04418924364394375, 0.041465227492153645, 0.07863697037100792, 0.06140302228076117, 0.04043593058096511, 0.04181929724290967, 0.10669866137738739, 0.02975181656490479, 0.10147270001471043, 0.07656497548201255, 0.055857070588639805, 0.08071701268532447, 0.09030379647655146, 0.03021711516859276, 0.015615380834788084, 0.10523697481091533, 0.04553056149078267, 0.04730448951678617, 0.052723656940673075, 0.07402888978166239, 0.02634428664376693, 0.03455551540745156, 0.0234734389066164, 0.0579398473990815, 0.007262557079749448, 0.041045804641076496, 0.05309886305726, 0.054222194744007926, 0.056340845700885565, 0.11494446998195988, 0.07625176371740443, 2.284522533416748, 113.34365681239537, 107.62264905657086, 115.51206452505929, 70.04966763087681, 73.91269929068429, 36.96110916137695, 51.85789408002581, 40.3886798449925, 52.60943555831909, 52.73234224319458, 40.24360145841326, 40.42083610807146, 9.526304227965218, 0.18194232561758586, 0.04816663271880575, 0.08069586274879319, 0.032690802788628, 0.2032464388757944, 0.09449981631977217, 1.8682446650096347, 2.538141770022256, 2.1211313009262085, 62.77978828975132, 104.68235206604004, 96.14373861040387, 89.2600679397583, 91.60563387189592, 95.71229716709682, 92.67479487827846, 90.75154045649937, 90.25506387438092, 93.55013588496617, 89.29576778411865, 89.3088720866612, 87.74342904772077, 90.04312992095947, 87.43402576446533, 86.11087335859025, 85.401212147304, 72.18133326939174, 63.27252674102783, 65.55156367165702, 72.16567202976772, 82.63778850010463, 76.42701612200055, 64.24271760668073, 64.42818587166923, 63.83353124346052, 66.93851443699428, 68.66733046940395, 65.11025578635079, 64.98436832427979, 62.17859540666853, 66.64309092930385, 69.88735771179199, 70.44943223680768, 72.66285732814244, 65.6567941393171, 66.44264929635185, 74.04142161778041, 80.37904030936105, 78.85933031354631, 84.21184035709926, 38.62644992555891, 72.76866449628557, 84.21152768816266, 81.99074445452008, 87.32053388868059, 79.41079493931362, 83.7627991267613, 86.78169413975307, 84.42313507625035, 71.28507123674665, 63.88374587467739, 68.76007502419608, 75.39735562460763, 74.31306838989258, 71.7008305958339, 65.86906160627092, 65.88167953491211, 77.83128179822648, 85.03011580875942, 82.41734300340924, 87.29756314413888, 80.47955989837646, 73.86188016619, 68.51559570857457, 71.61973817007882, 79.59892436436245, 85.60662174224854, 74.34845556531633, 78.9315151487078, 85.36901419503349, 82.11545767102922, 80.76544352940151, 81.90840135301862, 85.34612682887486, 94.11962413787842, 36.717977796282085, 1.2863255419901438, 0.957818186708859, 0.5084198841026851, 0.8848116184983934, 0.3168578861015183, 0.07255150191485882, 0.373010947235993, 0.3581569471529552, 0.10888973237680537, 0.25490614612187656, 2.555163553782872, 21.566808904920304, 33.98942715781075, 32.145878996167866, 70.11795452662876, 55.723242964063374, 43.404396057128906, 19.382781641823904, 23.336006130490983, 25.56204741341727, 47.11958394731794, 39.59823192868914, 74.69355174473354, 78.85195132664272, 104.15231568472726, 27.08740108353751, 0.9280024894646236, 0.1594658802662577, 0.14707196317613125, 0.07720459651734148, 0.090999545928623, 0.004953271709382534, 0.0691370458475181, 0.10346882111792054, 0.03219924827239343, 0.060495223850011826, 0.04618622987930264, 0.05219361252550568, 0.06038386268275125, 0.024430884048342705, 0.017277494771406054, 0.021458656394055912, 0.05676398353118982, 0.09170451667159796, 0.041932266538164446, 0.02157325078068035, 0.06620304007083178, 0.14900467518184865, 0.0208063993403422, 0.009549673014719571, 0.030728038466934646, 0.05213348414482815, 0.033546489729945145, 0.2417901727770056, 0.20714554536555493, 0.11144101047622305, 0.18229521811008453, 0.1579945177904197, 0.12386564484664372, 0.19026385194488935, 0.16466153146965162, 0.15592396818101406, 0.2618403397500515, 0.14422208895640715, 0.19660178971077713, 0.10871761518397502, 0.11696221599621431, 0.11775877539600645, 0.12395772204867431, 0.17346655470984323, 0.15187896309154375, 0.19325853910829338, 0.12987534808261053, 0.14242855805371488, 0.16931615956127644, 0.23049394892794745, 3.3859913604600087, 132.91004807608468, 119.60554013933454, 131.88959394182478, 83.33977890014648, 82.45154203687395, 34.85437018530709, 45.175436292375835, 114.64656911577497, 108.64367989131382, 46.547097546713694, 59.79829542977469, 52.88595649174282, 13.713772467204503, 0.6971816495060921, 0.08712034087095942, 0.6744738508548055, 0.0768227916476982, 0.5632832944393158, 0.18249154543238028, 12.154005237988063, 39.575744083949495, 3.487268303121839, 66.91373716081891, 109.74088382720947, 100.10554586138043, 93.59919016701835, 96.5431558064052, 100.5887096949986, 97.61370645250592, 94.39714213779995, 93.56164905003139, 98.28087942940849, 95.56894193376813, 92.95764214651925, 90.8218423298427, 93.25161348070417, 92.98959691183907, 90.20320946829659, 90.20375837598527, 75.87270968300956, 68.36482674734933, 70.81581769670758, 76.37154865264893, 86.74709211077008, 82.42966910770961, 68.40309742518834, 69.79450198582241, 65.7564868927002, 71.15658514840263, 73.05397837502616, 69.28618567330497, 69.5524684361049, 66.29886327471051, 69.7898258481707, 73.77847399030412, 76.06453554970878, 74.36918204171317, 69.55336475372314, 71.3759536743164, 77.17014680589948, 85.15445382254464, 83.62425204685756, 86.97721644810268, 45.057990891592844, 75.66760580880302, 87.68218762534005, 84.83714348929269, 93.42285878317696, 82.39169025421143, 86.76779774257115, 91.63314179011753, 89.27713966369629, 73.49362564086914, 66.97695187159947, 73.76437609536308, 80.32900633130754, 78.71439089093889, 74.30377170017788, 69.87670612335205, 69.91189180101667, 83.35196604047502, 88.90633514949253, 85.38171550205776, 90.25117983136857, 85.0431992667062, 79.20649705614362, 73.5011088507516, 73.25526074000767, 84.85882881709507, 90.51273781912667, 76.36712959834507, 79.10178770337785, 90.14765167236328, 86.15446635654995, 84.90155329023088, 86.61143548148019, 90.90469264984131, 95.34191649300712, 33.502778802599224, 1.3695727778332574, 5.560930814061846, 2.3990045275006975, 4.749169732843127, 1.5673539021185465, 0.3804411499627999, 0.6133499507393155, 1.0068778970411845, 0.14268534284617218, 0.37594110571912354, 5.159930731569018, 31.75739131655012, 56.953070640563965, 50.213213784354075, 91.70900917053223, 100.00590174538749, 88.15723596300397, 40.568777152470176, 28.750919682638987, 18.91547359739031, 42.64937353134155, 46.67245694569179, 90.86729049682617, 88.37732015337262, 117.5160083770752, 32.694630350385395, 1.1376627534627914, 0.33480413311294144, 0.27352061441966463, 0.23308679408260755, 0.23453524921621594, 0.21325419257794107, 0.13656746755753243, 0.19809855653771333, 0.1202513330749103, 0.13224913499185018, 0.183051038267357, 0.16645210395966256, 0.12818629800208978, 0.1459536153290953, 0.09496034482227904, 0.13014035671949387, 0.1774754345949207, 0.3119648615164416, 0.1368046019758497, 0.12473754877490656, 0.1981407342744725, 0.23991738898413523, 0.09244456767503705, 0.12384896645588533, 0.1320084043379341, 0.2360033004411629, 0.12022548089069979], [0.07337622051792485, 0.051153248708162985, 0.054034647664853504, 0.10153216003839459, 0.12530840028609547, 0.06482645536639861, 0.04396214475855231, 0.06564653957528727, 0.0249121570627072, 0.028131167903276424, 0.031072598549404314, 0.06596023309975863, 0.06305739243647882, 0.10612065132175173, 0.07515340551201787, 0.06445121871573584, 0.03201276310054319, 0.06202924903482199, 0.05701337568461895, 0.12258406861552171, 0.023700799027990018, 0.27533260147486416, 0.25510148278304506, 50.46073293685913, 112.24149186270577, 110.92316845485142, 96.13575513022286, 70.5643207005092, 36.77336188725063, 37.757042680467876, 44.22916807447161, 87.3950046811785, 138.1602736881801, 67.94071565355573, 35.48234142575945, 12.792727078710284, 0.07730022924286978, 0.08005613314786128, 0.08284377213567495, 0.07818446215242147, 0.036980063521436284, 0.10641008043395621, 0.11053382951234068, 2.708916332040514, 5.12512503351484, 13.25049524647849, 101.8369049344744, 90.52794742584229, 94.903137751988, 75.416748046875, 85.67811870574951, 85.75228377750942, 93.43429551805768, 87.72984531947544, 87.54698957715715, 83.4293828691755, 86.94598429543632, 83.43636580875942, 84.86862577710832, 79.65678201402936, 86.0621178490775, 78.28000341142926, 76.17519950866699, 62.377056803022114, 63.033710207257954, 59.29167447771345, 60.96474511282784, 59.889747619628906, 61.395137378147666, 57.4132741519383, 63.88667106628418, 59.89686952318464, 65.12844617026192, 61.5798066002982, 64.75476510184151, 57.43097121374947, 63.5436315536499, 60.171629088265554, 70.47715554918561, 64.98008128574916, 70.0915652683803, 61.14640576498849, 63.992492130824495, 69.03970527648926, 81.95355074746269, 73.01242814745221, 92.83607646397182, 34.825031416756765, 56.37128060204642, 86.05108410971505, 73.07915864671979, 78.93840776171002, 75.57183878762382, 85.4817487171718, 76.99867916107178, 78.84525326320103, 69.13506930215019, 63.03537082672119, 61.09496825081961, 66.79737567901611, 67.17666394369942, 66.91609954833984, 61.852314949035645, 60.85975783211844, 62.817433629717144, 67.38408156803676, 69.34625979832241, 71.34276212964738, 63.05775792258126, 59.713979039873394, 60.81571320125035, 71.25835541316441, 76.9397862298148, 79.73443508148193, 71.8023715700422, 78.10572174617222, 79.74710859571184, 76.3511209487915, 73.37756987980434, 75.74169445037842, 75.91506590162004, 77.89674077715192, 88.04025609152657, 46.124462945120676, 0.7932139507361821, 1.4297015113489968, 1.102790287562779, 0.011057424475438893, 0.14884382167032786, 0.08941502416772501, 0.05255967538271632, 0.0391296522824892, 0.008677370447133268, 0.12314029091170856, 1.3034210417951857, 11.044704488345555, 35.298314911978586, 22.704473938260758, 32.79157509122576, 81.99849169594901, 86.71308067866734, 61.15041487557547, 27.118541172572545, 15.420461961201259, 25.87332671029227, 57.87843867710659, 70.11748204912458, 72.97184371948242, 41.50949375970023, 0.3508892942752157, 0.008533897610115153, 0.0047829076814066085, 0.009191662671842744, 0.021650564757042697, 0.013416001174066747, 0.05001392734370061, 0.10608029205884252, 0.03232548292726278, 0.04166463536343404, 0.06680973858705588, 0.0370976298914424, 0.07515741565397807, 0.019955709809437394, 0.01744745422287711, 0.03322886409504073, 0.06231047465865101, 0.06759323618773903, 0.046188665820019584, 0.060195698136729855, 0.01724785127277885, 0.028472313258264745, 0.06861755265189068, 0.04089256089978984, 0.07478457423193113, 0.10382324031421117, 0.06929897822971855, 0.04382089073104518, 0.0642739717981645, 0.04785518175257104, 0.07435187245053904, 0.019805717947227613, 0.0365721045194992, 0.03314331779256463, 0.0018159053828899882, 0.023872705874964595, 0.08101291502160685, 0.012471269234083593, 0.015414227432172214, 0.02562563493847847, 0.11683747411838599, 0.06024922776435103, 0.0760809425264597, 0.03792257919641478, 0.08189336170575448, 0.02267752750776708, 0.12178877129086427, 0.06543761185769524, 0.08085723194692816, 0.20501962729862758, 73.41390201023647, 131.19831766401018, 119.21616309029716, 111.2293130329677, 79.78997898101807, 53.71881621224539, 39.25761038916451, 28.869138070515223, 77.07000936780656, 116.8135871887207, 52.65711062295096, 42.14361763000488, 17.448243345533097, 0.10361456365457603, 0.029249361383595636, 0.07567329904330627, 0.01851122240935053, 0.09715180937200785, 0.11723825761250087, 0.08473237936518022, 0.9408268013170787, 1.0419622829982211, 14.824327366692678, 108.66371154785156, 92.407059941973, 99.7052115031651, 77.66667897360665, 88.63590431213379, 87.40259211403983, 95.00680487496513, 89.41098976135254, 87.75662367684501, 84.65226582118443, 89.67204747881208, 85.34500122070312, 87.51550034114292, 83.44220229557583, 89.18994671957833, 82.82180459158761, 79.05444962637765, 64.62768254961286, 66.30081571851457, 61.80164173671177, 64.49225521087646, 63.55122593470982, 64.99409580230713, 60.69921275547573, 67.86448001861572, 64.55039078848702, 68.80543286459786, 63.955534662519185, 66.57231657845634, 59.48588357652937, 65.93836988721574, 63.635584013802664, 73.10241426740373, 67.32131849016461, 72.58188302176339, 63.53814247676304, 68.07525362287248, 74.63463102068219, 85.67276859283447, 75.36103044237409, 96.32772690909249, 37.34900624411446, 58.35712092263358, 89.08564036233085, 77.10320091247559, 81.5761523927961, 75.63511603219169, 87.96463884626115, 82.14580740247453, 79.96981225694928, 72.44753960200718, 66.17492825644356, 65.32306521279472, 69.45866080692836, 68.44998386928013, 71.34231049673897, 65.73585074288505, 62.571814809526714, 65.8217304774693, 70.49695096697126, 72.10791165488106, 73.31194414411272, 66.60300677163261, 61.92718178885323, 62.37600762503487, 74.1153643471854, 79.19656808035714, 82.65761171068463, 73.31832953861782, 81.81956168583461, 83.39073698861259, 79.19781180790493, 78.40750285557338, 80.2597883769444, 80.90267045157296, 80.17871679578508, 93.02622086661202, 58.77861254555838, 2.1068629579884663, 1.028290290917669, 1.0260567707674844, 0.6062153992908341, 0.2747848337250096, 0.29791052852358135, 0.06930304943983044, 0.14899866336158343, 0.09025314383740936, 0.09197893658918993, 1.423701524734497, 13.619089365005493, 38.05119466781616, 18.674986021859304, 41.67182799748012, 67.84718595232282, 54.25556107929775, 31.147683416094097, 18.716366018567765, 24.414906774248394, 37.26072938101632, 65.03288064684186, 79.17519542149135, 85.47980322156633, 59.68652670724051, 0.831800717328276, 0.09711976216307708, 0.031141476639147316, 0.06519897787698678, 0.06937097758054733, 0.02420189035391169, 0.04091772776363151, 0.026343616590436016, 0.08352275498743568, 0.033205044123211076, 0.07353803076382194, 0.051828329983566485, 0.04574962652155331, 0.06997296706374202, 0.04644633949335132, 0.04382357433704393, 0.05130148146833692, 0.056951350798564296, 0.10248854836182934, 0.039188345561602285, 0.0821007898609553, 0.020334551177386726, 0.012872730415048344, 0.05940575445336955, 0.042148539397333346, 0.056481489046875916, 0.022094693068148832, 0.16029629856348038, 0.1936438520039831, 0.14713004577372754, 0.17100640386343002, 0.23274796083569527, 0.1305119496371065, 0.10397966299206018, 0.14265449664422444, 0.09279273077845573, 0.17269827664962836, 0.11962827507938657, 0.14052571515951837, 0.13444829412869044, 0.21012675682348864, 0.12606332477714333, 0.13368480652570724, 0.11517719392265592, 0.13079105823167733, 0.1560309324413538, 0.40923258502568516, 0.18738812554095471, 0.21555081648486002, 0.5739253833889961, 89.71589061192104, 143.7053391592843, 137.4862289428711, 121.4588748386928, 99.41012845720563, 58.96154471806118, 57.745992115565706, 61.92788355691092, 108.66373934064592, 155.83444813319613, 92.95509215763637, 59.60730334690639, 21.635319880076818, 0.4701973008258002, 0.19262850577277796, 0.2564661795539515, 0.28429930603929926, 0.27111710767660824, 0.4624568447470665, 0.18612885954124586, 6.924476138183048, 10.691590087754385, 16.353104761668614, 115.56365489959717, 94.00597940172467, 106.00437886374337, 81.13008499145508, 94.52004882267543, 91.79943302699498, 103.66136292048863, 91.86395399911063, 92.64758573259626, 86.69302817753383, 92.35674108777727, 86.02885682242257, 91.00052915300641, 84.75455025264195, 92.8667597089495, 86.72581672668457, 84.69253063201904, 68.46791022164481, 70.19999190739223, 64.61554404667446, 67.14630726405552, 67.24887657165527, 68.87051664079938, 64.47897720336914, 72.30689416612897, 68.60799285343715, 71.37001296452114, 66.8262107031686, 70.76520006997245, 63.83934688568115, 69.40952314649309, 67.0708567755563, 78.86431912013462, 70.78917135511125, 75.54820101601737, 67.00124972207206, 70.88411848885673, 79.25430066244942, 90.71182455335344, 80.45673506600517, 101.76868057250977, 43.43444354193551, 64.30016531263078, 91.41799776894706, 83.23530578613281, 87.42024053846086, 79.58061586107526, 91.25593798501151, 86.63977023533413, 84.90278312138149, 76.48354666573661, 68.78477587018693, 71.44799954550606, 73.20952074868339, 72.35879026140485, 76.04448999677385, 67.83631896972656, 66.28352165222168, 68.41213703155518, 74.41526249476841, 77.57853412628174, 77.38774354117257, 70.00266306740897, 65.8439438683646, 66.27738639286586, 77.92063563210624, 84.93976838248116, 86.26558194841657, 72.47331047058105, 82.35331535339355, 88.31994887760708, 83.70303072248186, 82.48805482046944, 84.02292578560966, 83.33289323534284, 85.30037294115338, 96.11811365400041, 58.1953911781311, 0.9280210541827338, 4.775232860020228, 4.653577719415937, 1.934606909751892, 0.31595890862601145, 0.5108050161174366, 0.30368377587624956, 0.37350540927478243, 0.2709124343735831, 0.3801575223250048, 3.28505140542984, 20.760364498410905, 57.693904944828574, 32.10231726510184, 48.727727140699116, 105.38437720707485, 121.65556444440568, 87.85432924543107, 40.16891874585833, 22.549711499895366, 42.36054733821324, 75.39978749411446, 92.72722598484584, 94.99229703630719, 77.90008286067417, 1.2992209643125534, 0.21919773864958966, 0.09777908106999737, 0.20409092998930387, 0.12540726283831255, 0.15336917527019978, 0.20636238024703094, 0.25895740730421885, 0.14317242242395878, 0.15057180609021867, 0.1589535591857774, 0.09341923573187419, 0.13808715529739857, 0.14261216962976114, 0.2398076020181179, 0.09726334017302309, 0.09538430707263094, 0.10266909974494151, 0.2498689464160374, 0.12844054507357733, 0.14445041599018232, 0.10344421743814435, 0.14417944981583528, 0.12099329754710197, 0.14766851759382657, 0.1584554873406887, 0.1372959427535534], [0.07176107647163527, 0.09647443464824132, 0.013361098361201584, 0.03421185099120651, 0.05871900916099548, 0.04458367605028408, 0.049222328034894805, 0.06270476457263742, 0.0170011291546481, 0.043255579458283525, 0.056890360678413084, 0.02798727946355939, 0.023368976744157926, 0.03049290572692241, 0.07965833520782845, 0.06396417985005037, 0.038592435752174685, 0.07813788072339126, 0.08406350668519735, 0.04838913452944585, 0.3374585892472948, 0.27003055598054615, 13.12224279131208, 112.25190721239362, 103.85065964290074, 94.81132425580705, 62.50018583025251, 52.82834897722517, 27.288172755922588, 39.49513108389718, 64.9732095173427, 34.964645045144216, 76.40048789978027, 61.60451439448765, 18.70475731577192, 0.16448049832667622, 0.04000914562493563, 0.08012163213321141, 0.04380572208070329, 0.10894884634763002, 0.03352528551061239, 0.04799248331359454, 0.056057482691747804, 0.0802048205264977, 0.6052014508417675, 44.63535281590053, 100.96728924342564, 88.46028164454869, 86.51288223266602, 69.32029438018799, 73.13081850324357, 82.73987143380302, 87.5917637688773, 85.15899794442313, 88.81596687861851, 86.5627772467477, 87.70009313310895, 82.11621502467564, 78.49058246612549, 81.61641025543213, 80.04709706987653, 77.36485617501395, 73.20651912689209, 59.83150087084089, 58.250573771340505, 58.83226653507778, 61.58240522657122, 57.110760007585796, 61.189866747174946, 59.15847751072475, 64.03251375470842, 60.674317359924316, 62.43995189666748, 61.829385893685476, 61.78421565464565, 62.28841168539864, 61.50820541381836, 66.23102106366838, 72.76350198473249, 69.27850791386196, 71.86651733943394, 62.230790274483816, 68.72643879481724, 76.56254768371582, 84.7004029410226, 72.79501206534249, 88.02859701429094, 43.0392439024789, 40.69328192302159, 81.58749880109514, 67.18124280657086, 73.58935792105538, 74.51619897569928, 79.99796635763985, 72.95445932660783, 74.04866858891079, 65.92401490892682, 67.87672969273159, 59.84395204271589, 63.04536233629499, 63.22825281960623, 63.561682973589214, 60.25462532043457, 62.26161248343331, 59.275943756103516, 62.404238155909944, 61.99082728794643, 58.20875951222011, 56.70755951745169, 60.97042179107666, 67.4400076184954, 72.16449083600725, 75.85473469325474, 75.608900478908, 73.89459228515625, 82.33705656869071, 73.61476053510393, 73.4526173727853, 67.62637220110211, 71.54679598127092, 72.39322553362165, 80.09303855895996, 74.23424802507672, 88.49764210837228, 56.15858929497855, 3.7408449820109775, 1.204497041446822, 0.24622676042573793, 0.06199857246662889, 0.24350754490920476, 0.14970249416572706, 0.06676325893827847, 0.0611034490700279, 0.04760616279340216, 0.21354961315436022, 0.5165042760116714, 7.62885628427778, 53.98921578271048, 29.55937385559082, 49.80153996603829, 119.71576636178153, 149.49232700892856, 114.75762217385429, 36.485692569187705, 19.531233378819056, 32.5312955720084, 70.61030387878418, 65.93124798366001, 52.901131357465474, 2.1556725331715176, 0.26616852464420454, 0.07943661710513489, 0.04825576847153051, 0.07426568493247032, 0.062401717262608666, 0.027075036628437892, 0.08452062215656042, 0.009791049125072147, 0.04207841280315604, 0.050777062108474116, 0.03301871840709022, 0.07997031882405281, 0.049354065608765395, 0.035571306079093895, 0.03545093396678567, 0.018257528343903165, 0.09290720642145191, 0.004574042304219412, 0.15133495442569256, 0.11436550319194794, 0.04657866060733795, 0.05450259594778929, 0.07243981505078928, 0.04026111281876053, 0.04213731303544981, 0.00971078097687236, 0.03028092799442155, 0.039554004690476825, 0.024451336790142313, 0.019619524545435394, 0.02621366865267711, 0.05727776685463531, 0.03248675713049514, 0.031551386429263015, 0.04294607249487724, 0.06402893244688, 0.060597044814910205, 0.04241345303931406, 0.07120489488754954, 0.014668546284415891, 0.10370596910693816, 0.002506092544146148, 0.11235008455280747, 0.026349911699071527, 0.025212244263717105, 0.0656482834102852, 0.2281411423214844, 0.48858863966805594, 22.908090897968837, 132.45191165379114, 110.71232536860875, 108.60551343645368, 77.62772737230573, 82.53378091539655, 47.082025459834504, 50.887939453125, 49.40411690303257, 43.233661447252544, 72.08623327527727, 55.88668196541922, 25.177334342684063, 0.04374992275344474, 0.056065414766115804, 0.0963400440024478, 0.032212028479469676, 0.14911366147654398, 0.08354828147483723, 0.10378056724688836, 0.07860203938824789, 0.08621175533958844, 0.3471594144191061, 51.39502593449184, 103.86274256025041, 91.672287940979, 88.4239912033081, 73.00025490352085, 77.05388954707554, 84.8790202822004, 89.1812823159354, 89.64334447043282, 91.43800858088902, 90.43465396336147, 88.75573989323208, 82.21918732779366, 80.02138873508999, 83.47777707236153, 84.24260698046002, 81.88855729784284, 75.85836165291923, 62.61296898978097, 61.05056231362479, 62.66472612108503, 64.34202126094273, 59.41665172576904, 63.902617182050435, 63.570875440325054, 66.19159698486328, 63.875269072396414, 65.33653776986259, 64.04331125531877, 66.0683012008667, 64.35620253426688, 63.72193622589111, 69.15391976492745, 77.21765163966587, 72.57368414742606, 75.78168828146798, 67.48960386003766, 72.18356364113944, 78.80421025412423, 86.63857514517647, 75.41212054661342, 89.36893926348004, 48.99752221788679, 43.25052472523281, 80.60776111057827, 71.60101972307477, 76.88351276942662, 77.03296157291958, 83.56347615378243, 77.64010211399624, 78.20578970227922, 69.4641637802124, 69.33282893044608, 62.74690246582031, 66.86584322793144, 65.7548749106271, 65.89636107853481, 61.56657723018101, 63.87004402705601, 63.51654747554234, 65.75172737666539, 65.04558195386613, 61.000208718436106, 60.67001642499651, 64.249269757952, 71.70239394051688, 76.40551144736153, 79.0041446685791, 75.99009255000523, 75.49686772482735, 84.70544038500104, 79.08013016836983, 76.33496638706752, 70.5966020311628, 73.03621877942766, 76.85497651781354, 83.05893271309989, 77.69752202715192, 91.45291246686662, 66.03541537693569, 7.654619336128235, 0.6730363879884992, 0.6990812761443002, 0.25856369414499825, 0.27601507199662073, 0.1546614859253168, 0.013840396838661815, 0.09576644442443337, 0.043987735706780634, 0.2639774265033858, 0.09326186310499907, 9.322603889874049, 48.68630198069981, 21.756805658340454, 59.863274982997346, 105.8434168951852, 123.65782683236259, 69.47314085279191, 37.05123424530029, 29.44189371381487, 38.077229567936485, 78.87962600163051, 74.09196281433105, 78.05581978389195, 8.359760744231087, 0.2659300874386515, 0.03329359972849488, 0.03411494601251824, 0.06471911791179862, 0.06967224712882723, 0.061800284178129265, 0.08831182800765548, 0.016815500633258904, 0.06010908314159938, 0.08436416555196047, 0.009666799185132342, 0.049901321064680815, 0.08107493312231132, 0.0511828124789255, 0.020183482140834843, 0.016675162628026943, 0.08174506787742887, 0.02474486595019698, 0.04999240082023399, 0.08074351626315288, 0.029176900628954172, 0.08934606465377978, 0.07571534785841193, 0.010368873431746448, 0.07165318940367017, 0.030906313365059238, 0.15323730877467565, 0.20848771477384226, 0.10776690619864635, 0.07558798005006143, 0.12803000424589428, 0.11934281539704118, 0.08792327171457665, 0.1072732787579298, 0.13770760994936737, 0.15920795553496905, 0.25054916420153206, 0.12420863072787013, 0.15413457634193556, 0.20550621833120072, 0.20280659890600614, 0.1331057311700923, 0.17059859074652195, 0.21605940562273773, 0.19039087370038033, 0.2086165142910821, 0.47948041984013146, 0.7717903746025903, 27.658061844961985, 149.9081072126116, 124.08173642839704, 121.40045438494, 84.56669180733817, 79.14060728890556, 45.43912042890276, 58.066078254154746, 93.44341155460903, 44.915368693215505, 90.57144314902169, 95.94508266448975, 30.84202868597848, 0.749174313885825, 0.22617941615836962, 0.3077999050063746, 0.12730849081916468, 0.36851904541254044, 0.20927489681967668, 0.22525818273425102, 0.3375413976609707, 0.30841169932058876, 1.0500467291900089, 53.78404242651803, 107.64077690669468, 97.53669956752232, 93.49183355058942, 77.75639411381313, 79.44695336478097, 90.15520436423165, 94.13028962271554, 94.36763313838414, 94.34985269818986, 93.15365082877022, 92.84570666721889, 84.96640082768032, 80.83728095463344, 86.63444096701485, 90.04146930149624, 86.00574016571045, 79.65110533578056, 64.8820491518293, 64.25359153747559, 65.69996329716274, 66.87565408434186, 64.73011289324079, 68.27636923108781, 66.08276040213448, 71.76886735643659, 66.87798173086983, 69.8407769884382, 69.12760693686349, 68.16414192744664, 68.17056206294468, 67.28023379189628, 73.13722474234444, 80.18857628958565, 76.78698144640241, 77.83802155085972, 69.78007057734898, 76.01442514147077, 83.8270491191319, 90.13850784301758, 81.30624961853027, 91.80719416482108, 53.381119864327566, 47.24956737245832, 82.00909464699882, 74.90550654275077, 76.68585736410958, 80.55013275146484, 87.2543522971017, 83.44056946890694, 81.22558798108781, 71.12843799591064, 71.01020050048828, 67.64577157156808, 70.83273656027657, 71.08207266671317, 71.60588346208844, 66.05933802468437, 67.43296909332275, 66.02653557913644, 68.12831701551164, 69.09195572989327, 63.97155026027134, 64.61974770682198, 68.29612990788051, 75.08354718344552, 79.43218149457658, 82.22655241830009, 78.70457308632987, 77.73345811026437, 89.6265298298427, 81.60638400486538, 79.48837852478027, 74.32838916778564, 78.55458232334682, 80.41308648245675, 85.18881266457694, 80.63866669791085, 96.79673726218087, 67.77270821162632, 5.688938345227923, 2.497911048786981, 1.8554701847689492, 0.7717282750776836, 0.7052986110959734, 0.30852061776178225, 0.36801866654838833, 0.1631687544286251, 0.15970226829605444, 0.5252460869295257, 0.6675115930182594, 14.05684324673244, 81.85373987470354, 41.62286751610892, 59.277882303510395, 130.22498621259416, 161.99323408944267, 152.9147594996861, 54.798399516514365, 32.032143933432444, 46.43063531603132, 96.83486897604806, 86.0208386012486, 99.91195515223912, 14.753026689801898, 0.8478893797312463, 0.17209984947528156, 0.22449632361531258, 0.11208147968032531, 0.22747970638530596, 0.09642097965947219, 0.11473909100251538, 0.08490647109491484, 0.1104324563805546, 0.13985089851277216, 0.13627644388803414, 0.1696211067693574, 0.21243715499128613, 0.17187849778149808, 0.21934008172580174, 0.10879377395446811, 0.11451596154698304, 0.12450983242264815, 0.2476472056337765, 0.21287923412663595, 0.09628719969519547, 0.12263202747063977, 0.1662506740540266, 0.12957804117883953, 0.1891716548374721, 0.10370301069425684], [0.05306810845753976, 0.01861273294447788, 0.08952301301594291, 0.034340402843164544, 0.047538251616060734, 0.051165991595813205, 0.05289617786183953, 0.01878239044786564, 0.08500038712684597, 0.0783594563337309, 0.011217914122555937, 0.08350899429725749, 0.049251440579869916, 0.0370176068640181, 0.059375539288989136, 0.026973042637109756, 0.028908119337367158, 0.02985082839482597, 0.07111154882503407, 0.05000286383022155, 0.06656144226768188, 0.2524111457169056, 70.19168881007603, 120.3853086744036, 109.20857538495744, 94.67334692818778, 58.14431497028896, 21.244398593902588, 28.367429494857788, 49.409651143210276, 41.89882217134748, 72.40535014016288, 50.174950054713655, 20.065820830208914, 0.5209422750132424, 0.04388138212795768, 0.18807373089449747, 0.06408744930688824, 0.09753895431224789, 0.06231962809605258, 0.10325861775449344, 0.13264842570892402, 0.187447334506682, 0.31484961243612425, 6.0986853412219455, 76.83846064976284, 96.4648357118879, 90.79466792515346, 83.15325450897217, 70.28032003130231, 68.16512162344796, 70.64246014186314, 83.49755164555141, 86.19886534554618, 86.76787417275565, 84.46319838932583, 83.52065440586635, 75.4867650440761, 81.19707257407052, 79.44881548200334, 77.93520600455147, 74.8737324305943, 64.33233547210693, 58.44385528564453, 59.04924488067627, 60.051189013889854, 60.65162454332624, 59.63184438432966, 61.13745648520333, 59.99806308746338, 62.72299371446882, 59.75613376072475, 62.818163190569194, 58.71866348811558, 61.28464017595564, 57.604533740452354, 63.08999061584473, 67.96344321114677, 72.79786777496338, 70.3655674798148, 69.23067651476178, 60.613277435302734, 61.28657177516392, 63.91105924333845, 73.97936725616455, 67.20979990277971, 83.65014798300606, 60.36748491014753, 38.29240485600063, 73.5873498916626, 62.70581776755196, 75.83138179779053, 72.72270216260637, 76.20012269701276, 72.17740753718785, 69.96434375217983, 66.29444422040666, 67.25452545710972, 63.234172684805735, 61.92454147338867, 57.53274495261056, 60.588965688432964, 59.1970191683088, 60.61204760415213, 57.73309973308018, 60.82017394474575, 56.88215732574463, 60.437835420881, 58.09997851508004, 66.83898149217877, 70.70304843357631, 77.66308675493512, 73.17644732339042, 74.69216210501534, 77.31038924625942, 76.5837049484253, 74.62701579502651, 68.68659087589809, 65.9286424091884, 65.11116600036621, 65.95844323294503, 70.25268704550606, 77.44286360059465, 77.61503301348004, 80.74316760471889, 63.71762834276472, 9.568511928830828, 0.4029867244618279, 0.27133852722389357, 0.14132080892367022, 0.11148669623902865, 0.07384658099285193, 0.030212735225047384, 0.04653628270274826, 0.08007327972778253, 0.08615580334195069, 0.22143414935895375, 4.376178707395281, 45.249330384390696, 62.31229959215437, 104.05554117475236, 96.86102199554443, 123.05751637050084, 46.62403842381069, 27.642794915607997, 39.280251094273154, 54.941389969417024, 67.36635671343122, 61.041564396449495, 26.032789605004446, 0.19371976650186948, 0.06042350269854069, 0.11527513366724763, 0.05061215774289199, 0.06358616799116135, 0.011846838901484651, 0.025829631402822475, 0.06315442294414554, 0.05504166487870472, 0.07848729233124427, 0.09856322327894823, 0.06680266825216157, 0.11165590251662902, 0.03881443544690098, 0.02596159798226186, 0.03438649233430624, 0.04788134267021503, 0.07224854281438248, 0.03304063508819256, 0.05107011120500309, 0.08208972974015133, 0.0696861706674099, 0.027438010454976132, 0.03737279959022999, 0.09030267010842051, 0.01888218428939581, 0.06719071564397641, 0.00962409982457757, 0.07451768605304615, 0.04450654358203922, 0.11119723998542343, 0.009870143407689673, 0.06521888609443392, 0.01626180757635406, 0.04561902888651405, 0.02949825142111097, 0.027566467312031558, 0.08882210669772965, 0.03614780639431306, 0.0053601221547329, 0.012055841257928737, 0.04697490130950298, 0.08622647276414291, 0.03320469467767647, 0.0875915088025587, 0.02750711076493774, 0.049332440697721074, 0.4317489010947091, 90.6986368724278, 130.76180403573173, 119.93628828866142, 106.32081372397286, 68.98780918121338, 38.30402224404471, 38.771743706294465, 41.00795194080898, 37.77448960712978, 64.42078604016984, 55.240141664232524, 27.1355607850211, 0.5925119231854166, 0.015473487288025873, 0.07922724155443055, 0.024662515547658716, 0.02903170431298869, 0.020362308348662088, 0.09528993642223732, 0.04022988663720233, 0.08698020303355795, 0.18629067657249315, 9.32500101838793, 83.15020424979073, 98.79118292672294, 94.36679935455322, 87.67890112740653, 75.19646235874721, 69.13181754520961, 74.38646915980748, 86.36696311405727, 87.53922149113247, 88.53084754943848, 86.93088585989815, 86.82641274588448, 75.49910504477364, 80.44664628165108, 84.21760041373116, 82.10682106018066, 77.30071040562221, 68.41462448665074, 61.86270250592913, 63.33559553963797, 61.66592257363455, 62.20088522774832, 63.031618799482075, 64.36975846971784, 62.8063234601702, 65.83453600747245, 62.78634738922119, 63.92585890633719, 62.318170819963726, 65.26859133584159, 60.63702637808663, 65.88862078530448, 72.41509846278599, 75.74521023886544, 74.82481711251395, 72.60906437465123, 64.59978553227016, 63.77469389779227, 66.68145888192313, 75.42375877925328, 71.50949805123466, 86.25930077689034, 65.25339562552315, 39.26106364386422, 76.50479425702775, 65.52370834350586, 75.19564941951207, 76.35647800990513, 79.19481018611363, 74.40673705509731, 72.10161658695766, 69.94746657780239, 69.45481150490897, 67.23525810241699, 64.92051437922886, 60.40875026157924, 63.71302168709891, 61.0185033253261, 65.02200671604702, 61.19248621804373, 64.4085224696568, 60.79466015951974, 62.46012946537563, 61.21980653490339, 70.7176535470145, 74.21777384621757, 80.4507109778268, 76.20333971296037, 78.2524607522147, 78.84844248635429, 80.26381138392857, 76.1176267351423, 72.67813641684396, 68.56493486676897, 68.283602305821, 69.16719777243478, 73.32082394191197, 80.42856012071881, 80.4076668875558, 83.42788900647844, 75.9496818270002, 16.353664091655187, 0.8448461230312074, 0.2916052011506898, 0.22034970112144947, 0.274476480271135, 0.15670042937355383, 0.03660631286246436, 0.09189402471695628, 0.12480377379272665, 0.1331778323011739, 0.39834931758897646, 4.775198553289686, 36.25837530408587, 46.5693804195949, 107.97049672263009, 99.26621041979108, 115.30927440098354, 31.279845101492747, 30.874052933284215, 44.09620039803641, 61.16422094617571, 76.83903040204729, 78.8355188369751, 49.452868938446045, 0.3851667663880757, 0.08498955770794835, 0.14563169117484773, 0.05686852202883788, 0.0015022818323424353, 0.032051215680049996, 0.03980551048048905, 0.012510746401468558, 0.08538515040917055, 0.04159140107887132, 0.05178247797968132, 0.0604457857885531, 0.06637453301144497, 0.018743201657863598, 0.02690320781299046, 0.019081692244591456, 0.0632993783801794, 0.006446156891927655, 0.1020287594624928, 0.038834567580904276, 0.045892848300614526, 0.024718774582392404, 0.004779721535409668, 0.031247470594410385, 0.10828555801085063, 0.019621974056852714, 0.15559044107794762, 0.13535666252885545, 0.11011598764785699, 0.12017901481262275, 0.17346183210611343, 0.12001441578779902, 0.18783812996532234, 0.10154634820563452, 0.15459695724504335, 0.12032304065568106, 0.1614646137292896, 0.1555145401507616, 0.11436246335506439, 0.1331735168184553, 0.09738593788019248, 0.07096590806863137, 0.1701684266860996, 0.05920963069157941, 0.18014609414551938, 0.06930097990802356, 0.2027337649571044, 0.8829280052866254, 105.90495014190674, 145.2942393166678, 133.80364200047083, 119.16502434866769, 80.28586496625627, 33.699315547943115, 40.778835092272075, 71.8516412462507, 57.89292914526803, 97.68357058933803, 73.79611546652657, 34.0006102834429, 1.0047087562935693, 0.13497495943946497, 0.3479407610637801, 0.16613602877727576, 0.24345668192420686, 0.27749292126723696, 0.2412744861628328, 0.45399830862879753, 0.30147077462502886, 1.3373018694775445, 10.957455090114049, 88.71264021737235, 101.87230600629533, 98.76923356737409, 92.13230732509068, 77.60166467939104, 74.90556907653809, 78.74879142216274, 91.1918478012085, 93.46819577898297, 92.25071157727922, 89.21912915366036, 88.57344695499965, 78.71620437077114, 82.16262899126325, 87.60450676509312, 87.14285455431256, 80.63790239606584, 72.02919551304409, 66.92907183510917, 66.0747491291591, 65.66213035583496, 66.1436266217913, 66.948728288923, 67.43759659358433, 65.1858104978289, 69.47260584150041, 66.74818938119071, 68.368009022304, 65.77077238900321, 67.64524350847516, 63.58212457384382, 68.09020614624023, 76.19270202091762, 79.78614357539585, 77.61494268689836, 78.11321190425328, 67.89435727255685, 66.89580386025565, 72.73932225363595, 79.86595058441162, 76.7937559400286, 90.18922969273159, 71.29116480691093, 44.381090436662944, 78.12138993399483, 66.61583314623151, 77.66144698006767, 80.30176244463239, 82.08256489889962, 79.72502722058977, 77.86829485212053, 74.22705663953508, 74.40240137917655, 70.59442724500383, 67.95571681431362, 63.39681611742292, 67.01012257167271, 64.38786547524589, 67.81962244851249, 63.748221261160715, 66.70986311776298, 63.85230527605329, 66.1000405720302, 63.463025501796174, 71.59129919324602, 78.65603991917202, 85.13620785304478, 79.58818244934082, 79.43070152827671, 82.92481858389718, 83.83513682229179, 81.64722551618303, 76.98670741489956, 72.42148385729108, 73.15845843723842, 73.87777764456612, 77.69560432434082, 85.54276084899902, 86.36776215689522, 92.58327320643834, 79.22444425310407, 13.93411374092102, 1.5284664630889893, 1.6547071976321084, 0.6727920068161828, 0.6074329082454953, 0.33429789170622826, 0.32348424196243286, 0.27043849123375757, 0.3172222865479333, 0.24341632266129765, 0.3226735826049532, 6.914129836218698, 73.55052443913051, 70.17258821214948, 107.41782311030796, 96.50728225708008, 136.4194998059954, 65.37927613939557, 40.01340763909476, 57.5022736276899, 75.42195224761963, 91.53526251656669, 91.10051373073033, 66.45927633558, 0.5221021899155208, 0.12468675364341054, 0.2586367316544056, 0.1507503286536251, 0.17569702145244392, 0.21421107623193944, 0.07879769496087517, 0.1506334984941142, 0.1589571689920766, 0.10199945353503738, 0.16325126428689274, 0.13316755928099155, 0.17095362740967954, 0.11845466734043189, 0.13135557222579206, 0.12632715276309422, 0.19655799706067356, 0.11704908204930169, 0.13902394074414456, 0.10237218639148132, 0.1390539998454707, 0.11624257532613617, 0.09253819193691015, 0.1285333958055292, 0.22257085836359433, 0.16802656304623398], [0.020293956123558537, 0.06495789438486099, 0.11158041549580437, 0.015889390238693783, 0.01430107037802892, 0.08865531600479569, 0.06790046327348266, 0.05393228047926511, 0.038706188755376, 0.06335975442613874, 0.022625129337289503, 0.005551195919646749, 0.03446567737098251, 0.06470214096563202, 0.07861520975295987, 0.07419727503189019, 0.03772001613729766, 0.08955138935042278, 0.029866037757268975, 0.26096475816198755, 0.33266791488443104, 10.99386625630515, 96.3281854901995, 94.82150336674282, 94.50014918191093, 70.39067826952252, 75.05895750863212, 65.41033458709717, 53.50434616633824, 71.45035498482841, 53.711228779384065, 53.759199142456055, 30.98221901484898, 0.8275838664599827, 0.0755986398352044, 0.027232466930789605, 0.14984844704823835, 0.09042901332889285, 0.06329860485025815, 0.01293226083674069, 0.07896815652826003, 0.05893376549439771, 0.09620231496436255, 0.7467930359499795, 46.68388673237392, 91.05078547341483, 97.1470306941441, 92.32890660422188, 90.1863045011248, 78.0359479359218, 66.16202545166016, 64.30605043683732, 71.97946030752999, 78.97074467795235, 81.28958783830915, 83.28330394199916, 87.77464730398995, 80.82111944471086, 78.95912728990827, 78.690183367048, 76.37685012817383, 68.19010734558105, 60.216306005205425, 56.231795515332905, 56.64555031912667, 57.46763685771397, 58.34294659750802, 57.37923840114048, 60.56917027064732, 58.49928106580462, 59.15698364802769, 59.93163136073521, 61.55965682438442, 61.05566923958914, 56.67592436926705, 58.03940759386335, 67.55739048549107, 74.23367132459367, 73.4791316986084, 68.9154714856829, 71.4263698032924, 62.20208031790597, 57.99495301927839, 57.46826914378575, 61.4288569859096, 60.72023800441197, 72.87873091016496, 63.30400902884347, 35.02005345480782, 67.82220717838833, 61.34212262289864, 72.20979309082031, 72.99518966674805, 72.15866824558803, 69.58390208653041, 66.2090230669294, 67.8567397253854, 65.22241360800606, 61.89220455714634, 60.15539114815848, 58.643310274396626, 58.76359054020473, 60.5027802331107, 60.0860481262207, 60.79236725398472, 61.156140191214426, 57.632156303950715, 56.19374023165022, 60.63313538687569, 70.89843872615269, 74.28540066310337, 75.78960227966309, 75.08575671059745, 75.05946472712925, 73.34253011431012, 71.81876237051827, 67.96329035077775, 65.03722327096122, 62.35078566414969, 61.51971857888358, 63.833816119602744, 66.5246102469308, 67.16047464098249, 75.51587799617222, 77.83981418609619, 78.2848185130528, 64.50161443437848, 5.395958866391863, 0.9121369293757847, 0.08478295736547027, 0.049966402750994475, 0.06201471481472254, 0.007616250243570123, 0.024294369587940828, 0.04297652853918927, 0.013391070101144058, 0.09570722188800573, 0.030617505112396817, 7.099566834313529, 59.0745849609375, 71.655118397304, 94.01831245422363, 70.09660271235875, 68.2760843549456, 30.93704182761056, 29.159046445574077, 47.60218150275094, 65.42879595075334, 58.13655730656215, 64.92076451437813, 8.871080415589468, 0.7434881904295513, 0.08500258558030639, 0.13538833654352597, 0.03785652041967426, 0.10588978656700679, 0.07154762971081904, 0.0640955510150109, 0.061641208428357325, 0.047874709990407736, 0.025664284293140684, 0.02329412754625082, 0.03610635129734874, 0.019505593426791683, 0.06248367750751121, 0.06268036445336682, 0.061265693578336916, 0.06556787701057536, 0.027456240994589667, 0.12367112242749759, 0.064588398140456, 0.05330953121717487, 0.04343931995598333, 0.013204511138610542, 0.09045209030487708, 0.00987275067849883, 0.06417297186063868, 0.06144625853214945, 0.044603703011359484, 0.009293505689129233, 0.03119028705571379, 0.01103127543215773, 0.0663267777168325, 0.04126839805394411, 0.01635477365925908, 0.09700544258313519, 0.04928550982315626, 0.0611024923356516, 0.002320543538579451, 0.07484243969832148, 0.07796451502612659, 0.02942521051902856, 0.05560793288584266, 0.07890063550855432, 0.06655523367226124, 0.29288016845073017, 0.42007866874337196, 19.20759149960109, 117.57423428126744, 102.32637773241315, 104.47428131103516, 81.80682563781738, 92.86833000183105, 56.50962618419102, 44.96620866230556, 61.64956651415144, 58.94462585449219, 54.892332213265554, 38.49084193365914, 0.9315357570137296, 0.09201889551643815, 0.017117477554295744, 0.03828233846330217, 0.07583552998091493, 0.10053158551454544, 0.09896583881761346, 0.013279524033090897, 0.06729075884712593, 0.10807914087282759, 1.5095989555120468, 51.604726042066304, 93.17679527827671, 98.77508395058769, 94.8235808781215, 93.74285112108502, 80.21345778873989, 68.89908068520683, 68.10010038103376, 75.00319821493966, 82.52617958613804, 85.71761226654053, 85.71773733411516, 89.89475114004952, 85.19196714673723, 81.11445154462541, 81.69057532719204, 78.01925836290631, 71.46732248578752, 63.69756889343262, 59.5202910559518, 59.276972089494976, 60.85787487030029, 60.99121080126081, 60.1011187689645, 62.58265399932861, 60.22633225577218, 61.22516359601702, 63.82756274087088, 64.62395831516811, 62.865800040108816, 59.70227132524763, 61.30493586403983, 70.32618509020124, 75.42183412824357, 75.64119570595878, 73.26489094325474, 75.23751926422119, 63.739174706595286, 61.26324667249407, 60.84652846200125, 63.536516598292756, 65.80547864096505, 76.01757267543248, 69.17229775020054, 36.96538577760969, 70.26024668557304, 65.41141155787876, 74.54675020490373, 75.56134005955288, 75.68634510040283, 72.26370416368756, 71.07833453587124, 70.8271154676165, 66.79048306601388, 64.53158896309989, 61.9586432320731, 60.23841517312186, 61.60659885406494, 63.887789726257324, 62.22869191850935, 63.66804599761963, 62.56516538347517, 60.518469265529085, 59.35839802878243, 64.99467250279018, 75.32540702819824, 79.06222466060093, 78.38555349622453, 75.82132080623082, 77.99854578290666, 75.6972885131836, 75.47550201416016, 70.75797394343785, 66.48090607779366, 67.15114321027482, 65.85651315961564, 66.87050546918596, 69.56277956281389, 70.63326072692871, 78.82016331808907, 81.9117156437465, 79.0239817755563, 74.50967461722237, 9.623240283557347, 1.1378352642059326, 0.29161016802702633, 0.13307230653507368, 0.19799311219581536, 0.24548178325806344, 0.061029400543442795, 0.05455690249800682, 0.09599504965756621, 0.1611651083720582, 0.06817384503249611, 5.1760974526405334, 53.784831047058105, 70.48960672106061, 98.21011897495815, 76.9953579221453, 43.04726907185146, 31.520718302045548, 40.83455269677298, 57.21183197838919, 74.91187109266008, 66.74292959485734, 84.06023066384452, 17.294064555849346, 1.0312447952372688, 0.030176484491676092, 0.12196063064038754, 0.0726253129541874, 0.1149433571845293, 0.09095779566892556, 0.05018431427223342, 0.06323476149035351, 0.06419604205127273, 0.10001072846353054, 0.0934322839602828, 0.04508650442585349, 0.03856273627440844, 0.012371901173277624, 0.08814512552427393, 0.14042145146855287, 0.023219788945945244, 0.04444934647264225, 0.06137755007616111, 0.06240084195243461, 0.0268422159965017, 0.018262975283765366, 0.015131027271438922, 0.06254577703241791, 0.08623911387154035, 0.14316349290311337, 0.19055764403726372, 0.15520788303443364, 0.11672979061092649, 0.13679834588297776, 0.14715429661529406, 0.16862657799252442, 0.135857421372618, 0.11441708542406559, 0.15891021436878613, 0.15194643661379814, 0.10661676898598671, 0.1649441413049187, 0.1563801472740514, 0.14362520884190286, 0.23233750143221446, 0.15347501316240855, 0.20570591118718895, 0.12579670122691564, 0.49836616643837517, 0.6903859313045229, 23.250824689865112, 135.80027634756905, 113.46085902622768, 121.24223000662667, 87.82591111319405, 97.16819490705217, 80.79032502855573, 75.69817093440464, 96.18746362413678, 80.61455644880022, 75.39227649143764, 49.820463384900776, 1.9515689824308668, 0.2573108199451651, 0.18552618473768234, 0.41086695875440327, 0.3146009700638907, 0.32101782145244734, 0.2123982206519161, 0.22051225097051688, 0.11030339223465749, 0.5544625020452908, 1.8676875063351221, 50.62241056987217, 94.73403249468122, 105.85420049939836, 99.46584606170654, 97.9939466203962, 85.1638547352382, 71.7003789629255, 70.2545074735369, 79.80620302472795, 86.8015798841204, 90.90534578050885, 90.01271765572685, 94.6877783366612, 86.6268813269479, 82.48119694846017, 85.43008886064801, 82.76131357465471, 75.56351484571184, 67.77202728816441, 62.34751306261335, 62.31630870274135, 64.93214566367013, 63.487781933375764, 63.34712954929897, 67.00707231249127, 63.34291199275425, 64.64808246067592, 67.10611193520683, 67.2829783303397, 65.0287812096732, 62.31046526772635, 64.67014299120221, 73.636689049857, 80.3203558240618, 79.53853062220982, 77.21398993900844, 78.94986534118652, 68.96632535117013, 63.41172000340053, 63.817216873168945, 66.5122355052403, 70.62370695386613, 79.72704914637974, 74.27691691262382, 41.329816818237305, 71.33192988804409, 67.8691908972604, 76.10057585580009, 82.227691922869, 79.37397643498012, 75.65414714813232, 74.01096766335624, 75.2136869430542, 70.39138698577881, 68.94514724186489, 66.15839154379708, 65.26292855398995, 65.44555500575474, 67.8939264842442, 65.90879835401262, 66.84285858699253, 65.74960122789655, 62.74772235325405, 62.55311025891985, 67.56226117270333, 78.95058795383999, 82.9614703314645, 81.80480371202741, 80.1565659386771, 81.20926666259766, 80.78672586168561, 78.72864859444755, 75.64391245160783, 70.3484332220895, 71.76909664699009, 69.88353620256696, 70.97865567888532, 72.38645798819405, 76.18070943014962, 82.93745040893555, 85.5843597139631, 84.84965024675641, 85.73453113010952, 8.846723505428859, 2.702283190829413, 0.5130586751869747, 0.23697922378778458, 0.40449136229498045, 0.2994556613266468, 0.13451263281915868, 0.32048777703727993, 0.22810813837817737, 0.4443986123161656, 0.14174760745040008, 11.675852792603628, 89.27659075600761, 73.45436137063163, 99.78818689073834, 80.8748151234218, 99.76500770023891, 42.69138581412179, 45.59899500438145, 65.91754613603864, 89.07363387516567, 78.10984897613525, 102.71174567086356, 19.771356173924037, 1.408105424472264, 0.15659434720873833, 0.2649462659444128, 0.18056180541004452, 0.19777941437704222, 0.18714922693158897, 0.18213836795517377, 0.2074945702084473, 0.16816113011113235, 0.13529715500772, 0.1713067234626838, 0.18765225208231381, 0.099863201379776, 0.1893574512962784, 0.18980913848749228, 0.2418116144835949, 0.13054428861609527, 0.16149459140641348, 0.2135616232241903, 0.12134665144341332, 0.12043911085597106, 0.05072894040495157, 0.1093096641291465, 0.12458538051162447, 0.19902463470186504], [0.07436417429042713, 0.02299368581069367, 0.08676393356706415, 0.024485765656988536, 0.03098285211516278, 0.0386364557115095, 0.020768387808597515, 0.1650863622448274, 0.04552248013871057, 0.014427293158535446, 0.06433350646070071, 0.028461785787450414, 0.04546825162002018, 0.07749477201806647, 0.019334124234904135, 0.0674977663106152, 0.03344539140484162, 0.06408828390496117, 0.04621018555813602, 0.10899460674928767, 0.004795176018628159, 56.616965430123464, 108.56180926731655, 92.85931124005998, 70.0044001170567, 48.01281656537737, 42.07826634815761, 128.60166467939104, 100.38755239759172, 49.617694105420796, 48.11795670645577, 32.786735670907156, 1.9488891490868159, 0.3412455746105739, 0.08092426442142044, 0.0725808281983648, 0.02225342276506126, 0.030411050654947758, 0.09452249974544559, 0.014441323566383548, 0.10450857425374643, 0.07946890858667237, 0.24044108231152805, 39.49796942302159, 96.78568267822266, 93.92680467878068, 93.02572059631348, 90.58841064998082, 89.08994129725865, 84.70987333570207, 70.86502483912876, 60.92659255436489, 63.153893198285786, 67.52289962768555, 76.46984481811523, 73.87338638305664, 83.98772621154785, 81.34736210959298, 82.62745652879987, 76.23716354370117, 72.8846299307687, 61.851140703473774, 59.30812086377825, 59.00331728799002, 59.09966795785086, 57.0419658933367, 56.45527737481253, 56.907681533268516, 59.94998155321394, 58.527845110212056, 58.1568877356393, 56.1693867955889, 60.170962061200825, 57.973913873944966, 56.49137674059187, 61.881281988961355, 69.5298103604998, 69.34414754595075, 70.38755852835519, 70.37966537475586, 61.9524176461356, 55.75779635565621, 58.41654886518206, 53.58883626120431, 54.45970262799944, 56.798452377319336, 73.07380853380475, 69.24621963500977, 35.658711024693076, 63.86627810341971, 59.908132553100586, 71.42808600834438, 70.76344912392753, 69.45890399387905, 68.6672123500279, 69.39131886618478, 66.56900923592704, 66.57031549726213, 62.57385063171387, 58.94479261125837, 58.02241577420916, 59.43698910304478, 60.19724014827183, 60.688060896737234, 58.20965930393764, 58.24661677224295, 55.680831159864155, 60.00665800912039, 67.76700374058315, 71.15078340257917, 72.316864831107, 72.35772718702043, 75.77116870880127, 71.15310410090855, 69.62425027574811, 68.07742146083287, 65.26867471422467, 61.93642289297921, 60.455400466918945, 60.61534105028425, 61.026215825762065, 60.744751249040874, 64.80096367427281, 64.84905910491943, 75.23415633610317, 78.67662048339844, 75.28246021270752, 37.01451996394566, 0.6417221597262791, 0.7789220490625927, 0.07197073022169725, 0.20686127990484238, 0.07814012667430298, 0.0765425024021949, 0.12482024862297944, 0.056819351988711526, 0.08224701415747404, 0.0241017792972603, 0.05751674688820328, 5.949801513126918, 34.09622097015381, 46.157595430101665, 32.213894912174766, 34.635296957833425, 33.39255952835083, 24.490466696875437, 38.87666845321655, 55.59551075526646, 62.335527420043945, 67.50499411991665, 31.974664960588726, 0.20203469746879169, 0.025270817102864385, 0.0854014488203185, 0.020479211450687478, 0.020577342881421958, 0.17092379901025975, 0.029322130871670585, 0.049775737803429365, 0.10098823279674564, 0.05150866874360612, 0.06014797676886831, 0.0737606513180903, 0.024540794847000922, 0.013361171303716089, 0.05757905675896576, 0.029288706236651967, 0.04081208664657814, 0.03360393111194883, 0.03313351635422025, 0.06683135671275002, 0.0283500412479043, 0.08958840343569006, 0.010677018236102802, 0.039586123145584545, 0.06813282080526863, 0.07590887961643082, 0.035967780875840356, 0.04900372440793684, 0.05241787174184408, 0.035726052775446854, 0.04126790950873068, 0.02882181986102036, 0.0694176811458809, 0.0181158875514354, 0.09982922034604208, 0.052980964205094745, 0.07490147903029408, 0.021427041751199534, 0.03129457449540496, 0.03789668630010315, 0.05611110392159649, 0.033575062839580436, 0.03886970890952008, 0.03376085251303656, 0.051713973084198575, 0.014612148150003381, 77.23197187696184, 119.4815147944859, 102.00234849112374, 82.439820425851, 61.769367354256765, 60.356666564941406, 109.96701989855084, 63.999669619968955, 41.54105942589896, 44.9759396144322, 37.08040278298514, 2.1064147991793494, 0.4535909704864025, 0.08176902694893734, 0.1261098722794226, 0.006799558709774698, 0.1356106653277363, 0.16499220872563974, 0.5650074247803006, 0.0372530585154891, 0.08752446954271623, 1.2077997156551905, 50.08223329271589, 101.02285398755754, 95.70902456556047, 94.73556804656982, 93.14458342960903, 91.87582847050258, 86.31200286320278, 72.84075205666679, 63.94709260123116, 65.98394312177385, 70.78915051051548, 79.33023752485002, 77.18469633374895, 85.42013904026577, 83.28878607068742, 85.45593615940639, 80.38220868791852, 76.53793021610805, 66.55741964067731, 63.50917543683733, 63.58648109436035, 62.03148814610073, 60.956191880362375, 59.22351264953613, 59.346294266836985, 61.63824789864676, 62.07758249555315, 61.43093449728829, 59.559513636997764, 62.271631785801475, 61.27231407165527, 58.619436264038086, 64.80513954162598, 73.33334459577287, 73.57601043156215, 74.68117700304303, 72.7077704838344, 63.440061705453054, 59.27615220206124, 59.22571522848946, 56.78831148147583, 57.15147645132882, 63.441819599696565, 76.23895617893764, 75.64330101013184, 37.15298366546631, 67.54705851418632, 62.58992876325335, 72.6694928577968, 74.61828885759626, 74.18401254926408, 72.30631746564592, 70.80338042122978, 69.46535887037004, 68.42091260637555, 65.73216819763184, 61.54596192496163, 60.00645651136126, 61.820860454014365, 64.81317165919712, 63.983702659606934, 62.057175636291504, 61.056023597717285, 59.152383940560476, 62.50487586430141, 72.64387484959194, 76.1539727619716, 74.38771983555385, 74.11319650922502, 78.54920441763741, 74.07327216012138, 72.57459436144147, 68.2922180720738, 69.24235643659318, 65.94157995496477, 64.64469868796212, 64.23615850721086, 64.3233722959246, 64.08898871285575, 68.15036364964077, 68.25134876796177, 77.08644185747418, 81.85624817439488, 77.51418685913086, 46.9676650592259, 2.4770043534891943, 1.3418704186167036, 0.2507912383547851, 0.2608305167938982, 0.2545637573514666, 0.3267063876347882, 0.08506850525736809, 0.06086188381803887, 0.12964600324630737, 0.03159339792494263, 0.04251204078484859, 5.428184177194323, 40.29581369672503, 47.323391982487266, 41.592312812805176, 25.186467749731882, 22.5015743800572, 37.937233788626536, 54.71827983856201, 61.738350595746724, 73.41222749437604, 78.09360408782959, 55.4454470361982, 0.6587851441332272, 0.0961636316829494, 0.06415942151631628, 0.032788369338959455, 0.025341564556583762, 0.05532259533980063, 0.03213147619473083, 0.03496412241033145, 0.042125608306378126, 0.03909519627424223, 0.017179388785734773, 0.01972724367598338, 0.016741496211450015, 0.01234641539797719, 0.051249142669673474, 0.037602500657417944, 0.028404164593666792, 0.08406814786472491, 0.026185994601941535, 0.02771637266102646, 0.09388057169105325, 0.054504176934382746, 0.024564309478072182, 0.1091307887275304, 0.06620886190129177, 0.16532975275601658, 0.1695873157254287, 0.16518413914101465, 0.08443289436399937, 0.0817857189103961, 0.14184672784592423, 0.12449779521141734, 0.25795811521155493, 0.16654005566877977, 0.19173301596726688, 0.1412193136555808, 0.15297600493899413, 0.18561121874621936, 0.1691504477390221, 0.15405547272946152, 0.08421766984143428, 0.1285444287849324, 0.23855803906917572, 0.16156258061528206, 0.2694650648960045, 0.08555171040019818, 90.44103240966797, 133.5656384059361, 116.75754301888603, 94.23491559709821, 67.61251749311174, 56.09694487707955, 136.0898494720459, 114.91483211517334, 69.22109494890485, 68.34733813149589, 55.55130284173148, 3.5810956912381307, 0.4848787901656968, 0.32867625621812685, 0.3179627311016832, 0.12059343686061245, 0.25015941368682043, 0.27866016434771673, 0.6741485883082662, 0.2982946607683386, 0.29551614129117554, 1.395111316016742, 49.33610793522426, 106.01500265938895, 98.87223366328648, 96.82631574358258, 96.04767281668526, 96.28254972185407, 91.17371300288609, 76.3345286505563, 67.78966876438686, 70.29168033599854, 75.1430446079799, 82.9629294531686, 81.61361707959855, 90.67623588017055, 87.455808367048, 89.50031580243791, 84.72370025089809, 79.10065514700753, 69.98014395577567, 65.96873351505825, 66.66538769858224, 65.53883457183838, 63.7177186693464, 62.987310137067524, 63.68623638153076, 64.7993586403983, 65.23564992632184, 63.282261167253765, 62.49275125776018, 65.77091830117362, 64.5756961277553, 62.011359214782715, 68.36333288465227, 75.5837618964059, 78.5672766821725, 78.17820535387311, 76.22271823883057, 68.78968824659074, 63.1631759916033, 63.31430625915527, 60.4480562210083, 59.18853541782924, 66.02607699802944, 79.69492067609514, 80.18233680725098, 43.275680678231375, 69.24844305855888, 65.74868406568254, 73.35295241219657, 79.19218376704625, 78.71141706194196, 76.36493396759033, 75.99077347346714, 74.08525085449219, 74.57804489135742, 69.3181404386248, 64.19628974369594, 61.925993646894185, 64.23522744859967, 65.48304053715297, 66.25258827209473, 64.43306350708008, 64.33034133911133, 61.862820625305176, 66.4446017401559, 75.87430082048688, 79.31008080073765, 76.44494942256382, 76.09473242078508, 81.77897030966622, 78.38629000527519, 75.80167130061558, 73.71534960610526, 73.31714834485734, 69.6783697945731, 67.97110707419259, 68.95037923540387, 68.79206453050885, 68.80734361921037, 71.6415763582502, 72.10305486406598, 80.84651511056083, 86.85729054042271, 79.58091463361467, 54.504924978528706, 1.9561906201498849, 1.8894685889993394, 0.33785778496946606, 0.588701921914305, 0.2596005227948938, 0.47350551187992096, 0.3273756131529808, 0.1944650557956525, 0.225284998438188, 0.0988711356850607, 0.1381202678063086, 9.259233713150024, 52.458121163504465, 54.24386726106916, 49.87891163144793, 52.111784730638774, 49.517039026532856, 36.333919593266074, 56.51009866169521, 74.7058778490339, 84.83033425467355, 89.99885599953788, 69.37303815569196, 0.8885566975389207, 0.19272043369710445, 0.1201866686876331, 0.22469527008278029, 0.1084883992693254, 0.29215177467891146, 0.09010996616312436, 0.08508582147104399, 0.139295029054795, 0.17933961456375463, 0.13941712464605058, 0.08386190036045653, 0.13827973710639135, 0.09343970713338681, 0.14525319077074528, 0.14555845010493482, 0.12196262553334236, 0.14000297178115162, 0.07328815345785447, 0.21660249148096355, 0.15509151427873544, 0.14072960136192186, 0.16004410066774913, 0.14511715807020664, 0.09344974945166282], [0.037040884007832835, 0.025464906955936124, 0.04228462977334857, 0.03380021772214344, 0.034421972930431366, 0.07509933984173195, 0.05660938950521605, 0.06142409757844039, 0.09513845347932406, 0.05814797444535153, 0.08194836375436612, 0.023538888698177676, 0.025334217718669345, 0.07515861666096108, 0.10486497477229152, 0.027389278069936802, 0.15936046306576046, 0.052581687058721266, 0.12254437431693077, 0.17292209821087973, 4.3844262191227505, 92.14961528778076, 94.17740535736084, 83.12286308833531, 55.39536789485386, 27.441166877746582, 34.90429994038173, 97.52322701045445, 124.54322188241142, 70.63952105385917, 57.064161913735525, 8.845586606434413, 0.2445484719106129, 0.19653959519096784, 0.05610310060105153, 0.26615115414772716, 0.21196325256356172, 0.07477415871939488, 0.07367400918155909, 0.11124826581882578, 0.21140226695154393, 1.4888686793191093, 44.43560252870832, 96.89790998186383, 89.12113870893205, 93.22866358075822, 90.0255092893328, 89.19241333007812, 87.21148885999406, 83.9039170401437, 72.74066325596401, 62.49762889317104, 59.22529138837542, 60.45631068093436, 61.851731300354004, 71.94807529449463, 76.56100518362862, 84.07966477530343, 81.02226284572056, 76.92638315473283, 69.39899662562779, 65.53268541608537, 63.826256479535786, 64.33226599012102, 60.91724722726004, 59.43831620897566, 56.34335579190935, 54.42414174761091, 55.840903759002686, 56.30390739440918, 55.90034212384905, 56.767803873334614, 55.88864483152117, 55.033453600747244, 57.27067974635533, 68.43668501717704, 69.99590247017997, 67.70972279139927, 68.62903199877057, 64.42328044346401, 61.59241758074079, 61.01140921456473, 65.48962048121861, 62.50438254220145, 61.89082186562674, 62.16559532710484, 69.59239973340715, 71.23323072705949, 30.75329324177333, 61.177714347839355, 60.89812578473772, 67.09631497519356, 70.04423413957868, 69.73554652077812, 69.02527386801583, 67.10790457044328, 67.00022833687919, 65.45879132407052, 63.552191734313965, 59.43340383257185, 53.46675293786185, 55.839701720646445, 61.558829988752095, 58.4451059613909, 58.95088618142264, 58.99401365007673, 54.62715073994228, 58.63311726706368, 71.30238614763532, 71.8761544908796, 71.37757955278668, 74.71788433619908, 72.29824365888322, 67.58627414703369, 65.897292137146, 64.71453503199986, 62.73893983023507, 61.107329096112935, 58.10866028921944, 58.463650703430176, 58.87849290030343, 60.66126864297049, 59.63679150172642, 63.29947880336216, 66.43414470127651, 74.93516145433698, 78.68174825395856, 68.71377917698452, 17.260570764541626, 0.15026121347078256, 0.7941754077162061, 0.23744225608451025, 0.20982893423310348, 0.11532689231847014, 0.06683798599988222, 0.08357928373983928, 0.13008703743772848, 0.046187230718455145, 0.08271395481590714, 0.3022067408476557, 15.429247958319527, 29.326254844665527, 38.96292339052473, 32.81872170312064, 34.43411881583077, 19.554398672921316, 27.962207078933716, 56.084076813289094, 61.6465232031686, 65.026474407741, 63.566289629255024, 11.4873594556536, 0.6078799813985825, 0.12123166689915316, 0.0808184536706124, 0.06247464620641299, 0.06947450166834251, 0.04122012707271746, 0.060689183085092475, 0.021047009554292475, 0.04658310840438519, 0.09741528451974903, 0.09453225707901375, 0.007328311363900346, 0.0404877469076642, 0.07384728666927133, 0.1272176078387669, 0.062032709563417096, 0.04924441434975181, 0.031987216257091076, 0.07010501676372119, 0.027653686203328625, 0.08412497517253671, 0.028253207515392984, 0.09606377168425492, 0.08338797757668154, 0.04211876528071506, 0.054601132803197415, 0.11122537204729659, 0.040393389827970944, 0.06191771144845656, 0.02275726046147091, 0.006285274118584181, 0.05339139307449971, 0.0681256554754717, 0.04162666454379048, 0.0077916048966082075, 0.03902258963457175, 0.024538840666147213, 0.01954529620707035, 0.09313279217375176, 0.014512233868507403, 0.08434981453631606, 0.07465092997465815, 0.16142277526003973, 0.3084033669105598, 7.968980159078326, 112.2638372693743, 100.87375259399414, 93.70808928353446, 65.5232150214059, 43.062176431928364, 42.68791171482631, 79.71973964146206, 106.40613760266984, 56.36170598438808, 60.08668736049107, 11.024178641183035, 0.09801519090043646, 0.2922394685447216, 0.41848948544689585, 0.2774511235100882, 1.0489599875041415, 0.3668525091239384, 0.5037534630724362, 0.6656670634235654, 0.08296571844922644, 2.940621384552547, 53.836984225681846, 98.87176118578229, 90.93087346213204, 96.21961293901715, 91.5881244114467, 93.02977834429059, 88.79450389317104, 86.33429963248116, 77.26416288103376, 65.34738390786308, 62.50069304874965, 62.436095646449495, 66.06003979274205, 73.58249310084751, 80.5435597555978, 84.10394872937883, 84.63701452527727, 80.70144367218018, 72.4860395703997, 66.63794231414795, 67.6901775087629, 68.13417434692383, 65.12479141780308, 62.35416943686349, 59.470667021615164, 57.79229143687657, 58.21540199007307, 58.40570967538016, 57.35433605739048, 60.51020090920584, 59.22603484562465, 57.08522885186331, 61.44610936301095, 72.11627728598458, 72.38740294320243, 72.13223034994942, 72.42453411647251, 66.91568265642438, 65.88634872436523, 65.36893721989223, 68.65281568254743, 65.36608151027134, 64.98961421421596, 67.37500027247837, 72.20620087214878, 75.21085902622768, 33.68297685895647, 62.61976432800293, 62.6906498500279, 68.58778054373605, 75.37357194083077, 73.32847390856061, 72.9181341443743, 70.03815446581159, 71.48027392796108, 68.75968592507499, 65.25677245003837, 61.61518682752337, 57.16870450973511, 58.21154573985508, 63.81570911407471, 61.637205668858115, 60.506699017116, 61.28469576154436, 57.52873584202358, 63.045466559273855, 74.59273338317871, 74.58787659236363, 72.22604492732457, 75.08283846718925, 72.98086942945207, 71.94398975372314, 69.6440179007394, 68.27196407318115, 66.6681044442313, 63.58648109436035, 62.957349504743306, 62.34730461665562, 63.443243980407715, 63.576941217694966, 63.60101672581264, 64.45233086177281, 69.59386580330985, 78.15979262760708, 84.45085838862828, 74.6244866507394, 25.861295904432023, 1.0516868297542845, 0.5510050132870674, 0.6109990711723055, 0.3320011592337063, 1.0462505157504762, 0.2651775378201689, 0.2061130864811795, 0.2845059878059796, 0.20961020168449196, 0.09599644743970462, 0.09194531517901591, 16.502409390040807, 32.54821443557739, 40.5402443749564, 36.33900567463466, 20.24225296292986, 23.617562770843506, 34.59569569996425, 64.48407718113491, 71.8159761428833, 72.3889593396868, 84.2127297265189, 25.311193125588552, 0.4118234488580908, 0.1783883763211114, 0.09717082870858056, 0.0412773377528148, 0.13735754016254628, 0.08024657078619514, 0.0894540399312973, 0.024419119947456887, 0.02158599706100566, 0.08096446083592516, 0.07171476645661251, 0.07817479981375591, 0.045695967972278595, 0.08073051553219557, 0.05839987378567457, 0.061432938889733384, 0.03567128821409174, 0.008974404240559255, 0.07932564948818513, 0.013275055879993098, 0.09522090226944004, 0.031875512429646084, 0.11918713232236249, 0.05530861073306628, 0.1297757662832737, 0.11157894986016409, 0.12102977558970451, 0.12061908548431736, 0.13432839699089527, 0.1470274105668068, 0.14230984156685217, 0.12082770786115102, 0.17434289625712804, 0.09593374401863132, 0.13415337566818508, 0.11005251069686242, 0.10946507578981773, 0.14664813663278306, 0.2765045943004744, 0.24254559938396725, 0.22756178198116167, 0.24566227357302392, 0.2653609322650092, 0.45459987063493046, 10.40325026852744, 124.90217971801758, 113.45859391348702, 106.6961693082537, 78.41382571629116, 45.0980681010655, 46.98039763314383, 103.42409583500454, 136.46182823181152, 98.1465151650565, 86.51329912458147, 14.553827047348022, 0.288050111915384, 1.0307365996497018, 0.5013465636542865, 0.8567247741988727, 1.1987037637404032, 0.3724654050809996, 0.5977395198174885, 1.1597837550299508, 0.42911903506943155, 2.72873216015952, 52.69776105880737, 104.00498608180455, 93.81491783687046, 100.37183557237897, 96.56310408455985, 94.36795970371791, 93.77940559387207, 91.46842779432023, 79.91053022657121, 69.8717520577567, 67.50031798226493, 67.70827061789376, 69.60836669376918, 79.2062052318028, 85.16976070404053, 89.49472250257219, 85.64818586621965, 85.64702551705497, 76.32015282767159, 70.85740266527448, 70.73803261348179, 70.03434685298375, 68.45924581800188, 66.02345057896206, 63.4588565826416, 60.869103159223286, 64.51309980664934, 61.64133289882115, 61.082253047398154, 63.20093250274658, 60.724017824445454, 61.160649572099956, 64.53023406437465, 74.09324128287179, 74.98253427233014, 76.49390642983573, 75.26230348859514, 73.648834500994, 67.61495631081718, 67.91500731876918, 71.26663766588483, 68.6881125313895, 69.88784408569336, 70.05533736092704, 75.91545500074113, 79.44696726117814, 38.64846529279436, 65.01695537567139, 66.74356188092912, 71.18594128744942, 78.13434832436698, 76.11489609309605, 77.53875568934849, 73.44688510894775, 73.66498211451939, 71.48684692382812, 69.94352000100272, 65.87289006369454, 59.77823598044259, 63.65188448769705, 68.7359230858939, 63.58407701764788, 64.89044952392578, 63.14147676740374, 59.52517563956124, 65.09093979426792, 78.17894186292375, 79.26097093309674, 73.38414287567139, 79.7210111618042, 77.91653619493756, 75.98583330426897, 73.82767418452671, 72.21986103057861, 68.93209852491105, 66.64728764125279, 66.59008312225342, 66.64796161651611, 67.29999446868896, 67.91353430066789, 66.19622448512486, 69.37289919172014, 72.43078054700578, 84.08073479788644, 91.08871568952287, 75.17734091622489, 26.694937297276088, 1.120271846652031, 1.5938625825302941, 0.8644310321126665, 0.5958473842058862, 0.7881118559411594, 0.6723357598696436, 0.25976320835096495, 0.6244003006390163, 0.5222331743155206, 0.12081596920532839, 0.5916045318756784, 26.11797799382891, 47.019846030644004, 54.18178858075823, 51.623437540871755, 53.013455935886924, 30.065768991197857, 43.24834993907383, 72.52068328857422, 83.75743511744908, 84.40214456830705, 99.40745340074811, 27.10022919518607, 1.015452191233635, 0.36185482729758534, 0.191056828679783, 0.14493320722665104, 0.15096701202648027, 0.13902429358235427, 0.13777835401041166, 0.08527103438973427, 0.18425288663378783, 0.17576798264469418, 0.12128642467515809, 0.17980880795844964, 0.17022490794105188, 0.201302775314876, 0.2092002715383257, 0.1745820798512016, 0.15314930278275693, 0.13427214643784932, 0.10806172966424908, 0.18541694059967995, 0.2247445181544338, 0.10493405642254011, 0.1919213772884437, 0.13567367408956799], [0.06598537282219955, 0.019850620002086674, 0.10591671083654676, 0.09183674957603216, 0.04879295446776918, 0.062237518573445935, 0.12521599738725595, 0.07955737598240376, 0.060422098131052086, 0.03463254948811872, 0.01826245790081365, 0.05054803618362971, 0.08865819299327475, 0.013412449891412897, 0.08930447724248682, 0.10634518534477268, 0.10635272386882987, 0.08742991568786757, 0.2859040956412043, 0.49967286203588757, 22.24686210496085, 104.01522772652763, 84.84391103472028, 96.08588790893555, 59.55087007795061, 38.93708651406424, 43.46226760319301, 67.20859786442348, 69.07190322875977, 55.72977079663958, 23.585753917694092, 0.0442869153672031, 0.028479336095707755, 0.06477131761078324, 0.0650619138032198, 0.07518539843814713, 0.5253627949527332, 0.2408533873302596, 0.7351087172116552, 0.17369022699339048, 0.36293624926890644, 55.46754925591605, 103.59082480839321, 89.31422219957624, 86.67073835645402, 83.69975812094552, 87.7343338557652, 86.60459150586809, 84.07743440355573, 81.47904436928886, 75.84418037959507, 64.75501523699079, 58.87881251743862, 56.32122925349644, 57.10690723146711, 60.91424560546875, 72.79258019583565, 77.69334615979875, 80.50015435900006, 73.50478444780622, 69.59217739105225, 68.82242121015275, 67.14278452736991, 66.58335031781877, 64.29908834184918, 60.476279803684776, 54.69293628420149, 53.121333667210166, 54.50837128502982, 54.61107260840279, 53.327326910836355, 54.75504623140608, 54.27186155319214, 55.76776007243565, 60.94617257799421, 65.07388196672711, 64.72890390668596, 67.70795794895717, 65.03621578216553, 60.89753518785749, 66.33015101296562, 70.68278053828648, 73.30465548379081, 70.66052545819963, 66.39108671460832, 68.45801598685128, 69.28433745247978, 75.37879003797258, 29.506845474243164, 56.12590844290597, 59.30052648271833, 65.3053195135934, 71.95673969813755, 69.04405484880719, 70.90321213858468, 67.45919159480503, 68.4059670312064, 65.16943359375, 62.43554673876081, 61.337314469473704, 58.61084829057966, 54.179315022059846, 60.77075835636684, 62.79979910169329, 58.34191826411656, 55.53820201328823, 55.603584562029155, 62.305754389081685, 72.09180573054722, 70.69749682290214, 69.91954176766532, 68.65844372340611, 66.7186803817749, 61.915293421064106, 63.367362703595845, 63.181032861982075, 63.87241336277553, 60.72253785814558, 59.76607663290841, 55.70517417362758, 58.9963412966047, 59.19105066571917, 60.2312376839774, 57.4364081791469, 64.671233858381, 74.28660270145961, 73.99880831582206, 79.83536461421421, 52.080931254795615, 11.68618997505733, 0.18354638240167073, 0.6088831275701523, 1.5596256596701485, 0.19706019439867564, 0.07341836432793311, 0.1655580119362899, 0.30440766417554443, 0.2505123604621206, 0.061090366914868355, 0.15893806144595146, 0.5024846025875637, 24.525985888072423, 45.00493792125157, 37.0477670942034, 27.05560612678528, 37.59409005301339, 24.855332238333567, 25.046906232833862, 44.486574513571604, 61.92600754329136, 71.25173377990723, 60.62768105098179, 0.4767809904047421, 0.07357308388288532, 0.08948480470904283, 0.12356897576579026, 0.01843207808477538, 0.0377945498164211, 0.03690585893179689, 0.01929737817096923, 0.07621780303972107, 0.09268846708749022, 0.06841180047818593, 0.04408665254179921, 0.028653125877359083, 0.06357374401496989, 0.12356605806521007, 0.004029250354506075, 0.037944760506174395, 0.02942079325605716, 0.027218112522470098, 0.00665696118293064, 0.027054122482825602, 0.018799752462655306, 0.058640197318579466, 0.05159692918615682, 0.048215334569769244, 0.0641772330605558, 0.05665799296860184, 0.014778253522568514, 0.06126034672238997, 0.04450161402512874, 0.025627567066944072, 0.018247005962101475, 0.014554886579779642, 0.04731537661116038, 0.03359136125072837, 0.07188406772911549, 0.09614040542926107, 0.03571372379415801, 0.0981910807479705, 0.05030032679704683, 0.0794578552512186, 0.10065395251980849, 0.3548579913164888, 0.43963678926229477, 33.8933961050851, 121.21258899143764, 93.38292748587472, 105.4262262071882, 64.94502067565918, 50.17470686776297, 28.31936706815447, 62.54739189147949, 73.91801466260637, 57.45997994286673, 25.40557745524815, 0.07888651519481625, 0.1217097355318921, 0.14054229855537415, 0.23573907890490123, 0.5998380929231644, 0.8600734259401048, 2.1127263690744127, 1.5540168349231993, 0.2778437781546797, 1.059030641402517, 63.400978088378906, 107.2569306237357, 93.08284868512834, 91.49369144439697, 87.21843011038644, 89.2251671382359, 90.15298094068254, 87.65864018031529, 86.24124240875244, 78.86199842180524, 69.00774356297084, 63.09005314963204, 60.76050281524658, 59.84347261701311, 64.20389107295445, 76.06447996412004, 81.20759909493583, 84.63370718274797, 77.82944052559989, 74.24520533425468, 71.0832052230835, 69.52051367078508, 70.95244012560163, 66.74625083378383, 62.6008026940482, 57.09266689845494, 57.779409476688926, 56.95254952566964, 57.318948881966726, 56.50452273232596, 58.982757568359375, 57.16791936329433, 58.44972651345389, 63.955722263881135, 67.94674668993268, 68.01151084899902, 69.72375542776925, 67.26478099822998, 63.10485281263079, 69.27959183284214, 75.15685762677873, 75.02498776572091, 74.90004525865827, 70.54227406638009, 73.09679317474365, 73.14636162349156, 80.71766771589006, 32.4648117337908, 59.65225124359131, 64.36887604849679, 66.84544331686837, 73.48368276868547, 72.4334694998605, 74.42501081739152, 68.70073046003068, 70.3903933933803, 69.13602120535714, 64.25541196550641, 65.83345208849225, 60.68396840776716, 55.965714250292095, 62.07133606501988, 65.4079235621861, 59.220511027744834, 58.87643623352051, 56.82838521684919, 63.68429088592529, 74.45303290230888, 72.17794254847935, 73.10961260114397, 73.45970453534807, 67.79610279628209, 66.3562206540789, 67.37371485573905, 66.85018198830741, 68.62835107530866, 64.97361946105957, 62.48426750728062, 59.42642784118652, 62.62319673810686, 62.450707708086284, 63.09126213618687, 60.19394670213972, 66.6510396684919, 77.9706974029541, 76.04356588636125, 85.64712279183524, 59.497028487069265, 17.25331163406372, 0.8322589184556688, 0.657380142382213, 1.2796508201531, 0.7453675153000014, 0.7407191161598478, 0.5147889937673296, 0.5248913488217762, 0.44156941984380993, 0.04247948806732893, 0.18549456500581332, 0.49793434675250736, 28.044178451810563, 44.456064973558696, 43.073647907802034, 19.657322338649205, 30.957156862531388, 33.949812003544395, 38.44395201546805, 50.7143942969186, 70.84582001822335, 79.37278134482247, 81.58496965680803, 2.2117475356374467, 0.29136277415922707, 0.06720356031187943, 0.06714601375694786, 0.06191414235425847, 0.07451340449707848, 0.022566205356270075, 0.05950485449284315, 0.03655908003981624, 0.09092563310904161, 0.020910914089264612, 0.04408949560352734, 0.0355985153333417, 0.021119036046522002, 0.06712459919175931, 0.031731255884681425, 0.012830567945327078, 0.009951923840812274, 0.06925530093056814, 0.005426157182747764, 0.02545807241196079, 0.06831663594182048, 0.036892362870275974, 0.019066340389794538, 0.1941399560975177, 0.07991512678563595, 0.14141570883137838, 0.16694043204188347, 0.1347369836377246, 0.11209607496857643, 0.2406037135847977, 0.1855389547667333, 0.10851492998855454, 0.16622566325323923, 0.1652548424899578, 0.2015385390924556, 0.12631299852260522, 0.1434108189174107, 0.22745992030416215, 0.1904806438833475, 0.17104513464229448, 0.30089410128337996, 0.36266806508813587, 0.527748741209507, 41.16412660053798, 134.44088908604212, 105.46271814618791, 121.13016945975167, 78.56718635559082, 57.83247634342739, 57.79592187064034, 81.06272915431431, 83.21345370156425, 79.05422033582414, 34.64696298326765, 0.2824301320527281, 0.1851237184767212, 0.20984732253210886, 0.4590514674782753, 1.3498940680708205, 2.200695340122495, 2.012892480407442, 2.556103514773505, 3.9270176206316267, 0.81949632614851, 66.3087853022984, 111.56732204982212, 96.27644225529262, 96.96071474892753, 94.19806235177177, 94.17821134839738, 94.3360674721854, 91.19059712546212, 89.39951133728027, 83.21319661821637, 72.7438941683088, 67.47910513196672, 62.43620681762695, 63.54320771353585, 67.53667095729283, 79.7280774797712, 86.38921124594552, 86.27453817640031, 80.00844424111503, 77.55766868591309, 76.92444460732597, 73.7060181753976, 74.44634178706578, 71.48836163112095, 67.06399890354702, 61.09133434295654, 60.090140615190776, 59.52847603389195, 61.3802821295602, 58.80410548618862, 60.70631381443569, 61.71042578560965, 63.697839873177664, 67.26789379119873, 71.33309023720878, 71.99111938476562, 73.97090435028076, 71.03296279907227, 65.16946138654436, 73.76433440617153, 78.93010466439384, 77.36434200831822, 79.27697958265031, 73.4840510232108, 76.81350272042411, 77.5456691469465, 85.85241426740373, 38.59345987864903, 60.9587071282523, 66.05278587341309, 69.99542304447719, 79.49688311985561, 77.81253555842808, 77.4564403806414, 72.54261180332729, 75.48934977395194, 72.67074353354317, 68.37241418021065, 69.14647129603794, 62.78975200653076, 58.84137562343052, 64.49109486171177, 68.87146854400635, 63.2733188356672, 61.937305314200266, 62.0753173828125, 68.7492983681815, 79.34210504804338, 73.8988515308925, 75.9088750566755, 76.75659697396415, 74.24711608886719, 71.18338435036796, 71.1903464453561, 71.39046846117292, 73.13209697178432, 68.94065870557512, 66.90945012228829, 63.26785755157471, 67.4940437589373, 66.99273123059953, 66.84919534410749, 64.646942956107, 72.30999306270054, 82.62747042519706, 79.56963075910295, 87.23194435664585, 62.2895998273577, 18.36915237562997, 1.1770747814859663, 1.7767870468752724, 4.136509716510773, 1.2730163761547633, 0.3574316203594208, 0.7243530143584523, 0.8345479156289781, 0.7940374208348138, 0.1836864591709205, 0.2495816004063402, 1.4525280807699477, 39.75311074938093, 60.33904593331473, 53.24108934402466, 38.75545365469796, 54.048577717372346, 38.30629430498396, 41.798820223127095, 61.82361888885498, 82.59041568211147, 89.94543130057198, 91.98017651694161, 2.1656071543693542, 0.34114781128508703, 0.1758919238512005, 0.14630375296941825, 0.20380215905606747, 0.20505618676543236, 0.0756537097373179, 0.13549375374402317, 0.15912088592137608, 0.15312199853360653, 0.1152638564152377, 0.12084754822509629, 0.12660630206976617, 0.12342372855969838, 0.1814008139606033, 0.0789214801043272, 0.1251484424407993, 0.08994966905031886, 0.209020609036088, 0.15398483723402023, 0.12497602669256073, 0.18138713469462736, 0.13951487440083707, 0.07741123078657047], [0.05255143118223973, 0.026637982044901167, 0.04444865436692323, 0.07029563760651009, 0.04141010669991374, 0.06530356726476125, 0.05813187959470919, 0.07530180790594646, 0.01459808720807944, 0.0625055195497615, 0.03651460885469403, 0.05976355275405305, 0.03862355676080499, 0.020487696531095674, 0.09297550097107887, 0.024674050642975738, 0.07481109138045992, 0.07940134006951537, 0.12515862046607903, 0.10187414847314358, 52.17474930627005, 96.80588109152657, 78.99511895860944, 75.37022985730852, 39.578575474875315, 34.94038540976388, 61.27323123386928, 52.7531555720738, 54.97170843396868, 37.89866781234741, 3.33182298711368, 0.27785213770610945, 0.16467298514076642, 0.14474475091057165, 0.28631884338600294, 0.3123561590909958, 0.451106283813715, 1.0531137074742998, 1.3465911767312457, 0.36424118067537037, 42.79388216563633, 101.9845472063337, 86.07192175728935, 88.23689705984933, 77.43626281193325, 77.71394756862095, 79.58528505052838, 81.93732670375279, 80.03444440024239, 79.48073550633022, 74.63210187639508, 69.40238734654018, 59.465316908700125, 57.81477928161621, 56.420619760240825, 56.69308989388602, 69.73791585649762, 78.88519845690045, 81.34641020638603, 77.38285895756313, 72.80166843959263, 72.4951000213623, 70.13492897578648, 69.19043254852295, 63.45377744947161, 59.32380294799805, 54.531779766082764, 53.35535594395229, 51.982961654663086, 53.028054101126536, 51.58991248267037, 52.00135006223406, 53.46570028577532, 58.53108991895403, 61.492766516549246, 61.977125440325054, 70.23168958936418, 66.55401502336774, 60.187401499067036, 56.90365505218506, 62.422463280814036, 71.62370559147426, 70.67833369118827, 73.16150174822126, 73.64070510864258, 72.04978997366769, 69.8330089024135, 68.85698849814278, 24.953840323856898, 57.66873162133353, 64.15778977530343, 66.40142563411167, 66.58945083618164, 67.48378126961845, 70.48904391697475, 67.58883108411516, 67.41172845023019, 65.20808642251151, 63.54072720663888, 64.76818207332066, 62.46719578334263, 56.708025046757285, 54.90931013652256, 61.374549865722656, 55.40950400488717, 57.40390798023769, 53.471477712903706, 57.99387257439749, 68.73563820975167, 70.71549265725272, 72.61620712280273, 69.72584683554513, 63.58707863943917, 63.43282863071987, 61.1703006199428, 61.280283655439106, 60.41027191707066, 60.790741375514436, 58.27977010181972, 54.97759703227452, 57.215333870479036, 58.906111989702495, 57.51111173629761, 57.01372494016375, 64.72417218344552, 72.59665489196777, 78.29451819828579, 68.81372206551688, 71.51650183541435, 51.27181352887835, 9.472911664417811, 0.4504999720624515, 0.2654680050909519, 0.9160216237817491, 1.1369832413537162, 0.12344318894403321, 0.39743541234305924, 0.0676546028948256, 0.09644326953483479, 0.06527595767485243, 0.10899177047290973, 6.229866896356855, 31.798434325626918, 43.024204526628765, 39.21640757152012, 31.657601288386754, 18.060727051326207, 20.59561923571995, 47.24341474260603, 57.59315953935896, 63.3930640901838, 79.29965155465263, 16.362394503184728, 0.5913736128381321, 0.13757568917104177, 0.08404348311679703, 0.05219913919323257, 0.02268668094516865, 0.08214639419955866, 0.05381778448021837, 0.028464934189936945, 0.06117249000817537, 0.015518029719325048, 0.012879747315309942, 0.027663073735311627, 0.027886993684140698, 0.05129936783175383, 0.08514408727309533, 0.027484452784327523, 0.06353495895330395, 0.04929914837703109, 0.05110168004674571, 0.03465081225814564, 0.0547047111737941, 0.03782999987847038, 0.047751854439931254, 0.015029319961156164, 0.06939322674380881, 0.026451242422418933, 0.019070019745933156, 0.011606398321289037, 0.04351477983540722, 0.05314197717234492, 0.04805077625704663, 0.03425579631168928, 0.027888640827898468, 0.02868455901209797, 0.024459528404154947, 0.07493523614747183, 0.03193783926378403, 0.07191324473491736, 0.0030779120279476047, 0.06465005661760058, 0.07485642430505582, 0.08828062896749803, 0.07016320792692048, 67.78750787462506, 106.68396827152797, 87.40664291381836, 87.45099326542446, 56.65873452595302, 50.43203340257917, 41.009935651506694, 58.41129602704729, 58.12013176509312, 42.4352057320731, 3.973252671105521, 0.2671868971415928, 0.028616196608969142, 0.5918243229389191, 0.13522672307278427, 0.6438175301466669, 1.6079298619713103, 2.3117058404854367, 1.1272523977926798, 0.6413005452070917, 52.39346122741699, 106.63919407980782, 88.97874232700893, 89.5621200289045, 78.21346051352364, 79.09992558615548, 83.2118000302996, 82.45392526899064, 83.57522555759975, 83.22114535740444, 78.91016333443778, 71.39501953125, 61.84567941938128, 60.94654778071812, 59.372586250305176, 59.43999072483608, 72.51271370479039, 82.18868473597935, 83.90518856048584, 81.8786769594465, 75.49333803994315, 75.30221394130162, 74.50536673409599, 72.18472399030412, 67.10493768964494, 64.32941722869873, 58.447718484061106, 55.751299789973665, 55.60397366115025, 56.02728223800659, 55.22215277808053, 56.0148275920323, 56.41422046933855, 61.20641735621861, 64.56065327780587, 66.36130673544747, 71.29536846705845, 69.42078617640904, 62.79789529527937, 58.71650954655239, 65.3827154976981, 75.73024381910051, 74.99527726854596, 74.59357411520821, 76.1846421105521, 75.49686077662876, 72.1496216910226, 70.14243303026471, 28.078549453190394, 59.05862494877407, 66.49020276750836, 66.09270327431815, 70.52585547310966, 71.19965703146798, 73.9431324005127, 70.70249952588762, 69.78690760476249, 69.38851874215263, 65.65262522016252, 69.04437446594238, 66.06733540126255, 59.420563561575754, 56.92996440614973, 63.03300149100167, 57.62475994655064, 58.69247572762625, 54.46767915998186, 60.61520903451102, 72.06230367933, 74.2698505946568, 76.3242939540318, 72.21344784327916, 65.0252376283918, 66.59194523947579, 65.85418551308769, 65.17466558728898, 63.76912144252232, 63.4620110648019, 62.599420002528596, 59.75867680140904, 61.48964677538191, 63.137134143284385, 60.501286370413645, 59.48482050214495, 68.56500434875488, 75.8095714024135, 80.60037517547607, 73.34709508078438, 73.52049432482038, 61.125241552080425, 13.018033708844866, 0.5062243076307433, 0.5083866087453706, 2.8029193793024336, 2.568214442048754, 0.5562627911567688, 0.3843407721391746, 0.3472387215920857, 0.2829650619200298, 0.12649020472807543, 0.18554787071687834, 6.176633272852216, 34.82040739059448, 48.1101747240339, 41.08051197869437, 29.40391833441598, 26.54724986212594, 28.627205269677297, 53.83043902260916, 65.06646823883057, 69.08791882651192, 90.03607749938965, 31.36036777496338, 0.47897759824991226, 0.08290140690015894, 0.10354018264583179, 0.03264656909076231, 0.17508401934589657, 0.022308723369081105, 0.06285026962203638, 0.0494297188706696, 0.046031971728163104, 0.026262251760012338, 0.03877745868105974, 0.07036103481160742, 0.018417414943022386, 0.06132283979760749, 0.08936125026749712, 0.027460330864414573, 0.07016185085688319, 0.021206309220620563, 0.07311915074075971, 0.04249924361439688, 0.04640321520024112, 0.0514310138033969, 0.035855571539806466, 0.12094934204859392, 0.1584177879350526, 0.15381248933928354, 0.16025623785597937, 0.11371807900390454, 0.13547514831381186, 0.11195300585989441, 0.16379976485456738, 0.08870783461523907, 0.13451968958335264, 0.070785166695714, 0.08970236339207206, 0.164175469694393, 0.16210660285183362, 0.1566716730594635, 0.06332221786890711, 0.1332602064524378, 0.13614802435040474, 0.2038645978484835, 0.22677284931497915, 78.88503864833287, 122.1802785055978, 99.1312277657645, 100.50313568115234, 60.38097831181118, 51.08068248203823, 72.38410254887172, 70.19314793178013, 72.2195692062378, 59.96203667776925, 6.757010655743735, 0.39140828432781355, 0.584880955517292, 0.9567442557641438, 0.932515561580658, 1.3401473739317484, 1.8261177369526453, 3.178059135164533, 6.687959023884364, 1.7488749389137541, 52.65710367475237, 111.63160678318569, 92.59695420946393, 93.72111020769391, 83.97284317016602, 84.0819159916469, 88.99008178710938, 89.4765738078526, 87.70423425946916, 88.08344609396798, 82.87572956085205, 75.82166821616036, 66.11708450317383, 65.5464220046997, 63.36429854801723, 63.47087696620396, 77.38423470088414, 87.8366391318185, 85.71841130937848, 86.33006817953927, 79.86456789289201, 78.51360184805733, 77.02691664014543, 76.81434345245361, 69.37196813310895, 68.06253841945103, 61.91565472739083, 59.24809537615095, 60.39436749049595, 59.656010219029014, 58.11321483339582, 58.81723758152553, 59.25072179521833, 64.11729567391532, 69.33436448233468, 69.51003578730992, 74.02455139160156, 72.90225056239537, 66.09315490722656, 62.27201393672398, 68.08303560529436, 78.60850034441266, 78.25854737418038, 77.28668894086564, 81.11049801962716, 77.91218662261963, 76.5869289125715, 76.13105065482003, 31.390293666294642, 63.795788628714426, 69.59358787536621, 69.26584829602922, 72.12055737631661, 74.66973331996373, 76.90821361541748, 73.24619334084647, 72.86359078543526, 71.14532906668526, 69.37957641056606, 72.10160269056047, 70.55724048614502, 61.39304597037179, 60.53583976200649, 67.12402439117432, 61.695327350071494, 62.8565102985927, 57.90341050284249, 64.279404095241, 76.1531320299421, 78.45217282431466, 80.93297154562813, 76.3028587613787, 69.58082403455461, 70.8090432030814, 70.31217752184186, 69.50176048278809, 68.45022705623082, 67.13315432412284, 66.70640986306327, 62.961018153599326, 65.43664741516113, 65.63462938581193, 64.76757063184465, 63.12300845554897, 71.6962308883667, 81.77173723493303, 85.92547457558769, 76.85392039162772, 79.1087428501674, 63.10398428780692, 14.284922208104815, 0.8124186087931905, 1.3915673004729407, 3.9332128082002913, 2.614851402384894, 0.36543741077184677, 1.6531247454030173, 1.060205104095595, 0.37165911548904007, 0.6487852750079972, 0.2811053602823189, 11.629168714795794, 48.31121390206473, 61.2292491367885, 57.93627200807844, 47.24378994532994, 27.954845462526592, 33.02223791394915, 63.88063308170864, 76.61276926313127, 79.65088299342564, 102.8714986528669, 33.41645090920584, 0.8566599605338914, 0.23184944476400102, 0.21717611141502857, 0.0972081074225051, 0.2521472227360521, 0.19775178443108285, 0.190104979755623, 0.15685684526605265, 0.11989093598510538, 0.0917297446035913, 0.1120099960161107, 0.15947011432477406, 0.11839986885232584, 0.15901922780488217, 0.1827663385442325, 0.09060022807014839, 0.10064380163592951, 0.12048244210226194, 0.1354302835783788, 0.11567975766956806, 0.11423738220972673, 0.14055599139205047, 0.17596615558224066], [0.03142143000981637, 0.07045042501496417, 0.01416734978556633, 0.08876086212694645, 0.05684478687388556, 0.05554750594975693, 0.02280467139956142, 0.09873810889465467, 0.04904635337048343, 0.12651666759380273, 0.013632574284981405, 0.10534566933555262, 0.03792838067082422, 0.029293130284973552, 0.034655025960611444, 0.061980679498187134, 0.013537491172818201, 0.13400498005960668, 0.1083218257075974, 1.9882565566471644, 75.87680912017822, 86.08298328944615, 82.4935438973563, 71.25985622406006, 37.42008978979928, 36.55665104729788, 47.74894482748849, 58.508056640625, 47.681654998234336, 17.842475448335918, 0.10202443719442401, 0.047565528723810396, 0.25578921873654636, 0.33250368226851734, 0.40423566315855297, 0.4325488395988941, 0.9081316728677068, 2.074081574167524, 1.1254325125898634, 20.55626811300005, 100.44084508078438, 84.21577303750175, 89.49275616237095, 78.59574345179966, 75.2582596370152, 68.37602724347795, 72.60849462236676, 71.63892214638847, 77.61350440979004, 71.44740894862584, 71.39361599513462, 62.59407683781215, 58.88601085117885, 55.28134100777762, 56.86636407034737, 53.58818313053676, 61.515952655247276, 74.41325446537563, 77.5984685080392, 79.27342905317033, 73.45027582986015, 72.0284173148019, 68.98351519448417, 68.42778437478202, 66.68342522212437, 63.31329182216099, 57.665247099740164, 54.61431046894619, 53.4406589780535, 49.99740621021816, 52.03266906738281, 49.10116849626814, 53.54636887141636, 56.79511376789638, 56.57364688600813, 63.03357819148472, 65.48327677590507, 62.1330360685076, 54.70285136359078, 50.421600682394846, 56.196491718292236, 65.72398321969169, 71.82677364349365, 66.37245164598737, 64.47591999598912, 69.73603984287807, 64.06724779946464, 62.03887408120291, 27.263883590698242, 53.009592737470356, 64.10091876983643, 64.76552091326032, 62.514429637363975, 66.01719720023019, 71.79901559012276, 68.07518414088658, 69.45573561532157, 63.59739671434675, 59.45178181784493, 66.4571223940168, 65.93609782627651, 64.75709274836949, 57.33282790865217, 53.401280062539236, 57.03448963165283, 51.22228329522269, 54.66570281982422, 50.87939664295742, 63.76507759094238, 66.56628554207938, 67.72159031459263, 63.90893309456961, 57.75049802235195, 57.092486245291575, 62.039228439331055, 61.856157302856445, 60.54511560712542, 60.43561199733189, 58.578469685145784, 54.913308824811665, 55.16923877171108, 57.20041608810425, 55.83997964859009, 53.78388261795044, 66.06138079507011, 73.09980174473354, 74.63190037863595, 69.68050983973912, 71.93714577811105, 71.61861951010567, 51.87353447505406, 5.1761912533215115, 0.4238150625356606, 1.1928757450410297, 2.2740791738033295, 0.5599983707070351, 0.35886718332767487, 0.26546648517251015, 0.3738696468727929, 0.04468870309314557, 0.019396488388468112, 0.05580108466425112, 16.168956654412405, 33.74740055629185, 50.121897084372385, 45.63327046803066, 33.40094600405012, 30.420151438031876, 37.720571586063926, 51.235022817339214, 61.627832548958914, 73.32996082305908, 61.39584609440395, 0.7016818565981728, 0.12889897690287658, 0.036092767026275396, 0.12978987981166157, 0.045020605104842355, 0.06879910148148026, 0.00833620473609439, 0.08885259327611753, 0.09811234354440655, 0.038169769503708394, 0.02914884659860815, 0.01418049300887755, 0.06461699160614184, 0.023179344866158705, 0.08392041043511458, 0.04121802361415965, 0.03786036092787981, 0.059179795506809435, 0.03957481875217386, 0.05819878314754792, 0.03644941181742719, 0.037869494009230814, 0.022477179865485857, 0.05477665963449648, 0.03160774554791195, 0.022704053137983595, 0.053817397715257745, 0.02677306649275124, 0.10886380555374281, 0.07146307067679507, 0.07359387419585671, 0.048751177066670995, 0.026074755570984313, 0.030952518207154105, 0.038959061793450794, 0.01110350209221776, 0.08209192819361176, 0.04225558168920023, 0.05304969980248383, 0.0511597694296922, 0.15524573171777384, 0.17851314534034046, 3.909980203424181, 95.87965842655727, 93.75282178606305, 95.19469806126186, 81.01171548025948, 48.44953169141497, 31.86338608605521, 45.273423263004844, 65.94886861528668, 53.651262351444785, 20.619896241596766, 0.17764158067958696, 0.1931676154157945, 0.6617110414164407, 0.4236330794436591, 0.9142515701907021, 2.0895923418658118, 1.9631802908011844, 1.1956206091812678, 0.5314008338110787, 28.00532759938921, 103.43355928148542, 87.89728995731899, 94.40228380475725, 82.26578194754464, 79.92801884242466, 70.72877761295864, 75.73996434892926, 73.63741861070905, 79.41496385846818, 75.04540852137974, 77.01786313738141, 66.76892280578613, 62.64008780888149, 57.3873747416905, 60.56470257895333, 56.79350873402187, 64.56695529392788, 77.24309594290597, 80.88167299543107, 81.85852023533413, 78.58083261762346, 76.09359291621617, 72.34012739998954, 71.79140731266567, 69.53173501150948, 66.07205322810582, 62.07352474757603, 58.2430453981672, 54.670406750270296, 51.90368965693882, 55.89459943771362, 53.0144738469805, 57.255379813058035, 59.743856293814524, 59.11636447906494, 66.44681821550641, 66.61154610770089, 62.716392925807405, 58.77550670078823, 52.38317789350237, 58.63250582558768, 67.48214149475098, 74.82802023206438, 69.07908071790422, 66.88711861201695, 69.74667753492082, 65.78821236746651, 67.95052650996617, 30.720198971884592, 57.124788420540945, 68.11325332096645, 67.82552146911621, 64.7693841116769, 65.89564541407994, 71.57403291974748, 69.57765565599713, 71.95901870727539, 67.39910357339042, 62.04896286555699, 72.17615686144147, 68.67413970402309, 65.80355398995536, 61.709557260785786, 57.034663336617605, 59.01059900011335, 53.34597934995379, 56.868722983769004, 55.0828344481332, 67.6905596596854, 69.6052052634103, 72.52130167824882, 66.7498777934483, 62.759013175964355, 60.63004343850272, 63.831425939287456, 63.52719906398228, 62.93719278063093, 63.52939469473702, 59.77181584494454, 58.46110071454729, 57.581347601754324, 60.32690743037632, 58.872531345912385, 58.4906861441476, 69.93440396445138, 77.00597476959229, 77.4528203691755, 71.71178095681327, 76.24579320635114, 76.02794633592877, 63.00947489057268, 7.843432290213449, 0.41889828922493116, 0.6667633045996938, 1.5209415640149797, 0.49555355736187523, 0.6147262368883405, 0.5330826778497014, 1.0075339589800154, 0.3568684091525418, 0.06554271693208388, 0.0883254733468805, 18.04313768659319, 38.780870165143696, 45.67936481748308, 30.710259573800222, 27.412503821509226, 40.476466860089985, 45.11476462227957, 58.781746183122905, 72.47507531302315, 81.28037452697754, 79.12838540758405, 1.6082558844770705, 0.11694941882576261, 0.029896700754761696, 0.04810306755825877, 0.03600834709193025, 0.05542873518009271, 0.015167805565787213, 0.011008273095025547, 0.00811519570249532, 0.045555996375956705, 0.03221553311284099, 0.013595535602819706, 0.03495716742639031, 0.05596024862357548, 0.07427873316087893, 0.0164421180795346, 0.054263425924416096, 0.08103470278105565, 0.04309543162318213, 0.01477092195169202, 0.03069323640582817, 0.0381876896135509, 0.012913197395391762, 0.1738151724317244, 0.22459901310503483, 0.06433425284922123, 0.1516705442752157, 0.08669405803084373, 0.15647519645946367, 0.11681980506650039, 0.16478218856666768, 0.08055840512471539, 0.19984088518789836, 0.16159456675606115, 0.17262844182550907, 0.1321321962667363, 0.1725109059895788, 0.11637126627777304, 0.19727334938943386, 0.10934198953743492, 0.3859839125403336, 0.34109694830008913, 4.834418049880436, 112.95225088936942, 106.15689877101353, 108.41126264844621, 91.7014912196568, 54.44933244160244, 53.11173473085676, 63.862963812691824, 75.20774623325893, 68.92203058515275, 28.168599843978882, 0.2460061822618757, 0.41416898156915394, 1.005986139178276, 1.5949196858065469, 2.0415744270597185, 3.640095885310854, 2.8960819116660526, 10.846001642090933, 4.111705081803458, 28.182680368423462, 108.38490118299211, 91.31847872052873, 100.8298121861049, 86.44437299455915, 84.70025702885219, 75.06830978393555, 79.60341984885079, 78.74945150102887, 83.67618983132499, 76.85726942334855, 81.58708885737828, 70.01680265154157, 67.18769073486328, 61.516126360212056, 64.20327268327985, 59.03096417018345, 68.62951142447335, 81.13677610669816, 85.82082080841064, 83.37866796766008, 81.98629065922329, 79.58369391305106, 77.21162755148751, 76.95779596056256, 73.78488717760358, 69.68621431078229, 65.76682581220354, 61.48161465781075, 58.42018277304513, 56.583454268319265, 60.13142681121826, 55.6446727343968, 60.04796504974365, 63.72342314038958, 62.23567485809326, 70.67186491830009, 69.81399863106864, 69.47362027849469, 62.43606785365513, 53.13385084697178, 63.13407693590437, 71.7048397064209, 78.28645828792027, 71.0518410546439, 70.58115618569511, 70.6226647240775, 70.4512665612357, 71.55705847058977, 35.716120515550884, 58.23012522288731, 70.04784025464738, 72.546370778765, 69.39269460950578, 72.89471176692417, 75.81083597455705, 74.56826182774135, 74.2796128136771, 70.5600197655814, 65.79174900054932, 76.32586424691337, 72.45630822862897, 68.45416668483189, 62.799326624189106, 59.243176051548545, 62.268692697797505, 56.961808000292095, 61.01706504821777, 57.98521164485386, 72.98287051064628, 73.83510875701904, 75.96129921504429, 72.10168606894356, 67.13981069837297, 66.1600591114589, 68.04153401511056, 68.65576866694859, 67.3573796408517, 68.51810400826591, 65.29373686654228, 61.54362038203648, 61.3786631992885, 64.96633774893624, 61.859089442661826, 60.79904447283064, 73.38401085989815, 80.73498262677873, 79.83066068376813, 77.49451650891984, 81.38363865443638, 81.07695211683, 64.37030042920793, 9.06697792666299, 0.9354175201484135, 4.14124013696398, 5.391004800796509, 1.158787339925766, 1.1569612664835793, 2.556098086493356, 1.696191743016243, 0.3378266266414097, 0.2762477823666164, 0.2119492068886757, 28.108180046081543, 48.78091907501221, 64.28119673047746, 62.41727992466518, 47.065947328295024, 44.34170109885079, 54.18691635131836, 69.03194413866315, 80.5395575932094, 91.20288154057094, 82.94067437308175, 1.768260412982532, 0.2642482434000288, 0.12769562218870434, 0.15835028727139744, 0.0934121518262795, 0.15515039754765375, 0.08919557915734393, 0.15182568452187947, 0.1875305093292679, 0.09484408463218383, 0.07838798194591488, 0.09508065586643559, 0.13824876876814024, 0.07865427979933363, 0.1431172982390438, 0.12514414052878106, 0.10351926341120686, 0.19456701246755465, 0.12196284266454832, 0.11628606942083154, 0.09894171689770051, 0.10870764071920089, 0.11275042021381003], [0.03274413224841867, 0.013953511170776827, 0.04420707554423383, 0.03449757190953408, 0.11937927986894335, 0.019448759333629693, 0.04065431368404201, 0.04535259871876665, 0.05023471924609371, 0.043620865392897806, 0.029138549829700162, 0.02615090585978968, 0.034272905572184494, 0.01010392077400216, 0.016218841042635695, 0.04355876586799111, 0.031209611733044897, 0.3754146711102554, 0.25577583802597864, 15.165039232798986, 87.880523954119, 74.37129429408482, 78.95306151253837, 52.34203066144671, 44.66914190564837, 54.88296604156494, 56.65795980181013, 41.90745530809675, 42.251262596675325, 1.0494753484215056, 0.10530432619686637, 0.012980732833966613, 0.42254666345460073, 0.21673796778278692, 0.02910275032211627, 0.32458365868244854, 2.4193998788084303, 1.6765774126563753, 7.339053000722613, 86.46571786063058, 87.31613567897251, 86.02997548239571, 78.29030758993966, 76.12271281651088, 68.09857872554234, 68.18274920327323, 62.92815317426409, 61.202700069972444, 67.79784679412842, 66.64541162763322, 65.00997938428605, 60.50487164088658, 55.83588368552071, 55.25779356275286, 55.41639314379011, 55.59378412791661, 55.807392597198486, 63.8536045891898, 74.69378798348563, 73.88457298278809, 72.59395899091447, 71.86960233960832, 71.1299388068063, 68.15777042933873, 66.24697412763322, 62.56871591295515, 58.11595589773995, 57.19884579522269, 51.4284884589059, 48.993624278477256, 49.11836528778076, 51.32802445547921, 53.02719947269985, 56.100964409964426, 54.240799631391255, 57.699696268354145, 57.31568670272827, 55.987152917044504, 53.069882256644114, 52.54987212589809, 61.86730221339634, 65.01338400159563, 68.38709572383335, 70.27858992985317, 65.40487330300468, 65.13162149701799, 56.85839448656355, 56.225184304373606, 32.69511672428676, 57.39430209568569, 61.163477488926475, 62.09336185455322, 61.48628384726388, 57.810707637241904, 61.924485887799946, 60.78241048540388, 69.79400866372245, 64.99889700753349, 61.93191351209368, 61.13576807294573, 68.99461841583252, 64.9493077141898, 68.96658243451799, 55.55699341637747, 54.74776104518345, 51.84054790224348, 52.57308605739048, 51.57380655833653, 51.99649327141898, 57.0305951663426, 61.660496030535015, 56.31807477133614, 50.99105766841343, 52.90673507962908, 53.01963288443429, 57.669888496398926, 61.27211257389614, 59.42629582541329, 56.395297050476074, 52.95979847226824, 51.92625045776367, 54.9485570362636, 52.478931018284385, 55.40849304199219, 64.05149623325893, 70.73525333404541, 68.88252312796456, 65.10027122497559, 68.05147688729423, 65.36021723066057, 74.06636565072196, 43.26969133104597, 2.9104859616075243, 0.7423565025840486, 4.014258333614894, 1.5062998639685767, 0.0715869576004999, 0.7741995538984026, 0.14493631491703646, 0.265590955636331, 0.1596903939332281, 0.1306715817855937, 2.1701273918151855, 24.99594988141741, 38.45865092958723, 64.49928678785051, 45.34379809243338, 19.10971048900059, 25.67084925515311, 53.32139662333897, 61.214699608939036, 60.296467372349326, 84.28164890834263, 14.470996703420367, 0.6441505008510181, 0.0917158414210592, 0.19858791599316256, 0.038017584277050834, 0.03997017057346446, 0.02366070100106299, 0.04951809127149837, 0.06430917419493198, 0.022256937576457858, 0.032521450625998635, 0.06412238028964826, 0.09123112314513751, 0.028870107805622474, 0.020666185167751143, 0.025125161079423766, 0.031015506612935236, 0.05423986718856862, 0.050718857374574454, 0.06891204363533429, 0.08993651225630726, 0.03970755037984677, 0.12085510710520403, 0.052798099017568996, 0.03261763975024223, 0.04548469252352204, 0.014764245167108518, 0.11978109473628656, 0.06079306001109736, 0.03056757850572467, 0.08594963047653437, 0.09012340794184379, 0.07784121842788798, 0.02265554466950042, 0.03152808553672262, 0.05771595798432827, 0.015072759773050035, 0.006999641299314264, 0.11840893408017499, 0.06485042122325727, 0.2893087129507746, 0.6017509645649365, 25.020965133394512, 107.57953548431396, 82.61073916299003, 90.06120913369315, 63.77194241115025, 64.33463532584054, 45.95477751323155, 49.498240675245015, 48.87328495298113, 45.39765010561262, 1.0870554404599326, 0.0789776085210698, 0.4998445585370064, 0.48739610080208096, 0.2617942807929856, 0.23339088633656502, 1.7554192734616143, 0.9477735885551998, 1.2212055048772266, 11.879848429134913, 92.36475236075265, 90.9717149734497, 90.39694608960832, 81.21083695547921, 79.5000445502145, 71.89767306191581, 72.50681468418666, 66.32940755571637, 64.85011523110526, 68.93113967350551, 68.40580027444022, 69.88989380427769, 62.82190132141113, 61.18473897661482, 59.16616916656494, 57.72072499138968, 59.195608683994834, 58.55534608023507, 68.48625346592495, 76.8547750200544, 76.82179192134312, 75.38741275242397, 75.65579387119838, 72.93797125135148, 72.19295065743583, 70.31955650874546, 66.00230721064976, 63.16312735421317, 59.7062873840332, 53.345360960279194, 53.21262257439749, 52.477447577885215, 53.17791632243565, 55.6741053036281, 58.45234598432268, 57.7931877544948, 60.209489822387695, 60.532921518598286, 58.657269205365864, 56.585830552237375, 54.699252196720664, 63.682602473667686, 69.49539593287876, 71.43569428580147, 71.64990030016217, 68.53471715109688, 67.80322469983781, 61.90250873565674, 60.088389669145855, 34.30264152799334, 58.980151993887766, 66.28525870186942, 66.44287163870675, 66.42650863102504, 64.68400464739118, 63.424678393772666, 64.56065327780587, 72.47595078604562, 67.83207362038749, 64.63700703212193, 64.43570382254464, 72.73313835689, 67.96194240025112, 70.93147046225411, 59.29991504124233, 56.20046261378697, 55.31866673060826, 55.61765119007656, 52.87593371527535, 54.09016963413784, 61.48667989458357, 63.68645872388567, 57.39042500087193, 53.796535287584575, 55.34550067356655, 56.81619807652065, 61.983781814575195, 63.89136804853167, 63.41986329214913, 60.63062708718436, 54.89527824946812, 55.3390770639692, 58.4051399230957, 56.89131505148751, 58.63905102866036, 67.75149536132812, 73.3380902154105, 72.87809862409318, 70.17105266026088, 72.76988737923759, 69.77831268310547, 77.55056067875454, 55.86968319756644, 4.115962590490069, 0.5384055950811931, 1.7873201902423586, 2.241021816219602, 0.26062046949352535, 1.251929136259215, 0.5393143434609685, 0.5263667010835239, 0.33887336190257755, 0.3062923901847431, 1.452659119452749, 27.791107688631328, 39.23574788229806, 44.04270969118391, 30.036708150591167, 24.400709867477417, 36.711693150656565, 60.17981406620571, 66.16772297450474, 67.0199612208775, 93.6182073865618, 26.32069342476981, 0.6309789962002209, 0.07835512049496174, 0.16066456665950163, 0.027550762619024942, 0.04979129321873188, 0.011752352900137859, 0.01574041448267443, 0.06308892395879541, 0.056150126470518966, 0.05829324200749397, 0.026176271195124303, 0.05303406974832926, 0.011159293785957354, 0.0190361862935658, 0.029389146382787397, 0.0470943709702364, 0.034190894437155554, 0.04682027335677828, 0.04331820824050477, 0.0419377592791404, 0.031239477451890707, 0.07919910949255739, 0.10438256351543324, 0.12403150594660214, 0.12692243153495447, 0.2110087980649301, 0.17956575671476976, 0.1584340049219983, 0.14646767345922335, 0.19589790462383203, 0.16569916079086916, 0.17699132700051579, 0.08349135917212282, 0.19840939342975616, 0.14247224213821547, 0.14098593832126685, 0.14266314118036202, 0.2596105651131698, 0.14126667539988244, 0.4860490730830601, 0.8987194150686264, 30.04769672666277, 125.10241290501186, 93.68644564492362, 100.90724985940116, 71.46673883710588, 64.26845373426164, 77.38175419398716, 84.89402144295829, 59.26629270826067, 66.96114471980503, 1.8460614553519656, 0.22126215430242674, 0.4302109336214406, 1.9051283087049211, 1.1398536073310035, 1.443915571485247, 3.6095728831631795, 7.613713553973606, 9.407225131988525, 10.796529599598475, 96.45576136452812, 94.00409643990653, 93.74855559212821, 84.3908051082066, 85.8967924118042, 75.49477631705147, 74.98297895703996, 71.46295901707241, 68.50120598929269, 74.64695712498256, 72.1238716670445, 72.77695369720459, 66.61993258340019, 64.15304415566581, 63.40822505950928, 61.049068450927734, 62.37873131888253, 62.78763280596052, 70.30678571973527, 80.56755188533238, 80.03784901755196, 80.18676280975342, 81.1483587537493, 74.54982825687954, 74.03511960165841, 74.64535903930664, 69.85940510886056, 66.14355019160679, 64.29372433253697, 57.30957228796822, 58.886622292654856, 55.88266243253435, 58.06905555725098, 58.91877160753523, 62.34621374947684, 62.08912345341274, 64.81866768428257, 63.87795107705252, 62.50712013244629, 59.35085923331124, 58.76718275887625, 66.53592191423688, 72.82887758527482, 74.79762881142753, 75.00018964494977, 71.8969782420567, 70.74450833456856, 62.171869550432476, 61.73489039284842, 38.52247013364519, 61.95930331093924, 66.60886410304478, 69.10332993098667, 69.07882363455636, 66.0234158379691, 65.12894644056047, 65.6375754220145, 75.76729161398751, 72.06153242928642, 67.90978227342877, 67.99812861851284, 76.33903108324323, 70.70051234109062, 74.64625535692487, 62.00826031821114, 59.034611974443706, 58.7993529183524, 58.869488034929546, 56.97484629494803, 57.31825058800833, 64.28565747397286, 69.45071901593889, 60.78104863848005, 56.7444475037711, 59.61855942862374, 59.395188740321565, 67.03462191990444, 68.88774122510637, 67.33991186959403, 64.93782234191895, 59.05258696419852, 58.15504993711199, 62.96729237692696, 60.69579424176897, 60.94816671098982, 70.44540922982353, 77.96404797690255, 76.55240331377301, 72.74339389801025, 76.3907048361642, 72.02997371128627, 82.15863377707345, 56.73218393325806, 4.6990649700164795, 2.249643010752542, 9.900205901690892, 5.450035827500479, 0.34697431006601875, 1.5652568489313126, 1.7326751053333282, 1.292764242206301, 0.538315757044724, 0.3546562221433435, 3.938158622809819, 41.792361872536794, 57.27448041098458, 88.01588875906808, 64.04607663835797, 29.33166401726859, 41.32795817511422, 72.18614837101528, 77.77785015106201, 77.32958017076764, 108.18825326647077, 26.895179169518606, 0.7599857108933585, 0.25618143911872593, 0.29541284111993654, 0.08828883245587349, 0.14715405234268733, 0.09295533491032464, 0.10052690362291676, 0.16722144053450652, 0.14667089469730854, 0.16666980513504573, 0.19339527748525143, 0.21224696162555898, 0.22382401754813536, 0.1315340676477977, 0.10223248960184199, 0.1440906295818942, 0.13523354913507188, 0.14565497849668774, 0.10087377072444983, 0.10411471860217196, 0.15414223021694592, 0.20524313673377037], [0.03248771386487143, 0.09663180048976626, 0.04704772847305451, 0.02736816884550665, 0.016818611716319407, 0.020422333252749274, 0.02498615300282836, 0.19329306297004223, 0.03343614636521254, 0.059854320383497646, 0.05125526984089187, 0.1336172515792506, 0.06609085109084845, 0.08015882942293372, 0.05342404757227216, 0.05798395896064384, 0.01138727052602917, 0.32531674791659626, 0.10267250599073512, 39.89457607269287, 87.86006150926862, 76.44883346557617, 77.04366179874965, 45.51036378315517, 26.13787416049412, 48.83245733806065, 48.30182688576834, 46.10825974600655, 17.24713294846671, 0.05230807459780148, 0.3111713012414319, 0.15714598260819912, 0.2490431150155408, 0.1830766461789608, 0.17869588839156286, 2.069618442228862, 1.0789787024259567, 2.5157253614493778, 66.0847475869315, 92.11979361942836, 83.50060885293144, 83.08240372794015, 77.51380470820835, 69.87872110094342, 67.89211995261056, 64.13217176709855, 62.543903895786826, 59.0175541469029, 56.5247802053179, 57.64486108507429, 58.55884797232491, 57.50144679205758, 56.72466598238264, 56.35810334341866, 54.40398849759783, 55.606311729976106, 57.75690426145281, 55.29086351394653, 58.59327629634312, 63.70924186706543, 65.39392294202531, 64.51255089896065, 65.48559052603585, 63.430535725184846, 64.95716612679618, 62.1759272984096, 57.84014368057251, 54.469815731048584, 53.64934812273298, 49.37206138883318, 52.702298232487266, 50.457998820713584, 49.37595238004412, 57.09320885794503, 61.83071994781494, 66.60885715484619, 66.58552510397774, 62.231165477207725, 50.43915530613491, 52.68804747717721, 67.69852924346924, 68.70213399614606, 70.12310314178467, 67.81367479051862, 68.96244825635637, 68.1636277607509, 67.70433793749127, 62.451986176627024, 34.53838695798601, 57.15341847283499, 61.63778236934117, 65.5077691759382, 67.0635542188372, 67.4065728868757, 61.34685434613909, 62.42813995906285, 67.88127381461007, 65.4160737991333, 60.7405058997018, 63.68499265398298, 65.57357556479317, 70.5260569708688, 72.67687879289899, 63.856953620910645, 52.61323969704764, 51.97290761130196, 49.05036326817104, 50.38275677817208, 50.143561567579, 49.07937199728829, 48.89186791011265, 51.33068561553955, 49.88929224014282, 51.7689710344587, 49.29263653073992, 52.76289347239903, 54.5348995072501, 56.28837469645909, 54.130496978759766, 50.96649578639439, 51.16195208685738, 53.73789249147688, 51.563606602805, 56.47192873273577, 63.35721138545445, 68.94119371686662, 63.190670013427734, 66.67590032305036, 60.363774572099956, 68.90466008867536, 67.13413402012416, 74.54776464189801, 29.342715127127512, 1.3086001638855254, 1.0031164245946067, 0.651255305324282, 0.3706014965261732, 0.14046084721173557, 1.0834607247795378, 0.19311430970472948, 0.17576399285878452, 0.1884986838059766, 0.1824281702616385, 9.809392946107046, 26.8875344140189, 39.54278877803257, 48.89647456577846, 33.495121887751985, 20.96734091213771, 26.561974831989833, 54.80664702824184, 60.74796826498849, 69.35755062103271, 51.81406831741333, 0.21087005122431687, 0.14143645843224867, 0.021749763184094002, 0.044348275288939476, 0.023321365638236915, 0.09818783056523119, 0.04276155507458108, 0.0467027884109744, 0.01714593531297786, 0.11956233504627432, 0.0923190794086882, 0.03146775698821459, 0.027072483640430228, 0.0394879526990865, 0.07582711614668369, 0.083579819782504, 0.03942320688760706, 0.050449845381081104, 0.04073039103033287, 0.02573920982623739, 0.12579651123711041, 0.1103833643719554, 0.021997321596635238, 0.09629400540143251, 0.03569619384195123, 0.04795435643089669, 0.06043108193469899, 0.056927384941705635, 0.026972245358462845, 0.022422447534544126, 0.045885995096926174, 0.08461949149412767, 0.06896929842020784, 0.10518241381006581, 0.018185914061697464, 0.07524010193135057, 0.0611327142853822, 0.060461792429643016, 0.020331777665498, 0.25190381865416256, 0.046884330455213785, 54.80766493933541, 102.4936625616891, 87.27298041752407, 86.89605454036167, 57.66817576544625, 36.68075629643032, 53.30455766405378, 57.934055532727925, 52.399054527282715, 20.077056067330496, 0.0795451080692666, 0.22681936967585767, 0.181739335081407, 0.27862441912293434, 0.5500747146350997, 0.4309485826109137, 2.0728302470275333, 0.4639418050646782, 3.837851822376251, 74.07735075269426, 94.88288375309536, 89.2088041305542, 85.16783605303083, 81.04298932211739, 73.62150028773716, 72.39246123177665, 67.75517095838273, 66.06673090798515, 62.65032945360456, 60.31820828574044, 60.34101922171456, 62.34298283713204, 60.937007904052734, 61.383235113961355, 59.488503047398154, 56.75485590526036, 58.35150677817208, 58.553636823381694, 57.854245049612864, 61.933393478393555, 66.77521092551095, 68.3666958127703, 66.66563088553292, 67.31623240879604, 67.47199017660958, 66.29514598846436, 64.13946042742047, 61.70137228284563, 59.01503195081438, 56.56430503300258, 52.67823314666748, 54.249630791800364, 53.24265268870762, 53.33926739011492, 60.97812039511544, 65.98531886509487, 70.21349225725446, 71.10063825334821, 65.64202226911272, 54.105010986328125, 56.30938604899815, 70.46815763201032, 72.5453632899693, 73.11743627275739, 71.17767987932477, 71.92974594661167, 71.21549197605678, 71.06104046957833, 64.47127859933036, 38.3323153087071, 61.11470808301653, 65.15754522596086, 67.90666253226144, 69.04482609885079, 69.80928775242397, 64.25234086172921, 66.42447280883789, 70.39740412575858, 68.3705381665911, 62.89677510942732, 67.12335041591099, 70.28092452457973, 71.91507829938615, 75.0227643421718, 68.03092411586216, 55.4689736366272, 54.47623586654663, 52.188551902770996, 52.766061850956504, 53.36381190163748, 52.08600691386631, 51.72137587411063, 53.290359020233154, 52.59277030399868, 55.24202115195138, 52.06889002663748, 56.14829901286534, 56.548098359789165, 60.91070202418736, 56.46058579853603, 56.34297364098685, 53.55422380992344, 55.58489738191877, 54.06227956499372, 60.556962285723, 65.73828956059047, 71.85911055973598, 66.32810824257987, 69.95932715279716, 64.982666015625, 73.8608865737915, 72.58959552219936, 79.42922156197685, 38.860635484967915, 1.1612869543688638, 0.28742051284228054, 0.42098489297287806, 1.4052882556404387, 0.9955046730382102, 0.9265457562037877, 0.5990368244903428, 0.6149107984134129, 0.24709514954260417, 0.24193491786718369, 9.740233182907104, 31.123361246926443, 39.546777044023784, 38.95158393042428, 25.809097562517437, 32.382611070360454, 35.89724963051932, 60.78622504643032, 70.4599448612758, 73.64693764277867, 72.65045479365757, 1.7744768794093813, 0.39624645614198273, 0.08842694147356919, 0.04748712060973048, 0.01904088175589485, 0.12660110449152334, 0.051478104133691104, 0.07249634380319289, 0.0462646651347833, 0.06630637416882174, 0.01361337852930384, 0.01687719812616706, 0.0479859320579895, 0.035269727797380516, 0.053449289074965885, 0.05839212491576161, 0.06720709547932659, 0.012719714831161712, 0.0019023127887131913, 0.02051045629195869, 0.08322134294680186, 0.08552256053579704, 0.12225036509335041, 0.22796589029686792, 0.1522342711687088, 0.07586434736315693, 0.16995077979351791, 0.10418325063905545, 0.12651107646524906, 0.2602727338671684, 0.1176463964262179, 0.17978199225451263, 0.1404812846864973, 0.2321345651788371, 0.1800185702741146, 0.1252628977277449, 0.18685449846088886, 0.1998892104519265, 0.08607837571097271, 0.4906698965600559, 0.16057934266115936, 62.9470522744315, 115.2485818862915, 99.0735924584525, 100.34074238368443, 65.03189400264195, 36.4467305455889, 66.32350853511265, 65.83186789921352, 67.92325483049665, 28.17209131377084, 0.2976055677448, 0.6582622921892575, 0.8280318081378937, 1.122569854770388, 1.0720409261328834, 1.2521000185183115, 6.241991068635668, 9.040360246385847, 4.1703561288969855, 77.73497976575578, 98.8128821509225, 93.25002234322685, 88.40694727216447, 86.91649614061627, 76.53877789633614, 78.4250887462071, 71.11004611424038, 70.66880771092006, 65.80748667035783, 64.9433183670044, 64.56466933659145, 65.51123632703508, 65.00551169259208, 65.52965600149972, 62.0474134172712, 60.0311712537493, 61.685176031930105, 64.75611305236816, 60.14965888432094, 64.938857623509, 69.40446485791887, 72.91475731985909, 69.43964358738491, 71.48046152932304, 70.98122651236397, 70.77142565590995, 68.00664710998535, 64.63707651410783, 62.380141803196494, 60.577688762119834, 55.948965617588584, 59.38781670161656, 57.42782367978777, 56.34766367503575, 65.00897189549038, 69.07034683227539, 74.0195208958217, 73.398282459804, 68.11914539337158, 57.74501241956438, 60.11770411900112, 73.96871566772461, 74.50016253335136, 75.85759040287563, 73.73469339098249, 76.83859266553605, 75.38152068001884, 74.41915348597935, 67.4769720349993, 43.087481771196636, 65.21541677202497, 70.40660354069301, 71.43365846361432, 72.31342547280448, 72.7415109361921, 64.63120528629848, 68.13028335571289, 75.59954820360456, 72.1501567023141, 67.81838566916329, 69.08887072971889, 72.89171014513288, 74.31308923448834, 79.23340048108781, 71.25670869009835, 57.5201860836574, 57.7027256829398, 56.47859900338309, 55.90553937639509, 56.112616539001465, 54.15129293714251, 54.714354106358115, 56.77568313053676, 56.84735379900251, 58.139267104012625, 54.98048748288836, 59.07263251713344, 60.28444004058838, 62.67396027701241, 60.88758536747524, 59.886648723057334, 57.20500189917428, 60.05648354121617, 56.90179640906197, 63.592039653233115, 69.29191098894391, 75.18080111912319, 70.10646915435791, 72.52586664472307, 68.16813714163644, 78.28937653132847, 75.91468375069755, 83.49013096945626, 39.84806135722569, 1.3786815404891968, 2.732604043824332, 3.993093252182007, 1.2252826860972812, 0.9509544521570206, 2.327888412134988, 2.6036934639726366, 0.3856054257069315, 0.4569435034479414, 0.4494063364607947, 16.18161106109619, 42.33970621653965, 57.6918864931379, 69.18366500309536, 47.79917682920183, 34.996585914066856, 42.5975330216544, 72.0520828792027, 80.32063375200543, 87.20017719268799, 82.96153286525181, 1.4801376163959503, 0.38773176446557045, 0.14690755414111273, 0.11701215617358685, 0.10770313069224358, 0.23754908463784627, 0.14941749588719436, 0.2676266421164785, 0.1350093340235097, 0.2551176319164889, 0.24269159297857965, 0.05854132119566202, 0.12139773155961718, 0.1563238152968032, 0.34444608858653475, 0.09376028100294725, 0.15073169608201298, 0.11726508688713823, 0.1657623052597046, 0.053838422122810564, 0.19787975613559994, 0.21423426855887684], [0.018329911067017486, 0.01858162889922304, 0.035850591092769585, 0.04644171188452414, 0.04814108248267855, 0.04570516212178128, 0.10808357170649938, 0.03176772374925869, 0.05178136857492583, 0.027770555378603082, 0.012584599849235798, 0.08507221005856991, 0.06113470917833703, 0.07754100739423718, 0.07784045846866709, 0.08166590319680316, 0.07857188529201917, 0.03782051395890968, 0.7379864656499454, 72.4625894001552, 77.41409805842808, 79.8278397151402, 51.27595118113926, 32.59347152709961, 34.74988317489624, 53.529151235307964, 67.66402448926652, 45.43044907706124, 2.173389353922435, 0.14415154845586844, 0.22923445222633226, 1.5435455739498138, 0.20168084145656653, 0.2566139373396124, 0.1930612482662712, 0.43869340845516747, 1.4141980175461089, 33.82423721040998, 92.32827431815011, 85.29264654432023, 85.97243744986397, 80.10218933650425, 73.98436995915004, 67.77806527273995, 62.851514543805806, 62.284840311322895, 59.69702543531145, 58.38603237697056, 55.830655166081016, 54.678973879132954, 56.30466474805559, 56.47032369886126, 56.417076178959434, 55.353240966796875, 55.448021343776155, 56.69371523175921, 54.59422322681972, 54.14063092640468, 53.687243597848074, 53.05772985730852, 53.41467271532331, 53.024288177490234, 54.11121225357056, 54.64847476141793, 55.87598521368844, 53.70593772615705, 54.74990109034947, 51.94893980026245, 51.05658960342407, 50.30031987598964, 49.84597717012678, 50.9931629725865, 51.81566292898995, 61.971261160714285, 67.40886579241071, 70.13375473022461, 68.607332774571, 69.76946762629917, 61.68405737195696, 51.67632375444685, 62.916737283979145, 69.25689206804547, 69.66694000789097, 65.92694010053361, 63.17919158935547, 63.16885961805071, 62.75679670061384, 67.18862874167306, 39.71607685089111, 56.86471734728132, 61.06702259608677, 65.68651853288922, 64.7912153516497, 65.6692453111921, 67.92361613682338, 69.80859988076347, 65.10996396200997, 63.607652255467, 57.350917543683735, 63.12983853476388, 66.58657428196499, 65.29869788033622, 67.09020056043352, 66.93231664385114, 53.91270221982683, 53.66542278017317, 50.67308030809675, 48.724280834198, 49.19180079868862, 48.449931212833945, 48.77194547653198, 50.40763827732631, 49.163156849997385, 50.36915567943028, 48.398285252707346, 49.58578450339181, 51.649514130183626, 51.31951986040388, 52.99591520854405, 50.20760658809117, 51.12145103727068, 51.48784691946847, 51.06790821892874, 55.65878799983433, 61.87184633527483, 62.99374416896275, 65.89219910757882, 62.24074009486607, 61.8926978792463, 64.22907134464809, 69.90001732962472, 69.22606291089738, 69.28091893877301, 23.181005716323853, 1.2621727351631438, 1.1920076544795717, 0.45641864304031643, 0.9619636556931904, 0.593210977103029, 0.23401844980461256, 1.1504398392779487, 0.23347763025334903, 0.016794574613283788, 0.1865449779267822, 18.508449860981532, 24.62870110784258, 48.15005043574742, 46.984931332724436, 16.409565823418752, 35.066217286246165, 54.74252905164446, 63.40976061139788, 58.20314189365932, 66.2855088370187, 11.451888033321925, 0.7906836665102414, 0.01510311573344682, 0.09107554185071162, 0.2129760475030967, 0.0874190116301179, 0.08902468332754714, 0.03047322142603142, 0.07138532413435833, 0.011378448722617967, 0.03779385092535189, 0.064198817259499, 0.02138833132838564, 0.07301038157727037, 0.04028439674792545, 0.04993682540953159, 0.027698649326339364, 0.07324412332049438, 0.034514762594231536, 0.007875136798247695, 0.05237026233226061, 0.04019869438239506, 0.04949041043541261, 0.07868359929748944, 0.045887643937021494, 0.007716218807867595, 0.029947370357279266, 0.052667837257363966, 0.12151883648974554, 0.027816264890134335, 0.05352554623303669, 0.040016365237534046, 0.03836280932383878, 0.13577103029404367, 0.12024019152990409, 0.06171287529702697, 0.07972143217921257, 0.039361877499946525, 0.06322351137974433, 0.09954251215926238, 2.267950645514897, 93.8565444946289, 85.51752499171666, 87.65619441441127, 59.42952673775809, 44.718317781175884, 31.001316138676234, 51.30886479786464, 73.2651480266026, 49.93896838596889, 2.522731316941125, 0.16974879348916666, 0.5272389714206968, 1.4977248098169054, 0.06971969029733113, 0.3893493376672268, 0.4323721762214388, 0.8953302683574813, 1.190963579075677, 40.34227282660348, 94.5382947921753, 90.14900657108852, 90.42007664271763, 85.02604416438511, 76.26267732892717, 70.35988385336739, 64.89170714787075, 65.06039551326207, 61.791080474853516, 62.76786518096924, 58.577545574733186, 58.006170885903494, 61.544954436165945, 60.039245060511995, 58.933696338108604, 60.24181284223284, 58.88777569362095, 59.280084882463726, 57.722583634512766, 56.397871358054026, 57.342162813459126, 56.59723949432373, 55.6349834714617, 55.39009073802403, 55.49047483716692, 58.36626475197928, 57.092597416469026, 55.881446497780935, 56.87430586133684, 54.25895527430943, 55.09613330023629, 53.07203619820731, 52.2965338570731, 54.204981667654856, 53.84488432747977, 66.12117004394531, 70.3194522857666, 72.88749953678676, 71.41496780940464, 74.19540759495327, 66.07936968122209, 54.53946099962507, 66.11283915383476, 71.19307708740234, 70.76982062203544, 70.31410912105015, 66.62911810193742, 65.07429885864258, 64.07505757468087, 72.40047250475202, 42.86335720334734, 60.81890937260219, 65.03024727957589, 66.80566487993512, 68.00954450879777, 71.05400889260429, 70.83347306932721, 72.63612760816301, 68.49237482888358, 67.6083207811628, 61.23474516187395, 66.7433534349714, 69.00142765045166, 66.53703362601144, 68.51967430114746, 68.64322022029332, 55.911184787750244, 56.70791040148054, 53.67760297230312, 52.15214681625366, 51.24402073451451, 53.319412912641255, 51.62379537309919, 52.94690261568342, 51.054696219308035, 52.41645629065377, 52.94825751440865, 51.908056599753245, 53.55558565684727, 54.041699000767295, 55.53980009896414, 53.603833947862896, 54.0996469770159, 54.25335502624512, 54.93392065593174, 59.15962396349226, 64.93892015729631, 66.10017953600202, 68.59234551021031, 64.0729592187064, 64.8702163696289, 66.21513748168945, 73.92111355917794, 74.82350390298026, 75.83735030038017, 31.16052368709019, 1.6203647490058626, 1.1997032186814716, 0.2824334704450199, 0.8936304024287632, 1.313357942870685, 0.7676278608185905, 0.7842079454234668, 0.40524752171976225, 0.04374611617199012, 0.17243913055530616, 19.895633390971593, 32.84636511121477, 44.45979963030134, 34.682968548366, 25.304753882544382, 53.5306589944022, 62.530320167541504, 71.00437791006905, 64.7952105658395, 79.34244550977434, 22.06957186971392, 0.6726043511714254, 0.08896224453513112, 0.21720694404627594, 0.05331213679164648, 0.04436780691945127, 0.07055999484977551, 0.045238737149962356, 0.0030432524591950433, 0.07163546606898308, 0.020757482054510286, 0.0729341074558241, 0.03221293432371957, 0.042650838515588214, 0.06016677897423506, 0.05590044254703181, 0.0423761845034148, 0.06635693181306124, 0.04574036791122385, 0.016467939729669263, 0.04804344129349504, 0.059272211976349354, 0.16818612734121935, 0.1319519230829818, 0.13127726928464004, 0.13961408979126386, 0.14667614655835287, 0.151281920128635, 0.25904917238014086, 0.0989647124494825, 0.12182975480599062, 0.0700879923201033, 0.08559673119868551, 0.18880553091210978, 0.24133042458977016, 0.1238091771623918, 0.12750485885356153, 0.21801058735166276, 0.1141915675252676, 0.3834997144128595, 2.755695079054151, 107.94765799386161, 98.96055916377476, 102.83659090314592, 71.65824508666992, 47.811370917728965, 50.53564493996756, 75.05309322902134, 84.04591737474713, 65.90763800484794, 4.446041541440146, 0.18799128888973168, 1.0236969888210297, 4.524136688028063, 0.6663751282862255, 0.5599972307682037, 0.9708621267761502, 4.829719764845712, 3.9550536019461493, 41.0824887411935, 98.84561511448452, 93.5923878805978, 92.85271045139858, 90.2327879496983, 81.0747286932809, 73.45749500819615, 68.70867919921875, 68.86723709106445, 65.47003350939069, 67.20738887786865, 62.71260615757534, 62.34525489807129, 64.12288897378104, 62.74274744306292, 63.31054033551897, 62.471323013305664, 63.47995826176235, 64.1822543825422, 61.02989142281668, 60.314893995012554, 58.52885259900774, 59.145803996494834, 58.79717813219343, 59.67025402614048, 60.325434412275044, 61.63421099526541, 62.22902543204171, 59.75300012316023, 60.852225984845845, 59.28998606545584, 57.67094809668404, 56.628739152635845, 55.354130336216514, 58.32745211465018, 56.015525885990684, 68.31998307364327, 71.81733798980713, 75.56621074676514, 73.28390121459961, 78.29528944832938, 68.41873087201799, 57.010198729378835, 68.90566062927246, 75.16171441759381, 76.3904755456107, 72.94460678100586, 70.73242541721889, 69.83795601981026, 68.09975297110421, 76.62017604282924, 47.23742886951992, 62.8612767628261, 70.43638351985386, 70.36490045275006, 69.16413361685616, 72.82155418395996, 74.80971867697579, 76.87448011125836, 70.76194136483329, 70.44825104304722, 63.88312748500279, 68.99935708727155, 72.521162714277, 69.65651076180595, 71.49025848933628, 73.2483959197998, 58.501560074942454, 58.821781703404014, 58.134045532771516, 55.076664447784424, 55.693108626774375, 55.06736775806972, 55.07456956590925, 56.86674969536917, 54.788692883082796, 55.82834489004952, 54.90746191569737, 55.578150681086946, 56.22161987849644, 57.48033121653965, 58.138290882110596, 56.47669519696917, 58.2427396774292, 57.34380953652518, 57.77632795061384, 62.5516858782087, 67.96474947248186, 70.54647772652763, 72.43958391462053, 69.04508318219865, 69.57648141043526, 70.40308080400739, 78.24560982840401, 77.6492737361363, 79.94638293130058, 31.294947011130198, 2.57624134847096, 4.493545940944126, 4.471903605120523, 2.700453209025519, 1.78386432996818, 3.127829087632043, 3.2363249914986745, 0.5405291382755552, 0.16229691835386412, 0.7805050984025002, 31.191731521061488, 39.480741364615305, 68.60424777439663, 70.9470135825021, 25.316197565623693, 50.03083051953997, 70.84680666242326, 81.44606127057756, 74.04201916285923, 93.89563505990165, 24.083465542112076, 1.107865838067872, 0.25426753610372543, 0.28550419424261364, 0.24550127078379902, 0.17343410716525146, 0.2086561271654708, 0.09942961750285965, 0.1480545633073364, 0.16673004547400133, 0.15074618959001132, 0.13559668750635215, 0.12723100212003502, 0.14150418979781015, 0.13244665653577872, 0.16514589690736362, 0.20085754777703965, 0.1197602501405137, 0.15992394568664686, 0.08443658559450082, 0.1419722025415727, 0.15649804951889174], [0.10039133232619081, 0.01332483405712992, 0.1423304554607187, 0.007050228629460824, 0.04911165218800306, 0.042020245388682397, 0.08539198325680834, 0.023726971819996834, 0.1867839443896498, 0.04279031478134649, 0.10070117177175623, 0.04043218506766217, 0.05439216098082917, 0.05566536408982106, 0.11291638309402124, 0.05696739815175533, 0.4131507719201701, 0.5757601420794214, 20.65359500476292, 87.97204562595913, 72.95672443934849, 73.60652691977364, 64.36752809797014, 31.786125591823033, 58.68376963479178, 77.45690590994698, 50.18728658131191, 20.314397845949443, 0.031199616912220205, 0.15892276726663113, 0.18465080671012402, 0.09378800594380923, 0.07327572948166303, 0.0764956631298576, 0.1751429568976164, 0.7804301881364414, 10.721934608050756, 85.30339540754045, 84.68424143110002, 92.51585483551025, 83.45998273577008, 84.25702449253627, 77.95772511618478, 71.62483814784459, 62.93195383889334, 65.6780903679984, 62.943988118852886, 63.30351570674351, 56.535577705928254, 56.89666516440255, 53.92203712463379, 57.547315325055806, 56.65291540963309, 60.300344467163086, 55.11098854882376, 54.28367001669747, 52.478510652269634, 52.76759740284511, 52.24663536889212, 54.31302962984358, 52.15116712025234, 54.00957400458199, 52.01711205073765, 52.257366861615864, 50.817102568490164, 50.75773368562971, 49.378238337380544, 49.574069840567454, 50.49788842882429, 50.62142045157296, 51.80172484261649, 51.756283623831614, 53.212983880724224, 59.47250829424177, 64.43124307904924, 65.37233488900321, 67.53699057442802, 69.12238883972168, 67.30448300497872, 55.66520813533238, 49.020395687648225, 55.08774682453701, 56.50138214656285, 60.19765704018729, 55.58547755650112, 62.801932198660715, 63.66951206752232, 66.42979512895856, 41.06539964675903, 61.400591714041575, 58.06593581608364, 63.76149232046944, 68.14901569911412, 63.10117721557617, 64.94481917790004, 62.85749694279262, 62.360582624162944, 56.70288337979998, 58.844085420881, 63.556694167000906, 64.50811794825962, 58.4638591493879, 63.88856097630092, 66.5460593359811, 56.36343608583723, 55.35847643443516, 54.01358311516898, 47.125562872205464, 47.169690881456646, 48.71985483169556, 48.1614420073373, 47.352984360286165, 48.245456150599885, 47.60776785441807, 48.039129393441335, 47.80187273025513, 49.22227907180786, 47.717799527304514, 49.678174700055806, 47.05245392663138, 51.063298089163645, 50.39458956037249, 51.47513171604702, 53.69415705544608, 57.66608435767037, 61.34043421064104, 59.74109091077532, 60.18965966360909, 58.16796316419329, 61.5992546081543, 67.578047479902, 69.75351456233433, 66.80915982382638, 67.49949114663261, 36.96793229239327, 0.371235546788999, 2.915905773639679, 1.43106900368418, 0.2953729161194393, 0.45794545539787834, 1.4732244844947542, 0.5739256548030036, 0.16209369711577892, 0.07617333863994905, 3.998027341706412, 24.94382449558803, 39.81004776273455, 44.59227051053728, 24.965726954596384, 15.297445842197963, 38.959633418491904, 66.25677803584507, 59.85320009504046, 60.82254328046526, 42.75580603735787, 0.25201751398188726, 0.15142199689788477, 0.03908208019233175, 0.13439291210046836, 0.07050238722669226, 0.03899355851379888, 0.06602167444569723, 0.18753713183104992, 0.028957370801695755, 0.07027247920632362, 0.05909947731665202, 0.07805993740579911, 0.014856610746522034, 0.014547195385343261, 0.06332165468484163, 0.06423981434532575, 0.02585859806276858, 0.046295151713171175, 0.011993601785174437, 0.1003067461507661, 0.026615374954417348, 0.09447152140949454, 0.03523523786238261, 0.06822229243282761, 0.014243913980733072, 0.06295919484858002, 0.109945994269635, 0.06584841052868537, 0.010803478503865855, 0.11408499681523868, 0.06600180015500103, 0.05646846117451787, 0.01106842013541609, 0.09192616692078964, 0.16226425367806638, 0.2267566051866327, 0.05697440741849797, 0.4251451811620167, 0.5021286702581814, 32.77482993262154, 101.96309116908482, 83.55201162610734, 85.07133252280099, 74.39279202052525, 43.272731167929514, 53.78508465630667, 65.4622723715646, 54.32911123548235, 21.565985543387278, 0.013767334732360073, 0.2883802599140576, 0.8350301097546304, 0.7564771420189312, 0.28977980624352184, 0.48873015493154526, 0.5033719635435513, 0.5906241301979337, 14.473662206104823, 92.25317123958042, 87.06420789446149, 96.20163794926235, 86.7360166822161, 90.09895869663784, 81.04926354544503, 76.32321003505162, 66.25514520917619, 67.99193082536969, 66.6130677631923, 66.9730886731829, 59.72883428846087, 60.45030743735177, 56.0227415902274, 59.77367101396833, 59.16290351322719, 61.688657079424175, 57.564737933022634, 58.252314295087544, 54.69604212897164, 55.83181551524571, 55.58130863734654, 57.19566004616873, 55.630991731371196, 56.374039036887034, 56.078452246529714, 56.17646353585379, 54.00984845842634, 54.09881666728428, 52.80625023160662, 52.62335280009678, 52.45238889966692, 53.660694531032014, 53.807245935712544, 54.97137144633702, 56.2614677974156, 63.346240179879324, 68.55464458465576, 68.83544213431222, 70.28746277945382, 72.51372814178467, 69.43336241585868, 58.99896076747349, 50.36228391102382, 56.09730618340628, 60.04774270738874, 63.30725383758545, 58.796128954206196, 65.985520362854, 66.7029218673706, 69.72482545035226, 46.19502190181187, 64.714889390128, 62.06960596357073, 65.41663660321916, 69.44876657213483, 67.8915571485247, 66.20142868586949, 65.37114674704415, 64.30445929936, 59.756925855364116, 62.006564957754954, 65.90393461499895, 67.39092554364885, 60.238859857831685, 67.29254599979946, 68.21267509460449, 58.52116789136614, 57.580131667000906, 56.653915950230186, 50.794319425310405, 50.92885044642857, 50.600777353559224, 51.038763999938965, 50.45988873073033, 50.98864664350237, 51.04501737867083, 49.930161544254844, 51.80121415002005, 51.5975798198155, 51.84129135949271, 53.6279685156686, 49.847026348114014, 53.49712003980364, 52.3450357573373, 55.689370495932444, 57.536861760275706, 62.150628907339915, 62.58302225385393, 62.72661372593471, 62.09025600978306, 61.466842787606375, 64.85280418395996, 70.77977739061627, 72.727294921875, 72.06770937783378, 73.12740693773542, 49.033517360687256, 1.59825199842453, 1.6217770789350783, 0.6440911697489875, 0.5447168392794473, 1.3933604785374232, 2.5087467644895827, 1.2920912440334047, 0.4061088269310338, 0.2747327765183789, 3.583270694528307, 29.32280853816441, 43.237660135541645, 40.79536485671997, 27.65771096093314, 25.975906440189906, 50.40993118286133, 73.60381712232316, 65.82530879974365, 68.72458362579346, 65.29914951324463, 1.8141927825553077, 0.24924586127911294, 0.05148588353767991, 0.2617208090211664, 0.019962720772517577, 0.13157726318708488, 0.08723061638219015, 0.06644771979855639, 0.02005760880586292, 0.07527657318860292, 0.03174908778497151, 0.06599580190543618, 0.01766332165737237, 0.027316403408933963, 0.025045648649600998, 0.033081625388669114, 0.04892560127856476, 0.055578230015401325, 0.0472997024522296, 0.07606096645551068, 0.057150582250739844, 0.16337511049849646, 0.14570300520530768, 0.15132713770227774, 0.11423241533339024, 0.2034897886748825, 0.18960487230547837, 0.19872863058532986, 0.06789497392518179, 0.3545584859592574, 0.10518192526485239, 0.19438801492963517, 0.1272546558507851, 0.31518798427922384, 0.17640508631510393, 0.3480606446308749, 0.19215464405715466, 0.6610658903207097, 0.822865822485515, 33.12654079709734, 114.69261482783726, 96.29526492527553, 95.11086109706334, 82.8563927241734, 47.60152837208339, 76.90339156559536, 101.35624940054757, 68.71887220655168, 33.25887966156006, 0.1514853856393269, 0.42748818972281044, 0.948653512767383, 1.1661365798541476, 0.2285875097981521, 0.4861207806638309, 2.4499830263001576, 2.883935157741819, 13.602628214018685, 95.67410986764091, 88.09488977704729, 102.69998931884766, 88.46520791734967, 94.97718470437187, 85.2428765978132, 80.61090169634137, 68.45929445539201, 73.59440231323242, 67.94925498962402, 72.28025477273124, 61.933094705854145, 64.62030356270927, 60.44857038770403, 64.02141748155866, 63.78710338047573, 66.98522022792271, 61.08948612213135, 62.33672945840018, 58.378431047712056, 57.65867757797241, 57.93542432785034, 60.35408183506557, 57.891796588897705, 60.11882972717285, 60.21167850494385, 59.49349185398647, 57.57271793910435, 57.84732811791556, 54.4226861000061, 56.967290128980366, 56.397645541599815, 56.58599036080496, 56.86167056219918, 57.08600010190691, 59.08032417297363, 66.22970785413469, 71.47859246390206, 72.15603487832206, 73.64772973741803, 76.47069249834333, 73.07634462629045, 62.71214062826974, 55.74968433380127, 60.865191323416575, 64.78722013745988, 66.46733624594552, 62.20185797555106, 70.10352311815534, 69.12935093470982, 73.76538358415876, 50.86248820168631, 67.02513068062919, 67.6621345792498, 69.96876975468227, 73.23914786747524, 71.63574681963239, 68.50010817391532, 71.23232746124268, 68.92518506731305, 62.731477464948384, 64.70045103345598, 68.007077898298, 70.07844706944057, 61.672495569501606, 70.14474678039551, 71.46284089769635, 63.38198866162981, 61.31596960340227, 61.27489185333252, 54.04865067345755, 54.369973591395784, 56.192579882485525, 55.11644288471767, 53.26616539273943, 54.105000564030235, 53.60311828340803, 53.89504337310791, 55.20460510253906, 56.25851828711373, 55.16933604649135, 57.4925148827689, 53.33936466489519, 57.00896889822823, 55.167039666857036, 58.43958214351109, 61.19004740033831, 65.16345119476318, 65.89276191166469, 65.84538909367153, 65.8152825491769, 64.79261193956647, 67.79449081420898, 74.3121234348842, 77.01174177442277, 75.66041442326137, 75.65137481689453, 46.62793288912092, 0.7557426414319447, 5.968201645783015, 6.349862720285143, 1.3866299539804459, 1.1592132427862711, 4.6594341823032925, 2.044670935188021, 0.37607545565281597, 0.31382391176053454, 6.98227516242436, 41.4887638092041, 54.99609661102295, 67.04223714556012, 36.42954765047346, 22.845892361232213, 55.148595673697336, 83.25366987500871, 77.50366033826555, 81.20597321646554, 74.43591254098075, 1.4615535736083984, 0.28060251155069893, 0.17779188975691795, 0.32063727187258856, 0.12952875239508493, 0.17049930750259332, 0.15168372142527783, 0.1597758350627763, 0.1628893744200468, 0.16821949769343647, 0.2111140252756221, 0.1114704588960324, 0.14395731102143014, 0.08154351583548955, 0.15858628175088338, 0.16905340366065502, 0.15395084262958594, 0.17090447433292866, 0.09270566116486277, 0.11025215605539934, 0.19078354191567215], [0.010727015240783138, 0.01704947816740189, 0.03769592135878546, 0.08063782764864819, 0.14654814771243505, 0.10532581540090696, 0.03247069620660373, 0.06316879431584052, 0.006790572361621473, 0.003841353829817048, 0.005986551197046148, 0.08156630104141575, 0.07022638632250683, 0.06779964654041187, 0.013052271629151489, 0.061073118554694314, 0.1615431338016476, 0.6103522373097283, 73.27479212624687, 78.2990414755685, 76.59270286560059, 64.59748567853654, 47.21977349690029, 26.52735195841108, 43.672464506966726, 68.49586977277482, 43.053831645420615, 3.9674513595444814, 0.14058838465384074, 0.28678738538708004, 0.8952211056436811, 0.8171998379485947, 0.2388910911977291, 0.04689383673082505, 0.1655785444059542, 0.8605765732271331, 52.8376213482448, 92.36061123439244, 85.65219497680664, 88.21863719395229, 87.64628628322056, 81.58787400381905, 76.90962409973145, 77.82508400508335, 70.89647238595145, 71.56416647774833, 68.64159434182304, 70.07517446790422, 67.01349939618791, 63.03646864209856, 55.500869342258994, 56.00617708478655, 54.68022108078003, 55.05326638902937, 56.05164957046509, 52.0737954548427, 52.57334314073835, 53.81718185969761, 50.28675699234009, 52.90550872257778, 50.14859553745815, 50.27232558386666, 50.67860760007586, 51.17279127665928, 48.347810064043315, 49.84408378601074, 49.0279483795166, 49.448581899915425, 50.01175076620919, 50.544851303100586, 52.686973980494905, 54.64346511023385, 50.32360328946795, 54.491424628666465, 58.43168204171317, 63.800082615443635, 66.16178921290806, 73.4958838054112, 64.17250605991909, 63.72270747593471, 54.44121694564819, 48.664140701293945, 50.33237886428833, 53.05180304391043, 57.61648464202881, 59.438844272068565, 62.70041901724679, 64.29275853293282, 43.38333606719971, 62.07894434247698, 61.37467493329729, 58.57236221858433, 62.77473694937569, 63.58416039603097, 59.1897166115897, 57.375371728624614, 55.98319591794695, 57.76979316983904, 60.7421178817749, 64.83379391261509, 64.16910144260952, 62.08578136989048, 62.95660604749407, 65.00608839307512, 55.03600706372942, 54.59534536089216, 55.5459874698094, 50.93466261454991, 47.7662284714835, 48.171315397535054, 47.737626211983816, 45.33677346365792, 46.42125872203282, 47.6710763658796, 45.75908497401646, 47.52664416176932, 46.429798058101106, 48.00051130567278, 47.71937676838466, 48.46490805489676, 49.34751687731062, 51.16850771222796, 50.96845865249634, 55.22665868486677, 58.227102756500244, 56.39406027112688, 56.74144588197981, 56.598497118268696, 56.13575056621006, 61.11122008732387, 65.14831801823208, 67.98335674830845, 68.70554556165422, 70.6650139944894, 74.86564472743443, 66.95899077824184, 5.04904443025589, 2.326185234955379, 1.090853065252304, 0.41197001242211884, 0.32320948956268175, 0.4115509491946016, 0.181316024224673, 0.018959459249994585, 0.00658592365549079, 14.81469542639596, 26.631508929388865, 47.84262044089181, 52.06124005998884, 26.512470654078893, 38.738920416150776, 43.02034132821219, 60.432332447596956, 53.46001665932791, 68.74849932534354, 15.482570171356201, 0.46914888279778616, 0.12228714169136115, 0.06996517748172794, 0.060283507353493145, 0.0805608614214829, 0.07219201406197888, 0.045761310894574435, 0.04366972669959068, 0.03572881441297276, 0.020890305284410715, 0.06339839021010057, 0.03263966499694756, 0.05342468539518969, 0.06597851283316102, 0.06263633431600672, 0.0869569360677685, 0.011578843014181724, 0.0433074025703328, 0.03554645812671099, 0.014705502694206578, 0.004331268835812807, 0.0408669292394604, 0.036975778572793515, 0.03473409903900964, 0.04683239199221134, 0.03572481105636273, 0.028866348721619164, 0.06334620408181633, 0.028539722319692373, 0.08929942215659789, 0.03840953324522291, 0.056553179664271216, 0.020420784496569207, 0.09140767795698983, 0.032578898793352504, 0.05493753689474293, 0.05497519898095301, 2.010671445301601, 91.69586317879813, 85.12993362971714, 86.2235175541469, 68.66840049198696, 61.642291750226704, 32.996859618595664, 29.35160882132394, 61.06021336146763, 44.55361073357718, 4.72746616601944, 0.21371295010404928, 0.9736436860901969, 2.3639558596270422, 2.0186694732734134, 1.0526367787803923, 0.6490738423807281, 0.15823425778320857, 1.6390561631747653, 62.05689770834786, 96.09418405805314, 89.3357685634068, 91.97016416277204, 90.45379625047956, 86.67169025966099, 80.503892489842, 82.32618263789585, 75.69241782597133, 74.9426029750279, 72.3872709274292, 74.28744343348912, 70.76547799791608, 65.84419400351388, 60.287976673671174, 58.313430649893625, 56.77066305705479, 60.062973158700125, 59.446487290518625, 56.29523951666695, 56.01504646028791, 55.73060458047049, 54.284455163138254, 55.646878787449424, 54.46851989201137, 54.49498210634504, 53.90061582837786, 54.59076649802071, 52.284756660461426, 54.11943197250366, 52.355895791734966, 51.71541084562029, 53.43999889918736, 55.11537286213466, 55.04550872530256, 56.358902386256624, 53.431918144226074, 56.565673828125, 61.339656012398855, 67.62986019679478, 70.77211352757045, 73.39362021854946, 69.50441469464982, 67.29786137172154, 57.57627889088222, 51.8620491027832, 53.07132053375244, 57.07472317559378, 60.966419628688264, 61.33272865840367, 65.48174122401646, 67.32418114798409, 47.16030733925955, 63.519861766270225, 65.56616878509521, 62.17470441545759, 65.35952241080147, 66.01086044311523, 61.265351976667134, 59.62303406851632, 57.48969391414097, 61.45596885681152, 62.627657481602256, 66.45653179713658, 65.58107267107282, 63.43711566925049, 65.38841302054269, 67.40543338230678, 58.09859929765974, 56.42429883139474, 58.18058109283447, 52.77220058441162, 50.376340116773335, 50.61731406620571, 50.43599387577602, 49.9555606842041, 49.583717414310996, 50.09348242623465, 48.38661575317383, 50.84876550946917, 49.425169944763184, 51.41502979823521, 50.06004769461495, 52.104669775281636, 52.87954330444336, 54.896525451115195, 54.24855382101876, 56.77671841212681, 60.491621426173616, 60.027224676949636, 59.336226327078684, 59.69246046883719, 59.02090317862374, 65.35559667859758, 69.21302809034074, 70.8855289731707, 72.234785761152, 73.1473969050816, 77.69946752275739, 77.39061314719063, 10.536742533956255, 0.8888192091669355, 0.10760194076491253, 0.33782651807580677, 1.4769684778792518, 1.1047324176345552, 0.4008869028517178, 0.2903205986533846, 0.040530542111290355, 14.502909779548645, 32.04034628186907, 44.677090644836426, 27.21916845866612, 25.77999155861991, 48.722981521061485, 48.234891414642334, 68.34626810891288, 60.8683249609811, 79.53157547542027, 28.59548326901027, 0.28757391603929655, 0.01613346267757671, 0.04413685056247881, 0.0795495185468878, 0.028653611029897417, 0.054724768668945344, 0.04125089863581317, 0.017794964236340353, 0.04044792029474463, 0.05920954926737717, 0.05721331959856408, 0.0886400964643274, 0.048781877383589745, 0.04554714149396334, 0.04852012571479593, 0.035911228374711106, 0.027602711260052662, 0.09977334298725639, 0.01755919536974813, 0.0434726190620235, 0.09362207699034895, 0.17163239313023432, 0.1289904434233904, 0.18176520083631786, 0.16855432758373873, 0.17152964935771056, 0.1863947231322527, 0.17082290085298674, 0.2301472175334181, 0.12793743849865027, 0.20264926020588192, 0.18683555376316818, 0.17193430050143174, 0.1699627355805465, 0.08401419754539217, 0.13584835614476884, 0.17180985717901162, 1.9176235582147325, 99.85847486768449, 99.98263917650495, 97.45956066676548, 81.35788863045829, 65.02466787610734, 35.735443455832346, 64.6529461996896, 86.38147790091378, 64.76332528250558, 6.962340346404484, 0.20991669595241547, 1.56670999952725, 4.060406965868814, 3.2038669160434177, 1.0837204137018748, 3.109026610851288, 3.4140240848064423, 1.436253662620272, 61.33227007729666, 99.13587611062187, 91.41249479566301, 94.34009742736816, 96.18973568507603, 90.70387581416539, 83.2871185030256, 84.94313131059918, 78.31054769243512, 77.54737145560128, 74.24206474849156, 76.52552768162319, 74.82544245038713, 69.65359251839774, 64.20044476645333, 62.14957972935268, 60.65731511797224, 62.88705457959856, 62.84219006129673, 60.40685340336391, 59.46624796731131, 59.868479183741975, 56.268711294446675, 60.11018616812569, 57.46177952630179, 58.54580620356968, 57.60406126294817, 57.12620932715279, 54.817086696624756, 57.500682490212576, 55.341800757816856, 55.99212087903704, 58.50524956839425, 56.993665490831646, 59.76590987614223, 59.79489081246512, 53.89583894184658, 59.203619956970215, 64.70800372532436, 69.8576055254255, 74.34874044145856, 78.63719640459333, 72.90819127219063, 69.68148258754185, 58.708241190229145, 54.852070876530235, 56.05682250431606, 60.60746874128069, 64.09882736206055, 66.24511895860944, 69.17477825709751, 70.22194821493966, 50.01700013024466, 66.6313693182809, 67.93192618233817, 66.92116478511265, 68.6984931400844, 69.89295101165771, 65.64808109828404, 63.96785381862095, 60.55414826529366, 62.7470622743879, 67.23483426230294, 69.91191959381104, 69.77784020560128, 66.8730832508632, 67.78646564483643, 73.33715915679932, 60.63879122052874, 60.13918794904436, 59.903963633946006, 55.989880084991455, 53.504627568381174, 54.25533178874424, 53.45010852813721, 52.678219250270296, 53.0243124961853, 53.85804768971035, 52.40325123923165, 54.78601435252598, 52.6082752091544, 54.54142039162772, 53.06746080943516, 54.03849588121687, 54.78378745487758, 57.91824838093349, 57.23913492475237, 62.54227106911795, 64.55201666695731, 64.91851329803467, 63.281969342912944, 62.678824016026084, 62.000686781747, 68.40750258309501, 71.9363397870745, 76.17046083722795, 76.03302546909877, 76.9776747567313, 82.5923125403268, 75.60182721274239, 6.1450220091002326, 4.037043213844299, 6.58972886630467, 2.140839431967054, 1.6597844851868493, 3.728998303413391, 0.5676853039434978, 0.36936857125588823, 0.164297578856349, 23.347281319754465, 43.3724239213126, 65.62316485813686, 74.92642756870815, 37.33012104034424, 53.44633218220302, 58.15670708247593, 78.92846488952637, 69.55893720899309, 92.94985321589878, 30.679270608084543, 0.5514176168612072, 0.22199588135949203, 0.16706490250570433, 0.17210558988153934, 0.15322369736220154, 0.23257873420204433, 0.12967629304953984, 0.05229654968050974, 0.14114349415259703, 0.14098270849457809, 0.13994844470705303, 0.1313246310289417, 0.14632910303771496, 0.2099199936326061, 0.13515550403722695, 0.19723564998379775, 0.08078570757061243, 0.10269902992461409, 0.12577591091394424, 0.07742307800799608], [0.009811980234059905, 0.06649072534803833, 0.028993496006088595, 0.08147915000362055, 0.014065933397172816, 0.11910196260682174, 0.07149005601448671, 0.04762777413374611, 0.030444879018302475, 0.05804749019443989, 0.007059530072313334, 0.12939353393656866, 0.06524858557220016, 0.2713664285838604, 0.0868425282782742, 0.4680391252040863, 0.24040585277335985, 20.469990594046457, 80.82029260907854, 67.2389475958688, 69.68460927690778, 51.29618780953543, 25.324639626911708, 55.12865434374128, 144.89545440673828, 59.663257190159385, 22.317903961454117, 0.3642430534320218, 0.054845829494297504, 1.9401135742664337, 0.4244970716536045, 0.2666819042393139, 0.8655401925955499, 0.544731387070247, 0.6438419574073383, 18.589764629091533, 94.1722775868007, 79.40146350860596, 88.74031489236015, 86.18635163988385, 88.05515302930559, 81.8863547188895, 84.90874467577252, 78.1518508366176, 78.60442870003837, 71.77378668103898, 76.94528920309884, 72.01023387908936, 71.24557072775704, 66.5915561403547, 63.519924300057546, 53.00935649871826, 54.036067485809326, 51.92151526042393, 54.830163206372944, 52.38226073128836, 52.539199692862375, 50.557906968253, 52.616564410073416, 51.38431181226458, 50.92046397072928, 49.68421268463135, 50.798606463841026, 48.45948845999581, 50.75593410219465, 47.715801920209614, 50.50740398679461, 49.91609839030674, 50.06759343828474, 51.02628156117031, 53.1707318850926, 51.62193325587681, 48.80366052900042, 47.14803682054792, 53.89849662780762, 59.54718753269741, 64.4114546094622, 64.90441540309361, 68.12997068677629, 64.42309979030064, 60.82245295388358, 57.54356329781668, 56.07677425657, 54.496837275368826, 55.92419181551252, 59.15651117052351, 63.11930506569998, 64.36153875078473, 46.516296182359966, 60.23668507167271, 62.34802028111049, 63.92837415422712, 57.64409678322928, 60.05838734763009, 59.912787846156526, 59.738429750714985, 63.89985874720982, 60.51903206961495, 62.22571808951241, 62.52993106842041, 62.250425883701865, 61.387772287641255, 63.3928347996303, 60.03673676082066, 54.40482228142874, 52.13289335795811, 58.86757033211844, 51.915807315281455, 46.13383953911917, 44.50935765675136, 45.84345000130789, 45.870481967926025, 45.65173183168684, 47.51537765775408, 46.18258810043335, 46.11060128893171, 47.05227674756731, 46.70561374936785, 48.30812542779105, 48.97750793184553, 50.423879691532676, 49.98349939073835, 51.131890705653596, 52.21172761917114, 54.274123191833496, 53.84481831959316, 54.612601212092805, 54.427334444863455, 57.03377396719796, 61.23456450871059, 63.860789026532856, 66.20571572440011, 67.11043371473039, 66.12064892905099, 63.977435384477886, 70.3172219140189, 84.009738104684, 11.257886511938912, 1.498609836612429, 2.4418403889451707, 1.8800878695079257, 1.1227905686412538, 0.8393801163349832, 0.09929340159786598, 0.052909334655851126, 2.1452337333134244, 26.118387937545776, 29.00136055265154, 65.10075759887695, 33.829399721963064, 15.192041669573102, 43.78497668675014, 48.66899401800973, 57.14286763327462, 56.25788252694266, 55.2157222202846, 2.7562218393598283, 0.2154695415603263, 0.015484489733353257, 0.07063924773995366, 0.02098194313501673, 0.08830149391932146, 0.02937107699524079, 0.06400082752640758, 0.028007185984668986, 0.007328905930210437, 0.014409420546144247, 0.09820277869169201, 0.031123122266892875, 0.07431820354291371, 0.029444541981709853, 0.09627584780433349, 0.03861833882651158, 0.023533881109740053, 0.006712819033834551, 0.020612316272620643, 0.00896739327747907, 0.05196767732767122, 0.016498366936243007, 0.029441919443862777, 0.022783333169562475, 0.12071193621626922, 0.06454415087188993, 0.045525482656168084, 0.049750445410609245, 0.08106191882065364, 0.022174697435860122, 0.10447217084999595, 0.05876575343843017, 0.17228085547685623, 0.04036475904285908, 0.5304659754037857, 0.38172140983598574, 33.365722111293245, 96.74466746194022, 73.94517517089844, 79.44524410792759, 61.21337945120675, 45.39806352342878, 51.54586437770298, 103.05462537493024, 53.447447368076865, 27.529358625411987, 0.3177385431315218, 0.18580199565206254, 3.275060547249658, 2.1648552290030887, 1.8762956729957034, 2.2942990830966403, 0.6217744786824498, 0.2886337334556239, 23.869844913482666, 98.48729651314872, 81.13851315634591, 90.7524367741176, 89.08457728794643, 87.66772147587368, 85.88140910012382, 89.78480979374477, 81.68828242165702, 85.0083748953683, 76.12588119506836, 80.26181030273438, 77.15461758204869, 75.65564795902797, 70.48035866873605, 66.66592270987374, 55.7858601297651, 57.52918747493199, 56.24287441798619, 58.40772465297154, 54.0874285697937, 56.98860720225743, 54.49361331122262, 54.96296065194266, 54.22614240646362, 55.47206905909947, 54.0279415675572, 54.020545210157124, 53.33698490687779, 54.8584771156311, 51.39942414419991, 53.50094502312796, 52.23053986685616, 53.52602802004133, 53.8832105909075, 56.31479869570051, 54.03704718181065, 50.545605182647705, 51.21138504573277, 55.01087890352522, 61.57886859348842, 66.82079805646623, 66.43801484789167, 69.50094059535435, 67.61643627711705, 65.49055848802838, 62.1573269707816, 58.2426632472447, 57.98604890278408, 59.419945171901155, 62.53979056222098, 65.88438238416398, 66.05125032152448, 51.00772639683315, 63.83771405901228, 65.01863683973039, 65.41432980128697, 62.00518921443394, 61.45660809108189, 62.790002141680034, 62.75346156529018, 66.7753220966884, 63.28495706830706, 64.0549008505685, 66.86061818259103, 65.80474213191441, 63.483015469142366, 66.39036410195487, 63.13809299468994, 55.900217056274414, 53.861500944410054, 61.15302045004708, 54.83963360105242, 50.12971380778721, 47.558713572365896, 46.631031785692485, 50.07228347233364, 49.506085191454204, 51.245108127593994, 49.948393617357524, 49.86756869724819, 50.430233819144114, 48.86009727205549, 49.84727300916399, 51.58221387863159, 53.877596446446006, 51.378152234213694, 52.9994136265346, 56.05164609636579, 57.07393455505371, 58.571945326668875, 56.94245031901768, 58.64504732404436, 59.36675671168736, 62.95903096880232, 66.92501408713204, 70.29428591047014, 69.23521368844169, 68.7582893371582, 68.18524360656738, 71.41111155918666, 91.07330458504813, 19.69190526008606, 0.9910894185304642, 0.480889872780868, 1.387610952769007, 1.3404352899108614, 2.130654675619943, 0.5596933556454522, 0.22589189372956753, 1.7219176654304778, 28.804158517292567, 33.049923011234824, 44.7057762827192, 22.209743091038295, 22.442605018615723, 54.87587887900216, 56.07303612572806, 66.12085737500871, 62.22001361846924, 73.467910357884, 7.213058275835855, 0.36385566421917503, 0.06357354723981448, 0.037826563098600934, 0.07842372038534709, 0.12565545737743378, 0.0727425366640091, 0.04719075008428522, 0.027145361694108163, 0.05772815125861338, 0.0326920546857374, 0.10860294276582343, 0.03664001230416553, 0.09075787889638118, 0.043069365700440745, 0.037170080468058586, 0.017211592057719827, 0.05887066852301359, 0.02333241727735315, 0.1010890088177153, 0.08688919113150664, 0.12147500312754086, 0.14594298947070325, 0.16415181596364292, 0.18583954577999456, 0.20794762804039887, 0.1345966625958681, 0.15354997771126883, 0.12526535402451242, 0.14411482614065918, 0.034416303770350556, 0.35517847697649685, 0.21003607740359648, 0.3580913192459515, 0.1754857935011387, 0.774580999144486, 0.543028861284256, 38.1587666784014, 110.01772785186768, 84.2540784563337, 89.54733426230294, 70.17563847133091, 42.086663246154785, 74.05041258675712, 162.3172424861363, 74.22807107652936, 36.97431073869978, 0.716353249336992, 0.290912389755249, 7.501774600573948, 2.574487579720361, 2.6598835459777286, 6.0246197155543735, 6.514296182564326, 1.9133132866450717, 23.31947636604309, 104.21844863891602, 85.5013565335955, 95.84409059797014, 93.50782135554722, 91.82801791599819, 86.89570018223354, 96.20053318568638, 84.90559714181083, 86.86012540544782, 79.58931500571114, 82.52548476627895, 77.45398766653878, 78.59761946541923, 74.37128039768764, 70.25268704550606, 59.85437434060233, 60.37324496677944, 58.33407374790737, 61.4790438243321, 57.57231494358608, 60.19093118395124, 57.928041866847444, 59.38289042881557, 57.66648040499006, 59.44778660365513, 56.22758143288748, 56.75387620925903, 55.15257699148995, 56.933115414210725, 53.3745572907584, 58.59399196079799, 54.26867233003889, 56.51412861687796, 56.87228740964617, 59.22624329158238, 55.14182118007115, 52.91788693836757, 52.54895148958479, 57.218842710767476, 66.27362046922956, 70.16930866241455, 69.67913409641811, 74.50582531520298, 70.64038957868303, 69.09159442356655, 66.17533820016044, 61.68761484963553, 61.143772397722515, 61.25948074885777, 66.2927280153547, 69.24132810320172, 68.69885444641113, 55.45191233498709, 65.84132439749581, 68.52899878365653, 70.10794217245919, 65.37713609422956, 66.3606675011771, 64.43378611973354, 64.79844842638288, 70.00016171591622, 66.57771532876151, 67.75640078953334, 69.50801386151994, 69.95500537327358, 65.50972856794084, 67.62305096217564, 65.07494504111153, 58.882995332990376, 57.608379568372456, 64.11168847765241, 55.496394702366416, 52.12845345905849, 50.19805628912789, 51.43372392654419, 53.228617327553884, 52.105079718998496, 54.4172352382115, 52.99100283214024, 52.66558395113264, 53.60237830025809, 52.27742631094796, 54.649131366184776, 55.55269248144967, 56.02086557660784, 55.53474875858852, 57.56677028111049, 59.17416654314314, 60.75190789358956, 61.237739835466655, 59.17800889696394, 61.40311391013009, 63.94211074284145, 67.06895296914237, 71.41519709995815, 72.44435732705253, 73.7530574798584, 72.80949211120605, 70.60908099583217, 77.2524412700108, 94.79733753204346, 12.907130905560084, 3.20303921188627, 8.938856618744985, 4.256979320730482, 4.051057296139853, 3.5712296835013797, 0.3577200791665486, 0.38403060021145, 4.171648928097316, 41.65968949454171, 43.26293420791626, 90.45011370522636, 48.53232642582485, 23.31419399806431, 60.31022480555943, 63.997390610831125, 75.81583172934396, 72.91927364894322, 82.72399480002267, 6.250731902463095, 0.4681412311536925, 0.19829302467405796, 0.2488422957914216, 0.23720726583685192, 0.16373628111822264, 0.10139220540544816, 0.13632257069860185, 0.20636608504823276, 0.09506139225725617, 0.12716842762061528, 0.1504452728799411, 0.12136471404560975, 0.15650430561176368, 0.08924576360732317, 0.1302581096866301, 0.09274355734565429, 0.12277237565389701, 0.07829673255660705, 0.1710182103727545], [0.048430755867489746, 0.12975732370146684, 0.04059503686481288, 0.038689466259841404, 0.032279088095362694, 0.06477664411067963, 0.049721821410847564, 0.04619109158271125, 0.032285228837281466, 0.08966648246028594, 0.03799703823668616, 0.03146979598594563, 0.039655696733721664, 0.0030646691448055208, 0.05036351876333356, 0.10183888500822441, 0.005458037302430187, 52.96147646222796, 75.8392402103969, 75.92860794067383, 56.50584636415754, 51.576752594539094, 18.918053116117203, 64.34584971836635, 77.75597722189767, 39.71054261071341, 10.875822441918508, 0.2749568016401359, 0.10873302471424852, 1.2411151336772102, 0.6648378393479756, 3.277301558426448, 1.085975972669465, 1.294620822582926, 2.2018433128084456, 68.84615625653947, 84.56271743774414, 76.71248286111015, 82.09837205069405, 82.91951710837228, 85.22344943455288, 81.04039764404297, 77.36269528525216, 78.59688295636857, 79.49003914424351, 79.44169357844761, 77.18599564688546, 74.77940368652344, 72.62562193189348, 66.81111921582902, 64.42414202008928, 55.38379567010062, 53.73340048108782, 52.05180788040161, 54.88238934108189, 53.64236518314907, 52.60936607633318, 49.9545636177063, 50.55615949630737, 50.33850717544556, 51.05977535247803, 48.65245035716465, 51.51584815979004, 51.9616584777832, 48.471668652125764, 49.951482091631206, 51.09634372166225, 53.107649190085276, 51.107158592769075, 50.415072849818635, 52.31907728740147, 50.45374999727522, 50.234489168439595, 57.511059624808176, 61.07955714634487, 60.67159366607666, 63.433252470833914, 63.640294892447336, 66.52039963858468, 68.02703312465123, 66.27501010894775, 62.94703837803432, 61.99163327898298, 58.33711011069161, 57.269376959119526, 59.85554163796561, 62.63616207667759, 64.74729578835624, 43.95712178094046, 60.657141413007466, 63.15183653150286, 62.03287778581892, 64.5447141102382, 59.152905055454795, 63.18504197256905, 64.65669127873012, 64.67365183149064, 63.0985438483102, 62.2154278073992, 60.5360551561628, 59.311365672520225, 62.100970132010325, 64.72298404148647, 61.43687520708357, 53.161928517477854, 47.600868293217246, 55.49691581726074, 60.58031518118722, 50.157836641584126, 45.498454570770264, 44.53091791697911, 46.00817789350237, 48.10420969554356, 46.55415344238281, 45.03482559749058, 46.375713280269075, 47.663888454437256, 48.476806844983784, 47.218380383082796, 48.86398826326643, 49.30516760689871, 48.946049962724956, 50.00503880637032, 51.711116858891074, 53.10129158837454, 55.77480901990618, 55.93285969325474, 53.410086904253276, 55.443366050720215, 57.1502605165754, 58.681587900434224, 61.2418601172311, 61.55491815294538, 61.412021500723704, 67.65478338514055, 69.05606828417096, 65.37450272696358, 86.15184688568115, 13.87609280858721, 1.7559782777513777, 0.7872319317289761, 1.1356904421533858, 0.25553650515420095, 0.8104120450360435, 0.03385390341281891, 0.17875342816114426, 10.148590104920522, 27.317638329097203, 33.63248429979597, 52.533793994358604, 24.053084543773107, 27.957067149026052, 52.05017505373274, 55.721151556287495, 55.49716942650931, 70.19794913700649, 31.28175585610526, 0.42483264793242725, 0.03634254255199006, 0.05252100906467863, 0.052202053501137664, 0.07421084573226315, 0.03286318461011563, 0.10394694403346096, 0.10868259599166256, 0.033972219564020634, 0.04923600051552057, 0.05577112055782761, 0.08694471565208264, 0.021808393698717867, 0.017639459277104055, 0.013483196496963501, 0.029687233601829836, 0.07611075735517911, 0.037063611538282464, 0.038956110166119676, 0.02276868699118495, 0.10719868740332977, 0.033087484538555145, 0.03576821354883058, 0.05368179249178086, 0.0849827994991626, 0.06964388436504773, 0.07784083166292735, 0.04015660146251321, 0.13558775798550673, 0.05422424731243934, 0.10357437402542148, 0.06454257667064667, 0.071463504939207, 0.047766819529767544, 0.058277086088699956, 0.22843692930681364, 70.29126344408307, 83.29666532788957, 84.99580560411725, 64.43731580461774, 63.56151621682303, 30.19210113797869, 66.50457859039307, 72.80987426212856, 42.729965686798096, 12.746717844690595, 0.4308983167367322, 0.979494177869388, 1.8479129331452506, 2.257514451231275, 3.6524287206786017, 0.8184632701533181, 0.4870442939656121, 3.9401722976139615, 77.5717943736485, 87.11435999189104, 80.93140125274658, 85.80098370143345, 87.70892429351807, 86.74154050009591, 83.74827044350761, 79.8180844443185, 81.4594851902553, 83.49266706194196, 82.58400249481201, 80.54431016104562, 77.87176895141602, 75.89798028128487, 69.21566145760673, 67.11508900778634, 60.11626584189278, 55.430588313511436, 54.58274827684675, 56.571055207933696, 55.87190662111555, 55.00932250704084, 54.06448909214565, 54.49594095775059, 52.78161539350237, 55.411800384521484, 52.99285452706473, 54.51882484980992, 54.665845257895334, 51.313881397247314, 52.13331372397286, 52.2732469694955, 56.286307607378276, 52.164316586085725, 53.176721232278005, 55.09967688151768, 51.748935903821675, 52.58386271340506, 60.54593549455915, 65.02459144592285, 63.538246699741904, 65.71542998722622, 67.35175159999302, 68.08002703530448, 70.1220817565918, 69.1256822858538, 67.16888890947614, 65.83120782034737, 60.17183058602469, 60.49317782265799, 62.12077249799456, 66.25194208962577, 66.92649405343192, 46.49738665989467, 64.36972372872489, 65.19949150085449, 65.43325669424874, 66.77072238922119, 63.69016906193325, 65.23309993743896, 68.16231455121721, 66.70140716007778, 66.45350933074951, 63.32900169917515, 62.86029706682478, 63.0233712877546, 64.95494270324707, 66.06195749555314, 62.897588048662456, 55.43210302080427, 49.09314680099487, 58.25259917122977, 63.24717971256801, 53.93223360606602, 47.53025375093733, 47.671889305114746, 49.25862857273647, 49.87103584834507, 49.53008426938738, 49.74580846514021, 49.804312297276084, 49.93153381347656, 51.04659809385027, 51.05365398951939, 52.255727086748394, 52.92181614467076, 52.841415064675466, 53.3355153628758, 54.42965514319283, 55.87315034866333, 59.55836023603167, 60.19790717533657, 56.3362477847508, 59.35385390690395, 59.54670810699463, 61.17411518096924, 63.920745032174246, 63.60110010419573, 64.49677848815918, 70.61158234732491, 73.14882823399135, 65.9187342779977, 91.55682972499302, 22.759276117597306, 0.74231725611857, 0.27819325083068436, 1.0692283170563834, 1.3789391666650772, 1.5622765059982027, 0.33972991736871855, 0.30486486107110977, 12.847669959068298, 38.72551734106881, 32.69779525484358, 37.275615896497456, 28.65077703339713, 41.73599113736834, 60.285378047398154, 63.42199638911656, 60.925661495753694, 76.36598314557756, 46.8212456703186, 0.31998609538589207, 0.06711242627352476, 0.05837782818291869, 0.06527159469468252, 0.03843532096860664, 0.03264211450836488, 0.06131824611553124, 0.04854862079290407, 0.05311490701777594, 0.03145702595689467, 0.013959138770587742, 0.033359756892813106, 0.02027047541923821, 0.037310608463095765, 0.0313206573815218, 0.051878297302339754, 0.08370153539414917, 0.05751636690859284, 0.07390952868653194, 0.08187347384435789, 0.23079179865973337, 0.09630186962229864, 0.0643010385600584, 0.13370634322719915, 0.22639546170830727, 0.16478833609393664, 0.1579837290836232, 0.14861463968242916, 0.17560734626437935, 0.16899675955729826, 0.19804041965731553, 0.16930808499455452, 0.13776972304497445, 0.1177814384656293, 0.15197382228715078, 0.3094625329332692, 82.98155757359096, 95.7526662009103, 97.56272751944405, 74.06544154030937, 70.9646828515189, 27.019498075757706, 80.70955221993583, 90.25372982025146, 59.97657230922154, 18.100804260798864, 0.6682336628437042, 1.0776761323213577, 3.7281128423554555, 3.579731021608625, 8.267803941454206, 5.698540755680629, 2.9774896119322096, 3.375777291400092, 80.66221414293561, 91.01731600080217, 84.54609734671456, 90.54370594024658, 91.81810283660889, 90.30040087018693, 88.18040820530483, 84.08236762455532, 83.50219304221017, 86.67344120570591, 84.50983469826835, 83.76384135654995, 80.67724309648786, 79.69558075496128, 72.41930212293352, 69.84240981510708, 62.182847704206196, 59.780077253069194, 57.369156564985005, 60.22672830309187, 59.65250137874058, 58.51453930991036, 57.3261923789978, 56.704391138894216, 56.359538146427695, 59.1251608984811, 56.35891628265381, 57.92084353310721, 58.07321058000837, 54.85702494212559, 54.31960262571062, 55.80258444377354, 60.204841477530344, 57.06606224605015, 55.62289708001273, 58.30472455705915, 53.953418663569856, 55.17409208842686, 64.17954458509172, 67.3895011629377, 67.46909972599575, 70.29561996459961, 70.19617734636579, 72.10192230769566, 72.21783215659005, 70.74649551936558, 70.39076859610421, 68.6626056943621, 64.32226753234863, 64.7445512499128, 66.15466730935233, 68.46057987213135, 70.1488253729684, 51.29804992675781, 66.26321901593889, 68.706942149571, 67.42759813581193, 70.92502253396171, 66.26348304748535, 69.32933398655483, 70.75512518201555, 70.62149742671421, 67.49043069566999, 65.80257429395402, 67.16043989998954, 66.4174690246582, 67.12399659837995, 68.53022166660854, 68.73411655426025, 59.239688055855886, 52.24038199016026, 59.76698684692383, 65.70197827475411, 55.96850047792707, 50.19553756713867, 50.91183430807931, 52.33438416889736, 53.17592913763863, 54.06226914269583, 53.60593925203596, 52.956671782902305, 54.20382826668875, 54.676743507385254, 53.23055240086147, 55.72057832990374, 55.164114475250244, 56.28066219602312, 57.513046809605186, 56.96032108579363, 58.97919314248221, 65.23099463326591, 63.73481123788016, 60.347515787397114, 62.44904708862305, 62.49462032318115, 64.1243758882795, 68.44682243892125, 68.13213157653809, 68.91017695835659, 74.08896119253976, 76.47500732966832, 70.38320895603725, 98.16098826272147, 16.752393415996007, 3.330707149846213, 6.665166326931544, 2.269383494343076, 1.9237216881343295, 2.1308943884713307, 0.32951006719044273, 0.31557284934180124, 18.28294607571193, 46.37975018365042, 44.7389817237854, 71.63887350899833, 33.54720211029053, 41.03792299543108, 67.45665550231934, 70.70457703726632, 71.22751235961914, 87.74214363098145, 47.433979511260986, 0.533737491284098, 0.16455297943736824, 0.16406041729663098, 0.12643337063491344, 0.1056224030575582, 0.10316715123397963, 0.19969860996518815, 0.14154640824667045, 0.17824489330606802, 0.14070364061210835, 0.09977296979299613, 0.16062720652137483, 0.14749888383916446, 0.0757431202967252, 0.14251908819590295, 0.09766264446079731, 0.1355187374034098, 0.18177736018385204, 0.12966899201273918], [0.04198392680180924, 0.035335423557886055, 0.06816773821732827, 0.055588313045778444, 0.077251625779484, 0.07595410397542374, 0.02509106299839914, 0.07438780766512666, 0.15704515230442795, 0.017961458070203662, 0.0853433051545705, 0.03511447219976357, 0.34173091713871273, 0.05563752040533083, 0.22451848456902163, 0.281233549118042, 8.249430298805237, 79.0315831048148, 73.83672073909214, 71.74813393184117, 56.210648672921316, 42.226294245038716, 37.63899973460606, 43.878680092947825, 20.26248264312744, 27.055772883551462, 0.7754755797130721, 0.0822413619607687, 0.7092544159718922, 0.5764790635023798, 1.8842337727546692, 1.7521326669624873, 0.6404287634151322, 0.27795684923018726, 31.68643978663853, 92.94880403791154, 77.9730042048863, 78.39230019705636, 74.52341120583671, 83.29353169032505, 79.53282615116665, 92.9821970803397, 81.21174022129604, 83.2363202231271, 79.6833449772426, 77.57238497052873, 77.27159745352608, 76.48012120383126, 67.77382687159947, 65.93215819767543, 61.29902989523751, 60.117245537894114, 54.210852895464214, 53.13941287994385, 53.228738921029226, 52.96940088272095, 53.46113531930106, 50.92673124585833, 51.04732765470232, 51.074950218200684, 50.48021221160889, 51.37520619801113, 49.23120403289795, 50.12704917362758, 51.38275194168091, 50.53034346444266, 51.32509926387242, 52.44873762130737, 48.655253955296104, 52.70595645904541, 50.371795994894846, 50.29097802298409, 62.33904320853097, 68.04942716870988, 64.83968598502022, 62.68013027736119, 60.756910596575054, 63.87326799120222, 65.0110285622733, 61.76385048457554, 64.05849306924003, 69.58154664720807, 64.78612232208252, 61.860993249075754, 62.99072865077427, 56.894278458186555, 61.17249625069754, 60.52739770071847, 47.108275754111155, 60.95653929029192, 62.25015490395682, 62.76329326629639, 62.896705627441406, 61.39578356061663, 58.34930419921875, 63.23041370936802, 63.587599754333496, 62.05572346278599, 59.87809549059187, 59.01660224369594, 58.8895822252546, 62.19243621826172, 63.234978675842285, 59.33230059487479, 51.22267934254238, 47.97792271205357, 49.82703638076782, 55.77114731924874, 55.47899293899536, 48.70484324863979, 45.98608609608242, 44.5989477293832, 45.072912148066926, 47.22886174065726, 47.889656271253315, 47.07404892785208, 46.32599197115217, 46.670949186597554, 49.535938126700266, 48.82372692653111, 48.35956294195992, 47.00602606364659, 48.272005217415945, 51.011495794568745, 52.95810311181204, 54.60879707336426, 54.470878805433, 53.72013636997768, 54.029487541743684, 52.50326360974993, 53.15944801058088, 54.00592620032174, 52.9000300679888, 53.0548220361982, 58.43720585959298, 64.91044643947056, 73.29268373761857, 65.54332310812813, 80.900648525783, 8.464945180075508, 1.4247737186295646, 0.8306134981768472, 0.9696345755032131, 1.6761397847107478, 0.2271229869553021, 0.0605571876679148, 0.8978752632226262, 21.461330039160593, 24.146529129573278, 53.77447823115757, 42.18316330228533, 18.602971417563303, 40.173084190913606, 49.7463504246303, 56.50619724818638, 53.52327305930001, 66.01186793191093, 5.836338298661368, 0.3295890486666134, 0.03494517771261079, 0.19594131729432515, 0.05540070150579725, 0.05811117070594004, 0.010550493507512977, 0.03321673867425748, 0.030747329217514822, 0.028557615288134133, 0.0607613113575748, 0.01983602132116045, 0.13167095530245984, 0.01731192703092737, 0.016441146078120385, 0.01013923597721649, 0.05312640479366694, 0.038896731566637754, 0.05960335063615015, 0.014122351039467114, 0.055592408004615984, 0.11455249387238707, 0.013668420441847826, 0.06351532893521444, 0.038997514372957606, 0.0668187156053526, 0.052157307509332895, 0.07633694021829537, 0.025677320647186468, 0.11970230324992112, 0.08528231842709438, 0.27250302902289797, 0.17382625969392912, 0.38862406515649384, 0.35163975400584085, 15.105979544775826, 98.08157730102539, 79.53932271684918, 82.56012153625488, 64.34285504477364, 63.53983088902065, 38.58597319466727, 28.276201384408132, 24.797535385404313, 32.24266740253994, 0.6828820396746907, 0.14442802433456692, 1.9872269204684665, 2.858430926288877, 2.868799375636237, 1.863967397383281, 0.21332370170525142, 0.2094112280756235, 38.16879292896816, 96.88053253718785, 81.56666115352085, 81.15123530796596, 76.44342776707241, 85.27258709498814, 82.93659578050885, 96.61421503339494, 81.36951296670097, 83.06608935764858, 81.39088562556675, 80.94704164777482, 79.26755087716239, 79.73569965362549, 70.88539695739746, 68.48223740713937, 64.94304043906075, 62.65046146937779, 55.95944697516305, 56.54128565107073, 56.50035728727068, 55.77970402581351, 55.77446508407593, 54.18981722423008, 53.87532785960606, 53.99704640252249, 54.15861633845738, 54.12227725982666, 53.011152608054026, 51.70057644162859, 53.50881038393293, 54.32428571156093, 54.76235226222447, 55.59226942062378, 52.54400437218802, 56.393049308231895, 53.55125345502581, 52.616213526044575, 66.844345501491, 68.61653913770402, 67.45410551343645, 65.78488418034145, 64.86897264208112, 66.87230505262102, 67.04399503980363, 63.6356326511928, 65.9608542578561, 70.84275586264474, 65.67003045763288, 65.11824621473039, 64.40106010437012, 60.75028201511928, 63.65863118852888, 63.113663128444124, 48.768662452697754, 63.893313544137136, 64.49578489576066, 65.64484323774064, 63.710284096854075, 62.35513523646763, 58.99878706250872, 65.54938888549805, 64.84813499450684, 63.543367522103445, 62.229407582964214, 61.776718548366, 60.46461377825056, 65.09463623591832, 64.78769261496407, 63.72858565194266, 53.44444227218628, 49.690924644470215, 53.24911798749651, 55.9446507862636, 58.23906755447388, 49.96809523446219, 47.533456870487754, 47.04961906160627, 49.530987535204204, 49.719975062779014, 50.14773743493216, 47.4872339793614, 51.24414232798985, 49.2915734563555, 49.70678390775408, 51.41299397604806, 50.8883181299482, 50.05791112354824, 52.89455141339983, 52.59051561355591, 55.39859185900007, 55.41339847019741, 56.77951158796038, 56.252032143729075, 57.02080168042864, 54.98339877809797, 55.74995183944702, 55.430984360831125, 54.09654113224575, 55.778776441301616, 60.9025239944458, 65.44995321546281, 79.26181166512626, 65.1675923211234, 86.14098685128349, 14.955879347664968, 0.8916918007390839, 0.33620756066271235, 1.7541725060769489, 3.1419914705412726, 0.933590252484594, 0.23691036605409213, 0.7416063685502324, 31.563133580344065, 35.11727959769112, 49.980688844408306, 35.76387201036726, 31.190150805882045, 58.53677354540144, 53.07955067498343, 63.40693269457136, 59.3102331161499, 78.76448045458112, 14.05911009652274, 0.61784956072058, 0.10922600076134716, 0.1956990124391658, 0.06069940860782351, 0.04428411641025117, 0.1318785191646644, 0.05756444790001426, 0.033738019809659035, 0.02093640834625278, 0.05078548612073064, 0.043873283812510114, 0.0764378315902182, 0.07880851080907242, 0.0382624438165554, 0.04621620077107634, 0.03218024250652109, 0.08103525917977095, 0.0670974510056632, 0.15529203494744642, 0.10146384513271706, 0.21545838644461973, 0.1460786150502307, 0.08579826966992446, 0.18035049603453704, 0.20452834080372537, 0.1729448019926037, 0.17010377586952277, 0.1632130899067436, 0.23315494613988058, 0.18391550545181545, 0.4692927865045411, 0.3348630028111594, 0.5545923465064594, 0.6579600998333522, 16.039466551371984, 111.00644261496407, 91.43090752192906, 92.91468143463135, 75.34668936048234, 59.31185899462019, 52.597297055380686, 62.504611832754954, 34.37874514716012, 47.05233580725533, 1.2470239251852036, 0.23337880841323308, 2.807009914091655, 4.040378783430372, 6.351763052599771, 5.786373802593776, 4.640026995113917, 0.7373281781162534, 39.05195760726929, 103.52631078447614, 86.29879433768136, 84.12216690608433, 80.74311896732875, 90.42726108006069, 85.55512169429234, 99.41396386282784, 82.98326683044434, 87.66412925720215, 84.67659146445138, 83.5535054888044, 83.10025365012032, 83.12332861764091, 76.32024315425328, 72.29183741978237, 68.11017526899064, 65.29498754228864, 59.765020506722585, 59.5255161012922, 59.684011459350586, 60.445547921316965, 59.142830167497905, 58.61938067844936, 57.599579674857004, 58.168380056108745, 57.354054655347554, 58.25816467830113, 55.67327846799578, 55.031414304460796, 58.27833529881069, 57.15983860833304, 56.32365070070539, 58.91327558244978, 54.633285999298096, 59.30859334128243, 55.31520652770996, 55.11287151064192, 68.32675756726945, 73.81063720158168, 70.9653012411935, 71.23817784445626, 67.83523505074638, 71.05904633658272, 70.07523005349296, 68.22558484758649, 71.14305700574602, 75.06871277945382, 70.08509649549211, 68.14836951664516, 68.05784143720354, 64.01097433907645, 66.34051077706474, 67.45294516427177, 51.45444345474243, 65.83536979130336, 69.18520750318254, 67.22776099613735, 67.99012429373605, 64.56579494476318, 62.94268880571638, 67.56110082353864, 71.02200548989433, 66.13061264583042, 63.510592869349885, 62.69904327392578, 63.75283486502511, 66.69512598855155, 69.26088728223527, 65.7743924004691, 57.73512513296944, 53.707327365875244, 54.967039244515554, 59.52514089856829, 60.908958026341026, 53.45260293143136, 51.18333516802107, 51.650413921901155, 51.89511905397688, 53.525482586451936, 54.82657446180071, 50.972349643707275, 53.038677896772114, 52.64688982282366, 54.028143065316335, 54.29250117710659, 54.53972155707223, 53.865642070770264, 55.463397707257954, 57.005831786564414, 59.54315757751465, 59.072444915771484, 61.098984309605186, 59.753020967756, 59.53839111328125, 59.06696278708321, 60.29951763153076, 59.329563004629954, 58.02730730601719, 58.59347084590367, 67.3895081111363, 70.89818164280483, 83.21526718139648, 68.97627517155239, 90.59478214808873, 11.460457767759051, 3.200450139386313, 6.141011161463601, 2.808304016079221, 6.78909352847508, 1.435818531683513, 0.2547314097838742, 1.5793769998209817, 38.65040731430054, 38.69108901705061, 74.78744275229317, 57.41400718688965, 26.920950038092478, 58.048395088740754, 63.866361481802805, 73.5655881336757, 67.51880713871547, 89.75594002859933, 12.52174733366285, 0.8859239816665649, 0.205552073727761, 0.2473421362893922, 0.1367190522806985, 0.10953243396111897, 0.2018139971686261, 0.0873187037983111, 0.09659716806241445, 0.17267409366156372, 0.15471623013062136, 0.2598200967269284, 0.2645308125231947, 0.13971775637141295, 0.25560981407761574, 0.1858834469957011, 0.19557878960456165, 0.2586639001965523, 0.14083641634455749], [0.0526065214404038, 0.04762800144297736, 0.08558046671428851, 0.04612205403723887, 0.038543255534023046, 0.034744918279881985, 0.07561896195901291, 0.00810436628359769, 0.11349950930369751, 0.07817190925457648, 0.18964314168053015, 0.027091089070641568, 0.1526545286178589, 0.03751664901418345, 0.3147798047534057, 0.26038653776049614, 37.826896395002095, 84.62335436684745, 73.05246366773332, 69.40295015062604, 63.09649412972586, 22.759314332689556, 38.07350185939244, 62.07569258553641, 39.77621350969587, 13.825350982802254, 0.06948277979557003, 0.24745784008077212, 2.433590054512024, 1.335201342191015, 2.405901917389461, 2.4443932005337308, 0.5810580892222268, 6.086628045354571, 75.02219458988735, 86.94667216709682, 76.87289592197963, 73.36452811104911, 66.28408445630754, 77.07711737496513, 75.80947412763322, 80.71023314339774, 76.7749332700457, 78.54357637677873, 75.74972656794957, 76.36049406869071, 72.80825533185686, 67.37626484462193, 60.64921351841518, 62.1609400340489, 61.89606775556292, 61.98664447239467, 52.460890020642964, 53.58408716746739, 52.96899093900408, 52.41488599777222, 51.790996823992046, 52.842245374407085, 50.574725082942415, 51.639790126255576, 50.55482196807861, 48.94252722603934, 49.768734046391074, 49.69063976832798, 46.41523115975516, 51.53925664084298, 52.33645473207746, 50.805870805467876, 50.562204429081504, 53.38181121008736, 46.703894070216585, 53.568512780325754, 63.388763155256, 66.93617289406913, 66.12583228519985, 65.65884385790143, 63.684756415230886, 67.65251132420131, 61.99642058781215, 58.943389075142996, 55.35550955363682, 64.94248458317348, 61.02198437282017, 61.80919442858015, 63.02761663709368, 59.22194235665457, 60.742986406598774, 59.61573151179722, 41.414598737444194, 57.97224630628313, 55.358490330832346, 60.14799131665911, 56.80725227083479, 59.02712876456124, 59.914545740400044, 59.70431409563337, 59.33194623674665, 58.973863874162944, 58.73352568490164, 60.79955169132778, 61.76598358154297, 63.80975450788225, 60.089959962027415, 60.004851477486746, 51.73205178124564, 50.06559930528913, 59.01412868499756, 61.47315870012556, 53.57265738078526, 52.07699857439314, 46.41954599108015, 44.930588722229004, 43.27322449002947, 44.10514620372227, 45.128025259290425, 47.101904256003245, 46.51392337254116, 47.224244662693565, 48.36255761555263, 49.33292218617031, 49.00805916104998, 47.02678380693708, 47.27324683325631, 49.61692632947649, 51.733378887176514, 51.65972450801304, 53.156630516052246, 53.068166051592144, 52.58620425633022, 51.15881150109427, 51.06465993608747, 51.22271408353533, 52.778968129839214, 54.05158976146153, 56.802155767168315, 58.774054527282715, 63.87421989440918, 73.03477355412075, 69.49156747545514, 67.78495788574219, 1.9746539379869188, 0.694389993590968, 2.018865325621196, 0.9931798492159162, 0.9483286844832557, 0.03739592745634062, 0.3309609650501183, 11.561227491923741, 23.261804580688477, 33.72199099404471, 66.62531743730817, 30.90053251811436, 13.36048436164856, 27.97118067741394, 45.14390189307076, 55.524795464106965, 61.1400968006679, 46.992046288081575, 0.28696942276188303, 0.045087074395269156, 0.026016516910333718, 0.028107977272676568, 0.09385084507188626, 0.059716333502105305, 0.036997257598808835, 0.03290438525644796, 0.013169310438180608, 0.05001250242016145, 0.05219802978847708, 0.05129434327994074, 0.04831334895321301, 0.06774294815425362, 0.01231513069277363, 0.019753279064648917, 0.03037917647244675, 0.05577283725142479, 0.11260323918291501, 0.0799011489642518, 0.0466237187252513, 0.018200509349948595, 0.04100270409669195, 0.05256620288959571, 0.08743182237126998, 0.02298457987074341, 0.10982554751847472, 0.03229790047875472, 0.11975254198270184, 0.014750248686011349, 0.1612447276711464, 0.03406978611435209, 0.25511220363633974, 0.1611916119498866, 50.013446126665386, 92.76243250710624, 79.97300842830113, 78.94072846003941, 71.10539776938302, 34.61922924859183, 29.68048095703125, 54.04510709217617, 45.73054872240339, 15.972235781805855, 0.1572562445487295, 0.7188225196940559, 4.368596051420484, 2.622977537768228, 2.6085189878940582, 1.75017740045275, 0.5396448714392525, 8.16445209298815, 82.47772979736328, 88.2309980392456, 81.83823844364711, 77.06360312870571, 70.87071541377476, 79.29173755645752, 79.9695690699986, 82.40155669621059, 80.84632056100028, 80.76734038761684, 80.22068391527448, 79.90042754581997, 76.53540802001953, 69.86149651663644, 63.6021979195731, 65.17634010314941, 63.89021464756557, 65.245516368321, 55.63642174857003, 55.85990013395037, 57.03596959795271, 55.61491707393101, 54.15934589930943, 55.78415434701102, 53.69326768602644, 54.61560978208269, 53.135063307625906, 53.070792470659526, 51.83167505264282, 51.529452732631135, 48.84418937138149, 52.97278118133545, 54.93491077423096, 53.684043952396934, 53.118992124285015, 56.18266132899693, 49.51042434147426, 56.79070860998971, 66.9723938533238, 68.85871165139335, 67.7655863080706, 68.53543976375035, 67.28169291360038, 68.69807624816895, 66.1091079711914, 64.04701464516776, 60.549221992492676, 66.6489621571132, 64.76832103729248, 65.11687047140938, 64.80962807791573, 62.97499098096575, 63.070806639535085, 62.13427979605538, 43.47014338629586, 58.82144818987165, 58.02131795883179, 62.292024748665945, 57.26682349613735, 60.272843497140066, 63.91064235142299, 63.36507674625942, 61.11904375893729, 62.65831988198416, 62.242873191833496, 61.883081572396414, 62.692150660923545, 65.4329787663051, 63.58507061004639, 63.279155322483604, 55.01020840236119, 53.676706654684885, 62.00047833578927, 63.97261333465576, 56.07850783211844, 53.05586774008614, 48.96871846062796, 47.84722014835903, 46.51216547829764, 47.84517042977469, 47.33516223090035, 49.5933267729623, 48.80647454942976, 51.53551503590175, 50.25816168103899, 50.116769313812256, 51.083569458552766, 50.66207783562796, 50.33087805339268, 52.96558632169451, 54.00114236559187, 54.68381677355085, 56.61445713043213, 55.48161588396345, 54.67396770204817, 55.25093569074358, 54.57770388466971, 54.040396213531494, 54.49845967973982, 57.48784916741507, 59.907694816589355, 63.22693266187395, 65.41033458709717, 78.00788416181291, 70.85283769880022, 76.0356866291591, 4.805965176650456, 1.1224471756390162, 1.3721757467303957, 1.4793748344693864, 1.8419689663818903, 0.07932724404547896, 0.08765312656760216, 9.619643722261701, 36.576821667807444, 36.461839403424946, 56.22608062199184, 27.97503171648298, 25.20038672855922, 36.828794615609304, 51.59307738712856, 64.52286202566964, 64.68902124677385, 63.28627027784075, 1.4467857203313281, 0.19047604341592106, 0.02717747675654079, 0.06105976498552731, 0.07141999727381126, 0.05242899971614991, 0.012912854735207344, 0.01572334932695542, 0.09520006445901734, 0.05023290416491883, 0.07312988516475473, 0.05257131565096123, 0.02281139568159623, 0.01724923718055444, 0.006319622833481324, 0.028530012483575513, 0.0025706403082170126, 0.031043486004429202, 0.15774221132908547, 0.13760160920875414, 0.16705928423574992, 0.1404369899204799, 0.14115728198417596, 0.13271140732935496, 0.1374097873589822, 0.13421308674982615, 0.14042465415384087, 0.09230586833187512, 0.20722531394234725, 0.172057766733425, 0.3537760536585535, 0.1526493988931179, 0.4153933844396046, 0.36264420779688017, 55.81413582393101, 107.13769953591483, 93.30644866398403, 87.88426903315953, 80.55935301099504, 32.09449359348842, 53.70867184230259, 93.01737580980573, 57.1431177684239, 23.654184988566808, 0.4701831872974123, 0.786698223224708, 8.152806912149702, 4.437962089266096, 5.532559582165309, 7.89408118384225, 2.7650658105100905, 8.690946630069188, 85.41497652871269, 93.43917315346854, 84.26413249969482, 80.939377784729, 73.84416920798165, 82.99309853145054, 83.4688972745623, 86.44777761186872, 85.12826606205532, 84.43722602299282, 82.17084176199776, 83.86646624973842, 80.03478486197335, 72.96998855045864, 65.69781630379813, 68.72491713932583, 66.58949947357178, 69.19927065713065, 57.36613062449864, 59.448363304138184, 59.020263944353374, 58.17744050707136, 58.59851523808071, 59.829874992370605, 57.5304867880685, 58.64765984671456, 55.75915820258004, 54.45683997017996, 55.63546984536307, 55.799555029187886, 51.0547969681876, 57.29380335126604, 56.68099308013916, 55.483530112675254, 56.08099181311471, 59.5718605858939, 51.25788239070347, 60.48036534445626, 71.227158001491, 72.2851949419294, 71.25679901668003, 70.30105345589774, 68.92288521357945, 72.38068403516496, 70.11725970676967, 66.51921844482422, 62.847491536821636, 68.02968733651298, 68.00197792053223, 69.5193533216204, 68.4251093183245, 65.08629839760917, 64.6834557397025, 65.11113125937325, 46.89067554473877, 61.374772208077566, 60.53993225097656, 64.85488169533866, 58.96012033735003, 59.69834559304373, 64.38323102678571, 65.41024426051548, 63.81563268389021, 64.70267445700509, 65.40028054373605, 67.05042907169887, 65.62144865308488, 68.58949674878801, 67.24527740478516, 66.23550959995815, 57.32205472673689, 55.95588949748448, 63.468438148498535, 65.97338185991559, 59.40468692779541, 56.965445382254465, 51.801387854984824, 51.53345489501953, 48.23393603733608, 49.29161514554705, 50.928537777491975, 53.34036520549229, 51.11148732049124, 52.97947577067784, 53.48474529811314, 54.649534361703054, 55.20715856552124, 54.11967863355364, 52.55049051557268, 56.42472614560808, 58.601787839617046, 57.7863507270813, 61.52713925497872, 59.89133875710623, 58.71045766557966, 58.08011014120919, 57.732932976314, 57.69490895952497, 59.02730941772461, 60.36453192574637, 64.18458897726876, 65.80975873129708, 69.45356777736119, 82.91492434910366, 75.22786126817975, 78.16986751556396, 3.602183473961694, 5.316914422171457, 9.123088104384285, 2.735457582133157, 3.468400469848088, 0.17317781091800757, 0.8745557516813278, 16.757674046925136, 41.85476016998291, 46.771639006478445, 84.4628301348005, 41.04185220173427, 23.485965626580374, 42.84621252332415, 62.54362596784319, 71.94143281664167, 75.05857535770961, 65.21106025150844, 0.8337357363530568, 0.19658125724111283, 0.13704955311758177, 0.11320590720112834, 0.11514531634747982, 0.08924539041306291, 0.10440614939268146, 0.11215630173683167, 0.25940410047769547, 0.1522743318762098, 0.20070604447807583, 0.10498002038470336, 0.12635033151933125, 0.18751186318695545, 0.13398912948157105, 0.1056151155914579, 0.11923633968191487, 0.1352572842900242], [0.009787830324577433, 0.019488373904355934, 0.02340191961931331, 0.05456662251214896, 0.027288654719346335, 0.07315600197762251, 0.021831443533301353, 0.058775375064994605, 0.011426427085617823, 0.017317850641640167, 0.014907577208110263, 0.10507196866508041, 0.028665064701012204, 0.06963138575000422, 0.08938268518873624, 1.199379910315786, 64.76119913373674, 70.5652448109218, 65.32680334363664, 58.01855604989188, 56.58893639700753, 42.642883913857595, 56.33564676557268, 33.18669135229928, 25.162369659968785, 2.459742856877191, 0.10539586057088204, 0.033130177961928506, 1.924821891954967, 2.0517604861940657, 1.1749514554228102, 0.35494975639241083, 0.28430755702512606, 36.01413222721645, 88.8312737601144, 78.30516978672573, 78.79881845201764, 70.60755239214215, 66.57926477704729, 63.08111081804548, 66.84914670671735, 69.0259895324707, 72.06005246298653, 71.3758772441319, 71.68786525726318, 68.18864127567836, 62.26773384639195, 58.08168738228934, 60.49013451167515, 61.28337560381208, 62.517174175807405, 60.166501317705425, 56.49447563716343, 52.189323152814595, 52.34063754762922, 51.19963564191546, 51.624104567936485, 50.32144587380545, 51.75771842684065, 50.729530947549, 50.98354319163731, 49.56486347743443, 48.51807219641549, 48.64868443352835, 48.3076286315918, 49.927514280591694, 49.68562316894531, 49.27246938432966, 51.67248140062605, 51.6557605607169, 48.56494127001081, 52.04389040810721, 60.40491485595703, 64.57382706233433, 65.34230477469308, 64.19180815560478, 60.79098456246512, 60.68503148215157, 63.21159103938511, 64.40396445138114, 60.7044586454119, 58.42423357282366, 59.6581711087908, 56.0534074647086, 63.91842433384487, 58.16911309106009, 62.74763897487095, 58.783281735011506, 42.408104283469065, 58.208630970546174, 54.036915166037424, 54.79351840700422, 60.69852488381522, 62.85554449898856, 57.38652011326381, 59.79480743408203, 53.954645020621165, 53.345343589782715, 53.832165649959016, 58.55449840000698, 58.60984774998256, 57.43757547651018, 60.57893248966762, 60.917712756565635, 54.12356267656599, 53.55824334280831, 61.33340263366699, 71.98819419315883, 60.74065181187221, 50.46061829158238, 49.29051733016968, 45.352410384586875, 44.152991499219624, 41.37860706874302, 45.318951334272114, 47.839087281908306, 49.19455575942993, 47.91351638521467, 47.066086292266846, 47.07517106192452, 48.130060468401226, 47.436060496738975, 47.511934825352256, 47.14961406162807, 48.397107533046174, 49.72808361053467, 49.22380072729928, 50.60968494415283, 48.23661804199219, 48.31105409349714, 48.334698813302175, 48.219594955444336, 50.81481661115374, 52.24347046443394, 52.45974704197475, 58.468083654131206, 59.87260641370501, 65.0946431841169, 67.78238705226353, 70.98638207571847, 43.38285664149693, 0.10727673928652491, 1.441256582736969, 1.7750081994703837, 0.8001412504485675, 0.1448231352759259, 0.07807221210428647, 5.317912357194083, 21.50864553451538, 21.618265526635305, 57.54334790366036, 72.06374890463692, 22.071004935673304, 22.202042749949864, 44.20375851222447, 56.73073870795113, 56.722209794180735, 68.51865291595459, 26.756887435913086, 0.5089967474341393, 0.057677708965327056, 0.09220412879117898, 0.03236309073067137, 0.13092714521501744, 0.032119479695601125, 0.06745807879737445, 0.025466572759406905, 0.08572800736874342, 0.0923306280747056, 0.08305969554930925, 0.04001852637156844, 0.07072667019175631, 0.04253670892545155, 0.017536445786910396, 0.001050233215210028, 0.026784201252407262, 0.019397144871098653, 0.028841382025607994, 0.03450772279341306, 0.011958962572472436, 0.026632882854236022, 0.12129421425717217, 0.041572707439107556, 0.037772236192332845, 0.03274950963844146, 0.03381694021767803, 0.021226129228515283, 0.026257868423791866, 0.043448249476828744, 0.07560893321143729, 0.048488149752042124, 2.5466220464025224, 81.93920271737235, 78.52459389822823, 75.72066920144218, 63.001380239214214, 71.00766440800258, 38.875563689640586, 27.66811067717416, 37.19444356645857, 31.291507652827672, 2.3224564407552992, 0.2429843129856246, 0.679557272366115, 4.82039224249976, 3.3960864416190555, 5.785230389663151, 0.31912185890333994, 0.26699031197599, 41.616346631731304, 90.6360752923148, 80.00491455623082, 80.56726006099156, 73.16478824615479, 68.98059000287736, 65.51470347813198, 69.7066628592355, 73.31400775909424, 75.75880091530937, 75.60446752820695, 73.39192485809326, 70.59373937334333, 65.92541149684361, 60.80383178165981, 61.274586132594514, 64.70443929944719, 65.14295400891984, 63.28111471448626, 59.69458661760603, 54.76895652498518, 54.38022913251604, 55.117707456861226, 54.567017555236816, 54.93547010421753, 54.285313265664236, 54.37214837755476, 52.679421288626536, 51.59618323189871, 51.2933737891061, 51.04485409600394, 52.51715305873326, 53.30090985979353, 51.541622502463206, 52.990912505558555, 53.07924148014614, 53.88063628332955, 52.17664269038609, 54.087869780404226, 62.13538455963135, 67.62616375514439, 66.28675256456647, 65.44603443145752, 64.72028814043317, 63.070806639535085, 65.09336471557617, 64.84548773084367, 64.33744934626988, 62.86677278791155, 61.60260363987514, 59.10710253034319, 66.47789055960519, 61.082426752362935, 67.2404761995588, 59.77316379547119, 43.67072745731899, 58.77920314243862, 54.550585065569194, 57.5501571382795, 62.7911833354405, 65.03391592843192, 62.499914850507466, 61.00407886505127, 57.18765919549124, 56.30686732700893, 56.64805861881801, 60.50212015424456, 61.46283367701939, 60.35222666604178, 63.28784057072231, 63.88176563807896, 57.226694175175254, 56.73885072980608, 64.80151258196149, 72.81231307983398, 65.65457766396659, 53.234551089150564, 52.81757926940918, 46.574417863573345, 46.59002699170794, 45.81033836092268, 47.77486160823277, 48.16699014391218, 51.69717182431902, 49.450211252485005, 49.1128762108939, 50.10042715072632, 50.79658453805106, 50.22316707883562, 49.87094552176339, 50.239206995282856, 49.551012243543354, 51.74470097678048, 49.88892051151821, 52.54420934404646, 50.94557476043701, 52.14054332460676, 50.883218152182444, 52.226332732609336, 52.82256807599749, 52.24936948503767, 55.2356288092477, 59.46309348515102, 64.32778440202985, 66.20522240230015, 72.24157415117536, 71.92212377275739, 53.33693279538836, 0.21628322718398912, 0.5119676451597894, 2.185567591871534, 1.82535343510764, 0.7546563340084893, 0.019200423998492103, 1.4069902385984148, 21.42966709818159, 27.664176259722026, 50.466677120753694, 49.41245821544102, 20.314581973212107, 33.28658560344151, 51.69806466783796, 65.17455441611153, 63.245929036821636, 76.11047009059361, 44.51468692507063, 0.5073397106357983, 0.06166224979928561, 0.0974406006612948, 0.04309522806267653, 0.014779101691341825, 0.04877810472888606, 0.0373525080004973, 0.06401215227586882, 0.033455627105597935, 0.08374433059777532, 0.07690260093659163, 0.05270212363185627, 0.05494539433025888, 0.06987368381981339, 0.0028249736808772597, 0.014780192436384303, 0.041043741894619803, 0.13215525288666996, 0.12581078761390277, 0.15015673264861107, 0.12984782670225414, 0.23457514707531246, 0.22986817679234914, 0.12498452195099422, 0.07816814338522297, 0.11677327113492147, 0.10269233278398003, 0.1627805916858571, 0.15890040275241646, 0.09627340507826634, 0.1683545397328479, 0.16514694185129233, 2.913179474217551, 89.55155181884766, 90.66425718579973, 87.41176373617989, 74.12903145381382, 74.68244157518659, 54.71849523271833, 76.51307650974819, 48.11820336750576, 41.70167051042829, 4.002373005662646, 0.31756801371063503, 0.4063178428581783, 4.894023171492985, 7.470691834177289, 7.0733425957815985, 3.8448760168892995, 0.8900234731180328, 43.76962464196341, 96.60052013397217, 85.11895547594342, 85.17735508510044, 76.87859344482422, 73.54433359418596, 68.91429724012102, 72.72554397583008, 77.1662071772984, 81.12244892120361, 79.42719963618687, 77.97034999302456, 76.42900330679757, 68.31789861406598, 64.06378064836774, 64.99085794176374, 67.04295975821358, 69.49035154070172, 65.49871567317417, 63.585188729422434, 58.77786908830915, 57.38563421794346, 56.563988889966694, 57.58800745010376, 56.89918736049107, 57.801765305655344, 56.558176721845356, 55.40607854298183, 54.40371751785278, 53.84084742409842, 53.25582299913679, 54.23942388807024, 55.619843346732004, 54.731908730098176, 55.018678256443565, 56.59614862714495, 56.273564611162456, 55.08835826601301, 57.40636764253889, 65.79905155726841, 71.00199467795235, 69.96191883087158, 69.4969731739589, 67.8299057824271, 68.20489311218262, 69.11818517957414, 68.05048329489571, 65.7963695526123, 63.7274044581822, 61.562491689409526, 63.09516702379499, 68.42091955457414, 65.7840017591204, 70.7757682800293, 64.9185688836234, 48.46784714290074, 62.975810868399485, 57.32566084180559, 59.176042556762695, 66.10361889430455, 67.27809374673026, 62.462825366428916, 65.83611324855259, 59.8613155909947, 59.90299783434187, 60.10831710270473, 63.70257159641811, 63.32018443516323, 63.259005546569824, 66.29742499760219, 68.07535089765275, 59.17387471880232, 60.39587524959019, 67.17054258074079, 75.90710326603481, 67.58285563332694, 55.744862283979145, 54.768088000161306, 50.38770042146955, 49.45461641039167, 48.037440981183735, 51.65195294788906, 51.86150714329311, 54.27587761197771, 52.69768810272217, 52.88733570916312, 53.68943575450352, 54.64463588169643, 53.200661250523154, 53.003381047930034, 53.20291941506522, 54.5531975882394, 55.6079341343471, 53.79294654301235, 57.4733795438494, 53.93178197315761, 56.508372034345356, 54.466838427952354, 54.62196043559483, 56.43690981183733, 57.16426113673619, 58.46755559103829, 65.06831645965576, 67.6049439566476, 69.68984821864537, 75.0275308064052, 77.76546151297433, 51.855430943625315, 0.3233358599245548, 5.679065389292581, 6.395441600254603, 2.4143329049859727, 1.133264000926699, 0.18064662228737557, 8.278050797326223, 31.29715653828212, 37.3758089201791, 71.63911669594901, 92.72589887891496, 29.396497658320836, 35.64850064686367, 59.40542343684605, 75.47778797149658, 71.45871366773332, 88.32683454241071, 42.82315840039934, 0.7853656347308839, 0.15745671093463898, 0.31749752749289784, 0.09793696259813649, 0.3128494811909539, 0.17031543808323996, 0.18452079940055097, 0.12118317878672055, 0.2129495982080698, 0.16368782014719077, 0.19636719301342964, 0.15742291989071028, 0.08663366162883383, 0.22375070862472057, 0.07617158123425075, 0.13678705506026745, 0.11066754840846572], [0.10208946120526109, 0.06914901520524706, 0.06398679542222194, 0.04604740161448717, 0.0027708147120262894, 0.12231806931751114, 0.021906484417351227, 0.050744061557842154, 0.07065515260079078, 0.05945868697017431, 0.051406308343367915, 0.1705619634262153, 0.14184796277965817, 0.24501685106328555, 0.22003682862435067, 19.15608102934701, 83.51963302067348, 66.45393317086356, 68.73754201616559, 55.27535513469151, 28.110929795673915, 39.708909784044536, 59.126682553972515, 35.932226862226216, 20.92762327194214, 0.15273190875138554, 0.4085565470159054, 1.0983258528368813, 2.2977321445941925, 3.767101355961391, 1.952128095286233, 0.33456732439143316, 4.989264300891331, 67.89609432220459, 85.91288443974086, 77.7945397240775, 75.34768990107945, 66.81830365317208, 64.34967817578996, 61.90382889338902, 60.86640725816999, 58.633464676993235, 58.186834471566335, 57.706203256334575, 58.53377192361014, 56.722140312194824, 58.61041750226702, 56.62253441129412, 63.052650996616904, 63.68433257511684, 63.84477342878069, 59.850712639944895, 57.06032998221261, 51.55426822389875, 53.49866253989083, 52.819556031908306, 52.1602657863072, 50.72351728166853, 52.90692615509033, 49.32629707881382, 49.059920515332905, 48.84974445615496, 48.313791683741975, 48.890207290649414, 49.12718949999128, 49.73045989445278, 51.795454093388145, 48.76919746398926, 51.485248293195454, 47.57198463167463, 46.369129862104145, 48.59420360837664, 56.619261809757774, 62.55686923435756, 62.333442960466655, 61.11994702475411, 63.70505210331508, 58.452818461826865, 60.78043024880545, 57.10674394880022, 65.51785101209367, 59.40975216456822, 64.94625745500836, 60.79450035095215, 64.31217874799455, 58.96517167772566, 63.85945497240339, 53.75151443481445, 38.2139527457101, 55.54691505432129, 56.62748152869088, 65.2466072354998, 58.340424401419504, 59.307141167776926, 54.33849130358015, 51.10959046227591, 49.89812340055193, 50.413228103092735, 52.17725413186209, 56.060265336717876, 58.47129372188023, 56.04064014979771, 59.58406857081822, 62.13532897404262, 54.44205072947911, 56.652602740696494, 59.536973680768696, 61.807860374450684, 59.981199809483115, 54.16083281380789, 53.81794616154262, 46.713308879307334, 46.49731370380947, 43.92848130634853, 43.27883516039167, 43.698669637952534, 49.077471664973665, 47.770915031433105, 47.43853752953665, 46.891356468200684, 47.512775557381765, 47.78232397351946, 47.64574670791626, 47.11335488728115, 47.49056911468506, 45.957296235220774, 46.30081517355782, 45.078887598855154, 46.28116914204189, 44.08897427150181, 46.561546325683594, 44.05310072217669, 47.78683682850429, 48.568543910980225, 51.515990597861155, 47.42325496673584, 55.54884317943028, 56.83253329140799, 67.82600784301758, 61.42976719992501, 76.46419593266079, 13.372211183820452, 1.5454421064683368, 0.5094694420695305, 2.0498314925602505, 0.19851941109767982, 0.15547287810061658, 0.4178580136171409, 20.329654353005544, 34.18615845271519, 27.550929307937622, 82.17225224631173, 73.5333971296038, 28.29433618273054, 43.65791845321655, 47.69165693010603, 51.331502028873985, 54.329938071114675, 63.50929355621338, 12.15211706502097, 0.43754570718322483, 0.08382343421024935, 0.06815359076218945, 0.0801464393734932, 0.08044645363198859, 0.03343014811564769, 0.08050205957676683, 0.04745023883879185, 0.05966282423053469, 0.019960271261100258, 0.026749333034136465, 0.03698817540758422, 0.0648855014837214, 0.04937510358701859, 0.014751687180250883, 0.07205739271427904, 0.05988503766379186, 0.01346993537819279, 0.024959744419902563, 0.05437552669484701, 0.030066968939666237, 0.12029443361929484, 0.031014773795115094, 0.011481267133993762, 0.02501554205082357, 0.11075334916157381, 0.06248369107821158, 0.1422809631164585, 0.13915734072881086, 0.2675858214497566, 0.41919746888535364, 28.235488414764404, 99.89353547777448, 71.77535697392055, 77.75528240203857, 61.669764927455354, 50.94369527271816, 41.78453820092337, 50.116578238351, 43.34292534419468, 23.399752378463745, 0.0790574313806636, 0.6739143580198288, 2.7415231423718587, 2.9299148619174957, 2.6542277123246873, 3.7029712200164795, 0.5997421209301267, 6.044168038027627, 73.88337789263043, 90.47311919076103, 80.97650895799909, 77.16171169281006, 70.14983980996269, 69.1431986945016, 63.690982001168386, 64.61639172690255, 61.06090818132673, 61.0925224849156, 59.46583802359444, 60.95844309670584, 58.75113936832973, 60.78322342463902, 61.95911570957729, 66.98780495779855, 65.49451201302665, 67.41387544359479, 63.52166829790388, 60.04060690743582, 53.46518611907959, 56.8526656968253, 55.07597310202462, 54.710511752537315, 53.58351394108364, 56.10907990591866, 51.573518208095, 52.959614345005576, 52.411575181143625, 52.26783779689244, 51.340541635240825, 53.03659691129412, 51.347368240356445, 54.408272062029155, 50.83887127467564, 54.435842514038086, 49.60572235924857, 49.30492441994803, 50.983855860573904, 59.74391187940325, 64.0754953111921, 64.96783855983189, 64.2449618748256, 66.23708684103829, 63.52295371464321, 62.22380038670131, 61.696890694754465, 67.66069630214146, 62.40561389923096, 67.92010034833635, 61.887292180742534, 67.66989571707589, 60.70654310498919, 66.20276273999895, 55.50771679197039, 40.82261221749442, 58.40837778363909, 60.119955335344585, 66.03019727979387, 62.266427585056846, 61.75685364859444, 56.324946539742605, 53.04988186700003, 50.999187060764854, 53.51618242263794, 55.28045163835798, 56.78088385718209, 61.35354546138218, 57.176875591278076, 62.70475469316755, 63.40286799839565, 54.726739270346506, 58.87850679670061, 61.932844570704866, 62.698522159031455, 64.10634531293596, 57.084982190813335, 57.47538757324219, 49.27648891721453, 48.47566039221627, 46.835753508976524, 46.1740209715707, 45.10606895174299, 51.16980355126517, 49.34212507520403, 48.55960505349295, 49.27484219414847, 50.190472330365864, 50.51956680842808, 50.76425109590803, 47.814931869506836, 49.62763697760445, 47.259722164699006, 49.47593695776803, 47.569181033543174, 49.12274612699236, 46.91350385120937, 49.79570695332119, 46.716859408787315, 50.49452897480556, 52.15370668683733, 53.74757828031267, 50.743948459625244, 58.26775666645595, 58.497300829206196, 72.01729324885777, 64.88861519949776, 81.08324718475342, 18.906018836157664, 0.7420638097184045, 1.3538542155708586, 2.2022636788231984, 0.8338789886661938, 0.1847039224313838, 0.11390618926712445, 15.68996000289917, 42.9411735534668, 31.232593876974924, 68.80023561205182, 62.73397881644112, 41.93819761276245, 56.745190961020334, 55.864176750183105, 54.77088117599487, 60.91590622493199, 71.90329415457589, 26.586191041128977, 0.3631554160799299, 0.024555707350373268, 0.07736526682440724, 0.034581147067781, 0.10221358561622244, 0.039444115944206715, 0.08982847591063806, 0.047834299837372134, 0.04877704960693206, 0.11233270727097988, 0.05898555128702095, 0.08286642841994762, 0.08274786799613919, 0.018819526669436266, 0.02171725796402565, 0.04609943846506732, 0.14830199788723672, 0.11695420928299427, 0.1187994038420064, 0.1841533998293536, 0.12197578911270414, 0.3247082919946739, 0.10122122815144913, 0.17473553733101913, 0.22624604829720088, 0.23468238274965966, 0.1271814283515726, 0.3837676543210234, 0.3741798188005175, 0.42543643553342136, 0.5474763054932866, 30.868695872170584, 109.24940994807652, 84.0670885358538, 85.90994535173688, 72.14001928056989, 41.82188824244908, 53.37353590556553, 86.30611079079765, 53.022940226963584, 34.70938907350813, 0.3111913044537817, 0.6922648761953626, 4.86590815441949, 8.230044824736458, 5.9568339586257935, 8.848238212721688, 4.433959926877703, 6.158290462834494, 77.0201838357108, 93.69114957536969, 85.96452345166887, 81.1231437410627, 71.93965407780239, 71.23728152683803, 68.67561272212437, 68.74424007960728, 63.20628261566162, 64.29342555999756, 63.704649107796804, 64.27019078390938, 62.21462876456124, 64.99390125274658, 64.23617240360805, 70.71407522474016, 69.47890090942383, 68.71314689091274, 65.36214882986886, 62.26186261858259, 54.71710211890084, 60.18040466308594, 58.20480598722185, 57.64502436774117, 56.374435084206716, 60.76032216208321, 54.75381987435477, 53.53915316717965, 56.05912583214896, 54.53088692256382, 55.66715363093785, 54.96294328144619, 53.94089106151036, 55.9950703893389, 53.88454811913626, 57.192971093314036, 52.42947374071394, 50.39678519112723, 53.15911449704851, 62.74410234178816, 68.03236934116909, 68.06219795772007, 67.33702836717877, 70.38066591535295, 66.1872057233538, 66.74536146436418, 65.5962336403983, 72.13188294001988, 65.83176367623466, 66.48085049220494, 63.91080910818917, 71.06749534606934, 64.81129564557756, 69.60949230194092, 59.59658227648054, 43.68384913035801, 58.54135240827288, 62.69737570626395, 69.13164384024483, 65.83351462227958, 63.78025940486363, 60.668501717703684, 57.41678646632603, 55.11208636420113, 55.881026131766184, 56.72831378664289, 59.33503818511963, 64.3156042098999, 58.84925488063267, 65.00797135489327, 67.26856776646206, 57.4198853628976, 63.150238445826936, 64.01536560058594, 65.41014698573521, 64.81822994777134, 59.771162714277, 60.065092359270366, 51.109149251665386, 53.006966318402974, 48.232205935886924, 49.3395368712289, 48.17877776282174, 54.2612829208374, 53.89739533833095, 51.6665163721357, 51.116111346653526, 53.21056938171387, 53.09974908828735, 53.702175276620046, 52.051682812826975, 54.450239181518555, 50.61797414507185, 54.151463168007986, 50.748975481305806, 52.23684188297817, 49.717369488307405, 52.03920732225691, 51.073577948978965, 55.77734163829258, 54.129861218588694, 56.94088697433472, 52.83610316685268, 62.28937748500279, 64.51317623683384, 75.71855694907052, 68.64492947714669, 86.07770960671562, 19.080656596592494, 2.1156532977308546, 6.927579811641148, 4.232876888343266, 0.8153334323848996, 0.29726114336933407, 1.0231277793645859, 26.298506089619227, 48.26217699050903, 43.26385484422956, 102.86209079197475, 94.32298401423863, 41.20093468257359, 60.391789708818706, 64.19713047572544, 67.50682844434465, 69.45119844164167, 83.87041282653809, 22.56376075744629, 0.8076834114534515, 0.2330836999629225, 0.2700390512389796, 0.15268024509506567, 0.17316631653479167, 0.10732514597475529, 0.19984817265399865, 0.15893705721412385, 0.10500539080905062, 0.18524483697754995, 0.10280370073659079, 0.1435000869844641, 0.23762624764016696, 0.10998566821217537, 0.11603469933782305, 0.14277303671198233], [0.0520126167019563, 0.021110357583633492, 0.03564105269366077, 0.028911674860864878, 0.013436452219528812, 0.014548669502671276, 0.04108743615714567, 0.06793622885431562, 0.10307304521224328, 0.038318629908774576, 0.04549051774665713, 0.06255674215831927, 0.1433142769549574, 0.03881816060415336, 0.15679675420480116, 52.846035616738455, 76.44738824026925, 64.37187767028809, 59.2277649470738, 44.52972977502005, 20.571644476481847, 50.30689982005528, 29.191206182752335, 30.371955258505686, 3.023759186267853, 0.12507354574544088, 0.9722409099340439, 3.33584577696664, 4.251465056623731, 8.20971439565931, 9.300835183688573, 1.2699961896453584, 19.21501738684518, 86.28641264779228, 78.85166645050049, 78.19125407082694, 75.67480414254325, 74.1878410066877, 73.6171646118164, 65.18828405652727, 61.14774676731655, 59.283204623631065, 58.96485900878906, 58.35755171094622, 57.46581990378243, 62.74943855830601, 61.405684743608745, 63.306642396109446, 62.78800106048584, 66.69841248648507, 64.627578326634, 60.67236491612026, 58.36164419991629, 52.31042678015572, 53.97238029752459, 50.91864701679775, 52.77923910958426, 51.17561224528721, 48.96909366335188, 49.505564076559885, 49.04580177579607, 48.14197662898472, 48.166031292506624, 48.91549873352051, 50.466909885406494, 48.6513386453901, 48.38036584854126, 47.49871935163225, 47.88602931158883, 49.03088746752058, 48.53042956760952, 50.3191807610648, 54.214010851723806, 56.853530747549875, 61.102715492248535, 62.41937133244106, 61.35105105808803, 59.42289120810372, 56.80973972593035, 55.37569407054356, 61.437361580984934, 59.467408316476, 59.24935300009591, 61.631049564906526, 63.78178800855364, 58.73651341029576, 63.52225889478411, 52.50221790586199, 38.7820930480957, 62.499331201825825, 59.274012156895225, 61.4371531350272, 53.46527991976057, 50.60792704990932, 48.18206773485456, 48.2625105040414, 48.036899021693635, 52.36523069654192, 49.66167620250157, 51.93764202935355, 56.32845885413033, 61.69738401685442, 59.63149002620152, 60.43766866411482, 53.22899947847639, 57.062456130981445, 59.33794948032924, 60.14421149662563, 61.04527473449707, 52.677781513759065, 53.44447006498064, 49.98943315233503, 43.241877692086355, 44.86570644378662, 42.945286887032644, 43.112307684762136, 41.66458102634975, 46.556050300598145, 46.10271160943167, 45.852465288979666, 48.05805281230381, 46.237927028111045, 46.86274378640311, 46.172138009752544, 46.60070289884295, 44.94778898784092, 45.985634463174, 47.56546722139631, 46.50271245411464, 47.07653638294765, 48.34164006369454, 47.59092542103359, 48.112832409994944, 48.933383396693635, 48.146687507629395, 51.10073150907244, 51.224117619650706, 48.14894219807216, 58.95811230795724, 61.89141246250698, 71.34622928074428, 47.2321343421936, 0.19920703848557814, 0.9715841966015952, 2.8743870300906043, 0.8296009067978177, 0.08550301872725997, 0.0756433688636337, 2.7393616012164523, 61.76858220781599, 33.068971497671946, 36.33262375422886, 50.269587993621826, 17.464660201753887, 20.30038854054042, 28.58382419177464, 46.633105822971885, 58.73769460405622, 57.13812896183559, 62.23615428379604, 7.40504959651402, 0.2802342841667788, 0.05354694722752486, 0.05878633340554578, 0.0827820933024798, 0.05625678199742522, 0.023668453263651048, 0.05585829195167337, 0.07712532327111278, 0.03247717621603182, 0.020592450463612164, 0.03547275226031031, 0.055973293459309, 0.03379469444709165, 0.10707724320569209, 0.07020514139107295, 0.029373631679586003, 0.04292897680508239, 0.02657094957040889, 0.061980082387370725, 0.05394179014755147, 0.02230670303106308, 0.04230681786845837, 0.036424132995307446, 0.05076483830011316, 0.053838072677275965, 0.01856300311296114, 0.0729140228192721, 0.049011083120214086, 0.01526752476846533, 0.30265503536377636, 67.64085919516427, 85.23461518968854, 73.56249618530273, 67.323944909232, 57.477301801954, 26.85049704142979, 40.73264694213867, 33.11087608337402, 37.12788677215576, 3.804011489663805, 0.20819210420761788, 3.5705055509294783, 7.032982681478773, 10.83673882484436, 16.588038989475795, 5.059381178447178, 0.5773541022624288, 24.038880688803538, 90.17963423047746, 83.31125654493059, 81.2714877809797, 78.90238135201591, 77.67726802825928, 76.64052731650216, 69.4657757622855, 62.82907881055559, 62.94657979692732, 60.002433504377095, 62.017515318734304, 59.750887870788574, 64.66248607635498, 63.66972746167864, 66.14266777038574, 66.15759250095913, 69.39466094970703, 67.0518604006086, 64.84541824885777, 59.67359610966274, 53.700629302433555, 55.31324366160801, 53.23525285720825, 54.41905219214303, 54.14318091528756, 52.16022062301636, 51.99198389053345, 51.1253524507795, 51.43726750782558, 52.313602106911794, 50.6592047555106, 53.12088898250035, 50.588267121996196, 50.78020415987287, 49.335027490343364, 50.56221832547869, 51.428686482565745, 50.08688163757324, 53.13349996294294, 57.129433291299, 58.33424745287214, 63.53430012294224, 64.89518124716622, 65.17067037309918, 62.60028852735247, 58.99581323351179, 58.942402430943076, 63.486962045942036, 62.14026914324079, 62.99496010371617, 64.38642719813755, 64.74946362631661, 62.10107435498919, 65.24619729178292, 55.81026567731585, 41.495524406433105, 65.18392753601074, 61.377301352364675, 63.28528363364083, 55.73625694002424, 53.40036637442452, 51.04473597662789, 51.44028302601406, 49.63993876320975, 53.42317731039864, 52.04771191733224, 56.01395559310913, 58.6583183833531, 63.87231608799526, 62.73434707096645, 61.75239985329764, 54.843694823128835, 59.444486209324424, 60.85084329332624, 61.216429710388184, 62.62088993617466, 53.76487929480416, 55.412238121032715, 51.729203019823345, 45.2431013243539, 47.947065762111116, 45.70319019045149, 45.813249656132285, 43.70764323643276, 49.35205405099051, 48.54039675848824, 49.09015212740217, 49.50419180733817, 49.98897457122803, 49.38463415418352, 49.11305338995797, 48.372413635253906, 48.87690496444702, 49.29160124914986, 50.35985551561628, 50.11106831686837, 51.30450480324881, 50.941200869424, 51.7585209437779, 51.29020888464791, 51.89185340063912, 50.808347838265554, 53.658054215567454, 54.57512610299246, 52.79633515221732, 58.03989396776472, 64.77592236655099, 71.84020451136998, 54.968581744602744, 0.2800989571426596, 0.37798469034688814, 3.6733267307281494, 2.1131067829472676, 0.3250830875975745, 0.03876990319362708, 1.4836836946862084, 61.95400183541434, 43.36312028339931, 35.23240777424404, 54.4181558745248, 21.744300637926372, 36.05583878925869, 35.661660534994944, 54.19107484817505, 65.24944904872349, 64.1950877053397, 75.41077954428536, 16.75614891733442, 0.4898573915873255, 0.08093408282314028, 0.08911009053034441, 0.021339588765321032, 0.06899903182472501, 0.06448988164109842, 0.0666067616215774, 0.05606640881991812, 0.036952715167509656, 0.04603259937305536, 0.055927556806377, 0.048656931945255825, 0.0201644763749625, 0.09513559006154537, 0.012471911297844989, 0.10112610432718482, 0.08989641083670513, 0.13767309965831892, 0.11264261457004718, 0.21939766220748425, 0.06213187745639256, 0.1773358599415847, 0.22810056592736924, 0.14756445746336663, 0.12107287613408906, 0.08876888241086688, 0.17900554463267326, 0.27076741786939756, 0.19764281170708792, 0.36208566491092953, 76.16805676051548, 97.11039284297398, 83.29255199432373, 76.60501507350376, 61.106057575770784, 28.74922432218279, 63.79838030678885, 42.56048175266811, 48.30891057423183, 5.903021463326045, 0.27625492055501255, 3.5827606533254897, 9.890659945351736, 13.570117592811584, 18.10424188205174, 20.54764018739973, 2.7492328201021468, 25.81719742502485, 91.19306373596191, 86.90342657906669, 86.728561265128, 83.45233971732003, 81.15610599517822, 81.51253468649728, 70.70125579833984, 64.78733130863735, 65.4702558517456, 64.38053512573242, 65.49672154017857, 62.93005003247942, 68.74911076681954, 67.00480025155204, 69.62706429617745, 69.67339488438198, 72.76047257014683, 70.77141175951276, 67.2164145878383, 63.77523585728237, 57.39225237710135, 58.77761895315987, 54.72435603822981, 58.426484789167134, 58.289125851222444, 55.498555592128206, 56.033261162894114, 52.93364197867257, 55.13848257064819, 55.70044592448643, 54.134182998112266, 56.12577295303345, 52.94753837585449, 53.59890767506191, 51.46010276249477, 52.44192143848964, 54.465632915496826, 52.37626443590437, 56.22674070085798, 59.85275541033064, 61.237524441310335, 65.28674697875977, 67.76366860525948, 67.38956369672502, 66.60422270638603, 62.02488735743931, 60.777449471609934, 66.61488124302456, 64.76158128465924, 66.38056714194161, 65.57306139809745, 71.15051937103271, 65.73405810764858, 66.9962192262922, 58.546452386038645, 44.63480043411255, 66.08565780094692, 65.5828583581107, 66.79367923736572, 59.23797879900251, 58.28994573865618, 53.8253390448434, 53.715929235730854, 52.15405409676688, 56.45734098979405, 54.87751865386963, 58.17096826008388, 62.63858004978725, 64.96203681400844, 65.27899973733085, 64.52765628269741, 58.25505188533238, 62.94412708282471, 63.87701307024275, 63.27461120060512, 65.47896194458008, 58.906403814043315, 58.54101194654192, 52.71969999585833, 47.71693795067923, 49.767063004629954, 49.01020962851388, 47.84025457927159, 47.38841322490147, 51.642055238996235, 52.9627479825701, 51.56109135491507, 53.5205146244594, 50.592005252838135, 52.33899777276175, 52.00527579443795, 52.59332268578665, 51.24447236742292, 53.01312937055315, 54.13173375810896, 52.50652926308768, 52.80389131818499, 54.69281816482544, 53.60840933663504, 55.37133060182844, 54.489350591387065, 54.3978636605399, 57.32352427073887, 57.68024478639875, 53.78716911588396, 65.68947846548897, 69.40269306727818, 76.87896169934953, 57.05533422742571, 0.42004710329430445, 3.629055632012231, 8.738586085183279, 3.0377469956874847, 0.18954071003411496, 0.14119351575417177, 3.8438628826822554, 74.43946307046073, 45.85829135349819, 50.337621280125205, 63.08279923030308, 25.58353819165911, 31.67107731955392, 43.36465236118862, 63.950775146484375, 76.73112487792969, 72.83485998426164, 85.19240488324846, 14.008865935461861, 0.59413302476917, 0.19487475523991243, 0.1190691486533199, 0.13907993345388345, 0.21679381121482166, 0.19223719462752342, 0.22247882187366486, 0.10946212416248662, 0.1744086327297347, 0.09435622473912579, 0.27402590587735176, 0.10686381001557622, 0.07750421044017587, 0.17521998419293336, 0.1352205348334142], [0.06937851610460452, 0.024589238854657327, 0.045289413537830114, 0.013043451522077833, 0.06736785399594478, 0.036841275968721936, 0.0697788924777082, 0.06421876618904726, 0.03153397522068449, 0.02404395623930863, 0.06082894094288349, 0.031993523240089417, 0.16719362059874193, 0.3162085552300726, 7.766643404960632, 76.01765605381557, 66.68428679874965, 71.4511331830706, 60.5790992464338, 30.643490859440394, 46.42446184158325, 59.63546439579555, 32.5817221232823, 26.368443182536534, 0.2798766147877489, 0.1822367012500763, 2.686945910964693, 3.829661633287157, 0.23888161884886877, 36.898613589150564, 1.7193906924554279, 1.0493197739124298, 69.26796749659947, 87.90631566728864, 80.27856935773576, 82.85026441301618, 77.6818538393293, 75.95516395568848, 75.33002063206264, 71.42467444283622, 68.39501667022705, 64.32686029161725, 59.8099753516061, 62.393030711582725, 60.84861986977713, 62.8549747467041, 62.3687676021031, 65.82844938550676, 66.72887338910783, 72.45623179844448, 72.60461057935441, 62.128950527736116, 57.58156647000994, 51.53658505848476, 51.812741211482454, 50.235079765319824, 52.333171708243235, 50.54213455745152, 49.142840317317415, 48.512332984379356, 47.91671255656651, 49.71381548472813, 48.55016939980643, 48.08958373750959, 49.2952664239066, 45.352848121098106, 46.31652505057198, 47.30072348458426, 46.7563807623727, 52.56695774623326, 55.11060987200056, 56.37655428477696, 59.327033860342844, 58.53559235164097, 62.34938212803432, 58.73726381574358, 63.15217004503523, 62.33777863638741, 61.132745606558665, 53.85034213747297, 57.52096775599888, 63.89835098811558, 59.374094009399414, 56.55061708177839, 64.41039848327637, 56.510751792362754, 63.86839035579136, 50.664756366184776, 46.52812896456037, 64.25710732596261, 56.97532572065081, 56.2114268711635, 48.16501685551235, 50.882954120635986, 53.313982895442415, 55.32695245742798, 54.31893212454659, 51.868594305855886, 47.28072656903948, 49.441307135990684, 52.76195893968855, 57.29780551365444, 59.84316689627511, 56.285835129874094, 53.25501700810024, 57.724417958940776, 59.06462124415806, 57.904445784432546, 58.202912603105815, 52.54439694540841, 50.91382149287632, 58.3438081741333, 44.23594604219709, 46.306717668260845, 43.53950377873012, 44.71216862542288, 42.51935189110892, 44.73001159940447, 46.059667519160676, 46.62212766919817, 44.73209605898176, 45.37579454694475, 46.06012610026768, 46.030811650412424, 45.64608294623238, 45.250615801130024, 45.621013845716206, 46.37667907987322, 46.53461510794503, 50.26332766669137, 48.303424971444265, 54.50955595288958, 53.46729142325265, 53.844307626996724, 54.058986118861604, 56.623920576913015, 53.8089656148638, 56.05572121483939, 55.37381458282471, 62.762792995997835, 64.21329198564801, 67.15139334542411, 4.568610804421561, 1.1681818472487586, 0.700748680957726, 1.8215278003896986, 0.7048658686024802, 0.030034680850803852, 0.08948825845228774, 21.751964500972203, 70.54230185917446, 27.63682120186942, 53.710895265851704, 56.029154777526855, 14.30448225566319, 22.06688117980957, 35.598358971732004, 43.06787395477295, 57.0957727432251, 58.299193790980745, 53.48960556302752, 3.90381497996194, 0.1460742045726095, 0.03231813439301082, 0.07641792337277106, 0.01988162057075117, 0.06647862028330564, 0.07943115489823477, 0.017711524785097157, 0.06614401430955955, 0.08450884278863668, 0.06634857226163149, 0.021605192816683223, 0.05984297527798584, 0.09120444993355445, 0.03577952133491635, 0.023604691327948655, 0.0230466607359371, 0.03785889868491462, 0.010617090871424546, 0.050643733369984796, 0.023362688420872604, 0.07747435489935534, 0.03225109852584345, 0.05171548621729016, 0.04744169269023197, 0.1073676086962223, 0.08621629473886319, 0.3375011741050652, 0.28159770529185024, 13.783591440745763, 92.39850670950753, 72.25767312731061, 77.80915178571428, 69.23756217956543, 41.7727610043117, 40.84702818734305, 52.51157365526472, 39.42411354609898, 35.348939486912315, 0.17923312527792795, 0.46673948637076784, 5.513906274523054, 3.26944705418178, 2.099097694669451, 34.47167035511562, 0.7163543349930218, 2.2267892999308447, 70.0131617954799, 89.31511156899589, 84.29738657815116, 87.3913221359253, 83.25672708238874, 79.61516230446952, 76.61928667340959, 74.63246318272182, 70.35024670192173, 66.77974809919084, 64.57843371800014, 65.0397037778582, 64.62916946411133, 65.90706825256348, 64.7586283002581, 70.05656024387905, 69.08411816188267, 75.50346851348877, 76.01883724757603, 65.65416077205113, 59.586715834481375, 54.39948606491089, 55.17372383390154, 53.0652790750776, 55.69666610445295, 54.22506890978132, 51.41986921855381, 50.769073145730154, 49.89410734176636, 52.72775643212454, 50.23889780044556, 50.07804005486624, 51.80831173488072, 49.434775829315186, 48.06342724391392, 48.945167541503906, 48.64472048623221, 53.92077950068882, 57.824267046792166, 59.079990659441265, 62.508565357753206, 60.6672579901559, 63.130311012268066, 62.5249422618321, 64.55823530469621, 64.47865758623395, 65.03222751617432, 58.31828049251011, 60.07033824920654, 65.15250778198242, 60.360224042619976, 60.07126930781773, 66.53032166617257, 60.32860279083252, 66.9302669252668, 53.83713361195156, 47.93434361049107, 65.5936141695295, 59.55436502184187, 60.00046716417585, 50.29613011223929, 52.41863455091204, 58.06169046674456, 58.09364175796509, 55.30285957881382, 55.12365511485508, 50.714057309286936, 52.85824360166277, 57.21065078462873, 60.2250120980399, 60.971505710056846, 57.469280106680735, 55.64521816798619, 59.75854478563581, 61.3328537259783, 60.56721087864467, 61.152513231549946, 54.076179436274934, 52.219902174813406, 60.64592007228306, 47.09051268441336, 49.37803683962141, 46.966991083962576, 47.9774398122515, 45.53500209535871, 47.707457133701865, 47.55143880844116, 48.151207310812815, 47.31942803519112, 49.25513710294451, 48.43149764197213, 48.33741555895124, 48.04129375730242, 48.150401319776265, 49.14863511494228, 50.09732130595616, 49.58232430049351, 54.57304164341518, 51.50139938082014, 57.6054995400565, 56.03451531273978, 59.09647873469761, 58.53521714891706, 59.7789238521031, 56.76781776973179, 59.42353739057268, 58.91569355555943, 67.90726702553886, 68.21852547781808, 71.65391635894775, 6.9216430102075845, 1.2073101933513368, 3.193693233387811, 3.476382864373071, 0.658081693308694, 0.05307408295837896, 0.06705915448921067, 19.360246896743774, 77.62040397099086, 36.117156641823904, 42.56918437140328, 42.222493580409456, 20.316074098859513, 34.547770500183105, 48.85723114013672, 48.59812239238194, 62.14413928985596, 63.71075657435826, 69.14049584524972, 8.211848361151558, 0.21242895828826086, 0.024403759610972235, 0.11250643937715463, 0.048507471036698134, 0.05460687999480537, 0.015729442571422884, 0.0648218345429216, 0.05688677462083953, 0.06202396324702671, 0.08191309350409678, 0.008233686576464345, 0.10641084717852728, 0.02094171449009861, 0.02582841512880155, 0.1870575975626707, 0.19384032860398293, 0.15434284588055952, 0.12835490038352354, 0.19817892222532205, 0.07560535733188901, 0.11353363961513553, 0.2960112275821822, 0.13942965040249483, 0.23551231250166893, 0.3130386024713516, 0.15150332610521997, 0.4160933068820408, 0.577009243624551, 14.846340996878487, 106.3561383656093, 85.13996682848249, 85.24919251033238, 78.93013940538678, 45.08315379279, 60.02284731183733, 80.6633744921003, 48.62787457874843, 46.42287070410592, 0.2977328880556992, 1.034788919346673, 7.907585007803781, 7.590161766324725, 4.489182472229004, 48.79051801136562, 5.198920547962189, 1.8400569089821406, 77.44744941166469, 90.5731315612793, 85.60136890411377, 88.22686386108398, 86.0771815436227, 82.07542215074811, 80.52668258122036, 76.60457733699253, 76.11559091295514, 71.37437643323625, 67.76994977678571, 68.02012661525181, 67.09341757638114, 67.56337983267647, 69.33469799586705, 71.22152996063232, 71.96330574580601, 76.87072808401925, 77.1017209461757, 69.18176814488002, 62.75433703831264, 58.29968711308071, 57.625948088509695, 54.76513154166085, 57.82079642159598, 57.864003794533865, 55.9192898614066, 54.82861375808716, 53.250785555158345, 56.36542674473354, 53.08355631147112, 54.31793853214809, 55.463689531598774, 50.18359361376081, 51.28194400242397, 52.44654199055263, 50.61806794575283, 57.63449089867728, 60.914745875767295, 61.09585067204067, 66.51282610212053, 62.87483964647566, 66.74161638532365, 63.25198091779436, 68.19820199693952, 67.05926718030656, 66.50260530199323, 61.633134024483816, 62.391495159694124, 69.44276332855225, 64.17436122894287, 60.93050439017159, 67.28642463684082, 63.462358474731445, 70.80594430650983, 56.004603317805696, 51.31498963492257, 68.12773336683, 62.350215911865234, 62.194861139569966, 52.91642434256417, 54.30280882971627, 59.87735203334263, 60.97371523720877, 58.36119256700788, 56.8044764654977, 53.42710304260254, 55.05940859658377, 59.637618337358745, 63.970772062029155, 63.78329576764788, 60.622400420052664, 60.06099987030029, 62.66848509652274, 65.852872303554, 62.3553923198155, 63.657957213265554, 58.89693341936384, 53.908442974090576, 64.30106163024902, 49.415824617658345, 50.067152227674214, 48.89687408719744, 50.490603242601665, 49.22710459572928, 50.31836782182966, 49.35901614597866, 50.17989369801113, 50.27084214346749, 52.73381526129586, 52.268848759787424, 51.83513872964041, 50.2790653364999, 50.93832084110805, 51.94130025591169, 53.953984941755024, 52.46174464906965, 57.932252475193565, 54.92229979378836, 61.961151531764436, 58.01315382548741, 60.68774127960205, 60.32318319593157, 63.2810035433088, 59.62106078011649, 64.44099140167236, 61.06164469037737, 73.41996083940778, 73.18418761662075, 75.05387142726353, 7.613131642341614, 3.1782007047108243, 8.88975283077785, 6.378352505820138, 1.6113793168749129, 0.11754442618361541, 0.20483942196837493, 26.623277051108225, 84.03275053841728, 41.920587403433665, 67.07274668557304, 71.22741508483887, 23.296076570238384, 34.131684575762065, 53.69457394736153, 59.63686793191092, 73.01687499455043, 75.38903863089425, 75.07086672101701, 6.880067161151341, 0.31882609905941145, 0.10896713965173278, 0.16928763394909246, 0.19378509585346493, 0.15829335818333284, 0.1780718940177134, 0.10960060637444258, 0.1429470402321645, 0.1388202038194452, 0.2102803500103099, 0.1322413861219372, 0.2824489681848458, 0.2037181428500584, 0.1273301632276603], [0.06518025709582226, 0.04385724324466927, 0.025018402075927173, 0.02447615929746202, 0.1272452784968274, 0.03614496672526002, 0.04306454810180834, 0.03071914626551526, 0.06492616608738899, 0.06512939411082438, 0.18409489654004574, 0.03283405849444015, 0.23916027961032732, 0.054958764862801344, 44.80881806782314, 77.25262887137276, 68.47878415243966, 61.75935500008719, 35.8953423500061, 39.350226402282715, 62.137496812003, 37.91066040311541, 28.038534777505056, 10.816996387072972, 0.042364018370530436, 0.1843685768544674, 1.9098574263708932, 2.6719632063593184, 11.716166240828377, 1.319904340165002, 1.0072186844689506, 26.42873270171029, 65.60828181675502, 78.53109046391079, 76.93265737806047, 80.73438508169991, 82.56843852996826, 82.84802709306989, 75.63505349840436, 75.61653654915946, 70.27296188899449, 70.47847570691789, 67.59070709773472, 65.91582298278809, 64.15763691493443, 70.31160776955741, 68.23420756203788, 70.69824028015137, 65.39500686100551, 77.78896726880754, 71.79531914847237, 63.06008556910923, 54.230175835745676, 51.873360770089285, 52.799270766122, 49.76440879276821, 51.51836688177926, 47.48642104012625, 47.45765202386038, 49.29375866481236, 47.447844641549246, 49.189893518175396, 47.55624696186611, 47.9973464012146, 48.07445056097848, 46.3574777330671, 47.230341706957134, 46.14528669629778, 50.99498340061733, 56.59305667877197, 60.71971688951765, 60.62882055555071, 60.29670361110142, 60.92833655221121, 61.43643052237374, 59.173221588134766, 53.86288711002895, 59.471431323460166, 64.69007737295968, 57.907291071755544, 55.94544982910156, 56.70116717474801, 62.42567334856306, 54.48449032647269, 61.607356207711355, 59.52776731763567, 62.48668548039028, 47.76582200186593, 44.192978382110596, 65.32362801688058, 54.66897542136056, 54.49015310832432, 49.06312710898263, 57.37336022513253, 54.94059787477766, 57.207367760794504, 55.317218031202046, 52.033141544886995, 46.76446846553257, 48.60857595716204, 49.019968373434885, 54.5871708052499, 53.019306319100515, 54.51957525525774, 55.385199206215994, 60.08528382437569, 56.75254215512957, 57.58867795126778, 55.885813440595356, 52.50883953911917, 44.47232723236084, 58.295705795288086, 49.45872974395752, 42.511201654161724, 47.946773937770296, 45.68823766708374, 43.37031166894095, 43.12952879496983, 45.06171860013689, 47.68269375392369, 44.739078998565674, 47.481063979012625, 44.62001814161028, 46.547389371054514, 45.30742079871041, 45.86858858380999, 46.11245993205479, 50.23466634750366, 51.67115082059588, 56.24834265027727, 55.68996109281267, 57.89359964643206, 56.611160210200715, 61.998539788382395, 59.27904265267508, 59.87182821546282, 59.68190615517752, 58.27165460586548, 59.91592148372105, 63.81852313450405, 62.22352245875767, 67.45272977011544, 14.94183703831264, 0.6985100039413997, 1.9112985261848994, 1.745882110936301, 1.2976417690515518, 0.18207576631435327, 0.049878773346011124, 2.9122462442943027, 58.82915374210903, 48.47866548810686, 39.78353343691145, 57.544174739292686, 31.61848987851824, 15.221145936420985, 23.007212162017822, 35.53151035308838, 47.34539692742484, 55.443150656563894, 66.4755768094744, 29.738078049251012, 0.4290993846952915, 0.07031760178506374, 0.07610695077372448, 0.10059881476419312, 0.03725018152701003, 0.04290875646152666, 0.03600832673587969, 0.07578879927418061, 0.11222035544259207, 0.028482735556151186, 0.08781141521675245, 0.024896180955693126, 0.09575674137366669, 0.12985496489065035, 0.013827676003399705, 0.005333490503419722, 0.07038733482893024, 0.07892867257552487, 0.09747775723891598, 0.02622640475497714, 0.05597329685198409, 0.021762704543237175, 0.05828462461275714, 0.0798121319551553, 0.032793153010840924, 0.07670901489577123, 0.15341470496995108, 0.0315035972078996, 57.48880107062203, 87.49890109470913, 78.69519996643066, 70.53941140856061, 54.81661074502127, 44.129315512520925, 51.355094637189595, 35.742360387529644, 38.17958000728062, 13.389341098921639, 0.2181757427752018, 0.485796115228108, 3.0716166411127364, 1.7506088401590074, 5.0385661125183105, 1.9702800469739097, 0.8268605481301035, 36.210866996220176, 74.3549382346017, 79.14511666979108, 78.8322948728289, 83.28523554120744, 84.52172306605748, 83.37552043369838, 78.55602754865373, 81.21521432059151, 74.16184779575893, 75.64114012037004, 69.80691146850586, 70.90998663221086, 68.25728947775704, 72.09724617004395, 70.1618185043335, 73.22244439806256, 68.34457274845668, 78.13106182643345, 74.67101178850446, 63.1344312940325, 59.08543804713658, 53.18165445327759, 55.61825220925467, 52.34209319523403, 53.8708427974156, 50.32951273236956, 50.540998526981895, 52.472695010049, 49.6811763218471, 51.76457977294922, 49.71171018055507, 50.64445720400129, 50.24957718167986, 47.95382635934012, 49.62066446031843, 48.369050707135884, 53.781426429748535, 59.782453536987305, 62.325598444257466, 62.51883479527065, 63.961517061506, 62.670131819588796, 62.74133695874895, 61.4911892754691, 54.844834327697754, 60.211178234645296, 67.08894293648856, 59.593754359654014, 57.808873312813894, 59.57174941471645, 64.06186989375523, 57.197035789489746, 63.632283619471956, 63.59660461970738, 65.4704087121146, 48.77958154678345, 46.76793214253017, 66.37206254686627, 56.811476775578086, 55.427545002528596, 53.39440482003348, 59.75990663255964, 58.71148599897112, 59.157511711120605, 57.01065731048584, 54.18322338376726, 48.87811395100185, 51.27509307861328, 52.11678048542568, 57.79198571613857, 56.3549245425633, 56.69212062018258, 56.06136315209525, 61.9518062046596, 57.73201234000069, 59.26131084987095, 58.6113555090768, 53.69420221873692, 46.9025639125279, 59.35476412091936, 52.83832311630249, 44.20737157549177, 48.736044134412495, 47.96676043101719, 46.16944905689785, 44.70233345031738, 47.526067461286274, 49.70166655949184, 46.85350963047573, 49.21557406016758, 47.763591630118235, 50.41729627336775, 48.178364345005576, 47.92449106488909, 50.05844613483974, 53.30962290082659, 55.402462005615234, 60.29532091958182, 58.700229917253765, 62.66166196550642, 60.29450798034668, 65.24839987073625, 61.704915864127024, 62.54124273572649, 63.68012196677071, 62.61948640005929, 65.33691992078508, 67.68123517717633, 67.48433017730713, 70.37987382071358, 18.622643504823955, 0.46218608213322504, 3.549406043120793, 3.111576165471758, 4.05500864982605, 0.3919767066836357, 0.07564655119287116, 2.2203861006668637, 61.29544462476458, 58.198924337114605, 40.6640682220459, 41.961213520595, 26.74151975767953, 26.14818181310381, 37.501366342817036, 49.256815092904226, 54.92228242329189, 62.31598908560616, 72.252927507673, 43.20324918201992, 0.5343240712370191, 0.0562566903951977, 0.07255616345043693, 0.008635428501293063, 0.06303629678274904, 0.044006897535707266, 0.02869349531829357, 0.08730807793991906, 0.06797782305095877, 0.017395737980093275, 0.04572580994239875, 0.012253799608775547, 0.025155184557661414, 0.004998668246636433, 0.09206669830850192, 0.17106800127242291, 0.125640583889825, 0.18615080336374895, 0.18035604645098957, 0.1317839449537652, 0.1539014181388276, 0.10810379205005509, 0.11588337245796408, 0.17803116834589414, 0.1525526669408594, 0.1094058057559388, 0.34313895872661043, 0.1737176398081439, 63.05412401471819, 103.11483151572091, 88.097425869533, 80.42296682085309, 52.46506241389683, 50.50264794485909, 82.28346511295864, 54.89155401502337, 48.013712882995605, 17.503577062061854, 0.2579095592456204, 0.7810308816177505, 6.58982744387218, 9.00685863835471, 25.871945755822317, 3.008193050112043, 1.1310897575957435, 40.25126879555838, 78.94839232308524, 79.02120249611991, 79.21394552503313, 84.68916770390102, 85.98239421844482, 86.2737808227539, 80.6472338267735, 84.8704114641462, 76.6019092287336, 79.7632145200457, 72.3933436529977, 76.14368942805699, 72.06280394962856, 76.02478490556989, 72.37937777382987, 76.00819955553327, 72.6253787449428, 79.15274579184396, 79.240633555821, 67.37304782867432, 60.24697535378592, 56.03755862372262, 59.18236541748047, 54.978958879198345, 56.174135889325825, 53.23756660733904, 54.17640025275094, 56.054074491773335, 52.30221053532192, 53.18262372698103, 52.09528623308454, 52.9450682912554, 52.17936291013445, 50.639947823115754, 52.00025919505528, 51.29513168334961, 55.511923926217214, 61.39588778359549, 66.50247328622001, 65.910660471235, 65.09581048148019, 65.09166240692139, 67.01868970053536, 65.09708200182233, 54.81537743977138, 63.28957067217146, 72.10307570866176, 63.706914220537456, 60.90118299211775, 63.51415729522705, 68.3912160055978, 60.15070111410958, 66.37367452893938, 65.09744330814907, 67.26124436514718, 52.163732937404085, 50.905626092638286, 70.95362826756069, 58.97309957231794, 58.69387926374163, 57.287306785583496, 63.77666023799351, 61.55764184679304, 63.44697516305106, 60.61116518293108, 56.80375385284424, 52.056477069854736, 53.36703586578369, 53.303977489471436, 61.144356046404155, 59.19906193869454, 59.137528691973, 60.10550308227539, 66.62169742584229, 61.05189636775425, 61.12704113551548, 60.923236574445454, 57.491267681121826, 49.922900676727295, 61.47122015271868, 54.124125480651855, 47.885365758623394, 52.30617100851876, 51.154614789145334, 48.534379618508474, 47.3255980355399, 52.18445246560233, 53.41736166817801, 49.193468366350444, 52.369083472660606, 50.060120650700156, 53.088962009974885, 51.17901338849749, 50.77989149093628, 52.920193740299766, 56.762220995766775, 58.40016501290457, 64.15462139674595, 61.51949623652867, 65.60044424874442, 63.09841183253697, 69.15290532793317, 66.32279287065778, 66.0996514729091, 65.53420012337821, 65.1126320702689, 69.05240658351353, 69.26001180921281, 69.43286909375871, 74.46711690085274, 20.94173158918108, 1.8736056344849723, 8.741605945995875, 9.101335900170461, 6.750454596110752, 0.40805350829448017, 0.17157078215054103, 4.772422747952597, 71.56739739009312, 62.40545409066336, 56.61942161832537, 70.69377953665597, 42.125576632363455, 21.90044229371207, 35.138753005436485, 52.49080548967634, 63.49402836390904, 71.56636210850307, 86.00236334119523, 46.55674859455654, 0.6760450122611863, 0.12141483064208712, 0.23397795483469963, 0.12006328387984208, 0.14408043798591408, 0.10086697858891316, 0.13872580602765083, 0.19472269554223332, 0.20642218632357462, 0.08275686537048646, 0.17005388997495174, 0.11772117098527295, 0.179306189928736, 0.14968738997621195], [0.06792174891701766, 0.053744906426540444, 0.044160860524113686, 0.04780103465808289, 0.015578851902059146, 0.029288404288568666, 0.044329167742814334, 0.046036687546542714, 0.08155982103198767, 0.12444869641746793, 0.029438964423856566, 0.13878462144306727, 0.11283933544265372, 4.442964357989175, 79.05167729513985, 64.03564044407436, 64.47409956795829, 45.743232658931184, 25.474364621298655, 74.69275965009416, 86.76082175118583, 25.39596462249756, 39.42581932885306, 8.468261207853045, 0.20001654433352606, 0.3522401489317417, 4.487396785191127, 0.9548633566924504, 1.7127419177974974, 0.2007715773901769, 17.59629556110927, 73.25793579646519, 55.00960043498448, 83.14709145682198, 81.13380227770124, 79.3137286049979, 73.26605129241943, 76.2460572378976, 77.62831102098737, 81.86494731903076, 74.25984518868583, 72.85678849901471, 69.16639872959682, 68.2992079598563, 68.8226296561105, 69.632490839277, 68.54844679151262, 69.77802085876465, 74.98766204289028, 74.21395928519112, 66.82729462214878, 68.68509006500244, 52.52284363337925, 50.71101747240339, 50.97281517301287, 51.28409446988787, 48.69344820295061, 48.044396127973286, 46.887319564819336, 46.772743770054404, 46.99800784247262, 47.7155761037554, 46.81703506197248, 48.067815031324116, 47.2384363583156, 44.05641153880528, 45.49601575306484, 48.19206966672625, 52.77906887871878, 56.707149573734824, 57.384025709969656, 56.920014585767476, 59.26677908216204, 60.62479060036795, 61.57771519252232, 61.02473585946219, 60.982129505702424, 60.179105349949424, 59.49709102085659, 62.06492287772042, 59.08370099748884, 57.76157692500523, 56.1511686188834, 57.00024890899658, 57.64704629353115, 58.55391475132534, 65.14295400891984, 45.33232661655971, 44.82833208356585, 63.282691955566406, 52.353939873831614, 52.21564987727574, 55.453930786677766, 56.99924142020089, 53.345402649470735, 57.667161328451975, 53.022558076041086, 49.13872350965227, 46.48185396194458, 49.30801984242031, 47.1638821874346, 51.63498197283064, 49.3456825528826, 55.42960514341082, 55.26256002698626, 58.65714413779122, 53.43470089776175, 56.830282075064524, 58.18582003457205, 54.26757798876081, 47.04837185995919, 46.89091873168945, 51.28548410960606, 42.908218247549875, 44.13297026497977, 45.67784663609096, 45.03647926875523, 42.27739477157593, 42.685236658368794, 45.68424245289394, 46.034619263240266, 46.35469845363072, 42.84441293988909, 45.26872975485665, 44.625354358128135, 47.39411769594465, 53.12740986687796, 58.793460845947266, 58.91561712537493, 57.9927156993321, 58.15516805648804, 61.10778072902134, 60.25333990369524, 62.001548358372276, 61.65607002803257, 63.150856835501536, 62.22433539799282, 65.32402406420026, 63.53145830971854, 66.30773612431118, 63.742433411734446, 61.39408125196184, 24.564888851983206, 0.381876387234245, 1.7066218576260974, 2.6253653296402524, 0.6176845410040447, 0.24551782703825406, 0.08870332914271525, 0.044854011187063794, 22.797213281903947, 75.0196932383946, 33.1827586718968, 39.512546743665425, 51.9638923236302, 28.247976064682007, 12.134226322174072, 18.65668794087001, 32.7924679347447, 42.26606920787266, 55.758915015629356, 58.375478063310894, 2.368986789669309, 0.2434376829436847, 0.03648066853306123, 0.09649464142109666, 0.0338480340849076, 0.045699879726661105, 0.09067442587443761, 0.0034448169047079447, 0.050629399317715845, 0.04693634694974337, 0.025622528944430605, 0.040145911143294404, 0.06482361909002066, 0.006571380529619221, 0.01694482092612556, 0.05530783041779484, 0.05426915615264859, 0.045580189542046616, 0.03697685065812298, 0.027720811976385967, 0.049375914436365874, 0.04800315327676279, 0.03385753696784377, 0.17873223072716168, 0.01214126287959516, 0.1980612235409873, 0.1922804851617132, 7.019779367106302, 93.50055353982108, 70.63339274270194, 70.22114222390312, 54.08161640167236, 38.088815689086914, 69.48428576333183, 69.47194576263428, 31.138577801840647, 48.65628923688616, 7.174095817974635, 0.1517233071582658, 2.3891128982816423, 3.8117978147097995, 2.220518550702504, 1.7078592883689063, 0.48266492038965225, 23.37716031074524, 82.89037636348179, 66.73252119336809, 84.50515161241803, 81.43814032418388, 79.60823495047433, 74.73101643153599, 76.92390264783586, 80.53957843780518, 82.58026436397007, 77.44453116825649, 75.21741117749895, 73.32124083382743, 73.61187008449009, 72.03312819344657, 72.65678460257394, 70.93598679133824, 71.12002372741699, 73.44867774418422, 74.77160780770438, 69.20149408067975, 70.63544940948486, 57.139476912362234, 53.04571642194475, 52.88718979699271, 52.262984480176655, 52.39264481408255, 49.412367888859336, 51.05515480041504, 51.08685595648629, 50.721901825496126, 51.97553055627005, 48.502199036734446, 49.406621728624614, 48.7191287449428, 48.0901917048863, 46.589356490543906, 49.38374131066458, 55.07303401402065, 59.130455425807405, 60.140931946890696, 59.95111410958426, 61.6263803754534, 61.69287463596889, 63.67960780007498, 61.59273024967739, 61.46211106436593, 60.578341892787385, 63.31675897325788, 63.84866441999163, 62.463075501578196, 61.03143392290388, 58.93767070770264, 59.267043113708496, 62.15759795052664, 60.3134001323155, 68.14554159981864, 47.75540317807879, 47.95097412381853, 65.70038018907819, 55.53353977203369, 54.53906147820609, 58.614426612854004, 58.357885224478586, 55.660292284829275, 61.4353882925851, 55.298325879233225, 51.56161594390869, 49.54355335235596, 52.50949961798531, 51.22555937085833, 52.98202575956072, 51.48258018493652, 57.803797653743196, 57.527512959071565, 61.43293557848249, 56.34442581449236, 58.6900577545166, 60.21994686126709, 56.70979683739798, 50.90384387969971, 46.944927079336985, 53.12808384214129, 45.94944477081299, 46.738520417894634, 46.73026595796858, 48.76192964826311, 45.49586289269583, 46.179273809705464, 49.30226673398699, 48.04082127979824, 48.13470881325858, 45.698100634983604, 48.3301442691258, 47.76345614024571, 50.44563102722168, 57.10271399361746, 60.77427414485386, 61.39090592520577, 61.87168652670724, 61.64083957672119, 64.7294111251831, 65.413225037711, 63.568200383867534, 65.45704732622418, 66.35604694911412, 65.25750201089042, 70.0694283076695, 66.91446672167096, 69.07052748543876, 67.08096640450614, 64.22710500444684, 29.366755894252233, 1.321615334068026, 0.5032160633376667, 1.9573192681585039, 3.234720609017781, 1.9345656548227583, 0.09080756123044662, 0.11715493351221085, 22.716127804347447, 81.2781788962228, 42.43791205542428, 35.61466639382498, 41.25352559770857, 24.948917525155203, 18.410829407828196, 34.100417682102744, 42.53989771434239, 51.15277351651873, 60.42655849456787, 72.91922501155308, 4.934826467718397, 0.15940772981515952, 0.043160374209816964, 0.12142150742667061, 0.060542402389858446, 0.026600677885913422, 0.08033562850739275, 0.037891593894788196, 0.02530289993488363, 0.012984156891304468, 0.0476892290503851, 0.06843852797257048, 0.024537654926202128, 0.05209650398631181, 0.10946634465030261, 0.16233856683330877, 0.12778931430407933, 0.09475823638162442, 0.17097536767167704, 0.1786896458693913, 0.20727526769042015, 0.14919480069407395, 0.1514458813305412, 0.22760144913835184, 0.14941277328346456, 0.4010183486555304, 0.3108288581882204, 7.511259760175433, 104.94010938916887, 80.93014362880162, 81.01571764264787, 62.64275591714041, 36.69684485026768, 80.87355749947685, 104.43169580187116, 41.18091344833374, 58.98703071049282, 12.254872236933027, 0.3547646520393235, 3.082888573408127, 14.167863300868444, 6.160990706511906, 6.624446843351636, 2.0704650368009294, 22.916048322405132, 82.4691001347133, 68.72950989859444, 86.71535273960659, 84.42913137163434, 79.49161638532365, 73.76813507080078, 78.72809968675885, 81.50981099264962, 87.27791363852364, 81.52760532924107, 81.16821670532227, 75.75627177102226, 76.28805909837995, 76.17045388902936, 76.01243100847516, 74.26004668644497, 74.64726979391915, 71.28784356798444, 80.13618687220982, 75.20003373282296, 75.37818554469517, 58.78763825552804, 55.22062764848982, 58.63859939575195, 55.83762420926775, 55.23173781803676, 53.58378144672939, 53.932459422520225, 53.26025594983782, 55.8146083014352, 54.58257804598127, 52.21574020385742, 52.83290352140154, 51.77513408660889, 50.310276644570486, 49.24234894343785, 53.28326143537249, 58.93787915366036, 62.277155603681294, 62.24580533163888, 62.58325849260603, 63.15943786076137, 63.69038445608956, 68.56458745683942, 64.68704101017543, 63.19114249093192, 63.061621120997835, 64.28135653904506, 66.4490555354527, 66.77449526105607, 64.0964719227382, 61.87789821624756, 62.251558440072195, 66.23398794446672, 63.1786287852696, 68.87538732801164, 50.260729040418354, 52.1421275138855, 67.18035343715123, 58.855945995875764, 58.61466979980469, 60.77293314252581, 60.904156821114675, 59.89809935433524, 64.56045178004673, 61.02415221078055, 54.977336474827354, 51.86524180003575, 55.03496135984148, 53.66012825284685, 57.370348181043354, 54.355535234723774, 60.37906060900007, 62.08446816035679, 64.65118830544608, 58.7470885685512, 59.97282028198242, 63.882585525512695, 60.86604595184326, 53.89229188646589, 49.2073404448373, 56.36263704299927, 48.79904692513602, 49.56800058909825, 49.29375171661377, 52.139886719839915, 46.68823283059256, 48.55176748548235, 50.697669982910156, 51.031072344098774, 52.458402565547395, 47.6984418460301, 51.306762967790874, 51.637233189174104, 53.44170468194144, 60.28744166237967, 65.36189869471959, 65.85758318219865, 64.82862445286342, 65.41577502659389, 68.68272072928292, 67.73019913264683, 66.70957824162075, 69.5454021181379, 68.29337842123849, 68.51212160927909, 73.39990139007568, 70.49942452566964, 72.30930519104004, 71.05756637028286, 68.79971449715751, 32.702485288892476, 1.7710611884083067, 6.94171244757516, 5.595682229314532, 5.362557572977884, 2.714327241693224, 0.16642942731933935, 0.22754864554320062, 30.896464347839355, 90.12766170501709, 47.64621223722185, 55.33978230612618, 68.44752420697893, 40.16960661751883, 19.342456034251622, 30.86819212777274, 49.04307113374983, 62.21880463191441, 70.09711687905448, 84.77854238237653, 5.55372553212302, 0.45553806743451525, 0.235787390598229, 0.19239647393780096, 0.125504537618586, 0.09925069460379225, 0.37819245776959826, 0.09699018911591598, 0.1061492787141885, 0.10057060127811772, 0.24199566032205308, 0.132672730833292, 0.10608138450022254, 0.16373918524810246], [0.013730061107448168, 0.05578618064256651, 0.024093965966520563, 0.09001333599111863, 0.03266176148982985, 0.031143193332744495, 0.08071251399815083, 0.1410832673843418, 0.06246482101934297, 0.13106446713209152, 0.1050485252801861, 0.320004687245403, 0.4361911341547966, 28.5284001486642, 86.25839751107353, 62.49004146030971, 66.17994485582624, 39.714843545641216, 25.43913378034319, 34.195114680698936, 50.75464173725673, 30.31129401070731, 42.18347944532122, 0.8179782533219883, 0.2659133954771927, 1.7667277923652103, 1.3610599317720957, 0.8472281066434724, 0.9643303858382362, 4.715470101152148, 87.06588241032192, 85.42519732883999, 91.57422801426479, 81.94173880985805, 85.60177189963204, 80.30305480957031, 79.38926942007882, 78.42257349831718, 75.85914679936, 68.74948596954346, 74.59492206573486, 72.77829469953264, 75.00231579371861, 70.31981359209333, 68.69149630410331, 68.62944194248745, 72.01171384538922, 73.4504564830235, 71.88413102286202, 60.92626598903111, 66.44180161612374, 65.05430889129639, 56.62160682678223, 48.35163852146694, 51.986011913844514, 49.45592614582607, 48.697908946446006, 46.761512007032124, 47.864000047956196, 46.214535917554585, 50.55535350527082, 46.319759437016074, 48.32826478140694, 43.59505115236555, 46.49378054482596, 45.09263808386666, 45.14301947184971, 47.01165757860456, 55.2609862600054, 55.5815691947937, 60.773718288966585, 58.95676435743059, 62.40553746904646, 61.81629548754011, 60.50258568355015, 58.96557467324393, 63.788256781441824, 59.03099891117641, 61.56185245513916, 57.004942417144775, 60.77511487688337, 56.469232831682476, 59.625493730817524, 52.089977809361045, 57.60294607707432, 50.35582556043352, 67.50160339900425, 39.690531798771445, 40.82381772994995, 64.83943584987095, 48.125325271061485, 55.367981570107595, 57.587514128003804, 53.493093558720176, 52.45935099465506, 55.7901645387922, 49.14280905042376, 46.96106774466378, 45.43866184779576, 47.81780842372349, 50.47693961007254, 51.84562356131417, 54.98412833895002, 57.174832820892334, 54.53819295338222, 55.26797962188721, 51.18803562436785, 49.07862506593977, 60.736906732831685, 54.67023304530552, 52.42180640356881, 48.11425331660679, 43.47877304894583, 42.97829777853829, 41.85103246143886, 44.744165079934255, 45.07615695680891, 44.83382116045271, 41.39465740748814, 45.11246476854597, 46.721750940595356, 45.31245824268886, 45.62987279891968, 44.660779748644146, 46.84947272709438, 56.711335863385884, 59.71149158477783, 60.205612727573936, 58.59406839098249, 62.30909647260393, 61.846242223467144, 63.12030560629708, 63.14094870431082, 64.7990390232631, 62.806809834071565, 62.9086982182094, 62.52490752083914, 62.44450296674456, 60.330673354012625, 58.72207505362374, 59.501829692295615, 56.30287558691842, 42.76943492889404, 4.698972472122737, 1.6032256058284213, 2.2399834947926656, 2.4941192865371704, 1.8611601080213274, 0.18887111810701235, 0.09667506388255528, 3.0577562877110074, 51.996764251164024, 62.88450459071568, 27.478487389428274, 46.31094217300415, 120.22006661551339, 74.95370619637626, 18.237134865352086, 10.374511650630406, 41.808269773210796, 49.97781229019165, 62.17771298544747, 12.682695405823843, 0.2279105218393462, 0.12650947512260505, 0.05508121329226664, 0.0472033640502819, 0.06680749263614416, 0.027749164562140192, 0.05641529795580676, 0.015450529055669904, 0.03741035311083708, 0.015550889473940645, 0.05363562157643693, 0.03029568613107715, 0.05421815746064697, 0.03570720985797899, 0.07551578392407723, 0.05583530657791665, 0.01757677790841886, 0.03378124588302203, 0.028686279098370245, 0.03732569229656032, 0.07018306864691631, 0.08882761640208107, 0.1211721593780177, 0.07739968890590326, 0.26902450567909647, 0.4806151475225176, 36.452601773398264, 96.35440799168178, 68.6520722252982, 76.65702928815568, 47.820229870932444, 34.50200619016375, 46.81635761260986, 47.47263928822109, 39.386610644204275, 46.82890258516584, 0.4789804752383913, 0.13815940570618424, 4.088637062481471, 1.3347677311726978, 0.9410027861595154, 0.7274613561374801, 7.482672265597752, 94.0173397064209, 85.06450244358608, 91.86292566571916, 83.04348686763218, 86.13872868674142, 81.87627288273403, 82.07101699284145, 78.01285212380546, 76.82428632463727, 70.75584779466901, 75.94728469848633, 76.68805994306291, 78.10101086752755, 73.4180222920009, 72.2953462600708, 71.42996202196393, 73.07682405199323, 71.46429307120187, 75.4993621281215, 66.47243622371128, 69.42819990430559, 69.03234713418144, 58.993923323495046, 50.225578103746685, 53.6560183933803, 52.39427069255284, 50.83911793572562, 49.090746198381694, 51.28411184038435, 48.79693814686367, 54.07892744881766, 48.49694619859968, 48.453301089150564, 45.6547577721732, 47.3106872013637, 45.41688619341169, 47.11103766305106, 49.80790104184832, 57.775594915662495, 57.08480848584856, 62.76298059735979, 62.565811565944124, 63.62899712153843, 62.65778487069266, 64.34511320931571, 62.76250811985561, 64.64288520812988, 60.79289531707764, 64.69192559378487, 60.75026117052351, 62.39808900015694, 61.324974468776155, 61.301788330078125, 56.00833797454834, 60.27575479234968, 54.36902516228812, 70.31506102425712, 43.83007744380406, 44.48998260498047, 66.50514139447893, 50.097234453473774, 55.85298320225307, 59.09722219194685, 55.25524704796927, 57.403689111982075, 57.27775648662022, 51.50915009634835, 47.224974223545615, 49.35908910206386, 50.551177637917654, 53.41283144269671, 53.84496075766427, 57.41679688862392, 59.73622022356306, 58.625001771109446, 55.98430415562221, 50.359059946877615, 49.962390763419016, 62.00167342594692, 57.86178037098476, 55.76489741461617, 50.231178351810996, 45.222958496638704, 43.62803772517613, 43.37252467019217, 47.661255087171284, 46.94405855451311, 48.150074754442485, 44.917255129132954, 48.23925835745675, 49.33076129640852, 45.76537309374128, 47.81771809714181, 47.057741505759104, 51.34242459705898, 59.69213390350342, 62.44651794433594, 63.97149467468262, 62.293198994227815, 64.13396440233502, 66.00468349456787, 65.76797921316964, 65.28673308236259, 66.37322289603097, 65.84868253980363, 65.45615795680455, 65.28282124655587, 63.24421283176967, 61.93000970567976, 58.56335040501186, 58.35698890686035, 56.897408621651785, 47.602521964481895, 7.302903260503497, 0.2978338269250733, 0.5487279583300863, 3.5892999938556125, 2.0503973364830017, 0.7149248516985348, 0.017138006631284952, 1.7790772382702147, 57.15950509480068, 68.35785075596401, 37.133907386234824, 36.79035718100411, 94.59768799373082, 56.618209157671245, 23.773970195225306, 20.78238681384495, 52.50233255113874, 57.16849953787667, 68.99043560028076, 19.872594901493617, 0.3563763898398195, 0.1777369962739093, 0.06849739088543824, 0.04785567708313465, 0.07186549622565508, 0.048484655296696086, 0.03288226162216493, 0.029471405183098147, 0.08026510157755443, 0.02027182061491268, 0.02110332965717784, 0.08163055830768176, 0.06265293128256287, 0.10513617843389511, 0.2140195665082761, 0.1690839377364942, 0.1455863243235009, 0.09135800240827457, 0.13698777928948402, 0.22979427075811795, 0.18566565082541533, 0.2151080859558923, 0.23995316135031836, 0.27956896701029366, 0.4296932928264141, 0.4869187921285629, 40.6150278363909, 109.16139016832624, 79.28640828813825, 86.82903916495187, 58.52350943429129, 36.25431408200945, 43.792234080178396, 69.6235693522862, 45.955170086451936, 55.54589019502912, 1.070252307823726, 0.2839354755623, 6.7927126714161465, 7.673850212778364, 5.3220226509230475, 2.9660728531224385, 7.002248193536486, 94.94827325003487, 89.03278541564941, 95.51131357465471, 85.29186834607805, 91.30788271767753, 83.8927721296038, 84.32634666987828, 82.1908734185355, 77.80390589577812, 71.91992119380406, 78.59188720158168, 77.94444016047886, 80.02555765424455, 75.96993582589286, 76.46826062883649, 72.39620631081718, 74.28213500976562, 70.17200456346784, 81.11875942775181, 71.78662695203508, 71.98799964359829, 73.14431190490723, 61.270653452192036, 52.90431015832083, 57.40326179776873, 54.948876653398784, 54.511869703020366, 52.40117720195225, 54.120335238320486, 50.807243074689595, 55.508494990212576, 50.51507132393973, 52.17399542672293, 47.997763293130056, 49.97436945778983, 48.660503319331575, 49.55280487877982, 52.0575783593314, 61.371735845293315, 59.76165063040597, 65.934492792402, 65.60210486820766, 66.52297742026192, 67.15778568812779, 67.44517013004848, 65.02028356279645, 70.04340730394635, 64.6929052897862, 65.50037629263741, 62.670576504298616, 64.80010904584611, 63.30993584224156, 66.32817772456578, 58.215534005846294, 61.54822703770229, 57.69074004037039, 70.96310561043876, 48.34126486097063, 50.27241243634905, 68.77200508117676, 55.25936038153512, 58.76243019104004, 63.143609864371165, 58.39455781664167, 57.38748243876866, 61.459554127284456, 54.92526320048741, 49.3436849457877, 51.49424968447004, 52.98939085006714, 56.488072872161865, 56.71917690549578, 60.51197269984654, 61.040529114859446, 60.8783859525408, 59.833585330418174, 51.085303034101216, 52.86530644553048, 64.87013299124581, 60.52006040300642, 58.16635465621948, 52.24891437802996, 48.040835176195415, 49.07825333731515, 46.58011538641793, 49.961213043757844, 50.5313127381461, 51.85652528490339, 47.81926754542759, 50.19439458847046, 52.80781010219029, 49.86573089872088, 51.72669472013201, 49.42575011934553, 53.12652049745832, 63.19357436043875, 65.86881147112165, 67.9253670828683, 65.58342811039516, 67.95082528250558, 68.62714208875383, 69.34354305267334, 69.44031756264823, 69.39648137773786, 69.90366513388497, 67.24962697710309, 68.60070419311523, 65.19227232251848, 65.63440704345703, 60.81562287466866, 60.53185844421387, 57.46499306815011, 49.780208996364046, 7.777436562946864, 6.421627623694284, 8.810313207762581, 10.549705266952515, 4.581266513892582, 0.6036470085382462, 0.1484250027154173, 4.065082234995706, 66.99401664733887, 75.75760582515171, 43.41964735303606, 59.51949896131243, 133.52724266052246, 86.11154733385358, 27.02671377999442, 20.54300400188991, 62.67946325029646, 65.35776451655796, 85.24680927821568, 23.911092894417898, 0.45943454120840344, 0.2732884740190846, 0.22391954170806067, 0.16202881559729576, 0.10411534285438911, 0.14035589141505106, 0.1374602432229689, 0.11984257000897612, 0.17287240230611392, 0.07249680520700556, 0.13927962630987167, 0.12043506678725992, 0.22184591154967034], [0.017974989754813056, 0.04620429248149906, 0.026762106455862522, 0.05214954846139465, 0.04112702528280871, 0.05016123729624918, 0.04583764269149729, 0.11607813914971692, 0.05156085147921528, 0.04491383083430784, 0.07442922544266496, 0.09175605819161449, 0.5679409759385246, 67.6983277457101, 66.8813168661935, 62.846831457955496, 47.71998126166207, 30.820666449410574, 20.313996587480815, 41.993776253291536, 33.90057706832886, 40.39549255371094, 24.77540189879281, 0.25204392256481306, 1.4585251361131668, 2.482398109776633, 0.5660842869962964, 0.785105402980532, 1.7434146319116866, 71.70195620400565, 89.28621401105607, 76.07736887250627, 80.28456565311977, 76.40644250597272, 78.76556437356132, 76.79002475738525, 76.02149145943778, 75.81700597490583, 78.49167333330426, 75.07033865792411, 69.98791204180036, 65.58651311056954, 69.80127647944859, 66.36826883043561, 72.94430800846645, 74.54736859457833, 75.78033338274274, 64.07402924128941, 61.839933259146555, 69.05460221426827, 68.17787851606096, 64.14201041630336, 54.012217794145855, 47.31620059694563, 51.989642347608296, 47.437408447265625, 47.41031394686018, 47.189712115696494, 48.18848787035261, 46.04317944390433, 48.48877511705671, 46.97758708681379, 45.076580796922954, 42.760503019605366, 45.49932656969343, 42.37109122957502, 45.252801009586875, 47.61096749986921, 52.964964457920615, 54.84684930528913, 56.84093713760376, 56.31856114523751, 56.87046350751604, 56.00148357663836, 58.00242928096226, 53.9001225062779, 59.036779812404085, 53.73468589782715, 61.46480001722063, 55.054642132350374, 59.97780214037214, 58.586043221609934, 61.032802718026296, 55.272891998291016, 59.56098665509905, 51.99687542234148, 66.06296498434884, 32.947193895067485, 35.49056461879185, 67.86145755222866, 47.53629173551287, 58.80970573425293, 53.824765818459646, 51.877873625074116, 52.12202637536185, 55.72627932684762, 49.321874550410676, 48.457442215510774, 44.752183301108225, 49.478928157261436, 52.047753606523784, 56.11117478779384, 56.944812706538606, 56.344505718776155, 55.345455510275706, 53.233790261404856, 54.37016814095633, 52.375781536102295, 51.83172369003296, 59.3804099219186, 56.64034959248134, 55.175367082868306, 48.9615409714835, 45.33728068215506, 41.52328940800258, 44.20430047171456, 45.09232194083077, 46.6091171673366, 41.249304567064556, 42.15050329480852, 46.85468735013689, 44.15678174155099, 45.313135692051475, 43.4654220853533, 52.40753480366298, 56.860148906707764, 64.02389798845563, 62.98539938245501, 59.57504286084856, 63.47463594164167, 63.39653124128069, 62.844448225838796, 64.41056524004254, 60.29937171936035, 63.21261937277657, 62.112149783543174, 60.961986677987234, 61.102791922433035, 61.06974628993443, 59.501315525599885, 61.52120549338204, 56.6309243610927, 54.84042569569179, 26.07034809248788, 0.6321448822106633, 0.4313126845019204, 1.9292196674006326, 1.4862480142286845, 0.4733186161943844, 0.061439317118908675, 0.18650493078998157, 18.731759752546036, 78.76658575875419, 34.343892983027864, 61.10882990700858, 108.59601524897984, 119.68787629263741, 64.39602266039167, 11.26921468121665, 39.76848711286272, 46.50782980237688, 56.243722098214285, 28.65295355660575, 1.535569584795407, 0.12263198675853865, 0.08030862281365053, 0.0570541149271386, 0.0389359678540911, 0.04152560693078807, 0.04328067507594824, 0.05796447143490825, 0.09145470721913235, 0.12776982677834375, 0.1487339668508087, 0.026190272765234113, 0.014001389449861432, 0.01205313135869801, 0.05327842038656984, 0.020629971753805876, 0.06747501503143992, 0.08763893840036222, 0.11621326261333056, 0.035847954984222136, 0.03935207945427724, 0.014529339736327529, 0.035786449177456756, 0.13971008892570222, 0.01743786482672606, 0.885028315441949, 82.36017322540283, 73.48672607966832, 72.34167684827531, 53.954026630946565, 42.98192473820278, 20.945459297725133, 35.17104475838797, 39.17093161174229, 50.15252474376133, 24.362934248788015, 0.34220825295363155, 2.0061935484409332, 2.595086165836879, 1.2563862970897128, 0.6805696466139385, 2.3808629981109073, 82.17300265175956, 91.64520386287144, 80.79602949959892, 83.24270561763218, 80.36764526367188, 81.58921500614711, 80.78100749424526, 77.97458144596645, 77.72564833504813, 80.94670813424247, 76.24675900595528, 68.70198113577706, 68.56836032867432, 70.35759789603097, 68.95338780539376, 73.65564373561314, 77.43194798060826, 77.04005568368095, 68.29078674316406, 66.97324848175049, 70.2008534840175, 70.92529351370675, 67.4008058820452, 56.34370667593819, 49.762723854609895, 53.625640869140625, 51.09380415507725, 48.15723139899117, 48.26162460872105, 50.523951121738975, 49.16663442339216, 49.93767254693167, 49.45614848818098, 48.206139768872944, 45.396600927625386, 46.27347748620169, 45.61543444224766, 47.7850615637643, 49.70124966757638, 53.835820402417866, 56.81120579583304, 59.54820891789028, 60.2210933140346, 60.3134001323155, 56.95186512810843, 58.894904545375276, 58.20784929820469, 60.24594007219587, 58.350124086652485, 63.49903801509312, 61.3773569379534, 61.1897416796003, 58.94142273494175, 60.22500514984131, 60.538827487400596, 59.708476066589355, 58.25889771325247, 63.02157865251814, 52.378887380872456, 51.03241682052612, 64.21996920449394, 53.021175384521484, 59.595213481358115, 58.73806285858154, 57.10036550249372, 57.475571700504844, 59.59349727630615, 51.81164339610508, 49.55415630340576, 49.72015571594238, 52.26212290355137, 55.584171295166016, 58.41729927062988, 60.08594390324184, 57.887123925345286, 57.396664483206614, 56.05511324746268, 56.9275985445295, 53.28243112564087, 53.39628778185163, 61.627915927342, 59.68882656097412, 56.12189933231899, 54.55110270636422, 46.36176477159773, 43.39134039197649, 46.67207479476929, 45.71706574303763, 47.83446325574602, 45.59676463263375, 44.398189953395296, 48.20185273034232, 45.72666120529175, 47.58829205376761, 45.4328670501709, 55.99897527694702, 61.24251324789864, 65.15103476388114, 66.93602698189872, 64.03805146898542, 64.60400308881486, 64.20834486825126, 65.17910548618862, 64.69025107792446, 61.45949854169573, 63.03841413770403, 62.663183620997835, 61.84417166028704, 61.71552576337542, 62.29494299207415, 61.553709166390554, 62.23607785361153, 59.126606123788015, 56.8145409311567, 33.507135323115754, 2.3939699062279294, 0.6684326093111719, 0.292121810572488, 1.6361975222826004, 0.9131921870367867, 0.29372410316552433, 0.13545274308749608, 18.40991919381278, 81.90871402195522, 43.431226525987896, 59.53578553880964, 101.46272359575543, 96.91509287697929, 59.308871269226074, 21.381849595478602, 46.412493569510325, 53.18892921720232, 66.45572580610002, 41.856135913303916, 2.006295600107738, 0.16794726944395474, 0.07904793189040252, 0.12836562123681816, 0.07150993709053312, 0.04293858486094645, 0.08366013797266142, 0.04986271581479481, 0.09374437614211015, 0.0037324612577711897, 0.040075981324272494, 0.028204068009342467, 0.11113719642162323, 0.1163292106773172, 0.19096507717456135, 0.1122676357626915, 0.17886487075260707, 0.1661892259227378, 0.23779794414128574, 0.15928275723542484, 0.14839054670717033, 0.12061331793665886, 0.1772058933441128, 0.20030190902096884, 0.14287309348583221, 1.0414709150791168, 90.38106945582798, 83.5993149621146, 82.33563218797956, 65.27314240591866, 46.25271626881191, 31.9753007207598, 56.305317878723145, 51.136657169886995, 60.01417595999581, 32.01168496268136, 0.3761212160544736, 3.7808197055544173, 7.5156223603657315, 3.8779090557779585, 5.277904629707336, 1.9520688184670039, 79.85914829799107, 95.50975022997174, 83.42005838666643, 87.953702381679, 85.03356906345913, 83.53779561179024, 81.8719094140189, 81.86412048339844, 81.60164533342633, 83.42522784641811, 78.31278501238141, 70.68567793709892, 67.94626031603131, 73.72907229832241, 71.2568268094744, 74.81046213422502, 76.34953675951276, 79.31502791813442, 73.48468330928257, 69.95840304238456, 72.20786843981061, 72.83375522068569, 70.62047604152134, 58.75811535971505, 52.115679195949006, 56.66579736982073, 52.415733678000315, 52.040576117379324, 52.6795220375061, 52.68212761197771, 52.8212513923645, 52.3517199243818, 52.7194950239999, 49.366377762385774, 49.11452293395996, 48.709800788334434, 48.903662477220806, 49.686748777117046, 51.2089010647365, 58.21474538530622, 61.1215729032244, 60.78211171286446, 62.7874938419887, 61.647308349609375, 61.7743353162493, 62.76112542833601, 60.815678460257395, 63.35300077710833, 60.83475821358817, 67.34144742148263, 62.60732010432652, 63.33981309618269, 63.46520028795515, 66.27590642656598, 64.3913048335484, 62.088553701128276, 61.294687271118164, 66.00140394483293, 51.35064084189278, 52.270922797066824, 69.09713908604213, 56.0438745362418, 63.05610425131661, 61.25476292201451, 56.677463395254954, 60.33967127118792, 64.31065709250313, 54.869222504752024, 53.99514259610857, 53.04619237354824, 54.286289487566265, 59.115183285304475, 63.47203036717006, 61.346395765032085, 62.187544686453684, 60.78519671303885, 58.65956211090088, 59.686992236546104, 53.95224094390869, 56.49188395908901, 61.756117139543804, 61.11942590985979, 59.65690653664725, 56.28162799562727, 47.77867616925921, 47.11035326548985, 49.49078178405762, 49.06091063363211, 51.63284192766462, 49.23923962456839, 49.30014058521816, 52.27525847298758, 48.64194468089512, 49.314148153577534, 48.572087492261616, 58.97899859292166, 63.252453395298545, 69.22750118800572, 69.1452692576817, 65.2183906010219, 67.67910902840751, 67.25218391418457, 67.91828686850411, 67.93408012390137, 64.57966354915074, 66.02366597311837, 67.38713877541679, 63.99490315573556, 66.48527649470738, 64.5500155857631, 65.85652010781425, 65.84934261866978, 62.0728577205113, 59.10568509783064, 35.04925673348563, 2.8325666912964413, 5.027597078255244, 9.805126752172198, 6.943327035222735, 1.5357508893523897, 0.22904600948095322, 0.27868280027593884, 25.33229306765965, 91.64525944846017, 49.054629462105886, 73.08439758845738, 106.89092036655971, 124.02359390258789, 76.4627298627581, 20.407437699181692, 58.49052633558001, 60.603320666721885, 78.20214189801897, 51.84020744051252, 2.2756442555359433, 0.26529544006500927, 0.15346528297024115, 0.23719673497336252, 0.207890834659338, 0.0970646854756134, 0.14374760298856668, 0.20249749906361103, 0.25089904399854795, 0.12738026625343732, 0.15477311850658484, 0.10676729519452367, 0.18155542494995253], [0.06418296668146338, 0.03653347212821245, 0.035249575307326655, 0.058560578019491265, 0.08587480842002801, 0.056711366533168724, 0.030939113747860705, 0.06796503945120744, 0.09775880644364016, 0.15727951829986914, 0.1941493470221758, 0.33840666551675114, 8.663197261946541, 77.56787558964321, 64.27748639242989, 59.02940777369908, 40.77131714139666, 26.472224950790405, 30.60402509144374, 62.34788826533726, 29.595695563725062, 55.68544823782784, 7.830189023699079, 0.7446715012192726, 1.286110582096236, 1.52848177083901, 0.695655488542148, 1.5436943088259016, 37.76913602011544, 89.3695159639631, 77.32734285082135, 79.28235748835972, 76.50717748914445, 74.5792886189052, 74.32337256840297, 77.34459522792271, 71.84979997362409, 72.65313679831368, 73.74310071127755, 75.54824965340751, 74.1518007005964, 73.55410276140485, 73.99579974583217, 75.0070058277675, 72.65775040217808, 69.57523768288749, 65.96528720855713, 67.77789851597377, 68.58479976654053, 67.59388242449079, 65.60956723349435, 58.14103889465332, 52.29443897519793, 49.38999816349575, 48.84993205751692, 48.442145756312776, 44.0138955116272, 46.830379077366416, 47.453639439174104, 48.441878250667024, 48.500739915030344, 46.9828850882394, 47.77809599467686, 44.0197354725429, 45.03966154370989, 42.40412296567644, 45.89060395104544, 48.370516777038574, 50.888946941920686, 51.94987780707223, 54.364873613630024, 48.02992650440761, 46.87495524542672, 44.315878118787495, 45.310717718941824, 46.00388043267386, 52.02723210198538, 52.96270281927926, 57.62995025089809, 54.62886347089495, 62.87118489401681, 56.76053605760847, 64.57042939322335, 54.24701132093157, 65.86020960126604, 49.97356694085257, 77.38505458831787, 21.067667688642228, 21.28415444919041, 77.2959508895874, 46.12295171192714, 64.15310668945312, 48.108125005449565, 49.48765162059239, 50.43035193852016, 51.53877374104091, 44.03677940368652, 48.25257805415562, 45.32988085065569, 54.4933180127825, 54.35219662530081, 57.79662363869803, 53.52369689941406, 55.16751561846052, 54.65409932817732, 56.64479643957955, 51.89681094033377, 57.77037681852068, 52.002993311200825, 54.10298211233956, 58.7573093686785, 60.30906445639474, 53.2777167728969, 52.10413128989083, 42.43578590665545, 41.57057189941406, 43.54570157187325, 46.29310267312186, 42.21010841642107, 41.13443694795881, 43.56779336929321, 43.91151033129011, 43.46020746231079, 46.64411524363926, 53.3853964805603, 60.14741461617606, 61.10614790235247, 61.74928706032889, 60.84346430642264, 61.31389209202358, 58.3230539049421, 59.242800848824636, 61.29708439963204, 62.28999587467739, 59.84898253849575, 63.22885731288365, 64.82090500422886, 63.87470626831055, 62.44651794433594, 61.62902763911656, 63.45365238189697, 61.46985135759626, 60.60186154501778, 58.32924474988665, 23.97082829475403, 1.2732553290469306, 2.005422515528543, 1.7714380196162631, 2.161239560161318, 0.1615855965231146, 0.012435801360490066, 1.745148424591337, 55.926133837018696, 58.209575925554546, 39.695676939828054, 83.56053706577846, 95.88979584830147, 53.32789666312081, 22.128996338163102, 24.88531197820391, 51.02158110482352, 49.91978440965925, 47.93706035614014, 9.041000349181038, 0.2925921439060143, 0.043696915597787926, 0.22451651681746754, 0.16391996054777078, 0.07151292942996536, 0.03885672174926315, 0.020558778163311735, 0.028760096923049008, 0.06847731303423643, 0.16256636460976942, 0.0347577120576586, 0.03509601265458124, 0.01899048187104719, 0.025723150598683527, 0.05307843576052359, 0.06612028593995742, 0.1091136217915586, 0.07993320974388293, 0.13134512278650487, 0.040907254575618675, 0.03512880625203252, 0.12252655598734107, 0.16258612354951246, 0.36370896494814325, 11.402146748134069, 88.67899009159633, 70.4320478439331, 69.99813979012626, 50.93820966993059, 45.70092855181013, 30.697322028023855, 50.64678137642996, 37.651822635105674, 64.27236557006836, 7.153279014996119, 0.7078907777156148, 2.8032192374978746, 2.0829741827079227, 1.0189496321337563, 0.25675167994839804, 41.64794703892299, 94.49004650115967, 78.71613488878522, 82.60733454568046, 78.07625443594796, 78.01058006286621, 75.6407927104405, 82.36366816929409, 74.5161155973162, 74.51152283804757, 77.32907295227051, 77.51304735456193, 74.39632865360805, 75.49693720681327, 75.50993728637695, 77.40739999498639, 74.85796696799142, 72.8128411429269, 68.71703788212368, 69.81233801160539, 70.35600675855363, 69.94618116106305, 66.62012713296073, 62.330920764378135, 53.197360856192454, 51.17572341646467, 51.722994804382324, 50.217226369040354, 48.32196971348354, 49.20646844591413, 48.90142168317522, 50.11895799636841, 49.77471991947719, 49.659032412937705, 50.7072411264692, 47.18537296567644, 47.47579377038138, 45.21557950973511, 48.2015609060015, 52.22379664012364, 54.151650769369944, 54.42809527260916, 56.707587310246055, 48.79678528649466, 48.83382613318307, 48.22117567062378, 48.421943868909565, 47.95757491247994, 51.82082544054304, 54.5158440726144, 58.151631423405235, 58.114802496773855, 62.06503404889788, 57.24791744777134, 62.38579763684954, 55.883374622889924, 64.43425859723772, 55.960621220724924, 73.11660943712506, 44.65457500730242, 41.33339861461094, 72.77607822418213, 52.83331346511841, 64.160888671875, 52.050206320626394, 51.54026412963867, 55.09930862699236, 54.13597910744803, 48.32065650394985, 49.01488924026489, 48.26810727800642, 55.782549313136506, 56.11603505270821, 59.35445145198277, 55.049934727805, 57.84728990282331, 58.32934897286551, 59.73435115814209, 57.074375765664236, 60.39081696101597, 55.942802565438406, 55.712841510772705, 59.801206724984304, 63.0143038885934, 56.58478832244873, 56.24986777986799, 46.37820420946394, 43.48805931636265, 46.93840619495937, 49.083766732897075, 46.17854424885341, 43.009456975119456, 46.14572443280901, 45.67964621952602, 45.55517271586827, 47.890323298318044, 56.93510259900774, 63.34984629494803, 64.78295394352504, 62.60091386522566, 61.73829501015799, 62.976915631975444, 61.10639803750174, 62.65612425122942, 62.69724369049072, 64.4192921774728, 64.20428017207554, 65.30215113503593, 66.66473456791469, 64.0010175704956, 65.73839378356934, 61.96180466243199, 66.72007002149309, 65.39082404545375, 65.49076693398612, 61.83873816898891, 31.5524229322161, 3.1878836708409444, 0.34349554244961056, 0.5970223354441779, 1.1930203544242042, 1.0637432570968355, 0.15446933837873594, 1.2078745173556464, 57.90359810420445, 67.18746144430978, 46.403763157980784, 78.19063568115234, 100.38945620400565, 56.71848208563668, 23.0419305733272, 32.87610687528338, 57.50970125198364, 56.077020917619976, 61.110414096287315, 12.172003677913121, 0.3192600629159382, 0.07905389621321644, 0.21488288018320287, 0.10021074023097754, 0.023736549341785054, 0.039007298847926516, 0.05119779792481235, 0.03246270306408405, 0.13392943197063037, 0.19546338436858995, 0.044902804640254805, 0.03346350828983954, 0.192493735147374, 0.10532935735370431, 0.17008781672588416, 0.24223629598106655, 0.1860894909394639, 0.25505862651126726, 0.18760186407182897, 0.18399930452661856, 0.19654289287115845, 0.32611364658389774, 0.21529556518154486, 0.5687819250992366, 14.12298401764461, 102.27818502698625, 79.79775401524135, 79.78299604143415, 58.294691358293804, 41.03851359231131, 46.53820037841797, 86.87888554164341, 43.390871388571604, 78.56081485748291, 10.25971611908504, 0.9856457220656532, 3.601154489176614, 6.479179986885615, 4.3092575669288635, 3.2003954223224094, 42.29120431627546, 99.2113196509225, 82.55531338282994, 85.67438752310616, 81.51465388706752, 81.44705486297607, 79.56459331512451, 87.6613221849714, 76.9785154887608, 77.10279096875871, 80.09283011300224, 82.50489725385393, 78.80064582824707, 77.48638016836983, 75.0343747820173, 74.89238834381104, 77.18963650294712, 78.24514429909843, 74.24427427564348, 74.36572183881486, 72.10010187966483, 73.60644354139055, 69.66189561571393, 65.10284900665283, 57.243425437382285, 53.66793802806309, 52.93205084119524, 53.50478737694876, 50.91182388578142, 51.83573627471924, 52.126080649239675, 53.08962556294033, 52.65226425443377, 52.40625286102295, 54.25253513881138, 50.32268612725394, 50.27741513933454, 46.85831083570208, 51.88568687438965, 54.74929659707205, 55.793089730399, 58.68508979252407, 59.02030563354492, 51.77492216655186, 52.60613168988909, 50.176572459084646, 50.95607696260725, 51.131237574986045, 55.728388105119976, 58.59035805293492, 62.32335417611258, 60.74025576455252, 64.89032445635114, 61.56736932482038, 67.15807751246861, 61.98717253548758, 69.67428425380162, 57.09182269232613, 78.55768121991838, 31.013089861188615, 30.013369151524135, 79.09770216260637, 54.995776993887766, 68.94987896510533, 52.90289272580828, 52.386533873421804, 57.85885170527867, 56.595450333186555, 51.21447352000645, 51.15181466511318, 51.10640123912266, 58.459481784275596, 59.32690184456961, 61.74939128330776, 57.979924065726145, 59.58259555271694, 62.39396871839251, 64.00036443982805, 60.60054833548409, 64.21128395625523, 57.32359722682408, 58.51090540204729, 60.96327209472656, 63.56798498971121, 58.83742209843227, 59.53484058380127, 49.02620785576956, 47.162058285304475, 49.42757054737636, 51.74513871329171, 49.81659671238491, 46.14394569396973, 48.420672348567415, 48.129615783691406, 48.562703950064524, 51.11335638591221, 60.82349518367222, 65.19175120762416, 67.00921235765729, 63.95141438075474, 64.16868455069405, 64.65299483707973, 62.127595629010884, 65.61257580348423, 65.8347166606358, 67.6030193056379, 66.5057041985648, 69.38143157958984, 70.63191972460065, 68.69048186710903, 68.2537042072841, 65.7577097756522, 71.49237768990653, 68.4472323826381, 68.0246637889317, 64.05931295667375, 31.60480887549264, 4.010782931532178, 5.3994811688150675, 6.129216160093035, 8.192187564713613, 1.0471558443137576, 0.2321254728095872, 2.860475650855473, 71.74315902165004, 73.16795662471226, 56.36232784816197, 85.76415130070278, 100.89651489257812, 62.29076017652239, 31.596019404275076, 39.141488620213096, 69.81044115339006, 66.50407137189592, 74.36810507093156, 14.578988211495535, 0.41086375606911524, 0.1567547528871468, 0.3532986635608332, 0.28086228189723833, 0.1119695281875985, 0.11730525616024222, 0.16478370848510945, 0.15057996208114283, 0.2590561477201325, 0.2945649709020342, 0.1530411443007844, 0.16768323789749826], [0.07883643931043999, 0.05178094109786408, 0.15160825476050377, 0.016891532178436006, 0.08383180733237948, 0.0654788464307785, 0.040776585694402456, 0.07960389634328228, 0.30283747985959053, 0.1607083050268037, 0.3476132186395781, 0.16071591818971293, 29.930435453142437, 75.10225173405239, 59.84812791006905, 56.58689362662179, 34.709034715379985, 14.72236602646964, 41.65329715183803, 30.701834883008683, 36.66356297901699, 62.592388425554546, 0.8799276862825666, 0.5071099315370832, 1.502090449844088, 0.0727281788630145, 1.6110932465110506, 5.707947313785553, 85.98065716879708, 82.99514130183628, 81.78714139120919, 68.88212708064488, 64.0583610534668, 66.8886194229126, 68.58800288609096, 66.02071298871721, 69.73863846915108, 69.06137670789445, 69.76235961914062, 71.67738737378801, 75.33402974264962, 73.75848402295793, 70.36864553179059, 65.23245375497001, 64.4497183391026, 66.32011781420026, 68.95206069946289, 66.98849977765764, 65.88827337537492, 63.71755886077881, 60.51006194523403, 52.41799531664167, 48.655677795410156, 49.7935391153608, 49.776939868927, 45.454618385859895, 43.44917024884905, 46.277663775852744, 46.317265033721924, 46.454519748687744, 47.36578294209072, 45.49352829796927, 44.91493443080357, 40.23735155378069, 41.538571970803396, 41.35138055256435, 44.97480705806187, 48.09361021859305, 49.08821357999529, 48.71546009608677, 47.11109324863979, 44.134887967790874, 48.535279410226, 47.604828766414094, 51.78059537070138, 44.72933415004185, 48.1235465322222, 45.1642427444458, 52.98921367100307, 49.89660174506051, 62.52292728424072, 58.576447759355815, 64.43068027496338, 51.22859573364258, 64.13787623814174, 48.363818713596885, 72.6867035457066, 12.245623316083636, 8.678087251526968, 70.82997117723737, 46.87237746374947, 62.645159993852886, 43.528845242091585, 55.00748470851353, 50.06817708696638, 51.56844254902431, 43.450229849134175, 50.98459236962454, 50.595639160701204, 57.18233687537057, 56.04704638889858, 57.881138052259175, 52.528909410749165, 57.34051956449236, 51.58192900248936, 49.11462715693882, 48.55674934387207, 53.70248099735805, 55.01108387538365, 55.224483898707796, 53.905535152980256, 58.282250608716694, 54.908250536237446, 58.663640703473774, 49.13033703395298, 40.71801403590611, 40.96617589678083, 43.77084405081612, 40.977386815207346, 41.57596022742135, 42.323287623269216, 46.518158299582346, 43.973616804395405, 47.257602964128765, 52.07083552224295, 60.54426097869873, 57.03513928822109, 59.883890288216726, 60.96228545052664, 60.81877735682896, 60.82544067927769, 58.27446167809622, 59.722108432224815, 58.28121532712664, 57.370261328560964, 56.444021293095176, 57.18490423474993, 61.626290048871724, 57.24204274586269, 58.68907805851528, 64.39755821228027, 62.0832313810076, 64.5079095023019, 63.97883892059326, 53.31223889759609, 28.490730490003312, 1.711675803576197, 1.010755100420543, 1.7272009019340788, 0.9666025553430829, 0.11849604440586907, 0.07735663585897003, 18.99355571610587, 66.61236599513462, 43.64563751220703, 44.82657766342163, 62.32081808362688, 25.993176187787736, 30.07331473486764, 18.504418168749126, 37.89209829057966, 50.27195732934134, 51.41522782189505, 27.12866469791957, 1.3889113515615463, 0.04047048497678978, 0.1691506105874266, 0.09313817974179983, 0.14206369620348724, 0.03142927387463195, 0.18795529939234257, 0.09519060568085738, 0.09044436857636486, 0.09355240501463413, 0.021619686324681555, 0.0479398934569742, 0.029507465926664214, 0.058609364687332084, 0.047282630511160405, 0.05345146717237575, 0.03264266751440508, 0.031208397155361514, 0.017166047090930597, 0.05058116226324013, 0.16027607821992465, 0.06602926046720572, 0.2548294716647693, 0.2045632310743843, 37.154498372759136, 84.35623087201799, 65.77498994554792, 64.71493107931954, 47.097599846976145, 25.32191593306405, 34.36491475786482, 33.67931168419974, 46.2218245778765, 67.27054800306047, 0.45343656305755886, 0.8682324567011425, 2.53375962802342, 0.5306167730263301, 0.841218457690307, 6.972337067127228, 95.31558976854596, 88.63325010027204, 86.45911707196916, 69.55444867270333, 68.57066713060651, 67.91433334350586, 72.73690428052629, 69.57773208618164, 71.09786592211042, 71.60590430668422, 74.39985139029366, 75.4076042175293, 76.18969345092773, 76.66822978428432, 74.94880771636963, 67.86315986088344, 67.50912829807827, 69.04427024296352, 70.98536763872418, 67.75898551940918, 65.86099474770683, 67.54425839015416, 62.85007626669747, 54.505282810756135, 52.24983154024397, 51.83863019943237, 53.329623290470664, 47.19309936250959, 46.35596997397286, 49.77700240271432, 49.530542850494385, 50.175002166203086, 48.15228428159441, 48.63809885297503, 48.374119418007986, 43.77731282370431, 45.429650034223286, 44.61281285967146, 48.3512806892395, 49.96080657414028, 51.69261728014265, 52.34950344903128, 47.41048070362636, 44.09416110174996, 52.22085060392107, 52.236049788338796, 55.178563254220144, 45.9721862248012, 51.69040775299072, 46.99467618124825, 56.16835151399885, 52.55175856181553, 62.6945686340332, 59.572868074689595, 65.42536354064941, 52.972993101392476, 66.52688230787004, 51.02445765904018, 75.74300071171352, 24.548027311052593, 17.349634511130198, 73.88706043788365, 49.982505798339844, 65.58557510375977, 46.90231030327933, 57.578509262629915, 53.18810585566929, 54.590408665793284, 46.678237846919465, 53.08823939732143, 52.655349254608154, 60.020498820713584, 59.194795744759695, 60.72097451346261, 54.99962282180786, 59.50640855516706, 54.68987212862287, 51.85878692354475, 52.22616250174386, 56.2596195765904, 58.539754322596956, 58.98401519230434, 56.11356496810913, 59.077058519635884, 56.74796676635742, 61.18227236611502, 52.095619746616904, 42.576924664633616, 45.01012822559902, 47.46306119646345, 45.283494676862446, 42.86378799165998, 43.28386218207223, 48.31120695386614, 46.87421178817749, 49.85233129773821, 54.97698559079851, 62.51165730612618, 61.453439712524414, 62.965965270996094, 63.313389096941265, 61.38376317705427, 63.3327328818185, 61.02835587092808, 61.59045818873814, 60.64437757219587, 59.45629119873047, 58.54185267857143, 60.42609296526228, 62.488637924194336, 58.88441276550293, 60.29162447793143, 68.3560859135219, 63.96064853668213, 68.27659852164132, 65.81441402435303, 58.74244022369385, 38.43634721211025, 4.392790981701442, 0.45334634504147936, 0.9465875093426023, 1.3648932746478488, 0.45329094944255693, 0.05696959660521575, 19.27161741256714, 71.08979906354631, 56.28840248925345, 45.76845114571707, 63.81661237989153, 36.834933349064414, 32.83502565111433, 31.16934789930071, 42.979159355163574, 59.30125604357038, 59.4817077091762, 39.65589850289481, 1.4525160299880164, 0.08442061288016182, 0.14322738376046928, 0.05996648222208023, 0.16228243841656617, 0.04915668655719076, 0.05014413142842906, 0.11402818986347743, 0.22084043121763638, 0.09121811562883002, 0.043913059535303285, 0.048806477670690844, 0.20372078913663114, 0.1373019545738186, 0.22280328374888214, 0.13417168254298822, 0.1882409354937928, 0.1097301115681018, 0.10698324574955873, 0.20368497605834687, 0.5518684355275971, 0.1991969147430999, 0.567159140748637, 0.36849239255700794, 42.851715496608186, 96.50653879983085, 75.68768610273088, 74.38110515049526, 49.10838072640555, 22.566870076315745, 56.15313843318394, 46.86635684967041, 55.83655766078404, 78.79157842908586, 1.6140545904636383, 1.1056790011269706, 5.02216054712023, 3.340366014412471, 4.138822163854327, 6.795941412448883, 97.06798798697335, 91.55811514173234, 91.45687988826207, 74.38859530857631, 70.52006762368339, 71.32856001172746, 74.84143025534493, 72.51695210593087, 74.51258591243199, 74.93016569955009, 76.88531930106026, 77.31312683650425, 78.01316479274205, 76.71163518088204, 76.92613996778215, 71.06432696751186, 70.3272134235927, 70.19949858529228, 73.40036691938127, 70.67030157361711, 72.65859113420758, 71.13209969656808, 67.11413710457938, 58.55676351274763, 54.25724254335676, 54.59419195992606, 55.59873471941267, 49.648384298597065, 48.9580078125, 53.48752457754952, 54.44463545935494, 53.61418676376343, 51.06106424331665, 51.21288585662842, 52.670152391706196, 46.30262517929077, 48.27084486825125, 46.19476134436471, 52.744393893650596, 52.55961697442191, 54.40248768670218, 55.006227084568565, 52.182777949741904, 48.417622089385986, 54.595150811331614, 53.8339443887983, 58.46718038831438, 48.45168563297817, 55.01389789581299, 48.85551493508475, 57.472907066345215, 54.152508871895925, 68.27119282313755, 62.46078954424177, 71.79246343885148, 52.73788343157087, 72.68880884987968, 51.97032288142613, 83.84708772386823, 16.88766442026411, 11.353776863643102, 85.60758059365409, 51.90045179639544, 69.05094051361084, 48.095322949545725, 58.73547118050711, 53.889429228646414, 57.29111092431204, 50.71459232057844, 60.00223895481655, 55.89328275408064, 63.851089341299875, 61.922005380902974, 63.76860727582659, 56.059980460575645, 64.60420458657401, 58.28260496684483, 54.22771964754377, 54.80177634102957, 61.695209230695454, 61.15113748822893, 62.910595076424734, 59.24618462153843, 65.18814509255546, 57.50621325629098, 64.03195789882115, 55.12693119049072, 44.886828967503135, 46.59406042098999, 51.02494403294155, 47.213930061885286, 46.81235197612217, 47.50755746023995, 52.29686737060547, 50.46569742475237, 53.481267724718364, 58.82793780735561, 66.67009857722691, 64.447112764631, 67.74015590122768, 65.26757689884731, 65.4065408706665, 67.32949651990617, 64.67971760886056, 65.26564529963902, 64.28510161808559, 61.98494216373989, 62.46889114379883, 63.83653286525181, 69.01924283163888, 61.294360705784385, 63.876721245901926, 71.71269811902727, 69.12078380584717, 73.25235639299665, 69.45827865600586, 59.74787930079869, 40.32483632223946, 3.6071605554648807, 3.668244991983686, 9.088766608919416, 3.3825891315937042, 0.423515367188624, 0.30017599410244394, 26.524920088904246, 78.8097757611956, 62.00389684949602, 56.62057154519217, 71.23211206708635, 36.75615814753941, 41.132689476013184, 32.19350889750889, 50.589253766196116, 69.53210326603481, 70.68771375928605, 46.463489873068674, 1.857554861477443, 0.11024914335991655, 0.3537965996989182, 0.147268982604146, 0.2691592355923993, 0.16074482378150734, 0.22165736023868832, 0.1518084497324058, 0.3033091974045549, 0.4314806083483355, 0.21584231512887136, 0.18791518440204008], [0.052808083660368405, 0.09086892115218298, 0.11404037635241236, 0.01613835830773626, 0.08757189235516957, 0.06156483931200845, 0.07976817645664726, 0.0480058063486857, 0.14212203664439066, 0.047825468704104424, 0.1512333641627005, 0.8039981520601681, 66.22369071415493, 62.74983460562569, 64.23071806771415, 50.596007415226524, 30.5139000075204, 36.62511512211391, 68.75833102634975, 31.38423136302403, 57.6482379095895, 42.90535906382969, 0.16410307000790322, 1.15033073084695, 1.4419752870287215, 0.27307275416595594, 0.8241790320192064, 40.118999413081575, 91.1624777657645, 72.58207757132394, 73.91717393057687, 66.89642224993024, 69.56685815538678, 61.09859521048409, 63.321546282087056, 62.85200091770717, 64.46731117793492, 66.17662361689976, 68.18250601632255, 69.19153731209892, 66.6188417162214, 64.37221118382045, 70.22574887956891, 71.07785511016846, 71.76451778411865, 72.09126377105713, 66.74288095746721, 63.01984160287039, 62.70262854439871, 56.84557853426252, 53.608249528067454, 48.06919424874442, 50.04867001942226, 48.73926115036011, 51.52836881365095, 44.1196470941816, 45.171517508370535, 44.29864311218262, 48.5686411857605, 48.47462511062622, 46.95500891549246, 45.83973271506173, 42.613100460597444, 42.21370758329119, 40.74034207207816, 43.59873717171805, 44.85886246817452, 47.23808894838606, 49.31311982018607, 44.52645369938442, 45.65342371804373, 46.53659881864275, 57.53159849984305, 57.552939891815186, 58.19283076695034, 50.301487173352925, 47.472420419965474, 45.57634735107422, 50.31440387453352, 51.27379376547677, 58.09000785010201, 56.20212670734951, 60.190660204206196, 53.89768368857247, 60.195113999503, 52.628998211451936, 57.45394543239048, 12.22268123286111, 8.157881702695574, 57.6741373198373, 52.038484709603445, 53.05103179386684, 49.58537803377424, 58.1722606250218, 46.81251178468977, 44.13803202765328, 40.95231424059187, 51.16093764986311, 51.3091253553118, 56.634648595537456, 54.55808217184884, 56.46329212188721, 53.601113728114534, 51.28534514563424, 47.34367030007498, 44.88187142780849, 41.41449104036604, 51.24730028424944, 51.86937597819737, 58.6721522467477, 57.183632714407786, 56.16203907557896, 49.04772295270647, 53.59388760157994, 54.35792541503906, 47.25306926454817, 42.32949931280953, 42.19991193498884, 41.22727530343192, 39.96012885229928, 39.30609144483294, 47.15876483917236, 42.06296294076102, 44.080327238355366, 49.052499839237754, 56.089836869921, 55.784032753535676, 56.42267990112305, 55.63781138828823, 56.38604899815151, 52.143437249319895, 54.25541864122663, 53.309181690216064, 55.334546838487896, 51.80161714553833, 55.38002974646432, 52.22172260284424, 54.444896016802105, 53.42942026683262, 61.93110752105713, 60.399043628147666, 62.80042443956648, 62.55682059696743, 61.584253447396414, 58.095045294080464, 55.9288957459586, 32.17861543382917, 2.5945841584886824, 0.45697162193911417, 1.9220777877739497, 0.6647206427795547, 0.05098593893593975, 1.8720928813729967, 51.47923115321568, 62.241921288626536, 45.45583432061331, 17.70772555896214, 30.917989867074148, 15.972814219338552, 13.579939740044729, 29.242980684552872, 43.99019520623343, 50.308588232312886, 54.81760433741978, 6.702484667301178, 0.2735722373638834, 0.19425196865839617, 0.17703195767743246, 0.1199096499809197, 0.026959945214912295, 0.07947583642921277, 0.0528308281541935, 0.01671044814533421, 0.015894737094640732, 0.12275032326579094, 0.04430293897166848, 0.034609163778701, 0.0934082909620234, 0.06182923726737499, 0.07739636408431189, 0.09908452816307545, 0.025841224173616086, 0.04581510854352798, 0.0416744978699301, 0.07723019764359508, 0.09701301503394331, 0.14039170449333532, 0.9243283037628446, 76.47344398498535, 69.33817209516252, 69.99581909179688, 58.74551132747105, 41.808801310403005, 34.25762414932251, 47.41186686924526, 37.174599511282786, 69.49235262189592, 44.650496414729524, 0.2330047727695533, 1.104921321783747, 3.2266207465103696, 0.6182865372725895, 0.3874580705804484, 45.8388329233442, 97.10369477953229, 75.08636815207345, 76.33955914633614, 68.8308354786464, 70.84880079541887, 64.19725554330009, 66.631758417402, 65.15074293954032, 67.35816478729248, 69.01483072553361, 71.0368537902832, 72.70713124956403, 70.78630869729179, 66.73693329947335, 72.80058452061245, 71.51733561924526, 73.31675229753766, 73.60781233651298, 69.46465015411377, 65.67228167397636, 64.87533719199044, 61.01086030687605, 54.73824201311384, 50.2620005607605, 52.09008550643921, 50.5461436680385, 53.56447240284511, 45.6565260887146, 47.625624724796836, 46.2711637360709, 52.231682845524375, 49.77055447442191, 50.08056919915335, 47.9649087360927, 44.898818084171836, 44.180214541299, 43.443834032331196, 46.18230322429112, 47.770536354609895, 50.63422250747681, 49.20530462265015, 47.74069036756243, 47.917608874184744, 50.94478266579764, 59.37103680201939, 60.53564521244594, 59.497396741594585, 54.04470409665789, 51.30775308609009, 49.301377364567344, 51.427974292210166, 52.215031487601145, 59.75208990914481, 58.0874057497297, 63.23954364231655, 57.66931874411446, 63.3081362588065, 54.7235917363848, 61.84185791015625, 17.028325489589147, 12.522320560046605, 60.403914315359934, 52.22880629130772, 55.53085776737758, 52.86277035304478, 59.71098436628069, 49.902969769069124, 45.93556921822684, 43.60216958182198, 54.13474580219814, 52.92395966393607, 59.32946572984968, 58.691044398716514, 57.75017840521676, 55.22174283436367, 55.52840505327497, 50.93547902788435, 47.14255469185965, 45.037368638174875, 51.82173218045916, 54.466737679072786, 60.79964896610805, 60.51167392730713, 57.91489587511335, 53.19114221845354, 57.49399484906878, 56.32430035727364, 50.20075566428048, 44.04362685339791, 45.558174337659565, 43.279078347342356, 43.036211013793945, 43.40056759970528, 48.073095662253245, 45.483918939317974, 48.131467478615896, 50.17126750946045, 56.970871925354004, 57.73336376462664, 59.02419662475586, 57.63238559450422, 58.738132340567454, 54.904484612601145, 55.84019504274641, 55.739150864737375, 56.97654512950352, 54.78144243785313, 57.23753336497715, 55.3510696547372, 55.837276799338206, 57.381503513881135, 62.8153908593314, 63.70052882603237, 65.33747577667236, 63.112989153180806, 64.45014217921666, 60.02809320177351, 59.830604553222656, 40.5326360974993, 5.132533116000039, 0.41921633215887205, 1.2697152218648364, 0.7986329485263143, 0.08623792643525771, 1.3825093465191978, 55.73072964804513, 69.47900513240269, 56.691665513174875, 22.13672968319484, 23.633371659687587, 20.37629066194807, 22.588428599493845, 40.063295704977854, 53.52010120664324, 55.543548652103965, 66.75648553030831, 11.160250425338745, 0.3922251047832625, 0.19590456783771515, 0.08278614415654115, 0.053941651047872644, 0.02008928621320852, 0.038395779340394905, 0.026897385982530456, 0.08679505118301936, 0.09137422618057046, 0.09877221885004214, 0.05893484436507736, 0.12297854173396315, 0.1466337652610881, 0.17707127199641295, 0.19157887995243073, 0.19738397773887428, 0.09292873633759362, 0.19616356465433324, 0.1170794532767364, 0.19510111452213355, 0.13969817385077477, 0.20666588896087237, 1.245672500559262, 88.81653663090297, 80.23278767721993, 80.527724811009, 65.82410676138741, 41.10475771767752, 51.445442063467844, 89.3939458302089, 49.12353474753243, 77.03480979374477, 52.930657727377756, 0.3278170408947127, 1.8348826723439353, 5.561686430658613, 4.227010437420436, 1.4568028513874327, 48.43501343045916, 101.88320772988456, 77.7873205457415, 80.6294047491891, 72.47482517787388, 73.1593130656651, 66.82647473471505, 69.96518448420933, 68.11292675563267, 70.66588946751186, 72.0593090057373, 74.54310240064348, 75.0595828465053, 73.40628678458077, 70.9158717564174, 78.81017875671387, 74.09729208265031, 76.31946495601109, 75.69813619341168, 72.88531085423061, 70.30424962724958, 67.92558942522321, 64.50090571812221, 58.86518710000174, 51.813446453639436, 54.94479806082589, 51.9754193850926, 58.253266198294504, 49.62595203944615, 49.93451806477138, 48.00166123253958, 54.845949513571604, 53.03906699589321, 52.37346083777291, 49.55389922005789, 48.28367471694946, 49.14265966415405, 44.5529054914202, 50.35367161887032, 52.05039739608765, 53.36033085414341, 54.373892375401084, 50.10432856423514, 52.01447868347168, 50.364239828927175, 63.6556156703404, 62.081744466509136, 63.76142283848354, 55.82697262082781, 52.84563956941877, 49.70720427376883, 55.53643717084612, 55.75599329812186, 63.694608960832866, 63.09386076245989, 67.41093635559082, 56.90422827856881, 69.46519906180245, 55.27385779789516, 71.25841794695172, 15.871440001896449, 10.451490742819649, 70.90679046085903, 52.651301928928916, 60.19039617265974, 53.987614222935264, 62.566527230399, 50.43509060995919, 48.79682697568621, 44.967987401144846, 57.36913224628994, 56.25496080943516, 61.40131432669503, 61.19524465288435, 61.8728677204677, 59.74866444723946, 60.93263053894043, 52.96322046007429, 48.8268084526062, 47.75570542471749, 56.03262192862374, 58.35279219491141, 65.4271492276873, 63.495647294180735, 61.36307144165039, 56.26940264020647, 61.28632858821324, 57.55743190220424, 52.0063909803118, 47.59341982432774, 48.98933029174805, 46.55424724306379, 46.20640652520316, 45.354074478149414, 52.78310578210013, 48.09478446415493, 51.85130023956299, 53.985696520124165, 61.83018493652344, 61.55217361450195, 64.44595241546631, 60.86256490434919, 62.67173685346331, 57.84423964364188, 59.551627431597026, 58.28957748413086, 62.169083322797505, 57.44393655232021, 62.15797315325056, 58.707518577575684, 60.18320478711809, 59.543574469430105, 66.70463112422398, 66.92964853559221, 68.81760610852922, 66.31069605691093, 66.65251963479179, 63.70353739602225, 61.668000085013254, 41.696758134024485, 4.826750712735312, 1.7516398876905441, 7.049521999699729, 1.5789994086538042, 0.12758042051323823, 2.869973838329315, 66.74770300728935, 75.9680598122733, 63.09998212541853, 29.69134099142892, 41.6135812486921, 22.407768487930298, 21.99475540433611, 41.81496088845389, 61.46322277614048, 64.4671652657645, 77.00412654876709, 12.541170154299055, 0.5828134321740696, 0.37923476898244446, 0.3136127788041319, 0.1830731313675642, 0.12647467984684876, 0.1280677579343319, 0.13761501706072263, 0.20587747198130402, 0.49478936408247265, 0.1940745317510196, 0.16362472996115685], [0.04130165644788316, 0.031064669867711406, 0.17416455011282647, 0.09917872239436422, 0.08863509566123996, 0.026298142869823744, 0.04807698127946683, 0.07879568649721996, 0.12309678324631282, 0.1878032125532627, 0.30479955886091503, 8.714987397193909, 75.21383285522461, 59.361232893807546, 60.288956369672505, 43.265227113451274, 19.058019365583146, 37.47346585137503, 52.998649324689595, 26.534194196973527, 84.58529908316476, 15.600284814834595, 0.07243549278272049, 1.3129284573452813, 0.5780131497553417, 1.2066097280808856, 4.285905974251883, 79.07427978515625, 78.72094999040876, 77.44186305999756, 71.27892208099365, 78.23969691140312, 72.26650428771973, 66.29840469360352, 58.38658823285784, 64.36057295118059, 62.99192374093192, 68.23344326019287, 66.75725678035191, 71.07049001966203, 69.48966366904122, 71.47367313929966, 70.87223012106759, 66.9995196206229, 64.98655005863735, 67.47668715885708, 68.2962202344622, 64.20081302097866, 54.143253871372764, 53.806165490831646, 48.87708561761038, 50.516405378069194, 51.15368720463344, 49.623103278023855, 47.281984192984446, 43.96035616738455, 45.02323252814156, 44.38073260443551, 50.44260161263602, 48.8089724268232, 44.46783174787249, 43.56893982206072, 40.603334018162315, 38.79582616261074, 40.02913836070469, 41.02240766797747, 42.751755237579346, 47.185873235974995, 47.231165068490164, 43.24703672954014, 45.28611067363194, 52.25064447947911, 60.58248996734619, 58.449552808489116, 56.097705704825266, 56.086651120867046, 54.04957825796944, 50.618828773498535, 51.42765120097569, 52.259569440569194, 57.17119543892996, 56.792817388262065, 55.683864048549104, 56.620345728737966, 57.075782775878906, 54.57470921107701, 44.20028441292899, 11.964426245008196, 9.852533442633492, 50.06406375340053, 43.39093739645821, 52.379933084760395, 54.71146365574428, 53.291772978646414, 42.85064894812447, 43.63526732581002, 47.156451089041575, 54.6470364843096, 54.47406455448696, 58.99098423549107, 55.15295219421387, 52.52717236110142, 50.125548362731934, 49.863962582179475, 43.48361941746303, 43.38165807723999, 44.75416701180594, 44.22143472943987, 43.31105743135725, 46.58255073002407, 51.73563705171858, 55.45332976749965, 54.50660296848842, 50.87108659744263, 49.76653841563633, 50.81645291192191, 45.15629400525774, 42.11461932318551, 40.44099630628313, 41.940052781786235, 40.22306605747768, 45.193195887974326, 44.47459234510149, 45.06080838612148, 42.75922802516392, 50.3051940373012, 52.32490682601929, 53.47158193588257, 50.19687162126814, 52.73645905085972, 51.30591181346348, 50.79206126076834, 51.66904204232352, 51.37625190189907, 49.1740585735866, 50.64026744025094, 48.753501483372276, 53.35095426014492, 54.81529058728899, 59.818313189915244, 61.239643641880576, 64.74020862579346, 63.7694410596575, 63.010489327566965, 60.80353995731899, 64.53807163238525, 58.11849199022566, 35.95396777561733, 0.37690294267875807, 0.3114154652825424, 0.7403523815529687, 0.15537575259804726, 0.10119181365839072, 26.896719932556152, 64.42580263955253, 62.61160019465855, 43.96189866747175, 52.57315901347569, 31.848221642630442, 17.643376554761613, 12.315040162631444, 38.727136271340505, 48.60340302331107, 57.0666424206325, 27.894380501338414, 0.47782224310295923, 0.13125252989786013, 0.17774570866354875, 0.09200697365616049, 0.0597136736448322, 0.05392387343038406, 0.002781097698191713, 0.07788590674421617, 0.08354870895189898, 0.08201270244483437, 0.05362505339352148, 0.06119252714727606, 0.0408407208243651, 0.12346236434366022, 0.061367222773177285, 0.12326373000230108, 0.0356962616954531, 0.056928640231490135, 0.09838656668684312, 0.13892315115247453, 0.19091734902134963, 0.40495871007442474, 11.032978534698486, 89.71839891161237, 65.24794823782784, 70.19300896780831, 52.08777870450701, 29.730910982404435, 27.194214003426687, 48.0667519569397, 35.82956027984619, 92.45330715179443, 15.308217287063599, 0.08374910069895641, 2.312291226216725, 1.5293714659554618, 0.8211584112473896, 3.420498068843569, 88.95163740430559, 80.35027476719448, 81.22697762080601, 76.24915613446916, 81.24026952471051, 76.4161491394043, 71.1635194505964, 59.56388405391148, 66.942884853908, 64.49409648350307, 69.60116836002895, 69.43424483707973, 73.07355839865548, 70.45145416259766, 75.11454309735979, 72.58277933938163, 70.35225473131452, 67.05237456730434, 70.08747972760881, 69.41718700953892, 67.97181579044887, 57.58364398138863, 55.63555669784546, 51.959782464163645, 52.520599365234375, 52.18219082696097, 52.33138949530465, 48.955798285348074, 46.97575623648507, 46.869535650525776, 47.720655236925396, 50.098839487348286, 50.95259244101388, 46.63679531642369, 46.314478806086946, 44.725505692618235, 43.38723748070853, 43.56335694449288, 43.97086531775338, 45.71212557383946, 48.35914257594517, 50.28233098983765, 46.819446086883545, 47.24453687667847, 53.791202545166016, 59.556901114327566, 61.986387389046804, 57.72005101612636, 58.5371070589338, 55.88664722442627, 53.75359889439174, 55.548968247004915, 53.825672558375764, 58.40526499067034, 60.48874487195696, 58.65849903651646, 58.17557144165039, 59.78804683685303, 59.03012343815395, 49.19725513458252, 16.019619022096904, 14.224666561399188, 51.66455350603376, 45.58803769520351, 56.76072713306972, 56.444921084812705, 54.894270760672434, 45.35094778878348, 45.9409818649292, 48.71915653773716, 57.40226820537022, 57.0608024597168, 60.183420181274414, 58.328160830906455, 56.29346077782767, 52.716858182634624, 51.61612456185477, 45.31426477432251, 47.511462347848074, 45.34807818276541, 45.685649463108604, 44.98099095480782, 50.23069545200893, 54.487755979810444, 57.61041191646031, 57.67896284375872, 53.86601379939488, 50.86565310614449, 52.202941622052876, 47.9214894430978, 45.747300829206196, 43.667559078761506, 44.65150042942592, 40.9102463722229, 47.7636159488133, 48.60859332765852, 47.37823758806501, 45.84457213538033, 51.84593970435006, 54.87771667752947, 56.581446238926475, 52.319966656821116, 55.220221178872244, 52.42495393753052, 54.58551018578665, 52.7844363621303, 54.3211555480957, 52.49786485944475, 54.31744868414742, 52.38754136221749, 56.65581280844552, 56.13469444002424, 61.9640211377825, 63.92280169895717, 68.50474262237549, 67.3241741997855, 67.36633586883545, 63.716766766139436, 67.24372795649937, 61.64957346235003, 44.22969961166382, 1.605899685195514, 0.31027378940156525, 1.071850067802838, 0.42702722017254147, 0.18516467485044683, 25.337030002049037, 71.2059520993914, 65.70796067374093, 52.47687087740217, 34.686206408909385, 22.003230469567434, 23.896510362625122, 20.5855130808694, 44.93669966288975, 55.48889759608677, 63.0262200491769, 36.00474868501936, 0.4147897868284157, 0.0811689712905458, 0.22234949309911045, 0.08853174799254962, 0.020095650871683444, 0.05958260103527989, 0.03575326542236975, 0.036989043932408094, 0.0618381192907691, 0.12758134332086357, 0.02308550347307963, 0.22025747464171477, 0.1588622419429677, 0.2062479928135872, 0.16336839300181183, 0.216315824006285, 0.09900716160024915, 0.09742260591260024, 0.1849889885634184, 0.39647596382669037, 0.32792044963155476, 0.5287656752126557, 13.95560278211321, 104.13517447880336, 73.0986761365618, 80.04729856763566, 58.186893531254356, 28.71340114729745, 52.42149026053292, 74.58370072501046, 40.0662556375776, 102.57766628265381, 19.573358569826397, 0.1450283649776663, 3.558997597013201, 5.717173218727112, 2.658097641808646, 5.49201944896153, 90.08634076799665, 87.71530968802315, 83.7862354006086, 80.41683156149728, 82.91143635341099, 78.89901842389787, 72.5134710584368, 64.7952105658395, 69.06435748508999, 67.33512456076485, 73.52555956159318, 74.64269093104771, 74.56945691789899, 75.31027385166713, 78.17015933990479, 77.66411508832658, 72.82099832807268, 70.66348539079938, 73.62981033325195, 72.95020008087158, 70.57392311096191, 60.817478043692454, 59.27699293409075, 53.90378768103463, 55.69597475869315, 55.81911073412214, 54.41667938232422, 51.920841285160606, 49.25061729976109, 51.01596001216343, 49.6114615712847, 54.42638601575579, 54.66549784796578, 49.09740604673113, 47.98587145124163, 46.12487983703613, 44.97062076841082, 46.21026624952044, 45.14480863298689, 48.28985513959612, 51.830382687704905, 54.1495315687997, 49.44035523278372, 49.81723594665527, 56.69175236565726, 64.13768863677979, 63.70082759857178, 62.344497544424875, 61.57909093584333, 58.57217461722237, 55.499385901859824, 57.27156911577497, 55.04278155735561, 62.33606243133545, 61.14167404174805, 61.8272180557251, 59.89189461299351, 63.804189000810894, 57.623134068080354, 55.36397245952061, 15.890033381325857, 14.759026459285192, 56.653127329690115, 45.345465660095215, 63.453311920166016, 57.621042660304475, 60.28000014168875, 45.74561589104788, 48.617758001599995, 50.76924685069493, 60.94196891784668, 59.06531606401716, 65.49342809404645, 59.804910114833284, 59.3624974659511, 56.00146968024117, 55.04105493000576, 47.75131068910871, 51.09513473510742, 47.39835262298584, 49.437457833971294, 48.2180837222508, 54.55862760543823, 57.096568311963765, 61.47363812582833, 60.37155655452183, 56.333531039101736, 55.10906042371477, 54.970204148973735, 49.94078533990042, 48.78533812931606, 46.588206563677105, 48.30576651436942, 47.2199923651559, 51.235325063977925, 49.986382893153596, 51.13875205176217, 48.415864195142476, 55.20761367252895, 59.12480654035296, 60.217292649405344, 57.38116305215018, 59.45614528656006, 56.174278327396934, 57.84921107973371, 56.325040340423584, 56.89404916763306, 55.55351931708199, 57.83151054382324, 55.15013122558594, 61.07004506247384, 60.57568768092564, 64.6209636415754, 67.41634900229317, 72.01325634547642, 70.11168030330113, 70.97959368569511, 65.8759125300816, 70.25490352085659, 64.24312060219901, 42.69480085372925, 1.46178394981793, 2.913806766271591, 2.607570775917598, 0.5537985691002437, 0.24453039573771612, 33.73955604008266, 79.78159250531877, 73.19212940761021, 61.33261053902762, 71.33479254586356, 42.959134646824424, 25.608419690813335, 22.361422266278947, 54.2601295198713, 64.09904970441545, 74.39623832702637, 42.492201805114746, 0.6391786847795758, 0.1215765933905329, 0.40337927054081646, 0.1486229178096567, 0.08917198649474553, 0.15179304698748247, 0.149780647829175, 0.17456214449235372, 0.16352471389940806, 0.18619040266743728, 0.18712961726955005], [0.014056457655637391, 0.035028430566723855, 0.029505990112998655, 0.048693854428295574, 0.023047117050737143, 0.058054669094937186, 0.04947132324533803, 0.07701899004834038, 0.11627834769231932, 0.11589338763483933, 0.5740551735673631, 24.468552078519547, 75.08730615888322, 57.754826750074116, 55.25130047116961, 42.91707720075335, 31.234542846679688, 47.5175906590053, 36.021278449467246, 47.57611880983625, 78.71364743368966, 2.6822211359228407, 0.10635853891393968, 0.6587609882865633, 2.16046461888722, 1.6310851680380958, 27.97407807622637, 88.68267958504813, 70.95672021593366, 70.94213594709123, 76.13066155569894, 82.9121242250715, 77.8097562789917, 71.55509213038853, 57.50347566604614, 62.61585249219622, 64.46581036703927, 65.07206848689488, 66.3028793334961, 69.11156354631696, 66.65304769788469, 66.76471219744, 66.24226324898856, 67.92417894090924, 67.97941711970738, 67.71164049421037, 61.51457691192627, 53.73879228319441, 48.5520384652274, 49.23341703414917, 47.171209062848774, 48.52658026559012, 49.7331280027117, 50.128490924835205, 46.15216193880354, 44.89559064592634, 44.308735370635986, 45.71641261237008, 47.90597758974348, 45.252217360905235, 44.45942095347813, 43.46558884211949, 41.89897503171648, 41.92011840002877, 39.23405947004046, 40.278001989637104, 42.50042847224644, 45.368714332580566, 43.17310094833374, 44.40439816883632, 46.068679332733154, 54.55384029660906, 58.04708882740566, 58.37643691471645, 59.24648339407784, 55.823032992226736, 54.039513792310444, 49.84930535725185, 52.32714067186628, 53.820461409432546, 56.448214530944824, 56.98743643079485, 60.6115334374564, 54.860217639378135, 55.51965727124895, 55.68599019731794, 37.40469258172171, 22.75856740134103, 18.389545338494436, 41.444020884377615, 45.200269154139924, 55.528446742466514, 51.34208413532802, 50.072530133383616, 40.88671282359532, 43.411580494471956, 49.414528778621126, 55.94050965990339, 53.564715589795796, 53.95006963184902, 54.020889145987375, 53.14838995252337, 51.780723912375315, 50.91190379006522, 49.277736118861604, 51.29020888464791, 47.06198338099888, 50.46605525697981, 46.01147133963448, 42.07474708557129, 43.02846029826573, 47.709301880427766, 49.98151568004063, 52.3999855858939, 49.10230105263846, 47.6974378313337, 45.450564111982075, 43.77007974897112, 41.031443800245015, 42.55995716367449, 37.49235452924456, 41.44651528767177, 43.65269340787615, 44.621074267796104, 42.13424103600638, 45.38915940693447, 48.95331430435181, 48.545726026807515, 49.21052271979195, 49.68203442437308, 48.78036321912493, 48.86272021702358, 50.5320839881897, 50.56490380423409, 49.428105558667866, 51.84286512647356, 52.06196962084089, 55.092700890132356, 53.14624295915876, 58.46399811335972, 60.15490477425711, 65.40999412536621, 63.67247894832066, 66.08419173104423, 58.280148778642925, 63.96053736550467, 53.84814650671822, 56.63076107842581, 21.20306897163391, 0.17443204218787806, 0.6509043127298355, 0.14942539403481142, 0.07837013647492443, 3.3186055592128207, 61.12891020093645, 60.41978400094168, 53.3153794833592, 48.26421281269619, 51.25391844340733, 14.25439269202096, 19.10145776612418, 26.031076874051774, 49.42182091304234, 50.912570817129954, 54.77061019624983, 2.927673850740705, 0.05244450084865093, 0.14936803068433488, 0.01523808652668127, 0.019779836925278817, 0.03193149156868458, 0.05800800624170473, 0.09179168806544372, 0.07098811651979174, 0.043428626244089434, 0.07295284859303917, 0.028353569630001272, 0.02308886731043458, 0.012544324555035149, 0.036874575074762106, 0.020373483820419227, 0.009973477505679642, 0.04290304319666965, 0.0612958748159664, 0.1416214406490326, 0.16421421404395783, 0.5018129072019032, 31.514517034803117, 85.74043015071324, 62.15215056283133, 65.86595576150077, 49.76445048195975, 32.74757562364851, 37.52323579788208, 39.96354389190674, 56.21922622408186, 85.30788394383022, 2.2568578464644293, 0.1018802620736616, 1.321695021220616, 4.413553936140878, 3.2725971937179565, 38.3365432875497, 95.35344355446952, 74.42025130135673, 75.0732638495309, 78.17732293265206, 85.56408487047467, 78.63120705740792, 74.80577210017613, 61.08588695526123, 64.77948679242814, 66.24504252842495, 70.55399567740304, 69.21442467825753, 73.12181363786969, 70.37944998059953, 68.66345337459019, 69.19537966591972, 70.37241840362549, 70.2442936216082, 68.25842898232597, 61.92058794839041, 55.00068589619228, 52.04534258161272, 51.674854210444856, 48.57988684517996, 50.00111307416643, 50.574700764247346, 50.57494395119803, 47.853681973048616, 47.33863285609654, 47.617134026118684, 47.108713490622385, 51.34641981124878, 49.074067047664094, 46.3152813230242, 46.04178285598755, 42.74436582837786, 45.2924404825483, 43.17825998578753, 42.82861968449184, 43.855167388916016, 47.61677966799055, 45.4353232383728, 48.008908203669954, 49.0822867665972, 55.55601372037615, 63.619901929582866, 61.035998889378135, 62.38470676967076, 59.47152165004185, 55.456751755305696, 52.69445024217878, 55.935048375810894, 55.57909911019461, 57.67441177368164, 58.100558689662385, 62.646744183131624, 57.65029110227312, 60.121018409729004, 57.73010853358677, 40.41210569654192, 26.55210838999067, 23.662602731159755, 44.025700501033235, 47.01598630632673, 58.21171249662127, 53.81489590236119, 51.611149651663645, 42.214416299547466, 45.149220739092144, 51.88193137305123, 59.44154017312186, 55.37571144104004, 54.81385925837925, 55.979426520211355, 57.00671073368618, 53.82661403928484, 54.34332030160086, 54.30034221921648, 53.42401109422956, 50.927012647901265, 54.04215063367571, 50.11822496141706, 45.0369656426566, 44.86648464202881, 50.10668747765677, 50.059860093253, 54.70462662833077, 51.63328661237444, 50.04423359462193, 48.28729820251465, 46.34133011954171, 45.69236489704677, 43.670053482055664, 39.78294978822981, 44.70527253832136, 44.639358452388215, 46.794964109148296, 43.890686580113, 47.14022009713309, 51.71576867784773, 52.130068915230886, 52.726359844207764, 52.05717188971383, 51.996406418936594, 51.446213313511436, 51.70751074382237, 52.520734855106895, 52.435351916721885, 53.2362916128976, 54.99665246691023, 56.09159129006522, 57.714964934757774, 59.78209917885916, 63.5647679737636, 67.11146204812187, 65.7553960255214, 67.44332190922329, 60.81457369668143, 63.73308113643101, 58.81882177080427, 60.55712904248919, 27.61599223954337, 0.32805789368493216, 0.2641032268958432, 0.45231578605515615, 0.09641283045389823, 2.5147061475685666, 64.28129400525773, 66.30162865774972, 62.465979848589214, 47.91073015757969, 36.75837809698922, 14.037760887827192, 24.875079018729075, 33.56690720149449, 54.9634678704398, 56.64907652991158, 63.87870148250035, 4.349063362394061, 0.15838125560964855, 0.17860592821879046, 0.07993550319224596, 0.033555137658757825, 0.05401420679741672, 0.025433539978361556, 0.025061048001849225, 0.0734123457223177, 0.030536016449332237, 0.02337758056819439, 0.162812862811344, 0.14375693963042327, 0.20668026033256734, 0.09616842214018106, 0.13976852436150822, 0.08492842848811831, 0.1480544683124338, 0.16327828355133533, 0.17372623006147997, 0.2701871618628502, 0.5909145974687168, 38.83642448697771, 98.56838893890381, 72.06681306021554, 74.47464179992676, 55.945957047598704, 44.36857673100063, 62.57746369498116, 55.66123723983765, 62.2859103339059, 94.84685039520264, 3.548321907009397, 0.44975271501711434, 1.4952627590724399, 5.903941231114524, 4.7732956154005866, 41.70946291514805, 96.96483503069196, 77.47747257777623, 78.81778008597237, 81.24227060590471, 90.73502458844865, 82.09521756853376, 77.07132257734025, 63.674681527274, 68.50129631587437, 69.49315166473389, 73.11738763536725, 73.2317897251674, 75.33662836892265, 74.51592799595424, 74.76662594931466, 73.20434434073312, 72.32327107020787, 74.92436395372663, 72.3563722882952, 67.67095184326172, 58.15347269603184, 53.60240261895316, 55.15429319654192, 51.81861243929182, 53.864408765520366, 54.69888046809605, 53.45853669302804, 49.59748526981899, 49.75886413029262, 49.949713775089805, 50.930417265210835, 53.36040381022862, 50.11071048464094, 48.85636261531285, 49.87023333140782, 46.23337248393467, 48.29564298902239, 45.63719620023455, 44.55924572263445, 47.39763001033238, 50.6107063293457, 48.268986225128174, 50.36086300441197, 52.68848521368844, 59.21876008169991, 65.62742410387311, 62.92953586578369, 63.65887437547956, 60.04237174987793, 57.817450863974436, 54.61316054207938, 58.54185267857143, 58.181355816977366, 61.69072764260428, 61.454384667532786, 65.9226461138044, 59.58570834568569, 63.42986174992153, 58.85479954310826, 48.684728213718955, 29.100764955793107, 28.036976643971034, 46.26269735608782, 48.00131382261004, 61.647273608616416, 55.56344829286848, 56.07072237559727, 45.87193066733224, 47.05575084686279, 53.58370154244559, 63.51694352286202, 57.88698148727417, 57.65946619851248, 58.892083576747346, 59.44168608529227, 55.80920260293143, 57.56693703787667, 56.23101036889212, 57.59528916222708, 54.5638040133885, 55.94666576385498, 52.05537578037807, 46.65463829040527, 48.32372065952846, 53.45926625388009, 53.69246169498989, 56.75225727898734, 54.977329526628765, 53.041335582733154, 50.83691883087158, 50.4758973802839, 46.931635175432476, 47.82058770315987, 42.99705791473389, 47.76599570683071, 47.47298322405134, 50.45332268306187, 48.42305210658482, 49.778221811567036, 56.126912457602366, 55.276852471487864, 55.23738670349121, 56.91193730490548, 55.05925921031407, 55.4552127293178, 55.860240595681326, 56.96429892948696, 54.977089813777376, 58.32016345432827, 59.25794792175293, 60.45801298958914, 60.61738382066999, 62.52820096697126, 66.3915661403111, 70.43871116638184, 67.84516402653286, 69.97753143310547, 62.03851972307478, 67.41120733533586, 61.62323978969029, 64.4039227621896, 24.570252861295426, 1.149587707860129, 2.745260621820177, 0.5830676928162575, 0.15978314967027732, 4.685625416891916, 75.92531449454171, 71.91432789393834, 68.87640176500592, 67.10598686763218, 70.03570175170898, 22.296552147184098, 30.599119663238525, 38.41104882104056, 66.47116470336914, 64.83551011766706, 77.62050124577114, 5.3108291029930115, 0.29618064420563833, 0.26060090054358753, 0.20736933978540556, 0.11056411253022295, 0.1878789642027446, 0.16928852961531707, 0.2063673606940678, 0.21354955887155874, 0.11151495043720518, 0.14453023884977612], [0.04343478734205876, 0.018041014604802643, 0.03943695739975997, 0.06352136111153023, 0.058660010541124005, 0.06895091012120247, 0.06709063172872577, 0.12642317903893335, 0.05572272404762251, 0.04145522588597877, 0.17429553451282637, 46.69044235774449, 66.51987852369035, 54.11223363876343, 48.490209920065745, 27.374943596976145, 81.1734903880528, 61.482990401131765, 29.34887817927769, 67.28887040274483, 49.013457911355154, 0.3768480899078505, 0.14904417949063437, 2.35613066809518, 8.035061870302473, 7.066594592162541, 68.23297078268868, 85.49101761409214, 70.86139787946428, 82.42052527836391, 73.22643266405377, 76.7075148991176, 75.29166657584054, 70.45499774387905, 61.47606304713658, 57.69585044043404, 66.07142789023263, 66.76007774897984, 68.41347803388322, 69.35114438193185, 69.51589311872209, 65.86245386941093, 64.79946286337716, 58.27826234272548, 54.479591846466064, 51.28734622682844, 49.231568813323975, 48.86641318457467, 48.82744073867798, 48.8656975201198, 47.773951394217356, 46.73587315423148, 47.644475187574116, 47.139969961983816, 43.61033024106707, 45.95795283998762, 44.55927351542881, 47.4004544530596, 47.4059157371521, 44.53372151511056, 45.468191691807334, 44.799167019980295, 41.40517350605556, 41.07469981057303, 38.00426306043352, 38.82679428373064, 41.36407838548933, 42.530548913138254, 42.81340312957764, 45.05170277186802, 44.924859932490754, 53.69434118270874, 56.65465593338013, 58.34976972852434, 60.120796067374094, 58.865937505449565, 55.95328392301287, 55.449977261679514, 53.77081305640084, 55.97937788282122, 58.915193285260884, 57.41172122955322, 56.22948176520211, 53.598838193076, 57.795800277165, 48.29568467821394, 30.976403372628347, 41.79564837047032, 30.72359664099557, 31.759989942823136, 48.89396974018642, 54.562000955854145, 51.74523598807198, 44.26231792994908, 40.909134660448345, 46.80859300068447, 54.60856430871146, 57.14053651264736, 51.93504687717983, 56.1626991544451, 54.06279720578875, 52.062143325805664, 54.09630836759295, 53.75947707039969, 53.878694261823384, 52.02080849238804, 53.845749378204346, 51.94489247458321, 56.00627783366612, 47.915062359401155, 40.78334794725691, 44.627886976514546, 47.24650321687971, 46.9067189352853, 49.5621988432748, 47.18219416482108, 44.862253189086914, 42.883913448878694, 41.398298263549805, 40.5862067086356, 38.428103174482075, 38.33065468924386, 44.10422556740897, 42.77880457469395, 43.32725020817348, 41.86628375734602, 44.08079971585955, 45.51098564692906, 49.23095737184797, 45.336127281188965, 48.651783330099924, 46.7194858278547, 50.271165234701975, 48.026462827410015, 48.71139539991106, 49.13050031661987, 52.03197077342442, 50.471335887908936, 54.596394538879395, 56.04231119155884, 58.77980068751744, 58.33330249786377, 64.25462681906563, 59.87292603084019, 64.88532870156425, 60.56784316471645, 69.22300570351737, 54.7327425139291, 53.36302675519671, 5.027270947183881, 0.7548872530460358, 0.5838398656674794, 0.061963614342468123, 0.05378826142155698, 28.775281803948538, 68.41630595070976, 62.76199395315987, 48.47727584838867, 43.008049964904785, 43.75039202826363, 13.712857042040143, 16.400720766612462, 33.94207518441336, 46.650882789066856, 58.338194029671804, 24.18062220300947, 0.5110674734626497, 0.194740731003029, 0.10456852282264403, 0.1237363296427897, 0.09826434895928417, 0.08004620618053845, 0.021847455263403908, 0.024543585322265114, 0.01466812559270433, 0.09241683594882488, 0.004348188530587192, 0.020535811449268034, 0.09362859092652798, 0.010406911256723106, 0.052427367839430056, 0.1364343118454729, 0.015489953636590923, 0.16859252910528863, 0.04285854147747159, 0.044117285005216084, 0.23238149764282362, 56.32434204646519, 74.48497377123151, 62.886568205697195, 59.445069858006065, 42.586047649383545, 66.35075936998639, 59.28553227015904, 35.8179463659014, 77.33790411267961, 50.956570284707205, 0.21877578486289295, 0.16465000994503498, 3.3470775399889265, 10.031765699386597, 14.203821097101484, 79.58636896950858, 86.45241900852749, 77.67589923313686, 81.51737758091518, 80.72435188293457, 78.37100396837506, 78.6781073978969, 72.72969205038888, 64.73505306243896, 60.65441771915981, 68.61813722337995, 69.58064338139125, 70.59090450831822, 71.02958597455705, 71.04307242802211, 67.74699987683977, 66.3167826788766, 60.46904672895159, 56.330237592969624, 55.00101940972464, 51.80082505089896, 50.94074576241629, 51.26479237420218, 51.213955879211426, 48.45706353868757, 49.5298376083374, 49.15874126979283, 49.91544873373849, 48.28273671013968, 46.50124291011265, 49.17840814590454, 50.96810776846749, 50.45410782950265, 47.0309944152832, 47.66906486238752, 46.96534783499581, 43.25219576699393, 42.624651840754915, 41.23485231399536, 40.914116518838064, 43.94102280480521, 45.10956736973354, 46.841520513807026, 48.66011422021048, 46.50608580453055, 54.945892402103965, 59.36095496586391, 61.43540218898228, 61.8534266608102, 60.413725171770366, 58.880778857639854, 58.63156087057931, 58.241819041115896, 59.59906278337751, 61.14952550615583, 60.5235345023019, 59.11244569505964, 56.167660168239046, 61.891287394932334, 49.316507066999165, 36.69276278359549, 48.57552685056414, 37.88933638163975, 34.04462712151663, 50.69591556276594, 56.89973974227905, 52.35898079190935, 47.723785400390625, 42.592120374952046, 49.13973099844796, 57.97411189760481, 58.99718202863421, 53.919504506247385, 58.1770270892552, 57.90731191635132, 55.76909065246582, 54.959159987313406, 56.44978482382638, 55.49957002912249, 55.67160047803606, 58.10401541846139, 54.537981033325195, 57.99187496730259, 52.3205120904105, 43.330467224121094, 46.535452365875244, 49.73863097599575, 49.00840309688023, 52.5092043195452, 49.575758252825054, 49.29243155888149, 44.91894006729126, 44.80078247615269, 43.90405144010271, 40.48021541322981, 41.312752042497905, 47.176156180245535, 45.19240031923567, 45.00109209333147, 44.66425384793963, 47.50017499923706, 47.261830942971365, 51.70958825520107, 48.69887474605015, 51.09788622174944, 50.78485945292881, 53.210215023585725, 51.551346506391255, 51.429457732609336, 51.29807424545288, 54.81481810978481, 54.146978105817524, 57.06816060202462, 58.038090910230366, 60.978495597839355, 60.21160902295794, 65.5767856325422, 62.629373686654226, 68.58671052115304, 63.737819807870046, 71.6299798148019, 58.32491602216448, 59.42161273956299, 7.233393047537122, 0.5966719942433494, 1.0507192931004932, 0.10549580199377877, 0.059611886606684754, 28.65308904647827, 75.08145577566964, 66.38461099352155, 56.88031605311802, 36.831240381513325, 34.73424277986799, 20.61413618496486, 25.188310759408132, 43.495240279606406, 51.03834015982491, 66.86688545772007, 30.689567838396343, 0.5368664605276925, 0.16169473209551402, 0.12202844343015126, 0.09634208639285394, 0.01506016616310392, 0.0946462916742478, 0.03757224138826132, 0.030038022635770694, 0.03438591897221548, 0.06177707828049149, 0.07883587612637452, 0.09761607660246746, 0.22523633390665054, 0.08927171078643628, 0.1641128680535725, 0.23534718421953066, 0.15550984468843254, 0.21510763812277997, 0.1586452057319028, 0.12385466615004198, 0.3864367668117796, 69.60296099526542, 82.43988295963833, 70.11444568634033, 64.79288986751011, 40.78730494635445, 88.89290428161621, 76.5504230771746, 44.792865003858296, 82.5574117388044, 59.72508226122175, 0.6147014296480587, 0.3772139017071043, 7.649151103837149, 17.91571467263358, 18.900543655667985, 78.2575329371861, 93.32694584982735, 78.52527482169015, 85.95467785426548, 82.11282430376325, 82.10689749036516, 80.26721600123814, 76.90502439226422, 67.14716189248222, 63.05476324898856, 72.04635061536516, 73.42383098602295, 73.81329141344342, 74.0113776070731, 74.57860074724469, 70.3447367804391, 70.02548789978027, 65.03775828225272, 59.8452513558524, 57.92862898962838, 54.61876426424299, 54.56900821413313, 54.94592366899763, 52.23400354385376, 51.1731630052839, 51.61214324406215, 53.2550448008946, 52.657037666865754, 49.801449639456614, 50.32453782217843, 51.272153990609304, 51.161430971963064, 52.39567075456892, 48.8074438231332, 51.015268666403635, 50.79200914927891, 45.57470757620675, 45.80051360811506, 43.878020014081685, 42.95618166242327, 46.11473199299404, 46.300860336848665, 48.27316904067993, 51.801818643297466, 48.54771668570382, 57.995383807591026, 59.84949670519148, 64.41183676038469, 65.17282431466239, 63.849817820957725, 60.72483771187918, 62.206186703273225, 60.08679158346993, 60.639506884983604, 62.893815176827566, 63.72426387241909, 62.392947333199636, 57.36574847357613, 63.54006017957415, 52.92796530042376, 39.84931550707136, 51.94519819532122, 42.06810460771833, 38.93210465567452, 52.360061236790244, 60.153681891305105, 55.64627776827131, 50.96598856789725, 44.8211476462228, 51.90933159419468, 61.42530645642962, 63.575600215366904, 54.24636166436331, 60.52529239654541, 61.12920202527727, 57.24482897349766, 58.45498629978725, 61.443441254752024, 58.6427891595023, 60.63533101763044, 61.648774419512065, 57.76372044427054, 61.352364267621724, 55.9791590145656, 45.581885065351216, 49.206958293914795, 51.93023524965559, 52.52756493432181, 55.86363131659371, 54.05110338756016, 52.65908738545009, 48.447127614702495, 46.709615911756245, 47.05625459126064, 43.891756602696006, 44.752627985818044, 49.22835179737636, 47.951481342315674, 47.72030782699585, 46.755981240953716, 50.36242982319423, 51.93609258106777, 56.478209904261995, 51.13130010877337, 55.56272220611572, 53.90039348602295, 57.66367333275931, 55.19192116601126, 55.76785387311663, 55.482810974121094, 58.16662563596453, 57.312542642865864, 58.714508465358186, 62.12868649618966, 64.75179822104317, 64.5487232208252, 68.18712656838554, 64.7802233014788, 72.29067707061768, 66.02978038787842, 74.04950932094029, 59.36313670022147, 63.67361150469099, 5.739430035863604, 1.655911298734801, 2.395862204687936, 0.2222395704260894, 0.12351413656558309, 37.916479519435335, 82.41596726008824, 74.6190253666469, 63.37153162275042, 59.38189683641706, 59.1976375579834, 23.72942703110831, 28.11749758039202, 48.78681809561593, 61.681326729910715, 76.08966023581368, 38.314454964229036, 0.8246379931058202, 0.2624913533883435, 0.32378676001514706, 0.25819104271275656, 0.20093859199966702, 0.1567800079605409, 0.12020759470760822, 0.09651467177484717, 0.17703302976276192, 0.20037837991757051], [0.08316532309566226, 0.03958378219977021, 0.06349925444062267, 0.08631469588726759, 0.03376172443053552, 0.12548989483288356, 0.11145555148167269, 0.04368928547150322, 0.08246785694999353, 0.20077749421553953, 2.1780457326344083, 57.06343582698277, 66.03013474600655, 53.28626653126308, 34.79934740066528, 22.235560859952653, 76.34956455230713, 53.832870892116, 35.18925251279558, 87.07966763632638, 21.54011218888419, 0.16437947803309985, 0.34493582802159445, 8.434617161750793, 8.062514202935354, 20.534284012658254, 93.76048564910889, 74.06751905168805, 74.17978109632219, 82.26777608054024, 98.27336842673165, 67.17542021615165, 76.52929360525948, 66.51606396266392, 65.68462167467389, 59.52443218231201, 63.34164047241211, 65.08003112248012, 67.5710506439209, 63.30407851082938, 59.461620467049734, 55.743788787296836, 54.28639371054513, 51.81839009693691, 50.226418835776194, 48.34678520475115, 51.690213203430176, 46.99182741982596, 51.417058672223774, 46.923290388924734, 47.90599496023995, 45.669161387852256, 48.09974547794887, 47.49754510607038, 43.92816516331264, 43.460818903786794, 43.81648676736014, 47.79917682920183, 47.740471499306814, 43.596805572509766, 47.643307890210835, 43.2333869934082, 41.78963817868914, 40.01046855109078, 37.92246886662075, 39.514895234789165, 39.82089737483433, 42.09328835351126, 42.38764878681728, 42.76381731033325, 48.168021951402935, 49.26375981739589, 57.390907900674, 57.55580602373396, 60.82210554395403, 54.04079226085118, 51.42591415132795, 53.16016020093645, 57.73864092145647, 58.1108454976763, 54.64092901774815, 52.829366888318745, 58.1166090284075, 55.39260598591396, 51.547316551208496, 38.80855873652867, 34.850395815713064, 49.24526023864746, 43.195383821214946, 27.445304530007498, 46.395737988608225, 52.79229824883597, 48.953105858394075, 45.03783764157976, 42.61854437419346, 44.89147731236049, 49.28844676698957, 54.73377084732056, 51.662795611790244, 52.82833160672869, 53.49774537767683, 52.16374683380127, 52.66275603430611, 51.98377111979893, 54.983572483062744, 55.00540372303554, 48.947248526981895, 51.76191513878958, 54.18116324288504, 51.90225485392979, 43.44934395381382, 42.967437744140625, 45.35037456239973, 46.88865014484951, 46.65032345908028, 45.867059980119976, 46.72080251148769, 42.988094738551546, 42.744998114449636, 40.1466497693743, 40.027109486716135, 37.224195752825054, 41.45815699441092, 43.13432305199759, 42.288838454655235, 43.17945160184588, 43.985244614737375, 43.22125891276768, 44.56101403917585, 44.18457801001412, 44.21550791604178, 46.8909569467817, 47.27613033567156, 50.01157358714512, 48.318182945251465, 48.899983406066895, 52.78360605239868, 50.295775754111155, 54.596540451049805, 53.546396664210725, 57.06269931793213, 60.866872787475586, 62.97405297415597, 60.57659789494106, 65.11723177773612, 62.34449059622628, 66.70380428859166, 64.86111422947475, 64.00295611790249, 22.000781229564122, 0.3090264249060835, 0.7326595857739449, 0.09630291456622736, 0.11233702275369849, 5.829724482127598, 60.92171491895403, 59.44497953142439, 56.3802889415196, 46.75903844833374, 39.63821186338152, 17.557100772857666, 12.755861674036298, 17.753340482711792, 44.08910976137434, 51.09042385646275, 54.01883942740304, 2.726258167198726, 0.1542797964066267, 0.08474726642348937, 0.06890181132725307, 0.05520901197035398, 0.0669568246230483, 0.0416011482344142, 0.05126460987542357, 0.02876786275633744, 0.054402087948151996, 0.05997168658567326, 0.050448457776967964, 0.03178761161065527, 0.1406334936618805, 0.021707436169630716, 0.026215444718088423, 0.0527014077774116, 0.05657681643164583, 0.13055970493171895, 0.27702541063938824, 3.2121328839233945, 72.08626106807164, 72.52588748931885, 60.72890935625349, 41.87847784587315, 32.77708114896502, 66.11243615831647, 51.0787022454398, 41.08559806006295, 96.2182719366891, 21.399400745119365, 0.16762582026422024, 0.139233173802495, 10.994304861341204, 9.347485389028277, 25.809316430773052, 96.50874832698277, 74.93901075635637, 78.28807026999337, 82.25594329833984, 95.64717170170375, 69.90777151925224, 80.15043762751988, 68.46308817182268, 69.16635009220668, 60.5221448625837, 67.87008721487862, 67.54849679129464, 71.64229897090367, 66.02430520738874, 62.48902702331543, 57.336743218558176, 56.23718384334019, 53.40384047372, 53.179774965558735, 49.97199664797102, 53.287426880427766, 49.6262959752764, 54.41706848144531, 49.230814933776855, 50.12630919047764, 48.13618530545916, 50.43851954596383, 48.77397435052054, 46.8030309677124, 46.520531109401155, 46.46935762677874, 50.13237149374825, 49.108387674604145, 44.55007062639509, 48.749944005693706, 43.44769375664847, 43.64095095225743, 42.675203459603445, 40.83975689751761, 41.30366379874093, 42.9528534752982, 45.517131328582764, 44.262943267822266, 46.18616642270769, 50.09407302311489, 52.34889548165457, 60.62930692945208, 58.20221083504813, 62.389216150556294, 55.80011783327375, 52.538821016039165, 56.47657707759312, 59.900225503104075, 58.24231236321585, 57.36951787131173, 54.40835196631295, 58.16644845690046, 55.50527450016567, 53.91583585739136, 40.00467722756522, 39.545106002262656, 50.85087081364223, 47.47997311183384, 30.187553542000906, 48.48272671018328, 55.697548525674, 51.52077095849173, 46.529803480420796, 44.42209870474679, 46.15306173052107, 52.254083837781636, 54.00420304707119, 54.225843633924214, 57.23155444008963, 55.19744150979178, 55.65238176073347, 54.03850630351475, 55.79888800212315, 58.04109948022025, 56.62455286298479, 51.77317816870553, 55.344878809792654, 56.56424944741385, 54.70481422969273, 46.11201524734497, 44.23503235408238, 46.652786595480784, 49.76462071282523, 49.577227796827046, 47.25771066120693, 48.59163277489798, 45.258144174303325, 47.1934745652335, 41.98916612352644, 43.7663311958313, 38.7222204208374, 45.33881623404366, 44.96898446764265, 45.27626160212925, 45.43615007400513, 46.06708124705723, 45.80699975149972, 47.268577643803184, 47.04225397109985, 47.664343561444966, 49.32790558678763, 50.15048197337559, 51.6407732963562, 50.28131307874407, 51.893263884953086, 56.70977946690151, 53.77869578770229, 56.298758779253276, 56.029238155909944, 59.80412496839251, 60.69781616755894, 66.43296350751604, 63.07418346405029, 67.33912672315324, 63.974503244672505, 69.26675851004464, 68.13947582244873, 69.36913326808384, 27.105582782200404, 0.2528515149440084, 1.1470629061971391, 0.7543795460036823, 0.2126596194825002, 5.558932338442121, 65.67727742876325, 64.70530087607247, 62.95173536028181, 50.982862268175396, 31.078851086752756, 20.456823757716588, 24.31945242200579, 22.8013630935124, 51.70493643624442, 57.426566055842805, 64.46257945469448, 3.360560519354684, 0.1792062417204891, 0.07042140407221657, 0.08393744844943285, 0.07113579288125038, 0.09811647582267012, 0.039208732146237574, 0.05671519686334899, 0.0375904736242124, 0.03212927095592022, 0.10546545112239462, 0.08032078894653491, 0.14356485993734427, 0.26799725794366425, 0.09835256529705864, 0.15304947671081337, 0.2022095966551985, 0.1837491558066436, 0.28341691195964813, 0.3522073621196406, 4.254787164075034, 87.36965070452008, 79.41859776633126, 72.04651737213135, 44.76713582447597, 34.080698694501606, 80.19394029889787, 75.39367307935441, 47.21023709433419, 105.02465506962368, 26.024898188454763, 0.25911192329866545, 0.5435888969472477, 16.495252745492117, 16.8017030443464, 28.090139048440115, 101.33056885855538, 78.0909776687622, 80.31608963012695, 86.26411587851388, 93.02653353554862, 72.65566594260079, 83.37704903738839, 70.8224949155535, 71.49284321921212, 64.68810408455985, 71.02465970175606, 71.35883331298828, 75.5237364087786, 69.33476052965436, 66.68730926513672, 60.56527927943638, 58.98370252336775, 56.18705259050642, 55.949552740369526, 52.551365988595144, 57.19618116106306, 51.269899300166536, 58.4029859815325, 52.21218967437744, 52.84463208062308, 50.34881830215454, 51.78804383959089, 52.150844029017854, 49.784694058554514, 48.79999188014439, 49.36343172618321, 53.051101275852744, 51.593998023441856, 46.906611238207134, 51.80080073220389, 46.59662083217076, 46.95877136502947, 46.08526815686907, 43.28337580817086, 44.67963021142142, 45.47378499167306, 47.97712019511631, 46.0957738331386, 48.05164657320295, 53.37542928968157, 55.10044813156128, 61.943093163626536, 61.98695714133126, 64.98113046373639, 59.07271589551653, 55.965748991285054, 56.8364451272147, 62.35111222948347, 60.2981071472168, 59.16118035997663, 56.910005705697195, 61.18664278302874, 56.84155552727835, 56.55118335996355, 45.34108134678432, 42.09875658580235, 51.35810668127877, 50.13966710226876, 35.270067010607036, 49.41252422332764, 60.049639565604075, 53.656838280814036, 49.54274041312081, 47.15055554253714, 49.668825898851665, 54.81399474825178, 59.71154717036656, 56.14311565671648, 59.65704550061907, 57.61354207992554, 59.23509529658726, 56.69051211220877, 60.79693916865757, 61.38667447226388, 56.74605253764561, 57.0631057875497, 56.91189214161464, 59.289458002362935, 57.55105692999703, 48.79085152489798, 46.746076583862305, 50.023993492126465, 53.4621011189052, 52.0938583782741, 51.56461756569998, 52.984850202287944, 49.51284578868321, 49.679800578526084, 44.978371483939036, 47.45913199016026, 43.39780569076538, 48.26233332497733, 49.47824028560093, 48.36208861214774, 48.29092863627842, 48.76610204151699, 49.99555104119437, 51.08228056771414, 50.74665130887713, 49.49825804574149, 52.90950393676758, 52.99645021983555, 58.00259256362915, 53.73619365692139, 55.84686531339373, 61.322994232177734, 57.31597852706909, 60.04584584917341, 59.07187516348702, 63.17016587938581, 65.77985368456159, 69.40654931749616, 67.27226420811245, 72.77153410230363, 68.82511711120605, 72.31997067587716, 70.61165877750942, 71.11292266845703, 29.63900715964181, 0.5746791000877107, 2.9067767092159817, 0.9176355600357056, 0.18464377708733082, 8.2972069808415, 75.95785985674176, 68.92649132864815, 71.00756018502372, 63.413290296282085, 55.09901680265154, 26.966326986040386, 23.12910440989903, 27.762479373386928, 61.15762710571289, 63.57177175794329, 74.87751919882638, 4.7597978711128235, 0.4626729445798056, 0.19265636642064365, 0.20248202846518584, 0.1803148322339569, 0.17098360508680344, 0.09118245861360005, 0.13324621506035328, 0.10534727746354682, 0.16382709624511854], [0.04240744800439902, 0.09115410263517074, 0.08972810701067958, 0.08969078758465392, 0.0358642398246697, 0.06172799305724246, 0.10209603620959179, 0.21026235526161535, 0.1389218076531376, 0.3986044467559883, 10.661298547472272, 69.39552252633231, 59.67436735970633, 45.97369398389544, 37.47481727600098, 27.829326254980906, 23.52230817931039, 42.32008450371878, 46.494138377053396, 82.19648756299699, 7.730298246656146, 0.11096419713326863, 0.29510484050427166, 6.182174461228507, 3.7968370403562273, 45.379567418779644, 89.85754353659493, 68.9238510131836, 77.13350895472935, 71.36470454079765, 91.17936188834054, 83.37036487034389, 71.34521484375, 69.08830792563302, 63.020557267325266, 59.40629196166992, 59.80356911250523, 62.580124855041504, 58.86950887952532, 54.25112118039812, 51.128562518528526, 51.15727594920567, 50.26938649586269, 48.95017719268799, 49.249946798597065, 49.75129059382847, 49.742271832057405, 50.001526491982595, 46.91842317581177, 49.277284485953196, 49.83014222553798, 48.41427305766514, 49.19837032045637, 45.83561590739659, 42.61573730196272, 43.29791838782174, 43.54170635768345, 44.770533493586946, 47.135887895311626, 46.032948221479145, 46.27472121374947, 42.87648582458496, 39.61633546011788, 39.03778328214373, 38.20528834206717, 38.416954789842876, 39.97741944449288, 44.03275292260306, 47.26752846581595, 46.4393344606672, 51.4055871963501, 54.74498871394566, 55.27716861452375, 56.771507263183594, 59.37224578857422, 52.305215631212505, 46.80550800051008, 48.00953354154314, 50.23283897127424, 47.52342714582171, 55.8318954195295, 48.98702348981585, 53.534897395542686, 46.88180616923741, 50.93273448944092, 33.19057192121233, 38.12084688459124, 44.05961813245501, 39.51009055546352, 30.154573917388916, 40.472846848624094, 56.88687515258789, 47.68063013894217, 50.03137247903006, 49.51218223571777, 47.831155913216726, 47.07355560575213, 45.18285696847098, 46.35669953482491, 47.509447370256694, 47.77886029652187, 48.14540556498936, 52.36130149023873, 51.73179817199707, 50.962417193821494, 43.52664613723755, 50.023468903132844, 52.628279072897776, 54.00143418993269, 51.19879490988595, 41.12984766278948, 41.4165928704398, 45.33097519193377, 46.78101560047695, 47.345275333949495, 45.406144278390066, 44.606455257960725, 43.01475150244576, 43.54647282191685, 42.39425999777657, 40.236198152814595, 38.11333588191441, 40.589048521859304, 45.5615997995649, 44.11907386779785, 43.9793073790414, 42.918960162571494, 43.05588483810425, 41.773626055036274, 44.68699182782854, 42.45961822782244, 44.96381153379168, 47.177914074489046, 46.93563733782087, 48.81141471862793, 49.402907916477744, 48.77689606802804, 52.62446451187134, 51.01004014696394, 53.64746863501412, 56.227987902505056, 58.9518380846296, 60.86949225834438, 63.90848840985979, 62.6684364591326, 59.059840883527485, 62.37142876216343, 64.33319704873222, 69.7078023638044, 42.10518019539969, 0.8838579782417842, 0.4534960841493947, 0.499693652348859, 0.24963539466261864, 0.07997985902641501, 39.63087109157017, 65.18200288500104, 59.87388488224575, 44.77021387645176, 52.16784974506923, 40.34022658211844, 10.983153002602712, 25.900101593562535, 45.8852573122297, 48.099411964416504, 65.75242914472307, 14.063279884202139, 0.5752733339156423, 0.16018976856555256, 0.04013265596170511, 0.08136156667023897, 0.04833797638171485, 0.06833032199314662, 0.038536463398486376, 0.02599003368855587, 0.16152166495365755, 0.018508981547451446, 0.037571074308029244, 0.058220489482794485, 0.03920978048284139, 0.05880025015877826, 0.05397627668987427, 0.03889294873390879, 0.20062434886183056, 0.19311217910477094, 0.42397172270076616, 12.770510213715689, 81.9701291493007, 63.91389410836356, 56.2370275088719, 42.31883035387312, 34.756344999585835, 27.22816116469247, 46.7929630279541, 55.65776661464146, 89.48678765978131, 7.636393342699323, 0.038773899764886925, 0.3694686416004385, 9.503508056913104, 5.426663390227726, 54.16734674998692, 89.65901960645402, 72.98790100642613, 79.86562401907784, 76.32709407806396, 90.19908223833356, 81.27150167737688, 74.55006449563163, 69.79524544307164, 66.23063196454729, 61.751857893807546, 61.915745053972515, 63.811943190438406, 60.845534869602744, 56.913615294865195, 53.203329358782085, 53.919546195438926, 53.78725944246565, 52.40826783861433, 51.114884989602224, 52.05635895047869, 51.95872286387852, 50.70317990439278, 49.40598249435425, 50.273232323782786, 53.04669959204537, 49.80783155986241, 52.62222719192505, 48.34214380809239, 45.537138666425435, 46.87984330313546, 47.20046097891671, 48.77506521769932, 48.950079917907715, 46.4372569492885, 48.078737599509104, 43.41536031450544, 41.74710825511387, 41.846307686397004, 40.835414273398264, 40.417174407414024, 42.41383307320731, 45.98600271769932, 49.13025712966919, 49.48504952022007, 55.79964188167027, 57.172157764434814, 58.1190686907087, 59.5892310823713, 62.36477238791329, 56.395227568490164, 48.53309072766985, 50.15807982853481, 50.81586231504168, 49.692613056727815, 56.1986734526498, 51.222846099308555, 55.1586149760655, 49.97201749256679, 54.49149758475167, 37.02068649019514, 43.068547930036274, 45.882332120622905, 41.745145389011924, 34.21577514920916, 42.72551189150129, 60.401392119271414, 50.95437465395246, 52.9319292477199, 53.552264417920796, 50.580926350184846, 46.96040071759905, 47.35908487864903, 47.785200527736116, 50.81875971385411, 49.148673330034526, 52.90489728110177, 54.600306374686106, 54.675253118787495, 50.06760038648333, 44.76379721505301, 54.13977977207729, 54.531540053231375, 55.614149297986714, 52.68888473510742, 43.655417101723806, 45.305746282849995, 48.346257141658235, 49.712182658059255, 50.08882018498012, 48.03257376807076, 46.99712889535086, 44.70576933452061, 45.37419646126883, 43.9548636163984, 43.71546343394688, 43.00205714362008, 43.16746595927647, 47.45224632535662, 46.13517359324864, 46.72270284380232, 44.8191430909293, 44.876660278865266, 44.38468265533447, 48.89433799471174, 47.19650050571987, 48.2125494820731, 48.92239829472133, 50.25126906803676, 51.15795687266758, 53.88876567568098, 51.95124660219465, 55.04381683894566, 52.898352078029085, 57.03234263828823, 58.52702522277832, 61.649212156023296, 64.18972369602749, 65.70047051565987, 65.69632244110107, 62.17380114964077, 65.66253335135323, 65.57731369563511, 70.89108058384487, 48.644195897238596, 1.8272600642272403, 1.1896557978221347, 2.490186389003481, 0.06893440136419875, 0.042797636174197705, 40.07634789603097, 72.41442448752267, 66.6350588117327, 52.87096575328282, 48.26959766660418, 36.27178880146572, 18.11397283417838, 39.28523642676217, 55.307730266026084, 52.79915959494454, 75.26732703617641, 16.67356436593192, 0.6639657318592072, 0.22036215902439185, 0.12443851839218821, 0.029254986438900232, 0.07292101851531438, 0.08644939187381949, 0.005231033836025745, 0.06640727232609477, 0.09832422288932971, 0.17508608209235327, 0.1203014903834888, 0.2062872935618673, 0.20076169792030538, 0.1834857620831047, 0.10537075477519206, 0.17005066014826298, 0.27379666960665155, 0.459701449743339, 0.6837335739816938, 14.886916739600045, 92.35064056941441, 72.91420146397182, 64.32764543805803, 46.782453877585276, 41.25531128474644, 30.408933571406774, 64.16446699414934, 61.100742203848704, 99.42046737670898, 9.156673959323339, 0.21213162424308912, 0.41988040081092287, 13.879141330718994, 10.336210574422564, 55.63054009846279, 96.40607479640416, 76.58291285378593, 81.92891938345772, 83.3360824584961, 97.10979529789516, 80.03841182163784, 80.55112634386334, 71.62788840702602, 70.01689297812325, 63.82372038705008, 65.10530866895402, 67.27434866768974, 64.43272999354771, 58.91524192265102, 56.48842028209141, 53.33790554319109, 55.87195873260498, 55.099826267787385, 53.677818366459434, 54.21020323889596, 55.09418780463082, 54.92142084666661, 51.48768016270229, 52.2193671635219, 56.337776388440815, 52.65383454731533, 54.90402603149414, 51.578632082257954, 48.87326410838536, 50.854938983917236, 48.932438441685264, 51.13772371837071, 52.037008217402864, 51.07300124849592, 51.7854243687221, 46.78940207617623, 43.96765872410366, 43.579851967947825, 43.90972464425223, 41.32154846191406, 45.145190783909385, 49.02193471363613, 52.0949318749564, 52.447684969220845, 57.78758750643049, 61.56211648668562, 58.55756950378418, 63.3002986907959, 65.24447413853237, 58.45953736986433, 50.08151762826102, 52.620302540915354, 52.47469956534249, 51.51092536108834, 57.572464329855784, 53.56877681187221, 57.036963190351216, 52.464190414973665, 54.74169179371425, 38.242673124585835, 44.02670798982893, 48.23669447217669, 44.190688950674875, 38.912757396698, 45.350027152470176, 61.95630168914795, 53.759953022003174, 56.160347189222065, 55.85734667096819, 52.734933921269004, 50.75878286361694, 50.67438309533255, 51.00356442587716, 53.017701285226, 52.85684353964669, 55.24779857907976, 58.65234293256487, 57.06391525268555, 51.926698616572786, 48.187119075230186, 53.68428366524832, 56.80146789550781, 59.38228593553816, 56.63533994129726, 45.367908341544016, 46.96819312231881, 51.544495582580566, 52.386370590754915, 53.78835378374372, 52.66054303305489, 50.47235032490322, 49.84410115650722, 48.285338810511995, 45.43868269239153, 46.585257053375244, 45.81058849607195, 46.473411900656565, 49.74695144380842, 49.44400998524257, 50.029301915849956, 48.43661151613508, 48.561279569353374, 46.9649726322719, 51.69834606988089, 48.93663515363421, 52.10298831122262, 52.89491619382586, 54.49407884052822, 55.90455273219517, 58.317537035260884, 54.16879197529384, 61.04611546652657, 56.57362604141235, 61.847117696489605, 62.34207957131522, 66.4898762021746, 67.19665391104562, 70.13194125039237, 69.03303500584194, 63.73304639543806, 67.36876773834229, 70.53244236537388, 74.97266088213239, 50.2602287701198, 1.7701085252421243, 2.5032233808721815, 2.202660377536501, 0.6214541015880448, 0.21351617494864122, 50.95254380362374, 76.13118267059326, 74.25377246311733, 57.924623353140696, 71.11359664372036, 53.39271640777588, 17.633961745670863, 38.34334209987095, 60.982060023716514, 60.23833179473877, 86.54722717830113, 19.507654666900635, 0.6696163000805038, 0.33347537155662266, 0.18096793576010636, 0.1509833104376282, 0.19514524643974646, 0.18665792686598642, 0.10834622582686798, 0.19838305270033224, 0.2793069439274924], [0.07044980076274701, 0.05158951958375318, 0.08743904876921858, 0.10356755474848406, 0.0821580717872296, 0.01951920992827841, 0.12639516911336354, 0.03610137424298695, 0.22729336709848472, 0.2377684142972742, 23.625501087733678, 64.36805616106305, 57.40178877966744, 40.85835027694702, 35.322727407727925, 24.439114298139298, 37.955754211970735, 36.757433141980854, 62.925089018685476, 65.96703120640346, 1.172006939138685, 0.117241609575493, 0.5461807378700801, 9.440038868359157, 6.5149180463382175, 72.51529148646763, 80.89463833400181, 71.56247806549072, 71.46481418609619, 75.48102583203996, 67.14583478655133, 82.56900828225272, 72.39783913748605, 67.31248038155692, 62.39757483346121, 57.90759331839425, 57.83655841009957, 56.247588770730154, 52.221764292035786, 48.461645875658306, 48.57216044834682, 50.637557642800466, 51.52556521551949, 51.76845339366368, 51.36414466585432, 50.87098932266235, 48.715797083718435, 49.75516421454293, 48.42343078340803, 48.226359026772634, 47.89796979086739, 50.90094648088728, 48.884162357875276, 45.2669996534075, 43.71046073096139, 42.94062464577811, 44.694891929626465, 47.32195370537894, 43.264876229422434, 43.17119366782052, 45.14074741091047, 41.11590610231672, 38.320750032152446, 40.918841293879915, 41.59488712038313, 37.8690858568464, 42.0363895552499, 43.27094895499093, 49.70427908216204, 52.55189752578735, 56.37102351869856, 57.77298934119088, 56.78901672363281, 56.098449162074495, 57.9260790007455, 57.247583934238975, 51.602839606148855, 53.45726864678519, 50.512632506234304, 49.9597087587629, 50.84226894378662, 52.075768743242534, 49.05405970982143, 53.89516149248396, 49.926468576703755, 35.75710793903896, 45.13796813147408, 41.42430189677647, 39.10816158567156, 32.943566935403005, 37.39110885347639, 50.534321308135986, 51.863793100629536, 54.04028156825474, 54.73939888817923, 50.47570283072335, 47.18975033078875, 47.050008160727366, 48.69456686292376, 50.688553946358816, 52.82913064956665, 51.00912993294852, 51.20789705004011, 48.13016816547939, 41.38644116265433, 49.711814403533936, 54.876434734889436, 51.53675181525094, 50.418262072971885, 46.2896911076137, 42.97199576241629, 43.30086442402431, 45.29037686756679, 46.07075684411185, 44.845105034964426, 42.34039756229946, 42.55782406670706, 42.592558111463276, 42.83720418385097, 41.67018474851336, 39.844489983149934, 39.06395714623587, 38.40772063391549, 43.32589878354754, 44.309944357190815, 43.16077136993408, 42.52019609723772, 42.77468081883022, 43.75647170203072, 44.059142180851524, 43.76453856059483, 46.07329988479614, 43.68542289733887, 46.276791776929585, 46.07270233971732, 47.964036737169536, 48.84152126312256, 51.170359407152446, 51.34495721544538, 54.383550371442524, 54.297479561397004, 56.92081362860543, 56.826245171683176, 56.52199745178223, 53.6168965612139, 55.96812180110386, 60.413294383457725, 65.41186319078717, 63.955055236816406, 62.367398806980674, 7.917923927307129, 0.5840792528220585, 1.8257034506116594, 0.2689744026533195, 0.18511292976992472, 11.195169465882437, 63.73914691380092, 60.96248000008719, 54.41727345330374, 43.659499168395996, 50.51464400972639, 24.826102903911046, 9.718894396509443, 28.096851008278982, 49.31700733729771, 59.16298689161028, 34.56430721282959, 0.20165562709527357, 0.09164894465357065, 0.017321323044598103, 0.07833097821899823, 0.020688278267958334, 0.03971508551122887, 0.016176989002685462, 0.05027239829567926, 0.0651083459545459, 0.0420740125035601, 0.06999606439577681, 0.014322037110105157, 0.05520893733150192, 0.07918803580105305, 0.006250711241071778, 0.12862875711705002, 0.03235930450526731, 0.21439942398241588, 0.25333354622125626, 29.5899042401995, 77.4340741293771, 63.60676983424595, 47.81443507330758, 43.7777053969247, 24.66773956162589, 32.73172330856323, 43.68460300990513, 71.64165278843471, 69.05182988303048, 1.3012587406805582, 0.07387838392917599, 1.9540097543171473, 8.715437293052673, 10.059740883963448, 78.82024669647217, 80.10555226462228, 77.30706800733293, 73.17122227805001, 78.10816056387765, 70.17851502554757, 84.02118873596191, 73.76331996917725, 70.8089737210955, 64.18565899985177, 60.72740854535784, 57.12938812800816, 58.300757135663716, 52.728281021118164, 52.0390544618879, 51.16582570757185, 52.15798677716936, 52.742576939719065, 54.67966175079346, 53.20613643101284, 52.44621542521885, 51.587480613163535, 52.79106841768537, 50.96004785810198, 49.86526884351458, 49.01836333956037, 51.33538259778704, 51.32066283907209, 47.481286321367534, 44.65492589133126, 46.95781946182251, 47.53283153261457, 48.932733740125386, 46.34793438230242, 47.19105659212385, 46.8748197555542, 43.33343757901873, 41.5937510899135, 43.53045375006539, 42.67499501364571, 41.469781330653596, 44.77905198505947, 46.662930965423584, 51.637893268040244, 56.9033910206386, 57.165313788822715, 59.40037209647042, 60.44026034218924, 59.20489842551095, 60.38441072191511, 59.89260332924979, 52.313063621520996, 55.03760167530605, 53.982496874673025, 53.2787937436785, 51.167201450892854, 52.13713870729719, 51.922050271715435, 55.692396436418804, 50.350183623177664, 37.689075401851106, 45.64382478169033, 42.72981630052839, 42.08952590397426, 36.52724974496024, 40.14033385685512, 51.579566614968435, 55.40892383030483, 55.709513323647634, 57.18329920087542, 54.032902581351145, 50.91970314298357, 50.986103602818076, 50.35205268859863, 53.248607294900076, 54.80348212378365, 54.53257533482143, 55.38775961739676, 47.740266527448384, 44.79814216068813, 53.467204570770264, 58.16523947034563, 54.138410976954866, 53.062937532152446, 48.55463361740112, 43.95759425844465, 45.97286367416382, 48.22552524294172, 49.63705178669521, 46.872895104544504, 45.63474696023123, 44.75599091393607, 45.33649206161499, 44.862913267953054, 43.88340139389038, 42.79845060620989, 41.548289026532856, 40.9024782861982, 46.250009945460725, 46.59424802235195, 47.310520444597515, 45.51492527553013, 45.84628486633301, 45.61580964497158, 47.1179233278547, 46.889258112226216, 48.660082953316824, 46.4274982043675, 48.582614013126914, 48.21752091816494, 51.659331934792654, 51.20377676827567, 52.92969192777361, 55.01182385853359, 58.31040818350655, 55.48568058013916, 59.12737042563302, 56.57443898064749, 59.535521507263184, 54.7481883593968, 58.60312189374651, 61.83547946384975, 68.65417752947126, 65.93689686911446, 67.95873928070068, 10.529666662216187, 0.5816220875297273, 3.603383558137076, 0.5636806445462363, 0.18884735581065926, 10.950432198388235, 69.43938650403703, 67.1949793951852, 61.65572261810303, 48.24742943899972, 42.3406720161438, 19.95257908957345, 18.80451086589268, 33.94472592217581, 57.360339300973074, 65.93400641850063, 41.89866583687918, 0.5064532182046345, 0.14998077494757517, 0.06700367746608597, 0.0952451666817069, 0.039006169087120464, 0.043077443659837754, 0.030694040469825268, 0.038636513386986086, 0.04296940052881837, 0.14573372927095207, 0.1501390907381262, 0.19793944007584027, 0.22289777653557913, 0.22817626329404966, 0.1097112415092332, 0.21857819546546253, 0.11616041830607823, 0.41799806324498995, 0.47355078373636517, 35.98195511954171, 86.56256185259137, 72.3200193132673, 56.240147250039236, 48.74554232188633, 34.460139819553916, 53.559174401419504, 54.769338675907676, 75.37649018423897, 77.75783239092145, 2.0827894040516446, 0.15222687513700553, 3.5079550445079803, 19.293339218412125, 13.081414307866778, 81.4585610798427, 86.89977877480644, 80.38164588383266, 77.23790563855852, 78.6440681729998, 77.39673451014927, 86.0707961491176, 75.2560362134661, 74.59839616503034, 66.64930261884416, 64.28887448992047, 60.84752205439976, 61.53117615836007, 55.28965105329241, 54.04096596581595, 54.04957478387015, 56.56242901938302, 56.99448537826538, 57.49302557536534, 56.242009367261616, 56.28934049606323, 53.91731582369123, 54.471184526171, 52.60845586231777, 53.48170893532889, 50.10575989314488, 54.190598896571565, 53.21123988287789, 51.9659628868103, 49.157452378954204, 48.860521112169536, 51.25715977805001, 51.88098989214216, 48.424876008714946, 48.29292971747262, 51.15542425428118, 46.10187087740217, 44.60457577024187, 46.44373614447457, 47.10140398570469, 44.45507485525948, 48.08372293199812, 47.762879439762656, 54.250718184879844, 60.38957323346819, 61.024902616228374, 61.166736194065635, 62.267851965767996, 61.09204305921282, 62.09653718130929, 63.74713734218052, 54.92482893807547, 57.20027017593384, 54.76571866444179, 52.995870045253206, 53.70629208428519, 53.44416434424264, 54.85900170462472, 57.430787086486816, 50.957779271262034, 42.51673242024013, 46.809944425310405, 44.055543013981406, 43.570221764700754, 44.4160155568804, 45.538319860185894, 57.03791856765747, 58.55931350163051, 60.40477589198521, 58.92579623631069, 55.46747629983084, 53.74550076893398, 53.32923766544887, 53.16831391198294, 55.45510503223964, 59.00272669110979, 55.91763966424124, 57.52722460883004, 49.19714048930577, 47.29077366420201, 56.70926530020577, 60.41730349404471, 57.044654846191406, 55.21813324519566, 50.972770009722026, 47.06622873033796, 49.6749472618103, 50.68616029194423, 51.01600864955357, 50.52753986631121, 48.593025888715474, 48.557173183986116, 49.744724546160015, 49.69988087245396, 46.00549588884626, 46.451587608882356, 44.91675138473511, 43.874528544289724, 48.21401902607509, 48.98856946400234, 49.258975982666016, 47.52527189254761, 49.25686025619507, 48.90962403161185, 50.43275601523263, 49.01065083912441, 50.60209403719221, 50.00199896948678, 52.14451422010149, 51.7186313356672, 54.26217229025704, 56.074523040226524, 58.16479478563581, 59.45102446419852, 61.07911246163504, 60.78736455099923, 63.241134779793875, 63.51477568490164, 62.229254722595215, 58.01040928704398, 61.67366286686489, 66.84620067051479, 71.34046922411237, 69.05444935389927, 70.37583691733224, 10.308226704597473, 1.3866260456187385, 6.706829896994999, 1.1831577122211456, 0.26765486917325426, 15.044793707983834, 76.97848074776786, 71.00160557883126, 69.34793431418282, 58.90539632524763, 65.58887549809047, 33.7419045312064, 18.09543330328805, 39.604523522513254, 65.11626597813198, 72.38533238002232, 53.215617247990195, 0.6960596782820565, 0.25640277724180904, 0.15606229432991572, 0.17697588354349136, 0.1628687469554799, 0.15684490304972443, 0.1870626187218087, 0.15644295247537748, 0.15647320156650885], [0.0192290157678404, 0.05397425126284361, 0.05360195945416178, 0.03730251693299838, 0.03458438707249505, 0.038009899867964644, 0.03948778645800693, 0.030855121290577308, 0.020331650440182005, 0.03735729506505387, 26.212205989020212, 54.93696049281529, 53.55628047670637, 45.62292112622942, 32.352514948163716, 37.1886487688337, 43.84733329500471, 39.131187915802, 80.08420045035226, 37.07396180289132, 0.1626815934266363, 0.13974478920655592, 2.4637908339500427, 4.801445373467036, 21.259057555879863, 84.22869668688092, 71.06380585261753, 72.70642253330776, 66.04341275351388, 81.88173416682652, 69.74958883013043, 72.40270287649972, 74.72966153281075, 65.87170886993408, 61.359249932425364, 52.86782169342041, 51.53091532843453, 50.51336554118565, 50.38124901907784, 53.04841579709734, 53.736680030822754, 55.53279284068516, 56.36048310143607, 55.94390385491507, 54.28221089499337, 54.74217816761562, 52.27949687412807, 50.056861945560996, 49.3180183001927, 46.6155755179269, 47.64332526070731, 47.84996816090175, 46.95300088609968, 43.46515457970755, 41.74465206691197, 44.41552223478045, 43.245515074048726, 46.87439938953945, 44.74243497848511, 41.742164611816406, 44.33456529889788, 40.79831436702183, 39.2050507409232, 40.072651454380576, 39.710480076926096, 38.64219454356602, 38.56005988802229, 47.03342975888933, 54.15076487404959, 55.705406938280376, 55.866080556597026, 56.80941316059658, 56.35691867555891, 58.7043571472168, 54.59204844066075, 54.107352529253276, 52.37749774115426, 56.122236319950645, 54.631211962018696, 62.68201323917934, 53.399417945316856, 49.620796476091655, 55.710037912641255, 58.122803347451345, 45.759963921138215, 36.50674213681902, 45.953763076237266, 39.41989598955427, 39.892144203186035, 32.30158117839268, 30.480034487588064, 41.91401093346732, 53.80709654944283, 50.60523114885603, 49.576786586216514, 59.510292598179404, 55.73110832486834, 53.50576707295009, 54.383446148463655, 51.544888155800955, 50.90794331686837, 50.17078113555908, 50.006268637520925, 48.04583787918091, 52.4434118270874, 53.75169161387852, 50.7678085735866, 51.3399475642613, 47.07279825210571, 43.77384219850813, 42.452763829912456, 45.086871079036165, 47.507793698992046, 46.08589696884155, 43.97176510947091, 41.51403440747942, 40.50335986273629, 40.781194005693706, 41.18012135369437, 43.32348428453718, 40.15935802459717, 40.340900557381765, 39.451617990221294, 42.09618922642299, 42.78697913033621, 42.224616255079, 43.308566502162385, 42.735263688223704, 43.289094175611226, 45.95848785127912, 45.261326449257986, 45.12827886853899, 46.60084533691406, 46.194212436676025, 47.982755184173584, 47.380492278507774, 48.543196882520405, 49.5838737487793, 47.665927750723704, 49.85275166375296, 48.09185927254813, 48.68213653564453, 47.49984495980399, 49.32844059807913, 49.38214322498867, 52.73634440558297, 56.42418418611799, 63.15542180197579, 62.99564797537667, 70.06814983912876, 22.10279815537589, 0.6752764763576644, 2.7858611174992154, 0.4857841730117798, 0.11681756590093885, 0.6292142080409187, 51.684467043195454, 60.51105553763253, 62.468724387032644, 43.151752608163015, 52.86188098362514, 38.775836195264546, 20.26844940866743, 31.88825021471296, 39.15925516401018, 53.92695297513689, 56.68727077756609, 1.7894205003976822, 0.04208975451599274, 0.04424733641956534, 0.05374920494588358, 0.03565551906025835, 0.021662869989605885, 0.051309739239513874, 0.0519258659998221, 0.031755184422114065, 0.0773627223180873, 0.004264530675884868, 0.06776172321821962, 0.02208465414254793, 0.12388138685907636, 0.057751452151153765, 0.07284315662192446, 0.06007139052131346, 0.034900061919220855, 0.021374604564958384, 32.704979692186626, 66.78721741267613, 62.21473298754011, 54.143778460366384, 42.44230679103306, 34.94202518463135, 42.41749824796404, 48.47950622013637, 88.36992727007184, 38.800061089651926, 0.02858492632263473, 0.08649631935570921, 4.620452616895948, 5.629913832460131, 27.235189267567225, 89.35514014107841, 72.94517653329032, 75.85025310516357, 68.45729337419782, 85.24516255514962, 70.40779168265206, 75.82337747301374, 75.23470524379185, 69.22213023049491, 62.249175207955496, 56.88602747235979, 52.399113586970735, 53.695161070142476, 51.87259994234358, 55.293917247227256, 56.02466971533639, 60.326059750148225, 60.47236796787807, 59.60735893249512, 57.313022068568635, 58.68354034423828, 53.95586095537458, 53.09226935250418, 52.5873715536935, 49.74615587506975, 49.45959479468209, 50.344996792929514, 49.208681447165354, 46.774331433432444, 44.000318731580464, 45.15944848741804, 47.28840780258179, 48.46770123073033, 47.03051846367972, 44.445045130593435, 46.38421092714582, 43.86336626325335, 42.79422957556588, 43.11106048311506, 40.23953676223755, 40.93525988715035, 40.39239018304007, 50.50631659371512, 55.56340312957764, 57.46974911008562, 56.717811584472656, 58.97714342389788, 58.73335197993687, 60.345445224217, 55.92448016575405, 53.805290017809185, 55.42804874692644, 58.3055305480957, 57.52167647225516, 64.17374978746686, 56.9625688280378, 50.60298688071114, 56.282774448394775, 60.25604970114571, 47.38585628782, 39.60222019468035, 46.04683072226388, 40.35712807519095, 40.49953487941197, 37.480542591639924, 33.558347020830425, 45.15400457382202, 54.41273627962385, 51.92826196125576, 49.97898653575352, 59.88969898223877, 60.17508234296526, 55.606878008161274, 55.700296538216726, 53.85583816255842, 51.893965653010774, 52.26764324733189, 52.62434639249529, 51.62438249588013, 55.20806530543736, 55.205532687050955, 53.877631187438965, 53.50389105933053, 48.42715154375349, 46.80874586105347, 44.965781348092214, 46.93508495603289, 50.46583638872419, 48.15183959688459, 47.12219646998814, 45.35010705675398, 44.81114224025181, 42.660754680633545, 43.53585250037057, 45.541192940303254, 43.07770912987845, 43.09183829171317, 41.869556358882356, 44.77295841489519, 44.87461403438023, 44.22824396405901, 44.6495931489127, 45.0946044240679, 45.93228619439261, 48.4443552834647, 48.74492393221174, 47.02605424608503, 49.71006693158831, 49.44085202898298, 50.4868929045541, 49.63725675855364, 49.5449777330671, 52.318764618464876, 50.35493271691458, 51.814707551683696, 50.98656913212368, 50.9316714150565, 49.61593273707798, 50.356162548065186, 49.93681444440569, 55.820166860307964, 59.84231226784842, 64.81847313472203, 66.6416665485927, 72.57920101710728, 25.427201986312866, 0.08237606473267078, 1.9460201944623674, 1.3510040427957262, 0.07100556165512119, 0.7753306989158902, 53.79984957831246, 68.44008268628801, 66.67836693355015, 52.556167193821494, 49.86167662484305, 26.829513481685094, 27.95046636036464, 41.82212100710188, 47.931626864842, 59.00124672480992, 66.81954043252128, 2.5580166578292847, 0.2257870736398867, 0.09203519392758608, 0.039606119572584114, 0.06858439943087952, 0.031400113832205534, 0.04505744277100478, 0.03155249922669359, 0.02388573544366019, 0.1209641205413001, 0.15498992401574338, 0.15429414063692093, 0.23660963933382714, 0.14691672793456487, 0.13212713439549717, 0.10281644362424101, 0.17244309319981507, 0.2451020207788263, 0.20616185957831995, 42.303384508405415, 79.24073777879987, 69.40404101780483, 60.59345422472273, 45.786568573543, 50.80087852478027, 64.0067845753261, 54.51971074513027, 95.15321731567383, 44.53809193202427, 0.32721900727067676, 0.17544367004718098, 7.014666795730591, 12.630464928490774, 28.17517457689558, 93.924574307033, 76.33177021571568, 80.52930900028774, 71.10170132773263, 88.09469522748674, 73.4134920665196, 81.4940733228411, 76.45024394989014, 74.24113368988037, 64.83965819222587, 58.89170142582485, 55.958905015672954, 57.73768901824951, 55.56320858001709, 57.026568685259136, 58.542429379054475, 62.02363668169294, 63.44106919424874, 62.87431853158133, 59.43189607347761, 60.033714294433594, 57.79574121747698, 54.9562452180045, 56.088006019592285, 51.535987513405935, 52.142269951956614, 53.151801518031526, 50.79033810751778, 49.642551285879954, 45.18147080285208, 48.856748240334646, 49.38632256644112, 49.87106016704014, 49.11685405458723, 46.69206476211548, 48.794579233442036, 45.51858697618757, 44.14654009682791, 45.3976605279105, 43.030850478581016, 45.35138552529471, 43.88568735122681, 52.48132119859968, 58.73649951389858, 60.24369580405099, 60.12131718226841, 62.65278216770717, 61.117952891758506, 64.07998384748186, 59.517900875636506, 56.506732259477886, 56.343553815569194, 61.46946225847517, 61.16554110390799, 67.53849833352226, 57.98977313722883, 51.58214092254639, 59.45832702091762, 63.45358289991106, 51.312071391514365, 43.87359748567854, 46.0836318561009, 42.315550804138184, 44.08550017220633, 40.908029896872385, 38.991209506988525, 48.96863508224487, 57.39057786124093, 55.152083669389995, 58.752410888671875, 64.83366189684186, 61.01960114070347, 58.881536211286274, 59.866422516959055, 56.30098220280239, 55.111026763916016, 53.20196403775896, 52.816599573407856, 53.672607217516216, 54.916779450007844, 57.48707444327218, 57.54990005493164, 56.26344803401402, 51.64563703536987, 50.484756333487375, 47.91275903156826, 49.139574663979666, 53.00512504577637, 51.41714205060686, 49.60678195953369, 48.534876414707725, 46.22027512959072, 46.2069901738848, 46.466019017355784, 47.98703180040632, 45.82636438097273, 46.32980653217861, 45.62949759619576, 46.622009549822124, 47.00868722370693, 47.04793759754726, 47.69978632245745, 47.53600685937064, 49.30290944235665, 51.56054939542498, 52.428167479378835, 49.18283414840698, 53.618206296648296, 53.34218215942383, 54.038151945386616, 52.45613397870745, 53.436858313424246, 56.452869824000764, 53.815674100603374, 55.762225832257954, 54.52479682649885, 53.76747097287859, 53.057045459747314, 54.3684276172093, 53.58536563600813, 58.28353949955532, 62.66030011858259, 68.65888145991734, 70.4483413696289, 75.99187823704311, 27.08278226852417, 1.4700322215046202, 5.931470428194318, 1.5709795589957918, 0.20509531109460763, 1.299750873020717, 63.275674274989534, 73.18771730150495, 77.24472182137626, 59.325303758893696, 71.94933986663818, 52.96437038694109, 28.771012135914393, 41.44235679081508, 56.73884378160749, 66.40483025142125, 78.08343887329102, 4.142173366887229, 0.30432629425610813, 0.20803855173289776, 0.16386468708515167, 0.1631149873137474, 0.18276044886027062, 0.07904109904276473, 0.1158873758145741, 0.1821028534322977], [0.025526847025113444, 0.0921373473746436, 0.047736231171126874, 0.024261879634910395, 0.00892884231039456, 0.02475318478952561, 0.07258527260273695, 0.00865179137326777, 0.06584310438483953, 0.29151859294090954, 40.79797043119158, 52.99459505081177, 51.08474717821394, 41.19254125867571, 33.855406829289024, 35.138780798230854, 41.72486359732491, 46.832008429935996, 84.5918720790318, 15.709553922925677, 0.11552434600889683, 0.3559932889682906, 5.097278824874333, 2.6146861655371527, 42.8450973374503, 83.25369071960449, 69.81030913761684, 69.57902445111955, 70.09861768995012, 75.95718588147844, 70.59410067967006, 70.74533517020089, 71.5356719153268, 68.4418614251273, 57.779169763837544, 55.89487041745867, 52.17691714423043, 57.40810816628592, 58.1401321547372, 61.76517759050642, 61.49568475995745, 67.49253599984306, 68.83517115456718, 73.50637558528355, 78.92730454036167, 63.738007409232004, 55.34527833121163, 54.644767897469656, 48.317446436200825, 50.03365843636649, 47.27733932222639, 47.94252164023263, 46.55241639273507, 45.51447016852242, 43.80075257165091, 43.27868577412197, 44.67630202429635, 46.69522271837507, 44.75525093078613, 41.84196506227766, 43.20981175558907, 43.60317359651838, 36.81906018938337, 39.062220096588135, 38.81094544274466, 40.51426158632551, 36.94590302876064, 47.07298585346767, 49.92675345284598, 57.00824975967407, 56.02593776157924, 56.755470820835654, 55.99217993872506, 57.352227279118125, 52.07416023526873, 53.02039371218, 55.250612599509104, 56.270965984889436, 55.3741272517613, 57.673084667750764, 58.51936830793108, 59.78854710715157, 50.55711834771292, 56.57949726922171, 42.574326038360596, 39.00569650105068, 44.7878657749721, 38.30686058316912, 38.431000573294504, 39.13638169424874, 32.80910539627075, 42.46598277773176, 49.23633875165667, 50.6222368649074, 27.99024306024824, 25.28427233014788, 52.987886565072195, 49.8496527671814, 57.38473790032523, 47.78226143973214, 42.98556212016514, 51.23882695606777, 49.91587257385254, 51.903682708740234, 52.98851885114397, 50.01110110964094, 51.32422031675066, 47.95306553159441, 44.873950481414795, 42.08446066720145, 45.72851637431553, 44.80549335479736, 47.45515414646694, 43.55732590811593, 44.291410037449424, 41.78623703547886, 41.03961835588728, 41.06151212964739, 41.18437712533133, 42.9249529838562, 40.048304966517854, 41.00023249217442, 38.11674744742257, 41.00912618637085, 43.34649671827044, 42.723149503980366, 43.15123496736799, 41.69299915858677, 44.10910667691912, 43.15625156675066, 43.1708219391959, 44.01016432898385, 46.14845160075596, 45.7084812436785, 44.42731332778931, 44.264048031398225, 45.68576410838536, 44.19679989133562, 45.8837947164263, 44.94991166251046, 46.8847348349435, 47.27551889419556, 49.25041580200195, 51.4954378264291, 56.82902445111956, 57.02724960872105, 62.2552409853254, 62.59133924756731, 64.35489627293178, 69.69000107901437, 38.9089879989624, 0.38374463841319084, 0.5926920335207666, 0.957410414304052, 0.2645281255245209, 0.18011729711932795, 22.223186118262156, 66.43665300096784, 61.13416303907122, 53.15819386073521, 44.12243332181658, 45.29845414842878, 17.897432225091116, 24.536284855433873, 37.840375900268555, 47.460278442927766, 65.41885307856968, 9.767323340688433, 0.5710326528974942, 0.14922305489225046, 0.10349059530666896, 0.07897187490016222, 0.05884359497576952, 0.07358119916170835, 0.08578658529690333, 0.05010325987158077, 0.1186763040189232, 0.03582216726083841, 0.06549217285854475, 0.034530643706343005, 0.04045474635703223, 0.034877219037818055, 0.12284750305116177, 0.03743719934884991, 0.027021264424547553, 0.44325574221355574, 48.267030307224815, 61.760800225394114, 58.944118635995046, 45.918803215026855, 40.77516296931675, 36.61241381508963, 42.48938431058611, 57.49688529968262, 87.31127193995884, 16.52737079347883, 0.35387229706559864, 0.15710767252104624, 8.707148960658483, 3.37376035962786, 46.951538290296284, 85.65467548370361, 73.18725177219936, 72.9044531413487, 72.3910368510655, 77.10028961726597, 72.14504977634975, 72.60342938559396, 73.27573708125523, 71.33793313162667, 60.142516136169434, 59.48860032217843, 54.626751218523296, 60.46121610913958, 59.630149023873464, 64.33937399727958, 64.28588676452637, 70.60812214442662, 70.37823404584611, 72.37332589285714, 76.96297236851284, 66.32353632790702, 59.107012203761506, 56.91739511489868, 51.45584004265921, 51.972695691244944, 50.35131270544869, 48.53137104851859, 47.41965927396502, 46.89932605198452, 46.09388739722115, 46.61740984235491, 46.8866525377546, 49.71908916745867, 45.90357623781477, 44.57121052060808, 44.239076205662315, 46.855736528124126, 40.20299618584769, 41.17027923039028, 39.65555109296526, 43.23568337304251, 39.20364720480782, 50.117745535714285, 53.16117811203003, 58.24417795453753, 57.553144863673616, 59.29581560407366, 57.38965722492763, 58.68485355377197, 54.550578117370605, 57.15111861910139, 56.759452138628276, 57.22501618521554, 56.123869146619526, 60.80343573434012, 59.785781724112375, 61.21351146697998, 53.91839974267142, 58.77356815338135, 44.138560090746196, 41.343150411333355, 45.85504307065691, 39.43432739802769, 40.53963640757969, 42.96090643746512, 36.40735510417393, 46.54265417371477, 49.43223973682949, 52.28469065257481, 33.674705028533936, 28.34771224430629, 53.98001636777605, 51.827759742736816, 58.32773004259382, 49.981272493089946, 44.22800077710833, 52.72224303654262, 53.92784234455654, 53.831960678100586, 55.28226859228951, 53.11547633579799, 52.4089800289699, 50.260437216077534, 46.5720658983503, 44.49975177219936, 48.89638076509748, 47.4713260786874, 47.51357112612043, 47.292743478502544, 45.28532205309187, 44.38594375337873, 42.57673358917236, 42.47342429842268, 44.237954071589876, 46.33009488242013, 42.249671459198, 41.72302579879761, 39.95932633536202, 42.331687995365684, 44.90666954857962, 44.84195750100272, 45.86321415219988, 44.967170987810405, 45.47474036897932, 44.72449472972325, 47.107737268720356, 48.4441294670105, 48.28921937942505, 47.94515153339931, 46.57440396717617, 46.39664472852434, 49.64800909587315, 46.38606262207031, 50.174137115478516, 47.87827164786202, 50.51163196563721, 51.221432140895296, 52.49317135129656, 55.49195827756609, 60.08258792332241, 59.23904882158552, 63.102782249450684, 64.53275626046317, 68.79467705317906, 71.20472921643938, 42.3286064692906, 1.0157829906259264, 1.1037489218371255, 2.1815847541604723, 0.29830874715532574, 0.2915222570300102, 21.637086459568568, 73.05902276720319, 66.7746342250279, 60.60227148873465, 49.08873816898891, 37.68066808155605, 18.848557233810425, 32.31488003049578, 43.70293583188738, 54.827932834625244, 73.56586606161935, 12.043336067880903, 0.8335512291107858, 0.2176035749060767, 0.07195948011108808, 0.08751404045947961, 0.04294103437236377, 0.12603714689612389, 0.09818627672003848, 0.029014042046453272, 0.21934468219322817, 0.27539936932069914, 0.09863927348383836, 0.1298145242035389, 0.0999460369348526, 0.10411097308886902, 0.18398661592176982, 0.10114080139568873, 0.1402538533189467, 0.4876415676304272, 57.20477608272007, 73.94555037362235, 67.69401291438511, 54.8585535458156, 47.03311708995274, 49.57421922683716, 59.296927315848215, 62.12241227286202, 98.03206443786621, 19.59834255490984, 0.34189075284770554, 0.39184802930269924, 14.172660163470677, 8.248965638024465, 46.67377015522548, 92.5683901650565, 74.3591696875436, 78.9445777620588, 76.90885979788644, 80.76779896872384, 73.56270463126046, 74.61384201049805, 74.30396624973842, 76.24301392691476, 61.48706899370466, 63.68886974879673, 56.755317960466655, 62.66151605333601, 63.51618616921561, 66.67382975987026, 67.47333812713623, 74.81182398114885, 71.24520942143032, 69.2883048738752, 76.92757824489048, 70.59109210968018, 61.73159694671631, 59.85675062452044, 53.5937625340053, 56.52791384288243, 52.30568463461739, 52.010556425367085, 50.925143582480295, 51.02412067140852, 49.48822832107544, 48.35696084158761, 49.42324529375349, 52.95697055544172, 47.863242694309776, 47.580013275146484, 46.41200719560896, 49.92033331734793, 42.91755315235683, 43.951507636478965, 43.847465310777935, 47.09939248221261, 41.70745141165597, 53.28126730237688, 54.04042400632586, 60.271898542131694, 58.72442354474749, 61.3376966203962, 60.46744864327567, 59.49509688786098, 55.38251025336129, 61.21893801007952, 60.82755293164934, 61.407178606305806, 59.60817881992885, 64.660617010934, 61.79499231066023, 63.908085414341514, 55.93874829156058, 63.553623063223704, 48.69315985270909, 45.14421108790806, 45.8122421673366, 41.59235797609602, 43.70060818535941, 47.735937799726216, 41.29181712014334, 50.01700707844326, 51.548667975834434, 56.27784817559378, 33.332228319985525, 30.355713844299316, 56.920511381966726, 53.71424429757254, 61.09142466953823, 50.813538142613, 45.61741467884609, 54.18983459472656, 55.57940483093262, 57.018637316567556, 57.78274808611189, 55.276088169642854, 54.88239976337978, 53.35991396222796, 49.68627977371216, 46.666516235896516, 51.42106430871146, 50.78925766263689, 51.708813531058176, 49.05135686056954, 48.501990590776714, 47.07994100025722, 46.635329246520996, 46.35462897164481, 47.74000597000122, 48.874848297664094, 44.01884262902396, 46.38833815710885, 42.71481513977051, 45.403698512486045, 47.53530509131295, 47.716024262564524, 47.74341058731079, 45.82820217950003, 49.23063080651419, 48.38900245938982, 49.51052509035383, 51.70989397593907, 51.72277593612671, 52.031376702444895, 49.804451261247905, 49.80382592337472, 53.06076622009277, 49.280025550297324, 53.3083096912929, 50.65894419806344, 54.770915916987825, 54.342236382620676, 55.16016789845058, 57.61969123567854, 63.50511074066162, 61.569599696568076, 66.80456011635917, 68.23006643567766, 74.4582371030535, 74.6529186793736, 45.81495891298567, 0.9219247698783875, 5.78097939491272, 4.76505548613412, 0.6085768640041351, 0.3969917318650654, 27.35543305533273, 81.85118293762207, 72.23568207877022, 67.5889561516898, 61.21800695146833, 62.71769918714251, 25.23643398284912, 34.502568994249614, 53.256660257067, 61.53950704847063, 83.15447739192417, 17.122225182397024, 1.0915603701557433, 0.4188015844140734, 0.34210001304745674, 0.16476960852742195, 0.1880935983998435, 0.2125379852950573, 0.20830414390989713, 0.1538755523839167], [0.08424844818988017, 0.028310290970174328, 0.05560389220980661, 0.05247070587107113, 0.09851483016141824, 0.06276554095425776, 0.15201163025838987, 0.048519314865448644, 0.08996857982128859, 0.6211538634129933, 32.81985078539167, 47.8836738722665, 39.89530215944563, 49.601716722760884, 32.948979582105366, 35.015373843056814, 43.68238306045532, 57.11378594807216, 71.93267808641706, 3.7668434040887013, 0.0941730813522424, 0.551969184407166, 1.5430992607559477, 3.6854895523616245, 67.09270886012486, 76.87790557316372, 70.60194519587925, 68.69651290348598, 70.09919439043317, 80.25260393960136, 72.96677848270961, 70.43054703303746, 69.17530632019043, 68.89719077519008, 63.29055036817278, 61.51711995261056, 64.51427405221122, 65.86119624546596, 66.94435092381069, 69.75144399915422, 74.78059182848249, 78.68698719569615, 72.72180584498814, 68.74470560891288, 68.34558718545097, 64.22685486929757, 62.050248282296316, 57.88922575541905, 53.73966428211757, 50.748082637786865, 47.59376376015799, 45.828334195273264, 45.938987731933594, 43.480371134621755, 41.301631450653076, 43.7672518321446, 45.118600027901785, 45.31185027531215, 43.58730043683733, 41.83166435786656, 39.90509564535958, 40.67347955703735, 37.937994616372244, 39.108387402125764, 36.74374171665737, 39.06137589045933, 39.19149827957153, 43.22217607498169, 48.04966286250523, 52.64081709725516, 54.969853264944895, 55.83580378123692, 57.210480553763254, 54.670785427093506, 49.57517113004412, 48.7404214995248, 54.92320653370449, 56.47055993761335, 54.87923833302089, 54.827314444950645, 55.42881999697004, 58.589774404253276, 53.348748207092285, 52.261688641139436, 48.282886096409385, 44.42629541669573, 41.39425788606916, 40.4301050049918, 41.647460665021626, 42.057317529405864, 33.87813091278076, 43.191635268075125, 52.55448572976248, 54.951475279671804, 50.33247266496931, 36.47608321053641, 43.32187230246407, 54.54505777359009, 54.59886809757778, 52.08502721786499, 51.08543157577515, 51.73103734425136, 49.46217605045864, 48.1040220941816, 51.88075017929077, 50.30234180177961, 47.36247212546212, 47.867258753095356, 46.341945035117014, 45.563875334603445, 48.078404085976736, 46.96470512662615, 44.89624030249459, 42.63049527576992, 41.60956171580723, 40.03032997676304, 43.19011013848441, 41.40232821873256, 44.150212219783235, 44.328482151031494, 40.76223931993757, 41.02336999348232, 39.56881672995431, 38.648142201559885, 44.89818579810006, 42.254625524793354, 43.55746487208775, 41.356751510075156, 42.68999964850289, 42.25216586249215, 45.24743700027466, 44.62303713389805, 45.317836148398264, 43.77272006443569, 46.04966558728899, 46.39369521822248, 47.316290923527305, 47.12780019215175, 46.79187910897391, 47.66305119650704, 50.20686660494123, 50.738417693546836, 56.24111999784197, 57.3505597114563, 62.49024295806885, 59.553315843854634, 64.34348733084542, 64.20018768310547, 65.38469573429653, 57.09790931429182, 53.04721028464181, 3.2927819277559007, 1.6270502188376017, 1.836067340203694, 0.11711534777922289, 0.1225853714027575, 4.161489793232509, 63.0180698122297, 59.204794202532085, 62.18675259181431, 42.68436465944563, 42.73386362620762, 37.11848585946219, 17.028902190072195, 33.98601559230259, 50.49719360896519, 66.00209181649345, 24.41524028778076, 0.36652024409600664, 0.13495976025504725, 0.0587653395320688, 0.09331290929445199, 0.04421359287308795, 0.011379914358258247, 0.03493795810001237, 0.12733465512948378, 0.03813064856720822, 0.047012814453669956, 0.03672630499516215, 0.0814913297072053, 0.04508615158764379, 0.058772199521107335, 0.06457161796944481, 0.029050727042236497, 0.09626771216945988, 1.0660434365272522, 41.25147587912423, 59.4513510295323, 50.056681292397634, 58.85716887882778, 37.3451360974993, 30.058164187840053, 49.5890223639352, 67.93704005650112, 76.30119119371686, 4.047022998332977, 0.2796952288065638, 0.9861657513039452, 2.447959146329335, 6.106184184551239, 69.46941661834717, 80.68547671181815, 74.7257080078125, 69.33768572126115, 72.32002626146588, 80.13560322352818, 74.45434611184257, 70.48866871425084, 72.72090952736991, 70.53776468549455, 66.943190574646, 65.37066037314278, 66.38764040810722, 66.21514442988804, 70.71527031489781, 71.74063682556152, 74.71691853659493, 78.52527482169015, 76.2238438470023, 72.88466467176164, 69.25331374577114, 67.42377662658691, 62.740197454180034, 61.75422028132847, 55.23263413565499, 52.477155753544395, 49.946972710745676, 49.29073619842529, 47.531751087733674, 46.384162289755686, 44.826855591365266, 46.88267469406128, 46.557509422302246, 46.3232786996024, 45.212035928453716, 43.5693393434797, 42.824770382472444, 44.89167881011963, 42.07995823451451, 42.77970436641148, 39.13414437430245, 41.57360826219831, 41.2810891015189, 45.735217911856516, 48.27275562286377, 54.02785471507481, 55.80914354324341, 57.217880385262625, 60.788253920418875, 55.91864367893764, 52.89008372170584, 50.496828828539165, 56.39263241631644, 60.08125386919294, 57.612871578761506, 56.19076640265328, 57.691907337733674, 59.041907582964214, 56.06912428992135, 55.008158683776855, 52.15937294278826, 46.96048409598214, 40.62915005002703, 42.164688042231965, 44.29717009408133, 43.37676307133266, 39.41289915357317, 46.237808908735005, 56.28137786047799, 57.58786153793335, 54.56497131075178, 41.848385197775706, 44.256286893572124, 57.742149761744905, 54.88607883453369, 57.0790935925075, 52.58749314716884, 53.00409671238491, 52.57740436281477, 49.81049966812134, 54.48393447058541, 53.55375133241926, 49.78184529713222, 49.184484345572336, 47.74058614458357, 47.717670985630576, 50.82681267602103, 50.33478988919939, 48.775461265019004, 46.65110165732247, 43.8871534211295, 44.60243572507586, 43.983469349997385, 44.23887470790318, 45.824005467551096, 46.60809578214373, 43.32668392998831, 42.154981408800396, 42.272520610264365, 41.239973136356895, 46.57339300428118, 45.33825690405709, 45.22470596858433, 44.21606724602835, 45.282626152038574, 43.50288677215576, 47.85145507540022, 47.02757937567574, 47.97917686189924, 45.53138555799212, 47.783939429691856, 48.15969453539167, 50.65008871895926, 48.2591267313276, 49.39799901417324, 50.994222572871614, 54.82798842021397, 54.91160304205758, 58.17121492113386, 59.842027391706196, 66.5500545501709, 61.913834299360005, 66.78304154532296, 64.98014381953648, 66.39485263824463, 56.85116488592965, 56.14646468843733, 6.014883552278791, 0.583611823618412, 1.7126344378505434, 0.5500375851988792, 0.04727156021233116, 3.6750008123261586, 66.90623310634068, 66.76428140912736, 67.75184971945626, 52.09314271381923, 41.33986043930054, 20.273683139256068, 22.976414271763392, 41.20296703066145, 55.392738001687185, 71.21342836107526, 28.427788496017456, 0.34167769285184996, 0.08611631938921553, 0.1350952908396721, 0.1148682569286653, 0.03925421434853758, 0.030234628157424073, 0.014052715535009546, 0.10663563904485532, 0.14546861206846579, 0.1698031441441604, 0.17660913536591188, 0.13190997604812893, 0.17404531793934958, 0.23302122045840534, 0.2108243586761611, 0.18222706605281147, 0.20384783803352288, 1.214061779635293, 49.7790903363909, 70.01013932909284, 57.95546293258667, 62.91232517787388, 42.642866543361116, 51.26476458140782, 61.77511351449149, 73.30771963936942, 85.21337454659599, 5.2553837810243875, 0.3446077699107783, 2.323854548590524, 6.599039452416556, 7.142305203846522, 75.67938300541469, 83.90953813280377, 77.23450796944755, 73.30010441371373, 76.45870685577393, 83.0361773627145, 76.23432173047746, 72.43965339660645, 72.93118980952671, 75.43347930908203, 69.17415291922433, 66.6855583190918, 69.31976631709507, 71.0255560193743, 74.16238280705043, 73.3539182118007, 75.00529657091413, 77.03191934313092, 75.37365531921387, 76.4312058857509, 76.76824215480259, 71.38905102866036, 66.34446430206299, 64.99867466517857, 58.314973149980815, 57.152494362422395, 53.05941479546683, 51.75155537469046, 50.51859406062535, 49.38717719486782, 47.27439676012312, 48.602802004132954, 48.627447264535085, 48.91414730889456, 46.94887713023594, 45.42318820953369, 44.966149602617534, 47.16259329659598, 45.52197074890137, 46.5460970061166, 41.669830390385215, 44.795616490500315, 45.68923125948225, 48.36079624720982, 51.226962906973704, 58.24346229008266, 57.898331369672505, 62.08488505227225, 62.760006768362864, 58.78476170131138, 54.94289078031267, 53.117671966552734, 59.783912658691406, 61.814516748700825, 58.651884351457866, 58.58730084555489, 60.10266126905169, 62.88003689902169, 56.85558046613421, 56.7974066734314, 56.43772622517177, 49.62536839076451, 44.68157223292759, 43.145064967019216, 45.342259066445486, 46.79174361910139, 42.37996060507638, 50.26413713182722, 58.17500516346523, 60.64612851824079, 52.60901519230434, 36.934004238673616, 46.541532039642334, 58.34460721697126, 58.317870548793245, 58.60390704018729, 54.89353425162179, 54.63047545296805, 54.577933175223215, 53.79507269178118, 57.53871692929949, 54.98966257912772, 52.66361066273281, 52.845504079546245, 50.06129142216274, 49.66842985153198, 54.49035113198416, 53.783364977155415, 50.7242294720241, 48.79132400240217, 46.44778347015381, 48.408693654196604, 48.22670643670218, 47.910254205976216, 47.84736953462873, 48.890328884124756, 46.4902925491333, 44.92592300687517, 45.373866421835764, 45.2360315322876, 49.83123656681606, 47.15448127474104, 48.69121783120291, 46.638191904340474, 46.93865980420794, 46.81688914980207, 51.40694209507534, 50.47918387821743, 51.731999669756206, 48.647899287087576, 52.155270031520296, 52.802671909332275, 54.261533055986675, 52.27011680603027, 51.73361165182931, 54.07136780875069, 57.830284186771934, 57.70613724844796, 63.01900781903948, 63.41752869742257, 70.33770520346505, 64.92100075313023, 70.85005841936383, 69.27613162994385, 69.59142003740583, 57.74378606251308, 59.323698725019185, 5.588076991694314, 4.378019545759473, 6.343908114092691, 0.42683956452778404, 0.17551780678331852, 5.749212230954852, 75.94074644361223, 69.60909625462124, 75.92348017011369, 60.28161212376186, 60.02193709782192, 51.54831709180559, 27.813545158931188, 49.623770305088584, 63.42316368647984, 80.97282641274589, 36.66141945975167, 0.5206537076405117, 0.3110324186938149, 0.23555948425616535, 0.19906328405652726, 0.10673047109906163, 0.0890235433887158, 0.14127263293734618, 0.19778567046991416], [0.02527056265223239, 0.05184310169092246, 0.042770739046058485, 0.03225324948185256, 0.04383123839007957, 0.07696620680923973, 0.045468126091041734, 0.03583993809297681, 0.1167414342718465, 1.1829657682350703, 22.419776712145122, 51.182192189352854, 43.40659168788365, 39.79846511568342, 30.02420834132603, 54.042306968144004, 41.791614941188264, 67.31481497628349, 50.75717088154384, 0.4242262276155608, 0.0534853294624814, 0.7113755164401872, 1.5234483437878745, 18.565423352377756, 74.83153602055141, 74.82260758536202, 70.74910804203579, 62.7711238861084, 73.30109800611223, 72.44079984937395, 70.56780869620187, 70.20951788766044, 69.27539512089321, 69.13056686946324, 66.00649697440011, 66.12991087777274, 69.40188707624162, 67.24318599700928, 66.99915136609758, 61.178089550563264, 63.49133941105434, 60.600819315229145, 58.34920692443848, 60.10345336369106, 61.18043804168701, 63.72857175554548, 61.63666370936802, 59.109867913382395, 54.83927229472569, 50.842126505715505, 46.82588359287807, 47.789445877075195, 46.88861540385655, 42.16038015910557, 41.258041926792686, 42.63088437489101, 45.226759161267964, 44.7213819367545, 46.133287157331196, 43.891926833561485, 41.28975697926113, 38.446950163160054, 38.294159276144846, 39.06046915054321, 38.62235048839024, 38.49847452981131, 37.69164970942906, 40.37932409558977, 43.707691873822895, 51.611448424203054, 55.046266078948975, 54.985458918980186, 57.55581644603184, 56.216888155256, 53.953665324619834, 50.48672614778791, 54.281821795872276, 57.07153742653983, 54.338668482644216, 52.977964537484304, 57.603404658181326, 53.64299052102225, 52.72872223172869, 53.889842646462576, 47.23478160585676, 40.20505632672991, 42.654150417872835, 39.5433064188276, 39.53405141830444, 41.33377381733486, 41.04135193143572, 45.22201006753104, 52.97405270167759, 54.354618072509766, 56.27719851902553, 54.39534146445138, 50.71812200546265, 51.59182323728289, 50.46182727813721, 53.2025476864406, 51.79406097957066, 52.04829556601388, 49.60465233666556, 48.233227321079795, 47.433034556252615, 45.00788395745413, 45.18585511616298, 44.68772486277989, 47.176687717437744, 46.80384390694754, 46.73465721947806, 44.65256002971104, 43.03360891342163, 42.32070289339338, 40.92681435176304, 40.39750405720302, 43.51831872122628, 47.194600173405235, 47.86420849391392, 45.77075447354998, 42.722503321511404, 40.81141866956438, 39.30348934446062, 39.25939955030169, 42.33987644740513, 44.33749743870327, 41.322271074567524, 42.61920097896031, 42.81966345650809, 44.566965171269004, 42.43859992708479, 44.0130478313991, 43.99816826411656, 46.770996298108784, 45.87374414716448, 47.08191081455776, 49.898297105516704, 50.69258737564087, 53.12206322806222, 54.81594024385725, 55.46717405319214, 59.494944027491975, 58.85617528642927, 62.182555879865376, 62.028465679713655, 63.85038757324219, 60.410501207624165, 61.650942257472444, 58.63061591557094, 59.654064723423545, 63.217330251421245, 38.31964526857649, 0.5663313280258859, 0.967603855899402, 1.639053231903485, 0.1954218851668494, 0.05708002817950078, 36.87076868329729, 63.630893979753765, 61.02971771785191, 48.054623876299175, 43.39353254863194, 37.67423752376011, 16.332864659173147, 29.011633464268275, 55.18320117677961, 57.98244626181466, 28.477617502212524, 0.2635912043707711, 0.08979299531451293, 0.016067716026944772, 0.059307665431073735, 0.00536752539587074, 0.059318718766527515, 0.06060698535293341, 0.0348187632459615, 0.026625111931934953, 0.017472578678280115, 0.024239847602854882, 0.05575416057503649, 0.05152888908716185, 0.12789306230843067, 0.07612905065928187, 0.03787946168865476, 0.10196187626570463, 1.6591752150229044, 33.922373567308696, 64.41378225599016, 50.665235791887554, 45.27173832484654, 21.046143906457083, 38.22193622589111, 48.929704325539724, 74.15288461957658, 53.76314571925572, 0.32734700611659456, 0.014071915531530976, 0.27255283349326676, 1.724513577563422, 22.52746684210641, 78.39137608664376, 75.7317863191877, 74.52309158870152, 65.4085419518607, 74.80321516309465, 72.86005415235246, 71.48967484065464, 71.29467364719936, 74.50674247741699, 68.23324871063232, 70.11290318625313, 69.28888157435826, 70.78589875357491, 69.74955408913749, 69.20628138950893, 63.7735960824149, 66.98467132023403, 64.7898257119315, 62.985093661717, 63.823372977120535, 63.99905817849295, 64.79584980010986, 64.68269838605607, 61.705318859645296, 56.74410009384155, 52.436227389744346, 49.40839351926531, 48.9048957824707, 48.993478366306846, 44.234438283102854, 44.200822898319785, 46.47274487359183, 47.742205074855256, 46.13617065974644, 47.329728739602224, 45.86948142732893, 44.56592641557966, 41.9054160118103, 41.376936026981895, 40.281670638493125, 41.51161643436977, 40.35391453334263, 42.23926305770874, 42.677485942840576, 47.405808040073936, 52.05290569577898, 58.4720093863351, 57.90775312696184, 60.028586523873464, 57.829102993011475, 57.46158845084054, 53.17666564668928, 55.309043475559776, 60.15765626089913, 56.0940648487636, 55.54983677182879, 57.8485301562718, 56.59754521506173, 55.475744656154085, 57.56721843991961, 49.168086596897666, 44.05608149937221, 47.099941389901296, 40.80991438456944, 39.825052397591726, 42.15841381890433, 43.133367674691335, 48.458411489214214, 54.783085686819895, 56.74144588197981, 55.80911922454834, 54.25262199129377, 54.14003338132586, 54.060111727033345, 54.931530475616455, 56.11717108317784, 55.07818610327584, 56.32678781236921, 52.470124176570344, 52.15545415878296, 49.05208642142159, 47.530535152980256, 47.68473999840872, 47.00449398585728, 49.712259088243755, 49.73880468096052, 49.23633180345808, 46.53073106493269, 45.41014644077846, 44.396956648145405, 42.299285071236746, 43.274110385349815, 45.52870355333601, 50.634118284497944, 50.62595762525286, 48.684300899505615, 46.884592396872385, 43.85409389223371, 41.44337470190865, 42.963869844164165, 44.30609852927071, 46.76252991812569, 43.384750025612966, 44.5446822983878, 45.02786002840315, 45.258435998644146, 45.6870391028268, 46.83397824423653, 46.363779749189106, 48.63748741149902, 48.9616938318525, 51.49803645270211, 51.82962533405849, 53.250115053994314, 55.522540773664204, 59.10627569471087, 58.6935179574149, 62.90760040283203, 61.15225614820208, 65.05642114366803, 66.4638899394444, 65.96027060917446, 61.35498373849051, 62.68585559300014, 57.711459568568635, 62.16880539485386, 64.21803760528564, 45.32778944287981, 1.0722403611455644, 0.46138953630413326, 0.3986451317157064, 0.1781629669879164, 0.05420998789902244, 38.47931834629604, 70.13305991036552, 65.13973004477364, 57.4931332724435, 47.534478255680625, 34.31587437220982, 19.346843821661814, 37.13556105749947, 58.78239931379046, 68.32392270224435, 36.81445005961827, 0.20128909604890005, 0.08530418082539525, 0.01963034548264529, 0.07790048167641674, 0.01621742799345936, 0.04105316335335374, 0.028693251045686857, 0.07257725910416671, 0.09087278880178928, 0.08440884029758827, 0.12884204781481198, 0.15112416073679924, 0.09945104563874857, 0.19848913486514771, 0.1488866372300046, 0.17408904273595127, 0.242154953203031, 2.2936644085815976, 48.12964357648577, 75.4114465713501, 61.97357491084507, 53.57593693052019, 40.11044618061611, 77.65741007668632, 56.60951348713466, 80.20725304739815, 60.97744641985212, 0.7357005625963211, 0.08937845791557006, 2.5161044725349972, 4.71961600439889, 25.94866602761405, 83.353835105896, 80.27142660958427, 77.96521527426583, 69.02795587267194, 78.12783091408866, 76.11543110438755, 72.44508688790458, 73.26665578569684, 73.94024889809745, 71.66898005349296, 71.3263852255685, 72.01846054622105, 74.51861694880894, 73.53181294032505, 70.58696487971714, 64.13624341147286, 66.850188936506, 70.27726282392229, 67.65857015337262, 69.62777996063232, 64.3687996183123, 65.67144094194684, 68.08167375837053, 66.06585543496269, 60.15710735321045, 56.6503723689488, 51.89735984802246, 52.709597315107075, 51.45739991324288, 47.96489831379482, 46.17848171506609, 49.9913786479405, 49.558564935411724, 49.47701392854963, 49.89409344536917, 48.6087600844247, 46.26353113991873, 43.606915201459614, 45.9023220879691, 44.004126344408306, 44.3011131967817, 42.81325374330793, 44.03213105882917, 45.190110887799946, 50.12509672982352, 56.06189816338675, 60.580065046037944, 59.3718705858503, 62.40508583613804, 58.43883868626186, 59.7748452595302, 55.26657608577183, 57.875030585697715, 62.56094087873186, 59.2623530796596, 58.676272528512136, 61.85272489275251, 57.25322239739554, 56.00878265925816, 59.9702216557094, 52.94655867985317, 48.52514546258109, 46.677741050720215, 40.69238213130406, 40.31202036993844, 43.624612263270784, 47.443401268550325, 53.10775688716343, 58.42151682717459, 60.84801537649972, 58.53278527941023, 55.634045464651926, 55.64392927714756, 57.09527942112514, 55.22246544701712, 58.90470150538853, 57.71017415182931, 58.77177551814488, 53.24512277330671, 54.86313588278634, 51.67319359098162, 50.871572971343994, 49.73069960730416, 50.612731729234966, 52.42306750161307, 51.40893275397164, 50.216378688812256, 48.61748354775565, 47.01981476375035, 47.6089004107884, 46.38029214314052, 47.452447823115754, 48.637831347329275, 53.05992896216256, 51.840697288513184, 50.3671407018389, 49.84568534578596, 46.907031604221885, 44.70297963278634, 45.75069155011858, 47.907259532383506, 48.93832703999111, 45.14900534493582, 46.95038488933018, 47.293257645198274, 49.75871821812221, 46.860673223223, 49.30593885694231, 47.94052750723702, 51.15266234534127, 51.86157315117972, 54.27211168834141, 55.99872166769845, 55.515672479357036, 58.46183027539934, 61.58640044076102, 61.533156394958496, 65.18938187190464, 64.26977389199394, 67.34310109274728, 69.00514493669782, 68.56419140951974, 63.893501145499094, 62.95862102508545, 58.1681855065482, 62.465604645865305, 64.48935781206403, 45.543190547398154, 1.0349423225436891, 6.2685666254588535, 4.073672814028604, 0.297719235931124, 0.13453043757804803, 44.56046165738787, 76.0518272944859, 71.16794545309884, 64.39037377493722, 58.224736894880024, 56.26355920519148, 22.38162762778146, 46.34259121758597, 66.01853125435966, 78.26480075291225, 49.42347111020769, 0.297952869108745, 0.20068260787853173, 0.30371919540422304, 0.15805956215730735, 0.13760264058198246, 0.22950336922492298, 0.11660392236496721, 0.16555824263819627], [0.07704580575227737, 0.029318707662501504, 0.0257812247145921, 0.05749864357390574, 0.034448086350624046, 0.08233510835894517, 0.10198946549956288, 0.03892805613577366, 0.08462120818772487, 2.72613679085459, 21.373245988573345, 39.28801223209926, 46.17019598824637, 46.85944339207241, 50.687018394470215, 68.22520964486259, 39.33335270200457, 76.36043848310197, 27.020390919276647, 0.11564257395054613, 0.05318731348961592, 0.3527819184320313, 1.9752920866012573, 41.53124162128994, 77.92301886422294, 70.44292177472795, 71.03049618857247, 67.24019827161516, 71.41903945377895, 77.64252703530448, 67.53048011234829, 68.53726713997978, 68.14408942631313, 68.79275935036796, 71.25201170785087, 68.34337765829903, 70.436126436506, 66.11980819702148, 64.32640865870884, 64.2262851170131, 64.13311672210693, 65.71620123726981, 67.45090934208461, 68.44550228118896, 65.4784825188773, 64.12401458195278, 61.42633478982108, 60.78368200574602, 55.98773309162685, 50.14955786296299, 45.722311632973806, 45.80888966151646, 47.03834560939244, 42.85786117826189, 41.316764627184185, 41.73987865447998, 45.32059458323887, 44.79837492534092, 44.693415437425884, 45.05142136982509, 42.50665405818394, 42.161790643419536, 37.52520908628191, 36.301377705165315, 37.28702136448452, 38.72827230181013, 37.64222717285156, 38.54978002820696, 41.82327093396868, 47.77664382117135, 55.21907820020403, 56.579973220825195, 57.559908935001914, 57.03024428231375, 56.595106397356304, 59.47343935285296, 52.51413059234619, 53.26610285895211, 49.67520087105887, 50.845701353890554, 51.8064079284668, 56.50066648210798, 54.51528821672712, 53.52976962498256, 40.99410765511649, 28.47070230756487, 45.066644872937886, 42.595702171325684, 40.534717082977295, 41.89623049327305, 41.13834878376552, 42.9650753566197, 53.02625104359218, 50.86786263329642, 52.04444278989519, 52.60210173470633, 52.57478141784668, 52.125472681862966, 51.23551613943917, 47.204549993787495, 52.35685464314052, 50.17858048847744, 50.85840613501412, 47.26868534088135, 45.94632155554635, 43.85600117274693, 43.34753894805908, 46.011217730385916, 50.531635829380576, 48.24425758634295, 46.747963019779746, 47.16381270544869, 43.36296394893101, 39.70556422642299, 38.76677574430193, 39.79649530138288, 45.355377265385215, 43.72949532100132, 53.204041549137656, 45.918184825352256, 43.559142862047466, 42.51536362511771, 38.72814376013619, 38.78760644367763, 40.180081026894705, 43.169734546116416, 42.13789578846523, 43.167111601148335, 41.48603664125715, 43.408040387289866, 41.81109421593802, 45.81833226340157, 46.64358370644705, 47.94719082968575, 49.80982916695731, 53.184541429792134, 55.43332937785557, 59.24109159197126, 56.67256491524832, 58.08639826093401, 57.25075578689575, 61.03105872017996, 58.274121216365266, 61.814850262233186, 60.233384677342, 61.00664275033133, 56.36391551154, 63.92694977351597, 62.550671441214426, 68.85179819379533, 61.93303912026541, 75.33106286185128, 27.383284909384592, 0.8147378957697323, 1.9848269692489078, 0.4374923471893583, 0.2367709135370595, 12.70052100930895, 65.05442701067243, 56.25512409210205, 56.86245570863996, 38.199212142399375, 34.876458508627756, 32.159066677093506, 34.15167106900896, 38.78773151125227, 50.37438072477068, 42.94775002343314, 0.5322018308298928, 0.06242440068828208, 0.05395288419510637, 0.02358026067460222, 0.10093582953725543, 0.01779337476805917, 0.155730504276497, 0.10885690485260316, 0.01584395214116999, 0.08006091681974274, 0.016233209021655575, 0.03192665022132652, 0.046800405851432254, 0.06883549809988056, 0.11282470622765166, 0.027707475370594432, 0.05560074719999518, 3.4471761115959714, 33.59501961299351, 53.704627990722656, 60.633781569344656, 56.71159642083304, 28.55283522605896, 65.23776912689209, 49.68209000996181, 83.9530338559832, 29.39862380708967, 0.10616513607757432, 0.005901821257014359, 1.055168854338782, 2.3890199661254883, 46.29555538722447, 79.55500480106899, 74.30065890720913, 74.75500161307198, 70.43878759656633, 73.93710136413574, 79.6737425667899, 68.4840647833688, 67.76416192735944, 71.63936683109829, 70.4647113255092, 72.03890909467424, 70.97126279558454, 72.54500198364258, 67.92514474051339, 66.49660900660923, 65.43227699824742, 67.36925411224365, 67.11586720602853, 68.18921797616142, 70.01708057948521, 68.00374276297433, 66.27257823944092, 64.65908145904541, 63.31006785801479, 57.39520883560181, 51.57566867555891, 48.10454320907593, 49.343834332057405, 49.28685562951224, 44.54180574417114, 44.42313051223755, 45.391719818115234, 46.75799969264439, 47.1687250818525, 46.047174658094136, 45.925404003688264, 42.729475838797434, 44.88531426021031, 39.260563373565674, 40.0069979258946, 40.62361233575003, 40.08311891555786, 41.18128170285906, 40.900654384068076, 42.467007637023926, 48.85642862319946, 58.109827586582725, 56.80047082901001, 60.094823701041086, 60.28890773228237, 58.515143803187776, 59.97562735421317, 56.43613508769444, 55.149696963174, 52.389552865709575, 51.238872119358604, 53.24725239617484, 58.27572277614048, 56.43060432161604, 57.124187401362825, 45.27663333075387, 33.789061955043245, 46.30456025259835, 43.713041986737935, 39.74099309103829, 42.377928256988525, 43.61239733014788, 43.61114318030221, 55.37223734174456, 54.977166243961875, 56.55597414289202, 54.363536085401265, 56.13912739072527, 53.24837105614798, 52.296116965157644, 51.0909241267613, 54.93296875272478, 52.68058163779122, 52.19332184110369, 49.54933425358364, 48.34283515385219, 46.62018912179129, 45.65907260349819, 48.15011644363403, 54.07593624932425, 50.963035583496094, 49.94582278387887, 46.755988189152305, 45.89173303331648, 42.40286881583077, 42.94465807506016, 42.21742139543806, 46.92959587914603, 44.88456732886178, 53.41886247907366, 47.633959089006694, 46.69837025233677, 46.266963550022666, 42.5235208102635, 41.37531362261091, 43.566122327532085, 44.934045451028005, 45.121566908700125, 45.81397574288504, 43.92555264064244, 45.96286869049072, 46.36290775026594, 48.69425766808646, 50.42620038986206, 51.73248256955828, 52.03056723730904, 56.59728465761457, 58.31923239571707, 61.83781405857631, 60.359633445739746, 61.3764328275408, 60.97098459516253, 64.58574322291783, 62.04709380013602, 64.16056210654122, 60.7960011618478, 60.414023944309776, 57.60308156694685, 65.70044272286552, 65.44893183026994, 71.95678833552769, 63.40730789729527, 78.25023732866559, 34.65520354679653, 0.2908459204648222, 0.19338191034538404, 0.27778767687933786, 0.395553427615336, 12.715284194265093, 71.91156251089913, 64.09347724914551, 62.61994498116629, 47.53312335695539, 29.58771903174264, 26.066785403660365, 47.44878612245832, 45.139121532440186, 59.48232609885079, 50.22104787826538, 0.2750180597816195, 0.053679882415703366, 0.03341949511585491, 0.06512043066322803, 0.08302521918501173, 0.048911128126616986, 0.0673607090221984, 0.039147585963032076, 0.13987031818500587, 0.15239717385598592, 0.11365363174783331, 0.15890478608863695, 0.19773372182888643, 0.12265325204602309, 0.19070177844592504, 0.12403347369815622, 0.3433050098163741, 4.275274796145303, 50.67729091644287, 61.416558674403596, 66.19669001443046, 62.24651404789516, 71.46203490665981, 91.73497458866665, 54.46917997087751, 93.40904576437813, 33.80848911830357, 0.21085087582468987, 0.22598637294556412, 3.1266452882971083, 3.630551666021347, 51.48534556797573, 84.17013726915631, 76.2707302910941, 77.56052439553397, 75.19037573678153, 77.44849164145333, 83.52973570142473, 70.89743818555559, 67.59592519487653, 74.06430898393903, 72.55868298666817, 76.12802124023438, 75.10610103607178, 75.19930417197091, 68.88544831957135, 68.7104857308524, 70.25188800266811, 72.12825598035539, 70.49465111323765, 70.73548262459892, 72.18196555546352, 69.25531482696533, 70.86577524457658, 67.90470314025879, 65.45817293439592, 61.025562695094514, 54.514614241463796, 49.33652482713972, 49.91255828312465, 52.182017121996196, 46.38124404634748, 47.57476738521031, 46.82074540002005, 50.09537928444998, 49.076940127781455, 48.5877035685948, 46.99412032536098, 46.1372788974217, 46.626154150281636, 42.24126761300223, 41.70264673233032, 44.685296467372346, 43.18721273967198, 43.440530163901194, 44.63848992756435, 45.33143377304077, 51.55634226117815, 60.185185023716514, 60.57485389709473, 64.25592613220215, 61.6699594770159, 59.530831473214285, 62.451652663094656, 59.06599003928048, 57.82702200753348, 52.984534059252056, 54.72922325134277, 55.01130274363926, 63.12088925497872, 59.13459655216762, 60.67902823856899, 48.78858641215733, 38.64968122754778, 49.044116837637766, 44.749807017190115, 41.822735922677175, 43.240481104169575, 46.3258877481733, 49.42066056387765, 57.224491596221924, 56.152019773210796, 56.838651180267334, 57.0565744808742, 59.97539806365967, 56.6640498978751, 57.216164180210654, 54.12284006391253, 57.21619544710432, 55.06881645747593, 55.76671436854771, 51.561240741184776, 52.119792529514854, 50.05790070125035, 48.50199406487601, 51.403124059949604, 56.65010486330305, 51.82797166279384, 52.6400180544172, 50.84972088677542, 48.95013550349644, 45.694022042410715, 45.58495964322771, 44.623221261160715, 48.97828265598842, 45.79670599528721, 56.407105513981406, 49.721753801618306, 49.327620710645405, 48.967547689165386, 42.931807381766184, 42.98412036895752, 46.39169066292899, 46.22941895893642, 46.756606578826904, 48.342939376831055, 45.7885696547372, 49.694346632276265, 48.91431059156145, 51.37835373197283, 53.82438019343785, 52.98039640699114, 55.068809509277344, 57.66208219528198, 62.28681359972273, 65.39604909079415, 62.85114628928048, 63.166212354387554, 63.987690925598145, 67.88828454698834, 64.33130019051688, 65.33235495431083, 62.848373958042686, 65.22989681788853, 57.394187450408936, 67.02676350729806, 67.36932359422956, 74.83539227076939, 67.66622706821987, 82.55582754952567, 33.58471890858242, 2.4924697407654355, 9.805601835250854, 0.6592999622225761, 0.40308041657720295, 16.39369092668806, 79.82330254146031, 68.23306805746896, 71.60447992597307, 53.83493103299822, 51.0525735446385, 40.92628628867013, 50.307566847120015, 52.426812580653596, 67.11267798287528, 60.62954316820417, 1.1924113013914652, 0.18598000252885477, 0.20755410487098352, 0.13862224801310472, 0.15700258101735795, 0.11320930666157178, 0.21512275588299545, 0.21370860747992992], [0.054188800643065145, 0.019365145159619193, 0.0633639409872038, 0.01791137540047722, 0.02629922004416585, 0.08584934300077812, 0.02835282663415585, 0.04894009478656309, 0.06579469769660916, 2.8266598539693013, 24.919465848377772, 41.443951402391704, 43.67567457471575, 28.648789848600114, 30.739810262407573, 48.87059252602713, 44.55423954554966, 74.12418161119733, 11.950919815472194, 0.17143693433276244, 0.3848782532981464, 0.6344276911446026, 6.928476997784205, 44.72945574351719, 69.98806490216936, 75.7135820388794, 69.00668048858643, 66.02740410396031, 75.8273240498134, 70.35301208496094, 72.22395351954869, 61.79530497959682, 59.542907442365376, 69.14663110460553, 69.43031215667725, 69.32815279279436, 70.33852509089878, 68.52636541639055, 65.60261903490338, 67.61622783115932, 64.62025492531913, 62.61736025129046, 62.01844637734549, 58.931778635297505, 62.72310488564627, 63.975462096078054, 58.77896690368652, 59.44621631077358, 56.746358258383616, 48.63882493972778, 47.24868842533657, 46.55002621241978, 45.53801761354719, 41.645598547799246, 43.174066747937886, 44.25823238917759, 45.590261118752615, 48.433519567762104, 45.11193323135376, 46.471310070582796, 44.605864661080496, 41.869142941066194, 39.82931511742728, 36.03405966077532, 38.257104533059255, 38.36725779942104, 39.79205192838396, 37.63065147399902, 39.28985003062657, 42.521321705409456, 50.641792569841655, 55.979197229657856, 54.27646126065935, 56.05601303918021, 55.839496748788015, 56.06220735822405, 54.1259320122855, 52.67240360804966, 50.30563872201102, 48.19976132256644, 48.69931943075997, 54.35965551648821, 55.079391615731375, 51.16387326376778, 40.93496806280953, 24.204162699835642, 48.700903620038716, 47.397157532828196, 36.21675212042672, 38.930589948381694, 35.622507435934885, 41.9081084387643, 51.09097623825073, 51.374560015542166, 50.32044185910906, 54.37699474607195, 54.516789027622764, 51.24851621900286, 48.87073496409825, 45.150947366442, 48.59784099033901, 51.49162673950195, 47.71346732548305, 46.09190368652344, 44.21763059071132, 43.834055287497385, 44.64287771497454, 47.37252616882324, 49.16220842088972, 49.702774797167095, 46.0499643598284, 41.182521956307546, 38.885826178959434, 38.49486494064331, 38.155952657972065, 43.596280983516145, 42.821188586098806, 42.221301964351106, 42.90678691864014, 44.08428076335362, 44.739481994083945, 43.99864421572004, 40.75988735471453, 40.14608349118914, 39.66140842437744, 42.82900183541434, 44.45651313236782, 42.95697028296334, 43.64592586244856, 43.09036874771118, 43.43232086726597, 46.509101322719026, 50.87604761123657, 52.81850685392107, 56.64649527413504, 57.012575013296946, 58.85702991485596, 57.639667306627544, 61.49107115609305, 58.356099537440706, 58.87862491607666, 59.32330962589809, 61.529383523123606, 57.09221526554653, 61.300252778189524, 61.70759092058454, 65.52211720602853, 62.292031696864534, 68.8580515725272, 62.03261375427246, 68.59845992497036, 60.215423583984375, 75.45813151768276, 9.412099293300084, 1.2408385085208076, 0.5773425400257111, 0.08836399377988917, 1.3248889126947947, 53.827673639569966, 57.734878471919465, 56.08684914452689, 46.93882656097412, 44.70898635046822, 25.337497268404277, 16.074575798852102, 40.719024998801096, 55.7988532611302, 43.623420647212434, 1.645585407103811, 0.18049947518323148, 0.08709960484078952, 0.11541506115879331, 0.014779327304235526, 0.04828112532517739, 0.012168162552240704, 0.09624122216233186, 0.04460027301684022, 0.040559237357228994, 0.076226678277765, 0.012053962564095855, 0.04526309994980693, 0.12380901431398732, 0.07422830443829298, 0.07406749842422349, 0.13256597013345786, 3.3132061575140273, 40.64442913872855, 50.52406924111502, 51.635082721710205, 37.667987619127544, 32.03467655181885, 55.37053503308977, 51.86020088195801, 80.89759826660156, 12.024545533316475, 0.30094933403389795, 0.3672685596559729, 0.7335345702511924, 9.081101877348763, 54.338400976998464, 74.3323426927839, 76.39003086090088, 70.66288784572056, 68.66410650525773, 77.87156745365688, 72.77661323547363, 71.22343376704625, 64.2146885735648, 60.90802001953125, 70.26702812739781, 71.18414865221295, 72.1159576688494, 71.27116094316754, 70.1882633481707, 69.12312534877232, 69.42633083888462, 67.41327789851597, 65.46550328390938, 62.88823577335903, 60.97606372833252, 64.3640262058803, 64.71459061758858, 61.95754541669573, 62.59488977704729, 58.44621072496687, 52.36585603441511, 49.20793798991612, 48.4152249608721, 47.969911439078196, 43.69642884390694, 45.92986127308437, 46.02069854736328, 46.77018335887364, 47.406339577266145, 46.85100827898298, 48.826829297201975, 45.9269187109811, 44.974091393607004, 43.104178292410715, 38.380202293395996, 40.27858911241804, 39.584036758967805, 40.38103682654244, 40.45094265256609, 41.82725919995989, 44.00558546611241, 53.15045356750488, 59.80842590332031, 57.611054624829976, 58.2374382019043, 58.47075176239014, 58.78684616088867, 54.88441474097115, 54.945850712912424, 52.00874294553484, 50.17301150730678, 51.737863949366975, 57.99826731000628, 58.508807046072825, 53.68657309668404, 44.705387183598106, 32.18913153239659, 51.05258049283709, 44.19968686785017, 39.43004035949707, 38.37246894836426, 37.933339323316304, 42.57496527263096, 51.59398760114397, 53.89701666150774, 51.984882831573486, 56.29631648744856, 56.2310277393886, 54.61565147127424, 51.655319350106375, 45.89714568001883, 49.447310379573274, 53.47707101276943, 49.93561935424805, 48.928721155439106, 46.75846174785069, 47.270783696855815, 47.38628012793404, 49.61506768635341, 51.2220470564706, 52.39662265777588, 48.19861486979893, 43.33584860392979, 41.654995986393516, 40.1545672416687, 41.27314731052944, 45.07499313354492, 44.47611747469221, 41.85060862132481, 44.056039810180664, 46.43020452771868, 46.274036816188264, 44.90426547186715, 42.670548166547505, 42.82525328227452, 42.7660858971732, 45.26619366237095, 46.34835474831717, 43.275510447365896, 45.26342133113316, 45.620308603559224, 46.39326095581055, 48.66596460342407, 53.93887608391898, 54.79447725840977, 60.05946431841169, 59.34373038155692, 62.20627702985491, 60.71051747458321, 64.39620331355503, 61.678068024771555, 63.3905279976981, 61.310973848615376, 62.299646922520225, 56.93869481767927, 63.761332511901855, 62.67070852007185, 67.97428934914726, 63.807447705950054, 71.13758182525635, 62.46987778799874, 71.50841413225446, 62.52834687914167, 80.26959228515625, 13.411703876086644, 1.0520453133753367, 0.42244344470756395, 0.1308143184121166, 1.1781442612409592, 57.6177978515625, 65.01134817940849, 62.49100725991385, 55.713664872305735, 42.72216633387974, 28.93385532924107, 24.358961616243633, 45.73737185341971, 62.79116249084473, 54.1068765776498, 2.3360749099935805, 0.29562457118715557, 0.10390904106731925, 0.07550424882876021, 0.14781035855412483, 0.08637656471026794, 0.03424886168379869, 0.11325153868113245, 0.11999962372439248, 0.11442232371440955, 0.15467884285109385, 0.1700441733534847, 0.10893161155815635, 0.19208790335272038, 0.20259843793298515, 0.15598013730985777, 0.27432120431746754, 5.030558747904641, 56.29295703342983, 64.61582197461809, 61.643750871930806, 42.22587735312325, 49.98852988651821, 62.967097827366416, 59.55006408691406, 87.00600978306362, 15.17470417703901, 0.48596998304128647, 0.7133447879127094, 2.1723173771585738, 9.842100722449166, 59.992511476789204, 79.21717643737793, 78.59165096282959, 74.42098086220878, 71.95400905609131, 77.75485161372593, 75.1113886151995, 68.45634841918945, 63.3837674004691, 64.30025563921247, 68.86656311580113, 73.36712673732212, 72.51394353594098, 75.63073866707938, 73.41300569261823, 71.54858861650739, 73.6020175388881, 68.35129860469273, 66.6857806614467, 68.75296006883893, 64.99131652287075, 67.72313281467983, 67.57400362832206, 61.89913191114153, 65.72706821986607, 60.54832567487444, 55.01620122364589, 51.46027299336025, 49.723226819719585, 49.059840611049104, 46.37351764951433, 49.63914319447109, 49.755094732557026, 50.7341445514134, 50.09474005017962, 48.386278765542166, 50.51710367202759, 49.07411568505423, 45.91596835000174, 46.22544806344168, 41.32862172807966, 42.197900431496755, 41.18059383119856, 43.92443050657, 42.87404005868094, 44.359002113342285, 46.643653188432964, 56.00189004625593, 62.80223791939871, 58.995438030787874, 58.97328717367989, 62.13721193586077, 60.93606294904436, 57.416345255715505, 57.023146697453086, 54.93909706388201, 52.111871583121165, 51.931826387132915, 59.12165205819266, 61.0100473676409, 55.993781498500276, 49.755171162741526, 36.66507421221052, 54.291914054325645, 43.84589154379708, 39.27958754130772, 38.33271483012608, 42.73126152583531, 47.43548379625593, 55.00342001233782, 55.932967390332905, 54.86607149669102, 58.342557498386924, 58.63445132119315, 56.45509672164917, 54.02328280040196, 49.455227851867676, 53.26179150172642, 56.30570697784424, 52.91988454546247, 52.08871671131679, 49.36591223308018, 49.81651333400181, 49.61054788316999, 52.21887036732265, 53.63854019982474, 54.987216813223704, 51.66428600038801, 44.340606757572715, 43.406331130436485, 42.859778881073, 43.93719434738159, 49.187965393066406, 44.45471007483346, 43.205621991838726, 45.09907906396048, 48.76059212003435, 48.62318107060024, 48.393174852643696, 46.38174084254673, 46.42536858149937, 45.06308739525931, 47.20122875486101, 48.760560853140696, 46.85505560466221, 48.33941316604614, 48.231754302978516, 48.10408462796892, 51.90292535509382, 55.84614617483956, 57.90346261433193, 64.11817114693778, 60.89487402779715, 66.60736329214913, 62.98281465257917, 66.92760576520647, 62.86981609889439, 64.80523681640625, 65.52434062957764, 67.0795350755964, 57.811548369271414, 65.54847867148263, 65.12582669939313, 71.43053872244698, 66.9476443699428, 77.37782846178327, 66.39723587036133, 76.51947580065045, 64.0527399608067, 86.28911549704415, 11.606350830623082, 1.8798264435359409, 0.8758054503372737, 0.16258617783231394, 1.868075736931392, 68.92717920030866, 69.28924288068498, 71.24195766448975, 60.44363021850586, 66.72477395193917, 38.79566635404314, 25.770310980933054, 56.90773711885725, 70.28880378178188, 61.676066943577354, 3.8976519278117587, 0.540744206735066, 0.3211183532008103, 0.2844156069414956, 0.2521743912781988, 0.20500593446195126, 0.10533060585813862, 0.19062762813908712], [0.17052267624863557, 0.04612694627472332, 0.05295437241771391, 0.02247951232961246, 0.02076328861793237, 0.04676782599251185, 0.06119932606816292, 0.1415107444460903, 0.10896397767854588, 1.2078118750027247, 23.810012238366262, 37.50426721572876, 39.65856313705444, 23.40073207446507, 31.905269827161515, 46.026250158037456, 51.79185840061733, 64.19692897796631, 2.6158842955316817, 0.12427321369094507, 0.2951396900628294, 0.3236009499856404, 27.119091817310878, 64.74706649780273, 63.49932983943394, 72.84808935437883, 64.21787779671806, 70.86053630283901, 70.11203466142926, 79.62253434317452, 71.23131997244698, 58.84104905809675, 70.40681893484933, 68.34949207305908, 71.11059502192906, 68.3682313646589, 66.21818774087089, 67.21749155861991, 63.671791076660156, 61.07101086207798, 59.33492006574358, 59.82594926016671, 58.92287104470389, 58.58582782745361, 60.88538973672049, 60.94966057368687, 63.73198332105364, 56.97678484235491, 52.29031521933419, 47.22987617765154, 44.87096275602068, 45.468570368630544, 46.47958884920393, 42.37532268251692, 41.14507116590227, 42.634566920144216, 43.82080854688372, 45.9392100742885, 45.649334703172954, 46.45373460224697, 43.348296301705496, 42.481188910348074, 43.25466237749372, 37.195871421269004, 35.96497024808611, 36.83280372619629, 39.19973884310041, 39.71190445763724, 37.67181955065046, 40.04654707227434, 44.16450119018555, 53.16712577002389, 57.42604841504778, 55.59177262442452, 55.717799050467356, 56.69315242767334, 53.65470518384661, 49.60576057434082, 47.16610908508301, 45.50910268511091, 51.126943588256836, 56.488295214516775, 55.162561552865164, 54.6280574798584, 37.95594528743199, 27.91873914854867, 53.39255312510899, 54.15171330315726, 42.51059716088431, 36.54463413783482, 36.73248563494001, 37.07478516442435, 51.8578211239406, 51.208560603005544, 47.817245619637625, 50.0338842528207, 52.933416162218364, 52.31520366668701, 53.90034137453352, 43.85490683146885, 43.89152036394392, 47.28761223384312, 47.78993572507586, 46.05203839710781, 44.4964930670602, 43.3808069229126, 45.34638629640852, 46.499762943812776, 47.600020612989155, 45.917472634996685, 44.44486795152937, 38.24714081627982, 39.565384319850374, 37.756177629743306, 40.47368063245501, 44.49554116385323, 39.368600913456504, 42.389059271131245, 41.526120798928396, 44.702274390629356, 45.66937330790928, 42.75700112751552, 40.45017140252249, 39.100386551448274, 39.131646496909006, 41.62292310169765, 44.95785345349993, 42.693640504564556, 42.673011302948, 42.38876049859183, 44.78860228402274, 46.410770416259766, 52.521568638937815, 54.00358813149588, 59.24260629926409, 59.41347639901297, 59.13525663103376, 60.12221349988665, 60.15830939156668, 57.93329470498221, 61.23287609645298, 60.05578177315848, 62.48742198944092, 60.11230536869594, 62.62660830361502, 63.20080048697335, 61.72804641723633, 61.207751410348074, 65.31319182259696, 64.06202275412423, 60.051404408046174, 64.8571468080793, 68.45841898236955, 59.159637859889436, 0.7898119932838849, 0.44784622160451754, 0.3171476205544812, 0.2612644263676235, 28.314270564488, 63.29660224914551, 56.32739577974592, 48.54179334640503, 38.01375429970877, 23.33903901917594, 41.57226031167166, 38.76514291763306, 48.39806291035244, 42.87607588086809, 3.0247558185032437, 0.14925985863166197, 0.08097227755934, 0.10677336808294058, 0.049251250590064695, 0.10913289897143841, 0.07433538404958588, 0.06478023356092827, 0.11981971694954804, 0.07070454316479818, 0.05801454053393432, 0.03983119303094489, 0.03749816911295056, 0.05150291815932308, 0.0585821961451854, 0.15752353306327546, 0.03329650725104979, 2.8797173840659003, 37.13987936292376, 49.475721563611714, 50.04112427575247, 30.822358335767472, 38.367699010031565, 55.16439240319388, 60.545226778302876, 70.47417477199009, 2.7495326782975877, 0.23038790747523308, 0.2117415073194674, 0.26663030843649593, 30.514480182102748, 71.00731699807304, 69.41369901384626, 74.80645302363804, 66.66178158351353, 73.96083641052246, 72.25467150551933, 78.38205855233329, 71.08863176618303, 63.52262020111084, 73.16774817875454, 69.3808479309082, 70.0518354688372, 67.74533230917794, 67.06786905016217, 68.51998697008405, 65.15785094669887, 64.43744087219238, 62.69561781202044, 61.66697175162179, 60.327338218688965, 58.243986879076274, 63.66962323869978, 64.36711120605469, 63.323679379054475, 59.40900175912039, 53.73542240687779, 50.455024991716655, 47.1818710735866, 47.55254009791783, 49.18376520701817, 44.26522922515869, 44.736754826136995, 45.55324111665998, 47.47250379834856, 47.62462765829903, 47.880755628858296, 47.55808128629412, 44.098125049046104, 44.47764607838222, 45.06078059332711, 40.01848329816546, 40.052689279828755, 38.8735591343471, 41.79883759362357, 41.714774812970845, 40.98584624699184, 42.583747795649934, 47.016048840114046, 53.76196799959455, 58.278495107378276, 57.50372232709612, 58.51284394945417, 57.35486759458269, 56.2106590952192, 52.41662652151925, 51.091594627925325, 47.802265303475515, 53.36722346714565, 59.8799159186227, 57.47873660496303, 56.253626755305696, 43.596187182835166, 31.748268331800187, 56.094290665217805, 57.58807693208967, 41.61072901317051, 38.346277713775635, 37.335109846932546, 40.527890477861675, 52.897452286311555, 54.04717765535627, 49.773708956582205, 54.45854227883475, 55.39386360985892, 55.50452756881714, 56.199680941445486, 46.6528491292681, 45.75845616204398, 50.27946833201817, 51.79475927352905, 48.27701139450073, 47.21629939760481, 46.485029288700645, 49.16447005953108, 49.668568815503804, 48.917082922799246, 48.70574998855591, 47.46306119646345, 40.843627044132774, 41.30074208123343, 40.17473438807896, 41.7679945400783, 45.64772619519915, 39.54948336737496, 42.17589201245989, 41.02680587768555, 45.60889966147286, 47.38330282483782, 43.43367229189192, 44.31034735270909, 42.57707405090332, 42.76714202335903, 44.22920628956386, 46.92325564793178, 46.005898884364534, 45.58768681117466, 44.92696523666382, 46.49642433438982, 48.86168840953282, 54.78623669488089, 57.6011187008449, 61.84263610839844, 61.67504555838448, 61.462375095912385, 61.541480336870464, 61.10492501940046, 60.37724018096924, 61.69497994014195, 62.0358863558088, 62.75253050667899, 61.332763399396626, 65.82997104099819, 64.91374683380127, 64.17267976488385, 63.58384772709438, 67.40771933964321, 67.38842419215611, 63.40558474404471, 68.00028950827462, 69.64633859906877, 66.60719653538295, 1.9819287019116538, 0.7823612987995148, 0.5837436765432358, 0.3887279081557478, 30.1840238571167, 70.34972558702741, 62.290371077401296, 55.900963987622944, 44.959548813956125, 16.938598190035137, 40.974485942295615, 49.01049450465611, 55.191375732421875, 51.762328556605745, 3.9059750011989047, 0.23614682416830743, 0.09216944208102566, 0.10063503496348858, 0.10514930130115577, 0.11184551912759032, 0.08664855547249317, 0.054709786615733585, 0.22774772771767207, 0.1606163363903761, 0.07021151283489806, 0.15773762443235942, 0.14412417635321617, 0.23873016983270645, 0.12309489691896097, 0.2903668204588549, 0.234389744166817, 4.840831671442304, 54.769804205213276, 59.47595460074288, 57.77760989325387, 35.18683106558663, 46.12369169507708, 63.701244490487234, 67.6835697719029, 78.1517744064331, 4.476716101169586, 0.34874306086983, 0.8644490540027618, 1.0976536146232059, 32.07533393587385, 71.59150069100517, 74.21511963435582, 78.06115600040981, 70.22541536603654, 76.33261094774518, 78.05834197998047, 77.3185533796038, 70.70661980765206, 68.05934919629777, 74.36784103938511, 73.70826939174107, 74.60977731432233, 74.09384577614921, 71.54241861615861, 71.18486431666783, 69.46050207955497, 67.05845424107143, 66.01306302206856, 64.70995616912842, 62.688009534563335, 61.59726047515869, 66.51545252118791, 65.73139694758824, 67.5514497756958, 62.09250027792794, 56.960831778390066, 52.057505403246196, 48.51083564758301, 49.20586395263672, 52.058224541800364, 46.73568902696882, 49.169184412275044, 48.668504170009065, 50.237035683223176, 49.083474908556255, 47.40722894668579, 51.01655060904366, 45.456918239593506, 46.66503626959664, 47.098044531685964, 43.039049352918354, 42.51254265648978, 42.19383226122175, 45.53880623408726, 45.670078550066265, 42.65915312085833, 43.51435477393014, 49.55576481137957, 57.52059950147356, 60.45392744881766, 59.71112333025251, 61.108211517333984, 59.94829314095633, 59.14365700313023, 54.16800682885306, 53.88965851919991, 49.832473346165244, 56.83069896697998, 63.17955984388079, 62.12485803876604, 58.6315678187779, 48.68837949207851, 35.725966112954275, 60.228618213108604, 59.354889188494, 41.84856237683977, 38.15708521434239, 39.79611315046038, 44.765833037240164, 57.98376294544765, 57.986337253025596, 51.12637036187308, 57.402935232434956, 57.316298144204275, 58.36222090039934, 59.85765389033726, 50.38091203144619, 47.979232447487966, 53.40427821023123, 52.4670079095023, 50.50744220188686, 49.889122009277344, 47.19533668245588, 51.563266141074045, 52.415639877319336, 52.21711942127773, 52.06047575814383, 50.4385403905596, 42.24381065368652, 43.84305667877197, 43.78860017231533, 44.44878673553467, 46.78680344990322, 40.17390407834734, 43.6093088558742, 41.842097078050884, 47.36680085318429, 52.22947679247175, 47.523357663835796, 46.5648467200143, 45.46867111751011, 43.46731546946934, 46.98279128755842, 50.330384731292725, 48.635465485709055, 49.2225569997515, 47.84703949519566, 48.60051604679653, 51.71641138621739, 57.72894818442208, 61.369832038879395, 65.77263450622559, 64.65276554652623, 64.15669890812465, 65.95915194920131, 64.60852636609758, 62.26795618874686, 64.24630287715367, 64.71029663085938, 65.57436071123395, 63.95602103642055, 68.67177036830357, 67.8371249607631, 68.73540197099958, 66.56130368368966, 70.81314958844865, 70.78056948525565, 65.58503314426967, 71.56845351627895, 71.3213060923985, 66.5167726789202, 1.3180266980613982, 1.1325717866420746, 1.203608757683209, 0.5276074973600251, 36.568598474775044, 76.19598851885114, 69.80277729034424, 63.6636130469186, 54.55022375924246, 33.71812432152884, 54.56514501571655, 58.06274659293038, 62.580340249197825, 64.74142456054688, 5.633857803685324, 0.372073944658041, 0.21926591784826346, 0.2582002436476094, 0.2036489729902574, 0.21814880493496144, 0.1387060878000089, 0.12062257315431323], [0.12187362888029643, 0.04984249886391418, 0.06140913588127919, 0.06347617067928825, 0.031098973205579177, 0.027039276136617576, 0.09883292059281043, 0.029919156871203865, 0.08632344220365797, 1.4662094094923563, 27.568056617464336, 37.20574828556606, 32.37844215120588, 32.3035683631897, 50.948715346200125, 38.26125955581665, 61.42982973371233, 53.02591405596052, 0.1977717333606311, 0.027325740050790564, 0.2742863547589098, 1.3285356312990189, 59.45913301195417, 80.57211685180664, 72.49189690181187, 64.16537025996617, 66.65260996137346, 68.72488239833287, 80.66796725136894, 71.71723529270717, 57.8737347466605, 70.1604288646153, 66.21784033094133, 64.68062087467739, 62.40971333639962, 62.65257372174944, 62.38333797454834, 66.58857536315918, 61.52126802716936, 61.12584604535784, 60.69357081821987, 56.850261620112825, 52.97741910389492, 51.085876260484966, 54.66039439610073, 54.22127866744995, 53.608009815216064, 49.374885831560405, 44.77758591515677, 47.01344673974173, 46.471567153930664, 43.67916257040841, 43.66280651092529, 41.37358352116176, 42.31876087188721, 41.94333927971976, 43.62501525878906, 43.74664347512381, 47.56349393299648, 45.56221124104091, 43.705683844430105, 40.67533820016043, 42.38678026199341, 42.18935762132917, 37.16957596370152, 38.75999777657645, 38.04152624947684, 38.93955659866333, 39.245214802878245, 38.86921303612845, 41.06251267024449, 43.28480018888201, 50.903103896549766, 53.55221230643136, 53.477710247039795, 52.9747440474374, 53.64086437225342, 50.34238427025931, 45.76314272199358, 41.38672603879656, 48.00990874426705, 56.465168135506765, 55.8106860433306, 53.135799816676546, 37.807250363486155, 28.641471658434185, 28.496382849557058, 37.6761656488691, 44.07302468163626, 42.467306409563335, 34.313307012830464, 35.69529676437378, 41.068189348493306, 49.91217613220215, 43.37606477737427, 49.95243052073887, 49.392148630959646, 52.70471273149763, 52.03824152265276, 45.570847851889475, 40.443931920187815, 45.076872621263774, 45.70177970613752, 47.26014947891235, 43.41291454860142, 46.34907041277204, 46.406122071402415, 47.12185253415789, 44.566127913338796, 43.67260694503784, 40.58750949587141, 39.431013107299805, 36.70039190564837, 39.55818598611014, 44.23503930228097, 40.97357225418091, 40.47584499631609, 40.416114807128906, 40.75446775981358, 42.304127965654644, 42.9213399205889, 39.66284670148577, 39.284694467272075, 38.50275462014334, 36.953872612544465, 42.516683782849995, 40.90397909709385, 43.328288963862825, 43.03675992148263, 41.4843829699925, 43.58799525669643, 45.4912770816258, 46.56078897203718, 51.82166617257254, 56.707014083862305, 59.33716433388846, 57.56343861988613, 59.59155872889927, 57.16452169418335, 62.57980523790632, 61.12667982918875, 60.39354065486363, 61.6309175491333, 59.89781447819301, 60.689665930611746, 62.75369085584368, 61.777788570949006, 59.17705004555838, 58.36720970698765, 59.84479972294399, 57.78808430262974, 65.27498367854527, 64.59817355019706, 74.40106732504708, 29.45053379876273, 1.1262059339455195, 0.491737856396607, 0.3238236451787608, 6.176965049334934, 59.76035131726946, 56.962461130959646, 53.66389070238386, 40.12389094488961, 44.67516599382673, 27.689512865883962, 31.45879943030221, 53.64796543121338, 54.275047302246094, 4.325612323624747, 0.24568580516747066, 0.07256824815911905, 0.059926713284637244, 0.12711413124842302, 0.03689259357218232, 0.0648702344458018, 0.0995537486991712, 0.14541179154600414, 0.07175326653357063, 0.04545795824378729, 0.058977198520941396, 0.03529404988512397, 0.03950119430997542, 0.05103457971875157, 0.0637329826131463, 0.13298728609723703, 2.6177791995661597, 45.97835622514997, 49.23218720299857, 42.27582795279366, 33.98617192677089, 54.68451854160854, 47.80676426206316, 68.72371510096959, 57.65110404150826, 0.1707506775856018, 0.17250634623425348, 0.03843792315040316, 2.1640153654984067, 64.8574525288173, 82.86041573115757, 74.227584702628, 67.96616690499442, 71.36458642142159, 69.75266688210624, 81.44402544839042, 74.35011618477958, 61.643167223249165, 71.3019414629255, 70.22588089534214, 67.40010411398751, 65.01074368613106, 64.52482836587089, 64.04453413827079, 68.38512243543352, 65.01221670423234, 62.52783271244594, 62.09616892678397, 60.29017925262451, 56.29053211212158, 54.613518374306814, 56.50742360523769, 57.561951705387656, 55.165059430258616, 51.67606667109898, 46.471643584115164, 48.35260779517037, 48.24566459655762, 46.646748610905235, 46.450642653873985, 43.607943534851074, 44.19007750919887, 45.0548746245248, 45.2405617577689, 46.6517721584865, 48.733066831316265, 46.30418157577515, 46.888716152736116, 41.60118218830654, 42.95083849770682, 44.51886279242379, 39.52634586606707, 39.97713804244995, 40.2573276247297, 41.87123782294137, 42.12582329341343, 41.593282086508616, 42.394537925720215, 45.61205414363316, 50.9628757749285, 54.88810076032366, 56.00358540671212, 53.33110325677054, 54.11044795172555, 51.528219427381245, 47.42100722449166, 45.26741654532296, 50.32884917940412, 57.42456497464861, 57.08392606462751, 55.13650928224836, 41.464848109654014, 33.17770038332258, 31.89651162283761, 41.63231011799404, 45.35578720910208, 45.75969294139317, 37.17715992246355, 38.870557512555806, 42.64955071040562, 50.364246777125764, 45.99450036457607, 50.94814559391567, 52.06516579219273, 55.162742206028526, 53.39496415002005, 46.97881344386509, 42.940520422799246, 46.07772936139788, 47.22430372238159, 48.99229717254639, 46.165075165884836, 48.28208705357143, 48.145349979400635, 50.102671418871196, 47.353561060769216, 46.33140809195382, 43.388463837759836, 42.61638695853097, 38.7530391556876, 43.42533792768206, 45.67391048158918, 40.52389873777117, 40.850891385759624, 39.7110915184021, 40.04529292242867, 42.765853132520405, 42.941694668361116, 42.01866470064436, 41.81114632742745, 42.30086578641619, 39.271899359566824, 44.529319831303184, 43.180059569222585, 44.482304845537456, 44.54581832885742, 43.99942936216082, 44.50443833214896, 48.48147603443691, 48.56621279035296, 53.503564493996755, 58.22030741827828, 61.017169271196636, 59.712693623134065, 61.244222504752024, 61.47743879045759, 64.19878414699009, 63.45623016357422, 63.70558711460659, 63.04534149169922, 63.1562625340053, 64.1106184550694, 65.15555109296525, 63.64442212241036, 61.45806721278599, 60.746175629752024, 61.56587546212332, 61.08863844190325, 67.42875153677804, 67.70084994179862, 78.28818144117082, 37.258815152304514, 0.7360160542385918, 0.2839131381894861, 0.40633415484002655, 5.956694994653974, 67.28695964813232, 62.719873973301475, 61.09263365609305, 48.1369218145098, 37.445395129067556, 38.160823345184326, 43.59151104518345, 57.07284368787493, 65.82207093920026, 6.777358889579773, 0.37132595479488373, 0.08813203658376421, 0.10838524159044027, 0.16856291783707483, 0.020754009651552354, 0.07113972838435854, 0.1322182887899024, 0.2050728244440896, 0.1427905157740627, 0.17261193985385553, 0.18108203820884228, 0.09493778353290898, 0.08605278815541949, 0.19373039236026152, 0.1494702859116452, 0.19722058650638374, 5.411871109689985, 61.87873894827706, 58.75539166586739, 45.23360661097935, 43.73460572106497, 67.88144057137626, 54.00654458999634, 75.7323282786778, 64.11589908599854, 0.3867079365466322, 0.2637595624795982, 1.6958435731274741, 2.347568316119058, 67.44642775399345, 86.45091124943325, 77.80278723580497, 70.35215050833565, 73.27831486293248, 76.12465136391776, 82.04902594430106, 72.05300004141671, 66.62236445290702, 74.90813991001674, 73.49373681204659, 69.87155750819615, 66.83906487056187, 67.60107381003243, 67.48784596579415, 72.62583037785122, 66.1437655857631, 66.09902613503593, 65.35254641941616, 62.80121653420584, 58.841882841927664, 56.36779955455235, 59.012898853846956, 59.605170249938965, 58.28281341280256, 54.10967322758266, 49.35293994631086, 50.575472014290945, 50.25176933833531, 48.54570518221174, 48.47470154081072, 45.1280391556876, 46.542664596012656, 46.45334202902657, 48.54646948405674, 47.07930176598685, 50.65627956390381, 46.95542928150722, 47.54536608287266, 41.78234257016863, 43.98718316214425, 48.55899708611624, 43.3127875328064, 42.20336518968855, 44.05383375712803, 43.971292631966726, 45.23691395350865, 44.48187058312552, 45.58110686710903, 46.54213653291975, 54.99975831168038, 57.26100090571812, 59.2381386075701, 56.36489520754133, 57.09912177494594, 54.192162241254536, 51.35461868558611, 45.272672857557026, 52.70201335634504, 60.747711181640625, 59.20054885319301, 58.08413314819336, 45.22282648086548, 37.491656235286165, 37.92926073074341, 43.398615155901226, 48.78519916534424, 44.248226983206614, 37.806427001953125, 41.46681097575596, 46.48338256563459, 53.68005221230643, 48.97159848894392, 55.164534841264995, 54.589547089168, 57.015677383967805, 55.86426707676479, 50.51723568780081, 45.63121032714844, 50.67464712687901, 50.925504888807026, 51.57811096736363, 49.60353715079171, 52.112608092171804, 51.77139595576695, 52.486779008592876, 49.79339667728969, 49.181225640433176, 45.6875775882176, 43.984052998679026, 41.74822344098772, 46.28151307787214, 48.16263362339565, 42.040784290858674, 41.90007979529244, 41.06381893157959, 41.5401839528765, 44.329527854919434, 45.917840889522004, 42.87186874662127, 44.04746225902012, 43.70277254922049, 42.81041540418352, 47.49199002129691, 45.46400192805699, 48.74228014264788, 47.316985743386404, 45.652450970241, 48.48031221117292, 52.12830754688808, 51.124018396650044, 57.526262283325195, 62.011136872427805, 64.65961647033691, 62.73414557320731, 63.55665247780936, 62.61913204193115, 68.25229372297014, 66.50590569632394, 65.37488487788609, 66.29519462585449, 66.5878666469029, 68.19285188402448, 69.19856888907296, 65.40310846056256, 65.87746892656598, 65.12426335471017, 66.67036260877336, 62.96030943734305, 71.20854377746582, 69.90237276894706, 82.20262977055141, 33.94997876031058, 1.5014964874301637, 1.4074557679040092, 0.4339236601122788, 7.8329978329794745, 75.73683071136475, 67.45986557006836, 70.09212112426758, 55.31584576198033, 67.41446604047502, 39.668252399989534, 50.40398005076817, 64.16737134116036, 75.38666234697614, 9.263015270233154, 0.5140819059950965, 0.23028710431286267, 0.20189520423965795, 0.16922412307134696, 0.14159193794642175, 0.0860737141753946, 0.22405020041125162], [0.06032869778573513, 0.061797251126595905, 0.018853295660976852, 0.18940908781119756, 0.06487934038575206, 0.13445620584700788, 0.03960564799074616, 0.08250586169638804, 0.0083796750820641, 3.6591788956097195, 33.16457176208496, 40.82624612535749, 38.82664142336164, 30.05918209893363, 41.05006149836949, 40.11301006589617, 69.22787639072963, 38.70965460368565, 0.12317861456956182, 0.1342673831220184, 1.0945894590445926, 14.313375081334796, 79.12557138715471, 71.88568047114781, 71.58205808912004, 66.04166180746896, 69.02648285457066, 80.45183658599854, 71.02301297869, 57.742038590567454, 72.11474868229458, 68.15691580091203, 64.64328820364815, 62.27819783346993, 64.20660781860352, 58.43756021772112, 59.51071643829346, 59.199735913957866, 56.56735181808472, 53.09277309690203, 54.446945735386436, 51.85694912501744, 51.59064899172102, 50.63443095343453, 47.294209548405235, 45.495102064950125, 46.329254150390625, 46.80442755562918, 47.431981904166086, 45.274590560368125, 43.69144351141793, 45.97560126440865, 44.02471733093262, 42.541808468954905, 39.32269069126674, 43.308232988630024, 42.09321539742606, 45.034467765263145, 48.198250089372905, 44.580962317330496, 44.93011277062552, 42.05309649876186, 39.211762700762065, 39.64997516359602, 36.75079413822719, 36.217471258980886, 37.650255816323416, 37.46562133516584, 37.19361325672695, 37.75214072636196, 38.71356643949236, 42.36479616165161, 43.35804115022932, 45.08907018389021, 50.35361950738089, 50.91651044573103, 46.86206633704049, 46.912385191236226, 45.28271995271955, 42.06821925299508, 44.65897669110979, 52.164316586085725, 52.4554009437561, 51.593629768916536, 36.547750404902864, 21.24763819149562, 17.195617267063685, 34.41122797557286, 21.75653120449611, 45.93624666758946, 46.40458651951381, 31.955852712903702, 43.49137708118984, 49.30714436939785, 48.048783915383474, 45.86344691685268, 49.97778102329799, 50.395968777792795, 50.057779107775005, 43.39189624786377, 39.83227505002703, 42.332865715026855, 42.56952830723354, 42.22959116527012, 43.47588954653059, 44.886349541800364, 44.22430433545794, 43.20677191870553, 40.52775846208845, 39.472379207611084, 37.73824780327933, 37.00502177647182, 39.082157952444895, 41.826071058000835, 43.036690439496724, 40.65544898169381, 39.30045645577567, 39.82533032553536, 40.84587826047625, 41.17578567777361, 45.072123527526855, 40.877871240888325, 39.73656014033726, 38.734692437308176, 40.06105491093227, 43.15117938177926, 44.144511222839355, 41.80003268378121, 44.229129859379356, 41.829621587480815, 43.72530208315168, 43.08946200779506, 42.984683173043386, 43.52462421144758, 48.50047935758318, 53.48995297295706, 56.0395701272147, 57.665069920676096, 60.091419083731516, 58.16481910433088, 62.05059569222586, 58.3662508555821, 56.96714769090925, 57.62547561100551, 60.277978215898784, 55.380272933415, 55.129335267203196, 50.70235306876046, 52.67446027483259, 51.58869654791695, 55.81415319442749, 60.29149941035679, 68.88120991843087, 64.12057522365025, 68.56212084633964, 2.365678144352777, 0.8476216569542885, 0.09198004260127034, 0.12466255708464555, 37.72490726198469, 64.69674069540841, 50.76724576950073, 46.610485962459016, 28.23339353288923, 22.320780515670776, 39.31050355093819, 46.45071560995919, 47.1414464541844, 7.073661778654371, 0.2739134861954621, 0.046696539103452644, 0.04566173927326288, 0.06102389083909137, 0.05157321099457996, 0.050072644371539354, 0.19067732404385293, 0.08575616657201733, 0.06487672802593027, 0.010372592651817416, 0.1302318096693073, 0.03801582008600235, 0.017332045594230294, 0.03687880574060338, 0.03850122368229287, 0.04156854123409305, 6.07057466677257, 48.62417813709804, 50.80821929659162, 50.881606170109336, 31.398614134107316, 42.13116298403059, 49.595095089503694, 77.48071043831962, 41.131643772125244, 0.14063783628599985, 0.39307658480746405, 0.6153892470257623, 18.16928744316101, 85.9023301260812, 72.98182133265904, 75.25490365709577, 68.76474421364921, 73.69842379433769, 83.68015030452183, 75.33981759207589, 61.80528259277344, 74.67498615809849, 69.61343193054199, 67.45073563711983, 65.65277808053153, 65.27644974844796, 61.48153822762625, 60.82515580313546, 59.63112871987479, 59.6410368510655, 56.885026931762695, 55.64275503158569, 54.68579701014927, 53.602666650499614, 53.12468269893101, 48.889376980917795, 47.48843601771763, 48.90671968460083, 47.88352101189749, 47.82389851978847, 46.85265152794974, 45.7654321534293, 48.96787772859846, 45.98775713784354, 44.66541419710432, 41.62252705437796, 44.165769236428396, 43.93540171214512, 46.16907385417393, 48.6064532824925, 47.0894079208374, 44.84762028285435, 42.86652558190482, 41.57767295837402, 43.381737981523784, 39.163014139447895, 40.17300428662981, 40.16135563169207, 40.25997836249215, 40.08463709694998, 40.58893387658255, 41.67512839181082, 43.71831566946847, 45.148588453020366, 46.56015321186611, 51.807453632354736, 51.80600840704781, 49.377630370003835, 48.44909048080444, 45.39670862470354, 44.90619012287685, 47.121668406895225, 53.458338669368196, 56.31770304271153, 56.0952182497297, 41.00059379850115, 22.88458514213562, 18.507193974086217, 40.42024203709194, 23.267357928412302, 46.9634370803833, 47.89561087744576, 35.076181003025596, 45.05982869012015, 50.55542993545532, 48.83369411740984, 48.921807697841096, 50.45474706377302, 52.71962703977312, 51.08542462757656, 45.50521169389997, 41.72512068067278, 43.282548972538535, 45.025792939322336, 44.985694885253906, 45.432776723589214, 46.58918973377773, 45.634500299181255, 44.929098333631245, 41.74497863224575, 42.028496401650564, 40.28711455208914, 39.22955356325422, 42.85311903272356, 43.66703448976789, 41.72600310189383, 41.528212206704275, 39.01860972813198, 40.533876350947786, 40.1564884185791, 42.683642046792166, 46.99639238630022, 43.45505537305559, 41.79952893938337, 41.7953530720302, 42.659500530787874, 45.30691705431257, 47.405842781066895, 44.90200383322579, 47.33893162863595, 42.696187019348145, 45.12224783216204, 44.036994797842844, 46.50221218381609, 44.61771828787667, 51.0803177016122, 55.14437116895403, 58.774311610630576, 59.40858486720494, 62.90022141592843, 59.89324256352016, 63.990914889744346, 61.21815981183733, 60.756750788007466, 59.65107699802944, 62.091673442295615, 57.84565012795584, 56.20525687081473, 52.086402961185996, 57.09601593017578, 53.076726232256206, 59.30138805934361, 63.17156941550118, 71.99262714385986, 66.44087055751255, 78.1518577848162, 3.8772728613444736, 0.8312766168798719, 0.1597426954124655, 0.10796997815902744, 40.39562109538487, 72.15101133074079, 57.22852849960327, 55.26581873212542, 33.82903494153704, 26.108874116625103, 51.768477712358745, 53.859416484832764, 57.37205048969814, 9.504634533609662, 0.2314312229199069, 0.0508578484877944, 0.043103920096265416, 0.14315750822424889, 0.0589912509811776, 0.01843847836633878, 0.0955618457602603, 0.14063400934849465, 0.23132803131427082, 0.06715519433575017, 0.209819529737745, 0.11659402932439532, 0.1634819254811321, 0.14305888994463853, 0.30336787711296764, 0.22392256797424384, 9.447796532085963, 64.60482992444719, 61.807679721287315, 58.480979510716026, 49.79527963910784, 59.381410462515696, 55.2295560836792, 85.18039144788469, 46.940897124154226, 0.15439623301582678, 0.34579764891948017, 2.1343515515327454, 17.204008953911917, 87.02312319619315, 75.9174074445452, 78.76944146837506, 69.51601818629673, 74.87369074140275, 79.5769750050136, 75.89158099038261, 66.08964606693813, 76.3913996560233, 72.73741844722203, 70.56529344831193, 67.84401062556675, 67.70618615831647, 63.62710721152169, 65.02853107452393, 64.57399381910051, 63.190044675554546, 60.783348492213655, 59.43522426060268, 57.60636111668178, 57.16785682950701, 55.60629783357893, 51.59744085584368, 50.421607630593435, 51.71237448283604, 50.737389360155376, 50.971772943224224, 48.77417237418038, 47.605301243918284, 51.81699003492083, 48.52478068215506, 47.399822166987825, 42.9511650630406, 47.131899629320415, 46.06008093697684, 48.310783113752095, 51.44015448434012, 47.971238545009065, 46.381049496786936, 42.08654512677874, 42.51925114222935, 43.61590617043631, 42.19510725566319, 43.8165944644383, 42.904358523232595, 42.616873332432334, 42.98984221049717, 42.95735590798514, 45.05019153867449, 46.65055969783238, 48.01441465105329, 49.102700574057444, 55.880425112588064, 55.556607791355674, 50.809608936309814, 50.27772086007254, 48.35452549798148, 47.07724509920393, 50.16240160805838, 56.14457130432129, 59.821384293692454, 56.73947606767927, 44.94433920724051, 27.813185589654104, 22.817628826413834, 42.83178458895002, 23.44508590017046, 52.962299823760986, 48.66323743547712, 38.19636685507638, 50.14869976043701, 55.08326523644583, 51.13554893221174, 50.59398201533726, 53.57291793823242, 56.94982235772269, 56.42342683247158, 47.70108910969326, 44.38424144472395, 46.34477295194353, 49.36327191761562, 46.97878565107073, 47.37023326328823, 49.70413316999163, 49.642766680036274, 47.61920458929879, 44.98015022277832, 44.511202403477256, 42.345855372292654, 42.05766841343471, 45.164263589041575, 45.63714756284441, 43.89287873676845, 41.5373386655535, 39.13018390110561, 41.40034103393555, 41.55231550761631, 42.012710094451904, 48.76418086460659, 43.55654076167515, 44.30515704836164, 44.654665333884104, 46.17567811693464, 49.105170658656526, 48.75780936649868, 47.281185150146484, 50.59811619349888, 44.77234697341919, 48.93062496185303, 46.741317067827495, 49.06867871965681, 47.07657807213919, 53.4622609274728, 59.295871189662385, 60.63011986868722, 63.19859790802002, 66.96568189348493, 64.04591682979039, 69.17313153403146, 63.13065147399902, 61.6754207611084, 63.78724929264614, 67.40260546548026, 61.578569820949006, 59.94609751020159, 55.96853174482073, 60.11027649470738, 56.886493001665386, 63.341911452157156, 64.92840753282819, 74.28287846701485, 67.92210837772915, 79.41016265324184, 3.633581732000623, 1.112575305359704, 0.2678178532847336, 0.20507731634591306, 49.26439210346767, 78.42136451176235, 62.890855244227815, 62.228962898254395, 43.74372175761631, 30.668087482452393, 58.03258098874773, 60.585401262555806, 66.45992946624756, 13.855017185211182, 0.447994875056403, 0.11240744111793381, 0.1883921402373484, 0.22143231731440338, 0.3191816514091832, 0.16152086428233556, 0.2336197697690555], [0.02404675180358546, 0.020831873241279806, 0.037369345846985064, 0.03494194449324693, 0.05069012141653469, 0.111600486561656, 0.05008980112948588, 0.05643534188025764, 0.08672278041818313, 4.089244595595768, 28.368223326546804, 41.09588139397757, 30.6190436226981, 31.683948857443674, 39.64430890764509, 44.45547785077776, 75.1610334941319, 23.16213267190116, 0.37362711131572723, 0.5984345568077905, 0.21837686055472919, 44.34021071025303, 77.29793112618583, 68.83396216801235, 73.6815049307687, 71.39813232421875, 79.1746951511928, 62.130666732788086, 58.33653341020857, 71.6739480154855, 66.44859000614711, 63.37727778298514, 62.91475704738072, 57.64643137795584, 56.622506618499756, 53.03069789069039, 52.19289800098964, 51.44636269978115, 50.63419124058315, 48.886795725141255, 47.18920489719936, 46.59469965526036, 46.596447127205984, 43.72004577091762, 43.9798458644322, 45.460423605782644, 46.82380608149937, 46.945423875536235, 45.05239759172712, 46.34606531688145, 44.75775228227888, 46.311400754111155, 44.874985763004844, 43.25494377953665, 40.90837035860334, 41.62919732502529, 45.24441453388759, 42.33423798424857, 44.23749549048287, 43.96469184330532, 43.26680435453142, 42.649262360164094, 40.71830933434622, 40.91227177211216, 41.580229895455496, 37.74525853565761, 35.11750888824463, 36.74913699286324, 38.40145683288574, 36.36250100816999, 37.182068824768066, 37.9708491734096, 42.3388272694179, 39.87196316037859, 41.92189366476876, 46.93539762496948, 44.947379044124055, 45.78819097791399, 40.797890526907786, 45.67004728317261, 43.8049874986921, 49.26295035226004, 52.84874194008963, 57.698435170309885, 45.19265045438494, 34.677125113351, 18.369845458439418, 31.882118429456437, 24.435652358191355, 21.081998348236084, 50.02556378500802, 34.08896705082485, 29.090780394417898, 40.585567474365234, 51.77789946964809, 43.98851721627371, 47.67195531300136, 43.22345106942313, 43.61739655903408, 41.17887762614659, 40.33768701553345, 40.005747250148225, 43.13185296739851, 42.74927125658308, 43.36179665156773, 40.61337069102696, 41.09372745241438, 36.59320204598563, 37.622615882328574, 35.94828067507063, 38.71924311774117, 35.86731331689017, 41.86155203410557, 40.87797893796648, 38.60477154595511, 40.03581210545131, 38.37003013065883, 38.67509773799351, 40.62110751015799, 40.47599785668509, 42.69139276232038, 42.18096072333199, 41.098209040505544, 40.31588704245431, 40.77903311593192, 40.61654601778303, 42.62040649141584, 42.53125068119594, 43.5287583896092, 41.47067070007324, 43.6054630279541, 42.76551267078945, 44.21341303416661, 42.748281138283865, 41.9657541683742, 43.907636710575645, 45.55212245668684, 48.03983810969761, 51.95740965434483, 52.09304543903896, 51.77777787617275, 50.28933824811663, 52.41376386369978, 50.357044969286235, 50.160348415374756, 48.50513117653983, 48.82639850888933, 49.58702475684029, 50.71943868909563, 50.37397078105381, 57.55193935121809, 63.7928078515189, 67.84231526511056, 66.48046834128243, 73.94632857186454, 26.171937704086304, 1.0816601642540522, 0.24588437165532792, 0.4713904368025916, 13.66587506021772, 66.79283155713762, 53.470223563058035, 51.64407021658761, 32.41161632537842, 36.980112484523225, 31.53627184459141, 36.63637467793056, 49.321565355573384, 11.880696977887835, 0.19020959628479822, 0.05205813961635743, 0.14065842303846562, 0.10021489286529166, 0.08416088324572359, 0.04631728891815458, 0.13899595795997552, 0.039345898000257354, 0.08642618597618171, 0.034484360832720995, 0.021457558863663247, 0.06447124228413616, 0.12756071585629666, 0.03850921003946236, 0.045305277686566114, 0.11939123565597193, 5.6272183656692505, 46.72852890832083, 52.05362483433315, 39.22197307859148, 28.800401278904506, 45.08714900697981, 51.91251386914934, 82.07736764635358, 24.687413385936193, 0.34730961493083407, 0.20782971222485813, 0.41237933188676834, 50.002193519047324, 81.02916240692139, 72.51784842354911, 74.21583529881069, 73.75652463095528, 83.4643531526838, 67.89045238494873, 59.397196769714355, 73.21202904837472, 69.19022410256522, 67.25993115561349, 65.13421317509243, 60.38848236628941, 58.88644858769008, 55.61037642615182, 54.364995207105366, 53.15857253755842, 53.71313258579799, 51.68025296075003, 50.51441124507359, 48.9567779813494, 48.865871225084575, 46.24463898794991, 46.685467447553364, 47.570890290396555, 47.97417068481445, 48.2435245513916, 47.34515721457345, 49.013930388859336, 46.75917741230556, 47.22620405469622, 46.94331509726388, 45.48854991367885, 42.90953145708357, 42.94485262462071, 46.21314280373709, 43.8289726802281, 44.79099941253662, 44.10256494794573, 43.310744762420654, 42.284697328295024, 41.120061125074116, 41.52446712766375, 46.232576915196006, 39.644218581063406, 37.812746388571604, 39.16893400464739, 39.28399964741298, 39.29078803743635, 37.895933696201865, 41.82743290492466, 45.05876561573574, 42.89964764458792, 43.95784439359392, 47.54403550284249, 44.908927713121685, 48.424987179892405, 42.974246978759766, 46.51702574321202, 44.682871546064106, 51.580296175820486, 55.01977607182094, 60.385675294058665, 47.86707462583269, 39.63462659290859, 20.825800895690918, 36.89803341456822, 26.852192401885986, 21.9647113936288, 50.15485239028931, 37.38096795763288, 32.332198415483745, 43.64280612128121, 53.43655606678554, 47.26524598257882, 51.04801900046212, 45.12616661616734, 45.02978120531355, 43.031844070979524, 43.5796400478908, 41.709716524396626, 44.999473163059776, 43.85736649377005, 44.580694811684744, 43.14409916741507, 43.57319906779698, 40.66228253500802, 41.522639751434326, 37.83112089974539, 39.7970928464617, 39.41989598955427, 42.3556592805045, 41.55029010772705, 40.93800442559378, 39.84066847392491, 36.991295610155376, 38.85489627293178, 40.034742082868306, 41.23196881158011, 43.174622603825156, 43.49479906899588, 44.52956649235317, 43.715692724500386, 44.33892181941441, 44.20849370956421, 45.70066104616438, 44.395146642412456, 45.10363013403756, 43.72833149773734, 45.27123805454799, 44.21700177873884, 46.50262212753296, 44.84287118911743, 44.82415621621268, 45.6180156980242, 48.181741169520784, 49.98041091646467, 54.24118525641305, 54.39776291166033, 55.12519414084298, 52.08827897480556, 54.49726806368147, 51.75947632108416, 52.69913680212838, 50.948691027505056, 51.41887215205601, 51.005707945142476, 53.721466950007844, 52.38074254989624, 62.01485415867397, 64.3744762965611, 73.5328482219151, 67.06845269884381, 80.01459339686802, 30.06537641797747, 1.910512076956885, 0.2380425153034074, 0.43244665222508566, 14.489754234041486, 73.92781857081822, 59.405729157584055, 60.936278343200684, 37.59350987843105, 36.45287275314331, 41.87533726011004, 46.49546548298427, 57.77671357563564, 15.435259887150355, 0.13407788186201028, 0.06612326470868927, 0.019383304453055774, 0.08179059079182999, 0.0736930285181318, 0.05139538053689258, 0.06976745237729379, 0.07993840732212577, 0.11046960617282561, 0.13336479584021227, 0.08366847716804061, 0.22542468165712698, 0.2839670681527683, 0.1346824158515249, 0.12050819929156985, 0.22082125581800938, 10.15028372832707, 61.88262299128941, 58.71773937770298, 42.734620979854036, 43.02350275857108, 59.08835629054478, 56.52561051504952, 88.7173649924142, 28.902723925454275, 0.4233754261263779, 0.8923632789935384, 0.7573905044368335, 49.7710200037275, 83.96477631160191, 76.39948041098458, 78.64362348828996, 76.47866208212716, 80.06399508884975, 68.58133261544364, 63.72850227355957, 74.32901450565883, 71.54915836879185, 68.92516422271729, 69.0590351649693, 62.40803187234061, 61.87537602015904, 59.182928221566335, 58.70240470341274, 56.91703380857195, 55.36463253838675, 53.78927789415632, 53.27301631655012, 50.423167501177105, 52.272552149636404, 48.84397745132446, 48.74652896608625, 49.091513974326, 51.4530086517334, 51.3269613810948, 50.420339584350586, 51.31616040638515, 48.9656195640564, 49.924290316445486, 49.03081103733608, 47.60214328765869, 45.861914839063374, 47.04423073359898, 47.91842876161848, 45.72274936948504, 46.64417082922799, 44.687189851488384, 43.534626143319265, 41.71444129943848, 41.777673380715505, 42.03763675689697, 45.61911351340157, 44.45076697213309, 40.24912527629307, 42.08993584769112, 43.73067651476179, 42.748482636043, 41.64347587312971, 44.35050099236624, 45.849901403699604, 45.19059726170131, 46.15488910675049, 52.079155990055625, 48.99138348443167, 51.1361916405814, 45.02579641342163, 49.51664297921317, 47.27965654645647, 53.58995492117745, 58.07568413870675, 61.558975900922505, 51.04182815551758, 42.02813856942313, 22.13251038960048, 43.60943044934954, 27.913703441619873, 23.675236293247767, 55.83124228886196, 39.84423289980207, 36.973810468401226, 45.85727344240461, 56.17365298952375, 49.899704115731375, 53.231671060834614, 46.581379958561485, 48.33320842470442, 45.40234361376081, 45.85392788478306, 44.08219977787563, 49.38266086578369, 47.93460764203753, 46.67178644452776, 45.951543126787456, 45.32501711164202, 43.21241385596139, 44.443912574223106, 40.398473330906455, 42.97916282926287, 42.91359267915998, 46.50900404793875, 40.9645847593035, 40.45707791192191, 40.88365561621529, 37.82407195227486, 39.758825642721995, 41.95672845840454, 43.63071972983224, 44.34675243922642, 47.05330508095877, 46.89878061839512, 45.41004916599819, 47.075869355882915, 45.38772807802473, 46.8659781728472, 46.948039872305735, 47.645826612200054, 47.20522396905081, 49.5643493107387, 47.81201362609863, 50.5051076071603, 47.66975620814732, 47.187339305877686, 48.19682570866176, 51.02903652191162, 53.650244440351216, 58.11179045268467, 57.37495483670916, 58.28876454489571, 54.95603329794747, 58.322261810302734, 55.84778247560774, 55.530968938555034, 54.112796442849294, 55.294337613242014, 55.48667417253767, 57.597255502428325, 55.697055203574045, 64.04425621032715, 69.3141313280378, 76.60527910505022, 71.80909742627824, 81.46091651916504, 26.717499835150583, 1.9715307227202823, 0.6257303921239716, 0.5248617646949632, 18.886039291109356, 80.39105374472481, 65.31163542611259, 69.11878967285156, 46.55466413497925, 50.3702152797154, 49.36568294252668, 52.44538164138794, 67.40499564579555, 20.047758987971715, 0.24101319589785167, 0.10986353869416884, 0.1953357790729829, 0.1820501991148506, 0.14994767600936548, 0.14693876675197057, 0.1756878476589918], [0.023333504629720534, 0.031727812319461784, 0.05365510231682232, 0.053298223431089094, 0.05989102912800653, 0.14061864731567247, 0.03976385860836931, 0.07958934176713228, 0.14128055822636398, 6.139553776809147, 38.94550078255789, 37.5987731388637, 45.05794225420271, 40.50970704214913, 47.66117518288748, 51.43818119594029, 79.44286782400948, 11.884141547339302, 0.24338475721223013, 0.3472272679209709, 4.174799067633493, 70.78411306653703, 72.25918783460344, 74.38077858516148, 70.51366833278111, 76.71131556374687, 63.122000966753276, 61.16457530430385, 73.02660942077637, 69.43514810289655, 66.63396794455392, 65.65001269749233, 60.015655926295686, 53.72298860549927, 52.190462657383506, 52.19402360916138, 49.53974226542881, 48.792724064418245, 47.75148091997419, 44.618340151650564, 44.36887897763933, 45.307941913604736, 47.51138244356428, 46.81826836722237, 46.14030483790806, 45.94184691565377, 45.39499936785017, 47.00722810200283, 45.46198000226702, 44.489138398851665, 43.29636199133736, 45.70575407573155, 45.72011252811977, 41.983270577022004, 42.00524078096662, 40.946283204214915, 42.718285764966694, 42.54966688156128, 42.94093036651611, 45.847671031951904, 41.660363469805034, 40.02051912035261, 40.69883005959647, 40.49749558312552, 41.08349970408848, 41.45651027134487, 35.28567961284092, 37.58189249038696, 35.03268527984619, 37.51983118057251, 35.97517715181623, 38.152735642024446, 36.52421338217599, 41.421192577907014, 41.563199860709055, 43.617709227970664, 41.13854333332607, 41.027643135615754, 41.01975345611572, 42.546470710209434, 44.773681027548655, 47.72884021486555, 50.163391726357595, 51.97583280290876, 50.926470688411165, 41.01256207057408, 19.537438120160783, 23.47387054988316, 37.32506275177002, 18.301926817212784, 32.60107980455671, 40.95488159997122, 36.5556400844029, 49.07583883830479, 49.826539584568565, 46.69259977340698, 43.10877799987793, 42.62831006731306, 41.92097997665405, 39.39244713102068, 42.54689107622419, 39.8041661126273, 41.674711499895366, 40.34672662190029, 38.39458506447928, 38.3818108013698, 37.53629493713379, 36.36027063642229, 35.825797830309185, 36.184137276240754, 34.18400798525129, 37.27312844140189, 38.5450622013637, 43.06487928118025, 36.60996110098702, 39.99674238477434, 37.67612395967756, 39.519620009831016, 37.66144936425345, 42.10107033593314, 42.76214279447283, 41.74704572132656, 41.21612344469343, 39.65789958408901, 38.937083039964946, 39.49595097133091, 43.372872080121724, 45.43646969114031, 41.71183572496687, 41.7907394681658, 42.51810121536255, 43.28553669793265, 43.080474512917654, 43.05754198346819, 44.53905425752912, 44.57963521139962, 43.00526026317051, 44.7658052444458, 43.44209003448486, 45.33530044555664, 44.027114459446494, 46.226848125457764, 44.05789497920445, 47.291260038103374, 46.53298922947475, 46.654457637241904, 49.99607563018799, 50.38200289862496, 52.758877413613455, 60.382416588919504, 59.754869188581196, 65.58321271623883, 63.76261098044259, 70.76629093715123, 64.03979546683175, 42.50501428331648, 1.5952115101473672, 0.12822863858725342, 0.08920167918716158, 8.47719485419137, 66.66686071668352, 54.36697891780308, 53.544923646109446, 36.838126046316965, 39.7038653918675, 33.88307803017752, 36.59442145483834, 47.18286466598511, 9.129286766052246, 0.04508095061672585, 0.038388088145958524, 0.03981790392260466, 0.11506037733384541, 0.052652197025184116, 0.01601053079191063, 0.05094442277082375, 0.06088343409023114, 0.07446845833744321, 0.005758838661547218, 0.06720501237681933, 0.049748050181993415, 0.06654836011252233, 0.039147511324180026, 0.106743838238929, 0.2319685412304742, 11.496771659169879, 55.85524136679513, 46.27775757653372, 54.105754443577354, 32.57053204945156, 55.65193707602364, 57.66400684629168, 85.39545903887067, 12.748025843075343, 0.18119726702570915, 0.2188566933785166, 6.193969896861485, 75.22615895952497, 73.46623584202358, 77.3691987991333, 70.96678815569196, 79.76061589377267, 68.0772408076695, 60.512938499450684, 74.48139544895717, 71.8725483758109, 68.6742856161935, 67.63662079402378, 62.80833148956299, 58.0308369909014, 53.90844644818987, 55.28364780970982, 50.79405191966465, 52.62522186551775, 49.577432768685476, 46.94597973142351, 47.42748989377703, 49.06840426581246, 49.80998550142561, 49.389848777226035, 50.16325971058437, 47.74173954554966, 47.28695215497698, 49.08833169937134, 48.165475436619346, 45.69654771259853, 45.42673873901367, 47.85091311591012, 45.577511174338206, 45.16248485020229, 44.23099545070103, 45.26199695042202, 44.621598856789724, 45.371524878910606, 44.8452787399292, 45.74620301382882, 41.48837123598371, 40.83764811924526, 40.09224884850638, 40.084897654397146, 42.27140889848982, 45.13308354786464, 37.42938300541469, 39.682343346732004, 39.58632271630423, 38.817636557987754, 39.80850873674665, 41.05793033327375, 38.89903123038155, 42.256348678043906, 42.853730474199565, 45.770803110940115, 43.71372985839844, 42.533866677965435, 41.689347880227224, 45.72017158780779, 46.40442671094622, 49.15725782939366, 53.3601119858878, 55.262532234191895, 54.002872467041016, 45.04308353151594, 21.95808802332197, 27.840231452669414, 40.642275197165354, 21.294967583247594, 33.776808806828086, 42.34219714573452, 38.82655109677996, 50.612439904894146, 52.01267215183803, 47.979187284197124, 44.858841623578755, 43.22753661019461, 44.27478647232056, 41.47861596516201, 44.586552143096924, 42.07557392120361, 43.74626132420131, 42.888082368033274, 41.41197231837681, 40.688400813511436, 40.32383230754307, 39.26063980375017, 37.80890056065151, 38.2609920501709, 37.02493183953421, 39.99558898380825, 40.57279668535505, 43.48825734002249, 38.57961559295654, 41.997531754629954, 39.25302110399519, 39.11887918199812, 38.90275199072701, 43.251000676836284, 45.10595430646624, 41.95041254588536, 44.23037011282784, 43.09828274590628, 40.69503286906651, 42.36739478792463, 44.681384631565635, 46.61586386816842, 42.92424774169922, 43.40899576459612, 45.52726180212838, 45.2736942427499, 45.70531286512102, 44.58989422661917, 47.27098519461495, 47.6493250301906, 44.97166299819946, 46.86233731678554, 45.83841950552804, 47.886543478284565, 45.568541049957275, 47.2816333089556, 46.10814162663051, 48.268249716077534, 48.86021886553083, 49.668860639844624, 52.55309609004429, 51.33829389299665, 55.45110286985125, 62.27193750653948, 61.33550793784005, 68.02484444209507, 67.92941093444824, 73.34234251294816, 67.24492999485561, 56.03217724391392, 1.2790528408118655, 0.12090200744569302, 0.11800946694399629, 8.769650612558637, 73.50617408752441, 59.25370257241385, 63.57399518149239, 40.06055464063372, 34.846219948359895, 44.331407342638286, 44.72736433574131, 56.849886417388916, 13.049128634589058, 0.0025607949771386173, 0.05201144622904914, 0.05487520666792989, 0.050163768231868744, 0.03429819457232952, 0.07057003038270132, 0.04497586929106286, 0.10841587744653225, 0.20110410026141576, 0.12068153784743377, 0.12185875539268766, 0.15342666075697967, 0.18994378697659287, 0.2543646751769951, 0.18175673271928514, 0.24114806151815824, 14.790913479668752, 71.26887498583112, 51.67060191290719, 62.11809049333845, 58.73283086504255, 64.67840439932687, 63.1221399307251, 94.08812795366559, 14.753019741603307, 0.2667771705559322, 0.547387498830046, 6.4235062428883145, 77.46871784755162, 75.94516549791608, 80.11557851518903, 75.37466975620815, 82.05544607979911, 67.77832235608781, 66.07180309295654, 73.95270006997245, 76.15866279602051, 71.59695502689907, 69.53367355891636, 64.02619089399064, 60.40811102730887, 56.91659607206072, 58.62924017224993, 53.71684292384556, 54.105507782527376, 52.75076191765921, 48.67808920996529, 49.02586391993931, 50.7934786932809, 51.029776505061555, 51.47308547156197, 51.9965558052063, 51.06905814579555, 50.403205326625276, 50.81936420713152, 51.373392718178884, 47.61099876676287, 46.69253723961966, 51.12201036725725, 47.87234830856323, 48.36766801561628, 48.00583362579346, 48.37765952519008, 46.616506576538086, 47.36767632620675, 46.277048860277446, 47.34023094177246, 41.689486844199045, 41.68619687216622, 41.13550697054182, 40.29912451335362, 43.48842409678868, 47.87976203645979, 41.48532445090157, 41.063127585819785, 40.54869338444301, 41.69061940056937, 42.463172231401714, 44.32313551221575, 40.83577905382429, 46.22440235955374, 45.31884363719395, 47.855113301958355, 46.41430704934256, 44.94529458454677, 43.84216730935233, 47.66721664156233, 49.132987771715435, 53.01287923540388, 56.0420297895159, 58.07401309694563, 56.180413586752756, 48.067641326359336, 24.881130899701798, 32.39041042327881, 46.88616616385323, 23.612575701304845, 36.93636662619454, 44.09681183951241, 41.94654587336949, 54.046906675611226, 54.22666699545724, 49.917182309286936, 48.88872037615095, 46.37035621915545, 48.18452392305647, 43.52762235913958, 47.76423781258719, 45.45393746239798, 47.20033938544137, 45.12039961133684, 43.72108800070626, 43.87574447904314, 42.14546932492937, 42.16590050288609, 41.82558815819876, 41.536230427878245, 40.516683033534456, 41.738169397626606, 39.248438767024446, 43.9572503226144, 39.29807669775826, 42.96878916876656, 40.54498304639544, 40.495682103293284, 38.77582229886736, 43.97202566691807, 46.609686919621055, 44.74708332334246, 46.14141307558332, 45.116800444466726, 42.46636492865426, 45.178688049316406, 48.40166902542114, 49.39466387884957, 45.713358879089355, 46.35680375780378, 49.177980831691194, 48.56391641071865, 49.35134533473423, 48.33397620064871, 48.763517311641145, 50.209260259355815, 46.97673940658569, 50.80282054628645, 48.48549209322248, 49.62169279370989, 47.84236683164324, 51.99457209450858, 48.07372794832502, 51.505074977874756, 52.636081899915425, 52.3458764893668, 54.30322919573103, 53.71579027175903, 57.05330882753645, 64.56289754595075, 64.37627587999616, 72.76507922581264, 68.08348723820278, 77.9454129082816, 69.2773128237043, 56.161212239946636, 3.023383115019117, 0.21651523187756538, 0.2543552299695355, 11.153925827571324, 79.70769146510533, 66.07139314923967, 68.77361706324986, 54.05828087670462, 54.78541680744716, 50.23564256940569, 53.27753264563424, 68.97346115112305, 16.2047016620636, 0.1507340031010764, 0.15761681805763925, 0.11441498196550778, 0.12770068405994348, 0.19629433192312717, 0.18916571087070874, 0.11612079186098916], [0.043745030515960286, 0.02298932452686131, 0.07420739877436842, 0.04118649548451815, 0.06440040322818927, 0.14565638984952653, 0.13096373182322296, 0.07479179384452955, 0.06564255657472781, 9.692143831934247, 41.25433506284441, 36.88084357125418, 40.54720299584525, 43.8355005128043, 53.80258022035871, 54.02085440499442, 71.76746382032121, 5.093525060585566, 0.03269674675539136, 0.17985775747469493, 16.10742861883981, 76.65204048156738, 67.28687626974923, 75.13435935974121, 71.41159098488944, 69.96484402247837, 57.65467888968331, 73.93485014779228, 66.02416624341691, 68.3221926007952, 63.675675119672505, 62.0808481488909, 57.325257846287315, 57.299799646650044, 54.755404063633506, 53.40711307525635, 53.31133215767996, 50.012518542153494, 49.16951445170811, 47.456067834581646, 47.27855525697981, 48.13637638092041, 46.434505462646484, 45.51430688585554, 45.26758330208914, 49.58148009436471, 47.52706800188337, 46.680930273873464, 45.17806271144322, 44.45142010280064, 44.87620864595686, 44.57339572906494, 43.18285274505615, 41.09626007080078, 42.51331390653338, 41.349737303597585, 41.617378439222065, 41.7636901310512, 42.41571603502546, 44.528482573372976, 42.48633057730538, 41.378051212855745, 39.88263211931501, 41.72478716714041, 43.55478286743164, 42.397289412362234, 42.5009183202471, 34.3158083643232, 36.77783652714321, 35.27700826099941, 36.42622293744768, 37.59480224336897, 37.184160232543945, 37.77186666216169, 39.27924360547747, 42.861825125558035, 41.35362482070923, 41.32218074798584, 42.94160086768014, 44.426976340157644, 43.948843002319336, 40.07945721490042, 42.93652868270874, 49.44566018240792, 52.295074735369, 41.662816183907644, 29.30766146523612, 31.192540986197336, 32.34965923854283, 28.225894689559937, 32.866775444575715, 42.05011919566563, 50.11823885781424, 49.20000662122454, 46.979511737823486, 46.35699135916573, 40.46290397644043, 41.90486363002232, 39.94144862038748, 42.59629276820591, 40.34861305781773, 40.472905908312114, 40.50334596633911, 39.083325249808176, 38.04721335002354, 36.62299592154366, 37.684350626809255, 35.95135872704642, 34.705956663404194, 35.85553959437779, 40.74017531531197, 44.66505289077759, 42.97909682137625, 42.9769081388201, 40.24644674573626, 43.522407736097065, 39.88198593684605, 39.503781591142925, 37.292809213910786, 41.017043658665244, 42.09289230619158, 41.73335429600307, 40.132583141326904, 40.292964935302734, 39.29570041384016, 39.63805900301252, 43.7938460622515, 42.45315292903355, 41.66152381896973, 41.3677852494376, 41.31646932874407, 43.2699727330889, 42.739755698612754, 42.970265660967144, 42.941489696502686, 42.011337825230186, 42.455157484327046, 44.10244682856968, 44.40792785372053, 44.537470068250386, 45.11885711124965, 45.329894747052876, 46.17651884896414, 47.10002824238369, 47.300581046513145, 51.22299895967756, 51.11222035544259, 57.500922203063965, 59.72525596618652, 63.185681206839426, 62.91570895058768, 65.56728744506836, 64.99347741263253, 68.91004494258335, 63.684179714747835, 54.919822760990684, 0.7370319568685123, 0.2369515938418252, 0.2204815676169736, 1.811998997415815, 57.47177798407418, 60.07566751752581, 52.49036775316511, 49.67412042617798, 51.59601647513253, 29.312959466661724, 38.868309770311626, 46.90862621579851, 12.303576503481183, 0.2887399377567427, 0.10546374121414763, 0.07039861886629037, 0.0091796992512952, 0.056750691030174494, 0.031117324185158526, 0.05403952293896249, 0.0676417446562222, 0.05819437266992671, 0.04620886580752475, 0.06906031032225915, 0.03862015390768647, 0.12694665523512022, 0.09637648133294922, 0.11163571609982423, 0.0945266116676586, 15.753320625850133, 53.18322822025844, 45.46540546417236, 40.730475630079, 37.134056772504536, 62.30911036900112, 59.50700610024588, 79.8135542188372, 4.760750208582197, 0.08082366481955562, 0.08809971796082598, 19.58206466266087, 81.9008069719587, 70.75720964159284, 77.77572400229317, 73.4735106059483, 73.89081941332135, 62.349152837480815, 75.15999821254185, 69.33064719608852, 69.42590699877057, 66.04419095175606, 64.33262729644775, 59.50257314954485, 58.29343373434884, 57.87099368231637, 56.06296818596976, 55.22269473757063, 53.51325028283255, 52.50746032169887, 49.18946967806135, 49.3557504926409, 50.131516865321565, 48.47879750388009, 48.09632349014282, 46.38878631591797, 49.91963849748884, 48.391757420131135, 48.59158761160714, 48.51940972464425, 46.802621023995535, 46.95813907895769, 45.77233518872942, 45.07968316759382, 44.29524196897234, 45.13805150985718, 44.80589287621634, 45.668063572474885, 44.06680604389736, 46.90996721812657, 42.50212035860334, 42.761385440826416, 40.58048486709595, 39.79711716515677, 43.98492847170149, 42.9673821585519, 43.23854603086199, 44.83032274246216, 37.48190791266305, 40.324058123997276, 37.11841637747628, 39.55318675722395, 39.208656855991904, 38.71108940669468, 41.17218998500279, 41.05631487710135, 44.92079176221575, 43.16305037907192, 42.280677795410156, 45.89507164273943, 45.993510246276855, 46.14157983234951, 42.85264655521938, 47.148689951215474, 51.373159953526084, 53.085369791303364, 43.990438393184114, 32.30489546912057, 35.75841767447335, 35.98828492845808, 30.782444408961705, 35.553407600947786, 43.51495926720755, 52.49484239305769, 51.82456357138497, 48.18694884436471, 47.086632115500315, 42.56156914574759, 43.62465047836304, 42.32881838934762, 43.12635694231306, 41.982155391148154, 43.70042405809675, 42.068361691066194, 40.889113426208496, 38.7567321232387, 38.717214243752615, 39.032565185001914, 39.237127099718364, 37.74909046718052, 38.66636037826538, 42.27461896623884, 44.717709813799175, 43.17233664648873, 43.24302067075457, 41.71398271833147, 43.98648486818586, 40.58885397229876, 38.34297384534563, 38.15074150902884, 42.92682899747576, 43.13921805790493, 43.31239495958601, 43.29143571853638, 42.759710924965994, 41.393340723855154, 42.8898298399789, 45.3178847857884, 44.26212338038853, 44.158247811453684, 42.67759016581944, 42.579599721091135, 46.08790847233364, 45.97666086469378, 45.97757107870919, 45.39877223968506, 46.04268264770508, 45.13187108721052, 45.16903352737427, 47.02931989942278, 46.79024280820574, 46.6764486857823, 48.8142078944615, 48.736978667122976, 49.79865993772234, 49.55979476656233, 53.3713368007115, 52.547739028930664, 61.37321581159319, 63.034960883004324, 64.88664885929653, 64.95096833365304, 68.41843904767717, 66.12666606903076, 73.98003428322929, 66.71282999856132, 67.38086455208915, 2.080810470240457, 0.46098485801901135, 0.21810020825692586, 1.6499223858118057, 61.275016920907156, 67.52435180119106, 60.101535660879954, 55.14612906319754, 45.53017309733799, 37.055420534951345, 46.25497790745327, 56.47721631186349, 16.61993990625654, 0.2243902685918978, 0.07359770791871206, 0.07624629472515412, 0.05548705526494554, 0.05945988119180713, 0.07886993179896049, 0.04268323177737849, 0.21758342241602285, 0.1268779467791319, 0.2188097930380276, 0.15464597461479052, 0.10573454454009022, 0.3159761434154851, 0.20531765344951833, 0.23301511364323751, 0.18484250642359257, 22.47045166151864, 66.30297660827637, 52.44177205221993, 55.970835072653635, 60.88967677525112, 70.76433154514858, 64.29847690037319, 87.5795418875558, 6.585305903639112, 0.23066293128899165, 0.34107708079474314, 21.38661084856306, 84.57202107565743, 71.06655733925956, 81.92513956342424, 76.2764972959246, 74.406980242048, 62.60565253666469, 75.84725148337228, 70.40803486960274, 73.41993304661342, 68.06018992832729, 67.88175324031285, 62.49972030094692, 60.04321943010603, 60.344771248953684, 58.97013963971819, 58.78348323277065, 55.216990266527446, 55.057678495134624, 51.43067019326346, 50.62348754065377, 52.525067056928364, 52.0347570010594, 51.415797574179514, 49.28444460460118, 54.27430731909615, 51.744919845036094, 49.785489627293174, 50.83459118434361, 48.63546201160976, 49.231475012642996, 48.39440468379429, 48.62071098600115, 47.39520508902413, 47.214548451559885, 45.91932085582188, 46.627557686397004, 46.65157413482666, 47.909823417663574, 44.172842502593994, 42.76041964122227, 41.58318287985665, 41.20150443485805, 43.59985930579049, 43.873482840401785, 44.122780731746126, 47.22339003426688, 39.401368618011475, 42.86264501299177, 40.56310394832066, 41.70622158050537, 41.64776291166033, 41.91016163144793, 43.01646423339844, 43.50790684563773, 45.92512607574463, 44.853884083884104, 44.20208747046334, 48.553733825683594, 50.02262469700405, 49.27765621457781, 44.790478297642295, 48.10647480828421, 54.815457344055176, 55.79107822690691, 44.76201152801514, 34.05827685764858, 41.83128220694405, 43.303730555943076, 36.098823819841655, 38.490984371730256, 46.36168834141323, 55.33849688938686, 54.310292039598735, 50.96809039797102, 50.40082209450858, 45.32610103062221, 46.58692809513637, 44.82527835028512, 47.8716778073992, 44.539603165217805, 45.60081543241228, 45.891972746167866, 43.81316205433437, 41.32717997687203, 41.87370095934187, 41.924961294446675, 42.96352243423462, 41.30116244724819, 40.23337371008736, 44.379805019923616, 46.91674518585205, 44.41321543284825, 44.97905935559954, 43.96861062731062, 46.74064656666347, 41.50044025693621, 40.18102945600237, 38.03080865315029, 43.438428333827424, 45.07050459725516, 44.21785293306623, 45.282077244349885, 46.62977763584682, 44.232353823525564, 44.801584993089946, 48.17947605678013, 47.26652792521885, 46.13853652136666, 45.437143666403635, 46.56460005896432, 48.067978313991, 46.67999226706368, 48.774992261614116, 47.96832724979946, 48.10450846808297, 47.608191694532124, 48.82361575535366, 49.474255493709016, 49.50417096274239, 50.322251864842, 51.83100455147879, 50.37034729548863, 52.863899435315815, 52.18461227416992, 56.57546383993966, 54.738905566079275, 65.2545907156808, 64.75610610416958, 70.78485652378627, 67.98592758178711, 72.09963635035923, 68.0940693446568, 79.20230034419468, 65.10216808319092, 75.90424755641392, 5.821031417165484, 0.7240115755370685, 0.35964597868067877, 2.609681725502014, 71.99353040967668, 74.20733070373535, 67.66439969199044, 68.23681313650948, 70.0020307813372, 47.91497550691877, 58.75865731920515, 67.00679438454765, 22.320759671075002, 0.44974853524139946, 0.12075621741158621, 0.1518256166683776, 0.1473353976117713, 0.1280951164662838, 0.20276648391570362, 0.11350073066673108], [0.01919228836361851, 0.03937104111537337, 0.08317531791648694, 0.03029011535857405, 0.040862878385399065, 0.057484441835965426, 0.11454877550048487, 0.03189015182267342, 0.34875530164156643, 9.202613711357117, 40.93865408216204, 32.94633231844221, 35.964734009334016, 39.9144618170602, 49.6458169392177, 61.50726740700858, 61.53811046055385, 1.515008562377521, 0.10951407280351434, 0.1448000515145915, 32.259343079158235, 78.6635022844587, 68.39348806653703, 76.15868364061627, 70.41264847346714, 64.25257015228271, 64.02686486925397, 72.53581646510533, 66.29062965938023, 68.03326565878731, 60.678208351135254, 64.931638445173, 66.21877138955253, 64.20097282954625, 62.549802916390554, 56.82311153411865, 51.11772332872663, 52.34924636568342, 48.120600496019634, 45.859813008989605, 45.107031277247835, 46.25515856061663, 44.69613218307495, 47.3092246055603, 44.67270285742623, 45.99246801648821, 45.22798899241856, 44.51888363701956, 44.42541299547468, 45.17616237912859, 43.683824811662944, 43.66273702893938, 42.39297110693795, 41.109211512974326, 41.163636752537315, 43.33870431355068, 40.0521924836295, 42.668814590999055, 44.986723218645366, 46.97267471040998, 44.14881910596575, 41.67818559919085, 44.771811962127686, 44.34248971939087, 33.61951548712594, 38.6228403363909, 41.02585050037929, 44.117816243852886, 34.91222436087472, 35.696022851126536, 36.69898836953299, 35.62661729540144, 37.42048583711897, 38.268902574266704, 35.88733107703072, 41.9164080619812, 39.91874190739223, 43.827461447034565, 48.96576547622681, 48.97654560634068, 46.67950241906302, 47.3969212940761, 49.169750690460205, 52.21080003465925, 48.77534661974226, 53.3794001851763, 31.99483905519758, 33.83073377609253, 38.099484648023335, 39.59410122462681, 34.5096492086138, 42.48122017724173, 50.08554063524519, 48.98885086604527, 46.905548163822715, 43.24544211796352, 45.13406324386597, 42.26886933190482, 40.48782021658761, 39.06721585137503, 40.55755581174578, 40.45354127883911, 37.77287067685808, 35.79718862261091, 34.86445549556187, 36.68200697217669, 33.80246155602591, 34.709799017224995, 34.352581705365864, 40.540848868233816, 43.91545690808977, 42.734509808676584, 44.5712765284947, 42.189479214804514, 39.34161063602993, 44.550880091530935, 41.97402252469744, 36.35270404815674, 37.26948411124093, 42.25283636365618, 41.1804826600211, 41.35407992771694, 40.13651582172939, 41.24705335072109, 39.2745292527335, 40.92394821984427, 42.11307334899902, 42.18319456917899, 40.32930053983416, 42.2173102242606, 42.9113449369158, 42.49971628189087, 43.20347499847412, 41.20898764474051, 43.16442959649222, 43.446335383823936, 43.446300642830984, 44.42197016307286, 44.84442758560181, 45.591341563633506, 44.702764238630024, 44.69485024043492, 46.09487056732178, 47.6994423866272, 47.97360093252999, 46.02604171207973, 53.868508202689036, 61.26895114353725, 63.861379623413086, 65.51105567387172, 64.1986312866211, 65.03340870993478, 65.2408332824707, 68.20078672681535, 66.14027064187187, 61.91419560568673, 4.46686008146831, 1.1374983851398741, 0.10559429813708578, 0.1000905241817236, 33.01056146621704, 63.093471663338796, 50.707470417022705, 50.33387967518398, 38.45572573798043, 17.7083317892892, 34.3701502255031, 41.39617211478097, 17.559239080974034, 0.19756152321185383, 0.04562983116401093, 0.04904627533895629, 0.07840681807803256, 0.061853990224855285, 0.05506085724170719, 0.030141641718468497, 0.039092054657105885, 0.04199066126186933, 0.047112151980400085, 0.08113173328872238, 0.03127663742218699, 0.027611971566719667, 0.1389672423579863, 0.08355420508555003, 0.20400668308138847, 16.609668731689453, 55.21342584065029, 44.23491423470633, 38.49596970421927, 40.087298257010325, 59.1692750113351, 67.49275139399937, 68.20108549935478, 1.438269617302077, 0.08272464174245085, 0.5415349443043981, 38.79457548686436, 79.561612537929, 71.31571974073137, 77.83789648328508, 71.01887880052838, 67.18103436061314, 66.93535995483398, 72.96473571232387, 71.0654525756836, 69.16678088051933, 62.40495382036482, 67.97681154523576, 67.82716124398368, 67.49118110111782, 63.75597545078823, 59.98392350333077, 52.54072134835379, 53.80707917894636, 51.58679274150303, 48.31353807449341, 47.32872125080654, 47.316728660038535, 47.1184618132455, 48.387786524636404, 47.88319444656372, 48.54694890975952, 47.27700233459473, 46.137737478528706, 46.475135053907124, 47.36511244092669, 45.533546447753906, 46.26293706893921, 46.26507364000593, 44.603995595659526, 44.25901753561837, 43.68369974408831, 44.03008828844343, 44.363820689065115, 48.25441237858364, 47.446607862200054, 44.68737050465175, 42.09085300990513, 46.479029519217356, 46.640995502471924, 37.490078994206016, 41.35099492754255, 40.854890074048726, 46.0380516733442, 37.777519021715435, 38.95805965151106, 38.1306403705052, 37.61663000924246, 39.1988981110709, 40.05715697152274, 38.982076099940706, 43.242846965789795, 42.26663201195853, 46.1959216935294, 50.49358401979719, 50.8158449445452, 51.33636229378836, 49.41156884602138, 51.67859581538609, 53.22575466973441, 52.49962622778756, 56.02221352713448, 36.339116845812114, 38.51432337079729, 40.22849954877581, 41.29936981201172, 37.181252411433626, 42.09290967668806, 53.27442332676479, 50.37987674985613, 50.76106882095337, 45.74404559816633, 46.0558876991272, 44.312817437308176, 41.784962041037424, 40.66348457336426, 43.376036984579905, 41.52356038774763, 39.17184182575771, 38.925531659807476, 38.94381237030029, 39.081188678741455, 36.31949860709054, 37.7961471421378, 37.80814320700509, 42.01050056729998, 43.61381476266043, 42.934687410082134, 43.48042672021048, 42.042990343911306, 40.81376716068813, 46.05341066632952, 43.128180844443186, 39.16231237139021, 37.57463162285941, 42.241608074733186, 43.15320825576782, 42.697892802102224, 42.436623164585654, 43.07481173106602, 41.17213092531477, 41.910717487335205, 43.504894801548545, 43.87781851632254, 41.70712832042149, 44.73976687022618, 44.378252097538535, 43.395363398960654, 44.833946228027344, 43.34709426334926, 45.17013481685093, 44.32121433530535, 44.76377289635794, 46.984740257263184, 46.972573961530415, 47.78999478476388, 45.614322730473106, 48.170346123831614, 47.693685804094585, 49.67675379344395, 50.24155896050589, 50.36446564538138, 56.146770409175325, 64.9196389062064, 65.14250237601144, 68.13737051827567, 66.05921295710972, 69.50784710475376, 66.54888030460903, 72.95378535134452, 66.89221164158413, 72.57250295366559, 10.61025013242449, 2.1304425384317125, 0.3697753665702683, 0.14196666569582053, 36.94320365360805, 70.07798848833356, 56.83160918099539, 57.603182315826416, 34.917310442243306, 24.402532032557897, 44.011029379708425, 51.4785988671439, 21.65410086086818, 0.3118959494999477, 0.005898817891388067, 0.05176731272201453, 0.0906257274161492, 0.019904622907883356, 0.04733282174648983, 0.0212550382129848, 0.07766681457204477, 0.15033206609742983, 0.16005936770566873, 0.15138949507049151, 0.09544749903891768, 0.21148384043148585, 0.35388041234442164, 0.22661711195749895, 0.3099078961781093, 22.09713363647461, 71.0173293522426, 47.323315552302766, 54.210957118443076, 59.14262866973877, 64.95028046199253, 73.8230814252581, 75.99055113111223, 1.971699433667319, 0.1768698828028781, 0.6769648886152676, 40.85935081754412, 82.32135363987514, 73.93113980974469, 79.240633555821, 75.45972265516008, 69.3989062990461, 68.0013734272548, 75.02133996146065, 73.42585291181291, 72.30248900822231, 65.761399269104, 68.63821751730782, 68.21641322544643, 70.4750919342041, 68.7090960911342, 62.07228796822684, 55.07097039903913, 56.49997166224888, 53.365469047001426, 49.62793575014387, 49.88840981892177, 50.78611012867519, 48.510043552943635, 52.07033177784511, 50.442542552948, 51.59887565885271, 49.417308058057515, 48.498638084956575, 49.19074814660208, 50.61063684735979, 47.66681364604405, 48.76857907431466, 48.87057168143136, 46.548184939793174, 47.30936009543282, 47.60811873844692, 45.674355166299, 47.58749648502895, 50.87747894014631, 48.84759051459176, 44.752621037619456, 42.863367625645225, 47.86650487354824, 47.75517736162458, 41.50923320225307, 42.69430405752999, 42.27198212487357, 49.09564815248762, 42.706616265433176, 40.02531337738037, 42.17914029530117, 40.35413340159825, 43.98509522846767, 43.39580460957119, 42.719373158046174, 46.23923676354544, 44.04534305844988, 48.97250522886004, 50.973652430943076, 52.94015938895089, 51.628933565957205, 53.51185022081648, 55.84184871401106, 57.38581487110683, 56.2609258379255, 60.50987434387207, 42.887689794812886, 42.096310819898335, 46.86101368495396, 45.8969407081604, 40.38331583568028, 44.73182855333601, 55.15153476170131, 53.32920292445591, 52.99805525371006, 47.85315390995571, 49.16365712029593, 47.022378649030415, 46.26403488431658, 42.0383871623448, 44.415675095149446, 43.536985056740896, 42.007377352033345, 41.09376914160592, 41.87733834130423, 42.08010414668492, 38.864759240831646, 39.52006816864014, 40.705406529562815, 44.21751594543457, 45.00343711035592, 44.25380291257586, 45.145826544080464, 43.828197956085205, 42.66210610525948, 45.75628137588501, 45.105488777160645, 39.84720325469971, 36.80859620230538, 43.9854530606951, 45.6619804246085, 44.39284331457955, 44.83000659942627, 47.13716983795166, 43.29422194617135, 46.148917130061555, 46.17834275109427, 45.16057756968907, 43.49358313424246, 47.752630846840994, 46.86906317302159, 47.86385760988508, 48.370499406542095, 45.349467822483604, 48.31230476924351, 47.936490603855674, 48.50523887361799, 49.967671394348145, 49.16880573545183, 51.47993292127337, 49.561764580862864, 50.62660380772182, 50.96723576954433, 52.718942642211914, 54.374264104025706, 53.60036679676601, 59.01899242401123, 69.04149096352714, 67.0562447139195, 70.63946546827043, 70.69282763344901, 72.64955847603935, 68.20130784170968, 77.7605630329677, 67.67935916355678, 78.10332461765834, 15.018192529678345, 1.991031710590635, 0.6623033210635185, 0.0906344669471894, 46.61321660450527, 75.8860502243042, 66.00075081416539, 66.59942844935826, 53.752535820007324, 36.50577286311558, 55.54548372541155, 61.81586469922747, 28.888787576130458, 0.3541840431945664, 0.1183923099722181, 0.11619842983782291, 0.1797943144504513, 0.09903874740536724, 0.17001165795539105, 0.11369040156049387], [0.01461681816726923, 0.07853578044367687, 0.021166391005473476, 0.05526730152113097, 0.026920026999765208, 0.08087608164974622, 0.017859363994960274, 0.12545649733926567, 0.2196786707001073, 14.354937468256269, 38.680406161717, 30.027032784053258, 48.671026366097585, 35.208530289786204, 55.565932273864746, 65.8136636189052, 49.052802085876465, 0.39722362799303873, 0.38831734018666403, 1.6113435987915312, 53.911701679229736, 67.64131082807268, 72.63141672951835, 68.23726476941789, 67.78051103864397, 69.48807947976249, 61.14159761156355, 73.61881133488247, 64.91412898472377, 65.34839139665876, 62.911609513419016, 63.183388301304404, 62.6768924168178, 64.49340166364397, 63.7345541545323, 61.03399085998535, 52.62911980492728, 52.434240204947336, 48.84232030596052, 49.13857759748186, 47.99692256110055, 47.66735560553414, 47.038585322243826, 41.129243169512065, 43.51175962175642, 45.325732776096885, 45.35419259752546, 44.38300813947405, 46.36891794204712, 44.28337097167969, 42.21192537035261, 43.01413311277117, 43.640600068228586, 41.45591967446463, 42.960517338344026, 41.58473232814244, 40.03388050624302, 41.5906799861363, 44.32220445360456, 44.132265022822786, 44.656336375645225, 40.393901416233604, 43.738965715680806, 46.12096105303083, 40.82811519077846, 33.084233215876985, 31.388539246150426, 45.570677621024, 42.79240219933646, 35.19663497379848, 37.46413442066738, 39.713436535426546, 37.99226699556623, 36.635509627205984, 38.06608813149588, 36.48530694416591, 37.65326091221401, 40.23522540501186, 47.00788470676967, 46.03408425194876, 49.53436435971941, 50.65606764384678, 50.42684309823172, 51.93543945040022, 52.79077659334455, 42.35790007455008, 35.575575828552246, 40.85991709572928, 36.46270792824881, 38.68078136444092, 30.29689039502825, 35.231639998299734, 47.17329352242606, 49.32467467444283, 47.378564153398784, 50.91190031596592, 43.43897376741682, 46.93520654950823, 39.006318364824565, 39.8228428704398, 38.52505486352103, 36.08965914590018, 36.17149155480521, 35.15535920006888, 34.74420649664742, 35.628944941929404, 33.787064347948345, 35.518472058432444, 38.0219601222447, 40.47908633095877, 42.29141971043178, 42.14400672912598, 40.87310477665493, 47.256918566567556, 36.210165228162495, 39.505935532706125, 44.95134646551949, 42.07816559927804, 39.270846707480295, 46.16226461955479, 42.376281533922466, 39.824621609279085, 41.18149709701538, 38.64116621017456, 37.9201968056815, 39.809307779584614, 42.209236417497905, 41.66548081806728, 40.80815649032593, 42.65873622894287, 40.63430213928223, 42.53299467904227, 43.58380549294608, 40.49100596564156, 41.28611612319946, 41.18729884283883, 43.600140707833425, 42.74099595206124, 43.62500483649117, 43.18421459197998, 45.05290828432356, 45.48140369142805, 47.01367255619594, 46.62980195454189, 49.9220495223999, 50.252102851867676, 59.820835386003765, 62.59571661267962, 63.978609630039756, 60.78778144291469, 64.33089024680001, 63.20484433855329, 63.78836795261928, 65.67736080714634, 64.09620789119175, 72.60852936335972, 16.036091463906423, 2.1942608739648546, 0.1372445776526417, 0.246872535773686, 21.287286349705287, 63.26146520887102, 54.4947806085859, 42.47465065547398, 28.9311420576913, 20.814803634371074, 23.218387024743215, 32.919109276362825, 22.493627377918788, 0.3359053140240056, 0.05762615387461015, 0.053807467355259826, 0.09868611275617566, 0.07277966610022954, 0.05141765684155481, 0.0970257714922939, 0.06179087289742061, 0.07382395184998002, 0.015388022409752011, 0.09968609695455857, 0.04287016817501613, 0.028688823604690175, 0.04947800002992153, 0.07713491775627647, 0.10505256256354706, 22.903895923069545, 53.108632360185894, 34.47080183029175, 38.940195832933696, 42.376444816589355, 62.50074168613979, 71.58391325814384, 53.903176239558626, 0.2755485927420003, 0.19682137721351214, 3.1579586480345045, 60.20974690573556, 68.08258397238595, 74.1712417602539, 70.56837150028774, 71.02741118839809, 71.19892747061593, 66.22846412658691, 73.40177045549665, 66.27066748482841, 66.57508890969413, 64.69849858965192, 66.45710154942104, 66.46600914001465, 67.33754253387451, 66.9292802810669, 62.95152691432408, 56.363620213099885, 53.35244117464338, 52.14428840364729, 51.818661076681956, 50.170645645686555, 49.177237374441965, 49.69706685202462, 44.253115040915354, 43.91040209361485, 47.01209878921509, 48.13766527175903, 47.65252120154244, 48.110952922276084, 47.238721234457834, 44.975300380161826, 46.0787160055978, 46.329167297908235, 42.97148854391915, 45.563642569950645, 44.130944865090505, 43.93828521456037, 43.41444315229143, 46.022477286202566, 44.752165930611746, 46.351102760859895, 42.756650243486675, 45.14047295706612, 47.022882393428254, 43.96610232761928, 37.210219451359336, 35.03524569102696, 46.41400132860456, 44.505355494362966, 38.844341959272114, 39.33867849622454, 41.89000490733555, 40.04924644742693, 38.290532316480366, 40.391226359776084, 39.02547802243914, 40.8411534854344, 43.474221978868755, 47.93142884118216, 47.66263777869088, 50.25806440625872, 52.05630336488996, 52.30189091818673, 53.56563970020839, 54.71294709614345, 45.34298167909895, 41.163553374154226, 43.0450838633946, 39.58178554262434, 40.91360582624163, 33.93558209283011, 37.01861940111433, 48.98484522955758, 52.148290566035676, 50.66719518389021, 53.485471384865896, 46.716432094573975, 48.095965657915386, 41.892092841012136, 41.9864250591823, 39.47136129651751, 37.877868379865376, 37.979121003832134, 38.953925473349436, 36.587917940957205, 38.881094455718994, 36.02751793180193, 38.2980363709586, 40.62673902511597, 41.23792689187186, 43.988545009068076, 42.92758287702288, 41.52106251035418, 47.347446646009175, 38.32202155249459, 40.491884912763325, 44.67759091513497, 42.54185363224575, 40.583055700574604, 45.828480107443674, 42.88832555498396, 42.13125678471157, 42.81706830433437, 41.01583814620972, 40.925358704158235, 42.86889491762434, 43.369338921138215, 44.651979855128694, 42.818690708705354, 44.50513662610735, 43.857689585004536, 46.366246359688894, 46.522031920296804, 42.89979703085763, 43.1614488192967, 44.5310047694615, 45.960770334516255, 45.766422271728516, 45.92530672890799, 44.922417640686035, 46.983222075871055, 49.080157143729075, 47.92265674046108, 49.42805344717843, 50.976643630436485, 54.092139448438374, 61.52552727290562, 65.66062954493931, 65.9968181337629, 65.42549555642265, 66.4671277999878, 66.50723975045341, 63.14893913269043, 70.13557515825543, 66.662351335798, 77.37939875466483, 25.921449933733257, 1.9852397356714522, 0.42336809794817654, 0.32595489653093473, 23.361368792397634, 70.05484403882707, 62.37847423553467, 52.85830266135079, 31.85159499304635, 20.97095397540501, 34.271784578050884, 42.82947778701782, 25.773800713675364, 0.4837841231908117, 0.06732765079608985, 0.03807151424033301, 0.09134931037468569, 0.03945246871028628, 0.02589171226801617, 0.007725513041285532, 0.2133065890520811, 0.1173353831150702, 0.0829810533406479, 0.07121506612747908, 0.1467641932623727, 0.17552622061754974, 0.12491612562111445, 0.1906309122485774, 0.25903948290007456, 32.60665920802525, 61.40660885402134, 39.62914099012102, 64.13196332114083, 50.76821156910488, 70.40863936288017, 77.71426023755754, 61.33889171055385, 0.6695632657834462, 0.3196997807494232, 3.4213763645717075, 66.78067220960344, 71.06418105534145, 77.79597105298723, 72.84107167380196, 74.70740645272392, 72.79640865325928, 68.47090489523751, 74.76383972167969, 68.05896009717668, 68.70270374843052, 67.74333817618233, 69.70038168770927, 70.46565628051758, 67.71056352342877, 70.9753691809518, 65.86212035587856, 59.728841236659456, 58.104341983795166, 55.996345383780344, 54.49376269749233, 52.75341960362026, 52.66306522914341, 52.329148701259065, 46.03735337938581, 47.04879570007324, 50.84108427592686, 50.787812437329976, 49.31984567642212, 50.74896158490862, 49.79522057941982, 47.225936549050466, 48.05106292452131, 50.80604451043265, 46.507204464503694, 48.72813013621739, 46.315267426627024, 44.149638993399485, 43.88352646146502, 48.40627220698765, 47.111645630427766, 46.22557313101632, 44.691546372004915, 46.853540897369385, 49.46964536394392, 45.80221244267055, 41.25308091299874, 36.54520389011928, 48.24943746839251, 47.48075825827462, 42.15865005765642, 43.45044871738979, 46.0180721282959, 42.52992010116577, 40.85599136352539, 44.07724918637957, 42.062414033072336, 43.59187235151018, 45.04098170144217, 50.48843887874058, 51.8130121912275, 53.570288045065745, 55.99494879586356, 53.2743364742824, 57.64548989704677, 58.37403283800398, 48.21317481994629, 44.1474746295384, 47.467935357775005, 43.14305346352713, 43.81511102403913, 40.19065618515015, 40.50053194590977, 54.27061087744576, 54.479435511997764, 52.8727514403207, 55.5727276120867, 49.80100148064749, 51.56834180014474, 44.12645632880074, 44.946566104888916, 42.643853187561035, 40.22762060165405, 41.12187113080706, 40.95771993909563, 38.24328804016113, 40.56167956760952, 40.00928388323103, 41.90621158054897, 43.33240924562727, 43.37751695087978, 44.948476859501426, 42.58587047031948, 42.072874546051025, 49.18938977377755, 40.67247554234096, 42.08307102748326, 44.84957272665841, 45.456240790230886, 41.467783723558696, 49.34647464752197, 45.10688883917672, 42.66207831246512, 46.139658655439106, 44.85397788456508, 42.35352618353707, 45.21463108062744, 46.14992461885725, 46.71163783754621, 45.25328390938895, 47.40024600710188, 46.93508495603289, 48.312558378492085, 50.2418612071446, 45.1332676751273, 46.89657803944179, 47.805395466940745, 48.4927772794451, 47.435230187007356, 49.20230300085885, 48.00808136803763, 49.90785435267857, 51.88182715007237, 51.343491145542686, 52.01513876233782, 54.745079040527344, 56.68813582829067, 64.32779135022844, 68.44363321576799, 69.01674148014614, 67.61519254956926, 68.10200418744768, 69.97102791922433, 66.28951099940709, 72.03228051321847, 67.6834933417184, 80.84788390568325, 30.659023557390483, 2.6739931660039082, 0.6915023114000047, 0.29262384506208555, 29.128215551376343, 76.37546743665422, 69.26191561562675, 60.50273854391915, 45.986461298806326, 35.850616795676096, 44.48592833110264, 56.82414334160941, 32.27810321535383, 0.819709983255182, 0.1548817791044712, 0.1364211482661111, 0.184448793264372, 0.11219828948378563, 0.11766857095062733, 0.1323674986405032], [0.1289440044867141, 0.1192613233413015, 0.03346113680994936, 0.0718498695641756, 0.08345076920730726, 0.042847508498068364, 0.018334514927119017, 0.05200703914410301, 0.19090383260377816, 17.120865072522843, 45.244956493377686, 45.70192561830793, 49.23804106031145, 43.15412194388253, 49.882253714970176, 71.30018356868199, 34.0094518661499, 0.1221086462693555, 3.6629274487495422, 18.389812844140188, 65.156676701137, 69.67497907366071, 70.63246168409074, 68.26376519884381, 71.47122737339565, 73.42699241638184, 65.26615946633476, 67.10081045968192, 68.7173158100673, 65.79459081377301, 64.36581884111676, 73.5301592690604, 71.83884266444615, 64.26789787837437, 63.17371640886579, 59.16006170000349, 59.41509532928467, 58.27184568132673, 55.90437207903181, 58.26305621010916, 56.9717196055821, 56.47302654811314, 57.61321204049246, 53.40731804711478, 45.94109998430525, 43.08462953567505, 45.97221054349627, 45.89966440200806, 45.20511899675642, 43.49605669294085, 44.21181147439139, 44.207725933619905, 43.49290221078055, 40.92956583840506, 40.84008346285139, 42.2389886038644, 40.761266572134836, 43.41120529174805, 43.52103894097464, 48.89104454857962, 45.332097326006206, 40.85896519252232, 35.467475754874094, 40.12727471760341, 38.58917284011841, 23.681123154503958, 32.62954657418387, 37.24474157605852, 45.569475582667756, 40.161643981933594, 35.78978531701224, 37.65983738218035, 37.96864659445626, 37.1057185445513, 35.521352086748394, 36.885641302381245, 36.3064603124346, 36.039149216243196, 38.444685050419395, 38.74356528690883, 41.136153153010774, 41.562289646693635, 46.36611434391567, 45.57309559413365, 41.56088611057827, 38.07648263658796, 41.50097526822771, 39.0208227293832, 39.69413096564156, 37.97619233812605, 40.501872948237825, 34.62369694028582, 42.0297783442906, 47.88115862437657, 50.46034036363874, 46.004425866263254, 45.618401323046, 48.67434065682547, 42.77855096544538, 37.678663526262554, 37.972415992191856, 35.83342695236206, 37.030226366860525, 36.02670499256679, 35.37743404933384, 34.68885367257254, 35.7865891456604, 37.692514760153635, 40.467170170375276, 43.550481932503835, 43.004638399396626, 42.6269655908857, 43.312057971954346, 37.818270206451416, 31.95560952595302, 36.832491057259695, 46.29559012821743, 40.22896160398211, 40.071355615343364, 42.27127340861729, 40.23274837221418, 41.20619446890694, 39.49706268310547, 37.50112662996565, 40.104165009089876, 39.076943329402376, 43.66430732182094, 41.657552923474995, 42.49321971620832, 40.61502436229161, 41.69444785799299, 41.36383867263794, 43.90420082637242, 41.26853370666504, 43.44679396493094, 43.17262152263096, 43.76544182641165, 41.992671489715576, 44.16562679835728, 43.293818950653076, 45.08781255994524, 44.097656045641216, 46.788523129054475, 48.15031794139317, 51.839686325618196, 53.400772844042095, 60.61105401175362, 61.49539988381522, 65.54865237644741, 65.35971001216343, 64.577773639134, 61.928995268685476, 65.59667832510812, 64.21262495858329, 66.52160167694092, 67.54592595781598, 33.65272440229143, 0.7347222779478345, 0.14904233387538365, 0.3514716130282198, 11.897634949002947, 64.57034601484025, 52.39864458356585, 48.32890401567732, 26.50000558580671, 34.157649993896484, 23.31349570410592, 33.7421372958592, 26.289930275508336, 0.6191207553659166, 0.05863763924155917, 0.035850574129394124, 0.008062126630518054, 0.0538498520451997, 0.02571413286828569, 0.09492814155029398, 0.031781562470964024, 0.15114343113132886, 0.023035378394914523, 0.08225308026054076, 0.03591658540868333, 0.05272768743868385, 0.0968386654609016, 0.03588456194847822, 0.04020009216453348, 31.371794087546213, 54.016317231314524, 53.10318497249058, 46.423006193978445, 48.13491031101772, 57.983130659375874, 76.8993616104126, 38.0459383555821, 0.22662187527332986, 7.890329156603132, 25.737984486988612, 70.52980204990932, 70.66638278961182, 74.2959063393729, 69.20512104034424, 73.84045886993408, 75.04670783451625, 67.43945176260812, 67.92957074301583, 71.35635280609131, 66.81968634469169, 66.69957283564976, 71.15188121795654, 72.23693970271519, 67.06841100965227, 65.25265216827393, 62.0933062689645, 62.785784585135325, 61.38897432599749, 58.15786395754133, 60.349940708705354, 58.72600078582764, 59.108304568699424, 60.558998107910156, 55.83064821788243, 49.72584629058838, 44.77213157926287, 48.812154701777864, 47.007474763052805, 47.86025844301496, 46.79102100644793, 45.53551626205444, 45.984891005924766, 46.357321398598806, 43.672523566654746, 44.476190430777415, 45.05023670196533, 42.17777844837734, 44.76489850452968, 45.41258525848389, 49.43228490012032, 45.27751227787563, 42.4863166809082, 37.705282075064524, 43.25596169063023, 42.149193559374126, 27.00154219354902, 35.89437655040196, 37.572519370487754, 46.35614367893764, 42.6623284476144, 38.733292375292095, 40.20464290891375, 40.22732877731323, 38.625980922154014, 37.89626373563494, 39.96548243931362, 39.411495617457796, 38.39012084688459, 39.37814426422119, 40.20339570726667, 42.77505602155413, 43.515237195151194, 48.16940464292254, 47.75509398324149, 44.255678926195415, 40.71899373190743, 43.25213670730591, 41.51594168799264, 42.22095455442156, 41.67409658432007, 42.04272978646414, 38.535136699676514, 45.316842555999756, 51.01002972466605, 52.727888447897776, 49.271135330200195, 47.805291243961875, 49.08802250453404, 43.011746406555176, 40.39584343773978, 39.69452701296125, 36.755039487566265, 39.747600827898296, 37.38230201176235, 37.25336429050991, 35.994187423161094, 36.78146348680769, 40.07155016490391, 41.289882046835764, 42.83821167264666, 43.475278105054585, 44.04076419557844, 43.024941035679404, 38.72288049970354, 35.324398449489046, 38.409853730882915, 46.111042499542236, 42.010917459215435, 41.475002901894705, 44.14254140853882, 43.7116037096296, 43.05235515322004, 41.37277405602591, 39.905606337956016, 42.15200410570417, 40.886830942971365, 43.853989669254844, 43.23413045065743, 42.42934840066092, 42.62541266850063, 43.910311767033164, 44.473480633326936, 44.60486759458269, 44.53742490495954, 44.57352774483817, 45.87048544202532, 45.497401918683735, 45.306621755872456, 46.45073298045567, 46.08751589911324, 47.29876061848232, 47.40415089470999, 48.99207135609218, 50.18811341694423, 54.04944624219622, 57.68861041750227, 63.59272057669503, 62.83636747087751, 67.02510983603341, 69.26829406193325, 67.17554528372628, 66.60496616363525, 67.92711802891323, 66.6612604686192, 68.36108861650739, 70.98540932791573, 42.63885395867484, 0.6307026424578258, 0.08947774115949869, 0.27658927547080175, 12.912690332957677, 72.02808380126953, 58.30344608851841, 57.75117547171456, 32.2463812146868, 41.866905621119905, 34.75652912684849, 45.912793023245676, 30.105391093662806, 0.9937263684613364, 0.1122840970222439, 0.043802834914198945, 0.05605883636911001, 0.04063764547130891, 0.034528994866247685, 0.02051929590691413, 0.34811585023999214, 0.358406946595226, 0.07429913670888968, 0.14567319037658827, 0.15168684268636362, 0.2178826563592468, 0.16607574772621903, 0.12426364634718214, 0.32513004222086495, 41.8809027671814, 64.09020464760917, 57.664236136845176, 65.3798667362758, 58.490206718444824, 64.75987897600446, 83.31464726584298, 43.41397762298584, 0.25421412182705744, 8.822670578956604, 27.389897857393535, 74.2785427910941, 73.40913554600307, 77.83562442234584, 71.40976360866001, 75.45583166394914, 77.31574630737305, 70.58103111812046, 72.4584413255964, 73.07681710379464, 68.82964733668736, 68.38656766074044, 75.12496539524624, 71.30818789345878, 69.51116139548165, 68.60402543204171, 64.88878890446254, 65.48076152801514, 64.94952310834611, 62.451152392796104, 64.291855267116, 61.06718935285296, 61.05175045558384, 62.975442613874165, 58.95889745439802, 51.711016110011506, 48.61741753986904, 52.90539060320173, 50.24748229980469, 50.90034893580845, 48.18507283074515, 48.96528605052403, 47.57535103389195, 49.49766050066267, 45.674959659576416, 46.06552832467215, 47.72569962910244, 46.30719709396362, 48.435044697352815, 50.00699125017439, 53.04692193440029, 45.268767969948904, 46.16206659589495, 41.135024070739746, 43.95514154434204, 45.85311494554792, 33.74278000422886, 40.24874312537057, 39.034729548863, 47.503951345171245, 46.62232916695731, 40.32152203151158, 42.90042584283011, 43.392486844744, 42.29244456972395, 40.6917359488351, 42.03703573771885, 41.461874280657085, 42.04948690959385, 40.998377323150635, 43.11243622643607, 46.942165170397075, 46.99269247055054, 51.49983603613717, 50.0894489969526, 47.23510469709124, 43.052382946014404, 44.01290191922869, 46.542483942849294, 45.939682551792686, 43.80762434005737, 44.047354561941965, 41.630864892687114, 47.63051973070417, 55.23879023960659, 54.55948918206351, 52.397056920187815, 50.19014923913138, 53.42713778359549, 46.75961514881679, 43.07156344822475, 42.65726668494088, 40.93385982513428, 42.74059990474156, 39.22996350697109, 39.47410236086164, 39.991600717817036, 41.272834641592844, 41.06276627949306, 43.348237242017476, 45.5851229258946, 44.87714665276663, 43.84253208977835, 45.63249921798706, 41.083812373025076, 38.2701358795166, 40.47061995097569, 47.997787611825125, 42.01038939612252, 41.96100854873657, 45.139058998652864, 44.48414611816406, 46.08602898461478, 44.76174749646868, 42.6528754234314, 43.725322927747456, 44.245406014578684, 47.59892974581037, 45.01299435751778, 46.018249307359966, 44.90584966114589, 45.56794350487845, 47.16452489580427, 48.99901608058384, 46.48690182822091, 48.24321188245501, 48.73207671301705, 47.630839347839355, 47.58154535293579, 49.17334638323103, 48.13619225365775, 49.148416246686665, 49.59526184626988, 50.3138758114406, 53.307396003178184, 56.542772565569194, 60.340664863586426, 66.87578610011509, 65.96694782802037, 70.38803795405796, 70.48110907418388, 70.76212896619523, 70.72489356994629, 68.77524988991874, 71.34501334599086, 71.64778109959194, 76.35761751447404, 48.168466636112754, 0.941726701600211, 0.29483228655798094, 0.39109005140406744, 16.38252690860203, 80.19305092947823, 64.8812917981829, 67.95261096954346, 42.160407951899934, 55.67032895769392, 45.162325041634695, 60.50691441127232, 37.65121119362967, 1.5443373428923743, 0.20845829349543366, 0.1140573261571782, 0.1336842772683927, 0.1330183901424919, 0.11258512229791709, 0.1688022507088525], [0.019760931243321726, 0.03083451757473605, 0.02008223793070231, 0.13160132403884614, 0.052905103990009854, 0.04685122812432902, 0.06131889072379895, 0.08726918431265013, 0.14849774166941643, 32.53782687868391, 43.19871548243931, 31.319230965205602, 18.63231713431222, 46.90925850187029, 51.244576590401785, 73.48605905260358, 17.924042088644846, 0.16828283215207712, 3.3444849933896745, 30.95365149634225, 75.32902009146554, 65.27708203451974, 72.72702394212995, 71.37115941728864, 74.12457765851701, 69.5061308997018, 67.8765629359654, 61.93408829825265, 62.97505351475307, 62.94626712799072, 66.96568189348493, 53.44344520568848, 50.62440817696707, 63.059897967747276, 63.36217934744698, 61.76252337864467, 58.80721827915737, 58.73235838753836, 59.79072189331055, 59.92030579703194, 61.784708976745605, 61.095690863473074, 59.72278935568673, 60.976258277893066, 56.13736949648176, 46.54399517604283, 45.97710902350289, 45.83124549048287, 43.74201944896153, 44.31078161512102, 43.88579157420567, 46.334597315107075, 44.77830157961164, 39.9795560155596, 40.1562556539263, 40.558375699179514, 40.92045327595302, 46.083214964185444, 43.485026427677695, 49.85348469870431, 43.18974535805838, 42.55455493927002, 27.928857462746755, 41.29417603356497, 34.58268172400338, 26.22657138960702, 41.73344462258475, 42.523051806858604, 37.34002569743565, 44.83875438145229, 36.87071657180786, 36.148096970149446, 35.985495226723806, 35.87262521471296, 37.756108147757395, 36.293310846601216, 36.44994061333792, 35.33049201965332, 34.47617973600115, 34.16894429070609, 38.32673937933785, 37.53833075932094, 36.469649178641184, 37.00137744631086, 38.42430598395211, 37.703138555799214, 39.45420272009713, 38.5211569241115, 39.13554443631853, 37.403532232557026, 38.64938245500837, 34.89859894343785, 36.17412492207119, 40.87253849846976, 40.15827063151768, 42.367783887045725, 41.259723390851704, 38.76224551882063, 36.675420079912456, 35.87246888024466, 37.37048660005842, 35.78106880187988, 36.292254720415386, 37.62789303915841, 36.08424997329712, 36.15180035999843, 40.95873785018921, 37.14177622113909, 38.027563844408306, 40.77229336329869, 37.63447993142264, 41.01940952028547, 36.86357034955706, 33.99847718647548, 39.89921052115304, 40.86366217476981, 42.09896503176008, 41.52941424506051, 38.82655457087925, 42.386314732687815, 40.6399371283395, 40.65014055797032, 38.90720578602382, 37.86082444872175, 39.053892680576865, 40.299763747623985, 42.98090335300991, 40.61316919326782, 41.71570587158203, 41.463649545397075, 40.85747480392456, 41.624913760593955, 42.11082213265555, 41.169323853084016, 42.71015984671456, 42.707825251988, 42.97887795312064, 44.437422956739155, 42.26981428691319, 44.79269824709211, 46.46411173684256, 45.52462496076311, 52.46728236334664, 54.1140193258013, 57.93538958685738, 61.42971856253487, 62.19108826773507, 63.093436922345845, 63.086308070591514, 60.50014686584473, 70.14580290658134, 69.76550020490373, 60.644078799656455, 62.49811526707241, 66.10685675484794, 66.46438326154436, 47.53210197176252, 0.16838248180491583, 0.1710612294929368, 0.19238572594310555, 6.2965357303619385, 61.73785032544817, 54.13258491243635, 51.702070304325645, 31.546426636832102, 20.05370490891593, 22.822671481541224, 33.71201685496739, 32.83555371420724, 1.9453312371458327, 0.04352094432605164, 0.027092994057706425, 0.03934206427740199, 0.0039453838502855176, 0.029826703082237924, 0.03617008948432548, 0.028808452721152986, 0.07034103838460785, 0.027118791959115436, 0.11562200076878071, 0.026611169733639275, 0.06237551224018846, 0.02973854781261512, 0.06390877068042755, 0.4949366876057216, 46.123799392155235, 50.51068353652954, 36.92514181137085, 28.731589794158936, 53.9888961655753, 58.690822056361604, 80.09119033813477, 18.768675531659806, 0.2531627453863621, 3.189662192549024, 35.091609477996826, 80.16787065778459, 67.84208597455705, 77.96706349509103, 69.26100540161133, 77.54393904549735, 70.29728058406285, 70.69570418766567, 63.37162889753069, 65.15917805262974, 65.52688367026192, 70.40359497070312, 54.41616868972778, 47.33258097512381, 60.85906301225935, 66.92475005558559, 65.02390357426235, 62.76093087877546, 61.68376554761614, 62.41142954145159, 61.36168875013079, 63.61573301042829, 61.9398900440761, 61.43973091670445, 62.17512130737305, 59.68583188738142, 49.519995485033306, 47.27251727240426, 47.12382582255772, 46.88258784157889, 44.96313755852835, 45.43759529931204, 49.07819775172642, 46.665366309029714, 43.59964738573347, 42.36142975943429, 43.94983312061855, 42.98752498626709, 45.13818005153111, 46.46048130307879, 49.81991447721209, 43.48294196810041, 44.88019691194807, 30.350801467895508, 43.94599771499634, 38.54553467886788, 30.938094479697092, 43.28798246383667, 45.24009622846331, 38.35002279281616, 47.99880204881941, 39.915528365543906, 37.91272749219622, 38.4836540222168, 38.44446965626308, 39.8675718988691, 39.30960028512137, 38.333593777247835, 36.355872426714214, 36.03486565181187, 38.07621513094221, 40.945751667022705, 39.61707891736712, 39.38132653917585, 38.59687144415719, 38.97396060398647, 41.6021271433149, 40.06214925221035, 39.616880893707275, 40.97778633662632, 40.69133642741612, 41.44857542855399, 36.87167542321341, 38.583895683288574, 43.57891048703875, 42.880203110831125, 43.372969354902, 43.931194577898296, 39.354051385607036, 39.66501801354544, 37.884899956839426, 38.907514980861116, 38.873239517211914, 38.09189026696341, 39.66697045734951, 38.71239219393049, 38.47561495644705, 42.33345978600638, 37.84890133993966, 39.08996425356184, 41.73710284914289, 39.09636007036482, 41.386430740356445, 38.29758473805019, 36.632671288081575, 42.73760175704956, 42.723840849740164, 42.22511999947684, 42.32815831048148, 40.68963064466204, 43.624518462589805, 42.089345250810894, 40.612529958997456, 40.03965793337141, 39.8827919278826, 40.70155027934483, 41.847568784441265, 45.16286352702549, 43.9069801058088, 42.77738019398281, 44.04099348613194, 42.795417717524934, 43.57032251358032, 45.37158741269793, 43.8872263772147, 44.94649314880371, 45.0099058832441, 45.88576800482613, 46.603169509342735, 45.395937374659944, 47.21919332231794, 49.47929988588606, 47.34551852090018, 53.99698386873518, 57.8600572177342, 60.84802232469831, 61.60752991267613, 64.32630443572998, 63.43538556780134, 65.70912797110421, 63.424310139247346, 70.0467563356672, 72.72555787222726, 63.837137358529226, 66.82529354095459, 69.56193883078438, 68.61431571415493, 54.0825891494751, 0.43390837950365885, 0.172546135527747, 0.2727491743862629, 6.47309683901923, 69.05679784502301, 60.59683799743652, 61.59045818873814, 36.735678332192556, 28.119675840650284, 35.458644594464985, 42.691882610321045, 40.98950447354998, 2.608212615762438, 0.1813854926398822, 0.04945352187912379, 0.07692981697618961, 0.07305977892662797, 0.024765120220503638, 0.08812441663550478, 0.08933368138968945, 0.25123253038951326, 0.14687254173415049, 0.20591842835502966, 0.09876469389668532, 0.13733468710311822, 0.1193883858088936, 0.18636120350233146, 0.7219834072249276, 53.4417359488351, 63.91875089917864, 44.5097849709647, 29.37630271911621, 65.15646825517926, 63.59971046447754, 88.0456895828247, 23.165511233466013, 0.3116638090993677, 7.514467222349984, 40.83318737574986, 80.58231680733817, 70.81810365404401, 80.41845743996757, 75.18084975651333, 79.46548421042306, 73.0240455354963, 70.79487582615444, 66.30718721662248, 70.73391927991594, 68.30031272343227, 70.49850041525704, 61.54484326498849, 51.59154183523995, 62.941785539899556, 68.58611992427281, 66.09269632611955, 66.43690313611711, 64.40738991328648, 65.26620115552629, 62.793031556265696, 65.45045348576137, 63.10611738477434, 66.04264150347028, 64.76660483224052, 61.90949167524065, 50.77043499265398, 51.378193923405235, 49.72944893155779, 48.47787686756679, 48.454451016017366, 47.77182871954781, 51.69191203798567, 50.58623824800764, 47.11309780393328, 44.71785920006888, 44.86775963647025, 45.940161977495464, 49.33466618401663, 49.232736110687256, 54.69779307501656, 43.69475432804653, 47.41347190311977, 35.068763801029746, 46.79471397399902, 40.8841141973223, 35.84037167685372, 45.69962576457432, 44.596620082855225, 36.45847300120762, 51.175546237400596, 44.12612281526838, 40.3913687978472, 40.12927579879761, 41.18660749707903, 43.94360753468105, 41.939708845955984, 42.16496249607631, 39.43538005011422, 39.067347867148264, 40.5045097896031, 45.517176491873606, 41.793907846723286, 42.55613565444946, 41.56010443823678, 40.90559107916695, 44.16835396630423, 45.204712527138845, 43.3452182497297, 44.44432251793997, 43.39145156315395, 44.61813865389143, 39.304201534816194, 41.12892355237688, 46.26932941164289, 45.06274693352835, 48.3590453011649, 46.72209140232631, 44.00287914276123, 42.04492541721889, 40.065352371760774, 41.562254905700684, 40.226248332432334, 41.64238153185163, 42.15253564289638, 41.024231570107595, 40.75327614375523, 46.62693929672241, 38.75414044516427, 40.575440474918906, 42.41726548331124, 40.39108739580427, 43.704492228371755, 40.67947932652065, 39.03646659851074, 44.21614020211356, 42.22442517961775, 42.2844089780535, 42.981577328273225, 42.87896980558123, 47.97134624208723, 43.43720197677612, 43.76367003577096, 44.434661047799246, 43.29888766152518, 44.720523834228516, 43.44921888623919, 47.98849787030901, 46.464417457580566, 46.402238028390066, 46.067598887852256, 46.05129493985857, 46.188431535448345, 47.12410027640206, 46.16252170290266, 48.17811073575701, 47.21223817552839, 47.74680478232247, 50.18125901903425, 47.955900396619526, 50.56000532422747, 51.38012899671282, 49.93430267061506, 57.049865995134624, 59.96605273655483, 62.815710476466585, 63.9639002936227, 66.9375694819859, 68.5866618837629, 68.35534245627267, 67.31254986354283, 70.75994028363908, 72.46134567260742, 69.17779377528599, 69.30753748757499, 75.97898932865688, 74.62879453386579, 61.282201358250205, 1.0090680995157786, 0.4254102440817015, 0.4345796134855066, 7.930161442075457, 77.17764391217912, 66.20945385524205, 70.31205245426723, 48.85099860600063, 30.880507809775217, 40.874292918613975, 58.14382859638759, 49.140894821711946, 3.647685272353036, 0.31291247638208525, 0.1793733648955822, 0.17027095332741737, 0.1804894328649555, 0.13467390702239104, 0.18564671969839505], [0.027120031981862018, 0.061742567989443026, 0.06181761396250554, 0.06583410701049225, 0.03531281477106469, 0.016392393337030495, 0.0063012179951848725, 0.08144344549093928, 0.6860879819308008, 43.53379930768694, 44.8284467288426, 37.01721239089966, 24.008008105414255, 51.571986130305696, 51.225350924900596, 75.790130342756, 10.779727118355886, 0.09156511165201664, 0.16818557094250405, 37.370180879320415, 79.04062271118164, 62.94819177900042, 74.87057100023542, 65.58868789672852, 71.54416261400495, 67.31935214996338, 68.0855439049857, 63.45768928527832, 66.29160240718296, 63.24645015171596, 68.65244742802211, 57.33039256504604, 35.95547900881086, 47.37252964292254, 61.26027979169573, 64.31693826402936, 63.12949112483433, 61.74275575365339, 62.27864946637835, 59.854554993765696, 61.17481000082833, 61.682646887642996, 59.50842353275844, 58.18676151548113, 61.65771675109863, 52.492455686841694, 43.10512324741909, 44.68231916427612, 45.638651847839355, 42.57615341459002, 44.822815213884624, 44.23422288894653, 44.12055035999843, 41.58307865687779, 40.20055736814226, 40.39224427086966, 42.075841426849365, 40.19403995786394, 41.98671340942383, 43.565830503191265, 44.94137232644217, 44.68266657420567, 37.32709162575858, 37.75877625601632, 36.797444343566895, 34.686671938214985, 37.451440061841694, 40.80045441218785, 39.59174925940377, 38.37930597577776, 42.069452558244976, 37.02767637797764, 39.350233350481304, 35.67426456723894, 36.59157269341605, 36.54471056801932, 35.11641107286726, 34.851872307913645, 36.827140944344656, 34.95749882289341, 34.85244900839669, 36.509222643715994, 36.43691968917847, 36.86267403193882, 38.192628724234446, 36.99359198978969, 40.865642411368235, 38.62910761151995, 39.53605597359793, 35.68219246183123, 37.261549268450054, 36.17523315974644, 35.42872217723301, 34.271183558872764, 35.77427346365792, 35.663487911224365, 35.53484548841204, 36.88842405591692, 36.022334575653076, 35.41777876445225, 38.12143053327288, 35.50121620723179, 35.581242084503174, 35.081479004451204, 35.982347692762104, 41.20101458685738, 37.96149342400687, 36.63360234669277, 35.53538049970354, 44.509847504752024, 41.415790353502544, 34.46366950443813, 40.567988531930105, 34.23905856268746, 36.11168146133423, 41.320256096976145, 41.10651561192104, 39.7502098764692, 42.425297600882395, 43.36786937713623, 38.774377073560444, 39.51005581447056, 38.457292556762695, 36.96601806368147, 35.30417571749006, 40.96990360532488, 44.13580513000488, 41.965684686388286, 42.9892064503261, 42.926009110042024, 47.544796330588206, 48.170759541647776, 49.32704748426165, 49.29791716166905, 49.459532260894775, 48.131630761282786, 49.04819195611136, 47.45662369046892, 47.528450693402974, 46.97497109004429, 48.277091298784526, 51.35392733982631, 58.34125818525042, 57.684688159397666, 58.787895338875906, 59.60296072278704, 59.58563191550118, 59.34949738638741, 67.43349020821708, 77.59037385668073, 69.74094527108329, 60.858896255493164, 60.40533869607108, 58.9592170715332, 67.76331424713135, 61.809458460126606, 62.08495453425816, 1.3221316720758165, 0.49006632609026773, 0.06477020481335265, 1.966784234557833, 54.88583564758301, 55.948649474552695, 53.598928519657676, 32.62822641645159, 33.14083671569824, 28.84304584775652, 33.11385686056954, 34.232200690678184, 2.4518536116395677, 0.26651566315974506, 0.03728952638006636, 0.05017249079953347, 0.0312408854120544, 0.051999504012720923, 0.051991894242486784, 0.039346481540373394, 0.04469211951696447, 0.09953525183456284, 0.036634085300777636, 0.027844649706301943, 0.05869084995772157, 0.04798501942838941, 0.12128361554018088, 1.5745087010519845, 51.940650599343435, 50.583333900996614, 42.92264270782471, 29.22817407335554, 58.79712949480329, 59.06703921726772, 81.656008039202, 11.367820041520254, 0.17567526761974606, 0.13881154571260723, 41.97291776112148, 82.73672389984131, 66.60648087092808, 75.8106553213937, 67.82379831586564, 72.56201117379325, 69.45208086286272, 69.78002888815743, 64.36205291748047, 65.7776927947998, 66.36614268166679, 70.85929257529122, 61.154208592006135, 39.08715718133109, 47.67370278494698, 64.53491020202637, 66.42679350716728, 65.51373767852783, 63.23799419403076, 62.819518089294434, 61.45569092886788, 63.96436582292829, 64.06925582885742, 61.47631318228585, 59.19053649902344, 62.78237301962716, 54.00349085671561, 45.04170083999634, 47.18895476205008, 45.435298919677734, 45.05868918555123, 46.19574104036604, 44.728608063289094, 48.258129664829795, 43.75457484381539, 43.65981878553118, 42.25175244467599, 43.387286118098665, 41.57121808188302, 44.12363536017281, 47.578290121895925, 48.295990398951936, 45.33949020930699, 40.48520769391741, 39.75764444896153, 40.303050245557515, 38.390346663338796, 40.494987283434185, 43.19194793701172, 39.85038552965437, 39.88042606626238, 44.49535008839199, 39.12243318557739, 41.13520124980381, 38.74452761241368, 39.90234068461827, 39.36957366125924, 38.91593272345406, 36.61611025674002, 39.2985873903547, 38.122372014181956, 38.454634870801655, 37.80695159094674, 38.650806835719514, 40.007154260362896, 40.99074820109776, 40.04429933003017, 42.06617995670864, 39.764947005680625, 41.47829982212612, 38.485616888318745, 39.95558820452009, 39.42851175580706, 37.877267360687256, 38.12780897957938, 39.238440309252056, 38.97348812648228, 38.150230816432405, 38.13492740903582, 37.61966289792742, 38.69462217603411, 37.882085936410085, 37.53810146876744, 37.0889629636492, 38.84716640199934, 39.2215700830732, 44.46301664624895, 37.52334002086094, 36.437381744384766, 36.17566742215838, 44.53266886302403, 42.364070074898855, 34.96188661030361, 41.07997349330357, 36.53510815756661, 37.45292002814156, 42.19847365788051, 41.44650139127459, 40.870221274239675, 44.807845320020405, 44.77072804314749, 39.496201106480186, 41.725940568106516, 40.736739431108745, 40.1353554725647, 38.42248208182198, 44.03665086201259, 46.94917242867606, 44.82612255641392, 44.5309213910784, 44.31353657586234, 49.21893351418631, 51.58827270780291, 53.39163596289498, 50.9989994594029, 52.52870096479143, 50.1309540612357, 52.37498249326433, 51.22581992830549, 49.67362362997872, 49.90894521985735, 51.22110210146223, 55.622501032693044, 60.04940332685198, 60.580579212733674, 61.50949777875628, 61.8488894871303, 63.06493541172573, 61.62578283037458, 66.03493595123291, 75.2366646357945, 70.92824649810791, 63.71619006565639, 64.81586061205182, 60.15970597948347, 71.58882563454765, 64.16220188140869, 69.13059466225761, 3.941516774041312, 0.610461345740727, 0.05630782140152795, 1.8799584593091692, 63.07390553610665, 61.04374613080706, 63.55276843479702, 38.777611460004536, 37.64824431283133, 40.84118822642735, 44.6921717098781, 44.84545244489397, 3.5557215213775635, 0.20858916932983057, 0.08253410232386418, 0.01289787098565804, 0.05127536804814424, 0.018634083048839654, 0.040902107887502225, 0.06673910987696477, 0.15162760657923563, 0.203570656478405, 0.09234127428914819, 0.08881462245647397, 0.26669634346451077, 0.07728728279471397, 0.3184277447206633, 2.1402998609202246, 66.47675800323486, 60.85349750518799, 51.66246904645647, 36.94480173928397, 69.83958884647915, 63.15727002280099, 90.98677866799491, 13.529891865594045, 0.34685464363012997, 0.5826879846198219, 43.69087028503418, 87.87232507978166, 70.7622401373727, 79.44750922066825, 70.19815063476562, 77.55905137743268, 73.47210012163434, 73.23244980403355, 67.03631033216203, 70.0795796258109, 69.41784708840507, 73.8106302533831, 63.66647570473807, 41.95290347508022, 50.73213652202061, 64.582852772304, 69.508590562003, 67.32283319745744, 65.53653471810478, 65.78994246891567, 62.79469912392752, 66.6766437802996, 65.51862226213727, 63.14028862544468, 62.98997824532645, 66.63665689740861, 55.649675437382285, 46.27596494129726, 48.626033306121826, 47.58709348951067, 45.82663536071777, 46.52347019740513, 47.987865584237234, 50.01125744410923, 46.39555386134556, 47.20434849602835, 44.67832395008632, 46.24312775475638, 43.902957098824636, 46.32412985392979, 49.87999555042812, 48.79365859712873, 47.23868996756417, 46.060421398707796, 44.84433031082153, 44.27991771697998, 40.851714747292654, 43.884158747536794, 44.201639311654226, 41.46004343032837, 40.84071922302246, 47.98702137810843, 44.395341191973, 44.1970465523856, 41.25771188735962, 43.119269779750276, 42.312431062970845, 39.68870789664132, 38.82382392883301, 41.01744318008423, 41.57980605534145, 38.227605955941335, 41.6228848866054, 40.304137638636995, 43.168456077575684, 42.74438667297363, 42.77615731103079, 46.347183976854595, 41.9450798034668, 43.53961147580828, 41.54641996111189, 41.531634194510325, 40.5131186076573, 40.19572837012154, 39.414413860866, 40.22352116448538, 42.5633305140904, 40.965112822396414, 39.56547464643206, 39.970537253788535, 40.90531315122332, 41.722775663648335, 40.357638767787385, 39.04974113191877, 41.33177968433925, 41.230190072740825, 46.069426264081685, 39.84171765191214, 36.9543833051409, 37.44153887884957, 46.534191267830984, 46.00014577593122, 38.18630586351667, 43.511155128479004, 38.52432877676827, 39.07021747316633, 43.353243419102256, 41.445813519614084, 42.09282629830496, 46.48914609636579, 47.40009314673287, 42.60272332600185, 45.18220383780343, 44.78207445144653, 42.53009728022984, 40.71129512786865, 47.48789753232683, 49.467164857046946, 47.11339657647269, 47.40257017953055, 47.26137931006295, 51.4447020803179, 55.98440490450178, 54.97491502761841, 53.199573857443674, 55.827723026275635, 51.87241234098162, 54.36156627110073, 53.42714473179409, 52.96265765598842, 51.90691362108503, 54.503663880484446, 56.87496594020298, 62.68368080684117, 62.106903893607004, 64.42717838287354, 65.74653012411935, 66.44027301243374, 64.91047423226493, 66.55452224186489, 71.82647487095424, 70.73927634102958, 71.02638980320522, 66.78058883122036, 63.754307883126394, 75.4321938923427, 67.53305789402553, 73.6698250089373, 4.0449085746492655, 0.6209333123905318, 0.27664002989019665, 2.6198521511895314, 71.16579845973423, 68.2072902406965, 71.34764671325684, 48.83650813783918, 53.14411333629063, 46.839519432612825, 55.15716627665928, 56.25619411468506, 4.829321111951556, 0.33987767515437944, 0.10117192579699413, 0.15136357503277914, 0.1503184682556561, 0.10811779701284, 0.13704179067696842], [0.027667492694620575, 0.02061249778073813, 0.06804806499608926, 0.09986995280321155, 0.04730232499007668, 0.09320967019136463, 0.0862058995823775, 0.11661515890487603, 0.8309530913829803, 38.11648688997541, 38.375623430524556, 36.217617171151296, 25.355227334158762, 46.08858939579555, 57.167234965733115, 66.00001430511475, 8.235941239765712, 0.18179715983569622, 0.11865845854793276, 45.11915240968977, 76.90263421194894, 63.048350061689106, 69.03279181889125, 66.40411458696637, 69.14066260201591, 64.32240649632045, 65.54924297332764, 61.1983574458531, 63.68649346487862, 64.25555787767682, 65.04547773088727, 66.39641598292759, 66.77853911263603, 52.03203330721174, 55.56149237496512, 59.413344383239746, 61.54942907605852, 62.76484271458217, 63.35293129512242, 62.820692334856304, 63.83394118717739, 59.67825835091727, 59.55526828765869, 58.859677178519114, 59.80825914655413, 51.60586902073452, 43.74130031040737, 45.13024173464094, 45.87349053791591, 43.627196993146626, 43.01289633342198, 42.28250169754028, 43.10675607408796, 40.60417822429112, 41.76168557575771, 41.32792343412127, 41.21291337694441, 39.88986866814749, 39.87927961349487, 43.70097296578543, 46.57306643894741, 39.30022021702358, 44.37637260981968, 46.51247814723423, 43.77203566687447, 39.61381326402937, 33.89843354906355, 39.230053833552766, 39.606333528246196, 38.613574913569856, 39.15975890840803, 37.979867935180664, 37.795879636492046, 35.59506205150059, 34.54611335481916, 35.724857875279014, 37.050456047058105, 36.05965335028512, 37.077046803065706, 36.87860625130789, 39.4659868649074, 34.99873290743147, 36.997159889766145, 37.49135051454817, 38.98173563820975, 38.44691889626639, 36.862142494746614, 37.61231517791748, 38.36483982631138, 35.9573723929269, 37.71591281890869, 34.86146429606846, 36.564936774117605, 34.38592611040388, 33.39801039014544, 36.54372044972011, 36.59018305369786, 34.18203469685146, 35.55666283198765, 35.870776993887766, 35.92563302176339, 36.36786501748221, 36.89034523282732, 37.41117525100708, 39.71503462110247, 39.34661333901541, 35.38928072793143, 34.46631676810128, 36.95327506746565, 42.35329689298357, 43.7461119379316, 30.39458554131644, 38.540514605385916, 38.96241964612688, 37.30947099413191, 34.7606772014073, 39.88844428743635, 40.64370652607509, 39.52685308456421, 40.48385974339077, 37.74734994343349, 38.68982791900635, 37.43314892905099, 35.843831879752024, 37.14878347941807, 40.205000741141184, 40.746883801051546, 41.68699244090489, 43.28058958053589, 49.95675924846104, 52.37441274097988, 55.01005554199219, 52.92998375211443, 55.199751785823274, 56.156949520111084, 53.439748764038086, 53.03801434380667, 54.515444551195415, 53.51687376839774, 52.62676436560494, 55.01602751868111, 55.50468390328543, 56.80775948933193, 58.49008165087019, 61.84815992627825, 64.08872468130929, 67.95562648773193, 65.0662111554827, 67.92530454908098, 58.71136787959507, 61.28590474809919, 61.34044115883963, 62.128839356558665, 59.46305874415806, 65.94875049591064, 60.740603174482075, 77.42563206808907, 14.226541706493922, 1.2547913598162788, 0.2074409659419741, 0.7778221709387643, 47.8663763318743, 58.16166114807129, 52.599287714277, 35.34397847311837, 30.266221046447754, 23.891012600490026, 34.15958159310477, 38.200782435280935, 6.6168776495116095, 0.22130837610789708, 0.07117781455495528, 0.06641994057489292, 0.03921952763838427, 0.03249399709914412, 0.02899824914389423, 0.06519335960703236, 0.013813986559398472, 0.02937754343396851, 0.040933897253125906, 0.0582217379872288, 0.015124138444662094, 0.07486726050930363, 0.10345335051949535, 1.9817445746489932, 51.20574310847691, 45.57340478897095, 43.6545798437936, 28.05795325551714, 56.4004282951355, 62.97507435934884, 72.07241330827985, 9.415476986340114, 0.27209816074797083, 0.3774738891848496, 47.733328751155305, 79.9340637751988, 65.46391909463065, 72.90070111410958, 67.5103372846331, 71.82938616616386, 64.3134433201381, 67.33659757886613, 62.3647654397147, 65.44843850816999, 65.506990977696, 68.65317698887416, 66.65972491673061, 66.12647151947021, 54.367152622767854, 54.73337132590157, 60.28481524331229, 63.40206200735909, 66.03766659327916, 65.03659793308803, 64.72908455984933, 66.35266317640031, 61.316039085388184, 60.35869543892996, 60.730097498212544, 61.802954946245464, 53.37334483010428, 45.82190711157662, 46.05722522735596, 47.012404509953086, 45.39447477885655, 45.894998686654226, 45.020835399627686, 45.957278864724294, 42.39093181065151, 43.22066484178816, 43.48424475533621, 43.036888463156565, 42.668446336473735, 42.86706059319632, 45.01862587247576, 48.617466177259175, 40.24793366023472, 44.74125378472464, 48.535185609545024, 49.01510463442121, 40.90902696337019, 37.874616622924805, 40.49580717086792, 39.12884289877755, 37.72434793199812, 42.320484025137766, 41.57793698992048, 38.22452790396554, 37.22612040383475, 36.95265667779105, 37.80771589279175, 39.43400778089251, 38.739434582846506, 39.03101921081543, 38.73463337762015, 40.7910396030971, 36.9502352305821, 39.30008820125035, 39.48813077381679, 40.29482357842581, 39.342826570783345, 37.906025954655235, 41.55633504050118, 40.891357694353374, 37.12188352857317, 38.11312396185738, 38.86326537813459, 39.43220124925886, 37.90753023965018, 36.46411493846348, 37.78896965299334, 38.71290636062622, 36.10266964776175, 38.82047489711216, 37.16848162242344, 38.528278827667236, 38.77823679787772, 38.26942368916103, 38.48467193331037, 42.2170045035226, 39.699734687805176, 35.637317521231516, 36.503684929439, 36.41414696829659, 43.968273639678955, 45.455073492867605, 33.823396478380474, 40.28787537983486, 41.3268985748291, 39.30750887734549, 36.42215824127197, 39.55823114940098, 41.944541318076, 42.24166018622262, 40.936215264456614, 39.8762640953064, 41.32123926707676, 41.66598456246512, 39.38679129736764, 40.09999261583601, 42.466809613364084, 41.91528940200806, 43.17422308240618, 45.18520198549543, 52.597682680402485, 55.5206960269383, 56.15081078665597, 56.14704833711897, 57.523389203207834, 57.88048839569092, 55.99167619432722, 54.88419239861624, 55.75371776308332, 56.24882207598005, 55.57083075387137, 57.06966836111886, 57.63007531847273, 60.160129819597515, 60.41562897818429, 65.17828559875488, 65.75297110421317, 67.34563718523297, 65.14742864881242, 66.94344765799386, 63.43474633353097, 68.49346569606236, 65.1634303501674, 64.94752202715192, 60.91894258771624, 68.64502675192696, 61.385173661368235, 83.5287560054234, 19.264302696500504, 0.9340070358344487, 0.1680227361087288, 0.6026492906468255, 55.65424387795584, 66.16849422454834, 62.317594119480674, 43.720167364392964, 32.688679218292236, 34.83645078114101, 45.07888412475586, 47.67146546500069, 8.079287154333931, 0.2111105104642255, 0.11703846976161003, 0.0792687882536224, 0.024762658834723488, 0.008302356864857887, 0.009964748152664729, 0.15412701746182783, 0.11549337767064571, 0.15557421052030154, 0.19253166525491647, 0.2707737146743706, 0.1343439354428223, 0.25433625813041416, 0.16641302034258842, 2.8357176993574416, 65.36771433694022, 51.87919725690569, 47.477138246808735, 36.56749371119908, 65.48270007542202, 67.61933367592948, 80.41262790134975, 10.511497122900826, 0.37858942789690836, 0.8547338981713567, 54.72307062149048, 83.4684247970581, 69.26283277784074, 74.29876899719238, 71.62137794494629, 75.45775631495884, 67.69773714882987, 69.80236039842877, 65.45467104230607, 69.99765341622489, 69.20188317980084, 71.59516933986119, 69.34015233176095, 66.41997732434953, 53.39374474116734, 56.03729459217617, 62.65862560272217, 64.13354751041958, 68.21676758357457, 66.14535672324044, 65.63571330479213, 67.19399275098527, 63.5018242427281, 62.728552273341585, 63.94351427895682, 65.13482461656842, 56.006128447396414, 48.1017986706325, 46.83032349177769, 49.48153373173305, 47.74645389829363, 47.78092391150338, 45.85114860534668, 49.24471480505807, 46.43530103138515, 45.93626403808594, 46.79652745383126, 46.03985473087856, 45.66942541939871, 43.422471795763286, 46.543727670397075, 49.548910413469585, 40.74153021403721, 44.3930378641401, 50.28080586024693, 51.017266273498535, 43.07710811070034, 40.682484422411235, 41.1738714490618, 39.89028903416225, 38.1327908379691, 41.80881520680019, 46.21248272487095, 39.972527912684846, 39.268685817718506, 38.393476826804026, 40.67849268232073, 42.7545553616115, 43.0677558353969, 43.14807006290981, 40.49495949063982, 44.17939812796456, 40.246418952941895, 42.25752639770508, 42.312788895198274, 42.02482427869524, 42.56631823948452, 40.72474684034075, 43.672996044158936, 42.20261825834002, 39.56213256290981, 42.68354824611119, 41.64434092385428, 41.62129027502877, 40.9785714830671, 38.467443874904085, 41.62088033131191, 41.82922206606184, 37.845486300332205, 41.70643697466169, 40.99939176014492, 41.93375423976353, 41.261738368443076, 40.72750180108206, 41.86533880233765, 45.71688856397356, 40.61429132734026, 34.797162192208425, 36.615186146327424, 36.57793337958199, 45.746421882084434, 47.459333487919395, 39.672303199768066, 42.49180923189436, 43.237427370888845, 42.122300556727815, 38.288635458265034, 41.738551548549104, 43.29952342169625, 44.06586108888899, 44.25039829526629, 42.25751944950649, 44.328697545187815, 44.25950390951974, 41.39524800436837, 43.155608858381, 43.782166140420095, 44.744713987622944, 46.52743067060198, 47.868842942374094, 53.59867491040911, 57.7999518258231, 57.55533702032906, 56.4362462588719, 59.89060919625418, 62.70843029022217, 58.183436802455354, 58.39070156642369, 58.023999963487896, 58.86891828264509, 58.07970019749233, 60.498034613473074, 59.89113031114851, 62.84096717834473, 63.17749622889927, 67.90455027988979, 67.49136175428117, 69.20539896828788, 64.8334881918771, 69.38564218793596, 69.70874037061418, 71.70388780321393, 64.45386641366142, 70.1402929850987, 62.84970106397356, 74.76193591526577, 67.32362529209682, 88.79581710270473, 18.366225446973527, 1.2169584184885025, 0.5087264733655112, 1.0993671055350984, 61.601429394313264, 74.54784802028111, 68.29752649579729, 57.59457002367292, 55.0959734916687, 36.75219767434256, 56.39258030482701, 60.06177112034389, 9.894768936293465, 0.328144013349499, 0.2757505519049508, 0.16382584774068423, 0.13085933242525372, 0.181092216234122, 0.07941294301833425], [0.11694903884615217, 0.03994090196543506, 0.04775433787809951, 0.04229241596268756, 0.04347254781584654, 0.07524736225605011, 0.09993123808609587, 0.08446272954876934, 1.4377507822854179, 40.12957457133702, 40.45012623923165, 30.837057249886648, 22.166179622922623, 51.270875522068565, 54.93824243545532, 68.39525985717773, 6.4916137882641385, 0.03046779314588223, 0.03491255035623908, 37.81572369166783, 76.3698810849871, 60.848571232386995, 71.50901862553188, 60.12160900660923, 66.04262065887451, 61.77850423540388, 63.06419195447649, 60.18810326712472, 65.93981511252267, 64.16840662275041, 65.67099625723702, 63.65649809156145, 57.78808430262974, 64.8575359072004, 62.51378345489502, 61.17378861563546, 61.69277041299002, 59.9287964957101, 61.25951548985073, 61.18011842455183, 58.593651499067036, 57.389427934374126, 59.37392725263323, 57.07584878376552, 55.65162788118635, 48.99727208273751, 44.89330816268921, 45.874494552612305, 45.174123082842144, 43.84188938140869, 44.252969128744944, 42.975900650024414, 43.04469476427351, 41.17169318880354, 41.0588891846793, 40.29459776197161, 38.37040185928345, 39.094306877681184, 41.57896184921265, 41.32116283689226, 45.18586553846087, 42.023531913757324, 39.18149982179914, 47.81105130059378, 55.82269947869437, 47.06567634854998, 39.76359558105469, 37.77983972004482, 43.7104503086635, 41.17299597603934, 40.71137155805315, 41.07806968688965, 38.69538995197841, 38.6143079485212, 35.742961406707764, 35.78762790134975, 35.848796367645264, 35.60614095415388, 37.071651526859824, 35.92427464893886, 36.530258314950125, 34.218929631369456, 38.04039021900722, 35.58159644263131, 36.845817702157156, 38.55155529294695, 38.071219376155305, 38.485477924346924, 37.35799373899187, 37.486778599875315, 37.04005806786673, 37.4793301309858, 35.63042490822928, 36.17822435923985, 35.784956318991526, 36.02629157475063, 34.74494995389666, 35.18045261928013, 37.77464941569737, 36.403596128736226, 34.78414126804897, 35.92845399039132, 38.16756657191685, 39.91985361916678, 40.68298469270979, 36.60270023345947, 37.288185187748496, 36.517497948237825, 37.24678782054356, 41.09036799839565, 39.95910399300711, 41.410742487226216, 40.44877481460571, 38.750245979854036, 38.83791487557547, 35.1173733983721, 37.06500210080828, 36.70030157906668, 43.10210772923061, 38.11055660247803, 38.38662937709263, 37.3739572252546, 36.04647609165737, 37.05110570362636, 37.20219775608608, 38.88627086366926, 41.33075482504708, 39.74641268593924, 49.441456522260395, 53.997185366494314, 55.44419636045183, 51.36053507668631, 53.411834376198904, 53.878520556858604, 53.48568677902222, 56.76621273585728, 56.212208543504985, 55.11805139269148, 57.83943843841553, 56.06795351845877, 57.50034897668021, 56.13768911361694, 60.71770191192627, 59.37616457257952, 61.00949151175362, 58.79416956220354, 56.19877420152937, 54.75584874834333, 53.00597620010376, 56.36181715556553, 65.25894028799874, 69.86256653921944, 65.94000271388462, 57.48896087918963, 64.47316850934709, 65.00582436152867, 74.02565615517753, 42.673358712877544, 0.3925005357180323, 0.14294974080153874, 0.1519493136022772, 43.546038559504915, 59.2246104649135, 55.158712250845774, 41.08757829666138, 26.86749233518328, 24.418648379189626, 26.980079208101543, 41.051287855420796, 6.699579017502921, 0.20439363803182328, 0.032607105494077714, 0.05076307410906468, 0.023554774899301783, 0.02243734137820346, 0.012998288231236594, 0.034643694425800016, 0.06375002062746457, 0.005443147699614721, 0.07134320068040065, 0.08453023699777466, 0.051196746195533445, 0.17171792925468513, 0.06365670849170003, 3.2682076692581177, 53.553761754717144, 50.618828773498535, 35.53821536472866, 22.856241703033447, 59.42775494711739, 59.31020532335554, 73.56579657963344, 5.7084454127720425, 0.08079722230987889, 0.04177248850464821, 40.50286654063633, 79.28997271401542, 63.75509997776577, 74.89301368168422, 64.36722932543073, 68.19627039773124, 64.18539496830532, 67.33859866006034, 60.71869550432478, 66.32205636160714, 67.00036035265241, 67.6399837221418, 66.66194834027971, 59.26303400312151, 63.773415429251536, 64.27969591958183, 64.32595007760185, 63.40953826904297, 61.589554922921316, 63.08734335218157, 63.08562019893101, 61.592445373535156, 60.533741406032014, 61.36819921221052, 60.10161903926304, 57.97218724659511, 50.29547003337315, 48.406508445739746, 47.950359208243235, 46.03747844696045, 45.04712390899658, 45.75401278904506, 45.56100920268467, 44.172397817884175, 42.931626728602815, 41.76103591918945, 43.57641608374459, 40.218549728393555, 41.5041366985866, 42.91752188546317, 41.151470456804546, 47.14587593078613, 43.604170663016184, 39.99932016645159, 50.273829868861604, 56.9510452406747, 46.38582985741751, 40.33098200389317, 39.407587255750386, 43.75339365005493, 42.18963207517351, 40.92816230228969, 44.63525901521955, 40.348456723349436, 40.477366651807515, 39.09720080239432, 38.781898498535156, 38.271278858184814, 36.855239459446494, 38.4236215863909, 38.42727286475045, 37.9204226221357, 37.567711217062815, 38.89978510992867, 38.635107381003245, 39.53823075975691, 40.29285029002598, 41.054793221609934, 40.83800595147269, 39.999830859048025, 38.637174470084055, 39.11396680559431, 39.553002629961284, 38.6872501373291, 38.88459287370954, 37.99240248543875, 38.955912658146445, 37.0363199370248, 37.17383868353707, 38.31363507679531, 38.643691880362375, 37.78992850439889, 39.0203537259783, 40.448132106236045, 42.66405160086495, 42.73460708345686, 36.92453384399414, 38.24126958847046, 37.2288475717817, 37.54928806849888, 40.68235240663801, 41.08230808803013, 43.63284935270037, 41.886826106480186, 38.477074078151155, 38.83867917742048, 35.74174894605364, 37.29004383087158, 38.555724212101524, 44.817260129111155, 39.917491231645855, 42.197375842503135, 39.129562037331716, 38.89490052631923, 38.55592918395996, 38.06269046238491, 41.48864221572876, 42.960791792188374, 42.554481983184814, 53.11904770987374, 55.82234164646694, 58.03243160247803, 53.829448904309956, 54.33816473824637, 56.64515427180699, 54.313439573560444, 58.22763776779175, 56.76647676740374, 57.348985944475444, 59.97557176862444, 59.18652738843645, 58.61660834721157, 58.751132420131135, 61.544516699654714, 60.84379087175642, 60.880248069763184, 59.76092801775251, 58.53225721631731, 57.84438902991158, 55.81915589741298, 60.041482380458284, 68.21410642351422, 71.7109124319894, 68.03891454424176, 59.9615364074707, 65.78375857216972, 69.24907534463065, 75.66497938973563, 51.03644677570888, 0.2154916210898331, 0.046701746859720776, 0.07706529327801295, 48.33377817698887, 67.16164888654436, 62.686536516462056, 50.26845891135079, 24.020306416920253, 29.526845863887242, 40.07842193331037, 50.86078936713082, 9.736614039966039, 0.23567909640925272, 0.03569570529673781, 0.09908321859048945, 0.01687127281911671, 0.00808122060594282, 0.05945008993148804, 0.2705961013478892, 0.1255522250596966, 0.1379265867705856, 0.13811029334153446, 0.15102280117571354, 0.1901460446949516, 0.37263267753379686, 0.23766519555023738, 4.120702130453927, 67.01313808986119, 56.62507050377982, 42.234079701559885, 34.55869306836809, 70.1588933127267, 65.7819937297276, 83.49252114977155, 8.765748330524989, 0.25928798956530436, 0.10997453345251934, 43.872051511492046, 81.41028499603271, 65.99779088156563, 78.03957489558628, 66.93586717333112, 71.16298443930489, 66.1002698625837, 68.41101837158203, 63.82698604038784, 68.07865129198346, 69.32340717315674, 69.36413751329694, 68.54074818747384, 60.62185846056257, 65.79309000287736, 66.61803572518485, 68.31790556226457, 64.30421611240932, 64.56421770368303, 67.07874992915562, 64.42034830365861, 65.19515582493374, 63.527365820748464, 63.48423835209438, 62.371824809483115, 59.56553077697754, 52.83879559380667, 49.34082228796822, 49.76787941796439, 48.396020139966694, 46.16751050949097, 48.82638808659145, 47.58529043197632, 46.130754538944785, 46.685397965567454, 45.54172795159476, 43.872239112854004, 40.66319274902344, 44.25163507461548, 44.95313562665667, 43.69933319091797, 48.454576083592, 45.01504407610212, 39.79626253673008, 49.2371621131897, 58.833718708583284, 48.07458257675171, 41.98167249134609, 39.482131004333496, 44.11881331035069, 43.32564517429897, 42.51503011158535, 48.976750578199116, 44.030967235565186, 44.26194272722517, 40.66897365025112, 41.03472682407924, 40.170117310115266, 40.86382893153599, 42.137916633060996, 40.84885903767177, 41.45501640864781, 39.44673688071114, 42.679045813424246, 39.6074070249285, 41.64696386882237, 42.34882572719029, 43.37412970406668, 42.48943989617484, 43.364106927599224, 41.87566729954311, 41.11511400767735, 40.96310131890433, 40.34071295601981, 41.87508017676217, 40.89548145021711, 41.031416007450645, 39.19594512666975, 37.795143127441406, 42.451905727386475, 42.22635677882603, 39.03690433502197, 40.886754512786865, 41.8707549231393, 46.44522305897304, 44.349903447287424, 35.980280603681294, 38.89523751395089, 38.3260098184858, 38.54902267456055, 43.9577818598066, 42.31773601259504, 44.268018926892964, 43.34155307497297, 39.50959028516497, 39.66185310908726, 37.35895259039742, 38.3158723967416, 40.175192969185964, 46.685912132263184, 43.320076193128315, 43.2127161026001, 43.143067359924316, 40.93263694218227, 42.7683162689209, 40.55299779347011, 43.764184202466694, 44.18208360671997, 44.56687831878662, 54.74779578617641, 58.00990554264614, 58.8629150390625, 58.39100728716169, 60.31044714791434, 61.056906018938335, 58.16187654222761, 61.43737547738211, 59.70995603288923, 58.86559704371861, 63.12415490831648, 61.595599855695454, 61.817483629499165, 61.546712330409456, 65.605377469744, 64.31169237409318, 64.28470557076591, 62.1967579977853, 61.28764874594552, 63.712111473083496, 62.63828822544643, 62.96426296234131, 73.00055367606026, 73.3852059500558, 68.12695516858781, 62.845184734889436, 71.47217232840401, 72.38665948595319, 80.9619802747454, 52.11257682527815, 0.38063203543424606, 0.4399871033217226, 0.3495220462126391, 55.28753532682146, 73.09542437962124, 70.70277050563267, 60.19383553096226, 45.41302646909441, 41.34510285513741, 51.1301223891122, 63.912837982177734, 11.856627549443926, 0.29439235159329, 0.18354385825140135, 0.22570753576500074, 0.10669998452067375, 0.16282464217926773, 0.14710195442395552], [0.04969365881489856, 0.0429604472592473, 0.054469361302575896, 0.0793647263199091, 0.061454998063189645, 0.035918729579342265, 0.0887531064716833, 0.13639167270490102, 2.7675293811729977, 47.69745520183018, 40.650345529828755, 45.03072268622262, 31.99143443788801, 45.60511984143938, 63.679121426173616, 36.22663245882307, 0.03948721648859126, 0.03232571702184422, 0.21518148987420968, 38.081999506269185, 80.10056345803397, 64.2413557597569, 67.51996053968156, 64.57459136417934, 64.16187531607491, 62.98073714120047, 62.503847530909944, 63.0605719430106, 63.64196940830776, 67.30297524588448, 63.26300770895821, 64.94857815333775, 68.2475619997297, 61.83267933981759, 58.623216084071565, 60.75612545013428, 59.124188150678364, 56.61152499062674, 58.35153457096645, 56.6724294253758, 58.969097409929546, 55.57658386230469, 53.62370579583304, 50.47050905227661, 47.75096327917916, 44.44699757439749, 44.98072692326137, 42.28680610656738, 43.76364571707589, 44.19975982393537, 43.095885617392405, 42.70741878237043, 43.08190584182739, 41.10121761049543, 39.99925763266427, 38.00684431621006, 40.62029109682356, 40.386949743543354, 41.50942080361502, 41.33255788258144, 45.275757857731406, 44.893947396959575, 38.90777901240757, 40.628385748182026, 45.179803235190256, 49.42581612723214, 44.88609593255179, 48.12628412246704, 41.45411661693028, 40.4120466368539, 40.66017028263637, 41.48901741845267, 37.995647294180735, 37.717194761548726, 36.217530318668906, 35.71413680485317, 37.1905004637582, 36.24978038242885, 35.66340453284127, 37.06472069876534, 36.91224595478603, 37.30945709773472, 35.96118695395333, 36.90086480549404, 37.770504815237864, 37.48696272713797, 36.181514331272666, 38.60618897846767, 35.93111515045166, 37.61220053264073, 36.53258943557739, 38.34496103014265, 36.19910022190639, 35.705521038600374, 35.407363414764404, 36.241935866219656, 34.982967444828574, 33.831088134220664, 35.09184571674892, 35.43373530251639, 35.1050820350647, 37.535151958465576, 36.87857151031494, 40.61450324739729, 40.80392156328474, 37.80821616309029, 36.936189447130474, 38.21008607319423, 36.985994134630474, 40.71409525190081, 43.978897435324534, 40.41285262789045, 41.889733927590505, 40.15516826084682, 37.76764563151768, 36.951128074101035, 35.265932832445415, 38.442037786756245, 38.321118286677766, 36.979487146650044, 37.382934297834126, 35.58400746754238, 35.704854011535645, 35.04517466681344, 38.744037764413015, 39.85023614338466, 42.22371298926217, 40.85777357646397, 50.01703487123762, 51.39840623310634, 54.676066058022634, 44.77629702431815, 46.84717287336077, 54.67957489831107, 51.8719676562718, 53.68285928453718, 53.56112684522356, 58.31502873556954, 55.54227018356323, 57.022219112941194, 57.495631149836946, 60.704347474234446, 56.07936593464443, 53.46750334330967, 50.2975822857448, 50.832958357674734, 53.2171493257795, 58.578907421657014, 62.768789291381836, 68.17404311043876, 60.718528747558594, 58.8614559173584, 64.58923816680908, 68.0859955378941, 62.020912987845286, 67.96921021597726, 66.64830902644566, 67.61392102922711, 0.7063024086611611, 0.16098631439464434, 0.07184973385717187, 36.984211921691895, 64.48078373500279, 52.12446519306728, 45.02887099129813, 30.371302127838135, 34.17820623942784, 28.72154269899641, 43.53302110944475, 10.721206784248352, 0.1640465480408498, 0.062288062646985054, 0.019176330916317444, 0.09473317808338574, 0.03560158909697618, 0.12442732256438051, 0.021561054113720144, 0.05409395841083356, 0.0457088669229831, 0.09064574419919934, 0.04517721098714641, 0.16502711256699903, 0.20422833333058016, 0.12017474004200526, 4.748864012105124, 62.107265199933735, 50.29210710525513, 53.42577593667166, 37.2020240511213, 52.517941679273335, 70.21413149152482, 38.257465839385986, 0.3929968705134732, 0.07123747135379485, 0.1811226960271597, 39.96694156101772, 79.4668391091483, 67.28566033499581, 72.31876863752092, 65.68445491790771, 66.47322831835065, 64.67762620108468, 65.54183619362968, 65.97757857186454, 66.4831156049456, 67.16837474278041, 64.28814492906842, 66.78356960841587, 69.53497287205288, 64.05823598589215, 62.03833212171282, 62.96454783848354, 63.167310169764924, 59.615307671683176, 61.2122677394322, 60.00123841421944, 59.15547588893345, 58.40192985534668, 56.41301148278372, 52.00847543988909, 49.242571285792756, 46.762352739061626, 47.709433896201, 44.37272827965872, 45.97138718196324, 44.63918127332415, 46.259716578892295, 45.20141213280814, 44.677802835192, 43.74924210139683, 41.60193954195295, 40.65855482646397, 44.825243609292166, 41.534753935677664, 45.205997943878174, 42.18179103306362, 46.58503818511963, 45.6924934387207, 38.72849464416504, 40.800058364868164, 48.45133474894932, 51.808704308101106, 46.73336485454014, 48.57397740227835, 43.039949144635884, 41.74238348007202, 40.37789971487862, 44.940184184483115, 41.166999680655344, 41.03457396371024, 39.025081975119456, 38.73324721200125, 38.98958362851824, 37.28911624635969, 38.187490531376426, 38.24343047823225, 38.58612952913557, 39.22645814078194, 37.51633971078055, 38.5394515310015, 39.582271916525706, 40.057782309395925, 38.790747029440745, 39.01085901260376, 38.63083076477051, 40.07426691055298, 38.03555079868862, 39.062442438943044, 37.430515561785015, 38.4014880997794, 37.86042145320347, 38.936686992645264, 37.30169595990862, 35.49642889840262, 37.60819837025234, 37.37346737725394, 37.65524114881243, 39.1557810647147, 39.83224030903408, 43.65222440447126, 40.546723570142476, 37.342026778629844, 37.7245146887643, 37.783984320504324, 38.28738130841936, 42.129547527858186, 44.26891871861049, 40.68238367353167, 41.63209819793701, 39.642391204833984, 37.93125833783831, 37.122203145708355, 36.63981403623308, 39.58586760929653, 39.81466831479754, 39.09718690599714, 38.349380084446494, 38.381994928632466, 37.39759847096035, 36.843983377729145, 40.071553639003206, 43.21852479662214, 44.62720605305263, 42.517204897744314, 51.510414668491904, 53.941096033368794, 54.963547774723594, 48.97147689546858, 50.93441595349993, 56.72482231685093, 54.59112433024815, 56.599935395377024, 55.28844206673758, 59.25299385615757, 58.809177671160015, 60.1974972316197, 60.412627356392996, 62.20353943961007, 59.72533239637102, 56.8693448475429, 52.07850285938808, 55.067437240055625, 56.550756045750205, 62.11369228363037, 64.31963416508266, 69.12566144125802, 62.950839042663574, 63.90900257655552, 67.4619917188372, 71.97339453016008, 63.696957451956614, 70.24779551369804, 67.29975128173828, 73.43521908351353, 1.4820592275687625, 0.1750335091991084, 0.044269683970404525, 38.65303373336792, 74.37974330357143, 59.20343235560826, 54.867190156664165, 29.832910537719727, 35.958980900900706, 38.412914412362234, 54.72662809916905, 14.674380029950823, 0.2124196080757039, 0.02039285429886409, 0.09215889764683587, 0.13416657995964798, 0.022505786901872073, 0.047760308986263614, 0.1268344662551369, 0.104878090854202, 0.11422586068511009, 0.17237380120371068, 0.15143739964280808, 0.21855926433844225, 0.3523224416588034, 0.2526095493563584, 6.485203640801566, 74.28515747615269, 56.34405408586775, 60.30854334150042, 45.178180830819265, 62.703212193080354, 72.91503524780273, 49.076523235866, 0.7545551508665085, 0.12197843539927687, 0.22198378986545972, 45.30184834344046, 82.79490116664341, 70.75874519348145, 74.24476064954484, 69.13953699384416, 70.10333551679338, 68.94656467437744, 68.23298467908586, 67.79972280774797, 70.42846952165876, 70.39857837132045, 65.24651690891811, 69.87872110094342, 71.03560311453683, 65.80786187308175, 63.39542647770473, 66.73245865958077, 65.61008834838867, 62.812882559640066, 63.3546336037772, 63.62486294337681, 62.63902473449707, 59.87855407169887, 58.60600539616176, 56.158426012311665, 54.13206032344273, 48.33104406084333, 49.37214476721627, 46.001657009124756, 46.963516984667095, 48.00299528666905, 46.672304085322786, 46.19305208751133, 47.27002286911011, 47.153473785945344, 44.083009243011475, 42.66303368977138, 48.00359283174787, 44.75025517599923, 46.859311376299175, 44.81755542755127, 48.98261833190918, 45.192845003945486, 37.731726918901714, 41.4175169808524, 48.93146569388253, 53.74230112348284, 47.15661437170846, 49.80250576564244, 43.772765227726524, 42.01948806217739, 42.51702077048165, 46.786928517477854, 43.955315249306814, 42.62140008381435, 42.43068592888968, 41.70868124280657, 41.56347778865269, 40.346389634268625, 41.5223514011928, 40.38121747970581, 41.50528315135411, 42.25830807004656, 40.783087389809744, 41.06500359943935, 42.571967124938965, 42.769108363560264, 39.99675975527082, 43.602284227098735, 40.269827433994834, 42.63916662761143, 40.02025856290545, 42.11040871483939, 40.88856104442051, 40.93755279268537, 40.308897154671804, 41.45224755150931, 38.85379498345511, 37.487000942230225, 39.66437530517578, 41.31799793243408, 40.76212120056152, 42.35904652731759, 43.82949726922171, 47.014985765729634, 41.15124464035034, 39.134696756090435, 37.46993269239153, 39.21463925497872, 38.22506986345564, 42.834317207336426, 44.240483215876985, 42.89819547108242, 44.376219749450684, 41.57748188291277, 38.93900421687535, 37.70751592091152, 36.85930068152291, 39.97358056477138, 41.8795166015625, 40.765157563345774, 40.148574420383994, 39.99802432741438, 40.31747123173305, 41.338561126164024, 43.17452185494559, 43.914807251521516, 48.22780772617885, 46.20556926727295, 53.900601931980674, 57.231436320713584, 57.66448974609375, 54.28846427372524, 55.20127691541399, 59.52470316205706, 57.94919565745762, 60.667369161333355, 58.89225033351353, 63.327744075230186, 59.460738045828684, 62.42553438459124, 64.16506453922817, 67.15203257969448, 61.277622495378765, 58.267878259931294, 54.00617980957031, 55.60734701156616, 58.064320359911235, 62.54649557386126, 65.66711916242326, 72.47253227233887, 65.7347251347133, 69.29480143955776, 70.43910026550293, 72.51156030382428, 66.42011628832135, 75.61217308044434, 70.80830669403076, 77.09402929033551, 1.6260306792599815, 0.15028922339635237, 0.2754866289240973, 44.07227427618844, 82.44839450291225, 66.94309329986572, 64.1305319922311, 56.20704255785261, 58.054023129599436, 48.2926413672311, 71.95454406738281, 17.88523813656398, 0.3553365756358419, 0.13660314492881298, 0.16081178161714757, 0.26882718769567354, 0.10977025369980506, 0.24312745673315866], [0.05630308183442269, 0.06006858817168644, 0.06706945465079375, 0.0513056578513767, 0.08618517033755779, 0.07237407857818262, 0.10656906118882553, 0.13177713246217795, 4.100475490093231, 52.407698086329866, 40.806051186152864, 24.878320353371755, 28.675505672182354, 47.57306507655552, 67.603866985866, 22.59402711050851, 0.3075244740716049, 0.45047717328582493, 0.611116322023528, 30.97660139628819, 76.72477422441754, 64.61901814596993, 67.33265795026506, 63.73986952645438, 63.50975908551897, 64.92526694706508, 64.82260731288365, 64.01328808920724, 64.38405786241803, 64.20906053270612, 63.97079985482352, 61.91549491882324, 58.75206347874233, 60.770598547799246, 58.511551584516255, 57.11502272742135, 56.054126603262766, 55.84660823004586, 53.52762263161795, 53.47344752720424, 50.135428701128276, 47.53631952830723, 47.013415472848074, 45.17963647842407, 45.010465213230674, 43.89366735730852, 43.51976047243391, 43.4108578818185, 42.237699713025776, 43.10071808951241, 42.22428274154663, 43.456163610730854, 42.113493715013774, 42.15326520374843, 39.951940400259836, 38.6546630859375, 39.7648914200919, 39.67512764249529, 40.870127473558696, 41.43531479154314, 46.481395380837576, 46.92989812578474, 41.59036384310041, 45.918476649693076, 47.37842171532767, 45.87467520577567, 48.51079395839146, 49.7016978263855, 41.12744011197771, 40.658200468335835, 42.53993245533535, 42.58810084206717, 41.37948948996407, 37.18009901046753, 39.261946065085276, 36.914452007838655, 36.979521887642996, 36.55947896412441, 36.62729685647147, 37.18147127968924, 36.436412470681326, 36.10807187216622, 36.62617819649832, 35.74756806237357, 36.23898983001709, 35.94468150820051, 38.39255966459002, 36.54318196432931, 37.49953549248831, 38.20151547023228, 36.214872632707866, 36.46981246130807, 37.09664419719151, 35.56657443727766, 38.13305834361485, 36.22075775691441, 35.16051476342337, 34.940830094473704, 34.36156572614397, 36.39742265428816, 35.61290155138288, 37.149172578539165, 37.61309337615967, 40.80702740805489, 38.69633490698678, 40.052619797842844, 38.01398011616298, 38.468552112579346, 39.50824580873762, 38.673645564488, 39.69454090935843, 46.30011340550014, 43.87227732794625, 42.766461099897114, 35.87298304694039, 33.66157293319702, 35.395033836364746, 38.05822277069092, 37.96428312574114, 38.599348476954866, 37.218546867370605, 36.61446005957467, 35.73448460442679, 34.230856214250835, 37.26675346919468, 40.146948541913716, 40.54082802363804, 41.524661677224294, 45.90435096195766, 53.76665455954415, 52.46480185644967, 54.010004792894634, 54.31163304192679, 54.60033416748047, 55.66669157573155, 57.94651017870222, 53.748016016823904, 55.84028189522879, 54.8561737877982, 57.02231638772147, 53.911201408931184, 56.98850992747715, 53.188581807272776, 56.35723829269409, 56.254391057150706, 61.512026923043386, 59.747990471976145, 59.68385859898159, 57.23702962057931, 64.27695832933698, 64.96971457345145, 68.72878033774239, 57.73975958142962, 65.95492049625942, 65.14589309692383, 70.98848737989152, 60.390024866376606, 79.99834850856236, 6.667573009218488, 0.24204003651227268, 0.11650145000645093, 28.394160951886857, 66.99769224439348, 55.35120514460972, 48.704391615731375, 24.871181079319545, 24.283014331545147, 28.921937431607926, 46.24466330664498, 11.867677790778023, 0.23963693689022744, 0.09024856372603349, 0.13775844579296453, 0.02368798659050039, 0.10922313734356846, 0.06726468953170947, 0.08738387708685227, 0.003603187190102679, 0.05466929503849574, 0.07205070235899516, 0.09292977449617215, 0.09014062237526689, 0.24724562146833964, 0.267845700361899, 7.130749481064933, 62.515006337847026, 46.77544314520699, 34.3530923979623, 39.063171999795095, 52.345838274274556, 72.58877563476562, 24.812684195382253, 0.30134850261466845, 0.352997746850763, 0.5295028356569154, 33.39387968608311, 80.72604029519218, 67.25827748434884, 70.61515372140067, 64.17481981004987, 64.97951848166329, 67.10142190115792, 67.28426374707902, 65.8198961530413, 68.22945499420166, 65.45051601954869, 65.65030452183315, 64.48450796944755, 60.57082394191197, 61.18148027147566, 60.14184216090611, 59.29778889247349, 57.644221850803916, 58.33795779091971, 56.674024036952424, 55.24711070741926, 51.63830321175711, 50.019327776772634, 48.48704501560756, 46.230537618909565, 46.94252300262451, 45.059971128191265, 45.490856715611045, 43.85314546312605, 43.66950804846627, 44.88368143354143, 44.39637647356306, 44.670142446245464, 43.25341517584664, 43.409909452710835, 41.28302417482649, 41.89554956981114, 42.06675318309239, 42.1295405796596, 41.940893513815745, 43.62898962838309, 47.64095592498779, 49.039756843021934, 42.72837802342006, 45.78391088758196, 48.752361978803364, 46.82575852530343, 48.8330340385437, 53.59132024220058, 42.561134883335654, 41.01549073628017, 43.11374248777117, 44.53663975851876, 44.75502511433193, 40.277932507651194, 41.41922623770577, 39.366356645311626, 39.98471852711269, 39.36288949421474, 38.16182735988072, 38.90459673745291, 39.41531365258353, 37.27627944946289, 38.570895603724885, 37.75391251700265, 38.69583463668823, 39.98059129714966, 39.905925955091206, 37.464249065944124, 38.90446472167969, 40.492767333984375, 38.89212472098214, 37.533460072108674, 39.68344463620867, 39.08230039051601, 40.039859431130544, 38.48244156156267, 37.30488518306187, 37.42601660319737, 38.074443340301514, 38.66845873423985, 37.99693271092006, 38.680374894823345, 41.96440969194685, 43.11100489752633, 39.44806746074131, 42.7924473626273, 39.66488947187151, 40.17779854365757, 39.35217884608677, 40.22598082678658, 39.05564362662179, 45.7568268094744, 45.71969911030361, 45.7064072063991, 35.27239465713501, 34.01048019954136, 35.310251917157856, 39.34933703286307, 38.44411529813494, 40.12447806767055, 38.560949257441926, 40.234843254089355, 37.75326633453369, 37.56016199929373, 40.301514693668906, 43.318512848445344, 42.72010619299752, 43.44246523720877, 48.8455616406032, 56.47029938016619, 56.30319520405361, 56.20740039008004, 56.22166504178728, 57.93868998118809, 56.25602388381958, 60.266110692705425, 56.24638673237392, 58.78909737723214, 57.32849918093, 59.479303632463726, 55.11827720914568, 58.18805735451834, 53.909488677978516, 57.52186407361712, 56.00008004052298, 62.54505729675293, 61.49735927581787, 62.13698959350586, 59.85726479121617, 65.53819533756801, 67.41253444126674, 71.6743996483939, 59.777874674115864, 71.00200857434953, 66.69358348846436, 73.52958951677594, 62.74358122689383, 84.15929807935441, 7.8564315012523105, 0.2191385839666639, 0.04731875232287815, 30.631800515311106, 75.28206416538784, 61.22050830296108, 58.50623621259417, 31.06565645762852, 27.786438499178203, 39.583692823137554, 57.29622827257429, 15.87879467010498, 0.2550869349922453, 0.08848706646157162, 0.05889274805252041, 0.023014835747224942, 0.01698824038196887, 0.044856708363762925, 0.13413947927100317, 0.1795744826751096, 0.16305381059646606, 0.12135871579604489, 0.26946520060300827, 0.20203469746879169, 0.378840621560812, 0.47557786639247623, 10.529264535222735, 78.0377197265625, 53.6607848576137, 34.24221999304635, 39.02221236910139, 62.68249266488211, 76.49141897474016, 31.76128578186035, 0.7262535095214844, 0.6100580245256424, 0.5940066001244954, 37.036830629621235, 80.97402150290353, 71.46937915257045, 74.74956117357526, 68.10620784759521, 68.00436115264893, 69.36761161259243, 69.04172720227922, 67.83187212262834, 68.80135427202497, 67.74118423461914, 66.59289714268276, 66.4367641721453, 63.946606227329795, 63.705010414123535, 62.87547888074602, 61.26046044485909, 61.533079964774, 61.9109924861363, 58.11196763174874, 57.55240488052368, 54.02342871257237, 53.31194707325527, 51.39249679020473, 49.52972991125924, 49.33197028296334, 47.23052930831909, 47.96358510426113, 47.94644737243652, 46.22419391359602, 47.29334797177996, 46.5299528666905, 46.3684732573373, 46.393156732831685, 46.79391493116106, 45.25292955126081, 43.062082631247385, 44.99239294869559, 45.942958627428325, 44.94661474227905, 47.44713939939226, 50.73063571112496, 51.35397250311715, 45.34938791819981, 46.637941769191194, 49.37777975627354, 46.45285218102591, 49.23338924135481, 52.76669761112758, 43.40723787035261, 40.36718211855207, 44.79868412017822, 45.37205294200352, 48.86799737385341, 43.092387199401855, 43.71779455457415, 41.34768411091396, 42.27412911823818, 41.780209473201204, 40.442646503448486, 41.31722668239048, 41.62701906476702, 39.880978448050364, 39.96580900464739, 39.784318583352224, 41.14439719063895, 41.569484506334575, 42.01659761156355, 40.992957728249685, 42.47606461388724, 42.12607690266201, 40.91682979038784, 40.834479740687776, 41.77216693333217, 41.0504401751927, 42.94475882393973, 39.64478485924857, 40.236198152814595, 39.718067509787424, 40.12140696389334, 43.07418639319283, 39.70912865230015, 41.60511139460972, 45.12270641326904, 42.92737095696585, 41.641679763793945, 42.34776265280587, 42.267375469207764, 40.42535591125488, 39.84585877827236, 41.72621502195086, 39.93246112551008, 47.44397102083479, 46.22693845203945, 46.76157454081944, 36.81171246937343, 34.51076092038836, 35.65988874435425, 40.639384746551514, 40.83096047810146, 42.03665011269705, 40.54318346296038, 42.391126360212056, 40.854494026729036, 38.105022362300325, 44.091583320072715, 46.812758445739746, 45.64725719179426, 45.98905645098005, 52.5802982875279, 61.10073525565011, 60.093475750514436, 59.599236488342285, 57.96068797792707, 61.6817992074149, 61.341372217450825, 62.534315381731304, 58.46522099631173, 60.504545075552805, 58.41654886518206, 62.23784964425223, 58.01247290202549, 61.614756039210725, 56.602867535182405, 60.08353287833077, 57.6291755267552, 64.2966981615339, 62.08763653891427, 62.980612073625835, 62.831274441310335, 69.24447563716343, 69.61364037649972, 72.86500126974923, 63.323165212358745, 74.63499232700893, 68.02557400294712, 76.77288355146135, 64.60380853925432, 88.54272202083042, 7.910653506006513, 0.2709553177867617, 0.19215344983552182, 35.0942393711635, 83.48446123940604, 68.40739141191754, 67.1055908203125, 39.487644399915425, 38.83836650848389, 46.172402041299, 70.97684914725167, 18.576206956590923, 0.3993438056537083, 0.25649950919406755, 0.17558386895273412, 0.040048670289771895, 0.19569889030286244, 0.1079774759709835], [0.03812779193477971, 0.014724483015015721, 0.13769882970622607, 0.05971081701240369, 0.0938998760123338, 0.05058425638292517, 0.335954412817955, 0.1285748950072697, 5.444432973861694, 45.82878235408238, 40.17820501327515, 41.1617294720241, 47.461042744772776, 50.63422250747681, 69.48936489650181, 23.82887659754072, 0.4252801282065255, 0.2857331862407071, 0.5022596003753799, 25.552837576184952, 78.84572574070522, 63.24037047794887, 67.61318452017647, 63.753383772713796, 62.43359429495675, 64.292313848223, 65.71631935664585, 67.16497707366943, 66.02076857430595, 62.388451848711284, 64.94264439174107, 62.270096233912874, 60.02805151258196, 56.76475361415318, 52.6071982383728, 52.31830256325858, 50.18278414862496, 47.58381741387503, 47.05461481639317, 48.136268683842246, 47.17447124208723, 43.94501107079642, 44.469860621861045, 44.66679341452462, 42.345848424094065, 43.505728585379465, 42.507491316114155, 43.39813573019845, 42.079965182713096, 42.98681627001081, 42.02269465582711, 41.396429198128835, 41.64948953901018, 40.98262228284563, 40.190937587193076, 38.344870703560964, 40.273232051304404, 37.73940815244402, 39.59321880340576, 40.54228367124285, 49.085396085466655, 47.601778507232666, 48.39650303976876, 51.48574161529541, 52.31697545732771, 57.52099902289254, 54.46300997052874, 51.75728069032942, 42.643905299050466, 42.861217158181326, 46.27933829171317, 46.689216000693186, 41.97910860606602, 36.684501375470845, 38.49772759846279, 37.06125007356916, 36.51292255946568, 37.639802251543315, 36.16801398141043, 37.45961809158325, 37.51747226715088, 38.658661774226594, 37.412637846810476, 38.23910175051008, 36.410335881369456, 37.06235483714512, 36.8475512777056, 35.695720604487825, 37.13568959917341, 37.610466957092285, 36.497278690338135, 35.14710821424212, 36.07652357646397, 36.28421565464565, 35.16692100252424, 37.92541142872402, 36.49308545248849, 36.06329768044608, 37.85289308003017, 37.08443968636649, 38.11269664764404, 35.31038393293108, 37.160904611860005, 40.54743228639875, 41.94281816482544, 41.615241868155344, 39.99180916377476, 40.3191249029977, 37.657534054347444, 43.93520368848528, 46.602957589285715, 45.39826154708862, 46.66616882596697, 46.45545080729893, 37.62642002105713, 32.12187991823469, 34.1152103969029, 39.9168381009783, 36.57580723081316, 38.08015823364258, 34.204915114811485, 36.46539340700422, 35.94040489196777, 34.144806248801096, 37.348339217049734, 41.28166580200195, 40.036267212459016, 41.13372475760323, 39.98078237261091, 47.95335735593523, 49.92222670146397, 52.030080863407676, 51.30890996115548, 52.88948270252773, 49.584061350141255, 56.13482992989676, 54.87174122674124, 56.71237461907523, 54.339919158390586, 57.525386810302734, 54.46504579271589, 55.553349086216514, 54.39259345190865, 56.45431157520839, 52.604780265263145, 58.898635728018625, 57.76623221806118, 61.34658336639404, 60.165069988795686, 65.13116986410958, 61.94742883954729, 65.25501455579484, 65.16760621752057, 65.741881779262, 58.75586414337158, 72.81130559103829, 63.27499335152762, 79.74325234549386, 13.50359206540244, 0.20694095348673208, 0.09645156123276268, 19.439063787460327, 69.91688060760498, 52.612506662096294, 52.120386600494385, 29.612378188541957, 33.112119810921804, 29.625152451651438, 43.642931188855854, 19.5506066935403, 0.07014437858015299, 0.031900784466415644, 0.07975581354860749, 0.011147736638252224, 0.06899340676942042, 0.06121789078627314, 0.05682474973478487, 0.019849111958007728, 0.07078843723450388, 0.049144187942147255, 0.07477281522005796, 0.05142442183569074, 0.26060741447976654, 0.15201879558818682, 8.991741963795253, 55.603216307503835, 46.09148679460798, 39.095620087214876, 47.567485673086985, 56.07588488715035, 74.52555125100272, 28.653106416974747, 0.46362826760326115, 0.401799315320594, 0.7134136727878025, 27.253435237067087, 81.54390580313546, 68.6635228565761, 69.58802236829484, 65.30321420942033, 65.82677486964634, 67.3001264844622, 66.09226553780692, 68.63051891326904, 67.52979918888637, 64.01507377624512, 66.01601600646973, 65.41785253797258, 61.206181117466514, 59.11056968144008, 57.32010923113142, 54.84639072418213, 52.81253487723214, 50.66260589872088, 50.04343107768467, 50.004486424582346, 48.13681411743164, 45.62795162200928, 47.9789788382394, 46.47732721056257, 45.83092587334769, 46.82451132365635, 44.896347999572754, 45.67691557747977, 44.80255079269409, 45.315254892621724, 43.42158242634365, 43.375734737941194, 42.87329312733242, 41.830649920872276, 41.57819754736764, 40.32544081551688, 41.045197759355815, 39.38393906184605, 41.35689394814627, 43.63094902038574, 49.495777538844514, 51.70461334500994, 52.037230559757774, 52.8047251020159, 55.77775853020804, 57.2743935585022, 56.869959763118196, 51.99731663295201, 42.259034156799316, 43.000938483646934, 47.63688080651419, 46.89596312386649, 44.571735109601704, 41.04304729189192, 41.7082712990897, 38.974676268441335, 39.40409231185913, 39.20917797088623, 38.608242171151296, 39.07991368430001, 39.76017706734793, 41.40803268977574, 39.96607303619385, 38.580046381269185, 38.31443759373256, 38.98725250789097, 37.834289278302876, 38.88814687728882, 38.53132561274937, 39.32305199759347, 39.00666924885341, 36.408643995012554, 38.5803347315107, 39.35063634599958, 38.56263072150094, 40.36420828955514, 39.02261536461966, 36.85659783227103, 39.5052615574428, 39.568712506975444, 40.62779515130179, 39.4274035181318, 40.98471021652222, 43.325408935546875, 42.057525975363596, 42.66529185431344, 40.71463026319231, 40.9451402255467, 38.51940597806658, 44.408799852643696, 47.077946867261616, 47.133890288216726, 47.150944641658235, 45.89074291501726, 36.211158820560996, 34.26049028124128, 34.53998851776123, 39.20256328582764, 38.89297240121024, 39.736143248421804, 36.857223170144216, 38.37952484403338, 37.59634821755545, 37.11245829718453, 39.98601089205061, 44.25912175859724, 42.30471856253487, 42.52338532039097, 43.37630101612636, 50.14957175936018, 52.23906183242798, 53.39117043358939, 52.233055114746094, 54.24987050465175, 54.45917803900582, 57.39364201681954, 57.25255537033081, 57.94638163702828, 55.824884687151226, 59.2957044328962, 56.34590925489153, 58.98840645381382, 56.5736677306039, 57.399888447352815, 56.11457245690482, 61.664998463221956, 60.34984343392508, 63.464706965855186, 61.691394669669016, 66.50978973933628, 62.97027315412249, 67.83685398101807, 67.3068870816912, 69.42637252807617, 61.7444372177124, 76.48960549490792, 65.88387516566685, 83.66840784890312, 16.32065667424883, 0.17676055724067347, 0.08284599773053612, 19.478677204677037, 78.70818614959717, 58.83694962092808, 65.24139608655656, 35.29132155009678, 43.040953159332275, 41.30912855693272, 54.50991031101772, 22.72785288946969, 0.04254084120371512, 0.05041146404775126, 0.04289194575643965, 0.0249477530097855, 0.0871654295229486, 0.021670437351401364, 0.1624331817563091, 0.10195654298045806, 0.2786687953131539, 0.1786438176142318, 0.23576757737568446, 0.10042413270899228, 0.46628209948539734, 0.37677985642637524, 13.420125961303711, 71.21528353009904, 51.30093690327236, 50.18581008911133, 58.31320135934012, 64.72350515638078, 78.79615034375871, 32.160765511649, 0.5684250699622291, 0.3836605543536799, 0.647928095289639, 31.133575098855154, 84.96709564753941, 70.56190272739956, 72.80448246002197, 68.84534331730434, 68.0355029787336, 68.73014218466622, 69.76665360586983, 71.5115338734218, 70.7065155846732, 66.30235127040318, 68.5303258895874, 68.21836566925049, 64.67852946690151, 61.60731451851981, 58.227429321834016, 57.82060882023403, 56.16163608006069, 52.84314169202532, 52.06487396785191, 52.708628041403635, 51.42492750712803, 48.01651300702776, 51.52255664552961, 50.23042447226388, 48.54676825659615, 48.274516991206575, 47.79229811259678, 47.623147691999165, 46.53309692655291, 47.271631377083914, 45.99525077002389, 44.99463374274117, 46.120078631809776, 44.67105613436018, 44.1748366355896, 43.84127793993269, 44.55992317199707, 41.08845724378313, 42.46836600984846, 46.62234306335449, 52.248473167419434, 55.30345017569405, 55.39076818738665, 53.88756363732474, 59.07729475838797, 58.34084824153355, 57.77429560252598, 53.678137983594624, 43.94553913388933, 45.23995726449149, 49.060896737234934, 49.691807065691265, 47.086117948804585, 43.29832138334002, 45.09019579206194, 42.623144081660676, 40.86298472540719, 42.2387558392116, 41.32503645760672, 41.10407332011631, 42.21548284803118, 44.46941941125052, 41.541271345955984, 42.136777128492085, 41.63817439760481, 42.69853898457119, 42.27390677588326, 40.04279157093593, 41.952948638371055, 42.00649145671299, 40.97563239506313, 38.33853047234671, 41.45259843553816, 41.15824147633144, 41.88057967594692, 42.49746853964669, 41.86673191615513, 39.89008753640311, 42.198876653398784, 42.27151312146868, 41.801276411329, 41.87464244025094, 45.044056279318674, 45.330186571393696, 45.644860063280376, 43.6737916128976, 43.12245205470494, 42.99342748097011, 38.83293996538435, 45.90626866476876, 50.875794001988, 47.363448347364155, 48.47635868617466, 48.07419695172991, 37.47554683685303, 33.072758265904014, 34.596862997327534, 42.13354969024658, 40.28928933824812, 44.31778539930071, 38.14580828802926, 39.768233503614155, 41.530553749629426, 39.26298829487392, 42.72464336667742, 47.29752383913313, 45.09279094423567, 44.677914006369456, 45.58813149588448, 52.4178910936628, 54.06916522979736, 57.677896295275005, 55.034766810280935, 57.45348685128348, 56.58085911614554, 61.61845942905971, 60.90464319501604, 60.40649904523577, 58.8350944519043, 62.033225195748464, 57.60902575084141, 59.3921662739345, 57.64803988592965, 60.83909388950893, 58.20317316055298, 66.11267239706856, 63.03239004952567, 65.9078950881958, 64.65489169529506, 69.69795676640102, 65.63002273014614, 70.48699419839042, 70.0891889844622, 73.49732208251953, 64.71544524601528, 79.26058183397565, 67.40716348375592, 87.93173912593296, 17.366268498556956, 0.12002581517611231, 0.2556532403188092, 24.299419028418406, 89.16808768681118, 66.66559614453996, 73.32417297363281, 47.870197841099326, 53.489407539367676, 43.88826165880476, 69.93206242152623, 27.653800862176077, 0.14450385740825109, 0.07101699497018542, 0.14627005692039216, 0.1170458657933133, 0.28239406113113674, 0.18227100798061915], [0.04114873840340546, 0.06450060927974326, 0.017525400933144347, 0.052484147649790557, 0.04561306456370013, 0.005479215228530977, 0.10155806650540658, 0.06876733247190714, 7.324146509170532, 45.974694524492534, 35.945688996996196, 51.35105078560965, 49.536167417253765, 48.589346817561555, 72.21677603040422, 27.250546523502894, 0.3084482045045921, 0.6205111550433295, 0.7924810786332402, 19.81707010950361, 79.68479020254952, 64.74244594573975, 66.62042590550014, 60.71377617972237, 64.69516345432827, 65.21438149043492, 66.37794767107282, 67.18519633156913, 61.87090832846505, 61.91492516653878, 60.137464795793804, 60.28539194379534, 53.920550210135325, 51.58412115914481, 49.24196331841605, 49.86021402903965, 47.508582319532124, 46.916696548461914, 46.511578355516704, 45.561825616019114, 45.84631265912737, 44.3391615322658, 43.68760463169643, 42.67504712513515, 42.83154140199934, 41.8035762650626, 42.14954096930367, 41.720844064440044, 43.23028114863804, 41.621974672589985, 41.007569789886475, 41.34942463466099, 42.36021382468087, 40.62872968401228, 39.21618870326451, 38.47860268184117, 37.32132114682879, 36.63224049976894, 38.710731574467246, 38.1904330934797, 43.61862291608538, 53.29501778738839, 54.929515498025076, 54.2476818220956, 49.23283338546753, 50.675425325121196, 55.24679109028408, 48.87248591014317, 46.184950487954275, 44.15759468078613, 45.99828018460955, 43.89368125370571, 39.537963254111155, 39.70360483442034, 40.6056547164917, 41.267672130039756, 39.61498750959124, 35.46491881779262, 38.06363541739327, 35.98695434842791, 35.994635581970215, 37.90991694586617, 35.650599002838135, 36.17439590181623, 36.74296004431588, 34.71467317853655, 36.69740418025425, 35.644081592559814, 36.273619651794434, 37.28244250161307, 35.78721795763288, 36.12825638907296, 35.20784936632429, 37.65959072113037, 35.86082717350551, 38.27877943856375, 38.13048751013619, 38.60346181052071, 35.59202568871634, 38.15413570404053, 38.24122442517962, 37.22423049381801, 41.82804087230137, 44.08177941186087, 42.658534731183735, 42.46960973739624, 41.62102276938302, 39.36182641983032, 42.852545806339805, 43.361098357609336, 44.28412137712751, 43.60544913155692, 50.11978830610003, 51.49992636271885, 40.46604803630284, 33.92846713747297, 43.17194059916905, 42.61817611966814, 39.06473534447806, 37.067288058144705, 37.617505482264924, 36.82247870309012, 35.417302812848774, 35.24855886186872, 37.09098836353847, 40.83743967328753, 39.513814789908274, 40.513580662863596, 40.310450077056885, 43.9620862688337, 45.324832984379356, 46.93396282196045, 48.898937702178955, 50.06484195164272, 48.23541600363595, 52.12917954581124, 50.453173296792166, 53.14049332482474, 53.76007808957781, 55.67678730828421, 55.6997024672372, 58.81069237845284, 56.61181681496756, 60.29655075073242, 58.86486053466797, 60.56846155439104, 59.95569297245571, 62.52863870348249, 56.65511451448713, 64.81453350612095, 62.551699774605886, 68.29733194623674, 63.258303778512136, 67.40023612976074, 63.33816637311663, 70.25352777753557, 64.04433958871024, 82.53143242427281, 18.56748001916068, 0.4448498652449676, 0.21913107936935766, 14.312701974596296, 69.57458455221993, 52.25077649525234, 53.95141410827637, 27.69665561403547, 24.37249149594988, 32.7849360874721, 34.058933462415425, 20.03176770891462, 0.10490380054605858, 0.025111975447673882, 0.03227613986070667, 0.0663914353187595, 0.025495585220466768, 0.039958934033555646, 0.051591609471610615, 0.05047573149204254, 0.06928392153765474, 0.02493965469433793, 0.018930177071264813, 0.027640056131141524, 0.0640418313975845, 0.1861221149031605, 10.63349619933537, 58.426589012145996, 41.3744728905814, 46.82783603668213, 49.288842814309255, 56.84253522327968, 75.64649718148368, 31.1424548966544, 0.3754714237792151, 0.5045075054679597, 0.7165838426777295, 21.49029013088771, 81.37097208840507, 68.32937703813825, 69.1298998423985, 62.46673720223563, 69.15662261417934, 67.3253345489502, 67.93770708356584, 67.25295516422817, 62.195083481924875, 64.22425624302456, 61.48747198922293, 61.2872040612357, 55.545393398829866, 55.22447695050921, 52.8806654385158, 51.809937613351, 51.567191873277935, 50.15842029026577, 48.719476154872346, 47.58731235776629, 47.22451564243862, 46.31898123877389, 45.14752537863595, 45.15907675879342, 45.430869443076, 45.15636348724365, 43.63175501142229, 44.03440659386771, 45.02256550107683, 43.65458331789289, 41.92393296105521, 44.801883765629356, 45.032841886792866, 42.73797695977347, 40.210687841687886, 39.97424064363752, 40.13284369877407, 39.40116017205374, 41.480860233306885, 39.80202954156058, 44.62402030399868, 56.1161253792899, 56.985226903642925, 54.64319065638951, 49.80865144729614, 53.89467511858259, 56.26650176729475, 50.282716614859446, 46.83848067692348, 45.37699311120169, 46.732287883758545, 44.552964551108225, 41.0151606968471, 40.53851079940796, 43.66627366202218, 44.629867213112966, 41.526273659297395, 38.187000683375764, 39.97930588041033, 37.61408002035958, 38.856775760650635, 39.0649333681379, 38.57043354851859, 38.45676449366978, 38.71341010502407, 37.716517312186106, 38.48385551997593, 38.1305569921221, 38.21243109021868, 40.07107768739973, 38.46014131818499, 38.04470157623291, 36.50609595435006, 39.80016047613961, 39.3092702456883, 39.98216853822981, 40.72919716153826, 41.38721241269793, 37.915287903376985, 40.47738749640328, 40.26446689878191, 38.71569953645979, 43.87482731682913, 45.49937520708357, 43.92860984802246, 43.8288927759443, 42.592109952654155, 41.68018320628575, 44.36324746268136, 43.67212404523577, 45.04517841339111, 43.24751615524292, 51.50652715138027, 53.49197489874703, 40.05528443200247, 33.84658261707851, 45.05123029436384, 45.33188888004848, 40.65635224751064, 40.63997534343174, 40.6586868422372, 38.161851678575786, 38.40766852242606, 37.692007541656494, 39.87077849251883, 43.03291061946324, 42.207909311567036, 42.483162198747905, 43.7049959727696, 46.57380642209734, 47.39288091659546, 50.05819599969046, 53.19391802379063, 51.9183156149728, 50.1711493900844, 54.20329672949654, 52.80706317084176, 56.47904021399361, 58.122598375592915, 56.033605098724365, 56.671074526650564, 60.96849019186837, 57.607493673052105, 62.677941594805034, 62.106612069266184, 64.57956627437046, 60.8264342716762, 65.44060094015938, 59.364720889500205, 66.55286162240165, 63.767266273498535, 70.3877808707101, 63.508689062935964, 71.23019436427525, 66.46479320526123, 72.58549608503068, 65.98510347093854, 85.59567138126918, 20.304703371865408, 0.3741657595549311, 0.24940656551292964, 15.89027656827654, 77.5811744417463, 57.61124570029122, 63.74798502240862, 32.5572783606393, 28.623128414154053, 43.469309602464946, 47.04822942188808, 24.424005440303258, 0.06927681727600948, 0.026566318568906615, 0.06706714763173036, 0.043063302990049124, 0.034994232401783974, 0.10246881656348705, 0.18688818093921455, 0.18433029390871525, 0.13718659004994802, 0.1331156242106642, 0.1772720640791314, 0.08000113109924964, 0.2736086882650852, 0.24243380395429476, 15.40425876208714, 74.52176448277065, 47.32669932501656, 67.2371688570295, 63.33314282553536, 61.185808999197825, 82.8055110658918, 35.217149530138286, 0.4557187205978802, 0.7553837235484804, 0.8712134510278702, 23.65417456626892, 84.96071720123291, 69.3939105442592, 73.7692676271711, 65.06486320495605, 69.50425488608224, 68.83007117680141, 69.43291773114885, 70.24217442103794, 65.00166933877128, 66.80437251499721, 64.69552476065499, 64.54158742087228, 58.07629905428205, 57.33367906297956, 53.268534728458945, 56.93402910232544, 51.782273360661094, 51.456906591142925, 51.754689012254985, 49.238753250667024, 51.33154024396624, 49.13354015350342, 48.538454736982075, 48.58304827553885, 47.56404978888375, 47.288063866751536, 47.44932113374983, 46.30808298928397, 47.370667525700156, 45.614743096487864, 44.086754322052, 48.024475642613, 46.604364599500386, 45.90434748785836, 42.87878220421927, 42.228239740644185, 42.3472762789045, 42.29507793698992, 44.53415577752249, 41.723647662571494, 50.64630889892578, 56.38250194277082, 58.938226563589915, 56.45891128267561, 50.87101364135742, 55.34746353966849, 59.21240247998919, 50.491794858660015, 48.06460148947579, 47.60173681804112, 48.36366932732718, 46.523018564496724, 43.95842456817627, 42.37193890980312, 45.38387182780674, 47.249105317252024, 47.49796199798584, 40.392942564828054, 43.980193274361746, 41.16251114436558, 41.464601448604036, 41.26173489434378, 40.142126492091585, 39.838163648332866, 40.454468863351, 40.19324786322457, 41.56111887523106, 38.86434929711478, 41.61022874287197, 42.26076773234776, 39.47956364495413, 40.488018240247456, 39.0462600844247, 42.564987659454346, 41.31939104625157, 42.75066089630127, 42.64178262438093, 44.99264308384487, 40.430254391261506, 40.96250377382551, 41.551544257572715, 42.13894496645246, 45.7163222857884, 46.822857652391704, 44.93841239384243, 44.15450273241316, 43.82173613139561, 42.57269321169172, 46.05046115602766, 45.05882120132446, 47.125621931893484, 44.29236888885498, 54.77933018548148, 55.83667230606079, 41.50146859032767, 35.11493805476597, 46.036634240831646, 46.45914724894932, 43.860225677490234, 41.064954962049214, 44.17922094890049, 41.59296246937343, 40.50843552180699, 41.54123313086373, 42.919245038713726, 46.48439005443028, 43.59342179979597, 44.62797382899693, 45.160317012241904, 48.967926365988596, 49.4884159224374, 52.347860200064524, 54.98861340114048, 55.27683857509068, 53.009359972817556, 58.99373572213309, 55.87412657056536, 58.68750776563372, 59.50188527788435, 59.95770795004708, 59.64685249328613, 66.0527650288173, 60.54785319737026, 66.6854054587228, 62.72413321903774, 66.88315813882011, 63.864937101091655, 68.54533399854387, 61.0643892288208, 70.26103183201381, 66.21285847255162, 73.7630420412336, 67.30922862461635, 73.1001422064645, 69.89577892848423, 78.36634172712053, 68.2659330368042, 87.96496541159493, 22.904979842049734, 0.3811598542545523, 0.4804908941899027, 18.807978016989573, 87.14055470057896, 62.61922236851284, 72.69715363638741, 42.61013010569981, 37.94716623851231, 48.27859558377947, 62.29720115661621, 30.45628207070487, 0.23063980681555613, 0.16726386254387243, 0.13242700616163866, 0.16021864701594624, 0.11691114945071084, 0.16302862337657384], [0.08395999616810254, 0.0402616827881762, 0.15151278488337994, 0.03924464700477464, 0.07851045073143073, 0.05095209700188466, 0.05817586901996817, 0.05739912284272058, 3.8392640437398637, 40.52075467790876, 42.88236747469221, 33.61175434929984, 26.599319662366593, 54.831035205296104, 70.02782944270542, 35.44526236397879, 0.17397145261721952, 0.27341810134904726, 0.45351011625358034, 16.50687881878444, 77.84606061662946, 64.79211166926792, 64.66895484924316, 60.05833176204136, 65.45232949938092, 65.73991543906075, 65.54184314182827, 61.77290398733956, 60.84581279754639, 61.96764809744698, 58.16199813570295, 57.613444805145264, 53.52329042979649, 52.10660832268851, 48.98403923852103, 48.47992311205183, 48.32265411104475, 46.204124041966026, 43.69627945763724, 45.52164070946829, 44.50243377685547, 42.75090060915266, 40.8014132635934, 42.47145101002285, 42.611189705984934, 42.67169809341431, 41.05118015834263, 42.774666922433035, 41.068335260663716, 42.628004346575054, 40.06481736046927, 42.0038754599435, 41.44453157697405, 42.915677138737266, 39.09901428222656, 36.74088600703648, 36.71327386583601, 37.8063714163644, 38.15219020843506, 39.82773092814854, 39.072357518332346, 45.24261147635323, 51.90917525972639, 53.565511158534456, 50.2230350630624, 45.42437635149275, 43.20922463280814, 48.07467637743269, 45.091401304517476, 45.299013478415354, 44.49121938432966, 40.643862860543386, 40.74959707260132, 39.44678899220058, 40.451706954411094, 40.12619079862322, 42.42267465591431, 40.422131947108674, 37.43499367577689, 37.00466741834368, 36.12274299349104, 35.99784912381853, 36.38147306442261, 38.97359929765974, 36.79125002452305, 33.931361062186106, 35.5549362046378, 38.34953989301409, 31.861093180520193, 37.64090701511928, 39.255393913814, 34.17932142530169, 34.18871886389596, 36.30451134272984, 36.36358492715018, 38.24216938018799, 37.64592014040266, 36.75167655944824, 36.289072445460725, 38.92192554473877, 36.24301283700125, 38.5530561038426, 48.60165555136544, 48.00040013449532, 44.83939708982195, 44.77624143872942, 41.90409237997872, 43.27757753644671, 42.967291831970215, 41.156153542654856, 43.34850822176252, 43.5824089050293, 47.40221234730312, 48.91424110957554, 43.49254090445382, 45.97521563938686, 49.7534236907959, 42.18726968765259, 38.572757720947266, 35.825224603925435, 35.02704681668963, 35.397271156311035, 35.05013568060738, 35.52568081447056, 38.21251446860177, 40.40623794283186, 41.37807205745152, 41.83127873284476, 38.681781905038015, 43.533417156764436, 44.288307666778564, 45.2095866884504, 45.44965042386736, 47.06224046434675, 46.05650608880179, 46.08456638881138, 45.640416690281455, 50.10219199316842, 48.792724064418245, 52.96916464396885, 53.760244846343994, 56.85593135016305, 54.74440853936331, 57.5919748714992, 57.632764271327424, 59.68696444375174, 57.445756980351035, 61.34190028054373, 59.45779200962612, 63.91112872532436, 61.947164808000835, 65.65896197727749, 65.3913937977382, 66.0676133292062, 62.558703558785574, 69.42602511814663, 57.24977609089443, 91.64207717350551, 19.642206532614573, 0.22377582799111093, 0.1268785981727498, 8.14814988204411, 67.81863580431256, 52.57161998748779, 57.35113293784005, 33.35254832676479, 33.19234718595232, 32.11806535720825, 38.00280393872942, 21.600882870810374, 0.13863785431853362, 0.020493438633690988, 0.02697032510436007, 0.04205144442883985, 0.07527003889637333, 0.027563927894724265, 0.02489516993851534, 0.06841171905398369, 0.06282097726528134, 0.006543541934141623, 0.12545303681067058, 0.04778634437492915, 0.05641816137358546, 0.05534396919288805, 6.894539824553898, 53.78153760092599, 46.106831891196116, 38.03482123783657, 32.46847343444824, 61.771083559308735, 73.4104140145438, 40.2416490146092, 0.12993718976421015, 0.2640035093895027, 0.490057749407632, 17.452026639665874, 80.55948502676827, 66.12522084372384, 67.36072172437395, 62.45900385720389, 67.34371253422329, 67.55789075578961, 66.8586448941912, 61.531440189906526, 63.498176438467844, 63.80316761561802, 62.503256934029714, 59.01953438350132, 56.986428941999165, 55.045658111572266, 52.114890575408936, 49.85901199068342, 50.16025114059448, 47.06088556562151, 46.52511692047119, 48.48483201435634, 46.680621079036165, 44.91642829350063, 44.352630615234375, 45.44192402703421, 45.43776900427682, 44.50828068596976, 42.89024673189436, 43.85922166279384, 43.78459800992693, 44.243741921016145, 42.893397739955354, 44.09572444643293, 43.928766182490754, 44.40039948054722, 39.40928956440517, 39.16460527692522, 39.57306555339268, 39.614633151463096, 39.817666462489534, 41.97818449565342, 41.90363727297102, 47.71760150364467, 55.24053771155221, 55.025807108197895, 50.84727512087141, 44.584700448172434, 46.74337720870972, 47.441834449768066, 47.04831280027117, 47.63108600888933, 45.08336918694632, 42.57574347087315, 43.74472924641201, 42.456786836896626, 41.28248916353498, 41.673783915383474, 45.94626249585833, 42.5542631149292, 39.009028162275044, 37.8346540587289, 37.909079687935964, 38.20759514399937, 37.90560558864048, 39.37387807028634, 38.929846491132466, 37.99405268260411, 37.98159456253052, 39.29196923119681, 35.10213252476284, 40.38682120186942, 41.523779256003245, 37.553460461752756, 37.89465870176043, 38.29661546434675, 39.48782505307879, 40.7516884803772, 40.421756744384766, 39.58268186024257, 37.2091737474714, 40.141622747693745, 40.35660001209804, 41.230798040117534, 50.47914218902588, 46.750047479357036, 44.76483597074236, 46.42987101418631, 43.453307901109966, 44.765739236559185, 43.923228468213765, 42.838996819087434, 42.62246663229806, 44.70739868709019, 50.196440832955496, 51.83555909565517, 46.52962630135672, 47.44484649385725, 52.15843841007778, 44.87161241258894, 39.87008714675903, 38.54922764641898, 37.434229373931885, 38.16999844142369, 37.82791083199637, 37.85395962851388, 40.16023349761963, 42.46125452859061, 42.459871837071006, 44.03573022569929, 42.85445308685303, 46.38896002088274, 46.069252559116904, 46.6315598487854, 47.45451838629586, 49.26051153455462, 47.50978783198765, 48.788343225206646, 47.15323059899466, 52.98210913794381, 51.391117572784424, 54.13820947919573, 56.471160956791465, 58.98761435917446, 58.18610838481358, 60.190882546561106, 59.24803284236363, 61.2934296471732, 60.49856267656599, 63.4155832018171, 61.99055630820138, 66.1231711251395, 64.45777824946812, 67.15290805271694, 67.55194309779576, 69.88598891666958, 66.13778318677629, 71.00109141213554, 61.4080262865339, 93.05374268123082, 20.76230478286743, 0.20845206454396248, 0.20083816881690705, 8.314752050808497, 75.56085368565151, 57.046985966818674, 67.14757183619908, 38.192260469709126, 41.51175192424229, 45.95811264855521, 49.822037151881624, 28.02245317186628, 0.15141591722411768, 0.09313600842974015, 0.09088990824030978, 0.05608005076646805, 0.0026871150850118803, 0.08695255951689822, 0.210733027862651, 0.13522494531103543, 0.20159715094736644, 0.10707260881151472, 0.19011309503444604, 0.10868227708020381, 0.17822860846562044, 0.26955726423433846, 13.097823347364153, 66.94514301845005, 53.98151370457241, 48.3532782963344, 38.72619479043143, 68.44636385781425, 79.44008159637451, 43.62309755597796, 0.29853309797389166, 0.3242843161736216, 0.6837592497467995, 20.727607216153825, 83.31480012621198, 70.46373857770647, 69.09504767826625, 65.16278416769845, 70.15250097002301, 69.7848231451852, 70.77532359531948, 63.5956666128976, 65.78223691667829, 65.90854127066476, 65.1207823072161, 62.54315349033901, 59.51799120221819, 56.822298594883506, 55.87786817550659, 51.515528542654856, 54.022296156202046, 50.90682118279593, 49.28913811274937, 50.28431122643607, 49.87310988562447, 47.48888417652675, 46.13124786104475, 47.298823152269634, 47.09642907551357, 47.48510435649327, 45.686347757067, 46.83878639766148, 45.785105977739605, 47.96149022238595, 44.424808502197266, 47.11595698765346, 46.420355456215994, 47.407017026628765, 42.84905433654785, 40.87219108854021, 43.17199271065848, 43.17832599367414, 42.07215888159615, 45.26243468693325, 44.358255181993755, 50.54842267717634, 55.82189348765782, 56.976996762411936, 53.59181009020124, 46.65741409574236, 46.253438881465364, 51.509969983782085, 49.497604915073936, 49.84675536836897, 47.20028379985264, 44.96965149470738, 45.83766562598092, 44.5295386995588, 42.01828254972185, 41.52349090576172, 48.618261745997835, 47.63482066563198, 43.72471496037075, 41.01499394008091, 41.296903201511924, 40.95236982618059, 39.758207253047395, 43.385778359004426, 41.71412168230329, 40.90355178288051, 40.346337522779194, 41.292762075151714, 37.213443415505544, 41.98371526173183, 42.858705384390696, 38.96700198309762, 40.26863234383719, 40.89952530179705, 41.261988503592356, 43.65706035069057, 41.657090868268696, 40.744097573416575, 40.744688170296804, 43.54901238850185, 46.054282665252686, 43.14734397615705, 52.58603402546474, 51.03077704565865, 47.61196109226772, 48.77034044265747, 46.36039250237601, 47.3648727280753, 47.120435101645334, 42.723215511866975, 45.34761960165841, 47.12490279333932, 51.76973186220442, 54.23288563319615, 45.87335852214268, 49.40907791682652, 54.95412254333496, 47.49094084330967, 42.78713893890381, 39.78628144945417, 39.87051446097237, 39.54850019727434, 40.66362701143537, 41.65186582292829, 43.11363131659371, 43.85634510857718, 45.19268866947719, 46.73983710152762, 44.57825599397932, 49.23751299721854, 50.88826254435948, 50.90080056871687, 50.734877586364746, 52.79678331102644, 51.8645851952689, 52.732630593436106, 49.891300269535606, 55.10568707329886, 54.17078610828945, 56.72417960848127, 60.13941029139927, 62.364459718976704, 61.14152118137905, 62.01087284088135, 62.58921309879848, 63.162286622183665, 63.67158957890102, 64.70331369127545, 63.03408540998186, 67.99009650094169, 68.32287352425712, 70.58913271767753, 70.92365373883928, 71.91410555158342, 68.41070570264543, 74.39188180650983, 64.8483086994716, 91.95303685324532, 23.178165640149796, 0.18158718038882526, 0.507756059723241, 10.642186658723013, 83.2761264528547, 63.81101213182722, 76.95988042013985, 50.75439855030605, 53.64397716522217, 55.76399762289864, 66.25224781036377, 33.53237118039812, 0.26962750617946896, 0.19736447664243834, 0.2800918460956642, 0.134903862540211, 0.13303960114717484, 0.15722644329071045], [0.0264339906695698, 0.016373935488185713, 0.034535881996686967, 0.021668009892372147, 0.11906306897955281, 0.11665684809642178, 0.22823551297187805, 0.18800310896975653, 4.491560058934348, 41.14733975274222, 42.77181468691145, 35.86674356460571, 35.25566686902727, 55.13144751957485, 67.90138190133231, 41.06875910077776, 0.017795530813080922, 0.4462172490145479, 0.704102380999497, 10.966690114566259, 74.63042736053467, 64.68863214765275, 62.38993181501116, 64.37510163443429, 65.00560896737235, 67.0796879359654, 60.952391215733115, 61.1407846723284, 63.087475367954795, 60.0301707131522, 59.60543428148542, 54.27571780341012, 54.5598817552839, 53.480162961142405, 50.671565600803916, 50.636682169778005, 46.89535168239048, 45.9125394139971, 43.92191873277937, 43.92662613732474, 42.78520039149693, 41.00273731776646, 41.97221599306379, 41.23546722957066, 39.95732872826712, 41.46029009137835, 42.73618432453701, 42.43807881219046, 43.39757987431118, 42.73993982587542, 40.969993931906565, 41.04748024259295, 40.047551086970735, 39.42105286461966, 39.13719115938459, 38.06603602000645, 37.07416330065046, 37.77557700020926, 37.4928617477417, 36.32509538105556, 41.14146852493286, 36.794442721775596, 43.01980284282139, 49.45985882622855, 48.74985367911202, 45.57525300979614, 46.13260275976998, 43.78510175432478, 43.27118519374302, 43.230770996638704, 42.22379289354597, 42.479827063424246, 40.37225430352347, 43.53607831682478, 43.12011398587908, 42.571734360286165, 46.984285150255474, 44.35898126874651, 42.4036921773638, 39.47528008052281, 37.48825856617519, 37.22355999265398, 36.93484149660383, 35.99099472590855, 33.21131229400635, 33.34818833214896, 41.01787049429757, 41.082412311008994, 33.96357291085379, 35.84121935708182, 44.124486514500205, 37.847716672079905, 34.36326108660017, 35.650470461164204, 35.64537048339844, 37.303467750549316, 37.87759392602103, 39.429203101566856, 36.8115804536002, 36.945194312504356, 37.83873265130179, 40.364541803087505, 38.65970400401524, 39.401653494153706, 39.36155196598598, 39.179887839726035, 38.3057975087847, 39.209233556474956, 41.26897144317627, 43.390829699380056, 44.342552253178184, 44.519759110042024, 40.43869992664882, 43.58873871394566, 46.69214466639927, 48.52909551348005, 46.53347212927682, 40.96715211868286, 36.63283804484776, 35.45884261812483, 35.66742059162685, 35.50959573473249, 35.82550253186907, 35.99284642083304, 38.43389449800764, 40.356103215898784, 38.59990085874285, 40.447044713156565, 41.09734398978097, 43.038705417088096, 43.11412811279297, 45.02505643027169, 45.34029967444283, 44.43017945970808, 45.37419646126883, 43.763798577444895, 42.70184632710048, 44.02613476344517, 43.30276475633894, 44.52683237620762, 45.7652028628758, 49.01410756792341, 51.65143878119332, 57.92538070678711, 55.245123522622244, 61.42873886653355, 55.04220833097185, 58.882307461329866, 57.22406775610787, 62.089144298008506, 60.16978781563895, 68.69314997536796, 60.5789463860648, 70.20117310115269, 61.07632623400007, 71.57761819022042, 60.036201749529155, 104.4120671408517, 20.994755029678345, 0.3395452472780432, 0.035434072371572256, 2.8101808982236043, 60.72191252027239, 57.364334515162874, 52.80079589571272, 34.73868267876761, 26.19170880317688, 31.514471871512278, 47.19994681222098, 33.341806411743164, 0.24083167420966284, 0.03760105198515313, 0.05189119625304427, 0.020657119939901998, 0.054260484475110254, 0.03569761198014021, 0.01671050751714834, 0.026513766031712294, 0.05712356977164745, 0.018629753995420675, 0.146852294249194, 0.03739762718656233, 0.1120056262505906, 0.15384013285594328, 9.711449401719229, 57.11635678155081, 43.65912396567208, 37.85475867135184, 43.577246393476216, 60.08090645926339, 73.30263355800084, 46.85134874071394, 0.03502388098942382, 0.36343586817383766, 0.6681183661733354, 10.656000546046666, 76.88807078770229, 65.88545240674699, 66.39362975529262, 64.11731651851109, 66.3162476675851, 69.05117675236293, 64.71866226196289, 61.84188570295061, 63.49673121316092, 61.28463322775704, 62.66763046809605, 55.59711231504168, 56.659498827798025, 55.30165754045759, 52.52446256365095, 53.175348963056294, 49.03286075592041, 46.9459936278207, 47.23342323303223, 47.031623227255686, 45.59091772351946, 43.109493664332796, 44.99967466081892, 42.576115199497764, 42.40171194076538, 42.879549980163574, 44.90505409240723, 44.70851387296404, 45.08142369134085, 46.00927570887974, 43.800259249550955, 42.91700424466814, 43.093398162296836, 40.85634919575283, 40.218754700251985, 39.795578139168875, 38.67549378531319, 40.409673827035085, 42.11939968381609, 38.618421282087056, 42.53606578281948, 40.606054237910676, 46.76382575716291, 50.68743181228638, 50.94885778427124, 48.517290524074006, 47.112118107931956, 47.37968628747122, 45.8560470853533, 44.81452253886631, 45.08719417027065, 44.3747432572501, 43.44326775414603, 45.51472725187029, 44.74060065405709, 46.61217437471662, 47.964644704546245, 47.70751619338989, 44.386555194854736, 41.401866163526265, 39.38471726008824, 38.269934381757466, 39.44810220173427, 38.06232220785958, 36.982658999306814, 36.457198006766184, 41.21601227351597, 42.17730597087315, 36.21690845489502, 37.59449304853167, 45.19340780803135, 40.36275611604963, 37.10783427102225, 37.54016855784825, 38.36097315379551, 38.69396209716797, 38.73947627203805, 40.92214168821062, 39.9508182661874, 40.411063466753276, 42.99484143938337, 41.26550081798008, 40.53879220145089, 42.2883277620588, 42.75360345840454, 41.54262624468122, 41.20290797097342, 41.893909794943674, 42.79058871950422, 45.7217001914978, 46.45967183794294, 46.16134398324149, 42.29288925443377, 44.8855539730617, 48.88246699741909, 50.89851113728115, 47.875190121786936, 40.463310446058, 38.73107589994158, 37.7569488797869, 38.25710105895996, 38.57489776611328, 37.65482078279768, 38.50096893310547, 39.554281098502024, 42.99711002622332, 40.80429329190935, 41.40592391150338, 44.01601818629673, 47.50286395209176, 46.04632350376674, 47.72871514729091, 47.10507263456072, 46.71177680151803, 47.64026457922799, 45.604348591395784, 44.3200991494315, 45.68315505981445, 45.52444430759975, 48.173733370644705, 47.77886724472046, 52.081910950796946, 53.991612911224365, 60.36540045057024, 57.139331000191824, 64.85713985988072, 58.07315846851894, 60.954545157296316, 59.899746077401296, 64.06635843004499, 62.44251578194754, 68.69491481781006, 63.019751276288716, 70.71574974060059, 63.746949740818565, 74.80513286590576, 62.401347705296104, 99.90625068119594, 21.33757393700736, 0.21187599296016352, 0.18459617107042245, 3.299186212675912, 69.65421090807233, 61.83388137817383, 61.26278114318848, 41.790253094264436, 34.069154262542725, 41.27115317753383, 57.44076817376273, 39.539429324013845, 0.43592688547713415, 0.1262004974165133, 0.022497478240568723, 0.0505320770399911, 0.06150016813938107, 0.05156239514638271, 0.125722523778677, 0.04452259432790535, 0.1592316228364195, 0.16744313149579934, 0.20783352559166296, 0.2523144951888493, 0.48423141347510473, 0.390684151755912, 14.766089303152901, 69.30288914271763, 53.840107440948486, 49.034132276262554, 47.24985224860055, 69.96345438276018, 77.02713203430176, 50.13778066635132, 0.11929252238145896, 0.6903119438460895, 0.7875331469944545, 13.8636121068682, 80.63174629211426, 69.06209932054792, 69.34845542907715, 68.04837104252407, 69.171797479902, 71.10888576507568, 66.95666313171387, 64.45293535505022, 66.91690553937639, 65.99315643310547, 66.12792369297573, 59.001656668526785, 60.45384407043457, 57.699755328042166, 55.723131792885916, 56.504818030766074, 52.67050327573504, 49.82821757452828, 49.70675611495972, 50.2039657320295, 48.039504596165244, 45.312340123312815, 47.68378462110247, 46.534250327519004, 43.583993094308035, 45.05309935978481, 47.09610945837838, 46.28350026266915, 47.90422316959926, 47.6539421081543, 46.598076479775564, 45.74296862738473, 45.2880596433367, 43.23486001150948, 43.77146244049072, 42.516690731048584, 40.70281137738909, 43.15060615539551, 43.023672989436555, 40.68969317844936, 46.282847132001606, 43.43868889127459, 49.1738258089338, 52.535117626190186, 52.40973390851702, 51.18152168818882, 50.17631190163748, 48.437198638916016, 47.07082496370588, 46.04042795726231, 45.67535918099539, 46.28248235157558, 45.95732750211443, 48.9557010105678, 46.949061257498606, 48.041425773075645, 50.081198011125835, 47.27910763876778, 46.250840255192344, 42.79650163650513, 41.245660236903596, 41.871699878147666, 40.846131869724815, 40.11022383826119, 37.490780762263704, 38.22526093891689, 44.269707339150564, 43.9969835962568, 38.750503063201904, 40.3856851713998, 47.86250965935843, 41.360729353768484, 38.94746364865984, 40.348679065704346, 40.15552609307425, 42.26925843102591, 41.5381099155971, 44.5688168661935, 42.79012666429792, 43.66013145446777, 44.83726051875523, 42.77705710274832, 43.08586631502424, 43.91743714468819, 45.27158893857683, 44.133390630994526, 44.449220997946604, 44.585127762385774, 44.91974605832781, 49.388288906642366, 48.97098357336861, 47.07581377029419, 43.1918054989406, 46.232886110033306, 50.671899114336284, 54.12477861131941, 51.02745233263288, 43.612452915736604, 41.636628423418315, 39.54893445968628, 40.4889805657523, 41.53338166645595, 41.178224495479036, 40.80756936754499, 42.829352719443186, 44.08888394492013, 42.56154830115182, 43.756749629974365, 47.52748489379883, 50.72328451701573, 48.553556646619526, 48.8557893889291, 50.68722684042794, 48.33917692729405, 50.62997020993914, 47.821817534310476, 46.01355232511248, 48.73288270405361, 48.28762476784842, 49.771412576947895, 51.7198611668178, 53.29450362069266, 55.48502050127302, 63.54866204942976, 60.132191113063264, 66.28970554896763, 58.9226348059518, 61.975332805088584, 63.15410164424351, 66.43797315870012, 65.27516433170864, 71.90607343401227, 66.3301579611642, 73.81441007341657, 66.61956432887486, 76.55912917000907, 68.01060758318219, 105.03087370736259, 22.933232954570226, 0.30717977828213144, 0.23416721182210104, 4.6676903792790005, 77.07017612457275, 69.4532551084246, 70.53740337916783, 51.35971518925258, 45.74499750137329, 53.7689266204834, 67.81427233559745, 47.43406636374337, 0.9873414082186562, 0.18524740183992044, 0.18018216506711074, 0.1509020762251956, 0.11155381692307335, 0.16801409157259123], [0.04209950167153563, 0.05682884469362242, 0.07159957835184676, 0.03620889829471707, 0.12879959866404533, 0.04452619056350418, 0.1705897290791784, 0.22919916840536253, 7.207241330827985, 48.24454246248518, 36.393663678850444, 46.977357796260286, 30.323995317731583, 55.745220116206575, 65.78471742357526, 43.89917727879116, 0.08984037741486516, 0.2706903634326798, 0.15914160838084562, 5.628938479082925, 71.45205034528459, 65.01475974491665, 63.44484901428223, 61.968002455575125, 65.47313240596226, 64.19932610648019, 62.3360207421439, 62.462790625435964, 60.079044342041016, 60.719980921064106, 58.28661755153111, 58.82811151232038, 56.46413632801601, 54.41270848682949, 52.02925750187465, 48.75042690549578, 45.92242670059204, 44.5444460596357, 44.046110834394185, 41.50376149586269, 42.70855828693935, 41.651077202388215, 39.50519902365548, 39.94349486487252, 40.766102518354145, 42.36574111665998, 43.690498556409565, 45.966231618608745, 46.25466871261597, 46.874746799468994, 43.129157066345215, 40.91126428331648, 38.85160282679966, 41.39443506513323, 39.01039348329817, 37.674049922398154, 35.46963317053658, 37.35686813082014, 36.5173659324646, 38.6475898197719, 39.411881242479595, 38.72564240864345, 38.634714807782856, 39.735757623400005, 42.95366988863264, 44.30730404172625, 43.190068449292866, 43.93637793404715, 47.58065945761544, 46.37106840951102, 49.755786078316824, 45.31121104104178, 45.05882814952305, 46.229346002851216, 46.78613294873919, 46.551162242889404, 47.0546669278826, 49.17841509410313, 49.22485337938581, 48.956031050000874, 45.48887995311192, 42.323989391326904, 37.559633936200825, 39.534096581595286, 36.765159538814, 41.891311168670654, 46.078368595668245, 43.13176611491612, 32.50353751863752, 35.145642144339426, 47.775518212999614, 46.32470308031355, 38.13939510072981, 36.83030584880284, 37.78719438825335, 37.99676595415388, 38.6031665120806, 37.76015199933733, 41.30594628197806, 41.10888147354126, 45.43761961800711, 41.75584214074271, 42.448827675410676, 41.28596673692976, 39.93371180125645, 39.968094961983816, 39.07225329535348, 39.496895926339285, 39.69379397800991, 41.03948286601475, 44.413403034210205, 40.54384701592581, 39.47877155031477, 42.60195902415684, 45.340570654187886, 46.102173124040874, 40.741036891937256, 35.20681061063494, 36.22960976191929, 35.10743400028774, 34.226569175720215, 35.32006277356829, 35.518062114715576, 38.04065077645438, 37.9390993799482, 41.065514292035786, 39.248671531677246, 40.1083721433367, 40.29669264384678, 41.77852800914219, 44.30739784240723, 45.18687997545515, 41.965986933027, 46.18512766701834, 44.536799567086355, 45.19704866409302, 41.4959899357387, 43.15792260851179, 40.69923652921404, 41.62547656467983, 42.24685049057007, 43.58180788585118, 48.51603290012905, 51.273772920881, 51.944739614214214, 61.92224856785366, 57.850600719451904, 58.48682294573103, 53.205987044743125, 59.45087855202811, 55.14510072980608, 61.99405820029122, 60.41117518288748, 67.42212990352085, 63.951692308698384, 73.46409579685756, 60.71139989580427, 93.4525762285505, 16.75255148751395, 0.25907574381147114, 0.15852480647819384, 2.393729107720511, 60.28814343043736, 54.95607846123831, 55.38477884020124, 32.03679575238909, 34.967987128666465, 38.76038687569754, 39.68309027808053, 30.63874523980277, 0.37365029007196426, 0.05476642393374017, 0.04648863597373877, 0.049680834503046105, 0.037008948757180145, 0.019751849052097117, 0.03924454861719694, 0.022199925367853472, 0.13287287152239255, 0.05216163656275187, 0.13883582369557448, 0.04514390170308096, 0.1296173826392208, 0.2576045984668391, 10.417620011738368, 60.571567399161204, 43.82019363130842, 53.3973890713283, 37.20338242394583, 61.60718945094517, 71.09557996477399, 50.54748814446585, 0.07249634380319289, 0.17612931611282484, 0.07334270088800363, 5.902008763381413, 73.46909155164445, 67.36074256896973, 66.77220930371965, 64.1168440410069, 68.92556721823556, 64.9199446269444, 61.63856751578194, 63.258157866341726, 61.76202310834612, 63.34890133993966, 62.601296016148154, 60.52726568494524, 59.36840343475342, 56.473752634865896, 54.39484814235142, 51.654367446899414, 47.81934744971139, 47.01357875551496, 46.46722452981131, 42.96386637006487, 45.5842787197658, 43.727852072034565, 42.0207839012146, 42.520310742514475, 42.82364477430071, 44.79520654678345, 46.85630628040859, 48.4975437436785, 48.40609850202288, 48.90682390757969, 46.17377431052071, 43.53771809169224, 41.723126547677175, 43.20643145697457, 40.27190841947283, 39.26307167325701, 39.123353821890696, 39.737164633614675, 39.866133621760774, 39.71286678314209, 40.63128662109375, 42.04201064790998, 40.06519603729248, 41.505237988063264, 45.549923351832796, 46.848645891462056, 44.2251763343811, 44.896924700055806, 49.130750451769146, 48.23492268153599, 51.435537406376426, 49.381104469299316, 49.15318965911865, 47.948969568525044, 48.791157245635986, 47.91253668921334, 49.62824494498116, 51.50070456096104, 51.82632493972778, 50.67454290390015, 47.71860899244036, 43.164297580718994, 38.77439791815621, 40.419404779161724, 37.906234400612966, 42.407339981624055, 46.94924538476126, 44.871866021837505, 35.421204226357595, 36.53022357395717, 47.992222104753765, 46.23151731491089, 40.00756420407976, 38.105126585279194, 38.7159184047154, 40.758435181209016, 40.64220224108015, 40.69068677084786, 44.477889265332905, 43.07401268822806, 45.33113152640206, 43.10377182279314, 42.99952799933297, 43.10947629383632, 41.799633162362234, 40.2104481288365, 42.279312474387034, 40.412109170641216, 41.895306382860454, 42.65454993929182, 44.57368407930647, 42.222913946424214, 40.27499341964722, 46.937037399836946, 46.16557543618338, 46.559051922389436, 42.75952679770333, 37.62997055053711, 37.81298957552229, 36.54765313012259, 37.10177891595023, 37.99521650586809, 37.484933853149414, 39.391790526253835, 40.875856263296946, 42.38671425410679, 41.90735455921718, 40.73665257862636, 42.370903628213064, 43.79819563456944, 45.82623931339809, 48.20236342293875, 44.44658415658133, 47.10606970105852, 47.51117747170584, 46.592879227229524, 44.60450628825596, 45.15541853223528, 43.713847977774485, 43.703599384852815, 44.0382593699864, 46.206378732408794, 50.20909002849034, 53.62193053109305, 54.52054105486189, 62.957467624119346, 60.358605112348286, 60.5720329284668, 54.60410703931536, 61.26097461155483, 57.87421069826399, 64.87123775482178, 63.75420366014753, 69.82544231414795, 65.50283595493862, 75.78915064675468, 61.93254579816546, 90.0052900314331, 17.31918055670602, 0.26833419129252434, 0.3060262144676277, 3.324035793542862, 67.30717890603202, 61.19873264857701, 64.91953468322754, 42.39964485168457, 38.05833741596767, 41.897672244480674, 50.43653930936541, 35.57784441539219, 0.7137861613716397, 0.04956586692216141, 0.02855148133156555, 0.03532044489734939, 0.04623838547351105, 0.01284080364608339, 0.118140844894307, 0.16687282281262533, 0.22140075186533587, 0.15934109767632826, 0.30733657415424076, 0.11689300542431218, 0.29298555850982666, 0.4435718038252422, 15.866301809038434, 71.2947222845895, 47.55933196204049, 61.82212502615792, 40.564712456294465, 69.13463851383754, 74.43022196633476, 54.65540211541312, 0.13785631768405437, 0.4319003229694707, 0.2724836772041661, 7.390520044735499, 77.82545920780727, 68.88415595463344, 70.2756438936506, 66.26469203404018, 72.07300390516008, 67.40874767303467, 66.65099797930036, 67.03738730294364, 64.02393967764718, 65.67132977076939, 64.6238818849836, 63.81210994720459, 60.58920887538365, 60.43080384390694, 57.77527182442801, 53.26177413122994, 51.09872347967965, 49.62944003513881, 50.09660564150129, 47.2050051007952, 47.62086868286133, 46.48120430537632, 45.71785436357771, 44.49683352879116, 46.34816714695522, 46.403540815625874, 48.77178914206368, 50.64720869064331, 51.47842863627842, 51.041282721928184, 47.953326089041575, 46.936196667807444, 43.61141068594796, 45.14814029421125, 43.59229966572353, 42.267771516527446, 41.84549822126116, 41.69030325753348, 42.80333866391863, 41.03961488178798, 44.40874079295567, 46.34186165673392, 41.672877175467356, 43.8596316065107, 47.378025668007986, 48.57284484590803, 47.81992762429373, 48.24664429255894, 51.44592843736921, 50.0829176902771, 55.59300592967442, 51.411705085209434, 53.375818388802664, 50.94333744049072, 50.57098347800118, 50.75317219325474, 51.87669243131365, 53.04544544219971, 53.130140508924214, 52.01065022604806, 48.88154983520508, 44.28940200805664, 39.49740661893572, 41.66809681483677, 38.799168246132986, 44.31956761223929, 48.887841429029194, 47.21329082761492, 37.80985246385847, 39.537647111075266, 50.49006823131016, 46.36071906770979, 42.7897584097726, 38.9508821623666, 39.84094292776925, 43.71573093959263, 42.90839542661394, 41.34510285513741, 44.774566922869, 44.55392687661307, 48.433665479932515, 45.17298010417393, 45.63178702763149, 46.61663511821202, 43.921487944466726, 44.06083754130772, 44.111614976610454, 43.402481828417095, 44.78086199079241, 44.639900411878315, 46.61156293324062, 44.681846686771934, 42.161363329206196, 50.11282968521118, 49.0589234488351, 47.94082280567714, 45.98217078617641, 41.02587134497506, 39.9046231678554, 39.72600582667759, 38.19540800367083, 40.759112630571636, 40.843550613948274, 43.305599621364046, 42.15554073878697, 45.4102645601545, 43.11459711619786, 42.59188413619995, 45.52797051838466, 47.76302882603237, 48.44175665719168, 51.21547058650425, 47.25052622386387, 50.91123676300049, 51.238840852464946, 48.991873332432334, 47.42988702229091, 47.658131871904644, 46.50400134495327, 46.04847049713135, 45.93338748386928, 47.99968447004046, 53.20858914511544, 56.94979109082903, 56.47619840076992, 66.9675509589059, 61.96274266924177, 61.92765426635742, 56.34610380445208, 60.94702025822231, 59.775053705487935, 66.71257291521344, 66.9571842466082, 71.38925947461809, 69.76413140978131, 78.5567432131086, 62.88645703451974, 98.29743698665074, 20.197265114103043, 0.34104698098131586, 0.572660539831434, 4.087726414203644, 76.5313502720424, 66.21947315761021, 75.98021221160889, 48.602895804813926, 52.21272815976824, 58.10525567190987, 60.04017611912319, 43.45972456250872, 1.3680005307708467, 0.24199077486991882, 0.07272432478410856, 0.09069622720458678, 0.11181988407458578, 0.079524819872209], [0.030196321462946277, 0.02537407147298966, 0.06484679784625769, 0.016700707775141512, 0.12030343099364213, 0.024430381932428906, 0.1308842482311385, 0.1597814533327307, 5.18282287461417, 50.912039279937744, 40.18136991773333, 34.32871464320591, 38.494559219905305, 51.0204450743539, 64.47189698900495, 50.90978111539568, 0.35188961774110794, 0.11169924733362027, 0.07495549720312868, 1.0322680260453905, 60.58710357121059, 65.99166257040841, 61.33902372632708, 62.67610032217843, 65.31759698050362, 63.69001620156424, 60.83183997017996, 59.293675558907644, 61.56833512442452, 59.831493922642295, 57.77479239872524, 59.546173095703125, 56.823809828077046, 55.961298670087544, 54.141627992902485, 49.04335600989205, 45.688439164842876, 44.01261356898716, 43.35843372344971, 41.41317435673305, 41.743585518428254, 40.79778282982962, 41.441182545253206, 40.649219921657014, 43.80860751015799, 43.86361639840262, 45.51270185198103, 46.83781017575945, 48.92047016961234, 48.34252943311419, 45.98638834272112, 42.4591874395098, 39.94256033216204, 40.6980379649571, 37.48885611125401, 37.18852022715977, 38.0545471736363, 38.504773071834016, 37.42384876523699, 38.007368905203684, 36.872974736349924, 37.48921741758074, 38.60388217653547, 38.92112650190081, 40.56772450038365, 44.58081293106079, 43.44555718558175, 43.12946278708321, 47.65829515457153, 43.78674152919224, 45.2902900150844, 46.05931316103254, 46.65973479407174, 47.18432378768921, 45.687452520642964, 46.01471267427717, 49.1834316934858, 48.6408121245248, 48.155254636492046, 49.901854583195274, 49.858904293605256, 48.53429971422468, 44.767215728759766, 37.537208625248496, 40.07566697256905, 44.920718806130544, 46.05986206872122, 45.87544992991856, 33.965018136160715, 33.745708669934956, 44.34206587927682, 57.103162152426584, 44.95032508032662, 37.00685610089983, 38.381400857652935, 35.136817932128906, 40.27061258043562, 42.70688377107893, 48.79622943060738, 45.88865498134068, 46.73029375076294, 44.478094237191335, 46.96726901190621, 44.911887645721436, 43.44031476974487, 42.68035902295794, 41.67312731061663, 40.52993672234671, 44.7796425819397, 40.79539959771292, 39.877615519932334, 41.397759778159006, 40.433759757450645, 40.80322674342564, 41.166485513959614, 38.6549688066755, 35.58238853727068, 35.17339672361101, 36.14963252203805, 35.94020339420864, 33.42608111245291, 34.871705940791536, 36.85551738739014, 36.955595765795024, 39.63570703778948, 39.56417185919625, 38.50557558877127, 40.062944820949006, 40.56433030537197, 41.57568577357701, 43.320906502859934, 44.92472791671753, 44.805976254599436, 44.41086694172451, 41.99365813391549, 43.341546126774375, 41.58005966459002, 42.74868065970284, 40.2660893031529, 43.07156344822475, 41.26619216373989, 43.1754390171596, 43.53783968516758, 45.45373943873814, 52.501502241407124, 57.345008100782124, 58.966686385018484, 60.894603048052105, 56.74610117503575, 60.78673226492745, 59.92946352277483, 64.00558253696987, 59.75013746534075, 65.91787270137242, 62.17680277143206, 69.60403101784843, 63.22775949750628, 78.47260747637067, 8.111579775810242, 0.2482514546385833, 0.1371200257646186, 1.5616280436515808, 56.1401800428118, 58.94580010005406, 53.43280403954642, 35.288406780787874, 26.44299214226859, 27.995792933872767, 49.41398681913103, 37.93728242601667, 0.5643261213387761, 0.034361267794987986, 0.07710896379181317, 0.02943912727226104, 0.018481273569964936, 0.041182051080146005, 0.08840611044849668, 0.018873985890032988, 0.009844666114076972, 0.009153616365178354, 0.11452210907425199, 0.006327191043445575, 0.20877358157719883, 0.15018244912581785, 11.273628524371556, 61.76934650966099, 43.40297862461635, 43.37566178185599, 43.14264004571097, 57.732331957135884, 66.74938447134835, 56.767314025333945, 0.5573043695517949, 0.03970255296943443, 0.1130979929917625, 1.299129226378032, 61.99160548618862, 71.11206804003034, 63.10857704707554, 66.4323034286499, 67.28970418657575, 65.49943828582764, 63.90138040270124, 62.993285587855745, 60.736281394958496, 62.8635071345738, 59.464212145124165, 60.150930404663086, 59.25554384504046, 58.599661690848215, 56.829417024339946, 50.58662387302944, 48.780203410557334, 46.69701187951224, 44.5763452393668, 45.322477545057026, 43.23037147521973, 42.24852500643049, 41.797343730926514, 42.54433066504342, 43.89774594988142, 47.23984684262957, 48.9196537562779, 49.39137390681675, 52.39807135718209, 50.13512645448957, 48.52432210104806, 45.567349433898926, 40.96971947806222, 43.764166831970215, 39.20150715964181, 39.72921936852591, 40.19850764955793, 39.70995896203177, 39.36215993336269, 39.381448132651194, 40.404914311000276, 41.078639439174104, 42.067583492824006, 42.171083859034944, 43.123796531132285, 46.088512965611045, 45.4586900302342, 45.745087827954976, 48.944653374808176, 47.01372119358608, 46.282339913504465, 49.597172600882395, 49.71371473584856, 49.75847503117153, 49.07988616398403, 49.422116211482454, 51.927032130105154, 49.3489898954119, 50.23104286193848, 53.727254799434114, 52.07820756094796, 50.12836585726057, 45.80829211643764, 38.939191818237305, 41.0366792678833, 47.58321986879621, 49.09930290494646, 49.47066674913679, 36.58964456830706, 36.147805145808626, 46.23196199962071, 55.296317849840435, 47.62706300190517, 39.26984964098249, 38.55706868852888, 36.71801948547363, 40.87485572269985, 45.713084425245015, 50.186775888715474, 48.27313429968697, 50.31012378420149, 46.34625291824341, 47.681415285382954, 47.699167932782856, 47.45768329075405, 44.64093916756766, 44.66288505281721, 42.902444294520784, 46.80784259523664, 42.19649689538138, 42.71745545523507, 43.50045837674822, 42.98118822915213, 42.75315529959542, 40.86209883008684, 39.76341840199062, 37.33043370928083, 38.673114027295796, 38.6166946547372, 37.81373650687081, 35.9662869317191, 38.97827196121216, 38.137720584869385, 39.45720086778913, 41.1226875441415, 42.61040455954415, 40.49716901779175, 42.964255469185964, 42.53937659944807, 43.730124132973806, 46.6556909424918, 48.06571667534964, 47.17237983431135, 46.33256149291992, 46.140558447156636, 46.2300477709089, 43.98749930518014, 44.61339998245239, 43.25315114430019, 44.565690176827566, 43.398941721235005, 45.69486277444022, 45.668226855141775, 49.21443802969796, 54.8586334500994, 59.20007637568882, 60.13491480691092, 64.09506838662284, 60.03738294328962, 63.31831536974226, 62.873158182416645, 68.1568602153233, 62.93213449205671, 69.21489020756313, 65.04610306876046, 69.97660732269287, 64.41761071341378, 80.14347553253174, 8.227974261556353, 0.18395734392106533, 0.13017083651253156, 1.5560195446014404, 63.25480188642229, 63.826006344386506, 62.50769683292934, 42.124016761779785, 30.081986086709158, 37.195350306374685, 59.54312283652169, 47.27439328602382, 1.1695527051176344, 0.10093404499015637, 0.11599775989140783, 0.03821195063314267, 0.045862897764891386, 0.04495328086029206, 0.1556886522365468, 0.1587806548923254, 0.09976970603955643, 0.10213394596108369, 0.291358621524913, 0.09112983143755368, 0.33301554194518496, 0.3490908236375877, 17.674697296960012, 77.12897872924805, 50.69720097950527, 47.21692473547799, 52.0734098298209, 66.82094396863664, 73.81741864340646, 63.88432952335903, 0.744875387421676, 0.2107623948582581, 0.14608572609722614, 1.7678494921752383, 67.34644317626953, 72.04457187652588, 67.2365504673549, 69.51776913234166, 71.97911984579903, 67.23550823756626, 67.54777417864118, 65.18346200670514, 64.31349195752824, 66.28224318368095, 63.909030369349885, 63.471634319850374, 61.94912420000349, 59.68829154968262, 59.79189613887242, 53.1013263293675, 49.37570571899414, 49.61124617712838, 48.46400131498064, 47.627142906188965, 45.954544748578755, 44.22260897500174, 45.82737186976841, 45.00647347314017, 48.01511294501168, 49.27005141122, 51.17395857402256, 51.63665648869106, 54.6554160118103, 54.29219198226929, 51.50622143064226, 47.717910698481965, 44.30084221703665, 46.12262862069266, 42.144399302346365, 42.06177132470267, 44.356104714529856, 41.817246845790315, 42.516794954027446, 41.32935128893171, 43.410903045109336, 43.47799137660435, 44.708701474326, 43.928846086774556, 45.234495980399, 48.49839489800589, 46.43458884102957, 46.82692929676601, 52.47997324807303, 50.974989959171836, 49.50405284336635, 53.21727786745344, 52.11344187600272, 52.82036549704415, 51.34347030094692, 51.43551308768136, 54.944443702697754, 54.7055264200483, 53.342213426317485, 55.2475380216326, 54.05949681145804, 50.39553451538086, 46.873999868120464, 41.25021825517927, 42.615452425820486, 48.68624986921038, 52.16738421576363, 51.38216829299927, 38.95503371102469, 38.07346364430019, 47.73416600908552, 56.63606950214931, 48.608127798352925, 39.33541284288679, 39.63843420573643, 36.59413310459682, 42.46768856048584, 45.045744691576274, 51.299835613795686, 51.918124539511545, 53.009155000959126, 49.77507427760533, 50.717159679957796, 50.89318881716047, 50.03638907841274, 48.83214814322335, 46.30286489214216, 45.20952068056379, 50.93205009187971, 45.589531557900564, 46.278059823172434, 46.36902911322457, 44.062018735068186, 43.39324767248971, 43.66362639835903, 43.0928110395159, 40.97144610541207, 40.930479526519775, 41.37265593664986, 40.861261572156636, 37.201568944113596, 41.876014709472656, 42.08045155661446, 40.98225055422102, 43.59436328070504, 43.57501254762922, 43.227418490818565, 45.73171949386597, 43.97313043049404, 46.99166761125837, 49.16619668688093, 50.98462363651821, 50.240131105695454, 49.7893146106175, 48.97517333711897, 49.163396562848774, 45.93722983769008, 48.1786526952471, 46.1801666532244, 47.97895451954433, 47.65865298679897, 47.96922704151699, 48.371468680245535, 50.59169258390154, 57.487262044634136, 63.1788580758231, 64.83331448691231, 67.24324853079659, 62.441841806684224, 64.64911079406738, 62.3011268888201, 70.64170973641532, 66.00463485717773, 71.95499570029122, 67.40455790928432, 73.87380327497209, 64.2523478099278, 94.55859048025948, 9.743919202259608, 0.2743600165205342, 0.49141357094049454, 2.928356945514679, 70.0828035899571, 71.68013886043003, 70.16551494598389, 52.20422009059361, 40.198441641671316, 46.57642241886684, 71.23956053597587, 57.1566424369812, 1.9354124665260315, 0.3646902622921126, 0.28227667457291056, 0.1207104434392282, 0.11134425138256379, 0.20202111319771834], [0.06486462296119758, 0.11981544217893056, 0.11815155217690126, 0.0234661073357399, 0.07242125033267907, 0.011595814871335668, 0.14086103359503405, 0.17063202895224094, 11.854214787483215, 47.31133338383266, 40.36687987191336, 31.981397765023367, 35.9694379397801, 51.723116397857666, 60.30733435494559, 59.21707166944231, 1.9484019066606248, 0.031874219820435555, 0.13249585032463074, 0.035463812561439614, 42.498847757067, 70.50692858014787, 60.11147158486502, 62.529173714774, 58.93662847791399, 64.60012599400112, 59.75914927891323, 60.095087732587544, 57.15953983579363, 60.35852868216378, 59.543435505458284, 58.74210671016148, 56.90798377990723, 57.011251381465364, 52.98692076546805, 50.11023105893816, 44.43136065346854, 44.55730022702898, 43.304373264312744, 40.94127355303083, 38.92958245958601, 40.83078677313668, 40.57231725965227, 41.814957414354595, 45.14692783355713, 48.09952660969326, 48.831477642059326, 51.23893117904663, 50.29920816421509, 48.47089045388358, 46.02161223547799, 40.804345403398784, 40.72994409288679, 39.65464435304914, 38.719083309173584, 37.8182041985648, 37.09839514323643, 38.710088866097585, 36.332516057150706, 37.659611565726145, 34.997777530125205, 38.00944294248308, 38.236968653542654, 38.84471716199602, 41.25820868355887, 40.82581533704485, 43.03546755654471, 43.09840086528233, 44.439135687691824, 46.9900347845895, 43.64009632383074, 43.916916029793875, 45.1903749193464, 45.98682260513306, 45.890402453286306, 49.625931194850374, 47.72156892504011, 49.90818439211164, 49.14831897190639, 48.52795600891113, 49.86752700805664, 48.18437801088606, 50.265366962977815, 38.81623649597168, 33.880955355507986, 38.953425203050884, 41.603957993643625, 42.45644290106637, 38.090806347983225, 32.947930404118125, 39.767503942762104, 48.041880880083355, 40.56343051365444, 36.852776323046, 36.31695556640625, 40.5146541595459, 46.27082674843924, 48.10854884556362, 47.29641907555716, 45.80285515104021, 47.51142760685512, 47.39842905317034, 45.27279792513166, 45.073450633457725, 44.32567507880074, 43.76772778374808, 44.076415402548655, 43.69115168707711, 43.25164685930525, 44.42973130089896, 42.41519144603184, 42.67033624649048, 40.41720567430769, 39.819521631513325, 37.5273699760437, 37.227541310446604, 37.25475740432739, 35.98646102632795, 35.23853955950056, 36.18498495646885, 33.38553837367466, 35.12779222215925, 35.00153997966221, 36.80049807684762, 39.7555113519941, 38.80011667524065, 41.70530441829136, 39.207336698259624, 39.36661720275879, 39.97097846439907, 41.7844409261431, 42.351893356868196, 42.772884709494456, 44.18465791429792, 44.179936613355366, 44.03224917820522, 41.807995319366455, 40.5775214603969, 40.263827664511545, 41.34341791697911, 39.49700709751674, 41.858314173562185, 40.89388336454119, 43.990424496786936, 45.28367533002581, 53.48259483064924, 57.20611708504813, 61.187650271824424, 61.04772744859968, 64.40185219900948, 60.73173032488142, 64.5686923435756, 64.31577791486467, 66.59464808872768, 65.31997326442173, 67.00635664803642, 63.40627956390381, 58.50072629111153, 2.409604004451207, 0.20790467677371843, 0.2146559509315661, 3.1625626981258392, 55.55481168201992, 58.418542998177664, 51.00490542820522, 40.13275337219238, 28.43831327983311, 28.840132815497263, 51.11993285587856, 36.11081641060965, 1.8276936752455575, 0.03437603950234396, 0.029285900494349853, 0.10671215065355812, 0.010847337311133742, 0.01078654735881303, 0.08150369940059525, 0.03313443237649543, 0.1683595608919859, 0.023658112389966846, 0.048441775276192596, 0.023232243456212536, 0.26647098841411726, 0.27551507311207907, 17.638455493109568, 57.909229619162424, 46.01498365402222, 32.36798511232649, 35.186792850494385, 61.61883463178362, 63.156241689409526, 66.90405137198312, 1.5316349502120699, 0.019211723302890147, 0.17151162746761525, 0.07188893282519919, 41.65862989425659, 72.93780449458531, 62.22846957615444, 66.23660046713692, 61.82592569078718, 68.25167533329555, 63.059189251491, 64.28225285666329, 60.602472986493794, 62.236369677952354, 60.14032050541469, 61.41705894470215, 58.297289984566824, 58.311867305210654, 54.419309275490896, 51.74770607267107, 46.02551712308611, 46.42197438648769, 46.415390968322754, 43.379861967904226, 42.033711024693076, 42.298958505902974, 44.432979583740234, 46.65197713034493, 47.12016759599958, 50.20960419518607, 50.570062841687886, 53.439189434051514, 52.6301828793117, 50.190302099500386, 46.916036469595774, 42.055208751133506, 41.463965688432964, 42.04300076620919, 41.44909654344831, 40.984449659075054, 40.05921711240496, 40.96242734364101, 38.53918055125645, 39.46202291761126, 38.426446029118125, 41.21131181716919, 40.54664019175938, 41.93315322058541, 44.07512651171003, 42.13358095714024, 44.5448351587568, 46.16955327987671, 46.11281776428223, 49.555608476911274, 47.01328345707485, 48.43172345842634, 47.674296855926514, 48.68658685684204, 48.540897028786794, 49.62328740528652, 49.411940574645996, 51.710088525499614, 52.758502210889546, 50.26221942901611, 51.96629640034267, 49.60572583334786, 53.25530188424246, 42.33254262379238, 40.07390213012695, 42.40326138905117, 43.68177509307861, 45.08059338160923, 38.63009772981916, 35.82389749799456, 41.05753428595406, 48.39115987505232, 42.49204199654715, 39.0280419077192, 37.49195153372628, 40.87765237263271, 49.44514601571219, 48.79858486992972, 48.247769900730674, 49.73980869565691, 49.4624331338065, 47.911324228559224, 48.10626288822719, 49.266820498875205, 48.1766585622515, 47.425985608782085, 45.042930671146934, 45.23876912253243, 46.72748667853219, 46.24312775475638, 44.56991120747158, 43.38000440597534, 40.465728419167654, 41.283423696245464, 40.03817449297224, 38.80546678815569, 38.3293901171003, 37.329929964882986, 37.335485049656455, 38.10583182743618, 35.88261672428676, 36.89355182647705, 37.05364874431065, 37.51859092712402, 41.529612268720356, 39.99325091498238, 43.321893147059846, 42.69669771194458, 40.88164758682251, 41.95578350339617, 44.504563399723594, 45.05777897153582, 46.36937999725342, 45.96827438899449, 46.57434490748814, 47.68433352879116, 43.81116097314017, 43.92440618787493, 43.52811915533883, 43.86353996821812, 43.5549669946943, 43.8313559123448, 42.840824195316856, 46.30404608590262, 47.73781728744507, 54.942404406411306, 60.00103691646031, 63.64413029806954, 64.1345966884068, 65.25714070456368, 63.241787910461426, 67.03651182992118, 66.6988502229963, 68.58158275059291, 66.89280223846436, 70.24276501791817, 64.28058528900146, 59.74277932303292, 2.5889059603214264, 0.23090017427291187, 0.3489086234143802, 4.496306547096797, 63.17142350333077, 65.14455209459577, 60.611783572605674, 46.89819349561419, 26.636648859296525, 38.14140313012259, 60.02445234571184, 47.355600357055664, 3.1769441664218903, 0.08158170378633908, 0.11468438750931195, 0.06560438897992883, 0.03762191015162638, 0.029503374360501766, 0.16866009762244566, 0.18685745687357017, 0.25862956632460865, 0.17585807852447033, 0.14936678217990057, 0.09358236233570746, 0.3354128875902721, 0.3587209997432572, 24.799430506569998, 70.15068054199219, 52.611787523542134, 40.74321862629482, 47.23822791235787, 68.93607289450509, 70.20441790989467, 72.99823992592948, 2.1828462864671434, 0.1540775794003691, 0.39478296467236107, 0.26969484399471966, 47.7656170300075, 76.22874927520752, 65.82892881120954, 68.9255324772426, 62.803655351911274, 70.5462623323713, 65.35021877288818, 66.80114160265241, 62.04379340580532, 64.66521671840123, 62.10454150608608, 64.02587127685547, 60.832819666181294, 59.18877165658133, 58.06753737585885, 54.18237222943987, 48.47953053883144, 50.82405424118042, 49.33633722577776, 45.933106081826345, 42.93876600265503, 43.94359711238316, 46.455318791525706, 48.49750205448696, 48.806213991982595, 53.346827030181885, 54.32895837511335, 56.07383516856602, 55.10639926365444, 52.27503265653338, 49.45854909079415, 43.27709116254534, 45.16333253043038, 43.85092551367623, 44.51650735310146, 42.57214777810233, 43.29271766117641, 43.47129331316267, 41.963395254952566, 43.17677654538836, 42.483009338378906, 43.257288796561106, 43.44800642558506, 44.614303248269216, 47.28547913687569, 43.844439370291575, 46.09710093906948, 47.607135568346294, 50.67992775780814, 53.025900159563335, 48.66645792552403, 51.19492823737008, 51.387466294424875, 52.29251085008894, 51.696136542728965, 52.81008563722883, 52.40664890834263, 55.898639815194265, 54.84920127051217, 53.29258591788155, 53.67889881134033, 49.999056407383506, 54.36616597856794, 41.2123783656529, 39.00688464300973, 43.31944738115583, 46.97956732341221, 46.35256883076259, 41.08110952377319, 37.68178326742989, 46.34688867841448, 52.46083443505423, 46.72557592391968, 40.7660608291626, 37.75667095184326, 40.395687103271484, 50.27660567419869, 52.3145227432251, 53.107107230595176, 51.23062113353184, 53.21545396532331, 50.58616181782314, 50.085888045174734, 51.76719924381801, 51.26822131020682, 51.459890842437744, 48.152433667864116, 49.09251798902239, 51.10693277631487, 49.89928722381592, 46.70801782608032, 48.247478076389854, 43.593102182660786, 43.644543170928955, 41.22926943642752, 42.076630047389436, 42.22233724594116, 41.23032208851406, 40.405015059879844, 40.16729286738804, 38.089614731924875, 40.432123456682476, 39.49579463686262, 41.60666084289551, 44.00353227342878, 42.031438963753835, 45.189277103969026, 44.66432332992554, 43.49110957554409, 44.421275343213765, 47.775382723127095, 47.372348989759175, 49.68224287033081, 49.11608280454363, 49.94356461933681, 49.91394097464425, 48.43345355987549, 46.38838332039969, 45.24388994489397, 46.08598729542324, 45.76549816131592, 45.92584521429879, 45.64719813210623, 49.31045518602644, 50.245884214128765, 58.866743496486116, 62.77694647652762, 66.26578984941754, 66.69548034667969, 68.34876251220703, 66.31651169913155, 71.01388999394008, 68.60243429456438, 72.60272761753627, 69.02535724639893, 74.08142239706856, 65.16116523742676, 68.87483842032296, 3.79999977350235, 0.3503439149686268, 0.7308909978185381, 5.612642347812653, 69.73369829995292, 72.00365393502372, 67.6479880469186, 59.83962331499372, 43.328083992004395, 44.185456957135884, 68.89697538103376, 59.392881938389365, 4.974452912807465, 0.25389279478362625, 0.16435458936861583, 0.23889668232628278, 0.11436995438167027, 0.11133868061006069], [0.033891195697443824, 0.07846761481570345, 0.0689817698938506, 0.09564468810068709, 0.07244554867169686, 0.07769303995051555, 0.13549964342798504, 0.00955961864175541, 8.901213015828814, 47.693696226392476, 40.053707190922324, 43.75513069970267, 43.139798232487266, 46.45073298045567, 57.304190908159526, 65.26735455649239, 5.353988707065582, 0.33734492106097086, 0.5877658150025776, 0.3875715216355664, 22.372065169470652, 71.1167094366891, 60.27542127881731, 63.74674129486084, 63.028290612357004, 64.67919649396623, 61.57331698281424, 60.26026030949184, 60.915399006434846, 57.86774887357439, 57.433170318603516, 59.05983393532889, 57.03047704696655, 57.03472934450422, 51.20017760140555, 47.977988719940186, 43.896088804517476, 42.500157492501394, 40.89476578576224, 42.87218836375645, 39.61249310629708, 40.798422064099995, 42.02710676193237, 43.10112803322928, 46.20411014556885, 49.510021345955984, 51.10096079962594, 52.39939151491438, 51.220487185886924, 47.916177545275005, 44.04981075014387, 40.74093266895839, 39.395400115421836, 38.433032921382356, 39.18895523888724, 38.82854175567627, 37.362662928445, 38.26279163360596, 38.4111773627145, 35.82188946860177, 36.060810225350515, 37.01232780729021, 37.3456745828901, 39.91784906387329, 39.97020721435547, 43.30299057279314, 41.81677436828613, 45.13947589056832, 43.52287673950195, 43.79523570196969, 45.150394984654014, 44.256794112069265, 45.664975098201204, 47.14410066604614, 45.33552278791155, 46.54760129111153, 48.24266297476632, 48.44879518236433, 47.14667844772339, 48.50362341744559, 48.75078126362392, 47.95492764881679, 49.014788491385325, 47.12595544542585, 38.45201192583357, 43.5798693384443, 33.588967732020784, 37.57252631868635, 39.18157972608294, 36.05195127214704, 34.601594720567974, 40.48576354980469, 34.80072661808559, 36.08227668489729, 36.69489240646362, 42.992048263549805, 49.09227132797241, 45.54655694961548, 48.50586421149117, 46.483323505946565, 44.45354625156948, 45.677308150700156, 44.24494743347168, 43.888060161045615, 42.87408174787249, 43.76297174181257, 43.148848261152, 41.69929770060948, 43.79050397872925, 41.8122615133013, 42.38120085852486, 42.104242188589915, 40.47998264857701, 38.76852669034685, 38.364930152893066, 34.76216411590576, 35.195436409541536, 35.44882678985596, 36.89700508117676, 36.56491592952183, 34.53527763911656, 36.484778881073, 35.58356278283255, 38.19047130857195, 40.37596811567034, 38.319051197596956, 39.96924488885062, 40.741954054151265, 40.73284149169922, 38.80764157431466, 39.633851868765696, 40.74864169529506, 42.158333914620535, 42.7776893888201, 42.082067012786865, 42.35369641440255, 42.95878723689488, 39.82186317443848, 41.000246388571604, 40.52292946406773, 40.47931909561157, 42.118228912353516, 38.69825955799648, 40.36875935963222, 43.70033720561436, 47.35059417997088, 52.2291328566415, 55.13062415804182, 56.13829013279506, 58.298679624285015, 59.101036752973286, 63.23068468911307, 61.96260370526995, 62.17711544036865, 64.26458358764648, 69.39416067940849, 64.02027797698975, 48.68790701457432, 0.2498378695121833, 0.09977364154266459, 0.08124928948070322, 5.541926622390747, 54.4469005720956, 60.58001640864781, 52.34009906223842, 41.3199052129473, 24.921763965061732, 32.38615812574114, 47.422761644635884, 55.14121668679373, 5.94483528818403, 0.2903776227363518, 0.12655250781348773, 0.038583434985152314, 0.1717855249132429, 0.05188966615657721, 0.03427615236224873, 0.01079404347443155, 0.08110223058611155, 0.061673350632190704, 0.15584198758006096, 0.03992917688031282, 0.24293448137385504, 0.036514357796737125, 17.196548325674875, 57.26910250527518, 46.232517855507986, 47.11260100773403, 41.52274397441319, 54.82675164086478, 60.279479026794434, 70.22362967899868, 5.335356244019099, 0.2851585213627134, 0.5159577024834496, 0.46360253755535397, 21.689962250845774, 72.57539340427944, 61.46093681880406, 66.42397253853935, 63.493013926914756, 67.29392869131905, 64.25931685311454, 64.148590360369, 61.43342890058245, 60.908040864127024, 58.556165967668804, 59.48164517538888, 57.933548314230784, 60.53579112461635, 54.42513534000942, 49.29865019662039, 45.602187701633994, 45.907766001565115, 43.45125470842634, 45.0143666267395, 42.249855586460654, 43.48185804912022, 44.46028600420271, 45.9532801764352, 48.85260363987514, 52.20544992174421, 51.662969316755024, 55.55030230113438, 52.05846078055245, 51.59649242673601, 46.76313441140311, 43.54838357652937, 41.30182947431292, 40.4378661428179, 42.52702270235334, 40.69692277908325, 39.201548848833355, 38.527222701481406, 40.22684587751116, 38.585292271205354, 39.47129528863089, 39.618843759809224, 39.98726851599557, 40.50429439544678, 42.3078522000994, 44.98487499782017, 45.01812560217721, 46.246674810137065, 45.532292297908235, 46.326346329280305, 47.72544254575457, 47.240100451878135, 48.192556040627615, 49.72510978153774, 47.43136351449149, 48.3884813444955, 50.33283397129604, 49.940462248665945, 49.611013412475586, 52.039961201804026, 52.20209394182478, 49.6043153490339, 51.846238476889475, 45.64222322191511, 37.90645326886858, 42.95041118349348, 38.266519342150005, 41.635617460523335, 41.535768372671946, 37.8421859060015, 40.690346309116904, 42.49333783558437, 37.12395756585257, 38.17687020983015, 34.93854066303798, 45.06220497403826, 49.599691322871614, 47.80729232515608, 51.19236435209002, 48.958063398088726, 47.51994262422834, 47.6202711377825, 46.05713837487357, 47.261761460985454, 45.05704593658447, 46.12041561944144, 45.88756758826119, 44.89145646776472, 45.9927077293396, 45.46988705226353, 44.02612086704799, 43.40256520680019, 42.886498178754536, 39.97147526059832, 40.372869219098774, 36.276801926749094, 36.53958279745919, 37.90606069564819, 38.88564205169678, 38.55444574356079, 36.7921359198434, 38.18894617898123, 38.02804674421038, 38.59539842605591, 41.54005193710327, 40.476317473820274, 42.707651547023225, 41.40203292029244, 41.04424238204956, 41.29745558329991, 42.081302710941856, 42.82996416091919, 44.19861684526716, 45.7518310546875, 44.537331104278564, 45.18333986827305, 46.618299211774556, 42.31747545514788, 44.41361495426723, 43.21677385057722, 42.751032624925884, 44.27351842607771, 41.80636249269758, 43.623542240687776, 45.84591313770839, 48.13506664548601, 52.78987332752773, 58.49003996167864, 58.552136012486045, 62.017362458365305, 60.70861366816929, 65.76690224238804, 63.95124067578997, 66.46547412872314, 66.9884511402675, 72.32097121647426, 63.461740085056846, 49.80889810834612, 0.09807346348783799, 0.0439404621720314, 0.17551402055791446, 6.7546365431376865, 62.364973885672434, 66.63671248299735, 59.54308809552874, 51.21373701095581, 33.62617880957467, 42.38064152853829, 56.82154818943569, 64.04424926212856, 8.028901423726763, 0.36450811635170666, 0.12407767346927098, 0.1254656168499163, 0.13397287178252423, 0.018997131514229944, 0.24364865305168287, 0.13020215768899235, 0.09949369156467062, 0.10222179588994809, 0.21827931436044828, 0.20510092936456203, 0.4303796174270766, 0.11890072269099099, 24.616748469216482, 70.77176611764091, 50.93194934300014, 55.442045892987935, 58.08746828351702, 61.36714308602469, 65.57818916865757, 78.13746111733573, 6.882729189736502, 0.548352158495358, 1.2081411544765746, 0.46701160605464664, 27.857395240238734, 76.05320998600551, 66.23714242662702, 69.71629306248256, 67.35913753509521, 70.0716586794172, 68.62036759512765, 67.27831608908517, 63.67814173017229, 63.131492206028526, 60.50396837506975, 62.96609728676932, 59.48106152670724, 63.31391021183559, 55.48082031522478, 51.66680472237723, 48.4800968170166, 48.07777874810355, 46.5827522277832, 48.75850766045706, 43.024496350969585, 47.30831439154488, 46.27997405188424, 49.89416640145438, 49.88127401896885, 54.19930498940604, 54.48572015762329, 56.84881639480591, 54.854909215654644, 55.18742915562221, 49.65334531239101, 45.13312871115548, 43.63124779292515, 42.97057485580444, 44.148662771497456, 43.79984930583409, 41.826331615448, 41.65006971359253, 43.65420116697039, 41.93746110371181, 41.88473122460501, 41.863073689596995, 42.41158185686384, 44.551085063389365, 43.76109920229231, 47.892313957214355, 46.9090187890189, 48.011027404240195, 48.79722302300589, 49.89901624407087, 51.62030390330723, 49.74218150547573, 51.661673477717805, 54.38385956627982, 51.874441214970176, 52.25654002598354, 52.89051798411778, 52.6628463608878, 52.44265447344099, 53.55311209814889, 55.70151942116873, 51.13793216432844, 54.12286785670689, 47.96974120821272, 39.90242406300136, 45.40864910398211, 40.80015563964844, 45.415197781154085, 43.537797995976035, 37.97500419616699, 43.36744553702218, 45.535415513174875, 39.89733450753348, 38.995444434029714, 36.5559458051409, 46.539131437029155, 53.24085310527256, 50.208179814474924, 53.77472141810826, 50.64474902834211, 50.913727692195344, 50.630112648010254, 49.751224585941856, 50.345271246773855, 46.965507643563406, 48.93711805343628, 48.68112904684884, 47.93236684799194, 49.23248597553798, 46.70805951527187, 47.78583628790719, 46.950398785727366, 43.64439378465925, 42.16370487213135, 43.0699063028608, 40.29565388815743, 39.157518114362446, 40.22328839983259, 41.09426941190447, 40.742975439344136, 38.91987582615444, 40.75722966875349, 40.35537365504673, 41.74014616012573, 45.182836123875205, 42.85666956220354, 45.33228145326887, 44.28285680498396, 44.59075927734375, 43.927678789411274, 46.336268356868196, 45.93567344120571, 47.54486928667341, 49.60230384554182, 47.32413196563721, 48.89096464429583, 50.45531334195818, 45.84964084625244, 45.938518728528706, 45.992891856602256, 45.45363174165998, 46.973077705928254, 44.53429126739502, 47.22008269173758, 48.735536915915354, 51.9486722946167, 57.43476145608084, 62.315718105861116, 61.389967918395996, 65.74304212842668, 62.28655651637486, 69.11646897452218, 67.24406841823033, 68.0319663456508, 68.69057219369071, 75.30627168927873, 64.84992068154472, 55.09969425201416, 0.571508278804166, 0.15260865965059825, 0.5381507916109902, 8.628695113318306, 68.96009976523263, 72.06782054901123, 66.29715401785714, 60.71741703578404, 37.21930422101702, 46.218086447034565, 64.39712047576904, 74.59818771907261, 9.996982148715428, 0.4751204795071057, 0.2665970873619829, 0.2096399622304099, 0.386981549007552, 0.16502940601536206], [0.077620212786964, 0.045814406259783676, 0.1380363737366029, 0.0599758867174387, 0.06905980142099516, 0.006707917466493589, 0.018682282783889344, 0.0841633395424911, 20.44958026068551, 50.44129535130092, 40.909812109810964, 23.61086470740182, 21.556800024850027, 47.35025371823992, 52.18989290509905, 71.54265485491071, 5.757785439491272, 0.14432910749954836, 0.3803695780890328, 0.2573860559080328, 5.797845712729862, 60.476133891514365, 62.96245643070766, 63.10703454698835, 63.14340141841343, 60.799572535923545, 58.67500100816999, 56.82794748033796, 57.55132443564278, 57.52085311072213, 58.525100571768625, 58.833704812186106, 58.268639087677, 55.4282363482884, 49.77877766745431, 47.07201310566494, 41.865140778677805, 43.04212045669556, 41.84749582835606, 40.312885420663015, 40.98808356693813, 42.512438433510916, 44.11586727414812, 45.178319794791086, 48.41428000586373, 52.80343273707798, 52.99954216820853, 51.32961211885725, 49.401872634887695, 46.20732716151646, 40.18403802599226, 40.81480939047677, 39.51904330934797, 40.705621923719136, 38.70302949632917, 39.20417526790074, 39.794848578316824, 39.874367237091064, 38.217600549970356, 37.75001457759312, 38.03654786518642, 39.74607917240688, 36.11767775671822, 36.68141637529646, 39.67717041288103, 40.37396008627755, 41.089530740465435, 45.08970594406128, 45.773804732731406, 44.62381533214024, 43.93740974153791, 45.36968013218471, 45.55516576766968, 45.98696851730347, 47.51919221878052, 47.97800261633736, 47.96809795924595, 45.10810477393014, 48.401088850838796, 49.29428325380598, 47.72592544555664, 47.96547848837716, 51.31480898175921, 45.47170400619507, 38.98432036808559, 39.59168325151716, 30.906619140080043, 32.665500027792795, 36.26324251719883, 35.76877743857247, 38.01733957018171, 36.49417979376656, 38.12685360227312, 37.90941667556763, 38.24660927908761, 47.09323985236031, 48.33326053619385, 48.05911588668823, 48.13606718608311, 45.04213162830898, 44.08837672642299, 44.69872038705008, 45.58397299902779, 44.186408860342844, 42.59054660797119, 43.711096491132466, 44.416137150355745, 42.827507972717285, 42.474852153233115, 42.610581738608225, 42.21430165427071, 41.56983886446272, 41.44902011326381, 35.70563915797642, 37.23896067483084, 37.2132453918457, 34.31487730571202, 34.57458012444632, 36.419288635253906, 35.9154052734375, 34.53073351723807, 35.59444713592529, 37.46389818191528, 36.63014909199306, 36.41961520058768, 38.391837051936555, 39.92851454871041, 39.08477742331368, 38.86463417325701, 36.50845486777169, 39.505188601357595, 35.871676785605295, 39.33867849622454, 38.05074650900704, 40.65096739360264, 41.35719272068569, 42.34805795124599, 40.22930901391165, 41.03915977478027, 39.19333607809884, 40.02381256648472, 40.23810543332781, 42.57066433770316, 41.16181632450649, 42.48833513259888, 42.52839844567435, 44.900259835379465, 46.328118119921, 51.2512538092477, 54.38169867651803, 56.54170254298619, 59.34275763375418, 61.38848100389753, 59.3346768787929, 69.11576025826591, 62.27976812635149, 74.2783899307251, 31.074432032448904, 0.3594015160841601, 0.21166597280119145, 0.18202973449868814, 5.162788612501962, 58.590552602495464, 57.61263186591012, 55.18429899215698, 37.405981472560335, 22.517160926546367, 33.03557498114449, 45.245161465236116, 59.60445458548409, 6.551351359912327, 0.23966057705027716, 0.10524937843105622, 0.02216985439216452, 0.07002761627414397, 0.01822778645769826, 0.04938922390075667, 0.03374379414266773, 0.08990242265697036, 0.05265580004613314, 0.038055039410080226, 0.047008868772536516, 0.06216370753411736, 0.15129523298570088, 27.653149468558176, 60.270501954214915, 49.5781067439488, 25.747126579284668, 24.33513798032488, 55.11726624625069, 56.96829761777605, 75.23001520974296, 6.524715006351471, 0.27073745376297403, 0.48194974447999683, 0.9751237609556743, 5.832452952861786, 60.18771416800362, 64.9782052721296, 65.09986822945731, 64.94842529296875, 63.42228821345738, 61.194084303719656, 58.7360965183803, 59.21704387664795, 60.01806695120675, 60.18483761378697, 61.827961512974326, 59.52730873652867, 58.35860783713204, 50.94289970397949, 48.672388213021414, 44.581587655203684, 46.166822637830464, 44.9062248638698, 42.77328423091343, 43.07331786836897, 45.86915833609444, 44.86991357803345, 48.66975484575544, 49.88801029750279, 54.0868171283177, 55.403420857020784, 53.74046332495553, 51.15021310533796, 47.39939832687378, 42.88823870250157, 42.304284300122944, 40.69084310531616, 42.84872777121407, 39.88134322847639, 40.12426267351423, 40.859614849090576, 40.80550575256348, 41.33844995498657, 39.676836899348665, 41.3770888873509, 42.11385154724121, 37.76982389177595, 38.66352203914097, 40.96568604878017, 41.832657950265066, 43.17081151689802, 47.33582925796509, 47.6777674811227, 47.058068071092876, 46.003595556531636, 48.033810547419954, 48.86125067302159, 48.80681848526001, 48.235878058842246, 48.57345281328474, 48.55500534602574, 49.10811669485909, 49.13826840264456, 53.19338648659842, 50.18684189660208, 51.39314644677298, 52.29007550648281, 47.423258440835134, 40.35842391422817, 40.334751401628765, 35.42098535810198, 34.76146929604666, 37.01377650669643, 36.77769756317139, 40.77678884778704, 39.56824697766985, 39.64503499439785, 39.964113644191194, 39.022431237357004, 49.379277093069895, 51.72398144858224, 50.902957984379356, 50.46795906339373, 48.68621860231672, 47.85328939982823, 46.80439281463623, 49.41482407706124, 45.20798512867519, 46.004022870744976, 47.05710574558803, 46.83351271493094, 43.74041441508702, 44.26246731621878, 45.19238642283848, 44.68680770056588, 43.57259804861886, 40.9541346686227, 39.451840332576204, 38.62218025752476, 38.71870810644967, 36.669125011989046, 36.48456348691668, 38.41374124799456, 37.9610070501055, 36.73074163709368, 36.62255818503243, 39.03081423895699, 38.90957512174334, 37.65646750586373, 41.829201221466064, 40.94438982009888, 39.43555722917829, 40.37384196690151, 39.28311375209263, 41.93586996623448, 40.62981360299246, 42.145146233694895, 40.77847726004464, 42.202875341687886, 42.166136741638184, 44.04618031638009, 43.804195404052734, 43.74258572714669, 41.44552864347185, 42.16535159519741, 44.89819622039795, 45.8291506086077, 43.420644419533865, 45.84578807013375, 44.95836067199707, 46.08410085950579, 47.86185652869088, 52.64264794758388, 57.27880219050816, 59.931686946323936, 62.167881284441265, 64.10981246403286, 63.418126242501394, 71.94574069976807, 64.28941644941057, 75.1943917955671, 31.76515940257481, 0.37238620647362297, 0.21928438757147106, 0.1915956669087921, 6.2059138502393445, 65.88912105560303, 64.28221811567033, 64.32233006613595, 43.483612469264436, 30.435180391584122, 39.68113783427647, 54.8143630027771, 68.38285037449428, 8.7420289175851, 0.19149698077567986, 0.10584619069205863, 0.02700587355398706, 0.030268602405807803, 0.013437428461786891, 0.24044938758015633, 0.1314372814127377, 0.1947184479130166, 0.10744960965322596, 0.156949750280806, 0.17667450542960847, 0.12827069418770926, 0.24540272035769053, 33.80163124629429, 70.69048609052385, 52.65155553817749, 31.150521755218506, 31.94410330908639, 63.787700925554546, 62.43560927254813, 82.99953256334577, 7.886597105434962, 0.3775278462895325, 1.0195375148739134, 1.3275160917213984, 8.02936087335859, 64.91874953678676, 68.51508154187883, 69.26493808201381, 67.7455963407244, 65.70365279061454, 64.05953529902867, 61.35817296164376, 60.746536936078755, 62.13445350102016, 63.70535087585449, 63.923496518816265, 61.03824315752302, 62.05962140219552, 53.85628284726824, 53.766852583204, 46.72334555217198, 47.877288477761404, 46.67802940096174, 44.986747537340435, 44.68015827451433, 47.754611083439414, 48.046529224940706, 49.50687728609358, 52.275116034916465, 57.29990039552961, 57.27673857552664, 54.98812355313982, 53.56049803325108, 50.52741827283587, 44.9652532849993, 44.4054855619158, 42.651114055088584, 44.88080140522548, 41.548949105399, 42.08698286328997, 43.9451813016619, 45.282469817570274, 43.28788866315569, 43.45561817714146, 43.78145047596523, 45.45311062676566, 40.18332583563668, 41.5146666935512, 42.67558561052595, 43.26001596450806, 46.86202464784895, 51.00649309158325, 50.78637416022164, 48.66261904580252, 50.35874727794102, 50.78405346189226, 51.789238929748535, 52.94072914123535, 53.28668342317854, 52.27272238050188, 52.44878625869751, 51.59775352478027, 53.45081377029419, 55.20827375139509, 49.28032432283674, 53.12308113915579, 55.84531933920724, 48.10584599631173, 40.56845753533499, 40.83483062471662, 37.05433661597115, 35.794148785727366, 40.458620412009104, 37.94215311322893, 43.89032874788557, 40.91899415424892, 41.811236654009136, 39.88385847636631, 39.4609181540353, 50.09561204910278, 53.57279634475708, 53.66905321393694, 53.01081214632307, 48.91594689232962, 51.30454649244036, 49.47724321910313, 53.76995842797415, 48.7325005531311, 47.95784936632429, 50.20323964527675, 50.62032263619559, 48.020897320338655, 48.43473897661482, 49.32697452817644, 46.20610427856445, 45.52210623877389, 44.94744505201067, 39.07032864434378, 40.33118002755301, 42.08923060553414, 38.42250640051705, 38.27433259146554, 41.18175070626395, 39.41140181677682, 38.60664755957467, 38.71978160313198, 42.51971319743565, 41.13808822631836, 40.70274189540318, 43.75265366690499, 43.50393942424229, 43.31565713882446, 42.35885197775704, 41.785844462258474, 46.11140380586897, 43.02131060191563, 44.469638279506135, 42.869680064065115, 44.14797837393624, 46.254244872501914, 47.01503092902047, 45.11938517434256, 46.946650232587544, 43.285234451293945, 45.51132263456072, 48.705034324101035, 49.67855337687901, 45.07205057144165, 49.233205114092144, 47.51090996606009, 50.292068890162874, 50.7772650718689, 56.36538852964129, 60.17533942631313, 63.40593910217285, 66.01460552215576, 66.40231500353131, 66.04783875601632, 75.84752246311733, 66.51582772391183, 76.70968273707798, 36.038162572043284, 0.47363627914871487, 0.3326959790928023, 0.5041395223566464, 7.678335274968829, 73.45381941114152, 70.00736004965646, 72.38385241372245, 54.02098989486694, 32.812193870544434, 47.94472074508667, 63.111856596810476, 78.29370525905064, 12.314156004360743, 0.4591074873294149, 0.2936340479978493, 0.1474478037229606, 0.20554623832660063, 0.15208037942647934], [0.0766551595713411, 0.0341987043752202, 0.07409029720085007, 0.05961180518248251, 0.0952568171279771, 0.06692574771919421, 0.1575911965753351, 0.03729239997587033, 20.03273524556841, 54.63977561678205, 37.95262404850551, 34.097992760794504, 23.762382337025233, 46.050183228084016, 49.359158584049766, 72.01110935211182, 10.84774042878832, 0.048048394599131176, 0.1053118918623243, 0.7072234792368752, 1.1364349850586482, 31.43314320700509, 63.160632950919016, 57.07816253389631, 65.84636184147426, 60.75934246608189, 58.4544095993042, 60.24862902505057, 60.63936097281319, 59.920576776777, 60.373960631234304, 56.82843732833862, 55.80168465205601, 51.5759848185948, 47.4459547315325, 42.040245805467876, 41.51732785361153, 41.409259046827046, 44.8820173399789, 40.241284234183176, 43.256746837071006, 45.04911456789289, 46.59797920499529, 50.29740163258144, 52.518285615103586, 52.39707081658499, 54.34746837615967, 50.86484364100865, 48.39381061281477, 41.340398924691335, 38.685110092163086, 37.97612633023943, 39.70877776827131, 39.65961231504168, 38.69285038539341, 38.71102339880807, 39.652149949754985, 36.04741062436785, 39.7273086139134, 37.31819098336356, 37.37823731558663, 39.476152079445974, 35.91970273426601, 36.90714250292097, 38.13628230776106, 39.95845086233956, 42.10795947483608, 47.314963817596436, 44.136809144701274, 42.41816527502877, 45.20156846727644, 44.81483520780291, 45.97504193442208, 45.95694187709263, 47.02232653754098, 47.365873268672395, 46.05854191098894, 47.640049185071675, 46.66171850476946, 49.658466134752544, 48.20234257834298, 49.376900809151785, 51.42263807569231, 50.89935881750924, 37.1581392288208, 38.60790170942034, 35.76412214551653, 33.605914388384136, 39.129593304225374, 37.1091822215489, 38.85583080564226, 33.14802810123989, 36.49910954066685, 39.25956630706787, 44.21338871547154, 50.078547273363384, 48.09001105172293, 46.43279273169381, 47.644645418439595, 44.266389574323384, 44.48645986829485, 44.39705392292568, 45.84917879104614, 43.467259883880615, 43.809802600315635, 41.59192023958479, 42.939492089407786, 43.32140677315848, 43.891200746808735, 42.65078054155622, 42.402542250497, 43.313402448381694, 38.38718523297991, 37.56551211220877, 36.493412017822266, 35.72158874784197, 34.60713938304356, 36.3880877494812, 36.91649825232369, 35.85702303477696, 35.81167214257376, 37.76250396456037, 35.89734690529959, 37.17084400994437, 37.40692295346941, 37.93033422742571, 37.55160876682827, 36.52957044328962, 39.530931677137104, 39.27302844183785, 37.017535482134136, 37.38428224836077, 37.75363458905901, 37.33005503245762, 40.40137072971889, 39.47361251286098, 39.55538238797869, 38.78737020492554, 38.991216455187114, 39.691723414829795, 39.53398193631853, 39.22198002679007, 42.682450430733816, 43.388599327632356, 43.8743965285165, 43.68467944008963, 43.454009669167654, 42.15829569952828, 45.74124200003487, 44.204098973955425, 50.36836011069161, 53.39132676805769, 56.04520859037127, 58.82691642216274, 66.75468594687325, 65.96150738852364, 76.89469936915806, 16.561581986291067, 0.6839450597763062, 0.6972097679972649, 0.11608139611780643, 5.502707515444074, 60.75686195918492, 61.0014454977853, 50.10646513530186, 44.19731753213065, 30.568151542118617, 40.84852205004011, 44.68964951378958, 50.56652273450579, 6.686358332633972, 0.6206971279212407, 0.1783638812069382, 0.11826542392373085, 0.08466643933206797, 0.04804074072412082, 0.09167134309453623, 0.04875921770664198, 0.09335249502743993, 0.042738091333636215, 0.1156899764069489, 0.024731676925772002, 0.22558925354054996, 0.07964777720293828, 26.719089235578263, 63.723214694431846, 46.40507984161377, 34.95878423963274, 30.361824784960064, 53.23080948420933, 54.04969637734549, 77.76998479025704, 12.178826808929443, 0.08499120654804365, 0.09630049898156098, 1.4451357402971812, 1.8928475848266055, 30.930527891431534, 65.3146162033081, 60.66767488207136, 67.88945184435163, 61.61952945164272, 60.894672530038015, 62.38809054238455, 62.203212874276296, 61.066570963178364, 62.98725455147879, 59.44430555616106, 57.1912270954677, 53.67635229655674, 49.09900413240705, 44.88479661941528, 43.99901247024536, 42.81492131096976, 46.17712681634085, 43.0205636705671, 45.391264711107524, 46.71140507289341, 48.64049250738961, 50.69355664934431, 54.682642527988975, 53.91339009148734, 54.91815866742815, 52.876538208552766, 51.29765040533883, 44.457711696624756, 39.10875218255179, 40.33619315283639, 41.19002948488508, 41.35507699421474, 42.56044353757586, 40.737357820783345, 41.33495501109532, 40.01246963228498, 40.87672478812081, 38.85760607038225, 41.4022969518389, 40.337179797036306, 38.333527769361226, 37.4438977922712, 39.59655046463013, 41.99154588154384, 42.7945213999067, 47.41138049534389, 47.99310105187552, 46.45469345365252, 48.09589270183018, 48.22809955051967, 49.43194791248867, 50.02771077837263, 50.70818608147757, 50.93612173625401, 49.62989861624581, 48.71171849114554, 49.92116710117885, 51.67925589425223, 51.15135260990688, 50.502387387411936, 51.6728253364563, 52.275063923427034, 38.39407089778355, 38.418156828199116, 36.86959791183472, 35.53894492558071, 40.109303201947895, 38.46497031620571, 39.399225098746165, 37.141772747039795, 36.86166654314314, 38.06178372246878, 44.00863225119454, 53.1754219191415, 51.564669677189414, 48.77528756005423, 50.08842413766043, 47.930695806230815, 47.74152067729405, 45.73733363832746, 47.05399295261928, 47.14172438212803, 48.10981689180647, 44.47185822895595, 46.13986710139683, 46.71995483125959, 46.73761020387922, 45.1186660357884, 43.653961454119, 43.56497934886387, 39.26814038412911, 40.2867671421596, 39.87977293559483, 36.39641169139317, 36.333113602229524, 37.24349784851074, 38.319909300122944, 38.441402026585166, 38.04435764040266, 37.349367550441194, 38.743978704724995, 39.9577317237854, 38.350425788334434, 39.037376812526155, 40.3507114137922, 39.492216314588276, 41.127304622105186, 41.186267035348074, 39.88209710802351, 39.30800914764404, 40.282417569841655, 39.4719831602914, 42.58393539701189, 41.00305693490164, 41.31030280249459, 41.13938406535557, 42.459604331425254, 42.96686799185616, 42.94244507380894, 42.515165601457866, 45.72912434169224, 45.69478634425572, 46.304859025137766, 46.02961308615548, 46.12026275907244, 45.23134844643729, 49.40915434701102, 46.61350842884609, 51.4028947693961, 53.35922956466675, 59.28539330618722, 62.42589569091797, 69.17101233346122, 67.78092098236084, 75.85013498578752, 17.817960466657365, 0.6604814816798482, 0.5887819890465055, 0.14560030214488506, 6.755563693387168, 67.88378211430141, 66.26993097577775, 57.7559870992388, 49.66450064522879, 24.271925006593975, 39.68970496313912, 52.51297371728079, 60.20499433789934, 10.663700887135096, 0.5414734418903078, 0.16515280439385346, 0.0991352079436183, 0.16514338632779463, 0.10395542572119407, 0.22169742094618933, 0.15038301050662994, 0.313922787883452, 0.13248128896313055, 0.12954562077564852, 0.09427413557256971, 0.3270898142031261, 0.17290586765323365, 34.44271373748779, 73.97508716583252, 52.86248547690255, 46.27424873624529, 36.966271672930034, 64.15102917807442, 59.78694902147566, 85.48796040671212, 13.648907559258596, 0.11854265976165022, 0.1318867565797908, 2.0794210476534705, 2.6589833199977875, 33.22660180500576, 69.42175197601318, 61.843115534101216, 72.19279779706682, 65.3514347076416, 61.95414774758475, 62.855037280491416, 65.13570008959088, 64.85895333971295, 66.70170593261719, 62.75505270276751, 60.495804241725374, 56.27771963391985, 51.09388753346035, 46.18513461521694, 48.6140580858503, 46.54624291828701, 48.19185427256993, 43.5802514893668, 48.335299832480295, 50.4134851864406, 52.46049049922398, 54.46494156973702, 57.345247813633506, 56.06720311301095, 57.38253879547119, 56.785698958805625, 52.47261163166591, 45.88107797077724, 43.05679505211966, 41.68184035164969, 43.296775409153526, 43.50291109085083, 44.42697286605835, 42.88776969909668, 43.15326731545584, 42.40919862474714, 44.482405594417024, 41.40822376523699, 43.59135471071516, 42.2799517086574, 41.1541976247515, 40.176075390407014, 42.343378339494976, 44.77842664718628, 46.8895012991769, 50.2144957269941, 49.92419651576451, 47.81443507330758, 50.126458576747346, 49.73786320005144, 52.6586183820452, 53.13677256447928, 53.27246740886143, 54.15495811189924, 51.108659403664724, 52.33567305973598, 51.52114268711635, 54.09234094619751, 53.77879306248256, 53.48897327695574, 55.51745121819632, 56.52077109473092, 39.09863907950265, 40.122327600206646, 38.28693314961025, 36.47787931987217, 41.7281049319676, 38.678610052381245, 40.835706097739084, 38.857220445360454, 40.08767345973423, 38.64148930140904, 46.063826016017366, 55.38032504490444, 52.83067314965384, 52.171518393925254, 52.502061571393696, 49.69099760055542, 49.41834681374686, 50.512900011880056, 51.95192057745797, 49.21979856491089, 50.15749617985317, 47.19290133884975, 49.46498312268938, 49.73172446659633, 50.61028943743025, 47.89302267347063, 46.12654740469796, 47.10394702638899, 41.73741899217878, 41.711592538016184, 41.386969225747244, 41.01542125429426, 39.212586062295095, 39.966156414576936, 40.42023161479405, 40.60226052148001, 40.10466527938843, 41.40884910311018, 39.502600397382466, 40.64590910502842, 41.47437408992222, 41.877435616084504, 42.66131748471941, 40.749628339494976, 43.71747841153826, 44.3405442237854, 41.39181212016514, 42.40573494774954, 43.24236059188843, 41.21377495356968, 46.018693992069785, 42.850016662052695, 43.59927913120815, 44.32791239874703, 44.275109563555034, 47.62700046811785, 45.16197068350655, 46.82008532115391, 48.61105298995972, 48.71676288332258, 50.50377007893154, 49.9697801726205, 49.13469702856881, 48.47262750353132, 52.20289298466274, 49.52766282217843, 55.18730756214687, 59.712797846112935, 62.02169118608747, 65.42015933990479, 71.82899706704276, 71.32468291691372, 79.10343442644391, 20.598007678985596, 0.9354226227317537, 0.7042409649917057, 0.5812661009175437, 8.194136534418378, 75.19517694200788, 73.78847244807652, 64.07384858812604, 61.87581375667027, 43.382081917354036, 55.62185485022408, 59.429137638636995, 72.0351779120309, 14.421169434274946, 0.6993241373981748, 0.24923421761819295, 0.1704547820346696, 0.28904069161840845, 0.18199242864336285], [0.14233730866440705, 0.0836006575929267, 0.08627067253525768, 0.03936744827244963, 0.07155470683106355, 0.04076605143823794, 0.11911285987922124, 0.0328347845269101, 25.93564510345459, 51.72237294060843, 38.33035591670445, 25.846108879361832, 20.57935871396746, 46.653269495282856, 46.577746050698416, 72.87117821829659, 13.391672219548907, 0.12277631115700517, 0.08220734700028386, 0.2886423101382596, 0.6794886589050293, 9.866401178496224, 55.10800082342965, 62.09799630301339, 61.56951631818499, 60.206898144313264, 62.37308243342808, 61.49849183218819, 60.985902377537315, 54.7800076348441, 55.368256023951936, 53.391896520342144, 52.46489913122994, 45.11124535969326, 42.96467236110142, 42.80393968309675, 42.36078357696533, 42.21815095629011, 43.074808256966726, 45.17533206939697, 45.96181256430489, 47.38364328656878, 47.368319034576416, 52.11655466897147, 53.41897365025112, 52.683194160461426, 52.2339722769601, 50.42284093584333, 45.484513010297505, 38.04807145254952, 38.86177151543753, 38.44664444242205, 37.882488931928364, 40.36785609381539, 40.0106109891619, 40.85140207835606, 39.37993342535836, 37.933982031685964, 38.310664721897666, 37.527682644980295, 39.41109609603882, 38.189290114811485, 35.13608142307827, 36.79352903366089, 35.741318157741, 38.94344064167568, 40.89972332545689, 42.845326628003804, 46.654693875994, 46.61338683537075, 46.088540758405415, 45.5128755569458, 48.788068771362305, 47.935594286237446, 47.818729060036794, 47.43106821605137, 49.12915931429182, 47.9732882635934, 46.4726128578186, 48.38405186789376, 50.25319719314575, 48.84835829053606, 47.88491759981428, 50.11471264702933, 42.69298389979771, 34.83412313461304, 37.10581929343087, 36.48460865020752, 37.595733301980154, 34.49523169653756, 32.684114251817974, 33.28108957835606, 38.477959973471506, 36.813908100128174, 40.63953760692051, 49.55152293613979, 49.943884236471995, 47.56631490162441, 47.80056299482073, 45.911399909428184, 44.87652478899275, 45.63735948290144, 45.237855434417725, 44.76316840308053, 43.724968569619314, 44.52110011237008, 42.738571030753, 41.76195308140346, 42.478454794202534, 41.37274973733084, 41.36939375741141, 39.86329180853707, 38.18172352654593, 36.93460178375244, 36.15697676794869, 33.61984552655901, 35.73450544902256, 37.339344773973735, 38.14154209409441, 36.98039388656616, 37.9922913142613, 35.959064279283794, 38.70973450796944, 37.48649372373308, 37.454587595803396, 36.416457244328086, 39.085201263427734, 38.16375201089041, 39.6000315121242, 37.04020398003714, 38.731593540736604, 38.48653752463204, 35.39007977076939, 37.009902885981965, 38.935915742601665, 38.177672726767405, 39.62281812940325, 38.4302327973502, 38.93579762322562, 38.57002707890102, 41.43551976340157, 40.49668264389038, 43.04998581750052, 43.643591267721995, 44.492928641183035, 42.20972626549857, 45.212942668369834, 44.7424384525844, 44.76717056546892, 43.686406067439485, 48.309563704899375, 46.765191078186035, 52.38789919444493, 60.4738826751709, 67.63006169455392, 65.2110880443028, 73.67428575243268, 10.154839141028267, 0.7359052087579454, 1.212092508162771, 0.22087156240429195, 9.760979635374886, 67.74364389692033, 58.95508984157017, 58.64007936205183, 44.7069296836853, 49.44697686604091, 66.19240297589982, 42.898577622004915, 52.74589123044695, 9.391001956803457, 0.24767133433903965, 0.06344410989965711, 0.021279155043885112, 0.03516483985419784, 0.03909378492140344, 0.05463363802326577, 0.09333690907806158, 0.029567020945250988, 0.005014680824907762, 0.02418372766780002, 0.04884317623717444, 0.10400320137185709, 0.037400894332677126, 32.519935267312185, 60.37382166726248, 40.67741223743984, 33.07111154283796, 30.194064004080637, 51.546142305646626, 54.33809873035976, 77.98884609767369, 15.048241751534597, 0.33914048756871906, 0.06937741009252411, 0.4242412910929748, 1.4970008943762099, 10.489619851112366, 54.251155921391074, 63.55743762425014, 64.73025185721261, 60.94408811841692, 65.07941968100411, 61.850411142621724, 63.16841493334089, 57.27764878954206, 56.9713374546596, 55.49958045142037, 54.511233942849294, 45.97306169782366, 46.2713235446385, 42.53078862598964, 43.65686927522932, 44.087160791669575, 44.28357941763741, 45.73924091884068, 46.505884306771414, 48.89231954302107, 50.953019755227224, 53.477050168173655, 55.48509693145752, 54.31827899387905, 56.23284469332014, 51.775311265672954, 47.710889543805806, 40.763569899967735, 41.16108328955514, 38.43327610833304, 39.68263864517212, 41.13820634569441, 42.40841695240566, 43.33365992137364, 42.35165016991751, 41.13424587249756, 40.262180941445486, 39.23875297818865, 41.932798862457275, 41.21008893421718, 38.140670095171245, 37.58164235523769, 39.31955705370222, 42.03281470707485, 42.593919958387104, 43.34154960087368, 47.83780533926827, 47.81971917833601, 48.3733412197658, 48.09717117037092, 50.802198682512554, 49.24911996296474, 51.622794832502095, 51.134857586451936, 49.36099985667637, 50.13436562674386, 49.43243776048933, 51.078545910971506, 51.51379844120571, 50.66459308351789, 49.480797222682405, 51.88886220114571, 43.815420218876426, 34.88503953388759, 38.26569945471627, 39.390477316720144, 37.744153772081646, 35.148914745875764, 35.16643462862287, 35.520660740988596, 39.07123538425991, 35.9779668535505, 42.01190062931606, 51.05000965935843, 51.80685608727591, 49.79338278089251, 49.995960984911235, 46.97740990774972, 48.44480344227382, 46.81190381731306, 47.326091357639854, 46.92061185836792, 46.42720290592739, 46.63849762507847, 47.59049115862165, 43.11235979625157, 45.08696140561785, 43.2498368535723, 44.51850496019636, 41.15940877369472, 41.632622786930625, 38.24371188027518, 38.2980363709586, 36.033104283469065, 36.87328045708792, 39.21129022325788, 39.23061663763863, 38.58425004141671, 38.663581098829, 38.09417275020054, 39.75029672895159, 40.01470695223127, 39.41400391714913, 39.336257049015586, 40.726747921534944, 39.9262181690761, 41.4072927066258, 38.901306765420095, 41.16102422986712, 41.0188501902989, 39.27234404427664, 39.21395833151681, 42.60903576442173, 39.97270161764962, 41.66670717511858, 41.25773620605469, 41.04201201030186, 41.40643113000052, 45.8567419052124, 43.83830411093575, 45.92726959500994, 45.696995871407644, 48.84546436582293, 45.0922246660505, 47.927805355616975, 48.22098459516253, 46.43876123428345, 46.72552381243025, 50.72878401620047, 50.05937719345093, 54.8022210257394, 62.99669715336391, 69.7116516658238, 67.39806134360177, 75.84840488433838, 11.155932119914464, 1.0605424174240656, 1.5815022800649916, 0.43756353908351486, 11.82744858946119, 76.8702278137207, 65.26178210122245, 64.7577041898455, 49.175976276397705, 38.504797390529085, 68.37673595973423, 50.36712333134243, 61.35986137390137, 13.474452189036779, 0.35507900374276297, 0.10898858814367227, 0.05139188268887145, 0.04342561015593154, 0.03565402967589242, 0.21442759675639017, 0.23793449252843857, 0.12553980786885532, 0.08710643768842731, 0.1419804806688002, 0.09243311400392226, 0.2137854176440409, 0.18360732841704572, 44.02470690863473, 69.86816678728376, 55.443793364933555, 37.20186076845442, 29.961643287113734, 63.220512526375906, 56.8472843170166, 87.51554897853306, 16.539641312190465, 0.6851024776697159, 0.19243909950767243, 0.7846285285694259, 2.1309154501983096, 11.870411038398743, 56.016786984034944, 66.26711000714982, 66.55317429133824, 63.12840025765555, 65.46244607652936, 65.95856830051967, 67.0577038356236, 60.24471024104527, 59.52099977220808, 58.5342652457101, 56.26264204297747, 49.0021253994533, 47.5719325201852, 45.81409733636038, 45.913640703473774, 46.74877595901489, 46.96464606693813, 50.21421432495117, 48.41872337886265, 51.77540159225464, 54.19561549595424, 56.7384477342878, 58.63158171517508, 55.8190655708313, 58.8473093850272, 56.298560755593435, 48.83779008047921, 43.6708698953901, 42.005386693137034, 41.41954238074166, 42.04318489347185, 45.00328424998692, 43.15203748430525, 46.3909888948713, 44.96818889890398, 42.60569715499878, 42.30761248724801, 40.81720651899065, 43.32766362598964, 42.14223493848528, 40.45872810908726, 40.395016602107454, 40.191066128867014, 43.01497037070138, 46.11793163844517, 46.841218267168315, 52.15675694601876, 51.61776781082153, 50.519639764513286, 50.36595950807844, 53.36188725062779, 52.69257075445992, 54.04709080287388, 53.4393527167184, 54.84537976128714, 53.052852221897666, 50.31686006273542, 53.069368089948384, 54.63207353864397, 54.18327896935599, 52.80661848613194, 53.57129553386143, 46.07668713160923, 33.99971743992397, 39.506842272622244, 39.35664306368147, 39.375472681862966, 37.1588305745806, 35.69492850984846, 37.43161685126168, 41.30611303874424, 36.19408014842442, 43.29615354537964, 53.46527297156197, 56.2620062828064, 53.41469703401838, 53.974805218832834, 48.607450348990305, 51.38158464431763, 50.02638019834246, 49.65939024516514, 51.367236614227295, 49.24980436052595, 50.24541173662458, 49.79854876654488, 47.635956696101594, 48.23369632448469, 46.15619536808559, 46.028848784310476, 43.869376455034526, 44.947695187159944, 41.47502374649048, 39.53189747674124, 38.57531813212803, 40.330189909253804, 42.52453177315848, 40.69220495223999, 40.24838181904384, 41.08681052071707, 39.69342572348458, 42.00820766176496, 41.26538964680263, 42.336329392024446, 39.68767956324986, 43.69052982330322, 42.329735551561626, 44.646716594696045, 40.98529386520386, 44.89157806124006, 43.20150865827288, 40.735436643872944, 43.31467396872384, 44.32424374989101, 44.226437432425364, 45.15770101547241, 44.28095647266933, 44.46320424761091, 44.05569587435041, 48.50979341779436, 46.265000683920725, 48.85568169185093, 48.28635324750628, 50.650161675044465, 48.36480188369751, 50.41549321583339, 52.21182141985212, 50.43486826760428, 49.58678156988961, 52.7118797983442, 51.99243204934256, 56.673193727220806, 67.45833696637834, 72.40595463344029, 70.22818074907575, 76.63710185459682, 12.70799900804247, 1.1892361917666026, 2.876607196671622, 1.1431848342929567, 13.088288681847708, 84.68378979819161, 70.42011083875383, 74.22893265315464, 60.09415667397635, 65.08068425314767, 80.16047777448381, 63.38609504699707, 76.62552615574428, 19.88768812588283, 0.4095401513789381, 0.24301666553531373, 0.0836483518193875, 0.22519260911004885, 0.10506898311099835], [0.09661778874163117, 0.04893854433404548, 0.06043144834360906, 0.023762469379497424, 0.05107270320877433, 0.045483712040420086, 0.1054237958575998, 0.25219938850828577, 27.461716175079346, 50.41276257378714, 39.62075798852103, 30.610577242715017, 28.28381313596453, 44.326988288334434, 44.621953214917866, 72.43335832868303, 15.202437911714826, 0.47612530844552176, 0.36120916051524027, 0.32764482870697975, 0.15049058544848645, 2.7498464328902106, 28.773497853960308, 58.08543940952846, 58.3236722946167, 61.158238547188894, 61.706527846200125, 58.62099266052246, 55.73110485076904, 55.04344163622175, 53.76809631075178, 48.36698014395577, 42.87351546968733, 41.6691494669233, 42.52886744907924, 42.17710794721331, 43.11515992028372, 43.22948905399868, 47.080330099378315, 47.46243585859026, 49.79188196999686, 49.621772697993684, 51.34967851638794, 54.1804267338344, 54.225669928959434, 51.64852053778512, 51.14305298668997, 46.41262558528355, 41.57382018225533, 38.95680897576468, 36.90220928192139, 38.71289941242763, 41.622634751456125, 43.42119680132185, 48.66936574663435, 49.71969018663679, 47.037987777165, 43.47193602153233, 39.99797569002424, 37.407482283455984, 40.08233724321638, 38.07777500152588, 38.76497268676758, 36.30181196757725, 37.030219418661936, 38.76067870003836, 38.899239676339285, 38.45888716833932, 42.940708024161204, 44.93817615509033, 43.889244828905376, 45.615712370191304, 45.057890142713276, 49.93701246806553, 47.55175495147705, 46.74179301943098, 49.15974875858852, 49.550908020564485, 49.421292849949424, 46.9279283114842, 46.699308259146555, 47.98386689594814, 49.951561995915, 49.91716493879046, 48.87935767854963, 40.70350619724819, 37.954941272735596, 40.17413336890084, 39.89304746900286, 37.77131428037371, 33.368664673396516, 34.87358890260969, 38.57913964135306, 33.97421407699585, 43.367282254355295, 49.147961139678955, 47.38866336005074, 48.27066421508789, 48.46388666970389, 46.12864923477173, 46.1104553767613, 46.83568055289132, 43.557239055633545, 44.921997274671284, 44.05335085732596, 45.49948637826102, 43.45740039008004, 43.61693797792707, 43.03826420647757, 42.19289772851126, 41.076051235198975, 38.17620665686471, 36.060073716299875, 35.94899633952549, 34.37472908837454, 33.84238937922886, 33.65250900813511, 36.776109899793354, 37.47071783883231, 36.63692011151995, 37.4376791545323, 37.14758491516113, 37.96940047400338, 37.58181258610317, 37.17505809238979, 37.50702912466866, 38.66596780504499, 37.26796245574951, 37.96537051882063, 38.099175453186035, 39.13745519093105, 39.1271927016122, 37.51494312286377, 36.9439297403608, 37.75022997174944, 36.90553746904646, 37.99338912963867, 38.25016328266689, 40.41984598977225, 39.60249464852469, 40.76196486609322, 42.17214345932007, 43.528779234204976, 44.11231674466814, 45.75065680912563, 44.02390786579677, 45.248736313411165, 42.60141706466675, 42.43389252253941, 43.05669430324009, 46.594070843287874, 47.932926177978516, 49.86231933321272, 57.59859650475638, 64.44752270834786, 67.9847811290196, 67.0162022454398, 8.411363278116498, 0.6312913937228066, 1.6057607212236948, 0.26041259350521223, 19.2792934349605, 70.28617041451591, 61.84315027509417, 56.6607460294451, 47.46965503692627, 38.13099125453404, 32.09433725902012, 46.39547048296247, 46.202272347041536, 13.695232936314174, 0.36145850856389317, 0.07651513708489281, 0.023747005566422428, 0.1462785793202264, 0.02045738637181265, 0.07434172156666007, 0.05217327683099678, 0.08260642737150192, 0.0065730959509632415, 0.06741085276007652, 0.023454251632626568, 0.010594583016687205, 0.14901629170136793, 35.16544451032366, 58.51023837498256, 46.67785917009626, 30.667437825884136, 30.12339735031128, 54.46444129943848, 47.524104595184326, 79.27328314099992, 16.202400071280344, 0.4780300919498716, 0.2659856458859784, 0.2770940512418747, 1.2405444043023246, 2.8607787660190036, 31.58034426825387, 58.58896146501814, 59.08431938716343, 61.9592616217477, 63.22195080348423, 61.080161639622276, 57.17375932421003, 58.119252817971365, 56.04572623116629, 49.37115117481777, 46.15436451775687, 45.030389172690256, 45.295720032283235, 42.76248325620379, 45.549537726810996, 46.765816416059224, 49.547805649893625, 49.3959492955889, 51.31487498964582, 51.82055446079799, 52.901982511792866, 54.917905058179585, 55.92057875224522, 52.621007783072336, 52.638138566698345, 49.700401987348286, 42.91945001057216, 41.358047349112375, 38.99178968157087, 40.65418093545096, 42.12653200966971, 46.714983395167756, 50.38463626589094, 51.27698993682861, 51.0007677759443, 46.834461144038606, 42.06750358854021, 40.0850887298584, 41.586684771946494, 40.49293409075056, 39.70103400094168, 37.89799036298479, 38.98878805977957, 39.44543409347534, 40.27342660086495, 40.806721687316895, 44.30384383882795, 48.183912481580464, 47.180547441755024, 47.78680208751133, 47.85642998559134, 52.21333612714495, 50.16339520045689, 49.70985153743199, 52.79530681882586, 50.57918235233852, 48.81171696526663, 51.24600444521223, 49.76947750364031, 48.92870378494263, 51.74970020566668, 51.89365298407418, 51.63910920279366, 40.290272508348735, 39.31885528564453, 41.4157451902117, 40.58088091441563, 38.15213114874703, 34.68716526031494, 35.53391095570156, 39.628275939396445, 35.519253730773926, 45.19802836009434, 52.06056261062622, 48.344645159585134, 50.751796449933735, 49.1958898135594, 49.495246001652305, 48.682157380240305, 48.823476791381836, 46.856438296181814, 47.44231734957014, 46.56510380336216, 47.15351547513689, 46.901938574654714, 47.108901091984336, 44.86027990068708, 42.685219287872314, 44.32271862030029, 39.1152035849435, 37.11154113497053, 39.92946645191738, 36.65426976340157, 36.80900962012154, 34.661074774605886, 38.538732392447336, 39.545825140816824, 38.29307188306536, 41.53144659314837, 39.23720700400216, 39.93016821997506, 39.33537115369524, 39.59636633736746, 39.633045877729145, 40.003218105861116, 39.76634359359741, 40.51701307296753, 40.77080644880022, 40.25837680271694, 39.59542833055769, 41.68094750813076, 40.17759357179914, 40.7972651890346, 40.54314177376883, 41.28707497460501, 40.35480737686157, 43.37095437731062, 43.55044371741158, 42.885073798043386, 45.7183198928833, 46.809635230473106, 47.44760840279715, 48.05900818961007, 47.537128993443076, 46.884196349552695, 45.56227030072893, 46.17707123075213, 47.58647509983608, 48.92947850908552, 50.86025782993862, 52.2068395614624, 60.48614624568394, 67.117506980896, 70.01016017368862, 69.46244062696184, 9.948045117514473, 0.6783479058316776, 1.7869610552276884, 0.23007366433739662, 21.612255334854126, 77.98534420558384, 66.96270111628941, 63.363263266427175, 55.1138789994376, 40.258713790348594, 46.75026634761265, 51.25399487359183, 58.5546304157802, 17.936561005456106, 0.33449803239532877, 0.10792858752288989, 0.04587079251983336, 0.12967182828911714, 0.06822415840412889, 0.12299223457063947, 0.229433290128197, 0.24602273851633072, 0.08798854678337063, 0.20165336078831128, 0.14836259106440203, 0.20572932064533234, 0.4975511644567762, 47.098704610552105, 69.46870790209088, 56.65950230189732, 41.92042759486607, 36.71098790849958, 64.1103961127145, 53.70733431407383, 87.2442079271589, 17.841455800192698, 1.1247855701616831, 0.6230976219688142, 1.478149671639715, 1.7229075665984834, 4.249514349869319, 34.91029970986502, 59.778687613351, 60.673921312604634, 63.37891755785261, 67.73781435830253, 63.99793257032122, 60.2559107371739, 60.03217874254499, 59.96502440316336, 51.79186882291521, 48.51635251726423, 46.7399309022086, 46.933118615831646, 45.55592312131609, 47.850680351257324, 48.538350514003206, 51.0076082774571, 51.318039894104004, 53.36060183388846, 53.87657158715384, 55.86132104056222, 57.52799585887364, 57.62464530127389, 54.21672412327358, 55.484947545187815, 52.148856844220845, 46.26598385402134, 43.412122453962056, 40.6330132484436, 42.496898787362234, 44.2173352922712, 47.90872212818691, 53.260387965611045, 54.90022536686489, 54.22267178126744, 49.512963908059255, 44.2804388318743, 42.2574325970241, 45.169082164764404, 43.56500366755894, 43.305154936654226, 38.71943071910313, 40.496679169791086, 43.24909687042236, 43.001007965632844, 42.56561994552612, 47.79426792689732, 50.6532119342259, 49.685866355895996, 49.646959917885916, 52.18823575973511, 56.04894324711391, 52.58434908730643, 52.349180357796804, 54.49320684160505, 55.15975448063442, 54.32113470349993, 53.03766693387713, 50.98698949813843, 51.050614152635845, 55.520122800554546, 54.190178530556814, 54.508388655526296, 42.351848193577354, 39.86853422437395, 43.42617865971157, 41.55257953916277, 39.246312618255615, 35.70106029510498, 37.75220673424857, 40.75381810324532, 35.545517921447754, 46.3792325428554, 54.10577181407383, 52.241691725594656, 52.74951124191284, 51.34582921436855, 51.783329486846924, 51.87607404163906, 52.338949135371614, 49.7058459009443, 50.13659252439226, 50.07686233520508, 50.299315861293245, 49.6919390814645, 49.28008113588606, 47.88130453654698, 46.43407120023455, 46.43158027103969, 42.146886757441926, 39.6778860773359, 41.18399150030953, 39.21262080328805, 40.66364785603115, 37.372178486415315, 40.452353136880056, 43.22257907049996, 40.342085225241526, 43.15789828981672, 40.73343556267874, 43.412327425820486, 42.14305135181972, 42.8826071875436, 43.304682459150044, 43.40296125411987, 41.64780807495117, 42.71557249341692, 43.13020624433245, 42.03828293936593, 44.19709518977574, 44.84267316545759, 42.420899391174316, 43.69340985161917, 43.267669405256, 43.59448140008109, 44.08476366315569, 46.62770707266671, 47.386728286743164, 46.380069800785606, 48.75185476030622, 49.71059499468122, 49.30737018585205, 50.26995277404785, 50.80204929624285, 50.5492217200143, 48.47929082598005, 46.27778189522879, 49.38963338306972, 51.270430837358745, 53.465498788016184, 53.591622488839285, 63.26864269801548, 69.9038805280413, 73.37748650142125, 70.60565553392682, 11.202518922942025, 1.1544962844678333, 2.7129434645175934, 0.5854123298610959, 24.240397555487498, 85.53775814601353, 72.59596702030727, 72.65117045811245, 66.36511434827531, 50.088007245744976, 45.620572635105674, 63.88336372375488, 72.36109706333706, 23.11569438661848, 0.5383209681936673, 0.27893928651298794, 0.21723348833620548, 0.2863518201879093, 0.2117634375712701], [0.055369889230600426, 0.03529303547527109, 0.12760464421340398, 0.07375564372965268, 0.03579284776268261, 0.04836252238601446, 0.0572004070771592, 0.44854006437318666, 29.725460120609828, 52.23800918034145, 35.10988324029105, 46.3918331010001, 35.288743768419536, 42.44574614933559, 46.92598976407732, 73.24153109959194, 20.6099568435124, 0.3387356735765934, 0.58499804352011, 0.21088020210819586, 0.8396652638912201, 0.3873549603990146, 11.928048082760402, 45.49915633882795, 59.87267589569092, 56.31851945604597, 60.59618486676897, 57.68153020313808, 54.187708445957725, 47.36339970997402, 44.63004786627633, 43.04195717402867, 43.38465969903128, 43.39609643391201, 44.50270128250122, 44.75344787325178, 47.37435007095337, 47.994709559849326, 48.09122003827776, 48.37239626475743, 50.30671569279262, 52.402664116450715, 52.84572294780186, 51.84304230553763, 51.99220623288836, 50.65037359510149, 48.814885343824116, 38.72672980172293, 37.17777483803885, 38.3193291255406, 38.44716208321707, 40.19570057732718, 44.221007415226524, 48.15077999659947, 50.10816049575806, 51.91557802472796, 50.760592869349885, 47.591623714991975, 42.7314977645874, 37.57228313173567, 38.97492292949131, 39.832990714481895, 39.20115974971226, 36.08440630776541, 36.29684400558472, 37.14760575975691, 39.39040436063494, 38.67020968028477, 41.18934161322457, 43.56858546393258, 42.052575383867534, 43.808166299547466, 43.63045917238508, 45.3201881136213, 46.3408784866333, 46.74139697211129, 49.509180613926475, 49.33393314906529, 47.11696795054844, 45.28617320741926, 47.705674920763286, 49.285000460488455, 49.55548340933663, 49.532429286411826, 47.38682903562273, 45.58805853979928, 37.04072509493147, 44.02123628343855, 38.882852349962505, 36.10338878631592, 32.52306890487671, 40.227287088121685, 41.15952341897147, 37.51097222736904, 48.10866696493966, 48.18220322472708, 48.15370518820626, 46.441915716443745, 48.110146931239534, 46.876848629542756, 45.8436028616769, 44.53518411091396, 46.271969727107454, 43.393073967524934, 45.46224055971418, 44.32539020265852, 43.24637317657471, 43.09897061756679, 43.76852682658604, 41.629381452287944, 42.93181085586548, 37.30061551502773, 38.30467537471226, 35.39061825616019, 34.87695183072771, 33.69158567701067, 33.69222838538033, 36.63439791543143, 38.04404844556536, 35.88179683685303, 37.09898921421596, 37.05675458908081, 39.8316775049482, 36.612879344395225, 38.123424666268484, 36.388904162815635, 37.020217486790244, 36.7277295930045, 39.357171126774375, 39.146241188049316, 39.963085310799734, 39.04778868811471, 37.48353379113333, 39.27398034504482, 37.68878705160958, 38.20104646682739, 38.46120091847011, 39.09469945090157, 38.77668387549264, 39.50628989083426, 39.784672941480366, 41.52810103552682, 42.44160849707467, 44.68624142238072, 45.698618275778635, 45.705820083618164, 45.495918478284565, 44.34634944370815, 45.21409259523664, 46.456725801740376, 46.38229669843401, 48.22900629043579, 55.69832672391619, 58.12106629780361, 64.58996772766113, 65.49348367963518, 71.63746302468437, 8.800360781805855, 0.6916198879480362, 1.3052569947072437, 0.08332320462380137, 27.952488286154612, 69.24583053588867, 59.318501472473145, 57.291739736284526, 47.7098959514073, 29.99300398145403, 30.346361568995885, 47.441111837114605, 45.51179163796561, 12.990480627332415, 0.427506510168314, 0.09826476286564555, 0.09048873798123427, 0.11674446053802967, 0.0196126696454095, 0.11701949792248861, 0.061878892460039685, 0.024920363943757753, 0.05013056072805609, 0.03911573892193181, 0.03467524630416717, 0.028349240576582294, 0.5632070271032197, 37.240183557782856, 61.11873803819929, 42.29553304399763, 51.67721659796578, 37.22481414249965, 49.95612348828997, 50.447006770542686, 78.62828881399972, 22.18426057270595, 0.24082700588873454, 0.6477628584418977, 0.18819738711629594, 0.11912968754768372, 0.6568281405738422, 12.930886796542577, 47.97291306086949, 63.79922103881836, 58.91262245178223, 63.281885964529856, 60.6653333391462, 55.53234120777675, 49.622408458164756, 46.37096766063145, 44.99737133298601, 45.26516880307879, 45.44289330073765, 46.0637217930385, 46.42953750065395, 49.867162227630615, 50.37817096710205, 51.31929751804897, 50.719160761152, 53.92700856072562, 53.93422079086304, 55.46843862533569, 54.233236517224995, 53.710259505680625, 52.45615482330322, 51.4842130116054, 39.58254984446934, 40.26340729849679, 40.686437947409495, 38.63285616465977, 40.97141831261771, 46.19646365301949, 53.08839920588902, 51.41665915080479, 53.31462560381208, 52.141995498112266, 51.71502522059849, 43.80989987509591, 39.22109413146973, 41.030405044555664, 40.195585932050435, 42.12920011792864, 38.67182513645717, 38.26474755150931, 37.63091203144619, 41.042248249053955, 40.92826999936785, 43.80319138935634, 45.966360160282676, 42.78292138235909, 45.781788212912424, 46.203714098249165, 46.05921588625227, 48.42989955629621, 49.60205718449184, 50.87859065192086, 50.67480346134731, 49.883146558489116, 46.336876324244905, 49.30099868774414, 50.28637136731829, 52.50504582268851, 51.38909217289516, 50.36623396192278, 46.22980110985892, 37.648317268916536, 44.88703393936157, 38.808593477521626, 37.43796403067452, 33.97588511875698, 40.55547135216849, 41.733861514500205, 38.399931703295024, 48.33089467457363, 51.27897712162563, 49.8935341153826, 46.730797495160786, 50.960471698216026, 47.52196455001831, 48.15223217010498, 47.00980935777937, 48.05671180997576, 46.56497873578753, 49.359940256391255, 46.695500646318706, 45.55281032834734, 44.70990003858294, 45.34533017022269, 44.69806030818394, 42.979006494794575, 39.65478331702096, 39.94353655406407, 36.30536249705723, 36.13731336593628, 36.112261635916575, 36.5615599496024, 38.39611019407, 39.98469420841762, 37.42035729544503, 39.71243946892874, 39.78170953478132, 43.21757289341518, 38.18716049194336, 39.63151032584054, 39.59774208068848, 40.61527449744088, 39.638034684317454, 42.50025476728167, 42.83457081658499, 41.27890389306204, 40.992349760872976, 40.476070812770296, 40.10121202468872, 40.16101516996111, 40.58308001926967, 41.41353913715908, 41.091194834027974, 41.67152227674212, 41.57900701250349, 44.019422803606304, 44.472685064588276, 45.11493137904576, 47.2143816947937, 49.64536530630929, 49.10814101355416, 48.2929436138698, 47.38517883845738, 47.682665961129324, 48.8444047655378, 49.65429374149868, 52.836096218654085, 59.27763911655971, 61.077222551618306, 66.94493457249233, 70.40925080435616, 76.87026950291225, 9.3899119581495, 0.8646828500287873, 1.5982257255486079, 0.19543583584683283, 31.99871267591204, 75.9624387196132, 65.17347049713135, 64.10450404030937, 54.73455599376133, 32.991749218532014, 34.70423003605434, 60.82491956438337, 58.477498463221956, 17.824634211403982, 0.39406613313726013, 0.09857283812016249, 0.09254078394068138, 0.049931441234158616, 0.09163950623146125, 0.17025603912770748, 0.20812209296439374, 0.16719252137201174, 0.12794434598514012, 0.26562561520508354, 0.08713759601648365, 0.1366459062056882, 0.7281521047864641, 49.11713545663016, 70.83803803580147, 47.83875724247524, 59.366958209446494, 46.47482238497053, 59.94284575326102, 57.29500191552298, 87.16766657148088, 24.951269490378245, 0.6341491660901478, 1.44293945814882, 0.7195717309202466, 3.714195600577763, 1.2574295039687837, 17.514899151665823, 53.14011812210083, 65.0652106148856, 61.866447584969656, 67.92718056270054, 64.35078988756452, 60.04394204275948, 51.666631017412456, 49.047966139657156, 47.63368810926165, 48.29413175582886, 46.557457310812815, 50.16512182780674, 49.67158433369228, 51.13344710213797, 51.37055090495518, 54.13090344837734, 52.75142547062465, 56.72252246311733, 55.84445776258196, 57.9384572165353, 55.32999924251011, 57.83540848323277, 55.840010915483745, 53.88625042779105, 41.43033640725272, 41.144445828029085, 43.66680172511509, 41.44123813084194, 44.83189303534371, 48.477974142347065, 54.39031791687012, 53.519548824855256, 57.36450474602835, 55.22858680997576, 55.0321820804051, 46.50369562421526, 42.25081096376692, 43.568481240953716, 43.28883361816406, 44.91712311335972, 40.797143595559255, 41.56067419052124, 39.543580872671946, 44.13746574946812, 42.9785270690918, 47.12280791146414, 48.9575457572937, 46.22699056352888, 49.313769476754324, 47.81905562537057, 47.75555256434849, 52.26946020126343, 51.34303951263428, 54.77889592306954, 54.3997848374503, 52.31454011372158, 49.93683181490217, 51.163095065525596, 53.33694669178554, 54.73323583602905, 53.961145060403005, 51.93753433227539, 50.196687494005474, 38.058486802237375, 46.21291698728289, 40.867483683994834, 37.43609496525356, 35.15695381164551, 43.799581800188335, 43.116466181618826, 39.249286447252544, 50.929249967847554, 53.87874289921352, 52.43100234440395, 50.088632583618164, 52.67808723449707, 49.5718811580113, 50.79168258394514, 49.53978048052107, 51.682288782937185, 48.03806284495762, 52.04856654575893, 51.46840933391026, 49.397550855364116, 47.392644677843364, 47.84491682052612, 46.35858597074236, 46.69683470044817, 41.94943979808262, 43.17444542476109, 39.35277986526489, 39.408091000148225, 37.875509466443745, 38.61102492468697, 40.00398588180542, 43.029075213841026, 40.61273840495518, 41.647373812539236, 39.3369379724775, 44.134682995932444, 39.69497864586966, 42.77546943937029, 42.272409439086914, 42.91317926134382, 41.93432051794869, 44.35774448939732, 44.448818002428325, 43.28708962031773, 44.403661659785676, 42.5172118459429, 43.53899308613369, 42.89081648417881, 43.92713335582188, 43.51106480189732, 43.54993302481515, 46.13318988255092, 44.81452601296561, 45.76290300914219, 46.906621660505024, 46.98116888318743, 49.59200314113072, 51.65135192871094, 52.99414689200265, 52.16428184509277, 49.32021740504673, 49.407771655491416, 51.322973115103586, 52.30851602554321, 53.59109442574637, 60.258092471531455, 64.02227905818394, 70.72536604745048, 71.08717264447893, 73.58101313454765, 11.462424107960292, 0.9099591576627323, 2.690067172050476, 0.5653515234589577, 34.03095654078892, 84.58387470245361, 70.48315879276821, 73.14121300833565, 64.07716982705253, 44.42123712812151, 47.10579177311489, 66.30338655199323, 73.8571275983538, 28.36865758895874, 0.5618672732795987, 0.23001322043793543, 0.1983446069061756, 0.13576094726366655, 0.17149940026657923], [0.02656195728507425, 0.030840162986091206, 0.010007098067684897, 0.033463915410850725, 0.11503578722476959, 0.08799150519605194, 0.05534406418779066, 0.4417170419224671, 37.765224184308735, 53.63028226579939, 39.76387698309762, 22.938767194747925, 21.984873328890117, 45.12840741021292, 41.69484390531267, 68.00620937347412, 27.549428497041973, 0.1152859495154449, 0.43695519172719544, 0.04780332471377083, 0.3139633371361664, 0.2606756751026426, 6.740854356970106, 56.865012645721436, 61.024131366184776, 57.76986960002354, 56.61072594778878, 52.17274822507586, 48.108125005449565, 44.47715623038155, 43.055804933820454, 43.41969946452549, 44.087303229740684, 44.910696029663086, 47.4685572215489, 49.096252645765034, 51.14850732258388, 52.639125210898264, 53.59046561377389, 53.09979772567749, 52.0419796534947, 54.0871958051409, 55.05288771220616, 51.50462334496634, 49.29379340580532, 47.83877461297171, 41.55613701684134, 38.176178864070344, 39.481477873665945, 37.694519315447124, 40.654761110033306, 45.70362792696272, 51.164397852761404, 49.42151519230434, 53.57110793249947, 49.62331519808088, 50.551170689719065, 51.12767662320818, 44.28419780731201, 38.89157928739275, 36.70063509259905, 39.906617300851, 38.689567361559185, 34.47666263580322, 37.29490409578596, 37.457425934927805, 37.92191301073347, 39.614521980285645, 38.24980545043945, 41.76033762523106, 41.134919847760884, 42.928145681108745, 42.352348463875906, 43.3780380657741, 43.23026030404227, 45.16062273297991, 45.53781958988735, 48.446835790361675, 45.86153268814087, 47.06716326304844, 48.24854115077427, 48.075847148895264, 49.18829543249947, 48.77457536969866, 50.12279340199062, 44.77503245217459, 41.62459066935948, 40.59565625871931, 36.96231467383248, 35.53170837674822, 33.6131648336138, 41.91139841079712, 40.399185521262034, 43.39433853966849, 50.90020649773734, 48.53740208489554, 50.9560352734157, 47.83201054164341, 46.86296960285732, 44.62696634020124, 49.0934282030378, 42.9008218901498, 45.757681437901084, 44.36981003625052, 43.63125821522304, 41.837424414498464, 39.2823702948434, 41.239615304129465, 40.976209095546174, 40.54055009569441, 40.235468591962544, 36.70170511518206, 34.88878461292812, 35.592466899326865, 33.33388199125017, 37.69945253644671, 37.32134199142456, 35.69674546377999, 37.71455792018345, 36.08309309823172, 39.33639253888811, 40.89071498598371, 45.15689155033657, 44.372533730098176, 38.90693828037807, 38.40517411913191, 38.100203786577495, 35.23594788142613, 38.65318659373692, 39.713745730263845, 41.852449893951416, 41.62341294969831, 41.23608214514596, 37.25535147530692, 37.45141921724592, 37.41338130405971, 39.4878111566816, 38.74439212254116, 39.943877015795024, 40.072915485927034, 40.52576780319214, 42.229566846575054, 45.72622694287981, 44.71361037663051, 47.880905015128, 47.21160241535732, 48.42776298522949, 48.67472628184727, 47.09778050013951, 49.483739784785676, 53.608756746564595, 56.06616088322231, 59.412684304373606, 60.63968753814697, 64.05986881256104, 69.6479297365461, 69.10155814034599, 6.326406904629298, 0.793855464884213, 1.6388876693589347, 0.04595537530258298, 36.173642022269114, 70.73096629551479, 62.71289798191616, 50.862602846963064, 46.00011450903756, 29.42570788519723, 38.93367494855608, 47.42939370019095, 42.74953876222883, 20.753690753664287, 0.28678828105330467, 0.09655337541231088, 0.10490034001746348, 0.03364544388438974, 0.06956925908369677, 0.0805162816707577, 0.06481123582593032, 0.0809621334608112, 0.06769910800669875, 0.0471008984771158, 0.026620762522465417, 0.074172671352114, 0.6782828207526888, 46.672234603336875, 60.98282432556152, 44.731182370867046, 26.246834073747905, 30.07318271909441, 51.22251953397478, 46.826856340680806, 74.39477920532227, 32.033790656498496, 0.22772017919591495, 0.7929755949548313, 0.057471027198646746, 0.5645785363657134, 0.21437841653823853, 8.529112662587847, 62.26828275408064, 64.10429559435163, 60.357583727155415, 58.84947722298758, 54.54537739072527, 50.88980851854597, 46.087665285382954, 45.59290838241577, 44.921385833195274, 45.63558769226074, 46.863178048815044, 48.96635954720633, 51.466828618730815, 53.41731997898647, 54.55869361332485, 55.29244770322527, 56.15102618081229, 54.26865495954241, 56.11544445582798, 56.13206454685756, 51.91019664491926, 52.268602098737446, 50.68958575384957, 43.377503054482595, 40.81327036448887, 40.62491512298584, 40.34839766366141, 43.986495290483745, 46.530470507485525, 54.17896066393171, 51.29730646950858, 54.25001641682216, 50.84873424257551, 50.69178833280291, 52.87467956542969, 45.38392046519688, 41.33447905949184, 38.43829965591431, 42.13755532673427, 40.904118061065674, 35.8730594771249, 39.27472727639334, 38.75962952205113, 38.471157687050955, 40.5532340322222, 39.90330995832171, 42.923420906066895, 43.221116474696565, 44.34827756881714, 44.16958032335554, 47.205029419490266, 47.107674734933035, 49.89749806267874, 48.55366434369768, 49.968418325696675, 45.87123932157244, 48.765653882707866, 48.911072731018066, 50.56897892270769, 50.031240463256836, 51.41195174625942, 51.52295964104788, 47.560950892312185, 41.37534141540527, 43.30198655809675, 37.96191726412092, 36.20647573471069, 34.92075327464512, 43.847645963941304, 40.54208564758301, 43.663640294756206, 50.380283219473704, 50.54274947302682, 51.26960400172642, 49.04037870679583, 47.63947248458862, 46.80221108027867, 50.78254222869873, 47.14433690479824, 47.868818623679026, 46.71115493774414, 46.19231905255999, 45.070862429482595, 42.21733454295567, 43.29265512738909, 43.759872845241, 41.87323890413557, 42.83186101913452, 39.55037273679461, 36.88893822261265, 37.78228548594883, 36.793337958199636, 37.86041797910418, 39.68336125782558, 37.901353291102815, 40.52831779207502, 38.56737634113857, 40.995462553841726, 43.23286935261318, 47.825159617832725, 46.87111636570522, 41.474787507738384, 39.601778984069824, 39.363636425563264, 38.01976101739066, 41.830969538007466, 42.82222386768886, 44.998229435511995, 43.999384198869976, 43.976993628910606, 40.50599323000227, 41.774192333221436, 42.05501420157296, 41.78545536313738, 39.997027260916575, 42.42435959407261, 42.88090487888881, 42.95666108812605, 44.911286626543315, 47.81290994371687, 46.89506333214896, 50.19737189156668, 50.72287457329886, 50.438279833112446, 50.85334437234061, 49.25540460859026, 54.60384995596749, 55.40454993929182, 59.906346866062705, 62.572183064052034, 63.670005389622276, 68.62396676199776, 72.56038529532296, 76.81926277705601, 7.581122159957886, 0.8753338413579124, 2.353704878262111, 0.16677648441067763, 39.71295363562447, 77.01425007411412, 67.83561025347028, 61.72865091051374, 52.19652843475342, 34.43589408057076, 51.463861737932476, 58.958772386823384, 55.311454500470845, 27.763156822749547, 0.32029564306139946, 0.10668698378971644, 0.07105589538280453, 0.05319505896685379, 0.030371088335024457, 0.1297463992876666, 0.1270039507320949, 0.18957146124116012, 0.17397358321717807, 0.11779852397739887, 0.1463950973536287, 0.14821268910808222, 0.9968892101730619, 59.262769971575054, 67.50320843287876, 53.733261517116, 31.151160989488872, 31.457434109279088, 63.168032782418386, 52.62470422472273, 80.1900771004813, 34.65265703201294, 0.6434726715087891, 1.069142875926835, 0.2544666182781969, 1.9146592829908644, 0.6866660937666893, 10.507223980767385, 67.49863651820591, 68.03052112034389, 62.448032651628765, 61.669764927455354, 55.90004335130964, 53.12547826766968, 48.47436802727835, 47.04932723726545, 48.711207798549104, 48.61540951047625, 48.524742467062815, 51.1794684955052, 55.025511809757774, 55.8888498033796, 58.562377657209126, 58.727807317461284, 58.16714327675955, 55.68361391339983, 57.512129647391184, 58.541546957833425, 54.292577607291086, 54.49421085630144, 53.0219292640686, 45.649824551173616, 43.30332408632551, 43.896953855242046, 43.29106051581246, 45.41301952089582, 48.96463986805507, 55.693546363285606, 54.226006916591096, 58.80312579018729, 53.63047334126064, 54.05586290359497, 55.26292828151158, 49.142850739615305, 43.96584177017212, 40.42542539324079, 43.96207237243652, 42.773704596928184, 37.66046966825213, 42.71923071997506, 42.13701684134347, 40.81511858531407, 43.829132488795686, 43.10168736321585, 45.044535705021445, 48.27624709265572, 46.74107388087681, 46.68722881589617, 48.49659531457083, 49.53043515341622, 51.478644030434744, 50.07168592725481, 53.0968655858721, 50.028992721012656, 51.65605238505772, 52.79086691992623, 55.41349574497768, 53.75376912525722, 54.814571448734824, 55.404459612710134, 50.83289234978812, 44.55946806498936, 44.45069054194859, 40.79984991891043, 37.592766421181814, 36.71529231752668, 47.04272992270333, 41.94197743279593, 45.73098645891462, 53.527573994227815, 53.02365936551775, 57.153842312949045, 52.42064952850342, 50.28637136731829, 50.60704810278756, 55.25641087123326, 49.18724625451224, 51.00035783222744, 48.568818364824565, 51.230648926326204, 47.396351541791645, 43.15349660600935, 46.51093912124634, 47.38595008850098, 44.281130177634104, 46.04683767046247, 42.75871385846819, 38.484647614615305, 40.03815712247576, 37.816039834703716, 42.39509378160749, 43.565316336495535, 39.71513884408133, 41.388410976954866, 40.95498582295009, 43.78805473872593, 45.39830323628017, 49.872967447553364, 49.830552169254844, 42.40218094417027, 43.61231047766549, 41.692273071834016, 40.03224420547485, 44.18773596627371, 44.431770597185405, 46.0269067628043, 47.27706139428275, 44.8724079813276, 41.42574364798409, 42.52189145769392, 43.85815511431013, 44.399836676461355, 43.224031244005474, 44.57636260986328, 46.04299879074097, 45.62463733128139, 48.166667052677695, 52.43408039637974, 48.14844192777361, 54.20546109335763, 54.1455328805106, 54.27570390701294, 54.05109991346087, 52.9259329523359, 55.74963917051043, 58.703710964747835, 62.7960262298584, 66.36453069959367, 66.31566401890346, 71.3784967150007, 74.41797924041748, 70.70972565242222, 8.818083030836922, 0.7828830650874546, 3.232628549848284, 0.4352490561349051, 42.85375131879534, 84.5137117930821, 74.50044046129499, 67.22498866489956, 61.676796504429404, 43.12148972920009, 58.5735364641462, 68.14069175720215, 68.27434730529785, 37.177771363939556, 0.3513902159673827, 0.20989612277065003, 0.19205099104770593, 0.1083149928599596, 0.16928084859890596], [0.05527067044749856, 0.03676934107871992, 0.08755387046507426, 0.044426452701113055, 0.1658671796321869, 0.07037632220557757, 0.08101005838917834, 0.31765730891908917, 30.918382440294536, 56.48116288866316, 46.515257426670615, 42.72656454358782, 24.636752332959855, 41.43029819216047, 44.73898867198399, 64.09552001953125, 42.069890294756206, 0.272045587854726, 0.3439621031284332, 0.01238635990635625, 0.038628835763250075, 0.21753478502588613, 7.570732866014753, 58.563857623508994, 55.9382723399571, 58.200692653656006, 50.88749476841518, 49.9753873688834, 43.49651179994856, 45.1226612499782, 43.238962922777446, 45.98531484603882, 50.31277799606323, 52.66721330370222, 52.59809609821865, 54.034538882119314, 53.598601954323904, 56.535734040396555, 53.99691438674927, 55.7939304624285, 53.72817543574742, 55.452009609767366, 52.2083785874503, 50.280524458204, 48.13063022068569, 41.777235644204275, 37.92385503223964, 39.77912480490548, 37.40795823505947, 41.759149483272004, 45.53118058613369, 45.85695729936872, 46.59465101787022, 51.28082881655012, 52.37141111918858, 50.231598717825754, 50.610536098480225, 49.471389361790244, 45.27309669767107, 39.78592709132603, 37.40406724384853, 38.33450746536255, 37.900248527526855, 36.80102266584124, 37.87196588516235, 37.13688816343035, 37.2093266078404, 41.10733549935477, 38.84241036006382, 38.42479235785348, 41.18277556555611, 40.38378831318447, 40.759790079934255, 41.57403905051095, 43.240557534354075, 45.188797678266255, 46.63274104254586, 45.44724634715489, 45.71681560788836, 45.64310564313616, 48.1653607913426, 47.51731620516096, 49.809262888772146, 46.51114409310477, 50.00602545057024, 47.109311035701204, 43.213108675820486, 41.71066147940499, 38.567567416599815, 41.668201037815635, 36.30383389336722, 39.85877547945295, 44.094036034175325, 46.135058947971885, 48.16813659667969, 48.83548675264631, 50.00585174560547, 48.762926714760916, 42.67864281790597, 43.77292851039341, 45.795698506491526, 45.90410777500698, 43.79222018378121, 44.82646649224417, 43.539889403751914, 42.556093965257915, 38.97481523241316, 40.18606342588152, 40.680333954947336, 39.58770193372454, 38.728619711739675, 34.85827159881592, 35.42985125950405, 35.30892481122698, 34.432253224509104, 35.52478449685233, 36.38019806998116, 36.65886599676949, 37.40587724958147, 35.513403347560335, 42.120525291987825, 47.08857413700649, 51.213132517678396, 48.58838449205671, 47.69615936279297, 40.822862352643696, 38.85566404887608, 36.873336042676655, 39.024248191288535, 40.00559091567993, 45.28649629865374, 42.36358370099749, 43.935422556740896, 42.728190422058105, 40.884003026144846, 41.742616244724815, 39.569143295288086, 39.063300541469026, 41.43990060261318, 39.660699708121165, 40.5543075289045, 39.95183965138027, 43.31598023005894, 45.10218490873064, 47.02793025970459, 48.497165066855295, 49.146099022456575, 51.77537032536098, 53.30925464630127, 54.40760156086513, 58.68676430838448, 56.896800654275076, 64.76657703944615, 62.19996806553432, 71.38586180550712, 58.94985089983259, 42.17381797518049, 7.289662599563599, 0.8284140676259995, 1.5427775808743067, 0.25764593482017517, 46.41736078262329, 65.90270478384835, 62.29093388148716, 46.729696205684114, 43.47330829075405, 31.383814471108572, 24.233909675053187, 42.82016372680664, 54.34901087624686, 24.88411341394697, 0.25605846143194605, 0.011900414330219584, 0.04095214305977736, 0.12134167099637644, 0.07229578920773097, 0.017678537805165564, 0.038658898257251294, 0.0661219008533018, 0.07868731766939163, 0.07334387475358588, 0.04740082113338368, 0.053323464933782816, 0.3459223907973085, 40.95092807497297, 63.61847060067313, 55.72654683249337, 47.27453224999564, 27.3332804611751, 48.36718511581421, 49.98993342263358, 68.83442769731793, 45.07175874710083, 0.3138643795890467, 0.32454487362078255, 0.008432593179999717, 0.04636127155806337, 0.16912333347967692, 8.489849260875157, 62.50613348824637, 58.91107300349644, 61.876119477408274, 53.40022393635341, 51.503872939518516, 45.57300179345267, 46.14237192698887, 43.513573101588655, 48.003797803606304, 51.19992051805769, 54.583481311798096, 55.02468844822475, 55.97428832735334, 57.394322940281455, 57.54853820800781, 55.74599484034947, 57.24350881576538, 56.14802803312029, 55.41953372955322, 53.635125160217285, 53.243368353162495, 50.19546808515276, 44.53897435324532, 40.98027031762259, 40.82467930657523, 39.671966212136404, 42.396441732134136, 47.36370543071202, 48.3265312058585, 48.461746624537874, 54.04291493552071, 52.90409476416451, 51.47333560671125, 53.05447810036795, 51.605309690747944, 47.41138744354248, 40.83445542199271, 40.3880684035165, 41.89919737407139, 39.19157470975603, 38.538207803453716, 38.17795065471104, 39.15256404876709, 39.01904746464321, 41.60033450807844, 41.00425202505929, 40.36037635803223, 42.83741610390799, 43.64338976996285, 42.50879062925066, 45.65840905053275, 43.60009207044329, 46.78413534164429, 46.7191036769322, 47.04061072213309, 47.59703288759504, 46.155667304992676, 49.070280279432026, 49.88014146259853, 51.65256438936506, 51.152658871241975, 51.472772802625386, 49.65445007596697, 45.572091579437256, 42.285572801317485, 39.77923945018223, 42.78736822945731, 38.08561951773507, 39.347773688180105, 42.44957460675921, 49.514971937452046, 52.18105479649135, 50.94770438330514, 52.14214488438198, 50.5214775630406, 44.80725472314017, 45.374133927481516, 46.5441688810076, 47.725122928619385, 46.38998140607561, 46.81865746634347, 45.03232772009713, 43.89880902426583, 41.990475858960835, 41.693395205906455, 42.53063576562064, 41.57692950112479, 41.22506925037929, 36.72023943492344, 36.14337566920689, 37.33861868722098, 36.078809533800396, 36.62097746985299, 38.1997332572937, 38.16214350291661, 38.028644289289204, 38.443194661821636, 44.618631975991384, 50.01466900961739, 53.044587339673726, 53.38067517961775, 48.32257768086025, 43.40719618116106, 40.554269313812256, 38.61889375959124, 42.20399052756173, 43.93525232587542, 47.55221700668335, 45.19302218300955, 46.78907551084246, 46.23247616631644, 43.89968449728829, 42.286524704524446, 42.71527719497681, 42.02236809049334, 46.144105502537315, 40.6885849407741, 43.636226177215576, 42.39999573571341, 45.481681619371685, 49.067448888506206, 50.32567385264805, 50.59977681296212, 50.912202562604634, 55.19446420669556, 57.62253999710083, 57.15632976804461, 61.56730679103306, 59.32225349971226, 67.65155247279576, 64.50318472726005, 72.68448012215751, 59.72290052686419, 48.93447078977312, 8.596136723245893, 0.8941273614764214, 2.6647594443389346, 0.32947101071476936, 52.83652353286743, 71.5548906326294, 70.2706411906651, 50.94818728310721, 53.66467237472534, 32.606819016592844, 29.200860704694474, 54.582314014434814, 63.787152017865864, 32.5688853263855, 0.28158019908836907, 0.03410714625247887, 0.034414617610829215, 0.20255516096949577, 0.010061212931759655, 0.16842339746654034, 0.13669151732964174, 0.15151578400816235, 0.14071525713162764, 0.1787772990231003, 0.1114293464592525, 0.11032046417572669, 0.5252695913825716, 52.03569500786917, 73.9027772630964, 59.36297689165388, 54.0159524508885, 34.581118379320415, 56.86846242632185, 56.988117354256765, 74.9040891102382, 51.32921607153756, 0.47832251340150833, 0.8696744793227741, 0.08409407468778746, 0.292271685387407, 0.5082328798515456, 9.891320892742701, 66.43633338383266, 61.22988142286028, 65.54424027034214, 55.844916343688965, 54.66543184007917, 48.42079741614205, 49.42508309228079, 46.538850034986226, 53.1429877281189, 55.29060295649937, 58.527233668736045, 58.965949875967844, 59.37188448224749, 60.036500522068565, 60.03584739140102, 58.74400356837681, 60.14386408669608, 56.59858397075108, 57.92521742412022, 54.205805029187886, 54.95067623683384, 52.85332775115967, 46.990847723824636, 41.58653538567679, 43.81527083260672, 41.31324883869716, 44.63628734861101, 49.9803066934858, 50.02539702824184, 51.75349044799805, 56.836858545030864, 55.6013993535723, 53.78251034872872, 55.288740839277, 52.72468185424805, 50.11451809746878, 43.050934246608186, 43.055513109479634, 43.17135695048741, 41.7795980317252, 41.74740007945469, 40.637446199144634, 41.72448492050171, 40.10507869720459, 46.43315403802054, 44.100855691092356, 41.93165240968977, 44.94144180842808, 45.51890311922346, 44.23662001746041, 48.58997562953404, 47.065057958875386, 50.63606378010341, 50.859722818647114, 50.206387179238455, 51.17853396279471, 49.780365330832346, 52.854043415614534, 52.508919443402974, 54.647210189274375, 54.09578030450003, 53.74571616309029, 53.31793294634138, 47.349510260990684, 46.020101002284456, 39.94544383457729, 45.47468825748989, 40.16360684803554, 41.75143003463745, 44.51443331582205, 51.45512785230364, 52.58576651981899, 53.65429524012974, 55.3194831439427, 55.963932037353516, 45.36801603862217, 46.86586005347115, 50.09812382289341, 50.775548866816926, 47.41697726930891, 48.378270966666086, 49.610738958631245, 47.21257168906075, 42.87682281221662, 45.06685331889561, 46.38789347239903, 45.06280599321638, 43.18357188361031, 39.035080432891846, 38.2489230292184, 39.70269462040493, 37.93836287089756, 39.009663922446116, 39.166682788303916, 40.56816571099417, 41.54521792275565, 39.28992646081107, 47.86279106140137, 50.54887778418404, 56.403211048671174, 53.43247052601406, 50.9956191607884, 44.149201256888254, 43.04044246673584, 40.09488568987165, 45.26167385918753, 45.51892396381923, 52.0196134022304, 47.62072624479021, 48.40425375529698, 47.82882826668875, 45.961343560900005, 47.32879420689174, 45.46557222093855, 44.85390492847988, 48.792810916900635, 42.13095106397356, 46.21560941423689, 44.8567328453064, 47.822133677346365, 51.58998196465628, 52.18615130015782, 52.867609773363384, 54.45821223940168, 58.59372098105294, 59.74885204860142, 60.08353982652937, 64.37785312107631, 62.26610796792166, 69.27771581922258, 67.73098427908761, 75.58351870945522, 61.70112909589495, 52.657030718667166, 10.527446712766375, 0.9682615463222776, 4.183011404105595, 0.575502515903541, 55.966099875313894, 78.25166170937675, 77.01722390311105, 60.10464150565011, 62.22615582602364, 41.40772696903774, 35.46842418398176, 63.28001689910889, 75.8597721372332, 40.480555874960764, 0.2816236253295626, 0.11331325822642871, 0.08995300065726042, 0.30285935582859175, 0.11973925626703671], [0.053127724544278214, 0.07548425240176064, 0.027261693130380342, 0.03774422626676304, 0.04385911260864564, 0.025393272317679863, 0.08826069360865013, 0.831239541726453, 39.52960457120623, 48.64545004708426, 42.86632408414568, 26.184487887791224, 23.4279933316367, 37.69551985604422, 42.636418615068706, 58.91224030085972, 54.7945293698992, 2.204631928886686, 0.2631381329681192, 0.12134708570582525, 0.05070743423753551, 0.043184699690235515, 4.924686006137303, 54.31580196108137, 59.546610832214355, 59.50995213644845, 51.345902170453755, 50.740321499960764, 46.64804097584316, 50.34555264881679, 49.748945576804026, 54.22007315499442, 52.845392908368794, 57.51294953482491, 54.22356809888567, 58.38804040636335, 55.5804956981114, 54.390863350459504, 55.2700571332659, 55.20187446049282, 51.801082134246826, 52.80846323285784, 51.931610992976594, 48.50177519662039, 39.943953445979524, 38.8146835735866, 39.51316860743931, 39.88490070615496, 40.50736549922398, 46.29571866989136, 48.446193081992014, 54.588539600372314, 54.63355350494385, 51.11261292866298, 51.93021093096052, 50.68823085512434, 50.116751943315776, 47.170531613486155, 43.14172635759626, 41.49853992462158, 37.565310614449636, 38.6090099470956, 39.851292269570486, 35.103629861559185, 38.33052267347063, 37.90699870245797, 35.02542093821934, 36.4641774722508, 40.39216089248657, 37.84369713919503, 41.65360982077462, 40.00771706444876, 40.984432288578574, 43.75850057601929, 43.429312297276084, 44.39666134970528, 45.387550898960654, 44.88836451939174, 45.18493447984968, 45.481320313044954, 43.829236711774556, 46.34299421310425, 48.18259579794747, 50.098829065050396, 48.807482038225444, 46.946323667253765, 48.68704891204834, 42.17578084128243, 37.948878969464985, 40.00795677730015, 36.43669734682356, 40.499267373766216, 44.38200412477766, 47.04904930932181, 50.919296673366, 48.08302811213902, 48.24037701742989, 46.71626533780779, 45.74661990574428, 44.44967957905361, 43.33354875019619, 42.916208675929475, 43.9241977419172, 42.58057246889387, 42.32328414916992, 38.66240685326712, 38.304147311619346, 38.289698532649446, 39.13069806780134, 38.721553393772666, 35.00804696764265, 34.1215888432094, 35.99858910696847, 34.80012559890747, 35.898430824279785, 34.97073861530849, 36.652042865753174, 38.84375136239188, 38.31476068496704, 38.01726313999721, 44.37716817855835, 48.07457215445382, 50.24142347063337, 49.00101021357945, 49.01353086744036, 47.0150100844247, 41.20047262736729, 36.97941071646554, 39.19526072910854, 38.859280586242676, 44.83146572113037, 46.12538010733468, 49.092865398951936, 45.783101422446116, 46.177258832114084, 43.74814428601946, 42.64886631284441, 38.5644268308367, 39.452382292066304, 40.14702149799892, 39.79653351647513, 41.48526886531285, 42.5493437903268, 43.11899185180664, 48.89063113076346, 50.51856279373169, 54.65652772358486, 52.82739707401821, 55.44012124197823, 57.04149341583252, 63.85236086164202, 62.35532283782959, 64.12666879381452, 60.89600658416748, 69.90319265638078, 58.54765442439488, 67.16701984405518, 4.861440896987915, 0.3060177463505949, 0.7910370475479535, 1.2570287883281708, 62.63863563537598, 61.74440942491804, 66.22756780896867, 47.80513490949358, 34.628908089229036, 20.366485016686575, 56.82171147210257, 48.85427120753697, 53.50393622262137, 27.45750904083252, 0.2044177803077868, 0.04217923292890191, 0.0671866105071136, 0.05791510801230158, 0.06928551609494857, 0.05085565681968417, 0.032461960068238635, 0.08819452287363154, 0.01353388391102531, 0.028736779067133154, 0.013230755176794316, 0.07420741913041898, 1.0786777585744858, 49.436634472438264, 55.20017910003662, 52.23075873511178, 25.790552820478165, 23.285171372549875, 44.576751708984375, 48.41344274793352, 64.78091812133789, 59.574181284223286, 2.765757373401097, 0.6299903435366494, 0.1282681700374399, 0.17685400508344173, 0.07553113917154924, 5.836059067930494, 58.15634230204991, 61.401613099234446, 60.60381398882185, 54.07391432353428, 53.76601879937308, 49.68221160343715, 51.67815807887486, 51.371308258601594, 56.81784132548741, 54.84032494681222, 57.97989627293178, 56.2522405896868, 59.67524978092739, 57.711452620370046, 57.25792980194092, 56.904714652470176, 57.42433568409511, 53.1717289515904, 54.50050939832415, 53.15661314555577, 52.346651213509695, 42.008131231580464, 40.13588700975691, 40.7277067729405, 40.95738295146397, 41.18430069514683, 48.560397148132324, 52.32999638148716, 56.75616216659546, 56.775710923331125, 52.43923595973423, 52.96844550541469, 52.50594561440604, 53.303557123456685, 50.17504038129534, 45.7256224496024, 42.92579024178641, 40.94666535513741, 40.92247520174299, 43.32863637379238, 38.99464539119175, 39.822839396340505, 38.777361324855256, 37.95775529316494, 37.75837673459734, 40.82046869822911, 38.2094190461295, 42.25946841921125, 42.109696524483816, 44.18054805483137, 46.00147983006069, 45.217969690050396, 46.73592526572091, 47.01191813605172, 45.94440385273525, 47.26538494655064, 46.917186396462576, 47.68359007154192, 48.18807792663574, 50.95031690597534, 53.659933703286306, 51.56351627622332, 48.173802852630615, 50.909767218998496, 43.46028389249529, 39.1349538394383, 40.82280676705496, 36.65184136799404, 40.48326219831194, 45.445057664598735, 48.237917355128694, 53.00776188714163, 49.4718132019043, 51.19888176236834, 49.157146658216206, 48.82695089067732, 47.12957893099104, 44.70653363636562, 44.72051688602993, 46.47128227778843, 45.69509206499372, 44.87052501950945, 41.74954359872, 40.955836977277485, 41.45028815950666, 40.91895593915667, 40.010961873190745, 36.63062504359654, 36.97720466341291, 37.975410665784565, 36.10281555993216, 38.34196983064924, 36.441609723227366, 39.69513498033796, 40.451408181871685, 39.9251446723938, 40.83921841212681, 45.16808162416731, 50.58835744857788, 51.518210547310964, 50.67510570798601, 52.59073448181152, 48.441562107631135, 42.74960477011544, 39.938012736184255, 39.98727546419416, 42.514442988804404, 48.24750934328352, 49.1552289554051, 51.41868455069405, 48.872079440525596, 49.264711720602854, 48.15005043574742, 44.42150463376726, 40.617654255458284, 42.09181880950928, 42.36227396556309, 42.657193728855674, 43.18653876440865, 46.019809177943635, 47.15689924785069, 51.63376603807722, 52.94651699066162, 57.754969188145225, 56.15216221128191, 59.472334589277, 60.93084485190255, 65.5756252833775, 64.80072743552071, 66.87215219225202, 63.33328873770577, 72.2888080051967, 59.39777347019741, 69.73106493268693, 5.7622570395469666, 0.24159280051078114, 1.6421028396912982, 1.5037733252559389, 68.92976393018449, 65.54629693712506, 72.5830294745309, 52.00811413356236, 45.868321078164236, 22.078674009868077, 45.04922921316964, 56.06121029172625, 64.93007510049003, 35.09048039572579, 0.1976600329258612, 0.03970433412385838, 0.09416814840265683, 0.04561680668432798, 0.055039642844349146, 0.1703781618603638, 0.192963145673275, 0.20987635026020662, 0.13512810479317391, 0.1732139904052019, 0.17258281713085516, 0.1441261169633695, 1.8215922883578708, 60.92874649592808, 62.463367325919016, 56.94383648463658, 34.95355224609375, 33.76310348510742, 52.98574651990618, 55.13412257603237, 69.17016465323312, 66.8179770878383, 3.4550362612519945, 0.8562598420040948, 0.353699189211641, 0.3679123536816665, 0.13564413067485603, 6.806680287633624, 61.81069523947579, 65.73045894077846, 64.81427642277309, 57.26075424466814, 55.870853969029014, 51.81696571622576, 55.6230707849775, 53.711478914533345, 58.60172530582973, 57.81628009251186, 60.08349118913923, 58.50574289049421, 62.69974504198347, 58.98879555293492, 59.84739140101841, 60.27314921787807, 59.55708176749093, 56.0296585219247, 57.189788818359375, 56.14508894511631, 54.91116877964565, 43.83627871104649, 42.169586522238596, 43.84521756853376, 43.47051164082119, 43.22959675107683, 51.162091050829204, 55.329745633261545, 61.383638109479634, 59.317403657095774, 55.77104309626988, 54.79384844643729, 55.19485330581665, 54.878783226013184, 51.78837735312325, 48.99376671654837, 45.103935854775564, 43.01289285932268, 42.41970082691738, 47.282411507197786, 39.70622430528913, 43.00979743685041, 40.847486768450054, 39.96540948322841, 39.52764170510428, 44.77015134266445, 40.779126916612896, 46.85086931501116, 43.328667640686035, 47.594316141945974, 49.72185455049787, 48.69437231336321, 52.36444902420044, 51.70536722455706, 48.758545875549316, 51.43121910095215, 49.71430533272879, 48.883443219321116, 52.53716039657593, 53.64906324659075, 55.849512577056885, 53.83822100503104, 52.95972204208374, 52.51477677481515, 45.278665678841726, 40.20649807793753, 42.14746345792498, 37.77015045710972, 41.28109952381679, 47.35000358309065, 51.42660897118704, 56.45019129344395, 52.81409822191511, 53.980200495038716, 52.49219165529524, 51.52665260859898, 50.32493039539882, 47.40579414367676, 47.24329662322998, 49.14539378029959, 47.911796706063406, 47.60814305714199, 44.51431867054531, 43.09512478964669, 44.15211255209786, 43.44392088481358, 42.099903038569856, 38.864029679979595, 38.83501400266375, 40.6036571093968, 39.077019759586875, 40.433700697762625, 38.653853620801655, 41.889039107731406, 41.71153695242745, 43.40065097808838, 43.34582274300711, 47.279017312186106, 52.54193033490862, 54.2439158984593, 53.70468357631138, 54.00921617235456, 51.952080386025564, 45.142411504473, 41.85197741644723, 42.838972500392366, 44.90111446380615, 51.43330008643014, 51.545840059007915, 55.51650626318795, 52.342284270695274, 49.114637579236714, 49.82653611046927, 47.27609559467861, 42.2213089125497, 43.30595050539289, 44.19169643947056, 44.19062294278826, 47.409820624760215, 48.34341185433524, 49.49839006151472, 54.630624839237754, 54.74248388835362, 60.64168167114258, 58.753473963056294, 59.79895550864083, 64.32907676696777, 68.19766003744942, 67.32338905334473, 70.0189288003104, 66.61293574741909, 73.09920419965471, 60.074618339538574, 71.39662456512451, 7.181204693658011, 0.5629402814166886, 2.7777234741619656, 2.2484403210026875, 74.09240055084229, 72.38098975590297, 78.9496429988316, 60.75463853563581, 53.859621456691194, 28.636997018541607, 70.73261301858085, 65.64170265197754, 76.12412330082485, 43.359510694231304, 0.2866642991346972, 0.16203032194503716, 0.21637508725481375, 0.2046560546649354, 0.18870881253055163], [0.010861702745647302, 0.11452759163720266, 0.04989119053685239, 0.05278867416615997, 0.0728880213573575, 0.08377879339137248, 0.036701263660298925, 0.6854061356612614, 43.27809517724173, 48.65106419154576, 53.68600334439959, 42.53618390219552, 23.263642379215785, 33.06673417772566, 42.55269282204764, 52.25742939540318, 67.8495761326381, 9.047046150479998, 0.41571376153400963, 0.350035697221756, 0.0873748322150537, 0.030128481531781808, 2.41413922395025, 52.83582871300833, 59.09217779976981, 57.831691196986604, 53.31608125141689, 55.40576239994594, 53.80966738292149, 52.50243330001831, 53.59241458347866, 57.0685601234436, 56.419521944863455, 57.7574496950422, 56.83426339285714, 55.369405950818745, 54.3517484664917, 55.16377748761858, 53.70769214630127, 49.75024836403983, 49.57445893968855, 46.35902370725359, 43.87321186065674, 40.20938505445208, 39.684726578848704, 41.25048576082502, 38.970979826790945, 38.109695025852744, 43.155379567827495, 48.417354583740234, 50.35477985654558, 48.11590003967285, 52.58699287687029, 48.57384191240583, 50.34256492342268, 49.47145536967686, 49.60574320384434, 44.16679409572056, 41.19217300415039, 40.54348223549979, 38.762707574026926, 44.55172777175903, 39.8534323147365, 35.48193495614188, 38.04534428460257, 36.39883313860212, 36.9183395249503, 37.12666041510445, 36.41990007672991, 37.75636175700596, 38.37418515341622, 41.475388526916504, 38.72028882162911, 41.186826365334646, 42.208979334150044, 44.58856364658901, 41.437347139631, 43.66999094826834, 41.62143966129848, 44.165314129420686, 45.444046701703755, 47.00827380589077, 48.06065143857683, 51.53486885343279, 46.976784569876536, 49.00507490975516, 51.56079953057425, 47.187579018729075, 37.35480104173933, 39.419069153921946, 36.30296189444405, 41.837844780513215, 45.04937859943935, 49.32839543478829, 50.46700716018677, 46.920976638793945, 46.63159458977835, 47.839309624263215, 42.08653817858015, 42.82857799530029, 43.23051738739014, 44.123322691236226, 42.00283670425415, 43.716557775224956, 41.681527682713096, 41.13248797825405, 39.717733996255056, 37.88037667955671, 40.1654064314706, 38.474322591509136, 35.075159617832725, 33.900882789066856, 33.728675161089214, 37.58020755222866, 34.9695782661438, 36.0947139603751, 37.34861019679478, 36.488548278808594, 35.20215879167829, 38.88863672528948, 43.980200222560335, 51.86068378176008, 48.5088449886867, 47.08795574733189, 48.55991424833025, 47.4740115574428, 45.421194076538086, 41.01650864737374, 39.17447519302368, 38.00682347161429, 41.558832917894634, 44.048897062029155, 47.58579070227486, 47.98470067977905, 49.26523978369576, 49.757741996220176, 48.31330183574131, 45.39861937931606, 44.893294266292024, 40.54695633479527, 42.81538336617606, 39.78747306551252, 45.13385132380894, 43.631636892046245, 48.12658289500645, 50.125548362731934, 54.84957994733538, 54.816409247262136, 58.365180832999094, 58.654045241219656, 63.25503812517439, 60.64269610813686, 65.92399406433105, 60.831499508449006, 69.9412340436663, 64.28577559334892, 69.18160138811383, 4.691070633275168, 0.1908387475247894, 0.957912204521043, 3.7182060139519826, 69.54734066554478, 62.83233751569475, 64.73036997658866, 46.99200112479073, 39.451704842703684, 24.544075523103984, 38.66952875682286, 55.21920326777867, 57.10792861665998, 31.970464774540492, 0.14701708326382296, 0.0646639462294323, 0.05702822881617716, 0.09945052316678421, 0.17257274767117842, 0.02448813713687871, 0.13195706637842314, 0.07443187851458788, 0.06363576890102454, 0.13565763352172716, 0.07005411985197238, 0.05422910901584795, 1.1844399805579866, 55.14412103380476, 53.059696197509766, 60.04013442993164, 36.981811319078716, 26.85779438699995, 42.23148454938616, 50.10532910483224, 56.47696965081351, 73.11872168949672, 9.896611945969717, 0.6348804097090448, 0.4061770604125091, 0.08632103340434176, 0.10101774907005684, 2.4291453787258694, 55.3401575088501, 59.59230218614851, 62.380058424813406, 55.97153684071132, 57.323708398001536, 56.335167339869905, 55.76047141211373, 56.1469406400408, 60.09383010864258, 58.7540089743478, 60.44171946389334, 57.5586130959647, 56.52656241825649, 55.299944809504915, 55.968083586011616, 53.3874705178397, 52.44358900615147, 51.64298282350813, 48.54812315532139, 47.3160651070731, 42.08802161897932, 41.71996859141758, 43.749332427978516, 41.15583392551967, 40.013491017477854, 46.11227233069283, 50.06943471091134, 53.745135988507954, 47.51133380617414, 50.58121470042637, 50.24396651131766, 50.69335862568447, 52.525956426348, 51.845776421683176, 44.04866429737636, 43.01627663203648, 42.444547585078645, 40.55714586802891, 47.10940483638218, 40.34845324925014, 36.58374554770333, 39.37844998495919, 37.57305785587856, 38.64913231985909, 38.150977747780935, 37.32948875427246, 38.31642825262887, 38.95674991607666, 45.53925091879708, 41.89442048754011, 43.709467138562886, 44.78381150109427, 47.755712372916086, 43.70104244777134, 46.37812083108084, 44.906492369515554, 45.447527749197825, 46.627720969063894, 49.305744307381765, 50.769861766270225, 52.09208311353411, 47.71289757319859, 51.2508681842259, 54.48861060823713, 48.752111843654085, 37.52348245893206, 38.85325302396502, 36.384780406951904, 43.09184523991176, 46.629711627960205, 52.89515243257795, 51.093140602111816, 49.63395636422293, 48.37785407475063, 50.18046692439488, 45.34505224227905, 46.094036783490864, 44.7043901171003, 45.197243213653564, 44.0470940044948, 44.63469621113369, 44.01177283695766, 42.92474453789847, 42.749823638371055, 40.787499495915, 41.70854575293404, 39.93515007836478, 38.00865432194301, 33.83592408043997, 35.62753793171474, 40.027203287397114, 38.0952080317906, 38.978852135794504, 39.15060813086373, 40.04953827176775, 37.46575335093907, 40.427235398973735, 46.789964880262104, 55.14369371959141, 50.1937449319022, 49.14150973728725, 50.690989289964946, 50.22514384133475, 47.343937805720735, 43.36716760907854, 42.66079289572579, 40.687890120915, 43.88289417539324, 47.26877219336373, 51.05528334208897, 51.25667340414864, 51.39023862566267, 52.44880015509469, 51.9061666897365, 46.95095811571394, 45.434715270996094, 41.70287602288382, 43.99645553316389, 42.51345634460449, 48.14285210200718, 45.38329860142299, 50.05073363440377, 51.14773607254028, 57.514933245522634, 56.30739886420113, 61.0052878516061, 59.4806307383946, 65.40970924922398, 63.32695198059082, 68.58023480006626, 64.30770410810197, 72.20685400281633, 64.10753345489502, 71.48697893960136, 5.997182582105909, 0.15418127312191895, 1.6154288138662065, 3.622446809496198, 75.64945711408342, 65.55740710667202, 71.40898541041783, 51.59354986463274, 48.78718982424055, 23.41233035496303, 38.612133162362234, 65.62905693054199, 64.12985106876918, 37.31728771754673, 0.12437629673097815, 0.04991130231480513, 0.09561483934521675, 0.10288024627204452, 0.10954683247421469, 0.0913534222968987, 0.1905488773648228, 0.15436165487127645, 0.1236063494746174, 0.16276153842253344, 0.1612283071236951, 0.158955364088927, 2.862633717911584, 68.27723775591168, 64.70950453622001, 69.97353621891567, 55.55675022942679, 35.97136606488909, 50.42197935921805, 57.494526386260986, 61.32161848885672, 81.60749571663993, 11.425865292549133, 1.1216658289943422, 0.5940817275217601, 0.1526362353137561, 0.24949520932776587, 3.1644652017525265, 60.00194018227713, 63.815973145621165, 64.16507148742676, 57.602973869868684, 59.209373065403526, 57.565929549080984, 57.56367138453892, 57.60546827316284, 61.71914577484131, 58.29770687648228, 62.180700710841585, 58.74177319662911, 57.358539717538015, 57.931696619306294, 58.56972885131836, 56.340434074401855, 54.93065847669329, 53.33873585292271, 50.70617110388619, 49.86412933894566, 44.246142523629324, 43.356957231249126, 46.239445209503174, 42.03537164415632, 41.978667395455496, 48.921043395996094, 52.85003777912685, 55.12598623548235, 49.29624611990792, 50.597845213753835, 51.21853126798357, 53.67089101246425, 55.03004898343767, 54.29272699356079, 47.522919927324565, 44.9326662336077, 45.649848869868684, 42.5689411844526, 48.6910719190325, 43.24023791721889, 38.45185211726597, 40.408944266183035, 38.64603689738682, 38.980335576193674, 39.72298683438982, 40.50279011045183, 41.04718147005354, 41.315771034785676, 48.14315782274519, 42.52560526984078, 46.70605148587908, 46.04112972532, 51.50024945395333, 46.01319101878575, 49.75529623031616, 47.03358956745693, 49.348569529397146, 48.416736194065635, 51.33124494552612, 55.028600284031455, 56.21919495718819, 52.13075678689139, 55.03403377532959, 56.828996658325195, 52.006293705531526, 37.67320224217006, 40.016364097595215, 37.43367004394531, 44.50861767360142, 49.032951082502095, 54.55262436185564, 55.98439448220389, 51.78852326529366, 51.72829627990723, 54.55471229553223, 47.21872431891305, 49.824594088963096, 47.785148416246685, 48.59874773025513, 46.41646793910435, 48.0917272567749, 47.30239452634539, 46.57310117994036, 46.18890053885323, 43.13733509608677, 45.69018316268921, 43.540261132376536, 39.43888194220406, 36.439608642033164, 37.1513786315918, 42.45631435939244, 39.45042290006365, 41.50732592173985, 42.92202431815011, 41.856521538325715, 39.39931889942714, 43.13151945386614, 48.39072561264038, 59.13909898485456, 51.50873320443289, 50.1430196080889, 53.73573160171509, 51.50384862082345, 51.19618238721575, 46.6780606678554, 45.16348886489868, 44.42128576551165, 47.039783886500764, 49.97346271787371, 53.58552197047642, 52.69149725777762, 55.88623380661011, 55.131047998155864, 53.89741965702602, 50.42254911150251, 49.48077290398734, 43.63756023134504, 47.18682166508266, 44.61621747698103, 50.31559549059187, 49.09930290494646, 52.425638335091726, 55.30756350925991, 60.94558892931257, 59.66195787702288, 63.78553308759417, 62.700641359601704, 69.82968071528843, 67.72587735312325, 72.19456263950893, 65.31428963797433, 75.21336037772042, 66.75951494489397, 73.54891245705741, 6.41876757144928, 0.1966435331851244, 2.847817987203598, 4.5822726999010355, 82.42722334180559, 71.82953207833427, 78.87848649706159, 59.748574120657786, 57.57646301814488, 34.11305298124041, 53.880966322762625, 73.23437445504325, 77.11322021484375, 45.549152101789204, 0.26842913191233364, 0.11922677233815193, 0.13387369710419858, 0.19583286025694438, 0.2998317325753825], [0.1524612411324467, 0.03804857297135251, 0.0333304407873324, 0.07706795313528605, 0.05578147839488728, 0.12092388341469423, 0.020342120235519748, 1.854956018073218, 50.379272256578716, 45.54909304210118, 31.418385233197892, 19.34160140582493, 22.197152955191477, 36.95939990452358, 42.88808931623186, 54.29349824360439, 64.15660163334438, 31.91529607772827, 0.4029546161847455, 0.6846698980246271, 0.18018270789512567, 0.10901476602469172, 0.42932235130241936, 36.62833213806152, 60.40009280613491, 61.50919900621687, 59.693864004952566, 58.49142960139683, 57.62221690586635, 58.659548214503694, 58.186817101069856, 58.130237919943674, 55.021725041525706, 55.03842503683907, 56.78123821531023, 54.05562319074358, 51.93322992324829, 54.33894988468715, 49.660550594329834, 47.45177384785244, 44.18644707543509, 39.920544964926584, 39.28852987289429, 40.99683829716274, 39.66345466886248, 38.70627777917044, 42.09171806062971, 40.79014675957816, 46.401602268218994, 47.66796704701015, 54.075373445238384, 30.346431050981792, 31.384415490286692, 52.11678743362427, 50.83763796942574, 54.254518849509104, 48.86978653499058, 44.50742605754307, 40.11319419315883, 40.444393975394114, 42.03243603025164, 50.01961612701416, 38.695046016148154, 35.46442549569266, 36.11435999189104, 35.983264854976106, 36.48609903880528, 35.320778438023154, 34.74443231310163, 37.347825050354004, 36.982044083731516, 41.741973536355154, 39.249269076756065, 40.648406982421875, 41.046559606279644, 43.80615827015468, 41.136222634996685, 42.87790673119681, 40.8137880052839, 42.25219712938581, 44.96745933805193, 47.7337942804609, 47.3842373575483, 44.990006242479595, 46.16019753047398, 48.77070869718279, 50.410132680620464, 48.35763134275164, 36.036936214991975, 35.13812071936471, 37.31237881524222, 42.88689770017351, 47.353783403124126, 48.93895237786429, 48.31218664986746, 47.14119979313442, 48.453130858285085, 44.533547810145784, 43.87476478304182, 42.24648571014404, 40.69938244138445, 42.35915075029646, 41.7868241582598, 41.81805978502546, 40.587307998112266, 39.375573430742534, 39.1597033228193, 38.739205292293, 38.61735125950405, 35.910520689828054, 34.32957969393049, 36.45592648642403, 34.49940061569214, 36.047768456595286, 35.89192383629935, 33.86857713971819, 37.255136081150596, 40.04342038290841, 37.80184466498238, 37.9246506009783, 44.355760778699604, 50.04782581329346, 51.19378873280117, 46.98192276273455, 50.05327320098877, 50.09331219536917, 48.039112022944856, 46.00322730200631, 40.2781583241054, 38.4572126524789, 39.2953599521092, 42.57267236709595, 45.92720011302403, 49.13352278300694, 48.60862806865147, 49.8806278364999, 51.29177917752947, 49.77107906341553, 48.76104027884347, 42.577452727726524, 40.74243000575474, 41.52069078172956, 43.13119288853237, 41.37846115657261, 44.56813594273159, 44.98473603384835, 52.80832426888602, 51.576624052865164, 58.49750232696533, 55.29056126730782, 62.064651897975374, 57.92189271109444, 65.20652307782854, 57.98644495010376, 67.68716199057442, 57.986774989536826, 75.45680441175188, 3.9813390714781622, 0.10472022289676325, 0.9386012064559119, 6.760274137769427, 72.0780621937343, 58.46059349605015, 66.05040264129639, 46.867242744990754, 39.1769174848284, 23.510650839124406, 39.692452975681846, 44.784019947052, 61.6355311529977, 32.05230065754482, 0.08408435806632042, 0.05999306722411087, 0.030181807598897388, 0.09285513564412083, 0.03634772655953254, 0.01977442391216755, 0.04754206159019044, 0.055051632558128664, 0.08274562883057765, 0.10708946362137794, 0.04718514199235609, 0.054257308931222985, 3.1513708872454504, 59.68863895961216, 51.05774300439017, 45.89072901862008, 28.263784953526088, 25.780092307499476, 44.6801825932094, 48.08416414260864, 58.75887966156006, 70.06587082999093, 34.67376913343157, 0.5369155864630426, 0.880853859441621, 0.1897921208292246, 0.1375853107976062, 0.3653390503355435, 39.302273409707205, 62.79997975485665, 63.52360684531075, 61.74980122702462, 60.73882443564278, 59.28272519792829, 61.93655490875244, 60.71800763266427, 58.89405686514718, 55.71216058731079, 55.88313143593924, 56.690626757485525, 55.53029843739101, 53.54219995226179, 55.496849809374126, 51.13841506413051, 48.91816336768014, 45.720209802900044, 41.973796708243235, 39.6089425768171, 41.58559043066842, 41.4383407320295, 40.216739722660606, 43.63600036076137, 43.7366623878479, 49.006485394069124, 50.87772907529558, 55.50106736591884, 31.831723145076207, 33.80709947858538, 53.28865671157837, 51.72738259179251, 55.087159701756065, 50.60714190346854, 45.62134041104998, 41.706628050122944, 42.89165374210903, 44.61636686325073, 52.695138113839285, 41.18777826854161, 37.431974683489116, 39.04803882326399, 37.79898548126221, 37.427788393838064, 36.679397923605784, 37.2339197567531, 38.51766545431954, 39.12436825888497, 42.61105421611241, 42.83929211752755, 41.774637017931255, 44.58535705293928, 45.56025879723685, 42.955271448407856, 44.08207471030099, 43.094933714185444, 46.93985142026629, 47.83766637529646, 49.294491699763704, 49.571370465414866, 48.33555691582816, 47.906015804835725, 51.60065787179129, 49.91047382354736, 51.34633295876639, 36.82385097231184, 34.969352449689595, 38.00723688943045, 44.6372184072222, 48.820603711264475, 51.34124687739781, 50.81227009637015, 49.34360156740461, 49.03438935961042, 48.26976094927107, 46.09622546604702, 44.55815832955496, 44.795084953308105, 43.83925254004342, 43.18599680491856, 44.41147838320051, 44.37403106689453, 41.52521405901228, 38.98410497392927, 41.11324494225638, 41.54053136280605, 37.99514354978289, 37.1210914339338, 37.172455992017476, 36.144202504839214, 37.7012243270874, 38.245400292532786, 35.87799964632307, 41.21201011112758, 43.08306966509138, 40.235274042402, 38.441016401563374, 47.04451213564192, 51.15713698523385, 53.32833092553275, 47.781795910426546, 51.79038885661534, 52.33237613950457, 50.057188510894775, 47.876183714185444, 43.079050132206504, 41.018384660993306, 42.401500020708355, 44.90160778590611, 50.44887931006295, 51.385586806706016, 53.41101448876517, 52.806024415152415, 55.07064730780465, 51.16244888305664, 50.945071016039165, 45.51077372687203, 44.22566270828247, 43.394765853881836, 45.73281036104475, 45.42275742122105, 47.06989043099539, 46.36073643820626, 56.15180785315377, 53.43376636505127, 62.02012089320591, 57.85294573647635, 64.86902127947126, 60.318152700151714, 68.55570071084159, 60.12577097756522, 71.61360985892159, 58.53798253195626, 78.32264450618199, 4.418292607579913, 0.10841026596192803, 1.1044097606624876, 7.72621704850878, 78.30935955047607, 63.548863547188894, 72.76231384277344, 55.258741991860525, 47.11714512961251, 29.878792967115128, 47.977644784109934, 50.082459109170095, 70.52529266902378, 40.870478357587544, 0.05476880559165563, 0.022343644173815846, 0.03590925383780684, 0.039802816696465015, 0.07323870182569538, 0.323533585028989, 0.14710294508508273, 0.13478144125214644, 0.10159447669450726, 0.13351164438894816, 0.28532628236072405, 0.1327125472681863, 5.027781205517905, 74.675826890128, 56.99822003500802, 47.93040745598929, 29.233941078186035, 34.4481645992824, 51.69047723497663, 56.57834039415632, 63.34207820892334, 76.70470087868827, 38.15774529320853, 1.347070928130831, 1.5132008365222385, 0.49345704700265614, 0.347455445677042, 0.6739539301821164, 42.826194763183594, 65.0750423158918, 67.41137409210205, 63.12971346718924, 62.65964698791504, 60.76245525905064, 65.01965822492326, 62.91741820744106, 60.917782238551546, 57.80452721459525, 57.50809621810913, 59.78576782771519, 59.15184892926897, 55.77002171107701, 61.48702730451311, 53.65810980115618, 51.57840973990304, 48.29700483594622, 44.002059255327495, 42.45512621743338, 44.37290893282209, 43.026785782405305, 43.329953057425364, 45.963059765951975, 45.39472491400582, 51.782919543130056, 52.662373883383616, 56.932747159685405, 33.11094903945923, 35.38770696095058, 54.38105249404907, 54.822676522391184, 57.43977805546352, 55.341679164341514, 47.446138858795166, 43.806981631687705, 45.54870046888079, 46.37012692860195, 54.774560247148784, 44.20464093344552, 40.348102365221294, 41.27063206263951, 39.60827554975237, 40.85737752914429, 38.945469515664236, 40.129821232386995, 40.64006219591413, 40.847118513924734, 46.50429316929409, 44.763390745435444, 44.0680775642395, 46.48834357942854, 48.57349797657558, 43.956093447549, 47.11620364870344, 46.001879351479666, 48.00627483640398, 50.72485133579799, 54.02381086349487, 53.36001818520682, 51.012447697775706, 50.26762165342058, 53.58528920582363, 54.26264476776123, 55.74729415348598, 37.28028508595058, 35.56533418382917, 38.667350496564595, 47.616776193891255, 52.21253708430699, 54.30285399300711, 52.606204645974294, 51.800481115068706, 52.31191022055489, 50.7585118838719, 47.53115701675415, 49.385929993220735, 45.86132424218314, 47.33786160605294, 44.554378509521484, 47.47481754847935, 45.77106714248657, 44.33568743297032, 43.139676639011924, 43.41630526951381, 42.68122059958321, 42.440931047712056, 38.90696954727173, 40.081593785967144, 37.88159261431013, 39.01872089930943, 41.58435712541853, 39.747315951756065, 42.27657488414219, 46.50637762887137, 42.54632132393973, 41.30441073008946, 49.38163253239223, 54.29619067055838, 56.27379042761666, 48.356651646750315, 53.7189690726144, 55.6123879296439, 53.246797289167134, 50.95684126445225, 43.843675068446565, 42.57946423121861, 44.530257838112966, 46.484362261635916, 52.94767386572701, 53.98604393005371, 54.65130615234375, 56.74288763318743, 57.67707988194057, 53.71216331209455, 54.32870823996407, 47.48328740256173, 46.9918725831168, 46.75989655085972, 49.0095773424421, 46.93724584579468, 51.43095506940569, 49.22699342455183, 59.095693588256836, 57.682638440813335, 64.37911074502128, 59.88831629071917, 68.78107248033795, 63.526149885995046, 72.10536166599819, 62.900485447474885, 74.83628164018903, 62.28784193311419, 82.56378323691231, 5.9922424129077365, 0.12659700614001068, 2.190296709537506, 7.712767073086329, 87.81883089882987, 69.05770805903843, 82.5487334387643, 57.2931432723999, 60.00420529501778, 31.70522424152919, 56.35595982415335, 58.94942705971854, 82.90560681479317, 47.86817938940865, 0.19050908807132924, 0.2049794580255236, 0.14417949052793638, 0.11790478256131921, 0.1403772516974381], [0.08299944163965327, 0.07687865543578352, 0.03609822244782533, 0.010405622040187674, 0.07871632504143886, 0.08454139889883143, 0.10494475691978421, 4.915723264217377, 52.89180340085711, 46.35493469238281, 31.857150077819824, 28.89769516672407, 32.035444327763145, 39.85550287791661, 42.604046957833425, 58.309039388384136, 60.708342688424246, 48.39627374921526, 0.7526192090341023, 0.9357852318457195, 0.09733063727617264, 0.2640114618199212, 0.08727308588900737, 17.78307008743286, 57.31924418040684, 56.018478870391846, 57.87998117719378, 57.87626389094761, 59.8052088873727, 58.36384677886963, 58.22174916948591, 56.018409388405935, 57.1187504359654, 56.86608961650303, 53.31724507468087, 50.9483505657741, 49.25946235656738, 48.16407537460327, 44.59739133289882, 40.44167028154646, 40.469622884477886, 43.44308015278408, 43.29209927150181, 42.52018220084054, 39.72794784818377, 39.657225608825684, 41.86786447252546, 44.431162629808696, 47.89853259495327, 50.82624639783587, 47.40558917181832, 40.666996887751985, 38.76717873982021, 47.0953243119376, 50.99128348486764, 50.382753304072786, 50.200383935655864, 45.87909773417881, 41.510504722595215, 39.81436606815883, 48.259484563555034, 47.79643923895699, 39.89241518293108, 35.09185266494751, 36.68969515391758, 34.871952601841514, 36.031037194388254, 37.06784391403198, 34.086604663303916, 34.32301017216274, 38.13122401918684, 38.1201103755406, 40.63803679602486, 39.09235443387713, 40.41132402420044, 40.69200692858015, 42.874627181461875, 40.39714275087629, 40.52149813515799, 41.37831177030291, 47.332817213875906, 47.5722382409232, 43.45067800794329, 48.87723152978079, 49.23117971420288, 47.514557770320344, 47.27852399008614, 47.97109610693795, 40.9017139843532, 34.310065678187776, 36.50288241250174, 46.657434940338135, 49.134342670440674, 46.99067401885986, 49.42918947764805, 47.74359471457345, 47.74153804779053, 46.62637301853725, 44.6166969026838, 41.03846148082188, 41.57557807649885, 41.8194911139352, 41.81343575886318, 40.05472162791661, 40.63166182381766, 40.2022978918893, 40.03982121603829, 38.34703506742205, 35.838985511234824, 35.50817482812064, 35.21457869665963, 33.58966950007847, 36.8433267729623, 36.18165329524449, 36.331786496298655, 35.169154848371235, 37.37725067138672, 37.5907757622855, 40.14462784358433, 39.02509587151663, 41.68673883165632, 46.52504743848528, 52.055737086704795, 49.26627853938511, 48.8620879309518, 46.6668358530317, 47.73238032204764, 47.1318370955331, 46.284851687295095, 40.66989081246512, 39.88092981066023, 39.1961327280317, 43.320656367710654, 46.34588813781738, 50.3611478805542, 50.95055314472744, 50.8345217023577, 50.66191107886178, 52.42193147114345, 49.273261478969026, 46.906406266348704, 42.782865796770366, 42.69077784674508, 40.37935536248343, 45.29514333180019, 40.375870840890066, 46.89948238645281, 46.20727852412632, 53.704815592084614, 49.22232076099941, 55.91076094763619, 50.45265218189785, 58.31174223763602, 53.53539419174194, 65.19892869676862, 59.408987862723215, 70.96100725446428, 2.1495201204504286, 0.1701797310795103, 0.49194315395184923, 11.902306744030543, 77.20006574903215, 55.13881261008126, 70.98395020621163, 40.543885231018066, 43.93680872235979, 14.07277546610151, 26.77954724856785, 57.07283673967634, 61.75824328831264, 27.18272689410618, 0.15794208060417855, 0.0708846195733973, 0.054351706723017354, 0.04625191885445799, 0.08239105357123272, 0.07390014454722404, 0.04296500362189753, 0.0851522907614708, 0.05328522948548198, 0.04607534707923021, 0.09972423062260662, 0.055892256022031815, 7.579389452934265, 67.33730629512242, 52.19693143027169, 44.19202300480434, 23.93766106878008, 26.000827891486033, 47.05456617900303, 47.75166852133614, 64.04985645839146, 66.04480239323208, 52.364726952144075, 1.1150628690208708, 1.3585107028484344, 0.15157818208847726, 0.14234657745276177, 0.16870532876678876, 18.682816641671316, 58.98062447139195, 59.483368328639436, 60.87400163922991, 58.7928146634783, 61.46905926295689, 60.59971455165318, 59.77821513584682, 58.4810003553118, 58.313951764787944, 59.74174404144287, 56.808235440935405, 53.55042314529419, 52.123207569122314, 49.7643323625837, 47.165112018585205, 42.40278543744768, 42.26843506949288, 45.53714908872332, 45.674219676426475, 45.79332569667271, 40.83024828774588, 41.39750269481114, 42.73586123330252, 46.79689570835659, 50.19360249383109, 53.90967280524117, 48.77118812288557, 41.62072399684361, 40.55467925752912, 45.95048700060163, 52.830534185682026, 50.53273017065865, 52.781928062438965, 47.130638531276155, 42.655609539576936, 43.735585417066304, 49.84892668042864, 49.97765595572335, 41.851334708077566, 37.56359093529837, 38.43937315259661, 37.47489718028477, 39.82826941353934, 38.60822132655552, 37.53387001582554, 35.77450622831072, 38.617441586085725, 40.767214230128694, 41.55767951692854, 41.131310258592876, 43.23168121065412, 44.45805215835571, 45.923038142068044, 43.084660802568706, 42.68233578545706, 46.44996173041207, 48.76443099975586, 49.474238123212544, 46.818984031677246, 51.30798932484218, 50.853257519858225, 50.54577193941389, 49.37459053312029, 52.63528633117676, 41.601060594831196, 33.30639491762434, 37.04686730248587, 47.7388699395316, 52.324132101876394, 49.30946854182652, 52.33491918018886, 50.62494666235787, 49.2177141053336, 47.96441888809204, 45.97967985698155, 43.14327580588204, 42.977821826934814, 43.724044459206716, 44.567611353737966, 41.99535696847098, 42.79450750350952, 41.1455123765128, 42.98543010439192, 41.10847847802298, 38.35393810272217, 37.71712875366211, 37.189288003104075, 34.387972354888916, 38.87865563801357, 37.01165035792759, 37.70204421452114, 37.48257841382708, 39.48968022210257, 40.044952460697715, 41.529525416237966, 41.742977551051546, 44.23806871686663, 49.07349729537964, 53.6196654183524, 51.323640142168315, 50.88158532551357, 48.65213074002947, 50.91548558643886, 49.20808737618582, 49.54105200086321, 42.740700653621126, 40.87900727135794, 41.11626740864345, 45.56420537403652, 47.35368612834385, 52.12289490018572, 52.679633208683555, 54.202150276729036, 53.411570344652446, 55.69861854825701, 52.34733213697161, 48.381752014160156, 43.97182764325823, 45.58968789236886, 42.758366448538645, 46.82119355882917, 42.7291944367545, 48.488872391836985, 48.058928285326274, 55.43048061643328, 51.19178070340838, 59.25992121015276, 54.36845888410296, 61.683890615190776, 54.951906067984446, 68.91230310712541, 62.63498783111572, 76.43668106624058, 2.0960758796760013, 0.23820715504033224, 0.6663504838943481, 13.388968501772199, 83.72148513793945, 59.10473319462368, 78.48966530391148, 48.14768804822649, 56.441825662340435, 17.283621413367136, 39.59546307155064, 60.69134044647217, 70.2477399281093, 33.81141778400966, 0.10728653733219419, 0.037828398535826376, 0.050829818206174035, 0.024645480926015546, 0.025811584067663977, 0.21522345047976288, 0.2117307186126709, 0.13780932234866278, 0.13965117851538317, 0.2035523360329015, 0.30938121729663437, 0.1753660049289465, 12.175469091960363, 80.84919711521694, 60.88447257450649, 45.41238028662545, 39.78709091459002, 42.570706026894705, 54.065993377140586, 57.358164514814106, 67.33597918919155, 73.18070656912667, 56.503046240125386, 1.8765629615102495, 2.1257468589714597, 0.2166178806551865, 0.8509481613125119, 0.2131777759641409, 20.54254194668361, 62.571439606802805, 62.734986305236816, 62.13729531424386, 62.514936855861116, 63.87979234967913, 63.39522497994559, 59.6980676651001, 58.095670631953645, 59.63782678331648, 63.20205116271973, 59.57527215140206, 56.20578145980835, 54.364470618111746, 52.75506632668631, 49.49785157612392, 43.95972735541207, 45.87903867449079, 49.98980835505894, 46.997733388628276, 48.27662924357823, 43.161622524261475, 44.28868634360177, 45.114372049059185, 48.10765252794538, 52.98037903649466, 55.274142674037385, 49.787052971976145, 43.39051703044346, 39.12287092208862, 47.63716220855713, 55.27341658728463, 52.672973360334126, 55.60734006336757, 50.41250549043928, 45.139858041490825, 44.15203612191336, 53.647197655269075, 52.90016903196062, 43.9350334576198, 39.54300764628819, 41.79308795928955, 38.81734125954764, 41.888361658368794, 41.694510391780305, 38.88999857221331, 37.61970806121826, 42.52871111461094, 41.511223861149375, 43.07631949016026, 41.11262655258179, 44.797527245112825, 47.667598792484824, 48.76236738477434, 45.45584126881191, 45.84670870644705, 47.51209115982056, 52.23314196722848, 52.71163313729422, 49.339780058179585, 53.44461945125035, 53.26804140635899, 52.05790492466518, 51.14698914119175, 52.83222607203892, 40.62457118715559, 33.64133283070156, 37.38519941057478, 49.76261615753174, 54.62542758669172, 53.04317685535976, 56.833585943494526, 54.741194997514995, 51.88619409288679, 52.16586603437151, 47.80609376089913, 45.257338183266775, 45.44258410590035, 47.15530811037336, 47.6643192427499, 44.120526041303364, 45.0139080456325, 42.97391693932669, 46.03795787266323, 43.46048191615513, 40.931396688733784, 38.954154763902935, 39.56096526554653, 37.15886184147426, 40.86373860495431, 39.96422828946795, 40.26829883030483, 39.63214956011091, 40.98838581357683, 41.74234526497977, 45.10403660365513, 43.335845129830496, 45.173139912741526, 50.15706191744123, 55.87360198157174, 53.297015394483296, 52.04948370797293, 49.47340781348092, 53.4522624697004, 53.419244629996165, 51.53244393212454, 44.72395624433245, 44.18642623083932, 44.12092556272234, 49.89517389025007, 51.002146993364605, 56.04340900693621, 56.87281894683838, 56.34832375390189, 55.49442836216518, 59.036856242588584, 54.04686151232038, 51.002473558698384, 48.22363533292498, 47.58566910879952, 44.45303208487374, 51.65992947987148, 45.27012286867414, 51.1772381237575, 50.944754873003276, 59.55663013458252, 54.087157590048655, 62.27794075012207, 57.30365937096732, 65.3766427721296, 57.29644366673061, 73.54179750170026, 65.487779208592, 82.17059162684849, 2.974782420056207, 0.39741701047335354, 1.1010029720408576, 13.28387873513358, 92.30452537536621, 64.53158896309989, 87.8336375100272, 50.03170599256243, 64.8411728995187, 19.64311327253069, 39.90202106748308, 74.8442234311785, 81.47727257864815, 43.18633031845093, 0.18692058777170523, 0.16795249416359834, 0.11848761700093746, 0.11507526439215456, 0.18399519260440553], [0.02549385156349412, 0.06534185021051339, 0.07324714958667755, 0.12029539713902132, 0.020961632885571038, 0.11526289289551121, 0.052746506607426066, 6.3511911290032526, 58.183926650456016, 41.779163769313264, 31.844775336129324, 42.099482672555105, 74.05706201280866, 57.844993523189, 33.40877662386213, 58.60033566611153, 53.93975503104073, 63.394981792994905, 3.4916358973298753, 0.6682656354137829, 0.0992735680192709, 0.041615075165671964, 0.06669946307582514, 7.3490002155303955, 55.679639543805806, 55.26284837722778, 58.74326705932617, 53.885993344443186, 60.635581152779714, 56.33369084766933, 59.53572300502232, 56.49901281084333, 56.62322228295462, 53.06583840506417, 53.30900798525129, 48.886451789310996, 45.46452651705061, 41.7590765271868, 42.14779002325875, 41.417197363717214, 46.29101126534598, 46.15128993988037, 46.39060326984951, 43.76732131413051, 40.338284560612266, 39.896139417375835, 42.75275230407715, 45.94362218039376, 48.96202039718628, 49.657951968056814, 46.33624403817313, 43.15128013065883, 49.232367856161936, 49.3598256111145, 49.203623158591135, 51.15864127022879, 49.34715209688459, 45.19883435113089, 41.1130747113909, 44.21261051722935, 47.932359899793354, 48.236948081425254, 42.59971475601196, 34.68721737180437, 35.161008085523335, 34.75048071997506, 35.2879238809858, 35.1510408946446, 33.44457721710205, 32.48920338494437, 36.12860379900251, 37.9348783493042, 40.630039419446675, 38.99597944532122, 39.51380436761038, 40.53260483060564, 39.732877595084055, 42.18238510404314, 40.20196090425764, 40.97515296936035, 46.73603643689837, 42.40322664805821, 48.30451583862305, 46.51427773066929, 46.70499535969326, 48.758705684116904, 45.5464631489345, 50.70371491568429, 47.056463037218364, 33.97700030463082, 37.94953557423183, 47.47682557787214, 45.73521443775722, 45.93894256864275, 48.901432105473106, 46.986696175166536, 46.87595578602382, 45.20971523012434, 43.43882090704781, 39.77424716949463, 40.30392919267927, 40.079735142844065, 41.941682134355815, 39.987209456307546, 40.135025433131624, 39.52087415967669, 40.17710372379848, 37.692813532693044, 36.277177129473, 35.87879521506173, 32.67842367717198, 32.941638810294016, 34.970491954258506, 34.645965916769846, 34.66662291118077, 35.750079836164204, 40.374241488320486, 42.03578506197248, 43.054734911237446, 38.81232466016497, 40.40651587077549, 44.59916312353951, 50.09819677897862, 47.945693492889404, 49.02900103160313, 46.94209221431187, 53.65696334838867, 47.177101135253906, 45.09171397345406, 44.64966263089861, 41.76718854904175, 39.263804708208355, 40.43788698741368, 40.9572092464992, 45.41085863113403, 49.932041031973704, 53.867726530347554, 49.06996761049543, 54.5446652003697, 49.336820125579834, 51.14722885404314, 43.61210550580706, 42.905755111149375, 41.056175913129536, 43.94591433661324, 42.13785409927368, 44.476826190948486, 41.815405573163716, 46.910318102155415, 44.67496102196829, 48.713198457445415, 48.006174087524414, 52.74582174846104, 53.8834468296596, 63.72378444671631, 62.56182329995291, 64.37364251273019, 0.4579901301435062, 0.3292332791856357, 0.5002563478691238, 19.98445221355983, 75.29559230804443, 56.22279759815761, 68.22486918313163, 42.316058022635325, 41.352044105529785, 33.75156947544643, 32.13709994724819, 47.27899994168963, 66.42525100708008, 41.05424083982195, 0.07925344657685075, 0.06337337262396302, 0.08553989032017333, 0.029813413973897696, 0.060120882865573676, 0.059881665344749174, 0.04873797956055828, 0.026836105788658773, 0.15693824232688972, 0.051554904119776826, 0.10857759948287692, 0.1753716231989009, 8.905275106430054, 69.6988878250122, 50.059589113507954, 41.13882820946829, 31.6461888722011, 71.51992729731968, 61.43169185093471, 41.812907695770264, 63.68288734980992, 59.864553451538086, 67.72849682399205, 3.5199773822511946, 1.1390021273068018, 0.12055155767926148, 0.15124385431408882, 0.10098982735403947, 7.703492096492222, 60.420027187892366, 57.120028904506135, 62.378592354910715, 57.12979459762573, 64.1625006539481, 58.29657432011196, 59.894333430698936, 57.27386202130999, 58.16920689174107, 56.105842045375276, 55.5531336920602, 51.60738720212664, 47.85306358337402, 41.939031396593364, 43.802395820617676, 42.18459810529436, 49.427897112710134, 48.93712500163487, 47.84506620679583, 46.33031375067574, 42.267333780016216, 42.19995709827968, 44.580583640507285, 47.90644659314837, 51.17317342758179, 51.94550044195992, 48.31464283806937, 43.45686885288784, 51.98310061863491, 51.18634373801095, 52.91214425223214, 51.911235400608604, 50.72330188751221, 46.64698484965733, 43.30084705352783, 45.298009463718955, 50.10688897541591, 49.435272625514436, 46.16304629189627, 37.533369745527, 37.808021613529746, 37.41380514417376, 38.03893109730312, 36.478799956185476, 36.10769319534302, 33.95468963895525, 37.16469485419137, 40.23673663820539, 41.0209971836635, 40.80538763318743, 40.7789740562439, 41.7849029813494, 41.77009637015206, 44.23400054659162, 43.038670676095144, 45.48534332002912, 47.9516133580889, 44.5292329788208, 48.94935730525425, 48.46037782941546, 48.72495828356062, 49.42235592433384, 49.00203159877232, 51.8555907521929, 47.13933072771345, 33.81366205215454, 38.52980743135725, 49.55920416968209, 49.57849931716919, 49.76588528496878, 50.40290307998657, 47.91120263508388, 49.02208062580654, 46.90844556263515, 47.93341950007847, 41.1872432572501, 42.00012343270438, 41.7786739213126, 46.07024267741612, 42.40271942956107, 43.7983033316476, 40.99785968235561, 42.58903884887695, 39.630214486803325, 38.392285210745676, 37.3507467678615, 34.66401386260986, 35.53040558951241, 37.22972651890346, 37.854018688201904, 36.61655841554914, 37.82326943533761, 42.42964022500174, 44.825740405491416, 44.642933300563264, 41.16903550284249, 43.327055658612935, 47.58624580928257, 53.11337103162493, 49.641401359013145, 50.8614181791033, 48.119471413748606, 54.75927421024868, 49.9233592578343, 48.41310576030186, 46.34405033929007, 45.43748760223389, 40.00928040913173, 42.875530447278706, 42.49809735161917, 48.3678104536874, 52.86256538118635, 55.27813788822719, 52.3356556892395, 56.87051909310477, 52.865136214665, 53.14212267739432, 46.97163942881993, 45.440794944763184, 43.341042382376536, 46.43999801363264, 44.79824985776629, 47.11219106401716, 44.81874704360962, 47.894273349217, 46.77017641067505, 50.687463079180034, 50.172274998256135, 56.2950553894043, 56.45129953111921, 67.35897077832902, 64.88302884783063, 67.64517402648926, 0.34367483854293823, 0.5881008484533855, 0.40620775733675274, 22.081118038722447, 81.83065101078579, 59.10545580727713, 79.0528723852975, 46.39356320244925, 52.30633429118565, 25.70210746356419, 28.07195908682687, 56.8841792515346, 70.81781182970319, 52.493244307381765, 0.08259808139077254, 0.027716908703691194, 0.07792442717722484, 0.00440799630346841, 0.038172972188996415, 0.16359956988266536, 0.17464918696454593, 0.1165634138243539, 0.28891630257878986, 0.2045557400477784, 0.25439746198909624, 0.38577690507684437, 15.262489455086843, 81.2970779963902, 55.90052972521101, 46.94828305925642, 50.91354703903198, 79.51774856022426, 69.52251475197929, 47.172949586595806, 67.45343153817313, 65.42135443006242, 73.80296639033726, 5.0089759060314725, 1.6365577429533005, 0.4685708252446992, 1.077507421374321, 0.15102069771715573, 9.039482167788915, 61.92205401829311, 58.826166016714915, 65.09456675393241, 58.928811754499165, 67.97698525020054, 60.97063718523298, 63.727466991969514, 61.47989845275879, 62.1049861907959, 58.24909380504063, 58.582673345293315, 53.19389370509556, 51.38980783735003, 45.47033173697335, 46.69807495389666, 44.577272823878694, 52.95431981767927, 51.37882273537772, 49.8385773386274, 47.55830362864903, 43.469719546181814, 44.29520027978079, 47.795303208487375, 50.129321234566824, 53.49773842947823, 53.42042234965733, 48.675681659153526, 45.547189235687256, 54.853040150233674, 52.35092782974243, 54.78720249448504, 53.67284345626831, 53.722429275512695, 48.94638000215803, 45.83300338472639, 47.47620718819754, 52.91255072184971, 54.121533802577424, 48.61972781590053, 39.288981505802695, 39.15941497257778, 38.739820207868306, 42.04172577176775, 39.57905837467739, 37.04405328205654, 35.17204529898507, 39.23129061290196, 44.02760778154646, 45.664196899959016, 43.776215008326936, 42.433228969573975, 44.0248076575143, 45.78876767839704, 46.331449781145366, 45.6653641973223, 46.745155947549, 52.208211830684114, 47.580287728990825, 50.31153079441616, 51.19684246608189, 51.61411305836269, 53.52079255240304, 51.55261107853481, 55.90315614427839, 49.29862935202462, 33.85770320892334, 39.162857804979595, 51.32138197762625, 51.33942992346627, 53.00005633490426, 53.93796934400286, 51.354177474975586, 52.213909353528706, 50.44937263216291, 48.37200716563633, 43.484109265463694, 43.260776792253765, 45.70651142937796, 48.9753748348781, 44.885887486594065, 47.00588362557547, 43.66138560431344, 44.99840314047677, 42.865358284541536, 41.1906270299639, 40.08294868469238, 37.09727300916399, 37.777675356183735, 38.02986022404262, 39.58920969281878, 38.200584411621094, 39.9594965662275, 45.32548611504691, 47.88547345570156, 48.50257771355765, 44.02639879499163, 43.625772612435476, 50.98058325903756, 55.965141023908345, 51.83143533979143, 52.283373968941824, 49.63455043520246, 60.02207606179373, 52.14526115145002, 50.282122543879915, 48.83176251820156, 46.89322205952236, 42.99124574661255, 45.086537565503804, 44.04930353164673, 50.45115484510149, 55.173470224652974, 58.00145305906023, 52.73250205176217, 60.825760296412874, 54.633893966674805, 55.98201125008719, 48.341508047921316, 47.92204529898507, 46.29835203715733, 50.30460344042097, 46.465772356305806, 50.75832775660923, 46.80984367643084, 52.03669554846627, 50.37133393968855, 53.34514556612287, 54.27802807944161, 61.172593525477815, 58.95735495431082, 71.21777098519462, 67.24479103088379, 73.32361016954694, 0.6796576412660735, 1.0395890389169966, 0.6898376207266534, 23.199870075498307, 89.48985876355852, 66.32070841108049, 81.29049110412598, 54.142149107796804, 58.134295667920796, 42.46840075084141, 42.836255754743306, 64.47507926395961, 83.1260940006801, 63.80263260432652, 0.3432737429227148, 0.10322993607925517, 0.17315471358597279, 0.14449051740978444, 0.12908584544701235], [0.0011429515268121446, 0.0584172307114516, 0.037950595907334767, 0.16205370426177979, 0.053309714421629906, 0.17185176350176334, 0.043727178259619644, 8.598658050809588, 59.987904821123394, 43.2297808783395, 29.741062300545828, 53.61468355996268, 80.60261249542236, 58.154438495635986, 35.025146484375, 63.30735806056431, 52.279027870723176, 66.88395023345947, 10.12676407609667, 0.6323645104254995, 0.44935151083128794, 0.153587242854493, 0.08453103766909667, 3.214082722152982, 61.87660585130964, 57.81108283996582, 60.29131875719343, 54.73007787976946, 57.725995200020925, 53.87133959361485, 53.91397721426827, 51.7908022744315, 52.57703263419015, 47.04123606000628, 45.64128521510533, 41.915074007851736, 41.212319305964876, 40.22285066332136, 46.172242232731406, 47.320588384355815, 50.10991491590227, 49.228216307503835, 48.176151343754356, 42.698552880968364, 40.43942601340157, 40.73257051195417, 46.75993824005127, 47.59811333247593, 47.977603094918386, 48.69271516799927, 49.369862283979145, 53.192660399845664, 52.778266361781526, 52.11703756877354, 50.451759338378906, 50.15973697389875, 46.931068897247314, 42.26206357138497, 39.983443532671245, 47.71070889064244, 45.54813419069563, 45.61270032610212, 44.47598893301827, 36.77760028839111, 33.927876540592735, 33.84246233531407, 36.628179277692524, 34.030101912362234, 33.30888932091849, 33.090399742126465, 36.30609553200858, 36.244482381003245, 38.034397397722515, 37.96551295689174, 37.78916072845459, 39.60401630401611, 39.595108713422505, 39.58794164657593, 42.50529221126011, 43.83425331115723, 41.218715122767854, 45.06069721494402, 48.3807931627546, 47.29438672746931, 47.81666891915457, 46.5222681590489, 50.012931959969656, 48.00817516871861, 50.854706219264436, 35.44682223456246, 44.46176249640328, 47.982977526528494, 45.14976617268154, 47.09555012839181, 45.721668924604145, 46.70609317507063, 46.37809303828648, 43.95506511415754, 43.2786614554269, 43.3557517187936, 40.96526568276541, 40.4009816305978, 41.58338437761579, 40.877638476235525, 38.426842076437815, 38.09438814435686, 38.76009157725743, 38.56830045155117, 36.25203854697091, 35.257622786930625, 33.846773692539756, 33.87776265825544, 33.360389368874685, 34.96990483147757, 35.747161592756, 36.835621220724924, 45.30843870980399, 45.759894439152305, 48.04024110521589, 39.898540019989014, 40.65696716308594, 41.78617797579084, 47.1718031338283, 50.220297472817556, 52.16252742494856, 47.587885584150044, 48.33910744530814, 51.945476123264854, 48.80478266307286, 46.11073677880423, 46.632817472730366, 41.35342332295009, 38.19721106120518, 39.3885874067034, 43.12418910435268, 48.97065700803484, 51.02862657819475, 53.42837803704398, 52.52608149392264, 53.529786995479036, 54.10176270348685, 49.42757402147566, 46.65528794697353, 42.391623156411306, 42.537434577941895, 43.42089802878243, 46.234230586460654, 45.44888264792306, 46.4094363621303, 45.22745050702776, 47.47162485122681, 48.797045843941824, 54.7775444984436, 58.54981531415667, 63.793196950639995, 66.32698263440813, 46.5061240196228, 0.3532409066600459, 1.2593036719730921, 0.1835366114974022, 30.299544606889995, 72.43585968017578, 60.555225236075266, 57.99445274897984, 33.69344432013375, 43.147781712668284, 58.87343461172921, 41.21356650761196, 40.59161935533796, 63.393140520368306, 42.42252179554531, 0.10871025307902268, 0.07257869081305605, 0.06793264618941716, 0.07443555617438895, 0.06641635112464428, 0.025395570855055536, 0.022542232714061226, 0.03629132333610739, 0.11871359630354814, 0.014013625980753983, 0.21318675976778778, 0.15993309233869824, 12.917968358312335, 70.41931874411446, 48.773932661329, 34.46600062506539, 54.151848793029785, 81.07213701520647, 65.70069285801479, 38.865645136152, 65.77078628540039, 56.41830253601074, 72.32552228655133, 10.975786175046649, 0.6803962130631719, 0.5012039627347673, 0.3265866940574986, 0.14543661235698632, 3.58210535134588, 63.12576689038958, 59.31272751944405, 63.804988043648855, 56.21259764262608, 60.3261570249285, 55.68788358143398, 56.583221503666465, 53.888442584446494, 56.31041785648891, 49.730352197374614, 47.32402426855904, 42.459024156842915, 42.9549275125776, 42.99860041482108, 48.213782787323, 50.24223640986851, 51.9993211882455, 51.05800008773804, 50.33990376336234, 45.418182032448904, 42.54209681919643, 42.92728410448347, 47.210303102220806, 49.61543941497803, 50.87722185679844, 51.7345427104405, 48.85512236186436, 56.57496704374041, 53.22621325084141, 54.12272889273507, 52.493303367069785, 51.08858953203474, 48.503526142665315, 44.70370919363839, 42.55643442698887, 49.17062963758196, 48.907591683524, 48.13258613858904, 46.17932939529419, 39.54732595171247, 37.0894319670541, 35.32513148444039, 36.99302918570382, 35.50222717012678, 35.74756111417498, 36.193552085331504, 38.78969785145351, 37.794250283922466, 40.27258586883545, 39.63417496000017, 39.82858903067452, 41.41868775231497, 43.22302028111049, 41.82729046685355, 43.66016966956002, 44.51723691395351, 45.23663602556501, 47.57759182793753, 50.49515778677804, 50.04538352148873, 50.03408922467913, 47.80692754473005, 49.96983575820923, 51.40959630693708, 53.04710953576224, 33.66613095147269, 44.589442593710764, 52.078436851501465, 48.12188591275896, 49.1883544921875, 48.36702183314732, 48.61196320397513, 49.54243816648211, 46.168615273066926, 45.55005189350673, 44.94908135277884, 42.52443102427891, 42.34062337875366, 42.64197022574288, 44.933468750544954, 40.495518820626394, 40.67918750217983, 40.9163955279759, 39.369556290762766, 38.47719914572579, 37.91857440131051, 36.15910986491612, 35.24409464427403, 36.74384593963623, 37.13395949772426, 37.06070811407906, 38.13428470066616, 48.60784292221069, 47.016959054129465, 49.787052971976145, 43.0448510987418, 43.60749190194266, 43.74841179166521, 48.757517542157856, 51.70708690370832, 52.34007126944405, 48.608186858040945, 50.06214257649013, 53.95558302743094, 51.371944018772666, 48.17063447407314, 48.196189948490684, 43.803809779030935, 41.78563254220145, 40.93648624420166, 46.28886774608067, 51.374122279030935, 52.91201571055821, 54.86971582685198, 56.34686810629708, 56.803861549922395, 56.779320512499126, 52.440041950770784, 49.18408829825265, 44.44429472514561, 46.87580987385341, 45.246200220925466, 48.48180259977068, 47.614681312016074, 48.78159305027553, 48.19540132795061, 49.91619913918631, 50.29542487008231, 57.671080112457275, 61.54772676740374, 67.28404140472412, 70.62661824907575, 47.773513657706125, 0.3912724687584809, 2.04232439824513, 0.21711664460599422, 33.463281767708914, 76.7285748890468, 65.31829874856132, 64.79670442853654, 34.70714133126395, 50.38188130514962, 45.3590042250497, 35.45697007860456, 51.06737668173653, 69.87473283495221, 51.528080463409424, 0.3533015405493123, 0.06322710082999297, 0.014243425435519643, 0.024830702326393554, 0.09422885014542512, 0.13907377235591412, 0.21221067357276166, 0.10352830149765525, 0.36592088054333416, 0.2502539743270193, 0.45564527596746174, 0.39689608556883677, 20.25248418535505, 80.5301010949271, 57.65992825371878, 41.778635706220356, 61.57597119467599, 86.95562839508057, 68.7834140232631, 48.486558641706196, 73.45742552621024, 61.10101318359375, 77.38790334974016, 12.260072095053536, 0.9786868840456009, 0.6662208022815841, 0.64847282320261, 0.3365495694535119, 4.460540694849832, 69.61448805672782, 60.92148562840053, 66.70736176627022, 57.545168331691194, 65.6790075302124, 58.31564712524414, 58.91676357814244, 56.50516196659633, 59.39549446105957, 51.863046169281006, 50.71025317055838, 45.366980757032124, 45.952349117824006, 44.54029451097761, 51.73790563855852, 52.27573095049177, 55.00995479311262, 52.782435280936106, 53.37166336604527, 47.64751155035836, 45.33500167301723, 44.44235617773873, 49.63268831798008, 52.0385194505964, 53.005458559308735, 52.510816301618306, 50.97699451446533, 57.46351310185024, 55.04523427145821, 56.436930656433105, 55.08327913284302, 52.85992506572178, 51.06538254874093, 47.41533054624285, 44.96703897203718, 52.65543610709054, 51.57070766176496, 51.17724159785679, 49.859366348811555, 42.06665243421282, 39.201086793627056, 37.21243940080915, 39.65238618850708, 38.47045244489397, 37.062066486903596, 37.90518522262573, 40.73541579927717, 39.316353934151785, 42.677062102726524, 42.24665594100952, 41.18846614020211, 43.46106903893607, 46.09620114735195, 43.74632733208792, 46.818459442683626, 46.35821771621704, 47.45766592025757, 51.25364398956299, 52.45813853400094, 53.70865099770682, 53.202745710100444, 52.48948185784476, 56.34315429415022, 53.50792448861258, 55.739828314099995, 33.979484285627095, 47.60628093991961, 55.06020416532244, 52.40133006232125, 53.00342968532017, 50.751838139125276, 52.205168519701274, 52.213301386152, 48.9384833744594, 49.06802906308855, 46.55092600413731, 46.47499261583601, 44.20833737509591, 46.97960206440517, 48.401620388031006, 43.80284397942679, 42.804964542388916, 43.95445367268154, 41.285285813467844, 40.55304295676095, 40.07739707401821, 38.07299811499459, 36.95160749980381, 36.76288052967617, 39.04481833321707, 38.89013753618513, 40.25320039476667, 50.49392100742885, 50.07225220543997, 53.730652468545095, 46.178863865988596, 44.594038827078684, 44.86111715861729, 52.11500174658639, 54.09352561405727, 55.17557552882603, 51.33963142122541, 51.69832175118582, 57.643457548958914, 52.65104137148176, 48.716241768428254, 51.73685646057129, 46.29198748724801, 42.82574660437447, 43.79017046519688, 49.47208070755005, 55.313959326062886, 57.120859214237754, 57.60153906685965, 58.47895063672747, 58.38245405469622, 59.05309418269566, 54.148141929081504, 52.845573561532156, 45.810908113207134, 48.94107157843453, 46.99865402494158, 51.78670283726284, 49.28275966644287, 52.976977893284385, 50.65065847124372, 53.08384466171265, 52.854422092437744, 61.08149569375174, 63.058272089277, 72.68238871438163, 71.47817557198661, 55.452256270817344, 0.5433444072093282, 3.585402922970908, 0.40551814862659996, 36.16640199933733, 85.25428553989956, 71.12206649780273, 72.33982167925153, 44.580635751996724, 58.2203734261649, 75.7595443725586, 51.67134189605713, 56.92321423121861, 78.76787117549351, 65.46596881321499, 0.8033065891691616, 0.2658006229570934, 0.24220549049121992, 0.1487202061606305, 0.19327913943145955], [0.030113652148949246, 0.14856847215976032, 0.023797617493463413, 0.09330271769847188, 0.020085467757391076, 0.06774901425732033, 0.09488336502441339, 9.254826818193708, 61.73568248748779, 44.750098841530935, 34.306129523685996, 40.9473671231951, 99.60872186933244, 49.13176836286272, 36.180013520377024, 62.63971955435616, 54.533134664808, 67.26881790161133, 25.059369564056396, 0.5136339643171856, 0.9229990265199116, 0.05645751640466707, 0.06150530464947224, 1.915122858115605, 62.15108748844692, 56.02477046421596, 58.826235498700825, 50.45257575171334, 53.77754586083548, 47.13902153287615, 47.36723511559622, 43.30586017881121, 46.5105812890189, 42.01736191340855, 42.008395263126914, 41.371888160705566, 43.55402203968593, 44.95879146030971, 49.58581229618618, 49.47906712123326, 50.76910093852452, 49.570116315569194, 43.143581526620046, 40.245133536202566, 40.48197678157261, 44.593559401375906, 46.803736209869385, 49.102162088666645, 52.279337065560476, 47.44278982707432, 51.103806086948936, 50.543777806418284, 47.43437555858067, 50.47027281352452, 51.0923102923802, 49.48320477349417, 43.7793938091823, 42.71786887305123, 42.7544025012425, 46.993290015629356, 43.46774973188128, 44.449050767081125, 46.56462785175869, 41.36010748999459, 35.80078084128243, 34.644214970724924, 35.53311538696289, 34.59292336872646, 33.85485792160034, 34.56922653743199, 37.49575219835554, 35.645624092647004, 36.309840611049104, 38.253904887608115, 40.907668590545654, 40.59240102767944, 40.09332234518868, 41.556810992104666, 42.76074620655605, 40.989851883479524, 40.37014552525112, 45.73836544581822, 49.486929007938926, 46.4999748638698, 45.55803189958845, 48.58197477885655, 45.308626311165945, 46.613108907427105, 48.725194522312705, 36.379704747881206, 47.80336659295218, 47.41387837273734, 45.06594657897949, 46.569974490574424, 47.96074676513672, 47.04582187107631, 47.17068099975586, 45.42306661605835, 45.060846601213726, 45.14917210170201, 39.38347353254046, 40.236618518829346, 38.657668181828086, 41.0343724659511, 39.303218364715576, 37.80605179922921, 37.51242440087454, 34.81152064459664, 33.70142085211617, 35.222937379564556, 32.895916189466206, 33.58974245616368, 35.018392835344585, 33.14400509425572, 34.10928358350481, 36.731346130371094, 45.9811771937779, 44.81316416604178, 47.61624118259975, 45.54197113854544, 39.6525216783796, 42.303613798958914, 45.5592999458313, 49.89016423906599, 49.88706881659371, 51.120064871651785, 45.47715834208897, 46.407827854156494, 50.692695072719026, 49.71924202782767, 46.79947349003383, 47.4903815133231, 42.38650580814907, 39.51485007149832, 38.55522394180298, 41.774852412087576, 49.811062472207205, 52.20374066489083, 52.61344814300537, 53.1151636668614, 56.80659566606794, 53.0219292640686, 52.29167706625802, 47.60220234734671, 48.4558858190264, 47.84046997342791, 46.95904581887381, 47.006050382341655, 48.66182695116316, 48.836501189640586, 49.763178961617605, 53.745135988507954, 56.42674112319946, 62.981487546648296, 60.31288596561977, 74.98888492584229, 18.334340163639613, 0.8606364471571786, 2.3330137942518507, 0.023274377088195512, 42.299576895577566, 62.91383988516671, 62.85018048967634, 50.20700904301235, 29.854380471365793, 41.48563364573887, 87.98641450064522, 54.459775584084646, 33.06696694237845, 64.71876648494175, 60.94291387285505, 0.9671614510672433, 0.12798615731298923, 0.07871264738163777, 0.15259375902158873, 0.04227973075051393, 0.08947719154613358, 0.17138527067644255, 0.00390511449326628, 0.25802271174533026, 0.06674759835004807, 0.12301702824022089, 0.2575689618076597, 15.144899879183088, 70.50928401947021, 49.857146399361746, 35.241339683532715, 59.64009189605713, 106.10252911703927, 52.78356088910784, 45.138246059417725, 67.81986563546317, 60.01859501429966, 71.99393340519497, 27.10955888884408, 0.6000195060457502, 1.0693337342568805, 0.09558665978589229, 0.15919521264731884, 1.9790953568049838, 64.41466467721122, 57.30827644893101, 62.36322293962751, 52.28204686301095, 56.60977751868111, 48.21442549569266, 51.24037987845284, 45.28847653525216, 47.12103612082345, 44.91870035443987, 43.40229770115444, 42.23178332192557, 45.810755252838135, 46.394174643925254, 53.192601340157644, 50.94406352724348, 53.53695058822632, 51.68599564688546, 45.895985330854145, 41.776627676827566, 43.35520281110491, 45.46640600476946, 50.93063265936715, 51.39391074861799, 53.29338843481881, 49.310187680380686, 53.03977223805019, 51.324223790849956, 49.968553815569194, 53.648243359157014, 53.31102296284267, 52.84352036884853, 46.953605379377095, 44.676729338509695, 45.773092542375835, 48.7777715410505, 46.828176498413086, 49.294192927224294, 50.599766390664236, 43.826995917728965, 37.9809935433524, 35.55815322058541, 37.46291501181466, 35.25589963368007, 35.61963782991682, 36.77042974744524, 38.273165294102256, 37.82091052191598, 38.186931201389854, 40.146879059927805, 41.25253895350865, 41.7161088671003, 42.41465990883963, 44.144990648542134, 46.761939321245464, 44.55914497375488, 42.64660814830235, 45.548002174922395, 49.32488659449986, 48.25671918051583, 47.917522021702354, 49.2168664251055, 48.52579859324864, 47.08303642272949, 52.65297644478934, 36.645664419446675, 48.55903877530779, 49.622408458164756, 46.21960115432739, 49.43481751850673, 49.26158503123692, 49.031672613961355, 49.21434422901699, 45.804005077907014, 49.27353940691267, 45.16171360015869, 42.51897668838501, 44.19987446921212, 39.713144711085725, 43.096288612910676, 41.404489108494346, 40.136724267687114, 39.52657168252127, 36.14218405314854, 34.36292062486921, 36.34929595674787, 35.6186511857169, 35.254871300288606, 36.95700625010899, 34.32908289773123, 36.49959244046892, 39.31105940682547, 50.035850593021934, 48.45536470413208, 49.341148853302, 47.370247159685405, 42.30520493643624, 44.1841333253043, 48.37976482936314, 51.58774811880929, 51.85248490742275, 52.02723210198538, 46.50292437417166, 45.144634928022114, 53.64234781265259, 53.645474502018516, 49.706950664520264, 50.393585545676096, 44.92976188659668, 40.383604185921804, 41.43185806274414, 43.64856617791312, 51.176171575273784, 53.74964884349278, 55.29421601976667, 56.79693767002651, 59.10301004137312, 56.39418533870152, 56.06290912628174, 49.43498774937221, 50.53604098728725, 50.60374770845686, 49.286914689200266, 49.715441363198416, 51.11787271499634, 51.35207911900112, 51.97183411461966, 54.98620932442801, 58.06889574868338, 64.04260948726109, 62.52569266727993, 77.44365569523403, 19.55066054207938, 0.8526582324079105, 3.9113533411707198, 0.10759069743965353, 48.124272618974956, 67.26763670785087, 68.42812483651298, 55.8013858795166, 31.722136156899587, 44.00212526321411, 90.86074529375348, 46.99354362487793, 42.77866908482143, 70.93638978685651, 70.35921682630266, 1.8059848972729273, 0.1981893852353096, 0.1565282850393227, 0.11987542467457907, 0.1044097931257316, 0.3135831132531166, 0.245688546448946, 0.1690704891724246, 0.2857901560408728, 0.13723472532417091, 0.30385758940662655, 0.34644472705466406, 22.11863657406398, 82.86079788208008, 55.298642022269114, 45.852267265319824, 51.83315849304199, 101.11752319335938, 60.62579114096505, 51.53484800883702, 74.84156227111816, 63.89205592019217, 78.98727444240025, 29.932783944266184, 0.961919903755188, 2.0977460529123033, 0.2394135088792869, 0.4855743157012122, 2.434424489736557, 69.76153973170689, 58.62849671500069, 65.1801894051688, 53.31683165686471, 59.353186879839214, 51.966014998299734, 53.38710921151297, 46.59490115301949, 49.92999478748867, 47.992197786058696, 45.24757596424648, 43.69831875392369, 48.41130270276751, 48.45045927592686, 56.06273194721767, 53.45669542040144, 56.321396010262625, 54.2074864932469, 47.08911262239729, 44.778919969286235, 46.5102755682809, 48.53177751813616, 52.54850333077567, 53.53291368484497, 56.36951575960432, 51.045521123068674, 55.15308768408639, 54.54180949074881, 50.331190722329275, 55.611241476876394, 56.29347467422485, 54.30829790660313, 50.727759156908306, 47.3491975920541, 47.462071078164236, 49.95170095988682, 48.81000770841326, 51.40870346341814, 54.10880817685808, 46.60668877192906, 39.95539018086025, 38.10233688354492, 40.32365165437971, 39.72673886162894, 38.48847259793963, 39.46500369480678, 41.89232907976423, 39.09263931001936, 39.33662877764021, 42.68143946783883, 44.79356677191598, 45.04198571613857, 44.66958311625889, 46.918086188180105, 49.785791873931885, 47.1101587159293, 45.325090067727224, 49.07640511648995, 52.749702317374094, 50.015075479234966, 49.419003418513704, 53.07045200892857, 51.469486304691856, 50.592571531023296, 53.77249104636056, 37.62665973390852, 51.34752457482474, 52.812010288238525, 50.51503310884748, 51.857890605926514, 53.586710112435476, 52.53571169716971, 52.18037387302944, 47.8131913457598, 51.36611795425415, 49.99485969543457, 44.440431526729036, 46.5853647504534, 40.950149876730784, 45.1382669040135, 46.36057662963867, 42.21160922731672, 42.1210811478751, 39.24442618233817, 36.937495708465576, 39.8666547366551, 38.744972297123496, 36.97658627373831, 39.442845889500205, 36.87426710128784, 37.5502747126988, 41.32739537102835, 54.04787942341396, 51.46323987415859, 52.357747486659456, 50.3896598134722, 43.521935258592876, 47.10680621010916, 49.55843639373779, 55.32778624125889, 53.780919211251394, 54.684452533721924, 48.758698735918315, 47.57287400109427, 55.665559019361226, 55.212880407060894, 52.510607855660574, 52.168992723737446, 47.2235289982387, 43.05427633013044, 44.31405421665737, 45.27757133756365, 55.24426542009626, 57.49932759148734, 56.8174661227635, 60.09603268759591, 62.76225798470633, 56.97350181852068, 59.86658232552664, 50.538778577532085, 52.597588879721506, 52.71659762518746, 51.92399229322161, 52.19010135105678, 55.49108975274222, 53.42718294688633, 55.55933148520333, 57.93073081970215, 62.98221710750035, 67.70256614685059, 66.3697418485369, 80.65593297140938, 24.9834657055991, 0.9125470902238573, 6.341470164912088, 0.40031568493161884, 51.271254198891775, 73.81379168374198, 74.9101757322039, 62.60166427067348, 39.91711255482265, 55.15040915352957, 99.40094988686698, 66.32710770198277, 48.9326434135437, 81.83454895019531, 82.30865928104946, 3.1005157189709798, 0.3872849355850901, 0.27524338769061224, 0.3180767792676176, 0.19884084670671395], [0.0436258390545845, 0.052003907704991956, 0.08877196295985154, 0.02769680880010128, 0.03219322966677802, 0.034206517705959935, 0.05480414369542684, 6.578255219118936, 65.7765393938337, 45.996914863586426, 38.262524127960205, 16.02993188585554, 33.58855431420462, 40.70702198573521, 30.38495533806937, 59.752715247017996, 56.622857502528596, 61.26159300122942, 41.038982595716206, 0.18860650302043983, 0.7972599193453789, 0.16458827682903834, 0.14519077911973, 0.9219020796673638, 55.426412446158274, 60.032574789864675, 56.16458906446184, 53.56493445805141, 46.58472899028233, 44.965670176914756, 43.178815841674805, 42.44141394751412, 41.22860935756138, 42.11730132784162, 45.675928933279856, 45.23396791730608, 49.21162748336792, 49.73862055369786, 51.78781107493809, 52.82879018783569, 51.35807888848441, 46.0579617364066, 42.37670189993722, 39.092232840401785, 42.275744574410574, 47.72233670098441, 50.39765024185181, 53.08256619317191, 49.37398256574358, 50.77859912599836, 50.852305616651265, 50.762677328927175, 50.433596747262136, 49.13266815458025, 50.305371216365266, 40.982924529484336, 42.537278243473594, 42.42523506709507, 44.73435422352382, 47.5943717275347, 45.126524448394775, 43.05632952281407, 45.35061427525112, 43.73025962284633, 36.531804289136616, 35.37917457308088, 32.96106597355434, 35.262622015816824, 34.482314995356965, 36.34099980763027, 34.79140213557652, 36.03624139513288, 35.89734690529959, 39.544925349099294, 39.649440152304514, 38.675719601767405, 39.22032288142613, 41.61153153010777, 43.49997895104544, 42.657092979976106, 40.39578785215105, 45.57464851651873, 45.138374601091655, 45.299895899636404, 47.15955693381173, 45.87900740759713, 45.781385217394146, 45.99920082092285, 48.321670940944124, 39.666015080043245, 47.603706632341655, 47.040909494672505, 45.81276328223092, 47.804707595280235, 45.721873896462576, 45.0720922606332, 47.15508924211775, 45.310203552246094, 42.099996839250835, 44.82035902568272, 38.94082464490618, 40.72718913214547, 39.90080860682896, 39.467320919036865, 38.440224306924, 38.59555128642491, 37.178758008139475, 36.420351709638325, 34.56038148062569, 33.944882256644114, 33.82036011559622, 32.983793531145366, 32.72440685544695, 34.227142402103965, 34.55840471812657, 40.14424916676113, 45.04666880198887, 46.33146020344326, 46.7510723386492, 47.166869912828716, 39.95383725847517, 40.09022344861712, 43.12459209987095, 48.33679716927664, 49.99344226292202, 50.25106062207903, 53.69410841805594, 45.18933616365705, 37.5823198046003, 50.94025591441563, 48.58375351769583, 47.506334577287944, 45.305058411189485, 42.181513105119976, 38.68611758095877, 41.586761202131, 45.789170673915315, 49.7749422618321, 51.31237711225237, 53.10062108721052, 54.64402444022042, 56.23865338734218, 52.02072163990566, 51.23965379170009, 50.27072402409145, 48.91678067616054, 49.81894520350865, 52.65044730050223, 51.26921142850603, 52.76071868624006, 52.968841552734375, 55.90141214643206, 61.47814055851528, 61.85540689740862, 67.01534066881452, 55.49267046792166, 0.954525283404759, 0.07739008763538939, 0.5964473720107759, 0.5886251117501939, 52.340710503714426, 60.59735911233084, 61.867038181849885, 54.3144713810512, 44.057891505105154, 49.11826801300049, 56.6094057900565, 40.279252665383474, 42.77279090881348, 66.80392088208879, 56.90995706830706, 0.604689998286111, 0.043837128074041436, 0.06134780988629375, 0.052673950857881985, 0.03725439862215093, 0.014219004960198487, 0.04234231882063406, 0.08848498335906438, 0.08086013607680798, 0.05396016826853156, 0.1557535608964307, 0.18820958717593125, 10.437712465013776, 73.46750736236572, 52.30535112108503, 38.516796929495676, 34.33719144548689, 59.163299560546875, 41.519398416791645, 39.75389589582171, 63.03827517373221, 61.84310163770403, 65.98116384233747, 43.9918349811009, 0.2762589917651245, 1.3621235489845276, 0.12987133115530014, 0.11666794892932687, 1.209058750952993, 58.80359131949288, 62.077749252319336, 58.499614579336985, 54.9889886038644, 49.53864097595215, 46.92776502881731, 47.0707311630249, 44.28664704731533, 43.85816901070731, 44.4753531728472, 47.99375070844378, 48.111074515751426, 52.08941847937447, 52.75913102286202, 55.228875160217285, 53.98512329374041, 51.26649120875767, 50.2265682220459, 44.81117698124477, 40.831297465733115, 44.56263991764614, 50.8987716947283, 51.88974462236677, 52.87046895708357, 50.879539081028526, 52.37407227924892, 52.53868900026594, 53.692854268210276, 53.41837957927159, 49.02383852005005, 51.10092258453369, 43.69017546517508, 45.208203996930806, 43.72860942568098, 46.57758971623012, 50.443310328892295, 47.73374216897147, 46.06504889896938, 47.46106011526925, 45.56267329624721, 37.615302903311594, 37.58056538445609, 34.41796425410679, 36.47688225337437, 35.432283129010884, 37.21191133771624, 36.193993295942036, 37.56046077183315, 37.72197164808001, 40.648792607443674, 41.09234128679548, 40.6726770401001, 42.01749045508248, 43.00793531962803, 44.83848687580654, 44.52040876661028, 43.737583024161204, 47.023167269570486, 46.42109891346523, 48.98904888970511, 48.94072764260428, 46.614206722804475, 46.168948786599294, 49.10252686909267, 50.65296527317592, 40.01599931716919, 50.5361521584647, 49.3521409034729, 48.39349446977888, 50.21494388580322, 48.199441705431255, 49.99565873827253, 49.31900494439261, 46.14412982123238, 45.08824682235718, 45.640218666621614, 42.788653646196636, 43.206830978393555, 42.10211603982108, 41.75543567112514, 41.40284585952759, 39.525185516902376, 39.09612730571202, 38.02753257751465, 36.7797646522522, 33.8282185282026, 37.09975699016026, 35.01121187210083, 34.64852632795061, 35.63541024071829, 36.848193986075266, 40.74337843486241, 46.762814794267925, 49.99401548930577, 48.96934379850115, 49.83162914003645, 41.92396422794887, 41.947907720293315, 44.89702544893537, 51.5596148627145, 53.735418932778494, 51.84390040806362, 53.901348863329204, 44.7589612688337, 37.70459072930472, 52.679428236825125, 51.70439795085362, 50.09783894675118, 48.95866789136614, 44.38226120812552, 41.88666977201189, 44.14306947163173, 48.03597838538033, 51.308677196502686, 54.88028751100813, 56.97185509545462, 56.2384067262922, 57.934045110430034, 54.59612703323364, 54.84308685575213, 53.75373785836356, 52.79361145836966, 51.86206299918038, 55.779248918805806, 54.376174858638215, 54.84634556089129, 55.99049847466605, 57.53360652923584, 64.51841517857143, 63.48018755231585, 67.91909980773926, 56.753028529030935, 0.8146972379514149, 0.08409140804516417, 1.4064573986189706, 0.7759300353271621, 55.240409169878276, 65.40015547616142, 68.79443386622837, 60.339421136038645, 43.8494872365679, 51.69598020826067, 65.41919354030064, 53.003801413944785, 44.94912651606968, 73.25722013201032, 68.81964193071637, 1.7466727942228317, 0.2340851090848446, 0.06560003957045929, 0.042956576216965914, 0.01450243073382548, 0.14892551728657313, 0.15141306737703936, 0.12793849701327936, 0.263254813849926, 0.1195004933646747, 0.2456744872033596, 0.41424666025808876, 14.149708526475088, 87.818573815482, 59.437155859810964, 48.432602405548096, 22.77959438732692, 45.42451878956386, 54.18708310808454, 43.571062496730256, 70.70334720611572, 67.52633898598808, 71.33226340157645, 50.277029514312744, 0.72232842871121, 2.2490148501736775, 0.4899268735732351, 0.4564825881804739, 1.5621383019856043, 61.288899421691895, 64.00912611825126, 62.74866730826241, 57.96964073181152, 51.54026065553938, 48.69181885038103, 48.45069204057966, 46.37433058874947, 45.37443617412022, 46.97269902910505, 49.976339272090364, 48.982760769980295, 55.291516644614084, 55.10907779421125, 55.93182441166469, 56.48998015267508, 54.48328481401716, 51.43925469262259, 47.36977120808193, 43.19332020623343, 45.94907999038696, 52.89298459461757, 54.556209632328574, 53.59349502835955, 52.13074289049421, 55.02938890457153, 54.66607454844883, 54.30120032174246, 55.1223384312221, 53.00970043454851, 53.901727540152415, 46.590138162885395, 47.175985949380056, 45.7233121735709, 48.08505698612758, 53.35088130405971, 50.75695201328823, 49.59832600184849, 50.47549785886492, 48.86399521146502, 42.22085727964129, 39.751175676073345, 35.82021842684065, 37.524559429713655, 39.09130525588989, 41.13868577139718, 39.39461496898106, 39.03671325956072, 40.43440593991961, 45.004284790584016, 45.13946199417114, 41.271858419690815, 45.91614900316511, 46.918093136378694, 47.41184255055019, 46.28433404650007, 46.62666136877877, 49.796064785548616, 49.498945917402, 51.01726279939924, 52.667321000780376, 48.64831270490374, 49.09088168825422, 52.94959156853812, 52.03416640417916, 39.76552718026297, 53.72518423625401, 51.9546651159014, 50.889871052333284, 52.78133051736014, 51.73115198952811, 50.5762745312282, 52.66352728434971, 49.049519062042236, 46.52812896456037, 48.982673917497905, 44.74164635794503, 46.64597388676235, 44.16520643234253, 43.39814267839704, 42.847376346588135, 40.63769980839321, 41.07785081863403, 43.65777948924473, 38.84475885118757, 35.896141392844065, 38.94996847425188, 37.428260871342246, 36.09727784565517, 38.76061269215175, 38.419261591775076, 43.479419231414795, 49.964944226401194, 53.0944823537554, 51.70893512453352, 53.046970571790425, 43.22229766845703, 44.47361612319946, 48.03736455099923, 52.81680454526629, 56.22591039112636, 53.55253539766584, 56.27971029281616, 47.05033820016043, 39.959930828639436, 55.76753773008074, 54.525231088910786, 53.18441636221749, 50.22562326703753, 46.10650185176304, 44.3078008379255, 45.72772775377546, 51.47835220609392, 55.63850620814732, 57.358616147722515, 56.74295016697475, 58.507229804992676, 62.454035895211355, 57.45609589985439, 57.73104306629726, 56.04300948551723, 54.91763407843453, 55.90098135811942, 58.41775090353829, 55.64804955891201, 59.02239009312221, 58.244646957942415, 61.749189785548616, 66.76599066598075, 67.81350108555385, 69.98409748077393, 65.44142777579171, 2.1211386833872115, 0.2665448673069477, 2.544555825846536, 0.9305383648191179, 62.69905717032296, 70.53340121677944, 75.63728387015206, 67.71887356894356, 54.072399616241455, 63.08213220323835, 69.42889472416469, 52.35397808892386, 57.37713657106672, 80.52270126342773, 81.2074670791626, 2.943570677723203, 0.4697571758713041, 0.1850088017859629, 0.23780111968517303, 0.10794421418436936], [0.0792124562763742, 0.04261897111843739, 0.009345099795609713, 0.014949953416362405, 0.01452992666911866, 0.0866212851500937, 0.14272448074604782, 5.433205553463527, 61.54548249925886, 49.12464645930699, 46.94531965255737, 30.45166846684047, 29.485121931348527, 36.94752195903233, 37.57344695499965, 53.8088162285941, 61.81185558864048, 52.4580968448094, 59.61360536302839, 1.669124601142747, 0.3562549320714814, 0.16174487583339214, 0.05221324593627027, 0.030685019346752336, 42.463748931884766, 66.00054931640625, 53.02407625743321, 53.46596779142107, 48.645814827510286, 46.9579028402056, 43.08294112341744, 46.40657717841012, 46.19013384410313, 46.085323742457796, 49.27498810631888, 49.176045758383616, 52.32335042953491, 54.32258687700544, 51.69819320951189, 52.78932441983904, 48.03981726510184, 45.497193472726, 41.18182018824986, 41.13155344554356, 47.698084013802664, 46.45014238357544, 58.46239307948521, 66.7153730392456, 48.01880243846348, 52.50417382376534, 48.676890645708355, 51.616131510053364, 48.19020754950387, 45.97264133180891, 41.026382037571494, 42.85838924135481, 45.48556566238403, 41.67396804264614, 43.687906878335134, 46.685192993709016, 44.79809699739729, 45.57602078574044, 45.02330548422677, 45.4986560685294, 39.712064266204834, 37.299264090401785, 33.80244071143014, 35.39501646586827, 34.1285057749067, 35.6058908190046, 35.255427156175884, 35.3363493510655, 35.18884604317801, 38.09971393857683, 38.77746902193342, 38.602916376931326, 39.03191900253296, 42.32027905327933, 39.1785364151001, 43.34855685915266, 41.887288161686485, 41.779003960745676, 43.95452662876674, 46.262391635349815, 45.23129286084856, 47.01718487058367, 46.297764914376394, 47.30258560180664, 47.82100459507534, 41.275940486363, 49.57023443494524, 47.90802730832781, 43.311981541769846, 47.31970248903547, 46.191450527736116, 45.05676800864083, 45.486604418073384, 45.10322713851929, 41.291382857731406, 44.48368058885847, 42.363521167210166, 39.31599610192435, 37.17547498430525, 38.595144816807334, 38.238657065800254, 39.11260148457119, 36.02811895098005, 36.188295773097444, 34.48380190985543, 34.01327337537493, 32.98081970214844, 35.34417649677822, 32.62613500867571, 35.689821583884104, 32.73045178822109, 41.20303303854806, 44.66342006410871, 45.274625301361084, 43.9823055267334, 49.09324407577515, 42.27578626360212, 41.257458278111045, 40.51693664278303, 42.52314908163888, 48.223176751817974, 48.29794979095459, 51.595651694706504, 49.168034485408235, 18.964666843414307, 36.70029463086809, 52.37775829860142, 49.90777097429548, 52.271009649549214, 47.44660438810076, 43.613929407937185, 39.286702496664866, 41.55954163415091, 46.19927767344883, 51.10893733160836, 52.73170648302351, 54.161871569497244, 53.32064969199044, 55.72678654534476, 50.098175934382844, 54.089464391980854, 54.925878116062705, 55.5376808983939, 49.46667153494698, 54.19332953861782, 53.59931067058018, 57.00453247342791, 56.88618728092739, 60.927739007132395, 58.137269496917725, 70.10058403015137, 15.63317584991455, 0.521897163774286, 0.20116826253277914, 0.2287492182637964, 2.4184177943638394, 58.79241861615862, 53.32535014833723, 62.47031552450997, 63.383149010794504, 53.930833544049946, 39.42230006626674, 45.316627161843435, 22.801288400377544, 43.82438686915806, 63.70070253099714, 65.56030450548444, 1.546783868755613, 0.19764050468802452, 0.033448560163378716, 0.021239599844973003, 0.04508162236639431, 0.037490742547171454, 0.09660083893686533, 0.028129904131804193, 0.06372547123048987, 0.07652741856873035, 0.08221886173955031, 0.03857741977221199, 8.223788840430123, 74.00017711094448, 53.74930838176182, 48.31599426269531, 17.072033132825577, 26.02470711299351, 45.70508010046822, 39.931488377707346, 58.08679778235299, 67.62886660439628, 58.65051555633545, 64.86436598641532, 2.1263478781495775, 0.8985563495329448, 0.12238117307424545, 0.07712718245706388, 0.08602720738521644, 46.28133937290737, 67.36015892028809, 55.49460554122925, 55.58693667820522, 52.203959533146445, 48.94837760925293, 45.82353299004691, 48.32226848602295, 48.35646404538836, 48.737294810158865, 49.76683371407645, 51.2847614969526, 52.981445584978374, 54.537689208984375, 54.23792655127389, 55.35003089904785, 48.67811005456107, 49.1031938961574, 41.352488790239605, 43.56356191635132, 49.907937731061665, 49.98983267375401, 56.07565212249756, 62.79869433811733, 51.801749161311555, 53.86229651314871, 50.662261962890625, 53.32027448926653, 48.74749476569039, 47.880727836063926, 42.74104111535208, 43.823170934404644, 46.591996806008474, 44.23815209524972, 45.436535699026926, 49.80039698737008, 47.0389848436628, 47.72655078342983, 49.42168542316982, 48.25374187741961, 40.86752537318638, 37.77013308661324, 35.39865037373134, 37.60509947368077, 35.36421857561384, 37.02395214353289, 37.39699397768293, 37.303200244903564, 37.491142068590435, 40.40786729540144, 40.89820514406477, 40.84952259063721, 41.0695720400129, 43.177245548793245, 42.44739982060024, 43.890227999006, 44.31424529211861, 44.80527448654175, 46.19291659763881, 48.305929797036306, 47.37230730056763, 50.3496208190918, 48.14954669134957, 49.64841903959002, 50.32635825020926, 43.450726645333425, 50.17632579803467, 51.17310741969517, 47.26253618512835, 49.742410796029226, 48.379539012908936, 47.245659010750906, 46.73351771490914, 48.401165281023296, 42.854706696101594, 47.29617936270577, 43.76881865092686, 40.570576735905235, 40.85043280465262, 41.5404167175293, 39.93398625510079, 41.97824355534145, 37.83751671654837, 38.14730909892491, 35.74237775802612, 35.624511991228374, 33.90052148274013, 37.635824407849995, 33.525169372558594, 38.62659583772932, 34.66250262941633, 43.64825003487723, 47.07022394452776, 47.90826007298061, 46.818383012499126, 50.90825251170567, 44.45610318865095, 44.526415484292166, 41.900864941733225, 44.85825450079781, 51.561643736703054, 51.08781133379255, 52.08736876079014, 52.113688537052695, 19.999066012246267, 36.7957489831107, 53.37049606868199, 53.27740410396031, 53.367268630436485, 50.09376382827759, 45.75189011437552, 41.092042514256065, 43.97496822902134, 50.07054989678519, 53.59331437519619, 54.91311774935041, 55.84066752025059, 56.764416626521516, 58.993568965366904, 56.25792421613421, 56.15620606286185, 59.14456721714565, 58.50916140420096, 52.89893225261143, 56.30845499038696, 56.6684307370867, 59.393173762730186, 60.309974670410156, 63.56514317648751, 61.11051137106759, 71.37309101649693, 16.138764994485037, 0.5294220628482955, 0.6199592618005616, 0.5175218071256364, 2.5741634028298512, 64.76085867200578, 59.24278000422886, 68.25759519849504, 67.76763602665493, 62.88544259752546, 44.46446187155587, 57.937630380902974, 34.38238252912249, 47.155832699366975, 70.22069753919328, 75.99586650303432, 2.122076038803373, 0.33156754821538925, 0.07328819416995559, 0.06393853801169566, 0.08743359334766865, 0.2509099005588463, 0.14078167213925294, 0.09281513600477151, 0.22649283148348331, 0.09741134901664086, 0.16587232292762824, 0.32855002156325747, 10.954824328422546, 87.1435215813773, 59.986508233206614, 60.15611376081194, 39.52798216683524, 44.18465791429792, 51.87421539851597, 50.7899420601981, 62.54189586639404, 74.17299965449742, 63.91630513327462, 70.68243312835693, 2.286828032561711, 1.9907405376434326, 0.6346006904329572, 0.2544157824345997, 0.2946473721946989, 49.08579213278634, 70.93210969652448, 57.722805976867676, 57.892088413238525, 53.341612407139365, 51.411850997379844, 48.78410134996687, 51.577416147504536, 52.0945531981332, 50.81994785581316, 53.54864093235561, 54.15250539779663, 55.13992084775652, 57.94712856837681, 56.32903208051409, 57.790978227342876, 52.100646768297466, 49.37121370860508, 44.79354245322091, 46.97178186689104, 51.017933300563264, 54.54609305518014, 57.21292979376656, 62.329968861171174, 53.34023666381836, 55.293566363198416, 52.93156794139317, 54.661078793661936, 53.372844559805735, 50.373783179691856, 45.676748820713584, 46.25876814978463, 50.208103384290425, 47.28634071350098, 48.21397386278425, 51.976760387420654, 51.3450961794172, 50.110012190682546, 52.77195044926235, 51.53052622931344, 43.780321393694194, 40.467409883226665, 36.79310866764614, 40.17397356033325, 37.3897921698434, 40.41300548825945, 40.05868904931204, 39.3132689339774, 39.734805720193044, 42.5593387739999, 43.494680949619834, 43.49985040937151, 44.29292821884155, 47.05803680419922, 44.51805680138724, 46.545864241463796, 47.86634506498064, 45.54749148232596, 47.96499558857509, 50.76806913103376, 50.15879896708897, 53.125440052577424, 50.797588552747456, 51.23735393796648, 52.46691410882132, 43.01714168276106, 51.58776548930577, 54.433678150177, 50.45670992987496, 52.10463850838797, 50.44341107777187, 47.36923967088972, 50.07509749276297, 51.92921386446272, 46.69205086571829, 50.96311548777989, 47.981633050101145, 44.82901300702776, 42.39798075812203, 43.70570468902588, 41.3148330279759, 44.1640738759722, 41.015021732875276, 39.92821230207171, 39.50952775137765, 38.23812205450875, 36.23886128834316, 40.03107690811157, 35.25357893535069, 39.97769737243652, 36.75387913840157, 46.10714456013271, 51.15824522290911, 50.82317181995937, 50.654191630227224, 55.93723358426775, 49.41235399246216, 46.0983863558088, 45.614322730473106, 47.69540548324585, 53.56006377083914, 51.95175034659249, 55.48113645826067, 53.50705943788801, 19.817389726638794, 40.82599251610892, 54.359547819410054, 55.48631286621094, 56.492658683231895, 52.62560749053955, 47.31782994951521, 43.855827467782156, 45.33280604226248, 53.44515446254185, 55.617467062813894, 57.82450328554426, 57.20435919080462, 59.388886724199565, 61.792553492954795, 57.561041491372244, 59.75001239776611, 62.51209504263741, 60.81178052084786, 56.25179590497698, 59.515052114214214, 58.4047577721732, 60.934332847595215, 63.35825361524309, 65.62472820281982, 65.76576273781913, 74.27299118041992, 20.41374840055193, 0.5251176538211959, 1.2095082125493457, 1.4762262148516518, 2.9841735618455068, 70.9799758366176, 63.29088388170515, 74.0674078805106, 76.82514790126255, 65.63663741520473, 54.88456760134016, 63.83196095057896, 32.13669000353132, 60.0015093939645, 78.13423715318952, 87.99239689963204, 3.7322444149426053, 0.9110965452023915, 0.22061293199658394, 0.2802570829434054, 0.28419513734323637], [0.15601581468113832, 0.062084095020379336, 0.1651528722473553, 0.0822960315272212, 0.07846154871263675, 0.040312969857560735, 0.09902772799666439, 4.59492232969829, 64.16747556413922, 48.76214851651873, 42.081504208701, 69.94800158909389, 36.9121903691973, 27.724260807037354, 54.412878717694966, 52.61717932564871, 66.47301292419434, 45.30378341674805, 69.00083010537284, 6.948436566761561, 0.20638551829116686, 0.8390385689479964, 0.0689999885591013, 0.0586135241069964, 22.629923241479055, 74.70785113743374, 50.51306676864624, 60.74105480739048, 46.347767625536235, 51.22246047428676, 44.80349922180176, 47.77678625924246, 45.98151765550886, 50.104394572121755, 47.54676267078945, 52.99571718488421, 53.85823876517159, 52.20970221928188, 52.97896160398211, 51.965466090611045, 45.6137147630964, 42.52739443097796, 40.70763342721121, 43.3878767149789, 47.0212321962629, 48.41903952189854, 61.85747051239014, 48.31000491550991, 49.399711745125906, 51.62990631375994, 48.473812171391074, 52.82873807634626, 45.417351722717285, 45.53294890267508, 42.764189038957866, 45.64717033931187, 43.95860522133963, 39.612781456538606, 41.90853227887835, 48.940296854291645, 44.55187715802874, 46.29543726784842, 45.41088989802769, 45.34103965759277, 40.89325107846941, 39.28874179295131, 33.97164324351719, 35.17727034432547, 32.37944269180298, 36.621738297598704, 34.55418368748256, 34.500279562813894, 34.67499896458217, 36.66230188097273, 40.00191879272461, 38.00330768312727, 38.438108580453054, 41.709799902779714, 40.973388126918245, 41.60931158065796, 42.189454896109446, 44.06017051424299, 46.90928976876395, 44.22788265773228, 45.04297930853707, 45.83646706172398, 44.636648654937744, 47.340765953063965, 49.90225410461426, 45.809330872126985, 48.95248052052089, 47.73662914548601, 45.15104464122227, 46.090597425188335, 45.85218388693673, 47.01177569798061, 44.417818614414756, 41.61207696369716, 40.30356093815395, 41.53761659349714, 40.949395997183665, 40.15307337897164, 39.26206071036202, 36.33891534805298, 36.119352272578645, 40.01698248726981, 34.96334573200771, 33.41342149462019, 32.9968318258013, 34.07149233136858, 35.065446036202566, 33.675330366407124, 34.22677067347935, 35.21945980616978, 38.18861266544887, 42.254014083317344, 46.33132471357073, 42.99579334259033, 43.681587491716655, 46.4656959261213, 44.696674142565044, 40.018455505371094, 43.33398996080671, 40.458689893995015, 45.108420916966026, 50.81743260792324, 49.39486885070801, 52.98926230839321, 30.002939905439103, 21.19747393471854, 36.21524436133248, 45.19376911435808, 49.525578362601145, 48.348563943590435, 49.36539111818586, 42.32974597385952, 41.55907957894461, 41.27056605475289, 48.90330811909267, 50.057504653930664, 55.357972690037315, 49.683431012289866, 55.72385440553938, 53.71026297977993, 53.1508252961295, 53.28488731384277, 56.92352342605591, 62.060503823416575, 63.559890338352744, 58.10927867889404, 56.13539620808193, 59.21517481122698, 61.49519143785749, 62.26145962306431, 50.39733062471662, 1.6910434535571506, 0.42480493656226564, 0.43404652923345566, 0.2698741400880473, 3.7276138748441423, 62.734694480895996, 48.09032024656023, 63.19629110608782, 68.49522359030587, 45.962750571114675, 38.50088555472237, 35.431966985974995, 30.390708446502686, 50.40561982563564, 57.02294519969395, 63.82645797729492, 1.236225881746837, 0.1574079378374985, 0.1383068242243358, 0.029613775400710956, 0.03401086213333266, 0.0380467680682029, 0.02702830931437867, 0.15657515823841095, 0.07144510985485145, 0.06602339792464461, 0.14484406129590102, 0.10306979502950396, 6.016581084047045, 74.35803018297467, 55.29877751214163, 40.346104758126394, 54.16154500416347, 49.81857347488403, 34.088508469717844, 58.44225719996861, 56.85283940179007, 72.97699928283691, 49.52828468595232, 77.69297790527344, 7.415377225194659, 0.245192645915917, 1.0626841996397292, 0.054179765949291844, 0.10753902021263327, 24.203959465026855, 75.98365156991142, 51.413629736219136, 63.7354713167463, 49.015584060123985, 54.108106408800396, 46.85452059337071, 51.378958225250244, 48.71218054635184, 51.28334753853934, 49.33312368392944, 55.926894664764404, 55.91087906701224, 55.29640122822353, 54.372120584760395, 54.06081002099173, 48.979397841862266, 45.12122992106846, 41.57996933800833, 48.24188825062343, 49.501325675419395, 51.194678102220806, 58.75674656459263, 52.01513876233782, 50.908523491450715, 54.12192637579781, 51.47835220609392, 54.316990103040425, 47.49010705947876, 47.823901993887766, 44.38852153505598, 47.30857147489275, 46.75566857201712, 40.16270358221871, 45.946509156908306, 51.00588165010725, 46.02303661618914, 48.63841152191162, 48.51639768055507, 47.165556703295024, 41.14151021412441, 41.427616187504356, 33.90493706294468, 37.75176899773734, 34.9209235055106, 38.20815099988665, 35.59604869570051, 35.76573412758963, 36.96041781561715, 38.38125841958182, 40.69743347167969, 39.100678375789094, 39.95280197688511, 42.00861760548183, 42.66259595326015, 44.974973814828054, 43.650838238852366, 46.1070681299482, 48.294770990099224, 47.17498888288225, 46.276944637298584, 47.654171398707796, 47.02451522009713, 48.63622631345476, 51.07805258887154, 45.53614159992763, 51.15484060559954, 49.017678941999165, 47.48248488562447, 47.770244530269075, 47.459566252572195, 48.25341878618513, 47.272850785936626, 43.584799085344585, 42.84906823294503, 43.778848375592915, 42.80819892883301, 43.3495226587568, 41.56785862786429, 39.00714520045689, 39.72752400806972, 41.52021483012608, 37.8451041494097, 34.419114180973594, 36.63267823628017, 36.75756515775408, 36.30050570624215, 35.2788530077253, 34.08295685904366, 36.42387792042324, 40.39215394428798, 45.210510798863, 47.79047768456595, 47.099673884255544, 45.52669204984392, 50.23320722579956, 47.14964532852173, 42.13942091805594, 45.389791693006245, 42.91771643502371, 47.11881964547293, 52.38652345112392, 53.42153058733259, 54.87166479655674, 37.739335196358816, 26.17006516456604, 35.53449807848249, 45.54756096431187, 51.088276863098145, 50.33869825090681, 49.15686525617327, 44.209285804203574, 41.97240359442574, 45.019668102264404, 52.00509514127459, 53.89821522576468, 57.11033616747175, 53.176436356135774, 58.01816347667149, 58.167737347739084, 57.908691133771626, 55.41630629130772, 58.63344383239746, 64.59500517163957, 65.84488187517438, 62.64251273018973, 60.244244711739675, 61.64844785417829, 63.26111779894148, 64.57478591373989, 51.78310367039272, 1.9425350214753832, 0.5910265828881944, 1.0270843441997255, 0.49418090816055027, 4.147397977965219, 70.12349918910435, 53.268861293792725, 69.60961736951555, 73.61844308035714, 52.72297954559326, 41.291570459093364, 50.50849832807268, 33.452296665736604, 53.102761132376536, 64.55720697130475, 74.29570484161377, 2.234736953462873, 0.4308182496045317, 0.06386287457176618, 0.06589445591505085, 0.03490692190825939, 0.19151626474090985, 0.18953183479607105, 0.30531660254512516, 0.13189278197075638, 0.25694481815610615, 0.22296458509351524, 0.21628846547433309, 8.260992101260594, 87.42030307224819, 60.99565764835903, 58.309449332101, 82.17553179604667, 50.73149381365095, 39.316809041159495, 67.1326471056257, 62.835408619471956, 78.32383959633964, 53.495125906808035, 83.35478700910295, 9.019791841506958, 0.48381571578127996, 1.6129904304231917, 0.19326081898595604, 0.21589027398398944, 25.337624073028564, 79.89938531603131, 54.012148312159944, 66.42040116446358, 51.676132678985596, 56.734605380467, 50.19870941979544, 53.289956024714876, 51.10731145313808, 54.75961814607893, 51.101912702832905, 58.615163121904644, 59.093463216509136, 56.59120150974819, 57.25370877129691, 56.75689172744751, 50.5294679914202, 45.95322111674717, 46.333704471588135, 49.32380962371826, 51.74598639351981, 52.15927914210728, 60.87380708966936, 59.755028997148784, 53.37776388440813, 56.26880162102835, 53.38333286557879, 57.01833159582955, 50.66154629843575, 49.398666041237966, 47.68313149043492, 49.79249341147286, 49.017439229147776, 44.015882696424214, 46.75994518824986, 54.36138561793736, 49.8722483089992, 52.12016078404018, 52.941066128867014, 53.29355519158499, 45.21424545560564, 43.42435475758144, 34.69323451178414, 40.144957883017405, 36.030488286699565, 41.59383446829659, 38.36555201666695, 37.614701884133474, 39.966576780591694, 41.882299355098176, 44.550716808864046, 43.07643066133772, 41.41664150782994, 44.813313552311485, 45.2682329586574, 46.3055990082877, 45.915843282427105, 48.91298695972988, 51.41929599217006, 48.98532812935965, 49.44423580169678, 52.1970009122576, 50.34864807128906, 53.06469890049526, 51.897234780447825, 46.09568003245762, 51.97857734135219, 52.60741710662842, 51.1236640385219, 50.19742052895682, 50.107910360608784, 51.2621624810355, 49.23113455091204, 46.24313817705427, 46.21295520237514, 47.15018728801182, 45.705135686056956, 44.810141699654714, 43.19098561150687, 41.35003955023629, 40.80964687892369, 45.09517070225307, 38.296566826956614, 37.7853114264352, 37.36502879006522, 39.037748541150776, 40.089500835963655, 38.20893962042672, 36.36184440340315, 38.143498011997764, 42.90562309537615, 47.430154527936665, 51.87694951466152, 51.124508244650706, 49.802856649671284, 53.45915855680193, 49.64167928695679, 43.73318134035383, 47.27583156313215, 45.15790946143014, 48.93719795772007, 57.31998416355678, 55.00961780548096, 58.545681135995046, 29.190848350524902, 24.140418188912527, 39.280629771096365, 47.08724703107561, 54.16085365840367, 51.948575019836426, 54.184331621442524, 45.9274537222726, 45.27775199072701, 45.80628061294556, 56.66968836103167, 56.99891138076782, 59.384307861328125, 52.930150508880615, 60.42288984571184, 60.388016836983816, 58.84544726780483, 60.12859194619315, 62.41731466565813, 64.70188931056431, 67.70501886095319, 66.21802793230329, 63.09442356654576, 64.3790204184396, 66.89925711495536, 67.17627484457833, 57.79085315976824, 3.7469168390546526, 0.6309728079608509, 2.327161891119821, 1.134506642818451, 5.036183748926435, 76.38107463291713, 57.9090941292899, 74.18793133326939, 80.84063693455288, 57.58080564226423, 52.671326637268066, 51.210843086242676, 40.893949372427805, 68.87851401737758, 69.14720085689, 86.38436140332902, 3.658378984246935, 0.6015843163643564, 0.3204638111804213, 0.10619137502674546, 0.21383003810686724], [0.06324465453092541, 0.0016782181171168173, 0.07850999611296824, 0.07932252144174916, 0.022044773246826868, 0.04885003961888807, 0.07391173392534256, 3.6689237441335405, 65.15034689222063, 49.67410652978079, 45.56058188847133, 32.38648121697562, 18.026324783052715, 38.437552724565776, 48.26459843771798, 46.490963050297324, 65.9755219050816, 45.80511678968157, 65.1854213987078, 26.85895299911499, 0.1429930449064289, 0.7920698864119393, 0.04563244352383273, 0.23757432614053997, 6.190687741552081, 67.09537696838379, 51.0949193409511, 57.56266042164394, 52.42325510297503, 49.71543788909912, 45.37804576328823, 51.501371588025776, 46.09282432283674, 52.90792669568743, 48.90639659336635, 52.99862848009382, 49.22406128474644, 53.74584470476423, 52.46050092152187, 51.883651052202495, 44.90450865881783, 41.62094633919852, 41.35607753481184, 50.19893871034895, 46.87959664208548, 54.905787399836946, 37.963515349796836, 37.59671994618007, 56.4143385887146, 47.251293999808176, 49.62333951677595, 44.402150426592144, 45.08002362932478, 43.749047551836284, 44.524793079921174, 46.34145866121565, 44.99475186211722, 40.82271991457258, 46.144654410226, 46.348719528743196, 45.80730894633702, 42.95427090781075, 43.771712575639995, 44.83010734830584, 43.32647895812988, 40.61628198623657, 38.18047285079956, 34.198098931993755, 35.78977836881365, 35.22460494722639, 36.10804060527256, 34.3171945299421, 35.84111166000366, 36.50257321766445, 37.60589156832014, 37.28531905582973, 39.292240210941856, 39.30568844931466, 40.4809901373727, 40.495296478271484, 42.248441628047395, 43.49548346655709, 45.86712598800659, 45.556173256465364, 43.22114426749093, 46.5891306740897, 48.098873479025706, 48.320086751665386, 52.57923173904419, 46.922029290880474, 49.79428257261004, 45.88986049379621, 47.97538314546858, 47.15090990066528, 44.557466983795166, 43.30945239748274, 45.13197183609009, 43.3758076940264, 41.33378423963274, 41.23649556296212, 42.18105104991368, 44.18247965403965, 40.59872736249651, 36.53580297742571, 37.649286542619976, 37.40664849962507, 36.58514213562012, 33.251055989946636, 34.35651091166905, 33.64058242525373, 32.65368809018816, 34.39416667393276, 35.808020864214214, 38.18734809330532, 40.442653451647075, 43.352079595838276, 41.99914026260376, 41.43367501667568, 43.09709460394723, 45.13417441504342, 43.35264587402344, 38.69064433234078, 45.250459466661724, 42.96998078482491, 44.523653575352256, 49.00302519117083, 51.86732973371233, 50.39532606942313, 51.81164339610508, 49.37610871451241, 42.85079138619559, 45.86139372416905, 47.80945668901716, 48.866642475128174, 45.226192883082796, 43.850741386413574, 39.91226271220616, 41.90079198564802, 46.39130503790719, 48.6843113218035, 51.54883473260062, 53.777893270765034, 50.57793515069144, 55.13834013257708, 55.761152335575645, 60.698643003191265, 60.77804701668875, 57.44638926642281, 52.40446717398507, 57.11408472061157, 55.56987190246582, 59.62756429399763, 56.26428529194423, 64.83784471239362, 36.503598076956614, 0.24635261510099682, 0.19331808734152997, 0.7439589851668903, 0.3153123733188425, 5.721495866775513, 69.58965519496373, 50.61287416730608, 58.80705847058977, 66.56907176971436, 54.02145542417254, 44.88214240755354, 27.931843451091222, 35.08209044592721, 60.616966928754536, 55.6395206451416, 57.13926499230521, 0.7143883747713906, 0.0788012436990227, 0.07565946371427604, 0.053092725708016326, 0.025054327112489512, 0.07644608257604496, 0.0502723779396287, 0.13239949835198267, 0.03162466821127704, 0.04604695038869977, 0.119864215276071, 0.08637834247201681, 5.873105125767844, 75.38372325897217, 57.40615572248186, 50.07927336011614, 50.84107385362898, 24.357083865574428, 41.19683524540493, 57.18737084524972, 49.84904132570539, 72.45603724888393, 49.963064738682334, 72.50525828770229, 26.654373713902064, 0.14883699560804026, 1.0551722198724747, 0.019865985427583967, 0.30998929323894636, 6.842144327504294, 69.58163697378976, 54.734326703207834, 61.59031922476632, 52.40910162244524, 51.79586403710501, 47.41683483123779, 52.986496925354004, 49.535945074898855, 56.46477208818708, 51.19854130063738, 53.25679922103882, 51.09671892438616, 55.512267862047466, 53.9991169657026, 53.8559250150408, 45.23645884650094, 42.49593646185738, 42.5402763911656, 52.0995454788208, 52.21313810348511, 54.87128264563424, 40.70503480093819, 40.74454920632498, 58.166973045894075, 50.86032383782523, 52.784971373421804, 47.718014921460835, 46.86347334725516, 45.21351589475359, 47.19957160949707, 48.14911242893764, 46.458320413317, 43.42311103003365, 48.38720635005406, 50.30175467899868, 48.19201060703823, 45.0290481703622, 45.14331824438912, 46.35546622957502, 45.62038155964443, 42.5037636075701, 39.74731247765677, 35.45667130606515, 37.04394211087908, 37.67606142589024, 37.75628185272217, 34.33901187351772, 37.10282809393746, 40.03207050051008, 40.144853660038535, 39.70357009342739, 39.70795093263899, 40.77728564398629, 42.458798340388704, 42.0796559878758, 43.526396002088276, 46.81886938640049, 47.095310415540425, 47.69758721760341, 46.725468226841514, 48.83492047446114, 48.55578701836722, 49.08367640631539, 53.2334428514753, 47.43963187081473, 51.570356777736116, 48.62911483219692, 49.803575788225444, 47.39550733566284, 47.26504101072039, 44.97070762089321, 47.63217340196882, 46.23469264166695, 43.81700440815517, 42.64271715709141, 44.52659961155483, 44.58482551574707, 42.368058340890066, 37.81928811754499, 40.510259423937114, 40.02977064677647, 37.22426870891026, 34.52273614065987, 36.0231614112854, 36.25558907645089, 35.04385103498186, 35.775683947971885, 37.585557665143696, 39.393402508326936, 40.82172979627337, 45.37102460861206, 46.31594140189034, 45.49329900741577, 46.672380515507285, 47.574096884046284, 46.73122133527483, 41.69336741311209, 48.02304778780256, 45.595156124659944, 46.70898709978376, 50.32811614445278, 53.181720461164204, 52.25854458127703, 56.60862759181431, 56.082131317683626, 46.34016629627773, 46.3368797983442, 49.390494959695, 52.62239047459194, 49.208948952811106, 45.30968243735177, 43.19625234603882, 43.77843495777675, 48.80299002783639, 51.06036247525896, 53.37000274658203, 54.7545668057033, 50.194571767534526, 56.316594805036274, 57.434490476335796, 62.517604964120046, 62.74023914337158, 60.377573694501606, 56.65426336015974, 59.988933154514854, 58.23388419832502, 63.1929212297712, 60.183093615940635, 68.16065393175397, 41.15878690992083, 0.2342246701674802, 0.37534187787345474, 1.524466472012656, 0.4139080712837832, 5.884960489613669, 77.50600188119071, 54.395476954323904, 66.2042635508946, 70.35248402186802, 57.72230223246983, 52.461070673806326, 36.597489084516255, 35.28813927514212, 62.589053290230886, 60.867095129830496, 68.2674616404942, 1.2535641342401505, 0.10483811157090323, 0.11412607532526765, 0.08945043012499809, 0.018033191096037626, 0.1524856412517173, 0.19420519045421056, 0.2590427670095648, 0.260514536606414, 0.16938040325684206, 0.27615829716835705, 0.20831015573016234, 6.657422993864332, 89.07185513632638, 61.76381574358259, 62.170632771083284, 38.99435009275164, 22.70671820640564, 53.85590417044503, 61.7508920942034, 57.635362897600444, 77.38064248221261, 55.87410920006888, 75.93857165745327, 32.0764456476484, 0.2855659137879099, 1.5945005140134265, 0.22851107961365155, 0.41360886448196, 7.595321672303336, 71.38005311148507, 56.78207547324044, 64.38767092568534, 56.749641282217844, 54.03076253618513, 50.14751161847796, 56.531221185411724, 50.13560240609305, 59.043067932128906, 54.5026216506958, 54.7265898840768, 52.19667434692383, 55.60886171885899, 57.360092639923096, 58.08270876748221, 47.15316459110805, 45.071446078164236, 44.96432570048741, 55.2340863091605, 53.71241692134312, 54.79405689239502, 46.29898084912981, 43.7148346219744, 58.41495772770473, 52.80147681917463, 53.15556744166783, 50.858788285936626, 48.45777225494385, 48.44279888698033, 49.92703832898821, 51.82063436508179, 49.30243001665388, 45.62151411601475, 49.514853818076, 53.98346962247576, 51.59260490962437, 49.513134138924734, 50.84016363961356, 50.20575141906738, 48.18745606286185, 46.50871569769723, 42.70265926633562, 37.704132148197715, 38.54187297821045, 41.19893707547869, 40.70901959283011, 38.14665944235665, 37.58740241186959, 41.2435097694397, 42.524208681924, 41.29911272866385, 44.58031266076224, 43.51956592287336, 43.63384641919817, 45.587165696280344, 46.64380257470267, 48.90641048976353, 50.61469806943621, 51.56820978437151, 48.03114938735962, 52.6992757661002, 52.085100173950195, 52.44514887673514, 55.05863734654018, 49.16634259905134, 52.75170687266758, 51.821815558842246, 55.032338414873394, 51.0757805279323, 49.20429365975516, 47.38830205372402, 50.61214460645403, 49.710973671504426, 45.681338105882915, 46.43759741101946, 47.41896792820522, 48.665391377040315, 45.15635653904506, 40.53118739809309, 42.67180231639317, 41.86110734939575, 39.80363457543509, 37.519740853990825, 38.478258746010916, 39.059750011989046, 34.930112498147146, 38.318783691951204, 41.5860663822719, 43.0941972051348, 45.96385880878994, 48.247255734034944, 50.10522835595267, 48.51316329411098, 49.419795513153076, 50.313622202192036, 47.96540205819266, 42.980462142399375, 50.56713765008109, 48.39149686268398, 48.297970635550364, 53.37024245943342, 56.55954899106707, 54.43853841509138, 56.47860942568098, 45.55539158412388, 42.50964525767735, 47.39877993719918, 51.03047479901995, 55.04920169285366, 52.65729822431292, 48.35079778943743, 44.845105034964426, 46.31470809664045, 50.435542242867605, 53.76961101804461, 56.12439373561314, 58.589927264622276, 51.299929414476665, 60.23455892290388, 59.13838332039969, 63.0232184273856, 58.825637953622, 62.83999443054199, 61.65891184125628, 65.69182000841413, 60.40049580165318, 65.45340647016252, 63.28155245099749, 73.09891932351249, 44.84629317692348, 0.8217574219618524, 0.3870010908160891, 2.5759347592081343, 0.5398756276283945, 6.967141117368426, 83.75633035387311, 61.92170660836356, 71.43221323830741, 79.2345747266497, 68.0263591493879, 61.62397629874093, 43.80740199770246, 43.85052599225725, 77.37754358564104, 68.00964178357805, 81.43213708060128, 2.265126419918878, 0.29890308954886025, 0.15246132255664893, 0.1461955809167453, 0.16078995993094786], [0.051291931087949445, 0.04500168076317225, 0.10063816979527473, 0.034254893860114474, 0.07916685872312103, 0.04252013570762106, 0.014568138368693846, 1.784123801759311, 59.00977216448103, 52.999229499271934, 36.61295577457973, 48.4488959312439, 34.496343408312114, 36.16691616603306, 40.77806731632778, 41.38905021122524, 64.19859654562813, 49.14756856645857, 58.7367843900408, 45.186327593667166, 0.39780496965561596, 0.2371421264750617, 0.36311728241188185, 0.08588333081986223, 0.6819742141025407, 46.50494629996163, 58.82831301007952, 53.58009542737688, 54.545964513506206, 47.01120594569615, 50.10646513530186, 49.95761040278843, 49.31796618870327, 50.11495930807931, 51.77268484660557, 47.460354873112266, 50.93612173625401, 52.22438028880528, 52.69779927389962, 49.21888835089547, 45.11727292197091, 42.44171619415283, 46.32224341801235, 48.94457694462368, 53.41442952837263, 45.5234819820949, 30.920008318764822, 53.44379956381661, 51.99834844044277, 49.367048263549805, 46.61274412700108, 45.826809065682546, 43.03235476357596, 44.18072523389544, 41.68410546439034, 44.72048909323556, 44.31151465007237, 39.97090898241316, 45.52035181862967, 43.84530789511544, 44.494943618774414, 44.42203964505877, 44.787459305354524, 46.24245377949306, 43.667249883924214, 39.629314695085796, 40.837988580976216, 36.142788546425955, 33.241582121167866, 36.96615355355399, 36.74247019631522, 34.89260264805385, 34.481078216007774, 35.266380991254536, 37.89059400558472, 38.98314612252371, 37.75937727519444, 38.41390800476074, 39.79974358422415, 42.467299461364746, 43.14297008514404, 45.38769333703177, 46.2235928944179, 44.1949725151062, 45.169759614127024, 46.593292645045686, 49.21237094061715, 49.50167308534895, 49.33824450629098, 49.453469957624165, 49.3579044342041, 46.07803160803658, 47.444433076041086, 47.15762880870274, 47.67675999232701, 44.46817568370274, 43.652825423649375, 44.811496598379954, 44.159731251852854, 41.735344954899375, 40.72557715007237, 40.125013078962056, 39.42931079864502, 37.963147095271516, 38.85865524836949, 37.45711326599121, 37.37851524353027, 34.39737326758248, 36.27036442075457, 34.18598822184971, 35.14185190200806, 34.175433908190044, 38.89659241267613, 37.23619876589094, 38.40913806642805, 44.94993250710623, 41.56613894871303, 45.52285317012242, 43.98431355612618, 42.71726090567452, 44.09964670453753, 39.62503807885306, 43.80610268456595, 45.390750544411794, 42.00763096128191, 47.94732631955828, 50.488862718854634, 51.45503405162266, 48.88772678375244, 55.86584084374564, 59.624764169965474, 55.20823553630284, 51.78037997654506, 51.235908712659565, 49.09339346204485, 49.486279351370676, 45.096751417432515, 41.63750737054007, 43.45940841947283, 49.403519357953755, 49.70410190309797, 51.62764467511858, 54.00727762494768, 52.48396151406424, 54.82161692210606, 55.71326535088675, 44.97496339253017, 51.27718448638916, 55.086885247911724, 60.145476068769185, 55.544517925807405, 59.26414571489607, 53.72900921957833, 65.1250832421439, 24.80240954671587, 0.051532027311623096, 0.03657849292669978, 0.6589713884251458, 0.2950184222842966, 10.365660514150347, 71.88149070739746, 51.52972023827689, 63.5144282749721, 63.81124142238072, 37.73644127164568, 39.9876298223223, 34.28280094691685, 30.61536455154419, 49.11242805208479, 51.912128244127544, 50.877937521253315, 0.5773247895496232, 0.09505185884024415, 0.028354824919785773, 0.032283712311514785, 0.07004320222352232, 0.03968694666400552, 0.06451979825007063, 0.04442655108869076, 0.01812160081629242, 0.062171239272824357, 0.05606009844424469, 0.05669656089906182, 3.088172027042934, 70.42310551234654, 56.252178055899485, 45.613131114414756, 42.267052377973286, 28.059556552342006, 48.82464756284441, 54.42657361711775, 47.03405509676252, 68.58295849391392, 55.046780245644705, 64.13958549499512, 49.34663445608956, 0.32219513399260385, 0.3871360650019986, 0.32052151379840715, 0.13781818401600632, 0.9325034022331238, 49.169003759111675, 60.46363408224923, 56.148708956582205, 56.82654741832188, 49.780028343200684, 52.40849018096924, 52.240955216544016, 53.47360038757324, 53.06749555042812, 55.99428871699742, 50.22490760258266, 51.866450786590576, 56.63076802662441, 52.61944791248867, 50.74965293066842, 47.64319671903338, 44.62581293923514, 48.50039597920009, 50.55224071230207, 55.04429279054914, 46.49473244803292, 31.94023663657052, 53.49067905970982, 53.54190117972237, 51.07225431714739, 47.284787791115896, 48.3237658228193, 46.38049711499895, 44.50572722298758, 43.825255393981934, 45.817401204790386, 46.663789067949565, 44.187121050698416, 48.25252941676548, 48.54614986692156, 48.32201140267508, 46.70593684060233, 46.85661200114659, 47.77302728380476, 48.21034690311977, 42.92700965063912, 43.808680466243196, 37.23074790409633, 34.71404089246477, 38.399539130074636, 37.94683619907924, 36.134572301592144, 35.7890488079616, 37.30650411333357, 39.580340317317415, 39.9070029258728, 38.20226240158081, 39.83061443056379, 41.1173860686166, 44.696528230394634, 43.79881749834333, 46.80824906485421, 47.90161412102835, 44.54333782196045, 47.8252603667123, 50.696877888270784, 50.95218249729702, 51.67887374332973, 50.92241988863264, 49.17217561176845, 50.66856050491333, 48.146249771118164, 50.12275518689837, 48.09669869286673, 49.37895400183541, 45.56069653374808, 45.180254868098665, 46.35565035683768, 44.22803899220058, 42.82577092306954, 42.812451226370676, 41.73552213396345, 41.97398083550589, 41.71622003827776, 39.53759152548653, 40.17460584640503, 38.63085160936628, 36.021219389779226, 36.34763533728463, 35.25054604666573, 36.19001545224871, 35.768954617636545, 41.38722283499581, 40.41599668775286, 41.06924894877842, 49.669142041887554, 45.62654461179461, 46.78464950834002, 46.68752758843558, 47.47635310036795, 46.98268706457955, 42.586193561553955, 45.68156392233712, 48.025889601026265, 44.71764728001186, 50.63966294697353, 52.71798726490566, 54.63233757019043, 51.181771823338096, 56.096889291490825, 58.93869209289551, 56.81372104372297, 51.75946242468697, 53.1218443598066, 52.84481273378645, 51.62718956811087, 48.891527448381694, 44.950123582567485, 46.14713144302368, 51.7444612639291, 52.12307555334908, 54.49207081113543, 54.94615990774972, 54.00618328366961, 55.699858801705496, 58.68869590759277, 49.03068944386074, 54.61852107729231, 57.894968441554475, 61.64102717808315, 57.14098467145647, 63.041846547807964, 58.813860757010325, 69.05078070504325, 28.57071988923209, 0.08948743063956499, 0.3464665487408638, 1.3914218225649424, 0.1982953724052225, 10.825817125184194, 79.96157169342041, 56.417301995413645, 68.55485303061349, 71.45410701206752, 42.414114475250244, 47.93638290677752, 35.30747958592006, 23.243334531784058, 55.357020786830354, 57.998812743595664, 61.741053444998606, 0.7966096113835062, 0.08252444677054882, 0.06446473513330732, 0.05923581535794905, 0.09198269567319325, 0.12089087947138719, 0.18791751856250422, 0.13295544923416205, 0.09483953844755888, 0.15453956675316605, 0.1847548804112843, 0.14474143965968064, 4.093281498977116, 83.2014958517892, 63.02633122035435, 48.79770939690726, 59.033083370753694, 50.15238925388881, 50.611171858651296, 55.78125, 53.2612738609314, 74.45460319519043, 58.386678559439524, 69.4327370779855, 53.720087732587544, 0.5752917900681496, 0.6297463423439434, 1.0466011826481139, 0.2361016065946647, 1.2970955755029405, 53.6973671231951, 63.296470233372276, 59.22334589276995, 58.940568106515066, 51.03732919692993, 56.326009614127024, 53.10730178015572, 54.00437675203596, 54.93058899470738, 57.336732796260286, 52.352345262254985, 54.67603131702968, 57.38585308619908, 55.64521469388689, 53.13150930404663, 49.53596939359392, 47.27421610695975, 49.969599519457134, 53.444480487278526, 57.44118159157889, 47.63277094704764, 35.960026604788645, 55.30352660587856, 57.659080573490684, 52.946673325129915, 48.92768587384905, 49.374097211020334, 47.663391658238, 46.97868142809187, 45.40010976791382, 48.67371184485299, 49.21416704995291, 46.47866473879133, 52.47141654150826, 50.22881596429007, 51.26663364682879, 50.82972744532994, 49.031123706272666, 52.014089584350586, 51.86035374232701, 45.923382077898296, 45.480437891823904, 39.19010516575405, 37.839295455387656, 39.492820807865684, 40.4005126271929, 38.64718682425362, 37.95565346309117, 39.44129296711513, 42.25764799118042, 42.12816136223929, 41.99012497493199, 43.75354651042393, 43.95848362786429, 47.857110909053254, 46.77776384353638, 49.149128437042236, 50.85269471577236, 48.672808579036165, 49.94204296384539, 51.70157698222569, 53.977994441986084, 53.80377878461565, 52.35788297653198, 52.40822614942278, 53.172819818769185, 52.450908933367046, 53.72060537338257, 51.238059180123464, 55.05606303896223, 47.60361630575997, 47.52674491064889, 48.13232210704258, 46.827575479234966, 44.915789059230256, 45.262320041656494, 44.80206094469343, 44.43368482589722, 43.433310985565186, 43.02311365944998, 40.898733207157676, 42.59894003186907, 38.1656037058149, 40.12549250466483, 37.79962124143328, 39.81340026855469, 37.888252462659565, 42.66613606044224, 43.90476710455758, 42.75511816569737, 54.0735947063991, 49.96104976109096, 51.01817996161324, 51.33495528357369, 50.68313782555716, 49.30995144162859, 44.220392499651226, 48.40893336704799, 49.6814855166844, 46.40419742039272, 53.681962966918945, 53.737941128867014, 56.20766789572579, 53.09689685276577, 59.464545658656526, 59.141141755240305, 56.89204461233956, 53.69008888517107, 55.6402918951852, 55.13192694527762, 55.83422654015677, 50.512135710035054, 47.24304996218, 48.316973958696636, 54.58482926232474, 55.31771830150059, 57.47569676807949, 56.60351371765137, 53.79137972423008, 54.67303664343697, 58.70589964730399, 52.49527318137032, 59.74768475123814, 60.669960839407786, 63.65367712293352, 62.36470290592739, 65.80048983437675, 60.708127294267925, 72.7834085736956, 31.349500792367117, 0.13674991205334663, 0.5875851618392127, 2.3286917975970676, 0.4212837740778923, 11.672968421663557, 87.26949937002999, 61.54369681222098, 75.77832535334996, 77.55974619729179, 50.21946368898664, 53.82803841999599, 50.615149702344624, 40.35731567655291, 65.91440555027553, 65.07536888122559, 75.52582781655448, 1.3291241654327937, 0.30460834769265993, 0.15310979847397121, 0.17187210598162242, 0.2288042881659099], [0.06061131440635238, 0.07864988967776299, 0.014478631118046386, 0.03903020279748099, 0.08743348478206567, 0.0873491700206484, 0.0843840805547578, 3.410858963217054, 61.7328337260655, 52.39069584437779, 43.39570038659232, 41.71633815765381, 19.665146010262625, 31.511699540274485, 22.038172960281372, 43.298432554517476, 62.05816922869001, 47.94477980477469, 53.79963418415615, 59.19082137516567, 3.2261814900806973, 0.6756577044725418, 0.23728141614368983, 0.04288205610854285, 0.09670927561819553, 23.93447879382542, 67.24176161629813, 49.594289098467144, 59.570484842572895, 49.94330406188965, 53.83089412961687, 50.02814851488386, 53.6215865952628, 49.414038930620464, 52.627205576215474, 47.63362904957363, 53.817897524152485, 51.23704821722848, 50.47008868626186, 43.91083288192749, 46.09438419342041, 45.063820430210654, 49.396564211164204, 47.903059346335276, 53.078251361846924, 38.31366981778826, 42.33371686935425, 53.480590275355745, 51.68812526975359, 49.33914082390921, 46.95502281188965, 45.602045263562886, 45.99188436780657, 45.4457003729684, 44.824934414454866, 44.52267040525164, 43.1360114642552, 41.27789293016706, 46.646064213344026, 43.02855062484741, 44.443193435668945, 45.3254895891462, 46.00133739198957, 44.193287576947895, 42.61147458212716, 38.39840657370431, 40.44536672319685, 41.792858668736045, 33.98088782174246, 35.95374543326241, 36.87717144829886, 34.95092930112566, 35.7370137487139, 36.4125280380249, 36.85130330494472, 37.996255261557444, 38.00817142214094, 38.46287543433053, 39.29426213673183, 40.084261894226074, 42.67772218159267, 42.79623760495867, 44.90531117575509, 39.50354882649013, 42.30296066829136, 47.086906569344656, 47.97860016141619, 51.6358574458531, 51.31455537251064, 49.09791326522827, 51.33724471500942, 47.85725334712437, 44.49783059528896, 44.318459374564036, 47.04545361655099, 43.33332988194057, 42.95627546310425, 40.88512863431658, 43.744572911943706, 42.42125374930245, 40.99885327475411, 41.07965040206909, 39.70789187295096, 39.421959604535786, 38.939553124564036, 35.9981826373509, 35.77469730377197, 32.8368113381522, 35.05313730239868, 32.78169475282942, 33.214216641017366, 32.98540551321847, 39.404620374952046, 38.39591564450945, 40.637036255427766, 43.855764933994834, 40.933884143829346, 42.29723882675171, 43.09700427736555, 44.27885464259556, 45.00262764522007, 38.57266392026629, 43.8354240826198, 45.209729126521516, 41.69164078576224, 43.15516069957188, 46.75803443363735, 49.992632797786165, 50.63984707423619, 51.09834827695574, 49.86411196844918, 54.577992234911235, 52.056261675698416, 51.23440095356533, 49.362736906324116, 50.46945292609078, 49.96211978367397, 46.3319604737418, 44.31168835503714, 43.86092744554792, 50.19437026977539, 50.64896658488682, 50.82505825587681, 56.396547726222444, 48.4862459727696, 45.58905908039638, 48.516081537519185, 55.51433842522757, 53.07421793256487, 55.60284110477993, 53.92051894324166, 62.40414782932827, 52.85353619711739, 59.66545976911272, 16.427174295697892, 0.1620471631842, 0.12847775593400002, 0.5739607757755688, 0.24067338556051254, 15.352746554783412, 73.70365578787667, 51.175278731754844, 68.31595311846051, 47.321505546569824, 34.039415972573416, 32.26143101283482, 46.50879907608032, 44.6691940171378, 49.19378103528704, 56.81225149972098, 49.72642299107143, 0.3966514601239136, 0.008512536479559327, 0.06404077288295541, 0.05299262822206531, 0.09769832861742803, 0.06197122750537736, 0.03151721879839897, 0.1109228947066835, 0.12421036777751786, 0.0876822696466531, 0.09691589631672416, 0.10376901179552078, 4.237523061888559, 72.61624881199428, 57.8202405657087, 46.326870918273926, 40.97768906184605, 22.889808450426372, 37.92186784744263, 34.04664557320731, 50.33295209067208, 64.74389811924526, 53.66413388933454, 57.84528534752982, 63.72124835423061, 3.460615013326917, 0.9981607305152076, 0.320034705634628, 0.09916566738060542, 0.03202384357739772, 26.32127012525286, 68.79298169272286, 51.68138551712036, 62.10362434387207, 52.32229430334908, 55.80420684814453, 51.482872009277344, 56.60326705660139, 51.3334127834865, 57.88946894236973, 49.20671510696411, 56.98033537183489, 52.00423009055001, 54.43639489582607, 46.58399942943028, 47.688498973846436, 46.968877519880024, 51.0989215033395, 50.690551553453716, 54.02369621821812, 38.33118275233677, 44.16702686037336, 54.77822194780622, 54.49223061970302, 50.577341079711914, 50.16148097174508, 47.699112347194124, 45.96760041373116, 46.63876860482352, 47.18730456488473, 47.378195898873464, 45.89808368682861, 42.635682106018066, 46.37347943442208, 46.600494452885215, 46.75358411243984, 48.4272140775408, 49.53948865618025, 46.88773993083409, 45.90243673324585, 42.531507764543804, 41.97192069462368, 42.383518082754954, 37.713918685913086, 38.305665493011475, 36.93881934029715, 36.66462952750069, 39.28281845365252, 37.82721601213728, 39.488363538469585, 41.88455751964024, 40.771254607609336, 39.39019938877651, 42.01280389513288, 43.71375070299421, 43.05816732134138, 43.640554904937744, 47.10881076540266, 39.89215462548392, 43.731100354875835, 49.29104886736189, 48.240647997174946, 50.779425961630686, 52.66155399594988, 49.770321709769114, 51.80345841816494, 48.92555972508022, 46.22197049004691, 47.72524452209473, 47.583331039973665, 44.56046165738787, 46.16877508163452, 44.04421745027815, 46.690355505262104, 43.8260474886213, 44.29227161407471, 41.498866489955354, 42.7438725062779, 40.87152753557478, 41.317296164376394, 38.9042250088283, 37.5395119530814, 36.001573358263286, 36.17407628468105, 34.8203135899135, 36.49933188302176, 36.11650351115635, 42.2578911781311, 40.71916743687221, 44.23528596333095, 45.80228887285505, 44.853901454380576, 45.36321483339582, 45.789118562425884, 46.622138091496055, 47.951731477464946, 42.1666648047311, 45.53498819896153, 46.00093787057059, 44.30174200875418, 45.124697072165354, 49.268595763615195, 50.0518661907741, 54.0220217023577, 51.543790340423584, 50.80480078288487, 55.11988919121878, 54.22046225411551, 53.13401412963867, 52.209191526685444, 52.482370376586914, 52.6840626852853, 49.94078533990042, 45.42242043358939, 47.272645814078196, 52.56955984660557, 53.401794229234966, 53.91995961325509, 59.58933530535017, 51.71376064845494, 48.32497828347342, 50.61054304667881, 57.85506841114589, 58.019650391169954, 61.0793764931815, 57.20650618416922, 64.40964807782854, 56.74855736323765, 65.83826719011579, 18.43089059420994, 0.1135979647349034, 0.6459554582834244, 1.5054116887705666, 0.2856430225074291, 16.30057464327131, 77.4368395124163, 56.46378891808646, 72.75594929286412, 53.35641207013811, 35.04813807351248, 34.76750380652291, 50.66072293690273, 33.38265834535871, 55.03982162475586, 63.19809763772147, 58.32177543640137, 0.569119998386928, 0.007932459436623114, 0.08275867705898625, 0.010084835280265127, 0.09830557674701725, 0.11358571039246661, 0.12301248205559594, 0.15089804572718485, 0.24557498682822498, 0.17684525198170117, 0.2450553918523448, 0.2243269341332572, 5.248376522745405, 84.23243481772286, 65.60152121952602, 55.76889610290527, 55.63684906278338, 31.156045573098318, 43.99485397338867, 33.79759781701224, 54.15208503178188, 72.3265506199428, 59.182497433253694, 62.18994876316616, 71.40643542153495, 3.9658280866486684, 1.4547597553048814, 0.7524952813982964, 0.16546381770500115, 0.1984214170702866, 29.583977426801408, 73.04936477116176, 53.980131013052805, 65.71381105695451, 54.460442611149375, 59.36344242095947, 53.546268122536794, 59.60840811048235, 53.088440895080566, 60.11780139378139, 50.52717855998448, 58.32524258749825, 54.81761128561837, 56.87629304613386, 48.25671223231724, 49.405662877219065, 48.865058285849436, 54.28796400342669, 51.61690970829555, 56.1728504725865, 39.840425286974224, 44.0689252444676, 56.92508329663958, 55.1168771471296, 53.79744897569929, 53.30728483200073, 49.53119250706264, 49.22780636378697, 48.6954562323434, 50.490387848445344, 47.90851020812988, 47.67698233468192, 45.42454310825893, 50.68754298346383, 49.69634076527187, 50.34940195083618, 50.93165751865932, 52.90299694878714, 50.962041991097585, 48.782708236149375, 45.4333256312779, 46.84362581798008, 44.65702772140503, 40.093075684138704, 42.0241641998291, 39.992542198726106, 39.10800872530256, 42.02912521362305, 40.633520466940745, 40.89192744663784, 42.064283098493306, 42.3526611328125, 43.585184710366384, 44.13884496688843, 45.37623575755528, 46.075780391693115, 47.93026154381888, 50.23101159504482, 43.62372636795044, 47.24340779440743, 50.572366169520784, 49.63331365585327, 54.46575103487287, 54.81030525479998, 51.044673442840576, 54.56218160901751, 51.65155342647007, 49.204185962677, 49.78069537026541, 50.97547285897391, 48.05764634268624, 49.74629136494228, 44.573194231305806, 49.73230116707938, 46.48219442367554, 46.85756737845284, 44.965197699410574, 45.121198654174805, 44.873571804591585, 43.88166087014334, 39.952444144657676, 40.87310825075422, 38.369971070970806, 38.6012418610709, 36.28144679750715, 37.67846550260271, 37.367582253047395, 44.75022043500628, 43.19988277980259, 49.06474951335362, 52.524466037750244, 48.80961513519287, 49.02443259102957, 51.424003396715435, 51.44850621904646, 51.2680093901498, 43.324516092027935, 47.916083744594026, 48.352493149893625, 46.26950659070696, 47.93512180873326, 51.75356340408325, 53.277160917009624, 55.95450333186558, 53.18446152550833, 54.86875350134713, 59.49119894845145, 56.58521911076137, 55.199522495269775, 55.3022585596357, 51.90215410505022, 53.73823642730713, 51.972052982875276, 49.134995801108225, 48.574244907924104, 55.20882960728237, 56.883164814540315, 56.66080856323242, 61.108934129987446, 52.060128348214285, 52.63566500799996, 53.264984198978965, 58.44191673823765, 59.39902414594378, 62.90880938938686, 59.03004700796944, 66.66991792406354, 59.26003238133022, 67.41339601789201, 21.527671439307078, 0.2448948776083333, 0.5358376385910171, 3.232155203819275, 0.42244504605020794, 18.05014841897147, 86.32022258213588, 60.071324893406455, 80.43129076276506, 57.91638626371111, 45.519618783678325, 45.013623169490266, 66.99226570129395, 55.62853206907, 64.87637247358049, 71.06848893846784, 71.00835922786167, 1.0298567840031214, 0.13864332331078394, 0.20293822112892354, 0.1516467819788626, 0.12816919891961984], [0.09246492372559649, 0.02785297024196812, 0.03953671222552657, 0.03915103292092681, 0.04245974948363645, 0.12849199159869126, 0.06176479001130376, 1.5542862947498048, 54.49220282690865, 56.26488283702305, 43.25742776053292, 23.196460247039795, 20.965126173836843, 39.23328821999686, 22.60105173928397, 41.41226066861834, 62.50930186680385, 53.78292376654488, 47.96320990153721, 64.19189153398786, 12.336021985326495, 1.3895349523850848, 0.20586460695735045, 0.10265820247254201, 0.1669318825006485, 7.996681758335658, 62.841488293239046, 50.446124349321636, 59.07009642464774, 50.33497749056135, 51.59760761260986, 47.89490910938808, 53.63650437763759, 47.4105258669172, 53.2213773046221, 54.46395492553711, 54.05139521190098, 49.81611728668213, 49.404683181217735, 43.406014987400596, 46.66819422585623, 45.92580699920654, 50.073926721300396, 49.14495604378836, 48.255892344883506, 40.82321323667254, 50.63478531156267, 51.05851078033447, 52.816599573407856, 49.1274048941476, 49.484413760049, 45.862550599234446, 51.29271718433925, 48.80383423396519, 49.228216307503835, 43.41264009475708, 45.239484786987305, 41.376644202641074, 42.42216396331787, 43.59162221636091, 44.72139235905239, 44.64841195515224, 45.86505889892578, 43.85150568825858, 44.298306124550955, 38.07782711301531, 37.63680410385132, 42.763073853084016, 40.07575382505144, 35.76706123352051, 35.897607462746755, 33.38975593021938, 35.16898809160505, 33.07575641359602, 37.051595551627024, 39.84195041656494, 38.081329005105154, 36.45588479723249, 37.199630396706716, 40.96062776020595, 40.84232425689697, 41.44551822117397, 44.64193623406546, 40.291147981371196, 38.8960018157959, 42.46659074510847, 47.63931615012032, 51.72736522129604, 49.70864602497646, 48.360723291124614, 50.45311771120344, 46.757061685834614, 46.988325527736116, 44.332331453050884, 45.453093256269185, 40.46631554194859, 43.09368303843907, 42.62277235303606, 42.316134452819824, 41.523212977818076, 40.57818501336234, 37.76593637466431, 37.17818825585501, 38.136296204158235, 39.366672788347515, 35.96411909375872, 35.21700014386858, 34.737015111105784, 33.60090126310076, 32.49645035607474, 34.56728799002511, 34.78275162833077, 38.83226946422032, 37.10640294211251, 41.14301797321865, 41.55945825576782, 43.31534446988787, 44.83839307512556, 42.16702611105782, 42.516947814396445, 45.649928774152485, 40.30562802723476, 44.1531652041844, 43.675285475594656, 40.383725779397146, 39.590366567884175, 39.943234307425364, 42.28985289164952, 44.73626497813633, 46.277083601270405, 52.31829561505999, 46.405951840536936, 53.40628276552473, 49.42534712382725, 50.95315524509975, 77.93521295275006, 49.28549378258841, 49.76520783560616, 47.30683789934431, 48.51152351924351, 44.88638080869402, 48.04209280014038, 48.82286187580654, 51.888094425201416, 48.65677561078753, 56.91104098728725, 53.97184876033238, 56.71995162963867, 54.79096146992275, 60.87500217982701, 56.652672222682405, 65.23101547786167, 48.419150693076, 56.980519499097554, 8.231821826526097, 0.20693031405763967, 1.7030478779758726, 1.2300519730363573, 0.08919094476316657, 17.11645817756653, 70.92401504516602, 54.62480572291783, 66.87141568320138, 58.52702522277832, 52.9591383934021, 34.6735120500837, 42.70714085442679, 35.2581821169172, 47.475112846919465, 64.73321873801095, 33.7165401322501, 0.3356745035520622, 0.0879735986569098, 0.08256529457867146, 0.09357333781995944, 0.13511704467236996, 0.05034018733671733, 0.031965160476309915, 0.010546105082279869, 0.0482292106109006, 0.06793457322887012, 0.1037159367863621, 0.07547798273818833, 2.440136560371944, 65.89804254259381, 61.04989528656006, 49.867461000170024, 29.91177259172712, 23.822722230638774, 38.764969212668284, 15.847072669437953, 48.8898320879255, 66.75986930302211, 54.51971769332886, 53.821739877973286, 71.02548653738839, 13.01977162701743, 1.4987869071108955, 0.3339094439787524, 0.18720121628471784, 0.13469619011240347, 9.53341657774789, 65.88297189985002, 53.724572794778005, 64.87325968061174, 52.38848631722586, 55.183649335588726, 50.09101234163557, 56.7525178364345, 53.062996591840474, 54.71163388660976, 56.77536351340157, 55.35413728441511, 52.317013672419954, 52.138497080121724, 44.6829514503479, 48.216857365199495, 48.21128143583025, 51.93677003043038, 51.19563347952706, 50.546265261513845, 41.74351256234305, 51.84186111177717, 50.45578234536307, 54.02192790167672, 51.287992409297395, 54.261543478284565, 49.50346572058541, 52.79402835028512, 50.17158365249634, 51.27952255521502, 46.12087420054844, 48.42864888054984, 42.69211190087454, 44.14723144258772, 47.17644453048706, 47.87767062868391, 47.57220002583095, 49.38923038755144, 47.33491904394967, 49.294185979025706, 39.739752837589805, 39.852285861968994, 44.7169246673584, 43.34448868887765, 37.536875111716135, 37.495147705078125, 34.64859580993652, 38.64788164411272, 33.87631048474993, 38.031645911080496, 40.9598981993539, 42.90654025759016, 38.61319971084595, 41.08483028411865, 42.49132980619158, 44.00619690758841, 43.77574600492205, 47.13696139199393, 41.05769062042236, 40.21976913724627, 44.62792519160679, 49.749845368521555, 51.70037841796875, 50.94482435498919, 50.45558779580252, 54.28537927355085, 48.815990107400076, 49.23648813792637, 46.679533685956685, 46.77335868562971, 45.22848926271711, 44.65134756905692, 44.34641892569405, 44.74555819375174, 44.992552757263184, 43.7913863999503, 41.21423006057739, 39.65505429676601, 40.49138116836548, 41.19331250871931, 38.83907869883946, 38.130900927952354, 36.85709810256958, 34.90650599343436, 34.25408751623971, 35.51134320667812, 38.94529233660017, 41.20940453665597, 39.0228932925633, 44.60078205381121, 46.4315698487418, 46.10251358577183, 47.71376609802246, 45.41316195896694, 45.2870625768389, 46.067272322518484, 41.79305321829659, 44.98445463180542, 46.43568665640694, 42.019630500248496, 42.01371758324759, 42.05065073285784, 44.685400690351216, 45.54042863845825, 49.40814685821533, 53.60303143092564, 49.80267252240862, 54.15134504863194, 50.42410203388759, 48.24600158418928, 69.94856439317975, 51.76452071326119, 52.93536513192313, 51.25505099977766, 50.75995710917881, 47.396580832345144, 49.925412450517925, 51.44650166375296, 51.46229839324951, 52.0259883744376, 61.53428200313023, 57.60160507474627, 58.41727147783552, 57.78170238222395, 63.00970418112618, 59.60816492353167, 65.35800770350865, 52.61829103742327, 62.808532987322124, 9.098860604422432, 0.14984634358968052, 1.2352874406746455, 2.153558543750218, 0.2029086234314101, 19.512570517403738, 77.08143915448869, 59.47181347438267, 72.89803300585065, 62.2537054334368, 54.199569020952495, 37.184323515210835, 52.81484167916434, 39.54979951041085, 51.59812872750418, 71.63591357639858, 42.825680596487864, 0.3672794976404735, 0.02911393597189869, 0.06835722590663604, 0.08888806708689247, 0.07730647176504135, 0.20254837561930927, 0.09825873747467995, 0.15697275261793817, 0.20883721459124768, 0.10784420490797077, 0.3923126629420689, 0.28874493177448, 2.748374500444957, 76.82663481576103, 70.35003130776542, 58.16916172845023, 33.57884420667376, 32.56609909875052, 53.72964497974941, 30.507813385554723, 54.51880053111485, 69.71775218418666, 65.85003049033028, 57.24476643971035, 76.39878559112549, 15.170064517429896, 2.2530441539628163, 1.5173543393611908, 0.21725482147719177, 0.15704185462423734, 10.896819029535566, 70.4577978679112, 52.881554807935444, 67.33547891889299, 54.83507558277675, 57.53881420407976, 50.808855056762695, 58.97394725254604, 53.007525648389546, 55.347453117370605, 56.858356271471294, 58.397552490234375, 53.542898246220176, 54.380566120147705, 47.38819088254656, 50.413985456739155, 50.02603278841291, 54.323736803872244, 52.80452707835606, 52.07136358533587, 42.26600667408535, 53.606766087668284, 53.55346645627703, 55.86229726246425, 52.89126491546631, 53.077632972172324, 51.57478625433785, 56.96804748262678, 52.46488870893206, 53.74484069006783, 48.42177711214338, 50.51882682527815, 44.48657103947231, 48.34386696134295, 49.92261232648577, 53.22863122395107, 50.98561028071812, 52.99642590114048, 51.00724002293178, 53.07770940235683, 43.46863910130092, 43.62564059666225, 48.01154157093593, 46.466870171683176, 40.16505207334246, 39.910744530814036, 36.81199387141636, 40.549072061266216, 37.50858552115304, 41.25954621178763, 43.560779162815635, 43.51234327043806, 41.124483653477256, 42.393662452697754, 44.64310353142874, 46.40124096189226, 45.843675817762104, 50.64820923124041, 44.463867800576345, 43.85306208474295, 48.190693923405235, 52.15822301592146, 54.93840571812221, 53.01098237718855, 50.593040534428184, 55.96570382799421, 52.20195150375366, 52.11055142538888, 49.93738767078945, 49.82657779966082, 48.19880247116089, 47.22658273151943, 45.947846685137065, 47.74466821125576, 46.416780608040945, 47.07587282998221, 42.93175874437605, 41.69684498650687, 43.80228464944022, 44.53585113797869, 39.422789914267405, 41.64011294501168, 38.358360631125315, 37.449904509953086, 36.43029458182198, 37.7548713684082, 39.66173846381051, 43.69141224452427, 42.14707088470459, 49.110315799713135, 48.96117271695818, 49.24134840284075, 52.497923919132774, 49.91035223007202, 48.39297682898385, 50.0480967930385, 45.20476811272757, 48.17399392809187, 48.58835322516305, 44.17427383150373, 43.49781111308506, 44.72494288853237, 46.021369048527305, 47.3807806287493, 51.32729489462716, 56.103990350450786, 51.087342330387656, 57.312438419886995, 54.15508317947388, 48.854483127593994, 71.30531133924211, 55.99872514179775, 54.50420583997454, 54.136660030909944, 52.163364682878765, 49.83590923036848, 53.7142790385655, 53.88041046687535, 56.479394572121755, 54.42613935470581, 64.35569531576974, 60.33352211543492, 59.70245892660958, 59.27904960087368, 65.16240201677594, 62.85585716792515, 69.283858026777, 56.418493611471995, 66.56470830099923, 11.474877885409764, 0.1671824926244361, 3.480963681425367, 3.311698398419789, 0.2376811004110745, 20.472061157226562, 84.3171889441354, 63.745004245213096, 78.84147344316754, 69.3039939062936, 64.30021395002092, 48.89483479091099, 59.58742455073765, 44.10254062925066, 63.13889898572649, 78.51203155517578, 56.117709568568635, 0.3851546070405415, 0.15279440182660306, 0.1537881570735148, 0.20086541878325598, 0.18204540865761892], [0.043432541391147036, 0.10254277688051973, 0.026988647246201123, 0.03316054240401302, 0.06880402086036545, 0.061080806356455596, 0.04588312828647239, 1.827897778579167, 56.96905149732317, 57.43022428240095, 38.89079761505127, 33.157918861934114, 30.18472215107509, 46.58659110750471, 52.06600652422224, 29.455755370003835, 60.43741852896554, 59.142691203526084, 45.24721813201904, 59.766820090157644, 25.140981367656163, 0.2524679798100676, 0.9891315464462552, 0.1548291112163237, 0.04833988306511726, 0.46965398426566807, 45.46035759789603, 56.7817245892116, 56.101416042872835, 50.83008180345808, 54.34906298773629, 51.80059576034546, 54.23035996300833, 52.27866309029715, 58.46930653708321, 54.24205725533621, 53.81667116710118, 49.323976380484446, 50.152945109776084, 44.128603322165354, 49.57285043171474, 48.85526132583618, 52.86793286459786, 50.653736523219514, 44.98342629841396, 45.53741659436907, 49.043995244162424, 47.24378299713135, 55.127799715314595, 48.41062177930559, 51.650757857731406, 46.38136216572353, 51.327284472329275, 49.70957360948835, 50.9841685295105, 48.151412282671245, 44.97574506487165, 40.60050957543509, 43.70726455960955, 44.593962396894185, 45.49302455357143, 45.082045555114746, 42.08163275037493, 42.651947838919504, 42.14832156045096, 39.30644580296108, 39.74151420593262, 39.570428712027415, 41.92169564110892, 39.26890121187483, 37.69041987827846, 35.249538557870046, 36.26620592389788, 35.17269148145403, 35.53761434555054, 37.54116562434605, 38.03843082700457, 38.514066287449424, 38.50084386553083, 40.313837323869976, 41.322535106113975, 40.92487233025687, 42.909093720572336, 43.049468176705496, 41.896421568734304, 43.99926955359322, 47.233068874904085, 53.18154328210013, 50.73411328451974, 48.17006819588797, 50.73739978245327, 48.63480193274361, 47.86593859536307, 46.358770098005024, 41.689622334071565, 41.51906142915998, 44.101884024483816, 43.68343571254185, 42.00523035866873, 40.451012134552, 39.91947841644287, 36.81912619726998, 36.77134690965925, 38.276476110730854, 36.605566365378245, 36.07523468562535, 36.00168800354004, 35.438380173274446, 36.31616694586617, 33.3021183013916, 37.340109075818745, 38.13426733016968, 37.20674535206386, 36.295614174434114, 42.18075922557286, 41.94903332846505, 43.73889970779419, 41.85850524902344, 43.09568064553397, 44.03996862683977, 44.79599516732352, 40.3779969896589, 44.19314513887678, 41.348768029894146, 43.39601305552891, 41.378568853650776, 44.64224542890276, 43.74024765832083, 45.424032415662495, 46.09934868131365, 47.79356615883963, 50.667233398982454, 52.72746113368443, 46.77303212029593, 53.70896019254412, 45.687650544302805, 50.502300534929546, 53.5776218686785, 50.563861574445454, 50.70488568714687, 47.35013907296317, 47.433701583317344, 46.20180681773594, 50.004441261291504, 52.18114512307303, 52.94734730039324, 52.37958220073155, 57.275084904261995, 55.38694667816162, 59.46874931880406, 55.785832336970735, 56.46797520773751, 43.50176811218262, 51.41595390864781, 3.8271859032767157, 0.29050792860133307, 1.3377744555473328, 2.1230663742337907, 0.21042125459228242, 20.68944423539298, 67.0544103894915, 55.784599031720845, 56.8352952003479, 65.94408130645752, 63.29494162968227, 33.357300894601, 39.302950859069824, 22.06137820652553, 42.61088398524693, 63.430681637355256, 21.246613332203456, 0.44956693212900845, 0.1041105320411069, 0.002940095416436504, 0.06016557118190186, 0.07624485623091459, 0.08187669010034629, 0.04912449346323099, 0.003861496565930013, 0.09650036147130386, 0.04734618549368211, 0.0867076830140182, 0.16098856713090623, 2.278524935245514, 66.52563163212368, 65.0268635068621, 45.26516880307879, 35.30764634268624, 32.00145026615688, 51.20551381792341, 47.64603853225708, 36.60655995777675, 66.7171448298863, 63.617483956473215, 50.18207890646798, 65.08176817212785, 26.595284496034893, 0.15249253516750677, 1.4679361454078128, 0.04931563338530915, 0.15135444195142814, 0.6244200595787593, 51.76718882152012, 59.07744067055838, 63.8519926071167, 54.625945227486746, 54.88123594011579, 52.86034195763724, 59.05364309038435, 53.13446923664638, 60.49271924155099, 55.84449945177351, 56.33892284120832, 51.31295381273542, 51.886548451014924, 46.85962404523577, 50.361547401973176, 51.519607135227744, 54.500036920819966, 51.80549771445138, 47.57995074135916, 45.752710001809255, 50.48163659232003, 50.16939149584089, 55.900046825408936, 50.21677473613194, 53.74091148376465, 47.79506696973528, 52.739248752593994, 52.337225982121055, 52.25670678274972, 49.91766173498971, 46.15158176422119, 42.62715319224766, 46.04654237202236, 46.76923492976597, 47.157486370631624, 47.48096670423235, 46.62099163872855, 46.62540027073452, 45.61873483657837, 41.58315856116158, 42.05971465791975, 41.456096853528706, 43.984713077545166, 40.40481703622, 38.946754932403564, 36.65391540527344, 37.19614587511335, 37.10765709195818, 36.547614915030344, 41.14797551291329, 39.68318060466221, 38.9468799999782, 41.50348356791905, 42.02555383954729, 44.13029868262154, 43.375488076891216, 44.71303020204817, 44.6485960824149, 42.45698833465576, 43.13963842391968, 48.55068704060146, 54.55035924911499, 51.946045875549316, 49.024116447993684, 51.945253780909944, 51.03140933173043, 49.738551071711946, 49.39397600718907, 42.98829276221139, 42.38865974971226, 47.05662284578596, 45.13244431359427, 43.83429847444807, 41.778118065425325, 43.314493315560476, 39.89372839246477, 39.62768881661551, 39.16842678615025, 38.42672743116106, 37.085672991616384, 37.821674823760986, 37.02107558931623, 37.332879475184846, 35.4462559563773, 38.134479250226704, 40.336391176496235, 40.878958633967805, 38.95578759057181, 45.6509918485369, 45.21712895802089, 46.768519265311106, 44.56574576241629, 46.76562534059797, 47.23025138037545, 48.21067694255284, 42.159122535160606, 46.780247824532644, 43.759184973580496, 46.61345631735665, 43.41780260631016, 47.08169542040144, 47.32763385772705, 50.30708047321865, 47.40238605226789, 50.659156118120464, 50.81266614368984, 55.160616057259695, 49.56417907987322, 51.13907166889736, 48.44701296942574, 52.25481339863369, 56.72355079650879, 51.717446667807444, 51.4973520551409, 50.053585869925364, 49.84213829040527, 49.471809727805, 53.19603375026158, 57.00827407836914, 54.92474903379168, 54.15950223377773, 59.25967107500349, 58.82560321262905, 61.69882229396275, 57.91894320079258, 60.67906297956194, 49.46690429959978, 56.095586504255024, 4.2610679013388495, 0.26917307770677973, 1.3143139715705598, 2.865383033241544, 0.2314167022705078, 22.196023872920446, 74.73410837990897, 59.080810546875, 64.24516337258476, 71.08540780203683, 70.42898368835449, 38.238229751586914, 49.683927808489116, 27.059842790876115, 47.10942568097796, 71.29123428889683, 28.7344993523189, 0.5089678689837456, 0.18932333455554076, 0.08069237507879734, 0.0752242717093655, 0.029814638729606355, 0.2116632315197161, 0.21589593296604498, 0.1286580426884549, 0.16762444962348255, 0.09217877193753209, 0.18638647214642592, 0.23764095827937126, 3.2935672913278853, 78.55638885498047, 71.89228125980922, 52.99585962295532, 44.316159520830425, 45.25284617287772, 60.66082395826067, 61.94744273594448, 43.088972159794395, 70.82769911629813, 71.35378892081124, 54.9031331879752, 70.6945229939052, 29.13776411328997, 0.509071874831404, 2.7743284106254578, 0.45187612250447273, 0.21755587389426573, 0.9427880389349801, 56.86506475721087, 58.46542249407087, 62.8027868270874, 56.5247037751334, 58.599585260663716, 56.60462195532662, 60.83985819135393, 55.63596664156233, 63.65109239305769, 58.60480335780552, 57.8924879346575, 53.41570104871477, 55.83205870219639, 48.02226611546108, 54.763585567474365, 52.824162687574116, 55.42206982203892, 53.91151407786778, 47.231811250959126, 46.65955066680908, 52.45244448525565, 52.03526769365583, 57.94124691826956, 52.19351291656494, 56.62329523903983, 49.56591265542166, 56.808819089617046, 54.56823001589094, 55.20914575031826, 53.649591309683665, 49.267508370535715, 44.15170955657959, 48.34192841393607, 51.07584653581892, 51.1526415007455, 52.91712958472115, 49.981529576437815, 49.462283747536794, 49.44773074558803, 44.875048296792166, 45.490283489227295, 46.416797978537424, 47.24617665154593, 41.86772550855364, 42.010396344321116, 38.950110912323, 41.157327788216726, 39.523726395198274, 39.6139418057033, 42.79060609000069, 40.94195795059204, 40.40023469924927, 43.23605857576643, 44.74171583993094, 47.05446890422276, 45.86670214789254, 46.700902870723176, 48.413633823394775, 46.1459641456604, 44.9013854435512, 51.03131900514875, 59.4278313773019, 56.262305055345806, 51.428224427359446, 54.57393101283482, 53.02305139814104, 52.09514032091413, 51.33893660136631, 44.96763999121529, 46.64444875717163, 48.922193322862896, 47.28650747026716, 45.56034564971924, 43.948843002319336, 46.013309138161794, 41.66532448359898, 41.8923464502607, 42.225554261888774, 42.257668835776194, 39.124382155282156, 40.18082448414394, 40.19471740722656, 41.23231969560896, 37.96724305834089, 42.759679658072336, 43.20840127127511, 43.159923689705984, 41.84099578857422, 48.969632148742676, 48.303880078451975, 50.90440320968628, 48.661086968013215, 51.878095967429026, 51.83864409582955, 50.12038237707955, 45.03261259623936, 49.02141012464251, 45.5734395299639, 48.14821263722011, 46.05867740086147, 49.11222308022635, 50.06357043130057, 52.232447147369385, 50.395590100969585, 54.47155278069632, 51.99407182421003, 56.548518725803916, 50.80518640790667, 53.51767975943429, 59.56640625, 53.55119439533779, 61.333715302603586, 54.26848125457764, 56.94199521200997, 54.51221016475132, 53.29946116038731, 52.7282532283238, 55.03457920891898, 59.303958892822266, 57.69830662863595, 55.86961024148123, 63.39414800916399, 60.57235949380057, 65.32621274675641, 59.58549295152937, 62.702691078186035, 53.282118456704275, 59.54059369223458, 5.712099730968475, 0.25744679836290224, 2.7824473806789944, 3.8065071957451955, 0.389187357787575, 25.465377126421245, 81.0890141895839, 65.71957806178501, 69.242648260934, 76.23584338596889, 76.02440275464738, 45.56029353822981, 56.54079580307007, 33.526534693581716, 59.10360063825335, 79.86575603485107, 41.02464151382446, 0.5916240736842155, 0.3067543911082404, 0.317376259714365, 0.10863695094095809, 0.1037885807454586], [0.056326033281428475, 0.02841738924118025, 0.053581623759652884, 0.059618753381073475, 0.03182680379333241, 0.055049613916448185, 0.08555306747023549, 1.3450178440128053, 58.655031885419575, 50.0308062008449, 47.07994100025722, 41.110924243927, 79.7210111618042, 46.75404964174543, 54.11618021556309, 36.01392378125872, 52.92665556498936, 56.61187587465559, 47.28299862997872, 55.14673008237566, 38.87522322790963, 0.06863548633243356, 1.4310213433844703, 0.32463650298970087, 0.07605272225503411, 0.05588692273678524, 21.6457838671548, 58.978546960013254, 54.192322049822124, 56.1691575050354, 50.82133402143206, 53.76151984078543, 52.7280968938555, 56.16547843388149, 54.70845855985369, 55.22783293042864, 52.42847320011684, 48.988788332257954, 45.917833941323416, 47.85517236164638, 50.2563099861145, 49.638118335178916, 50.09417029789516, 49.81757640838623, 49.25922959191458, 48.32024308613369, 51.81154612132481, 49.86319828033447, 50.738323892865864, 51.788585799080984, 55.20452172415597, 53.13112367902483, 47.85960878644671, 48.26658909661429, 48.03247649329049, 47.28971058981759, 42.978089332580566, 42.85737827845982, 44.248425006866455, 45.19350855691092, 42.70408364704677, 44.16328525543213, 44.04390478134155, 45.57968248639788, 41.66366733823504, 44.08610813958304, 39.50443819590977, 39.519724232809885, 37.985680103302, 41.28150946753365, 39.272750513894216, 37.04724945340838, 34.80817856107439, 34.64735903058733, 34.42042391640799, 37.74390711103167, 38.54446465628487, 40.39540222712925, 39.565436431339805, 39.255213260650635, 38.76779018129621, 41.95196894236973, 40.11814478465489, 45.406022684914724, 42.84065049035208, 43.98733949661255, 47.61964232581002, 51.17906549998692, 46.200257369450156, 48.43768848691668, 51.4563125201634, 49.565117086683, 47.81177043914795, 45.20986809049334, 39.44090734209333, 43.72723715645926, 41.90679522923061, 43.45891857147217, 39.699606146131245, 38.626411710466655, 39.20319209780012, 39.30321141651699, 37.94037437438965, 36.48111023221697, 35.925983905792236, 34.164243834359304, 35.114812987191335, 34.9323741367885, 36.32843051637922, 38.366052286965505, 40.415677070617676, 38.25992897578648, 37.82061522347586, 41.98405224936349, 42.887248584202354, 45.0301251411438, 42.61533778054373, 45.81336777550833, 39.83276489802769, 45.264817919049946, 42.62480122702462, 40.85203089032854, 42.46394000734602, 44.508638518197195, 48.58126258850098, 50.505215304238455, 48.94779743467058, 49.9589409828186, 47.15551655633109, 48.08425794328962, 47.682857036590576, 50.76514046532767, 49.066000189099995, 54.65149375370571, 33.24389934539795, 31.188319955553325, 52.729010581970215, 51.7863450050354, 53.26033238002232, 51.389283248356406, 51.38978699275425, 49.88799292700631, 47.727214336395264, 46.31429467882429, 48.57872302191598, 54.637170042310444, 52.8785844530378, 52.66234956468855, 52.46541677202497, 58.343752588544575, 54.73730400630406, 56.850862639290945, 44.85217135293143, 35.34258883340018, 1.4418846347502299, 0.20664040318557195, 0.9643053071839469, 2.145888601030622, 0.12989004515111446, 39.7568210874285, 63.78414344787598, 58.101243087223594, 56.722157682691304, 64.92243903023856, 52.91951976503645, 34.27403926849365, 39.948834555489675, 39.07465042386736, 52.6968925339835, 61.59979656764439, 21.443002428327286, 0.7599697517497199, 0.16427707352808543, 0.08525242895952292, 0.09943263698369265, 0.11456913155104433, 0.10998634674719401, 0.03573730627873114, 0.06334920999194894, 0.02630141849762627, 0.06648292898067407, 0.09266513905354909, 0.08333138775612627, 2.062734297343663, 70.02074922834123, 58.1089243207659, 53.44344867978777, 40.02514662061419, 63.397795813424246, 52.50797101429531, 60.6016183580671, 38.08610936573574, 57.41304833548409, 62.39150210789272, 52.14013338088989, 59.85207448686872, 42.99667228971209, 0.11599785488631044, 1.980329530579703, 0.43878294793622835, 0.18935279654605047, 0.05246608844026923, 25.685381412506104, 63.843620027814595, 60.53502682277134, 61.43713229043143, 53.58082151412964, 58.7895906993321, 54.59114170074463, 58.520966393607004, 57.558745111737935, 57.05760281426566, 53.98141990389143, 49.68270492553711, 48.53575883592878, 51.992306981767925, 52.35392597743443, 53.121795722416465, 52.13087838036673, 50.83896854945591, 50.86866862433297, 51.2589385168893, 53.73066636494228, 51.394042764391216, 51.91481719698225, 51.97854260035923, 54.14585944584438, 54.67721945898873, 50.53184427533831, 50.17550591060093, 49.86503260476248, 49.375264508383616, 44.09133665902274, 44.48695319039481, 44.65564155578613, 48.96420213154384, 45.76353529521397, 46.46433407919747, 46.34013155528477, 47.886018889290945, 46.38102170399257, 47.56410884857178, 42.61312825339181, 40.823230607169016, 40.581631319863455, 44.467067446027485, 42.13166325432913, 37.612516675676616, 36.215411118098665, 37.710514068603516, 36.17447233200073, 38.626950195857454, 40.33529683521816, 41.835864543914795, 42.29726314544678, 41.1773281778608, 41.95776373999459, 44.37201608930315, 42.8359500340053, 47.208031041281565, 45.90573017937796, 45.573352677481516, 48.560081005096436, 52.561809131077354, 47.99902786527361, 47.80737222943987, 52.529388836451936, 50.25018514905657, 49.644371713910786, 47.28065013885498, 41.09287977218628, 44.21105064664568, 44.84533779961722, 43.356922490256174, 41.88582556588309, 40.75815030506679, 41.604694502694265, 42.11654397419521, 39.908958843776155, 37.15940032686506, 38.41531501497541, 36.78955813816616, 37.49597454071045, 36.820793764931814, 36.92628826413836, 42.04516165597098, 42.190851484026226, 41.56160872323172, 40.766658374241416, 44.55688680921282, 47.088921546936035, 47.13773611613682, 44.405461243220735, 49.24865790775844, 44.353599888937815, 46.66393845421927, 43.89945520673479, 43.845238413129536, 44.121005467006135, 47.670569147382466, 50.875491755349294, 53.674399852752686, 49.97658940723964, 52.60407502310616, 50.50741440909249, 49.56979322433472, 51.484682015010286, 52.009799071720664, 50.945157868521555, 56.202147551945274, 35.07053559167044, 33.25681604657854, 54.2589795930045, 53.77620138440813, 55.07465989249093, 53.561335291181294, 55.23564270564488, 53.73196915217808, 51.44651208605085, 49.39775930132185, 52.1319761957441, 55.66305071966988, 55.07809925079346, 55.394951002938406, 55.17131975718907, 61.44763101850237, 58.24682869229998, 61.001382963997976, 50.666660172598704, 40.07573298045567, 1.633428882275309, 0.24785595014691353, 1.0348149750913893, 2.593590566090175, 0.19484287766473635, 42.61457347869873, 69.92148726327079, 64.4288945879255, 64.31351975032261, 69.93456377301897, 60.93919658660889, 39.78744527271816, 46.90680578776768, 33.50409548623221, 56.674923828669954, 70.47933033534459, 27.198412452425274, 0.6373932691557067, 0.1280128373099225, 0.098585628505264, 0.043618303923202414, 0.06275845026331288, 0.18340180015989713, 0.1954553233725684, 0.163715409381049, 0.1355284811662776, 0.1149717742311103, 0.14372721979660646, 0.21153585692601545, 2.744104181017194, 81.06961481911796, 67.27411242893764, 58.917750222342356, 54.06164033072335, 87.34064892360142, 60.009534563337056, 64.01914542061942, 47.912866728646414, 64.90210165296281, 65.89299815041679, 58.78085681370327, 65.17007977621896, 46.02234527042934, 0.2307135228599821, 2.750911678586687, 1.522150224872998, 0.3056375224675451, 0.13911797212702887, 28.828015157154628, 64.91837433406285, 57.310458183288574, 64.82806859697614, 56.92820998600551, 59.30591828482491, 56.4213284764971, 59.574153491428916, 60.089008058820454, 59.86872237069266, 56.08328471864973, 53.57150745391846, 49.75328125272478, 53.600832326071604, 54.189879758017405, 54.69374227523804, 53.494979994637625, 52.38121155330113, 52.18654039927891, 50.91113601412092, 54.6186009815761, 54.035393510546, 54.50937877382551, 53.46142019544329, 57.45533159800938, 54.976068428584504, 52.85542263303484, 52.416084562029155, 53.2069319997515, 51.01622404370989, 47.21712275913784, 45.47527885437012, 48.80286496026175, 52.23469836371285, 50.219481059483115, 50.946332114083425, 48.994815894535606, 52.75379828044346, 49.424846853528706, 51.39961869376046, 46.51597309112549, 45.15585626874651, 43.44773891993931, 49.07736396789551, 43.54606635229928, 40.87543242318289, 38.95144844055176, 39.96931437083653, 40.054822376796174, 41.09801796504429, 42.689780780247276, 44.58693081992013, 46.38346746989659, 42.57043504714966, 43.460071972438264, 46.83998496191842, 45.31457049506051, 51.37325028010777, 47.80322068078177, 47.91673340116228, 51.486182825905935, 55.269487380981445, 49.37360736301967, 50.299239431108745, 55.39897400992257, 52.146772384643555, 54.062967436654226, 49.8515704699925, 43.199524947575156, 46.5835234778268, 46.045319489070344, 47.54497003555298, 44.86032158987862, 42.978044169289724, 43.469490255628315, 43.44468518665859, 42.97250992911202, 39.089102676936555, 41.025107043130056, 37.060513564518516, 39.87192494528634, 39.67316825049264, 40.11418431145804, 44.879515988486155, 44.6612035887582, 43.51963540485927, 44.15439503533499, 49.31681973593575, 50.79712997164045, 50.43432283401489, 49.423797675541465, 56.03681516647339, 46.94556283950806, 52.05788408006941, 46.50446687425886, 45.49290296009609, 48.06702641078404, 48.85620628084455, 52.633104596819194, 55.15118040357317, 53.58581032071795, 53.93096555982317, 52.648335048130576, 51.25239678791591, 53.716655322483604, 52.36638757160732, 54.785340377262656, 57.135988916669575, 40.802580560956685, 36.55252381733486, 56.01848929268973, 56.6332346371242, 57.25944103513445, 55.76210771288191, 56.31147050857544, 55.20835018157959, 53.6883761542184, 51.400963170187815, 55.53826802117484, 60.37460681370327, 57.738574913569856, 59.479748317173545, 58.78450461796352, 65.48433290209088, 61.886256899152485, 64.01704706464494, 53.64312253679548, 45.72694608143398, 1.9049984642437525, 0.23026001719491823, 1.8761282648359026, 4.081765728337424, 0.3250598002757345, 45.86967250279018, 75.112229347229, 68.63898876735142, 68.68684101104736, 73.54548699515206, 65.39537511553083, 48.32408543995449, 56.003102506910054, 49.80377033778599, 68.10768781389508, 78.65855516706193, 36.55548027583531, 0.9835198989936283, 0.3209156340786389, 0.1526168156415224, 0.1200387751949685, 0.17038086242973804], [0.136152909802539, 0.06757442041167191, 0.041589704741324694, 0.03299320549038904, 0.0871749697253108, 0.03129316992791636, 0.03409245257665004, 0.899583597268377, 51.30361543382917, 58.4310428074428, 33.83360685620989, 49.89956167766026, 102.65987042018345, 56.286418778555735, 40.816556862422395, 36.46774189812796, 56.887024538857595, 56.260085105895996, 53.18723733084542, 51.9300719669887, 44.14452164513724, 0.08903089870831796, 0.5248004794120789, 0.44366050192287987, 0.04562051487820489, 0.19214496814778873, 6.962600903851645, 53.09169612612043, 52.24506507601057, 57.70699187687465, 50.29119341714041, 56.29008047921317, 52.86015435627529, 58.42375414712088, 52.63533844266619, 52.475220680236816, 46.1297470501491, 48.26885420935494, 46.84666218076433, 50.76055465425764, 48.52668101446969, 52.24908808299473, 49.960622446877615, 49.21889182499477, 49.83923394339425, 51.44743619646345, 50.28652422768729, 50.88375663757324, 50.670255865369526, 50.38115174429757, 56.77038165501186, 45.99905143465315, 48.66388709204537, 46.82317379542759, 50.96609279087612, 49.03787735530308, 42.67163208552769, 44.33142123903547, 44.44337408883231, 45.7302325793675, 44.6865679877145, 45.095163754054475, 43.04912771497454, 43.32766710008894, 44.19406924928938, 44.83259827750069, 39.82735225132534, 38.35228443145752, 37.199140548706055, 38.8344338280814, 38.17591483252389, 37.570351532527376, 33.474207809993196, 37.09516075679234, 35.6799829346793, 35.458196435655864, 36.58245665686471, 39.75217274257115, 38.087641443525044, 40.63857180731637, 40.16492700576782, 45.44428988865444, 41.319860049656455, 43.19954579217093, 42.324882234845845, 48.45456566129412, 47.79958329881941, 48.549755981990266, 46.53700181416103, 48.39421360833304, 53.22940942219326, 47.10494409288679, 46.47811235700335, 42.07669258117676, 41.60035187857491, 41.790485858917236, 41.131087916237966, 40.674869196755544, 40.58302443368094, 37.47073173522949, 39.1074389730181, 37.820191383361816, 38.77889687674386, 34.55934967313494, 36.64775930132185, 35.49699865068708, 36.81766012736729, 35.144106592450825, 37.80491924285889, 40.93696566990444, 38.458466802324565, 37.032439368111746, 38.23412684031895, 42.93688998903547, 42.52863468442644, 45.081917013440815, 40.89665569577898, 42.825138636997764, 41.27892473765782, 45.73963696616036, 43.13909299033028, 40.88298511505127, 41.36736488342285, 47.24803182056972, 50.88366978509085, 50.091352803366526, 49.32161399296352, 50.776250634874614, 50.2989684513637, 51.58633416039603, 49.71265513556344, 51.308684144701274, 51.85203327451433, 47.32561193193708, 37.38497012002127, 51.51889147077288, 50.002193519047324, 49.71394750050136, 51.961488246917725, 53.555523123059956, 53.71302488871983, 53.52153253555298, 50.41042103086199, 52.27164888381958, 48.384889125823975, 48.79739325387137, 49.23444536754063, 50.55015625272478, 51.735376494271414, 52.44228969301496, 54.27295242037092, 56.76460075378418, 45.27885675430298, 24.06760627882821, 0.22424591705203056, 0.39510719584567205, 0.5443223661610058, 1.6936612959418977, 0.04323467379435897, 50.82150772639683, 57.54231609616961, 62.58779566628592, 53.09078243800572, 66.07004519871303, 54.643875053950715, 32.158225945064, 38.528817313058035, 35.71392488479614, 43.93969569887434, 58.01192052023751, 15.971240452357701, 0.47393098047801424, 0.12885584921709128, 0.13985581110630715, 0.03336760415030377, 0.05054581058876855, 0.12760159080582006, 0.07106422779283353, 0.059163320676556656, 0.029310202226042747, 0.09689445461013488, 0.09213274012186698, 0.05728899660919394, 1.348206741469247, 63.419363021850586, 63.809671129499165, 44.21012306213379, 50.28334890093122, 90.78992230551583, 58.79047312055315, 47.553189754486084, 39.56412322180611, 60.6623386655535, 62.0325095312936, 57.987966605595176, 54.96970040457589, 49.251051562173025, 0.1645059162484748, 0.6607376422200884, 0.9209075101784298, 0.11318947986832686, 0.30807237752846306, 8.612259149551392, 56.25628791536604, 59.55101599012102, 63.35468224116734, 52.55814048222133, 59.74637154170445, 54.420139585222515, 60.10200119018555, 54.15097679410662, 55.07298537663051, 48.8701547895159, 49.7966171673366, 48.083257402692524, 52.50898892538888, 50.90574421201433, 53.891350405556814, 52.02704797472273, 51.210825715746196, 51.27339424405779, 52.662811619894846, 52.24205303192139, 52.209962776729036, 50.606301171439036, 49.75670324053083, 55.07808535439627, 49.77483803885323, 49.324052810668945, 50.02447639192854, 52.23234292439052, 49.417513029915945, 43.40530627114432, 45.14213705062866, 46.130678108760286, 48.83437851497105, 45.221461159842356, 46.43762520381382, 45.260006291525706, 47.54898262023926, 45.21601377214704, 47.563181264059885, 42.31044735227312, 41.02034057889666, 39.96269621167864, 43.0030403137207, 38.87374326160976, 37.98013196672712, 35.87109661102295, 39.46912397657122, 37.071773120335166, 37.12133114678519, 37.40965359551566, 41.10265588760376, 40.68793181010655, 41.29440879821777, 42.537125383104595, 45.275184631347656, 42.0771164212908, 44.53054618835449, 44.443262917654856, 48.393994740077424, 50.03916488374983, 50.54165860584804, 45.618707043784006, 48.28054455348423, 54.59239585059029, 51.20333555766514, 46.67765767233712, 45.85390356608799, 43.69135665893555, 43.29366609028408, 43.23234823771885, 41.14948327200753, 43.4784916469029, 40.76277780532837, 41.67088304247175, 40.43951286588396, 39.98179333550589, 37.91034773417881, 37.5746350969587, 36.449412550245015, 38.42966651916504, 36.290812969207764, 40.14949853079659, 43.941432748522075, 41.7761413029262, 41.20718111310686, 41.69339868000576, 46.54423836299351, 45.48265436717442, 47.37074048178536, 43.29369388307844, 47.862523555755615, 44.80288083212716, 48.33630037307739, 44.852383272988455, 43.1408508845738, 43.61248765672956, 50.57816791534424, 52.71225152696882, 51.61844526018415, 53.42349692753383, 51.414435727255686, 52.238224574497764, 51.497980867113384, 51.31474297387259, 54.23327473231724, 53.81814071110317, 47.969824586595806, 39.99876083646502, 53.33657496316092, 52.95493125915527, 51.10141938073294, 55.23734501429966, 55.47046055112566, 54.24792848314558, 56.521285261426655, 53.42397287913731, 56.617326736450195, 51.96892629350935, 51.55202048165457, 54.03011635371617, 54.78589970724923, 56.05515146255493, 55.62517956324986, 58.14704213823591, 60.78450189317976, 49.850920813424246, 26.446999515805924, 0.2007104413849967, 0.5145131828529494, 1.1976599054677146, 1.9613613826887948, 0.025504265379692827, 55.35995640073504, 64.43748256138393, 69.5179636819022, 57.50683512006487, 72.11579091208321, 59.72944572993687, 38.39211845397949, 46.357328346797395, 29.67646837234497, 49.74108369009835, 66.91275746481759, 20.35475124631609, 0.5485310746090752, 0.22972196606653078, 0.09129647963813373, 0.028886609777276005, 0.02285161754116416, 0.21702027906264576, 0.15945564795817646, 0.1169488759977477, 0.1814258654734918, 0.16777142030852182, 0.14063927478023938, 0.12723178922065667, 1.8898648534502303, 73.59513882228306, 73.92986828940255, 49.38294921602522, 62.90833691188267, 104.63897446223667, 65.46177210126604, 53.59796272005354, 44.39364930561611, 68.51392119271415, 66.62811756134033, 65.44026047842843, 61.104695728846956, 55.33666951315743, 0.211610577202269, 1.3033505827188492, 1.6919427024466651, 0.1651038820190089, 0.38250647485256195, 10.833413243293762, 60.435229846409385, 52.93028947285244, 63.64035742623465, 54.95589085987636, 61.82240990230015, 56.20723015921456, 62.661279814583914, 57.25422641209194, 58.03381429399763, 51.55049882616316, 51.36571148463658, 50.51245880126953, 54.70202105385916, 53.37153829847063, 55.16333280290876, 51.9208482333592, 51.010696751730784, 52.815130029405864, 54.512658323560444, 55.700595310756135, 54.83855663027082, 53.4216000693185, 52.34332650048392, 56.21011018753052, 51.63182749067034, 50.65932634898594, 52.53724724905831, 54.51847049168178, 51.16549219403948, 45.75308173043387, 49.59168004989624, 48.71892377308437, 51.41527645928519, 50.428493295397075, 49.84732164655413, 49.31646190370832, 50.80124677930559, 49.015729972294395, 50.37538821356637, 46.40016399111067, 46.60218633924212, 43.38277326311384, 46.627251965659006, 41.41394560677664, 41.16282033920288, 37.88979843684605, 42.01150458199637, 40.120413371494834, 39.10097367422921, 38.93295233590262, 44.58071913037981, 41.94112280436924, 45.22596706662859, 44.42107037135533, 49.63270568847656, 46.330001081739155, 48.85689067840576, 47.10043818610055, 51.634113448006765, 51.68160438537598, 52.935313020433696, 48.27820648465838, 50.05012914112636, 57.552637645176475, 51.92997816630772, 50.64146947860718, 48.35393490110125, 46.48113482339041, 46.182490825653076, 47.75975275039673, 43.46983071735927, 45.61815813609532, 41.45763240541731, 43.75235489436558, 41.5479485648019, 42.39293984004429, 37.863322326115195, 40.169241837092805, 39.197956630161826, 41.120359897613525, 38.40717172622681, 43.23744821548462, 47.21586513519287, 44.79082570757185, 43.59375531332833, 44.74057980946132, 51.9851781300136, 49.24541309901646, 52.047736236027305, 47.38559225627354, 51.05957385471889, 47.86407995223999, 52.12984657287598, 46.42631353650774, 45.086273533957346, 47.6674667767116, 52.36243404660906, 54.95321232931954, 55.470505714416504, 55.83319125856672, 54.92335591997419, 54.654276507241384, 54.16039507729666, 55.78438711166382, 55.69188921792166, 55.6119293485369, 50.161522660936626, 41.696997846875874, 55.173265252794536, 54.264656271253315, 52.766826152801514, 56.860329559871126, 57.650027070726665, 57.09402527127947, 59.12767614637102, 56.02739340918404, 59.434765679495676, 53.990129470825195, 53.764438084193635, 57.4299533026559, 57.045492104121614, 57.548729283469065, 59.74030576433454, 58.88784517560686, 65.68152277810233, 54.8314208303179, 31.25147213254656, 0.48883106665951864, 0.5659762099385262, 3.231554836034775, 2.9208259667669023, 0.21533690153488091, 60.499271392822266, 69.278014591762, 72.05651582990373, 63.9233922958374, 78.1636141368321, 64.86877114432198, 46.46148879187447, 52.81783287865775, 51.44592843736921, 58.05894245420183, 76.87054743085588, 28.344427483422415, 0.5127833528178078, 0.39321071760995047, 0.15465776755341462, 0.1310222622539316, 0.11353510525077581], [0.027479105928380574, 0.05683138580726726, 0.029033549928239415, 0.08169869679425444, 0.035435904416122606, 0.0956119487860373, 0.05311169076178755, 0.44687206244894434, 50.414781025477815, 59.97051348005022, 37.02705104010445, 62.08832441057478, 98.31973375592912, 62.46473612104143, 42.2125437600272, 48.491085393088206, 61.45393303462437, 55.227631432669504, 53.89635310854231, 48.93628774370466, 49.830031054360525, 1.5946275357689177, 0.009638873228271092, 0.8592564697776521, 0.04647593379818967, 0.007268686795474163, 0.5399440782410758, 43.232136317661826, 44.84626538412911, 54.03751618521554, 53.68757711138044, 53.240109648023335, 56.906232833862305, 52.230602400643484, 53.11020612716675, 49.62475347518921, 45.69863912037441, 50.31256260190691, 50.39212989807129, 51.92935630253383, 50.099266801561626, 50.95327683857509, 46.60551800046648, 51.32959474836077, 51.24238443374634, 50.18228735242571, 49.75085980551583, 50.99190534864153, 45.052682467869346, 55.98589529309954, 44.8315942628043, 46.858067648751394, 53.07075078146798, 48.457049642290386, 53.45353051594326, 45.87754481179373, 43.96873222078596, 41.47214371817452, 44.38483551570347, 45.63763393674578, 44.37011923108782, 43.61966167177473, 45.017722606658936, 42.06912251881191, 45.138093199048726, 45.095851625714985, 41.080612727573936, 38.745076520102366, 38.14297342300415, 38.44079405920846, 38.95466545649937, 36.56334563664028, 37.01751463753836, 35.34577110835484, 35.975726059504915, 37.367950507572715, 35.90435068947928, 36.845980984824045, 37.45775597436087, 40.43436425072806, 41.56456170763288, 42.68125186647688, 44.160203729357036, 40.2181258882795, 43.780620166233604, 44.70658574785505, 43.629114695957725, 43.91124977384295, 37.36838476998465, 47.70171444756644, 54.883518423352925, 44.15706314359392, 49.13626732145037, 45.227599893297466, 42.93610484259469, 42.61118623188564, 41.49991914204189, 41.60352373123169, 41.66489369528634, 39.23768990380423, 37.958345890045166, 39.26518392562866, 37.72795057296753, 36.197224208286826, 36.37223890849522, 34.79302453994751, 37.284575598580496, 37.633138929094585, 39.55413171223232, 42.05849872316633, 37.66591010774885, 36.424062047685894, 39.004390239715576, 42.03743873323713, 41.67124087469918, 44.13772283281599, 42.03848443712507, 42.637259347098215, 41.173447608947754, 46.03741591317313, 42.459520953042166, 44.13598925726754, 40.43964488165719, 46.5991256577628, 44.930741582598, 46.810323102133616, 52.37728929519653, 49.54238258089338, 51.52106278283255, 48.46022844314575, 51.280189582279746, 49.39221463884626, 50.836567946842735, 46.30466447557722, 45.29215908050537, 50.18461152485439, 51.33969742911202, 51.77691977364676, 49.77218730109078, 52.60899782180786, 52.53381831305367, 53.576874937329976, 51.42787701742989, 51.87471219471523, 50.356975487300325, 51.71073123386928, 49.52672481536865, 49.531331471034456, 53.14408901759556, 53.877613816942485, 57.29327181407383, 51.31372158867972, 50.327306679316926, 17.26375651359558, 0.1790710911154747, 0.2902105131319591, 0.17571980665837014, 0.6716926715203694, 0.7796807597790445, 64.22074045453752, 50.98129197529384, 60.25129018511091, 55.952286856515066, 74.22601440974644, 38.87734242847988, 33.46991729736328, 36.847634656088694, 32.05512162617275, 44.31884152548653, 58.74726922171456, 9.61196596281869, 0.6672150460737092, 0.08124216486300741, 0.0570449275629861, 0.020481696585193276, 0.0848622170409986, 0.12731690465339593, 0.015442615641014916, 0.043382808166955195, 0.08102893523339715, 0.028383917108710324, 0.037796405609697104, 0.05805344094655343, 0.588471491421972, 62.41974653516497, 67.11665930066789, 43.88578462600708, 63.27591051374163, 98.73027501787458, 64.3825431551252, 46.22507286071777, 49.471750668116975, 64.93648828778947, 59.41416427067348, 59.54718058449881, 52.969869886125835, 55.46089288166591, 2.0630517431667874, 0.05310901054846389, 1.271608823112079, 0.11137591861188412, 0.008971852100720363, 0.5973637199827603, 46.37042570114136, 51.57884747641427, 66.0593797138759, 54.755445752825054, 58.25075442450387, 56.59401553017752, 56.52265753064837, 54.00775705065046, 51.911923272269114, 47.83527272088187, 52.335759912218364, 52.116724899836946, 55.007265840257915, 52.406238964625764, 52.309794494083945, 47.541912828172954, 54.217370305742534, 51.990677629198345, 53.588450636182515, 52.8275534084865, 53.042603628976, 45.817255292619976, 54.62895032337734, 47.33294575554984, 48.12135437556675, 52.79001229149954, 51.075902121407644, 53.684860365731375, 48.165194034576416, 45.52687617710659, 42.63510887963431, 46.116743496486116, 47.96300145557949, 49.30352783203125, 46.605976581573486, 46.70827143532889, 46.220657280513215, 47.68755054473877, 47.58168084280831, 45.410070010593955, 41.26053633008684, 40.180056708199636, 41.05229187011719, 41.26900271006993, 39.55140107018607, 38.40211343765259, 38.567070620400564, 36.53236361912319, 39.051089082445415, 37.8916049684797, 38.81485033035278, 40.7080260004316, 40.89930643354143, 43.95001377378191, 45.93738269805908, 44.907152448381694, 42.38469927651541, 45.57668086460659, 46.75848954064505, 44.72056204932076, 45.65870434897286, 38.1432444027492, 48.387095178876606, 53.49627583367484, 47.37582656315395, 51.21431023733956, 45.13166611535208, 44.97379262106759, 44.701492718287874, 44.67536054338728, 45.174998555864605, 43.92608070373535, 41.20259182793753, 40.05588892527989, 41.73143311909267, 40.091501917157856, 37.58759696143014, 37.32724796022688, 35.59787607192993, 37.54728351320539, 41.591642311641145, 41.465758323669434, 42.621309757232666, 40.904555797576904, 40.95777899878365, 42.19913026264736, 46.50217396872384, 43.68855653490339, 47.00937509536743, 45.77600383758545, 47.89963041033064, 44.33959926877703, 48.36723027910505, 43.67698083605085, 44.31459270204817, 42.536260332380024, 50.138617924281526, 47.7726868220738, 48.91169459479195, 53.79281105313982, 53.1032509803772, 52.32731785093035, 51.6606034551348, 54.17322492599487, 51.87440299987793, 51.54284885951451, 47.4282020841326, 48.47284289768764, 51.41439403806414, 53.88810907091413, 53.59074354171753, 53.573512009211946, 54.358022689819336, 57.528714997427805, 55.442525318690706, 54.84142623628889, 56.5582983153207, 52.6171167918614, 53.69318430764334, 54.55021333694458, 53.30528722490583, 54.99670805249895, 57.32138422557286, 60.27799211229597, 55.114987237112864, 57.22872652326311, 19.67165126119341, 0.2816694942968232, 0.5488420064960207, 0.7674591498715537, 0.41986224321382387, 0.7766349517873355, 69.36408192770821, 57.31895930426461, 67.27220167432512, 60.25353445325579, 79.21344525473458, 46.96837377548218, 42.688074997493196, 39.019068309238975, 32.04450477872576, 51.55996227264404, 69.62293011801583, 12.037479604993548, 0.8462570416075843, 0.2736993948263781, 0.10891550992216383, 0.026663004720051373, 0.08014870568045548, 0.27125096906508717, 0.12643020866172655, 0.20793514299605573, 0.2131021057388612, 0.14700078485267504, 0.18730959189789637, 0.18810400712702954, 0.7029121762939862, 72.28387478419712, 76.30480425698417, 50.69920553479876, 74.58248479025704, 99.08289609636579, 69.55637332371303, 54.48474393572126, 57.441918100629536, 72.90759372711182, 63.373998233250205, 63.80582182747977, 57.93940217154366, 61.97497844696045, 2.8036220158849443, 0.1338594885809081, 1.7899917726005827, 0.17942274867423944, 0.08221502123134476, 1.0739258421318871, 52.64301272800991, 45.894415037972585, 57.581271171569824, 59.888872146606445, 57.743171146937776, 58.67926025390625, 56.758722577776226, 56.67140804018293, 54.37660564695086, 48.94267661230904, 54.08477088383266, 54.52747188295637, 56.927654130118235, 53.90528849193028, 53.89500168391636, 48.75466878073556, 54.994967528751914, 54.33519090924944, 55.415635790143696, 54.40349864959717, 55.15167025157383, 48.14350870677403, 52.22756256375994, 51.4314866065979, 50.48962007250105, 54.50229855946132, 53.06415694100516, 57.064967904772075, 51.1966826575143, 46.82687023707798, 46.45449890409197, 49.06508650098528, 51.90321717943464, 53.23787580217634, 50.2345621245248, 49.64642490659441, 48.1100948197501, 51.1312757900783, 48.900490624564036, 48.72928353718349, 45.91900471278599, 44.998462200164795, 45.84740700040545, 44.19036585944039, 42.33603061948504, 41.279018538338796, 41.743311064583914, 38.60760988507952, 41.428901604243684, 39.27992452893938, 41.08524717603411, 42.91944653647286, 45.307879379817415, 46.1279787336077, 46.62286417824881, 49.42659779957363, 43.19437633241926, 47.05353089741298, 49.642054489680696, 48.714751379830496, 47.10864748273577, 40.07991579600743, 50.24271583557129, 57.246770995003835, 49.21242305210659, 54.91828720910208, 48.27586841583252, 48.36608730043684, 48.301288400377544, 47.03400298527309, 46.66444567271641, 46.67784527369908, 42.970147541591096, 43.05648933138166, 42.87753847667149, 42.23896081107003, 40.21079901286534, 39.897640228271484, 37.56608533859253, 40.69286503110613, 41.98211717605591, 44.840230873652864, 48.385319914136616, 45.876089164188926, 43.19682557242257, 45.45464617865426, 50.753193037850515, 47.512629645211355, 52.026318413870676, 49.353190081460134, 51.058031354631694, 47.50018194743565, 51.20449938092913, 45.64097602026803, 49.5216908454895, 44.77485874720982, 52.580635275159565, 51.234560762132915, 51.272814069475444, 56.739462171282085, 56.01561621257237, 53.92975657326834, 54.57511568069458, 56.128555706569124, 54.7093757220677, 54.323292119162424, 48.75610705784389, 48.76267310551235, 54.045412812914165, 55.82464844839913, 55.09597001756941, 56.13314151763916, 55.52432298660278, 58.26157624380929, 57.19270706176758, 56.43437371935163, 59.6981440952846, 55.17918511799404, 58.18572275979178, 55.409924370901926, 55.97680357524327, 59.685477529253276, 57.79687377384731, 63.5658449445452, 58.13364948545183, 61.758382252284456, 22.462377854755946, 0.2411358750292233, 1.3680046562637602, 1.5515826855387007, 1.2364255338907242, 1.0299693665334155, 75.51977593558175, 59.94117818559919, 75.16058186122349, 65.46336323874337, 86.86049365997314, 50.5373854637146, 50.168905121939524, 50.60898665019444, 49.09331355776106, 59.17975984300886, 81.80482455662319, 17.858900989804948, 0.8777581112725394, 0.4512204948280539, 0.16251504022095883, 0.11775751332087175, 0.1179150827229023], [0.07147914517138686, 0.010623616681966399, 0.07964383491447993, 0.10180662745343787, 0.07677498207028423, 0.04010607095967446, 0.226239249376314, 0.08593312171953064, 35.63975286483765, 58.416958808898926, 38.05386277607509, 45.81504576546805, 80.29350798470634, 63.51848602294922, 38.897085734776084, 49.538095542362754, 63.881786482674734, 53.066898005349294, 56.97310924530029, 49.70389345714024, 57.17618424551827, 8.001156398228236, 0.5324239560535976, 1.4831937381199427, 0.6384696971092905, 0.31168734069381443, 0.32486810056226595, 28.55674706186567, 42.943400451115195, 40.729200635637554, 53.54513904026577, 52.67202145712716, 58.420009068080354, 50.882599762507844, 53.58252034868513, 48.512211390904014, 50.431599140167236, 51.11087587901524, 54.01513951165335, 49.398228304726736, 53.01156602587019, 47.61726256779262, 46.35796758106777, 55.01199408939907, 52.014680181230815, 47.72951419012887, 50.955173696790425, 48.3432867867606, 54.806556701660156, 44.51536437443325, 40.74812405450003, 55.54671008246285, 51.125929151262554, 51.48333753858294, 51.129274708884104, 44.47370644978115, 45.37558957508632, 44.265566212790354, 44.03451429094587, 48.17210749217442, 41.175361837659565, 44.619806221553254, 45.38910729544503, 46.73935072762625, 46.95983443941389, 45.52693176269531, 43.25755282810756, 38.28368834086827, 37.87959500721523, 40.73319237572806, 37.3461366380964, 37.03713982445853, 36.46653985977173, 37.90776995250157, 36.29713582992554, 35.81362458637783, 34.61985458646502, 38.09105995723179, 36.75497695377895, 40.618022509983604, 40.480316162109375, 40.31717940739223, 43.089805943625315, 44.61050258363996, 44.23557778767177, 42.08760472706386, 43.67020981652396, 46.83323131288801, 44.33023657117571, 46.10406303405762, 49.61532824380057, 48.95512778418404, 44.87061187199184, 49.98823111397879, 41.190401213509695, 42.12622281483242, 40.971553802490234, 44.59587662560599, 41.133179324013845, 40.340025084359304, 39.053225653512136, 37.94748932974679, 36.75423697062901, 36.07704816545759, 37.78696162360055, 36.903578077043804, 38.235398360661094, 40.7629063470023, 40.91512748173305, 37.90018946783883, 39.158133029937744, 36.734889711652485, 37.53315782546997, 42.53833089556013, 42.298993246895925, 42.88450057165963, 42.99824258259365, 42.482356207711355, 44.49668066842215, 46.54711144311087, 42.02067273003714, 43.281590121132986, 42.147425242832725, 45.567957401275635, 46.64012350354876, 47.989623478480745, 48.727869578770225, 51.368299688611714, 49.99181638445173, 51.70375524248396, 48.47246074676514, 56.47970029285976, 48.84362309319632, 46.19385807854788, 49.74943889890398, 53.20238092967442, 48.977400234767366, 51.863945960998535, 52.78699329921177, 53.97569458825247, 53.49436160496303, 52.45347629274641, 54.75834662573678, 52.52848904473441, 52.39200905391148, 50.5760452406747, 53.741189411708284, 52.141738414764404, 52.78062527520316, 53.02235657828194, 61.273411887032644, 52.085819312504356, 53.01074266433716, 7.967603547232492, 0.32930208263652666, 1.786855963724, 0.6714196833116668, 0.08030648542834179, 4.448122961180551, 70.79333332606724, 42.91923809051514, 59.15467684609549, 54.01583085741316, 72.69723701477051, 31.956599644252233, 34.806156635284424, 33.757819380079, 26.40861071859087, 49.004310607910156, 52.495988845825195, 4.537887607301984, 0.45573799099240986, 0.0196025289395558, 0.12119662735079016, 0.11880639275269848, 0.016622621965195452, 0.140199977638466, 0.07370109629950353, 0.031249126219855886, 0.0393673125654459, 0.06968695776803152, 0.03138365935800331, 0.15067589336207934, 0.24241249795470918, 42.499702385493684, 71.05155617850167, 41.027719565800254, 50.97333628790719, 86.82327216012138, 67.0389506476266, 47.83830908366612, 57.307321071624756, 68.86606284550258, 57.850069182259695, 61.70417240687779, 55.396972928728374, 62.21090453011649, 7.832053746495928, 0.5690854745251792, 2.233754651887076, 0.41242395234959467, 0.8315192610025406, 0.26170395421130316, 28.968438250677927, 49.00681890760149, 50.508866582598, 53.55445657457624, 56.009432315826416, 59.770523480006624, 53.48557908194405, 56.514319692339214, 50.09078305108206, 51.31841162272862, 52.88692923954555, 53.838905402592246, 53.51022434234619, 54.65914372035435, 48.92439242771694, 47.55578490665981, 56.43420001438686, 53.535686016082764, 50.16596950803484, 53.786370073046, 51.460012435913086, 51.26102992466518, 45.652937344142366, 43.59894214357649, 55.56089135578701, 53.02889135905674, 53.07039989743914, 52.26541634968349, 45.40423699787685, 45.76283005305699, 45.0807705606733, 45.60109336035592, 50.806193896702354, 44.64635181427002, 47.40535988126482, 47.99474777494158, 48.341007777622764, 49.09379645756313, 49.919659342084614, 45.376850673130576, 41.19221469334194, 41.65576376233782, 42.319959436144146, 40.991258893694194, 40.26811122894287, 38.44340310777937, 37.84294673374721, 38.01391758237566, 37.28592354910714, 36.27528027125767, 40.56528915677752, 38.894223076956614, 41.69852992466518, 42.90125962666103, 42.82446118763515, 43.94120693206787, 46.36281394958496, 47.05965573447091, 43.9208973475865, 46.34151772090367, 49.98570196969168, 45.11430951527187, 49.6585807800293, 50.253603662763325, 50.08032948630196, 46.83419711249215, 51.23701695033482, 44.051520006997244, 43.814252921513145, 42.69652053288051, 46.92375939232962, 43.585160391671316, 43.32466547829764, 41.33491332190377, 39.33857774734497, 37.54047080448696, 38.08085305350167, 37.75834199360439, 37.05717495509556, 39.48131111689976, 43.89080817358834, 41.58129644393921, 40.89184059415545, 40.480614934648784, 39.268685817718506, 42.48217208044869, 45.33001981462751, 46.12952470779419, 44.94800785609654, 44.5543646131243, 46.29165744781494, 46.38508987426758, 49.26136268888201, 42.797922543116975, 45.523151942661826, 43.36587177004133, 47.22935158865792, 48.70731680733817, 49.19667843409947, 50.663144384111675, 50.67700604030064, 50.67164897918701, 50.602208682468955, 51.63179622377668, 56.17045681817191, 50.592005252838135, 46.26990611212594, 52.22425869532994, 54.53349944523403, 51.49606316430228, 52.60179948806763, 53.392344679151265, 55.322901657649446, 53.37578364780971, 54.19199895858765, 56.85158177784511, 57.06701067515782, 55.47630051204136, 51.94789409637451, 54.80288805280413, 54.08926984242031, 56.113217558179585, 55.05790778568813, 64.75061702728271, 54.835402148110525, 55.848817757197786, 10.091748629297529, 0.33892788897667614, 1.488341810447829, 1.2881302280085427, 0.07713386602699757, 5.12658372095653, 77.98742171696254, 45.70569154194423, 64.87534414018903, 60.22442150115967, 80.00581782204765, 37.548304898398264, 42.19695200238909, 40.9800306047712, 31.54316098349435, 56.351314953395296, 61.23998410361153, 6.636701728616442, 0.45175488186734064, 0.12621052616408893, 0.1533063564981733, 0.03879766206123999, 0.04541988903656602, 0.25731926092079704, 0.11783519200980663, 0.21933272640619958, 0.21656937897205353, 0.19474212878516742, 0.152568517518895, 0.288288874817746, 0.4817841276526451, 51.50311211177281, 81.53969519478935, 52.93970080784389, 58.8181825365339, 84.81066390446254, 71.66592284611293, 50.895419188908164, 61.15307603563581, 75.9106468473162, 63.09909970419747, 67.03882558005196, 61.316622734069824, 69.3862258366176, 9.965150713920593, 0.5940050259232521, 4.13668646131243, 1.1870857243027007, 1.1444038088832582, 0.4208057325865541, 35.148563861846924, 45.19919913155692, 41.47038582393101, 56.7669666154044, 56.15241929462978, 62.960545676095144, 55.56044667107718, 57.346088545663015, 52.36630071912493, 54.63031564440046, 54.96199137823922, 56.85919005530221, 53.61583696092878, 55.92076982770647, 50.24493925912039, 49.201743670872276, 59.708705357142854, 55.93688270023891, 52.757025718688965, 54.94151851109096, 53.64888606752668, 50.07232863562447, 51.18087203162057, 46.49569477353777, 56.054682459150044, 57.709538391658235, 56.26420538766043, 57.22899750300816, 49.40352978025164, 48.63185589654105, 47.88347932270595, 47.423036098480225, 53.72809205736433, 47.43247870036534, 51.79874406542097, 52.211908272334504, 49.52324724197388, 52.26889739717756, 54.39990643092564, 49.746482440403526, 44.322103704724995, 45.249465874263215, 46.57772520610264, 44.439858300345286, 44.758210863385884, 40.71292100633894, 42.040211064474924, 41.46651567731585, 38.715077672685894, 38.048634256635395, 43.87237112862723, 40.42542886734009, 45.053471088409424, 45.05562155587332, 44.41066891806466, 47.23648738861084, 49.49920647484915, 46.581553663526265, 46.630243165152415, 49.98675462177822, 50.93472514833723, 48.37703766141619, 52.83421673093523, 56.83232137135097, 51.463510853903635, 49.55300637653896, 53.66252885546003, 45.74948256356375, 47.49287591661726, 46.13830028261457, 47.13370268685477, 47.42253582818167, 44.84529611042568, 44.08067464828491, 40.64673246656145, 40.127316406794954, 39.00016573497227, 40.923517431531636, 40.69937549318586, 41.90312658037458, 47.126497404915945, 46.296753951481406, 44.29664550508772, 45.8324544770377, 41.824639729091096, 45.94926411764962, 51.063614232199534, 51.01403188705444, 47.52862092426845, 48.00048003877912, 50.577556473868235, 51.3651556287493, 52.58257729666573, 46.839863368443076, 48.22003616605486, 46.25759390422276, 49.74337659563337, 50.6009475844247, 53.56098788125174, 52.73275218691145, 53.63190814426967, 51.31426354816982, 49.06282833644322, 52.78943906511579, 57.3640079498291, 48.109684876033235, 45.288775307791575, 53.36740412030901, 58.2349785396031, 51.661673477717805, 55.245766230991904, 56.3834399495806, 57.71058756964547, 56.42127636500767, 55.505319663456504, 60.77596255711147, 58.46592971256801, 58.13937132699149, 53.24117967060634, 58.58855152130127, 55.662588664463584, 58.4528740474156, 58.530999592372346, 68.66104234967912, 58.28084012440273, 61.47693852015904, 12.746794274875096, 0.38884567469358444, 3.8675371323313033, 2.709058335849217, 0.18874644408268587, 5.578218800680978, 84.23173999786377, 51.34877177647182, 70.34376403263637, 63.936246463230674, 86.26944514683315, 40.68067789077759, 52.21031018665859, 48.06496974400112, 43.35401119504656, 62.724112374441965, 74.95531817844936, 11.52240182672228, 0.6212515181728772, 0.30833239214760916, 0.1803809893982751, 0.2525258724178587, 0.1451501077307122], [0.10320801261280264, 0.029667895353798355, 0.10322047730109521, 0.036357796019209285, 0.176036465380873, 0.08987082328115191, 0.306424650230578, 0.15383175973381313, 27.181462321962627, 62.0324261529105, 41.45589882986886, 38.822687898363384, 40.87548106057303, 54.96248470033918, 29.660932200295584, 44.0635438646589, 61.28017943246024, 53.88481909888131, 55.25869682856968, 49.97945553915841, 54.719124044690815, 17.51840451785496, 0.8637523342456136, 2.695164978504181, 0.5313913343208176, 0.5934993273445538, 0.5445528509361404, 14.348402687481471, 41.489965847560335, 39.203563826424734, 58.01450525011335, 52.27211441312517, 59.354243006025044, 52.538101877485005, 53.207498277936665, 48.83483362197876, 52.45327132088797, 52.05940573556082, 55.54332978384835, 53.29010888508388, 52.90987566539219, 48.00901937484741, 52.74102749143328, 53.39735780443464, 51.41329622268677, 45.08288628714425, 50.70725849696568, 54.69648681368147, 44.52203117098127, 37.516489097050254, 54.93874270575387, 49.20686796733311, 50.045772620609824, 49.01389912196568, 48.911586897713796, 43.72200863701956, 46.491188866751536, 43.098168100629536, 43.837373052324565, 45.54025840759277, 42.40628038133894, 44.44985328401838, 46.66559559958321, 43.511446952819824, 46.25306715284075, 44.21742909295218, 41.477577209472656, 39.18728767122541, 38.4357670375279, 37.28915793555123, 34.76054865973336, 31.487050805773052, 34.07461902073452, 35.58044304166521, 37.57337052481515, 36.51709147862026, 37.36906916754586, 39.30637632097517, 37.095681871686665, 36.85678890773228, 38.22752257755825, 41.19679355621338, 42.78594732284546, 43.13109908785139, 39.79812117985317, 42.30563572474888, 50.28962312425886, 52.623887811388286, 48.67208249228341, 52.0183870451791, 38.489681584494456, 45.06260449545724, 46.632609026772634, 43.53259726933071, 48.81807109287807, 43.97252246311733, 43.379069873264854, 42.371640137263704, 43.726813316345215, 41.29179627554757, 38.322188309260774, 33.98434802464077, 38.113863945007324, 36.34901802880423, 36.29251875196184, 38.00907816205706, 37.08680902208601, 39.600264276777, 38.877894810267854, 37.52355194091797, 38.49320432118007, 35.75831345149449, 43.47514608928135, 42.86452797480992, 44.05533109392439, 44.36407777241298, 45.25200196674892, 42.79942682811192, 44.8217590876988, 45.899181502205984, 41.22571890694754, 42.687515667506624, 43.16389805930001, 42.912161350250244, 46.714948654174805, 48.44401829583304, 49.55194330215454, 52.026968070438926, 51.0009970664978, 50.453652722494944, 49.540770598820274, 36.167458125523154, 36.92206028529576, 46.757773876190186, 49.17119244166783, 50.12116057532174, 49.876424176352366, 50.68299886158535, 50.93055970328194, 52.332629748753135, 46.4788384437561, 49.16655451910836, 54.758989334106445, 53.56344059535435, 54.81149687085833, 53.8527010508946, 54.228869574410574, 52.776129790714805, 55.257633754185264, 58.13465002604893, 57.90273305347988, 49.708573068891255, 50.52709518160139, 2.059744183506284, 0.21047032624483109, 0.6414915121027401, 1.393535052027021, 0.10618940048984118, 12.278724534170967, 66.4058585848127, 49.21328115463257, 61.847485951014924, 55.987958908081055, 64.82094669342041, 27.83827379771641, 50.923729624067036, 19.639790296554565, 31.37644590650286, 48.32016665594918, 42.19155672618321, 1.395714289375714, 0.11284011575792517, 0.08084541865225349, 0.12125872687569686, 0.04149396005751831, 0.045287001345838816, 0.05133318601708327, 0.03599538368039897, 0.08326721869941268, 0.01913967984728515, 0.07373386275555406, 0.09660303739032575, 0.22533953908298696, 0.1387422808579036, 32.912661348070415, 73.57057694026402, 43.71107564653669, 42.73741068158831, 55.045185634068076, 60.01467623029436, 37.01839358466012, 47.47636352266584, 63.980985913957866, 60.36349664415632, 59.82341316768101, 56.01847539629255, 60.32428101130894, 20.420347452163696, 0.8175775376813752, 4.363630260740008, 0.2785903295235974, 1.1456908541066306, 0.4773350549595696, 16.4378137247903, 49.6976991380964, 45.99121734074184, 56.222669056483674, 55.01696899959019, 61.1158058983939, 53.86821290424892, 55.359320640563965, 51.102718693869456, 53.533747468675884, 53.95690318516323, 57.47258397511074, 54.777058124542236, 52.49731247765677, 48.84501620701381, 56.698488644191194, 54.936838899339946, 53.04290587561471, 47.71755634035383, 51.30004753385271, 53.28904928479876, 45.50797707693917, 39.46945401600429, 56.37998669488089, 52.38039166586739, 50.3662964957101, 51.43788937159947, 49.828016076769146, 45.44181285585676, 48.058115346091135, 44.79182972226824, 45.29647043773106, 47.812812668936594, 45.19653102329799, 47.18043974467686, 46.408703327178955, 47.8477760042463, 48.89404617037092, 47.10222387313843, 45.83430617196219, 41.98755761555263, 40.881703172411235, 40.821017605917795, 38.55642598015921, 33.9829340662275, 38.04594530378069, 39.45238924026489, 39.038116795676096, 37.54601894106184, 37.03939798900059, 39.62756027494158, 38.78231886454991, 39.28867925916399, 40.36599745069231, 42.378862789699006, 44.332856042044504, 43.94421202795846, 41.68651648930141, 45.35296624047415, 52.71378707885742, 53.54683787482125, 50.31783281053816, 53.59708377293178, 43.03476926258632, 46.82262488773891, 47.43671710150582, 46.64226702281407, 51.22075816563198, 44.55174166815621, 46.06691449029105, 43.36086211885725, 44.275307587214876, 42.531653676714214, 39.55402054105486, 35.67162772587368, 38.83656692504883, 38.44086006709507, 38.24835327693394, 40.403232846941265, 39.369476386478965, 43.172479084559846, 41.2587228502546, 41.657320158822195, 42.584307125636506, 40.14739670072283, 46.26541757583618, 45.23293610981533, 45.58630411965506, 46.71508066994803, 48.847100666591096, 45.928089482443674, 47.85493959699358, 49.448856353759766, 43.53920153209141, 45.617685658591135, 45.44021129608154, 43.98590121950422, 50.68185935701643, 47.07967349461147, 51.48843056815011, 51.96018545968192, 50.46258463178362, 46.93894815444946, 49.49993256160191, 40.30388055528913, 39.14882591792515, 48.428145136152, 51.133023262023926, 52.46611854008266, 50.87476914269583, 51.77668353489467, 54.33051129749843, 55.773888383592876, 49.54593311037336, 50.9223747253418, 57.151406969342915, 55.0847521509443, 57.080379009246826, 55.56376096180507, 58.20442383629935, 55.12848063877651, 57.723559856414795, 59.298254421779085, 61.63824789864676, 53.595926897866384, 55.087177072252544, 2.7604435213974545, 0.3052278773060867, 1.8326110456671034, 2.019312615905489, 0.10435029238994632, 13.628409504890442, 74.69925621577671, 51.31661203929356, 69.16019398825509, 62.98439189365932, 73.22423703329903, 30.23477349962507, 53.507792472839355, 32.98040281023298, 37.39365884235927, 53.90135581152779, 53.43705633708409, 1.616921590907233, 0.14169835937874659, 0.09684412766780172, 0.02364229064966951, 0.08970508431749684, 0.06992331865642752, 0.21085405136857713, 0.11006985405193907, 0.19322611870510237, 0.17505998563553604, 0.25105046587330954, 0.15091435770903314, 0.41978784863437923, 0.1925299824880702, 38.48807307652065, 85.14699145725795, 53.55412653514317, 51.06181117466518, 53.627044405256, 67.94145216260637, 41.670584269932334, 56.134541579655235, 70.6315723146711, 66.72094549451555, 64.54852867126465, 60.04929910387312, 63.665287562779014, 22.741353239331925, 1.3106484711170197, 6.6320677144186835, 1.684047268969672, 1.8980179131031036, 0.5961334545697484, 21.51381152016776, 49.255501883370535, 39.39828709193638, 59.02427305494036, 56.20936325618199, 63.087322507585796, 57.24006945746285, 57.32093606676374, 52.74040910175869, 56.22988476072039, 54.6401230267116, 58.498961448669434, 57.40608971459525, 54.8521021434239, 48.98574849537441, 56.17911774771554, 57.25720371518816, 56.223211015973774, 48.94972208568028, 54.02815348761422, 55.658371107918875, 49.527919905526296, 44.60712923322405, 57.60640627997262, 56.09570114953177, 52.011112281254356, 53.2813333102635, 52.48959302902222, 48.03708662305559, 49.85628134863717, 46.38327986853463, 47.29292760576521, 49.64354487827846, 48.20864806856428, 51.48906980242048, 50.93684434890747, 49.13281406675066, 52.061483246939524, 50.44035039629255, 49.73908608300345, 46.69086619785854, 45.182280267987935, 45.121205602373394, 41.957993030548096, 38.36286653791155, 41.951322759900776, 41.89402791431972, 42.948469161987305, 40.89028072357178, 38.619901248386924, 42.98724705832345, 42.012025696890696, 39.90432786941528, 41.79756607328142, 45.520862511226106, 47.072996275765554, 46.49077544893537, 44.603300775800435, 46.57966027941023, 55.40376131875174, 55.8675605228969, 52.40752438136509, 56.61479411806379, 47.549288340977256, 50.056594439915244, 49.1169548034668, 49.994863169533865, 52.64011532919747, 48.6292850630624, 46.92988075528826, 45.6192490032741, 46.286644322531565, 45.52830055781773, 41.01735980170113, 36.26039375577654, 41.32719039916992, 39.69391557148525, 42.49839959825788, 43.487729276929585, 44.842308385031565, 46.00625671659197, 44.805305753435405, 44.73372541155134, 45.84233134133475, 42.27770744051252, 48.06783240182059, 50.184941564287456, 48.917020389011924, 50.48733064106533, 50.675029277801514, 47.33271646499634, 52.46989141191755, 54.35963814599173, 46.95035362243652, 48.94008493423462, 48.06425755364554, 46.02005236489432, 52.331903662000386, 50.85243763242449, 54.78158835002354, 56.56919309071132, 54.50298295702253, 50.766766343797954, 48.39543996538435, 38.401425565992085, 41.541837624141145, 50.710128102983745, 53.60164526530674, 55.631592750549316, 54.8047536441258, 54.362316676548545, 57.56620052882603, 57.966864926474436, 52.17767449787685, 53.61968278884888, 58.48489134652274, 57.55931486402239, 59.65744849613735, 57.478538581303184, 61.63555894579206, 55.8615677016122, 59.39728709629604, 61.85987458910261, 65.55086190359933, 57.10064343043736, 60.651589802333284, 3.8344771691731045, 0.2752044126391411, 2.436601664338793, 2.9743650938783373, 0.2398323006927967, 14.475379279681615, 82.00723252977643, 56.69243328911917, 73.9328977039882, 66.48879923139299, 77.69050434657505, 39.85244567053658, 69.68993854522705, 28.146714755467006, 46.60751213346209, 60.91524614606585, 68.70715754372733, 2.9793271933283125, 0.3452715671488217, 0.2008397023060492, 0.20038650876709393, 0.12212679029575416, 0.18582379019686154], [0.06938420901341097, 0.07065606183771576, 0.032437376744513, 0.028699317148753574, 0.09385967281247888, 0.028399581089615822, 0.11564334748046738, 0.14732102624007634, 7.87417459487915, 63.7820520401001, 41.464163712092805, 34.24436698641096, 18.09503378186907, 45.43254395893642, 32.647698743002756, 47.078964778355186, 63.15498406546456, 52.62199790137154, 55.96880619866507, 48.26921204158238, 53.37492554528372, 24.850289583206177, 0.6282261524881635, 0.9142404964991978, 0.25401001849344795, 1.3896326614277703, 0.34737288153597284, 7.281319984367915, 41.086470058986116, 39.889778341565815, 58.388353075299946, 52.133695874895366, 60.44578416006905, 51.0674010004316, 53.75239338193621, 50.965179102761404, 53.56914506639753, 51.875191620418, 52.407183919634136, 50.829032625470845, 50.789705821446006, 49.127936431339805, 51.7156331879752, 48.927390575408936, 46.222588879721506, 44.4894962310791, 50.62943172454834, 49.77595322472708, 43.389200346810476, 51.2533278465271, 52.21765790666853, 50.342964444841655, 48.98707907540457, 43.04637622833252, 46.821794578007285, 44.15544768742153, 46.30837133952549, 42.70697757175991, 44.67713928222656, 45.413790770939414, 46.46868712561471, 45.140611921037944, 45.27529580252511, 44.510507583618164, 45.65016153880528, 43.013907296316965, 43.168525559561594, 38.87229108810425, 37.079568999154226, 37.98012154442923, 35.955951486315044, 31.15661879948207, 30.522373335702078, 32.528835909707205, 37.080621651240754, 35.944247245788574, 38.62252071925572, 39.76050015858242, 38.20137998035976, 36.79257713045393, 36.18307767595564, 39.060899938855854, 41.3956857408796, 39.646963119506836, 42.221781390053884, 44.5271554674421, 50.60662078857422, 46.89751952035086, 48.24989604949951, 49.692981311253135, 50.802080563136506, 35.99494130270821, 47.38557488577706, 45.5293219430106, 40.58626576832363, 44.03575107029506, 40.48080948420933, 42.09476831981114, 41.717012132917134, 40.70424270629883, 38.65190117699759, 37.59078271048409, 38.43974488122122, 36.302621432713096, 37.47849287305559, 36.2879398890904, 36.92080266135079, 34.755573749542236, 37.43673767362322, 39.472577231270925, 35.512520926339285, 39.45979254586356, 43.820454188755576, 47.54324688230242, 44.80978386742728, 46.802099909101216, 44.799243450164795, 42.70097085407802, 42.37797342027937, 44.865647384098594, 41.43692329951695, 43.8174421446664, 43.594731535230366, 39.43898269108364, 41.98339564459664, 44.419249943324495, 46.51159225191389, 47.998458112989155, 48.73376859937395, 38.00918933323452, 25.96159836224147, 31.115190165383474, 51.95495694024222, 50.907717500414165, 50.02659559249878, 50.665572779519216, 51.42427437646048, 48.0897331237793, 50.309623513902935, 52.90958731515067, 53.51806538445609, 39.654765946524485, 53.501059668404714, 54.714819635663716, 55.87079838344029, 51.42117200578962, 53.697464397975374, 53.10673202787127, 56.186295236860005, 49.88683952604021, 54.281787054879324, 51.35328115735735, 55.893039567129954, 0.6227302902511188, 0.11967769957014493, 1.4533856404679162, 1.4849104859999247, 0.08326888111020837, 25.11807141985212, 63.97187682560512, 55.516263076237266, 59.97799668993269, 55.54886402402605, 44.14533805847168, 28.49804868016924, 52.57156440189907, 22.201035261154175, 32.61521938868931, 52.39198126111712, 38.948231424604145, 0.40432645114404814, 0.02384442283904978, 0.09464657665895564, 0.09180803397404295, 0.04102211019822529, 0.04579113590131913, 0.02208049811555871, 0.05716772883066109, 0.02794169887368168, 0.03653625072911382, 0.08008125251425163, 0.08888466762644903, 0.16143276329551423, 0.2445332184433937, 10.096786073275975, 77.3794890812465, 49.387201513562886, 39.44710166113717, 32.94156238010952, 58.256590911320274, 34.895097051348, 55.632919856480186, 66.08769362313407, 60.09324645996094, 61.211816106523784, 53.89359467370169, 56.44575139454433, 28.31624906403678, 0.6559680295842034, 1.3071230202913284, 0.6397249326109886, 1.0125877963645118, 0.34717618780476706, 7.9460024663380215, 49.70030818666731, 46.1933091708592, 58.31026921953474, 54.29971688134329, 60.94866698128836, 55.284311362675254, 55.32236664635794, 52.202382292066304, 56.17243010657174, 54.099452427455354, 53.09042807987758, 53.573612758091514, 50.67696435110909, 51.83636508669172, 53.53002323423113, 52.51507207325527, 47.21064356395176, 48.06861407416207, 52.142537457602366, 50.9355137688773, 45.58110339300973, 51.84300409044538, 53.01422371183123, 50.78805562428066, 51.76554209845406, 44.2783647945949, 47.18713433401925, 44.68849958692278, 48.408745765686035, 44.141381059374126, 46.119383811950684, 46.98837763922555, 48.03555454526629, 47.34707839148385, 48.77273757117135, 46.57312549863543, 47.02647808619908, 46.17930160249983, 45.76316704068865, 41.48297595977783, 41.48390701838902, 40.31722457068307, 38.64631829942976, 36.70667307717459, 35.11124161311558, 37.23788717814854, 38.65793221337454, 37.034214632851736, 38.94224207741873, 40.67349345343453, 39.06292881284441, 39.84755413872855, 38.549321447099956, 39.99933058874947, 43.893660409109934, 41.06115082332066, 41.617350646427695, 48.30666978018624, 51.588356086185996, 48.68441207068307, 49.19308621542794, 50.71397393090384, 52.160957132067, 43.00146654673985, 48.749721663338796, 45.156262738364084, 42.53752490452358, 46.344887597220286, 42.72791249411446, 44.78379760469709, 43.723485129220144, 41.98893335887364, 40.00566734586443, 38.05798653193882, 39.66355889184134, 37.95859949929373, 38.6795654296875, 38.94378457750593, 39.55884606497628, 37.435087476457866, 40.94674873352051, 43.006642954690115, 38.680076122283936, 41.72445017950875, 45.8125513621739, 48.95671544756208, 47.68882553918021, 48.31793281010219, 47.883659975869314, 46.98227364676339, 45.535352979387554, 48.724294730595176, 44.40536049434117, 44.81298003877912, 46.30531760624477, 41.38789333615984, 44.45746156147548, 47.59247139522007, 47.44835533414568, 48.958647046770366, 51.159784248897004, 41.717727797372, 29.362055437905447, 33.81906427655901, 52.9280104637146, 51.890536717006135, 54.86198248182024, 52.532518999917166, 52.277269976479666, 49.966024671282085, 53.37305300576346, 53.17896897452218, 56.968335832868306, 44.0463262285505, 54.79064185278756, 56.78663349151611, 57.00003351484026, 55.41910988943917, 55.92968436649868, 57.38147572108677, 58.23492642811367, 53.3482722554888, 58.79615674700056, 54.52631500789097, 57.51305375780378, 0.9560106779847826, 0.3320598932249205, 1.915529979126794, 2.2573585510253906, 0.11098394250231129, 25.745137657438004, 71.20527812412807, 58.567366463797434, 67.75943715231759, 58.826895577566965, 53.297004972185405, 28.971307856695994, 63.527150426592144, 24.77671684537615, 30.625498499189103, 63.22101974487305, 45.12951912198748, 0.26002775558403557, 0.024952087152217115, 0.048372646128492694, 0.04136047864864979, 0.037749902212194035, 0.040531997568905354, 0.1658449372542756, 0.1358110231480428, 0.16726797446608543, 0.1215202207011836, 0.17576049161808832, 0.1760193934398038, 0.24982500448822975, 0.3959010275346892, 11.198156322751727, 92.85519095829555, 57.322832924979075, 50.32181065423148, 26.754021303994314, 63.20314202989851, 42.84720958982195, 57.344535623277935, 73.2727632522583, 64.83115359715053, 65.60359873090471, 60.70331219264439, 62.070578711373464, 31.7552547454834, 0.8311012291482517, 1.8501309284142085, 1.011423104575702, 4.045273789337703, 0.3485833608678409, 9.884600247655596, 50.520171301705496, 41.432368755340576, 61.32565539223807, 55.87122917175293, 64.16045788356236, 56.72402327401297, 58.03536374228341, 54.24672644478934, 56.777715478624614, 55.522103037152974, 55.45858955383301, 56.456997053963796, 53.07322086606707, 51.365607261657715, 53.74558414731707, 53.13883965356009, 49.012078693934846, 49.40569067001343, 55.33452251979283, 54.740302153996055, 47.61561584472656, 54.291743823460166, 55.783080850328716, 54.556862762996126, 53.35161781311035, 45.539375986371724, 49.364981174468994, 47.61687694277082, 51.32324409484863, 48.396464824676514, 49.61508853094918, 48.41987330572945, 53.011381898607524, 50.8355257170541, 53.08716937473842, 50.523377895355225, 50.75631625311715, 50.0533253124782, 48.84979656764439, 45.029437269483296, 43.63051128387451, 43.38348545346941, 44.70323324203491, 40.18872806004116, 38.29133135931832, 40.13477182388306, 42.4122245652335, 40.171121324811665, 42.79391343252999, 44.30210331508091, 41.977517468588694, 41.05155536106655, 38.52271332059588, 42.744261605399, 46.999456541878835, 44.34755148206438, 45.19493988582066, 49.342531544821604, 55.85965347290039, 49.35543434960501, 51.49009813581194, 52.95722416469029, 56.4712095941816, 47.995994976588655, 53.46387638364519, 47.767517362322124, 43.986443178994314, 49.09308079310826, 46.8682849747794, 47.54147856576102, 47.06217098236084, 44.67788968767439, 40.219717025756836, 41.651910986219136, 42.493581022535054, 41.30667584283011, 42.88219376972744, 41.48037385940552, 43.66422046933855, 43.12218802315848, 45.25915861129761, 46.908654008592876, 41.91149568557739, 45.33489050183977, 51.24092878614153, 54.52010679244995, 50.36490338189261, 52.19801882335118, 49.074539525168284, 48.98660659790039, 48.558298792157856, 52.27063792092459, 47.35596513748169, 49.093268394470215, 48.91526249476841, 43.81923130580357, 45.534383705684114, 49.184807436806814, 49.20927204404558, 50.564393111637656, 53.434860706329346, 45.32247059685843, 30.341525622776576, 34.924296855926514, 55.64238677706037, 54.587295872824534, 56.633825234004426, 54.39085987636021, 53.797049454280305, 52.66888434546334, 57.07442787715367, 57.12491001401629, 56.63504811695644, 44.00808334350586, 57.01873459134783, 59.0087160382952, 62.09413310459682, 56.47178282056536, 59.682691301618306, 59.32594299316406, 64.0004825592041, 55.30640663419451, 61.70896666390555, 55.95324223382132, 59.95091956002371, 1.1888166942766734, 0.6472981433783258, 3.468751136745725, 3.2537059102739607, 0.15618486489568437, 28.517322983060563, 77.88502611432756, 62.99814237867083, 75.46625396183559, 65.26108728136334, 60.03134495871407, 37.69328948429653, 68.331725529262, 30.332364422934397, 46.9157064301627, 69.05230930873326, 61.82285458700997, 1.0085765144654681, 0.1529084907046386, 0.1682271651391472, 0.1858936385916812, 0.09217012061604432, 0.09624209068715572], [0.03561647276261023, 0.043301037911857874, 0.0546745367215148, 0.0733557084043111, 0.13236656226217747, 0.02345844328270427, 0.04511005637635078, 0.01884890384306865, 0.5760983782155173, 45.7920298576355, 44.692275932856965, 36.813154220581055, 20.752839599336895, 29.711237158094132, 37.01268911361694, 38.3422338621957, 64.36299092429024, 51.61361973626273, 60.86444091796875, 50.15530749729702, 52.09548078264509, 30.564809458596365, 0.13270986026951245, 0.3568224859024797, 1.021596787231309, 1.8120308071374893, 0.0783780278371913, 1.383850783109665, 33.65408624921526, 40.591775689806255, 58.77786214011056, 51.40147386278425, 56.56868587221418, 48.63802589688982, 52.56497056143624, 50.37626368658883, 55.06789582116263, 51.557544299534385, 54.07856614249093, 47.68098797116961, 51.38274499348232, 50.11687353679112, 53.808677264622276, 46.86574193409511, 46.857108797345845, 46.86356367383684, 54.94378709793091, 48.26395920344761, 49.98172412599836, 50.49025583267212, 51.46481016704014, 46.23214265278408, 43.62797866548811, 41.547198159354075, 43.459540435246055, 41.619066851479666, 46.91503592899868, 42.27665131432669, 42.16682461329869, 46.81668070384434, 44.464416708265034, 46.41161462238857, 43.03186838967459, 46.15640033994402, 43.78397267205374, 45.40690163203648, 42.942028181893484, 41.73789841788155, 38.4979464667184, 35.295733656202046, 38.81626081466675, 32.80093084062849, 27.675616468702042, 28.833528552736553, 34.3354127066476, 38.07608658926827, 36.08832161767142, 37.84791122164045, 37.60483544213431, 38.22974600110735, 38.57847261428833, 39.21023409707205, 41.19824225561959, 47.245905671800884, 42.92327151979719, 45.78455707005092, 49.92925133023943, 37.693268639700754, 41.46864530018398, 41.95772899900164, 46.32422712871006, 42.508682932172505, 32.22143370764596, 44.51088278634207, 43.864220891680034, 41.49950572422573, 44.37688677651541, 39.538366249629426, 41.65840755190168, 38.187956060682026, 37.61444132668631, 37.814264569963726, 38.060397556849885, 37.71628107343401, 38.103702204568044, 36.24713659286499, 34.71633379799979, 32.3117116519383, 37.95681381225586, 36.2997726712908, 39.84453862054007, 39.86254487718855, 43.83470146996634, 44.74485642569405, 46.60599742616926, 43.94593170710972, 41.21965660367693, 41.46769339697701, 43.340535163879395, 44.75536905016218, 41.6498612676348, 42.746144567217144, 44.49213307244437, 39.71432590484619, 41.067063740321565, 40.92789479664394, 47.27094350542341, 46.030624049050466, 52.82367283957345, 54.60703917912075, 41.57402515411377, 49.01475722449166, 51.65129634312221, 48.171753134046284, 48.43266841343471, 47.53060116086687, 52.19414867673601, 45.22374711717878, 51.91089493887765, 50.63215889249529, 56.94026511056082, 42.84925236020769, 40.62173284803118, 51.62406635284424, 52.848922593253, 50.98135798318045, 53.50050728661673, 48.742321831839426, 55.05095263889858, 54.28419460569109, 58.31507737295968, 57.08066388538906, 55.35105923243931, 0.5069632594074521, 0.2025172444326537, 1.0638703874179294, 1.4902271607092448, 0.1277354657649994, 34.20445653370449, 59.72779205867222, 59.23449775150844, 57.92634998049055, 60.28176498413086, 33.31082092012678, 31.275141171046666, 53.5576353754316, 33.0997485433306, 41.6015921320234, 50.06069040298462, 34.31097936630249, 0.43247433645384653, 0.11134044480110918, 0.11555967054196767, 0.04362746414595416, 0.06225099427891629, 0.018889037493084158, 0.02547855399149869, 0.06839137657412461, 0.04108367028779217, 0.02880717028996774, 0.02952577280146735, 0.050043009354599884, 0.030189084886972393, 0.06108259768890483, 0.885546010519777, 55.124075480869834, 53.49563659940447, 40.19433873040335, 24.101826156888688, 45.92795746667044, 33.661677156175884, 44.60092796598162, 70.56628009251186, 57.36519956588745, 64.06856100899833, 56.321309157780235, 57.948907307216096, 32.72067567280361, 0.12250260370118277, 0.5341016203165054, 2.0280004697186604, 1.03907867201737, 0.2985972873866558, 2.0112941776003157, 37.76352187565395, 48.11024420601981, 60.09537260872977, 55.4626646723066, 58.60957677023751, 51.55060652324131, 55.39719179698399, 50.19702795573643, 56.53542137145996, 54.28581701006208, 53.85899611881801, 50.354679107666016, 52.52039091927664, 51.75105163029262, 55.770063400268555, 49.19884279796055, 47.24265391486031, 49.51276935849871, 57.00174624579293, 49.09135069165911, 50.464519705091206, 53.18512160437447, 52.0261447089059, 47.61342716217041, 45.87164926528931, 44.59045008250645, 43.79533645084926, 44.98344714300973, 47.42312642506191, 45.27068567276001, 45.191302503858296, 51.19517489842006, 47.162193775177, 47.13995606558663, 46.398256710597444, 47.601938315800254, 45.76303849901472, 49.827998706272666, 47.39074087142944, 45.05044167382376, 42.86271102087838, 39.402991022382466, 40.97500705718994, 35.784174646650044, 31.863028253827775, 32.2704428264073, 37.79336091450283, 39.616081850869314, 37.40538045338222, 38.88802875791277, 37.65074913842337, 40.174859455653596, 39.61077342714582, 40.883916173662456, 42.61546632221767, 48.09135205405099, 43.95937647138323, 47.45750958578927, 51.482976232256206, 39.52253130504063, 43.71981995446341, 42.92055477414812, 48.688143253326416, 46.014347893851145, 38.09121976579939, 48.354000908987864, 43.947665282658164, 43.00132063456944, 45.58948639460972, 41.48805856704712, 42.36312859398978, 39.250016008104595, 38.33129392351423, 39.91883223397391, 38.69894395555769, 38.39317805426461, 38.32943875449044, 38.02691418784005, 37.22429650170462, 36.184654917035786, 39.700849873679026, 39.32776982443673, 42.32759550639561, 43.26513678686959, 46.39669336591448, 47.893967628479004, 48.493538107190815, 45.62366458347866, 43.91129493713379, 44.82391650336129, 46.47129270008632, 48.540382862091064, 44.533388001578196, 44.10505935123989, 46.18594060625349, 40.85341705594744, 43.967151505606516, 43.52511058534895, 49.21536214011056, 49.83938332966396, 51.944697925022666, 54.78571905408587, 41.8353191103254, 50.82408550807408, 54.89903027670724, 49.53712626865932, 51.32100330080305, 49.993386677333284, 53.39050340652466, 48.056993212018696, 52.295637539454866, 52.900207247052876, 57.92721503121512, 48.174549783979145, 42.85884434836251, 54.44670254843575, 55.02558823994228, 54.42578847067696, 56.19189201082502, 53.022436482565745, 57.48580987112862, 56.047598770686555, 59.495048250470845, 58.118505886622835, 61.96919059753418, 0.5334869218724114, 0.6077542081475258, 1.9592510844979967, 1.6648666581937244, 0.13813895466072218, 37.3751870564052, 65.38898972102574, 64.22371428353446, 66.3584371294294, 63.77955763680594, 41.79729161943708, 33.575377055576865, 63.82610361916678, 30.85422624860491, 42.26261247907366, 58.434252875191824, 39.77306250163487, 0.4938708447984287, 0.1409169855926718, 0.10046762001833745, 0.05924196967056819, 0.08867511565663985, 0.022104828684989895, 0.09422230228249516, 0.18238829954394273, 0.1588441114872694, 0.16783494475696767, 0.18107682705989905, 0.08828892066542592, 0.08286989573389292, 0.11369764152914286, 1.1454183544431413, 68.92128712790353, 59.92105620247977, 50.74025896617344, 27.399439471108572, 44.90726709365845, 50.341772828783306, 46.17410087585449, 76.5680923461914, 63.70892224993025, 69.26149872371128, 61.110184805733816, 62.7389189856393, 38.85486500603812, 0.17143936348812921, 0.8675336741975376, 2.4493309812886372, 5.286607248442514, 0.26721395711813656, 2.794559610741479, 41.50721822466169, 44.369660649980815, 58.7284882409232, 56.78980881827218, 62.15031623840332, 53.536193234579905, 58.58272893088204, 53.93116358348301, 58.6477084841047, 57.320223876408164, 56.47068500518799, 50.103150844573975, 53.07871341705322, 53.61235243933541, 58.08289984294346, 51.0204416002546, 49.746440751211985, 50.605946813310894, 59.01162038530622, 52.29678399222237, 52.21674421855381, 56.72555187770298, 55.809449263981406, 49.590550967625205, 48.05153540202549, 46.69460085460118, 46.90416199820382, 46.51376703807286, 51.143542834690635, 47.43970830099923, 46.76102563313076, 53.129515171051025, 51.50564125605992, 52.806392669677734, 49.618131841932026, 50.08442544937134, 47.49913624354771, 53.40020309175764, 50.96655832018171, 48.86404732295445, 45.53048924037388, 41.58354418618338, 45.37712860107422, 43.38760226113455, 37.10367577416556, 37.15961572102138, 40.19308458055769, 43.83530248914446, 42.4525762285505, 42.00954518999372, 39.10657044819423, 41.14193058013916, 41.00079182216099, 42.86432647705078, 45.23861278806414, 50.81866938727242, 44.74685055868966, 49.11655528204781, 55.192334583827424, 40.260930265699116, 45.01258788790022, 43.705221789223806, 50.847160475594656, 47.67103467668806, 41.18116358348301, 52.14429187774658, 47.39546912057059, 47.408868721553254, 48.155501297542024, 44.16726657322475, 48.11411782673427, 42.20651272365025, 40.78785732814244, 40.54607391357422, 41.838598660060335, 42.829738344464985, 41.59235102789742, 43.07800095421927, 41.50440420423235, 40.38653979982649, 44.66380568913051, 42.09970848900931, 45.93327978679112, 45.624414988926475, 49.78041049412319, 50.1247284752982, 52.82250901630947, 48.836991037641255, 46.36363731111799, 46.52593680790493, 49.48868342808315, 50.82851498467581, 47.664572851998464, 46.35310731615339, 48.75646489007132, 44.3662108693804, 47.16106816700527, 44.70255926677159, 52.25869049344744, 52.18600191388811, 55.66379417691912, 57.89660474232265, 44.02825743811471, 52.323979241507395, 56.16090999330793, 51.32017993927002, 52.945561613355366, 53.06713424410139, 55.16579246520996, 49.42570843015398, 55.55140011651175, 55.00824901035854, 60.95090430123465, 45.59247064590454, 45.24341399329049, 56.734480312892366, 56.829715796879356, 55.38716902051653, 59.702097620282856, 54.47590235301426, 62.39902005876814, 56.40738344192505, 62.61426135471889, 53.70547219685146, 60.62410272870745, 1.2708387672901154, 1.3322441237313407, 2.908998178584235, 3.0098486755575453, 0.29488040826150347, 39.619385719299316, 71.84436648232597, 68.84251540047782, 69.12716920035226, 70.96903242383684, 45.47643572943551, 41.87271431514195, 68.19967501504081, 48.64106225967407, 61.81429440634591, 64.30290985107422, 54.62469802583967, 0.8307794407010078, 0.6123114664639745, 0.22215623275509902, 0.20652362730886253, 0.15063903533986636, 0.21042928844690323], [0.06454145708786589, 0.07671815476247243, 0.0049336124294703555, 0.057696266898087094, 0.056223045236298015, 0.15446613569344791, 0.15551306094442094, 0.11784595357520239, 0.27389603427478243, 28.762511014938354, 55.04935107912336, 38.20087276186262, 34.56597825459072, 31.188361644744873, 33.19755833489554, 29.196632725851877, 67.02706227983747, 50.54281200681414, 59.46378135681152, 52.711660930088584, 50.489349092756, 46.59566198076521, 1.2834208692823137, 0.268710371106863, 2.186362292085375, 0.7359236106276512, 0.5416430213621685, 0.2012374188218798, 21.45955651147025, 33.097514697483604, 59.594483920506065, 56.77890362058367, 55.814448492867605, 55.63505642754691, 54.26756756646292, 54.86909743717739, 56.866958141326904, 53.889276368277415, 51.2660882132394, 47.65892744064331, 51.39103766850063, 53.32920639855521, 50.91761173520769, 46.751478808266775, 44.5293858391898, 51.55765894481114, 49.37525061198643, 53.2535057749067, 53.5169015611921, 51.18939747129168, 47.341075147901265, 47.3855470929827, 49.899429661887034, 48.73170498439244, 47.549312659672324, 42.77274921962193, 42.79869031906128, 44.26032032285418, 41.15966585704258, 46.88301862989153, 45.84643077850342, 45.75510365622384, 44.83070141928536, 43.859833104269846, 45.46908800942557, 45.59991216659546, 43.85480955668858, 45.50456551143101, 41.644938468933105, 37.88817603247506, 37.1781257220677, 34.21326337541853, 30.97580235345023, 31.16629069192069, 33.48806251798357, 38.230221952710835, 38.74637930733817, 35.00274549211775, 36.55468818119594, 34.58517612729754, 37.99621704646519, 40.17757967540196, 47.12602145331246, 51.59148972375052, 37.789233684539795, 34.0285142489842, 37.72984743118286, 37.079791341509136, 39.75572327205113, 39.93430239813668, 38.06333664485386, 40.69047832489014, 31.460786615099224, 29.720995903015137, 46.30343811852591, 42.22574533735003, 40.85469205038888, 40.33297266278948, 40.40242338180542, 37.93777922221592, 37.5044652393886, 36.10147455760411, 39.112538950783865, 36.56548220770699, 33.45449924468994, 33.79754223142351, 33.12404291970389, 32.66721970694405, 37.21716070175171, 38.4222423689706, 38.095600605010986, 40.67266661780221, 42.64560065950666, 42.84272452763149, 46.02278995513916, 45.41864061355591, 46.764367716653005, 42.78158038003104, 42.70278780800955, 43.8348890713283, 41.24912738800049, 42.4371269089835, 42.678840841565815, 42.894349643162315, 46.12732212884085, 44.58700377600533, 46.252678053719656, 47.19248444693429, 48.406070709228516, 48.21135439191546, 50.375746045793804, 48.017562185014995, 49.4045581136431, 48.87416042600359, 48.57679142270769, 46.76546205793108, 43.2565974508013, 43.36359970910208, 50.118825980595176, 52.407500062670024, 54.2389930997576, 52.21517045157296, 38.433616570064, 44.88039493560791, 57.288223947797505, 47.91896029881069, 53.409065519060405, 50.18432664871216, 60.05316925048828, 52.03402049200875, 66.77174377441406, 50.38218355178833, 42.55490582329886, 1.0255976468324661, 0.17098549141415528, 0.7065616633210863, 0.2943790251655238, 0.11591416437711034, 35.260881492069785, 58.77741745540074, 57.87045519692557, 53.337558133261545, 62.824465206691194, 27.724121843065532, 35.33999368122646, 51.41640206745693, 25.287155832563126, 28.157875299453735, 56.10968092509678, 22.30344476018633, 0.2638696480010237, 0.05208263473053064, 0.09630397986620665, 0.047152463745857985, 0.04963248549029231, 0.08218469750136137, 0.09401450093303408, 0.07043132425418921, 0.0283552625748728, 0.11056814302823373, 0.07056599988469056, 0.17732300848833152, 0.06041480387960162, 0.10782519914209843, 0.3212483876517841, 36.96581309182303, 64.68018313816616, 44.70859725134713, 26.96173770087106, 35.29950305393764, 38.7558844430106, 30.246891157967703, 74.02311311449323, 53.47920410973685, 64.38019466400146, 57.86529963357108, 56.288013390132356, 48.457435267312185, 1.6974105004753386, 0.22850782264556202, 3.0491014378411427, 1.0082215049437113, 0.522318398313863, 0.10389257980776684, 23.53804758616856, 42.88517107282366, 65.96312631879533, 54.84944445746285, 61.99380806514195, 54.65842458180019, 56.92451354435512, 55.53559296471732, 57.56169809613909, 54.798416887010845, 53.77500629425049, 47.57839781897408, 53.87408413205828, 56.1381824357169, 52.31908423560006, 48.96959393365042, 45.36713709150042, 53.28824329376221, 53.119002546582905, 55.483516216278076, 55.90912812096732, 51.67648703711373, 49.9487236567906, 48.74868985584804, 48.694830894470215, 49.68950721195766, 48.25778572899954, 44.35216161182949, 44.028889724186485, 45.87706191199166, 44.27877821241106, 48.065598555973594, 48.164370673043386, 48.77563149588448, 49.219871520996094, 47.089751856667654, 47.15276506968907, 48.2113231250218, 48.77010767800467, 49.8441150529044, 42.929851463862825, 39.12858581542969, 40.70135920388358, 36.86449793406895, 34.95634542192732, 34.29784032276699, 37.14660521915981, 41.34518275942121, 40.14862653187343, 38.27346059254238, 38.35743652071272, 37.85879210063389, 38.865290778023855, 41.338099070957725, 47.35058375767299, 53.01136105401175, 37.215305532727925, 35.58946180343628, 40.692302227020264, 38.54605579376221, 41.12017577035086, 40.670849663870676, 41.06182132448469, 40.431901114327566, 33.15588998794556, 35.04140179497855, 48.488802909851074, 42.542961869921, 41.89240550994873, 43.07286623546055, 41.94739702769688, 40.137172426496235, 39.67953974860055, 37.266850743974956, 40.28158031191145, 38.157582010541645, 36.719700949532644, 37.05812685830252, 35.56050171170916, 36.39033896582467, 40.95665686471121, 40.59471477781023, 40.32769203186035, 43.81454127175467, 45.67847892216274, 45.53143072128296, 50.18841913768223, 48.50868170601981, 49.596418721335276, 46.174729687826975, 46.877560819898335, 46.997184480939595, 41.50323690686907, 44.21721369879586, 45.77743864059448, 44.107817786080496, 50.05605248042515, 47.16239527293614, 48.70872381755284, 49.646727153233115, 53.07970353535244, 51.12836102076939, 51.00408901487078, 49.00972672871181, 52.328043937683105, 50.52931860515049, 51.357915605817524, 48.97072649002075, 46.36575998578753, 45.929531233651296, 51.135045187813894, 54.56474549429757, 57.14189141137259, 55.13971587589809, 45.23245668411255, 45.18811328070504, 59.79312597002302, 53.68079914365496, 57.5875905581883, 53.04816566194807, 63.59081677028111, 53.07822356905256, 68.78102384294782, 58.26066950389317, 45.95372486114502, 1.3231147336108344, 1.0363336993115289, 0.9705009290150234, 0.5348018684557506, 0.09926997856902224, 39.64580624444144, 63.60153784070696, 64.20052119663784, 59.73046711512974, 68.57794884272984, 30.903996195111954, 40.011073044368196, 60.958762713841026, 27.56530339377267, 33.197415896824424, 63.67971897125244, 27.217610325132096, 0.386101489088365, 0.1508136631122657, 0.020737044579748596, 0.0670284168528659, 0.01851867272385529, 0.05132392401407872, 0.24873744856034005, 0.12049300010715212, 0.14887882050658974, 0.14733034931123257, 0.21328763078366006, 0.2331882214971951, 0.18021804599889688, 0.30568377141441616, 0.39142459630966187, 44.48182889393398, 76.89038453783307, 53.36070953096662, 48.40545926775251, 43.43490212304251, 47.537747383117676, 38.577875069209504, 77.57032830374581, 60.01223046439034, 69.78987448556083, 62.309013094220845, 59.49448544638497, 54.70535271508353, 1.9151986369064875, 0.3988295303923743, 3.6360515994685034, 1.9197473185403007, 1.1935245330844606, 0.37474430565323147, 29.281438963753835, 47.42995997837612, 57.620990548815044, 55.74643605095999, 64.98092201777867, 56.56976284299578, 58.3573363167899, 58.5625513621739, 60.13095433371407, 57.92778130940029, 55.12707362856184, 49.09187528065273, 56.976496492113384, 56.81981461388724, 56.16772270202637, 50.64674663543701, 48.555644580296104, 53.820113999503, 54.65255682809012, 57.88733237130301, 57.78869227000645, 53.39088208334786, 52.27073172160557, 51.929596015385215, 52.4896034513201, 50.12899119513375, 49.71104662758963, 44.83543314252581, 44.92609323774065, 49.352745396750315, 45.57055255344936, 52.10789373942784, 52.39075837816511, 52.312608514513286, 52.50990956170218, 49.75646005358015, 49.7566476549421, 51.018218176705496, 51.46147503171648, 51.892405782427105, 46.446227073669434, 44.861422879355295, 43.80822535923549, 40.774238858904155, 37.55561440331595, 37.604376861027305, 38.82246208190918, 44.5717316355024, 44.86269439969744, 40.03078508377075, 40.37497452327183, 38.71426820755005, 41.43971300125122, 43.37685687201363, 50.98670809609549, 53.22738054820469, 39.95889207295009, 36.47113956723894, 42.349235670907156, 40.41423879350935, 44.773073060171946, 43.536366667066304, 43.156664984566824, 42.28659071241106, 32.9748546736581, 37.3333797454834, 51.970242977142334, 45.98599576950073, 44.807991232190815, 44.875777857644216, 43.9212760244097, 43.79860210418701, 41.322125162397114, 39.110548291887554, 44.19146020071847, 39.58003459657942, 39.30901663643973, 42.17118113381522, 40.70825181688581, 40.17167370659964, 44.93409061431885, 45.586335386548726, 44.20649610246931, 48.077674525124685, 47.803543772016255, 48.1457599231175, 54.02577025549752, 52.785176345280235, 53.29507337297712, 47.839326994759695, 50.22255563735962, 49.07120786394392, 44.45743029458182, 47.88771077564785, 47.71568727493286, 45.805318287440706, 51.94726875850132, 50.66903645651681, 51.343369552067344, 50.60034309114729, 54.7511100769043, 53.61093500682286, 54.15070581436157, 52.6044328553336, 53.733070441654746, 50.59109156472342, 53.02414573941912, 50.383757318769185, 50.10481146403721, 46.475246225084575, 55.14590672084263, 55.27388906478882, 60.01356451851981, 52.9843464578901, 43.19344179970877, 49.52427210126604, 61.84248324802944, 56.34136860711234, 57.974348136356895, 54.28307247161865, 66.28441102164132, 56.198934010096956, 66.53656114850725, 52.40146207809448, 51.97936248779297, 1.6940165225948607, 1.1758150947945458, 3.8655903339385986, 0.8716506447110857, 0.8607096746563911, 44.412520612989155, 71.32944938114711, 68.42106546674455, 64.01482364109584, 75.75777258191789, 38.82701315198626, 47.190452098846436, 70.47143023354667, 40.65188455581665, 40.79608746937343, 73.15953540802002, 37.07936750139509, 0.49549031789813724, 0.3634406179189682, 0.20438819618097373, 0.1825822927057743, 0.17711484751531056, 0.11684728573475565], [0.029870699292847087, 0.08167116862854787, 0.04749747844679015, 0.07544603052416018, 0.05715158648256745, 0.09513245522975922, 0.08649781891810042, 0.16379719999219688, 0.28999666603548185, 12.864528894424438, 56.03038808277675, 38.05246271405901, 40.360657760075156, 34.67156308037894, 30.029270103999547, 26.171560764312744, 63.788687569754465, 51.30664832251412, 53.47374629974365, 53.7155053956168, 48.86324480601719, 51.091466086251394, 4.496873693806784, 0.4908151573368481, 2.454431393316814, 1.050293281674385, 0.5407150025878633, 0.23000817213739666, 16.348838567733765, 32.38843018668038, 39.997763769967214, 69.07169478280204, 52.725904737200054, 55.75522204807827, 52.0165388243539, 54.20498514175415, 51.177863461630686, 50.397372313908164, 48.23227889197213, 49.84755093710763, 54.002014364515034, 51.69469479152134, 49.83741004126412, 43.63852950504848, 45.91483926773071, 52.453618730817524, 51.28930909293038, 50.41938420704433, 49.00615882873535, 52.99362230300903, 51.75124617985317, 52.18927451542446, 51.336605480739046, 49.38266781398228, 51.167364733559744, 49.646153926849365, 45.56164148875645, 44.09512690135411, 41.292977469308035, 46.33851262501308, 44.548555919102256, 43.852884905678884, 46.82039104189192, 46.38993624278477, 45.74743284497942, 45.02060958317348, 47.56476892743792, 46.73765189307076, 44.20947687966483, 42.644360406058176, 36.920034885406494, 34.3388729095459, 35.218487058367046, 33.76810966219221, 36.61459902354649, 36.026190825871055, 36.601268904549734, 35.866555963243755, 34.73419761657715, 36.165290287562776, 37.93140425000872, 40.75980397633144, 47.79468829291207, 49.02867794036865, 42.355485575539724, 35.53645747048514, 41.895608629499165, 38.761873790196006, 39.18354606628418, 38.627766609191895, 41.220292363848, 39.396609101976665, 32.39003522055489, 35.15572050639561, 40.32817145756313, 46.71698795046125, 44.85427665710449, 40.214321749550955, 39.11241735730852, 36.41349731172834, 37.62315436771938, 37.68280117852347, 37.51316090992519, 36.52018690109253, 34.509558882032124, 32.397455896650044, 32.059412138802664, 32.0789018358503, 35.772956780024934, 38.12400484085083, 38.15552881785801, 43.335869448525564, 42.684104101998464, 46.569161551339285, 46.30622434616089, 45.15124266488211, 44.657632214682444, 43.80346931729998, 43.21221930640084, 43.43480832236153, 41.32807282039097, 40.35066277640206, 42.39043154035296, 47.36370890481131, 50.845392159053254, 50.838575976235525, 53.823112147195, 50.05835233415876, 50.033185958862305, 50.31168712888445, 50.651061466761995, 49.367055211748394, 48.05669443947928, 46.58012580871582, 43.12333795002529, 38.90468011583601, 41.62283277511597, 39.243217195783345, 47.49347693579537, 50.54928077970232, 53.780241761888774, 52.815293312072754, 54.656496456691194, 33.821134839739116, 49.62315191541399, 52.65929583140782, 55.83847883769444, 53.656160831451416, 53.75905670438494, 62.960469245910645, 64.7751441683088, 35.69984783445086, 45.66871670314244, 0.640120382819857, 0.40169129254562513, 1.815412951367242, 0.3253877226795469, 1.5258808646883284, 56.66990722928728, 52.82310308728899, 59.804090227399556, 54.89658451080322, 58.396670069013325, 27.79983810016087, 44.656628199986045, 42.62664597375052, 28.296891382762364, 35.69625561577933, 54.1552950995309, 13.301365613937378, 0.5436564247523035, 0.06530136202595063, 0.0820250857089247, 0.04736003100073763, 0.10088489191340548, 0.03677828077759061, 0.004462159513163247, 0.17630802866603645, 0.064488592424563, 0.09940046763845853, 0.07913614144282681, 0.21185795749936784, 0.055128578429243395, 0.3158570740904127, 0.3038063464420182, 15.99637382371085, 66.92338126046317, 45.63861015864781, 35.941092763628276, 39.57407651628767, 37.77734184265137, 28.155525071280344, 70.58786119733537, 55.938147272382466, 59.76937007904053, 57.4731502532959, 54.48499754496983, 53.90886681420462, 5.316151857376099, 0.32415059049214634, 2.764298903090613, 0.9360766219241279, 2.4236009333814894, 0.5167261841041701, 22.759508882250103, 36.31570489065987, 51.97217457635062, 70.68832520076207, 52.49343538284302, 58.25530549458095, 52.958440099443706, 56.040351799556184, 52.483753068106516, 51.63338736125401, 48.98108625411987, 50.69426189150129, 55.04598120280674, 52.09592546735491, 52.59612280981881, 46.22513886860439, 47.32116508483887, 53.43293605531965, 54.11031593595232, 53.18488189152309, 51.669670854296, 55.70365251813616, 53.25825139454433, 52.34849943433489, 53.21175752367292, 50.90404885155814, 51.977729661124094, 50.622566904340474, 44.875784805842805, 44.697188309260774, 45.63977745601109, 47.622803756168906, 47.592884813036235, 47.52817971365792, 50.55871295928955, 47.5612461907523, 48.4651095526559, 47.60216065815517, 49.21631751741682, 48.358993189675466, 47.83152764184134, 43.82021100180489, 40.96088484355381, 37.32629953111921, 37.283390930720735, 36.94807086672102, 39.80413484573364, 36.50458124705723, 38.354348046439036, 37.9463289805821, 39.41168321881975, 38.55181237629482, 40.07324552536011, 43.57240349905831, 50.028975350516184, 49.03935384750366, 42.91220303944179, 35.287295069013325, 44.547346932547434, 39.553020000457764, 40.24122864859444, 39.80642775126866, 42.57767159598214, 40.72385399682181, 31.73249592099871, 35.90655326843262, 45.42523445401873, 50.89866747174944, 46.6967339515686, 42.02853809084211, 43.369731494358604, 37.76082250050136, 39.17119564328875, 37.95040757315499, 38.48155219214303, 36.916699750082834, 35.12344264984131, 35.03438411440168, 35.1228346824646, 35.43828637259347, 39.984722001211985, 39.150774887629915, 41.551030090876985, 44.8751733643668, 45.065408093588694, 47.950779574257986, 49.184456552777974, 49.68250690187727, 47.13216713496617, 46.92007337297712, 47.28142833709717, 47.754510334559846, 42.01956796646118, 43.258838244846885, 44.44409670148577, 50.03999171938215, 52.278169768197195, 55.44619396754673, 55.704746859414236, 51.664734159197124, 53.41811554772513, 52.88491078785488, 53.192010743277415, 51.01461900983538, 51.60745668411255, 49.92803192138672, 45.3413280078343, 41.46774203436715, 43.71460880552019, 41.99668754850115, 48.54982198987688, 51.98200627735683, 55.799450806209016, 53.41711500712803, 60.6713296345302, 40.211785657065256, 50.777202538081575, 56.674565996442524, 57.68295805794852, 58.14437402997698, 55.59627158301217, 62.54399422236851, 68.8973227909633, 41.17444814954485, 48.969340324401855, 1.1556386117424284, 2.6725340442998067, 2.020441915307726, 0.3550592448030199, 1.8127300781863076, 61.72856058393206, 57.31099666867937, 66.50951875959123, 61.62150968824114, 62.68238844190325, 31.16491494859968, 49.501697404044016, 51.76311370304653, 31.66828066962106, 38.07400907788958, 64.19228063310895, 17.082927908216202, 0.2641201359885079, 0.10747638464506183, 0.14405324230236666, 0.01192300021648407, 0.05172728254858937, 0.060731184402746816, 0.12629695795476437, 0.4169309990746634, 0.2531971335411072, 0.1907950770109892, 0.14672460752938474, 0.49033893431935993, 0.16317957027682237, 0.4384227272655283, 0.3431895502976009, 19.234498398644583, 80.33116722106934, 52.402174268450054, 57.46967962809971, 47.16978815623692, 45.73514148167202, 34.3808330808367, 77.1448414666312, 61.117035729544504, 64.88988671983991, 62.24180316925049, 59.204794202532085, 58.3328925541469, 6.291198211056845, 0.4978916804705347, 4.072683129991804, 1.9042545727321079, 3.1363886169024875, 0.41399299672671724, 25.560869693756104, 42.47128425325666, 51.062130791800364, 60.50240503038679, 53.27836990356445, 63.242850984845845, 56.7612760407584, 58.10510628564017, 55.470710686274934, 56.01566137586321, 51.80859661102295, 51.51580647059849, 56.06376722880772, 54.66227388381958, 52.721162591661724, 47.365154130118235, 49.74890736171177, 56.12126704624721, 53.99260650362287, 53.481028011866975, 53.29096351351057, 58.18193599155971, 56.17594242095947, 56.323188645499094, 54.8131331716265, 53.04539680480957, 54.838660853249685, 54.360704694475444, 47.25733545848301, 47.52945123400007, 46.44164821079799, 50.881203174591064, 50.579984869275776, 50.47662694113595, 53.50833443232945, 51.68164260046822, 51.64058916909354, 51.015018531254356, 51.15410757064819, 53.032424518040244, 50.82822663443429, 49.52086400985718, 45.03216443743025, 42.2914787701198, 41.08058840887887, 40.43115070887974, 42.73406164986746, 38.99790409633091, 40.898451805114746, 40.43847063609532, 40.356311661856516, 40.584469658987864, 40.96935469763619, 45.96705845424107, 52.59460462842669, 51.92208501270839, 43.67069966452462, 35.05713251658848, 46.75051300866263, 42.74862160001482, 42.24778502328055, 42.3140013558524, 45.012782437460764, 42.02435180119106, 34.01795298712594, 35.443302971976145, 49.65812914712088, 53.38125188010079, 49.85623965944563, 44.252875328063965, 44.137837478092735, 40.116626603262766, 40.28628076825823, 41.701448168073384, 42.1087897845677, 39.33876534870693, 38.535171440669465, 40.09216547012329, 38.813995701926096, 39.50737380981445, 43.852679933820454, 43.554115840366904, 43.51212787628174, 48.51627261298043, 48.918840817042756, 52.47710711615426, 52.677277769361226, 53.2759554045541, 51.16361618041992, 49.87491641725813, 49.491174357278005, 48.058184828077046, 46.508236271994456, 44.6663487298148, 47.25602224894932, 50.304401942661826, 54.03994458062308, 57.642060961042134, 56.89767265319824, 56.087953908102854, 55.753307819366455, 54.34831953048706, 55.98758370535714, 53.64393547603062, 52.3128273827689, 51.88368231909615, 46.248550823756624, 44.2906631061009, 46.856525148664204, 44.03077616010393, 51.818942478724885, 54.77966022491455, 57.32498686654227, 57.89532279968262, 57.154488495418, 42.40298693520682, 55.05480541501726, 56.51242283412388, 60.36222512381417, 58.956569807870046, 59.60910987854004, 62.41281223297119, 68.18757820129395, 45.11298588344029, 53.191795349121094, 1.7791608337845122, 3.673857399395534, 6.957413639341082, 0.6691712353910718, 2.9999470583030154, 66.53316347939628, 60.59582356044224, 71.54384994506836, 66.0108118057251, 70.46693474905831, 39.65785789489746, 59.37439278193882, 59.529434885297505, 42.11158990859985, 48.38322155816214, 75.91918618338448, 24.509747947965348, 0.7800869579826082, 0.19209102461380617, 0.2336928072784628, 0.14137792800154003, 0.24916554987430573, 0.1940779515675136], [0.030619459293250526, 0.06428634827690465, 0.06307139061391354, 0.03939883051706212, 0.0596916348274265, 0.05389558191278151, 0.03918740239792636, 0.05443578399717808, 0.13842898766909326, 2.232354155608586, 47.662936551230295, 43.58327395575387, 32.6209898676191, 28.472225700105938, 31.946556023189, 20.53133797645569, 60.64919267381941, 59.0169357572283, 49.945940903254915, 57.02272980553763, 45.53175033841814, 55.48171663284302, 9.478603107588631, 0.6608388253620693, 1.461316249200276, 0.4226972168045384, 0.8519173264503479, 0.3076075810406889, 5.52515367099217, 45.150165694100515, 28.382270847048076, 45.611897809164866, 66.90164729527065, 59.146345955984934, 54.722174303872244, 52.635515621730256, 53.26406356266567, 51.65209191186087, 54.73689406258719, 54.820387090955464, 52.818023954119, 51.49861315318516, 46.74742453438895, 41.35851635251726, 44.902865409851074, 49.34581109455654, 49.880419390542166, 50.653753893715994, 52.010247230529785, 51.19502551215035, 49.86495617457798, 53.27238403047834, 51.511078221457346, 52.87680571419852, 50.048972266060964, 51.72080264772688, 47.86882904597691, 43.26119368416922, 42.071321623665945, 45.715134143829346, 47.92384140832083, 45.54931538445609, 46.07575607299805, 44.4765864780971, 45.66358893258231, 45.33253506251744, 46.052736691066194, 44.66225624084473, 48.09762280327933, 41.59887538637434, 41.32756560189383, 34.82386064529419, 36.29903963633946, 35.45487172263009, 36.54318543842861, 37.06848662240164, 38.26494904926845, 35.989858695438926, 36.18386629649571, 35.927251952035085, 37.4485113961356, 46.08451427732195, 48.94929477146694, 45.04563352039882, 39.275366510663716, 36.59041929244995, 47.30954074859619, 49.9318082673209, 40.66689613887242, 40.82284845624651, 46.929422174181255, 46.29218898500715, 35.65397582735334, 35.173466205596924, 41.16797937665667, 43.90035499845232, 52.52715499060494, 40.47734580721174, 40.00702919278826, 35.71483162471226, 37.354043688092915, 34.08608702250889, 38.029742104666575, 35.788975851876394, 35.14836931228638, 33.79723303658621, 32.84342949731009, 33.960241249629426, 38.63717099598476, 39.676451274326865, 45.177513803754536, 45.485746315547395, 44.69721610205514, 42.68178687776838, 46.25627722058977, 43.934418542044504, 43.84759732655117, 43.73744753428868, 42.92245858056204, 44.510465894426616, 39.118010657174246, 41.456027371542795, 44.66743264879499, 51.00373118264334, 47.863638741629465, 43.93122237069266, 39.5954943384443, 42.090290205819265, 44.75469854899815, 45.614760466984336, 51.46279866354806, 48.717579296657014, 48.63487836292812, 41.85117837360927, 39.70752361842564, 39.20168433870588, 39.877316747392925, 37.99899632590157, 41.78556306021554, 44.91979469571795, 54.73958648954119, 54.09390776497977, 58.58145046234131, 57.25160346712385, 40.50949164799282, 57.74743039267403, 52.485528332846506, 54.985778536115376, 60.24644729069301, 59.358238220214844, 36.29663903372628, 52.05844341005598, 43.05448477608817, 0.4629275309188025, 1.332556358405522, 0.4905462403382574, 0.2427226970238345, 5.325022101402283, 65.54656096867153, 47.11758286612374, 61.96782875061035, 50.83517483302525, 63.35202802930559, 26.958272286823817, 48.00462116513933, 34.234500544411794, 21.961173023496354, 34.90096133095877, 61.80139854976109, 5.50210736479078, 0.3734218951846872, 0.2557508950786931, 0.061045895729746134, 0.051443013695201704, 0.05580499641863363, 0.10960285911070448, 0.06588575709611177, 0.08003346329288823, 0.022301077975758483, 0.14118005361940178, 0.06861048231699637, 0.07095828133502177, 0.06690854685647146, 0.05257561417030437, 0.18791917418794973, 3.592281856707164, 57.78618744441441, 53.718475750514436, 32.95895372118269, 33.39253173555647, 40.36210993358067, 23.382960319519043, 70.91885948181152, 63.29008483886719, 58.49109608786446, 60.15874712807791, 52.30428457260132, 59.63907051086426, 10.893877335957118, 0.7454013334853309, 2.7567900717258453, 0.3665632903575897, 2.0341672130993436, 0.5121454213346753, 7.220027753284999, 51.37586627687727, 30.76097447531564, 54.71240513665335, 61.74506255558559, 56.21679088047573, 57.04500225612095, 55.3639794077192, 55.25940554482596, 53.16185556139265, 56.2029743875776, 53.97791106360299, 53.75099331992013, 54.255300521850586, 48.65129695619856, 42.73016718455723, 47.267531939915244, 48.67913143975394, 52.00526884623936, 51.40169620513916, 54.22416911806379, 51.57388298852103, 52.289120129176546, 53.92559460231236, 53.4690979548863, 53.270858900887625, 52.5792247908456, 52.29961885724749, 49.731543813432964, 44.826212882995605, 43.53831563677107, 48.64579398291451, 49.8949932370867, 47.518983772822786, 47.8092725617545, 47.204101834978374, 48.24299648829869, 48.437198638916016, 49.50218377794538, 49.06606272288731, 49.97031518391201, 44.2725248336792, 43.08361857278006, 38.626557622637065, 40.19381761550903, 37.3543633052281, 39.81704807281494, 39.30085597719465, 38.717634609767366, 37.63221134458269, 38.18464524405343, 37.09829439435686, 39.27014146532331, 48.329063824244905, 50.06911161967686, 45.70393017360142, 41.172401905059814, 36.28740835189819, 49.40975536618914, 52.26705959865025, 42.028677054813926, 42.74985490526472, 49.39515372685024, 46.156369073050364, 36.79037455150059, 35.01009668622698, 43.20468051092965, 47.82031672341483, 54.23745059967041, 42.808994497571675, 40.99327734538487, 38.05313321522304, 39.57628951753889, 35.77277265276228, 38.65872083391462, 38.455663204193115, 38.17043270383562, 38.05311584472656, 36.761112213134766, 38.113787514822825, 41.45926523208618, 42.23055001667568, 46.36447804314749, 47.10479818071638, 47.6173528943743, 46.59472744805472, 49.20169503348214, 47.38277128764561, 46.66325058255877, 46.76150505883353, 46.99296692439488, 47.35278981072562, 41.64200285502842, 44.13719129562378, 47.11522742680141, 52.69554458345686, 51.36940792628697, 48.98070757729666, 41.72850097928728, 45.355516229357036, 46.95207677568708, 47.663457666124614, 52.17814350128174, 50.55061830793108, 51.503462995801655, 44.149527822222026, 41.73837436948504, 42.01792819159371, 42.04135056904384, 41.29464156287057, 43.673124585832866, 46.26026201248169, 55.35584306716919, 56.16567645754133, 58.953463963099885, 63.26759352002825, 43.62982341221401, 58.37690939222063, 56.73862491335188, 57.65558910369873, 61.5197046824864, 59.99000317709786, 41.299956934792654, 54.808957304273335, 46.24076189313616, 0.6493271802152906, 1.2105367630720139, 0.7407296470233372, 0.4845656326838902, 7.082702687808445, 71.89774254390171, 52.66523306710379, 67.46923174176897, 55.376058850969585, 65.64421095166887, 33.7681166103908, 51.48251070295061, 46.34809766496931, 29.308912140982493, 39.01900577545166, 72.16827065604073, 7.677498885563441, 0.35696706814425333, 0.07605575530656747, 0.035655926181269545, 0.05658768656264458, 0.032723959402314255, 0.07329983104552541, 0.13943560793995857, 0.192158878115671, 0.10399675528917994, 0.2787326861705099, 0.14440522555794033, 0.12536997055368765, 0.12219711366508688, 0.2460185315992151, 0.1978968009352684, 4.586146320615496, 74.50492204938615, 59.05246884482247, 48.418591363089426, 38.86532551901681, 48.61755650384085, 28.749757596424647, 73.70237037113735, 69.7695232118879, 62.684243610927034, 65.1850392477853, 57.18543924604143, 64.13207449231828, 13.059083666120257, 0.9972653899874006, 4.421370659555707, 2.0726467711584906, 4.939033167702811, 0.483444692833083, 10.4656320640019, 59.903115953717915, 38.36734465190342, 57.31191035679409, 57.91279404503958, 58.245772566114155, 56.62276022774832, 57.408573695591514, 55.24060719353812, 55.769549233572825, 56.770642212459016, 58.62476553235735, 57.079083170209614, 56.65699052810669, 50.87006173815046, 46.696247577667236, 49.38226134436471, 51.02524280548096, 54.91116183144705, 53.01322317123413, 52.3468005997794, 54.905572005680625, 55.02475445611136, 56.56203644616263, 56.078066621507915, 56.66556460516793, 53.74798127583095, 54.54523842675345, 51.7047245161874, 45.93928303037371, 46.52783366612026, 51.10111713409424, 52.51636791229248, 52.888551643916536, 51.53482369014195, 50.501727308545796, 50.900456632886616, 53.22519881384713, 52.90901756286621, 51.52405398232596, 52.07337508882795, 46.61039910997663, 47.07617507662092, 40.53480740955898, 42.77301672526768, 40.56585543496268, 41.16833373478481, 41.61161143439156, 42.27731139319283, 39.999229839869905, 41.30683217729841, 39.83572135652815, 41.618636063167024, 50.25918654033116, 50.370104108537944, 45.45078298023769, 40.97945043018886, 35.09306859970093, 51.427425384521484, 55.23989152908325, 44.43641546794346, 44.21358673913138, 51.38830702645438, 47.7520089830671, 36.21893038068499, 37.15132999420166, 45.29935394014631, 50.73212262562343, 57.652531896318706, 46.65977995736258, 42.818853991372244, 39.56547464643206, 42.286851269858225, 37.834449086870464, 42.510142053876606, 40.99033825738089, 40.95571190970284, 41.83114671707153, 40.092981883457725, 41.82599115371704, 45.49810021264212, 46.253414562770296, 50.62660033362252, 49.734719140189036, 51.26829079219273, 49.62941919054304, 53.38192932946341, 50.983108929225374, 49.990541390010286, 50.62270934241158, 48.15925679888044, 51.13683434895107, 44.42119543892996, 47.34831517083304, 49.68081154142107, 56.301666600363596, 53.954756191798616, 52.45150300434658, 43.369432721819194, 48.50032649721418, 47.04627002988543, 48.939258098602295, 56.90840414592198, 53.10480737686157, 53.55716289792742, 46.61026362010411, 44.84739794049944, 43.54963077817644, 42.61626883915493, 41.60750504902431, 47.78716686793736, 50.65376084191458, 59.378450529915945, 60.49596405029297, 61.75383118220738, 59.10354505266462, 48.81691421781267, 60.37783772604806, 57.212752614702495, 59.603454044886995, 62.623294012887136, 66.49683829716274, 47.78438758850098, 57.76531852994646, 49.46645961488996, 0.8045033078108514, 3.175444006919861, 2.5167072287627628, 0.7158140039869717, 7.927951914923532, 77.64108875819615, 56.260331766945974, 72.70775658743722, 60.4635784966605, 75.50580310821533, 38.27980777195522, 62.42323453085763, 48.96622058323452, 35.10060739517212, 49.09083999906267, 81.88716765812465, 13.807670422962733, 0.703574860734599, 0.4211707572851862, 0.2453173335109438, 0.224166976287961, 0.16253987460264138, 0.14710096376282827], [0.08155356493911572, 0.04217957219641123, 0.055946284372891696, 0.032264519948512316, 0.07275887578725815, 0.03224145993590355, 0.022915203057761704, 0.05519863377724375, 0.06873561095978532, 0.33219619733946665, 38.423625060490195, 50.24334464754377, 35.359900270189556, 32.99231202261788, 37.75939464569092, 31.847162042345317, 37.60645089830671, 61.75641591208321, 48.87614413670131, 60.35324110303606, 45.74177006312779, 61.08266299111502, 20.703104393822805, 0.050035379228315184, 0.8370335793920926, 0.4874383328216416, 3.119759623493467, 0.06709004140325955, 1.6721670436007636, 40.417903968266074, 51.44842978886196, 25.716069868632726, 38.01569979531424, 53.744965757642476, 56.7586669921875, 55.463637420109336, 56.20753935405186, 53.11175904955183, 53.3818598474775, 53.923155784606934, 53.94790874208723, 50.07673379353115, 42.17314052581787, 41.727132184164866, 46.97691658564976, 51.84273311070034, 55.18747779301235, 43.48412316186087, 33.534928117479595, 31.609783785683767, 37.35951886858259, 43.63749769755772, 46.63984904970442, 47.210313524518696, 50.81009531021118, 51.41181625638689, 49.00137846810477, 43.56376688820975, 41.8946532521929, 41.55510868344988, 47.29990012305123, 45.74973617281233, 41.892933573041645, 42.79623760495867, 43.17957319532122, 46.43315403802054, 45.23905399867466, 43.938337326049805, 46.701879092625205, 42.445388317108154, 38.74525022506714, 37.375239167894634, 34.69375910077776, 34.39089754649571, 36.50891692297799, 35.29740817206246, 36.928240707942415, 35.797793115888325, 36.88972684315273, 38.487142017909456, 41.923022747039795, 51.58625773021153, 55.080868107931956, 43.18826886585781, 37.73569434029715, 35.222669873918804, 45.77010134288243, 53.76457009996687, 47.7427887235369, 47.01545129503523, 52.46543761662075, 47.52684218542916, 39.96574994495937, 37.15249034336635, 41.788950307028635, 39.6250068119594, 50.02655042920794, 49.6983904838562, 39.94407851355416, 39.64934982572283, 34.08773027147566, 36.28346872329712, 35.145572662353516, 37.64696931838989, 35.225921630859375, 37.559237888881135, 36.8912867137364, 38.66102763584682, 38.609225341251914, 41.10084588187081, 46.740889753614155, 45.07715054920742, 41.914129052843364, 43.95227888652256, 45.443598542894634, 42.61650160380772, 42.70456654684884, 45.88674422672817, 47.30744934082031, 46.35031761441912, 39.25397648130144, 42.415948799678254, 44.900909491947715, 49.99607563018799, 48.12057965142386, 41.884647846221924, 34.487237794058665, 37.81733567374093, 42.13527284349714, 49.92726761954171, 47.89228963851929, 50.14570508684431, 44.31606919424874, 40.870596476963584, 36.69793919154576, 39.40428338732038, 39.04207032067435, 39.91863421031407, 37.86488219669887, 41.570915835244314, 46.54414456231253, 53.474468912397114, 51.16979660306658, 63.04099191938128, 51.594154357910156, 42.21922097887312, 57.13883072989327, 51.18728174482073, 51.23587397166661, 38.72274153573172, 50.06368160247803, 61.11301967075893, 35.68419701712472, 0.246830765157938, 1.8783249812466758, 0.9564666535173143, 0.18825568684509822, 12.200728399412972, 63.38002232142857, 51.598559515816824, 59.82194014957973, 49.616509437561035, 55.85058259963989, 25.74858570098877, 44.77932643890381, 26.877339669636317, 31.08640377862113, 38.5575898034232, 52.03617443357195, 2.001325249671936, 0.16044918607388223, 0.0984343219814556, 0.06947807076254062, 0.02789329388178885, 0.0500819572646703, 0.051425836581204615, 0.07529534146721874, 0.007280372016664062, 0.022038359394563094, 0.047309398717646084, 0.05933601462415286, 0.033651571055608134, 0.025548424438706467, 0.11955674391772066, 0.06712003943643399, 0.5667084849306515, 47.95847817829677, 58.34147357940674, 38.92787320273263, 39.369177613939556, 46.7856639453343, 31.047771794455393, 45.28510665893555, 70.2581205368042, 56.02980790819441, 66.65257522038051, 49.929032461983816, 64.89803695678711, 21.858963285173687, 0.12682443750756128, 1.8107357280594962, 0.18341539800167084, 8.052760669163295, 0.255006949284247, 1.8630105001585824, 47.883138860974995, 51.734897068568635, 31.283562387738908, 43.99097687857491, 54.13340827396938, 56.6824244090489, 56.97142778124128, 56.753379413059776, 53.29066474097115, 55.362860747746055, 54.93368441717965, 56.3032785824367, 50.86682735170637, 44.286900656563894, 42.2724997656686, 49.493943214416504, 52.24964393888201, 56.52463429314749, 43.942624364580425, 34.81201049259731, 35.028332233428955, 38.84120832170759, 44.09591204779488, 47.6911427634103, 46.73313208988735, 51.04404810496739, 54.02157701764788, 49.6646535055978, 44.288074902125764, 43.98673847743443, 42.43480273655483, 50.14550706318447, 48.2342209134783, 44.9202115876334, 44.65337644304548, 48.50666672842843, 49.86695725577218, 49.14648117337908, 46.195695877075195, 48.161803313664024, 46.494885308401926, 40.81364904131208, 39.33077492032732, 38.490049839019775, 36.698939732142854, 38.1995769228254, 37.607861382620676, 38.29631321770804, 36.9574613571167, 39.3277906690325, 39.778735705784385, 44.325001103537424, 53.503623553684776, 56.47605248859951, 43.23399496078491, 37.20166621889387, 35.11923898969378, 44.81972673961094, 55.26026364735195, 49.621532985142295, 46.04814740589687, 52.169169902801514, 47.41900266919817, 38.62520619801113, 37.48049742834908, 41.48873949050903, 43.16658353805542, 53.643869468144004, 50.86884580339704, 41.01021705354963, 40.16867208480835, 38.31429515566145, 38.14689915520804, 37.14672681263515, 37.59044572285244, 37.894092423575266, 39.575236865452354, 40.39591291972569, 42.436949729919434, 42.1987098966326, 43.545944758823936, 48.67185320172991, 47.69295971734183, 44.97362586430141, 47.557751246861045, 47.86101579666138, 45.09232888902937, 47.48073741367885, 49.59346226283482, 49.710185050964355, 48.53631121771676, 43.32514837809971, 43.586935656411306, 45.54910693849836, 51.919837270464214, 50.3179544040135, 43.284032412937705, 34.6912716456822, 37.93094219480242, 43.10398374285017, 51.15939514977591, 52.2526455606733, 52.86261054447719, 45.025046007973806, 43.86291115624564, 40.68109130859375, 40.59103570665632, 41.22094896861485, 40.75458587918963, 40.48550646645682, 43.516592093876426, 47.17640284129551, 54.47281040464129, 52.64358942849295, 62.472559792654856, 59.077975681849885, 43.520253794533865, 58.431862694876536, 55.19347756249564, 54.84190913609096, 42.83354595729283, 52.93822431564331, 65.02328518458775, 38.18515246255057, 0.4893305227160454, 1.6537512774978365, 0.840774587222508, 0.33247941785625046, 13.57971739768982, 70.45585932050432, 55.48932491030012, 66.81342601776123, 54.64285019465855, 59.221928460257395, 30.17596742085048, 52.31495353153774, 36.77176032747541, 27.717750344957622, 41.464396476745605, 63.32652119227818, 3.3648382212434496, 0.2222944503383977, 0.07801767824483768, 0.0488172935188881, 0.047420023674411435, 0.018498686474881003, 0.12759731603520258, 0.1805090153855937, 0.1376814456390483, 0.17723930440843105, 0.10686131979205779, 0.22114753616707666, 0.0981432915266071, 0.25902824636016575, 0.23075591772794724, 0.35842358427388327, 0.5237576525126184, 61.580695969717844, 67.45090239388603, 49.88424437386649, 45.38148512159075, 53.793825490134104, 43.7830867767334, 47.92200013569423, 74.22795295715332, 58.81789766039167, 71.24652263096401, 55.407916341509136, 70.69984531402588, 25.303784608840942, 0.17604517777051243, 2.7787120725427354, 1.4132931232452393, 11.530058741569519, 0.30762774710144314, 4.584533904279981, 57.35583339418684, 53.53094734464373, 38.14199720110212, 50.86239440100533, 57.952183382851736, 56.84886850629534, 59.15992273603167, 59.36258084433419, 57.464023794446675, 56.95456797736031, 57.70428555352347, 59.0423036302839, 53.29735238211495, 45.75951228822981, 46.315559250967844, 51.62230151040213, 55.72538300922939, 57.31464099884033, 43.669674805232454, 38.466047286987305, 36.568931988307405, 39.34602969033377, 45.141907760075156, 48.311074938092915, 48.773025921412874, 52.59015083312988, 57.22228554316929, 49.650406224387034, 46.08487558364868, 44.886179310934885, 45.440617765699116, 51.394807066236226, 50.01254633494786, 47.08331435067313, 45.928739139011924, 49.345765931265696, 53.32612834657942, 51.76806429454258, 50.00437525340489, 54.11653109959194, 49.467550482068745, 43.777945109776084, 41.843813283102854, 39.48270075661795, 38.16922371728079, 41.60264825820923, 39.59393794195992, 41.080414703914094, 39.67376926967076, 42.00455985750471, 44.34705121176583, 46.80671351296561, 55.113264083862305, 59.528225898742676, 44.01321111406599, 38.486568791525706, 35.25173071452549, 46.046042101723806, 57.747433866773335, 51.62437207358224, 47.564414569309776, 54.60718856539045, 49.062713691166465, 39.54651996067592, 39.197442463466096, 42.64706325531006, 44.69206748689924, 57.04187904085432, 54.51281465802874, 42.95266934803554, 41.99504777363369, 39.32177700315203, 39.32927758353097, 39.789119788578574, 39.847533294132774, 41.54704877308437, 42.56082568849836, 43.20296777997698, 46.37590088163103, 45.294823714665, 45.57369661331177, 51.47022976194109, 49.61409841264997, 48.01985856464931, 50.93487800870623, 51.92646585191999, 47.32150902066912, 49.98758840560913, 53.95308862413679, 54.77194425037929, 51.432862349918906, 46.41374771935599, 46.7266389983041, 49.049327986580984, 54.365773405347554, 52.0436680657523, 42.986844062805176, 34.93310717173985, 36.7713851247515, 44.26812662397112, 51.563040324619834, 53.964369024549214, 55.24020072392055, 49.6532758304051, 44.81402574266706, 42.84472908292498, 42.17357478822981, 44.58856017248971, 43.61272736958095, 43.18953691210066, 45.47845070702689, 51.462096895490376, 55.88875947679792, 56.90809842518398, 62.186988830566406, 56.75966058458601, 48.76892301014492, 59.90986960274832, 56.522897243499756, 59.61804526192801, 49.158789907182964, 55.35749326433454, 64.56755978720528, 42.03350952693394, 0.8328535322632108, 6.271866151264735, 3.1995275488921573, 0.3657759726047516, 14.994780574526105, 78.03202220371791, 60.76615864889962, 71.10580771309989, 59.783266476222444, 66.6928608758109, 35.418452739715576, 58.93951892852783, 40.92617859159197, 46.214664459228516, 50.36681761060442, 75.57081740243095, 6.6904230288096835, 0.588134232376303, 0.2540130854717323, 0.1958092065261943, 0.19782202637621335, 0.16582386195659637, 0.1719651874154806], [0.07347662334463426, 0.07617579493671656, 0.06637565937957593, 0.04687738225662282, 0.05779026435422046, 0.08079743944108486, 0.09583868804786887, 0.008429337060078979, 0.08582272407199655, 0.12512614578008652, 29.16730785369873, 57.47795145852225, 37.2310015133449, 24.674392461776733, 25.09873284612383, 49.928302901131765, 20.728630338396343, 52.88172851290022, 46.50707244873047, 53.87137433460781, 50.47713763373238, 54.490636008126394, 36.3302127293178, 0.025376164753522192, 0.5291413121989795, 0.1932147464581898, 1.8986000418663025, 0.26577193449650494, 0.7775889177407537, 28.28147680418832, 58.46957751682827, 46.14009986604963, 43.09672287532261, 41.64656434740339, 44.44702884129116, 49.40357494354248, 54.28665426799229, 48.834837096078054, 52.21132114955357, 47.12436778204781, 49.53010858808245, 43.324814864567344, 42.42397396905081, 42.764831747327534, 50.17253902980259, 53.16541303907122, 43.413321018218994, 30.572779042380198, 43.5191525050572, 49.76093121937343, 50.92065157209124, 45.136359623500276, 46.44972896575928, 42.88669272831508, 46.37699522290911, 48.827016898563926, 49.17778975622994, 45.079710960388184, 43.46645736694336, 40.64277894156319, 44.371536663600374, 46.03577961240496, 44.783241748809814, 44.30199214390346, 47.48487854003906, 46.71252720696585, 44.9135274205889, 46.385850702013286, 46.16544689450945, 44.10260316303798, 40.0406619480678, 36.43217406954084, 36.79539462498256, 34.937897954668315, 36.099372727530344, 35.89731911250523, 37.093760694776265, 35.14093821389334, 37.34494502203805, 37.63055419921875, 44.26794249670846, 50.178670815059114, 54.481502601078574, 40.36176947184971, 34.9668094090053, 34.50400032315935, 38.98405981063843, 52.06467941829136, 49.668673038482666, 50.93954719815935, 48.89063113076346, 43.09732042040144, 36.51520504270281, 36.940889903477256, 38.14743069240025, 43.43288367135184, 45.53297669546944, 51.009849071502686, 42.53352621623448, 38.91114888872419, 36.73914548328945, 36.22111211504255, 35.234238624572754, 34.091836656842915, 34.68432344709124, 34.40841742924282, 35.82753487995693, 38.671707017081125, 38.758778367723735, 39.3800550188337, 44.01278379985264, 44.41195086070469, 45.46454736164638, 47.35905361175537, 44.17635481698172, 43.69340985161917, 42.2595865385873, 43.9084392275129, 47.359150886535645, 42.58665909085955, 39.00422695704869, 41.185436725616455, 42.949035440172466, 47.864889417375835, 47.82910966873169, 52.32223871776036, 45.16161285127912, 42.49466494151524, 45.044097968510215, 47.759106567927766, 46.49379791532244, 48.53848947797503, 43.70481531960623, 37.988445486341206, 36.47454071044922, 38.243899481637136, 38.185447760990684, 40.10608271190098, 40.97067832946777, 38.59218488420759, 37.770918233054026, 43.08478934424264, 51.90088258470808, 52.863076073782786, 64.02223736899239, 53.66052082606724, 43.54454469680786, 55.52729334150042, 42.54650545120239, 54.28481994356428, 54.17903014591762, 63.8868864604405, 26.39377110345023, 0.319463704845735, 0.4891198511634554, 0.32796346875173704, 0.299127033246415, 15.587406328746251, 60.540911946977886, 50.56692573002407, 55.279795033591135, 52.41008479254586, 47.75615010942732, 32.81856884275164, 35.19252858843122, 30.431383201054164, 32.87180594035557, 37.920415673937114, 45.54755401611328, 0.5612666883638927, 0.07463718285518033, 0.010350115331155913, 0.007285108191094228, 0.021032460067155104, 0.013075323160072523, 0.037620858422347477, 0.03604279292215194, 0.043742689570145946, 0.012529865821956523, 0.10142390656151942, 0.06155667653573411, 0.04707987746223807, 0.0908602291185941, 0.018841100690354193, 0.07401441662971463, 0.13492337720734732, 35.03876147951399, 67.77285412379673, 42.13521725790841, 33.335282053266255, 39.892717429569785, 52.09029047829764, 24.957826852798462, 58.9111772264753, 51.03016560418265, 62.298653330121724, 55.10162932532174, 60.92853110177176, 38.932691778455464, 0.015826588430042778, 1.0337260620934623, 0.27335469903690474, 5.077819960457938, 0.7283816667539733, 0.5658432713576725, 37.13225718906948, 58.33509513310024, 50.55779927117484, 45.913390568324495, 45.29330553327288, 48.0364647592817, 49.98140798296247, 56.828996658325195, 51.91756868362427, 53.0763440813337, 49.69761575971331, 51.36771951402937, 45.6828875541687, 41.898266315460205, 45.14896018164498, 51.1238968031747, 54.905075209481375, 44.47094454084124, 33.717339175088064, 47.96425560542515, 51.89783232552664, 50.799336024693076, 45.35490478788103, 46.8089508329119, 45.065175328935894, 47.286125319344656, 50.77682386125837, 51.391881874629426, 47.821765422821045, 45.66008704049246, 42.450575147356304, 48.51830496106829, 47.72763122831072, 47.900478090558735, 47.93444435937064, 50.18796055657523, 48.00878661019461, 46.75271558761597, 49.88420615877424, 48.25406149455479, 47.13474839074271, 43.20256131035941, 40.076862062726704, 40.11197131020682, 36.99437713623047, 38.03907700947353, 38.199743679591585, 38.39267430986677, 37.18583474840437, 38.17280551365444, 40.92852708271572, 47.08609710420881, 52.07098143441336, 56.08186728613717, 39.89618110656738, 34.321564946855815, 34.62631641115461, 39.90841688428606, 51.892054898398264, 51.48499468394688, 51.87879426138741, 49.662857396262034, 43.19319861275809, 38.324641023363384, 36.70847960880825, 38.978695801326204, 42.931859493255615, 49.56259141649519, 52.6616929599217, 45.619089194706504, 39.99534579685756, 38.100068296704976, 39.47709356035505, 36.47427667890276, 35.31867660794939, 36.74255010059902, 38.2595329284668, 40.253829206739155, 41.33613967895508, 38.936336108616416, 41.905228410448345, 46.72550991603306, 45.92739118848528, 46.25168793542044, 48.93240717479161, 46.87232535226004, 45.0620243208749, 45.901540415627615, 48.18342958177839, 49.88112463269915, 45.637012072971885, 43.72862332207816, 44.07501881463187, 46.282381602696006, 50.100569588797434, 50.875328472682405, 52.88078008379255, 45.5758227620806, 42.22841691970825, 47.76524182728359, 51.21111754008702, 49.10774149213518, 51.77205603463309, 46.410614081791465, 39.38826431546892, 38.10787807192121, 39.40064600535801, 39.11951494216919, 42.30556624276297, 41.49659442901611, 40.473437445504324, 39.43913207735334, 46.00796249934605, 54.960580893925254, 55.559140409742085, 63.65925652640206, 59.82839502607073, 45.237341267721995, 57.68406629562378, 45.09905821936471, 57.76187569754464, 55.4492963382176, 66.73425824301583, 29.909549168178014, 0.27367960874523434, 1.0871338248252869, 1.0313281736203601, 0.24157594570091792, 16.863081693649292, 67.86923953465053, 54.78846706662859, 62.67191750662667, 61.219132559640066, 54.14679397855486, 36.15901606423514, 42.85286194937569, 34.11462674822126, 35.236941473824636, 43.654336656842915, 57.92768056052071, 1.2964690434081214, 0.0779733427667192, 0.04666898040367024, 0.057496356910892894, 0.04350805216069732, 0.031690045060323815, 0.047366646717169454, 0.23947237857750484, 0.18492152861186437, 0.13709751197269984, 0.19303817807563714, 0.1619207113981247, 0.26038708058851107, 0.2831351842199053, 0.1129102355667523, 0.23974056275827543, 0.2558981371777398, 44.197143827165874, 77.45999091012138, 52.265152318137034, 34.87989091873169, 40.28052418572562, 62.947212082999094, 30.087270191737584, 65.39027513776506, 59.42489228929792, 64.20236246926444, 60.651735714503694, 63.788173403058735, 45.645384652274, 0.11620491663260119, 1.8422694759709495, 0.7783895890627588, 9.059638891901288, 0.6675448683755738, 1.3901117614337375, 47.07322556631905, 60.869339397975374, 52.50833232062203, 48.450077125004356, 51.33297504697527, 49.70795815331595, 55.35802480152675, 58.159152848379954, 53.51740183149065, 55.651409012930735, 51.38733427865164, 52.37736919948033, 47.47175339290074, 46.265504428318565, 47.03931488309588, 51.064111028398784, 56.34438412530081, 48.45425646645682, 38.21077047075544, 47.95564678737095, 50.08812536512102, 50.95179687227522, 46.69733149664742, 49.00402225766863, 46.89746740886143, 49.38108362470354, 52.344945430755615, 52.791773659842356, 51.351346084049766, 47.60618019104004, 44.28363847732544, 51.326238768441335, 51.94331175940377, 51.40860618863787, 51.933782305036274, 52.509193897247314, 51.294680050441194, 50.69046122687203, 52.23502492904663, 49.951377868652344, 48.52948808670044, 46.28978143419538, 43.059414522988455, 42.937647342681885, 39.46932894842965, 40.86893933159964, 41.35689742224557, 41.26765128544399, 40.303487982068745, 41.39306279591152, 42.13609273093087, 49.436335699898855, 53.99944700513567, 58.16746289389474, 40.62012086595808, 35.20650141579764, 34.424321855817524, 39.82495164871216, 52.705883502960205, 54.82599081311907, 54.72069433757237, 52.83346285138811, 43.42235367638724, 37.545695849827354, 35.809076990400044, 38.457719870976035, 44.063724517822266, 53.90679625102452, 59.72577708108084, 48.68244573048183, 42.96910183770316, 40.93451642990112, 41.30723517281668, 38.89951065608433, 36.4366626058306, 38.684234619140625, 39.89416265487671, 41.88444287436349, 44.507016113826204, 42.75204358782087, 46.148865018572124, 50.719723565237864, 50.54665436063494, 50.54493120738438, 54.08652182987758, 48.70170266287667, 50.76179838180542, 46.77356365748814, 51.45747981752668, 52.96457883289882, 47.81505693708147, 43.79713256018502, 44.91043894631522, 47.65078067779541, 51.43298394339425, 51.702320439474924, 53.1592777797154, 47.524806363242014, 42.32585845674787, 48.94698796953474, 52.678521496909006, 51.27959898539952, 54.91554961885725, 47.003399644579204, 41.58953700746809, 40.487372057778494, 41.55425405502319, 41.21025916508266, 45.24684987749372, 44.0455584526062, 44.701784542628694, 41.31197731835501, 48.31604984828404, 57.99575901031494, 58.87501185280936, 62.11818776811872, 59.93470941271101, 51.635298115866526, 60.16172790527344, 50.09600114822388, 58.79707390921456, 57.17676789419991, 68.83790874481201, 34.0385092326573, 0.42202047311833923, 2.2460405869143347, 1.5988382526806422, 0.35217576952917234, 18.665458304541453, 72.72797584533691, 59.03822503771101, 67.05343764168876, 61.9976156779698, 60.053085872105186, 39.83522456032889, 50.476762431008474, 44.92343555177961, 49.42587171282087, 51.696789673396516, 72.24021925245012, 3.005395314523152, 0.2419468600835119, 0.10722846830529825, 0.14167568273842335, 0.1121643152354019, 0.13512035592326097, 0.10092312736170632], [0.032321031737540445, 0.05774246834750686, 0.01970094535499811, 0.08900375730757203, 0.029770455921867063, 0.09658876779888358, 0.08165993208863906, 0.04727422346227935, 0.12884691969624587, 0.2627386658319405, 14.00565847328731, 60.348391260419575, 34.02553694588797, 33.20062943867275, 22.116135222571238, 47.96048273359026, 40.49931948525565, 31.411506516592844, 60.602139472961426, 40.240037032536094, 58.78062057495117, 49.97911507742745, 55.95161288125174, 6.106246718338557, 1.4565088557345527, 0.7606029606291226, 4.234332970210484, 1.8869047037192752, 0.39776865446141785, 21.298424312046595, 46.71893344606672, 47.06245585850307, 56.18454776491438, 55.29667220796858, 52.99729790006365, 50.93541996819632, 50.02069309779576, 50.21084792273385, 47.156638690403526, 43.692298139844624, 43.32142414365496, 40.259419032505576, 42.69104535239083, 45.55563129697527, 49.58553784234183, 47.63436903272356, 46.34307411738804, 58.56833921160017, 61.37143012455532, 53.411226408822195, 51.26915584291731, 50.28193146841866, 51.46544592721121, 50.14751161847796, 48.08552598953247, 51.1211314201355, 49.6589629309518, 45.60242394038609, 43.53553983143398, 41.24194642475673, 44.585350104740684, 48.204923834119526, 46.23124633516584, 44.76665639877319, 44.70142323630196, 43.33896834509713, 43.41619062423706, 44.764874185834614, 47.737188475472585, 48.23810148239136, 42.63915620531355, 36.88632917404175, 37.5622673034668, 35.87096112115042, 36.030436175210134, 36.39607122966221, 36.15594148635864, 36.742727279663086, 37.15946633475167, 40.190663133348735, 48.75360223225185, 48.83085925238473, 52.15228578022548, 42.39693852833339, 34.59782532283238, 38.49766853877476, 37.96720484324864, 49.22075046811785, 50.02482032775879, 48.75286224910191, 46.10106141226632, 39.75708859307425, 39.01818936211722, 36.763846329280305, 37.7352739742824, 39.563688959394185, 48.18753596714565, 48.35369866234915, 46.21187823159354, 44.5030973298209, 36.351776463644846, 37.15098605837141, 37.03960990905762, 34.68732506888253, 33.776027134486604, 33.77123982565743, 36.07107271466936, 34.89438486099243, 36.193777901785715, 42.28243568965367, 43.956687518528526, 44.85398135866438, 43.186816692352295, 45.21534674508231, 46.01213836669922, 44.92333132880074, 43.211104120527, 44.754128796713694, 44.22560017449515, 39.49937643323626, 40.363899094717844, 43.269816398620605, 40.50988074711391, 49.49568721226284, 45.614638873508994, 48.10861137935093, 45.992506231580464, 47.008812291281565, 48.00911317552839, 51.76024409702846, 47.72401816504342, 47.33758020401001, 39.07933350971767, 39.53958913258144, 35.884110586983816, 36.741559982299805, 40.7374655178615, 49.77623462677002, 47.672813415527344, 48.67076233455113, 36.93694332667759, 39.879185812813894, 42.820184571402415, 53.635562896728516, 52.35345349993025, 66.12091990879604, 53.70565979821341, 51.57479667663574, 51.310973576136995, 57.183709144592285, 50.43913446153913, 59.33020223890032, 17.665133101599558, 0.021330230071076324, 0.6311462415116174, 0.1427936234644481, 1.4194557411330087, 36.99098988941738, 55.70724821090698, 53.35881962094988, 54.615672315870015, 46.71304137366158, 39.88139533996582, 36.00491544178554, 51.00076082774571, 30.135803358895437, 30.72185264314924, 42.08698286328997, 37.21005269459316, 0.16292733166898998, 0.06483074370771646, 0.02454491355456412, 0.02468485800948526, 0.06683507508465222, 0.0593240452664239, 0.06339706706681422, 0.05897398905030318, 0.011551078209387404, 0.017256885966552154, 0.015689164732715914, 0.09281028447938816, 0.14186993374356202, 0.08639198102589164, 0.02899452737931694, 0.04464994178020528, 0.3061750036265169, 17.49928481238229, 69.86479691096714, 37.149078777858186, 34.278569493974956, 32.72033173697335, 50.04477208001273, 42.23123441423689, 40.1626375743321, 63.07626792362758, 45.06823253631592, 67.04628794533866, 54.19496931348528, 60.040815353393555, 6.554881479058947, 2.1667212545871735, 0.8043773717113903, 5.6473889861788065, 2.911743585552488, 0.36831513206873623, 30.88467672892979, 50.459860937935964, 49.99722555705479, 59.90336608886719, 57.1893059185573, 56.17833260127476, 54.08925247192383, 52.57432631083897, 52.59022031511579, 48.42335435322353, 46.45038904462542, 43.52440881729126, 42.70627580370222, 44.356910705566406, 46.57851382664272, 51.005106925964355, 50.447708538600374, 48.84634678704398, 60.219307626996724, 60.28428718021938, 53.26992436817714, 51.74732739584786, 52.06471068518502, 51.356696196964805, 51.38179309027535, 51.63343947274344, 52.987073625837056, 51.48201390675136, 47.952554838997976, 45.22374711717878, 42.29900714329311, 47.669898646218435, 49.830322878701345, 48.11534765788487, 48.08644315174648, 46.05511992318289, 46.04389163425991, 47.112913676670615, 48.108013834272114, 49.27474839346749, 49.837465626852854, 43.18145268304007, 39.81949731281826, 39.470878396715435, 37.42581857953753, 37.18687697819301, 37.34586565835135, 37.034152099064414, 37.654115540640696, 40.47546284539359, 41.31248106275286, 49.46076556614467, 51.52883434295654, 54.109923362731934, 41.056252343314036, 33.434856687273296, 37.957168170383994, 37.397337913513184, 50.29422977992466, 50.86661543164934, 48.82954256875174, 48.00621230261666, 39.45902476991926, 39.342868259974885, 33.96211378914969, 37.051887375967844, 39.000263009752544, 49.84030049187796, 53.22246469770159, 48.18378741400582, 44.9976110458374, 37.79449347087315, 39.74298027583531, 38.52813638959612, 35.66249779292515, 37.21652841567993, 37.01361322402954, 38.74770988736834, 39.6576737676348, 37.895958014896934, 44.6153176852635, 44.679234164101736, 48.28814588274275, 46.89453179495675, 48.389905725206646, 47.85357427597046, 47.64692790167672, 45.41221700395857, 46.32309457233974, 47.059732164655415, 41.997205189296174, 42.01888704299927, 44.15488140923636, 43.22848156520298, 50.73685434886387, 49.364671979631694, 51.335045610155376, 49.94761194501604, 47.950779574257986, 47.9420039994376, 53.64260489600045, 50.0500978742327, 47.67874717712402, 42.79313176018851, 39.8244548525129, 37.229538917541504, 39.26382902690342, 42.490159034729004, 50.64130619594029, 50.20418460028512, 50.39428383963448, 40.722092628479004, 42.47515787397112, 44.05031449454171, 55.30216475895473, 53.033164501190186, 67.08079964773995, 58.61124433789934, 51.84926789147513, 55.04920169285366, 58.18101535524641, 54.4276888029916, 62.014472007751465, 20.556719745908463, 0.05556729542357581, 1.0579521507024765, 0.7100171436156545, 2.9524760970047543, 42.708923067365376, 61.85753999437605, 59.41046782902309, 64.25472409384591, 54.681016649518696, 45.54464619500296, 40.030246598379954, 56.549908365522114, 38.39155217579433, 35.1030809538705, 50.1287966455732, 45.84903635297503, 0.15684214819754871, 0.08998928192470755, 0.029415113917951072, 0.046168146921055656, 0.06451227329671383, 0.059050208888947964, 0.026517336822247932, 0.15871562409613812, 0.13454965368977614, 0.21758140038166726, 0.15835336782038212, 0.14562745711633138, 0.30586743727326393, 0.2605344312531607, 0.13470973367137568, 0.3455839646714074, 0.3777034511523587, 22.808577060699463, 82.63351535797119, 47.10197721208845, 42.98880345480782, 33.04216882160732, 62.024324553353445, 48.664679186684744, 40.87388644899641, 70.48234585353306, 50.037320137023926, 68.37597860608781, 58.51010635920933, 65.86487184252057, 8.430770465305873, 1.8706374508993966, 2.9683631530829837, 14.143042598451887, 4.682485265391214, 0.24120763689279556, 37.97901678085327, 52.03469099317278, 54.66157558986119, 62.13523169926235, 58.98102746691023, 56.85068198612758, 56.03364331381661, 54.1884241104126, 56.813147817339214, 49.43631138120379, 47.59641102382115, 45.323676109313965, 43.83905104228428, 45.67994499206543, 48.83912760870797, 52.50391674041748, 51.26932954788208, 51.24168266568865, 59.75362546103341, 59.090753419058665, 55.01887975420271, 55.27665792192732, 55.7729469026838, 53.076500415802, 51.507805619921, 53.66465500422886, 54.98083141871861, 54.421803678785054, 50.33254214695522, 48.16330412455967, 43.95833771569388, 48.60821465083531, 53.287812505449565, 52.108981132507324, 51.54297045298985, 49.59098175593785, 47.15798316683088, 49.9695474079677, 50.86484016690935, 52.99729095186506, 54.080330984933035, 48.10031175613403, 41.23074245452881, 41.86945908410208, 40.1935327393668, 39.89787299292428, 39.979962485177175, 39.50499405179705, 42.0109452520098, 42.67932026726859, 44.939840248652864, 52.99969155447823, 53.270483698163716, 57.00231599807739, 41.02598251615252, 32.83162450790405, 38.86789287839617, 36.885460649217876, 51.938746792929514, 53.41908482142857, 50.91101789474487, 47.48601804460798, 39.456780501774375, 39.96642392022269, 35.58992733274187, 38.55658578872681, 39.32283660343715, 50.630480902535574, 55.48930753980364, 52.626785210200715, 47.8100403376988, 40.378907203674316, 41.42950957162039, 41.38604164123535, 37.81149571282523, 38.189755644117085, 38.57385206222534, 41.10345493044172, 42.638871329171316, 40.68741416931152, 47.7260331426348, 47.62975195475987, 50.957358905247276, 49.536879607609336, 49.85770920344761, 51.666731766292024, 50.347887243543354, 48.610656942640034, 49.846435751233784, 48.93426929201399, 44.61391414914812, 44.26339142663138, 46.902324199676514, 45.24266011374337, 52.639024462018696, 50.75303670338222, 53.39271988187517, 50.229719230106895, 50.86515630994524, 51.52328968048096, 55.667838028499055, 51.99088607515608, 49.71624388013567, 44.48724501473563, 43.395689964294434, 40.36778661182949, 41.26037652151925, 45.522724628448486, 53.1854863848005, 54.24719544819423, 52.174471378326416, 42.86121368408203, 45.144454274858745, 46.57392454147339, 57.7361604145595, 55.76278863634382, 64.75582122802734, 60.164270945957725, 56.93885462624686, 55.20070021493094, 60.730132239205496, 55.73069143295288, 61.9966915675572, 23.467441729136876, 0.15165822207927704, 1.7539803449596678, 1.277554526925087, 3.2412564754486084, 43.92544494356428, 68.06319849831718, 61.64612020765032, 68.67826693398612, 57.54374047688076, 51.73157582964216, 43.80718312944685, 65.8999741418021, 43.492391518184114, 45.605338709695, 58.715022632053916, 58.93129920959473, 1.1988941878080368, 0.30038207875830786, 0.09587226874594178, 0.1727382695036275, 0.26523168491465704, 0.19352797179349832, 0.1278215175760644], [0.00865651058432247, 0.03908430578719292, 0.025537564485732998, 0.014719544976417507, 0.038827215653977225, 0.08900847312595163, 0.0823785210294383, 0.010887918794261557, 0.06793857658548014, 0.13558352392699036, 1.7883407069104058, 39.772999967847554, 38.41798659733364, 40.956924370356965, 30.495560237339564, 46.10458067485264, 52.29013804027012, 20.41909330231803, 60.60528700692313, 50.17518629346575, 39.675148487091064, 52.414840834481375, 52.73882838657924, 46.72684744426182, 1.888677362884794, 0.6743817329406738, 1.4297296298401696, 3.115752249956131, 0.1916273409234626, 13.069030012403216, 50.17656898498535, 49.20753846849714, 52.49455404281616, 50.181578636169434, 52.16325698580061, 47.41879422324044, 49.15281098229544, 43.56924901689802, 43.53717613220215, 40.19900097165789, 41.420608929225374, 40.94623804092407, 41.00969246455601, 44.024012088775635, 49.20439093453543, 54.12853063855852, 61.958552905491416, 52.11854880196707, 46.260394028254915, 51.16108356203352, 52.55552448545183, 51.65132761001587, 48.895216941833496, 51.22685520989554, 53.57706948689052, 51.001479966299875, 50.62079858779907, 45.047700609479634, 44.6655079977853, 40.87671089172363, 42.69869531903948, 46.92013938086373, 47.09180504935128, 47.70737028121948, 44.040757247379844, 45.367244788578574, 43.98143352781023, 46.9651254926409, 48.335008008139475, 45.325072697230745, 43.76600810459682, 38.515560150146484, 38.030537673405235, 34.529614857264924, 35.8931884084429, 34.33860887799944, 36.860669476645334, 35.474208559308735, 36.17586891991751, 41.431722572871614, 46.810990129198345, 49.59440721784319, 47.02565125056675, 44.660804067339214, 35.79621934890747, 35.566105433872764, 37.73779617037092, 42.89490897314889, 49.43212161745344, 49.62067835671561, 40.50837298801967, 38.57707602637154, 39.52157245363508, 35.064442021506174, 39.49570083618164, 38.235384464263916, 49.43235785620553, 49.52291372844151, 45.986520358494346, 44.00706195831299, 37.707022598811555, 34.93699468885149, 36.21411875316075, 36.158060686928884, 35.301691736493794, 35.38091162272862, 35.47611583982195, 35.50629881450108, 37.031556946890696, 45.40239919934954, 45.313882623400005, 43.995868410382954, 43.574046748025076, 46.10047776358468, 43.702126366751536, 42.910274914332796, 45.67101655687605, 44.1766813823155, 46.08442742483956, 37.675536836896626, 40.69906629834856, 40.66448858806065, 39.48812729971749, 45.49964618682861, 47.80687195914132, 49.06619126456124, 48.923367568424766, 50.04711709703718, 49.32971559252058, 48.01130533218384, 47.213106700352256, 42.5757851600647, 38.82888569150652, 37.97833933149065, 34.64929757799421, 38.12918472290039, 45.52904748916626, 52.147578375680105, 50.22161415645054, 53.02405888693673, 47.56535952431815, 43.54722670146397, 37.98926189967564, 43.12397371019636, 50.57800810677664, 56.42244713647025, 59.5265930720738, 57.39279086249215, 49.109732151031494, 56.788436549050466, 53.658689975738525, 59.56437042781285, 8.468590378761292, 0.7725827406559671, 0.0848374640835183, 0.8682816912020955, 8.105150086539131, 45.86731011526925, 53.15014089856829, 53.932480267116, 41.95205579485212, 42.831065450395855, 41.16531474249703, 42.16697399956839, 36.25287927900042, 27.18646502494812, 47.714756216321675, 41.34018005643572, 28.367868968418666, 0.2461374652172838, 0.013873224362864025, 0.08702229934611491, 0.0129286535749478, 0.06293529005987303, 0.09732364836548056, 0.019594715608816062, 0.023954923963174224, 0.027163497238819088, 0.07491074103329863, 0.07838123052247933, 0.015725851424836686, 0.049019839614629745, 0.037343347777745554, 0.03782526031136513, 0.06469180009194783, 0.09191887266933918, 3.4410510574068343, 55.51486301422119, 42.90685640062605, 42.154922349112375, 39.664326667785645, 55.50212001800537, 55.28515209470476, 24.17100589615958, 66.7249059677124, 54.15660483496529, 45.21270642961775, 57.688495772225515, 59.723755155290874, 49.62800523212978, 3.3611129011426653, 0.33658718743494576, 4.663983081068311, 8.570722818374634, 0.14691347096647533, 15.112153019223895, 54.35720975058419, 50.43886348179409, 56.184158665793284, 52.58532530920846, 55.56191968917847, 48.48229244777134, 51.302389076777864, 45.409625325884136, 46.13992963518415, 41.248335293361116, 44.01168251037598, 40.92073467799595, 43.30201087679182, 46.68156950814383, 53.111067703792024, 56.27744518007551, 60.993628774370464, 52.77848523003714, 49.43786082948957, 52.64387430463518, 54.48193686349051, 51.85516691207886, 51.01487956728254, 53.85913508278983, 52.8447710445949, 50.58415378843035, 51.05863584790911, 46.70913648605347, 44.52564423424857, 42.581965582711355, 44.798121316092356, 49.718682697841096, 50.130359990256174, 50.93148381369454, 45.34029620034354, 48.21136481421334, 48.1264647756304, 49.69579185758318, 50.38414294379098, 47.50066484723772, 45.25696645464216, 39.55965553011213, 39.28915868486677, 37.38638755253383, 38.061787196568076, 37.99732181004116, 37.91837637765067, 37.77490302494594, 40.38781826836722, 43.95738928658621, 49.54437671388899, 49.16801364081246, 51.644806725638254, 45.906289509364534, 34.88876029423305, 35.902266229902, 35.63829026903425, 44.60075078691755, 51.4579245022365, 49.169524874006, 42.21723031997681, 36.66100951603481, 38.27104261943272, 34.90956667491368, 39.089926038469585, 37.71079199654715, 50.3032728603908, 55.505260603768484, 48.96359763826643, 46.09391866411482, 38.73039150238037, 36.487641538892476, 37.0289374760219, 37.77067852020264, 36.87582349777222, 36.42240490232195, 36.964256695338655, 37.357583795275005, 40.27988147735596, 45.62956012998308, 48.01247262954712, 48.14146941048758, 47.66503838130406, 47.643443380083355, 47.5270471572876, 44.671900340488975, 48.26989991324288, 47.95409386498587, 47.48890502112252, 39.02162177222115, 42.591974462781636, 43.469865458352224, 42.158326966421946, 47.85257026127407, 50.58303165435791, 52.53249815532139, 49.8846195765904, 50.41903679711478, 50.192796502794536, 51.344939844948904, 49.91487898145403, 45.35210813794817, 42.65929555892944, 40.22579322542463, 37.48549665723528, 41.13568762370518, 47.436456544058665, 53.97876916612898, 52.38413674490792, 55.41118546894619, 50.1613906451634, 44.963022913251606, 39.89058085850307, 45.60659980773926, 52.2042235646929, 56.31800528935024, 59.78500352587019, 61.99281447274344, 50.28680215563093, 59.197213717869346, 55.73637158530099, 62.0488030569894, 10.041765894208636, 2.190709258828844, 0.9924685273851667, 1.4197992427008492, 16.017030818121775, 52.327331747327534, 59.16010338919503, 58.853048597063335, 48.11995083945138, 42.66226938792637, 46.87986414773123, 41.74289417266846, 44.45157296316964, 37.182308537619456, 48.928564820970806, 49.1793600491115, 35.326062543051584, 0.2747092992067337, 0.04137161001563072, 0.03132791770622134, 0.012847013089672794, 0.05158099379124386, 0.024343882288251604, 0.06841656379401684, 0.1530355667429311, 0.11668669006654195, 0.15487097682697432, 0.15713033559066908, 0.11633674241602421, 0.17043348960578442, 0.18991106801799365, 0.10876107535191945, 0.1683589502104691, 0.23004964419773646, 6.229680163519723, 74.38079942975725, 51.67424276896885, 55.40719025475638, 44.52022811344692, 62.53673335484096, 57.347221102033345, 29.515266690935405, 69.02531555720738, 59.17812006814139, 48.312686920166016, 63.42967414855957, 60.96983814239502, 54.593719482421875, 4.502471770559039, 1.4976584762334824, 10.571810960769653, 7.603013328143528, 0.13940576596983842, 21.18222611291068, 58.01398066111973, 50.95182466506958, 59.41790934971401, 54.726145199366975, 57.32180806568691, 51.57413312367031, 53.51055785587856, 48.49837057931082, 47.78443969999041, 43.46700280053275, 48.13666125706264, 42.25931903294155, 44.13141734259469, 49.42995377949306, 54.999181611197336, 58.48081970214844, 59.945896012442454, 52.75766495295933, 51.953813961574006, 55.673660618918284, 55.359080927712576, 55.017934799194336, 51.12851388113839, 55.57254695892334, 55.928645610809326, 54.34480026790074, 54.60612549100603, 48.57839298248291, 47.246336460113525, 45.56311798095703, 47.11427552359444, 53.751625605991904, 53.50264385768345, 54.427410875047954, 48.55927848815918, 52.170173917497905, 49.56315769468035, 51.87880120958601, 53.682939188820974, 49.9688595363072, 47.61774894169399, 43.37409496307373, 41.167204652513774, 39.33933857509068, 41.237325872693745, 40.33014474596296, 41.59589808327811, 40.758897236415315, 41.82312849589756, 46.49299887248448, 52.61493853160313, 53.766960280282156, 52.55627836499895, 48.398660455431255, 35.18354109355381, 36.34557172230312, 36.864921774183, 46.32779155458723, 54.69025427954537, 51.726124967847554, 42.973506995609824, 37.400006021772114, 39.300703116825645, 36.31071955817086, 41.33515303475516, 39.20518275669643, 52.09887497765677, 58.43262004852295, 51.6946565764291, 47.322877815791536, 40.90465307235718, 39.07128749574934, 39.07055098669869, 39.63195153645107, 38.62872893469674, 38.56776544025966, 39.77892330714634, 38.635176862989155, 41.47061858858381, 49.04898752485003, 51.407400676182334, 50.07295049939837, 50.47037703650338, 50.979468073163716, 48.44900710242135, 48.94435460226876, 51.931586674281526, 51.07435267312186, 51.48296928405762, 40.43431561333792, 43.78830834797451, 44.62831776482718, 43.19129480634417, 49.940754073006765, 51.43951872416905, 54.043498584202354, 51.495246750967844, 52.60765681947981, 52.54593249729702, 54.34334462029593, 52.57659837177822, 47.00468158721924, 43.820190157209126, 42.863461426326204, 38.776305198669434, 42.091704164232524, 49.290531226566856, 55.37315450395857, 53.86290448052542, 59.18936225346157, 51.69097750527518, 48.39870909282139, 41.49201556614467, 48.471140589032856, 56.31015729904175, 60.752581868852886, 60.24784387860979, 66.60307625361851, 54.047153336661204, 60.98165007999965, 57.70235048021589, 64.73139830998012, 12.26948343004499, 2.348628133535385, 2.0169111447674886, 2.030530048268182, 15.150460175105504, 56.27060815266201, 63.750500270298545, 62.214573178972515, 53.06169033050537, 53.94543170928955, 52.361846923828125, 50.831221308027, 50.455539158412385, 39.82504892349243, 63.46884114401681, 56.91514042445591, 47.317750045231406, 0.35212990056191174, 0.1751801948994398, 0.11591595570955958, 0.18302344903349876, 0.11667923975203719, 0.1779776183622224, 0.1613740428750004], [0.040738699691636224, 0.04099117239405002, 0.034291036027882776, 0.057972186378070285, 0.04861789243295789, 0.046696807124785016, 0.017178192867764404, 0.09828916977026633, 0.02949178498238325, 0.039976067042776516, 0.5850650827799524, 36.53660202026367, 43.39275435038975, 37.1637533732823, 28.286060878208705, 36.097965717315674, 36.40778589248657, 28.124640328543528, 59.09039906093052, 52.6415570804051, 47.3838552066258, 52.56686394555228, 48.656640120915, 55.391126019614084, 24.036445345197404, 0.47884341116462437, 3.4563472994736264, 5.126304055963244, 0.12795989800776753, 3.130299823624747, 51.18343939099993, 46.25084720339094, 53.837970869881765, 53.90564979825701, 51.368556771959575, 45.23520469665527, 44.48176636014666, 40.38741874694824, 42.06963668550764, 40.456681864602224, 43.046699319567, 40.68132059914725, 42.08452320098877, 42.499198641095845, 45.54917294638497, 48.53944485528128, 49.04694822856358, 47.13779517582485, 52.12628214699881, 48.67874581473214, 50.00461496625628, 49.72006886345999, 53.041009017399375, 51.36252920968192, 52.633695193699424, 48.8909125328064, 49.38567290987287, 44.20909820284162, 42.864809376852854, 40.61337763922555, 39.73834235327584, 47.31206294468471, 46.680381366184776, 45.098224435533794, 46.715626103537424, 46.09619072505406, 47.42414781025478, 47.28990861347744, 47.10965844563076, 44.832507950919016, 44.18722874777657, 38.18304715837751, 36.24369028636387, 35.20234291894095, 37.56696775981358, 34.48963144847325, 34.93741852896554, 34.852101598467144, 39.76240049089704, 45.26295927592686, 46.58469077519008, 48.05357122421265, 48.43688596997942, 47.351577350071494, 37.70263828550066, 36.34010696411133, 35.24401126589094, 42.42508915492466, 49.145369461604524, 46.821391582489014, 38.209648336683, 37.79177672522408, 38.75785773141043, 37.023483140128, 37.719869818006245, 36.38649661200387, 47.33116006851196, 52.01154654366629, 49.725457191467285, 43.497769423893516, 39.38736799785069, 37.20267023359026, 33.897940226963584, 36.37774535587856, 36.3525789805821, 35.13584171022688, 36.075095721653526, 37.20716919217791, 40.16642781666347, 44.64653941563198, 46.27532918112618, 44.5294622693743, 45.175745487213135, 43.86932781764439, 43.36130332946777, 43.6658741406032, 44.1040483883449, 43.75251817703247, 44.10743563515799, 38.85687303543091, 42.694918973105295, 40.975531646183555, 41.4908378464835, 44.95578636441912, 46.48428235735212, 47.03036560331072, 49.678636755262104, 46.193757329668315, 49.00200728007725, 50.47329180581229, 48.86179610661098, 43.99691064017159, 39.151924814496724, 38.56610482079642, 35.96463326045445, 37.284658976963584, 47.78094128199986, 52.17728887285505, 51.06100518362862, 53.07791437421526, 50.91855321611677, 50.96135411943708, 41.237437043871196, 40.448055676051546, 41.157119342258994, 48.631890637534006, 49.778544902801514, 52.054580211639404, 52.06352949142456, 54.99384192058018, 52.686400754111155, 40.552038942064556, 11.473185999052864, 2.3634145515305653, 0.2354439433131899, 1.2670423367193766, 40.84292527607509, 49.418457984924316, 53.811946392059326, 48.78624139513288, 43.23371008464268, 63.66833087376186, 45.6133326121739, 46.79252529144287, 38.05773639678955, 23.94041429247175, 41.52793427876064, 45.736253193446565, 13.900450587272644, 0.2602878787687847, 0.03751776181161404, 0.14518810569175652, 0.007533201798131424, 0.08685669608946357, 0.01836245191017432, 0.02863373334652611, 0.047750768783901415, 0.04941770201548934, 0.05718014602150236, 0.05826809549970286, 0.08645539012338434, 0.047153603684689314, 0.055720562913588116, 0.0560412690974772, 0.007565342305627252, 0.05112907929079873, 1.448176337139947, 49.30901690891811, 49.74339049203055, 36.924176011766704, 31.842128072466167, 45.184020791734966, 37.117822306496755, 29.94897324698312, 65.1725880759103, 58.66714954376221, 46.67251600537981, 59.10436494009835, 52.79595994949341, 61.40838064466204, 28.316690274647303, 0.38762371454920086, 0.41420214836086544, 8.887502482959203, 0.10770329354064805, 5.103760625634875, 57.569018023354666, 46.022348744528635, 57.49110092435564, 55.164090156555176, 53.84703132084438, 46.64972938810076, 46.30410167149135, 42.00769349506923, 44.652789320264546, 41.57392093113491, 43.61671910967146, 41.413125719342915, 43.96757534572056, 44.64332239968436, 48.629375389644075, 49.643725531441824, 51.64647429330008, 49.50506728036063, 54.98275259562901, 51.01848568235125, 50.72365971973964, 50.937473160879954, 54.5251407623291, 52.131576674325125, 52.024164472307476, 49.04793834686279, 50.895422663007466, 45.95810570035662, 44.946788447243826, 42.61925656454903, 40.8473755972726, 48.11389201028006, 49.807056835719514, 48.878794874463765, 48.35284055982317, 48.423871994018555, 48.313604082380024, 50.2290278843471, 47.30240842274257, 47.733113356998985, 46.477681568690706, 40.35592256273542, 39.05342020307268, 37.92249665941511, 38.561994961329866, 37.354623862675254, 36.95289291654314, 37.17921658924648, 41.04249491010393, 47.35971369062151, 49.06924499784197, 50.64401946749006, 50.67691918781826, 47.340759004865376, 38.00738974979946, 36.17870378494263, 35.568843024117605, 42.43402106421334, 51.573108264378135, 48.249486105782644, 38.100589411599294, 38.06287458964756, 37.87018714632307, 37.48725455147879, 38.12515476771763, 37.61413213184902, 47.857625075748985, 53.67028651918684, 51.46851008278983, 46.82104764665876, 41.22550351279122, 39.110371112823486, 37.2814176423209, 38.806526388440815, 37.31819445746285, 37.126702104296, 38.22014011655535, 39.83831303460257, 42.115321091243196, 45.66315467017037, 46.84895856039864, 46.524484634399414, 46.889702796936035, 47.21696989876883, 47.07074853352138, 47.12674059186663, 47.46416596003941, 46.383140904562815, 43.965681961604524, 40.15269470214844, 44.53589630126953, 44.075873443058555, 45.021262713841026, 46.959323746817454, 48.98123564038958, 50.292704650333945, 49.182948793683735, 49.40458938053676, 49.73533752986363, 51.30900723593575, 50.79787342888968, 46.79200070244925, 41.869445187704905, 39.675516741616384, 38.849358558654785, 39.62904371534075, 48.829924719674246, 53.94686303819929, 53.04051916939871, 53.543353353227886, 53.609614849090576, 52.91657372883388, 44.59785686220442, 43.25519391468593, 44.4225503376552, 50.36586223329817, 50.39784479141235, 52.78139305114746, 54.91470193862915, 56.08761692047119, 57.231137548174175, 41.57663767678397, 16.203126158033097, 3.307702532836369, 0.5001848574195589, 2.7889852012906755, 45.42166655404227, 53.15148884909493, 61.22293322426932, 52.26508631025042, 44.813622747148784, 64.94015693664551, 50.96939665930611, 50.78048208781651, 47.308977944510325, 30.41263348715646, 46.26370137078421, 55.30382537841797, 18.77634981700352, 0.3080134806888444, 0.01952835658032979, 0.10484622006437608, 0.047662620299628804, 0.0846952363582594, 0.01366464524263782, 0.034593089284109216, 0.16330336220562458, 0.09774368189807449, 0.18245365603693894, 0.12774428672024182, 0.18741164356470108, 0.1572101041674614, 0.13263817983014242, 0.19642927896763596, 0.11570752332253115, 0.18608449692172663, 1.4860670353685106, 64.04935618809291, 57.82429831368582, 51.760185037340435, 40.689884253910606, 51.17552191870553, 45.74015808105469, 36.58037914548601, 69.81884847368512, 64.17469474247524, 54.93698828560965, 63.968465260096956, 56.946716512952534, 65.86421176365444, 34.643005984170095, 0.4463754562394959, 11.31250022138868, 13.002231768199376, 0.23158375759209904, 8.969100390161787, 59.87653909410749, 48.52372803006853, 60.021075521196636, 55.827594484601704, 56.88623939241682, 48.64830923080444, 50.31237847464425, 43.31687307357788, 47.431926318577354, 44.94986302512032, 45.989393438611714, 44.97982713154384, 45.427197320120676, 46.664612429482595, 52.174401896340505, 51.1224376814706, 53.95778213228498, 52.726874010903494, 56.04216180528913, 53.62252460207258, 53.01179879052298, 53.45727212088448, 56.70375190462385, 54.54916068485805, 56.731735774448936, 49.8572540964399, 53.471939768110005, 48.021901335035054, 47.0139331136431, 44.1872113772801, 43.18521165847778, 49.78196341650826, 51.60829046794346, 51.759500639779226, 53.015807901109966, 50.57466949735369, 52.30366618292672, 53.60961137499128, 52.52909353801182, 48.06016159057617, 48.961186613355366, 42.65581103733608, 41.16550234385899, 38.78398643221174, 42.22343853541783, 40.20961087090628, 39.55264827183315, 38.4213946887425, 44.62569481985909, 50.71914686475481, 53.17292404174805, 52.57611199787685, 52.944102491651265, 50.767711298806326, 40.52719218390328, 36.72796583175659, 34.76016650881086, 44.45579399381365, 54.141482080732075, 49.498386587415425, 37.173647608075825, 37.6738657951355, 38.73474107469831, 36.9606887953622, 39.23246485846383, 36.82070343835013, 50.11558812005179, 55.810769421713694, 53.76934698649815, 50.860125814165386, 44.19634825842721, 42.674963746752056, 38.3267046383449, 41.76779651641846, 39.826035567692344, 39.791652406964985, 40.55438395908901, 43.06436858858381, 46.178408758980886, 49.066000189099995, 51.06407976150513, 49.15472173690796, 49.41880539485386, 49.74164302008492, 48.83944027764456, 50.52452434812273, 48.62226390838623, 48.08495276314871, 48.42557430267334, 42.79120363507952, 47.034503255571636, 46.34343542371477, 47.065054484776084, 50.96793058940342, 51.860652514866416, 51.440613065447124, 51.261245318821494, 50.05274861199515, 52.880866936274934, 52.85509606770107, 54.078538349696565, 48.780762740543906, 43.9977513722011, 41.68549510410854, 40.489578110831125, 42.54103027071272, 51.7536016191755, 57.138997486659456, 55.998325620378765, 55.179754870278494, 55.528672558920725, 55.401801926749094, 47.60217455455235, 43.9242706980024, 45.80019746507917, 52.933725357055664, 53.37866020202637, 53.34380456379482, 56.34899772916521, 59.2060101372855, 58.326847621372764, 45.12512786047799, 19.174651827130997, 5.829100012779236, 2.1159546758447374, 2.8256430285317555, 54.90410940987723, 59.95620713915144, 64.46544211251395, 59.522917475019185, 51.94273158482143, 73.66913713727678, 56.63602433885847, 59.84681470053536, 51.95459910801479, 36.29609360013689, 57.63334444590977, 65.77535125187465, 27.33438175065177, 0.5912079960107803, 0.1431328502616712, 0.20349176999713692, 0.11895246777151312, 0.1644389991249357, 0.09254577795841865, 0.08025704058153288], [0.014606468811897295, 0.05438072766576495, 0.0031079452601261437, 0.09289428032934666, 0.059975058904715946, 0.06363349580871207, 0.011739234273721064, 0.0762601639809353, 0.060979541790272505, 0.2752509872828211, 0.07413983025721141, 26.953940085002355, 48.47215155192784, 36.673370361328125, 32.05002859660557, 36.04776150839669, 41.752573013305664, 26.148192235401698, 61.43939740317208, 50.56894418171474, 61.508941922869, 49.28293684550694, 53.97030626024519, 41.377846240997314, 40.24905579430716, 1.8238721660205295, 1.7853654665606362, 8.23234120437077, 0.22143978119960853, 0.4541649839707783, 38.17993089130947, 49.52125310897827, 62.01466655731201, 51.73388263157436, 49.80072702680315, 45.33548109872, 47.39993681226458, 45.464033194950645, 45.26270914077759, 45.7396856035505, 47.65168741771153, 44.4182494027274, 41.8809027671814, 38.670942715236116, 41.55560547964913, 42.054145676749094, 44.30661964416504, 42.01480150222778, 40.68512126377651, 46.904940196446006, 47.5611697605678, 50.43135247911726, 52.1293671471732, 52.55668136051723, 51.32925428662981, 50.850203786577495, 48.522282804761616, 45.190392289842876, 43.603482791355674, 44.47915383747646, 38.29827955790928, 46.604260376521516, 49.20530462265015, 46.057781083243235, 48.32003116607666, 45.36730037416731, 46.453602586473735, 46.913576807294575, 48.80517176219395, 47.535301617213655, 40.95187302998134, 35.89767347063337, 37.18200281688145, 34.87500286102295, 34.94653109141758, 35.06260422297886, 35.90575075149536, 38.75994566508702, 42.28917891638619, 46.285400594983784, 46.17972196851458, 48.90706014633179, 49.20911223547799, 48.39223337173462, 41.726232392447336, 37.050685337611604, 36.40388100487845, 41.49281808308193, 47.145028250558035, 47.73716415677752, 40.959370136260986, 39.006551129477366, 37.451783997671946, 38.71269791466849, 40.95666381290981, 38.1775233404977, 48.64904921395438, 52.618707929338726, 50.93783099310738, 46.99652787617275, 39.432496547698975, 39.638840675354004, 35.60717970984322, 36.28854438236782, 35.355790410723, 34.88804462977818, 35.10173995154244, 34.313074248177664, 39.542121750967844, 44.13783400399344, 44.171796798706055, 44.314985275268555, 46.87563616888863, 42.957936082567485, 44.04249777112688, 46.09449536459786, 43.53939608165196, 46.39147179467337, 40.71448087692261, 36.9702981540135, 43.51875993183681, 38.89826692853655, 40.004573004586355, 44.95676953451974, 48.13655355998448, 48.599227155957905, 49.08134528568813, 51.683077403477256, 47.80808789389474, 48.080238410404746, 46.82213503973824, 47.167630740574424, 46.68723576409476, 39.83316789354597, 36.15194279806954, 37.17652416229248, 44.314307825905935, 52.45269462040493, 50.40361874444144, 52.2355877331325, 53.222666195460725, 50.90683855329241, 50.87146874836513, 48.0663663319179, 43.16832058770316, 42.91459321975708, 45.89885493687221, 49.407504149845664, 54.636544704437256, 49.936088357652935, 58.64026696341378, 45.42703751155308, 15.720545973096575, 0.3252744073314326, 0.4698431598288672, 7.735478128705706, 60.20914241245815, 50.87757968902588, 51.63853945050921, 49.842867851257324, 54.87230403082711, 55.493479933057515, 52.981094700949534, 41.2293632371085, 28.034155675343104, 21.999235255377634, 30.369127341679164, 40.317565032414024, 7.431431038039071, 0.42711605397718294, 0.09992502270532505, 0.11552604234644345, 0.06141953103776489, 0.04590111964249185, 0.02227277628013066, 0.03555642919881003, 0.025150044654895152, 0.05543403114591326, 0.07137560751289129, 0.08416270850492374, 0.0775950662791729, 0.05252064944111875, 0.02063271133894367, 0.13221572392753192, 0.03791849780827761, 0.1314487757959536, 0.048712079878896475, 36.82115854535784, 58.67628642490932, 37.75761938095093, 34.990026814596995, 43.529824938092915, 42.77925968170166, 30.741001878465923, 68.55228219713483, 55.84675414221627, 65.90836061750139, 54.03465700149536, 59.91331590924944, 47.508255754198345, 47.54202052525112, 3.0340199385370528, 0.6732130242245538, 7.3017880746296475, 0.24942323033298763, 1.391946628689766, 42.07054689952305, 53.13830811636788, 62.77232592446463, 54.63622856140137, 52.76092365809849, 46.41755880628313, 48.3838712147304, 47.96711131504604, 48.64216702325003, 47.632194246564595, 48.79677139009748, 47.78774356842041, 42.91542700358799, 41.92771972928728, 44.04319259098598, 44.80382578713553, 46.15048394884382, 43.4785715511867, 42.70838805607387, 46.97052076884678, 49.04267856052944, 49.4592091696603, 51.42621292386736, 54.01236023221697, 52.388607910701204, 52.72380985532488, 50.29398659297398, 46.92236280441284, 45.041165828704834, 44.64428472518921, 41.040584155491416, 49.377467087336946, 51.36116736275809, 47.19515950339181, 51.30308042253767, 49.770380769457134, 47.83885799135481, 49.31282452174595, 50.1321074622018, 49.13377986635481, 42.495116574423655, 38.70517996379307, 39.66826977048601, 38.16877555847168, 38.51978465488979, 37.298055103846956, 38.243854318346294, 40.592515672956196, 43.766834940229145, 49.15388100487845, 48.26790925434658, 49.343903814043315, 51.12284415108817, 50.44509254183088, 41.88639531816755, 36.841513293130056, 37.128421783447266, 40.68712581907, 50.95120974949428, 47.65987586975098, 42.37900522777012, 39.01176575251988, 37.816050257001606, 37.99287148884365, 40.02533769607544, 38.753608907972065, 50.551889828273225, 53.901477405003135, 52.254598004477366, 48.834607805524556, 43.667156083243235, 40.365434646606445, 36.91516767229353, 38.103188037872314, 37.965478215898784, 38.10945878710066, 36.73129749298096, 36.02128887176514, 40.14683042253767, 44.890723432813374, 47.4338162285941, 48.14740317208426, 48.45268269947597, 46.29571866989136, 46.71466030393328, 47.95809602737427, 45.18362474441528, 49.64919376373291, 42.97784614562988, 39.76106643676758, 47.16405241830008, 42.29877437864031, 43.079703262874055, 47.248994146074565, 49.78546878269741, 50.6794934953962, 49.85132728304182, 52.756115504673545, 50.97412838254656, 49.18029110772269, 50.82837949480329, 49.225857394082205, 50.643578256879536, 42.659177439553396, 37.15090962818691, 39.832563400268555, 46.26008830751692, 53.97926248822893, 53.30232381820679, 53.598355293273926, 55.24997336523873, 52.35781349454607, 54.358971118927, 51.07246623720442, 45.39901890073504, 43.97273438317435, 47.251540660858154, 52.119254044124055, 55.40383774893624, 55.20607464654105, 57.625631945473806, 49.999587944575715, 18.890446186065674, 0.7711063570209912, 0.30235230017985615, 9.86041009426117, 59.333002362932476, 57.350031648363384, 56.69683844702584, 54.39840909412929, 58.96927111489432, 61.17556735447475, 59.21217318943569, 46.59780550003052, 35.550020354134695, 26.111781937735422, 35.30069466999599, 51.344015734536306, 11.512947934014456, 0.39853572472929955, 0.12027014206562724, 0.05546977976337075, 0.01470472916428532, 0.033668951730110815, 0.051512231052454026, 0.053161003294267824, 0.14633225144020148, 0.27868700719305445, 0.16103157268038817, 0.16666481111730846, 0.1730390369359936, 0.10944281305585589, 0.11906445319099085, 0.27719330734440256, 0.18441669855798992, 0.341789325433118, 0.26273011629070553, 50.942979608263286, 68.32061535971505, 48.60519218444824, 44.26787648882185, 50.31581783294678, 53.65741845539638, 36.226389271872385, 72.7999244417463, 63.29801968165806, 70.19711535317558, 59.920583724975586, 65.23804705483573, 52.58039903640747, 49.695625100817, 4.346406544957842, 4.853460890906198, 16.898885760988506, 0.3100467515843255, 4.760219974177224, 51.544134276253835, 50.72720677512032, 67.51579856872559, 56.0821521622794, 55.54671355656215, 47.0167019707816, 50.94449431555611, 50.3553009714399, 49.86826351710728, 49.577001980372835, 51.17427124295916, 47.962560244968955, 44.76197678702218, 43.98356662477766, 46.19158601760864, 47.184372425079346, 47.73382554735456, 44.894461563655305, 45.91514151436942, 50.230150018419536, 51.66581460407802, 53.12825754710606, 55.02900675364903, 56.01629018783569, 53.24279860087803, 54.70589467457363, 52.64721291405814, 49.30737018585205, 46.459689208439414, 46.94999231610979, 42.74768706730434, 50.68420784814017, 54.829913071223665, 50.46929311752319, 54.58911977495466, 51.28270830426897, 51.45056635992867, 51.736526421138215, 53.537291049957275, 53.22524050303868, 43.5351368359157, 41.08231503622872, 41.32816662107195, 40.715484891619, 39.699571405138286, 40.19887242998396, 40.057719775608604, 44.422508648463655, 46.973008223942344, 51.34296655654907, 53.461784975869314, 50.97798810686384, 51.86622497013637, 53.44675602231707, 44.13684735979353, 37.553012302943635, 37.91892181124006, 42.921388557979036, 53.778372696467805, 50.83926037379673, 43.81525693620954, 38.5272331237793, 38.74632024765015, 39.153314454214915, 42.19847018378121, 39.900975363595144, 51.348181179591585, 57.62808813367571, 54.867721693856375, 53.72316231046404, 45.77995041438511, 43.15208612169538, 38.822465556008474, 41.21538693564278, 40.87019695554461, 41.60312768391201, 38.7273725100926, 38.73525871549334, 42.72077669416155, 48.96463639395577, 50.15552636555263, 49.65882396697998, 53.94615084784371, 48.41212259020124, 50.068607875279014, 51.415943486349924, 47.91615322657994, 51.11269630704607, 45.083688804081504, 41.42086948667254, 49.75046723229544, 45.19533940723964, 46.132925851004465, 49.922897202628, 52.654029096875874, 52.87321696962629, 53.33346911839077, 54.40081317084176, 52.712922028132844, 50.62182692119053, 52.72116953986031, 51.16820893968855, 51.958205223083496, 45.14446817125593, 39.16311488832746, 41.98398624147688, 48.93548175266811, 57.4198054586138, 54.4907853943961, 54.17627171107701, 56.980905124119346, 55.11820772715977, 56.12220157895769, 51.680298124040874, 46.275888511112754, 45.364750385284424, 49.556772300175254, 53.78200313023159, 57.90705483300345, 55.96382086617606, 59.34181962694441, 54.098844460078645, 25.60511408533369, 1.190195043172155, 0.7617955537778991, 12.149819816861834, 71.94176633017403, 61.94653252192906, 62.07888180868966, 62.02208028520857, 64.38714286259243, 67.09211826324463, 63.69387245178223, 55.605366774967735, 39.79005779538836, 33.808478696005686, 44.273858887808665, 64.24401691981724, 19.6256993498121, 0.7421686298080853, 0.3584045852933611, 0.30494674667716026, 0.1432016265711614, 0.16762401536107063, 0.23934627962963922, 0.17460333156798566], [0.042315540436123095, 0.09512932039797306, 0.06961490413440125, 0.09919052890368871, 0.07863757426717452, 0.03444903969232525, 0.03270479418071253, 0.0905123713559338, 0.05577695256631289, 0.07469777603234563, 0.23198406611170086, 16.388111523219518, 54.55031755992344, 34.44891153063093, 25.59485854421343, 29.50032458986555, 45.39437402997698, 21.978736332484655, 51.15588630948748, 54.70509563173567, 51.54809127535139, 51.4649213382176, 54.48428535461426, 46.37024504797799, 44.95446968078613, 9.01215316568102, 0.26255847407238825, 3.572396546602249, 0.283076884491103, 0.5726263959492955, 30.889026301247732, 51.02464526040213, 56.85409007753645, 57.15928622654506, 52.91593449456351, 52.593597139631, 49.79862172263009, 53.851116861615864, 54.3592004094805, 54.04740694590977, 53.04309000287737, 50.834733622414724, 48.45110893249512, 42.68373237337385, 40.99175568989345, 39.38040937696184, 39.63176046098982, 39.29534605571202, 44.61687408174787, 46.431031363351, 48.641843932015554, 52.225022997174946, 51.90064287185669, 50.02907262529646, 53.1698112487793, 52.355294772556846, 49.81341791152954, 45.85915987832205, 42.02857283183506, 45.708925928388325, 40.363186904362266, 43.29592078072684, 49.1267100742885, 47.53685801369803, 48.18046270098005, 46.52294213431222, 45.25346108845302, 46.42779697690691, 46.7370856148856, 46.7965760912214, 38.3660557610648, 34.77998971939087, 35.79560790743147, 34.74675301143101, 35.12523181097848, 34.99723557063511, 39.625190939222065, 43.95319604873657, 47.05765117917742, 46.599476541791645, 47.746756144932334, 49.52133648736136, 50.65533113479614, 50.61756420135498, 43.964274951389854, 37.070032596588135, 39.191404478890554, 40.566651003701345, 45.54471220288958, 45.43311718532017, 38.889960357121055, 36.86705487115042, 37.09906564440046, 39.10793924331665, 37.94127069200788, 41.818740708487375, 48.00938415527344, 51.36694826398577, 53.47500392368862, 49.010657787323, 41.81943205424717, 40.27940552575247, 38.288180351257324, 35.66424873897007, 35.484884466443745, 36.17860998426165, 35.28666278294155, 36.179464612688335, 38.22012274605887, 42.719161237989155, 47.126556464603965, 46.638174533843994, 45.77879353931972, 44.07377856118338, 44.16804824556623, 45.396805899483816, 44.71691077096121, 44.57248204095023, 38.01492854527065, 39.65621812002999, 41.21873249326433, 41.02555520193917, 46.66013431549072, 46.27241093771798, 47.99604361397879, 49.68078374862671, 52.32369089126587, 38.81204325812203, 44.749282428196494, 49.58799055644444, 47.62722975867135, 49.55289173126221, 47.36919450759888, 44.46746001924787, 39.87991189956665, 36.4125280380249, 40.74782875605992, 51.33771024431501, 50.59108461652483, 52.5035206930978, 49.20088904244559, 55.59904044015067, 51.65698691776821, 53.5424987248012, 48.11937413896833, 46.68932022367205, 42.874516010284424, 52.314109325408936, 50.73802512032645, 57.46835947036743, 39.352154527391704, 23.88988525526864, 6.357557850224631, 0.27254034844892366, 0.2433202149612563, 16.17797715323312, 62.167811802455354, 43.5942416872297, 56.31525032860892, 50.31797524860927, 52.29072863715035, 54.45362295423235, 48.02057770320347, 35.119270256587434, 28.380339247839792, 19.97788963999067, 31.60617072241647, 38.82684639522007, 3.292005249432155, 0.2520072002496038, 0.06186581030488014, 0.12315292523375579, 0.05570475983300379, 0.15089463948139123, 0.039777558230395825, 0.047583302948623896, 0.027983084420806596, 0.07430205440946988, 0.051294716474200995, 0.05302827166659491, 0.04703671245702675, 0.043560753975595744, 0.013152346214545625, 0.0523682063711541, 0.057277407231075425, 0.08495265218828406, 0.20432338251599244, 20.980867317744664, 66.8745423725673, 36.053639684404644, 33.86847986493792, 43.16672945022583, 48.781398500714985, 27.240509850638254, 58.11592810494559, 59.6918420791626, 57.31980003629412, 55.83724900654384, 59.387781960623606, 48.96651588167463, 52.192349093300955, 13.052876319204058, 0.12968352623283863, 4.485894671508244, 0.5274641364812851, 1.315488759960447, 37.65350757326399, 53.20818962369646, 58.554296902247835, 59.375768525259836, 54.40915795734951, 54.13013219833374, 50.52022688729422, 55.86416980198452, 56.87963512965611, 56.60470185961042, 54.4402094568525, 54.18850401469639, 50.548777035304475, 44.08708783558437, 43.52147667748587, 41.47647244589669, 40.553744724818635, 40.87286158970424, 47.435890265873496, 46.36306061063494, 49.590860162462505, 53.2624237877982, 51.77356031962803, 51.133037158421104, 54.015803064618794, 54.17825542177473, 51.12252800805228, 47.46997117996216, 41.92631271907261, 47.381874970027376, 42.389642919812886, 44.92489467348371, 51.2513302394322, 48.7390388080052, 50.35581166403634, 48.62558167321341, 48.911843981061665, 49.38617318017142, 49.216494696480886, 49.058642046792166, 41.728973456791465, 37.265315192086355, 38.12029797690255, 37.79167250224522, 36.60194635391235, 37.24856308528355, 41.29341173171997, 44.41183968952724, 48.900223118918284, 50.528926031930105, 49.02386631284441, 52.37504850115095, 50.758706433432444, 51.91151680265154, 48.03419269834246, 37.57993309838431, 39.149197646549766, 40.06961509159633, 48.73600244522095, 47.83255597523281, 39.11172948564802, 37.3986302784511, 38.521598134722026, 40.13357673372541, 39.162927286965505, 42.34278426851545, 49.864838055201936, 54.84913526262556, 53.556499344961985, 50.36812039784023, 44.60438469478062, 41.34568302971976, 40.09297840935843, 37.37869242259434, 38.96175261906215, 38.67958280018398, 36.843142645699636, 38.36631979261126, 40.86212314878191, 44.575438499450684, 47.68194334847586, 48.41167443139212, 47.848512513296946, 48.79609394073486, 45.54264163970947, 48.77941826411656, 46.78130742481777, 48.7254307610648, 40.4676113809858, 43.492068426949636, 43.63724061420986, 43.06572001320975, 48.05171952928816, 49.5017842565264, 48.97755656923567, 50.06445632662092, 54.23703718185425, 42.809206417628694, 46.24039363861084, 52.73222412381853, 49.521555355616975, 51.59251805714199, 48.52182422365461, 46.49141468320574, 41.89049475533621, 39.615053517477854, 42.213370595659526, 53.43765735626221, 52.23980181557791, 53.73112494604928, 51.698419025966096, 57.4849066053118, 54.703473227364675, 56.079480579921174, 49.58762925011771, 50.16885995864868, 44.843989849090576, 55.98559652056013, 53.7780704498291, 59.90690967014858, 40.59594113486153, 33.082826205662315, 5.315765363829477, 0.7260585256985256, 0.3303058259189129, 19.933622666767665, 70.43410451071603, 51.613112517765586, 61.46792670658657, 55.94641562870571, 56.644310065678184, 60.40804154532296, 54.51290498461042, 42.54252413340977, 38.148094245365684, 17.609273059027537, 36.185999393463135, 51.39883354731968, 5.346859421048846, 0.379784138074943, 0.05263761191495827, 0.0739810937749488, 0.008645348683265703, 0.10179313139191695, 0.055847567705703635, 0.0408534229999142, 0.19290469666676863, 0.1887211754385914, 0.16687000010694775, 0.20216824673116207, 0.23282832652330399, 0.10940494401646511, 0.13819525949656963, 0.12714789515095098, 0.18297053687274456, 0.26221076558743206, 0.3968313533280577, 29.282495089939662, 76.49751254490444, 47.04957389831543, 36.48560224260603, 44.100483962467735, 58.74236379350935, 30.44359118597848, 61.901820863996235, 65.16761316571916, 64.01376056671143, 62.121988432747976, 62.86508437565395, 57.393301555088584, 56.75921242577689, 15.84875934464591, 0.9614423236676625, 10.594027825764247, 0.929068060857909, 2.6093063056468964, 45.05250528880528, 50.46757691247122, 63.182137625558035, 59.002761432102744, 59.118879726954866, 55.584709780556814, 54.840821743011475, 56.90156364440918, 59.645629610334126, 57.81547062737601, 58.10268483843122, 54.86505705969674, 52.63787800925118, 46.35728318350655, 46.71885354178292, 43.177617277417866, 43.20392663138253, 42.22234072004046, 49.413663727896555, 49.448623589106965, 52.38349403653826, 57.08660806928362, 55.59991938727242, 52.58753831045968, 58.46549892425537, 56.042943477630615, 53.42124571119036, 49.1788979939052, 44.213951519557405, 50.72379173551287, 43.72088997704642, 45.15065901620047, 55.09998607635498, 52.16133233479091, 54.32216303689139, 51.98926714488438, 51.67966931206839, 51.399101052965435, 51.528361865452354, 50.255976472582134, 43.594026293073384, 38.92279406956264, 40.86296040671212, 41.02988045556204, 40.06624174118042, 39.524070331028526, 44.458833830697195, 46.313467843191965, 51.15053967067173, 53.34756006513323, 51.534743785858154, 54.59168366023472, 54.003265040261404, 53.886524881635395, 47.28764350073678, 37.554520062037874, 39.88470615659441, 41.40835925510952, 51.39227097375052, 49.64962107794625, 40.24944836752755, 38.32240717751639, 37.47004038946969, 39.03159591129848, 40.002780369349885, 43.243361132485525, 51.13866867337908, 58.4840784072876, 56.323539529527935, 51.96131106785366, 47.069188662937705, 46.78382962090628, 43.22308281489781, 41.14899689810616, 42.035972663334434, 41.653255462646484, 39.10037612915039, 40.95714323861258, 42.41055352347237, 47.62955393110003, 51.62957280022757, 51.64733934402466, 51.63922037397112, 50.09495544433594, 48.25000722067696, 52.32217270987374, 50.98959507261004, 51.857504980904714, 42.40566546576363, 45.12893894740513, 45.89616250991821, 46.495576654161724, 50.08147941316877, 52.27544954844883, 50.77563919339861, 53.54919331414359, 54.189195360456196, 45.68915482929775, 47.75966937201363, 53.26264265605381, 52.22326510293143, 53.93236909593855, 51.24127619607108, 48.44244105475289, 44.71255772454398, 41.60348899023873, 43.943746498652864, 57.23375701904297, 55.12035819462368, 55.75245319093977, 54.94959579195295, 59.77437278202602, 56.90021569388253, 61.09132044655936, 52.49376194817679, 52.5734543119158, 46.63184472492763, 58.89925411769322, 55.3024913242885, 63.832412583487375, 46.90117079871041, 51.09543350764683, 9.658107212611608, 0.8475580917937415, 0.9390887745789119, 21.257944107055664, 76.11138030460903, 53.45175872530256, 66.95287636348179, 59.705154827662874, 63.44222954341343, 62.95407690320696, 59.23507445199149, 48.97580909729004, 43.224152837480815, 29.300449235098704, 45.416931356702534, 63.71184049333845, 9.781753880637032, 0.6107878025088991, 0.21242494136095047, 0.24820916833622114, 0.13940568454563618, 0.2564472077148301, 0.2226583215274981, 0.12817521073988505], [0.047268751077353954, 0.04723026457109621, 0.05732003280094691, 0.010916371463931032, 0.03446094798190253, 0.015815567325002382, 0.02191291862566556, 0.058572398099516115, 0.05574010472212519, 0.04540157198373761, 0.3011964022048882, 7.362365944044931, 54.45693377086094, 35.88967261995588, 24.471579756055558, 20.868704284940446, 49.05506025041853, 28.58436267716544, 52.664816175188335, 57.17688601357596, 55.750195026397705, 51.94019201823643, 50.44750704084124, 46.29346745354788, 55.2071099281311, 23.42749653543745, 0.297834614025695, 2.5722198614052365, 0.3411324221108641, 7.5789438996996195, 37.84359291621617, 46.5536983353751, 53.895738192967, 53.76748834337507, 52.79918391363961, 54.33100809369768, 55.86501053401402, 55.83441761561802, 54.0767457144601, 54.30564716884068, 53.318339415958945, 54.497024876730784, 49.242390632629395, 46.20036506652832, 40.38420867919922, 39.3068071092878, 38.949395247868125, 39.06751809801374, 43.160569872174946, 50.89972012383597, 54.12157549176897, 51.75415052686419, 49.41371931348528, 49.655124051230295, 53.49081107548305, 51.67570883887154, 49.86607830865042, 48.15556730542864, 43.16153914587838, 44.16825321742466, 41.39245482853481, 40.670196533203125, 46.0263717515128, 48.32831341879708, 46.46854816164289, 46.0309019769941, 48.33806521551949, 47.65519625799996, 47.88426446914673, 44.76328999655587, 34.57543822697231, 35.196562017713276, 36.15278353009905, 36.89837735039847, 36.67387410572597, 39.29512023925781, 45.180042948041645, 47.83868081229073, 46.004922662462505, 47.42635038920811, 48.76139463697161, 49.45179196766445, 49.49861935206822, 48.64006519317627, 46.6050455229623, 35.607235295431956, 38.71838501521519, 40.43974910463606, 44.281866686684744, 43.352625029427664, 38.34227555138724, 37.57381868362427, 38.884130818503245, 39.36772196633475, 41.53247492653983, 43.609315804072786, 49.165779794965474, 51.4741450718471, 49.91049119404384, 45.6682893889291, 45.78313268933977, 39.948080675942556, 38.12296608516148, 38.0334107535226, 36.59707914079939, 35.34027508326939, 36.099595069885254, 35.196353571755544, 35.61153623035976, 42.82334252766201, 43.99657365253994, 46.05439383643014, 44.684935161045615, 46.230683531079976, 46.26165860039847, 44.64994403294155, 43.01656150817871, 41.85477059228079, 36.01433025087629, 40.4655373437064, 40.58472326823643, 47.60792071478707, 47.96342876979283, 47.54262154442923, 48.92310701097761, 50.27548354012625, 37.3763439314706, 38.87915243421282, 38.546601227351594, 39.266601358141216, 47.046405519757954, 51.01732185908726, 48.7165926524571, 46.72086157117571, 42.972350120544434, 37.04143728528704, 37.199807575770784, 44.39201647894723, 50.49158293860299, 49.832560198647634, 53.09073032651629, 48.870741912296836, 53.07034431185041, 55.30398866108486, 52.16488981246948, 49.954893657139365, 47.64343990598406, 50.89325482504708, 53.586803913116455, 50.59424952098301, 44.29025663648333, 11.233981234686715, 1.5271936399596078, 0.5007730658565248, 1.0954584181308746, 30.564288343702042, 43.1654440334865, 39.44921391350882, 54.14308016640799, 51.590593406132285, 54.17204373223441, 52.02801724842617, 48.718857765197754, 41.777520520346506, 22.88248678616115, 27.81229100908552, 35.42963239124843, 32.23394046510969, 0.31218117848038673, 0.25621471447604044, 0.020429088068859916, 0.0525211786984333, 0.05276588896023376, 0.03645661446665015, 0.0459690681392593, 0.10038038755634002, 0.0874079107972128, 0.02211069970923875, 0.023211509122380188, 0.04484146846724408, 0.038579224675361595, 0.056559391652366946, 0.027175240983654345, 0.100036397443286, 0.01324623595324478, 0.11402179806360177, 0.22476999035903386, 9.291436008044652, 65.58642278398786, 38.203766686575754, 24.360818522317068, 37.49581820624215, 53.8051996912275, 33.77460970197405, 56.32845190593174, 61.8277530670166, 59.93928827558245, 57.06090668269566, 56.43999828611101, 51.44738408497402, 58.582124437604634, 27.094660214015416, 0.14145522671086447, 3.1474725135735104, 1.0759388655424118, 11.586890663419451, 44.42581251689366, 47.740739004952566, 55.834403719220845, 56.333485875810894, 56.69636249542236, 55.31124258041382, 56.31128290721348, 56.369922229221885, 54.96266882760184, 54.69409663336617, 55.973492758614675, 55.53313677651541, 50.86287382670811, 48.295285156794954, 42.448560169764924, 40.268354415893555, 41.19688040869576, 42.7052891595023, 44.11808722359793, 53.366000584193635, 54.48864534923008, 52.02583203996931, 53.19911527633667, 50.27773823056902, 54.260136468069895, 51.924864292144775, 52.85187905175345, 49.9089035306658, 44.38538442339216, 46.21839216777256, 45.00400686264038, 42.64039298466274, 48.80055121013096, 49.42594119480678, 48.28235455921718, 50.34718200138637, 49.89824499402727, 49.16059991291591, 50.702599729810444, 46.978653635297505, 37.78564146586827, 39.851549352918354, 37.66299186434065, 38.53958702087402, 38.38390915734427, 40.756017208099365, 45.900050027029856, 48.75032615661621, 47.87207038061959, 50.971071175166536, 49.73847811562674, 49.94371053150722, 51.09886939185006, 50.380008765629356, 48.86327954701015, 36.769773142678396, 38.271640164511545, 39.98804324013846, 46.36340454646519, 44.65186173575265, 39.43710667746407, 37.533744948250906, 38.762047495160786, 38.57701349258423, 39.234608377729145, 44.85635764258248, 51.15773800441197, 53.225858892713276, 51.519489015851704, 48.53124598094395, 48.06297908510481, 42.66613606044224, 39.97199637549264, 38.72394357408796, 37.741197313581196, 37.19023643221174, 37.05778987067086, 36.88427250725882, 39.338751452309744, 43.97422129767281, 46.165082114083425, 48.89526210512434, 47.93720626831055, 47.97072785241263, 47.91067109789167, 48.39905650275094, 48.02725144795009, 44.84571647644043, 39.41130454199654, 42.85422032220023, 44.073000362941194, 50.705702100481304, 50.845409529549734, 49.009504386356895, 50.61847441537039, 51.00574268613543, 38.20791128703526, 41.11902584348406, 41.095311641693115, 39.304656641823904, 49.91914864948818, 52.866925375802175, 53.12956380844116, 49.75363213675362, 45.92813464573452, 39.365637506757466, 38.898888792310444, 45.92647055217198, 52.20736067635672, 53.41564198902675, 54.42679943357195, 48.62444911684309, 55.344555718558176, 57.46556282043457, 55.706101758139475, 52.4315755707877, 50.193112645830425, 54.32729775565011, 56.774217060634065, 53.07234539304461, 49.580604621342246, 16.525737966809952, 1.1968128766332353, 0.8660655415483883, 1.6846505680254527, 38.04703964505877, 51.78835998262678, 45.67718308312552, 56.886090006147114, 58.24991021837507, 59.53014360155378, 57.78144529887608, 52.37652151925223, 47.764567852020264, 32.24998732975551, 24.78352607999529, 40.99864482879639, 43.81527778080532, 1.0691184486661638, 0.13965645751782826, 0.033687658940574954, 0.09181651566177607, 0.06715435295232705, 0.0586348572479827, 0.06080943984644754, 0.07812292581158024, 0.18009977734514646, 0.10239630831139428, 0.0986412548060928, 0.1657425191785608, 0.12509368466479437, 0.1745341345667839, 0.13449613084750517, 0.2208860966243914, 0.22404323864196027, 0.20472317534898007, 0.4004952252975532, 13.039901426860265, 79.34528732299805, 49.312185287475586, 36.02071564538138, 31.637208325522288, 66.63141795567104, 37.3772645677839, 64.17199884142194, 69.20856734684536, 65.68867942265102, 62.21707453046526, 60.48599338531494, 57.91730342592512, 65.26079545702252, 33.61549595424107, 0.5004140394074577, 10.830726027488708, 1.2613995309386934, 13.153950027057103, 49.77445241383144, 45.54921810967581, 58.17847578866141, 58.421648842947825, 58.902408599853516, 57.68574775968279, 58.67789145878383, 58.30335576193673, 56.74192878178188, 56.88372067042759, 58.54639680044991, 56.64420236860003, 53.598278863089426, 51.02117463520595, 45.73616981506348, 41.50617946897234, 42.21761247089931, 43.25086171286446, 46.559017181396484, 55.36628968375069, 60.039015769958496, 54.232600757053916, 53.06008529663086, 51.21613413946969, 57.398193086896626, 54.023102147238596, 54.507520130702424, 51.89778021403721, 45.678079400743755, 47.43483761378697, 46.62194006783621, 43.1465379851205, 51.907052585056846, 52.62322425842285, 50.683356693812776, 53.382398332868306, 51.66491828645979, 52.22526271002633, 53.61316537857056, 49.0957419531686, 39.838052477155415, 42.626350675310405, 40.48453719275338, 42.41326332092285, 40.93735476902553, 44.431565625326975, 48.932209151131765, 52.18080813544137, 51.953272002083914, 54.330764906747, 53.30103145326887, 53.03297342572893, 55.21626417977469, 52.51431819370815, 49.89666427884783, 35.77115024839129, 38.615305015019004, 41.4876833643232, 49.66903781890869, 46.46942710876465, 38.60994100570679, 37.51621811730521, 40.54333979742867, 39.76611777714321, 42.033384459359304, 45.20142255510603, 52.53880711964199, 56.23652376447405, 52.53061866760254, 49.52662754058838, 50.62133012499128, 45.21142101287842, 43.445967129298616, 43.175171511513845, 40.67282295227051, 38.71076284136091, 39.893103054591585, 39.67025695528303, 39.63958065850394, 47.03142867769514, 48.96436888831002, 53.26723888942173, 51.49230766296387, 50.70159918921334, 50.281531946999685, 51.08734580448696, 49.55057103293282, 46.756967885153635, 40.9323034286499, 43.58856153488159, 48.03212908336094, 52.68775217873709, 54.16872944150652, 50.51861490522112, 52.949546405247276, 53.92546953473772, 41.29382167543684, 41.05960137503487, 41.04826191493443, 41.34109027045113, 50.779356479644775, 55.55362354006086, 54.81011070523943, 53.35705130440848, 47.20365367616926, 40.400703702654155, 41.180180413382395, 48.802389008658274, 54.20973423549107, 55.56589405877249, 55.03283173697335, 50.73283134187971, 57.914690903254915, 58.26129136766706, 56.70409236635481, 53.77805307933262, 52.143187114170615, 59.134443691798616, 58.81921781812395, 58.1017815726144, 51.64350046430315, 24.91907674925668, 1.342555359005928, 3.228872614247458, 2.245334041970117, 38.859218052455354, 55.117912428719656, 49.59684950964791, 63.63850225721087, 61.684335299900596, 65.81186403547014, 64.55774893079484, 59.261595726013184, 56.10076291220528, 36.75781181880406, 42.069330964769634, 51.94068534033639, 57.419249602726524, 2.3080050562109267, 0.5056795797177723, 0.19846299769622938, 0.17029220504420145, 0.26513549579041346, 0.18021690606006555, 0.18225855007767677, 0.11361155579132692], [0.04550342348271182, 0.06224846334329673, 0.06227449194661208, 0.04168701684102416, 0.06333897768386773, 0.013690072494292898, 0.029123014770448208, 0.05440711249996509, 0.009217110279548382, 0.047758331056684256, 0.053637039714625905, 0.9971854857036045, 47.105746609824045, 45.822400433676584, 36.16244500023978, 23.06255977494376, 43.942985670907156, 30.69479635783604, 47.37760182789394, 62.73149830954415, 50.58263908113752, 55.621969495500835, 53.66308123724801, 46.781790324619834, 50.8678035736084, 30.6179701260158, 0.06878676571484123, 0.7253290191292763, 1.0906207348619188, 23.610192469188146, 48.673048291887554, 39.812924316951204, 51.14583574022566, 53.35124955858503, 57.19708095278059, 56.84546388898577, 56.000486510140554, 50.29150608607701, 54.290517466408865, 52.80547203336443, 53.15713426045009, 52.153581619262695, 49.4510624068124, 44.32003314154488, 40.83503212247576, 38.1517767906189, 38.610298837934224, 39.38271270479475, 47.44144882474627, 50.537732873644146, 51.77586364746094, 52.52406999043056, 45.04925005776541, 43.264841488429475, 47.660251072474885, 52.02475854328701, 50.92826679774693, 50.0517897605896, 47.74338626861572, 45.15754815510341, 45.44064555849348, 38.20596579142979, 42.87213972636631, 48.46533189501081, 48.382669176374165, 47.0618895803179, 45.530655997140066, 46.61100707735334, 46.252017974853516, 39.2073575428554, 34.4438601902553, 36.00557552065168, 34.49303953988211, 38.319961411612375, 39.60918576376778, 38.92974921635219, 45.47835690634591, 44.566537857055664, 47.467122418539866, 49.40906402042934, 49.26945039204189, 48.50008678436279, 47.88385452542986, 50.15205921445574, 46.91123873846871, 35.38363879067557, 37.05092852456229, 41.20628132138933, 43.0521536554609, 44.52182272502354, 40.332350799015586, 39.06650366101946, 38.915088517325266, 39.792190892355784, 39.31820910317557, 44.07399048124041, 51.588303974696565, 50.19411318642752, 51.29631287711007, 46.69423260007586, 47.10023321424212, 46.937270164489746, 44.13833774839129, 40.8912604195731, 38.17246505192348, 36.37520578929356, 34.483155727386475, 33.297817366463796, 35.05559696469988, 38.32416507175991, 42.32349259512765, 44.81357410975865, 46.600060190473286, 43.93915721348354, 45.666229248046875, 44.58391530173165, 46.387410572596956, 37.146626063755576, 38.69460480553763, 38.88048996244158, 41.312640871320454, 46.4259626524789, 49.450357164655415, 48.836980615343364, 44.979038511003765, 36.87252310344151, 35.70942940030779, 47.60480097361973, 46.43106263024466, 41.42139754976545, 36.43947662625994, 41.70820181710379, 47.44936977113996, 49.63281338555472, 45.35706915174212, 39.30467401232038, 36.79749298095703, 38.8896997996739, 46.05095100402832, 50.368106501443044, 53.490890979766846, 50.663943426949636, 47.202086857386995, 56.279276030404226, 55.07855435780117, 53.42652286802019, 51.77813918249947, 50.652228764125276, 54.20380047389439, 52.51861218043736, 48.69173199789864, 2.918963198150907, 0.11187340013150658, 0.4011973190520491, 2.6181133644921437, 63.000497817993164, 42.303818770817344, 48.827916690281455, 50.24675621305193, 54.25844805581229, 52.59575455529349, 57.280282156808035, 45.61156776973179, 35.74955524717058, 24.623625448771886, 25.557234048843384, 37.50136981691633, 23.76718180520194, 0.27843206801584786, 0.042886181601456234, 0.07761199572788817, 0.03562465250226004, 0.1135065999946424, 0.04006520279550126, 0.05317263338448746, 0.0048073154341961655, 0.08446257348571505, 0.08668635665838208, 0.014088219879860324, 0.019341596601797, 0.0476404797019703, 0.04402577777260116, 0.029034401489687816, 0.02583738705808563, 0.021651655502085174, 0.017963167978450656, 0.027423868088849952, 1.6171591324465615, 53.442208426339285, 52.905029296875, 31.36076729638236, 27.557177475520543, 53.643341405051096, 31.49234880719866, 51.993661880493164, 68.00652204241071, 58.580734797886436, 60.113945143563406, 58.758337702069966, 52.74191338675362, 55.64579834256853, 37.235531738826204, 0.09576520270534924, 1.151519524199622, 0.9922009131738118, 25.47339013644627, 52.59994779314314, 42.511184283665244, 51.13144602094378, 55.60653754643032, 58.54941231863839, 58.09010859898159, 56.3164940561567, 54.16802419934954, 55.72049147742135, 53.335532733372276, 56.541615690503804, 54.02484614508492, 51.50302178519112, 44.814970697675435, 40.737347398485454, 40.19375160762242, 41.60138716016497, 41.24265514101301, 48.94983673095703, 50.61990227018084, 53.40936081750052, 52.73768540791103, 45.11076940808977, 42.42514474051339, 48.10854537146432, 54.256252425057546, 52.257408550807405, 51.449652671813965, 49.412565912519185, 46.222363063267295, 46.03162111554827, 38.475059100559776, 45.8203125, 51.09151472364153, 49.17377022334507, 49.33706678662981, 49.082446575164795, 48.16133083615984, 48.79255730765206, 42.3468142236982, 36.39194399969918, 37.98662505831037, 37.36733559199742, 40.04716893604824, 41.09868846620832, 43.14780950546265, 48.47929777417864, 49.270249434879844, 49.368385791778564, 50.267743246895925, 50.27225610188076, 51.35959359577724, 52.27852412632534, 52.48238427298409, 49.48216949190412, 37.0463878767831, 39.12667506081717, 40.394898482731406, 45.24358769825527, 46.052430970328196, 39.681367124829976, 38.430785179138184, 38.499627930777415, 39.58799723216465, 39.29891395568848, 44.374051911490305, 53.62747866766793, 51.70295967374529, 50.77378749847412, 48.946494647434776, 50.55721909659249, 47.42203903198242, 45.90817594528198, 41.32464041028704, 40.40541458129883, 38.9730087007795, 37.60112510408674, 36.239781924656455, 37.69502305984497, 41.048188958849224, 45.83343069893973, 46.81831005641392, 47.61155809674944, 46.71257931845528, 47.66734865733555, 46.7079622404916, 48.545305660792756, 39.451961926051546, 41.58581624712263, 41.937857151031494, 44.69595152991158, 48.03017316545759, 51.78528887884957, 50.080117566244944, 46.44605336870466, 38.831282820020405, 37.20623465946743, 47.98967211587088, 48.29983275277274, 43.10567215510777, 38.149119104657856, 41.30270494733538, 48.48563800539289, 51.63649320602417, 47.04233040128435, 41.766764708927695, 39.65811497824532, 41.764200823647634, 46.450086797986714, 52.78698287691389, 54.25342798233032, 51.249669619968955, 47.5812326839992, 55.244866439274375, 56.54933166503906, 54.71209246771676, 53.89916018077305, 53.66412694113595, 55.76873976843697, 54.855117661612375, 49.647877080099924, 3.73006181206022, 0.31373309663363863, 0.9912699631282261, 4.53177319254194, 61.36171654292515, 45.06365367344448, 52.044626917157856, 58.17714173453194, 59.532957621983115, 58.477790287562776, 63.897565841674805, 50.62405034473964, 43.774394580296104, 31.744179316929408, 28.35575478417533, 46.29601744243077, 31.82803017752511, 0.11533747746476106, 0.05284495525328176, 0.06757417613906519, 0.02517667885071465, 0.03319565998390317, 0.1253208310476371, 0.018062870217753307, 0.02762109786272049, 0.14028540519731386, 0.21169704970504555, 0.13446261121758393, 0.16835145918386324, 0.18882619908877782, 0.17167248097913607, 0.14941138907202653, 0.17809873686305114, 0.08552360547972576, 0.2125027421861887, 0.21418749035469123, 2.005922785827092, 66.57942458561489, 61.515250887189595, 49.51491982596261, 32.621594360896516, 60.359348569597515, 38.95086479187012, 55.759241580963135, 73.43637248447963, 64.26212392534528, 65.06339713505336, 62.331136158534456, 58.23555524008614, 60.034006118774414, 42.70996182305472, 0.18714924050228937, 6.742473721504211, 1.715082809329033, 34.04335560117449, 56.75115598951067, 44.864466190338135, 53.25498921530587, 56.078959465026855, 59.37520572117397, 59.34169455936977, 59.28351034436907, 54.553749970027376, 58.39222322191511, 55.77347843987601, 57.50978115626744, 57.30284990583147, 54.84420204162598, 47.32755395344326, 44.75984716415405, 41.95465094702584, 42.90822172164917, 43.49656391143799, 50.39344310760498, 54.38403327124459, 53.77641677856445, 55.06284448078701, 46.387341090611045, 43.28401156834194, 48.39419971193586, 54.59104095186506, 52.830926758902415, 53.732660497937886, 50.729715074811665, 48.4531204359872, 50.68409667696272, 40.078321184430806, 46.9236273765564, 54.45638486317226, 53.039525577000205, 54.04440532411848, 52.26293931688581, 52.2303592136928, 50.97792904717581, 43.94322885785784, 38.59936932155064, 41.00513792037964, 39.51717076982771, 42.88270793642317, 44.46045970916748, 44.50903456551688, 50.70557703290667, 49.77429607936314, 53.19214970724923, 55.17541919435774, 54.10749844142369, 54.19485119410923, 53.78570999417986, 55.616146905081614, 52.73383263179234, 36.45696176801409, 37.69181299209595, 41.95581824438912, 48.70998838969639, 47.98730278015137, 41.0340702193124, 39.36856964656285, 39.51401628766741, 40.59332513809204, 38.783750193459646, 45.991081850869314, 55.52859960283552, 54.50653696060181, 55.09960045133318, 50.230910846165244, 54.19802304676601, 50.1910525049482, 49.47741344996861, 43.54882478713989, 43.67920773369925, 41.042230878557476, 38.090292181287495, 39.65209436416626, 39.134707178388325, 42.919192927224294, 46.4503230367388, 50.86098739079067, 50.058199473789756, 48.35378551483154, 50.99852350779942, 49.81021479197911, 51.505022866385325, 40.958845547267366, 44.33694158281599, 44.32830844606672, 45.15361547470093, 51.14323363985334, 53.07951593399048, 52.22683647700718, 47.96718079703194, 39.47234099251883, 40.11476101194109, 47.76488399505615, 48.81769241605486, 43.818480900355745, 41.439476762499126, 43.33917679105486, 51.813258852277485, 53.776976108551025, 50.52319376809256, 43.16027109963553, 41.92628492627825, 43.78732170377459, 48.94792250224522, 53.03136839185442, 57.62778588703701, 51.287985461098806, 52.00732898712158, 58.728536878313335, 59.575987815856934, 58.54736260005406, 56.50555106571743, 55.84020546504429, 60.619947705950054, 55.786718232291086, 56.93779502596174, 5.254277280398777, 0.23948041243212564, 2.9510508477687836, 4.426824561187199, 73.71458530426025, 50.310971464429585, 60.81376770564488, 61.38665362766811, 66.62876374380929, 62.822332109723774, 68.75680937085832, 58.28588104248047, 50.45674467086792, 38.63113995960781, 38.131779875074116, 56.067321232386995, 44.66045665740967, 0.541378772684506, 0.17491757470582212, 0.17723483964800835, 0.08648896403610706, 0.16864839967872414, 0.15837274678051472, 0.13898514211177826, 0.15444282123020717], [0.046035401722682376, 0.11148220433720521, 0.008026192264099206, 0.038396837855024, 0.015508160427478808, 0.08203927387616464, 0.02813897784134107, 0.058335446885653904, 0.1401311606168747, 0.0921182194724679, 0.15841298390712055, 0.07914731012923376, 24.9116039616721, 46.31300926208496, 35.62706198011126, 35.47189480917794, 37.441458974565776, 38.22600439616612, 30.23779944011143, 63.39202186039516, 49.650989873068674, 49.58725752149309, 45.95179326193673, 52.0096948487418, 46.612483569553916, 41.00994259970528, 0.7434314649019922, 1.6156554988452365, 1.0186350090163094, 7.790256857872009, 34.85658318655831, 43.39019046510969, 53.174647194998606, 46.0476575578962, 51.75540815080915, 52.326216561453684, 53.06219407490322, 54.198610169546946, 54.936564445495605, 54.189330850328716, 55.64543008804321, 51.35689074652535, 45.49521671022688, 41.90465170996529, 38.73600564684187, 38.6253799029759, 41.70248344966343, 42.521286964416504, 45.5539220401219, 50.586071491241455, 53.61776161193848, 50.633697918483186, 48.18346432277134, 48.557850633348735, 45.303866795131135, 48.193945680345806, 51.262277126312256, 52.162767137799946, 49.90127788271223, 45.4858991759164, 44.35021611622402, 41.11586441312517, 39.23261424473354, 45.88253014428275, 47.27485534123012, 48.087666034698486, 46.78103991917202, 47.53681285040719, 43.210037572043284, 34.798867974962505, 34.587284905569895, 34.9196971484593, 36.66188151495797, 41.1674165725708, 39.55205767495291, 42.949421065194265, 47.31791680199759, 46.909915106637136, 48.042843205588206, 48.31270081656319, 48.63740403311593, 48.718548570360454, 47.27434812273298, 47.42014217376709, 46.84312207358224, 37.37110498973301, 39.076720987047466, 37.65358052934919, 41.4388027872358, 43.05391502380371, 39.43127713884626, 39.33223056793213, 38.82335492542812, 40.57136188234602, 38.89478588104248, 45.97569159099034, 52.8885794367109, 50.31008556910923, 50.47164855684553, 48.070490087781636, 47.738550322396414, 45.59170634405953, 44.57409054892403, 44.538154465811594, 41.160680294036865, 37.329217774527415, 36.4999954359872, 35.09044565473284, 34.729924474443706, 36.50716945103237, 42.02705465044294, 44.801616259983604, 46.397718225206646, 43.35153416224888, 45.30841439110892, 43.909036772591726, 44.743949685777935, 36.029529435294016, 38.777472496032715, 39.070151465279714, 43.985268933432444, 49.74636779512678, 46.59455721718924, 38.93167734146118, 41.20801837103707, 44.02609307425362, 51.116222517830984, 44.17432941709246, 50.00028623853411, 49.64236715861729, 44.877448899405344, 37.694296973092214, 47.83335154397147, 49.314241954258506, 45.63963501793997, 41.225242955344065, 37.60456098828997, 37.64381831032889, 39.96889747892107, 48.67248201370239, 52.67351879392351, 52.11849321637835, 49.93556029456002, 40.27724116189139, 50.36427109582083, 54.234838077000205, 53.674483231135774, 53.274537972041536, 55.917823791503906, 49.962199687957764, 27.83347085544041, 0.2020991040127618, 0.1294029112905264, 1.2128028529030936, 22.91658159664699, 55.45900297164917, 51.76084164210728, 55.76466812406267, 47.30395439692906, 52.15309524536133, 51.755383832114084, 52.264638151441304, 47.03884587969099, 27.632813828332083, 31.90212229319981, 34.773597376687185, 34.19355133601597, 13.976504700524465, 0.3674995329763208, 0.06521256214806012, 0.062304076073425155, 0.053424030608896694, 0.005303673978362764, 0.017403965217194388, 0.06150105023490531, 0.056023905386349986, 0.08492827921041421, 0.01302369003782847, 0.047291909477540424, 0.03034828955839787, 0.051086609783981524, 0.08545324818364211, 0.062005839576678615, 0.03743183892220259, 0.18789701323424066, 0.08479926256196839, 0.020805347611063292, 0.04073966660403779, 30.96634238106864, 55.5600506237575, 30.534623009817942, 37.93355819157192, 50.88580288205828, 38.23217439651489, 37.32775517872402, 69.22008051191057, 56.5195586340768, 55.151989868709016, 52.16223212650844, 58.04169007710048, 49.85293926511492, 46.703602245875764, 0.9332960397005081, 1.7992337452513831, 1.470280402473041, 8.212924463408333, 42.06805944442749, 44.09524849482945, 54.8277348109654, 47.36983721596854, 53.08355631147112, 53.17344863074166, 54.078823225838796, 54.909192017146516, 57.396046093532014, 55.47466768537249, 57.209691933223176, 54.234772069113596, 48.716894899095806, 42.89512436730521, 39.80999912534441, 40.28401565551758, 44.00278186798096, 44.186742373875205, 46.53751598085676, 52.83159726006644, 56.579226289476665, 52.050849028996055, 47.61810677392142, 48.26922246388027, 44.97876058306013, 48.23392908913748, 52.49839292253767, 53.5171343258449, 52.40947682516915, 47.822220529828755, 45.94777372905186, 42.215531485421316, 40.881779602595735, 48.21275097983224, 49.79053749356951, 50.44652039664132, 48.82185091291155, 50.93563188825335, 46.285814012799946, 36.95820134026663, 37.80943209784371, 38.7368290083749, 39.77740512575422, 43.324439661843435, 41.571937220437185, 46.88530111312866, 48.25767803192139, 49.143417017800466, 50.678923743111746, 51.556456906454905, 49.4124755859375, 51.600025585719514, 50.92497335161482, 50.832263537815635, 47.91886649812971, 38.733594621930806, 38.81005259922573, 40.52783489227295, 44.875364439828054, 44.35735886437552, 40.28029489517212, 39.21491718292236, 38.20529529026577, 39.49497822352818, 39.228594711848665, 47.46106358936855, 54.46317672729492, 53.01273332323347, 50.854379653930664, 50.5943363734654, 49.53328044073922, 50.04334075110299, 47.35797316687447, 44.10204383305141, 42.82399913242885, 40.30673279081072, 38.160323074885774, 37.439784458705354, 35.937834058489116, 37.73763983590262, 43.75653770991734, 47.70306934629168, 48.58295100075858, 47.67618676594326, 47.41388184683663, 47.20939636230469, 48.05694457462856, 37.88627570016043, 40.18263101577759, 40.81305149623326, 44.89635842187064, 51.755057266780305, 48.45942940030779, 41.16811139242989, 40.54381922313145, 44.09994200297764, 52.53219243458339, 47.03808157784598, 51.674142020089285, 52.1922413962228, 46.966570717947825, 41.05240304129464, 46.93979236057827, 52.81416422980172, 47.61411503383091, 42.83460208347866, 39.999959400721956, 39.611238956451416, 42.04373380116054, 49.335301944187705, 54.73031064442226, 53.48492595127651, 54.44963468824114, 42.428118569510325, 51.59847961153303, 57.32284334727696, 56.700993469783235, 55.33796535219465, 57.96307815824236, 52.55390208108084, 30.85087721688407, 0.23155846180660383, 0.16287231604967797, 0.7156925733600343, 25.65567786352975, 59.82385785239083, 54.35346467154366, 60.2001861844744, 53.22902727127075, 58.12219190597534, 57.974879673549104, 58.68277604239327, 50.862373556409565, 37.26987668446132, 33.052917684827534, 37.26445014136178, 44.819601672036306, 17.48581051826477, 0.5134349092841148, 0.04121695152883019, 0.042789069669587274, 0.05680261592247656, 0.07041020145905869, 0.034482376117791445, 0.029007161701364175, 0.03171737305819988, 0.19296656548976898, 0.16488995349832944, 0.12145466064768178, 0.11740346731884138, 0.21715040850852216, 0.229919039777347, 0.16632189308958395, 0.2175300217100552, 0.25081894972494667, 0.23482777923345566, 0.33238724565931727, 0.19540870801678725, 40.46901144300188, 64.86610998426164, 47.9021942956107, 46.602631023951936, 52.508078711373464, 50.02740853173392, 39.1139737537929, 75.62506198883057, 61.87973254067557, 61.119821957179475, 56.948755809238975, 63.60677678244454, 55.65913540976388, 53.30194861548287, 1.3266559264489581, 5.753530536379133, 1.5059814410550254, 11.798128928456988, 50.29984392438616, 43.310265336717876, 58.122376033238, 48.7610159601484, 52.83220870154244, 56.63594790867397, 57.70331627982003, 57.010643414088655, 60.56444549560547, 59.73171779087612, 59.748323985508506, 57.5718355178833, 50.79575422831944, 45.44595398221697, 41.50622115816389, 41.70912592751639, 46.28928811209542, 46.22565303530012, 48.890766620635986, 54.11845227650234, 57.90939637592861, 54.33016388756888, 51.27288007736206, 51.70792416163853, 44.98406900678362, 49.57000167029244, 55.0777587890625, 56.73705809456961, 53.96493877683367, 50.047686849321636, 47.68746369225638, 45.05394009181431, 42.51505790437971, 50.0156626020159, 51.66468204770769, 53.52744197845459, 51.55708919252668, 52.4022923878261, 50.22021409443447, 38.65534748349871, 39.13912623269217, 40.442222663334434, 41.573361601148335, 46.832317624773296, 44.693245206560405, 48.723353249686106, 51.819842270442415, 50.88287074225289, 52.88067586081368, 53.83373246874128, 53.02418395451137, 53.7328793661935, 52.23372214181082, 54.373440742492676, 48.54322467531477, 39.73806095123291, 38.88837616784232, 40.960339409964426, 47.51233434677124, 45.08660704748971, 39.67997748511178, 40.07843235560826, 39.32183606284005, 41.007767813546316, 38.90845993586949, 48.77964755467006, 57.35851887294224, 54.85599660873413, 53.148765155247276, 52.849593094417024, 51.72681631360735, 50.81746734891619, 48.94151626314436, 46.20290463311331, 45.94111735480172, 42.49542229516165, 40.05040679659162, 40.59738983426775, 38.614620617457796, 40.039362634931294, 47.903444971357075, 50.45975324085781, 52.029549326215474, 50.22188513619559, 49.35514947346279, 48.99810586656843, 52.444759777614046, 38.62920836039952, 42.92184019088745, 42.643158367701936, 46.29148374285017, 55.63109595435006, 51.936683177948, 43.43771961757115, 41.51244674410139, 45.59599685668945, 55.54084580285208, 48.68234150750296, 53.65964535304478, 53.770844323294504, 49.52108635221209, 42.55304718017578, 50.20449032102312, 52.844072750636506, 50.07966940743582, 44.30389942441668, 42.28551721572876, 40.45803676332746, 43.89795439583914, 52.073232650756836, 57.34400061198643, 56.100405079977854, 55.31918089730399, 44.153325012751985, 52.13275439398629, 55.8560334614345, 60.312865121024, 56.38562863213675, 61.55678721836635, 52.81824629647391, 37.11920152391706, 0.5457384416035244, 0.9647359869309834, 2.8607281744480133, 28.929688147136144, 66.9420302254813, 61.16950852530343, 68.15776348114014, 59.275728361947195, 60.71234485081264, 64.39428561074394, 62.479091099330354, 59.90298393794468, 40.32953677858625, 41.282530852726524, 46.187180859701975, 53.71589796883719, 26.678975548063004, 0.5355832151004246, 0.10744048335722514, 0.1063190685319049, 0.1388077594872032, 0.12906331808439322, 0.16204203345945903, 0.07229084947279521, 0.12030514090188912], [0.04710915285561766, 0.05302108937342252, 0.06388934422284365, 0.029496646685791866, 0.07363019617540495, 0.060517242311366966, 0.08025178193513836, 0.04675890664969172, 0.0670730983838439, 0.07661634736827441, 0.12514697680515902, 0.2056217457034758, 7.794152191707066, 49.27961908067976, 37.41267258780343, 25.854116678237915, 24.5670462676457, 50.939908504486084, 31.11703838620867, 58.794280733381, 52.8453095299857, 53.89166307449341, 45.132465158190044, 53.264608996255056, 44.15724032265799, 51.01424380711147, 5.1356519886425565, 1.1945282220840454, 0.36657040140458513, 0.20659085655851023, 6.18547876392092, 43.050531251089915, 47.97011293683733, 53.087933676583425, 58.36974579947335, 55.60369920730591, 56.63882098879133, 52.83987603868757, 54.76911285945347, 52.114967005593435, 48.36972120829991, 44.41491079330444, 41.56233828408377, 39.184477124895366, 40.282382828848704, 41.055984837668284, 40.60092646735055, 42.982539653778076, 44.80020924976894, 49.6678010395595, 50.54275989532471, 51.00432525362287, 48.51484823226929, 46.18972390038626, 44.679988043648855, 48.81784527642386, 50.40550170625959, 53.1952486038208, 49.84414284569876, 47.02187490463257, 44.77139854431152, 42.59048407418387, 38.59954650061471, 42.116401536124094, 46.477844851357595, 49.48462220600673, 48.07772316251482, 46.92388793400356, 39.67866774967739, 34.975953238351, 36.71979475021362, 36.61809049333845, 38.96929488863264, 41.97853537968227, 42.36195434842791, 48.93231337411063, 45.26768752506801, 48.48987640653338, 47.26678153446743, 48.28111777986799, 47.72966705049787, 48.16132736206055, 49.20748635700771, 47.56460911887032, 45.72098452704293, 38.1712942804609, 38.38176563807896, 39.022629261016846, 39.47109031677246, 43.500385420663015, 39.138907364436555, 38.65403427396502, 36.554500579833984, 38.59866407939366, 38.247380529131206, 46.17443438938686, 50.3011223929269, 48.71936845779419, 49.840199742998394, 47.02673864364624, 46.15991265433175, 47.920534065791536, 46.53524044581822, 44.89289127077375, 44.402365820748464, 42.65596737180437, 34.5081136567252, 37.315918922424316, 36.03587314060756, 34.881721769060405, 37.35041672842843, 43.06121410642351, 45.22900342941284, 46.077110971723286, 45.95789378029959, 46.82922567640032, 41.75132233755929, 35.6412467275347, 39.71950231279646, 41.94274173464094, 44.506220545087544, 48.338197231292725, 43.903342723846436, 44.51037904194423, 45.52476739883423, 48.44132934297834, 48.09837320872715, 48.53498411178589, 45.991728033338276, 46.747431482587544, 49.85532597133091, 50.44095836366926, 48.012212072099956, 44.09587730680193, 42.5819273676191, 39.28629602704729, 38.63246359143938, 37.82244259970528, 37.99315636498587, 41.0532785143171, 48.44438655035836, 50.39999178477696, 51.45302949632917, 55.73947395597185, 48.21972349711827, 60.81269768306187, 54.90573876244681, 52.55696276256016, 54.16329942430769, 47.60006925037929, 17.380835396902903, 0.159947382286191, 0.5881134963461331, 3.848788721220834, 42.30180031912667, 45.740634032658164, 48.174695696149556, 46.62595265252249, 53.44194092069353, 48.7673214503697, 54.535903521946494, 51.26060955865042, 43.86166395459856, 23.141797031675065, 54.88401869365147, 34.804492541721885, 38.1488481249128, 6.623205287115915, 0.6583812800901276, 0.05861079639622143, 0.07742864878049918, 0.031504299491643906, 0.03975209281114595, 0.03478411724790931, 0.05107060314289161, 0.004853376511683953, 0.05975959010954414, 0.05470466706901789, 0.04611216438934207, 0.018345746378015195, 0.06118889698492629, 0.04487768527386444, 0.10868964597050633, 0.038727535467062674, 0.019224235488634025, 0.06967407238802739, 0.10630659027291195, 0.2071621287614107, 11.5522460767201, 59.9736054284232, 37.74275371006557, 26.208938598632812, 39.28888423102242, 53.821461950029644, 36.34379645756313, 64.4524906703404, 60.02489703042166, 57.629585470472065, 47.736750738961355, 58.36459023611886, 49.48156499862671, 54.16334458759853, 6.4503892574991495, 1.0321081089121955, 1.1184817084244318, 0.2812587906207357, 11.127811891692025, 45.715158462524414, 51.47858149664742, 54.36452272960118, 59.14478955950056, 56.979678767068044, 58.742342948913574, 53.774318422589985, 57.57123449870518, 55.101782185690745, 50.05306822913033, 45.66732011522566, 42.90992750440325, 41.18381779534476, 41.6561632837568, 42.97021007537842, 43.39348043714251, 43.05496767589024, 46.095339570726665, 50.510256222316194, 51.52104888643537, 53.308247157505576, 49.85724714824131, 47.0728052003043, 45.98492922101702, 48.47614329201834, 53.088149070739746, 54.833842277526855, 52.51092052459717, 47.90947948183332, 45.961138589041575, 43.67244366237095, 39.625336851392476, 43.09069183894566, 49.4617417880467, 50.89095497131348, 50.20800263541085, 50.973968573978965, 41.5611640385219, 37.95197091783796, 38.3876507622855, 39.0331905228751, 39.452493463243755, 44.906200545174734, 44.962731088910786, 50.902864183698384, 48.791789531707764, 51.05688142776489, 50.27848168781826, 49.52420261928013, 50.757480076381135, 50.44191026687622, 50.66401638303484, 50.37577731268746, 47.828265462602886, 38.46367447716849, 39.09209735052926, 39.22239691870553, 42.39272444588797, 44.2897389956883, 38.87626893179757, 39.59039436067854, 37.83506747654506, 38.24997220720564, 38.127499784742085, 48.95855324608939, 52.83915342603411, 52.20632886886597, 51.45741033554077, 48.319801875523154, 49.12508072171892, 49.109217984335764, 46.577301365988596, 45.18295771735055, 46.22040714536394, 42.03584064756121, 37.233819007873535, 38.07541956220354, 37.988528864724294, 38.08868714741298, 38.96449368340628, 46.26057815551758, 46.81308501107352, 46.86914655140468, 47.718518665858674, 48.697325297764365, 43.06687688827515, 37.247531277792795, 42.77529920850481, 43.856067180633545, 45.704010077885215, 49.272695200783865, 46.87740101133074, 46.81643056869507, 46.553340503147666, 51.279640674591064, 49.22437047958374, 50.288494041987825, 47.589104993002756, 49.54446356637137, 51.721118790762766, 52.30194650377546, 50.93695552008492, 46.60390254429409, 43.685325622558594, 40.635219301496235, 38.72645534787859, 40.989348139081685, 39.98659801483154, 43.52020515714373, 50.54352419716971, 52.19964470182146, 52.594514301845, 58.64663846152169, 50.05185924257551, 59.1454496383667, 55.9630252974374, 56.021966866084504, 56.07310560771397, 50.355783871241975, 19.95994939122881, 0.31164405015962465, 0.5036530941724777, 5.2907379525048395, 47.612075737544465, 50.879111766815186, 54.10239151545933, 52.34192991256714, 57.658326693943565, 55.38613026482718, 59.23188522883824, 59.645045961652485, 49.67290449142456, 32.83867692947388, 57.00629036767142, 34.503771032605854, 49.68631451470511, 8.66874279294695, 0.6189152949622699, 0.10467256938240357, 0.13714400519217762, 0.004406692243979445, 0.056849434838763306, 0.07546127720602921, 0.0058330012668323305, 0.036070127705378194, 0.14038877322205476, 0.16810059121676854, 0.14328322719250405, 0.1160808125776904, 0.16933908047420637, 0.13147587648459844, 0.18906319780009134, 0.08588481681155306, 0.2084461748600006, 0.17477163539401122, 0.2766280605324677, 0.3579957272325243, 16.757227625165665, 71.84799344199044, 49.07178456442696, 35.514991010938374, 37.0702097756522, 63.924962588718955, 38.615315437316895, 70.12483324323381, 63.445154735020225, 64.0622728892735, 54.44094596590315, 64.9028867994036, 53.5785425049918, 64.1906408582415, 7.626075267791748, 3.5226428849356513, 0.8777017657245908, 0.3090944412563528, 16.735267843518937, 48.714080878666465, 53.4289790562221, 57.42713928222656, 60.96331378391811, 60.60078457423619, 60.027884755815776, 58.29448291233608, 59.106171471732004, 57.98869964054653, 52.581500325884136, 48.222662585122244, 44.795168331691194, 43.52013567515782, 43.71951770782471, 45.579355921064106, 44.08653197969709, 44.70968811852591, 47.873567717415945, 52.52254833493914, 54.09612076623099, 55.23691422598702, 52.47132274082729, 48.99266195297241, 46.68088858468192, 49.27364362989153, 53.98647819246565, 56.24153341565813, 54.30790185928345, 48.65442017146519, 47.27452877589634, 45.381943702697754, 41.03509855270386, 44.83083690915789, 50.01589189256941, 52.73579202379499, 53.28410564150129, 52.58030523572649, 43.31264509473528, 40.03204270771572, 40.2517169543675, 43.3535977772304, 41.65338747841971, 46.76921755926949, 46.96495873587472, 54.51715728214809, 51.70782688685826, 53.024031094142366, 52.45864922659737, 51.116403170994346, 53.1241581099374, 52.36584561211722, 53.347032002040315, 52.97367055075509, 48.800443513052805, 40.42268432889666, 38.950295039585654, 40.075781617845806, 44.20365081514631, 47.214385168892996, 39.9389785357884, 38.10321930476597, 37.26321683611189, 37.967562675476074, 37.906533173152376, 50.26071514402117, 54.21398653302874, 52.65315362385341, 54.32101311002459, 49.45937245232718, 51.01942021506173, 52.09467131750924, 49.92818825585501, 48.331447056361604, 48.61923796789986, 46.65964446749006, 40.049875259399414, 40.00018869127546, 40.88010508673531, 40.53330659866333, 42.40967805044991, 47.214777742113384, 49.406698158809114, 49.989134379795615, 51.30998693193708, 52.95200259344918, 46.315389020102366, 40.2693966456822, 44.28747388294765, 46.46269083023071, 47.86894369125366, 52.67439079284668, 50.21067769186837, 47.38889959880284, 48.87481355667114, 53.584521429879324, 52.50864151545933, 52.819941656930105, 49.714916774204795, 51.2929117338998, 53.352368218558176, 54.921848160879954, 53.165308816092356, 48.84664555958339, 46.44393416813442, 43.34605550765991, 42.33266074316842, 42.64032697677612, 41.255418981824604, 47.21441643578665, 53.54208878108433, 54.06173760550362, 55.38700226375035, 60.401169776916504, 51.06253031321934, 60.901113510131836, 57.64001471655709, 57.272486277988975, 56.750652245112825, 51.88888304574149, 24.326244286128453, 0.6695204909358705, 1.4130325657980782, 5.867332475525992, 54.65753173828125, 55.99613693782261, 59.215008054460796, 56.47580235345023, 64.1355207988194, 59.12081132616316, 66.53380271366665, 61.608857018607004, 56.9611930847168, 35.48226152147566, 62.706311089651926, 42.90102686200823, 60.19108404432024, 13.224438633237567, 0.8941238873771259, 0.1891718448272773, 0.18624514687274182, 0.10516154207289219, 0.08055592847189733, 0.13887241030378, 0.11692652505423341, 0.13692250422069005], [0.015554456871801188, 0.040207929243998866, 0.07545672423605408, 0.06951649620064668, 0.07457015716603824, 0.0393551125058106, 0.051608518564275334, 0.021710411545687487, 0.03034537864316787, 0.04149769878547106, 0.043166158720850945, 0.09186165181121655, 0.5907030031085014, 37.2382241657802, 39.64932203292847, 37.968059471675325, 22.962337221418107, 44.81619010652815, 35.556992871420725, 49.30025175639561, 57.05774177823748, 50.983814171382356, 55.571709700993125, 51.16827147347586, 45.71328592300415, 52.73977681568691, 23.676023176738195, 1.0257304225649153, 1.1926193130867822, 0.25603370847446577, 2.1279316331659044, 28.938173634665354, 51.337744985307964, 55.555572509765625, 57.372714042663574, 53.1077812058585, 48.30924756186349, 49.20582921164376, 44.6028665133885, 43.17780140468052, 40.14936651502337, 39.73119265692574, 40.7019567489624, 39.60040324074881, 39.07235057013375, 38.434165477752686, 39.56539126804897, 41.121294430324006, 43.69066183907645, 44.14877394267491, 49.93025534493582, 48.11074447631836, 50.92581755774361, 51.432021617889404, 49.56414086478097, 47.390577588762554, 52.67751400811331, 51.195560523441856, 50.78687443052019, 45.661400250026155, 43.91341413770403, 44.32413952691214, 38.599511759621755, 39.11901119777134, 43.69580698013306, 46.96834250858852, 50.277984891619, 43.435989516122, 35.215117182050435, 33.66941050120762, 33.898148672921316, 37.36881903239659, 42.052241870335166, 43.52277251652309, 45.21613883972168, 48.90505559103829, 45.472523893628804, 49.01522970199585, 48.69947576522827, 48.443354742867605, 48.305346148354666, 50.69415419442313, 49.90209429604666, 48.82329266411917, 42.73286655970982, 35.81091826302664, 38.053091526031494, 35.87051296234131, 40.742450850350515, 43.80772161483765, 36.10079363414219, 39.044502190181184, 39.498372418539866, 39.78428036825997, 39.5582137789045, 45.318642139434814, 50.77235616956438, 50.30944286073957, 48.92764071055821, 47.56181246893746, 48.12776408876692, 47.12209572110857, 48.46244491849627, 48.444786071777344, 45.073912688664024, 43.54135547365461, 39.251919814518516, 37.18195417949131, 36.51232154028756, 35.817713601248606, 36.84723513466971, 40.245032787323, 44.83529417855399, 45.09504563467843, 44.98561150687081, 43.15985073362078, 38.66781602587019, 37.15975815909249, 40.462806701660156, 41.411854199000764, 43.48078802653721, 46.9979453086853, 47.66661214828491, 50.774183545793804, 47.12894664491926, 48.63771322795323, 47.801622595105854, 44.18164587020874, 43.64880589076451, 43.33636277062552, 44.20747927256993, 42.48654249736241, 40.84089640208653, 40.08181960242135, 36.73038380486624, 36.82619946343558, 37.1851920400347, 36.748820849827354, 36.96490287780762, 38.868174280439106, 38.81704248700823, 44.46281514848982, 49.54293843678066, 51.90775087901524, 56.03788866315569, 47.62221663338797, 46.98754732949393, 52.092732770102366, 50.33736767087664, 33.74626105172293, 6.1299009919166565, 0.1382376000817333, 0.23571060757551873, 7.311215911592756, 45.86049393245152, 45.25825187138149, 47.558567660195486, 52.89092097963606, 50.051553521837505, 50.257366112300325, 53.68355410439627, 45.51091269084385, 35.51869440078735, 22.382457937513077, 37.20730120795113, 39.088098662240164, 33.359548636845176, 1.245891043118068, 0.1657199239624398, 0.06088028568774462, 0.0664956650829741, 0.036572291116629324, 0.04907624962340508, 0.05243051963459168, 0.09650905350489275, 0.018531873622643094, 0.0338879930121558, 0.007981034062270607, 0.006457983757302697, 0.05767650795834405, 0.04873293465269463, 0.061970202917499204, 0.06020953346576009, 0.010858201504951077, 0.061234922015241215, 0.06737071741372347, 0.0761958049344165, 0.06313514576426574, 1.8797741149153029, 48.708449363708496, 43.49960374832153, 27.782224416732788, 35.18600770405361, 52.51310920715332, 35.66122627258301, 58.04493488584246, 62.50092928750174, 57.26513508387974, 62.80869974408831, 57.56249713897705, 49.687485286167686, 58.30704525538853, 25.71554527963911, 0.37701115544353214, 2.589824208191463, 0.6138026693037578, 3.4620346171515326, 33.43473856789725, 53.65551812308175, 57.88220460074288, 59.511793409075054, 55.02724538530622, 50.8085423878261, 49.91955859320504, 48.64312934875488, 45.703951018197195, 42.87141363961356, 41.76106718608311, 41.41687079838344, 41.54376227515084, 41.681579794202534, 40.607742650168284, 41.34390081678118, 42.82240104675293, 45.053808076041086, 48.79942907605852, 49.54173987252371, 51.61698613848005, 52.97776998792376, 52.86332620893206, 49.59678002766201, 46.60677909851074, 53.9319417817252, 51.63291488374983, 52.791711126055034, 46.580414158957346, 45.022489070892334, 46.001535415649414, 39.935424532209126, 40.65749175207955, 47.83220509120396, 49.97841330936977, 52.60318217958723, 46.10664776393345, 37.58938959666661, 36.768015248434885, 36.032864570617676, 40.36087315423148, 45.64716339111328, 45.65494189943586, 46.187479632241384, 48.87970161437988, 48.776423590523855, 50.888759340558735, 51.05191346577236, 50.76517520632063, 51.08994790485927, 52.14628948484148, 51.60318354197911, 50.78142009462629, 43.41015958786011, 36.56103188650948, 36.69207143783569, 38.25144522530692, 44.13241440909249, 44.971336432865684, 37.461223125457764, 39.13616630009243, 39.56078461238316, 38.99250534602574, 37.811975138528005, 46.33889825003487, 51.733576910836355, 52.25804083687918, 51.486995765141074, 49.37669931139265, 50.07880783081055, 47.90930230276925, 49.951172896793906, 48.63787998471941, 48.11821378980364, 45.84354032788958, 40.97748408998762, 38.23689569745745, 38.81071267809187, 36.45970630645752, 39.48034879139492, 41.983579771859304, 46.989843709128245, 47.08503402982439, 47.66256134850638, 43.783340385981965, 40.46931716373989, 38.9408871786935, 43.81194264548165, 43.862737451280864, 46.044513498033794, 49.44223819460188, 49.61578335080828, 51.156535966055735, 49.13801826749529, 50.388798236846924, 48.21551636287144, 47.13336222512381, 45.12449210030692, 46.603249413626536, 44.78597933905465, 45.697812284742085, 44.792288303375244, 41.55282967431204, 39.01278018951416, 38.68878221511841, 38.29958234514509, 38.81968627657209, 38.49643175942557, 40.67458084651402, 42.05424989972796, 46.76455531801496, 51.75558532987322, 54.1832720211574, 57.94837577002389, 49.5702657018389, 46.5121203150068, 53.28242070334298, 50.183621406555176, 36.44026524680001, 8.57895382813045, 0.08497624485088245, 0.9683977961540222, 10.805730751582555, 52.65702724456787, 49.23177031108311, 54.39680058615548, 57.10730675288609, 56.69035925183977, 55.794972692217144, 62.64342294420515, 49.77114854540144, 40.523155280521934, 31.76110165459769, 37.53951890127999, 44.78718485151018, 41.60302693503243, 2.1743686156613484, 0.22809649471725735, 0.01920199311072273, 0.07344458292105369, 0.04502836076010551, 0.09590828538473163, 0.02738482179120183, 0.0404245888681284, 0.029841186412210976, 0.12841576497469628, 0.14351924881339073, 0.1311574535710471, 0.14319889886038645, 0.16865126309650286, 0.204246083806668, 0.15276004081325872, 0.05393836693838239, 0.14074044435151986, 0.14935988826411112, 0.18857522255608014, 0.17779714161796228, 3.4532012854303633, 63.418779373168945, 52.10559388569423, 51.244517530713765, 34.88422312055315, 57.97717605318342, 44.20887238638741, 61.91578674316406, 70.45669310433524, 62.50634888240269, 65.31262901851109, 64.63159438541958, 55.92188501358032, 64.17181818825858, 30.176012584141322, 2.059913328715733, 5.810121442590441, 0.3462662452033588, 4.605541348457336, 41.79304279599871, 51.7293906211853, 61.67781094142369, 62.650357246398926, 59.274303981236045, 52.89274835586548, 52.38097531454903, 49.90439414978027, 47.342402253832134, 43.881080695560996, 46.18483236857823, 44.32143667766026, 44.320755754198345, 43.482525076184956, 41.92972428458077, 42.554680006844656, 44.275991984776084, 45.41707032067435, 48.708140168871196, 53.056093556540354, 53.57422072546822, 54.26669904163906, 55.50623682567051, 52.501321588243755, 49.59220116479056, 56.13134888240269, 54.39684574944632, 55.76852090018136, 49.27456079210554, 48.39565535954067, 48.833516938345774, 42.477030413491384, 43.36249494552612, 48.814155782972065, 51.70021513530186, 54.63352918624878, 48.84281015396118, 39.62351989746094, 38.68240029471261, 38.499697412763325, 43.06678656169346, 50.51974398749215, 50.76490422657558, 48.452700069972444, 53.2119277545384, 51.293498856680735, 52.777314458574565, 52.12961728232247, 54.79495668411255, 53.30803871154785, 55.02228437151228, 53.43780674253191, 54.01627901622227, 42.56618274961199, 35.84874425615583, 37.834226744515554, 37.61796406337193, 47.12051500592913, 47.30226945877075, 36.88892085211617, 39.27103778294155, 38.91909415381295, 39.58506161825997, 38.990924630846294, 48.86831004279, 55.20459120614188, 54.351710251399446, 53.243368353162495, 52.17281770706177, 53.724934101104736, 50.68881450380598, 50.41090740476336, 51.698436396462576, 49.59260416030884, 47.0095522744315, 44.64872809818813, 41.33139058521816, 41.455065046037944, 39.98957184382847, 41.36195223672049, 45.08672864096505, 49.68014451435634, 48.23385960715157, 48.25802891595023, 46.20565611975533, 43.26460872377668, 42.171361786978586, 45.3556204523359, 45.85662725993565, 48.45577117374965, 53.28275074277605, 50.91097967965262, 54.36301497050694, 51.160506861550466, 52.77249240875244, 50.11751971926008, 48.97343976157052, 48.229746273585725, 49.80858891350882, 48.10463006155831, 48.90932873317173, 44.94628470284598, 44.636263029915945, 39.93228742054531, 41.11508968898228, 40.41704586574009, 40.86277280535017, 40.48440170288086, 43.62459489277431, 42.86806460789272, 48.13182878494263, 53.897680214473176, 56.884589195251465, 59.464726311819895, 53.09200184685843, 48.673624992370605, 53.44430330821446, 50.57359252657209, 42.64300550733294, 12.850264242717198, 0.2400500832923821, 1.6401067525148392, 11.07958357674735, 60.71743788037981, 53.292565073285786, 58.98751013619559, 61.34435299464634, 61.11229010990688, 58.91708319527762, 66.08416393824986, 56.642076219831196, 47.86505617414202, 32.392328126089915, 44.40590245383126, 53.61588559831892, 54.590297494615825, 3.7448527898107256, 0.38135763364178793, 0.15535470444176877, 0.17056815166558537, 0.15648947283625603, 0.189239074076925, 0.10288969147950411, 0.27771938911506105, 0.09474402107298374], [0.06167200034750359, 0.035253334391329966, 0.031847397331148386, 0.07140228072447435, 0.045663025097123215, 0.03957081878823893, 0.04772328133029597, 0.0696225105119603, 0.02911579515784979, 0.11044594565672533, 0.029219516020800387, 0.04506895751027124, 0.1949781368353537, 29.928886004856654, 49.13671548025948, 36.99567297526768, 21.910282679966517, 37.81857245309012, 51.426508222307476, 33.912684304373606, 62.6331604548863, 51.699037415640696, 41.94405147007534, 50.50681686401367, 50.396156379154746, 44.73630666732788, 41.64718968527657, 0.4589613580277988, 2.947655349969864, 0.19345215229051455, 1.0379343905619212, 22.945708445140294, 53.94734941210066, 55.13626609529768, 55.32553155081612, 53.923850604466026, 49.36004100527082, 44.6789562361581, 42.05443402699062, 42.93841859272548, 43.49236372538975, 41.05416093553816, 43.70662879943848, 43.82472733088902, 44.28361068453108, 43.851144381931846, 42.667563915252686, 43.81731012889317, 45.07501745223999, 44.29644053322928, 47.06621830804007, 48.69403879983084, 50.95131049837385, 53.8191898890904, 52.136815616062705, 52.80574648720877, 54.22630221503121, 53.35738481794085, 48.96477883202689, 47.84381553104946, 43.96792622974941, 41.569331645965576, 41.996753556387766, 39.47192757470267, 41.07043014253889, 44.78200496946062, 44.71197060176304, 39.950231143406455, 36.23115921020508, 34.987855502537315, 36.5179009437561, 39.039982386997764, 43.36315502439226, 43.09351280757359, 46.279869828905376, 48.111606052943635, 46.77812167576381, 46.68752064023699, 47.97335079738072, 48.99906471797398, 50.42884070532662, 49.02912262507847, 49.04338380268642, 47.20322288785662, 38.894532271793906, 35.42462968826294, 38.61103534698486, 36.83542319706508, 40.50406857899257, 42.767850739615305, 39.672028745923726, 37.27987861633301, 38.05361958912441, 38.88027456828526, 38.72682360240391, 44.378276416233604, 52.33274091993059, 50.93337024961199, 50.549232142312185, 48.84562764848982, 46.932475907461985, 49.078270707811626, 47.77056762150356, 46.53472280502319, 46.55757890428816, 46.86724621909005, 42.0167852129255, 42.03380135127476, 36.3356740134103, 34.13630165372576, 33.99529143742153, 38.31183201926095, 40.71211848940168, 45.57058382034302, 45.04989276613508, 41.61422395706177, 36.41004058292934, 37.60878896713257, 40.968208244868684, 42.58120822906494, 43.419914858681814, 45.94863530567714, 47.589556625911165, 48.38152272360665, 46.60962438583374, 48.98983056204659, 46.09621851784842, 44.56987994057791, 39.1191987991333, 37.68737309319632, 35.912295954568044, 37.082869393484934, 35.12235525676182, 36.33939824785505, 39.425506659916465, 40.49385820116316, 39.99822235107422, 41.52215685163225, 40.289226804460796, 41.00220578057425, 38.995889118739534, 41.80216925484793, 43.29168585368565, 52.10932159423828, 49.43650593076433, 55.013432366507395, 47.39445120947701, 52.42836550303868, 43.001813956669395, 24.714811870029994, 8.233318294797625, 0.17182065945650848, 0.6301087343267032, 15.373636313847133, 53.08056163787842, 41.620807375226704, 49.05772835867745, 48.85798154558454, 54.38925831658499, 50.195617471422466, 50.74087735584804, 48.32116024834769, 33.06516735894339, 21.72203687259129, 39.154711042131694, 44.584158488682334, 25.8738808291299, 0.2682588467640536, 0.021561249192538004, 0.09167007423405137, 0.04376290991370167, 0.09521003892379147, 0.03122169304905193, 0.019000234115602713, 0.036314895642655234, 0.04998263670131564, 0.09411588085017034, 0.04898157023957797, 0.041070184404296536, 0.04060295197580542, 0.03425007286880698, 0.025587935532842363, 0.026763796008058956, 0.037652417086064816, 0.06334807005311761, 0.048834864183196, 0.032426689817969284, 0.026969911197998693, 0.4895886374371392, 37.02646739142281, 57.31646837506975, 33.227209772382466, 30.177165985107422, 51.60894359861101, 50.80165324892317, 39.49716343198504, 68.86076831817627, 55.82450948442732, 45.9257618359157, 54.648943764822825, 54.480140754154746, 50.2445501599993, 47.14922496250698, 0.9036004702959741, 1.7505064627953937, 1.2507419713905878, 1.915623128414154, 29.100297689437866, 53.43954726627895, 57.60889026096889, 58.969243322099956, 55.503735474177766, 50.410553046635215, 45.85324696132115, 43.15343059812273, 46.66956649507795, 45.30515568596976, 42.79888139452253, 43.98622778483799, 43.67398268835885, 45.938970361437114, 44.96546867915562, 43.42096056256975, 44.62619856425694, 45.28120524542672, 46.135694708142964, 48.592615944998606, 51.58694560187203, 51.58762305123465, 54.68269463947841, 53.861473151615684, 54.703928334372385, 53.88339124407087, 54.33154310498919, 49.56286934443882, 48.835274832589285, 46.0388993535723, 46.64041185379028, 43.855851786477224, 40.34151547295706, 44.3657557623727, 48.01283393587385, 48.09505891799927, 42.60027061189924, 37.39929730551583, 38.31859609058925, 39.293011460985454, 42.87186527252197, 44.6731128011431, 44.86358724321638, 49.3453038760594, 48.96019649505615, 49.50026954923357, 51.07756274087088, 50.04828439440046, 50.93239055361067, 51.97907413755144, 51.26640435627529, 52.40033646992275, 48.402690410614014, 40.988139152526855, 35.89414725984846, 39.491236618586946, 39.79530715942383, 43.30736446380615, 45.01325144086565, 40.042020320892334, 38.561036109924316, 37.499375683920725, 39.77383722577776, 40.17175708498274, 45.49757562364851, 54.09356035505022, 52.910598278045654, 51.458251067570274, 51.36896671567644, 49.14156532287598, 51.08980546678816, 48.786404677799766, 48.1615114893232, 46.56635100500924, 47.90223945890154, 45.01843132291521, 42.1421411378043, 38.21473789215088, 36.32788855688912, 37.070921966007774, 39.38650989532471, 42.16485479899815, 47.24149009159633, 47.799777848379954, 43.526757308415, 38.74003560202462, 39.39476088115147, 44.32462590081351, 44.530935287475586, 45.48919262204851, 47.61565753391811, 49.49721581595284, 50.60813896996634, 48.64690569468907, 51.57811096736363, 46.87118237359183, 48.05412013190133, 42.02505356924874, 39.94734416689192, 38.2227908543178, 39.27318130220686, 37.21539238521031, 38.67928402764456, 41.212121282305034, 41.497685296194895, 42.303846563611714, 44.36719751358032, 42.26346363340105, 42.648157596588135, 40.92716523579189, 42.822713715689524, 45.14320707321167, 54.488089493342805, 50.87320579801287, 58.600988796779085, 50.34989527293614, 52.422754832676475, 42.942594460078645, 28.3762971333095, 9.641397663525172, 0.3574242378984179, 0.5869831112878663, 18.43016971860613, 58.86673654828753, 47.88922895703997, 56.18012523651123, 54.81341804776873, 57.981650693076, 56.17017194202968, 57.91245705740792, 52.52083212988717, 41.75345196042742, 32.352410725184846, 30.61258179800851, 52.78428002766201, 31.424405847276958, 0.1523672097495624, 0.052198277453758886, 0.08036456124058791, 0.032557328165109665, 0.06451833939978055, 0.06835455926401274, 0.10668395752353327, 0.03617445246449538, 0.02322560059837997, 0.17795762872057302, 0.1350118988858802, 0.10468447088663067, 0.10495126407061305, 0.1469847849969353, 0.13614201253013952, 0.2119386081716844, 0.10572510611798082, 0.17091436737350055, 0.10775997835610594, 0.057006556407681534, 0.10544336480753762, 0.9003077298402786, 49.10751567568098, 65.72278812953404, 48.61140039988926, 29.440990447998047, 52.04460259846279, 61.029550961085725, 42.39190803255354, 74.75079100472587, 61.32070827484131, 51.00856712886265, 58.131241934640066, 63.583833830697195, 54.28469140189034, 55.10897009713309, 0.6430305923734392, 8.347485882895333, 1.0470971103225435, 2.3227187352521077, 35.26143387385777, 54.27454355784825, 60.13729109082903, 62.20742348262242, 57.51767430986677, 52.46315860748291, 48.68566274642944, 44.941841329847065, 48.09732403073992, 47.92625938143049, 44.43419551849365, 47.74479675292969, 46.790479046957834, 49.28607048307146, 46.650531905038015, 45.76222555977957, 47.247107710157124, 48.091154030391145, 48.118140833718435, 49.08786269596645, 53.713587692805696, 54.83908816746303, 58.93129226139614, 55.01950856617519, 58.86208125523159, 55.35804564612252, 58.12496771131243, 51.82321214675903, 51.48976462227957, 48.61023310252598, 47.59288133893694, 45.727300439562114, 43.293516704014365, 44.39851999282837, 50.72647374016898, 48.11129338400704, 45.86501373563494, 40.163787501198904, 41.407052993774414, 42.262223379952566, 44.630412646702354, 47.90918418339321, 47.354106494358604, 50.867320673806326, 52.03467014857701, 52.80922753470284, 52.04536690030779, 51.48953880582537, 53.13657801491873, 54.49136209487915, 54.41205883026123, 53.712121622903005, 51.390818800245015, 41.07356378010341, 36.45813601357596, 40.538642815181184, 40.86931106022426, 45.78771155221121, 46.212812764304026, 40.236093929835725, 38.034327915736604, 36.49936662401472, 38.052476610456196, 39.473219939640586, 44.9949985231672, 56.40012952259609, 53.77881390707833, 55.151885645730154, 52.019668987819124, 51.148604597364155, 53.39701386860439, 52.017612321036204, 49.85705259868077, 48.645311083112446, 50.738803318568635, 48.21222639083862, 46.42438193729946, 39.906756264822825, 39.13939721243722, 39.11183370862688, 43.00468703678676, 46.5185751914978, 51.20174789428711, 49.13828229904175, 45.96464048113142, 41.251990045819966, 42.34270783833095, 47.87410967690604, 45.89608955383301, 48.26201023374285, 50.45639378683907, 52.33821610042027, 52.197674887520925, 49.80457632882254, 53.83991983958653, 50.44282742909023, 49.66781146185738, 43.73260811397007, 43.41905328205654, 40.39120898927961, 41.01056446347918, 39.163184370313374, 39.78523227146694, 44.20372029713222, 43.3893393107823, 44.702739919934956, 47.14668192182268, 43.642149516514365, 45.47903435570853, 43.2753575869969, 46.62391683033535, 48.10204880578177, 57.85238640648978, 53.58044631140572, 60.77988828931536, 51.225524629865376, 53.71138858795166, 45.90486512865339, 36.08035550798689, 11.73584006513868, 0.627167420727866, 1.843106516769954, 20.486661059515818, 65.36831883021763, 51.1238968031747, 61.05934483664376, 58.95076806204659, 62.750300134931294, 61.46709292275565, 61.33466720581055, 60.88012300218855, 44.58694819041661, 31.424353735787527, 51.51075165612357, 59.738429750714985, 42.45045007978167, 0.3080651307744639, 0.10140010355306522, 0.19207555401538098, 0.13110154228551046, 0.20614249418888772, 0.16510728826480253, 0.15723096233393463, 0.16403734710599693, 0.09324401084865842], [0.05513775222269552, 0.009616410326478737, 0.01026293121477855, 0.026799707473920922, 0.018391902026321207, 0.027491429820656776, 0.11464386539799826, 0.03875239020479577, 0.016506770592448965, 0.10653199282075677, 0.04005727072113326, 0.1180001710142408, 0.17755632953984396, 14.45730093547276, 51.56732736315046, 39.78621196746826, 30.555547509874614, 29.053968838282994, 51.72140366690499, 46.6409399168832, 49.445469106946675, 51.04539605549404, 49.82991988318307, 47.96766022273472, 50.89119815826416, 44.67221648352486, 46.52146564211164, 11.224542106900897, 2.366470456123352, 1.3031626556600844, 0.5095344185829163, 14.484335507665362, 46.768175329480854, 56.300405502319336, 51.478105545043945, 53.97745248249599, 52.75737312861851, 54.67232097898211, 53.90070268086025, 50.94225352151053, 48.88877943583897, 49.36783340999058, 48.989344188145225, 50.26377582550049, 51.52357108252389, 49.80573320388794, 49.9099075453622, 49.83377613340105, 47.03388139179775, 49.94678510938372, 51.106720856257844, 50.14551053728376, 50.641608442579, 51.763898849487305, 52.25867312295096, 51.55494567326137, 52.58795172827584, 52.49733679635184, 51.32568986075265, 48.76961088180542, 44.94615616117205, 44.86982672555106, 42.0017979485648, 39.375267710004536, 39.20751735142299, 41.79403291429792, 42.88903079714094, 36.63269908087594, 35.94277770178658, 35.27959993907383, 36.09793792452131, 41.70760774612427, 44.62058094569615, 44.411978653499055, 47.94371325629098, 46.88348068509783, 49.24389839172363, 47.971085684640066, 47.494922161102295, 49.41643605913435, 48.92322860445295, 50.292815821511404, 48.76918704169137, 42.786610875810894, 37.96149689810616, 39.5465338570731, 38.02859565189907, 38.883168492998394, 42.503544739314485, 47.60980715070452, 40.845325878688264, 39.40137209211077, 37.94616917201451, 38.83523287091936, 40.067325660160606, 40.32985292162214, 47.76766674859183, 50.779304368155344, 47.523972579411094, 51.095975467136924, 48.44792665754046, 48.342098644801546, 51.09757702691214, 47.341297490256174, 47.73159864970616, 46.67540298189436, 44.18857322420393, 44.57392726625715, 40.16052532196045, 34.128460611615864, 33.2716052872794, 36.86541509628296, 39.91839449746268, 40.789458887917654, 43.52469021933419, 38.289774962833945, 36.49650049209595, 38.06667178017752, 42.32505246571132, 39.909903798784526, 43.02564627783639, 46.97153173174177, 48.23931394304548, 47.91724756785801, 48.00116096224104, 48.523224285670686, 47.29271221160889, 45.02989585059029, 41.40239770071847, 36.617906366075786, 35.70149803161621, 36.74856376647949, 40.05367939812796, 46.49041066850935, 45.55595786230904, 49.83138942718506, 48.99826567513602, 50.26142733437674, 46.03484855379377, 49.32333367211478, 45.65552207401821, 48.06274284635271, 42.48816837583269, 48.16978331974575, 50.34265177590506, 53.3981603213719, 50.518402985164094, 53.34521157400948, 29.142256123679026, 16.94656777381897, 7.65442304951804, 0.4707060935241835, 0.8271798395684787, 29.322065080915177, 48.642059326171875, 45.51155192511422, 51.1052964755467, 45.09251996449062, 49.13772644315447, 51.133005891527446, 55.099989550454275, 46.87817573547363, 26.87080315181187, 19.59794303349086, 33.5586701120649, 44.554687704358784, 9.27558890410832, 0.43419227855546133, 0.04773580708674022, 0.11579875914113862, 0.039655924042952914, 0.009532037041416126, 0.11807485057839326, 0.08642834371754102, 0.031562684037323506, 0.07745825326336281, 0.025708109173657637, 0.00484965177851596, 0.03391526672723038, 0.00883625790343753, 0.025081773853993843, 0.007937881779590887, 0.03128945494868925, 0.0532928494337414, 0.03521348063700965, 0.0765906987445695, 0.0340832380710968, 0.11546194792858192, 0.06312449276447296, 20.609906469072612, 63.3795359475272, 37.89286259242466, 29.50021689278739, 41.399979727608816, 55.45207561765398, 49.43605777195522, 55.224716663360596, 60.62512411390032, 52.61960424695696, 55.13614102772304, 54.56401940754482, 48.54330457959856, 52.69794518607003, 13.987118073872157, 0.239087024969714, 2.685030162334442, 0.2419362206544195, 20.11166330746242, 48.16593401772635, 59.27583258492606, 55.83657850537981, 58.48872675214495, 55.06376164300101, 57.05140849522182, 57.19723728724888, 52.906714235033306, 49.89200551169259, 52.26280035291399, 51.5649163382394, 53.04828725542341, 53.08974368231637, 52.305809702192036, 52.03889812741961, 52.48890168326241, 48.25529479980469, 50.97905118124825, 51.54329007012503, 51.00972400392805, 53.10434532165527, 53.15936810629708, 53.083552837371826, 54.69601433617728, 54.45092357907976, 54.05666194643293, 52.38917766298567, 50.429538999285015, 46.38648646218436, 47.25487927028111, 42.55051456178938, 41.098149980817524, 40.93927942003523, 44.069897992270334, 44.08508675439017, 38.58554588045393, 36.31780324663435, 38.02076850618635, 38.97376952852522, 43.83644894191197, 47.83872944968087, 47.68631376538958, 50.12051091875349, 48.066157885960166, 51.80381277629307, 49.966900144304546, 50.64659030096871, 50.03068808146885, 53.13256195613316, 50.759067739759175, 51.467804840632844, 44.241546290261404, 38.91330977848598, 38.940056868961875, 38.163936138153076, 40.92961794989449, 43.76428842544556, 47.90115206582205, 41.42299563544137, 37.65058238165719, 37.55744525364467, 39.41773509979248, 41.171203340802876, 41.91365310123989, 49.73244707924979, 51.56787627083914, 51.12039143698556, 51.864109243665425, 49.298625877925325, 50.196902888161794, 51.77987623214722, 49.376515184129985, 48.481368337358745, 49.45769446236746, 46.489677633558, 45.61535106386457, 41.30085672651018, 36.606174332754954, 35.65379170009068, 39.1903726713998, 42.77335371289934, 44.77546671458653, 44.37962784085955, 41.17009162902832, 39.004414558410645, 41.0688077381679, 43.692350251334055, 42.66791827338082, 44.38571793692452, 49.58912658691406, 49.984607628413606, 50.41147715704781, 50.694195883614675, 50.070230279650005, 50.06399427141462, 47.051189354487825, 43.19846882138933, 38.99659783499581, 36.734149728502544, 37.68542412349156, 42.278739248003276, 47.60245943069458, 47.99620342254639, 51.24861349378313, 52.63592903954642, 51.16550261633736, 49.003511565072195, 51.64271184376308, 48.002658299037385, 50.21333537782942, 46.22896385192871, 49.80892242704119, 51.57810749326433, 54.368424143110005, 52.84057780674526, 54.937161990574424, 31.428126607622417, 19.078888280051096, 8.061155830110822, 0.5806628561445645, 1.7912403856004988, 34.73493412562779, 52.67271975108555, 51.176765646253315, 56.30333416802542, 50.238467012132915, 56.926160267421174, 55.54661280768258, 61.15202685764858, 50.08640568596976, 36.66493872233799, 21.520943846021378, 33.37791619982038, 52.93195704051426, 11.803989733968463, 0.29228121201906887, 0.12442202999123506, 0.035299708867179494, 0.047166641735072644, 0.04024082462170294, 0.062171911022492816, 0.004513558540825865, 0.028018688849572624, 0.00724017305765301, 0.11625256336161069, 0.14151371642947197, 0.18167066733751977, 0.09551250947905437, 0.08280922113252537, 0.12287159104432378, 0.20800541208258697, 0.1468878494841712, 0.09938410815915891, 0.19129762718720095, 0.12307181315762655, 0.2537817321717739, 0.2815252106104578, 28.67244325365339, 71.28413322993687, 49.804871627262656, 40.08680493491036, 41.5530937058585, 64.69414901733398, 55.3954929624285, 60.954218591962544, 61.786765643528526, 60.9623201915196, 57.26772676195417, 60.443824768066406, 53.29871770313808, 60.189208030700684, 16.44311693736485, 4.322577263627734, 4.242632159164973, 0.6721429473587445, 24.31278215135847, 50.33315358843122, 60.49383790152413, 58.69280924115862, 59.97666958400181, 57.39328071049282, 58.646353585379465, 60.53125395093645, 53.97101150240217, 53.93171943937029, 53.83229766573225, 52.565533365522114, 54.95262173243931, 55.64480127607073, 53.33641515459333, 55.21972090857369, 55.4421501159668, 49.58207763944353, 52.07646356310163, 55.51883738381522, 54.210689612797324, 54.75306946890694, 53.85183252607073, 56.39799989972796, 55.7823999268668, 56.81659759793963, 56.37330252783639, 54.145185470581055, 51.58690391268049, 49.468106337956016, 49.860634395054404, 46.489833968026296, 42.07172114508492, 43.491286754608154, 46.280050482068745, 45.994830404009136, 41.194914068494526, 40.24383422306606, 39.90704114096505, 41.7644579069955, 46.53020995003836, 50.65194388798305, 50.361120087759836, 51.19894429615566, 51.84389693396432, 53.60252768652779, 52.771912234170095, 52.740690503801616, 54.31327281679426, 54.05425092152187, 52.83178833552769, 52.26686157499041, 45.402986322130474, 38.577232360839844, 39.69329718181065, 38.63200501033238, 42.027666091918945, 45.28516571862357, 51.722755091530935, 43.48841714859009, 38.8611809185573, 37.43886729649135, 38.31020266669137, 41.89785984584263, 40.60465070179531, 51.66355643953596, 55.70398603166853, 52.58620425633022, 56.03563744681222, 50.62440470286778, 51.02293947764805, 54.87870332172939, 53.14230333055769, 50.42373725346157, 49.98024763379778, 47.555899551936555, 48.742481640407014, 45.49203790937151, 39.01574012211391, 37.62278611319405, 41.713034289223806, 44.89605964933123, 47.43217645372663, 48.16440888813564, 43.18230036326817, 40.139486176627024, 43.48250423158918, 45.819801807403564, 44.208997453962056, 46.56660808835711, 50.83470235552107, 51.941783155713765, 52.259791782924104, 52.73167174203055, 51.70325149808611, 50.68297106879098, 48.27271393367222, 45.30014950888497, 39.557136808122905, 39.52294472285679, 41.24152258464268, 45.2152737889971, 49.43125656672886, 49.16392810004098, 54.280880314963206, 54.58600698198591, 53.01308420726231, 50.906682218824116, 55.45280517850603, 47.181405544281006, 53.5936861038208, 47.087507588522776, 52.112361431121826, 54.39231204986572, 55.885844707489014, 54.09828860419137, 56.75754485811506, 35.69970192228045, 26.33020203454154, 8.970604675156729, 0.7955443656870297, 2.289119852440698, 38.48487343106951, 57.27274683543614, 56.90295328412737, 60.734377588544575, 56.801436628614155, 60.375975608825684, 61.07665974753243, 63.82310894557408, 61.00931780678885, 36.66860737119402, 31.506870542253765, 45.027342387608115, 61.69928087506975, 17.9943630695343, 0.5237503786172185, 0.22644138495836938, 0.31350863724946976, 0.29863856945719036, 0.10118081460573844, 0.31802656767623766, 0.20628425372498377, 0.1410287810223443, 0.10348325355776719], [0.0160014587787113, 0.004726696568208614, 0.005611225064577801, 0.013542327431163617, 0.06154175555067403, 0.030128342432102988, 0.030117658898234367, 0.03745139430144003, 0.020889508005763804, 0.051675211771258285, 0.03563743270933628, 0.034055506344884634, 0.045326210491891415, 3.092906790120261, 47.8326358795166, 39.962640626089915, 25.945117235183716, 27.798250436782837, 38.59397751944405, 53.05270283562796, 55.317207608904155, 43.42961801801409, 42.758286544254844, 45.523391655513215, 48.22431625638689, 48.22322538920811, 41.208237239292686, 25.56614511353629, 0.31404771975108553, 1.6994662987334388, 0.1285137590020895, 6.213510402611323, 45.414822578430176, 56.086574690682546, 55.69887563160488, 57.84382969992501, 54.40809488296509, 54.53158174242292, 56.42334345408848, 55.676731722695486, 52.763414587293354, 53.68457896368844, 53.223764010838096, 51.96232203074864, 52.806146008627756, 54.01008817127773, 50.839288166591096, 51.41011394773211, 51.097101075308665, 52.31220204489571, 51.6117194039481, 51.141597339085166, 51.63244240624564, 49.210783277239116, 50.317186628069194, 53.42883314405169, 53.29725510733468, 52.8842785017831, 52.37872062410627, 50.3734461920602, 46.6470056942531, 43.91604750497, 44.17702184404646, 39.64042139053345, 39.42101117542812, 38.47843245097569, 38.95532553536551, 35.581818784986226, 34.47657925742013, 36.08264493942261, 40.178896359034944, 44.1561598777771, 43.8122935295105, 47.71215064185006, 46.5264961378915, 46.143514905657085, 49.77700935091291, 47.19834177834647, 50.46687167031424, 48.8055990764073, 48.8105913570949, 49.52703401020595, 45.45438214710781, 41.50289297103882, 39.001808983939036, 39.29293850490025, 38.36430828911917, 40.02706779752459, 45.92248576028006, 40.493788719177246, 43.24715484891619, 40.50521503176008, 39.52628680637905, 40.7394631249564, 38.64796502249581, 40.04247195380074, 46.53709214074271, 50.06527968815395, 50.60973705564226, 50.936479568481445, 48.994020325796946, 49.50025217873709, 48.13048778261457, 48.569871016911094, 47.70795740400042, 47.8085812159947, 43.89946910313198, 42.5604122706822, 43.71541132245745, 35.9650536264692, 32.37453031539917, 35.83663354601179, 39.009309564317974, 38.95908798490252, 39.34465742111206, 36.73990283693586, 36.36267123903547, 37.83174276351929, 42.72258669989449, 40.34485060828072, 41.78533724376133, 46.54883459636143, 47.870729378291536, 48.36715037482125, 47.917747838156565, 46.35492427008492, 47.328040327344624, 47.532060282570974, 41.63481841768537, 38.10254532950265, 36.6958304132734, 39.91843271255493, 47.59840515681675, 50.09115825380598, 50.8949293409075, 49.11637462888445, 49.54078449521746, 49.95007160731724, 51.13618469238281, 50.92380952835083, 49.92011444909232, 49.35663638796125, 50.870054789951865, 51.76519816262381, 50.02627944946289, 53.80180549621582, 50.950216157095774, 43.70252241407122, 20.937800645828247, 7.558441502707345, 1.0571074017456599, 0.877236833529813, 3.4041407065732137, 41.60703951971871, 48.88264765058245, 45.61390931265694, 48.050705092293875, 50.16662958690098, 50.96943487439837, 54.67343269075666, 53.250347818647114, 43.509338174547466, 23.879659243992396, 36.84065866470337, 35.00466319492885, 32.90820755277361, 0.4906808616859572, 0.15290801573012555, 0.004776858965799744, 0.026006606906386356, 0.03379613633400627, 0.02371647997227098, 0.0168385216301041, 0.021751244086772203, 0.04886253144858139, 0.054735940748027394, 0.006650029099546373, 0.052621720624821525, 0.042568019923887083, 0.03364102662141834, 0.08265129210693495, 0.05647460530911173, 0.01953949642899845, 0.07271804833518607, 0.017832996124135594, 0.07038688699581794, 0.03087390653256859, 0.018609864437686544, 0.11765639803239278, 6.388093880244663, 58.23676422664097, 45.17743042537144, 26.590354749134608, 40.07074417386736, 46.48745421000889, 58.290515490940635, 57.68171780450003, 48.15788105555943, 49.30188110896519, 49.22917863300869, 54.288804735456196, 52.63875000817435, 47.22681202207293, 31.238697869437082, 0.28132971110088484, 2.9302407758576527, 0.25674372751797947, 10.420870900154114, 46.77793060030256, 54.99393572126116, 56.39836120605469, 61.66548483712332, 57.734475476401194, 56.711686747414724, 58.04070690699986, 57.422265120915, 54.68724570955549, 55.75838347843715, 57.129659107753206, 53.1525171824864, 55.59370769773211, 55.27329846790859, 50.970265184129985, 53.581040382385254, 53.96983725684029, 53.67161015101841, 53.323981353214805, 53.89208344050816, 53.60735321044922, 52.035073144095286, 52.1619541985648, 55.17204931804112, 53.30760792323521, 54.392270360674175, 53.67842285973685, 50.52790117263794, 48.967512948172434, 46.44189487184797, 44.7224554334368, 41.82090507234846, 42.238443170275005, 40.563913413456504, 40.422055516924175, 38.85753658839634, 37.51929269518171, 37.90918738501412, 43.35754087993077, 45.31160708836147, 45.06535250799996, 51.08203738076346, 48.90800510134016, 48.92239134652274, 49.193252972194124, 50.55341495786394, 51.71449020930699, 51.334239619118826, 51.41854906082153, 51.33011586325509, 46.74178607123238, 41.56553792953491, 37.65156555175781, 38.871721335819785, 40.734613282339915, 40.92040811266218, 48.05930001395089, 43.206306389399934, 45.18139437266758, 39.890368938446045, 39.46326664515904, 40.092106410435264, 38.81187997545515, 40.8368490764073, 47.63846499579293, 53.629670824323384, 51.11629547391619, 51.757819175720215, 50.595924036843435, 50.315696239471436, 49.42473220825195, 49.061469963618684, 49.11753845214844, 50.289473737989155, 45.869658606392996, 46.828527382441926, 45.55369274956839, 36.93318782533918, 35.23929343904768, 36.50102724347796, 41.23160055705479, 41.254526138305664, 40.29708521706717, 37.300653730119976, 37.42173998696463, 39.912877627781455, 44.25665862219674, 42.25896120071411, 44.87227596555437, 47.23318004608154, 48.86290781838553, 48.358041286468506, 49.06684439522879, 48.74252332959856, 49.442912169865195, 49.004720551627024, 43.46811103820801, 38.93868112564087, 39.22482531411307, 41.73379898071289, 48.95766735076904, 51.721622535160606, 52.70783247266497, 52.53552062170846, 51.66038806097848, 53.668302808489116, 54.377446378980366, 52.88872882298061, 53.69547373907906, 50.56769698006766, 53.4666382925851, 53.77527379989624, 52.40076725823538, 56.40664693287441, 52.91379792349679, 44.40664938517979, 24.37933373451233, 10.377400364194598, 0.6243290273206574, 1.2828933490174157, 5.117733887263706, 45.936757360185894, 53.765706130436485, 52.60464130129133, 53.146277700151714, 53.870266096932546, 56.302924224308555, 57.88819394792829, 58.56763744354248, 47.21521895272391, 33.68944215774536, 28.536336728504725, 38.31960705348423, 42.05801929746355, 1.2381346821784973, 0.16485655600471155, 0.04480378941765853, 0.03176193923822471, 0.02011792717634567, 0.027263852568077188, 0.020537165126630237, 0.020956506553505148, 0.05294079153931566, 0.029602762777358294, 0.1364652259009225, 0.12457232549786568, 0.12761845918638365, 0.048226822167634964, 0.12056056862430913, 0.18239070155790874, 0.14418111901198113, 0.33546977596623556, 0.12384603518460478, 0.20162981562316418, 0.17906262299844197, 0.28850003491554943, 0.24343966426593916, 10.190024818692889, 70.37497534070695, 52.1271367754255, 34.63649899618966, 37.86371142523629, 51.8381472996303, 64.15694209507534, 65.37624672480992, 53.877391474587576, 54.57848903111049, 54.93649843760899, 59.065017291477744, 58.66159793308803, 50.8850212097168, 36.75619983673096, 1.1118487843445368, 6.829403936862946, 0.1630049967872245, 13.953667708805629, 52.7099620955331, 53.54915509905134, 59.039524350847515, 61.036943844386506, 58.560737882341655, 57.69439131872994, 62.29522786821638, 60.93255410875593, 56.7412235396249, 57.57349961144583, 59.78444072178432, 53.61320011956351, 58.66747610909598, 57.131743567330496, 51.922428948538645, 56.478209904261995, 56.68694421223232, 54.930790492466514, 56.47536809103829, 54.430669580187114, 55.364806243351524, 51.5521559715271, 53.422503335135325, 53.99352713993618, 55.76749951498849, 55.48635802950178, 56.333537987300325, 52.74764565059117, 52.676245961870464, 48.80014474051339, 47.84202636991228, 42.39819267817906, 44.831990310123985, 43.51759263447353, 42.90941333770752, 38.9773200580052, 40.374317918504985, 40.86794226510184, 46.36236926487514, 47.37696954182216, 48.94490698405674, 52.79477528163365, 50.57191106251308, 50.94450126375471, 54.14812455858503, 53.07270322527204, 55.49048178536551, 53.82778481074742, 53.592977387564524, 52.73290504728045, 48.022151470184326, 44.5728885105678, 37.74315670558384, 39.350973333631245, 41.55173185893467, 42.14298186983381, 50.653076444353374, 46.07393911906651, 47.74718345914568, 41.26934664590018, 40.60201733452933, 40.4761437688555, 39.552050726754324, 39.09139905657087, 48.3385967527117, 54.1310076713562, 53.92614698410034, 54.0465418951852, 52.35959570748465, 52.24901165281023, 52.59803009033203, 51.28300012860979, 52.19858857563564, 52.318344252450125, 46.78838416508266, 47.07852356774466, 48.899458817073274, 40.364680767059326, 36.72655187334333, 40.0202933038984, 42.6738555090768, 44.32310771942139, 43.14696877343314, 39.221948759896414, 40.3381838117327, 41.78659834180559, 46.55175978796822, 44.30986792700631, 47.22334139687674, 51.08607428414481, 51.40531274250576, 51.4489335332598, 50.55178560529436, 49.53435393742153, 50.92144366673061, 51.87616089412144, 46.19432360785348, 41.33856807436262, 40.776802744184224, 43.749349798474995, 51.93317781175886, 55.73295654569353, 54.62923519951956, 53.1855662890843, 53.33826337541853, 55.786065101623535, 56.07993916102818, 55.53335217067173, 55.50061920710972, 53.9869715145656, 56.092737742832725, 56.05742004939488, 54.67867163249424, 58.42560236794608, 53.81349236624581, 45.7688888822283, 30.955284323011124, 14.899013553346906, 2.4553331392151967, 2.3622798238481795, 5.638190005506788, 52.15544721058437, 58.9337797164917, 56.8060884475708, 57.921750273023335, 59.14212145124163, 60.0628411429269, 64.77428953988212, 62.19412463051932, 54.47513805116926, 37.48977327346802, 52.656662464141846, 46.87861694608416, 52.7107298714774, 2.951361128262111, 0.4688760031546865, 0.07045511369194303, 0.11584757295038019, 0.10602801093565566, 0.08595948280500514, 0.09005355954702411, 0.1070905424920576, 0.22131191806069442, 0.14183114868189606], [0.034381447426442585, 0.011770483355836144, 0.06900098600557872, 0.034178640094718764, 0.04753302689641714, 0.04544677598667996, 0.011426467797718942, 0.04369693595383849, 0.1007042998181922, 0.050924009044787714, 0.02788439828769437, 0.04351592316691365, 0.07161359688533203, 0.2719779243426663, 38.514875752585276, 46.923582213265554, 25.582534176962717, 27.089857271739415, 38.8311299596514, 51.94844300406319, 55.73248059409005, 56.391121183122905, 50.26370634351458, 48.445772715977256, 47.70187078203474, 47.80791418892996, 45.62407452719552, 43.43004880632673, 2.0772382276398793, 2.675658779484885, 0.17368141960884842, 3.4132213507379805, 35.256747313908164, 54.261595589774, 46.852724484034944, 48.48676361356463, 52.501769747052876, 53.14880337033953, 57.09276417323521, 52.86737353461129, 55.21617385319301, 53.108719212668284, 51.57130173274449, 51.96385063443865, 51.16549219403948, 54.16427217211042, 56.64805514471871, 52.51795210157122, 51.983680793217246, 52.339543206351145, 53.62056868416922, 50.03842837469918, 49.967414311000276, 47.04137849807739, 46.27070862906319, 47.49740614209856, 47.5311153275626, 49.04179613930838, 50.598661627088276, 50.05427026748657, 48.12094095775059, 45.141126087733674, 42.83807270867484, 41.29532943453108, 39.40799025126866, 37.74715886797224, 37.01235212598528, 36.98711279460362, 37.14861324855259, 35.51339292526245, 42.376298904418945, 45.25714710780552, 48.46558550425938, 47.98759113039289, 46.3692375591823, 48.069090025765554, 47.85727071762085, 48.647847175598145, 48.95775767735073, 49.34346955163138, 49.69383941377912, 45.518520968300955, 39.921410015651155, 38.533764430454795, 40.90013326917376, 39.96629190444946, 37.16849204472133, 42.38148920876639, 42.70532390049526, 42.496162278311594, 38.57984140941075, 44.656190463474815, 39.152480670383994, 37.47722135271345, 40.72867604664394, 39.04632261821202, 45.447809151240754, 49.85576023374285, 50.35543646131243, 52.4859174319676, 49.48262807301113, 48.74944026129586, 49.037126949855256, 48.79859529222761, 45.91824388504028, 46.72150080544608, 45.72961071559361, 44.1358676637922, 44.779229164123535, 41.42171369280134, 36.85164029257638, 37.28784820011684, 36.6416448865618, 39.222094672066824, 36.3969258580889, 35.61601781845093, 35.59584024974278, 37.97303785596575, 41.067793301173616, 40.388381072453086, 43.45988784517561, 45.75659057072231, 47.25047411237444, 47.04505409513201, 47.64988088607788, 49.10633448192051, 49.89841522489275, 45.67352138246809, 43.40768255506243, 37.198737553187776, 36.764464718954905, 38.74870000566755, 48.607123783656526, 49.00004093987601, 50.90834631238665, 49.854617255074636, 49.853543758392334, 48.51981619426182, 46.986807346343994, 49.31545441491263, 47.0770331791469, 50.4683655330113, 51.82343101501465, 50.04914944512503, 55.33057941709246, 46.709390095302034, 48.18776873179844, 43.22666808537075, 14.882918051310948, 2.9756042616707936, 0.15269028741334165, 0.6105859247701508, 7.397388339042664, 50.82068089076451, 46.072514738355366, 49.74687153952462, 51.5537679536002, 53.67325687408447, 52.943414619990754, 51.2380313873291, 55.25640044893537, 32.21913732801165, 27.102237224578857, 33.39994198935372, 42.50882189614432, 19.980380569185527, 0.15074842875557287, 0.031630367905433686, 0.03983322524332574, 0.0678611828812531, 0.097358267222132, 0.039957787309374125, 0.009752078314444848, 0.025570900911199193, 0.06182403290378196, 0.07342759918953691, 0.05213776909347091, 0.030928155407309532, 0.04690949731905546, 0.01140177421205278, 0.009161712136119604, 0.016335082573017905, 0.022062618717817322, 0.03961821785196662, 0.02955168266115444, 0.030248188679771762, 0.051474721636623144, 0.054940251034817526, 0.06428093356745583, 1.47233869774001, 47.741416454315186, 54.21819714137486, 19.150011777877808, 41.855253492082866, 47.551115717206685, 54.87164395196097, 63.164419719151084, 55.278895241873606, 53.04612636566162, 53.89572082247053, 53.73835802078247, 54.062821524483816, 49.90796204975673, 47.3094608443124, 2.1026204313550676, 3.366218524319785, 0.26739632018974846, 5.199095989976611, 41.816270623888286, 54.88509219033377, 48.99238749912807, 49.04965802601406, 55.17879949297224, 52.745251996176584, 59.256648608616416, 55.05658415385655, 56.838550431387766, 57.34427159173148, 53.121503898075645, 53.375922611781526, 51.30168036052159, 54.210331780569895, 57.95406287057059, 53.11311742237636, 55.18863466807774, 53.489261627197266, 56.67236341748919, 50.72754723685128, 50.871117864336284, 48.7753917830331, 48.094190393175396, 49.341117586408345, 49.80330828257969, 50.33313969203404, 51.97754553386143, 51.61498505728585, 48.30744450432913, 46.43961933680943, 44.75677258627755, 42.69705901827131, 41.269405705588206, 40.59579522269112, 39.38099997384207, 39.46359668459211, 38.50813947405134, 37.86688675199236, 44.57331929888044, 48.173854964120046, 49.77951070240566, 51.286988394601, 48.56627185004098, 50.63931553704398, 51.86713171005249, 51.26861388342721, 51.4342485155378, 51.89755092348371, 51.79089607511248, 48.04681410108294, 42.02058935165405, 38.42364590508597, 39.862464972904746, 38.8481183052063, 38.069221769060405, 42.916663782937185, 46.15324933188302, 44.33740363802229, 42.63617542811802, 44.0434844153268, 38.762499128069194, 38.03660692487444, 39.78053528921944, 38.49846063341413, 46.002848625183105, 51.898846762520925, 51.11454800197056, 52.71826171875, 50.049239771706716, 51.622906003679546, 50.52779000146048, 50.119982855660574, 49.85482570103237, 47.962945869990754, 47.41276666096279, 45.56198195048741, 46.597339970724924, 42.60909135001046, 36.78394399370466, 38.432244300842285, 40.81865174429757, 40.91351202556065, 38.37989657265799, 36.6829206602914, 37.26621845790318, 39.13030896868025, 43.71069002151489, 41.81514154161726, 46.18254293714251, 47.88463967187064, 48.45220674787249, 50.80078125, 52.13736799785069, 49.98341948645455, 50.329707281930105, 47.61161368233817, 44.75868681498936, 39.39208582469395, 38.82038804462978, 41.360857895442415, 51.42907558168684, 50.87426539829799, 52.397588457380024, 50.95279393877302, 50.907991954258506, 50.15765598842076, 50.393026215689524, 52.554461411067415, 49.759183747427805, 52.271377904074534, 54.703410693577354, 52.58547122137887, 57.06875467300415, 48.25002806527274, 48.59901523590088, 43.710512842450825, 18.84432578086853, 3.425289286034448, 0.06642374715634755, 0.3526427373290062, 9.027707576751709, 55.24973712648664, 50.33952161243984, 55.13500499725342, 55.701547213963096, 58.47125898088728, 54.818413802555625, 57.55115073067801, 57.99890654427664, 38.5146985735212, 36.548532077244346, 28.326744318008423, 49.627984387534006, 24.233595269066946, 0.2849513239094189, 0.03173064520316465, 0.047682633690003834, 0.040065114585948844, 0.023590189338262593, 0.06792554871312209, 0.056625630240887403, 0.003855347342323512, 0.011539767878795308, 0.055639837602419515, 0.13754098889018807, 0.0666953647243125, 0.14240472790385994, 0.17287796629326685, 0.21403149515390396, 0.17243842487888678, 0.05225356109440327, 0.11752765279795442, 0.20781304740480014, 0.16503844410181046, 0.05746254551091364, 0.12844293351684297, 0.19572535316858972, 1.8189982218401772, 61.00715691702706, 62.879967417035786, 35.59131349836077, 39.064526898520334, 52.05689743586949, 63.154706137520925, 67.48023768833706, 65.5388137272426, 61.04081399100167, 60.754999841962544, 57.89501360484532, 61.11329065050398, 55.639753409794395, 55.28019802910941, 2.3758913448878696, 6.619556180068424, 0.4852136064852987, 7.971078515052795, 48.653172969818115, 54.54065261568342, 50.02514341899327, 49.80971452168056, 56.353493213653564, 53.76194020680019, 63.29977757590157, 56.63705962044852, 58.7522371837071, 58.672145298549104, 57.24331774030413, 55.552751541137695, 52.77906193052019, 57.670093468257356, 60.29734284537179, 54.12515033994402, 57.910129410879954, 56.255488872528076, 56.59947681427002, 52.95062337602888, 51.51463222503662, 49.39629323141915, 50.808990546635215, 49.53462839126587, 50.38688053403582, 51.57706526347569, 55.771366187504356, 54.322830063956125, 51.17467423847744, 47.57234941210066, 47.389507566179546, 46.558211190359934, 43.715838636670796, 43.59359897886004, 39.88179833548409, 40.69093343189785, 41.52953931263515, 39.661849634987966, 46.95191696711949, 50.037156854357036, 52.32348939350673, 54.55514655794416, 51.13709143229893, 55.1171099117824, 53.89867728097098, 54.96288422175816, 54.49463817051479, 54.43739543642317, 54.68143006733486, 50.17204918180193, 41.48808635984148, 38.77097940444946, 40.924278259277344, 41.79297678811209, 38.83585820879255, 44.55108158929007, 47.45314959117344, 47.1725674356733, 46.78830426079886, 46.95407090868269, 40.110414913722444, 37.38171141488211, 40.52754306793213, 39.45755522591727, 46.64106151035854, 51.76058803285871, 53.51351431437901, 55.35384546007429, 50.81811005728585, 52.826691831861226, 53.96393128803798, 52.23027236121041, 49.55991983413696, 50.09500755582537, 51.17504596710205, 47.17009735107422, 49.705349104745046, 44.87938049861363, 39.73708125523159, 42.29313938958304, 42.94715595245361, 43.3385306085859, 40.71429327556065, 39.43463659286499, 39.63943474633353, 40.969691685267854, 45.97813735689436, 44.13967875071934, 47.34824916294643, 48.26242017745972, 49.90687118257795, 52.04060391017369, 52.96147298812866, 53.19962249483381, 52.99813863209316, 48.879454953329905, 45.96325431551252, 40.20293017796108, 40.33700609207153, 43.41376222882952, 53.019101347242085, 53.5231306212289, 54.99804210662842, 52.06215374810355, 51.22759519304548, 51.277830668858115, 49.736793177468435, 53.77052470615932, 50.20353494371687, 53.2208422933306, 56.00563165119716, 53.2880140032087, 58.875602449689595, 48.898055280957905, 49.568049226488384, 46.82608161653791, 25.324434655053274, 5.778606150831495, 0.7644131247486387, 1.363363151039396, 10.19592297077179, 60.262921469552175, 55.31046438217163, 60.23819977896554, 60.604960441589355, 63.3554812840053, 60.4847218649728, 59.03532069069998, 64.04406860896519, 44.85329696110317, 40.18424647194998, 45.27972527912685, 57.74847609656197, 36.87871742248535, 0.3640436455607414, 0.12242370364921433, 0.11537141778639384, 0.10380391563688006, 0.21145825966128282, 0.13765720836818218, 0.13970793118434294, 0.12994797847100667, 0.09347732511482068, 0.21570453180798463], [0.03099055348762444, 0.05199893743598035, 0.057267636326806884, 0.016312024256746684, 0.07466995609658104, 0.026207190339586565, 0.0274919947010598, 0.05911595893225499, 0.013108837700981115, 0.04800516852576818, 0.12067144124635629, 0.07512660337878124, 0.1413918108280216, 0.11085526512137481, 17.181083372661046, 52.477249554225374, 35.00214794703892, 21.91728299004691, 33.2852897644043, 45.891507216862266, 50.07549006598336, 49.953952176230295, 57.423477581569124, 46.60238436290196, 47.878309862954275, 49.439010756356375, 49.65034369059971, 51.78870044435774, 11.969420262745448, 2.880594377006803, 1.0016759761742182, 1.1621086874178477, 19.174684831074305, 52.057394232068745, 53.35922261646816, 54.151754992348806, 57.16213151386806, 55.58603341238839, 55.153369086129324, 55.504277433667866, 55.52185637610299, 55.221013273511616, 50.77151196343558, 50.9904705456325, 51.481586592538015, 50.83172505242484, 52.25501142229353, 52.07223558425903, 53.78680780955723, 52.82590321132115, 53.04618542534964, 54.85500649043492, 50.37627758298601, 52.98343276977539, 54.545766489846365, 51.15872812271118, 49.77167313439505, 52.00617906025478, 50.034832681928364, 53.95848042624337, 50.018942151750835, 43.73013802937099, 44.42491967337472, 42.95249564307076, 38.01190955298287, 39.25551550728934, 36.009779180799214, 35.29941272735596, 36.16935498373849, 38.43582609721592, 44.59115879876273, 47.621438435145784, 46.29976946966988, 47.211512088775635, 46.94578170776367, 46.62527172906058, 46.41987950461251, 50.002881390707834, 48.76812744140625, 49.57872860772269, 45.927377292088096, 37.24509940828596, 36.75767980303083, 38.09860222680228, 37.49360867909023, 35.72025121961321, 39.78917537416731, 40.79874168123518, 41.4226655960083, 41.70577342169625, 37.023830550057546, 37.79873882021223, 42.56170810971941, 39.684188093457905, 37.53488097872053, 41.705109868730815, 39.994008268628804, 46.0658027785165, 51.358190059661865, 50.00634854180472, 51.13523626327515, 51.17989580971854, 48.77060794830322, 48.39705889565604, 47.16493483952114, 47.970408235277446, 48.35508482796805, 45.950504371098106, 46.13599695478167, 42.650850023542134, 38.41810124261038, 36.12241990225655, 36.467248576028005, 38.93713515145438, 36.318974018096924, 37.24580465044294, 36.797420024871826, 40.74233620507376, 41.79817056655884, 39.77952085222517, 41.884383814675466, 45.938980783735005, 48.33585916246687, 47.202611446380615, 48.61349875586373, 49.37907212121146, 49.06075777326311, 46.77351154599871, 46.706579548971995, 39.90396656308855, 35.62737464904785, 37.60031563895089, 40.9308443069458, 47.55618790217808, 48.337665694100515, 49.06298467091152, 51.7379264831543, 50.41684464045933, 50.625259331294465, 49.75389616830008, 51.52450908933367, 50.176245893750874, 53.21786151613508, 52.398026193891255, 51.27881383895874, 48.61816447121756, 45.096949441092356, 36.78746673039028, 6.527520775794983, 0.10364877539021627, 0.04175410020564284, 0.1129737396591476, 10.758588092667715, 46.35930163519723, 44.709465776171, 47.835397788456504, 49.82616090774536, 48.98485565185547, 52.151385988507954, 47.6650071144104, 46.051347051348, 28.1120571408953, 24.1472395828792, 30.461274351392472, 38.37944493974958, 3.04304347719465, 0.2682270641837801, 0.01870654210714357, 0.055819798660065444, 0.0787817629586373, 0.0731713165129934, 0.053907133971474, 0.06119573661791427, 0.04870486705164824, 0.019708407543865696, 0.051063719405127425, 0.02362015174834856, 0.06550392508506775, 0.027409001386591365, 0.02060853852890432, 0.07023013183580977, 0.03222690875242863, 0.012351835196438645, 0.015707827838403837, 0.02321550908631512, 0.07751392027629272, 0.09723731156970773, 0.13253295261945042, 0.19373793766966887, 0.025314175490556017, 23.799186944961548, 64.22006647927421, 31.299105507986887, 26.051362139838083, 47.909958907536094, 47.806475911821636, 56.73024885995047, 55.117999281202046, 63.505611010960166, 52.26246336528233, 53.98669358662197, 56.51044259752546, 54.468537262507844, 57.86898217882429, 12.372173462595258, 2.338429263659886, 1.1480198034218378, 1.3914767567600523, 25.869678906032018, 56.120916162218364, 57.935941968645366, 56.137570994240896, 59.11093098776681, 56.56927299499512, 57.955167634146555, 56.43875455856323, 56.400469984327046, 56.39167703901018, 52.02663108280727, 52.89041723523821, 54.10113736561367, 51.945444856371196, 52.55291543688093, 53.193605354854036, 54.928494112832205, 55.258801051548545, 54.980640343257356, 55.236136027744834, 51.35238136563982, 53.34584733418056, 53.641882283346995, 49.97576951980591, 52.42167091369629, 52.57984665461949, 51.163550172533306, 54.622745582035606, 51.26684904098511, 45.43989167894636, 45.944966656821116, 43.700351102011545, 40.007393973214285, 41.89463588169643, 38.24987840652466, 37.44068425042288, 37.69081245149885, 40.56283644267491, 46.99268899645124, 49.98518432889666, 49.59748526981899, 49.72880622318813, 50.06686040333339, 49.451899664742605, 49.044790812901084, 52.79377474103655, 50.287524768284385, 51.87407990864345, 49.747708797454834, 39.32386493682861, 38.27079595838274, 37.56944826671055, 40.66097627367292, 38.513698032924104, 42.44301898138863, 42.44132709503174, 43.26133264814104, 44.76102140971592, 39.348426818847656, 43.27794926507132, 45.62171561377389, 38.61134454182216, 38.84902504512242, 41.12977123260498, 38.885520458221436, 48.572824001312256, 51.01146452767508, 51.048779828207834, 52.794893401009695, 50.32488175800869, 51.27412380490984, 49.50035640171596, 47.74087102072579, 49.256592750549316, 49.04150084086827, 47.5508690561567, 47.66870355606079, 44.18821539197649, 39.42906066349575, 37.67949036189488, 37.93704966136387, 41.19779757090977, 37.489220891680034, 39.04060077667236, 38.29664673124041, 40.676123346601216, 43.65699781690325, 42.46946382522583, 43.42638710566929, 47.25725555419922, 49.93029703412737, 48.85085269383022, 49.67004530770438, 50.58174276351929, 50.168734891074045, 48.72009107044765, 45.68740735735212, 42.01113632747105, 37.82428387233189, 38.64195483071463, 43.10377877099173, 49.704053265707834, 50.306517669132774, 50.98003435134888, 53.33707523345947, 52.08605555125645, 52.76024273463658, 51.152255875723704, 53.111849376133506, 51.111685344151084, 53.79649359839303, 55.563743591308594, 53.783201694488525, 50.91126108169556, 47.96690286908831, 40.00676168714251, 8.242198961121694, 0.10854228173515626, 0.3426354043185711, 0.06898327624159199, 12.494693653924124, 53.328219754355295, 47.982345240456716, 54.910279410226, 54.53217233930315, 55.93675068446568, 54.825163977486746, 57.76967852456229, 49.64584820611136, 40.499791962759836, 29.457155432019913, 28.383181061063492, 48.64854894365583, 4.236935070582798, 0.1833638564816543, 0.0620869245114071, 0.07174190107200827, 0.09015728040997471, 0.0504560234424259, 0.022124618158808777, 0.12852538909230912, 0.00797682799332376, 0.06076365230338914, 0.05953366508973496, 0.09321092548114912, 0.12361221201717854, 0.1729597704751151, 0.085684838970857, 0.21344046401126043, 0.22127453078116688, 0.1569572277367115, 0.08632691630295344, 0.08031076698430947, 0.15212029085627624, 0.18024617806077003, 0.20334535571081297, 0.34548033880335943, 0.2917687009487833, 30.066446440560476, 71.72042451586042, 49.109777314322336, 32.57946048464094, 43.41795546667916, 60.141633714948384, 60.231654575892854, 60.89817442212786, 67.94939395359584, 59.33699062892369, 56.814700739724294, 62.490069253104075, 59.274303981236045, 65.18348979949951, 13.972888163157872, 5.700916605336325, 2.4755430604730333, 2.6518698845590865, 31.890421526772634, 57.91471522194998, 59.34550217219761, 59.23681150163923, 61.10978181021554, 59.2530494417463, 57.33484983444214, 59.277263913835796, 58.886705671037944, 56.50795514242989, 51.91781881877354, 54.18277522495815, 54.04551703589303, 55.6698773247855, 54.29204259599958, 55.60031196049282, 57.817878178187776, 58.44030475616455, 56.641569001334055, 58.546744210379465, 52.544146810259136, 54.091812883104595, 55.620340142931255, 52.63420588629586, 54.13743128095354, 54.97958074297224, 51.691119943346294, 57.66732461111886, 55.21680266516549, 47.15679849897112, 48.85105071749006, 47.20455346788679, 41.19211047036307, 44.42696244376046, 40.47651202338082, 40.1997583253043, 40.67412573950631, 43.409975460597444, 49.49530158724104, 50.90774529320853, 52.77827330998012, 51.47633375440325, 52.57248156411307, 52.10136938095093, 51.36360618046352, 55.91082348142351, 53.91542591367449, 53.85220078059605, 49.804107325417654, 39.988915239061626, 38.62042931147984, 38.48623527799334, 41.47511059897286, 38.82999740328108, 43.43768835067749, 43.59583282470703, 45.87324387686593, 47.45150286810738, 42.267806257520405, 46.07604789733887, 46.049814973558696, 39.40169865744454, 38.54523243222918, 41.914601530347554, 38.72560766765049, 47.57585825238909, 53.55829545429775, 54.115610463278635, 55.04614795957293, 52.9632864679609, 52.34541096006121, 52.56327520098005, 51.250423499516074, 53.588888372693745, 53.18352699279785, 49.01977729797363, 51.55041197368077, 45.788427216666086, 42.21549327032906, 39.115043776375906, 40.00370447976248, 42.956143447331016, 41.0464380128043, 42.55134834562029, 40.0797038759504, 43.951243604932515, 47.238154956272666, 45.42526919501168, 45.92388234819685, 50.27810648509434, 51.812425068446565, 50.56671380996704, 52.47510603496006, 53.13858951841082, 52.953354018075125, 50.57295676640102, 49.612340518406455, 44.03163773672921, 41.11180666514805, 41.97221599306379, 46.82217672892979, 50.51082597460066, 52.470287459237234, 54.010213238852366, 55.17966454369681, 56.8172333581107, 53.52101142065865, 53.15959392275129, 55.651252678462434, 52.354884828839985, 56.73820802143642, 56.72857781818935, 56.538829462868826, 51.37541116986956, 48.47713688441685, 44.75591100965227, 14.106183273451668, 0.19242995285562106, 0.5022748538425991, 0.7401369873966489, 13.413383603096008, 57.03545543125698, 53.39349808011736, 57.30142552512032, 60.38462611607143, 59.28478186471121, 63.438873563494, 58.77445752280099, 59.71015058244978, 40.200011934552876, 36.21583495821272, 41.3886194229126, 57.728447914123535, 9.353730951036725, 0.47936116052525385, 0.15894362543310436, 0.2238289708537715, 0.16741889422493322, 0.15766907882477554, 0.1392245971198593, 0.1883461627044848, 0.12482487623180662, 0.13554768370730536, 0.17004173062741756], [0.04437323519960046, 0.07814337007169213, 0.04560264226581369, 0.03641987858074052, 0.024276936326974204, 0.048039709350892475, 0.05499853380024433, 0.0378596620368106, 0.04261760047769972, 0.0194907996670476, 0.044759745709598064, 0.0007688960571873135, 0.042770566019628725, 0.041355281070406945, 3.583931859050478, 46.91598435810634, 32.7946948323931, 31.329007080623082, 27.279555252620153, 42.513939244406565, 54.766090393066406, 48.172972542899, 53.34974874768938, 49.10300629479544, 48.42419508525303, 51.22203663417271, 43.844421999795095, 49.960827418736045, 16.116169452667236, 2.195580814565931, 0.26381851360201836, 0.0908034493082336, 8.843480433736529, 49.87793888364519, 55.99165882383074, 55.39261988231114, 50.763580594744, 55.62697914668492, 54.34074599402291, 54.350414412362234, 55.103633880615234, 53.467631884983604, 54.85842847824097, 54.30439649309431, 53.57196603502546, 53.6340377671378, 51.57558182307652, 51.538224833352224, 49.837892941066194, 52.622147287641255, 52.170635972704204, 51.963854108537944, 52.070057324000764, 52.51920277731759, 50.07744945798601, 51.466039998190745, 52.19799450465611, 52.67561714989798, 52.33890049798148, 50.28885187421526, 50.55470037460327, 47.04013477052961, 43.16631255831037, 42.63545281546456, 36.84903471810477, 38.313871315547395, 36.43510273524693, 35.67446953909737, 35.79021610532488, 38.653381143297466, 44.589220251355854, 47.059079033987864, 46.871668747493196, 46.94707407270159, 48.347441809517996, 49.24703550338745, 48.58759587151663, 49.80366958890642, 51.121972152165, 45.281493595668245, 38.84241383416312, 37.724000522068565, 38.79736518859863, 38.90217876434326, 37.96262945447649, 38.25568362644741, 37.69245222636631, 37.41204724993025, 37.170944758823936, 40.19482510430472, 37.28609725407192, 33.705600193568635, 35.953398023332866, 40.04651233128139, 41.536966936928884, 37.9295768737793, 39.99242755344936, 40.375374044690815, 44.03742558615548, 52.76610354014805, 49.975147656032014, 50.06880589893886, 48.4282945224217, 48.081447396959575, 47.57356882095337, 47.35799748556954, 46.35712684903826, 45.16200195040022, 44.462245396205354, 45.365455627441406, 39.7588186945234, 37.692351477486746, 33.77437693732125, 33.88999148777553, 36.31349883760725, 35.71442168099539, 37.678065981183735, 40.10539484024048, 41.4633994102478, 42.211980955941335, 46.91241298403059, 47.550427845546174, 46.174927711486816, 47.833539145333425, 47.91865457807268, 47.838719027382986, 47.93101889746529, 46.51872457776751, 44.658573695591514, 42.41741834368025, 39.69386345999581, 36.05556433541434, 36.39525481632778, 38.205079896109446, 42.01667751584734, 45.30127164295742, 48.495535714285715, 49.232159410204204, 49.68156542096819, 50.482439109257285, 50.910177162715364, 50.10733018602644, 51.47198418208531, 49.16354594911848, 50.30939074925014, 51.16680540357317, 50.04860748563494, 29.43332658495222, 2.0449403950146268, 0.30906255011047634, 0.23007418002401078, 0.03767504622893674, 15.69710796219962, 49.60281106403896, 46.30600547790527, 50.12643773215157, 49.56525257655552, 52.289352893829346, 52.135547569819856, 50.131989342825754, 37.24834769112723, 20.165251289095195, 27.917281763894216, 34.55873128346035, 29.022493498665945, 0.19006619469395705, 0.09952598983155829, 0.04964531658749495, 0.08214522711932659, 0.028103329307798828, 0.006463004492356309, 0.005333185162661331, 0.03856837490041341, 0.02269327630554991, 0.005920969091156232, 0.025039541834433163, 0.04190001916140318, 0.04645155742764473, 0.0557428086841745, 0.06214968900063208, 0.08270761051348277, 0.05231858849791544, 0.052946989956711016, 0.06344097506787096, 0.07498752405600888, 0.014893165124314172, 0.06434011539178235, 0.07223218333508287, 0.1576364684317793, 0.09471692038433892, 6.91370165348053, 56.435447216033936, 34.30143254143851, 17.513606786727905, 38.405497210366384, 46.966490813664024, 57.72797196252005, 54.17744595663888, 60.05236325945173, 53.066769463675364, 54.00970949445452, 56.64547388894217, 48.938879421779085, 56.360361507960725, 17.643729175840104, 1.2617531291076114, 1.2952792729650224, 0.06451985253287212, 11.542459539004735, 54.079601424080984, 59.58574308667864, 57.751154627118794, 54.58315474646432, 57.72207989011492, 57.80621215275356, 57.1183682850429, 57.281216689518516, 56.20040702819824, 56.850261620112825, 56.67496204376221, 56.81084448950631, 55.26304292678833, 54.07036031995501, 53.96894441332136, 53.19191346849714, 54.96668488638741, 54.199430056980674, 54.99071870531355, 54.37878738130842, 53.57122605187552, 51.491293225969585, 52.136155537196565, 54.37789453778948, 54.371158259255544, 53.452293736594065, 51.65080302102225, 52.05629294259207, 47.4541848727635, 43.81971767970494, 43.37100996289934, 39.018804277692524, 39.58072941643851, 38.44101987566267, 37.25492068699428, 37.421837261744905, 40.57792445591518, 47.431175913129536, 51.20339809145246, 50.022895676749094, 50.75368635995047, 50.30228621619088, 52.37681334359305, 51.27645492553711, 52.51448147637503, 52.904244150434224, 47.870249952588765, 39.20937252044678, 38.59899064472744, 38.39067670277187, 39.660887309483115, 38.89596707480294, 40.02670996529715, 39.31730236325945, 40.4699946131025, 40.46516214098249, 41.25386258534023, 39.61902788707188, 39.04499551228115, 40.071974005017964, 41.638198716299875, 40.26881299700056, 39.05331598009382, 40.19426924841744, 42.40609277997698, 44.94208104269845, 53.567071029118125, 50.86780704770769, 51.51297507967268, 51.345249039786204, 49.76898070744106, 48.0098740032741, 49.58146619796753, 47.201343400137766, 47.052999360220774, 46.55822508675711, 46.70650659288679, 41.82490028653826, 37.309255599975586, 34.86575133459908, 36.10700879778181, 36.69741807665144, 37.31155545370919, 38.468576431274414, 42.30245344979422, 42.892508370535715, 44.86665834699358, 49.02202156611851, 50.28547157560076, 49.717008181980674, 49.81361593518938, 50.66963747569493, 49.62181091308594, 48.95663554327828, 48.73509223120553, 46.789200578417095, 46.04178980418614, 42.34186710630144, 38.249454566410606, 37.64538860321045, 39.62346083777291, 44.56521075112479, 47.47107594353812, 50.72543151038033, 52.43133238383702, 52.58786487579346, 52.033520221710205, 52.24830641065325, 51.69320787702288, 54.00328588485718, 51.84499822344099, 53.0779595375061, 52.8110271181379, 53.234387806483674, 34.594907079424175, 2.3303291840212683, 1.2720449311392648, 0.3850447657917227, 0.045102392323315144, 19.32673052379063, 54.931770188467844, 52.40284824371338, 54.46254791532244, 53.83673756463187, 57.13631548200335, 58.95832075391497, 57.836596625191824, 40.80696487426758, 27.884609597069876, 23.639649357114518, 40.43842894690377, 36.69773074558803, 0.36020292022398537, 0.10125313965337616, 0.06329403152423245, 0.011270330104577755, 0.06734237500599452, 0.044272859514291794, 0.03195156941988638, 0.12331810779869556, 0.026956276036798954, 0.003506732589033033, 0.022551671136170626, 0.08872698965881552, 0.20600994915834495, 0.12540958342807634, 0.1250213799732072, 0.13503138641161577, 0.1928664544331176, 0.15832362084516458, 0.13425949854510172, 0.1989501722689186, 0.12598855021808827, 0.1612777587558542, 0.17970725840755872, 0.20623792335391045, 0.19546657348317759, 8.267332332474844, 68.96768024989537, 44.459434849875315, 41.37799910136631, 38.425348213740754, 53.24995871952602, 63.6620705468314, 60.027099609375, 63.91487380436489, 61.205444608415874, 59.77515098026821, 62.79327474321638, 52.59570244380406, 60.25865527561733, 21.699898174830846, 6.275980353355408, 3.5388022235461642, 0.281692917325667, 17.110578264508927, 57.182903153555735, 62.71264089856829, 60.77999251229422, 55.101625851222444, 60.68671294621059, 59.35228361402239, 60.072450501578196, 59.03195081438337, 59.187361172267366, 60.63167626517159, 59.94704941340855, 59.94909913199288, 58.98856626238142, 57.321769850594656, 55.73329700742449, 55.571341446467805, 57.37101520810808, 56.21272965839931, 56.13270378112793, 55.63935388837542, 56.37635626111712, 52.836071899959016, 53.55400494166783, 55.53549221583775, 56.016727924346924, 57.277308327811106, 53.93829590933663, 55.224126066480366, 51.061488083430696, 46.960404191698345, 45.10417209352766, 42.21444409234183, 42.92065552302769, 39.345623220716206, 39.07507078988211, 40.17720447267805, 44.15343618392944, 49.180864334106445, 52.03411429268973, 50.49530022484915, 52.14196423121861, 53.71436589104788, 55.04560947418213, 52.461883613041465, 54.64601162501744, 55.05966567993164, 49.15521158490862, 39.99782977785383, 39.4810540335519, 39.71406534739903, 41.94751862117222, 39.77907964161464, 40.81978777476719, 41.63750737054007, 42.354207106998985, 41.987474237169536, 44.01184926714216, 41.86338288443429, 39.77929156167166, 42.03474283218384, 44.60302979605538, 41.927028383527485, 39.154318468911306, 41.62340600149972, 42.44236237662179, 43.79400587081909, 56.66569314684187, 53.5142160824367, 53.83594199589321, 53.096483434949604, 52.29362256186349, 49.0469308580671, 52.077905314309255, 50.21868896484375, 49.35863052095686, 47.84156084060669, 48.21687820979527, 43.903068270002095, 40.092769963400706, 37.10899462018694, 36.70682941164289, 39.62048700877598, 39.97697128568377, 40.92850971221924, 44.84357295717512, 46.11955404281616, 45.34292956760952, 51.16430057798113, 53.53885439464024, 52.80669839041573, 52.890111514500205, 50.83707863943917, 51.19496297836304, 52.27151339394705, 50.38868359157017, 48.23015621730259, 48.87163128171648, 43.41977589470999, 40.536019870213096, 40.24708250590733, 42.336131368364605, 45.958463532584055, 48.89021076474871, 53.915328638894216, 54.57031447546822, 54.428731032780235, 54.99998412813459, 55.897378717150005, 52.608358587537495, 56.9112355368478, 54.174409593854634, 56.37665850775582, 55.334161213466096, 54.80065768105643, 36.42015021187918, 4.4189179454530985, 2.3462392560073306, 1.1986007349831718, 0.47608182792152676, 21.718185833522252, 62.8700384412493, 57.65986919403076, 60.163096700395855, 58.997411319187705, 62.4496237891061, 61.96173518044608, 62.76134777069092, 48.217732838221956, 31.407448768615723, 38.53689806801932, 46.81790358679635, 48.23231710706438, 1.3062096578734261, 0.1775157938578299, 0.14138282702437469, 0.1341118086129427, 0.16703928102340015, 0.09387082114283528, 0.08561134005763701, 0.19460936662341866, 0.15892401577106544, 0.08680133441729204, 0.10700162047786371], [0.03702218358271888, 0.04300840950704046, 0.029938203349177326, 0.0259731008471655, 0.07822161194469247, 0.03793395483600242, 0.03762386433248009, 0.05824841119881187, 0.02800530304999224, 0.03250282823241182, 0.05384816927835345, 0.07415401163910117, 0.06527425455195562, 0.009969832924460726, 0.27222613245248795, 39.15140717370169, 50.65845087596348, 37.491736139569966, 32.86592776434762, 34.890948976789204, 54.78755685261318, 50.98603412083217, 51.94516692842756, 54.792781897953574, 48.25015313284737, 51.676893506731304, 47.20337922232491, 52.86823858533587, 22.289117574691772, 0.671581066080502, 0.8885462752410344, 0.08975998458585568, 3.183172792196274, 46.77852814538138, 52.106382506234304, 52.96884502683367, 49.35142523901803, 47.21517031533377, 50.231418064662385, 51.15045281818935, 52.44851180485317, 55.77358961105347, 52.86501809528896, 52.42033338546753, 50.39454787118094, 49.59913199288504, 49.92330019814627, 50.004545484270366, 47.504844188690186, 48.493972369602744, 49.06707715988159, 49.26280096599034, 51.6091103553772, 53.041721207754954, 51.59160784312657, 51.47880036490304, 51.81499590192522, 50.232439449855256, 53.901908193315776, 53.0285404750279, 51.2120485986982, 48.64883729389736, 42.44993591308594, 42.95017841884068, 39.50714104516165, 36.130108083997456, 36.74403354099819, 35.224976675851, 34.75795003346035, 35.55284479686192, 43.75456094741821, 47.926134313855854, 48.73925072806222, 48.801687240600586, 48.49824898583548, 48.0831948689052, 48.44824627467564, 48.01020404270717, 40.30633326939174, 39.86052295139858, 38.60474027906145, 40.41499267305647, 38.99367611748831, 38.601964473724365, 37.94596767425537, 35.30563136509487, 33.70177868434361, 34.654790128980366, 35.11811685562134, 35.91408511570522, 35.745455810001914, 36.006433623177664, 32.98527002334595, 35.28227846963065, 39.385290486471995, 40.49250677653721, 39.48524727140154, 41.3078396660941, 39.292900289808, 43.00602109091622, 49.662833077566965, 50.88724115916661, 50.596858569553916, 49.222727230616975, 46.99891110828945, 48.73466839109148, 47.6561655317034, 47.31162520817348, 44.875572885785786, 46.24036584581648, 39.89898470469883, 34.91238416944231, 34.65093387876238, 35.43621580941336, 33.72782053266253, 35.105311325618196, 35.51433788027082, 38.58833558218819, 42.24026012420654, 46.96502474376133, 46.45128188814436, 47.6439471244812, 47.64058767046247, 49.68170091084072, 43.167101178850444, 42.70897517885481, 41.019402572086875, 48.89660658155169, 46.761734349387034, 48.025569983891074, 45.3347932270595, 47.010243620191304, 40.74547331673758, 38.15924957820347, 36.402043206351145, 38.6219996043614, 41.7125757081168, 44.704143456050325, 47.44406829561506, 48.07969992501395, 49.09019729069301, 50.86842196328299, 46.762755734579905, 47.836144719805034, 46.33412831170218, 50.90193312508719, 46.71446575437273, 37.564014775412424, 2.8019972230706895, 0.1902959602219718, 1.2198842614889145, 0.1383761569325413, 22.809450796672277, 50.284286907741, 43.20538227898734, 49.22634376798357, 48.74934993471418, 51.27675369807652, 46.197040353502544, 51.75977856772286, 28.856270006724767, 26.39889713696071, 39.98766803741455, 36.334058557237896, 15.26418307849339, 0.3603867489312376, 0.029774873184838464, 0.1328926711742367, 0.07070818689784833, 0.05676351194935186, 0.04664547595062426, 0.08321802491056067, 0.03311553856890116, 0.01761012620824788, 0.011387938883022537, 0.011889577277802994, 0.06357193911182028, 0.03227576327377132, 0.06308956856706313, 0.034506209660321474, 0.03373619115778378, 0.07961572320865733, 0.04920162593147584, 0.029649395096514906, 0.020557422789611986, 0.035140544907855134, 0.0125136242381164, 0.04617348699165242, 0.03123735702995743, 0.0650297783847366, 0.5868862707700048, 46.477997711726594, 56.55585602351597, 32.56308010646275, 40.33947270257132, 48.00005619866507, 57.818642480032786, 56.082457883017405, 55.815091201237266, 60.59558037349156, 54.130882603781565, 57.45899329866682, 50.80131278719221, 57.26009069170271, 24.040678535188945, 0.6926672746028218, 1.8669110451425825, 0.07997061737946101, 5.61851487840925, 54.88087463378906, 55.192275524139404, 56.81428384780884, 52.02941036224365, 49.72116320473807, 51.53210347039359, 54.54763902936663, 56.076197556086946, 56.854937757764546, 54.15353373118809, 53.0114791733878, 52.69568354742867, 51.231604303632466, 51.12402881894793, 51.45553432192121, 50.334320885794504, 50.90739440917969, 51.06111635480608, 52.7415486063276, 53.8161952154977, 53.23934882027762, 53.13129390989031, 52.28768880026681, 53.29867948804583, 51.63379730497088, 55.68047332763672, 56.186055524008616, 53.77375214440482, 51.0582571710859, 44.99948011125837, 45.11181163787842, 40.14925534384591, 38.63561807359968, 38.67713703427996, 38.09307493482317, 37.221461636679514, 38.42532736914498, 45.85876383100237, 50.53051022120884, 51.88406794411795, 51.39068331037249, 50.042677198137554, 50.11578961781093, 51.316549505506245, 49.852696078164236, 42.69911221095494, 40.37107310976301, 38.23649617603847, 42.112861428942, 39.662627833230154, 39.31479753766741, 41.08543825149536, 38.98662369591849, 36.43172243663243, 37.703180244990754, 37.05583395276751, 38.26317378452846, 39.43125629425049, 39.10324226106916, 36.74277939115252, 39.13730927876064, 41.30527230671474, 41.241227286202566, 38.651939392089844, 41.31479481288365, 39.093407085963655, 43.85780075618199, 52.522134917122976, 51.7893396786281, 51.081794193812776, 51.2292697089059, 47.69010400772095, 49.21403156008039, 49.464350836617605, 48.0085642678397, 46.3379567691258, 48.160615171704976, 40.549919741494314, 37.00740500858852, 35.20952040808541, 36.40823057719639, 36.43948010035923, 36.5694774218968, 38.013816833496094, 40.99022708620344, 43.66716650554112, 47.9375502041408, 48.014303479875835, 49.17548642839704, 50.246794428144185, 50.666309288569856, 45.91162919998169, 45.348303999219624, 43.838067872183665, 49.75202710287911, 49.62424278259277, 50.35269887106759, 46.750947271074565, 49.07962213243757, 42.802845341818674, 40.10495015553066, 38.66310167312622, 40.44028064182827, 42.22203152520316, 47.03788355418614, 49.10714394705636, 50.54052257537842, 51.05613449641636, 53.58879109791347, 48.06239891052246, 49.9285113470895, 49.18372699192592, 53.0805720601763, 50.752842153821675, 41.28989594323294, 3.665580792086465, 1.2839570747954505, 1.356722953064101, 0.14721080501164707, 26.665301493235997, 54.80952705655779, 48.91783332824707, 55.22916351045881, 57.26133789334978, 56.802927017211914, 52.66339179447719, 54.31000368935721, 36.98718922478812, 34.519908223833355, 35.471102714538574, 43.407515798296245, 18.22845482826233, 0.24184263710464748, 0.05022395768069795, 0.07366435362824372, 0.028838203089045625, 0.025876431659396206, 0.0603196257725358, 0.10969421028026513, 0.06174069523279156, 0.020444612950086594, 0.050298206375113556, 0.0075446520765711155, 0.10482616256922483, 0.1213061021906989, 0.1589904443493911, 0.1405371552599328, 0.09893932166908469, 0.1573397179267236, 0.10926080960780382, 0.15008374942200525, 0.12306498709533896, 0.12736255648945058, 0.15026851450758322, 0.16336611312414917, 0.18990295273917063, 0.08122887914734227, 0.7968910134264401, 57.46686560767037, 64.60041087014335, 48.17043645041329, 46.578138623918804, 46.94877290725708, 65.9760708127703, 59.44628579275948, 64.38127163478306, 64.56071581159318, 60.38262503487723, 60.14542743137905, 56.352728911808555, 61.67685209001814, 27.573708977018082, 2.2318013395581926, 4.36674348797117, 0.1556482251201357, 9.679779512541634, 60.18087019239153, 57.52085311072213, 60.38102000100272, 53.78856222970145, 53.18667105266026, 53.933112553187776, 54.708368233272004, 59.37574768066406, 59.19191224234444, 57.1597170148577, 56.02679933820452, 53.13578244618007, 53.28745814732143, 54.96106031962803, 53.41843169076102, 51.615652084350586, 53.55393198558262, 52.36566495895386, 53.81677539008004, 55.14798423222133, 56.15280144555228, 54.59894800186157, 54.84532070159912, 54.9018304007394, 53.52316883632115, 57.18063804081508, 58.38650485447475, 58.05194214412144, 53.150557790483745, 47.255452496664866, 47.47534213747297, 43.21872282028198, 39.9810915674482, 41.13260262353079, 39.9532744543893, 38.717704091753276, 40.859201431274414, 47.349287918635774, 50.988736970084055, 55.97035217285156, 54.28358316421509, 51.619320733206614, 52.11952154976981, 53.61110871178763, 49.833890778677805, 41.62562942504883, 40.21338374274117, 38.92809901918684, 42.47503975459507, 42.40781940732683, 40.70133488518851, 42.46870299748012, 41.382279191698345, 37.0978809765407, 41.63803195953369, 39.22045142310006, 39.80540289197649, 41.09235865729195, 41.102412700653076, 37.27368777138846, 42.33133363723755, 42.56461245673043, 40.58507762636457, 38.70234162466866, 41.59664501462664, 37.53813968385969, 42.629925523485454, 52.92065232140677, 52.99559211730957, 53.35729796545846, 53.45408637183053, 49.664452007838655, 52.62676436560494, 50.183902808598106, 51.6841265814645, 48.73105880192348, 49.988936356135774, 42.84141479219709, 37.93835939679827, 38.845627376011436, 37.490478515625, 37.44935212816511, 38.64908715656826, 39.105490003313335, 42.4452736718314, 44.751634393419536, 49.24094888142177, 50.00550433567592, 51.956231934683665, 50.73564188820975, 53.32500968660627, 45.190708432878765, 46.349563734872, 45.24544286727905, 51.908570766448975, 52.16777678898403, 53.501712799072266, 49.65751770564488, 52.5517064503261, 45.54781804765974, 42.09243025098528, 41.30384792600359, 42.74171161651611, 45.35051005227225, 49.9285113470895, 51.741782733372276, 52.52838829585484, 52.596702984401155, 57.285812922886436, 50.444581849234446, 53.05689607347761, 51.87481641769409, 56.58170679637364, 53.199625968933105, 44.91665063585554, 4.97039429630552, 2.5390999700341905, 1.9702865609100886, 0.3947492821940354, 30.68604510171073, 61.118355887276785, 52.39618839536394, 61.05443246023995, 59.690751211983816, 62.64356190817696, 58.00571925299508, 62.24293572562081, 41.21259028570992, 39.98921748570034, 50.701620033809114, 51.610788345336914, 28.163261890411377, 0.38423307506101473, 0.1381917582558734, 0.14741234348288604, 0.12361651392919676, 0.10713743604719639, 0.13201539324862616, 0.18535243906080723, 0.10019908978470735, 0.11918401106127671, 0.12354547131274428, 0.15764562865453108], [0.029585297285978283, 0.02208862696508212, 0.0213558447680303, 0.02015111262777022, 0.05346091916518552, 0.046647436916828156, 0.025848801713436842, 0.05407563457265496, 0.028017862733187418, 0.05657088603558285, 0.08630500640720129, 0.08922153990715742, 0.0391212689823338, 0.05201243349750127, 0.03712396044284105, 10.138861758368355, 47.05728987285069, 35.15285784857613, 25.26308900969369, 29.41423988342285, 44.07072830200195, 58.118978364127024, 50.49404954910278, 51.631824016571045, 49.13905702318464, 52.527491978236604, 44.58347756522042, 51.61452995027815, 22.86072850227356, 0.11643727416438715, 1.3121751206261771, 0.38878547506672995, 0.9122701393706458, 35.80284098216465, 55.46650007792881, 52.28117486408779, 51.624757698604036, 46.794491631644114, 42.659656865256174, 43.297755105154856, 47.40172597340175, 49.32655416216169, 49.27858032499041, 50.990442752838135, 46.6460850579398, 44.6364541053772, 43.492436681474956, 43.07841437203543, 43.248547962733674, 44.11859096799578, 45.94937528882708, 47.77938141141619, 47.532404218401226, 47.42885174070086, 50.71479729243687, 53.076219013759065, 49.376977239336284, 48.17845467158726, 46.149167265210835, 50.11871133531843, 49.119789668491904, 49.503316334315706, 46.38405806677682, 41.090708460126606, 41.37009899956839, 35.961860929216655, 36.54925121579851, 34.652045590536936, 34.62857804979597, 35.406609535217285, 40.45612253461565, 47.59139095033918, 49.57217993055071, 47.48566716057913, 49.06073692866734, 46.964083262852256, 42.817353180476594, 39.35841138022286, 40.34841850825718, 40.36641781670706, 39.6977162361145, 38.51712696892874, 36.75784655979702, 36.842499937329976, 34.78682327270508, 33.540399823869976, 33.6170071874346, 35.671763215746196, 35.57646867207119, 33.99803597586495, 36.09958117348807, 35.10640566689627, 34.54863902500698, 33.66195855821882, 32.843023027692524, 37.24833032063076, 43.80384452002389, 39.4287862096514, 38.3852710042681, 40.61654601778303, 42.11403567450387, 46.41170494897025, 49.97486972808838, 48.371673652103965, 48.31717893055507, 47.994306564331055, 45.72534452165876, 47.94495350973946, 47.02989659990583, 46.329243728092735, 40.02497638974871, 33.704478059496196, 34.0188319342477, 33.191468238830566, 34.54595007215227, 36.79252849306379, 38.83245011738369, 38.38315527779715, 42.94081572123936, 47.55249146052769, 49.74119486127581, 48.25677476610456, 47.308727809361045, 43.6749450138637, 45.94880901064192, 36.34968158176967, 29.095578125544957, 50.12321029390608, 42.85779169627598, 46.65316874640328, 45.072578634534565, 47.23927709034511, 48.07475280761719, 47.43436861038208, 41.42959989820208, 38.887855052948, 38.025823320661274, 39.29223326274327, 41.411093371255056, 43.833075591496055, 43.3791949408395, 46.099842003413606, 42.699421405792236, 43.89191293716431, 45.65581389835903, 49.49971716744559, 49.630940846034456, 40.08760745184762, 5.153238747801099, 1.1472362854651041, 1.3048848318202155, 0.02204502260844622, 26.580561263220652, 48.849442209516255, 47.803387437547954, 48.88027136666434, 39.152018615177695, 49.299827916281565, 56.19149248940604, 44.22726426805769, 23.4100113936833, 14.279839600835528, 26.41764858790806, 37.15167045593262, 1.619974998491151, 0.053817753946142535, 0.0944262088409492, 0.014668605656230023, 0.04004595275702221, 0.026437970277454172, 0.1301711214972394, 0.015245082222723534, 0.022611100625778948, 0.015825173684528897, 0.04879444045946002, 0.034562460213367424, 0.05090568181393402, 0.042781683815909285, 0.0322746674397162, 0.040109884326479266, 0.016413931734859943, 0.02358030986839107, 0.06419716841940369, 0.049133463696177514, 0.0151678123511374, 0.015127827978825994, 0.04610830352508596, 0.03856816455455763, 0.13812710743929657, 0.08824833070061036, 0.016209830097588043, 16.65822274344308, 59.660359791346956, 34.68840203966413, 27.0891363961356, 44.04251166752407, 47.6122807094029, 61.81439862932478, 56.6383068220956, 57.26983206612723, 53.70056676864624, 58.41339438302176, 49.955039569309776, 56.596454347882954, 26.6835526738848, 0.24803758040070534, 1.5627136996814182, 0.7187917956284114, 1.9308813725199019, 43.29074437277657, 58.81723758152553, 56.79370675768171, 54.960566997528076, 49.92125047956194, 43.87632465362549, 47.73691054752895, 48.763096945626394, 51.44386829648699, 51.673388140542166, 51.43163251876831, 47.6640830039978, 46.54415498461042, 46.5102755682809, 47.044776167188374, 45.269497530800955, 45.846934522901265, 46.757009574345176, 49.41615118299212, 50.30303314753941, 50.08356039864676, 53.06870801108224, 53.286398547036306, 51.59023209980556, 48.51671382359096, 48.69662005560738, 49.4903301511492, 52.39673730305263, 51.24623720986502, 47.8892810685294, 42.80016681126186, 43.391052041734966, 38.43525634493147, 39.374684061322895, 37.01129599979946, 36.773295879364014, 37.64752517427717, 43.90333577564785, 51.278886795043945, 52.357309750148225, 51.05994210924421, 50.33531795229231, 48.73059327261788, 45.90291963304792, 38.88313375200544, 40.51014477866036, 39.41284009388515, 40.88301290784563, 41.43602698189871, 39.28847081320626, 38.58295767647879, 38.69829429898943, 35.93463441303798, 37.2712732723781, 36.52074275697981, 37.51096180507115, 36.29968581880842, 38.25275148664202, 35.06664112636021, 36.310493741716655, 36.03531033652169, 37.987285137176514, 41.70465823582241, 43.78117602212088, 37.545595100947786, 39.23212092263358, 38.915036405835835, 42.1063266481672, 49.300213541303364, 52.12115437643868, 50.40828793389456, 50.49440738133022, 48.63086230414254, 48.90086930138724, 49.26858881541661, 47.201409408024375, 48.05741357803345, 41.28799908501761, 35.1169148172651, 37.040405477796284, 35.15911817550659, 34.63645730699812, 38.30500888824463, 40.67949322291783, 40.31069326400757, 46.13334969111851, 48.411094256809776, 52.164830752781455, 50.155915464673726, 50.28015272957938, 44.87199108941214, 46.90724352427891, 38.12204892294747, 31.827842576163157, 51.05908400671822, 44.93801982062203, 47.156339917864116, 48.70811585017613, 49.5989339692252, 50.20610230309622, 49.84410115650722, 44.03970112119402, 42.320251260484966, 39.7867956161499, 40.72004985809326, 43.56578533990042, 47.19573967797415, 47.396143095833914, 47.14550767626081, 45.338656425476074, 45.28464807782854, 48.22149181365967, 52.56618997028896, 51.70491211754935, 45.79534067426409, 5.847705117293766, 1.9283630847930908, 1.9132190517016818, 0.04765786376914807, 32.050838061741416, 52.66846397944859, 53.0111734526498, 52.16338900157383, 44.33804634639195, 52.40697199957711, 62.90937219347273, 48.90387092317854, 37.977623667035786, 19.19590289252145, 27.979615790503367, 46.72940785544259, 2.6493570251124243, 0.12337012429322515, 0.07783017187778439, 0.05414642613115055, 0.059181742902312956, 0.01751838488105152, 0.07977137235658509, 0.07200753396110875, 0.05400786928034254, 0.009391130763106048, 0.017503964315567697, 0.05044224239619715, 0.12746634520590305, 0.09804795057113681, 0.132389686735613, 0.20001445444566862, 0.10324072478605167, 0.12075966436948095, 0.1262080291552203, 0.08265597399856363, 0.061450092255004814, 0.21796501693981035, 0.21041997894644737, 0.19162611956042902, 0.2758264121200357, 0.25475556563053814, 0.3857033247394221, 21.24886975969587, 69.57194423675537, 45.89859437942505, 35.18635858808245, 39.690893105098176, 56.38040706089565, 67.83154555729458, 63.60007177080427, 61.77850423540388, 61.341969762529644, 63.021849632263184, 54.91661269324166, 61.761349133082796, 30.275566373552593, 0.9291596902268273, 2.5648156872817447, 1.5181527308055331, 4.584692410060337, 50.009826115199495, 61.285717146737234, 58.83827672685896, 58.46517930712019, 52.887162004198345, 47.42973068782261, 49.07011004856655, 53.33865942273821, 55.3860434123448, 53.69535214560372, 54.766750471932546, 49.68738106318882, 48.33939232145037, 48.25802544185093, 48.790059430258616, 47.69424165998186, 47.65987239565168, 48.88226202556065, 51.29159157616751, 52.05357967104231, 51.444816725594656, 55.05115761075701, 56.237649372645784, 51.3968220438276, 49.08178997039795, 50.46879979542324, 53.721220288957866, 53.98394904817854, 54.8323449407305, 50.17483540943691, 44.807397161211284, 44.431985991341726, 40.21750055040632, 41.94034808022635, 38.3710480417524, 39.608869620731895, 40.31342043195452, 45.76723173686436, 52.75337444032942, 53.25488151822771, 53.28687102454049, 52.7103442464556, 49.859442778996055, 46.296632358006065, 38.53124918256487, 40.914279801504954, 41.46680750165667, 42.45636647088187, 42.10205698013306, 40.16861997331892, 41.28293037414551, 40.167150429316926, 38.115673950740266, 39.18616206305367, 40.101361410958425, 39.812538691929404, 38.36481550761631, 39.46187005724226, 38.071295806339805, 38.74976308005196, 39.17880392074585, 39.09761422021048, 44.91648735318865, 47.311764172145296, 38.35244424002511, 37.77416998999459, 39.35624006816319, 41.88917112350464, 49.155531202043804, 53.906605175563264, 50.65338911328997, 51.58463532584054, 50.66930743626186, 49.6731025150844, 52.42386654445103, 49.21112373897007, 50.38480997085571, 43.23081963402884, 37.4279898915972, 39.39760616847447, 36.39280210222517, 35.622146129608154, 42.30606998716082, 42.24355704443795, 41.69742863518851, 45.46808052062988, 51.052517959049766, 53.56420142310006, 50.87429666519165, 51.532728808266775, 45.64030204500471, 46.88106618608747, 39.44084480830601, 31.04291500364031, 52.24394294193813, 45.6187869480678, 49.67360625948225, 50.934085914066856, 50.952720982687815, 50.72657101494925, 52.12825543539864, 44.404217515672954, 45.15365021569388, 42.08778190612793, 41.96746342522757, 45.43120643070766, 49.72338662828718, 47.0943272454398, 51.0797757421221, 47.01555551801409, 48.344106674194336, 50.08623545510428, 54.700266633714946, 54.44885301589966, 48.279147965567454, 7.095130409513201, 4.131209978035518, 3.586965616260256, 0.11021630905036416, 34.95344107491629, 57.397668497903005, 58.13223900113787, 58.908425739833284, 48.60538673400879, 58.31389617919922, 64.95486627306256, 54.878783226013184, 36.006047998155864, 24.19274159840175, 35.525725977761404, 57.299962929316926, 4.665337979793549, 0.3003105068845408, 0.18697386634136948, 0.12647554837167263, 0.13937257203672612, 0.09450439643114805, 0.16325016506016254, 0.18657804972359113, 0.17119446662919863, 0.13303939758666924, 0.18159784695931844, 0.11522873544267245], [0.008643081528134644, 0.05535299710131117, 0.06117768758641822, 0.012142954128129142, 0.023710631000410234, 0.03175704700074025, 0.051289495147232494, 0.031608987266996076, 0.019765526621735523, 0.04488197700785739, 0.0651109650997179, 0.0357375776927386, 0.07971372402140073, 0.04228965432516166, 0.020367405842989683, 0.8193788038832801, 46.07115983963013, 49.53379808153425, 27.533029011317662, 26.66423668180193, 38.58504908425467, 54.550578117370605, 56.275662967136924, 53.40089096341814, 52.41081435339791, 50.68402372087751, 49.408845152173726, 49.74260881968907, 27.496649980545044, 0.18080010690859386, 1.1374910026788712, 0.7883340354476656, 0.6419072097965649, 31.357723985399517, 50.340331077575684, 49.84551164082119, 57.07096072605678, 52.02467169080462, 48.838276454380576, 37.91494744164603, 43.04078640256609, 42.11131545475551, 42.02910784312657, 41.9215532030378, 43.6842417035784, 43.189158235277446, 41.88168443952288, 44.04488795144217, 45.88007743018014, 47.4659412247794, 46.72958503450666, 49.43697493416922, 49.58459288733346, 51.92350244522095, 51.336699281420024, 51.509817123413086, 50.607621329171316, 48.41329336166382, 47.307425022125244, 48.41947725840977, 51.54486036300659, 48.62340341295515, 46.399879114968435, 42.24434913907732, 38.60936083112444, 37.310395104544504, 34.65090261186872, 35.40341336386544, 35.79769236700875, 37.2391482761928, 38.53151321411133, 43.66397728238787, 47.058821950639995, 47.68348584856306, 45.922277314322336, 40.75692047391619, 38.128159863608225, 40.73048952647618, 40.128191879817415, 39.66691834586007, 41.64697776521955, 38.55998345783779, 34.85810831614903, 32.96388346808297, 34.259548800332205, 36.054122584206716, 35.04170751571655, 35.81297492980957, 34.63398722239903, 34.171553339277, 34.308179242270334, 34.97973305838448, 34.04882035936628, 34.99980640411377, 33.61949464253017, 31.49375581741333, 35.40088421957833, 42.56796843664986, 42.92888913835798, 40.02763754980904, 42.24747582844326, 40.85292720794678, 43.907039165496826, 47.40312950951712, 47.198178495679585, 48.22036967958723, 47.417171818869456, 48.536599567958284, 47.65519973209926, 44.08677169254848, 40.568655558994834, 33.57414722442627, 35.85874966212681, 32.692896774836946, 34.105135508946006, 35.26723561968122, 38.99502754211426, 39.796272959027974, 47.60066679545811, 47.723365034375874, 48.000893456595286, 42.121418135506765, 42.94253887448992, 44.54183006286621, 44.74138580049787, 41.81604480743408, 38.001278809138704, 42.833441734313965, 42.35917159489223, 40.22559520176479, 37.95430203846523, 37.258009161267964, 38.153156008039204, 44.154012884412495, 46.427525997161865, 43.654625007084434, 41.983871596200125, 39.06637511934553, 38.43710803985596, 40.21034737995693, 42.518834250313894, 40.189488887786865, 40.91443961007254, 45.59517696925572, 46.67837333679199, 50.71759046827044, 37.7859992980957, 38.05048247746059, 6.2724272183009555, 0.739796308534486, 0.4610254615545273, 0.171773012727499, 30.447412695203507, 47.69661446980068, 48.16260930470058, 47.53537457329886, 54.09659324373518, 48.59803901399885, 52.486469813755576, 31.60058437074934, 20.38842569078718, 23.724141189030238, 43.810017994471956, 19.704721212387085, 0.3111432098916599, 0.04301676566579512, 0.06219213815139873, 0.0424870299840612, 0.07960174538727317, 0.030835582874715328, 0.07736053743532725, 0.05760670706097569, 0.04958614833386881, 0.02920922264456749, 0.015876616816967726, 0.04750565818643995, 0.006324365793261677, 0.014672420719372374, 0.029288149837936674, 0.014822049565347177, 0.008243368423011686, 0.0823836371834789, 0.03821530598880989, 0.03629576095512935, 0.03793217368157847, 0.03507789237690823, 0.0092114148262356, 0.028567789920738766, 0.051155681256204844, 0.00814863051553922, 0.04001330165192485, 2.2684381050722937, 56.868285247257774, 51.57293455941336, 24.75643331663949, 36.41574157987322, 44.72896589551653, 59.810246331351145, 63.371615001133506, 59.17072718484061, 57.172293254307334, 56.3055089541844, 55.41566358293806, 53.608301639556885, 31.094567911965505, 0.18596956666026795, 0.7209582765187535, 1.186039803283555, 0.7327610403299332, 39.751630783081055, 56.418938296181814, 53.93530123574393, 58.89709322793143, 55.38890607016427, 50.22561631883894, 40.86984607151577, 44.38772249221802, 45.21001747676304, 45.73406798498971, 43.81326975141253, 44.14057854243687, 45.01514482498169, 44.661773341042654, 45.57553441183907, 47.951696736471995, 49.07718331473214, 47.873428753444124, 49.81052051271711, 51.2431070463998, 52.18215261186872, 53.214040006910054, 52.740853786468506, 52.10721976416451, 49.83918878010341, 49.63431767054966, 49.9460312298366, 53.855188505990164, 51.72177539552961, 49.90800721304757, 44.968310492379324, 41.44479213442121, 38.31709180559431, 38.34841081074306, 38.918267318180625, 36.88224710736956, 39.12259299414498, 39.51864726202828, 46.35522304262434, 49.35942608969552, 50.64084414073399, 48.736401966639924, 43.45973151070731, 37.244793687547954, 38.834075995853965, 41.29032325744629, 39.97606801986694, 42.303582532065256, 40.47971861703055, 38.04003586087908, 37.341060979025706, 37.16270419529506, 39.637023721422466, 38.2325565474374, 37.93536124910627, 37.079978942871094, 36.21465029035296, 36.8905918938773, 37.35978984832764, 36.56314066478184, 37.569305828639436, 35.6400203704834, 35.69833312715803, 39.504236698150635, 43.13711622783116, 41.51692485809326, 40.40613719395229, 40.108222757067, 40.693212441035676, 45.265245233263286, 47.93126208441598, 47.92755174636841, 51.01226704461234, 49.793945584978374, 48.150231088910786, 50.59479495457241, 47.16829776763916, 40.21987336022513, 35.53859404155186, 36.67207452229091, 33.10586643218994, 35.71558550425938, 36.86374058042254, 39.517327104296, 39.619177273341585, 49.150559765951975, 50.741693769182476, 49.26753616333008, 44.35515628542219, 43.46315349851336, 44.93171433040074, 45.41401311329433, 41.854833126068115, 37.84068162100655, 43.53687735966274, 43.05442224230085, 40.31511926651001, 39.48698084694998, 38.419716698782786, 41.14928872244698, 47.84669555936541, 48.98237861905779, 45.61571931838989, 42.0758900642395, 42.12651811327253, 39.594146387917654, 42.13555424554007, 43.61337007795061, 44.13529791150774, 42.30922099522182, 48.55756228310721, 48.82953214645386, 55.398741245269775, 41.35437522615705, 39.938544273376465, 7.693533590861729, 0.7300787642598152, 1.059632963367871, 0.4218545848769801, 34.314988476889475, 52.8404666355678, 54.13575676509312, 50.34289148875645, 57.24858794893537, 54.62768227713448, 58.86338056836809, 36.140464373997276, 31.05172531945365, 17.13172858101981, 49.25457429885864, 24.104977164949688, 0.4276452027261257, 0.03894184396735259, 0.04848206329292484, 0.03429618950134941, 0.07042806050074951, 0.03067246644890734, 0.07382157697741475, 0.025191979815385172, 0.032899435343486924, 0.035496422954435856, 0.06542800380183117, 0.04164889674367649, 0.1329877067889486, 0.12135663947888783, 0.10266612776155983, 0.11883656041962759, 0.16248803452721663, 0.21401560386376722, 0.11111460799085242, 0.12533217615314893, 0.12056100288672106, 0.25621821571673664, 0.11248151000056948, 0.14972232095897198, 0.1309925831322159, 0.17571292631328106, 0.1832378525286913, 3.2308539365019118, 69.36737537384033, 60.56692600250244, 38.33126960481916, 37.14528506142752, 51.70186185836792, 65.73324516841343, 67.46363844190324, 63.59073339189802, 63.58823204040527, 60.61988517216274, 60.35325499943325, 58.89881638118199, 34.97589070456368, 0.8157102635928563, 2.152541935443878, 2.707869976758957, 2.101141116448811, 45.78393520627703, 58.32121958051409, 59.11835166386196, 61.61397784096854, 57.48301669529506, 52.50964553015572, 43.7462717464992, 46.15052563803536, 47.87503726141793, 47.329617568424766, 46.245201792035786, 48.31451082229614, 47.14616428102766, 46.41918468475342, 47.34911073957171, 50.45477485656738, 52.64150149481637, 49.81403630120413, 52.63680451256888, 52.95724500928606, 54.38165351322719, 54.57015814099993, 55.06184046609061, 52.3699381010873, 50.50803279876709, 49.53322485515049, 52.602431774139404, 55.93801525660923, 54.18557187489101, 52.025203227996826, 47.34490360532488, 43.23105239868164, 41.1422050339835, 38.35882616043091, 39.6124792098999, 39.69000720977783, 41.096777711595806, 43.65340212413243, 49.16912535258702, 50.48366894040789, 50.383663518088206, 48.710016182490754, 41.53694609233311, 38.66568292890276, 40.34696633475167, 40.119968686785015, 41.11780296053205, 44.61807612010411, 42.086364473615376, 39.309836523873464, 39.288783482142854, 40.01721525192261, 42.09336130959647, 39.445437567574636, 40.37828881399972, 38.39848647798811, 37.84321771349226, 38.495615346091135, 38.344554560525076, 37.94736426217215, 40.54207522528512, 37.72926378250122, 35.08290685926165, 42.42128849029541, 46.468652384621755, 41.61345965521676, 39.02371665409633, 40.29947887148176, 40.264109066554475, 45.85287523269653, 49.66868346078055, 50.08962965011597, 52.65294170379639, 51.198760168892996, 51.454377446855815, 50.74941669191633, 48.47893646785191, 43.50329671587263, 37.65779461179461, 39.596008505140034, 34.732453618730815, 36.87469094140189, 39.37166506903512, 42.24981737136841, 43.72145625523159, 50.01836545126778, 52.04376881463187, 51.115889004298616, 47.68892281396048, 45.00673055648804, 47.04486649377005, 48.112960951668875, 43.01931994301932, 34.57581342969622, 45.752942766462056, 43.67568499701363, 40.50587511062622, 39.34464699881417, 42.35336290087019, 46.29182767868042, 49.4081711769104, 49.87460027422224, 48.67506674357823, 45.27192940030779, 44.83263996669224, 41.69898850577218, 43.90838016782488, 46.046702180589946, 45.27240882601057, 43.572580678122385, 51.55383743558611, 52.20603009632656, 57.67308119365147, 44.24558319364275, 46.25384187698364, 9.10037010056632, 1.998780471937997, 3.2997027678149085, 0.8729748193706784, 39.54488365990775, 57.098041330065044, 59.46005712236677, 56.71857588631766, 62.97099576677595, 58.48904636928013, 62.65901470184326, 40.42084305627005, 31.030491624559673, 33.5339241027832, 57.81802756445748, 34.55558027539934, 0.31560251489281654, 0.16707189141639642, 0.18963122660560267, 0.16380022625838006, 0.21319898696882383, 0.10103244613856077, 0.2325871480362756, 0.2239041661045381, 0.12875564316553728, 0.12073191228721823, 0.17448932411415236, 0.11016312547560249], [0.0335897361593587, 0.013456984689193112, 0.03962895906131182, 0.014894121858690466, 0.04723755882254668, 0.004865111774831478, 0.0373002981234874, 0.05693761046443667, 0.019294753936784606, 0.034638995570795875, 0.06268338393419981, 0.015313794071386968, 0.14971738122403622, 0.0074102325930393165, 0.11510943541569368, 0.02206748042122594, 18.163437059947423, 51.22577823911394, 42.14770317077637, 35.07380819320679, 34.54081187929426, 49.42176880155291, 55.0086589540754, 55.275118895939414, 52.12776558739798, 52.91992276055472, 46.6468563079834, 50.75219597135271, 23.399338960647583, 0.2038467252360923, 1.3595969017062868, 0.08490374338413988, 0.5654165542551449, 30.326197896684917, 56.434648173195974, 51.266581535339355, 52.50479916163853, 53.984202657427105, 54.16286168779646, 47.98826857975551, 40.775121280125205, 41.431475911821636, 41.20505149023873, 41.38853257043021, 41.90809454236712, 43.50409228461129, 45.24723897661482, 47.023500783102854, 47.656940255846294, 51.39841318130493, 50.51037434169224, 53.1725731577192, 51.47238370350429, 50.86209562846592, 53.13267660140991, 52.902555738176616, 50.72847134726388, 51.34772259848458, 48.83563961301531, 50.36824199131557, 51.69332252229963, 51.664136614118306, 49.41043628965105, 44.92748635155814, 40.1882312638419, 38.7136880329677, 34.905887603759766, 34.95662334987095, 34.64578526360648, 39.176577023097444, 36.76881776537214, 42.794476236615864, 46.77937929970877, 47.42157350267683, 43.644473688943044, 40.53618662697928, 39.24170248849051, 39.17652491160801, 41.4579450743539, 42.30304404667446, 37.560891560145784, 33.257059233529226, 33.991445609501426, 34.63972643443516, 33.08218697139195, 34.14139815739223, 33.91316720417568, 34.993653774261475, 35.21293197359358, 33.28124591282436, 34.779385226113455, 34.869433879852295, 33.38216849735805, 34.04773644038609, 32.281143052237375, 34.15086507797241, 31.992692061832972, 32.10168150493077, 39.3180319241115, 42.748503480638774, 38.866635254451204, 39.969373430524556, 41.01583814620972, 44.03886733736311, 45.301945618220735, 47.6658478464399, 45.06785038539341, 46.013986587524414, 43.875028814588276, 40.414193630218506, 36.23302827562605, 34.67262962886265, 35.14243902478899, 33.33552871431623, 34.08038255146572, 34.68472644260952, 35.571955817086355, 37.82544422149658, 45.030858176095144, 48.30832692555019, 44.713697229112896, 42.85855252402169, 50.34404836382185, 46.572875363486155, 47.18670701980591, 50.092002459934776, 48.86411680494036, 43.45482955660139, 44.2446278163365, 44.698348658425466, 45.4513839994158, 47.16335759844099, 50.50215114865984, 49.263304710388184, 46.29121623720442, 44.469509737832205, 41.12768677302769, 40.62592608588082, 38.24333667755127, 40.41611133302961, 40.422399452754426, 41.131636823926655, 41.568994658333914, 49.379259722573416, 48.422909668513704, 51.236610480717246, 39.37134197780064, 25.57780245372227, 7.100153522832053, 0.8569514048951012, 0.3167584128677845, 0.838223186986787, 35.869307449885774, 49.52022130148751, 45.724093845912385, 50.382103647504536, 44.91026871544974, 47.069796630314414, 47.08427667617798, 23.036029815673828, 27.041049650737218, 32.75751154763358, 40.500604901994976, 3.055966692311423, 0.21101219074002334, 0.030184816901705096, 0.026390547465000833, 0.10207458771765232, 0.002692281281010115, 0.04721583891659975, 0.03480278035359723, 0.06761250658226864, 0.014899565405877573, 0.058046608098915646, 0.06653563758092267, 0.044380376780671735, 0.02449651195534638, 0.03686566251729216, 0.013291607045435479, 0.03888752384643469, 0.08541307891053812, 0.03249788849747606, 0.055684023802833896, 0.010452198380205249, 0.014700741074713213, 0.026669159032670513, 0.0874090643067445, 0.02936347061768174, 0.1751992753041642, 0.012132352866631533, 0.04043973716241973, 0.032333021451319964, 25.580569573811122, 61.751830101013184, 36.99112885338919, 36.23676988056728, 46.05071129117693, 51.557690211704795, 61.29456915174212, 58.87474087306431, 56.724721567971365, 57.54769400187901, 52.38486630575997, 54.36949069159371, 27.57170442172459, 0.312378360756806, 0.41071583543504986, 0.3615393899381161, 0.6724580047386033, 37.62925141198294, 58.86067771911621, 57.53354746954781, 56.86794825962612, 56.730175903865266, 57.3925268309457, 50.89027404785156, 43.87881905691964, 43.58974967684065, 43.07074008669172, 42.954163210732595, 45.07829005377633, 45.599067960466655, 47.74996968678066, 48.117550236838206, 49.51051466805594, 53.55102069037301, 52.811245986393516, 54.507600034986226, 54.22726106643677, 52.98449237006051, 53.52998154503958, 54.556518827165874, 53.330352851322715, 52.323652676173616, 49.53938095910208, 51.21375090735299, 53.63414546421596, 54.84300347736904, 50.79200220108032, 48.37012072971889, 42.80433920451573, 39.688148566654746, 37.485962186540874, 36.76207453863961, 38.50705208097185, 39.93739087241036, 40.479114123753135, 43.73676661082676, 47.54711702891758, 48.093245438167024, 45.396017278943745, 38.536147662571494, 40.798925808497835, 41.067286082676475, 40.899257796151296, 41.74064295632498, 39.96093136923653, 37.58496706826346, 35.6237268447876, 36.331897667476106, 36.29253959655762, 36.37755080631801, 36.06126880645752, 37.69580473218645, 37.876305035182405, 35.64449501037598, 37.318371636526926, 37.90088776179722, 37.117985589163645, 35.760901655469624, 34.63682903562273, 36.320638111659456, 34.28544473648071, 36.597051348005024, 41.76018476486206, 42.520456654684885, 39.18265322276524, 39.61483812332153, 40.326041834695, 44.691108635493684, 47.720078536442344, 50.06673880985805, 47.707568304879324, 47.662318161555696, 44.92074312482561, 42.28592715944563, 37.76895189285278, 37.65462623323713, 34.56336920601981, 34.33777509416853, 36.72621488571167, 37.99910749707903, 38.03019026347569, 39.90878166471209, 46.826838970184326, 49.98012604032244, 45.664738859449116, 44.57210683822632, 51.06132480076381, 46.688924176352366, 47.06297697339739, 51.73897566114153, 49.22410644803728, 44.874808583940776, 46.55527557645525, 45.54445859364101, 45.43071658270699, 47.42022902624947, 49.6374443599156, 51.46739837101528, 48.5298250743321, 46.10590778078352, 43.16615969794137, 42.50445147923061, 40.52539260046822, 43.89359092712402, 41.87043183190482, 44.034799167088096, 43.9170480455671, 50.604661396571565, 53.2306809425354, 52.999083587101524, 45.864058358328684, 31.88658959524972, 7.910956621170044, 0.6703579117144857, 0.09093524116490569, 1.4587552951914924, 40.92916979108538, 55.48778935841152, 48.67863116945539, 57.8230858530317, 51.56790058953421, 53.71459518160139, 49.65219191142491, 31.474922725132533, 31.59119735445295, 29.841821602412633, 50.324510029384065, 3.7019155280930653, 0.12726570240088872, 0.0337338196778936, 0.048179250077477524, 0.0928241265937686, 0.06901096725570303, 0.047812298339392455, 0.021497134418625916, 0.06488362872706992, 0.026209795914058174, 0.03165991810549583, 0.049950820194291215, 0.08374999636518103, 0.11351567879319191, 0.11856454930135182, 0.13683478321347917, 0.1723354504044567, 0.16195356606372766, 0.057262852654925415, 0.27102458264146534, 0.18287360135998043, 0.10630874122892107, 0.1518668308854103, 0.13348181598952838, 0.1905781357948269, 0.27701449979628834, 0.10975046083331108, 0.2922812934432711, 0.0915865126465048, 29.785291058676584, 68.7782723563058, 52.56444249834333, 47.61500440325056, 48.97490930557251, 60.53532559531075, 65.36292007991246, 66.69916984013149, 63.27561868940081, 63.655059814453125, 56.57209743772234, 60.775469235011506, 31.55758544376918, 1.0646097191742487, 5.9880765335900445, 1.7715424597263336, 1.7143947205373218, 44.16106183188302, 60.58303887503487, 60.04564435141427, 59.85142135620117, 60.46710123334612, 57.179564544132774, 54.47955363137381, 45.201710905347554, 46.757395199366975, 43.74751547404698, 45.44677039555141, 44.78005599975586, 47.72976432527815, 50.88997874941145, 50.58900710514614, 50.45449692862374, 55.58392810821533, 55.45134258270264, 57.68082843508039, 53.740074225834434, 56.72072982788086, 54.962418692452566, 57.89055980954851, 54.76091398511614, 54.59476171221052, 52.25443124771118, 52.384963580540244, 55.61348227092198, 57.281449454171316, 53.89375100816999, 49.87114701952253, 44.59419863564627, 41.97180952344622, 40.293034417288645, 38.45873430797032, 40.32966184616089, 43.235377652304514, 42.54414306368147, 45.29732854025704, 50.65326751981463, 49.70239612034389, 44.875708375658306, 39.122030190059114, 39.94368941443307, 40.506153038569856, 42.40517561776297, 43.254165581294465, 42.16103328977312, 38.62208645684378, 39.57606022698538, 39.640470027923584, 37.603692463466096, 38.58287082399641, 39.111802441733225, 39.8571982383728, 42.154081617082866, 38.62286465508597, 39.96878283364432, 39.66199902125767, 38.465953486306326, 38.57607201167515, 36.1012522152492, 39.34409809112549, 36.82875987461635, 39.45590155465262, 43.42499051775251, 45.263640199388774, 37.951227460588726, 38.60836723872593, 39.05668933050973, 43.58333996364048, 47.36095394407, 52.55383259909493, 47.856513363974436, 48.48529406956264, 47.50512211663382, 42.72761719567435, 39.67731632505144, 41.20580884388515, 38.96706451688494, 36.72905322483608, 38.65439905439104, 39.047958918980186, 40.364910057612825, 40.822963101523264, 49.89010170527867, 53.03136144365583, 47.10282836641584, 44.60180343900408, 52.61185005732945, 49.23273958478655, 48.67590747560774, 54.001371656145366, 51.95616592679705, 45.01777471814837, 47.105694498334614, 47.25836031777518, 47.888711316244944, 48.25089659009661, 52.471986293792725, 56.43629142216274, 50.51439734867641, 48.486221654074534, 45.87135396684919, 43.793658460889546, 42.049146447862896, 44.44090747833252, 44.28646639415196, 46.17223181043352, 46.0183813231332, 54.556682109832764, 55.86674410956246, 57.0160664830889, 45.70703949247088, 33.88915422984532, 11.354974559375218, 1.5045895214591707, 0.3996351957321167, 1.7129230052232742, 45.4985796383449, 58.383746419634136, 55.32150159563337, 59.72249058314732, 58.487566402980256, 57.01048360552107, 58.155911513737266, 33.40993697302682, 39.60635437284197, 43.154427664620535, 58.26754127229963, 7.413187674113682, 0.5277614976678575, 0.26035128108092714, 0.16898265959961073, 0.20544315528656754, 0.09230174283896174, 0.17926336079835892, 0.16199932646538528, 0.16061579356236116, 0.12910367734730244, 0.1075285639879959, 0.1635787117161921, 0.13811949427638734], [0.03284317800509078, 0.030578720050730875, 0.053500002782259665, 0.052604774212730784, 0.03471991765711989, 0.044654101199869595, 0.007652941176534763, 0.03705360993210759, 0.04574069021535771, 0.03067641891539097, 0.012295761062497539, 0.0164432970341295, 0.005623462019554738, 0.03241477474304182, 0.020348990402583565, 0.052876968535461595, 0.9933981746435165, 43.15628283364432, 44.50674860818045, 28.961008889334543, 28.96838092803955, 45.181439535958425, 57.322756494794575, 56.11867536817278, 53.73512710843767, 51.1411144392831, 53.4671767779759, 48.36400631495884, 35.933168343135286, 0.13135097175836563, 0.49924109663282124, 0.2175480436001505, 0.41200065506356104, 37.51292814527239, 52.17129257747105, 55.045227323259624, 58.677266120910645, 51.222477844783235, 55.69837883540562, 52.848797525678364, 43.37859044756208, 38.98304189954485, 42.34961782182966, 43.05164296286446, 43.67103665215628, 42.89064277921404, 48.182401248386924, 48.79919283730643, 50.37305014474051, 53.51011664526803, 53.46930987494332, 54.72021838596889, 53.36213043757847, 55.94193056651524, 52.03769956316267, 51.20976611546108, 53.45494794845581, 50.747884614127024, 52.58528709411621, 49.78689316340855, 51.86092349461147, 51.247988155909944, 49.11931024278913, 45.36210312162127, 39.82785946982247, 37.27426099777222, 36.45647192001343, 34.43614074162075, 34.300744669778005, 39.36954934256417, 39.23587989807129, 42.79949631009783, 45.66409615107945, 47.52853754588536, 39.532470703125, 39.0281982421875, 39.89974900654384, 43.314458574567524, 41.63768802370344, 37.33676699229649, 33.529397351401194, 34.45695754459926, 33.93436615807669, 33.26363222939627, 34.94596481323242, 34.98725100925991, 35.48741013663155, 35.228433404650005, 34.61588021687099, 34.28365210124424, 35.832454204559326, 36.127815178462434, 34.84727954864502, 35.394672530038015, 34.0623311315264, 35.13868004935128, 35.58375038419451, 33.393876211983816, 28.45699177469526, 36.412854603358674, 44.46621629170009, 40.07073722566877, 41.18198694501604, 41.49647978373936, 41.51996122087751, 47.075587953839985, 45.681484018053325, 45.173661027635845, 42.503398827144075, 39.15517309733799, 36.02599280221121, 36.200027806418284, 33.48799303599766, 34.13003437859671, 31.720093386513845, 35.040595803942, 36.04546512876238, 38.577868121010916, 42.55807420185634, 44.78650740214756, 47.73299176352364, 50.42243446622576, 44.66661623546055, 45.306996958596365, 46.98091874803816, 44.33153588431222, 42.83641903741019, 46.973737784794395, 44.93229103088379, 45.60247605187552, 47.61256211144583, 50.493115016392295, 52.51578426361084, 53.56639010565621, 46.972358567374094, 43.88286638259888, 41.715803146362305, 38.775276865277974, 40.48200804846627, 41.45861210141863, 40.44261176245553, 42.512299469539094, 43.50217458180019, 49.81588452202933, 48.618949617658345, 49.58597557885306, 45.361946787152974, 41.74392598015921, 7.594919545309884, 0.3908369849835123, 0.07059642539492675, 1.1375577705247062, 39.3696084022522, 46.666412012917654, 45.64421040671212, 47.82992260796683, 36.73981598445347, 55.20072453362601, 38.843886852264404, 28.072923149381364, 32.97118602480207, 38.092880385262625, 27.33622302327837, 0.1372678242623806, 0.026310410782960907, 0.11121470547680344, 0.0202763294801116, 0.024786202303533043, 0.05877817062927144, 0.019846910111872212, 0.015022934946630682, 0.044778676836618354, 0.01607549373459603, 0.026140405530376092, 0.08701107637690646, 0.03675301891884633, 0.06088042139474835, 0.033388879615813494, 0.07406164945236274, 0.010892357261452292, 0.045274095609784126, 0.018403079194415892, 0.015018946857058575, 0.039106256395046196, 0.05702903627284935, 0.08978211161281381, 0.03163018130830356, 0.054823417482631545, 0.03810211277699896, 0.08367957121559552, 0.042837262619286776, 0.09902375856680529, 2.22930737052645, 55.84545482907976, 42.74698877334595, 28.709729024342128, 48.09462118148804, 49.04998459134783, 65.2205445425851, 59.889643396650044, 61.16529791695731, 54.183636801583425, 58.20872477122715, 52.7088052204677, 42.487098353249685, 0.031120211351662874, 0.5533493246350969, 0.5929984599351883, 0.472814111837319, 47.42215020315987, 56.61498866762434, 57.20748240607125, 62.06169196537563, 55.07810967309134, 57.32264879771641, 55.28385625566755, 47.08962331499372, 42.07092557634626, 43.47983264923096, 43.75900779451643, 45.36246790204729, 45.986006191798616, 48.92775535583496, 51.26604652404785, 52.63197551454817, 55.92216641562325, 56.45532948630196, 56.18289756774902, 54.499887534550254, 57.4376345361982, 53.60691894803728, 54.03498009272984, 55.00112363270351, 54.17065756661551, 53.56715440750122, 52.64022650037493, 53.911194460732595, 54.011540344783235, 51.0900764465332, 47.93084519250052, 43.0229503767831, 38.95961257389614, 38.981287479400635, 36.4641774722508, 37.24705185209002, 41.59428262710571, 41.61134740284511, 44.24619810921805, 46.971371923174175, 48.25869246891567, 40.149158069065635, 39.72491495949881, 38.93363673346383, 43.8209787777492, 42.51379680633545, 40.407759598323274, 35.73082290376936, 36.711658409663606, 36.242536885397776, 36.63738911492484, 37.48054953983852, 37.413502897535054, 38.57416820526123, 36.70578718185425, 37.406033584049766, 37.59466675349644, 37.04768718991961, 36.05556780951363, 36.98149865014212, 37.482609680720735, 35.47918346949986, 35.76463631221226, 36.85824802943638, 35.40992382594517, 32.365428175245015, 41.408425262996126, 44.007204396384104, 40.374387400490896, 40.5497773034232, 40.608951636723106, 42.19966527393886, 48.42085994992937, 47.92185769762312, 44.506786823272705, 44.658431257520405, 38.92058106831142, 38.593133313315256, 36.21375397273472, 34.95280531474522, 34.44651092801775, 34.06775767462594, 37.68481615611485, 36.32154485157558, 39.907117571149556, 43.68553406851632, 45.99502495356968, 47.6618526322501, 51.55818353380476, 45.71668011801583, 49.299664633614675, 46.66554001399449, 46.85686561039516, 45.18420491899763, 48.62284408296858, 46.76566008159092, 48.133833340236116, 49.93738767078945, 51.05374084200178, 51.61942148208618, 54.775453090667725, 48.727595124925884, 47.598596232278005, 44.45574535642351, 41.32193061283657, 40.9900985445295, 43.56562205723354, 41.41404635565621, 44.762473583221436, 44.31254645756313, 53.59766394751412, 50.45581708635603, 53.95751462663923, 48.79825483049665, 50.40205887385777, 10.626972709383283, 0.4606346796665873, 0.26097284629940987, 1.41316762140819, 42.05394070489066, 51.02101135253906, 51.063245977674214, 53.20967306409563, 40.36815486635481, 59.70294530051095, 43.32353639602661, 34.07883310317993, 30.616219179970876, 40.70625768389021, 34.07270131792341, 0.16396638591374668, 0.04122959263622761, 0.06424541904457978, 0.051920804128582985, 0.01153176964726299, 0.043944150009857755, 0.03426096335585628, 0.023052784514480403, 0.025168765436059663, 0.06170570318187986, 0.04475604769374643, 0.07630272848265511, 0.03889441776222416, 0.16973328217864037, 0.22558317386678287, 0.233340891876391, 0.1352323413427387, 0.06387003990156309, 0.13503259420394897, 0.12731307771589073, 0.14643407240509987, 0.1477927980678422, 0.2825202415032046, 0.07284960270460163, 0.15217796633286135, 0.2162493954279593, 0.18157514317759446, 0.21053299573915346, 0.23105224754129136, 3.80742392369679, 66.27309935433524, 55.45651551655361, 39.8732659476144, 42.10069513320923, 56.142038685934885, 67.33522878374372, 66.36815765925816, 65.87818459102085, 60.83612700871059, 65.44077464512416, 55.994716031210764, 47.143193926130024, 0.2448548169008323, 1.2473851229463304, 1.7590969332626887, 1.2077342505965913, 54.11993571690151, 56.79397078922817, 62.395337513514924, 63.87053040095738, 57.68616812569754, 58.31710624694824, 58.057083811078755, 48.46192380360195, 44.44535085133144, 45.65458059310913, 46.074012075151714, 47.721384797777446, 48.09685502733503, 53.29102952139718, 53.647711821964805, 54.35939148494175, 58.845641817365376, 59.178127016339985, 58.71398040226528, 55.408687591552734, 57.66736282621111, 53.20448275974819, 56.12341056551252, 56.720347676958355, 55.7990061214992, 54.47769498825073, 55.455310004098074, 56.479127066476, 56.37231935773577, 53.35939632143293, 50.015968322753906, 45.97155393872942, 40.61888756070818, 39.91078274590628, 37.367370332990376, 40.16092831747872, 44.224019459315706, 44.42245306287493, 47.009857995169504, 51.32865326745169, 50.43776566641671, 41.44325310843331, 39.806528500148225, 39.152630056653706, 44.28750514984131, 44.08517708097185, 42.540828772953574, 37.950643811907085, 40.20854779652187, 38.72591686248779, 39.84400360924857, 40.166069984436035, 39.179898262023926, 40.67224972588675, 38.404375076293945, 37.74374730246407, 39.89536121913365, 40.091533184051514, 39.68146092551095, 39.88150998524257, 41.297486850193565, 37.755746841430664, 39.01043169839041, 38.9364264351981, 37.95369407108852, 33.49159567696707, 42.25754724230085, 49.1902756690979, 40.40037018912179, 41.78066110610962, 41.39584902354649, 41.576609883989605, 49.75919416972569, 49.710098198481965, 47.009145804813926, 46.11871331078665, 43.635573046548025, 39.06103890282767, 38.58542776107788, 37.196062496730256, 37.10784469332014, 34.68150247846331, 40.43906470707485, 37.951338631766184, 43.709988253457205, 47.42644418988909, 48.003182888031006, 50.08026695251465, 52.63259390422276, 48.825457027980256, 51.49348538262503, 49.74785818372454, 47.35215752465384, 47.31813219615391, 50.17875419344221, 48.547758374895366, 48.28861141204834, 52.02080154418945, 53.57559299468994, 52.529173442295615, 56.63367584773472, 50.386578287397114, 49.79596056256975, 45.64994961874825, 43.68375880377633, 43.19714171545846, 44.11109038761684, 42.95566054752895, 46.76612908499581, 48.09275559016636, 56.15242624282837, 54.55564682824271, 55.649692807878765, 52.32513264247349, 49.13371385846819, 12.887587359973363, 1.440020997609411, 0.7202116708670343, 1.8471314779349735, 46.090316023145405, 55.99465697152274, 56.54955400739397, 59.20532921382359, 48.36813007082258, 62.670680727277485, 51.42368030548096, 40.379515171051025, 46.69129351207188, 51.38049030303955, 45.05139010293143, 0.21697996051183768, 0.1771466436662844, 0.2663259176271302, 0.1285447951938425, 0.17661761705364498, 0.09897370982382979, 0.10479521458702427, 0.18673442490398884, 0.1158844174018928, 0.20433399480368408, 0.13724524261695997, 0.31362762515033993, 0.11625681099082742], [0.050901692028024366, 0.02048245145540152, 0.07832154658223901, 0.02849192970565387, 0.02444098743477038, 0.05921082491321223, 0.05856897149767194, 0.030900393147021532, 0.02459311328961381, 0.02852646035275289, 0.05746582283505371, 0.046366876257317405, 0.029116975808782235, 0.03995703413550343, 0.055614172015339136, 0.054459424157227786, 0.06464453334254877, 13.630801422255379, 62.88474082946777, 29.452152729034424, 23.58087280818394, 40.98225055422102, 46.930777072906494, 58.90990570613316, 50.697103704724995, 49.328065395355225, 50.01923745019095, 44.77614068984985, 39.266274792807444, 0.69968017829316, 0.32082351616450716, 0.06335096061229706, 1.0520227317299162, 49.25877448490688, 53.45025444030762, 55.22873272214617, 56.45770924431937, 58.35469600132534, 49.48083891187395, 57.3723909514291, 44.981484276907786, 42.089578015463694, 40.146962438310894, 45.272155216761995, 42.93379456656319, 45.84361675807408, 47.689322335379465, 51.84477240698678, 50.690113816942485, 54.49400241034371, 52.265280859810964, 50.630182129996165, 47.51912273679461, 48.757694721221924, 53.73056214196341, 54.80737311499459, 50.655883516584126, 50.466902937207905, 50.524645941598074, 52.75782823562622, 51.13997493471418, 52.49430390766689, 50.545330728803364, 41.878998960767476, 37.75601782117571, 37.53424869264875, 37.66349908283779, 36.61539111818586, 36.24947813579014, 38.97797318867275, 40.321494238717214, 43.750051566532676, 45.59341907501221, 50.887831756046836, 43.1987259047372, 43.73360865456717, 45.10401228496006, 40.303599153246196, 34.75647701535906, 34.33813987459455, 33.19152729851859, 33.719441005161826, 33.07445362636021, 34.40518651689802, 33.479318210056846, 35.46917806352888, 34.36489043916975, 33.850435393197195, 33.26466751098633, 31.83239712033953, 34.18746471405029, 34.13490506580898, 34.109919343675884, 34.186085496629985, 34.68060963494437, 35.60585260391235, 33.95699644088745, 32.9059111731393, 36.22048330307007, 32.384396757398335, 33.399003982543945, 40.459561892918174, 41.30677311761038, 40.061409269060405, 38.88965463638306, 42.91544437408447, 50.93529837472098, 46.24227660042899, 42.992055211748394, 39.10258218220302, 36.361688068934846, 35.10685729980469, 34.54404279163906, 33.51621661867414, 33.90235580716814, 34.964370591299875, 34.16864551816668, 36.77280603136335, 38.96860701697213, 42.40460239137922, 44.89355134963989, 47.60273041043963, 47.23258250100272, 45.33972992215838, 46.470590932028635, 47.93126903261457, 50.11336122240339, 47.27682168143136, 49.9407297543117, 48.64595379148211, 48.27968645095825, 44.72776733125959, 43.007577487400596, 44.69908169337681, 46.92290128980364, 41.407834666115896, 40.02230133329119, 38.83622298921858, 39.2905969619751, 38.109121799468994, 39.93192958831787, 39.76243870598929, 44.349979877471924, 48.896425928388325, 48.49332966123308, 53.89424433026995, 45.72828360966274, 49.67451647349766, 19.3116511957986, 0.2796594021575791, 0.18057137275380747, 0.883545635002, 31.331570965903147, 52.53515584128243, 42.965155260903494, 49.29331398010254, 51.307645389011924, 56.146436895642964, 25.54118197304862, 40.5480124609811, 43.96446255275181, 39.388257367270334, 9.119492411613464, 0.22830187369670185, 0.032099839499486346, 0.09364794274525982, 0.021312026672863534, 0.09214007508541856, 0.04894429152565343, 0.09441981704107352, 0.022421955596655607, 0.1257300419466836, 0.04705969783078347, 0.03258706496230193, 0.00891233524972839, 0.009005142725072801, 0.048500142858496735, 0.03771960562361138, 0.06182152232421296, 0.030473394452461174, 0.04881988212998424, 0.06349297799170017, 0.07061195706150361, 0.07041633541562728, 0.033704646064766815, 0.0072455920079456905, 0.02491790086164006, 0.008503101450125021, 0.03935931942292622, 0.03225577023944684, 0.048222635606569905, 0.04679689782538584, 0.05889500757413251, 19.454593011311122, 69.9891835621425, 24.23139442716326, 32.887157985142295, 50.998718057359966, 51.15109205245972, 65.23596259525844, 56.78197125026158, 54.49132735388619, 55.72346878051758, 51.0443503516061, 46.133749212537495, 0.6701911549483026, 0.2627876560602869, 0.14994084994707788, 2.5354198132242476, 56.57577998297555, 57.09645366668701, 60.832923889160156, 57.79283339636666, 60.941809109279085, 53.56641789845058, 58.56116172245571, 47.96236916950771, 43.86431469236101, 41.6846786907741, 47.55692441122872, 46.25314358302525, 49.27856295449393, 49.77351788112095, 52.86221102305821, 53.10390411104475, 56.478887353624614, 53.570340156555176, 52.757463455200195, 49.769619941711426, 51.640689917973106, 54.19909654344831, 53.08166640145438, 52.74792357853481, 52.77882916586739, 54.227900300707134, 53.41978658948626, 52.398755754743306, 54.06627825328282, 52.46718508856637, 44.238176413944785, 41.317219734191895, 39.46224873406546, 37.74509872709002, 38.44036327089582, 38.91883359636579, 41.05465425763811, 42.40175362995693, 45.70777947562081, 48.05617332458496, 53.4211414882115, 42.8560129574367, 43.09209190096174, 46.46570634841919, 45.0539539882115, 38.960904938834055, 37.466257095336914, 36.353343282427105, 36.63836186272757, 35.97409323283604, 37.07588645390102, 37.12462111881801, 36.90738221577236, 35.48127487727574, 36.65288707188198, 36.12518528529576, 36.04377671650478, 37.25512565885271, 37.04724945340838, 35.68084798540388, 36.59784344264439, 37.45298603602818, 36.25126729692732, 35.96223265784127, 36.6889899117606, 36.78145653860909, 33.9246768951416, 38.107252734048025, 43.84061091286795, 41.79301152910505, 39.960163593292236, 38.52102838243757, 42.34459774834769, 50.35076379776001, 46.57157605034964, 43.64287560326712, 41.32134696415493, 37.95051874433245, 37.55755989892142, 36.66722815377371, 35.65985400336129, 34.68336806978498, 37.32029281343733, 34.68737023217337, 38.76897484915597, 40.15191650390625, 44.94769866125924, 46.836114815303254, 49.43849311556135, 48.7315034866333, 46.87526444026402, 46.61630160467965, 48.92617811475481, 50.35305322919573, 49.719155175345286, 51.1348888533456, 50.78116648537772, 49.58858462742397, 47.37613923209054, 46.27724340983799, 46.7711352620806, 47.406999656132285, 43.43187618255615, 42.51176445824759, 41.05601610456194, 40.53866713387625, 42.27199254717146, 41.50141300473894, 43.77356774466378, 46.841621262686594, 52.96790354592459, 49.65551315035139, 56.24896451405117, 48.02561862128121, 52.78459964479719, 24.197349991117203, 0.20733947067388467, 0.08232465891965798, 0.957879092012133, 34.274160861968994, 56.930680070604595, 49.38323409216744, 54.24157435553414, 56.81907115663801, 59.455721446446006, 32.04019342150007, 48.61380795070103, 39.931658608572825, 45.98139953613281, 11.122923833983284, 0.2516486080629485, 0.04175470410180943, 0.19637661107948848, 0.02454416546970606, 0.11185122560709715, 0.05471980857795902, 0.02123075514100492, 0.05989347863942385, 0.06298736083720412, 0.03742529784462281, 0.023505218094214797, 0.07256944916610207, 0.05093984605212297, 0.13338254631630012, 0.1060115700321538, 0.14825177272515638, 0.17217907522405895, 0.14414390815155848, 0.1968212007944073, 0.1606848141444581, 0.15220179648271628, 0.09319778225783791, 0.08722773939371109, 0.15521993381636484, 0.11594473916505064, 0.09064903509403978, 0.1253751545612301, 0.17418278913412774, 0.11551202381295816, 0.11663217656314373, 26.256066492625646, 78.8637285232544, 38.57523822784424, 34.97161408833095, 52.74374771118164, 58.52864415305001, 68.79752581460136, 64.74282809666225, 58.30129909515381, 62.19301986694336, 53.8806779725211, 50.519785676683696, 0.7773996336119515, 0.6275389865040779, 0.4674270866172654, 4.26763698884419, 62.642603056771414, 59.45941093989781, 64.1604231425694, 60.143572262355256, 60.75308213915144, 57.172800472804475, 61.50868483952114, 49.33595160075596, 47.26666341509138, 43.82647132873535, 49.78123385565621, 48.0941104888916, 52.0911659513201, 51.999508789607454, 55.57293258394514, 55.804602895464214, 58.21794155665806, 55.25908245359148, 53.491867201668875, 49.66988549913679, 53.53593962533133, 55.22425808225359, 54.663969244275776, 53.68675027574812, 53.08993475777762, 54.89902332850865, 56.146996225629536, 53.817140170506065, 56.603211471012656, 55.380001953669954, 47.288783005305696, 41.46737377984183, 40.37544352667672, 40.18687636511666, 42.57490273884365, 40.367147377559114, 43.20975617000035, 45.178601196834016, 47.55674375806536, 49.16221536908831, 55.898038796016145, 44.18606145041329, 44.93460130691528, 48.84650659561157, 45.118798051561626, 40.46372733797346, 39.30937099456787, 40.85186413356236, 39.02035025187901, 38.784907068525044, 39.95674507958548, 38.34946346282959, 40.570785181862966, 38.07058014188494, 39.4908892086574, 38.0099640573774, 36.97187886919294, 39.156257016318186, 40.00220366886684, 39.006120341164724, 39.062967027936665, 39.70289611816406, 40.09658452442714, 35.94552918842861, 37.23972150257656, 40.314876079559326, 36.07307726996285, 39.460820879255024, 45.68555566242763, 44.07563373020717, 41.45430074419294, 36.980584962027415, 42.00328138896397, 51.633651392800466, 48.3571206501552, 44.956880705697195, 42.45728015899658, 39.44727884020124, 39.82270390646798, 39.41313191822597, 37.8530216217041, 37.70779037475586, 38.76911381312779, 37.43009172167097, 40.63628237588065, 41.55159636906215, 45.016993045806885, 49.03090831211635, 51.82985462461199, 49.5611948285784, 48.47461468832833, 49.26948165893555, 51.49502788271223, 52.17733056204659, 50.439617361341206, 54.151049750191824, 52.31505428041731, 51.25614186695644, 49.26393699645996, 46.93917049680437, 48.326972416469026, 49.92526306424822, 45.38396910258702, 45.52727222442627, 43.30706916536604, 42.159296240125386, 45.304947240012034, 42.521759441920686, 46.06535461970738, 48.05495391573225, 53.70821673529488, 52.769466468266074, 60.324447768075125, 51.2666266986302, 55.05780356270926, 24.568458489009313, 0.3800918401351997, 0.5255050701754433, 1.5003027000597544, 39.409299986703054, 63.77146298544747, 54.17307901382446, 60.96250779288155, 61.25704887935093, 65.3572781426566, 38.055380957467214, 53.64011744090489, 54.17114741461617, 53.26597431727818, 19.0851468699319, 0.3298894225486687, 0.14988542720675468, 0.2649774785552706, 0.09726025283868824, 0.17178068017320974, 0.13069067576101848, 0.24498189293912478, 0.22596837819686957, 0.2328022707785879, 0.09002556997750487, 0.14472495125872747, 0.20980172497885569, 0.10850409378430673], [0.04791633132845163, 0.0741089569138629, 0.025796705491042564, 0.02529967180453241, 0.05363306010674153, 0.03566077770665288, 0.0023049465630070438, 0.048681135289371014, 0.016160224098712206, 0.17804871526147636, 0.06574695597269706, 0.035259397101721594, 0.03376081519361053, 0.022154368526701416, 0.023638071858191063, 0.09450652024575643, 0.024624334382159368, 1.8645807930401392, 40.70997844423567, 42.243126256125315, 35.30812924248831, 32.010715688977925, 44.73365592956543, 52.87437731879098, 59.037307875497, 49.555521624428884, 54.43366772787911, 45.05824102674212, 48.292835916791645, 2.113378848348345, 0.32650043868592804, 0.16169416212609836, 3.0893160913671767, 56.358217988695415, 47.88218695776803, 57.049129486083984, 51.35836723872593, 57.10332196099417, 53.324127265385215, 52.6988901410784, 49.62628207887922, 43.202123573848176, 41.64073828288487, 41.08382626942226, 43.16084780011858, 44.5008669580732, 47.105975900377544, 49.84801994051252, 51.534066336495535, 51.277257442474365, 49.924477917807444, 51.97625316892351, 51.10000542231968, 50.60558203288487, 48.02671643665859, 51.78904785428728, 50.95383269446236, 49.446341105869834, 49.189771924700054, 50.04278836931501, 50.421367917742046, 47.99833999361311, 42.68566049848284, 38.214050020490376, 39.725484711783274, 35.94312163761684, 36.67749759129116, 37.558442320142476, 39.135433265141074, 39.42214373179844, 40.28531844275338, 42.492361613682334, 45.64313343593052, 48.49103675569807, 48.4028502191816, 45.0395746912275, 37.28179284504482, 32.60706220354353, 35.23741395132882, 33.81058052607945, 35.806367192949565, 33.3896621295384, 32.6641069139753, 34.632246698652, 34.19435385295323, 33.9835524559021, 35.43922437940325, 34.168360642024446, 34.53846338817051, 35.27671991075788, 33.856035641261506, 33.661284582955496, 34.13610363006592, 36.03959390095302, 34.71205718176705, 34.50436510358538, 35.6776031766619, 35.674035276685444, 34.70152023860386, 34.987403869628906, 34.61115544182913, 31.855121203831263, 36.86828817640032, 42.74097858156477, 45.29124886648995, 50.02714102608817, 52.20669364929199, 45.012507983616416, 42.67441136496407, 37.957581588200156, 36.654273237500874, 35.97318649291992, 36.024870668138774, 33.849910804203574, 33.71878787449428, 34.35469395773751, 34.8134001323155, 36.02649654660906, 37.79033497401646, 40.12723650251116, 44.97185059956142, 44.20747232437134, 44.20542260578701, 45.61247798374721, 49.44526413508824, 46.73719678606306, 47.67973729542324, 47.75556298664638, 48.02207851409912, 47.2967734336853, 46.55059943880354, 44.81413343974522, 44.19507673808506, 43.67881863457816, 40.693393094199045, 38.15499380656651, 38.3476117679051, 35.821493421282085, 37.43378816332136, 39.06411695480347, 40.75253963470459, 39.34392091206142, 45.00727946417672, 47.678420611790244, 48.354396956307546, 48.521827697753906, 46.995013168879915, 46.06455210277012, 35.51549475533621, 0.2747925418828215, 0.11198866287512438, 1.331848076411656, 31.36354657581874, 47.29181589399065, 45.86577456338065, 47.099819796425955, 48.99202619280134, 44.30290930611746, 27.228456463132584, 36.62063005992344, 31.40068817138672, 29.935486793518066, 0.24721791009817803, 0.03784341451578906, 0.058673065554882796, 0.010590533010794647, 0.037941581569612026, 0.03731967029826982, 0.042478782390909534, 0.05666467993121062, 0.019470496202952096, 0.019329069149015204, 0.03404152513082538, 0.025704219471663237, 0.05413338129541703, 0.049636868826512776, 0.043274585224155865, 0.023227999219670892, 0.11004593569253172, 0.03245213148849351, 0.012970524274611046, 0.022645963755037104, 0.03197971505245992, 0.023710049156631743, 0.029281646079782928, 0.0397020678168961, 0.035236387979239225, 0.02489447613645877, 0.05715688584106309, 0.027829443736534034, 0.01428636143516217, 0.047305286795433076, 0.046181151044688055, 3.216543904372624, 52.98939432416643, 37.64179291043963, 26.91122429711478, 48.758108139038086, 47.75692483357021, 60.63234329223633, 62.23520238058907, 55.16820696422032, 57.58437006814139, 51.44407326834542, 52.44465902873448, 3.20287549495697, 0.12647809966334275, 0.03450758708640933, 5.47143063374928, 64.85086563655308, 50.18677936281477, 61.49453830718994, 54.935612542288645, 58.91315746307373, 56.04498277391706, 56.137063775743755, 50.82832390921456, 45.48134115764073, 42.61217287608555, 43.18232468196324, 43.99856778553554, 47.6147403717041, 47.00835371017456, 52.59486518587385, 53.407974651881624, 53.68558645248413, 51.03671775545393, 54.82262441090175, 53.353719643184114, 51.119019167763845, 50.70654630661011, 54.36554411479405, 52.41614362171718, 51.73982334136963, 52.64068160738264, 52.758252075740266, 52.457030296325684, 50.3322503226144, 45.22686685834612, 42.26723997933524, 42.032998834337505, 38.367758069719585, 37.567478452410015, 38.60512590408325, 40.39058017730713, 41.775390897478374, 42.47863892146519, 44.32122475760323, 48.131199972970144, 52.22438028880528, 50.642966815403526, 49.11805609294346, 41.83901555197579, 35.971435546875, 37.47842339106968, 36.014778409685405, 38.237983090536936, 35.87247582844326, 35.88695240020752, 36.805796078273225, 37.5554962839399, 36.087067467825754, 38.838776452200754, 36.37036984307425, 36.59403582981655, 36.487794399261475, 35.844860213143484, 36.356636728559224, 35.31367737906319, 36.343483788626536, 37.526352064950125, 36.58658388682774, 36.77633571624756, 36.69917944499424, 35.591299601963584, 37.0636020387922, 35.70175511496407, 34.53841127668108, 40.16020917892456, 43.97627101625715, 45.11550807952881, 47.807059560503276, 51.672797543661936, 45.9754136630467, 42.83069372177124, 38.400223527635845, 38.194112164633616, 37.323874609810964, 37.53152847290039, 35.7221793447222, 36.25368179593767, 35.23348127092634, 37.432005950382774, 37.70794670922415, 38.841375078473774, 41.001128809792654, 47.68898187364851, 47.05198492322649, 46.57940319606236, 47.157111167907715, 49.56577716554914, 48.68942172186715, 49.64528887612479, 49.61745091847011, 50.67128767286028, 48.772650718688965, 49.38767746516636, 46.64602599825178, 46.128927162715364, 43.35412584032331, 42.98509659085955, 41.0211569922311, 40.54045976911272, 36.8198036466326, 39.80273478371756, 39.90030138833182, 42.48004593167986, 41.22457940237862, 47.472462109157014, 49.92492607661656, 49.93978827340262, 51.43990434919085, 51.250117778778076, 49.977437087467735, 40.29112018857683, 0.12683804892003536, 0.09453063538031918, 1.4837811865976878, 35.579004764556885, 53.78589759554182, 50.11949648175921, 52.864344120025635, 56.24025494711739, 48.43484319959368, 34.50851665224348, 42.364636353084016, 35.94291319165911, 37.4974718775068, 0.6919125808136803, 0.059640751486378055, 0.020686597197449634, 0.0376248142815062, 0.08194904228938477, 0.009655158916887428, 0.02433067969312625, 0.0625334344804287, 0.028896401037595103, 0.07027180067130498, 0.053957762861890454, 0.05619495727920106, 0.02910442291093724, 0.08113534988037177, 0.1020713307495628, 0.142859441361257, 0.18025362837527478, 0.09769014548510313, 0.15348892313029083, 0.10739759994404656, 0.10412267781794071, 0.10355850987668548, 0.1735732475561755, 0.2620125247963837, 0.1654913526560579, 0.11511301808059216, 0.07585767057857343, 0.07120446741048779, 0.1291621806366103, 0.23216898047498294, 0.11944627841668469, 4.33202029977526, 62.61364296504429, 53.02082450049264, 47.78612463814871, 46.15868977137974, 55.88748448235648, 63.06533145904541, 69.9398444039481, 58.974732398986816, 67.16011333465576, 53.258407729012625, 61.79704897744315, 3.3870021062237874, 0.7042355909943581, 0.20832515135407448, 7.796815957341876, 72.01583412715367, 53.660020555768696, 66.30530425480434, 57.59285381862095, 61.281027112688335, 55.60013825552804, 60.3619749886649, 53.92792572293963, 49.100317341940745, 45.24211120605469, 45.70396144049508, 47.18137427738735, 49.2663653918675, 50.10349825450352, 55.799252782549175, 55.361165387289866, 56.00997427531651, 52.84556661333357, 57.08315134048462, 54.72411979947771, 55.463672161102295, 51.89696032660348, 55.541790757860454, 54.08664689745222, 53.89517886298043, 53.767769745418, 55.65484489713396, 54.58199439729963, 52.40447759628296, 46.22258540562221, 42.391108989715576, 44.59015825816563, 39.72003732408796, 40.32785184042794, 40.347032342638286, 43.23104197638375, 43.28495304925101, 45.10793801716396, 45.891371726989746, 50.3054233278547, 54.75757884979248, 53.13220064980643, 50.35254601069859, 44.11322348458426, 38.062138080596924, 39.70223951339722, 40.57925851004464, 42.04612398147583, 39.251270157950266, 38.023790972573416, 40.10799694061279, 39.870490142277305, 38.374282428196494, 41.733142375946045, 38.529470443725586, 38.713003635406494, 40.73990086146763, 38.244670731680735, 37.93623672212873, 36.95468555177961, 39.27162837982178, 37.884993757520405, 38.2979599407741, 38.81464883259365, 39.37967981610979, 37.51563446862357, 39.3455467905317, 38.627012729644775, 36.164494718824116, 42.65746818270002, 46.35475403921944, 45.84951230457851, 50.242642879486084, 52.961483410426546, 47.89785514559065, 45.23988430840628, 39.50296170370919, 39.51481185640608, 40.111224378858296, 40.23437772478376, 38.05103833334786, 38.02229363577706, 38.186479568481445, 37.96760089056832, 39.23828397478376, 40.34668493270874, 44.056828430720735, 49.47439445768084, 47.97565759931292, 49.494707516261506, 49.50952107565743, 53.758288928440635, 50.16810607910156, 51.19664444242205, 52.217772551945274, 52.46624708175659, 51.10341698782784, 50.39674002783639, 50.86735888889858, 48.77339417593819, 46.125498226710725, 45.72472960608346, 41.71936757223946, 43.23829936981201, 39.446156706128804, 41.06383630207607, 42.09476484571184, 44.83515521458217, 43.663640294756206, 49.62774814878191, 52.83509567805699, 53.27342973436628, 54.413160119737896, 56.32883753095354, 54.211658886500764, 44.34851728166853, 0.4344576671719551, 0.2879728132060596, 2.085471191576549, 38.86615582874843, 60.67021792275565, 53.85703672681536, 59.07759353092739, 60.512320109776084, 55.32581295285906, 36.675350597926546, 46.619900771549766, 42.52962480272566, 49.47136851719448, 1.4689466740403856, 0.3087034693786076, 0.1783591043204069, 0.1449012482272727, 0.1159998362085649, 0.11496227474084922, 0.15460146271756717, 0.12524286737399443, 0.11528938290263925, 0.11827417702547141, 0.1523237835083689, 0.15194145616676125, 0.15006477758288383, 0.1949120203831366], [0.08739098813384771, 0.025778785381200056, 0.011491282310869013, 0.08586931228637695, 0.03457334730774164, 0.02461145748384297, 0.015304940885731151, 0.02092912936184023, 0.029265242495707104, 0.03001387696713209, 0.018304974905082157, 0.03419335412659815, 0.037238398766411204, 0.020433666483898247, 0.14479796162673406, 0.02859986087839518, 0.08401035703718662, 0.13394582537668093, 15.063077892575945, 53.44112450735909, 34.75335727419172, 28.15606529372079, 40.26756232125418, 48.990073748997276, 48.43620157241821, 44.91887753350394, 55.71950830732073, 45.25278016499111, 55.81719650541033, 5.0049689667565485, 0.19183509477547236, 0.07639490067958832, 10.680813431739807, 60.996665137154714, 50.49827752794538, 53.888324465070454, 48.94497299194336, 52.24581200735909, 51.60016802379063, 51.93011713027954, 47.69470024108887, 44.25739860534668, 39.221497126988, 41.18954658508301, 40.872597558157786, 43.67488248007638, 44.60026093891689, 47.26470749718802, 48.643164089747835, 51.29809161594936, 50.25030326843262, 52.1254448890686, 53.12825754710606, 54.27992146355765, 51.79238646371024, 51.576658793858115, 49.94131340299334, 47.97389970506941, 45.64817087990897, 44.34800658907209, 42.545720304761616, 41.13641371045794, 39.80167865753174, 39.3227983883449, 37.04962226322719, 35.860260895320344, 36.68657888684954, 38.42286075864519, 40.02252714974539, 39.162576402936665, 38.86652060917446, 40.39730255944388, 42.643262590680806, 43.11090414864676, 40.68839039121355, 35.04441383906773, 35.34275559016636, 36.062140805380686, 35.354591846466064, 33.385753767830984, 36.20022235597883, 33.54923445837838, 34.442150933401926, 34.07765885761806, 33.887041977473665, 34.174381256103516, 33.90207093102591, 32.47367763519287, 34.64943306786673, 33.481659752982004, 36.10859646115984, 34.344382831028526, 34.040461676461355, 34.68826654979161, 34.07176678521292, 34.636481625693186, 33.88912991115025, 33.10141611099243, 35.51085335867745, 33.65537166595459, 34.470551695142476, 34.44914776938302, 32.765922342027935, 34.580819606781006, 39.696500301361084, 43.62099225180489, 44.533745833805625, 43.13125194822039, 40.593644755227224, 36.2123886517116, 38.169157709394185, 36.57000201089041, 37.39255060468401, 35.06894792829241, 33.424660205841064, 32.81658165795462, 36.454856463841026, 35.9983354977199, 36.05338954925537, 38.012899671282085, 39.07084281103951, 43.83406570979527, 45.448031493595664, 46.61622864859444, 47.79176657540457, 47.45598098209926, 48.976302419389995, 47.39050463267735, 49.96050085340227, 48.050260407584055, 46.78591060638428, 42.65151357650757, 40.83491400309971, 38.07265417916434, 40.554217202322825, 36.96190473011562, 38.739448479243684, 38.201202801295686, 39.69535732269287, 38.40588978358677, 43.59733016150338, 43.49926676068987, 45.66996043069022, 43.163759095328196, 47.90174961090088, 44.75554622922625, 47.825468812670024, 42.21200180053711, 42.143440450940815, 1.4686475758041655, 0.2924945977117334, 1.7678699025085993, 33.182744775499614, 49.368170397622244, 47.07676567350115, 46.91547366550991, 52.42957101549421, 34.23952409199306, 29.055573872157506, 24.6815664768219, 40.516401631491526, 10.919530085154943, 0.20855258272162505, 0.10335001642150538, 0.032910302081810575, 0.02508788406183677, 0.06898174953780004, 0.019413495868710533, 0.04753379024831312, 0.04790755108531032, 0.041370419186672995, 0.041122238218252144, 0.0540630613187594, 0.060296379162796905, 0.030567222274839878, 0.049433332069643905, 0.01856231948892985, 0.025573788077703545, 0.05144446576014161, 0.01890889821308, 0.02583990103032972, 0.02206258479106639, 0.04045623913407326, 0.04369283081697566, 0.02176721510477364, 0.022504755528643727, 0.01937579476673688, 0.12883629383785383, 0.06305686317916427, 0.035017940415335555, 0.052984553655343394, 0.03259500042934503, 0.06101066619157791, 0.12641312314995698, 23.68673208781651, 61.994141578674316, 30.225445543016704, 40.412064007350374, 50.08641610826765, 52.98802900314331, 58.502581460135325, 49.066899980817524, 62.094855717250276, 49.36365754263741, 59.777179854256765, 5.710259326866694, 0.1537527104041406, 0.014796835204054202, 13.085177625928607, 67.2068816593715, 52.28024727957589, 57.919683183942524, 50.50737271990095, 55.175433090754915, 52.33970996311733, 53.97966548374721, 48.88835906982422, 47.037622996738975, 40.67573077338082, 43.70965821402413, 44.110253129686626, 45.76549121311733, 45.817290033612935, 48.443646567208425, 50.20050205503191, 52.55079623631069, 52.72960812704903, 54.03673798697335, 55.34521927152361, 54.839209760938374, 53.3361302784511, 52.563921383449006, 52.02229193278721, 50.56919084276472, 47.02800668988909, 47.823196751730784, 45.470474175044465, 45.36900615692139, 43.69589383261544, 40.49629701886858, 39.13326890127999, 39.00994879858834, 38.4173960004534, 40.201863629477366, 42.43932253973824, 43.36733783994402, 41.60459722791399, 43.62885761260986, 46.54673276628767, 46.492363112313406, 45.31206219536917, 39.47672530582973, 36.8025095803397, 37.41447564533779, 37.11652299336025, 38.24737010683332, 38.660489150456016, 35.78539752960205, 36.95986195972988, 36.57133259092058, 36.647807938711985, 36.33580255508423, 36.74299825940813, 35.492968695504324, 36.47195250647408, 35.76476485388619, 37.20819405147007, 37.134063720703125, 36.304945605141775, 36.595901421138215, 35.5934431212289, 35.79187325068882, 35.74741172790527, 35.47022376741682, 36.767344747270855, 35.14302962166922, 36.53790133340018, 36.240685190473286, 35.6565431867327, 37.45255177361624, 42.1399941444397, 46.67518411363874, 46.319974831172395, 45.723802021571565, 42.84443378448486, 38.895723887852256, 38.98828084128243, 37.93448230198452, 39.11507504326956, 35.799182755606516, 36.201417446136475, 35.11444125856672, 37.52803700310843, 37.582726274217876, 36.79575940540859, 39.61593246459961, 41.17508390971592, 46.772813252040315, 47.42510666166033, 47.785825865609304, 51.30573810849871, 49.55883591515677, 52.235757963997976, 47.755573408944265, 50.525820187159944, 49.692227431706016, 47.45440721511841, 42.521922724587576, 44.06900862285069, 41.157199246542795, 42.73586470740182, 39.46490294592721, 40.639898913247244, 39.28357580729893, 42.22262907028198, 40.93646887370518, 46.10795055116926, 44.979552677699495, 47.1385177884783, 45.65133578436715, 51.85022326878139, 47.98102160862514, 53.53972291946411, 47.5555590902056, 47.28871004922049, 2.204697068248476, 0.3303960710763931, 1.942583007471902, 36.394987310682026, 54.82829761505127, 52.402511256081716, 53.224330289023264, 57.14121743610927, 39.92050674983433, 34.0165251323155, 26.950019563947404, 46.32367822102138, 12.621079649244036, 0.21172782805349144, 0.0865865373717887, 0.06365294262234654, 0.029599512594618967, 0.03871970856562257, 0.046001553003277094, 0.056781167430537086, 0.00901182459866894, 0.05762890872678586, 0.04119573373879705, 0.007935989515057631, 0.03389058501592704, 0.0544386847343828, 0.04291295998596719, 0.19704226750348294, 0.10803492074566227, 0.08143599517643452, 0.12476979275899273, 0.15124089590140752, 0.18921392756913388, 0.13826497218438558, 0.09855845317776714, 0.2084363903850317, 0.12608188949525356, 0.10782686155289412, 0.17672988745783055, 0.11827405488916806, 0.11570594912128788, 0.2584516273013183, 0.14950846029179438, 0.13254636047141893, 0.4521707152681691, 32.44427980695452, 68.52396133967808, 45.57737568446568, 40.85463646480015, 53.80798939296177, 60.050369126456125, 60.82840061187744, 54.95787109647478, 69.44823850904191, 55.141932351248606, 65.12004579816545, 6.288931795528956, 0.44608718742217335, 0.32337079090731485, 14.655734539031982, 72.08760901859829, 55.52189111709595, 62.520613534109934, 53.65745319638933, 57.90207992281233, 53.50356101989746, 57.07896505083357, 52.40662806374686, 51.030016217912944, 42.52318034853254, 48.050343785967144, 45.46408878053938, 47.561697823660715, 48.48760781969343, 52.85158722741263, 53.53608553750174, 57.30639001301357, 53.312561988830566, 56.21210779462542, 56.29293966293335, 58.63798795427595, 54.35777602876936, 55.553891045706614, 54.837271213531494, 52.16605363573347, 49.30647039413452, 48.235596656799316, 46.368598324911936, 46.03607491084507, 44.683305808476035, 42.711441789354595, 40.84782723018101, 40.395746162959504, 40.168150969914024, 42.00251708711897, 44.144441740853445, 44.05725227083479, 43.45552090236119, 46.47550678253174, 47.62278985977173, 49.2329306602478, 46.48063107899257, 41.800355775015696, 40.18391990661621, 39.90455368586949, 41.66053022657122, 40.68084464754377, 42.297725200653076, 38.41879606246948, 40.20257234573364, 39.10607712609427, 37.21420771735055, 39.01576444080898, 40.34954759052822, 38.336133343832834, 39.261737619127544, 37.26321683611189, 41.867857524326865, 40.45914500100272, 38.968561853681294, 38.48386941637312, 37.64412750516619, 37.62239701407296, 37.639107431684224, 37.429271834237234, 41.106484345027376, 37.14189781461443, 37.72839873177664, 38.94831132888794, 37.0290903363909, 38.404830183301655, 43.57232012067522, 47.795952865055625, 47.83096136365618, 46.199124813079834, 44.79764883858817, 40.30039950779506, 40.54026174545288, 39.924001693725586, 41.80472271783011, 38.64318118776594, 38.681198256356375, 36.71459402356829, 40.6088022504534, 39.28323881966727, 38.51170737402779, 42.41699797766549, 42.14011921201433, 49.012919425964355, 49.7729446547372, 50.49396269662039, 51.84671442849295, 52.884778772081646, 53.68365485327584, 49.30830471856253, 53.569610595703125, 51.883008343832834, 51.08209991455078, 45.33086402075631, 47.63692249570574, 42.33028098515102, 44.48536900111607, 42.299670696258545, 43.15175608226231, 41.502941608428955, 45.07952683312552, 42.442911284310476, 47.326376233782085, 48.81846366609846, 49.38095160893032, 48.677165099552695, 55.02865586962019, 52.68523693084717, 57.22405385971069, 51.28938552311489, 51.76661906923567, 2.718384772539139, 0.37988100573420525, 2.5394215413502286, 42.21583373206002, 60.15451567513602, 57.78236593518938, 59.02294594900948, 61.90627465929304, 46.210273197719026, 40.0773275920323, 32.619468212127686, 55.05881799970354, 21.13592505455017, 0.2115381368036781, 0.22376198587673052, 0.1733681128493377, 0.11754395120910235, 0.2017182015946933, 0.10637140393789325, 0.14380055586142199, 0.13187560146408422, 0.13340482940631254, 0.1517976067428078, 0.13975147956183978, 0.11073164282632725, 0.16680449433624744, 0.26546854791896685], [0.02225931075268558, 0.031126782963318483, 0.03347611886316112, 0.028573157132736275, 0.058918939504240236, 0.025461115641519427, 0.04477868362196854, 0.020919804594346454, 0.011782082911979939, 0.028720789389418702, 0.018719222230304564, 0.021510126667895486, 0.06183907602514539, 0.061706537779952796, 0.022686216148680875, 0.04353992634319833, 0.09890766122511455, 0.06568011348800999, 1.1273483697857176, 31.12832920891898, 43.73410545076643, 26.54465470995222, 34.20949745178223, 43.90788337162563, 49.302047865731375, 53.02319383621216, 54.04462766647339, 46.51160267421177, 45.67447328567505, 5.7596853375434875, 0.04045046140838947, 0.1045431863250477, 11.909195014408656, 66.51260375976562, 52.01197385787964, 55.731004101889475, 46.495003427777974, 50.48388433456421, 50.52592093603951, 49.53571925844465, 45.82964393070766, 44.530118874141145, 41.02450949805123, 41.231947966984336, 39.83081592832293, 41.35932581765311, 40.65986803599766, 43.919403484889436, 45.50018119812012, 46.55133247375488, 47.016340664454866, 50.32721635273525, 52.83098234449114, 52.34079735619681, 49.79103428976876, 51.92899152210781, 48.10101005009243, 46.828381470271516, 43.26786395481655, 41.46830831255232, 40.9201614516122, 38.17849956239973, 39.87056309836251, 37.93240131650652, 38.807252475193565, 38.076632022857666, 38.397805554526194, 39.19857849393572, 41.209936073848176, 46.34690604891096, 39.53184189115252, 38.726441451481406, 42.80426277433123, 39.32729387283325, 36.51649045944214, 34.983776909964426, 35.12504768371582, 33.79555852072579, 33.523043223789756, 33.52484975542341, 34.79470600400652, 33.07440846306937, 35.96746117728097, 35.15163149152483, 34.262182167598176, 34.67216757365635, 34.407934529440745, 33.80736003603254, 36.44615037100655, 33.56728935241699, 35.764810017177034, 35.149421964372905, 35.7559232711792, 34.941740308489116, 35.804463386535645, 33.98658881868635, 35.21172298703875, 34.82551779065813, 34.37565319878714, 34.762344769069124, 36.161003249032156, 33.41282742364066, 35.32591315678188, 35.640590122767854, 34.95854105268206, 37.33531829289028, 41.66608878544399, 42.439006396702354, 39.95106840133667, 36.77872937066214, 38.60468121937343, 40.0370523588998, 35.24316011156355, 36.31004558290754, 33.77101400920323, 32.74744708197457, 34.58165686471121, 36.481336048671174, 35.97832815987723, 36.14818034853254, 38.02766806738717, 39.509423528398784, 43.42556027003697, 46.4029814856393, 48.08597067424229, 47.08078868048531, 46.9661295073373, 47.367870875767295, 48.16851874760219, 44.89376674379621, 45.04756511960711, 42.51981742041451, 39.462200096675325, 39.18830558231899, 40.53562382289341, 39.465021065303254, 39.35804312569754, 38.57885129111153, 43.335063457489014, 46.358169078826904, 45.78191328048706, 42.19467299325125, 43.92617450441633, 43.06499392645699, 45.8279242515564, 41.99047933306013, 49.07256276266915, 43.509046350206646, 45.53751734324864, 3.4398785488946095, 0.4460639272417341, 2.8440928842340196, 37.1879608971732, 47.926109995160786, 49.62522595269339, 46.878273010253906, 50.254041399274556, 30.973568507603236, 26.857405287878855, 33.858196531023296, 24.52800781386239, 0.15131041859941824, 0.032890682241746357, 0.050832227005490234, 0.08376892070685114, 0.013688624670196856, 0.06108899627413068, 0.04102103132754564, 0.008363910169074578, 0.028714048144008433, 0.07172035758516618, 0.04703344531091196, 0.03512408025562763, 0.039368669635483196, 0.03556642062695963, 0.007283099727439029, 0.051518534642777274, 0.10348672087171248, 0.0424978254762079, 0.073779779220266, 0.05578159374584045, 0.015801687891195928, 0.07377479198787894, 0.01985694734113557, 0.041860053448804786, 0.09004682169428893, 0.026416742309395756, 0.00862698837382985, 0.03244635037013462, 0.03278501398329224, 0.04254792510930981, 0.03782722467024412, 0.04511827343542661, 0.05213585223204323, 2.8139294513634274, 44.1669191632952, 41.108329091753276, 25.64208892413548, 47.78177159173148, 46.3212776184082, 56.33496584211077, 56.07681247166225, 60.5478948865618, 50.77387087685721, 54.40836933680943, 6.97004633290427, 0.01750876155814954, 0.06765583104320935, 12.273562022617885, 71.7161305291312, 56.48775325502668, 59.368299211774556, 49.35138007572719, 50.9267520904541, 52.433389050619944, 51.70396021434239, 47.27674177714756, 46.93893425805228, 42.96922690527779, 42.38175671441214, 43.63404096875872, 43.719858169555664, 43.069131578717915, 46.48494938441685, 45.57325192860195, 48.775985854012625, 49.270558629717144, 52.077064582279746, 53.36078943525042, 53.94641835348946, 53.4408153125218, 53.853920459747314, 49.0012777192252, 48.861601557050435, 44.68313905170986, 43.95096220288958, 42.087305954524446, 39.96513850348336, 42.17612130301339, 40.82334525244576, 40.714956828526084, 38.88251536233084, 39.99645750863211, 41.28923239026751, 43.76887771061489, 48.36637912477766, 40.01434564590454, 42.18248585292271, 44.257068565913606, 43.23912273134504, 39.11475542613438, 37.352473395211355, 36.89280489512852, 35.88616030556815, 36.99354682649885, 36.17363854816982, 37.123248849596294, 36.519342694963726, 38.63866138458252, 36.77848965781075, 35.28394603729248, 38.606567655290874, 36.61449480056763, 36.52841009412493, 38.10640157972063, 37.92831577573504, 36.51591375895909, 37.87401907784598, 37.66562523160662, 36.65891810825893, 38.796802384512766, 36.62284306117466, 36.955057280404226, 37.09406641551426, 35.329533168247764, 35.34384993144444, 36.09974793025425, 36.3085412979126, 37.351358209337505, 35.95169224057879, 37.35020480837141, 39.55554567064558, 45.20594583238874, 44.55352735519409, 42.00929505484444, 37.859181199754985, 39.68247536250523, 40.157478536878315, 36.54232733590262, 36.50269481113979, 34.761601311819895, 34.553839751652305, 36.35743229729788, 37.42242785862514, 38.71121794836861, 38.556971413748606, 39.46586527143206, 42.00222178867885, 45.70674419403076, 48.12732287815639, 49.71265166146414, 48.4329845564706, 48.39479725701468, 49.753541810171946, 50.735030446733745, 47.27091918672834, 46.51991619382586, 43.40272848946707, 43.40764086587088, 42.41517754963466, 43.6960779598781, 42.09996209825788, 41.36197655541556, 42.03989144733974, 46.38322080884661, 47.88856887817383, 48.12066650390625, 44.20909820284162, 46.07760081972395, 45.42296239307949, 47.00660276412964, 47.08963373729161, 54.67342921665737, 47.8765207018171, 51.287940297807964, 4.3273515445845465, 0.6952595497880663, 3.7590301547731673, 42.89438785825457, 53.14865050997053, 53.634986196245464, 52.6981987953186, 53.70735515866961, 38.77530118397304, 29.766819272722515, 37.20125280107771, 30.88150487627302, 0.07482388176556144, 0.032051904393093925, 0.05686744994350842, 0.0831135848004903, 0.041224927707974396, 0.05017941864207387, 0.07013430233512606, 0.0265611549174147, 0.03123121289536357, 0.053095843576427014, 0.0476403304242662, 0.05507389868476561, 0.06669128672885043, 0.04493852272363646, 0.029087965044059923, 0.17164804014776433, 0.21606160407619818, 0.09005150358591761, 0.17334874745990547, 0.17811057051377638, 0.18352492712438107, 0.20290661496775492, 0.2323437982371875, 0.12454878033271857, 0.15821464812116964, 0.1723057305706399, 0.10316892221037831, 0.20197130872734956, 0.11437454127839633, 0.1435175524758441, 0.13789111295981066, 0.24691368213721684, 0.18577436570610317, 4.183825211865561, 56.180420534951345, 54.75724186216082, 37.200478076934814, 46.59646449770246, 52.54420934404646, 61.957816396440776, 63.11415645054409, 66.52451297215053, 55.087486267089844, 60.20149939400809, 8.815792730876378, 0.11301825834172112, 0.13191710066582474, 14.761746679033552, 76.43360996246338, 59.04151848384312, 63.14048317500523, 51.230273723602295, 54.842666489737375, 54.74067040852138, 55.199369634900776, 50.15625592640468, 48.494368416922434, 46.876779147556846, 45.39427328109741, 45.73146588461739, 47.546793937683105, 43.84715264184134, 48.3750296320234, 47.795654092516216, 50.99660580498831, 52.54345893859863, 54.933767795562744, 57.41587277821132, 56.28534875597273, 54.409866673605784, 56.529473713466096, 50.63503197261265, 51.88689933504377, 46.60995789936611, 46.03028358731951, 45.69157975060599, 42.26183775493077, 43.08842325210571, 42.646820068359375, 42.60020112991333, 41.7111165864127, 42.244015625544954, 42.95648043496268, 44.885981287275044, 50.7071646962847, 44.87998846599034, 44.37185628073556, 46.89980547768729, 44.21292666026524, 40.41179650170462, 39.85875463485718, 39.90718010493687, 38.97214017595564, 40.0300555229187, 38.238434723445344, 38.9049128804888, 39.08052165167672, 42.68755040849958, 40.975069590977256, 37.989463397434776, 41.50934784752982, 39.8547420501709, 40.00928388323103, 42.009340218135286, 40.080541133880615, 40.26394230978829, 40.176367214747835, 39.85791390282767, 38.000542300088064, 41.88346665246146, 38.384058543613975, 39.73418385641915, 38.738465309143066, 36.400997502463206, 37.76717662811279, 39.88137796946934, 37.45032835006714, 39.157987117767334, 38.01879869188581, 39.024814469473704, 40.94392776489258, 45.63948563167027, 45.757615430014475, 42.74161434173584, 40.71201426642281, 40.18893650599888, 42.84912381853376, 37.334182262420654, 39.51922396251133, 36.532248973846436, 35.84711142948696, 37.197063037327354, 40.53496026992798, 39.08438485009329, 39.98675434929984, 41.62023067474365, 43.064379010881694, 47.14585508619036, 50.59296063014439, 52.60371719087873, 48.8466351372855, 49.732874393463135, 51.363686084747314, 52.407652923039024, 49.03145374570574, 48.66968188967024, 44.955473695482524, 44.6889442716326, 43.81353030885969, 47.14549725396292, 45.88182142802647, 43.09890808377947, 44.075352328164236, 49.67620488575527, 50.754513195582796, 49.85373135975429, 46.706065382276265, 48.93650313786098, 47.75027193341936, 50.658565521240234, 49.30567135129656, 57.34163127626692, 52.341269833701, 56.721539293016704, 5.6455985222543985, 0.6606013381055423, 4.170784745897565, 48.122976779937744, 59.009862491062705, 59.07430008479527, 56.59419618334089, 61.904204096112935, 42.85903542382376, 38.795728887830464, 46.310775416237966, 42.83843401500157, 0.772333094051906, 0.14182789171380655, 0.11616123254810061, 0.19380732466067585, 0.15694391487964562, 0.09292484154658658, 0.1940394922026566, 0.11441921602402415, 0.16285529839141027, 0.16039902876530374, 0.20100416562386922, 0.09883301558771304, 0.1731476839631796, 0.13661712275019713, 0.10281397375677313], [0.03767986043489405, 0.09144325354801756, 0.007003779938843633, 0.028911193101001636, 0.06422846923981394, 0.007198413468099066, 0.04571404414517539, 0.03386362003428595, 0.04100673798737781, 0.03212650253304413, 0.03284810416932617, 0.01365622631939394, 0.05072721014065402, 0.0390573577689273, 0.06304392351635865, 0.09614684472658805, 0.07951274194887706, 0.12563162722757884, 0.14664619602262974, 8.968442048345294, 51.37008884974888, 35.30006585802351, 37.1487626348223, 35.69384111676897, 55.60676336288452, 52.855742250170024, 54.761810302734375, 47.292872020176475, 48.68403339385986, 16.832712854657853, 0.1385296686951603, 0.2522567111466612, 10.653749329703194, 67.98130008152553, 52.03925943374634, 55.14107424872262, 44.96549994604928, 49.461331844329834, 43.75327900477818, 45.71701710564749, 44.8234474999564, 43.45236642020089, 39.05381277629307, 40.63100869315011, 39.44550357546125, 40.292356967926025, 39.5469959122794, 39.68735647201538, 41.51833534240723, 41.02162252153669, 42.13188559668404, 42.36838490622384, 44.64962094170706, 46.380507537296836, 43.31176267351423, 41.44261734826224, 41.3675594329834, 40.013310364314485, 38.70516954149519, 37.51719086510794, 38.028078011104036, 38.8271347454616, 40.439839431217735, 37.393815176827566, 38.45274496078491, 35.83183234078543, 38.49780055454799, 39.84961427961077, 42.58133329663958, 41.617711952754426, 36.2396742275783, 37.50188398361206, 37.378053188323975, 36.11566972732544, 34.37711926868984, 35.35537004470825, 31.886179651532853, 34.59224591936384, 34.13124336515154, 34.717497621263774, 34.38718720844814, 33.740243911743164, 34.49100719179426, 34.05242647443499, 34.386238779340474, 34.34466075897217, 34.50836379187447, 35.94599124363491, 34.17565277644566, 34.304388999938965, 33.815440790993826, 35.53123589924404, 33.12785053253174, 34.33198724474226, 32.9122896194458, 35.674771785736084, 34.691480091639924, 34.18495988845825, 34.46320397513253, 35.39655549185616, 34.55533708844866, 34.67810133525303, 33.05143771852766, 33.972487449645996, 37.03878654752459, 35.868897506168906, 37.309092317308696, 40.56620284489223, 38.80710308892386, 33.885318824223106, 39.76316826684134, 43.32622882298061, 36.23768704278128, 35.25417995452881, 33.69459424700056, 35.24706499917166, 34.340620381491526, 35.50609384264265, 35.212733949933735, 36.950606959206716, 36.20504787990025, 36.935352189200266, 37.25033835002354, 45.711736474718364, 47.827758244105745, 48.31244373321533, 48.64080170222691, 47.5065986088344, 47.608705861227854, 44.42172350202288, 43.208373478480745, 41.38471800940377, 40.887070655822754, 39.53460727419172, 38.27923107147217, 39.86759969166347, 41.65448876789638, 40.77440561567034, 43.67458023343767, 45.33038459505354, 44.91820355824062, 44.69874817984444, 44.18169798169817, 41.89000143323626, 43.00741073063442, 43.47525378635952, 49.62056023733956, 45.636883531297954, 48.102715832846506, 4.877757438591548, 0.8203606711966651, 5.109465965202876, 36.29356098175049, 51.73872900009155, 43.83109882899693, 53.62579720360892, 41.96595566613333, 20.073696613311768, 23.802999768938335, 33.636552470070974, 12.655793717929296, 0.20433837813990458, 0.030565156135708094, 0.031038760008024316, 0.011016059284364539, 0.028933845992599214, 0.056154628550367694, 0.008488335679950458, 0.01549632168774094, 0.06208152337265866, 0.09021809750369617, 0.06314653158187866, 0.051056157132344585, 0.04831438371911645, 0.00961989036295563, 0.020496061171538064, 0.06522037887147494, 0.005065017945266196, 0.010046341140488428, 0.060496608061449866, 0.01953818685641246, 0.039972382597625256, 0.04438543186656066, 0.01654641060823841, 0.047817163435476165, 0.04690790954711182, 0.008286219605776881, 0.023939926642924547, 0.05021657521969505, 0.03413913239325796, 0.06950918837849583, 0.026091511993269836, 0.059630987367459705, 0.07238872136388506, 0.13996938429772854, 15.611815350396292, 62.114081382751465, 27.01165008544922, 41.959132535117014, 41.745687348502024, 60.51603044782366, 59.422835622514995, 59.97909450531006, 51.94315195083618, 56.56454821995327, 20.215794222695486, 0.03374886619193213, 0.2313612795301846, 11.810898848942347, 71.38552829197475, 55.791682720184326, 58.25240462166922, 46.63826833452497, 53.054797717503135, 47.11392116546631, 48.56559787477766, 46.252702372414724, 46.39969846180507, 41.520041125161306, 43.670466899871826, 42.233565534864155, 42.10079935618809, 40.75025715146746, 43.8969156401498, 41.48887498038155, 45.29369810649327, 43.04996149880545, 44.399607385907856, 47.393263067517964, 48.103990827287944, 44.94963720866612, 43.66021135875157, 44.08509022848946, 42.66529532841274, 41.04153953279768, 39.774097783224924, 39.81947646822248, 42.01218897955758, 41.970888887132915, 39.92930664334978, 40.330603327069966, 37.35901165008545, 40.577851499829976, 41.86042990003313, 44.14660957881382, 45.200373377118794, 39.80069201333182, 42.313744272504536, 41.38597910744803, 39.60982499803816, 38.35920831135341, 38.66428286688668, 34.89642415727888, 38.520792143685476, 36.683479990277974, 37.25455938066755, 37.422841276441304, 37.033683095659526, 36.71877336502075, 37.426718371255056, 36.60619517735073, 37.049264430999756, 36.2396742275783, 36.54637466158186, 37.87853193283081, 36.42360346657889, 37.21072319575718, 38.55141632897513, 36.542726857321604, 35.941707679203574, 36.36155605316162, 36.99389771052769, 37.09982647214617, 36.466459955487935, 35.85467801775251, 36.40650742394583, 35.93297379357474, 36.19850615092686, 34.39930486679077, 36.29766389301845, 38.045931407383506, 37.30891861234392, 39.55132116590227, 42.97341666902815, 40.20465680531093, 37.65831920078823, 37.83944136755807, 42.96144492285592, 38.14967843464443, 37.313104901994976, 36.1233092716762, 36.448363372257774, 36.51509734562465, 36.82417753764561, 37.99545969281878, 36.9888915334429, 38.085692473820274, 39.685362339019775, 40.72649431228638, 45.83116558619908, 49.81323031016758, 50.1205769266401, 51.54663910184588, 48.91919864927019, 50.59182807377407, 45.967867919376914, 45.831721442086355, 43.178121021815706, 42.665951933179585, 42.16913488933018, 40.97654955727713, 41.87073755264282, 43.45440571648734, 42.87587438310896, 46.79909828730992, 46.619053091321675, 47.34806156158447, 48.00693491527012, 47.32685565948486, 46.042286600385395, 45.954002789088655, 46.62611940928868, 52.95189837047032, 50.25340911320278, 51.84865297589983, 5.895261628287179, 0.6516570523381233, 6.4154819420405795, 40.891917024339946, 57.81000934328352, 48.474079677036826, 57.996662276131765, 47.86103664125715, 27.62823322841099, 29.192866802215576, 40.46422413417271, 16.61999375479562, 0.17043773723500116, 0.08805010348026242, 0.030123541796846048, 0.06760580944163458, 0.06692232111735003, 0.06113029191536563, 0.07696293627044984, 0.04627267524067845, 0.04782747377508453, 0.08586329368076154, 0.023818850550534468, 0.048284762272877355, 0.03378896761153426, 0.05357514375022479, 0.00817108663198139, 0.14095628634095192, 0.1646499420915331, 0.0672002083488873, 0.16389739247305052, 0.18463420974356787, 0.10149074904620647, 0.15187628966357025, 0.17377318468477043, 0.19797946007124015, 0.13813428633979388, 0.10956852523876087, 0.08305508829653263, 0.1301043943635055, 0.10643123715583767, 0.1014686898727502, 0.12226127593645028, 0.20591150729783944, 0.20381905457803182, 0.24853063108665602, 24.708954538617814, 69.63135133470807, 46.29426997048514, 53.70810209001814, 45.669984749385286, 67.18855231148856, 60.86249542236328, 66.92352022443498, 56.95063182285854, 61.953425134931294, 23.01133939198085, 0.2647244935589177, 0.2788341407264982, 13.616760849952698, 76.83837727137974, 58.492478779384065, 61.84199687412807, 49.191856384277344, 55.03498567853655, 49.136538301195415, 49.90516192572457, 51.33497960226876, 49.73809596470424, 44.245979240962434, 46.222852911267964, 44.61087083816528, 44.40663896288191, 43.431320326668875, 45.16784885951451, 43.981770515441895, 47.63858658926827, 44.8599568094526, 45.52877998352051, 48.36216851643154, 52.58003773008074, 46.09589890071324, 45.11990281513759, 44.63147572108677, 44.08734144483294, 42.96052776064192, 42.64463138580322, 40.18012966428484, 43.47396489552089, 42.984339237213135, 42.9387903213501, 43.442955085209434, 40.29444490160261, 41.60503149032593, 46.36359562192644, 46.48677676064627, 47.10815068653652, 41.56124741690499, 43.32693059103829, 41.81974472318377, 42.38077354431152, 41.37443814958845, 41.900058950696675, 36.50650242396763, 40.638544014522004, 40.02015086582729, 41.418065888541086, 39.48476784569876, 39.73639685767037, 39.35536112104143, 40.73706947054182, 38.535772459847585, 39.47765636444092, 38.01577622549874, 39.78006975991385, 40.294903482709614, 39.14246484211513, 39.63721479688372, 41.1274470601763, 37.5163049697876, 37.41417339869908, 39.04694448198591, 40.49347605024065, 41.032343591962544, 40.53190653664725, 37.26986626216343, 39.21168974467686, 38.82320901325771, 38.69426086970738, 35.488837991442, 38.744329588753835, 40.90472602844238, 39.6438364301409, 41.6161972454616, 44.29677057266235, 42.00783593314034, 38.98613384791783, 41.289479051317485, 45.46342175347464, 41.354204995291575, 39.39736645562308, 37.17834111622402, 39.142381463732036, 38.972188813345774, 37.987611702510286, 38.712996687207905, 40.202384744371685, 40.005841050829204, 41.9147926058088, 41.8661447933742, 49.472410746983115, 51.621231487819124, 51.52143798555647, 54.95556082044329, 51.17604650769915, 52.740725244794575, 48.46725307192121, 49.24003519330706, 45.47562626429966, 45.20289557320731, 43.694771698543, 42.828081199101035, 45.17851087025234, 47.55144228254046, 44.44686903272356, 49.555129051208496, 49.33016375132969, 48.91140277045113, 50.62183039528983, 50.27103321892874, 48.1741988999503, 49.40156691414969, 48.11190482548305, 56.21784700666155, 55.460403033665244, 57.474991525922505, 7.836420689310346, 0.8745060286351612, 7.45923946584974, 45.95035151072911, 62.57164805276053, 53.92944737843105, 65.64538519723075, 52.95866938999721, 34.17744541168213, 36.62467391150338, 49.05510193961007, 27.257187264306204, 0.2891991159745625, 0.18036921003035136, 0.10451588207589728, 0.13873690686055593, 0.20822060267840112, 0.1728616135993174, 0.15957246454698698, 0.10660822623010192, 0.2035640204059226, 0.1804192859147276, 0.10848832463047334, 0.20202483156962053, 0.18391969879823072, 0.1177315932831594, 0.13633726776710578], [0.037068042371954234, 0.040598541498184204, 0.03991732965888722, 0.06237882349107947, 0.13082984329334327, 0.040811021346598864, 0.015702654008886645, 0.06853254578475441, 0.030448173305818012, 0.024572937050834298, 0.036567544764173884, 0.016062374260010462, 0.09380163771233388, 0.019760364666581154, 0.08821488570954118, 0.02736277279577085, 0.0511657405378563, 0.012739926693029702, 0.09675651522619383, 0.5405676790646144, 29.237144197736466, 49.406520979745046, 44.03328445979527, 32.87969561985561, 42.1771114213126, 50.55497135434832, 56.2988942691258, 52.27584906986782, 48.2424441065107, 25.614653961999075, 0.680161711360727, 0.40890886953898836, 14.734256131308419, 66.75851440429688, 53.34845290865217, 58.79633740016392, 48.34288726534162, 47.94128833498274, 44.76012856619698, 43.809236322130474, 41.953164032527376, 42.962772028786794, 38.87314224243164, 40.6566927092416, 38.73637390136719, 39.908951895577566, 38.7425126348223, 39.53610461098807, 39.583901269095286, 38.34206015723092, 38.436180455344065, 39.765033858163015, 40.8781943321228, 38.065104961395264, 38.090403352464946, 40.0001608984811, 38.44727325439453, 39.43687391281128, 38.046386514391216, 39.34380626678467, 38.28182622364589, 38.12617267881121, 39.79561982836042, 38.02429471697126, 38.306891850062776, 37.682144573756624, 39.4026540347508, 40.74227019718715, 42.315953799656455, 42.35986988885062, 38.915078095027376, 37.08026729311262, 36.0409939629691, 36.32950053896223, 34.75607054574149, 35.21395683288574, 35.168185574667795, 33.246828011104036, 33.499367237091064, 34.08881071635655, 35.3361930165972, 35.32214028494698, 34.99616207395281, 33.320513657161165, 34.985284669058665, 35.557583468300955, 33.63779272351946, 35.121931416647776, 34.97244439806257, 37.44750043324062, 37.45854459490095, 37.08509976523263, 36.97938639777047, 36.474974972861155, 34.098350593021934, 35.16752896990095, 34.03702231815883, 34.16400064740862, 34.78953307015555, 34.60532590321132, 33.37679059164864, 35.04949644633702, 34.028747013636995, 33.66447033200945, 33.585403306143625, 35.39502688816616, 36.64847149167742, 36.57088443211147, 37.715711321149556, 36.58241496767317, 37.060325963156565, 39.70560938971383, 36.44780056817191, 34.920419761112754, 34.88516460146223, 35.57862261363438, 33.94191884994507, 35.407415526253835, 35.45134898594448, 35.500886167798726, 37.63730090005057, 36.52200732912336, 36.35399293899536, 36.26715782710484, 40.05408934184483, 43.26726988383702, 44.880474839891704, 45.558625970567974, 42.925418513161794, 42.64217867170061, 39.73815475191389, 41.07068027768816, 40.367147377559114, 39.84787375586373, 39.56686776024954, 41.24897105353219, 40.33859028135027, 42.49260480063302, 42.67165987832205, 44.18049594334194, 44.34852770396641, 44.51069865907942, 44.65187215805054, 43.769405773707796, 42.865882873535156, 46.194573743002756, 51.11488151550293, 49.505091599055696, 48.1811922618321, 3.5998338971819197, 0.41888078302145004, 4.869634560176304, 42.374659129551475, 48.367421354566304, 45.66388423102242, 51.76232508250645, 30.256858348846436, 25.48776248523167, 21.4735050201416, 30.217646190098353, 1.919157590184893, 0.2888593056372234, 0.06638814442391906, 0.02432662883906492, 0.0442600555584899, 0.01923286136505859, 0.03397214153249349, 0.05696928447910717, 0.04379927599802613, 0.013421292050874658, 0.03311626460137112, 0.032183869276195765, 0.038130000566265414, 0.026698241043569784, 0.07331958998526845, 0.024353451328352094, 0.0061447893801544395, 0.05044078354590705, 0.05403511246134128, 0.01962558555948947, 0.01938666998674827, 0.03409595042467117, 0.02286383626051247, 0.06982634243156229, 0.023073749550219094, 0.0689067646328892, 0.02954216960019299, 0.017779943167365024, 0.07220276205667428, 0.06542722348655973, 0.05466258093448622, 0.010673157371846693, 0.03530609727438007, 0.059441268976245604, 0.08590362580227, 1.2927386207239968, 37.02445936203003, 49.89130374363491, 44.4562143598284, 42.51376206534249, 46.60984672818865, 57.58907747268677, 60.91429424285889, 56.71771430969238, 54.50813504627773, 30.815781865801128, 0.6122714057564735, 0.562964817242963, 16.663442577634537, 70.36081491197858, 56.306415694100515, 62.12417016710554, 50.14942932128906, 49.325234004429404, 46.368084158216206, 47.560864039829795, 43.780175481523784, 46.02120576586042, 41.41812494822911, 42.588284969329834, 42.001117025102886, 42.82826880046299, 41.489059107644216, 42.10110855102539, 41.288825920649934, 40.81305149623326, 40.053623812539236, 41.23799984795706, 42.11586652483259, 39.88716581889561, 40.03990112032209, 41.515229497637065, 39.61238193511963, 41.04583351952689, 39.71853651319231, 41.74212639672415, 39.87588889258248, 41.05710697174072, 41.94240822110857, 40.88464226041521, 41.057072230747764, 38.3817378452846, 42.30174820763724, 41.286984648023335, 45.29328121457781, 43.931872027260916, 42.40793057850429, 39.05201666695731, 39.590168544224326, 39.5288541657584, 38.78785310472761, 37.97527517591204, 36.659442697252544, 35.410973003932405, 37.00854103905814, 37.06418221337454, 37.96880292892456, 38.205507210322786, 37.4601148877825, 36.20067398888724, 37.05533715656826, 38.08820424761091, 38.27049718584333, 38.71279866354806, 38.209898471832275, 38.82730497632708, 39.92496401923043, 38.82719727924892, 37.98799385343279, 38.0531644821167, 35.54389204297747, 37.157096999032156, 35.78045041220528, 36.01700530733381, 36.69274541309902, 36.798010621752056, 36.33059140614101, 36.18772602081299, 36.80433348246983, 35.90550409044538, 34.840654441288535, 36.10554272787911, 37.57710518155779, 39.93943016869681, 39.526755809783936, 38.198552063533235, 39.27533176967076, 42.33860492706299, 40.08042648860386, 35.48817791257586, 37.74185044424874, 37.19312340872628, 36.16469621658325, 37.809383460453574, 36.15284953798567, 38.16697597503662, 39.2089695249285, 37.28701441628592, 36.78792878559658, 39.39510134288243, 40.963820457458496, 45.17985187258039, 47.54935087476458, 47.2321378162929, 45.894432408469065, 44.888989857264924, 41.45687157767159, 42.743545940944124, 41.83774055753435, 41.01171439034598, 43.58961418696812, 43.122914109911235, 43.7335843358721, 44.820570945739746, 45.2583908353533, 45.037222726004465, 47.78984539849417, 46.36093098776681, 45.985724789755686, 45.45066486086164, 45.52890157699585, 48.92915889195034, 53.48307773045131, 52.69851841245379, 52.19544104167393, 4.181170131478991, 0.4714484651173864, 5.708669926439013, 48.50932094029018, 54.86819764545986, 52.275209835597444, 57.559165477752686, 36.0426059450422, 30.302574021475657, 26.71794104576111, 38.102750301361084, 3.071706099169595, 0.3544594741293362, 0.09488210973462888, 0.036883043191794834, 0.030912128410169055, 0.0609582086492862, 0.03564549370535782, 0.03030488028057984, 0.06960769809250321, 0.046517996183995686, 0.06453334180904285, 0.05568308403183307, 0.040103333070874214, 0.027650856712300862, 0.006307494444107371, 0.009656382824427314, 0.1380823241280658, 0.10252069056566272, 0.22596832391406807, 0.14737107498305185, 0.1687787598265069, 0.11433608191353933, 0.061512463193918974, 0.16904420272580215, 0.08153164825801339, 0.18167758839471, 0.10206763273371117, 0.12600658567888395, 0.2100389136799744, 0.11669540245618139, 0.2374392705304282, 0.1458297555467912, 0.18297455380005495, 0.17332460518394197, 0.17996366322040558, 1.7702353298664093, 48.767651489802766, 58.650487763541086, 59.9383989061628, 45.44418913977486, 53.704419544764924, 62.22693402426583, 65.07060241699219, 62.064241954258506, 60.99268381936209, 35.16638946533203, 0.6774805209466389, 0.4597434103488922, 18.564356803894043, 72.31304332188198, 60.426211084638325, 66.37045751299176, 53.94347926548549, 54.45255640574864, 50.172087396894185, 50.5147134917123, 45.79773085457938, 49.05774572917393, 44.599072796957834, 45.347206183842246, 44.88006837027413, 45.63289526530674, 44.60525321960449, 43.9414188521249, 43.383283955710276, 43.24481678009033, 42.340883936200825, 42.55335290091378, 44.68782908575875, 40.6821265901838, 41.98076575142996, 45.26004103251866, 42.553109713963096, 42.27797147205898, 40.88745280674526, 44.19183887754168, 41.52990409306118, 42.816119875226704, 45.214575495038716, 42.731449127197266, 42.43729019165039, 40.96183327266148, 43.7710941859654, 43.539538519723074, 46.975669384002686, 46.79054505484444, 45.10262959344046, 42.36255536760603, 42.4969231060573, 41.49382904597691, 39.382785660879954, 40.50494057791573, 39.637204374585835, 38.36830350330898, 39.15286976950509, 39.42434631075178, 41.225746699741904, 41.99027436120169, 40.87962218693325, 38.28934417452131, 39.45532832826887, 40.66786193847656, 39.549820355006624, 42.07026549748012, 39.84756108692714, 43.612505027226035, 42.077178955078125, 42.121581418173655, 42.60521078109741, 39.96111897059849, 37.034652369362966, 38.586998053959434, 38.15353468486241, 38.731739452907014, 38.231250286102295, 38.124505111149375, 36.93436207090105, 38.61225128173828, 38.27211959021432, 38.10374736785889, 37.53076764515468, 39.0172061920166, 41.404885155814036, 40.27672699519566, 43.01609250477382, 39.68782894951956, 40.887473651341026, 43.6560389654977, 41.20844568525042, 38.09806374141148, 38.702609130314414, 39.793931416102815, 38.33064774104527, 40.241520472935264, 37.85982043402535, 38.57822595323835, 41.38149404525757, 39.36524840763637, 38.676077433994834, 39.69698320116316, 43.40541744232178, 47.51112188611712, 48.96931253160749, 49.70379270826067, 48.0767365183149, 49.47886214937483, 43.68534299305507, 45.43497582844326, 44.329941272735596, 43.359878948756624, 45.80173649106707, 46.35826635360718, 45.23526723044259, 47.96558965955462, 47.8089668410165, 46.911190101078574, 50.70565693719046, 48.77077470506941, 49.563223702566965, 48.59315095629011, 47.794427735464915, 51.77822603498186, 57.79880884715489, 57.36691229684012, 56.14866031919207, 5.691807082721165, 0.45771600199597223, 7.440998707498823, 55.83209344318935, 58.81234604971749, 52.74862882069179, 64.0441450391497, 40.47557749067034, 40.553619657244, 32.76781225204468, 50.082004002162385, 7.2982722861426215, 0.7594318634697369, 0.27825480752757614, 0.13387015515140124, 0.13067597869251454, 0.12327270023524761, 0.09623854194900819, 0.1790600988481726, 0.1551655695906707, 0.14334774230207714, 0.15796995482274465, 0.10131987357246024, 0.13130070588418416, 0.1125250244513154, 0.13285935510482105, 0.08574665351105587], [0.035020498492355855, 0.06844715215265751, 0.07451178279838391, 0.012315774452872574, 0.09014240013701574, 0.07624742109328508, 0.026731104190860475, 0.019358332668031965, 0.04588456678071192, 0.056155958479004245, 0.028039999938170825, 0.08581243069576365, 0.05982082110962697, 0.026948347355106046, 0.03503219982875245, 0.00938234119010823, 0.0827459477420364, 0.10194611389722143, 0.0755566656589508, 0.03324944066948124, 15.893801042011805, 47.635004792894634, 48.82766308103289, 43.166072845458984, 30.054304463522776, 53.89401503971645, 55.51822246823992, 50.793798310416086, 48.815267494746614, 32.380116667066304, 1.473832669002669, 0.9354607292584011, 13.192978058542524, 64.93345192500523, 55.247225352696006, 57.95547335488455, 52.07685266222273, 47.75272464752197, 44.17092479978289, 43.033268451690674, 39.89873456954956, 37.68582017081124, 38.60346181052071, 39.73786640167236, 39.71025078637259, 39.959142208099365, 38.16413416181292, 39.63620383398873, 38.296181201934814, 40.477502141680034, 39.2756861277989, 40.24198947634016, 39.41204799924578, 40.049430574689595, 38.805084637233186, 38.9098356791905, 37.95537206104824, 39.45923668997628, 40.079554489680696, 39.58448144367763, 39.041295596531455, 41.58529165812901, 39.033458028520855, 40.24831581115723, 37.56920855385916, 39.936407702309744, 41.1025516646249, 39.840699740818565, 38.0367945262364, 38.83064011165074, 36.81314032418387, 36.514308725084575, 36.199166229793, 34.96544408798218, 35.24698856898716, 34.682659353528706, 34.44105659212385, 35.50468683242798, 35.65715115410941, 35.68662541253226, 34.41682127543858, 34.88090535572597, 36.173958165305, 35.43823773520333, 33.985984325408936, 32.43343366895403, 33.507041522434776, 35.35974740982056, 33.52161536897932, 36.52770137786865, 36.90212937763759, 36.389505181993755, 35.265873772757395, 34.00420250211443, 33.66518947056362, 34.287341594696045, 33.295107569013325, 34.68237795148577, 35.91925457545689, 33.3649126461574, 35.094069140298025, 34.96296010698591, 33.61077465329851, 34.568170411246165, 34.51335259846279, 33.81870297023228, 34.32708181653704, 34.55188730784825, 34.72196878705706, 36.697098459516255, 39.56498827253069, 38.11373192923409, 35.056948389325825, 35.12003108433315, 36.986775806971956, 35.87748547962734, 35.45838751111712, 36.01801627022879, 35.54351684025356, 34.56278903143746, 36.27289356504168, 37.30752549852644, 38.912222385406494, 37.92226389476231, 37.12905406951904, 36.39006798607962, 39.359992095402305, 39.960556166512625, 39.33065332685198, 38.997212750571116, 39.38381052017212, 37.40001991816929, 38.02320384979248, 38.72793878827776, 40.035898957933696, 40.00033112934658, 41.84351103646414, 39.83641617638724, 42.6230502809797, 42.930383001055034, 41.631087235042024, 40.47928435461861, 38.830278805324006, 41.441866942814414, 44.4580591065543, 49.64809594835554, 51.33822788511004, 52.10960647038051, 43.059761932918, 0.783953033387661, 0.3445256943149226, 8.227864827428546, 47.82539585658482, 37.59935678754534, 50.27823850086757, 42.81828771318708, 24.60241780962263, 30.464018889835902, 24.901273727416992, 15.919167178017751, 0.1998510496424777, 0.07203548281852688, 0.0705427872017026, 0.032040532146181376, 0.023263345805129836, 0.0181222148904843, 0.10376484559050628, 0.026246387611276338, 0.024477005769897784, 0.03758060093969107, 0.02708041401846068, 0.030334749392100742, 0.034538589351411374, 0.04346688204844083, 0.05730156986308949, 0.047250681689807346, 0.021844386588782072, 0.059568297517086775, 0.04120242070140583, 0.021379132089870315, 0.06517415706600461, 0.06064679500247751, 0.012808170352530266, 0.04083863432918276, 0.06859543241028275, 0.058788776131612916, 0.03701196484533804, 0.07114561128297023, 0.04874986410140991, 0.04081255144306591, 0.01420258017190333, 0.029332241043448448, 0.08445762018007891, 0.05135872946786029, 0.07128512486815453, 0.10011281405708619, 21.581818750926427, 57.59574426923479, 49.78466279166085, 50.63881179264614, 37.042764391217915, 56.8447516986302, 60.546255111694336, 57.331716196877615, 54.00518274307251, 36.210540430886404, 1.5611438410622733, 0.8248843284589904, 14.736642837524414, 66.42015102931431, 57.84684174401419, 61.47875199999128, 53.374105657849995, 50.22500140326363, 45.77459682737078, 45.269573960985454, 42.92108631134033, 42.42956032071795, 40.4506265095302, 42.080152784075054, 40.70638622556414, 40.68730994633266, 40.4311854498727, 40.501598494393484, 40.383972440447124, 41.46772813796997, 41.73981959479195, 43.2919533593314, 41.255992208208355, 41.826637336185996, 40.7318548474993, 40.57559680938721, 42.0186299596514, 40.08879211970738, 41.14960486548287, 41.02994646344866, 40.327386311122346, 42.89753539221627, 40.758949347904746, 40.8224767276219, 39.60554838180542, 40.33746119907924, 42.50803327560425, 42.16095338548933, 40.01696859087263, 40.123074531555176, 40.42579712186541, 40.071126324789866, 39.61555726187569, 37.76387275968279, 39.291090284075054, 38.28790242331368, 37.56233331135341, 38.9888471194676, 37.78275796345302, 37.87251131875174, 37.951091970716206, 38.75102417809622, 38.930051462990896, 37.68511840275356, 37.05270726340157, 34.50266974312918, 36.58720575060163, 37.352122511182515, 37.107695307050435, 38.57996300288609, 39.6858799798148, 39.29785782950265, 37.32248497009277, 36.837945393153596, 36.87038653237479, 35.10153497968401, 36.392326150621685, 36.7778400012425, 36.948609352111816, 35.470202922821045, 35.53319181714739, 36.204214096069336, 34.52276740755354, 37.03816468375069, 35.88618115016392, 36.08076892580305, 36.48582458496094, 35.91894885471889, 37.36930193219866, 38.98993451254708, 40.91637468338013, 39.110506602696006, 37.06058652060372, 37.043664182935444, 39.42498207092285, 36.17278044564383, 36.46675525392805, 38.26645680836269, 37.05784545625959, 36.5963773727417, 38.29790088108608, 39.50697428839547, 39.91849177224295, 39.63497747693743, 38.19754457473755, 38.57470669065203, 41.85043839045933, 41.96041100365775, 42.29057897840227, 41.53734908785139, 40.996824400765554, 41.291733741760254, 38.793644428253174, 40.689394405909944, 41.96921784537179, 42.03765065329415, 44.7675770350865, 41.805490493774414, 45.07417672021048, 44.70538023539952, 43.447124004364014, 42.67353936604091, 42.68644911902291, 43.02306849615914, 47.19609751020159, 53.289990765707834, 56.12044021061489, 55.073318890162874, 45.87498787471226, 1.0366088045494897, 0.23102513328194618, 9.188067657606942, 55.53435271126883, 41.51694917678833, 55.60123954500471, 47.65969869068691, 32.413749422345845, 37.42105211530413, 31.045322554452078, 24.904730456215994, 0.3201339345957552, 0.09772788560284035, 0.012183733234581138, 0.038123361101107936, 0.0566375792425658, 0.019484424830547402, 0.032648136506655386, 0.009735830793423312, 0.053822859922157865, 0.0020915341530261295, 0.014601934501635177, 0.043960129509546926, 0.049068124166556766, 0.04672072548419237, 0.055185297171452215, 0.05465863864602787, 0.201968377456069, 0.19201569365603582, 0.14956635289958545, 0.05690444367272513, 0.16554294845887593, 0.13241180697722094, 0.08146441222301551, 0.15825132972427777, 0.20785445161163807, 0.21517441953931535, 0.2016589112047638, 0.20235250970082624, 0.08589329171393599, 0.15015008300542831, 0.12161286787262984, 0.13313272329313414, 0.1667362879961729, 0.14708166622689792, 0.20630163779216154, 0.1875469705888203, 28.299993753433228, 65.79011617388043, 57.94860506057739, 58.29458713531494, 41.208761828286306, 65.46436377934047, 65.91348838806152, 62.33895983014788, 60.39304733276367, 43.32890040533883, 1.8424978979996272, 0.8417608514428139, 16.183568716049194, 69.71786335536412, 60.53009360177176, 65.7866907119751, 58.57467596871512, 53.99045256205967, 48.993127482278005, 48.60161733627319, 44.304566451481406, 45.33435549054827, 44.39515706471035, 45.31167657034737, 42.796508584703716, 43.48206649507795, 43.58636590412685, 43.60186733518328, 41.869274956839426, 44.79215976170131, 43.42364951542446, 44.09296948569161, 43.49766520091465, 43.84362990515572, 42.62952947616577, 43.39838239124843, 43.44750962938581, 43.127142088753835, 45.34779330662319, 45.0031487601144, 41.42698390143258, 46.5610043661935, 43.744315828595845, 44.283033984048025, 43.062287603105815, 43.71141610826765, 43.2811940738133, 43.68273741858346, 41.98828717640468, 42.181957789829795, 41.52666623251778, 42.33133363723755, 42.49172932761056, 39.36733981541225, 41.0485189982823, 40.23046588897705, 38.172055108206614, 41.09860856192452, 39.91975287028721, 41.060702664511545, 40.81930487496512, 41.684511934007915, 41.76022645405361, 39.28841175351824, 37.77694232123238, 36.622457436152864, 38.36987379619053, 40.51002318518502, 38.58788742337908, 40.99135269437517, 41.43268142427717, 42.682106494903564, 39.58253594807216, 38.61585392270769, 39.72104133878435, 37.92023154667446, 37.81733567374093, 38.54551730837141, 38.557860783168245, 36.2958573613848, 38.591347626277376, 39.31366845539638, 35.507254191807334, 38.0688465663365, 38.341844763074604, 36.87394748415266, 38.58002553667341, 37.871142523629324, 39.26481567110334, 40.265978131975444, 43.50935901914324, 40.563253334590364, 38.769179821014404, 39.51242167609078, 42.10623632158552, 39.26456206185477, 40.21271671567644, 40.46644408362252, 39.396737643650596, 37.74035310745239, 41.01718609673636, 41.65015309197562, 42.85356371743338, 42.59195014408657, 40.47573382513863, 40.979690143040244, 45.1193573815482, 43.97657673699515, 44.4495336668832, 44.412381649017334, 44.4858067376273, 42.56075273241316, 42.643099308013916, 44.794348444257466, 43.66685036250523, 44.56147609438215, 47.39703246525356, 45.09708840506417, 47.57411078044346, 48.00350945336478, 45.809938839503694, 45.93883834566389, 43.96348980494908, 46.45520414624895, 49.19222116470337, 55.532469749450684, 58.767759459359304, 59.50807612282889, 50.05086217607771, 2.4609729051589966, 0.5095902755856514, 10.914379732949392, 59.51399598802839, 47.398210184914724, 61.11463860103062, 53.138099670410156, 37.110491956983296, 44.49663550513131, 39.66293355396816, 39.51642731257847, 0.5710900298186711, 0.16901258299393312, 0.12608410151941435, 0.1271130455923932, 0.1507686355284282, 0.0917264333527003, 0.17110399076981203, 0.14036602872822965, 0.17630625090428761, 0.154440487069743, 0.12158242879169327, 0.10365893305944544, 0.1759904199945075, 0.3552226631769112, 0.15668364241719246, 0.1578343835260187], [0.07521863308336053, 0.01259806876935597, 0.03459217665450914, 0.02326320670545101, 0.051448866059737544, 0.05338980869523116, 0.030071036757103035, 0.028979745493935685, 0.037997313043368716, 0.030801350783024515, 0.11320148993815694, 0.019599809710468565, 0.0304020431025752, 0.07744458078273705, 0.03674663729699595, 0.06266110762953758, 0.05589672756780471, 0.06923446312014546, 0.040362842181431394, 0.04977032309398055, 0.9399606649364743, 41.66353184836251, 44.8852413041251, 39.21690436771938, 30.03785112925938, 41.991212368011475, 57.82609094892229, 51.011485372270855, 53.03566237858364, 40.388860498155864, 1.6082361255373274, 0.6230076753667423, 4.114456568445478, 60.34801605769566, 58.398219517299104, 59.4029220853533, 56.07440492085048, 51.10688066482544, 42.931876863752095, 43.132012775966096, 41.196025780269075, 40.89154529571533, 41.336316858019146, 39.996940408434185, 39.69552060535976, 39.67963702338082, 38.61648620877947, 39.20547110693795, 39.38960879189627, 39.99683965955462, 39.63507127761841, 40.398723466055735, 40.319420201437815, 39.92649957111904, 38.87992368425642, 39.21969059535435, 37.82675395693098, 39.55587223597935, 37.6900828906468, 37.802654130118235, 39.76183073861258, 40.00809574127197, 39.545894622802734, 38.382446561540874, 39.44228655951363, 39.60257455280849, 40.29716512135097, 40.439634459359304, 38.96620988845825, 38.00614602225167, 36.76079954419817, 35.470084803445, 35.17567573274885, 36.39479276112148, 36.4664113180978, 36.262446948460166, 37.63213491439819, 35.45726537704468, 36.368632793426514, 35.149960449763704, 36.96724789483206, 36.082915919167654, 36.002876145499094, 37.48768186569214, 42.196621962956016, 47.48444775172642, 47.52659205027989, 47.579756191798616, 46.77035706383841, 44.17818219321114, 42.28532614026751, 41.39150987352644, 41.83089310782296, 44.21219709941319, 43.216554982321604, 42.75912727628435, 37.30084480558123, 34.69355412891933, 32.87581157684326, 34.03793600627354, 34.59771762575422, 34.45066595077515, 35.07329055241176, 34.73123073577881, 35.56586572102138, 33.701716150556294, 34.12957579748971, 35.63989182880947, 33.30346972601754, 34.208347524915425, 35.18506622314453, 36.048074177333284, 35.57421398162842, 36.2735710144043, 37.40490797587803, 34.41429213115147, 34.37414196559361, 35.28710051945278, 35.88409669058663, 36.56719146456037, 35.59647600991385, 35.664207049778526, 35.484481470925466, 35.57079894202096, 35.13990640640259, 37.357747077941895, 35.787551471165244, 35.866135597229004, 36.32208333696638, 36.17098086220877, 35.99691459110805, 36.65206371034895, 36.22971051079886, 37.575097152165, 38.2776712008885, 39.71826205934797, 38.90588215419224, 40.433770179748535, 40.72673055103847, 41.781171798706055, 39.557574544634136, 38.50365093776158, 38.965560231889995, 45.820969104766846, 46.596825804029194, 54.86233336584908, 49.840491567339214, 60.174811363220215, 30.472339357648575, 0.10422204927142177, 0.09358015709689685, 11.658246057374136, 48.43654203414917, 38.05643360955374, 59.123416900634766, 32.284075192042756, 26.192749295915874, 25.806455510003225, 28.05731749534607, 8.513024977275304, 0.2784501170473439, 0.001499609146516637, 0.05776769627950021, 0.09199508572263376, 0.0582068780703204, 0.020867024747920886, 0.05878800938704184, 0.0328286098582404, 0.02648060263267585, 0.04179127713931458, 0.05159653902852109, 0.02347347452970488, 0.013012526440434158, 0.031667989279542647, 0.006168842174312366, 0.03387515852227807, 0.022566648100369742, 0.05542011439268078, 0.03423711284995079, 0.023947707743250897, 0.025928302268896784, 0.031442484951445034, 0.010700363233419401, 0.019963567244953344, 0.04127696116587945, 0.04606935561501554, 0.064883486234716, 0.05509287052388702, 0.037564132894788466, 0.01252826363114374, 0.09608080969857317, 0.010310801012175424, 0.07497743424028158, 0.054151389614811966, 0.04843362607061863, 0.039865635468491485, 2.7308698168822696, 51.78237410954067, 49.24804994038173, 44.96721615110125, 39.92057275772095, 47.08014249801636, 62.112802914210725, 55.77911690303257, 57.74079486301967, 44.833046436309814, 1.7683657216174262, 0.8904737489564079, 5.231253121580396, 62.48173141479492, 58.170172691345215, 62.27020045689174, 59.325171743120464, 52.211147444588796, 46.269812311444966, 45.55217456817627, 42.9237231527056, 43.12781606401716, 44.554885728018625, 42.90944113050188, 41.55834654399327, 43.00212662560599, 41.77215651103428, 41.64159985951015, 41.47250502450125, 42.147949831826345, 42.197233404432026, 41.58377000263759, 42.011424677712576, 40.76540422439575, 39.68067230497088, 39.787056173597065, 40.64717020307268, 42.50884621483939, 40.29630354472569, 40.594381264277864, 41.570676122392925, 40.28003086362566, 41.2433569090707, 40.81684173856463, 40.726011412484304, 40.3982127734593, 41.632348333086284, 41.350835118974956, 40.27948890413557, 40.44484560830252, 38.82946239198957, 37.92807258878435, 38.56538915634155, 40.174432141440256, 38.56953375680106, 38.73273304530552, 39.13431460516793, 37.09900311061314, 37.6063814163208, 37.684367997305735, 38.2890419278826, 37.54403175626482, 40.10778849465506, 39.47239657810756, 42.68396166392735, 47.09203086580549, 48.319246019635884, 47.19213008880615, 46.412031514304026, 43.655872208731516, 42.449522495269775, 41.416829109191895, 42.86251299721854, 43.10016223362514, 42.233555112566265, 41.71993037632534, 38.92034135546003, 36.545137882232666, 35.089729990277974, 37.2006378855024, 37.32231821332659, 36.380680969783235, 35.85418816975185, 36.99605165209089, 37.23155736923218, 35.69124249049595, 36.16968502317156, 37.53179250444685, 35.27953740528652, 36.621644496917725, 37.801153319222585, 37.056087562016074, 37.187752451215474, 38.978973729269846, 37.97972549710955, 35.78460543496268, 36.67048338481358, 36.57491091319493, 38.37134681429182, 38.91049575805664, 37.858305726732524, 37.659149510519846, 36.8160411970956, 37.47245141438076, 37.289547034672324, 38.929089137486045, 37.355370794023784, 38.21660695757185, 38.258091177259175, 37.90533113479614, 38.58442027228219, 39.05919763020107, 38.67412151609148, 40.43664673396519, 41.577930041721885, 42.10685471126011, 41.66651609965733, 43.93944556372506, 42.97597360610962, 44.156799112047466, 39.903883184705464, 40.514932087489534, 40.74654681341988, 48.56168951307024, 49.44134882518223, 56.60073791231428, 51.75087097712925, 63.17603015899658, 30.596527985164098, 0.12737255809562548, 0.06863617843815259, 14.26674745764051, 53.467642307281494, 42.26529795782906, 63.63795334952218, 35.25811610903059, 34.58751767022269, 31.198589393070765, 37.04716954912458, 15.563101530075073, 0.33607177223478046, 0.013424736464263072, 0.05627455622223871, 0.05025808459946087, 0.023133323228518878, 0.05609088018536568, 0.03453785992626633, 0.02553725235962442, 0.03129158215597272, 0.042175775792981894, 0.09679213831467287, 0.0589791527017951, 0.004049797667123909, 0.060160977499825616, 0.032890604210219214, 0.024833204424274818, 0.12279953062534332, 0.13829458345259937, 0.1211123668721744, 0.06295335944741964, 0.0929232741306935, 0.11768337658473424, 0.06309190272752728, 0.15140093517090591, 0.19742797394948347, 0.28684864352856365, 0.2332543922322137, 0.1179616709372827, 0.1529736164957285, 0.22472907469740935, 0.10211344741817031, 0.11906357109546661, 0.16405578968780382, 0.11313228615160499, 0.09617331437766552, 0.12292964650051934, 4.025738928999219, 64.69396141597203, 54.75829798834664, 52.959100178309846, 42.63840232576643, 52.741520813533235, 67.30417728424072, 61.975687163216726, 63.078685896737234, 53.21048600333077, 2.6575213755880083, 0.9197973183223179, 6.255371127809797, 64.48837116786412, 61.46122864314488, 65.47332695552281, 62.32789829799107, 58.095337118421284, 48.24032490594046, 48.69792284284319, 44.971854073660715, 45.11693246023995, 46.701041834695, 45.21084083829607, 43.79816436767578, 44.66401760918753, 42.709187098911826, 42.42369256700788, 42.96246978214809, 43.402516569410054, 43.3789587020874, 45.29948248182024, 44.01460075378418, 43.17219420841762, 42.39276960917881, 43.484109265463694, 42.16376045772007, 43.92016083853585, 42.18822159085955, 42.67694398335048, 45.06816305433001, 43.5714168548584, 44.66333321162632, 41.304452419281006, 44.673008578164236, 41.313054289136616, 43.22701549530029, 43.401008810315815, 41.28805119650704, 42.691427503313335, 40.58859688895089, 40.01709713254656, 40.61665718896048, 42.04965019226074, 42.308408055986675, 41.78253017153059, 43.13443769727434, 39.40725026811872, 39.64166511808123, 40.02359369822911, 42.04463011877877, 39.000940459115164, 41.51959296635219, 40.82855987548828, 46.937200682503835, 52.857208320072715, 52.75835977281843, 51.274214131491526, 50.404817308698384, 49.31367220197405, 44.8625693321228, 43.95533956800188, 46.98636613573347, 47.28131021772112, 46.27689252580915, 44.81711769104004, 41.38087565558297, 38.30261523383004, 34.42844213758196, 39.79638065610613, 39.47877155031477, 37.58615173612322, 39.339147499629426, 39.283888476235525, 38.71742268971035, 39.06934200014387, 38.203037125723704, 41.20175804410662, 37.04993840626308, 39.73907538822719, 39.86060980388096, 39.38942119053432, 38.919330392565044, 40.19598197937012, 41.239837646484375, 38.65753616605486, 38.95709385190691, 39.20465121950422, 39.82521220615932, 40.4943584714617, 39.829374177115305, 38.9213627406529, 38.76167229243687, 39.66766875130789, 38.98162794113159, 41.52868468420846, 40.127979959760395, 40.47529261452811, 39.766201155526296, 41.02448170525687, 42.437978063310894, 40.27631705147879, 40.41741759436471, 42.955552850450786, 44.289311681474956, 45.692924227033345, 43.962468419756206, 46.21499102456229, 45.84280034473964, 46.69600091661726, 43.42142261777605, 43.10790947505406, 43.32527344567435, 51.13175521578108, 51.3500155040196, 59.20910208565848, 55.33438702992031, 64.71360397338867, 36.020642689296174, 0.21089114009269647, 0.36740266531705856, 16.567672082356044, 61.268874713352744, 48.248534202575684, 70.70058877127511, 42.74461596352713, 43.56610843113491, 38.879388672964915, 46.77575581414359, 24.204159225736344, 0.4461099590573992, 0.12560145956064972, 0.14362647091703756, 0.1643882311348404, 0.17345108411141805, 0.18200777710548469, 0.2519331585083689, 0.14196183452648775, 0.1573843519602503, 0.1649842970073223, 0.11145530720906598, 0.20950193463691644, 0.1352716013789177, 0.168477381712624, 0.19819688983261585, 0.09161387117845671], [0.03058079636788794, 0.0392573661436992, 0.07414995399968964, 0.03611237329563924, 0.025773596284644942, 0.01352710195351392, 0.04855800832488707, 0.023289296376918043, 0.05854574524398361, 0.05938525591045618, 0.05250150118289249, 0.02813003644613283, 0.023588915388765078, 0.06466114387980529, 0.06458288165075438, 0.04687767063400575, 0.06147899106144905, 0.04587199691949146, 0.08545438812247344, 0.0970398782353316, 0.06129370350390673, 18.523829698562622, 52.76134055001395, 26.784912994929723, 30.773550714765275, 32.93477399008614, 48.18756028584072, 61.730075291224885, 46.379006726401194, 51.64912155696324, 2.07487062897001, 0.05793587796922241, 0.13740365340241364, 32.53876141139439, 70.32961055210659, 54.37917300633022, 60.94376850128174, 52.17362369809832, 48.70496484211513, 42.57298156193325, 44.45384849820818, 40.56897170203072, 44.29268503189087, 45.00502477373396, 42.4568042073931, 40.19829225540161, 40.52284261158535, 39.76855659484863, 40.0818578175136, 40.28747933251517, 42.899067470005576, 37.64355775288173, 39.24176154817854, 41.86708280018398, 41.50482109614781, 38.553632804325645, 40.99263116291591, 40.94181203842163, 38.439859526497976, 39.33031633922032, 39.324955804007395, 40.93874788284302, 40.29407317297799, 39.090672969818115, 39.620000634874614, 41.081394399915425, 39.96891137531826, 38.97883823939732, 41.42007391793387, 39.81316402980259, 36.380236285073416, 36.33233540398734, 36.89246790749686, 36.278045654296875, 36.81290061133248, 36.90955352783203, 38.54958895274571, 39.12742894036429, 38.24832201004028, 39.23320484161377, 38.560442038944785, 37.674275738852366, 37.77943672452654, 37.747214453560964, 42.678601128714426, 51.41855253492083, 54.36949416569301, 55.68404817581177, 56.12220505305699, 55.3791230065482, 50.73389094216483, 51.66684988566807, 54.75509486879621, 57.06115681784493, 54.459928444453645, 47.674640791756765, 39.90880250930786, 38.115013871874126, 37.27521637507847, 35.618296827588765, 36.999741145542686, 37.77467026029314, 35.31393793651036, 36.171324798039024, 34.28964492252895, 36.10000153950283, 35.921943528311594, 35.72583062308175, 34.12736974443708, 35.1093100139073, 35.436827250889365, 36.772903306143625, 35.893080711364746, 36.26299238204956, 37.01301915305001, 36.2918586730957, 34.965277331215994, 35.70585107803345, 36.38472829546247, 36.45743077141898, 37.40776021139962, 36.575303486415315, 37.552345275878906, 34.43205520084926, 35.31799915858677, 35.76784985406058, 37.42410237448556, 36.36520733152117, 35.7803635597229, 37.345552989414756, 35.14267873764038, 35.005778380802695, 36.21026250294277, 36.78251266479492, 35.03700358527047, 37.11170441763741, 37.802928583962576, 38.3774334362575, 36.513818877083914, 37.44424867630005, 37.61450038637434, 39.02169472830636, 43.278116021837505, 51.81614930289132, 51.19271871021816, 55.85148933955601, 55.10708713531494, 59.27961240495954, 4.498605532305581, 0.27730909255998476, 0.20875087779547485, 18.80599778039115, 60.891198430742534, 42.322832516261506, 50.89956726346697, 22.749536480222428, 31.347127982548304, 26.372097934995377, 30.780408586774552, 3.4511077063424245, 0.22754667779164656, 0.025342743511178663, 0.02303501537867955, 0.05053871311247349, 0.006907834239037973, 0.04836850367220385, 0.02881107186632497, 0.005371250977207507, 0.030198872754616395, 0.0406859944840627, 0.04963072469191892, 0.01774037439775254, 0.06529883109033108, 0.005678967880417726, 0.07911488972604275, 0.07469250381525074, 0.029468911566904614, 0.038574081379920244, 0.07202784929956708, 0.02523417621185737, 0.01598563025306378, 0.03958217407177601, 0.057215409486421516, 0.04573347060275929, 0.03897657138960702, 0.06460406551403658, 0.11099973201219525, 0.026014343901936497, 0.0791685279192669, 0.0783801923639008, 0.013066487785960947, 0.07677186759454863, 0.04431205169696893, 0.08298501598515681, 0.03852040247459497, 0.02378929695779724, 0.05338715901598334, 25.025292124067033, 59.74735818590437, 26.862694604056223, 38.303143296922954, 39.04268871034895, 55.62540537970406, 65.83976800101144, 52.42932782854353, 57.2593263898577, 2.486692313637052, 0.13536199581410202, 0.09626360703259706, 32.99495928628104, 71.25338050297329, 56.94449308940342, 63.2129876273019, 53.5216714995248, 49.61902468545096, 45.25797394343785, 46.644983768463135, 42.11761399677822, 45.74321528843471, 45.716103417532786, 44.977089541299, 41.41104473386492, 42.4885435785566, 42.762222698756624, 41.653564657483784, 42.20774602890015, 43.86992188862392, 41.15714018685477, 41.1623409135001, 43.05818816593715, 42.93000085013253, 41.5536321912493, 42.56253147125244, 41.41617597852434, 39.8327579498291, 41.60708120891026, 42.42409208842686, 43.222242082868306, 40.952474049159456, 41.19859661374773, 40.76614073344639, 42.97153718130929, 42.343979358673096, 41.78585488455636, 43.261687006269185, 42.99047449656895, 38.18756696156093, 38.601210594177246, 39.62938070297241, 38.67798471450806, 39.544101987566265, 39.16229500089373, 39.83320263453892, 41.76364149366106, 40.42942060743059, 40.74528571537563, 40.76234006881714, 40.83500780378069, 40.99948556082589, 39.89068160738264, 45.274684361049104, 54.804180417742046, 55.597376346588135, 57.31491545268467, 57.56185443060738, 56.39564446040562, 50.40787104197911, 51.92982530593872, 57.27650581087385, 57.356927735464915, 56.37158284868513, 50.58107921055385, 40.690888268607004, 38.95231349127633, 37.73229667118618, 37.358424527304514, 37.84468725749424, 37.98316485541207, 37.37466246741158, 37.40727036339896, 37.93489224570138, 37.557712759290425, 37.34738383974348, 38.91604042053223, 35.61530910219465, 38.427998951503206, 37.26552363804409, 38.56023359298706, 37.275838238852366, 38.391468797411235, 38.250670501164024, 38.25818845203945, 37.31609957558768, 39.76337671279907, 38.63720573697771, 37.93243605749947, 39.4716739654541, 38.99792841502598, 39.709090437207905, 36.98908608300345, 37.41990218843733, 37.939471108572825, 38.1852080481393, 38.25583301271711, 37.75674390792847, 36.97818783351353, 36.570345946720664, 36.10123831885201, 37.50015388216291, 39.26968288421631, 37.54670333862305, 39.92978606905256, 40.05168873923165, 40.77446467535836, 38.189609731946675, 40.35994209562029, 38.11969348362514, 41.286658082689556, 45.35791335787092, 54.220399720328196, 53.99854721341814, 57.896236487797324, 57.30753993988037, 60.163464954921174, 4.069828288895743, 0.32895459128277643, 0.45179567539266174, 22.275603328432354, 64.93756525857108, 46.544346060071675, 55.99208613804409, 29.37962395804269, 37.897910458701, 27.786766801561626, 41.3114457811628, 5.608964145183563, 0.29540263595325605, 0.09068921115249395, 0.01657069198388074, 0.03725858857589109, 0.025316467242581502, 0.11035075397895915, 0.03818322824580329, 0.02882726849722011, 0.03070682067690151, 0.08620648990784373, 0.023390689864754677, 0.11625332332083158, 0.03824265095006142, 0.08656092946018491, 0.0599501838109323, 0.015967128299442784, 0.10101653449237347, 0.11499025752501828, 0.12480399092393261, 0.12322851403483323, 0.08180984761565924, 0.130518517856087, 0.145619803241321, 0.1316788127379758, 0.1796183567494154, 0.14705892173307283, 0.2247794491371938, 0.15324560047260352, 0.13895889637725695, 0.17220297322741576, 0.1135628234062876, 0.20695768616029195, 0.17853986604937486, 0.16406043086733135, 0.1615120161856924, 0.2866726044033255, 0.24475740641355515, 32.10530151639666, 67.04953970227922, 36.97492218017578, 46.23154163360596, 43.94082130704607, 58.23896680559431, 72.20561027526855, 57.42183085850307, 64.3900124686105, 3.7172228438513617, 0.31542970559426714, 0.23437077232769557, 35.40056112834385, 74.91483102525983, 60.08525603158133, 67.30468450273786, 58.50458254132952, 53.8357891355242, 46.38972084862845, 49.067775453839985, 44.553631578172954, 49.73004995073591, 49.81835460662842, 48.62659611020769, 44.34298651559012, 44.6568192754473, 44.827206475394114, 44.09583214351109, 46.31403412137713, 46.40547241483416, 42.35814673560006, 42.78407825742449, 45.95051826749529, 45.059526443481445, 43.417298861912315, 45.362857001168386, 44.199228286743164, 42.97730071204049, 44.116801806858604, 43.41274084363665, 44.70616538184029, 44.930786745888845, 42.691437925611226, 42.76409176417759, 45.56586946759905, 42.411970955984934, 41.922800404684885, 46.73418474197388, 45.28968552180699, 41.10996886662075, 41.34458521434239, 43.34598255157471, 39.834946632385254, 41.800963742392405, 41.799591473170686, 43.313968726566856, 45.23207800728934, 43.81415217263358, 43.794026715414866, 42.356798785073416, 43.62485892432076, 42.216191564287456, 41.68977172034127, 46.050732135772705, 56.27613197054182, 56.83638606752668, 59.47980390276228, 61.206611905779155, 58.209968498774934, 51.59398065294538, 53.29311398097447, 59.523209299360005, 60.0872779573713, 57.10380833489554, 49.99646125520979, 43.98220477785383, 41.59188549859183, 40.26586348669869, 39.50117254257202, 39.823791299547466, 40.99804728371756, 38.977650097438264, 38.90286316190447, 39.66244718006679, 40.26307031086513, 38.98482411248343, 40.56441020965576, 38.20687600544521, 39.233406339372905, 40.170805181775776, 42.05201257978167, 39.37937062127249, 40.21543346132551, 40.848449093954905, 40.11623750414167, 38.69244738987514, 41.549803733825684, 41.07228531156267, 40.33108970097133, 41.64047425133841, 41.0482063293457, 42.08330379213606, 38.330936091286794, 38.87872511999947, 39.57097067151751, 41.37617519923619, 40.772324630192344, 39.998913696834016, 40.12778541019985, 39.2991224016462, 40.18440628051758, 40.21387011664254, 42.32635872704642, 39.8296833719526, 42.19094181060791, 43.370124067579, 43.33342368262154, 41.15244320460728, 42.92727368218558, 42.23813050133841, 42.72534513473511, 46.15206118992397, 57.01577465874808, 56.66141653060913, 60.15782996586391, 58.41916833605085, 63.42807606288365, 6.071910892214094, 0.49745823230062214, 0.6724322746906961, 25.441060168402537, 73.4463778904506, 51.2796893119812, 61.53697790418352, 34.266521317618235, 46.84718329565865, 33.58347865513393, 55.53990432194301, 8.565325805119105, 0.49658313925777164, 0.22297522452260765, 0.10464389449251549, 0.10895706340670586, 0.12098784212555204, 0.14271242996411665, 0.14422914572060108, 0.060786084671105654, 0.08817045523652009, 0.18936731719544955, 0.09258917705821139, 0.1696948499551841, 0.1809097853090082, 0.18977004129971775, 0.17202405711369856, 0.1220955912555967], [0.04026113317481109, 0.051933075434395244, 0.049411944645856104, 0.007738485782673317, 0.059386368707886765, 0.032240309819046936, 0.03800224938562938, 0.014129937909144377, 0.06788004615477153, 0.0406580354486193, 0.04953294101038149, 0.032843666550304206, 0.0053579936751962775, 0.018699371688334004, 0.030529129318892956, 0.041147289731140645, 0.03571241422157202, 0.06041517707386187, 0.0502714245979275, 0.035317876642303805, 0.17401931647743496, 0.831596451146262, 37.681005069187705, 50.44693728855678, 27.63584324291774, 34.19536134174892, 24.29620722361973, 58.995438030787874, 47.173832007816856, 52.09367772511074, 14.763278756822858, 0.38571404559271677, 0.04271102457174233, 1.9066838366644723, 64.97019399915422, 58.297574860709055, 60.69349438803536, 53.93843139920916, 50.79111977985927, 45.69674573625837, 51.335525035858154, 52.74021455219814, 55.6164665222168, 54.1296249798366, 54.98586538859776, 47.46112959725516, 46.09990106310163, 41.63970994949341, 42.6316625731332, 40.26004784447806, 42.654084409986226, 42.95240184238979, 45.059894698006765, 41.861736161368235, 43.8873792375837, 41.95680488858904, 41.322135584695, 39.92842074802944, 39.55264479773385, 39.56966093608311, 42.11133977345058, 39.28638287952968, 40.571744033268516, 38.364860670907156, 38.501034940992085, 39.144052505493164, 42.20755842753819, 41.41033254350935, 39.21951341629028, 38.14945609228951, 38.308684485299246, 36.58063275473458, 37.47951078414917, 38.04925264630999, 36.621130330221995, 37.09417758669172, 37.24240698133196, 37.916566371917725, 40.05766071592058, 40.500914096832275, 40.041429724012104, 37.32025807244437, 36.84939949853079, 38.7863245010376, 42.80962330954415, 44.1676869392395, 47.02834020342146, 52.430071285792756, 51.07182700293404, 53.74989897864205, 48.575155121939524, 50.70116145270211, 52.54718664714268, 51.6032634462629, 45.49675921031407, 40.90328427723476, 41.804357937404085, 38.679252760750906, 37.061628750392366, 39.633334227970664, 38.99217530659267, 37.62731981277466, 37.5229891368321, 35.18641069957188, 36.435887881687705, 38.10191304343087, 36.701771123068674, 36.63568333217076, 35.89512348175049, 34.1099853515625, 34.00226048060826, 37.41624743597848, 38.400463240487234, 36.387309551239014, 36.71136311122349, 35.21934168679373, 35.85659224646432, 36.122499806540354, 37.38736030033657, 37.34560857500349, 37.876263345990864, 35.10566915784563, 35.43705654144287, 36.271691526685444, 36.67520815985543, 36.52575935636248, 36.13742453711373, 35.65482350758144, 36.287905148097444, 36.370543548039024, 33.73108271190098, 34.93296125956944, 35.38924251283918, 35.73859446389334, 36.13715703146798, 36.71675491333008, 35.61095258167812, 37.30910273960659, 37.14392668860299, 37.34050859723772, 39.83703804016113, 44.12313856397356, 51.911315304892405, 52.00396258490426, 56.07588141305106, 53.95014606203352, 60.16366645268032, 22.205852099827357, 0.3565970765692847, 0.24445184852395738, 0.048415641499949355, 34.48270409447806, 46.89926699229649, 46.030203683035715, 39.20568650109427, 24.198666674750193, 27.82128197806222, 30.634072576250347, 24.423416580472672, 0.3070803050483976, 0.023823133802839687, 0.017520903942308257, 0.03741263298849974, 0.026546753011643887, 0.01050443115777203, 0.019099741276087503, 0.07636458373495511, 0.043138250575533936, 0.008654345209444208, 0.04201298506398286, 0.05182914761826396, 0.02990643433960421, 0.05864802761269467, 0.02215596817300788, 0.028604953283710138, 0.06360864107097898, 0.007299500767008534, 0.012134271424396761, 0.040639358772231, 0.0273487915817116, 0.03378384467214346, 0.05999538781387465, 0.045829591873501024, 0.060238425486854145, 0.0762056436921869, 0.022228651147867953, 0.014494727665026273, 0.07674123852380685, 0.06097435099737985, 0.04169074539095163, 0.041436752770096064, 0.023561354992645125, 0.024807582941970656, 0.13540295218782766, 0.04228766621755702, 0.024654454551637173, 0.016621846738936644, 1.6644461836133684, 50.21330411093575, 51.79945625577654, 30.596805913107737, 42.478805678231375, 31.64296838215419, 67.50834315163749, 50.497704301561626, 60.904226303100586, 15.15940945489066, 0.263446893543005, 0.026857898637120212, 2.391145029238292, 67.35847745622907, 60.12208843231201, 62.43519238063267, 55.990651335035054, 53.034158093588694, 47.096998827798025, 53.14539875302996, 53.89300407682146, 57.422800132206504, 55.73495067868914, 55.66071959904262, 48.653395312173025, 47.60381432941982, 41.83663579395839, 44.23302779878889, 42.647181374686106, 44.20432826450893, 42.36107192720686, 45.15936858313424, 42.856791155678884, 45.114955697740825, 43.8559455871582, 43.08319820676531, 41.79442548751831, 42.5198278427124, 43.21126045499529, 43.121764183044434, 42.83967774254935, 42.42970970698765, 41.15999937057495, 41.06005648204258, 40.43379102434431, 43.968794754573274, 43.23820904323033, 42.63715859821865, 40.54705708367484, 39.371425356183735, 40.1846147264753, 38.44933686937605, 40.02239513397217, 39.74415452139718, 39.37815816061837, 41.06477778298514, 40.23255034855434, 42.235424177987234, 42.01782396861485, 41.785382407052175, 38.908946309770855, 38.47912379673549, 42.42635025296892, 43.212754317692344, 48.475868838174, 50.59842538833618, 54.70516858782087, 53.56080027988979, 55.42986570085798, 51.54697608947754, 54.056363173893516, 55.53957428250994, 53.02625799179077, 47.46414858954293, 45.08793415342058, 42.21935994284493, 39.63167360850743, 38.123469829559326, 40.73707641874041, 40.35702732631138, 38.89130483354841, 36.80928407396589, 37.866323947906494, 37.36246143068586, 39.60385649544852, 37.19404057094029, 39.085982935769216, 37.05330828257969, 35.888543537684846, 37.828310353415354, 38.33732843399048, 38.78691509791783, 37.82530525752476, 39.00916017804827, 36.59172902788435, 36.57540076119559, 39.092149462018696, 38.770798751286094, 38.31474331447056, 39.964405468532014, 37.79151964187622, 37.17252547400338, 37.60632930483137, 39.30975661958967, 37.0553753716605, 37.63738775253296, 37.597251483372276, 38.87292684827532, 37.634476457323345, 36.92129945755005, 37.268830980573384, 38.19715894971575, 37.74974012374878, 38.45245313644409, 38.75373050144741, 38.71591145651681, 39.8904002053397, 39.347978660038535, 39.03795003890991, 42.201760155814036, 45.73431117194039, 53.565896783556255, 53.15356288637434, 57.692859240940635, 55.35278238568987, 62.43420573643276, 22.289454562323435, 0.43884328327008654, 0.13342002859073027, 0.3675617410668305, 39.587813104902, 50.84986679894583, 50.630112648010254, 44.27566889354161, 31.586934634617396, 31.461266040802002, 34.57604619434902, 33.63781009401594, 0.4338577879326684, 0.023533663978534083, 0.024269686180299947, 0.033823142027748485, 0.03686404421127268, 0.006528386006331337, 0.04031905292400292, 0.057254805229604244, 0.0348189600211169, 0.019253412494435906, 0.06259882490017585, 0.08977631692375455, 0.007886654930189252, 0.027807347243651748, 0.06739323120564222, 0.037884018051304987, 0.03098559339663812, 0.11499405732112271, 0.10578899018998657, 0.09143215950046267, 0.15577716034437927, 0.07972367813012429, 0.22017244063317776, 0.1432005680565323, 0.12724237436694757, 0.1510278359055519, 0.1910316686012915, 0.08870170744402067, 0.16758360181535992, 0.056394168375326056, 0.0789987448869007, 0.1671911778726748, 0.12961332499980927, 0.14046337136200496, 0.27527907863259315, 0.1448395558233772, 0.11786378547549248, 0.36227538330214365, 2.364973987851824, 61.48785414014544, 60.99335084642683, 41.297844682421, 47.62691361563546, 34.79476853779384, 71.95118113926479, 55.60628046308245, 65.13713141850063, 19.422379425593785, 0.41884362644382883, 0.0785076551671539, 3.47983763899122, 69.14786788395473, 62.59375722067696, 66.10443183353969, 59.74299471718924, 55.90617861066546, 49.20469318117414, 57.043932233537944, 56.91601242337908, 59.914733341761995, 58.78697122846331, 59.71244348798479, 52.413993154253276, 52.44286291939871, 43.899114745003835, 47.2956200327192, 45.20846455437796, 47.65410539082119, 46.29318952560425, 50.2596173286438, 44.431565625326975, 48.44344506944929, 46.11004195894514, 46.53799540655953, 43.44648477009365, 44.392634868621826, 45.91991492680141, 47.07997574125017, 44.29720483507429, 43.129893575395855, 43.32459599631173, 42.93560109819685, 41.83166435786656, 46.519700799669536, 45.47142955235073, 44.556275367736816, 42.621076992579866, 43.33820751735142, 41.865654945373535, 42.568631989615305, 42.05541719709124, 40.9346102305821, 41.64223561968122, 43.84148291179112, 42.37375238963536, 44.98372507095337, 45.22444888523647, 44.3495317186628, 40.59250177655901, 41.036912032536094, 45.08896943501064, 47.23437166213989, 50.477276597704204, 53.573546750204905, 56.068231446402415, 55.81060266494751, 56.376964228493826, 51.12318113871983, 53.909634590148926, 56.965949126652305, 54.226152828761506, 47.503378118787495, 45.71597140175955, 46.073970385960166, 41.596172537122456, 39.62922436850411, 42.38980620247977, 43.11079297746931, 40.44097546168736, 39.760729449135916, 38.88495070593697, 39.869764055524556, 42.545855794634136, 39.65286908830915, 41.64081818716866, 40.43831082752773, 37.80264718191964, 39.15484305790493, 40.843453339168, 41.547128677368164, 40.77092456817627, 40.72217948096139, 38.314548764910015, 38.72536448069981, 39.82919699805123, 40.75727135794503, 41.35155078342983, 42.13628380639212, 38.05902181352888, 38.8817823273795, 41.2759439604623, 42.28178950718471, 39.525623253413606, 39.720707825251985, 40.45407281603132, 42.11143357413155, 40.34503820964268, 39.14177349635533, 39.820685454777305, 40.33095073699951, 39.48461845942906, 40.83194017410278, 41.87732791900635, 41.11921691894531, 42.55680268151419, 41.865491662706646, 41.59401512145996, 44.26670571735927, 46.99495758329119, 56.237274169921875, 55.4085625239781, 59.45376205444336, 57.173033237457275, 63.08814239501953, 26.447652646473475, 0.5180257686546871, 0.24784479503120693, 0.33082734793424606, 41.05011360985892, 58.221881185259136, 53.65304109028408, 50.60587385722569, 39.31139986855643, 36.37110982622419, 44.26027168546404, 44.3772862979344, 0.5792663225105831, 0.16222621500492096, 0.17797643771128996, 0.12215625228626387, 0.16371595220906393, 0.06860787674252476, 0.10261329023965768, 0.1421918986099107, 0.12479454571647303, 0.18198898168546812, 0.10940242665154593, 0.17153965096388543, 0.16982924060097762, 0.12138437799045018, 0.09690838493406773, 0.169148697118674, 0.16832102010292666], [0.12208579320992742, 0.029655983671545982, 0.040235409912254126, 0.028240615601784418, 0.051869004765259366, 0.031018495559692383, 0.037335619263883145, 0.07491625752300024, 0.045052655706448216, 0.04241624181824071, 0.08102384622075728, 0.0333385696368558, 0.013892037594424827, 0.012144000768395407, 0.07614466375006096, 0.05589390825480223, 0.032535421662032604, 0.0367761807117079, 0.12200016209057399, 0.042074439980621846, 0.07213636740509953, 0.11686135855104242, 8.324763536453247, 48.66869871956961, 35.64649261747088, 41.671331201280864, 30.772345202309744, 47.078099727630615, 49.97008241925921, 53.808465344565256, 40.30656255994524, 0.25606299404587063, 0.20321939246995108, 0.15409066155552864, 22.49406337738037, 71.82555770874023, 55.8079970904759, 58.53291034698486, 54.5100805418832, 56.30644696099417, 56.22187696184431, 60.148373467581614, 57.78744159426008, 58.96974359239851, 57.01314129148211, 56.01693984440395, 53.52140746797834, 53.5016120501927, 51.15579598290579, 51.488996846335276, 52.251526900700156, 50.92550836290632, 53.41612836292812, 52.51337671279907, 49.25927822930472, 45.49994495936802, 43.449541977473665, 41.684786387852256, 40.41980430058071, 39.68931238991873, 40.16897085734776, 41.60516698019845, 40.703666005815776, 39.08231776101248, 39.48224217551095, 39.56631537846157, 40.34454836164202, 39.863528047289165, 38.87658507483346, 38.59891421454293, 37.31484195164272, 38.99357189450945, 38.23676715578352, 38.4432988848005, 37.59945058822632, 37.87343890326363, 38.56809547969273, 39.280991077423096, 40.78664139338902, 40.33715547834124, 38.83644880567278, 40.16537169047764, 41.70134047099522, 45.638221059526714, 48.12342146464756, 54.03456320081438, 51.92723362786429, 53.96337890625, 52.685938698904856, 55.7882398877825, 46.48987913131714, 48.12197971343994, 55.4809627532959, 49.455304282052175, 50.36793279647827, 43.4533600125994, 42.11688443592617, 41.47779260362898, 41.876827648707796, 38.71887833731515, 39.8860992704119, 39.18247604370117, 38.34334557397025, 38.30516174861363, 36.84813840048653, 37.595212187085835, 36.84312180110386, 36.44267279761178, 35.90677561078753, 36.51799127033779, 36.89854410716465, 35.93860878263201, 36.82098831449236, 38.04446186338152, 37.29804468154907, 35.52247422082083, 36.31613220487322, 37.95635175704956, 36.81301178250994, 37.03390891211373, 37.760947568076, 36.53754350117275, 36.46681431361607, 36.03663049425398, 35.13595288140433, 35.831491879054475, 37.53200789860317, 35.08808674131121, 36.43463373184204, 34.63796159199306, 35.06191635131836, 35.928992475782124, 36.14527252742222, 37.100267682756694, 35.801041398729595, 36.424114159175325, 39.1560138293675, 39.07891314370291, 38.24287462234497, 41.48253474916731, 43.15612997327532, 50.161376748766216, 53.37316417694092, 55.479451520102366, 57.163840770721436, 56.76826245444161, 46.94492360523769, 0.6124013045004436, 0.073224934350167, 0.0735080802280988, 2.866306926522936, 50.09397922243391, 45.65722090857369, 55.615761280059814, 28.47853466442653, 31.287477697644913, 28.72868718419756, 35.70689330782209, 5.7369890468461175, 0.14927959043000424, 0.0854190160919513, 0.07812446608607258, 0.08441929652222566, 0.033262438007763455, 0.03998213653851833, 0.012116202885018927, 0.022818211565858552, 0.05509515718689986, 0.023750535644856945, 0.07688240773443665, 0.019539172428527048, 0.04503368047465171, 0.02480903161423547, 0.027655528425904255, 0.01723541202954948, 0.0795599612008248, 0.050043908413499594, 0.0562082429948662, 0.03559478339073913, 0.0331951917947403, 0.020480575306074958, 0.018607330109391893, 0.05079656320491007, 0.08109570986458234, 0.063361328627382, 0.021699346335870878, 0.014903614563601357, 0.05523630264880402, 0.0403668557160667, 0.03177015968997564, 0.045315961220434735, 0.04936156342072146, 0.038327026779630353, 0.020241155921082412, 0.11552244611084461, 0.06684481884752001, 0.07951052992471627, 0.08459352395896401, 12.713797279766627, 58.86142117636544, 35.40300689424787, 51.279126507895334, 37.39104979378836, 52.61037703922817, 58.98671804155622, 57.27565465654646, 42.85366794041225, 0.26439673400350977, 0.05036581221169659, 0.17552342505327292, 25.824456555502756, 72.341155733381, 57.62477036884853, 62.43630409240723, 55.78173289980207, 56.37339980261666, 59.33015360151018, 62.02184404645647, 59.64343397957938, 63.15369170052664, 58.81061594826834, 57.63339308329991, 55.672538484845845, 54.6003862789699, 50.04191984449114, 51.838390486580984, 54.0323988369533, 53.033369473048616, 55.17159768513271, 54.39180135726929, 49.82311759676252, 47.175384930201936, 45.11675180707659, 43.52992568697248, 41.534420422145296, 43.093894958496094, 42.57320737838745, 43.597781794411794, 41.50512681688581, 41.23983417238508, 40.874886989593506, 40.320361682346885, 43.39615201950073, 42.389340673174175, 42.53961631229946, 41.877796922411235, 41.5739244052342, 39.91826942988804, 40.08360876355852, 40.00655671528408, 38.86254276548113, 39.91933945247105, 40.501129490988596, 42.68359688350132, 44.094466822487966, 44.04949113300869, 40.574471201215474, 42.64827224186489, 43.33533443723406, 47.40235478537423, 49.83677428109305, 54.34966400691441, 51.819036279405864, 55.586415563310894, 54.3691154888698, 55.97020973478045, 47.09382350104195, 48.63760553087507, 56.483236925942556, 51.899524211883545, 50.73607962472098, 44.77769013813564, 43.52081659861973, 41.618535314287456, 42.31830923897879, 39.62499638966152, 40.192077091761995, 42.327230725969585, 38.94456972394671, 38.52724354607718, 38.671783447265625, 37.51588807787214, 38.54738637379238, 37.93411752155849, 38.817021642412456, 38.748481137411936, 38.30851425443377, 38.20628193446568, 38.058306149074006, 38.73170471191406, 39.09930263246809, 38.06617498397827, 38.230659689222065, 38.78362512588501, 38.66152095794678, 37.85368864876883, 39.624350207192556, 39.5927289554051, 39.34661681311471, 37.335787296295166, 36.79562391553606, 37.8497177532741, 38.881917817252024, 37.28848048618862, 37.15988670076643, 36.47323792321341, 36.72861896242414, 36.836034638541086, 37.49368858337402, 37.85779850823538, 36.86148588997977, 38.4413777078901, 40.81297506604876, 39.64580624444144, 40.64888640812465, 43.375710419246126, 44.46426384789603, 52.081910950796946, 55.96139594486782, 57.243897914886475, 59.715667452131, 57.749361991882324, 47.96495042528425, 0.41762280623827663, 0.14658139592834882, 0.33083242337618557, 3.2943422326019833, 56.58814082826887, 50.33712795802525, 59.464184352329795, 34.726537227630615, 38.84188577107021, 29.453955786568777, 45.35027033942086, 10.055682267461505, 0.2978397166090352, 0.11813038188431944, 0.10511557811072894, 0.05878919003797429, 0.04858654411509633, 0.01966770731710962, 0.0057575541099400395, 0.02425237505563668, 0.040179976993905644, 0.030251750988619666, 0.12730340180652483, 0.02292937595796372, 0.08836571047348635, 0.044635692544813664, 0.03074420795642904, 0.023181314314050332, 0.024591321957164576, 0.2182174048253468, 0.13204235823026725, 0.07377536874264479, 0.11326745711266994, 0.15405354569000856, 0.1020241929218173, 0.1581115379397358, 0.11995546466537885, 0.17627896022583756, 0.10043395111071211, 0.13177768886089325, 0.08288453851959535, 0.07127422759575502, 0.12367656427834715, 0.13007886787610395, 0.11653407397014753, 0.1061299065394061, 0.14683454377310617, 0.15397357355271066, 0.1207640612764018, 0.13066524426851953, 0.18083152307995728, 19.34792947769165, 69.5113559450422, 44.70625918252127, 57.76704168319702, 43.11339160374233, 60.04826382228306, 61.56225545065743, 64.96553870609829, 48.30053104673113, 0.46530186065605705, 0.31864175466554506, 0.2555455703820501, 26.51813691002982, 76.97093500409807, 61.98588711874825, 65.7154369354248, 58.804161071777344, 60.756792477199006, 62.46250574929373, 66.26097474779401, 61.723808016095845, 65.06254250662667, 61.127319063459126, 59.41816643306187, 57.231130599975586, 59.60073035103934, 54.47559315817696, 56.42484426498413, 58.021512508392334, 56.536084924425396, 58.53475856781006, 57.0650269644601, 52.470641817365376, 49.53670937674386, 48.4424341065543, 46.337272371564595, 45.15497037342617, 45.872503893715994, 44.232100214277, 45.445863655635286, 45.590330600738525, 43.300284249441965, 43.53078031539917, 42.8269555909293, 45.523176261356895, 45.39441224506923, 44.13111857005528, 43.575759478977744, 43.25783770424979, 42.53940439224243, 43.891756602696006, 43.35833992276873, 41.667033740452354, 43.731854234422954, 44.58114297049386, 44.309822763715474, 46.187677655901226, 45.28451606205532, 42.63353163855416, 44.40678487505232, 46.05725996834891, 50.59915147508894, 52.39114052908761, 57.241212436131065, 54.377109391348704, 59.379951340811594, 55.89771570478167, 58.554401125226704, 48.00231783730643, 48.73769085747855, 58.12259142739432, 51.12400797435215, 54.55139453070504, 45.763101032802034, 45.62113543919155, 44.82304103033883, 47.26792103903634, 40.61109168188912, 41.66445248467581, 43.431518350328716, 42.49143750326974, 41.42483343396868, 40.69552966526577, 39.91289152417864, 40.842727252415244, 40.0625696182251, 40.025942189352854, 41.42691789354597, 41.267613070351736, 39.33998475755964, 40.29388904571533, 41.18295969281878, 41.279101916721885, 39.69331802640642, 40.03391524723598, 40.83404895237514, 41.66750969205584, 39.24774047306606, 42.00008174351284, 40.07978030613491, 41.485446044376914, 39.115050724574495, 40.0670998437064, 39.275828565870015, 41.582262243543354, 39.85031257356916, 40.44620745522635, 38.84664528710501, 39.25428915023804, 40.6430846623012, 39.81301464353289, 41.19218690054757, 39.496621472494944, 41.83508287157331, 45.03129938670567, 42.236094679151265, 42.50744962692261, 45.12409952708653, 46.634669167654856, 55.60020773751395, 57.64079291479928, 60.5298365184239, 63.063775062561035, 57.23167603356497, 51.20680965696062, 1.2895788188491548, 0.14523915866655962, 0.32276187358157976, 5.215350866317749, 61.86814294542585, 54.34723213740757, 64.90461690085274, 39.828856536320274, 44.989106450762065, 35.17275054114205, 57.460445472172324, 14.69788578578404, 0.3583799951842853, 0.23231391555496625, 0.14944310379879816, 0.2258947164352451, 0.1312623279435294, 0.08237750322691031, 0.1734267654163497, 0.08592609888208763, 0.10754837042519025, 0.06989889818110637, 0.16416918646012033, 0.15694322277392658, 0.1519043403012412, 0.16080309636890888, 0.10855897369661502, 0.08893606665411166, 0.14407152203576906], [0.03449782296749098, 0.017110207051570927, 0.05642481101676822, 0.08562955872288772, 0.04043609003669449, 0.033742905261793306, 0.044299064536712, 0.03387538922418441, 0.05297150881960988, 0.04537534660526684, 0.02874621409656746, 0.05182798393070698, 0.0231560032615172, 0.07201270439795085, 0.03111380258841174, 0.09144836291670799, 0.02379481344749885, 0.014004354647892927, 0.11865959848676409, 0.014624322764575481, 0.11110823654702731, 0.08329127276582377, 0.37261536132012096, 37.84381873267037, 45.58039467675345, 34.40018381391253, 34.06216784885952, 29.988428592681885, 48.79582296098982, 50.070240701947895, 53.1135447365897, 2.647327933992658, 0.20334313011595181, 0.06473557917135102, 0.9986925934042249, 52.06801455361502, 63.937816756112234, 60.0759037562779, 59.71859264373779, 60.16361781529018, 57.48715782165527, 60.35079533713204, 58.555207116263254, 58.99884959629604, 57.86772802897862, 57.00236463546753, 55.39966882978167, 56.41400507518223, 56.265966756003245, 56.39515461240496, 56.021831376211985, 57.191108976091655, 57.4002115385873, 55.07565695898873, 51.136813504355295, 48.64960159574236, 42.23604604176113, 40.20284332547869, 41.121165888650076, 39.63057231903076, 41.62569195883614, 40.31529644557408, 39.250161920275005, 40.966221060071675, 41.79574564525059, 39.737095151628765, 39.39996855599539, 38.82344872610909, 39.21730041503906, 40.65807540076119, 39.55416645322527, 37.538580894470215, 36.77469246728079, 39.12434046609061, 37.02569614137922, 39.22031940732683, 40.14337716783796, 39.40663535254342, 40.80581842150007, 40.68785885402134, 39.673887389046804, 42.916431018284385, 41.934556756700786, 46.64983013698033, 52.06723982947213, 54.06480176108224, 53.07317917687552, 56.81939772197178, 51.418215547289165, 54.47239351272583, 34.529333455221995, 32.43628590447562, 58.47096020834786, 52.486066818237305, 52.80256073815482, 47.42106281008039, 49.47609676633562, 48.689272335597444, 49.30316652570452, 50.7561286517552, 45.44042321613857, 41.19038036891392, 40.35053423472813, 36.63150746481759, 36.87554209572928, 37.500497817993164, 36.7925180707659, 35.97874852589199, 36.48285075596401, 36.055046694619314, 35.741359846932546, 36.571256160736084, 38.10040181023734, 38.42338534763881, 37.27774551936558, 36.36945615495954, 38.00009066717965, 36.39098514829363, 37.66112279891968, 37.62115328652518, 37.8018342426845, 36.41044357844761, 36.70457124710083, 35.50292893818447, 36.808703899383545, 38.01060676574707, 36.752520765577046, 35.42607838766915, 38.07382147652762, 38.348191942487446, 38.80198226656233, 39.27147551945278, 38.22459738595145, 39.59749889373779, 39.88736384255545, 37.84101513453892, 37.29980952399117, 37.158955642155235, 38.57636383601597, 38.25826140812465, 42.8741512298584, 51.97352252687727, 54.162361417497905, 57.13510649544852, 56.16072586604527, 56.34061125346592, 7.271463096141815, 0.6732410884329251, 0.44875296152063776, 1.4876924795763833, 7.146947034767695, 54.99893147604806, 45.982671056474956, 36.81422076906477, 21.47222481455122, 29.228163651057653, 27.443671703338623, 24.52831527165004, 0.22646239240254673, 0.03577448321240289, 0.05988661865038531, 0.0540973510859268, 0.08229942420231444, 0.04749079826953156, 0.02620320225001446, 0.06566954869776964, 0.034611084032803774, 0.058615573282752714, 0.0263685510560338, 0.02849467098712921, 0.10675967524626426, 0.03480739778439913, 0.03594699056286897, 0.05646688358059951, 0.028177194629928896, 0.03549755271524191, 0.02696691546589136, 0.04976517301318901, 0.05458996072411537, 0.036061652802995274, 0.03838236809575132, 0.08326808043888637, 0.016325557637693625, 0.018029988410749605, 0.011846391068372344, 0.03437631091635142, 0.04623947452221598, 0.023682208864816597, 0.05701442741389785, 0.03392137014972312, 0.07569752952882222, 0.031047214554356675, 0.014016951650514134, 0.007053033099509776, 0.06245557937238898, 0.04517951800620981, 0.10082115033375365, 0.0901861045775669, 0.7133283402238573, 46.583002362932476, 48.71714850834438, 38.621780736105784, 50.42120810917446, 36.61842748097011, 54.01557724816458, 54.59284748349871, 58.2699418749128, 1.652979267495019, 1.1373804828950336, 0.0008437223545375413, 1.269544231040137, 56.04177270616804, 65.31425489698137, 61.81369686126709, 61.225691659109934, 61.172218322753906, 59.27820886884417, 62.28028229304722, 59.877963474818635, 60.70689746311733, 60.107643127441406, 59.519366945539204, 58.516359737941194, 58.84173692975725, 55.763389655521934, 59.21023464202881, 57.76578753335135, 58.93457875932966, 59.77683939252581, 56.832845960344585, 55.08976527622768, 50.29557425635201, 43.707452160971506, 42.42716319220406, 42.44494710649763, 43.49281883239746, 43.73514768055507, 42.52154752186367, 42.52684899738857, 43.429298400878906, 43.045309679848806, 42.50349957602364, 42.601670673915315, 41.525092465536936, 40.62866367612566, 41.7917469569615, 42.12148066929409, 39.98444059916905, 41.517835072108674, 41.33086947032383, 39.588351590292795, 41.59072514942714, 41.59799296515328, 41.03528962816511, 41.816235882895334, 43.26754433768136, 41.139182567596436, 43.524155208042686, 44.28256845474243, 47.525310107639854, 54.86084297725132, 56.71524769919259, 55.52145685468401, 57.4985111781529, 53.08368485314505, 55.906366212027415, 38.652516092572895, 37.2418337549482, 61.2714455468314, 52.87479073660714, 54.801084995269775, 49.01520538330078, 49.97204875946045, 48.12851449421474, 48.63534389223371, 50.11732169560024, 46.476430892944336, 41.04233162743704, 40.33886126109532, 38.842514583042686, 38.764489786965505, 39.87471464702061, 38.616190910339355, 37.67083290645054, 38.04414919444493, 37.91797685623169, 38.325217723846436, 38.48809739521572, 39.204800605773926, 39.0292752129691, 37.572880676814485, 38.69656767163958, 39.3996593611581, 37.592818532671245, 39.00304923738752, 39.774577208927695, 39.26617751802717, 37.760506357465474, 38.269812788282124, 39.097127846309114, 38.72663252694266, 39.98527785709926, 37.56497710091727, 38.15591444287981, 39.4484600339617, 39.59541096006121, 40.27267966951643, 42.353102343423025, 41.77497400556292, 41.417548247746055, 41.08792570659092, 41.20317547661917, 39.32277406964983, 37.964877196720664, 41.46614742279053, 40.061631611415315, 45.185229778289795, 53.76792260578701, 56.63181720461164, 59.81717368534633, 54.990253176007954, 59.16649573189871, 6.092866224902017, 1.096417486667633, 0.7343084258692605, 1.7204890506608146, 10.142476558685303, 60.19100761413574, 54.08735908780779, 42.36660269328526, 30.215725013187953, 33.573772021702354, 30.252414975847515, 32.95043870380947, 0.5300957666976112, 0.058976893180183, 0.012476650016781474, 0.0678483314279999, 0.035672214414392195, 0.05223399892981563, 0.015422346103670341, 0.02256639364973775, 0.0637389130092093, 0.05022461246699095, 0.028556166615869318, 0.05232807441747614, 0.018840790260583162, 0.021247659144656997, 0.0057001899112947285, 0.08877302147448063, 0.04259111725592187, 0.07370379686887775, 0.050250722494508536, 0.10326298752001353, 0.1187868102320603, 0.25742584520152634, 0.18896083400717803, 0.16720898263156414, 0.11882076412439346, 0.11460954509675503, 0.20524559303053788, 0.16625467741063663, 0.0870864616174783, 0.09515934557254825, 0.16875487539385045, 0.15756853350571223, 0.1321606133133173, 0.18833474974547113, 0.08897278218397073, 0.061480137785630565, 0.15289326437882014, 0.11127600433038813, 0.2594682356076581, 0.19861253324363912, 0.9618882025991167, 58.60529667990548, 56.95451586587088, 45.26896251950945, 47.07351739065987, 40.27244343076433, 60.661296435764854, 58.41285242353167, 62.790363448006765, 4.196847438812256, 1.1222388382468904, 0.10835091450384685, 1.8456773502486092, 56.60564334051949, 68.60729803357805, 66.39534596034459, 63.63990579332624, 65.4190754209246, 62.576609066554475, 62.42973804473877, 62.65693719046456, 61.46932329450335, 62.46885640280587, 64.78065408979143, 61.46374389103481, 60.89776447841099, 60.60650988987514, 61.47600051334926, 59.174319403512136, 61.60217979976109, 61.991800035749165, 59.443270274571006, 55.486378874097554, 55.08102791649954, 45.90481996536255, 45.41908529826573, 45.21202550615583, 45.81822109222412, 47.507362910679404, 45.72478519167219, 44.020315647125244, 45.958592074257986, 47.19938748223441, 45.05978352682931, 44.48420170375279, 43.3509817804609, 43.44160713468279, 43.3749600137983, 44.59439665930611, 42.21760204860142, 43.361786229269846, 45.31822524751936, 40.84547526495797, 44.07467140470232, 44.94084773744856, 42.92967081069946, 44.34934064320156, 44.22157369341169, 43.588443415505544, 47.672118595668245, 46.001458985464915, 49.96683413641793, 57.42640624727522, 58.001168182918, 56.48177433013916, 60.98490878513881, 54.95007174355643, 57.65842396872384, 35.22260386603219, 36.79426554271153, 63.616351400102886, 54.57113783700125, 56.14155578613281, 51.44154759815761, 52.38463354110718, 51.594685895102366, 51.61883783340454, 53.178315843854634, 48.687979970659526, 43.99888392857143, 42.44265767506191, 41.981470993586946, 41.69149487359183, 42.61678647994995, 40.8424562726702, 40.057851791381836, 40.54713698795864, 39.99525547027588, 39.13356767381941, 39.754813058035715, 41.97784750802176, 42.090932914188926, 40.54728637422834, 40.761812005724224, 42.63958004542759, 39.93065111977713, 40.15214579445975, 43.17315305982317, 40.796330656324116, 40.41548946925572, 41.37064095905849, 40.50991896220616, 41.48757914134434, 41.70900433404105, 40.700122424534385, 40.443563665662495, 42.475925649915425, 42.319660663604736, 42.764803954533164, 45.16214091437203, 43.10712085451399, 44.38541221618652, 43.259619917188374, 41.75724915095738, 42.621323653629844, 41.108739035470144, 42.55357871736799, 42.18310076849801, 48.06695345469883, 56.1883727482387, 59.80659852709089, 62.79023143223354, 56.049777030944824, 61.52655560629708, 9.79154302392687, 0.8322112038731575, 0.4983048268726894, 2.5293414422443936, 9.733209422656468, 67.6958680834089, 55.79905128479004, 47.2721073286874, 30.513549123491558, 38.83971445901053, 39.050661768232075, 44.4941063608442, 0.5776615600500787, 0.10580205198909555, 0.11912310575800282, 0.1613661175859826, 0.24150716939142772, 0.13231069168874196, 0.10522853383528334, 0.3054427557757923, 0.1320042788450207, 0.10400885356856243, 0.16846714940454277, 0.10327833598213536, 0.18416201722409042, 0.1591688176350934, 0.14292630420199462, 0.2146680559962988, 0.10260650488947119, 0.17882770060428552], [0.039331774293844185, 0.08320933966232197, 0.01620968251622149, 0.011654029783260609, 0.0716682393103838, 0.03447913272040231, 0.13290730038923876, 0.026720848134053603, 0.019706261676869223, 0.07632459766630616, 0.03248465706461242, 0.015434971944029843, 0.03197671592767749, 0.06594988544072423, 0.05944052258772509, 0.1320814961301429, 0.011168877244926989, 0.0011920871100820868, 0.04773460268708212, 0.13430038706532546, 0.07419994167451348, 0.08231376164725848, 0.057922700819160254, 10.22360633100782, 53.09455530984061, 34.82471874782017, 41.94392640250069, 20.145876237324305, 56.45059428896223, 53.96395560673305, 53.83866221564156, 11.442578315734863, 1.4423446272100722, 0.45092394788350376, 0.5411340658153806, 9.797943183353969, 67.29449149540493, 57.80755662918091, 62.20115620749337, 59.99494334629604, 63.67686326163155, 59.39222880772182, 59.05927113124302, 56.53228773389544, 60.31125313895089, 57.54757588250296, 60.261094093322754, 59.518818037850515, 57.908903053828645, 57.245801721300396, 57.573847021375386, 58.129689012254985, 59.80594539642334, 56.34876496451241, 52.11151375089373, 45.69090230124337, 42.37589243480137, 41.6915921483721, 41.17528540747506, 41.88207701274327, 41.15959637505667, 42.70299972806658, 42.664527552468435, 40.04056119918823, 41.352961267743794, 40.61560453687395, 38.937906401497976, 40.13532073157174, 40.08174317223685, 40.44885124479021, 37.43797445297241, 39.6181697845459, 39.22993571417672, 40.40827029091971, 37.285030705588206, 39.062828063964844, 37.92697477340698, 41.150681836264475, 41.01719651903425, 39.05946166174752, 39.72721481323242, 40.834299087524414, 41.92712913240705, 47.57164764404297, 55.99125930241176, 56.87586920601981, 54.61827094214303, 56.982996531895225, 53.325468267713276, 50.01114279883248, 26.64290918622698, 13.756296311106, 53.21811165128435, 55.1874361038208, 53.23670155661446, 51.78481987544468, 53.07490233012608, 52.90740558079311, 53.98448405947004, 50.689683028629844, 51.986220359802246, 45.40370198658535, 38.64973333903721, 36.87739726475307, 38.563794544764924, 36.741243839263916, 36.0468304497855, 36.92405094419207, 35.87680108206612, 36.66887835093907, 37.28154270989554, 38.641666480473106, 38.31222459248134, 36.60963453565325, 38.11581291471209, 36.251187392643516, 38.74595546722412, 38.576332569122314, 37.8231200490679, 39.238878045763286, 38.11669186183384, 37.94558899743216, 36.91214868000576, 37.649432454790386, 37.59721326828003, 34.66425010136196, 38.366660254342214, 36.283979415893555, 41.004755769457134, 41.02270296641758, 44.295690127781455, 41.230506215776714, 42.9200301851545, 41.672877175467356, 42.32339184624808, 38.0992032459804, 43.210749762398855, 40.43817186355591, 41.1540447643825, 37.38158287320818, 46.68724618639265, 48.15998983383179, 58.539823804582866, 49.723244190216064, 65.16061632973808, 22.762527874537877, 0.11427715793251991, 0.4286703605737005, 0.2562921217509678, 1.360818156174251, 13.481027790478297, 51.60576827185494, 46.2603314944676, 30.16790403638567, 20.416750022343226, 23.115795135498047, 37.625120707920615, 8.102690424237933, 0.8095934603895459, 0.23006818177444593, 0.18931238300033978, 0.040669553580560854, 0.12383127026259899, 0.009996306816382068, 0.04937306119661246, 0.05222090320395572, 0.006008354223532868, 0.037120744186852656, 0.07608935636069093, 0.1237913588328021, 0.010328980661662561, 0.06164805484669549, 0.026043017095487033, 0.04239256773144007, 0.031506579369306564, 0.06257367839238473, 0.029221348065350736, 0.013314186994518553, 0.05789965098457677, 0.04128246747755578, 0.01616475671263678, 0.018605949290628945, 0.06962924836469547, 0.04046795404117022, 0.06228016449936798, 0.025752037530764937, 0.053117397241294384, 0.0352419214323163, 0.04345890926197171, 0.03158787125721574, 0.06964467146566936, 0.051890816273433824, 0.024082429174865996, 0.03725761827081442, 0.04852966930983322, 0.04290289391896554, 0.07020516174712352, 0.08604546676256827, 0.06942163700503962, 14.19983891078404, 60.191264697483604, 34.78661135264805, 44.82148463385445, 28.122828585760935, 60.19580881936209, 60.19504451751709, 60.455838203430176, 14.570225664547511, 2.268022298812866, 0.10573075831468616, 0.641970557825906, 12.063914026532855, 70.52165181296212, 60.35397066388811, 65.70061642783028, 62.32523018973214, 65.80103874206543, 60.3931793485369, 59.4033876146589, 59.37862423488072, 62.68819713592529, 62.556827545166016, 63.31921168736049, 61.48231642586844, 60.0815109525408, 59.206079619271414, 59.34257698059082, 61.09428037915911, 60.48900890350342, 58.16624695914132, 54.452073505946565, 47.720811571393696, 45.86138677597046, 43.56897108895438, 44.1722206388201, 43.51241275242397, 43.84259114946638, 43.35072469711304, 43.8519503729684, 42.25796413421631, 42.940666334969656, 43.91593633379255, 41.45361287253243, 42.96232039587838, 42.312566552843364, 42.712761947086875, 40.86269637516567, 42.20112786974226, 42.047009876796174, 42.04511996677944, 40.487639563424246, 40.78411224910191, 41.631577083042686, 43.12807314736502, 42.515200342450825, 41.14744050162179, 41.78917612348284, 43.23088216781616, 45.457578318459646, 49.23910066059658, 56.99567004612514, 56.82387236186436, 56.78038011278425, 58.42826352800642, 54.105876037052695, 51.140516894204275, 28.167614936828613, 16.179608242852346, 55.90170744487217, 55.71156999043056, 54.72931705202375, 51.57987233570644, 53.44225706372942, 55.07749128341675, 55.913175446646555, 51.724985463278635, 54.76458610807146, 45.77233171463013, 39.99610315050398, 39.60105289731707, 38.6925550869533, 37.43617834363665, 38.52032314028059, 38.279203278677805, 39.56748267582485, 38.94401386805943, 39.41503572463989, 38.98360817773001, 40.537690911974224, 38.24278082166399, 39.961396898542134, 38.26385818208967, 39.676690987178254, 39.6980219568525, 40.83771760123116, 39.76672574451992, 39.6137090410505, 39.87583678109305, 39.48546961375645, 40.21924454825265, 39.27508858272007, 37.3899450302124, 39.77646017074585, 38.844460078648154, 44.094174998147146, 43.831456661224365, 47.90318093981062, 43.0669116292681, 44.53841502325875, 44.439806188855854, 43.951723030635286, 40.878350666591096, 44.02269887924194, 41.84325395311628, 44.05767958504813, 40.44998032706124, 49.16378218787057, 49.67846999849592, 61.31956877027239, 51.15513590403965, 67.70366396222795, 23.80580336706979, 0.17519236781767436, 1.822038275854928, 1.1496803143194743, 2.088830428464072, 15.34850641659328, 57.50272526059832, 51.7775833266122, 36.240539278302876, 26.442387648991176, 25.030887160982402, 43.64295550755092, 11.450848409107753, 0.7689844423106739, 0.21740420774689742, 0.14654356081570896, 0.0764944621228746, 0.13654255175164767, 0.010757561190985143, 0.05557715453739677, 0.02975984024150031, 0.0473303790204227, 0.030060271799032177, 0.03487485095060297, 0.06527106543736798, 0.05919185307409082, 0.0448573224379548, 0.024043818835967352, 0.0206365620251745, 0.05898075404443911, 0.008298110931978693, 0.11348514471735273, 0.1293025423905679, 0.1302142898951258, 0.08955541306308337, 0.17287464147167547, 0.12363600145493235, 0.16411726496049336, 0.218985112916146, 0.07560716223503862, 0.163471733885152, 0.13283798125173363, 0.11161035924617733, 0.1236912477761507, 0.15439419741077082, 0.1305177714675665, 0.2736781973923956, 0.08950522861310414, 0.13477130393896783, 0.23375729524663516, 0.15933713503181934, 0.2629603296518326, 0.3775393271020481, 0.2462704580809389, 19.63359250341143, 72.2529136112758, 45.52019895826067, 54.63540867396763, 28.274016175951274, 68.20398984636579, 64.38560036250523, 65.90271868024553, 13.301669597625732, 2.676087179354259, 0.5838206495557512, 0.6654641000287873, 13.474727511405945, 73.46896648406982, 65.80573572431291, 67.64871065957206, 64.92449569702148, 67.60512460981096, 63.112259592328755, 60.77310684749058, 59.988405091421946, 66.09871346609933, 63.91595772334507, 65.44660418374198, 64.37089797428676, 61.80429594857352, 60.77421161106655, 62.62818554469517, 64.6303437096732, 63.78392110552107, 60.8373498916626, 55.13549484525408, 50.2681427683149, 48.09738656452724, 45.389576298849924, 46.858359473092214, 47.134668486458914, 45.73748302459717, 46.47902604511806, 47.49005494798933, 43.56340905598232, 44.423630782536094, 45.32746982574463, 42.96513441630772, 43.66862562724522, 44.60719176701137, 45.51391431263515, 43.957667214529856, 44.085666928972515, 44.20420667103359, 44.594827447618755, 41.88583946228027, 42.79114804949079, 43.51667547225952, 45.81893328257969, 45.33223281587873, 43.114965370723176, 43.429305349077495, 43.97658021109444, 47.60109758377075, 49.81673567635672, 58.53948334285191, 58.64110769544329, 57.79688419614519, 62.36448751177107, 54.90131275994437, 50.17673226765224, 27.192289352416992, 15.271119117736816, 57.103711060115266, 60.202020508902415, 57.10325942720686, 53.22105073928833, 54.50193725313459, 57.943459919520784, 58.59593745640346, 53.380560534340994, 55.9499557358878, 48.45667791366577, 42.082282406943186, 40.839617933545796, 40.591476917266846, 41.175368785858154, 40.28241409574236, 39.83725690841675, 40.755423137119834, 40.83509118216378, 41.80793278557913, 42.733370304107666, 42.7274295943124, 39.973736899239675, 41.69985703059605, 39.21937445231846, 43.60789489746094, 41.08380195072719, 42.6668586730957, 43.0181040082659, 42.094688415527344, 42.29851382119315, 42.37545122419085, 42.82350581032889, 41.63285902568272, 38.96828392573765, 41.33532326562064, 39.67769500187465, 45.722044127328054, 46.05337939943586, 50.97332239151001, 44.8361314364842, 47.24428326742989, 46.501333236694336, 47.706727572849815, 44.23841960089547, 47.33001708984375, 44.8687184878758, 45.12114654268537, 42.345014640263145, 50.84226894378662, 53.864707538059776, 63.28748621259417, 54.79607534408569, 66.35314260210309, 27.441218989236013, 0.18068126828542777, 0.9662372320890427, 0.956067674926349, 5.758775992052896, 16.848294189998082, 63.001116207667756, 55.04761750357491, 41.257329736437114, 31.080383164542063, 35.19622850418091, 51.166440623147146, 18.915016753332957, 1.063158739890371, 0.3360922639923436, 0.2289428992995194, 0.1825523693114519, 0.37187350541353226, 0.13016725384763309, 0.18145604671112128, 0.1979201968227114, 0.174778977142913, 0.10509598201939038, 0.1719314642250538, 0.2489982774215085, 0.11498560277479035, 0.17286857536860875, 0.11483522584395749, 0.12125689483114652, 0.14461475717169897, 0.12467093020677567], [0.04194902635312506, 0.018238777028662816, 0.07164437523377792, 0.12321976093309266, 0.03385005611926317, 0.05063446458163006, 0.18494425953498908, 0.04927440220490098, 0.0461908167760287, 0.012473508399645132, 0.021540397811414938, 0.056675896115068874, 0.10171528306922742, 0.023984177304165702, 0.07074135368955986, 0.04342413094959088, 0.06052229061190571, 0.06222251616418362, 0.0671575420669147, 0.15757731374885353, 0.06343019314642463, 0.06700787081250123, 0.0834031089075974, 0.3804046990615981, 41.64543179103306, 46.038864612579346, 41.75152383531843, 24.090453692844935, 33.096264021737234, 56.05339356831142, 55.68160588400704, 29.07591472353254, 0.713327417416232, 0.009889022796414793, 0.13085170569164412, 0.07159188376473528, 25.03864482470921, 69.9159495489938, 57.52740526199341, 65.6855388368879, 56.239264828818186, 59.56684398651123, 55.00949273790632, 61.43299811226981, 59.45954990386963, 63.88784531184605, 59.07993507385254, 60.06155572618757, 58.41815389905657, 58.408718245370046, 54.859276158469065, 58.41833455221993, 56.49975626809256, 53.136616230010986, 46.151421955653596, 43.04535831723894, 39.118688106536865, 40.753547123500276, 40.97269330705915, 42.401190825871055, 42.427656514304026, 41.95824316569737, 41.39067608969552, 42.071262563977925, 43.117365973336355, 39.33470760072981, 39.6861127444676, 40.43594149180821, 38.60148504802159, 38.55662052971976, 40.48184476579939, 40.13891642434256, 40.16524314880371, 40.915137904030935, 40.42848607472011, 39.92365428379604, 39.162128244127544, 42.494053500039236, 43.704784052712576, 41.735209465026855, 42.9703768321446, 40.59271022251674, 39.66536194937569, 41.08245400020054, 51.71798515319824, 56.554042543683735, 51.05752413613455, 53.31485489436558, 53.8832175391061, 56.984188147953574, 40.73164987564087, 38.47569138663155, 52.20846543993269, 58.628267424447195, 54.49758768081665, 53.03888981682913, 52.40225417273385, 53.79796314239502, 53.52742460795811, 51.51931183678763, 55.083963530404226, 45.93256064823696, 38.37795107705252, 39.50405951908657, 39.42825814655849, 38.132832527160645, 37.93621935163225, 35.51131888798305, 37.56210054670061, 36.35979815891811, 38.88862977709089, 39.28784547533308, 38.111994879586355, 38.293891770499094, 37.80751092093331, 36.477771622794016, 37.75009100777762, 39.024137020111084, 35.832676546914236, 37.14959989275251, 39.0461871283395, 37.52265214920044, 35.909627846309114, 36.246497358594624, 39.26773044041225, 36.38464144298008, 37.04758644104004, 38.680649348667686, 39.97482081821987, 42.25771747316633, 42.83613763536726, 45.71505076544625, 43.75800725391933, 41.0462087222508, 43.49166195733206, 41.90061828068325, 48.081148624420166, 48.51333005087716, 48.71004744938442, 42.88307271684919, 41.2461952481951, 46.16267803737095, 56.31502103805542, 52.51160839625767, 60.836849621364046, 2.3454534581729343, 0.36912883126309937, 1.2243851742574146, 1.952582985162735, 0.8174265772104263, 17.721677541732788, 60.73834500994001, 36.97072894232613, 21.429123401641846, 26.04292528969901, 31.4266813823155, 33.8507376398359, 0.32961059893880573, 0.07511324302426406, 0.03326781879046133, 0.13213317335716315, 0.030006307908999066, 0.04231578131605472, 0.06552996725908347, 0.1228908614388534, 0.006112469484963055, 0.022198617491605024, 0.09534295714859452, 0.0674731694161892, 0.09747338747339589, 0.11681042771254267, 0.09131822668548141, 0.04642216329063688, 0.03332564015207546, 0.1007635902081217, 0.07439984487635748, 0.08810045077864613, 0.03941411451835718, 0.09365505379225526, 0.10572266339191369, 0.026097952986934354, 0.014454113951485072, 0.10015685097979647, 0.03856000177828329, 0.09394125986312117, 0.04076658748090267, 0.05144281692004629, 0.06581700792802231, 0.07143907767853566, 0.11727379927677767, 0.032581721499030075, 0.02908347314223647, 0.06666821653821639, 0.07544962675975901, 0.1081220107153058, 0.06306055440966572, 0.03177500103733369, 0.016893779825685278, 0.01937258359976113, 0.686594114771911, 50.484162262507844, 48.50080592291695, 37.93023695264544, 32.36485494886126, 40.04359756197248, 62.82934979030064, 59.77662399836949, 32.02312169756208, 0.7193179045404706, 0.6478337517806462, 0.2901124783924648, 0.08584516322506325, 30.276935168675013, 72.23088087354387, 58.53591891697475, 66.73162487574986, 57.26532963344029, 61.3678309576852, 55.118367535727366, 61.162734031677246, 62.35082040514265, 67.0473996571132, 60.101500919886995, 60.8902256829398, 60.50053596496582, 59.80659852709089, 56.58052907671247, 61.07464476994106, 56.71835354396275, 54.896782534463064, 48.53097152709961, 45.07858187811715, 41.64575488226754, 42.68896436691284, 44.38290044239589, 42.96023941040039, 43.51834651402065, 44.30732488632202, 43.07903970990862, 45.402003152029856, 44.44334282193865, 42.114112104688374, 42.76878179822649, 43.08227757045201, 40.233384132385254, 41.25005497251238, 42.13587038857596, 42.35538135256086, 43.55861827305385, 42.81960787091936, 42.66852971485683, 40.77904006413051, 40.348824977874756, 43.77162919725691, 45.31437594549996, 44.16765914644514, 44.41226352964129, 41.018530573163716, 42.273145948137554, 42.90110329219273, 55.49366058622088, 58.42641530718122, 54.34256294795445, 56.00823375156948, 54.73367357254028, 55.51903540747506, 39.60387734004429, 33.43802853993007, 53.711315631866455, 62.39942305428641, 55.40938588551113, 54.43979256493704, 53.090695585523335, 54.470246519361226, 54.489298479897634, 52.11902475357056, 56.34187235151018, 48.16672958646502, 40.148428508213584, 41.36712517057146, 41.12231234141758, 41.04381854193551, 39.237728118896484, 36.99452652250017, 39.8971712248666, 41.35920075007847, 40.474236488342285, 40.53889642442976, 39.891192299979075, 39.293056624276296, 39.0171297618321, 37.65727349690029, 39.15141759599958, 40.74962139129639, 39.09859391621181, 40.17884424754551, 42.03597961153303, 39.728083338056294, 39.27103083474295, 39.315402030944824, 42.025324548993794, 38.73420606340681, 39.306053229740684, 40.80755547114781, 42.67990739004952, 45.33326809746878, 46.15807138170515, 47.64993299756731, 46.418281418936594, 42.434865270342144, 46.321836948394775, 43.81342608588082, 49.56990786961147, 49.93494190488543, 52.4379540170942, 44.959152766636436, 44.70023162024361, 49.09821203776768, 59.18485287257603, 54.55174541473389, 63.48664937700544, 2.5090464055538177, 0.36499497879828724, 4.341296144894191, 3.81708539383752, 0.6475583208458764, 21.42586122240339, 68.12346022469657, 41.89326361247471, 31.43482119696481, 28.05194480078561, 34.60792105538504, 41.22579533713204, 0.8931887032730239, 0.14533035377306597, 0.12067545817366668, 0.07382296797420297, 0.010505629620248718, 0.15680423166070664, 0.11792106740176678, 0.07987859446023192, 0.05424005039302366, 0.004579752600485725, 0.03597050519394023, 0.030664490269763128, 0.02220200847036072, 0.042404682974198034, 0.021188467142305205, 0.05895062708961112, 0.07650242812399353, 0.14575717944119657, 0.05131682314510856, 0.22894170507788658, 0.092437361633139, 0.1675917442355837, 0.20867207273840904, 0.11049294777746711, 0.164684140256473, 0.44682939616697176, 0.1199691846434559, 0.1828442072229726, 0.13799226896039077, 0.1380683055945805, 0.1261679684477193, 0.3161350020340511, 0.1809429656714201, 0.1592682772981269, 0.22705224289425782, 0.15513526621673787, 0.20616240240633488, 0.2122667341360024, 0.22500861755439214, 0.13333066552877426, 0.14180775279445307, 0.22824058841381753, 0.8761179021426609, 63.0458973475865, 61.757027353559224, 56.58300263541085, 37.28577763693673, 41.988443510872976, 67.15187971932548, 68.3525562286377, 35.850693225860596, 3.4790355563163757, 0.3604465142956802, 0.37113553072725025, 0.22582128537552698, 30.952157633645193, 74.84692628043038, 61.56149114881243, 67.24828597477504, 57.90349040712629, 60.73132732936314, 56.29081004006522, 64.19676916939872, 62.57464967455183, 71.14660058702741, 61.621634755815776, 61.92847415379116, 62.79251044137137, 61.62258665902274, 58.74437182290213, 63.37642315455845, 62.188281195504324, 59.11867822919573, 51.15619897842407, 47.44936629704067, 44.821376936776296, 44.23978839601789, 47.560478414808, 47.42183058602469, 46.33255801882063, 45.6783503804888, 46.67887013299124, 48.072341782706125, 48.82788889748709, 45.120118209293906, 44.32093293326241, 47.54991020475115, 42.544810090746196, 44.73369761875698, 45.295146805899485, 47.647139821733745, 45.37988703591483, 46.01597029822213, 45.19727100644793, 43.416597093854634, 41.61986936841692, 46.404405866350444, 48.69040141786848, 46.82652630124773, 48.76943717684065, 46.61974443708147, 43.94299609320504, 44.256116662706646, 55.41272449493408, 60.14609445844378, 53.30767740522112, 57.52720723833357, 55.36565392357962, 61.12883377075195, 36.10834632601057, 31.144334384373256, 57.2500262260437, 62.5061890738351, 57.175433840070454, 54.06530897957938, 54.726530824388774, 56.79876504625593, 56.86754526410784, 53.23825100490025, 59.6612491607666, 48.592539514814106, 44.2767528125218, 43.52971724101475, 43.13865525381905, 42.70564351763044, 41.26247140339443, 39.24907800129482, 43.30242082050869, 42.915180342538015, 42.903149536677766, 41.58018473216465, 41.72762203216553, 40.57013552529471, 40.58238172531128, 39.58877543040684, 41.34620067051479, 42.3256812776838, 39.88093328475952, 40.88455540793282, 46.497053146362305, 42.17437730516706, 41.339120456150596, 41.353621346609934, 44.783738545009065, 40.08627339771816, 41.800887312207905, 42.737518378666465, 44.60548945835659, 47.136718205043245, 49.616825580596924, 50.64647912979126, 48.56769970485142, 45.400582245418, 50.3639931678772, 46.77398402350289, 52.76427616391863, 53.68374170575823, 55.50703239440918, 48.30640227454049, 46.713308879307334, 49.229682377406526, 62.46008777618408, 53.9975015095302, 66.51129749843052, 3.2387926876544952, 0.5420317405036518, 5.613310243402209, 8.026618940489632, 4.205092344965253, 23.941609382629395, 75.54371942792619, 46.5260340826852, 33.67927346910749, 36.64028303963797, 43.59902204786028, 50.37449189594814, 2.5497754429067885, 0.4088331993137087, 0.22459950165024825, 0.1777876964105027, 0.13998861398015702, 0.3701480451439108, 0.20719806397599833, 0.24761425597327097, 0.19567462589059556, 0.20483604286398205, 0.3812883687870843, 0.22384178159492357, 0.21617767427648815, 0.22073200132165635, 0.2027633355132171, 0.10798888214464698, 0.15778103710285254, 0.23395282189760888, 0.24626755395105906], [0.06552882732025214, 0.044153355926807435, 0.044662314866270335, 0.08877701126039028, 0.01833976509182581, 0.07900529274983065, 0.06217075072761093, 0.03614475637940424, 0.03938308171927929, 0.014640178431623747, 0.05610278168959277, 0.04516538751444646, 0.0687045951240829, 0.08388948280896459, 0.051786783284374645, 0.023378352401778102, 0.05178898173783507, 0.01313945320102253, 0.11967461902116026, 0.014773503777437975, 0.0730936513947589, 0.0647514093933361, 0.08898436477673904, 0.0799769548965352, 9.6660863501685, 58.90906497410366, 30.235919952392578, 31.248949936458043, 21.133564404078893, 42.60991818564278, 57.67229952130999, 60.69070816040039, 2.1775046416691373, 1.3377441657441003, 0.1581956491406475, 0.06077949609607458, 0.48623303749731606, 38.54923459461757, 65.98383889879499, 57.387506757463726, 62.30184950147356, 53.88686534336635, 61.255249295915874, 60.498534883771626, 60.38138825552804, 59.208198819841655, 63.684256144932334, 56.87260355268206, 58.8845100402832, 58.74360057285854, 59.94348498753139, 53.77747985294887, 51.048529693058555, 46.72925499507359, 43.11597285951887, 40.474167006356375, 42.03563220160348, 42.56655100413731, 43.88998828615461, 42.5724778175354, 41.80663694654192, 42.86911031178066, 41.9893467766898, 41.544530051095144, 41.022327763693674, 41.276291370391846, 39.21219001497541, 39.78247731072562, 37.99992043631417, 38.25088242122105, 40.24607501711164, 39.986212389809744, 40.21487065723964, 41.28097445624215, 41.09206683295113, 40.41700070244925, 44.39316293171474, 51.419108390808105, 52.080587318965364, 53.19406393596104, 48.14175081253052, 49.16113839830671, 43.74544143676758, 40.155710220336914, 42.26228591373989, 53.08287538800921, 52.666994435446604, 59.04181725638253, 52.255859102521626, 58.77336665562221, 49.63261188779558, 37.812506675720215, 25.696154594421387, 37.10541977201189, 63.94124916621617, 51.449069023132324, 55.99723475319998, 55.11090864453997, 54.91079705102103, 47.61376414980207, 53.00508335658482, 43.46552978243147, 39.211401394435335, 38.80655765533447, 38.637681688581196, 38.187577383858816, 38.841427189963206, 37.04990713936942, 38.27780669076102, 37.501484462193076, 37.38735335213797, 36.71788052150181, 36.94970369338989, 37.43024458203997, 38.88145228794643, 37.53632967812674, 40.05081326620919, 36.54201814106533, 37.138659954071045, 38.75122914995466, 37.09729732785906, 34.96549619947161, 38.18470082964216, 38.24683509554182, 37.42945943559919, 37.258481638772146, 38.119696957724436, 37.66348171234131, 38.74516337258475, 44.06257111685616, 44.48556702477591, 43.11589642933437, 41.879141398838584, 42.15261902127947, 42.887224265507285, 46.96970782961164, 49.20982442583357, 54.12104742867606, 52.33348090308053, 52.35074370247977, 46.21248619897025, 46.60423953192574, 53.54621601104736, 53.84934507097517, 46.99134799412319, 0.15595174740467752, 0.5345640012196132, 3.030542799404689, 1.6126079538038798, 0.45236670332295553, 32.53335918698992, 56.88336978639875, 25.457318953105382, 23.233178002493723, 26.01017495564052, 39.02394594464983, 15.764257090432302, 0.23350205751402037, 0.017602981234501516, 0.024644944883350815, 0.11211777451847281, 0.01347544084170035, 0.03944845517565097, 0.13375211719955715, 0.05198498675599694, 0.002553762385754713, 0.07056745194963046, 0.04902402278301971, 0.014587848114648035, 0.0047274934227711386, 0.045047899175967486, 0.05013977862628443, 0.09498000198176929, 0.06722272892615624, 0.059235157178980966, 0.048727455482419045, 0.07122185147766556, 0.07828303293458053, 0.032361815084836314, 0.15793902719659464, 0.12795366905629635, 0.09419327455439738, 0.16814090976757662, 0.022336114131446396, 0.01656918733247689, 0.05247369821050337, 0.026973541360348463, 0.040910046747220416, 0.0636752460684095, 0.08770747043724571, 0.15918738235320362, 0.16768770265792096, 0.05346920407776322, 0.051100285657282384, 0.12646751451705182, 0.09698693893317666, 0.07557767988847834, 0.05442245417673673, 0.03245563612186483, 0.030113411269017627, 14.667244229997907, 68.18263108389718, 29.546544006892614, 38.22231142861502, 29.087400095803396, 49.77092620304653, 65.09701251983643, 62.45212514059884, 3.1230135517460957, 1.9886949445520128, 0.8301848811762673, 0.29444978279726847, 1.0221057427780968, 44.09604753766741, 65.88279819488525, 57.83020428248814, 63.70201574053083, 55.43229409626552, 61.23348753792899, 64.08681392669678, 62.202816826956614, 63.47027942112514, 65.15685040610177, 59.162750652858186, 59.046187673296245, 58.935475076947895, 61.299592699323384, 56.94116490227835, 54.37185307911464, 49.64341981070382, 45.02152674538748, 42.25004666192191, 43.93920585087368, 44.57626186098371, 45.88719238553728, 44.328242438180105, 45.18157502583095, 44.26366935457502, 42.28577082497733, 42.553297315325054, 44.39766536440168, 44.135669640132356, 42.789991174425396, 42.49255616324288, 40.46028797967093, 40.28933102743966, 42.48143209729876, 42.237404414585654, 42.39125837598528, 44.80759865897042, 44.07842690604073, 41.39918415887015, 45.298850195748464, 54.114880902426584, 52.28407226290022, 54.47941814150129, 50.589559486934114, 49.89279065813337, 45.7967198916844, 42.92507805143084, 46.787647656032014, 54.796342849731445, 52.640626021793906, 56.85793590545654, 55.97967665536063, 60.08471407209124, 54.20042017527989, 41.734935011182515, 30.016589641571045, 44.82231146948678, 62.9679594039917, 54.35446868624006, 54.85870293208531, 54.92376238959176, 55.658138343266074, 49.459900515420095, 56.82000568934849, 45.06304570606777, 40.58776657921927, 40.81324257169451, 41.405628613063264, 40.29423645564488, 39.755000659397666, 39.15313727515084, 39.29648903438023, 39.97566849844796, 39.771370615277974, 39.177848543439595, 38.84754160472325, 38.32652745928083, 39.77062715802874, 39.94087191990444, 42.00258656910488, 40.24251406533377, 39.84176628930228, 41.11401966639927, 39.12302725655692, 37.68369402204241, 40.02556698662894, 39.73562560762678, 39.62922089440482, 39.910640307835166, 41.832348755427766, 39.16607829502651, 41.19398300988333, 44.57833589826311, 45.86892557144165, 46.39035313470023, 45.54369081769671, 45.080430098942344, 44.521148749760215, 48.65536860057286, 51.652265616825645, 56.12421655654907, 54.3012489591326, 55.82830320085798, 48.15358359473092, 47.61384752818516, 54.66800962175642, 57.96997424534389, 50.11686658859253, 0.2716524989477226, 1.3020815593855721, 8.935025555746895, 4.058272131851741, 0.753192598266261, 35.27123083387102, 61.93436622619629, 31.74991158076695, 30.317748887198313, 27.296635661806377, 44.242480822971885, 18.311006375721522, 0.35794996683086666, 0.008687857205846479, 0.03928245158333864, 0.054258316555725675, 0.012978575940776085, 0.1064691808340805, 0.20219633808093412, 0.04692412653405752, 0.03830985984365855, 0.0748638678342104, 0.07467940808939082, 0.010445406244668578, 0.09511406014540366, 0.025265224277973175, 0.015684414987585375, 0.021061838937125037, 0.05158604887713279, 0.07936836326760904, 0.05367891889597688, 0.2023654154368809, 0.2780575709683554, 0.1538390200585127, 0.22736525109836034, 0.22469080532235758, 0.15808308018105371, 0.347378744078534, 0.13877673686615058, 0.15279611173485005, 0.10362139650221382, 0.12589257822505065, 0.09916805582387106, 0.17140072770416737, 0.21465307394308702, 0.19004787424845354, 0.27496092713304926, 0.19110064847128733, 0.19770773393767221, 0.2575813925692013, 0.17166372787739548, 0.1759293925549303, 0.12352674374622957, 0.18106363633913652, 0.2418102031307561, 19.54258152416774, 78.9784015927996, 41.86526584625244, 45.11471945898873, 30.4330472946167, 54.35455901282174, 67.15727846963065, 72.28344399588448, 3.383652205978121, 2.941548534802028, 0.5255696667092187, 0.21321747026273183, 1.2579471447638102, 44.70351116997855, 70.46289089747837, 56.55904524666922, 68.14187295096261, 57.68967349188668, 65.24587767464774, 65.04592241559709, 64.83796283176967, 64.57501520429338, 66.55392469678605, 58.90525736127581, 61.57251099177769, 62.70808982849121, 66.732284954616, 58.545062746320454, 55.81851666314261, 52.21210282189505, 48.246168340955464, 45.11505992071969, 45.603827476501465, 47.573777266911094, 48.62333740506853, 47.20168386186872, 45.854264872414724, 47.78286593300955, 45.737385749816895, 44.78187642778669, 46.28854465484619, 46.07571785790579, 43.44661678586687, 45.188189710889546, 43.82302849633353, 42.46029915128435, 46.49272441864014, 45.27420840944563, 43.62451498849051, 46.8719744682312, 47.90753746032715, 45.46072932652065, 49.00815643583025, 57.3102080481393, 58.026657649448936, 57.86192628315517, 52.19228655951363, 51.82652991158621, 48.7667794908796, 44.377668448856895, 47.04497766494751, 55.84887681688581, 57.21495519365583, 60.03461061205183, 55.6024728502546, 61.507976123264854, 52.405426025390625, 35.73370293208531, 28.06183382443019, 41.52124316351754, 68.43428094046456, 54.76845278058733, 58.59524263654436, 56.22109528950283, 57.25741563524519, 48.563569000789094, 57.0637971333095, 47.271409034729004, 42.92824295588902, 42.36675207955496, 43.09951605115618, 41.343365805489675, 41.49192871366228, 41.111396721431184, 43.16572196143014, 40.877197265625, 41.60002531324114, 41.01236752101353, 41.596523421151296, 42.02432748249599, 42.361832754952566, 42.02295868737357, 44.26562874657767, 42.311381884983604, 41.24354798453194, 43.44269452776228, 42.37175130844116, 40.40963213784354, 42.61496952601841, 42.02816983631679, 43.885402475084575, 42.881610121045796, 44.09612396785191, 40.2853045463562, 43.14894553593227, 47.58079842158726, 47.16136693954468, 47.945967946733745, 47.599221570151194, 46.39984437397548, 47.38014139447893, 51.118960108075825, 54.45836509977068, 57.19479152134487, 57.127730982644216, 58.5852233341762, 50.03808443886893, 50.71464095796858, 58.75561400822231, 58.09035873413086, 53.699600969042095, 0.460536319230284, 2.144117896045957, 9.505154779979161, 8.288632903780256, 1.844196732555117, 41.72567653656006, 69.33898503439767, 36.37336451666695, 36.41881963184902, 38.11960663114275, 51.90918220792498, 27.32834550312587, 0.2914030248565333, 0.11825589729206902, 0.2073503000927823, 0.19189119605081423, 0.08810318527477128, 0.16630824096500874, 0.26299428354416576, 0.14858642619635376, 0.11367050691374711, 0.14291688613593578, 0.1981815006583929, 0.10548608537231173, 0.3107822835445404, 0.17016397549637727, 0.17010925843247346, 0.1574897827314479, 0.1363103027854647, 0.09216863462435347, 0.14263469699238027], [0.07978434594614164, 0.05302688406248178, 0.07880076872450964, 0.012919648567081561, 0.04265904200396367, 0.11182447775666203, 0.03418388856308801, 0.059561675015304766, 0.08503378462046385, 0.1281175081218992, 0.08520286876176085, 0.015926329685109, 0.09081832279584237, 0.05749962066433259, 0.057388320565223694, 0.06417586241981812, 0.06578253834907498, 0.1462616023740598, 0.01719725800545088, 0.08991841572735991, 0.0810456204095057, 0.15688590013555118, 0.04630531956042562, 0.03695313585922122, 0.16856214430715355, 36.7872964995248, 52.36951773507254, 30.9862003326416, 23.258691787719727, 28.88635049547468, 45.23042433602469, 46.513575962611604, 13.633765697479248, 2.593150658266885, 1.075910747051239, 0.3803424909710884, 0.3495150165898459, 1.7141919199909483, 48.25513499123709, 58.81941931588309, 59.63374819074358, 58.51673494066511, 64.6044408253261, 59.32158647264753, 64.59954929351807, 61.10218048095703, 62.52228110177176, 59.35678604670933, 57.43699182782854, 54.59650223595755, 51.451521737234934, 45.827861717769075, 42.31147221156529, 38.194831303187776, 41.463597433907644, 41.83165740966797, 42.480966567993164, 42.836339133126394, 44.521381514413015, 43.751458576747346, 43.308069705963135, 40.63105385644095, 42.19124753134591, 42.9914368220738, 41.874486105782644, 40.12754569734846, 41.105146816798616, 40.9030966758728, 39.36702367237636, 41.03241307394845, 39.14912816456386, 38.542143957955496, 39.27663803100586, 40.87149279458182, 41.95554379054478, 45.29899263381958, 47.954663617270334, 54.48643582207816, 52.73442322867257, 57.42733383178711, 50.39954710006714, 52.750730650765554, 51.14291402271816, 49.1320914540972, 42.045140811375205, 43.22810983657837, 47.730163846697124, 55.78880269186837, 48.53945875167847, 55.66340855189732, 51.06090790884835, 55.7159160886492, 26.139541728155955, 26.141952753067017, 62.97601931435721, 48.66903223310198, 55.7567332812718, 52.83942093167986, 52.05721705300467, 52.129784039088655, 46.917881216321675, 38.243666716984336, 42.68033817836216, 38.057534899030415, 39.114546980176655, 38.052938665662495, 39.42652457101004, 38.830758231026785, 37.51946987424578, 36.5334266935076, 38.87891966956002, 38.04882533209664, 39.05719654900687, 38.635510376521516, 38.348706109183176, 39.058950969151084, 38.658911909375874, 40.68116079057966, 40.05227238791329, 38.85652909960066, 38.83568797792707, 38.79032666342599, 37.259742736816406, 36.9740640776498, 37.651978969573975, 39.44495466777256, 37.63459805079869, 37.896260261535645, 39.3196508543832, 43.18834529604231, 42.57436425345284, 45.365987164633616, 42.066492625645225, 42.61281558445522, 43.24280527659825, 49.81489787782942, 49.97324384961809, 54.162747042519705, 53.82173292977469, 52.741968972342356, 50.36593518938337, 51.023165294102256, 52.63188518796648, 57.52324676513672, 44.255387101854595, 0.34253785812429016, 0.6336443360362733, 5.13314151763916, 2.1028742577348436, 0.9788796965565, 47.97580698558262, 51.66588061196463, 23.49795821734837, 25.45974734851292, 29.612850666046143, 39.92405727931431, 2.2517522232873097, 0.4763027046407972, 0.06803481999252524, 0.05523904053760426, 0.023302704228886535, 0.04961497250146099, 0.036985227172928195, 0.012078988631921155, 0.037774780698652775, 0.1424681573574032, 0.04314558893176062, 0.022432528868583695, 0.12680011881249292, 0.08174076596541063, 0.0437919138930738, 0.055444375412272554, 0.06251171457448176, 0.1142652699989932, 0.060076377753700526, 0.11422320082783699, 0.09112582129559346, 0.06530423901442971, 0.1033381624147296, 0.05077346587287528, 0.11619228231055395, 0.11329470029366867, 0.0221143400496138, 0.03971967240795493, 0.18626691427614006, 0.06947683582880668, 0.06080479866691998, 0.02105906542523631, 0.022472129868609563, 0.03919634548947215, 0.03697379046518888, 0.078620163058596, 0.041025913387004814, 0.17211367801896163, 0.03749431503404464, 0.07563811700258936, 0.029380145615765026, 0.16621255395667894, 0.013931338342704942, 0.02184503458972488, 0.5909037409084184, 49.179895060403005, 51.10996566499983, 32.728183201381135, 32.75354412623814, 33.89380604880196, 54.19205801827567, 55.01372766494751, 14.584138563701085, 2.291144383805139, 2.727375307253429, 1.0907849946192332, 0.4413545956569058, 2.403690653187888, 53.27279050009591, 62.14948245457241, 61.08317020961216, 59.05349717821394, 67.3610691343035, 59.48434802464077, 64.75798211778913, 61.71530342102051, 64.30395902906145, 62.25991712297712, 61.497095244271414, 56.047265257154194, 54.75415686198643, 49.947809968675884, 46.23217739377703, 40.62420988082886, 44.17143201828003, 44.85680232729231, 44.862381730760845, 43.66636051450457, 47.84520517076765, 45.030611515045166, 45.91296672821045, 42.095049721854075, 44.718223980494905, 44.06541987827846, 43.422513484954834, 42.954986572265625, 41.98750550406319, 44.355510643550325, 42.0938754762922, 42.86036600385393, 42.33808033806937, 38.95099333354405, 42.51779202052525, 43.58995812279837, 43.65548658370972, 46.19924293245588, 49.59674181256975, 55.98508930206299, 53.2482042993818, 57.432826382773264, 51.55849620274135, 54.9371828351702, 52.33783047539847, 50.990366322653635, 44.324299335479736, 46.949505942208425, 52.70079742159162, 58.643761907305034, 50.05229697908674, 56.211239269801546, 55.15685360772269, 58.99765450613839, 24.173510721751622, 22.40424054009574, 66.58407987867082, 51.968905448913574, 57.53109128134591, 53.7870648929051, 54.125692299434114, 53.08708947045462, 51.43992519378662, 40.426780291966026, 44.336090428488596, 39.46541016442435, 40.93255008969988, 38.8117618560791, 41.748713288988384, 40.850061076028005, 38.839075224740164, 38.07137223652431, 39.96851880209786, 39.968386786324636, 40.59903655733381, 40.47916276114327, 40.48830311638968, 40.49178416388375, 39.461977754320415, 39.59087378638131, 41.540979521615164, 40.403225898742676, 40.04686321531023, 39.600990363529746, 39.9053110395159, 39.90748929977417, 39.98242562157767, 40.36496564320156, 38.547032015664236, 40.090376308986116, 42.64314447130476, 45.218775681086946, 45.00987114225115, 47.54974692208426, 45.72788061414446, 44.04975169045584, 46.294283866882324, 53.05914728982108, 52.619298526218955, 55.52716132572719, 55.517996651785715, 54.509597642081125, 53.98370238712856, 53.58909681865147, 56.03721121379307, 59.73207909720284, 44.71076856340681, 0.1971505752631596, 2.642866539103644, 14.06593930721283, 2.4920702193464552, 1.165273700441633, 52.279524666922434, 58.97701140812465, 30.375596114567347, 33.01331295285906, 32.69004453931536, 49.27895900181362, 3.2492783878530775, 0.4787736034819058, 0.11679646346185889, 0.05684524488502315, 0.17130524425634316, 0.11526298789041382, 0.04419562526579414, 0.009615371319731432, 0.10180733991520745, 0.10011958583657231, 0.047525590152612755, 0.022360419255814383, 0.041898173546152453, 0.05998445661472423, 0.03367008488359196, 0.028032173036730716, 0.09008385613560677, 0.02407242078334093, 0.05777273100933858, 0.03325895373044269, 0.1445036538477455, 0.1125234706061227, 0.1543822551944426, 0.10871848370879889, 0.18231398638870033, 0.31743909205709187, 0.16591555917901651, 0.24431462160178594, 0.5243309874619756, 0.20563436645482266, 0.1467382325125592, 0.11510769836604595, 0.15600616591317312, 0.16042835504880973, 0.22811959204929216, 0.1744740435055324, 0.10243398057562964, 0.38377612243805614, 0.1639102439263037, 0.21086264162191323, 0.20164960170430796, 0.2370034610586507, 0.17892322476421083, 0.13935708786760057, 0.8733502392257962, 57.633427824292866, 64.58327661241803, 46.36443982805525, 37.03296743120466, 39.86898238318307, 53.21525246756417, 59.6271196092878, 18.244430473872594, 9.9597840990339, 3.79584344795772, 0.7617244975907462, 0.6362412795424461, 3.061317022357668, 54.41944476536342, 63.8668270111084, 62.66521944318499, 61.071816853114534, 69.63544382367814, 64.6527933393206, 68.81914860861642, 65.91608701433454, 67.76852539607457, 65.76310852595738, 62.585613931928364, 59.47068091801235, 56.58172069277082, 51.67475346156529, 49.67152179990496, 41.87917613983154, 46.98848186220442, 47.918776171548025, 46.29340839385986, 46.04814393179757, 50.04013763155256, 47.66476740155901, 49.119963373456685, 45.459138189043315, 46.67141124180385, 46.40594489233834, 46.02187974112374, 44.778937339782715, 45.18894706453596, 46.2032972063337, 44.951683453151155, 46.59547437940325, 44.04753521510533, 41.70663499832153, 45.48158434459141, 45.88152265548706, 46.7406222479684, 47.641028881073, 51.528347969055176, 58.072105816432405, 56.78296136856079, 60.88016469138009, 54.16108642305647, 57.540127413613455, 55.48032699312483, 54.506088801792686, 47.53319978713989, 47.47235093797956, 53.77703169413975, 61.53674166543143, 51.729675497327534, 57.978656019483296, 56.293047360011506, 62.827862875802175, 26.370906318937028, 25.021519252232142, 68.47559492928642, 50.926043374197825, 58.92777647290911, 54.328829833439414, 56.924249512808665, 53.60754428591047, 50.92918395996094, 40.52575043269566, 47.07929481778826, 42.087545667375835, 43.37389693941389, 40.8688976424081, 43.41783734730312, 44.20440469469343, 41.794342109135215, 40.65503208977835, 43.218767983572825, 41.558061667851035, 44.072222164699006, 42.58131940024239, 40.57832745143345, 42.34795372826712, 42.44562108176095, 43.219737257276265, 43.59097950799124, 42.5430383001055, 42.59877674920218, 42.62190382821219, 42.24559981482369, 42.29680803843907, 42.186640875680105, 42.801181248256135, 41.16767365591866, 42.23349257877895, 45.681741101401194, 48.24495588030134, 45.97336394446236, 51.86496039799282, 46.99601718357631, 47.90584904806954, 49.38686800003052, 56.45459645135062, 55.109473841530935, 56.937430245535715, 57.10894652775356, 57.71559722082955, 56.47149794442313, 56.334132058279856, 58.24862827573504, 61.7545051574707, 45.211605140141074, 0.7743197903037071, 2.5537285336426327, 13.076029453958784, 9.168479817254202, 1.0379031236682619, 59.076731954302105, 64.33538573128837, 35.19026000159127, 41.50522061756679, 42.806729384831016, 57.66862392425537, 6.367116400173732, 0.9032960523452077, 0.2154468513493027, 0.1491549571177789, 0.2675476334989071, 0.13769859900431974, 0.15310947277716228, 0.113086295048041, 0.16723889245518617, 0.29181638838989393, 0.13201514897601946, 0.15719319507479668, 0.16957648630653108, 0.17934958902852877, 0.13840138486453465, 0.18707404525152274, 0.17238667979836464, 0.18546865853880132, 0.16512480803898402, 0.1493253101195608], [0.06590128876268864, 0.031203213147819042, 0.01964551074031208, 0.021741663172308887, 0.012626703795311707, 0.09305389212178332, 0.012441499358309167, 0.09175136951463563, 0.09122348284082753, 0.05286586091720632, 0.10583371921841588, 0.027388853985550146, 0.013510264955194933, 0.06927100223089967, 0.03719223463641746, 0.02751929555753512, 0.04632951272651553, 0.03852553219933595, 0.035873318623219214, 0.04311807094407933, 0.07552345815513815, 0.08510053211024829, 0.07854764123580285, 0.080698875444276, 0.1436091818447624, 2.6757158849920546, 49.01022005081177, 36.28684554781233, 30.495758260999406, 26.628123419625418, 31.453115803854807, 57.43316337040493, 28.299486534936086, 0.5306455429111208, 3.557937345334462, 0.934298751609666, 0.4568071450505938, 0.09538874469165291, 8.223316362925939, 48.52750090190342, 62.412610735212056, 63.28956372397286, 61.56501388549805, 59.87834562574114, 59.28406620025635, 59.921500887189595, 58.984445980616975, 53.72743545259748, 48.962815965924946, 44.73382616043091, 43.0728314944676, 40.28067357199532, 42.77825914110456, 44.57917663029262, 45.62929262433733, 47.34037337984358, 47.51065288271223, 41.93869093486241, 42.32038675035749, 41.81270967211042, 42.73896707807268, 42.5613363810948, 42.26663548605782, 42.685462474823, 41.92582981927054, 43.32573897497994, 42.40886858531407, 42.758554049900596, 40.55406434195382, 39.81653390611921, 40.72426741463797, 39.72827788761684, 42.083696365356445, 42.17351572854178, 41.55429227011544, 45.80539819172451, 52.96739285332816, 55.062319891793386, 55.86052199772426, 54.76975209372384, 53.77782031467983, 54.31049353735787, 53.89509548459734, 55.24260480063302, 51.98857927322388, 48.416472162519185, 44.77230181012835, 47.11297621045794, 48.825721059526714, 57.353276457105366, 47.98827205385481, 53.16977303368704, 52.8583790915353, 38.127273968287874, 56.59160450526646, 52.656971658979145, 57.784717900412424, 49.45718376977103, 52.46509368079049, 46.62569209507534, 41.748167855399, 38.099019118717735, 39.97424759183611, 36.79761457443237, 40.93942185810634, 39.90493583679199, 40.58817304883684, 40.408249446323936, 39.12414244243077, 36.942998681749614, 37.56898621150425, 37.495668819972444, 38.20714003699166, 39.19415596553257, 38.63257128851754, 39.120254925319124, 40.03184468405587, 39.29540858949934, 39.288390908922466, 38.96130446025303, 38.536682673863, 38.61342205320086, 39.158296312604634, 37.46611813136509, 37.50518437794277, 39.30636937277657, 37.86598348617554, 37.62064259392874, 39.22746215547834, 40.58809314455305, 42.13707937513079, 42.05353076117379, 42.23793247767857, 42.666087423052105, 43.05329663412911, 49.19531658717564, 52.70318760190691, 52.38045767375401, 53.87300716127668, 53.75216409138271, 52.217286178043906, 54.44408655166626, 53.27168921061924, 60.730827059064595, 37.25806474685669, 0.10583394992032222, 1.6147083725248064, 12.841325385229927, 2.4772770702838898, 4.371278490339007, 66.05440480368478, 26.164129665919713, 18.528491939817155, 26.07791989190238, 34.52166264397757, 20.639835834503174, 0.059024261709834845, 0.045878215692937374, 0.08608744093882185, 0.03778082983834403, 0.06790002901107073, 0.020794407930225134, 0.03901537341464843, 0.01945920368390424, 0.0501990316967879, 0.07200253315802131, 0.008404343222667063, 0.032795514312705824, 0.037353583478501866, 0.06621594580688647, 0.0782880676644189, 0.1270558586610215, 0.0751539415546826, 0.027890308327706795, 0.060451858676970005, 0.03142832392560584, 0.026784094383141825, 0.031096320133656263, 0.08578136736260993, 0.027516276076702133, 0.050646484829485416, 0.09446515675101962, 0.043000131379812956, 0.06385420289422784, 0.1644942183047533, 0.02767449178333793, 0.043478159300450764, 0.021114912249946167, 0.020978952491922036, 0.03821381999711905, 0.11429040293608393, 0.046138328699661155, 0.037509975622275045, 0.07706764100917748, 0.08773807915193693, 0.023550566285848618, 0.07332301658711263, 0.0972030387659158, 0.03938652867717402, 0.02425203239545226, 0.15415714441665582, 6.170822841780526, 61.791997637067524, 31.620077541896276, 38.77608633041382, 30.950410161699565, 36.97320250102452, 58.31505652836391, 32.256018366132466, 0.7773169609052795, 2.5692464666707173, 2.252425981419427, 1.114559558885438, 0.1980267132499388, 8.394739712987628, 53.34381151199341, 62.45314652579171, 66.89667933327812, 63.4894495010376, 61.37867709568569, 61.36944988795689, 63.19913986751011, 59.13575690133231, 56.509417738233296, 51.888556480407715, 49.05737052645002, 45.340285778045654, 42.631332533700125, 45.94115209579468, 47.069508280072895, 45.83969797406878, 48.03082629612514, 48.976618562425884, 43.10407754353115, 45.57453039714268, 43.39389385495867, 45.05800478799002, 43.63563558033535, 45.429372106279644, 43.90954399108887, 44.370046275002615, 45.00255468913487, 44.87777893883841, 44.60986682346889, 42.51212576457432, 43.42797129494803, 42.520515714372905, 42.79576512745449, 44.93309702192034, 43.089788573128835, 43.82399429593767, 48.43388087408883, 55.90351745060512, 57.46491663796561, 58.56489985329764, 58.696533475603374, 55.64533976146153, 56.6636642728533, 55.26134409223284, 56.05954967226301, 53.72635848181588, 49.358748640332905, 47.21026141302926, 50.000935895102366, 51.05566896711077, 57.10325595310756, 53.24801322392055, 54.593865394592285, 55.9043755531311, 40.90544169289725, 57.15574959346226, 53.993739059993196, 57.639736788613455, 52.9746606690543, 51.549612930842805, 49.96325581414359, 42.181367192949565, 39.66191911697388, 40.764514854976106, 38.47097355978829, 42.32764761788504, 40.87116970334734, 42.13830920628139, 43.13112688064575, 40.2746981212071, 39.22073629924229, 39.029306479862754, 39.389594895499094, 40.260926791599815, 40.956427574157715, 39.965360845838276, 40.68025752476284, 43.350234849112375, 39.83219861984253, 39.71240472793579, 40.753769465855186, 40.13423333849226, 40.419509002140586, 40.06011343002319, 39.532123293195454, 39.86382334572928, 40.359209060668945, 40.60148927143642, 38.76955154963902, 40.50316531317574, 42.980778285435264, 43.90802580969674, 44.56456456865583, 44.55944374629429, 44.2363976751055, 46.27013887677874, 50.25456946236746, 54.50417457308088, 54.73597690037319, 56.29364837918963, 56.38616711752755, 53.632227761404856, 57.41685594831194, 57.15809113638741, 60.8591741834368, 40.20538636616298, 0.08053361145513398, 3.5603040754795074, 10.431217636380877, 0.620871538562434, 4.707445366042001, 71.88231754302979, 33.2581535748073, 26.620909452438354, 28.418964283806936, 41.26685224260603, 26.995625802448817, 0.14618342156921113, 0.01080480928067118, 0.04086898180789181, 0.04174222923549158, 0.04091238769303475, 0.014897249905126435, 0.05487356800585985, 0.026100373660613383, 0.04773128465084093, 0.0610015873930284, 0.0198576360541795, 0.07331269606947899, 0.07189778770719256, 0.04618829941110952, 0.05387027594926102, 0.08195966136242662, 0.11278044538838522, 0.03603266239432352, 0.05083505988919309, 0.07742750205631767, 0.1229671694870506, 0.08099106619400637, 0.15860114166779177, 0.15699118162904466, 0.14111285151115485, 0.1719723256038768, 0.13212532949234757, 0.1358692143112421, 0.24416298259581837, 0.09329089761844703, 0.23566435862864765, 0.0677320169551032, 0.10472359521580593, 0.2158784403332642, 0.12269693613052368, 0.1071300942982946, 0.1792547841157232, 0.20062585520957196, 0.15706086717545986, 0.14035127737692424, 0.2043220525873559, 0.139220729470253, 0.09844228798257453, 0.18992752927754605, 0.35252024818743977, 10.318005425589424, 75.94401209694999, 47.11445270265852, 48.014543192727224, 39.783505644117085, 40.95616006851196, 69.63683346339634, 36.67775467463902, 3.8610796502658298, 11.174263204847064, 3.1941422607217516, 1.4574026763439178, 0.17902052668588503, 10.231654950550624, 52.78187247685024, 66.01088823590959, 68.63957241603306, 67.84434413909912, 65.91359261104039, 65.16447952815464, 65.22895881107875, 63.732553073338096, 59.21901021684919, 53.620895249503, 49.510837759290425, 48.655445030757356, 45.06510932104928, 48.37011725561959, 50.034978594098774, 49.47329316820417, 52.80814708982195, 52.165483883449006, 46.83486761365618, 47.33381428037371, 44.66920791353498, 46.99730954851423, 46.861138752528596, 47.23468433107649, 46.28557777404785, 45.92381634031023, 48.28021798815046, 46.70456804547991, 48.82960510253906, 45.449542726789204, 46.076673235212056, 45.08334834235055, 45.860990728650776, 47.807386125837056, 46.75357369014195, 46.52323395865304, 51.29420409883772, 58.84457874298096, 61.38868250165667, 60.98367200578962, 58.440978731427876, 57.76509271349226, 60.00364249093192, 57.140265532902305, 59.023216928754536, 56.85119267872402, 51.78185299464634, 49.20918519156319, 52.429119382585796, 53.91120488303048, 58.93051406315395, 53.10354975291661, 55.46762568610055, 52.30395800726754, 38.766348430088584, 59.709504399980815, 54.49076107570103, 59.77273300715855, 53.155060223170686, 55.16706051145281, 49.88273661477225, 43.7276679447719, 42.38142320087978, 43.19985498700823, 39.912964480263845, 45.21794884545462, 43.31668199811663, 44.51035124914986, 44.9087679045541, 42.68664714268276, 41.073657580784385, 42.235709054129465, 41.24743897574288, 42.66649041857038, 43.45885951178414, 42.2514397757394, 43.15152679170881, 45.58285781315395, 42.728645529065815, 42.87532894951956, 43.7770870072501, 42.778971331460134, 42.59272486822945, 43.86202873502459, 40.99783536366054, 42.28816447939192, 43.44617210115705, 45.07790790285383, 41.45106635774885, 43.320246423993794, 45.53833723068237, 46.43822622299194, 47.282633849552695, 48.16963740757534, 46.86057594844273, 48.1734276499067, 54.16261502674648, 56.33866923195975, 55.56545284816197, 58.819134439740864, 59.24282169342041, 57.35279355730329, 59.96810245513916, 58.851513045174734, 63.07236303601946, 41.26325307573591, 0.1446056512317487, 4.686867407390049, 22.027563061032975, 8.04794991016388, 5.103944752897535, 81.16835566929409, 35.28373064313616, 30.309800148010254, 37.71492270060948, 47.65598487854004, 38.127430302756174, 0.13777000802968228, 0.16660870984196663, 0.19986201476837906, 0.10535182364817176, 0.13178460991808347, 0.15524769946932793, 0.08782907748328787, 0.19213731427277836, 0.1568117905408144, 0.17506721881883486, 0.06688370568943874, 0.09848420109067645, 0.14649257569440774, 0.21204295328685216, 0.10703841064657484, 0.2064698873353856, 0.148484591660755, 0.1518184920506818, 0.17754806498331682, 0.10929154045879841], [0.04223651485517621, 0.06239459943026304, 0.005438573101335871, 0.00963601574767381, 0.040062831315611086, 0.05886312321360622, 0.03626212597425495, 0.04804964988891568, 0.06521917107914176, 0.08418465911277703, 0.016379933737750565, 0.012055027015906359, 0.09237977436610631, 0.04719660923417125, 0.0692381611359971, 0.03566486248746514, 0.0768166101936783, 0.09616218640335969, 0.030002484364168983, 0.03880217771178909, 0.02520361838729254, 0.030529047894690717, 0.15886646243078367, 0.023989127217126743, 0.07696707533406359, 0.09658737001674515, 24.295102460043772, 52.19356155395508, 19.84001132420131, 29.990964685167583, 27.62131108556475, 58.60686002458845, 47.292607988630024, 0.6154573719416345, 1.7616317229611533, 0.7053230383566448, 0.9595026906047548, 0.15232656550194534, 0.12984500399657659, 23.680756637028285, 61.227303641183035, 61.14525931222098, 62.9583500453404, 58.670415197099956, 57.891994612557546, 53.32432528904506, 50.16611194610596, 48.19516856329781, 45.82873024259295, 45.481698989868164, 45.78950418744768, 46.97600984573364, 48.0839661189488, 52.69145209448678, 55.76908370426723, 60.261531829833984, 57.715413093566895, 49.4046310697283, 43.19246557780674, 44.80029262815203, 43.662695339747835, 41.33777597972325, 41.51480565752302, 41.66398695537022, 43.10900034223284, 42.81067943572998, 41.54635047912598, 43.57837894984654, 41.965281690870015, 40.809389795575825, 40.73955692563738, 39.70203454153878, 38.84981713976179, 40.650456701006206, 41.191644941057476, 46.815509932381765, 51.29486070360456, 55.17787190846035, 56.221546922411235, 54.82240901674543, 52.38030481338501, 55.28656257901873, 54.22508628027779, 55.440399169921875, 52.18235758372715, 53.76596321378435, 53.09234578268868, 50.31634242194039, 50.89192424501692, 54.38288681847708, 50.35119458607265, 44.97306306021554, 50.58346939086914, 52.53298452922276, 55.293059144701274, 54.349577154432026, 54.37488596779959, 50.979450702667236, 47.94794123513358, 41.29386683872768, 40.24716241019112, 38.50298738479614, 42.24810116631644, 39.94712182453701, 39.89277648925781, 39.198634079524446, 38.930968625204905, 39.504441670009065, 38.12881646837507, 36.63590914862496, 38.01938581466675, 39.51527738571167, 40.48827879769461, 39.80477408000401, 38.19945532935006, 38.161438260759624, 42.02113478524344, 46.15607030051095, 46.51345436913626, 47.61693947655814, 45.57754591533116, 42.12741790499006, 38.140784740448, 39.49522835867745, 37.160397393362864, 39.157250608716694, 37.28638560431344, 40.0121465410505, 37.15055527005877, 41.47458948407854, 37.90254143306187, 42.52125569752285, 42.34500421796526, 42.43060949870518, 43.52489519119263, 48.650650773729595, 48.121896335056846, 54.55382292611258, 53.271004813058035, 56.22185264314924, 51.81189005715506, 58.86796637943813, 52.64614289147513, 66.5413623537336, 14.817500761577062, 0.4915032461285591, 4.416792665209089, 17.711875370570592, 1.2717465928622653, 14.496222138404846, 52.83213227135794, 12.086851767131261, 34.534794739314485, 23.975832734789165, 33.65815094539097, 5.306239817823682, 0.5312236004642078, 0.06107907609215804, 0.051809246186167, 0.10882685253662722, 0.06841171905398369, 0.05521695422274726, 0.034517303707876375, 0.11391829433185713, 0.09144315855311495, 0.03588408697396517, 0.017492262979171107, 0.013833107676223984, 0.005049148707517556, 0.04674236396593707, 0.03862158900925091, 0.05616945114785007, 0.017552362522110343, 0.0243830184917897, 0.009914664634769517, 0.04115887910925916, 0.06649563794157334, 0.04316107988623636, 0.0483517065378172, 0.02257674979045987, 0.019289208609344702, 0.02341936475464276, 0.04044385586998292, 0.0366701019395675, 0.025825773931241462, 0.043800551643861194, 0.08094669678913695, 0.01882146897592715, 0.02274914687898542, 0.056016159909112115, 0.025875040662607977, 0.05224594793149403, 0.013860639234605645, 0.027712438854255846, 0.048232233484408686, 0.061051941476762295, 0.06869346036442689, 0.034294482985777516, 0.06874572113156319, 0.15918061057371752, 0.09124991177980389, 0.2855575813778809, 38.19392456327166, 55.5312294960022, 24.580445868628367, 42.248090744018555, 31.363181795392716, 68.45887061527797, 50.8166127204895, 1.099791705608368, 1.705769183380263, 5.864725598267146, 1.907493301800319, 0.6785975524357387, 0.37197476997971535, 25.87851354054042, 64.76800142015729, 65.10165391649518, 64.45375524248395, 63.531499998910085, 60.515141078404014, 56.35635587147304, 52.485173974718364, 50.59819262368338, 49.38579102924892, 46.463086877550396, 47.56678737912859, 50.02964237758091, 49.844643115997314, 53.05035434450422, 57.68930523736136, 61.83424268450056, 58.47273199898856, 50.677832875932964, 44.59349339348929, 46.30734300613403, 45.01176800046648, 43.720810072762625, 45.39576019559588, 44.396063804626465, 44.843652861458914, 45.31064476285662, 44.284586906433105, 46.25389051437378, 44.55331196103777, 44.59336832591465, 44.09868785313198, 42.996936321258545, 40.7850467818124, 42.14970077787127, 42.904295989445274, 46.81518336704799, 53.76061657496861, 57.94252191271101, 57.563890252794536, 56.41291420800345, 54.543115752083914, 57.75462525231497, 56.28533833367484, 54.90732295172555, 55.51327535084316, 57.536799226488384, 54.5302928515843, 51.61723974772862, 53.00516326086861, 56.44112736838204, 53.17714507239205, 47.05519846507481, 54.184279509953086, 57.14241252626692, 56.30867385864258, 55.83516454696655, 56.181886604854036, 53.07537828172956, 49.098326683044434, 43.634912967681885, 41.918787819998606, 40.943649836948936, 42.74185405458723, 41.03048842293875, 42.32371841158186, 41.187205042157856, 41.23319864273071, 40.661757946014404, 40.462101459503174, 39.10864795957293, 40.0870099067688, 40.90867607934134, 41.46637323924473, 40.85486575535366, 38.96498005730765, 38.341056142534526, 43.15993063790457, 47.318556036267964, 48.0401542527335, 48.57121549333845, 48.274054936000276, 42.60290745326451, 38.9394211087908, 41.844035625457764, 37.61372913633074, 40.646162714277, 38.46393503461565, 42.20822198050362, 39.389490672520225, 43.58347545351301, 41.11157737459455, 44.67543349947248, 44.20639535358974, 44.68870455878121, 45.87037427084786, 51.30321591241019, 50.18890898568289, 57.8197785105024, 54.175559520721436, 58.56786673409598, 54.06586830956595, 61.5391457421439, 54.960737228393555, 66.41557911464146, 15.497175284794398, 0.5739600158163479, 2.7489707427365437, 6.750937930175236, 0.7237607347113746, 17.521084785461426, 63.722770009722026, 16.951949153627666, 37.12964466639927, 27.292904479163035, 42.99780484608242, 6.586751997470856, 0.566635474562645, 0.05788108626646655, 0.13943650360618318, 0.05064124993181654, 0.08422672149858304, 0.0587397859032665, 0.023841388091178875, 0.06223720644733735, 0.009654774696433117, 0.02106332323247833, 0.04863355302118829, 0.02005870463991804, 0.03099721670150757, 0.02066307408469064, 0.026381836771698933, 0.04658045193978718, 0.053469957251633914, 0.06327818094619683, 0.02339863890249814, 0.00967417486078505, 0.21554371900856495, 0.1081270861572453, 0.08598945369677884, 0.07982967887073755, 0.12201070652476378, 0.08693902274327618, 0.09330113671187844, 0.11040007668946471, 0.14335330628923007, 0.1567944607564381, 0.15835635337446416, 0.07477468119135924, 0.25029270510588375, 0.1645819257412638, 0.16950146747486933, 0.09296817279287747, 0.1475239624934537, 0.14422483023788246, 0.143991617751973, 0.18180395875658306, 0.23504431332860673, 0.14221328603369848, 0.3045045318348067, 0.15280072577297688, 0.1729240116796323, 0.3655065670609474, 48.678210803440635, 69.33225222996303, 34.723320211683, 45.65008858272007, 40.27164786202567, 73.04755129132951, 63.427381243024556, 1.2427735818283898, 6.952956804207393, 4.609228236334665, 4.002415997641427, 0.7765334972313472, 0.4801971699510302, 27.875106198447092, 66.446672303336, 67.04389776502336, 68.32408251081193, 64.05478273119245, 62.18931647709438, 58.732386180332725, 53.61075782775879, 53.833221776144846, 51.44791909626552, 49.4067884853908, 50.57845973968506, 52.64710521697998, 53.609552315303254, 55.28003127234322, 59.86422688620431, 65.77601827893938, 61.77613489968436, 54.84598772866385, 47.51384905406407, 49.881260122571675, 48.25095564978463, 46.83051456723894, 46.117507798331125, 46.31882490430559, 48.16250160762242, 48.4216103553772, 46.87956884929112, 49.141905784606934, 46.21043300628662, 46.89176293781826, 46.84606116158621, 46.193267481667654, 43.285182339804514, 45.63303770337786, 45.50658743722098, 49.87074749810355, 55.398758615766255, 60.10812950134277, 59.06972122192383, 58.005802631378174, 56.71682841437203, 60.351580483572825, 59.501530919756206, 59.68576240539551, 58.23867498125349, 60.0260226385934, 57.56688492638724, 55.50151899882725, 54.0177937235151, 58.39166041782924, 56.87354850769043, 50.45011608941214, 52.6237210546221, 58.21704176494053, 57.96749373844692, 57.47628736495972, 58.247075353349956, 53.6370324407305, 50.60640886851719, 45.37150403431484, 45.23680625643049, 42.903465679713655, 45.82305703844343, 44.31796257836478, 44.22770200456892, 44.49965449741909, 41.83566999435425, 43.67706421443394, 42.18803398949759, 40.820322786058696, 42.151000091007774, 43.34984574999128, 44.305261271340505, 43.34580537251064, 41.224412645612446, 39.53472539356777, 46.850633076259065, 51.12348338535854, 51.489156654902864, 51.458442143031526, 50.12362371172224, 46.43050677435738, 41.27617672511509, 43.2505281993321, 41.02947398594448, 43.085421630314414, 41.08382626942226, 46.457556111471995, 41.439271790640696, 46.995846952710835, 42.335453919001985, 47.8799044745309, 46.33394071034023, 47.160824980054585, 49.43710000174386, 55.2852007320949, 52.44448184967041, 60.420284271240234, 56.18758412769863, 60.38182599203927, 55.85318122591291, 64.72195570809501, 57.42194202968052, 67.0406390598842, 17.790527241570608, 0.5362491022263254, 7.711209808077131, 30.685940878731863, 4.279083711760385, 18.8524169581277, 66.83099801199776, 17.794157675334386, 50.727766105106895, 35.64265373774937, 55.21269975389753, 12.643631764820643, 0.8811041031564985, 0.1261582246848515, 0.17279723419674806, 0.23682829045823642, 0.1549850521343095, 0.21412944846919604, 0.1268734684480088, 0.17525673364954336, 0.2009002547711134, 0.1552653413798128, 0.10819343331136874, 0.09105843598289148, 0.13738503440150193, 0.121534972052489, 0.10679696074553899, 0.1498056993420635, 0.11971801812095301, 0.155361625498959, 0.1108133995107242, 0.14944190957716533], [0.03279077474560056, 0.06577208212443761, 0.030208833648690155, 0.02531124252293791, 0.008672314513075565, 0.07182095040168081, 0.041670653969049454, 0.07551897303866488, 0.03336577210575342, 0.036015478494976244, 0.04494606803304382, 0.009900816583207675, 0.04247183758499367, 0.016006629215553403, 0.041633653454482555, 0.04495350816952331, 0.0086774679865422, 0.061775985839111466, 0.09558985568583012, 0.08234808873385191, 0.13303646631538868, 0.07289849793804543, 0.030124752981854335, 0.028339646091418605, 0.0328034565650991, 0.07990478591195174, 2.2351102020059312, 46.570551191057476, 28.878530297960552, 25.739636421203613, 29.315043926239014, 27.665433883666992, 68.76477200644356, 6.554567941597529, 0.5761726913707597, 1.6413066195590156, 0.9111810092415128, 0.4225199834576675, 0.33259048046810286, 6.586112328938075, 59.502225739615305, 63.51710333142962, 62.30391311645508, 63.02339908054897, 54.983058316367014, 51.95893130983625, 51.253254890441895, 50.089782510484966, 54.19843993868147, 52.43768303734915, 56.526256697518484, 55.95504181725638, 55.7621111869812, 61.64720412663051, 59.75389644077846, 57.40629816055298, 58.48302228110177, 58.24582815170288, 45.252286842891145, 42.498486450740266, 43.109458923339844, 41.92569432939802, 40.851346492767334, 43.29875564575195, 42.05347517558506, 43.18760878699166, 42.44170229775565, 43.288371562957764, 40.94860737664359, 39.14041512353079, 40.86183132444109, 39.83396693638393, 40.18695279530117, 40.834521429879324, 41.51247106279646, 45.370298521859304, 49.921236583164756, 54.84291315078735, 54.89480924606323, 55.59646960667202, 55.17178528649466, 57.215007305145264, 54.093435287475586, 55.6658821105957, 55.04744379861014, 56.59670448303223, 54.452083928244456, 54.00522443226406, 54.48039436340332, 57.91737290791103, 51.12007529394967, 41.31665693010603, 54.380917004176546, 53.2069319997515, 57.07532072067261, 55.66308546066284, 52.08426986421858, 47.86321837561471, 42.19881411961147, 39.8640387398856, 38.64037411553519, 38.849271706172395, 41.39137438365391, 41.339412280491416, 40.55053465706961, 39.82073409216744, 38.369310992104666, 40.3555577823094, 39.31773662567139, 38.57331357683454, 39.08904709134783, 39.08108792986189, 38.33900989804949, 38.46762800216675, 41.62605673926217, 46.684789998190745, 49.50550501687186, 51.70405748912266, 52.16547693525042, 51.97803885596139, 50.91513122831072, 48.522956780024934, 43.71036345618111, 39.15281765801566, 37.52843305042812, 38.12753799983433, 38.36164365495954, 40.46103491101946, 37.764161109924316, 40.19869525091988, 40.488240582602366, 41.80480262211391, 41.72482885633196, 44.167270047324045, 43.32478359767369, 45.69567918777466, 49.445889472961426, 54.377144132341655, 51.107252393450054, 56.20745250156948, 54.5647246497018, 55.756146158490864, 57.535461698259624, 47.90946211133684, 0.2168805551316057, 0.027286878653935025, 1.827750780752727, 4.86366171496255, 0.12394511486802783, 37.8175163269043, 25.36917757987976, 19.046898773738317, 30.254968438829692, 21.396621465682983, 21.90130387033735, 0.6706976134862218, 0.16551704199186393, 0.05162661848589778, 0.04181656274678452, 0.04542418077055897, 0.05942632084978478, 0.026070000736841133, 0.005004382783746613, 0.031252776738256216, 0.06564136235309498, 0.0557741366459855, 0.05219060322269797, 0.03290344209277204, 0.024900776334106922, 0.02246708496074591, 0.07256846529032503, 0.036980514747223685, 0.0273776564614049, 0.022597607956933122, 0.07968333243791546, 0.041448800159352164, 0.004929924591644002, 0.03826202651751893, 0.048166042393339534, 0.029717598043914353, 0.055228360396410735, 0.016144968935155442, 0.022948356278772866, 0.033684310370257924, 0.07694716711661645, 0.10669355879404716, 0.02259511434073959, 0.01049277392615165, 0.02458717441186309, 0.07424513889210564, 0.022082245343231728, 0.08709100101675306, 0.04054250129099403, 0.07143808701740843, 0.11788106097706727, 0.012528838689572044, 0.09208700007625989, 0.024056734750047326, 0.006217248862542744, 0.04720512484865529, 0.014825313318786877, 0.30360840420637814, 4.700866290501185, 59.596568380083355, 27.25714210101536, 33.10499790736607, 34.52183287484305, 39.83541216169085, 75.60170909336635, 7.552109956741333, 0.9888062838997159, 3.3889013528823853, 3.346077867916652, 2.700087125812258, 0.4056245700589248, 7.323983226503644, 63.21523189544678, 66.30895900726318, 64.80916254861015, 63.724284717014854, 58.32792459215437, 52.16259690693447, 53.02267272131783, 51.50326497214181, 55.88594198226929, 54.549480301993235, 57.702513762882774, 56.966035979134695, 59.22696590423584, 64.18777125222343, 61.119926180158345, 60.53008665357317, 61.462229183741975, 60.01535715375628, 46.00911937441145, 44.70690189089094, 45.079026562826975, 44.64304447174072, 42.41028254372733, 46.043898582458496, 45.68816818509783, 45.06575550351824, 44.243596008845735, 46.48231601715088, 44.540051324026926, 43.14801447732108, 44.34795100348336, 42.216559818812776, 43.05918870653425, 42.598762852805, 43.12235825402396, 48.85111672537667, 53.06088433946882, 56.602283886500764, 57.93960019520351, 57.821824754987446, 57.77910028185163, 58.27786976950509, 57.38000617708479, 58.35227802821568, 55.97640405382429, 56.8013219833374, 56.8943965775626, 56.31370782852173, 57.26697983060564, 59.524230684552876, 52.23716150011335, 43.84150723048619, 56.43608297620501, 56.156101839882986, 58.645658765520366, 56.516251291547505, 53.9957401411874, 50.70935685294015, 43.819682938711985, 40.730222020830425, 40.115587847573416, 40.920633929116384, 42.16011265345982, 43.02453456606184, 41.88365772792271, 41.44231162752424, 40.74262802941458, 41.081248487745015, 41.371096066066194, 39.71038975034441, 41.48383058820452, 41.26352058138166, 41.20871319089617, 41.43760074887957, 44.15482234954834, 46.864730971200125, 50.89729520252773, 54.66090508869716, 54.51074409484863, 52.77510493142264, 52.204543181828086, 49.8535680770874, 45.58479636056082, 40.72607742037092, 39.01958247593471, 38.89792646680559, 39.641560895102366, 42.83985144751412, 40.312218393598286, 41.35634504045759, 42.44845594678606, 43.92647327695574, 44.70648152487618, 47.52360085078648, 46.137428283691406, 48.735578605106895, 51.654648848942344, 56.647106715611045, 53.180518422807964, 60.080225535801475, 54.77508136204311, 57.73660857336861, 57.719331877572195, 49.281870297023225, 0.16545723591532024, 0.04735458575721298, 4.330849962575095, 2.153045028448105, 0.061860741648290835, 40.965119770595, 32.83091926574707, 23.172911064965383, 31.97848994391305, 24.829851457050868, 33.313930238996235, 0.34078552786793026, 0.010184523100698633, 0.0759282721472638, 0.05035328645525234, 0.014985547667103154, 0.08235952883426632, 0.019640650733241012, 0.044742962145911794, 0.11068275437823363, 0.04475753368543727, 0.021865098870226314, 0.02764710780632283, 0.06656615808606148, 0.015039116310487901, 0.06200773947473083, 0.08482450406466212, 0.09265629774225609, 0.017944372558434094, 0.0792881129309535, 0.01914811403756695, 0.018565618865458027, 0.11556317178266388, 0.23508179560303688, 0.11477456481329032, 0.12296562242720808, 0.1651272779064519, 0.1477864741214684, 0.06590867800904171, 0.15728117392531463, 0.23272005947572844, 0.15335396251508168, 0.1303782103849309, 0.05585812231791871, 0.13166834972798824, 0.10686747410467692, 0.09414413504834686, 0.17153730323272093, 0.16266068097736153, 0.2480538652411529, 0.19807018020323344, 0.1691598929464817, 0.24039461623345101, 0.20594008719282492, 0.11879651328282696, 0.14423492683895997, 0.08947962070150034, 0.39502908289432526, 8.634386556489126, 75.6397921698434, 42.4352821622576, 42.45721762520926, 42.28888014384678, 38.384239196777344, 83.47738797324044, 9.148549778120858, 3.329533121415547, 7.2046961188316345, 3.885772245270865, 3.8799235991069247, 0.4000010075313704, 8.46584323474339, 63.87210764203753, 71.36771311078752, 69.18595790863037, 70.1332197189331, 58.4148257119315, 56.924902643476216, 54.99491194316319, 55.03581946236746, 59.10826287950788, 58.08070421218872, 62.79290648869106, 61.203506061008994, 61.02752903529576, 67.77494553157261, 61.745159830365864, 62.23689774104527, 63.63479886736189, 64.71129717145647, 49.913030760628835, 49.002267837524414, 47.02167340687343, 46.435808249882285, 44.14723144258772, 48.91650969641549, 47.86252008165632, 46.18845238004412, 48.06323964255196, 47.93066801343645, 46.59800352369036, 44.262307507651194, 46.24720982142857, 44.89987768445696, 45.31820787702288, 44.99798277446202, 46.422988823481965, 50.46055228369576, 55.05564267294747, 58.992832456316265, 60.18156501225063, 60.50944355555943, 60.348321778433665, 60.65523760659354, 58.61634431566511, 60.05208533150809, 58.44286864144461, 60.246620995657786, 56.947557244982036, 58.55966091156006, 60.27084241594587, 61.28427192143032, 56.198857579912456, 46.729164668491904, 57.53267547062465, 56.434401512145996, 61.470469747270855, 58.78563717433384, 55.099468435559956, 51.94414554323469, 46.67822742462158, 42.31087119238717, 42.069108622414724, 42.10342924935477, 45.25387798036848, 45.808851446424214, 43.608836378370015, 44.333067962101524, 40.36192580631801, 43.32951532091413, 42.90400069100516, 42.12233877182007, 43.383513246263774, 43.46371977669852, 43.9263516834804, 44.11392872674124, 46.05460228238787, 48.50289733069283, 54.33371441704886, 57.5500876562936, 57.610992091042654, 55.70007766996111, 54.062442847660606, 52.60971001216343, 47.90117291041783, 43.34101111548287, 41.48223945072719, 42.1313019480024, 43.289545808519634, 47.029330321720664, 42.061323165893555, 43.966241291591096, 46.82872888020107, 47.55801180430821, 47.58895213263375, 50.05561126981463, 48.41219902038574, 51.29594462258475, 56.01377146584647, 60.6441969190325, 56.474513462611604, 60.987507411411826, 56.630000250680105, 58.88232830592564, 59.30615452357701, 50.414395400456016, 0.7749105500323432, 0.11613893588738781, 8.770080532346453, 11.41364254270281, 0.27409468218684196, 46.96184594290597, 36.19745349884033, 29.51307453427996, 48.78251716068813, 34.3013595853533, 47.887999125889365, 1.9849077420575278, 0.29495287580149515, 0.18325462591435226, 0.10707127209752798, 0.11338772744472538, 0.28904970256345613, 0.17324098252824374, 0.17787412820117815, 0.148043706747038, 0.17290588122393402, 0.13965945664261067, 0.12531218651149953, 0.21551110861556871, 0.08206452894955873, 0.15134494246116706, 0.12950106816632406, 0.16220911592245102, 0.12092296060706888, 0.16813993267714977, 0.1390666477382183, 0.1255025291549308], [0.036766609975269864, 0.05152406131050416, 0.021445165421547632, 0.02948909459103431, 0.07131878699042968, 0.04443057480135134, 0.035129193016993146, 0.05009749571659735, 0.049546440464577506, 0.13204649729388102, 0.015251599551577653, 0.01718293922021985, 0.04415009556604283, 0.03783033575330462, 0.035093088168650866, 0.0340137051950608, 0.04967895835371954, 0.0588872790602701, 0.03458232432603836, 0.02230835017482085, 0.02437398210167885, 0.033036750475210805, 0.07550414026315723, 0.10982114382620368, 0.004974410195635366, 0.044167839256780486, 0.16837674139865808, 14.145322476114545, 33.45585066931588, 19.591554164886475, 37.726394176483154, 19.060619728905813, 53.196968282972065, 27.215643984930857, 1.0943420380353928, 6.0281355040413995, 2.9637771248817444, 0.7758677729538509, 0.2945053683859961, 1.8676332235336304, 44.63628387451172, 67.86302784511021, 62.1540196282523, 63.33237852369036, 59.33535780225481, 55.6937826020377, 56.66769422803606, 60.165327072143555, 58.74737344469343, 58.02216216496059, 59.672519138881135, 61.8479653767177, 59.90824372427804, 61.367122241428916, 61.31031376974923, 63.546626227242605, 58.00254045213972, 53.47329466683524, 45.45026533944266, 42.729656491960796, 44.44587891442435, 41.3929203578404, 43.014181750161306, 44.70798233577183, 43.322949273245676, 41.749512331826345, 43.17644303185599, 44.205009187970845, 42.655102321079795, 41.31074401310512, 43.07952955790928, 40.033633845193044, 40.582221916743684, 39.326241220746724, 41.37059579576765, 42.88049840927124, 48.64769778932844, 50.973530837467735, 51.17449705941336, 54.96509027481079, 55.92318432671683, 55.227023465292795, 55.94607516697475, 56.862473079136436, 55.61507340839931, 58.03885868617466, 56.313721724918906, 57.547357014247346, 55.508210114070344, 58.23986659731184, 45.29006767272949, 44.87927974973406, 58.69383062635149, 54.64548703602382, 54.735424518585205, 52.44046926498413, 47.98549624851772, 41.30731855119978, 38.917829581669395, 42.29457071849278, 47.42938675199236, 49.746680464063374, 52.60350527082171, 49.57162754876273, 44.70173590523856, 39.24481528145926, 40.04545273099627, 39.839310101100374, 39.4302453313555, 38.30802093233381, 39.9345247404916, 38.3445337159293, 41.667843205588206, 48.42844043459211, 52.64868245806013, 52.37449959346226, 52.97060292107718, 53.29245737620762, 54.0384646143232, 52.07727650233677, 52.82043150493077, 50.82605879647391, 50.1481682232448, 45.01204940250942, 39.19185611179897, 37.72164855684553, 38.95399842943464, 39.42404406411307, 39.452225957598, 40.6685220173427, 42.820851598467144, 43.74958256312779, 44.61045394624983, 41.61731937953404, 45.51897260120937, 44.14668600899832, 46.25698593684605, 49.65332099369594, 53.457689012799946, 52.42047234943935, 62.21253735678536, 50.91912644250052, 66.15956578935895, 5.480008184909821, 0.20492654586476938, 0.15827559413654463, 1.9807657471724918, 1.2725315221718378, 0.3703650677842753, 44.97569990158081, 18.40223969732012, 34.183274950299946, 37.31182643345424, 29.940260205950054, 12.79095094544547, 0.2612101435661316, 0.016940522406782423, 0.04460802188675318, 0.047683614173105786, 0.04125157377815672, 0.028214631103245274, 0.11611171306243964, 0.03722305030428937, 0.016798924022753323, 0.028900872583367994, 0.03044691462335842, 0.031940217529024394, 0.023639471336667026, 0.06035013270697423, 0.0388585029036871, 0.03532408184504934, 0.07677336715693985, 0.059104498475790024, 0.016417283697852066, 0.09486784014318671, 0.02714028285949358, 0.036024014465510845, 0.04600328326757465, 0.028976508881896734, 0.02514543740211853, 0.044480932277760336, 0.042970048529761176, 0.021703680478302494, 0.015195138652675917, 0.04267876362428069, 0.0393454230257443, 0.0628651702510459, 0.03195539635739156, 0.05695694192711796, 0.052005288523754904, 0.03485201485455036, 0.015403813615973507, 0.04201062376211796, 0.09194007688867194, 0.07963422685861588, 0.010138196122300411, 0.021242006947951655, 0.05387603671156934, 0.0582690793754799, 0.018079407812495316, 0.029721109462635856, 0.027465801553002427, 0.32530570136649267, 29.171376023973735, 41.03090878895351, 22.892414024897985, 48.17041213171822, 20.483487469809397, 64.24983256203788, 26.2117144039699, 0.5332051941326686, 3.0952633150986264, 5.867503574916294, 1.8996642019067491, 0.7249794378876686, 2.5547258172716414, 49.05543892724173, 70.34379877362932, 64.96396146501813, 67.86671039036342, 59.86116967882429, 57.02666596003941, 56.56833151408604, 62.92009326389858, 61.00235571180071, 58.741828782217844, 60.90374687739781, 64.89495195661272, 63.74927738734654, 62.34729072025844, 63.8109495980399, 64.28414276668003, 61.43914726802281, 58.355696541922434, 46.70089244842529, 46.221258299691335, 45.37692362921578, 43.44441768101284, 44.73326335634504, 46.9981745992388, 45.93171296800886, 43.44016538347517, 45.26856994628906, 46.62961087908064, 45.59986352920532, 44.59880181721279, 43.98246533530099, 43.14533594676426, 42.350889342171804, 42.071262563977925, 42.431582246507915, 44.326321261269705, 50.76398706436157, 53.83810635975429, 54.104872022356304, 56.846850054604666, 57.19872767584664, 57.82698031834194, 57.240020820072715, 58.95870290483747, 57.18670381818499, 59.332203320094514, 58.48186888013567, 58.831113134111675, 57.8176280430385, 58.750687735421316, 48.42443132400513, 47.020002365112305, 59.868437494550435, 57.530771664210725, 57.20330653871809, 54.845855712890625, 51.10972247804914, 45.06060341426304, 41.55309023175921, 42.80019460405622, 46.00517627171108, 49.80063670022147, 53.07915462766375, 50.09338862555367, 45.16277667454311, 41.25399112701416, 41.73295477458409, 40.850439752851216, 39.95858287811279, 40.52455881663731, 41.583839484623496, 41.35511173520769, 42.75438165664673, 48.18819604601179, 55.44218485695975, 51.4351761000497, 53.59143836157662, 54.029841899871826, 56.386816774095806, 53.788680349077495, 54.93485171454293, 53.390458243233816, 51.11810200554984, 47.01867525918143, 40.980669839041575, 39.948087624141145, 40.65771409443447, 41.45542287826538, 42.220127718789236, 42.981810092926025, 44.91846064158848, 45.92570277622768, 47.718133040836875, 45.235916887010845, 47.35850817816598, 47.85396684919085, 50.37427997589111, 51.93801028387887, 55.440697942461284, 54.847561495644705, 63.17161110469273, 50.56164509909493, 67.33640302930559, 6.510906764439174, 0.3356521118964468, 0.49198272611413685, 1.8900583173547472, 0.8937056926744325, 0.47662454737084253, 49.7955436706543, 22.10067026955741, 41.74076802389962, 46.39341729027884, 35.06246873310634, 24.67880630493164, 0.2565477394631931, 0.06483582593500614, 0.03413418587297201, 0.03253685337092195, 0.05774708238563367, 0.026815259496548345, 0.0347878831172628, 0.07438776016767536, 0.03178804248039212, 0.041728590681616745, 0.016234333693448986, 0.02504203375428915, 0.04385400663263031, 0.02751156534733517, 0.08825135696679354, 0.06795317187373127, 0.07722983802003519, 0.04120984048183475, 0.019947982991912534, 0.03358703898265958, 0.06788694685591118, 0.10251404770783015, 0.12126107460686139, 0.13441288817141736, 0.13291051664522716, 0.17887762721095765, 0.1184856899614845, 0.06957460593964372, 0.12346420995891094, 0.12228678885315146, 0.18944893138749258, 0.13189556396433286, 0.10523345321416855, 0.14750686341098376, 0.09784490575215646, 0.0974836265668273, 0.07418789089258228, 0.15914605957056793, 0.1513250885265214, 0.2225550077855587, 0.07068915399057524, 0.10429538533623729, 0.12471561852310385, 0.15596021552171024, 0.2376483135989734, 0.1539650240114757, 0.19246838507907732, 0.2921668110149247, 39.682180064065115, 60.12733432224819, 34.40038183757237, 57.570115838732036, 29.007653883525304, 67.45491845267159, 35.228287492479595, 1.5736144461802073, 18.302958624703543, 11.102748002324786, 2.9326819820063452, 0.6827331962330001, 3.059645329202924, 50.47374691282, 71.73941394260952, 68.80764933994838, 68.28119822910854, 63.82720838274275, 60.27729729243687, 61.231806073869976, 66.2717514038086, 63.99469470977783, 61.04733140127999, 62.17631639753069, 66.57524177006313, 65.43393066951207, 64.73268372671944, 66.38431916918073, 65.31597110203334, 63.49624483925955, 60.51398767743792, 49.07469585963658, 47.98639951433454, 49.11820547921317, 45.04134995596749, 48.86260904584612, 49.46105391638619, 47.59267636707851, 44.45968151092529, 48.55983781814575, 48.2286936214992, 48.62795448303223, 46.13945368358067, 47.64097329548427, 45.13384437561035, 46.8114834512983, 44.564161573137554, 45.90331220626831, 44.08939116341727, 52.70112746102469, 54.411496026175364, 55.00257233210972, 59.28115490504673, 59.41982010432652, 59.243718011038645, 59.011071477617534, 60.76370593479702, 59.29159804752895, 61.149400438581196, 59.836691175188335, 60.72734601157052, 61.239970207214355, 62.40744822365897, 49.071426732199534, 49.22388757978167, 61.88200460161482, 58.590399742126465, 60.48845304761614, 58.16024718965803, 51.1421149798802, 45.922232151031494, 42.84888410568237, 46.15038667406355, 51.20823751177107, 54.0204861504691, 56.70643738337925, 54.782123361315044, 48.29724107469831, 43.126249245234895, 43.84243481499808, 44.09302854537964, 43.15788091932024, 42.369781494140625, 42.67620400020054, 43.9613219669887, 46.12033224105835, 52.06554446901594, 57.61562653950283, 54.36466516767229, 56.803295271737234, 56.8559695652553, 61.06436838422503, 55.329752581460134, 58.68326241629464, 55.316617012023926, 54.0810466493879, 51.07084730693272, 44.472605160304475, 41.65999174118042, 43.102093832833425, 44.42209870474679, 44.87896013259888, 44.53431558609009, 47.402636187417166, 49.22626386369978, 50.41736575535366, 45.99856506075178, 51.17529262815203, 50.224223205021445, 51.451872621263774, 54.087216649736675, 58.08106204441616, 56.567393507276265, 68.23386015210832, 50.25237035751343, 71.74648026057652, 7.420566661017282, 0.22436947827892645, 0.41150038476501194, 4.736408497606005, 4.053278114114489, 0.5379649272986821, 55.024827412196565, 27.76884913444519, 48.451501505715505, 48.22542101996285, 45.2826817376273, 36.493849754333496, 0.37661119976213997, 0.15833698798503193, 0.21249670322452271, 0.20043190275984152, 0.19852242379316262, 0.15666913533849375, 0.12842473520764283, 0.1317317656108311, 0.17421763869268553, 0.10209034330078534, 0.10993789256151233, 0.15416606036680086, 0.13071347453764506, 0.11023161680038486, 0.20153965188988618, 0.1448146535881928, 0.13115465800677026, 0.16934620509190218, 0.19529043936303683, 0.26450595100011143, 0.14482202247849532], [0.04065985052979418, 0.035318962298333645, 0.02209093907315816, 0.06159301208598273, 0.01279226888436824, 0.06430958810129336, 0.01131389374911253, 0.04058713193184563, 0.016791655216366053, 0.01800188857928983, 0.04277140740305185, 0.049472972085433345, 0.02120820911867278, 0.03449115975360785, 0.03631378963057484, 0.02524715319408902, 0.06288634732897792, 0.09039332917226212, 0.026817517321822897, 0.0660244021564722, 0.05398819515747683, 0.02475407875941268, 0.06115113651113851, 0.09319722585912261, 0.010799227481974023, 0.05163266762558903, 0.11341847186642033, 4.505156380789621, 21.076026371547155, 20.19817532811846, 24.67971478189741, 34.488832405635286, 33.09860903876168, 54.68019676208496, 0.47362905953611645, 0.6171594634652138, 3.9493599874632697, 3.606564964566912, 0.5070541288171495, 0.10566487934972559, 16.151410715920584, 73.12708037240165, 59.84333365304129, 68.2663151877267, 60.109435762677876, 64.33863748822893, 63.53170844486782, 66.08371230534145, 62.66175924028669, 65.67781938825334, 63.16226577758789, 61.90858840942383, 61.99241842542376, 64.82429572514125, 59.75082533700125, 59.30799579620361, 56.94173812866211, 52.48719242640904, 44.73284993852888, 42.090359687805176, 43.30564131055559, 46.4106627191816, 47.167033195495605, 50.480295589991975, 49.49765355246407, 50.76539060047695, 47.768719400678364, 42.333463260105674, 42.86743232182094, 41.16590881347656, 40.174894196646555, 42.66811977113996, 41.06672327859061, 41.02902930123465, 40.5515456199646, 42.429963316236226, 46.0182215145656, 49.58200468335833, 51.49762998308454, 50.742207935878206, 53.48366485323225, 53.78391735894339, 55.41423225402832, 55.95773424421038, 57.509607451302664, 55.11374003546578, 57.2413444519043, 53.18784529822213, 56.257427419934956, 49.019315242767334, 42.770345142909456, 57.44867522375924, 57.2928375516619, 53.993019921439036, 55.67255585534232, 49.73921462467739, 43.03106587273734, 39.62666048322405, 46.4850675037929, 51.54425239562988, 52.87315443583897, 53.98047494888306, 52.9901898929051, 53.724555424281526, 51.923002174922395, 41.199319226401194, 39.42045879364014, 39.10256828580584, 39.03870391845703, 37.69536352157593, 39.317305837358745, 37.593916348048616, 46.36782360076904, 54.954417841775076, 52.5949833052499, 54.31788642065865, 51.91195106506348, 53.13532386507307, 53.675376074654714, 53.14875473294939, 52.41403831754412, 52.979732854025706, 54.2831106867109, 50.34812348229544, 45.24119751793997, 39.92468956538609, 40.20065811702183, 38.81435006005423, 39.11242430550711, 43.058222906930105, 46.44282940455845, 45.63356229237148, 44.63397012438093, 48.55340378625052, 44.93052966254098, 46.41807992117745, 47.99240623201643, 50.66451317923409, 52.81182616097586, 60.649866649082725, 55.81330898829869, 59.453532763889854, 11.134454369544983, 0.18864764938397066, 0.22567906443561825, 0.5604783935206277, 0.8003819946731839, 1.2660225800105502, 4.343440098421914, 32.64590263366699, 20.328289031982422, 46.24635171890259, 42.23764065333775, 35.90242256437029, 12.037702815873281, 0.3067454887287957, 0.050979214653904946, 0.004688207941528941, 0.04630196081208331, 0.0195481833735747, 0.01296049467886665, 0.03655659660164799, 0.05404769928593721, 0.02821773709729314, 0.027451759270791496, 0.022336119220459034, 0.059000295852976184, 0.041170543126229725, 0.040196540033710856, 0.0393425630006407, 0.02553995801801128, 0.03037337160536221, 0.04669611841174109, 0.06001193728297949, 0.06127068081072398, 0.008007424833652164, 0.016902512571375285, 0.013988946813956966, 0.02256790847916688, 0.05005553850371923, 0.025142412832272903, 0.06057658019874777, 0.0507973536982068, 0.03505533787288836, 0.02397969218769244, 0.03757835498877934, 0.06367411291492836, 0.01056596071326307, 0.038193229851978164, 0.060926358215510845, 0.024983795093638555, 0.03252572539661612, 0.06676824617066554, 0.0816529296072466, 0.012983731958749039, 0.09855233957724911, 0.064972448961011, 0.024905660089903643, 0.03536916031901326, 0.06293572432228497, 0.04626111300396068, 0.024637365647192513, 0.08926393477512257, 3.4583136396748677, 41.74208818163191, 24.30866881779262, 37.068625586373464, 42.43206167221069, 42.425683225904194, 56.9387469291687, 0.38512214592524935, 0.4567435256072453, 4.149640074798039, 3.8978351865495955, 0.3845394200512341, 0.278441350374903, 20.065497738974436, 74.33665752410889, 64.40254007066999, 70.37804644448417, 62.17742810930525, 67.66967337472099, 65.87333474840436, 67.75792244502476, 64.9446107319423, 67.09618295942033, 66.20770290919712, 63.36739049639021, 64.53245748792375, 67.97369180406842, 60.32003566196987, 62.97874995640346, 57.689454623631065, 55.1832845551627, 46.36356782913208, 44.45805563245501, 47.011977195739746, 47.3833966255188, 48.12137869426182, 51.748241083962576, 49.80504880632673, 52.423133509499685, 49.02922337395804, 44.985486439296174, 45.08158697400774, 44.33790043422154, 43.48884446280343, 45.4906621660505, 44.06840760367257, 43.717544419424875, 41.069860390254426, 45.02087361471993, 47.5267379624503, 52.888329301561626, 55.09594917297363, 53.56060573032924, 55.60108321053641, 57.00542879104614, 57.61953142711094, 58.77479798453194, 59.082443373543875, 56.76239817483084, 56.34121574674334, 56.183300563267295, 57.57201964514596, 52.70735304696219, 43.43392937523978, 56.85431241989136, 58.403159686497276, 53.26464026314871, 56.15371860776629, 52.50803007398333, 45.484579018184114, 43.22487197603498, 44.94573926925659, 51.179079396384104, 53.64508540289742, 56.05027730124337, 56.14876454217093, 55.138242857796804, 51.95975119726998, 42.85234430858067, 40.34383617128645, 41.94574335643223, 40.7103328023638, 40.88264465332031, 39.880189827510286, 40.04640116010393, 47.295112814222065, 57.40693392072405, 54.58968257904053, 56.44513995306832, 53.99236331667219, 56.40970761435372, 55.48077515193394, 54.89265530450003, 54.089662415640696, 56.71319450650896, 56.093887669699534, 52.59621313640049, 47.367606844220845, 42.51623214994158, 42.61329501015799, 41.70442199707031, 41.09480094909668, 46.08829409735543, 47.69127825328282, 47.88508783067976, 46.12548433031355, 50.69999762943813, 45.956069878169465, 48.64468227113996, 50.63078662327358, 54.484865529196604, 53.75396367481777, 64.25025640215192, 55.72349657331194, 61.04116834912981, 12.360586472920009, 0.4172609028007303, 0.5642003480877195, 1.5601367865289961, 0.9172937955175127, 0.9774407680545534, 4.74399071931839, 41.54046882901873, 24.65014672279358, 54.35914134979248, 48.11141497748238, 43.943826402936665, 19.194845029285975, 0.22529132238456182, 0.056911198488835774, 0.019950493571481535, 0.054760731024933715, 0.03091330566842641, 0.05431481138137834, 0.057468855886587074, 0.03686069564095565, 0.033377185064767084, 0.048807359766215086, 0.018900742222155844, 0.03894349280744791, 0.02783815442983593, 0.0056972683939550605, 0.008843608134027039, 0.03068022888952068, 0.04530075864334192, 0.06491771832640682, 0.006448036858013698, 0.03562239637332303, 0.054093313802565844, 0.14894060790538788, 0.08109676159386124, 0.08806822036526032, 0.14247777898396763, 0.11580808221229485, 0.11229967618627207, 0.14050724543631077, 0.13049111861203397, 0.1405559778213501, 0.11096125907663788, 0.11894679521875721, 0.11333807903741087, 0.09290265345147677, 0.14570235381168978, 0.1038378830999136, 0.2072543552411454, 0.12319662288895675, 0.25971782792891773, 0.14752423390746117, 0.17465671870325292, 0.10419418862355606, 0.10229034149753195, 0.07687518133648805, 0.21287305945796625, 0.10944056031959397, 0.16583157011440822, 0.16379520509924206, 6.5025441731725415, 61.27438463483538, 34.66784232003348, 45.730826650347026, 46.82924999509539, 44.340186391557964, 65.42917115347726, 0.8730762196438653, 3.263796648808888, 9.808499234063284, 9.435282826423645, 0.7082335193242345, 0.47047501163823263, 20.819731644221715, 77.9295779636928, 66.38627161298479, 74.73986843654087, 64.53602886199951, 70.44890417371477, 69.48800999777657, 71.61248425074986, 68.67638397216797, 70.4355080468314, 69.90160151890346, 65.02078383309501, 66.64236831665039, 70.5405717577253, 61.976903097970144, 64.63416521889823, 60.444088799612864, 57.419534478868755, 49.92268875667027, 46.31131737572806, 49.42982871191842, 50.05507278442383, 52.298013823372976, 57.28336020878383, 54.10035221917288, 57.801310198647634, 54.02055563245501, 47.46548611777169, 48.41717740467617, 47.312372139522004, 46.41012075969151, 48.526055676596506, 46.88845559528896, 46.228804043361116, 43.86567306518555, 45.90527159827096, 49.70779487064907, 56.21153804234096, 55.80717025484358, 55.24060719353812, 57.78575665610177, 58.17788519178118, 59.22226892198835, 61.93699959346226, 61.98988928113665, 57.790109702519004, 56.49454859324864, 55.901092529296875, 57.28193582807268, 51.08651549475533, 46.51995440891811, 57.47532851355416, 60.809452874319895, 54.982234954833984, 58.40580695016043, 53.78166961669922, 46.391562121255056, 44.695784773145405, 49.29236555099487, 54.71338830675398, 55.67755855832781, 56.482764448438374, 56.23997354507446, 57.44090713773455, 55.990171909332275, 45.69323689596993, 42.834838322230745, 43.850303649902344, 42.60290397916521, 42.369395869118826, 43.52836929048811, 42.50600092751639, 49.52704095840454, 59.97411959511893, 56.98987177440098, 59.32661696842739, 57.26775802884783, 59.60579558781215, 58.59639603751046, 58.94338212694441, 57.34029722213745, 58.380487714494976, 59.00877162388393, 55.89376217978341, 49.82262427466256, 46.30715193067278, 45.67030436652047, 43.448284353528706, 43.04296118872506, 49.18640552248274, 51.264712469918386, 50.56959383828299, 48.9822222845895, 54.51748037338257, 49.46138048171997, 52.0192277772086, 53.076604638780864, 55.54579986844744, 57.52343436649868, 66.82407760620117, 56.205107484545024, 62.5531519481114, 14.92435884475708, 0.3579857391970498, 0.47284950422389166, 1.2926922632115228, 9.115592735154287, 3.7909058843340193, 5.459350321974073, 44.516510827200754, 32.05212695258004, 57.01724420275007, 50.00563287734985, 55.37265770775931, 28.14392852783203, 0.46357528758900507, 0.12630793665136608, 0.10076820424624852, 0.1471614890864917, 0.11516504814582211, 0.09312595932611398, 0.2216395961919001, 0.1203066608203309, 0.06270946682031665, 0.10574214413229908, 0.0759867075830698, 0.20337704329618386, 0.10314932611903974, 0.08532732565488134, 0.14500536264053412, 0.12700509067092622, 0.06474077674959387, 0.2281326199216502, 0.11850535390632493, 0.11212745721318892, 0.10946673141526324], [0.034430179811481915, 0.018120835768058896, 0.0796727201502238, 0.025351593304159384, 0.046830210502126386, 0.06691744245056595, 0.05133661261892744, 0.052376372540103536, 0.03792254187698875, 0.02007027535832354, 0.04863669124564954, 0.06356110969292265, 0.05905873807413237, 0.04618980575885091, 0.1190738712570497, 0.05972892032670123, 0.012204891652800143, 0.04518961460728731, 0.02984436195609825, 0.022429874100323235, 0.04091736814007163, 0.04835760300712926, 0.018197511921503713, 0.07105094886251859, 0.07806033774146012, 0.09748669354511158, 0.07231786195188761, 0.2616331965795585, 17.792434522083827, 33.614516258239746, 27.517270496913365, 43.40732819693429, 18.291223117283412, 60.56231239863804, 11.529263172830854, 2.4638828975813727, 2.522431241614478, 1.3102802165916987, 1.1999310978821345, 0.16953802694167408, 0.8393743623580251, 48.694650241306846, 74.69766507829938, 62.316009930201936, 70.1244649887085, 64.50756209237235, 68.28089250837053, 63.34794248853411, 65.49416460309709, 64.08697373526437, 62.71437100001744, 64.21400765010289, 63.79399599347796, 58.99650110517229, 59.31259550367083, 55.08673933574131, 50.45820031847273, 50.307462624141145, 46.71814482552664, 45.59718499864851, 45.81962810243879, 46.26019600459507, 50.59112630571638, 53.10867057527815, 55.4276249068124, 54.38267837251936, 56.88474552971976, 53.363857064928325, 44.9897734778268, 41.82696737561907, 41.54608992167881, 41.35848161152431, 41.42730699266706, 39.259132044655935, 40.805436270577566, 41.254946504320415, 42.72057867050171, 43.570187023707796, 48.54218244552612, 49.58668082101004, 50.31393139702933, 52.13710396630423, 52.6929737499782, 55.16182851791382, 55.90105084010533, 55.16270399093628, 55.162408692496165, 56.53037697928292, 54.87389864240374, 42.79093960353306, 55.022840227399556, 60.58267756870815, 52.50157519749233, 56.59814970833914, 49.29820203781128, 46.20055614198957, 42.78390455245972, 49.598398957933696, 53.349345752171104, 55.15553344999041, 51.73524795259748, 54.051707880837576, 56.05846575328282, 55.225032806396484, 54.61043684823172, 42.72720030375889, 38.68918521063668, 41.41776711600167, 38.383467946733745, 39.50855152947562, 39.24990831102644, 40.57163981028965, 50.310797759464805, 54.9559360231672, 55.24964679990496, 54.436766624450684, 52.86664744785854, 52.70204809733799, 53.7851437159947, 52.019387585776194, 54.68889938082014, 50.83914920261928, 51.925437518528526, 52.062424727848594, 53.49981246675764, 46.48063107899257, 38.77398450034005, 39.713453905923025, 38.96833603722708, 41.79352569580078, 46.04180717468262, 47.33108016422817, 46.694402830941335, 46.45648261478969, 48.781912667410715, 45.39544752665928, 47.605773721422466, 48.559876033238, 59.52301474979946, 48.81152241570609, 65.96095848083496, 19.268890244620188, 0.584780640900135, 0.07619908225855657, 0.4268831264759813, 1.5705964309828622, 0.6402471874441419, 0.32769740160022465, 11.192616871425084, 23.19029198374067, 25.75059720448085, 30.14097629274641, 30.37203516278948, 42.53821625028338, 5.452955373695918, 0.24315831650580677, 0.08193626547498362, 0.02772846076238368, 0.02789316326379776, 0.07382976010973964, 0.04116294692669596, 0.06728744081088475, 0.03157170855307153, 0.016577803030876175, 0.009607353580317326, 0.01738894754089415, 0.03569372397448335, 0.037308287873331986, 0.008355551465813602, 0.01408450405246445, 0.011502807228160756, 0.04156441574117967, 0.03030466314937387, 0.035302012493567805, 0.022289246021370803, 0.022422444141869034, 0.01407562626991421, 0.015010602572666747, 0.017084785737097263, 0.03800313487382872, 0.030526869797280858, 0.02658241002687386, 0.07164672296494246, 0.022839716036937067, 0.024470035518918718, 0.04453415995729821, 0.01767074822315148, 0.003404100562745173, 0.017310011865837232, 0.031091614493301938, 0.034271558680172474, 0.0788179085190807, 0.012143190767216896, 0.04847263844151582, 0.017526622296177914, 0.07845422053443533, 0.023045722661273818, 0.06241167137133224, 0.02463825961707958, 0.009196889087823885, 0.054332395616386614, 0.06376927066594362, 0.025006232550367713, 1.6238007417746951, 26.26248836517334, 43.99230745860508, 28.54395716530936, 44.264280796051025, 26.807253190449305, 72.79487310137067, 10.281026244163513, 1.1508599881614958, 1.7275081425905228, 2.4665251672267914, 1.1442910092217582, 0.34075385385325974, 0.9565481862851551, 54.87050792149135, 75.14280836922782, 66.95908805302211, 71.69405610220772, 66.54162638528007, 68.84124388013566, 65.27147483825684, 66.98485197339738, 66.02821704319545, 66.71090534755162, 64.83559349605015, 64.63467243739537, 61.820825713021414, 62.280532428196494, 58.28017657143729, 53.183256013052805, 51.52935545785086, 48.90119934082031, 46.14412634713309, 46.01536580494472, 48.41646868841988, 54.411245891026084, 54.45767027991158, 55.397865772247314, 57.22288308824812, 58.1147677557809, 53.011854376111714, 46.956082412174766, 42.77409717014858, 44.37874889373779, 42.53256736482893, 43.15596669060843, 42.40275069645473, 42.02644320896694, 42.71652092252459, 46.67429821831839, 46.90034048897879, 51.97854954855782, 51.03115572248186, 54.789919240134104, 54.51045574460711, 56.48357738767351, 56.711627687726704, 57.574729442596436, 57.39425345829555, 57.35295336587088, 55.50696986062186, 56.25695146833147, 43.67445169176374, 54.348031180245535, 63.87351812635149, 55.606558391026084, 59.439539091927664, 52.588240078517366, 48.36125830241612, 44.88573810032436, 50.5114096232823, 56.03371626990182, 56.27006619317191, 52.78913681847708, 55.1038874898638, 57.891417912074495, 58.80955287388393, 55.52435425349644, 44.44885621752058, 40.52123410361153, 42.49220527921404, 40.355425766536165, 40.19519335883004, 42.16523347582136, 42.63767623901367, 52.96400908061436, 56.52645124707903, 56.2967438016619, 55.65909719467163, 55.65387562343052, 55.24024588721139, 55.26213618687221, 56.32663147790091, 56.95905998774937, 52.51722254071917, 54.07990714481899, 53.93772963115147, 55.43065432139805, 48.22501107624599, 40.997185707092285, 41.90813970565796, 42.45901026044573, 43.76098803111485, 49.69587523596627, 49.80029623849051, 51.34761142730713, 48.2426768711635, 49.998472758701865, 48.76410790852138, 50.5316219329834, 51.87163066864014, 61.04189790998186, 52.16923243658883, 66.92856461661202, 20.184280667986187, 0.6168013055409703, 0.6798404114586967, 1.2399018044982637, 1.6843004439558302, 0.7658015159623963, 0.2940610907971859, 13.764403121812002, 31.326901776450022, 32.692476408822195, 33.047105516706196, 29.707325322287424, 54.20140334538051, 6.906036921909877, 0.3409113554017884, 0.04562545461314065, 0.03569021594843694, 0.014446110630940114, 0.019741689686530402, 0.058874868654779026, 0.027331180205302577, 0.0882504205884678, 0.03822787585003035, 0.016848945624328086, 0.06297560182533093, 0.04693404332335506, 0.06034421588161162, 0.028118833832974945, 0.08468603542340652, 0.02263214030036969, 0.035534115574721775, 0.019907133487452353, 0.01289542910775968, 0.04780753841623664, 0.03202927185754691, 0.14269135466643743, 0.15532894725246088, 0.1613690217158624, 0.08467463603509323, 0.09320922235825232, 0.13010109668331488, 0.21095585876277514, 0.13583163704190934, 0.10133269109896251, 0.12803410259740694, 0.24764573999813624, 0.16801166241722448, 0.09058347504053797, 0.11917307307677609, 0.29412199610045975, 0.21716465774391377, 0.14235747472516128, 0.17468554287084512, 0.1228218272860561, 0.2799968511930534, 0.1959965636155435, 0.10776824291263308, 0.1316669655165502, 0.17734428734651633, 0.20519578856016907, 0.225093827982034, 0.15113651007413864, 1.3955995355333601, 42.96962295259748, 60.564501081194194, 39.9229907308306, 62.25460869925362, 28.52253760610308, 74.62620980398995, 14.8136271408626, 4.720047661236354, 8.534999523844037, 3.501892524106162, 4.311649484293802, 0.5543993711471558, 1.7552720585039683, 53.102743761880056, 78.03612858908517, 70.26579134804862, 76.80449785505022, 69.4231207711356, 72.69126156398228, 67.45979608808244, 72.3071790422712, 70.75761958530971, 67.07570661817277, 66.89535917554582, 68.26926122392926, 65.09562982831682, 62.4712952205113, 59.609200205121724, 56.43428339276995, 55.52462175914219, 51.9229987008231, 49.05682509286063, 50.68119580405099, 51.113033294677734, 56.55102702549526, 56.88285561970302, 59.729466574532644, 59.68998691013881, 62.35119560786656, 56.90734107153756, 51.69195720127651, 46.40439196995327, 47.80068458829607, 45.38516419274466, 46.92351620537894, 44.87723003114973, 46.15022339139666, 44.96707023893084, 49.021639415196006, 48.22863803591047, 53.91409533364432, 53.331992626190186, 55.90905169078282, 56.11751501900809, 58.888637270246235, 59.18904263632638, 60.6069267817906, 58.478332247052876, 57.17384270259312, 58.57696887425014, 56.72487095424107, 47.48517731257847, 52.9747440474374, 61.44092600686209, 57.76385246004377, 60.19300174713135, 54.158581597464426, 48.75052070617676, 47.19981827054705, 53.08293792179653, 58.82899393354143, 60.337413106645855, 55.00653280530657, 57.6730568749564, 61.473513058253694, 61.3142603465489, 58.00421149390084, 47.727488790239605, 43.94757843017578, 45.70560121536255, 42.22863231386457, 44.471729687282014, 44.160571983882356, 44.40462398529053, 55.18986449922834, 59.1414544241769, 59.173513412475586, 57.57750524793352, 58.99006707327706, 57.26243918282645, 57.54144409724644, 57.37681347983224, 60.67506776537214, 54.88576963969639, 56.14541898454939, 57.686282770974294, 58.35570349012102, 50.35447760990688, 43.174313408987864, 44.33879327774048, 43.502838134765625, 46.61318186351231, 51.59354291643415, 51.83931459699358, 52.785787786756245, 51.97279296602522, 52.9300080708095, 51.60585512433733, 51.88096557344709, 55.52480936050415, 63.577239990234375, 54.66051598957607, 69.6107290812901, 22.896134785243444, 0.48602133457149777, 0.5245720031005996, 0.9320698997804097, 4.237924320357187, 4.52603919165475, 0.9509931015116828, 15.0636111668178, 34.94379002707345, 37.13493571962629, 38.88758059910366, 41.16207340785435, 63.759539876665386, 10.44939238684518, 0.6001893569316182, 0.25145205003874643, 0.16688974547599042, 0.10718377998897008, 0.20088763401976653, 0.15586895256170205, 0.15967159851321153, 0.16179180331528187, 0.13865761325827666, 0.12227769648390156, 0.16208689819489205, 0.15510196371802262, 0.0860466067013996, 0.0850451500820262, 0.18651573306747846, 0.0739849139271038, 0.11830036847719125, 0.16976761605058396, 0.08575071793581758, 0.1548567818743842, 0.12849531642028264], [0.061401678781424246, 0.008508269342460802, 0.05998854139553649, 0.015260279710803713, 0.011954789582107748, 0.05943320798022406, 0.07920247502624989, 0.07270674394177538, 0.059167622588574886, 0.022912259912118316, 0.04024142512519445, 0.08658862047429595, 0.014079370935048376, 0.01677644924659814, 0.07333115900733642, 0.04074127473203199, 0.040369264515382905, 0.09043778678668396, 0.04318715598700302, 0.03308054991066456, 0.049127200817955394, 0.03899086133709975, 0.010151560717661465, 0.09578884965074913, 0.2035152201673814, 0.04693806364334055, 0.18779831353042806, 0.197536240997059, 15.258353539875575, 36.77643993922642, 42.21114369801113, 69.83705275399345, 39.1501009123666, 28.86876286779131, 44.6554331098284, 0.23037485246147427, 0.9515944463866097, 2.839188975947244, 0.9526655546256474, 0.25574712242398945, 0.08448554868144648, 5.051732080323355, 69.18849400111607, 65.10362720489502, 72.35300241197858, 67.1217314856393, 70.16932950701032, 62.28693866729736, 64.92668437957764, 64.7792158126831, 65.54849951607841, 61.29342269897461, 58.842681884765625, 56.840589727674214, 53.82499163491385, 50.18487555640084, 52.06742395673479, 49.56410264968872, 46.07646131515503, 45.49686690739223, 45.77901588167463, 51.43490859440395, 54.089582511356895, 55.874199526650564, 56.01918758664812, 58.551691327776226, 59.21089472089495, 59.90401227133614, 55.67818737030029, 43.59645468848092, 39.6454553604126, 40.824265888759065, 41.135305472782676, 41.65925175803048, 41.78469453539167, 42.19185549872262, 40.52044895717076, 43.3280040877206, 45.323419025966096, 47.27204132080078, 49.88461262839181, 49.98718541009085, 51.61812216894967, 55.440538133893696, 54.717320987156455, 55.9787768636431, 53.228985582079204, 59.0549840927124, 53.80161789485386, 60.53877190181187, 62.51400579724993, 56.91763482775007, 58.076566559927805, 53.80441107068743, 49.35027878625052, 44.36931324005127, 50.597390106746126, 55.01462745666504, 54.96443019594465, 56.41932044710432, 56.60411821092878, 53.65434040342058, 55.70991631916591, 54.57283319745745, 53.74754006522042, 44.16774947302682, 38.95626354217529, 39.47564833504813, 38.062627928597585, 37.83202069146292, 39.65192413330078, 41.79859093257359, 51.310452461242676, 55.491569178445, 53.51619284493582, 55.17681925637381, 53.815941606249126, 52.48347861426217, 53.25037213734218, 51.32861157826015, 51.54617704663958, 56.03134346008301, 54.3233129637582, 53.021474157060894, 52.178963388715474, 51.83659437724522, 46.48957341057913, 40.07268966947283, 38.60222155707223, 42.782452378954204, 48.57940394537789, 47.359272480010986, 50.70509760720389, 49.62731041227068, 48.46928194590977, 48.63161965778896, 50.927637985774446, 50.56194387163435, 53.933970655713765, 58.72766835348946, 51.1760847227914, 0.6060891374945641, 0.12298506924084254, 0.5163135805300304, 1.6959409564733505, 2.878530327762876, 0.07876556632774216, 0.09268685217414584, 7.219959574086325, 25.267996174948557, 29.741718905312673, 17.06847391809736, 40.42681155885969, 28.24664374760219, 0.06073530311031001, 0.1328599929277386, 0.04038052819669247, 0.02392376563511789, 0.025415920120264803, 0.09827072040310927, 0.03560100216418505, 0.022585292546344653, 0.015756310861823813, 0.07512736333800213, 0.04238217257495437, 0.0655763926250594, 0.030170248754854714, 0.07834964471736125, 0.018375471300844635, 0.02452039299532771, 0.0704369085973927, 0.04496841897655811, 0.05689090011375291, 0.035660635214298964, 0.05679379157455904, 0.041557643961693556, 0.05025672074407339, 0.005686585708255214, 0.05290971124278648, 0.027877020915704112, 0.016408081066661646, 0.06878062497292246, 0.021524747401209812, 0.017240460330088223, 0.053036990841584544, 0.03588098606892994, 0.026821128824459653, 0.022703235503286123, 0.017716671473213604, 0.02405397650519652, 0.041591893016759834, 0.018889385242281214, 0.03393616560580475, 0.0608773340604135, 0.02104831743054092, 0.03274344353537474, 0.08505891755755458, 0.02935357079175966, 0.06703878486795084, 0.04708759240540011, 0.14693346060812473, 0.06950691528618336, 0.09849161069308009, 0.08083199722958462, 22.076659032276698, 53.404545715876985, 44.26850530079433, 74.22402027675084, 39.245419774736675, 44.016733850751606, 43.271873065403526, 0.23545854538679123, 0.9900651020663125, 1.225277366382735, 2.0004085217203413, 1.2183604346854346, 0.12020234284656388, 6.1862799780709405, 73.6175537109375, 63.08129147120884, 74.78785964420864, 69.22227614266532, 73.66772665296281, 62.99041598183768, 69.47526700156075, 65.40444946289062, 68.31292370387486, 63.75585733141218, 62.76116016932896, 59.6581711087908, 57.238700662340435, 52.64660494668143, 55.331381934029714, 49.91059194292341, 47.92633581161499, 46.65508644921439, 49.50292723519461, 53.80184371130807, 55.15686403002058, 57.181923457554404, 59.32431016649519, 59.112542969839915, 62.02020427158901, 60.938689368111746, 57.55303021839687, 45.74388231549944, 42.5296630178179, 43.88843188967024, 43.97809144428798, 44.55923877443586, 44.16482775551932, 44.017192431858604, 44.37088353293282, 46.0471190725054, 49.27482829775129, 50.88018526349749, 53.715105874197825, 53.44590139389038, 54.846668652125764, 56.93683270045689, 56.35093627657209, 58.76613358088902, 57.05308995928083, 59.206955092293875, 54.87685162680489, 60.13803454807827, 65.31173270089286, 57.79683208465576, 59.16162504468645, 56.10541125706264, 52.47431741441999, 46.87438549314226, 50.5768894468035, 54.96003198623657, 57.5498548916408, 57.21723420279366, 58.099040508270264, 55.91301563807896, 58.4807710647583, 56.577579566410606, 55.90572697775704, 46.444521290915354, 40.82490512302944, 42.16370487213135, 40.98415436063494, 40.26519298553467, 41.53222131729126, 43.314861570085796, 52.51009021486555, 58.35810061863491, 54.31624664579119, 57.12163046428135, 55.66141094480242, 54.75875309535435, 55.75656999860491, 54.243304456983296, 52.00966705594744, 56.427317823682515, 57.565193040030344, 55.1262537411281, 55.518594196864534, 53.21197291782924, 47.466101033346995, 40.90567793164934, 40.90274926594326, 43.55860090255737, 51.621714387621196, 50.17247997011457, 52.96995326450893, 50.88484403065273, 51.10979543413435, 50.03010095868792, 52.35231399536133, 52.937182085854666, 57.14208943503243, 61.602082524980815, 54.93682152884347, 0.9044356654797281, 0.1906712579407862, 3.2408222130366733, 3.098450801202229, 1.9863657781055994, 0.12021009171647684, 0.16159895009228162, 11.880336540085928, 31.05986860820225, 39.33210897445679, 20.54479316302708, 43.98391056060791, 35.787193638937815, 0.1837755643895694, 0.04258901040468897, 0.06832339415060622, 0.06244736909866333, 0.06063473064984594, 0.03536661242001823, 0.008045401590477144, 0.05141580783362899, 0.04478887521794864, 0.04462076138172831, 0.036098174950374026, 0.059167602232524326, 0.05877369908349855, 0.08845856799078838, 0.0698726185198341, 0.05361256156382816, 0.02146740610312138, 0.0167090215254575, 0.04643020053793277, 0.01964122918434441, 0.014016541984996625, 0.003133318441021921, 0.13023309888584272, 0.10979683191648551, 0.10774230930422034, 0.15780177313302243, 0.1326474350477968, 0.20911632318581852, 0.16365918596940382, 0.11715010234287807, 0.19756473946784223, 0.16771610613380158, 0.1188347012336765, 0.16177315717296942, 0.09665174263396434, 0.14747715714786733, 0.15484786592423916, 0.10231862283710923, 0.1493807735719851, 0.213710575231484, 0.08351869734802417, 0.11158177256584167, 0.1503301661993776, 0.14645233856780188, 0.12439104808228356, 0.21495010943285056, 0.2618923969566822, 0.1593108485851969, 0.27481333219579285, 0.42347115384680883, 25.4599940095629, 69.15410041809082, 52.951286928994314, 87.2092376436506, 48.93638849258423, 40.57114996228899, 51.305811064583914, 0.32790115209562437, 4.8869377459798535, 7.337010230336871, 4.167873884950366, 0.7139826108302388, 0.17157520619886263, 7.510519777025495, 74.22408975873674, 68.05222729274205, 78.32925919124058, 71.01309095110211, 73.99456296648297, 65.5210680280413, 70.82640675136021, 68.7283217566354, 72.65511703491211, 66.86312648228237, 61.78264536176409, 62.533870697021484, 59.29681614467076, 55.18126957757132, 56.96665436880929, 54.57665818078177, 50.21137598582676, 49.85612154006958, 50.88631010055542, 55.8333614894322, 57.480609144483296, 60.43422930581229, 60.98843847002302, 62.760486194065635, 66.00856058938163, 64.60765089307512, 62.571036611284526, 49.52034289496285, 46.08584485735212, 46.39878477369036, 46.542560373033794, 47.657826151166645, 47.154453481946675, 48.17244447980608, 45.779206957135884, 47.781966141292024, 51.16106966563633, 53.72727564402989, 56.27687195369175, 57.39937080655779, 57.006134033203125, 60.06182670593262, 57.46099437986101, 58.30910192217146, 58.75653117043631, 62.97314970833914, 56.631320408412385, 57.96928637368338, 58.69425446646554, 58.8110328401838, 62.73890508924212, 57.07761362620762, 53.737402643476216, 48.09609072549002, 54.16463347843715, 58.18690742765154, 58.146746839795796, 60.1840455191476, 60.88147095271519, 58.38087681361607, 58.87155859810965, 57.792770862579346, 57.34938893999372, 48.51685973576137, 43.076830182756694, 44.809394768306184, 43.16394669669015, 42.23744262967791, 45.00887754985264, 46.322274684906006, 53.79309940338135, 59.96739373888288, 57.11370256968907, 59.962189538138254, 58.528880391802105, 57.20685706819807, 58.75769846779959, 55.95396832057408, 55.3313888822283, 58.657894543239046, 60.204765047345845, 58.38165501185826, 57.12572642735073, 56.78806829452515, 50.975094182150706, 43.61911971228463, 44.29269198008946, 47.01236629486084, 53.19587046759469, 52.82927656173706, 55.658447538103374, 54.58409970147269, 53.08962903703962, 53.30802134105137, 55.894738401685444, 55.28472130639212, 60.681140490940635, 64.92500291551862, 55.87721504483904, 1.4473909735679626, 0.21925773471593857, 4.0914415291377475, 6.5791250467300415, 8.42119584764753, 1.7476686664990015, 0.43693757695811136, 13.286393983023506, 39.41335078648159, 42.27077661241804, 29.856548309326172, 53.31304488863264, 46.4809958594186, 0.5077608366097722, 0.2822014114686421, 0.13899394949632032, 0.16599914112261363, 0.12480682720031057, 0.17566012271812984, 0.20624793853078568, 0.13424018743847096, 0.15021375673157827, 0.19440576540572302, 0.13721356860228948, 0.1467540016663926, 0.10740578986172165, 0.17758705360548838, 0.13484174944460392, 0.20311187181089604, 0.12794115687055246, 0.1449353921094111, 0.12481400610080787, 0.11936883042965617, 0.0887269014492631, 0.07824372540095023], [0.03777984596256699, 0.03149102395400405, 0.03378246046070542, 0.040624064592910666, 0.02491333771363965, 0.09813654688852173, 0.03874893985422594, 0.04817405589190977, 0.014191045076586306, 0.07091110279517514, 0.07359519733914308, 0.027919617647837316, 0.04562780573698027, 0.013741993145751101, 0.11325596951480423, 0.039120868646672795, 0.013663881890741842, 0.04124748221199427, 0.03308556428445237, 0.10622952226549387, 0.021865509383912598, 0.015054953317823154, 0.13829670048185758, 0.021644318842196038, 0.03106739079313619, 0.056719688765172444, 0.08654258187328066, 0.14188339587833199, 2.018580666610173, 32.50930799756731, 62.67211900438581, 22.427492686680385, 57.56205940246582, 19.797081879207067, 39.05624117170061, 5.3027544277054925, 2.3579376339912415, 0.7227912438767297, 0.7381878005606788, 0.05525016172655991, 0.19466400226312025, 0.028761141866977726, 12.363165991646902, 80.3381849016462, 62.13714245387486, 72.10032422201974, 63.618150983537944, 71.618834904262, 62.83605480194092, 65.45928464617047, 58.52925559452602, 61.03982734680176, 55.33682932172503, 53.343200070517405, 53.60172169549124, 54.174590247017996, 47.16044977733067, 48.051229681287495, 45.41790757860456, 46.896449497767854, 49.50169045584542, 53.00123405456543, 53.298102787562776, 57.70454611097063, 61.3584508895874, 59.638389587402344, 59.72651359013149, 60.32534408569336, 58.611452783857075, 52.0425910949707, 40.428281102861675, 41.99102129255022, 41.208633286612375, 41.90374844414847, 41.63735451017107, 42.43453870500837, 42.059092794145855, 43.76796402250017, 44.903278827667236, 46.28034578050886, 48.05578422546387, 47.309773513248985, 50.02680056435721, 50.83571679251534, 54.444444383893696, 51.93848276138306, 53.63547951834542, 56.64800303322928, 57.47085039956229, 57.28738668986729, 55.63605349404471, 57.33027444566999, 57.54594652993338, 53.16954026903425, 48.26911129270281, 52.84851612363543, 55.491325991494314, 55.82200118473598, 54.11725371224539, 55.50504520961216, 54.8802284513201, 57.12120662416731, 57.31307070595877, 54.45436988558088, 50.75805330276489, 45.74867309842791, 39.47677046912057, 39.19117866243635, 38.245692116873606, 39.36529357092721, 39.11869158063616, 44.71042462757656, 55.17492239815848, 55.34858567374093, 54.441647733960835, 53.45362779072353, 52.80940471376692, 53.88752889633179, 53.51307657786778, 54.34154156276158, 53.817449365343364, 56.47158132280622, 53.515432017190115, 52.86767578125, 53.882689476013184, 55.46043430055891, 52.64051832471575, 45.93823037828718, 38.83087982450213, 41.35815157209124, 43.69809988566807, 51.41526256288801, 49.73993028913225, 52.31480414526803, 49.8056116104126, 50.98159769603184, 46.95654099328177, 56.46661336081368, 52.8901184626988, 58.410371916634695, 29.182475771222794, 0.2910495895360197, 0.2695236088974135, 0.7912322485021183, 2.7907037947859084, 0.8024108686617443, 0.21809886475758894, 0.07618150141622339, 15.70868192400251, 34.04178878239223, 27.680857147489274, 31.567476204463414, 46.76061568941389, 4.375295851911817, 0.2940950718309198, 0.05849871598184109, 0.05618604811440621, 0.01967665719400559, 0.03621595845158611, 0.049678211965199025, 0.013069995812007358, 0.02233085039603923, 0.0652159887499043, 0.0369716191531292, 0.04396660951897502, 0.01825910933049662, 0.0690999978354999, 0.09841453590031181, 0.04117133022685136, 0.02168996219656297, 0.018707147699647715, 0.04375427894826446, 0.026050962740555406, 0.05854664769555841, 0.06680236969675336, 0.03509273533044117, 0.022797170194930265, 0.06064992983426366, 0.007468469557352364, 0.013435951799952557, 0.010021448235160537, 0.08782122683312212, 0.08610652812889644, 0.03547029257086771, 0.05585105198302439, 0.02354969097567456, 0.005690122996124306, 0.03800659540242382, 0.04635903578517692, 0.024380916729569435, 0.04374606867453881, 0.04962829892922725, 0.010733926119948072, 0.033791596934731515, 0.03492507950535842, 0.04963484000680702, 0.08100518650774445, 0.003736878520742591, 0.12363372157726969, 0.05136977941063898, 0.08936729601451329, 0.019214515474491885, 0.10929944539176566, 0.2619313991495541, 7.584853342601231, 47.27626929964338, 63.180706296648296, 40.3448714528765, 64.78344031742641, 23.76482810292925, 53.548859800611226, 3.6733302048274448, 1.7233163160937173, 0.4115437295820032, 2.4031806119850705, 2.3740576718534743, 0.9092504956892559, 0.07316095528325864, 17.190221990857804, 84.71243722098214, 63.957514899117605, 73.50258881705147, 66.19773919241769, 72.82837036677769, 64.6462481362479, 68.4145758492606, 61.88687528882708, 62.570418221609934, 56.98417772565569, 54.63430043629238, 55.048701422555105, 55.86688307353428, 49.69607673372541, 52.09006118774414, 49.04741375786917, 49.555521624428884, 51.75534214292254, 54.468752656664165, 56.999248368399485, 60.86957563672747, 62.72985853467669, 61.69700186593192, 61.698148318699424, 64.55728340148926, 61.866815839494976, 52.0198426927839, 43.579525402614046, 44.78276579720633, 43.5402889251709, 44.563015120370046, 43.598879609789165, 44.059298515319824, 43.30773619243077, 45.71510982513428, 46.2702430997576, 48.5559537751334, 48.558083398001536, 50.224532399858745, 51.600095067705425, 54.023102147238596, 55.32741451263428, 54.2874950000218, 56.97215039389474, 58.824380329677034, 58.684582574026926, 61.04585143498012, 57.176375320979524, 59.854992730276926, 57.87795230320522, 56.67486824308123, 49.585107054029194, 53.50227560315813, 56.67608070373535, 57.62472520555769, 57.301918847220286, 57.444589682987754, 55.818805013384136, 57.80170972006661, 59.18246269226074, 57.19806064878191, 53.52832439967564, 48.417611667088096, 42.744671549115864, 41.61940731321062, 39.83325127192906, 40.864228452954976, 41.59843070166451, 46.08137369155884, 56.13718884331839, 55.25606346130371, 55.917386054992676, 55.49623489379883, 54.25704799379621, 54.87017093385969, 55.87610680716378, 56.40954433168684, 55.627885886601035, 57.67931372778756, 55.26131282533918, 56.916446685791016, 56.77271277563912, 57.430391039167134, 54.67794901984078, 47.88807555607387, 40.62153482437134, 44.49912296022688, 46.95408133098057, 53.206383092062815, 53.351715087890625, 55.354040009634836, 53.69737754549299, 53.38406242643084, 49.533329078129356, 58.057271412440706, 55.65584543773106, 60.43607752663748, 32.249893529074534, 0.2784743271768093, 1.0291371026209422, 3.929325291088649, 3.2391574680805206, 0.8955452825341905, 0.06532627783183541, 0.16223680015121186, 20.550341299601964, 40.38449008124215, 33.06750890186855, 30.04286425454276, 54.492942810058594, 6.386612176895142, 0.2950118812067168, 0.050901220446186404, 0.09964048583060503, 0.0908301564465676, 0.02617182339807706, 0.05389555477138076, 0.05360978974827698, 0.05339485699576991, 0.06492916521217142, 0.03913632567439761, 0.04506504575588873, 0.021236398856022527, 0.07490527882639851, 0.01997270541531699, 0.04566319812355297, 0.10152032638766936, 0.05562644671382649, 0.045159396050231795, 0.02823137056215533, 0.00851471203246287, 0.03547704738697835, 0.0627662737720779, 0.14156627575201647, 0.07803657544510705, 0.09577618818730116, 0.08910610752978496, 0.11512782371469907, 0.2605440393090248, 0.15827252715826035, 0.11176195754004375, 0.12137840688228607, 0.1133677853005273, 0.1159045020384448, 0.12162723924432482, 0.14493962616792747, 0.08203229175082274, 0.16391225238995893, 0.14114105142652988, 0.10291998806808676, 0.1333321447351149, 0.10442418485347714, 0.18094660261912004, 0.29094875923224855, 0.11639002098568849, 0.3811755691255842, 0.22181368113628455, 0.163374038413167, 0.14419838094285556, 0.22234979165451868, 0.40648147836327553, 7.297254375049046, 62.739641598292756, 73.60341412680489, 38.50436312811715, 72.96843910217285, 28.498967579432897, 50.31942047391619, 6.823908346039908, 3.4648503746305193, 3.3710920342377255, 3.3512514531612396, 2.6631114184856415, 1.0356668893780028, 0.11660989347313132, 14.952737024852208, 87.42937047140938, 63.78721455165318, 74.69469819750104, 65.94030843462262, 75.66635513305664, 65.2825016294207, 70.98016343797956, 64.62366649082729, 65.63693618774414, 59.47980390276228, 58.62377193995884, 57.156423568725586, 59.769383975437705, 52.24289376395089, 54.05956629344395, 51.391676902770996, 51.8884140423366, 56.17916291100638, 56.15287440163748, 58.82093402317592, 61.765372140066965, 66.06211730412075, 64.4305830001831, 63.201988628932405, 66.67145347595215, 63.5949717930385, 58.241141591753276, 45.95471497944423, 46.35261399405343, 47.562726157052175, 48.66234111785889, 47.5597870690482, 46.93584925787789, 47.40008272443499, 48.990744250161306, 48.30890710013253, 51.24165487289429, 51.60609483718872, 52.46235956464495, 55.150079114096506, 55.6741087777274, 59.50546360015869, 57.870507308415, 59.9929700578962, 60.6652569089617, 60.278707776750835, 62.551262038094656, 59.21711335863386, 61.759730202811106, 62.18719727652413, 58.33333029065813, 49.691935607365195, 58.21116706303188, 57.55133833203997, 59.89900956835066, 58.58554989950997, 58.875824792044504, 58.30418954576765, 61.240887369428364, 60.988785879952566, 59.08685547964913, 54.938878195626394, 50.21532951082502, 44.44823087964739, 44.866088594709126, 42.40931327002389, 43.84344925199236, 41.99585723876953, 49.53614657265799, 58.68848746163504, 58.75029168810163, 55.56155143465315, 55.7718734060015, 54.4376004082816, 57.86113766261509, 57.07310771942139, 58.78416415623256, 56.853812149592805, 61.343317713056294, 57.47998033251081, 58.428388595581055, 60.625325611659456, 59.46382999420166, 57.01851224899292, 50.67255571910313, 42.282202925000874, 46.32038130078997, 49.14109631947109, 57.07853773662022, 55.33021811076573, 57.52431331362043, 56.601384094783235, 56.57592936924526, 51.53223896026611, 61.745493343898225, 58.27414900915963, 61.6893310546875, 34.0294314111982, 0.2849806637636253, 1.1354843846389224, 7.589249815259661, 12.449026618685041, 3.1558474813188826, 0.6392920815518924, 0.2100802500333105, 26.49077316692897, 45.82486704417637, 39.81353228432791, 43.61511060169765, 62.78215067727225, 10.462136251585823, 0.7058318310550281, 0.23860838636755943, 0.2627626045473984, 0.10569784936628171, 0.17962609204862798, 0.11854119412600994, 0.10360582412353583, 0.13446981725948198, 0.21650817511337145, 0.08529630981917892, 0.16931136910404476, 0.08052859029599599, 0.16903487965464592, 0.22092706656881742, 0.15137395661856445, 0.23430332594684192, 0.07915714210165398, 0.21285366692713328, 0.0697171457910112, 0.15010629035532475, 0.10962327622941562, 0.09205664920487575], [0.02501149967844997, 0.018788561723860245, 0.038707410118409565, 0.031058963388204575, 0.046673794609627554, 0.03387567760156734, 0.00977323079548244, 0.04987274116969534, 0.030327740125358105, 0.07192629296332598, 0.031069887802004814, 0.020097642371963178, 0.043341356462665966, 0.05891171310629163, 0.022267561738512347, 0.034771428643060584, 0.07595075201243162, 0.021121921516688805, 0.044357214987810166, 0.039769646512078385, 0.021064232469403317, 0.07830444749976907, 0.03703598837767329, 0.008318519569002092, 0.04321778505774481, 0.0674228153324553, 0.017061661263661723, 0.13007259821253164, 0.04733114915766886, 17.599724497113908, 56.622127941676546, 60.433756828308105, 37.63348633902413, 48.35814550944737, 24.213520186288015, 21.12357289450509, 1.900700569152832, 0.6326209423797471, 2.011859804391861, 1.2868899745600564, 0.734642753643649, 0.5981495720999581, 0.07871299343449728, 17.927886179515294, 70.99049540928432, 67.79260090419224, 74.05474826267788, 67.92799350193569, 66.20582689557756, 62.38543633052281, 58.727147238595144, 58.02699811117989, 56.79174389157976, 59.62822437286377, 55.61591761452811, 53.502887044634136, 56.25516925539289, 54.14164188929966, 49.81332411084856, 49.33274500710623, 49.587834221976145, 57.3827611378261, 57.21140813827515, 57.32211378642491, 61.15394456045968, 60.27100222451346, 59.71600096566336, 60.96372372763497, 60.66580581665039, 51.68808705466134, 42.06860140391758, 41.45035069329398, 42.237098693847656, 41.15635504041399, 42.37891837528774, 43.488896574292866, 43.19346611840384, 43.24873903819493, 41.928803648267476, 44.69126844406128, 45.888714041028706, 47.148217473711284, 49.81829902103969, 51.40415934153965, 52.906867095402305, 51.802315439496724, 51.25507184437343, 53.943281241825645, 56.137904507773264, 57.89982523236956, 59.07516860961914, 57.9711206981114, 58.4800762448992, 54.07483843394688, 53.59054899215698, 55.11453560420445, 59.01472623007638, 56.281753063201904, 56.088280473436626, 55.226637840270996, 58.29301684243338, 58.63830757141113, 51.743995734623496, 54.35639681134905, 49.068709986550466, 46.7557623726981, 40.85823910576956, 39.345560686928884, 40.06162813731602, 39.41251700265067, 41.27244554247175, 41.88238968167986, 53.609475885118755, 55.4227750641959, 53.869098799569265, 53.619088717869346, 58.267336300441194, 56.52514498574393, 53.971108777182444, 54.07260806219918, 53.04395852770124, 56.87951006208147, 54.97766998835972, 54.54447759900774, 52.90505708966936, 52.26958179473877, 54.58206387928554, 53.30408866064889, 42.8233460017613, 40.39765344347273, 44.27606841496059, 46.223735332489014, 49.43912887573242, 54.705109528132844, 49.77210392270769, 52.132615430014475, 51.867830004010884, 54.34875726699829, 51.19025904791695, 66.58389227730888, 10.26707512991769, 0.37808885904295103, 1.6774362751415797, 3.128169332231794, 2.087080350943974, 0.769638007240636, 0.09111744138811316, 2.935511418751308, 37.08762196132115, 34.504997389657156, 19.199717453547887, 41.74545110974993, 29.535246235983713, 0.1255216095596552, 0.10049040522426367, 0.023801205247374516, 0.05441309039347938, 0.02572839567437768, 0.008473009270216738, 0.03952592351873006, 0.017306934709527662, 0.05855181134705033, 0.03204814870176571, 0.023183824893619333, 0.022168585531679646, 0.012260901325914477, 0.017890232249296138, 0.031000741690929447, 0.049540676309594085, 0.057929554022848606, 0.05342170662645783, 0.07375828323087522, 0.05869910094354834, 0.03298884251021913, 0.030490958331418887, 0.01804904845942344, 0.04530302155762911, 0.0441729011280196, 0.1137865771140371, 0.060034654635403834, 0.015993686160072684, 0.04080817149952054, 0.09559452400675841, 0.011275026415075575, 0.028976312106741325, 0.0406651125688638, 0.015292961349976915, 0.07291523739695549, 0.017539790964552333, 0.05203327130792396, 0.020669681319434727, 0.03611188814310091, 0.015730346719335233, 0.020521623282028095, 0.05424411481778536, 0.03083989835743393, 0.02471339549603207, 0.03782129427418113, 0.057458121462592056, 0.02040020961846624, 0.055278032552450895, 0.11500617595655577, 0.06946313620678016, 0.04155100110386099, 0.13833034224808216, 29.415921347481863, 72.47971670968192, 46.63897010258266, 53.959498337336946, 47.364775453295024, 33.93500886644636, 23.230617591312953, 1.921508469751903, 0.8860682653529304, 2.018907449075154, 3.593551857130868, 1.0968893127782005, 0.8582629316619464, 0.027977983533803905, 23.637851510729107, 74.84139551435197, 69.3003738948277, 75.62495081765312, 70.07890565054757, 69.92134829929897, 64.45522826058524, 61.47060176304409, 57.51733732223511, 57.35370029721941, 61.29199137006487, 57.615195751190186, 55.89068065370832, 56.90175471987043, 55.93477392196655, 50.79006017957415, 50.44543995176043, 51.77332755497524, 59.33678913116455, 57.591356481824604, 59.18160111563546, 63.53368868146624, 63.90997532435826, 63.24458803449358, 62.71267563956124, 60.57068497794015, 54.946382250104634, 44.6377603667123, 45.813423361097065, 43.52911622183663, 43.5137676511492, 44.314109802246094, 44.80341584341866, 45.33753081730434, 45.716822556086946, 43.850869928087505, 46.943975176130024, 49.493550641196116, 50.41546194893973, 53.50326919555664, 52.69239010129656, 55.71088906696865, 54.96428428377424, 52.75788034711565, 54.94765029634748, 56.77094445909773, 59.80201966421944, 60.98469339098249, 57.678479943956646, 60.18109948294503, 55.82671901157924, 53.737374850681846, 58.2986170904977, 58.97683770315987, 57.35471820831299, 55.34650468826294, 55.322533403124126, 57.40974794115339, 59.81240027291434, 54.01335382461548, 56.86653777531215, 52.2429632459368, 48.53115218026297, 42.33801433018276, 41.8310181753976, 41.87462159565517, 41.72492265701294, 42.85709340231759, 44.30016129357474, 55.024097851344514, 57.792562416621614, 55.50408288410732, 57.502405643463135, 58.28022173472813, 58.07704251153128, 55.837652002062114, 57.59826993942261, 54.17122037070138, 58.39275128500802, 56.17775590079171, 56.760737555367605, 55.85673175539289, 55.3534494127546, 55.47083922794887, 55.47547715050833, 43.14131988797869, 43.031691210610525, 46.90429401397705, 49.12851660592215, 50.50514234815325, 57.290700980595176, 50.84063264301845, 56.41025652204241, 54.926565987723215, 58.04546642303467, 53.49326031548636, 69.06048733847481, 11.21254517350878, 0.43325337607945713, 3.849448800086975, 3.929018267563411, 1.4692634684698922, 0.2127889889691557, 0.2508765437773296, 4.723108342715672, 41.289180278778076, 41.547875608716694, 21.885607889720372, 42.85151399884905, 38.225187982831685, 0.16843855593885693, 0.022320421312802603, 0.0358348728290626, 0.05210233599479709, 0.054110789471971135, 0.028302777891180346, 0.03460242931864091, 0.023684369998850992, 0.03372076127145972, 0.0406324309296906, 0.028747058872665678, 0.027106198349169323, 0.050330304474170716, 0.053399806908730946, 0.037607830549989424, 0.0428354407527617, 0.01822704855086548, 0.0021236214379314333, 0.05185097608981388, 0.05035386660269328, 0.022154073363968303, 0.041703491671276946, 0.0632909441898976, 0.11541493902248995, 0.12965209649077483, 0.13831964853618825, 0.17519582834626946, 0.11631668492087296, 0.09171757847070694, 0.12182075743164335, 0.11547348302389894, 0.12623008154332638, 0.18896628942872795, 0.07761503556477171, 0.12560501508414745, 0.12587009157453263, 0.15755637415817805, 0.07792396577341215, 0.08131720405071974, 0.3642994804041726, 0.132027430459857, 0.08656238152512483, 0.11608154539551054, 0.16055967871631893, 0.10469699664307491, 0.14434893429279327, 0.1099602027929255, 0.16698236550603593, 0.13053690615509236, 0.1297481091959136, 0.17314806394279003, 0.2638029615793909, 36.676903520311626, 77.96779305594308, 62.39396871839251, 53.99926287787301, 61.881566865103586, 37.19331101008824, 24.685702392033168, 2.517374472958701, 3.244317808321544, 5.78069669008255, 5.786395515714373, 1.2907247287886483, 1.213093483022281, 0.2606212837355477, 23.273550510406494, 78.65442098890031, 67.73650809696743, 79.4513098852975, 72.39222499302456, 73.09562587738037, 65.92454992021833, 65.67727048056466, 61.13975633893694, 60.452947752816335, 65.28091744014195, 63.435072898864746, 57.94977583203997, 62.59794003622872, 58.616698673793245, 54.77364655903408, 52.84144285746983, 53.61666032246181, 63.20848519461495, 62.04246629987444, 62.68671716962542, 67.09695420946393, 65.2341560636248, 63.70725468226841, 66.71642221723283, 65.28699016571045, 58.89048549107143, 47.561173234667095, 49.53457975387573, 46.07651342664446, 45.06735011509487, 46.81228944233486, 48.00557654244559, 49.14337880270821, 50.4688275882176, 47.27519580296108, 49.31415510177612, 51.79134423392159, 52.902632168361116, 55.31697831835066, 55.781552246638704, 57.25524779728481, 55.06581483568464, 54.193454606192454, 54.98934643609183, 59.83539881025042, 62.96644469669887, 63.008258955819265, 61.15072059631348, 61.7003231048584, 57.97401809692383, 57.01559400558472, 60.617786816188264, 62.61167662484305, 58.58828748975481, 57.83735050473894, 56.93776028496878, 59.51961013248989, 60.85055146898542, 55.626506669180735, 58.87105137961251, 54.28739077704293, 51.25537756511143, 44.49480812890189, 44.28909976141793, 45.20725209372384, 43.669744287218364, 44.5907210622515, 46.708431243896484, 58.825624057224815, 61.197426387241904, 57.04568665368216, 57.61891303743635, 61.722314153398784, 59.58696596963065, 57.632191044943674, 59.854416029793875, 57.51005213601248, 61.387001037597656, 60.565369606018066, 59.760372161865234, 59.317535672869, 57.11524854387556, 58.75489834376744, 57.24452672685896, 47.964123589651926, 45.6655934878758, 49.93603277206421, 49.84707498550415, 53.81543091365269, 58.405869483947754, 55.318340165274485, 58.7797520501273, 57.39044237136841, 59.2309124810355, 57.923386573791504, 69.19511563437325, 13.867219958986555, 0.4087131257568087, 7.411541819572449, 11.500396013259888, 6.83780083486012, 2.73491518838065, 0.3738951597894941, 5.001553492886679, 54.67473895209176, 45.484485217503135, 32.13858686174665, 54.238190582820344, 47.18006106785366, 0.34799029412014143, 0.18162265419960022, 0.1003198486619762, 0.16441717743873596, 0.15628864004143647, 0.1006975280387061, 0.1693413739225694, 0.11606279068759509, 0.2266827127231019, 0.14528311416506767, 0.12209196787859712, 0.09182480735970394, 0.12332030625215598, 0.16827589752418654, 0.20614790889833653, 0.10227710327931813, 0.1128675150019782, 0.08217078753347908, 0.2245869351817029, 0.15834898448416165, 0.16382511492286408, 0.14074341633490153, 0.13384580931493215], [0.04173823605690684, 0.025156940267022167, 0.05878326642726149, 0.03884642498035516, 0.04093619409416403, 0.02728456993853407, 0.029527245222457817, 0.02929363240088735, 0.02387196627179427, 0.10287705715745687, 0.05335440952330828, 0.08547429633992058, 0.028206619301012585, 0.06336691297058548, 0.02198716053473098, 0.08381966155554567, 0.04118900606408715, 0.01681550911494664, 0.06728165969252586, 0.0320064357614943, 0.06897493026086263, 0.0695480616497142, 0.027309132906209146, 0.1023265141993761, 0.039155758917331696, 0.1347038032753127, 0.04710806041423764, 0.16071935157690728, 0.17627957090735435, 2.778654532773154, 34.81279911313738, 70.96860163552421, 34.38673904963902, 50.4735141481672, 35.31619610105242, 13.557724612099783, 0.42961262858339716, 1.0889040955475398, 1.8322438767978122, 3.062619158199855, 0.8676667756267956, 0.6130818479827472, 0.15615882272166864, 0.06817446928471327, 27.484810250146047, 73.57876191820417, 70.60546793256486, 70.55929020472935, 64.57207611628941, 63.57185513632638, 65.16645281655448, 66.6003108705793, 66.894150188991, 59.48475796835763, 60.43126242501395, 59.692182540893555, 56.87840529850551, 56.990990434374126, 56.75646788733346, 54.65838636670794, 55.1857442174639, 55.24024241311209, 58.46961225782122, 61.89730453491211, 62.2537054334368, 61.32131276811872, 60.92370210375105, 56.15314538138253, 60.718417576381135, 54.552798066820415, 43.232223170144216, 42.737914425986155, 42.592589378356934, 43.4468287059239, 41.65957137516567, 43.25909880229405, 43.958240440913606, 41.716411113739014, 42.48943989617484, 42.26532575062343, 43.40965584346226, 41.699870926993235, 44.09481423241751, 46.0688738822937, 49.61793034417288, 48.46031876972744, 48.96544238499233, 54.48798527036394, 58.19614158357893, 54.541403021131245, 53.554543427058626, 61.360938344682964, 56.91581439971924, 58.1332881791251, 57.93739761625017, 57.619423730032786, 56.376842635018484, 58.529318128313335, 55.25981201444353, 59.61332743508475, 54.919892242976594, 49.92656932558332, 56.921372958592, 53.92827313286917, 50.798470973968506, 45.642817292894634, 40.870214326041086, 38.32466881615775, 40.353626183101106, 39.46490642002651, 39.88881254196167, 43.91587380000523, 53.30474526541573, 56.21128443309239, 56.02988086427961, 53.34868567330496, 57.90227447237287, 56.01332678113665, 55.56777702059065, 55.41184902191162, 54.88021108082363, 54.34117330823626, 54.43472385406494, 53.17123910358974, 55.84899493626186, 54.45011411394392, 53.95462417602539, 52.93406234468733, 51.12182971409389, 42.54729059764317, 41.98247153418404, 46.26600122451782, 49.72474847521101, 48.42672075544085, 54.056304114205496, 52.55890130996704, 54.41504308155605, 51.35444150652204, 61.49242605481829, 24.613901444843837, 0.10214409684496266, 0.1032011051263128, 0.30866709990160807, 1.2662087700196674, 1.4883772028344018, 0.14764311324272836, 0.10540926842285053, 11.464374814714704, 50.40314279283796, 22.82933132989066, 30.705666814531597, 54.97098234721592, 3.918809626783643, 0.3012948440653937, 0.07085055033011095, 0.052952173964253495, 0.06331425865313836, 0.0333984639229519, 0.013222601730376482, 0.0327403019182384, 0.016056362439745238, 0.09035706826086555, 0.0134738089649805, 0.010638000776192971, 0.051876261697283814, 0.021252459779913937, 0.04651664589930858, 0.023700770190251724, 0.015026717779359646, 0.03221203526481986, 0.02685140844966684, 0.04632133637954082, 0.07226669362613133, 0.04271361996818866, 0.03527081345341035, 0.017271228500508835, 0.0060049191400009605, 0.05812869048012154, 0.022087576932140758, 0.08664574633751597, 0.039025103606815846, 0.06915916608912603, 0.039259700304163356, 0.020566236959504228, 0.036846548185816834, 0.0563730591508959, 0.03235405603689807, 0.05223761212878993, 0.06445636879652739, 0.05555208606113281, 0.04603005825941052, 0.06837499673877444, 0.029401176808668033, 0.0462223449056702, 0.01932012096845678, 0.021227679681032896, 0.07860136763857943, 0.04802417429164052, 0.03868740690605981, 0.04741789646712797, 0.0956557278654405, 0.14325259812176228, 0.07493330910801888, 0.11846926941403321, 0.19679543003439903, 6.311350158282688, 51.04748746326992, 73.74927765982491, 35.87781204496111, 69.35129724230084, 34.995866775512695, 23.735065494264873, 0.05834869188921792, 0.5296976566314697, 1.0486737000090736, 2.346195395503725, 2.636440541063036, 3.314235359430313, 0.6622281393834523, 0.054042226901011806, 34.5898939541408, 77.42688274383545, 71.87427847726005, 72.63855947766984, 66.99127905709403, 65.544191632952, 67.40645476749965, 70.44745894840786, 66.53348309653146, 61.25638880048479, 61.895491055079866, 61.057892663138254, 59.76895318712507, 59.363553592136924, 59.49053886958531, 57.9234664780753, 55.93298823492867, 57.25845439093453, 61.39675630841936, 63.652864183698384, 63.601378032139365, 63.645714487348286, 63.44758660452706, 58.524405751909526, 63.595367840358186, 56.88923059191023, 47.31158699308123, 43.58968366895403, 43.683508668627056, 44.742184843335835, 44.44369718006679, 43.37525183813912, 45.765897682734895, 43.16121258054461, 45.491183280944824, 44.64979812077114, 45.946602957589285, 45.44929606573922, 46.91744000571114, 48.071851934705464, 50.65902410234724, 51.796656131744385, 51.81465196609497, 57.17113985334124, 60.62071200779506, 57.37297807421003, 55.268174171447754, 61.99866485595703, 58.70790767669678, 59.83947045462472, 60.94891711643764, 58.835657255990164, 57.917376382010325, 60.46172332763672, 57.43297576904297, 59.98373590196882, 59.0567558833531, 52.68032455444336, 56.873982770102366, 55.606780733381, 52.88291665485927, 47.506053175245015, 42.57264804840088, 40.257240772247314, 43.315007482256206, 40.99269022260393, 41.75765214647566, 44.954584326062886, 56.65025772367205, 57.982786723545615, 57.42154598236084, 56.19837468011038, 58.40320832388741, 57.15099702562605, 55.93984610693795, 56.41822957992554, 57.29759011949812, 55.63879803248814, 56.262784481048584, 55.00757156099592, 58.75752476283482, 56.355987616947715, 57.70058911187308, 54.38221979141235, 52.46199131011963, 45.37470367976597, 42.70286423819405, 49.02984871183123, 52.53638219833374, 50.67636333193098, 55.848105566842214, 54.82460117340088, 57.88028689793178, 54.03108215332031, 65.68228707994733, 27.03703359195164, 0.07668766818408455, 0.6102396547794342, 4.585982603686197, 0.9392203560897282, 0.9074814734714372, 0.17206433495240553, 0.1075020536248173, 14.717644725527082, 56.75283745356968, 30.663619790758403, 27.246162210191997, 63.10378279004778, 6.127558146204267, 0.5573897021157401, 0.026875900171164955, 0.06206440393413816, 0.03543498160849724, 0.0008409719552478886, 0.018073530002896274, 0.033981966719563515, 0.019040075995560204, 0.08472007073994194, 0.017414000750120198, 0.015432373154908419, 0.07156179073665823, 0.029908731180642332, 0.09145624749362469, 0.023442860726001005, 0.02480497906383659, 0.051863244002951045, 0.04050615895539522, 0.058631966688803265, 0.04356383113190532, 0.028623901374105896, 0.024186731881595085, 0.052429651109767814, 0.13474849159164087, 0.27696724661758965, 0.09249473176896572, 0.19982632382639817, 0.08432244921901397, 0.1517157211367573, 0.13355607486196927, 0.09107699391565152, 0.1116239299465503, 0.1881086483065571, 0.15721526103360312, 0.11211052097912345, 0.22347738114850862, 0.17479186930826732, 0.1409311941159623, 0.13155693427792617, 0.08982435041772467, 0.21123403097902024, 0.1155911274254322, 0.12546963377722672, 0.1982246690562793, 0.2510294041463307, 0.08662055911762373, 0.15174265897699765, 0.19010948522814683, 0.21889029443264008, 0.1652586015739611, 0.3628108559974602, 0.5900162713868278, 7.243470541068485, 66.16777161189488, 82.05364649636405, 44.2982679094587, 66.7290540422712, 48.080325262887136, 22.409922429493495, 0.7597901299595833, 2.6827787288597653, 5.087613446371896, 9.33426296710968, 4.600924704756055, 1.2231092027255466, 0.3058297650090286, 0.19785931866083825, 33.0547832761492, 78.63347911834717, 74.9224670955113, 75.45865958077567, 70.7962098802839, 69.3481844493321, 70.49219839913505, 73.09553555079869, 71.22653266361782, 64.87025805882045, 65.35502692631313, 65.14917264665876, 62.465611594063894, 62.51635428837368, 62.18493216378348, 60.83401475633894, 60.94390746525356, 61.15876661028181, 62.96128913334438, 67.35949189322335, 67.81841346195766, 66.09477383749825, 65.5767022541591, 60.536555426461355, 65.86713000706264, 59.747851508004324, 50.30061517442976, 46.16089929853167, 46.878957407815115, 49.240528515407014, 45.75601734433855, 47.55074398858206, 47.8978134563991, 46.410030433109824, 46.36422095979963, 47.34306580679757, 47.729462078639436, 45.90490334374564, 48.36428771700178, 49.25174290793282, 54.21565410069057, 52.61154086249215, 53.026414326259065, 59.10519872392927, 62.6389274597168, 58.42953504834856, 55.562089920043945, 65.03743866511753, 60.9535585130964, 61.70478384835379, 64.63652760641915, 60.95132119315011, 60.384910992213655, 62.70751312800816, 59.257051604134695, 62.830322538103374, 60.24634306771414, 55.7114588192531, 60.06546756199428, 57.61867332458496, 55.91719150543213, 50.683245522635325, 45.51837158203125, 42.432336126055034, 45.27390268870762, 42.207589694431846, 43.2128689629691, 46.88625996453421, 58.513830593654085, 61.18623283931187, 59.76053197043282, 56.66109343937465, 60.55705261230469, 60.93889781406948, 58.70580237252371, 59.691341808864046, 58.61184188297817, 59.07495321546282, 59.7686196735927, 57.703639371054514, 61.99013941628592, 58.12451260430472, 59.25462668282645, 58.52167510986328, 54.094411509377615, 48.54533345358712, 45.56098140989031, 51.715865952628, 53.15186057771955, 53.79663256236485, 58.94534846714565, 57.814473560878206, 59.75565433502197, 57.45763145174299, 65.94753456115723, 28.619228737694876, 0.17840510899467127, 0.4185877101761954, 6.095159130437033, 13.198256952422005, 2.5424657208578925, 0.9870284135852541, 0.2572835428374154, 20.030834913253784, 65.14836665562221, 34.79667929240635, 42.06238971437727, 72.35369028363908, 10.795761823654175, 0.7121780876602445, 0.23812073682035717, 0.09781555911259991, 0.1757772242916482, 0.10917658984128918, 0.1132567362593753, 0.14298060057418688, 0.12859303903366837, 0.19168916903436184, 0.15234012263161795, 0.12341872097126075, 0.23184833196657045, 0.1721842728023018, 0.15672658011317253, 0.12234762630292348, 0.08834262671215193, 0.17358839245779173, 0.08676821512303182, 0.19963190997285502, 0.2544271546815123, 0.16712519712746143, 0.06976097915321589, 0.20191165192851], [0.06296546451215233, 0.027129324518942406, 0.011310395901091397, 0.012672951894014009, 0.02492476933236633, 0.025014556478708982, 0.05738673957863024, 0.012615158521969403, 0.028949238559497253, 0.04401506031198161, 0.020490052743947933, 0.01876685708495123, 0.036999459444944344, 0.01457548011759562, 0.05702736707670348, 0.061467937725995264, 0.039386962939585955, 0.020856329339689443, 0.015646676566185694, 0.11930888864610877, 0.009054947195441594, 0.08027636525886399, 0.06516797561198473, 0.02383512182028166, 0.035146499052643776, 0.09668746750269618, 0.06882928271910974, 0.036530221945473125, 0.03881600625546915, 0.10470621793397836, 23.592229638780864, 54.340468066079275, 40.27729327338082, 32.91647243499756, 54.02802494594029, 21.800777333123342, 0.8759728584970746, 0.34650913359863417, 0.5031429986868585, 0.864571461720126, 2.947640150785446, 2.5175284189837317, 2.598373315164021, 0.045752486546656916, 1.7454973544393266, 55.271801131112234, 77.63414750780377, 69.06574712480817, 70.34616810934884, 69.06629603249687, 70.64016028812954, 68.05238015311105, 67.07550512041364, 67.40336976732526, 60.52224908556257, 58.715279715401785, 63.14959226335798, 60.57740388597761, 57.14462552751814, 55.97560848508562, 53.8501684325082, 59.619566917419434, 60.55751814161028, 62.40176459721157, 63.130324908665244, 63.971501622881206, 60.40030125209263, 60.3182430267334, 59.089099747794016, 54.20275477000645, 43.35389307567051, 43.057691369737896, 43.08727332523891, 44.530052866254536, 43.16030931472778, 44.19728626523699, 45.37740305491856, 43.24003989355904, 43.09101493018014, 45.94793006352016, 46.77949741908482, 47.06183052062988, 47.93221051352364, 47.350319726126536, 48.156223910195486, 50.464012486594065, 52.15457173756191, 56.35250309535435, 61.09312002999442, 52.9678236416408, 46.763784067971365, 58.533229964120046, 56.14751386642456, 57.94373089926583, 59.305056708199636, 60.27431651524135, 57.201982906886506, 56.92464556012835, 60.05997153690883, 55.6997788974217, 51.29310975755964, 57.53231763839722, 55.02230521610805, 53.97111919948033, 49.569946084703716, 44.58334902354649, 40.68540613991873, 41.555122579847065, 39.960778508867534, 40.82391153063093, 41.60436793736049, 42.08364077976772, 50.1365647315979, 57.237234592437744, 55.115390232631135, 55.89606203351702, 57.14809615271432, 59.218565532139365, 57.331424372536794, 56.672387736184255, 54.481460911887034, 56.76479877744402, 54.71780041285923, 53.73659665243966, 53.01602676936558, 53.08582489831107, 53.85486888885498, 55.28547518593924, 53.2933988571167, 48.73451900482178, 42.397247723170686, 42.4519613129752, 46.95947313308716, 51.20747668402535, 50.3179544040135, 55.84706333705357, 55.731139591761995, 55.94468552725655, 40.20401757104056, 0.18978954239615373, 0.1539135096328599, 0.08724657552582876, 2.4412471864904677, 1.4070532066481454, 0.46173092084271566, 0.14911594135420664, 0.19503069615789823, 35.871881757463726, 35.96740211759295, 18.897694894245692, 54.32820449556623, 25.789906638009207, 0.08662076267812933, 0.05066007249323385, 0.030219853057393005, 0.09292647003063134, 0.03830870633412685, 0.037667528060930114, 0.01752061556492533, 0.037752538320741484, 0.008897963029864644, 0.10355954803526402, 0.03395271846758468, 0.03773162587146674, 0.04920898464375308, 0.021589048772252033, 0.033657993389559646, 0.04255876809890781, 0.014112759946978517, 0.046478695435715575, 0.02518379668306027, 0.03283771579819066, 0.033153390644916465, 0.02813429425337485, 0.041253721341490746, 0.042352808972022364, 0.09155874699354172, 0.028965326624789407, 0.04269006462501628, 0.01186175225302577, 0.054580108395644596, 0.03754672168620995, 0.022135388205892274, 0.055613479909620116, 0.03369603206270507, 0.06648431997746229, 0.0553377198853663, 0.04783378075808287, 0.014502330649910229, 0.05031543437923704, 0.02060972257251186, 0.018822724265711646, 0.04869880773393171, 0.022680531721562147, 0.0583958432876638, 0.049371727875300815, 0.1168695552540677, 0.050176602721746476, 0.07070583238133363, 0.021341001814497367, 0.04888476025579231, 0.06461231649986335, 0.07122140364455325, 0.031834111615483246, 0.02427353517019323, 0.14651498092072351, 32.15809392929077, 66.40404510498047, 31.922150475638254, 48.9257299559457, 60.44199044363839, 22.366933924811228, 2.766170356954847, 0.3954635624374662, 0.6114286109805107, 2.669698093618665, 3.0098834165505, 5.779654460293906, 10.517986740384783, 0.12953796690063818, 2.1818368434906006, 63.53659997667585, 78.1862096786499, 70.13101713997978, 71.68487753186906, 69.71147796085903, 70.68528188977922, 68.93041011265346, 70.87403665270124, 68.32689653124127, 62.76332800728934, 61.632550375802175, 65.52071366991315, 61.191673278808594, 59.51307882581438, 57.32850612912859, 58.96484511239188, 62.44552435193743, 62.99059663500105, 63.59702845982143, 65.59804017203194, 65.37040328979492, 62.06521470206124, 62.22528730119978, 60.79126249040876, 56.55716923304966, 44.99398061207363, 45.17174679892403, 45.89416490282331, 45.83541093553816, 46.076655864715576, 46.49036203111921, 47.44819899967739, 45.001779964991975, 47.52273232596261, 48.11984314237322, 47.94179555347988, 46.79819502149309, 50.40260778154646, 48.11177975790841, 51.79943193708147, 51.86219848905291, 52.45135014397757, 57.162749903542654, 63.89017295837402, 54.534044878823416, 48.707445349012104, 58.3685576575143, 58.70322459084647, 59.17456259046282, 60.32410730634417, 59.73749869210379, 57.71093497957502, 57.068483693259104, 59.111702237810405, 58.70503112248012, 52.99135371616909, 58.376645360674175, 58.14592000416347, 56.75925064086914, 51.9102418082101, 47.76835462025234, 43.25548921312605, 43.45513527733939, 43.39539813995361, 42.406825814928325, 43.664685998644146, 43.266978059496196, 51.75554364068167, 59.48956612178257, 58.228947503226145, 56.78452818734305, 58.796288762773784, 60.04210077013288, 58.87303161621094, 59.035598618643625, 58.46348394666399, 58.12803534099034, 57.122422558920725, 56.101700919015066, 55.52641786847796, 56.34718772343227, 58.23413780757359, 56.79956061499459, 55.91581923621041, 51.80867998940604, 44.857177530016216, 44.61272253308977, 48.72422872270857, 52.86737353461129, 52.90180533272879, 55.94744048799787, 59.162132263183594, 58.20636238370623, 44.18100316183907, 0.37770896085671013, 0.42724595272115296, 1.4050564680780684, 2.714982326541628, 1.0232158260686057, 0.09820728416421584, 0.24997952048267635, 0.7308609251465116, 37.648195675441194, 51.86359160287039, 20.00285104342869, 52.51748309816633, 34.23431989124843, 0.16428862219410284, 0.08025676238217525, 0.05871360802224704, 0.022317622355850678, 0.0481776555201837, 0.016187519866174886, 0.028309047554752657, 0.048144173209688494, 0.039560722187161446, 0.0338760474031525, 0.03786553136472191, 0.027733310591429472, 0.035837308769779544, 0.015837143042257855, 0.02288012788631022, 0.0422634289466909, 0.033437092921563556, 0.11771305570644991, 0.01771458497803126, 0.0314392890515072, 0.04793781374714204, 0.029482787608035972, 0.03367317221792681, 0.02767337898590735, 0.18107361080391066, 0.11295168048569135, 0.13408970194203512, 0.06570827947663409, 0.1917084122874907, 0.1109331880829164, 0.10157953535339662, 0.08873030769505671, 0.09232446697673627, 0.11919128495667662, 0.13010667424116815, 0.17034038103052548, 0.1517743601330689, 0.07422107804034438, 0.1368576227022069, 0.13168718586010592, 0.1564028781971761, 0.1406766213476658, 0.254753122904471, 0.1477140337228775, 0.17202947182314737, 0.19284459203481674, 0.14651586301624775, 0.15211251484496252, 0.16460940640951904, 0.3412036954292229, 0.15343037912888186, 0.17831271966653212, 0.119291396013328, 0.18220533936151437, 38.287065165383474, 75.27144731794084, 50.528557777404785, 50.02291999544416, 68.39473874228341, 34.468019076756065, 2.433144284146173, 0.44755662285855835, 1.5063923618623187, 6.2434219632829935, 9.652226431029183, 4.847487611430032, 4.763416145529066, 0.1608452605349677, 2.845387203352792, 61.59616265978132, 81.05309895106724, 72.577727999006, 74.85084506443569, 72.65006569453648, 73.47756835392543, 73.82163619995117, 72.99670437404087, 71.4651963370187, 65.8109746660505, 64.18747942788261, 68.42881270817348, 64.43628747122628, 60.80962657928467, 61.31462860107422, 59.58463832310268, 65.4172272000994, 65.75060176849365, 66.06965609959194, 70.17200456346784, 69.19727652413505, 64.06630979265485, 65.58410903385708, 64.33248833247593, 59.64417743682861, 47.79855496542794, 47.71451997756958, 47.495384216308594, 48.42218010766165, 48.788044452667236, 49.134634494781494, 51.05863584790911, 48.30022185189383, 48.059150627681184, 52.3398037637983, 51.89600494929722, 51.36429752622332, 52.200092860630576, 51.0778615134103, 54.38550976344517, 54.23178086962019, 53.75643375941685, 61.1874418258667, 67.60638918195451, 57.08817488806588, 49.4406852722168, 59.625827244349885, 58.90773091997419, 61.5063294001988, 62.74966090066092, 62.0482610974993, 58.29280839647566, 58.79471846989223, 62.68686308179583, 59.68665872301374, 57.106240204402376, 59.64984021868025, 58.296477045331685, 58.15346574783325, 53.76992021288191, 49.35888065610613, 44.97744737352644, 46.473265988486155, 44.719040393829346, 43.84851448876517, 45.974402700151714, 46.619542939322336, 54.49428728648594, 63.47694969177246, 59.52864973885672, 57.289304392678396, 61.544739042009624, 63.02112007141113, 61.239539418901714, 63.461851256234304, 60.4457494190761, 61.01921898978097, 60.014036996024, 59.46391337258475, 58.36848817552839, 57.484673840659006, 58.956319672720774, 58.657415117536274, 57.45153440747942, 54.64693226133074, 46.423718384334016, 46.64878095899309, 52.73968996320452, 55.048916816711426, 54.72322348185948, 62.33076095581055, 63.83132866450718, 62.197473662240164, 46.54988724844796, 0.603557170501777, 0.37911103133644375, 1.3403852411678858, 8.101086258888245, 4.779055237770081, 0.8995110211627824, 0.5400501468351909, 0.8463711983391217, 49.544932569776265, 47.91469757897513, 28.674862963812693, 67.03932585035051, 41.970065525599885, 0.26765609053628786, 0.2318259131695543, 0.19470487721264362, 0.1683899185487202, 0.17530944224979195, 0.11930172331631184, 0.13503942026623658, 0.09892650414258242, 0.08975488878786564, 0.11833109254283564, 0.1359700174736125, 0.12115320110959665, 0.17149372771382332, 0.09306131529488734, 0.14763620575623854, 0.09712928879473891, 0.12721177243760654, 0.1790863581533943, 0.0899553212470242, 0.2065753181065832, 0.10396305245480367, 0.054713247144328694, 0.10197935532778502, 0.10165639301495892], [0.032877471164933274, 0.058774106204509735, 0.02862302606393184, 0.040595847714160166, 0.022226249133901935, 0.03535330295562744, 0.01633464152525578, 0.004293011335123862, 0.05786516783492906, 0.029506980774125884, 0.02114299002901784, 0.03790786177186029, 0.08166477682867221, 0.04203737500522818, 0.00859650518811707, 0.050753452482500246, 0.012531967584176787, 0.05501943946416889, 0.03401497744822076, 0.013796617759258618, 0.024939863343856165, 0.050605341858629665, 0.019526122503780892, 0.0416594377851912, 0.06322474631347827, 0.08075192331203393, 0.023790000937879086, 0.05443980431716357, 0.12075267545878887, 0.09611103164830379, 0.9522835122687476, 43.99159526824951, 55.24926812308175, 31.9523959841047, 36.17559099197388, 54.42625399998256, 4.253003214086805, 0.040761203305529695, 1.0402062343699592, 0.4333548577768462, 0.9865620157548359, 26.725227969033376, 16.6061338356563, 0.27573738832558903, 0.022693585038983395, 20.633038759231567, 73.46615941183907, 70.99421964372907, 70.90598446982247, 70.06495366777692, 73.33794430324009, 69.14936174665178, 72.43872928619385, 64.76624352591378, 66.33433382851737, 64.69737992967877, 61.266894476754324, 61.39432443891253, 61.929801259722026, 59.16889980861119, 61.074561391557964, 59.010918617248535, 63.67010266440255, 64.47274466923305, 63.83716515132359, 59.15860257829939, 58.85432011740548, 60.63767256055559, 60.623560769217356, 55.48832784380232, 43.72958217348371, 43.80023145675659, 43.33656774248396, 43.03202819824219, 43.69015114648001, 43.13551466805594, 43.22191899163382, 44.62479155404227, 45.057167530059814, 43.783041613442556, 47.20293453761509, 52.96402645111084, 52.196483271462576, 51.49342284883772, 50.94093336377825, 49.915618964603965, 54.36686774662563, 55.09969425201416, 61.574428694588796, 50.50546543938773, 43.08099562781197, 57.89485032217843, 55.59852627345494, 58.86786215645926, 56.28242703846523, 60.296870367867605, 57.664701666150776, 61.04173115321568, 52.61510876246861, 53.787968158721924, 60.45616476876395, 56.68498134613037, 57.05636256081717, 55.38184322629656, 51.05828148978097, 43.3524443762643, 40.90383318492344, 41.62492070879255, 42.89289052145821, 41.860072067805696, 42.37385661261422, 43.977844783238, 52.97473015104021, 55.115629945482524, 59.036779812404085, 55.603456020355225, 57.50180115018572, 58.56276675633022, 57.68514674050467, 57.93244355065482, 57.39389910016741, 57.31069789613996, 53.75781992503575, 53.75159086499895, 53.63451371874128, 54.8162841796875, 55.57861968449184, 56.87069279806954, 55.333886759621755, 54.76493351800101, 43.97811576298305, 45.8924834387643, 46.81797654288155, 50.00721011843, 57.001082692827495, 55.50324215207781, 49.89066103526524, 52.39205074310303, 3.873998088496072, 0.23248781050954545, 0.3940931116896016, 2.3885416260787418, 4.265068326677595, 0.3180190223668303, 0.6670292360442025, 0.01772556367463299, 8.907850282532827, 56.70808063234602, 16.80287034170968, 31.062474182673864, 49.35414545876639, 3.066226576055799, 0.2558960201484816, 0.011325582362977522, 0.05450849920245154, 0.019701019993850162, 0.05547644976260407, 0.04784710718584912, 0.04316535126417875, 0.037997492855148654, 0.03971161480460848, 0.044674908476216454, 0.03278658479186041, 0.032600767977003536, 0.03551233460062316, 0.016395389069137827, 0.0034429683208665146, 0.029070984705218246, 0.027278809176225747, 0.033114045791860135, 0.07964606729469129, 0.013054427674173244, 0.0033012138737831265, 0.023116736439988017, 0.09376504431877818, 0.03933644261477249, 0.019227034445585947, 0.024529361531936696, 0.029938064249498502, 0.01931012445129454, 0.01589368366902428, 0.029933538420924118, 0.02569537137502006, 0.041168673762253354, 0.04620686073654464, 0.022846085784424628, 0.06401646097323724, 0.05058652947523764, 0.06519703048148326, 0.022764670063874552, 0.05020573562277215, 0.03741664991581014, 0.0651284780885492, 0.07588624368820872, 0.04172543888645513, 0.06813039843525205, 0.036365388826067956, 0.07802435502942119, 0.085712855681777, 0.007137063724387969, 0.07647105945008141, 0.025942235985504727, 0.070970006420144, 0.03159460910995092, 0.04718616658023425, 0.030564687946545224, 3.4143484788281575, 60.684718813214985, 54.215963295527864, 27.350065571921213, 60.40688814435686, 53.32454068320138, 6.731066082205091, 0.09955874950225864, 0.4258424980299813, 0.4726692853229386, 2.2874166752610887, 7.49091282912663, 17.087086405072892, 1.3711363396474292, 0.12468629223959786, 24.73968642098563, 79.8915546962193, 71.6741703578404, 73.34026500156948, 71.16714641026088, 72.98430183955601, 70.36999348231724, 71.62258693150112, 68.25945731571743, 70.5657937186105, 65.32879052843366, 63.92589364733015, 64.21502903529576, 63.58179106031145, 61.59862232208252, 60.865816661289756, 61.18615640912737, 66.68930339813232, 67.5087947845459, 65.88204084123883, 62.19474996839251, 61.98251029423305, 62.32614735194615, 61.611712728227886, 57.2517215864999, 45.11031430108206, 46.09273747035435, 45.81937449319022, 45.29773153577532, 45.222864695957725, 44.16159336907523, 45.670054231371196, 47.29663446971348, 45.06260102135794, 47.31300095149449, 49.860919271196636, 53.42442103794643, 53.02299233845302, 52.729302406311035, 52.91791125706264, 52.041604450770784, 56.31146356037685, 57.73505217688424, 63.75079904283796, 53.08437272480556, 44.12891946520124, 58.26053401402065, 56.296563148498535, 61.738934244428364, 57.23562608446394, 61.129667554582866, 58.00633069447109, 61.050610951014924, 56.026615210941856, 56.51353801999773, 61.701393127441406, 59.01327405657087, 57.63256972176688, 56.161959171295166, 53.18807806287493, 45.510169233594624, 42.71994291033064, 43.92937067576817, 42.725094999585835, 43.12527649743216, 43.96801308223179, 46.71275302342006, 56.041307176862446, 58.62134007045201, 59.56193855830601, 55.64819894518171, 56.86436298915318, 60.57989828927176, 57.074066570826936, 60.02091571262905, 58.45964854104178, 59.182268142700195, 55.59793567657471, 55.042791979653494, 55.69348382949829, 57.413395745413645, 57.37865475245884, 59.78115422385079, 58.29321139199393, 58.791008131844656, 46.215925557272776, 48.57590552738735, 48.91484907695225, 52.50688362121582, 57.96877220698765, 61.03906304495675, 52.52018594741821, 58.16070229666573, 5.062028876372746, 0.40200928119676455, 1.4505893162318637, 1.0233915937798364, 0.6984926334449223, 0.06328678477023329, 0.6541576981544495, 0.15579461226505892, 11.25245475769043, 68.25337069375175, 24.87721732684544, 24.164547545569285, 60.42264665876116, 5.615459842341287, 0.3958909309336117, 0.11057049754474844, 0.030941990736339773, 0.03848768012332065, 0.027991861271272813, 0.08692035624491316, 0.013975286207694029, 0.03547878782930119, 0.0355071472004056, 0.03154600564656513, 0.06947547875876937, 0.06155559087970427, 0.04130446219018527, 0.027874506943460022, 0.03629364053319607, 0.036907853824751716, 0.030102140802357878, 0.009809321224955576, 0.021784965580861484, 0.06440929203693356, 0.01869462024686592, 0.03596769945163812, 0.027595930998878818, 0.018392762069457343, 0.11137184061642204, 0.21374866818743093, 0.14394211183701242, 0.1047615660354495, 0.19309197233191558, 0.12856403844697134, 0.0614845889753529, 0.07185577960418803, 0.22727529092558793, 0.0721180062474949, 0.12410173432103225, 0.2606039403804711, 0.1407459540558713, 0.08983311709016562, 0.14791089030248777, 0.16363767640931265, 0.09876457176038198, 0.2676267778234822, 0.15948069947106497, 0.17124747378485544, 0.08082931701626096, 0.1287384626588651, 0.14443499967455864, 0.09788050848458495, 0.1719389823930604, 0.19716696866921016, 0.2139155063778162, 0.10508087782987527, 0.1737203403775181, 0.17308504161025795, 3.5382802401270186, 71.24049854278564, 67.98197405678886, 47.79519551140921, 48.40304476874215, 70.80019814627511, 9.33074631009783, 0.16286208374159677, 1.7574225259678704, 3.3344654738903046, 5.7430331110954285, 46.06365578515189, 30.651078292301722, 1.001744372504098, 0.25562783596771105, 24.56504171235221, 79.58768912724086, 73.7772650037493, 75.25015108925956, 74.20082024165562, 74.08555657523019, 70.76150362832206, 76.3861676624843, 70.53231729779924, 73.04766941070557, 69.36221981048584, 68.17522430419922, 67.07299682072231, 65.91061878204346, 65.26831340789795, 66.86243166242326, 65.32348210471017, 66.98648480006626, 71.62686007363456, 68.69920185634068, 63.31741905212402, 63.80042307717459, 63.7790504183088, 65.28766414097377, 61.44819382258824, 47.24420683724539, 48.670074462890625, 49.1067270551409, 49.873808179582866, 48.875869682856965, 46.51464598519461, 47.255511556352886, 49.73646661213466, 48.282441411699565, 49.37970093318394, 51.58097015108381, 57.61470242909023, 56.65241513933454, 55.875213963644846, 57.13447420937674, 55.93749761581421, 60.460569926670615, 61.09138992854527, 67.01636205400739, 55.05456222806658, 45.4805977003915, 58.40834304264614, 56.582509313310894, 60.89420700073242, 57.675099645342144, 62.57430921282087, 60.54494885035923, 64.68458134787423, 57.02310153416225, 59.49035126822335, 61.730221203395296, 60.50010517665318, 61.435311862400596, 59.52567590985979, 54.97042301722935, 49.747819968632285, 45.67383752550398, 47.39086593900408, 45.98574563435146, 45.65708194460188, 46.30735690253121, 49.125254426683696, 59.53634139469692, 60.607704980032786, 64.48732893807548, 55.691333362034385, 59.26622322627476, 62.6742798941476, 60.79475743430001, 61.51552186693464, 61.87784957885742, 63.38698441641671, 58.69461577279227, 60.05425316946847, 58.31203406197684, 58.15347269603184, 59.64353820255825, 61.3592985698155, 60.44807011740548, 62.36236136300223, 48.60080787113735, 50.75298111779349, 50.87965372630528, 55.025953020368306, 61.87313870021275, 62.136308670043945, 54.54172611236572, 60.52477822984968, 5.4883251786231995, 0.28522002377680367, 1.419968387910298, 3.4209998590605597, 9.813153658594404, 0.8973509999258178, 2.0362783798149655, 0.3654999988419669, 15.647746222359793, 69.68818759918213, 26.514365775244578, 40.46744115012032, 69.08305508749825, 9.40360164642334, 0.7748523588691438, 0.2215091817613159, 0.2360181739287717, 0.17893522126334055, 0.1995087694376707, 0.23795172731791223, 0.0627376124528902, 0.12681816784398897, 0.11769567163927214, 0.17392471512513502, 0.1524351853877306, 0.11196840181946754, 0.13228281747017587, 0.1057610141911677, 0.09277234080114535, 0.13536705768534116, 0.10938876774162054, 0.11515085319323198, 0.17946012238306658, 0.13620854967406817, 0.12763542256184987, 0.13250110218567507, 0.13421567875359738, 0.10389903267579419], [0.04990629133369241, 0.00658690753126783, 0.01176083373970219, 0.06363580282777548, 0.07863606791943312, 0.05535688849964312, 0.005974510593140232, 0.06612474391502993, 0.03717029420658946, 0.01857382065749594, 0.045693945937923024, 0.04020410230649369, 0.03764118393883109, 0.05697351175227335, 0.08257910955165114, 0.024779454272772585, 0.03767699362444026, 0.027867061717967902, 0.07040442034069981, 0.026209022384136915, 0.11328498367220163, 0.04376040951215795, 0.11001056366200958, 0.013483681649501835, 0.0652223601937294, 0.03810942738449999, 0.09989184912826334, 0.06763965476836477, 0.06987596369747605, 0.20013934560120106, 0.15931624972394534, 12.41764507974897, 63.01314353942871, 40.187327998025076, 29.06708356312343, 50.57959924425398, 28.460729905537196, 0.23603019756930216, 0.30192623447094646, 0.7322192979710442, 0.16115619242191315, 1.158433741756848, 14.798558235168457, 2.577526765210288, 0.0672779752473746, 0.915962455528123, 51.16737515585763, 72.58535712105888, 73.99206856318882, 75.41046687534877, 70.96687848227364, 71.43927260807583, 67.678574017116, 72.55962099347795, 65.40368516104562, 63.76969119480678, 64.44340937478202, 64.5614036832537, 60.222608021327424, 60.52448640550886, 60.68704645974295, 65.33985900878906, 63.71921253204346, 64.40734127589634, 62.93269034794399, 58.97945717402867, 61.06140150342669, 64.27022552490234, 60.94892406463623, 54.216011932918, 43.23511014665876, 42.70829772949219, 46.02730975832258, 43.26314960207258, 44.53573301860264, 43.240557534354075, 44.86694669723511, 45.569142069135395, 46.340496335710796, 45.99496589388166, 56.71706117902483, 55.78849697113037, 59.45755577087402, 53.824626854487825, 57.627424580710276, 52.33669097082955, 58.312374523707796, 55.69028070994786, 62.12492752075195, 46.164515835898264, 43.61034761156355, 62.407997131347656, 58.03503370285034, 57.90072154998779, 56.193378925323486, 56.648392132350374, 58.55068383898054, 56.75152424403599, 52.32895415169852, 63.818168776375906, 56.606574399130686, 57.338584491184776, 56.74787991387503, 56.46189900806972, 48.2177015713283, 41.603648798806326, 40.734467370169504, 41.96043879645211, 43.131008761269705, 43.58297865731375, 42.28582293646676, 42.871146133967805, 50.08799682344709, 57.11568628038679, 58.133420194898335, 57.853835105895996, 57.770491463797434, 58.684450558253694, 59.508159501211985, 56.93552296502249, 57.66504907608032, 55.987538542066304, 55.10602406093052, 51.650869028908865, 55.192129611968994, 52.194509983062744, 58.20842947278704, 55.58170468466622, 57.542878900255474, 54.094557421548025, 56.29631648744856, 41.461822169167654, 50.32573986053467, 53.03581523895264, 58.168418271201, 51.46631097793579, 66.47383975982666, 10.497564247676305, 0.22756304405629635, 0.17796730462993893, 0.6001487533961023, 1.8868221938610077, 0.6697559154459408, 0.18299048580229282, 0.17622199042567185, 0.5380578051720346, 41.62066841125488, 37.69772590909685, 16.689013685498917, 53.24057517732893, 26.60244287763323, 0.17862477792160852, 0.042275208314614635, 0.0024536530254408717, 0.06287395049418722, 0.06918460436697517, 0.06786155607551336, 0.022867610611553704, 0.0442489106208086, 0.025558334442653825, 0.11106046089636427, 0.0161097970724638, 0.0738971047103405, 0.00546152115566656, 0.03436476903568421, 0.0364170762311135, 0.04714731366506644, 0.013412753535833741, 0.03137714881449938, 0.05766134948602744, 0.013126190385914274, 0.05332416043217693, 0.04227980538936598, 0.04060877041359033, 0.01996094131443117, 0.027194570749998093, 0.021318038493128758, 0.04954378739265459, 0.025558227573388388, 0.017552927402513366, 0.1077453355704035, 0.05047932094229119, 0.045525072142481804, 0.03276728047057986, 0.08611355096633945, 0.006806741002947092, 0.015596035801406418, 0.027739914433498467, 0.044919025019875596, 0.057959803113979955, 0.062266871998352666, 0.07539649068244866, 0.047154692733394246, 0.007315817837869483, 0.07772646458553416, 0.05171976777325783, 0.0871063426935247, 0.05998330310519252, 0.14813163131475449, 0.046501270295786004, 0.05864836009485381, 0.04505008066605244, 0.02938936690666846, 0.005956151980041925, 0.05124108845900212, 0.13404460650469574, 0.09653144516050816, 18.620970726013184, 75.66547966003418, 31.151230471474783, 34.219603606632774, 69.93197904314313, 25.685701029641287, 0.29779810884169167, 0.29086969633187565, 0.568288114454065, 0.07442944935922112, 1.522756455200059, 8.124777010508947, 4.036985891205924, 0.0984667966674481, 1.768186588372503, 58.42409460885184, 76.63250909532819, 76.79962716783795, 77.09984493255615, 72.56483214242118, 71.74754333496094, 70.67268480573381, 76.4449772153582, 67.6717300415039, 66.28785037994385, 66.65734168461391, 66.95748996734619, 60.50658089773995, 60.61757837023054, 63.73937620435442, 68.15508842468262, 64.76166466304234, 66.3946441922869, 64.82896491459438, 62.04507882254464, 63.46076038905552, 66.20540305546352, 62.538963726588655, 55.69993870598929, 46.05891016551426, 46.71228402001517, 46.46087040219988, 45.54639714104788, 45.208391598292756, 45.45746714728219, 46.912075996398926, 48.751837389809744, 47.226919719151084, 48.207091672079905, 56.95504740306309, 57.098023959568565, 60.848133495875764, 55.16436808449881, 58.715342249189106, 54.129176821027485, 58.436594418116975, 58.16202940259661, 63.65488610948835, 48.82502623966762, 44.391304288591655, 59.542553084237234, 55.999604088919504, 59.55845751081194, 56.71216269901821, 57.060010365077424, 59.61933762686593, 57.687311104365754, 53.12877171380179, 64.2376732145037, 58.06303146907261, 58.57243864876883, 59.93691199166434, 58.717913082667756, 52.54593597139631, 42.9941257749285, 43.028501987457275, 44.336979797908235, 45.41822372164045, 45.2484062739781, 44.57753338132586, 43.129799774714876, 52.49186161586216, 58.734324727739605, 60.56887149810791, 59.189702715192524, 58.6272668838501, 60.26672213418143, 61.51022039140974, 58.450032234191895, 59.59566511426653, 59.049668720790315, 56.810781955718994, 53.63671629769461, 57.60922724860055, 55.40613065447126, 60.09094660622733, 58.69170447758266, 60.15140288216727, 56.730631010872976, 58.33737414223807, 45.05334254673549, 51.11274494443621, 56.37575871603829, 60.321265493120464, 54.18438025883266, 70.11634949275425, 13.44923196520124, 0.42654543316790033, 0.8242270722985268, 1.000307832445417, 0.3828389570116997, 0.30262455557073864, 0.30734091677836006, 0.08572373938347612, 1.4755724327904838, 45.74279144832066, 55.40954221997942, 14.819659914289202, 52.708961554935996, 37.4107792036874, 0.4577589396919523, 0.053290104759590964, 0.021026670467108488, 0.029229266569018364, 0.02915698562615684, 0.06681743995951754, 0.01425101315336568, 0.01784506726211735, 0.027967069298028946, 0.07282539936048643, 0.07213654382420437, 0.06213189781244312, 0.033548342130546055, 0.05948685974414859, 0.07228991309446947, 0.01863188629171678, 0.020097337031204785, 0.021228017252204672, 0.04465647946510996, 0.012727852162372853, 0.015107722986223442, 0.05167420753943069, 0.042085798656834025, 0.014721522905996867, 0.025446074216493537, 0.12203878430383545, 0.17211185954511166, 0.07664561258362872, 0.08083255362829991, 0.24156565911003522, 0.17825306286769255, 0.10747543469603572, 0.08677036607904093, 0.12363138741680554, 0.08388720293130193, 0.08182259050330945, 0.10456560512206384, 0.13630239106714725, 0.1524214654096535, 0.1744927167892456, 0.11681958793529443, 0.16318628777350697, 0.1152083251093115, 0.21366767824760505, 0.07407282492411987, 0.20033257880381175, 0.1442052884293454, 0.23851056875927107, 0.1928184548658984, 0.1984853893518448, 0.11012305119740111, 0.17003866364913328, 0.1222469045647553, 0.20037938414939813, 0.2870049237140587, 0.26875971417341915, 27.10291814804077, 85.60523905072893, 53.81569147109985, 42.81205865315029, 66.97775786263603, 39.931120123182026, 0.4606787030185972, 0.8538011025105203, 1.4217152084623064, 5.302823041166578, 6.691210346562522, 28.08243523325239, 6.651727208069392, 0.10649637651762792, 1.4315928327185767, 58.64645780835833, 78.0885319028582, 78.85289628165108, 80.3172082901001, 74.60881846291679, 74.81108052389962, 72.46285343170166, 78.64647224971226, 71.06889888218471, 71.81912367684501, 71.6505047934396, 70.01050758361816, 64.57848235539028, 64.90479060581752, 65.4496683393206, 72.48834637233189, 68.11608818599156, 69.04595865522111, 64.21600873129708, 63.34100123814174, 64.95066956111363, 71.6821538380214, 66.01635646820068, 59.33258547101702, 48.55767692838396, 50.173390184129985, 48.77580867494856, 47.73750114440918, 49.827776363917756, 48.2701222555978, 50.44058663504464, 52.53723335266113, 51.004453795296804, 52.762889998299734, 60.81402478899275, 60.42828859601702, 64.24293994903564, 59.28150231497628, 61.76092529296875, 56.541417666843955, 61.86548178536551, 60.15625967298235, 66.25982829502651, 50.39639261790684, 47.875641754695344, 60.34261730739048, 59.32400444575718, 62.02181625366211, 58.67629337310791, 59.478754724775044, 62.191574641636436, 60.57675770350865, 57.01719903945923, 63.28406769888741, 60.42821911403111, 61.4702821459089, 62.737300055367605, 60.19460678100586, 53.86248411451067, 44.15199443272182, 45.89518976211548, 46.27156673158918, 48.60111011777605, 47.63279526574271, 46.45647914069039, 45.807857854025706, 54.12056105477469, 60.98852184840611, 64.16087477547782, 61.97296346936907, 61.34458923339844, 61.27148723602295, 62.73802266802107, 61.22378090449742, 63.13860716138567, 62.07813140324184, 58.06252077647618, 54.84187092099871, 59.70241028921944, 58.45331178392683, 62.8137788772583, 60.622692244393484, 64.81456129891532, 58.12024988446917, 59.577669279915945, 46.88756275177002, 55.53487035206386, 57.334460735321045, 63.965540068490164, 58.27401351928711, 74.68794454847063, 13.236792530332293, 0.24145579071981565, 0.8759516882044929, 1.2643593549728394, 9.701340641294207, 2.1214300734656195, 1.0110223889350891, 0.6873530969023705, 1.6780012505395072, 58.01082270486014, 46.48381682804653, 28.81383040973118, 65.50923524584088, 45.88552481787545, 0.5791903265884945, 0.2341598022196974, 0.14332089945673943, 0.18497241873826298, 0.20659872756472655, 0.18154006291713032, 0.1146930456161499, 0.1358737333544663, 0.10560625392411437, 0.20057379800294126, 0.08994033240846225, 0.1206124901239361, 0.04907016994963799, 0.17111975992364542, 0.1525424617741789, 0.1394307767706258, 0.09431357881320374, 0.14083598208214554, 0.1336994764528104, 0.10218708203839404, 0.10407849840287652, 0.17356860637664795, 0.11039830571306603, 0.12095557100006513, 0.11007490913782801], [0.0703608448218022, 0.019948159411017383, 0.030024278908967972, 0.014772092424599188, 0.01992827663863344, 0.05087670158328755, 0.04295688155772431, 0.07241693484996047, 0.07213646240000214, 0.10108550757701908, 0.035098852323634286, 0.05109705583059362, 0.027763485043708767, 0.03402131496529494, 0.02760897413827479, 0.038900229414658885, 0.03818583042759981, 0.036171575476016314, 0.06080430333635636, 0.03308986280379551, 0.04459463439083525, 0.031543542564447434, 0.027465587814471552, 0.0582714406773448, 0.07313221932521888, 0.06653242811028447, 0.08616153696285826, 0.04251884988376072, 0.05811750143766403, 0.04882436046110732, 0.0071840938346992645, 0.5258955806493759, 41.20629521778652, 53.16413457053048, 36.929564339774, 32.96064908163888, 57.81452567236764, 5.2312105638640265, 0.16895608816828045, 0.4828677752188274, 1.187183759042195, 0.8633387535810471, 7.5448386669158936, 2.0593424907752444, 0.35567999577948023, 0.20144864677318505, 5.948759717600686, 57.725317750658306, 68.13108934674943, 72.67754581996373, 70.9022741317749, 74.6867425101144, 74.36775766100202, 66.65768909454346, 71.76530293055943, 65.36296871730259, 62.751001902988975, 59.994158199855256, 62.235077313014436, 64.7197322845459, 66.5849414552961, 62.45527267456055, 65.95002896445138, 64.04743153708321, 61.57218442644392, 62.44995035443987, 63.51747158595494, 62.73555605752127, 61.98537990025112, 50.82824747903006, 45.516367026737754, 43.482375689915244, 43.492992537362234, 45.42398725237165, 43.546854972839355, 43.54997818810599, 44.031873975481304, 42.939283643450054, 45.43789407185146, 52.919926234654014, 59.77153096880232, 58.870189802987234, 60.57872404370989, 60.16911384037563, 59.90094116755894, 56.967717443193706, 58.3943841116769, 59.32013429914202, 67.19841180528913, 47.49727412632534, 44.4200941494533, 65.7409507206508, 57.47532851355416, 63.32201875959124, 57.75358649662563, 60.41159207480294, 55.594614437648225, 51.44346182686942, 63.40079743521554, 60.08217103140694, 59.931714739118306, 62.16306618281773, 58.80871214185442, 55.50896399361746, 41.84797177995954, 43.52783080509731, 42.33592292240688, 43.426946435655864, 41.9808942931039, 43.189321517944336, 43.88129261561802, 43.978897435324534, 48.0316288130624, 56.91299343109131, 59.415810993739534, 60.03362396785191, 56.28305237633841, 59.189410890851704, 58.89675971439907, 61.25716699872698, 57.48368719645909, 55.85476541519165, 52.10374913896833, 55.962834221976145, 52.71204308101109, 57.90377875736782, 54.805021149771555, 59.96159894125802, 58.00084509168352, 58.759671756199424, 51.739416871752056, 54.13512447902134, 49.9352719443185, 58.94891289302281, 55.31670733860561, 65.28380094255719, 22.79172420501709, 0.19446806849113532, 0.20221076373543057, 0.174373131777559, 1.159160045640809, 0.2709716840514115, 0.025315362926838652, 0.04166793982897486, 0.042687730464552126, 24.653638192585536, 50.42468220846993, 11.35912697655814, 35.7913556098938, 51.08587973458426, 5.959083437919617, 0.32141598580139025, 0.10319118494434015, 0.11091815174690314, 0.023821598617359996, 0.07844027663980212, 0.044549545738846064, 0.052987627418977876, 0.04944749988083329, 0.01214225693339748, 0.08630354755691119, 0.01665291007209037, 0.07942778257919209, 0.09304403300796237, 0.04315665244523968, 0.07744687423110008, 0.05036145940955196, 0.10195921640843153, 0.08830068646264927, 0.06585356739482709, 0.017053361084046106, 0.07593923727316515, 0.013367069469365691, 0.00628593229755227, 0.05108148684459073, 0.04775001221735563, 0.026210126699879766, 0.04849846348432558, 0.03930193232372403, 0.04924687064651932, 0.028255663812160492, 0.054169004383896074, 0.03794647041442139, 0.034176804657493315, 0.005375118626813803, 0.10241240316203662, 0.02317021008847015, 0.045606204574661593, 0.03046833597389715, 0.008159825495178146, 0.02816341528003769, 0.020300811023584435, 0.03197658022067376, 0.01076150856845613, 0.043649187444576194, 0.04184164818642395, 0.058468534744211605, 0.03726153681054711, 0.0662329498944538, 0.02006907095866544, 0.056161461398005486, 0.08194773950214897, 0.025065120908298662, 0.051426399765270095, 0.029502546547779014, 0.04723389134077089, 0.06414110785616295, 1.5233832044260842, 57.001023633139475, 53.934613364083425, 27.1552346093314, 53.97379078183855, 64.39066559927804, 3.902394073350089, 0.13898670274232114, 0.17922309653035232, 0.7820063978433609, 0.5934008583426476, 1.9502557728971754, 2.3043969869613647, 0.8376640198486192, 0.1970226035586425, 8.651623300143651, 65.51885155269078, 71.10163879394531, 75.13219152178083, 74.65136228288922, 77.49662181309291, 72.08450317382812, 70.20026288713727, 74.87322521209717, 68.88496194566999, 64.9838958467756, 64.88025651659284, 65.11342416490827, 66.18021583557129, 65.93657030378068, 64.5892173222133, 69.23291383470807, 64.93964971814836, 63.16226577758789, 61.955321993146626, 64.52774660927909, 64.50294154030937, 63.840027809143066, 53.876095635550364, 47.39221041543143, 46.55284023284912, 46.14054455075945, 47.551605565207346, 45.35394593647548, 46.26975672585623, 46.382772650037495, 45.053662163870676, 47.42623226983206, 53.347733770098, 62.18517535073416, 58.59774398803711, 61.958073479788645, 61.25291470118931, 61.57394232068743, 57.91428790773664, 61.460902077811106, 61.43207400185721, 68.47597013201032, 48.591851643153596, 45.392105443137034, 66.09089674268449, 58.184072562626426, 63.454270771571565, 60.80125399998256, 61.94667148590088, 59.093032428196494, 53.79781028202602, 66.0739917755127, 63.22650187356131, 60.27259336199079, 64.27212933131626, 58.592456408909385, 58.23361669267927, 44.80520153045654, 45.312597206660676, 44.22439466203962, 45.6034140586853, 43.28216682161604, 44.04929310934884, 44.90501935141427, 47.61699158804757, 52.52448688234602, 60.057623045785085, 61.22082792009626, 62.31005532400948, 57.647463185446604, 59.23197555541992, 60.269668170383994, 62.35699735369001, 59.00205271584647, 57.24519027982439, 56.48101697649275, 58.00246054785592, 55.14584766115461, 58.608270508902415, 56.358072076525005, 60.806159428187776, 60.24257714407784, 61.57324055262974, 55.54079021726336, 55.34104340417044, 55.45472635541643, 59.647651536124094, 59.61730180467878, 68.71472413199288, 26.43665885925293, 0.1623326228665454, 0.36597171638693127, 0.7917293161153793, 1.2650820761919022, 0.5757767526166779, 0.07487324518816811, 0.1525721408958946, 0.20497044708047593, 24.66904582296099, 66.86126436505998, 18.08579788889204, 25.86576533317566, 64.78284972054618, 8.748549801962715, 0.3345003936971937, 0.04454393425424184, 0.030240059830248356, 0.024412212460967045, 0.04165304598531552, 0.04285749653354287, 0.0797345754025238, 0.01813220971130899, 0.04827037054513182, 0.03358363612954106, 0.017870809184387326, 0.015009964749749218, 0.045695611741393805, 0.040378953995449204, 0.08730670729918139, 0.01227714799876724, 0.025807451789400408, 0.03700119988726718, 0.04102604230865836, 0.023731964141396538, 0.05214818799868226, 0.029914240884993757, 0.06366125467632498, 0.028053066826292446, 0.028095772124028633, 0.2346690020390919, 0.11898359895816871, 0.11507035179861955, 0.13776662892528943, 0.15993128743554863, 0.1733474446726697, 0.13224429025181703, 0.1681297817932708, 0.08749653425599847, 0.17432131884353502, 0.0729259243234992, 0.16287995635398797, 0.11708037608436175, 0.14884694293141365, 0.1154048288507121, 0.08563474951578037, 0.08718422494296517, 0.18681879394820758, 0.18922012937920435, 0.1409065361533846, 0.20564607796924456, 0.10681230242231063, 0.07740731563951288, 0.12390352067138467, 0.21995768429977552, 0.11400108917483262, 0.12063123126115118, 0.15149590293211596, 0.14386223469461712, 0.10378786149833884, 0.1825314432914768, 1.6623470676796777, 70.33976881844657, 67.70997987474713, 52.4374155317034, 46.196717262268066, 75.0238343647548, 8.26891825880323, 0.5263509047882897, 1.3653180918523242, 4.051765143871307, 5.318724862166813, 20.503592082432338, 5.201011955738068, 1.5800152570009232, 0.22805548406073026, 7.51114250932421, 66.72813688005719, 72.12745693751744, 79.25878225054059, 75.7946675164359, 78.34298188345772, 75.8021159853254, 72.33760520390102, 78.74899291992188, 71.36460031781877, 69.11246681213379, 65.14558737618583, 66.78520938328334, 69.01080077035087, 70.47468199048723, 68.17925425938198, 70.36235741206578, 66.13414927891323, 64.46698461260114, 66.11550726209367, 67.98313440595354, 66.46136774335588, 68.04698835100446, 55.46406473432268, 50.88545894622803, 48.832908970969065, 48.67964908054897, 52.10517004558018, 47.60995306287493, 48.51933676855904, 49.291003704071045, 47.18166610172817, 50.75514548165457, 57.388236318315776, 64.44131796700614, 61.316845076424734, 63.113176754542756, 63.6666841506958, 67.46846743992397, 62.40369619641985, 62.97869437081473, 65.92366749899728, 71.2556734085083, 52.08765711103167, 46.49400288718087, 68.05529839651925, 60.206828662327354, 66.42716176169259, 62.020037514822825, 65.46094526563371, 59.788818086896626, 59.051614216395784, 66.32095159803117, 66.24759251730782, 63.05187974657331, 68.79881123134068, 62.50284004211426, 61.43489497048514, 46.64251715796334, 48.68037516730172, 47.6567074911935, 48.51769699369158, 45.584789412362234, 46.25442899976458, 47.784265995025635, 50.78653049468994, 54.30724178041731, 62.2092091696603, 63.45392336164202, 65.83329227992466, 58.993923323495046, 62.2774543762207, 61.0901392527989, 64.72373444693429, 61.76355866023472, 58.91517244066511, 57.56165293284825, 62.99482808794294, 57.26371417726789, 62.117715290614534, 59.54581873757498, 64.50330979483468, 60.49980640411377, 63.3281957081386, 56.9313679422651, 59.926149232046946, 56.64835044315883, 63.49639769962856, 62.25878456660679, 71.05769143785749, 25.84013863972255, 0.21209977380931377, 0.6756337657570839, 0.6856405830809048, 6.495006680488586, 1.5073455678565162, 0.10436107431139265, 0.37860820974622456, 0.22510593304676668, 38.00305754797799, 59.96744932447161, 19.589124032429286, 45.123505456107004, 67.83975832802909, 13.776697090693883, 1.0766905737774712, 0.28220559124435696, 0.16047373547085694, 0.14900950635118143, 0.3015680494053023, 0.16566056571900845, 0.19184744411281177, 0.21251817207251275, 0.14528212350394043, 0.2120446903364999, 0.10794068580227238, 0.1706319068159376, 0.20072516559490136, 0.19113488734832831, 0.3127799449222428, 0.10044342345957245, 0.21960084273346833, 0.15926063699381693, 0.18484110864145414, 0.15279020848018782, 0.206791879343135, 0.10019682347774506, 0.10014608941440072, 0.12768601413284028, 0.15286415522652014], [0.024348484452015588, 0.10051870013454131, 0.04641814975600157, 0.030732435373855487, 0.05810762196779251, 0.05828602918024574, 0.06849453425300972, 0.05050764638664467, 0.036520362831652164, 0.03516473128859486, 0.12418706688497748, 0.04139916193006294, 0.039239059268896065, 0.007429756590032152, 0.034199104710881195, 0.08366724223430667, 0.004292610575378473, 0.03161211531343205, 0.029769146349281073, 0.07783333385097128, 0.04804964649624058, 0.011183539538511207, 0.0288479061398123, 0.08478264523936169, 0.04652541596442461, 0.03386950971824782, 0.053307278480912955, 0.06314406849976097, 0.1812522690743208, 0.037136533696736605, 0.2448497957416943, 0.4220685948218618, 6.695155620574951, 60.522304671151296, 39.37672683170864, 22.45571279525757, 52.01430150440761, 37.68092169080462, 0.24132605482425007, 0.16387567935245378, 0.11339126939752273, 0.12105517994080271, 1.2540497481822968, 2.054434674126761, 0.36130841661776814, 0.32147344414676937, 0.38346896320581436, 10.591595087732587, 62.65712479182652, 71.23137555803571, 75.43172836303711, 75.47320216042655, 71.9454836164202, 75.31804888589042, 66.89852060590471, 68.21225820268903, 68.2031421661377, 68.77137279510498, 61.23038864135742, 65.74029758998326, 66.94555296216691, 70.36188493456159, 64.3283611025129, 61.06362492697579, 62.5618371963501, 67.35888739994594, 64.5390374319894, 61.13290541512625, 58.891604151044575, 48.31888123920986, 45.75230700629098, 44.44524662835257, 46.93232652119228, 46.43830960137503, 45.01125035967146, 43.03918831689017, 47.75264474323818, 46.947654247283936, 48.81890140260969, 56.60730743408203, 63.18587575639997, 61.62805489131382, 64.63315078190395, 60.234093393598286, 64.60821369716099, 58.92417730603899, 62.080716133117676, 56.53685964856829, 62.55279064178467, 34.83006886073521, 36.067848750523154, 68.57557255881173, 60.26315770830427, 65.08155277797154, 60.26886912754604, 64.37368420192173, 48.7615579196385, 65.73439162118095, 60.9205823625837, 61.80865246909005, 59.48646027701241, 58.12762539727347, 58.436010769435335, 47.317774363926475, 42.660000801086426, 44.40684740883963, 43.71272931780134, 44.242720535823274, 41.50265325818743, 45.698823247637065, 45.90088728496006, 42.94886173520769, 45.65271847588675, 54.92044462476458, 59.16072872706822, 61.66658265250069, 62.572460991995676, 61.06150572640555, 59.19642162322998, 61.190165519714355, 59.61830234527588, 56.88489491598946, 55.239026478358674, 58.3179817199707, 57.37296765191214, 56.884589195251465, 57.518869400024414, 58.8955785206386, 59.13517325265067, 56.863664695194785, 59.85297775268555, 49.42420761925833, 54.04464503696987, 62.85635049002511, 57.40858064379011, 48.38575070244925, 0.40645455409373554, 0.22549747489392757, 0.20312656887939998, 0.852180652320385, 1.0540698447397776, 0.08488599969340221, 0.24914163830024855, 0.07811206246593169, 17.111491952623638, 57.274039200374055, 15.500050101961408, 25.944934844970703, 51.65728569030762, 27.711418798991613, 0.17141443411154406, 0.04140428826212883, 0.04048198953803096, 0.022716483899525235, 0.052561164767082245, 0.01917882283617343, 0.028578181684549366, 0.017026575914184962, 0.0152599845480706, 0.01880348440525787, 0.019337352365255356, 0.02127403549716941, 0.026554820793015615, 0.044917790086141655, 0.05369165499827691, 0.04986657667905092, 0.03705973710332598, 0.09466904973877327, 0.04699409367250545, 0.02372512111573347, 0.0652833062091044, 0.032459992316684554, 0.050156755572451014, 0.05018667218142322, 0.04607680932219539, 0.023649157424058233, 0.021121290479121462, 0.006888262744593833, 0.05079234271709408, 0.019469561520963907, 0.00851073072824095, 0.00914535011231367, 0.034757810445236306, 0.020155903085001876, 0.017745461714054857, 0.06484793099973883, 0.06703476115529027, 0.017657778026270013, 0.020554852838228856, 0.05936722723501069, 0.02034421860506492, 0.05774567781814507, 0.08347396153424468, 0.01428598484822682, 0.04010679359946932, 0.05368197908891099, 0.026913843849407773, 0.01594200893305242, 0.036139721649565866, 0.040593025008482594, 0.007760730705090931, 0.02670033093142722, 0.05917527646358524, 0.026498770407800163, 0.11461052218718187, 0.037854254112711976, 0.17962366289326123, 0.10178883626524891, 11.447939719472613, 75.24533598763603, 33.64817680631365, 28.31820671898978, 75.7135750906808, 37.069056374686106, 0.24958379885980062, 0.23131864038961275, 0.21552961905087742, 0.5020025170275143, 1.7813468022005898, 0.3574378085987908, 0.7051904254726001, 0.3639640398323536, 0.2697119430771896, 13.03738444192069, 70.93470137459892, 73.08116667611259, 77.62280804770333, 73.78614480154855, 76.07824434552873, 75.90288570949009, 68.9787904194423, 69.42501762935093, 71.75361606052944, 70.38943454197475, 64.50840282440186, 65.55078547341483, 69.61986596243722, 72.64055361066545, 66.31067521231515, 62.75446905408587, 64.88386263166154, 66.8601040158953, 65.08240045819963, 61.42149884360177, 61.69050530024937, 50.24924714224679, 48.356856618608745, 46.12609577178955, 48.12069082260132, 47.208347184317454, 48.133079460689, 46.069930008479524, 48.38610506057739, 48.43625715800694, 50.375120707920615, 57.87322405406407, 64.64822142464774, 62.225773675101145, 64.83260577065604, 62.11832673209054, 66.30013479505266, 58.8580721446446, 63.20323930467878, 57.742434637887136, 65.26371370043073, 38.07954331806728, 38.21728440693447, 69.13176890781948, 59.37719290597098, 64.19622720990861, 59.79602336883545, 66.97836235591343, 50.10045494352068, 65.46751131330217, 61.858825411115376, 61.8241400037493, 60.117426191057476, 60.939384187970845, 60.96084022521973, 51.70873710087368, 45.045067242213655, 46.947199140276226, 45.9871734891619, 46.020347663334434, 44.504497391836985, 47.840605463300435, 46.43419279370989, 44.74163246154785, 46.52036435263497, 57.43359068461827, 61.33939892905099, 64.34306349073137, 63.5275673185076, 61.70818846566336, 59.876490456717356, 63.326201575142996, 59.18356050763811, 59.560708727155415, 56.42268337522234, 59.9181935446603, 58.90991265433175, 60.113292012895855, 59.07082598549979, 63.31413950238909, 61.582460812159944, 60.58968135288784, 60.488439151218955, 53.74954114641462, 54.78716427939278, 67.3077972957066, 58.60243402208601, 52.570018427712576, 0.496223515697888, 0.27814059651323725, 0.5908920158232961, 1.1815485528537204, 0.8306682695235524, 0.23185821143644197, 0.21331074168639524, 0.25197962458644596, 20.10440591403416, 73.24636704581124, 30.700295857020787, 12.539414865630013, 56.038955211639404, 35.912973403930664, 0.2356106729379722, 0.021960790967568755, 0.047277283655213456, 0.03655007927279387, 0.06819892368678536, 0.056506089333977015, 0.016040618730975047, 0.01503586782408612, 0.08629078431321041, 0.008106808161496051, 0.045726837922952006, 0.015200175078851836, 0.020440575666725636, 0.03329868195578456, 0.03686043779764857, 0.01938510257085519, 0.06497008087379591, 0.05790625313030822, 0.027191145844491463, 0.04437020554074219, 0.03456669766455889, 0.0316333738155663, 0.044363542326859066, 0.01822759986056813, 0.04683195772979941, 0.03073991961511118, 0.10882039288324968, 0.1348511946520635, 0.2104277549577611, 0.1341016170169626, 0.18370986862906388, 0.13787998498550483, 0.145455448489104, 0.16929060593247414, 0.08917881255703312, 0.1516090418611254, 0.1456260864755937, 0.1179391300039632, 0.17516491429081985, 0.14770624414086342, 0.16301358704056057, 0.24957060813903809, 0.18237443028816155, 0.11968525845025267, 0.20367365809423582, 0.15971000359526702, 0.15983831456729344, 0.11021815466561488, 0.10319368195320879, 0.12343645787664823, 0.2350361980497837, 0.13865781681878225, 0.16737616008945874, 0.09890194796025753, 0.31004262609141214, 0.18477750276880606, 0.4629525552902903, 0.4645550921559334, 15.46056696346828, 85.96500982557023, 54.62394067219326, 36.56269598007202, 64.97972692762102, 54.33838013240269, 0.4568086106862341, 1.0210914143494196, 0.5510723239609173, 1.1722373153482164, 2.542108540024076, 10.673972930227007, 0.6780732348561287, 0.584707576249327, 0.5033891169088227, 12.689052139009748, 74.00239358629499, 76.25203963688442, 77.51666041782924, 78.43082101004464, 74.50414385114397, 78.42713846479143, 72.76660782950265, 73.06784003121513, 74.29714311872209, 76.07697977338518, 66.29011549268449, 70.51488426753453, 72.12750557490757, 74.55842317853654, 67.236022404262, 64.46062006269182, 68.16827610560826, 71.47773783547538, 69.78145326886857, 64.39365332467216, 65.39964130946568, 52.70240592956543, 52.642015661512104, 48.468034744262695, 51.652995177677695, 49.60406173978533, 50.843516145433696, 47.738637174878804, 52.110978739602224, 53.247089113507954, 54.61791658401489, 61.95230647495815, 70.1449830191476, 66.36441952841622, 69.32014151981899, 65.2011729649135, 69.9172419139317, 61.95246628352574, 66.17696407863072, 60.0394743510655, 67.93209293910435, 38.0564683505467, 39.3363994870867, 70.38302830287388, 64.70756598881313, 67.71395424434117, 63.00622313363211, 69.2204487664359, 53.84244550977434, 65.25014386858258, 62.876938002450125, 63.79856095995222, 64.82761001586914, 63.82229600633894, 62.115693364824565, 52.99251059123448, 47.49535642351423, 48.30731248855591, 47.878532205309185, 49.68124580383301, 47.420729296548025, 52.267254148210796, 50.41798414502825, 46.7304744039263, 51.111011368887766, 58.98166670118059, 64.88439069475446, 68.91689586639404, 67.07944474901471, 62.725286620003835, 62.652003969464985, 64.54546451568604, 62.61664458683559, 61.6207731791905, 60.51102079663958, 62.56110763549805, 62.30284309387207, 63.05781350816999, 62.28689002990723, 62.46223476954869, 63.287131854466026, 62.060719217572895, 63.91318539210728, 55.704514094761436, 59.75174249921526, 68.92681789398193, 62.73452077593122, 52.39272124426705, 0.885155662894249, 0.42878299738679615, 0.4670625776052475, 5.084491968154907, 2.2627041041851044, 0.2883796085204397, 0.3678296538335936, 0.27430312814457075, 27.23531433514186, 72.33044855935233, 24.56069908823286, 37.02039813995361, 63.906869479588096, 46.24552835736956, 0.35739839928490774, 0.25458430339183125, 0.07385829250727381, 0.14562566578388214, 0.2030457825000797, 0.1261996560330902, 0.1167025270738772, 0.09079466906509229, 0.1922636710639511, 0.17011064264391149, 0.07785159322832312, 0.07875481833304677, 0.17106333295149462, 0.14008089474269322, 0.2751256211527756, 0.1130349842299308, 0.18947916690792355, 0.1925352479198149, 0.11481009290686675, 0.12970017748219625, 0.11654149714325156, 0.13354017000113214, 0.17350106500089169, 0.12582442616777761, 0.10846249958766357, 0.09174331530396428], [0.048858372028917074, 0.02548133598507515, 0.03743429521897009, 0.041190319029348235, 0.007193843534748469, 0.03192710144711392, 0.015760351537859867, 0.045333226543984244, 0.03441565237673266, 0.01845253082657499, 0.04874247146238174, 0.007666036054225904, 0.06278080799217735, 0.030933129068996226, 0.035272472471530945, 0.06826022254037005, 0.037218249669032435, 0.04262355122981327, 0.032865929284266064, 0.008060934105222779, 0.04484566520633442, 0.005430168172876749, 0.06593615189194679, 0.03837380498381598, 0.03308370170582618, 0.057113432458468845, 0.0740787892469338, 0.056633043235966136, 0.029422679583409002, 0.12436734006873199, 0.030773496920508996, 0.07259091122874192, 0.10321363766810723, 33.14318173272269, 65.31393527984619, 38.244927815028596, 19.50469126020159, 68.1471813746861, 17.87189064707075, 0.05152387132069894, 0.29227287960903986, 0.7183624186686107, 0.44064055968608173, 1.1443364982094084, 1.3516480539526259, 0.08659208100289106, 0.12086107821336814, 0.06230225081422499, 12.862638115882874, 68.70566368103027, 69.91182926722935, 75.05652563912528, 79.41506808144706, 72.12130778176444, 72.60942568097795, 74.0015459060669, 66.06277738298688, 67.55769620622907, 66.63831751687187, 69.79191725594657, 69.99809115273612, 64.14794417790004, 60.88351372310093, 64.04934229169572, 65.1733454295567, 64.91294084276471, 65.10123007638114, 61.90844249725342, 51.49863747188023, 45.71173300061907, 45.77178628104073, 45.67060661315918, 46.97049992425101, 44.06102166857038, 46.65625722067696, 44.20517247063773, 46.882362025124685, 45.47787400654384, 49.54488393238613, 59.022459575108115, 63.33237157549177, 61.17337172372, 62.16902773720877, 60.246704374040874, 63.39793477739607, 60.1548422404698, 65.10228620256696, 54.42480182647705, 60.83526543208531, 36.09875781195504, 34.274907793317524, 71.73364693777901, 57.19102559770857, 65.8297278540475, 59.28987489427839, 55.85106202534267, 60.82195963178362, 66.54641369410923, 59.45673588344029, 64.40050424848283, 58.50062901633126, 62.24812602996826, 51.79192788260323, 43.71951770782471, 44.237217562539236, 45.339316504342214, 43.33980907712664, 44.96098361696516, 45.76302807671683, 53.855369159153526, 50.614975997379844, 49.47981752668108, 44.851698875427246, 51.35121406827654, 54.69854695456368, 62.49641295841762, 61.71374702453613, 61.818741253444124, 61.71849264417376, 62.334540775844026, 63.01155240195138, 59.850490297589985, 58.571868896484375, 60.198650632585796, 58.96110003335135, 61.371555192129954, 57.6659905569894, 61.200087547302246, 62.67116710117885, 60.28138978140694, 57.19825867244175, 59.27809074946812, 60.418262345450266, 53.7960558618818, 68.90417371477399, 7.333687254360743, 0.6322791778615543, 2.2105322522776465, 0.9720099908964974, 1.6842637487820216, 0.6311372848493713, 0.3293943633990628, 0.758856791470732, 12.778016873768397, 55.70305149895804, 31.017449855804443, 40.25224849155971, 45.747623920440674, 44.32751635142735, 6.992000469139644, 0.585198347057615, 0.1019421648234129, 0.15036692922668798, 0.07120100688189268, 0.03968838855092015, 0.03777235493596111, 0.05195148069677608, 0.0068036600298780415, 0.06735557251210723, 0.008671283988015992, 0.05435458371149642, 0.018002465334055678, 0.04569878389260598, 0.0075786848486002, 0.04093481327540108, 0.032022835952895026, 0.032328583832298, 0.0469384402302759, 0.03253898397088051, 0.02269126444921962, 0.01836391076046441, 0.06689260806888342, 0.009492230784547116, 0.032870997940855365, 0.017028828650446873, 0.06987223175487348, 0.06001390503453357, 0.09215196301894528, 0.018286435632035136, 0.048191036230751445, 0.05638811245028462, 0.04402089910581708, 0.023968101113236377, 0.00898584264463612, 0.003460463074069204, 0.057101137403930934, 0.07030189369938203, 0.05961910621928317, 0.062493719825787206, 0.023391709363620197, 0.04190103017858096, 0.014081901022499161, 0.058847910458488126, 0.08279451049332108, 0.050803379089172394, 0.023437712341547012, 0.02361586001435561, 0.017121708220137016, 0.0296669691534979, 0.07147446327975818, 0.050097071632210693, 0.08122395298310689, 0.12901265865990094, 0.054161594781492434, 0.009654420161885875, 0.037762265120233805, 0.022190888977742622, 0.03421295700328691, 0.3187943979033402, 43.640839781079976, 70.89238684517997, 22.71920759337289, 36.3707137789045, 85.74149322509766, 15.595839704786028, 0.1358269415795803, 0.28624127326267107, 0.3760141703699316, 0.19833284110895225, 0.4002026952803135, 0.900238356419972, 0.22878382354974747, 0.27659730932542254, 0.21520192734897137, 17.618496792657034, 77.98173114231655, 70.25179072788784, 79.68712479727608, 76.80257320404053, 73.97575419289726, 75.70001220703125, 75.92083985464913, 68.4487054007394, 71.7564856665475, 70.03089359828404, 71.00706686292375, 69.79141698564801, 64.36690970829555, 62.326418331691194, 67.10380513327462, 66.33387524741036, 65.89706284659249, 68.12929671151298, 64.80431270599365, 55.21031999588013, 47.94632577896118, 50.17439419882638, 47.85668706893921, 49.862934248788015, 46.049377237047466, 48.134681020464214, 45.279325757707866, 50.43912403924124, 46.04468372889927, 51.43964726584298, 61.947602544512065, 64.79717690604073, 61.76444802965437, 63.82583958762032, 59.79364708491734, 64.58666733333042, 60.25484071459089, 68.0799228123256, 56.676924909864155, 65.05658095223563, 35.25651454925537, 34.53291177749634, 72.41929517473493, 59.48397282191685, 66.78505652291435, 62.548593929835725, 60.33856650761196, 63.69476876940046, 70.35472134181431, 61.05177130017962, 65.1062536239624, 60.21959250313895, 64.73016153063092, 55.01639229910714, 46.467502457754954, 44.991044998168945, 47.74474811553955, 45.51313264029366, 45.0723215511867, 46.17796060017177, 51.76250226157052, 52.20873989377703, 51.47825493131365, 47.461042744772776, 52.65786797659737, 56.97578082765852, 63.0490448815482, 62.14706448146275, 61.28734997340611, 61.39252485547747, 62.863604409354075, 64.94189398629325, 61.055141176496235, 60.323454175676616, 61.82845483507429, 60.25840514046805, 62.727009773254395, 59.65132018498012, 62.325674874441965, 64.43513407026018, 63.05771623338972, 57.11641584123884, 59.776443345206125, 64.18429020472935, 54.73123128073556, 71.1998793738229, 10.498407585280281, 0.8885425297277314, 2.016223055975778, 1.596441341297967, 1.4935244066374642, 0.7032295678343091, 0.2026674992271832, 0.6016653605869838, 18.826468910489762, 54.99138920647757, 41.32059308460781, 28.469892842429026, 42.11731175013951, 54.59791966847011, 10.03823012965066, 0.6587169106517519, 0.11700854636728764, 0.1049713147804141, 0.11215132128979478, 0.01248488064655768, 0.07868739909359387, 0.05392949848568865, 0.11345456992941243, 0.018278820772788355, 0.03157988829272134, 0.04054232147921409, 0.0665007269542132, 0.0475513202005199, 0.026919928612187505, 0.015340604686311312, 0.004066419654658863, 0.04406374519956963, 0.02332834097822862, 0.028713953149105822, 0.041097135815237246, 0.030775440923337425, 0.03785600812573518, 0.02174171745511038, 0.06417602526822261, 0.029408148755984645, 0.06681570969522, 0.14808771652834757, 0.17553831211158208, 0.1373958909618003, 0.15547472371586732, 0.20832266791590623, 0.16146211672042096, 0.14378604878272327, 0.12181418921266284, 0.07437637435006243, 0.10844198747404984, 0.15832101527069295, 0.1154286182884659, 0.14137701876461506, 0.14674313153539384, 0.15323904582432338, 0.16121800696211203, 0.1691408668245588, 0.12295658434075968, 0.083135732183499, 0.07871177207146372, 0.1155771224626473, 0.09395516304565327, 0.2061386943927833, 0.13351667911878654, 0.17352750072521822, 0.13913986166673048, 0.28249266584004673, 0.28743508777448107, 0.08968819558088269, 0.434406614197152, 0.20103045207049164, 0.16830894217959472, 0.3014023782951491, 54.48608146395002, 81.11440985543388, 56.75573137828282, 31.68280587877546, 83.68852983202252, 28.678519453321183, 0.20327929354139737, 0.40120936983398026, 1.801004015973636, 2.6575380946908678, 2.5560140567166463, 5.949814540999276, 0.1680320863212858, 0.34428991696664263, 0.28342182455318315, 18.338925974709646, 78.43851266588483, 71.86805289132255, 77.67497512272426, 82.66977105821881, 74.23543616703579, 76.71925040653774, 79.90725762503487, 73.31996931348527, 74.13286685943604, 71.6276660646711, 73.65289919716972, 71.89178098951066, 65.83682891300747, 61.60093607221331, 68.77090726579938, 68.32369341169084, 69.16063867296491, 71.55066612788609, 67.54011031559536, 57.08339105333601, 50.34624399457659, 50.61651849746704, 50.28422089985439, 52.96542303902762, 49.99904251098633, 52.27700594493321, 48.2372989654541, 52.79836055210659, 49.26368338721139, 53.42781523295811, 63.173167501177105, 67.51615292685372, 63.53752408708845, 65.98731299809047, 63.748520033700125, 66.76011943817139, 63.039616176060264, 71.88200487409318, 58.37080887385777, 69.07751042502267, 41.76592745099749, 36.6393380846296, 75.69901861463273, 60.705313273838584, 69.69257886069161, 64.6128203528268, 63.80368178231375, 64.28983334132603, 71.8882235118321, 64.75567531585693, 70.26266465868268, 63.500594411577495, 68.19657611846924, 58.62927491324288, 49.002313000815256, 47.82359627314976, 50.22814198902675, 47.42572157723563, 49.379492487226216, 50.354884079524446, 55.865281513759065, 55.48508998325893, 57.37958928516933, 50.31175313677107, 55.5420617376055, 58.38135623931885, 67.91581330980573, 65.59798458644322, 63.30501651763916, 63.44889286586216, 65.92407049451555, 67.66660921914237, 63.29770006452288, 63.87048871176583, 66.58137008122036, 62.75105054037911, 65.97565392085484, 62.21653951917376, 65.9208882195609, 65.92083958217076, 65.54649148668561, 60.46867847442627, 64.30792645045689, 64.37134265899658, 59.35385390690395, 72.63832323891776, 10.478095395224434, 0.7287707658750671, 4.092533699103764, 2.2005125156470706, 3.4180705419608524, 1.385372547166688, 0.4118165006594998, 0.9812015891075134, 22.098290511540004, 69.7861988885062, 38.618831225803916, 45.835143429892405, 56.47012220110212, 63.60114874158587, 14.206794926098414, 0.8948184358222144, 0.23342093186719076, 0.2284038167979036, 0.1898682795997177, 0.21034949272871017, 0.14644051848777703, 0.22432670343135083, 0.27144503008042065, 0.18847071459250792, 0.21049111655780248, 0.17980221259806836, 0.1703232955187559, 0.12589056976139545, 0.11223185661115817, 0.12383772991597652, 0.09089076997978346, 0.19740373667861733, 0.1742213706352881, 0.08752156541283641, 0.11935109352426869, 0.09183646459132433, 0.14076831857008593, 0.1812263626073088, 0.12154048175684043, 0.08452375698834658, 0.15613919948892935], [0.06300577627761023, 0.0065243491470547655, 0.03253603573622448, 0.021027418551966548, 0.05676005820610693, 0.05480783831860338, 0.061201470238821845, 0.023397448073540415, 0.036379739841712375, 0.011676061815316123, 0.0033982534992641634, 0.02033691756826426, 0.02563547539258642, 0.05336801415043218, 0.009337019291706383, 0.027460816016952907, 0.018667494113157903, 0.04122114487524543, 0.05829516904694693, 0.05468799885628479, 0.07235629417534385, 0.060871566512754986, 0.03508116291569812, 0.060500068590044975, 0.05315696940358196, 0.043819652404636145, 0.03012516688821571, 0.019538015526320254, 0.02562329908167677, 0.07203331829181739, 0.0451551789550909, 0.014064188714006116, 0.2468698759164129, 3.48333323427609, 57.50287464686802, 54.060146468026296, 28.09101104736328, 24.283585820879253, 71.70219244275773, 10.59928240094866, 0.15452339047832148, 0.21883356890508107, 1.6404118218592234, 0.23088052389877184, 0.5064914875796863, 0.21209948882460594, 0.13018319942057133, 0.08137180576367037, 0.14506785571575165, 11.496232305254255, 71.57821573529924, 70.34216594696045, 68.67461218152727, 80.7943480355399, 73.94400092533657, 72.259535244533, 74.58078248160226, 68.86726488385881, 68.7525987625122, 64.87915175301688, 65.53576346806118, 68.10848685673305, 65.41863073621477, 65.8385729108538, 67.6211610521589, 64.66937174115861, 59.925093105861116, 50.28635399682181, 45.4626088142395, 52.8998042515346, 51.97262968335833, 50.81149884632656, 49.50397293908255, 48.02955477578299, 47.13423074994768, 46.734070096697124, 47.77415289197649, 46.37465367998396, 49.54385559899466, 57.676551818847656, 62.2231958934239, 61.245285579136436, 64.20635768345424, 63.464706965855186, 63.99279090336391, 61.2364752633231, 66.24756472451347, 55.48808118275234, 54.76844235828945, 28.17812235014779, 37.47928844179426, 72.58951909201485, 57.28271402631487, 63.070445333208355, 57.73135573523385, 65.29459844316754, 61.680381774902344, 62.73711245400565, 60.36477511269705, 61.746257645743235, 59.58959238869803, 53.38560840061733, 42.67440094266619, 44.295759609767366, 45.86446482794625, 45.89335543768746, 46.052420548030305, 46.00379705429077, 53.11647687639509, 60.56452192578997, 58.490720885140554, 57.289999212537495, 48.77921329225813, 48.0401542527335, 51.86330325262887, 59.90889685494559, 62.164261272975374, 64.85059465680803, 60.454594475882395, 64.21573080335344, 62.56886877332415, 62.82272120884487, 60.03805691855294, 64.69992991856166, 60.82771274021694, 63.80867753710066, 62.00067983354841, 66.21552658081055, 58.02793959208897, 62.21626853942871, 63.335505213056294, 57.574566159929546, 56.30328205653599, 82.92631244659424, 16.521518673215592, 0.18397220383797372, 0.1217619962990284, 0.13034469075500965, 0.0607052372236337, 0.19349899834820203, 0.3406513136412416, 1.16013083926269, 13.082677142960684, 55.267764227730886, 50.35700675419399, 87.51335334777832, 57.73435388292585, 38.59540884835379, 41.20982142857143, 0.1561848106128829, 0.07061314449778625, 0.06480881345591374, 0.0481135441389467, 0.11013713079903807, 0.06937266713274376, 0.021490401654903377, 0.05718462435262544, 0.06103299677904163, 0.040099760584001026, 0.03337455574156983, 0.00840681224196617, 0.030632592338536466, 0.07551551251006977, 0.034680131756301434, 0.042393592319318225, 0.04465956001409462, 0.017350177746266127, 0.04110055223905614, 0.024500233719923666, 0.017810012446716428, 0.03312928229570389, 0.019357306383816258, 0.08358648978173733, 0.07099277127001967, 0.11053997025425945, 0.04559223693130272, 0.03476163399006639, 0.015016288696123021, 0.059630234193589, 0.043650089896151, 0.0658636979226555, 0.040841348469257355, 0.05793636651443584, 0.006659442924761346, 0.03871295374951192, 0.03247620930363025, 0.04863928664209587, 0.004118291112328214, 0.04530271960954581, 0.023663533884765844, 0.016755801425980668, 0.10925891649510179, 0.011431170045398176, 0.03679460972281439, 0.028706496049250876, 0.06622384395450354, 0.04529278924954789, 0.004195658099238894, 0.03466195719582694, 0.035957250012350936, 0.02010175768685128, 0.04110963103760566, 0.04410069143133504, 0.007829764857888222, 0.0034029383594835444, 0.16030925858233655, 0.04351997741365007, 0.09654937205570084, 0.1689103413373232, 6.7067747456686835, 71.62533841814313, 49.0052764075143, 15.454619305474417, 52.582820483616416, 80.49868828909737, 8.549859115055629, 0.3351976562823568, 0.41267199761101175, 0.4392990959542138, 0.048089887015521526, 0.5383002321634973, 0.2741959196116243, 0.22833080642989703, 0.25980685172336443, 0.10706351644226483, 17.145527703421457, 80.64358602251325, 69.91761016845703, 73.97483008248466, 76.15604332515171, 72.69525677817208, 72.74254621778215, 79.0699441092355, 69.86935492924282, 70.16445881979806, 66.83362443106515, 69.70031915392194, 68.86975928715297, 65.90277426583427, 67.18318830217633, 71.66100352151054, 66.93574905395508, 63.72707094464983, 54.74571132659912, 47.92802422387259, 52.17814350128174, 51.849128927503315, 51.756829057421, 51.23321281160627, 48.86630201339722, 50.21159485408238, 48.881150313786094, 49.63215330668858, 49.566465037209646, 51.6884309904916, 59.80740451812744, 65.56259741101945, 63.514984130859375, 65.54240594591413, 64.64140524183, 64.48939950125558, 62.492042541503906, 64.81003802163261, 55.66690696988787, 57.240931034088135, 32.147668157305034, 37.305798871176584, 75.29732240949357, 59.11911596570696, 66.30497768947056, 57.12803670338222, 64.92123699188232, 63.324339457920615, 64.86196885790143, 62.37352016993931, 65.52814824240548, 61.195953369140625, 57.963338715689524, 46.21372645241873, 46.58364507130214, 46.96158538545881, 47.35217489515032, 47.4172169821603, 49.37898874282837, 53.364020347595215, 62.95979527064732, 59.26506287711007, 56.993776662009104, 48.605091435568674, 48.87056473323277, 54.292900698525564, 61.414807728358674, 63.62999766213553, 67.47429697854179, 61.93974413190569, 64.03682858603341, 62.02367837088448, 64.68870857783726, 60.856957708086284, 66.21949400220598, 63.89001314980643, 65.8042140688215, 62.22459942953927, 68.54127625056675, 58.09353058678763, 64.7731430871146, 65.26206697736467, 59.89757129124233, 56.458643777029856, 84.01335116795131, 20.535835197993688, 0.2075859010219574, 0.0952006887112345, 0.46883382541792734, 0.061448986242924414, 0.35118706258279936, 0.35979001809443745, 1.8587977205004012, 21.94112225941249, 50.60406385149275, 64.85522215706962, 65.40365042005266, 51.1540276663644, 43.39361245291573, 49.007145472935264, 0.2061391829379967, 0.08739875057446105, 0.048664724919945, 0.014506216959229537, 0.024350537020446997, 0.04990332613566092, 0.0648735456966928, 0.051723984868398735, 0.07883019000291824, 0.011139122636190482, 0.04058243986219168, 0.05318232286455376, 0.03117049758189491, 0.04551896193463888, 0.04046027302475912, 0.10247680970600673, 0.02969923010095954, 0.012611015217511781, 0.03850942038531814, 0.035008077908839495, 0.03597888849409563, 0.007868036777446312, 0.05530400348028966, 0.040695130958088806, 0.04841598416013377, 0.03829812118783593, 0.03563863032364419, 0.14364598558417388, 0.0982439454112734, 0.27704590239695137, 0.10100457870534488, 0.12571784188704832, 0.16720082664063998, 0.19554451001541956, 0.08794957173189946, 0.11674325274569647, 0.0675725137282695, 0.09787189787519829, 0.07306349729853016, 0.1624509050909962, 0.16367441229522228, 0.14705886745027133, 0.2271981414939676, 0.16591527419430868, 0.1194038021245173, 0.20027680322527885, 0.2214106313352074, 0.14100429947887147, 0.13582738941269262, 0.10525555309972592, 0.16011401691607066, 0.18480957033378737, 0.16428809293678828, 0.08669906561928135, 0.10660338827541896, 0.11011928532804761, 0.29284252332789557, 0.13074537925422192, 0.20562714684222425, 0.3881229263331209, 7.7021267754690985, 89.67365251268659, 67.19449996948242, 45.734033243996755, 35.36022336142403, 88.49443204062325, 19.14001853125436, 0.283120690711907, 0.6517081324543271, 3.0596312156745364, 0.5311499929853848, 2.395215153694153, 3.247071249144418, 0.30858689706240383, 0.5701560399362019, 0.268994107310261, 14.6112573828016, 79.22169276646206, 73.4760605948312, 71.98011343819755, 81.20206832885742, 74.20808805738176, 75.0481322152274, 80.38645403725761, 71.22312109810966, 74.2180517741612, 68.39117431640625, 68.41545827048165, 68.18674441746303, 70.19805335998535, 69.67864772251674, 74.75910799843925, 70.31936195918492, 65.48675087520054, 55.35524899618966, 50.28847319739205, 58.67789145878383, 56.916505745479036, 56.97093793324062, 55.61436121804373, 51.24828692844936, 53.378462178366526, 52.62676436560494, 52.550080571855815, 52.26671566282, 55.94240999221802, 62.68384756360735, 68.0646367754255, 65.49521378108433, 70.27061339787075, 69.96453135354179, 68.13321549551827, 64.33242579868862, 68.9442092350551, 57.1600991657802, 58.8181825365339, 32.769198417663574, 40.32321391786848, 75.77426065717424, 63.943854740687776, 68.77419376373291, 61.802545002528596, 64.88155582972935, 64.76574325561523, 68.49385479518345, 64.5673166002546, 66.6246782030378, 62.50455624716622, 58.41379043034145, 47.21970054081508, 49.808224133082796, 49.511866092681885, 50.12577765328543, 49.44758483341762, 53.26631130490984, 57.720902170453755, 66.82787132263184, 63.986815452575684, 61.58507333483015, 52.957616737910676, 51.7845002583095, 57.5381680216108, 66.24908638000488, 67.67160497392926, 68.42482444218227, 63.44323008401053, 67.11283779144287, 65.18850639888218, 68.1138995034354, 65.05947835104806, 69.06997162955147, 67.09523800441197, 68.59543745858329, 64.71600110190255, 69.19261428288051, 60.772578784397666, 65.59083489009312, 67.6118643624442, 60.9330404826573, 60.225276129586355, 85.75168623243059, 20.25010790143694, 0.21370883818183625, 0.43232446163892746, 0.887115977704525, 0.2122597587960107, 0.4709642082452774, 0.38069986179471016, 1.5467194893530436, 23.761684043066843, 68.53109019143241, 63.71154172079903, 83.92209352765764, 67.29485280173165, 50.96132285254342, 56.747188568115234, 0.3367112779191562, 0.23279999090092524, 0.0626157611342413, 0.13272595512015478, 0.2567527656044279, 0.1726298260369471, 0.17077521341187613, 0.13489691434162004, 0.21226559419717106, 0.11992782114871911, 0.16987274826637336, 0.18538118180419716, 0.14919710771313735, 0.15414673568946974, 0.07786231408161776, 0.23317625213946613, 0.08944042851882321, 0.0934944309826408, 0.15897810858275208, 0.22152695937880448, 0.08330653980374336, 0.24799936530845507, 0.13759430817195348, 0.18587514172707284, 0.15246031832482132, 0.2613034285604954, 0.22756514751485415], [0.044577793151672394, 0.007566712946364922, 0.05892181649271931, 0.0486575969095741, 0.02868184826469847, 0.019293792113395672, 0.022187667632741586, 0.027573398547247052, 0.014562599826604128, 0.05534497681739075, 0.0049392726837790436, 0.024706840847751925, 0.042704022090349875, 0.0442109567645405, 0.024748513075922216, 0.025829500784831386, 0.00923484209592321, 0.015763523689072047, 0.038766167858349423, 0.025407299332852875, 0.048457357832895856, 0.05983412039599248, 0.06919388672603027, 0.040270042339605946, 0.052349804501448355, 0.014580421548868929, 0.09040589564080749, 0.04965554889557617, 0.03462944179773331, 0.05735527590981551, 0.031466019938566854, 0.029474431449281316, 0.09671597954417978, 0.31810413779956953, 16.617749486650737, 66.3361542565482, 50.28175776345389, 32.37477350234985, 28.171043872833252, 82.0865045275007, 17.105052709579468, 1.4672386114086424, 0.1793723606637546, 0.29522673253502163, 0.08918094315699168, 0.09005991063479866, 0.2602814733982086, 0.035976106500519175, 0.31864387169480324, 0.08605955993490559, 7.9534943614687235, 68.45128318241665, 77.72041634150914, 67.13774013519287, 78.52083492279053, 77.26381547110421, 67.34759657723563, 67.78838334764752, 71.22856848580497, 71.6840020588466, 69.61113207680839, 65.35993235451835, 67.50243718283517, 67.42491613115583, 65.74391760144914, 57.618617738996235, 53.111293520246235, 53.088301931108745, 58.798442704336985, 57.30550064359392, 61.534879548209055, 57.11672503607613, 58.764167240687776, 50.78791318620954, 51.185374464307515, 45.1858412197658, 48.43631969179426, 46.08536195755005, 47.63753393718174, 55.380158288138254, 61.1440155846732, 61.248877797807964, 64.93425096784318, 60.53057997567313, 67.80306489127022, 61.45879677363804, 67.10168593270438, 60.121713229588096, 67.51391560690743, 32.31599869046892, 37.67037432534354, 76.10650266919816, 59.53978075299944, 63.150488580976216, 59.16725308554513, 59.655273709978374, 57.27943100248064, 59.2419045312064, 54.74848713193621, 56.02488510949271, 50.17192758832659, 47.87729890005929, 45.65492452893938, 46.114196981702534, 47.20415047236851, 48.45407928739275, 46.51443753923689, 49.04966150011335, 60.05483681815011, 62.84765829358782, 63.81453486851284, 62.221966062273296, 57.16373654774257, 49.55307585852486, 52.48329101290022, 58.7425513948713, 62.45772538866316, 63.79597623007638, 65.47052683149064, 62.05482019696917, 64.38000011444092, 64.76563208443778, 62.064533778599326, 62.814348629542756, 61.169918469020296, 67.60980074746269, 61.80750601632254, 60.0839011328561, 66.75149672372001, 60.47307668413435, 58.411254337855745, 74.62735625675747, 71.39265714372907, 12.94404321057456, 0.11419802717864513, 0.18534926351691994, 0.28106554384742466, 0.24687429996473448, 0.2903531954756805, 0.2428315340408257, 3.249877452850342, 16.077487094061716, 58.173191683632986, 46.901709284101216, 20.094518627439225, 44.79671083177839, 32.96606520244053, 54.33834886550903, 4.5968756420271735, 0.1187750037227358, 0.053327335976064205, 0.08230119517871312, 0.025380339440224425, 0.057811753558261056, 0.04872709246618407, 0.03927136432113392, 0.006754163020689572, 0.0748935876680272, 0.010727077157103589, 0.03890153220189469, 0.007165236498362252, 0.04839866116110768, 0.03136890800669789, 0.03318638101752315, 0.07049222955746309, 0.04035990073212555, 0.012790182389185896, 0.08783868553915194, 0.05703381994473083, 0.012068623161342527, 0.048016947893691916, 0.04171881638467312, 0.02369657175482384, 0.11105339734682015, 0.02173392108774611, 0.006568250786845705, 0.01169418718200177, 0.08107010195297853, 0.026061273080163767, 0.046402143114911656, 0.02687936748511025, 0.00980414739543838, 0.02138516596252365, 0.013701349746302834, 0.017161731608211994, 0.008007479116453655, 0.06811270902731589, 0.05020959309435316, 0.03249861113727093, 0.03200460032426885, 0.03129553122978125, 0.056509213987737894, 0.02901552464546902, 0.03238163848540612, 0.024225773090230565, 0.01171448386074709, 0.11717961861618928, 0.04718203769464578, 0.06946022529155016, 0.018705948389002254, 0.04144660170589175, 0.03663742369306939, 0.04710337173725877, 0.061573863827756474, 0.06407394646001713, 0.022187106145013655, 0.12174193880387715, 0.03566353934417878, 0.149106713277953, 0.20864014088043145, 25.737466846193584, 80.03140803745815, 39.37467016492571, 18.108867645263672, 61.209321703229634, 89.69246128627232, 14.747808592660085, 2.906267536537988, 0.23456556616084917, 0.08318090904504061, 0.1713398631129946, 0.09030863443123442, 0.4600353432553155, 0.22709649694817408, 0.3440858950572354, 0.08480705892933266, 13.879295059612819, 77.85013920920235, 73.92970848083496, 70.28853280203683, 78.32737622942243, 76.86434963771275, 68.32121290479387, 70.34978812081474, 74.35672392163957, 72.41696058000836, 67.85317529950822, 62.82344382149832, 69.99151815686906, 69.37405259268624, 65.94021115984235, 60.34812028067452, 54.83564533506121, 54.55076224463326, 57.58755929129464, 59.467804363795686, 62.70865263257708, 58.59169905526297, 56.930610588618684, 52.4184330531529, 52.116134302956716, 48.406918389456614, 50.30593054635184, 47.37406866891043, 49.67393977301461, 58.010544776916504, 64.24906131199428, 62.438249588012695, 66.9444968359811, 62.34968784877232, 67.0680010659354, 62.45042978014265, 68.46226133619035, 59.692175592694966, 64.63212244851249, 30.88703911645072, 39.164177962711875, 74.86353247506278, 60.160643986293245, 66.48744433266776, 61.73745427812849, 65.86573341914585, 61.90324524470738, 62.310298510960166, 60.04225363050188, 58.84673268454415, 53.868723596845356, 50.36765834263393, 46.292765685490195, 47.09088788713728, 49.612420422690256, 48.45569126946585, 48.52150460651943, 49.46172789164952, 58.5983623777117, 63.118888173784526, 65.50735228402274, 63.25246034349714, 59.024398122514995, 50.48867164339338, 54.85925531387329, 59.950037138802664, 62.6583685193743, 63.3359568459647, 63.37942477634975, 62.61391394478934, 67.64850221361432, 65.61762714385986, 64.61606516156877, 64.06207833971295, 62.71167509896414, 67.16655431474958, 63.50708402906145, 58.2242887360709, 65.2931740624564, 62.551491328648154, 58.23204639979771, 72.52740914481026, 76.24680764334542, 17.346379280090332, 0.1611193615411009, 0.0656251385807991, 0.06473833402352673, 0.42861371647034374, 0.4577971005014011, 0.5550476163625717, 4.952636003494263, 25.727647304534912, 48.102962493896484, 71.68721212659563, 26.154942410332815, 56.9082339150565, 33.70297724860055, 64.3561122076852, 6.815029851027897, 0.1517442331782409, 0.09907381409513098, 0.105897616861122, 0.012776644767395087, 0.02742347284220159, 0.023983815984268273, 0.019531240354159048, 0.021272395138761828, 0.05088243181152003, 0.03197358788124152, 0.016537762679425732, 0.029865203159196035, 0.10464966882552419, 0.07202785608491727, 0.013211004718739008, 0.07020335684397391, 0.008554506414969052, 0.03453095583245158, 0.03766689023801258, 0.008151827263645828, 0.05192312811102186, 0.05680719942652753, 0.07127496041357517, 0.02627885211924357, 0.049738849247140546, 0.03778043628803321, 0.016558446123131683, 0.07843547261187009, 0.18759596081716673, 0.1401984305786235, 0.12858246745807783, 0.17295644565352372, 0.0396141093224287, 0.08541313319333962, 0.12231607442455632, 0.09206852356770209, 0.11988864253674235, 0.1839104164391756, 0.12637583086533205, 0.10747896986348288, 0.1234023275652102, 0.15374893774943693, 0.12902705717299665, 0.17633635071771486, 0.1380427519657782, 0.20071934376444134, 0.10487622488290071, 0.3719656504690647, 0.0944846442767552, 0.46013696065970827, 0.1513188731457506, 0.16932279563375882, 0.08101111011845724, 0.15329855334545883, 0.14080395522926534, 0.20242283307015896, 0.1466985246432679, 0.24156796612909862, 0.20138897640364511, 0.25718792368258747, 0.46652854340417044, 30.518214838845388, 96.20718955993652, 64.9379335130964, 46.90042039326259, 39.15638555799212, 101.56500802721295, 30.570350646972656, 2.393550408738, 0.23508111706801824, 0.6531072716627802, 0.27540110637034687, 1.7482835820743015, 1.8381539710930415, 0.18151920475065708, 0.8447674672518457, 0.13661839839603218, 11.53317414011274, 76.91398062024797, 81.91867773873466, 71.46781580788749, 79.54656273978097, 77.75021021706718, 68.02100903647286, 71.89871529170445, 75.27080808367047, 73.77214418138776, 67.07738808223179, 68.2912244796753, 71.93782670157296, 73.50519439152309, 70.31504017966134, 64.11994988577706, 56.67388159888131, 58.7283353805542, 61.39463015965053, 63.83007104056222, 66.4473601749965, 63.304189682006836, 63.650335039411274, 61.26897198813302, 57.59484795161656, 50.96165984017508, 52.78892489842006, 50.22183302470616, 52.01951265335083, 61.652505602155415, 66.54016726357597, 64.43131256103516, 70.32078633989606, 65.6788546698434, 70.31342124938965, 67.54416111537388, 71.70690332140241, 64.64060619899205, 66.61531897953579, 36.129385471343994, 41.31089339937483, 78.57178606305803, 65.36483778272355, 68.88392666407994, 64.17242962973458, 66.77081271580288, 64.36262266976493, 64.78537886483329, 60.79475048610142, 61.45565618787493, 55.069889954158235, 54.35890163694109, 50.764101709638325, 49.963436467306956, 52.794198581150596, 53.4125326701573, 52.4925286429269, 53.85941301073347, 61.43287999289376, 66.63908181871686, 67.61481039864677, 68.48300170898438, 64.98504229954311, 55.49746125085013, 56.89049168995449, 65.2145412990025, 65.99040494646344, 67.09014497484479, 65.42315401349748, 63.43075111934117, 70.24577358790806, 68.63061618804932, 66.54418332236153, 67.41741207667759, 63.284422057015554, 66.60949638911656, 61.82015173775809, 61.064410073416575, 67.32677282605852, 62.57754707336426, 59.59167684827532, 77.26694910866874, 73.14568764822823, 16.391663789749146, 0.20868482919675962, 0.3866018679525171, 0.6146653858678681, 1.1723027804068156, 0.633202311183725, 0.3594644841338907, 3.780661634036473, 28.36532245363508, 72.5061615535191, 59.17160265786307, 28.65460549082075, 58.905083656311035, 41.51487513950893, 74.1967694418771, 8.50281720502036, 0.31338232117039816, 0.16272442255701336, 0.194162999146751, 0.15970809012651443, 0.10925446530537945, 0.12976398691534996, 0.17825436565492833, 0.10928974234099899, 0.20690822095743247, 0.06151949281671217, 0.18705169430800847, 0.1361725873180798, 0.1874996359859194, 0.22310320979782514, 0.10019935441336461, 0.2252930322928088, 0.11386748562966074, 0.06327435400869165, 0.16722750663757324, 0.08623299348567214, 0.13330842315086297, 0.17238496989011765, 0.07256469263562135, 0.09753688478044101, 0.2248581184872559, 0.10961687085883957, 0.15336314987923416], [0.07212234887161426, 0.029149155332041637, 0.03347784573478358, 0.04365703809474196, 0.04651572309168322, 0.05727177539042064, 0.024112220254859755, 0.05373695060344679, 0.07301008980721235, 0.07468608487397432, 0.025686976200501834, 0.04783208442053624, 0.012513714144006371, 0.018431711675865308, 0.08456096784876925, 0.036454158169882636, 0.04035389908988561, 0.027451364024143134, 0.0163341546763799, 0.02618686143042786, 0.01858607160725764, 0.006905809660176081, 0.03237248844067965, 0.01860082126222551, 0.04045214417523571, 0.06377868194665227, 0.09794791415333748, 0.0754730294325522, 0.06844542867371015, 0.0789779613592795, 0.1051420613325068, 0.06128269088055406, 0.02413538035138377, 0.14104687076594147, 0.1249460761568376, 23.413169349942887, 62.40585013798305, 58.79630960736956, 27.19801640510559, 18.971601145608084, 82.62486485072544, 31.362643310001918, 4.355381446225302, 0.22985447038497242, 0.6205975732633046, 0.04364113662657993, 0.31231189146637917, 0.009796088943923158, 0.13466972724667617, 0.20434179795639856, 0.13276281314236776, 3.8590386169297353, 53.42043277195522, 86.3135245186942, 67.8420581817627, 69.04816818237305, 78.07112666538784, 75.35404750279018, 71.35604708535331, 65.78614180428642, 64.37519890921456, 70.87051391601562, 70.12132440294538, 66.16139316558838, 63.396440914699006, 60.62724331447056, 61.115305628095356, 62.978777749197825, 61.20226928165981, 64.59370585850307, 65.60094451904297, 63.32551370348249, 60.76135744367327, 57.56814949853079, 57.8052567754473, 54.38312653132847, 55.004100935799734, 48.415176323481965, 46.228838784354075, 47.95504576819283, 60.16396522521973, 61.21794441768101, 64.81365803309849, 60.41865839276995, 63.82290049961635, 59.405034337724956, 66.95231355939592, 60.56436906542097, 75.71095561981201, 38.27469389779227, 29.01347647394453, 79.70067378452846, 58.538072858537944, 65.60810811179024, 55.02070713043213, 56.67817905970982, 52.02219465800694, 51.90187617710659, 46.07183034079415, 47.02672822134835, 42.5918459211077, 47.84440960202898, 45.20112378256661, 48.75984171458653, 47.4256659916469, 50.007074628557476, 47.55440221514021, 54.39860016959054, 62.385693413870676, 65.43208939688546, 63.79538563319615, 66.23253577096122, 59.91870076315743, 54.46678979056222, 51.44151285716465, 59.85778590611049, 63.07876927512032, 69.04724407196045, 62.76372405460903, 66.73710700443813, 62.166859899248394, 64.90913322993687, 64.6459493637085, 65.81885392325265, 60.64835888998849, 62.63548115321568, 64.11003480638776, 66.05550261906215, 60.913856506347656, 66.67813764299665, 76.43193544660295, 41.56749732153756, 2.185760404382433, 0.20482932536729745, 0.10009069381547825, 0.14397720566817693, 0.2073686205382858, 0.023791855034817542, 0.09877204921628747, 5.625451786177499, 16.877259492874146, 61.82493209838867, 45.469970430646626, 9.36382668358939, 26.643082891191753, 25.75698607308524, 51.55460173743111, 10.316590598651342, 0.2639192081987858, 0.03367771500987666, 0.16719409557325499, 0.03642938146367669, 0.015076775004022887, 0.08500789850950241, 0.053401866262512546, 0.061842617977942736, 0.12961525203926222, 0.030573854954647164, 0.047428233948137076, 0.061331884669406075, 0.02686029556207359, 0.04504870663263968, 0.011469220592906433, 0.06184975616633892, 0.002359070544896115, 0.05112265017149704, 0.04195785070104258, 0.018055357138759325, 0.036389598955533335, 0.040092388301023414, 0.024641423286604028, 0.055757034170840464, 0.05333742579179151, 0.010856103135405906, 0.05357894354632922, 0.035793139532740624, 0.046295036362218, 0.051772937777319124, 0.05483446403273514, 0.015748025949246118, 0.123159846290946, 0.06584729773125478, 0.01908418077177235, 0.016197558791775788, 0.018716263817623258, 0.04000960363607321, 0.027983159059658647, 0.034571162424981594, 0.056113366835883687, 0.0310024210651006, 0.09387750471276896, 0.05691263698307531, 0.016506606047706943, 0.0253722207687263, 0.013286836096085608, 0.025975613123072044, 0.04451354945610676, 0.03471482185912984, 0.058900496922433376, 0.026708425854199698, 0.06733200020555939, 0.06927081224109445, 0.019575499497087936, 0.0058654594135337645, 0.04656741049672876, 0.026277140514659028, 0.04305387135328991, 0.062039460986852646, 0.06706623160945517, 0.15854999369808606, 0.09316129742988519, 39.896000453404014, 65.83345903669084, 41.53270769119263, 20.31441695349557, 55.02656446184431, 90.86921514783586, 26.20402101108006, 7.623177000454493, 0.09756157666976963, 0.66107099290405, 0.18508502840995789, 0.3715984544583729, 0.27646692203623907, 0.06555679653372083, 0.21751404899571622, 0.2453439049422741, 7.4628638199397495, 67.5070299421038, 84.90302630833217, 66.89245482853481, 72.20265729086739, 78.11263520377022, 72.54915700639997, 69.17252704075405, 64.70288985116142, 68.82220581599644, 72.10515322004045, 70.90055097852434, 67.08533682141984, 68.42121832711356, 60.43809945242745, 61.61725044250488, 63.40052645547049, 64.68476894923619, 67.08899852207729, 64.45716680799211, 62.57471915653774, 61.52868175506592, 58.18792533874512, 57.32324286869594, 55.54092223303658, 54.56162575313023, 50.356461320604595, 48.075461523873464, 50.23614631380354, 62.40805966513497, 63.79088320050921, 67.65239320482526, 62.393392017909456, 67.60431861877441, 61.5827248437064, 68.16335678100586, 62.97708933694022, 76.32672582353864, 41.19812066214425, 32.2985691343035, 80.00979219164167, 59.70146533421108, 68.12603105817522, 57.30960702896118, 57.719168594905305, 53.93098293031965, 53.567526136125835, 48.30797951562064, 51.34695482254028, 45.34390926361084, 48.92873852593558, 47.32649782725743, 49.29646151406424, 49.656451157161165, 52.39609806878226, 50.016044752938406, 54.372641699654714, 64.97716304234096, 67.31475244249616, 65.31510257720947, 64.66790567125592, 59.48100594111851, 55.166456018175396, 52.57520873206002, 59.87256472451346, 65.80058016095842, 69.31454127175468, 64.0691168648856, 64.69309289114815, 62.45328548976353, 66.08898598807198, 65.5580393927438, 67.16405296325684, 62.799111230032786, 61.68981048039028, 62.979583740234375, 68.19454029628209, 60.75268609183175, 63.00251279558454, 77.71268994467599, 49.348347187042236, 3.337914820228304, 0.20304867305925914, 0.09127476651753698, 0.21242856473795005, 0.13641130950834068, 0.09586544946900435, 0.353163227971111, 9.984468443053109, 29.417126859937394, 46.03017241614205, 76.47484752110073, 15.048698595591954, 24.582306248801096, 29.691254138946533, 58.75570433480399, 17.721519470214844, 0.2726467970226492, 0.049046587465064864, 0.08621624724141189, 0.02468741947918066, 0.03516416471185429, 0.05259664197053228, 0.044986949767917395, 0.02302736828901938, 0.042582571107361994, 0.006195606988122953, 0.008124263474850782, 0.05281062477401324, 0.019957587655101503, 0.08261018645550523, 0.029673160785543065, 0.0652639272489718, 0.015084537444636226, 0.04159737897238561, 0.0728375179959195, 0.014667039936674493, 0.04554025775619915, 0.01640168248143579, 0.013527244445867836, 0.02197265175969473, 0.02879551305834736, 0.03601859975606203, 0.026440535139824663, 0.043786804524383376, 0.15802069567143917, 0.1356685986476285, 0.20927052705415658, 0.134205839995827, 0.1735175805432456, 0.21764884676252091, 0.1678752904491765, 0.10309580327676875, 0.1714259692068611, 0.2010077890008688, 0.1843380970614297, 0.1519710538642747, 0.19243669749370643, 0.127953546919993, 0.16752892546355724, 0.1635216876332249, 0.07925626928252832, 0.05068962608597108, 0.09025820570864848, 0.1198423800191709, 0.15523958419050488, 0.08167129076485123, 0.13894042665404932, 0.11697722519082682, 0.21531966674540723, 0.22169560247233935, 0.21085634481694016, 0.14605232860360826, 0.15108808981520788, 0.16152888456625597, 0.21481280108647688, 0.17220472384776386, 0.1748622605311019, 0.25856011148009983, 0.17138622062546865, 48.028179032461985, 84.63832078661237, 76.33860029493059, 40.82690967832293, 30.477911812918528, 98.89083399091447, 45.53360203334263, 7.7269874300275525, 0.40893663519195145, 0.7936642808573586, 0.22181377613118716, 1.4484989941120148, 0.7907476659332002, 0.2597760462335178, 0.6770355105400085, 0.29243553802371025, 5.744031480380467, 61.33579976218087, 88.22017969403947, 71.95249434879848, 72.34711728777204, 79.05229568481445, 74.55885396684918, 71.54009791782924, 66.90324538094657, 67.27177783421108, 74.49119935716901, 75.8194169998169, 71.8808445249285, 72.3983463559832, 65.52224227360317, 66.79242856161935, 69.0179921558925, 70.09399713788713, 73.14885602678571, 69.63613169533866, 66.95657975333077, 65.11636325291225, 61.094620840890066, 63.828278405325754, 62.221021107264924, 60.17065634046282, 56.952813557216096, 53.36553505488804, 54.779097420828684, 65.96597508021763, 68.67848232814244, 71.24539007459367, 64.92188317435128, 70.4130723135812, 63.72342314038958, 70.58483178274972, 63.1160672051566, 77.41791956765312, 43.394119671412874, 35.541710308619905, 82.78392301286969, 64.37947899954659, 72.18245192936489, 60.26418604169573, 60.99751281738281, 57.874235016959055, 54.90469305855887, 50.21089308602469, 51.96912431716919, 47.049664224897114, 51.246112142290386, 50.51220171792166, 53.750982897622244, 54.130496978759766, 54.888680934906006, 52.57867588315691, 60.074757303510395, 69.87627533503941, 71.68713569641113, 69.19924286433628, 68.39714281899589, 63.92265578678676, 60.179021971566335, 57.264238766261506, 64.52150017874581, 70.55298124040876, 74.25345284598214, 67.67548901694161, 68.21418980189732, 65.56006826673234, 68.58115196228027, 66.452210017613, 68.17969199589321, 63.634187425885884, 63.50577081952776, 62.160036768232075, 66.98436559949602, 64.41604042053223, 65.68322508675712, 78.04766259874616, 45.1401880809239, 2.821760288306645, 0.2931541066084589, 0.34718517160841394, 0.36384909600019455, 0.5810972814049039, 0.15119052146162304, 0.25217040149228914, 7.178542665072849, 29.285458496638707, 76.21699292319161, 54.4727965082441, 17.55209459577288, 40.71386596134731, 36.88585669653756, 71.48480415344238, 21.160478251320974, 0.36837541311979294, 0.09826264583638736, 0.4441453830472061, 0.09492244864148752, 0.09123924520931073, 0.14159390569797584, 0.13865360990166664, 0.09969724528491497, 0.16607283002563886, 0.1283433652882065, 0.11894189619592258, 0.13882751842694624, 0.07993428182921239, 0.19334389881363936, 0.09827294599797044, 0.14551138691604137, 0.07521285875035183, 0.13175832347146102, 0.2455477368618761, 0.13130511636180536, 0.13166961180312292, 0.14001286482172354, 0.07718607929668256, 0.1229843907058239, 0.20374308579734393, 0.13496969400772027, 0.09970264642366342, 0.18367151782980987], [0.04165032845256584, 0.020626076962798834, 0.018938273690374832, 0.043359164614230394, 0.014755846599915197, 0.010285132032419955, 0.046594232986015935, 0.023436460444437604, 0.03688253768320594, 0.05867565077330385, 0.0082388807620321, 0.03622669626825622, 0.03840583183669618, 0.01789136031376464, 0.08918805420398712, 0.03266347139807684, 0.00956757361668029, 0.036886116955429316, 0.007164906560709434, 0.03746978260044541, 0.04345513999994312, 0.10321139171719551, 0.042319954306419404, 0.02901154164490955, 0.028106282631467496, 0.04087008781997221, 0.10853803410593953, 0.030207829416862557, 0.1130987461656332, 0.014260412559711506, 0.04848896060138941, 0.038832993379661014, 0.040793796735150475, 0.030670797252761464, 0.09897958593709127, 0.11504364466028554, 49.074848720005576, 63.33593600136893, 51.404291357312886, 32.86367654800415, 20.17512467929295, 83.3156408582415, 54.28298561913626, 13.260074206760951, 1.737273401447705, 0.14157022482582501, 0.28540653948272976, 0.40484680607914925, 0.13136075623333454, 0.012794753170705267, 0.04809460622657623, 0.038152429541306834, 0.4539461157151631, 36.36397402627127, 88.18039430890764, 76.9296488080706, 62.20431068965367, 66.91632883889335, 69.95612403324672, 78.64445032392229, 68.12907436915806, 63.86886978149414, 71.20345769609723, 68.25383622305733, 68.25537872314453, 66.22307232448033, 67.00308404650006, 65.82057707650321, 69.49609075273786, 64.87683800288609, 65.78077779497418, 64.04094191959926, 64.78179359436035, 61.9361241204398, 60.886730739048545, 55.83813490186419, 58.384003502982004, 56.357651710510254, 55.305663176945274, 48.40537241527012, 48.73413685389927, 53.8749144417899, 60.84744562421526, 57.75852319172451, 62.67498166220528, 59.74560029166085, 71.89578315189907, 62.93205806187221, 74.82084969111851, 37.97877706800188, 31.23618609564645, 83.09654331207275, 59.47785145895821, 66.69180474962506, 53.47938128880092, 52.624280384608674, 44.45823628561837, 48.78416040965489, 46.522264684949604, 51.053417750767295, 49.38144493103027, 55.48776156561715, 55.61256510870797, 62.944870540073936, 59.29639230455671, 57.87605891908918, 46.79172624860491, 52.980090686253135, 64.53423622676304, 69.26673071725028, 67.79859719957624, 69.29280730656215, 65.03100463322231, 62.1245036806379, 53.39649970190865, 58.42012023925781, 63.53384849003383, 66.0004381452288, 67.19707775115967, 64.55551855904716, 69.85602828434536, 66.44254507337297, 66.83298519679478, 62.3695319039481, 65.69949081965855, 72.26551069532121, 55.61328772136143, 53.99214792251587, 71.50805977412632, 65.57849488939557, 19.64823235784258, 0.005514770887592542, 0.0276001073819186, 0.022280146866770725, 0.10993676619338137, 0.10624348651617765, 0.05997841086770807, 0.09634725004434586, 8.059789640562874, 17.868649312428065, 65.18070357186454, 46.1530304636274, 8.043534329959325, 33.508389472961426, 35.163512911115376, 47.68654653004238, 11.836243271827698, 0.05165559193119407, 0.09637310901390654, 0.03361790893333299, 0.01599644779759858, 0.03863118688708969, 0.13263484143785068, 0.02190129871347121, 0.05570600155208792, 0.04736387490161827, 0.0454282316246203, 0.04600134605009641, 0.02477930499506848, 0.05575342775721635, 0.059300520457327366, 0.010683387983590364, 0.02233075031212398, 0.05436391017532774, 0.029475181230476925, 0.03709029492789081, 0.035947102521147044, 0.017880931230528013, 0.012322881259024143, 0.04606883653572627, 0.08570136808391128, 0.05894213183117764, 0.01971107249015144, 0.009575240214222243, 0.006514227524998465, 0.05478430333148156, 0.05617409572005272, 0.001757883747424265, 0.02592384090114917, 0.050979441963136196, 0.03627782388191138, 0.08182296369756971, 0.09428461893860783, 0.05185098287516406, 0.031119261402636766, 0.07424733056021587, 0.03316819288634828, 0.003728192424335118, 0.04581858264282346, 0.04803208600995796, 0.1384992160435234, 0.03155898602147188, 0.07943799453122274, 0.027513431318636452, 0.03618379928437727, 0.03931970315586243, 0.03100495200072016, 0.06215407233685255, 0.033726291331861696, 0.020979256136342883, 0.035914420881973844, 0.02199580507086856, 0.11974826721208436, 0.07339526021054812, 0.05717028012233121, 0.012775044272919851, 0.005445911457562553, 0.0737510093354753, 0.015535325576950396, 0.028659052880746976, 0.1107696747141225, 0.9322869224207742, 64.62163761683873, 65.48422867911202, 35.07127557482038, 13.383787751197815, 55.291652134486604, 100.81932735443115, 41.555164269038606, 19.35965977396284, 2.7729066354887824, 0.38414885529450005, 0.18299718972827705, 0.49280690188918796, 0.25363682423319134, 0.15663279300289495, 0.33674924873879974, 0.2158275909189667, 1.336308928472655, 48.016995906829834, 92.22663606916154, 73.75707353864397, 62.62113312312535, 71.27300916399274, 74.15293325696672, 77.47356769016811, 67.46620232718331, 64.79855264936174, 74.18137918199811, 72.43057210104806, 68.53725324358258, 66.88099030085972, 70.27697794778007, 68.29080063956124, 68.55601337977818, 65.85189955575126, 68.7668147768293, 67.52000222887311, 64.65480831691197, 61.21714537484305, 63.02494852883475, 59.624882289341514, 60.978975023542134, 55.41789048058646, 57.503152574811665, 48.34037201745169, 52.73901946204049, 57.33626726695469, 63.37735421316964, 57.720815317971365, 63.631880623953684, 59.70436273302351, 72.20812552315849, 65.23034845079694, 76.54297460828508, 38.75159045628139, 32.930671078818186, 81.29113033839634, 62.659779003688264, 67.78643090384347, 55.695186138153076, 55.853337560381206, 48.22651883534023, 51.36133411952427, 48.26523419788906, 51.11641706739153, 48.076628821236746, 55.66479819161551, 54.93809652328491, 60.956198828560964, 58.19703095299857, 57.77749177387783, 48.478436197553364, 54.88623169490269, 63.82015596117292, 66.52999510083879, 66.97686154501778, 71.52007320949009, 65.55532959529332, 63.41866820199149, 55.703048024858745, 60.12106009892055, 64.49927983965192, 67.35029942648751, 65.2194606236049, 63.96584578922817, 70.16452135358537, 64.89429882594517, 66.43963377816337, 63.04731478009905, 63.594283921378, 71.8535589490618, 58.91114943368094, 52.899620124271934, 67.98006330217633, 72.76425239018032, 25.00937553814479, 0.045953197205173116, 0.13682605725313934, 0.12084676112447466, 0.15748246812394687, 0.12504945775227888, 0.07141620426305703, 0.12619466201535293, 14.780341795512609, 23.13807453427996, 45.24821867261614, 72.77561269487653, 10.031491245542254, 23.15444622720991, 38.12504359654018, 55.94970907483782, 21.596100773130143, 0.07551441328333956, 0.08081813475915364, 0.030775983751352345, 0.041705605307860036, 0.01319059862622193, 0.005681125197692641, 0.02538168802857399, 0.01881165735955749, 0.041955777776560614, 0.05221378876428519, 0.027972987819729105, 0.022888714746971215, 0.028464577959052155, 0.016465189966506193, 0.040096598610814126, 0.03815895026283605, 0.018008656966100847, 0.02932773217824953, 0.014970127958804369, 0.053915466381503005, 0.05163767521402665, 0.045447457914373705, 0.04001094713541014, 0.044023864303848574, 0.057729508328650675, 0.055209503908242495, 0.05565959993483765, 0.017102208820038607, 0.03190959524363279, 0.24527458580476896, 0.13377330106283936, 0.10240820303027119, 0.14577532346759522, 0.1330113062368972, 0.17743674452815736, 0.16789267451635428, 0.11477873101830482, 0.10661471302488021, 0.19983051717281342, 0.0909648999305708, 0.2161772535847766, 0.12005917195762907, 0.1422363290829318, 0.253642198230539, 0.07334780347134386, 0.07323868825499501, 0.11154401887740407, 0.1499828105526311, 0.11784764991274901, 0.10558927697794777, 0.16719550692609378, 0.16098300314375333, 0.1094501887315086, 0.1543116739818028, 0.1279647291771003, 0.22966952888028963, 0.09229211442704711, 0.17589831565107616, 0.17464507504233293, 0.13692599189068588, 0.1355658955872059, 0.1414332150348595, 0.18954909672694548, 0.16919133625924587, 1.09645049061094, 76.53922258104596, 81.96184689658028, 67.65065615517753, 46.182146889822825, 34.667564392089844, 94.28888920375279, 73.70289148603166, 24.95455425126212, 2.7925101092883517, 0.5498544893094471, 0.26781625194208963, 0.7415262471352304, 1.1582090109586716, 0.5106192603707314, 0.5813295032296861, 0.2853256309671061, 1.0817875117063522, 40.860796042851035, 92.26492759159633, 79.80507741655622, 66.43134457724435, 73.04737758636475, 73.74396923610142, 78.98164640154157, 69.95264993395124, 66.65945393698556, 77.14724554334367, 76.15365314483643, 74.20500305720738, 71.27583708081926, 74.76047679356166, 69.51514966147286, 74.41568633488247, 68.31669657570976, 71.08373328617641, 69.98144326891217, 69.78790814535958, 69.90005901881626, 68.44368185315813, 63.258387156895225, 65.91332163129533, 61.972574370247976, 61.91499464852469, 51.713347230638774, 53.19180229731968, 57.13002041407994, 64.0542060307094, 60.18801294054304, 65.43103327069963, 63.65573378971645, 79.62830134800502, 69.36030210767473, 80.39589663914272, 41.53407301221575, 37.01461723872593, 86.317061151777, 67.58991500309536, 71.74304090227399, 59.55696364811489, 57.679004532950266, 51.52871969767979, 54.46459763390677, 54.64746379852295, 56.24082817350115, 54.1950353213719, 62.75606713976179, 61.403892108372276, 69.25139604296002, 65.44629151480538, 62.27831595284598, 51.93227802004133, 58.166691643851145, 67.51625714983258, 70.04087815965924, 71.82494626726422, 74.90786893027169, 71.01455007280622, 67.09540476117814, 59.11589894975935, 64.46745709010533, 69.66393143790108, 71.04518468039376, 68.43281487056187, 65.98768820081438, 73.5546794618879, 69.41271931784493, 67.17120960780552, 66.66005843026298, 64.56942885262626, 70.43238135746547, 59.52933761051723, 56.00935241154262, 71.62979221343994, 70.94860471997941, 23.025096825190953, 0.046617245501173396, 0.23815688916615077, 0.32701875801597324, 0.44693657755851746, 0.17144257974411758, 0.10714597880308117, 0.16400954074093274, 11.432735323905945, 28.981000593730382, 78.86509037017822, 57.90574162346976, 14.062390514782496, 50.71212223597935, 46.14653042384556, 72.79720074789864, 27.547997168132238, 0.12560737638601235, 0.2819225878587791, 0.19982747733592987, 0.11310011002102069, 0.1630127727985382, 0.22219030878373555, 0.09578612872532435, 0.14352414783622536, 0.12300429892327104, 0.15287848588611397, 0.0680907109220113, 0.08996463753283024, 0.24640043824911118, 0.10242678810443197, 0.09418441967240401, 0.11460269189306668, 0.1341856060815709, 0.11398783060056822, 0.12187311319368226, 0.12975570878812245, 0.09253443285290684, 0.09012717381119728, 0.09771708332534347, 0.2227424191577094, 0.18583031770374092, 0.08685737462448222, 0.1711372932685273, 0.10606925229408912, 0.1427065809922559], [0.016389351803809404, 0.035066689763750346, 0.06421006737010819, 0.055588804983666966, 0.04415424480768187, 0.022470939039651836, 0.017253749438428452, 0.11090046233896698, 0.02897771667422993, 0.06970770736890179, 0.03342608708356108, 0.028420094899567108, 0.005644492364288973, 0.02661343604060156, 0.039449540831680806, 0.059088220420692644, 0.0760625135153532, 0.025515159259417226, 0.013405270990915596, 0.04577884763213141, 0.021755997224577835, 0.023943533056548665, 0.028464387969246933, 0.01286445907317102, 0.03490024512367589, 0.03536659206396767, 0.1143193356692791, 0.06698733834283692, 0.03113179055175611, 0.052826794263507636, 0.014968835349593843, 0.05363469537613647, 0.13598635659686156, 0.02173334263664271, 0.026204864660810148, 0.041276187635958195, 0.8336373759167535, 50.47751978465489, 71.06823880331856, 55.866566930498394, 24.7933178288596, 14.420998334884644, 68.70592771257672, 82.39710290091378, 26.81824176652091, 5.3726567796298434, 0.29005265874522074, 0.1447899006307125, 0.04421438675905977, 0.14455370259072098, 0.04416740499436855, 0.08263743642185416, 0.040537612446184666, 0.06488073816789047, 9.281121407236371, 56.766911029815674, 83.90493147713798, 74.74372468675885, 62.11622837611607, 57.84799861907959, 66.82117325919015, 76.65516022273472, 72.3726588657924, 68.53956699371338, 67.07020364488874, 71.63640689849854, 73.66373143877301, 69.45459611075265, 67.12984003339494, 69.20566299983433, 69.72194194793701, 64.70570387159074, 63.29094641549246, 61.523901394435335, 64.22493021828788, 64.00014904567173, 66.38376331329346, 61.839314869471956, 66.08130128043038, 62.374069077628, 57.08184507914952, 48.59166751589094, 52.67812544958932, 52.677920477730886, 61.59389059884207, 55.57301596232823, 67.9234424318586, 61.55270167759487, 82.0168766294207, 37.88753679820469, 24.56035167830331, 83.25515678950718, 60.89105946677071, 66.67511517660958, 51.06503513881138, 53.31766544069563, 50.02339594704764, 55.79744277681623, 54.25769417626517, 61.58703967503139, 62.47094781058175, 66.34417247772217, 64.06869302477155, 69.72629846845354, 65.23064027513776, 64.67194952283586, 51.49095276423863, 54.079146317073274, 65.60574572426933, 69.09884139469692, 66.4281553540911, 68.02546283176967, 66.59984534127372, 64.76666041782924, 57.85546793256487, 60.48672989436558, 63.96217714037214, 67.63846206665039, 66.90417643955776, 70.72248254503522, 64.31711196899414, 64.03163828168596, 62.47327545710972, 68.2264186314174, 63.878527777535574, 48.57936225618635, 54.920382090977256, 69.08943353380475, 36.718929699489046, 4.100574936185565, 0.08533998711832932, 0.034546952295516214, 0.15494858766240732, 0.08852368699652807, 0.10504454906497683, 0.10434604476072959, 0.7161026799253055, 7.61508321762085, 24.342096601213726, 73.86654240744454, 43.18987389973232, 8.084051881517683, 45.43193599155971, 32.8421162877764, 38.905295031411306, 12.428922006062098, 0.038533467666379044, 0.02659644213105951, 0.07889779923217637, 0.05887234450450965, 0.043905782247228284, 0.04738570676584329, 0.07844922651669808, 0.030122428999415467, 0.023885460636977638, 0.0215460907202214, 0.05558019098160522, 0.010684486362151802, 0.028354197274893522, 0.020770632063171694, 0.04985052593318479, 0.023838582348876765, 0.05117819844079869, 0.023665381196354116, 0.047905332275799344, 0.03622739176665034, 0.03648828848132065, 0.017746180961174623, 0.06361423219953265, 0.02195571213295417, 0.07633856191698994, 0.03236363355868629, 0.008102121180854738, 0.011995165808392423, 0.03806671021240098, 0.02968636168433087, 0.018568215958241905, 0.05457229167222977, 0.05368602655029722, 0.014686284886140908, 0.024665116033117686, 0.05385912422622953, 0.015154424855219466, 0.04878983999203358, 0.020756308188928024, 0.011763624214966382, 0.03438864668299045, 0.014272249603111829, 0.03710468665563634, 0.0682798254170588, 0.06129720474460295, 0.08462143210428101, 0.04823643022349902, 0.024060017163200036, 0.044418690260499716, 0.021425674503136958, 0.032296302528785806, 0.026657420376847898, 0.022198396967723966, 0.05258258951029607, 0.03431294592363494, 0.08284823689609766, 0.05225337788994823, 0.07287396889712129, 0.04133817520258682, 0.012810457015543111, 0.006276528650362576, 0.0587090618376221, 0.07197281332420451, 0.07476744122271027, 0.011485690334146577, 0.05174429342150688, 2.8979722559452057, 68.02683857509068, 71.94341305324009, 38.121402740478516, 9.188848461423602, 39.567093576703755, 100.73866571698869, 69.60638645717076, 29.2664794921875, 10.928774663380214, 0.8275436429040772, 0.4475137394453798, 0.07348949515393802, 0.23555769292371614, 0.2841534752930914, 0.011233358427749147, 0.15120688772627286, 0.05097443098202348, 16.27699419430324, 71.19880935123989, 86.72491346086774, 72.83233778817313, 61.539104052952354, 61.544509751456125, 74.17343044281006, 77.07872935703823, 72.27115958077567, 69.52771200452531, 72.5123176574707, 73.7017936706543, 72.77776663643974, 70.98026071275983, 70.22640201023647, 71.22191905975342, 67.44771317073277, 62.816002300807405, 67.10957213810512, 63.98407786233084, 65.06216730390275, 64.60533019474575, 63.53503663199288, 62.92902169908796, 63.812825611659456, 60.027773584638325, 56.3053491456168, 49.82607405526297, 56.15767560686384, 55.00310039520264, 64.67103236062187, 59.975731577192036, 71.06669630323137, 63.19570745740618, 77.55217266082764, 40.50414848327637, 27.711047070366995, 83.25363513401577, 62.15516608101981, 68.42135729108537, 52.89922060285296, 51.66706875392369, 48.418077196393696, 53.3556547164917, 52.69987678527832, 59.490587506975444, 60.969893727983745, 65.09401089804513, 64.8955911908831, 70.52411842346191, 66.47106048039028, 65.79776614052909, 53.17816298348563, 56.991358688899446, 67.92895930153983, 72.8694064276559, 66.8833179473877, 66.21150357382638, 63.811873708452495, 65.59462860652378, 57.845233236040386, 58.65763051169259, 65.42469651358468, 69.08652918679374, 69.11503069741386, 69.85151890345982, 64.79730197361538, 65.38926764896938, 62.19024058750698, 68.21900490352085, 69.7055719920567, 50.94601597104754, 53.68932458332607, 74.06997176579067, 45.68665000370571, 6.594840569155557, 0.20098603516817093, 0.18632581111575874, 0.18138923815318517, 0.10505477458770786, 0.21016422552721842, 0.20892098652465002, 1.0412066664014543, 16.50388935634068, 24.856701033455984, 58.865346908569336, 73.84747655051095, 11.157164556639534, 25.767170395169938, 36.71733856201172, 49.55826963697161, 19.280860253742762, 0.010167187379140939, 0.06456078855054719, 0.05278983446104186, 0.038989748539669175, 0.07042372466198035, 0.012572733968097185, 0.06687620109213249, 0.02761355764232576, 0.044229348456220965, 0.03654980446611132, 0.04873528238385916, 0.022460895025038292, 0.024202987884304354, 0.0650531742721796, 0.015264430648780294, 0.04538758398432817, 0.08310296572744846, 0.07061666609453303, 0.03168995685077139, 0.05534888178642307, 0.036903772436614544, 0.058428833660270484, 0.026586259016767144, 0.015636975211756568, 0.04899869646344866, 0.011625856161117554, 0.04309590659769518, 0.01999434898607433, 0.018145615866939937, 0.019875769902552878, 0.1343137134930917, 0.10625939816236496, 0.10453187514628683, 0.12102563652609076, 0.13558196329644748, 0.07429036325109856, 0.115449761439647, 0.17370596900582314, 0.12107244187167712, 0.11320037035537617, 0.16150369734636374, 0.14648625174803392, 0.0840671979156988, 0.16016962964619907, 0.12658537604979106, 0.15384200561259473, 0.21579360988523277, 0.08733821168009724, 0.14115612847464426, 0.10702901972191674, 0.09007266030779906, 0.08640757376062018, 0.11061276349106006, 0.16644812774445328, 0.1283845387931381, 0.1286103959594454, 0.11885958989816052, 0.14415564680738108, 0.24029761286718504, 0.1655732789742095, 0.08600942298237767, 0.1780969998134034, 0.23013275116682053, 0.2035020158759185, 0.17486098488526686, 0.11733581737748214, 2.464003622531891, 76.133684022086, 91.75656264168876, 71.84834085191999, 39.55242245537894, 27.828535897391184, 81.32281412397111, 100.35286004202706, 43.83562905447823, 9.434672253472463, 0.6578608708722251, 0.4052373436944825, 0.12347980269363948, 0.4457736499607563, 0.7998025257672582, 0.48726533353328705, 0.22020106124026434, 0.1517081893980503, 11.059391243117195, 65.45174585069928, 89.43289048331124, 82.02667358943394, 69.45039245060512, 67.06851523263114, 74.26258277893066, 77.2186313356672, 73.84744875771659, 73.89569010053361, 75.18792302267892, 80.0744104385376, 80.13221945081438, 75.77971499306815, 72.94519737788609, 74.74301597050258, 75.13647856031145, 68.57869924817766, 71.5642637525286, 64.94834886278424, 69.46845081874302, 71.0440868650164, 71.32091699327741, 70.7005957194737, 72.27037443433488, 68.53208378383091, 64.63970293317522, 55.11600167410714, 58.69240624564034, 58.53146512167794, 70.57796696254185, 63.68709795815604, 72.66120365687779, 67.53926958356584, 82.50559902191162, 43.48567608424595, 31.74662160873413, 83.50314494541713, 65.72372613634381, 71.14936597006661, 55.987514223371235, 56.02321406773159, 53.929482119424, 58.46210125514439, 58.191805907658164, 65.70088740757534, 66.68974808284214, 71.4023220879691, 69.6188028880528, 74.68023204803467, 70.36346912384033, 71.50786522456578, 57.50183241707938, 60.60714912414551, 72.09659303937639, 78.55034392220634, 71.4286140714373, 68.09626497541154, 68.79092502593994, 70.45690849849156, 63.0246011189052, 64.85849475860596, 70.76043360573905, 74.11353697095598, 73.19229616437639, 73.8178494317191, 67.35494777134487, 68.985947063991, 63.81192929404122, 68.8396110534668, 70.33549567631313, 57.0070789882115, 59.23891680581229, 74.28896508898053, 41.95025273731777, 5.711303727967398, 0.18796515172081335, 0.28304390768919674, 0.5320271487746919, 0.5078188106417656, 0.19891639479569026, 0.2128264983849866, 1.1747556030750275, 15.74426191193717, 37.75999566486904, 86.16454819270542, 57.24958154133388, 16.328284059252056, 64.0595075062343, 45.52580962862287, 63.56974983215332, 25.722403151648386, 0.09642911529434578, 0.2141336418156113, 0.15829748367624624, 0.1590480248310736, 0.19126185482101782, 0.13400917340602192, 0.1739977662052427, 0.11193106882274151, 0.15487181821039744, 0.16700610066098825, 0.17301731024469647, 0.15234926928366932, 0.09178986959159374, 0.15594880256269658, 0.10259943455457687, 0.1641427914478949, 0.25907856651714867, 0.13304806926420756, 0.12047161268336432, 0.1216607860156468, 0.07920807972550392, 0.19202075552727493, 0.11523005180060863, 0.11212496698967048, 0.20269099010952882, 0.09648592224610703, 0.10616611316800117, 0.2084736419575555, 0.08980990440717765, 0.08796700329652854], [0.035513372759201696, 0.027876554422878792, 0.023313642213387147, 0.027832705793636184, 0.04793771875223943, 0.12385619963918414, 0.018367469676637223, 0.028200897554467832, 0.03635505134505885, 0.030342199706605504, 0.01631448564252683, 0.0698472141687359, 0.03286792756989598, 0.08729205772812877, 0.026405281852930784, 0.04383877691413675, 0.012205995968542993, 0.025677936417715888, 0.05565039899998477, 0.013010916616102415, 0.03479173041081854, 0.04090080510026642, 0.04607188315796001, 0.026759227771045904, 0.00735123227683029, 0.02827179428589131, 0.041356943481202633, 0.07588688829647643, 0.031089626385697296, 0.04810912348330021, 0.05258189061922686, 0.0839644812845758, 0.022253936755337884, 0.02881101079817329, 0.049116897263697216, 0.022226907312870026, 0.03960622474551201, 0.4097034883286272, 35.362978322165354, 66.33404895237514, 59.50967420850481, 34.07351425715855, 13.368230734552656, 49.17091451372419, 83.41444424220494, 48.038021155766074, 10.76685036931719, 2.921263269015721, 0.31148554437926834, 0.06825569671179567, 0.04330585890316537, 0.13295474355774267, 0.06879642126815659, 0.36468065423624857, 0.07245554349252156, 0.1284691656806639, 19.20119047164917, 50.236889771052766, 72.24993978227887, 77.09794807434082, 67.70193386077881, 59.591065406799316, 62.672188486371724, 74.77373395647321, 72.54216711861747, 72.94181360517229, 72.92853559766496, 74.9684294291905, 72.26873465946743, 66.47764042445591, 66.06251335144043, 64.53621646336147, 69.42013999394008, 65.3269214630127, 65.2929378237043, 63.99563271658761, 66.90508665357316, 66.05014555794853, 70.11898286002022, 68.05347796848842, 70.54835374014718, 61.901244163513184, 56.29168898718697, 50.72128690992083, 57.05281203133719, 60.07807854243687, 70.70536913190568, 65.25877353123256, 74.46685981750488, 42.859379359654014, 34.75170707702637, 77.00379998343331, 67.30850601196289, 66.96321528298515, 60.95690754481724, 61.51651545933315, 63.26282705579485, 69.38733754839215, 66.82206957680839, 69.18991838182721, 68.92326041630336, 68.87544986179897, 67.69574301583427, 69.37349673679897, 68.15169770377022, 67.62232834952218, 58.43405832563128, 52.60252210072109, 66.80395562308175, 69.72630541665214, 67.89878327505929, 70.04165635790143, 69.57421629769462, 68.9566673551287, 64.3541180746896, 63.297971044267925, 67.51811926705497, 67.82333973475865, 68.3715317589896, 64.30632141658238, 66.50007615770612, 66.70198386056083, 60.09293379102434, 49.806483609335764, 49.84422622408186, 68.96509552001953, 52.21076529366629, 10.114153964178902, 0.16069872411234037, 0.07181405648589134, 0.21610737804855618, 0.20022252042378696, 0.1784251257777214, 0.10558819810726813, 0.1530694527817624, 1.4371228388377597, 20.573860951832362, 42.10115371431623, 65.61382647923061, 33.55323314666748, 12.270635962486267, 39.37678241729736, 35.52537509373256, 46.11133084978376, 11.330963322094508, 0.1399544293859175, 0.06982771985765014, 0.11537538043090276, 0.027160206343978643, 0.06496248806693725, 0.027894988522997925, 0.022310640230508785, 0.03933370811864734, 0.045002593392772336, 0.030300581761236702, 0.04241825028189591, 0.02929331688210368, 0.01377475875363286, 0.05815584545156785, 0.00714211626577058, 0.02891976639096226, 0.05421524993809206, 0.06228789301323039, 0.021350514875458818, 0.010356146659302925, 0.006255610263906419, 0.08794213498809508, 0.0419806325142937, 0.053255424834787846, 0.05189121660909482, 0.052884954892631085, 0.003147649100615776, 0.03772519335948995, 0.018626532650419643, 0.03636263058121715, 0.007439385001946772, 0.023481657662029778, 0.049231288089816055, 0.033908430486917496, 0.01632081637425082, 0.08312720978366477, 0.036883399422679625, 0.024294483242556453, 0.017726023382108127, 0.02548804160739694, 0.03700658406264015, 0.07781252996729952, 0.04237319555665765, 0.03729886980727315, 0.029070659008409296, 0.015469938549878342, 0.046812527879540405, 0.025328402673559527, 0.025417348436479057, 0.027684230457193086, 0.014571017053510462, 0.026482936793140004, 0.034319581996117315, 0.014966570738969105, 0.04512757615053228, 0.022650223258616667, 0.029046411559517895, 0.056188043007361035, 0.027107251774785773, 0.027877682487347295, 0.038107161077537706, 0.046995152187134535, 0.05278530863246747, 0.017939992614888718, 0.0716523751616478, 0.04751235532707401, 0.021665316108348112, 0.027110591863415072, 1.8962441682815552, 53.35632521765572, 68.46604810442243, 40.46884816033499, 9.268400124141149, 27.50804328918457, 90.22374834333147, 84.29469762529645, 39.77013036182949, 17.777857201439993, 4.840261050633021, 0.41869909848485676, 0.16995710373989173, 0.033004102762788534, 0.08500752531524215, 0.08006672507950238, 0.17830680284116948, 0.1704882202403886, 1.1932140354599272, 31.820616449628556, 65.95708833421979, 83.3469077519008, 82.4604218346732, 64.25407791137695, 63.935954638889854, 72.58252225603376, 77.08741460527692, 72.06331811632428, 71.86248738425118, 77.16931302206856, 77.01868997301374, 73.77502073560441, 67.32821805136544, 71.40767220088414, 69.93056161063058, 68.23112256186349, 66.21735395703996, 67.73133863721574, 64.52136121477399, 69.69655323028564, 64.89037309374127, 71.40949262891496, 67.5369210924421, 69.56050750187465, 60.045547076633994, 56.1969815662929, 50.91674321038382, 57.080396379743306, 58.141830989292686, 71.42888505118233, 67.02664538792202, 76.20482662745884, 40.26846211297171, 34.51691355024065, 76.5891592843192, 66.64148589542934, 67.78560406821114, 59.248776299612864, 61.88752147129604, 65.051376751491, 67.96060139792306, 67.12430231911796, 68.49801676613944, 68.45758519853864, 69.20685114179338, 69.3535623550415, 69.79955332619804, 68.1262742451259, 66.93740967341832, 59.32946572984968, 55.23876592091152, 67.42406150272915, 67.67418275560651, 66.70401273454938, 70.85521398271833, 69.66219438825334, 69.13755675724575, 64.73969445909772, 66.5350672858102, 66.80679743630546, 67.49472468239921, 68.39275155748639, 67.17251586914062, 71.61861256190709, 67.38065610613141, 67.8666548047747, 55.61022009168352, 50.841285773685996, 71.04278755187988, 62.315058026994976, 15.889852728162493, 0.2808909974992275, 0.156225020598088, 0.22506773152521678, 0.21118624854300702, 0.2067885273801429, 0.09818633100283997, 0.056796376792980094, 3.5338218850748877, 25.733834675380162, 30.62217378616333, 71.4190811429705, 66.05165331704276, 11.995234557560511, 27.062941687447683, 40.03326211656843, 55.85140596117292, 16.69277092388698, 0.07501950341143779, 0.08052869207624878, 0.006879147474787065, 0.023409788929192082, 0.03149222156831196, 0.03515947264220033, 0.021381232155753032, 0.08763779846153089, 0.014726839227867978, 0.026672244670667818, 0.02114607736335269, 0.04403686842748097, 0.027085860958322883, 0.015517871959933212, 0.08092551292585475, 0.04622074695570128, 0.04649044426956347, 0.05931337869593075, 0.01457128337850528, 0.020872351247817278, 0.044923829047807624, 0.0665713624496545, 0.07100847935570137, 0.028352409335119382, 0.05189789000100323, 0.11248283992920603, 0.022564612495313798, 0.030977457761764526, 0.037384802874709876, 0.02746196274113442, 0.03884813149592706, 0.11429512553981372, 0.1692502602402653, 0.06647952273488045, 0.10480601007917098, 0.11960101154233728, 0.23192715059433663, 0.13117827102541924, 0.09272682467209441, 0.08392760969166245, 0.11978812435907976, 0.18174272775650024, 0.13369573093950748, 0.17217808456293174, 0.13344282736735685, 0.13432452934128897, 0.09508596879563161, 0.08627985311405999, 0.1034110506464328, 0.10568740671234471, 0.1626868995704821, 0.19657938448446138, 0.10951012372970581, 0.14368607343307563, 0.058833688364497254, 0.22075258807412215, 0.08284819618399654, 0.1531690481517996, 0.36668933502265383, 0.0943425183317491, 0.214802690914699, 0.1335392879056079, 0.16734246404043265, 0.08629355952143669, 0.15024263518197195, 0.12961854971945286, 0.10223490518650838, 0.1391664466687611, 1.325614565185138, 57.30279084614345, 89.67329815455845, 71.9766184943063, 48.25045885358538, 23.8216643674033, 61.855830737522666, 96.50516305650983, 63.75195244380406, 19.596782684326172, 4.0360526612826755, 0.5803166947194508, 0.3028506434389523, 0.12153765905116286, 0.5461318290659359, 0.3940354362130165, 0.6749597904937608, 0.18317306600511074, 0.6095521088157381, 25.824934244155884, 59.178133964538574, 83.81593894958496, 88.12521171569824, 77.37862750462124, 72.0564741407122, 74.8948063169207, 78.8257566179548, 76.10557161058698, 78.13714150020054, 78.4304666519165, 82.19443089621407, 77.5207668031965, 70.1313089643206, 73.8179953438895, 72.51706327710832, 73.39774050031389, 74.18127495901925, 72.49573230743408, 70.16518143245152, 73.52660873958042, 69.6758337020874, 73.86381871359688, 72.05640465872628, 74.19801316942487, 67.07766601017543, 61.4871176310948, 54.13965123040335, 59.85750797816685, 63.72256851196289, 76.32141739981515, 73.35580812181745, 78.08571093423026, 48.68322740282331, 46.34234455653599, 77.33378383091518, 74.54804256984166, 71.69437571934291, 67.85537093026298, 67.43973663875035, 71.4157738004412, 73.38792269570487, 73.73644433702741, 75.51353645324707, 74.37686674935478, 75.223678452628, 73.02574784415108, 73.07459368024553, 73.29383019038609, 71.95871993473598, 64.68243435450962, 57.87833792822701, 71.23546109880719, 72.88810403006417, 70.71784809657505, 75.91790771484375, 75.42430768694196, 75.93086610521588, 69.926392691476, 69.76078237806047, 72.75695678165981, 72.82577174050468, 73.2126613344465, 64.45199040004185, 77.34677001408168, 71.26736722673688, 72.28393731798444, 63.267246110098704, 58.2086101259504, 72.95109639848981, 57.089519364493235, 12.847379871777125, 0.19016466369586332, 0.1339816384549652, 0.3211013084011418, 0.5008362510374614, 0.3696774946791785, 0.28760404299412456, 0.3457698832665171, 1.9840756952762604, 32.60553012575422, 54.51548624038696, 73.94990689413888, 47.03695249557495, 21.795833689825876, 55.11070367268154, 49.05350732803345, 70.88554981776646, 21.858188561030797, 0.19325494287269457, 0.17527624831667968, 0.1818493798907314, 0.1289913933724165, 0.0921761527923601, 0.10038563263203416, 0.0638913187597479, 0.15457814825432642, 0.07125761705849852, 0.10866278955446822, 0.16604266235870974, 0.09527707818363394, 0.10618279834410974, 0.19232458993792534, 0.1468021505113159, 0.13074653276375361, 0.1746415738016367, 0.15011736404682907, 0.11285710627479212, 0.07530932607395308, 0.1256307858441557, 0.30029066652059555, 0.21660178580454417, 0.1320721594882863, 0.1292385293969086, 0.23254087194800377, 0.14870261853294714, 0.09037359737391983, 0.11055514229727642, 0.11123489867895842, 0.08917030372789927], [0.02106313324267311, 0.037078525737992356, 0.012306554858306689, 0.03490630444139242, 0.04171741520985961, 0.03115243837237358, 0.02967015826808555, 0.05043265808905874, 0.019245192042684982, 0.01212284404651395, 0.029079330685947622, 0.06379229335912637, 0.00952133908867836, 0.024376160199088708, 0.07539813952254397, 0.04584292847929256, 0.0711075183270233, 0.033996480583612404, 0.03943594638258219, 0.002805601294052654, 0.06351848412305117, 0.0222826455719769, 0.013114032734717642, 0.05088451491402728, 0.0563191902557654, 0.025683013555992926, 0.0454885262463774, 0.027706868081752743, 0.017038044852337668, 0.08501674660614558, 0.035598355877612314, 0.06085764975952251, 0.0038729540538042784, 0.11170804793281214, 0.044799260196409056, 0.020148123681013073, 0.0343059875470187, 0.0191738440854741, 0.05391455375190292, 31.56583990369524, 74.4567015511649, 61.64749595097133, 56.64462620871407, 21.227842773709977, 31.538582120622905, 77.69734832218715, 68.31491088867188, 30.75720160348075, 10.81579782281603, 0.27951932538832935, 0.0840268861502409, 0.016257542983761857, 0.06259212775954179, 0.11041469233376638, 0.50266275874206, 0.04834421890388642, 0.213367494355355, 0.06701525327350412, 5.2084977711950025, 27.5187018258231, 59.977565901620046, 79.11318274906704, 64.52757290431431, 53.760904925210134, 66.86679513113839, 78.65285069601876, 78.74594960893903, 71.1863442829677, 72.17618465423584, 77.13322407858712, 77.34428255898612, 69.65257808140346, 67.12398965018136, 65.4306719643729, 65.7188207081386, 69.61081940787179, 70.48728602273124, 71.18858855111259, 73.08164610181535, 71.56164428165981, 72.81432110922677, 72.3350830078125, 68.59656306675502, 62.44940839494978, 59.31650039127895, 65.44937651497978, 67.87535394941057, 70.07629312787736, 72.44385705675397, 42.23066813605172, 37.10503762108939, 66.8590339933123, 70.55960287366594, 70.9755220413208, 70.68242618015834, 68.7774246760777, 70.53511047363281, 69.90697942461286, 71.3947902406965, 70.21916893550328, 70.87746906280518, 70.4481120790754, 71.88487448011125, 71.61281081608364, 71.3817206791469, 71.14389773777553, 58.93210520063128, 56.4110312461853, 67.78788307734898, 68.90949603489467, 66.60887105124337, 68.53660706111363, 68.82563822610038, 71.9193514415196, 68.74388572147915, 71.121552331107, 66.62838159288678, 74.25553035736084, 72.07686015537807, 82.50921208517892, 57.54822553907122, 41.83115366527012, 44.14924989427839, 58.917381967817036, 65.44196278708321, 19.35278626850673, 0.1687870786658355, 0.25569083115884234, 1.1658708112580436, 0.39883835134761675, 0.15820731994296822, 0.6688518896698952, 0.013491813891700335, 0.10098412765988282, 3.510108551808766, 24.22905809538705, 63.155109133039204, 50.309967449733186, 16.773733070918492, 21.479002782276698, 44.55577162333897, 38.77559995651245, 40.12621511731829, 6.829714868749891, 0.20477148704230785, 0.007159047410823405, 0.05835972486862114, 0.02066289766558579, 0.018778351468167136, 0.05257786351389118, 0.038118607963302305, 0.044784308677273135, 0.038217646934624226, 0.03254893468692899, 0.03768465767747589, 0.011844991589896381, 0.050379376126719375, 0.04767578387899058, 0.034229469152965715, 0.07081818420972143, 0.056069733641509495, 0.058859730538512976, 0.02489745999420328, 0.019402842868917754, 0.08235291311783449, 0.042314027303031514, 0.05357423112062471, 0.03751212657828416, 0.018657631606661847, 0.03703207662329078, 0.014191926323941775, 0.026405821288270608, 0.010683709439555449, 0.01575715054890939, 0.10363391547330789, 0.060971331516546864, 0.010343240923248231, 0.057608885158385546, 0.023790872855378047, 0.03623257577419281, 0.03673528879880905, 0.06747253837862185, 0.031162667287779704, 0.03096203805346574, 0.08436095608132226, 0.0517204904130527, 0.023453428908916454, 0.05202209922884192, 0.020591325791818754, 0.02425167616456747, 0.06931154469826392, 0.028485704146857773, 0.026035885692441037, 0.09565953444689512, 0.02337293599599174, 0.021513602463528514, 0.017777724357854043, 0.017383300433201448, 0.05732440256646701, 0.03539768932387233, 0.03096988531095641, 0.055612258546586545, 0.03328098576249821, 0.040733949946505685, 0.03749434217544539, 0.060498908295163085, 0.0909801669684904, 0.055122888913112025, 0.02787465961383922, 0.02305258095397481, 0.07844159299773829, 0.07198428735136986, 0.0102839038840362, 0.0045747335617696595, 0.6015482183013643, 47.511823654174805, 82.1887264251709, 55.571890354156494, 22.55865035738264, 19.4491925239563, 59.26724461146763, 84.06788757869175, 52.595358507973806, 28.485324791499547, 14.115488648414612, 0.5702329586659158, 0.16667203072990688, 0.05139017617329955, 0.08786423238260405, 0.13547689893415996, 0.3265521973371506, 0.06701393013021775, 0.23386306528534206, 0.2432003313941615, 10.907855374472481, 42.23176942552839, 78.76112447466168, 82.6835354396275, 62.70278140476772, 61.70395701272147, 75.03073392595563, 80.70700917925153, 77.94355773925781, 71.64161804744175, 75.3900808606829, 79.8251507622855, 75.92153467450822, 68.26302174159459, 71.59282779693604, 69.177488054548, 69.10334382738385, 68.25759519849504, 67.64755725860596, 70.0211661202567, 71.2848002570016, 69.2800156729562, 71.68164661952427, 70.06932408469063, 66.8378141948155, 60.543767656598774, 60.13839585440499, 66.04200226919991, 71.2250040599278, 67.877487046378, 69.6420932497297, 47.885417870112825, 41.83205345698765, 70.58426203046525, 72.57676914760044, 71.23488439832414, 70.03258201054165, 67.45093018668038, 68.25960322788784, 69.24794278826032, 70.31752068655831, 70.27437237330845, 69.37006432669503, 68.86800139290946, 72.83003098624093, 71.7488704408918, 70.34912804194859, 71.06847504207066, 59.62579945155552, 55.846021107264924, 68.77111571175712, 70.0110981804984, 68.12000696999687, 67.70472008841378, 68.06507451193673, 68.73720155443463, 66.81207806723458, 66.81236294337681, 67.88376821790422, 74.7962600163051, 73.10208770206997, 74.29273101261684, 60.762177331107004, 54.83379364013672, 44.84737362180437, 60.55898421151297, 75.49919537135533, 29.433611461094447, 1.117072201200894, 0.2674585282802582, 0.3879328008208956, 0.16290902479418687, 0.06110001568283353, 0.4673779063991138, 0.03330034436658025, 0.18227357284298965, 6.174866693360465, 24.18337890080043, 60.51298018864223, 74.97612108503068, 37.84129306248256, 11.519934347697667, 32.36595971243722, 45.39457900183541, 50.28454399108887, 10.840371864182607, 0.3381848388484546, 0.04412796175373452, 0.07694170490971633, 0.05530864465981722, 0.06511774366455418, 0.103196891423847, 0.06353055526103292, 0.02948985794293029, 0.02737962082028389, 0.03909605462104082, 0.027492362806307416, 0.03050455278051751, 0.012947923969477415, 0.04133822948538831, 0.060566273251814504, 0.035851398549441776, 0.05248657001980713, 0.025812657849330987, 0.0438677198253572, 0.012746809582625116, 0.0280892615805247, 0.08648156800440379, 0.01719731737726501, 0.06791267011846815, 0.013675780002293842, 0.14541572704911232, 0.05156654778069683, 0.06698932645044156, 0.02826648814204548, 0.016976947862921015, 0.02470054234644132, 0.05078951661874141, 0.0737248518105064, 0.13243475503155164, 0.12866208675716603, 0.2599187014358384, 0.1201021232243095, 0.22593583565737518, 0.1181359187300716, 0.10334691551647016, 0.14183345570095948, 0.2012894353164094, 0.06648434033351285, 0.1351698346968208, 0.16973987753902162, 0.16381951022361005, 0.20457931235432625, 0.12723054071622236, 0.21207222528755665, 0.15595647000840732, 0.14445546429072106, 0.11677996149020535, 0.11924222936587674, 0.11799908535821096, 0.15756169387272426, 0.08344169040875775, 0.12586181344730513, 0.1588144323655537, 0.14687269101185457, 0.06430607328989676, 0.25299164599605967, 0.2393746423934187, 0.16940495265381678, 0.14232479647866317, 0.1487974641578538, 0.2635609959917409, 0.11652914780591216, 0.17079635656305722, 0.26001597621611183, 0.05077955572466765, 0.4834060434784208, 47.908562319619314, 102.52951526641846, 75.97578620910645, 70.56013093675885, 33.747473512377056, 47.96905333655221, 88.62255682264055, 78.33986909048897, 44.06671224321638, 17.805080243519374, 0.4026123359799385, 0.4088867221559797, 0.16718317115945475, 0.15611564075308187, 0.512024750666959, 0.8008600090231214, 0.16908435842820577, 0.27677579117672785, 0.1279402883457286, 7.278214139597757, 36.67557641438076, 72.92986270359584, 89.21288967132568, 71.33681447165353, 68.23847375597272, 75.48275593348912, 81.03205980573381, 81.99059854234967, 75.99064145769391, 77.51800142015729, 87.69147041865757, 82.13626752580915, 74.25161852155412, 76.54398209708077, 69.2204487664359, 71.42388929639543, 76.04903411865234, 74.03395230429513, 79.45160170963833, 79.05317115783691, 73.38855498177665, 78.5746556690761, 77.54560661315918, 73.97130039760044, 69.98635564531598, 65.18094675881522, 72.93148858206612, 71.8356464930943, 73.66016006469727, 69.19321877615792, 53.18069212777274, 46.47499261583601, 68.60377529689244, 80.10163348061698, 77.0825856072562, 74.49807807377407, 71.74616064344133, 73.6444571358817, 72.87966196877616, 75.72995894295829, 74.62092222486223, 75.25254126957485, 74.49959972926548, 78.47756154196603, 75.6709895815168, 74.75313949584961, 77.15934235709054, 66.11440944671631, 62.16125270298549, 74.71943378448486, 77.78480529785156, 70.57198456355503, 68.2495561327253, 72.29660388401577, 76.54804679325649, 72.49976921081543, 75.62370014190674, 74.16228553227016, 84.71857248033795, 80.7556813103812, 94.53357001713344, 63.83883966718401, 59.914879253932405, 55.90226330075945, 65.36424023764474, 73.26031902858189, 22.4822062764849, 0.6009172350168228, 0.4003145178513867, 2.2542266505105153, 0.8515148194772857, 0.9307915398052761, 1.3093184339148658, 0.12538146493690355, 0.2726453042456082, 6.5579017741339545, 36.940983704158235, 75.87754562922886, 57.049268450055806, 28.56104452269418, 32.33744083132063, 59.373836926051546, 55.75247403553554, 68.34785229819161, 12.498103482382637, 0.29176682819213184, 0.168614337220788, 0.23464158922433853, 0.17522215550499304, 0.1418395218040262, 0.27101179904171396, 0.25046461873820847, 0.1619047929665872, 0.10615809966943093, 0.10496628005057573, 0.11203257766153131, 0.11752484366297722, 0.13071304027523312, 0.18295697974307196, 0.1284575898732458, 0.12327964843383857, 0.1294943778110402, 0.1744679231196642, 0.13349065051547118, 0.08377289692206041, 0.17106673919728824, 0.2655776563499655, 0.12087109339024339, 0.14734047305371079, 0.06207282455371959, 0.13546925862985, 0.15932900618229592, 0.13044856089566434, 0.1318718966628824, 0.16215431743434497, 0.138462561581816, 0.14409755063908442], [0.035828311395432265, 0.08815229085407086, 0.03330402202638132, 0.015938161639496684, 0.0640315448067018, 0.05387955830831613, 0.02369722314844174, 0.009205653215758502, 0.032730619223522286, 0.014092693970139538, 0.024259284238464067, 0.03441447851115039, 0.05581537800441895, 0.05808414465614727, 0.05230911275638001, 0.03431425549622093, 0.035378975328058004, 0.07432926366371767, 0.08660863047199589, 0.046518033503421714, 0.04400277204279389, 0.009350071760958858, 0.027211703759218966, 0.0740960036803569, 0.057086569257080555, 0.05115831057940211, 0.012707040645182133, 0.08049847691186837, 0.12916929168360575, 0.042190296442380974, 0.22961242337312016, 0.04621924739331007, 0.15136257080095156, 0.03443227309201445, 0.04828425676428846, 0.06767328974923917, 0.05770470787371908, 0.09754044708928891, 0.016969336396349326, 0.10668492782860994, 11.090839658464704, 61.466759409223286, 72.05049174172538, 71.23632962363106, 43.71378544398716, 44.93167611530849, 50.19662148611886, 83.08327920096261, 64.80271462031773, 17.485619442803518, 2.107815078326634, 0.1527173202484846, 0.25125253360186306, 0.2748448705034596, 0.38545780362827436, 0.10159253608435392, 0.24508921003767423, 0.26435873604246546, 0.40416395557778223, 0.46960702964237755, 2.0579257096563066, 24.215382303510392, 60.584129742213655, 71.72666399819511, 66.44311482565743, 60.25320788792202, 69.30927453722272, 78.3721295765468, 81.73732280731201, 71.57189287458147, 70.28751141684396, 74.8574389048985, 79.5819012778146, 79.20522553580147, 71.81991577148438, 72.70450483049665, 69.1892374583653, 72.80175876617432, 74.59131595066616, 73.33941732134137, 70.59048761640275, 76.19445296696254, 71.5402090890067, 70.12006677900041, 69.53701564243862, 73.48722634996686, 72.24287346431187, 76.21908433096749, 66.22361428397042, 59.03686319078718, 41.658546515873496, 63.02724143436977, 78.71336255754743, 71.39422743661063, 78.08605139596122, 74.22609778812954, 73.5180971963065, 70.32473986489433, 76.1738029207502, 75.63180868966239, 71.91478647504533, 71.29545879364014, 72.91074820927211, 72.63681547982353, 72.25197560446603, 69.46849250793457, 64.28289903913225, 59.8885177884783, 63.257129532950266, 71.88801506587437, 68.91034371512276, 68.69169780186245, 72.26970740727016, 68.70448248726981, 70.29466806139264, 77.51012216295514, 70.30768203735352, 75.84832150595528, 75.6354148047311, 76.7324241910662, 54.906079224177766, 61.4639036996024, 65.09503923143659, 36.07515825544085, 2.3970464382852827, 0.24783966530646595, 0.027520296396687627, 0.9218480139970779, 0.4747192753212792, 0.5239082872867584, 0.19021183545035975, 0.03779687379885997, 0.32483439094253946, 14.246226821626935, 41.79691641671317, 58.24352829796927, 35.203968797411235, 13.602441481181554, 31.720287936074392, 48.431188447134836, 45.84008707318987, 39.02993876593453, 3.3778107251439775, 0.24975055562598364, 0.030252375240836824, 0.06667815707623959, 0.009215574245899916, 0.007884212204122117, 0.021318433739777123, 0.012518145825846918, 0.056926903181842396, 0.03886668264333691, 0.08300988429359027, 0.11740497366658278, 0.0119769284834287, 0.01501035490738494, 0.03802220170785274, 0.04572927386366895, 0.06380730255373887, 0.037749169394373894, 0.04642306913488677, 0.00963009468146733, 0.030562011125896658, 0.07427043467760086, 0.0469441127830318, 0.08746533521584102, 0.05702537218374865, 0.020373816302578365, 0.03325166626434241, 0.008658092419084693, 0.044030843036515374, 0.022485926181876233, 0.05322784238627978, 0.019578724234764065, 0.0366993671549218, 0.04231112656582679, 0.053313432793532095, 0.06341897017721619, 0.06316236858921391, 0.05890688193695886, 0.04975263707871948, 0.05912853218615055, 0.01147572011021631, 0.029183034585522752, 0.019423621307526315, 0.07225758090083088, 0.02345393441750535, 0.04266379174909421, 0.05176615242713264, 0.04312658995123846, 0.05520282033830881, 0.05372686418039458, 0.042097791763288636, 0.055024562403559685, 0.06472475653780357, 0.025523849596668566, 0.017288760149053166, 0.015630902323339666, 0.03239485974024449, 0.012679084154245044, 0.0728101594639676, 0.09817212926489965, 0.02299887660358633, 0.034991318093878884, 0.12056468054652214, 0.03599337860941887, 0.16653958069426672, 0.031957282684743404, 0.16720219728137764, 0.017529735075575963, 0.1161437127739191, 0.09786879697016307, 0.03235456493816205, 0.14430237321981362, 0.005733303692457932, 0.10438041934477431, 24.009368215288433, 72.43831239427838, 77.80599035535539, 45.966360160282676, 30.130286489214214, 56.5017260823931, 81.84778526851109, 83.73765359606061, 59.3101566859654, 19.074199983051844, 3.3418668253081183, 0.08056787747357573, 0.19494957051106862, 0.1262385903724602, 0.407729195696967, 0.21174063879464353, 0.8363513531429427, 0.13222474844327994, 0.755085819533893, 0.2539507416742188, 4.839945341859545, 38.22103296007429, 75.02510588509696, 76.92916938236782, 64.61298016139439, 68.27388872419084, 77.73170021602085, 81.18412808009556, 79.35103348323277, 72.16986874171666, 74.91410146440778, 80.0535797391619, 77.11659703935895, 75.64917918613979, 72.11538096836635, 73.55758380889893, 70.76935509272984, 72.69180352347237, 74.43276500701904, 74.62931564876011, 71.82211140223912, 75.22273349761963, 70.59402424948556, 66.31644916534424, 65.89741720472063, 68.94944817679269, 69.32671451568604, 75.39325618743896, 68.67557798113141, 54.01964889253889, 47.18207604544503, 60.2994134085519, 75.60137557983398, 70.25538989475795, 75.00749220166887, 74.11809498923165, 75.51926176888603, 71.49519865853446, 73.36379855019706, 74.79181316920689, 72.18747547694615, 71.82426534380231, 74.06121703556606, 70.53884860447475, 70.70317350115094, 68.99751581464494, 66.01862158094133, 60.59065410069057, 65.30012920924595, 70.41822787693569, 65.85338647024972, 65.53376933506557, 70.60311249324253, 70.58301135471889, 72.53548295157296, 78.9639423915318, 69.4162073135376, 76.04073796953473, 82.23156206948417, 86.63011918749127, 53.825537068503245, 64.80590384347099, 75.39242240360805, 49.37513596670968, 7.543813807623727, 0.20437773317098618, 0.19857437243419035, 1.0945985785552432, 2.16511578645025, 0.16315415235502378, 0.2690487158085619, 0.17808165135128157, 0.7441025088940347, 15.469184466770717, 40.93105970110212, 67.25338595254081, 64.7367136819022, 18.57740899494716, 9.31500690323966, 41.35569190979004, 53.43814720426287, 46.89393424987793, 5.551661482879093, 0.4106647010360445, 0.07372798664229256, 0.10315500545714583, 0.01851197049420859, 0.07782043490026679, 0.025675547974450246, 0.03843244398012757, 0.08937937393784523, 0.0512494819371828, 0.02791133103892207, 0.037799157069197724, 0.06434974380369697, 0.011016760719940066, 0.031841086955474954, 0.06009750733418124, 0.05139065793316279, 0.0504606883706791, 0.06744420275624309, 0.017836872255429626, 0.12410818040370941, 0.04478231039164322, 0.048564383161387274, 0.030080634634941816, 0.0415920151530632, 0.09099624824843236, 0.0296897102546479, 0.04268069066373365, 0.013970660295204392, 0.05298419063910842, 0.10807460147355284, 0.016111764824017882, 0.02593721991537937, 0.053692900110036135, 0.11144016909279994, 0.20814589597284794, 0.1618937464164836, 0.1884688011237553, 0.18329896139247076, 0.2564441135951451, 0.1451293852712427, 0.060810932623488564, 0.11474531995398657, 0.10204387722270829, 0.13920382037758827, 0.13240829216582434, 0.173309541706528, 0.2293134065611022, 0.16508818071867737, 0.16582722749028886, 0.20494368565934046, 0.15464468539825507, 0.1598764346646411, 0.1317534651607275, 0.10929762691791568, 0.09685825476688997, 0.10695858778698103, 0.17394824671958173, 0.24593200481363706, 0.20959299403641904, 0.08219494338014297, 0.30500675631420954, 0.16122129107160227, 0.15137245027082308, 0.1974931133112737, 0.10003613281462874, 0.37031719035335947, 0.08386255175407444, 0.1675180417618581, 0.18314383471650736, 0.14558749140373298, 0.2580199161810534, 0.14581021373825415, 0.20317667190517696, 22.741054466792516, 84.56414876665387, 93.5793947492327, 87.51056712014335, 60.94524151938302, 61.550964627947124, 61.9394314629691, 91.8045607975551, 82.38381099700928, 27.496669088091167, 3.7838382635797774, 0.3634434677660465, 0.7764930565442357, 0.30929262776459965, 1.0195758385317666, 0.6179865705115455, 0.7607494699103492, 0.43406107702425545, 0.39026446427617756, 0.36070234913911137, 3.5673382580280304, 30.525072710854666, 67.64776570456368, 85.26146302904401, 77.16449792044503, 74.4282625743321, 77.25396987370083, 80.13608959742955, 80.8795051574707, 74.40135220118931, 79.65680980682373, 85.70384093693325, 82.02707658495221, 88.22067301613944, 80.90590136391776, 81.27246747698102, 76.33220795222691, 77.27514103480748, 79.86067690168107, 79.8412914276123, 74.23565850939069, 79.04901613507951, 74.70783724103654, 71.75409548623222, 70.73423194885254, 75.39725834982735, 75.53880705152238, 81.24393817356655, 71.37315355028424, 67.8992418561663, 54.86651965550014, 63.68575695582798, 81.09207139696393, 74.77455384390694, 81.62693677629743, 79.98930890219552, 80.99776349748883, 76.38705703190395, 80.22874382564, 81.90410041809082, 77.97272627694267, 75.9313107899257, 79.61198697771344, 75.6988171168736, 74.63828577314104, 73.10495730808803, 72.13091714041573, 65.75971780504499, 68.16721997942243, 74.55827726636613, 69.89931556156704, 71.49358667646135, 77.78830024174282, 75.80195617675781, 79.60833917345319, 83.8408899307251, 77.78035845075334, 80.47318145206997, 98.241121837071, 93.13519641331264, 58.90207508632115, 79.67423588888985, 76.36751174926758, 42.21704619271414, 4.681782628808703, 0.20698987586157663, 0.547574231667178, 2.6690909947667802, 2.342235790831702, 0.7651478967496327, 0.5264267921447754, 0.2637925664229052, 1.0440936429159982, 23.587633405412944, 55.08219173976353, 66.41341127668107, 45.911042077200754, 22.607388496398926, 46.512891565050396, 62.946975844247, 63.51126684461321, 56.590729032244, 6.856477158410208, 0.3730468281677791, 0.2160816751420498, 0.2692388684621879, 0.07256509297128234, 0.2109657246619463, 0.15323759375938348, 0.1738944931754044, 0.1761797855475119, 0.10178720778120415, 0.103101597965828, 0.23980548498885973, 0.1472612473049334, 0.07219618705234357, 0.08022854889609984, 0.16637614874967507, 0.14402192112590584, 0.12869125019226754, 0.15328624472022057, 0.13294817533876213, 0.19029688302959713, 0.22020701877772808, 0.11513612898332731, 0.170623153714197, 0.13023330244634831, 0.2037119681813887, 0.07739920714604002, 0.12607416776674135, 0.13205413759819098, 0.12153292287673269, 0.22233254329434463, 0.10937478992023639, 0.12259811429040772, 0.20808106873716625], [0.024296486617199013, 0.004431527897915137, 0.036874218843877316, 0.016782069212890098, 0.06068136636167765, 0.023352791987625614, 0.1028249795947756, 0.009866729528377098, 0.03397010253476245, 0.01125549987357642, 0.010967734020336397, 0.029341119674167464, 0.09512176151786532, 0.031047058491302387, 0.04966328080211367, 0.03189638077414461, 0.04112415847235492, 0.02511328841293497, 0.07136373315006495, 0.05852599987494094, 0.07886869686522655, 0.0636289631947875, 0.04491847201383539, 0.04028276826388069, 0.09291617665439844, 0.07530933285930327, 0.16187833010085992, 0.01814930370476629, 0.12419664779944078, 0.08643018933279173, 0.071162886784545, 0.02762542013078928, 0.036289026495069265, 0.05635712714865804, 0.09257614240050316, 0.05051859115649547, 0.03785626936171736, 0.044602488433676105, 0.07790522463619709, 0.09655784017273358, 0.3269507959485054, 2.270521478993552, 44.90073578698294, 66.86719117845807, 67.93800585610526, 50.33225727081299, 29.43902063369751, 34.08099399294172, 60.73635087694441, 75.34468827928815, 46.69463906969343, 11.906198603766304, 0.439912383045469, 0.11304191885782139, 0.12164459617010184, 0.14836974282349857, 0.3336809405258724, 0.3723017695759024, 0.24227084698421614, 0.3581313528120518, 0.3648960755339691, 0.30547065713575905, 1.6620996466704776, 26.517996209008352, 59.493762833731516, 71.8928371156965, 65.22826399121965, 57.08781705583845, 64.42815807887486, 78.81493827274868, 81.59728881290981, 75.00506728036063, 68.83532401493618, 67.59249973297119, 73.88851955958775, 72.2806647164481, 76.88133103506905, 74.2280502319336, 75.99970885685512, 71.4339155469622, 73.05142143794468, 79.00401960100446, 77.81928225925991, 75.435348374503, 71.27164036887032, 73.18626512799943, 75.3570977619716, 77.09845529283795, 67.95822511400495, 63.650515692574636, 28.67519474029541, 45.13528960091727, 83.82461724962506, 72.02003778730119, 75.23271111079625, 67.59888512747628, 77.18246596200126, 73.42262894766671, 76.57466534205845, 71.85098811558315, 77.30706800733293, 72.94967896597726, 76.47825908660889, 73.00299944196428, 73.98264680589948, 74.04764025551933, 70.02879524230957, 67.9287439073835, 74.55487959725517, 73.42830562591553, 71.74364539555141, 70.16052613939557, 75.18992410387311, 77.39308670588902, 77.33474963051933, 70.2695642198835, 72.73573003496442, 76.81949206760952, 70.27586623600551, 54.77890287126814, 47.09962177276611, 27.27243161201477, 5.597535227026258, 0.13585021533071995, 0.06991020257451705, 0.6283295612250055, 0.1912100011748927, 0.0938888294622302, 0.15497780538031034, 0.0504919688350388, 0.08143355923571757, 4.8230794583048135, 36.16114221300398, 59.94063622610909, 47.98876537595476, 25.302292483193533, 16.28206811632429, 49.69797011784145, 56.83123050417219, 44.62800162179129, 23.286507163728984, 0.6066611696566854, 0.1344452135797058, 0.03724784058119569, 0.06995706898825509, 0.044477468356490135, 0.04147240639265094, 0.04350222015221204, 0.021993582868682485, 0.04652614199689456, 0.07522114366292953, 0.01783002583709146, 0.019700385563607727, 0.05812597634004695, 0.036618221152041636, 0.004380902824258166, 0.07862710447183677, 0.005057728782828365, 0.036833883329693756, 0.045190038691673956, 0.06821144265787941, 0.03922254033386707, 0.06198926975152322, 0.06591352953442506, 0.06410344237727778, 0.12000125220843724, 0.009802675822616687, 0.034300671225147586, 0.06336007333759751, 0.03807828262714403, 0.05740286835602351, 0.03768007417342492, 0.10154526254960469, 0.08568603997784001, 0.07105021604469844, 0.0489046447245138, 0.05539262354640024, 0.034230704086699655, 0.0342098968103528, 0.06273126815046583, 0.0030810767576830195, 0.019249261556459323, 0.08274613094649144, 0.03477078403479286, 0.030503752109195505, 0.02567699325403997, 0.03060060619775738, 0.01875908616265016, 0.02584389251257692, 0.03357534443161317, 0.03901048796251416, 0.05633402981662324, 0.09494125084685427, 0.017288478557020426, 0.07671480958483048, 0.07849351449736527, 0.08825973687427384, 0.055200598136122735, 0.05258891684934497, 0.043843747183148346, 0.07585620494293314, 0.03904141219598906, 0.05612287989684513, 0.07881251416568245, 0.09968963890735592, 0.039756499896092076, 0.17469725438526698, 0.033420702908188105, 0.0313804023899138, 0.055645201421741924, 0.034996030519583395, 0.06803762234215226, 0.0344198457231479, 0.024171425827911923, 0.033411423941808086, 0.04358772913526211, 0.4337649643421173, 8.676811388560704, 58.640795026506694, 77.05066558292934, 66.6776373726981, 44.53110899244036, 20.75267631667001, 59.56339073181152, 88.63340296064104, 75.05553899492536, 43.279901708875386, 12.462371502603803, 1.2015145272016525, 0.3442184807998793, 0.11933847277292184, 0.009163744348500456, 0.1265380685882909, 0.6661210847752435, 0.7163196482828685, 0.6886037183659417, 0.18238030640142305, 0.2028707747480699, 4.964530450957162, 39.53760889598301, 77.29112883976528, 76.16048322405133, 61.79853589194161, 63.967145102364675, 76.02634825025285, 85.44323485238212, 79.47050080980573, 74.03964287894112, 77.24136584145683, 74.43585695539201, 77.11927904401506, 73.20987510681152, 72.73819664546421, 73.31422315325055, 73.91513810838971, 71.39457484654018, 70.0665864944458, 75.78358513968331, 74.3721558707101, 73.27594552721295, 71.68432862418038, 75.91890825544084, 76.97008037567139, 76.03231675284249, 61.24855818067278, 66.54516996656145, 39.56126056398664, 52.58807332175118, 75.76500565665108, 68.75780991145542, 74.87398256574357, 68.70232159750802, 74.07137530190604, 71.89974362509591, 76.22264875684465, 72.84963185446603, 75.48423589978898, 71.65720980507987, 75.45311491830009, 70.99263545445034, 72.18639850616455, 72.99892779758999, 69.36536039624895, 65.40706198556083, 68.85496657235282, 73.74750586918422, 67.45778805868966, 65.88539682115827, 70.89572892870221, 68.74772112710136, 70.87872668675014, 70.03918974740165, 69.38264751434326, 76.64628737313407, 83.9749345779419, 76.46974754333496, 67.58494009290422, 43.9278108051845, 14.717420646122523, 0.24021016327398165, 0.071772855839559, 0.41992686688899994, 0.10713217740080186, 0.07346115274620907, 0.24168947818023817, 0.03937159751408866, 0.09229354613593646, 4.940180488995143, 32.16195365360805, 67.61547742571149, 66.15750912257603, 37.59767532348633, 10.224480066980634, 26.765124525342667, 56.35835000446865, 52.10308906010219, 31.727003370012554, 1.54490698661123, 0.26970040798187256, 0.048262238302933316, 0.180425121315888, 0.0268865955793964, 0.03826777710180197, 0.0776632386924965, 0.05420961470476218, 0.027620443076427494, 0.07407866711063044, 0.01258131828425186, 0.07156209607741662, 0.08781102166644164, 0.027512133620413284, 0.003153574407666123, 0.06507245823740959, 0.03903101703950337, 0.03482913804639663, 0.030948311290038482, 0.020162956456520727, 0.06742345315537282, 0.02453438438741224, 0.07199845516255923, 0.023650034430569837, 0.08787642565688916, 0.03625493011038218, 0.016513418539294174, 0.060782481650156636, 0.019494253410292522, 0.059156989944832664, 0.05443884419011218, 0.04771741878773485, 0.06651515939405986, 0.06879329322172062, 0.06050604648355927, 0.1138759401759931, 0.1289428916892835, 0.15558977611362934, 0.12511001021734305, 0.09752111562660762, 0.14255161716469697, 0.2665017124797617, 0.06803592600460563, 0.13197994657925197, 0.10605255354728017, 0.21999999774353846, 0.09690372339848961, 0.23540116846561432, 0.13935552723705769, 0.21102878770657948, 0.0999351464478033, 0.11602783256343432, 0.06826291632439409, 0.15563198099178926, 0.17540850836251462, 0.2309789386178766, 0.16716103734714644, 0.14136351591774396, 0.10222929370190416, 0.1627558387283768, 0.2084778488746711, 0.19264107224132332, 0.12615681333201273, 0.19446930342486926, 0.17695664029036248, 0.24402469715901784, 0.0996585280767509, 0.17723910084792546, 0.12570737887706074, 0.16993856616318226, 0.16015278840703623, 0.07290460475321327, 0.09193038062325545, 0.22149333118328027, 0.16474185644515923, 0.4000410410974707, 8.15085620539529, 67.86228438786098, 89.63750798361642, 81.45781067439488, 65.82930401393345, 42.32828337805611, 49.671931743621826, 74.2609360558646, 86.79583372388566, 65.21752207619804, 20.09308382443019, 1.3600641680615289, 0.6121056803635189, 0.48659646085330416, 0.37233737909368103, 1.4383659149919237, 1.964465707540512, 1.6390029660293033, 1.243432683604104, 0.41178702509828974, 0.19265452080539294, 3.434474153178079, 31.94239752633231, 69.10116904122489, 82.56821618761334, 74.88785117013114, 69.58627837044853, 75.38322993687221, 90.39275632585797, 84.30646092551095, 79.7507494517735, 79.30862862723214, 69.45936257498605, 77.95331301007951, 78.42391450064522, 82.54597500392369, 78.85452910831997, 81.22011974879673, 73.68167863573346, 77.49500288282121, 83.01298427581787, 83.90493842533657, 80.23102283477783, 80.27328177860805, 81.28188228607178, 81.92912088121686, 80.78295993804932, 63.97771331242153, 75.52698816571916, 42.31625257219587, 50.33497749056135, 80.99311515263149, 70.467789377485, 78.09925297328404, 70.01648998260498, 78.98012474605015, 76.3600354875837, 81.46561350141252, 76.46116651807512, 83.69405364990234, 76.74805763789585, 80.93619550977434, 75.49087142944336, 77.18434197562081, 80.80558327266148, 78.2054978779384, 72.89417675563267, 79.42657429831368, 81.67880507877895, 71.47728620256696, 68.55537414550781, 77.21715831756592, 76.27785219464982, 76.96304185049874, 73.83870097569057, 78.89036791665214, 87.16079480307442, 90.71937724522182, 73.5161030633109, 63.1687901360648, 33.730683190482004, 8.67247658116477, 0.23462283451642307, 0.16698024847677775, 0.8951822934406144, 0.4793485669153077, 0.10269006647701774, 0.3039307626230376, 0.4852164291909763, 0.1066924799233675, 6.723795660904475, 50.29451813016619, 72.61258016313825, 58.91481113433838, 34.24481514522007, 24.865982089723857, 64.5172895703997, 69.65790040152413, 62.457586424691335, 35.49201331819807, 1.494234751377787, 0.42859295329877306, 0.11000200733542442, 0.31427774312240736, 0.13191423724804605, 0.17109128859426292, 0.22009303846529552, 0.15123605116137437, 0.1258748820317643, 0.15235062635370664, 0.1533268346850361, 0.17532310794506753, 0.2494499103299209, 0.1740278388772692, 0.09561997585530792, 0.1454131757574422, 0.092845208676798, 0.17634464241564274, 0.14965864723282202, 0.130324836820364, 0.18167410072471413, 0.14294657882835182, 0.20074763867471898, 0.10715941379645041, 0.2050089200160333, 0.14315070930336202, 0.11532044623579298, 0.10123301430472306, 0.07582779468170234, 0.14677757397294044, 0.12159669159778527, 0.17332005899931702, 0.1444129337157522, 0.14288141232516083, 0.15579685143062047], [0.07291280145623855, 0.029313913812594752, 0.042666044485356124, 0.043318028428724835, 0.06446848064661026, 0.04946608495499406, 0.06320621552211897, 0.018046680372208357, 0.03631201186882598, 0.045080451893487146, 0.03361208371019789, 0.0462582394081567, 0.032826720138213465, 0.0915442467001932, 0.05019625309588654, 0.05713585125548499, 0.04250135046562978, 0.02183564705774188, 0.05887429868536336, 0.06696624268910714, 0.026402011314140897, 0.03827717820448535, 0.04329268853845341, 0.027841075523091213, 0.02777979363288198, 0.0913700939023069, 0.05672440119087696, 0.02221137225361807, 0.048555589347545586, 0.06878112030348607, 0.03939294422577534, 0.0294993404698159, 0.049155580545110364, 0.020457610288368802, 0.005220009762394641, 0.059275319666734765, 0.05396587474803839, 0.028179896895640662, 0.0801391519073929, 0.12460292742720672, 0.07473801994430167, 0.11356118813689266, 0.7207204092826162, 31.683431216648646, 63.48409243992397, 64.36696529388428, 62.50619602203369, 38.506298201424734, 23.01683020591736, 34.90933043616158, 61.127993038722444, 74.77121176038469, 43.45707382474627, 7.455540418624878, 0.11461734824946948, 0.06631094070949725, 0.5953956970146724, 1.126978486776352, 1.5399325106825148, 0.31517142802476883, 1.1739940153700965, 0.14323943454240048, 0.1841890500592334, 0.48877282121351784, 2.1539886806692397, 22.64520059313093, 67.44678906032017, 86.58776991707938, 69.41754136766706, 57.185036250523154, 64.2907713481358, 68.1804701941354, 73.82149028778076, 81.78606442042759, 71.96599469866071, 71.89204502105713, 73.02167619977678, 72.57043933868408, 73.13263198307583, 70.63167653764997, 71.4272244317191, 72.22349493844169, 75.14355182647705, 75.35128211975098, 74.28647763388497, 82.003570829119, 76.5777086530413, 74.63706983838762, 67.49221638270787, 39.61308370317732, 6.064543630395617, 2.2871257194450925, 86.8919620513916, 75.28287710462297, 80.13923018319267, 86.95642743791852, 79.68744441441127, 80.2383531842913, 78.72197137560163, 73.37111500331334, 79.39359814780099, 77.98159912654332, 77.56344263894218, 74.71615423474992, 75.07407678876604, 74.42346831730434, 77.33158125196184, 70.25854437691825, 69.65905380249023, 74.63315105438232, 76.80793721335274, 85.08509690420968, 82.7906141281128, 77.14962877546037, 80.73392650059291, 73.2753757749285, 64.43787860870361, 37.742833614349365, 16.307750395366124, 4.405752846172877, 0.6711243305887494, 0.2331170296030385, 0.38129010583673206, 0.41777509663786205, 0.17562125623226166, 0.043693231152636666, 0.28581971302628517, 0.35031734353729654, 0.08369559821273599, 2.6364451008183614, 18.267232724598475, 58.11775895527431, 58.37276826586042, 25.153330053601945, 22.186391932623728, 44.64061607633318, 54.21253088542393, 49.0792886189052, 37.95319380078997, 10.857401030404226, 0.09238090751958744, 0.020224998305950845, 0.03216068034193345, 0.015432396903634071, 0.03280634373160345, 0.031453660423202176, 0.0504365427020405, 0.07733910929943834, 0.04505887447989412, 0.05033656056704266, 0.0674751710944942, 0.05725184003157275, 0.06416632900280611, 0.031042804076735462, 0.07223295007965394, 0.07948738509523016, 0.08367654494941235, 0.01653369825466403, 0.06495008444679634, 0.10200942799981151, 0.05118513306868928, 0.007933417867336954, 0.028299178262906413, 0.02112697999525283, 0.17863570233540876, 0.05614680504160268, 0.06996791876320328, 0.09812711525176253, 0.10530616502676692, 0.057997590729168484, 0.04174017666706017, 0.061758784976388724, 0.08558587463838713, 0.04598032842789378, 0.014550696626039488, 0.03430782298424414, 0.006113463114680988, 0.0390528896158295, 0.0383490927384368, 0.02496734231577388, 0.03275437134185007, 0.003812288782293243, 0.022529586517651166, 0.004608956747688353, 0.06178171267466886, 0.028834854518728595, 0.014844843252961124, 0.007621126365847886, 0.03232426156422921, 0.012167507765947707, 0.027001393526526432, 0.03231474171791758, 0.02758506086788007, 0.07084689981171063, 0.048600006249866316, 0.07187912120882954, 0.0413412998563477, 0.013922191690653563, 0.047088243799018006, 0.022686341677659323, 0.06965291566614594, 0.017228049924597144, 0.03177048199410949, 0.030437028368136713, 0.06717890234930174, 0.03243553791461246, 0.0358679039137704, 0.032879082685602565, 0.1142115978790181, 0.06757810485682317, 0.030634943462376083, 0.04849701141938567, 0.04990776714735797, 0.03765324489878757, 0.016492022633818642, 0.061075269510703425, 0.07121443508991174, 0.3224121837743691, 3.9147119266646246, 43.76223175866263, 72.35979775020054, 68.99820368630546, 49.25316728864397, 21.40184129987444, 29.886950152260916, 59.77506065368652, 88.73863342830113, 78.16014698573521, 38.023936884743826, 6.927518580641065, 0.40246094124657766, 0.23618332935231073, 0.3208995120865958, 0.13985764315085752, 0.611265762576035, 0.5810451699154717, 1.8986623585224152, 0.2930761022227151, 0.7688310933964593, 0.29694472891943796, 4.985842747347696, 36.30385473796299, 83.50074086870465, 82.8138905933925, 64.80715451921735, 59.569977624075754, 75.35968944004604, 85.59805461338588, 78.63295800345284, 79.32839625222343, 75.86009870256696, 78.23612553732735, 80.97944804600307, 79.79429381234306, 80.04974433353969, 77.11969593593052, 75.54965318952287, 75.98910590580532, 78.62896973746163, 80.12302003587995, 74.18174743652344, 79.39170128958565, 68.6207914352417, 72.98963110787528, 75.32890892028809, 59.15940856933594, 14.570441058703832, 7.407241753169468, 86.63965906415666, 67.25831917354039, 77.65756293705532, 75.18073163713727, 77.98509407043457, 74.86555440085274, 78.24264989580426, 72.51984255654472, 77.08378069741386, 76.82008266448975, 75.75536155700684, 69.66919817243303, 72.71788011278424, 73.99705042157854, 74.07013157435826, 70.11888558523995, 73.32984270368303, 73.91235882895333, 73.52261352539062, 70.63823563711983, 73.7199354171753, 75.42325850895473, 81.20713356563023, 78.82224082946777, 76.40599087306431, 64.22864055633545, 32.99582781110491, 12.674163886478969, 2.9564072574887956, 0.32979239204100197, 0.28133698499628473, 0.37687675122703823, 0.20030447388333933, 0.14836849431906426, 0.3716075196862221, 0.17072194841291222, 0.10522623360157013, 3.140379922730582, 17.502901349748882, 55.75245666503906, 80.56243801116943, 43.88403715406145, 23.578920364379883, 22.5524160861969, 40.36925615583147, 59.54952907562256, 46.96601486206055, 17.504221507481166, 0.036083674657025507, 0.02649422931218786, 0.046760579238512685, 0.05814262758940458, 0.08632989507168531, 0.05977083343480315, 0.0699724785185286, 0.02393369429877826, 0.04532147092478616, 0.03833457887438791, 0.01806193044675248, 0.0323050895572773, 0.06346973816731147, 0.02903110041682209, 0.03714387544563838, 0.03900600963139108, 0.10124837633754526, 0.05331997047843678, 0.07360715991152184, 0.031720202549227645, 0.027486690253551518, 0.10104276665619441, 0.032960384751537015, 0.1061155962358628, 0.04929612550352301, 0.1292306583906923, 0.01709096719111715, 0.058357729975666316, 0.039403108680354695, 0.04772447555192879, 0.013252834706301135, 0.06397996935993433, 0.09062331861683301, 0.08077755836503846, 0.05972615868917533, 0.033536966490958414, 0.14879838696547917, 0.14518955775669642, 0.1306949369609356, 0.06972817198506423, 0.11550846828946046, 0.13433088042906352, 0.08625960562910352, 0.12354874185153417, 0.11732718641204493, 0.16068587265908718, 0.09700205669339214, 0.13984929717012815, 0.07643399786736284, 0.10961487596588475, 0.16208315268158913, 0.15313885334346974, 0.09082116585757051, 0.11129177348422152, 0.1326875907502004, 0.200661478298051, 0.13752942665347032, 0.12086133605667523, 0.12120495976081916, 0.10235877853951283, 0.15955916526062147, 0.16448767722717353, 0.09899203026933329, 0.15144360145287855, 0.07512901217809745, 0.20679044084889547, 0.09933796099254064, 0.0853160009054201, 0.27340048657996313, 0.10031640170408146, 0.14759362089846814, 0.1977439812783684, 0.09647590706923179, 0.08858633613479988, 0.1852564127849681, 0.3087760183428015, 0.18389424016433104, 0.3376081112240042, 2.90773577775274, 44.25808995110648, 86.92174203055245, 84.524398122515, 76.96404239109584, 49.96020555496216, 36.21007490158081, 45.638669218335835, 72.62706020900181, 88.53724684034074, 58.23371049336025, 12.712668197495596, 0.43335930896656855, 0.3775290676525661, 1.0874784120491572, 2.677490064076015, 4.642985624926431, 4.627610129969461, 3.4809736694608415, 0.46897729486227036, 0.569270307464259, 0.6362104469111988, 3.0462266206741333, 26.34335844857352, 76.43658379146031, 89.79581574031285, 73.24806935446603, 62.581653458731516, 79.55930573599679, 90.0793856212071, 81.53693675994873, 102.97594397408622, 87.00126416342599, 86.11235332489014, 86.23400238582066, 83.34665066855294, 84.90605572291783, 84.90974521636963, 83.71786512647355, 80.99172551291329, 85.11654445103237, 86.03417914254325, 80.16514001573834, 86.71925067901611, 77.0828913279942, 78.68675095694405, 88.61556693485805, 58.43605940682547, 11.417012419019427, 3.2640689313411713, 88.27955899919782, 72.47943183353969, 79.0362661906651, 86.19689205714634, 84.1738476072039, 83.09710611615861, 84.6703519821167, 78.18538979121617, 82.07331684657505, 82.59196513039726, 78.7654115131923, 74.45479774475098, 75.06185490744454, 77.80901282174247, 81.59157739366803, 77.67988749912807, 76.82379300253731, 79.48286165509904, 78.99427127838135, 80.80383927481515, 81.61453424181256, 83.56037725721086, 92.81047930036272, 91.04428195953369, 78.6801849092756, 52.713206904275076, 21.546004261289323, 6.519434809684753, 1.2105391515152795, 0.1569961892174823, 0.47196762583085466, 0.7719880182828222, 0.43762023746967316, 0.20866420173219272, 1.1328610054084232, 0.5408428928681782, 0.2151700904858964, 3.535324215888977, 25.76678650719779, 70.37929712023053, 67.3174136025565, 34.51832403455462, 34.48975651604788, 55.19049678530012, 66.71665150778634, 66.83479172842843, 57.65549530301775, 18.720215320587158, 0.11723672412335873, 0.08499255683273077, 0.08745429545108761, 0.1458132400044373, 0.2489416604595525, 0.1826057835881199, 0.17698019902620996, 0.10102369303682021, 0.12525239400565624, 0.10591665655374527, 0.1120273122297866, 0.1308901650565011, 0.14337776069130215, 0.15323859799121106, 0.19973606509821756, 0.0965279642758625, 0.23604349685566767, 0.11529190705290862, 0.31485854195696966, 0.22411244921386242, 0.16093684919178486, 0.2241777649947575, 0.14354663448674337, 0.172792538734419, 0.1869817373475858, 0.35909766810280935, 0.1185070231024708, 0.1843806683484997, 0.16292174054043634, 0.1340243997318404, 0.1560983516808067, 0.24561111203261785, 0.22360392792948655, 0.14490320240812643, 0.10750241324837718, 0.10985465667077474], [0.03169705432706645, 0.05845838386033263, 0.024310827454818145, 0.061100131033786705, 0.015493724594957061, 0.04610441212675401, 0.001131297687866858, 0.007058953741631869, 0.02236634456286473, 0.027491017610632947, 0.07464350680155413, 0.013907151113796448, 0.02054140088148415, 0.030908810373927866, 0.05194127553009561, 0.015857022421966706, 0.05530181859752961, 0.1426369497286422, 0.08617071075631039, 0.08781411578612668, 0.10563170577266387, 0.03852692658879927, 0.016700906246634464, 0.058743551772619994, 0.023945560179916874, 0.009128831177284675, 0.08689748282943453, 0.07329774115766798, 0.0325553536282054, 0.018900860965784107, 0.021625423338264227, 0.06177930387535265, 0.059538869453327994, 0.039704432511436086, 0.044382297034774504, 0.04029509045981935, 0.03026604772146259, 0.04791301329221044, 0.03765460196882486, 0.0776952655453767, 0.053302868003291745, 0.16877109238079616, 0.018738709756040146, 0.24063883455736296, 9.250081198556082, 44.399461473737446, 60.20097133091518, 73.40709972381592, 58.80358437129429, 36.52231304986136, 25.130850894110544, 34.056814261845176, 68.95271383013043, 69.96327372959682, 38.909752300807405, 7.526977453913007, 0.10197615264249699, 0.2302003875374794, 0.31972257952604977, 1.0399441570043564, 1.8385352534907204, 0.5695525780320168, 0.43038851980652126, 0.4731723240443638, 0.2869407614426953, 0.33910262531467844, 0.32464163271444185, 14.72858987535749, 48.0144077028547, 75.67074639456612, 77.35801219940186, 65.75109509059361, 43.803097588675364, 45.6801186970302, 56.24450377055577, 58.650571141924175, 63.01153155735561, 67.23647403717041, 66.03440788814, 65.55182770320347, 70.29176371438163, 75.00767285483224, 78.15097536359514, 78.42413684300014, 77.86311149597168, 75.17526340484619, 74.89961447034563, 58.368738310677664, 16.867135967527116, 0.27230913085596903, 0.11151175453726735, 0.09671971148678235, 19.186760800225393, 104.51453222547258, 62.88408769880022, 71.22286401476178, 75.54820796421596, 79.5988826751709, 76.11274909973145, 80.44834164210728, 79.65566335405622, 82.00946290152413, 77.17473261696952, 82.95990698678153, 83.47728375026158, 81.93320642198834, 82.48510878426688, 83.01970318385533, 85.14689418247768, 89.78746400560651, 80.96073654719761, 79.62386144910539, 75.16139480045864, 52.81975058146885, 26.18936378615243, 8.3169789484569, 1.3457163551024027, 0.22215824121875422, 0.2000141151781593, 0.3343238117439406, 0.09709758763866765, 0.25684447639754837, 0.7663669256227357, 0.1480538169188159, 0.20779703397836002, 0.7580176879252706, 0.041186726186424494, 0.72138640497412, 13.863701564925057, 40.85586282185146, 57.304225649152485, 43.89945520673479, 14.68379831314087, 22.97799846104213, 40.7195600100926, 49.33891153335571, 45.56543173108782, 21.752601998192922, 1.1700477642672402, 0.394351063562291, 0.06492895486631564, 0.026013702686343874, 0.05949148056762559, 0.07651171726839882, 0.03135556461555617, 0.011639418379802789, 0.025773616640695503, 0.07010173265423093, 0.060292823639299185, 0.03734446736052632, 0.04234811011701822, 0.03485370779942189, 0.03855360658573253, 0.09513041962470327, 0.06568134163639375, 0.08417380255247865, 0.13331279291638307, 0.0298516154954476, 0.0013471545202524535, 0.08811569746051516, 0.06874680000224284, 0.07843157782086305, 0.1370784044265747, 0.08840413591159241, 0.04023423604667187, 0.09726177954248019, 0.04376110161787697, 0.09194595300193344, 0.22304572431104525, 0.1060121264308691, 0.08573727615709816, 0.04186744608783296, 0.03615105996972748, 0.10296175868383475, 0.03189860976168087, 0.016796248898442303, 0.08707387479288237, 0.04155440395697951, 0.05040987627580762, 0.04610570473596454, 0.025687999092042446, 0.02661419939249754, 0.05535936854513628, 0.01402156992948481, 0.050366616275693686, 0.012956924736499786, 0.032700780646077225, 0.015755730714382868, 0.029590355764542307, 0.053260028694889376, 0.06398972669350249, 0.06976540320153747, 0.058644668864352364, 0.13408594285803183, 0.04983970669231244, 0.009153560386039317, 0.12359486866210188, 0.07449339449937854, 0.052550240353282006, 0.0579488854855299, 0.032843215324516804, 0.03036321732880814, 0.010534152687926377, 0.06432299595326185, 0.03148042523701276, 0.047678240175758085, 0.035798605132315836, 0.03397947310336998, 0.026905204402282834, 0.023387346383450285, 0.031608088208096366, 0.03566817713103124, 0.06075148617050477, 0.010642023640684783, 0.016117025166749954, 0.19367503747344017, 0.13316154746072634, 0.037959725596010685, 0.07068090979009867, 0.4809914901852608, 16.391556092670985, 56.38834190368652, 71.77880328042167, 67.578506061009, 36.31079946245466, 17.63346494947161, 28.181111812591553, 57.89316190992083, 98.72479288918632, 72.50828075408936, 32.38498388017927, 4.699989080429077, 0.23497618841273443, 0.22026226509894642, 0.42198714347822325, 0.5625794636351722, 1.0187088336263384, 0.884303802890437, 0.9005635646837098, 0.7436743261558669, 0.20497892876820906, 0.291533710701125, 2.329743581158774, 31.466657842908585, 66.74352713993618, 78.00117915017265, 74.24458694458008, 66.12841701507568, 68.46473489488874, 64.77957017081124, 65.1691973549979, 71.93342849186489, 65.15027741023472, 70.13690226418632, 67.53264100211007, 68.34207834516252, 68.43275928497314, 69.23690904889787, 74.14412294115338, 72.09288270132882, 72.04170227050781, 73.49185385022844, 80.86458042689732, 73.92807565416608, 36.761883463178364, 3.337000697851181, 0.5868103834135192, 0.04710488147767527, 34.04954297201974, 89.62696756635393, 64.33323873792375, 83.27297891889299, 75.35946014949253, 81.06476497650146, 78.19225461142403, 82.88747896466936, 78.21166093008858, 80.18298993791852, 77.58466938563755, 79.58401353018624, 78.319093976702, 78.13015161241803, 76.88971751076835, 76.40520572662354, 73.5778169631958, 76.30395657675606, 74.63381808144706, 87.68150670187813, 81.9903484072004, 70.65209034511021, 50.232234477996826, 27.685178927012853, 9.06228962966374, 1.6075067818164825, 0.35074628623468534, 0.42962036388260977, 0.26513753139546936, 0.3923630645232541, 0.7176814952066967, 0.2747986486979893, 0.5119200934256826, 0.3673233581440789, 0.10555725691041776, 1.3137641953570502, 13.289918456758771, 41.17376027788435, 64.4590289252145, 67.4400771004813, 27.36308649608067, 11.380912184715271, 35.59506205150059, 57.70632484980992, 57.82423577989851, 27.821777037211827, 3.2759579505239214, 0.2968572521848338, 0.061673330276140144, 0.038332383813602586, 0.030249749310314655, 0.05428474549470203, 0.015793857597080723, 0.02314968440415604, 0.05475177097001246, 0.018876477809888974, 0.09713709873280355, 0.0069345040579459494, 0.06214949901082686, 0.06300635981772627, 0.043562586020146093, 0.02256776429047542, 0.0543814028081085, 0.011561848256470901, 0.0691113972238132, 0.022452163975685835, 0.025066445747922574, 0.1153546172593321, 0.04967801858271871, 0.11440776235290936, 0.12500784998493536, 0.03919056097843817, 0.0836936372465321, 0.056866588204034736, 0.0057741167256608605, 0.06484881309526307, 0.1997125877865723, 0.04180242546967097, 0.08702667589698519, 0.047813930216112306, 0.07743981746690613, 0.08528479507991246, 0.03142298724768417, 0.05890849685030324, 0.14319211351019995, 0.16649934356766088, 0.1291213599698884, 0.1110639146396092, 0.1085255965590477, 0.13717177084514073, 0.10209569694208247, 0.11225711846990244, 0.19736611869718346, 0.1374508115862097, 0.18373078107833862, 0.17849143221974373, 0.07953563572040626, 0.12743294771228517, 0.13662358240357467, 0.0962343689586435, 0.16145143657922745, 0.2914961741438934, 0.21445651591888495, 0.11592998781374522, 0.36261036247015, 0.20728345082274505, 0.13226737401315145, 0.1508767261568989, 0.17393002126898083, 0.16192026356501238, 0.2237919092710529, 0.16080517268606595, 0.1240489442965814, 0.1027227718649166, 0.14881928584405354, 0.07726983087403433, 0.15553926596684114, 0.07859715393611363, 0.16146886135850633, 0.18230827312384332, 0.22248825351042406, 0.18689852181289876, 0.08250591597918953, 0.3330144834305559, 0.2000005580484867, 0.2275296872747796, 0.24298363445060595, 0.6890581739800317, 14.18517473765782, 64.28125926426479, 87.7024416242327, 86.43486091068813, 69.69389901842389, 48.721946239471436, 36.42823444093977, 46.1605657849993, 78.52066121782575, 84.03599534715924, 53.77119868142264, 12.365478004728045, 0.4528164363333157, 0.39573497644492556, 1.0383998113019126, 3.4623351267405917, 7.760060855320521, 4.720461079052516, 1.069739009652819, 0.8678604566625187, 0.6303911134600639, 0.36910456685083254, 0.6945317259856633, 19.41643524169922, 54.84748159136091, 78.24448422023228, 82.64879444667271, 88.04245172228131, 82.31257806505475, 50.05351986203875, 60.19062546321324, 74.71978119441441, 70.71244239807129, 77.06049033573696, 73.32866150992257, 73.13007504599435, 76.08705466134208, 78.69836834498814, 83.19818850925991, 81.86888694763184, 83.09026214054653, 82.57927077157157, 96.02666841234479, 81.59337697710309, 25.157448598316737, 0.8306645240102495, 0.46833143809012, 0.1607024289135422, 21.130986622401647, 105.72275447845459, 68.47553239549909, 81.27472564152309, 75.58853530883789, 84.29191139766148, 80.92496027265275, 91.05532264709473, 87.04286997658866, 87.72940758296421, 82.99446732657296, 88.73860563550676, 87.57288551330566, 86.9967269897461, 86.97181074959892, 87.12041882106236, 83.62355722699846, 88.16433702196393, 81.6905266898019, 96.48138632093156, 91.77883161817277, 67.29927880423409, 35.89087118421282, 13.701940553528921, 2.636566911424909, 0.4628322646021843, 0.20311730009104523, 0.3572767786681652, 0.2967259692294257, 0.9231534068073545, 1.3921973066670554, 0.5667081049510411, 0.6691884973219463, 0.8995621555617878, 0.17039918287524156, 1.235116992677961, 19.981358528137207, 51.802888665880474, 65.1198581968035, 54.36993885040283, 24.233541420527867, 35.1757104737418, 53.027143887111116, 67.17774091448102, 67.06003148215157, 35.79079975400652, 3.14656685931342, 0.37706245269094196, 0.15563270023890904, 0.12797715993864195, 0.13248363669429505, 0.09850682344819818, 0.09995690028050117, 0.06258762228701796, 0.15902905299195222, 0.23940544788326534, 0.2040239450122629, 0.12679949456027576, 0.11881704575249127, 0.28759253504020826, 0.18292652709143503, 0.20166119108242647, 0.14372987965387957, 0.19477347710302897, 0.18313923424908093, 0.18484884394066675, 0.04984869388863444, 0.176363682108266, 0.13122031305517468, 0.23907375282474927, 0.18564564761306557, 0.22463701106607914, 0.1349484015788351, 0.18326240192566598, 0.20380639311458382, 0.11442503785448414, 0.3930881470441818, 0.1893603689968586, 0.22516750331435884, 0.14365016535988875, 0.19823157654276916, 0.1956251606877361, 0.10125200649989502, 0.16566855886152812], [0.05658871454319783, 0.057971568911203315, 0.051617702535752735, 0.01900291602526392, 0.06360547909779207, 0.022463693981990218, 0.058861901850572655, 0.018950840158920203, 0.04735490127599665, 0.22540013226015226, 0.07799112038420779, 0.05297854183507817, 0.07597127091139555, 0.06102750064539058, 0.11910716018506459, 0.19306187251848833, 0.07846236295465912, 0.05349144306299942, 0.05144995850111757, 0.1286065825926406, 0.027535012124904563, 0.05393198870920709, 0.05295642498614533, 0.04983607313728758, 0.034678991817470105, 0.061659488161759715, 0.02917495323345065, 0.07678160457206623, 0.027053326900516237, 0.044229141503040276, 0.08339775526630026, 0.04749540212963309, 0.025896974307085787, 0.054549760916935544, 0.01661221493434693, 0.07927288660513503, 0.024546640426186577, 0.029839866661599705, 0.051767706272325346, 0.06000574904360941, 0.044802734295704534, 0.04830773746860879, 0.021453779423609376, 0.21230081016463892, 0.2944237270525524, 1.2993008685963494, 16.903033835547312, 51.334017276763916, 73.05215794699532, 72.94691358293805, 57.491291999816895, 35.21304314477103, 21.844907079424175, 36.31523241315569, 63.3456426348005, 69.33914484296525, 37.793538093566895, 6.962994345596858, 0.3516381526631968, 0.527798844235284, 0.0854792632162571, 0.5419805518218449, 0.7161664622170585, 0.8563191188233239, 0.6513862354414803, 0.9111150013548988, 0.9702629532132829, 0.45074592743601116, 0.05428239097818732, 4.138890343053, 27.391257967267716, 57.2590970993042, 62.52233668736049, 57.064220973423545, 66.58668545314244, 72.26007720402309, 68.28734738486153, 66.17222540719169, 61.36495440346854, 65.71670150756836, 68.93897724151611, 76.2714945929391, 74.02225153786796, 71.1638182231358, 66.46109676361084, 51.412684781210764, 23.343392065593175, 1.8073646575212479, 0.30532574919717653, 0.2385681899530547, 2.2466431260108948, 0.42602931229131563, 0.2999681181141308, 28.02096799441746, 83.82414477212089, 88.0873579297747, 91.05562141963414, 83.89992877415249, 81.5787718636649, 75.94249738965715, 76.5167521068028, 79.38969326019287, 76.31758894239152, 73.05307510920933, 77.8722344807216, 78.7379869733538, 78.91870961870465, 83.4051822934832, 85.41708183288574, 68.11543505532401, 35.44014154161726, 17.04676948274885, 5.568867393902369, 0.09311491277601038, 0.08878286023225103, 0.2598023462508406, 0.06633892349366631, 0.20817359377230915, 0.20613489459667886, 0.33965782980833736, 0.5034720067467008, 0.06909288000315428, 0.7819732310516494, 0.7941793160779136, 0.049700756291193623, 0.36292091437748497, 12.080447265080043, 42.890569823128835, 62.30877685546875, 48.1638182912554, 30.75351905822754, 19.995815992355347, 45.328675338200156, 58.64147594996861, 51.46179812295096, 30.47218302318028, 6.774596980639866, 0.11153574075017657, 0.24204690328666142, 0.18363710253366403, 0.05648352125925677, 0.008206217782571912, 0.02909900141613824, 0.038032719000641785, 0.03404131817764469, 0.12288848656628813, 0.022792244030694877, 0.07771627298955407, 0.09048658023987498, 0.04827669449150562, 0.09103777459157364, 0.05962985421397856, 0.04725589283875056, 0.03483653747077499, 0.011134707917725402, 0.0904085012152791, 0.07025139712329422, 0.04549596977553197, 0.07018288544246129, 0.08700649626553059, 0.05937623818005834, 0.09234208853117057, 0.0262060928091939, 0.15709098055958748, 0.11344490759074688, 0.17459877181266034, 0.09279269006635461, 0.15775636556957448, 0.18050345139844076, 0.23723779991269112, 0.11696779355406761, 0.17522226407059602, 0.09150027763098478, 0.06706336819167648, 0.10212220730526106, 0.027478456231100217, 0.018614800779947212, 0.025423814875206778, 0.03146097163802811, 0.00310485644149594, 0.0821286572941712, 0.02740441957887794, 0.03692013870126434, 0.03024744229125125, 0.08850101035620485, 0.03641274039234434, 0.06350061829601016, 0.03694012834291373, 0.03737126949376293, 0.052304366403924565, 0.06905210683388369, 0.121867318504623, 0.04931972834414669, 0.01587264229809599, 0.022303576680964658, 0.020617054143388356, 0.015718582618449415, 0.03419140673109463, 0.011663610697723925, 0.018559401788349663, 0.030868145770260265, 0.022295363014563918, 0.04269576431917293, 0.06698236468115024, 0.03874379316610949, 0.058043459696429114, 0.0617338963119047, 0.019359626973580037, 0.08385883338217225, 0.0363516620626407, 0.029401214128094058, 0.07062796370259353, 0.012947645770119769, 0.030195741315505335, 0.013847344189084001, 0.06912072029496942, 0.08313908414649111, 0.007506493811628648, 0.10936485616756336, 0.02819673643846597, 0.5695194112403053, 2.4585857646805898, 25.89911494936262, 63.2059907913208, 82.54302201952252, 65.13986206054688, 34.33340120315552, 18.443532841546194, 28.519365753446305, 63.274527822222026, 89.9361207144601, 78.12776143210274, 31.066566671643937, 3.020616863455091, 0.20396498031914234, 0.10709248310221092, 0.40636591027889934, 0.38784828249897274, 0.7916694421853337, 0.7862091894660677, 1.53317625607763, 1.0050821134022303, 0.581427483686379, 0.7562735272305352, 0.2586841476815087, 13.41829684802464, 51.28930214473179, 82.22837284633091, 72.62956156049455, 53.60277087347848, 64.40413815634591, 72.40462752750942, 74.47089672088623, 75.42414787837437, 72.04130622318813, 76.83937086377824, 78.83941677638462, 84.71837793077741, 81.57943194253104, 84.02398885999406, 83.06090600149972, 76.2293815612793, 47.84563248498099, 10.506994690213885, 1.076519365821566, 0.10216258692422084, 1.0061779745987482, 0.39474635092275484, 1.0047320978982108, 54.499675614493235, 79.8272352218628, 74.07662814004081, 79.49425670078823, 75.08165032523019, 74.23543616703579, 74.52782331194196, 73.30602427891323, 77.44717843191964, 75.98162964412144, 75.1040096282959, 77.9119781766619, 75.76713875361851, 80.19098731449672, 80.23150226048061, 84.89097813197544, 88.52241243634904, 63.16904721941267, 39.82808876037598, 20.288963965007238, 1.8273740581103732, 0.6312605068087578, 0.5587251675980431, 0.16652180307677814, 0.26961170988423483, 0.2124159982694047, 0.9166882165840694, 0.4182491754846913, 0.441019453640495, 0.9697980753013066, 0.26756166560309275, 0.3521648315446717, 0.21954801199691637, 8.317258613450186, 39.6765068599156, 73.15046106066022, 65.81319114140102, 46.47159842082432, 17.67478241239275, 21.65812039375305, 57.5519289289202, 61.51282596588135, 38.54451676777431, 10.791144745690481, 0.027853406200717603, 0.23432664041008266, 0.21830288666699613, 0.07129596785775252, 0.018162380770913193, 0.015884896640532782, 0.05673065049839871, 0.03701826165031109, 0.05874088512999671, 0.01363344450614282, 0.12474889388041836, 0.06587343490017311, 0.06937909285937037, 0.03747857641428709, 0.03197297719972474, 0.02088399830141238, 0.007412783036540661, 0.024888259059350406, 0.08065314218401909, 0.09404177804078374, 0.08074522617139987, 0.017230117760066475, 0.08951805971030678, 0.03398736785831196, 0.08128582859145743, 0.03679395493652139, 0.0921205332768815, 0.0845963873767427, 0.2291968342448984, 0.077282845175692, 0.14024358029876435, 0.1431822476110288, 0.11662720968680722, 0.09997834198709045, 0.06794762145727873, 0.041720098815858364, 0.06583389666463647, 0.04364697202774031, 0.024758043100259135, 0.07749744544603995, 0.20576540513762406, 0.207092497497797, 0.18015072175434657, 0.15137141889759473, 0.07191177909927708, 0.11523094746683325, 0.08601599120135818, 0.1719549008245979, 0.286203356725829, 0.19373146444559097, 0.1317522166562932, 0.12248949440462248, 0.13531273417174816, 0.1498846129647323, 0.18698071954505785, 0.13554853866142885, 0.18830621056258678, 0.11837180464395455, 0.18725350419325487, 0.13296188174613885, 0.13220701153789247, 0.09753767866641283, 0.13481546299798147, 0.13294088787266187, 0.16676522072936806, 0.1489708162844181, 0.10227789716528994, 0.13062194016362938, 0.1719177985297782, 0.28664038756064003, 0.16200460546783038, 0.12032652832567692, 0.13496398074286325, 0.10584037564694881, 0.2309033769581999, 0.09239726699888706, 0.16981611773371696, 0.1511140912771225, 0.21852548686521395, 0.1696892859680312, 0.21580201014876366, 0.22566762433520385, 0.2806827143899032, 0.6820076523082597, 1.7375404728310448, 26.582562344414846, 72.47455419812883, 93.38783986227853, 87.78056022099086, 68.96969522748674, 48.21267802374703, 32.070115838732036, 49.388299328940256, 75.3532554081508, 85.99649211338588, 53.517790930611746, 9.260657225336347, 0.4032257044953959, 0.6341180077620915, 0.8683208291019712, 2.102449983358383, 7.735657044819423, 3.6036148028714314, 2.2614933805806294, 2.180816326822553, 2.278030744620732, 0.6112310215830803, 0.181715247088245, 6.219467180115836, 35.81589317321777, 70.71417944771903, 91.08499145507812, 87.57689462389264, 87.05620356968471, 92.85662923540387, 91.57552732740129, 93.74231610979352, 89.91167000361851, 95.32906232561383, 94.81950923374721, 103.55112974984306, 98.15622874668666, 100.64534446171352, 95.92287622179303, 81.18038300105503, 34.876687799181255, 3.1405857631138394, 0.5386749463421958, 0.18896703581724847, 4.47566431760788, 0.9905574470758438, 0.3266800604760647, 34.22456462042672, 91.68546867370605, 95.75198527744838, 92.06352710723877, 82.54189641135079, 81.4671629496983, 77.98898506164551, 79.41563783373151, 84.98334748404366, 81.46439061846051, 74.7856570652553, 79.49246406555176, 79.13997500283378, 83.58998353140694, 85.61238179888043, 94.17633533477783, 93.37162276676723, 59.974237714494976, 26.97782972880772, 7.749094860894339, 0.22873950164232934, 0.1708517385912793, 0.5464006374989236, 0.17759515531361103, 0.3292946187513215, 0.47155643360955374, 0.884767432297979, 0.8386630405272756, 2.293879585606711, 2.563144428389413, 1.4726494124957492, 0.22374226764908858, 0.620938523539475, 18.796169553484233, 57.635303837912424, 72.46586200169155, 59.671720096043174, 43.78220435551235, 29.846073899950298, 58.18227297919137, 72.97377531869071, 71.99085535321916, 47.94732979365757, 13.336908255304609, 0.20968063361942768, 0.30566713373575893, 0.4433896578848362, 0.2115644503917013, 0.14810371638408729, 0.0955277561609234, 0.15323056413659028, 0.07438653880464179, 0.22218616972012178, 0.12733971700072289, 0.22682406513818673, 0.15331341326236725, 0.09039220280413117, 0.10986117739230394, 0.14017540110009058, 0.13415606266685895, 0.1309896247195346, 0.09599145342196737, 0.1605639127748353, 0.17458631390971796, 0.15880804056567804, 0.14181718443121227, 0.15692074969410896, 0.1270160015140261, 0.1723787545093468, 0.11763022015137331, 0.27380464917847086, 0.28339340750660214, 0.34643102064728737, 0.13093517906963825, 0.19892628783626215, 0.2978722048657281, 0.279680463884558, 0.17949252921555722, 0.22851167672446795, 0.09338669319237981, 0.16664430578904493, 0.13636606479329721, 0.16984484690640653], [0.027830658314217414, 0.03982720324503524, 0.04772781394422054, 0.055638059840670655, 0.03552860587037035, 0.08947526450668063, 0.018581835852403725, 0.01590847403609327, 0.05027936685032078, 0.020319360474656736, 0.060086087589817386, 0.10401844126837594, 0.08125452098569699, 0.051528115557240586, 0.13814963480191572, 0.11943626323980944, 0.09944067762366363, 0.05565140662448747, 0.09966112008052212, 0.04772004811093211, 0.03467525987486754, 0.030272276672933782, 0.03242545827691044, 0.09536925716591732, 0.0374427735140281, 0.08826666471681424, 0.06438005396298, 0.0734847386234573, 0.03659305768087506, 0.022634633916563222, 0.0558044094858425, 0.010939967519204532, 0.08879262435116939, 0.028528346680104733, 0.08222766912409238, 0.05380099413118192, 0.03461788295369063, 0.08655360128198351, 0.042367607820779085, 0.06225125890757356, 0.05000403769580381, 0.03612869206283774, 0.045219409079956155, 0.18375486907150063, 0.06700770117874656, 0.05413411072056208, 0.14464278066796915, 2.8718565830162595, 20.57038858958653, 49.646393639700754, 73.88378783634731, 72.87566675458635, 64.15914467402867, 30.84371015003749, 23.820684671401978, 30.95133079801287, 67.10154002053397, 71.23287636893136, 42.01957491465977, 9.312753081321716, 0.15029862789171083, 0.32341296864407404, 0.13025105292243616, 1.6295964079243797, 1.0894128339631217, 0.7505426747458321, 2.356873256819589, 3.979678452014923, 1.7978933943169457, 0.06908512434789113, 0.009897428997127073, 1.246392073375838, 7.868530920573643, 11.875932250704084, 15.368409531457083, 26.048608916146414, 31.09102085658482, 25.181004728589738, 17.53633608136858, 17.18253902026585, 14.252934438841683, 17.122754982539586, 14.268936140196663, 12.398561852318899, 6.7341901659965515, 0.8844025975891522, 0.2418707013130188, 0.10071279507662569, 0.3467812532825129, 0.09625765628048352, 0.37987115340573446, 0.06590883407209601, 0.05487307267529624, 0.1506714014602559, 4.643141959394727, 30.300190789358957, 64.61380699702671, 81.03282410757882, 86.90615027291435, 86.59291158403668, 83.0052717753819, 78.13592556544712, 76.99624034336635, 76.6183695111956, 74.19917351858956, 81.30583272661481, 81.09296771458217, 68.18843282972063, 37.13617249897548, 11.024084840502058, 0.9042181542941502, 0.12884111143648624, 0.05547255836427212, 0.3193938700216157, 0.14880572871438094, 1.5257920580250877, 0.35395798246775356, 0.26674986630678177, 0.16974012181162834, 1.6385698978390013, 0.6697940762553896, 0.7082517040627343, 0.3605107579912458, 0.8353689430015427, 9.819846510887146, 50.19708701542446, 63.887602124895366, 39.77179792949131, 24.915250028882706, 24.302682944706508, 28.815379858016968, 54.957245758601594, 61.607585498264854, 38.038274492536274, 13.526504618780953, 0.23114333408219473, 0.30010360798665453, 0.033100987385426245, 0.10235196604792561, 0.1967389623501471, 0.13474862729864462, 0.01654061591917915, 0.05980108252593449, 0.031069691026849405, 0.03023497760295868, 0.057106701391083856, 0.08467609488538333, 0.013889003694722695, 0.026764304909322943, 0.04549513178478394, 0.060074952830161364, 0.026746691836576377, 0.0510282896991287, 0.027332784940621684, 0.03319659296955381, 0.0240817234984466, 0.06479589414915868, 0.015988269754286324, 0.034277733348842175, 0.05747429095208645, 0.05918170897556203, 0.054595657025596926, 0.07307670158999306, 0.1245695570749896, 0.022413823354457105, 0.05197424215397664, 0.029140599005456482, 0.08729697032166378, 0.07947266767067568, 0.07304454581545931, 0.15979112924209662, 0.09727108904293605, 0.016892436326348355, 0.07716836953269583, 0.10701520474893705, 0.030446096988660947, 0.022144753685487167, 0.05373281153983303, 0.008479052472726574, 0.026435117037700753, 0.00418067943870223, 0.08362967175032411, 0.023025025646867495, 0.10402381526572363, 0.011262263171374798, 0.058548418671957085, 0.018255448634071008, 0.03360788018575736, 0.05636881830702935, 0.08785415613757712, 0.11968761975211756, 0.1061134859919548, 0.03021752568227904, 0.018023026641458273, 0.030560240149497986, 0.051255656605852504, 0.05946412882102387, 0.007846193038858473, 0.038745686278811524, 0.042789069669587274, 0.09028112662157842, 0.04236874097426023, 0.06747176484870059, 0.014511166872190577, 0.01739543772834752, 0.07733925179179225, 0.012480782295045043, 0.04411399411037564, 0.02480264490337244, 0.03593416285834142, 0.0770873592368194, 0.01994713651947677, 0.04586365093876209, 0.06069811260593789, 0.0520959577656218, 0.12484996845679623, 0.09207505785993167, 0.09071275631764106, 0.10965032942060914, 0.07739263892705951, 0.1351367493293115, 0.06166722346097231, 0.0354342996808035, 5.435279156480517, 28.03242383684431, 64.41051660265241, 87.11169188363212, 72.89602497645787, 35.71259083066668, 18.50057234082903, 31.913607665470668, 52.29204879488264, 96.06721809932164, 81.44818047114781, 37.22851405824934, 2.635898147310529, 0.2254375602517809, 0.24564845860004425, 0.2271728864205735, 0.9270792475768498, 0.8032299961362566, 0.2820895346147673, 5.564031013420649, 5.177084531102862, 2.3728080817631314, 0.3868404137236731, 0.1478862323399101, 5.33018331016813, 20.722559349877493, 33.022279603140696, 41.69985703059605, 51.22905778884888, 55.83337885992867, 58.257115500313894, 48.87895120893206, 42.62959895815168, 39.37640026637486, 42.395576681409565, 39.06605550221035, 37.372831617082866, 27.244435582842144, 8.05346851689475, 1.1517720477921622, 0.041220456162201505, 0.35201653093099594, 0.6944976363863263, 2.3822641457830156, 0.5877778657845089, 0.03335919031607253, 0.4793034036244665, 19.44726266179766, 54.97121511186872, 81.06746782575334, 88.2785793031965, 90.28626823425293, 89.0238847732544, 87.10027599334717, 85.15312671661377, 83.95290878840855, 83.29902076721191, 80.82535089765275, 82.16062096187046, 80.76391492571149, 76.28104141780308, 61.73769746507917, 32.93856075831822, 8.018598982266017, 0.7668747955134937, 0.10128773815397706, 0.34147247672080994, 1.1086585841008594, 2.068873030798776, 1.4539696148463657, 0.1811184619686433, 0.45957193097897936, 0.6691394799521991, 0.9883101390940803, 0.4243155228240149, 0.519168313060488, 0.19524242622511728, 2.3655118218490054, 42.29110009329659, 80.05927726200649, 60.94657557351248, 38.409193652016775, 25.099175793784006, 19.87216063908168, 47.444936820438926, 72.28085926600865, 50.069938455309185, 18.973867995398386, 0.7111204415559769, 0.30128393322229385, 0.05076041764446667, 0.11087308345096451, 0.1641242267297847, 0.06846872278090034, 0.09544724119561059, 0.02515446870321674, 0.0671322869935206, 0.009382104551020478, 0.050582349699522765, 0.0719288849670972, 0.03355940564402512, 0.016079593782446215, 0.07197674204196249, 0.07324790276054825, 0.039212647293295176, 0.025615378881671598, 0.006860248154095773, 0.028811770757394176, 0.09390461897211415, 0.016336787392252257, 0.023100987642205188, 0.05725543626717158, 0.07809567584523133, 0.12690647239131586, 0.12879427894949913, 0.05760716846478837, 0.06302109759833131, 0.15053614228963852, 0.13008223340979644, 0.08251189387270383, 0.11056375969201326, 0.02669307230306523, 0.20279484667948314, 0.07093273449156966, 0.06513522272663456, 0.021489268501422236, 0.08050260919013194, 0.04987389807190214, 0.044419809843280485, 0.11066612348492656, 0.12718517386487552, 0.2128126019878047, 0.09000811805682522, 0.15971772532377923, 0.12841873695807798, 0.056863236241042614, 0.20069354586303234, 0.08934843952634505, 0.1611257397702762, 0.14265579943146023, 0.0912183802574873, 0.09441051432596785, 0.15617316695196287, 0.18305232748389244, 0.17535362845020636, 0.10178184735455684, 0.11178731439369065, 0.1488164495676756, 0.18583953220929417, 0.1288656744041613, 0.07223665488085576, 0.09390345867723227, 0.19034400050129208, 0.13252912568194525, 0.1838907389236348, 0.1564366285290037, 0.20753688365221024, 0.15979095282299177, 0.16316832016621316, 0.08491414532597576, 0.11146720192794289, 0.18301747792533465, 0.08283494439508234, 0.20806721305208548, 0.08274336252361536, 0.08330078582678523, 0.19345695631844656, 0.2250090382461037, 0.3178117163479328, 0.19286103972366878, 0.10474416839757136, 0.24345879895346506, 0.3713351014469351, 0.14697888174227305, 0.1577246237014021, 0.2952393532863685, 4.159431823662349, 29.50019257409232, 71.8962208884103, 98.7517796925136, 94.40491717202323, 82.58680956704276, 45.922367640904014, 34.382226194654194, 41.40536458151681, 82.09327902112688, 91.79898139408657, 57.334811619349885, 12.737242238862173, 0.19806153566709586, 0.4996645567672593, 0.356715087379728, 3.1391333724771227, 5.446481823921204, 1.3693995071308953, 6.740526054586683, 10.000879219600133, 4.8400347999164035, 0.16667169146239758, 0.12719692609139852, 1.5027784300701958, 9.433419840676443, 20.30245736667088, 28.2896374634334, 38.47497919627598, 43.50747953142439, 50.67994165420532, 36.77854176930019, 28.515778745923722, 23.597039529255458, 24.827869483402797, 22.08744784763881, 21.054226398468018, 12.840727840151105, 1.6453924860273088, 0.22579373685376986, 0.2606053245919091, 0.4817953641925539, 0.49232649909598486, 1.2407057327883584, 0.27357424582753864, 0.09909932701183216, 0.1870361151439803, 6.902008703776768, 35.56757845197405, 74.57477228982108, 93.40439741952079, 103.03120994567871, 107.06277016230992, 105.47370324816022, 98.39093194689069, 97.57608195713588, 98.61140523638043, 95.47607231140137, 96.68606635502407, 95.75165176391602, 81.06600870404924, 54.47975165503365, 21.32314600263323, 3.569513044187001, 0.2187215970563037, 0.14039732276328973, 0.6769652143120766, 2.276307157107762, 2.328482483114515, 1.374779258455549, 0.5269732571073941, 1.1344438918999262, 5.226831461702075, 3.096551771674837, 1.2224757224321365, 0.573725622679506, 1.0245383722441537, 14.417797820908682, 64.32050268990653, 78.62572492871965, 47.96319253104073, 36.16800703321184, 36.91632802145821, 39.541169847760884, 70.5154401234218, 86.41516276768276, 58.660861424037385, 22.191773312432424, 0.9769878323589052, 0.6283538256372724, 0.24254323808210237, 0.15568194831056253, 0.2819201179913112, 0.2767634146979877, 0.21051244969878877, 0.1623214813215392, 0.14273171392934664, 0.11972328355269772, 0.17097094362335546, 0.1398929948253291, 0.1379679502653224, 0.11730822814362389, 0.16894650725381716, 0.15129664433853968, 0.08170947193035058, 0.10756038728037051, 0.06862434478742735, 0.09509007393249444, 0.12373715745551245, 0.12902240242276872, 0.2616555882351739, 0.14518081822565623, 0.23316827256764683, 0.24025820355330194, 0.1429540698549577, 0.16119666025042534, 0.19223016500473022, 0.2415608007993017, 0.26774780132940834, 0.16212348480309757, 0.22924433169620378, 0.2437520075057234, 0.23700337963444845, 0.2353691958955356, 0.1726193358855588, 0.09909533044057232, 0.24490937111633165, 0.13134436282728398, 0.18065908019031796], [0.06207525370908635, 0.03980254188978246, 0.026381171807380657, 0.036987561333392344, 0.05005498889035412, 0.058477647469512055, 0.02090997262192624, 0.0558484362305275, 0.12634558177420072, 0.02096037081043635, 0.004667812875205917, 0.008672204251135034, 0.0924865622073412, 0.06615030432918242, 0.07636742679668324, 0.004747967792874468, 0.03321094737787332, 0.03481663264600294, 0.012161863202761327, 0.07634630400155272, 0.025700896346409405, 0.025410507107153535, 0.049870675030563555, 0.011411824163847735, 0.057503020124776025, 0.05313005870474236, 0.05314657763977136, 0.02599218294822744, 0.00577799285695489, 0.09263438106115375, 0.04516565892845392, 0.03490279641534601, 0.026409889105707407, 0.03928916908002325, 0.03369771143687623, 0.04411715269088745, 0.035469427438718934, 0.054069314018956253, 0.041475235883678706, 0.02126546051087124, 0.04950616601854563, 0.03951895157141345, 0.06110588501074484, 0.07932154435132231, 0.1444720612572772, 0.06299662962555885, 0.09655950258352927, 0.1771306980933462, 0.15568276255258492, 2.9554701192038397, 18.099704708371842, 47.78918879372733, 66.65057413918632, 77.59245831625802, 60.264165197099956, 38.647044386182515, 19.783301864351543, 40.472315311431885, 57.760242870875764, 63.44365392412458, 45.806252820151194, 7.761737108230591, 0.36030746889965876, 1.227514577763421, 0.2768753729760647, 0.4410782961973122, 1.2370482661894389, 1.2090836124760764, 1.7989889298166548, 3.418453778539385, 0.8720793702772686, 0.6019431799650192, 0.578735599560397, 0.1631247175059148, 0.1489137922014509, 0.09748701924192053, 0.04960569014240589, 1.8562012655394418, 1.3796056509017944, 0.2936993230666433, 0.43519404051559313, 0.6989197848098618, 0.6495754697493145, 0.6119569454874311, 0.3691944048873016, 0.09792918658682279, 0.10696284220154796, 0.35809305629559923, 0.2559660721038069, 1.0049008088452476, 1.4198850095272064, 3.2408354580402374, 0.27273259099040714, 0.3127520707036768, 0.20364358542220934, 0.04408040323427745, 0.5970935544797352, 3.1029391203607832, 6.008953699043818, 5.95577826670238, 4.199275399957385, 3.683474140507834, 4.172888313020978, 5.2894803285598755, 5.475084517683301, 6.224340038640158, 5.439405517918723, 2.068789001022066, 0.5397405720182827, 0.20651350356638432, 0.4752158543893269, 0.09685676198984895, 0.1541096605360508, 0.06294402959091322, 1.0542528863464082, 4.301994962351663, 1.6080927103757858, 0.5133199925933565, 1.1684625978980745, 0.5379456026213509, 0.41853291168808937, 0.8025227997984204, 12.167370966502599, 47.76695108413696, 68.18295764923096, 40.011083466666086, 18.497211149760656, 20.697219269616262, 35.53416109085083, 52.71465212958199, 61.05577346256801, 45.95783124651228, 16.082957063402446, 1.7701051597084319, 0.06349504073815686, 0.015103660257799285, 0.1802691803979022, 0.11893813711191926, 0.04088039476690548, 0.035090021190366576, 0.020755587245470712, 0.037064452921705585, 0.085431412926742, 0.051575853888477595, 0.052074919787368605, 0.0828387306204864, 0.08709773208413805, 0.013849132977026914, 0.020586801659581915, 0.02470623355891023, 0.02904838609642216, 0.01551288812022124, 0.01683218580936747, 0.028070313490128944, 0.02968902832695416, 0.02948279439338616, 0.02295805763320199, 0.054975925013422966, 0.06587850355676242, 0.0497637209482491, 0.062260900890188556, 0.029178481615547622, 0.043819706687437635, 0.08481892650680882, 0.021444797316300016, 0.008400784306494253, 0.08623262029141188, 0.05489218022142138, 0.038648781300123246, 0.024261050125850097, 0.044014697295746634, 0.013977446493559649, 0.025945728744513223, 0.03498885840443628, 0.031122097679014717, 0.047542743517884185, 0.03488577197172812, 0.0310012166654425, 0.027399021832804595, 0.006944320763328246, 0.06778553301202399, 0.05729682011795895, 0.020990540173703005, 0.03662237717903086, 0.04774437698402575, 0.03774951205455831, 0.04191530316269823, 0.03757042969976153, 0.1592938716390303, 0.08280237471418721, 0.03482382172452552, 0.07827304489910603, 0.05251885471599443, 0.03875542664900422, 0.06527912643338953, 0.037718676030635834, 0.021216860440160547, 0.027323639984907847, 0.039253335645688434, 0.057182839805526395, 0.05241869955456682, 0.04115197162276932, 0.05415312327178461, 0.011780721601098776, 0.016704170000074164, 0.042682176655424495, 0.03511200572497078, 0.008641557368849005, 0.05204412108287215, 0.015037034904318196, 0.09550580555307013, 0.08419795161379234, 0.05467924236186913, 0.06957605121923344, 0.06773933834795441, 0.0958936425990292, 0.02114985341073147, 0.04438446834683418, 0.010093512046816093, 0.02427654616933848, 0.22693077155521937, 0.03053838453654732, 0.09002029776040997, 0.31640454328485895, 0.07123888949198381, 5.386159300804138, 27.23661364827837, 63.17522416796003, 83.58907331739152, 69.39113126482282, 37.9376437323434, 19.105918509619578, 29.1716365814209, 59.7104424067906, 90.70339638846261, 88.66017436981201, 36.43080874851772, 3.085891932249069, 0.5393516357455934, 0.492823132446834, 0.39730464507426533, 0.19231779101703847, 0.7501469531229564, 3.278324463537761, 3.7411307266780307, 6.959666158471789, 3.3493695769991194, 0.9421307827745165, 0.7517799426402364, 0.3731249411191259, 0.7478569788592202, 0.38211238171373096, 0.41473259989704403, 5.334813850266593, 4.334672340324946, 1.6868899507181985, 1.611177493418966, 2.8803201402936662, 2.2881101923329488, 2.3836025425365994, 1.333036869764328, 0.1564350678984608, 0.16160383554441587, 0.7293508318918092, 0.639287956058979, 2.9813656210899353, 3.0817660050732747, 5.004910341330937, 1.0631491861173084, 0.7626049646309444, 0.11285236331501178, 0.2823488978402955, 7.153107047080994, 16.862425088882446, 23.089110578809464, 26.356943913868495, 20.164983783449443, 20.300079345703125, 19.370493752615793, 23.760560171944753, 25.787622417722428, 23.245606592723302, 20.835656915392192, 15.0754474231175, 6.261564578328814, 0.8281275087169239, 0.28434113093784874, 0.0752435556745955, 0.42976049493466106, 0.46919627168348854, 2.0498319268226624, 5.934036919048854, 1.3934985739844186, 0.47263134164469583, 0.8718051878469331, 0.40416088859949795, 0.3828105671065194, 0.433063983385052, 2.6244442590645383, 35.009724957602366, 86.5839900970459, 72.27847603389195, 34.00828456878662, 20.204757009233745, 24.292022671018326, 41.0178496497018, 68.36190155574253, 59.798892974853516, 23.542332887649536, 3.617731588227408, 0.060546446458569596, 0.06070938307259764, 0.23093969215239796, 0.0673427414149046, 0.08545945677906275, 0.10037284224693264, 0.034394638147205114, 0.06389169195400816, 0.05459061211773327, 0.020231999091005752, 0.016076966155586497, 0.1264326378170933, 0.039294902700930834, 0.019534695793741515, 0.04893353674560785, 0.010908698929207665, 0.08760893358183758, 0.006687357855428542, 0.017977496941706965, 0.025274214866970266, 0.012012065571200634, 0.024111741887671605, 0.0187942071352154, 0.023027064644598534, 0.04974799250651683, 0.02570527289727969, 0.04204758017190865, 0.017480164699788605, 0.098448781562703, 0.056273460388183594, 0.039397517551801035, 0.07891027070581913, 0.034200434639517746, 0.050028831365385225, 0.07353583909571171, 0.02836999696280275, 0.040263938917113204, 0.05385755681033645, 0.026771071599796414, 0.02334873774088919, 0.07968728829707418, 0.04580647757809077, 0.19721879517393454, 0.1360472754708358, 0.10867844335734844, 0.1069137773343495, 0.13189321623316833, 0.13200563591505798, 0.09499400694455419, 0.08239030039736203, 0.25414653973920004, 0.11840920549418245, 0.08878842421940394, 0.09159597821001496, 0.3167365368987833, 0.21770285815000534, 0.18915366008877754, 0.1423302654709135, 0.08113832864910364, 0.09161286016127893, 0.15884750416236265, 0.14226500397281988, 0.1126473236030766, 0.06699695996940136, 0.13351795476462158, 0.14386953573141778, 0.10115126440567629, 0.12162855560226099, 0.1780638601630926, 0.1277557403913566, 0.06695920628096376, 0.15375081050608838, 0.1400233685438122, 0.17173504190785543, 0.13228797433631762, 0.09099160028355462, 0.2075856974614518, 0.19785269615905626, 0.1358251366764307, 0.18601512350142002, 0.12471842765808105, 0.15621556181992802, 0.10337020962366036, 0.11843151572559561, 0.11202752257564239, 0.16471590926604612, 0.35189659308109966, 0.16201668339116232, 0.2899096507046904, 0.254124962325607, 0.17944672810179846, 5.510888150760105, 30.828629084995814, 74.21476527622768, 91.68124416896275, 92.77322305951799, 75.96683692932129, 54.007743154253276, 32.016767569950645, 52.6049713407244, 74.84691933223179, 84.04795319693429, 61.369206701006206, 10.982345274516515, 0.7322679896439824, 1.3516293806689126, 0.9082372529166085, 1.1450552025011607, 3.835049092769623, 5.664059017385755, 6.660108472619738, 8.808617847306387, 4.13524774994169, 1.1355090290307999, 0.9603978140013558, 0.19491351316017763, 0.26322045283658163, 0.11040543711611203, 0.12167495382683617, 2.1530159328665053, 2.4647173328059058, 0.4175369579877172, 0.47860342689922875, 1.001590209347861, 0.772313117980957, 0.7854416306529726, 0.6054767732109342, 0.14215140363999776, 0.24107068138463156, 0.5034128927758762, 0.4037984423339367, 3.756425883088793, 6.384091717856271, 9.990202443940298, 1.0808687210083008, 0.5651347722326006, 0.293153672346047, 0.1119717877092106, 1.793729794876916, 5.486061368669782, 8.542942183358328, 10.59752537522997, 6.639225227492196, 7.290699618203299, 6.9933041249002725, 9.731211815561567, 11.520427669797625, 9.621098501341683, 7.2963398184095105, 5.314777851104736, 1.8583810457161494, 0.17172829726977007, 0.6474264679210526, 0.2860292989228453, 0.38038659574730055, 0.44367371978504316, 2.3727985279900685, 9.24623189653669, 5.466996380261012, 2.382021827357156, 1.7692254526274545, 1.4753106811216898, 0.7407382779887745, 1.1961651742458344, 17.593448536736624, 65.06609998430524, 86.55923366546631, 54.4153071131025, 26.366422993796213, 31.515576635088237, 47.76195532935006, 63.16443361554827, 81.6779921395438, 67.01106752668107, 28.553116628101893, 3.6515436938830783, 0.2061206589319876, 0.13539951880063328, 0.3491762919085366, 0.2301359267107078, 0.13253922228302273, 0.2238290658486741, 0.1304459688918931, 0.10813929300223078, 0.1379419488034078, 0.10455868406487362, 0.11837420665792056, 0.22873640752264432, 0.09582032689026423, 0.17650682585580008, 0.11681512317487172, 0.11005721294454165, 0.13694040397448198, 0.09460793408964362, 0.06614927974130426, 0.10349310588623796, 0.12837668135762215, 0.09502312966755458, 0.08826049004814454, 0.16659418919256755, 0.21793137517358574, 0.12623933676098073, 0.17145509192986147, 0.13160329179040023, 0.1601161610867296, 0.18889040207224234, 0.2284789170537676, 0.17010506508605822, 0.20614146281565937, 0.07656959630548954, 0.15524145694715635, 0.09089528223765747, 0.08001080022326537, 0.07691093334662062, 0.10778169147670269, 0.150876074763281, 0.14068905210920743, 0.10206286263253007], [0.03893997121070113, 0.03749532944389752, 0.01643234208625342, 0.023642541707626412, 0.05012559724439468, 0.03481857664883137, 0.035781472123094966, 0.005702221275506807, 0.07653972719396863, 0.03958326651315604, 0.037372192301388295, 0.021107933517279368, 0.05914843361824751, 0.02870820595749787, 0.016964391572400928, 0.02484913303383759, 0.04420892794483474, 0.06298305892518588, 0.025353476238836135, 0.07847416267863341, 0.03903214340763433, 0.041598742827773094, 0.03401509958452412, 0.03225210275767105, 0.04165621135117752, 0.015274603585047382, 0.09429490552949053, 0.07433328737637826, 0.05425942935315626, 0.02649577976470547, 0.051406885098133764, 0.013690198023271347, 0.013921278212884707, 0.03037400942827974, 0.03820221365562507, 0.07786061774407114, 0.05996819891567741, 0.04218614720074194, 0.02349826311027365, 0.05833635612257889, 0.034139169712683985, 0.04665865310068641, 0.03775686398148537, 0.07126440240868501, 0.0802612474986485, 0.058769370030079565, 0.05167714898873653, 0.03856626126383032, 0.09860341290810279, 0.1362073825938361, 0.12460333454821791, 3.2366333178111484, 19.534733533859253, 44.29397739682879, 66.6264430454799, 69.01244054521833, 56.260991845812114, 33.029832295009065, 31.820463589259557, 28.883562530790055, 49.206451075417654, 80.88370186941964, 55.06759010042463, 18.96218981061663, 1.6514387215886797, 0.4249394493443625, 0.44954573469502584, 0.17369648308626243, 3.2443136828286305, 2.7309516753469194, 2.5882897419588904, 0.7255901736872536, 1.6986613933529173, 0.09474807192704507, 0.12352902362389223, 0.21013926900923252, 0.25857091375759667, 0.3779782306935106, 0.17213586611407145, 0.3311348871460983, 0.10603354778140783, 0.43921322056225365, 0.3210098147392273, 0.4226806605500834, 0.1533053522663457, 0.044670341935540946, 0.14050173573195934, 0.9989819207361766, 1.5078160911798477, 3.694925206048148, 2.6045365844454085, 2.69034965974944, 0.9315411852938789, 0.38078628001468523, 0.16068820681955132, 0.12792152006711277, 0.05905206807489906, 0.1438070290854999, 0.3740560811545168, 0.20638243774218218, 0.049103777789111645, 0.0914329940985356, 0.08643124106207065, 0.015805971143501144, 0.08404242460216794, 0.1180364726377385, 0.06335061455943755, 0.18461763991841249, 0.14834014512598515, 0.0133599728412394, 0.37423904133694513, 0.11856719558792454, 0.964070588350296, 1.9862569953714098, 3.7963597859655107, 1.6604992811168944, 0.061637021867292266, 0.15054024064115115, 0.344461124922548, 3.7582471796444485, 19.056450809751237, 47.77555295399257, 55.89229610988072, 33.2598489352635, 14.190982563155037, 20.731086526598247, 38.98168352672032, 59.85923113141741, 60.75085871560233, 48.116296086992534, 17.55437707901001, 3.313392238957541, 0.11502185011548655, 0.037913853236074956, 0.11504314254437174, 0.017302575122032846, 0.11728988055671964, 0.11491366449211325, 0.007861836663713413, 0.027625973136829476, 0.11967864951917104, 0.02650449554702001, 0.05076243628614715, 0.023875487868541052, 0.0145150209510965, 0.03282144792111857, 0.004335527067139212, 0.037535458004900386, 0.021080844702997377, 0.008524149606403495, 0.06416881922632456, 0.03536042418064816, 0.03110102577401059, 0.018109967333397696, 0.021786851908213327, 0.042878693967525444, 0.03373308346739837, 0.006136745347508362, 0.018473909768675054, 0.01999558731248336, 0.02904655405187181, 0.024716608359345367, 0.0239909304239388, 0.00847549016387867, 0.051272511415715726, 0.010685397295414336, 0.025629215907039385, 0.03604669789118426, 0.10474410054406949, 0.04772913369483181, 0.005903514201885888, 0.0304176561933543, 0.012060414583954428, 0.043199233910334964, 0.00987634776226644, 0.042423301975109746, 0.05536808093477573, 0.050154770857521465, 0.049086919586573324, 0.04420698054933122, 0.03067976070035781, 0.03202777568783079, 0.026845954724454453, 0.039616616509322605, 0.01890098479842501, 0.07484199186520916, 0.025698116049170494, 0.02007444156333804, 0.028430825930887034, 0.06421112588473729, 0.0487777858174273, 0.030364482796617916, 0.02103997653882418, 0.01428471938041704, 0.025677788836349334, 0.02537660071227167, 0.02246230637787708, 0.051975938491523266, 0.04902254357667906, 0.008001806563697755, 0.023694675249446715, 0.014511076966300607, 0.016481846304876462, 0.02948592583249722, 0.02245265252089926, 0.07067078604762043, 0.08562292265040533, 0.05093515058979392, 0.014320211850904992, 0.04426978575065732, 0.04664885505501713, 0.03760055326191442, 0.0367482657810407, 0.011846619225772364, 0.05917825523231711, 0.0615414162831647, 0.05915427580475807, 0.04139252585758056, 0.02170463721267879, 0.0668795123430235, 0.06936001923999616, 0.03866407208676849, 0.14249022331620964, 0.037229906900652816, 0.05845380374895675, 0.06203367986849376, 0.09435414163661854, 5.663630400385175, 26.156003747667583, 63.824547222682405, 83.05229718344552, 64.00080912453788, 35.82488414219448, 25.65125186102731, 31.416776725224086, 43.146058559417725, 91.88339505876813, 94.52541283198765, 54.76806715556553, 7.902372121810913, 0.7186381753001894, 0.1409819892474583, 0.3666694132345063, 0.3883355249251638, 0.933610988514764, 1.2563737034797668, 1.192686298063823, 2.7979496802602495, 2.8261780398232594, 0.5537518858909607, 0.912161790898868, 0.7583642836127962, 0.4791384924735342, 1.0251959541014262, 1.3139684072562625, 0.43228570371866226, 0.19355155767074653, 1.448798309479441, 1.7612813817603248, 0.21490160774971756, 0.4466335709605898, 0.23098580539226532, 0.5896519795060158, 1.426981617297445, 2.722784285034452, 2.4034693964890073, 5.338403029101236, 5.2334040233067105, 4.541364312171936, 1.2805757990905215, 0.8659485621111733, 0.6943321824073792, 0.26825178999985966, 0.31109169551304405, 0.4340790446315493, 0.4143962093761989, 0.17738295027187892, 0.27810048152293476, 0.07159932050853968, 0.3526030566011156, 0.20187389824007237, 0.5457280735884393, 0.10652133303561381, 0.25466912026916233, 0.27169904645000187, 0.05254205043560692, 0.7733462825417519, 0.27718131084527287, 0.4750636454139437, 1.17835824404444, 1.4971878443445479, 0.48031154381377356, 0.4705536131347929, 0.18653967178293637, 0.47664425202778404, 0.35998239634292467, 4.932489267417362, 34.110565526144846, 75.21815463474819, 65.28860214778355, 32.20854479925973, 18.096428632736206, 22.36187216213771, 45.42531435830252, 66.46181242806571, 62.57768603733608, 27.652388640812465, 5.596789164202554, 0.24470141370381626, 0.07795194855758122, 0.04138073291895645, 0.07109941661890064, 0.09159813595137425, 0.045437500412975035, 0.06176825053989887, 0.15878307047699178, 0.018648600305563638, 0.031002034300139973, 0.04563624671261225, 0.01838695550603526, 0.009364448221666473, 0.04230814779709492, 0.029647311994007657, 0.013966226917026299, 0.08592007349112205, 0.026207967262182916, 0.04730176519868629, 0.0275852729100734, 0.027585466292553713, 0.032824084029666016, 0.030208894716841832, 0.04205181083774992, 0.04247095548946943, 0.01840971696323582, 0.029980245378932784, 0.011061160658885325, 0.006134554951651288, 0.02364166470111481, 0.04321676725521684, 0.024883980896057825, 0.0477557967283896, 0.012915488299248474, 0.009760800882109573, 0.01954762188584677, 0.042205020652285645, 0.02525932271964848, 0.036566984972783496, 0.025176712777465582, 0.027946977876126766, 0.010726619145966001, 0.02598612871952355, 0.02474095080313938, 0.09649285008864743, 0.10355581609266144, 0.09008853124188525, 0.134141474163958, 0.11859816392617566, 0.10252623419676508, 0.16619682551494666, 0.14271609405321733, 0.13914303721061774, 0.23637866601347923, 0.1390692126005888, 0.1513190767062562, 0.1252191322190421, 0.19153890066913196, 0.18021985090204648, 0.2798736292336668, 0.14252755631293568, 0.09410944833819355, 0.12657162893031323, 0.13535370411617414, 0.12100951453404767, 0.10098205812807594, 0.1368238859410797, 0.08006140536495618, 0.1554220151156187, 0.0854585271860872, 0.1437039596161672, 0.16910284172211373, 0.10183994352285351, 0.07662337699106761, 0.1676375317786421, 0.13348710856267385, 0.1441519284354789, 0.11220062364424978, 0.11140716514949288, 0.11413625335054738, 0.1714027225971222, 0.11689728019492966, 0.16681978851556778, 0.20488945714065007, 0.13204370172960417, 0.13363103941082954, 0.1127779483795166, 0.18023969126599176, 0.26381104971681324, 0.10103050552840744, 0.17809994465538434, 0.14927929187459604, 0.17853598482906818, 0.13873278136764253, 0.20655656339866774, 5.024591113839831, 31.70170497894287, 73.7597346987043, 93.33425535474504, 86.311217716762, 71.95151465279716, 49.53198112760271, 43.45364488874163, 37.94426189150129, 67.10083130427769, 101.1318712234497, 68.24377523149762, 26.740081480571202, 2.9270899849278584, 0.5508047097495624, 0.5668002228651727, 1.0874842745917184, 6.141637367861612, 10.947672026497976, 9.942319801875524, 4.336028107575007, 6.784687502043588, 0.5840540656021663, 1.2043403812817164, 0.494696811905929, 0.523102839078222, 1.6412579821688789, 1.0506842264107294, 0.30484830481665476, 0.12542886739330633, 1.1190601459571292, 0.9532444264207567, 0.8418103573577744, 0.28608529163258417, 0.19400308201355593, 0.6680486670562199, 4.9686159917286465, 7.9449411290032526, 11.095217892101832, 12.354497245379857, 11.283983077321734, 8.209789957318987, 0.9129760329212461, 0.40562345726149424, 0.44379333193813053, 0.14833703743559973, 0.39627093768545557, 0.41717158045087543, 0.38648184867841856, 0.3369229808449745, 0.2120051181742123, 0.16270329297653266, 0.5104687884449959, 0.2988782008843762, 0.37019320843475206, 0.1505938856197255, 0.23971659690141678, 0.2054819403482335, 0.1316935640892812, 0.7352894789406231, 0.6224563792347908, 3.5955503327505927, 6.350416839122772, 6.491702812058585, 4.037607320717402, 1.5699467744146074, 0.5182379601257188, 0.7197474986314774, 5.970172762870789, 29.16862801143101, 64.18351895468575, 77.15087250300816, 45.357333183288574, 23.82863862173898, 30.791866166251047, 53.57382467814854, 74.90222004481724, 78.45666830880302, 74.28445570809501, 34.26468004499163, 6.390728984560285, 0.24077880276100977, 0.1315333212592772, 0.2667498934481825, 0.15533860959112644, 0.327464256967817, 0.3755261408431189, 0.10396858251520566, 0.18144452518650464, 0.2394422244812761, 0.1722803126488413, 0.1288765716765608, 0.15817010908254556, 0.08433425572833844, 0.12444653867610864, 0.07076405068593365, 0.1965415765132223, 0.15514783268528326, 0.10249897744506598, 0.2528296118336064, 0.08911666553467512, 0.11120680732918636, 0.12420454594705786, 0.18848193756171636, 0.12048825036202158, 0.12476621009409428, 0.08072993199207953, 0.11691385002008506, 0.11159497685730457, 0.0993786391669086, 0.13815207752798284, 0.10848876567823545, 0.15238892287015915, 0.13624525841857704, 0.13949013501405716, 0.0919495356668319, 0.11997354083827563, 0.18934370417680058, 0.15024959695126328, 0.1327737918389695, 0.15861684296812328, 0.13973562898380415, 0.08669472299516201, 0.20158956492585794, 0.11206965281495027], [0.014839845842548778, 0.1752292394105877, 0.041097247773515325, 0.016194274682285528, 0.03453203131045614, 0.010649069378684674, 0.025783792969637682, 0.05504928482696414, 0.02198548285689737, 0.04387703950383833, 0.023006623777161752, 0.03890752027343426, 0.040782831609249115, 0.031236390117555857, 0.04472474008798599, 0.015035954337300999, 0.025779319727527242, 0.06261282986296074, 0.05246320805911507, 0.02485185395926237, 0.015413545504478472, 0.025410408719575832, 0.03902649799627917, 0.06816627258168799, 0.02837988661069955, 0.04054148009579096, 0.043086203546928506, 0.060056903798665316, 0.015901905817112753, 0.051493164218430004, 0.06255275237240962, 0.05634853010997176, 0.011064558422991207, 0.03434807707422546, 0.061918566402580054, 0.02050881423721356, 0.06097258680633136, 0.05492134026384779, 0.03263011122388499, 0.060490379109978676, 0.024396002259371535, 0.013280061772093177, 0.018715934728139212, 0.02236389335510986, 0.041027205996215343, 0.03352127197597708, 0.03620861670268433, 0.05104211824280875, 0.11118900935564723, 0.04592113981821707, 0.11039938458374568, 0.17527491838804313, 0.1286583819559642, 3.849202573299408, 30.562520027160645, 57.65574196406773, 65.55576038360596, 63.18412481035505, 58.54980836595808, 54.937311376844136, 15.060672078813825, 24.626239708491735, 41.624715736934114, 50.06225374766758, 62.99821880885533, 33.40196738924299, 12.235286133629934, 1.641423544713429, 0.36268288429294315, 0.06383486464619637, 0.6494787377970559, 1.568806944148881, 1.0528847426176071, 0.4582692523087774, 0.4132109172642231, 0.3664516849177224, 0.7184459599001067, 0.5024658207382474, 0.08067190367728472, 1.638644156711442, 1.3243038526603153, 1.4419026566403252, 3.0025789056505476, 0.5008253401943615, 1.1025385239294596, 1.0591140197856086, 0.10869723877736501, 1.0127641069037574, 1.1992290041276386, 0.1699492870164769, 2.427183381148747, 2.7566760778427124, 2.7047395961625234, 1.754507105265345, 2.4719927481242587, 0.4236481429210731, 0.5228927646364484, 1.0556965917348862, 0.5245134319577898, 0.28440494037100245, 0.15151387053940976, 0.10757835488766432, 0.028295990844656314, 0.18123347365430423, 0.25353987514972687, 0.7765007104192461, 1.1541620109762465, 0.637544066778251, 0.3478494573916708, 0.07453880884817668, 0.25466928311756676, 1.2736293375492096, 0.8168600276112556, 0.5729812426226479, 0.6052664816379547, 0.32571849493043764, 2.727855818612235, 15.361754894256592, 38.00660112925938, 57.32458734512329, 58.104856150490896, 28.38326791354588, 16.442653145108903, 22.58121463230678, 47.290950843266074, 55.22627305984497, 60.046123777117046, 47.469196455819265, 26.71461112158639, 6.277076865945544, 0.1337202667657818, 0.15743825478213175, 0.05238990592105048, 0.14945655236286776, 0.03173606330528855, 0.04270438849925995, 0.1536058618554047, 0.031468058936297894, 0.06728872324207, 0.06346611479031188, 0.0148534402916474, 0.065799895274852, 0.03987694664725235, 0.03910030225025756, 0.01736676283845944, 0.03696325620902436, 0.017756286043939844, 0.02439650098261024, 0.02458241448870727, 0.015912996471992562, 0.026415166411814944, 0.040072167957467694, 0.02414959396368691, 0.050470483023673296, 0.029687986775700535, 0.0421198475440698, 0.06075130296604974, 0.03956748378862228, 0.040767079418791194, 0.0322217043888356, 0.016905102878808975, 0.026020676329998032, 0.06712203432938882, 0.017667818648208464, 0.027999845932104757, 0.025836822177682604, 0.06608918868005276, 0.039961831378085275, 0.04805017914623022, 0.016822316517521228, 0.007855907115819198, 0.06424187030643225, 0.12739651038178376, 0.11246669758111238, 0.02423064666800201, 0.015100922368999039, 0.037610005254724195, 0.07632440767650094, 0.012479011318646371, 0.07572868107152836, 0.05231866992211767, 0.05902867218745606, 0.0068056455929763615, 0.06020825103457485, 0.019126348330506256, 0.027876598527655005, 0.02940300546054329, 0.026082721572103243, 0.039349942068968496, 0.03310010189722691, 0.052476493774780204, 0.02189370590661253, 0.06958298584712402, 0.021200404269620776, 0.06023250187614134, 0.04913632372128112, 0.09290354233235121, 0.03433493724358933, 0.06783717631229333, 0.05970977206847497, 0.03744432735922081, 0.005318681476637721, 0.011897129372560551, 0.025346081903470413, 0.054213974292257, 0.06650324431913239, 0.01939159445464611, 0.044495446141809225, 0.03084086187716041, 0.06594765984586307, 0.04420029019404735, 0.036440987805170674, 0.06292628590017557, 0.03652401674272759, 0.043951203381376605, 0.02804997270660741, 0.0674597072814192, 0.02949290456516402, 0.04057624823014651, 0.03315069007554224, 0.046486193247671635, 0.010678921526830112, 0.06425485746668917, 0.15260101934628828, 0.05070680659264326, 0.05614182798724089, 0.06111691799014807, 0.19423978216946125, 0.1110181270965508, 6.749597796372004, 39.80525697980608, 71.61558314732143, 80.55945723397392, 59.48866980416434, 45.56522328513009, 32.4508284841265, 16.156951904296875, 52.440997328077046, 73.64527702331543, 84.73685319083077, 63.18663311004639, 22.249794244766235, 2.3977306187152863, 0.5497243191514696, 0.2957815299076693, 0.09854726413530962, 0.2322430493576186, 0.46271235389368875, 0.4561431035399437, 0.4898458293506077, 0.7679752707481384, 0.6595134564808437, 0.5938062423041889, 0.35378824014748844, 0.2625458261796406, 0.43376510004912106, 0.5669846215418407, 1.1976786873170306, 0.6323175015194076, 0.4933302423783711, 1.0999532512256076, 2.4917738352503096, 0.5267771876284054, 1.811965450644493, 2.932231217622757, 4.007952409131186, 3.174574613571167, 4.285583317279816, 3.5580515563488007, 3.2866110588823045, 1.5836810831512724, 3.761731266975403, 2.902679660490581, 3.455672021423067, 1.2401092733655656, 1.6856074652501514, 0.28160799188273294, 0.9358838094132287, 0.6891876927443913, 0.15694943815469742, 0.7832192384770938, 1.1557194931166512, 0.9138497688940593, 0.19986495961036, 0.3995394951530865, 0.10568490970347609, 1.107204673545701, 0.49101073827062336, 0.4311968450035368, 0.826038652232715, 0.46797859988042284, 0.42729741281696726, 1.6470071822404861, 4.822223092828478, 15.0338294506073, 47.567450932094026, 78.12701797485352, 59.1671974999564, 29.780510698046, 16.693406684058054, 20.991600547518047, 39.916615758623394, 63.91919558388846, 62.682812282017295, 39.09075287410191, 9.394887736865453, 0.10179989638605288, 0.12346496991813183, 0.05633862689137459, 0.17083215607064112, 0.04012810977708016, 0.041751267321939976, 0.1743712861623083, 0.020209621006090726, 0.10839779448828527, 0.033348289650997946, 0.02333476161584258, 0.10166144810084786, 0.06244650735918965, 0.044876406235354285, 0.04287861254332321, 0.014366506598889828, 0.036508956657988687, 0.031425148381718566, 0.014091049370888089, 0.043753929502729855, 0.044429333082267215, 0.017809179544981037, 0.013948155833142144, 0.01932433806359768, 0.0085182989382052, 0.0038879301698346224, 0.019286748919902102, 0.003051906113146937, 0.03360922707776938, 0.018993837226714407, 0.0374633093763675, 0.020402888135452355, 0.10607109790933983, 0.038309425581246614, 0.038089183292218616, 0.028150370444304178, 0.03924330011276262, 0.022039409427504455, 0.06109610732112612, 0.04667640696944935, 0.02774236903392843, 0.039135195913591554, 0.0570239947576608, 0.07628911028483085, 0.037685244610267024, 0.012366312589230282, 0.14342554312731537, 0.20692918768950871, 0.08967717617217984, 0.1575239673256874, 0.16248931017305168, 0.12853256799280643, 0.10685254633426666, 0.11899704752223832, 0.1764851263059037, 0.14877655170857906, 0.08388248032757215, 0.09981095418334007, 0.15077753790787288, 0.10359703709504434, 0.19241278591964925, 0.15426826131130966, 0.1928298949663128, 0.12535639985331468, 0.13884692452847958, 0.14213224181107112, 0.23523096474153654, 0.11440320259758405, 0.12197398420955453, 0.24949952481048449, 0.1115097664296627, 0.10142197273671627, 0.07141634675541095, 0.14750671413327965, 0.1345563033329589, 0.14636609676693166, 0.15032420866191387, 0.18953562102147511, 0.24043459551674978, 0.1712199795458998, 0.15108705844197953, 0.06095500596399818, 0.1635889575949737, 0.1116673086902925, 0.1406835831169571, 0.16888139503342764, 0.13715399322765215, 0.06907263251819781, 0.10080033287938152, 0.15874645672738552, 0.184377004259399, 0.2833620591887406, 0.10824979243001767, 0.1642870751342603, 0.15863643905946187, 0.187348838363375, 0.3122852657522474, 0.24786979226129396, 0.22184173177395547, 7.182825795241764, 46.25061443873814, 81.61716760907854, 88.52683843885148, 75.19347463335309, 79.70821257999965, 78.59308229173932, 23.111369132995605, 36.51472214290074, 55.13857984542847, 69.334885597229, 80.77752644675118, 43.748363154275076, 17.994083404541016, 4.419777350766318, 1.1590887180396487, 0.13585594216627733, 1.2397917189768382, 4.117486417293549, 3.1742521737303053, 2.338603837149484, 3.3630751158509935, 2.032207169703075, 2.6494616823537007, 1.2628223917313983, 0.7866015998380524, 2.5077056203569685, 1.27639938890934, 5.1427903941699435, 7.541441866329738, 1.8444477362292153, 4.96369970696313, 4.988520409379687, 8.186324153627668, 2.59661585518292, 6.618479209286826, 7.571191447121756, 5.4697257195200235, 8.531021680150713, 7.144632850374494, 11.499530094010488, 7.92153525352478, 5.8363374301365445, 4.055703903947558, 3.4197858784879958, 1.2393778668982642, 1.0220765386308943, 0.29277203711015837, 0.6852480641433171, 0.6246886508805412, 0.3240053839981556, 0.9874597447259086, 2.3612562673432484, 3.019079791648047, 1.7053736788885934, 0.7916864327022007, 0.44248937762209345, 1.483038380742073, 1.49114171734878, 1.1673539259604044, 1.2080983796289988, 0.8358098821980613, 1.3173201531171799, 7.382003290312631, 24.644494363239833, 53.69513675144741, 78.24638107844761, 78.8771732875279, 40.541303975241526, 25.4685628754752, 32.24903195244925, 64.13369342258999, 72.35717827933175, 79.86419269016811, 71.52064990997314, 47.0392210824149, 10.278946127210345, 0.24202092896614755, 0.32327044914875713, 0.1791131602866309, 0.36146545676248415, 0.142632322119815, 0.1189517756657941, 0.3965164045138018, 0.0982091569208673, 0.2313349795128618, 0.17393851652741432, 0.09806709204401289, 0.21904512255319528, 0.08628661132284574, 0.08137414670948472, 0.13350819743105344, 0.12544485367834568, 0.12255637081606047, 0.09234371701521532, 0.058632509516818185, 0.2036517821252346, 0.11575683924768652, 0.07043954809861523, 0.12642839018787655, 0.10500380303710699, 0.09844095126858779, 0.13209001852997712, 0.09086451067456178, 0.13968843008790696, 0.09606626869312354, 0.13535887455301626, 0.11254342632102114, 0.14313456016991818, 0.31232679209538866, 0.18853038496204785, 0.11552540452352592, 0.12641272959964617, 0.13056361329342636, 0.12183450455112116, 0.0809839755030615, 0.17493704866085732, 0.09082278755626508, 0.1542470095945256, 0.1939753299312932, 0.19178584670381887, 0.2403717903154237, 0.05874038301408291], [0.026413040900869027, 0.03496447524854115, 0.02138713880309037, 0.0120095846775387, 0.011971414538233407, 0.01076893089339137, 0.033498150895216634, 0.04163245584017464, 0.027160978177562356, 0.035391063429415226, 0.0163782102588032, 0.03407688359064715, 0.021898262269262756, 0.1261132920959166, 0.024619133411241428, 0.08622888156345912, 0.046865416291568956, 0.11027460199381624, 0.046389345944459946, 0.03653993517426508, 0.07353994423257453, 0.020976587797382047, 0.09459065180271864, 0.05556833018947925, 0.018873334496415088, 0.0353469959726291, 0.06964922443564449, 0.03155973919534257, 0.05278381246275135, 0.05533493449911475, 0.04891385244471686, 0.054406108268137486, 0.03321841465575354, 0.026941655303484628, 0.06222789016153131, 0.019096217983003174, 0.057986496681613584, 0.09247135623757329, 0.01865926178704415, 0.043286259419151714, 0.06116305837141616, 0.06899626340184893, 0.06533813862396137, 0.0772213020495006, 0.07601664454809257, 0.05743454915604421, 0.1105805534337248, 0.11268027326358215, 0.060869184854839525, 0.055133721724684746, 0.0813853425372924, 0.06911940393703324, 0.09820330794900656, 0.091937132046691, 0.28501885171447483, 5.342277518340519, 39.990318775177, 69.16772583552769, 59.97370965140206, 55.88527495520455, 70.17930712018693, 37.66134514127459, 26.771397011620657, 14.821040868759155, 34.43612684522356, 54.29714952196394, 52.10105671201433, 66.42031778608049, 50.00008821487427, 28.599525383540563, 17.833093643188477, 11.448348794664655, 4.317500301769801, 1.5513617545366287, 0.23753016708152636, 0.08821274832423244, 0.16011388120906694, 0.0641467532675181, 0.21921642550400325, 0.48247856753213064, 1.2550931721925735, 1.0166955930846078, 0.4692183647836958, 0.29759281128644943, 1.458164046917643, 0.3565815788294588, 0.3546564392745495, 3.5436978808471133, 4.10457101890019, 1.5463328872408186, 2.7378175812108174, 1.9034503187452043, 1.7190394827297755, 1.055437445640564, 0.5709746788655008, 1.5891094718660628, 2.474913162844522, 4.063210564000266, 1.8416402297360557, 4.377740749291011, 1.8851455066885268, 1.1138083934783936, 1.5402071816580636, 0.40668085909315516, 0.904179504939488, 0.8823471793106624, 1.0475366924490248, 1.0482680989163262, 0.495859332382679, 0.5531090146728924, 0.4666038879326412, 0.8921039700508118, 4.318119994231632, 8.33337322303227, 19.383443457739695, 30.664394514901296, 54.139491421835764, 60.709850447518484, 44.12800925118582, 23.694444588252477, 10.837237358093262, 24.329499517168315, 51.22349575587681, 61.30689525604248, 54.666890961783274, 45.344864640917095, 26.22278114727565, 8.904344916343689, 0.2130610000874315, 0.019839744782075286, 0.05153816805354186, 0.20912043510803155, 0.03981470462999173, 0.04532193232859884, 0.059632201945143085, 0.02286859109465565, 0.04276070351313267, 0.03718797343650034, 0.019499717313530188, 0.07378266977944545, 0.07146319959844862, 0.027906320057809353, 0.020942381150754433, 0.016511991919417466, 0.007903608127630182, 0.013210512780850487, 0.009161345727209533, 0.015576388819941452, 0.07021118035273892, 0.006970599152347339, 0.029390096331813505, 0.03372869334582772, 0.04778443769152675, 0.006529131546683077, 0.011281718466696995, 0.027404333065663065, 0.011491647023441536, 0.04292950266972184, 0.0852526935881802, 0.09140169327812535, 0.05040990002453327, 0.04090019102607455, 0.06968005706689187, 0.00910195694970233, 0.0678733354434371, 0.043176859218095026, 0.018238341069913337, 0.03096505074894854, 0.04865826526656747, 0.051089025368647914, 0.01279636299503701, 0.015842082777193615, 0.052713689261249135, 0.05890417458223445, 0.033221915896449766, 0.08280485815235547, 0.027397293264844587, 0.05945361152823482, 0.04844487278855272, 0.07178592442401818, 0.027471713289352398, 0.01921012535292123, 0.03962946456990071, 0.05149601745818343, 0.012620488414540887, 0.010717073006422391, 0.005775286774483642, 0.012562750173466546, 0.0432453505428774, 0.018326894978859594, 0.029207963962107897, 0.09873726072588138, 0.04138418666220137, 0.03521337207140667, 0.020821944577619433, 0.05492781688060079, 0.08640722092241049, 0.05025657146636929, 0.019213155011779497, 0.0638360045850277, 0.058955661819449494, 0.005207146010694227, 0.022968140663579106, 0.024988544838769094, 0.01846504640499396, 0.060619158271167956, 0.030243903731129, 0.04365896513419492, 0.01889399758407048, 0.009919842705130577, 0.0368321055679449, 0.028504048341086934, 0.04742594728512423, 0.029595899395644665, 0.05785547835486276, 0.010167265410668083, 0.04581226887447493, 0.04037123565961208, 0.055805603707475324, 0.047483066362994056, 0.05606289740119662, 0.018563301668369343, 0.032799649983644485, 0.0994664483836719, 0.005789950340321022, 0.1396644642310483, 0.06409375968256167, 0.05812380502798727, 0.03074672192867313, 0.17204373462923936, 0.5862894313676017, 8.97255277633667, 46.83857100350516, 82.34371989113944, 68.16810934884208, 59.30533463614327, 40.74540383475167, 12.737389888082232, 18.346291065216064, 20.678485189165386, 66.97358894348145, 85.58476270948137, 86.86639962877545, 63.69978536878313, 28.01133952822004, 10.799579858779907, 4.2826672451836725, 1.0543846849884306, 0.7241275236010551, 1.3515122383832932, 0.3180411968912397, 0.1135681906182851, 0.3226979013000216, 0.2647105428789343, 0.23189601940768106, 0.8382110276392528, 0.667086232985769, 0.3728845497327191, 0.30758033107434, 0.9727121932165963, 1.128073805144855, 0.850350561950888, 0.14538402589304106, 0.559053795678275, 1.8365198416369302, 1.2400580304009574, 1.3573260349886758, 1.5151121339627673, 0.4476906470954418, 1.4962547229869025, 2.789338690893991, 2.8536468744277954, 0.5351291937487466, 0.8528274861829621, 1.4413593943629945, 2.0734510251453946, 0.4387172114636217, 0.35701057580964907, 0.2987510162804808, 0.8894551321864128, 1.2673028941665376, 0.6423261101756776, 0.5012891324503082, 0.9098973838346345, 0.3089142223553998, 0.1450756045856646, 0.11449852319700377, 0.4367652019219739, 1.4911661446094513, 4.004504365580423, 4.24048125743866, 13.312505313328334, 31.493873936789377, 56.428193296704976, 73.75261974334717, 51.64372280665806, 28.564668008259364, 17.63425009591239, 26.73844517980303, 45.14344678606306, 58.45131070273263, 63.71906661987305, 40.34597274235317, 14.036166276250567, 0.6261506495731217, 0.09489238954016141, 0.04809202779350536, 0.0576486201690776, 0.04130726793248739, 0.0670977495610714, 0.05616906099021435, 0.060467478553099294, 0.0035538532413608792, 0.028190884073930125, 0.05409950543461101, 0.06257305414016757, 0.02708094327577523, 0.005644448259512761, 0.0541115087190909, 0.03228378355769174, 0.01689750837561275, 0.028105258043589335, 0.006629569572396576, 0.008024378879261869, 0.02531655545213393, 0.025948989105277827, 0.004097758218579526, 0.011371620115824044, 0.008362279140523501, 0.025797804717772772, 0.03768838283472827, 0.016845646247799908, 0.011474044128720249, 0.0546421095329736, 0.04833958450970905, 0.022341913909518292, 0.04157443431073001, 0.02232223978665258, 0.019334399041586688, 0.06691854846264635, 0.028705132193863392, 0.08623538871428796, 0.01692572525436325, 0.044605334888079336, 0.04333907658500331, 0.07435960774975163, 0.030539392161050012, 0.014778884560135859, 0.011418185429647565, 0.019624347233080437, 0.0838504738307425, 0.0022674721341380583, 0.07581449539533683, 0.1709403552647148, 0.10897377572421517, 0.207676159750138, 0.08349519968032837, 0.11615101381071977, 0.17683478897171362, 0.23002765966313227, 0.11035900496478591, 0.11080721127135412, 0.10899565169321639, 0.1364381659243788, 0.1354898860944169, 0.27281841209956575, 0.09880220331251621, 0.19534435575561865, 0.14403694389121874, 0.20227920077741146, 0.24253949256879942, 0.182803942954966, 0.14900934350277695, 0.10656741913408041, 0.17024872452020645, 0.0985891433166606, 0.168554300442338, 0.07281580487532274, 0.1903423991586481, 0.10526353945689541, 0.13061195212815488, 0.15720838068851403, 0.15421639409448418, 0.12435841054788657, 0.08727348622466836, 0.16034982140575135, 0.12101457640528679, 0.11076802587402718, 0.16312923654913902, 0.14005770241575582, 0.10622259442295347, 0.14448325708508492, 0.19624201687318937, 0.10051696308489357, 0.18281820576105798, 0.15864954835602216, 0.09028755913355521, 0.13907818283353532, 0.22633542492985725, 0.1205210236034223, 0.1471798773854971, 0.2659784805561815, 0.2654350554304463, 0.15402530506253242, 0.2678785143154008, 0.31610064102070673, 0.8166279143520764, 9.255175965172903, 55.45339577538626, 93.95697375706264, 78.43805408477783, 71.98003700801304, 94.01788861410958, 56.6423020362854, 37.047412736075266, 22.319481202534266, 51.16782331466675, 72.83446393694196, 74.14540835789272, 81.95662879943848, 67.29386615753174, 38.511161940438406, 28.29859890256609, 17.28150568689619, 8.652292064258031, 3.3072995373180936, 0.5552891748292106, 0.1432030379240002, 0.7668136730790138, 0.9483157651765006, 1.819614440202713, 3.5210065841674805, 3.2364237861973897, 3.0496192957673753, 2.2784960567951202, 2.4501736674989973, 3.5618533066340854, 6.023513649191175, 1.8523081030164446, 8.890445913587298, 11.17981481552124, 11.690275515828814, 12.867385472570147, 14.004162873540606, 8.989574994359698, 7.115586340427399, 9.726012825965881, 14.372074331556048, 14.345124006271362, 18.27502339226859, 13.738647886684962, 13.075913940157209, 8.226709689412798, 3.7493031110082353, 6.554023376532963, 6.753891348838806, 7.838118655341012, 7.546177063669477, 6.676381153719766, 3.1335639570440565, 1.4462953295026506, 1.4537693113088608, 0.4246871428830283, 1.2642430812120438, 6.951499853815351, 16.828648158482142, 36.58193901606968, 56.94960348946707, 77.51987743377686, 82.7414903640747, 61.089465277535574, 36.12614761080061, 18.69200563430786, 36.216286591121126, 69.7047312600272, 84.25707312992641, 72.24688257489885, 74.13507638658795, 46.444118295397075, 17.16862177848816, 0.4887855776718685, 0.3003551544887679, 0.2192463217569249, 0.39113437331148554, 0.10624075880540268, 0.17132412110056194, 0.2153555748185941, 0.1647693778255156, 0.14703108822660788, 0.2113987792815481, 0.250409331704889, 0.1375625527330807, 0.17803803512028285, 0.13336314021476678, 0.13186668551393918, 0.1635138030563082, 0.07348233660949127, 0.11301614809781313, 0.12218910695186683, 0.15801468385117395, 0.14258410542138986, 0.12948812171816826, 0.11563220593546118, 0.07462722874645676, 0.08866332271801573, 0.2529315820762089, 0.1839998337839331, 0.19452313839324883, 0.04697661121774997, 0.23087213720594132, 0.20197632988648756, 0.14149295325790132, 0.07963670351143394, 0.11877564154565334, 0.14977025267268929, 0.19562670774757862, 0.12711552903056145, 0.23775392078927585, 0.10904446550245796, 0.1540358087846211, 0.09048221725970507, 0.25770407170057297, 0.08692016625510794, 0.07194715112979923, 0.09494385642132588, 0.1502776611596346, 0.10701284344707217, 0.16947047199521745], [0.010222992643580904, 0.04536175894151841, 0.06147571373730898, 0.045600932357566695, 0.02882997245926942, 0.020013081641601663, 0.04531054651098592, 0.009688681939483752, 0.031451936944254806, 0.04992681362533143, 0.03661790902593306, 0.011982384753147406, 0.01567934633099607, 0.04696979194081255, 0.04603216511064342, 0.059114377945661545, 0.008400602798376764, 0.01872685574926436, 0.018155230708154182, 0.022450406569987535, 0.03247833651091371, 0.06034889777324029, 0.06362989957311324, 0.024479411176538894, 0.03200209313737495, 0.08795197374586548, 0.11852893978357315, 0.04116118273564747, 0.05671157009367432, 0.040433820337057114, 0.02277422383693712, 0.10074911705617394, 0.06929061189293861, 0.04475592555744307, 0.023181270209274123, 0.04968920083982604, 0.05560798038329397, 0.043736837205610106, 0.02001684411828007, 0.053031287754752805, 0.01824352507745581, 0.05353009920301182, 0.03666718423898731, 0.043375870146389515, 0.03987435803615621, 0.0480463759574507, 0.05275256931781769, 0.04497541127992528, 0.042220006098172495, 0.01966729510708579, 0.035620547365397215, 0.0732679602556995, 0.01782958478932934, 0.14285907495234693, 0.08313007320144347, 0.22221871225961617, 0.2250046684805836, 15.070338760103498, 57.16944101878575, 70.57934270586286, 62.72971262250628, 69.33440617152623, 59.849065916878835, 53.57780947004046, 27.50864257131304, 20.209108318601334, 14.25155782699585, 32.2926527432033, 64.28043937683105, 62.53995731898716, 68.1054435457502, 63.331774030412944, 64.00479044233049, 58.244296073913574, 45.246137687138145, 27.645700999668666, 16.635892970221384, 7.864415849958148, 3.2381773378167833, 1.315067633986473, 0.30349381321242874, 0.10907562383051429, 0.4013504236936569, 0.2598043004316943, 0.37197702271597727, 0.09735431814832346, 0.058700770139694214, 0.11743839830160141, 0.31279715257031576, 0.05598086591011711, 0.6983157257948602, 0.3890525735914707, 0.4736297109297344, 1.322796310697283, 0.4970506770270211, 0.5673575443880898, 0.1773642905588661, 0.44442466806088177, 0.5700293981603214, 0.914973965712956, 0.5267906497631754, 0.7145886240260941, 0.38669219453419956, 0.6009982792394502, 0.4273049309849739, 0.4114689550229481, 0.33861606142350603, 2.211744930062975, 5.49240985086986, 13.754965731075831, 21.368675810950144, 35.90936034066336, 44.34580053601946, 38.92885289873396, 44.155753408159526, 34.18221535001482, 44.672331128801616, 45.09654991967337, 12.841973304748535, 25.146058763776505, 56.72485705784389, 58.78571360451834, 53.84437363488333, 51.68063511167254, 32.425693375723704, 4.872196708406721, 0.4765456201774733, 0.32405651839716093, 0.06311993979449783, 0.1522106852914606, 0.013114958086849322, 0.10132781243217842, 0.10341417190751859, 0.11731061658688954, 0.04936762613111308, 0.015117118999894177, 0.07788410862641675, 0.06598895548709802, 0.036657376015292745, 0.035763419698923826, 0.018599170725792646, 0.046718601669584, 0.04254389800397413, 0.03763239012498941, 0.07074459030159883, 0.050914132967591286, 0.035757821785019975, 0.06940239375191075, 0.03772212977388075, 0.011089851663980101, 0.06087958001132522, 0.06265544864748206, 0.042960019782185555, 0.013425131710911435, 0.012807166120702667, 0.05340899766555854, 0.022831147835989083, 0.050108321742819886, 0.05041067355445453, 0.036379495569105656, 0.04926470933215959, 0.10755599037344966, 0.015726680933896984, 0.04227972735783883, 0.016158317415309802, 0.038419965721134625, 0.01395747042261064, 0.08779282335724149, 0.010676001281743603, 0.017573809317712272, 0.01793827592129154, 0.048274133021810224, 0.037590005435049534, 0.0386547795496881, 0.06749841091888291, 0.09474887259836708, 0.04301242982702596, 0.04230401212615626, 0.09176099792655025, 0.056674566186432324, 0.04212005788992558, 0.12213368421154362, 0.08159844324524913, 0.02252156793006829, 0.05256506634343948, 0.10113392783594982, 0.00790025616463806, 0.03130751755088568, 0.04185414680146745, 0.02905576177207487, 0.0676189526649458, 0.026502631272056272, 0.01813212489443166, 0.018702830520591567, 0.050681487058422396, 0.007535337487102619, 0.006232412847956377, 0.04172800035615053, 0.023522593679704835, 0.013891538023017347, 0.01640716165171138, 0.05679545737802982, 0.0665519427774208, 0.019568637811711857, 0.03877693281642028, 0.0520180415894304, 0.020735653582960367, 0.11102428819452013, 0.03465673926153353, 0.013950641815816718, 0.043486376359526596, 0.05636693876502769, 0.049917069862463644, 0.03140788305816906, 0.02831876078354461, 0.028545774852058718, 0.08692116370158535, 0.023288968983771544, 0.018760142980941703, 0.05306799649926169, 0.1304472852498293, 0.0117371325115008, 0.05082533308970077, 0.08484957593360118, 0.06080899201333523, 0.011637531204282172, 0.10293036965387208, 0.08792870678007603, 0.06548126880079508, 0.05101103116092937, 0.0694641200825572, 0.3626896153603281, 0.6152521829519952, 22.736150775636943, 67.67559323992047, 78.80889333997453, 69.38123008183071, 65.30889088766915, 46.30840955461775, 24.962275436946324, 18.3893438407353, 26.258889198303223, 27.150897196360997, 59.625055994306294, 103.54327133723667, 93.31270204271588, 88.707839012146, 69.02112579345703, 52.48801578794207, 38.96585553033011, 22.641323498317174, 13.719912937709264, 3.5565830980028426, 0.48709428842578617, 0.8680155969091824, 1.632747307419777, 0.4207352192274162, 0.24182483234575816, 0.1639750168791839, 0.3784772796290261, 0.46727270632982254, 0.41324226558208466, 0.09044892154633999, 0.18592002003320626, 0.4566831631319863, 0.2588620324219976, 0.4766605368682316, 0.3393754506749766, 0.5759325985397611, 0.325545604207686, 0.7594573763864381, 0.42725805778588566, 0.3378271423280239, 0.19205769497369016, 0.2675527089408466, 0.883728622325829, 0.44341633788176943, 0.17913817108741828, 0.23823530067290577, 0.31450516091925756, 0.27498006182057516, 0.13647860661149025, 0.21686592591660364, 1.11772663465568, 1.1999051507030214, 2.2833917140960693, 3.8940353904451643, 10.36765898977007, 20.364256381988525, 29.336833477020264, 48.975419998168945, 45.94762086868286, 74.13395772661481, 61.04008443014962, 22.540491240365164, 12.514988473483495, 18.677565540586198, 41.54934515271868, 56.88368245533535, 65.62231717790876, 46.436211245400564, 13.266306740897042, 0.9970751830509731, 0.061341703071125915, 0.07588674580412251, 0.04003206314519048, 0.022706080261351805, 0.08910494044955287, 0.030077784787863493, 0.06665032356977463, 0.026259462981085693, 0.0642251715596233, 0.07514262359057154, 0.047870533607367954, 0.044765336838151724, 0.04340321171496596, 0.0750165314280561, 0.02863370281245027, 0.036396034860185215, 0.0312333061758961, 0.042520108566220315, 0.0035664390057458407, 0.010796390357427299, 0.0200021707985018, 0.06555391954524176, 0.014479559014684387, 0.053765333723276854, 0.026659874977277856, 0.05489527094843132, 0.027578884502872825, 0.03799037502280303, 0.030567473332796778, 0.07637528423219919, 0.05176690560100334, 0.01739059298831437, 0.04518316852461014, 0.044776078047496934, 0.06309176702052355, 0.05363915674388409, 0.05599639418401888, 0.014369196990238768, 0.04143671884334513, 0.022154019081166813, 0.014486909245273896, 0.03987896528893283, 0.010757669756588126, 0.01574483683465847, 0.05627820334796395, 0.05599445018119045, 0.011160744154559714, 0.04761677847376891, 0.014070003759115934, 0.11308212205767632, 0.1418844001101596, 0.15934727234499796, 0.15334032396120684, 0.09328637178987265, 0.1963418565158333, 0.16403820206012043, 0.14137429105384008, 0.18300788344017097, 0.16506504267454147, 0.20559058737541946, 0.10285692502345357, 0.15084350508238586, 0.15216748975217342, 0.1580123904028109, 0.22256707213819027, 0.14433107525110245, 0.13207262089209898, 0.09455782427851643, 0.0967782758442419, 0.07004283581461225, 0.1781840015734945, 0.1324892413935491, 0.1530550814100674, 0.13344349233167513, 0.13021886322115148, 0.20841060605432304, 0.12974300661257335, 0.16847101705414907, 0.10702802227543932, 0.1025940469865288, 0.14440321709428514, 0.12359222237552915, 0.3185865490564278, 0.09539379977754184, 0.1549710336008242, 0.23384697043469974, 0.09551201414849077, 0.08909777511975595, 0.18893768239234174, 0.14317983202636242, 0.11872547066637448, 0.13191653069640907, 0.1463529331875699, 0.28128593202148167, 0.1018618873453566, 0.3108694888651371, 0.15109193032341345, 0.1150946704936879, 0.16201892255672387, 0.2394271610038621, 0.15337296149560384, 0.14758717481579098, 0.24275274255446025, 0.17821762976901873, 0.5911301001906395, 0.5440938898495266, 25.616344111306326, 81.96465396881104, 94.51636627742222, 75.7214890888759, 86.92233262743268, 82.91698796408517, 81.38491712297711, 39.86207239968436, 27.237065281186783, 19.15145526613508, 42.55086544581822, 82.95236124311174, 80.81689493996757, 92.38902936662946, 82.8078942980085, 88.42315741947719, 84.2194138935634, 74.64875670841762, 54.99088546207973, 39.920176710401265, 25.247108152934484, 10.915919627462115, 6.336989879608154, 1.3878666247640337, 0.3882667486156736, 0.4613840537411826, 0.5957080402544567, 1.0932359716721942, 1.3568324957575117, 0.5143044111984116, 0.5776549918310983, 1.8675040304660797, 1.4274333587714603, 2.2305862733295987, 2.993070295878819, 3.4675547438008443, 5.33532931974956, 3.055132474218096, 3.794475087097713, 2.288301484925406, 1.478695539491517, 2.986250638961792, 4.65110980612891, 2.848617898566382, 3.2600237769739966, 1.9915367577757155, 1.7730002786431993, 1.6900611519813538, 0.797389275261334, 0.6378897939409528, 3.205094575881958, 8.9355788060597, 20.144304207393102, 39.04814999444144, 57.3675411088126, 78.50914110456193, 62.617992537362234, 72.55817576817104, 49.33518729891096, 58.39981760297503, 57.184952872140066, 16.200016839163645, 42.60736124856131, 74.00117765154157, 82.91147804260254, 69.56187629699707, 78.53950473240444, 57.15401601791382, 16.744623592921666, 0.718831476356302, 0.6072786365236554, 0.14282551461032458, 0.288906884512731, 0.10672106660370316, 0.1944341417402029, 0.1381564608642033, 0.24342660925218038, 0.16432264393993787, 0.1328125904713358, 0.21487952822021075, 0.21048540329294546, 0.12926126032003335, 0.15138383608843597, 0.2122570446559361, 0.21643312914030893, 0.12632985333246843, 0.10617466949458633, 0.18992918490299157, 0.08638152480125427, 0.12872083431908063, 0.20804883832378046, 0.1259204660143171, 0.056241416571927924, 0.16039336978324822, 0.1542541884950229, 0.14732464961707592, 0.11040810375873532, 0.09045527941946473, 0.17563140711614064, 0.19436533828931196, 0.12940242274531297, 0.12741924130490848, 0.21231581935925142, 0.15358059321131023, 0.17210025659629277, 0.06745685743434088, 0.17346088215708733, 0.21675400835062775, 0.1922176256775856, 0.07978139431881053, 0.24235446963991436, 0.09576082615447895, 0.07613791232662541, 0.15855691475527628, 0.1507365679634469, 0.14177635019379004, 0.12214222018207822, 0.13693383575550147, 0.21595442268465245], [0.08280068516199078, 0.06111731832580907, 0.06434497370251588, 0.06002054789236613, 0.05042577774396964, 0.06489255824791533, 0.04611128568649292, 0.07733438669570855, 0.05759207784597363, 0.07692499259220702, 0.02889115596190095, 0.16455635854176112, 0.0597263758203813, 0.06930999085307121, 0.17257780954241753, 0.0690284531031336, 0.04363396790410791, 0.08511763119271823, 0.10018086433410645, 0.026340385067409704, 0.026164859932448183, 0.04774116412071245, 0.08014530622001205, 0.01767944364941546, 0.02060962757760925, 0.014873419755271502, 0.05048515634345157, 0.004987053423454719, 0.08574594783463649, 0.06159328349999019, 0.039568409988922734, 0.08225096323128257, 0.07289334785725389, 0.04267511310588036, 0.04447813332080841, 0.01811229301217411, 0.02802280755713582, 0.05938572409961905, 0.057977709653122086, 0.02166298364422151, 0.02817029901780188, 0.02552262314462236, 0.002480838318920827, 0.057227623116757186, 0.05012449462498937, 0.04184929188340902, 0.06580447538622788, 0.04942980708022203, 0.010075198386662772, 0.047838058921375444, 0.058530885327075205, 0.14929755803729805, 0.07966535125992127, 0.11815299067114081, 0.025117771833070686, 0.13312302024236747, 0.04346004920080304, 0.33443294731634005, 0.6601599646466119, 27.906628438404628, 62.94729546138218, 65.78052765982491, 59.30664784567696, 50.33590507507324, 56.18298094613211, 43.94593170710972, 61.75604765755789, 40.251435552324565, 17.318147012165614, 15.555239643369402, 13.814672470092773, 18.9607150554657, 24.874410254614695, 19.344537019729614, 34.31260177067348, 37.65163850784302, 31.16162497656686, 35.84948076520647, 30.970889977046422, 22.236674308776855, 24.676504714148386, 15.974117006574359, 17.52621603012085, 14.635421480451312, 10.994531546320234, 9.346942561013357, 6.256956619875772, 4.908929663045066, 3.1597256617886678, 1.1623016084943498, 0.6865931919642857, 0.20635079086891242, 0.298714673944882, 0.4027237242885998, 0.1647748061056648, 0.5573115891643933, 0.5290971802813667, 0.49653732457331246, 0.3614404595323971, 1.1308421194553375, 0.6897655874490738, 1.433006682566234, 2.800298822777612, 7.313520976475306, 13.507192100797381, 24.991258110318864, 36.742348602839876, 52.951630864824565, 54.02922698429653, 51.74989128112793, 42.78595079694475, 36.78324222564697, 22.810303688049316, 15.598073550633021, 16.18308755329677, 14.831475325993129, 21.489260060446604, 29.319959776742117, 53.870745522635325, 56.036770003182546, 59.95166301727295, 57.81184714181082, 44.127033029283794, 17.159172228404454, 2.3514121898583005, 0.47262580479894367, 0.036265023318784576, 0.15381457922714098, 0.057239036075770855, 0.04144824715331197, 0.08180648886731692, 0.07388926763087511, 0.024555527538593327, 0.015918295830488205, 0.0538241966361446, 0.05658123708729233, 0.04224229597353509, 0.02695635237198855, 0.11559092386492661, 0.09965613963348524, 0.04080073814839125, 0.10981168504804373, 0.026804391061887145, 0.0532441000853266, 0.027359863576878394, 0.0027298464639378445, 0.04409621649288705, 0.05682154026414667, 0.04342448039512549, 0.049235064137194834, 0.015407162186290537, 0.006939733866602182, 0.045258228068373034, 0.053965433700276275, 0.06968053882675511, 0.07476098156933274, 0.1284596933318036, 0.04918177878218038, 0.06337803415954113, 0.03126107182885919, 0.046773505330617936, 0.06623230528618608, 0.03711628960445523, 0.023722583394763724, 0.028374054602214267, 0.05819813175393002, 0.02237220710542585, 0.03457365604117513, 0.08628233655222825, 0.12353726103901863, 0.03682047547772527, 0.13663946012301104, 0.06520366655396563, 0.1117388466373086, 0.08302446601114102, 0.03618775514353599, 0.06003670381116016, 0.07418200120862041, 0.07946985853569848, 0.05776213907769748, 0.025919583093907152, 0.055519906537873406, 0.02914926389764462, 0.07212190103850194, 0.05961292476526328, 0.030719821407858814, 0.026918493510623063, 0.04420669556462339, 0.11628461735589163, 0.02335580298677087, 0.11167049780488014, 0.08200635814241, 0.039680242738021274, 0.02322057604656688, 0.03667759296617337, 0.03809404160295214, 0.02787916169368795, 0.06851570454559155, 0.0420793322181063, 0.028345303377136588, 0.05661992036870547, 0.06739693600684404, 0.02853614983281919, 0.048988131673208306, 0.015945779891418557, 0.042317430156150034, 0.06272372962640864, 0.04319537304607885, 0.11219486966729164, 0.06719978087182556, 0.03741535730659962, 0.023664517760542885, 0.010959963098035326, 0.06808510622275726, 0.03570735913568309, 0.022791611296789985, 0.028431484109855125, 0.03835055498140199, 0.035274155238377194, 0.024371057615748475, 0.07041125997368779, 0.0471226896292397, 0.08790315993662391, 0.02386820549145341, 0.04595733287611178, 0.09555921304438796, 0.01936534702378724, 0.023399600725887076, 0.018007917362930517, 0.10349550790020398, 0.04770436716665115, 0.296864064676421, 0.048362770051296265, 0.40496196704251425, 2.287345673356737, 37.98848022733416, 76.95487076895577, 74.80615425109863, 71.17125279562813, 57.3962858063834, 45.353542940957205, 23.824613877705165, 19.508837597710745, 28.29724747794015, 27.16686589377267, 30.162758895329066, 36.07886859348842, 48.65344394956316, 59.95710345676967, 56.6128625188555, 62.86910738263811, 53.889189515795024, 45.49878461020333, 36.56064626148769, 27.94069024494716, 21.39983674458095, 13.6445232459477, 9.759092330932617, 6.173481830528804, 6.33101920570646, 3.0984258311135426, 2.138493980680193, 0.6879655154688018, 0.763338813824313, 1.0038739953722273, 0.4361307445381369, 0.5844091836895261, 0.3032367027231625, 0.20856342571122305, 0.39479965663381983, 0.49469599766390665, 0.38429951721004074, 0.3799359942121165, 0.4997501064624105, 0.5282967803733689, 1.6586335812296187, 1.68164938049657, 0.6004586539098195, 1.450908824801445, 2.483786880970001, 0.9565279930830002, 1.734040534922055, 7.504410573414393, 19.94983802522932, 30.23512785775321, 40.2875314440046, 45.88742862428938, 46.609106745038716, 47.084460803440635, 31.47590936933245, 34.985051904405864, 27.12300886426653, 30.818651471819194, 29.684528282710485, 23.429374286106654, 41.27088219778878, 60.5199978692191, 65.98914037431989, 65.01250852857316, 29.22714921406337, 5.526209797177996, 0.7184955743806702, 0.056244598901165385, 0.05068964983469673, 0.05915060493030718, 0.013094039700393165, 0.06875301538301365, 0.07746686387274947, 0.08028367986636502, 0.05899360549769231, 0.04555497857342873, 0.0439389592169651, 0.0477376730580415, 0.05721683440996068, 0.15656548232904502, 0.012730606166379792, 0.05164993294913854, 0.04708636086434126, 0.09981244017503091, 0.05696982730712209, 0.03339300850140197, 0.010574210002752287, 0.0347866821102798, 0.03567897601585303, 0.04231920791789889, 0.05010444391518831, 0.05502825702673622, 0.03159150820491569, 0.06541182074163641, 0.00817351833185447, 0.03598097838195307, 0.06143865893994059, 0.07987913050289665, 0.027787177790222422, 0.1019893501486097, 0.09754082706889936, 0.04472070958997522, 0.041193104415599785, 0.028866626920976808, 0.031953822156148295, 0.022328509450224892, 0.09469494942043509, 0.05903463651026998, 0.045208240393549204, 0.04348589799233845, 0.07268992984401328, 0.023581283566142832, 0.0707820522199784, 0.03565575994018998, 0.013991560021947538, 0.025702551971854906, 0.04267857363447547, 0.10747266627315964, 0.26975311658212114, 0.1690495495817491, 0.1273717845657042, 0.08582307012485606, 0.2098749660487686, 0.17655302051986965, 0.25826272315212656, 0.1604230081928628, 0.1942360909389598, 0.10329710426075117, 0.23135338138256753, 0.1902186886540481, 0.16910187820238726, 0.26187339797616005, 0.2558199699435915, 0.2528916299343109, 0.25788695045879906, 0.3353978783956596, 0.1405382002038615, 0.1173185690173081, 0.16499718917267664, 0.11550000017242772, 0.19064256948019775, 0.11189283337444067, 0.19643708212035044, 0.08482387302709476, 0.10713531223258801, 0.21151761790471418, 0.1984511369041034, 0.08868263382464647, 0.0896826655204807, 0.24897732426013264, 0.17256769937063965, 0.11243263512317624, 0.08014025113412312, 0.21033624772514614, 0.13751227328819887, 0.10868923884949513, 0.11526894542787756, 0.09977484933499779, 0.11263766126441103, 0.13805085367390088, 0.13802763420556272, 0.20031815314931528, 0.10759011389953749, 0.14757847599685192, 0.18945621885359287, 0.14636609676693166, 0.1556666134191411, 0.23624149337410927, 0.2758668256657464, 0.2354947520153863, 0.3641887434891292, 0.1282205640205315, 0.2817416361400059, 0.16660869627126626, 0.6205597381506647, 2.1586033701896667, 41.953841481889995, 93.65544973100934, 84.58600085122245, 80.44765377044678, 65.48552799224854, 78.2108827318464, 63.76730796269008, 90.3612254006522, 58.71011025565011, 27.2783271585192, 24.211847407477244, 22.175163643700735, 31.082172325679235, 39.66329138619559, 35.743545055389404, 57.64922455378941, 69.95613098144531, 65.4820955821446, 79.49349239894322, 75.60580158233643, 60.24547454289028, 69.91997950417655, 53.410455158778596, 52.811770575387136, 40.16322817121233, 32.93145275115967, 24.16250651223319, 15.004940577915736, 10.25731725352151, 5.944666360105787, 1.9059477618762424, 1.2910362035036087, 0.45348123780318667, 0.6097773824419294, 0.8320660516619682, 1.0259172639676502, 1.1956434079578944, 1.5786495017153876, 2.132611462048122, 3.0733634616647447, 5.448168499129159, 6.288329907826014, 8.602150389126368, 12.475165741784231, 20.482228108814784, 31.520013059888566, 46.32550212315151, 62.53601769038609, 80.17900167192731, 85.89615317753383, 80.10029247828892, 69.26076221466064, 55.08765302385603, 36.264104093824116, 22.994352783475602, 24.923749412809098, 24.113354955400737, 36.225996698652, 44.52560601915632, 83.4146248953683, 71.91905961717877, 82.37477833884103, 74.47685827527727, 73.8873314176287, 30.447638511657715, 3.9003465260778154, 0.6025845855474472, 0.16422526059406145, 0.416888631348099, 0.08852532905127321, 0.1407930850982666, 0.15692176749663694, 0.45984193363359993, 0.2332286350429058, 0.14366887935570308, 0.17567487406943524, 0.21804504335990973, 0.13196743439350808, 0.11020515393465757, 0.2347447265471731, 0.15654277854732104, 0.09836874157190323, 0.2667225349162306, 0.18840381103966916, 0.13281409681907722, 0.14787989482283592, 0.09341399065618004, 0.1581948756107262, 0.1471484476434333, 0.15190575165408, 0.15694729398403848, 0.12259890139102936, 0.15046318620443344, 0.2207203848021371, 0.10487377537148339, 0.1141357376639332, 0.14151313288935594, 0.21128363188888344, 0.1230388092143195, 0.17973749392798968, 0.10818433415676866, 0.09461957096521344, 0.11111887597611972, 0.14149469030754908, 0.22978441842964717, 0.18670892555798801, 0.14734877832233906, 0.17753186156707151, 0.1125009296728032, 0.2368587159684726, 0.2392361398254122, 0.19603122318429606, 0.25042971489684923, 0.13117991308016436, 0.24817763002855436, 0.13278314205152647, 0.1355089122163398], [0.016352709216464843, 0.0788890461304358, 0.10701023108725037, 0.005692216700741223, 0.03250654999698911, 0.0844558220622795, 0.06361411006322928, 0.0409543822253389, 0.09707033767231874, 0.06883159652352333, 0.047451694296406846, 0.04272016104576843, 0.13745011948049068, 0.1442949500467096, 0.03575368272140622, 0.13779482884066446, 0.1560425761022738, 0.0458355765523655, 0.08703016356698104, 0.12492398305663041, 0.06896861309983901, 0.07373897212424449, 0.03631543507799506, 0.028801945570324148, 0.0696339031149234, 0.045799797400832176, 0.015086471269439374, 0.02048730637345995, 0.03202141781470605, 0.05799007934651204, 0.017264521181849495, 0.009544522085759257, 0.01983974308573774, 0.03960480660732303, 0.05463563970157078, 0.014795601966657808, 0.02859019853972963, 0.03831911166863782, 0.015150182315015366, 0.015854181056576114, 0.09092081551040922, 0.0627509660220572, 0.031947684806904623, 0.029432277461247783, 0.05806998363030808, 0.09749054083866732, 0.08918860381735222, 0.06195516658148595, 0.048549682700208256, 0.0775932070932218, 0.12224226338522774, 0.0190974088119609, 0.05054283860538687, 0.10208627209067345, 0.05208356771618128, 0.10066920598702771, 0.03822556883096695, 0.08839090447872877, 0.09355888502406222, 0.29390774188297136, 2.5886584307466234, 28.68341272217887, 55.200269426618306, 68.17875398908342, 58.53285476139614, 61.5134721483503, 55.73270641054426, 60.441267830984934, 70.22367136819022, 59.41427544185093, 65.50052915300641, 49.156569957733154, 42.60064581462315, 30.816737243107386, 22.526447193963186, 35.30763592038836, 13.14879880632673, 8.97106238773891, 5.456140688487461, 6.586233053888593, 3.6962292960711887, 9.01249623298645, 16.699585369655065, 21.236552340643748, 40.47246469770159, 34.64936705998012, 51.85161985669817, 45.693806648254395, 43.74833883558001, 36.73151636123657, 28.999022483825684, 34.32511895043509, 33.48083986554827, 33.72681304386684, 34.261025292532786, 35.23707696369716, 33.059476784297395, 26.053095715386526, 28.167505502700806, 16.396815879004343, 24.718643801552908, 31.892499038151332, 39.86755452837263, 39.96401636941092, 50.72473669052124, 43.022054059164866, 37.48462118421282, 29.344309738704137, 25.466902256011963, 29.28468724659511, 28.383641379220144, 21.758765050343104, 29.122203622545513, 37.68445484978812, 46.93088476998465, 48.353153228759766, 61.02876581464495, 61.737732206072124, 64.33560112544468, 62.73684842245919, 55.88880116598946, 19.21753089768546, 0.40283907524177004, 0.30840776381748064, 0.07715454777436596, 0.09904750729245798, 0.0054422096249514395, 0.08078209097896304, 0.06004264099257333, 0.01962058475640203, 0.022357986707772528, 0.05127723062677043, 0.0608755223719137, 0.07312891485967807, 0.01073959019101624, 0.05077228182926774, 0.08269029429980687, 0.030171622788267474, 0.029866994491645267, 0.18086508342197963, 0.027704827387684157, 0.04804369235145194, 0.035672010853886604, 0.07111932483634778, 0.041034391682062826, 0.05707113937075649, 0.11447609082928725, 0.039173126021134, 0.06314357316919736, 0.036994509531983306, 0.03750499178256307, 0.054255361535719464, 0.0377596052629607, 0.038581697935504575, 0.04887347961110728, 0.02229629091120192, 0.034197479619511535, 0.018228210542084913, 0.04169745949496116, 0.07720416904027973, 0.07440821799848761, 0.03342353239921587, 0.01702788209409586, 0.11466028594544955, 0.03331909568182059, 0.026092412748507092, 0.045824584285063405, 0.06778108182230166, 0.06261513688202415, 0.13630205179963792, 0.13391151864613804, 0.2041908103440489, 0.23055355144398554, 0.0622235271813614, 0.15695789270102978, 0.06092814276260989, 0.05843475727098329, 0.05365805733682854, 0.059197905606457164, 0.05366561960961137, 0.030712591617235115, 0.08840928599238396, 0.039672459941357374, 0.06818284919219357, 0.0849172869431121, 0.058798628460083685, 0.0305289562924632, 0.0789549658074975, 0.03504063741170934, 0.13250616405691418, 0.03421192902273365, 0.10714616200753621, 0.1357681940176657, 0.12141241505742073, 0.07537833308534962, 0.16392091049679688, 0.022547700009973984, 0.05982267351022788, 0.0661853574482458, 0.0630163885653019, 0.08828593511134386, 0.02427975394363914, 0.038358307243990045, 0.03370221351672496, 0.0747044731729797, 0.05017987326053636, 0.10075677093118429, 0.034284691725458415, 0.03909107756667903, 0.021652286539652517, 0.0031889826974033243, 0.05097242591104337, 0.09881196743143456, 0.05073830418820892, 0.019487342531127588, 0.055780850749995024, 0.09246816033763544, 0.02439346962741443, 0.0375006118390177, 0.02922514107610498, 0.0738439889890807, 0.07977260050496884, 0.06182571567062821, 0.07340604891734463, 0.03616215740995748, 0.1014607645837324, 0.07815469482115336, 0.054754122093852074, 0.07137441329125847, 0.09506021160632372, 0.008502204087562859, 0.11877374164760113, 0.06480428762733936, 0.1618021306182657, 0.05505403117941959, 0.2101116662046739, 5.037292420864105, 40.86139358792986, 72.12068939208984, 78.71798310961042, 68.5574586050851, 59.97561345781599, 52.42606564930507, 43.462879044669016, 27.827318225588115, 22.860301188060216, 20.094482149396622, 14.65344510759626, 19.046645164489746, 18.580730233873638, 29.490551948547363, 44.02092708860125, 23.93691761153085, 26.40164688655308, 24.52474042347499, 19.75580610547747, 23.49363817487444, 23.283425637653895, 29.799090181078228, 28.88212772778102, 34.09823247364589, 34.542701789310996, 35.02949258259365, 31.220271246773855, 25.268473863601685, 20.38414212635585, 18.749953610556467, 15.07295823097229, 13.953050187655858, 10.083548017910548, 7.169368437358311, 9.801873258181981, 12.905634437288557, 15.60765164239066, 13.50261844907488, 19.091594798224314, 20.44268069948469, 24.15667871066502, 32.73633691242763, 43.05974803652082, 52.28836972372872, 60.576354707990376, 61.66443565913609, 60.6027717590332, 49.3240875516619, 51.55197879246303, 41.06377029418945, 34.20836836951119, 22.45364396912711, 21.590564795902797, 17.27042157309396, 16.564687831061228, 30.372222764151438, 46.17823852811541, 66.6891644341605, 72.96983569008964, 68.03509303501674, 34.969574792044504, 4.8185084121567865, 0.30531426838466097, 0.07898397996489491, 0.187256856156247, 0.06657424622348376, 0.05300421420750873, 0.024861645219581466, 0.06617619044014386, 0.13769300787576608, 0.013246001010494573, 0.04323098934920771, 0.04143217944407037, 0.04309652406456215, 0.03771269813712154, 0.05469495044755084, 0.09133858952139105, 0.11091690324246883, 0.013237241971572595, 0.03149230977786439, 0.05468649590121848, 0.060812968228544505, 0.05647234918017473, 0.017283774613003646, 0.014598260234509195, 0.03529803627835853, 0.09686490441007273, 0.06866927737636225, 0.07739958034030028, 0.013765144760587385, 0.02706960156293852, 0.05380290759993451, 0.008275579328515699, 0.019549822035644735, 0.01802153556075479, 0.02222297520243696, 0.09010290261358023, 0.08312311143215213, 0.06187069575701441, 0.0828076469312821, 0.0226960922258773, 0.0537021519350154, 0.0524583734971072, 0.05224234491054501, 0.026789127416642647, 0.07945686459009137, 0.09071013717246906, 0.06933819755379643, 0.1876632579203163, 0.17117381202323095, 0.21687381049352034, 0.14335618327770913, 0.1228131420378174, 0.07960381491908006, 0.15210061334073544, 0.14895481642867836, 0.1204338725656271, 0.18877028780324118, 0.14137330039271287, 0.12729563936591148, 0.14636837664459432, 0.08983370063028165, 0.0855069678010685, 0.21109501272439957, 0.10112949700227805, 0.18738298224551336, 0.23486594004290445, 0.14887147875768797, 0.2122014183551073, 0.13236500163163456, 0.2662748917937279, 0.2893810176423618, 0.21994640704776558, 0.27178630605340004, 0.25436149963310783, 0.12952717819384166, 0.1920695693365165, 0.15182683803141117, 0.18112075541700634, 0.20974103680678777, 0.19573072716593742, 0.1849068044019597, 0.1395333441240447, 0.2245019825973681, 0.14556024143738405, 0.26387434346335276, 0.08065105908151184, 0.1278132123074361, 0.10728074264313493, 0.18541468786341803, 0.20510645263961383, 0.18736311474016734, 0.2380390412041119, 0.15430365369788238, 0.1391994370413678, 0.18284783059997217, 0.08661996200680733, 0.11184323924992766, 0.1562334480030196, 0.13692102501434938, 0.28930431604385376, 0.17658169540975774, 0.21408923848399095, 0.1886546654360635, 0.1624004085149084, 0.21032146923244, 0.2633253000676632, 0.1424504475934165, 0.3098167824958052, 0.20137395363833221, 0.3718738853931427, 0.22676356695592403, 0.16791444191975252, 0.20884459705225059, 0.3180477651102202, 5.165201808725085, 45.44574901035854, 88.19499942234584, 99.7499440056937, 84.12810066768101, 75.63185732705253, 72.65206677573067, 77.59181213378906, 88.42829908643449, 85.02855246407645, 90.95970848628453, 73.2750631059919, 57.38321277073452, 46.842858042035786, 34.32524749210903, 54.93100241252354, 23.825718641281128, 26.14455659048898, 21.361442736216954, 22.83757884161813, 22.4578788961683, 30.813204084123882, 43.9829169682094, 46.73025900976998, 71.91587734222412, 64.42875562395368, 82.76767117636544, 71.0925852911813, 67.83745152609688, 58.43160561152867, 49.19387136186872, 53.19899715696062, 52.74269853319441, 55.624106066567556, 57.99707221984863, 63.227696963718955, 67.05867658342633, 65.89545781271798, 70.54922226497105, 55.24273681640625, 68.01481819152832, 80.25915609087262, 84.33014733450753, 79.96655355181012, 80.61582102094377, 69.65118149348667, 59.093609128679546, 45.9412910597665, 35.54019560132708, 38.16392224175589, 38.1192626953125, 39.92584644045149, 50.598342009953086, 65.08919579642159, 74.388838495527, 72.87563896179199, 84.33111313411167, 78.41852269853864, 84.84459890638078, 80.80051803588867, 76.28316756657192, 36.25410563605172, 3.647050814969199, 0.4256392632211958, 0.1603947268532855, 0.42017512928162304, 0.14082116287733826, 0.1525741493595498, 0.1608623189053365, 0.3589393523122583, 0.14388530488525117, 0.11301286398832287, 0.1599187073963029, 0.22049573542816298, 0.1302247800465141, 0.12709338164755277, 0.19235584326088428, 0.2178509144910744, 0.2069271927965539, 0.32015260787946836, 0.08127114509365388, 0.1903016734868288, 0.15608351890529903, 0.12868059719247477, 0.08047097588756255, 0.11214309066001858, 0.17094469788883412, 0.26181154272386004, 0.19124966833208287, 0.19564607313701085, 0.14491838802184376, 0.14648878946900368, 0.11371600268674747, 0.09931484330445528, 0.13121972951505864, 0.1010527682623693, 0.13441675582102366, 0.2253523633948394, 0.14954611898532935, 0.23774773254990578, 0.348467331379652, 0.13009678120059626, 0.09411528373935393, 0.24646560475230217, 0.20328614674508572, 0.16321657757673944, 0.15577977948955127, 0.18974724252309116, 0.18442469170050962, 0.43069937026926447, 0.1858448926359415, 0.2610226779111794, 0.24989679349320276, 0.11639273512576308, 0.16539137730641024, 0.22720789882753575], [0.04373334614293916, 0.05933319191847529, 0.0389325039328209, 0.17833580342786653, 0.06194447286959205, 0.048425364906766584, 0.01970120150196765, 0.04057172579424722, 0.031029864413929836, 0.05179038630532367, 0.0677326615633709, 0.021306221805778996, 0.09147637962762799, 0.046241608514849625, 0.08054264275623219, 0.07407988168831382, 0.09475611935236625, 0.12818378742252076, 0.03994109874059047, 0.05272804706224373, 0.0053171365372171354, 0.09559725850288357, 0.08712458850017615, 0.12434973887034825, 0.059954383942697725, 0.030116105053041662, 0.037665679053004296, 0.050374755303242376, 0.024842849799564908, 0.08102261807237353, 0.03777312846588237, 0.045248256996273994, 0.0793556339506592, 0.014505594403349927, 0.04087739564212305, 0.07718396905277457, 0.040178480824189525, 0.005018431427223342, 0.09013980134789433, 0.03402780854542341, 0.047093577084264586, 0.009676198591478169, 0.02345520836700286, 0.029840256819235425, 0.019508801201092343, 0.01508771807753614, 0.023785252889086093, 0.02801851073413023, 0.041167421865143945, 0.016853554573442255, 0.030773239077201912, 0.056948188825377395, 0.015997706480058174, 0.053808532655239105, 0.04236685125423329, 0.07075745532555239, 0.0273618432027953, 0.13254108146897384, 0.027161529487265006, 0.14259139288749012, 0.053983676114252636, 0.9847088009119034, 1.1352195931332452, 20.378135408673966, 37.468914781297954, 69.67497907366071, 87.14224311283657, 76.80661010742188, 68.10916083199638, 60.74323654174805, 60.70924595424107, 65.43571635654995, 71.54322460719517, 68.8561338697161, 55.892775535583496, 34.379248891557964, 34.352032797677175, 35.679291588919504, 39.721034390585764, 36.073737348829, 26.16337057522365, 27.2707188810621, 11.911156143460955, 18.8074951171875, 7.59531125000545, 13.258305890219551, 25.721765654427664, 21.12982279913766, 41.194097655160085, 62.58163956233433, 47.43582078388759, 28.531578949519567, 16.100082635879517, 32.045522689819336, 44.906037262507844, 29.093273060662405, 14.030624219349452, 12.864907571247645, 11.635525447981697, 34.98783813204084, 46.286387239183696, 13.314341374805995, 10.115706018039159, 12.54958094869341, 15.448987790516444, 15.633458989007131, 24.202007021222794, 30.451772689819336, 43.93178864887783, 36.986407552446636, 55.751077447618755, 59.79543972015381, 59.729244232177734, 63.74116883959089, 65.74502236502511, 68.4813619341169, 70.76126738956997, 64.07298701150077, 45.88034493582589, 19.431241852896555, 3.172597199678421, 0.05249760639188545, 0.09454863012901374, 0.25320001052958624, 0.09635422538433756, 0.026242170516135435, 0.02229147161623197, 0.12094472801046711, 0.02677415723779372, 0.04974074914519276, 0.036849241969840865, 0.03572168640260186, 0.016441897555653538, 0.05293676443397999, 0.11310397767062698, 0.04694184986874461, 0.05325952657897558, 0.011450521015961255, 0.04258330053250704, 0.07819407020828553, 0.04491119811843548, 0.033825910450624566, 0.07355506199279002, 0.054239256507051845, 0.0638405711257032, 0.009981491004249879, 0.018284501807231988, 0.09470693234886442, 0.03535906711061086, 0.03992188602153744, 0.05800849478691816, 0.06027714269501822, 0.03892890091187187, 0.11752489794577871, 0.039386796698506386, 0.058302110460187705, 0.04328027134761214, 0.05027615398700748, 0.03687996603548527, 0.032223027532121966, 0.04680765260543142, 0.022004795659865652, 0.010252058539273483, 0.06095425957547767, 0.06277625502220222, 0.03353005900446858, 0.053131449701530595, 0.054319415241479874, 0.04603243313197579, 0.10671852888273341, 0.17092651315033436, 0.04608548439240881, 0.12526212419782365, 0.10994190948882274, 0.08565774506756238, 0.03487485434327807, 0.028811546840838025, 0.011708517841595625, 0.05158889533153602, 0.0447969260359449, 0.013251646421849728, 0.20532092398830823, 0.026209522803713168, 0.09563145666782345, 0.06479230469891004, 0.07359642548752682, 0.06061814725399017, 0.13183151025857243, 0.14644145486610277, 0.09737540701670305, 0.08968628211213009, 0.07465994770505599, 0.1155700928398541, 0.07098936502422605, 0.03723720454477838, 0.13906790981335299, 0.07436878832855395, 0.0283241856710187, 0.012592518352903426, 0.054304022674581835, 0.12062630509691578, 0.0513858335491802, 0.021966056399313465, 0.07810995900737387, 0.04507312710796084, 0.08282927862767663, 0.028294569313792244, 0.03525471860276801, 0.06687873202775206, 0.024242979041965942, 0.02823489555157721, 0.07368457397179944, 0.05224517440157277, 0.03719388347651277, 0.03602618917024561, 0.023153209393577914, 0.07403416878410748, 0.04671356693974563, 0.0749626150354743, 0.0977221451965826, 0.02981399412133864, 0.032571041357836554, 0.028807811505560364, 0.035828216400529654, 0.09932986606976815, 0.10617791289197547, 0.08685318806341716, 0.08120876058403935, 0.03878736189965691, 0.0518267184628972, 0.021818687074950764, 0.1093458639723914, 0.01388865424918809, 0.1164679303765297, 0.07713921288294451, 0.10566711172993694, 0.016069040866568685, 0.5519488826394081, 3.5582712931292395, 31.256766659872874, 54.18464776447841, 88.57255063738141, 95.41638728550502, 84.70111860547746, 73.89434215000698, 56.719663279397146, 56.570256165095735, 47.82383598600115, 49.1550726209368, 34.55840471812657, 23.935036386762345, 25.82220881325858, 15.514389446803502, 9.6790178162711, 13.019450272832598, 11.725489854812622, 15.652670758111135, 7.642384426934378, 17.368172304970876, 21.39258108820234, 26.364835330418178, 32.07284300667899, 46.631994111197336, 42.89795228413173, 65.87881687709263, 65.53887626102993, 58.860851424080984, 57.506578036717, 51.54751457486834, 61.490341595241, 71.91789926801408, 60.345980235508506, 44.00783668245588, 38.196325165884836, 38.15529605320522, 38.77997384752546, 52.667963709150044, 36.56388064793178, 32.82162605013166, 31.79880952835083, 36.25686754499163, 31.82671696799142, 28.080708605902537, 33.0438746043614, 29.647994654519216, 31.077451024736675, 38.787616865975515, 33.50091321127755, 39.30929109028408, 43.0675230707441, 52.629536696842735, 62.46261692047119, 76.5162170955113, 78.91288702828544, 63.924163545881, 32.76512329918997, 8.18791355405535, 0.1656806232141597, 0.25319135242274826, 0.06134861055761576, 0.07400345828916345, 0.08372993887002979, 0.07990631940109388, 0.1387426879789148, 0.09938632696866989, 0.056716173953775845, 0.051977709467921934, 0.13505905706967625, 0.042269016682569466, 0.07151877161647592, 0.029701516763972383, 0.03191443659099085, 0.05239361411492739, 0.10330103976385933, 0.03740463984598007, 0.009425918405343379, 0.07134243393582956, 0.024630351291437234, 0.05643888383305498, 0.08201976599437849, 0.044427090524030585, 0.0141461158803265, 0.010999204474501312, 0.015538660576567054, 0.03540893604180642, 0.04662699944206646, 0.09212967314358268, 0.017855598125606775, 0.12720673770776816, 0.0725567809173039, 0.02989099088257977, 0.04258493919457708, 0.041131130419671535, 0.0817058417680008, 0.05572072576199259, 0.041671403750245056, 0.08098850811698607, 0.023946684851710285, 0.04765344650617667, 0.04010782836537276, 0.055173419415950775, 0.04342396131583622, 0.10161736368068627, 0.10380515735596418, 0.043992454917835336, 0.05027380286316786, 0.15573515902672494, 0.054326149701539955, 0.1281509870397193, 0.1267100093620164, 0.08952308765479497, 0.07617768804941859, 0.10832410558526005, 0.1144556397838252, 0.16310847337756837, 0.18968594366950647, 0.11827613120632512, 0.23638469140444482, 0.15570895400430473, 0.15306162248764718, 0.09714007750153542, 0.14916793070733547, 0.35241879363145145, 0.1822904140821525, 0.21675782171743257, 0.1381162101668971, 0.16458145076675074, 0.18805801602346556, 0.19868186595184462, 0.27864002542836325, 0.14207198790141515, 0.22108528736446584, 0.11817602014967374, 0.25628083092825754, 0.16444654443434306, 0.21273554755108698, 0.22350547249828065, 0.2410065462546689, 0.1158242720578398, 0.1392763422003814, 0.2133420357214553, 0.1594030207821301, 0.17153418197163514, 0.10090514618371214, 0.20444241112896375, 0.10841245084468808, 0.13079713790544442, 0.17608854972890445, 0.14594369514712266, 0.13685021309980325, 0.1992519303624119, 0.10718312181000199, 0.14403497613966465, 0.18396716910813535, 0.15697457109178814, 0.24841272884181567, 0.1774007278893675, 0.13737649843096733, 0.10413196017699582, 0.09313781333288976, 0.20707951033754007, 0.12032039436910834, 0.15978856437972613, 0.11444126841213022, 0.13490854443183967, 0.17821628626968178, 0.1241868497537715, 0.148080564769251, 0.23468273558786937, 0.4758424407669476, 0.07228412519076041, 0.19099274783262185, 0.16236192200865063, 1.1302992914404189, 3.3720135390758514, 30.739007745470317, 65.02742631094796, 102.5055787222726, 112.72999886104039, 97.10336126599992, 92.77464744022915, 75.91726848057338, 83.27131829942975, 80.43046392713273, 95.04714611598423, 89.16093104226249, 85.55255086081368, 52.57998561859131, 71.88632665361676, 65.23553875514439, 72.11508219582694, 67.45366777692522, 48.555029664720806, 48.96745041438511, 26.973322084971837, 31.750109604426793, 16.816509655543737, 23.709494386400493, 40.19129194532122, 33.35076263972691, 59.383133615766255, 77.79526928492955, 65.41590009416852, 45.90335736955915, 32.56840590068272, 49.836093357631135, 69.43678787776402, 53.21715974807739, 31.355660370418004, 28.09359404018947, 31.797753402165004, 63.56034891945975, 77.49560042790004, 29.77223539352417, 23.982998064586095, 20.62222215107509, 27.009146996906825, 26.116404226848058, 38.78398643221174, 50.90287113189697, 67.78413105010986, 61.36553110395159, 84.10616520472935, 79.55870819091797, 84.91070406777519, 85.51002093723842, 78.64419324057442, 87.54464108603341, 90.79555034637451, 88.36882945469448, 65.71540219443185, 32.51540504183088, 5.997939935752323, 0.2209658244890826, 0.2717424455497946, 0.22419334415878567, 0.14049013278314046, 0.21511557698249817, 0.13906311935612134, 0.3958661508347307, 0.11713395320943423, 0.1165629659912416, 0.14772445602076395, 0.18214955021228108, 0.14539592739726814, 0.16867940872907639, 0.32111876032182146, 0.15082905228648866, 0.19444289484194346, 0.14437195020062582, 0.10586040600069932, 0.1349338266466345, 0.25785961906824795, 0.1739295870065689, 0.18658720994634287, 0.1674133709498814, 0.1265087423047849, 0.18344385576035294, 0.0814278188294598, 0.1548493994133813, 0.11705194546708039, 0.23768229463270732, 0.1398929948253291, 0.1810490342655352, 0.303009529198919, 0.21321544822837624, 0.156785178397383, 0.17287263300802025, 0.12819453541721615, 0.1814216992684773, 0.17581010609865189, 0.1666633997644697, 0.1614836805633136, 0.06380528051938329, 0.18152514871742043, 0.14736754660095486, 0.1757678740790912, 0.18205866723188333, 0.1610956128154482, 0.18232250878853457, 0.16896199142294271, 0.23319622821041516, 0.20950630440243653, 0.18670117668807507, 0.2220849594367402, 0.16364762373268604, 0.2328919188252517, 0.11741429673773901], [0.045741633379033635, 0.06482405335243259, 0.03183712770364114, 0.09055868815630674, 0.08681631647050381, 0.14299563691020012, 0.10197020189038344, 0.15032134524413518, 0.004095994875699813, 0.05213416607252189, 0.05939723205353532, 0.12432761862874031, 0.10056741894888026, 0.06987128859119755, 0.1470642550183194, 0.12399320943014962, 0.1490477757262332, 0.11850753878908497, 0.04922025850308793, 0.04604110141683902, 0.030609325372747014, 0.04704127221235207, 0.03943713381886482, 0.0671577388420701, 0.059385221983705244, 0.004180642119276204, 0.05135429524151342, 0.04872071423700877, 0.054782637528010776, 0.05920298783374684, 0.005630479343900723, 0.06669871668730463, 0.01113664428703487, 0.09768000817192452, 0.04671777385686125, 0.07370272478354828, 0.0717982126932059, 0.011006852412330253, 0.04900860986007111, 0.07154961103307349, 0.07850689520793301, 0.066513381632311, 0.038636096087949615, 0.010274401849268802, 0.008333918073081543, 0.004095328215043992, 0.07112648338079453, 0.00912074388803116, 0.017447742600260035, 0.0709933548101357, 0.08679805030780179, 0.024043041913371, 0.05318130166935069, 0.10868650435336999, 0.049880293264452896, 0.09479907740439687, 0.034093765541911125, 0.09860125516674348, 0.030458962012614523, 0.03929792557443891, 0.02699541563301214, 0.3306805400976113, 0.10656035558453628, 0.2597670352884701, 0.4549832429204668, 5.523678915841239, 23.776499339512416, 31.57705429622105, 46.26307603291103, 66.92710549490792, 74.53997571127755, 73.11628981998989, 70.71921689169747, 62.69521481650216, 67.07810374668666, 68.86304037911552, 64.61279950823102, 56.22073745727539, 56.765163557870046, 46.85558714185442, 56.798820631844656, 51.88178893498012, 52.005195890154155, 49.04385280609131, 54.786625794001985, 46.4881386075701, 35.993152141571045, 44.74385241099766, 22.93676437650408, 49.48107862472534, 79.18294266292027, 62.09627314976284, 59.29177870069231, 29.123980624335154, 11.711248653275625, 24.75446002823966, 38.41892113004412, 41.02478742599487, 22.762998614992412, 55.985738958631245, 45.834841183253694, 41.32243435723441, 52.887856824057444, 63.994097164699006, 59.960105078560964, 62.475464139665874, 70.40973023005894, 66.57319899967739, 68.26122215815953, 70.41026524135044, 67.14980915614537, 68.69192709241594, 69.48416764395577, 74.54535361698696, 68.60724244798932, 50.44620772770473, 20.77164489882333, 7.597473008292062, 0.2587739857179778, 0.2290120284472193, 0.12087827229074069, 0.05809282311903579, 0.04811793765319245, 0.038643526046403816, 0.055318385030009916, 0.04573864443227649, 0.031159610487520695, 0.06575333420187235, 0.04390075769541519, 0.06476945163948195, 0.12415954550462109, 0.02161003416404128, 0.06658916042319366, 0.09759155434689351, 0.059102720714041164, 0.05432570186842765, 0.07762836199253798, 0.04005711805075407, 0.07272268951471363, 0.06637086892234427, 0.015327883851049202, 0.04217498869236026, 0.017563527815842202, 0.07140308139579636, 0.041282196063548326, 0.019515255765457238, 0.028980851506016085, 0.13496759054916246, 0.10341612608837229, 0.04432780388742685, 0.056487928344202895, 0.09683307433234793, 0.045926239008882215, 0.1661883709686143, 0.03223390105579581, 0.03596367573897753, 0.019936020419533764, 0.03198607631825975, 0.06349313405475446, 0.07002857979387045, 0.03667572020952191, 0.023104502453601787, 0.055116453008460145, 0.05801577546766826, 0.012721004047697144, 0.03144103967185531, 0.06246300254549299, 0.0755979884415865, 0.20434818975627422, 0.1544042532997472, 0.2082293422094413, 0.08160474683557238, 0.14199069940618106, 0.11412712026919637, 0.08356429490127734, 0.08301960091505732, 0.029709021361278634, 0.05073924056653466, 0.035279939749411175, 0.02106320109617497, 0.07838353754154273, 0.12778604376528943, 0.009666090116037853, 0.08199199355606522, 0.03780699075598802, 0.016759319630052363, 0.048540922813117504, 0.048140471801161766, 0.1484517641365528, 0.045215327691818984, 0.09415664044874054, 0.054877259236361296, 0.08262804549719606, 0.04259105958044529, 0.06446535938552447, 0.021403291329209293, 0.028850087629897252, 0.0415563174257321, 0.04748311046777027, 0.12992135275687489, 0.08717313768076045, 0.08109277180795159, 0.05363314492361886, 0.03720239230564662, 0.06180059630423784, 0.05293167881401522, 0.022914945214454616, 0.003131989360554144, 0.0163042601197958, 0.02144930448516139, 0.034143712504633834, 0.0363707899648164, 0.13525880420846598, 0.05844046375049012, 0.02010086371696421, 0.08551717296774898, 0.036558153839515786, 0.02595575918842639, 0.08188819805426256, 0.07362210125263248, 0.02176445346724774, 0.059551110225064416, 0.007755031859103058, 0.0796330054955823, 0.03650655125134757, 0.09649515710771084, 0.051982259045221975, 0.03198596775265677, 0.03454783439104046, 0.028270460964579667, 0.03276860700654132, 0.08807658670204026, 0.058918735943734646, 0.14276612922549248, 0.02877474988677672, 0.169782353831189, 0.0565033887646028, 0.30195022746920586, 0.08701725104557616, 0.14236500646386827, 1.6239415513617652, 10.501787883894783, 37.97809961863926, 49.2725944519043, 61.97035789489746, 83.28192125047956, 84.1915863582066, 83.23240143912179, 78.75922761644635, 71.08242702484131, 61.62203080313546, 54.16641569137573, 45.793339593069895, 36.62298549924578, 36.83407872063773, 30.29036603655134, 20.893967935017177, 16.67982816696167, 11.770580189568655, 11.46116474696568, 8.749272414616176, 17.75856031690325, 29.71166099820818, 24.45951768330165, 32.87300450461251, 58.55898693629673, 59.2786466053554, 36.38333865574428, 30.988732951028005, 30.261148861476354, 27.549004656927927, 24.665660313197545, 24.044793605804443, 22.488331113542827, 20.585209097181046, 51.51192242758614, 64.46449715750558, 16.49359038897923, 19.178475073405675, 28.09703860964094, 22.31637188366481, 21.48506682259696, 28.693234000887188, 37.23870359148298, 45.07000780105591, 54.63755219323294, 59.993609292166575, 72.37653596060616, 75.46292577471051, 82.96099785396031, 84.08071395329067, 71.24033873421806, 38.93625967843192, 17.064695835113525, 1.909597086054938, 0.05469967983663082, 0.36577969097665375, 0.040526148597044606, 0.04589149462325232, 0.04674593645281025, 0.06243238704545157, 0.0788781081459352, 0.10461868013122252, 0.062200925179890225, 0.041775925284517665, 0.0443646279828889, 0.12717043608427048, 0.0470681184503649, 0.08003277118716921, 0.013760490010359457, 0.035540646474276266, 0.03838426460112844, 0.069300959551973, 0.023866714410749928, 0.014595880272931286, 0.1595596538058349, 0.009682676904568715, 0.011340739987125354, 0.024103633394198756, 0.053532070347240994, 0.08284648627574955, 0.07659797263996941, 0.0016123151913883962, 0.05558418416018997, 0.07449631219995873, 0.023018786517371024, 0.04087189272312181, 0.029599855254803385, 0.06298544736845152, 0.056004183766032965, 0.05356998009873288, 0.01592587337030896, 0.10956490864711148, 0.05522021119083677, 0.035200734356684346, 0.0816899776192648, 0.07717922609299421, 0.08899737907839672, 0.07911809919668095, 0.044274437108210156, 0.03296979942492076, 0.035753614867904356, 0.03468946500548294, 0.1498563994786569, 0.06603688041546515, 0.05751494877040386, 0.09973500575870275, 0.044786744617990086, 0.0764194093644619, 0.030169329339904443, 0.028958096834165708, 0.07388390720422779, 0.19921431238097803, 0.17184386535414628, 0.14084096252918243, 0.17696052151066916, 0.16573631736849034, 0.20927054062485695, 0.24515282948102268, 0.21820441766508988, 0.11342848704329558, 0.08200450574180909, 0.1195131955402238, 0.20366612635552883, 0.28084043306963785, 0.13357545382210187, 0.25130773921098026, 0.18764600956014224, 0.2503276360886437, 0.16658031993678638, 0.14151410997978278, 0.16272267193666526, 0.11545133564089026, 0.11788754777184554, 0.10482323129794427, 0.17207425513437816, 0.28532226543341366, 0.17771167334701332, 0.18796032055148057, 0.15959222348673002, 0.20956874319485255, 0.13641500073884213, 0.10346700264407055, 0.11290319915860891, 0.1404369492083788, 0.12086008755224091, 0.19285538074161324, 0.16993439995816775, 0.22707456669637135, 0.1837303875280278, 0.2367416551070554, 0.12868371845356055, 0.1450012642890215, 0.11527121173483984, 0.18314284405538014, 0.09221501927822828, 0.20069985623870576, 0.08786373026669025, 0.08830200960593564, 0.1405349296650716, 0.14426687226763793, 0.16176650752978666, 0.2566924845533711, 0.14508762822619506, 0.20042654233319418, 0.170325154704707, 0.1451230477541685, 0.1665195096284151, 0.16894732149583952, 0.22758876053350313, 0.08228472713381052, 0.2607102803885937, 0.13476736843585968, 0.4638514242001942, 0.17226841114461422, 0.2815953168485846, 1.339609322803361, 10.70404212815421, 39.222157205854145, 52.15619414193289, 70.9977354322161, 95.50284372057233, 104.57607936859131, 99.39340414319719, 98.83506774902344, 84.23288645063127, 86.7982725415911, 87.49664987836564, 83.71700354984829, 75.58907726832798, 84.07655893053327, 69.50795827593122, 97.62041841234479, 83.47833987644741, 92.7184087208339, 81.53392124176025, 91.34948853084019, 78.29352460588727, 58.78503268105643, 72.97007192884172, 37.64438806261335, 62.18939985547747, 98.6396427154541, 80.22048936571393, 86.96337563650948, 45.91423824855259, 22.181113038744243, 38.123931884765625, 62.22867802211216, 63.77046939304897, 44.59126649584089, 86.84996713910783, 77.56398459843227, 70.20137459891183, 80.02642617906842, 94.7824683870588, 88.88227353777204, 89.98718997410366, 94.78455979483468, 88.38116945539201, 91.22255883898053, 91.48131670270647, 82.94799777439663, 88.7295173917498, 85.11277157919747, 95.10478142329625, 93.4217609677996, 76.09673350197929, 38.21062108448574, 14.433799522263662, 0.9382023364305496, 0.319164688033717, 0.45076118090323036, 0.14417543288852486, 0.12478432697909218, 0.3174874037504196, 0.14315788820385933, 0.24705810153058597, 0.2359726849411215, 0.2653190259422575, 0.14645882536258015, 0.20526331636522496, 0.21042706285204205, 0.1613554238740887, 0.19269747207207338, 0.25570613890886307, 0.10700551526887075, 0.11995247911129679, 0.28900562492864473, 0.18483663031033107, 0.14821864664554596, 0.38325620176536696, 0.12849328081522668, 0.2287408858537674, 0.11063827640776124, 0.13044786878994533, 0.1949503304702895, 0.18195867831153528, 0.07174341420509986, 0.15480519964226655, 0.21237158136708395, 0.08452990451561553, 0.19969258457422256, 0.24005258030125073, 0.12585517737482274, 0.20528209821454116, 0.12408177182078362, 0.14480670115777425, 0.13575843668409757, 0.1374406199902296, 0.1593467837997845, 0.11216348063732896, 0.14640215411782265, 0.13965552113950253, 0.20795104785689286, 0.20213693912540162, 0.11942812081958566, 0.12114573722439152, 0.10107936004975013, 0.3265705449240548, 0.2529465912708214, 0.1290730754179614, 0.21239921131304332, 0.10474661112363849, 0.18649410137108394, 0.13627850663449081, 0.1807484839643751, 0.24757609516382217], [0.039472946897149086, 0.09833783430180379, 0.05328234571165272, 0.05678164240505014, 0.04396558493109686, 0.06845366608883653, 0.04894189290436251, 0.07489170812602554, 0.09520697873085737, 0.08421361220202275, 0.15280531266970293, 0.07136783828692776, 0.07557345261531216, 0.05547235141109143, 0.03457413101568818, 0.05197502925459828, 0.18808808869549207, 0.019925893284380436, 0.021761288101385747, 0.13508811193917478, 0.06930143452648606, 0.17875181324779987, 0.07247943471052817, 0.026920434120776396, 0.08350699261895247, 0.06239705572703055, 0.06969544624111482, 0.014052805440899516, 0.02384384608428393, 0.053830310236662626, 0.0375211918061333, 0.02127028998386647, 0.023507307982072234, 0.041856440249830484, 0.026707754104531238, 0.07034871940101896, 0.03171007202139922, 0.05935462683971439, 0.02937175553025944, 0.03010526206344366, 0.06468808172004563, 0.043199006601103714, 0.05781304956014667, 0.08059900187488113, 0.06793771484600646, 0.015249977852883083, 0.061016155539878776, 0.062246834859251976, 0.06021555885672569, 0.023888308787718415, 0.015793101030534933, 0.0893403310328722, 0.019981141301936338, 0.03619656252807804, 0.04445849312469363, 0.027424337974350368, 0.03054511221125722, 0.04845905077776738, 0.02827951092539089, 0.061201341317168305, 0.04363981687596866, 0.15252027367906912, 0.017353573814034462, 0.020181385467627218, 0.06107338996870177, 0.25373732884015354, 0.014138391607307961, 0.021307136131716625, 1.1639414919274194, 4.014498046466282, 13.077424304825918, 22.094455105917795, 27.508415017809185, 41.70475203650338, 56.068589278629844, 62.74010712759835, 61.60894039699009, 61.93852819715227, 64.96487167903355, 61.923395020621165, 69.8065710067749, 73.54186698368618, 71.08722128186906, 68.89606516701835, 72.81537028721401, 65.86134215763637, 74.32963984353202, 62.7383839743478, 69.45896652766636, 55.2134883744376, 52.872164317539756, 59.48422295706612, 65.56322969709123, 75.53401279449463, 76.38856479099819, 75.68535845620292, 67.66860335213798, 57.77776275362287, 55.79989549091884, 46.87948547090803, 46.98620980126517, 57.35067088263375, 61.801996094839915, 61.65719563620431, 69.26857198987688, 77.64001873561314, 72.92708342415946, 76.14459269387382, 72.6686451775687, 73.62429346357072, 49.132980823516846, 23.69932917186192, 21.61840796470642, 17.370296716690063, 6.5796075122697015, 1.510392244373049, 0.07921636463808161, 0.32877116969653536, 0.09251002594828606, 0.027625545659767728, 0.027305197403100983, 0.01446297561882862, 0.05865852454943316, 0.17257403688771383, 0.0353037732919412, 0.0221223959566227, 0.09901047963649035, 0.10242653704647507, 0.17912764022392885, 0.06256146476204906, 0.04413355627496328, 0.10000771576804773, 0.06794287849749837, 0.0154724440404347, 0.03741384417350803, 0.036023956790034256, 0.035496741865894625, 0.04632993681090219, 0.02142222415256713, 0.013241540490915733, 0.07459697286997523, 0.04539480020425149, 0.06304099903042827, 0.10031997758362975, 0.016301776681627547, 0.059462228922971656, 0.07553223839827947, 0.05677822258855615, 0.05216517173019903, 0.08889221972120659, 0.038327478005417755, 0.032186118619782586, 0.09951896020876509, 0.046952672502292056, 0.05288891753713999, 0.04504706118521946, 0.02668519620783627, 0.026583767096911157, 0.05944226642272302, 0.0393406020344368, 0.04650652894218053, 0.05345941621011921, 0.011915686457151813, 0.022243660342480456, 0.019934578532619134, 0.05013708484226039, 0.018977552386266843, 0.07976656154330287, 0.030461506518934454, 0.07331453489937953, 0.0920159031770059, 0.03089675959199667, 0.052602321308638365, 0.07125344406813383, 0.06395071092993021, 0.023619286616199782, 0.09281371786658253, 0.09699310681649617, 0.037110342245016775, 0.0571700833471758, 0.018017467743317996, 0.052341407630592585, 0.05095814274890082, 0.031123339398098842, 0.07100487633475236, 0.019201679288276603, 0.05057004446695958, 0.09825083254171268, 0.03221177742151277, 0.014616884324433548, 0.027996122471189926, 0.024366343493706415, 0.07639794051647186, 0.0032065249480573194, 0.037176811535443575, 0.09284275916538068, 0.10122441726603679, 0.08167338065270867, 0.1233487640108381, 0.05049715284258127, 0.046965052373707294, 0.03102391705449138, 0.06550340939845357, 0.0414418553534363, 0.01091547664587519, 0.08983005011188132, 0.03689555537753871, 0.006957065347316009, 0.02977614543799843, 0.022555854304560592, 0.049039462847369056, 0.06465779870216336, 0.0372666156451617, 0.02915087202563882, 0.0940128860196897, 0.024657918472907374, 0.042154880307082615, 0.022074360766315033, 0.09221079879041229, 0.0691838376224041, 0.01795845724908369, 0.058720936200448444, 0.038298630089099915, 0.05852338072976895, 0.034282449167221785, 0.057205530016549995, 0.039736554359218905, 0.031945703484650166, 0.01609376328997314, 0.09856979149792876, 0.02382605489609497, 0.06756057829729148, 0.05371573959876384, 0.06771165411919355, 0.06581685186496802, 0.10776315389999322, 0.02025948484827365, 0.19339515534894808, 0.05674909986555576, 0.012392277579887636, 0.026589526162881936, 0.4197154625185898, 0.06456853742046015, 0.13894054879035267, 2.756082223994391, 10.030247517994471, 24.116507700511388, 38.24908978598458, 50.40422323771885, 64.84050587245396, 75.34021363939557, 80.70138113839286, 83.191664150783, 76.0754303250994, 77.88528319767543, 72.03935377938407, 69.74177210671562, 66.64280605316162, 57.133442401885986, 53.24833631515503, 46.791858264378135, 43.237847736903596, 39.421872752053396, 43.67969063350132, 39.44412088394165, 47.740172726767405, 63.98469625200544, 52.5200400352478, 50.71167060307094, 32.788743700299946, 20.05050700051444, 32.10258477074759, 37.66843230383736, 26.610539266041346, 26.398007767541067, 46.339613914489746, 44.13066346304757, 36.270791734967915, 51.31764384678432, 56.89699520383562, 60.06981018611363, 71.72296060834611, 76.90284265790666, 81.7930543082101, 85.0851663861956, 87.94559383392334, 76.91362626211983, 55.27959353583199, 48.144241741725374, 35.637376580919536, 15.338431528636388, 4.779112560408456, 0.16577394892062458, 0.1507515771580594, 0.1391636375337839, 0.11890259544764246, 0.034768083465418646, 0.007760364296180862, 0.07881057355552912, 0.02024643831620259, 0.03329962172678538, 0.06805189193359443, 0.04457139117377145, 0.09480021055787802, 0.07656892455582108, 0.010988240196768726, 0.06640391357775245, 0.09535960839795214, 0.06532580285732235, 0.054325630622250695, 0.051524465038840256, 0.029458058399281332, 0.024670747873772467, 0.018173283132325326, 0.013679565379529126, 0.019568639508049403, 0.08468273095786572, 0.019279147631355693, 0.034231284234140597, 0.08152956515550613, 0.06659444621098892, 0.011687460355460644, 0.08706689266754047, 0.11266108429325478, 0.04646554881972926, 0.06123712046870163, 0.0475367622316948, 0.020344171107613614, 0.039730267732271125, 0.09677508672965424, 0.031210385262966156, 0.033669362243797095, 0.04017364626218166, 0.03681508112432701, 0.03425727551802993, 0.03772886762661593, 0.056819633580744267, 0.05317317960517747, 0.03127262728022678, 0.013224109774455428, 0.02625570389708238, 0.03773388878575393, 0.01384303973255945, 0.1928490296538387, 0.07082133261220795, 0.1136386836213725, 0.14587652018027647, 0.0705575453383582, 0.059204582391040664, 0.09176294532205377, 0.0680029084905982, 0.010628486867062747, 0.20207627809473447, 0.22778539998190744, 0.12196889519691467, 0.13670567157013075, 0.14210724458098412, 0.12574388406106404, 0.20425434836319514, 0.15821795937206062, 0.22007151533450398, 0.16608380872224057, 0.22300004533358983, 0.22298146704477922, 0.1256732621363231, 0.13291551066296442, 0.1889701435076339, 0.17632349926446164, 0.21179629223687307, 0.04956096450665167, 0.17895574016230448, 0.21486879379621573, 0.20171385897057398, 0.29354035588247435, 0.2024343545947756, 0.16729738217379364, 0.2688478151602404, 0.2142344992607832, 0.1997686754912138, 0.16405888380748884, 0.07197976830814566, 0.12735117067183765, 0.12109606846102647, 0.09066914687199251, 0.13779093404965742, 0.13031885214149952, 0.13961199990340642, 0.15707841409104212, 0.11762408619480473, 0.15806660535080092, 0.14743793782378944, 0.08464725714709077, 0.1913746137704168, 0.09224270350698914, 0.1496628270085369, 0.18568923670266355, 0.11877120392663137, 0.1346394374434437, 0.2715620638004371, 0.1690723890704768, 0.12044242210686207, 0.15825945857380116, 0.18290147557854652, 0.23142316192388535, 0.060565262234636714, 0.1921693275549582, 0.20178395163800034, 0.149615967380149, 0.1364737618714571, 0.2537041891898428, 0.14025424686925753, 0.27745964590992245, 0.07433999808771269, 0.4562404326030186, 0.1099828387211476, 0.07986810430884361, 0.2161137562777315, 0.43440186445202145, 0.2596571668982506, 0.18475597963801452, 1.8686016287122453, 7.694018227713449, 19.781266042164393, 34.98547574451992, 50.15947641645159, 74.67622988564628, 87.00349453517369, 95.97986534663609, 101.85207980019706, 95.5796491077968, 100.84717573438371, 97.51951667240688, 96.02589716230119, 98.13277857644218, 95.08456216539655, 96.95601776668003, 96.95767143794468, 86.36522606440953, 94.58011599949428, 80.2584056854248, 90.47918496813092, 70.68383666447231, 71.25124740600586, 79.6024193082537, 89.51730414799282, 101.2217183794294, 100.19508034842355, 104.67579296657017, 101.95562880379813, 89.29596928187779, 87.88033635275704, 66.16226863861084, 68.57289750235421, 88.28302615029472, 87.6379623413086, 87.87519468579973, 89.34642015184674, 101.33873994009835, 95.18785408564976, 98.72986507415771, 93.41425691332135, 92.93802043369838, 81.45387799399239, 56.93457801001412, 48.25660106113979, 32.997874055589946, 11.5280567918505, 2.8626460943903242, 0.19681510754993983, 0.5569750900779451, 0.15989094174333982, 0.24627488212926046, 0.23074451833963394, 0.0822942266240716, 0.18860255394663128, 0.2417931311896869, 0.18539619099880966, 0.16898251032190664, 0.14930253848433495, 0.13618881787572587, 0.33386517635413576, 0.1636713860290391, 0.10517488207135882, 0.16527063878519194, 0.1530243166323219, 0.12695390198911938, 0.1256920439856393, 0.07972909962492329, 0.1705631712185485, 0.17147077965949262, 0.11602582409977913, 0.16283529517906054, 0.2841698686991419, 0.09883328700172049, 0.12677936921162264, 0.22452490351029805, 0.1299121653927224, 0.12833088024386338, 0.32902716738837107, 0.19681189129395144, 0.130526850266116, 0.12233500555157661, 0.12845575782869542, 0.14625160076788493, 0.23134656889098032, 0.14067803270050458, 0.22250217704900674, 0.19109085042561802, 0.07663309361253466, 0.1874921042472124, 0.1453287931425231, 0.10554426296481065, 0.19502571571086133, 0.16897442218448433, 0.10952612358544554, 0.15279803877430304, 0.18535670026072434, 0.09302903738405023, 0.12119859510234424, 0.2848213980240481, 0.16676541071917328, 0.1531780455261469, 0.22072774012173924, 0.27733208132641657, 0.11506841118846621, 0.17005497563098157, 0.16933059878647327, 0.07003032362886838], [0.07260644968066897, 0.15286161750555038, 0.026691806835255454, 0.09370782346065555, 0.03502491914800235, 0.05278029086600457, 0.07354383223823138, 0.05950385704636574, 0.03964986472523638, 0.11004887374916247, 0.08187997420983655, 0.031203484561826502, 0.047176897791879516, 0.04484615035887275, 0.06675382051616907, 0.007471123477444053, 0.016700029240122864, 0.06747990726892437, 0.11954812652298383, 0.12152959805514131, 0.051283086383981366, 0.10797101631760597, 0.04222980753651687, 0.04133671974497182, 0.012095575420452016, 0.07634031253733806, 0.14191846256809576, 0.07150117041809217, 0.11834445968270302, 0.055459119978227785, 0.0715479961197291, 0.03312101773917675, 0.017255997085677724, 0.012538857259122389, 0.07366211446268217, 0.03629960485600999, 0.0429512598950948, 0.045900274866393635, 0.011651959403284957, 0.025472060411370227, 0.08349907411528484, 0.050286338797637394, 0.0217701972661806, 0.03464630339294672, 0.008705223461480012, 0.08098244879926954, 0.05636102193966508, 0.050574926526418755, 0.10615190464471068, 0.03910536412149668, 0.022313970141112804, 0.08701493724116258, 0.025324261913608228, 0.041649202084434886, 0.05693955107459, 0.027025169393579875, 0.019943143340892026, 0.05116327067038842, 0.019629643198900988, 0.03715882017942412, 0.02559452410787344, 0.22705619196806634, 0.019237499151911055, 0.0691086762983884, 0.03918950246380908, 0.005461465176527521, 0.0859637236488717, 0.07892627056155886, 0.012112371706669884, 0.2791961798710482, 0.26671965792775154, 0.23821700736880302, 0.1145514217870576, 0.38330972460763796, 3.5392762209687914, 11.071792909077235, 12.836045622825623, 22.371201855795725, 42.658208165849956, 43.79013572420393, 46.37510183879307, 49.74688196182251, 60.26796586172921, 63.20021683829171, 66.7052286693028, 62.042452403477256, 63.950775146484375, 66.63109139033726, 71.36971419198173, 81.16978699820382, 84.16562094007219, 80.89586121695382, 80.28464903150285, 77.26073047092983, 71.81523963383266, 69.88906696864537, 75.48127596718925, 67.84134946550641, 59.74113954816546, 67.99552304404122, 70.50208568572998, 70.92604391915458, 60.768951824733186, 59.46955530984061, 57.240305696214946, 42.58679805483137, 31.21877043587821, 20.026365484510148, 12.654366731643677, 6.328885240214212, 0.39379238496933666, 0.20514202144529137, 0.19202071481517383, 0.2857045792043209, 0.15759536278034958, 0.08615552514259305, 0.07931723565395389, 0.06627972809863941, 0.07449059214975152, 0.08783947942512375, 0.013879678079060145, 0.03975729378206389, 0.008862216956913471, 0.10831598352108683, 0.033797510367419036, 0.019878531540078775, 0.021138540535633053, 0.1057609599083662, 0.037746869160660675, 0.02472821470083935, 0.04368917690590024, 0.02541060888740633, 0.04681684336225901, 0.06523405135210071, 0.005227784925539578, 0.04736941514004554, 0.05372771234916789, 0.07379194535315037, 0.013325962969767196, 0.0702689779656274, 0.048045059599514515, 0.05099529932652201, 0.09033684113195964, 0.034083658762808354, 0.04796515531571848, 0.1741867382079363, 0.05078194756060839, 0.10197861572461468, 0.06556801271757909, 0.017627800349146128, 0.0716988615957754, 0.04760318402467029, 0.038766137324273586, 0.043512774764427116, 0.08052975737622806, 0.10294802513505731, 0.05813344022525208, 0.01059989509771445, 0.032304421200283935, 0.07554766149925334, 0.11457229352423123, 0.05434488405340484, 0.015375734140564288, 0.06759754488510744, 0.030718610222850527, 0.06916066565151725, 0.05757717043161392, 0.053058402014098, 0.05305520611416016, 0.021828254418713704, 0.038123042189649174, 0.023579427772866826, 0.10216690919228963, 0.12499609775841236, 0.1190129252416747, 0.13069173427564756, 0.08217306062579155, 0.1728958524763584, 0.06234972790947982, 0.06862747283386332, 0.017904766469395587, 0.06825417000800371, 0.07508348247834615, 0.040801352222583125, 0.04892318230122328, 0.01918889399218772, 0.054299920930394104, 0.05558031990325876, 0.13399444919611725, 0.04471996998680489, 0.03550861283604588, 0.09179732669144869, 0.04075248073786497, 0.16596600147230284, 0.14955348787563189, 0.09754440973379783, 0.06250737873571259, 0.06482076245759215, 0.029157765941428285, 0.0318288665397891, 0.03231524383383138, 0.04120234266987868, 0.04042545739295227, 0.060078793338366916, 0.06003869870411498, 0.04025732320068138, 0.050470408384821246, 0.019303741133106605, 0.03127324474709375, 0.017333194014749358, 0.02761326587226774, 0.0359736807378275, 0.007480567836734865, 0.011421060721789087, 0.02587200252206198, 0.04251783547390785, 0.009480017154211444, 0.037522752436676195, 0.03469140900831137, 0.047045964282006025, 0.06240664342684405, 0.045912342611700296, 0.06183497088828257, 0.04088382136874965, 0.018682401527517607, 0.08787139771240098, 0.08331838702516896, 0.12249898032418319, 0.041594980351094685, 0.02566615365711706, 0.030033123612936054, 0.03641520008178694, 0.04848132368975452, 0.053121943425919325, 0.02576146916752415, 0.09427883103489876, 0.07644351771367447, 0.2069352130804743, 0.05037124049184578, 0.09003717971167394, 0.017154169335429157, 0.025471688913447515, 0.06047363965106862, 0.025342003908008337, 0.1540917879236596, 0.26899570865290506, 0.15883162644292625, 0.17627022069479736, 0.5080771967768669, 1.4178669920989444, 8.323777760778155, 22.562794957842144, 27.0157755783626, 43.232591424669536, 63.86579172951834, 62.366877692086355, 73.03439835139683, 77.17452417101178, 82.38591630118233, 83.55998120989118, 87.24925231933594, 85.83723940168107, 84.01897920880998, 83.023038319179, 88.55697972433907, 87.79576287950788, 85.68469170161656, 81.57319940839494, 80.3743085861206, 82.51677867344448, 79.36294269561768, 74.86058643886021, 75.1731789452689, 73.1582360948835, 72.14718982151577, 81.81407260894775, 81.54697690691266, 82.32400785173688, 89.28463676997593, 82.8028290612357, 82.62139075142997, 70.70099871499198, 58.020320892333984, 42.384317125592915, 29.723511150905065, 17.527579614094325, 2.631684933389936, 0.5423556459801537, 0.4575129843183926, 0.36228979538593975, 0.12560477081154073, 0.12596690495099339, 0.19174413037087235, 0.02599633897521666, 0.07074826117604971, 0.052877263698194704, 0.09720121350671564, 0.03948722327394145, 0.04530528107924121, 0.07965972620461668, 0.01650242627199207, 0.03471544611134699, 0.03196835298357265, 0.07142954426152365, 0.03899298854438322, 0.04073999908619693, 0.040410417664263926, 0.05706554824220283, 0.04891330961670194, 0.009351848674538945, 0.029107981827110052, 0.03189783623175962, 0.051661501971206496, 0.06787205301225185, 0.053239146779690466, 0.0964666586369276, 0.02734588405915669, 0.05654209579474159, 0.021451440174132586, 0.04586231761745044, 0.0069625055018280235, 0.057867122015782764, 0.04120785576690521, 0.026177495950832963, 0.0818471670416849, 0.032717693131417036, 0.02034215416227068, 0.03733722060652716, 0.06667918166411774, 0.08346090652048588, 0.05460584183622684, 0.057982377974050384, 0.08861729090235063, 0.04691590268963149, 0.0016300020548182406, 0.03330805591706719, 0.0344842556597931, 0.07179988867470197, 0.030255737381854227, 0.051125211641192436, 0.027751296858436296, 0.03470961071018662, 0.020603368092062216, 0.027870885262797986, 0.0628185820366655, 0.04135197660486613, 0.04917225554319365, 0.08578957763633557, 0.06159550230950117, 0.16149426570960454, 0.10349868344409124, 0.13148950146777288, 0.1722640956618956, 0.3135008476674557, 0.15856080954628332, 0.14444943889975548, 0.08828019470508609, 0.23595352311219486, 0.1584801860153675, 0.10550021247139998, 0.09493663680872746, 0.1835642278726612, 0.14728367967264994, 0.11398523859679699, 0.19548868015408516, 0.14541852261338914, 0.2016058090542044, 0.14250508323311806, 0.09886770229786634, 0.24006036988326482, 0.403599061604057, 0.14887454573597225, 0.20846984216145106, 0.24090232327580452, 0.12969602484788212, 0.1699555702507496, 0.13446632958948612, 0.1909176204353571, 0.2663637798811708, 0.1741764380463532, 0.21727044135332108, 0.12441054917871952, 0.16248487255402974, 0.10232791198151452, 0.16598466118531569, 0.13388551718422345, 0.10786219965666533, 0.09640463375087295, 0.1234681454620191, 0.16187533097607748, 0.08202435967645474, 0.10173524556947605, 0.21486355550587177, 0.23581898318869726, 0.19676969998649188, 0.14172749567244733, 0.1485404758048909, 0.2107312229595014, 0.14797361407961163, 0.17242543771862984, 0.15907834177570684, 0.17251523504299776, 0.159463016848479, 0.19875419778483255, 0.1670308807598693, 0.09601148377571787, 0.1628383757280452, 0.2232830487191677, 0.14411177273307527, 0.10964068065264396, 0.11287438177636691, 0.1909160598048142, 0.1089289313448327, 0.27566538218941006, 0.11575028459940638, 0.1374603382178715, 0.21558025133396896, 0.0700859906417983, 0.14983172794537886, 0.10000515090567724, 0.24294151099664824, 0.41482384928635185, 0.47102934760706766, 0.41471707501581734, 0.2880454435944557, 0.5554191278559821, 5.3449443238122125, 16.763399362564087, 21.477620090757096, 39.913023539951865, 60.413690430777415, 64.24633066994804, 77.0021254675729, 78.54916967664445, 87.87841170174735, 92.99828910827637, 99.44211796351841, 101.24136093684605, 100.27378259386334, 100.76941844395229, 101.22280229840959, 112.7043183190482, 110.80147075653076, 106.50395434243339, 102.91563361031669, 104.1295325415475, 101.66202572413853, 96.12586089542934, 99.83751215253557, 99.17745413099016, 99.20052215031215, 116.74108968462262, 112.05135440826416, 105.3344474520002, 97.85518414633614, 91.23452363695417, 85.64487852369035, 68.67873246329171, 53.371260370527, 35.96420594624111, 22.49526367868696, 10.992887428828649, 1.462137113724436, 0.2602562318955149, 0.2568193163190569, 0.5256594504628862, 0.27739428941692623, 0.19053302678678716, 0.3900614194571972, 0.14820013621023723, 0.1658723364983286, 0.2340334861406258, 0.14842999673315457, 0.08526125670011554, 0.11644093825348786, 0.2517744084554059, 0.12384789437055588, 0.09868223832121917, 0.06868000501500708, 0.19656137616506644, 0.07348725598837648, 0.2652197155569281, 0.14593690979693616, 0.08568141236901283, 0.12084712753338472, 0.1973407957702875, 0.14031713349478586, 0.09106577094644308, 0.20318425792668546, 0.15821995426501545, 0.20279111473688058, 0.22582380952579634, 0.13191910912947996, 0.14217308961919375, 0.17580318504146167, 0.1276581941970757, 0.22557614424398967, 0.25323475152254105, 0.12838048115372658, 0.18938429414161614, 0.15727898904255458, 0.08784324529447726, 0.23538412366594585, 0.11716313021523611, 0.13296686219317572, 0.11282818711229733, 0.1369565123958247, 0.1499850768595934, 0.19062757385628565, 0.1566669097436326, 0.1951308614973511, 0.16316952795854636, 0.22183255798050336, 0.16549709306231566, 0.07272314413317613, 0.12227353027888707, 0.11393164790102414, 0.15795102369572434, 0.13944946362503938, 0.14041402829544886, 0.1635572835803032, 0.19227102638355323, 0.1244744128946747, 0.15217958124620573, 0.1330270618200302, 0.21004394840981278, 0.15056763988520416, 0.2714809381536075], [0.007839608704671264, 0.04959376149677804, 0.07448753195681743, 0.08300394032682691, 0.013504685701004096, 0.03336306814370411, 0.11175753349172217, 0.04516889214781778, 0.10306469244616372, 0.07267973824803318, 0.042554493328290324, 0.04336507465424282, 0.022743699939123223, 0.038500599430075715, 0.05039668894772019, 0.05580142393176045, 0.08428962848016194, 0.028694367235792533, 0.06613062681364161, 0.017722674811791097, 0.007084576920273581, 0.057670129729168754, 0.03332319403333323, 0.007355245811465595, 0.04188950865396431, 0.05974934423076255, 0.05678223612319146, 0.047323671701763353, 0.08738230288560901, 0.009755074046552181, 0.021532307977655103, 0.0681035148778132, 0.025113736246047274, 0.0643196100635188, 0.039132278213011365, 0.03755174623802304, 0.05813672433474234, 0.012759291234293153, 0.03160645293870142, 0.022800691791677048, 0.03520414399515305, 0.035812281005616696, 0.02474482184542077, 0.022834450605192354, 0.04945440736732312, 0.04598358878865838, 0.026400657636778693, 0.035324329510331154, 0.05794568280024188, 0.08864806925079652, 0.05927505503807749, 0.10494654825223343, 0.010794436176573592, 0.020601179816627076, 0.015452808933332562, 0.004097270945619259, 0.03093667441446866, 0.06388699649167912, 0.06321454793214798, 0.09520570308502231, 0.0695808416764651, 0.1403157085712467, 0.07009715932820525, 0.08935527915933303, 0.12902599865836756, 0.03772286259170089, 0.10742843257529394, 0.026636114377262335, 0.042818813252129724, 0.12783063708671502, 0.05903250591031142, 0.07037988451442548, 0.04392837067799909, 0.03898604713114245, 0.20904509057956083, 0.36074384834085194, 0.36817809513636995, 0.2814297543040344, 0.10388846788555384, 0.07855336128601006, 0.1389296922300543, 0.2781619296542236, 0.550059189753873, 2.0775587132998874, 6.997417024203709, 4.850151377064841, 8.844065819467817, 10.693735344069344, 6.358011220182691, 14.290851627077375, 24.02080842426845, 32.84223788125174, 26.957676478794642, 33.679752894810264, 31.497987270355225, 25.848406996045792, 22.41648152896336, 18.998264857700892, 14.427127514566694, 13.890079532350812, 15.689501421792166, 7.879591584205627, 1.4027912467718124, 1.2510924211570194, 0.45267929083534647, 0.2871067582496575, 0.05552595228488956, 0.027830456450049366, 0.1992464613701616, 0.026184135415990437, 0.06157501733728817, 0.11448260476546628, 0.06839771409119878, 0.05615896438913686, 0.013418478675053587, 0.020540394953319004, 0.020641333822693144, 0.08006072004458734, 0.039072041266730854, 0.08417151588946581, 0.07493106315710715, 0.0318967403977045, 0.03800255472638777, 0.016064832253115516, 0.006145414480540369, 0.06353057561708347, 0.04724549089691468, 0.05473247004140701, 0.036342383096260686, 0.07403735111334495, 0.03075455900813852, 0.0566188516760511, 0.025279507440115725, 0.02154711530809956, 0.00992550338352365, 0.10629458020308188, 0.07880946754344872, 0.04153179517015815, 0.00782465803370412, 0.08705406157033783, 0.10035133268684149, 0.037016653522316895, 0.010402803575353963, 0.03661137134102838, 0.07134781471852746, 0.034916563890874386, 0.029673106502741575, 0.02981072697522385, 0.012789897404478064, 0.043889918098492284, 0.09253363218158484, 0.03278816577845386, 0.0646776051393577, 0.047206678693847995, 0.01730966242030263, 0.027481686057788984, 0.059664717343236716, 0.029287186318210194, 0.02808013867719897, 0.03820647146286709, 0.040774489021194835, 0.055226379074156284, 0.013696880745036262, 0.06304889717804533, 0.06903057013239179, 0.03992778588352459, 0.053679672069847584, 0.017413600414459194, 0.034208631342543025, 0.03265551896765828, 0.03197644790634513, 0.07327085081487894, 0.025482021305443983, 0.008591089630499482, 0.03098965442872473, 0.03518556570634246, 0.040340019656079154, 0.03307638709832515, 0.05350505108279841, 0.046781624002116065, 0.07321244930582387, 0.06042176564889295, 0.0693866042420268, 0.039870157904390774, 0.06243960665804999, 0.03376855727817331, 0.05212965042197278, 0.09903944629643645, 0.06626160442829132, 0.07467102139656033, 0.040911108654524596, 0.037461338232138326, 0.07805516730461802, 0.07982047115053449, 0.035484355209129195, 0.04258406388440302, 0.019435395586437414, 0.05555719882249832, 0.041550420956420045, 0.15398928842374257, 0.07181225158274174, 0.028560672088393142, 0.09541942125984601, 0.01684206527923899, 0.053359831018107276, 0.0556808584369719, 0.004342756009594138, 0.04680075868964195, 0.04529237195051142, 0.018104484770447016, 0.0297278642787465, 0.021861212560907006, 0.05203818729413407, 0.11145882202046258, 0.031763883241053135, 0.039421951597822566, 0.035396637594593425, 0.06324687334043638, 0.09004827375922884, 0.022824925669868077, 0.048067960156393905, 0.035255600698292255, 0.03335917674537216, 0.0201961792273713, 0.12332038767635822, 0.08402537301714931, 0.05813002719410828, 0.07333554912890707, 0.07052288576960564, 0.015436892198132617, 0.06432901455887727, 0.03430546846772943, 0.008057892572001686, 0.014718159068641918, 0.04001767481012004, 0.019401692752061144, 0.03434466743575675, 0.11977303374026503, 0.08917417816285576, 0.02233007686611797, 0.10502645253602948, 0.044310928721513064, 0.07811875282121555, 0.02195144584402442, 0.07088419888168573, 0.016854896376441632, 0.024488551043240086, 0.044429835198181014, 0.11112063338181802, 0.07727574091404676, 0.22310645319521427, 0.33437847452504293, 0.26967399939894676, 0.3838762470654079, 0.749131593321051, 1.634763804929597, 1.8838112354278564, 1.7722418393407549, 4.115956945078714, 8.349429641451154, 17.44559781891959, 14.887630667005267, 23.54266119003296, 28.396269730159215, 24.416252987725393, 36.81881352833339, 47.65368502480643, 57.84912770135062, 54.615498610905235, 57.46924189158848, 52.4402608190264, 48.92253725869315, 50.54897158486502, 41.467311246054514, 34.11951133183071, 32.892080783843994, 31.330702441079275, 23.767824513571604, 10.68659085886819, 8.161104798316956, 4.063818965639387, 1.955542266368866, 0.4827894451362746, 0.5582527443766594, 0.28926501529557364, 0.10063453284757477, 0.07689313537308148, 0.11774045495050293, 0.1154415240245206, 0.1875630518687623, 0.033371804282069206, 0.05809661612979003, 0.07666583971253463, 0.05124510877898761, 0.04364168284726994, 0.0742576646485499, 0.03713276443470802, 0.07281518062310559, 0.04162171802350453, 0.03834299610129424, 0.018621623449559723, 0.041359996888786554, 0.054302842023649385, 0.0544882347541196, 0.019949816732800434, 0.082724064987685, 0.07205299580735819, 0.053561237175017595, 0.030053835894380296, 0.01790193697836782, 0.08099684052701507, 0.03461968107149005, 0.025373114738613367, 0.07152685296854802, 0.04930302281198757, 0.0071690184829224434, 0.009393048472702503, 0.016888514393940568, 0.014193773635530045, 0.05252258665859699, 0.021944789415491477, 0.028149883595428297, 0.0719876257436616, 0.05447881329538567, 0.02791226402457271, 0.03087622033698218, 0.031739415268280675, 0.008777573106012173, 0.1326424138886588, 0.014872724256877388, 0.02505482583572822, 0.03311022224703005, 0.010429760075307317, 0.03806793836078473, 0.01469926186837256, 0.05799744823681457, 0.00940403395465442, 0.04972458304837346, 0.0575322989108307, 0.0030739593494217843, 0.060355119939361296, 0.003591259816728, 0.0426782038328903, 0.06695639714598656, 0.039721623196133544, 0.03948776949463146, 0.05468832116041865, 0.039251089694776704, 0.07091758958995342, 0.04325561677770955, 0.04937596871916737, 0.023957638103248816, 0.1138897958610739, 0.13241424970328808, 0.13142632985753672, 0.13074509426951408, 0.20763251637773855, 0.10394565481692553, 0.1802438303296055, 0.11407495449696269, 0.15918211692145892, 0.1410947074847562, 0.20997913474483149, 0.2978669394339834, 0.15081649938864367, 0.1863430594759328, 0.11203576677611896, 0.13791385745363577, 0.12490328773856163, 0.12881394289433956, 0.18367514120680944, 0.1629595620823758, 0.10148145311645099, 0.18720451396490845, 0.0805472025115575, 0.19555356167256832, 0.0833697724821312, 0.10461523995867797, 0.2613682150840759, 0.1031598909092801, 0.19283119775354862, 0.09301687125116587, 0.10546530184469052, 0.19892228447965213, 0.1719251267079796, 0.129868888429233, 0.1083814621503864, 0.2538879636142935, 0.09902042017451354, 0.23572390686188424, 0.09510867257735559, 0.138165946783764, 0.08739523576306445, 0.175805926322937, 0.12671816535294056, 0.2019029531095709, 0.10249554405787162, 0.15774028428963252, 0.13916681307767118, 0.16932017648858683, 0.21199168318084308, 0.2023324386349746, 0.18023928414498055, 0.18480495629566057, 0.20047991589776107, 0.2602632886597088, 0.1566854744617428, 0.10307305878294365, 0.12433349474200181, 0.18710270657071046, 0.21533535447503838, 0.13481376666043485, 0.12171797294701849, 0.3648638315498829, 0.15181644287492546, 0.18507596318210873, 0.24151254338877542, 0.16228265554777213, 0.2619242066783564, 0.1466553426746811, 0.18052245037896292, 0.1869021723312991, 0.08495398211692061, 0.271863333348717, 0.16573752516082355, 0.11992163290934903, 0.4921449231249945, 0.6988372749515942, 0.5714383625558445, 0.47361310039247784, 0.30294604546257425, 0.5546398439577648, 0.7294123885887009, 0.5481243335774967, 1.5783252162592751, 3.8130684665271213, 10.449985589299883, 8.840929576328822, 17.73676208087376, 21.517827578953334, 18.55787066050938, 27.450771025248937, 36.394719805036274, 49.0776766368321, 45.346546104976106, 47.72817666190011, 44.34390715190342, 41.4301210130964, 40.40152359008789, 32.654136248997276, 27.831582682473318, 24.133622850690568, 21.046235970088414, 14.325399807521276, 5.633652397564479, 3.5488999102796828, 1.2637685409614017, 0.5483678462249892, 0.167943713920457, 0.29744027661425726, 0.3931196310690471, 0.354161760104554, 0.18519875087908336, 0.24279155475752695, 0.16754454533968652, 0.32306550443172455, 0.1091474060501371, 0.16550465194242342, 0.21563865962837422, 0.20910626729684217, 0.1193390427423375, 0.2661275682704789, 0.12092012433069092, 0.2353631162217685, 0.0958636717072555, 0.1577796528914145, 0.10155580698379449, 0.2619788151766573, 0.08698068479342119, 0.17718935066035815, 0.11701287542070661, 0.24001637367265566, 0.17204241827130318, 0.14536459265010698, 0.08995440522474901, 0.10924580041319132, 0.17891966924071312, 0.16153210082224437, 0.16747642042381422, 0.136873527563044, 0.1447765063494444, 0.1489308098597186, 0.170695051284773, 0.1680405680090189, 0.08995716007692472, 0.14223243429192475, 0.14292543567717075, 0.13934317789971828, 0.1221026208783899, 0.07156996708363295, 0.1276004101548876, 0.21612446356032575, 0.13131560651319368, 0.11205629246043307, 0.2604357451200485, 0.11142779261405979, 0.07788260227867536, 0.09031153177576405, 0.14273225675736154, 0.22179603922579968, 0.15237411723605224, 0.12607040868273803, 0.1428046157317502, 0.13405646729682172, 0.11327561988894429, 0.1458564762558256, 0.12359671427735261, 0.13721237438065664, 0.1425420633916344, 0.15126175406788075, 0.13776756530361517, 0.08099013660103083, 0.1675070630652564, 0.10524952092341014, 0.16064412918473991, 0.08754112757742405, 0.1659478438752038, 0.1544922457209655], [0.041751097688185315, 0.03616611666179129, 0.02561049342953733, 0.028514999896287918, 0.05554031687123435, 0.05148487930585231, 0.06715355228100504, 0.05517000299213188, 0.029701574439448968, 0.06409001416925873, 0.03417997341603041, 0.0359619861867811, 0.03303511181314077, 0.0405980902723968, 0.006871700977041785, 0.013702186040713318, 0.06210241546588285, 0.03591718251949974, 0.01691009011119604, 0.06435832727168288, 0.05373190908825823, 0.03157460589760116, 0.023431505442463925, 0.0335089599580637, 0.051786294739161215, 0.008048912161029875, 0.052646039319889884, 0.09081766461687428, 0.015943518673468913, 0.027425708615088036, 0.01962219797340887, 0.01724934235348233, 0.06254901364445686, 0.030762287522000924, 0.025699412051056112, 0.02726465493573674, 0.025514928557510887, 0.012932967361328858, 0.008651603079800094, 0.05802535638213158, 0.018508467557174817, 0.036736849429351945, 0.010565450115661536, 0.06393537603850875, 0.020142580049910715, 0.042276758767132244, 0.037512856003429206, 0.020662081727225865, 0.05806762911379337, 0.08063200581818819, 0.05583971705553787, 0.02650853622305606, 0.020646587380075028, 0.021879595770899738, 0.02937048327709947, 0.03542828446786318, 0.01709019366119589, 0.09743001551500388, 0.03171847228493009, 0.014953817673293608, 0.02504861554397004, 0.057177377598626275, 0.006730779007609401, 0.057995534768061976, 0.04274253913068345, 0.007102415605913848, 0.044305995771927495, 0.02492161244819207, 0.022960110201633403, 0.038595668971538544, 0.1310942955315113, 0.0662607087620667, 0.04728109362934317, 0.056258831173181534, 0.06723898662520306, 0.045529228169471025, 0.13791634089180402, 0.09673077160758631, 0.010681639059579797, 0.04425677823434983, 0.020527109237653867, 0.04041796975902148, 0.11298067428703819, 0.09660602972975799, 0.28158095904758995, 0.20109105881835732, 0.28675831694688114, 0.29546934951628956, 0.2885364858167512, 0.3604464057300772, 0.18147971401257174, 0.06220166478306055, 0.1544947698712349, 0.17091524946902478, 0.22700444688754423, 0.27317068033984726, 0.28681740377630505, 0.20864495847906384, 0.06986615886645657, 0.29392633374248234, 0.19908910909933702, 0.2885160483419895, 0.07235390573207821, 0.048735010969851694, 0.00915556715335697, 0.0426331728563777, 0.05894773653043168, 0.007180321179995579, 0.2207532258970397, 0.04240827920979687, 0.030664235819131136, 0.1587680477116789, 0.08703207025038344, 0.11806586677474634, 0.0632452652124422, 0.055463530455849, 0.06408332381397486, 0.06276817367013011, 0.06018161174974271, 0.014687640259840658, 0.015468588265191232, 0.13623016779976233, 0.04586134391969868, 0.06698563521994011, 0.07732370655451502, 0.06839968862810306, 0.016837101795577576, 0.0354409798580621, 0.07923843738223825, 0.05913848629487412, 0.02585309344742979, 0.045908634417823384, 0.028231599567724124, 0.02252131517577384, 0.0014719533314096875, 0.06211274955421686, 0.029748457816562483, 0.018032819598114917, 0.034253228056643686, 0.03941401613077947, 0.03698480308854154, 0.02388446488683777, 0.04067378763907722, 0.039052770872201235, 0.08820250244545084, 0.007342404536237674, 0.025012312224134803, 0.06946360439594303, 0.09138897074652569, 0.021084412100857923, 0.09810878802090883, 0.06718661729246378, 0.01679565348396344, 0.04737784593765225, 0.0626530669895666, 0.025421248316498737, 0.05146923228832228, 0.053641175385564566, 0.04118533518963626, 0.051816954343978844, 0.026824356954810873, 0.02852928645110556, 0.022994539068479623, 0.013673092155451221, 0.022280399621065174, 0.08008049934038095, 0.006083416735886463, 0.0352289715914854, 0.019599215992327248, 0.02456618732373629, 0.043698486406356096, 0.06510825774499349, 0.019035651947238615, 0.03371252046365823, 0.02110913282792483, 0.04912792006507516, 0.0041118615689421335, 0.06279800885490008, 0.057833113840648105, 0.024059294523405175, 0.00890684250875243, 0.018810212079967772, 0.021456128851111447, 0.020145596138068607, 0.025916363445243666, 0.054569200945219824, 0.05280054174363613, 0.008975424587593546, 0.07425077751811061, 0.03996721216078315, 0.04005186279703464, 0.012295069804947292, 0.06052954415125506, 0.024864778355030075, 0.03569929813966155, 0.07252375661794629, 0.04802518191614321, 0.027746621752157807, 0.02242024738474616, 0.050325571692415645, 0.020625488333670155, 0.04432947986892291, 0.042697908489831855, 0.061990070422845225, 0.016033275285735726, 0.022074119886383414, 0.001880964168646772, 0.014433564518445303, 0.03221480029502085, 0.04570124697472368, 0.025995590890358602, 0.016624703371365155, 0.007270078640431166, 0.05237245400037084, 0.04347335187984364, 0.03590358467772603, 0.05333087792886155, 0.016274202714807222, 0.024953829290877496, 0.008870369555162532, 0.05642794584855437, 0.014711648525137986, 0.03591180173680186, 0.045711509816880734, 0.040039577920522006, 0.06400060360985142, 0.04995932563074997, 0.03818376089579292, 0.01924390282614955, 0.045666502589093785, 0.038090994980718405, 0.01386995127956782, 0.02960709183077727, 0.06844604614057712, 0.005524466304840254, 0.054909849273306985, 0.026192615407385995, 0.07337251571672303, 0.029615193538899933, 0.02400690483461533, 0.05626221367024949, 0.030059915568147386, 0.07177187196378197, 0.02806325163692236, 0.006237530274250145, 0.046741648111492395, 0.04984649204249893, 0.05427767515980771, 0.052756959439388344, 0.07165724704308168, 0.006583221813863409, 0.13174947537481785, 0.09220516016440732, 0.07038069197109767, 0.073133461044303, 0.18026183864900044, 0.05257342250219413, 0.16944270634225436, 0.21504609499658855, 0.18101779451327665, 0.2030225766024419, 0.1622678092015641, 0.29992604894297464, 0.15708164391773088, 0.5381347239017487, 0.20692304016223975, 0.4112172456724303, 0.11416719454739775, 0.4431201166340283, 0.7169897694672857, 0.7667285033634731, 1.3342422736542565, 0.8290390798023769, 0.5709846669009754, 0.48636749599661144, 0.3486600081835474, 0.32477134146860664, 0.05707111901470593, 0.18926169643444674, 0.08081323573631899, 0.05129938818780439, 0.06648892723023891, 0.0637461869046092, 0.10837258691234247, 0.0794696006923914, 0.015972551490579332, 0.05577904923952051, 0.13933913383100713, 0.0910676165616938, 0.1038882846810988, 0.04861011302896908, 0.0434453080275229, 0.04054656571575573, 0.03631763692413058, 0.03546433164072888, 0.08342187718621322, 0.013851273755010749, 0.0753253802124943, 0.0161130862709667, 0.06286409816571645, 0.03150971420109272, 0.04418082980971251, 0.051856037961052995, 0.0032707334446188596, 0.0501965211172189, 0.05411271990409919, 0.017984643611790876, 0.0311393256831382, 0.025508745407153453, 0.05974920852375882, 0.011067363317124546, 0.038483690337410996, 0.056042259758604426, 0.039011705932872634, 0.045900590385177305, 0.028665122376488786, 0.0016438752333799908, 0.029821671745074645, 0.03386344361518111, 0.044316933756428104, 0.0452197890595666, 0.03584940704916205, 0.01555959677456745, 0.007756826584227383, 0.012940315047412046, 0.03191910491191915, 0.042304989216583114, 0.032086611459297795, 0.0007085676677109275, 0.09742774242269141, 0.03581932419911027, 0.014072024945302733, 0.02181481772900692, 0.04921960032411984, 0.02749690559825727, 0.004455575603060424, 0.03593177102240069, 0.01774817076511681, 0.027089553885161877, 0.0560708871510412, 0.016367453782420074, 0.04476931305336101, 0.03685432080445545, 0.009321934610073055, 0.00882998654352767, 0.030496037166033472, 0.06181715255869286, 0.027349936609555568, 0.045168152544647455, 0.025118631876206825, 0.05541995832962649, 0.056549807345228534, 0.23772737649934633, 0.13840134415243352, 0.08267811459622212, 0.10889656522444316, 0.18270651889698847, 0.15432633033820561, 0.0970002653609429, 0.143118288900171, 0.07968667083020721, 0.0892068360533033, 0.07916082654680524, 0.14585404710045882, 0.15952715197844164, 0.14841405116021633, 0.06937243643083743, 0.08965041475104434, 0.19707368367484637, 0.10770777865712132, 0.11205163771020514, 0.15969754569232464, 0.1677614458437477, 0.2014301906206778, 0.14540774747729301, 0.11078080268842833, 0.14984958698706968, 0.08208525140902825, 0.16328861085431917, 0.18551547745508806, 0.10435784448470388, 0.11711698983396802, 0.11977065886769976, 0.12463875407619135, 0.13501416519284248, 0.1445550053779568, 0.0775393924808928, 0.09435095930738108, 0.12818338030150958, 0.06755122129938432, 0.12452561514718191, 0.18856234396142618, 0.15107054289962563, 0.09017544479242393, 0.07669607523296561, 0.313142934015819, 0.07594661973416805, 0.12802473881414958, 0.1740927475371531, 0.13479608403784887, 0.12140413693019322, 0.14017781668475696, 0.03854926735428827, 0.1794573132480894, 0.12033161733831678, 0.12715724536350795, 0.1766177663313491, 0.1584815430854048, 0.05915259982326201, 0.11087311737771545, 0.23121943856988633, 0.18591630166130407, 0.1188962986426694, 0.20013352377074106, 0.12500721216201782, 0.15337954328528472, 0.1390004770031997, 0.20443094388714858, 0.21966149019343512, 0.14261668867298535, 0.1450544342930828, 0.08674401177891664, 0.14406931001160825, 0.25204709810870035, 0.14330370537936687, 0.16638483399791376, 0.17035540379583836, 0.2584132765020643, 0.24852897546121053, 0.25896090854491505, 0.2012179855789457, 0.24286073818802834, 0.11143472045660019, 0.1491403007613761, 0.26524037016289576, 0.21474924949663027, 0.32413037014859064, 0.30325640738010406, 0.4396529926785401, 0.46647572623831884, 0.6268621342522758, 0.4039134947316987, 0.28626249783805435, 0.12368877790868282, 0.25080185064247673, 0.3177508110446589, 0.3216095582715103, 0.6696307935885021, 0.5816814729145595, 0.33593573953424183, 0.335074570029974, 0.31442267820239067, 0.3198264496667044, 0.34341631670083317, 0.19175916670688561, 0.14688334401164735, 0.07403632652546678, 0.16198036819696426, 0.20553702382104738, 0.1867980579180377, 0.28920883259602953, 0.10111193651599543, 0.09144058690539428, 0.3461418018809387, 0.26690041965671946, 0.2455139458179474, 0.17354212994022028, 0.1889042713280235, 0.19048194667058332, 0.19462035889072077, 0.1638757200645549, 0.1611816646265132, 0.12364254253251211, 0.3177908446107592, 0.10882246241505657, 0.19924152163522585, 0.1071192580940468, 0.18955677774335655, 0.13070766627788544, 0.1115210165402719, 0.20883087707417353, 0.23586688776101383, 0.11191827843763999, 0.22862444924456732, 0.11660724718655859, 0.17042088242513792, 0.0928947620892099, 0.19482182950845786, 0.2315033104802881, 0.12339642431054797, 0.11772304374192442, 0.1817739267966577, 0.1254472014095102, 0.1352348926344088, 0.09336217093680586, 0.10841395719242947, 0.25779871376497404, 0.19877359031566552, 0.12674663668232306, 0.17252815434975283, 0.15095460840633937, 0.11331800118620906, 0.24057326093316078, 0.10089766872780663, 0.139880984755499, 0.15364980378321239, 0.17446823524577276, 0.14487878871815546, 0.1560285304273878, 0.195766988077334, 0.16061559000185557, 0.14578133528786047, 0.1111833503735917, 0.0473424264096788, 0.09221951796540193, 0.13536483209047998, 0.1073646434981908, 0.1826600528189114, 0.13614426526640142, 0.10085355038089411, 0.05472394424889769, 0.08531556664300816, 0.12379503649260316, 0.1822094784251281, 0.0832470797800592, 0.15194049264703477, 0.08370361171130623, 0.1217477877757379], [0.015625460472490107, 0.01421605163652982, 0.08179031259247235, 0.025368146165939312, 0.012340857348005687, 0.016044221751924072, 0.013842592747615916, 0.012789303686336746, 0.017702591871576648, 0.02788682744306113, 0.03334596906123417, 0.05047257969688092, 0.03491633318896804, 0.049828602466732264, 0.01309846290054598, 0.03958310366475156, 0.021805706700044017, 0.007553082026009048, 0.03732939370508705, 0.03422078390472701, 0.01640241190658084, 0.03264522559142538, 0.017589307057538202, 0.032302439878029485, 0.051421700910265954, 0.023929119276415025, 0.040519427707684894, 0.026226365739213567, 0.044483286794275045, 0.04154923352013741, 0.030764516509537185, 0.019865820882841945, 0.008713316687914942, 0.07514681693698678, 0.016297820822468827, 0.06442304594176156, 0.04615010806758489, 0.04585644828953913, 0.011602076053220247, 0.03228242988032954, 0.05505269107275775, 0.0775058049974697, 0.04916772971461926, 0.0393504441848823, 0.022580707345956137, 0.016190049105456898, 0.02816415997222066, 0.025939498096704483, 0.03620147851428815, 0.026220623636618257, 0.04740145217095103, 0.03126898693985172, 0.031125191798699752, 0.044363535541508875, 0.06273595682744469, 0.05845359340310097, 0.07576122361102275, 0.008473601292020507, 0.026717318055619086, 0.03556630188333137, 0.02127031373259212, 0.02350978633122785, 0.04283361549356154, 0.03578138052086745, 0.0030948427489160425, 0.04207174280392272, 0.0464837505216045, 0.03168348362669349, 0.05234332788469536, 0.07672326413116284, 0.055472931558532376, 0.035707257355430295, 0.0520404841351722, 0.08901621521051441, 0.0385985018552414, 0.03538141466145005, 0.09189420113606112, 0.20082416385412216, 0.08988080453127623, 0.07347387527780873, 0.11087639470185552, 0.04646420871306743, 0.04943480449063437, 0.01216970113039549, 0.02396133272642536, 0.040608230978250504, 0.12557853864771978, 0.0648851418601615, 0.09398051311394998, 0.1262200663664511, 0.023836679058149457, 0.0216645442747644, 0.10735141206532717, 0.0394927669050438, 0.23402708077004977, 0.16217554200972828, 0.04186260813315, 0.042172223662159274, 0.07968013653797762, 0.06868058176977293, 0.039470772192414315, 0.010866343925174857, 0.026583578803443482, 0.013761275414643543, 0.02416697803086468, 0.040250714269599745, 0.0870356054178306, 0.028252530676711882, 0.08404240424611739, 0.12287971989384719, 0.01215724746829697, 0.00692332604168249, 0.09963569537337337, 0.09264172959540572, 0.010633680204461728, 0.03958718166021364, 0.04101617640948721, 0.019668246752449443, 0.01361474408102887, 0.031737790176911015, 0.029860640011195625, 0.030688164356563772, 0.029865525463329892, 0.05330757364364607, 0.029089590135429586, 0.06533210644764559, 0.03335227265155741, 0.04727799611698304, 0.012563833284990063, 0.035023365302809646, 0.029958807065018585, 0.05553098362205284, 0.09749005907880408, 0.040195210105074305, 0.07673997644867216, 0.053266328892537525, 0.004946559725794941, 0.014990775779421841, 0.06598111840763263, 0.023231536083455597, 0.010237434413284063, 0.059679869030203135, 0.02982827728348119, 0.09494676733655588, 0.058905769139528275, 0.04073183970259769, 0.00904496933799237, 0.008138036039391798, 0.014451698366818684, 0.021552368865481446, 0.012909698699201857, 0.04466337338089943, 0.021603082572775226, 0.06663679358150278, 0.033173536349620135, 0.035992058858807595, 0.009858182531648448, 0.0208539154513606, 0.03511401079595089, 0.059052135928400924, 0.028910009057394097, 0.05313061171078256, 0.02552957134321332, 0.01972049055621028, 0.06255375660423722, 0.006280749986347343, 0.03493669941755278, 0.01978947890789381, 0.013201852977674986, 0.07651089624102626, 0.019136780806417977, 0.022044766461476684, 0.018217616914106265, 0.061552069282957485, 0.04083890574319022, 0.036815997146602185, 0.017588277380647402, 0.023795802412288528, 0.07564136718532868, 0.01099665233466242, 0.025264681449958255, 0.034156994827623875, 0.02504178778534489, 0.04358637206522482, 0.02057270339823195, 0.0181380535941571, 0.06108375798378672, 0.01692134022180523, 0.017935329382973056, 0.030466917835708176, 0.10445571637579373, 0.07403906780694212, 0.00567296369367146, 0.011935049302077718, 0.025298133226377622, 0.016261488664895296, 0.024606924869918397, 0.053698114651654444, 0.028721698626343693, 0.009628031935010637, 0.029425543001187698, 0.010212938450942082, 0.062058331045721254, 0.021190640150702426, 0.01833048103643315, 0.024406726505341272, 0.10948890593967267, 0.03885681335149067, 0.04402252080451165, 0.050064488380615196, 0.025009450502693653, 0.039289287823651514, 0.02809447272946792, 0.04339361044445208, 0.025122151776616062, 0.05943948442914656, 0.03732908497165356, 0.018630858311163526, 0.03375084751418658, 0.029146651537822824, 0.1006440119817853, 0.05486611769135509, 0.023808991436713507, 0.047252791933715343, 0.024783204875088165, 0.029391572145479064, 0.029261174678270305, 0.02349527077084141, 0.061415507325104306, 0.019886414420657923, 0.0859469570485609, 0.044903310148843696, 0.060980871718909056, 0.022711795222546374, 0.031074556122933115, 0.08455560742212193, 0.023646034466634904, 0.1775689231497901, 0.006483783779133643, 0.041415039649499316, 0.012931232008018663, 0.020458353284214224, 0.016709250531026294, 0.03929684331108417, 0.026997793898252503, 0.061964883202953, 0.04699170183656471, 0.08340899180620909, 0.030450290335076194, 0.030528318469545672, 0.048492224354829104, 0.06685283913144044, 0.003884540463332087, 0.10815838019230536, 0.09793696259813649, 0.043777186290494034, 0.03798407482515488, 0.06508715530591351, 0.07399801643831388, 0.07077268165137086, 0.09178872286741223, 0.02262097331030028, 0.10943659088973488, 0.09134079476020165, 0.20645960074450287, 0.05985281403575625, 0.03319974476471543, 0.06307827774435282, 0.09073296987584659, 0.09103143707449947, 0.223807230591774, 0.27123424996222767, 0.08431279366569859, 0.10996380581387452, 0.14784463814326695, 0.047461790897484334, 0.0685842637238758, 0.051639704033732414, 0.03550012775563768, 0.018127578709806715, 0.014927538012021353, 0.05266686016693711, 0.13911536655255727, 0.004818385733025414, 0.14578726568392344, 0.0510496737302414, 0.024040119123778174, 0.13273092199649128, 0.09325638732739858, 0.03214646842596786, 0.050722134698714526, 0.004254088021947869, 0.05432503690410938, 0.04801427446571844, 0.09499812565211739, 0.053395335362958055, 0.07796148197459322, 0.07029824996633188, 0.05265194596722722, 0.041793132932590585, 0.017395476744111096, 0.0799702238291502, 0.028514212795666287, 0.009046993916854262, 0.07752000673541001, 0.008929441117548516, 0.061678398932729445, 0.05616643845236727, 0.0423752311617136, 0.026140602305531502, 0.06010450981557369, 0.057470857564892085, 0.025227216138903583, 0.05369642509945801, 0.044341347446399074, 0.06222059591008084, 0.07146139469529901, 0.012501974640014981, 0.03169677273503371, 0.07307836400078875, 0.033741890851940425, 0.0786232232515301, 0.0392269440261381, 0.03164882066526583, 0.02952230888019715, 0.031075543391385248, 0.03903480665758252, 0.05316028743982315, 0.0432678405860705, 0.048688860410558324, 0.03262085261355553, 0.017312035596530353, 0.03733104593785746, 0.03296692582911678, 0.006620822407837425, 0.08304221648722887, 0.013909256268691803, 0.05913494434207678, 0.0260265660139599, 0.07280102638261658, 0.10927490278014115, 0.0219769842057888, 0.040107974250401766, 0.005377566441893578, 0.013767016669070082, 0.04913547555250781, 0.014662564998226506, 0.03689201342474137, 0.0423729716401015, 0.09415142929979733, 0.043816805950232914, 0.02601243043318391, 0.09870796836912632, 0.13571776529507978, 0.2490639053285122, 0.10823164161826883, 0.20387208887508937, 0.13965307841343538, 0.07880639377981424, 0.12491741483764988, 0.12205418704875878, 0.0791628078690597, 0.1441952868231705, 0.11693259115730013, 0.15608170043144906, 0.09725475670503718, 0.1714092908161027, 0.14360493421554565, 0.1216213224189622, 0.1410796982901437, 0.15624950214156083, 0.12251555014933858, 0.1456773430109024, 0.17464507504233293, 0.18084047974220344, 0.18860762938857079, 0.0898494901401656, 0.10036043184144156, 0.16770478816969053, 0.1166375098483903, 0.07800479965018374, 0.08291110995092563, 0.13244482449122838, 0.14704966651541845, 0.1402801533362695, 0.17880278479840073, 0.07089547613369566, 0.16997205865170273, 0.12544904702476092, 0.08530998908515487, 0.22651499243719236, 0.223635819075363, 0.1763752307742834, 0.14764836510377272, 0.13780793813722475, 0.12705211314771855, 0.19366627080099924, 0.10035467786448342, 0.1293010496135269, 0.0887234341353178, 0.08493836224079132, 0.1022606963025672, 0.16566348341958864, 0.07568658475897141, 0.13976659732205526, 0.1585630215704441, 0.0957391130338822, 0.1239635031670332, 0.17966075161738054, 0.11737205114747797, 0.11201059991227728, 0.17443652051900113, 0.09319220469998461, 0.36553435985531124, 0.07098169079316513, 0.12144547328352928, 0.17131181247532368, 0.13892300187477044, 0.09583720884152822, 0.11286089250019618, 0.0994632321276835, 0.25487563918743816, 0.15925375664872782, 0.1728088507162673, 0.10570559823619467, 0.2603956572711468, 0.1471422729747636, 0.14747448371989386, 0.15129926348371164, 0.3697653242519924, 0.23345632425376348, 0.22256338090768882, 0.12631480342575482, 0.11332090531608888, 0.14186707032578333, 0.13966348714062146, 0.1645750453961747, 0.1692316276686532, 0.34305878302880694, 0.24125649141413824, 0.3120277210005692, 0.13440541071551187, 0.08770567231944629, 0.16900700543607983, 0.2264277192630938, 0.17591242917946406, 0.3351124594254153, 0.34222299073423657, 0.27537350356578827, 0.3121669835277966, 0.2870426502610956, 0.18584360341940606, 0.184791182034782, 0.14693561834948404, 0.15662375491644653, 0.14471146198255674, 0.13533378232802662, 0.14695175391222748, 0.2766863874026707, 0.3209459510232721, 0.30664753541350365, 0.2725337530885424, 0.12956683178033146, 0.22268873346703394, 0.32801131904125214, 0.24501902237534523, 0.1820028102291482, 0.11994934427951064, 0.17899136325078352, 0.17046875985605375, 0.11402536715779986, 0.17564550707382814, 0.2439586349896022, 0.2195946273526975, 0.07666275237819978, 0.18740583530494145, 0.1075654559369598, 0.16384302824735641, 0.11764852702617645, 0.13564855472317763, 0.10004951352519648, 0.15070353687873908, 0.157967674945082, 0.16620165668427944, 0.1751037375735385, 0.11363421886094979, 0.13779508668397153, 0.16991025768220425, 0.10647050397736685, 0.11181247447218214, 0.2576320112815925, 0.11097588150628976, 0.14530872207667145, 0.05371386005676218, 0.13775497169366904, 0.20244191347488336, 0.11308606434613466, 0.12178791633674077, 0.11880043521523476, 0.16484037972986698, 0.1366067004523107, 0.16703197998659952, 0.07380758558533021, 0.12865313009491988, 0.09905107638665608, 0.144433411902615, 0.17013349570333958, 0.15876044811947004, 0.10400430059858731, 0.06421306649489061, 0.07212936492370707, 0.17609302806002752, 0.10856682434678078, 0.16252192056604794, 0.11223358687545572, 0.13711191048579557, 0.2943816307399954, 0.07300626965505735, 0.12912832173917974, 0.046049352402665784, 0.08827791482742343, 0.14828987925180367, 0.12310968898236752, 0.1093873360327312, 0.1873223212148462, 0.11036305581884724, 0.10945934216891016, 0.1832475420087576], [0.016355769409398948, 0.003976799597564552, 0.06182762235403061, 0.03179120445357902, 0.026301942665928175, 0.03201781479375703, 0.031951504959059615, 0.022548456576519778, 0.01155830460733601, 0.028828099702617953, 0.051371889654546976, 0.02541903798867549, 0.06986718345433474, 0.03027154385511364, 0.06880758995456354, 0.08368442274097886, 0.027816283549847345, 0.03446850686201027, 0.053570773984704695, 0.0778073731011578, 0.05084121420181223, 0.024804052863536135, 0.04663408334766116, 0.04446956003084779, 0.029105064126529863, 0.017576128211138502, 0.04374333417841366, 0.01972021914220282, 0.016287403613595024, 0.02227739540727011, 0.0663838085851499, 0.026849016613726105, 0.04116304870694876, 0.022749116344909583, 0.04825338002826486, 0.005549380838471864, 0.055993540944265466, 0.02163657166862062, 0.025537856255791018, 0.014329127801050032, 0.008508465269447436, 0.029713547189853022, 0.0429038676167173, 0.07098591806633131, 0.04091385332867503, 0.013236184305112277, 0.023344386635082107, 0.04335120200578656, 0.01870808916698609, 0.01208688847587577, 0.023173633297639232, 0.012983996587406312, 0.04870489758572408, 0.024496094656309912, 0.008645230787806213, 0.040174555499106646, 0.051176854941461764, 0.1006154999403017, 0.0795047420210072, 0.03425773013649242, 0.04293442204860704, 0.02191711027574326, 0.02355356201795595, 0.011153423609877271, 0.06338902642684323, 0.04448174312710762, 0.032920276546584706, 0.036425181331911256, 0.019577409573165432, 0.04282396672559636, 0.06439167726784945, 0.02223454083182982, 0.013852192321792245, 0.04903421437899981, 0.0460957811613168, 0.004610865975597075, 0.13731412749205316, 0.08515327463724784, 0.05240768693121416, 0.044321317092648575, 0.03439304358991129, 0.018984149442985654, 0.02335811679118446, 0.06131551840475627, 0.059625464092407904, 0.03750725130417517, 0.08054593365107264, 0.08410563692450523, 0.04315597051754594, 0.08631788500185524, 0.07182437700352498, 0.09473874885588884, 0.021440134084384357, 0.08778353421283619, 0.1269474151943411, 0.08641085108476025, 0.12274437929902758, 0.1126252305028694, 0.02811547338829509, 0.07930284392620836, 0.010972996059406017, 0.06670594308525324, 0.019937489447849135, 0.05746471682297332, 0.019208527402952313, 0.04522178734519652, 0.048200237165604315, 0.042094924952834845, 0.053919951497976265, 0.07685385498085193, 0.039894222148827145, 0.059706433676183224, 0.10317566684846367, 0.04428166011348367, 0.05000386806204915, 0.10648026131093502, 0.039663085980074744, 0.10168275410043341, 0.033607534132897854, 0.01920367418123143, 0.02869875735736319, 0.02256582537665963, 0.03757348310734544, 0.04875056299247912, 0.06673532365156071, 0.04921014154595988, 0.029212055528270345, 0.00652109769206228, 0.03959959885105491, 0.047999231344355006, 0.050336662347295454, 0.03377600420000298, 0.037758190517446825, 0.07592878104852778, 0.028917455979223763, 0.015640832683337585, 0.07279793904828173, 0.059049727129084725, 0.04733941710687109, 0.058463018254509995, 0.022423265169241598, 0.02574708252879126, 0.0298464450586055, 0.021143965423107147, 0.07042011485568114, 0.0691277567031128, 0.05335072847083211, 0.029504575367484773, 0.0249631150426077, 0.0415682630347354, 0.030422300765556947, 0.01893926095882697, 0.07670823458049979, 0.05392009399033018, 0.030608816471483027, 0.06281362873102937, 0.07184819358267955, 0.0602415603186403, 0.0204562057208802, 0.05817706324160099, 0.038268716872802803, 0.022378159553876946, 0.03536543855443597, 0.005565118185976254, 0.04134613781103066, 0.032420555861400704, 0.03239714301058224, 0.06121189932205847, 0.01540095528720745, 0.037710988228874545, 0.052114016975143125, 0.05729608730013881, 0.044457712809422185, 0.05772948797260012, 0.056015705290649614, 0.038747854198196104, 0.01895918613964958, 0.02308420747119401, 0.03359989043591278, 0.02934236478592668, 0.014715258331437196, 0.0208524854388088, 0.05302098759316972, 0.005254463650219674, 0.03139352186449936, 0.04678511167211192, 0.07436512423945324, 0.06655769675437893, 0.029019521216728857, 0.03288717421569994, 0.050923371221870184, 0.05518584678481732, 0.013368449439959866, 0.004449621458271784, 0.020348408558805074, 0.008222643419035842, 0.022391100913020115, 0.07947386189230851, 0.01008492348981755, 0.019331966493544833, 0.07172769254871778, 0.04354863873283778, 0.046911325970930715, 0.027620130950318914, 0.025684898187007223, 0.021273441779028093, 0.10472086071968079, 0.022915208146774342, 0.023667856152834635, 0.014914661113704954, 0.04425593685092671, 0.02984061644279531, 0.02362307793061648, 0.02692932292952069, 0.04859519882925919, 0.03169221976505859, 0.05043853080964514, 0.09585746989718505, 0.018935568031987975, 0.05516125328306641, 0.030775661447218487, 0.015573996984000717, 0.021314725545900207, 0.014938330111492957, 0.040740830291594775, 0.043614076650036235, 0.022119673334860375, 0.026959000354898826, 0.0353188842668065, 0.03589463819350515, 0.059382121078670025, 0.004305043881426432, 0.04135625137548361, 0.040131658515227694, 0.020590898314757005, 0.010219840848419284, 0.043443031542535336, 0.08491048123687506, 0.028439797860171114, 0.02408327055828912, 0.0653208020542349, 0.07651397679001093, 0.02509887802547642, 0.0857002010036792, 0.06607471552810498, 0.06160084916544812, 0.060299860047442574, 0.03932613566783922, 0.004103539336938411, 0.03638573809127722, 0.009225378228750612, 0.07408058057938303, 0.023232087393158248, 0.0519818451388606, 0.0674085593117135, 0.029597836613122906, 0.06295637214290244, 0.015590805992750185, 0.0442067396693996, 0.02560562494077853, 0.0601837287790009, 0.02371542145764189, 0.09542057476937771, 0.06788427342793771, 0.17960629239678383, 0.02899261051788926, 0.06225116391267095, 0.12051704738821302, 0.006335847453945982, 0.0721129308055554, 0.060823431238532066, 0.12174799133624349, 0.025115266342514327, 0.021958853750090514, 0.07747885358652898, 0.027486946400521056, 0.0811784097126552, 0.04494152184841888, 0.025062472925388386, 0.05090306945411222, 0.054062749192650826, 0.09641777697418417, 0.08465471424694572, 0.04255734317536865, 0.046662161126732826, 0.05697639552610261, 0.022520936892500946, 0.07952992924089942, 0.02848315964053784, 0.02256959633502577, 0.09808444218443972, 0.017702780165044323, 0.03177220547305686, 0.028267263368304287, 0.03022009732999972, 0.0689825705651726, 0.04728768898972443, 0.0365786286337035, 0.017530050594359636, 0.031054254355175153, 0.065801605183099, 0.04716874858630555, 0.03352908191404172, 0.013546112808398902, 0.023543456935190728, 0.0433222624872412, 0.03432275075465441, 0.03986446499558432, 0.04616761427106602, 0.07381247103746448, 0.014343421141217862, 0.05267848347180656, 0.0709059527143836, 0.03055645731676902, 0.010705152842482286, 0.056727756546544175, 0.03360588190012744, 0.04408119033489909, 0.03776571207812854, 0.014165653448019708, 0.08582371473312378, 0.012022882267566664, 0.05257703230849334, 0.05577742075547576, 0.027805720455944538, 0.030387882076736008, 0.010006400024784463, 0.04326629013355289, 0.025826240424066782, 0.047476742416620255, 0.029185443384838954, 0.04018567668806229, 0.046991525417459865, 0.06093815793948514, 0.011240952082776597, 0.08953532164118119, 0.07534985497061696, 0.02626146126671561, 0.034438393477882655, 0.054218286382300515, 0.03220698357160602, 0.04767508159524628, 0.05495045959417309, 0.030213627498596907, 0.03938807234434145, 0.018025705158444386, 0.033430426315005334, 0.04298230626487306, 0.044058177819741626, 0.02831729005889169, 0.058208255496408255, 0.024124864754932265, 0.09005453663745097, 0.09519241058400699, 0.12405882376645293, 0.08662149549594947, 0.09827293242727007, 0.13235000600772245, 0.22451121067362173, 0.1937799932701247, 0.10451358862753425, 0.12362236290105752, 0.14833779739482061, 0.20298143023891108, 0.12269713969102927, 0.1800809276423284, 0.2203668002039194, 0.16222050174006394, 0.11019506411893026, 0.12449073844722339, 0.22691265467022145, 0.21204424250338758, 0.19473850540816784, 0.19602005449788912, 0.13715388466204914, 0.19595944775002344, 0.18978350343448774, 0.15778516259576592, 0.10944703354367188, 0.11263147981039115, 0.08684231114706822, 0.08848603508834328, 0.238005168735981, 0.08668799192777701, 0.10093624344361679, 0.10072614864579268, 0.10773316265216895, 0.1191098607544388, 0.10526824848992483, 0.08465580668832574, 0.12387722065406186, 0.13702767714858055, 0.11316662680889879, 0.20539706918810094, 0.07063182456684963, 0.17005721479654312, 0.14300528567816528, 0.13623392688376562, 0.1030285061736192, 0.10731638608766453, 0.06383956010852541, 0.1192325127444097, 0.07740613498858043, 0.05985101591795683, 0.13312713216458047, 0.09845995024910995, 0.06859865545162133, 0.13036476182086126, 0.10544997373861925, 0.16123833587127073, 0.16294984546090874, 0.12115907722285815, 0.17254328568066868, 0.12004866823554039, 0.197214045428804, 0.0733142906267728, 0.17827157330300125, 0.1398614700883627, 0.08512224523084504, 0.15724939134504112, 0.1891746675329549, 0.19195634898330483, 0.09426792697714907, 0.08856714037912232, 0.11000236017363411, 0.14429763704538345, 0.1084891456578459, 0.16414880326816014, 0.20930391097707407, 0.203792754560709, 0.174606982086386, 0.08332334711615529, 0.07274383266589471, 0.11356145955090012, 0.08987306244671345, 0.16617205898676599, 0.21656826617462294, 0.16004906754408563, 0.30101192210401806, 0.3407794753355639, 0.22067391872406006, 0.20198250455515726, 0.13601306373519556, 0.1715672809098448, 0.20839860955519335, 0.2729207623217787, 0.31047713277595385, 0.1764461241130318, 0.3782224218760218, 0.25519039801188875, 0.23036196029611997, 0.18236915128571646, 0.2697513795324734, 0.25199976350579945, 0.06932489148208074, 0.15697769235287393, 0.1040191198033946, 0.15430699209017412, 0.21495768188365869, 0.22376744129828044, 0.2236906989876713, 0.17346195424241678, 0.08679916310523238, 0.25535571628383225, 0.2382055265562875, 0.16738631097333773, 0.10566772241145372, 0.22415605187416077, 0.18938730683709892, 0.2006405115659748, 0.15304282706763062, 0.12303068036479609, 0.14476402130510124, 0.1328442237739052, 0.1170633855674948, 0.12851313474987233, 0.15115345987890447, 0.1352102482425315, 0.09188601800373622, 0.08831906119095427, 0.14466236318860734, 0.17630517881895813, 0.1144563861723457, 0.08252397179603577, 0.13389395815985544, 0.16997334786823817, 0.2028077252741371, 0.1591496965182679, 0.16210182596530232, 0.1913172232785395, 0.13133950451655046, 0.15102622099220753, 0.11787229430462633, 0.10844997383121933, 0.09801129610942942, 0.14731015610907758, 0.21803390181490354, 0.14149973860808782, 0.20954413951507636, 0.09908528133694615, 0.11921972914465837, 0.19583172031811305, 0.14473515642540796, 0.10454697255045176, 0.14336839690804482, 0.2547588497400284, 0.11536874435842037, 0.17103509232401848, 0.1750063949397632, 0.10850583761930466, 0.12599339495812142, 0.23038085071103914, 0.17126318865588733, 0.08208470858101334, 0.08760177503739085, 0.11579653354627745, 0.16559944328452858, 0.16553815800164426, 0.13158320715384825, 0.15981396873082432, 0.12562140849019798, 0.1188759154507092, 0.1751845646649599, 0.17980331182479858, 0.14106626329677446, 0.13787915717278207, 0.1667863910219499, 0.11552207970193454], [0.039754735705043585, 0.06402379593678884, 0.05447480654610055, 0.040509419316159825, 0.024901666911318898, 0.05694150525544371, 0.0062682789367889714, 0.02091680038055139, 0.04301518467920167, 0.02854781724246485, 0.03447280538135341, 0.059957810544541905, 0.044753313197621276, 0.059657680935093334, 0.042105798476508687, 0.035925983118691614, 0.022380137483456304, 0.050170207529195716, 0.025629950421197072, 0.030705656989344528, 0.026134641375392675, 0.011643421736412814, 0.04126336332410574, 0.019735387792544704, 0.045411349673356326, 0.03557494641946895, 0.01839093511391963, 0.04542516464633601, 0.014231478130178792, 0.05348642190386142, 0.04198629828169942, 0.04990658310375043, 0.01415420656225511, 0.01811578237850751, 0.02191508824138769, 0.11618270139609065, 0.04713445542646306, 0.025396088238007257, 0.09206839464604855, 0.04035494742648942, 0.04779645115403192, 0.040866844422583065, 0.07122291677764483, 0.016575428158310906, 0.018267494326989566, 0.022302446920158606, 0.0431376636427428, 0.02167624730749854, 0.08490269844021116, 0.04298238429640021, 0.040986704240952215, 0.016754403643842255, 0.04459439690357872, 0.019572117000019977, 0.061768108047544956, 0.021328664351520792, 0.02126580656373075, 0.041564602338309796, 0.06311171595007181, 0.021241243596055677, 0.0950014301176582, 0.05415867368823715, 0.06155108540718045, 0.02536573906296066, 0.04018970379339797, 0.06143924926540681, 0.03188003486554537, 0.018226498937500373, 0.04854806100151368, 0.033420027765844545, 0.02404519117304257, 0.003309894669135766, 0.0526798201857933, 0.037640407016234737, 0.05110102526045271, 0.0026350752658410265, 0.027296135567926934, 0.10092284916234867, 0.03881790615352137, 0.05597397538700274, 0.07327525450714997, 0.019179472533453788, 0.027440078290445463, 0.026594206358173063, 0.022482326553602303, 0.032610172472362, 0.004684601103820438, 0.03184696985408664, 0.05792709094073091, 0.0040088947280310094, 0.02305733918079308, 0.05690075922757387, 0.026553020978878652, 0.004052750990792576, 0.0629513238423637, 0.13930716126092843, 0.09071384875902108, 0.02728388801084033, 0.010880067295927023, 0.08012744039297104, 0.07037438838077442, 0.04906430062172668, 0.003863783228942858, 0.026444965973496437, 0.07964720044817243, 0.05811638185488326, 0.06748722866177559, 0.06879718801272766, 0.06256926791476351, 0.06298012765390532, 0.06923779472708702, 0.05894377388592277, 0.06165811752102204, 0.01470973844906049, 0.008936703138585602, 0.05807218886911869, 0.025681883795186877, 0.07507705675171954, 0.05575517837756446, 0.09845865424722433, 0.040981543982135396, 0.01970115739719144, 0.03349481928827507, 0.019722415899325694, 0.046506189674671204, 0.035069346228348355, 0.014507903118750878, 0.03906493361241051, 0.03893046493508986, 0.035412667984408994, 0.06939376278647355, 0.04354583299053567, 0.01444163908516722, 0.1064943273418716, 0.04918953783011862, 0.03124304993876389, 0.04927170842087694, 0.03544734112386193, 0.013949920872359403, 0.038941667548247745, 0.008466580999083817, 0.0807174944451877, 0.014384173954437886, 0.02716229623183608, 0.03861896647140384, 0.01277014016107257, 0.01040784000152988, 0.03768058307468891, 0.031845918124807734, 0.05136724847501942, 0.01166629430372268, 0.04769717808812857, 0.015637462060632448, 0.025353917286598256, 0.0535547571655895, 0.03468560753390193, 0.019802445712100183, 0.04389048806790795, 0.05463379408632006, 0.020180192942331945, 0.012375164926717324, 0.04198764178103634, 0.03220191830769181, 0.10980942552643162, 0.010941031971015036, 0.03582102732200708, 0.09414506464132241, 0.015294331990714585, 0.04530446344454374, 0.07107648213527032, 0.052802455212388716, 0.02691389643587172, 0.035870146472007036, 0.031226948302771364, 0.027669284027069807, 0.015850991941988468, 0.01629495231567749, 0.01844097367886986, 0.07747820219291107, 0.024572239856102636, 0.012790706557487803, 0.1192142872938088, 0.053966217408222814, 0.06355753381337438, 0.06354162216718708, 0.005159094281095479, 0.019492451899818013, 0.012122479333941425, 0.04360554746485182, 0.02401163592003286, 0.012518776015245488, 0.03187123087367841, 0.021723434329032898, 0.0349372388528926, 0.019453566754236817, 0.03889232448169163, 0.014007020442347442, 0.017008104494639804, 0.04242861829698086, 0.011293534305877984, 0.0356419415745352, 0.03206500690430403, 0.05341428006067872, 0.015337240848956364, 0.0222474279081715, 0.08146977264966283, 0.02043814820769642, 0.031597686266260486, 0.026988747330116372, 0.02974769107199141, 0.056749849646751366, 0.021020621327417235, 0.04310660030958908, 0.016916824571256126, 0.04522686957248619, 0.03065191362319248, 0.0090049807248371, 0.04275967213990433, 0.060601272088076384, 0.02195799709962947, 0.005195929826835969, 0.052029946486332586, 0.04426299361512065, 0.022048400016501546, 0.06935666727700404, 0.0467208103010697, 0.025917469457324063, 0.03655436761411173, 0.005143884918652475, 0.021916039886751344, 0.06685850489884615, 0.0418784688892109, 0.020528992172330618, 0.07978199142962694, 0.028924322753612484, 0.024052085088832036, 0.01900443764004324, 0.030860753131232092, 0.014631503361410328, 0.031045151807899986, 0.05267180668722306, 0.028092347218522003, 0.04790161390389715, 0.04388422179701073, 0.016882300709507296, 0.04291453079453536, 0.045003801185105524, 0.03680096081058894, 0.05377035148973976, 0.03198101783969572, 0.025283161351191144, 0.050313860177993774, 0.055137837039572854, 0.06832791319383041, 0.05651576863601804, 0.09171145808483873, 0.08952079420643193, 0.018246469919436743, 0.03907906410417386, 0.04688998943726931, 0.026381192163431218, 0.026854889334312508, 0.027490491745993495, 0.03301550893645201, 0.1641377838594573, 0.05790193086223943, 0.04874206094869545, 0.10946641928915467, 0.08861271757632494, 0.05988366702305419, 0.09152596018144063, 0.0594584426975676, 0.07972810217844588, 0.08650597490902458, 0.05823262847427811, 0.031773443799465895, 0.03442443261987396, 0.02025602601601609, 0.04492541681975126, 0.07432432392878191, 0.025890312789540206, 0.03385566081851721, 0.06811955544565405, 0.05964976243142571, 0.02614578292039888, 0.0383873485427882, 0.05366778413632086, 0.14787201024591923, 0.006648701715416142, 0.023901474063417742, 0.021682766332690204, 0.028071597617651736, 0.029252255335450172, 0.03958093913804207, 0.07290288805961609, 0.025134599501533166, 0.051464021139379056, 0.046130807138979435, 0.02553741860070399, 0.015258417132177522, 0.041903469511973004, 0.027799857913383415, 0.012299125748021262, 0.008324440635208572, 0.01500017857844276, 0.05824645023260798, 0.042956912091800144, 0.06657170171716384, 0.04089641497869577, 0.02736372613747205, 0.08154367189854383, 0.055086207310003896, 0.04599883207785232, 0.02502446308998125, 0.039362399971910884, 0.07179417540984494, 0.019106960888685923, 0.02616162840942187, 0.014563052748729075, 0.056778996118477414, 0.04307498397039516, 0.08058691038084881, 0.023523200968546525, 0.024683044624647925, 0.028187309890719395, 0.07895187847316265, 0.038080969625817876, 0.03226918826944061, 0.03091783488967589, 0.060868194193712304, 0.02026185463182628, 0.021515885733866265, 0.05165373274524297, 0.039363821502774954, 0.03369282937741705, 0.03050993356321539, 0.028396317336176122, 0.011115961691497691, 0.015183618824396814, 0.03127253907067435, 0.0056780912979905096, 0.029089752983834063, 0.027371592054675733, 0.031763340413038216, 0.022869566488744955, 0.017344135391925062, 0.027199849752443175, 0.04495698905416897, 0.0679808221757412, 0.03038743763629879, 0.010569830907375684, 0.0467105678149632, 0.13075493302728447, 0.13619010709226131, 0.15144958613174303, 0.18464355995612486, 0.11407062544354371, 0.13902641061161244, 0.1404164574508156, 0.15273999688880785, 0.12482733252857413, 0.1495289791907583, 0.12531975896230765, 0.1394534669816494, 0.10498192706810576, 0.11734398693910666, 0.09560341960085289, 0.06471157260239124, 0.16071963656161511, 0.1779829380767686, 0.07785394774483782, 0.11131817528179713, 0.07036613060959748, 0.077417799005551, 0.15496137126215867, 0.15690609333770617, 0.12484281669769969, 0.13508864119648933, 0.15417550557426044, 0.12367728352546692, 0.07656065321394376, 0.09817301814577409, 0.08349095205111162, 0.12460743289973054, 0.12245095361556325, 0.14996431368802274, 0.18252317873494966, 0.120553905410426, 0.12187725225729601, 0.11963397477354322, 0.11779768259397574, 0.11304256346608911, 0.07942975033074617, 0.1717198427234377, 0.09414373471268586, 0.09807691723108292, 0.10119041587625231, 0.17330483267349855, 0.1132473521200674, 0.08319127027477537, 0.2192964790655034, 0.15028991550207138, 0.11195561143436603, 0.15708838855581625, 0.09420016847018685, 0.14968489296734333, 0.131792779479708, 0.11140631019536938, 0.08910339338971035, 0.07974506555391209, 0.11132434316511665, 0.16501077344374998, 0.17373539028423174, 0.16211967143629277, 0.12836996386093752, 0.1507064274379185, 0.1364921365997621, 0.11768397369555064, 0.12467118805008275, 0.10722808154033762, 0.12355053318398339, 0.10656389075198344, 0.09081712178885937, 0.0860760754772595, 0.18382941292864935, 0.1110195384493896, 0.13852500037423202, 0.14070414272802217, 0.14124150175069058, 0.21673959626683167, 0.2515200121062142, 0.14801478758454323, 0.24023640900850296, 0.15032868699303695, 0.10942006177668061, 0.14744666378412927, 0.12403043386127267, 0.22887770565492765, 0.11470737627574376, 0.26023460019912037, 0.3056707706834589, 0.1022876612842083, 0.14374855293759278, 0.1673056874424219, 0.13126953398542746, 0.20042568737907068, 0.22580930244709763, 0.2871576483760561, 0.2179502248764038, 0.22948219893234117, 0.08799482323229313, 0.21453997572617872, 0.2617339997419289, 0.08336614231978144, 0.08136076599891696, 0.18091757489102228, 0.11908554205937044, 0.1027267345094255, 0.1868739995573248, 0.1887217725494078, 0.1258823730583702, 0.15818515898925917, 0.13979513650493963, 0.16335497157914297, 0.18898686261049338, 0.09989517394985471, 0.11464288830757141, 0.0910551111613001, 0.11549307911523751, 0.17733443501804555, 0.11211910444710936, 0.17201305127569608, 0.1579040555017335, 0.10551444813609123, 0.1053074745993529, 0.11049010471573897, 0.11996102865253176, 0.1402481807661908, 0.10901299504829304, 0.09735134616494179, 0.12658646170582089, 0.12291138033781733, 0.10475560849798576, 0.1364211889782122, 0.08120597859046289, 0.197477004889931, 0.20109648709850653, 0.12789572216570377, 0.1540558391383716, 0.1235947058136974, 0.08096694427409343, 0.14293698434318813, 0.10210211588335888, 0.22303672693669796, 0.06083316143069949, 0.2111748762960945, 0.1297857543187482, 0.15643890840666635, 0.1668211320149047, 0.1305261988724981, 0.15631795275424207, 0.26102064230612343, 0.08808358239808253, 0.09880333646599736, 0.1521173867263964, 0.1044262068878327, 0.15811608412436076, 0.07649121194013528, 0.1367537389908518, 0.12731020072741167, 0.1283663540546383, 0.11713069624134473, 0.1196034135563033, 0.13220591231116227, 0.17775391893727438, 0.17300547659397125, 0.07106212433427572, 0.13148088407303604, 0.19273019103067263, 0.10604895052633115, 0.13650915425802979, 0.19519233677004064, 0.1098575336592538, 0.08568325798426356, 0.13618780007319792, 0.0892841008358768, 0.08272076730749436, 0.16239352816981928], [0.04395048074158175, 0.022446491422929933, 0.020124466557587897, 0.07344840307320867, 0.020184978310550963, 0.04262774118355342, 0.021505073278344104, 0.0680763531210167, 0.038278389389493635, 0.035940313778285465, 0.036305728634553294, 0.03093004852001156, 0.020929378723459582, 0.08020497658955199, 0.03156685024233801, 0.014768178973879133, 0.07199953403323889, 0.031773610040545464, 0.02650023265076535, 0.024155012065810815, 0.026676288739378964, 0.05824991754655327, 0.046904798464051316, 0.00970086079489972, 0.027695083624816368, 0.05106039119086095, 0.037439614933516295, 0.0275790219062141, 0.02900778256090624, 0.057298170402646065, 0.013427602426548089, 0.05874976036804063, 0.05924147434000458, 0.0410647289827466, 0.03866176846038018, 0.03211243310943246, 0.04379727092704602, 0.03861721245838063, 0.005536910212997879, 0.04887344568435635, 0.0645824202469417, 0.01688538125849196, 0.03608630058754768, 0.030934292756553208, 0.03737279959022999, 0.02488520395542894, 0.029573443279202496, 0.023566201429015825, 0.003632035106420517, 0.019862684354718243, 0.0904160872367876, 0.013866334687918425, 0.032265344368559976, 0.023627491800912788, 0.022844034912330762, 0.04983768465795687, 0.037523067955459864, 0.009550686576403677, 0.08335399654294763, 0.030402820025171553, 0.060440913907119205, 0.058626110931592326, 0.01991890776636345, 0.02351573877967894, 0.011157298893002527, 0.024157990834542682, 0.013147095201670058, 0.017810572238106812, 0.037546080470617325, 0.03292214930323618, 0.012326469012935246, 0.02798255516349205, 0.03963420752968107, 0.029383236342774968, 0.0565623738137739, 0.018455892967592393, 0.07263412033872944, 0.033309596191559515, 0.046076090075075626, 0.04734464521918978, 0.043359802437147925, 0.06064846419862338, 0.02663735779268401, 0.07034949293094021, 0.04789282348273056, 0.04630752479923623, 0.060285922938159535, 0.06008260670517172, 0.06470915701772485, 0.05738734347479684, 0.032244964569274864, 0.01361223095695355, 0.04215311272335904, 0.05996329989284277, 0.105261341003435, 0.05445716802829078, 0.07985939870455436, 0.07808873443199055, 0.03914266319147178, 0.0013289178314153105, 0.10921226721256971, 0.06620822407837425, 0.026893877956484045, 0.02706113174956824, 0.04666716192982026, 0.03433870989829302, 0.049949585260557275, 0.05577551407207336, 0.06421516995344843, 0.02760640249055411, 0.05506844326321568, 0.01204373110418341, 0.04366729075887373, 0.01752602688169905, 0.08185741970581667, 0.03744703132127013, 0.04232188473854746, 0.04335534106940031, 0.038552680385432074, 0.03689868003129959, 0.025736655141892176, 0.024845842138997147, 0.024132951196017008, 0.04596979417172926, 0.02022068791224488, 0.044307454622217586, 0.027125841937959194, 0.04088952445558139, 0.009219467340569412, 0.024577518858547722, 0.004780619322056217, 0.0367847641796938, 0.030378586146980524, 0.023539845432553972, 0.034212146153939624, 0.01259335719182023, 0.03613619326746889, 0.00880686376642968, 0.05277286430022546, 0.025654499818171774, 0.04600533922868116, 0.010107662046461232, 0.06691884023270436, 0.012948895122722855, 0.02388728759251535, 0.0293489330049072, 0.05672397371381521, 0.022372129073898708, 0.01175736981843199, 0.0834549218416214, 0.03005732356437615, 0.020729324547573924, 0.006301279063336551, 0.0625440264120698, 0.05965643243065902, 0.03219669019537313, 0.04231881776026317, 0.015501977277121373, 0.08214478607156447, 0.007682135145712111, 0.02533599717675575, 0.012467754422686994, 0.01152821836460914, 0.028996427277369157, 0.02776432133811925, 0.05743272389684405, 0.005596830368241561, 0.028472465928643942, 0.013000359459381019, 0.02306594979017973, 0.018611933969493424, 0.04331287156258311, 0.01631285885481962, 0.01925416736464415, 0.014631540680836354, 0.008436158881522715, 0.07827922635312591, 0.04347215087286063, 0.04958461145205157, 0.04092891341341393, 0.1004253744280764, 0.04021010394873364, 0.025912634895316193, 0.04257752959217344, 0.04605907920215811, 0.048769585721726925, 0.059275523227240355, 0.010932526534556277, 0.032352234170372994, 0.031691069648201974, 0.027353697389896427, 0.009113569228377725, 0.01574376135665391, 0.03644346445798874, 0.016602176008746028, 0.009478888241574168, 0.09962648086782012, 0.020981639490595887, 0.006756971307498003, 0.028196666888626556, 0.06477500884128468, 0.021188903101054684, 0.02557856835690992, 0.017244977676974874, 0.04369737021625042, 0.07701156687523637, 0.00773042648298932, 0.01888263042617057, 0.034138908476701806, 0.02251841783124421, 0.028900119409497296, 0.03911765578335949, 0.06513303105852433, 0.025886300951242447, 0.021626958523743918, 0.03201763837465218, 0.041186855108078034, 0.09324248414486647, 0.06365625387323753, 0.056017822319907803, 0.04411028591649873, 0.03466753136100514, 0.06073192400591714, 0.036935487163386176, 0.06700423386480127, 0.012905988808987396, 0.03386715180905802, 0.02179437516523259, 0.030212290784610168, 0.013959032749491078, 0.029777977482548783, 0.04380977972011481, 0.029490692541003227, 0.025173089400466, 0.0673950971769435, 0.0666685625910759, 0.054884516168385744, 0.07653433284057037, 0.022453039285859892, 0.0324498278621052, 0.021757218587611402, 0.022424281275432025, 0.039190554193087986, 0.017990689358807037, 0.04208015663815396, 0.08123536594212055, 0.024006769127611603, 0.09086250221090657, 0.04403952489207898, 0.014588117832317948, 0.05300654497529779, 0.021958110754245093, 0.05616345629096031, 0.048233465025467534, 0.038876826741865704, 0.11562212290508406, 0.0628275726256626, 0.08089282789400645, 0.020153959082173448, 0.07186029864741222, 0.010911558106142496, 0.040333156274365525, 0.026641330615218197, 0.010036261502786406, 0.08902107352124793, 0.01659788766742817, 0.030257050347115313, 0.04013614023902586, 0.032060179127646346, 0.029289116750338247, 0.09913471939840487, 0.051352972098227055, 0.1407373502318348, 0.04407047965962972, 0.014916978310793638, 0.031639385635831525, 0.05076762368636472, 0.02389950122285102, 0.06459955325616257, 0.03251751173021538, 0.04040588165766426, 0.07052735053002834, 0.035699454202715836, 0.04947357937427504, 0.02790202323480376, 0.034668589875634225, 0.06239408374364887, 0.08118342408644301, 0.05422276471342359, 0.02566926134750247, 0.032496789270745854, 0.03282883038212146, 0.0398853570888085, 0.057927491276391914, 0.006579247294991676, 0.021470255950199704, 0.008871603640727699, 0.051896071527153254, 0.04915358904483063, 0.017300743077482496, 0.05657800386792847, 0.030438639888806, 0.0195838522631675, 0.023139596284766282, 0.03740116574668458, 0.027897478746516362, 0.03024484689480492, 0.05426579061895609, 0.027273039932229688, 0.041745004443717856, 0.008179938969468432, 0.023999473179823587, 0.039214645578925095, 0.05821256419377668, 0.0333139727424298, 0.01597592550595956, 0.06072831419961793, 0.04425949237442442, 0.030023695368851935, 0.014863830359120454, 0.026714637842295424, 0.035996703431010246, 0.009643851978970426, 0.028902786052120582, 0.012539908988401294, 0.021557839554069296, 0.06748498949621405, 0.02177311835943588, 0.012348609610593744, 0.04931998618745378, 0.05454518759090986, 0.020149597798341086, 0.03205624023186309, 0.0346458114550582, 0.025042429000937512, 0.009614976073083068, 0.0348735820901181, 0.032686338028205295, 0.0590976317014013, 0.02863399458250829, 0.018337848230398128, 0.06642580990280424, 0.05929297514791999, 0.02262924295584006, 0.039121669317994795, 0.02234329642461879, 0.026133923824610453, 0.07023252027907542, 0.02466213726438582, 0.016369260381907225, 0.01377194537781179, 0.004134970351255366, 0.15280033222266606, 0.2206930262701852, 0.13216962425836495, 0.16561415392373288, 0.20590632329029696, 0.16827318338411196, 0.09907141886651516, 0.1563896331936121, 0.13117680538977894, 0.16342785981084618, 0.17764158067958696, 0.13798194165740693, 0.12203357315489224, 0.1487874761223793, 0.1471907203750951, 0.09167585535241024, 0.14068267388003214, 0.11838937870093755, 0.070926634461752, 0.08109900075942278, 0.15606262002672466, 0.16306424646505288, 0.12514867314270564, 0.14775011821516923, 0.1329318769276142, 0.08041543101093598, 0.10770066761012588, 0.0766412496034588, 0.19467108616871492, 0.1228842796491725, 0.10217891247676951, 0.10832079433436904, 0.08401604994599308, 0.16735821962356567, 0.10662936259593282, 0.08462116747562375, 0.15307972580194473, 0.14008675728525433, 0.13986882540796483, 0.16448318532535008, 0.10882597722645317, 0.1770993090633835, 0.14343435051185743, 0.1466258264013699, 0.08337456293936286, 0.10776881288204875, 0.15846726670861244, 0.123326820188335, 0.10096594970673323, 0.047784257879746814, 0.21989937100027288, 0.08928797527083329, 0.12694186477788857, 0.08216646526541029, 0.08227228280156851, 0.10157378816178866, 0.12175574020615645, 0.07279388140887022, 0.16847081349364348, 0.1453154802854572, 0.11117497046611138, 0.18915176019072533, 0.1272110939025879, 0.08846638471420322, 0.12496679861630712, 0.08530027246368782, 0.08130036281155688, 0.09560941106506757, 0.11072120017239026, 0.23699765279889107, 0.09875883135412421, 0.26779687298195703, 0.14117987720029695, 0.11247901977705103, 0.19583079751048768, 0.20174725646419184, 0.197579721521054, 0.12531647485281738, 0.14098238279776915, 0.18279429418700083, 0.23050836101174355, 0.20156008936464787, 0.13678188462342533, 0.11105955165943929, 0.08791545499116182, 0.11649338901042938, 0.06617113535425492, 0.1336471206907715, 0.18346299044787884, 0.13511518548641885, 0.1910297687032393, 0.19617291486689023, 0.11712425015866756, 0.23306263823594364, 0.1671715546399355, 0.15851169718163355, 0.2762202338448593, 0.2059435070093189, 0.15951681110475743, 0.13615111847008976, 0.20571034880621092, 0.08530526648142508, 0.17386549258870737, 0.15169345161744527, 0.09152758866548538, 0.15276730113795825, 0.15797395817935467, 0.16244158201983996, 0.19820706785789557, 0.13028347332562717, 0.13209436115409645, 0.16010831722191401, 0.11326304663504873, 0.21808922956032412, 0.13513206743768283, 0.09134971749569688, 0.1558543233467, 0.11883566475340299, 0.1350121567291873, 0.16024459419505938, 0.12743734461920603, 0.15217389512274945, 0.06312783115676471, 0.12789037530975683, 0.14173638448119164, 0.2022815892206771, 0.061014153861573765, 0.11704970630151884, 0.1821635008922645, 0.14462665867592606, 0.09893237347049372, 0.16493496751146658, 0.07911871666354792, 0.1422237761850868, 0.06943479379905121, 0.11357182078063488, 0.14324531065566198, 0.13618135399052075, 0.1288681307009288, 0.0644604739333902, 0.23274787941149302, 0.1263305725795882, 0.12437466824693338, 0.11866641097835132, 0.1287890135177544, 0.10074930026062898, 0.17806088817971094, 0.1354817843862942, 0.08188626422945942, 0.18577577705894197, 0.19923994743398257, 0.11011961102485657, 0.10660873513136591, 0.20592718145677022, 0.11633010634354182, 0.10077327290283782, 0.15674575551279954, 0.08712595914091383, 0.22292080601411207, 0.1259637429778065, 0.1445033960044384, 0.11932650341519288, 0.1353111056877034, 0.18001553043723106, 0.05788711165743215, 0.09730465617030859, 0.1333576983639172, 0.13737146370112896, 0.14702878120754445, 0.11004491789000374, 0.14858804110969814, 0.18373947989727768, 0.13069885889334337, 0.06212494282850197, 0.147153821640781, 0.057046461052128246], [0.019955502856256704, 0.07128545735031366, 0.005637518720634813, 0.0030935844905408366, 0.07684860990515777, 0.08655044609414679, 0.021509785704048615, 0.002871541751249294, 0.0557539570145309, 0.02218290601324822, 0.08035538744713579, 0.002421537326881662, 0.01806811529344746, 0.03210910489516599, 0.04147486947476864, 0.08971204608678818, 0.005318871890527329, 0.025139542629144022, 0.029846041330269406, 0.057988532286669524, 0.10322800225445203, 0.07057011180690356, 0.05332350903855903, 0.027416914801246355, 0.010285466210916638, 0.04901252839980381, 0.031816116866788695, 0.03216640378481575, 0.08044669111924511, 0.027875114232301712, 0.00885841461630272, 0.044561240289892466, 0.018386921579284326, 0.016096457073997174, 0.04548458056524396, 0.09078360894428832, 0.015138060286907213, 0.031393189382340224, 0.02736679481209389, 0.10290758444794587, 0.05164556657629354, 0.029926101677119732, 0.04619993628667934, 0.0164685487148485, 0.014112200155588133, 0.06359730275081736, 0.02804501261562109, 0.011655308821770762, 0.03400518958057676, 0.038252011340643675, 0.03023977145286543, 0.06012527298714433, 0.06601765073303666, 0.06585093467895474, 0.01633537434307592, 0.10751761243279491, 0.02940731415791171, 0.049313177088541646, 0.03790822478809527, 0.022367255496127263, 0.03649811027571559, 0.041835168176995854, 0.03875740118590849, 0.06890919378825597, 0.046299789500023635, 0.010695221634315593, 0.04659210917140756, 0.05229991182152714, 0.06871977395245008, 0.048207253217697144, 0.02355503783162151, 0.014572489474500929, 0.06339191020067249, 0.05007095142666783, 0.047676292780254564, 0.0767341342621616, 0.019827415800786445, 0.06031087267079523, 0.039465557650796006, 0.06121918000280857, 0.03028951824775764, 0.030742470906781297, 0.01209802069102547, 0.04132837376424244, 0.08486174206648554, 0.08343656746936695, 0.07786929620695965, 0.07386144090976034, 0.004101993973433439, 0.04742926871404052, 0.041819996133978875, 0.04700171022808977, 0.014066950351532017, 0.11319447388606411, 0.03481942821027977, 0.018831482456464852, 0.11136665660887957, 0.035505196412226984, 0.04983211049277868, 0.06569490555141654, 0.025660072287012423, 0.024141840004761304, 0.04744790807100279, 0.028990106723670448, 0.015144820192030497, 0.04443050355517438, 0.09219666490597384, 0.05068166347752724, 0.01533455215394497, 0.026048721878656318, 0.07264450192451477, 0.026167373904692273, 0.1118399076429861, 0.026072161870875528, 0.04925233285341944, 0.05490696889215282, 0.035940968564578464, 0.023880120566380874, 0.047974118763314824, 0.04762060880394919, 0.06563127932271787, 0.02496735249379916, 0.08400918317160436, 0.051499399955251386, 0.04090628427054201, 0.07156958031867232, 0.01910809743484216, 0.005410327384847083, 0.035006788692304065, 0.05275870666706136, 0.025271259846964052, 0.050987163691648414, 0.0719063508191279, 0.04454147795747433, 0.013983455769318556, 0.00417011125578678, 0.02605574471609933, 0.11928359286061355, 0.05537170431177531, 0.04342029044138534, 0.04486785330144422, 0.03251735905983618, 0.013513179263100028, 0.02562075966436948, 0.02248392959258386, 0.006316286561611507, 0.02405049222787576, 0.008983009760933263, 0.019928590461079563, 0.025016566638701727, 0.08960846093084131, 0.03667188987934163, 0.060645872194852145, 0.019892307497294884, 0.018966478694762503, 0.028829568730933324, 0.021610699128359556, 0.01922945851194007, 0.07272195669689349, 0.06677891952650887, 0.04566111841372081, 0.038924320800496, 0.02800624112465552, 0.005480303004982748, 0.037454732693731785, 0.03921660654512899, 0.016584072694448487, 0.04513157272179212, 0.024702747585251927, 0.08966566821826355, 0.006782915518020413, 0.09802902622946671, 0.01588080677070788, 0.052226450227733166, 0.036995218601077795, 0.01577501298327531, 0.016516933350690773, 0.05979673990181514, 0.007801648911221751, 0.014474459824019244, 0.03977397217282227, 0.04207973933911749, 0.06670572595404727, 0.029857332152979713, 0.07093251736036368, 0.009562521075297679, 0.05959846518401589, 0.02624642662703991, 0.04177829337173274, 0.03063394601589867, 0.012637057391527508, 0.05366020829283765, 0.03357259636478765, 0.028104465853955065, 0.025071399053558707, 0.02576222234139485, 0.062482618992882114, 0.03648159473336168, 0.03781919420829841, 0.04854342321466122, 0.02306538151710161, 0.01983077115645366, 0.02878308908215591, 0.027038338061954294, 0.011869065164189254, 0.07391684329403297, 0.047819168506456275, 0.07111742493829556, 0.024497356731444597, 0.0416851406916976, 0.02253448554048581, 0.1079816964587995, 0.022279975536678518, 0.048506521087672026, 0.01425172561513526, 0.04079544896792088, 0.02638276127566184, 0.03076393296942115, 0.03351743146777153, 0.04225418051438672, 0.02979159907304815, 0.025676693002294217, 0.031066624048565115, 0.04362740986315267, 0.026854597564254488, 0.028507715822862725, 0.037327483629009554, 0.016714397219142745, 0.026630446913519075, 0.06220787337848118, 0.03665346086823514, 0.03840059354635222, 0.04724429328260677, 0.05038733534248812, 0.06171130109578371, 0.01741518988274038, 0.028874294366687536, 0.019174327541674887, 0.005647139074946088, 0.05506352388433047, 0.020658577093854547, 0.02219856151246599, 0.03229180723428726, 0.015942205708207827, 0.02124652429483831, 0.011940161215274461, 0.05024996253528765, 0.0938018751995904, 0.04711577875007476, 0.01893137807824782, 0.059495768908943446, 0.0037204401617470595, 0.03386623578678284, 0.037055306269654205, 0.07977042240755898, 0.019679995586297343, 0.005484832650316613, 0.04042565756078277, 0.021111516182177832, 0.028603796381503344, 0.03063430903213365, 0.08106900951159851, 0.028168299035834413, 0.02821012563072145, 0.03884047422824161, 0.043655402825347016, 0.020270375335322957, 0.07033153889434678, 0.04047814902982541, 0.01626258110627532, 0.04327568445088608, 0.01862885832919606, 0.07250967701630932, 0.02530474555013435, 0.08706981715347085, 0.014415412010358912, 0.02876448704461966, 0.02571823970148606, 0.03922923408182604, 0.02032768101032291, 0.06183140179408448, 0.0468332130195839, 0.051504858769476414, 0.09142111973570925, 0.028214023814403584, 0.013031848573258944, 0.02692274283617735, 0.04396105570984738, 0.07453856457556997, 0.058600950853100846, 0.07237910652267081, 0.017904727453632013, 0.01339603612931179, 0.02437954269615667, 0.03209045536017843, 0.014669709971972873, 0.04114883679098316, 0.031085378756480556, 0.06195152284843581, 0.021856403443962336, 0.057713583111763, 0.05536073918587395, 0.029489634026374136, 0.053259933699986765, 0.014707265188917518, 0.041594457879130325, 0.008073554008400865, 0.047093858676297326, 0.03238525507705552, 0.007428275687353951, 0.04895328890000071, 0.033671140005545955, 0.0353450892892267, 0.04437202062191708, 0.06397777090647391, 0.04295045243842261, 0.04331544321030378, 0.013021410160165812, 0.01848427439108491, 0.023571592389738986, 0.032773512814726145, 0.012114942506221789, 0.05166166142693587, 0.019131980171161037, 0.009512673348321446, 0.009382565106664385, 0.020885390994538153, 0.05875415727496147, 0.01602467485437436, 0.04355095932260156, 0.02119779190979898, 0.010841035417148044, 0.03449523435639484, 0.032179848956210275, 0.04724899213761091, 0.029149776191583703, 0.02019146171265415, 0.005531816535429763, 0.029852416166769605, 0.0160743792408279, 0.031502331740089824, 0.008986388017157359, 0.03822111764124461, 0.04771173605695367, 0.024988280210111822, 0.06214738876691886, 0.0338841321478997, 0.07263707875141076, 0.0383035596460104, 0.06580966617912054, 0.06514432188123465, 0.021083406172692776, 0.09637678667370762, 0.1647610996982881, 0.11954719014465809, 0.07214415020176343, 0.1159401929804257, 0.22220846638083458, 0.14427471613245352, 0.10375333085123982, 0.13056473966155732, 0.09852264009948287, 0.2268005742558411, 0.11960850256894316, 0.164304092792528, 0.152459069820387, 0.07916492489831788, 0.1705040843891246, 0.1100198392357145, 0.1265669741800853, 0.15511573797890119, 0.0861283362443958, 0.12493460891502244, 0.12370320356317929, 0.1912435343755143, 0.15814551897346973, 0.08195789038602795, 0.1184087305196694, 0.11278650470610176, 0.10275342129170895, 0.19347073057932512, 0.22058474565190928, 0.12437986582517624, 0.09187577212495462, 0.12715387982981546, 0.051286434954298396, 0.17310883104801178, 0.1450923236885241, 0.0896415530837008, 0.18638746280755314, 0.1356549465230533, 0.18994042144290038, 0.09288535759385143, 0.14065037561314447, 0.1431156290428979, 0.09615272083984953, 0.07775234391114541, 0.16701683508498327, 0.06622572349650518, 0.1315783081310136, 0.13879564085177012, 0.05634437747565763, 0.11310302772160087, 0.11906118265220098, 0.1214184540190867, 0.1422687494861228, 0.09128273251865592, 0.14921582170895167, 0.15874951013496943, 0.1491063740104437, 0.12555191293358803, 0.11330991983413696, 0.22910121509007045, 0.15129531440990313, 0.16879668672169956, 0.2580499345702784, 0.2084950293813433, 0.0733249436265656, 0.15142486031566346, 0.09386218339204788, 0.15478058239179, 0.16685801717851842, 0.09788521073226418, 0.1970145289919206, 0.2185136125023876, 0.12391846201249532, 0.2879243658057281, 0.12252245763582842, 0.12949714623391628, 0.19592131408197538, 0.22067066175597055, 0.13859761719192776, 0.13776064424642495, 0.09946343568818909, 0.12784015014767647, 0.09989138093910047, 0.1439272654908044, 0.22751319887382643, 0.19016253309590475, 0.24376394972205162, 0.12255445734730788, 0.13271161088986055, 0.15950583240815572, 0.15868553785341127, 0.20392325041549547, 0.19472578966191836, 0.2511929582272257, 0.19065471525703157, 0.42143044620752335, 0.09580716331090246, 0.12588941625186376, 0.17507400416902133, 0.1502368404929127, 0.14017455971666745, 0.11921024322509766, 0.10513498421226229, 0.1125583608767816, 0.1735396600727524, 0.15824887342751026, 0.12997932678886823, 0.14588781100298676, 0.12530389481357165, 0.10249335917511157, 0.12588317372969218, 0.28251418897083824, 0.21557096897491387, 0.15529191281114305, 0.1949642404381718, 0.2137870868401868, 0.12634782093976224, 0.15792441155229295, 0.17801069015903132, 0.12669266600693974, 0.09076406713575125, 0.17886620068124362, 0.1394505085689681, 0.21064990732286656, 0.18593268149665423, 0.06431601382791996, 0.183811825300966, 0.08958374868546214, 0.12044892247234072, 0.1373373605310917, 0.11731866401221071, 0.11776230377810341, 0.056546706440193314, 0.22516831755638123, 0.09998946996139628, 0.1471923624298402, 0.18369708502931253, 0.18529124877282552, 0.18704387758459362, 0.1111534201939191, 0.12685322096305235, 0.1347378793039492, 0.09365129470825195, 0.124583507754973, 0.08342989068478346, 0.14272769700203622, 0.0874672486845936, 0.07310758171869175, 0.07183177303522825, 0.1639186849019357, 0.14034519770315715, 0.12648487144282886, 0.14652053133717605, 0.06760215892323426, 0.10485878653292145, 0.13987794491861547, 0.15176016518047877, 0.16409568754690035, 0.11246246352259602, 0.16731860674917698, 0.11296519011791263, 0.07958862252001252, 0.11695743910968304, 0.11046430681432996, 0.10152914734291178, 0.1316877015467201, 0.14672567961471422, 0.11979657890541212, 0.16501135698386601, 0.04981461785999792, 0.14094894459205015, 0.10051335327859436, 0.11004055490983383, 0.17346863102700028, 0.1119555232248136], [0.018484235375321338, 0.026807140825050216, 0.021735403686761856, 0.021638437639921904, 0.057072571079645834, 0.08992107558463301, 0.028221755720941082, 0.057480628469160626, 0.05495759778256927, 0.03203507333195635, 0.03071096313319036, 0.027958309410938194, 0.09428417110549552, 0.04129219088437302, 0.05934020797056811, 0.0536357369273901, 0.05308150952415807, 0.0466678947476404, 0.008209350918020521, 0.06507593912205525, 0.004732983195156391, 0.06518791775618281, 0.0250871173172657, 0.039307062048465014, 0.004131277000331985, 0.0526488925596433, 0.05622399179264903, 0.06984620315155812, 0.01625597896054387, 0.003974560856087399, 0.07104478097919907, 0.04113083864961352, 0.13036738096603326, 0.05609275972736733, 0.04588329792022705, 0.012198961256737155, 0.037482946179807186, 0.029331816959061792, 0.024058873831693615, 0.05465863864602787, 0.011338107271252998, 0.014443198019372565, 0.0769149095618299, 0.04560387719954763, 0.047819914894976785, 0.10130182454096419, 0.07510271216077463, 0.05618981398375971, 0.016348210529291203, 0.03590719787670033, 0.030989386407392364, 0.022781611386952654, 0.026947745155276995, 0.03152676917878645, 0.021374529926106334, 0.04095821255551917, 0.020236721694735543, 0.04825773622308459, 0.0195642731352044, 0.004586550673203809, 0.03554779484069773, 0.08035968935915402, 0.07349558839840548, 0.03797842262844954, 0.009662265723038996, 0.052493016102484295, 0.03391463229698794, 0.005794465990870127, 0.04249097566519465, 0.04139042918437293, 0.058954732226473947, 0.031013277625398974, 0.008533833997457154, 0.018767437232392173, 0.02813848590345255, 0.03917667815195663, 0.016189638591770614, 0.06231238134205341, 0.013386536639050713, 0.03932419505768588, 0.04543879980753575, 0.016137691647080437, 0.060169988444873264, 0.08470529224723577, 0.038584690274936814, 0.015376220989440168, 0.048764106551451344, 0.013339019679863538, 0.07707378853644643, 0.028653936726706367, 0.005874486897872495, 0.02965276741555759, 0.04850380016224725, 0.10208938656640903, 0.03557453929845776, 0.00311142996153129, 0.05536373831065638, 0.03706624425415482, 0.025559124935950552, 0.030248507591230527, 0.058242847211658955, 0.016561328200623393, 0.04698689441595759, 0.007356748766531902, 0.04134200553276709, 0.022922843362071683, 0.04710215037422521, 0.028071638329752853, 0.05469226684155209, 0.052528462771858485, 0.0351861967439098, 0.04365015435697777, 0.035206698679498265, 0.007994107735742415, 0.01870772784708866, 0.012541082853983556, 0.009902733444635357, 0.019851785385981202, 0.020557426182287078, 0.05716323692883764, 0.054633200368178744, 0.008694261728253747, 0.0038116721635950463, 0.0534568140283227, 0.017459840879642537, 0.04711634871949043, 0.03529864017452512, 0.047632557805627584, 0.0673447430932096, 0.04339918800230537, 0.042582537180611064, 0.06994597494070019, 0.07229475783450262, 0.021627240115776658, 0.03822646449719157, 0.07294986303895712, 0.0611693619617394, 0.02321066095360688, 0.01761116267048887, 0.021066318964585662, 0.039352595140891414, 0.014086552380051996, 0.0044684711610898376, 0.01364125105153237, 0.04704631372754063, 0.03579997577305351, 0.015326813462057283, 0.058832175231405666, 0.06800863532615559, 0.016142388805747032, 0.010463865789850908, 0.004716676726405109, 0.05189189514411347, 0.01442135258444718, 0.033373110461980104, 0.03923155467158981, 0.04924637531595571, 0.02052344854122826, 0.055474515937800915, 0.0285731435620359, 0.031803791278174946, 0.029353197597499405, 0.034546433216226954, 0.05649520902495299, 0.021991063807425753, 0.04113505913742951, 0.06124315264501742, 0.02140985954818981, 0.11117286700755358, 0.02219267691751676, 0.057070026573325904, 0.07629229939941849, 0.04149510678169983, 0.01849254573296223, 0.008690085345213967, 0.016715325115780746, 0.06252370428826128, 0.027001883768077408, 0.034395462567252774, 0.04336349706032446, 0.031100550799497535, 0.07384778199983494, 0.057335455901920795, 0.014754257131634014, 0.08795894230050699, 0.02585836057551205, 0.007589929870196751, 0.056263492708759646, 0.019434404925310185, 0.041030557959207466, 0.04005051251234753, 0.060498175477342944, 0.04262792778068355, 0.01893175975419581, 0.08244376217148133, 0.055295226629823446, 0.06014887922044311, 0.04062266681077225, 0.021983727147536616, 0.1132565869816712, 0.024907867025051798, 0.05335746971624238, 0.020906922607017413, 0.033191313967108727, 0.024177217124296085, 0.033309708149837594, 0.02095855912193656, 0.039363991136529615, 0.020972131518647075, 0.006325199119081455, 0.026306828118062446, 0.00492294119404895, 0.04319593623014433, 0.0351377493435783, 0.038954485074750016, 0.05961795949510165, 0.0734793646261096, 0.044574878843767304, 0.08275415123041187, 0.044114319807184596, 0.06983536016196012, 0.07304399620209422, 0.033189926362995587, 0.027841282476271902, 0.026481425356385962, 0.04662130314058491, 0.060746967127280574, 0.04866464349574276, 0.023654383840039372, 0.04118783219850489, 0.08662420285067388, 0.027056697523221374, 0.03192225670708077, 0.048696439646716626, 0.03217654109799436, 0.018443049996026924, 0.06743406544306449, 0.0209344660397619, 0.04073443849171911, 0.02414322760887444, 0.00688277678896806, 0.0154449328381036, 0.05772098592881646, 0.009684633629928743, 0.052461403155965466, 0.06855972111225128, 0.06708913216633455, 0.05112200556322932, 0.01708786967875702, 0.05812757768269096, 0.022954344350312437, 0.011054952911633466, 0.08260419499129057, 0.01049013527309788, 0.02161602902093104, 0.03838024428114295, 0.0359140409023634, 0.021640982146241834, 0.07069273665547371, 0.0754733754854117, 0.02135246227096234, 0.038230983540415764, 0.03753618403737034, 0.03856369640145983, 0.004906630484453801, 0.03599714108609727, 0.0010913197828423499, 0.03906924230977893, 0.022964176322732652, 0.0588084604325039, 0.09497665001877717, 0.013042884945337261, 0.024321836685495715, 0.04537721936191831, 0.03489323924960835, 0.029694622848182917, 0.023012197942339947, 0.03395316630069699, 0.009680329173404192, 0.02407978119195572, 0.010870913858525455, 0.034669621248862574, 0.049025417172483036, 0.03905668941193393, 0.06632071161376578, 0.006892650321658168, 0.007748064152630312, 0.037152323206620555, 0.04978276403354747, 0.007825968454458883, 0.02790090534836054, 0.03885912376322916, 0.00447121456298711, 0.03588474515293326, 0.04260653357154556, 0.05748921872249671, 0.027127073479018042, 0.01817609226730253, 0.02066898582104061, 0.06538211447851998, 0.03582128855798926, 0.012632249122751611, 0.030137862278414623, 0.05279673855485661, 0.08454200958034822, 0.086012164263853, 0.03590582723596266, 0.0637688296181815, 0.04519780452496239, 0.01894439068356795, 0.01939291081258229, 0.07121252162115914, 0.031087282047207867, 0.03778934206015297, 0.010405706008896232, 0.041215163589056046, 0.05719150469771453, 0.03152518819219299, 0.011024866668906595, 0.027785915715087737, 0.04317364974745682, 0.01730060567414122, 0.022970574907958508, 0.014431769793320979, 0.01971781543189926, 0.039161333082509894, 0.05730847056422915, 0.04329855108101453, 0.05097449544285025, 0.02869020103077803, 0.017616387390132462, 0.04779990150460175, 0.025159062385292988, 0.0036521973504152682, 0.02213080130916621, 0.0259035934161927, 0.009592877035694463, 0.011952844731110548, 0.050099565248404226, 0.05237229454464146, 0.045734145745102844, 0.033973308612725565, 0.036369989293494394, 0.06694571700479303, 0.04438132672969784, 0.03167685433956129, 0.014103994970875127, 0.02282395027577877, 0.047203462437859604, 0.03628503331648452, 0.021178119483270814, 0.008738676934236926, 0.17902408220938273, 0.14030714545931133, 0.14383455046585628, 0.10991770614470754, 0.08526770956814289, 0.12868458697838442, 0.10101266005741698, 0.09525623358786106, 0.14661397917994431, 0.11125489510595798, 0.12112372554838657, 0.24440283115421021, 0.18672678459967884, 0.13002686495227472, 0.20252453189875397, 0.13883769645222596, 0.12733266023652895, 0.10289009860051529, 0.1703306236969573, 0.23570699776921952, 0.13680582333888325, 0.12018959995891366, 0.11508555098303727, 0.20225279219448566, 0.1261648064745324, 0.11249799840152264, 0.13819236893739018, 0.14718807408852236, 0.0884908933990768, 0.12668577209115028, 0.17191052463437828, 0.094792387049113, 0.2707501830799239, 0.12258250798497881, 0.15408630536070891, 0.15589314912046703, 0.1903247165360621, 0.14237947283046587, 0.08150716671454054, 0.13804387833390916, 0.11919550544449262, 0.11734777316451073, 0.18370646238327026, 0.13872340401368483, 0.13195659140391008, 0.2591826266476086, 0.10018296779266425, 0.16875708741801126, 0.08849615883082151, 0.14335893812988484, 0.18656698960278714, 0.1831373886338302, 0.10609040901597057, 0.09140032263738768, 0.1396562810987234, 0.10544780921190977, 0.1147402852241482, 0.19268528558313847, 0.14847377581255777, 0.09572962711432151, 0.14468198642134666, 0.17207800064768108, 0.13854254728981427, 0.06257787852415017, 0.20134086827082293, 0.11753287751759801, 0.17791701161435672, 0.07463947630354337, 0.1077774709888867, 0.19892026244529656, 0.147975228992956, 0.0829407347898398, 0.11609792523086071, 0.13604063939835342, 0.19110951013863087, 0.19827455495085033, 0.21780016007167952, 0.1828342191874981, 0.10034095788640635, 0.20858702515917166, 0.13272979562836035, 0.08990382043910877, 0.2232976100806679, 0.27463376468845774, 0.09293594916484185, 0.17067895643413067, 0.13370738817112787, 0.1239933722785541, 0.14008335103946074, 0.21635482619915689, 0.10501028304653508, 0.14885398612490722, 0.2506710833736828, 0.19214310896183762, 0.24844312721065112, 0.1024272223668439, 0.15954136050173215, 0.1686509916824954, 0.09671358431556396, 0.08761797166828598, 0.10833909442382199, 0.25824817536132677, 0.07901709925915514, 0.09115554112941027, 0.0935763640861426, 0.14024101543639386, 0.1312852217150586, 0.1255981618804591, 0.14659702937517846, 0.1461283109549965, 0.14371603753949913, 0.17525122394519194, 0.14158583113125392, 0.17690136682774338, 0.10296131085072245, 0.0986092279532126, 0.16482994386128016, 0.12449010062430586, 0.07920957928789513, 0.19693747455520288, 0.16391279521797383, 0.11895636256252017, 0.09900948219001293, 0.2082904375025204, 0.17781760623412474, 0.10590427328965493, 0.12865520641207695, 0.13284962491265365, 0.14273714220949582, 0.12848988814013346, 0.16104575406227792, 0.22565347009471484, 0.19830679893493652, 0.06906848666923386, 0.180839190525668, 0.21983613153653486, 0.21049018017947674, 0.11710367697690215, 0.1286172763045345, 0.07736823202243873, 0.08657019146318946, 0.10856108394052301, 0.10985484666057996, 0.10912241560540029, 0.13410224126917974, 0.10814323529068913, 0.12247063113110405, 0.14236136951616832, 0.21008343914789812, 0.1765754528875862, 0.12464133250926222, 0.15274632083518164, 0.14293684863618442, 0.1987991575151682, 0.10478507048849549, 0.13802653497883252, 0.1608793501343046, 0.07383685080068451, 0.1435191673891885, 0.07018671237996646, 0.13773575558194093, 0.05930816076163735, 0.1006223192172391, 0.19576031129275048, 0.1493820356471198, 0.0881532272323966, 0.14759045892528125, 0.12219080328941345, 0.1456068025103637, 0.10304414640579905, 0.16447109383131775, 0.13823886215686798, 0.11282449588179588, 0.12429468253893511, 0.1587580596762044, 0.1302711647003889], [0.03576439678935068, 0.013413259044422634, 0.026469113338472586, 0.011689890358996178, 0.018320493000958647, 0.03552303170519216, 0.07730360834726266, 0.04740833251604012, 0.036214302826140604, 0.0016972806042758748, 0.025462065590545535, 0.01558678736910224, 0.007259803075742508, 0.017249934375286102, 0.032527584582567215, 0.04520394865955625, 0.04205536975392273, 0.049262158040489466, 0.07088388675557715, 0.030097618366458585, 0.008395735157786735, 0.009958631159471614, 0.0029343641279930516, 0.020065337319725325, 0.0637729415403945, 0.02218330804524677, 0.027376148417325954, 0.01604581461288035, 0.0147974391002208, 0.02987594097586615, 0.034461687585072856, 0.07289017231336661, 0.03414772943194423, 0.023020233493298292, 0.0704855052754283, 0.012341284825067435, 0.01614895023937736, 0.031739303310002596, 0.05725195538252592, 0.018862362585163543, 0.034406142708446295, 0.013359469877156829, 0.02499272970349661, 0.02681656228378415, 0.00794238894845226, 0.026754951304090873, 0.05432247882708907, 0.11157308053225279, 0.026622409666223184, 0.03678717976436019, 0.051182771766824384, 0.07079056104911224, 0.04627263452857733, 0.06475283431687526, 0.01484561339020729, 0.045801066261317046, 0.03773471999115177, 0.1332555788436106, 0.014690245834312268, 0.045515063750956736, 0.03506779916850584, 0.038090604823082685, 0.09367346923266139, 0.04247746942564845, 0.06305922448102917, 0.05968944315931626, 0.016169793138812696, 0.07262620862041201, 0.026270747018445815, 0.04347415255116565, 0.05841786174901894, 0.022030373037393605, 0.06243821566126176, 0.04685179470106959, 0.02906344278848597, 0.02459856022947601, 0.04525953424828393, 0.05158469859244568, 0.0032960960234049708, 0.03002343074019466, 0.05786887263613088, 0.03072703762778214, 0.019697971675278883, 0.05273889344451683, 0.06063795369118452, 0.03476355763684426, 0.03550588173259582, 0.02096528510030891, 0.011744938208721578, 0.02410812020700957, 0.039103281018989425, 0.08695886989257165, 0.048311398165034394, 0.022572871962828294, 0.03829243845705475, 0.04441364195996097, 0.03814252293003457, 0.029816908429243734, 0.07211903762072325, 0.04499933981735792, 0.016064513341656754, 0.12714902151908192, 0.018499527858304124, 0.019241714550714408, 0.049290354563189406, 0.006176001991012267, 0.016424749279394746, 0.05376107591603484, 0.01863258348644844, 0.02905144289668117, 0.062104769982397556, 0.061405587143131664, 0.05712934410465615, 0.04810388519295624, 0.01566064081686948, 0.007260928595704692, 0.10515409175838743, 0.020894220431468317, 0.07133205235004425, 0.023270509438589215, 0.04959715077919619, 0.03174742537417582, 0.07411899244678871, 0.08074429657842432, 0.03922783290701253, 0.008116831820059036, 0.05887615108596427, 0.03763973865924137, 0.04229091979297144, 0.06733639711248023, 0.029153905077172176, 0.015140012771423374, 0.04216613041769181, 0.01332678399713976, 0.026603507376941185, 0.02700184135963874, 0.07257409713097981, 0.03795732697471976, 0.014313830229054605, 0.03412131406366825, 0.006326146523601243, 0.017202055248032724, 0.06690389210624353, 0.017437335569411516, 0.016765587597287128, 0.019708363439089487, 0.0347972740419209, 0.05748816020786762, 0.046940489406032224, 0.06100026424974203, 0.0673839556319373, 0.04299655210758958, 0.02204619986670358, 0.0470961283759347, 0.030220938713422844, 0.05005741465304579, 0.02324253004709525, 0.06683489866554737, 0.026080821674051027, 0.09050456141786915, 0.027861972705328038, 0.06692483848226921, 0.040252712555229664, 0.027038521266409328, 0.044244917442223856, 0.010961947812964874, 0.028173628928405896, 0.037987056986561844, 0.009321194158733954, 0.06675477046519518, 0.05580720165744424, 0.03303161396511963, 0.06682974858475582, 0.04726487324972238, 0.04574966384097934, 0.047259940300136805, 0.017191261452223574, 0.005885667882726661, 0.03057245717250875, 0.026521134922014813, 0.011935988224909773, 0.06125826361988272, 0.03320289995255215, 0.05618818549971495, 0.05868650733360222, 0.021053250380126492, 0.0608204999672515, 0.02419971564917692, 0.041898248185004504, 0.016286960869495357, 0.10495783907494374, 0.04092719332714166, 0.05768382256584508, 0.022226435731032064, 0.048310091985123496, 0.059779342263936996, 0.023140357940324714, 0.013799716119787522, 0.038582966795989444, 0.04958632814564875, 0.081883265104677, 0.01737589931248554, 0.03389047645032406, 0.02855265519714781, 0.06084327160247734, 0.05266368801572493, 0.04147080165733184, 0.03957616225151079, 0.031233679370156357, 0.01389228186703154, 0.04954783146136573, 0.02767767750525049, 0.02498617166254137, 0.10420468556029455, 0.018605618504807353, 0.09192997350224427, 0.05089601268991828, 0.007296209023999316, 0.02100222115404904, 0.04557035417695131, 0.019570668327755163, 0.06248922113861356, 0.028809884430042336, 0.05547333189419337, 0.034855628053524663, 0.027439791609400084, 0.09431346346225057, 0.0008180160553560459, 0.08210264226155621, 0.08417554638747658, 0.009976323960082871, 0.06917823970850025, 0.04218373161607555, 0.05478869006037712, 0.03332398791930505, 0.04155709095565336, 0.025873754838747636, 0.0817578514771802, 0.03712457451703293, 0.01672615283834083, 0.006866815100823129, 0.04391450481489301, 0.03794347128963896, 0.055032324844173024, 0.09182727044182164, 0.04087457632912057, 0.02958894780437861, 0.036305026350809, 0.04254738228129489, 0.06822397519967385, 0.04705658335504787, 0.07574513554573059, 0.07871432336313383, 0.04840122941615326, 0.015965048589610627, 0.029756915755569935, 0.06306110402303082, 0.07468774049941983, 0.039230065287223885, 0.0374603950684624, 0.028447261745376245, 0.005538623089835579, 0.015888481001768793, 0.020231269665860703, 0.031035994977823327, 0.013486032773341452, 0.03546489482479436, 0.048622021318546364, 0.021990330989605615, 0.024957374636349932, 0.052803761392299614, 0.07254253846726247, 0.09394148377967732, 0.02484261231230838, 0.05186962562480143, 0.03139121484543596, 0.029026842609580075, 0.04018136799069388, 0.053181264349924665, 0.03910469576450331, 0.032757780980318785, 0.042131460670913966, 0.03188025538942643, 0.04863486259377428, 0.026950656070507, 0.04272948411692466, 0.07003400807401963, 0.07785457199705498, 0.03901696457926716, 0.06309499684721231, 0.07282118565802063, 0.08372111791478735, 0.04644603754526802, 0.05559342919981905, 0.03242657107434102, 0.00964487062966717, 0.06963040187422719, 0.03811296594462224, 0.07806867015148912, 0.04437841581446784, 0.060460516783807955, 0.019153423574087874, 0.0578916035592556, 0.024227537281279053, 0.061243899033537934, 0.02333072602881917, 0.02878150131021227, 0.04445377391363893, 0.04124242712610534, 0.017915560265204737, 0.044066801999828646, 0.04284031941954579, 0.05241884204692074, 0.04701892466151288, 0.03660745619397078, 0.004154233960434794, 0.018083925159381967, 0.01007146474772266, 0.04717197162764413, 0.030910045307661806, 0.01243232556485704, 0.016500541640977775, 0.015169588416548712, 0.020756409969180822, 0.09065855494035141, 0.06481618913156645, 0.013372377309549068, 0.011715844323459481, 0.017836310767701695, 0.049438214129103084, 0.049233388155698776, 0.04560847766697407, 0.021736664065558995, 0.04899107990786433, 0.037561774985598664, 0.08334078546613455, 0.03496837343222328, 0.02790816736939762, 0.06552775523492269, 0.030426952123109783, 0.03364788321778178, 0.030906686559319496, 0.02125599834003619, 0.01391247591735529, 0.019124728328149234, 0.03862189095733421, 0.07094478527350084, 0.03643320161583168, 0.026978265660415803, 0.02633672606732164, 0.04003352199548057, 0.05830734196518149, 0.1330231534583228, 0.12928327199603828, 0.1455001232347318, 0.09555717065398182, 0.08224834408611059, 0.13527838672910417, 0.1571254637092352, 0.102927200895335, 0.2667514947908265, 0.07199196158243076, 0.17247878414179596, 0.0693316361201661, 0.13667946654771054, 0.14665090505565914, 0.13835229964128562, 0.08591836358287505, 0.19829111120530538, 0.13099839139197553, 0.18070138006338052, 0.19578563421964645, 0.09016010311565228, 0.14040513948670455, 0.09975415401692901, 0.12070882852588381, 0.1643878918673311, 0.15372973520840916, 0.10056406698588814, 0.10364663121955735, 0.11468653167997088, 0.10888956274305071, 0.13674793073109218, 0.10362573912633316, 0.09771285605217729, 0.15260708544935497, 0.14160097603287014, 0.1019993924668857, 0.10148573467241866, 0.19013617879578046, 0.11505946809692041, 0.14178096423191683, 0.17964946079467023, 0.06264987787497894, 0.08399046239043985, 0.1897098823849644, 0.061688597314059734, 0.12382683264357702, 0.08251030610076018, 0.21540886695895875, 0.07302182167768478, 0.08947120008191892, 0.11887303846223013, 0.12799979586686405, 0.1751283819654158, 0.24043595258678707, 0.069221238472632, 0.1643542636718069, 0.1575161370315722, 0.20495568215847015, 0.1316460259258747, 0.1199687368103436, 0.10310568953199045, 0.12745297806603567, 0.2485898264816829, 0.16626349836587906, 0.1516804780278887, 0.16399706926728996, 0.11113385802933148, 0.132201936095953, 0.14384552916245802, 0.3090779392846993, 0.1077277140159692, 0.12497430321361337, 0.0850254250690341, 0.1386475030864988, 0.11365688193057265, 0.14050879249615328, 0.14909611456096172, 0.08977460701550756, 0.12592320729579243, 0.1472648163991315, 0.1768940250788416, 0.10047013059790645, 0.10472559689411096, 0.13955011750970567, 0.11060284330908741, 0.13945923452930792, 0.1133969012381775, 0.13197769384299005, 0.07210923957505397, 0.0869130144960114, 0.1455733643046447, 0.18267884823892797, 0.17496941478124686, 0.1324810582612242, 0.15871311351656914, 0.2352923857314246, 0.19909039831587247, 0.18261453668986047, 0.1564654391258955, 0.11158591841480561, 0.17894898195351872, 0.1682308835110494, 0.169152008369565, 0.23736734581845148, 0.15905824356845447, 0.10376690833696298, 0.23146436257021769, 0.18298028063561234, 0.178801956985678, 0.11044808982738427, 0.1979957991944892, 0.2136400347309453, 0.08805373364261218, 0.14810282071786268, 0.14254917443862983, 0.11624588657702718, 0.38573982992342537, 0.13965786887066706, 0.1598352204476084, 0.12957357641841682, 0.17764106499297277, 0.1633772546691554, 0.18913516322416918, 0.13156918862036296, 0.14093883442027227, 0.1604856098336833, 0.15627705066331796, 0.14724022629005568, 0.2198965618652957, 0.1801590948764767, 0.11727903756712164, 0.10502603184431791, 0.12002721295825072, 0.046522878243454864, 0.1326521440808262, 0.09496851438390357, 0.24601489465151513, 0.15166633735810006, 0.13024890875177725, 0.151840585150889, 0.05196539066465838, 0.1720634935689824, 0.13516199083200522, 0.12031036562153272, 0.08379172626882792, 0.05650216740156923, 0.107578816291477, 0.09394463896751404, 0.151089840435556, 0.15281874766307219, 0.09500837153089897, 0.1069693018549255, 0.10547737976802246, 0.21754693080271992, 0.17230619197445257, 0.24970338387148722, 0.06768743720437799, 0.12119305825659207, 0.09647932688572577, 0.2527726963162422, 0.07601992187223264, 0.16025958981897148, 0.17441909573972225, 0.08869034198245832, 0.10360593268913881, 0.20263559451060636, 0.06086514757147857, 0.12807976800416196, 0.10744906682521105, 0.1890239106225116, 0.22969715882624897, 0.11354213487356901, 0.1933526654860803, 0.09963655711284705, 0.11734934736575399, 0.09689853260559694], [0.02345008373127452, 0.021376908191346695, 0.06062700892133372, 0.04084556556439825, 0.06310596197311368, 0.00547540483031688, 0.05540060651089464, 0.014229925981323634, 0.0656358797901443, 0.0355556929883148, 0.013265067844518592, 0.052181459963321686, 0.012141419790818222, 0.01632961188443005, 0.08118302375078201, 0.029804077332041094, 0.020430243274729167, 0.017543365147763064, 0.013400466114814793, 0.028257112484425306, 0.03647305876282709, 0.024988049508205483, 0.052129317939813645, 0.022271101994972144, 0.06199888459273747, 0.05454165920881288, 0.03402723179065755, 0.03640483545937708, 0.04426436086318322, 0.022236627327012162, 0.01581569794299347, 0.05058290949091315, 0.014333400875329971, 0.05900440777518919, 0.031331741251051426, 0.06589444912970066, 0.0637092406728438, 0.07340050528624228, 0.017439359300104634, 0.052940258889326026, 0.015233988175168633, 0.015594500615926725, 0.015143968630582094, 0.026575526289109672, 0.034713922800230126, 0.04997038575155394, 0.03942064541791167, 0.0508806913691972, 0.06474669357495648, 0.02818877891903477, 0.04794323863461614, 0.0416532597238464, 0.043365865147539547, 0.0350427171215415, 0.02469582822439926, 0.005585141754376569, 0.027650393612150635, 0.013686257431150546, 0.025336738476263623, 0.010083561330767614, 0.0555159438933645, 0.0803811853485448, 0.03257893950545362, 0.03438532864674926, 0.029961928326104368, 0.04675825186339872, 0.0039495326678401655, 0.024706484616867135, 0.03371057306815471, 0.04342167126014829, 0.03275750278096114, 0.05887406798345702, 0.021906971266227107, 0.07338325014071805, 0.03303924069872924, 0.015612890611269643, 0.03959344793111086, 0.019193772658971802, 0.02224231175413089, 0.01738304428623191, 0.046917303864445, 0.045016320156199593, 0.07793906317757708, 0.02535203435192151, 0.0405370967595705, 0.03899966872164181, 0.04778156748839787, 0.04808291167552982, 0.02875389511297856, 0.026716027142746106, 0.07013003434985876, 0.05881846882402897, 0.021801923867315054, 0.021082883700728416, 0.04904061296422567, 0.01771503620381866, 0.020103942569611327, 0.014973021910658904, 0.0375192851227309, 0.022669142511274134, 0.06003028486988374, 0.028793928679078817, 0.05665416942377176, 0.05183298134111932, 0.021790225923593556, 0.013408712859797691, 0.011825109665681208, 0.012961198658948498, 0.05438455460327012, 0.03416041464411786, 0.002188708001215543, 0.08874722357307162, 0.048892193606921604, 0.0132955629045942, 0.07377560622990131, 0.028640013188123703, 0.030225878448358605, 0.012378842586518397, 0.04166437412745186, 0.004231312145878161, 0.016268246873681034, 0.027541464992931912, 0.03061928626682077, 0.048661098150270324, 0.03976423519530466, 0.015071209320532424, 0.014659910229966044, 0.03498265320169074, 0.14540492477161543, 0.05575083236077002, 0.009572498932746904, 0.03930546749117119, 0.05808593598859651, 0.02078427909873426, 0.04962257209366985, 0.018743289867416024, 0.07184832250433308, 0.0016942087490211374, 0.02936290404094117, 0.01140586577821523, 0.015580935004566396, 0.0376169330972646, 0.03627842777807798, 0.029361380729824305, 0.05557917657175234, 0.05115603409441454, 0.03875826631805726, 0.03977956669405103, 0.038535845931619406, 0.024725590466654727, 0.030962567310780287, 0.03756966295519045, 0.01970861110437129, 0.04017719500032919, 0.04700820720089333, 0.030763790477067232, 0.02203221356363169, 0.023130934785253236, 0.04039020410605839, 0.09034621170056717, 0.0323265787613179, 0.0649583897154246, 0.04561216211212533, 0.030144321931792156, 0.011079742340371013, 0.01042834363345589, 0.04372431144916585, 0.021512496451448117, 0.00918520471480276, 0.00247738287933836, 0.10374290855335337, 0.04714689975870507, 0.01089202902013702, 0.029286938652928387, 0.02691729080730251, 0.03072302070047174, 0.0574248121785266, 0.04317064044464912, 0.03836029874426978, 0.026323981483333876, 0.04721507217202868, 0.04276995533811195, 0.011441517704432564, 0.0613224326765963, 0.01793431836579527, 0.07078686303326062, 0.040732192540807385, 0.04267994427521314, 0.040265007609767575, 0.09971032065472432, 0.07279210364712135, 0.017091070667707493, 0.026668924938089082, 0.039295038407934565, 0.027376104312549745, 0.048862677333610396, 0.035399195671613724, 0.023812166980600784, 0.04264470795169473, 0.029269829392433167, 0.01883083615185959, 0.05106742759900434, 0.06638370001954691, 0.002308129104286698, 0.07730716387076036, 0.016008359479850957, 0.02404061615067933, 0.09063419553318194, 0.027088105212897062, 0.049951810855418444, 0.008845660702458449, 0.05218497816739338, 0.030776109280330793, 0.04002829388316188, 0.06264637663428273, 0.05016554260094251, 0.050974912741886716, 0.02181034957590912, 0.015929442464507053, 0.046099550423345396, 0.034456055744418075, 0.05060125029246722, 0.07000614064080374, 0.04194851066651089, 0.036574855978999815, 0.006353799794201872, 0.019555012828537395, 0.05244202080315777, 0.03548712023933019, 0.026229319062882235, 0.03587855352088809, 0.042164705494152646, 0.039215062877961566, 0.016746410501322577, 0.02320932423962014, 0.0343542788842959, 0.02019204355643264, 0.01245396489477051, 0.031213282607495785, 0.052565147767641714, 0.015358309361285396, 0.007056070815971387, 0.009855528611556759, 0.050583062161292346, 0.03253883469317641, 0.05109326621251447, 0.05444319699225681, 0.06420726502048117, 0.04396909974249346, 0.04208296577313116, 0.052427272844527445, 0.04833847849762865, 0.037982792393969636, 0.05150803092068859, 0.030034792809081928, 0.0279389525031937, 0.017119670918743526, 0.06946196234119789, 0.07364401793373482, 0.030880023525761705, 0.029160439369401762, 0.027298164387632693, 0.011577078823133238, 0.04326090595817991, 0.04882283714999046, 0.007573474547825754, 0.03634799797354, 0.08866776712238789, 0.05080997105687857, 0.02637313456008477, 0.08889174474669354, 0.03522994189656206, 0.013211107347160578, 0.01149695401545614, 0.025831288724605526, 0.047756329378379245, 0.04364687024748751, 0.07232118677347898, 0.03417608201769846, 0.053494109705622704, 0.05593451518299324, 0.05156118396137442, 0.06170431897044182, 0.018400368447016393, 0.028111152816563845, 0.05508859236059444, 0.037700827166970284, 0.06522576643952302, 0.04604803604472961, 0.01562291766250772, 0.07170981993632657, 0.038827049412897656, 0.04796441231987306, 0.0125706678289654, 0.04858363659254142, 0.02612434291014714, 0.03517426809828196, 0.042142368121338744, 0.05835585043366466, 0.009321380755864084, 0.024021932688940848, 0.04331556534660714, 0.05033860635012388, 0.031890104325222116, 0.098460024887962, 0.01307052931016577, 0.019074384422440614, 0.026262546922745447, 0.027734589629939625, 0.028248613833316734, 0.015832732564636638, 0.0369540993789477, 0.02209190428922219, 0.02341175837708371, 0.04616948702771749, 0.03347976938156145, 0.03742833768150636, 0.04193020039903266, 0.051332863712949414, 0.015437982943175095, 0.0029723968639570686, 0.04431971575000456, 0.060560247860848904, 0.015115161426365376, 0.04469620090510164, 0.0492042077572218, 0.02951898066593068, 0.019551723630034497, 0.018497448148471967, 0.013928267123576785, 0.035686680780989785, 0.015381488117522426, 0.01855071314743587, 0.055763887374528816, 0.024496966573808874, 0.06748437202934708, 0.04041278575147901, 0.019084784667938948, 0.033115714988006015, 0.04207882331684232, 0.037865324411541224, 0.02393568749539554, 0.06832020503601857, 0.012922882634614195, 0.06207538263073989, 0.05149151537833469, 0.055045345931180885, 0.01867033717488604, 0.04056656892810549, 0.05036477066044297, 0.011423575542201954, 0.03754904566864882, 0.10142886665250574, 0.14769587612577847, 0.14389602573854582, 0.11214481413896595, 0.1608118223292487, 0.0860676955697792, 0.1924743561872414, 0.09808993153274059, 0.10985648871532508, 0.16418689622410707, 0.11411650798150472, 0.1193760364715542, 0.15330095535942487, 0.1776198675589902, 0.19986327684351377, 0.09194072828228984, 0.12849455646106175, 0.13733001878218992, 0.09331215612058129, 0.10351445938327483, 0.14850414703999246, 0.21292659587093762, 0.1050813120922872, 0.1446793129933732, 0.19345574852611336, 0.16792619414627552, 0.16048109079045908, 0.09520226291247777, 0.2024639251508883, 0.2031479427324874, 0.047321242546396594, 0.20717469522995607, 0.08518816490790673, 0.218888326681086, 0.07201731165072747, 0.10811129664736134, 0.15729118910218987, 0.1008511958643794, 0.25221578191433636, 0.10912345376397882, 0.08500641251781157, 0.07189845267151083, 0.11149367836437055, 0.10171607016984906, 0.08965598552354745, 0.22746006958186626, 0.09257075483245508, 0.1333244230066027, 0.10226329509168863, 0.09611646671380315, 0.0878787733880537, 0.13619975586022648, 0.21096675603517465, 0.15868741061006272, 0.08958174022180693, 0.12129861116409302, 0.09383293174739395, 0.1391152444162539, 0.14410323676254067, 0.11459444090723991, 0.09730188096208231, 0.18319624476134777, 0.06958950656865324, 0.08749093634209462, 0.13251270513449395, 0.16310164731528076, 0.07824890262314252, 0.12941672626350606, 0.16908787323960237, 0.1448761560022831, 0.17018321874950612, 0.1878754086792469, 0.11672236743782248, 0.21669087745249271, 0.13888370112649032, 0.10040727111377887, 0.2126320166779416, 0.14446356599884375, 0.12516920561236994, 0.2355733806533473, 0.10500266988362585, 0.15546063732888016, 0.11614112077014786, 0.1691924761980772, 0.1312875694462231, 0.1430968064814806, 0.11509994949613299, 0.16132427911673272, 0.20991448392825468, 0.10384664298700434, 0.19560437037476472, 0.1394056166921343, 0.15817295892962388, 0.14150665966527803, 0.19377529780779565, 0.21473494597843715, 0.11552193042423044, 0.14457162948591368, 0.11457259207963943, 0.08169432702873435, 0.2575490400195122, 0.10525711373026882, 0.16368578454213484, 0.10760504166994776, 0.09789990101541791, 0.16829533076712064, 0.11716547794640064, 0.15792969055473804, 0.15220824256539345, 0.20013201742299966, 0.15197319803493364, 0.1927499771118164, 0.11679107589381081, 0.16921703916575226, 0.13234134790088448, 0.15265851840376854, 0.15235358476638794, 0.15693023561366967, 0.12942074319081648, 0.18386751945529664, 0.16512693863894257, 0.10299373803926365, 0.1962845338774579, 0.09038152944828783, 0.178233249645148, 0.1499431569661413, 0.1349156554788351, 0.1502247897109815, 0.17714083540652478, 0.12063224906367914, 0.1388103650616748, 0.14998772314616612, 0.16232513183993952, 0.10768770080591951, 0.12222599211548056, 0.11830796806940011, 0.1799341876591955, 0.1370518058538437, 0.10668729591582503, 0.148257580984916, 0.14323661183672293, 0.21997418627142906, 0.13479034363159112, 0.1570536068507603, 0.15429407278341906, 0.21880425619227545, 0.25454581688557354, 0.10799637317125287, 0.13298074501965726, 0.1478235221334866, 0.09706256166100502, 0.10252567779804979, 0.10993006905274731, 0.09488205545182739, 0.1070179460304124, 0.15007414136614117, 0.09354266803711653, 0.19466674354459557, 0.12082918706749167, 0.2455803065427712, 0.20377025433949061, 0.11176300926932267, 0.13210983175252164, 0.11379982211760112, 0.13060199123408112, 0.11043388808944396, 0.16926695220172405, 0.1287875207407134, 0.11081084821905408, 0.09016334651304142, 0.2216706866664546, 0.1428295179669346, 0.11785421813172953, 0.1829528542501586, 0.09221896156668663, 0.10870147283588137], [0.028998272892619883, 0.03850326268002391, 0.047377367570464096, 0.02497827012224921, 0.03532297922564404, 0.026587112274553095, 0.03849771904892155, 0.03263764635526708, 0.014359627950138279, 0.04755221586674452, 0.01277318932781262, 0.0398950499615499, 0.0220473686432732, 0.08028871459620339, 0.04773871460929513, 0.039528576590652974, 0.014837967996884669, 0.09292625968477555, 0.03608437694076981, 0.04809242134381618, 0.04867931003017085, 0.04533486859872937, 0.033745300490409136, 0.010386752829487835, 0.04137798824480601, 0.029701666041676487, 0.04478229342826775, 0.038187170534261634, 0.0433994729870132, 0.04549398845327752, 0.03318749720762883, 0.01953388494439423, 0.019859865041715757, 0.014345858778272356, 0.016714095271059444, 0.05381716362067631, 0.03167217584060771, 0.016483366223318235, 0.03851959841059787, 0.07448537421545812, 0.08209510373749904, 0.02759378173920725, 0.0555591665740524, 0.03895018994808197, 0.025589240016415715, 0.018030982464551926, 0.0373583366163075, 0.020426017697900534, 0.027655625117144415, 0.02817873829709632, 0.031501748199973784, 0.012537572283430823, 0.011424712088358189, 0.031225163755672317, 0.018455010872068148, 0.017965162871405482, 0.03617882562269058, 0.053287560253271034, 0.039948002834405215, 0.0781058267291103, 0.041916867185916216, 0.04979531014604228, 0.026423414004966617, 0.11618983958448682, 0.015295836642118437, 0.05156457663646766, 0.031187416852584908, 0.04404740607632058, 0.027104580043149844, 0.007417598090666745, 0.049599006572472196, 0.026924435781048875, 0.06285165383347444, 0.019715773041493127, 0.052396555564233234, 0.09077818744948932, 0.04426018448014345, 0.05176247137465647, 0.05917686423552888, 0.01559807819181255, 0.004643377981015614, 0.011110958343903934, 0.04454044658424599, 0.04716901660763791, 0.036469028264816315, 0.06730397670928921, 0.019907542304801087, 0.016561835405549834, 0.026069768338597248, 0.05847099104097911, 0.021263920236378908, 0.014761773603303092, 0.013629410615456956, 0.016502360114827752, 0.08461736089416913, 0.06920101812907628, 0.06361052061298064, 0.010688430346947695, 0.05807923884796245, 0.02821993046174092, 0.03185995362166848, 0.018433977982827594, 0.01054410170763731, 0.05623004771769047, 0.020337538427806327, 0.03464273429874863, 0.004007764543140573, 0.05069678123774273, 0.06602719093539886, 0.025816064095124602, 0.031205798366240094, 0.031672253872134855, 0.020538176143808023, 0.09581498003431729, 0.02056299356211509, 0.01777805175100054, 0.025950205379298756, 0.007968902704305947, 0.12034522875079087, 0.04220347359244313, 0.05540987869192447, 0.01400607982317784, 0.02293404597522957, 0.07486127583043915, 0.06424576509743929, 0.03689176915213466, 0.03902649460360408, 0.03441187632935388, 0.03967765073425003, 0.06796943635812827, 0.009836732343371426, 0.053347050811031034, 0.043422736560127566, 0.05524967996669667, 0.04458788975274988, 0.05978947279176541, 0.044293307167078765, 0.06281484330871276, 0.06255906953343324, 0.02701956808700093, 0.03044802402811391, 0.035756773448416164, 0.01828715657549245, 0.028239506197028925, 0.04024119442328811, 0.05353490662361894, 0.04741679045504757, 0.01914337447046169, 0.039954961211021454, 0.08539443276822567, 0.0796655412497265, 0.02141494007914194, 0.028393632033839822, 0.06796979598168816, 0.01179856198307659, 0.03727714990132621, 0.049126895477197, 0.027711817994713783, 0.028974805758999925, 0.04270986766953554, 0.04764968063682318, 0.06595705077052116, 0.031636783454035006, 0.030270488733159642, 0.011782672389277389, 0.05451778495418174, 0.07646864386541502, 0.02552021773798125, 0.06448609541569437, 0.023864629611905133, 0.04065608466044068, 0.05640050589240023, 0.0046872728354563666, 0.005030128098691681, 0.010407780629715748, 0.020357097199718868, 0.015006812954587596, 0.03049251896196178, 0.05077164061367512, 0.031183756156159297, 0.01846623553761414, 0.0338095272225993, 0.015942078482891833, 0.041640720396701775, 0.01660328371716397, 0.01879783729756517, 0.01716750594122069, 0.009914294833184352, 0.045854704454541206, 0.01735672730553363, 0.034492401472691975, 0.01678795211150178, 0.01706376132954444, 0.02225968903595848, 0.02069425446513508, 0.0144994333053806, 0.05570993026984589, 0.04703158951763596, 0.02599535170676453, 0.061221731294478686, 0.12208801880478859, 0.05553965190691607, 0.01231975999793836, 0.030633918874497925, 0.019740040846435086, 0.05531706867207374, 0.025917879971010343, 0.0363990543410182, 0.04313788077394877, 0.03018915613314935, 0.0315772487914988, 0.044086761107402186, 0.032219658605754375, 0.020331915068839277, 0.02627419906535319, 0.06593109680605785, 0.07487499580851623, 0.0033612718564524713, 0.04253905326394098, 0.04323564409943564, 0.028518419712781906, 0.026150831220937625, 0.019713869750765816, 0.05156452235366617, 0.030009683620716845, 0.011683038003476602, 0.07374708061771733, 0.04769457929900714, 0.016768649486558776, 0.031528862459318976, 0.009370398125611246, 0.04030851527516331, 0.06590255762317351, 0.01629500150946634, 0.03456702336136784, 0.09998987029705729, 0.006036229714352105, 0.03196392893525107, 0.04414758498647383, 0.03652584200192775, 0.031037335084485154, 0.03081030065992049, 0.0797963695866721, 0.00697239557380921, 0.010501997761561402, 0.06692185971353735, 0.05680266681260296, 0.01647486417953457, 0.08869798907211848, 0.04723474968756948, 0.01834099324020956, 0.05258745799905487, 0.052263864648661444, 0.07639642059803009, 0.009106000170244702, 0.07808447323207345, 0.01572841119819454, 0.020929455058649182, 0.04549782556880798, 0.059267597938222547, 0.015952499084440724, 0.016474591069189564, 0.01577392902358302, 0.018712706597787992, 0.04129230962800128, 0.02991600168336715, 0.01199107593856752, 0.03732732078060508, 0.0173784302481051, 0.0973618363163301, 0.03389473765024117, 0.028655789127307277, 0.08008295563714844, 0.039241305219807794, 0.061691684648394585, 0.02666200727357396, 0.03828183634738837, 0.01681940390595368, 0.04686497524380684, 0.04635837082085865, 0.026293815512742316, 0.034694391169718335, 0.0353197901110564, 0.028920105658471584, 0.024618928154398288, 0.01263462908432952, 0.013682931761390396, 0.013500118312159819, 0.03363343381455966, 0.06017793408994164, 0.013698953669518232, 0.048054508199649196, 0.007852949551306665, 0.01958782847837678, 0.03058222807677729, 0.02770160434634558, 0.038185633652444394, 0.06610905618539878, 0.024958078616431782, 0.09235175086983613, 0.06769888409014259, 0.01524278538168541, 0.03933139431423374, 0.015143692127561994, 0.012303917053421693, 0.05039357447198459, 0.0570784132661564, 0.05704956874251366, 0.041703203293894014, 0.061166769957968166, 0.021030577132478356, 0.011171392913508629, 0.05903355763959033, 0.028379075761352266, 0.015762587310746312, 0.03491222805210522, 0.03620317145915968, 0.013151956056909902, 0.06028966845146247, 0.027452369952308278, 0.02794657414779067, 0.015192767172785742, 0.01763954579031893, 0.05140686474208321, 0.04113251802378467, 0.014449521965746368, 0.044114499618964534, 0.04030407426346626, 0.024255333468317986, 0.04936711383717401, 0.005095187308532851, 0.007033825469469386, 0.04440032910289509, 0.08392292780003377, 0.0355779794710023, 0.011611342297068663, 0.03299165843054652, 0.1070285379620535, 0.021821251937321255, 0.01696609639163528, 0.08265992985772234, 0.019041941966861486, 0.048448448668101, 0.024658032127522996, 0.1034711484930345, 0.005966117963128324, 0.11172780687255518, 0.03749137019206371, 0.013700665274102772, 0.06121150577174766, 0.023258960772571818, 0.01307479220642043, 0.1251066175422498, 0.11748191953769752, 0.13306113784866674, 0.11638501339725085, 0.10123718050973755, 0.12312251329421997, 0.08243721430855137, 0.08557733188250236, 0.11427426737334047, 0.13898694701492786, 0.08064366983515875, 0.13654769504708902, 0.1405914787735258, 0.19205823780170508, 0.19895915607256548, 0.11617184483579227, 0.144837438794119, 0.18615657091140747, 0.06385973295462982, 0.0953382006181138, 0.15294164392564977, 0.1578735757086958, 0.17702828001763138, 0.08076035750231572, 0.21969836178634847, 0.1228945255279541, 0.10262772946485452, 0.1455033394907202, 0.10367346049419471, 0.1797092668712139, 0.08127225110573427, 0.0933309243991971, 0.09394737346363918, 0.12394510129732744, 0.08689166778432471, 0.11217378079891205, 0.08511466599468674, 0.11900531207876545, 0.09904450138232537, 0.19098736026457377, 0.2535231831882681, 0.09389050544372626, 0.12283851924751486, 0.09886176511645317, 0.060727493172245364, 0.06940496539963142, 0.10479658522776195, 0.06430709109242473, 0.09799632762691804, 0.11932381641651903, 0.176126629114151, 0.17036099492439202, 0.1571855411997863, 0.16090246103703976, 0.16620533434408052, 0.17244823649525642, 0.09061563081507172, 0.13292119678642067, 0.12801251161311353, 0.2733852059713432, 0.15038280694612435, 0.14694670561168874, 0.12121108014668737, 0.15475896426609584, 0.12514169780271395, 0.1921015961893967, 0.12988213343279703, 0.13876856730452605, 0.11465259135833808, 0.20678011354591164, 0.24657704734376498, 0.09733903753970351, 0.13760546328766005, 0.16211285894470556, 0.13795887146677288, 0.20312784452523502, 0.09532548487186432, 0.1797099318355322, 0.09349202218332461, 0.08772513270378113, 0.07215785660914012, 0.1289079471358231, 0.17493684510035173, 0.18191651414547647, 0.14682114949183805, 0.1579062132430928, 0.12762372461812838, 0.10087425248431307, 0.09597280049430472, 0.15794369551752294, 0.09618216925965888, 0.14845787095172064, 0.14766399855060236, 0.18331930387232984, 0.2444118692406586, 0.23321148167763436, 0.20262825276170457, 0.18353879638016224, 0.1777555745627199, 0.14659160109502928, 0.07627011130430869, 0.08398761254336153, 0.11666499051664557, 0.11865092680922576, 0.12617995137614862, 0.14969025339399064, 0.1370448712259531, 0.1227558601115431, 0.196433173758643, 0.08511649803923708, 0.1214809063822031, 0.16207988214279923, 0.10077625167156969, 0.20220720821193286, 0.053188450035772154, 0.10508787352591753, 0.11863905244639941, 0.07979207446000405, 0.1564472679580961, 0.16558235777275904, 0.1063621419348887, 0.1436675222856658, 0.08222944688584123, 0.20007079999361718, 0.19906536037368433, 0.125017770166908, 0.13210935677800859, 0.10620599067104713, 0.10442729932921273, 0.142576288697975, 0.12396870074527604, 0.18441483937203884, 0.08825918047555856, 0.19571510728980812, 0.15349800192884036, 0.15368120638387545, 0.11463494944785323, 0.08312587306967803, 0.11297279649547168, 0.11925166100263596, 0.08270917114402566, 0.12284051414046969, 0.22561049168663366, 0.08983789397669689, 0.08470915989684207, 0.10828821108277355, 0.09776571393013, 0.15945245884358883, 0.1400171531630414, 0.10905536956020764, 0.1830247246793338, 0.16976540402642318, 0.24916850828698703, 0.18720722810498305, 0.08733954160873379, 0.10134487758789744, 0.17002194454627378, 0.13060813876135008, 0.14419568037348135, 0.12609673584146158, 0.16392856437180722, 0.20310379724417413, 0.1495297391499792, 0.2029275952705315, 0.08207858819514513, 0.13545492797025613, 0.1355754765016692, 0.08004972777728524, 0.18213942646980286, 0.07009464196328606, 0.15389068371483258, 0.11587128096393176, 0.08654007129371166, 0.12417289907378809, 0.11281413465206112, 0.07070275183234896], [0.05793781179402556, 0.05912331425185714, 0.006173026190871107, 0.06382491053747279, 0.05718703315194164, 0.02397521385656936, 0.03341934583815081, 0.025684594542586377, 0.042870225850492716, 0.045497218279966285, 0.013830400321499577, 0.03579063913119691, 0.051560461321579557, 0.05005800497851201, 0.02669225466836776, 0.08619919565639325, 0.059848145714827945, 0.015191978375826563, 0.039969074739409347, 0.027483026164450815, 0.06023150442966393, 0.024422310758382082, 0.03772072520639215, 0.015869298816791604, 0.0178844528272748, 0.05979969831449645, 0.03233437512868217, 0.013080526675496782, 0.03603431801976902, 0.05613853369972535, 0.04567214460777385, 0.047620116866060665, 0.059022483948085985, 0.035457753243723085, 0.02602779246600611, 0.021387542531426464, 0.04490437884149807, 0.0023395158017852475, 0.034456201629447084, 0.018250946554222276, 0.022789875943479792, 0.03155230923688837, 0.015252542715253574, 0.0052074047021700865, 0.03560706826725176, 0.028239356919324825, 0.05612315809620278, 0.0357349687255919, 0.041797831787594726, 0.04585143052307623, 0.02063040601621781, 0.02204228302330843, 0.010362333202335452, 0.01150512442524944, 0.055465067337666235, 0.07298390514084271, 0.05862707445131881, 0.024612680543214083, 0.03326399185295616, 0.07888741764639105, 0.05766785663685628, 0.0398430877498218, 0.04976196014987571, 0.06782361239727054, 0.12784705763416632, 0.022012731126908745, 0.036441679910889695, 0.02276776757623468, 0.08722750869180475, 0.029675963135170083, 0.054694166739604304, 0.012311064571674381, 0.06977724363761288, 0.022421918277229582, 0.03935474609690053, 0.008400563782613193, 0.033734186086803675, 0.0660049756988883, 0.05693436706704753, 0.06871481386146375, 0.021244371642491648, 0.02702479450298207, 0.030420706208263124, 0.041877970165972195, 0.06643425766378641, 0.023665571186159338, 0.026227702453200306, 0.06146813450115068, 0.01469119917601347, 0.0689341706622924, 0.005775501785267676, 0.012290641515781837, 0.03442104673013091, 0.049776596150227954, 0.05283838364162615, 0.07301980642867939, 0.04288828845268913, 0.04958764789626002, 0.016203694444681917, 0.018949993686484437, 0.05905140311058078, 0.009050497702056808, 0.025923406638737236, 0.020611210260540247, 0.021352199338642613, 0.007356255132305835, 0.053285280375608375, 0.033040601161441634, 0.03511142557752984, 0.04510333887966616, 0.026704161261607493, 0.0826312888945852, 0.03585157836122172, 0.0855266046045082, 0.03132141734074269, 0.045400985050946474, 0.020753622886591723, 0.027780675728406225, 0.03485743295667427, 0.06756441880549703, 0.01711140975489148, 0.04787305436496224, 0.06252734123596124, 0.047366314235010316, 0.07134896822805915, 0.046228404223386727, 0.030594970964427506, 0.006712780442155365, 0.0518695916980505, 0.011220220293450569, 0.006969060574192554, 0.020382691540622284, 0.07357026796255793, 0.026572903751262596, 0.011185695583532964, 0.0254940873544131, 0.06648721053664174, 0.04848614128838692, 0.04467549201633249, 0.03676149721390434, 0.005591561543821756, 0.03850495901757053, 0.03855588646339519, 0.03308223946286099, 0.09609780700079032, 0.03129023187128561, 0.024513097047539692, 0.07071321484233652, 0.0902113053681595, 0.058317940682172775, 0.07805738611412899, 0.02294247338016118, 0.0442397232566561, 0.06750426667609385, 0.018523142573290637, 0.05393391574866005, 0.05371745289968593, 0.04665868702743735, 0.01090851572475263, 0.003235682870061802, 0.02277407286289547, 0.022961105951773267, 0.015968524385243654, 0.029785756886537586, 0.04484852183876293, 0.025946890735732656, 0.022683142385046397, 0.03710964335394757, 0.08775134451155152, 0.018018256540277174, 0.027089077214311277, 0.010100171868024128, 0.03058333069618259, 0.04449525275932891, 0.038435534707137516, 0.06495186899389539, 0.01934497570618987, 0.03828364125053797, 0.02795834164135158, 0.02990584062146289, 0.04801228975078889, 0.00932719325646758, 0.009561549073883464, 0.01725465019366571, 0.007788402211320187, 0.06695159990340471, 0.0203236454232995, 0.01675498209494565, 0.018326206265815666, 0.027508727374619672, 0.006491185748018324, 0.06023815407284668, 0.011474826140329242, 0.01907103754846113, 0.05082912610045501, 0.021384317793750336, 0.03494036689932857, 0.02091874777605491, 0.03278934642938631, 0.029478906387729303, 0.01217537622765771, 0.038288435100444725, 0.024168436881154776, 0.044980418868362904, 0.011828729650005698, 0.006362063926644623, 0.02480192735259022, 0.05680617144597428, 0.0872863716046725, 0.015562887669407895, 0.014905948724065508, 0.027123901327805858, 0.02308141190691718, 0.030901125964841673, 0.026843629045678035, 0.029186763135450225, 0.031640410223709683, 0.012125942407042851, 0.010945605297040726, 0.03705993727115648, 0.030777439208967344, 0.025656518459852253, 0.028542833402752876, 0.055719494220933745, 0.017485808414806212, 0.04417970683425665, 0.0037056845695977764, 0.03598298006025808, 0.025446430447378328, 0.033421825883643966, 0.04070105117612651, 0.06184334401041269, 0.05939893517643213, 0.017099944209413867, 0.03415917292503374, 0.03668791687648211, 0.03296038135886192, 0.007417903431425137, 0.03638841491192579, 0.03826368214296443, 0.012644695151331169, 0.027496118497635638, 0.06835118015961987, 0.03749379256208028, 0.052834054588207176, 0.07099252021206276, 0.028289278436984335, 0.029455768343593394, 0.07461745784218822, 0.046267952636948655, 0.013601227663457394, 0.017983851422156607, 0.014074463430526, 0.030903985989945273, 0.02346054674126208, 0.011170923876176988, 0.05292704102716275, 0.01473483576306275, 0.0465659855731896, 0.07404465215014559, 0.010436257048110877, 0.0067939353508076495, 0.04455500794574618, 0.016299875087237785, 0.03891750830890877, 0.033770684485456774, 0.016516526229679585, 0.013653479100737189, 0.024527605822575942, 0.08556971871959311, 0.014863072096237114, 0.054373426628964286, 0.01717390791912164, 0.013564465484315795, 0.021271292519356524, 0.02018586210241275, 0.024699444816048657, 0.021852473029866815, 0.017386911935838203, 0.013828005092883748, 0.032124955473201613, 0.031383014749735594, 0.021517463327784623, 0.012465432984754443, 0.03974243386515549, 0.015137159531669957, 0.037943915730076175, 0.10234938761485474, 0.08170088846236467, 0.05383576565821256, 0.03868412279656955, 0.062394735137266774, 0.013020151477706219, 0.06113023763256414, 0.043895020681832514, 0.07550468309117214, 0.020112412382981608, 0.04477643767105682, 0.07884047659380095, 0.0032698916371113485, 0.048802009517593045, 0.04962558478915265, 0.06344399454870395, 0.05776304152927228, 0.029905236725296293, 0.02637178427539766, 0.04032583148883922, 0.06063385533967188, 0.03505995191101517, 0.016632760974711606, 0.026890880528039167, 0.03474195647452559, 0.03613014073510255, 0.05883243307471275, 0.06214924116751977, 0.028020710883928195, 0.017446687478306036, 0.03888669264103685, 0.07818816016827311, 0.02588475219506238, 0.10664089090589966, 0.049702327099761794, 0.053557722363620996, 0.03990785391735179, 0.008193234014990074, 0.016399210917630365, 0.12216904945671558, 0.013312053850053676, 0.04741808984960828, 0.05986282242728131, 0.01885582659659641, 0.039434012557779036, 0.058739758761865754, 0.037479316017457416, 0.02399487610507224, 0.021732475808156387, 0.03749105467328003, 0.057350010478070805, 0.1028848806662219, 0.04198762481766088, 0.02255120125067021, 0.016106512962973545, 0.025224286563960568, 0.02706106050339128, 0.017684566588806253, 0.019280406313815286, 0.011372948348123049, 0.04987390485725232, 0.00956063559611461, 0.023637595187340463, 0.06284932645836047, 0.006776854928050722, 0.15824256305183682, 0.13743112049996853, 0.10368497523346118, 0.10435154089438063, 0.14273277244397573, 0.12953746478472436, 0.09478076374424355, 0.06515433027275971, 0.12456129251846246, 0.1278797494513648, 0.1382216273673943, 0.09329097904264927, 0.1441397690879447, 0.14652429042117937, 0.11281667237303086, 0.17557431517967156, 0.11400145558374268, 0.08526626428855316, 0.13964501741741384, 0.12031721882522106, 0.08801278405423675, 0.13698790142578737, 0.11963314696082047, 0.1606968513556889, 0.09580705474529948, 0.16618900879153184, 0.05943977619920458, 0.14718949901206152, 0.12184709816106729, 0.14617055654525757, 0.20693617660020078, 0.12209656834602356, 0.2210346550813743, 0.16643580554851464, 0.06892273734722819, 0.09747430349567107, 0.15061572087662561, 0.08440460623907191, 0.08003068129931178, 0.1672521646001509, 0.20830783514039858, 0.11822537678693022, 0.12545376962849072, 0.15273881623787539, 0.20018764372382844, 0.08362233000142233, 0.19052625500730105, 0.0992571474718196, 0.14705410413444042, 0.13236760720610619, 0.11379854647176606, 0.07546298032892601, 0.15557336913687841, 0.2004314006439277, 0.14013353548943996, 0.15293218514748982, 0.15894800876932486, 0.11229867873979466, 0.13233644887804985, 0.1331101416477135, 0.19871416421873228, 0.08918298554739781, 0.08935667015612125, 0.12403432865227972, 0.18165823657597813, 0.041423341525452476, 0.18364536709019116, 0.06915194647652761, 0.15747497709734098, 0.15271432112370217, 0.13525767784033502, 0.1130580340645143, 0.11756778135895729, 0.1033283711544105, 0.09270488084959132, 0.06740868823336703, 0.09767411848796265, 0.21794377879372664, 0.13701241011066095, 0.10579991460378681, 0.07623844407498837, 0.06347967191998448, 0.11625031062534877, 0.1673767707709755, 0.1632808077016047, 0.10431926976889372, 0.1311025329466377, 0.17883460809077534, 0.123184042849711, 0.16774434676127775, 0.10050242207944393, 0.08701379730233125, 0.11407427596194403, 0.14688362899635518, 0.11964503489434719, 0.33150477015546387, 0.19731871624078068, 0.12283329452787127, 0.10504477298153297, 0.1177965969379459, 0.11555010319820472, 0.11377242287354809, 0.12106508655207497, 0.10098415480128356, 0.12439484787838799, 0.10357729172600166, 0.18441654928028584, 0.1260136424430779, 0.12040493983243193, 0.11508361037288393, 0.1228008469832795, 0.14248297656221048, 0.31353759712406565, 0.202292174366968, 0.07795806215809924, 0.14385132385151728, 0.05334730526166303, 0.1591225822589227, 0.10760490596294403, 0.19259974945868763, 0.17977702537817614, 0.11985099741390773, 0.12898178531655244, 0.13124784800623143, 0.17621376658124582, 0.14436003512569837, 0.19169191031583718, 0.10971112615828003, 0.12751454833362783, 0.1834180714296443, 0.09447774357561554, 0.08075113621141229, 0.16542366200259753, 0.16664360011262552, 0.07942606588559491, 0.0992815000936389, 0.20252043354724134, 0.15830711887351104, 0.1288556863686868, 0.11180096651826586, 0.1290762916739498, 0.12251329741307668, 0.11655607207545213, 0.08742887752928905, 0.2315902986696788, 0.22308258233325823, 0.12268701594855104, 0.16759151353367738, 0.15686629047351225, 0.07955496039773736, 0.26570769080093926, 0.12381787598133087, 0.17121164713587078, 0.18440961465239525, 0.11266727253262486, 0.1341258678585291, 0.10514092817902565, 0.10337863702859197, 0.07238868743713413, 0.08765902303691421, 0.1283077829118286, 0.0914134658606989, 0.18528150500995771, 0.12669200104262146, 0.11720956915191241, 0.08106641750782728, 0.12399189307221345, 0.1867852878889867, 0.22348118094461306, 0.1747302311871733, 0.13895536799515995, 0.292823252933366, 0.10696946470332996, 0.10215440379189593, 0.10676591098308563, 0.11918749873127256], [0.03904428579179304, 0.020993904011057954, 0.01581294139448021, 0.03933164197951555, 0.0412343152399574, 0.016732073056378534, 0.029344410569007908, 0.03222305128084762, 0.03728133306971618, 0.04225866563085999, 0.04128448611923626, 0.015581203025898762, 0.0706715527921915, 0.006296394883455443, 0.044038602084453614, 0.004251265740354678, 0.015594868721174342, 0.03269757117543902, 0.042673694967691383, 0.08923278323241643, 0.06631881850106375, 0.04145874409005046, 0.03537972510925361, 0.035887259125177345, 0.008651631917538387, 0.023133789721344198, 0.01240482708505754, 0.056145481898316314, 0.016176890615107756, 0.037194358451025825, 0.013210576393508484, 0.011334729863197675, 0.016365626826882362, 0.03695736652506249, 0.009864699860502566, 0.014314858209607857, 0.04882124937804682, 0.05812669558716672, 0.04495179486860122, 0.02021977867531989, 0.006684137782680669, 0.048710247834346125, 0.0422274326639516, 0.00556363643512928, 0.016411572129332593, 0.057264779694378376, 0.05779793179993119, 0.08463051768818072, 0.02045993596714522, 0.016300377203151584, 0.0073869529047182626, 0.007863008832958127, 0.06019495853355952, 0.0062336011324077845, 0.00967795938985156, 0.06327795024429049, 0.01347440098678427, 0.023261698661372066, 0.014646466754909073, 0.019336717935012918, 0.020733114165653075, 0.08043098303356341, 0.012313947497334863, 0.06015645167125123, 0.03049320088965552, 0.012812427311603512, 0.01555945597855108, 0.038067466778946776, 0.04321559338963457, 0.018946339775409018, 0.049465542126979144, 0.03847703390887805, 0.03748723112844995, 0.05720099740262542, 0.03242272038811019, 0.06745535108659949, 0.049135658756962845, 0.03382146265357733, 0.004453720657953194, 0.06110891127692802, 0.04811636684462428, 0.08488378088389124, 0.03399727446958423, 0.005421409558039159, 0.024337146131853973, 0.041731342141117365, 0.005147280138252037, 0.030511874173368727, 0.016582618933171034, 0.03174067734341536, 0.04895352638725724, 0.05157929066834705, 0.015355439158156514, 0.09545379584389073, 0.0261983863477196, 0.05432815816519516, 0.02052047655784658, 0.04033829278445669, 0.02369697717949748, 0.024540206217872243, 0.03312094649299979, 0.007565680724967803, 0.015053811682654279, 0.03115189554435866, 0.01977294640216444, 0.00966394764171647, 0.03917934140190482, 0.022681856561186056, 0.056463246632899554, 0.04550621226163847, 0.017995532402502637, 0.05016342557168432, 0.01118595851585269, 0.03928015134962542, 0.011018817529215344, 0.02799725901734616, 0.01650284866004118, 0.041111259521650415, 0.06365857446300131, 0.008282077997656805, 0.04798535530322364, 0.015488284440445048, 0.02444965741597116, 0.032959713001868556, 0.03763753681310585, 0.036960531890924485, 0.04383606955941234, 0.08326135615685157, 0.008400054033180433, 0.0178186603755291, 0.028883620830518857, 0.024345588803823506, 0.0673072472480791, 0.04390279330047114, 0.042990211197840314, 0.06386256923100778, 0.0205794293766043, 0.014664707472547889, 0.03244119689666799, 0.048276019349162064, 0.00781321369244584, 0.016224966517516544, 0.03740529802494815, 0.10315018785851342, 0.024006311116474013, 0.039261620558266125, 0.042402891641748805, 0.010377964952827563, 0.042251412091510634, 0.02845649660698005, 0.066478742419609, 0.016539964525561248, 0.013808788981155624, 0.018235229986852834, 0.010613349598965474, 0.01750359281764499, 0.04535258514806628, 0.004207956970536283, 0.018284137094659463, 0.030175025641385998, 0.03949928762657302, 0.006993168075236359, 0.03316426416859031, 0.02445370827003249, 0.026838869122522216, 0.036546588210122924, 0.042768136864261966, 0.10087189118244819, 0.039210645614990165, 0.03273255644100053, 0.0628217507952026, 0.04026658181101084, 0.06618260259607009, 0.012483906948805919, 0.008526978249262487, 0.06198460143059492, 0.00957165754932378, 0.02964118482278926, 0.0623870405501553, 0.1106022936957223, 0.04258108850834625, 0.03383111820689269, 0.02502549615954714, 0.017305177303829362, 0.04348384203123195, 0.046268905978649855, 0.04040499956214002, 0.03818425622635654, 0.04745482573551791, 0.009921265932332193, 0.0520999746929322, 0.027331555095900382, 0.024131648408781205, 0.034384795996759615, 0.03885629766487649, 0.002440734990938966, 0.021239301289564798, 0.019025445084220598, 0.05000491300597787, 0.022649120639211366, 0.026080015913716385, 0.01383857921298061, 0.021491024210782986, 0.058963166416755745, 0.014835538841517908, 0.013215410107347583, 0.030487511373524154, 0.051290360279381275, 0.03647947431142841, 0.024523921377424682, 0.04857333303828325, 0.01784364233857819, 0.014177166490948625, 0.03628327930346131, 0.021041465923190117, 0.044042720792016814, 0.029290650239480392, 0.05216130068791764, 0.027058678845475827, 0.03911264480224677, 0.03259869844519666, 0.010478592544261898, 0.032687946156199486, 0.04815407982096076, 0.040580244801406345, 0.02191160905307957, 0.030138510279357433, 0.04473496561071702, 0.030868949834257364, 0.06762495769986085, 0.0593232445951019, 0.04244493706417935, 0.08955468024526324, 0.05443997734359332, 0.03449313768318721, 0.029965775619660105, 0.046466665009834936, 0.029895750805735588, 0.03919288156820195, 0.05450707767158747, 0.018000143047954355, 0.017079925730026195, 0.03674904948898724, 0.033716866480452676, 0.05701370816677809, 0.04914535162970424, 0.027611103041895797, 0.01669730831469808, 0.010700344573706388, 0.04985791517953787, 0.05405036932123559, 0.049278938211500645, 0.07900008160088744, 0.061000983496861796, 0.032855269499123096, 0.03326727256977132, 0.04891883289175374, 0.040906206239014864, 0.0232190086306738, 0.013517239447017866, 0.009789490190866803, 0.02820541150867939, 0.04144717167530741, 0.03208287612402013, 0.029890539656792368, 0.011867922680851604, 0.014023504602456731, 0.022217857352058803, 0.010998385991635067, 0.019074021406205635, 0.036176332006497045, 0.07500772404351405, 0.012854084272735884, 0.04109211465609925, 0.00526787489486326, 0.016826738869505267, 0.02414137520827353, 0.037612770284925184, 0.047913379701120515, 0.029540741283978735, 0.07109031067895037, 0.03793053162683334, 0.02748782340703266, 0.06224583741277456, 0.06501851470342704, 0.02676449659546571, 0.0158334297593683, 0.021426283488316194, 0.059096043929457664, 0.021924643710787808, 0.03873436492202537, 0.054494239789034636, 0.025739633910624043, 0.017424292430015545, 0.026500079980386154, 0.005866616739824946, 0.04996568011119962, 0.00801822795931782, 0.07849862386605569, 0.014577227345268642, 0.03001868099506412, 0.012074600206688046, 0.09976638800331525, 0.015885383489408662, 0.07079616574836628, 0.023015176711071814, 0.04922461809058275, 0.03408612523760114, 0.0293424563881542, 0.009569686405094606, 0.07486567952271019, 0.07369534910789557, 0.029566529007362466, 0.009341404324264398, 0.01746581368414419, 0.039570184357996495, 0.09844583672072206, 0.0681807321629354, 0.0171046973472195, 0.01422890817879566, 0.05182350899225899, 0.03494173414739115, 0.014356710249558091, 0.04413954095382776, 0.02305601943018181, 0.024451899974207793, 0.04373509676328727, 0.0229666377085128, 0.056908379175833294, 0.050587791550372324, 0.021754514625562087, 0.013416574536157506, 0.019842908451599733, 0.021329731347837617, 0.016209533238517385, 0.08271384625030415, 0.0428460360770779, 0.027497740196330205, 0.039977240908358774, 0.010001843662134238, 0.024367714134444083, 0.07475548543568168, 0.06762843179915633, 0.03740138287789055, 0.038218786873455556, 0.061220469219344, 0.02206036089254277, 0.03635555346097265, 0.06852519725050245, 0.02947990722688181, 0.02471361432357558, 0.03235321804615004, 0.060329769871064594, 0.08681876598192112, 0.09012236978326525, 0.19048726638512953, 0.16292262263596058, 0.12587634766740458, 0.10371373833290168, 0.10175794935120003, 0.1350882069340774, 0.12391454008008752, 0.13625986049217836, 0.11231486858533961, 0.15716181961553438, 0.15834095062954084, 0.1222740188241005, 0.12402419133910111, 0.06512390476252351, 0.18381069893283503, 0.10688546885337148, 0.10777366440743208, 0.06854423015777554, 0.1192941101534026, 0.1909535149378436, 0.07508613555026905, 0.08844394556113652, 0.12941196294767515, 0.15543258669120924, 0.15392589968230042, 0.15745692806584494, 0.1117253845025386, 0.10435325080262763, 0.11868361862642424, 0.10363978480121919, 0.11262364273092576, 0.10282637059156384, 0.11392484898013727, 0.20025344804993697, 0.2106877560062068, 0.12982398298169884, 0.12843320332467556, 0.0945877069607377, 0.1551924395774092, 0.14918635971844196, 0.10189136969191687, 0.0930638462305069, 0.13568391996834958, 0.15192001446017198, 0.2323980810386794, 0.09099854848214559, 0.04936719186870115, 0.0827474065923265, 0.1510073034358876, 0.16377541901809828, 0.10337920021265745, 0.14947111372436794, 0.13935505226254463, 0.1393243960504021, 0.07220828533172607, 0.22037274417068276, 0.23908444653664315, 0.11446489500147955, 0.15062117629817554, 0.11737728943782193, 0.11887016147375107, 0.1780589475695576, 0.08986608032137156, 0.16935117196823868, 0.07893371409071342, 0.13971188025815146, 0.1679640021175146, 0.11283431428351573, 0.0757338854351214, 0.09488262542124305, 0.12922422587871552, 0.1822689859462636, 0.1509024290634053, 0.16110484089170182, 0.14495012989001615, 0.2047289836087397, 0.14721562261027948, 0.10914629325270653, 0.14452189286904676, 0.09741934215916054, 0.12388331389852933, 0.14072373881936073, 0.1756802209253822, 0.13148636663598673, 0.12294135801494122, 0.10637955314346723, 0.06302278036517756, 0.07071413764996187, 0.11572424242539064, 0.08936779813042708, 0.14539561527115957, 0.2115323692560196, 0.1754778546414205, 0.12196748384407588, 0.09870794801307575, 0.1933923733553716, 0.1685329130185502, 0.10022741862173591, 0.10953358068530049, 0.16188977020127432, 0.1057121189577239, 0.14744749159685203, 0.17307882622948714, 0.11400624604097434, 0.1530734154262713, 0.2067028691193887, 0.1270271973418338, 0.09846528353435652, 0.1498434530305011, 0.1822111883333751, 0.10488180922610418, 0.20734394900500774, 0.1929431560316256, 0.13320535368153028, 0.08405100807015385, 0.3415761025888579, 0.10670520245496716, 0.11401096864470414, 0.09192907783601965, 0.10010053257324866, 0.11093963416559355, 0.15643348012651714, 0.1158801969140768, 0.20687865040131978, 0.17646046834332602, 0.12851352830018314, 0.05677984428725072, 0.09879490227571555, 0.13238385133445263, 0.20592577010393143, 0.08163734365786825, 0.23308011729802403, 0.2649119592138699, 0.11398612069232122, 0.05381765555856483, 0.09077489655464888, 0.1185797213443688, 0.15862613889787877, 0.15428776240774564, 0.09333501596535955, 0.18696147629192897, 0.1290592604449817, 0.15037029476038047, 0.14777426049113274, 0.14853412471711636, 0.1684179963277919, 0.11362851916679315, 0.17087061543549809, 0.08329148311167955, 0.12702662737241813, 0.10425644421151706, 0.1871077005884477, 0.09403590871287243, 0.09130184006478105, 0.0791941290455205, 0.16432945643152508, 0.20450579987040587, 0.13249362472976955, 0.10940658607121025, 0.12817458648766789, 0.11740117387047835, 0.12792917394212314, 0.10635361953505448, 0.07560387812554836, 0.2903786269681794, 0.14503432251513004, 0.16550425839211258, 0.15004282018968038, 0.10760290428463902, 0.1789705865085125, 0.11912957898208074, 0.09524011159581797, 0.19507299603096076], [0.048812842329165766, 0.011572871057848846, 0.010681284525032555, 0.027442884032747576, 0.011678121169097722, 0.03484832701672401, 0.046679311099329164, 0.06136154343507119, 0.06340326887688466, 0.060284708360476155, 0.07011037719036851, 0.00592409968209852, 0.04675182613677212, 0.02004162421716111, 0.06870787923357316, 0.05722682923078537, 0.012165816517413726, 0.057012954992907386, 0.05556339384721858, 0.029707253777555058, 0.013893584654267346, 0.026971632980608513, 0.016641456400975585, 0.05892909038811922, 0.017544747662863562, 0.015898772681664144, 0.04777590172099216, 0.04148871837449925, 0.034787777944334915, 0.044285354736660204, 0.010390312593829418, 0.07816867942788772, 0.0203142070011901, 0.015986546275338957, 0.04267683319215264, 0.03239267485748444, 0.06775956547686032, 0.038505776652268, 0.02895670583737748, 0.049044755420514514, 0.05617237563378044, 0.022110784526116083, 0.04745226087314742, 0.03249451278575829, 0.04503229287053857, 0.06543157968137946, 0.019423278647341898, 0.037593710236251354, 0.006583700605135943, 0.029310510959476233, 0.03694971265005214, 0.022202868513496857, 0.045510727912187576, 0.023712010122835636, 0.04632013197988272, 0.04566236352548003, 0.0493325255145984, 0.03652396245992609, 0.018243194291634218, 0.03902329870366624, 0.05107540717082364, 0.04532214267445462, 0.03798661593879972, 0.05286087368481925, 0.023107996908947825, 0.020608993147366812, 0.03736288619360753, 0.0340292673957135, 0.046113385752375634, 0.07501315232366323, 0.03056263198543872, 0.07502957287111453, 0.006890818701192204, 0.06247558258473873, 0.011067051191015967, 0.02194620416100536, 0.050278671351926665, 0.033073696706976206, 0.004730873799417168, 0.05463134118222764, 0.012197257285671574, 0.062275998294353485, 0.07059608612741743, 0.09294634432132755, 0.018666277839136974, 0.03333937030817781, 0.016231007175520062, 0.09307019053293125, 0.03816898918843695, 0.0337644962460867, 0.004981286299880594, 0.04516197448330266, 0.05035922024399042, 0.03247266056548272, 0.012911458649406475, 0.06987300528479473, 0.03648799331858754, 0.03404384232791407, 0.006576299484420035, 0.0063125533467557815, 0.014899733343294688, 0.03624803280191762, 0.04658746799188001, 0.03060135937162808, 0.02657905636754419, 0.010658093046263924, 0.07631851799253907, 0.026420813519507647, 0.02344933564641646, 0.020243534186322774, 0.016328399003084217, 0.04316210786678961, 0.06076938592429672, 0.09526893576341015, 0.03812106426006981, 0.012543699454649218, 0.03403853279139314, 0.006333960702509752, 0.03424602201474564, 0.03322848750810538, 0.014048705393049334, 0.0684388672400798, 0.04262226540595293, 0.017779251061646, 0.06622025450425488, 0.025848791535411562, 0.029097298293241432, 0.023801025435594574, 0.013807375931979289, 0.027397981977888515, 0.03952112288347312, 0.06261100460376058, 0.0375466945448092, 0.024918511543156843, 0.03749805376199739, 0.02829084076386477, 0.04341817001945206, 0.043804649995373826, 0.029860209141458784, 0.0355417355229812, 0.04266637696751526, 0.014178031623097402, 0.026417103629293184, 0.02449333810779665, 0.020593147658343827, 0.03085902625960963, 0.047593026355441125, 0.015942974149116447, 0.03742895514837333, 0.04755337616162641, 0.011932848304110979, 0.02377307657817645, 0.043727724480309656, 0.0368183482704418, 0.012480792473070323, 0.01703946807953928, 0.09429267993462936, 0.06703405547887087, 0.06091645160423858, 0.020278363388829997, 0.0158160847079541, 0.015748429677582214, 0.022073892577152168, 0.038064735675496716, 0.0321176340803504, 0.026872989255934954, 0.08311335409858397, 0.05933016565229211, 0.03976447946791138, 0.03350673097052744, 0.019379363860934973, 0.05218030645378998, 0.054386169516614506, 0.05495636284883533, 0.020327889659841145, 0.06271769745009285, 0.02172490505368582, 0.060567922091909816, 0.05831790675542184, 0.04434689447017653, 0.03339341562241316, 0.041742157989314625, 0.031175712123513222, 0.07768053455012185, 0.06404350737908057, 0.04230402908953173, 0.059048471839300225, 0.01916457699345691, 0.05576356167771986, 0.027314262630950128, 0.02014290913939476, 0.014115675951221159, 0.041831073218158314, 0.0353381614466863, 0.10538038318710667, 0.07180967993502106, 0.05575530729921801, 0.0639234541782311, 0.03342518123931118, 0.008367800719237753, 0.01996284969417112, 0.029874292135770832, 0.04916770596589361, 0.019384714109557014, 0.05533968763692038, 0.02767635096928903, 0.03462263948417135, 0.02837541506492666, 0.010435290983878076, 0.028096004522272518, 0.03446500901398914, 0.027711517742968032, 0.03248202434874006, 0.031565808691084385, 0.035340478643774986, 0.08470598435295479, 0.015065255175743784, 0.01255661282422287, 0.023187346490366117, 0.014391439368150063, 0.049489341742758236, 0.03276074617835028, 0.06496598930763346, 0.03103838342108897, 0.05255116994625755, 0.005138782759396625, 0.04933940925236259, 0.017427094779642563, 0.03502892928996256, 0.013861025999566274, 0.06513568413044725, 0.026419724470802715, 0.018393834154786806, 0.03061939143974866, 0.032734490265803676, 0.024499295645260384, 0.011783854736547385, 0.028834216695811068, 0.0896547030923622, 0.051940257727567635, 0.02954834426886269, 0.043500540778040886, 0.051768785143004994, 0.07012831765626158, 0.035980968203927786, 0.03824053052812815, 0.05079697711127145, 0.021860802047220722, 0.029677669650741985, 0.026050414823527848, 0.03560181301353233, 0.04658705069284354, 0.04038546793162823, 0.04632190974163158, 0.032967227777200084, 0.09684388339519501, 0.010626016999594867, 0.024120925859149014, 0.07294666713901929, 0.023235191690868566, 0.02405211392657033, 0.020069618875692998, 0.03507681689890368, 0.05029146173702819, 0.04941319654296551, 0.09006208873220853, 0.06658169653798852, 0.05073045693071825, 0.03845066943072847, 0.043826308833169084, 0.03511122880237443, 0.02519514348490962, 0.04011174351243036, 0.01688215821715338, 0.01239906293007412, 0.04232240721051182, 0.033083437077168903, 0.04565136108015265, 0.015605983124779803, 0.036827915614204745, 0.027523568631815057, 0.05131904873996973, 0.0501843210575836, 0.026013863838410804, 0.02704992065472262, 0.03928696723388774, 0.04410130211285182, 0.01763604624596025, 0.02517316912833069, 0.07166559980916125, 0.03223182134596365, 0.006700143151517425, 0.05479630661596145, 0.022195648900898438, 0.016848245036921332, 0.004039388091769069, 0.03308458040867533, 0.0812685734459332, 0.05977696739137173, 0.016239171648131948, 0.06402904779783317, 0.0374676757492125, 0.01396603523088353, 0.016796262469142675, 0.012823649432643183, 0.03902311549921121, 0.05058176615940673, 0.022621879154550176, 0.010373139720676201, 0.016421533023406352, 0.012237878632731736, 0.01041990180965513, 0.008366873670768524, 0.0931738910398313, 0.021958746880825077, 0.04590783713917647, 0.0656932159992201, 0.031156828493944237, 0.027757983821045076, 0.057311191489653926, 0.015200295518817646, 0.02560713468119502, 0.05274873220228723, 0.025686899865312234, 0.03860631857865623, 0.017130669971395816, 0.028244262727509652, 0.06980091093906335, 0.03480291606060096, 0.02755760055567537, 0.046697085324142656, 0.005975152232817241, 0.04266937609229769, 0.04562118662787335, 0.023327932160879885, 0.04594197762863977, 0.01744998855117176, 0.021682136991460408, 0.041430109912263494, 0.06523683334567718, 0.04072939358385546, 0.059529593879623074, 0.06552743632346392, 0.0658142530758466, 0.03130400273948908, 0.05537557874673179, 0.04711611462490899, 0.051823712552764585, 0.018185568008837954, 0.021063280824039663, 0.05980955742831741, 0.02204227793429579, 0.08073648664035968, 0.11391857931656496, 0.11538679338991642, 0.11067322774657182, 0.1216579225978681, 0.13062080022479805, 0.11187715243015971, 0.1699207614042929, 0.1430706421711615, 0.10488878456609589, 0.15667069596903666, 0.10550940662090268, 0.1297073292412928, 0.1605196858623198, 0.11588724010757037, 0.126713524173413, 0.13765894541782991, 0.12200364976056985, 0.2134006204349654, 0.1528831949191434, 0.11399882286787033, 0.17250383565468447, 0.09400150020207677, 0.1344919917838914, 0.08201882283070258, 0.14195963607302733, 0.1345672006053584, 0.12048445056591715, 0.10296743802194085, 0.15253034313874586, 0.09110556023993663, 0.14170846955052444, 0.11998033975916249, 0.12614835878568037, 0.1083368823996612, 0.15763862617313862, 0.10801117202000958, 0.17907939638410295, 0.12502116284200124, 0.23907304714832986, 0.13521072321704455, 0.08112978589321886, 0.18998907240373747, 0.10417593603155442, 0.18046203362090246, 0.09122725549553122, 0.11433547123202256, 0.15989759138652257, 0.09263436749045338, 0.10496335556464535, 0.17079296388796397, 0.08679487476391451, 0.09535761350499732, 0.06958667707762548, 0.12549784726330213, 0.14289982776556695, 0.13293389896196978, 0.1456113894070898, 0.0849655850657395, 0.16477186126368387, 0.12285787106624671, 0.11403960282249109, 0.21103668585419655, 0.16095189909849847, 0.12624370652650083, 0.10409700205283505, 0.12116458692720958, 0.17946252439703259, 0.12010058973516737, 0.29331038679395405, 0.10286324218447719, 0.12424027760113988, 0.13142263862703527, 0.19175128212996892, 0.09165809130562202, 0.14660925657621451, 0.1663540013666664, 0.12289223207959107, 0.19372021433498177, 0.15895461770040648, 0.0718151828540223, 0.1364167377884899, 0.13543499261140823, 0.14838240428694657, 0.09299472386815719, 0.08765639710639204, 0.1542021312883922, 0.20941612709845814, 0.17653156524258, 0.12116103140371186, 0.13756484618144377, 0.10831020240272794, 0.11924338287540845, 0.1300595160573721, 0.08912364766001701, 0.24584762219871792, 0.13075035970125878, 0.18370738519089563, 0.16857173879231724, 0.1465294879994222, 0.08733545004257134, 0.13002031030399458, 0.14961249328085355, 0.11873433233371802, 0.18496358421232018, 0.08415037273828473, 0.12636470289102622, 0.16284346474068506, 0.11749411959733282, 0.1282036006450653, 0.1505652243005378, 0.11829724721610546, 0.16503258155924933, 0.17764941097370215, 0.15285605351839746, 0.06757421685116631, 0.18201636735882076, 0.05882140688065972, 0.06515188754669257, 0.14397287661475794, 0.06294480990618467, 0.22768964512007578, 0.14981977215835027, 0.11066552637411015, 0.1448805257678032, 0.08839391038886138, 0.08758709832493748, 0.12908011861145496, 0.12529590167105198, 0.15379141404160432, 0.10398937282817704, 0.10345676355063915, 0.14158785316560948, 0.09525735995599202, 0.09348341157393796, 0.11223436040537697, 0.12242260442248412, 0.1387907825410366, 0.10185867787471839, 0.18285541662148067, 0.20189259866518633, 0.1621140938784395, 0.10160033923706838, 0.12873420145894798, 0.16315651365688869, 0.12578188202210835, 0.11022162197956017, 0.07934641944510595, 0.1455783447516816, 0.12621660583785602, 0.09593510787401881, 0.17242953607014247, 0.14794791117310524, 0.13949193991720676, 0.10543239968163626, 0.08230496104806662, 0.15195392764040402, 0.10672494782400982, 0.14252526286457265, 0.0657620940889631, 0.12710050626524858, 0.08274818690759794, 0.11059064324945211, 0.15807573843215192, 0.19320570837174142, 0.08851481854383435, 0.1591425176177706, 0.09750367049127817, 0.16419056031320775, 0.12380142829247884, 0.12299474515020847, 0.2111827473023108, 0.07911105600318738, 0.1443248191582305, 0.14887530569519314, 0.14286731236747333], [0.03338050310100828, 0.023663016501814127, 0.03956823017714279, 0.041749231716884036, 0.030284117109009197, 0.04736053990200162, 0.030555571828569685, 0.024311702764992203, 0.043132503383925984, 0.04063469384397779, 0.03122458021555628, 0.037112774793058634, 0.04295607070837702, 0.05652082032923188, 0.017889731829719882, 0.008228331238829663, 0.03526464557009084, 0.007206176756881177, 0.05578437573941691, 0.03386987612715789, 0.03928802574851683, 0.02024240612185427, 0.04895395047164389, 0.051605037679629664, 0.02808329216869814, 0.03107072918542794, 0.05213033574234162, 0.04310620336660317, 0.07375371669019971, 0.05317441453891141, 0.021013070928997228, 0.02406822913326323, 0.03822416426347835, 0.09768219984003476, 0.0278739895605083, 0.030960786156356335, 0.05864769513053553, 0.0257116918385561, 0.0976904643965619, 0.049212228041142225, 0.018444770082299198, 0.01709446673547583, 0.043121297378093004, 0.018915295101968304, 0.05945863268737282, 0.02963112893381289, 0.00908347959297576, 0.02694108703040651, 0.06841659772076777, 0.07510064941431795, 0.027787588303908706, 0.061482723004051616, 0.009425211032586438, 0.023103075833725076, 0.06732828861900739, 0.03070062565218125, 0.006268878592111702, 0.04471217701211572, 0.008857485023327172, 0.06947695796511003, 0.035301544304404936, 0.04683679568448237, 0.02153952419757843, 0.05810171192778008, 0.05192898726090789, 0.04718382563441992, 0.016549326612481048, 0.027492820817445005, 0.035470401136470694, 0.017503280691536408, 0.05324040206947497, 0.02025793948476868, 0.022030539278473173, 0.006990505673456937, 0.06794573512992688, 0.06337859055825643, 0.014311395984675204, 0.041097715962678194, 0.04382640722074679, 0.04921782595504608, 0.007391920629223543, 0.04467674730611699, 0.038100592858557186, 0.0706201469791787, 0.0707430432417563, 0.022407217816050564, 0.03552840570253985, 0.022341915605855838, 0.10661801070507083, 0.005598194223629045, 0.012340113503991492, 0.020559080111395036, 0.07833331916481256, 0.05438088372881923, 0.09051347058266401, 0.017552632239780257, 0.02432690025307238, 0.027783467900007963, 0.036390196066349745, 0.054427376948297024, 0.023493126600182483, 0.03793765285185405, 0.006344965692343456, 0.07580711293433394, 0.017518167749845555, 0.02230248084690954, 0.036010151995079856, 0.008857955756996359, 0.059627825394272804, 0.05716122167983225, 0.0797126315800207, 0.06612012309155293, 0.04792992238487516, 0.04955574996503336, 0.011573869352495032, 0.02053349425217935, 0.049400480796716044, 0.03684659907594323, 0.0697546959189432, 0.06378887354263238, 0.0300903817904847, 0.05135902802326849, 0.024621615153072134, 0.030483182320105176, 0.037742231373808215, 0.0115524861695511, 0.028663426038942168, 0.02074957712154303, 0.040525022228913646, 0.04828645861042397, 0.01170233214673187, 0.07004593671964747, 0.028686289276395525, 0.014439208233462912, 0.08024682184415204, 0.03236169294853296, 0.059549122117459774, 0.10813371544437748, 0.02440996651005532, 0.034351574922246594, 0.06224144729120391, 0.017642232788992778, 0.11049319883542401, 0.019203913364825503, 0.04555451716961605, 0.02374012691767088, 0.02728432396958981, 0.039670610933431556, 0.0748043196009738, 0.030694634187966585, 0.03457302500360778, 0.0876939200929233, 0.04973308848483222, 0.05806199727313859, 0.012889045789571745, 0.029414815362542868, 0.06343043741903134, 0.036284195325736485, 0.08456284060542073, 0.02636221862797226, 0.021039671198065792, 0.0105890376892473, 0.008017803874931164, 0.03290215287623661, 0.02278409312878336, 0.017132262832352092, 0.023768605032403554, 0.0199969240264701, 0.10939448100647756, 0.014812438116808022, 0.048992599826306105, 0.02155897270755044, 0.04162507337917175, 0.04697750349129949, 0.04284817346238664, 0.01618853597236531, 0.04372513247653842, 0.07963905802794866, 0.027784003942672695, 0.032495540766311545, 0.035866458634180684, 0.03261965160657253, 0.011614246426948478, 0.0284799671332751, 0.03018676090453352, 0.04451066228960242, 0.03858355372878058, 0.05440778085695846, 0.03408523974940181, 0.052542345598340034, 0.0781440350360104, 0.018637660624725477, 0.026147228199988604, 0.039731729975236316, 0.03705874304952366, 0.03177092304187162, 0.046973846187548976, 0.039866514171340635, 0.02779389189423195, 0.052509423079235215, 0.028771011158823967, 0.0337529984701957, 0.02001468637692077, 0.03383280775908913, 0.07292611431330442, 0.03177318595615881, 0.025390736293047667, 0.05579970384548817, 0.02055682398245803, 0.057656945793756416, 0.04113186323749168, 0.03128199106348412, 0.03710860858804413, 0.04316507985017129, 0.09076836226241929, 0.02589685047444488, 0.030972684267908335, 0.03695616891075458, 0.03519636119848915, 0.023180377935724597, 0.058944194577634335, 0.012480515970050223, 0.047903856462133784, 0.09934022051415273, 0.03524963637547834, 0.10889685699450118, 0.01249588733272893, 0.0377997202532632, 0.03106325851487262, 0.04428162957940783, 0.08113936680768218, 0.06989952243332352, 0.049230280465313365, 0.0274324532531734, 0.005215215488403503, 0.02409220177547208, 0.03338799073493906, 0.011404656289544488, 0.020613473174827437, 0.03957414360983031, 0.016392406907730868, 0.033582933845796754, 0.04390556850869741, 0.040635318096194945, 0.016219629839594876, 0.03601102391257882, 0.02835670276544988, 0.08006531372666359, 0.05013350896271212, 0.036431651163314066, 0.014880127073930842, 0.02811249122688813, 0.01845604563797159, 0.014769593719393015, 0.01930163937088634, 0.03976606384717992, 0.0038780193177184886, 0.04297903572608318, 0.03559893263237817, 0.0826609069481492, 0.04404028145862477, 0.021083764099915112, 0.03433804493397474, 0.04667096172592469, 0.07723987355296101, 0.04954837768205574, 0.011091163781072413, 0.031139597097145658, 0.019947178927915435, 0.04706947552040219, 0.07332827523350716, 0.012493285150932414, 0.04988653578662446, 0.051508488931826184, 0.037623942364007235, 0.04929600675989475, 0.031640135417027135, 0.035153993471924744, 0.07029721859310355, 0.14031040242740087, 0.03091288836938994, 0.008885488163546791, 0.01794248283840716, 0.07204443269542285, 0.012554531418053167, 0.013238473512631441, 0.026039807624848824, 0.06310037084456001, 0.04652810296309846, 0.028132246773956076, 0.04032631324870246, 0.05213335183049951, 0.05239813655082669, 0.013480289822577365, 0.06162798378084387, 0.046139282041362355, 0.05320114203329597, 0.020692318943994384, 0.0282275962111141, 0.03604701680264302, 0.022562283423862288, 0.04429597380970206, 0.057276151941290925, 0.035901369260890145, 0.0864823211782745, 0.03647482295387557, 0.032031025870570114, 0.02705426497517952, 0.059957640910787244, 0.03946079772764018, 0.07396476822240011, 0.03550666544054236, 0.04726961620950273, 0.026022014740322317, 0.022372894122132232, 0.021382373790921907, 0.06530771989907537, 0.06250701232680253, 0.027929519170096943, 0.026026861176693013, 0.08292335072266203, 0.02520206623843738, 0.1021019055375031, 0.023407302098348737, 0.03998020271371518, 0.028362432993682365, 0.04020265702690397, 0.07366410257028681, 0.02640018266226564, 0.09875328772302185, 0.04432207705186946, 0.06071476385529552, 0.024551732831501534, 0.027875097268926244, 0.02529243183588343, 0.032791938433157544, 0.019380510585116487, 0.018875027441286614, 0.06850391839231763, 0.009320490178652108, 0.0708442060276866, 0.02902589605322906, 0.042751075101218054, 0.02230539176213954, 0.03632858847933156, 0.025947440349097763, 0.0657906604132482, 0.023380952887237072, 0.02742869247283254, 0.023678370052948594, 0.005343887356242963, 0.050946288742125034, 0.10884928490434374, 0.18588609328227385, 0.09879152995667287, 0.08660878653505019, 0.1372513087200267, 0.13735384893204483, 0.10905068088322878, 0.11426750916455473, 0.1425260499651943, 0.13698459017489636, 0.1018452225252986, 0.1648980009236506, 0.11839501054159232, 0.1723582220396825, 0.11570717048432146, 0.10197411025209085, 0.1538546806467431, 0.1836968543274062, 0.14103277080825397, 0.09662717288093907, 0.10475575099033968, 0.12599336781672069, 0.14907537853079184, 0.12653886925961289, 0.114464474309768, 0.08115533273667097, 0.09297350607812405, 0.09100771549024753, 0.1953887997993401, 0.14524974381285055, 0.11930553668311664, 0.2194362437086446, 0.11966962500342301, 0.12299500299351555, 0.11031492732997451, 0.12184260625924383, 0.15887123931731495, 0.13258351704904012, 0.20703787542879581, 0.1462589018046856, 0.13867438664393766, 0.1897080231990133, 0.11411961567189012, 0.11339255182870797, 0.11142283930842366, 0.1157135758548975, 0.1636770042989935, 0.11222055900309767, 0.11756399513355323, 0.12064147713993277, 0.15701311188084738, 0.17057824826666287, 0.09688270238361188, 0.15378255237426075, 0.1953865470630782, 0.18335901174162114, 0.112049703885402, 0.16335240671677248, 0.09209027740039996, 0.16341264705572808, 0.193857359832951, 0.10765618963965348, 0.06415359968585627, 0.14617447847766535, 0.24131688103079796, 0.1088214378271784, 0.21047495385365828, 0.10630525355892521, 0.07213104090520314, 0.08329127955117396, 0.1568145996757916, 0.17637917984809193, 0.09252554404416255, 0.0961005347115653, 0.1712559690432889, 0.11909151316753455, 0.14162667893937655, 0.12727277273578302, 0.14305798070771353, 0.0975894033908844, 0.08486686500587634, 0.13686405521418366, 0.1368045476930482, 0.17875132470258645, 0.13094159801091465, 0.14237475022673607, 0.16909349150955677, 0.1283853801765612, 0.18599653164190905, 0.10913661055799041, 0.1052914611729128, 0.11579101027122565, 0.12283640221825667, 0.23689646965691022, 0.15869102041636193, 0.0999043206019061, 0.16210303375763552, 0.09206534123846463, 0.11291318040873323, 0.10282562420304332, 0.145163162744471, 0.09339841827750206, 0.13040423898824624, 0.2344679114009653, 0.13080205049897942, 0.11234285815485887, 0.05870691088161298, 0.17570349467652185, 0.1315934123205287, 0.09911692142486572, 0.21694532808448586, 0.19958817160555295, 0.16188094924603189, 0.15222007621611866, 0.16412335820496082, 0.093334086372384, 0.2166393223617758, 0.17836880737117358, 0.1792026183434895, 0.19151755395744527, 0.07456119371844189, 0.12602363047855242, 0.10705820351306881, 0.12424941068249089, 0.06331653853080102, 0.14156242167311056, 0.10231952528868403, 0.11907939453210149, 0.18481341084199293, 0.1606398815555232, 0.10053505282849073, 0.09678728678928954, 0.12473282617117677, 0.08255290452923093, 0.14372154724385056, 0.15110885298677854, 0.16676492217395986, 0.2503567316702434, 0.10334063228219748, 0.14713626115449838, 0.13938600703009538, 0.1602163128554821, 0.18061656318604946, 0.09689120442739554, 0.20717286318540573, 0.09757063511226859, 0.23782771825790405, 0.11490271293691226, 0.20636698071445736, 0.12677729289446557, 0.12426794825920037, 0.11553658678063325, 0.11741653590330056, 0.15598992178482668, 0.13301634096673556, 0.14521927759051323, 0.1532942107213395, 0.18267795257270336, 0.13703853370887892, 0.09557568787464074, 0.05720138416758605, 0.10987313317933253, 0.10659839425768171, 0.16714395183537686, 0.1611161452851125, 0.15727992542088032, 0.19427843152412347, 0.07553953264972993, 0.2501610421708652, 0.08291224310440676, 0.17320020257362298, 0.07800426360751901, 0.21022426230566843, 0.11482749054474489, 0.07125408189105135, 0.11388237268796988], [0.017608638520219495, 0.03783860370250685, 0.02481026654796941, 0.014249825717083045, 0.02782592722879989, 0.02055780785823507, 0.04778349452785083, 0.05012660486889737, 0.01920369962629463, 0.08962017923061337, 0.017094224159206663, 0.012812949783567871, 0.05641807994938322, 0.04838332287701113, 0.04870958626270294, 0.05443952611780592, 0.06880750174501113, 0.019241885880806615, 0.052087530360690186, 0.025234727521560023, 0.008505339767517788, 0.049116351043007205, 0.057833208835550716, 0.0579268466681242, 0.058617785306913514, 0.06981093290128879, 0.048839403582470756, 0.014497645365606462, 0.05378452269360423, 0.04423005073996527, 0.05635683537860002, 0.018789185976077403, 0.02945642652256148, 0.04237011500767299, 0.05294794329841222, 0.031131817693156854, 0.024336481167535697, 0.053592005345438204, 0.013179296777317566, 0.03344879765063524, 0.03157736074977687, 0.038024525690291605, 0.013058908549802644, 0.026082665592964207, 0.05642581185592072, 0.03916427453181573, 0.05638300308159419, 0.0018092050616230282, 0.028976702264377048, 0.02200868196918496, 0.02994491745318685, 0.03752011293545365, 0.010764861379617026, 0.017263511861009256, 0.05859983127032008, 0.07737931928464345, 0.03644240933603474, 0.07376134342380933, 0.056978587194212844, 0.05470020570127027, 0.049848395333226235, 0.07495801456804786, 0.02441268234646746, 0.02781704350906823, 0.038370151072740555, 0.03706215608066746, 0.022504148239802037, 0.01975676334196968, 0.0057422569620289975, 0.05064233898052147, 0.054397704611931524, 0.039628273740942986, 0.010855674810175384, 0.06134354190102645, 0.03841818117403558, 0.0454528319117214, 0.0319878065825573, 0.05133228695818356, 0.010471254188035215, 0.08536663997386183, 0.013250316493213177, 0.04195541136765054, 0.06193558406084776, 0.003759562794584781, 0.02876378476087536, 0.04366893620629396, 0.02273769999322082, 0.064524032308587, 0.043504859653434584, 0.09300335483359438, 0.05615824853469219, 0.043984261607485156, 0.0276668277303023, 0.015338915134114879, 0.04515766578593424, 0.004155902732496283, 0.0393257421175284, 0.02887203823775053, 0.028863685471670966, 0.034045145115149875, 0.028266662864812782, 0.06481458778892245, 0.036061710478471856, 0.037016843512122116, 0.01630724567387785, 0.021449662412383726, 0.02377929026260972, 0.04669533470379455, 0.01392523746471852, 0.034551539192242284, 0.049079068936407566, 0.03174475873155253, 0.047960354680461545, 0.04270646481641701, 0.01784929114260844, 0.049182911935661516, 0.0378101629072002, 0.03908861448456134, 0.008511910531004625, 0.045058223086276224, 0.034671938445951254, 0.001967158047981294, 0.03343025328857558, 0.027931958503488983, 0.014369907755670803, 0.013750425639695354, 0.035993310755917, 0.05117337744949119, 0.04980056539976171, 0.03604075053174581, 0.03725212213716336, 0.04093736795974629, 0.10155222431889602, 0.011982366941603166, 0.013087881995098931, 0.06458752283028193, 0.07293182079281126, 0.07137980764465672, 0.013330195331946015, 0.05473308750827398, 0.059474232207451544, 0.024235828979206935, 0.016641933071826185, 0.046786153223365545, 0.015143802389502525, 0.07561696706605808, 0.03985881619155407, 0.026239717612043023, 0.03672912770083972, 0.051142361613788774, 0.017655223341924802, 0.07246338057198695, 0.045870975724288394, 0.014963035571521946, 0.030606943714831556, 0.030909943527409008, 0.03205252864531108, 0.01932292671075889, 0.04739599674940109, 0.06966847447412354, 0.03376331559515425, 0.0205004360260708, 0.011002687055484524, 0.005042700080334076, 0.021483214272718345, 0.052486257893698554, 0.051292473915964365, 0.06860548151390893, 0.029070876139615263, 0.005956847902520427, 0.007118877289550645, 0.029592174238392284, 0.007161138995018388, 0.030581793814365352, 0.03295463755992906, 0.026802743918129375, 0.05077253967257483, 0.026443695416674018, 0.03814365608351571, 0.035182939775820286, 0.044429014170808453, 0.05341369991323777, 0.035728878873799524, 0.02942711380975587, 0.009589441103993781, 0.050060688584510765, 0.02500278389613543, 0.04192294007433312, 0.023564635709460293, 0.04354952761371221, 0.07556554089699473, 0.03131469305870788, 0.02797228723232235, 0.05735219536083085, 0.03496255160176328, 0.03422853277463998, 0.08165765899632658, 0.021400243010638014, 0.06980674634022371, 0.0575274813121983, 0.01927020284347236, 0.019482036387281756, 0.08037533637668405, 0.09866049805922167, 0.03550078593460577, 0.01115973653005702, 0.044351562791104825, 0.028014049366382614, 0.037450162760381184, 0.05306832219607063, 0.05804972257465124, 0.026898522528686693, 0.016878414400187985, 0.042645732539572885, 0.030986251575606208, 0.029492514407528297, 0.03979043682504978, 0.049840483614908795, 0.022942442846085345, 0.06664256112916128, 0.07284507687602725, 0.011908052938192018, 0.0336772434280387, 0.04631505314526813, 0.032511930779687, 0.003466261155803555, 0.039782443682530096, 0.009949128276535442, 0.062180664124233384, 0.033062266784587076, 0.07695416959800891, 0.05835778425846781, 0.06418298703751393, 0.03224024535822017, 0.07260582542845181, 0.06864443620932953, 0.020065210094409328, 0.051376116927713156, 0.049580224723156006, 0.04146894247138074, 0.09233209371034588, 0.06641579472592898, 0.028091672076178447, 0.00563840802559363, 0.015286598387839538, 0.06256036553531885, 0.10732848436704703, 0.07718587573617697, 0.0402950158209673, 0.03598925650918058, 0.05013475068179624, 0.04384268866851926, 0.05216536172000425, 0.07440181262791157, 0.0067695780640601045, 0.06985458984438862, 0.0373617496474513, 0.04872254288888403, 0.05135212392945375, 0.019449076548750912, 0.016692387239475335, 0.04813109105452895, 0.03925521518769009, 0.028855841606855392, 0.0380141882092825, 0.03445357569892492, 0.03581009612285665, 0.06134523145322289, 0.016491735952773263, 0.0229470331354865, 0.03666222414800099, 0.03272872271814516, 0.029210108132766824, 0.07309753940041576, 0.0635563667331423, 0.018760539923927615, 0.02653220182816897, 0.05579947992893202, 0.04107454738446644, 0.042632297546203644, 0.03634409300450768, 0.019453351319368397, 0.02213618209186409, 0.018895018779273545, 0.05226045161751764, 0.037432134084935696, 0.034242022050810714, 0.01704639252940459, 0.012639654484311385, 0.03520642387281571, 0.04516849181215678, 0.06773531463529382, 0.019289191645969237, 0.01674926883008863, 0.018814873615545884, 0.009194034151732922, 0.0849345556593367, 0.03211143227027995, 0.051918768523527045, 0.029640926979482174, 0.011768185666629245, 0.03298947015511138, 0.009918190472360169, 0.021855124405452182, 0.046593652838574987, 0.035129416933549304, 0.03795423964038491, 0.049774370555366786, 0.11730218918195792, 0.028441450092941523, 0.02319465600885451, 0.0691292155534029, 0.04147465912891286, 0.026353190719549145, 0.08870712893881968, 0.05385246779769659, 0.04558403683560235, 0.039838846905955246, 0.03818621379988534, 0.014424521342984267, 0.014453645762322205, 0.028275461767667105, 0.04452205489256552, 0.011355408217890986, 0.013397183701662081, 0.04105375028614487, 0.032788013108074665, 0.01180027867667377, 0.022271900969956602, 0.02832131546788982, 0.03541836428589054, 0.11875725324664797, 0.019208747926833372, 0.006235067192132452, 0.0354606064834765, 0.01164862185916198, 0.05725344137421676, 0.03042825830302068, 0.01831342775507697, 0.0502721302743469, 0.02962564297818712, 0.014192558209677892, 0.048755180423281023, 0.08424029219895601, 0.04679445170664361, 0.017492775273110186, 0.0315914064246629, 0.027073302971465246, 0.038822574474449666, 0.029651573193924766, 0.04717811576223799, 0.035020484921655486, 0.19580349326133728, 0.12465673525418554, 0.1111886700881379, 0.22434225545397826, 0.1290746767606054, 0.1682576449321849, 0.18468995818070003, 0.11244195819433246, 0.13442138342985085, 0.14539127264704022, 0.0736302233168057, 0.07835073715874127, 0.11311100050806999, 0.10109295789152384, 0.16332916010703358, 0.12027220481208392, 0.15500078057604177, 0.14451915158757142, 0.16282807556646212, 0.13384244378123963, 0.18575630310390676, 0.16155415321035044, 0.14655951995934757, 0.2346180576298918, 0.1692870096968753, 0.11408241838216782, 0.13119518011808395, 0.1193555040018899, 0.091576076777918, 0.08589563265975032, 0.14825986086257867, 0.09298552293330431, 0.08029506568397794, 0.13102228939533234, 0.17434858238058432, 0.15605720531727585, 0.0627416225948504, 0.12447657063603401, 0.1162702324134963, 0.13209079205989838, 0.15846198770616735, 0.09551356120833329, 0.08175715258611099, 0.10556360121284213, 0.14506539941898414, 0.09061710323606219, 0.1440445841955287, 0.10452445197318282, 0.0988213854974934, 0.06699770635792188, 0.16407269878046854, 0.1711922546050378, 0.08575024296130453, 0.08232401431139026, 0.11408296121018273, 0.1123689478263259, 0.1408065879451377, 0.19058292625205858, 0.20225645628358635, 0.2949206046760082, 0.11511447014553206, 0.1993095108440944, 0.16307152036045278, 0.16065030385340962, 0.15767059874321732, 0.16920622331755503, 0.09205691383353301, 0.16447872056492738, 0.09429681899824313, 0.1465545937951122, 0.20468649374587194, 0.1450321783444711, 0.09790503752550908, 0.11162255252046244, 0.11306403909942933, 0.1351849524570363, 0.12739720248750278, 0.14111091090100153, 0.06251885954822813, 0.15459089114197663, 0.08538406475314073, 0.11919906096799032, 0.19672218896448612, 0.1001150735786983, 0.08941599447280169, 0.23071753978729248, 0.229164291705404, 0.10798598480011735, 0.14923233725130558, 0.3621638592864786, 0.21298079724822724, 0.17114008883280413, 0.10182124309773956, 0.18334777520171233, 0.1613620463758707, 0.11435547444437232, 0.11855967741991792, 0.10697185314659562, 0.21556634136608668, 0.09800338439111199, 0.1853991358407906, 0.16239139756986073, 0.1408894777830158, 0.08902614217783723, 0.147611262808953, 0.1096552148727434, 0.09824782663158008, 0.11082965720977102, 0.1336448136717081, 0.18863639927336148, 0.17794992056276115, 0.1230528141771044, 0.12770383246243, 0.05110358673014811, 0.08898887024926287, 0.08174904409263815, 0.08528204022773675, 0.11143693248076098, 0.1474781206675938, 0.12166702853781836, 0.22612590688679898, 0.04013415891677141, 0.1310417226382664, 0.12280463320868355, 0.16401571540960244, 0.08620390468942267, 0.10826752255005495, 0.16598406407449925, 0.17242241145244666, 0.09371003548481635, 0.12971939359392437, 0.10401311476847955, 0.178084650476064, 0.10969875646489007, 0.09527034033089876, 0.16826938358800753, 0.1261083795023816, 0.10421658706452165, 0.14243315852114133, 0.20242280592875822, 0.19465872326067515, 0.10132485401949712, 0.08251847566238471, 0.08802709435778004, 0.16369144352419035, 0.18959337792226247, 0.20332558320036956, 0.11186851467937231, 0.11638882676405565, 0.1139268981558936, 0.14530588580029352, 0.10644091306520359, 0.18477287515997887, 0.06774582514273268, 0.13471356060888084, 0.20708663495523588, 0.07217105411525283, 0.06857480494571583, 0.14444154075213841, 0.11708204528050763, 0.23742271427597317, 0.07604395558259316, 0.12154079388294901, 0.1243651280445712, 0.13627773310456956, 0.14400597555296762, 0.15258591515677317, 0.19109475878732546, 0.17113130858966283, 0.09947446866759233, 0.20095252910895006, 0.09331647838865008, 0.10623840428888798, 0.11646232567727566, 0.16431376870189393, 0.11246448555695158], [0.05261722872299807, 0.0463718499190041, 0.06443365822945323, 0.012342023580068988, 0.0603606432144131, 0.019655944912561348, 0.10618722239243132, 0.046679931958871226, 0.020704159380069802, 0.025153018334614377, 0.01650365102770073, 0.07091912986444575, 0.05062442904870425, 0.04087265946769288, 0.037486369388976266, 0.0432006690118994, 0.052589374860482554, 0.06288727013660328, 0.04522989244599428, 0.017939159713153328, 0.010589187815120178, 0.03343622778941478, 0.028156592610425184, 0.021486500078546147, 0.07567603353943143, 0.08179820395473923, 0.06449228365506444, 0.03794040770402976, 0.0034813210285002632, 0.09631249548069068, 0.07825660399560418, 0.04253963341138192, 0.03778650578377502, 0.02840130796123828, 0.03325756612632956, 0.07490466135953154, 0.011250935877407236, 0.04016632826200553, 0.05401409823181374, 0.04052713925817183, 0.032871469522693327, 0.08148216269910336, 0.0475920356943139, 0.05863101673977716, 0.05053779369752322, 0.045147457226578674, 0.025870141639773334, 0.06173658331057855, 0.055417963436671665, 0.009297548909671605, 0.02905823503221784, 0.02127585736369448, 0.0300864666434271, 0.07143397509519543, 0.015897956743304218, 0.02385656861588359, 0.06950723419764213, 0.05653323752007314, 0.00328223842994443, 0.012015498110226222, 0.042230587851788313, 0.04142301582864352, 0.10439943189599685, 0.07823134892221008, 0.014428590856758612, 0.025410490143778067, 0.09328708425164223, 0.07529913447797298, 0.07523700781166553, 0.025503122048186402, 0.02831476421228477, 0.02596472772503538, 0.03810563776642084, 0.022194707433560064, 0.06048309164387839, 0.035459028889558146, 0.012369299839649881, 0.02552432966019426, 0.04255325500188129, 0.026933879292170917, 0.03879801489944969, 0.07101451831736735, 0.027884824068418572, 0.07014254653560263, 0.018891719402745366, 0.027735042552064573, 0.04957628243469766, 0.020734033580603342, 0.016742268045033728, 0.03161892441234418, 0.03750523944784488, 0.06148652958550623, 0.021210599258275967, 0.0017391381573231357, 0.08602425575788532, 0.029654562140681913, 0.04831133370420762, 0.021212874046925987, 0.01451907689417047, 0.033185173225189955, 0.04902706261990326, 0.04638634342700243, 0.030265504893447672, 0.02652392370094146, 0.059526805100696425, 0.016608528792858124, 0.04520373831370047, 0.042570564430207014, 0.012166813963891139, 0.04001214474971805, 0.0422795441533838, 0.03581322077661753, 0.03214721142181328, 0.01673609168002648, 0.018536351953766177, 0.031370183652532954, 0.001280629462728809, 0.06111968641302415, 0.011232178624985474, 0.06305794883519411, 0.07632595473634345, 0.04457803742427911, 0.014445070776024034, 0.03178901957081897, 0.030329365216727768, 0.050299135968089104, 0.02974798284204943, 0.015787321608513594, 0.05817371127860887, 0.0710004319303802, 0.0307765571134431, 0.048657132113086324, 0.04829810566401907, 0.05440839832382543, 0.010530839740697826, 0.05374695220962167, 0.013118831673637033, 0.08051739446818829, 0.025464484567887018, 0.002226155712768169, 0.08746282463627202, 0.006345261703245342, 0.051858358550816774, 0.03834335233217903, 0.021158313046076467, 0.03311543000329818, 0.013326549054389554, 0.0073851759911381775, 0.04699859914502927, 0.04968101092215095, 0.060895288097006936, 0.0379369743168354, 0.05968750933451312, 0.018948056469006196, 0.022203175550592796, 0.059815012849867344, 0.053459127832736285, 0.03416864527389407, 0.03238547560093658, 0.036447854579559395, 0.018473738438582847, 0.02818013947190983, 0.043817297888121436, 0.0454940495214292, 0.02233679945181523, 0.04610921276201095, 0.0041511063380832115, 0.04756789341835039, 0.015136886421324951, 0.009279448139880384, 0.0577696097482528, 0.04597949722249593, 0.03717400918581656, 0.04243640109364476, 0.08617566406194653, 0.0662362611453448, 0.012940191214771142, 0.02134207559616438, 0.010356005863286555, 0.03863470169848629, 0.025250510246093785, 0.007620114500501326, 0.16726513818970748, 0.017925906227901578, 0.047249426400022845, 0.023123145203239152, 0.050297975673207214, 0.06226199333156858, 0.01705105067230761, 0.03938886962298836, 0.0012050608056597412, 0.02987610043159553, 0.01935517069484506, 0.0229662594252399, 0.0328215802354472, 0.0488250254254256, 0.017306637850457003, 0.02644530015199312, 0.014874914228650076, 0.017601183116702095, 0.030900851158159118, 0.006546933761066092, 0.06257706428212778, 0.04071638606754797, 0.005345174876440848, 0.029952839349529574, 0.031763672895197353, 0.030419552698731422, 0.026180116792342494, 0.035288468934595585, 0.04304142023569771, 0.061689967954797406, 0.007387584790454379, 0.03854866006544658, 0.04805511888116598, 0.05268580825733287, 0.03379512870950358, 0.038233958916472535, 0.05169470268966896, 0.050410446245223284, 0.06557037401944399, 0.10653476802898304, 0.029609850075628077, 0.017631213380289928, 0.02499959647788533, 0.03690829147983875, 0.030272887354450564, 0.03597852887053575, 0.03289363726175257, 0.022523013209658008, 0.07034494674631528, 0.0714529130075659, 0.03896723474775042, 0.026633227210757986, 0.02672191513037043, 0.04184330041919436, 0.080738535816116, 0.027593026868999004, 0.008369085694929319, 0.050903466397098134, 0.03024404961615801, 0.033696673278297694, 0.06374599691480398, 0.061671966420752664, 0.04302165451060448, 0.0418714426590928, 0.0450087850248175, 0.030152535598192896, 0.05336842127144337, 0.028425915033689568, 0.09578370635530778, 0.047885410487651825, 0.0743644932018859, 0.008742240939422377, 0.02834834830303277, 0.07738115132919379, 0.014173897648496287, 0.0741809019818902, 0.031483797556055446, 0.03283499148009079, 0.01212004678589957, 0.030752072177295173, 0.02799898588896862, 0.02070985907422645, 0.03246750709201608, 0.041190376704824824, 0.012163635875497545, 0.016997010447084904, 0.04010607435234955, 0.02627618208394519, 0.052478400458182604, 0.07842511138213532, 0.09422577638179064, 0.03496011226837124, 0.035946715756186416, 0.017552199673705866, 0.013581904682463833, 0.04732868268287607, 0.0235906880615013, 0.016496804609362568, 0.008038823193471347, 0.025819526320057254, 0.07554611443941082, 0.014951454675091165, 0.01641419466717967, 0.012418664958594101, 0.03469578216650656, 0.0907000337860414, 0.09138835327965872, 0.05253090210525053, 0.03803309219490204, 0.0376732616818377, 0.02214458574807005, 0.05437670734577945, 0.04099081277049013, 0.046470590334917815, 0.09363041618572814, 0.07331367315990583, 0.03701609033825142, 0.1291427066815751, 0.07316934876143932, 0.024835674291742698, 0.047377574523644786, 0.05868223934833493, 0.04480589966156653, 0.03526093398353883, 0.06546015279101473, 0.060866009310952256, 0.01845820337933089, 0.04250428852226053, 0.017146545994494642, 0.0936399767441409, 0.029841478182268993, 0.01903327877101089, 0.02856517756091697, 0.0200046304879444, 0.030964199187500135, 0.010327872953244617, 0.017331731771784167, 0.04196596258719053, 0.015379929183317083, 0.04021219044391598, 0.02151916136166879, 0.018099707883915732, 0.017168389733082483, 0.01611586317553052, 0.04052803831707154, 0.012879362246686859, 0.05078492972201534, 0.037999928795865605, 0.03154805821499654, 0.045264029542782476, 0.043974887646202526, 0.05798999113695962, 0.02054110571875104, 0.03458095368530069, 0.021937973531229154, 0.01953523692541889, 0.03000602631696633, 0.010459734359756112, 0.01417438789004726, 0.04827027555022921, 0.011337094557737666, 0.029463873444391147, 0.005984538916631469, 0.03115762577259115, 0.034267860664320846, 0.06645996057029281, 0.03400725232703345, 0.0233114064405007, 0.0678755406822477, 0.03747060702049306, 0.15759943399046147, 0.09534784938607897, 0.11283775445606027, 0.12740424568099634, 0.1489762988473688, 0.17036258269633564, 0.18919583782553673, 0.08327623642981052, 0.14863103308847972, 0.09508543275296688, 0.11539512579994542, 0.18923564068973064, 0.10367760634315865, 0.13895511015185288, 0.1009287592023611, 0.1634701732546091, 0.10648439358919859, 0.1478404447968517, 0.09559236626539912, 0.07278107745306832, 0.07419236922370535, 0.11097324200506721, 0.10811636530395065, 0.1007761973887682, 0.16165449496890816, 0.1939835130636181, 0.15042034350335598, 0.12119410320052079, 0.08432686648198537, 0.1611733322164842, 0.15289839410356112, 0.2017502420182739, 0.13688808892454418, 0.12265071432505335, 0.1264524646103382, 0.1442315477345671, 0.09542832363929067, 0.09872040591601815, 0.12249755540064403, 0.12123518171054976, 0.10718529990741185, 0.11107986021254744, 0.11188004298933915, 0.16723615117371082, 0.09593366937977926, 0.22128279533769402, 0.10016849464071648, 0.18078159647328512, 0.10673261526972055, 0.10407148913613387, 0.08785414935222693, 0.09738631785980292, 0.14241827146283217, 0.21656133154673235, 0.1798266941415412, 0.11314894418631281, 0.12460839641945702, 0.13978470063635282, 0.06470870239926235, 0.13745591416954994, 0.1912932302802801, 0.1502931181873594, 0.16871181556156703, 0.16144838317164353, 0.1396226529031992, 0.134595712646842, 0.1498041929943221, 0.20664294090654167, 0.13509379806263105, 0.18480300211480685, 0.1339297169553382, 0.1357708538749388, 0.11080173549375363, 0.07633087411522865, 0.1283455773123673, 0.09944759189550366, 0.21820934382932528, 0.1171453118856464, 0.17547390556761197, 0.10782661049493722, 0.11639319652957575, 0.15928961043911322, 0.1044325308342065, 0.1401471604726144, 0.10149436563785587, 0.06772258531834398, 0.17671885447842733, 0.09001478127070836, 0.16808501205274037, 0.1653131286480597, 0.09968479416732277, 0.12230581497507435, 0.1016865267551371, 0.12769194452890328, 0.15159298772258417, 0.09281331753092152, 0.29297174353684696, 0.09213843303067343, 0.09214314884905304, 0.09559147738452468, 0.10425104985811881, 0.12611146005136625, 0.1505309311406953, 0.12315595149993896, 0.23177160322666168, 0.07649961898901633, 0.0950228718242475, 0.11446273726012025, 0.12939209544232913, 0.10639871497239385, 0.13789845470871243, 0.17041440920106002, 0.27316753193736076, 0.10884765642029898, 0.1486904320440122, 0.10565972926893405, 0.10056273705725159, 0.1334527339786291, 0.09960253536701202, 0.2126058523676225, 0.18871341299797806, 0.20890008764607565, 0.18045081065169402, 0.2516195939055511, 0.153037018807871, 0.09493829921952315, 0.1724135633558035, 0.14956032750861986, 0.17845867254904338, 0.25443730556539124, 0.15378124958702497, 0.1836586528058563, 0.11337733907358986, 0.16873491289360182, 0.1307421765689339, 0.17780442908406258, 0.06263084496770586, 0.15757941720741137, 0.10491592596684184, 0.0978064803140504, 0.17522303760051727, 0.10556566395929881, 0.12434507054941994, 0.070383141482515, 0.07797306456736156, 0.06596536282449961, 0.056401326919772794, 0.06598456536552735, 0.1398565439241273, 0.11598573625087738, 0.10495910115007843, 0.15400037568594727, 0.22268369873719557, 0.15944176513169492, 0.06866377445736102, 0.18325317384941237, 0.12772421565439018, 0.14947153441607952, 0.09926540524299655, 0.08931586306009974, 0.07098520560456173, 0.13212621158787183, 0.14890708827546664, 0.12913277292890207, 0.13120393321982451, 0.15687744558921882, 0.07126371708831616, 0.1448247501892703, 0.11116839546178069, 0.07333966105112008, 0.10191945425633873, 0.1474118006548711, 0.13277874514460564, 0.14566796565694468, 0.18959226512483188, 0.1732957810163498], [0.04164580940934164, 0.014648846716486981, 0.02312626307164984, 0.009185575364556695, 0.010302818895849799, 0.07851832173764706, 0.020749946923128197, 0.02804068016952702, 0.01612499795321907, 0.009617981135046907, 0.020935431255825927, 0.051366854924708605, 0.019021758942731788, 0.03767067985609174, 0.04624427855014801, 0.0256840059134577, 0.019391687753211175, 0.041140948821391375, 0.045530011877417564, 0.07125484185027224, 0.028307159531063268, 0.026170412045238272, 0.07413105679942028, 0.008709170838951, 0.053724815004638264, 0.04502949730626174, 0.024276234043229903, 0.054560162858771424, 0.05369877961597272, 0.026809705687420707, 0.09226304598684822, 0.027728998501385962, 0.015069726721516677, 0.046375110279768705, 0.04184962775824325, 0.07514744797455412, 0.03147149571616735, 0.03271848362471376, 0.07414114661514759, 0.0557097742067916, 0.03994722251913377, 0.026758264251319424, 0.05909210164099932, 0.05104780097358993, 0.06618596134441239, 0.033743034183446846, 0.0075954158258225235, 0.014017667504958808, 0.0340208332054317, 0.0028388940388270256, 0.02518089594585555, 0.01936938939616084, 0.010062529289695834, 0.021667534917859093, 0.02162668202072382, 0.032428060458706956, 0.03537774717967425, 0.022118000746039406, 0.05776816446866308, 0.018811932166240046, 0.05129068597619023, 0.05091715584109936, 0.07804023953420774, 0.0360221315308341, 0.017517153339992677, 0.06298504703279052, 0.0512507372269673, 0.025027613188805323, 0.028209691368309513, 0.027136930896501456, 0.026412720293072716, 0.003402818343602121, 0.0408137117379478, 0.017774872814438174, 0.02985140514959182, 0.047808539255389144, 0.03280724957585335, 0.027892170906332985, 0.02111722605435976, 0.02533226862682828, 0.07385506946593523, 0.046271671008850844, 0.02382577839307487, 0.019953384130660976, 0.010951104823366871, 0.07135343298848186, 0.007675746738511536, 0.025232490052336028, 0.009610987983510962, 0.021778695917289172, 0.03968879906460643, 0.02617228140921465, 0.030746755855424062, 0.032311640812882354, 0.021255957627935067, 0.03047396781455193, 0.042297817101436, 0.07023000969950642, 0.02825358579866588, 0.0606735089261617, 0.010623553917477173, 0.006927228890292878, 0.029466811501021897, 0.009220301090473575, 0.04178064110289727, 0.0656638965010643, 0.04680814115064485, 0.05229753016361168, 0.06184079271874257, 0.03700074526880469, 0.013709750009833701, 0.059153475133436065, 0.10611419845372438, 0.1093094130711896, 0.04510776632066284, 0.04464469670451113, 0.004131181581344987, 0.03840007107438786, 0.04795337255511965, 0.06241770354764802, 0.004996781919284591, 0.028239116039393202, 0.04422112800447004, 0.05354086076840758, 0.005160951770709029, 0.03220692589612944, 0.027491755517465726, 0.07436534137065921, 0.06556870482329812, 0.050968212208577564, 0.018592670360313993, 0.04077085207349487, 0.02657527183847768, 0.013737781987791615, 0.004505376256669739, 0.03614379625235285, 0.03045183400224362, 0.007954257374097193, 0.030132854689977, 0.022813682344609072, 0.052970857425991974, 0.03193644826699581, 0.049582562276295254, 0.06351978691028697, 0.026213200463514243, 0.02815556462987193, 0.057232148945331573, 0.0036626264336518943, 0.03890280445505466, 0.042264996362583976, 0.031072072684764862, 0.02955219495509352, 0.06157815216907433, 0.04274600983730384, 0.06432336914752211, 0.010007571345860404, 0.02358886449863868, 0.11369766188519341, 0.049879994709044695, 0.08507685802344765, 0.05444927327334881, 0.006942386090356324, 0.010818964369328958, 0.03752362435417516, 0.039087532221206596, 0.013952888614897217, 0.033085123236690245, 0.03308154735714197, 0.09483121282288007, 0.06012985309852021, 0.04512305371463299, 0.03744452752705131, 0.036696045726005516, 0.07556662655302457, 0.027715734838108932, 0.03571821230330637, 0.043838885479739735, 0.028879040719142983, 0.01642623696742313, 0.041132667301488776, 0.016008929449266622, 0.05456871579268149, 0.027744699801717485, 0.010907044151930936, 0.03610013930925301, 0.04153079093833055, 0.04295081206198249, 0.041703749514584026, 0.020886352817927088, 0.032437431027314494, 0.06358420023960726, 0.00953411081406687, 0.04290007799863815, 0.02547808240966073, 0.05382640187495521, 0.04522115970030427, 0.021652513848883764, 0.027078503942383186, 0.01755750072853906, 0.04948597960174084, 0.10442332989935364, 0.024752550359283174, 0.010667401698551007, 0.04393696432401027, 0.0488490693138114, 0.03368841211444565, 0.02073218796535262, 0.029285422127161707, 0.03969250386580825, 0.04055097958605204, 0.01771276650418128, 0.04538924300244876, 0.03777057717421225, 0.006560917095547276, 0.05961363044168268, 0.0492584260978869, 0.05504499987832137, 0.021464125386306217, 0.026753078547439406, 0.036484858486801386, 0.008453632006421685, 0.027290060983172486, 0.041174997708627155, 0.021880769636482, 0.09500346572271415, 0.02132436922485275, 0.01598815101065806, 0.025181172448875647, 0.029199560305901935, 0.036734956316649914, 0.07461283701871123, 0.00485564281864624, 0.02030817821754941, 0.012398234269182597, 0.015378176866631423, 0.015819119455825006, 0.03960656740569642, 0.017514301796576807, 0.0072761218429410034, 0.05606724681066615, 0.005708301373358283, 0.0291359713966293, 0.013404108151527388, 0.03770874906331301, 0.025126604662675942, 0.05362839178581323, 0.07648475907210793, 0.039776662564171214, 0.028613784416977848, 0.07933691316949469, 0.048079237408403835, 0.05034836707636714, 0.027750662428193858, 0.03490302372457726, 0.06034104033772435, 0.01215698623231479, 0.02558080921880901, 0.05024912793721471, 0.003108407088023211, 0.05157958922375526, 0.0329843913204968, 0.01775789926094668, 0.03011361143684813, 0.04134401738909738, 0.04541483395067709, 0.07940210002873625, 0.0352514616346785, 0.03497738437727094, 0.021974266673039113, 0.03303039938743625, 0.032433051083769114, 0.04542021134069987, 0.05890742476497378, 0.04374563101945179, 0.0333849101859544, 0.03208227562052863, 0.04095134578113045, 0.036729477146374326, 0.01697864250413009, 0.009061697770708373, 0.05552996242684977, 0.009514930325427225, 0.02922104611726744, 0.02779838040338031, 0.03627042785020811, 0.04156820875193391, 0.028220178127022724, 0.047548762123499594, 0.10251414270273276, 0.048486205749213696, 0.028638238819049935, 0.02493161744704204, 0.07012639061680861, 0.0795819525207792, 0.043929690428610356, 0.01733454260309892, 0.04723138754655208, 0.026203504198097756, 0.040348664192216735, 0.031206945090421608, 0.02826093602925539, 0.033281742329044, 0.02766306694996144, 0.026123642322740386, 0.03268108955983605, 0.07272594648280314, 0.03553133697382041, 0.02895968799878444, 0.015287697614569749, 0.021544307869459902, 0.01716667812849794, 0.06785724059279476, 0.021589891852012703, 0.02308809886952596, 0.018219213167737638, 0.06491222897810595, 0.05002257187983819, 0.036156953046364446, 0.01915644305492086, 0.02080727804319135, 0.014066013973206282, 0.046366479314331493, 0.04256673749270184, 0.03441689070314169, 0.010906689617383693, 0.031798362998025756, 0.060742434513356, 0.0853319668344089, 0.036044631752052476, 0.0637856505012938, 0.06383139054690089, 0.01827502776203411, 0.010572157434320875, 0.09741954571966614, 0.011801959747182471, 0.06988021132669278, 0.03587364771270326, 0.05467895059181111, 0.06250868830829859, 0.06297206665788378, 0.06736746723098413, 0.012930570436375481, 0.029519024770706892, 0.04795836318018181, 0.035779724895421944, 0.04439146743555154, 0.06833712091403348, 0.017388352126415287, 0.047510658989527395, 0.054547969584486315, 0.029440022938485657, 0.022919314979974712, 0.18536985026938574, 0.11659423288490091, 0.1384540663233825, 0.08683190241988216, 0.142976420798472, 0.12330626057726995, 0.11813880928925105, 0.12206251945878778, 0.12379914841481618, 0.12469993079347269, 0.12569950787084444, 0.14930935097592218, 0.08568420114793948, 0.09472158191991703, 0.16729667649737426, 0.13229619818074362, 0.1303867463554655, 0.06868450370218072, 0.18708027420299395, 0.16874594587300504, 0.10257270027484212, 0.08428982525531735, 0.17493654654494353, 0.15352618827351502, 0.16325875531349862, 0.12199507307793413, 0.0973195635846683, 0.15844712778925896, 0.11460164694913796, 0.09409122288759265, 0.14677530766597816, 0.05571253245164241, 0.10619606370372431, 0.10662411752023868, 0.18932701221534184, 0.13607806738998207, 0.09596089220472745, 0.0707149315359337, 0.14288711201931747, 0.1277794891170093, 0.08698360927935157, 0.07430229189672641, 0.1851285903581551, 0.11650223710707255, 0.17423119582235813, 0.10228130341108356, 0.15151226919676575, 0.1541160387652261, 0.317062396556139, 0.10449121732796941, 0.047545796925468106, 0.10226415683116231, 0.09561163665992872, 0.2027160959052188, 0.11382566751646143, 0.09136524237692356, 0.0804576969572476, 0.07807828499270336, 0.15282311742859228, 0.11109191777982882, 0.12445029776011195, 0.1890769584902695, 0.14767421728798322, 0.20434342644044332, 0.0770907179851617, 0.11414385294275624, 0.1209812331944704, 0.12598001424755367, 0.11366792848067624, 0.15406248878155435, 0.1148977732019765, 0.0736071802675724, 0.18757139784949167, 0.13451876677572727, 0.06976410041430167, 0.200770125325237, 0.14300263939159258, 0.08952424794967685, 0.2138929518737963, 0.1393421193850892, 0.23206530032413347, 0.14672873302229814, 0.05707611981779337, 0.12474524336201803, 0.0762118183608566, 0.19758590976042406, 0.12771941162645817, 0.10736923039491687, 0.10701542188014303, 0.140260231548122, 0.19745865730302675, 0.27167670907718794, 0.10797410365194082, 0.09178894678396837, 0.14345040465039866, 0.16192915237375669, 0.1748364490589925, 0.09054986720106431, 0.1381314229220152, 0.16383852277483257, 0.1057257167994976, 0.11045081075280905, 0.11370835559708731, 0.160731348076037, 0.16379109317702906, 0.16116316776190484, 0.154617611851011, 0.0683772766164371, 0.13876669454787458, 0.12232846447399684, 0.12677299098244735, 0.18065647461584636, 0.1499018341835056, 0.16629834792443685, 0.13326881027647428, 0.11328541793461357, 0.11176535700048719, 0.15624040977231093, 0.18256288660424097, 0.13013058581522532, 0.11593852378427982, 0.09918993857822248, 0.1192155900810446, 0.10041797839637313, 0.07297160330095462, 0.1819598182503666, 0.07836134944643293, 0.14972476368503912, 0.1982303008969341, 0.12140284771365778, 0.09123572361256395, 0.09748857987246343, 0.11959267913230828, 0.1858840033944164, 0.11700933346790926, 0.13054027168878488, 0.14769783030663217, 0.08695591826524053, 0.10670600991163935, 0.23841098695993423, 0.16218090243637562, 0.11102503458304064, 0.14595917931624822, 0.15639441008014338, 0.130219609609672, 0.09926647054297583, 0.13087473517017706, 0.10983754401760441, 0.09740152382957083, 0.09861146033342395, 0.19363353827169963, 0.11672437590147768, 0.12344538739749364, 0.20106021261640958, 0.22509723422782763, 0.10580791453165667, 0.1102449500135013, 0.34731998294591904, 0.11937083889331136, 0.17010684284780705, 0.16136545262166432, 0.2112651757363762, 0.153295757781182, 0.0849644315562078, 0.10599129540579659, 0.08808194712868758, 0.1271454252834831, 0.15606438421777316, 0.14417659996875695, 0.14178477759872163, 0.19268201504434856, 0.11765231325158051, 0.11056860443204641, 0.2456867822578975, 0.06826899599816118, 0.09223463572561741], [0.04183799088267343, 0.03473626695839422, 0.04947695508599281, 0.02268695235917611, 0.010044597305490502, 0.028967657392578464, 0.024377571551927497, 0.019779214369399205, 0.05265963376898851, 0.03750420807461653, 0.017708878498524427, 0.02166765196514981, 0.02802760649605521, 0.06496465937899691, 0.0644818138597267, 0.03567947134641664, 0.05413442284667066, 0.02345206166085388, 0.08556930481323174, 0.014806840202904173, 0.08002819786114351, 0.04086919215374759, 0.021983011293091943, 0.0194586201437882, 0.03716679296589323, 0.054673213578228436, 0.046409864843423874, 0.024782965691494088, 0.03782379128304975, 0.017089506644489508, 0.01587606211458998, 0.0941252378480775, 0.02078488129856331, 0.060387614981404374, 0.05240571578698499, 0.035509311727115085, 0.07680202847612755, 0.03958478303892272, 0.052808908080416064, 0.05173366417043975, 0.01132329145912081, 0.03093800095043012, 0.04486875914569412, 0.03394843351894191, 0.061760006339422295, 0.028546232863196304, 0.03145634742187602, 0.028088888386264443, 0.009838106376784188, 0.0267274519761226, 0.018469290641535605, 0.021597491444221566, 0.05607068019786051, 0.03778634632804564, 0.03223818939711366, 0.00740116906152772, 0.026317660929635167, 0.08504840026476554, 0.01906677125953138, 0.010461072770080395, 0.03807323432660528, 0.04295638622716069, 0.026018968118088584, 0.012059513828717172, 0.021431202867201397, 0.015138732036575675, 0.05855291735913072, 0.044468450626092296, 0.04497525182419589, 0.04569013596379331, 0.01900814244124506, 0.014065847732126713, 0.023167255068463937, 0.027142428726490055, 0.02981821121647954, 0.031393732210355144, 0.040030241278665404, 0.07055120782128402, 0.07479207882923739, 0.042055471534175534, 0.05598078787858997, 0.008801332009690148, 0.026931896273578917, 0.03874328087217041, 0.01736571280551808, 0.014381329196372201, 0.06971816359353916, 0.07843132676290614, 0.0579735366627574, 0.020310836378484964, 0.03934493448053088, 0.022761158645153046, 0.1025020240672997, 0.06111581197806767, 0.0776854742850576, 0.019002430872725587, 0.027878698593537723, 0.01739409253267305, 0.007673692473742578, 0.015581360785290599, 0.05333385669759341, 0.020278619535799538, 0.028574273322841952, 0.019775555369311144, 0.03133631796975221, 0.05487817186596138, 0.039565505859042914, 0.012386940053797193, 0.06826539297721215, 0.03897805059594767, 0.03649462599839483, 0.04444697838542717, 0.04876127366774848, 0.028201392885031443, 0.06374127431107418, 0.02975213886903865, 0.015086393237912228, 0.06931756330387932, 0.027293560527531163, 0.045324117211358886, 0.07512734976730176, 0.03100674333316939, 0.029935536706554036, 0.015450009976380637, 0.05905865664993014, 0.05062040872871876, 0.02762225646126483, 0.03055465580629451, 0.08307046390005521, 0.09260436945727893, 0.02787222197678472, 0.05855525830494506, 0.03694008084546242, 0.049208021124026606, 0.024773264337064962, 0.02107721962966025, 0.07048701840851988, 0.020226569114519016, 0.02484049697938774, 0.020609554635094743, 0.029502329416573048, 0.044022778647818735, 0.012974899129143782, 0.0775310057880623, 0.025087207223155668, 0.025762848289949552, 0.015714675953079547, 0.019212659681215882, 0.11247662454843521, 0.048374915828130076, 0.0006343069399008527, 0.04057677070211087, 0.03067970641755632, 0.06259709463587829, 0.02315583871677518, 0.0116583902189242, 0.0033249791387269007, 0.018184222813163484, 0.03492515414421048, 0.04357027382190738, 0.04983248707971402, 0.049732392986438105, 0.006966014800127596, 0.03595629327797464, 0.01776342253599848, 0.025408106789525067, 0.03827441995963454, 0.02852496418303677, 0.026923036302572916, 0.04418981361335941, 0.07914004301918404, 0.0337510408966669, 0.020771271582426767, 0.01690585266000458, 0.018629825241597633, 0.03738154251394527, 0.01462497585453093, 0.013578087074815162, 0.026731244986876845, 0.018107512732967734, 0.06685978054468121, 0.10297966522297688, 0.04030828457325697, 0.028260133661595837, 0.03224900185263582, 0.1086945789200919, 0.0614415155723691, 0.040506030033741675, 0.00604040185654802, 0.0019621574569360484, 0.03770263885547008, 0.012752339643027102, 0.02629399871719735, 0.04159744682588747, 0.04172757966443896, 0.032547916884401014, 0.03948164571608816, 0.06719542467700583, 0.03978275241596358, 0.07810240012726613, 0.03282650979235768, 0.05350265585418258, 0.029593327747923986, 0.02468188263342849, 0.04316059134102293, 0.0030301145369386567, 0.0022785063857944416, 0.10049212870321103, 0.010855070914008787, 0.02766956222642745, 0.03127951441066606, 0.017191454834703888, 0.09229395325694766, 0.048212735780647824, 0.041774537680404525, 0.07009942563516752, 0.0722292520638023, 0.053097285463341644, 0.07496493562523808, 0.008185294307103115, 0.034798665038709126, 0.01319189038726368, 0.031224827880838087, 0.03238599128755076, 0.056662915740162134, 0.05370505267222013, 0.004421645883537296, 0.030854307048554932, 0.04633194188188229, 0.04683725708829505, 0.06713329801069838, 0.023939039458387663, 0.01638835944634463, 0.06035463817949806, 0.03480697709268757, 0.05899858594472919, 0.031754773908427784, 0.049341872334480286, 0.0042058335800123, 0.01941230334341526, 0.04049419977569154, 0.05754492644752775, 0.030860556356076683, 0.0065617639920674264, 0.062222997924046855, 0.06398980133235455, 0.019166515907272696, 0.03903260141877191, 0.04149122895406825, 0.07205157766916923, 0.03745343329917107, 0.021457158528002243, 0.029039015527814627, 0.027154852702681507, 0.01676608292785074, 0.04861235558720572, 0.027000879536249807, 0.008883543312549591, 0.010175272972056908, 0.0417226399295032, 0.03270954392584307, 0.05945372687918799, 0.027465034808431352, 0.038393082163695774, 0.07955625639962298, 0.0490908483043313, 0.04331415399376835, 0.027873365308291147, 0.04822269328204649, 0.06280439386942557, 0.07997006776609591, 0.016037868967811977, 0.061252543569675515, 0.021680727334959165, 0.009356663728665029, 0.0357524410023221, 0.048717837248529704, 0.03271096545670714, 0.03865999069863132, 0.06644400821200439, 0.05770969510610614, 0.010171965113840997, 0.03236997446843556, 0.0250933174309986, 0.05938585302127259, 0.04360121162608266, 0.012209813576191664, 0.04143949065889631, 0.09661004665706839, 0.04201933275908232, 0.047948962077498436, 0.03781055985018611, 0.03450294251420668, 0.03964504034125379, 0.03215768121715103, 0.05665504473394581, 0.07000152660267693, 0.021292793597759943, 0.03177478390612772, 0.04001239241499986, 0.0603182212050472, 0.06846928596496582, 0.017674539537568177, 0.01474270676927907, 0.032714415807276964, 0.06604602706751653, 0.05654749014813985, 0.023703933859776174, 0.029347409693790332, 0.012398149452305265, 0.0674501263669559, 0.04942084363262568, 0.08228113768356186, 0.060537801922432015, 0.03297882733334388, 0.04971689185393708, 0.03226359374821186, 0.047535540868661234, 0.014432485647765654, 0.020997871744579504, 0.045367763976433446, 0.011638420933325375, 0.029972231880362545, 0.029234728775918484, 0.051110355116959126, 0.022700684211616005, 0.023587380203285387, 0.01598523839909051, 0.007900629358898317, 0.08291801743741546, 0.024036185317007557, 0.030176392889448574, 0.00831314641982317, 0.030178374211703028, 0.06892382300325803, 0.02242321936812784, 0.04002250937212791, 0.019274262179221426, 0.0559900125621685, 0.06648879830858537, 0.03808020966659699, 0.028014256319563304, 0.023642718126731257, 0.041184032402400456, 0.051626855973154306, 0.08205212532941784, 0.037539172984127483, 0.04831294183220182, 0.027766770849536573, 0.010559351782181432, 0.03112574141206486, 0.04156793733792646, 0.0958715020013707, 0.08200492643352066, 0.19302646656121525, 0.06483982250626598, 0.14029201412839548, 0.1507037675806454, 0.13087462660457405, 0.18388433355305875, 0.11937837063201837, 0.24738933518528938, 0.11273481390838112, 0.09722574933298997, 0.10136611573398113, 0.17941060289740562, 0.11687600133674485, 0.08141711833221571, 0.13938485352056368, 0.14608219771512918, 0.15645136630960874, 0.10902937488364321, 0.20563489571213722, 0.13516538350709847, 0.13004547038248607, 0.14865718382809842, 0.10109843366912433, 0.12609022190528257, 0.12560623644718102, 0.15040814344372067, 0.08343851486487047, 0.09869009575673512, 0.13675035988645895, 0.18304574569421156, 0.11117002394582544, 0.1308998002537659, 0.15086083486676216, 0.12001202734453337, 0.19617492333054543, 0.09204520910446133, 0.13222283497452736, 0.23330772508467945, 0.15307212620973587, 0.24258169744695934, 0.14587369747459888, 0.11541043354996613, 0.16843020995812757, 0.1234715109957116, 0.10122858347105128, 0.07301552487271172, 0.12137425424797194, 0.20909124453152927, 0.07280256665710892, 0.15734186209738255, 0.15014565895710671, 0.15155800245702267, 0.12063200479107243, 0.06476631680769579, 0.12744647770055703, 0.18018836687718118, 0.12139955003346715, 0.16775837886546338, 0.10218311260853495, 0.32045132613607813, 0.06612606705831629, 0.09752338193356991, 0.12491233939571039, 0.10522979591041803, 0.13857719328786644, 0.11921046035630362, 0.2245661855808326, 0.12237524267818246, 0.10706982003258807, 0.07762324583849736, 0.13343228293316706, 0.16159847511776856, 0.08316313142755202, 0.11975513398647308, 0.19656954572669097, 0.20171835087239742, 0.09229322043912751, 0.1280805551047836, 0.1592319756746292, 0.1118604401126504, 0.0985920067344393, 0.142766658482807, 0.13603901091430867, 0.0951674540660211, 0.13744583113917283, 0.20011791746531213, 0.3267916387745312, 0.11671077805970397, 0.15194301679730415, 0.08648739662021399, 0.24360492825508118, 0.1986156137926238, 0.16297420486807823, 0.0877658108781491, 0.1950742716767958, 0.2549319033111845, 0.09136159864387342, 0.17783173333321298, 0.14538849065346376, 0.14211085438728333, 0.13975369158600057, 0.12301525047847203, 0.13280056683080538, 0.10277724465621368, 0.06529377600444214, 0.09984219393559865, 0.15006232128611632, 0.1991491187363863, 0.14669038222304412, 0.1616048804883446, 0.17111092539770262, 0.1219044750822442, 0.11305243615061045, 0.09842582672302212, 0.07637989148497581, 0.1344458514026233, 0.2166134294654642, 0.14119218582553522, 0.20706627890467644, 0.1835151697908129, 0.09646170533129148, 0.1269273441284895, 0.1468583196401596, 0.12842458592993872, 0.18131670275969164, 0.06697857845574617, 0.1336873306759766, 0.23042452122483933, 0.18852349104625837, 0.1293321672294821, 0.09076207224279642, 0.1331129643533911, 0.3210309036076069, 0.11617606532360826, 0.2995486749070031, 0.15847102579261574, 0.09794070132608924, 0.22513307444751263, 0.11259004846215248, 0.1293491848877498, 0.09821290243417025, 0.1250244333807911, 0.1651409843138286, 0.1298911308071443, 0.11906127764710359, 0.12503915759069578, 0.17572135371821268, 0.1559434285653489, 0.09821710935128586, 0.11200530733913183, 0.1184428201190063, 0.20381366700998374, 0.06494860524045569, 0.0788358829117247, 0.1044202900624701, 0.0932971333552684, 0.11407225392758846, 0.12047636242849485, 0.11412146128714085, 0.12361793885273592, 0.12580557646495955, 0.21979394022907528, 0.06923225109598466, 0.10916916666818516, 0.0769387057849339, 0.15206583163567952, 0.1734585887087243, 0.1963729877024889, 0.175582919003708, 0.10149807043905769, 0.14795770921877452, 0.14302784018218517, 0.20248823027525628, 0.0965159609913826], [0.03648106886872223, 0.022842533653602004, 0.02421987322824342, 0.029745611362159252, 0.03599841333925724, 0.0486123623725559, 0.013536082364485731, 0.020467881612213593, 0.0200623890850693, 0.06908060530466692, 0.02782420374985252, 0.017933212353714874, 0.05375422949769667, 0.03702018529708896, 0.07587348722985812, 0.0603990957939199, 0.04332008099715624, 0.059686471175934584, 0.07000833909426417, 0.010606366625454808, 0.014067721336946955, 0.08051535886313234, 0.023311781331098506, 0.0241321030272437, 0.03367758269554802, 0.031833344870912175, 0.04247114208659955, 0.03197708233658757, 0.026940240557970743, 0.016735402966982553, 0.04264436189883521, 0.029532765104834522, 0.04480519398514714, 0.05125628085806966, 0.0309451900289527, 0.06376766253794942, 0.046473267155566385, 0.035609602595546415, 0.04509523038619331, 0.05202438589185476, 0.033846229181757996, 0.05606787784823349, 0.02498897910118103, 0.06433388644031116, 0.013232527849530535, 0.047816155810973475, 0.08027519139328174, 0.02841995919256338, 0.0361863912881485, 0.018100427131035497, 0.06778216747833149, 0.014923728037891644, 0.04018333913492305, 0.04548669080915196, 0.030592925181346278, 0.012331247595804078, 0.07344019958483321, 0.057341983408800194, 0.05015586329890149, 0.03682095045223832, 0.04447551078296133, 0.0501029952429235, 0.02729260888216751, 0.07425362057983875, 0.012781866094363587, 0.034351086377033165, 0.032366320557360134, 0.04972581458943231, 0.019745738844254186, 0.0720325108351452, 0.011037506079966468, 0.05088258787457432, 0.04961191909387708, 0.0389753737752991, 0.02510454548921968, 0.03145997758422579, 0.024683197295027118, 0.06834486978394644, 0.0540073875204793, 0.05960999349398272, 0.02762779839602964, 0.061093902082315514, 0.005029810035401689, 0.0410275757978005, 0.055756440452699146, 0.05279983267454164, 0.020981342631525228, 0.015170037945998567, 0.02318345000302153, 0.02169304613822273, 0.019664913449170332, 0.10081105373267617, 0.013628067964288806, 0.03330949441130672, 0.059621352170194895, 0.03892710279407246, 0.06703143633369889, 0.018938748664887886, 0.01573087428031223, 0.06508999836764165, 0.09230396843382291, 0.023966319958812425, 0.04942930835698332, 0.05862991072769676, 0.06614878441074065, 0.024473884508812, 0.005861462842273925, 0.04402270061629159, 0.012203153754983629, 0.04306388653016516, 0.04287202057561704, 0.025259003808189715, 0.01272866131538259, 0.05653165992615478, 0.07849787747753517, 0.00868298193173749, 0.046643993351608515, 0.04622998860265527, 0.02761984257293599, 0.038903839220958095, 0.028940451531005756, 0.05365426432607429, 0.016734771929415207, 0.057192000028278143, 0.006350476244863654, 0.01225305491659258, 0.03668596948097859, 0.03315762809610792, 0.07280893131558384, 0.0117190978988739, 0.04287734707551343, 0.06937576803777899, 0.04980657382735184, 0.035245514275240045, 0.01771406420240445, 0.05673651643363493, 0.021431263935353075, 0.03178688218551023, 0.03903284229870353, 0.06140202483428376, 0.03962097270414233, 0.0320951915346086, 0.03426010840173278, 0.029859069202627455, 0.027712907043418715, 0.061574481294623444, 0.10488885241959776, 0.021203959793118492, 0.02945279296753662, 0.04014798067510128, 0.034905975351908376, 0.04155924191166248, 0.019774062592270117, 0.015431017781208669, 0.028872509819588492, 0.042483542314065356, 0.09434793304119792, 0.05864166295421975, 0.07314026675054006, 0.06670575309544802, 0.0573162737169436, 0.027120836045859114, 0.05305658354024802, 0.030282603975917612, 0.0516669709634568, 0.044766989070922136, 0.01981589597250734, 0.025659005290695598, 0.0033067439341851112, 0.015860119934326837, 0.05923403759620019, 0.03274091259975519, 0.017172666200037514, 0.08116950733321053, 0.017320203461817334, 0.04629029679511275, 0.019782252509945204, 0.07466896543545382, 0.021200358468507017, 0.03024100638659937, 0.016287454503721426, 0.04061703157744237, 0.04193747090175748, 0.009370496513188949, 0.011160546531235533, 0.046161843330732415, 0.040498851133244376, 0.039430982898920774, 0.04684959624760917, 0.05004198815939682, 0.019637086728055562, 0.03246673356209483, 0.050911347581339736, 0.03463725173579795, 0.06471725194049732, 0.060169445616858344, 0.024065204563417604, 0.024851967613877993, 0.09226940385997295, 0.057003597995000224, 0.010572568796175932, 0.010735400237276085, 0.021363347668999007, 0.016678185501535023, 0.006621927571749049, 0.0284248429483601, 0.029681025006409203, 0.06159394846430846, 0.021579337239797627, 0.012153961662469166, 0.04565435341958489, 0.026491482941699878, 0.026463176157059412, 0.04697902340974126, 0.03559221174301846, 0.010250255332461424, 0.02582951435553176, 0.028061346649857502, 0.038362066327993355, 0.06312088974352394, 0.023467817243986895, 0.05082316177764109, 0.006451934617611447, 0.02174363431653806, 0.005190006640207554, 0.02399716616076018, 0.033192284272185395, 0.041876813263765404, 0.010400017340933638, 0.09088762836264712, 0.016121583225737725, 0.04155020382521408, 0.013703828095458448, 0.03920111898332834, 0.06316992746932165, 0.02380003477446735, 0.051518649993730445, 0.03266496417511787, 0.05369046077664409, 0.047617874307824035, 0.010104999644681811, 0.02334258851728269, 0.010878064769453235, 0.027901689056307077, 0.03485486130895359, 0.035733723613832674, 0.023581546498462558, 0.05221993629155414, 0.06208616455218621, 0.04652440833992191, 0.011214294986400222, 0.01621791993134788, 0.0302615252855633, 0.010363742858836693, 0.05117055135113852, 0.033283669368496964, 0.01168662151654384, 0.056249199368591817, 0.01576875349772828, 0.07224906528634684, 0.01630853658675083, 0.014496944778199707, 0.0594262597816331, 0.057814298064580986, 0.03314008457320077, 0.03378017379769257, 0.021183481606255685, 0.04079047530623419, 0.027349134241896014, 0.04833556758239865, 0.04020262310015304, 0.011048407593209828, 0.04268003587744065, 0.07819058253828969, 0.037393579725176096, 0.012703167058394423, 0.023122144364086644, 0.02169763982029898, 0.06988107306616646, 0.04918561589771083, 0.047812111742262325, 0.014886108360120227, 0.02561944500277085, 0.043619070667773485, 0.05000875351418342, 0.04464576200449041, 0.022878799654011215, 0.06632846048367874, 0.0248375046399555, 0.03432526133422341, 0.019180648095373596, 0.07531928018267665, 0.034708141681871245, 0.02546070852050824, 0.05755412059703043, 0.027905821334570646, 0.01910788539264883, 0.045812635283385, 0.03346991026774049, 0.022922972283725227, 0.03260627768135496, 0.024741178112370626, 0.014878037186073405, 0.012976798179027225, 0.04631278005295566, 0.0339470323441284, 0.05777952993022544, 0.024431455714095916, 0.017209985626063178, 0.010564647748001983, 0.01665861315892211, 0.050255397600787025, 0.007301432047305363, 0.07930342746632439, 0.023237505495282154, 0.04486489828143801, 0.034396096997495205, 0.026937570522672365, 0.014739919686689973, 0.037209907080978155, 0.00694971893348598, 0.10404392025832619, 0.00320899290714546, 0.02987193761925612, 0.02185882072496627, 0.02396867617166468, 0.034217947628349066, 0.00979514917292233, 0.012175289714442832, 0.037552482448518276, 0.04413922204236899, 0.03054382638739688, 0.08981618085610014, 0.062415145470627716, 0.048633973712899854, 0.06463488457458359, 0.02608839582119669, 0.036535874142178466, 0.0442698434261339, 0.06185826499547277, 0.02956827623503549, 0.053664354141801596, 0.027748772708166922, 0.060037674116236825, 0.05665024070601378, 0.04367125679605773, 0.05476743834359305, 0.03460688390103834, 0.043497921632868905, 0.031388290359505584, 0.07738803845963307, 0.022904573806694577, 0.12284059556467192, 0.19552200979420117, 0.09361983782478742, 0.2286914885044098, 0.12849988974630833, 0.18191766765500816, 0.09870806336402893, 0.11274401484323399, 0.0691384029175554, 0.1149750854820013, 0.14033082633146218, 0.10607716401240655, 0.24858157549585613, 0.1118047663143703, 0.15766917381967815, 0.14606880343386106, 0.08176842983812094, 0.12596055386321886, 0.15599110243575914, 0.12168521327631814, 0.07127436330275876, 0.19026930736643927, 0.13706788713378565, 0.09559404903224536, 0.10424305671559912, 0.09046519281608717, 0.08637699897267989, 0.06573640475315706, 0.1282504467027528, 0.07257624130163874, 0.11986981997532503, 0.1790697340454374, 0.09958209789225034, 0.08988629387957708, 0.1221143731049129, 0.1554742351706539, 0.14989184614803108, 0.17846491507121495, 0.15024724922009877, 0.12577667087316513, 0.15031735545822553, 0.18768341041037015, 0.07780630101582833, 0.22063741354005678, 0.15974080908511365, 0.1370476939316307, 0.15367444817508968, 0.10798535376255002, 0.14375616610050201, 0.1501351823764188, 0.21481631589787348, 0.14942007432026522, 0.16965907758900098, 0.1886877915156739, 0.06816894600966147, 0.08330031763762236, 0.19820166671914713, 0.14438211465520517, 0.1421205031552485, 0.15735571778246335, 0.11981200879173619, 0.18913376544203075, 0.19307571463286877, 0.1316767499915191, 0.10998739847647292, 0.1026149322944028, 0.16827508328216417, 0.1250678189098835, 0.1165311291281666, 0.2370415133024965, 0.11288580830608096, 0.15623135811516217, 0.12360723157014165, 0.10820515161114079, 0.1531598607876471, 0.06166343045021806, 0.08216717772717987, 0.16849928482302598, 0.14280332651521477, 0.12185781901436192, 0.1370944314237152, 0.11188452132046223, 0.08514830097556114, 0.2099543682166508, 0.12558822812778608, 0.1090858154264944, 0.18973124266735145, 0.11950806581548282, 0.09195471288902418, 0.11541495259319033, 0.10206381936690637, 0.20363070682755538, 0.09752563466983181, 0.1436285065220935, 0.25176273765308516, 0.15916356577404908, 0.10658105090260506, 0.18558858281799726, 0.07711014444274561, 0.14586014034492628, 0.1355289832821914, 0.11649606243840285, 0.16850026191345283, 0.10983666870743036, 0.17706017116350786, 0.0864990334957838, 0.19319838019354002, 0.2196530220764024, 0.11130953074565955, 0.21473466099372931, 0.1500271867428507, 0.14262343331107072, 0.05284524702333978, 0.2141036098556859, 0.18528704185570988, 0.2081334244992052, 0.15140344575047493, 0.11804886268717901, 0.14263582336051123, 0.1392192638346127, 0.08221019684736218, 0.13845299423805305, 0.09466651201780353, 0.10632163339427539, 0.1072617843747139, 0.16415873702083314, 0.08948348835110664, 0.11265410216791288, 0.16632548932518276, 0.16670111274080618, 0.1115555064752698, 0.09377750900707074, 0.11190294354621853, 0.05682560808158346, 0.07250061178846018, 0.1190431471914053, 0.1020414616380419, 0.2010022114430155, 0.22302744457764284, 0.17212686873972416, 0.12084636757416384, 0.11510913686028548, 0.10013924978141274, 0.1665968761912414, 0.08105704015386955, 0.2165158832711833, 0.10640318651816674, 0.10436949493097407, 0.12720121443271637, 0.118940674832889, 0.14918956240373, 0.11949283948966435, 0.18142613688749926, 0.09696735641253845, 0.12442657617585999, 0.1580968273005315, 0.24857905134558678, 0.1626646164804697, 0.19437586915280136, 0.1548491008579731, 0.1263213309326342, 0.14349422444190296, 0.17934863907950266, 0.20415511940206799, 0.12299241098974432, 0.12135734515530722, 0.12176222700093474, 0.18222232987838133, 0.07633999362587929, 0.10293107533029147, 0.1236062544797148, 0.21524870555315698, 0.136178015598229, 0.1407430906380926, 0.12612618426127092, 0.09142379994903292], [0.05973136305276837, 0.047392295340874364, 0.031841036065348556, 0.04704595410398074, 0.0331526713977967, 0.0986072194895574, 0.013948671519756317, 0.012866857694461942, 0.046767032106540034, 0.023192515230870674, 0.06583260066275086, 0.031085511070809195, 0.013636865170805581, 0.02394023198368294, 0.046794814722878594, 0.028564997749137025, 0.02529956493526697, 0.023279155671064342, 0.022633753517376523, 0.023066424764692783, 0.04332877642342022, 0.04085619820814047, 0.014527148068217295, 0.01626288135802107, 0.04690898163244128, 0.03763717379687088, 0.01471446783814047, 0.02727360311629517, 0.010353544477506407, 0.04897588072344661, 0.032515801821968386, 0.03608110300930483, 0.03172911510669759, 0.03995836745681507, 0.04347635439730116, 0.020679813543600694, 0.025535674765706062, 0.02009919112814324, 0.010460478203770305, 0.030625403260013888, 0.02462026826106012, 0.04695750367162483, 0.017656393814831972, 0.04138825447963817, 0.01759042833665652, 0.06528903983001198, 0.055987512160624774, 0.022245015716180205, 0.00023998360276371905, 0.01573822451090174, 0.049410248308309486, 0.02932743023016623, 0.09776762739888259, 0.029545212829751626, 0.0980348005624754, 0.016754819246541177, 0.04047550613592778, 0.02581967050874872, 0.019145140357847725, 0.01051819184795022, 0.010726432548835874, 0.05685734316440565, 0.02637473420639123, 0.01719032507389784, 0.027619776415771673, 0.0874865869326251, 0.03404280077666044, 0.03468351764604449, 0.047278467698821, 0.0761746685685856, 0.05486372585541435, 0.03149012828777943, 0.01169317022764257, 0.031061518072549785, 0.05002156764801059, 0.011279427562840283, 0.031890681079987965, 0.09240084966378552, 0.02374361628400428, 0.030496824266655103, 0.022607940348929594, 0.04661169508472085, 0.044778826114322455, 0.039927355013787746, 0.029399365120168244, 0.01030103350058198, 0.05501846576641713, 0.03541340419490423, 0.020494724457551326, 0.015225599786000592, 0.045925903134047985, 0.050384329432355504, 0.04312805558687874, 0.020659655964534198, 0.043504150584340096, 0.008279647145952498, 0.10060265527239867, 0.04113231785595417, 0.04068924127412694, 0.061984214665634293, 0.015367875008710792, 0.032216981785105805, 0.023468887632978813, 0.0614036601036787, 0.05377275350370577, 0.0031021166443159537, 0.08058755498911653, 0.060296134890190194, 0.05682480401758637, 0.03984914367486324, 0.04961912513577512, 0.0332468995558364, 0.028883624223193953, 0.04646956574703966, 0.005265816813334823, 0.01168894804348903, 0.0129373388231865, 0.058733434815491946, 0.01989696394386036, 0.04909574393449085, 0.021096233877220323, 0.05647062570122736, 0.044406636085893424, 0.022509812310870205, 0.09429953992366791, 0.028607236554047892, 0.05027476638289435, 0.07951541537685053, 0.05993208049663475, 0.03869035853339093, 0.03349262083481465, 0.018773511817146624, 0.013111905527434178, 0.04052669821040971, 0.04514085168817213, 0.052930861179317744, 0.05264537435557161, 0.008104422262736728, 0.04300928142453943, 0.020178591599687934, 0.10947201720305852, 0.053139134110616784, 0.043251257190214734, 0.015737790248489807, 0.03429561274658356, 0.02090232553226607, 0.003670184889675251, 0.037250351160764694, 0.04104819647701723, 0.020387344594512666, 0.04327804236007588, 0.017484848287754824, 0.037517229161624394, 0.0316310159063765, 0.040288858115673065, 0.07550631157521691, 0.014398933787431036, 0.06099975534847804, 0.07735466810741595, 0.035451446260724745, 0.026482178530256664, 0.09314098887677703, 0.033684493574712954, 0.03896315335961325, 0.004723673270616148, 0.053805720127586804, 0.009680675226263702, 0.04046920933095472, 0.059183595302913866, 0.06366538016923837, 0.027832997563694204, 0.04704628997881498, 0.05079234950244427, 0.01918886854712452, 0.009369513485580683, 0.03999634845448392, 0.014539410892341818, 0.10118612074958426, 0.04403760124530111, 0.08151791470923594, 0.022577776074675576, 0.029641456236796718, 0.04438141493925026, 0.04874961304345301, 0.06987579406372138, 0.055322666585977585, 0.049921843356319835, 0.019120614709598676, 0.010889525225918208, 0.020895104223330106, 0.04961129484165992, 0.050465336335556846, 0.03530825501573937, 0.05154767432915313, 0.0189394950534084, 0.01456204173155129, 0.017968133158449615, 0.03942329848983458, 0.026282109087333083, 0.03600336325221828, 0.09722765601639237, 0.035618562650467665, 0.028902684271867787, 0.06281235308519431, 0.02803977262893958, 0.034288006369024515, 0.020247167741347636, 0.03382808854803443, 0.027857321347775202, 0.027425951191357205, 0.0722085228189826, 0.0492704768798181, 0.036089530414236445, 0.04486675746738911, 0.06614148337393999, 0.006545739539433271, 0.016950922652280757, 0.05568383042035358, 0.06664377570684467, 0.04159770806186965, 0.021972738272909607, 0.009842210665478237, 0.030987401692462817, 0.02871296927332878, 0.026447873496051346, 0.039855460835886855, 0.06860651288713727, 0.04399154568091035, 0.01881121631179537, 0.04319276747160724, 0.05354293030021446, 0.04220089176669717, 0.023567052990464226, 0.07467410873089518, 0.052912601801965914, 0.024555973675368086, 0.03269210218318871, 0.043242300527968576, 0.04503816559112497, 0.02913953031280211, 0.057254208118787835, 0.04402396947677646, 0.010301286254876425, 0.023102358282942857, 0.01963934116065502, 0.037992295276905806, 0.014069590700923331, 0.051181631827993054, 0.025154456828853915, 0.039565044455230236, 0.102042520152671, 0.03931476342092667, 0.04904309640239392, 0.02424347267619201, 0.03273711958900094, 0.03629165581826653, 0.027291967666574886, 0.01969418884254992, 0.027244626278323785, 0.055628068412521055, 0.018108081006045853, 0.02304802798399968, 0.05869153527809041, 0.015263879339077642, 0.011458935698361268, 0.025959740492648313, 0.03251653463978853, 0.061519872796322615, 0.02345697595072644, 0.040921307035854886, 0.08724477740802936, 0.05200030468404293, 0.04052422834294183, 0.01758103571566088, 0.07917326409369707, 0.04777277706723128, 0.06721609285367386, 0.1199115091668708, 0.027134517008172612, 0.040916872809508016, 0.049295379115002494, 0.011625555061203028, 0.029682975794587816, 0.045935612970164845, 0.030036916623690298, 0.033746104554406235, 0.014014120463148823, 0.017417150848944272, 0.08011606814605848, 0.05059437673272831, 0.05137784719201071, 0.08327578859669821, 0.028033487698329345, 0.033737253065087965, 0.01806967592399035, 0.017762447141909173, 0.02476849762855896, 0.05934575838702066, 0.037984023935028484, 0.08660976362547704, 0.019849006785079837, 0.027810743311420083, 0.04650780798069068, 0.07804135233163834, 0.019871469686872194, 0.050954370094197135, 0.04036072175949812, 0.028157320339232683, 0.09403403595622097, 0.01804534874723426, 0.039650590757706335, 0.02002914935084326, 0.05277249789131539, 0.017872899072244763, 0.028535182920417616, 0.02704532357997128, 0.020159258440669094, 0.06276100834033319, 0.0507722037977406, 0.06752948782273702, 0.09087673109024763, 0.05023188975506595, 0.07525091777954783, 0.02201544357064579, 0.04004267543288214, 0.041081967164895365, 0.019191940614421452, 0.030391261181128875, 0.03074039119694914, 0.027741125618506755, 0.05275642339672361, 0.0256076215300709, 0.022504129580089023, 0.00967451836913824, 0.08141057046928576, 0.010517726203293672, 0.04540690866165927, 0.051613081712275743, 0.10332138224371842, 0.04510707421494382, 0.04364334186539054, 0.08356183860450983, 0.04218813191567149, 0.011289011021809918, 0.02495590391169701, 0.0027639169794773416, 0.03687108061941607, 0.03362596992935453, 0.05368084593542984, 0.02499668556265533, 0.019395251758396626, 0.04035239952749439, 0.08629848568567208, 0.18027068674564362, 0.06869665626436472, 0.16764277006898606, 0.10808045723076377, 0.20325368562979357, 0.12142074746744973, 0.10559767724147864, 0.13910228439739772, 0.14263967743941716, 0.1383934731462172, 0.11647145875862666, 0.09373303782194853, 0.0840407418353217, 0.10571564055447068, 0.08997776718544108, 0.1428998006241662, 0.22534624300897121, 0.0654422462518726, 0.0795558967760631, 0.09589340511177268, 0.09752256090619735, 0.06587843570326056, 0.11641642956861428, 0.16428836435079575, 0.11860138018216405, 0.10305551865271159, 0.13440874910780362, 0.11516445103500571, 0.12724066445870058, 0.09164184717727558, 0.1100450943091086, 0.09237130624907357, 0.16248103204582418, 0.1683449452476842, 0.129294359258243, 0.13716205422367367, 0.09313711444182055, 0.16610457189381123, 0.10271771677902766, 0.17417151188211782, 0.14259573551160948, 0.16049196092145784, 0.13976947431053433, 0.07813009792672736, 0.09215023953999792, 0.1383708915007966, 0.15846930231366838, 0.07973274335797344, 0.1142285205423832, 0.12470131500491075, 0.08705087924110037, 0.16577825083264283, 0.1471285122845854, 0.25986637281520025, 0.1324954703450203, 0.18546552370701516, 0.09892989681767565, 0.1491053562079157, 0.07718456616359097, 0.09278773676071848, 0.2268612759986094, 0.12337247202438967, 0.0820775500365666, 0.18544736610991613, 0.19513574694948538, 0.15174863008516176, 0.07020630168595485, 0.11047290385301624, 0.10979552912924971, 0.13264226461095469, 0.1340340349291052, 0.22250744248075144, 0.1165146678686142, 0.1844112974192415, 0.07031695717679602, 0.13674532515662058, 0.20126651440347942, 0.1267707518168858, 0.16398839758975164, 0.17029737548104354, 0.16002687944897584, 0.17531115215803894, 0.13405952070440563, 0.0926899327231305, 0.04817977933479207, 0.1731227274451937, 0.13809658693415777, 0.08566691207566432, 0.06242590703602348, 0.1410074071692569, 0.17679736098008497, 0.16128877816455706, 0.09371878180120673, 0.1405230960143464, 0.11202107649296522, 0.1323116280670677, 0.12240310332604817, 0.15954129264823028, 0.11631582996674947, 0.15450117524181092, 0.18905026492263588, 0.09395697473415307, 0.15820900270981447, 0.18467002282185213, 0.0763170455715486, 0.12399117382509367, 0.1788958933736597, 0.17026141312505516, 0.14565945682781084, 0.1269015326563801, 0.11646448341863495, 0.17684807468737873, 0.12871744164398738, 0.12250569782086781, 0.09925510508141347, 0.1200459540954658, 0.11165702209940978, 0.10718383427177157, 0.13539573257522924, 0.1701892577111721, 0.18155199156275817, 0.14540671610406466, 0.10445227620324918, 0.15886066774172442, 0.12084621829645974, 0.13614193110593728, 0.1412899355803217, 0.14960660359689168, 0.09461084500487361, 0.11229957440601927, 0.12235826573201589, 0.20780065735535963, 0.10707925845469747, 0.13803560020668165, 0.10489032484058823, 0.1427695354712861, 0.12368013337254524, 0.06798602653933422, 0.13798012318355696, 0.12307781140719141, 0.16608819205846104, 0.11059152534497635, 0.1460186732666833, 0.18432209720568998, 0.21418169566563197, 0.12836476628269466, 0.1279925084007638, 0.1181554062558072, 0.10576918375279222, 0.12668543282364095, 0.09279505136821951, 0.10310902113893203, 0.17897066793271474, 0.23010316704000744, 0.17419322500271456, 0.084670734458736, 0.11140409817120858, 0.23569418702806744, 0.1328395011701754, 0.14893137982913426, 0.14102742395230702, 0.17826197881783756, 0.06782060648713793, 0.07464344573340245, 0.15766992020819867, 0.16213013444628033, 0.09307805475379739, 0.2162776224847351, 0.15960655414632388, 0.13235863697315964, 0.08040785856012787, 0.0971025816564049, 0.14365434513560363, 0.15258903641785893, 0.12063531604196344], [0.03118398685806564, 0.03306145593523979, 0.026178062527573535, 0.040990992582270076, 0.0347051018449877, 0.11995319835841656, 0.031340908259153366, 0.041083368339708874, 0.04905153059267572, 0.022431248133735995, 0.020130997457142388, 0.07544030368860279, 0.028950066372220005, 0.050367118391607485, 0.019698848681790487, 0.0016474619270801277, 0.04760221032691853, 0.019983487336763313, 0.0649633633771113, 0.07139711028763226, 0.0493453803605267, 0.017219373158046176, 0.07572801610721008, 0.019595280489219085, 0.0333372159594936, 0.025836661025615673, 0.05744337011128664, 0.04633716320885079, 0.0068998114106112295, 0.04134185625506299, 0.06596739164420537, 0.07226789463311434, 0.06062569934874773, 0.06599415306534086, 0.02109436790591904, 0.022354590640004193, 0.009760381038566785, 0.05275530720661793, 0.0009111473191296682, 0.046983871542449505, 0.010306788325708891, 0.003332226104768259, 0.03382262294845922, 0.037387513622109375, 0.020956531998568347, 0.04721397633797356, 0.02631746245814221, 0.02711374874758933, 0.08210896620793001, 0.023990621690505316, 0.014238996298185416, 0.02001421309874526, 0.036958197730460336, 0.039140430811260424, 0.0251616934048278, 0.011445612663270106, 0.11735816832099642, 0.00755699717306665, 0.049362842459231615, 0.08271278095032487, 0.02652484311589173, 0.03245521882282836, 0.019521281156422834, 0.013865925022400916, 0.045703618454613855, 0.11858470179140568, 0.03155355774132269, 0.010959632312213736, 0.026592869644186327, 0.04104547555159245, 0.04035160564152258, 0.013153617619536817, 0.034151478337922266, 0.03407207956271512, 0.04974902727242027, 0.03721870089481984, 0.12296377681195736, 0.012717826807472323, 0.020017761836892793, 0.04592686665377446, 0.031324949115514755, 0.015377454226836562, 0.011812259908765554, 0.030007824434765747, 0.09904199080275637, 0.025031803142545477, 0.020678588787892034, 0.024872413570327417, 0.05354156983750207, 0.007862512654225742, 0.038290155186716995, 0.02828866775546755, 0.06717479721243892, 0.05454874650708266, 0.034640009980648756, 0.05892716334866626, 0.05984656472823449, 0.014287155321133988, 0.00836569641251117, 0.0157219294924289, 0.062171069639069695, 0.025264666182920337, 0.04690270857619388, 0.01169751285176192, 0.033986044715025594, 0.051031092048755715, 0.0520254681552095, 0.019323260889255574, 0.06543153896927834, 0.03785770785595689, 0.04441058515970196, 0.025602337438613176, 0.015407718585005828, 0.016402975090646317, 0.03704322495364717, 0.01289447576605848, 0.011015891346947422, 0.028557964733668735, 0.02865088331912245, 0.008750718386311616, 0.048264219625187774, 0.0050559442357293195, 0.055528710529740365, 0.018848242271425467, 0.029484012363744632, 0.03578645935548203, 0.03136168160874929, 0.03140760485881141, 0.07382141412901026, 0.04009542813790696, 0.04216279202540006, 0.04635800780462367, 0.05327511252835393, 0.026318395443792855, 0.008968740169491087, 0.0322938462320183, 0.034026811098945994, 0.03828199580311775, 0.06678968109190464, 0.022088187613657544, 0.01072321374834116, 0.010672478836828043, 0.007315977293598864, 0.04580171426225986, 0.07124716761921134, 0.046918735573334355, 0.04529926925897598, 0.040336732153913805, 0.04554663598537445, 0.03468124794640711, 0.02677100374629455, 0.005744125053752214, 0.044274718700242896, 0.0338171064587576, 0.04365818142624838, 0.0292182030555393, 0.05349273227953485, 0.024795510107651353, 0.06794143321790866, 0.044556375193808756, 0.05740265801016774, 0.039047325628676584, 0.021677796063678603, 0.026587753490145718, 0.05588053432958467, 0.0035120535758323967, 0.09385995101183653, 0.09727607627532311, 0.07067063676991633, 0.016458986460098197, 0.022775256906503012, 0.04312639656875815, 0.014010235001998288, 0.0755890521353909, 0.011992708663456142, 0.07675480243882962, 0.013995130812483174, 0.015407698228955269, 0.024405494964282428, 0.03167572118608015, 0.028977431689522097, 0.002285013748665473, 0.029021282015102248, 0.025392503876771246, 0.02306619575912399, 0.06352790218911, 0.04069594520011118, 0.06269753138933863, 0.011491005807848913, 0.029846879321017435, 0.02024740183592907, 0.06009187549352646, 0.0531236160147403, 0.04274702424715672, 0.05599931527727416, 0.07364960906228848, 0.036196477711200714, 0.0401836139416056, 0.022896085333611284, 0.013753531633743217, 0.027797784988901446, 0.0032170320628210902, 0.05467582933072533, 0.029595960463796343, 0.009273180172645619, 0.044168327801993916, 0.017569892474317124, 0.03864474740943738, 0.05592485284432769, 0.04212043447686093, 0.04659606163789119, 0.01831420128499823, 0.04480449848675302, 0.037248030571000915, 0.028126608147951107, 0.05602221583415355, 0.03752407897263765, 0.028627928479441574, 0.024398553551041653, 0.037115302336003096, 0.03702238714322448, 0.04162557549508555, 0.0639653740716832, 0.02901340422353574, 0.0449196255233671, 0.017832677212676833, 0.034743554424494505, 0.04320954085726823, 0.019819381946165646, 0.05143640815679516, 0.035514814646116326, 0.02941634545900992, 0.03908991387912205, 0.029709309738661562, 0.02983794640749693, 0.016017947179664458, 0.040616970509290695, 0.04832993234906878, 0.008538293668867221, 0.012290218279563954, 0.04750299832916685, 0.0904138752126268, 0.037316413330180306, 0.09354095134351935, 0.023152827717629925, 0.05552484288013407, 0.023349860716345053, 0.013750462959121381, 0.09598831859018121, 0.022514012442635636, 0.07199685381991522, 0.02837385613072131, 0.01011197074382965, 0.032443100187395296, 0.010748152454782809, 0.05552649511290448, 0.03810303219194923, 0.023926467900829654, 0.023711613179849725, 0.015573993591325623, 0.05041773371132357, 0.0327998433661248, 0.012418765890678125, 0.01618988625705242, 0.02981655898370913, 0.024002719969887818, 0.06470359981592212, 0.04531170002051762, 0.059915381749825816, 0.02967675362846681, 0.05100267839484981, 0.02309086898873959, 0.022028958291879723, 0.02744575253953891, 0.04145328188315034, 0.022739455702581575, 0.02351589823540832, 0.02344573432180498, 0.0047288076602853835, 0.038131252463374815, 0.011761801500272537, 0.021608646559928144, 0.06872165349445172, 0.02105099255485194, 0.02097108996739345, 0.022514431438009654, 0.020450539953474487, 0.07814866264483758, 0.031132506406200782, 0.022248679805280905, 0.02511925612842398, 0.016119191389796988, 0.05496539414993354, 0.03336307492905429, 0.022263985858964067, 0.04337615513109735, 0.05171778645100338, 0.015721352737663046, 0.038905993569642305, 0.0023878576051044676, 0.04080456508589642, 0.060722607720111094, 0.05363303975069097, 0.010764579787584288, 0.010359927795694342, 0.037123180127569606, 0.009035858309029468, 0.06299325730651617, 0.029010720617536987, 0.01974558108486235, 0.06528441900653498, 0.03655915467866829, 0.017342366111863936, 0.03603907794292484, 0.07040269686175243, 0.023931110776694756, 0.02699629433586129, 0.036402525047638586, 0.009478940828038114, 0.040944875949727635, 0.05852163689477103, 0.008483571515950774, 0.027961776724883487, 0.03859949251636863, 0.015266651154628821, 0.05471324035897851, 0.043439886532723904, 0.01465607650711068, 0.05901079957506486, 0.045195853736783774, 0.04588123856644545, 0.05619256205058523, 0.021814548011337007, 0.070485749548035, 0.04222579739455666, 0.025923286198771427, 0.0476127174416823, 0.05073608198602285, 0.02092675618561251, 0.011947074638945716, 0.06133471416043384, 0.023709867648514252, 0.019754624260323386, 0.03424269040780408, 0.06244777621967452, 0.05401733484385269, 0.043755167829138894, 0.01950427028350532, 0.05853809815432344, 0.038404142284499745, 0.0349248895155532, 0.044111999217420816, 0.14801366121641227, 0.12546582041042192, 0.11550173722207546, 0.11196036117949656, 0.16298865766397544, 0.15090818304036344, 0.07031125748263937, 0.14528145853962215, 0.10118492652795144, 0.122008385935, 0.1404492442629167, 0.10380248392799071, 0.10371083420302186, 0.1441142154591424, 0.0878025603347591, 0.08177528982715947, 0.1544759880219187, 0.07844033092260361, 0.17756824461477144, 0.180969414966447, 0.13071485874908312, 0.09689522814005613, 0.16713662365717546, 0.122189622638481, 0.11839388417346136, 0.061470332954611094, 0.26602584230048315, 0.1560570831809725, 0.09598107862153224, 0.12266264297068119, 0.0818310993324433, 0.16111267118581704, 0.17132707951324327, 0.1977064718625375, 0.13852979083146366, 0.05824982933700085, 0.10080042787428413, 0.1114052448953901, 0.1244751185710941, 0.08064930846116372, 0.07468602380582265, 0.07964468986860343, 0.14708933367260865, 0.11198900214263371, 0.11406445077487401, 0.09402047204119818, 0.1600161043128797, 0.11900396857942853, 0.2701630602989878, 0.0846934789525611, 0.094494679809681, 0.10277205386332103, 0.138814884104899, 0.1747168776180063, 0.14657680903162273, 0.13697651560817445, 0.1889854512576546, 0.06162634851144893, 0.0870749604489122, 0.1332672903580325, 0.18559611455670424, 0.2012509216687509, 0.08621681721082755, 0.10668872083936419, 0.13019047331597122, 0.30440193733998705, 0.08093643733965498, 0.12030770576425961, 0.1327487810381821, 0.10080525904361691, 0.10696546134671994, 0.11113456370575087, 0.16686797807259218, 0.08019094448536634, 0.22719606517681054, 0.14809629321098328, 0.26893130210893496, 0.13274218567780086, 0.1483956357198102, 0.13210540770420007, 0.10914942808449268, 0.1281474722283227, 0.15545587401304925, 0.104916041317795, 0.2073339202574321, 0.0704852474321212, 0.06769534892269544, 0.10023270440953118, 0.08467707197581019, 0.06859351894153015, 0.1735690270683595, 0.16211655017520699, 0.16399316090558255, 0.1081195001357368, 0.09912883649979319, 0.1476297325321606, 0.1508166350956474, 0.0652933960248317, 0.09792697456266199, 0.17940919154456683, 0.16002818223621162, 0.0832695732159274, 0.04391579742410353, 0.11235695132719618, 0.12345268843429429, 0.1152807247958013, 0.15916651061603002, 0.07152943140161888, 0.09229452322636332, 0.11014510358550719, 0.10834962528731142, 0.1694585976323911, 0.052969011810741255, 0.10479808479015316, 0.06614115089178085, 0.12423255587262766, 0.09653964864888362, 0.14724501674728735, 0.11662658543459006, 0.1289584165705102, 0.08790991814540965, 0.14357715499188217, 0.11180342960038356, 0.09330872951873712, 0.14234237053564616, 0.1340741634901081, 0.18197200473930153, 0.14761891668396337, 0.13038529429052556, 0.12238972261548042, 0.14579212399465696, 0.14027311014277594, 0.09065296381179776, 0.15236376279166766, 0.28229768201708794, 0.17177559116056987, 0.07183289940335921, 0.07496270324502673, 0.19524138128118856, 0.1267495679536036, 0.11780465793396745, 0.09000398577856165, 0.10548850095697812, 0.19741973653435707, 0.14731228670903615, 0.0805753752855318, 0.09682523725288254, 0.10642989365650074, 0.1100561815713133, 0.14895269939942019, 0.08498530329338141, 0.09337920216577393, 0.17880985513329506, 0.14635363886398928, 0.09426131804606744, 0.1430034672043153, 0.0962707112942423, 0.11026295833289623, 0.1665555534086057, 0.13836759382060596, 0.11822233695004668, 0.08607830107212067, 0.11907829530537128, 0.08932449402553694, 0.2872310115822724, 0.07021318203104393, 0.1277285718492099, 0.2558144059564386, 0.15129850352449076, 0.10490612792117254, 0.10480111784168653, 0.17206763263259614, 0.25898243167570656, 0.16935666810188973, 0.09297592844814062, 0.26521160027810503], [0.03048500418663025, 0.059610129200986454, 0.05161924281024507, 0.021721793970625316, 0.013449810877708452, 0.03896356387329953, 0.027810315834358335, 0.019036725728905628, 0.052519987869475565, 0.04451500491372176, 0.015562070034710425, 0.043159105349332094, 0.03203111068744745, 0.045424499682017734, 0.0026405959963865045, 0.009033458839569772, 0.04205304577148386, 0.015595932324816073, 0.09387526554720742, 0.04004256008192897, 0.02752581797540188, 0.007817750547214277, 0.033439579752406905, 0.041399691187377484, 0.065905522821205, 0.015259877678805163, 0.04130788879202945, 0.020008638933567063, 0.003873577033768275, 0.04959974617564252, 0.13938572204538754, 0.05137794218691332, 0.026387701010597602, 0.035612896883061955, 0.05211655130343778, 0.0332296851224133, 0.004357616350586925, 0.005053765290150685, 0.03788748875792537, 0.023056509671732783, 0.07289999750043664, 0.060304738714226654, 0.029584109849695648, 0.019954042309629064, 0.041639244583036215, 0.0238707703538239, 0.051398956416440864, 0.06596700487924473, 0.020757828107369796, 0.024339694030848995, 0.08284749729292733, 0.016267286746629646, 0.031123624382806674, 0.049715161589639525, 0.044634888480816565, 0.025527535738157373, 0.02488325147091278, 0.03122213070413896, 0.032218854541757276, 0.016186581791511605, 0.030728591472974846, 0.07859979343733617, 0.02694270703276353, 0.059340099404965124, 0.016237275142754828, 0.01899129950574466, 0.020751778967678547, 0.025320781028962562, 0.02933336401890431, 0.07166087720543146, 0.014250765488083874, 0.03747625243184822, 0.03326137949313436, 0.027904306505141512, 0.03455071137951953, 0.024517746708754982, 0.02017055095971695, 0.0582975439195122, 0.04852940468117595, 0.031091980902212005, 0.028428632566439252, 0.023190937636952316, 0.0331636670577739, 0.04899814006473337, 0.05356291315651365, 0.08143277892044612, 0.02006545097434095, 0.013791992694937756, 0.028391482774168253, 0.038719813738550456, 0.0681823877883809, 0.0887489877641201, 0.028343688463792205, 0.021780565281265547, 0.03246924414166382, 0.012736620531151337, 0.03155299455725721, 0.02798526591089155, 0.013846238177003605, 0.05348725310925927, 0.02866572966533048, 0.02518952521495521, 0.04051079334957259, 0.015500611725396343, 0.02226176704945309, 0.04140325349622539, 0.04657217041988458, 0.032436311444533725, 0.05974059791437217, 0.08226804195770196, 0.009587996672572834, 0.09781000191079718, 0.07249153977526085, 0.07476231149796929, 0.03789794498256274, 0.03759345239294427, 0.08314619519348655, 0.021713722796578492, 0.022064067390082136, 0.020213235901402574, 0.04132344081465687, 0.021454050837616836, 0.027372000872024467, 0.01537800214386412, 0.058885094177510054, 0.024513617823166505, 0.019765709826190556, 0.024045995237039666, 0.03787784677531038, 0.011127355990798345, 0.012459617091475852, 0.03176374074869922, 0.014956852421164513, 0.006078844682113933, 0.03185630988861833, 0.003647894166143877, 0.03187373127522213, 0.03714514769879835, 0.015100706934130617, 0.02611845831519791, 0.017798031214624643, 0.04154442949220538, 0.03702551858233554, 0.0024559089423356844, 0.01297227743946548, 0.040648060983845165, 0.022442428694505776, 0.023011136035035764, 0.025213267155257717, 0.020203291970704283, 0.04386039164715579, 0.007694002723188272, 0.023845796872462546, 0.03236059372180274, 0.05535655262480889, 0.05973967510674681, 0.10117698088288307, 0.05111825665725129, 0.03510279461209263, 0.059930418085839064, 0.023707129759714007, 0.04784580779128841, 0.03518551481621606, 0.07325069153947489, 0.016675291549680487, 0.034761437214910984, 0.05420227295586041, 0.0813285695122821, 0.01831709354051522, 0.0730468664052231, 0.0664614737033844, 0.02230600074731878, 0.06492738745042256, 0.04768042505851813, 0.02475067929896925, 0.0019182028065967771, 0.015304915440667952, 0.06270933111331292, 0.05181956331112555, 0.021479166811332107, 0.01576976790758116, 0.028129461387704526, 0.038623712823859284, 0.05831248526062284, 0.013958691785644208, 0.04388069002223866, 0.07059406409306185, 0.024331387065883194, 0.04610915508653436, 0.0737665274313518, 0.012849211543133216, 0.024552937231159637, 0.04360882818166699, 0.009335615572386553, 0.035197029555482526, 0.06891983321734838, 0.029420399705746343, 0.044148212631366084, 0.06539457916681256, 0.03147821660552706, 0.037577754485287836, 0.010310061409005096, 0.03406917204016021, 0.02958692577002304, 0.03494024137035012, 0.03296032029071024, 0.04917421990207263, 0.025008045935205052, 0.01702273540597941, 0.032792460905121903, 0.05443258470456515, 0.07099188917449542, 0.019894458453304002, 0.04130809574521013, 0.01663124275260738, 0.010068745518635427, 0.034085331351629326, 0.0710558071732521, 0.013976749298827989, 0.02893070437546287, 0.026784462488389442, 0.05890190827527216, 0.018568159979102866, 0.004362948363580341, 0.0928555970479335, 0.05828906901712928, 0.04018791585362383, 0.06248760622526918, 0.06690805152590786, 0.020688856719061732, 0.07337250214602266, 0.02699289657175541, 0.04428627754428557, 0.026706358018730367, 0.007013466874403613, 0.055451598417546065, 0.0017321128813949014, 0.0510112177580595, 0.03244869131594896, 0.023883835545607975, 0.058950871362217834, 0.0633761410468391, 0.030239391473254988, 0.007907136509727155, 0.023594409826078584, 0.006598124139210475, 0.012700862583837338, 0.034419462350862365, 0.047043755650520325, 0.03480684817103403, 0.023305803437584212, 0.011172128275835087, 0.04907690440969808, 0.09497983913336482, 0.0365684370377234, 0.024643211226378168, 0.04769403647099223, 0.020122276585815207, 0.024893244595399926, 0.0287063332008464, 0.007665504252405039, 0.023982796485402753, 0.03446650179103017, 0.06720013371003525, 0.07224683969148568, 0.029308658558875322, 0.018568979310137883, 0.012877632830558079, 0.05998280777462891, 0.028605231483067785, 0.06347236409783363, 0.03660758850829942, 0.01814627574224557, 0.05136682778330786, 0.0298567859322897, 0.022090289375877807, 0.053384115786424706, 0.03747676811846239, 0.04100730117144329, 0.02829074576896216, 0.09255942329764366, 0.02331181356151189, 0.03630699070968798, 0.07770518572734934, 0.10004546267113515, 0.08351458542581115, 0.01984242838807404, 0.10669857995318514, 0.04010189796930977, 0.041626766324043274, 0.019471098402781144, 0.0522118244054062, 0.06115286677543606, 0.03127767558076552, 0.061449644421892505, 0.03401465514408691, 0.04055101690547807, 0.023305747458445172, 0.009915795243744339, 0.027267755840771964, 0.04066690390131303, 0.008892985127334083, 0.050249205968741856, 0.0222829984101866, 0.034123044327965806, 0.04019933559798768, 0.034443855684782775, 0.012037282476999929, 0.020257544238120317, 0.046083509855504544, 0.025692689465358853, 0.008828781295700796, 0.04431516956537962, 0.009162018325046768, 0.015918289045138017, 0.02594608667173556, 0.03701139487592237, 0.03880808096645134, 0.04070723941549659, 0.04289469721594027, 0.02579105838334986, 0.05258706784141915, 0.06804446876049042, 0.023168133771313087, 0.06735509753759418, 0.018640999017017226, 0.020902713993564248, 0.021575294867424027, 0.03041547809594444, 0.05066353302182896, 0.04149277940658586, 0.03568040433206728, 0.042158120311796665, 0.020258584093036394, 0.03795639398906912, 0.028479543048888445, 0.10097616165876389, 0.01921791154226022, 0.07643810300422565, 0.013014882653286415, 0.045318861957639456, 0.0099948089503284, 0.02979149390012026, 0.011675926956481167, 0.06048980914056301, 0.0832206236996821, 0.016795519473297254, 0.09327518274741513, 0.08028286562434264, 0.005683583190797695, 0.03613265470734664, 0.006113588643659438, 0.143339694876756, 0.10737938806414604, 0.1753463274134057, 0.1846244116978986, 0.11225992760487966, 0.17143457303089754, 0.10923811261143003, 0.0934715914939131, 0.0943129952730877, 0.08461870439350605, 0.19927204214036465, 0.09257998290870871, 0.15020326658018998, 0.1465785867933716, 0.09747158257024628, 0.09226503409445286, 0.11823559552431107, 0.08962193663631167, 0.10684797300824098, 0.13964013196527958, 0.18153535388410091, 0.0899406581052712, 0.14332077732043608, 0.1544434590531247, 0.1688874882778951, 0.1429254628185715, 0.1375283817095416, 0.12784582270043238, 0.09236040897667408, 0.2508207953401974, 0.2535451134400708, 0.11204390241099255, 0.11332458297588996, 0.0946827968582511, 0.15992014589054243, 0.14896294527820178, 0.07553521038166114, 0.14219212931181702, 0.09707400854676962, 0.11571987265987055, 0.15573103353381157, 0.20592855209750788, 0.16721679935497896, 0.11624383740127087, 0.14632932016892092, 0.10155113866286618, 0.09536548451121364, 0.18983965899263108, 0.14790994035346167, 0.12600290801908287, 0.237355430743524, 0.12357726746371814, 0.11939342053873198, 0.11777468025684357, 0.09789000797484602, 0.14985017052718572, 0.11879094929567405, 0.1384347823581525, 0.13409475024257386, 0.15952103159257344, 0.14422439597547054, 0.11196960282645055, 0.14085466893655912, 0.12094455159136228, 0.16159243615610258, 0.18655413814953395, 0.0927569041294711, 0.10673960418041263, 0.07207314151206187, 0.13721472211182117, 0.07758410793862172, 0.10930081603250333, 0.09714287985116243, 0.1668329249535288, 0.07161690135087286, 0.12325404052223478, 0.13411092651741846, 0.1263787078538111, 0.1582422237843275, 0.15929706075361796, 0.08966440614312887, 0.1459612963455064, 0.10149656409131629, 0.15487825072237424, 0.0980571379352893, 0.18420201007808956, 0.11633974154080663, 0.1838828000639166, 0.1643075668918235, 0.08710836472788028, 0.12002851574548654, 0.16592185598398956, 0.1022194820855345, 0.07165530643292836, 0.1812543318207775, 0.0923697320478303, 0.11427930210317884, 0.13698754858757767, 0.07949877769819327, 0.17672783828207425, 0.1309976992862565, 0.0625092311363135, 0.13031993779752934, 0.12901485711336136, 0.16757916419633798, 0.09715591450887066, 0.20171091412859304, 0.16834236681461334, 0.15051153860986233, 0.13390423118003777, 0.15228772615747793, 0.3307657369545528, 0.15809878148138523, 0.13262969814240932, 0.0823128999077848, 0.14630330513630593, 0.11286749464592763, 0.0980685916064041, 0.20728988333472184, 0.09063214635742561, 0.15560866652854852, 0.12400410670254912, 0.08119702192821673, 0.07147894839623145, 0.12751790029661997, 0.1140497944184712, 0.10908864491752215, 0.0806812538898417, 0.1542141820703234, 0.2046533269541604, 0.18499512251998695, 0.08804352169058152, 0.11810052634349891, 0.08993964708809342, 0.07516950714801039, 0.08454276275421892, 0.18782089517584868, 0.14030861109495163, 0.07793888675847224, 0.09850098126168762, 0.1728304417005607, 0.1317155079117843, 0.14142169351024286, 0.08361633853720767, 0.08512139706207172, 0.07894334250262805, 0.21984199407909596, 0.09111412335187197, 0.15319247118064336, 0.12192363691117082, 0.12213198787399701, 0.11794499254652432, 0.08844875637441874, 0.20856528489717416, 0.15418191094483646, 0.0878580848553351, 0.16963466389903, 0.08543299391333546, 0.10741944198629685, 0.12755764887801238, 0.12213673761912755, 0.10321096424013376, 0.13827528591666902, 0.08878112996795348, 0.12962699069508485, 0.12398073795650687, 0.19766384629266603, 0.17488001100718975, 0.11821445237312998, 0.21883382674838814, 0.12139186901705605, 0.1640894314540284, 0.10723280414406743, 0.1547377532614129, 0.13582255824335984, 0.13957145065069199], [0.04078776455883469, 0.03287028208641069, 0.0511846682722015, 0.030190699800316776, 0.051073707440601926, 0.03483852218570454, 0.01850496801281614, 0.011409105782929276, 0.041781482486320395, 0.03784247135211315, 0.041764040743666034, 0.013741456254917597, 0.03614132299220987, 0.02771509362251631, 0.010350571645955955, 0.02504468004086188, 0.00788549124263227, 0.033124617367450676, 0.05359525892085262, 0.03155971883929201, 0.013904553172843797, 0.053561162536165545, 0.06653284201664583, 0.02701390062325767, 0.01773671370132693, 0.06043397927922862, 0.027189342637679408, 0.10214680419968707, 0.0303685065092785, 0.06087898290050881, 0.06105233502707311, 0.0314746339406286, 0.009517515543848276, 0.04087367048487067, 0.04815461925630059, 0.04709289176389575, 0.04193842763613377, 0.01735009971473898, 0.09867736643978528, 0.059984687316630564, 0.02644995490222105, 0.04552406451797911, 0.008549923759086855, 0.062220419490975995, 0.042974764348140786, 0.07682763638773135, 0.026815161108970642, 0.013647068641148508, 0.09115330874919891, 0.06269201489963702, 0.011242924075174545, 0.06471208828900542, 0.025595204339229634, 0.030148298147001436, 0.03533295029774308, 0.035436762762921195, 0.005167782073840499, 0.012665330249417042, 0.060559895022639205, 0.06765519322029181, 0.056340750705982955, 0.06851237293864999, 0.04516745365357824, 0.02810221820670579, 0.05619298952764698, 0.06362712436488696, 0.02776458766311407, 0.03295731438057763, 0.026808709937280843, 0.016975348216614554, 0.013210193869391722, 0.06658981860216175, 0.06530353333801031, 0.02475023825120713, 0.043332338732268126, 0.029127194546163082, 0.0831855773659689, 0.0765590722273503, 0.035001869313418865, 0.05193814069830945, 0.03708584373816848, 0.0625223336475236, 0.055755897624684234, 0.046661764183746915, 0.058428989723324776, 0.08042587366487298, 0.02348613429681531, 0.041343460990382094, 0.037979664347533665, 0.0583757586511118, 0.08163961675018072, 0.03267580037936568, 0.021880632233140723, 0.03871731672968183, 0.030602692692939724, 0.05829514190554619, 0.028413967728348713, 0.04517781488331301, 0.03212076212678637, 0.008232700156180986, 0.0225668211267995, 0.010760377959481307, 0.0795765310259802, 0.016415660302819948, 0.01788273104466498, 0.02607028402521142, 0.04511303514508264, 0.051815068016627004, 0.015438741206058433, 0.006506903163556541, 0.10576560108789376, 0.03013881901279092, 0.00865355895699135, 0.06990479465041842, 0.03443456654037748, 0.06397288545433964, 0.024096201739407012, 0.037125595712236, 0.02854450259889875, 0.04155810536550624, 0.05561746291017958, 0.04894297516771725, 0.05245083497305002, 0.02223258325830102, 0.051332039292901754, 0.05050164135172963, 0.018497229320928454, 0.002473686559824273, 0.027813837431105118, 0.02768356040386217, 0.06420342451227562, 0.012717356073803135, 0.016171002627483437, 0.0212686682851719, 0.044103765194969516, 0.04206024163535663, 0.037019673003149886, 0.027450604064922248, 0.024089543614536524, 0.026475304970517755, 0.029874410879399096, 0.034391479566693306, 0.026900357965912138, 0.038731939159333706, 0.02583518181927502, 0.019077812720622336, 0.012727839439841253, 0.05379117572946208, 0.10843766520598105, 0.016416934252317463, 0.07011940170611654, 0.006410805641540459, 0.054897757779274664, 0.03519510251602956, 0.07206828998667852, 0.03179820014962128, 0.07219327613711357, 0.02813784299152238, 0.0353354506992868, 0.0505541192500719, 0.10795523359307221, 0.00996357259074492, 0.04031864919566682, 0.01640573503183467, 0.004757533016215477, 0.029651444272271225, 0.019303561321326664, 0.020057683444714973, 0.04341691472966756, 0.04182404698804021, 0.04583564101319228, 0.05890143330075911, 0.05789134571594851, 0.02250330176736627, 0.023632618132978678, 0.07290562934109143, 0.033008540381810496, 0.021909948338621428, 0.04044099584487932, 0.022827666951343417, 0.0675601711762803, 0.016859730938449502, 0.02977306828168886, 0.014215735269577374, 0.03498762007802725, 0.026530483438234245, 0.08408312991793666, 0.01623367381814335, 0.03373700879248125, 0.024341828023482646, 0.05825910491070577, 0.034262808971107006, 0.02939975188512887, 0.04859120225799935, 0.011282983934506774, 0.009711148233951201, 0.05026184368346419, 0.04302758829934256, 0.01565514468321843, 0.030383254467908825, 0.023569563570033227, 0.038486251807106395, 0.00419579295807385, 0.009407783708801227, 0.060128217829125266, 0.021704503202012608, 0.010503101229135479, 0.026979658353541578, 0.05233498529664107, 0.022488742102203623, 0.02740243316761085, 0.02252173756382295, 0.04309015601341214, 0.008168635424226522, 0.06711326087159769, 0.10885566991886922, 0.062194825150072575, 0.03283521878932204, 0.037481836775051694, 0.0571657678644572, 0.0516807757584112, 0.046654897409358194, 0.03203730231949261, 0.014566764335281082, 0.043180044940007586, 0.10825817233749799, 0.016105125358860408, 0.052740420148308785, 0.02632395094925804, 0.015850376171459044, 0.01577629880713565, 0.04306727581258331, 0.07901904665465866, 0.026203317600967627, 0.0249595238960215, 0.049340732395648956, 0.047362120888595066, 0.028812595177441835, 0.04143454413861036, 0.027070556600977267, 0.009373181815525251, 0.02500153369536357, 0.04676491507728185, 0.012662884130674814, 0.06100361621273415, 0.06940361511494432, 0.03926366973402245, 0.009472084231674671, 0.06439618952572346, 0.06994957117629902, 0.028490341933710233, 0.024372350224958997, 0.06460251166884388, 0.05516991478257945, 0.0751810490286776, 0.02573708601162902, 0.07372162198381764, 0.01467392367443868, 0.030356825528932468, 0.010521941602097025, 0.04568620046068515, 0.0903235554162945, 0.03711416918252196, 0.006868915590790233, 0.01761524236228849, 0.010450443519013268, 0.12385458472583975, 0.0322466575141464, 0.0024418967701162076, 0.08962197056306259, 0.05625268703858767, 0.08989867035831724, 0.018665416099663292, 0.07451337057032756, 0.0016571212971549748, 0.02624822304850178, 0.044903717269854884, 0.034128299581685236, 0.02108543159972344, 0.04897397404004421, 0.02891113542552505, 0.05211677861266902, 0.06192097520189626, 0.014186586253345013, 0.03781340630458934, 0.01208734987968845, 0.05052722890728286, 0.06918046530336142, 0.021087066869118383, 0.05443335144913622, 0.009776386831487929, 0.03842156367110355, 0.031293763646057675, 0.036952789806361706, 0.006924914237710514, 0.06207411377025502, 0.020125265532572354, 0.015089567085461957, 0.029414801791842495, 0.02951437680582915, 0.030758416479719535, 0.033629929181188345, 0.005958525580354035, 0.01944506131777806, 0.016750315470354896, 0.04587853799707123, 0.02300892909988761, 0.015118089304970843, 0.013003879359790256, 0.02935332651915295, 0.004641841523282762, 0.014283491232033287, 0.0551253112831286, 0.04937698991437044, 0.05527977978012391, 0.05091715584109936, 0.022644140192174485, 0.0530717046931386, 0.03765745860125337, 0.00947276785570596, 0.03836599504575133, 0.001043737302617436, 0.0372446752153337, 0.016780559472473602, 0.025582056026905775, 0.08700630627572536, 0.0668646999235664, 0.01939193711483053, 0.01592280639202467, 0.050237494454319985, 0.061972855989422114, 0.013039364196759249, 0.09053560439497232, 0.017539645079523325, 0.007797958528889077, 0.017512278065883687, 0.0035197373487920102, 0.019113491788240414, 0.02040251324485455, 0.03201691234218223, 0.03257183185113328, 0.01747782375397427, 0.027126018357064043, 0.02768311257074986, 0.031308094305651527, 0.04994605348578521, 0.04858049497540508, 0.021400304078789692, 0.04630518385342189, 0.04377014648967555, 0.03836334536650351, 0.01605787218016173, 0.13175301732761519, 0.11975689817752157, 0.0715035181492567, 0.137602477733578, 0.13205644461725438, 0.10922684214477028, 0.11457679899675505, 0.06219201601509537, 0.1390731209622962, 0.1285105427461011, 0.22374161625547068, 0.16529691166111402, 0.11398236160831791, 0.16068011868212903, 0.14850525983742305, 0.09024296581212964, 0.0869389141776732, 0.12250664776989392, 0.1181578625525747, 0.10298681698207345, 0.13170119082289083, 0.1433655877730676, 0.16404985929174082, 0.09890139834689242, 0.09652833068477255, 0.15914304687508515, 0.08570269801254783, 0.23035077803901263, 0.08202334865927696, 0.12017229731593813, 0.09924239612051419, 0.0897286566240447, 0.17962060948567732, 0.09773124435118266, 0.146146047860384, 0.09947197844407388, 0.18624643608927727, 0.10555342318756239, 0.2411318581019129, 0.25444523085440907, 0.08710210184965815, 0.08603984849261385, 0.1785091691251312, 0.12232108201299395, 0.14870537338512285, 0.16712446430964129, 0.11269442071872098, 0.11217156877475125, 0.1827323575104986, 0.13375746405550412, 0.14846167074782507, 0.15703456715813705, 0.2040083251361336, 0.09219452073531491, 0.07277284003794193, 0.18388662700142178, 0.1553065420261451, 0.09324905236384698, 0.08856939990073442, 0.18934104431952747, 0.1299804531569992, 0.22643018913056168, 0.06492577253707818, 0.14634897054306098, 0.12940440406756742, 0.13453434593975544, 0.13447357634348528, 0.08818712684192828, 0.10570437687316112, 0.22244028108460562, 0.12552312947809696, 0.21205857316298143, 0.10935615734862429, 0.14062041150672094, 0.14177989214658737, 0.20253559201955795, 0.14230110203581198, 0.17572987611804688, 0.11622676546020166, 0.09607268084904977, 0.17657075742525713, 0.08504789814885173, 0.13672376131372793, 0.06619928098682847, 0.1619525754026004, 0.35230311698147226, 0.11354950376387153, 0.09091732784041337, 0.09394581961844649, 0.11668411163347107, 0.2390888977263655, 0.0928663993254304, 0.07548895464943987, 0.14418733439275197, 0.1521377292062555, 0.1939099327261959, 0.09380857912557465, 0.15123515549514974, 0.09744953018214021, 0.08390109254313366, 0.14150809815951756, 0.094308021611401, 0.16943879798054695, 0.09135791419872216, 0.19992336790476525, 0.09291718088622604, 0.126125749998859, 0.1918939644736903, 0.06327484933925526, 0.0995913463245545, 0.18714552213038715, 0.12328724802604743, 0.1550873616444213, 0.13457093254796096, 0.1034353489854506, 0.14836837218276092, 0.07528137043118477, 0.09761497059038707, 0.06760043544428689, 0.3469997415585177, 0.12259445020130702, 0.18103049668882573, 0.1583578054394041, 0.1375046329838889, 0.13154081228588307, 0.13660051221294062, 0.09738128312996455, 0.08533562413815941, 0.08659275275255952, 0.12607537555907453, 0.18051130883395672, 0.15670778469315597, 0.07117813346641404, 0.16946099964635714, 0.13812952302396297, 0.10422182535486561, 0.14714249010596955, 0.12357589682298047, 0.12719054786222322, 0.11259898476834808, 0.09854860763464655, 0.19405501708388329, 0.10767086635210685, 0.18552247993648052, 0.14110158782984528, 0.19218266755342484, 0.1999414169362613, 0.17721076522554668, 0.20785176461296423, 0.11962974071502686, 0.14717501907476357, 0.12460623867809772, 0.07212646757917744, 0.12284610526902334, 0.17007297037967614, 0.10194974405957119, 0.12985419136072907, 0.09978652692266873, 0.16753136818962439, 0.06819204334169626, 0.14481848052569798, 0.10156782383897475, 0.188118541347129, 0.12763760744460992, 0.08491129547889743, 0.13154640341443674, 0.06625846281115498, 0.15391308894114836, 0.11950790296707835, 0.18793643611882413, 0.10571460239589214, 0.18188021252197878, 0.16415287447827204, 0.10378786149833884, 0.07728158988590751, 0.12100243062845298], [0.04114535929901259, 0.036182445607015064, 0.036180467677435706, 0.04405514816088336, 0.009040965981382345, 0.03421920970348375, 0.013209474622271955, 0.042873964578445466, 0.045270838641694615, 0.018976773767332946, 0.03217876669285553, 0.02400625853001007, 0.016671635942267518, 0.02684077919859971, 0.0582774660683104, 0.025200402131304145, 0.03591100445815495, 0.08362885750830173, 0.015310576119061028, 0.051107213499822786, 0.03117225498759321, 0.040620373362409215, 0.004853070746841175, 0.06172353508216994, 0.020746355776542, 0.020587364843647395, 0.020814708001645546, 0.041083012108824084, 0.02184296675425555, 0.00607794350279229, 0.07659398963940994, 0.05705015228262969, 0.04034223846559014, 0.03533117932134441, 0.06582183909735509, 0.051379048198993714, 0.03519325690077884, 0.050140175569270334, 0.03659662677507315, 0.05420613721279161, 0.029271943029016256, 0.07583511607455355, 0.04145960582952414, 0.04767312402171748, 0.00579865594461028, 0.03412408248654433, 0.03339547497619476, 0.07359253748186997, 0.040315775599862845, 0.034310360705213885, 0.04676047745825989, 0.026582603409354175, 0.01603203865566424, 0.07379245425441436, 0.023882509009646516, 0.07292896416038275, 0.07974522840231657, 0.016096316277980804, 0.0580206269930516, 0.008153138532569366, 0.01969659255285348, 0.01043126727121749, 0.06803921011409589, 0.052639498242310116, 0.02217640564776957, 0.029395378726933683, 0.02851995320192405, 0.015067981190181204, 0.0378048397999789, 0.033497180590139966, 0.02850282358537827, 0.03065149293148092, 0.08736270000892025, 0.026799585337617567, 0.05568509928083845, 0.037758601031133106, 0.024609376077673266, 0.020582459035462568, 0.015998836240864227, 0.013554935459978878, 0.03227497956582478, 0.05214898867000427, 0.044425048133624453, 0.014360109710001519, 0.05066245075847421, 0.03340619243681431, 0.015499532854716693, 0.03323483181052974, 0.03928109112062624, 0.02632078219072095, 0.04085928214980023, 0.03796427856598582, 0.02089071410175945, 0.046256821269967725, 0.04866335427920733, 0.017250419527824436, 0.04997789374153529, 0.020342155858608227, 0.03167458463992391, 0.023133445364822234, 0.04430843849799462, 0.03141621886087315, 0.02944155303495271, 0.05568652759705271, 0.012331170412445707, 0.042548288125544786, 0.021462703855442147, 0.08612289439354624, 0.007601459028332361, 0.03452008570145283, 0.10079614631831646, 0.05321829200589231, 0.021876610216817687, 0.009709213560979282, 0.03902803148542132, 0.08029154408723116, 0.04862902719261391, 0.04638737480023077, 0.04993902386299201, 0.014388949144631624, 0.0349438647473497, 0.023331577590267574, 0.04814247347946678, 0.036026484332978725, 0.050867867057344744, 0.030226570554077625, 0.024614366702735424, 0.022112496130700623, 0.026074287381821444, 0.031220485256718736, 0.028249611279794147, 0.057924458224858554, 0.04194625114489879, 0.009180783210987491, 0.06594276760837861, 0.0026119162295279758, 0.026939015802262083, 0.029534783746515, 0.05180340060698135, 0.03229483350047043, 0.006570001831278205, 0.023373572122571722, 0.041238325381917615, 0.015307342899697167, 0.054421069965298684, 0.024614295456558466, 0.03339536641059177, 0.09864985184477908, 0.017331248315583383, 0.07381227426230907, 0.09907781066639082, 0.03707512288487383, 0.036758304706641605, 0.017989466299435923, 0.034183074321065626, 0.023314746529129998, 0.03244161758837955, 0.01968232974676149, 0.05964413059077092, 0.03400332021660038, 0.028245702918086733, 0.05469904540638838, 0.018309860357216427, 0.05054475207413946, 0.053781347149716954, 0.009969871940224298, 0.03509777006027954, 0.02434233862108418, 0.03861064423940011, 0.050795321485825946, 0.04820685288203614, 0.043768657105309625, 0.011053782438726296, 0.07063548865595035, 0.032457094972154925, 0.06072063996855702, 0.03396854190421956, 0.010955371960465397, 0.09088564025504248, 0.06227935025734561, 0.027855416360710348, 0.028472133446484804, 0.04979746449472649, 0.01900042749808303, 0.017324198336739625, 0.0209734241278576, 0.05390277099130409, 0.02305425693547087, 0.027879390699256743, 0.0753874865227512, 0.02003369214279311, 0.007034013338852674, 0.02845774171873927, 0.08576289763940231, 0.03573899922360267, 0.014494807392890965, 0.0967780654983861, 0.07354328941021647, 0.01676168941360499, 0.029827792130942856, 0.07620106358081102, 0.02161630552395114, 0.021520423436803476, 0.013525531993114522, 0.017080914694815874, 0.04072632321289607, 0.02174354441064809, 0.04345251406942095, 0.05239878794444459, 0.04265550683651652, 0.015400037568594729, 0.01844471410316016, 0.04811105391542826, 0.037236899204019985, 0.0413616796556328, 0.027291748839031373, 0.01711927736843271, 0.025337299963991557, 0.013598251439231848, 0.0444449054609452, 0.08276443103594439, 0.03545572442401733, 0.02687503843169127, 0.024333975676979338, 0.03583877779809492, 0.026342240860685706, 0.05083613536719765, 0.05319399366687451, 0.05954104755073786, 0.04566560013751898, 0.02163667175253587, 0.05078422404559595, 0.042520451226404736, 0.05891421690051045, 0.04147145983629993, 0.06696357604648386, 0.0382642012222537, 0.010579604356150542, 0.07176520196454865, 0.04101597624165671, 0.016480535035952926, 0.021669361873396804, 0.010973913778018738, 0.024214339775166342, 0.08445136408720698, 0.017991325485387018, 0.035247702550675185, 0.030131735107196227, 0.03776198013552597, 0.028427412899743234, 0.0508472565561533, 0.039847732322024446, 0.035498428025415966, 0.026580842610980784, 0.014759668448407735, 0.038469698945326466, 0.08858784248254128, 0.05139447808531778, 0.01265390626420932, 0.024292171134480407, 0.022391131447095956, 0.027627506625971625, 0.0232205658685416, 0.0224694021578346, 0.04127157699050648, 0.030880722416830913, 0.05624243437445589, 0.030052801128476858, 0.010531212934958083, 0.01856669773613768, 0.024583233819742287, 0.013620790676213801, 0.015976999287626574, 0.06465534240539585, 0.02721628556693239, 0.04159574370299067, 0.025293558204014386, 0.017523545139868344, 0.010917402837159378, 0.03241999607001032, 0.050115280119436126, 0.045421751615192206, 0.05313338013365865, 0.0685436941151108, 0.03677443687670997, 0.0734732374548912, 0.07037208814706121, 0.06798424199223518, 0.0345977677830628, 0.030747634558273212, 0.0280083835989769, 0.05212421874914851, 0.060352385443236144, 0.04251942324585148, 0.019955153410722102, 0.043251389504543374, 0.06995829035128866, 0.010254152667974787, 0.015494313224085739, 0.02207025562945221, 0.04981462125267301, 0.022540422721898982, 0.059218824841082096, 0.059994458220899105, 0.04347826786605375, 0.030663621744939258, 0.0685086545667478, 0.015320311400241085, 0.06375950654702527, 0.02733526498611484, 0.0070932659852717605, 0.045621888911617656, 0.025513357748942714, 0.01494778210430273, 0.058651528853390894, 0.036820807959884405, 0.017658303890909468, 0.025506765781236545, 0.03862090029620698, 0.05044175724365881, 0.053053363891584535, 0.06047728338411876, 0.015405353890465838, 0.021243252059710876, 0.074344666408641, 0.01538769162393042, 0.027878243975075226, 0.06618499103933573, 0.02794695582373866, 0.05708205699920654, 0.037483489007822106, 0.01975819674719657, 0.02145863094899271, 0.048445310443639755, 0.004672705960859145, 0.019338928262836168, 0.010434450448623725, 0.061828925141266415, 0.06557447237095662, 0.048222333658486605, 0.05032237579247781, 0.019526376954412887, 0.021616846655628512, 0.020184686540492942, 0.0657369950786233, 0.07219379860907793, 0.029521854261734655, 0.01804532160583351, 0.0414933154492506, 0.06790775073958294, 0.04295308515429497, 0.022352300584316254, 0.17334177211991378, 0.07708441439483847, 0.18358406823660645, 0.14015634783676692, 0.14972561863916262, 0.10726049515817847, 0.16139662452042103, 0.17662966783557618, 0.19671997694032534, 0.10918176706348147, 0.0938108657885875, 0.12154282948800496, 0.08910354266741446, 0.1297667689089264, 0.17770495585032872, 0.12091270115758691, 0.144651398062706, 0.2234408352524042, 0.1513289561761277, 0.09829719005418674, 0.20082256251147815, 0.10721763888640062, 0.07777264567890338, 0.11473229208162852, 0.1845171217407499, 0.17467526985066278, 0.07672607326614005, 0.12751518615654536, 0.14647980566535676, 0.11744888845298972, 0.16658649460545608, 0.19216349215379783, 0.15762494690716267, 0.1878423233117376, 0.08931941858359746, 0.1784857189548867, 0.13748509117535182, 0.15298653580248356, 0.12504430088613713, 0.1576959759529148, 0.07207241547959191, 0.17272088543644973, 0.16086078541619436, 0.09815673330532652, 0.14040161110460758, 0.12555260503930704, 0.12449976296297141, 0.1755222851144416, 0.13986740048442567, 0.1139603363616126, 0.09104496706277132, 0.09394603674965245, 0.15154208402548516, 0.11541058282767024, 0.08865711412259511, 0.12727384482111248, 0.2323190995625087, 0.17077229571129593, 0.23411469321165765, 0.2197421680071524, 0.09787231178155967, 0.10261326309825693, 0.1660970944379057, 0.20693910787148134, 0.08407078736594745, 0.11019456200301647, 0.13836212482835564, 0.09334985552621738, 0.17430217058530875, 0.100225566221135, 0.08814401951219354, 0.17628178293151514, 0.15248626550393446, 0.11969755350479058, 0.11518201152128832, 0.08808633046490805, 0.12116024430309023, 0.150627269542643, 0.09664376306214503, 0.10823107164885316, 0.10432584477322442, 0.1314798662705081, 0.05813983202512775, 0.11879396199115685, 0.14407336765101977, 0.10804857287023749, 0.08670861260699374, 0.21378429127590998, 0.2070300451346806, 0.1378811113536358, 0.1877584292420319, 0.183042597291725, 0.11009970280740942, 0.1068387720733881, 0.14879955404571124, 0.2548104998256479, 0.08391840875680957, 0.11450711345033986, 0.16869107953139714, 0.09096626378595829, 0.11115560507667915, 0.07889325983290162, 0.15241482933717115, 0.16903817733483656, 0.12635695402111324, 0.06796687149575778, 0.1192834707243102, 0.1395157700670617, 0.08850159389632088, 0.23259021501455987, 0.19649202988616057, 0.13525664646710667, 0.08161200716027192, 0.07351739651390485, 0.12517757873450006, 0.1530717598008258, 0.12697895350200789, 0.11373270143355642, 0.11831695187304701, 0.11485524262700762, 0.19353581565831388, 0.10727758745529822, 0.1891228003161294, 0.16292256835315908, 0.12586245127022266, 0.18214235774108342, 0.10737816670111247, 0.14701016220663274, 0.2156361083367041, 0.11447341740131378, 0.13591787884277956, 0.19762709683605603, 0.17042287731809275, 0.08396205212920904, 0.2059417971010719, 0.15526312935565198, 0.1017727278439062, 0.11626213070537363, 0.1643362282110112, 0.1846442792032446, 0.06799256083156381, 0.13348066247999668, 0.13469366596213408, 0.10225330705621413, 0.17670925999326365, 0.14153651520609856, 0.12467569352260657, 0.1412848194262811, 0.1333380751311779, 0.13694675506225654, 0.28335524669715334, 0.13460998902363436, 0.1519424875399896, 0.14525438499237808, 0.14525129087269306, 0.1800236999988556, 0.12889928902898515, 0.07946820969560317, 0.14548438122229918, 0.10237604725573744, 0.08442779178065912, 0.13973689105893883, 0.08707163562732083, 0.13682733289897442, 0.10914798959025315, 0.11131871132446186, 0.17259501719049045, 0.0874849788046309, 0.18372850120067596, 0.23690349927970342, 0.20141560211777687, 0.151837273899998, 0.20196963953120367, 0.24988449843866484, 0.15913221745618752, 0.12635004653462342], [0.08502834276961428, 0.05326506681740284, 0.060346271842718124, 0.01802618182929499, 0.017910393221037726, 0.04728975173618112, 0.012498705797562642, 0.019594695252765502, 0.0406757553906313, 0.05985468679240771, 0.09887185493218047, 0.05173920780154211, 0.014249734114855528, 0.003455961630347052, 0.011960173757480723, 0.03453960715393935, 0.02238258020952344, 0.028427558784772242, 0.046306659667087455, 0.06060167920908757, 0.024460960113044296, 0.05035120335274509, 0.052316848055592606, 0.09251674344497067, 0.040603182677711756, 0.017512362882761017, 0.012746329519099422, 0.04590382021186607, 0.007408228370227984, 0.04843686607533267, 0.044809227875832996, 0.03990773517372353, 0.04320751543023756, 0.02206766532201852, 0.017756652452849915, 0.021609228403706635, 0.004059518105350435, 0.017448305784325515, 0.06538865555609975, 0.036234496028295586, 0.027957359461912086, 0.020420139888301492, 0.03257196416546192, 0.03544363292998501, 0.07788722988750253, 0.08502354552703244, 0.04584892672885742, 0.017291453933077197, 0.06335989013314247, 0.04501038636746151, 0.05484368532363858, 0.022045092158285633, 0.003127870652990948, 0.0482271546497941, 0.06393430395317928, 0.03003853153703468, 0.05125968710386327, 0.043120713837976964, 0.0014683811625997934, 0.02530451993724065, 0.04451013303228787, 0.03839395747386983, 0.029472589226705686, 0.01311275115170117, 0.03444776404649019, 0.024202358543074558, 0.04615308344364166, 0.007776977377943695, 0.03823054588532873, 0.053484365942754915, 0.08402877247759274, 0.04320097774533289, 0.010195941148724939, 0.0319747074640223, 0.025821093735950332, 0.04877970267885497, 0.031484126645539484, 0.034889286783124716, 0.039793608976261954, 0.06738972317959581, 0.03751219443178602, 0.0434101700915822, 0.03702763221891863, 0.03810978700805988, 0.03986564225384167, 0.025653476926631162, 0.034034444617905786, 0.0424908976336675, 0.017792492672534924, 0.024247637184868966, 0.05391204656500902, 0.02676764499795224, 0.03391262722600784, 0.05678910289758018, 0.04517953157691019, 0.02714178242188479, 0.013765771557310862, 0.0434891888871789, 0.0437921615583556, 0.03712475432881287, 0.022727386260937368, 0.045893557369709015, 0.015991808314408575, 0.007867895981429942, 0.046069874694304805, 0.08571965460266386, 0.10334215220063925, 0.05165497785700219, 0.08906414692423173, 0.0379954131453165, 0.007676596603622394, 0.03878283607108252, 0.012382787419483066, 0.03310252087456839, 0.05045032035559416, 0.025171208162126795, 0.04811159674344318, 0.04655680838706238, 0.015118194477898734, 0.02345990382933191, 0.035016403533518314, 0.02777706422576947, 0.027656544532094682, 0.04000746964343956, 0.028677522603954588, 0.03939093576212015, 0.031806932895311286, 0.023227849941966788, 0.04084004907469664, 0.02239694818854332, 0.016842730243557265, 0.008859444293193519, 0.06190323829650879, 0.03223629289173654, 0.06964895302163703, 0.07659168940569673, 0.13901160497750553, 0.03006698251036661, 0.035827527687485726, 0.07009166319455419, 0.013579481464278485, 0.02075838789876018, 0.031988322269171476, 0.03610957094601222, 0.016597290556611757, 0.05677339820457356, 0.031655639942203245, 0.006060796922871045, 0.044948205418352566, 0.0271472514141351, 0.05469058407470584, 0.02288520841726235, 0.027089329968605722, 0.01848516327195934, 0.029840898034828048, 0.08195155965430395, 0.01635956920550338, 0.022267948503472974, 0.04375525603869131, 0.0317507976932185, 0.015515420752178346, 0.07775949567024197, 0.06483264360576868, 0.0392199144033449, 0.04061456170997449, 0.015911062647189413, 0.028706723358482122, 0.020794346862073456, 0.057689644396305084, 0.010507065569981933, 0.05196804373658129, 0.05316342905695949, 0.045986123116953034, 0.017858795721882155, 0.019117939585287656, 0.010139209683984518, 0.01323568812637989, 0.011439866319830929, 0.047966112050094774, 0.054654526723814864, 0.033274129166134765, 0.01179027876683644, 0.020559134394196526, 0.004342962114606053, 0.025405760754698088, 0.028429977762113725, 0.0598176455657397, 0.038287519078169546, 0.012691881324696754, 0.03560048647757087, 0.02402318119337516, 0.03820338073585715, 0.06709346800510373, 0.04900686602507319, 0.041028912511787245, 0.08379647601395845, 0.01608640797037099, 0.08924041675137621, 0.016300687632922615, 0.02513974958232471, 0.024416477053559253, 0.03940315957048109, 0.04963172892374652, 0.06953616014548711, 0.046569575023438246, 0.01672914348143552, 0.043081993237137794, 0.009565081696824303, 0.04299392956974251, 0.03812032126422439, 0.018892067151942422, 0.03170528495684266, 0.026729005821315304, 0.04029463923403195, 0.07286197918334178, 0.030509526442204202, 0.03808840297694717, 0.06236505601555109, 0.04798568778538278, 0.01936959126032889, 0.025077307397233586, 0.04430936469829508, 0.005971271436594958, 0.03968380504686918, 0.013337932327496154, 0.017766711734501377, 0.031299863675875325, 0.0029029286607900368, 0.01354863356599318, 0.07182759325951338, 0.039452719768243175, 0.008885678153352013, 0.03199444265503969, 0.027422173447640877, 0.047099690684782605, 0.07019777928612062, 0.014695894638342517, 0.03089535841718316, 0.022291929627369558, 0.06393014453351498, 0.0278395505156368, 0.03336323777745877, 0.02302621477948768, 0.010283082856663635, 0.07693774226520743, 0.017580928846395442, 0.04190514549346907, 0.06734973711094686, 0.029253273137978146, 0.02911722008138895, 0.04645662608423403, 0.059692014807036946, 0.016148789087310433, 0.02330923343210348, 0.04650023892255766, 0.03939722917441811, 0.06759329725589071, 0.04229222936555743, 0.02830532579017537, 0.06139211143766131, 0.03942173785929169, 0.04420391017837184, 0.02181309085738446, 0.07246663075472627, 0.018345424073881338, 0.02432570094242692, 0.020290956998776113, 0.009204802502478873, 0.0368239733257464, 0.04482259501570037, 0.05833553509520633, 0.027448188480255858, 0.05116412223183683, 0.04683642588289721, 0.024366192519664764, 0.028212176502815316, 0.022875656340537325, 0.03988259205860751, 0.03825730052111404, 0.04169030095051442, 0.056051589615110836, 0.03963767823630145, 0.025561435347689048, 0.05869571505380528, 0.019202651289690818, 0.08743651783359901, 0.04071128687688282, 0.02790763132673289, 0.018287297371508818, 0.013715657505339809, 0.02449257136322558, 0.025027833712686385, 0.01358622355785753, 0.06725726635860545, 0.042504210490733385, 0.029831235696162497, 0.016200020177555934, 0.016182173010227934, 0.010984697395802608, 0.08516272663005761, 0.08733537540371929, 0.06147850930158581, 0.0328992962438081, 0.015449009137228131, 0.04535530607349106, 0.041467134175556045, 0.014025373118264335, 0.019504039581598978, 0.0032975131013829794, 0.011848790537832039, 0.03814740838216884, 0.06393332007740225, 0.010341989026138825, 0.07040087160255228, 0.0381028455948191, 0.04683429189026356, 0.0557737363103245, 0.058829026828919134, 0.06186310973550592, 0.033961610669004064, 0.0183140910230577, 0.03389418803687606, 0.02566807221488229, 0.09791599586606026, 0.00595351417515693, 0.020189298882282207, 0.06312412635556289, 0.03609209866928203, 0.05525684190381851, 0.030693477285759788, 0.017530837694981267, 0.029102814782943045, 0.04222832493750112, 0.055553202251238484, 0.051366970275661776, 0.03693680012864726, 0.024526065548083613, 0.06636976291026388, 0.02007597335614264, 0.03860871380727206, 0.05009918526879378, 0.12452963207449232, 0.051408964807965925, 0.019205336592027118, 0.05968745505171163, 0.03814797156623431, 0.03935780289715954, 0.06443211795496089, 0.0505296207432236, 0.03792047234518187, 0.023977463200156177, 0.014052266853728464, 0.18428785832864897, 0.14567153475114278, 0.11549417834196772, 0.1337112286793334, 0.18353004327842168, 0.07475374838603394, 0.08979797576154981, 0.10727053069110427, 0.11970615732882704, 0.114045275375247, 0.2008463248078312, 0.1603274568915367, 0.07287625556013413, 0.08722544594534806, 0.167543798951166, 0.24131321694169725, 0.23470271165881837, 0.08866629470139742, 0.09707444280918155, 0.12060825606541974, 0.13239166805786745, 0.21931986138224602, 0.1371463800647429, 0.16786910220980644, 0.11413756970848356, 0.06966757202254874, 0.09492112549820117, 0.1849399847643716, 0.1264308329139437, 0.11060210370591708, 0.13108394108712673, 0.12651147001555987, 0.1347642471747739, 0.15410857488002094, 0.07905551791191101, 0.08499149831810168, 0.13082269153424672, 0.11884793266654015, 0.247914548431124, 0.08818773752344505, 0.08447466497974736, 0.11961584431784493, 0.1115945086681417, 0.10783743991383485, 0.1384176289928811, 0.12092263491025992, 0.20641601165490492, 0.24602566978761128, 0.08494737997118916, 0.09132444885160242, 0.15377081371843815, 0.07638687361031771, 0.19789019200418675, 0.16299141251615115, 0.07992123360080378, 0.08906698998595987, 0.14335255990070955, 0.16705267530466827, 0.15777639592332499, 0.14037521609238215, 0.14929104410111904, 0.10177854288901601, 0.08053190833223717, 0.1291287967136928, 0.16059657745063305, 0.08538355585187674, 0.16376347680177006, 0.09487808602196829, 0.14576049069208757, 0.08272736266787563, 0.11951855596687112, 0.1072303071351988, 0.08827546531600611, 0.1711589249649218, 0.12293244206479617, 0.12125519849359989, 0.10678292185600315, 0.11429722899837153, 0.1592698243579694, 0.09986429382115602, 0.15303370755697998, 0.17226598198924745, 0.13143520509558065, 0.16881711062576088, 0.14532447765980447, 0.2162805266146149, 0.1265983089272465, 0.13977530971169472, 0.09356039137180362, 0.10834219532885722, 0.18749074717717512, 0.08205276315233537, 0.1422426394586052, 0.12447705918124743, 0.15299266975905212, 0.08963965318564858, 0.1398346001016242, 0.13590813507991178, 0.1387011616357735, 0.14381726139358111, 0.12275165319442749, 0.08623522586588349, 0.09441580011376313, 0.07596712506243161, 0.17262941891593592, 0.14440335280128888, 0.1589154933712312, 0.13175274591360772, 0.1737379687173026, 0.251205958958183, 0.1409886796027422, 0.12429641958858285, 0.09594771505466529, 0.11482773481735162, 0.1297690894986902, 0.1299708993839366, 0.10960468436990466, 0.19732361526361533, 0.0717834477712001, 0.09284984307097537, 0.1298319896949189, 0.10345413083476679, 0.12447937977101121, 0.12221802611436162, 0.18133604100772313, 0.14636832236179284, 0.17457357102206775, 0.11754661106637546, 0.17655543610453606, 0.22008660595331872, 0.07338517718017101, 0.0501425029443843, 0.16371688858738967, 0.09793272853962012, 0.17405822367540427, 0.16879846448344843, 0.29266089307410376, 0.10003646529678788, 0.11463287313069616, 0.20023371625159467, 0.08675003038453204, 0.12784282357564994, 0.15970050410500594, 0.0811686252376863, 0.1474137276943241, 0.14501475356519222, 0.16522038648171083, 0.1292246329997267, 0.06456005573272705, 0.09294063784182072, 0.10474629899752991, 0.09639638955039637, 0.1475649867206812, 0.09756546467542648, 0.09796448397849288, 0.13946052374584333, 0.10417350009083748, 0.18143170087465219, 0.12139667304498808, 0.09586223999836616, 0.08755256089248828, 0.19195596900369438, 0.14344741909631661, 0.12323505511241299, 0.13236635870167188, 0.2155163197645119, 0.17519552979086125, 0.07601363185260977, 0.1638467873313597, 0.19457016087004117, 0.13876480822052273, 0.21386418198900564, 0.1115129284028496, 0.21216177833931787, 0.11907141496028219, 0.1025205480733088], [0.08230019773223571, 0.015547361091843672, 0.04699799185618758, 0.049276858501668484, 0.01259776427676635, 0.03966420556285551, 0.01809113459395511, 0.011664094153924711, 0.06317467721445219, 0.03528556480471577, 0.036114110345286984, 0.007863595765749258, 0.03747768753341266, 0.014087530318647623, 0.04652112423043166, 0.045335564097123485, 0.054111257661134005, 0.030015271356595413, 0.025536351604387164, 0.027741531043180397, 0.03395792283117771, 0.03812462317624262, 0.055661092711878676, 0.02230295751776014, 0.011064611009455152, 0.06720446954880442, 0.026093966593699794, 0.020793298525469642, 0.023635244063500847, 0.06122944623764072, 0.04020928631403616, 0.036046012570815425, 0.03252299429316606, 0.05188965258587684, 0.02524721765491579, 0.0392021944613329, 0.009425088048114308, 0.01302468918064343, 0.050259322925869904, 0.005697711562139115, 0.02650562021881342, 0.05056989858193057, 0.09684517939708062, 0.01868147193454206, 0.0633111781041537, 0.016429139400965402, 0.020664431154727936, 0.021009713876992464, 0.01733536532680903, 0.024032019111993055, 0.04006570491141506, 0.024465871010241762, 0.029034469343189682, 0.02849571593105793, 0.02442731665048216, 0.048020215039806705, 0.011168792428049659, 0.050987279042601585, 0.0545371842703649, 0.07026912045798131, 0.026630061844895993, 0.08752310568732874, 0.050098086042063575, 0.005861220690089145, 0.03462621536371963, 0.05414408518533621, 0.0252744998516781, 0.07241055662078516, 0.009816038721640195, 0.003938202405281897, 0.054202008327203136, 0.022900511078270416, 0.037057837205273766, 0.03514585444437606, 0.0324080097489059, 0.023560554321323122, 0.014989439065435102, 0.04672816222799676, 0.02716984663025609, 0.018003752854253565, 0.07566133647092751, 0.02256159301448081, 0.011953745486347802, 0.005683542902780963, 0.020079235413244793, 0.03185689003605928, 0.01161370614343988, 0.053122411615082195, 0.06171771325170994, 0.030359017197042704, 0.05502427402617676, 0.043846926119710715, 0.004605487313321126, 0.011720382874565465, 0.06973250782383339, 0.025063802854024937, 0.013832492753863335, 0.04516237821163876, 0.06653515582105943, 0.025452535566208617, 0.030999723888401474, 0.0026417927625256455, 0.018408804333635738, 0.057497035445911546, 0.0340317779752825, 0.03591024449893406, 0.023987132324171916, 0.06245676680867161, 0.03781176424984421, 0.03344422093193446, 0.05578531211774264, 0.043460636133594174, 0.05160042364150286, 0.02062763420066663, 0.02597262247997735, 0.10554278375846998, 0.0060057410155422986, 0.02942290689264025, 0.0433717616168516, 0.04138701276055404, 0.02593704010359943, 0.007742030279976981, 0.049866766668856144, 0.008036670541124684, 0.05456883792898484, 0.038098275661468506, 0.049104452931455204, 0.07513983481164489, 0.04484545825315373, 0.04856467832412038, 0.044626081096274514, 0.024383644440344403, 0.006798973473321114, 0.021857446691553508, 0.015449487504416277, 0.027109194081276655, 0.0616204384714365, 0.025766437740198204, 0.04639210758198585, 0.027904827280768325, 0.09411518874445132, 0.020767115555437546, 0.04306867020204663, 0.022118489291252832, 0.028982537665537426, 0.03348372184804507, 0.011692819085770419, 0.03850739495828748, 0.03690617445058056, 0.029589039406606128, 0.042063827692930184, 0.04426973146785583, 0.056066632736474276, 0.04033699678257108, 0.02782981693079429, 0.03546223836019635, 0.07419542941663947, 0.05151507072150707, 0.009988663119396992, 0.020389040932059288, 0.055820680755589686, 0.040266598774386306, 0.036764981491225104, 0.018306370990883027, 0.02932343365890639, 0.017352913938728825, 0.06538058777472802, 0.03050472241427217, 0.024956986175051758, 0.03679041976907423, 0.042415424183543236, 0.021627182440300072, 0.08944238269967691, 0.07824788482061454, 0.06367688812315464, 0.01195757751286562, 0.027036378792087947, 0.028088253956022005, 0.02039643526742501, 0.04969340775694166, 0.06152544356882572, 0.0027304342448977487, 0.022331922481368695, 0.06776669009455613, 0.017592263773881962, 0.014591228915378451, 0.0190813190503312, 0.02163199664625738, 0.03609470085107854, 0.03077990568376013, 0.01929459617739277, 0.11594273070139544, 0.029046024794557264, 0.06061210150697401, 0.067081179735916, 0.053711702315402884, 0.021032134370346154, 0.026077922633183852, 0.013132561829739382, 0.034550847086523256, 0.05643836136109062, 0.012417146736489875, 0.02782500781384962, 0.03089686476492456, 0.08239524691764798, 0.03806926828942128, 0.04617946149249162, 0.04709880858925836, 0.030412387368934493, 0.045428279122071605, 0.027071089250966907, 0.08524031032408987, 0.05583182908594608, 0.0542127190024725, 0.05173400683062417, 0.038542332726397684, 0.041164616122841835, 0.021792967205068896, 0.060682526656559536, 0.06849898544273206, 0.03698282176628709, 0.03330223069393209, 0.002914784363903371, 0.023074877614687597, 0.036448621324130466, 0.0468968731750335, 0.035447056139154096, 0.021362804840984087, 0.019990240456536412, 0.047914682488356314, 0.027006131397294145, 0.03727507697684424, 0.03248359515730824, 0.018567386449181607, 0.03760184247844985, 0.017675267266375676, 0.02397999243943819, 0.018841777529035295, 0.03578593688351767, 0.040917978821588416, 0.016569316254130433, 0.012745187035761774, 0.04474813597542899, 0.010992837271520069, 0.014742123229163033, 0.023198467679321766, 0.09772215198193278, 0.03060939661892397, 0.03956574334629944, 0.03351318723122988, 0.00799031981400081, 0.06286223897976534, 0.02398716116191021, 0.02050182532652148, 0.03591742679210646, 0.020755127537995577, 0.0384375499561429, 0.0064889330117564115, 0.011069978221452661, 0.03326480270230344, 0.038522753598434586, 0.006014568756134915, 0.029993571806699038, 0.07670963914798838, 0.04632020661873477, 0.03204523100118552, 0.011271778776842569, 0.05067793832027486, 0.029027694171028476, 0.017275350600747124, 0.0755354342982173, 0.06379337901515619, 0.0701481851616076, 0.034566914795764854, 0.05870083799319608, 0.026687416713684797, 0.06532384189111845, 0.02709266496822238, 0.023364057365272726, 0.04384590492450765, 0.07981668492513043, 0.04066498025453516, 0.052614110854587386, 0.024001876890127147, 0.03898625408432313, 0.04355483715023313, 0.05079625786415168, 0.04713163611346057, 0.08193935959466866, 0.014967836206778884, 0.016686120968578116, 0.018212432906563793, 0.0070399174416836885, 0.02110996742599777, 0.03517235802220447, 0.03916955692693591, 0.037611447141638825, 0.028397801631529416, 0.01814827911688813, 0.03970749609704528, 0.034699571784585714, 0.016139920634616698, 0.03554093824433429, 0.05224243312009743, 0.021168877836316824, 0.04953013187540429, 0.0489456112762647, 0.02509011304937303, 0.03511165627943618, 0.0021899524768481827, 0.052257652660565715, 0.021501197147050073, 0.03170543084187167, 0.014394803205505013, 0.056960836718125005, 0.10513006483337708, 0.05246030053656016, 0.009614350972697139, 0.026083128693114434, 0.00554952460307894, 0.024095587665215135, 0.02698348868372185, 0.016381032964480773, 0.07855864707380533, 0.023253020198483552, 0.0278357117037688, 0.031136435123958757, 0.051263978837856224, 0.03538880730047822, 0.014222702127881348, 0.024468174636630074, 0.0509960558930678, 0.03619706803666694, 0.039999540961746655, 0.01950259430200926, 0.050564874030117474, 0.03220675286969968, 0.054381222996328554, 0.036037819260465245, 0.01684121202145304, 0.02076538359480245, 0.03540280208523784, 0.03417888097465038, 0.01439705424542938, 0.0749733087473682, 0.02622899506241083, 0.036459674659584246, 0.05321751847597105, 0.046023048992667875, 0.018710465735888908, 0.03396085410245827, 0.030134211760014296, 0.1315335112490824, 0.15204809473029204, 0.1713219362178019, 0.17300025187432766, 0.19156218799097197, 0.08376892749220133, 0.12193917536309787, 0.09287467066730772, 0.1252455408019679, 0.1330607035862548, 0.11321370356849261, 0.1416360970054354, 0.11807183788291045, 0.09754506112741572, 0.1378777865320444, 0.23022801748343877, 0.18655698799661227, 0.183644742837974, 0.11320526259286062, 0.09935962661568608, 0.0946383121024285, 0.1687450637774808, 0.15727259724267892, 0.09062983933836222, 0.10384736223412411, 0.1532331154282604, 0.15783114012862953, 0.07322640677115747, 0.20795450838548796, 0.14039284443216665, 0.12322117228593145, 0.08058132603764534, 0.08273826672562531, 0.12786104902625084, 0.11301327789468424, 0.32108830767018454, 0.1295032530490841, 0.2215761938797576, 0.1625720914453268, 0.09119978839797632, 0.14101063699594565, 0.10022352383072887, 0.13220330673669065, 0.1865799631923437, 0.09835269421871219, 0.09422146768442222, 0.0847522672265768, 0.06383321580610105, 0.09997145485665117, 0.1300245172211102, 0.09830607207758085, 0.0906749754878027, 0.1045408725206341, 0.06129985103117568, 0.1269857795642955, 0.14760701517973626, 0.10570549645594188, 0.11765369746301856, 0.1397385059722832, 0.12061357577996594, 0.133680613179292, 0.13908218619014534, 0.09446006095302956, 0.07301277002053601, 0.09594662261328527, 0.11357275715896062, 0.13581221736967564, 0.14635640728686536, 0.09709402532981974, 0.12070103894386973, 0.18619409389793873, 0.19174935509051594, 0.14473545498081616, 0.18594532938940184, 0.14554581578288758, 0.09069174208811351, 0.09446990649615016, 0.14030213787087373, 0.12704182655683585, 0.11791065867458071, 0.20416020841470786, 0.07239970684583698, 0.07445140675242458, 0.06671034677752427, 0.06685644893773965, 0.09679768194577523, 0.07520844148738043, 0.12377544040126459, 0.1355953982898167, 0.10501225758343935, 0.09400683348732335, 0.2552180008164474, 0.13065392630440847, 0.08414102931107793, 0.1711256496076073, 0.11482101732066699, 0.16306374434913906, 0.1239115409553051, 0.11535540435995374, 0.11863712540694646, 0.13941747748426028, 0.1693099441805056, 0.0899124921166471, 0.13150679054004805, 0.19985860852258547, 0.10197389990623508, 0.1282268336841038, 0.12303788640669414, 0.11001331851418529, 0.11758485330002648, 0.13456435075828008, 0.1442763174750975, 0.10482103284448385, 0.13816935302955763, 0.15421923037086213, 0.1936856090490307, 0.10435122198292188, 0.062072369935257096, 0.1116109767130443, 0.2051594326538699, 0.0942077748477459, 0.14039023885769503, 0.07186492625623941, 0.13772523828915187, 0.11883547476359776, 0.05012810103861349, 0.11290562152862549, 0.18307885820312159, 0.1645733897707292, 0.1448905545153788, 0.12999472953379154, 0.12534094282558986, 0.10448441162173237, 0.10403752845845052, 0.1552125106432608, 0.07218724396079779, 0.0963323222739356, 0.12474791678999152, 0.14521454141608306, 0.21984671668282577, 0.20801465372954095, 0.1499565648181098, 0.1306970404194934, 0.10168132239154407, 0.09555831059281315, 0.10553706370826278, 0.13083652007792676, 0.15165104317877973, 0.06979989992188555, 0.12843013634639128, 0.11534845616136279, 0.14899007310824736, 0.1496901855404888, 0.13094686344265938, 0.11307501779603106, 0.21993943170777389, 0.2630234334085669, 0.22874091299516813, 0.09550655194159065, 0.13505102321505547, 0.18529766771410192, 0.15831513915743145, 0.11161601144288268, 0.07757146004587412, 0.11589261410491807, 0.14355674465852125, 0.1653642359056643, 0.09251755768699305, 0.14279356918164662, 0.08821312830384288, 0.17211199525211537, 0.15066445326166494, 0.1454349567315408, 0.08587126646723066, 0.1520916431077889, 0.16507781270359242]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.07794405040996415, 0.016128592492480363, 0.014031957452451544, 0.02370757080747613, 0.049045111651399305, 0.040227756037243774, 0.030599126991416727, 0.03991675290412136, 0.011157828998485846, 0.029386761332196847, 0.02559679720018591, 0.0658064227817314, 0.04260985839313694, 0.02584473728867514, 0.017012328375130892, 0.02200993725896946, 0.04844323412648269, 0.027465240065274493, 0.02525395211497588, 0.023039354610123804, 0.018373851298487613, 0.06975045507507664, 0.005188257716196988, 0.01765194601778473, 0.0567621854133904, 0.027744630251878073, 0.014825718743460519, 0.02263761098895754, 0.04187351558357477, 0.03912727401724883, 0.017879660673705593, 0.026423162947009717, 0.07706481151814971, 0.011980219378269144, 0.06189431556101356, 0.025566933177677647, 0.012662985910927611, 0.00813250513082104, 0.0615675263106823, 0.023114504059776664, 0.03477426152676344, 0.02773307480051049, 0.052382933973733864, 0.023361975959103023, 0.03157586118738566, 0.011632018955424428, 0.0037483466107265224, 0.0663982138835958, 0.04150668937446816, 0.05367038292544229, 0.019190152674647312, 0.03697711189410516, 0.06564596282052142, 0.026149406297398464, 0.051148180051573684, 0.05973092879035643, 0.03931049543565937, 0.08505371319396154, 0.057252579634743075, 0.02176920321237828, 0.01773777391229357, 0.06233562116644212, 0.022535959657813822, 0.07165321654507092, 0.032532297008271725, 0.03511502859847886, 0.013049447227136364, 0.005961238448175469, 0.043028470394866805, 0.057096916916114945, 0.044743694963731935, 0.057677518975521834, 0.020895060118553892, 0.03358759538137487, 0.04661341177831803, 0.0410337029690189, 0.025338901306635568, 0.048513123233403475, 0.02049716209460582, 0.0652022755571774, 0.02854653141860451, 0.02924194499584181, 0.00877613970078528, 0.011353974812664092, 0.041845383521701605, 0.035294602891164165, 0.010871544896092798, 0.05269280056070004, 0.08917217648455075, 0.04821247115199055, 0.03667803740661059, 0.05111739491777761, 0.025307661554376994, 0.031069806377802576, 0.021507507522723505, 0.04214278542037521, 0.03714171091892889, 0.005316672588898135, 0.07102473026939801, 0.08332898574216024, 0.034690740651318004, 0.01907647431029805, 0.04921637389010616, 0.033973172905721834, 0.07954569839473281, 0.023455841100907752, 0.055515750510884185, 0.006140045148120927, 0.037466925968016894, 0.07777823680745703, 0.03835173563233443, 0.02710581328054624, 0.022438805317506194, 0.02343977678434125, 0.025205119646021297, 0.007341330754570663, 0.01885762980340847, 0.04852494331342833, 0.011193779480111386, 0.018760711254019822, 0.021858340661440576, 0.029310880761061395, 0.03424416961414473, 0.0920484389311501, 0.03272972355729767, 0.03074070332305772, 0.02406010706909001, 0.023259970093412057, 0.03205468299399529, 0.06846168637275696, 0.043795533877398284, 0.04283199718754206, 0.01086219129086073, 0.07425303703972272, 0.010002082845728313, 0.048855566286614964, 0.036300863538469584, 0.027083026378282478, 0.043321862151580195, 0.013507843433347131, 0.03543396719864436, 0.014478856730940086, 0.01778224849009088, 0.021455893060192466, 0.021658125333487988, 0.06294999391372715, 0.015520687880260604, 0.04449346481955477, 0.029863109878663505, 0.01723572245932051, 0.01174538943450898, 0.024943939642980695, 0.03421916559870754, 0.045887175747858625, 0.024375374794804623, 0.052054024301469326, 0.02735495607235602, 0.06898338480719499, 0.031037630247218267, 0.06055776442268065, 0.03048526542261243, 0.07634185281183038, 0.0258488729596138, 0.05716992049877133, 0.05343018152884074, 0.02641236236585038, 0.08008581226957695, 0.03438985786799874, 0.010083358618430793, 0.05921325406857899, 0.026686744964016334, 0.021699950232037475, 0.06804062146693468, 0.028666007864688123, 0.042952966410666704, 0.04958202284095543, 0.025885768301252807, 0.0757309270224401, 0.013328465915817236, 0.021123745079551424, 0.08079523420227425, 0.0177924299080457, 0.017883311192105924, 0.03470373459692512, 0.01227605895006231, 0.0071143573981576735, 0.06953516948435988, 0.05185632294576083, 0.0330971977673471, 0.046811408296759636, 0.014484072968895947, 0.04126096470281482, 0.022862167064366595, 0.045102487318217754, 0.021741437559415187, 0.024458936382351176, 0.015210617732788836, 0.01916405452149255, 0.03697752919314163, 0.02291785952235971, 0.06559032973434244, 0.0590064637362957, 0.043099034644131146, 0.031002007158739225, 0.06281911807933024, 0.02475549520126411, 0.031797070388815234, 0.0670340351228203, 0.00837115861941129, 0.09364767133125237, 0.04909480755616512, 0.031132435160023824, 0.050249599519052675, 0.01862668871347393, 0.022944339351462464, 0.005685720576106438, 0.009217528426753623, 0.013965790958276816, 0.027822573569470217, 0.024901079978527765, 0.041794554463454654, 0.015949793426053863, 0.021381893727396215, 0.02939470697726522, 0.07169543499393122, 0.04748623512153115, 0.01538707924607609, 0.016197390854358673, 0.031955223330961804, 0.02496765783455755, 0.03093738348356315, 0.05699310105826173, 0.01399935214846794, 0.05957450611250741, 0.053419993325535736, 0.0074279050376000145, 0.021719169736440693, 0.03053321749238031, 0.026167548627459576, 0.03474208878885422, 0.06260132190904447, 0.0425835244490632, 0.035325639082917144, 0.06052823457866907, 0.021228843368589878, 0.03991581313312054, 0.04587475855701736, 0.026896089980644838, 0.0816137713513204, 0.03659197881019541, 0.0503634475171566, 0.027432280226743648, 0.01670469586471362, 0.043382736920778237, 0.02504731954208442, 0.018808095050709586, 0.0458777983939009, 0.06438988593540021, 0.03851666035396712, 0.0428114952519536, 0.05680916717808161, 0.05281736941209861, 0.03658381264124598, 0.02303256925993732, 0.06853712589613029, 0.07335246500692197, 0.03784550779632159, 0.022935582857046808, 0.01375238151688661, 0.026865014773128287, 0.006639977027329483, 0.05074786474662168, 0.00865297541687531, 0.03462561486022813, 0.05355875034417425, 0.06912940554320812, 0.03917503948988659, 0.03730278495433075, 0.05828155763447285, 0.034940716344863176, 0.08645864030612366, 0.037852961503501446, 0.021941639316667403, 0.024668123639587845, 0.007194562781868237, 0.042152882021452696, 0.07964828610420227, 0.03811210420514856, 0.010968423581549099, 0.03221080372376101, 0.01797871321572789, 0.025833105502117957, 0.07041191815265588, 0.027935023785435727, 0.01213094066562397, 0.02492933248036674, 0.03235334696780358, 0.07273270469158888, 0.015237771007897598, 0.04210406481953604, 0.053198495746723244, 0.13696192710527352, 0.03665582217010004, 0.032524962044720135, 0.047814228771520514, 0.11347894290728228, 0.07875413979802813, 0.016091023704835346, 0.039550825753914456, 0.05828750838658639, 0.021304751081126075, 0.03628325894741075, 0.008377654744046075, 0.05108159201751862, 0.033833801812891445, 0.012409904223334576, 0.07687856044088091, 0.0515045636067433, 0.027643988241574595, 0.012916826709572757, 0.028288320006270493, 0.037748609602983506, 0.012126689643732138, 0.011131067577350353, 0.018855236271130185, 0.05327163842905845, 0.017477148611630713, 0.03548954939469695, 0.0491007379522281, 0.03397900491420712, 0.01078139727802149, 0.025166455024321164, 0.03757875871711543, 0.022269281824784617, 0.06536375332091536, 0.06381207265491996, 0.02431459671684674, 0.043366231556449614, 0.03921199929235237, 0.02326325759557741, 0.04022871616429516, 0.0039973261300474405, 0.0492680171903755, 0.07263618308518614, 0.030145577221576656, 0.0689406506717205, 0.05237517153312053, 0.04105474094727209, 0.022197240065517168, 0.027689728287181685, 0.05809722002595663, 0.026528378283338885, 0.3092448046164853, 0.18557318007307394, 0.07790052238851786, 0.0877967860017504, 0.12157600985041686, 0.12683604045638017, 0.07172135503164359, 0.16221096153770173, 0.1067974017933011, 0.09476158834461655, 0.22087519935199193, 0.18466117472520896, 0.08473141584545374, 0.1553154308348894, 0.11682388984731265, 0.20696196093090943, 0.13374202059847967, 0.16291264817118645, 0.17745678845260823, 0.08811714952545506, 0.062452207053346295, 0.10168147166924817, 0.1511339180703674, 0.09399763255247048, 0.10073341575584241, 0.09632922136890036, 0.0926952524376767, 0.18074840254017285, 0.13436464433159145, 0.12442322421286788, 0.11585563394640173, 0.2005097714385816, 0.07440068625978061, 0.1780854104352849, 0.14800025336444378, 0.09439625151987587, 0.08721070816474301, 0.09915747067758016, 0.09473222813435964, 0.09451704432389565, 0.1027187549376062, 0.10107484100652592, 0.13947944130216325, 0.089173458915736, 0.11437338776886463, 0.07845076679119042, 0.13484664846743855, 0.16492428737027304, 0.16231280964400085, 0.14739149888711317, 0.10271969810128212, 0.09900326680924211, 0.09002628243927445, 0.08382701687514782, 0.06268807939652886, 0.20557233478341783, 0.14025073205786093, 0.18928924495620386, 0.11520962789654732, 0.14207740261086396, 0.1337202667657818, 0.0940446143171617, 0.16372017269687994, 0.1659115965345076, 0.12660198658704758, 0.1666003367198365, 0.09741567807005984, 0.14353771853659833, 0.09336998766022069, 0.13433381170034409, 0.15821186612759316, 0.09911509616566555, 0.10544137669993298, 0.11540265753865242, 0.11830728953438145, 0.14690348293100083, 0.11655832481171403, 0.10100119960095201, 0.07599994580128364, 0.1252144096153123, 0.1563020750348057, 0.12493323827428476, 0.13473812357655593, 0.12974743066089495, 0.13802711851894855, 0.18026132296238626, 0.1765940583177975, 0.1177148741802999, 0.1284461769142321, 0.13207043600933893, 0.18115810198443277, 0.1080279318349702, 0.12563484348356724, 0.14874989885304654, 0.1444465076284749, 0.1549366454460791, 0.15562980967972959, 0.16284731881959097, 0.16479414435369627, 0.21590501176459448, 0.0987859931109207, 0.1167517751455307, 0.08702689981354134, 0.09685300969119583, 0.16047288051673345, 0.1262237440262522, 0.24026067342076982, 0.0916114216670394, 0.08184583032769815, 0.14292563923767634, 0.13163507437067373, 0.10755126098436968, 0.08979739222143378, 0.18446396530738898, 0.08992466503488165, 0.12053686061075755, 0.1565783337822982, 0.1678658995245184, 0.1312442517706326, 0.12725523939090116, 0.14539066196552344, 0.13592569556619438, 0.16683821752667427, 0.1478397934032338, 0.12366398423910141, 0.19187815460775579, 0.1414180022797414, 0.12196387403777667, 0.15651262445109232, 0.18141404539346695, 0.1278784873762301, 0.14642918695296558, 0.1326012946665287, 0.18319400559578622, 0.14161662305040018, 0.09961045387067965, 0.10915824903973512, 0.08407095021435193, 0.14603974856436253, 0.1422925389238766, 0.11495308737669672, 0.08315905343208994, 0.12007469683885574, 0.10435861122927495, 0.10597021332276718, 0.16692513786256313, 0.06537883036902972, 0.12467283010482788, 0.17213509258415016, 0.0867711396089622, 0.08400807037417378, 0.11913474941892283, 0.15570462495088577, 0.1124842105699437, 0.0714065758511424, 0.08846033896718707, 0.12935337823416504, 0.11302432444478784, 0.18010063229926995, 0.14121712877282075, 0.11794571179364409, 0.25296993287546293, 0.09499441406556539, 0.13421945140830108, 0.12567771332604544, 0.06388994133366005, 0.14828415241624626, 0.14448947246585572, 0.09046813087271792, 0.2591232412627765, 0.10284674021282367, 0.1283510055925165, 0.13485838712326118, 0.09185225410120827, 0.08120512363633939, 0.10432084397013698], [0.06511021192584719, 0.10139619519135781, 0.044612032028713396, 0.0912843474320003, 0.05741203536412545, 0.02008113361495946, 0.023376705258020332, 0.07215495926461049, 0.012501087455478097, 0.008342739876492746, 0.1269328674035413, 0.004394343754808817, 0.02900203876197338, 0.04168742396203535, 0.05942936068666833, 0.02871453668922186, 0.05477615751858268, 0.022515963230814253, 0.02393478504382074, 0.0008223684864268371, 0.04072587537978377, 0.0172183333031301, 0.06902672283883605, 0.05994938313961029, 0.024847509638805474, 0.035403141352747164, 0.0028124559820363565, 0.04020642628893256, 0.037998924564038, 0.06271226238459349, 0.02830472867935896, 0.03283939517236181, 0.06152963012989078, 0.02415020464520369, 0.04473637017820563, 0.06209136213042906, 0.005016054858320526, 0.05475435618843351, 0.01360680437314191, 0.024313412673239197, 0.023002096252249818, 0.013727658245313381, 0.014803315213482295, 0.007205232745036483, 0.0005356774750647933, 0.012339021062611468, 0.025184468432728733, 0.022815387163843428, 0.03976059824760471, 0.06294790402586971, 0.04338058257209403, 0.05707443705094712, 0.04160724487155676, 0.04863592789375356, 0.08569281175732613, 0.06226591526397637, 0.04369232191571167, 0.03418553061783314, 0.0962463179603219, 0.014622947034825171, 0.01601066649891436, 0.04162166374070304, 0.007963024894706905, 0.029701340344867537, 0.014612475543149879, 0.02198139637974756, 0.05906109259064708, 0.019795980969710008, 0.03611911114837442, 0.005300790204533509, 0.04485439795202442, 0.03705897375143, 0.03401132353714534, 0.05853609647601843, 0.07079773994960956, 0.08043759196464505, 0.03840495652652212, 0.020150137233680913, 0.023094436386600137, 0.04444780619814992, 0.0685692477439131, 0.06365334295800754, 0.027378494452152933, 0.045343872758426836, 0.04490468418225646, 0.02892104203679732, 0.013969142073100167, 0.029613086687667028, 0.08236787481499569, 0.0398601562982159, 0.059740258646862845, 0.06873775513044425, 0.06489596449370895, 0.018891247820907404, 0.059603805254612646, 0.04870264824213726, 0.02546285608384226, 0.04764423878597362, 0.021352865999298434, 0.03419726248830557, 0.013875440627868687, 0.09242463910153934, 0.0768072803371719, 0.016857464631487216, 0.043568631767162254, 0.0419350994218673, 0.019136446627921293, 0.03252080601773091, 0.02438056219502219, 0.053109393920749426, 0.005729818142884011, 0.017692464736423323, 0.05678128278149026, 0.03470798561881695, 0.010358755626449627, 0.04363804589956999, 0.04839574685320258, 0.022482923664418713, 0.04377152052308832, 0.03966449394023844, 0.07521270947264773, 0.039381144501801045, 0.04408160084858537, 0.02485471059169088, 0.03309279068240097, 0.027123431442305446, 0.06628242188266345, 0.08290596665548426, 0.0254715209760304, 0.05789143392550094, 0.028334619843267968, 0.04151608369180134, 0.016622462509466068, 0.05645588792062231, 0.05397787803251829, 0.0827491165005735, 0.030547534581273794, 0.017123014400047914, 0.03484278338562165, 0.012698343522580606, 0.03427060873114637, 0.03396525100937911, 0.0218077728391758, 0.03765871049836278, 0.057823722915990014, 0.012382346371720945, 0.023711884593857185, 0.060072767947401316, 0.017416394282398478, 0.026971098634281328, 0.03766153320404036, 0.018316051989261593, 0.017430177024964775, 0.02015869695294116, 0.009023324070897485, 0.0641421392293913, 0.03393911723313587, 0.05007308202662638, 0.017436592573566095, 0.03443793546674507, 0.030071311563785588, 0.04258208256214857, 0.06091964750417641, 0.0374735993599253, 0.0633712691654052, 0.06578919477760792, 0.021360319706478288, 0.03754655544513038, 0.030062368472239802, 0.026802966138347983, 0.0567407470994762, 0.026469640899449587, 0.014940520083265645, 0.006399903280128325, 0.04476818668523005, 0.03875103313475847, 0.07005219281251941, 0.020851323447589363, 0.0017782748909667134, 0.05914338531770876, 0.025713311840913126, 0.012200978202080088, 0.03514229213552816, 0.07001509051769972, 0.0317629977528538, 0.008905811135524085, 0.04824705268921597, 0.05759723471211536, 0.02303565659427217, 0.013257296922217523, 0.04539058989446078, 0.03464482757928116, 0.06006415055266448, 0.03566364112443157, 0.03357705773253526, 0.009004972243149365, 0.041886685948286734, 0.002368315796567393, 0.09529816705201354, 0.07296770172459738, 0.04040088763992701, 0.060147223594997606, 0.05345095827111176, 0.04038451798260212, 0.02052418984073613, 0.018562076912660683, 0.021957737559984838, 0.033491267157452445, 0.040392439878944836, 0.012985794705205729, 0.0253403906910015, 0.0174983647053263, 0.0895556505503399, 0.009568118989201528, 0.042859538923949, 0.06550534322325673, 0.036168644204735756, 0.05948055615382535, 0.018425509865794863, 0.06158135485436235, 0.06423824014408247, 0.06163381239665406, 0.025424116823290075, 0.051836957556328604, 0.03325803431549242, 0.004833043785765767, 0.030603863165846894, 0.019420651020482183, 0.022075921396857927, 0.0024799926946538365, 0.057722098726247034, 0.05113238375633955, 0.028538504349333898, 0.018510944209992886, 0.10608082810150725, 0.03570028880078878, 0.044648978260478804, 0.04197241206254278, 0.034735059166061025, 0.0594266126198428, 0.03960784983688167, 0.025179370938401138, 0.0580207762707557, 0.006806746516044119, 0.10610858018376998, 0.05663385747798851, 0.01881608140787908, 0.06295621607984815, 0.026199293888307044, 0.034215945950044055, 0.04685780991400991, 0.031303717754781246, 0.01300213806929865, 0.04392936473180141, 0.01854476748433496, 0.10886651290846722, 0.02593413258104452, 0.011958753922954202, 0.04604569170624018, 0.05217861011624336, 0.05387096805498004, 0.045408696601433415, 0.042296782335532565, 0.015977313110072697, 0.03880777901836804, 0.021185021880748015, 0.08146293980202504, 0.04757941494296704, 0.06968322582542896, 0.012813834423598434, 0.046594758850655386, 0.03932892444676586, 0.007303860354503351, 0.034657706173935106, 0.030665335045861344, 0.02162780499617968, 0.03274785740567105, 0.046548659181488414, 0.06945451881204333, 0.07662337020571743, 0.03516139968165329, 0.036185607580201964, 0.02436028078331479, 0.030783196578600576, 0.05223508797852056, 0.08821180516055652, 0.036847389569239955, 0.03925894034494247, 0.014046256729800786, 0.053502021423940144, 0.048445330799690316, 0.05409065394529274, 0.023568225159708942, 0.019054165775222436, 0.04135232265772564, 0.038551258854568005, 0.017785057625068084, 0.053009564456130774, 0.031953018092151196, 0.02539131135147597, 0.02938062059027808, 0.03720881463959813, 0.02070803042235119, 0.06692786474845239, 0.011330800297270929, 0.0412242254242301, 0.07908797224185296, 0.041462343718324385, 0.03796405125675457, 0.11847135930189065, 0.04765001651165741, 0.06539601766105209, 0.03630004929644721, 0.016625761885994246, 0.0722004414669105, 0.02387811379906322, 0.006975253054406494, 0.031463794343705685, 0.008993042749352753, 0.05737296531775168, 0.07604073932660477, 0.017780314665287733, 0.04252878363643374, 0.011260394655567194, 0.023872354733092443, 0.027191135666466186, 0.01737403334118426, 0.04262833490169474, 0.01736169078919504, 0.03654727353049176, 0.03871729637363127, 0.0316830256155559, 0.024614492231713872, 0.013539119656862957, 0.033241729118994305, 0.0679271025583148, 0.025369660995368446, 0.04171921332765903, 0.009192461646827204, 0.008397317840717733, 0.10623152394379888, 0.018520543784169213, 0.03764525854161807, 0.049222575700176616, 0.0382484863512218, 0.05391640275982874, 0.12875496463051864, 0.022441700965698277, 0.021887056263429776, 0.018057898252404163, 0.0878135526020612, 0.023493642286796654, 0.12881496069686754, 0.34582679878388134, 0.11350111064634152, 0.1518197405551161, 0.145426339336804, 0.10386734509042331, 0.08697768566863877, 0.1918931095195668, 0.13637298585048743, 0.08053855797541992, 0.24734550182308468, 0.15695596566157682, 0.1009329796901771, 0.15313563708748135, 0.13684654901070253, 0.10355503577739, 0.1561894789338112, 0.08109087869524956, 0.16657652014068194, 0.09813993956361498, 0.10480557581675903, 0.13791909574397973, 0.1583554848496403, 0.17393160904092447, 0.09177302835243088, 0.16156104712613992, 0.1005951574604426, 0.13756574184766837, 0.09100711837943111, 0.24734210914799146, 0.07017762679606676, 0.16278943978250027, 0.1240345864955868, 0.1002551910600492, 0.13857350205736502, 0.17772490477987699, 0.1395374967583588, 0.12538643181324005, 0.07437038967119795, 0.15043385992092745, 0.098735136911273, 0.14559468387493066, 0.0934613049030304, 0.08152547358934369, 0.118500699156097, 0.10280112230351993, 0.09579614390219961, 0.10550281126052141, 0.09255194584173815, 0.1304941584489175, 0.10425351294023649, 0.09243856942547218, 0.15747611703617231, 0.1457195614597627, 0.21193506621888705, 0.12235537517283644, 0.10944494365581445, 0.16216722317039967, 0.19608047125594957, 0.13689676060208253, 0.17518079201025621, 0.08250866404601506, 0.1560188816594226, 0.08010884853346006, 0.10016908496618271, 0.12674361041613988, 0.24894459173083305, 0.1039529422830258, 0.23152415507606097, 0.160299704809274, 0.12863683168377193, 0.09305187008742775, 0.1488541489733117, 0.08302660339644977, 0.18059105026934827, 0.22136111184954643, 0.06906849345458405, 0.14762996323406696, 0.0684670875115054, 0.13441017403134278, 0.09122459563825812, 0.15141317594264234, 0.12737170314150198, 0.17412765137851238, 0.21576465001063688, 0.10357535790119853, 0.12131751514971256, 0.16417077423206397, 0.20615172226514134, 0.08541783544101886, 0.2348428698522704, 0.17327784055045672, 0.21219190529414586, 0.10807784487094198, 0.15017702084566864, 0.1173366451902049, 0.08204364364168473, 0.13843812075044426, 0.13154438138008118, 0.07316389333988939, 0.11818623888705458, 0.12485813801842076, 0.18437887701605046, 0.10031046452266829, 0.09864596383912222, 0.14279555050390108, 0.07853440301758902, 0.11671817409140722, 0.13334985449910164, 0.23551155254244804, 0.10270842084927218, 0.07014076877385378, 0.11817980637507779, 0.15938968078366347, 0.16596644930541515, 0.12433782379542078, 0.12402200645634107, 0.07749190860028778, 0.14933129479842527, 0.1306460281567914, 0.12134046320404325, 0.12192355548696858, 0.14911970043820993, 0.10453052486159972, 0.08741114062390157, 0.08552167844027281, 0.14724702521094254, 0.13856920014534677, 0.1950542006109442, 0.08367861448121922, 0.1486931461840868, 0.15996943467429706, 0.09692592506429978, 0.11384468685303416, 0.1006262886470982, 0.24896863901189395, 0.269274857959577, 0.07280604754175458, 0.12380190326699189, 0.11399225464888982, 0.10433646384626627, 0.0910286143688219, 0.07996923316802297, 0.10551513345646006, 0.18814842402935028, 0.07111914163189274, 0.07233746482857636, 0.11540581951183931, 0.07140441132443291, 0.15795485063322953, 0.09501194741044726, 0.1530126729714019, 0.15216731333306857, 0.12052020936139993, 0.12786198540457658, 0.09637181301202093, 0.12604733849210398, 0.09626126608678273, 0.10631215426006488, 0.1759900264441967, 0.1328535739864622, 0.13793831185570785, 0.162223378728543, 0.08451369431402002, 0.18578824853258474, 0.12359094672969409, 0.13226033081965788, 0.1933610386082104, 0.1874976682343653, 0.10307964735797473, 0.22201513818332128, 0.12532383017241955, 0.06548678529049669, 0.08307925771389689, 0.130680362028735, 0.08233337809464761], [0.018861078457640748, 0.03220069015930806, 0.021167844766750932, 0.03102662440921579, 0.02964649096663509, 0.07552621300731387, 0.020883733672755103, 0.03259562128888709, 0.05095492310023733, 0.020764163928106427, 0.012119699036702514, 0.03207694233528205, 0.058650395699909756, 0.03816146423508014, 0.04470327463267105, 0.055651752677346976, 0.015608049263911588, 0.014591500329385911, 0.09260014218411275, 0.026247502105044465, 0.04877924466771739, 0.038834543832178624, 0.052376392896154096, 0.035855832775788646, 0.048645590232419114, 0.02236447180621326, 0.04126193161521639, 0.038692217719342024, 0.02553647374069052, 0.03579367218273027, 0.023089109886703745, 0.01415167817114187, 0.027857365452551415, 0.02220921790493386, 0.021834278113341758, 0.03409921078543578, 0.06441894759024892, 0.029705662612936327, 0.01593193268802549, 0.014992283823500787, 0.02844095985139055, 0.023923918305497085, 0.01192744801353131, 0.026661050539197664, 0.023780372525964464, 0.03382968989067844, 0.05836879688182047, 0.0391036440352244, 0.045700510764228444, 0.009867302042299082, 0.031179250683635473, 0.025851768607805883, 0.02442496722298009, 0.038637521011488776, 0.05222054358039584, 0.02070857833937875, 0.042167328031999726, 0.022021932061761618, 0.05883465866957392, 0.015118038414844444, 0.03606956112863762, 0.006159114526651267, 0.028372091939672828, 0.03600061179271766, 0.017250468721613288, 0.053769886693251986, 0.029211929999291897, 0.059291930203991275, 0.023407610831782222, 0.0072607725326504025, 0.03359730521749173, 0.018260023656434247, 0.05061358945178134, 0.03158314186813576, 0.019681498541363647, 0.08490611825670515, 0.04588664309786899, 0.055716515452201874, 0.01792791299521923, 0.036412960916225395, 0.02196733543782362, 0.045103125141135285, 0.0198163421092821, 0.015274425469604986, 0.01622170615675194, 0.009278638138701873, 0.04103638657501765, 0.04194437160289713, 0.028152540060026304, 0.021601874780442034, 0.07397373845534665, 0.056191371221627505, 0.058923465332814624, 0.011354110519667822, 0.07019644935748406, 0.02650485517057989, 0.028936753515154123, 0.029105746054223607, 0.009248665550590625, 0.08825238834002189, 0.03653717692941427, 0.045046104450843165, 0.06530864949205092, 0.027294963398682218, 0.04863538167306355, 0.013521285212066556, 0.04324587980019195, 0.016194564756006002, 0.0764188054682953, 0.024204823321529796, 0.04070960750271167, 0.03967676863872579, 0.03437629734565105, 0.018825172080791423, 0.02652998810767063, 0.04407486638852528, 0.01945012149267963, 0.059512101246842315, 0.05386409449524113, 0.028571318302835737, 0.03541230496817401, 0.012432659743353724, 0.04245509473340852, 0.004341113106680236, 0.044973236575190506, 0.0545718234830669, 0.024077067051881125, 0.031461718026548624, 0.03159354380997164, 0.036532545927912, 0.03402403249804463, 0.05559144448488951, 0.02871679960350905, 0.03136615315452218, 0.016276920247556906, 0.048714512426938326, 0.01167331459665937, 0.01424931172680642, 0.07924010657838412, 0.0430472488515079, 0.018837711407936046, 0.013226912124082446, 0.010240003516498421, 0.03880504112956779, 0.005629660436950091, 0.019993100481640016, 0.02739423307191048, 0.054091352836361954, 0.05345479877931731, 0.011889357602090707, 0.0355687954995249, 0.037305709440261126, 0.04476935376546212, 0.06299386120268277, 0.02018643376816596, 0.00583027525239491, 0.0317457799267556, 0.009594150137023201, 0.03673795883410743, 0.02725711471534201, 0.05352725274860859, 0.028806759776281457, 0.08268538849162203, 0.018720718400020684, 0.027217812270724347, 0.06860276737383433, 0.030737151192235093, 0.06900284519152981, 0.060895281311656745, 0.03706042581636991, 0.05570894978674395, 0.0869271687365004, 0.07573866910700287, 0.0542242167783635, 0.050373781605490615, 0.0092168999336926, 0.048427967088563104, 0.056076790405703444, 0.04390668130612799, 0.006099480204284191, 0.027896170870267918, 0.04043104852150593, 0.03993241349235177, 0.0744995895240988, 0.0063503613179948714, 0.026542612251692584, 0.019717018153252344, 0.03402702144480177, 0.021313787471236925, 0.034440527470516305, 0.01601015929398792, 0.030945994092949798, 0.01727434297624443, 0.023552586623866643, 0.023287006321230104, 0.06461393819855792, 0.029560625752700225, 0.032936398538627794, 0.01767134533396789, 0.037073345123124976, 0.07187399826943874, 0.02816867223009467, 0.029317805210926702, 0.006678279480963413, 0.03017313252868397, 0.1081781391320484, 0.07381394345845495, 0.03846302216074296, 0.0344146277888545, 0.004100739531817713, 0.005876497906034014, 0.05141794182626264, 0.012754815447676395, 0.007064474896261734, 0.01076734481778528, 0.013221350681435848, 0.019591455248051455, 0.01872193467404161, 0.024187122039230805, 0.03308616139526878, 0.018114701811490313, 0.020165906387514303, 0.05762787735355752, 0.03761566423677972, 0.030193851595478396, 0.014449296352852668, 0.03655318696317928, 0.043569198343902826, 0.016190681839361787, 0.03719024992148791, 0.02768433902279607, 0.05309758401874985, 0.07607223013682024, 0.09463948596801076, 0.0037032855242224677, 0.049369746553046365, 0.009596500412694045, 0.016861096490174532, 0.015810938019837652, 0.025400610673906546, 0.03651421191170812, 0.0499032345334334, 0.05948606585817678, 0.021837908275691525, 0.030889034470809356, 0.04409428945343409, 0.042761236163122315, 0.028494508138724735, 0.012405709180581783, 0.08453042698757988, 0.023912761493452957, 0.053323088346847465, 0.03129614869664822, 0.004818591413952942, 0.015370390677292432, 0.032846645319036076, 0.03636826920722212, 0.03316910890862346, 0.003776295468144651, 0.025821483893586055, 0.07329641122903142, 0.0217937678763909, 0.07356271586780037, 0.03563449126003044, 0.01415768575056323, 0.028726146423390934, 0.03555057344159909, 0.01948774965213878, 0.04673075423176799, 0.02726852088900549, 0.04984236654958554, 0.048862338066101074, 0.03660155293930854, 0.025854090893907205, 0.05947271228900977, 0.05192618491128087, 0.01806223239483578, 0.06553930390094008, 0.010789458274043031, 0.036531249926026375, 0.07567969762853213, 0.048672941979020834, 0.03547394648194313, 0.07787351669477564, 0.04833853278043015, 0.033068363421729634, 0.03003824994500194, 0.03428447459425245, 0.028287504067910568, 0.06356444129986422, 0.013167057701918696, 0.03487693066043513, 0.02156915751818035, 0.04878674587234855, 0.061590474365012984, 0.044403216269399436, 0.014641638978251388, 0.04711193145651903, 0.05785282528293984, 0.045825666548418145, 0.03773357665964535, 0.06450345912682158, 0.006247434765100479, 0.009190925613178738, 0.07056732302797691, 0.03272951999679208, 0.06049926791872297, 0.029280146517391716, 0.006588167485980583, 0.03395708484042968, 0.0016882489851143742, 0.05434696037056191, 0.04203374484287841, 0.01912385132163763, 0.04787518496492079, 0.038563045007841926, 0.012321618335720683, 0.06553341421697821, 0.00738532272433596, 0.012559680650675935, 0.0213586572956826, 0.031026878859847784, 0.04266706907323428, 0.03373282223141619, 0.10200227624071495, 0.036742308243576965, 0.015689448021086197, 0.041876365430653095, 0.08127644445214953, 0.0379261313272374, 0.05473015623699341, 0.01016329343630267, 0.06840903884066002, 0.014053288897100304, 0.012121251185557671, 0.023986716721472994, 0.038294121223900995, 0.013841846359095402, 0.043596288854522366, 0.026324118886675154, 0.04399241081305912, 0.03250146437702434, 0.017844482025663768, 0.01589414168016187, 0.03134870123384254, 0.03566521193299975, 0.04638870133619223, 0.011034182106543864, 0.036829357501119375, 0.040613079110958746, 0.035805152995245795, 0.07049300308738436, 0.1408393747572388, 0.14711849710771016, 0.11637676241142408, 0.11896624203239169, 0.0693853964496936, 0.13229898017432007, 0.17643454830561364, 0.18986371984439238, 0.11154543701559305, 0.11173641748194184, 0.0827212490673576, 0.14342362965856278, 0.11161812168679067, 0.12221392776284899, 0.09985725062766246, 0.15498457715979644, 0.11242195498198271, 0.09136001087192978, 0.10892205778509378, 0.1531115219529186, 0.07931798882782459, 0.1453315479946988, 0.10222609780196633, 0.13524832762777805, 0.16458582053227083, 0.056837831889944415, 0.13649765987481388, 0.1123946507328323, 0.10644489606576306, 0.16223772295883723, 0.08624539710581303, 0.08762895036488771, 0.08733745172087636, 0.12509694163288387, 0.09939489686595541, 0.09151607392621891, 0.16614536541913236, 0.10722645984164306, 0.09833071646945817, 0.11265301651188306, 0.09191716954644237, 0.10024320134626967, 0.07633056198912007, 0.14045322047812597, 0.13280283313776764, 0.08826983347535133, 0.14057482752416814, 0.1701691730746201, 0.12271072396210261, 0.07018846978566476, 0.11605719955904142, 0.15784769638308457, 0.06711570359766483, 0.09817121324262448, 0.14289401950580732, 0.11925014108419418, 0.15892185802970613, 0.18771181388625077, 0.12486847889210496, 0.15551957488059998, 0.0854592260771564, 0.06139230142746653, 0.09109147385294948, 0.2133395115711859, 0.07822898762034518, 0.24370714277029037, 0.20876417708184036, 0.07927543111145496, 0.09255953864859683, 0.11011153645813465, 0.11880150730056421, 0.19870709388383798, 0.08224235262189593, 0.1298175368990217, 0.1521117277443409, 0.21673122314470156, 0.1420812024069684, 0.11586061439343862, 0.09837834962776729, 0.07711994927376509, 0.1936400793492794, 0.10312977752515248, 0.10004173072853259, 0.08319158918623414, 0.09642452161226954, 0.06551285460591316, 0.19327569247356483, 0.14979903612818035, 0.043897419303123436, 0.10247254172073943, 0.19383975863456726, 0.10541170436356749, 0.07735764687614781, 0.1718668541205781, 0.29447103451405254, 0.05594917153939605, 0.10291547581021275, 0.0934769179938095, 0.11821567373616354, 0.3965037023382527, 0.09342237734901053, 0.14006427063473634, 0.11097732678587947, 0.10594246124050447, 0.18374555957104477, 0.16019759885966778, 0.11067931420568909, 0.11910348252526351, 0.24513779314500944, 0.10935567558876105, 0.08477218901472432, 0.09304818564227649, 0.1585972604474851, 0.12766697444021702, 0.1164356456803424, 0.10534967947751284, 0.09045220565583025, 0.13599862450999872, 0.14388563058206014, 0.14064702365015233, 0.09977242017963103, 0.16390697338751384, 0.07751571160874196, 0.11785172112286091, 0.11073901171662978, 0.1922479969050203, 0.09696990770420857, 0.09236559976956674, 0.12651650474539824, 0.11173214271132435, 0.14521983398922853, 0.1191578060388565, 0.15987977305693285, 0.10323808528482914, 0.07472768585596766, 0.1575159877538681, 0.12595593982509204, 0.10031156374939851, 0.20295518450438976, 0.14605543629399367, 0.1319407815379756, 0.15294374738420757, 0.07782268085117851, 0.06621168460696936, 0.10212119628808328, 0.15226571448147297, 0.1409343153770481, 0.16028962177889688, 0.3123969797577177, 0.15398913914603846, 0.0649505662066596, 0.145632356139166, 0.1413583183395011, 0.2166587556047099, 0.1904228734118598, 0.15173638931342534, 0.1191386306392295, 0.19872934983244964, 0.08679501725626843, 0.07244855458182947, 0.13542303682437964, 0.09036189943019833, 0.121737094063844, 0.10191391062523637, 0.06859659270516463, 0.182719492486545, 0.08563635085842439, 0.16280013349439415, 0.12260228049542223, 0.10769342085612671, 0.15165063605776855, 0.14695446805230208, 0.1405187262488263, 0.12957396996872766, 0.1462540706353528, 0.14006397207932814], [0.021467568951525857, 0.012591909367724188, 0.017464434561718787, 0.058963241055607796, 0.04687764009992991, 0.08385903694267784, 0.032105186355433295, 0.0350870492069849, 0.08359875769487449, 0.0074916941147031525, 0.012476696666064007, 0.0269981467364622, 0.06750098935195378, 0.02955405753371971, 0.005700211115514061, 0.03285727117742811, 0.018424395372026732, 0.026470273633354476, 0.0625403623229691, 0.008955558778585067, 0.029576048853674104, 0.019000926221321737, 0.011574279018012541, 0.028399740545345203, 0.005560784467629024, 0.03820093122443982, 0.057505374641290734, 0.051982991863042116, 0.03556407289579511, 0.0085421078838408, 0.03835792047902942, 0.0007075246321619488, 0.04152715738330569, 0.08009493178022759, 0.07215293044490473, 0.06940838521612541, 0.06200636883399316, 0.008294196633089865, 0.05851610004901886, 0.017016635376161764, 0.05168038560077548, 0.017102190160325596, 0.026319840723382573, 0.04415682663342782, 0.018971236921580772, 0.03995018771716526, 0.09695460673953805, 0.029510271668966328, 0.01654087545882378, 0.06315994621919734, 0.04940214320751173, 0.02908946799912623, 0.030344516903694187, 0.03805374340819461, 0.10492546616920403, 0.047082500000085147, 0.021967951208353043, 0.035250230093619654, 0.01591537134455783, 0.022782517231202552, 0.019948625903842703, 0.045614211287881644, 0.03930003581834691, 0.07645551421280418, 0.0976507972393717, 0.01480633978332792, 0.03344563567744834, 0.0825146147981286, 0.046425057242491415, 0.025212873604946902, 0.017992974325482334, 0.04692151078156062, 0.03631984216294118, 0.01880005101806351, 0.006104495850325162, 0.012906113489797073, 0.044299105248813114, 0.04805683896743825, 0.036952508214328966, 0.0627881158143282, 0.012053595307017011, 0.014674534355955464, 0.04003597489957299, 0.023986920281978588, 0.0601092731314046, 0.038976608709033043, 0.067866855434009, 0.048508129215666225, 0.03984530655933278, 0.0314497792028955, 0.009320123769742037, 0.021667053157995855, 0.011313407748405422, 0.030773734407765523, 0.002575615666241252, 0.06838759713407074, 0.025630696809717586, 0.026404778040679436, 0.07091211381235293, 0.07540030404925346, 0.03735310511131372, 0.03192963916808367, 0.021237343716035997, 0.05014114248167191, 0.02278138916673405, 0.04171115233163748, 0.050638919164027484, 0.011549436154642274, 0.02996307165761079, 0.010743954019354922, 0.0488606654772801, 0.017708961619064212, 0.0370315134392253, 0.02446710764031325, 0.03580856263371451, 0.037454953217612844, 0.041843904315360954, 0.024947683459946086, 0.007212694933904069, 0.04540950405810561, 0.04104601837960737, 0.034097955495651276, 0.0313353205232748, 0.021489529737404416, 0.05066985357552767, 0.0259604241166796, 0.03296471380495599, 0.04185906278767756, 0.023112008747245585, 0.060751370819551606, 0.049963091500103474, 0.05375493178144097, 0.028101419231721332, 0.057832252101174424, 0.03149026060210807, 0.058373499129499705, 0.026381697672020112, 0.0469548098876008, 0.018924139805936387, 0.05431268417409488, 0.019675105045150434, 0.01312599954794028, 0.06131325209779399, 0.010675873208258833, 0.03724186947303159, 0.07837212458252907, 0.008539543869639081, 0.005602782392608268, 0.07808751306895699, 0.02154946473560163, 0.02163339782107089, 0.038110546967280765, 0.05933916981198958, 0.04257442868713822, 0.02104769996367395, 0.019482684388224567, 0.014342766354924865, 0.023699131528181688, 0.018266617320477962, 0.04168710844325168, 0.00507886302823733, 0.0551042258074241, 0.0401486218906939, 0.014628740027546883, 0.06940902982439313, 0.008698309189639986, 0.02280299541806536, 0.04498420170109187, 0.0283660326219563, 0.03599512244441679, 0.0319835419899651, 0.08013976258890969, 0.022479566612413952, 0.011517679867600756, 0.06933979211109025, 0.026205392221787145, 0.033724666240492036, 0.013086392610732998, 0.004970169351768813, 0.07173219802124159, 0.03607792407274246, 0.01715798270223396, 0.04675039442788277, 0.029528473370841572, 0.006102736748289317, 0.02327939655099596, 0.04696562573579805, 0.03556172516463058, 0.09192189215017216, 0.02437151562688606, 0.021873298965926682, 0.04800449338342462, 0.07116034906357527, 0.04678599376763616, 0.035086944034057, 0.06486963054963521, 0.034721390078110356, 0.02555633446068636, 0.05603957615260567, 0.04116828360461763, 0.010307211561926773, 0.029837447684258223, 0.013236956986864763, 0.07933602428862027, 0.03377803980505892, 0.030031997244805098, 0.04959108467612948, 0.03162746377555387, 0.011056895218124347, 0.033283462415316274, 0.011590806434729269, 0.024336613481864333, 0.03812753748414772, 0.013804360691990172, 0.02788060697327767, 0.04650846276698368, 0.03892796114087105, 0.08540400689733879, 0.04152927780523896, 0.036170181086553, 0.04384785910536136, 0.049317760592592616, 0.03315364170287337, 0.04213032751743283, 0.023685141832434704, 0.06519103901726858, 0.038662457173424106, 0.05245573399588466, 0.05926045974982636, 0.02212020428851247, 0.05167810572311282, 0.035412932613066266, 0.01645792624913156, 0.02262779767625034, 0.03197940631902643, 0.04957009419532759, 0.06456771639308759, 0.05285511292251093, 0.04494737082027963, 0.05714330156998975, 0.01775150915740856, 0.0046123006530771294, 0.02257600679461445, 0.047022951766848564, 0.04425801656075886, 0.03176498586045844, 0.04767351078667811, 0.05994175640600068, 0.024819145178688422, 0.04347473269860659, 0.0419674825056323, 0.05086005372660501, 0.027220901301396743, 0.08184829340981585, 0.03424475993961096, 0.05635445032800947, 0.030756886383252482, 0.020033644645341804, 0.019196430819907358, 0.03852667553084237, 0.03029568273840206, 0.049225734280688424, 0.07655331825039216, 0.027134143813912357, 0.04893576234046902, 0.0371113837962704, 0.07895297769989286, 0.01942399110911148, 0.013304032717964478, 0.03938785182046039, 0.027585384868351475, 0.0021803781356928603, 0.06668689660727978, 0.0440500082581171, 0.03798517065921, 0.04458355052130563, 0.030590825115463564, 0.05700949446431228, 0.06182686918015991, 0.03722553374245763, 0.0394253985557173, 0.04520740918815136, 0.026852470356971025, 0.0553205495567194, 0.03650130617565342, 0.04151082843808191, 0.02295199831548546, 0.020340927710224475, 0.021985981580136076, 0.017822198935651352, 0.013195713932093765, 0.06600239726581744, 0.015770792495459318, 0.01796066079155675, 0.031187712015318017, 0.03829546133056283, 0.011686361976899207, 0.041848362290433476, 0.03207569383084774, 0.01682711884911571, 0.00294236426790511, 0.06384034042379685, 0.031596844882837365, 0.06136393187833684, 0.006103794838834021, 0.038810204781059704, 0.022883568058854768, 0.06656457031411783, 0.11590060724743775, 0.02036829642020166, 0.03766471553327782, 0.04656837401645524, 0.06579112181706087, 0.02082530502229929, 0.016716928154762303, 0.011307953175024262, 0.03664677729830146, 0.021838922685544406, 0.047645745133715015, 0.03916322958788701, 0.05627919740176626, 0.033411797136068344, 0.10773157488022532, 0.042983931356242726, 0.05349051347002387, 0.02278398795585547, 0.04445770263139691, 0.020781281670289378, 0.033637186113212786, 0.038761981297284365, 0.058813318743237426, 0.0546459703972297, 0.050231811723538806, 0.03425807958202703, 0.02043528818259282, 0.05930842539029462, 0.06307751778513193, 0.03674201647351895, 0.0591039081503238, 0.015908524926219667, 0.043132954609713385, 0.0047746007164408055, 0.015142852440476418, 0.01581877509930304, 0.04165099002420902, 0.029235794075897763, 0.06931906286627054, 0.02642758020998112, 0.08108301447438342, 0.038655726106039116, 0.08078036750001566, 0.014700579922646284, 0.12005937551813466, 0.07912084047815629, 0.07506605769906725, 0.22349815789077962, 0.13328624862645352, 0.16430216575307505, 0.1255055418504136, 0.12717548438480922, 0.22271522347416195, 0.11151984267468963, 0.1283693124673196, 0.19668652516390595, 0.19596658593841962, 0.10104263773454086, 0.10305509117564984, 0.14976449869573116, 0.144107905083469, 0.14078340918890067, 0.06527536056403603, 0.23944244161248207, 0.06800643687269517, 0.08170014207384416, 0.19511472593460763, 0.18125544461820806, 0.0620677491117801, 0.132725453004241, 0.10097025840410165, 0.18088833003171853, 0.08769204055092164, 0.07643637952527829, 0.1430375160915511, 0.13268384523689747, 0.17200579095099652, 0.13149393908679485, 0.12119318039289542, 0.1098307790234685, 0.16673654583948, 0.08363767846354417, 0.17507028579711914, 0.10084437658744198, 0.19417997609291757, 0.16656095454735415, 0.09502477172229971, 0.10282730696988956, 0.09582098506923233, 0.12719088712973253, 0.2046182874057974, 0.06366695437048163, 0.07179608209324734, 0.16966540153537477, 0.13568558916449547, 0.16640145810587065, 0.09861668505306755, 0.12567604412989958, 0.16151292542261736, 0.16830141044088773, 0.09237487534327166, 0.15838591035987648, 0.16276897516633781, 0.09188161431146519, 0.13746017536946706, 0.11877668648958206, 0.14650231945727551, 0.19335529820195266, 0.22105019353330135, 0.1046864657795855, 0.09416595673454659, 0.2214587123266288, 0.08859745053840534, 0.11145538184791803, 0.10143650017146554, 0.1270135316465582, 0.17840437617685112, 0.07082644198089838, 0.08905367712889399, 0.13046964976404393, 0.1607694953147854, 0.22189104769911083, 0.13595095063958848, 0.16070118040910789, 0.054922531092805524, 0.1150895543396473, 0.12510956238423074, 0.07640310416796378, 0.1492294738335269, 0.12843451968261174, 0.15304232495171682, 0.16791672179741518, 0.10150711531085627, 0.09708106531096355, 0.15576076693832874, 0.09371825932924237, 0.1491552692438875, 0.08846888850842204, 0.12420510234577314, 0.12908196422670568, 0.14176647072391851, 0.11740782351366111, 0.17617110029927321, 0.1362464390695095, 0.1856128472302641, 0.1343035897506135, 0.10862420126795769, 0.111365835581507, 0.07756447792053223, 0.18018396997026034, 0.10054704932762043, 0.08230522567672388, 0.09859862923622131, 0.12250121948974473, 0.14881707381989273, 0.0878075339964458, 0.10604755274419274, 0.1090592507805143, 0.1905360666236707, 0.1295736985547202, 0.11120408640376159, 0.14629004656204156, 0.07112885146800961, 0.10328249540179968, 0.09534812758543662, 0.1233474069408008, 0.1832284073212317, 0.12392697084162917, 0.11672375164926052, 0.1584522303725992, 0.13676057862383978, 0.20430742337235383, 0.05556912746812616, 0.1550141612866095, 0.12547257861920766, 0.1716162847088916, 0.19831829331815243, 0.11756216308900289, 0.08768008476389305, 0.19352080646370137, 0.15565836243331432, 0.11420013063720294, 0.11675922546003546, 0.18386878153043135, 0.13123065392885888, 0.11301489959337882, 0.18747710862330028, 0.08613235995705638, 0.14412139435963972, 0.17254590482584067, 0.17090817913413048, 0.10387124666678053, 0.16426373352961882, 0.12311770926628794, 0.17316289671829768, 0.09704577470464365, 0.15826625749468803, 0.10487367359123059, 0.1302699569080557, 0.0880540254126702, 0.11273826086627585, 0.11206600908190012, 0.08891630092901842, 0.17261952587536403, 0.17842569574713707, 0.18268112811659062, 0.2133822457066604, 0.06375531320061002, 0.19303306192159653, 0.04830695376066225, 0.09332402369805745, 0.1371306109109095, 0.14745636683489594, 0.11033400094934873, 0.10359743064535515, 0.211587981986148, 0.13980751298367977, 0.11469725253326551, 0.20194374663489206, 0.08493205186511789], [0.03996093571186066, 0.04681700621066349, 0.03126921085640788, 0.042505197759185515, 0.010114808716545147, 0.026353818364441395, 0.02000330395198294, 0.09122923003243548, 0.04528375794844968, 0.021676354176763977, 0.05965806091470378, 0.059976572037807534, 0.08498808528695788, 0.014658753327759249, 0.03927774255030921, 0.034492588069822104, 0.0488416936381587, 0.01875419562150325, 0.03831957646512559, 0.017210638716018627, 0.05315358012116381, 0.010364837844723036, 0.04981783750866141, 0.02806429997352617, 0.03775603277608752, 0.028662638938320533, 0.03664715388523681, 0.041223859015320025, 0.0517500066863639, 0.030466103593685796, 0.015489889175764151, 0.05378407486049192, 0.04914242375109877, 0.019643670214073997, 0.007153929560445249, 0.009487827940444862, 0.025180941746969308, 0.0311698495809521, 0.021861609503892914, 0.057487040625086853, 0.08017616599266018, 0.016591784244935428, 0.0205926845581936, 0.049126020167022943, 0.0332260651380888, 0.010063106892630458, 0.03527981761310782, 0.05348265264183283, 0.01350546007909413, 0.03055310874645199, 0.021831682716895427, 0.019938956779826964, 0.016818808491474817, 0.02915043437055179, 0.026456663917217935, 0.007776730560830661, 0.0277072158309498, 0.018571659523461546, 0.036484909376927784, 0.02497902499245746, 0.03434712373252426, 0.025305917719379067, 0.035766167765749354, 0.03949567782027381, 0.05217888831560101, 0.01671703502402774, 0.06087734763111387, 0.03600770926901272, 0.03904371242970228, 0.0493651087661939, 0.09128658659756184, 0.045913852352116785, 0.01233703549951315, 0.04247650929859706, 0.05671568201588733, 0.025229071932179586, 0.03852719800280673, 0.021045725426769683, 0.05544562052403178, 0.021939484967983196, 0.04130398043032203, 0.06791218157325472, 0.015349569830245205, 0.016334800980985165, 0.07231231153543506, 0.025820308331666247, 0.029040467592754533, 0.033271004512373886, 0.04008768605334418, 0.0326515461451241, 0.03564569726586342, 0.04572779805000339, 0.0304809635105942, 0.04540943281192865, 0.058916713909379075, 0.10238773841410875, 0.08144126739352942, 0.010991751615490233, 0.021882810330550586, 0.035642786350633414, 0.031656298121171336, 0.018556117678859403, 0.027870805534933294, 0.13583265484443732, 0.09505418621535812, 0.0869092418413077, 0.0974877452743905, 0.015599467492263232, 0.017612487510112778, 0.025402980457459177, 0.03765719057992101, 0.03576908546632954, 0.03826193491529141, 0.04803875940186637, 0.02852742387247937, 0.02940663562289306, 0.02619605727626809, 0.04438941486712013, 0.03852238718952451, 0.031659232785126994, 0.022283994160326462, 0.03961077432281204, 0.0228108816913196, 0.08543025263186012, 0.016932573369038955, 0.03994460337396179, 0.012394069760505642, 0.04659173258447221, 0.06436777247914247, 0.04860362284151571, 0.033371200385902605, 0.032792501617223024, 0.03742397470133645, 0.07140953426382371, 0.04474048210041864, 0.08119179042322294, 0.03620607898171459, 0.046261815287704976, 0.08480134566447564, 0.06270285788923502, 0.0224547169636935, 0.05494806097288217, 0.04101612212668572, 0.01153329635105495, 0.022907959696437632, 0.03316339225109134, 0.0330089916075979, 0.05885345408959048, 0.047796434190656455, 0.0029516992134241654, 0.02320244050185595, 0.020451532310939262, 0.016673627442547252, 0.013395076850429177, 0.02897589820037995, 0.02519128262065351, 0.020852594004411782, 0.026313096085297208, 0.029082608010087694, 0.016083366437149898, 0.04106616069163595, 0.02458869433030486, 0.04576495462762458, 0.055399595493716855, 0.020702183146827986, 0.040978965549064536, 0.016977024198110615, 0.04023774407271828, 0.021482861434508647, 0.06091499275394848, 0.0533661447864558, 0.01611987331749073, 0.015859166592625634, 0.07890376355499029, 0.012972006873626794, 0.04565377666481903, 0.02840441565162369, 0.02510542419206883, 0.04878542272906218, 0.053316706724997075, 0.018837155009220754, 0.04277120044987116, 0.03414937827203955, 0.02664003800600767, 0.02722259933528091, 0.12638908943959645, 0.07759927998163871, 0.04596235742792487, 0.06313311694455997, 0.05820452355380569, 0.04748034204489418, 0.038159784860908985, 0.008883565364937698, 0.02706999341691179, 0.05685108028618353, 0.01857357468855168, 0.018038280108677487, 0.013468110118992627, 0.020239320483856967, 0.04927862608539207, 0.04496884306094476, 0.042059807372944694, 0.04449523240327835, 0.0604426238153662, 0.056049774533935955, 0.040439693057643514, 0.04806965649394052, 0.054220288060605526, 0.08915024623274803, 0.01142049499321729, 0.02047395789330559, 0.060998920750405104, 0.01622419129125774, 0.019715284496279697, 0.036162825766950846, 0.025155187950336506, 0.017649961302855184, 0.01844479892003749, 0.011850824446550437, 0.07942696833716971, 0.024818434413256388, 0.03471327140661223, 0.030708021683884517, 0.03289448543052588, 0.07136338709720544, 0.014147178635799458, 0.026596001083297387, 0.008685983601026237, 0.01784648879298142, 0.032510780662830384, 0.025588452915794084, 0.013961797779692071, 0.03317842858710459, 0.03540461038106254, 0.0477400818573577, 0.03769507997536233, 0.024810916245249764, 0.009650247171521187, 0.0480163541755506, 0.0461450835157718, 0.021656227131773318, 0.03482264446626816, 0.045447627548128366, 0.03265884718192475, 0.016920498838382106, 0.04617861332371831, 0.03397279631878648, 0.00854159558990172, 0.0443600614422134, 0.034290849430752654, 0.023418506407844167, 0.01909139529535813, 0.018861010604138886, 0.017997355965365256, 0.03225366338821394, 0.01010777654924563, 0.016526502390791262, 0.014461513375863433, 0.036219785389091284, 0.07713882611798388, 0.011370050155424645, 0.06394334203962769, 0.03282069813992296, 0.05618778855672904, 0.025934042675154548, 0.028038529213517904, 0.026893701537379196, 0.04272838828286954, 0.01089502899308822, 0.06971818394958973, 0.04367431698899184, 0.07935165095009974, 0.02855184774047562, 0.05802315792867115, 0.02927292011944311, 0.036087484631155214, 0.07398724808756794, 0.017401174741930196, 0.02565372289557542, 0.06687056246612753, 0.08049511816352606, 0.05543157824182084, 0.06285105672265802, 0.024986029170187454, 0.036158557781683545, 0.0389136745860534, 0.044694043163742335, 0.07557811415089027, 0.016503618797287345, 0.02324274887463876, 0.023680807690003088, 0.027700260847008655, 0.03646298251780016, 0.022246937666620527, 0.012550859695433505, 0.034787889902612994, 0.023714208576296057, 0.03102138272619673, 0.04256554666374411, 0.09099493867584638, 0.01230911717617086, 0.05321460077539086, 0.03610652771645358, 0.02402930157924337, 0.0262605876528791, 0.027657966062958752, 0.03010046821353691, 0.04954392649233341, 0.04139936888324363, 0.026994077222687856, 0.008315589994059076, 0.05341280763968825, 0.024409189587458968, 0.057123101582484584, 0.02918954173635159, 0.046699853747018745, 0.0276145415181028, 0.01994015439413488, 0.036372442197586806, 0.026604275817849805, 0.03476281464099884, 0.009642016541744982, 0.019465045870414803, 0.024006341650549854, 0.022613129445484707, 0.011409171940093594, 0.03616023037050452, 0.06536595177437578, 0.03257034246676734, 0.04401227831840515, 0.018356319649943283, 0.018592068160484945, 0.008721546469522374, 0.03591230046004057, 0.04787976507629667, 0.041080243685947995, 0.01495955468687628, 0.03228210757619568, 0.07561866340360471, 0.06984196909304176, 0.025081841707495705, 0.04793524888477155, 0.02356205049103924, 0.003730433710318591, 0.013944776728749275, 0.03673966195700424, 0.03831970877945423, 0.0054206224574175265, 0.010134873845215355, 0.0440452890470624, 0.02240993025978761, 0.007085579455763633, 0.19511674796896322, 0.15811532416513988, 0.17206638412816183, 0.10414468270859548, 0.0695441940001079, 0.13610022834369115, 0.06291840810860906, 0.1516977942415646, 0.21622378751635551, 0.29570124564426287, 0.19194585883191653, 0.14757154136896133, 0.1996818230088268, 0.13113856315612793, 0.17450632820171968, 0.1966330294630357, 0.12005763846848692, 0.08847172478479998, 0.16403010035199778, 0.15960370429924556, 0.10875636631889002, 0.16038929857313633, 0.14446229035300867, 0.06773824590657439, 0.18598670645483903, 0.1309673823416233, 0.10458740645221301, 0.15105447519038404, 0.15481027508420603, 0.07143641782126256, 0.143292102430548, 0.16150714430425847, 0.1639556379190513, 0.127613668729152, 0.0957168231585196, 0.10493710983012404, 0.1386624037155083, 0.11165888128536088, 0.11342866346240044, 0.1248109255518232, 0.16833448223769665, 0.10591544876141207, 0.11898076268179075, 0.13302497193217278, 0.09595362509467772, 0.07675192545035056, 0.10354947857558727, 0.11343021730759315, 0.16529730521142483, 0.14959574703659329, 0.09640599082091025, 0.17794305378837244, 0.09074642522526638, 0.12482446911079542, 0.1556950711778232, 0.06617040932178497, 0.13805359495537622, 0.08815360042665686, 0.1276307270995208, 0.12940217847270624, 0.15848878983940395, 0.10958970910204308, 0.14423363762242453, 0.17986649700573512, 0.1057337031566671, 0.1651363159929003, 0.1322120191263301, 0.14220238876129898, 0.11454523354768753, 0.11550386782203402, 0.14540662110916205, 0.08339003353778805, 0.10306129977107048, 0.10927605628967285, 0.15369944540517672, 0.07939928410840885, 0.12688452856881277, 0.15761149834309304, 0.18148690648376942, 0.09333109403295176, 0.08611396487270083, 0.16940690683467047, 0.10673693753778934, 0.1653492267110518, 0.13197419260229382, 0.1541263796389103, 0.11344591860792466, 0.10861039986567837, 0.07831337702061449, 0.07400028274527617, 0.11325604415365628, 0.11911618470081262, 0.15680237247475556, 0.1641044406486409, 0.1572268232703209, 0.2507814945919173, 0.21425505887184823, 0.11024651742939438, 0.11502558205808912, 0.12073139660060406, 0.20102874216224464, 0.08600070380738803, 0.12278164444225174, 0.23250691805567059, 0.17479629335658892, 0.14511373825371265, 0.22122172718601568, 0.10418035329452582, 0.056532857540462694, 0.12146511008696896, 0.06039912972067084, 0.17200371463383946, 0.11018914729356766, 0.18035315589181014, 0.06655150172965867, 0.11415665011320796, 0.1657733382391078, 0.10235259708549295, 0.18246939804937157, 0.125011839770845, 0.1604454405605793, 0.14992276020348072, 0.12592722422310285, 0.20464503525623254, 0.0619903350515025, 0.1522204697664295, 0.1421991182225091, 0.1442188998418195, 0.16521016774433, 0.11971244056309972, 0.15585960234914506, 0.14924797069813522, 0.190243536606431, 0.14232611283659935, 0.09762468042650393, 0.10222288154597793, 0.09364319300012929, 0.1330065836331674, 0.2133235524275473, 0.13471299063946518, 0.08999205713293382, 0.1266139152326754, 0.11402884125709534, 0.09919516329786607, 0.15392285984541687, 0.09750194701233081, 0.08896474832934992, 0.18716657028666564, 0.09369556911821876, 0.08510480009551559, 0.16935681737959385, 0.10312500063862119, 0.08988836341138397, 0.08888293736215148, 0.09401965101382562, 0.12694749661854335, 0.07833880172776324, 0.12896873030279363, 0.10245504230260849, 0.10558277661246912, 0.0766060132799404, 0.09457775285201413, 0.07889409443097455, 0.237684465944767, 0.06670964110110487, 0.1205935182848147, 0.11195385402866773, 0.07948890501367194, 0.09396791271865368, 0.168802997097373, 0.13393551164439746, 0.06497096975467034, 0.13971589718546185, 0.1258798896202019, 0.14345062178160461, 0.09535899093108517], [0.02050508568728609, 0.04220237436571291, 0.012234696303494275, 0.03433777012729219, 0.04694091009774378, 0.023289352356057082, 0.012096763704903424, 0.026414102808173214, 0.03514605121953147, 0.009372405741097671, 0.03132495590086494, 0.03239961287805012, 0.0400207078616534, 0.020853822152795534, 0.07189405576458999, 0.029927747124539952, 0.03562250154625092, 0.04600478622264095, 0.03255584556609392, 0.014107399520331194, 0.032319220049040656, 0.04469726620508092, 0.028090384555980563, 0.0347219193354249, 0.04706430847623518, 0.025484733749181032, 0.06827302649617195, 0.04437379159831575, 0.03713300870731473, 0.015528270509094, 0.02732132957316935, 0.03874266340530344, 0.005802329363567489, 0.0221111526313637, 0.04770661651023796, 0.10050844747040953, 0.018005254112982323, 0.06635444837489299, 0.06013516602771623, 0.022123081276991537, 0.041387633620096106, 0.048704314045608044, 0.035262145168547115, 0.02463272786034005, 0.03760245655264173, 0.05508938963924136, 0.0051160263912087035, 0.044942349661141634, 0.054810023201363425, 0.02472892546627138, 0.031997051622186384, 0.03893244965001941, 0.06503402601395335, 0.012075644302447992, 0.06252075944628034, 0.06641512297626052, 0.05329983834443348, 0.04164373648485967, 0.018626646305035268, 0.03395829602543797, 0.031823431474289725, 0.05809139141014644, 0.013242928095028868, 0.08028078930718557, 0.023888475028797984, 0.02565623856415706, 0.02037362800911069, 0.01687206161607589, 0.028192205520878946, 0.03353206407544868, 0.029316085124654428, 0.049340393128139634, 0.06552610639482737, 0.021310043654271534, 0.04322880107377257, 0.025973360386810133, 0.010353023701879596, 0.032985507510602474, 0.020991295043911253, 0.12585291106786045, 0.09471400946910892, 0.01092636289208063, 0.012294073206638651, 0.018787328486463854, 0.01833945805472987, 0.028420217035870467, 0.036391017093722305, 0.04655540381957378, 0.010560729208269289, 0.013186672452970274, 0.01348399292744164, 0.04314567714131304, 0.029095042164304426, 0.030766358732112815, 0.03330233586685998, 0.08270181582442351, 0.04597443874393191, 0.027961020158337693, 0.08970312335129295, 0.06719539753560509, 0.014797389906431948, 0.08697056105094296, 0.0492286078764924, 0.008004809929324048, 0.013642161136626132, 0.02721865026147238, 0.04215294648227947, 0.034615911809461455, 0.02477296069264412, 0.019028890345777785, 0.04296655746709023, 0.027726379356213977, 0.05598989721121533, 0.03308216482400894, 0.045509621900107176, 0.04752335098705121, 0.07306773135704653, 0.051088882876294, 0.05409984130944524, 0.014178555791399308, 0.07033548796815531, 0.07130599660532815, 0.011186644684390297, 0.03149886442614453, 0.03167356005204575, 0.1055037679948977, 0.052967624206628115, 0.041326470473515134, 0.037835227990789075, 0.08098421299031802, 0.036676273215562105, 0.0368856725149921, 0.03264536129842911, 0.013960876668404256, 0.030792536613132273, 0.034717342616724114, 0.05427576169105513, 0.028532631628747498, 0.0312971156090498, 0.03356959724000522, 0.023324517433398535, 0.054692880915743966, 0.04454609538827624, 0.02309343554744763, 0.08176579033689839, 0.013172044086136987, 0.1013267267761486, 0.01144524964703513, 0.04534189822152257, 0.023846022485356246, 0.020072309267041937, 0.04988993524706789, 0.053144932192351134, 0.09057955310813018, 0.0681603014735239, 0.02653439179994166, 0.025403112771787813, 0.055119706583874564, 0.036552220050777705, 0.014699779251324279, 0.011381865994605635, 0.03285464185423084, 0.031361294843788655, 0.0493688746355474, 0.031707853211888244, 0.047184924861150127, 0.03622385320652809, 0.06657645146229438, 0.030684496874787977, 0.05452425817825964, 0.028542643412947655, 0.03763227816671133, 0.027329086924770048, 0.009429294965229928, 0.028566015551665, 0.021534111184467162, 0.030145543294825723, 0.06334688261683498, 0.07281649698104177, 0.01715135171876422, 0.04304654996043869, 0.021668055693485906, 0.0677175030910543, 0.04899374994316271, 0.04120575570102249, 0.0365919347054192, 0.02425662098851587, 0.04174383397081068, 0.03449971268751791, 0.03247910664815988, 0.0765382886997291, 0.030406297517142127, 0.03194835655657308, 0.049434210772493055, 0.07445157638617925, 0.018835658839504634, 0.026237871996792297, 0.02983221278658935, 0.05699783044734171, 0.0940867309857692, 0.026071651273273995, 0.04458839526133878, 0.10838103467332465, 0.04728426578055535, 0.03860039836061852, 0.006999613733829132, 0.037194565404206514, 0.053846635789211304, 0.06298195291310549, 0.026726946467533708, 0.05267859882275973, 0.05530286014878324, 0.03957307830985103, 0.028286767857415334, 0.08994891587644815, 0.03510443327416267, 0.006338745646644384, 0.07186955386506659, 0.01457053529364722, 0.02933750647519316, 0.031971609951662164, 0.08337235770055226, 0.011809379527611392, 0.02517787307234747, 0.0850137203399624, 0.06149939460945981, 0.05776220014584916, 0.026736737727852802, 0.04337600585339325, 0.027333706051909497, 0.04346050721194063, 0.05101897341332265, 0.11944243790847914, 0.06128303014806338, 0.05694320159299033, 0.03657858452892729, 0.00471716484753415, 0.011942625993729701, 0.07686743246657507, 0.019147740843306695, 0.020008949363338094, 0.04901898466050625, 0.012222273175471594, 0.10464199459446327, 0.029057074737335955, 0.017652666961242045, 0.04927126058776464, 0.04482731083407998, 0.052457596574510844, 0.05085068655067256, 0.07114235431488071, 0.039573780593595335, 0.008819937439901488, 0.022768537713480846, 0.01012290533565517, 0.05441944148125393, 0.047992418852767775, 0.06872503259884459, 0.01410630707895117, 0.055574582889676094, 0.03617587399535945, 0.030932043412966386, 0.022822854441723654, 0.04844458780384489, 0.04600368360323565, 0.030430039457444633, 0.06379750450806958, 0.026050752394699624, 0.016539121445800577, 0.05120629318324583, 0.10071366360144955, 0.05094352710459914, 0.027194979567346827, 0.021624897473624775, 0.014048792754432984, 0.03073440651808466, 0.014904208281742675, 0.07545652067554848, 0.05879220273345709, 0.07592215176139559, 0.05428919668442436, 0.02927916942696486, 0.061573097083185396, 0.023441642755642533, 0.013765918290508645, 0.007926244904021067, 0.041708590861942084, 0.04185242332252009, 0.017180442211351225, 0.03412971093452402, 0.03666148454483066, 0.036241600289940834, 0.06000030040740967, 0.029452348527099406, 0.016813456546515226, 0.029564255915049995, 0.009112916986591049, 0.034839618019759655, 0.01695134673666741, 0.018170346772032123, 0.059910387732088566, 0.03564109679843698, 0.0496912262668567, 0.011582342558540404, 0.021642522420734167, 0.05319352887038674, 0.04453711836997952, 0.03675148542970419, 0.04358425164329154, 0.04448958020657301, 0.052997768124831576, 0.05008365699489202, 0.05721980639334236, 0.05206098607076066, 0.022261146189911023, 0.026396415096574595, 0.04232547418879611, 0.014812451687508395, 0.017522722416158234, 0.011579592795377331, 0.052544533873775175, 0.061186651034014564, 0.049356033360319476, 0.01974900090135634, 0.026532837954748954, 0.07590744790754148, 0.037797711789608, 0.02801043277473322, 0.04272923305896776, 0.025524697765441876, 0.012428064364939928, 0.031103549924279963, 0.046148744212197404, 0.02568751054682902, 0.019421679001035433, 0.02670923839988453, 0.04763745004311204, 0.023486688999193053, 0.032516510891062875, 0.07534062010901314, 0.04573446465656161, 0.06252071873417922, 0.05688436242884823, 0.095767631860716, 0.010745870880782604, 0.019111593586525748, 0.023859445604362657, 0.04422292272959437, 0.02373234412100698, 0.032645666639187505, 0.0054966688455481616, 0.028497174781348025, 0.10299867098884923, 0.1589580646583012, 0.1444904495562826, 0.15746146067976952, 0.12486329488456249, 0.09925908129662275, 0.15889217890799046, 0.15385822259954043, 0.08910779708198138, 0.09279942113373961, 0.13128793585513318, 0.13666934280523232, 0.1848643145390919, 0.12678596457200392, 0.16919736165021146, 0.08954331478370087, 0.09510298645389931, 0.13627668816064084, 0.24263701162167958, 0.09180961496063642, 0.12377143704465457, 0.15118345112672874, 0.19735196445669445, 0.07666120531835727, 0.14904625580779143, 0.12031341902911663, 0.28276958955185755, 0.13421031832695007, 0.141983601929886, 0.16496109110968454, 0.09355321925665651, 0.10850300812827689, 0.12529014769409383, 0.163292098524315, 0.15770410480243818, 0.14043872697012766, 0.15204649338764803, 0.13268324812608107, 0.15982601951275552, 0.12688347005418368, 0.15803421208901064, 0.1605691374944789, 0.1341184853975262, 0.15710475482046604, 0.1527733943824257, 0.21957538409956864, 0.13320418660129818, 0.08056279524628605, 0.14533080160617828, 0.21696104295551777, 0.19919578837496893, 0.17458446829446725, 0.17597158386238984, 0.14044574302222046, 0.11594908178916999, 0.18037964589893818, 0.18413157814315387, 0.12821542072509015, 0.10716822118099247, 0.1369769498705864, 0.14977907362793172, 0.14402523237679685, 0.14303685112723283, 0.09674799282635961, 0.12366486633462564, 0.15295184909233026, 0.1668996385165623, 0.19409836190087454, 0.15360747676874908, 0.0989030132602368, 0.13866990831281456, 0.15153419944856847, 0.1903653743543795, 0.08592303190380335, 0.11967518899057593, 0.13872324116528034, 0.15220020871077264, 0.18065576893942698, 0.12867396111999238, 0.20851196561540875, 0.13768022427601473, 0.16598327697387763, 0.10749024711549282, 0.14405759849718638, 0.08264388250453131, 0.1101514750293323, 0.12778301749910626, 0.19877185326601776, 0.1656517040516649, 0.19041464956743376, 0.11239889836204903, 0.1833057196012565, 0.15955072428498948, 0.13237976655364037, 0.09063666540064982, 0.14060795360377856, 0.09560368422951017, 0.08304810617119074, 0.22408639346914633, 0.09749513452074357, 0.06517347174563579, 0.16383591720036098, 0.166782319811838, 0.09163353512329714, 0.09129936341196299, 0.05006360289241586, 0.15999212488532066, 0.11708264239132404, 0.10805576534143516, 0.08406131501708712, 0.1609340671982084, 0.12485397181340627, 0.06370612619710819, 0.12246537927005972, 0.13228247820266656, 0.1551828450922455, 0.14913173764944077, 0.1358246209898165, 0.1520961078682116, 0.09476056375673839, 0.1859718465379306, 0.1265960019081831, 0.09436793625354767, 0.20776981115341187, 0.15151422337761947, 0.18924767790096148, 0.1265232493834836, 0.09609029561813388, 0.08737320373100893, 0.11269137409648725, 0.09491274559072085, 0.10983703511634044, 0.20620132317500456, 0.09986871108412743, 0.17305422254971095, 0.13217901518302305, 0.13929398411086627, 0.08148499219013111, 0.1022263081478221, 0.13185871951282024, 0.11931300056832177, 0.10380266713244574, 0.15537043288350105, 0.07037432052727256, 0.19453666838152067, 0.15463378812585557, 0.16256354190409184, 0.12529926720474446, 0.1202140815023865, 0.20271676086953708, 0.13079298527113029, 0.1856010000088385, 0.1902508105018309, 0.12210557929107121, 0.12334401426570756, 0.1338827759027481, 0.07671270612627268, 0.10641993276242699, 0.15191299840807915, 0.10645563727510826, 0.08465343181576047, 0.07249853547130312, 0.10872499764497791, 0.11177537217736244, 0.1193893493286201, 0.12958733710859502, 0.10398576980722801, 0.21259091102651187, 0.05503962927364877, 0.1730064536843981, 0.10587851610034704, 0.13109447195061616, 0.10884135961532593, 0.09217390684144837, 0.11194955890199967, 0.09871572402438947], [0.001004220695384512, 0.02097504073753953, 0.05995041451283863, 0.04147897121895637, 0.015456510341859289, 0.046499668953142, 0.04889534540208323, 0.037083706352859735, 0.03262671176344156, 0.08497836188014064, 0.008218740146341068, 0.07779914247138159, 0.048731594546032805, 0.020421875241611685, 0.013727686234882899, 0.022052349090310078, 0.07438286114484072, 0.022749606586460556, 0.02666915563999542, 0.023415195156953166, 0.059627397917211056, 0.050582617720855136, 0.027632405648806264, 0.030089465768209527, 0.04768386183838759, 0.003733110106882772, 0.051819576881825924, 0.04544630779751709, 0.0037614232527890374, 0.06011075912309544, 0.04398941508095179, 0.006491171329149178, 0.0275914221336799, 0.08809575531631708, 0.0038132891973613626, 0.05072205666718738, 0.04466339712962508, 0.04023420211992093, 0.045893855925117216, 0.040806922995086224, 0.02202434595009046, 0.013107804631415223, 0.03550736093893647, 0.056520813543881686, 0.040568852198443243, 0.006291099341719278, 0.0757283621600696, 0.05081778099494321, 0.0124841809073197, 0.04357780895328947, 0.004367427966956581, 0.0096276740077883, 0.03625852973865611, 0.021577450912445784, 0.08717893915516989, 0.04456673303086843, 0.0473698901145586, 0.021148408131141747, 0.023009544870417033, 0.06755730775850159, 0.045509265669222386, 0.011417865670020027, 0.05110206002635615, 0.06286940430956227, 0.04442884114437869, 0.021526623550536375, 0.08388257532247476, 0.016013614733570387, 0.07196464376257998, 0.03952909227726715, 0.023869226686656475, 0.028133401979825327, 0.013442834689547973, 0.04958687097366367, 0.070980449074081, 0.028828907159290144, 0.030678312028092996, 0.002644124378483476, 0.06341437649513994, 0.04154619707592896, 0.06268447637557983, 0.02396904258057475, 0.04195816621982625, 0.018523641296529343, 0.04490692674049309, 0.03576909903702991, 0.01500592237737562, 0.03205208081219878, 0.03273979301697441, 0.07163041098309414, 0.04660095048270055, 0.020276860433763692, 0.006094793223642877, 0.0449968360231391, 0.035636241880378554, 0.008588506108415979, 0.033391122174050124, 0.02567546485391046, 0.0485282240302435, 0.019625192009178654, 0.02659260162285396, 0.06668199079909495, 0.041121976982269964, 0.031081083629812514, 0.06257126280771834, 0.01500530491050865, 0.04502895447824683, 0.03408637290288295, 0.02493885063034083, 0.011961220397746988, 0.022621709520795515, 0.05085738029863153, 0.015422320658607143, 0.013953615495535945, 0.024960942034210478, 0.03826466601874147, 0.014450536375599248, 0.0390503281461341, 0.052936231783990345, 0.01800257050698357, 0.00015777259146229232, 0.05950640833803585, 0.03141400344403727, 0.018110113218426704, 0.020863250396879654, 0.013484995462931693, 0.017077028385496566, 0.037611637131444046, 0.03401635826698371, 0.03701425829370107, 0.034294028367315016, 0.03063758635627372, 0.03994476282969117, 0.01630876898499472, 0.006099830497987568, 0.03796205297112465, 0.024244931526482105, 0.03117838894416179, 0.014390077209100127, 0.039449293166399, 0.03466481722093054, 0.015797626859109317, 0.0668359368241259, 0.03351893103016274, 0.09361478273889848, 0.054735662548669746, 0.02945389219426683, 0.0188938856257924, 0.05220838423286166, 0.03272743010893464, 0.019427142904273102, 0.029411934981388704, 0.06919838541320392, 0.06908791991216795, 0.006124264968093485, 0.0554587603546679, 0.034224665125033686, 0.04858942449625049, 0.005317936360370368, 0.017695942228393893, 0.034327344436730654, 0.01269410946406424, 0.009928955430431026, 0.03884712387142437, 0.001089970240302916, 0.046103943937591145, 0.03003949166408607, 0.0038332436400066528, 0.025761226591254984, 0.016791248095354865, 0.06809870406453099, 0.017918084415474107, 0.011463319882750511, 0.008899918907055897, 0.047648381242262464, 0.024059004449684705, 0.08500528614968061, 0.04625304522258895, 0.04019549508978214, 0.017457944374265413, 0.029209714582456008, 0.019036798671420132, 0.0227653485988932, 0.01304679415521345, 0.00878342122970415, 0.06070223809885127, 0.009823272753107761, 0.08315609501940863, 0.043256498873233795, 0.01416820813236492, 0.043695955470736535, 0.04397598348025765, 0.03065965910043035, 0.00871474585229797, 0.03314731775649956, 0.02184348413720727, 0.028446905514491454, 0.06150176948202508, 0.05006733822769352, 0.032609487151993174, 0.02462515710586948, 0.031065565533936024, 0.016201869185481752, 0.052373451446848254, 0.01918342330359987, 0.0401749795834933, 0.0822297182998487, 0.017026584395872693, 0.04191394948533603, 0.09390390651034457, 0.03391330236835139, 0.014328756303127323, 0.00762181677522936, 0.024275757372379303, 0.03964003275281616, 0.04568505034382854, 0.02990103659353086, 0.011921784790631915, 0.039474195401583395, 0.06368507125547954, 0.034736609618578634, 0.02906847412564925, 0.03946932012747441, 0.029397580573069196, 0.010331707524268754, 0.028643952083906958, 0.0237804793952299, 0.033689026188637526, 0.042935870720871856, 0.04642820903765304, 0.029435415685709034, 0.06661317377750363, 0.06848313486469643, 0.032860616355070045, 0.026414153698299612, 0.04053094923230154, 0.056217152159661055, 0.01291313547907131, 0.03052663231002433, 0.04090208074610148, 0.03521986904421023, 0.03678296266921929, 0.05304811203054019, 0.021409460908866355, 0.04113074365471091, 0.03600046251501356, 0.020063294929319193, 0.048752581634159596, 0.019834686303511262, 0.040640821015196185, 0.026157389261892865, 0.025358994424875294, 0.05562325081388865, 0.02376924964067127, 0.03758689774466412, 0.022397850640118122, 0.070348902605474, 0.02647753565439156, 0.033169906187270365, 0.0294040062996958, 0.05931697493152959, 0.05514593535502042, 0.042423145912055454, 0.038201111036219766, 0.01799082336947322, 0.09383724044476237, 0.03516414435580373, 0.051232681410121064, 0.032864321156271865, 0.05367634046290602, 0.022649090105135525, 0.09743415457861763, 0.00960894559310483, 0.017390501386086856, 0.08202838338911533, 0.0423284936696291, 0.010223008758787597, 0.02695630826721234, 0.05748532393148967, 0.05967448824750526, 0.037348094130201, 0.06910391976790768, 0.03668063280305692, 0.020108921320310662, 0.06267233738409621, 0.04197202869025724, 0.008964698645286262, 0.053060807420739105, 0.028664348846567527, 0.019765560548486452, 0.015888845714341317, 0.016340251313522458, 0.0031194392192576614, 0.05441182831834469, 0.020244945539161563, 0.02144341140852443, 0.013221125916710921, 0.02019308171501117, 0.02785659531530525, 0.032378015108406544, 0.02281779596315963, 0.030000343586185148, 0.11535792851022311, 0.03563067789322563, 0.018148567494271056, 0.022404127089040618, 0.024677823297679424, 0.031151054160935537, 0.02541809482499957, 0.016736346130658473, 0.024610885818089758, 0.016495308439646448, 0.041011084004172256, 0.045524586989943466, 0.06115749438426324, 0.042930103173213344, 0.010052130740535046, 0.022378100182062814, 0.09175584106040852, 0.02320739041481699, 0.07448118086904287, 0.06977278566254036, 0.017941487088267292, 0.04549649903284652, 0.027241700096055865, 0.05471792903595737, 0.03554538604138153, 0.05032516796407955, 0.030175090102212768, 0.046423038600810936, 0.0400858675794942, 0.03330948423328144, 0.07098384853452444, 0.019599041269559945, 0.031219141757381812, 0.010781290408756052, 0.012948339572176337, 0.046412053118859015, 0.00808160228189081, 0.11232116539031267, 0.0590252388002617, 0.004413930516290877, 0.024561281515551463, 0.03328098236982312, 0.05380532657727599, 0.018663221038877964, 0.10663308096783501, 0.0208508773108146, 0.014436628104054501, 0.026560238895139525, 0.09649742341467313, 0.029828453702586036, 0.11167620428438697, 0.0802329390176705, 0.11888004094362259, 0.1745296155235597, 0.1374768130481243, 0.19934959869299615, 0.12511929257639817, 0.07835248099373919, 0.0830981277727655, 0.17156536744109221, 0.13368471153080463, 0.14179823973349162, 0.1513616887054273, 0.12103225902787276, 0.10741892629968268, 0.14418316818773746, 0.1732339664761509, 0.12255120037921838, 0.09279580454209022, 0.09562893251755408, 0.22519199842853205, 0.08548986871859857, 0.1339745952614716, 0.09202542980866772, 0.14603053405880928, 0.10559126508555242, 0.09477921668440104, 0.11069551762193441, 0.099044996712889, 0.15304156499249594, 0.15438378868358477, 0.2183706180325576, 0.1675922056393964, 0.16021813132933208, 0.0866848367399403, 0.12865029381854193, 0.11065271563295807, 0.11139942985028028, 0.0908565107466919, 0.10795340154852186, 0.1231525723955461, 0.07292421441525221, 0.09385813932333674, 0.12372156472078391, 0.09857712646148034, 0.08627294562757015, 0.12610132273818764, 0.18701237998902798, 0.10414411273917981, 0.0995353739708662, 0.0637839405930468, 0.13460029954356806, 0.1225747319736651, 0.08525650016963482, 0.12019064490284238, 0.12846983064498219, 0.12445962083126817, 0.1792481073311397, 0.11436232764806066, 0.1146120692470244, 0.0966852961906365, 0.15880703633385046, 0.13456038811377116, 0.12816763828907693, 0.17393615522554942, 0.21454829456550734, 0.15291739308408328, 0.1420566937220948, 0.11133472475090198, 0.13565159456006118, 0.11993095598050527, 0.11633974154080663, 0.10592184734663793, 0.11362399333821875, 0.12531005591154099, 0.14936655147799424, 0.10346183899257864, 0.09684199706784316, 0.09208761754312686, 0.13107212100710186, 0.18602920988840715, 0.10906326770782471, 0.13114201011402266, 0.09318199953330414, 0.15329488925635815, 0.15580226614006928, 0.1216762973261731, 0.10594276658126286, 0.13496284080403192, 0.23067096514361246, 0.1027777942695788, 0.14082251994737557, 0.1762923409364053, 0.1586205613400255, 0.11487103892224175, 0.20331829573426927, 0.1736595436398472, 0.1682017743587494, 0.16484947209911688, 0.14539446176162787, 0.09704949307654585, 0.18830889756126062, 0.236495346895286, 0.24279635878545897, 0.13385673372873239, 0.17859915643930435, 0.13777108011501177, 0.07959882768669299, 0.1183534027742488, 0.08593735577804701, 0.08055276649871043, 0.13288610295525619, 0.1426993885210582, 0.2115759447749172, 0.06458949058183602, 0.10720252112618514, 0.09000382293015718, 0.11597205698490143, 0.11703726196927683, 0.10589628693248544, 0.15350207313895226, 0.13234056080026285, 0.08573893856789384, 0.08973627657230411, 0.12430287924196039, 0.1373616520847593, 0.16518583547856125, 0.15378412657550403, 0.07911952412022011, 0.08712956894721303, 0.09491967343326126, 0.11104971968701907, 0.07683289503412587, 0.09354509719248329, 0.09229218228054897, 0.13921994236963137, 0.12075872799115521, 0.1329677171472992, 0.10790198895015887, 0.15609170203762396, 0.07997265298451696, 0.10042971705219575, 0.1862937978335789, 0.10552671604922839, 0.15250423311122827, 0.1418263039418629, 0.1591549212379115, 0.08430269706462111, 0.11623152877603259, 0.10724396604512419, 0.11954638947333608, 0.08514627894120556, 0.14399084422205174, 0.16091542105589593, 0.10069454248462405, 0.1766262073069811, 0.16708668347980293, 0.0986083255016378, 0.14251975316022122, 0.15000414369361742, 0.11637521535158157, 0.17786925631974423, 0.05700899913374867, 0.16347250741507324, 0.13305560100291455, 0.09232322525765214, 0.14765299271259988, 0.2245550847479275, 0.11114854152713503, 0.13608239644340106, 0.1166120105023895, 0.09212381060102157, 0.13591977874083178, 0.19307857805064746, 0.12335896917751857, 0.12453044631651469], [0.026421797395284687, 0.05170977634510823, 0.05548960994929075, 0.05446609076378601, 0.020980133142854487, 0.020022287665467178, 0.02959640829690865, 0.004856035944872669, 0.032506709452718496, 0.013596915573413883, 0.06873806047120265, 0.023506593823965107, 0.10597747364746672, 0.05722701922059059, 0.040263284130820205, 0.028001598248790418, 0.025763102740581547, 0.04105891054496169, 0.07137366011738777, 0.02113912407574909, 0.01716372141215418, 0.02974354861570256, 0.01675180485472083, 0.029816372386579002, 0.06712065690330096, 0.06522649925734315, 0.06993762217462063, 0.0025371401861775666, 0.06562211909996611, 0.024951691905568753, 0.04826851475185581, 0.0594097442392792, 0.06155746363635574, 0.030893529765307903, 0.014290103555790015, 0.015315710932814648, 0.026128546434587667, 0.06718145364097186, 0.04555456466706736, 0.08092370123735496, 0.031029620141323124, 0.021958997938781977, 0.028620712259518247, 0.039435172852660925, 0.058703260363212655, 0.03194043805290546, 0.05631725303828716, 0.024899327661842108, 0.020232910024268285, 0.049010150134563446, 0.013525224956018584, 0.04133168162245836, 0.059584799488740306, 0.039861184278769154, 0.046043031848967075, 0.020700924464368393, 0.03181648327569876, 0.02270871976257435, 0.049447136864598305, 0.020678178274205754, 0.04208126265023436, 0.04036518991259592, 0.00918747017359627, 0.012543757978294576, 0.08682420783277069, 0.0359898468346468, 0.05722116346337965, 0.01885667985438236, 0.02949661954439112, 0.025365248821409683, 0.05033029090347035, 0.1069634732391153, 0.027199539322672144, 0.012412594614683517, 0.06368221462305103, 0.09987805451133422, 0.05706792990011828, 0.04937974476654615, 0.022123839539874877, 0.04024039035929101, 0.04737642101411309, 0.005387090529049081, 0.12102556867258889, 0.02757744600863329, 0.024288466333278587, 0.02347164078881698, 0.052458834900919876, 0.053095246465610604, 0.048309192926223786, 0.04955961422196456, 0.01684782773788486, 0.08825079378272806, 0.059182177164724896, 0.00033945410645433834, 0.010272580830912505, 0.051333644028220854, 0.020395025610923767, 0.013183194960999702, 0.030481072076197182, 0.02963939688301512, 0.039122944963829856, 0.02720627547906978, 0.04342417844704219, 0.052410492673516273, 0.02497752882274134, 0.036861285966421874, 0.049155376984604766, 0.025875417249543325, 0.06753372866660357, 0.03290889412164688, 0.057958099991083145, 0.048869781595255644, 0.06092548969068697, 0.06727593964231865, 0.026365139721227542, 0.016815529470997195, 0.0575882237670677, 0.04576965348262872, 0.06739650174443211, 0.011377062814842378, 0.06371140519955329, 0.07192689007414238, 0.02727564041768866, 0.033620253271822415, 0.024862249115748063, 0.03193123711805258, 0.02887142077088356, 0.06632041305835758, 0.008791093764427518, 0.00926433886135263, 0.061481467714267116, 0.03540313456739698, 0.03322866053453513, 0.040692365927887816, 0.06260820225413356, 0.10475337611777441, 0.02614802717497306, 0.06624189298599958, 0.05700646819812911, 0.008098059300599354, 0.0450783145081784, 0.04333324457651802, 0.03624682500958443, 0.0316675109123545, 0.040952282159456184, 0.025525612091379504, 0.03128819287355457, 0.05555950244888663, 0.021095102420076728, 0.02416020625137857, 0.04993795517033764, 0.02676054582531963, 0.015804530952924063, 0.010529655697090285, 0.011987025084506189, 0.01893642807512411, 0.022598585047359978, 0.013601286187102752, 0.03492216519745333, 0.034067876038274596, 0.0261193929971861, 0.034182738446231396, 0.06754462593900305, 0.03177891618439129, 0.0198386828747711, 0.06306803186557122, 0.05882749333977699, 0.03636298681210194, 0.014726138640461224, 0.04685343336313963, 0.06185481125222785, 0.031273237961743555, 0.03210321181852903, 0.15368178992399148, 0.04947457342807736, 0.13632126791136606, 0.011319479788653553, 0.026905652235395143, 0.047157444192894866, 0.042780764400959015, 0.02702072329287018, 0.029329547259424413, 0.02613900096288749, 0.02876575929777963, 0.04351356865039893, 0.04559017757752112, 0.05260889970564416, 0.02872522022309048, 0.04547500304345574, 0.04321076561297689, 0.025602088076993823, 0.013336252953324999, 0.0139770826291559, 0.026624419826215932, 0.030671645421534777, 0.0691864974796772, 0.05694896914064884, 0.023611888888158968, 0.013640541982437884, 0.06587965028094393, 0.055094583824809105, 0.006585184900489236, 0.009455085233119982, 0.05514392689136522, 0.08513582950191838, 0.047049889607088904, 0.023982385971716473, 0.0407773660096739, 0.02958908011870725, 0.059689131033207686, 0.04343736916780472, 0.023857845958056192, 0.02707341323340578, 0.045627778595579524, 0.043000874375658374, 0.013649050811571735, 0.015838201556886946, 0.016757314559072256, 0.061095788409667354, 0.044886004113193066, 0.04141895479655691, 0.01710768968665174, 0.04205273364537528, 0.03423709588657532, 0.039439104963093996, 0.070163445414177, 0.03078622284478375, 0.026434825267642736, 0.04996344433831317, 0.012466284546202846, 0.053520643817526956, 0.08506110244031463, 0.05281261627429298, 0.008922631170467606, 0.044363762850740125, 0.01900480404895331, 0.037422393714743, 0.07805864818926368, 0.020925489021465182, 0.007753608631901443, 0.03341222461313009, 0.052294673531183174, 0.07000861050827162, 0.018050536147451827, 0.021053647323112403, 0.01738101207385106, 0.12926576579255716, 0.03942961904353329, 0.03881783490734441, 0.01711731979490391, 0.039908254253012795, 0.08422214817255735, 0.04523462522774935, 0.04521723776789648, 0.04637698642909527, 0.032767962398273606, 0.052139852195978165, 0.020702249303992306, 0.018351317150518298, 0.023301297965060388, 0.03978181603763785, 0.023194170856316174, 0.04570642080424087, 0.13089433126151562, 0.08468802353101117, 0.037144170608371496, 0.06732367458088057, 0.10570240233625684, 0.03001956987593855, 0.01736723950931004, 0.018550438340753317, 0.03639683213883212, 0.07367666903883219, 0.019903342173035656, 0.006059036548582039, 0.014629359190751399, 0.04386156551273806, 0.07131954016430037, 0.014848020493185945, 0.05972870998084545, 0.02577054457339857, 0.017562231813956584, 0.05523669959178992, 0.0094744540152273, 0.059207730793527195, 0.07582768611609936, 0.03724210696028812, 0.11901181244424411, 0.0686111676373652, 0.04523549714524831, 0.007685292878055147, 0.04320580891466566, 0.027112688536622694, 0.02319590112061373, 0.0229539609780269, 0.007697510749234685, 0.0463298791354256, 0.028946711016552787, 0.022026064340025187, 0.0038545148646725075, 0.04043185937085322, 0.04523001118962254, 0.04441623057105711, 0.03760829195380211, 0.040375507037554464, 0.01989482995122671, 0.026202365955603973, 0.05470977643770831, 0.04539077649159091, 0.020519591069647243, 0.03707082775820579, 0.039180969885949574, 0.03953113127499819, 0.03943856892042926, 0.017533841908776333, 0.0205494584848306, 0.028489788927670037, 0.028725586632000547, 0.03138750325888395, 0.029702029057911465, 0.0144000058727605, 0.03805463568174413, 0.06078920593219144, 0.04259403156382697, 0.01660392662909414, 0.04415025162909712, 0.03754943243360945, 0.039427057573837895, 0.024815333508221165, 0.05174668865012271, 0.06321253946849278, 0.028532974288931916, 0.0023697496258786744, 0.11258045397698879, 0.03457128456128495, 0.05732762560780559, 0.021074408798345497, 0.017238297499716282, 0.08272493351250887, 0.03613304825765746, 0.04892485149736915, 0.0073133157399882165, 0.021645830278950076, 0.04391576689002769, 0.027042312580826025, 0.049592628343296905, 0.01773860172501632, 0.035122902997370274, 0.039402189265404425, 0.09406505179192338, 0.0781091922628028, 0.05101683602801391, 0.09318042533206088, 0.0943081776744553, 0.14362218257571968, 0.13826896197029523, 0.09675348896001067, 0.09648737431104694, 0.1770619082131556, 0.1344764804733651, 0.09916732979140111, 0.21210018093032496, 0.1213119240211589, 0.0723277549924595, 0.1309011708945036, 0.17693728847163065, 0.09048630204051733, 0.05963631386735609, 0.10379146451928786, 0.11039428878575563, 0.08302467635699681, 0.10559228967343058, 0.12239958851465157, 0.10047807624297482, 0.11051113251596689, 0.13609511218965054, 0.1459608892244952, 0.17069946176239423, 0.14306862013680594, 0.11750877595373563, 0.10452433662222964, 0.2639722967786448, 0.08866134139576129, 0.12938642288957322, 0.1687466108373233, 0.11686324487839427, 0.14551089837082795, 0.10031993008617844, 0.10776949820241757, 0.2037281851683344, 0.23704173043370247, 0.14065174625388213, 0.12600734563810484, 0.2070902990443366, 0.1350754911878279, 0.17316438949533872, 0.10679658076592854, 0.07879571363862072, 0.12093288078904152, 0.07343285105058125, 0.14890951743083342, 0.13699719735554286, 0.15800023105527672, 0.10755279447351183, 0.2031084384237017, 0.10064475837030581, 0.09395889498825584, 0.1962858230939933, 0.09720252307930163, 0.0651828016021422, 0.10653771287096397, 0.17171896062791348, 0.13164378676031316, 0.14525120944849082, 0.17978736625186034, 0.07763848573501621, 0.10329916022185769, 0.16894375240164144, 0.16231940500438213, 0.08273562043905258, 0.18435157276690006, 0.11822761595249176, 0.3009151358689581, 0.1590036079287529, 0.16116000578871795, 0.09601102237190519, 0.1640843152999878, 0.14953944220074586, 0.17104886658489704, 0.1335531435906887, 0.06316749152860471, 0.10156792561922755, 0.22728658174829824, 0.1533752413732665, 0.19667657784053258, 0.09946788009256124, 0.21319491575871194, 0.16006968143795217, 0.14457228087953158, 0.190562529489398, 0.18140424734779767, 0.1648590394428798, 0.154806271727596, 0.2186708426369088, 0.1957748590835503, 0.09464175227497305, 0.08959594874509744, 0.16956725823027746, 0.13546130619943142, 0.11927771674735205, 0.20923171485108988, 0.0955538186909897, 0.1328791140445641, 0.13627326834414685, 0.1518746611795255, 0.1290955077856779, 0.11926998144813947, 0.10046515015086957, 0.12530398980847426, 0.14295561691480024, 0.11186748330614396, 0.11158568771289927, 0.1358438235308443, 0.21528732776641846, 0.3102975924100195, 0.1011818866910679, 0.11773627517478806, 0.10441624599375895, 0.20117242873779365, 0.1305989921092987, 0.2019455786794424, 0.12922296380358084, 0.15703276225498744, 0.1496766284108162, 0.10320247576705047, 0.07536898287279264, 0.15668685867318086, 0.11161910556256771, 0.10194479075393506, 0.1695217556719269, 0.1695964488067797, 0.06533108864511762, 0.14221190182226046, 0.15787638484367303, 0.16137217011834892, 0.16880136861332826, 0.18274983657257898, 0.15800773565258297, 0.08812856926981892, 0.1136081563308835, 0.12567223076309475, 0.142653207427689, 0.09806220659187861, 0.13075010185795172, 0.19057733512350492, 0.09289095550775528, 0.15064014813729695, 0.14814128008271965, 0.1352246603263276, 0.13620897036577972, 0.21176113055220672, 0.19099825753697328, 0.09812649099954537, 0.10065327398478985, 0.08570696599781513, 0.07995313153203044, 0.10522616574806826, 0.18852110260299274, 0.12083251188908305, 0.2271918718303953, 0.09647815302014351, 0.1388228636767183, 0.11410380580595561, 0.10807453362005097, 0.13030593283474445, 0.09920346178114414, 0.16862484094287666, 0.11856762985033648, 0.12142834705965859, 0.10906807173575674, 0.08461380537067141, 0.12439908193690435, 0.09796564427337476, 0.1772262222532715, 0.10365992372057267, 0.3205971025994846, 0.16290230729750224, 0.21090278375361646], [0.10102079569229058, 0.03555737575516105, 0.08907868792968136, 0.07877394623522248, 0.01861529950318592, 0.030718138641012565, 0.050295139396829266, 0.0938711129128933, 0.04533976083621383, 0.04148399577076946, 0.013113864797300525, 0.04607958113774657, 0.09515082317271403, 0.04520682564803532, 0.030103311275265048, 0.019905449024268558, 0.0021523215608405216, 0.0240767786744982, 0.03811144602618047, 0.01976096856274775, 0.0444113179775221, 0.023263450978057723, 0.023655403338904892, 0.02786630515142211, 0.024760926874088388, 0.06121676441814218, 0.04776318597474268, 0.04780969615759594, 0.03623466905472534, 0.06607684612806354, 0.040440405519413095, 0.015702036542019675, 0.031178090388753583, 0.08935139793902636, 0.03757475196783032, 0.05001744215509721, 0.03756802090044532, 0.042271751178694625, 0.02353311436516898, 0.05685062227504594, 0.027368260447734168, 0.03047469723969698, 0.02285010610441012, 0.05139154002868703, 0.044374595662312846, 0.043130203150212765, 0.05736567106630121, 0.06789220550230571, 0.05544623799089875, 0.06386320026857512, 0.034566935151815414, 0.025405557194192494, 0.049938827087836604, 0.04489203968218394, 0.020617495191150477, 0.04594847120876823, 0.03444556559302977, 0.02005994296632707, 0.07621134338634354, 0.0732464235542076, 0.08645203137504202, 0.00996034954940634, 0.051810640575630326, 0.0535545061076326, 0.011371156167505043, 0.10394484057490315, 0.06263687714402165, 0.010092290683782526, 0.034870260661201816, 0.016652268856497746, 0.0509403312046613, 0.022778417183352367, 0.027198282336550098, 0.03246471492041435, 0.04717513360083103, 0.05188188335991331, 0.025073969004941837, 0.061064399379704676, 0.08374099220548357, 0.0156630903282868, 0.027268975507467985, 0.024903266557625363, 0.0452872116916946, 0.010174736081223403, 0.008789510233327746, 0.014389788831717201, 0.04583181068301201, 0.03907702849911792, 0.01146788303075092, 0.05631960755480187, 0.02343798884456711, 0.026534071192145348, 0.05462933950392263, 0.04889604429315243, 0.08071866831076996, 0.04162346864385264, 0.032266277354210615, 0.033932711862559826, 0.025485871991674815, 0.03396588543962155, 0.006408454093616456, 0.032936327292450836, 0.025034396842654263, 0.12752682981746538, 0.021184473963720456, 0.08367896053407874, 0.032681435612695556, 0.03885290159710816, 0.011552833070579385, 0.07001573512596743, 0.023977227409237196, 0.02671106705175979, 0.043342998517411094, 0.05059244290792516, 0.011804439792675632, 0.05088893556967378, 0.028030887212870375, 0.0224670663010329, 0.03249261288770607, 0.03445595396416528, 0.02863294624590448, 0.04152536605085645, 0.043699867225119045, 0.04122020510424461, 0.03824394016659685, 0.05596640293619462, 0.011958734415072416, 0.012436658859119883, 0.04809219403458493, 0.021863412710704973, 0.0515513010988278, 0.01931922190955707, 0.04181671202448862, 0.03752873372286558, 0.013419203859354769, 0.04480166221037507, 0.047300930600613356, 0.024979427024456005, 0.014010750688612461, 0.09767979782606874, 0.038294796366244555, 0.014620329585990735, 0.018297405846949135, 0.09021132572421006, 0.014795610448345542, 0.01908818582471992, 0.015256858197972178, 0.049974185547658374, 0.033902201535446305, 0.027993001210104142, 0.013529080731262053, 0.04689445419769202, 0.01994801182965083, 0.05106135131791234, 0.025281329306640794, 0.05629589275590011, 0.07736917518611465, 0.0224313719663769, 0.03971028148329683, 0.0404037544503808, 0.02040314767509699, 0.09329097904264927, 0.03549300992329206, 0.04479406261816621, 0.0287932331806847, 0.04377888262804065, 0.06248068516807897, 0.04004623095637985, 0.009297823716354157, 0.03345102324549641, 0.05281329820198672, 0.058101698357079706, 0.020097947712721567, 0.051167548833681006, 0.03915460540779999, 0.0645014913752675, 0.03664199701909508, 0.029409624569650208, 0.04621344252622553, 0.01309288534269269, 0.0353523190798504, 0.028886945652110235, 0.03925215499475598, 0.015226963641388076, 0.010751858952322176, 0.028492045056607043, 0.04639822457517896, 0.027714576239564588, 0.09649059056703534, 0.0958141182948436, 0.04951302261490907, 0.020430265327117274, 0.034728246674473794, 0.04977615510246583, 0.011770945607817598, 0.053989789714770656, 0.04335405185286488, 0.027888532262295485, 0.09948366960244519, 0.009399265549810869, 0.009829745129016893, 0.017172094534284303, 0.055649072464023314, 0.039832390645252805, 0.008319435591277267, 0.009896566409484615, 0.06438759248703718, 0.033745130856654475, 0.04550777967753155, 0.04823059821501374, 0.03063963892470513, 0.027407902159861157, 0.019017979502677917, 0.04624339984729886, 0.053557026865226884, 0.021698415046557784, 0.03101583230974419, 0.012788482658964182, 0.047306592975343974, 0.04974946832018239, 0.043071330059319735, 0.03229375462979078, 0.03793265204876661, 0.04004064661317638, 0.014854746471558298, 0.021078318856390457, 0.07949301693588495, 0.004725368335909609, 0.023888181562402418, 0.04046531453994768, 0.030511772393115928, 0.004614794693355049, 0.07314027353589024, 0.03623545615534697, 0.03512559338871922, 0.05088933251265969, 0.02269105749603893, 0.032528127410582135, 0.025506988001455153, 0.008740269795193203, 0.06470715533941984, 0.10493132871176515, 0.06213073751756123, 0.019350526122642413, 0.01272176400691803, 0.036713819950819016, 0.07725657908512013, 0.0355273777219866, 0.022206162801012397, 0.09974128899297544, 0.05630326843155282, 0.023277813868064965, 0.04661768315626042, 0.04242043177198086, 0.035663725941308906, 0.02136628911830485, 0.02190693055412599, 0.02189415373972484, 0.023827071002285396, 0.031990300198750835, 0.049508758022316864, 0.041902495814221244, 0.012109917106239923, 0.03899940409298454, 0.024738584412261844, 0.034823699588222165, 0.03333258156531623, 0.039306858487959416, 0.04838807601481676, 0.07791181321122817, 0.06889429994459663, 0.036773327471954484, 0.029599353138889586, 0.0769179290426629, 0.04415913025981613, 0.011074057065083511, 0.019509625621140003, 0.03893398653183665, 0.0246347600727209, 0.026005375365327512, 0.010274917535882975, 0.1041183148377708, 0.02739742897184832, 0.026242017845756242, 0.020346179571268812, 0.06296173935489995, 0.009415144117416015, 0.033268721242036135, 0.06935667406235423, 0.029420715224530016, 0.01716797413038356, 0.05064127707321729, 0.0889783122443727, 0.027806234446221163, 0.0359017899526017, 0.0455404850654304, 0.0426303637214005, 0.04984591528773308, 0.0030788435293028927, 0.04173918939860804, 0.022562816073851924, 0.037651555346591134, 0.08402098289557866, 0.0023533806046803613, 0.0021837254337567303, 0.03564197550128613, 0.04422675984512482, 0.017076336279777542, 0.05803833675703832, 0.036784611509314606, 0.034108842590025494, 0.02127957234292158, 0.028938103799841235, 0.04026982860107507, 0.05721409312848534, 0.019624912113483464, 0.022722733207046986, 0.03349559621087142, 0.08278459709669862, 0.057753732028816424, 0.0971785911491939, 0.04194973881489464, 0.02871355620611991, 0.04908160326470222, 0.04877163829015834, 0.04301949676924518, 0.04735133557447365, 0.011517215919281756, 0.03308446845039725, 0.03758542871634875, 0.036657827241080146, 0.04157638170623353, 0.017999812262132764, 0.025320280609386306, 0.03553437002535377, 0.04067323124036193, 0.022774405345054607, 0.05324711956615959, 0.006307106830977968, 0.0694218473508954, 0.030288751503186565, 0.05877863881843431, 0.06626885118229048, 0.03578581474721432, 0.04608602382774864, 0.054203504496919255, 0.04435294700254287, 0.09283259471080132, 0.029445444433284656, 0.07664889669311897, 0.06823067234030791, 0.04016393981873989, 0.1979636230639049, 0.13041987243507588, 0.17404567077755928, 0.08632730306791407, 0.1078005615355713, 0.15120924902813776, 0.16039208056671278, 0.18728181267423288, 0.1268983706831932, 0.094334436979677, 0.1787489905421223, 0.1290329061448574, 0.20073401369154453, 0.24231104339872087, 0.12489521317183971, 0.13123273024601595, 0.14732964363481316, 0.14493118519229548, 0.07409209531864949, 0.15147192350455693, 0.159569845401815, 0.11237996723502874, 0.2295284207378115, 0.10089970433286258, 0.10494760676686253, 0.12554552113371237, 0.16814720657254967, 0.11156272608786821, 0.13633422793022223, 0.1648214893149478, 0.10997082865131752, 0.14616823595549377, 0.15630948463720934, 0.20657168115888322, 0.09689465138529028, 0.12705467801008904, 0.12430445344320365, 0.0990977528105889, 0.1591614351740905, 0.1746563794357436, 0.11422691919973918, 0.10761384905448981, 0.12227519947503294, 0.16284925942974432, 0.21720002298908575, 0.09892587310501508, 0.09384709955858332, 0.10880344307848386, 0.08979749400168657, 0.18912944995931216, 0.14437193662992545, 0.13683535318289483, 0.20544515017952236, 0.08993294316210917, 0.13363646769097873, 0.24646791177136557, 0.11366269697568246, 0.07955443114042282, 0.23407799803784915, 0.1690319755247661, 0.15754718679402555, 0.10833756772003003, 0.1619246197598321, 0.13330436551145144, 0.11814453612480845, 0.18607590666839055, 0.1685055951986994, 0.12979104689189366, 0.14585734478064946, 0.10339526113654886, 0.16895534177975996, 0.14772293610232218, 0.11398084168987614, 0.15201500936278275, 0.10372561948107821, 0.15070299405072415, 0.13484709630055086, 0.14612506755760737, 0.12392682156392507, 0.2792932375201157, 0.11728244381291525, 0.13861413273428166, 0.06740013190678187, 0.07405045362455503, 0.16892214784664766, 0.131256492542369, 0.20696390154106276, 0.1461949430938278, 0.09669576598597424, 0.10470049109842096, 0.1722052666757788, 0.14532333772097314, 0.13715336897543498, 0.13362847454845905, 0.2088716570287943, 0.21219221742025443, 0.09580511413514614, 0.16507710702717304, 0.08110984374902078, 0.1284188319529806, 0.1513283047825098, 0.11482721913073744, 0.16992651538125106, 0.1995360736868211, 0.07694401192877974, 0.2297643337930952, 0.11990523950329848, 0.09271032270044088, 0.22824645095637866, 0.1516464427113533, 0.10508209919290883, 0.1527248519871916, 0.12229607121220656, 0.08699071354099683, 0.12778133473226003, 0.22935262588518007, 0.2934105114213058, 0.1398465558886528, 0.13111193744199617, 0.1308363979416234, 0.09136347818587508, 0.2021313887089491, 0.08817289117723703, 0.13327921900366033, 0.07524002729249851, 0.10026235638984612, 0.11374791418867451, 0.07197113734270845, 0.13137321413627692, 0.0825924291940672, 0.0945882158620017, 0.15495765289025648, 0.1347348258963653, 0.21939777077308723, 0.08365806844085455, 0.07866723303283964, 0.060687948151358535, 0.06862821243703365, 0.16286338652883256, 0.21476427226194314, 0.1323587048266615, 0.11592099043939795, 0.12483482355518, 0.16590965592435428, 0.18602178671530314, 0.1770443341561726, 0.11466783125485693, 0.1412346621177026, 0.22323272856218473, 0.08456130033092839, 0.09883653718445982, 0.12962833419442177, 0.07503006820167814, 0.10145610304815428, 0.061035758416567526, 0.16594485832112177, 0.2975468337535858, 0.08196030597069434, 0.12255889496632985, 0.14613462133066996, 0.13227413222193718, 0.1552046803491456, 0.0733488891273737, 0.10856427984046084, 0.10282964791570391, 0.17357278615236282, 0.197827508939164, 0.17716841106968267, 0.12370127652372633, 0.0860794885084033, 0.13142741551356657, 0.160132622346282, 0.1475688950823886, 0.1914190985262394, 0.25206425147397177, 0.08399888301002127], [0.015143128943496516, 0.035131717167262516, 0.04697217359872801, 0.03297186217137745, 0.038517271035483906, 0.05158011508839471, 0.01709080603905022, 0.06675017678311893, 0.0377836559366967, 0.04641270790515201, 0.01869963462065373, 0.01265445163673056, 0.03999474371916481, 0.02992716697709901, 0.04230963718146086, 0.021384735092786804, 0.028292445499183874, 0.06342572160065174, 0.04202267454404916, 0.03377951901139958, 0.04265940502019865, 0.03238620163340654, 0.0157678883655795, 0.019531915496502603, 0.029492795999561037, 0.036903083723570616, 0.01066593945558582, 0.037226595649761815, 0.03430264236937676, 0.07641701413584606, 0.08943913930228778, 0.055081980036837716, 0.03761034791490861, 0.042034087503062825, 0.06178741915417569, 0.014840980692367469, 0.028680324953581606, 0.008317813892582697, 0.04218143816771252, 0.026142361407567347, 0.015554996307141014, 0.013523169843080853, 0.01489993860013783, 0.06772572693548032, 0.0058666031691245735, 0.03427430335432291, 0.02646172578845705, 0.04601161228492856, 0.015653025957622697, 0.08474497297512633, 0.016681542553539788, 0.05750088273946728, 0.04417925900114434, 0.04066515667364001, 0.027842011901416948, 0.05710700673184224, 0.019113235641270876, 0.017762840692219988, 0.023929806293121407, 0.029349838849157095, 0.06529896679733481, 0.0230293665746493, 0.04437304860247033, 0.021192557012130107, 0.07111220700400216, 0.05292427260428667, 0.016240576215620552, 0.03263422653877309, 0.04223877437678831, 0.033158479657556326, 0.018856627267918417, 0.021284646088523523, 0.06278390211186238, 0.05272407423970955, 0.04043304680713585, 0.05086962107036795, 0.033675126398780515, 0.00651789119001478, 0.04867856364165034, 0.055134261160024574, 0.027668096590787172, 0.02989718590730003, 0.04974915958674891, 0.09701401926577091, 0.10118291127894606, 0.037350943977279324, 0.038507279607334306, 0.01974947757220694, 0.037548716579164775, 0.01780991066646363, 0.0315568147094122, 0.05494470222453986, 0.02660275250673294, 0.04185454713712845, 0.046101396038596115, 0.03148157196119428, 0.051745928690901825, 0.03480768616178206, 0.04807993969214814, 0.029627878751073564, 0.027550389424764683, 0.0728697959067566, 0.030997623822518756, 0.049231810561780415, 0.019722346349486282, 0.003157275604150657, 0.030371217256678, 0.02752343631748642, 0.046090118786586184, 0.04200781123446567, 0.009276511779587184, 0.03553906548768282, 0.037393634007977586, 0.052364905298288376, 0.032097590155899525, 0.012108985816926827, 0.06620217154600791, 0.014218854834325612, 0.025070440622844865, 0.00904780815887664, 0.012585247002009834, 0.0444928982428142, 0.043699544920985184, 0.016117576476452605, 0.032569602863597016, 0.06207241064735821, 0.03419001234163131, 0.018450250948912332, 0.058595393651298115, 0.10367057672036545, 0.015162370500287839, 0.01714071737868445, 0.05335639084556273, 0.006395083985158375, 0.09165445435792208, 0.03301827396665301, 0.03128308689753924, 0.08159699118030922, 0.006754612974223814, 0.02023477429923202, 0.04147249460220337, 0.01351353888665991, 0.007753827459444957, 0.033752459034855874, 0.05431678591828261, 0.0675970156277929, 0.01312135243123131, 0.03209462495786803, 0.05342231730797461, 0.02592298255435058, 0.04114915909511702, 0.057417165088866434, 0.033183917935405455, 0.04078336765191384, 0.03482467667864902, 0.03784357736419354, 0.05650191295093723, 0.08690591023436614, 0.023516040727762238, 0.015741133729794195, 0.018542742057304298, 0.016066041741786257, 0.04742351473708238, 0.02714537356847099, 0.013898516755684145, 0.03997770570484655, 0.020371095377153585, 0.04823791282251477, 0.0070950030349195, 0.01759917974205954, 0.028342970913009982, 0.020198119837524633, 0.026448436680116823, 0.05421516512121473, 0.06535595695355109, 0.05489718441718391, 0.06427488103508949, 0.04642236345846738, 0.06819395002509866, 0.054797921529305835, 0.06730345423732485, 0.027417276121143783, 0.009524834392193173, 0.04824284237942525, 0.01968171906524471, 0.005081047910997378, 0.03671809811411159, 0.034469690905617814, 0.01573810407093593, 0.002542318468580821, 0.02001889329403639, 0.018038397155968205, 0.011964107564251338, 0.00958941989977445, 0.05357487912156752, 0.044940276736659665, 0.02163979810263429, 0.022679644537025263, 0.036130910872348716, 0.04932854590671403, 0.03831735087026443, 0.033842202076422315, 0.018686184360246574, 0.04639165296352335, 0.03371757894222226, 0.009060848753766289, 0.11048703095210449, 0.05025199135499341, 0.026895899990839616, 0.04827866902840989, 0.021465356927365065, 0.06049377178507192, 0.04453695552157504, 0.010428616743800896, 0.024679623111816387, 0.0293191113908376, 0.007418184175289103, 0.057212715702397485, 0.03598273578765137, 0.04255382497129696, 0.05088398904938783, 0.03843574844566839, 0.01695035437920264, 0.06038740463554859, 0.03480881252991302, 0.06549288532031433, 0.02076732420495578, 0.038545420060732534, 0.026721329893916845, 0.027462186657690575, 0.015541020182094403, 0.01201788570532309, 0.03760878389169063, 0.0690485377396856, 0.060813422847007, 0.028413406240620782, 0.06445393285581044, 0.018653562092887502, 0.03478308926735606, 0.03182601330003568, 0.05225697412554707, 0.060116974503866265, 0.030564464029989073, 0.019732772040047815, 0.010236055290858661, 0.05953276263816016, 0.006209212463415627, 0.06733173557690211, 0.02469682227820158, 0.0409743650816381, 0.0231373774752553, 0.03246665892324277, 0.040324776366885216, 0.06599625652389866, 0.007813044906859952, 0.041835093538143804, 0.06082620644675834, 0.017407880364251987, 0.025106075585686734, 0.04161004043583359, 0.04798933491110802, 0.04219141602516174, 0.013588383843723153, 0.02896749454417399, 0.05922725224601371, 0.04705427972865956, 0.02158734225668013, 0.04356869622798903, 0.04330844072891133, 0.0555451107211411, 0.06833798943885735, 0.01379642098410321, 0.02471736153321607, 0.03151979383879474, 0.01917965743424637, 0.016221215915200964, 0.019668055066306676, 0.042296409141272306, 0.05521885412079947, 0.0352748575221215, 0.014119826889197742, 0.022157952887937427, 0.042880417446472814, 0.031123644738857235, 0.07672573399863072, 0.018977942543902566, 0.0473290728405118, 0.02458842800531004, 0.04004417160259826, 0.023223693914977566, 0.01832172623835504, 0.06375781699482884, 0.04421199831579413, 0.05591201496177486, 0.016274335029135858, 0.019366671863411154, 0.017798937058874538, 0.037287300785205195, 0.035470231502716026, 0.10598986369690724, 0.02106118923984468, 0.0032011210527603646, 0.02565877798146435, 0.04088581965437957, 0.039505143383783956, 0.05232260881790093, 0.022009095875546336, 0.008946364629082382, 0.09122343534337622, 0.09226184497986521, 0.06557429595185177, 0.04149094396936042, 0.04163268993475607, 0.04177065306742277, 0.04425135334687574, 0.07058004555957657, 0.009860671058829342, 0.06834456444318805, 0.03479627659544349, 0.058754577966673036, 0.04849728961874332, 0.031166538330061094, 0.038808901993823905, 0.022107629338279366, 0.04165113590923803, 0.02592277729750744, 0.027478496943201338, 0.06371280976704188, 0.0267723082298679, 0.03128529552902494, 0.046924703288823366, 0.0754689582224403, 0.02556461258791387, 0.03990913634853704, 0.007992792225975012, 0.0325684086419642, 0.038923889930759153, 0.01589076087943145, 0.0362774133682251, 0.027528118209115097, 0.020509645442611406, 0.02341352087179465, 0.047233528324535916, 0.039008004524345906, 0.033097621851733754, 0.030474106914230754, 0.07778268799717937, 0.026275091338902712, 0.038410442482147894, 0.015168987913057208, 0.030939799068229537, 0.03692885787625398, 0.06709621607192925, 0.14138410267020973, 0.17700461271618093, 0.08846647292375565, 0.13984035407858236, 0.11206959853214876, 0.11572355031967163, 0.08784557266959123, 0.10103839010532413, 0.07168734007115875, 0.131358517067773, 0.11969815061560699, 0.09417706435280186, 0.1482669583388737, 0.18352025880345277, 0.13757876972002642, 0.11577574323330607, 0.1268228090235165, 0.1025316489062139, 0.12415109095828873, 0.11289663772497859, 0.08456161245703697, 0.15056981119726384, 0.11599374296409742, 0.09499266344521727, 0.1254250540265015, 0.07168499912534441, 0.1829714732510703, 0.1478006826447589, 0.12519665913922445, 0.19677132847053663, 0.1809382023555892, 0.1252659104232277, 0.12805912696889468, 0.11994596517511777, 0.14547990289117607, 0.07756444399378129, 0.10272354539483786, 0.1594861006098134, 0.11937621289065906, 0.08036455445523773, 0.18347573333552905, 0.10568550002894231, 0.08894843634750162, 0.13118421499218258, 0.10187826718070678, 0.10927212078656469, 0.11770135776272841, 0.1044882114178368, 0.17011273253176892, 0.16451618926865713, 0.129781343841127, 0.09208771932337965, 0.07805098752890315, 0.07163165270217828, 0.14085541532507964, 0.13633702349449905, 0.14158793458981173, 0.16243170254996844, 0.11525304056704044, 0.17073093221655913, 0.10998383616762501, 0.10590676351317338, 0.18846090297613824, 0.16917202515261515, 0.14549478994948523, 0.08127373709742512, 0.09173384974045412, 0.19041376747190952, 0.10843955153333289, 0.12378624267876148, 0.18619264183299883, 0.16593933504606995, 0.12855122770581925, 0.14699736503618105, 0.20566274278930255, 0.08794396703264543, 0.18864684871264867, 0.10949964714901787, 0.08409543854317494, 0.14585444065076963, 0.12608830843652996, 0.16314207443169185, 0.21882045960852078, 0.23160069382616452, 0.07503878737666778, 0.07841979166758911, 0.14278495178690978, 0.15547361091843673, 0.17234580484884127, 0.08515039086341858, 0.11798987085265772, 0.16432439456028597, 0.15698164142668247, 0.10985988817576851, 0.13685691702578748, 0.17017177864909172, 0.11682889743575028, 0.08553621944572244, 0.11231822733368192, 0.07131659532231943, 0.12169957107731275, 0.13393924358700002, 0.20269791116671904, 0.15138640095080647, 0.1159142322306122, 0.13693307579628058, 0.14601764189345495, 0.165828760979431, 0.07519637713474886, 0.07450338932020323, 0.12210465648344584, 0.1488267904413598, 0.10484988415347678, 0.10905401927552053, 0.08027641954166548, 0.10861656774899789, 0.10666313328381095, 0.08057484602821724, 0.07650219742208719, 0.10639962420931884, 0.12887925867523464, 0.13339185581675597, 0.14443042634853295, 0.09343701334936277, 0.13200564948575838, 0.140547496133617, 0.14004937000572681, 0.19268840684422425, 0.15398453867861203, 0.13056388470743382, 0.05105585179158619, 0.21634284327072756, 0.205843341669866, 0.1558742451348475, 0.17609377444854804, 0.12528081105223723, 0.1344258346195732, 0.11377185290413243, 0.20338361151516438, 0.06869245613259928, 0.15303211978503636, 0.08323300017842225, 0.12091974435108048, 0.1266489547810384, 0.16322185657918453, 0.0994511813457523, 0.11781265107648713, 0.14017768097775324, 0.10238482749887876, 0.14826285998736108, 0.12602474327598298, 0.10062492479171072, 0.10801406936453921, 0.06764572087143149, 0.12120951951614448, 0.11831919103860855, 0.13060500392956392, 0.07495045568794012, 0.08392317207264048, 0.05984765038426433, 0.07788609673402139, 0.135829004326037, 0.09239584886069808, 0.08694735515330519, 0.11838647457105772, 0.11475397806082453, 0.11897302738257817, 0.10482183351580586, 0.10710878151335887, 0.19636890292167664, 0.09340383298695087, 0.1308498600763934, 0.1181557048112154, 0.10238391147660357, 0.19837254897824355], [0.017081922319318567, 0.10405242230210986, 0.03038900505219187, 0.0433843145146966, 0.04728217589269791, 0.0010901597000026542, 0.028436371258326938, 0.022590520658663342, 0.04090947338512965, 0.028259156571168984, 0.030442833235221248, 0.033631164114922285, 0.029837681778839657, 0.015657641692087054, 0.005904105375520885, 0.01850570591964892, 0.04586822087211268, 0.02484369118298803, 0.048105391540697644, 0.032308217603713274, 0.015520991524681449, 0.020297918768067445, 0.023233970327835, 0.030220911572022096, 0.008305392460897565, 0.07721438099231039, 0.09156074867184673, 0.015268895409203, 0.008751784534459668, 0.055218969471752644, 0.05328918873731579, 0.01705752220004797, 0.024098661428849612, 0.0393816194763141, 0.017373127496934364, 0.08757682530475513, 0.03809537153158869, 0.04360537104574697, 0.0339283081702888, 0.06855275934295994, 0.046447601568486006, 0.04575303616002202, 0.05743280532104628, 0.05547560498650585, 0.05973439610430172, 0.016228143757741367, 0.026236799911462834, 0.03626875186871205, 0.07483744568058423, 0.042022508302969594, 0.03809324771698032, 0.045769510990274806, 0.040396911424717734, 0.0547798148223332, 0.03370974864810705, 0.008465307897755077, 0.04788575654051133, 0.04827520849981478, 0.016278443558673774, 0.013310047082736023, 0.01086735409418387, 0.015858136915734837, 0.07673897900219474, 0.01708388328552246, 0.07627513924879686, 0.03677107134301748, 0.06706967178199973, 0.029957500885107687, 0.04051820295197623, 0.02192120693091835, 0.015917371326525296, 0.04860266949981451, 0.058801525804613314, 0.03995444891708238, 0.0318547187239996, 0.017049659675519382, 0.02633427146689168, 0.034830298341278515, 0.0775971222402794, 0.018345955027533428, 0.02542285474815539, 0.03718280978500843, 0.04695664193215115, 0.07135484434132065, 0.0031011295879060136, 0.021186192353655185, 0.05506156970347677, 0.027514920703002384, 0.0658036611442055, 0.039550333816025934, 0.028172351586233293, 0.11024718239371266, 0.044352064907018623, 0.05552012027640428, 0.04040503009621586, 0.06910560932010412, 0.016689069203234146, 0.024288481600316505, 0.010512895033960896, 0.030193234128611426, 0.0178235797544143, 0.09570791399372475, 0.06781164982489177, 0.019714660244062543, 0.0642479635508997, 0.0421204514402364, 0.011364096010636007, 0.031179857972477163, 0.05728255731186696, 0.04354067951706903, 0.056797984920974286, 0.05794486177286931, 0.019676104187965393, 0.012426952415678118, 0.01654183558587517, 0.04175223423434155, 0.029713106142090898, 0.0521105666245733, 0.02253525737406952, 0.04494861593203885, 0.057502328019057, 0.02008876034856907, 0.039118303784302304, 0.065198258629867, 0.05001747947452324, 0.03510178020223975, 0.028466664454234496, 0.06399081234953233, 0.03135127627423831, 0.06972600067300455, 0.06327962622578655, 0.03729316672044141, 0.0574266238670264, 0.05259179723049913, 0.016271101809771996, 0.033440475418631516, 0.03706805594265461, 0.07589629957718508, 0.02696625898326082, 0.05428326628836138, 0.04495760652103594, 0.03977617062628269, 0.05504152577902589, 0.05706739385745355, 0.053469339784766944, 0.0805949035233685, 0.03486217252377953, 0.013160793127359023, 0.01627565477974713, 0.08893099799752235, 0.06477623020431825, 0.03133363436375346, 0.03132521713684712, 0.0632495739098106, 0.05152919442792024, 0.007945754482144756, 0.0434753840922245, 0.06277683177696806, 0.046136513618486266, 0.028129040695992962, 0.03800039019967828, 0.02003976163853492, 0.03360402271417635, 0.054817171567784886, 0.021052103655944978, 0.04482953982161624, 0.010984046002184706, 0.021597440554095165, 0.019275325782863156, 0.0675335590328489, 0.053427158655332666, 0.028147552827639238, 0.010631225604031767, 0.06726592446544341, 0.018878871342167258, 0.048824472419385395, 0.01873560545832983, 0.04133572229849441, 0.028750424406358173, 0.043787360923098664, 0.05913134810647794, 0.017691928693758588, 0.05568741308525205, 0.04805282543280295, 0.08873648236372642, 0.04621810745447874, 0.025151313515380025, 0.022718853683077862, 0.011396472309050816, 0.033333711326122284, 0.01499078086843448, 0.025923099601641297, 0.03327208677572863, 0.01852817560679146, 0.006970557592077447, 0.036996205869529925, 0.004616283229552209, 0.036344591727746386, 0.004772398022136518, 0.007912943921318012, 0.02129699881853802, 0.0412155401759914, 0.07349829575312988, 0.03321206696065409, 0.05845957129661526, 0.0489670495901789, 0.08169501234910317, 0.020086046208494475, 0.05176355363801122, 0.0182371790786939, 0.03692069849265473, 0.027885814729545797, 0.052282181701489856, 0.05266137081863625, 0.035660116135009697, 0.07671589524086032, 0.019984525495341847, 0.057146544967378886, 0.012206955247425606, 0.0160266120718526, 0.050808077944176536, 0.021474639286420176, 0.07154617086052895, 0.024613764502906373, 0.028331534205270664, 0.011215940433820444, 0.02204721258021891, 0.09303348857377257, 0.01664120364668114, 0.033584301093859334, 0.010487542421157871, 0.04403833406312125, 0.03397800407505461, 0.04494869735624109, 0.02962932063798819, 0.05490514702562775, 0.03248394121016775, 0.047944578741277964, 0.035410723981580565, 0.07382598745503596, 0.039822718128561974, 0.0981322517618537, 0.09571954408394438, 0.032797926504697116, 0.03861628286540508, 0.0315115292822676, 0.03525894587593419, 0.03462244949436613, 0.05648239489112582, 0.030392940555300032, 0.02527437941171229, 0.01276859819024269, 0.04140687008787479, 0.056919320553008995, 0.013669097280528928, 0.11018867910440479, 0.0233852802443185, 0.05576105449082596, 0.02504172671719321, 0.08142158987798861, 0.028355089548443044, 0.03744320099108985, 0.03169954455058489, 0.07029021611171109, 0.054159654171339104, 0.030015044047364166, 0.038131930998393467, 0.03926004635702286, 0.028984298463910818, 0.027163468401080797, 0.004487312382220158, 0.01673944873203124, 0.03553912994850959, 0.011452811071649194, 0.041468464104192596, 0.06220448070338794, 0.03353733629254358, 0.043156038371047804, 0.038720743331526, 0.026236241816409996, 0.05420078696416957, 0.01864184718579054, 0.03265147489894714, 0.04393858941537993, 0.04128336653645549, 0.01734047130282436, 0.03864029621971505, 0.03980551387316414, 0.04071173470999513, 0.01729646321785237, 0.018272976889940243, 0.02684081482168819, 0.02959265260558043, 0.009062266891955264, 0.028509846422821283, 0.011411143084322768, 0.0968311405075448, 0.010485711224776293, 0.012727789397883629, 0.030471711685614924, 0.0542299877186971, 0.020761563442647457, 0.02774606704978006, 0.04272345194060888, 0.028278289562357322, 0.05193290580064058, 0.0243128851122622, 0.0027452820754011293, 0.0249348252213427, 0.04913709046585219, 0.04302632961688297, 0.03952774877793022, 0.05811772535422018, 0.021092311944812536, 0.03873202058353594, 0.03103486182434218, 0.018031046925378696, 0.03265650623611041, 0.02218985421183918, 0.020537372079810927, 0.05203332219805036, 0.002001062746525609, 0.016994482904140438, 0.05962939281016588, 0.023462877509051135, 0.05333392455109528, 0.00860768320438053, 0.030193861773503677, 0.094502720449652, 0.12119833725903716, 0.04247069425348725, 0.04716372064181736, 0.01011782480470304, 0.0664739723184279, 0.007846573018468916, 0.007314096055259662, 0.05770595637815339, 0.012153496017812617, 0.036342508625239134, 0.024521105457097292, 0.009434008239103215, 0.0039054228026153786, 0.032480650315327306, 0.061789902592343945, 0.032686093755598576, 0.01147378289273807, 0.0564990698892091, 0.061436697973736694, 0.02153847586097462, 0.023319301195442677, 0.015705580191154565, 0.015383403282612562, 0.1946695933916739, 0.18301707080432347, 0.1158410454435008, 0.15151885098644666, 0.1821897601974862, 0.1039308559681688, 0.1262187228671142, 0.08425677381455898, 0.17051857789712294, 0.17474099275256905, 0.11171014460601977, 0.14360251863087925, 0.11430834340197699, 0.11050875764340162, 0.08252699806221894, 0.08491850830614567, 0.1587663378034319, 0.07952114221240793, 0.08674466317253453, 0.10663392235125814, 0.16563411642398151, 0.12564154740955147, 0.11032094593558993, 0.07949327477919203, 0.1194424107670784, 0.2002039828470775, 0.15539905349058764, 0.08678956862006869, 0.14588333267186368, 0.16512142893459114, 0.12575450991945608, 0.12729916774800845, 0.07867073427353587, 0.0674177941733173, 0.08636407966592483, 0.10095778693045888, 0.12971043693167822, 0.13320015610328742, 0.0956361521301525, 0.24109974982483046, 0.11206626013985702, 0.18744789090539726, 0.16000178722398622, 0.10913499564464603, 0.10336881184152194, 0.144595364640866, 0.11962246681962695, 0.11122050695121288, 0.16637139900454453, 0.16454847396484443, 0.11887888743409089, 0.15091973170638084, 0.07673568132200412, 0.11623851768672466, 0.0994225200265646, 0.1940231802208083, 0.09806481216635023, 0.2417133083300931, 0.06601570333753314, 0.10217563515262944, 0.11523284736488547, 0.13115776569715568, 0.09585052848394428, 0.134027914543237, 0.208086008472102, 0.15424155417297566, 0.21608958686036722, 0.08801032775746924, 0.1595273283975465, 0.11858008775327887, 0.09416219086519309, 0.0896342656176005, 0.11974927144391195, 0.15144053447459424, 0.09001915782157864, 0.11936207222087042, 0.15002154133149556, 0.2004952507891825, 0.16343414304511888, 0.329934368708304, 0.12190169308866773, 0.16175942362419196, 0.06880522865269866, 0.1235291457601956, 0.1119437709982906, 0.12407900339790753, 0.14039756703589643, 0.13851911069027015, 0.23623563083154814, 0.11537265272012778, 0.12655211426317692, 0.22724076706383908, 0.06451470923743077, 0.13080575530018124, 0.11111363090042557, 0.19192877332014696, 0.11442104806857449, 0.17162572991635117, 0.08869895937719516, 0.06859395998929228, 0.0790961893009288, 0.1991036840315376, 0.11850892300052301, 0.13903510943055153, 0.13334106068525994, 0.09089233061032635, 0.121042382770351, 0.15680984993066105, 0.11378339478479964, 0.1408862072442259, 0.11379389850688831, 0.17528037380959305, 0.11599054027880941, 0.09229459107986518, 0.07623188264135804, 0.08565697153764111, 0.10723268200776406, 0.19111709616013936, 0.1864473774496998, 0.1508514303714037, 0.10112593469343015, 0.11181852021919829, 0.07653290791703121, 0.18281154254717485, 0.2569651742066656, 0.15332175924309663, 0.09433155999119792, 0.14552936809403555, 0.12177256787461893, 0.12366744476769652, 0.1162338765071971, 0.1040672075801662, 0.14865793021661894, 0.11794875163052763, 0.1419853661209345, 0.08964272016393286, 0.10230645670422486, 0.1258538474461862, 0.09664454337741647, 0.07674520795366593, 0.14486048184335232, 0.13953130851898873, 0.1905054511236293, 0.10640048594879252, 0.12388889145638261, 0.13635751525206224, 0.07561378473682062, 0.13208787435931818, 0.10828698971973998, 0.1722421654100929, 0.16374842689505645, 0.0735953805435981, 0.110701651578503, 0.17736829391547612, 0.12237144288207803, 0.07923025424991335, 0.08754200967294828, 0.12722040340304375, 0.1030885429520692, 0.09467035252600908, 0.14932194458586828, 0.09527327838752951, 0.0978176761418581, 0.09449134141738925, 0.08536232449114323, 0.21528485789895058, 0.07215196692517825, 0.17102043596761568, 0.11477714324636118, 0.1284427706684385, 0.1491315205182348, 0.11842878801482064, 0.08670615631022624, 0.17374632826873235, 0.08423930832317897, 0.10958738172692911], [0.05711297784000635, 0.014311592759830611, 0.026405968869637166, 0.026711542026272843, 0.018312611816717044, 0.03572544548660517, 0.01548202325856047, 0.008912996821371573, 0.014111603044771721, 0.12956470118037292, 0.0524018447447036, 0.04596308006771973, 0.04997920331412128, 0.010702027340552636, 0.03371206245252064, 0.02042422297277621, 0.06372442628656115, 0.05498162131490452, 0.02735659134175096, 0.05206510138564876, 0.013462777681914824, 0.06437927364770855, 0.008231807882631463, 0.014062134449237158, 0.013307128533987063, 0.01945580931247345, 0.019390317112473503, 0.11612166038581304, 0.02362445366036679, 0.01906816055998206, 0.02893351690311517, 0.06271727675838129, 0.0029096205003692633, 0.03319258622026869, 0.04189494371946369, 0.0342957450609122, 0.013481276242860725, 0.03275401511096528, 0.0058881424151227945, 0.04307348780067904, 0.047296438698789904, 0.039008245404277525, 0.007916317088529468, 0.01201261772907206, 0.04889794758387974, 0.02865929715335369, 0.034402458263295035, 0.009070267667993903, 0.03597957381446447, 0.09955055279923336, 0.049563834709780555, 0.03838054962190134, 0.013431964558549225, 0.0017155154907543743, 0.011653838097117841, 0.030630821362137794, 0.012237825198099017, 0.052480795686798434, 0.03806153977555888, 0.03831940683137093, 0.011251747574923294, 0.02125095173583499, 0.01905957709199616, 0.0567965735681355, 0.033252412652862925, 0.03250381889353905, 0.031111956973161017, 0.051230910433722396, 0.018694582927439893, 0.03401391893359167, 0.051047159757997305, 0.11289449355431966, 0.022203106000753384, 0.02468498862747635, 0.037911644604589255, 0.03752007222335253, 0.007303868836191083, 0.01293319636689765, 0.03282268964020269, 0.04253443922581417, 0.02776380056249244, 0.038678321322160106, 0.03910747775807977, 0.02721613798556583, 0.012387819604815116, 0.05148113039987428, 0.006885962086796228, 0.05609359432544027, 0.017347709575135793, 0.09243084091160979, 0.003181256303962852, 0.020952484537182108, 0.044778100081852505, 0.01394309226556548, 0.015403886558488011, 0.059933485064123354, 0.008799325242372496, 0.021765761343496184, 0.09884768551481621, 0.04355629600052323, 0.039013822962130816, 0.01018388951862497, 0.03510815843141504, 0.03983494532959802, 0.0378000696987978, 0.02459714378762458, 0.04151097771578601, 0.07219918617712599, 0.04445396051076906, 0.026689094391518405, 0.04144711060715573, 0.037318988370576074, 0.04176356237647789, 0.038826625328511, 0.030526218403662955, 0.02007417014933058, 0.03833761192592127, 0.034751204906829765, 0.04023818172780531, 0.04511199698650411, 0.07295474849109139, 0.02223048488875585, 0.055770394525357654, 0.020480490489197627, 0.028816459434373037, 0.04442146886140108, 0.028461480446692024, 0.02939484268426895, 0.04691028441967709, 0.044183292891830206, 0.024759167772052542, 0.03210109139659575, 0.013064473385124334, 0.04020411926986916, 0.03201015752607158, 0.04056579879085932, 0.045382936019450426, 0.07778334617614746, 0.018770068251926984, 0.03603401607168572, 0.0701737387904099, 0.027416629816538522, 0.024218207424772636, 0.029292553530207703, 0.03799843941149967, 0.01711487367616168, 0.03321614156344107, 0.015093239656250392, 0.021955069221024002, 0.041557172379855595, 0.03304339333304337, 0.05285836649792535, 0.021350567461922765, 0.028447519588683332, 0.01267665415070951, 0.05790404110614743, 0.03714653530291148, 0.024091821795861636, 0.035723474342375994, 0.0369502351220165, 0.02804692947704877, 0.013032251453426267, 0.017728584851803522, 0.01375913548482848, 0.023774457396939397, 0.01660542279881026, 0.025817953815151538, 0.019394047358738523, 0.025498938879796436, 0.010931703810846167, 0.02880952480648245, 0.026478275257561888, 0.0338752433391554, 0.022149863054177592, 0.08377140414501939, 0.02613865491002798, 0.006857138767372817, 0.06343334833426134, 0.054000473248639276, 0.03790428928498711, 0.05317093365426574, 0.0629202469385096, 0.02711973342645381, 0.041418774984776974, 0.05090400243976286, 0.032899062149226665, 0.044509963398533206, 0.02455833667357053, 0.12573513095932348, 0.009682036537144865, 0.03151506105703967, 0.03160342327984316, 0.04799951293638774, 0.04972082057169505, 0.01664335121001516, 0.006954407186380455, 0.03277507683794413, 0.055651152173855474, 0.008777262676241142, 0.0376465511508286, 0.029255006794950793, 0.006119254411065153, 0.045892336006675444, 0.10552143704678331, 0.026613783789798617, 0.056443552153983285, 0.06879314394401652, 0.035720800914402516, 0.030701185443571637, 0.011690780088039381, 0.01780071821329849, 0.02045267224977059, 0.01977117033675313, 0.029616262231554304, 0.0172044776180493, 0.019996628863736987, 0.04674487454550607, 0.07045904240970101, 0.016074769398463622, 0.014441966478313719, 0.01992084668017924, 0.040626432680125744, 0.07274843313332115, 0.036859379283019474, 0.015086876694113016, 0.07464736766581025, 0.008614702649148447, 0.07117571109639746, 0.02523778601815658, 0.02529881176139627, 0.02445870398410729, 0.028911026859922067, 0.024957121882055486, 0.013266396076817597, 0.01481672645812588, 0.023799134019230093, 0.03875385244776096, 0.04044439869799784, 0.03894472434850676, 0.029869484715163708, 0.00815287814475596, 0.041096871186579974, 0.02587532395097826, 0.07447219706539597, 0.04966406451006021, 0.05180582297699792, 0.04297087634248393, 0.07530585876000778, 0.045869968099785705, 0.04760509070807269, 0.04038369356255446, 0.019372374950242893, 0.027220709615253975, 0.017916835911039795, 0.054197329828249555, 0.04403662076219916, 0.023112444705995064, 0.05780159588903189, 0.0146045587358198, 0.029970969805227857, 0.015785034945500747, 0.042767950267131837, 0.022523401670956185, 0.053153301921806166, 0.005864660438549305, 0.057813544890710285, 0.024501573826585497, 0.02413567721045443, 0.019568064449621097, 0.021190424715834003, 0.0526105383677142, 0.03186143282800913, 0.01987290139576154, 0.08953414099024874, 0.08670974576047488, 0.06788416486233473, 0.018896489503926465, 0.03986310792554702, 0.05707986533109631, 0.04228830404047455, 0.05517105472141078, 0.01889493565873376, 0.06262944040021726, 0.04292824059458716, 0.020350466216249124, 0.017946781357750297, 0.08668457889663321, 0.06148603425494262, 0.07855018574212279, 0.008313422922843268, 0.0329958857037127, 0.043984207324683666, 0.0592218850340162, 0.030514520459941456, 0.031741118391177485, 0.029379005676933696, 0.06283827312290668, 0.04899526986160448, 0.022183503124064634, 0.04467687622777053, 0.023593344526099305, 0.03412391963813986, 0.01033571851439774, 0.024614597404641763, 0.02144834435811, 0.018327738058620265, 0.021395993685083728, 0.03876861736976674, 0.01633357283260141, 0.015219012907307063, 0.03228336625865527, 0.030193848202803304, 0.08074224061731781, 0.038433621238384924, 0.020848890899547508, 0.03939192642324737, 0.05934882536530495, 0.03351412360955562, 0.015612359657617552, 0.04884174792096019, 0.023216855978327136, 0.05794275152896132, 0.022071824741682837, 0.022338565339201262, 0.09062333218753338, 0.041890563775918314, 0.05890448670834303, 0.046428015655172725, 0.018034838239795396, 0.04677780045728598, 0.032829861755349805, 0.09959129204175302, 0.037228610898767195, 0.007810540264472365, 0.03203436087018677, 0.07663852189268384, 0.006143924248005662, 0.035692492433424504, 0.03356521390378475, 0.029515825478093963, 0.004439115615761173, 0.013732850734543587, 0.04254154688013451, 0.031331761607101986, 0.014535024163446255, 0.024249835638329387, 0.0367870711987572, 0.02697080516788576, 0.030756896561277763, 0.002663027515934248, 0.03477203593190227, 0.024299789386402284, 0.1397284772247076, 0.12708053019429955, 0.16304892514433178, 0.13459549551563604, 0.17438914520399912, 0.15874409542552062, 0.11288780319903578, 0.1090343010478786, 0.18786875903606415, 0.2989045823259013, 0.1413201575300523, 0.19947685115039349, 0.22658689000776835, 0.0686121243717415, 0.06722800114325114, 0.10907151190830128, 0.14976401015051774, 0.14385665713676385, 0.1186953844236476, 0.11726664751768112, 0.10966910448457513, 0.13017839539263928, 0.06568818805473191, 0.2036265270518405, 0.12108131710972105, 0.10494759998151235, 0.0831118341801422, 0.28041757004601614, 0.1621608720826251, 0.1386085958885295, 0.2336146400443145, 0.14167446137538978, 0.08742609553571258, 0.08674971825842347, 0.08478172921708652, 0.15106390682714327, 0.07200998347252607, 0.08256796800664493, 0.15463802218437195, 0.1425327267497778, 0.08314162865281105, 0.15694713113563402, 0.1356984813298498, 0.1683116156075682, 0.09966304711997509, 0.07881297556949513, 0.12506792747548648, 0.15800667713795388, 0.15148590132594109, 0.2740938679448196, 0.1039617768089686, 0.19715673636112893, 0.06661510081695658, 0.10768455240343298, 0.09819953529430286, 0.07857525082571165, 0.1145664309816701, 0.1190344076603651, 0.10793042635279042, 0.1543870320809739, 0.07494879327714443, 0.0985126927761095, 0.16305632117603505, 0.11994065903127193, 0.13987855560013226, 0.10723227488675288, 0.12687068645443234, 0.17093850964946405, 0.15888282869543346, 0.13888831516461714, 0.18882488273084164, 0.21453165688685008, 0.09668846494917359, 0.12097748768116746, 0.2047593548361744, 0.1228721881551402, 0.09392310905137233, 0.059386422990688255, 0.1064067759684154, 0.10226851302598204, 0.1223977157580001, 0.15140645844595774, 0.09499747425849948, 0.13421877287328243, 0.049119960849306414, 0.15143053286841937, 0.05812172871083021, 0.1860424413212708, 0.09419583263141768, 0.2338320698056902, 0.136024286704404, 0.09294150636664458, 0.11517533473670483, 0.1685352743204151, 0.11330950592777558, 0.14413339085876942, 0.05686190291973097, 0.1934893631509372, 0.1528548864381654, 0.14032994423593792, 0.1083044009283185, 0.12429530679115228, 0.113252468274108, 0.11007363349199295, 0.12887212048683847, 0.13052847875016077, 0.11976782259132181, 0.09849653685731546, 0.10734491169984851, 0.07546481915882655, 0.16043496397989138, 0.11411060472684247, 0.15060007385909557, 0.14605965678180965, 0.13597573073846952, 0.16284189053944179, 0.15787913969584874, 0.12998900269823416, 0.07818749520395483, 0.10862175175654036, 0.1845473436904805, 0.10466195709471192, 0.12483651989272662, 0.10217140109411307, 0.09867668790476662, 0.13662872569901602, 0.07150459023458616, 0.07621204227741275, 0.1968830967588084, 0.11461540763931614, 0.13406017209802354, 0.11226140681122031, 0.07520466883267675, 0.10108928701707295, 0.29126560794455664, 0.10458038361477, 0.21246185366596493, 0.2397329088832651, 0.06001594063958951, 0.0983531420518245, 0.12341477189745222, 0.15837879931288107, 0.08123829721340112, 0.13990923895367555, 0.07181551533618144, 0.16764274292758533, 0.08491443031068359, 0.1548068688384124, 0.14910323917865753, 0.13003966212272644, 0.09557971158730132, 0.14996200666895934, 0.11608481593430042, 0.09953318908810616, 0.06059555203786918, 0.19458005391061306, 0.1771396276141916, 0.11209636673863445, 0.12674684024282865, 0.20995050056704453, 0.18578250812632696, 0.10936342445867402, 0.14361019964729035, 0.07518406850951058, 0.11188403956059899, 0.054640643897333314, 0.156184050653662, 0.12877017738563673, 0.14098378057990754, 0.102910027174013, 0.1408200907920088, 0.1212119215301105, 0.145874647423625, 0.14446090614157064, 0.16792993965957845, 0.0741649903357029], [0.05986921422715698, 0.0322090531034129, 0.05767356311636312, 0.03268846523548875, 0.029896375057952743, 0.024239888314956, 0.03915572159790567, 0.024522660998627543, 0.026038954367062876, 0.009239216950455946, 0.05242430425382086, 0.03839127726054617, 0.05301215306722692, 0.0338398000624563, 0.06232213189027139, 0.0025401942298880643, 0.006688587276065456, 0.09256854959364448, 0.03271987462150199, 0.06162775307893753, 0.03387146389910153, 0.015730803034135273, 0.01839402244825448, 0.04471197684428521, 0.10084223920213324, 0.002024803202532764, 0.03953216604090162, 0.054955772523369105, 0.016563942256782736, 0.07155320048332214, 0.02000716990525169, 0.03552613939557757, 0.0639092999377421, 0.04696847897555147, 0.035426791690822156, 0.07213370076247624, 0.017145835229062607, 0.014643937515627061, 0.05531539947592786, 0.01464255669686411, 0.014148496690073183, 0.031151593596275364, 0.11407548375427723, 0.07756344654730388, 0.041830825552876504, 0.0094746923506526, 0.017228239914402366, 0.026616832108369896, 0.07001564691641501, 0.013946337359292167, 0.04707227787002921, 0.016802812028410177, 0.020654019034866775, 0.03200662914397461, 0.02391887000495834, 0.007360535840104733, 0.024457908401797925, 0.014879533355789525, 0.02664171568384128, 0.04226774103673441, 0.05599602438243372, 0.03916289371305278, 0.028435053204053214, 0.027641533641144633, 0.00896368338726461, 0.06150162020432098, 0.011891534851331795, 0.029547682697219507, 0.037476825793938975, 0.03678525611758232, 0.0833788105685796, 0.07598813250660896, 0.03605365966047559, 0.011528600888725902, 0.04691200111327427, 0.07552097471696989, 0.024246169852891138, 0.0753296956952129, 0.01843707379885018, 0.06711344407605273, 0.056500162330589125, 0.010766015737317502, 0.04197161478389587, 0.014646675404427307, 0.03011951469151037, 0.055242205903466256, 0.03910552018455096, 0.04256196739152074, 0.05394042289948889, 0.012623106711544096, 0.05383027630991169, 0.0018355621182958462, 0.024275826922218715, 0.013467159321797746, 0.03832041106319853, 0.012329096639794963, 0.04046325518616608, 0.005069846146008266, 0.0482424182950386, 0.0595264658331871, 0.016690344849069203, 0.013987945974804461, 0.01904428800168846, 0.005256831313350371, 0.06126742384263447, 0.015990363034818853, 0.007011958830324667, 0.03789824353797095, 0.023685338607590114, 0.01563300408555993, 0.011570030540627028, 0.0034931994201282835, 0.027006511376904588, 0.06188544710831983, 0.03939956333488226, 0.05213212028944066, 0.05663699230977467, 0.012628058320842683, 0.017363320969577347, 0.06456536866192307, 0.028486562493656362, 0.02487431007570454, 0.016470930372763957, 0.029090624901333025, 0.033633311678256304, 0.05623613417680774, 0.015189596717911107, 0.0315044521620231, 0.03271629874195371, 0.04702246661431023, 0.02322012821345457, 0.014394104314435805, 0.034534368863595385, 0.04258712747001222, 0.015317101929602879, 0.039352805486747196, 0.014707341524107116, 0.019689598553148762, 0.007012927863148174, 0.04739618334653122, 0.03285162915874805, 0.04561432324615972, 0.01584327869516398, 0.04410590597295335, 0.023968998475798538, 0.031413528469524214, 0.009641248949005135, 0.046183539487953694, 0.04205044358968735, 0.08360823004373483, 0.04997940348195178, 0.03386167942413262, 0.018411094389323677, 0.03125513464744602, 0.02720196678170136, 0.03330416791141033, 0.03564388557736363, 0.024780005582475235, 0.028732019143977335, 0.04292178772655981, 0.04185264045372605, 0.01711847330443561, 0.030942601417856555, 0.0782190877944231, 0.048298417790127654, 0.0378081069460937, 0.036931667011231184, 0.014648117291341935, 0.04123816592618823, 0.03938927335132446, 0.01819842285476625, 0.073103842990739, 0.01621347213430064, 0.058258847067398686, 0.052503041457384825, 0.04618561580511076, 0.06023294970925365, 0.035050489740180116, 0.03972728217818907, 0.01808816769958607, 0.04931723812062826, 0.009066768971803998, 0.048144095178161345, 0.02481972871880446, 0.042966866200523715, 0.03319288816835199, 0.023098529649100134, 0.0255448926639344, 0.030700724039758955, 0.060656688043049405, 0.03320037580228277, 0.019938113700066293, 0.048520268207149844, 0.08993295673280954, 0.017735005489417484, 0.09379492700099945, 0.04593711253255606, 0.022735330209668194, 0.08571937640330621, 0.012233206070959568, 0.11857970777366843, 0.02301491377875209, 0.05306646979546972, 0.02193889464251697, 0.03257842042616435, 0.043309438175388744, 0.031617160221295695, 0.02967782232112118, 0.02535155089572072, 0.11652696292315211, 0.01954233440171395, 0.01895716240895646, 0.016016042192599604, 0.051455960143357515, 0.026671525423548052, 0.009916380480197924, 0.041838462464511395, 0.06375996116548777, 0.0602075724995562, 0.041725846007466316, 0.026197107309209447, 0.04153574763664177, 0.013673545077576168, 0.024015495087951422, 0.028743632270821502, 0.03303874536816563, 0.01781662816314825, 0.011275710039106863, 0.07157919515988656, 0.0241746743143137, 0.04258703247510961, 0.015836106580016867, 0.017457988479041626, 0.04219827262152519, 0.03877297695726156, 0.03405237490577357, 0.02289392759225198, 0.014715165032872131, 0.01912427201334919, 0.015882793181974973, 0.03997031985116856, 0.04443128387044583, 0.0744794641754457, 0.033759030646511486, 0.0681871036067605, 0.025832589815503786, 0.07935728279075452, 0.028722078605954136, 0.029255013580300977, 0.024470498619068946, 0.04234605754858681, 0.02554319123737514, 0.04051959394876446, 0.08801490786884512, 0.021476761404690996, 0.06748341529497079, 0.05930969425077949, 0.0737424258674894, 0.07342843378760985, 0.02770667809194752, 0.05611811318833913, 0.004473413864616305, 0.07375800503151757, 0.04165741914351072, 0.06591257280004875, 0.03290426990549479, 0.048678441505346975, 0.07435228635690042, 0.010009844438172877, 0.01703217382808881, 0.08228731913758175, 0.08137770223298244, 0.07520879432559013, 0.033291428416435204, 0.06852922096316304, 0.024528136776228036, 0.02151008595579437, 0.05550506358434047, 0.03447842025863273, 0.025333250806267773, 0.01577253802679479, 0.04383196442254952, 0.005443972967831152, 0.017953278330553855, 0.03074103919789195, 0.010543779403503453, 0.006634828218791101, 0.02115432495650436, 0.022035538385223066, 0.020292834844440222, 0.01912004474018301, 0.04426466959661671, 0.011859883737218167, 0.03293332138231822, 0.05035762907937169, 0.04466522917417543, 0.030762874454792057, 0.03773874709648745, 0.028532662162823335, 0.00482314608026562, 0.04370552281449948, 0.06626786730651345, 0.02206895962756659, 0.01846869522705674, 0.01586715125345758, 0.06546796272907938, 0.07619608313377414, 0.0296178703595485, 0.061849613673985004, 0.06969944959772484, 0.02653302964089172, 0.01940670034049877, 0.022173199569806457, 0.0638839430840952, 0.017163031002772704, 0.02636235603131354, 0.035814883187413216, 0.06535465416631528, 0.026289639129702533, 0.05685035425371357, 0.009532629063219895, 0.020249345838757496, 0.04174416306029473, 0.010271992201783826, 0.038720750116876194, 0.008813627912396831, 0.05818105981286083, 0.04601621953770518, 0.05783455912023783, 0.0266042537654617, 0.04273666641009705, 0.017500295137454356, 0.06350624335131475, 0.0614776611328125, 0.039658543188124895, 0.029801203736237118, 0.01393851385052715, 0.026027388737670014, 0.015907076253954853, 0.02934910263866186, 0.0654641357915742, 0.020282846808965718, 0.03520558927474277, 0.02945578530696886, 0.04061793742169227, 0.0455694551180516, 0.031070047257734195, 0.015386421067108, 0.048452492736812146, 0.07437752785959414, 0.04252296519864883, 0.025815473769658377, 0.1519715152680874, 0.13559824813689503, 0.13850800985736506, 0.13446509465575218, 0.14194863023502485, 0.1145399274038417, 0.09896007805530514, 0.0972954620208059, 0.11411041473703724, 0.14731377948607716, 0.1635374974991594, 0.11133934557437897, 0.11604441595929009, 0.19637928450746195, 0.12757442226367338, 0.10437712166458368, 0.1211597557578768, 0.1804946440138987, 0.12988382977034363, 0.24179701240999357, 0.11146739191774811, 0.10428304956959826, 0.2692505935473101, 0.0947953929592456, 0.30957905096667154, 0.12302713841199875, 0.16024878754147462, 0.11523877776094846, 0.1276911845696824, 0.20311002619564533, 0.13444393793387072, 0.10060780535319022, 0.09964824148586818, 0.09916263432907206, 0.11789749509521893, 0.21854323734130177, 0.08952285695288863, 0.19125006188239368, 0.14220462792686053, 0.1605103492204632, 0.14878936244973115, 0.1282367810074772, 0.1990727564053876, 0.1012261611010347, 0.12439339581344809, 0.13124016698982033, 0.06918434652366809, 0.1302146834454366, 0.16326566279998847, 0.10602636888091053, 0.07121010603649275, 0.10879469676209347, 0.12673534585961274, 0.14353159815073013, 0.10668962329093899, 0.13483865532491887, 0.19011726123946054, 0.19161586011094706, 0.13351707266909735, 0.09577279551220791, 0.20465393763567719, 0.10239071039749043, 0.08580850197800569, 0.0938717643065112, 0.0913701888972095, 0.16227698299501622, 0.12185978676591601, 0.1696623752691916, 0.09286716607000146, 0.1581418141722679, 0.19014292343386582, 0.18540535122156143, 0.11755122510450226, 0.08719571254083089, 0.2331388241478375, 0.15149850850658758, 0.0972315033099481, 0.24929740279912949, 0.11090276935803038, 0.11890478033040251, 0.15958614381296293, 0.196106757702572, 0.27494903919952257, 0.12365220487117767, 0.17342937099082129, 0.11535488867333957, 0.10214456503412553, 0.12414720973798207, 0.22130661191684858, 0.1579208288873945, 0.10163840505161456, 0.11467752073492322, 0.09451364486345223, 0.09529771243355104, 0.17350935669881956, 0.24705329750265392, 0.20401483907231263, 0.10594104310231549, 0.16815324553421565, 0.15044228732585907, 0.06300783902406693, 0.15609698104006903, 0.09465779284281389, 0.058726663036005836, 0.1395180228033236, 0.17428697140089103, 0.10468741572861161, 0.08404291314738137, 0.23224000952073506, 0.13592570913689478, 0.11560731727097716, 0.1417998953589371, 0.09159275516867638, 0.11312843207269907, 0.11896955328328268, 0.13256028401000158, 0.10459774054054703, 0.10169417384479727, 0.14172195882669517, 0.14369124386991772, 0.1030725295256291, 0.07824833943907704, 0.18437139956014498, 0.10410366526671819, 0.12953240291348525, 0.13489989989570209, 0.1272173635661602, 0.08205764860446964, 0.1411066497010844, 0.08677627611905336, 0.2383040226995945, 0.08242812193930149, 0.18577192298003606, 0.10199797432869673, 0.11074631275343043, 0.08086563899580922, 0.08398833179048129, 0.13445445522665977, 0.0737830972565072, 0.1706217559320586, 0.12934163957834244, 0.1881258830960308, 0.11936370070491518, 0.1597307396254369, 0.07122265214898757, 0.08744304534047842, 0.07625877976949726, 0.10194873304239341, 0.07689437030681542, 0.14702768198081426, 0.14606322587600776, 0.22998151928186417, 0.08673787103699786, 0.10336223683719124, 0.258241525718144, 0.11629516179008142, 0.1000008082815579, 0.1256877149322203, 0.08901926183274814, 0.08661481192601578, 0.09008601387696606, 0.06859723052808217, 0.11218888498842716, 0.15411757225436823, 0.13579392406557286, 0.09003634511360101, 0.09135087100522858, 0.09518253111413547, 0.11606117577425071, 0.14816904573568276, 0.10574677174112626, 0.16392291896045208, 0.08166284978921924, 0.154122511989304, 0.12064933457544871, 0.12194535003176757], [0.0433617192985756, 0.012825418712704309, 0.042551300821027586, 0.011245189533968056, 0.02570637551668499, 0.019578557993684496, 0.03232995108036058, 0.02459630579687655, 0.018747038773394058, 0.026732154223801832, 0.026207354884328585, 0.019562118786520193, 0.02446590663333024, 0.0712762496301106, 0.020884732815570066, 0.005989641924056092, 0.04986771661788225, 0.07249501387455634, 0.06497932252074991, 0.03599334468266793, 0.030677952404533113, 0.06228635273873806, 0.030540701733636003, 0.023954681386905055, 0.026351563931841935, 0.05705686977931431, 0.013459419781741287, 0.0168481856651072, 0.01548934295507414, 0.01629713041308735, 0.015811667444982698, 0.04170526604035071, 0.02511646904583488, 0.02177821076475084, 0.005793428256375981, 0.0889255493613226, 0.05384177408580269, 0.06925680049295936, 0.02624497625843755, 0.049913951994052956, 0.02695699528391872, 0.0719309002161026, 0.015529210280094827, 0.054467169634465656, 0.05667796903955085, 0.03715711027117712, 0.023571924871898124, 0.03225198062136769, 0.02844421342680497, 0.07129479399217026, 0.016753786176975285, 0.039674237703106234, 0.019385044895378605, 0.0664841164169567, 0.03796258901378938, 0.03239101923203894, 0.04694618570751377, 0.04088318354583212, 0.02323276762451444, 0.010213288744645459, 0.03959134786522814, 0.0037785168221619514, 0.03476989854659353, 0.011770441795566251, 0.04831709785919104, 0.023001977508621554, 0.03964519301163299, 0.03452244021796754, 0.07075126708618232, 0.04124857804604939, 0.022161041918609823, 0.08475951398057596, 0.01669547627014773, 0.0380792529322207, 0.002861596760340035, 0.008155038430621582, 0.045874514284410646, 0.004545764357317239, 0.03520701080560684, 0.005048895953223109, 0.013903740627158965, 0.04904977318697742, 0.02038004864672465, 0.018548652097316723, 0.05018934900207179, 0.04843093567926969, 0.028842840875898088, 0.034820177991475375, 0.016044942695381384, 0.047237826843879054, 0.039351943747273514, 0.03800421713718346, 0.017101355562252656, 0.026922880239518623, 0.039586835607354126, 0.028036863410047123, 0.019568040700895444, 0.07906560094228812, 0.05673654357503567, 0.03581221993746502, 0.03059632464178971, 0.07372650743595191, 0.049515685864857266, 0.0636208818427154, 0.04166392629433956, 0.021502148792413727, 0.020373763716114417, 0.005545694696983057, 0.015131066287202495, 0.004161629143969289, 0.052337926745946915, 0.06375352186816079, 0.033984321236078224, 0.02892967639490962, 0.030705572172467197, 0.06987763289362192, 0.05297574966347643, 0.0040016131991121385, 0.03225816207538758, 0.00810778355558536, 0.05935621461165803, 0.03555524515520249, 0.04123423042308007, 0.020617227169818113, 0.06643518047141177, 0.009630258378040577, 0.020754847642300383, 0.045400537217834165, 0.046784080298883576, 0.02420596495669867, 0.012062550272925623, 0.043928190866219144, 0.019634019749771272, 0.02817055516477142, 0.019279040762090256, 0.05513793881982565, 0.004859559662041387, 0.012635692687971252, 0.011075079956624125, 0.04895438473405583, 0.04137727917571153, 0.018940170195751956, 0.06767236015626363, 0.051096455327102115, 0.042942808741437535, 0.06365811305918864, 0.023710295125576, 0.00861161870748869, 0.02684925918999527, 0.04404188958661897, 0.07084014838827507, 0.0683320861841951, 0.03632715337776712, 0.0438716858625412, 0.041225789447448084, 0.04883766992549811, 0.02245449474347489, 0.01066818879917264, 0.05208747947056379, 0.0559190208358424, 0.026953071655173386, 0.029822319746017456, 0.01088321824291987, 0.08591972743826252, 0.021465346749339784, 0.011154471946481084, 0.009009316563606262, 0.0519625170688544, 0.016126438143796155, 0.04281610929008041, 0.021792641508259943, 0.030567357981843606, 0.05994423305881875, 0.03331554355099797, 0.01659387074011777, 0.03230925236961671, 0.007638679218611547, 0.04248425816851003, 0.029422988316842487, 0.03603373108697789, 0.014598475669377615, 0.05673508472474558, 0.01420091521660132, 0.07834397894995553, 0.022647424301664745, 0.06498455402574368, 0.057164655067026615, 0.052990317810326815, 0.00916075794624963, 0.03261191291468484, 0.0009100939995343131, 0.01956576421590788, 0.01972041591735823, 0.022040973450722437, 0.0346513856202364, 0.028793009264128547, 0.04467972607484885, 0.06926011852920055, 0.04294829469706331, 0.035534997670246024, 0.02538652259058186, 0.04853096191904374, 0.07082202471792698, 0.011936997545750012, 0.03516708241243448, 0.024583834323233793, 0.027872345809425627, 0.043113063355641704, 0.05988013185560703, 0.09129312088979141, 0.05056361195498279, 0.028869154463921274, 0.03534030561734523, 0.04928158449807337, 0.030317121052316258, 0.021949822448992302, 0.06931460489119802, 0.05155166072238769, 0.08680877116109643, 0.03082015298839126, 0.07027142747704472, 0.07719758725059883, 0.017983651254326105, 0.025277895919446434, 0.03301283550847854, 0.05520748865923711, 0.007541855664125511, 0.02375313952299101, 0.03335044739235725, 0.05255228274368814, 0.05921200556414468, 0.0430472997416343, 0.003429420096966039, 0.016055585517148887, 0.023257400142028928, 0.01448924679841314, 0.027564596251717637, 0.023475657716127377, 0.03719811414235404, 0.018280678262401904, 0.04100302640082581, 0.04781337042472192, 0.012121548892797103, 0.023525998229160905, 0.07798545461680208, 0.07325282213943345, 0.09227659633117062, 0.07056730945727654, 0.017552572867966125, 0.01699626405856439, 0.04793185281700321, 0.023747687494116168, 0.047999265271105936, 0.05983508391571896, 0.03596001843522702, 0.014835935784503818, 0.030875494304512228, 0.040572221124810834, 0.010128619448680962, 0.02335185730563743, 0.014096018791730915, 0.030430375332278863, 0.013507174228184989, 0.030944827012717724, 0.03252490097656846, 0.02559987096382039, 0.050398904364556074, 0.022169486286916902, 0.027536431959431087, 0.03063123526849917, 0.06613182103527443, 0.015884850839419023, 0.014394358765067799, 0.015286118324313844, 0.052104307139026265, 0.033817557684545, 0.025111817688282047, 0.017093671153166463, 0.03803688859833138, 0.030944653986287967, 0.010163420661618667, 0.028422337457803742, 0.04853277700021863, 0.02009507411691759, 0.04538559926939862, 0.07487389658178602, 0.01029816669012819, 0.05606111963944776, 0.04668789795999016, 0.04785210459626146, 0.019329484751714126, 0.03838943164529545, 0.06376639367746455, 0.04409161602546062, 0.01914670268472816, 0.030190112867525647, 0.046002642051982026, 0.05761689865695579, 0.04805352432387216, 0.04962404790733542, 0.04318753257393837, 0.05254334983016763, 0.07370862803821053, 0.021856164260368263, 0.07306499686092138, 0.046228200662881136, 0.010877131783802594, 0.02332527399994433, 0.043136001231947114, 0.031762916328651566, 0.027333134386156286, 0.015477877409596528, 0.04584875370242766, 0.021539505537865416, 0.023096285394525955, 0.04379457714302199, 0.009810328001289495, 0.026225582031267028, 0.01680046090457056, 0.04763833213863628, 0.05452109620507274, 0.012600588678781475, 0.0158745455888233, 0.07395018650484936, 0.021594176800655465, 0.034135593833135705, 0.08867426748786654, 0.030583273020706007, 0.015299056290781923, 0.019973149855754206, 0.02706178483952369, 0.051707706813301356, 0.02169729207110192, 0.01642558048479259, 0.0586826532546963, 0.027100678466792618, 0.010605436184310486, 0.01884703617542982, 0.049139098929507394, 0.008259491263223546, 0.03736137306051595, 0.0727196903899312, 0.022761243462030376, 0.014262212373848473, 0.0371115364666496, 0.06340601694371019, 0.033915144590927024, 0.020320205250754952, 0.0636231888617788, 0.023552157450467348, 0.034720280673354864, 0.05369821982458234, 0.1647247980747904, 0.17870533359902246, 0.07898199864264045, 0.09640098323247262, 0.12637895212641784, 0.09284117139343705, 0.08985210928533759, 0.17544101018990788, 0.07451321450727326, 0.11263653489628009, 0.17202986537345819, 0.12315633147954941, 0.19230480385678156, 0.22858539276889392, 0.08409965224564075, 0.06257145279752356, 0.11679392574088913, 0.12380334176123142, 0.13866720774344035, 0.22804449179342814, 0.09431610296347312, 0.10006650404206344, 0.1414528111261981, 0.2348893087889467, 0.10410861178700413, 0.17024100279169424, 0.16767482406326703, 0.08154787881565945, 0.06902213594210999, 0.0720970191593681, 0.1139460192727191, 0.17696699473474706, 0.3246973268687725, 0.16835852951875754, 0.06532353655036006, 0.13557947985827923, 0.1568701716938189, 0.1354593113064766, 0.10065442749432155, 0.11497785390487739, 0.1674491704574653, 0.14353014608579023, 0.13542898079114302, 0.13649016884820803, 0.13840973084526403, 0.218589418434671, 0.14058254925268038, 0.08185967922742877, 0.13389986141451768, 0.15310773572751454, 0.08078041499746696, 0.09869548332478319, 0.16865586356392928, 0.11401024939758436, 0.15070882945188455, 0.14977593879614556, 0.14056649511413916, 0.141865021150027, 0.06477353642029421, 0.0870116124195712, 0.17268975424979413, 0.12412473665816443, 0.1365691910364798, 0.11279504746198654, 0.14031395795089857, 0.11218209285289049, 0.11851106717118196, 0.09978796541690826, 0.15926196692245348, 0.10832724041704621, 0.19436072425118514, 0.15241576571549686, 0.09277787086154733, 0.16295859856264933, 0.09511985483446292, 0.05694537290505, 0.1366574005889041, 0.11588970997503825, 0.15945657076580183, 0.0750433946294444, 0.2299498181257929, 0.109803617266672, 0.09251473498131547, 0.14408944893096173, 0.13556149868028505, 0.2392940324332033, 0.10723804921976157, 0.15941705288631575, 0.08261760284325906, 0.2019232413066285, 0.1522886896772044, 0.07833448624504463, 0.09415247424372605, 0.1435694739754711, 0.2748719576214041, 0.10207664367875882, 0.11369707155972719, 0.21226670699460165, 0.1134263225165861, 0.12454397630478654, 0.12424358885203089, 0.1241473997277873, 0.13361584022641182, 0.1568090764007398, 0.10783281909035784, 0.11394367154155459, 0.09648557619324752, 0.19260943893875393, 0.07485751674643584, 0.08414881889309202, 0.0963492381519505, 0.15087576263717242, 0.17834619858435222, 0.2088956364563533, 0.11826260121805326, 0.18266337764050278, 0.16362972397889408, 0.08272470959595271, 0.08290131190525633, 0.09780606640768902, 0.11087847780436277, 0.1728502142110041, 0.148119716239827, 0.1061070127678769, 0.15079475912664617, 0.0996991858950683, 0.18450450098940305, 0.10231151179011379, 0.165316195626344, 0.10578849485942296, 0.14379104280046054, 0.2038964211408581, 0.1513522570686681, 0.0885628859645554, 0.11592002691967146, 0.13207207806408405, 0.09131887807909932, 0.05571656294965318, 0.1221567408314773, 0.14955640557621205, 0.14154506474733353, 0.10902746141489063, 0.15942944293575628, 0.14339723464633736, 0.1948301347770861, 0.09960600268095732, 0.05699640552380255, 0.13603253769023077, 0.07315055334142276, 0.19643697355474743, 0.1360774974205664, 0.21360964993281023, 0.09434651490300894, 0.1007514444312879, 0.1993698054658515, 0.1287381233913558, 0.07640401340488877, 0.06732182218027966, 0.19405581775520528, 0.12822454023574079, 0.1373873142791646, 0.10184402151831559, 0.12318370358220168, 0.13347946825836385, 0.1718662977218628, 0.13574941216834954, 0.14316927402147225, 0.1479698685663087, 0.0994157889591796, 0.13894326293042727, 0.1019696726330689, 0.1274813815419163, 0.15180391711848124, 0.13934505065636976, 0.10678238581333842, 0.17538147552737168], [0.027346121546413218, 0.020550973314259733, 0.042404608335345984, 0.044039127949093065, 0.005376047371620578, 0.01840282983279654, 0.029588157311081886, 0.04501255428684609, 0.04709032350885017, 0.017002141868163432, 0.010026527917943895, 0.05398916206987841, 0.019243561862302676, 0.044680950830557516, 0.019815997752760137, 0.008260219840199819, 0.054302937018551996, 0.04725700563618115, 0.016376982110419443, 0.015050921123474836, 0.01796396016808493, 0.020120269818497554, 0.04168070646535073, 0.05932589766702481, 0.021661986197744097, 0.013433308906054922, 0.03483819309622049, 0.05940545589796134, 0.07969915587455034, 0.021316686512104104, 0.01679990959486791, 0.08316674801920142, 0.06159038615546056, 0.02667118445970118, 0.019349922226475816, 0.01381097810475954, 0.02463026308188481, 0.03039996339274304, 0.02222791493737272, 0.04560606547498277, 0.03307613264769316, 0.024747815881190554, 0.02071483273591314, 0.02017866793487753, 0.03016807065744485, 0.02770703941184495, 0.04440324341080018, 0.028877205281917537, 0.03143914995182838, 0.055404623438205035, 0.03517822056476559, 0.017887864162081053, 0.02554465178400278, 0.013962835938270603, 0.027649994972827177, 0.019870384030842354, 0.0676484757236072, 0.02696308513571109, 0.012664665285098766, 0.02684441614629967, 0.031878860999963114, 0.029409624569650208, 0.08101810581449952, 0.017540644222338284, 0.04257682052307895, 0.0638425253065569, 0.04243008053994604, 0.04347902782527464, 0.04583233315497637, 0.08886739891022444, 0.026548493453966718, 0.07404771912842989, 0.015690664295107126, 0.07374148948916368, 0.018297600925766995, 0.015158445175204958, 0.05208199012226292, 0.03937871873910938, 0.0410721114437495, 0.1016506797501019, 0.00425837975594082, 0.05845646360622985, 0.030170411603259187, 0.049159811210951636, 0.012877189238289637, 0.08004222996532917, 0.09704064497990267, 0.0312860690589462, 0.009058711368457546, 0.027579688566869924, 0.01796755301100867, 0.007503114707235779, 0.018495728062199693, 0.028677475106503283, 0.09079116782439606, 0.049482848162629774, 0.024894638984863247, 0.04158535193918007, 0.02144910940634353, 0.03362487409529941, 0.0787315581526075, 0.03056140722973006, 0.0555541996977159, 0.0213132480358971, 0.01519169339111873, 0.03093410955209817, 0.022455884043925574, 0.03973204210134489, 0.054507654426353316, 0.016924822802788446, 0.028915406803467443, 0.013288370433396526, 0.04986890744683998, 0.004875208375908966, 0.061506444588303566, 0.005780872814024666, 0.03390816246558513, 0.017636904592758844, 0.05479792831465602, 0.04375156141551478, 0.04130687777485166, 0.03469074743666819, 0.05360964047057288, 0.02443358631405447, 0.008635884816093104, 0.02979200958673443, 0.020472205576619933, 0.03990850531096969, 0.03174241100038801, 0.07872720874313797, 0.011518260863210474, 0.0693493051720517, 0.051125506803925545, 0.016706180160066912, 0.05154290422797203, 0.040155583659985235, 0.047157108318060637, 0.043956570593374114, 0.021859344893268177, 0.08054611685552768, 0.07292926271579095, 0.04229689768648573, 0.02645639419954802, 0.047819412779062986, 0.06196175515651703, 0.06476488509880644, 0.0718665411695838, 0.03195214956732733, 0.01692383044532367, 0.0378418912046722, 0.05126426721523915, 0.06732987639095102, 0.0463110022912068, 0.0413009846982147, 0.03987519941957934, 0.06471929433090345, 0.021472410298883915, 0.03785374860412308, 0.09689969290047884, 0.029744484994028295, 0.016570371376084428, 0.05652877615232553, 0.07367257747266974, 0.010691739053332379, 0.04943002760410309, 0.04897750581481627, 0.07196248602122068, 0.024039520316624215, 0.022859537741169333, 0.056090971787593195, 0.0190590291749686, 0.006448695461066174, 0.042300561775586436, 0.016302082022385936, 0.054442548991314, 0.04140493626307164, 0.025641838354723792, 0.02110028133860656, 0.04382564386885081, 0.012461098842322826, 0.012529674983982528, 0.042958557539220364, 0.0339547642506659, 0.012868598136784775, 0.019903837503599267, 0.03541499875219805, 0.058483876420983245, 0.07389796644981418, 0.08247367199510336, 0.007170417113229632, 0.07680551614612341, 0.039343153326106925, 0.044860562442668846, 0.019311506966395036, 0.05428573615582926, 0.02693350100889802, 0.011336594986330186, 0.021276488401261822, 0.03382015986634152, 0.02697480682815824, 0.05092334747314453, 0.02055208950436541, 0.021162591209369044, 0.00874303312905665, 0.08365803451410361, 0.040763449256441424, 0.01115022601360189, 0.0671433810410755, 0.05474308572177376, 0.012626510412831391, 0.03580321577776756, 0.038350992636489015, 0.006409962985864175, 0.02089763685528721, 0.013109170183140253, 0.01495261157729796, 0.06637077392744166, 0.0780998013381447, 0.0339016485294061, 0.01697980279901198, 0.029784399816500287, 0.051362050896776576, 0.041202854963817766, 0.04780434930164899, 0.04367954510131052, 0.0801638573674219, 0.01607580077169197, 0.012632656243762799, 0.07229093089699745, 0.03965742699801922, 0.05347517179325223, 0.06963637976774148, 0.0772229033921446, 0.005059181695937046, 0.03222518188080617, 0.030191507256988968, 0.006631099668863628, 0.047294959492449246, 0.06758850001330886, 0.0344785322169108, 0.08550749027303287, 0.029482845283512558, 0.03250029729679227, 0.031946660219026465, 0.03233082639053464, 0.04798231885901519, 0.031001118277864795, 0.00913082861474582, 0.051368541084229946, 0.0241444269195199, 0.061448314493255954, 0.04706474273864712, 0.08184097201696464, 0.03090000298938581, 0.06961921961711985, 0.06086442153900862, 0.030783301751528467, 0.054268609931958575, 0.02360824854778392, 0.021443533544827784, 0.09003694222441741, 0.07800811768642493, 0.049335022523467026, 0.017909433093986342, 0.014448534697294235, 0.05947733311248677, 0.04191368824935385, 0.05272742281002658, 0.01495188384849046, 0.019777326345709816, 0.039694797314171276, 0.03525259478815964, 0.04019127460196614, 0.04795050574466586, 0.04508059099316597, 0.01986164619613971, 0.08081455887960536, 0.03594902277524982, 0.011513249882097756, 0.030039919141147817, 0.01846803704808865, 0.01542983713027622, 0.023713718334745084, 0.01585150762860264, 0.01964331228685166, 0.030285701488277743, 0.03220846277794667, 0.04865269110138927, 0.01755237439647317, 0.021164384238155823, 0.06389256726418223, 0.022522807952814868, 0.03976518175165568, 0.04082668532750436, 0.026645810642678822, 0.04140654778374093, 0.06584376934915781, 0.006882401474285871, 0.05317021779982107, 0.043709220830351114, 0.01611097263438361, 0.0453127144303705, 0.02014328402999256, 0.03153503034263849, 0.02162718752931271, 0.03938674920105508, 0.05309586053980248, 0.0472591871262661, 0.05125536144311939, 0.026866672094911337, 0.0456887890717813, 0.016236979980021715, 0.03146834731368082, 0.039102717834923945, 0.025063980969467332, 0.07327551235045705, 0.0487456537916192, 0.07689506919788462, 0.021111309228997146, 0.018452622428802506, 0.03671721262591226, 0.05197850674656885, 0.027429600013419986, 0.02513875383218484, 0.0015250085146232906, 0.07654757784413439, 0.06955150182225875, 0.02712177751319749, 0.057518151455691884, 0.06896818562277726, 0.01831694595914866, 0.008020646088490528, 0.047387169008808475, 0.04382415787715997, 0.027532834027494704, 0.02232662821188569, 0.014118006719010217, 0.035092765864517005, 0.052855642179825475, 0.06603601189064127, 0.03899720224684902, 0.01692396106331476, 0.016030644266200916, 0.01931959849649242, 0.024408870676000203, 0.08161347958126239, 0.04946379829198122, 0.01910165644117764, 0.04737457539886236, 0.021797233493998647, 0.036185872208859236, 0.06998699916792767, 0.10933265289557831, 0.11249577280666147, 0.17130174301564693, 0.06703303767634289, 0.10078733214842421, 0.1554945505091122, 0.21149389632046223, 0.08465570490807295, 0.12130698428622314, 0.1141234426093953, 0.11337669446532216, 0.23598351436001913, 0.17056414830897534, 0.14243979459362371, 0.18213086335786752, 0.08053766230919532, 0.19610071874090604, 0.16294980474880763, 0.17977646897946084, 0.19217548865292752, 0.10639138679419245, 0.0954315195392285, 0.10308253113180399, 0.08350540484700884, 0.11210680939257145, 0.06740973996264593, 0.10712706803211144, 0.14815303230924265, 0.25189564909253803, 0.1389218076531376, 0.12351356659616743, 0.19745715095528535, 0.14150934666395187, 0.09996756006564413, 0.18816173688641616, 0.06999224424362183, 0.11684021539986134, 0.1289202557610614, 0.08000120573810168, 0.11408002993890218, 0.19117991493216582, 0.09801988636276551, 0.10322964430919715, 0.0976427633847509, 0.14004204182752542, 0.08965361065098218, 0.11367925323013749, 0.19312235713005066, 0.1859100591391325, 0.170047240331769, 0.10960559360682964, 0.0745955750878368, 0.16935715664710316, 0.07466795441827603, 0.1347560097596475, 0.2098586947790214, 0.22696346337241785, 0.1157354653945991, 0.1400496142783335, 0.0869305342701929, 0.1019864392333797, 0.13511996237295015, 0.13938093158815587, 0.1230525156216962, 0.12381983016218458, 0.17117260423089775, 0.14322574170572416, 0.1154964989317315, 0.19338457020265715, 0.1291937596563782, 0.10805482896310942, 0.13049851464373724, 0.09866332755024944, 0.13828806951642036, 0.10873808658548764, 0.18245955929160118, 0.1794688076313053, 0.10248221763010536, 0.17977041644709452, 0.14488581834094866, 0.16834909788199834, 0.1856994011572429, 0.11124384855585438, 0.13739088337336267, 0.1843806683484997, 0.18330177052744798, 0.18704037634389742, 0.1328892513577427, 0.13208364030080183, 0.1266770732722112, 0.09588017367890903, 0.14544296344476088, 0.11949753495199339, 0.1628108543476888, 0.1694434391600745, 0.09545308338212115, 0.07114850862749986, 0.07255171904606478, 0.11145366515432086, 0.10127634555101395, 0.20698408117251738, 0.20785822426634176, 0.20371270099920885, 0.14335257347140992, 0.062104281437184126, 0.140544076317123, 0.0789634474952306, 0.16409218630620412, 0.11131732032767364, 0.16317435912787914, 0.11366896663925477, 0.09707604415182557, 0.17188825511506625, 0.11361609519060169, 0.11306534867201533, 0.1327975405646222, 0.11006576927112681, 0.09943921877337353, 0.10838222210960728, 0.11466150730848312, 0.14618110097944736, 0.08663781426314797, 0.18433068745902606, 0.10970389976033143, 0.07716309053025075, 0.14020005906266825, 0.0613502458270107, 0.06735912803560495, 0.13743582953299793, 0.15315823230360234, 0.10999085900506803, 0.22055708856454917, 0.1569451362426792, 0.12671294063329697, 0.14079763128289155, 0.14369394443929195, 0.11032525463295834, 0.1088216956704855, 0.1576942117618663, 0.20052981536303247, 0.20314543215291841, 0.13230767899325915, 0.20557166981909955, 0.08797938656061888, 0.14355427479105337, 0.1477927437850407, 0.1751263735017606, 0.1544353844864028, 0.12417767596031938, 0.1276443927947964, 0.09576845288808856, 0.1275538762233087, 0.13160169044775621, 0.13677028167460645, 0.14664036062146935, 0.22359384489910944, 0.0856896158573883, 0.15794092709464685, 0.168030674968447, 0.12536095960864, 0.050077061634510756, 0.0994029442912766, 0.1281909934644188, 0.17024370336106845, 0.1640292318271739, 0.1302735260022538, 0.21686615661850997, 0.08704422281256743, 0.11432673170098237, 0.16957556349890573, 0.10773061814584903, 0.09188913247947182, 0.17466336834643567, 0.10256486319537673, 0.17502555676868983, 0.13512914973710263], [0.03884774473096643, 0.01832149044743606, 0.044284106232225895, 0.019208579989416257, 0.0294227304735354, 0.012645790985386287, 0.003757818111418081, 0.03119842947593757, 0.03518120272617255, 0.06483271824462072, 0.02053606589990003, 0.05126174306496978, 0.07029871137014457, 0.04891502291762403, 0.016346739804638282, 0.033704873373998065, 0.01099605267933969, 0.03841683088934847, 0.08043375824178968, 0.06729016173630953, 0.01991575427486428, 0.04519167735374399, 0.02908407025305288, 0.03001748338075621, 0.011202022832419192, 0.023377907961340885, 0.03506387384342296, 0.034304131753742695, 0.04108086454549006, 0.013754746211426598, 0.03276047815701791, 0.02537613082677126, 0.02408949611708522, 0.029549962574882165, 0.031188987661153078, 0.01742074708454311, 0.039311441992010386, 0.01257425982372037, 0.01442226012503462, 0.06742280854710511, 0.03293020012123244, 0.04033258291227477, 0.020265094636540328, 0.02425177624848272, 0.09498679411730596, 0.044964670070580075, 0.03076474042609334, 0.005231254359906805, 0.036209101855222664, 0.032234823863421164, 0.01245106415756579, 0.039459399945501766, 0.009065266864906465, 0.054710573716355224, 0.006733455828257969, 0.06893103583050625, 0.013015416151444827, 0.05107584821858576, 0.05535609122099621, 0.008262469183786638, 0.028532292361238172, 0.02493702367480312, 0.07762897945940495, 0.045324792353702445, 0.038905335390674214, 0.022858964379078577, 0.039409765108887634, 0.03693307497139488, 0.02494138665497303, 0.04695063689723611, 0.004318520010981176, 0.05836771122579064, 0.10540994695786919, 0.018439385906926224, 0.0523868830475424, 0.02641167365280645, 0.027931312198883722, 0.029812514914997985, 0.05646715499460697, 0.055624177014189105, 0.05040671430262072, 0.11079712824097701, 0.035987159835972955, 0.03589127944516284, 0.04253139938893063, 0.02927099307999015, 0.022100732029814805, 0.022212462998660545, 0.05407467783827867, 0.040600098736052, 0.013962531445680984, 0.018509487056040337, 0.041500338286693604, 0.05739800325993981, 0.0521202018218381, 0.03490421116085989, 0.00957697132668857, 0.04685569967010191, 0.012080187094397843, 0.03454381407105497, 0.04636838939040899, 0.01794516135539327, 0.05966973171702453, 0.0690351366730673, 0.020518944765041982, 0.004915619801197733, 0.023815715718748312, 0.01491482396210943, 0.033753622722412856, 0.025673941542793597, 0.04065580985375813, 0.01188991654531232, 0.06785299974892821, 0.019595350039058497, 0.0196450747815626, 0.01753050012380949, 0.047432742813335996, 0.007879237694266652, 0.04637264719765101, 0.05568602548113891, 0.05812606454959937, 0.021720640461093614, 0.03435830259695649, 0.017677871144509742, 0.020068216004541943, 0.08324684229280267, 0.01608110182652516, 0.029110122605093887, 0.019794813889477934, 0.023558042045416575, 0.0540866098765816, 0.05316793452948332, 0.021586984329457794, 0.0517776671663991, 0.03831366642511316, 0.052933446397738795, 0.017620787689728395, 0.047827731618391614, 0.0392056583826031, 0.008525878174363502, 0.032747097446450164, 0.020180182764306664, 0.033218214487923045, 0.023640436552731053, 0.030898303259164095, 0.07487050390669278, 0.02974393538066319, 0.02714573997738106, 0.016992913791909814, 0.06422235563929592, 0.018296225196016685, 0.061955756906952174, 0.038677066032375605, 0.01999505466249372, 0.03629599504971078, 0.04667781153693795, 0.002257514208655006, 0.0493095333554915, 0.04376456893182226, 0.021104578161612153, 0.013246468351488667, 0.01979768239626927, 0.052680237484829764, 0.05572422021733863, 0.03507240981395755, 0.052332786843180656, 0.01944932760670781, 0.016596852901524732, 0.04931087685482843, 0.05585563209440027, 0.03392103427488889, 0.011489826005085238, 0.02098159199314458, 0.03615183010697365, 0.017449827399104834, 0.08315167775643723, 0.029239990814988102, 0.01364105342820819, 0.026176150755158493, 0.007828725002972143, 0.006320881940025304, 0.018371858101870333, 0.027926766014258777, 0.0060217697090203205, 0.07121224342180149, 0.03319188393652439, 0.06667739033166852, 0.06571998420570578, 0.034137558192014694, 0.056669860546078, 0.025371264034350003, 0.037960007188043425, 0.03535613923200539, 0.0281420244635748, 0.08910631109029055, 0.045245223944740634, 0.06435226795396634, 0.04343761004773634, 0.02398338681086898, 0.043556994891592433, 0.02060768866379346, 0.055542450863868, 0.025725194685427204, 0.038418527226895094, 0.08856889099947043, 0.023332220502197742, 0.052443941057260544, 0.044867856694119315, 0.048752917508993826, 0.06715866164969546, 0.03371450857126287, 0.04311721598995583, 0.1104583153501153, 0.05441220151260495, 0.045978374247040064, 0.03393668468509402, 0.03230729140341282, 0.03205754641177399, 0.03295409133923905, 0.011160554164754493, 0.04482891896207418, 0.034574901152934344, 0.07036092624600444, 0.020914863163073148, 0.06527300604752131, 0.03088457988841193, 0.04209827691582697, 0.04090689495205879, 0.026639454465891634, 0.022992449180622185, 0.012543547632438796, 0.03894996603152581, 0.05709649622440338, 0.01673581517700638, 0.08463768980332784, 0.025983496003651192, 0.029046350491366217, 0.050159822550735304, 0.04477664123156241, 0.024875249846705368, 0.05441900043349181, 0.02376063903128462, 0.05822908652148076, 0.03918998422367232, 0.0777181661022561, 0.018997991557366083, 0.06499573628285102, 0.07910940037774188, 0.054532441310584545, 0.010197364375926554, 0.02210578033035355, 0.015391080906348569, 0.006413958708955241, 0.015103751860026802, 0.02469039655157498, 0.06172913299607379, 0.03374656256554382, 0.025137673265167644, 0.06624580813305718, 0.04426037446994867, 0.06245191528328827, 0.09276959951967001, 0.046462865213730505, 0.03288033797538706, 0.021184319597003714, 0.03568113036453724, 0.01290014068529542, 0.024903263164950267, 0.03440809349662491, 0.013060494625408734, 0.05523020261898637, 0.031555857975035906, 0.02804389812185296, 0.030771664875958647, 0.05289692085768495, 0.06530375046921627, 0.015970353037118912, 0.030107182317546437, 0.041553287766873837, 0.0613143988219755, 0.036526289835040054, 0.04165633688015597, 0.08970473147928715, 0.02240151642555637, 0.06256518991930143, 0.04183543619832822, 0.035775182103472095, 0.02093453050058867, 0.04184522406597223, 0.009503487680506493, 0.03736582764291337, 0.013120317665327872, 0.011200005887076259, 0.032640316390565464, 0.04132681652637465, 0.0732756412721106, 0.008281825243362358, 0.022090842381918004, 0.038065366713064056, 0.008224919904023409, 0.014533843512513807, 0.03528062167710491, 0.026618458896077106, 0.04957557675827827, 0.036511592766536136, 0.027745658232431327, 0.013524714358417051, 0.03043227523033108, 0.022882536685626422, 0.03241385193541646, 0.010174501138473195, 0.04883914573916367, 0.06429805300597634, 0.04780247315232243, 0.015433752277333821, 0.008415406736146127, 0.027437067291300212, 0.029392596733357226, 0.05046871883262481, 0.03525377883176718, 0.04183906636067799, 0.02879788793091263, 0.013571098164123083, 0.018199522081496458, 0.01775362279399165, 0.012081416939119143, 0.0466257780790329, 0.04212604596146515, 0.05149459931999445, 0.037501052886779816, 0.04986565387142556, 0.042667957954108715, 0.04553200677037239, 0.05942961174462523, 0.0446263864370329, 0.009053079527802765, 0.05736740811594895, 0.025807969172352126, 0.05260316947741168, 0.028172967356762717, 0.03752618582387056, 0.04682299428220306, 0.061459503535713465, 0.038267149456909726, 0.061585107153015475, 0.02316102272431765, 0.01595028706027993, 0.02684125586945031, 0.051014908988560946, 0.03293757579688515, 0.09413764146821839, 0.061577005444892814, 0.20292416188333715, 0.09895796102604695, 0.09999324261609997, 0.07105022961539881, 0.08335090920861278, 0.06600681452878884, 0.1133771762251854, 0.08315719424613885, 0.17282478271850518, 0.13674870426101343, 0.13530265114137105, 0.17408035748771258, 0.13999079886291707, 0.16128843889704772, 0.1229727470449039, 0.1296532228589058, 0.08711777600858893, 0.0856549223618848, 0.18457443080842495, 0.13152124333594525, 0.18018044158816338, 0.11539547863815512, 0.0778918167842286, 0.12775249699396746, 0.056683346429573636, 0.09692306164652109, 0.09169819272522416, 0.12079333327710629, 0.1457148524267333, 0.11503166173185621, 0.20624166886721337, 0.17165707823421272, 0.11216579444174256, 0.11431394810123102, 0.09717732228870903, 0.05641074498583164, 0.20354358293116093, 0.0773963098015104, 0.10244544103209462, 0.12070990061121327, 0.19900720992258616, 0.16747049002775125, 0.09188332421971218, 0.10965171363204718, 0.19441573987049715, 0.16297991813293525, 0.2034556990755456, 0.07571346831641027, 0.11489272490143776, 0.12872538050370558, 0.11477503978780337, 0.1737881260258811, 0.09487655931817633, 0.1532477175018617, 0.11052435716348034, 0.14086635330958025, 0.14472556194024427, 0.1091694448675428, 0.20211644736783846, 0.10639568192086049, 0.11728635217462267, 0.12671253351228579, 0.09778894018381834, 0.11214184215558426, 0.10202040669641324, 0.08840903493442706, 0.1532526436660971, 0.12094768642314843, 0.17456603928336076, 0.1393870926861252, 0.18695775792002678, 0.1585489623248577, 0.11589452757367066, 0.09057048788028103, 0.10823720560542174, 0.11824253015220165, 0.10224359043474708, 0.12008354493549891, 0.07202371702130352, 0.2604286069316523, 0.17085560624088558, 0.17234807115580353, 0.1497130657413176, 0.1197261062583753, 0.15792123600840569, 0.11495253097798143, 0.11964097725493567, 0.13722964988223144, 0.2008881497063807, 0.1070432486012578, 0.09465313809258596, 0.11721471244735376, 0.12177526844399315, 0.11257217584976129, 0.08968390723956482, 0.12508734714772018, 0.07129951659590006, 0.1381382896964039, 0.11239648956273283, 0.11281743233225175, 0.13690026184277876, 0.08340194182736532, 0.11997423294399466, 0.16852033297930444, 0.11414473503828049, 0.11950201328311648, 0.18361329952520983, 0.0824719417308058, 0.17325310116367681, 0.20456765512270586, 0.10293855957154717, 0.1101354073200907, 0.15839428348200663, 0.07539809881044285, 0.14892002115292208, 0.16626024139778955, 0.1827091516128608, 0.16560489870607853, 0.15262163324015482, 0.14293326597128594, 0.0936603599361011, 0.09075730214161531, 0.1675779428333044, 0.10443719915513482, 0.1611874457448721, 0.13891692220100335, 0.19265878200531006, 0.12362158937113625, 0.10813444147684745, 0.12793564716620104, 0.1321323048323393, 0.10809883874441896, 0.1279471144080162, 0.106833601636546, 0.12447601423731872, 0.18902602765176976, 0.16401012428104877, 0.12340722658804484, 0.2895863966218063, 0.06770737934857607, 0.18204530009201594, 0.08196743737374033, 0.12914745642670564, 0.13101540905024323, 0.08851849620363542, 0.13711341683353695, 0.10218959940331322, 0.16962506941386632, 0.08911165794623749, 0.11251463608017989, 0.08833259117922612, 0.1438645010015794, 0.13088442465024336, 0.07954920642077923, 0.2168074090565954, 0.14841159486344882, 0.17676860466599464, 0.09884916472115687, 0.1537918211626155, 0.05731971388948815, 0.12523783264415606, 0.09746237485004322, 0.12601623444684915, 0.19962555888508046, 0.08420346131814377, 0.15037648299975054, 0.07562863108302866, 0.1246809046715498, 0.13800946303776332, 0.12990225878145012, 0.11634842678904533, 0.1865505419139351, 0.15185395229075635, 0.11810598176504884, 0.17003901648734296, 0.16656517503517015], [0.08604618600968804, 0.009114570067530232, 0.015338051698303648, 0.029566542578062842, 0.026766333729028702, 0.06276151724159718, 0.018131453144763197, 0.04868719121441245, 0.025035263671140586, 0.08343833844576563, 0.01564202011962022, 0.03050798616771187, 0.011564131526808654, 0.005020876697796796, 0.11799973675182887, 0.0395191788806447, 0.023750030136268054, 0.07169395578759057, 0.037709478488458056, 0.03483140096068382, 0.04420240043795534, 0.024135068225275193, 0.008928150204675538, 0.058372773097029755, 0.02414544132937278, 0.007877165617953454, 0.008453068822356207, 0.017401140815179263, 0.1081026317551732, 0.05481092565293823, 0.041037984524986575, 0.022793317812361887, 0.024742594554222057, 0.03413557008441005, 0.03613250882231763, 0.008112585039011069, 0.060767832079104016, 0.02112113611240472, 0.052724891874407015, 0.035000183153897524, 0.06935353244521789, 0.034673285337963274, 0.07453040858464581, 0.04124944996354835, 0.024970597587525845, 0.10284688270517758, 0.016163509904540012, 0.058478807764393945, 0.012040273968263395, 0.06079846793519599, 0.04902370387156095, 0.08023701701313257, 0.037776002061686347, 0.0535778544976243, 0.02454259805381298, 0.03663895378953644, 0.02104462280736438, 0.047663261515221426, 0.013512789105464305, 0.03555279225111008, 0.04129787700782929, 0.02294725026669247, 0.03931738935144884, 0.010410108852998486, 0.015410424243392689, 0.03539197266634021, 0.051194859868181605, 0.04631114139088562, 0.07200177998415061, 0.05402719056499856, 0.051966208299355846, 0.009283879821720933, 0.0531886773450034, 0.010346825284484242, 0.05962753362421479, 0.02769572992942163, 0.07796153625739471, 0.0668107835309846, 0.02430740594198661, 0.024240885761433413, 0.018895609104739766, 0.025170449899243455, 0.007008197201815034, 0.04312734991045935, 0.027917101979255676, 0.043537839848015986, 0.03591688735676663, 0.053976727915661674, 0.019692604463281374, 0.05256673553958535, 0.005712419656837093, 0.026315079103889208, 0.08726161186184202, 0.033824115725500245, 0.008539509094719375, 0.04719606640615633, 0.03462970981906567, 0.06617361879242317, 0.03333950262250645, 0.041186271567962, 0.06457724302474942, 0.05900980891393764, 0.043247962902699194, 0.018680213252082467, 0.05602148301633341, 0.022074253897049596, 0.04348650528118014, 0.015387808671221137, 0.031730007380247116, 0.030915660184941123, 0.06890208952661071, 0.018122652545571327, 0.0047195414164369655, 0.04095154255628586, 0.013933686073869467, 0.037880258967301676, 0.004250066853793604, 0.00744703463611326, 0.05977814804230418, 0.061226501395659785, 0.011636520187104387, 0.035928232462278435, 0.08484017143824271, 0.05841358019305127, 0.036579086644841094, 0.023081023445619003, 0.0032651936302759816, 0.0061336139083973, 0.039605617456670315, 0.014024299336597323, 0.05867157956319196, 0.014282956885706102, 0.053659265129161735, 0.03344221246827926, 0.029283647758087943, 0.019059585573683892, 0.046781529007213454, 0.022950985601970127, 0.029312743339687586, 0.02581138220349593, 0.015721990560580577, 0.03437382069283298, 0.05207309113549335, 0.1250854879617691, 0.022218883636274507, 0.030814656854740212, 0.03872026835701295, 0.039293219934084585, 0.04605251098317759, 0.03555902120258127, 0.02695789434281843, 0.008693736711783069, 0.0536755465769342, 0.015910460447360362, 0.05360251246020198, 0.06532448649938617, 0.012485479453711637, 0.0448444675920265, 0.02357327176391014, 0.02995739910485489, 0.006379643496724644, 0.036433259291308265, 0.025823227728583982, 0.03333286315734897, 0.03144110752535718, 0.031567230221948454, 0.10366919929427759, 0.04844430281913706, 0.11113900811012302, 0.06791393897895302, 0.055780389346182346, 0.0418436803988048, 0.04497937731710928, 0.052420674091471095, 0.03711806736620409, 0.038124351762235165, 0.013052224979868956, 0.07067224489791052, 0.07200350346309797, 0.01643199603339391, 0.07833384842212711, 0.024700194597244263, 0.04121911605553968, 0.021393255796283484, 0.021962317671360712, 0.0773882759468896, 0.020194286114669273, 0.04917279837120857, 0.060247796055461676, 0.05521410437566893, 0.02617462914037917, 0.013782438073706414, 0.021477078619812216, 0.018416938272171786, 0.009726568790418761, 0.007562856322952679, 0.06429717769580227, 0.03592758106866053, 0.0048617695657802475, 0.0545138358803732, 0.03821571650249617, 0.019988781606246318, 0.025584057705210786, 0.02533864007065339, 0.028040191624313593, 0.02453010283144457, 0.11036352400801011, 0.009232658061331936, 0.00987656319713486, 0.014579788814964039, 0.08214923047593661, 0.015039569232612848, 0.047246654584471665, 0.03104647495118635, 0.013199675728433898, 0.06383014882781676, 0.03250400209799409, 0.03847720354263272, 0.03329626976379326, 0.018806244346446226, 0.0507239565652396, 0.04024010876725827, 0.026316948467865586, 0.03870625660887786, 0.05795732646116188, 0.0671666751482657, 0.023914915842137167, 0.04286666354164481, 0.052995966614357064, 0.029873281118593047, 0.015211788205696004, 0.03369091930133956, 0.018599360715597868, 0.034565737537507496, 0.025276716964851533, 0.05405142444318958, 0.047230193324919255, 0.014964226400479674, 0.02553420913006578, 0.03998458944261074, 0.038574943119393926, 0.035543323294924836, 0.037144974672368596, 0.04753272155565875, 0.03551489267764347, 0.022354845090636184, 0.09358781775725739, 0.0683595057842987, 0.07082151581666299, 0.05912876967340708, 0.07026869298091956, 0.06213338380413396, 0.037440137405480654, 0.017212340142577887, 0.0669653063107814, 0.027872242332835282, 0.0669937776401639, 0.008328309981152415, 0.034627341731850586, 0.0290728642472199, 0.04887112170191748, 0.04182720896122711, 0.00974704443277525, 0.031063346724425043, 0.039498877112886736, 0.04921838913911155, 0.04348349937104753, 0.03695076437933104, 0.08403182588517666, 0.06581703506942306, 0.037574572156050375, 0.028060515444459658, 0.05884333713246243, 0.06897044514438935, 0.02760781893240554, 0.03849387514804091, 0.051303472968616655, 0.031332504602947404, 0.0647056218502777, 0.027564370638823936, 0.03595455962100199, 0.04907606981162514, 0.008500992054385799, 0.06911772795553718, 0.05173723326463785, 0.03541841178334185, 0.02979215547176344, 0.047705028738294325, 0.03195751338664975, 0.05039947094129665, 0.04542137163558176, 0.07452565883951527, 0.027456982294097543, 0.04085574698235307, 0.013587580627894827, 0.0434386821330658, 0.03794172406196594, 0.03277180969182934, 0.047012308945081065, 0.03016184170597366, 0.01737621652760676, 0.020356430539063046, 0.033409924379416873, 0.05469081138393708, 0.03204017252262149, 0.016558776908953275, 0.030873251746275594, 0.0686242701485753, 0.045179076958447695, 0.09488496636705739, 0.05437454281906996, 0.03287893340789846, 0.05580654687115124, 0.049596889543214014, 0.016580557883051888, 0.014402039781478899, 0.03135272155382803, 0.006327196132458214, 0.09147036780736276, 0.06778448128274508, 0.055595756574933014, 0.007147855823859572, 0.059796407419656, 0.029574277877275432, 0.054304358549416065, 0.04757432932300227, 0.04061020890782986, 0.07217488105275802, 0.046108747965523174, 0.029371412870075022, 0.06062954664230347, 0.05276205863005348, 0.018562753751341785, 0.032371599559805224, 0.017134077913526977, 0.010149798222950526, 0.05656880632575069, 0.01150949758344463, 0.06213747537029641, 0.039904396781431775, 0.1524552564535822, 0.010940435708367398, 0.03426641538473112, 0.028253624814429452, 0.10087921936064959, 0.04687597768913422, 0.011079262276845319, 0.05595035897567868, 0.03571856514151607, 0.04784882727212139, 0.01655647497890251, 0.012562417691307408, 0.1566649012799774, 0.1289276789341654, 0.1586919975067888, 0.1165574834282909, 0.22898293286561966, 0.1538517222340618, 0.12654135269778116, 0.06239719821938446, 0.07644228956529073, 0.231195011309215, 0.1383508611470461, 0.08433660345950297, 0.15966059267520905, 0.10357605679226772, 0.16164701751300267, 0.10278203511344534, 0.0814331453293562, 0.08425925725272723, 0.12325314485601016, 0.07859165780246258, 0.15857290104031563, 0.14448062436921255, 0.10265059609498296, 0.1556364321815116, 0.13924943150154181, 0.10682480103735413, 0.11412707955709525, 0.09241044414894921, 0.20465176632361753, 0.11273865441658668, 0.1645005965339286, 0.11515459870653492, 0.11261010595730372, 0.08425072806754283, 0.1540245179619108, 0.09898902435920068, 0.10033512927059617, 0.10020379881773676, 0.14202248198645456, 0.17105542123317719, 0.19915616192987987, 0.0939187053591013, 0.2314007431268692, 0.08743313194385596, 0.1345421490924699, 0.13941992021032742, 0.13251480859305176, 0.07230233028531075, 0.151093952357769, 0.18739264458417892, 0.09064233795340572, 0.18339079432189465, 0.14932119819734777, 0.11931419478995459, 0.1230657199131591, 0.1170120747493846, 0.08440988524151699, 0.11411216535738536, 0.10656743949013096, 0.09247065056115389, 0.1157793937517064, 0.10299472870039088, 0.20685073547065258, 0.11438779985266072, 0.10696600417473487, 0.10094503725745849, 0.14222039708069392, 0.16505650670400687, 0.12204338477126189, 0.14530699859772409, 0.19307468325964042, 0.16995809440101894, 0.1596569557275091, 0.1473804930491107, 0.1780568848231009, 0.09963165130466223, 0.1771385826702629, 0.1389119281832661, 0.18465706280299596, 0.08742999032671962, 0.14647046902350017, 0.0949122231187565, 0.1446714691285576, 0.12682742306164332, 0.11187618891043322, 0.09017119716320719, 0.16909103521278926, 0.15959702751466207, 0.11734659251357828, 0.09973299050969736, 0.14681919531098434, 0.12370336641158376, 0.170289314485022, 0.1909497422831399, 0.15610935751880917, 0.1294893973640033, 0.11130164616874286, 0.17417521668331964, 0.06977547266121421, 0.0962534493633679, 0.18683152326515742, 0.15047526412776538, 0.26042762984122547, 0.1300135249538081, 0.10867542387651545, 0.12865596637129784, 0.09231259261390992, 0.1158726651753698, 0.15577357767948083, 0.1264113453882081, 0.2119539294924055, 0.1337539085320064, 0.10466910885380847, 0.1439721573676382, 0.07905509043484926, 0.1082982262596488, 0.0901005616677659, 0.11542441137135029, 0.11234839500061103, 0.25339046173862045, 0.11190907750278711, 0.13307233367647442, 0.14328778694782937, 0.12664131447672844, 0.09442736913583108, 0.1804483136428254, 0.07144258570458208, 0.16720962045448168, 0.16492582085941518, 0.07615411574287073, 0.12625955710453646, 0.15121140676949704, 0.1744338335203273, 0.16517367613102707, 0.1208818820970399, 0.10583354279931102, 0.11909597792795726, 0.14143425997878822, 0.14331472478806973, 0.11540853365191392, 0.07121498470327683, 0.07153519216392722, 0.15082103200256824, 0.23570542356797627, 0.10399525572678872, 0.08201232925057411, 0.12095424107142858, 0.15627228734748705, 0.145065575838089, 0.19534515642694064, 0.0983511810856206, 0.059463721700012684, 0.12090709645833288, 0.07897009713841335, 0.112748527101108, 0.1658273089144911, 0.08233371057680675, 0.09746620857289859, 0.20433520259601728, 0.09290632432592766, 0.12535177224448749, 0.15149822352187975, 0.08115375175007752, 0.13445802432085785, 0.2717820448534829, 0.1100650228826063, 0.1908554123448474, 0.1218505994017635, 0.2575765342584678, 0.11004071097288813, 0.10084027823592935, 0.09115857418094363, 0.08977728044348103, 0.17927262958671364, 0.11165004675941807, 0.21340866786028656], [0.020562695006706884, 0.017166410107165575, 0.03567542388503041, 0.07471452227660588, 0.022476913540491035, 0.009691718383692205, 0.07234415518386023, 0.10426441699798618, 0.03383757107492004, 0.01833594324333327, 0.044294111231075864, 0.023184880015573332, 0.09995802664863211, 0.03900351601519755, 0.03244875577677574, 0.017847228396151747, 0.034500676207244396, 0.0355391740532858, 0.0477020296135119, 0.028104596471946155, 0.02974489550771458, 0.03066857505057539, 0.025627163338607976, 0.020018341984333735, 0.06362405738660268, 0.020519423132230128, 0.03207720696393933, 0.05811908920960767, 0.022220647827322994, 0.0445574099597122, 0.03965550674391644, 0.0043914133316970295, 0.03161885655884232, 0.04188450785087688, 0.022818002916340317, 0.06027733947017363, 0.03526801788913352, 0.013004550261289945, 0.021321409115833894, 0.01907439629680344, 0.013812280891995345, 0.009643273527867027, 0.10054517657096897, 0.04318704742140003, 0.03974911064973899, 0.03710904624313116, 0.03982123552954622, 0.03721062293542283, 0.061419788881071975, 0.014903012363772308, 0.056385954708925316, 0.1040006365094866, 0.005192155899879123, 0.0216411992774478, 0.04318910338250654, 0.07707250610526119, 0.027967015015227453, 0.024022487391318594, 0.00855456493861441, 0.029116327807839428, 0.023844740054171, 0.03800678878490414, 0.025788700474160056, 0.049526963116867204, 0.02653663944719093, 0.036519786076886315, 0.068035939575306, 0.010498668699126159, 0.025200363115540574, 0.02997870510444045, 0.029372610484382937, 0.0805394265002438, 0.018692158861085773, 0.012016079954004713, 0.064905572549573, 0.029826180610273565, 0.04552168286006365, 0.014164619530285043, 0.045944813905017715, 0.007194600949463035, 0.06257808887000595, 0.022039826726540923, 0.04977146303281188, 0.06542248731212956, 0.041493647931409736, 0.01422249008568802, 0.04539095291069575, 0.036058137991598675, 0.013329250471932548, 0.047500331686543565, 0.030280799072768008, 0.058533993017460616, 0.03955919548336949, 0.04227179867614593, 0.013565751308176135, 0.08923628447311265, 0.037457650394311974, 0.01869359226631267, 0.06621073465794325, 0.03590162371152213, 0.022330492468816892, 0.03610901115462184, 0.02807320574564593, 0.08271864349288599, 0.007552562098551009, 0.01582457827005003, 0.039927409296589236, 0.04095768669087972, 0.04363041577328529, 0.016626355604135563, 0.026492314147097722, 0.026003405917435884, 0.0405939749575087, 0.027753742977178524, 0.06153227641646351, 0.029581385531595776, 0.019742761771859865, 0.004986357925060604, 0.0360140467860869, 0.05705122436795916, 0.032608588093093464, 0.06557409239134618, 0.022268937468262653, 0.01982396375387907, 0.023525850647794347, 0.048017392334129126, 0.012235929540890669, 0.05055217185456838, 0.01733621010290725, 0.0663344112357923, 0.022542261551799517, 0.02758052316494286, 0.012474475312046707, 0.019277510665623204, 0.021230739873967, 0.02162155568865793, 0.07319688371249608, 0.025201260478102734, 0.013458734461372452, 0.01294577555797462, 0.043444544675626924, 0.03653287162472095, 0.051874297338404825, 0.002778988514494683, 0.012189712824432977, 0.021976312456120337, 0.03931306708338005, 0.025759766044627343, 0.03529147484472819, 0.04295684763097337, 0.013892403155166124, 0.021922938891553452, 0.04454235666032348, 0.036650570309055705, 0.07439073215105704, 0.02250541710028691, 0.01607840125715094, 0.03484413027763367, 0.02999739195885403, 0.010866918983603162, 0.017906890284003954, 0.01621948056189077, 0.01842772019361811, 0.04933366545342973, 0.025699325537841235, 0.022472301198701774, 0.023904669963355576, 0.02102258738263377, 0.05477452564186283, 0.013864107396719711, 0.06842610399637904, 0.02038278483918735, 0.02446859363200409, 0.032425739868943176, 0.024579057436702505, 0.019012140708842447, 0.06729081991527762, 0.08625894745013543, 0.02441899781115353, 0.08996123128703662, 0.08022100358669247, 0.034221367444843054, 0.09374265944851295, 0.06999838498554059, 0.028280433733016253, 0.011671970249153674, 0.017178935863609825, 0.015961403160222938, 0.055034251883625984, 0.03423537240762796, 0.10243407557053225, 0.06510083457188946, 0.04434313199349812, 0.0050379456702752835, 0.027275002594771128, 0.009333655454351433, 0.0034442212781868875, 0.13225617818534374, 0.034603548901421685, 0.01268666678307844, 0.03384698914097888, 0.0240132202993014, 0.018355564779735038, 0.08268730874572482, 0.12682365040693963, 0.03136736433953047, 0.06844225991517305, 0.0153850164996194, 0.03597822352977736, 0.031022017156439166, 0.03681083349511027, 0.034202721302530596, 0.028426583390682936, 0.016012395066874366, 0.0402509856836072, 0.013412336236797273, 0.04202361770772508, 0.02839190685855491, 0.06002574547060898, 0.01931252476892301, 0.05000755250720041, 0.029433682028736387, 0.041396196732031446, 0.02534078593764986, 0.03990592348522373, 0.02551596162707678, 0.027336971501686742, 0.06036674324423075, 0.03322519322058984, 0.012613217911816068, 0.11703899901892457, 0.037915461364069154, 0.03651077513183866, 0.021695383691361973, 0.021593118286026374, 0.03225662519357034, 0.07403541050319161, 0.010629216292207795, 0.04634006055338042, 0.0959277796958174, 0.056180504483303854, 0.05650602148047515, 0.019689958176708648, 0.03862468991428614, 0.027162935751091157, 0.00803467140732599, 0.0463356025783079, 0.015917873442439095, 0.04365427984989115, 0.04281244520097971, 0.09811751398124866, 0.039139090704598596, 0.06257990055850574, 0.03420197830668517, 0.05121799112696733, 0.025986445934644768, 0.028578059548246007, 0.05605164050523724, 0.024150118131988814, 0.017179471906274557, 0.00401306093304551, 0.01771289372949728, 0.06123522057064942, 0.03687575233301946, 0.018057433455916386, 0.02538635634950229, 0.023304190220577375, 0.02876739456717457, 0.016941538512972847, 0.03262668801471591, 0.0618895793865834, 0.05975888443312474, 0.041161287908575366, 0.0406218864955008, 0.05765635546829019, 0.028068644293983067, 0.04851481278559991, 0.048550123747970374, 0.02135384817873793, 0.027566336694040468, 0.03701953390347106, 0.059843165267791064, 0.030342518618064265, 0.027356900075184445, 0.04224832136450069, 0.04115613782778382, 0.03721607496429767, 0.022967492662636296, 0.030250000368271555, 0.04075228735538466, 0.042204196232237985, 0.010414875561504491, 0.016473425685295036, 0.02622291199596865, 0.01960432875369276, 0.019679210182013254, 0.015442978657249893, 0.013160286770601357, 0.02539318919714008, 0.035305171074079614, 0.011633839125611951, 0.012403565009922853, 0.0038521281177444117, 0.028187140256964734, 0.011064379459380038, 0.06659432407468557, 0.03174051110233579, 0.00499794221416648, 0.05086018264825855, 0.03842168241473181, 0.03210603113153151, 0.0018571157831632132, 0.027714041893237402, 0.021644496957638433, 0.02221023231478674, 0.026748069262664233, 0.0375880648248962, 0.011451286912363554, 0.043757712335458825, 0.05028400802984834, 0.016028883467827524, 0.031343147424714904, 0.05573284100475056, 0.04227461459647332, 0.06598130839743785, 0.02850463188120297, 0.02250216352487249, 0.04239924451602357, 0.06294116617313453, 0.036827203152435165, 0.06337386795452662, 0.02588633487799338, 0.01653363718651235, 0.012385327684959131, 0.05252841866708227, 0.030381846507745128, 0.02897780149110726, 0.015497183427214622, 0.055318256108356376, 0.008862959104590118, 0.0728823963020529, 0.029994436938847815, 0.028344645198168497, 0.04849833795534713, 0.015872318297624588, 0.03290350316092372, 0.04001392251146691, 0.03727661385866148, 0.01671543707405882, 0.04276346854333367, 0.052723768898951154, 0.02193534929704453, 0.16717645366277012, 0.11410531215369701, 0.11903277917632035, 0.09522326357130494, 0.11727952611233507, 0.1097024069832904, 0.25897325788225445, 0.15208329712705954, 0.16805259164954933, 0.08812141072537218, 0.1476782884980951, 0.12602458042757853, 0.17400073818862438, 0.1557069591113499, 0.14229964997087205, 0.12837773987225123, 0.2526589738471167, 0.09376296800162111, 0.14826588625354425, 0.12452257531029837, 0.1247766866747822, 0.21522380331797258, 0.107074074447155, 0.1266606120126588, 0.18211624771356583, 0.11643270083836146, 0.16312762163579464, 0.23220307007431984, 0.26948848792484825, 0.09596957745296614, 0.14650388008781842, 0.07664228776203734, 0.12348799939666476, 0.11283971542226416, 0.1119159646332264, 0.16365143709949084, 0.13030613639525004, 0.10698367322662047, 0.08387991546520165, 0.12751525401004724, 0.16352123980011257, 0.17252135542886599, 0.30226875894836014, 0.06558669278664248, 0.1208952356662069, 0.10334004874208144, 0.06889703444072179, 0.12276489819799151, 0.14390777796506882, 0.16075523250869342, 0.1324622899826084, 0.1576764341443777, 0.15691363864711352, 0.08843425608107022, 0.18625567773623125, 0.123786079830357, 0.09345897074256625, 0.1347545169826065, 0.09670424088835716, 0.11237438289182526, 0.1871494712041957, 0.12107230616467339, 0.07442716269620828, 0.1186660174280405, 0.13928107837481157, 0.16774370893836021, 0.1399058869906834, 0.105314354944442, 0.12134608147399766, 0.15523171318428858, 0.19094706885516644, 0.1721042056701013, 0.1147874298372439, 0.13891475088894367, 0.16493327117391995, 0.1959830607686724, 0.18250982516578265, 0.1795214076659509, 0.13281743521136896, 0.19286965711840562, 0.21323608926364354, 0.13582456670701504, 0.09442652096705777, 0.15051860894475663, 0.14362879150680133, 0.0950137794549976, 0.11851865319269043, 0.08313504686313015, 0.13610453025570937, 0.14283547550439835, 0.06206141159470592, 0.07781468770865883, 0.18926260567137174, 0.09550927286701542, 0.18509235658815928, 0.13695253618061543, 0.17885834324572766, 0.08368950496826853, 0.14458536303469113, 0.11315401284290211, 0.12413101989243712, 0.13520777837506362, 0.10534758280430521, 0.18368453213146754, 0.11806023493409157, 0.10226856730878353, 0.24040408858231135, 0.17247919126280717, 0.10588504360722643, 0.12576476936893805, 0.10352886468172073, 0.12524620576628617, 0.10112032320882593, 0.0760380116158298, 0.14057743309863976, 0.09583156343017306, 0.13148340822330543, 0.10843073057809047, 0.13835873215326241, 0.13433183037808963, 0.08532506613326923, 0.11523573792406491, 0.07894759691719498, 0.09873061108269862, 0.13903759286871978, 0.0849941446046744, 0.10347560646810702, 0.1306318739163024, 0.10073703913284199, 0.1766573249229363, 0.14291654686842645, 0.10855007810252053, 0.13669545283274992, 0.1144690883478948, 0.13785026515168802, 0.12493735019649778, 0.1091750224253961, 0.12689933420291968, 0.11451921851507255, 0.0793587484263948, 0.11871261921312128, 0.07960207108408213, 0.10946898415152516, 0.11592890215771538, 0.15611379513783114, 0.10197741471763168, 0.17404121958783694, 0.11310196920697178, 0.13595090992748737, 0.07876166475138494, 0.05566476358632956, 0.13178999748613152, 0.13899492658674717, 0.12342433924121515, 0.15814781242183276, 0.14699086467070238, 0.11758220701345376, 0.1306362436818225, 0.1277190995003496, 0.11144358890929393, 0.1792130134999752, 0.06019304506480694, 0.08476817208741393, 0.11390730206455503, 0.09526948537677526, 0.11604862287640572, 0.1609998715243169, 0.1451436345066343, 0.18860435884978088, 0.08950878413660185, 0.13343247292297228, 0.10771211449589048, 0.10479229688644409, 0.07818828908992664, 0.1409850019429411, 0.18210102138774736], [0.032873878322009525, 0.044018419060323916, 0.058465467765927315, 0.04169979365542531, 0.036772170569747686, 0.04797893296927214, 0.020104320852884223, 0.036510276408599954, 0.05358336420197572, 0.04215764533728361, 0.008398998911226434, 0.01324636402672955, 0.02485820504703692, 0.04769818571263126, 0.01670584428523268, 0.056739091474030695, 0.02332820527122489, 0.03641869792980807, 0.034205191169998476, 0.04591422215370195, 0.025481227419472167, 0.035851374800716124, 0.03773797356656619, 0.015934604419661418, 0.02591257043448942, 0.10539419137473617, 0.04070132937548416, 0.007249018609789866, 0.027458600600117018, 0.02981528333787407, 0.04619457246735692, 0.0614097872748971, 0.05611457462821688, 0.06777282405112471, 0.007594352222180792, 0.031797335017472506, 0.02604725963569113, 0.01158192441133516, 0.039769795789782486, 0.007354997298015016, 0.05491574574261904, 0.020723295763933232, 0.009003367507830262, 0.049248465203813145, 0.04444535329405751, 0.05412264008607183, 0.02063223297175552, 0.04134227355409946, 0.03659682355022856, 0.07821345595376832, 0.024038085215059773, 0.029775765458387986, 0.02441613269703729, 0.05619224313912647, 0.014496225531079938, 0.08898321805255753, 0.057569129791642935, 0.0492212288081646, 0.01886118363056864, 0.023958708492240736, 0.03020862669550947, 0.02351162855380348, 0.0331305816902646, 0.08087089764220373, 0.057462179102003574, 0.03487495951620596, 0.10206688634519066, 0.039563399007810016, 0.00541710976644286, 0.035650535220546384, 0.008568451157771051, 0.0695355087518692, 0.03228141886315175, 0.020461912200387036, 0.05649199616163969, 0.009255020879209042, 0.011523174304914261, 0.05748865553843124, 0.04089021995397551, 0.023127268999814987, 0.01175380835775286, 0.029102014111621038, 0.02355722101804401, 0.027096924471801946, 0.049020341730543544, 0.041714470367878675, 0.030964104192597524, 0.016544873726421168, 0.028306542064196298, 0.0299105530471674, 0.03367737574236734, 0.02135423494369856, 0.008473468977691872, 0.018712179036810994, 0.047970013626452, 0.037977893371134996, 0.0412161406794829, 0.04613766373534288, 0.07712023425847292, 0.018832233933998004, 0.006564797467685172, 0.03541544319263526, 0.00825340480410627, 0.03568324739379542, 0.05257527490279504, 0.04705025940867407, 0.055484358088246415, 0.04963637010327407, 0.05782094770776374, 0.02904383312644703, 0.01811082398385874, 0.03527594317815133, 0.05622477550059557, 0.02643240289762616, 0.04276213522202202, 0.09620602655091456, 0.026442457090264986, 0.01251743421224611, 0.039804424824459214, 0.10201740078628063, 0.019841704051941633, 0.04441856473152127, 0.012632741060640131, 0.0517786205081003, 0.023027631221339107, 0.02382539671712688, 0.019995870600853647, 0.028171279500903826, 0.04353301885670849, 0.07760799237127815, 0.033198903381292305, 0.025640700112230012, 0.02876567787357739, 0.012081584028367485, 0.012073219387925096, 0.06707053352147341, 0.024267156941017935, 0.02804306522011757, 0.03435870632529259, 0.05377609868134771, 0.08223412877746991, 0.0020252217738223927, 0.02443593574155654, 0.01787046143519027, 0.020766922172957232, 0.08097619949174778, 0.03530877748770373, 0.014281562496242779, 0.012954264031057912, 0.003288286509424714, 0.10220268155847277, 0.021148525178432465, 0.018782819621264935, 0.037191722342478375, 0.03002684037866337, 0.03920575337750571, 0.030224677441375594, 0.028043952404654453, 0.006780918928728039, 0.04722221375309995, 0.0503231866418251, 0.052198833852474175, 0.03928773397845881, 0.018477845271783214, 0.03811897776488747, 0.008450429321133664, 0.03072285445939217, 0.027237766289285252, 0.053191727359912226, 0.04163848801649042, 0.0338559661592756, 0.0899145480777536, 0.05280639410817197, 0.07426945080182382, 0.04616058125559773, 0.024491295717390518, 0.02962512389889785, 0.050400549811976295, 0.02850635875282543, 0.01204430531444294, 0.047464169162724695, 0.034990534385932345, 0.05794830873076405, 0.06992307438382081, 0.04737384258104222, 0.017553068198529736, 0.0008812891277817211, 0.016283424005710652, 0.02597517886066011, 0.020387441285752823, 0.03606626684112208, 0.04017349019912737, 0.03348026471212506, 0.02501930622383952, 0.050885410580251894, 0.06660579131650073, 0.038184364791959524, 0.05383715665500079, 0.009345077743221606, 0.06251896132848092, 0.0210391147993505, 0.03398852476051875, 0.02494386670046619, 0.052755276672542095, 0.09451950740601335, 0.061934077713106356, 0.014025693726060646, 0.02199517742597631, 0.018658457723047053, 0.030608860576259236, 0.03824126334594829, 0.017867911839857697, 0.0439757561710264, 0.015887480162616287, 0.021987861122137735, 0.029495323542505503, 0.018490656012935296, 0.04780476999336055, 0.02737474045716226, 0.02649787474157555, 0.05202084733173251, 0.03671494292627488, 0.03207951398300273, 0.012282259063795209, 0.04013529207025256, 0.03911107738635369, 0.019034701998212507, 0.013172079709225466, 0.02408792530851705, 0.0657711796728628, 0.04846430942416191, 0.04465594681512032, 0.03040585307670491, 0.06204480105744941, 0.010883058787190487, 0.04278666087027107, 0.024669574008190205, 0.03165456446419869, 0.06881192579333271, 0.029999356317733015, 0.030602577341986553, 0.07090679409780673, 0.08387300119336162, 0.022045443300157785, 0.019262525219736353, 0.04524593979918531, 0.033484193429883034, 0.0653429494372436, 0.04590406109179769, 0.029475238905953507, 0.03421690268442035, 0.032408457582018206, 0.03566176497510501, 0.0030316552355153753, 0.05504163773730397, 0.02827793333147253, 0.03067553003451654, 0.0655984857252666, 0.04038260451384953, 0.02824755701502519, 0.01265099025996668, 0.05880122046385493, 0.030447430309972594, 0.014999929216823407, 0.036551863819892914, 0.013059465796686709, 0.013870181981474161, 0.056227920510407, 0.015373866472925459, 0.011531676348697926, 0.07670321342136178, 0.039627340755292347, 0.01385381062781172, 0.049036501042012653, 0.03925976137231503, 0.04539656439529998, 0.03177018343870129, 0.023002243833616376, 0.049611203239432404, 0.051741192516471655, 0.017546240439904586, 0.03864830632561019, 0.02055972980867539, 0.03976791285510574, 0.0019475818886089005, 0.009517231407309217, 0.03289160844204681, 0.02608665537887386, 0.003655544224394751, 0.020225244274895107, 0.07337739438350711, 0.04769205854141286, 0.02242889192088374, 0.05954243854752608, 0.08110672927328519, 0.029987101975296224, 0.042785853413598876, 0.0008734798258436577, 0.07487871418041842, 0.06012794641511781, 0.05183059289785368, 0.024289250041225126, 0.01463576965034008, 0.059514978235321384, 0.03685075171025736, 0.01128088980580547, 0.03729821841365524, 0.07412511961800711, 0.0769631059042045, 0.017377694037609866, 0.04016466924388494, 0.0246711566911212, 0.03830836367394243, 0.06459664912628275, 0.06279572897723742, 0.017113134930176393, 0.09751456776367766, 0.011483097482206566, 0.023555774042116742, 0.09525997231581382, 0.03344303010297673, 0.028794410438942056, 0.03040143581373351, 0.012353188025632074, 0.029012006441397325, 0.08108520614249365, 0.013517755133632039, 0.036621291523001025, 0.05097589661766376, 0.01036094390188477, 0.009877170485976552, 0.07697126189512865, 0.08956985228828021, 0.0257494964171201, 0.045379692622061284, 0.035207149905285666, 0.03275949088856578, 0.03519941460607307, 0.028317446121945977, 0.023921719852036664, 0.010606647369318774, 0.05591669346072844, 0.02014114834102137, 0.05469006160274148, 0.02318785708796765, 0.04308482272816556, 0.012815294970226074, 0.025536051352641413, 0.08059155156037637, 0.05333945121882217, 0.043501694287572584, 0.053305405724261484, 0.15212575984852655, 0.12882102679993424, 0.12471683988613741, 0.08558577285813433, 0.16722932511142322, 0.2104844262025186, 0.11068530566990376, 0.13406246554638657, 0.1278763703469719, 0.12985040513532503, 0.1450711533959423, 0.06184670954410519, 0.06403636919068438, 0.13698193031762326, 0.21474907307752542, 0.12467422788696629, 0.14147535205951758, 0.1369323565491608, 0.10254288544612271, 0.1708326039037534, 0.14996491079883917, 0.16642937303653785, 0.14839636853763036, 0.10501972825399467, 0.0976794178464583, 0.12514681395675453, 0.11543947484876428, 0.07346996691610132, 0.1387648760740246, 0.1429456967328276, 0.10216424254966633, 0.199655414425901, 0.11085417267999478, 0.19605661396469387, 0.0782955994031259, 0.13630444024290356, 0.11837169607835156, 0.07482188008725643, 0.1787594264107091, 0.09105634609503405, 0.10412786182548318, 0.10820758076650755, 0.11075037039284195, 0.1616663829024349, 0.17989890383822577, 0.1359092207359416, 0.1356106246156352, 0.2065846547484398, 0.0733700729906559, 0.11063031719199248, 0.10312513634562492, 0.0710788502224854, 0.13647243194282055, 0.24362086025731905, 0.13008505611547402, 0.14868176036647388, 0.1796805648399251, 0.12099959435207502, 0.07742516111050333, 0.1641186491719314, 0.1686756903571742, 0.12107477603214127, 0.17527337132820062, 0.14851405365126474, 0.22497345586972578, 0.2095956674643925, 0.1875478798257453, 0.09474414320928709, 0.15580669018839086, 0.14922143997890608, 0.10221731755882502, 0.20922871572630747, 0.14548222348093987, 0.11174926893519503, 0.12606392188795976, 0.15851521199303015, 0.07519142382911273, 0.15323201620153018, 0.21791276974337442, 0.16152212635747024, 0.06677561506096806, 0.10522960592061281, 0.11828641779720783, 0.06484072495784078, 0.10379561715360199, 0.17944281974009105, 0.10051344827349697, 0.09294656145253352, 0.1117265447974205, 0.1697558095412595, 0.0956311784684658, 0.1633252381746258, 0.11727336501436574, 0.11129111530525343, 0.17219506150909833, 0.13522050769201346, 0.13919931490506443, 0.10940370229738099, 0.174215399527124, 0.08567797898181848, 0.08953521307557821, 0.13396391512027808, 0.128864317334124, 0.15075792824583395, 0.11246330490601913, 0.10010390489229135, 0.1851902420499495, 0.15152874402701855, 0.13613593285637243, 0.08716537524014711, 0.13621625783188002, 0.12181081010826997, 0.12619445845484734, 0.0994112224185041, 0.12154538077967507, 0.1590766997209617, 0.1343404749142272, 0.15122167978967938, 0.14470905996859074, 0.2275006595466818, 0.1032321752448167, 0.10029299903128829, 0.22289517096110753, 0.11574792329754148, 0.1681454423815012, 0.20003377912299974, 0.09005499804126364, 0.18436548273478234, 0.1220093901668276, 0.1591960404600416, 0.12421203697366373, 0.11019056543175663, 0.09992099899266448, 0.09104600522134985, 0.11916969397238322, 0.0899318710767797, 0.1364299420799528, 0.13149509259632655, 0.21330892321254524, 0.10808552588735308, 0.1857371548456805, 0.0879769641906023, 0.09668311130787645, 0.21761851624718734, 0.10894179636878626, 0.25035760019506725, 0.16781471084271157, 0.13162713551095553, 0.13912808229880674, 0.1381396467664412, 0.1414105383945363, 0.08684366143175534, 0.13193459329860552, 0.15145262596862658, 0.12649462877639703, 0.1862549992012126, 0.14109230547079019, 0.11983839023326125, 0.07781145788197007, 0.09513776815895524, 0.1788351916308914, 0.20204583901379788, 0.14848000476402895, 0.08215633473758187, 0.13578374604029314, 0.08226636597620589, 0.10478653612413577, 0.12688515282102994, 0.14408714191189834, 0.10289144888520241, 0.09108923468738794, 0.20074884646705218, 0.2248390516532319, 0.18161323613354138, 0.09612409344741277, 0.09258920419961214], [0.028208218947319046, 0.01527536693694336, 0.028231691169951643, 0.03682801739445754, 0.07092955894768238, 0.015456352582467454, 0.07455556187778711, 0.008850435892652189, 0.028784218842961957, 0.024350920392732536, 0.11369217253689255, 0.02266939526556858, 0.07028450963220426, 0.024730482704139183, 0.06751403758036238, 0.048523114661553075, 0.03290786953376872, 0.05098708226744618, 0.019788140497569526, 0.02785557581643973, 0.07184706721454859, 0.021516523556783795, 0.007677156395012779, 0.027436018954696398, 0.01483171699302537, 0.044578264733510356, 0.011584932865974094, 0.05306368101654308, 0.06910349907619612, 0.06515382815684591, 0.06542062812617847, 0.013010875055832523, 0.032556676771491766, 0.04233987609456692, 0.05052477600319045, 0.009212664178838688, 0.011458165561115103, 0.08649914884673697, 0.05564031596960766, 0.058991115274173875, 0.028579538754586662, 0.0034065254772680676, 0.03585955793304103, 0.024110393299322044, 0.11425742613417761, 0.021384236369548098, 0.015491129198510731, 0.02599892419363771, 0.03440781868994236, 0.03432819939085415, 0.03263324944834624, 0.033642536361834834, 0.02037692568930132, 0.03105254444692816, 0.021817798194076334, 0.005822751995375646, 0.04801531262429697, 0.044344886006521325, 0.03349445966471519, 0.008545367396436632, 0.02710822716887508, 0.06347255408763885, 0.05051775655842253, 0.013175538541483027, 0.0231013082500015, 0.05458435941753643, 0.04614065607477512, 0.012092268410404878, 0.040303046282913, 0.02064681299296873, 0.04077107599005103, 0.04742483448769365, 0.034148784553898234, 0.01690831913479737, 0.058145959196346145, 0.03679216360407216, 0.01910245880883719, 0.04260472866839596, 0.03463090743337359, 0.04620802442410162, 0.05661038016634328, 0.027389101650831953, 0.07976861750440938, 0.05545974423044494, 0.06010887958109379, 0.007328373280220798, 0.01971025824812906, 0.016958993826327578, 0.017251897037827542, 0.029390954678612094, 0.054410427143531184, 0.008996976556123366, 0.0647319218676005, 0.029272740307663168, 0.10124667999999863, 0.0882491652986833, 0.06827938436929669, 0.06676436495035887, 0.04781981650739908, 0.02155172934622637, 0.02825098531320691, 0.03914413900513734, 0.0020368959688182387, 0.021179559673847895, 0.038935421633401086, 0.07192789430596999, 0.030227242303746085, 0.0340573824942112, 0.049338408413210084, 0.013565932816293622, 0.03956351435876318, 0.015301828106333102, 0.0036187684745527804, 0.0047961382661014795, 0.020254412799009254, 0.013346080684901347, 0.03863655070641211, 0.04496324175436582, 0.03941581764125398, 0.05115569482690521, 0.013714765231790287, 0.04235221525388105, 0.017827525435547744, 0.009188761934638023, 0.03364389682454722, 0.03467178238289697, 0.018147770215624144, 0.03099729473303471, 0.038368203677237034, 0.032996642270258496, 0.008623871353587933, 0.02562471721986575, 0.02068437329892601, 0.04628141477171864, 0.008521695854142308, 0.0674542382891689, 0.026440146678526486, 0.050023725389369895, 0.01850572118668684, 0.017167324433103204, 0.02351642070737268, 0.027173281713787998, 0.03544630975063358, 0.04160405575696911, 0.06146067740129573, 0.008821620206747736, 0.062397313570337634, 0.025617589209494845, 0.02870887770716633, 0.031884004295404465, 0.023550322013241903, 0.030880776699632406, 0.08828208103243794, 0.02459116419777274, 0.0440814346075058, 0.05686141437451754, 0.07512337355209248, 0.031167098121451478, 0.06157408095896244, 0.011197194207592734, 0.029588028389428343, 0.027670446018289243, 0.017249350835170065, 0.04916520556434989, 0.02684798524049776, 0.04520920730595078, 0.038851720946175713, 0.04816000343167356, 0.0062553613263714525, 0.03804784693888255, 0.020311806683561633, 0.013716572679446211, 0.07259706554136106, 0.04116000887006521, 0.01749962678046099, 0.025886417998533164, 0.05007338397470968, 0.06277427369994776, 0.03910918766632676, 0.05679888737254909, 0.02124613244086504, 0.09623607208154031, 0.013623491245588022, 0.06667426907058273, 0.07729481453342096, 0.003033529476462198, 0.019154824748901383, 0.027889375342056155, 0.01383676243546818, 0.052888378101800165, 0.07206955206181322, 0.03946277565721955, 0.04031659662723541, 0.020144829393497536, 0.030017680155911615, 0.034033603234482665, 0.044149651125605614, 0.04015531903132796, 0.07219904368477208, 0.029092202495251383, 0.042231863497623374, 0.03213854313695005, 0.0029594979132525623, 0.024408989419628466, 0.016402569665972675, 0.03778274669977171, 0.04997407698205539, 0.02040697630893971, 0.014731673789875848, 0.007326023852718728, 0.11793720296451024, 0.03778843282322798, 0.012185269268229604, 0.023604360542127063, 0.047695844766816924, 0.017416552041790316, 0.06013651631240334, 0.030459508233304535, 0.0335456076344209, 0.026534844722066606, 0.01598791521973908, 0.058185992762446404, 0.015586025713543807, 0.028119249435673867, 0.05179891549050808, 0.04385691076251013, 0.04291743492441518, 0.015119383610518915, 0.024811735576284782, 0.0677090689007725, 0.032239790739757676, 0.0157256190265928, 0.014725285382675273, 0.06641600507178477, 0.026442099163042646, 0.033315170356737714, 0.044839365008686266, 0.05871550113494907, 0.03870708442160061, 0.05337873500372682, 0.04934154324499624, 0.04522473218717745, 0.04222279826977423, 0.03998569206201604, 0.03824184688606432, 0.07707000231104237, 0.014283648991425122, 0.045249230694025755, 0.06909347711397068, 0.02002154297328421, 0.061158071139029095, 0.068797418714634, 0.038948720919766595, 0.037110192967312675, 0.03262619607682739, 0.03242643876001239, 0.04067318035023553, 0.05972967350057193, 0.03682795971898096, 0.05307026280622397, 0.02896492289645331, 0.0477845666131803, 0.04178827122918197, 0.04817561312977757, 0.01731322133647544, 0.05801752608801637, 0.026617795628096377, 0.018646261056086848, 0.016788350750825236, 0.03427713284535067, 0.027937193401157856, 0.07267471708889518, 0.07881423764462982, 0.025347422010132244, 0.048565170262008905, 0.003957123354276908, 0.0623213719310505, 0.02843163508389677, 0.023411162962604846, 0.040035652595439127, 0.04309713813875403, 0.028916872439107726, 0.008492818251917405, 0.01768106534811003, 0.06761488145483391, 0.03522207089034574, 0.032351844012737274, 0.01632317258710308, 0.013798852683976293, 0.018881865377937044, 0.04022361358095493, 0.05623847172994699, 0.050289035974336524, 0.06810034611927611, 0.044959916932774444, 0.013191365370793002, 0.038779867480375936, 0.0619885776458042, 0.017596217936703136, 0.04223651146250112, 0.009160639202621366, 0.033501648743237765, 0.0864659481282745, 0.05566632082419736, 0.03835771691852382, 0.024010631688205258, 0.02859522309154272, 0.023203439644670913, 0.016791237917329584, 0.04214735535372581, 0.04185605009219476, 0.03933666313865355, 0.033569800800510814, 0.0505112935123699, 0.011206978682561644, 0.021317363350785205, 0.046854359563440084, 0.022663013643718193, 0.02674015754434679, 0.06698510596262557, 0.03553850569629243, 0.036968745557325225, 0.04398961864145739, 0.008266139210068753, 0.02719685062766075, 0.02026654839781778, 0.0381130405834743, 0.053845964039542844, 0.06089538987725973, 0.05186173426253455, 0.030968548596969674, 0.034233530185052326, 0.05036585970914789, 0.0266600038989314, 0.06605906172522477, 0.045971422655774016, 0.05015131372160145, 0.05525547465575593, 0.01270647406844156, 0.03395621631560581, 0.10355335301054375, 0.06777150090783834, 0.028774658284549202, 0.004000650527554431, 0.04629750283701079, 0.019795461890420744, 0.03355558549187013, 0.06660849867122513, 0.042660836729088, 0.027997121614004885, 0.015294554210933191, 0.02335721264327211, 0.11968563842986311, 0.06984019811664309, 0.0752645902601736, 0.16076694402311528, 0.13376533506172045, 0.16946641435580595, 0.16201295144855976, 0.23692789939897402, 0.20185579492577485, 0.08253037716661181, 0.24014806374907494, 0.07778615531112466, 0.12824640263404163, 0.1835308710911444, 0.18500051008803503, 0.111412627356393, 0.08415015560707875, 0.0881794865376183, 0.0967323797355805, 0.10786635907632963, 0.14211883395910263, 0.09060397358345133, 0.13395384566060134, 0.09645505568810872, 0.09336110563682658, 0.09204769254262958, 0.09396684741867439, 0.14731645291405066, 0.15806123135345324, 0.19323050204132283, 0.2531612797507218, 0.08792818430811167, 0.1393804159015417, 0.10709285629647118, 0.20392178477985518, 0.06075419352522918, 0.10572544538549014, 0.23144107524837765, 0.19004665288541997, 0.12782615875559195, 0.13517025538853236, 0.11819466629198619, 0.0854486884283168, 0.082509098308427, 0.22912906216723578, 0.14696980294372353, 0.05164063362670796, 0.06558425006057535, 0.10849591743733202, 0.14601481918777737, 0.19513901748827525, 0.12075106054544449, 0.13419041010950292, 0.10943473170378379, 0.15614860398428781, 0.04546822447861944, 0.10906197849128928, 0.12676391218389782, 0.11270529084971972, 0.11044045630842447, 0.07885368767061404, 0.2223593182861805, 0.20587797409721784, 0.13753729765968664, 0.12156342981117112, 0.14617419349295752, 0.1271267519997699, 0.1756369846739939, 0.1808456773204463, 0.20374303151454243, 0.11535396586571421, 0.09838403575122356, 0.14337880563523087, 0.13549291236060007, 0.1674663916762386, 0.19869243752743515, 0.1403315727199827, 0.16051759597446236, 0.09611933691693203, 0.09130119545651333, 0.1872288326599768, 0.13110380859247275, 0.19986174335437162, 0.15736589580774307, 0.11565736601395266, 0.08338417099522692, 0.1679539190871375, 0.19662532130522387, 0.0764745267640267, 0.12180726815547262, 0.13691707594054087, 0.06935295569045202, 0.12157060871166842, 0.09573914696063314, 0.13769606128335, 0.16914846641676767, 0.17581318664763654, 0.15531700503613266, 0.24176664118255886, 0.07272794137575797, 0.1606908259647233, 0.14661689688052448, 0.07586871712867703, 0.1458253857812711, 0.15449311424578938, 0.1319065833730357, 0.18211588130465575, 0.08910032641142607, 0.16097494214773178, 0.0936959016003779, 0.1356412808277777, 0.08590962405183486, 0.08877310289868287, 0.05381570816306131, 0.15883364847728185, 0.1516576792512621, 0.17714599227266653, 0.13031279960913317, 0.06415930616536311, 0.16695333777793817, 0.14857109130493232, 0.18225867221398012, 0.11940370712961469, 0.07678459012614829, 0.09261488675006799, 0.08952607999422721, 0.09245774482509919, 0.14598203237567628, 0.07504021230020694, 0.11999773739704064, 0.13875826714294298, 0.06791684989418302, 0.11216835930411305, 0.15012668711798532, 0.0927301427083356, 0.0890217859830175, 0.09605889301747084, 0.10909388999321631, 0.07093744352459908, 0.09706863454942193, 0.09148724975862674, 0.232612742377179, 0.10630210515643869, 0.14097215048968792, 0.11000388009207589, 0.09593962013189282, 0.1330597943493298, 0.09936484454997949, 0.1414782019065959, 0.0969638687425426, 0.11234959600759403, 0.10124495652105127, 0.30477890425494736, 0.13931737999830926, 0.1783981200839792, 0.14775897988251277, 0.22668529115617275, 0.10377883019724063, 0.1586494126490184, 0.13152194901236466, 0.14539535742785248, 0.15296790323087148, 0.08942489685224635, 0.2105862878795181, 0.1637374617691551, 0.12275116464921407, 0.12135492957064084, 0.1459828330469983, 0.08475314253675086, 0.09143557931695666, 0.10275734322411673, 0.12990646569856576, 0.12420526519417763, 0.1431010133985962, 0.11727812833019666, 0.0938864681603653], [0.023236949096566865, 0.04660381729315434, 0.045179938697921376, 0.008298034596789097, 0.029240095987915993, 0.03017176528062139, 0.059027871516134055, 0.036405330789940696, 0.009683927105340575, 0.05491204094141722, 0.021219296380877495, 0.05065208952873945, 0.07112072940383639, 0.018846608698368073, 0.03999922205028789, 0.04739794075222952, 0.0068359833177445185, 0.03556780483839767, 0.014915758644097617, 0.043200882750430276, 0.017492252801145827, 0.02910611924848386, 0.019671357835509946, 0.04412750034992184, 0.005696319717182112, 0.05278484044330461, 0.06587101931550673, 0.0687993321833866, 0.04568076539518578, 0.04337675563458886, 0.053516504753913195, 0.05362456824098315, 0.06329876769866262, 0.033829126706612964, 0.05820261687040329, 0.05853421014866658, 0.014382937324366398, 0.029290975936289345, 0.020580643954287683, 0.04447800100647977, 0.0406883557859276, 0.04905569679769022, 0.019899649246196662, 0.02330552354188902, 0.02044855523854494, 0.06904100600097861, 0.0035682133748196065, 0.012259377166628838, 0.03250634304380842, 0.020813072732250606, 0.027611496592206613, 0.012106977353271629, 0.039009666935141595, 0.06943327388060944, 0.02608943567611277, 0.02224176553344088, 0.05270228987293584, 0.06175875783498798, 0.015182073460891843, 0.0014262146640768541, 0.05345678010157176, 0.05475339945405722, 0.03895058689106788, 0.05035021608429296, 0.016954121944893683, 0.07749022583344153, 0.008409027658802058, 0.042998743775699816, 0.06332848074712924, 0.04466524953022599, 0.03892864306856479, 0.05069567522566233, 0.03551623956965549, 0.08314254467508622, 0.029390086153788225, 0.022311111812346747, 0.027319222721936445, 0.024624622759542296, 0.04365479553650532, 0.06561847536691598, 0.06859554097588573, 0.020590859298993434, 0.060312182243381224, 0.04351375524752906, 0.018025908718949983, 0.00655614911478811, 0.027236885890098553, 0.030715512710490396, 0.048732958401420286, 0.04860656089814646, 0.03409048143242087, 0.0661655238696507, 0.0503999459158097, 0.03579938544758728, 0.0888820756226778, 0.022647018876991103, 0.07313344068825245, 0.03929807485214301, 0.02345930502217795, 0.03251245664432645, 0.024426370094131147, 0.05575705113421593, 0.02035610653859164, 0.027833667617025118, 0.05653455048533423, 0.06568405577646834, 0.023136666709823266, 0.02635304313818259, 0.024109848774969578, 0.02542117198130914, 0.11568984069994517, 0.046143414319625924, 0.01167185405003173, 0.013004661371399249, 0.029091317007052045, 0.027897105552256107, 0.008556197663503034, 0.015877325886062214, 0.08660253044217825, 0.014017051734429384, 0.008755295953181173, 0.08546412509999105, 0.03329162519159062, 0.014487438502588441, 0.03692408777507288, 0.02234074513294867, 0.0015070651861606166, 0.06878876739314624, 0.03136898943090013, 0.07109409690435443, 0.02364392252638936, 0.046001875307410955, 0.026123713568917344, 0.010514783057650285, 0.033810025945838006, 0.013227887518171753, 0.038936541216181855, 0.017765568402994956, 0.03708069026470184, 0.024612695810252, 0.0514171106208648, 0.055056216062179635, 0.009501447834606682, 0.016221180292112485, 0.04129724936293704, 0.008637585394483591, 0.03183803694056613, 0.017631299893504808, 0.08950481470674276, 0.024313945323228836, 0.06381228300077574, 0.019145635688411336, 0.027078488675345267, 0.015851933409326842, 0.02280398947186768, 0.048580304985599856, 0.08720483883683171, 0.04245114905227508, 0.10199453415615217, 0.037295436420078786, 0.06471160652914218, 0.030795237182506492, 0.022263371784772192, 0.03218372678384185, 0.019890388939529657, 0.09069015431616988, 0.031204230950347016, 0.011825709321003939, 0.034580437998686514, 0.03881187058453049, 0.06267429835030011, 0.06049949862062931, 0.013755304306479437, 0.004734552731471402, 0.0026512280040021452, 0.029903906796659743, 0.025368353119120002, 0.16533362040562288, 0.08442222779350621, 0.014377753316823925, 0.01760445874450462, 0.02272400206753186, 0.06965943638767515, 0.022589633474126458, 0.020904647818367397, 0.008773284764694316, 0.050966213922947645, 0.038854058499314954, 0.04674491865028228, 0.023341623301218663, 0.025660874654671977, 0.02111493599867182, 0.03665199523259487, 0.04095111507922411, 0.04871702300650733, 0.09024472321782794, 0.04165984151352729, 0.007419609098828265, 0.0037009161647542244, 0.05439217115885445, 0.07947380082415682, 0.013061598092982811, 0.05887311124908073, 0.023661074195323244, 0.021821002575701902, 0.024204808054491878, 0.05208138283342123, 0.037093188879745345, 0.0239788321445563, 0.07795129037861313, 0.03937802663339036, 0.05487535594563399, 0.009111880524350064, 0.038385865943772454, 0.01766376440147204, 0.022545471022437726, 0.06484881309526307, 0.021239898400381207, 0.03220997591103826, 0.07982787396758795, 0.048417022318712304, 0.0262244166473725, 0.018033672855900865, 0.012749450780185205, 0.05075851435373936, 0.027593070973775218, 0.012071905574495239, 0.041990220214107206, 0.06665795030338423, 0.0434385837454881, 0.01429191354795226, 0.023274409318608896, 0.04359360185584851, 0.10553544200956821, 0.022764707383300577, 0.03843006232221212, 0.018338762556335757, 0.059290057447339804, 0.05094794097489544, 0.07882845973862068, 0.0124100433230134, 0.003509639263419168, 0.07918868040932076, 0.05936881500695433, 0.04693283213834677, 0.050512684509158134, 0.05402463588065334, 0.01879889750853181, 0.02238369979230421, 0.07829491408275706, 0.03495276712679437, 0.01066537287884525, 0.03888976979734642, 0.024859965845410312, 0.03680913715756365, 0.09874530136585236, 0.023455898776384335, 0.06761625209557158, 0.042018464234258444, 0.008254542198431278, 0.05050181777083448, 0.026446587672191005, 0.03672642034611531, 0.02011262103249984, 0.0790938754965152, 0.07053277881017753, 0.02836345588522298, 0.030093659114624773, 0.022731849325022528, 0.062153482011386325, 0.026475038645522933, 0.04196089053792613, 0.05895533612264054, 0.03812819227044072, 0.055694707336702516, 0.05302298248612455, 0.017283755953290632, 0.006916595398381884, 0.0312979671704982, 0.02481749464225556, 0.01650954919335033, 0.0560887597634324, 0.007590266593199755, 0.030443895142525434, 0.026269004879785434, 0.016478054990459765, 0.048234737278627496, 0.0335345644769924, 0.011688482398832483, 0.032579947129956315, 0.03699602605774999, 0.004527380299155733, 0.02979703413854752, 0.023394070665485094, 0.07889971270092896, 0.01469053590803274, 0.038692556986851354, 0.02161515879976962, 0.05437936041770237, 0.028866443716521775, 0.016313830856233835, 0.016305352561175823, 0.04619369037183268, 0.029446533481989588, 0.011329355017681206, 0.0479727277665266, 0.01583582329164658, 0.0540664268524519, 0.06472094995634896, 0.03562876442447305, 0.044080399841602357, 0.07675316716943469, 0.06980426290205546, 0.02570505576607372, 0.021795180925567235, 0.02379326129864369, 0.02698191617881613, 0.034871702548116446, 0.0483683747505503, 0.011824558355978556, 0.032011344962354214, 0.01788813727242606, 0.03292968782729336, 0.024784188750865202, 0.03576913974913103, 0.008734022184008998, 0.019824021429355656, 0.03340061827163611, 0.03449087816157511, 0.04767703916877508, 0.029009309264698198, 0.014909343095496297, 0.04851736407727003, 0.009782567437339042, 0.09971411366547857, 0.038942023779132535, 0.044671522586473396, 0.04663833436955299, 0.012720438319125345, 0.016952147407989417, 0.04708529556436198, 0.11588905858142035, 0.034194694233259985, 0.015776979038491845, 0.07444082839148385, 0.033851799954261096, 0.053675760315465074, 0.04584159855065601, 0.006211122115408736, 0.05447812797501683, 0.020987831122641052, 0.012843033481788422, 0.15866915801806108, 0.18610044249466487, 0.09729545523545571, 0.1084713748257075, 0.12940508260258607, 0.15055064936833723, 0.2228313750986542, 0.08570539179657187, 0.08470956701785326, 0.11223497787224394, 0.16923907798315796, 0.09795617192451443, 0.145086244014757, 0.08084061462432146, 0.05930392670312098, 0.08042917134506361, 0.1204789544322661, 0.08873678091913462, 0.147531942065273, 0.15482159304831708, 0.24522573128342628, 0.08027766126074962, 0.08744381887039968, 0.15556130478424685, 0.14596086208309444, 0.10350977070629597, 0.1472251085298402, 0.2392763090985162, 0.10508831457367965, 0.11730668108378138, 0.14829488684024128, 0.1466333038572754, 0.16496334384594644, 0.12550585397652217, 0.17182768907930168, 0.0916852666331189, 0.09196411059903246, 0.0752659405448607, 0.15369580845747674, 0.1695848187165601, 0.1044465493676918, 0.15563712428723062, 0.09964306426367589, 0.15815812615411623, 0.13439597907875264, 0.11801215394267014, 0.10792417025991849, 0.08942009282431432, 0.13903586938977242, 0.1315533109009266, 0.18026079370507173, 0.09741231932171754, 0.1161606354372842, 0.18875377226088727, 0.10931069550237485, 0.12338955753615924, 0.23665526402848108, 0.16208423833761895, 0.11355998034455947, 0.10854270921221801, 0.10121970823300735, 0.18606540294630186, 0.08197956279452358, 0.13573234022728034, 0.13393526737179073, 0.1778128972010953, 0.11030905121671301, 0.09842579279627119, 0.23816847854426929, 0.16244490684143134, 0.10526232487921204, 0.11987564180578504, 0.17070934123226575, 0.1484853516199759, 0.0945073344877788, 0.10797332333666937, 0.11131867061236075, 0.07462948148271867, 0.10117985108601195, 0.16148819960653782, 0.15083115574504646, 0.11116858545158591, 0.08951766615999596, 0.10814183072320052, 0.10423360472278935, 0.14357646288616316, 0.06724030976848942, 0.08592816162854433, 0.11188576982489654, 0.11636741219886712, 0.11422793700226716, 0.13477549728538307, 0.09261906652578286, 0.22369550301560334, 0.14200108099196637, 0.14329362234898976, 0.14839095382818154, 0.09862329398414918, 0.11837860356484141, 0.11763465777039528, 0.13676855819565908, 0.08649032789149455, 0.0911790659385068, 0.19042686319776944, 0.13169394406889165, 0.16110060683318547, 0.12818017761622155, 0.14716659166983195, 0.17373658450586454, 0.0934290202068431, 0.15139195136725903, 0.1790900765252965, 0.06421065091022424, 0.1536078838897603, 0.1343731124486242, 0.13237178698182106, 0.05480372639639037, 0.1332241626722472, 0.18586348449545248, 0.09398894730423178, 0.1355437482041972, 0.1485895203160388, 0.1759060780916895, 0.2143062882657562, 0.07938241572784525, 0.11691067447619778, 0.16317159070500306, 0.10301851135279451, 0.1749156340956688, 0.1453254140381302, 0.06701057816722564, 0.19235796029014246, 0.12452598155609199, 0.15907557335283073, 0.12121365857975823, 0.12327686644026212, 0.16697406023740768, 0.15388928593269416, 0.09519442583301238, 0.13582486526242324, 0.20643330072718008, 0.17231618000992707, 0.08904688499335732, 0.0961625324562192, 0.14525082946888038, 0.10273267169083868, 0.08694331786994423, 0.1395844513816493, 0.19294352244053567, 0.19135884461658342, 0.11406217089721135, 0.15509049647620746, 0.14126918597945146, 0.1339532078376838, 0.10804300888308457, 0.11146764297570501, 0.19219892525247165, 0.12030216891850744, 0.15097777359187603, 0.11860883049666882, 0.1687209215015173, 0.08201131144804613, 0.11561484900968415, 0.08415045416248695, 0.09710717533848115, 0.183124537180577, 0.1607059980077403, 0.08417608243014131, 0.2332182398864201, 0.0973819073821817, 0.15915614260094507, 0.09848002131496157, 0.14712031558156013, 0.1010249008291534, 0.14266964154584066, 0.1533356692109789], [0.06829530280083418, 0.09866859298199415, 0.015777367499790022, 0.04562467090519411, 0.01964238778288875, 0.056189033668488264, 0.013348126467982573, 0.055873494528766186, 0.04697525414771267, 0.11264028719493321, 0.012643020018003881, 0.03605719482792275, 0.029721055179834366, 0.03290396795741149, 0.03730533963867596, 0.026362668157422116, 0.011688072733314974, 0.010534667526371777, 0.02673637301528028, 0.017574867832341363, 0.0315420565727566, 0.03994199440681508, 0.017812448387433375, 0.0328674695587584, 0.04574683774262667, 0.04385774536058307, 0.029078662328954254, 0.021241145208477974, 0.01635150990581938, 0.03644214810005256, 0.09193029241370303, 0.050021014641970396, 0.02557852934114635, 0.06033152049141271, 0.01471548733700599, 0.037292857987007925, 0.0018194049272486673, 0.05730228232485907, 0.0214105431722211, 0.031684002705982754, 0.03631251059206469, 0.07277932004737002, 0.024890608486852477, 0.05236324967284288, 0.018774480425885746, 0.04280608393517988, 0.035248211451939175, 0.025170329459277645, 0.006025923615587609, 0.018069831987044642, 0.028854850945728164, 0.0186063224848892, 0.04337388203878488, 0.05801939884466784, 0.07455130746322018, 0.07231569063982793, 0.05292367888614535, 0.04351509874686599, 0.04256074602848717, 0.062417486416442056, 0.007000754520829234, 0.02569420768746308, 0.0426201721254204, 0.057429500855505466, 0.013852143128003393, 0.039176315135721645, 0.04865421101983104, 0.0780893179721066, 0.04416908097586461, 0.06806288420089654, 0.02520188642665744, 0.06998714166028158, 0.05300910644499319, 0.03276710744415011, 0.021473589253478816, 0.034260132150458436, 0.03423651573913438, 0.01991548286085682, 0.037950860535992045, 0.07570849465472357, 0.016290787807000533, 0.02285211456806532, 0.08366557982351099, 0.06237034858869655, 0.035175530173416646, 0.01752110241380121, 0.025625020864286592, 0.06277915236673184, 0.046747931345765076, 0.03655924628089581, 0.029608591393168484, 0.07328043172934226, 0.12270662561058998, 0.010866429590220963, 0.07924748903938703, 0.08227691719574587, 0.04944052454084158, 0.03512980369850993, 0.035191150049545934, 0.026840009061353545, 0.06416432053915092, 0.04432470976774182, 0.07573083202753748, 0.06793867836573295, 0.1356350247349058, 0.016218449188662425, 0.07291182436581169, 0.03394300523879273, 0.015124554047361016, 0.025148221092032533, 0.01257781873989318, 0.05407024021925671, 0.04071000783837267, 0.036810446730149646, 0.052799164317548275, 0.005786577173109565, 0.048949214297213724, 0.07187784556299448, 0.05666681731651936, 0.023001595832673565, 0.0375524688778179, 0.032912510713296275, 0.018264822595353638, 0.020066183792161088, 0.05099772848188877, 0.036991547726626904, 0.0504180695861578, 0.11879747680255345, 0.09802156912961177, 0.03186438445534025, 0.03350041041682873, 0.03039766994438001, 0.04068465098472578, 0.07045545295945235, 0.023035402143640176, 0.010405312458585416, 0.037812754910971434, 0.03509355975048883, 0.005547080180674259, 0.012490778812207282, 0.014688831088798386, 0.030444794201425145, 0.04892619499670608, 0.006702407762142164, 0.06999031720416886, 0.036918310049389086, 0.01051709262122001, 0.059149770332234244, 0.05241696250491908, 0.06856107139693839, 0.008655690405118679, 0.03804726679144161, 0.04744119396699326, 0.02000092907941767, 0.07009063182132584, 0.09459336594279323, 0.03327138109930924, 0.02512054025594677, 0.039143127987959554, 0.030645304692110846, 0.012643322814255953, 0.06102062708565167, 0.030249216660325016, 0.061257347597607543, 0.0410442440105336, 0.028076030147661055, 0.005787631870979177, 0.06059447316718953, 0.07028410251119308, 0.07907791635287659, 0.05685722442077739, 0.05141100041302187, 0.03813565615564585, 0.03467370942234993, 0.013595134418989931, 0.03732597728126815, 0.030462028990898813, 0.04521300031670502, 0.02907480825004833, 0.004187676406997655, 0.030087738896587064, 0.022113854897075465, 0.1083203668573073, 0.016299936155389463, 0.0223831026814878, 0.13285556887941702, 0.007890277459020061, 0.034638232218899896, 0.08247769570776395, 0.00869047295834337, 0.027793978407446827, 0.04152598351772342, 0.02322805350247238, 0.018004081943737607, 0.08447796944528818, 0.05767893711371081, 0.023687852579834204, 0.028641563640641313, 0.02659550914540887, 0.0059351636196619696, 0.027461553923785686, 0.028809307675276483, 0.054872149867670875, 0.05064349927540336, 0.015556397481954523, 0.022705486543210487, 0.03131229104474187, 0.03364478909809675, 0.09257687521832329, 0.031211596447974443, 0.030035949711288725, 0.011635015535700535, 0.02707103157549032, 0.03121042936774237, 0.01547027612105012, 0.02234980357544763, 0.07514662694718156, 0.030078907763319354, 0.013919550493093473, 0.01860707056974726, 0.050202247952776294, 0.031540685932018926, 0.03923400757568223, 0.018606661752398525, 0.004871367867703417, 0.022921900198395764, 0.02433092057305787, 0.018698280943291526, 0.021830327343195677, 0.032200707122683525, 0.021529838110187223, 0.025022544532216022, 0.027233276083799343, 0.028758743245686804, 0.02469004880237792, 0.0711244884878397, 0.04619043679641826, 0.01509399283012109, 0.03662996659321444, 0.008780945425054856, 0.04200161620974541, 0.014561369981882828, 0.06461230971451316, 0.0364933842793107, 0.037444873579910824, 0.04134468235341566, 0.04852673125320247, 0.012745075077483696, 0.011295876948029866, 0.050166387377040725, 0.019252572807350328, 0.03580478997901082, 0.013180892182780164, 0.03913881929059114, 0.034942470357886384, 0.055572825483977795, 0.04103946712400232, 0.058503743926329274, 0.06697214594376938, 0.03348855301737785, 0.06226902973971196, 0.005651813757140189, 0.09122903325728007, 0.07374338260186569, 0.005624032837139177, 0.03581016058368342, 0.01291146204208157, 0.05293373816779681, 0.07922512452517237, 0.019987633185727254, 0.05115543698359813, 0.02842499901141439, 0.015590076567605138, 0.032625235949776, 0.024417284510231445, 0.006630117065339748, 0.027305431497682418, 0.0306207281537354, 0.014711497551096337, 0.04699699101703508, 0.09469593329621212, 0.05064579950911658, 0.014965580077841878, 0.015474048775753804, 0.05905891449323722, 0.04598743947488921, 0.01649803445408387, 0.040727402083575726, 0.020631150708400776, 0.04727207589894533, 0.013690942715454315, 0.036758084182760546, 0.03264840113531266, 0.032355474175087044, 0.017279530376462, 0.04813711305281945, 0.022472243523225188, 0.004950256893477801, 0.03024692999731217, 0.04869517757158194, 0.043095611434962065, 0.023274017464635626, 0.04493532343102353, 0.045513733822320185, 0.05534773166956646, 0.06857433675655297, 0.04351907156940017, 0.040887051195438416, 0.03662348319111126, 0.05802038950579507, 0.01886335324629077, 0.03927441433604274, 0.07813711397882019, 0.04246472314532314, 0.018894542108422945, 0.06625788605638913, 0.0028802117324500743, 0.01777244026639632, 0.06969589407422713, 0.039366030134260654, 0.06169441235916955, 0.03366224101877638, 0.004398400121967175, 0.046541979004229815, 0.03457668909270849, 0.04109924266647015, 0.026928522258198688, 0.10111680839742933, 0.06352748149739844, 0.021118693386337588, 0.04919114935078791, 0.047725306757326634, 0.007394022391443806, 0.07095231022685766, 0.03428774174036724, 0.04549659063507404, 0.023693584504404237, 0.07429229029055152, 0.0189295545153852, 0.07095637465161936, 0.052986110893211195, 0.006131417575358812, 0.038789407682738135, 0.015366041267822896, 0.030314305131988864, 0.030948311290038482, 0.08882859349250793, 0.030734800068395476, 0.050451022639338455, 0.039836658630520105, 0.04308411365907107, 0.025971933766933422, 0.09296150279364415, 0.17803388248596871, 0.13029013653951033, 0.11416609532066754, 0.08120182595614876, 0.10130337160080671, 0.2113149937774454, 0.08366961032152176, 0.1300228073128632, 0.22455326627407754, 0.15017635588135037, 0.06793388790850129, 0.14730855476643356, 0.08092668679143701, 0.16235520451196603, 0.1673552883522851, 0.10372977211539235, 0.053270013337688785, 0.12081075805638518, 0.1360624475138528, 0.13125847386462347, 0.11096227009381567, 0.1229164150676557, 0.08386185286300522, 0.07690962377403464, 0.10195233606334243, 0.18169837870768138, 0.11906351681266512, 0.09792612639388867, 0.14319566903369768, 0.12227836144821984, 0.08769528394831078, 0.1795664895325899, 0.17713725274162634, 0.06362916675529309, 0.12198550573417119, 0.1505720910749265, 0.12110993771680764, 0.0894531374797225, 0.07684288306960038, 0.21355099736579827, 0.1372974491012948, 0.10379547466124807, 0.16047340977404798, 0.16232130490243435, 0.091508800030819, 0.1251256979469742, 0.21183925707425388, 0.0971748252798404, 0.1425109457756792, 0.08890980734888997, 0.12934514081903867, 0.16770845225879125, 0.1150884415422167, 0.14930435695818492, 0.21167475304433278, 0.15182273967989854, 0.1298402135393449, 0.11782576037304741, 0.24254641362598964, 0.1975477896630764, 0.09058020450174809, 0.14649967317070278, 0.18831001035869122, 0.11439746219132628, 0.1682682300784758, 0.1452237559216363, 0.20819734249796185, 0.1305033593837704, 0.16626454330980778, 0.11404439327972275, 0.24504722229072026, 0.11029799788125924, 0.14579998143017292, 0.20925606068755898, 0.07545083455209221, 0.14047802771840776, 0.1386871023901871, 0.09742878058126994, 0.14979211507099016, 0.13412023601787432, 0.18678226162280354, 0.15110205406589167, 0.11129656394145318, 0.11071176175028086, 0.12914398232741015, 0.12818104614104542, 0.1991068867168256, 0.13878462144306727, 0.10083190511379923, 0.10922870811607156, 0.1607290274862732, 0.18113125913909503, 0.23235264633383068, 0.1727322983954634, 0.1541963094579322, 0.12882117607763835, 0.08468671395842518, 0.10536678534533296, 0.093258076879595, 0.1488441609378372, 0.1823145699288164, 0.1001866115257144, 0.12907513816441807, 0.25039567958031383, 0.06896211951971054, 0.12775445117482118, 0.12612310371228627, 0.15750465621905668, 0.11735096227909837, 0.07694897880511624, 0.17589321306773595, 0.12604805773922376, 0.09202342813036271, 0.14155072372938904, 0.13458731238331112, 0.11779955535062722, 0.16966185958257743, 0.1038968206516334, 0.15474733417587622, 0.13616409205964633, 0.09118315750466925, 0.16185714623757771, 0.12832001011286462, 0.11132593772241048, 0.15016126526253565, 0.14964561936046394, 0.17425125331750937, 0.18105781450867653, 0.08801380864211492, 0.1405306277530534, 0.09073981629418475, 0.18936407379806042, 0.11592264606484345, 0.15762975093509468, 0.16016036085784435, 0.19750273493783815, 0.12183336461228983, 0.0836928840726614, 0.1494312837187733, 0.08675330092332192, 0.07880718766578607, 0.1508898897362607, 0.14326816371509007, 0.1640513792101826, 0.11881640792957374, 0.08709944877773523, 0.09331728584532227, 0.16324589028954506, 0.119924360620124, 0.0727246165541666, 0.18481597570436342, 0.17774485370942525, 0.160957558080554, 0.23796038542475018, 0.16590088925191335, 0.078645960960005, 0.18604928095425877, 0.08990015635000807, 0.1709069034882954, 0.07883363696081297, 0.09077454371643917, 0.094375807259764, 0.12105516637010233, 0.10756909967000995, 0.07769385419253792, 0.09471322915383748, 0.1537879128009081, 0.12404837432716574, 0.12883634812065534, 0.18894805040742668, 0.19825778156518936, 0.17996858938464097, 0.09333234932273626, 0.11717427176024232, 0.15438107454351016], [0.02831497455814055, 0.011694158344263477, 0.04646047337778977, 0.02771233198499041, 0.027682471355157237, 0.02636337892285415, 0.07533977194023983, 0.016897847643122077, 0.0076091909348698595, 0.025907946218337332, 0.049179485333817344, 0.06991959349917513, 0.04724997601338795, 0.09054010308214597, 0.04947241907939315, 0.07337992531912667, 0.051763492569859536, 0.053815697985036035, 0.032791117405784984, 0.056256361305713654, 0.03142220014706254, 0.022569674366552914, 0.016368963522836566, 0.025889121960582476, 0.026627128877277886, 0.020290449793849672, 0.08814948171909366, 0.020865520096517036, 0.012380546557583978, 0.04555692257625716, 0.05175564870504396, 0.006834845499335123, 0.04109862180692809, 0.030235567928424904, 0.025405431665214043, 0.016935480891593864, 0.05077027675828763, 0.0375317837377744, 0.020088244661954895, 0.02113806556112, 0.01114478161824601, 0.054325908821608336, 0.058852789125272205, 0.014166834098952157, 0.0723821735009551, 0.023970660886594226, 0.05889166918184076, 0.04598394501954317, 0.029974684784454957, 0.015393837454861828, 0.0315859306470624, 0.04229508939066103, 0.046368148510477374, 0.04920774292466896, 0.03621843510440417, 0.052520327136984894, 0.03791278793609568, 0.007138414857243853, 0.027353045996278524, 0.01831135991960764, 0.02237177623568901, 0.03931510608111109, 0.06723972622837339, 0.038368420808443, 0.03971919064809169, 0.06053751693772418, 0.03430999429630382, 0.05157560622319579, 0.02103009876529021, 0.024554122971104722, 0.010624586138874292, 0.09605216195008584, 0.04573380308491843, 0.03646332857065967, 0.013647464735965644, 0.06838197886411633, 0.11388614534267358, 0.08319121599197388, 0.06620512317333903, 0.05338195465239031, 0.07956459559500217, 0.02398344109367047, 0.07790142484009266, 0.04477384566728558, 0.030412180415753807, 0.03408812352323106, 0.03616029143865619, 0.0334356646053493, 0.042814474020685465, 0.03036249808168837, 0.011869507908288921, 0.07174775004386902, 0.03307338458086763, 0.05918826362384217, 0.055008586296545606, 0.009118224826774426, 0.04580659292904394, 0.02578369458205998, 0.01571064884774387, 0.04979211085342935, 0.02735599083825946, 0.055154654530010054, 0.18002481279628618, 0.05297128829572882, 0.012945372677807297, 0.06884249379592282, 0.05034182260611227, 0.04339760362303682, 0.0758231942142759, 0.014498887084690588, 0.03784671898132988, 0.03413580757166658, 0.04291374369391373, 0.013636009368513311, 0.03481964873416083, 0.04764820821583271, 0.0249840003504817, 0.05128342904416578, 0.029556588469339267, 0.01998068668347384, 0.04324426827952266, 0.040448788819568496, 0.057118840382567475, 0.025769825326278806, 0.03269053137462054, 0.01640412860017802, 0.05278777849993535, 0.06322619837841817, 0.024972148040043454, 0.0696014284289309, 0.013447419041767716, 0.015454708831384778, 0.0594763153099588, 0.03998875904030033, 0.01209578915898289, 0.03992121766454407, 0.053482961375266314, 0.03619258292019367, 0.023787587049550245, 0.022048936059166278, 0.025010539551398585, 0.05445469476814781, 0.010845532407984138, 0.02475913554163916, 0.06185068575931447, 0.023129821987822652, 0.032940028700977564, 0.015192402460213219, 0.017407956699441587, 0.02267559537930148, 0.048165296004819017, 0.03726851554321391, 0.025310552113556435, 0.029344006840671812, 0.02729820509973381, 0.023324617517313788, 0.05257084406912327, 0.053714253607073, 0.019079390314540694, 0.022247648432052562, 0.007618683639780751, 0.03237046979899917, 0.02805318556992071, 0.04141578943069492, 0.05102990800514817, 0.029696149551974874, 0.05160633707419038, 0.008345766142675919, 0.08245444909802505, 0.0727407249755093, 0.03776998006339584, 0.009623470483347774, 0.034381559384720664, 0.04727575355874641, 0.02799569160145308, 0.09140494346086468, 0.02741000901109406, 0.025264074161116565, 0.029337784674550806, 0.04832518260393824, 0.046245147074971876, 0.07891276771468775, 0.04159793197842581, 0.016057437917749797, 0.07373096541102443, 0.009694643717791353, 0.03349552835736956, 0.004956614342518151, 0.026624106003769805, 0.09077532403171062, 0.05184468607019101, 0.06213718360023839, 0.00711610632216824, 0.04599509334989956, 0.001698070885530407, 0.023781973868608475, 0.042487823870033026, 0.029119757802358696, 0.026781507468383228, 0.022036496815936904, 0.0163664614249553, 0.010979655032445277, 0.04111435703401055, 0.011961449403315783, 0.012383728038652666, 0.03983763572094696, 0.011309243239728468, 0.04533106880262494, 0.10070921919707741, 0.018636386675227965, 0.12917265721729823, 0.026814514804365377, 0.04040323876376663, 0.0779871509543487, 0.030368988269141743, 0.03516863286495209, 0.008780152387251812, 0.0060375320775035235, 0.04065183024587376, 0.04091519343533686, 0.0572681316573705, 0.017254597607201765, 0.07038824406585523, 0.008974767256794232, 0.057607650224651606, 0.047248883572007926, 0.05237664734678609, 0.026599833109815205, 0.09834776126912662, 0.022975575711045946, 0.09405817823218447, 0.08982506966484444, 0.019359272439032793, 0.012685909368363875, 0.02752400967957718, 0.08076076462332692, 0.016586798708885908, 0.09023430770529167, 0.04707879859155842, 0.03146605725799288, 0.030966394248285463, 0.030869194106864076, 0.026782050296398144, 0.027429952851629684, 0.04738585604354739, 0.04568644812596696, 0.028873914387077093, 0.034146799838968685, 0.058701591167066774, 0.0170414154750428, 0.06381454930773803, 0.09859521620507751, 0.06550883767860276, 0.05875029641070536, 0.021689778992107937, 0.06305843059505735, 0.031328694628817697, 0.049529470303761106, 0.03806230991280504, 0.07055296522698232, 0.0887184604736311, 0.038884260092995, 0.07712201880557196, 0.05238451496032732, 0.023155523197991506, 0.05489699103470359, 0.04388377057122333, 0.06434466836175748, 0.029508100356906652, 0.04284846523244466, 0.03288576625553625, 0.02245138705308948, 0.038368563300796917, 0.03403946238436869, 0.09997875589345183, 0.024219598421560865, 0.07939540967345238, 0.02365516754798591, 0.04450690659827419, 0.05431713197114212, 0.049872829379247766, 0.04572082271001168, 0.029442764219960997, 0.03952155036053487, 0.05567604762368968, 0.056230173246668916, 0.02212050793293331, 0.05107485077210835, 0.023638984487791146, 0.02009440236724913, 0.03992508192147527, 0.016228454187512398, 0.07228502085698502, 0.02022991089948586, 0.06936240089791161, 0.028118777853835906, 0.026084311040384427, 0.04190870780231697, 0.01627598556556872, 0.033786772550748925, 0.03663632785901427, 0.05035365286416241, 0.027985583126012768, 0.0321893213050706, 0.039847247169486115, 0.0442779281708811, 0.032827256180878193, 0.02411160957334297, 0.05406460837860193, 0.03221012858141746, 0.01266226072662643, 0.0795726633763739, 0.017490746453404427, 0.035374412180057595, 0.08330147793250424, 0.05398515532059329, 0.013397383869492581, 0.018195447478709475, 0.0012473635412918935, 0.02123330982535013, 0.061665398201772144, 0.02687922668909388, 0.049315022703792365, 0.06765942727880818, 0.018291799451357553, 0.0030548698268830776, 0.058749244681426456, 0.022778388345614076, 0.03692733795781221, 0.030357687268406153, 0.03075344960338303, 0.04953449824824929, 0.057566646353474686, 0.07139079991195883, 0.021512633854789392, 0.04168555459805897, 0.06056972020970924, 0.029776895219194036, 0.07134338388485567, 0.012793232404094721, 0.08176874196422951, 0.01874013976859195, 0.07841310131230525, 0.028319581810917174, 0.040366791255239926, 0.01645186693141503, 0.03500694136268326, 0.037657295752848895, 0.01543687014574451, 0.017288916212107455, 0.0732728321371334, 0.055580852553248405, 0.11612924640732152, 0.10080238205513783, 0.1799845892403807, 0.06078188453934022, 0.1254624141646283, 0.09968514022018228, 0.15821217825370176, 0.0955452827204551, 0.111838448792696, 0.04292246965425355, 0.15426123168851646, 0.12692222797444888, 0.1871028287070138, 0.14972153385835035, 0.18679907572056564, 0.11259514426014253, 0.09997287299484015, 0.13984837436250278, 0.14447024278342724, 0.20731945389083453, 0.07498206184910876, 0.16056343780032226, 0.14165405104202883, 0.12868822392608437, 0.08869857261223452, 0.06240195474986519, 0.18183297291398048, 0.09301501206521477, 0.0898670166996973, 0.22266095424337046, 0.1279637792280742, 0.12177102081477642, 0.12324458174407482, 0.13261991366744041, 0.18309377240283148, 0.13736926524766854, 0.11195367760956287, 0.16367491441113607, 0.089608013097729, 0.09657597062843186, 0.10226131376943418, 0.13861669759665216, 0.15704693006617682, 0.09826056951923029, 0.127641176538808, 0.09603257264409747, 0.09830179730696337, 0.16076148860156536, 0.13170995749533176, 0.20863824098237924, 0.1547545130763735, 0.11479854424084936, 0.2450330544795309, 0.06617046360458646, 0.2850029468536377, 0.1521520870072501, 0.1232846017394747, 0.08864285131650311, 0.1216644501047475, 0.2375951978777136, 0.15389417138482842, 0.211805058909314, 0.15940004879874842, 0.21858221239277295, 0.17187975985663279, 0.15257994404860906, 0.11006244444953543, 0.13529279881290027, 0.18332340222384247, 0.08404274351362671, 0.19051710835524968, 0.13308127676802023, 0.19831547061247484, 0.13969175490949834, 0.14734136871993542, 0.1600357818284205, 0.20965400790529592, 0.13373800367116928, 0.2020582833460399, 0.2026341153042657, 0.20434118727488176, 0.13348690500216825, 0.14487292617559433, 0.18771403948111193, 0.2643432111612388, 0.09072541099573884, 0.13199593286429132, 0.15897441735225065, 0.16322154445307596, 0.11403299389140946, 0.13362356195492403, 0.12875401468149253, 0.08554111846855708, 0.19723144306668214, 0.15867343278867857, 0.13243571855127811, 0.17450178201709474, 0.14299058860966138, 0.1109321295682873, 0.10285733892981495, 0.19922292977571487, 0.15243028636489594, 0.3028389454952308, 0.15200270073754446, 0.1834805237927607, 0.1350920203008822, 0.13361080549657345, 0.1682704421026366, 0.15828661354524748, 0.1661452025707279, 0.13043048472276755, 0.11774026496069771, 0.11040737094091517, 0.16767200135758945, 0.19700365886092186, 0.25065224724156515, 0.1219519589628492, 0.11079549297158207, 0.18110033151294502, 0.19249995052814484, 0.14719781785139016, 0.12823891160743578, 0.18221749870904855, 0.12297862315816538, 0.09010743522750479, 0.18871923482843808, 0.11695366645497934, 0.19478231162897178, 0.1534547656774521, 0.18810520134866238, 0.10561533272266388, 0.08668565776731287, 0.11148250289261341, 0.06510023746107306, 0.16824396566620894, 0.16800470064793313, 0.1365738729281085, 0.1131644622821893, 0.15848361940256186, 0.16708837981734956, 0.07761670476091759, 0.09394820127636194, 0.07512450670557362, 0.17030649499169417, 0.1690526979842356, 0.10106656287929841, 0.12768197006412915, 0.09992830681481532, 0.15611798848424638, 0.08876344056001731, 0.13293776661157608, 0.11237507499754429, 0.15854185127786227, 0.10608518429632698, 0.08202792877065283, 0.10292325860687665, 0.13946639985910483, 0.13768126921994345, 0.10460322988884789, 0.09420595637389592, 0.15330415804471287, 0.09837436662720782, 0.17718263316367353, 0.15258219678487095, 0.13689602778426238, 0.11383363351758037, 0.1522236317396164, 0.08070453442633152, 0.12606295836823328, 0.10198734847030469, 0.10442828320498977, 0.0975207220762968, 0.09481996271227087, 0.12160875595041684, 0.1599644542272602, 0.16709359096629278], [0.032183496081935506, 0.01748374566834952, 0.02142539121476667, 0.023295879862936478, 0.03816394767324839, 0.017434465366282632, 0.03421468726758446, 0.010514750827236899, 0.023412372451275587, 0.07426295043634516, 0.03857349444712911, 0.03326613263093999, 0.05275663713525448, 0.05029072891920805, 0.010543546157090791, 0.028300394536927342, 0.02628181392459997, 0.012038057703258736, 0.014046393284973289, 0.047606050835124085, 0.03618209955415555, 0.008063169878109224, 0.023400158820939914, 0.031317522549735646, 0.057919002803308625, 0.06747762739126172, 0.04103653924539685, 0.04673017069165196, 0.02327339830143111, 0.030163303948938847, 0.02105327752152724, 0.06932621462536709, 0.01035174381520067, 0.02721006509714893, 0.03294337048594441, 0.008199733532299953, 0.03419958647074444, 0.06405210441776685, 0.04739440219210727, 0.06987295100199324, 0.04734381401379194, 0.044766035729220936, 0.021073823561891913, 0.020793885458260775, 0.005214139586314559, 0.06494931091687509, 0.03116894034402711, 0.02178745241170483, 0.029187010800732032, 0.015201292965295059, 0.0957339968798416, 0.023483976555456008, 0.056360058419938595, 0.0065429974097891575, 0.08913067049746003, 0.038952632674149106, 0.023227203637361526, 0.010748396727389522, 0.0044485341059044, 0.026705745640876036, 0.021311841772070954, 0.03546165482008031, 0.013564439191083823, 0.0415770500632269, 0.03581444213965109, 0.013199655372383339, 0.026212516839482954, 0.07393099753452198, 0.12163908646575042, 0.05648135673254728, 0.014328291506639548, 0.06217449624091387, 0.04564922030216881, 0.02858848523880754, 0.04019593274486916, 0.10769414688859667, 0.07837739679962397, 0.05782477464526892, 0.08817293867468834, 0.014292286742212517, 0.08572724062417235, 0.048248036564993005, 0.052680217128779204, 0.0353168249130249, 0.030884108306573968, 0.03803663754037448, 0.04014478138248835, 0.05511042083214436, 0.020711063473884548, 0.03508945122095091, 0.04945244300844414, 0.0719800532928535, 0.056447328201362064, 0.032932602135198455, 0.06298542701240097, 0.05286639017452087, 0.059325286985508034, 0.06254469816173826, 0.04650014392765505, 0.0658230943871396, 0.05395543548677649, 0.05618435177685959, 0.029769319375710826, 0.04802913777530193, 0.05223468425018447, 0.02770544994356377, 0.0733101787045598, 0.03998184137578521, 0.041829556692391634, 0.03582172282040119, 0.02477282328930284, 0.020162530675796524, 0.04783990453662617, 0.04161106841638684, 0.009586641298873084, 0.057936305446284156, 0.07617194085781064, 0.023502787242510488, 0.06826738787016698, 0.025775365564706068, 0.07683740729199988, 0.039771539624780416, 0.03741162197132196, 0.04297439115388053, 0.06731771704341684, 0.017408809957227538, 0.01868328362304185, 0.014365249612767781, 0.02838860748202673, 0.04447049980184861, 0.02816977315316243, 0.07968730186777455, 0.03880234056019357, 0.020660339588565484, 0.0492824258814965, 0.03550917262743626, 0.05035137298649975, 0.010893249535001814, 0.013260366445008134, 0.0614290644547769, 0.012404488665716988, 0.02510303914147828, 0.048476587515324354, 0.03084913661171283, 0.03684301641104477, 0.029197853790330033, 0.04322878071772201, 0.05576919012569955, 0.028176287089341452, 0.035961643526596684, 0.013859091326594353, 0.030121017646576678, 0.008923034050634928, 0.018997109461841837, 0.0676201129598277, 0.023399276725415672, 0.09719966644687311, 0.036634102264153104, 0.017354025039821863, 0.014569363124402506, 0.014796282198014004, 0.031370258291385004, 0.05291656105379973, 0.03288300461801035, 0.020670249592512846, 0.019181406358256936, 0.03123234265616962, 0.028581710066646338, 0.050305687223694155, 0.00819136549918247, 0.045689647418579886, 0.06417536030390433, 0.009431024381358708, 0.03176026664940374, 0.04431562079116702, 0.008965797872016472, 0.035405523010662625, 0.04096578500632729, 0.024362849038360373, 0.014249398240021296, 0.0024234242903600845, 0.010248072994207698, 0.005965742648446134, 0.0635031017341784, 0.01322275779343077, 0.04645111298720751, 0.04691857951028006, 0.07376847482685532, 0.01338566726605807, 0.05562241282314062, 0.033276992583913464, 0.025914173473470976, 0.08334282785654068, 0.01679829807419862, 0.07248185029519455, 0.042864163140101094, 0.04645110620185733, 0.02083750338559704, 0.01519033801741898, 0.025681098390902792, 0.013672827526793947, 0.016122690934155668, 0.048567148191588264, 0.018465104080470543, 0.03945660098854985, 0.02746787617382194, 0.013675472965197904, 0.03845273896253534, 0.04029232542961836, 0.057575453738016744, 0.036853957788220475, 0.02376460167579353, 0.03145093271242721, 0.03494592749380639, 0.03590802229674799, 0.08884166886231729, 0.0221520174028618, 0.031103743306760277, 0.005636883442223604, 0.037069206059511216, 0.02821554712552045, 0.07884481243257012, 0.013500773946621587, 0.03204726999891656, 0.01586689510648804, 0.04794447696102517, 0.033273735615823946, 0.054378909191914966, 0.05470715729253633, 0.06197745645684855, 0.027415881731680462, 0.054732012030269415, 0.03877770973901663, 0.057022454483168464, 0.05989429966679641, 0.015744794426219802, 0.03331218140998057, 0.024584916586588536, 0.030822728028787032, 0.028656925673463514, 0.03366868370877845, 0.01537192247009703, 0.034108655992895365, 0.028267565316387584, 0.061010747615780146, 0.055926532218498845, 0.04073706781491637, 0.014852509002334304, 0.03968188140009131, 0.05206803944227951, 0.03834078746980854, 0.026690380215378742, 0.053963876462408474, 0.03441871256966676, 0.07256444157766444, 0.059301246489797316, 0.018164818407967687, 0.005416114864471767, 0.04595366200166089, 0.015430118722308959, 0.08600126699145351, 0.020302220680085675, 0.04348152144146817, 0.022428980130436163, 0.014726114891735571, 0.09949497399585587, 0.05199195191796337, 0.037755700293928385, 0.036770409771374295, 0.015897225621821623, 0.01400089411929782, 0.045311170763203075, 0.03639819599421961, 0.02385759659643684, 0.05149949834282909, 0.004635939964958067, 0.04337127646431327, 0.03658775153702923, 0.018874830666131208, 0.022729949426970313, 0.01398024205783648, 0.032083714114768166, 0.048361294237630706, 0.04892943160874503, 0.06733123346098832, 0.01316227063736213, 0.018301907926797867, 0.03215493993567569, 0.07231516816786357, 0.027337197114580443, 0.0886411074815052, 0.07444854333464589, 0.04936248283567173, 0.020738922425412705, 0.0037585632276854342, 0.02294377107838435, 0.019130887729781013, 0.060055892781487534, 0.017308563193572418, 0.060127600362258296, 0.0449135492422751, 0.00778781867120415, 0.0824291736685804, 0.037511376797088554, 0.024056339503398964, 0.0016418424908936555, 0.0681797754285591, 0.04502215895003506, 0.03800127568787762, 0.014110156068844455, 0.024742033066494123, 0.02097567686411951, 0.017146432339879017, 0.033062005548604896, 0.021025094569527676, 0.05013706787888493, 0.024259350395628383, 0.033261762865419896, 0.0651721553876996, 0.02674743652875934, 0.040347503897334845, 0.049394007572638135, 0.01695730597046869, 0.045968776369201284, 0.032014513720891306, 0.049202182330191135, 0.014022366359962948, 0.013935683511330612, 0.014918108071599687, 0.028122720142294253, 0.02438134590296873, 0.00858884452775653, 0.038510061600910764, 0.019553421663918664, 0.019882472132199576, 0.003558383946905711, 0.06087183114141226, 0.03675018942781857, 0.04163291724398732, 0.013330317468249371, 0.035874930143888505, 0.028101168173764433, 0.069211196154356, 0.030747481887894015, 0.02201502287893423, 0.010065417304368956, 0.019713890106816376, 0.01798321699191417, 0.028414016922137568, 0.04086862557700702, 0.0367859210819006, 0.037672783314649544, 0.11047018292759146, 0.08414363488554955, 0.061513345289443216, 0.1433225143700838, 0.08563618801001992, 0.1252735371568373, 0.12377797812223434, 0.18243833471621784, 0.11842793306069714, 0.1893509780722005, 0.10102092461394412, 0.17322666543935025, 0.06644128728657961, 0.07982252032629081, 0.21470612181084497, 0.07391105539032392, 0.21830224884407862, 0.09357196717922177, 0.12875947010304245, 0.12923918079052651, 0.1534247880003282, 0.0895540424223457, 0.1460460725107363, 0.14786826473261627, 0.16277837966169628, 0.14241819003862993, 0.09072401999895062, 0.13785520488662378, 0.09226765323962484, 0.1754113310681922, 0.12026536517909595, 0.1275415811687708, 0.07926359067537955, 0.14945450318711145, 0.10896287845181567, 0.12364278680511884, 0.08804621547460556, 0.1528320333787373, 0.12118169958037989, 0.24470494208591326, 0.09916540275194816, 0.14325118676892348, 0.12272379254656178, 0.13146951182612351, 0.1237531980233533, 0.2201935023601566, 0.11649921084088938, 0.15304438769817352, 0.07993199516619955, 0.09489690179803542, 0.19724172965756484, 0.07627500354179315, 0.10925681982189417, 0.13267488857465132, 0.12042593370590891, 0.24580373455371174, 0.152846540457436, 0.10159635623650891, 0.13819891001496995, 0.07805490946131093, 0.09963705244341067, 0.10190324405474321, 0.06561217856194292, 0.14116038967456135, 0.10052453553570168, 0.08417958367083754, 0.1274814765368189, 0.14592541541372026, 0.16529925939227852, 0.07962565696133034, 0.16728275295879158, 0.177230497023889, 0.11883703539414064, 0.11044254619628191, 0.1508621647953987, 0.18104319886437484, 0.1308927842016731, 0.12519416213035583, 0.17613787922476018, 0.21898309088179044, 0.1536850876041821, 0.11770760028489999, 0.13691983079271658, 0.06694145580487591, 0.31347134496484486, 0.0932870435395411, 0.09218952671757766, 0.14786472277981894, 0.07021422697497265, 0.163191892472761, 0.08922183167721544, 0.12205061795456068, 0.1880143183682646, 0.1947010774165392, 0.16735474552427018, 0.13888965866395406, 0.12554060854017735, 0.19124495929905347, 0.1455911419221333, 0.16465889875377926, 0.11540881863662175, 0.17393401105489048, 0.09999343939125538, 0.12719607113727502, 0.12495548065219607, 0.19330157179917606, 0.14462702508483613, 0.14776231827480452, 0.13682057469018868, 0.13286000649843896, 0.16506623689617428, 0.09254199173301458, 0.14991943538188934, 0.22093657962977886, 0.11829473663653646, 0.20592036896518298, 0.1366115587630442, 0.07557403615542821, 0.19310505448707513, 0.1414034137768405, 0.12552262736218317, 0.1843666633857148, 0.06435794050672225, 0.13082366862467357, 0.17035449455891336, 0.09430323793951954, 0.17967018325413975, 0.10110473725944757, 0.11885009040789944, 0.06505683157593012, 0.13852136342653207, 0.16675967031291553, 0.16662586320723805, 0.12325254774519376, 0.12275064896259989, 0.1609684417822531, 0.16899380114461693, 0.1166843966181789, 0.05373176320322922, 0.1897813185517277, 0.11757246325058596, 0.10193595622799226, 0.12550410335617407, 0.10583432311458246, 0.09012422218386616, 0.13621386938861438, 0.0738738648859518, 0.10968637998614993, 0.1148042982178075, 0.08163549804261752, 0.07615404110401869, 0.13554465744112218, 0.07668072677084378, 0.10428668651729822, 0.15016085814152444, 0.07751379135463919, 0.1562567896076611, 0.10697107283132416, 0.06908459509057657, 0.11065935849079064, 0.08980302406208855, 0.17402821885687964, 0.12848456842558725, 0.13463931530714035, 0.08513742405921221, 0.0973556616476604, 0.13519826531410217, 0.09692289201276642, 0.18334853516093322, 0.0858175807765552, 0.11744822348867144, 0.2793172576597759, 0.12436857500246593, 0.1303394524646657, 0.16237682263766015, 0.08113680194531168], [0.016356692217024307, 0.04265000731019037, 0.04409968041415725, 0.020229493600449393, 0.043983980015452416, 0.013278485874512365, 0.06044123281857797, 0.010139444626734724, 0.030084821196006875, 0.01748840550759009, 0.005361202721750098, 0.04054920182430318, 0.08344057082597699, 0.03589772892051509, 0.0583647188863584, 0.02104804601653346, 0.031838148898844204, 0.01844291259268565, 0.036561577048684867, 0.015452352618532521, 0.07749698404222727, 0.022712446616164277, 0.02147759939543903, 0.02261029995445694, 0.04558098003534334, 0.04318147325622184, 0.0231317558126258, 0.1036188452105437, 0.04448763281106949, 0.017326668204207505, 0.010992017092316278, 0.016524838283658028, 0.022909688264397637, 0.07190489875418798, 0.02937302439074431, 0.022656637110880444, 0.047632612088429074, 0.05503638926893473, 0.011120719070147191, 0.10619402131331818, 0.030655652351145233, 0.06223415303975344, 0.034463797828980854, 0.04867906915023923, 0.016929100966081023, 0.02102343555140708, 0.032377977788980515, 0.03219528902055962, 0.03680817024516208, 0.029150101888392652, 0.10034262029720203, 0.0046480950716483805, 0.02364797846946333, 0.031195650875036205, 0.04317651316523552, 0.011442602512293627, 0.014122246714707996, 0.04915117006748915, 0.016031399136409163, 0.007193316821940243, 0.07023651685033526, 0.0745606916025281, 0.05372692524854626, 0.08506505151412316, 0.020041188258411627, 0.060853870319468636, 0.003620751069060394, 0.02446172516127782, 0.07688380551657506, 0.001575620547685373, 0.028628379705228975, 0.03473499809790935, 0.08650143550974981, 0.0811512004584074, 0.11148740870079824, 0.1210052804755313, 0.09907691500016622, 0.23682717766080583, 0.05730902696294444, 0.13678116537630558, 0.11830680098916803, 0.01614438709137695, 0.03952045113380466, 0.08766669726797513, 0.03822517867333122, 0.026483627202521478, 0.019521006349740282, 0.020368079288995693, 0.0634077675640583, 0.044675766823015044, 0.04642499956701483, 0.07404302366610084, 0.0823335341577019, 0.005907074390311858, 0.12669026399297373, 0.03374929706166897, 0.05289826774969697, 0.04215113818645477, 0.017150333916236247, 0.047157651146075556, 0.023630158443536078, 0.044753011249537976, 0.02127490741466837, 0.06945115327835083, 0.02411413881262498, 0.06672747978674513, 0.04165128179426704, 0.051253692246973515, 0.05174050380342773, 0.010303903703710862, 0.03993235581687518, 0.02489257454206901, 0.047864494645701985, 0.04375272849574685, 0.019375457195565104, 0.046488795429468155, 0.03392638113083584, 0.060817663690873554, 0.033243561163544655, 0.028506301077348844, 0.04282576145072069, 0.022604679988164986, 0.03858471063098737, 0.019815668663276092, 0.027887095464393497, 0.045783071512622495, 0.043692613685769696, 0.03141999490825193, 0.0604003035862531, 0.02395508172256606, 0.08740523058388915, 0.03680531022005847, 0.013959736729572927, 0.008151252205217523, 0.015159515564196875, 0.026284249865316918, 0.07752137737614767, 0.04256671713665128, 0.016097210247867873, 0.06806632437344108, 0.03892318086166467, 0.017353855406067202, 0.04434641271031328, 0.039853676288787804, 0.006622332996422691, 0.012730688438750803, 0.02611543713802738, 0.07917136419564486, 0.006252605626026967, 0.01115481969567814, 0.033964569081685374, 0.039247103301542144, 0.024481100728735328, 0.0068180038360878825, 0.01601791155657598, 0.029352139082870314, 0.003299160033098555, 0.035785207458372624, 0.015721518978742615, 0.03462910931557417, 0.045881452304976325, 0.008126493310555816, 0.024006155053419725, 0.06630719519619431, 0.03296372314382877, 0.006697324262599328, 0.01681832503527403, 0.05401586920821241, 0.025081124156713486, 0.04431812458538583, 0.04453859418364508, 0.015404169846858298, 0.026649182961721505, 0.041819717934621234, 0.0275765113266451, 0.03166941759575691, 0.03796986969453948, 0.06353308619665247, 0.017121452073167478, 0.05184031291199582, 0.06546760989086968, 0.020415008467222964, 0.10175172718507902, 0.01950929992433105, 0.03823765353964908, 0.03036339035523789, 0.04819323129153677, 0.042953431207154474, 0.04807362931647471, 0.0018283857623048658, 0.02669525209681264, 0.04584214137867093, 0.07462080301983015, 0.01107986702118069, 0.02796742383257619, 0.01755178576734449, 0.0358168509389673, 0.013151984046479421, 0.03753630956634879, 0.03260339390752571, 0.012192007969133556, 0.05034974789513009, 0.01007046051589506, 0.020417873581339206, 0.01683670824526676, 0.015623753956918205, 0.09113617573997804, 0.03702358815020748, 0.028155971750883118, 0.07538386314575161, 0.023705397799078907, 0.05094789687011923, 0.03299299514453326, 0.04847578684400235, 0.007193234549569232, 0.06378001187528883, 0.02959137356707028, 0.01665723234015916, 0.03467174167079585, 0.03151913905250175, 0.027944453725857393, 0.011634915451785284, 0.010155215476905661, 0.03629454977012106, 0.0586771299796445, 0.023731277124690156, 0.02921916657526578, 0.021776239620521665, 0.029547085586403097, 0.06011375146252768, 0.01978836441412568, 0.04609837995043822, 0.016353552296225513, 0.04187257920524903, 0.00936990958039782, 0.03281249804422259, 0.01589895079710654, 0.08822256672595229, 0.03320801949926785, 0.018574280364971076, 0.02184846967325679, 0.05359487554856709, 0.006043666034072105, 0.08869943435170821, 0.05649243720940181, 0.021227409963362982, 0.043374370583998303, 0.010779869726060756, 0.051056472651128254, 0.03320553945377469, 0.041605199088475535, 0.050143527532262464, 0.05042628664523363, 0.07265215579952512, 0.07767845823296479, 0.09216471947729588, 0.07483166456222534, 0.08618794554578406, 0.052640991019351144, 0.02929136948660016, 0.007137695610124085, 0.020151100753407394, 0.04834150476381183, 0.019505104881578257, 0.026077864957707267, 0.04457014945468732, 0.05854280040200267, 0.012428747988971216, 0.024628758430480957, 0.10286409713860069, 0.05795019505811589, 0.025454696700243012, 0.07536817541612045, 0.06105884896325214, 0.049996546669197936, 0.019250788260251284, 0.09572052117437124, 0.03325258907196777, 0.01721440628170967, 0.08657455444335938, 0.03451868452663932, 0.04878619625898344, 0.03385990166238376, 0.02203784540428647, 0.07936505880206823, 0.04020351876637765, 0.02744583396374115, 0.05043789637940271, 0.06973399381552424, 0.04670264252594539, 0.05147023991282497, 0.07616748288273811, 0.07762520680470125, 0.03297336512644376, 0.04544655207012381, 0.03076232484142695, 0.05212495495964374, 0.0384225916516568, 0.03196213421012674, 0.03744073112362197, 0.04694020442132439, 0.019896604320300475, 0.0805846101471356, 0.022275261414636458, 0.0980917839333415, 0.03203205045844827, 0.04187111356960876, 0.0035408217642855433, 0.015138813460777913, 0.03326844643535359, 0.037019445693918636, 0.018665595911443233, 0.018827511330268214, 0.040454491906400235, 0.0616974521960531, 0.06107705405780247, 0.020161616349858896, 0.025467833138204048, 0.000894654359269355, 0.009485480209280337, 0.07783374097198248, 0.025089836546352932, 0.03797014450122203, 0.024221980079476322, 0.011457362345286777, 0.01706708106212318, 0.04128822484718902, 0.03404140977987221, 0.0360126422185983, 0.009354553484757031, 0.03686339281765478, 0.07630988024175167, 0.05396931492058294, 0.029464572335460355, 0.0147730644260134, 0.027863280581576482, 0.05344637476706079, 0.038625171674149375, 0.034393871402634044, 0.01630986651538738, 0.009645598358474672, 0.0477229658115123, 0.0295853888882058, 0.03221056284382939, 0.03351432377738612, 0.05296058440580964, 0.047298365738242865, 0.06958774916295495, 0.029010700261486427, 0.016938111911128675, 0.050709510554692576, 0.06754279389445271, 0.11197990298803363, 0.1257041897624731, 0.09995329047420196, 0.1461922832365547, 0.09127662570348807, 0.09118922360773597, 0.18855441867240838, 0.1388601559613432, 0.10298064909875393, 0.1696727161428758, 0.11496209832174437, 0.16390316002070904, 0.10797704849392176, 0.05835666467568704, 0.07295583414712123, 0.07153090382260935, 0.10340442135930061, 0.08348751187856708, 0.14137259471629346, 0.075797945926232, 0.11260929850063153, 0.11379919108003378, 0.1279082072100469, 0.17863039619156293, 0.10533461600009884, 0.1869154716176646, 0.08104695033814226, 0.1799787674099207, 0.11117964557238988, 0.07126333032335554, 0.1505509072116443, 0.0998891553442393, 0.06986081879585981, 0.20372757448681764, 0.1412415967455932, 0.15951727250857012, 0.15339804014989308, 0.21349409541913442, 0.07496931896145854, 0.19183586830539362, 0.15437602624297142, 0.16005486223314488, 0.17547917099935667, 0.14780362748673984, 0.05766378542674439, 0.18226241772728308, 0.10545690836650984, 0.16944879958672182, 0.13415667334837572, 0.1648262526307787, 0.13990959179188522, 0.1397463091249977, 0.09276049357971974, 0.11279425357601472, 0.12855656099106583, 0.12938236525016172, 0.11881032825580665, 0.0956125051847526, 0.07078511241291251, 0.10017960225897175, 0.12264874657349926, 0.13977896023009503, 0.21153825893998146, 0.13208478023963316, 0.17024694675845758, 0.25075049911226543, 0.0908250810046281, 0.12094873136707715, 0.1570342414613281, 0.10671641185347523, 0.15915139285581453, 0.29459398505943163, 0.21801526924329145, 0.17484798415430955, 0.24255127193672316, 0.24335837577070507, 0.18083262230668748, 0.2685554479914052, 0.1584862656891346, 0.20290411795888627, 0.2286848117198263, 0.1683855487832001, 0.20596777142158576, 0.11744084102766854, 0.08600645778434617, 0.11370412153857094, 0.09293885329472167, 0.15934740805200168, 0.1461120939680508, 0.20000613560634, 0.1135596139356494, 0.19909350600625786, 0.17523523766015256, 0.27049391397408074, 0.27243655973247116, 0.14237791219992296, 0.21223514154553413, 0.16505650670400687, 0.1323728183550494, 0.13171714996652945, 0.183920146631343, 0.09745481596993548, 0.16877525858581066, 0.16176044142671994, 0.13103252170341356, 0.12462647259235382, 0.11835866820599351, 0.1971726683633668, 0.19354972562619618, 0.10316609271935054, 0.10747543469603572, 0.15626320854893752, 0.17593507867838654, 0.1413529036300523, 0.14771191669361933, 0.23135699118886674, 0.15559301951101848, 0.1372829827346972, 0.09757281320967845, 0.14206712959068163, 0.1491620410233736, 0.11092119836913687, 0.1718158825699772, 0.09859314667327063, 0.0975260960736445, 0.06689292019499199, 0.1715829414980752, 0.18030671695513384, 0.16093969903886318, 0.09286618219422442, 0.19285403724227632, 0.08193993634943451, 0.2612997373299939, 0.13671529319669518, 0.08656059697802578, 0.07638157425182206, 0.17122586922986166, 0.20745385810732841, 0.15378130386982644, 0.17238997747855528, 0.09407652581908874, 0.07633167478655066, 0.15807652553277357, 0.08803532498755626, 0.15806908878896916, 0.08932384263191905, 0.11366580466606788, 0.13371285716337816, 0.06660809833556414, 0.10924843991441385, 0.09488937005932842, 0.12455433074917112, 0.14437067455479077, 0.16845842344420298, 0.13920092981840881, 0.134444494332586, 0.2276367058179208, 0.10378450274999652, 0.07464832440018654, 0.09239204227924347, 0.24556795720543179, 0.09172394312918186, 0.05927018994199378, 0.09621482715010643, 0.09615996080849852, 0.08574224303343467, 0.1059245275599616, 0.16021617714847836, 0.12297277418630463, 0.13980403888438428, 0.10526896095169441, 0.17360541011605943, 0.10084886848926544, 0.11443345168871538, 0.11943771530474935, 0.12087185334946428], [0.07220308096813303, 0.027516980056783984, 0.010876235269409205, 0.01613741853673543, 0.002616064198913851, 0.012512242571184677, 0.04449989054618137, 0.04195450891607574, 0.009153526459288384, 0.023192689953637973, 0.08266695269516536, 0.012240663170814514, 0.019475128900791918, 0.04522061687228935, 0.04716835842866983, 0.06766016688197851, 0.04922525591350027, 0.039451413588332276, 0.014108410537508982, 0.004091519937251827, 0.041201470752379725, 0.07399313777152981, 0.047121600580534766, 0.03083124364327107, 0.03534874998565231, 0.025408520695886443, 0.023800258691023504, 0.04790984792634845, 0.043082780337759426, 0.022594825963356664, 0.020352254156023264, 0.06257923559418746, 0.02961929528308766, 0.025045916670933366, 0.02480220385561032, 0.07384134948785816, 0.05575532426259347, 0.030688500231398002, 0.05352858606992023, 0.017375096944825988, 0.05233245775369661, 0.05544139664354069, 0.01614263647102884, 0.05105504772758909, 0.09200192535562174, 0.013184770858580512, 0.03848586164947067, 0.03409066802955099, 0.022831166495702097, 0.02318905639861311, 0.029181531630456448, 0.012039756585311676, 0.03834788155342851, 0.07188544515520334, 0.05944245641252824, 0.021801740662860017, 0.01800977824521916, 0.11936005018651485, 0.03447524471474545, 0.05972456413188151, 0.0440209907080446, 0.038983611190425496, 0.03639077960646578, 0.05665536703807967, 0.057463549742741246, 0.0357494283068393, 0.0264355224623744, 0.13751741658364022, 0.09718942056809153, 0.07719674586717572, 0.01972194092481264, 0.11675182942833219, 0.14931728983564035, 0.16110070182808808, 0.020261632411607673, 0.17191485368779727, 0.0952463201912386, 0.12060639687946864, 0.07197301688471011, 0.10295619469668184, 0.08029932009854487, 0.16237317211925983, 0.1230242478528193, 0.012305414071306586, 0.02836832607031933, 0.019313922551061426, 0.10591416633022682, 0.08538004104048014, 0.06629271525889635, 0.03076771580215011, 0.028471237780260186, 0.051374244171061685, 0.1522757296583482, 0.08353724171008382, 0.2525918260216713, 0.054554344420986514, 0.05529393402061292, 0.024686355875538926, 0.050326019525527954, 0.07944713439792395, 0.12185171219919409, 0.07809627974139792, 0.06477849651128054, 0.010222024034841784, 0.05930795041578157, 0.03046382710869823, 0.056962071651858945, 0.09137556967990738, 0.008995739077883107, 0.025456788284437995, 0.019521513554666723, 0.04542141913303307, 0.011988352468636419, 0.015359098158244575, 0.025122387567535043, 0.005388573552149215, 0.03645641429881964, 0.03123454450230513, 0.0018858432595152408, 0.04302073170297912, 0.017097730488915528, 0.030216443418924297, 0.06755626959992306, 0.0444858720126961, 0.04577851854264736, 0.024664685163380842, 0.022914022406829253, 0.026744931038202982, 0.02262453731548573, 0.025730941877035157, 0.04346848678375993, 0.021888520202732513, 0.025764607391985397, 0.02047611054565225, 0.020644370266901593, 0.020045878631728034, 0.03689791667940361, 0.021600568600531136, 0.045962384569325616, 0.02900204893999866, 0.05208605115434953, 0.028586351246173893, 0.05694827024957963, 0.02137121358620269, 0.009991567249276807, 0.05569016793742776, 0.04067555183012571, 0.09789773648870842, 0.03830704053065606, 0.03477206985865321, 0.014349597506225109, 0.0223687448804932, 0.030306783571307148, 0.01681362448393234, 0.013687133589493377, 0.021762302511238625, 0.030971500224300792, 0.04775670596531459, 0.040414047826613696, 0.030381025480372564, 0.04117739972259317, 0.03159176944089787, 0.03966201389474528, 0.02430834571298744, 0.009996582471233393, 0.02781858547989811, 0.0186282120245908, 0.028316026287419454, 0.056879867134349685, 0.030536002878631865, 0.02631621734638299, 0.012093970685132911, 0.013005007424258759, 0.03482877163748656, 0.01279509752722723, 0.030700503515877893, 0.0909668066139732, 0.011160943474221443, 0.03352581476792693, 0.0018198650588081883, 0.01115532435609826, 0.06544555071741343, 0.030475216318986247, 0.02897605426343424, 0.06416459195315838, 0.025739455795181648, 0.13906035093324526, 0.051919290995491404, 0.029608408188713447, 0.027972058226753558, 0.011422958075334983, 0.020789419001500522, 0.0020240054998014656, 0.010497412561172885, 0.014248662029526063, 0.04350270191207528, 0.020435021857597997, 0.07089034640895468, 0.04614155174099973, 0.012721269524523189, 0.035651844793132374, 0.05018237366208008, 0.03901735473690288, 0.036960704917354245, 0.057994055561721325, 0.06721574680081435, 0.014193539540948612, 0.004467765060586056, 0.026076803050403084, 0.022956741275265813, 0.029142366589180062, 0.013908710048001791, 0.03677450133753674, 0.028354869024561982, 0.023812577494287064, 0.019621073301615458, 0.04124974173360637, 0.06248319574764796, 0.024915754994643585, 0.009766544681042433, 0.11515586078166962, 0.03383822925388813, 0.04034515277349523, 0.056501563505402634, 0.03398897259363106, 0.04800523977194514, 0.005267949533715312, 0.014588014355727603, 0.041716750245541334, 0.03160157087924225, 0.04471685890374439, 0.05414735911680119, 0.06281152527247157, 0.046003673425210376, 0.01831570084738944, 0.018316136806138923, 0.015270820752318417, 0.025065550081697956, 0.039725534950516055, 0.1257849218589919, 0.04674656070502741, 0.023574505001306534, 0.03385520280737962, 0.10237967063273702, 0.11000863662255661, 0.10311377766941275, 0.05211614418242659, 0.04178184550255537, 0.020017967093735933, 0.1015005742332765, 0.02379476255737245, 0.10370555520057678, 0.04518533983666982, 0.15552660450339317, 0.09756169880607299, 0.12253563478589058, 0.07252191778804574, 0.11445089003869466, 0.11835296851183687, 0.029861600138247013, 0.11697062983044557, 0.07798763271421194, 0.06988682025777442, 0.08600830339959689, 0.07678424407328878, 0.07723647409251758, 0.045524810906499624, 0.012317483512950795, 0.004748944883301322, 0.09207512571343354, 0.054102019406855106, 0.01935041755703943, 0.0524077683554164, 0.054481534220810444, 0.07457679323852062, 0.09106509241142444, 0.06964858661272696, 0.028477945098919526, 0.029475808875369172, 0.030891450055475746, 0.026899263828194568, 0.0459571191375809, 0.02459804623919938, 0.03229893185198307, 0.04068630661017128, 0.026569762134126255, 0.035340458287724426, 0.05528433953544923, 0.029603695763008933, 0.03801877510600856, 0.014092962839640677, 0.052179997720356495, 0.044675437733531, 0.07678371481597424, 0.050333703934614143, 0.027327354964134947, 0.022410062574116246, 0.00948821724991181, 0.06654888936983687, 0.024081555561029484, 0.049539838318846056, 0.01378596730397216, 0.035007239918091466, 0.03178793730746422, 0.005566374323929527, 0.03259965178689786, 0.05063814563410623, 0.022421584098732898, 0.02703180885873735, 0.02946924404906375, 0.02224209123024983, 0.03302281675860286, 0.03750937511878354, 0.09313556059662785, 0.06224725555096354, 0.03187490514080439, 0.02953327400609851, 0.025746733083256652, 0.04845111870339938, 0.04634956343631659, 0.05247731480215277, 0.021346128146563257, 0.03601681860163808, 0.02927477591271911, 0.021412845102271864, 0.06468329804816417, 0.04739078899313297, 0.014707351702132394, 0.05383611849642225, 0.030029493450586284, 0.030104824408356632, 0.019583960828770484, 0.009583172288590243, 0.02753974829933473, 0.03750413343576448, 0.08467281077589307, 0.02537191373163036, 0.030045737578932728, 0.05030872366790261, 0.05912411492317915, 0.007758299853386623, 0.020658743334934115, 0.09181576927325555, 0.0557878430533622, 0.048504648331020556, 0.012594147685116954, 0.026891396214653338, 0.051268005943191905, 0.08289795315691403, 0.026807232427277734, 0.014102232476164187, 0.02257806614839605, 0.15702622117740767, 0.13154073086168083, 0.08609987848571368, 0.07135089526751212, 0.1103713610874755, 0.15112405217119626, 0.20580533013812133, 0.16007041425577231, 0.13121640469346726, 0.11285251937806606, 0.1991918935839619, 0.1319684386253357, 0.07869190456611769, 0.154111668999706, 0.06734311460916485, 0.08288862330040761, 0.13302573189139366, 0.18583908437618188, 0.10138742851891688, 0.11794301122426987, 0.11505021287926606, 0.19519156324011938, 0.14989502169191837, 0.09383165610155889, 0.08490638967071261, 0.1696469182414668, 0.11678400555891649, 0.1342114989778825, 0.11440222550715719, 0.15325104232345307, 0.14003746850149973, 0.11589650889592511, 0.09045462802584682, 0.09978371100234133, 0.10140194916831595, 0.1248330729348319, 0.12517266614096506, 0.09065984415688685, 0.19475890217082842, 0.11846426182559558, 0.22328688922737325, 0.12801598571240902, 0.1499109129820551, 0.11303075695676462, 0.2306868971458503, 0.18527273833751678, 0.14526083107505525, 0.11554683265941483, 0.08538660247411047, 0.11310996913484164, 0.09727825437273298, 0.1467196135116475, 0.15498708773936543, 0.08085765942398991, 0.11950156545000416, 0.09752372798642941, 0.11095378162073237, 0.1288675335901124, 0.11778869879032884, 0.12656765271510395, 0.13990381067352636, 0.15031578125698225, 0.1363573931157589, 0.20782319828867912, 0.18877410117004598, 0.09371705153690917, 0.12397317907639913, 0.18434704015297548, 0.35377274240766254, 0.19760182819196156, 0.19347941582756384, 0.2349411760057722, 0.1611952217561858, 0.19121610799006053, 0.12531384213694505, 0.3445610324186938, 0.14965841653091566, 0.22559112629720143, 0.1879934873431921, 0.19447200399424347, 0.1312895914805787, 0.23183432700378553, 0.21539623263691152, 0.10445327364972659, 0.3826788498886994, 0.24070869652288301, 0.2720243089965412, 0.20591130373733385, 0.20499754776912077, 0.1431309910757201, 0.16132227065307753, 0.08972447006297962, 0.2946124140705381, 0.17005388997495174, 0.3538905903697014, 0.19713688242648328, 0.11705351966832366, 0.12122504439737115, 0.13109709109578813, 0.21817279793322086, 0.1997886515621628, 0.1710553533796753, 0.31652315120611874, 0.0779165697417089, 0.14291493195508206, 0.15891598191644463, 0.15163095854222775, 0.18207261791186674, 0.125365763636572, 0.07765848216201578, 0.1421853168202298, 0.1644001462097679, 0.09950059226581029, 0.08309333053018365, 0.14861017492200645, 0.089326570342694, 0.1447457687130996, 0.15204037300177983, 0.10032701399177313, 0.11655438930860587, 0.18476682262761251, 0.11554255788879735, 0.13586227968335152, 0.13553367874452046, 0.15965129674545356, 0.12395734206906386, 0.20358559781951563, 0.11658351203160626, 0.09606475556003195, 0.16598056283380302, 0.1472638121673039, 0.11001542875809328, 0.19415989145636559, 0.1397722563041108, 0.1258165551615613, 0.10643359845770256, 0.1656145067619426, 0.15938011343990052, 0.1394258098942893, 0.10325518436729908, 0.12599765615803854, 0.10248873156628438, 0.15113535656460694, 0.06629224706973348, 0.17180746873574598, 0.17323389862264904, 0.10101999502096858, 0.19530851553593362, 0.13470061416072504, 0.1289494191961629, 0.16160649540168898, 0.165372229048184, 0.12899980720664772, 0.11459914994026933, 0.06758415060383932, 0.07861782889813185, 0.0839006786367723, 0.1100964458393199, 0.10827958011733634, 0.15852700493165425, 0.16533465177885123, 0.10153635338480983, 0.14754403355930532, 0.15974280397806848, 0.10419765593750135, 0.06719415581652097, 0.19103755828525337, 0.11442947547350611, 0.12188688745456082, 0.0742803073621222, 0.09761267714202404, 0.1219373026064464, 0.09810793306678534, 0.1210225559771061, 0.0755140468744295, 0.11373569377298866], [0.018882313211049353, 0.062440475182873864, 0.018550267010661106, 0.025805271995653, 0.01393190661578306, 0.004916303425229022, 0.04707893769123724, 0.016624549004648412, 0.059853736843381605, 0.03479239876781191, 0.021568894585860626, 0.014730681432411075, 0.006958205286147339, 0.05257374480632799, 0.033899304190916676, 0.042326033980186493, 0.06453581846186093, 0.044881291687488556, 0.02830318670852908, 0.024601924066830958, 0.020977878710255027, 0.02871654854555215, 0.024944697905864035, 0.02193810584555779, 0.08566615211644343, 0.07337084652057715, 0.007076271651645324, 0.040634646346526485, 0.054796930868178606, 0.013204691798559256, 0.04133304547784584, 0.024495278717949986, 0.03021790226921439, 0.04636995341362698, 0.030632677155413797, 0.060568464919924736, 0.04908480255731514, 0.0071456047839352065, 0.04728733275883964, 0.014219442615285516, 0.06446890133832182, 0.0498440459237567, 0.06538032314607076, 0.027603980120537535, 0.0505091357710106, 0.0135836281614112, 0.06633225349443299, 0.01568486282069768, 0.0873791409124221, 0.03244110529444047, 0.05658615307350244, 0.029707033253673996, 0.03428219810926488, 0.04640368678207908, 0.0105788969833936, 0.031447299157402346, 0.03271016139271004, 0.04615686288369553, 0.02918226784095168, 0.04979506926611066, 0.09405253960617951, 0.0791150593597974, 0.08594308939895459, 0.008361357181066913, 0.03848021623811551, 0.07729224967105047, 0.03785972649763737, 0.23089252039790154, 0.1968495092753853, 0.11326850884194885, 0.031212230878216878, 0.33835976517626215, 0.19895959033497743, 0.02973287525985922, 0.26787653299314634, 0.5575972252658435, 0.28486981828297886, 0.16850463167897292, 0.027664456250412122, 0.056901475082018545, 0.08395154840712037, 0.09087119424449545, 0.008408757092963372, 0.3048840771828379, 1.504400834441185, 1.4242281764745712, 1.5916932246514728, 2.354893671614783, 5.21646865776607, 3.2060060926846097, 0.18129707952695234, 0.026946678158960173, 0.25188243123037474, 0.3747213440282004, 0.5931569657155445, 0.21763146269534314, 0.3708825728722981, 0.1597296403987067, 0.037750611281288524, 0.03580232350421803, 0.13626984852765286, 0.16133808051901205, 0.08274845153625522, 0.0580432154238224, 0.06714256001370293, 0.03112932068428823, 0.05560473020055464, 0.040710150330726586, 0.05739437309759004, 0.03416534759370344, 0.03375640471598931, 0.029880039327378784, 0.045717124694160054, 0.019044084441182867, 0.03163326864263841, 0.04477918573788234, 0.013519035020310963, 0.05580385987247739, 0.004068431086904768, 0.029073298509631838, 0.05414444820157119, 0.06829344361488308, 0.039669932398412905, 0.0226222438671227, 0.008894597496172147, 0.012799826916307211, 0.030616643372923136, 0.06640381179749966, 0.02904637424009187, 0.023170182947069407, 0.04009084802653108, 0.046370265539735556, 0.0536811207421124, 0.04821680359808462, 0.07344965836299316, 0.07099349730248962, 0.029675997061921016, 0.03970062932265656, 0.052256458438932896, 0.017343509443370358, 0.08325511363468, 0.03472557324650032, 0.036573169819478474, 0.04974105448595115, 0.12794750795832702, 0.005131363827136478, 0.012130670947954059, 0.059045065593506606, 0.03087861556559801, 0.013052521838939615, 0.06512483435549907, 0.026902247685939074, 0.038999064825475216, 0.05846234650484153, 0.08654864119099719, 0.06320352852344513, 0.026075686860297407, 0.03724011546000838, 0.04110212644029941, 0.024122535683480755, 0.06816645578614303, 0.019408724071191888, 0.049088083274130306, 0.03261570253276399, 0.03714404847206814, 0.03768467124817627, 0.051499494950154, 0.028562032551105534, 0.035858916717448404, 0.009192430264582592, 0.0012531940654818235, 0.06303400333438601, 0.10209416345294033, 0.09216428521488394, 0.07444583597992148, 0.03684532003743308, 0.05849888561559575, 0.012893682728255433, 0.039289141938622506, 0.03734694740601948, 0.016414279484057, 0.04657983108024512, 0.008267786353826523, 0.05341975583827921, 0.00998147828171828, 0.04744940084804382, 0.021461321340341653, 0.06077836972794362, 0.043385525699704885, 0.0220992545198117, 0.031072808895260096, 0.006700653325034571, 0.049146430500383885, 0.04380307240145547, 0.04011144834969725, 0.02113315975293517, 0.018449845524238687, 0.02502452246179538, 0.05803194495716265, 0.012305540448453809, 0.0682377562459026, 0.031770658413214345, 0.03145586566201278, 0.03316644226600017, 0.025808998849242926, 0.013121896107415003, 0.014324189762451818, 0.035265195183455944, 0.03186775677438293, 0.03438011071245585, 0.029209022476736988, 0.11589701101183891, 0.020419817584167634, 0.0283968550751784, 0.10379664174148015, 0.04518079025936978, 0.04152056880827461, 0.02940706309995481, 0.07016601706189768, 0.023340032136599933, 0.07821464339005095, 0.030787702051124403, 0.09185298691902842, 0.025813826625900607, 0.04495030887691038, 0.048041239447359524, 0.06456293950655631, 0.03412133441971881, 0.035268357156642845, 0.06665195883916956, 0.012076567958242126, 0.03546257423503058, 0.042787515824394565, 0.02815760362760297, 0.024318165811044828, 0.060636521982295175, 0.05156564532912203, 0.06986814697406121, 0.029694941759641682, 0.026498349716088603, 0.044182543110634596, 0.037444761621632745, 0.017811583255284598, 0.1599211636930704, 0.12294047591941697, 0.0865521017195923, 0.02073317184112966, 0.13846994404281887, 0.07156856251614434, 0.023543864056201916, 0.07196517980524472, 0.2053890081920794, 0.1949413466666426, 0.16778535741780484, 0.0760752156909023, 0.08911294037742273, 0.09016795376581804, 0.07141339512807982, 0.07814017417175428, 0.40839239582419395, 1.5604929902723856, 0.9303520662443978, 0.9934293329715729, 1.55883323933397, 4.157092452049255, 2.356969880206244, 0.23212501140577452, 0.09065141675195523, 0.06874127672719103, 0.33107208194477217, 0.3813484598483358, 0.09444215441388742, 0.26592449631009785, 0.12966121600142547, 0.07013175104345594, 0.02797734401454883, 0.09650086358721767, 0.18501771773610795, 0.07488656483058419, 0.041331115045717785, 0.05830194761178323, 0.05412780713023884, 0.06472755888743059, 0.024452612435977374, 0.07200480625033379, 0.017525177016588192, 0.005422373077765639, 0.01929383452183434, 0.017425847971545796, 0.03302864876708814, 0.018252347729035785, 0.12853050524634974, 0.052742387899862866, 0.0317649044362562, 0.007166738605259785, 0.04838316002860665, 0.030110456249011413, 0.028898338255073344, 0.03663234146577971, 0.06021077518484422, 0.003777662292122841, 0.013801402279308863, 0.05947205411004169, 0.057811957118766646, 0.06989498303404876, 0.044181511737406254, 0.014745595632120967, 0.01876337789664311, 0.024493205793468014, 0.027051281117435013, 0.0552644245326519, 0.0109256996240999, 0.0066645298169792765, 0.018875268321218233, 0.024781211678470885, 0.04199583848406162, 0.03980066913313099, 0.05098050387044038, 0.042988867698503394, 0.08785373544586556, 0.06404267956635781, 0.05518292908423713, 0.012126549695884543, 0.02066935901530087, 0.02385712501459888, 0.02055283758922347, 0.018637173775849596, 0.03324090809162174, 0.0186234164783465, 0.0891743138698595, 0.04375482516895447, 0.023452735106859888, 0.03684186629418816, 0.03514705884403416, 0.07323961784797055, 0.022075687302276492, 0.051828106067010334, 0.06380524659263236, 0.04216705661799226, 0.013308701887061554, 0.04532087042129465, 0.01949916939650263, 0.05958783932562385, 0.05506791061322604, 0.005870295247794794, 0.031012870504387786, 0.02047402913948255, 0.04250831562759621, 0.04637704071189676, 0.03581254563427397, 0.025635592439877133, 0.056395864712872674, 0.08333027495869569, 0.06206320971250534, 0.19389113730617932, 0.08477759693882295, 0.15705644312713826, 0.09858963186187403, 0.0694964454908456, 0.13464573424841675, 0.12709099320428713, 0.11166259287191288, 0.12114925203578812, 0.1549560244062117, 0.14625325639333042, 0.186153680352228, 0.0963664050879223, 0.09525693247893027, 0.164341751486063, 0.18350094769682201, 0.11416644815887723, 0.13067493374858583, 0.08196008883948837, 0.07660291916025536, 0.12981163364435944, 0.12409133916454655, 0.10867493533130203, 0.1667429240686553, 0.11723571989153113, 0.1491468282682555, 0.17342838032969407, 0.08112701747034277, 0.091430788859725, 0.12895757518708706, 0.05455938254349998, 0.13066825696400233, 0.10109887471688644, 0.1906153873673507, 0.18262732028961182, 0.1346236682896103, 0.2005930141146694, 0.14234655031136104, 0.1872782300093344, 0.18316207373780863, 0.17510418540665082, 0.08500713855028152, 0.2740368981446539, 0.13084382111472742, 0.17812723533383437, 0.14047430934650557, 0.17496961834175245, 0.15822015782552107, 0.11134999178882156, 0.1432514310415302, 0.10333875274019581, 0.14046512198235306, 0.17845753261021205, 0.12847101129591465, 0.18747415021061897, 0.15530937830252306, 0.1341027162436928, 0.1568405604256051, 0.19303262765918458, 0.13176474241273745, 0.1151529566517898, 0.1599075115684952, 0.10388826432504825, 0.23311523827058928, 0.15554500637309893, 0.39077366409557207, 0.25871050198163303, 0.17870443793279783, 0.17228564593408788, 0.5670133914266313, 0.4526477525276797, 0.06313116954905645, 0.29208552251969067, 0.5818680429032871, 0.310457672391619, 0.20202778998230184, 0.12912786033536705, 0.1314498885933842, 0.09623177016952209, 0.22863280879599707, 0.20043065425540718, 1.5767873844930103, 4.135349367346082, 3.3175995903355733, 3.264157520873206, 4.76673651593072, 8.955778087888445, 5.912424113069262, 1.095068776181766, 0.17848756457013742, 0.3084861481828349, 0.5184632880347115, 0.6258774985160146, 0.3320198325174195, 0.7230883879320962, 0.32754980666296823, 0.16996496117540769, 0.09929462974624974, 0.18435317410954408, 0.28036228301269667, 0.20971792590405258, 0.10255673434585333, 0.16039571751441273, 0.15008290803858212, 0.23128856771758624, 0.11835247996662344, 0.22604961240930216, 0.217251591650503, 0.06451181867825133, 0.18566419876047544, 0.08553968675966774, 0.11561440117657185, 0.1151477862149477, 0.17863834862198147, 0.09767308711473431, 0.15614048870546476, 0.10577186396611588, 0.1628010155899184, 0.14423302694090775, 0.13667781092226505, 0.17093594478709356, 0.10035099341933217, 0.07866211009344884, 0.08790767897984811, 0.1655578762292862, 0.23471400248152868, 0.13168527239135333, 0.10442842569734369, 0.09616158929254327, 0.11198539912168469, 0.11581376833575112, 0.10942898451217584, 0.2062176080154521, 0.11999796809894697, 0.1989951048578535, 0.14775808421628817, 0.14623146184853145, 0.10812847036868334, 0.13695286187742436, 0.18413942200796946, 0.181353574352605, 0.12052437556641442, 0.23805464750954083, 0.12116835958191327, 0.15286795502262457, 0.11091645540935652, 0.10381774418056011, 0.07802000561995165, 0.19129001402429172, 0.08841331649039473, 0.13714334022785934, 0.17667435615190438, 0.2252961399831942, 0.19758793179477963, 0.11149988695979118, 0.16081130664263452, 0.29307754071695463, 0.12650135984378202, 0.1538346502929926, 0.24433619901537895, 0.21511724617864403, 0.09322039104465928, 0.13405437740896428, 0.09283513921712126, 0.17974263722343103, 0.0903121153158801, 0.09930064835186515, 0.1422019816402878, 0.09286426194012165, 0.17551387128021034, 0.20204338271703037, 0.1550680233963898, 0.200782569657479, 0.16090170107781887], [0.057043339791042466, 0.016655323960419213, 0.023771426041743586, 0.03533447360885995, 0.02586347672955266, 0.10363517754844256, 0.07724391083632197, 0.05433056017916117, 0.05509577465376683, 0.04581421287730336, 0.05760955012270382, 0.07078289360340152, 0.09395611299467937, 0.10336666767086301, 0.12021603568324021, 0.13461347669363022, 0.0738122606916087, 0.057953268821750364, 0.1680989491620234, 0.13734745713216917, 0.20198240956025465, 0.08637955026435, 0.11028663241969687, 0.0529432817628341, 0.08315614930221013, 0.04431946808472276, 0.08978397758411509, 0.07761343422212771, 0.029119788336434534, 0.08059834369591304, 0.08418659972293036, 0.07691463814782244, 0.09966083509581429, 0.07947534788399935, 0.13324772140809468, 0.09798692991690976, 0.0899101918829339, 0.060181849236999235, 0.06615587510168552, 0.13811962998339108, 0.06623037824673311, 0.08470697501408202, 0.0806169898382255, 0.09866783980812345, 0.135697870648333, 0.049151611115251265, 0.09617833553680352, 0.1445204679455076, 0.14375166062797817, 0.06994469250951495, 0.15943807390119347, 0.06311282874750239, 0.1250998864748648, 0.031112825497984886, 0.08188241693590369, 0.11035205676619496, 0.04995047414143171, 0.06977581871407372, 0.09095138351299933, 0.11388976871967316, 0.1108277573117188, 0.30958857759833336, 0.07464279433978455, 0.12447350365774972, 0.10732544453016349, 0.07250258632536445, 0.08789459682468857, 0.31300489285162514, 0.08328958321362734, 0.2345704244715827, 1.5791777819395065, 8.460830977984838, 10.94906861441476, 8.520295398575918, 7.849782075200762, 18.422804628099712, 34.27821166174752, 48.81690032141549, 59.40850843702044, 51.50230264663696, 50.161856174468994, 38.05185127258301, 57.579471588134766, 83.7504938670567, 85.1402656010219, 94.5266843523298, 87.59484182085309, 90.89265836988176, 106.61417361668178, 106.11531380244664, 70.71408912113735, 46.68649925504412, 28.006500107901438, 30.549606800079346, 27.75954028538295, 14.021271075521197, 15.816490173339844, 12.586664353098188, 2.6151497406618933, 0.3494055010378361, 0.027571413832317506, 0.05281844149742808, 0.1304625522877489, 0.02978885100622262, 0.15236478059419564, 0.4410397282668522, 0.326193632291896, 0.17141889887196676, 0.09903247095644474, 0.1378754252301795, 0.14837446542722837, 0.24115606823137828, 0.10681017182235207, 0.15022035209195955, 0.03531936263399465, 0.15822247841528483, 0.03824366196723921, 0.11602631264499255, 0.0536748409005148, 0.16939708164760045, 0.09813132895422833, 0.10528802100036826, 0.10877569099622113, 0.12906760642571108, 0.05656180723703333, 0.12005701421626977, 0.124613526144198, 0.10481474961021117, 0.09542499203234911, 0.044410476594098976, 0.04970668329458151, 0.14309235529175826, 0.04352709863867078, 0.010905712526956839, 0.07518009229430131, 0.08553435347442116, 0.052588122963373146, 0.14251190929540566, 0.07108184256191764, 0.06232686806470156, 0.0548411102832428, 0.0691050732774394, 0.11933673572327409, 0.1327575748520238, 0.037009868172130415, 0.09663357146616493, 0.08573049080691167, 0.04312755007828985, 0.05032747498314295, 0.16686146413641317, 0.06560026348701545, 0.11719114014080592, 0.07097102422267199, 0.12625359956707272, 0.07843524869531393, 0.06031118479690381, 0.08131964677678687, 0.04054160223209432, 0.08341154309787921, 0.04852269057716642, 0.03675960410120232, 0.1290530450642109, 0.09067055143948112, 0.054407696040081124, 0.08195417879947595, 0.0755797629909856, 0.08607277101171867, 0.06933824505124773, 0.07661821333957569, 0.04103874787688255, 0.09229311865887471, 0.07188648331378188, 0.04236770960103188, 0.06661115852849823, 0.033516260994864364, 0.06266353678490434, 0.06193734146654606, 0.033181244507431984, 0.03986721984776003, 0.025607920085479106, 0.008896438870579004, 0.041002290190330574, 0.06362905818969011, 0.1019481291462268, 0.13921994236963137, 0.024169337636392032, 0.11350839811244182, 0.03655402156125222, 0.061977700729455264, 0.07857107104999678, 0.14108279240982874, 0.17046094313263893, 0.194237298731293, 0.07492995035967656, 0.1339631551610572, 0.18680998656366551, 0.1568831317126751, 0.1831482859062297, 0.03543468305308904, 0.08262433391064405, 0.045577156490513256, 0.08145280248884644, 0.11552399317068712, 0.11635796699140753, 0.07227385217057807, 0.053675580503685136, 0.029977175007973398, 0.028760144420500313, 0.0456325588747859, 0.06343451541449342, 0.12380704656243324, 0.12284563029451029, 0.028772751601146798, 0.08929084547396217, 0.08819727772580725, 0.07609893727515425, 0.08777781416262899, 0.08476203134549515, 0.05232492940766471, 0.11909528582223824, 0.1203374255980764, 0.0885319651237556, 0.13123823995036737, 0.17656384993876728, 0.09222886817795889, 0.09190586515303169, 0.07902988964425665, 0.034207579613264115, 0.14607428599681171, 0.06330474559217691, 0.14945478817181929, 0.09990457844521318, 0.06288866113339152, 0.03985655327726688, 0.15028013102710247, 0.11588791864258902, 0.041464589669236114, 0.2897470194314207, 0.2622731365263462, 0.16185136511921883, 0.22130701903785976, 0.14197408886892454, 0.17301479966512748, 0.3349913816366877, 0.17537597939372063, 0.16063563392630645, 0.8745219877787999, 6.344410989965711, 8.832419770104543, 6.615568782602038, 6.277082945619311, 16.31835334641593, 33.44529982975551, 48.38543455941336, 59.86230223519461, 54.518248149326865, 50.07456942967006, 39.26045915058681, 58.529908725193565, 87.04071603502545, 96.97787679944719, 101.45307949611119, 95.65358488900321, 100.41160011291504, 115.89095674242292, 112.11799458095005, 72.92545754568917, 46.56732027871268, 25.09787474359785, 29.28283555167062, 26.520238740103586, 13.217179502759661, 14.812762090138026, 11.831519365310669, 1.8315864035061427, 0.2408318913408688, 0.07181083344455276, 0.023583015526777933, 0.1423884430634124, 0.045447345956095626, 0.2159052017543997, 0.42650816802467617, 0.39863753212349756, 0.2561387728367533, 0.15178490456725868, 0.16119089270276682, 0.11927650895501886, 0.21379805196608814, 0.051903667726687024, 0.09978723259908812, 0.03707960121599691, 0.08171644727034227, 0.04761019668408802, 0.13039465807378292, 0.0806697527212756, 0.12833370294954094, 0.04716353065201214, 0.05193732984896217, 0.09587403293699026, 0.08342166005500726, 0.033016472456178496, 0.13279473142964499, 0.12302940471896104, 0.0716253151851041, 0.07233540886746985, 0.11538382140653473, 0.04879057959520391, 0.07014125053371702, 0.07265795727393456, 0.03373831157971706, 0.10783541109412909, 0.014552676251956394, 0.08494723069348506, 0.09818352865321295, 0.128591532685927, 0.11972939036786556, 0.13240892998874187, 0.1597642321139574, 0.07895382586866617, 0.0968987090247018, 0.07990251960498945, 0.13665482215583324, 0.1463867649435997, 0.08489536347665957, 0.10029857658914157, 0.07657739267285381, 0.09570694368864809, 0.11836485644536358, 0.051361521639462025, 0.21892735601535865, 0.12108593114784785, 0.15995541614081177, 0.054449174885771105, 0.049462400509842804, 0.106223632581532, 0.047293816160942824, 0.07423988703106131, 0.07722339193735804, 0.0638280725106597, 0.05290110741875001, 0.052667348712150536, 0.044495089910924435, 0.08562998619994946, 0.09454001273427691, 0.09675796050578356, 0.08553260285407305, 0.08080732569630657, 0.041813896104161224, 0.10713569221219846, 0.12249318563512393, 0.11398044813956533, 0.0641879267724497, 0.18301124897386345, 0.12838577372687204, 0.0917235224374703, 0.07846141300563302, 0.11963075851755482, 0.28136781762753216, 0.23780209677559988, 0.18229935717369827, 0.22428078018128872, 0.16782578453421593, 0.18248588645032474, 0.1216070189007691, 0.2553493651960577, 0.2890725013400827, 0.17017622983881406, 0.2901396197932107, 0.24929512292146683, 0.14963373142693723, 0.30849298781582285, 0.2895944304764271, 0.47645670494862963, 0.300688668021134, 0.17906480788120202, 0.20487381012312003, 0.22031977772712708, 0.27819387508290155, 0.1471664695335286, 0.20146597655756132, 0.13767083335135663, 0.1244260740599462, 0.1667962704918214, 0.17458972015551158, 0.1852017907159669, 0.23506860488227435, 0.20401303416916303, 0.33991863152810503, 0.21911144256591797, 0.16451237590185233, 0.24667467496224812, 0.30720911813633783, 0.14932456373104028, 0.1515286218907152, 0.262123913105045, 0.25961916893720627, 0.2649227886327675, 0.15842503468905175, 0.2781709134578705, 0.23891030730945723, 0.18292857626719133, 0.241408537541117, 0.28464720451406067, 0.09599101915955544, 0.3629278082932745, 0.17273973513926777, 0.20308728170182022, 0.18207620057676518, 0.2197031658142805, 0.14860067543174538, 0.17107591299074038, 0.26464586492095676, 0.30809517630508965, 0.4095306247472763, 0.2873332532388823, 0.23367872089147568, 0.25639086216688156, 0.1907448654196092, 0.22552454844117165, 0.5600232322301183, 0.15538344718515873, 0.40963452202933176, 2.643402201788766, 13.767170241900853, 16.715140649250575, 12.401036279542105, 11.817090562411718, 25.9119256905147, 48.78955915996006, 66.9870684487479, 84.22319371359688, 75.13365064348493, 71.09025764465332, 57.686077799115864, 81.71784700666154, 116.63275337219238, 123.74533244541713, 127.75499888828823, 120.9651358468192, 126.00831903730119, 142.65132522583008, 142.41594805036272, 100.12007454463414, 68.70740073067802, 42.64630242756435, 45.82427297319685, 42.71209144592285, 23.714189631598337, 25.73041616167341, 21.434996366500854, 4.957362081323351, 1.288429326244763, 0.21965870819985867, 0.0901633125862905, 0.28709283471107483, 0.1543515311287982, 0.2361339862857546, 0.5840707847050258, 0.5488573685288429, 0.3871710774089609, 0.25708912898387226, 0.19425342072333607, 0.20702647604048252, 0.36147161786045345, 0.2764775614653315, 0.2480475412947791, 0.2624473571777344, 0.22434738517871924, 0.16511395147868566, 0.2501346878707409, 0.15676643726016792, 0.2910825934793268, 0.27931386498468264, 0.23466064248766216, 0.2839270888694695, 0.15791744978300162, 0.18958419055810996, 0.2845177671739033, 0.23993766361049243, 0.18544666043349675, 0.18630055604236467, 0.18302600032516889, 0.13839725937162126, 0.1793089040688106, 0.16061269944267614, 0.13079179104949745, 0.2713688984513283, 0.23188418575695582, 0.16069181662585053, 0.2199842014483043, 0.21635887026786804, 0.27681658470204895, 0.36286918286766323, 0.218306265771389, 0.18073869948940618, 0.28374046459794044, 0.15195681819958345, 0.16605867578514985, 0.24275274255446025, 0.21028303700898374, 0.24139529253755296, 0.3007018858832972, 0.230782543442079, 0.3099939344184739, 0.16476477735808917, 0.34730060398578644, 0.18151194442595753, 0.2620279411120074, 0.2005718302513872, 0.20100419276526996, 0.22072267825050013, 0.16159616809870514, 0.10644215478428773, 0.2098756581544876, 0.18661431063498768, 0.13857578193502768, 0.19308939389884472, 0.18066600124750817, 0.1211659304265465, 0.23909147615943635, 0.22487310054046766, 0.21165773538606508, 0.27296068732227596, 0.1725937822567565, 0.24364428328616278, 0.15688310457127436, 0.22919433723602975, 0.11330692749470472], [0.07657558098435402, 0.03661654517054558, 0.025882636862141744, 0.03877913805523089, 0.04503946837836078, 0.02447718388534018, 0.10726375891161816, 0.047187204738812785, 0.0512415023653635, 0.05215918705133455, 0.00933757993126554, 0.04359262137274657, 0.05589543156591909, 0.03356424020603299, 0.01704113049033497, 0.09479857528848307, 0.01682700858717518, 0.03902140898363931, 0.02372612534756107, 0.05162465751969388, 0.015580152992957404, 0.05028198938816786, 0.002183960376506937, 0.06534010637551546, 0.011268855139080967, 0.07457159566027777, 0.0226406694855541, 0.07162242462592465, 0.04798554190035377, 0.08220570494553872, 0.022875532507896423, 0.033553526138088534, 0.025449536441426193, 0.044944744889757464, 0.05508012424356171, 0.02210948513155537, 0.023272009000980427, 0.02434818759294493, 0.041712892773960314, 0.03308078400524599, 0.050121302117726634, 0.03153865711231317, 0.03863885433280042, 0.053290572948753834, 0.04700620552258832, 0.05647002859041095, 0.019209694483184388, 0.07374134021145956, 0.04457967269367405, 0.025468355610168407, 0.04846126280192818, 0.02016131779445069, 0.06367204338312149, 0.041025584297520776, 0.047536260115781, 0.03191972577146121, 0.058443055754261355, 0.04561222996562719, 0.029319165673639094, 0.03263377870566078, 0.12823942729404994, 0.6088019747819219, 0.1339447261499507, 0.1674905475229025, 0.36240503777350697, 1.207082748413086, 3.354888835123607, 9.410006148474556, 31.517845221928187, 51.32862547465733, 78.84768513270787, 90.57455594199044, 102.93230233873639, 103.8287797655378, 95.35872418539864, 106.48531927381242, 113.17844254629952, 114.01870904650006, 103.23044259207589, 108.58126422337124, 114.95041384015764, 122.05491910661969, 112.22973551068986, 101.78766305106026, 99.46922983442033, 111.77835273742676, 124.7800303867885, 119.11537252153668, 102.60406943729946, 115.41995225633893, 117.91190283639091, 120.5961309160505, 126.16819708687919, 114.63759899139404, 111.72947910853794, 114.25595528738839, 108.03683117457798, 108.34500462668282, 91.96826035635812, 71.94294752393449, 42.84720264162336, 16.001991442271642, 5.789381069796426, 1.9140699888978685, 0.04845426710588591, 0.3702162786253861, 0.26148625303592, 0.1409275300268616, 0.01758490506160472, 0.11599875055253506, 0.040702221649033685, 0.02964160212182573, 0.055286748334765434, 0.02576554716298623, 0.11524119334561483, 0.06524829380214214, 0.04355101360540305, 0.033366956149360964, 0.05274565165330257, 0.017428775850151266, 0.1436862905642816, 0.06284993035452706, 0.07505426476044313, 0.014963050838559866, 0.04361201390357954, 0.187697849635567, 0.08309485723397561, 0.01980577053369156, 0.010411576184976314, 0.034570453355887105, 0.08294363213436944, 0.037991749056215794, 0.02586759882979095, 0.04330175715897765, 0.03729549748823047, 0.02511985493557794, 0.021337127379540886, 0.02354488525140498, 0.10827840625175408, 0.04571587618972574, 0.05053930004526462, 0.03908226678946188, 0.039305847470781634, 0.050132827035018375, 0.015438308639984046, 0.043843563978693316, 0.05508136935532093, 0.07027262169867754, 0.10690386393772704, 0.1519282247338976, 0.046302897190409045, 0.0901875566425068, 0.0516922226441758, 0.0446154450598572, 0.09239983186125755, 0.03622407033773405, 0.015953523672318885, 0.030261491358812367, 0.051682862253593545, 0.028839380347302983, 0.018062106865857328, 0.019823588863281266, 0.04254843740324889, 0.05017717269116214, 0.036769473393048556, 0.029214335405933003, 0.0672076383073415, 0.08671321307442018, 0.030492997329149927, 0.043757356104574034, 0.059013710490294864, 0.07569001814616577, 0.028925907132881026, 0.05952208928231682, 0.04466575503881488, 0.06363581639847585, 0.06106031459889241, 0.02934976081762995, 0.015730529923790267, 0.016390471386590173, 0.03846433173332896, 0.05633303915549602, 0.05440023894022618, 0.06086339016578027, 0.04444529561858092, 0.04835800673546536, 0.010294775711372495, 0.045380069208996635, 0.04892556056646364, 0.015683677080752592, 0.06708345961357866, 0.09696511724697691, 0.039393062969403606, 0.009200780486155833, 0.016197446833497713, 0.020264010676848035, 0.08497657733304159, 0.04956570407375693, 0.03921311887513314, 0.045420367403754165, 0.03627047874033451, 0.07925548896725688, 0.06724396028688975, 0.05980025471321174, 0.07055482441293341, 0.05685861202489052, 0.03340813643964274, 0.08061375322618655, 0.03755093199600067, 0.04197339254564472, 0.017645206468712007, 0.016034092920433198, 0.035158658400177956, 0.0681905166379043, 0.02673867155265595, 0.01798052660056523, 0.05873339410339083, 0.02355411841667124, 0.03630083300439375, 0.03779868548735976, 0.028899827639439275, 0.05476833740249276, 0.04806604329496622, 0.03529852143089686, 0.05001437856948801, 0.015780157975054214, 0.02869030281103083, 0.0609546463404383, 0.06672397854604892, 0.09826193337461778, 0.0933674227978502, 0.05536935318793569, 0.09529285412281752, 0.04368805053776928, 0.09011506874646459, 0.0036353361792862415, 0.06852092926523515, 0.592859821660178, 0.10011218301951885, 0.23683510294982366, 0.3142906624291624, 0.29730931935565813, 2.2507594994136264, 7.701145342418125, 31.216338566371373, 53.118547439575195, 84.64262172154018, 105.94859872545514, 123.3196302141462, 120.80731446402413, 112.44100243704659, 126.60293197631836, 132.2736486707415, 134.63354873657227, 126.08267865862165, 128.9491024017334, 138.13933181762695, 144.9635328565325, 135.11241858346122, 127.66857719421387, 118.34245491027832, 130.4080434526716, 142.24499457223075, 137.56688363211495, 123.13883808680943, 138.13328688485282, 139.96034349714006, 140.05699293954032, 149.06191389901298, 136.63528306143624, 137.4238063267299, 137.72382954188754, 126.82544108799526, 123.62158502851213, 103.16306591033936, 76.33203424726213, 44.335746492658345, 16.5439179284232, 5.119277255875724, 2.2031969087464467, 0.03481564198487571, 0.3041198296206338, 0.22260463583682263, 0.055945368350616524, 0.0534197626236294, 0.0647993003949523, 0.11066333470599991, 0.10129021480679512, 0.05952548195741006, 0.027130827474008714, 0.12825419221605572, 0.08058697823435068, 0.029708746554596082, 0.053177786857954094, 0.09390140271612576, 0.12246688561780111, 0.03579197245250855, 0.014671894854732921, 0.026395456665860753, 0.06941371171602181, 0.018261540182200924, 0.09268629577543054, 0.035415422836584706, 0.029911587813070843, 0.06238630773233516, 0.04721512645483017, 0.03760647687262722, 0.07202921994030476, 0.0701495965144464, 0.08900263093944107, 0.035838472457336526, 0.09903924273593084, 0.04517703117536647, 0.0395990492376898, 0.06540922195251499, 0.02813727641478181, 0.033039254269429615, 0.0403783026018313, 0.03818887026448335, 0.026833934476599097, 0.07477799922760044, 0.08062144781329803, 0.014836139345009412, 0.06237426373575415, 0.06482674035110644, 0.05455746907474739, 0.04536573176405259, 0.04886412600587521, 0.03625668412340539, 0.04821703090731587, 0.03701177146285772, 0.04046041890978813, 0.021842289915574447, 0.051523532053189616, 0.06073981536818402, 0.05112925231722849, 0.018050955142825842, 0.03527557337656617, 0.003016892009847132, 0.013145946781150997, 0.05054828045623643, 0.012794647997777377, 0.07783028722873755, 0.07485005286123071, 0.05906604589628322, 0.03527558355459145, 0.1242505099092211, 0.040227912100298066, 0.03992843727714249, 0.08066075534692832, 0.06715580501726695, 0.037323269926543744, 0.15549449622631073, 0.2823880085987704, 0.1549591456672975, 0.14938963523932866, 0.22891730495861598, 0.12625013903847762, 0.1854085267654487, 0.15819806472531386, 0.14510136177497251, 0.1433653435004609, 0.1194547601044178, 0.12495679701013224, 0.11654322062219892, 0.09664565617484705, 0.11462794696646077, 0.22033047143902096, 0.11108031483100993, 0.09975052385457925, 0.16379546294254915, 0.13385159043329103, 0.11927992877151285, 0.14274079272789614, 0.11522313074341842, 0.1623545666890485, 0.1390408362661089, 0.22105596108095987, 0.1378641886902707, 0.19393042448375905, 0.1128010389262012, 0.16054898500442505, 0.0947529234524284, 0.1315649002790451, 0.06684604021055357, 0.2117857885147844, 0.14257195964455605, 0.15795360212879522, 0.19282849718417439, 0.13439897820353508, 0.1622797514178923, 0.2406230925449303, 0.07425727788358927, 0.05339140325252499, 0.17441476668630326, 0.1242905706167221, 0.16459318942257337, 0.11817189465676035, 0.09346283839217254, 0.2124524898827076, 0.1076601454988122, 0.11032504428710256, 0.09577584213444165, 0.07295626162418298, 0.16709336026438645, 0.18388803835426057, 0.13563991018704005, 0.1844480333051511, 0.19427673518657684, 0.1222592539020947, 0.15072518214583397, 0.23702085869652884, 0.24249574063079699, 0.7739547384636742, 0.26838768699339455, 0.6577060020395687, 1.6478225099188941, 2.916627300637109, 5.373484483786991, 14.752795662198748, 47.44512789590018, 77.17484378814697, 106.43782138824463, 125.6353258405413, 139.6856951032366, 139.39603860037667, 130.11495453970772, 144.123690196446, 148.04724066598075, 148.6792210170201, 137.7690484183175, 144.0403118133545, 150.74914496285575, 160.39752469744002, 148.6617532457624, 135.92794254847934, 131.7199467250279, 142.67083576747348, 155.17185401916504, 149.01704243251254, 130.94500023978097, 147.7571255820138, 151.5451166970389, 155.90815462384904, 163.99109131949288, 153.44128009251185, 150.72256115504672, 157.54701232910156, 148.78848838806152, 146.37547629220145, 129.4212324959891, 102.02122674669538, 62.35510744367327, 26.252015692847117, 9.803358435630798, 4.119348968778338, 0.14952361876411097, 0.4700537228158542, 0.8117313885263034, 0.35682533574955805, 0.21889744619173662, 0.14500942027994565, 0.19228104156042847, 0.2103181986936501, 0.19442708497600897, 0.18817028642765113, 0.21358970100326197, 0.20013360519494328, 0.17103933995323523, 0.09191742738974945, 0.1375183936740671, 0.288825161755085, 0.17495711972670897, 0.24739522486925125, 0.10550714709929057, 0.12008004369480269, 0.07565985726458685, 0.30350567400455475, 0.17094693705439568, 0.09752893913537264, 0.19266716869814055, 0.15709697880915233, 0.2070773390254804, 0.17026543005236558, 0.17363533351038182, 0.19107962745640958, 0.12494623900524207, 0.24397744398031915, 0.077970933967403, 0.1393761954137257, 0.19945056470377104, 0.0846846919240696, 0.09684758819639683, 0.2634717550660883, 0.10020062327384949, 0.08661619613745383, 0.18931923620402813, 0.2172905124191727, 0.11467108822294644, 0.2802598513662815, 0.18310263407017502, 0.24738873807447298, 0.1896460186690092, 0.1878158061632088, 0.1315433635775532, 0.16413515114358493, 0.08392214069941215, 0.1258419459419591, 0.14560073640729698, 0.14011502505413123, 0.16348336397537164, 0.08072103639798504, 0.13378737387912615, 0.1102261206667338, 0.1668272659714733, 0.07870232686400414, 0.1007286999374628, 0.11027306171932391, 0.19319307404969419, 0.19963931957525866, 0.11053788036640201, 0.14040668654654706, 0.22111008103404725, 0.17016298483525003, 0.21333140986306326, 0.11966590663152081, 0.20719163146402153, 0.11396978156907217], [0.04158537229523063, 0.01814011125160115, 0.11308570472257477, 0.007409620215184987, 0.1146797463297844, 0.04920227053974356, 0.09411753647561584, 0.022464443763185824, 0.04168578190729022, 0.033974278917802234, 0.07011740681316171, 0.03087968086557729, 0.042483742481895855, 0.06766792932259184, 0.01921988947183958, 0.043666493480226824, 0.07069622432546956, 0.0379672980468188, 0.04134995457051056, 0.11857963992016655, 0.05834417963134391, 0.07106751190232379, 0.017028952483087778, 0.04420048018385257, 0.04559730898056712, 0.0669425211048552, 0.033696581676070175, 0.0845677667696561, 0.0641680389110531, 0.06992957474929945, 0.048833751385765414, 0.05553686652066452, 0.046604146382638385, 0.0803347531972187, 0.09881258489830153, 0.039681213043097935, 0.06888978090137243, 0.02551096591300198, 0.0658680201907243, 0.03830264701641031, 0.03459970500054104, 0.011215849679761698, 0.07278161349573306, 0.005382383616441595, 0.043305176975471635, 0.05284186791894691, 0.06845018520419087, 0.09232439912323441, 0.03195038198360375, 0.02564989765440779, 0.10334576879228864, 0.03411331074312329, 0.017759397127000347, 0.021224270042564188, 0.07409498587782894, 0.0647382051018732, 0.13419543126864092, 0.16060011940343039, 1.3926669614655631, 4.9231778127806525, 13.861661400113787, 23.122359446116857, 44.001604148319785, 56.897915840148926, 63.04328482491629, 66.52717413221086, 76.20404148101807, 82.91560527256557, 91.69113840375627, 103.70262827192033, 95.55542073931012, 97.1008529663086, 87.61007922036308, 75.10635811941964, 92.09322370801652, 86.91833046504429, 79.7708992276873, 90.2912848336356, 97.06294359479631, 87.06001118251255, 83.71956048692975, 70.91557993207658, 90.3771367754255, 100.65241772787911, 67.15064988817487, 97.51479884556362, 70.49932725088937, 79.08519540514264, 106.67876407078334, 99.65607384272984, 94.41296318599156, 86.15500136784145, 100.53604929787772, 102.60611915588379, 89.08181190490723, 90.38122926439557, 80.96072959899902, 87.37655026572091, 94.29129328046525, 109.84245954241071, 106.24632208687919, 92.94949885777065, 93.62516253335136, 72.72232001168388, 39.45587028775896, 20.17969833101545, 9.37836752619062, 1.3090861035244805, 0.11308839172124863, 0.2898851420198168, 0.03192283006917153, 0.08696967217006854, 0.04346864623948932, 0.049422353373042176, 0.05341637673388634, 0.028725152369588614, 0.10009306868804352, 0.00801151555164584, 0.18189463817647525, 0.06124776668314423, 0.11580140542771135, 0.09380209233079638, 0.05295921376507197, 0.07806063629686832, 0.041237514532570324, 0.09459011576005391, 0.011733921344525047, 0.052785993952836306, 0.06489238861416068, 0.05456508563033172, 0.05819340915020023, 0.04284445169780936, 0.04000526101195386, 0.06308484596333333, 0.05465518829545804, 0.024481838635568107, 0.01895241266382592, 0.02288054857802178, 0.08401590066828898, 0.04515897535852023, 0.040132781490683556, 0.02345630929007062, 0.005890779795923403, 0.06832053073282753, 0.11104009806045465, 0.06504748814872333, 0.08402533230504819, 0.13692718611231872, 0.0708762328805668, 0.0641644766022052, 0.08110096851097685, 0.09633666489805494, 0.044593603017606905, 0.09697760229132005, 0.012522150030625718, 0.08019039487200123, 0.03523744988654341, 0.06982117199472018, 0.05158907514331596, 0.048000720728720934, 0.04690360424241849, 0.036081204789557626, 0.04094726100031819, 0.05405194012980376, 0.0480214737222663, 0.022535922338387797, 0.14209584519267082, 0.019688197378335253, 0.09826475608029536, 0.01851288482014622, 0.050814249220171144, 0.09902612665402037, 0.017443535683144416, 0.05726563464850187, 0.08653018503848996, 0.01201189000026456, 0.030193994087832313, 0.0464373149776033, 0.08306686087910618, 0.04146100361166256, 0.025713377998077443, 0.013403338862449994, 0.095037080347538, 0.03469391280253019, 0.09869438409805298, 0.042265613829450946, 0.08569303567388228, 0.07071769317345959, 0.05951355331178222, 0.06517474739147083, 0.052004688020263395, 0.07578673652772393, 0.03550773413319673, 0.05194197442116482, 0.05473668035119772, 0.056949851236173084, 0.07491375372878142, 0.027603759596656476, 0.056760417829666815, 0.09158823612545218, 0.05523707278605018, 0.09309474671525614, 0.05160965171775647, 0.031335479979004176, 0.043461436804916175, 0.08005903049239091, 0.016171621790687953, 0.0727620649018458, 0.06789721309074334, 0.04014394339174032, 0.11375799043370144, 0.05795442233128207, 0.08487583523882286, 0.04552834268127169, 0.045541065212871344, 0.04506301015083279, 0.04740684652434928, 0.0308387584186026, 0.0890314754630838, 0.09485346877149173, 0.0769622034526297, 0.05509058725354927, 0.15572561882436275, 0.06367729524416582, 0.07756808094148125, 0.026857847746993815, 0.029086166926260506, 0.026730184775910208, 0.10914934666029044, 0.025690302718430758, 0.0770178772509098, 0.12458191998302937, 0.2551909408399037, 0.12569747226578848, 0.6448149223412786, 2.4321383152689253, 7.931529368673052, 18.52671841212681, 42.339108671460835, 57.095512185777935, 65.63201686314174, 77.75670678274972, 85.68003640856061, 96.3230229786464, 110.43839263916016, 119.84094510759626, 115.3275898524693, 112.63712229047502, 102.35094656263078, 87.28105422428676, 109.30572509765625, 102.05688490186418, 102.70085089547294, 112.99532277243478, 110.49233150482178, 103.42106642041887, 102.94726875850132, 101.30855001722063, 105.4578057697841, 112.08355930873326, 96.3745369229998, 123.95822525024414, 100.71575055803571, 111.3691941670009, 131.42662157331193, 124.25660869053432, 110.78494794028146, 111.99924986703056, 111.08417906079973, 118.42934908185686, 106.22535242353166, 102.11397130148751, 96.41686534881592, 106.17180265699113, 108.28298500605992, 133.0940502711705, 125.50008610316685, 112.01020022800991, 109.77934905460903, 85.9344516481672, 46.5121237891061, 26.134479965482438, 11.360663396971566, 1.848256868975503, 0.07742260981883321, 0.12068809249571391, 0.09397090505808592, 0.11083141461546932, 0.06782905424812011, 0.005616101186855563, 0.04851927076067243, 0.06689334088670355, 0.12476055111203875, 0.10412974136748485, 0.012157850516294795, 0.05532192359013217, 0.06826927419751883, 0.0881621160411409, 0.03648821723514369, 0.08240977435239724, 0.04720485004197274, 0.09585236052849463, 0.10672631846474749, 0.06371359686766352, 0.050343233958951066, 0.03591080089764936, 0.06361373008361884, 0.034893137469355545, 0.008842385922824698, 0.07417362130114011, 0.042621451163930554, 0.011671090698135751, 0.06790773038353239, 0.0009319464318520788, 0.07086528132536582, 0.05122464755550027, 0.03806645576176899, 0.014730345557576843, 0.038665598790560446, 0.06528768275997468, 0.08199969492852688, 0.05614775499062879, 0.11623068739260946, 0.08150496147572994, 0.09065124711820058, 0.05460986554888742, 0.08232338327382292, 0.14002986890929087, 0.08591780039880957, 0.03494325406583292, 0.048497876551534445, 0.03025348803826741, 0.09097317127244813, 0.04220113603930388, 0.019557592957945805, 0.0383197257428297, 0.042172430615339956, 0.03630689571478537, 0.03838179134098547, 0.024854213564789722, 0.09531977839235749, 0.047704638580658605, 0.04439609843705382, 0.07788951655051538, 0.03157124714925885, 0.07458078302443027, 0.08349503683192389, 0.036181885815624676, 0.07510842542563166, 0.07315723691135645, 0.04282925929874182, 0.06463447745357241, 0.09896796263222184, 0.1740715093910694, 0.33669453167489594, 0.05759770290127822, 0.1661132164299488, 0.2633739917406014, 0.14153827939714703, 0.19257399226937974, 0.13712662112499985, 0.18452401565653936, 0.18944605439901352, 0.1342981071876628, 0.14996944341276372, 0.20081367370273384, 0.1416086706199816, 0.16514388844370842, 0.11862333757536751, 0.1452765323753868, 0.18394462817481586, 0.2950058015329497, 0.2603861034980842, 0.2545050233602524, 0.12319811566599778, 0.17594288183110102, 0.12958999696586812, 0.2651096028941018, 0.1698131321796349, 0.11242056398519448, 0.29998418582337244, 0.15174439602664538, 0.1549554815781968, 0.1566639377602509, 0.19773065485060215, 0.1871169286647013, 0.16475720490728105, 0.17762254098696367, 0.16506812322352613, 0.12369892879256181, 0.1252997014671564, 0.22211271151900291, 0.08330554235726595, 0.1263293240751539, 0.13580807830606187, 0.13598285535616533, 0.22219347075692245, 0.18462970427104405, 0.2464670975293432, 0.1409386851425682, 0.13402980087058886, 0.07008268617625747, 0.20115915659282887, 0.14433726349047252, 0.12395437008568219, 0.17268984924469674, 0.2676674627832004, 0.17235052745257104, 0.5270554955516542, 0.6250057167240551, 2.7257476917334964, 9.915612663541522, 22.988563196999685, 39.20723247528076, 66.21677030835832, 84.04138020106724, 90.07869774954659, 96.98585333142961, 105.1163296018328, 113.22163949693952, 123.08143207005092, 131.32938848223006, 122.12991796221051, 120.07369586399624, 108.92834063938686, 95.09000955309186, 113.67998436519078, 109.00984995705741, 100.54009314945766, 111.56791959490094, 119.22348649161202, 112.07328292301723, 110.50174631391252, 91.27193273816789, 115.93983037131173, 126.74092320033482, 91.39886243002755, 124.93304361615861, 96.633392061506, 104.31567478179932, 134.89581544058663, 127.37680843898228, 119.46704864501953, 109.58307634081159, 123.93464306422642, 126.26809828622001, 113.6878775187901, 112.61851501464844, 104.65849195207868, 110.20152854919434, 117.37494604928153, 139.95297840663363, 138.78315189906527, 130.3387838091169, 130.32945932660783, 105.97464752197266, 59.56092412131173, 34.84093236923218, 17.38978120258876, 3.736187083380563, 0.18547582386859826, 0.48755851494414465, 0.18780550600162574, 0.1759313874478851, 0.16376665234565735, 0.17675687958087238, 0.22225964149194105, 0.17201683750110014, 0.1856115444430283, 0.19504464683788164, 0.26650184818676537, 0.15605044710849011, 0.2539328012083258, 0.1959470169884818, 0.19103896963809217, 0.19161701362047875, 0.09208617904888731, 0.19585713823991163, 0.2785222317491259, 0.12590080206947668, 0.2634556602154459, 0.1083759388753346, 0.19191313987331732, 0.17231236664312227, 0.12373689961220537, 0.1853119848029954, 0.21119812290583337, 0.10251832247844764, 0.12994427366980485, 0.17992475602243627, 0.17028251556413515, 0.15328207851520606, 0.3000093459018639, 0.2649214044213295, 0.14316358789801598, 0.12896293561373437, 0.2445626397218023, 0.1680136030273778, 0.1658173208790166, 0.17510119985256875, 0.15264574837471756, 0.14486211032739707, 0.14073830018086092, 0.30731247259037836, 0.14291197354240076, 0.36059978178569246, 0.15104387647339276, 0.10319596861622163, 0.1996196692011186, 0.19119695973183426, 0.13219390224133218, 0.13903741644961493, 0.11973225378564425, 0.11767745975937162, 0.14603551450584615, 0.11318694893270731, 0.25380431381719454, 0.1609813475183078, 0.18377555081886904, 0.14219200717551367, 0.21715287837599004, 0.1844057198613882, 0.209443010655897, 0.19355382397770882, 0.10945172222065074, 0.12019227338688714, 0.17524259297975472, 0.11915369411664349], [0.13451118075421878, 0.12918565794825554, 0.013064966171181627, 0.05957956798374653, 0.07075204740145377, 0.0642261282939996, 0.00415217418256881, 0.07219124053205762, 0.03378394305972116, 0.023598757539210573, 0.050680082490933795, 0.02419953583739698, 0.1127692631312779, 0.03319481860048004, 0.06171579978295735, 0.03658810776791402, 0.014762884704396129, 0.04287779151595064, 0.09019888139196805, 0.04877219129619854, 0.02730710239016584, 0.0810799135693482, 0.050401839028511725, 0.07021702253924948, 0.0671584920159408, 0.06440923775413207, 0.08930261805653572, 0.024605496553704143, 0.0709548954452787, 0.0799850362486073, 0.1645482839750392, 0.0759652183790292, 0.16932200853313717, 0.1580145074320691, 0.06825477390417031, 0.14691983562495026, 0.13794774349246705, 0.062071094289422035, 0.11571088885622365, 0.0802776680460998, 0.04887456526713712, 0.08209557192666189, 0.014813579751976898, 0.11920214151697499, 0.04599306113751871, 0.0659082844587309, 0.03755490142585976, 0.060070861263998916, 0.022986425485994135, 0.06983682579760041, 0.04872653267479368, 0.052921494003385305, 0.028182733172018613, 0.11072301186089005, 0.023918506988723363, 0.5365708363907677, 2.5728065499237607, 21.168465205601283, 43.30424819673811, 66.22592108590263, 87.75472681862968, 88.8078305380685, 90.5370843069894, 89.2673704964774, 88.74982002803257, 84.38698359898159, 78.30363423483712, 81.94465705326625, 84.26477173396519, 75.09953498840332, 60.984283447265625, 41.5496369770595, 59.61505058833531, 70.96216760362897, 45.76653691700527, 53.276768343789236, 37.19938373565674, 27.434107507978165, 29.705202647617885, 40.72189460481916, 27.923187732696533, 30.6304212978908, 37.02169050489153, 41.49326971599034, 21.495497805731638, 23.906625202723912, 39.38787521634783, 30.9244065284729, 23.876947709492274, 37.4615010534014, 46.798514638628276, 42.5685590335301, 66.23167419433594, 42.278628076825825, 36.99611071177891, 73.43687970297677, 55.66253655297415, 48.712479318891255, 74.55320508139474, 70.55093152182442, 83.95841176169259, 107.58812345777238, 98.9855796269008, 101.47418117523193, 110.92965807233537, 100.20420333317348, 81.28055518014091, 69.09017004285539, 30.554824897221156, 9.16904262134007, 0.8746142685413361, 0.07471596077084541, 0.20030375463621958, 0.14330420749528067, 0.06789536747549262, 0.17855924500950746, 0.07418348720031125, 0.13952683018786566, 0.1461792282227959, 0.0895299476438335, 0.11350205381001745, 0.04104480380192399, 0.09721941860126597, 0.0473433288612536, 0.06274918147495814, 0.1453233648623739, 0.103855653932052, 0.026038162177428603, 0.025098219846508334, 0.08851877440299306, 0.02483585579986019, 0.12256664383624281, 0.09313721622207335, 0.03609616309404373, 0.06298310642263719, 0.05566562532580324, 0.039771610870957375, 0.022843843226187995, 0.010643691988661885, 0.04050528025254607, 0.08350418348397527, 0.037873446475714445, 0.10139071262840714, 0.03427633556670376, 0.028996532450297048, 0.06205937598964997, 0.03170668613165617, 0.11870071770889418, 0.09513360195394073, 0.07962254927094493, 0.11583423295191356, 0.10606041776814631, 0.021842734356011664, 0.056239937365587266, 0.09601063560694456, 0.037461467153791866, 0.07564706687948533, 0.08057443212185587, 0.03168341238051653, 0.079139059143407, 0.050682647353304286, 0.060018274800053666, 0.05591720236199243, 0.05452650412917137, 0.004900802716812385, 0.05517271034685629, 0.03293968264811805, 0.05534711420269949, 0.0059252527675458366, 0.0467012311731066, 0.027450861908229332, 0.07901078209813152, 0.009588374107676958, 0.030377100155289685, 0.02585837584254997, 0.11072158693735089, 0.04462666802906564, 0.08438406698405743, 0.04585508104147656, 0.06357582033212696, 0.11546036015663828, 0.07718966196158103, 0.03584147836746914, 0.04255992500111461, 0.042730366212448904, 0.03489784650238497, 0.029221629657383476, 0.08849790266581944, 0.10091196546064955, 0.080325158712055, 0.10042182568992887, 0.019429125922865102, 0.038973826715456586, 0.03529321189437594, 0.10408746185047285, 0.031215681228786707, 0.03723594925499388, 0.03839097870513797, 0.03727509054754462, 0.03845525632745453, 0.09968974068760872, 0.043753312035862885, 0.047302481053130965, 0.06390495731362275, 0.051233169955334494, 0.07447480263986758, 0.06755749096295663, 0.07738232519477606, 0.10734810759978634, 0.15586889827890055, 0.055517616482185464, 0.10551640910229512, 0.11734085210732051, 0.09504362142511777, 0.04998189370547022, 0.03562730896685805, 0.028203019672738652, 0.09775826361562524, 0.06814700218715838, 0.0845632545117821, 0.07419739716819354, 0.10783822022910629, 0.04737793753987976, 0.08365706420902695, 0.04919124773836561, 0.19986756518483162, 0.0727881206465619, 0.01311966881621629, 0.043766618107578585, 0.22798605635762215, 0.16299867284085068, 0.07181409041264228, 1.132361929331507, 15.7644898550851, 35.26031868798392, 65.13818059648786, 95.66289547511509, 100.6219846180507, 104.0718138558524, 102.67134884425572, 105.84759971073696, 95.31751441955566, 90.73266220092773, 98.46652139936174, 100.06024360656738, 93.20804132734025, 85.3944376536778, 84.31627178192139, 114.66506522042411, 109.92456640516008, 90.03352056230817, 94.58244364602226, 72.92119829995292, 71.11331176757812, 68.21603802272251, 68.1740847996303, 66.64971951075962, 61.870845794677734, 74.12886469704765, 89.19552612304688, 49.92405407769339, 57.33316837038313, 62.25890963418143, 62.16972255706787, 56.561233929225374, 71.44910430908203, 75.01180703299386, 63.40561253683907, 97.10629340580532, 74.96103654588971, 77.11597864968437, 104.98096479688371, 84.80113097599575, 80.30770315442766, 102.9786468233381, 94.30045100620815, 104.86880697522844, 120.27417918613979, 111.27676922934396, 115.68073899405343, 126.64695576259068, 114.01482500348772, 97.73115880148751, 83.09708527156285, 38.52940443583897, 12.658110073634557, 1.1324335826294762, 0.03451713068144662, 0.21694823221436568, 0.11838108700300966, 0.0438300645244973, 0.04138586264369743, 0.08266907650977373, 0.11950574522571904, 0.06040240704481091, 0.10895419998892716, 0.08191089505063635, 0.040314598341605494, 0.10113526454993657, 0.08832629437425307, 0.07432999648153782, 0.19726064721388475, 0.06526571858142104, 0.05275917824889932, 0.04037635859900287, 0.14377659000456333, 0.05213359610310622, 0.09010153197284256, 0.1150584774357932, 0.09658295275377375, 0.047623238127146444, 0.028019133290009837, 0.05131727437089596, 0.05797779107732432, 0.08115595698888813, 0.0952510970777699, 0.07653802407107183, 0.09228490159979888, 0.08525035942771605, 0.07570951245725155, 0.06205884673233543, 0.089767563822014, 0.07757840145911489, 0.1056798342615366, 0.1307924831552165, 0.09861735001738582, 0.12507305720022746, 0.09113181954515831, 0.03613108729145356, 0.06744411454669066, 0.12933128513395786, 0.10447532603783266, 0.11593404545315675, 0.11347188614308834, 0.0814155237749219, 0.07003473410648958, 0.11120282432862691, 0.11026590317487717, 0.04898684245667287, 0.02980509852724416, 0.05494199486981545, 0.022245958879856125, 0.057720253110996315, 0.019960568120170916, 0.07660216598638467, 0.09043565618672542, 0.030701779161712954, 0.04076569860002824, 0.08816150535962411, 0.011123408613327359, 0.11645235121250153, 0.05119071401921766, 0.21796135285070964, 0.1863183200891529, 0.12720884116632597, 0.18336860622678483, 0.17096130842609064, 0.2518214987857001, 0.1563367210328579, 0.22087331302464008, 0.15273224801889487, 0.15733682736754417, 0.2532579574201788, 0.1754709200135299, 0.23382864998919622, 0.13411991032106535, 0.18964755215815135, 0.1495853111680065, 0.22961671171443804, 0.22240772497441086, 0.30674288315432413, 0.18341784072773798, 0.13335151012454713, 0.1463293880224228, 0.22882339571203503, 0.16226829774677753, 0.1905836590698787, 0.1448255508605923, 0.23229339665600232, 0.18405681715479918, 0.24938373959490232, 0.2038486251341445, 0.27507283112832476, 0.3209398170667035, 0.20017810352146626, 0.27394431882670944, 0.135262807565076, 0.2562737198812621, 0.25681052250521524, 0.19265259376594, 0.2689537209059511, 0.2587250497724329, 0.2906734640044825, 0.23242231830954552, 0.14500530835773262, 0.25013343936630655, 0.24032847263983317, 0.1984504990811859, 0.13704915956727096, 0.17139160819351673, 0.12786590733698436, 0.2375720462628773, 0.16618546683873447, 0.11616515448050839, 0.18944665150982992, 0.21228870509990624, 0.24996980386120932, 1.1719559133052826, 7.55152804510934, 36.542785917009624, 65.75443022591728, 93.60973058428083, 117.52105276925224, 113.0811538696289, 115.18389415740967, 111.07188074929374, 111.37860202789307, 105.88496712275914, 99.74736622401646, 104.84157003675188, 103.30940886906215, 95.51375934055874, 78.80915042332241, 57.63836451939174, 79.61915751865932, 97.42299229758126, 69.54269926888603, 73.32688277108329, 57.693109376089915, 44.47964021137783, 46.36405767713274, 61.10625907352993, 44.45351498467581, 46.738548210689, 55.90463958467756, 57.22911214828491, 36.865599223545615, 40.52198450905936, 58.78125980922154, 43.72656318119594, 35.30744137082781, 50.54480961390904, 70.86266245160783, 62.3711438860212, 91.91714245932442, 62.689294951302664, 56.8467458316258, 101.52668176378522, 81.66266441345215, 76.65557016645158, 102.39610290527344, 94.69781153542655, 110.16894149780273, 133.22656631469727, 123.94024331229073, 129.1448470524379, 143.0710242135184, 129.37626375470842, 111.79859978812081, 98.71341868809291, 51.23291056496756, 19.028270653315953, 3.0714383763926367, 0.16193821760160582, 0.4048806514058794, 0.27621377419148174, 0.2610661584351744, 0.20489157416990825, 0.19587514655930655, 0.26491280059729305, 0.24257331075412886, 0.2628901962723051, 0.24804821982979774, 0.3515062725969723, 0.3870051348848002, 0.17345963365265302, 0.1678345376359565, 0.31824082189372604, 0.23497841400759562, 0.12949554489127227, 0.14278387970158032, 0.16863987727888993, 0.3007849385695798, 0.33752163872122765, 0.26990223143781933, 0.2117323199553149, 0.20699572483343737, 0.13717873261443206, 0.13114249865923608, 0.30209000568304745, 0.14434140255408628, 0.21189385200185434, 0.2940938504678862, 0.1883883811533451, 0.23459550312587193, 0.194266516449196, 0.23798519266503199, 0.17220918860818657, 0.16689207963645458, 0.28551849776080673, 0.27263737895659035, 0.1459904597806079, 0.263648906988757, 0.2741856058793408, 0.17653464579156466, 0.19118300905185087, 0.24688711070588656, 0.21457428245672158, 0.214872077905706, 0.2590233337666307, 0.1838708035647869, 0.20412834441023214, 0.161589613450425, 0.17625659571162292, 0.19545217497008188, 0.2528850074325289, 0.1298727560788393, 0.10420803752328668, 0.2653604708611965, 0.21710563876799174, 0.16762197975601467, 0.21571179213268415, 0.23993323956217083, 0.10691194528979914, 0.13465337455272675, 0.18236761779657432, 0.2247030053819929, 0.17440248520246573], [0.0393235368787178, 0.0057376064526449356, 0.026216170750558376, 0.08063049947044679, 0.061167312785983086, 0.006220138573553413, 0.0642671457358769, 0.06518092206014053, 0.03371946866224919, 0.023986731988510916, 0.05284279751192246, 0.038218264401491196, 0.09035681720290865, 0.06358840715672288, 0.0937888269711818, 0.026332191757059524, 0.0830145865412695, 0.03787777213645833, 0.03714335297367402, 0.04344025294163397, 0.10562506970018148, 0.02924542248781238, 0.040327151239450486, 0.029261707328259945, 0.030532471103859798, 0.020807554546211447, 0.028482779660927396, 0.027256907762161324, 0.08777662672634635, 0.03227632985051189, 0.04781718718420182, 0.02901887321578605, 0.0471459294536284, 0.04075144257928644, 0.04936904766197715, 0.02829026909811156, 0.015898279047438076, 0.038744169753044844, 0.004081960651092231, 0.03325776968683515, 0.01464826996172113, 0.06592453537242753, 0.04711208412689822, 0.06914326122828893, 0.09557498898357153, 0.07229271544409649, 0.06512540432491473, 0.01629009230860642, 0.04080678050273231, 0.05403479354988251, 0.05129284032487443, 0.058453423769346306, 0.1549901682883501, 0.1178105069058282, 4.7786292263439725, 23.368761675698416, 64.98170021602085, 81.75989055633545, 86.9317752293178, 84.38469764164516, 76.78297233581543, 81.81720624651227, 74.2246595110212, 73.5316183907645, 64.45974458966936, 64.25384167262486, 66.81059115273612, 49.29238292149135, 41.52753128324236, 28.747546332223074, 24.497206449508667, 23.886914900371007, 20.955659253256663, 16.63819456100464, 33.43226500919887, 20.39354477609907, 53.160521507263184, 43.16473879132952, 41.13980443137032, 54.96360336031233, 34.1532552582877, 48.840684005192344, 34.52023826326643, 32.053950854710166, 54.58506897517613, 48.25993619646345, 65.43284675053188, 66.58898530687604, 47.5913735798427, 52.60852534430367, 48.017718519483296, 67.90007563999721, 31.0825058392116, 38.19970546449934, 35.739275387355256, 28.606362410954066, 30.813343048095703, 30.62746136529105, 20.450375829424175, 33.79447112764631, 34.4639196395874, 57.076752049582346, 76.21895926339286, 80.6913618360247, 83.30708067757743, 88.8059058870588, 106.60068716321672, 95.82472596849713, 95.89313098362514, 90.7859548841204, 65.35830647604806, 46.900232791900635, 10.10809860910688, 0.6186523490718433, 0.06215939883674894, 0.13271277797009262, 0.01155235809606633, 0.08272715910737004, 0.05706208771360772, 0.07158990244248084, 0.045197807917637486, 0.023090219291459237, 0.06182009061532361, 0.04995440625186477, 0.09347031584807805, 0.0778998506388494, 0.08363972763930048, 0.024695797690323422, 0.10319108994943754, 0.03557491249271801, 0.04688488006857889, 0.029605069796421697, 0.0299015692435205, 0.03277062904089689, 0.017254465292873125, 0.0660582406978522, 0.02455478623908545, 0.03697417723014951, 0.0884005803880947, 0.036985732681517086, 0.055651939274477105, 0.009724909772298165, 0.05000266366239105, 0.053873088476913314, 0.02242748735339514, 0.04429564132754292, 0.01979628291779331, 0.023610748949327638, 0.08731637642319713, 0.020444619735436778, 0.04477284822080817, 0.03537939941244466, 0.03240369765886238, 0.049425549272980006, 0.021054536203986833, 0.08533472168658461, 0.037224478620503626, 0.038456243595906665, 0.02399632308099951, 0.01126759815295892, 0.009921782467115139, 0.014614110812544823, 0.020502444489725997, 0.03938281709062202, 0.027985666246552552, 0.09462560314152922, 0.0614541634651167, 0.042862663577709875, 0.02028246852569282, 0.045200067439249585, 0.05964381167931216, 0.020431900596512214, 0.015309159677209598, 0.0626717945560813, 0.036557553336024284, 0.03870346782995122, 0.05868402389543397, 0.018330338544079235, 0.023750969907268882, 0.029735548687832694, 0.06428595472659383, 0.013829466487680162, 0.03147532943902271, 0.08476080998246159, 0.05522047581949404, 0.012967372479449426, 0.05646825761401227, 0.05006382680897202, 0.04394889296963811, 0.05787973598177944, 0.07427975774875709, 0.04810958827978798, 0.05984948242881468, 0.07065554615110159, 0.021248765156737397, 0.05053325769092355, 0.06661973521113396, 0.05502993979358247, 0.07931371405720711, 0.0602367902174592, 0.0353445396758616, 0.006853994605730155, 0.05538759220923696, 0.058150770009628365, 0.03407553330596004, 0.03139241924509406, 0.026641914155334234, 0.02845841516474528, 0.025329546005065953, 0.0724417149488415, 0.032494641707411835, 0.0006325079739326611, 0.06724600267729589, 0.03981886065698095, 0.0949967142992786, 0.022663208722536052, 0.024725597252004912, 0.053932110845510445, 0.12372833650027003, 0.019546168124569312, 0.03686202217691711, 0.04897311230057052, 0.05864684696176222, 0.0598661404635225, 0.06682788939880473, 0.05455780155690653, 0.08609622118196317, 0.07323149578379733, 0.16860424061971052, 0.09147578930216176, 2.8900728055409024, 19.16335231917245, 61.93561690194266, 87.54072230202812, 100.62418024880546, 95.95276737213135, 86.57153197697231, 91.03503390720913, 84.45841108049665, 86.54926300048828, 79.59842409406389, 99.51917348589215, 92.30748530796596, 77.62309292384556, 67.52840260096959, 54.757353033338276, 39.077398436410085, 18.241546971457346, 24.757015228271484, 26.95791619164603, 29.465232712881907, 24.254507609776088, 38.09549985613142, 21.457199335098267, 27.608677523476736, 40.79255778448922, 21.984322684151785, 30.601808616093226, 25.37679280553545, 27.93778416088649, 33.03423745291573, 28.022512231554302, 55.43294722693307, 54.056311062404085, 26.186476809637888, 30.678874560764857, 41.956815310886924, 50.0671591758728, 33.343265533447266, 31.044207368578228, 24.765123776027135, 38.48898329053606, 34.708312102726524, 35.61005278996059, 34.804707935878206, 52.72065537316458, 63.62593991415841, 97.15263789040702, 109.83188438415527, 103.4961417061942, 98.1827083315168, 101.14564255305699, 118.74871608189174, 107.16359547206334, 110.4827013015747, 106.22415733337402, 83.18231882367814, 57.581562995910645, 12.504156231880188, 0.2949386537075043, 0.05750130343117884, 0.03519514662080577, 0.0878051726945809, 0.07090409352843251, 0.0839430463633367, 0.03994869154744914, 0.0315102739924831, 0.04073554450379951, 0.05595089841101851, 0.10066472087055445, 0.05476976232603192, 0.014390285858618361, 0.07078949574913297, 0.006756221102218011, 0.08693980984389782, 0.037373260994042666, 0.017768028092437556, 0.04172385111451149, 0.1164412639502968, 0.017259223519691398, 0.052101386045770984, 0.047231950730617554, 0.014267240318336656, 0.013824683663967465, 0.03849662660754152, 0.05007499888805406, 0.02589145951372172, 0.019240262485774498, 0.03660631286246436, 0.062346810208899636, 0.09404568640249115, 0.11129281842815024, 0.037939182948321104, 0.022421640077871934, 0.12388376173164163, 0.016895966404782872, 0.10477518423327378, 0.10374850646725722, 0.0072404300527913225, 0.01758812471026821, 0.043371361281190596, 0.07799745111593179, 0.07131565215864352, 0.07438109695379223, 0.008457028922358794, 0.02970334541584764, 0.09957109883959804, 0.05989239298339401, 0.08899411532495703, 0.020710042278681482, 0.029677065754575387, 0.1381141067083393, 0.06948473397642374, 0.0447893467997866, 0.08674599988652126, 0.045874941761472394, 0.04947943513148597, 0.03758052969351411, 0.008665501173319561, 0.05119123988385711, 0.035572130499141555, 0.06744669297976152, 0.17988450532513006, 0.15995787243757928, 0.07822110304342848, 0.1131775105105979, 0.13520908116229943, 0.0901040154110108, 0.11936646912779127, 0.18509778486830847, 0.11842531391552516, 0.12892010648335728, 0.1165218467691115, 0.11157919413277081, 0.21042607219091483, 0.24772540000932558, 0.15639506147376128, 0.11013200107429709, 0.20362314794744762, 0.15575487725436687, 0.10969223574336086, 0.16855362190731935, 0.23747056456548826, 0.220981593642916, 0.21449437817292555, 0.12404988067490713, 0.10944193774568182, 0.09142492631716387, 0.19254014694264956, 0.17134701487209114, 0.15254179680986063, 0.12354072156761374, 0.15957565366157464, 0.17300614155828953, 0.1152925177344254, 0.13843151181936264, 0.1891185933990138, 0.05689615197479725, 0.11297526636293956, 0.1817941064281123, 0.19901090115308762, 0.12015647387930325, 0.12520667431609972, 0.11353750726474182, 0.17049723118543625, 0.11118096193032605, 0.30654238962701386, 0.12286576921386377, 0.1750064492225647, 0.14039436435060842, 0.1867046779287713, 0.21826321950980596, 0.11735017517847673, 0.18790976969259127, 0.2845627676163401, 0.28457557835749214, 7.733109661511012, 35.739094734191895, 87.7092091696603, 104.5338829585484, 111.99969455174038, 107.64319487980434, 94.20105007716587, 102.31329427446637, 94.29029273986816, 98.04454340253557, 83.19306073869977, 84.60999992915562, 86.66796602521623, 62.86513301304409, 60.87767028808594, 45.08490473883492, 36.17664016996111, 34.35866832733154, 27.95493926320757, 25.050724267959595, 48.10136093412127, 30.650661400386266, 75.49093396323067, 61.14441163199288, 57.4045854296003, 74.90110833304269, 52.23765482221331, 69.03138133457729, 51.07674632753645, 44.32149921144758, 76.46462672097343, 70.26677799224854, 87.1794159752982, 88.3362215587071, 66.76443426949638, 73.27732127053397, 69.39227771759033, 92.84762437002999, 49.675221715654644, 59.51012584141323, 53.06776653017317, 44.71251603535244, 51.023352895464214, 47.97655044283186, 32.26462023598807, 47.54165227072579, 52.14664731706892, 80.35215078081403, 97.57106535775321, 104.56483023507255, 101.88559096200126, 110.44970430646623, 134.1237733023507, 123.193117414202, 126.6243463243757, 129.08210481916154, 103.42718083517892, 77.25274699074882, 19.28016369683402, 1.2531095700604575, 0.19205945916473866, 0.23410652365003312, 0.21596933688436235, 0.1686901838651725, 0.20331300316112383, 0.14650677064699785, 0.1220541734780584, 0.16234153881669044, 0.18283412419259548, 0.1974181623331138, 0.13619675673544407, 0.1616675364119666, 0.1684186884335109, 0.13449322671762534, 0.20415870206696646, 0.20282155381781714, 0.08235735752220665, 0.09722828026860952, 0.1577031005706106, 0.12955047908638204, 0.10705272095011813, 0.18821131065487862, 0.11689178406127862, 0.09793101184602294, 0.2320509153817381, 0.18204639931874617, 0.16486651689878531, 0.12508385947772435, 0.11843585834971496, 0.09580098185688257, 0.11513169136430536, 0.15099613474948065, 0.1141748484224081, 0.13627818093768188, 0.21480989695659705, 0.2318296315414565, 0.2080391895558153, 0.17192877722637995, 0.11283293685742787, 0.1351978039102895, 0.18251323141157627, 0.1307104482714619, 0.17136674667043345, 0.276238852845771, 0.1439106006707464, 0.13070082664489746, 0.16436792936708244, 0.14828713797032833, 0.11320862134120294, 0.09953459365559475, 0.07524335211408989, 0.1799941294427429, 0.13991827704012394, 0.2433622841324125, 0.15501114859112672, 0.18091116952044622, 0.21087678229170187, 0.0900162672623992, 0.13278508266167982, 0.18698135736797536, 0.14351988663630827, 0.08050010539591312], [0.011856993178038724, 0.03645183079476867, 0.04680015818615045, 0.028048892139590213, 0.020164298259520104, 0.05722167236464364, 0.027598317745806913, 0.02551847051030823, 0.04852780673120703, 0.031901123733924966, 0.018499271711334586, 0.003922752586991659, 0.009669689744311784, 0.08704568166285753, 0.02920109379504408, 0.052071591573102136, 0.03492716260786567, 0.046870542623634846, 0.028218013600313237, 0.019895004673994014, 0.058121599789176664, 0.0390096635424665, 0.05081392352336219, 0.022488368907943368, 0.0645638487434813, 0.007939907206621553, 0.020860013784840703, 0.033827613573521376, 0.07670916417347533, 0.021555907425603697, 0.10237264100994382, 0.05467986661408629, 0.0640334989875555, 0.034257909948272366, 0.010195155744440854, 0.06408417198274817, 0.021310857896293913, 0.020659808634913394, 0.00302975215683026, 0.05396624794229865, 0.038254559239638705, 0.044144470510738235, 0.06185909280819552, 0.035373832032616646, 0.09378926801894392, 0.020866763511938707, 0.01892387687361666, 0.05597910511174372, 0.057610662920134406, 0.05413130837093506, 0.041404576639511755, 0.19783010094293527, 3.3162186358656203, 20.257400035858154, 39.13022559029715, 51.356612818581716, 66.79440879821777, 81.02716827392578, 72.55570915767125, 74.19601208823067, 76.49665791647774, 45.23243236541748, 43.92139761788504, 35.21710089274815, 35.07772697721209, 19.40647152491978, 17.60732408932277, 46.479380403246196, 57.19695935930525, 40.60003709793091, 62.9820225579398, 98.03303023747036, 150.09252629961287, 115.28918021065849, 122.9491800580706, 126.92025620596749, 104.93155615670341, 134.41134534563338, 146.50510188511439, 88.60083675384521, 122.667722429548, 120.98823165893555, 107.42554255894252, 153.63830321175712, 107.86346667153495, 99.33158602033342, 85.99813188825334, 120.65778923034668, 122.08960451398576, 109.74150916508266, 100.03608472006661, 94.63645894186837, 108.72207641601562, 104.68594428471157, 132.94448334830147, 105.25366074698312, 95.86896514892578, 108.08658722468785, 107.41683646610805, 78.96806267329625, 60.62757682800293, 35.41529130935669, 27.551863840648107, 22.459143468311854, 37.257606165749685, 37.79626873561314, 47.434021200452534, 65.1090190070016, 73.05672291346959, 86.9320809500558, 92.92898777553013, 94.48762852805001, 87.03856209346226, 50.07261003766741, 12.606841053281512, 1.261529918227877, 0.07071993912437133, 0.13320194743573666, 0.1264729020850999, 0.05551969279934253, 0.12331671001655714, 0.04311717188517962, 0.04736952031297343, 0.031735856352107863, 0.04301944248644369, 0.162562564813665, 0.07986528160316603, 0.06489582200135503, 0.01794552946064089, 0.022374364846785153, 0.07075924665800162, 0.03236017642276628, 0.038897759547191005, 0.07096084619739226, 0.05129281996882387, 0.019078939088753293, 0.033364489674568176, 0.02322874221551631, 0.010571954721984054, 0.03560503605487091, 0.025069227741499032, 0.03217976753200803, 0.0785634850284883, 0.09284778032451868, 0.018650347533236657, 0.03543985348993114, 0.10349341122699635, 0.021281204219641428, 0.028299693949520588, 0.053952222623463185, 0.02628852124325931, 0.023758086043276956, 0.056800135876983404, 0.07944215395088706, 0.04323437184627567, 0.01554945097970111, 0.07728383583681923, 0.04785732253055487, 0.015066844644024968, 0.05484482186979481, 0.018379822406651716, 0.05976596833871944, 0.046935383430016894, 0.03404818155935832, 0.06693402584642172, 0.028564200470490114, 0.04460374033078551, 0.056763338922922096, 0.012497459837634648, 0.00995481270365417, 0.04037259612232447, 0.018451580877548883, 0.045604762687746964, 0.012096214091538318, 0.032988628771688254, 0.04186103053923164, 0.06488822240914617, 0.12174012033002717, 0.07671563061220305, 0.03350134000980428, 0.05387025898588555, 0.026327004356841956, 0.05107162773076977, 0.08778326279882874, 0.025182354796145643, 0.018593783157744577, 0.020683211307706575, 0.012533798780558365, 0.03817419694470508, 0.07313052977302245, 0.009983972746080585, 0.04225513046341283, 0.04007232062784689, 0.0635077225576554, 0.028522395927991186, 0.009778733714483678, 0.024409184498446326, 0.06310817399727446, 0.010477096374545778, 0.051160495462162156, 0.01754530066890376, 0.03821865455912692, 0.007827232225931116, 0.08431336363511426, 0.02929136609392507, 0.07042113944355931, 0.07486837330673422, 0.048101500142365694, 0.039673040088798316, 0.052016270613031726, 0.048076658975332975, 0.05127521537776504, 0.014524176084835614, 0.023047714161553552, 0.025675422445471798, 0.03923634512882147, 0.03730959066056779, 0.02372358593025378, 0.07352606140609298, 0.006020050895001207, 0.029117488102721314, 0.04789196513593197, 0.0376829952666802, 0.05666122279529061, 0.0073439465070675525, 0.060801487416028976, 0.024571400169017057, 0.18388440140656062, 1.476304816348212, 13.74264223234994, 37.18685613359724, 59.37129388536726, 83.22583539145333, 96.59348855699811, 80.26396424429757, 87.62940216064453, 89.23326873779297, 64.74305043901715, 68.42312908172607, 62.8938638142177, 58.21873017719814, 32.53496074676514, 36.46293374470302, 37.71931743621826, 42.828630106789724, 24.87203049659729, 40.66552734375, 50.714508942195344, 56.42836700166975, 56.45990834917341, 73.66769191196987, 63.319239480154856, 74.62391689845494, 84.10585948399135, 98.11483832768032, 77.72799682617188, 71.34196308680943, 74.00613171713692, 74.0445830481393, 75.07984379359654, 71.12960529327393, 72.20327568054199, 59.4558812550136, 66.61881392342704, 71.3266075679234, 69.52060399736676, 71.34886959620884, 86.00267601013184, 80.16286100660051, 72.48576164245605, 77.83856351034981, 61.41305678231375, 67.49940776824951, 75.02056871141706, 68.49870463779995, 53.446412086486816, 43.82109342302595, 33.513954980032786, 36.09182003566197, 44.696948596409385, 59.49946730477469, 67.55898857116699, 85.39091491699219, 89.97425242832729, 96.8938661302839, 93.92991052355084, 100.13561071668352, 106.93722316196987, 104.21751758030483, 59.193023954119, 15.261072022574288, 1.2723606399127414, 0.05025930596249444, 0.14345860135342392, 0.11188992924456086, 0.09374365010964018, 0.0685430427214929, 0.05422474942835314, 0.015846359244148647, 0.06750759149768523, 0.05227561348250934, 0.05745200786207404, 0.11184954284025089, 0.027973403422428027, 0.04803900367447308, 0.08501371355461222, 0.040575773255633454, 0.030659160377191644, 0.04887495881744793, 0.011142997071146965, 0.09118785975234849, 0.0032204067143278992, 0.014443096239119768, 0.047617070243826935, 0.035530471841671636, 0.019437039337520088, 0.08262577240488359, 0.021213915598179613, 0.06260881972100053, 0.007319830524336014, 0.06178904085287026, 0.048030732332595756, 0.006830032565630972, 0.055782723506646495, 0.01521750825590321, 0.06951199072812285, 0.02284884742195053, 0.008913358141269003, 0.0898199670815042, 0.020951643153758984, 0.019659607305324504, 0.08379001636058092, 0.0545263378880918, 0.05416742678997772, 0.053427928792578835, 0.03125830340598311, 0.03259462384240968, 0.034201143708612235, 0.07593448074268443, 0.04539026080497673, 0.009369745035655797, 0.0025084879848041703, 0.06556348010365452, 0.06236372608691454, 0.050877610820212534, 0.011526265880092978, 0.07953229054276433, 0.013880539818533828, 0.009053547716965633, 0.036002216528036764, 0.02871676567675812, 0.04374392789655498, 0.15422782062419824, 0.22209492033081396, 0.20414001521255287, 0.14232962764799595, 0.11352327838540077, 0.12723375697221073, 0.13164850936404296, 0.09289539991212742, 0.13208503808294023, 0.1327398108052356, 0.1409863183008773, 0.1032884054418121, 0.1153141087187188, 0.2734556107648781, 0.2072434036859444, 0.15847209787794522, 0.16532519300069126, 0.20810736875448907, 0.1149832686143262, 0.10054242171879325, 0.1056103997730783, 0.15504536032676697, 0.11645282618701458, 0.2101524868713958, 0.10809456397380147, 0.10082991022084441, 0.09739631946597781, 0.1418049165180751, 0.12885466856615885, 0.18093270622193813, 0.14364720694720745, 0.2108379972300359, 0.17257110561643327, 0.19723560927169664, 0.1609678039593356, 0.15248361921736173, 0.09392962298755135, 0.12279210745223931, 0.1347846167960337, 0.1560354379138776, 0.14077133126556873, 0.14125423106764043, 0.13558322537158216, 0.2215117873357875, 0.2533189984304564, 0.15758598542639188, 0.13521088606544904, 0.14411786597754273, 0.18663974212748663, 0.12418254784175328, 0.11997238732874393, 0.7130316304309028, 6.79082145861217, 32.22065550940377, 65.18773514883858, 75.36624853951591, 90.5359309060233, 103.8386948449271, 91.79625770023891, 93.1877108982631, 102.33120673043388, 65.65345900399345, 61.91165256500244, 50.55115679332188, 49.113685676029746, 25.921554156712123, 26.466213021959575, 65.39975942884172, 74.27160154070172, 61.24113055637905, 92.09004143306187, 142.91423116411482, 211.68549973624093, 160.56526810782296, 180.92683901105607, 177.3486557006836, 156.8640183040074, 204.2988837105887, 213.41243280683244, 123.59743309020996, 183.30812563214982, 177.61436871119906, 160.3957737513951, 222.88460622514998, 161.71056747436523, 151.49852207728793, 127.27732413155692, 174.56415121895927, 173.48312268938338, 160.25201552254813, 143.65975897652763, 136.33653831481934, 154.83055850437708, 150.4412841796875, 189.51982906886508, 147.08088520595004, 136.47370965140206, 150.54614639282227, 146.22957801818848, 110.7886791229248, 81.5563222340175, 48.064768246241975, 42.8428669657026, 37.62481498718262, 57.98878301892962, 58.661556243896484, 65.89977959224156, 90.63337939126151, 95.33767809186662, 107.75665201459611, 111.24036761692592, 116.60418237958635, 117.73030471801758, 76.2970917565482, 22.43047172682626, 2.6617274241788045, 0.15761521671499523, 0.2206272083733763, 0.3123861231974193, 0.24970351957849093, 0.23215616973383085, 0.16467170949493135, 0.1202138779418809, 0.19022756389209203, 0.17851723012115273, 0.22535114203180584, 0.20569616742432117, 0.0827984120696783, 0.1440441363624164, 0.21425948292016983, 0.13461932566549095, 0.09349236823618412, 0.11479574867657252, 0.12055923869567257, 0.14936481442834648, 0.06985627939658505, 0.14657993029270852, 0.1716333566499608, 0.1028760868523802, 0.11897162960043975, 0.1369249333760568, 0.11510473995336465, 0.2117541145001139, 0.22712165702666554, 0.0972844222560525, 0.11937500509832587, 0.26312304234930445, 0.1271383820899895, 0.11082257330417633, 0.144940263990845, 0.14997926859983376, 0.1643116381019354, 0.2431732171348163, 0.11660639223243509, 0.14140166315649236, 0.2404333741537162, 0.1830557608710868, 0.11774456687271595, 0.14209169255835669, 0.11387530235307557, 0.14300535353166716, 0.23458423944456236, 0.15625455044209957, 0.12894332595169544, 0.14529762124376638, 0.16042834147810936, 0.16525177551167353, 0.1982646890516792, 0.16352056126509393, 0.09113521222025156, 0.1464882737823895, 0.10727559934769358, 0.12455389648675919, 0.09583028099898781, 0.18010116155658448, 0.0880047230582152], [0.06890300554888588, 0.10815068560519389, 0.09637387575847761, 0.09828842338174582, 0.1828518882393837, 0.14458650297352246, 0.2002019336713212, 0.027921739766108136, 0.10921622985707861, 0.12468583083578519, 0.12483113232467856, 0.19956446359200136, 0.067042720371059, 0.12312624523682253, 0.22677867114543915, 0.24211833945342473, 0.16964765105928692, 0.19111499270158155, 0.06710465026221105, 0.2664318505142416, 0.16590885525303228, 0.17238821328750678, 0.15033936713423046, 0.27754736691713333, 0.15499808000666754, 0.15485151644263948, 0.11021823608981711, 0.21630473674408027, 0.1617215070873499, 0.1913999638387135, 0.22451653038816793, 0.21008662826248578, 0.17790011609239237, 0.0560164652498705, 0.1520291907446725, 0.17854187451303005, 0.21297855808266572, 0.15726863459817, 0.2295787680361952, 0.11974520023380007, 0.15659805200994015, 0.1386487651616335, 0.32670019939541817, 0.16444670728274755, 0.20673702657222748, 0.13874799412276062, 0.25585804932883804, 0.125621517055801, 0.18852571664111956, 0.20170890566493782, 2.257183326142175, 17.652113914489746, 41.81275136130196, 76.33778735569545, 95.15011147090367, 58.95670877184187, 54.50153425761631, 72.31470394134521, 60.58311530521938, 32.85028736931937, 29.862040860312327, 35.370506695338655, 8.6299683707101, 14.387581842286245, 24.724136352539062, 64.58019161224365, 62.52942384992327, 75.34825270516532, 89.76107474735805, 87.38105964660645, 60.24653761727469, 29.67013508932931, 27.910512481416973, 22.908209017344884, 6.257257129464831, 9.87415623664856, 6.547023066452571, 6.668972636972155, 7.257983156612941, 5.647403751100812, 8.839502590043203, 7.116902589797974, 4.556323783738272, 4.935287654399872, 3.919025020939963, 2.0306861656052724, 3.6889571377209256, 3.987133869103023, 2.2767181864806583, 2.0447071960994174, 2.8331457802227566, 2.796494249786649, 3.3813983840601782, 2.681009543793542, 2.2461302621023993, 4.988944249493735, 6.262471318244934, 15.514288697923933, 28.123083932059153, 55.04169416427612, 81.16671589442662, 101.52157483782086, 96.26470674787248, 62.855356897626606, 36.71951682226998, 20.18384119442531, 18.750671012060984, 30.594269820622035, 30.15168694087437, 64.37831170218331, 61.03044727870396, 72.90333448137555, 74.1621813092913, 79.62381281171525, 73.99619579315186, 42.30460391725813, 22.931289196014404, 12.925249201910836, 8.446265816688538, 1.839881032705307, 0.30044553535325186, 0.20961111092141696, 0.18516843393445015, 0.20809949774827274, 0.22006277580346378, 0.14306882369731153, 0.09905080497264862, 0.28119150708828655, 0.19201151388032095, 0.19539334598396504, 0.17996117978223733, 0.22103534718709333, 0.20044669482324803, 0.18855293946606771, 0.1296554213123662, 0.22226166352629662, 0.16442842754934514, 0.1961479312075036, 0.2114357322986637, 0.1702926800187145, 0.12562621251813003, 0.1955676752009562, 0.2596465546105589, 0.124606102971094, 0.12047695953931127, 0.16316507676882402, 0.09202597263668265, 0.20172323632453168, 0.2612876051238605, 0.2419898792036942, 0.1957955001188176, 0.2256761874471392, 0.24055781747613633, 0.2835739792457649, 0.17295396221535547, 0.21520261945469038, 0.1128464193482484, 0.15050034278205462, 0.13634775791849407, 0.13020867162517138, 0.12601191896413053, 0.12142559220748288, 0.11970429814287595, 0.08099853007921151, 0.15562633558043412, 0.14724872154848917, 0.11623194946774415, 0.13388380727597646, 0.13159238094730036, 0.09097658430359193, 0.11444760592920439, 0.11766751243599824, 0.08931124902197293, 0.030931809318384955, 0.12257266922720841, 0.06479403496320758, 0.11511495869074549, 0.15737268115792954, 0.07653858046978712, 0.08145294498120036, 0.09497154065008674, 0.04486440634354949, 0.06693447367953402, 0.05313594838870423, 0.10934338053422314, 0.15445153361984662, 0.13173722103238106, 0.16521784876074108, 0.11034893550510917, 0.08323088993451425, 0.14124728286904947, 0.18348948045500688, 0.1482016154165779, 0.15124061091669969, 0.15658038295805454, 0.3633134604564735, 0.19769291473286493, 0.221954436440553, 0.11350391299596854, 0.08027082162776164, 0.13792172845985207, 0.12191970140806266, 0.056350891411836655, 0.14497035023357185, 0.1859655361622572, 0.19092637353709765, 0.16580113103347166, 0.1259745859674045, 0.2774856202304363, 0.09339529701641627, 0.10628710274717637, 0.0756482407450676, 0.20289229787886143, 0.16868086079401629, 0.13226229857121194, 0.11103443229304892, 0.1307937723717519, 0.09360963944345713, 0.34944396040269304, 0.1106703778994935, 0.2346164020044463, 0.10192562213965825, 0.21149118218038762, 0.11554559772568089, 0.0880965017048376, 0.2118679183934416, 1.4606363028287888, 13.281098587172371, 42.524896553584504, 81.54396833692277, 102.47121293204171, 67.62312739236015, 63.16362762451172, 79.39277131216866, 77.91987133026123, 49.36291061128889, 51.46766240256173, 45.641910552978516, 22.434202909469604, 20.41877715928214, 23.69152808189392, 29.18374729156494, 26.273270232336863, 58.37260845729283, 77.30662332262311, 70.50639356885637, 52.82191494532994, 36.61315032414028, 34.5569212777274, 27.236670970916748, 8.849032044410706, 11.231162003108434, 6.865754306316376, 7.469276138714381, 7.6697724887302945, 6.273024763379778, 8.698551433426992, 7.452671681131635, 5.092159305300031, 5.915573384080615, 3.6238559910229275, 2.249553552695683, 4.010855887617383, 3.7009788240705217, 2.375019345964704, 2.595299171549933, 3.8708687935556685, 3.6392173724515096, 4.894511716706412, 3.84305602312088, 3.049536785909108, 5.992746157305581, 7.2105686494282315, 13.979368226868765, 27.565522262028285, 46.888132504054475, 64.56883130754743, 71.34262316567558, 67.45248658316476, 36.34720802307129, 28.13194462231227, 20.02698908533369, 23.141836983816965, 56.8402874810355, 51.36347416469029, 91.007143838065, 89.67875249045235, 84.8737188066755, 80.39868981497628, 95.57429899488176, 89.08646024976457, 49.606896604810444, 25.39636414391654, 14.463585581098284, 7.8082144771303446, 1.351700708270073, 0.1573925350925752, 0.139062780088612, 0.10134565790316888, 0.17957510692732676, 0.2365702571613448, 0.14703172604952539, 0.10465262045285531, 0.23443496174045972, 0.1703508576112134, 0.11702439694532327, 0.11133393765028034, 0.16782973360802445, 0.2970373625201838, 0.22268494724162988, 0.11573416260736329, 0.21803680594478334, 0.05744183662214449, 0.139121215524418, 0.16115415681685719, 0.14414731439735207, 0.0531969113674547, 0.19666061869689397, 0.11360124205904347, 0.13907485801194394, 0.15200910610812052, 0.1895340603909322, 0.1387508711112397, 0.049301574139722755, 0.18410774799329893, 0.15232661978474685, 0.09644077931131635, 0.1364111602306366, 0.21966127306222916, 0.14232631639710494, 0.10255414234208209, 0.15387628520173685, 0.1371744849852153, 0.022056481368573647, 0.15044131023543222, 0.05430071142369083, 0.18951530568301678, 0.11355822972421135, 0.08320392495287315, 0.06954275550586836, 0.10999946282910449, 0.16213736762957914, 0.14503998149718555, 0.09464314327176128, 0.24180778754608973, 0.11951730746243681, 0.1957575428698744, 0.12995924215231622, 0.10951724834740162, 0.040505415959549804, 0.13664838964385645, 0.12263292313686439, 0.26140330891524044, 0.25606087701661245, 0.31745923097644535, 0.3343560014452253, 0.32935183282409397, 0.33409910808716503, 0.23258044411029133, 0.2601947294814246, 0.3899547266108649, 0.3511723248021943, 0.21381019774292195, 0.438178970345429, 0.29233913176826065, 0.539512149989605, 0.42823563675795284, 0.5028137192130089, 0.4852231059755598, 0.3164270163646766, 0.36618434212037493, 0.6426570724163736, 0.4698321947029659, 0.5511486998626164, 0.34534563603145735, 0.4656703323125839, 0.4837111128228051, 0.4096113975558962, 0.34399545990994995, 0.5356067738362721, 0.28115304772342953, 0.40695810850177494, 0.3995889739266464, 0.3636228181421757, 0.5540711230465344, 0.3690874677683626, 0.35498379170894623, 0.5652876326016018, 0.5502083046095712, 0.3463209079844611, 0.4268986242158072, 0.34612065872975756, 0.34815922219838413, 0.2987119326634066, 0.6433089545794896, 0.3464786266641957, 0.4832858070731163, 0.35771823355129784, 0.4805642845375197, 0.38836057643805233, 0.5899610657777105, 1.5352386768375124, 6.262909923280988, 28.05161997250148, 66.28541156223842, 101.99890913282121, 118.06212288992745, 79.35400036403111, 74.58692468915666, 91.06775992257255, 82.26091126033238, 48.43999181474958, 44.587274755750386, 44.97228486197335, 14.199372512953621, 22.817835535321915, 37.174081870487754, 97.13206427437919, 90.91252326965332, 109.78380979810441, 122.47820336478097, 122.6155275617327, 91.97801562717983, 45.23732042312622, 42.65498072760445, 36.61329623631069, 10.09737753868103, 17.85057704789298, 11.345568435532705, 9.243199876376561, 11.521754775728498, 9.158315471240453, 14.044297405651637, 11.514391422271729, 6.747396085943494, 7.9139929839542935, 6.275268162999835, 3.2957574938024794, 7.420818533216204, 8.659942030906677, 4.253949906144824, 3.2187464833259583, 4.723930835723877, 5.152558258601597, 6.3726067798478265, 5.319884777069092, 4.175591162272862, 9.760581851005554, 10.946659326553345, 24.857800585883005, 44.189966338021414, 86.68747656685966, 124.60217039925712, 149.59873172215052, 143.7033519744873, 89.28109318869454, 53.23660428183419, 27.91762743677412, 27.840729985918315, 46.89221804482596, 45.16903005327497, 89.7767081941877, 83.9231982912336, 94.70964431762695, 89.58915546962193, 102.31302329472133, 99.69266305650983, 62.437735421316965, 33.28010640825544, 21.597855193274363, 15.660041059766497, 3.4190298276288167, 0.48349311309201376, 0.3366146816739014, 0.3319239690899849, 0.4569272186074938, 0.4996908839259829, 0.4328843615949154, 0.5324191791670663, 0.4865432637078421, 0.5182252579501697, 0.33702497822897776, 0.4694073774984905, 0.37627681770495003, 0.41457097285560196, 0.4306483715772629, 0.2697952671774796, 0.44764599949121475, 0.4101272470184735, 0.3548552771764142, 0.40067889115640093, 0.3903911331934588, 0.27083128158535275, 0.4336105297718729, 0.453176955559424, 0.4093954605715615, 0.39122803828545977, 0.3944393273975168, 0.39046759051936014, 0.32340490764805246, 0.38351868625198093, 0.5560648217797279, 0.4737697605575834, 0.40741421974131037, 0.42782781007034437, 0.5854212322405407, 0.3823381167437349, 0.39107623643108774, 0.36919236928224564, 0.3489046336284706, 0.34951764930571827, 0.2951588790331568, 0.4592590449111802, 0.3563056322080748, 0.3578861031149115, 0.24304467546088354, 0.22234278917312622, 0.3970038912125996, 0.3956421528543745, 0.22564067292426312, 0.33335152534501894, 0.259946521371603, 0.45538922399282455, 0.2943562263888972, 0.2944798011864935, 0.2332433456821101, 0.23861544313175337, 0.2120225429534912], [0.07854337325053555, 0.03458673141098448, 0.019925435273242847, 0.0332347537790026, 0.1120928722832884, 0.015736836906788603, 0.024600796002362455, 0.018265233109039918, 0.02563203013102923, 0.017388499707781842, 0.013496018264309635, 0.0710812658071518, 0.047410758278731785, 0.03597115658755813, 0.03421531151980162, 0.03426751121878624, 0.018901444505900145, 0.02396501038622643, 0.045157784529562504, 0.03981942044837134, 0.03532599870647703, 0.03362375790519374, 0.054617746733129025, 0.016875559464097023, 0.0823898118521486, 0.032919167141829214, 0.07279952682022538, 0.028856516749198948, 0.050461913126387765, 0.03636167723951595, 0.07120401279202529, 0.05051028249519212, 0.04556576388755015, 0.034755001310259104, 0.0766926622018218, 0.006940692297316023, 0.055974816770425866, 0.016532870441941277, 0.08456681003527981, 0.06657324877700635, 0.026616336777806282, 0.05248210865205952, 0.014823147095739841, 0.06028767355850764, 0.0063973337528295815, 0.11349532952798264, 0.5873831212520599, 0.7108764946460724, 3.2588310752596175, 12.589108381952558, 30.631369726998464, 53.51514366694859, 77.57235717773438, 72.0639226096017, 74.56847722189767, 56.244083404541016, 28.207379477364675, 41.07320594787598, 21.226821388517106, 41.336351599012104, 52.99965681348528, 29.36259044919695, 57.05924606323242, 75.31755556379045, 98.62485694885254, 77.91954476492745, 81.4152112688337, 34.1981406211853, 17.5082688331604, 6.320564338139125, 1.4698473342827387, 0.27537632627146585, 0.02140153561984854, 0.7307636503662381, 0.019676680942731242, 0.2900738561792033, 0.12810152183685983, 0.06983930245041847, 0.05948687331484897, 0.1043335868577872, 0.1853242391454322, 0.19480703744505132, 0.1269617322832346, 0.18932148894029005, 0.09687569990221943, 0.10711510545973267, 0.19877498809780392, 0.08725195630852665, 0.06414399162999221, 0.04390116481642638, 0.03219457995146513, 0.03566641293998275, 0.07438981612878186, 0.11515557579696178, 0.12653185320752008, 0.1553067591573511, 0.20811530761420727, 0.2706574951963765, 0.46682970438684734, 0.3713579002235617, 0.3855390649821077, 4.825365849903651, 20.62218393598284, 66.21128817967006, 72.02284485953194, 88.50085912431989, 85.34020696367536, 39.973674365452354, 32.46906403132847, 24.01489724431719, 28.693758589880808, 56.09210545676095, 70.27087048121861, 60.95808179037911, 76.62098203386579, 85.55850546700614, 83.61049461364746, 77.01966272081647, 66.56659821101597, 39.64049434661865, 13.421697991234915, 2.712003069264548, 0.05512293641056333, 0.10553979141903774, 0.07506540630544935, 0.008359794854186475, 0.04680947447195649, 0.16124726539211615, 0.052800826728343964, 0.053919690261994085, 0.04119390508692179, 0.08687141351401806, 0.04737735739243882, 0.017084471914651136, 0.06328328352953706, 0.011092567500392241, 0.00794653988642884, 0.06219745786594493, 0.04189826175570488, 0.035175340183611424, 0.04409885938678469, 0.040818017042641125, 0.010498676332645118, 0.016484139753239493, 0.009060358512215316, 0.03235245808692915, 0.015190173472676958, 0.028613099096609012, 0.06808068895978586, 0.025540107295715382, 0.05938437381493194, 0.015375618789611118, 0.08426160498389176, 0.08332085689263684, 0.03379263848598514, 0.050394582096487284, 0.024488522205501795, 0.02911525572250996, 0.04078003604497228, 0.023589402237640958, 0.0899622423042144, 0.060232902211802344, 0.014492300205997058, 0.08841875834124428, 0.014098803329813694, 0.027055184390129786, 0.02717155484216554, 0.028664545621722937, 0.060283432714641094, 0.047061641833611896, 0.05134117576692786, 0.01875942203748439, 0.03493757812040193, 0.0018041908998774098, 0.021909985658047453, 0.10062740144452878, 0.023317648962672268, 0.03049056138843298, 0.019818282719435434, 0.02804870723879763, 0.0644501873425075, 0.018183031984205757, 0.05619181226938963, 0.09146726690232754, 0.04097204788454941, 0.03312715508842042, 0.049131808070732017, 0.09334735851734877, 0.04650537882532392, 0.01181425225721406, 0.014060040320535856, 0.0393711259322507, 0.06810263956763915, 0.05304219520517758, 0.02454752761072346, 0.013115220171000277, 0.038340068222688775, 0.09229365470153944, 0.03379391073914511, 0.02350375076223697, 0.027224395756742785, 0.04441768942134721, 0.0076626264157571965, 0.041569467434393506, 0.03505339047738484, 0.045780618608530076, 0.07584464270621538, 0.05866348464041948, 0.017351409287324975, 0.012188557618563729, 0.02990553867337959, 0.05051016375156386, 0.06636827691857304, 0.05472388318074601, 0.10406175215861627, 0.027842866855540445, 0.038923296212617836, 0.024346160469576716, 0.06611830461770296, 0.007533648783074958, 0.036386545547949414, 0.059960070066154, 0.21475157008639403, 0.16535111303840364, 1.4966734605176109, 8.811721955026899, 27.942455087389263, 60.28364099775042, 85.50753348214286, 84.53855855124337, 88.99966335296631, 66.65582697732108, 49.38077442986624, 63.01712485722133, 32.86091463906424, 39.437256063733784, 46.618691784994944, 38.814377852848594, 23.3468314238957, 41.27250460215977, 57.1834659576416, 63.569291251046316, 72.28859955923897, 38.90109484536307, 22.25814250537327, 8.139886736869812, 2.0368691938264027, 0.4002296466912542, 0.08144430723041296, 0.6872519137603896, 0.05294868968693273, 0.39704001641699244, 0.13683500034468515, 0.10872808497931276, 0.04830088087224534, 0.1325193547776767, 0.21412011182733945, 0.3022654205560684, 0.2384839430451393, 0.5043754896947316, 0.1994490312146289, 0.2194205288376127, 0.5614542897258485, 0.34941576048731804, 0.07118877289550644, 0.028686408020023788, 0.20128791539796762, 0.08098942413926125, 0.20747152715921402, 0.1443140847342355, 0.14233872001724585, 0.5753475385052818, 0.20465613608913763, 0.4866016720022474, 0.7620795613953045, 0.31423347549779074, 0.4971685792718615, 6.288223947797503, 23.307890244892665, 57.63425465992519, 64.52731582096645, 61.18975557599749, 51.20587165015084, 29.065987484795706, 28.02826360293797, 46.60802630015782, 43.998157841818674, 82.21480301448277, 91.06814207349504, 75.25192982809884, 87.712815284729, 101.17319910866874, 96.18794999803815, 90.09559576851981, 78.02640805925641, 43.31944738115583, 12.562697410583496, 2.1276382889066423, 0.07473773495959384, 0.18064196753714765, 0.052329529875091145, 0.05504643497988582, 0.016880358403016413, 0.05949727525668485, 0.06835037270294768, 0.039452981004225354, 0.11280589045158454, 0.03427200651328478, 0.03406402874471886, 0.035548279993236065, 0.06063295288809708, 0.05288535862096718, 0.07188813893922738, 0.0922175230724471, 0.018077165254258683, 0.011309819994494319, 0.03666810365393758, 0.0244428839401475, 0.06377310438879899, 0.017118741325767975, 0.02443415967614523, 0.047727050592324564, 0.07723661658487149, 0.03144939922328506, 0.028216815986005322, 0.04018836707941123, 0.04007663611056549, 0.034273692672806125, 0.08107075334659644, 0.028786780312657356, 0.021777499999318804, 0.03277958570314305, 0.04664334535066571, 0.03623937808775476, 0.05868156759866646, 0.01319777752671923, 0.02660955482029489, 0.0047589956832650515, 0.015844622194500904, 0.014018584375402756, 0.005773623515519181, 0.04244270807664309, 0.03108594872589622, 0.03340561568204846, 0.06606930081865617, 0.003905772672234369, 0.057675741213772974, 0.012439890382146197, 0.024121039513764635, 0.02237668713288648, 0.05338728793763688, 0.05180092056148818, 0.12926012038120202, 0.1407736111432314, 0.12361639179289341, 0.09968072974256106, 0.2722613891320569, 0.16861451363989285, 0.11924395284482411, 0.18217639305761882, 0.08817889621215207, 0.11288867850920983, 0.13979553005525044, 0.17180159262248448, 0.1860497830701726, 0.07652361198727574, 0.12259179034403392, 0.13747424818575382, 0.09696058463305235, 0.14666959191007273, 0.10311062926692621, 0.12534958736172744, 0.14015577786735126, 0.14286102913320065, 0.20407788854624542, 0.07405800571931259, 0.2108852911208357, 0.12980642249541624, 0.19625252059527806, 0.12705227599612304, 0.19345774341906818, 0.16987129620143346, 0.11182001299623932, 0.08641897314893347, 0.17934950760432652, 0.14353972700025353, 0.1666621919721365, 0.1074636010453105, 0.19372438053999627, 0.12281194781618458, 0.2245795527207, 0.19376806462449686, 0.14541515707969666, 0.20810868511242525, 0.1573250615703208, 0.20055782528860228, 0.14453611496303762, 0.19948901049792767, 0.6487916803785733, 1.4580386536461967, 5.546569321836744, 21.559323957988195, 44.26528828484671, 79.92369706290108, 102.87170015062604, 94.66168090275356, 97.61923721858433, 81.4988328388759, 54.76333195822579, 64.75267369406563, 33.784837450299946, 54.737637519836426, 67.16371944972447, 40.8011839730399, 75.62778568267822, 102.7964928490775, 133.74466569083077, 104.97168895176479, 119.34214782714844, 50.06359474999564, 27.602535315922328, 9.79226563658033, 3.086512927498136, 1.0041931782449995, 0.1604759610657181, 0.8386508268969399, 0.08809650849018778, 0.6428896742207664, 0.29254969475524767, 0.2025256718375853, 0.16756500995584897, 0.23148537001439504, 0.255636602640152, 0.3268723844417504, 0.20216850457446917, 0.25487243650215013, 0.22568283709032194, 0.2272084823676518, 0.384204305176224, 0.32474015599914957, 0.12952362267034395, 0.06493918717439685, 0.23836031396474155, 0.21413741447031498, 0.17769576848617621, 0.1853331279541765, 0.1963683193815606, 0.6412665641733578, 0.29645086399146486, 0.6588879014764513, 1.0278640623603548, 0.7552386799028942, 0.8003050216606685, 8.485580461365835, 32.806329590933665, 103.95700182233537, 107.67209938594273, 129.49115916660853, 119.96509552001953, 54.04835537501744, 52.02590152195522, 39.61090196881975, 39.61919811793736, 78.12469727652413, 95.43384116036552, 85.04729175567627, 100.7618796484811, 111.25148473467145, 110.61246585845947, 104.15936115809849, 91.08690220969063, 58.12934855052403, 22.83047604560852, 4.844500754560743, 0.20254368015698024, 0.24138511451227324, 0.15824781491288117, 0.1540598424949816, 0.12884362201605523, 0.21286913752555847, 0.12107269971498422, 0.14757435050393852, 0.17829275716628346, 0.10871625132858753, 0.12198899340416704, 0.15467105326907976, 0.1883499217884881, 0.1500223691442183, 0.20969661990446703, 0.2747730000742844, 0.16566593971635613, 0.12849676848522254, 0.13999246805906296, 0.09008731666420187, 0.12611341423221997, 0.08013978973031044, 0.13512427785566875, 0.12680090591311455, 0.14099271010075295, 0.1142420233892543, 0.1604342040206705, 0.08891272504947015, 0.1646568360073226, 0.17671855592301913, 0.23963745257684163, 0.15221616785441125, 0.19317256872143063, 0.12010441667267255, 0.13799472525715828, 0.12098021539194243, 0.13127173243888787, 0.11089508155626909, 0.18934770753341063, 0.20316707742001328, 0.10112032320882593, 0.09472524600901774, 0.12054041613425527, 0.11207316084099667, 0.10986702636416469, 0.09746796597859689, 0.18250344693660736, 0.1671916257057871, 0.13111002397324356, 0.06842537796390907, 0.11947063782385417, 0.15419195326311247, 0.1772706527262926, 0.15415069833397865], [0.027704874885135462, 0.03701372903638652, 0.03637040998520596, 0.08536815310695342, 0.05963583889284304, 0.13079359595264706, 0.012028184170568628, 0.059107178689113686, 0.04231635807082057, 0.051882473685379536, 0.06551005225628614, 0.0192482200052057, 0.03482883270563824, 0.07150916356061186, 0.0211929861855294, 0.03686180843838623, 0.040090780173029215, 0.01728471608034202, 0.05133010207542351, 0.04604375448876193, 0.045041534517492564, 0.10859009131257023, 0.04024363036400505, 0.028928383785699095, 0.0043222396551365295, 0.03738894533099873, 0.028760962055197785, 0.08494163956493139, 0.11499666289559432, 0.04516340619219201, 0.049192418211272786, 0.02568659622089139, 0.05443668644875288, 0.03701889268787844, 0.05476797777893288, 0.04578965330230338, 0.026689213135146668, 0.06268199972276177, 0.04438850223752005, 0.045381826614694934, 0.10335980768182448, 0.05082000998247947, 0.023175444986139025, 0.05368191123540912, 0.3346699188862528, 3.029075643845967, 8.47636193888528, 17.273657696587698, 26.482883487428936, 47.68834958757673, 74.47592721666608, 70.9393219266619, 70.98173373086112, 68.32027489798409, 51.39516837256295, 22.44042328425816, 13.948552097593035, 13.060938835144043, 40.81848498753139, 52.00748879568917, 58.85618918282645, 65.33822618212018, 86.6179528917585, 79.693496295384, 46.60832854679653, 21.672860997063772, 5.599200623376029, 1.2474700212478638, 0.15790457118834766, 0.13203543717307703, 0.053263041390372176, 0.025608622369223406, 0.028915250740413154, 0.12507296220532485, 0.008327257403704737, 0.08105783403984138, 0.14934964238532952, 0.044863313902169466, 0.17753245867788792, 0.18961722164281777, 0.12164967161204134, 0.09749183684055295, 0.08946174808910914, 0.2773427478969097, 0.03225090853603823, 0.07354259730449744, 0.08176841626742057, 0.11927549115249089, 0.22663942218891212, 0.21378650330007076, 0.03250081976875663, 0.06332536627139364, 0.3740181917590754, 0.45879329847437994, 0.5414593283619199, 0.2699305670601981, 0.34061630123427933, 0.5077436289616993, 0.2729346587189606, 0.40197443163820673, 0.22402073842074188, 0.04036521366132157, 0.4164974151977471, 0.14497282010103973, 4.842476223196302, 28.67323534829276, 58.53754479544503, 88.83414336613247, 79.68617984226772, 58.20573009763445, 41.372579506465364, 21.182927880968364, 20.52032855578831, 45.26573508126395, 52.6462401662554, 60.06790637969971, 69.0691170011248, 76.36712959834507, 75.69169521331787, 69.92707361493791, 54.37007781437465, 27.413992473057338, 7.082486425127302, 0.1589184517839125, 0.02999101033700364, 0.13761344285947935, 0.09755694227559225, 0.020837133584011878, 0.022152283727856617, 0.04458048015034624, 0.03859608966325011, 0.021752356884202788, 0.006165140765785638, 0.033717758754002194, 0.061696563315178664, 0.031868106219917536, 0.008268275747208722, 0.0018736393831204623, 0.06451261934957334, 0.021809131605550647, 0.03187563795862453, 0.07183354401162692, 0.011095230750340437, 0.02146262412757746, 0.09657588241887943, 0.040918311303747554, 0.023611636133864522, 0.05630104962204184, 0.007606941591283041, 0.06130437007439988, 0.03959002472194178, 0.03868888611240046, 0.034224946717066426, 0.03002961558688964, 0.03363608688648258, 0.01963869315971221, 0.06825391895004682, 0.0870636696262019, 0.023435980380911912, 0.05192323328394975, 0.012715400196611881, 0.021790035933788334, 0.016251894179731607, 0.03010746051690408, 0.025072074195902263, 0.049917147893990786, 0.025791226320766976, 0.11732922201710087, 0.015263209285746728, 0.054572027043572495, 0.024586830055341125, 0.05745103077164718, 0.02578614918248994, 0.02384801228929843, 0.03784238314256072, 0.013441949201348637, 0.03256443242675491, 0.06240554420011384, 0.018078569821747284, 0.056871453300118446, 0.06412344558962754, 0.05887845131967749, 0.037511251268110106, 0.08263437622892005, 0.03605567490948098, 0.030522981791624, 0.05779703613370657, 0.03122837661898562, 0.0013621488719114236, 0.04336699830102069, 0.041763352030622106, 0.04556973331740924, 0.04185901189755116, 0.03729847286428724, 0.08227750073586192, 0.03619805530511907, 0.06648759730160236, 0.022048746069361056, 0.042912464655403576, 0.025783565660406436, 0.03507094078564218, 0.014082653348201087, 0.022596732646759068, 0.054851291701197624, 0.1030647535143154, 0.05216333968564868, 0.03682440080280815, 0.04932634745325361, 0.03699154433395181, 0.09292205276765994, 0.05063064442947507, 0.07772313976394278, 0.048925981258175204, 0.05232198456568377, 0.03198494316477861, 0.014045201607846787, 0.035553162052695236, 0.009582496298077916, 0.023011068181533898, 0.047319546208849976, 0.22135694564453193, 1.7802468155111586, 6.375627074922834, 13.075728944369725, 24.30885468210493, 48.067151478358674, 83.31318814413888, 83.32202625274658, 86.28862912314278, 82.43007905142647, 67.44834545680455, 45.0074496950422, 23.558176517486572, 21.489614418574742, 34.973528317042756, 47.41262769699097, 55.08794832229614, 27.860916239874705, 58.420516286577495, 70.19659423828125, 52.058328764779226, 25.298297269003733, 7.941073587962559, 2.2559901901653836, 0.252435138715165, 0.0915761785581708, 0.02515133556776813, 0.021360631832586865, 0.13038038169699057, 0.0918585169794304, 0.03918540411229644, 0.08353895161833082, 0.23100331159574644, 0.15771447281752313, 0.16733795856790884, 0.45886489748954773, 0.2460073764835085, 0.4608048562492643, 0.2405668827039855, 0.7471372431942395, 0.275431749011789, 0.6452111325093678, 1.6294842596564973, 1.177149040358407, 1.0987397049154555, 0.4797941744327545, 0.239551414336477, 0.4009631701878139, 0.4280601947435311, 0.5314511539680618, 0.3697934156017644, 0.5221971848181316, 0.4021520992474896, 0.3857955512191568, 0.42451468642268864, 0.25947252394897596, 0.07429925884519305, 0.20984972454607487, 0.5471069110291344, 0.05473450564646295, 5.47315856388637, 28.691326720373972, 54.27078110831124, 60.77391283852713, 62.14344446999686, 43.82063831601824, 45.259797845567974, 34.263297353472026, 40.82822983605521, 73.76839910234723, 68.04107543400356, 71.90391254425049, 76.23961625780377, 89.39212540217808, 87.09105573381696, 82.91209643227714, 63.664474623543875, 31.02518320083618, 6.868376382759639, 0.03011820511892438, 0.02358519871320043, 0.10117645841091871, 0.11657215335539409, 0.01869781275412866, 0.04208834994850414, 0.09146548914057867, 0.08526450009750468, 0.004030285544493901, 0.04033121566421219, 0.09183955192565918, 0.03047672605940274, 0.04019257738920195, 0.07051960166011538, 0.017057038743847182, 0.05463440476783684, 0.04122646798246673, 0.06164034668888364, 0.0469502874517015, 0.007144409714133612, 0.01383671154534178, 0.024961267731019428, 0.05468550184741616, 0.06800068968108722, 0.04847342214946236, 0.04773531175617661, 0.039734179486653635, 0.024536280892789364, 0.008538046851754189, 0.02252205817161926, 0.007089148125877338, 0.06523357637758766, 0.027111397623749714, 0.01989554750200893, 0.05951197911053896, 0.032402822348688326, 0.008613534720747598, 0.02592321834526956, 0.037894457312566895, 0.02900910231151751, 0.014903411003095763, 0.022644988360947797, 0.03245351569993155, 0.06803239762250866, 0.08541540628565208, 0.020961437806753174, 0.029868958850524256, 0.039584908567901166, 0.05723363493702241, 0.12224443469728742, 0.021936155057379177, 0.01839488758040326, 0.03738164768687316, 0.16527314936476095, 0.1350269623632942, 0.13391624124986784, 0.1974049173295498, 0.10148492043039628, 0.1730710637888738, 0.14643065258860588, 0.15292588834251675, 0.17673060670495033, 0.23481252576623643, 0.12456127894776207, 0.1808908541819879, 0.14687334240547248, 0.13325933792761394, 0.14867673920733587, 0.09602516982704401, 0.2474487205701215, 0.13123666574912413, 0.16380899293082102, 0.09541181488228695, 0.20344336330890656, 0.16745880565473012, 0.16185576202613966, 0.07695250718721322, 0.11629514821938106, 0.10856548084744386, 0.0666781502908894, 0.15765298397413322, 0.33945038808243616, 0.15379354464156286, 0.1878677683749369, 0.14660693598645075, 0.1499422884413174, 0.2189770790615252, 0.12890124320983887, 0.12364617948021207, 0.15681423326688154, 0.144620361870953, 0.09248760036591973, 0.11608078543628965, 0.15557540474193438, 0.13571802313838685, 0.06963336707225867, 0.21901925679828438, 0.6532549751656396, 6.07240812267576, 13.669686147144862, 24.623163393565587, 38.99927289145333, 62.627178055899485, 100.91116864340646, 94.81055300576347, 97.56536088671002, 94.95293549128941, 77.86423015594482, 41.0475948878697, 32.47992753982544, 29.272916998182023, 62.08275195530483, 73.71594715118408, 85.01330116816929, 98.96046883719308, 126.53183800833565, 112.18653856004987, 67.31969955989292, 35.51260083062308, 8.422144276755196, 3.7053340417998175, 0.5379258436816079, 0.20029287093452044, 0.13160755299031734, 0.1510224619082042, 0.27659209817647934, 0.38833560634936604, 0.2044429810983794, 0.4537891298532486, 0.3060118838080338, 0.17672378064266273, 0.20959801519555704, 0.41902313966836247, 0.3692768876041685, 0.24010243905442102, 0.18945391183452948, 0.561758273414203, 0.1395456934613841, 0.28956205078533714, 0.6653739905783108, 0.7284762273941721, 0.7526629609721047, 0.4076456273240702, 0.21539125218987465, 0.40998076487864765, 0.8198522584778922, 0.7821259828550475, 1.20358878161226, 0.894680991768837, 0.707866296172142, 1.0871145001479556, 0.7476821882384164, 0.8549333874668393, 0.3158182076045445, 0.18331060505339078, 0.7054475088204656, 0.2505091577768326, 7.9423529250281195, 44.55788387571062, 85.08649349212646, 126.4824641091483, 106.23668493543352, 78.21062564849854, 61.779073987688335, 37.06138556344168, 33.41537741252354, 62.91540322984968, 76.56953757149833, 80.68134948185512, 90.61152730669293, 97.95703084128243, 98.20096124921525, 96.69198622022355, 77.84683881487165, 42.89520079748971, 10.44387378011431, 0.35239298215934206, 0.09485943987965584, 0.1634129998939378, 0.19176106660493783, 0.13827291104410375, 0.11444253048726491, 0.10972513112106494, 0.23920924269727298, 0.10447228620094912, 0.14019241875835828, 0.1527475014861141, 0.0795582037951265, 0.14886315991835936, 0.13319223081426962, 0.07038880046457052, 0.25404717507106916, 0.15669253122593674, 0.13635514037949698, 0.14742938828255447, 0.10854694327073437, 0.170753595286182, 0.36734604835510254, 0.1314293561237199, 0.07149228839469807, 0.13485808856785297, 0.09475334414413997, 0.12351396014647824, 0.1430216926549162, 0.09968545234629086, 0.2040078637323209, 0.1396803826625858, 0.1433633757489068, 0.08154491361762796, 0.14706509640174253, 0.1338309765394245, 0.13264299742877483, 0.07222777964281184, 0.07525472436100245, 0.09599658993205853, 0.1362075861543417, 0.13154387926416738, 0.12997795614813054, 0.09042992256581783, 0.07083303055592946, 0.18223710837108748, 0.06839111194546733, 0.10154894020940576, 0.11439173535576888, 0.17076191412551062, 0.21486236128423894, 0.16039944945701531, 0.12605896858232363, 0.09780827164649963], [0.015288633992895484, 0.027653180694739734, 0.005359244300052524, 0.03623407533658402, 0.033122914244553874, 0.03274230359654341, 0.03578147890844515, 0.04865587343062673, 0.016485898855275342, 0.011445709354510265, 0.038732889108359814, 0.03684890948768173, 0.033299869392067194, 0.04160208800541503, 0.06572159911905016, 0.013799929858318396, 0.016007743709321533, 0.053479185327887535, 0.024504791778911437, 0.02329502151613789, 0.044280791588659794, 0.10251630722944226, 0.018737418843167167, 0.04330148235229509, 0.04767678811081818, 0.09755585661956243, 0.09441772715321609, 0.1053257000499538, 0.025954797365037457, 0.04681108599262578, 0.06730811577290297, 0.023725214414298534, 0.025975311174988747, 0.03876391512208751, 0.04516189645177551, 0.024827201085697328, 0.05339046348152416, 0.02489257963108165, 0.019023518044767634, 0.05479387406791959, 0.1049965698538082, 0.07251318504235574, 0.3992355928889343, 2.35968336888722, 12.292029465947833, 25.916931867599487, 38.37853125163487, 47.09404584339687, 64.14354596819196, 63.635035106113975, 65.55647604806083, 63.60462284088135, 47.32003600256783, 25.10046468462263, 26.22788459914071, 22.336056130273, 44.68239559446062, 53.24903113501412, 41.73577226911272, 37.118051597050254, 43.492169175829204, 64.65936633518764, 28.31729129382542, 7.155431219509669, 1.2360095105000903, 0.01243901507197214, 0.044079572028879604, 0.03655045246705413, 0.0529546811511474, 0.05399896011554769, 0.11301432283861296, 0.07765960174479655, 0.08150314300187997, 0.09886522564504828, 0.06260086729058198, 0.054719666085605106, 0.16696909336107119, 0.04261652499969516, 0.1781530739473445, 0.1573081524776561, 0.21901943321738923, 0.3073538632265159, 0.22362007706293038, 0.9980480394193104, 0.4746399681482996, 1.0663239700453622, 1.8391451750482832, 0.4689942310963358, 0.02299530920572579, 0.07258983235806227, 0.11459358595311642, 0.0942145534125822, 0.061233218892344406, 0.04920873697847128, 0.04633622683052506, 0.056022945259298594, 0.08260536207152264, 0.0752243734896183, 0.11125788066004004, 0.2297908238002232, 0.26831706506865366, 0.3260508956653731, 0.30530422606638496, 0.33392640735421864, 0.10620192624628544, 0.08952671781714473, 2.665010013750621, 20.88881584576198, 43.25675031117031, 82.88943835667202, 66.78595978873116, 41.80735608509609, 31.58678524834769, 19.831977469580515, 27.01046368053981, 34.59348269871303, 39.33416911533901, 36.5061411176409, 52.2933793749128, 66.44940989358085, 66.458664894104, 59.750846181597026, 40.71613107408796, 14.906877177102224, 0.774647875555924, 0.05020577633487327, 0.033582760819367, 0.08694682589599065, 0.032920744735747576, 0.0199195608563189, 0.051392126961478164, 0.06473989465406962, 0.025664133319099034, 0.08591933388795171, 0.02494114407870386, 0.014776572452059813, 0.07400233870638268, 0.033565179977033816, 0.09896866152329103, 0.02737179391884378, 0.05433498762015786, 0.03718440434230225, 0.06098277840231146, 0.03774942723768098, 0.08188450003841094, 0.0504385002755693, 0.0596577487885952, 0.0506566323206893, 0.05610482747267399, 0.02541042907562639, 0.11330693428005491, 0.0448793612553605, 0.0699938116595149, 0.033758820300655704, 0.012964823732285627, 0.0645291552479778, 0.013115411008974271, 0.005226849819467003, 0.02783095178061298, 0.013022545858153274, 0.012584720289201608, 0.047035321460238526, 0.038224700306143077, 0.01850139891861805, 0.012824188867983009, 0.009734149722914611, 0.05272543809509703, 0.027972421242988536, 0.04838356375694275, 0.10766279857073512, 0.029239149431564977, 0.024887590702357035, 0.038381316366472414, 0.019513337207692008, 0.035724336081849675, 0.031231019512883255, 0.030387274787894318, 0.027993586446557726, 0.03844627930915781, 0.03544118341856769, 0.06307970266789198, 0.040205215103924274, 0.055799914191343954, 0.05494627642578312, 0.04673503239506057, 0.015123395448816674, 0.009916585737041064, 0.06036227848380804, 0.04685956731970821, 0.007112141133153013, 0.012313704921065696, 0.038894170096942356, 0.02377294935286045, 0.05891642213932105, 0.0581206294841, 0.0036721848716427174, 0.051098141486623457, 0.03083526057058147, 0.025696523188214217, 0.07838384288230113, 0.032792966413710795, 0.03399028895156724, 0.026365590947014943, 0.08913703515593495, 0.0468733280098864, 0.02548890165053308, 0.07232242170721292, 0.017889650405517647, 0.019488876020269733, 0.010319841643130141, 0.05398639703967741, 0.10041198693215847, 0.03374326488535319, 0.03270831238478422, 0.0035701056393528624, 0.04721375920676759, 0.03438136939491544, 0.06929850325520549, 0.18619790726474353, 1.128114517245974, 9.167296886444092, 22.1843352658408, 34.64066791534424, 47.02557829448155, 69.90709059579032, 74.30379254477364, 79.87573364802769, 77.75538662501744, 61.207494327000205, 44.376264912741526, 39.18031862803868, 26.773153168814524, 38.42166914258684, 34.70262152808053, 36.53858920506069, 32.13462291445051, 43.581866945539204, 62.8440591267177, 33.893844263894216, 11.734589389392308, 2.034531125000545, 0.24401660902159555, 0.09312232237841402, 0.1350237868194069, 0.05997344399137156, 0.02143189836559551, 0.15434690351997102, 0.1882467030414513, 0.35850229433604647, 0.3398813121020794, 0.5182163012879235, 0.24884690982954843, 0.5360042325087956, 1.1074639282056262, 0.9869273390088762, 0.9975212791136333, 0.8410517009241241, 1.2388946413993835, 1.5943524305309569, 2.6879994315760474, 3.183791399002075, 3.09861929501806, 3.9970498170171465, 2.665003934076854, 0.4767009232725416, 0.6078375322478158, 1.6134360922234399, 1.2506268918514252, 0.14542380161583424, 0.1517227507595505, 0.1735372580587864, 0.33547232725790566, 0.8704562059470585, 0.6126284237418855, 0.8561706553612436, 0.755563562469823, 0.2894147272620882, 0.20191708020865917, 0.38643698394298553, 0.08664136978664569, 0.16357772105506488, 0.17966632917523384, 2.33828313435827, 20.43069158281599, 43.092679023742676, 64.44140829358781, 44.75413574491228, 31.531706878117152, 23.867152486528667, 27.165667329515728, 45.75495774405343, 61.91316032409668, 59.892214230128694, 55.28094148635864, 66.51286084311349, 77.55973924909318, 79.9927760532924, 73.32996777125767, 49.947365283966064, 15.802341903959002, 0.6717115076524871, 0.05422183512044804, 0.008692309243737586, 0.12301598329629217, 0.03129095111840537, 0.031494172356490574, 0.027824809342356663, 0.11448537318834237, 0.05247616468529616, 0.026621893979609013, 0.05223435516070042, 0.025987088846574937, 0.0195371877135975, 0.015039374153794987, 0.03891937428021005, 0.02322537498548627, 0.0338699711220605, 0.028860313152628284, 0.05417073464819363, 0.037662442440965345, 0.03818418498017958, 0.0308881082705089, 0.02296910757598068, 0.050985070411115885, 0.05177504462855203, 0.026956484686317186, 0.06630103409822498, 0.01652224627988679, 0.03082623266215835, 0.053518625175846476, 0.02868322908346142, 0.04138223248134766, 0.10946873987891845, 0.015132708341947623, 0.018032680498436093, 0.037075526613209925, 0.010593099569502686, 0.0661817883540477, 0.033761873708239624, 0.027114481565409472, 0.03495926749227302, 0.024818505659433346, 0.068352822214365, 0.015254795451515486, 0.04638656734355858, 0.06501734762319497, 0.025583742186427116, 0.02500776943218495, 0.013913398724980652, 0.05614329023020608, 0.01487808977253735, 0.03203405213675328, 0.08391825947910547, 0.10805481539240905, 0.1622518907700266, 0.21897028014063835, 0.15224324140165532, 0.132224314180868, 0.09071160280810935, 0.10374372279537575, 0.12371339515915938, 0.07121624677841153, 0.15661300692175115, 0.1799422079431159, 0.14315792891596044, 0.13497604509549482, 0.1799945772758552, 0.20008305433605397, 0.13634068758359977, 0.22762917407921382, 0.14436740401600087, 0.2013164952929531, 0.18913067132234573, 0.14185419173112937, 0.06897452992520162, 0.18447060137987137, 0.1664813081068652, 0.2771179628159319, 0.2174269658114229, 0.2661443145147392, 0.10294358073068516, 0.1173900051840714, 0.15758738320853027, 0.07504390353070838, 0.13707425179226057, 0.09594144539109298, 0.11907501119588103, 0.1927837545850447, 0.22856986788766726, 0.16373727177934988, 0.15334743500820228, 0.12596033673201287, 0.26715636306575363, 0.13704755822462694, 0.3904743215867451, 5.5986703889710565, 20.4446314062391, 38.18666022164481, 51.69330167770386, 65.28254331861223, 84.15806824820382, 92.38369315011161, 92.21219771248954, 93.36854471479143, 74.78339890071324, 42.57199491773333, 43.61080619267055, 35.200616291591096, 65.10369668688092, 80.65040915352958, 62.16592884063721, 56.888671261923655, 63.46029485974993, 93.22343853541783, 40.881248065403526, 14.80635585103716, 3.049060400043215, 0.47101121715136934, 0.22968147109661782, 0.19883202575147152, 0.11566222432468619, 0.21022209099360875, 0.27365097456744736, 0.17083902284502983, 0.331316843096699, 0.20206961488085134, 0.2509876878133842, 0.1828942966780492, 0.25475977254765375, 0.6392730282885688, 0.6172272084014756, 0.49873186967202593, 0.2985022653426443, 0.627615036708968, 1.0344500860997607, 1.7070497146674564, 2.5068889898913245, 3.1860011432852064, 3.8062596661703925, 0.7767968773841858, 0.16905949690512248, 0.168003167158791, 0.47085102860416683, 0.4623800345829555, 0.12107336467930249, 0.08596711632396493, 0.0778539070327367, 0.14915473998657294, 0.4131481392042977, 0.22501680068671703, 0.5424855990069253, 0.6981672080499786, 0.506473248558385, 0.5577191444379943, 0.7906895290528024, 0.6398665021572794, 0.23967735043593816, 0.230545273316758, 5.108748563698359, 31.382282393319265, 64.8147975376674, 117.51135308401925, 89.86050346919468, 57.731644085475374, 47.9446964263916, 29.217876843043737, 41.950523717062815, 50.72618886402675, 59.427998134068076, 58.528658049447195, 78.48840073176792, 93.59916237422398, 91.76419176374162, 90.23988206045968, 61.59392533983503, 19.419105087007793, 0.8558306821755001, 0.13117147210453237, 0.0722232266728367, 0.17129332918141568, 0.12616317799048765, 0.11533202204321112, 0.1495610060436385, 0.1316379920712539, 0.09477815816977195, 0.2144202957195895, 0.14180464510406765, 0.13004532110478195, 0.08543075474777392, 0.10482153496039764, 0.23347510610307964, 0.1870617637676852, 0.11583769348050867, 0.12464077611054693, 0.19990632310509682, 0.1277922455753599, 0.17178700411958353, 0.20947182125278882, 0.17123075468199594, 0.20646178562726292, 0.12602899090519973, 0.18021886024091924, 0.23893500598413603, 0.15436363619353088, 0.10724053944328002, 0.12749504723719188, 0.11970762296446733, 0.17157703824341297, 0.20568195890103066, 0.11666732467710972, 0.10007248872092792, 0.08605538015919072, 0.10761191522968666, 0.1378707026264497, 0.10651552477585417, 0.0862316567716854, 0.07299183042986052, 0.06782439949789218, 0.25857031664678026, 0.10480269882827997, 0.16869046884988034, 0.2646102825445788, 0.09586188716015645, 0.13287524639495782, 0.083647496865264, 0.12493478533412729, 0.1464199453060116, 0.1133495055671249], [0.03637616735483919, 0.06145602943641799, 0.05033113567956856, 0.03793883689546159, 0.03903719510084816, 0.030349307360925844, 0.05653973788555179, 0.05705824720540217, 0.04373095430699842, 0.04158748593181372, 0.06619453802704811, 0.004314757958387158, 0.0040442438579962724, 0.02109339929717992, 0.039505815133452415, 0.034049314712839465, 0.02159644989296794, 0.04229660591642771, 0.03525345652763333, 0.03407087516305702, 0.018100623906190907, 0.021839375607669353, 0.0556325128168932, 0.014071368462672191, 0.08285485261252948, 0.06160966333534036, 0.01551984140782484, 0.027716164011508226, 0.006814388940776033, 0.03399703358965261, 0.09049748429762465, 0.05512459882135902, 0.03624902685571994, 0.0409147727436253, 0.062339488816048415, 0.03883458793695484, 0.01360534637102059, 0.040457056768770726, 0.05972040471221719, 0.0929265378841332, 0.09252241599772658, 1.7334348474230086, 13.83196827343532, 31.411895615713938, 41.89672381537301, 56.121329580034526, 64.06499658312116, 69.18725722176688, 59.89404855455671, 49.71105704988752, 51.538124084472656, 30.220936162131174, 33.981832776750835, 29.170615196228027, 45.98336935043335, 72.46618856702531, 47.03152942657471, 36.56604848589216, 31.113960334232875, 36.17446190970284, 25.997918333326066, 6.568900338241032, 0.1824421752244234, 0.020703423169574568, 0.037910128078822575, 0.12503801765186445, 0.06755893624254636, 0.012452423772109407, 0.14783866703510284, 0.07472116513443844, 0.04389631329104304, 0.04744156037590333, 0.4635062398655074, 0.462149658373424, 0.4382627015667302, 0.034184441569128206, 0.752303554543427, 1.3491334574563163, 0.8177810981869698, 0.959995687007904, 0.6023867247360093, 1.8830973080226352, 1.7280249148607254, 2.404063901730946, 3.4228608906269073, 2.2670586705207825, 4.829671127455575, 6.366816324847085, 4.006576665810176, 3.5583123309271674, 1.6404536196163721, 2.845420207296099, 2.7617658504417966, 1.951914438179561, 1.541794519339289, 1.6316885756594794, 0.29024104720779825, 0.6133469651852335, 0.18294617746557507, 0.34198441782167976, 0.15761263828192437, 0.012596490327268839, 0.1430446949920484, 0.09884933435491153, 0.15245326156062738, 0.10999102185347251, 0.21514365476156982, 0.2906006707676819, 1.3351024389266968, 13.455536586897713, 67.64310346330915, 80.81012739453996, 71.2145609174456, 67.09700979505266, 28.329645190920147, 12.270589062145778, 30.871975421905518, 35.22842993055071, 36.779118469783235, 52.11621420724051, 46.220160484313965, 69.86809035709926, 61.00722639901297, 45.54459408351353, 10.898255569594246, 2.2238936381680623, 0.5182978340557644, 0.04864527132096035, 0.050673738188509426, 0.02999668288975954, 0.1415450783180339, 0.10415413470140525, 0.1510271437998329, 0.06488088066024439, 0.051839013517435105, 0.04933911408962948, 0.06702968571335077, 0.03214350322793637, 0.04366627634902086, 0.059060183353722095, 0.03400087749053325, 0.032068012814436636, 0.03132415183686784, 0.07323581126651593, 0.03670080225648625, 0.0526353354299707, 0.015613757439755967, 0.010736395139247179, 0.035377105964081626, 0.016905649099498987, 0.04536997600059424, 0.030260358205331222, 0.02787788095884025, 0.04300572929371681, 0.03532162215560675, 0.03414544955428157, 0.025477717697088207, 0.02705152708637927, 0.023438222939148545, 0.04180769768676587, 0.03359072342781084, 0.007734727546838778, 0.01838675024919212, 0.08683668609176363, 0.03650052586038198, 0.05775607975998095, 0.03169637579204781, 0.02215594272794468, 0.07065419586641447, 0.04026510599734528, 0.023698059442852224, 0.047454194697950564, 0.01757940892795367, 0.0321458984565522, 0.05231554866103189, 0.018480274427149977, 0.05113895536799516, 0.048730844764837196, 0.021878601717097417, 0.07947844200368438, 0.07582898890333516, 0.008782038714603653, 0.0348499860348446, 0.0332910314734493, 0.07275853651974883, 0.07283385390681879, 0.014464368311954396, 0.03914585230605943, 0.038792793572481186, 0.03787826746702194, 0.04483877129054495, 0.020493140078282783, 0.016768741088786294, 0.005594472459051758, 0.02855386977483119, 0.02121684856579772, 0.0532873261586896, 0.08709481438355786, 0.04697233644713249, 0.021319395563166057, 0.07782382079000984, 0.05512836469071252, 0.04487420778189387, 0.03957430985090988, 0.07089033283825431, 0.05318596999027899, 0.034789491245257, 0.0236837881550725, 0.017532277885558348, 0.051657461295170445, 0.01622160946551178, 0.03875397119138922, 0.014151049678080847, 0.015814127134425298, 0.04978784965351224, 0.053928762275193415, 0.05765176857156413, 0.7088519632816315, 10.656590274402074, 26.95703203337533, 42.417647634233745, 59.965344020298545, 71.75458186013358, 77.10718223026821, 72.58599635532924, 68.4159515925816, 70.21554892403739, 48.41121932438442, 47.51786511284964, 27.95237190382821, 46.10946178436279, 45.293507031032014, 49.47731270108904, 44.19258233479091, 35.01132651737758, 47.80691017423357, 31.729258060455322, 7.883393117359706, 0.4232790470123291, 0.08093793011669602, 0.05920341531080859, 0.04730662350941982, 0.07695161830633879, 0.12957430923623697, 0.41520876863173073, 0.330343633890152, 0.5541924993906702, 0.6436275403414453, 1.4295908829995563, 1.4604729115962982, 2.7944084874221256, 3.0563768531594957, 2.1803049828325, 2.779970347881317, 3.818566228662218, 4.409966494355883, 5.386364706924983, 9.324142915861946, 6.968400478363037, 6.979646137782505, 7.082185047013419, 7.7475966555731635, 14.298704828534808, 9.987072280475072, 10.440558620861598, 10.339068021093096, 5.087758490017482, 4.758542852742331, 4.053070536681584, 2.2874887628214697, 2.2128401398658752, 1.6671555468014307, 1.7668861895799637, 2.1238877815859656, 1.1955958562237876, 1.4455612088952745, 0.4104990842086928, 0.2001115120947361, 0.5466506097997937, 0.2805540370089667, 0.13837618407394203, 0.08512130885251931, 0.10314296146056481, 0.28323452174663544, 1.6576473712921143, 13.430161765643529, 49.010258265904014, 55.787308829171316, 50.2257205418178, 31.6035338810512, 35.77961662837437, 21.05525299480983, 35.54402405875069, 47.903580461229595, 50.76262869153704, 66.01951095036098, 56.775752612522666, 82.3522800718035, 77.79727036612374, 56.338151591164724, 14.074532491820198, 2.507847624165671, 0.37624527939728325, 0.06553485949656793, 0.03215738944709301, 0.03120867196204407, 0.056657918329749785, 0.01815058443961399, 0.02563316498084792, 0.06227280917976584, 0.02441258735156485, 0.07691284003002302, 0.018909045794446553, 0.04788106447085738, 0.05997877727661814, 0.01617322482966951, 0.0578156958467194, 0.03475892324266689, 0.028633726561175923, 0.06103412314717259, 0.012820306799507566, 0.0719617735594511, 0.054663412139884064, 0.028497300310326473, 0.040142304729670286, 0.02806048999939646, 0.01923299876839987, 0.0007035430098767392, 0.011704163343113447, 0.08493393140711955, 0.02528998232446611, 0.003932532821116703, 0.018009922433910624, 0.020509000834343687, 0.02285301871597767, 0.030319180406097854, 0.040775255765765905, 0.02705870259420148, 0.059852318705192635, 0.03767036094463297, 0.03194977808743715, 0.03446670874421086, 0.039304649856473715, 0.008781217687231089, 0.05039927077346614, 0.008630628714204898, 0.08674509743494646, 0.033735984204603095, 0.03279713601140039, 0.03719929479328649, 0.044505607203713486, 0.057700738443859985, 0.22771219962409564, 0.13977157776909216, 0.11006908052201782, 0.09789642013077225, 0.19649669820708887, 0.2648306707186358, 0.11153331159480981, 0.10039268939622811, 0.16767816245555878, 0.12664807268551417, 0.15483833929257734, 0.08032652256744248, 0.18206671465720448, 0.09262625221163034, 0.11778024424399648, 0.2130401147795575, 0.08038917170571429, 0.1980639241103615, 0.1795714156968253, 0.12767097779682704, 0.07683442852326802, 0.15326276740857533, 0.19912166520953178, 0.0999491989080395, 0.19766160712710448, 0.11909430873181139, 0.11338202775056873, 0.09199237836790936, 0.15687417505042894, 0.1670291301395212, 0.15056264586746693, 0.15924231654831342, 0.18928733148745128, 0.16129379932369503, 0.16642228913094315, 0.15087538265756198, 0.10240915976464748, 0.172148839703628, 0.12171192041465215, 0.19205852278641292, 0.14894813964409487, 3.397166452237538, 23.17289890561785, 47.56917755944388, 59.9354042325701, 77.44068881443569, 83.7792385646275, 91.33440399169922, 84.44936452593122, 78.1155812399728, 80.59224578312465, 49.117896284375874, 50.88010883331299, 43.40397916521345, 61.49253027779715, 98.95713370186942, 70.75389535086495, 54.8378791809082, 51.17307962690081, 56.16133730752127, 44.880485262189595, 10.386461683682032, 0.8341067593012537, 0.3649316036275455, 0.20140819251537323, 0.24156826468450682, 0.30497652079377857, 0.25644769626004355, 0.2632003410586289, 0.26510846295527046, 0.25863901153206825, 0.4356412765170847, 1.5078972982508796, 1.9743288925715854, 2.476900781903948, 1.9172381503241402, 2.7929102821009497, 2.829132761274065, 3.0012689530849457, 3.9462076766150336, 3.9248215556144714, 10.470098887171064, 7.714276569230216, 9.222376993724279, 12.623045120920453, 12.401565211159841, 20.75751052583967, 19.46070221492222, 16.03471224648612, 11.277652399880544, 4.511227369308472, 6.2375828708921155, 5.559420449393136, 4.969082823821476, 4.4617427332060675, 4.282243405069623, 1.8773531019687653, 1.943965698991503, 0.7176696072731699, 0.7238690831831524, 0.17893858679703303, 0.14673270923750742, 0.3294101868356977, 0.28069994917937685, 0.30211986122386797, 0.16814986642982277, 0.320007998496294, 0.5687898503882545, 2.9293455438954488, 21.239713771002634, 104.22625841413225, 115.23811095101493, 98.67204911368233, 93.5979255948748, 42.334022590092246, 19.878751005445206, 42.39332546506609, 49.1662140573774, 56.438806670052664, 74.62302058083671, 71.29026848929269, 100.9317353112357, 96.13320514133999, 72.91310364859444, 21.73724126815796, 2.9159166301999773, 0.5934487357735634, 0.16566633326666697, 0.11630766040512494, 0.10860666113772563, 0.15975884454590933, 0.17184891365468502, 0.28213613639984814, 0.16133567850504602, 0.12177327355103833, 0.1870798942233835, 0.21544877838875565, 0.13226734687175068, 0.12304802371987275, 0.14480530337563582, 0.09973391331732273, 0.19115479556577547, 0.22248544437544687, 0.14175862685910293, 0.08861174048589808, 0.13111865493868077, 0.14620655961334705, 0.1889552700200251, 0.1643216804202114, 0.10786344137574945, 0.08901274111121893, 0.16127025415854795, 0.10187848431191274, 0.21570400255067007, 0.11074440607002803, 0.13226681761443615, 0.07620237315339701, 0.17940490320324898, 0.12096600686865193, 0.15545387912009442, 0.07534458953887224, 0.2229723475341286, 0.16424860219870294, 0.14909049629100732, 0.16117705058838638, 0.16765623220375606, 0.16357420624366828, 0.0950033368010606, 0.18214478689645017, 0.07534942749355521, 0.1748702943857227, 0.09502463601529598, 0.09396101201751403, 0.14420113579503127, 0.1400045459823949, 0.16590930308614457], [0.06448154923106943, 0.044460766217006106, 0.08744905716074364, 0.02128051041758486, 0.08299155027738639, 0.061614216305315495, 0.02743556603257145, 0.0418000030996544, 0.04247429048908608, 0.044627855465348275, 0.056815983062343936, 0.02964828908443451, 0.03253372871716108, 0.07688165456056595, 0.07623404038271733, 0.03304236535249012, 0.044257989419358115, 0.04636701874967132, 0.054000714128570895, 0.0928133243162717, 0.03614620505166905, 0.01851430974368538, 0.0666020865152989, 0.041001112932073216, 0.046574005857110023, 0.011937610771773117, 0.05244565775085773, 0.06241052464715072, 0.05783287635339158, 0.01649812944898648, 0.0232618564207639, 0.04179610152329717, 0.041283522599509785, 0.07281258861933436, 0.11469506765050547, 0.07488988965217556, 0.06015900296292134, 0.03103873965197376, 0.0601463754262243, 0.15688100111271652, 6.643744162150791, 25.959668500082834, 50.14976283482143, 69.12416063036237, 66.18132754734584, 67.31937299455915, 61.158377511160715, 41.942366531917024, 35.58953128542219, 23.00685259274074, 14.373005390167236, 23.437390770230973, 24.96722255434309, 45.29310056141445, 49.01124838420323, 56.10557801382882, 46.03155163356236, 28.568972417286464, 16.07833824838911, 2.740699997970036, 0.20868571129228386, 0.08848749393863337, 0.03301142415563975, 0.03853478402431522, 0.05819511905844722, 0.05535732954740524, 0.034203111460166316, 0.058396562534783564, 0.026410311493756514, 0.16269094363919326, 0.12491832407457487, 1.2003577607018607, 0.5460312430347715, 1.5244651692254203, 3.1507909297943115, 2.949590640408652, 2.626102924346924, 2.073915034532547, 1.3525576165744235, 4.289258914334433, 5.003114231995173, 7.1009503943579535, 4.302993765899113, 4.406326941081455, 6.261152029037476, 4.965846266065325, 5.649733568940844, 11.759872147015162, 6.845271016870226, 11.69595045702798, 14.715421301977974, 12.276695660182408, 5.078340206827436, 1.2550482260329383, 3.112652050597327, 1.0261869409254618, 3.0259139963558743, 3.049113814319883, 1.9937912310872759, 2.5101568145411353, 1.2635894077164787, 0.4762765946132796, 0.353826210967132, 0.17098706561539853, 0.029269999026187828, 0.11150739155709743, 0.22619074769318104, 0.08312532345631293, 0.031171756264354502, 0.1941515047635351, 0.12196229983653341, 12.410568339484078, 47.94736106055123, 73.50789029257638, 99.33115523202079, 75.6434816632952, 85.74381392342704, 44.30494165420532, 18.081351041793823, 26.457769223621913, 35.7725259917123, 52.16209316253662, 48.5545780318124, 62.79499094826834, 53.97232471193586, 26.85895299911499, 10.36937519482204, 1.239353005375181, 0.2465173905449254, 0.030035142254616534, 0.04859999267916594, 0.09331071762634174, 0.10078519476311547, 0.01822825973587377, 0.06716212896364075, 0.021807336880426322, 0.042524658143520355, 0.04227167993251767, 0.024454023788816164, 0.029932313665215458, 0.04743695312312671, 0.0632230703319822, 0.020105264016560147, 0.06363291905394622, 0.03989092107596142, 0.01042434197318341, 0.019753506373880163, 0.056772356653319936, 0.0902189863845706, 0.03173176139327032, 0.026533567379894, 0.03834795279960547, 0.037549110129475594, 0.01670263990360711, 0.034239399512963634, 0.037480510239090235, 0.019454949269337312, 0.05157193874141999, 0.021709950141874806, 0.028452384684767042, 0.040454362984746695, 0.04144871873514993, 0.053612452998225174, 0.006751408592598247, 0.04721436649560928, 0.026910271362534592, 0.019753404593627368, 0.012699454623673643, 0.0977564247857247, 0.045290441518383365, 0.037662764745099206, 0.03164698522804039, 0.03580986542095031, 0.0340955331256347, 0.03580583153026445, 0.04137194249778986, 0.06952132058462926, 0.07521321158856153, 0.025156885984220674, 0.020880941501153365, 0.023272192205435464, 0.02521004750659423, 0.018769187852740288, 0.016808170758719956, 0.029758340679109097, 0.031890681079987965, 0.021988794107788374, 0.025763187557458878, 0.012418402874443148, 0.07680206918822867, 0.0444907405014549, 0.050699464843741486, 0.06430903848792825, 0.039245311969092915, 0.10416970029473305, 0.04034968878009489, 0.014883504481986165, 0.05273145330803735, 0.02740970706301076, 0.048976586399866004, 0.060761338498975546, 0.019943128073854104, 0.08825560459601027, 0.01647566824353167, 0.07030789194894688, 0.041893929309610806, 0.02068765231940363, 0.017770484389205064, 0.0320627100632659, 0.05560593460021274, 0.004597260500304401, 0.031821745314768383, 0.08069131656416825, 0.13115076321576322, 0.06504256876983813, 0.1511154483471598, 3.892271850790296, 23.037792921066284, 50.23666048049927, 73.58923285348075, 72.23218713487897, 75.10997813088554, 77.00814955575126, 62.01413154602051, 60.77064718518938, 38.060262066977366, 33.839175837380544, 34.24476650782994, 38.66296965735299, 44.94118472508022, 42.41947153636387, 42.99741922106062, 44.2479247365679, 36.77329935346331, 22.36353972979954, 4.913709589413234, 0.08409286011010408, 0.02038956679669874, 0.03030293288507632, 0.023917309374415448, 0.1398399876696723, 0.18063093455774443, 0.5385312597666467, 0.248587682311024, 1.0551747168813432, 1.3800582609006335, 2.802693997110639, 3.5152958163193295, 2.922030393566404, 3.0057034237044196, 2.1586242147854398, 1.3241978926318032, 2.002392666680472, 1.7053172247750419, 6.761804478509085, 9.147530998502459, 9.35097599029541, 14.523815172059194, 10.824740154402596, 13.665903721536909, 14.818596839904785, 15.918151003973824, 11.4097124678748, 9.608528341565814, 8.752403446606227, 8.066872460501534, 4.6205538000379285, 1.0533874013594218, 2.283620136124747, 2.6096063809735432, 0.6211532663021768, 0.9904587609427316, 1.4416201689413615, 2.396409158195768, 1.2131058595010211, 1.4464111690010344, 1.4207508202110017, 0.9716329425573349, 1.267033868602344, 0.6810241022280284, 0.30841794184276033, 0.16500561657760823, 0.08597583549895457, 0.06380097860736506, 0.11327186080494098, 0.16164899883525713, 0.6572009005716869, 12.550331354141235, 44.8806277002607, 64.46477508544922, 60.608010700770784, 32.56650556836809, 78.53195204053605, 49.96568073545183, 31.745885099683488, 46.1049975667681, 52.370858737400596, 69.76571559906006, 63.498364039829795, 79.12540463038853, 71.2160895211356, 33.30016238348824, 11.887729423386709, 1.478148694549288, 0.18876059832317488, 0.05669791457642402, 0.11549991874822549, 0.04685031210205384, 0.19359847158193588, 0.07023279169308287, 0.1096322736037629, 0.09727086512637989, 0.030291519926062653, 0.027433985045978, 0.022740982406373535, 0.051838436762669256, 0.024189698775964122, 0.042268568849457164, 0.05303799168073705, 0.051091905749802075, 0.06038524689418929, 0.01887994003482163, 0.05359170000467982, 0.031693729505475075, 0.06596580387226172, 0.03726850197251354, 0.024864316951217394, 0.048470711402062855, 0.044096335236515315, 0.06272272539458104, 0.0474927829844611, 0.04918487290186541, 0.016963433141687086, 0.0361464289682252, 0.01695510751700827, 0.06074202060699463, 0.05531998297997883, 0.05510871431657246, 0.039463182778230736, 0.024505241308361292, 0.0758659690618515, 0.034723965118506124, 0.019007682733769928, 0.04570271600303905, 0.008761010066206967, 0.06712054833769798, 0.041593765773411305, 0.10681956274701015, 0.0670718973768609, 0.03303522716409393, 0.026768522004463842, 0.01258882797057075, 0.14779467082449368, 0.14762164439473832, 0.17217334838850157, 0.12195261035646711, 0.11873138749173709, 0.11648056469857693, 0.13562810367771558, 0.10756986641458102, 0.1384288655327899, 0.1384694283562047, 0.10843162624431507, 0.1374532136001757, 0.1179416405835322, 0.17957248778215476, 0.264941326209477, 0.16246349870094232, 0.14070790181202547, 0.1477493175438472, 0.1544802492218358, 0.13271581780697617, 0.15186244754918984, 0.09160441240029675, 0.1726018703941788, 0.1594104575259345, 0.12020143360963889, 0.22031715858195508, 0.21663654036819935, 0.16110515301781042, 0.12866401379661901, 0.13367310858198575, 0.05927458006356444, 0.20572648436895438, 0.15315842229340756, 0.24667730767812046, 0.2292524469750268, 0.14983688481152058, 0.15668493163372788, 0.24561265909246036, 0.21314717403479985, 0.42800694331526756, 12.747773970876422, 40.042141914367676, 69.43944208962577, 88.87263638632638, 91.05682345799038, 89.44876016889299, 86.84588159833635, 65.51058319636753, 60.591633796691895, 42.77752958025251, 28.312139204570226, 35.43990182876587, 36.2254547391619, 60.275601931980674, 65.11420236315045, 75.64096641540527, 67.11902863638741, 47.81455666678292, 26.673001834324428, 6.27134416784559, 0.33600324019789696, 0.18660771527460643, 0.12078341309513364, 0.2010908823992525, 0.3339803101761, 0.13904463606221334, 0.3232798943562167, 0.1531466700668846, 0.5671451900686536, 1.198010680930955, 2.371614294392722, 3.9244459186281477, 3.463581676994051, 5.952486991882324, 8.516711865152631, 10.842019455773489, 10.674022436141968, 8.719607080732073, 10.544370787484304, 10.57703079496111, 14.553982513291494, 21.251445804323467, 17.18175039972578, 17.63219690322876, 21.470036131995066, 15.78579476901463, 19.542235851287842, 30.308969838278635, 22.197319711957658, 29.478062561580114, 38.58313832964216, 32.42664875302996, 26.223015648978098, 14.215960468564715, 13.589134812355042, 14.578519208090645, 18.320983988898142, 13.133152331624713, 9.793894120625087, 6.728215149470738, 2.9920360999447957, 2.1437285797936574, 0.8359819586787904, 0.653502341892038, 0.32502486929297447, 0.25130095386079376, 0.41509219631552696, 0.23694193150315965, 0.17190983252865927, 0.49508357686655863, 0.625721815441336, 21.886995792388916, 71.0504583631243, 104.2747915812901, 125.75555746895927, 103.08580889020647, 98.34892313820976, 56.54444013323103, 29.15070513316563, 41.58782427651541, 54.36302191870553, 78.49227782658168, 76.98129476819719, 96.4852842603411, 88.96651349748883, 46.06210633686611, 16.261562245232717, 2.414582823004041, 0.28078620455094744, 0.13637502145554337, 0.16617648303508759, 0.14777668964649948, 0.3057381084987095, 0.17161940596997738, 0.16431068815290928, 0.2626303445015635, 0.1971143822052649, 0.20243850722908974, 0.07805264993969883, 0.12451682133334023, 0.17617500866098063, 0.1597859180931534, 0.135620151247297, 0.11284076036619288, 0.18387081713548728, 0.09003059792199306, 0.18107196874916553, 0.1528669779321977, 0.2567293697169849, 0.15895226996924194, 0.11685143836906978, 0.13889012006776674, 0.10258143980588232, 0.10099195116864783, 0.060117890526141436, 0.16867440114063875, 0.09972338923918349, 0.1161486796502556, 0.11406730062195233, 0.1422889291175774, 0.12732774764299393, 0.17481189966201782, 0.12351139528410775, 0.0769677742251328, 0.14758019947579928, 0.08617976919880935, 0.15881587085979326, 0.16197655483015946, 0.14620901591011456, 0.0987716828073774, 0.1041472814977169, 0.16160568115966661, 0.18640171204294476, 0.14842596623514379, 0.14939080231956073, 0.1327182605330433], [0.016993716159569364, 0.01953190701481487, 0.07173051525439535, 0.0276684833557478, 0.021568633349878446, 0.05039776781839984, 0.009994893767205732, 0.03515626995691231, 0.057487060981137414, 0.027827104487057244, 0.011262073181569576, 0.015236488576712353, 0.0398451437109283, 0.031470759505672116, 0.06618402751960925, 0.052724600104349, 0.06796335668436118, 0.03348856319540313, 0.030931727894182717, 0.030698315240442753, 0.01073959528002888, 0.009513529150613716, 0.027286476621936475, 0.044546139493052445, 0.03056220450837697, 0.08177364098706416, 0.02298224062126662, 0.019195185708148137, 0.05789189532931362, 0.049958660666431697, 0.055460711142846515, 0.030095670970955064, 0.04527176484199507, 0.08326890146625893, 0.029169697979731218, 0.00818802201787808, 0.024296283056693416, 0.05777355882206133, 1.6675297724349158, 16.6214302948543, 40.758640153067454, 58.17781570979527, 71.15569577898297, 72.82334681919643, 72.21042537689209, 58.57136862618582, 34.198175362178254, 33.04688664845058, 17.999542951583862, 13.704860533986773, 20.401140894208634, 30.09206097466605, 34.9514365196228, 64.3218297958374, 56.94255454199654, 34.60404396057129, 15.741911683763776, 2.3702085869652882, 0.04731336814750518, 0.0789392034390143, 0.29516311309167315, 0.1432707014360598, 0.11045583191194705, 0.03638778387435845, 0.07119516469538212, 0.0754233810252377, 0.2734485540006842, 0.9392847354922975, 1.2283069980995995, 1.4069938212633133, 3.9865745391164507, 3.408949077129364, 2.334902835743768, 1.8462167041642326, 4.189178798879896, 4.442337717328753, 3.8036953466279164, 1.3083311383213316, 8.064008065632411, 8.343251824378967, 12.16086745262146, 12.51922687462398, 8.886214460645403, 10.228415352957589, 6.554640463420323, 7.8462532588413785, 12.975240622247968, 4.204972054277148, 10.21627598149436, 9.444368464606148, 2.815748793738229, 3.452153410230364, 15.399606943130493, 28.895028795514786, 35.23711517878941, 32.20193011420113, 29.36265298298427, 19.093337059020996, 13.525433727673121, 9.012733340263367, 6.464090670858111, 6.327648026602609, 1.9899671162877763, 0.4372330382466316, 0.09597335689302001, 0.2540691596056734, 0.05320879590830632, 0.06907206933413233, 0.12340050909136023, 0.09113606717437506, 0.14538465014525823, 0.5004992634057999, 0.6767429805227688, 10.759367159434728, 51.30007880074637, 79.36807741437639, 41.31880739756993, 47.62515572139195, 35.43473584311349, 18.147695916039602, 15.79167468207223, 22.971698181969778, 45.41227258954729, 54.08612925665719, 50.22033221381051, 51.08366673333304, 41.14505726950509, 20.300591775349208, 4.954866375241961, 0.39454927721193855, 0.14014640051339353, 0.03783188620582223, 0.03855872613244823, 0.04738422077415245, 0.07388855516910553, 0.054601265117526054, 0.025054964935407043, 0.0264708894038839, 0.016754312041614736, 0.04333979243944798, 0.06771538606179611, 0.03884207217821053, 0.03745208979983415, 0.04835437996579068, 0.012238027910435838, 0.05218027252703905, 0.024649141622441154, 0.02111340420586722, 0.009850190237297543, 0.029978711889790635, 0.06060687678733042, 0.042065608847354136, 0.07981212516980511, 0.050600157851087194, 0.03647176276094147, 0.04625558294355869, 0.03307121666148305, 0.03148712916299701, 0.02745275671726891, 0.02452625214521374, 0.035428420174866915, 0.0013071903979705113, 0.023882588737511208, 0.04133972226242934, 0.09283492887126547, 0.017313876122768437, 0.05619794283328312, 0.014824320961322104, 0.01597058373902525, 0.020177102215322, 0.015891030597101365, 0.0812145077756473, 0.05483979392530663, 0.08996921764420611, 0.06571870177452054, 0.01333976861289037, 0.00958502893003502, 0.03233748281906758, 0.05900957142668111, 0.07509703282266855, 0.05006500745990446, 0.061907716627631865, 0.045012747669326406, 0.038619597508971176, 0.05539341403969696, 0.03807630130488958, 0.0382314178028277, 0.015992235791470324, 0.027424378686451485, 0.006926273428169745, 0.05100610160401889, 0.08616002382976667, 0.04599866922944784, 0.03703629371843167, 0.03382023450519357, 0.09118027373084, 0.05976357989545379, 0.03653361462056637, 0.06622670058693204, 0.07805900102747337, 0.0019698212979294893, 0.034943779930472374, 0.05977645849010774, 0.01052040556844856, 0.030523270169006925, 0.015771764496873533, 0.02672800837483789, 0.04481357728530254, 0.014317541815606611, 0.002775072307226115, 0.03603298130578228, 0.07613719307950564, 0.08631147963127919, 0.028818182913320403, 0.9347904452255794, 13.698698350361415, 41.72695847920009, 63.780523436410085, 79.74924169267926, 83.09329155513218, 83.47770064217704, 73.99450738089425, 50.03168167386736, 33.85068552834647, 24.23045642035348, 28.043455839157104, 34.937244824000764, 36.84845454352242, 27.89802656854902, 43.51611614227295, 46.75787809916905, 42.092603955950054, 21.428055116108485, 3.897218099662236, 0.25257917812892366, 0.17982035662446702, 0.21805811194436892, 0.28393417277506416, 0.4985456796629088, 0.4571541207177298, 0.34602324824248043, 1.0374304290328706, 2.1323378767286028, 3.9302042382104054, 2.4002417411123003, 3.9620599917003085, 6.94076749256679, 4.350048703806741, 0.44418785933937344, 0.6759947463870049, 0.7694371065923146, 2.793812245130539, 2.4050655279840742, 1.0033990208591734, 1.4215563769851411, 3.6109636085374013, 8.071678876876831, 13.817772235189166, 14.105544907706124, 14.896616424833026, 13.914591039930071, 9.530441011701312, 7.71401948588235, 3.517347489084516, 2.1903742253780365, 2.5986779502459934, 0.6884810935173715, 4.9324367216655185, 19.728117534092494, 36.10625491823469, 44.10034499849592, 42.8040578024728, 37.53656244277954, 25.530893427985056, 16.891016926084244, 10.499032923153468, 6.913256100245884, 4.315425395965576, 1.669645281774657, 1.0513045702661787, 0.354439416634185, 0.271048548498324, 0.09526187899921622, 0.44948097531284603, 0.1558535091046776, 0.15942853369883128, 0.17698895212795052, 0.49113683721848894, 0.5749286381261689, 12.411240577697754, 49.910355704171316, 63.33745765686035, 39.9340626852853, 32.23949554988316, 31.334054946899414, 29.801890305110387, 30.851572036743164, 43.78754752022879, 59.30232606615339, 73.48633698054722, 68.41971751621791, 72.29180267878941, 54.79097884041922, 24.65670234816415, 5.051914470536368, 0.1738906390964985, 0.11247832767133202, 0.03461778795878802, 0.05409789391394172, 0.012139577568242592, 0.055621035397052765, 0.030117845495364497, 0.05637284880504012, 0.05377524372722421, 0.040713336052639146, 0.003202325028334079, 0.07029854173638991, 0.10560862879667963, 0.011643303840953325, 0.06925952141838414, 0.04531458379434688, 0.024281438406822935, 0.003121742845645973, 0.02063639578409493, 0.02587022476031312, 0.020648020785301924, 0.07426653310124363, 0.062339373465095244, 0.027375997443284308, 0.04302354762330651, 0.009175541527968432, 0.03046796956498708, 0.027190182324764983, 0.02068301453255117, 0.009715450145969433, 0.10621088290853159, 0.09049989309694086, 0.02577779980908547, 0.017510637707476105, 0.007717212013501141, 0.06364684937787907, 0.038478825241327286, 0.005195710575208068, 0.047972924541682005, 0.011012910033709236, 0.06724307140601532, 0.0539217937205519, 0.08634141659630196, 0.07501194453133003, 0.010784844235916222, 0.02085606301469462, 0.07590761754129614, 0.11790721171668597, 0.11752949841320515, 0.13732039715562547, 0.2147018877523286, 0.21206595562398434, 0.179238512845976, 0.10587982567293303, 0.10164528539670364, 0.19906283622341497, 0.1821637994476727, 0.13484389361526283, 0.14833806880882808, 0.1642918927328927, 0.15624361245759896, 0.15588124761623995, 0.3030811824968883, 0.2669245483619826, 0.08219047183437006, 0.19493840182466166, 0.23562321226511682, 0.15673901087471417, 0.10780750294881207, 0.0949834082275629, 0.15880681920264447, 0.11058189693306174, 0.1972998393965619, 0.1442079482866185, 0.07665707982544388, 0.1307667259659086, 0.14875383435615472, 0.18613746336528234, 0.16234997979232244, 0.17573355377784797, 0.10356334783136845, 0.13736716178911074, 0.1384176289928811, 0.14826389136058943, 0.11365579627454281, 3.8120127746037076, 30.365410055433, 63.73228209359305, 79.13147735595703, 93.97816576276506, 94.05310208456856, 92.5384156363351, 81.7469391141619, 49.828700474330354, 47.138201645442415, 32.277060985565186, 24.822138956614904, 32.09402806418282, 42.83283029283796, 48.49417386736189, 83.36580685206822, 78.95804337092808, 56.27146625518799, 26.15815942628043, 5.06793658222471, 0.8556219648037637, 0.32177753640072687, 0.5745798711265836, 0.3178846724331379, 0.37512691797954695, 0.3727471056793417, 0.15065817002739224, 0.5285769339118684, 1.2652386277914047, 2.9680973844868794, 4.592700208936419, 9.236727629389081, 15.033898932593209, 14.333277327673775, 11.792045780590602, 9.473527448517935, 12.62614836011614, 15.345866101128713, 12.454659002167837, 12.976092645100184, 23.504519053867885, 21.57326204436166, 26.42132592201233, 23.02951066834586, 21.537186997277395, 26.60542365482875, 14.39823603630066, 19.642663376671926, 36.196459906441824, 20.02265167236328, 24.139811958585465, 23.571442365646362, 12.889151573181152, 11.486346755708967, 19.633993761880056, 34.56757634026663, 40.918379238673616, 38.99492679323469, 42.173536573137554, 30.53516149520874, 25.266297340393066, 22.434475626264298, 20.662877798080444, 18.01425576210022, 12.379937205995832, 4.435611861092704, 0.9985940158367157, 0.3684946724346706, 0.1336073721093791, 0.3029380387493542, 0.4830309493201119, 0.37386210156338556, 0.30871611727135523, 0.5911585443786213, 1.8292789501803262, 19.468194110052927, 82.05616869245256, 111.41341945103237, 58.557249886649, 69.80821772984096, 51.142163617270334, 26.954096419470652, 25.52098182269505, 40.63266931261335, 70.33902536119733, 82.7085211617606, 82.92028141021729, 88.21683761051723, 69.17754364013672, 34.339348861149375, 7.1847743306841165, 1.0780994296073914, 0.27631194463797976, 0.08470169601163693, 0.18276371939906053, 0.17906866196010793, 0.15872836698378834, 0.2018263465059655, 0.16726017131337098, 0.1535247904913766, 0.08344982604363135, 0.18318069273872034, 0.166020949238113, 0.19173704646527767, 0.08960970264992543, 0.11576547021312372, 0.1229479940874236, 0.10003855518464531, 0.11273736520005123, 0.13392658212355205, 0.055473881507558484, 0.06702898003693138, 0.1283750935856785, 0.15616137401333877, 0.19378258527389594, 0.11241406361971583, 0.06466013964797769, 0.1481309120676347, 0.1619165994759117, 0.13153241202235222, 0.09210172428616456, 0.13242264996681893, 0.12738501599856786, 0.10244597028940916, 0.11959350694503103, 0.1348125860095024, 0.1718916885022606, 0.11693373109613146, 0.1415512529867036, 0.11760071744876248, 0.07134337709950549, 0.09923560398497752, 0.20815281703003816, 0.1301497205027512, 0.14180611073970795, 0.14879797984446796, 0.17425178257482393, 0.21702280321291514], [0.034278802041496546, 0.04027436460767474, 0.020601914330784763, 0.02290527439410133, 0.03839534507798297, 0.060304121247359684, 0.027867068503318087, 0.05115935213065573, 0.06119669335229056, 0.06916906591504812, 0.03931272103052054, 0.058827778324484825, 0.05512137917269554, 0.09774811951709644, 0.056505027426672835, 0.08249565652970757, 0.01448915180351053, 0.06290321570954152, 0.07600179820188455, 0.012661237835085817, 0.029688237833657434, 0.031201018087033714, 0.03222826921514102, 0.03500433578821165, 0.03580420304621969, 0.02335174025834671, 0.018810895703999058, 0.027845959278887937, 0.03423569471176181, 0.004167931037954986, 0.06965624048773732, 0.04619903722777963, 0.044654362435851774, 0.03592849030558552, 0.03558151463844946, 0.05217714448060308, 0.055507184006273746, 2.4491173241819655, 27.729218346732004, 65.91544083186558, 75.17888341631208, 86.19541903904506, 70.9010512488229, 71.24782194410051, 37.92069707598005, 28.643806253160747, 25.371409688677105, 102.9525980268206, 105.92424528939384, 37.00854103905814, 49.65363713673183, 68.5020397731236, 69.32605443681989, 35.26412630081177, 10.37555388041905, 1.6018627818141664, 0.026033059594088366, 0.09467801318636962, 0.07723715262753622, 0.17655705101788044, 0.04689645926867213, 0.14083104234720978, 0.03669220861047506, 0.25882305737052647, 0.4996440921510969, 2.1659454447882514, 2.871472477912903, 1.8509586325713565, 3.34604942372867, 3.6364205053874423, 4.4746889642306735, 9.900318809917994, 11.63869035243988, 22.988486766815186, 39.62063292094639, 62.978701319013325, 75.40611035483224, 47.76426213128226, 21.186881405966624, 12.318365744182042, 4.257211216858455, 14.94624740736825, 11.690649850027901, 14.221622381891523, 18.364497082574026, 18.108264889035905, 10.697375331606183, 7.472560031073434, 1.1871954841273171, 1.8657239888395583, 19.297912870134624, 85.94414438520158, 125.50554738725934, 139.87918853759766, 139.36253438677107, 131.5736871446882, 125.39334787641252, 124.54433359418596, 109.39328629629952, 98.20506068638393, 73.95595877511161, 60.06979628971645, 53.10754844120571, 28.983988319124492, 16.91573687962123, 6.181718919958387, 0.7180179400103432, 0.1675315581794296, 0.07961832199777875, 0.04981523871953998, 0.21774164321167128, 0.04487385155100908, 0.043943573255091906, 0.30323127444301334, 0.8099934703537396, 16.16221169063023, 56.35641840526036, 79.4117259979248, 68.11924266815186, 56.38754980904715, 33.40927342006138, 17.98131435258048, 27.17830957685198, 37.87649263654436, 56.98632819311959, 64.30001245226178, 56.91398702348982, 38.68307426997593, 23.14888940538679, 9.024902241570608, 1.3483128100633621, 0.2678500972688198, 0.10146128027034657, 0.08028890458600861, 0.05947464611381292, 0.03081284516624042, 0.03730034222826362, 0.045278132893145084, 0.017733670471768295, 0.019282842254532234, 0.04582866567320057, 0.03608174083222236, 0.031273224391043186, 0.03563382290303707, 0.021791235244433795, 0.04285262804478407, 0.06283017141478402, 0.07177732059998171, 0.05004783373858247, 0.02739557487490986, 0.04681794598166432, 0.05435930970790131, 0.059171117043920925, 0.025071614488427128, 0.05291394869397793, 0.010491133567744067, 0.018099314333604913, 0.02852177506844912, 0.021875982571925436, 0.024505738335262452, 0.04485995854650225, 0.07755290889846427, 0.05041061927165304, 0.012928449166273432, 0.056763471237250736, 0.0015944449114613235, 0.014874724238844854, 0.004458048863203398, 0.042727462082569084, 0.04954627422349794, 0.05070303733061467, 0.03173131695283311, 0.01809597254863807, 0.038155140288706334, 0.07991288083472423, 0.10903258435428143, 0.027288050823179737, 0.0442660809494555, 0.03405902115628123, 0.02096637923802648, 0.06254513920950037, 0.02103579167409667, 0.028535915738237754, 0.10710271541029215, 0.04321901659880366, 0.07249177047716719, 0.026750025139855485, 0.061700885583247454, 0.03981625847518444, 0.04058992749612246, 0.034917232247867754, 0.02925089148006269, 0.03770901369197028, 0.0756946728963937, 0.048414009623229504, 0.04927759810483881, 0.04175114518563662, 0.04570374059091721, 0.03487819612824491, 0.02230018570220896, 0.03157799178734422, 0.020438853884115815, 0.03192248062363692, 0.014775478314342243, 0.036097537127456496, 0.024275706482252905, 0.015092064094330584, 0.015690470912626812, 0.0448621943193887, 0.07132879538195473, 0.01102563426164644, 0.006992000570919896, 0.04254710068926215, 2.056674599647522, 27.06152078083583, 68.46743079594204, 79.51742199489048, 90.2261107308524, 80.36733954293388, 77.6073135648455, 56.07584319795881, 45.36229419708252, 40.98444618497576, 95.64645603724888, 78.80620438711983, 27.16714382171631, 28.666905539376394, 35.055617809295654, 49.59585244315011, 43.8100631577628, 17.315786361694336, 2.5449190863541196, 0.1568841766566038, 0.18760204049093382, 0.053806459730757136, 0.03977182121681316, 0.10119802903916154, 0.2671109012195042, 0.6416527863059724, 1.4615793036563056, 2.160803343568529, 5.548536530562809, 4.9114097356796265, 4.065813967159816, 2.313705836023603, 1.4015203778232848, 5.124048496995654, 9.466527138437543, 13.807455897331238, 25.31910364968436, 47.97030053819929, 69.36630535125732, 84.19486590794155, 56.155389649527415, 23.52302384376526, 5.78701651096344, 3.7193337934357777, 8.11116201536996, 7.494796872138977, 8.241048165730067, 7.437717420714242, 3.3589270412921906, 4.599619746208191, 4.251684359141758, 2.865411477429526, 1.6520947835275104, 26.010372979300364, 99.4048547744751, 134.39190428597587, 146.3301740373884, 146.5785860334124, 137.27583748953683, 132.87216649736678, 132.82193102155412, 118.84617151532854, 109.08477238246373, 87.92183099474225, 72.92961256844657, 62.03690774100167, 41.05651290076119, 22.489270857402257, 11.370457751410347, 1.9174055584839411, 0.2307006578360285, 0.3628885346863951, 0.23648609167763165, 0.27540338624800953, 0.1590598856231996, 0.0416642044936972, 0.2734370731881687, 0.7738257082445281, 16.778621128627233, 49.89051512309483, 58.20706762586321, 45.447218554360525, 31.418569360460552, 33.863324301583425, 27.556307213647024, 47.26071923119681, 56.54398850032261, 70.73348154340471, 81.93390124184745, 78.13708591461182, 57.41903073447091, 29.58651351928711, 8.980474591255188, 1.159708627632686, 0.0776171525940299, 0.05882709300411599, 0.06193911922829492, 0.0088001895263525, 0.03299103078565427, 0.06821147658463035, 0.03824835742956825, 0.04698018370462315, 0.05418423070971455, 0.02915917390159198, 0.025990495092368553, 0.05466239773003118, 0.04448949199702058, 0.03395683717514787, 0.03934651207444923, 0.031155247507350783, 0.04400027503392526, 0.06128047885639327, 0.018930801323481967, 0.02811701875180006, 0.04795772874993937, 0.04632081730025155, 0.01910440281166562, 0.032664129577044926, 0.005781555589887181, 0.015033906857882227, 0.029319097820137228, 0.04868876541565571, 0.025860145122611096, 0.02361231466888317, 0.06269565863268715, 0.038566800699170144, 0.033933570209358416, 0.03743589316893901, 0.0223312168049493, 0.03366735717281699, 0.012747738327431892, 0.08101456386170217, 0.08385628887585231, 0.032922220549413135, 0.02115708320135517, 0.0407300246214228, 0.08248707984707185, 0.1093655957707337, 0.07366909658802406, 0.0937814445101789, 0.1511460774179016, 0.11344315018504858, 0.1194019972213677, 0.1397239581814834, 0.15815595484205655, 0.12536513938435487, 0.18278031636561665, 0.11711445211299829, 0.1853779519775084, 0.09104729443788528, 0.13241723525737012, 0.14665726971413406, 0.16539843407060417, 0.0965550649645073, 0.133237909791725, 0.14901812374591827, 0.2030215316585132, 0.19010519688682898, 0.11074114231658833, 0.07946956676564046, 0.1451610050031117, 0.14291181069399628, 0.1258687480751957, 0.12279510657702174, 0.06282553702060666, 0.11988117865153722, 0.12313867599836417, 0.09889721857117754, 0.1008208314222949, 0.16518594404416426, 0.11782194700624261, 0.09157447543527399, 0.14954035143767083, 0.15465429345411913, 0.11544339678117208, 0.15587522222527436, 5.527926870754786, 47.37710155759539, 90.98331151689801, 98.76885141645158, 106.60837187085832, 92.10712705339704, 89.41115651811872, 57.71585430417742, 44.39275993619646, 41.47859512056623, 118.69595146179199, 119.5123370034354, 49.913100242614746, 70.74862166813442, 91.25889791761125, 100.47491904667446, 54.27320255552019, 19.316575731549943, 2.793357355254037, 0.5700695674334253, 0.2287515252828598, 0.204817993832486, 0.28935471762503895, 0.17582050125513757, 0.20174580439925194, 0.42767120418804033, 0.985332184604236, 1.6469308606215884, 5.197809270450047, 8.730784126690455, 10.080377902303423, 10.337818213871547, 12.510269778115408, 13.789605106626238, 21.869955335344585, 20.15199065208435, 30.998554229736328, 49.584259373801096, 69.76324898856026, 86.45368358067104, 57.073938029153005, 29.04475552695138, 30.874355179922922, 20.62787972177778, 32.949670927865164, 23.48367272104536, 29.912345818110875, 42.041531222207205, 35.47594213485718, 24.349852527890885, 19.48562887736729, 13.78967979976109, 6.556557731969016, 24.646509340831212, 93.00627258845738, 139.03205026899064, 151.62895366123743, 156.12625857761927, 142.29488263811385, 138.8041215624128, 136.69556563241142, 119.07246044703892, 106.31547055925641, 83.19191428593227, 68.9840224129813, 66.04366983686174, 42.661275795527864, 26.663587025233678, 15.206535611833845, 3.1943439756120955, 0.4532714347754206, 0.2579676961260182, 0.26501129674060003, 0.30080388326730045, 0.5080618890268462, 0.11496785229870252, 0.5161139283861432, 1.8376078861100333, 27.590825864246913, 86.70244993482316, 112.10633550371442, 96.80337974003383, 77.521454674857, 49.74914012636457, 28.889166252953665, 41.30012716565813, 58.155689171382356, 83.52193982260567, 97.22994354793003, 97.66072491237095, 78.74421950748989, 40.55157688685826, 13.824944513184683, 3.219783067703247, 0.7806818432041577, 0.22745339279728277, 0.10143770796379872, 0.17019244682575974, 0.1132683799202953, 0.22379474554743084, 0.10744559272591557, 0.18547059914895467, 0.1504965022738491, 0.16868143076343195, 0.13334095211965696, 0.13551630824804306, 0.2820947729051113, 0.17481759935617447, 0.14946071856788226, 0.13368520007601806, 0.1969343532941171, 0.11487833995904241, 0.0626001955409135, 0.19941225461661816, 0.18727715792400496, 0.17683937586843967, 0.14970503188669682, 0.08534403118704047, 0.11206647727106299, 0.07314601394214801, 0.11999890447727271, 0.12900478765368462, 0.13739500886627606, 0.11247637349047832, 0.2042956847165312, 0.09326222272855894, 0.07375353348574468, 0.1518397166260651, 0.204706944791334, 0.1346510946750641, 0.13644010653453215, 0.22890661124672207, 0.15765769300716265, 0.19526016313050473, 0.09854198513286454, 0.15513647400907107, 0.15238012905631745, 0.18607824082885469, 0.13326458978865827], [0.0367338095924684, 0.022921437098245536, 0.04726909034486328, 0.03651422208973339, 0.02459920653408127, 0.010123902782132583, 0.009225107662911926, 0.04824290684025202, 0.04295771615579724, 0.03689136542379856, 0.05939340511603015, 0.06319814774074725, 0.05035567829119308, 0.01832005873854671, 0.07966497128031083, 0.05272673748965774, 0.04618501869429435, 0.02779632104959871, 0.020392574403168898, 0.06595481839030981, 0.021433270702670728, 0.04027093122048037, 0.008241432901870991, 0.07602309063076973, 0.033787054142781665, 0.041058265936693976, 0.04626038018614054, 0.022749742293464284, 0.04799317202663847, 0.012383858656643756, 0.030326515369649445, 0.033410972716020684, 0.041461729644132514, 0.03776887744399054, 0.05414845155818122, 0.07210268492677382, 0.4050044704760824, 45.63144656590053, 76.44877787998745, 83.71021515982491, 84.62015124729702, 70.93431922367641, 39.59187085287911, 24.65913769177028, 21.656388555254253, 32.19920989445278, 20.874446971075876, 31.520398684910365, 56.64442818505423, 77.14428561074394, 83.54076944078717, 60.69209780011858, 14.550839321953909, 1.340450489095279, 0.24461314986859048, 0.06119140756449529, 0.07428597991487809, 0.1271948090621403, 0.13450105701174053, 0.04652308180396046, 0.2607747140739645, 0.12747921022985662, 0.9879847679819379, 1.1029850542545319, 3.1871912394251143, 2.585962095430919, 3.24044331908226, 4.764574323381696, 3.8742816618510654, 15.313655989510671, 32.19894586290632, 60.46560737064907, 85.78468322753906, 112.62658882141113, 115.6277242388044, 117.20242227826799, 108.47704819270542, 124.6799624306815, 115.76294313158307, 54.57141923904419, 20.339861256735666, 11.3144257409232, 10.744990468025208, 8.649129765374319, 6.540679361139025, 5.014885783195496, 4.888347796031407, 5.8745099646704535, 2.436120718717575, 41.070916516440256, 130.20968627929688, 124.98458535330636, 103.83434527260917, 101.036180632455, 101.59681688036237, 100.99031557355607, 109.00049768175397, 107.9039260319301, 107.98066193716866, 114.06599848611015, 120.47634397234235, 114.38098117283413, 115.79969215393066, 107.53449031284877, 102.019058908735, 77.50006811959403, 42.19006633758545, 11.103034615516663, 0.3356933125427791, 0.2359306700527668, 7.938685144696917, 0.16074471521590436, 0.19934011277343544, 0.10832675865718297, 0.10354327676551682, 0.05762224551290274, 3.209781352962766, 21.88384131022862, 51.51106432506016, 80.89375591278076, 59.85513169424874, 44.14750589643206, 16.36362780843462, 19.840961490358623, 38.69158928734915, 38.50638157980782, 36.74306774139404, 50.28815358025687, 42.63506719044277, 33.729825087956016, 15.624540976115636, 4.380670717784336, 0.4150286582963807, 0.01898515028213816, 0.04908066688637648, 0.017300878784486225, 0.03082080777468426, 0.04764523623245103, 0.024231196281367114, 0.011242801090702415, 0.05893863059048142, 0.012074043807972754, 0.08839750662446022, 0.04716485379529851, 0.041415501053311994, 0.01477275908525501, 0.06413604598492384, 0.014615349138953855, 0.046950423158705235, 0.024582076917535493, 0.013578789358559464, 0.03383386627371822, 0.04573451554668801, 0.021701490506529808, 0.060834952763148716, 0.0215619294238942, 0.04494279070890375, 0.03048122813925147, 0.028396965337118933, 0.05813390162906476, 0.06837794836610556, 0.08084995805152825, 0.019815342966467142, 0.019554317330143282, 0.04020728802840624, 0.01880088052712381, 0.026947975857183337, 0.07714910592351641, 0.06161624512502125, 0.019507986959069967, 0.04141440861193197, 0.03923364795212235, 0.01951329649559089, 0.00649406316058178, 0.06738275462495429, 0.057188430934080055, 0.01988212438300252, 0.017330283099519353, 0.05419957238648619, 0.01891828913773809, 0.02363285392389766, 0.01409148278513125, 0.009703535071041967, 0.031111122375088077, 0.044927387963980436, 0.05761579943022557, 0.048793307305978875, 0.025554821327594773, 0.042288266721048524, 0.05409609240346721, 0.045441843037094386, 0.067016413568386, 0.05609738394351942, 0.010060676040926149, 0.01292394199741206, 0.06170824768819979, 0.0679346885798233, 0.02320055247816656, 0.018775576259940863, 0.05548781183149133, 0.030370257129626613, 0.028614028689584563, 0.035533745773136616, 0.024027121785495962, 0.09035338381571428, 0.012989416385867765, 0.08130072922046695, 0.06512653747839586, 0.048511029952870946, 0.04476849202598844, 0.022342924926696078, 0.06688211113214493, 0.35198805960161345, 45.460920401981895, 83.31161785125732, 93.15276840754917, 92.8465404510498, 86.23608684539795, 56.57014151981899, 50.723694460732595, 31.644406659262522, 33.91546358380999, 26.249271154403687, 50.75836944580078, 66.39900766100202, 39.96785177503313, 43.467919962746755, 49.62448249544416, 20.667817967278616, 1.7001238805907113, 0.21681833347039564, 0.10170241125992366, 0.11398209019431046, 0.15218214610857622, 0.3737250103482178, 0.20972552549626144, 1.0436970527682985, 2.431954405137471, 4.619851163455418, 4.45746785402298, 7.081446800913129, 6.647430615765708, 2.0562507595334734, 1.4831482491322925, 7.1918419514383585, 20.478430918284825, 39.85619074957711, 62.08100100925991, 92.46930885314941, 120.43743406023297, 121.70695332118443, 120.63223375592912, 114.92037677764893, 129.8752555847168, 122.94116183689663, 64.77900736672538, 23.67577304158892, 6.266095238072531, 1.120872757264546, 1.8359440096787043, 1.5470975147826331, 2.5306629027639116, 2.038558908871242, 5.09183577980314, 5.785670297486441, 50.49896192550659, 138.69778633117676, 128.09710039411272, 108.85265391213554, 105.18650640760148, 105.07006849561418, 106.89641639164516, 111.03934233529228, 109.64888967786516, 112.93507494245256, 116.93587548392159, 124.08754512241909, 118.80963788713727, 119.53258405412946, 111.68034839630127, 110.10330186571393, 86.2033052444458, 50.50117492675781, 14.508161749158587, 1.6232831009796687, 0.7867130424295152, 12.062338522502355, 0.8684438882129533, 0.4135140324277537, 0.1237341176186289, 0.1258660475058215, 0.14281191676855087, 3.4131470918655396, 23.56648482595171, 46.1169102532523, 56.879822731018066, 39.41873216629028, 33.371833051954, 21.105038574763707, 34.30854402269636, 55.47144719532558, 57.3679267338344, 57.94523171016148, 70.95490673610142, 62.1245036806379, 42.155228069850374, 17.437016793659755, 4.775860369205475, 0.14999045085694107, 0.0158827796112746, 0.022508648623313223, 0.058361658693424294, 0.048634798132947514, 0.08614871265100581, 0.01144243372670774, 0.0829593130786504, 0.01644334283524326, 0.052746350544371774, 0.009294038339118873, 0.0688212692205395, 0.06604416788156543, 0.053357849695852826, 0.03600733946742756, 0.04160644080755966, 0.11964918752866131, 0.02630699096646692, 0.03334612851696355, 0.03797587472945452, 0.0532475165091455, 0.016303316956119876, 0.02045504203332322, 0.00830386660527438, 0.011565184104256332, 0.014903326186218431, 0.06177823857537337, 0.02340326820766287, 0.054606500015194924, 0.04306684833552156, 0.050417258736810515, 0.08767666494739906, 0.030094184979264225, 0.03846253361552954, 0.010593585570209792, 0.015570543240755796, 0.05365221854299307, 0.01887752953916788, 0.0077969034069350785, 0.06359272263944149, 0.07297277038118669, 0.047865078185818026, 0.008619454938785305, 0.06398614402860403, 0.22118904893951757, 0.12037918264312403, 0.14233122899063996, 0.1476152390241623, 0.10437469250921692, 0.1234535841005189, 0.09402835661811487, 0.16031411689307007, 0.13938808334725244, 0.0871513227799109, 0.1907628873097045, 0.17073408061904566, 0.12750799368534768, 0.15896939619311265, 0.26660878530570437, 0.16728719057781355, 0.2071635401142495, 0.12215239820735795, 0.1088323350995779, 0.17489671653934888, 0.3193307119820799, 0.12075315043330193, 0.11963075851755482, 0.13983534649014473, 0.08457731375736849, 0.14533662343663828, 0.16574714678738797, 0.15122942865959235, 0.2022868546524218, 0.10411652350532156, 0.1603482879166092, 0.14012559662972177, 0.12133256505642619, 0.13098218797573022, 0.14161916077136993, 0.24181481716888292, 3.54704995240484, 70.38805879865373, 100.92355033329555, 103.64876583644322, 108.17541994367326, 93.76538412911552, 61.74813365936279, 44.72985526493618, 37.09192289624895, 44.754993847438264, 31.78201573235648, 42.25216933659145, 67.8378962108067, 108.0591070992606, 122.12467902047294, 90.03950296129499, 25.623604978833878, 2.333187064954213, 0.6912197694182396, 0.2200495172291994, 0.265432205583368, 0.28630299280796734, 0.342213762657983, 0.18837048139955315, 0.6035870260425976, 1.0814232741083418, 3.554916398865836, 3.300153966460909, 7.601162501743861, 12.6058509349823, 14.531454716409955, 17.089681557246617, 11.032603331974574, 23.292142152786255, 43.67492764336722, 66.60338197435651, 94.79141766684396, 123.91226986476353, 126.02242388044084, 126.76301847185407, 118.51768847874233, 136.5632997240339, 124.97926303318569, 66.72861630575997, 33.982715197971885, 25.149749994277954, 29.869840213230678, 29.353078365325928, 24.163203069141932, 14.51538266454424, 7.4854637043816705, 12.71972061906542, 9.455422180039541, 50.30244255065918, 144.37019838605607, 137.3856051308768, 116.04405335017613, 110.38333511352539, 108.2895371573312, 112.63296031951904, 118.52199636186872, 116.20896884373256, 120.67256110055106, 123.57895088195801, 131.19870676313127, 124.59062249319894, 126.38004766191754, 112.22991616385323, 113.11879226139614, 88.30480875287736, 52.713821819850374, 17.403229440961564, 2.5529010466166904, 0.748700099331992, 11.405591317585536, 0.5012071654200554, 0.45264172713671413, 0.30258283923779217, 0.39345566875168253, 0.4058086701801845, 5.992534237248557, 36.32787118639265, 74.54802867344448, 110.91219724927629, 81.45717144012451, 63.83669267381941, 27.829215083803447, 30.710367270878383, 57.9274582181658, 61.6050910949707, 63.54042843409947, 90.1250352859497, 81.90209238869804, 54.35203334263393, 23.622890302113124, 6.312769762107304, 0.9006745730127607, 0.12499955828700747, 0.14674068880932672, 0.10844493231603078, 0.15176207864923136, 0.2275964415499142, 0.1585778407752514, 0.13290911886308873, 0.15727940973426613, 0.12623165574456963, 0.13151818992836134, 0.1503582846905504, 0.14871445218367235, 0.10482452729982988, 0.16652222376848969, 0.16062196823103086, 0.16892117075622082, 0.08435493747570685, 0.18507881302918705, 0.1618418249168566, 0.08631651436111756, 0.10453378861503941, 0.10561473561184746, 0.06666383320199591, 0.10085209153060402, 0.07924978248775005, 0.13813425919839314, 0.11581967159041337, 0.20752822554537229, 0.22536790184676647, 0.1005092142149806, 0.12580622785857745, 0.1366724640663181, 0.09952790330031089, 0.14291919315499918, 0.19163169711828232, 0.13202714547514915, 0.08444023611290113, 0.10879664415759699, 0.13408721850386687, 0.12902684004179069, 0.135165220658694, 0.15012205950915813, 0.19511039688118867], [0.053564134519547224, 0.15228912393961633, 0.13385613661791596, 0.09545948875269719, 0.10801257658749819, 0.06139248463192156, 0.018311220819928815, 0.034277098918599744, 0.13765897255923065, 0.014518530673480459, 0.06847210188529321, 0.0183507386994149, 0.04147088308153408, 0.03713016564558659, 0.09271157799022538, 0.04635218258148857, 0.11094387500946011, 0.052507774239139896, 0.15541185066103935, 0.01048462896142155, 0.03248810062983206, 0.08470918703824282, 0.11847142715539251, 0.10803552464182888, 0.0944568854091423, 0.11614588408597878, 0.07998346883271422, 0.07124279106834105, 0.03919121915740626, 0.04648392354803426, 0.037611816943223984, 0.03482179629749485, 0.039073035320533175, 0.011923772050067782, 0.12861214657979353, 0.9260658962385995, 37.87653432573591, 64.54353291647774, 77.7030736378261, 85.03168610164097, 75.19234207698277, 32.17958818163191, 18.430251359939575, 8.926539199692861, 57.3762263570513, 78.48617036002022, 50.942097187042236, 52.73438153948103, 41.55558810915266, 33.39598846435547, 16.21437529155186, 2.372707550014768, 0.23660236543842725, 0.21554347473595822, 0.04967151143188987, 0.1698571148195437, 0.08625404164195061, 0.21000057645142078, 0.058902274684182236, 0.16704472287424973, 0.5786555324281965, 1.7408427127770014, 2.8529698593275885, 6.3104534064020426, 8.632776311465673, 9.320868577275958, 5.366244026592799, 18.024625948497228, 57.00958728790283, 79.41770839691162, 94.440915788923, 96.30401965550014, 101.33614826202393, 88.99762753077916, 88.63425758906773, 80.81884043557304, 86.89018331255231, 85.07767622811454, 102.39392811911446, 96.62781265803746, 95.44406196049282, 42.09611627033779, 5.700733780860901, 4.570615793977465, 11.15275158200945, 29.75918320247105, 62.95485510144915, 93.6753910609654, 65.505768094744, 76.06993430001395, 111.93523611341203, 100.55981908525739, 119.33917399815151, 107.65527779715401, 106.3091824395316, 98.12050805773053, 98.91595867701939, 97.8353053501674, 103.13095828465053, 98.61737373897007, 97.39367089952741, 94.47669206346784, 97.40478801727295, 100.12368760790143, 105.07802418300084, 106.46772643498012, 103.27649525233677, 75.38527270725795, 26.6421639919281, 3.561353687729154, 6.753723723547799, 4.631765152726855, 0.047017323318868876, 0.10427352972328663, 0.10001737132136311, 0.03620810101607016, 0.070502014032432, 0.2998618595302105, 7.393058742795672, 29.922420706067765, 60.8395802634103, 59.424058505467, 62.337757791791645, 30.535825048174175, 36.152634143829346, 58.68759114401681, 30.320083481924875, 38.388296944754465, 40.373650891440256, 46.36176824569702, 31.55614021846226, 31.24643121446882, 16.548423835209437, 5.60961423601423, 1.0773787711347853, 0.11432006848709923, 0.08931358996778727, 0.0631318005866238, 0.012540329680112856, 0.06913190255207674, 0.017508347651788166, 0.04717921159629311, 0.058034292688327174, 0.019677544378542473, 0.10056405341518776, 0.0360768010972866, 0.06308760760085923, 0.027822675349723016, 0.07232747000775167, 0.05637989878388388, 0.1288995604429926, 0.0566002767799156, 0.11365776402609688, 0.09906750371945755, 0.0990354565105268, 0.06753929943910666, 0.05608749429562262, 0.026210357401786104, 0.023116997675970197, 0.04441055462562612, 0.014848045938249146, 0.0924746064203126, 0.05858347857637065, 0.0662690954548972, 0.04851429709898574, 0.09244681362594877, 0.12273722753993102, 0.035150461697152684, 0.16077816699232372, 0.09902569239160844, 0.026423895764829855, 0.07813310383685998, 0.20517821450318607, 0.13765978680125304, 0.06363878838185753, 0.07797480840235949, 0.05105497308873704, 0.05502994657893266, 0.06100254412740469, 0.07409498587782894, 0.05156956047617963, 0.09420374434973512, 0.04494254643629704, 0.025448555958324244, 0.16742942508842262, 0.0474371600763074, 0.09806659671344928, 0.02316026106875922, 0.0509104587004653, 0.04693708994558879, 0.05307610160005944, 0.01861104678495654, 0.0384218859752374, 0.04746416237737451, 0.06015752375658069, 0.03822139584060226, 0.022540899392749583, 0.09750668318676096, 0.11066579778811761, 0.03969306026452354, 0.06315773419503655, 0.0801047230405467, 0.1008391450824482, 0.04409138532355428, 0.0634756957047752, 0.051490212591098886, 0.05490680943642344, 0.020958988295335854, 0.03193762891792825, 0.027972165096018995, 0.039586048506732495, 1.1666136171136583, 37.36121422903878, 80.5805311203003, 89.88035447256905, 94.0222520828247, 87.39387907300676, 45.972106320517405, 30.956152847834996, 16.084294591631206, 45.077112334115164, 61.457275118146626, 27.434084926332744, 25.015547275543213, 33.54104600633894, 38.61658695765904, 24.659504209245952, 4.248113853590829, 0.23489321715065412, 0.06607462053320237, 0.1503095794469118, 0.1682829407176801, 0.20425685894276413, 0.509686247578689, 0.4595057602439608, 1.3031191208532877, 3.0121057544435774, 4.589326424258096, 8.596617885998317, 3.982517659664154, 4.856352210044861, 4.703951724937983, 5.840178915432521, 23.19685455730983, 62.26599679674421, 87.95717648097447, 98.08390494755336, 103.74679797036308, 104.84710080283028, 95.01339176722935, 92.44901316506522, 87.88385214124406, 89.98770414079938, 90.65965053013393, 103.67018018450055, 108.4713020324707, 104.83494840349469, 48.23134783336094, 5.57712185382843, 4.540072381496429, 10.905649321419851, 33.87638691493443, 66.59866414751325, 104.36798082079206, 77.80610847473145, 77.51927294049943, 112.99971403394426, 103.62307139805385, 121.49950790405273, 109.58516774858747, 108.29478999546596, 100.85101808820451, 102.12476185389927, 103.70947919573102, 105.20966475350517, 100.79370934622628, 104.32287311553955, 100.44180393218994, 101.63147449493408, 105.0910312107631, 107.37416757856096, 107.07739612034389, 109.32898766653878, 83.20087051391602, 32.69142723083496, 4.413050626005445, 4.438687307494027, 1.8476918935775757, 0.5597404731171471, 0.1117597319451826, 0.08974006279770817, 0.07387174107134342, 0.09174874358411346, 0.5255628813590322, 8.59316028867449, 35.66750397000994, 43.871356691632954, 37.22506080354963, 35.9801972252982, 23.849886213030132, 35.183954511369976, 55.36943026951381, 41.26774856022426, 55.67394549506051, 56.558784689222065, 66.34561075483049, 45.48135505403791, 35.68993622916085, 16.618168115615845, 5.206855390753065, 0.6414521570716585, 0.1541009210050106, 0.08507804545973029, 0.056605257226952484, 0.10733585325734955, 0.01575765266482319, 0.04701181700719254, 0.1306039589856352, 0.08244617775614772, 0.021555927781654254, 0.030068627957786833, 0.047342718179736815, 0.04264666213254843, 0.010834918423954929, 0.07151985727250576, 0.026626536855474114, 0.009437448411647762, 0.07363977030451808, 0.06647432515663759, 0.07571547678006546, 0.05631973647645541, 0.03362673328125051, 0.10355841488178287, 0.0742486265621015, 0.04032723605632782, 0.006973178857671363, 0.0474008143480335, 0.05622408339487655, 0.07320567752633776, 0.09167951265616076, 0.06682983679430825, 0.09027455161724772, 0.0660016644479973, 0.03818955558485218, 0.08396678830363921, 0.0476528290393097, 0.05673180740060551, 0.06896445368017469, 0.20341886819473334, 0.08631649400506701, 0.0730363219710333, 0.04758456841643367, 0.23637407911675318, 0.19911349564790726, 0.2520988296185221, 0.1371174609022481, 0.2009994565908398, 0.15661500181470597, 0.10416437379483666, 0.13416155880051, 0.16707738755004747, 0.13521805139524595, 0.1799159079257931, 0.1386860710169588, 0.17136719450354576, 0.20104030439896242, 0.14468902961484023, 0.12329777888953686, 0.13568572487149919, 0.1546193760420595, 0.21655602540288652, 0.10380607337823936, 0.12789823274527276, 0.20978276671043464, 0.17653575858899526, 0.33505953369396074, 0.19833684446556227, 0.17042937768357141, 0.20831547544470855, 0.20154459162482194, 0.09526346677115985, 0.16343425161072186, 0.1153601948171854, 0.1630679919783558, 0.16302631635751041, 0.0765853790300233, 0.17752289133412497, 4.965368577412196, 64.33451025826591, 91.29484094892229, 100.60271726335797, 107.96686281476701, 97.64203425816127, 51.12655796323504, 28.852071557726177, 17.74181342124939, 74.23941748482841, 101.92946883610317, 80.58413028717041, 77.65225451333183, 63.772359303065706, 55.59771680831909, 30.01706906727382, 4.937324345111847, 0.583905602140086, 0.37729044045720783, 0.25068191279258045, 0.4486336479229586, 0.22250551544129848, 0.5209542172295707, 0.22284547505634172, 0.9295702853373119, 2.8696194802011763, 6.272974388939994, 13.546375598226275, 16.91291069984436, 22.489732912608556, 23.84324026107788, 16.603995527539933, 25.33529990059989, 65.0330890927996, 88.70394802093506, 101.31819411686489, 106.34781442369733, 110.66381304604667, 98.45051274980817, 98.16648428780692, 89.76248523167202, 96.3908304486956, 94.64144774845668, 111.63467788696289, 113.51408917563302, 105.37437180110386, 49.9807687486921, 10.609450221061707, 11.694908227239337, 15.502224888120379, 39.81109694072178, 68.68012210300991, 109.07096631186349, 97.55035972595215, 90.75433363233293, 117.71868732997349, 109.74067538125175, 125.9248433794294, 111.89440849849156, 112.29145635877336, 107.16570077623639, 107.27694143567766, 106.5528974533081, 110.84238869803292, 106.34980160849435, 107.2766774041312, 103.71499606541225, 106.09842273167202, 109.74622699192592, 114.6376267841884, 114.35889284951347, 114.29681069510323, 85.23106466020856, 33.958174160548616, 9.661720275878906, 11.640238932200841, 6.9920860188347955, 0.22602200960474356, 0.17375380572463783, 0.18313284244920525, 0.10065296864403145, 0.23790015865649494, 0.9947012875761304, 13.665735227721077, 49.79383093970162, 86.67715154375348, 85.44030966077531, 83.41522938864571, 41.012662819453645, 46.13409314836775, 71.29838398524693, 46.61675671168736, 63.46863269805908, 72.81609984806606, 84.75663471221924, 63.29832540239607, 47.08122294289725, 22.653319563184464, 7.961485658373151, 2.0537161869662146, 0.3490710104150431, 0.1825152670166322, 0.16122431733778544, 0.21500318444200925, 0.18157279544642993, 0.1962915635002511, 0.16726603385593208, 0.24994939352784837, 0.12153513490089349, 0.15035881394786493, 0.12432942353188992, 0.21339473075100354, 0.15052090239311966, 0.12559597699769906, 0.1590961329638958, 0.2454383298754692, 0.15179813600012235, 0.1436227254037346, 0.24968975888831274, 0.1705935424459832, 0.15982068622750895, 0.2274481409362384, 0.10535818830664669, 0.08464645647576877, 0.14189974857228144, 0.07952602087919201, 0.275151432624885, 0.1355924941599369, 0.11901779712310859, 0.21990570851734706, 0.24143106490373611, 0.18800194188952446, 0.12789484007017954, 0.2306414081582001, 0.14144218526780605, 0.13354181205587728, 0.20745091326534748, 0.400900880673102, 0.2405543162354401, 0.1689235456287861, 0.13338032072143896], [0.21465101119663033, 0.20942151466650621, 0.19593035216842378, 0.22812811444912637, 0.22130574339202472, 0.11475370664681707, 0.09514360356011561, 0.04348957904481462, 0.08301310054957867, 0.02850484222705875, 0.019233215899605836, 0.027398660512907163, 0.08869605524731533, 0.055799747950264385, 0.05051553774891155, 0.08015628491661378, 0.04677828560982432, 0.03158028184303215, 0.032357435141290934, 0.16249585125063146, 0.1977321883397443, 0.22599945510072367, 0.3145761899650097, 0.23684633948973247, 0.10170527467770235, 0.05578758521005511, 0.09896167939794914, 0.07387560872094971, 0.07705639089856829, 0.09803253425551312, 0.08055983683360474, 0.10335848453853812, 0.06428699967052255, 0.18511340474443777, 3.6155722183840613, 39.231707504817415, 81.78771114349365, 74.82087748391288, 66.33497306278774, 62.21055017198835, 30.27586167199271, 17.460647617067607, 29.25849253790719, 58.23747294289725, 58.046765736171174, 46.26688017163958, 44.50927427836827, 46.967359338487896, 21.249307496207102, 4.37124114377158, 0.15349057875573635, 0.03741009866020509, 0.08259827816592795, 0.03381914545648864, 0.12401337549090385, 0.07707369354154382, 0.1084766945402537, 0.23422005612935337, 1.163402029446193, 0.3996208922139236, 2.2034348845481873, 10.32441861288888, 8.506103702953883, 6.2315913523946485, 9.455282347542898, 13.88373235293797, 44.05582094192505, 91.29626532963344, 99.9726893561227, 97.73484134674072, 92.74069159371513, 99.84253570011684, 94.26687036241803, 93.99802371433803, 87.71884632110596, 84.63132395063127, 82.54952553340367, 97.09157017299107, 97.18237618037632, 100.70672484806606, 96.07074778420585, 118.95894077845982, 49.92664922986712, 37.33608259473528, 89.9082167489188, 144.02374730791365, 128.85368973868233, 140.39735739571708, 101.64310577937535, 51.34035750797817, 115.36026723044259, 107.75038473946708, 95.64592102595738, 87.99915749686105, 97.35382298060826, 87.13342584882463, 93.23488916669572, 84.09735488891602, 96.38194370269775, 95.00237887246269, 98.9350106375558, 95.41277422223772, 106.68906130109514, 103.66314165932792, 107.14769104548863, 103.17580195835659, 102.94460759844098, 93.25139808654785, 87.94812297821045, 40.46381419045584, 30.370972088405065, 12.857065660612923, 0.9255643231528146, 0.29074525300945553, 0.16649962855236872, 0.03409415909222194, 0.2107695737587554, 0.04518785720158901, 0.0639300834653633, 1.315535877432142, 20.384069170270646, 39.20653418132237, 51.63282108306885, 74.55652632032121, 101.4380852835519, 139.04426520211356, 33.18150452205113, 24.30327180453709, 32.940092836107524, 43.829646655491416, 45.049243109566824, 53.414099488939556, 42.75987768173218, 31.912294455936976, 11.068314467157636, 3.2398329632622853, 0.44209251606038635, 0.05284594591440899, 0.03813328467575567, 0.06855710875242949, 0.02920904283278755, 0.05782353971153498, 0.019329837589923824, 0.0321118122498904, 0.06736980817679848, 0.030056743416935205, 0.0050672091892920434, 0.05060385247426374, 0.14902375558657305, 0.44917634023087366, 0.20268470687525614, 0.3482004228447165, 0.14734742125230177, 0.2664680571428367, 0.21227672217147692, 0.046380514811192236, 0.05191688898152538, 0.022776585138802017, 0.09833448233881167, 0.0677815160847136, 0.04036295074703438, 0.07100354640611581, 0.037090009943182976, 0.06629805532949311, 0.016203628287517598, 0.06898485722818545, 0.042942021640815904, 0.008249502379580267, 0.05195470713078976, 0.22137388187859738, 0.27038906674299923, 0.432098455194916, 0.40417443215847015, 0.22347569838166237, 0.05506996318165745, 0.06895713228732347, 0.15471758720065865, 0.2264638308967863, 0.16073137521743774, 0.1618049397532429, 0.14632091990539006, 0.026192014903894494, 0.09759766116206135, 0.03743428164826972, 0.11777241394988128, 0.03257991320320538, 0.024186747148633003, 0.051899162254163196, 0.020792927027546933, 0.046883054809378724, 0.03667529273246016, 0.09142609339739595, 0.05140111076512507, 0.030514228689883436, 0.041319719050079584, 0.09480569312082869, 0.202490985127432, 0.20488117901342257, 0.35999189583318575, 0.22194751538336277, 0.1156300346234015, 0.06041939077632768, 0.039571480359882116, 0.063038624157863, 0.14891139018748487, 0.03531787324962871, 0.05604213422962597, 0.07162763577486787, 0.0783668862921851, 0.11854671740106174, 3.5088027247360776, 38.70360272271292, 95.89035865238735, 81.95836584908622, 79.55467823573521, 74.2535709653582, 53.753119468688965, 26.912226574761526, 27.231131519590104, 30.488629409245082, 53.70960290091378, 47.826660428728374, 39.05957630702427, 49.14857605525425, 29.075678484780447, 6.932882155690875, 0.15080898122063705, 0.10288165083953313, 0.05162539712286421, 0.039234010968357325, 0.3349849491247109, 0.4879261723586491, 0.6799901234252113, 1.8801022001675196, 3.41620495063918, 4.266158759593964, 3.757225360189165, 5.722026969705309, 1.5231212356260844, 4.425207367965153, 7.084060626370566, 16.079385689326696, 48.20319373267037, 98.4097546168736, 104.6417954308646, 104.94386836460659, 97.01803043910435, 100.17144952501569, 97.3231258392334, 99.52924142565045, 92.98606722695487, 89.36285958971295, 86.48687512534005, 102.34450558253697, 104.03325135367257, 104.47131443023682, 98.37129633767265, 124.27966281345913, 58.72939845493862, 43.24451800755092, 103.5420206614903, 157.08979306902205, 141.66070665631975, 151.57538305010115, 110.58166449410575, 58.13325343813215, 121.21110207693917, 111.9214369910104, 100.89041437421525, 90.76470729282924, 99.50131661551339, 89.74916553497314, 94.79859515598842, 88.15784740447998, 99.3462050301688, 100.02835832323346, 102.83448559897286, 100.02495370592389, 107.20014994485038, 105.62561171395438, 110.91439982822963, 104.95356110164097, 101.64915766034807, 95.79894815172467, 91.2524847303118, 52.00568573815482, 26.82150047166007, 8.160917196955, 3.286487945488521, 0.9352263361215591, 0.8897616671664375, 0.22612149640917778, 0.11895199279700007, 0.010140213067643344, 0.06352176144719124, 1.3873581034796578, 23.837188380105154, 37.50225918633597, 47.75477089200701, 53.75057642800467, 90.30308982304165, 153.96863446916853, 51.96494844981602, 40.34173434121268, 50.73436689376831, 60.943344661167686, 64.94120611463273, 68.60192012786865, 50.987201418195454, 36.373659815107075, 11.488649215017047, 3.0544413455895016, 0.3790914352451052, 0.06701426261237689, 0.029397387190588882, 0.015179118440885628, 0.05819163817380156, 0.08713241200894117, 0.034382845208581, 0.03512225499642747, 0.07290429262710468, 0.06089851113834551, 0.026053298597357104, 0.009953076502175202, 0.12681421877018043, 0.23611219174095563, 0.219920188454645, 0.2701415371681963, 0.1920819729566574, 0.18338768663150923, 0.1778911051473447, 0.02433722585971866, 0.06342779113245861, 0.010357233163501536, 0.06749125915978636, 0.01603581470304302, 0.05571545693757279, 0.0618732131219336, 0.05501375673338771, 0.06660759621965033, 0.030187829597187892, 0.0505840392517192, 0.06887971144169569, 0.005055913277569094, 0.0794737126146044, 0.15429860539734364, 0.30354812315532137, 0.3225896071110453, 0.3799022031681878, 0.20899740313845022, 0.04898785347385066, 0.048081463003265004, 0.39186903674687656, 0.4252055436372757, 0.3242340502994401, 0.29909191227384974, 0.255107263901404, 0.11454270939741816, 0.10876685647027833, 0.08989368312593017, 0.24773571374160902, 0.11160797080291168, 0.08081862330436707, 0.10871786624193192, 0.19891624551798615, 0.19448679605765, 0.15181463797177586, 0.23633586402450288, 0.09727438672312669, 0.1362419743090868, 0.21005236224404403, 0.28815058938094545, 0.4490330879177366, 0.3280231255505766, 0.5008664865578923, 0.2613967406962599, 0.25425477964537485, 0.08953445311635733, 0.2985693317438875, 0.23620658953274998, 0.3441199032323701, 0.1903402278465884, 0.16767265275120735, 0.29122212742056164, 0.14316689914890698, 0.26893521047064234, 8.108817866870336, 65.08997399466378, 109.3301271711077, 100.66423661368233, 90.57691138131278, 86.02120685577393, 46.531446729387554, 32.207988943372456, 44.52804831096104, 86.3257394518171, 78.6219173158918, 61.95869186946324, 70.8939710344587, 74.43739250728062, 40.71919175556728, 9.650612711906433, 0.7631655974047524, 0.22319853039724485, 0.16025056530322346, 0.11762000141399247, 0.26828794234565323, 0.3422978738588946, 0.5597683201943124, 1.519210159778595, 4.75464665038245, 5.5806663036346436, 9.97562164919717, 23.237037726811, 24.939961297171457, 20.945035457611084, 20.980412210736954, 22.613836424691335, 52.30365228652954, 104.93443271092006, 111.85160759517125, 109.51985468183244, 101.38545962742397, 102.4071158000401, 104.18273489815849, 104.02604607173375, 98.04591914585659, 95.45097541809082, 92.56455475943429, 109.24947248186383, 108.71376637050084, 104.84268869672502, 104.83443423679897, 126.49719429016113, 63.20062678200858, 50.128584725516184, 121.65723201206752, 152.49836785452706, 141.81291389465332, 147.05471829005648, 106.53087861197335, 65.23773438589913, 122.75996671404157, 118.03370475769043, 105.00143418993268, 94.37139211382184, 102.62562274932861, 95.03880827767509, 99.14424868992397, 93.31636374337333, 105.3875594820295, 104.55309472765241, 108.71795613425118, 103.64514582497733, 113.88690866742814, 108.70066901615688, 114.85607814788818, 108.89008385794503, 106.84674371991838, 101.86815098353794, 99.52129963466099, 50.96869489124843, 40.844356604984824, 19.95821234158107, 3.692915005343301, 0.8186690562537738, 0.6634201354214123, 0.24428378897053854, 0.4076283111103943, 0.11548865506691591, 0.12847969654415334, 3.0242340522153035, 36.14876399721418, 59.62299237932478, 74.44819000789097, 100.27169813428605, 111.2197036743164, 146.70316723414828, 45.19861200877598, 40.22327102933611, 59.72725009918213, 79.33428832462856, 82.59964983803886, 87.29210186004639, 65.60010378701347, 47.76084361757551, 20.13063883781433, 4.910493007728031, 1.0843756071158817, 0.1330879128405026, 0.17654322247420037, 0.13671530676739557, 0.22489180096558162, 0.20483380369842052, 0.12143938003906182, 0.13083516300788947, 0.1971667922501053, 0.18983134015330247, 0.11942558309861592, 0.07927710709295102, 0.26570891216397285, 0.5363212983523096, 0.33598204276391436, 0.506302746278899, 0.3276777240846838, 0.3581518174282142, 0.3283880688250065, 0.09447541620050158, 0.16274665136422428, 0.11622566623347146, 0.20525946228631906, 0.11801779935402529, 0.1967219446918794, 0.12391074028398309, 0.1362589512552534, 0.2071970733148711, 0.12404145326997552, 0.20618567615747452, 0.10763546039483377, 0.0941216755392296, 0.15390730782278947, 0.29658567532896996, 0.3959640498672213, 0.535784441445555, 0.449474461376667, 0.3009033836424351, 0.17822909701083386, 0.21701999407793793], [0.18717817323548452, 0.12221027724444866, 0.22249201259442739, 0.21776775323918887, 0.02069019173671092, 0.1477615311741829, 0.1482164074799844, 0.016990815422364643, 0.11206860108567135, 0.07002354506403208, 0.06764968351594039, 0.026884152853329266, 0.140610735597355, 0.09235914690153939, 0.12314581418676035, 0.007563687528350523, 0.044496789641146145, 0.0259885137701141, 0.021848115138709545, 0.09159146595214095, 0.1304056096289839, 0.35030369141272133, 0.19532788092536585, 0.19564501462238176, 0.0262212292291224, 0.04482342961377331, 0.10000750542219196, 0.011558604859081762, 0.03619346162304282, 0.025628301581101756, 0.07730269911033766, 0.10683168816779341, 0.2931772310818945, 7.157614256654467, 53.561891147068565, 85.57687650408063, 95.21969073159354, 89.94047723497663, 64.54092734200614, 49.92885875701904, 19.409721544810704, 26.624446085521154, 64.87118216923305, 54.48586259569441, 32.55374867575509, 29.237144197736466, 27.00175063950675, 8.213503769465856, 0.925941697188786, 0.33419969411832945, 0.027809868001246026, 0.03082198164026652, 0.06316606660506555, 0.07588080862270934, 0.11838446610740253, 0.4713309428521565, 0.39397838498864857, 1.2331418586628777, 1.0776775436741965, 2.4834514132567813, 3.355836395706449, 6.429093028817858, 7.873662165233067, 12.017170020512172, 23.610348803656443, 81.5795431137085, 95.52068669455392, 95.41472666604179, 88.69073254721505, 90.51497513907296, 93.05101203918457, 99.03307751246861, 90.98957879202706, 88.86309650966099, 73.51389353615897, 73.03576714651925, 70.78766359601701, 76.45679610116142, 81.52732740129743, 92.06830746786935, 86.08847236633301, 101.2324047088623, 78.27002579825265, 39.15072972433907, 104.93643379211426, 83.9161319732666, 81.60300718035016, 76.00365543365479, 103.23616095951625, 63.17134012494768, 100.71739728110177, 89.61522511073521, 87.47983523777553, 87.63419641767229, 101.2378659929548, 98.57885987418038, 98.53862980433873, 89.91629750388009, 98.60948058537075, 99.88479464394706, 97.9396117074149, 99.22668906620571, 101.57538863590786, 101.37648255484444, 103.98213345663888, 106.07869679587228, 99.21223681313651, 96.56827354431152, 98.3333661215646, 87.30658885410854, 62.43581771850586, 32.0742951801845, 16.61268424987793, 2.4769926284040724, 0.2925922524716173, 0.14373457511620863, 0.2167563425110919, 0.060116601309606006, 0.07956732330577714, 0.017442626446219425, 0.07468529777335269, 5.559712707996368, 23.010698420660837, 36.95221199308123, 34.32108552115304, 25.044660227639334, 27.012414387294225, 12.446875282696315, 20.03876280784607, 25.457117455346243, 39.2467086655753, 49.66160672051566, 53.37031888961792, 55.27015093394688, 52.821432045527864, 23.92731867517744, 8.13708574431283, 0.6877184201564107, 0.029187658801674843, 0.008939767572363573, 0.09444075663174901, 0.08486070390790701, 0.05914495951895203, 0.01006600508532886, 0.02642274564797325, 0.03747035935521126, 0.06300376102860485, 0.06292703907404627, 0.10181527877492563, 0.307070859840938, 0.27926560757415636, 0.2632277267319815, 0.2617505559963839, 0.3039607267294611, 0.05893494614533015, 0.05700830702802964, 0.012991734431125224, 0.050404441210308244, 0.09118649589696101, 0.10537055121468646, 0.08120138490838663, 0.040104937806193314, 0.039970978030136654, 0.11082334683409759, 0.004157766159291246, 0.03676507987880281, 0.10095864866993257, 0.054606449125068526, 0.05669253379372614, 0.11595814701701913, 0.2163059173950127, 0.18183897116354533, 0.14336640201509, 0.1954689754971436, 0.04094295569562486, 0.027373307051935365, 0.2406062920178686, 0.15755883045494556, 0.22814917617610522, 0.20551205373236112, 0.09879205921398741, 0.0798209189836468, 0.10138975589403085, 0.035749648830720356, 0.056082551168011766, 0.03832783084362745, 0.05090632302952664, 0.041637097019702196, 0.06936043314635754, 0.047775576024183204, 0.057269604078360965, 0.03917827610192554, 0.071783407059099, 0.04035810939967632, 0.03882037941366434, 0.06287623037184988, 0.12567593556429657, 0.35668976445283207, 0.15367603594703333, 0.1882998730455126, 0.1430275687681777, 0.021480242289336662, 0.04976659454405308, 0.051833103477422676, 0.07723131722637586, 0.05761757040662425, 0.03207370911591819, 0.22070407282028878, 0.3185428242598261, 9.009970562798635, 61.45588547842843, 99.67150579180036, 105.58319296155656, 100.80256829942975, 76.32901178087506, 57.3752292905535, 26.6287522315979, 30.414311477116176, 41.85770968028477, 47.400516986846924, 32.27369805744716, 32.05229023524693, 31.989294392721995, 13.030657717159816, 1.0243126643555505, 0.25932655749576433, 0.007213736485157694, 0.04889866343832441, 0.2676165997982025, 0.3843152592224734, 0.6030442523104804, 2.0813667603901456, 4.331045814922877, 4.030319963182722, 3.921102966581072, 3.5468117594718933, 3.352758777993066, 4.413126187665122, 7.455970338412693, 14.157577361379351, 29.560999734061106, 83.20599828447614, 103.20110729762486, 98.62506539481026, 93.61492783682687, 94.80278491973877, 98.05404853820801, 104.0083976473127, 96.60155541556222, 91.16652161734444, 77.93906920296806, 77.77461229051862, 76.03728471483502, 82.26265525817871, 85.76110798971993, 93.93520505087716, 91.11361108507428, 107.10289600917271, 84.22678593226841, 46.76064000810896, 117.51274272373745, 92.75958374568394, 90.62627833230155, 88.91090706416539, 108.63813522883824, 69.9900381905692, 103.46994004930768, 95.25647449493408, 91.09955487932477, 91.72464261736188, 104.36900915418352, 101.40473393031529, 99.26356315612793, 93.89094502585274, 103.20865998949323, 100.44231115068708, 98.19730649675641, 101.752658026559, 104.65936742510114, 103.16252395084926, 106.9142176764352, 105.9129753112793, 103.6855218069894, 98.70004340580532, 103.19436059679303, 91.89162172589982, 72.14164515904018, 39.38762160709926, 17.027182510920934, 4.9321631363459995, 0.8552891026650156, 0.5630160602075713, 0.3984036275318691, 0.1978365063135113, 0.09667753375002316, 0.09115486259439162, 0.04705397438790117, 7.105861467974527, 27.50086406299046, 39.435369627816335, 46.041741166796, 28.008235420499528, 25.40492606163025, 24.755378927503312, 35.479402337755474, 44.982606410980225, 54.60613243920462, 71.98409475599016, 68.42223276410783, 67.24256760733468, 60.854275703430176, 27.914947169167654, 7.93704971245357, 0.8279503296528543, 0.03648149295310889, 0.053210879010813575, 0.08049552528453724, 0.037012131086417606, 0.02117814153565892, 0.0630759232278381, 0.0653178436415536, 0.10530097423387424, 0.019211192349238054, 0.05853661894798279, 0.03877377762858357, 0.3387261740863323, 0.29852682831031935, 0.17449300177395344, 0.06633274882499661, 0.2406230111207281, 0.036926374438085725, 0.03579990452687655, 0.013559358660131693, 0.011315290683082171, 0.1077711945399642, 0.03650329428325806, 0.11171638712819133, 0.03612817298354847, 0.04710533270346267, 0.0721624299351658, 0.024635572618405734, 0.044539187901786396, 0.05550121968345983, 0.024011471375290836, 0.017206752406699315, 0.11706080713442393, 0.1610610889536994, 0.11911429837346077, 0.10384734866342374, 0.19101085114691937, 0.0490888941234776, 0.06634078946496759, 0.41858648881316185, 0.365826672741345, 0.39933379047683304, 0.4125263568546091, 0.18542129679449967, 0.273970645985433, 0.18172705359756947, 0.09435106787298407, 0.2093983901930707, 0.24663483138595307, 0.11419813574424811, 0.1070741762274078, 0.16945711842605046, 0.20820959684039864, 0.20948022151631968, 0.1761040881808315, 0.12868519765990122, 0.07897980697453022, 0.12210260730768953, 0.17314708685236319, 0.23633529405508721, 0.6510252548115594, 0.356775449854987, 0.4469419244144644, 0.2896338940731117, 0.146733021363616, 0.18491546250879765, 0.07615052629262209, 0.15755136656974042, 0.24417565762996674, 0.23812532371708325, 0.287950122995036, 0.6571836386408124, 20.147656713213237, 84.09210205078125, 111.00632449558803, 120.76404108319963, 112.63615649087089, 88.54856545584542, 72.98037610735211, 29.895298412867955, 39.939152240753174, 94.40805775778634, 77.10390962873186, 49.267140116010395, 46.657862254551475, 44.67219911302839, 16.5728953906468, 2.153649304594312, 0.6794316076806614, 0.10270182548889092, 0.11499382661921637, 0.278043837419578, 0.24493523687124252, 0.27246733808091705, 1.7471365864787782, 5.213312872818538, 5.941349898065839, 8.18801690850939, 9.872571178844996, 12.800607204437256, 18.373097215379985, 18.173440728868755, 20.335803508758545, 31.600445406777517, 94.50683334895542, 109.21359893253872, 105.68474783216203, 98.259263583592, 101.20516777038574, 101.4885014125279, 109.0887814930507, 103.38966751098633, 98.86693218776158, 83.83449063982282, 83.89585712977818, 80.5235767364502, 85.64823450360979, 90.8224607195173, 102.99899114881242, 94.13957936423165, 110.10485131399972, 84.89452866145542, 58.99217932564871, 119.65830475943429, 101.19261237553188, 96.69776712145124, 100.7509570802961, 113.11647156306675, 80.43653665270124, 105.88736425127301, 99.21081938062395, 92.5673826762608, 95.33450971330915, 108.44475296565464, 105.60510063171387, 105.08455548967633, 98.26567677089146, 107.76712989807129, 103.40861524854387, 100.99084363664899, 108.49293872288295, 111.41901275089809, 108.0017010825021, 112.00431510380336, 114.0118442262922, 109.97355120522636, 102.12511621202741, 103.85324437277657, 92.78086607796806, 69.4022136415754, 39.04643726348877, 25.465331963130406, 7.503112997327532, 1.5694030778748649, 0.4826070006404604, 0.41194791932191166, 0.413824448628085, 0.22362675384751388, 0.20687700834657463, 0.30630864788378986, 11.441264237676348, 40.783302783966064, 57.25705432891846, 53.19174671173096, 36.14689493179321, 39.40636437279837, 20.6703679561615, 33.46404259545462, 44.375097615378245, 67.23790536608014, 84.5499188559396, 84.53782204219273, 77.95414679391044, 74.50662435804094, 40.94957317624773, 12.591859868594579, 2.406549836908068, 0.18805648253432342, 0.17878795202289308, 0.21269141563347407, 0.349781762276377, 0.20838916434773377, 0.1768936858113323, 0.19442544292126382, 0.11849224460976464, 0.21830835565924644, 0.14841068562652382, 0.2135694535183055, 0.5278081808771405, 0.4261029469115393, 0.4211933660720076, 0.3329752912478787, 0.45365651696920395, 0.23340323567390442, 0.10222843196243048, 0.09699998716158525, 0.2020739032221692, 0.2537412643432617, 0.2308349534869194, 0.28701173620564596, 0.15073826430099352, 0.11591850700122969, 0.23503484097974642, 0.09313627984374762, 0.1197840395782675, 0.23045698234013148, 0.13453112968376704, 0.15451044403016567, 0.20402009093335696, 0.32115656829306055, 0.25131140330008095, 0.2283351490540164, 0.2862203743840967, 0.11293084946061883, 0.10520272236317396], [0.051562591921538115, 0.07863934524357319, 0.17109588906168938, 0.11798843235841819, 0.08545315997408968, 0.30065143001931055, 0.06744112220725842, 0.08171124969209943, 0.04533215106597968, 0.07104457063334328, 0.05412903527862259, 0.07772292263273682, 0.05545757291838527, 0.16296682240707533, 0.0775225648124303, 0.14997172329042638, 0.05454019696584769, 0.018811475851440003, 0.03666157275438309, 0.11135153206331388, 0.15194015337952546, 0.12334356643259525, 0.10653551441750356, 0.141837621905974, 0.08014208317867347, 0.029785933305642436, 0.05678384085851056, 0.032198759727180004, 0.037194378807076385, 0.09707590844482183, 0.04861057782545686, 0.25990257944379536, 19.469599383217947, 68.11289201463971, 101.08740970066616, 88.72856548854283, 85.3260395867484, 74.81551347460065, 50.94812822341919, 33.66257694789341, 60.99558816637312, 62.58532905578613, 50.484558309827534, 39.22410617555891, 41.384002344948904, 21.84056966645377, 4.248527271406991, 0.264251744640725, 0.2466520933168275, 0.06455263934497323, 0.1693165259701865, 0.060380639641412666, 0.055679494581584416, 0.3598272018134594, 2.98248428106308, 2.5589398997170583, 1.5731844178267886, 3.018686132771628, 3.2586119898727963, 5.076012994561877, 9.736678310803004, 17.676003558295115, 42.83468198776245, 70.49206638336182, 80.25682844434465, 92.87541021619523, 84.7197745186942, 88.47439343588692, 85.95708887917655, 86.23415524618966, 87.59919834136963, 94.21529388427734, 87.8693026133946, 86.29193646567208, 74.36631243569511, 73.55579117366246, 75.9882721219744, 84.08980914524624, 81.82904597691127, 83.04875360216413, 92.65691716330392, 98.56826387132917, 97.3634809766497, 26.827121564320155, 74.69709532601493, 84.71381296430314, 82.04704570770264, 66.04066821507045, 84.87695666721889, 49.37115117481777, 106.4544345310756, 102.05996295383999, 85.22775731767926, 78.35351535252163, 84.17129067012242, 90.128036907741, 92.30527578081403, 95.67688914707729, 95.24184853690011, 96.91731630052838, 97.37734958103725, 97.26934678213937, 100.15117468152727, 101.68758119855607, 103.69561753954206, 97.04487133026123, 93.06836863926479, 95.72892420632499, 93.03348868233817, 92.09011786324638, 96.3327921458653, 69.29765714917863, 45.975260802677695, 19.35851158414568, 4.256078226225717, 0.41030404610293253, 0.09240152141345398, 0.043705254793167114, 0.02962905940200601, 0.12449782235281807, 0.08645350379603249, 0.1657206839216607, 1.1520368392978395, 17.67874983378819, 30.340705735342844, 62.511608668736045, 67.70604719434465, 52.705351965767996, 19.901549782071793, 12.98756412097386, 26.27065944671631, 24.230274030140468, 44.06192146028791, 51.775286946977886, 64.27742385864258, 57.018936089106965, 35.957712854657856, 15.574149165834699, 1.3007676984582628, 0.24393998884728976, 0.07366025527673108, 0.01665181084536016, 0.03620644539062466, 0.05585357952596886, 0.03177072287404111, 0.03680672835824745, 0.04799187941742795, 0.019159357362825955, 0.1200243631111724, 0.12984451545136316, 0.3051878980227879, 0.23059974610805511, 0.2120112114186798, 0.15071461057024343, 0.10287671110459737, 0.03554713326905455, 0.020157222835613147, 0.05177497677505016, 0.10091146334473576, 0.03358254708083613, 0.09064385787184749, 0.0353463954691376, 0.04131516608010445, 0.04781156552157231, 0.03774214994960597, 0.014474900871781366, 0.011729314939917197, 0.04828574614865439, 0.012753921477789325, 0.15338358735399588, 0.18099525357995713, 0.2711276928228991, 0.14248621995959962, 0.20588015897997788, 0.0028145352677841273, 0.0690395539360387, 0.14064559872661317, 0.09048223761575562, 0.12774260395339557, 0.20752290583082608, 0.12216668815485068, 0.13411602910075868, 0.14258789164679392, 0.04192411393991538, 0.032644224752272875, 0.1132197832422597, 0.02290297076771302, 0.07524548271404845, 0.06980023240404469, 0.09754986515534775, 0.03321594139561057, 0.1901624516717025, 0.03779176103749445, 0.052652967162430286, 0.035173097625374794, 0.022834280971437693, 0.149813977469291, 0.07270469476601907, 0.07789667509496212, 0.06569891569337674, 0.11641291475721768, 0.01485332494069423, 0.07328326122037002, 0.04591954526092325, 0.005252437799104622, 0.1027192502681698, 0.037509042636624405, 0.26375899251018253, 22.384481600352697, 79.45740345546177, 112.26986135755266, 99.43419006892613, 97.42807143075126, 90.3808957508632, 70.95020975385393, 51.218423570905415, 32.2262453351702, 31.273695945739746, 46.136097703661235, 38.665429319654194, 43.71812459400722, 29.22306019919259, 7.06537344626018, 0.37844731552260263, 0.2244955093732902, 0.09563852700271777, 0.2304413488933018, 0.4773700673665319, 0.31813681604606764, 2.0064571457249776, 4.324167098317828, 4.5142150947025845, 1.6399632287876946, 2.3294743384633745, 1.731640800833702, 2.0453210260186876, 8.2762051820755, 20.481350898742676, 45.194411822727744, 75.86564336504254, 91.47072069985526, 101.3214806147984, 91.54691464560372, 94.75277873447963, 91.72523321424211, 91.0104511805943, 93.42396354675293, 96.89436640058244, 92.86200019291469, 91.3585489818028, 79.29907485416958, 79.40295042310441, 80.77515711103166, 88.95603561401367, 86.78261825016567, 87.97507504054478, 95.65639890943254, 101.65191609518868, 98.94502299172538, 33.19218042918614, 82.74104567936489, 97.48140580313546, 88.65336513519287, 75.7736005783081, 89.30470316750663, 58.325228691101074, 110.12174933297294, 104.16162627083915, 86.80619348798479, 79.23138550349644, 84.98655755179269, 91.97244317190987, 96.3196461541312, 99.90787655966622, 98.23368726457868, 97.32846900394985, 99.33993080684117, 101.77854006631034, 105.22865418025425, 102.3961237498692, 103.79671382904053, 97.81210531507219, 96.30799402509416, 97.25965404510498, 96.79368005480084, 96.66211591448102, 100.58645847865513, 75.9137179510934, 51.9059408732823, 22.26934994970049, 4.68137355361666, 1.1815590837172099, 0.7873068962778363, 0.5111142109547342, 0.08432259849671807, 0.13337247685662337, 0.03728543142122882, 0.18939402433378355, 1.8396276405879428, 19.264116832188197, 32.179758412497385, 46.134284223829, 45.00172437940325, 30.59585748400007, 20.01847927910941, 24.06808396748134, 46.67229018892561, 40.23768854141235, 61.082246099199565, 69.12415368216378, 75.4644752229963, 66.6872397831508, 40.79014328547886, 17.210753917694092, 1.2776030557496207, 0.19414686358400754, 0.12262050594602313, 0.01580560812726617, 0.02370607463776001, 0.04074438920776759, 0.04726349921630962, 0.01665286935998925, 0.11977870629302093, 0.044480684612478526, 0.0654812620154449, 0.23389786056109838, 0.27394554018974304, 0.16651778614946774, 0.08101543917187623, 0.08262436783739499, 0.030527015682309866, 0.06020099070987531, 0.08813049630927187, 0.023873082461899946, 0.09766788275114127, 0.06363474431314639, 0.012025964512888874, 0.06633171066641808, 0.05952353456190654, 0.045383926680577655, 0.05872494634240866, 0.022844184190034866, 0.04451133403927088, 0.048004110011139085, 0.06822344594235931, 0.17449178041091987, 0.10390176717191935, 0.14237968996167183, 0.1321125051804951, 0.10033654740878514, 0.021469628305307457, 0.13186383566686086, 0.41717627591320444, 0.1632623922611986, 0.31963667699268883, 0.5222948395780155, 0.1428137081010001, 0.31859973977719036, 0.21782821070935043, 0.15681473538279533, 0.19756228317107472, 0.19891749402242048, 0.1554711139095681, 0.20299705011504038, 0.1690763652856861, 0.17138756412480557, 0.1443394348025322, 0.20173676631280354, 0.10588845663837024, 0.10830243317676441, 0.09605851982321058, 0.4247152070913996, 0.3587528094649315, 0.31813114349331173, 0.2063922764999526, 0.22555586961763247, 0.2436090266065938, 0.16741075180470943, 0.2067069403295006, 0.19757957224334988, 0.2502512059041432, 0.26551132276654243, 0.12699157425335475, 1.2538300114018577, 42.45491082327706, 103.09686347416469, 125.80595970153809, 112.86328615461076, 108.86979511805943, 97.930148260934, 74.90895979745048, 52.087337493896484, 89.15903418404716, 86.15702329363141, 68.92703328813825, 59.2090117590768, 63.632026536124094, 38.503616196768625, 8.7435462304524, 0.7679186537861824, 0.4846464054925101, 0.20129677706531116, 0.3114861414900848, 0.2806760918881212, 0.16032476989286287, 1.5872049054929187, 6.27437618800572, 7.85687358038766, 7.883029205458505, 12.40206982408251, 11.928949611527578, 15.46578506061009, 18.34864476748875, 25.439929349081858, 50.798116615840364, 85.08090019226074, 96.3157343183245, 107.0417171205793, 92.76770618983677, 100.36540154048375, 98.46247059958321, 96.91974817003522, 97.68342467716762, 101.9777032307216, 98.54758603232247, 97.97541577475411, 83.41810594286237, 86.19459220341274, 87.08458001273019, 92.3740143094744, 87.54393931797573, 91.0046146937779, 99.5770936693464, 108.59461866106305, 101.39183112553188, 39.71789033072335, 93.98311982836042, 107.31648363385881, 95.95605387006486, 84.14833382197789, 93.35209138052804, 63.86723000662667, 113.73547962733677, 108.60203238895961, 90.71594483511788, 81.61983571733747, 87.55082498277936, 97.3730833871024, 100.11989389147077, 107.55042948041643, 102.18188994271415, 102.5623802457537, 103.84187711988176, 107.64419542040143, 108.81649548666817, 106.26761136736188, 108.1967578615461, 104.18889100211007, 98.54846150534493, 102.34731960296631, 102.76933928898403, 102.81145926884243, 106.88633455548967, 75.360488482884, 57.026440143585205, 26.986949239458355, 10.054775527545385, 2.70215573481151, 0.7040331704275948, 0.3039430305361748, 0.1635381624634777, 0.19400697680456297, 0.10064822568425111, 0.22976368239947728, 3.1524871587753296, 34.00603335244315, 52.261174474443706, 89.9821594783238, 93.59442370278495, 74.3001377923148, 30.58764123916626, 24.872386591775076, 46.30430664334978, 46.142014094761436, 75.29206262316022, 85.68059921264648, 89.52106312343052, 77.63534259796143, 51.667075702122276, 26.1891188621521, 3.0219385411058153, 0.37760414076702936, 0.09658802141036306, 0.1496927911149604, 0.16405046997325762, 0.17554965721709387, 0.1684727541037968, 0.12119353323110513, 0.2268869246223143, 0.11629218980669975, 0.22541606426239014, 0.4192113109997341, 0.5487793641430991, 0.31480092076318605, 0.2534034896109785, 0.2972622833081654, 0.2353805410010474, 0.19947286136448383, 0.08676271220403058, 0.16316316330007144, 0.24142878502607346, 0.08369636495730706, 0.16065267872597488, 0.15229570572929724, 0.14427464827895164, 0.191365887810077, 0.14853675743298872, 0.09933625108429364, 0.13525808496134623, 0.1631204698766981, 0.13897405484957354, 0.22515314551336424, 0.3246942056076867, 0.38752036009516033, 0.2990335039794445, 0.33702847946967396, 0.09416355472058058, 0.20037403729345116], [0.09253937937319279, 0.07298940805984394, 0.16581316824470246, 0.033647418421294005, 0.11453312848295484, 0.10180605069867202, 0.09157380368560553, 0.033760659130556245, 0.027042368559965065, 0.010783462568984499, 0.05813038681766816, 0.02135090164041945, 0.056823877817285914, 0.04728206054174474, 0.0671051252367241, 0.1136286413030965, 0.02634316197197352, 0.03151270314784987, 0.004901026209284152, 0.020202319969290068, 0.0504606883706791, 0.07912492525896855, 0.04434880454625402, 0.06494116171130113, 0.06763147163603987, 0.12601719796657562, 0.03288115221740944, 0.06172677169420889, 0.24493621396166937, 0.11967118563396589, 1.84841211778777, 57.357143129621235, 96.06051308768136, 100.88421658107212, 83.74939605167934, 73.67207622528076, 60.97997556413923, 36.87609795161656, 18.828464780535015, 22.706612246377126, 59.42522580283028, 54.838813713618684, 37.34002569743565, 29.22449847630092, 10.743102295058113, 0.8533444755843708, 0.4384099436657769, 0.3601551242172718, 0.14403762242623738, 0.18198410980403423, 0.1303358290876661, 0.16447778418660164, 0.5287684979183334, 1.8606926245348794, 5.872086346149445, 4.3244141936302185, 4.349364740507943, 3.127388962677547, 9.68523211138589, 21.092010702405656, 44.7584262575422, 66.79821641104562, 81.61333220345634, 74.5101123537336, 83.92382362910679, 88.82379055023193, 88.0988849912371, 77.80020945412772, 81.73972688402448, 81.40087018694196, 89.43211923326764, 86.88455527169364, 88.55724375588554, 69.5789966583252, 64.91327435629708, 67.57449695042202, 76.2279919215611, 75.3554996762957, 86.35922976902553, 84.0096686226981, 92.76324544634137, 87.37518841879708, 103.46452740260533, 42.05547278267996, 51.977413518088206, 76.61073344094413, 62.783769607543945, 72.50408404214042, 80.14084216526577, 48.69665479660034, 102.73276397160122, 94.82172570909772, 94.4476624897548, 84.59930665152413, 74.62731456756592, 81.67394133976528, 90.58215032305036, 91.15332004002163, 92.2856262751988, 89.31847449711391, 88.93828991481236, 93.21318994249616, 94.09238025120327, 94.87196813310895, 93.11794403621128, 91.50066743578229, 94.62623119354248, 97.84258011409214, 87.02875123705182, 87.00312628064836, 90.49554102761405, 91.37063884735107, 67.89610821860177, 42.50171736308506, 13.668986116136823, 3.5602702030113766, 1.3135615033762795, 0.0507969024724194, 0.17869766615331173, 0.01787415605836681, 0.02239236468449235, 0.03328240390068718, 0.155050272920302, 0.1927692067942449, 9.478354709489004, 24.750548192432948, 46.349859033312114, 69.38849789755685, 44.394580364227295, 35.949837071555, 8.97978845664433, 20.20587740625654, 25.91719937324524, 28.15777976172311, 44.80809198107038, 59.52747549329485, 64.65257794516427, 43.711256299700054, 21.311910765511648, 5.020969365324293, 0.39025149068662096, 0.19847679909850868, 0.04177694308704563, 0.04732641637591379, 0.0755918137729168, 0.05065223880644355, 0.06272262361432825, 0.04193346754514745, 0.04105035082570144, 0.13946763479283877, 0.32124920189380646, 0.184590769931674, 0.19951611118657248, 0.01597114692309073, 0.04367457822497402, 0.03066955553367734, 0.033643903609897406, 0.044642053810613494, 0.035182977095246315, 0.04183804516547492, 0.06931929356817688, 0.024167665047571063, 0.08535007693405662, 0.020373091966445957, 0.13590612661625656, 0.02052056646373655, 0.030224643514624665, 0.04920138844421931, 0.023868968843349388, 0.05832013235028301, 0.06549815753740923, 0.13356295520705835, 0.2227505480072328, 0.16164359769650868, 0.05517008102365902, 0.024880693393892477, 0.10699267060096775, 0.0768836901656219, 0.17773505566375597, 0.11945781351200171, 0.056466038804501295, 0.09723839044038739, 0.06543479593736784, 0.01389825382336442, 0.026833459502086043, 0.06258311002914395, 0.05914508844060557, 0.061296356575829644, 0.04646831384993025, 0.034542012560580454, 0.06831355539283582, 0.08211328169064862, 0.02139328633035932, 0.007650982754837189, 0.02002359045270298, 0.04792274687705295, 0.03439021070620843, 0.17369843726711615, 0.06725611284907375, 0.055835591562624486, 0.03994391126824277, 0.05520913749933243, 0.018233309732750058, 0.025321812402190905, 0.18482759222388268, 0.09043439411159072, 1.5660728280033385, 60.80616637638637, 110.34649576459611, 113.98505197252545, 98.28950909205845, 88.4033897944859, 73.95323508126395, 64.85231086186, 37.375687326703755, 32.4549765586853, 55.678298541477744, 49.00178146362305, 43.01030118124825, 36.04040336608887, 16.672362327575684, 1.3460137162889754, 0.4104760411594595, 0.39318145917994635, 0.17346768107797417, 0.33826202899217606, 0.6184277811220714, 0.7993077923144613, 1.2734909164054053, 4.04308727809361, 3.704626194068364, 1.4664966740778513, 2.1046167356627326, 3.671566230910165, 11.174842510904584, 26.397142716816493, 50.24250044141497, 74.10531030382428, 88.59898853302002, 83.70558071136475, 92.14210428510393, 93.39908899579729, 93.30737972259521, 81.42046410696847, 87.09376553126744, 88.23643847874233, 93.11087771824428, 94.04957934788295, 93.82053198133195, 74.3839886529105, 70.27436542510986, 73.48407186780656, 80.95071724482945, 79.37372629983085, 88.96927888052804, 89.24313517979213, 98.67060388837541, 90.52038778577531, 106.87640557970319, 46.55354200090681, 58.21090303148542, 88.98657989501953, 68.95410346984863, 83.61702592032296, 85.86817278180803, 54.70323698861258, 101.31160722460065, 99.31232561383928, 96.6845794405256, 88.27016503470284, 75.81260776519775, 85.40653446742466, 91.60548101152692, 97.39591516767229, 94.92970071520124, 91.89424119676862, 91.25283908843994, 96.35068375723702, 97.57635988507951, 98.4860805783953, 94.27910614013672, 94.94566767556327, 96.71852833884103, 101.22608879634312, 90.91640731266567, 89.78733198983329, 93.12955447605678, 98.93022332872663, 73.95246383122036, 46.679200172424316, 16.15131344114031, 4.679889244692666, 1.9527645068509238, 0.9695103764533997, 0.5361712064061845, 0.28185693281037466, 0.16954304810081208, 0.010906377491275114, 0.14546027965843678, 0.9016923755407333, 12.270100951194763, 29.996881076267787, 38.98680087498256, 56.10724210739136, 37.96681227002825, 31.680405276162283, 19.567190306527273, 29.214732783181326, 36.778142247881206, 39.70910433360508, 58.46761812482561, 70.56504331316266, 74.77523476736886, 52.83644710268293, 24.076935972486222, 6.647623862539019, 0.2321845596390111, 0.2790502134178366, 0.11007026795830045, 0.05329269337068711, 0.034293974084513526, 0.00499754908794005, 0.058737451742802343, 0.0337599772028625, 0.03933679545298219, 0.0960698581433722, 0.3208449850124972, 0.18112089112401009, 0.20572043183658803, 0.04121305334514805, 0.045956844330898354, 0.025645400663571696, 0.059363115312797685, 0.03735532731349979, 0.10255637472229344, 0.05303193236302052, 0.006911920292103397, 0.05387487302401236, 0.06368937995284796, 0.03699257570718016, 0.1596451085060835, 0.04782199799748404, 0.04098538788301604, 0.056868230258779864, 0.04254297858902386, 0.09936978428491525, 0.07623324649674551, 0.14376558416656085, 0.11381626302110297, 0.19800254383257457, 0.056757934391498566, 0.01482122005628688, 0.16869232803583145, 0.2552540717380387, 0.3252673777086394, 0.1974055144403662, 0.2441141280744757, 0.1863021438143083, 0.2609350654695715, 0.07023448124527931, 0.1636165739702327, 0.12932884240789072, 0.16032809471445425, 0.09137726601745401, 0.1697454008140734, 0.09797394954200302, 0.13117529904203756, 0.2589296687926565, 0.1129856411633747, 0.13748192920216493, 0.16062700296086924, 0.2497836681348937, 0.2620276968394007, 0.5241652077862194, 0.17340575797217234, 0.2925148994794914, 0.2173316723534039, 0.18515889373208794, 0.07798573960150991, 0.21417595525937422, 0.25126965982573374, 0.3649102433451584, 5.560591220855713, 87.88121877397809, 129.86737632751465, 127.30649266924176, 109.76135322025844, 99.5508086340768, 85.63407407488141, 54.88309805733817, 30.794742720467703, 36.88942807061331, 81.1401390348162, 79.71919073377336, 57.89549650464739, 49.80841868264334, 20.49953086035592, 2.377954742738179, 0.6359656314764703, 0.453415935592992, 0.23422157604779514, 0.43329617806843346, 0.45711606847388403, 0.406937372471605, 2.306403930698122, 7.372425198554993, 14.580304895128522, 10.939141375677925, 12.361600041389465, 10.350880827222552, 17.28706771986825, 27.507706301552908, 52.76097924368722, 75.78748307909284, 92.52777099609375, 86.72564996991838, 93.37186595371791, 96.55490521022251, 99.86320659092495, 86.35896573747907, 91.62046132768903, 92.04043129512242, 98.0113171168736, 98.5255880355835, 101.02547345842633, 78.2407808303833, 74.33946459633964, 78.62532888139997, 89.4216205051967, 84.86528369358608, 95.47615568978446, 94.41060774666923, 100.59972258976528, 92.19692557198661, 110.27607577187675, 52.33415487834385, 65.0627509525844, 101.8856257029942, 77.52928529466901, 91.3951312473842, 92.68065915788922, 64.93254171098981, 105.49579851967948, 103.97766576494489, 100.12683514186314, 90.96533652714321, 79.85607719421387, 88.68472930363247, 95.57415308271135, 100.00383118220738, 96.2194322858538, 93.21828297206334, 93.91452026367188, 101.08582551138741, 100.7530415398734, 101.53349794660295, 98.86019243512834, 97.93096120016915, 103.26578113010952, 105.73064763205392, 94.96996552603585, 93.48665714263916, 99.30311230250767, 102.32313292367118, 76.60277775355748, 50.514004775456016, 18.990079879760742, 8.507958003452845, 6.202180062021528, 1.3288607852799552, 0.44136716212545124, 0.20073135383427143, 0.26178128006202833, 0.12328020483255386, 0.23517035799367086, 1.246438430888312, 20.09993474824088, 43.20716101782662, 65.97394466400146, 97.82199260166713, 70.45731844220842, 53.31920794078282, 19.384589910507202, 36.18201807567051, 45.25546216964722, 51.180562836783274, 71.6310567855835, 84.83995056152344, 88.03353023529053, 63.88441290174212, 35.290991510663716, 10.215561185564313, 0.6520897405488151, 0.49995057284832, 0.19244515204003879, 0.09246153105050325, 0.13776877309594834, 0.14430341816374234, 0.26182845181652475, 0.07969966477581433, 0.14166785244430813, 0.2405841989176614, 0.5806994970355714, 0.4101594638611589, 0.26227009668946266, 0.1816037366432803, 0.1982186979481152, 0.1717132745044572, 0.14913017701889786, 0.19224032945930958, 0.2604564540088177, 0.16204459832182952, 0.09859871744577374, 0.1243599576077291, 0.21171442020152295, 0.20795244563903126, 0.3334113178508622, 0.14140720000224455, 0.09899906667747668, 0.09460226832223789, 0.2551382322396551, 0.20691945749734128, 0.16075185340430054, 0.29131253542644636, 0.45152941825134413, 0.30043969995209147, 0.1381233347845929, 0.12693613794233116], [0.08295131315078054, 0.08335848165942089, 0.05408358700307352, 0.07671986467071942, 0.06581519623952252, 0.035493220269147835, 0.01808223221451044, 0.036642108977373154, 0.026936696908835853, 0.023067086336335967, 0.07129355227308613, 0.03833782905712724, 0.05200229957699776, 0.07684521723006453, 0.0832538583448955, 0.14586129385445798, 0.04681874326031123, 0.0025693744163228466, 0.04236302092405302, 0.04829159172784005, 0.08869350395564522, 0.04158374720386096, 0.04445620646168079, 0.018356282330517257, 0.063808035371559, 0.07080934968377862, 0.02962155480469976, 0.10497789657009499, 0.08298499562910625, 5.043329536914825, 66.00312014988491, 113.89831066131592, 100.76996040344238, 92.43660368238176, 62.32193674360003, 49.89035184042794, 30.953008787972585, 11.360428895269122, 30.018681049346924, 39.85480458395821, 31.074529307229177, 27.39244089807783, 25.60596350261143, 9.369602373668126, 0.149112643674016, 0.06759738882205316, 0.07652218706373658, 0.0556767431220838, 0.09036589600145817, 0.13611609249242715, 0.17973661183246545, 1.804898481283869, 1.6831635449613844, 2.391100517341069, 6.257049117769514, 6.9337224534579684, 9.117431402206421, 26.437091384615215, 47.49790988649641, 67.12252358027867, 79.74731704166958, 78.89484255654472, 82.95633561270577, 86.94829109736851, 92.31243937356132, 83.98252895900181, 80.4040607724871, 74.46528257642473, 74.68871579851422, 75.42676040104458, 81.13339233398438, 82.30127334594727, 75.64714336395264, 64.52924047197614, 69.66136755262102, 73.09411117008754, 76.12788227626255, 78.19356087275914, 77.70538738795689, 78.9716270991734, 89.16154943193708, 89.81012208121163, 100.6946975163051, 76.55658612932477, 33.45373841694423, 82.86211803981236, 71.83940546853202, 90.1507158279419, 55.16034507751465, 32.761121136801584, 93.53867135729108, 99.46128109523228, 96.58576910836356, 94.43121610369, 78.08245917728969, 68.32848766871861, 74.95697184971401, 87.83301217215401, 93.50019223349435, 92.24477781568254, 90.21954468318394, 92.07867418016706, 93.41459042685372, 95.91222463335309, 95.57235349927629, 93.13432094029018, 92.43720122746059, 90.6246246610369, 91.25288772583008, 91.74251338413784, 94.30859429495675, 93.97904818398612, 84.48628030504499, 58.993054798671174, 28.27647931235177, 11.049083590507507, 4.169431584221976, 1.1966823807784488, 0.36515296889202936, 0.39553277300936834, 0.1149334234318563, 0.091709612469588, 0.0353384633947696, 0.08419489820620843, 0.09749338390039546, 5.246984711715153, 19.10880548613412, 32.8491860798427, 42.318809509277344, 53.8460898399353, 45.187939575740266, 19.584097010748728, 37.2970997265407, 32.802118982587544, 30.124766145433696, 51.35777316774641, 62.66900621141706, 74.83425276620048, 65.01632308959961, 39.66766875130789, 10.477219922201973, 1.131993891937392, 0.22784644099218504, 0.05448517795386059, 0.029312013914542537, 0.08153683905090604, 0.03724882445697274, 0.055726975069514344, 0.11266717075237206, 0.056388831697404385, 0.05128262498016868, 0.1621681595487254, 0.10876654434416975, 0.11318501510790416, 0.08419845372970615, 0.010857444938405283, 0.03812013127441917, 0.024683229525440505, 0.01654054976201483, 0.06002343845154558, 0.028497324059052125, 0.02693681395612657, 0.03367205263514604, 0.12837813342256205, 0.1602096225001982, 0.04094534074621541, 0.0683029702465449, 0.07949706778994628, 0.05143946156437908, 0.02269927455511476, 0.054029524725462706, 0.1506035208169903, 0.2225054068756955, 0.11564990212874753, 0.03678358013608626, 0.017673745651596358, 0.082492725258427, 0.07164667546749115, 0.11190037189849786, 0.06482250629259007, 0.11427228605108601, 0.009811437406044985, 0.026472757071522728, 0.027769666497728655, 0.01552439437779997, 0.04658082174137235, 0.04509196663275361, 0.07474552454160792, 0.035647882148623466, 0.03835940307804516, 0.04671339391331587, 0.0787140926612275, 0.03432150225022009, 0.059167975426784584, 0.03486525985811438, 0.06645285630864756, 0.09488363643842083, 0.07622631186885492, 0.07253367001456873, 0.046397278018827946, 0.11684651220483439, 0.05747141396360738, 0.06873331072607211, 0.050006460065820386, 0.08832623330610138, 5.820662728377751, 76.82328578404018, 129.73763956342424, 112.62200995853969, 105.4482033593314, 79.07318196977887, 67.99598857334682, 54.948939187186106, 26.687959568841116, 31.54609659739903, 32.01389796393258, 42.282237665993826, 36.865797247205464, 34.51084082467215, 14.44217210156577, 0.5084401315876416, 0.023552830896473358, 0.09835033291684729, 0.036977746324347596, 0.09675789265228169, 0.6680979015571731, 2.2979477558817183, 2.5548087613923207, 1.227502201284681, 1.6759727022477557, 5.534164181777409, 8.600858892713275, 13.489224927765981, 30.90855768748692, 53.46907711029053, 72.1466200692313, 84.57971273149762, 85.64529541560582, 87.333895274571, 90.58675697871617, 95.6313784463065, 88.63300691332135, 84.78181498391288, 80.4774476460048, 79.7719692502703, 79.85456943511963, 86.67089816502163, 86.16643115452358, 80.9817201069423, 70.51469666617257, 72.51035826546806, 78.14755684988839, 82.53626837049211, 81.44920880453927, 85.46633761269706, 82.44362803867885, 92.44970103672573, 92.6160478591919, 104.51150975908551, 81.4788567679269, 42.21521186828613, 90.86270468575614, 79.8223158972604, 99.96625532422746, 63.09141499655587, 39.38664885929653, 100.30274963378906, 103.10303347451347, 100.6585807800293, 96.66314424787248, 80.07396575382778, 68.76030431474958, 77.99592631203788, 88.54123510633195, 95.99510274614606, 95.92055552346366, 94.2792659487043, 96.68474619729179, 96.08403968811035, 96.48110144478935, 97.0160710471017, 97.39294828687395, 95.6988593510219, 93.11166981288365, 93.42852851322719, 94.48669052124023, 97.05491147722516, 95.25740555354527, 89.54784148080009, 64.92798369271415, 33.33159603391375, 13.549543108258929, 4.062599556786673, 2.2496432278837477, 1.76747222670487, 1.0946784828390395, 0.49783392356974737, 0.2827066486435277, 0.0720907427104456, 0.13174567557871342, 0.12244111485779285, 6.258601605892181, 24.08662870952061, 29.86464296068464, 36.645956243787495, 40.74906553540911, 32.7940799168178, 32.41896057128906, 49.94332838058472, 41.569939613342285, 41.61031559535435, 61.90820625850132, 72.36729485648019, 85.72080843789237, 75.40647860935756, 47.750334467206685, 13.165612578392029, 0.7574486413172313, 0.23724355388964924, 0.11497972666152886, 0.05989804518009935, 0.042677365842142274, 0.038809648382344415, 0.04465142437922103, 0.15394090887691292, 0.028480737270521264, 0.06015343219041824, 0.17433293536305428, 0.058970962784120014, 0.14352151512035302, 0.04241588219468083, 0.03669598126517875, 0.04175452429002949, 0.038837203689451726, 0.049345556779631546, 0.03981087090713637, 0.03284383618405887, 0.04709640318261726, 0.04198476139988218, 0.037723147576408725, 0.01862305515844907, 0.007088608266453126, 0.028108949274090782, 0.05394998685057674, 0.019714441416519027, 0.061644261835941246, 0.048660093918442726, 0.1172681674361229, 0.13131711286093506, 0.07520939143640654, 0.051563847211322615, 0.012663596592444395, 0.22855594434908458, 0.19056875844086918, 0.2750974212374006, 0.19798045073236736, 0.1918493847229651, 0.13980896504861967, 0.13292587867804936, 0.22640384840113775, 0.09663931865777288, 0.14727432946009295, 0.11569628678262234, 0.1754524910024234, 0.16602367694888795, 0.12250211515596934, 0.16658820451370307, 0.4269562454095909, 0.10376388885612998, 0.16866772435605526, 0.20080174505710602, 0.18650267805371964, 0.29074234887957573, 0.23191892674991063, 0.189644118770957, 0.24156446488840239, 0.273540129086801, 0.17303700133093766, 0.07043228777391569, 0.2053890624748809, 0.18621660768985748, 13.183177624429975, 104.76401424407959, 139.6464238848005, 123.92162214006696, 117.34765352521623, 86.69844082423619, 72.33090714045933, 50.8639612197876, 20.144446645464214, 45.42129135131836, 61.75795146397182, 50.76686709267752, 46.81921679633004, 44.52550179617745, 19.14589670726231, 0.9406736152512687, 0.2251918220094272, 0.19568985221641405, 0.27389074170163696, 0.23996773628251894, 0.22678010963967868, 1.5276086862598146, 6.123116510254996, 8.056962592261177, 10.249894840376717, 17.831643206732615, 14.050723620823451, 14.152794395174299, 32.52223859514509, 54.11192444392613, 72.79061385563442, 87.29655565534318, 86.56696006229946, 91.75511046818325, 96.24598135266984, 101.11223561423165, 93.44371032714844, 88.29145431518555, 83.9101426260812, 86.06637709481376, 85.79351438794816, 92.48886803218296, 90.82181453704834, 88.60233756474086, 76.48403998783657, 77.76113278525216, 82.97696481432233, 86.97083105359758, 87.98953424181256, 88.47135707310268, 86.91298730032784, 95.34010301317487, 95.12220750536237, 109.71883024488176, 82.61361571720668, 49.54722547531128, 103.27978869846889, 86.49156515938895, 110.38574613843645, 71.49940926688058, 44.34075614384243, 104.20740100315639, 105.86455331529889, 103.23295783996582, 101.19214684622628, 83.03280748639787, 73.12047958374023, 83.50722353799003, 93.3495761326381, 99.56036240713937, 100.8569449016026, 96.8710412979126, 101.50341919490269, 101.35970960344586, 100.48459093911308, 100.71759183066231, 103.88716547829765, 99.46728433881486, 97.74970354352678, 98.19144221714565, 98.8733662196568, 101.3275602885655, 98.53605897086007, 89.99589606693813, 66.9030647277832, 35.946133681706016, 17.8632800919669, 9.773099899291992, 6.33400171995163, 2.4867641840662276, 0.9389153953109468, 0.3139497664357935, 0.21886178239115647, 0.15503527729638986, 0.20527767416621956, 0.6951269911868232, 12.193510958126613, 37.04264627184187, 48.943691049303325, 61.372979572841096, 73.47310066223145, 66.02821009499687, 34.44175836018154, 51.08268008913313, 49.82272154944283, 51.06550761631557, 73.23925903865269, 84.53347941807338, 95.94217831747872, 85.78204986027309, 61.75162165505545, 20.636827264513286, 1.7952421137264796, 0.3508565074631146, 0.20639843759792192, 0.1739805992692709, 0.24357048581753457, 0.1309447871255023, 0.17678578517266683, 0.24602838392768586, 0.1715575507176774, 0.15668835145022186, 0.3295854117189135, 0.1819879910243409, 0.27780865718211445, 0.2130533190710204, 0.09696319020752396, 0.14866637119225093, 0.11157764707292829, 0.18133809018347943, 0.19459716656378337, 0.1098876063312803, 0.2772493543369429, 0.12279643650565829, 0.23693245915429934, 0.1772326547652483, 0.05979614957634892, 0.148633407961045, 0.14613823113696917, 0.15809431672096252, 0.1878885179758072, 0.14792876291487897, 0.2471998067838805, 0.4222773393349988, 0.09540511774165289, 0.13531267988894666, 0.122604601085186], [0.03463387941675527, 0.05954322564814772, 0.02028872461856476, 0.03305980030979429, 0.04099702136591077, 0.013755415416588741, 0.034999433372701914, 0.037965584745896716, 0.04635806208742516, 0.06632229938570942, 0.032178614022476335, 0.08237478908683572, 0.042074158388589106, 0.0790455366617867, 0.06618463141577584, 0.029652200838817016, 0.04323134897276759, 0.09058893724743809, 0.03778798159744058, 0.03987565403804183, 0.14942200135971817, 0.12719285488128662, 0.020663479509364282, 0.08942631499043532, 0.18854892253875732, 0.03179614418851478, 0.03498511289113334, 0.18346218977655682, 8.272770166397095, 97.36022227151054, 110.40294292994908, 102.96162373679024, 87.36687837328229, 73.70152269090924, 40.3394136428833, 14.236365590776716, 16.863842521395, 43.163859844207764, 71.32946327754429, 52.74231290817261, 43.936270236968994, 30.03745855603899, 12.262441430773054, 0.29683391058019226, 0.09109232880707298, 0.12875542603433132, 0.1142936327627727, 0.2117542094950165, 0.2011705966932433, 0.3909907138773373, 2.2843438344342366, 2.1116965157645087, 2.8087300275053297, 10.185424242700849, 21.88477063179016, 34.599114213671, 57.66170351845877, 71.17378888811383, 83.37091377803257, 87.95954581669399, 85.55070263998849, 88.4743378502982, 84.1796076638358, 79.70733710697719, 82.6424993787493, 84.94544506072998, 80.2129158292498, 75.30429145268032, 68.56434426988874, 72.4424535206386, 67.43005779811314, 68.4360179901123, 61.20208168029785, 62.904112407139365, 66.18328693934849, 75.50478867122105, 73.69012764522007, 78.39313398088727, 75.8553113937378, 78.35768427167619, 73.9581891468593, 82.22905376979283, 81.19238948822021, 98.99797521318708, 52.246433871132986, 51.600147179194856, 67.90889290400914, 82.9096645627703, 34.407899788447786, 60.879115513392854, 90.57870401654924, 85.75363172803605, 99.00190789358956, 97.43014199393136, 92.6692293712071, 72.62357916150773, 66.15019961765834, 74.33405889783586, 87.23103414263043, 85.34407016209194, 84.76217937469482, 85.71190084729875, 87.68972642081124, 86.83095686776298, 83.33828503744942, 85.353241784232, 88.96183735983712, 90.42833805084229, 86.47629301888603, 87.54147270747593, 84.63635444641113, 87.80377415248326, 87.26610170091901, 73.43810953412736, 43.50257062911987, 18.684338297162736, 5.309509379523141, 2.024336814880371, 1.8211520548377718, 1.1804992663008826, 0.34657625428267885, 0.10842869497303452, 0.13042014384908335, 0.14392814758632863, 0.02239910762624017, 0.07621162837105137, 2.7407145457608357, 20.322374377931865, 36.72473839351109, 42.007266180855886, 53.951198714120046, 38.8551880972726, 19.553302594593593, 15.521011080060687, 22.46750909941537, 34.09364666257586, 57.27939626148769, 62.912019457135884, 72.9964542388916, 71.03073937552315, 60.05409336090088, 20.928865262440272, 2.8241135563169206, 0.1421484180859157, 0.04713469969906977, 0.033381568400987556, 0.0035821585417059915, 0.013156140921637416, 0.0354202438278922, 0.04431999394936221, 0.13011320174804755, 0.15679866767355374, 0.031648589963359494, 0.02275816460938326, 0.05530611372419766, 0.07801651116460562, 0.06532678673309938, 0.007799391934115971, 0.03475566966725247, 0.0576164372531431, 0.11628263603363719, 0.009723149822093546, 0.0662681930033224, 0.0297320813738874, 0.022096314766843404, 0.05054254683532885, 0.003661359693588955, 0.047742836709533415, 0.02556198156837906, 0.036825259149606736, 0.06289178239447729, 0.11594779257263456, 0.12432649226060935, 0.13496586707021507, 0.04516397276893258, 0.04340380204043218, 0.059659200853535106, 0.07048241794109344, 0.050709900712328296, 0.04224218062258192, 0.09707546061170952, 0.04846563256744828, 0.01130294643475541, 0.05855666287243366, 0.02209992966215525, 0.046907342970371246, 0.0323963593026357, 0.03319201964352812, 0.03495593588533146, 0.11050457786768675, 0.040464578329452446, 0.07714388120387282, 0.045874191980276785, 0.022063862133238996, 0.012554135323236031, 0.06998295509921652, 0.16426040870802744, 0.08652407822332212, 0.13360019320888178, 0.08098757852401052, 0.10647721468870129, 0.04156990169680544, 0.06525397992559842, 0.10471532387392861, 9.752993549619402, 114.99373585837228, 125.407897404262, 115.62813418252128, 100.34269482748849, 87.2992376599993, 59.31435339791434, 39.956164905003135, 25.879910128457205, 27.472730806895665, 45.76764862877982, 46.452959878104075, 42.932252066476, 36.75511939185006, 16.96918589728219, 0.2732120709759848, 0.011733407354248422, 0.028099646558985114, 0.26226982527545517, 0.2961102936949049, 1.233127310872078, 2.372663689511163, 2.526377818414143, 2.0595429028783525, 2.807001445974622, 13.947244099208287, 25.85865558896746, 40.98844139916556, 60.20250688280378, 76.34977994646344, 83.96545028686523, 89.8448908669608, 88.88580322265625, 90.32860360826764, 88.23877307346889, 85.17461749485561, 87.34676333836147, 88.52399662562779, 84.59677750723702, 80.17350564684186, 73.21863678523472, 74.37979888916016, 71.25871671949113, 73.62209783281598, 66.23634338378906, 67.12408692496163, 70.52658503396171, 80.11726692744664, 79.05191353389195, 83.45304843357631, 80.64268275669643, 81.45003564017159, 77.71876267024449, 85.18734659467424, 85.33009733472551, 102.11562497275216, 57.6270181110927, 58.67064448765346, 77.46170711517334, 92.66152381896973, 42.57161276681082, 64.88661411830357, 94.73490796770368, 88.13320214407784, 102.7708192552839, 98.30733816964286, 97.61225427900041, 75.58104515075684, 68.77235943930489, 77.7750222342355, 88.95330497196743, 87.19951016562325, 87.62449673243931, 87.8033642087664, 89.5108562197004, 89.89703709738595, 86.2264357975551, 86.01858738490513, 91.37736470358712, 93.69176796504429, 87.9217198235648, 88.38214220319475, 83.75666386740548, 88.21748379298619, 88.62781660897392, 74.68163558415004, 46.71609510694231, 21.850771359034947, 6.465448175157819, 2.826256207057408, 1.7663039522511619, 3.692666172981262, 1.5511384350912911, 0.30346650896327837, 0.3956315134252821, 0.13878498785197735, 0.014093566735807275, 0.15713011845946312, 2.8891667170183997, 25.047072989600046, 34.71701124736241, 38.428565229688374, 44.37601130349295, 33.36616332190377, 22.787207875932964, 23.7423871585301, 35.47149181365967, 46.17879090990339, 68.18210302080426, 70.46465573992047, 82.44053609030587, 80.80613912854875, 72.85468319484166, 27.008938550949097, 3.1878052864755904, 0.11159197773252215, 0.03198862082457968, 0.07683566345700196, 0.0286772647606475, 0.031732046377978156, 0.07515259805534567, 0.040166358796081374, 0.06452967093459197, 0.05532133326466594, 0.08167270890304021, 0.03006315218018634, 0.031557445746979544, 0.009601065257032002, 0.0433947537759585, 0.029799697388495718, 0.014478785484763128, 0.07587253049548183, 0.024906576112178818, 0.015346187333177243, 0.03903558018750378, 0.035374636096613746, 0.07985408577535834, 0.05511665317629065, 0.012674200398448323, 0.04660043140341129, 0.033806843616600545, 0.022776225515242134, 0.03770989578749452, 0.12754611378269537, 0.10322465707681008, 0.11018089630774089, 0.045329107836421044, 0.04131604817562869, 0.1372203268110752, 0.14440601265856198, 0.11619574283914906, 0.09828219443027462, 0.1151299136025565, 0.1104974736060415, 0.12223683510507856, 0.09307079442909785, 0.1559909667287554, 0.13396654783615045, 0.16261388920247555, 0.2739165803151471, 0.11799424061817781, 0.20192063573215688, 0.16905679633574827, 0.17578289684440407, 0.13517258954899652, 0.10273548761116606, 0.14834223501384258, 0.2510555955980505, 0.35655810151781353, 0.1679065302014351, 0.23663805638040813, 0.23707999980875424, 0.2625770659318992, 0.11815421203417437, 0.10828589049300977, 0.29320361252341953, 16.145393575940812, 139.46219934735979, 134.81008856637138, 129.80758013044084, 113.12835298265729, 99.86122635432652, 58.21299096516201, 28.365072318485804, 25.059751714978898, 62.46969713483538, 100.04958506992885, 74.3088230405535, 70.75440951756069, 51.44603613444737, 23.828525713511876, 0.6890076909746442, 0.1785775925964117, 0.19403862367783273, 0.44931609130331446, 0.31657879107764786, 0.7555034714085715, 2.1500751078128815, 7.936004877090454, 9.78687470299857, 8.121131811823163, 18.796897377286637, 29.324955531529017, 39.82325628825596, 61.47878674098423, 76.07363074166435, 86.57458918435233, 92.02313028063092, 91.23406505584717, 93.6055964061192, 88.75849832807268, 87.84160014561245, 92.04041045052665, 94.0988073348999, 91.7237115587507, 83.65045370374406, 75.84295749664307, 80.66978767939976, 76.90808854784284, 77.93451118469238, 70.46685831887382, 71.14580849238804, 75.87161186763218, 86.82159069606236, 85.85651370457241, 89.54320008414132, 87.34886169433594, 86.32680947440011, 81.04684557233537, 87.00894887106759, 88.69486672537667, 110.11556543622697, 61.36608695983887, 67.7450543812343, 86.83700180053711, 102.36424541473389, 49.05925696236746, 67.19746685028076, 99.64155905587333, 90.57372910635812, 107.90118844168526, 103.79768657684326, 102.40176568712506, 78.38468497140067, 71.38929421561105, 82.20365810394287, 91.46462018149239, 89.4114761352539, 91.08030142102922, 91.4785304750715, 93.92601953233991, 95.41499069758824, 91.23920672280448, 92.78368009839738, 96.60873290470668, 98.18831552777971, 90.82873494284493, 91.64955343518938, 87.43926470620292, 90.4446246283395, 91.25230407714844, 77.78040013994489, 48.20658097948347, 23.779553072793142, 10.544694747243609, 7.56981657232557, 4.5443112168993265, 5.389392818723406, 1.4388456663915088, 0.18533158089433396, 0.4275654884321349, 0.43515031571899143, 0.14595848721052918, 0.40733797954661505, 5.466496978487287, 39.108911991119385, 58.604393414088655, 65.39466639927456, 74.92170974186489, 55.586929730006624, 31.180600506918772, 24.187252521514893, 34.52618244716099, 49.387594086783274, 80.8590566090175, 82.81237588609967, 93.81018611363002, 88.33582551138741, 86.95949854169572, 36.98800563812256, 5.528545260429382, 0.4289640305297715, 0.17332212174577372, 0.19308555339063915, 0.09186724293977022, 0.1996148380317858, 0.13329644022243364, 0.08821679917829377, 0.18312597567481653, 0.1696667993175132, 0.260145223566464, 0.11176801685776029, 0.08143092651984521, 0.21542577605162347, 0.1258603342409645, 0.12767247057386807, 0.14923271723091602, 0.14574423299304076, 0.1670455371162721, 0.07741903393928494, 0.19154939082052025, 0.114024390067373, 0.24183674742068562, 0.27003405722124235, 0.11489071643778256, 0.09340666926332883, 0.11619454861751624, 0.2931494382875306, 0.09680093212851457, 0.21802763215133122, 0.2006931116006204, 0.2565314546227455, 0.15258862929684774, 0.12672780055020536], [0.025638325239664743, 0.07140168361365795, 0.02172123417923493, 0.011450085905380547, 0.0069552909782422435, 0.03835736068763903, 0.11807822968278613, 0.04742214070366962, 0.03683600714430213, 0.026764968177303672, 0.05442248810348766, 0.021430682091574584, 0.04527985976476755, 0.041319009980985096, 0.01958740609032767, 0.03214546080146517, 0.08949735760688782, 0.060635470253016265, 0.048611992570970736, 0.07725246716290712, 0.09350797454161303, 0.020365677275029675, 0.13163173597838196, 0.01221827490787421, 0.07228647292192493, 0.0919066115415522, 0.10151452491325991, 4.0275580542428155, 96.89257376534599, 111.35988358088902, 103.90392453329903, 91.7844318662371, 75.01633725847516, 37.388868059430806, 28.529817581176758, 28.521177496228898, 46.71796417236328, 76.05946336473737, 64.48413971492222, 35.72276299340384, 29.496360642569407, 13.2189747435706, 0.2736225575208664, 0.032810272449361425, 0.037139732989349535, 0.052659308072179556, 0.021149073095460023, 0.07451332985822644, 1.128874259335654, 3.1321206859179904, 3.7036968725068227, 8.58392700127193, 23.039707149778092, 37.38602277210781, 51.99799755641392, 70.7805347442627, 79.39322294507707, 85.60790715898786, 83.8499573298863, 85.51171629769462, 89.61450249808175, 90.37520517621721, 87.79950101034981, 92.06324917929513, 89.27917548588344, 83.70858928135463, 80.53850146702358, 77.57307284218925, 72.52494948250907, 65.57172039576939, 65.3648099899292, 63.5732239314488, 62.26373863220215, 65.94151742117745, 74.59818771907261, 78.22120080675397, 81.09160586765834, 79.96415642329625, 79.53543172563825, 72.08560098920549, 70.29484176635742, 68.05447850908551, 77.56698622022355, 81.63673373631069, 91.64441176823208, 41.76887001310076, 71.83827986036027, 61.128715651375906, 42.344931261880056, 94.04033824375698, 83.25331551688058, 91.92309706551688, 88.81821114676339, 97.02971036093575, 87.74451296670097, 73.85113130296979, 63.71389716012137, 63.94948278154646, 69.877352305821, 79.67844649723598, 81.99287755148751, 84.27026775905064, 80.3823059626988, 78.93889413561139, 76.67913150787354, 80.528336252485, 80.53914070129395, 88.30644157954625, 84.70807375226701, 82.51113673618862, 77.90545381818498, 81.46550927843366, 83.42954267774309, 83.3080186843872, 61.96286078861782, 36.5289694241115, 11.144634349005562, 3.523582411663873, 2.1505616988454546, 2.7514922874314443, 1.9153369494846888, 0.7967534608074597, 0.10655110036688191, 0.2014126708464963, 0.13387185148894787, 0.053556076916200776, 0.1625040750950575, 1.3461125109876906, 17.276181629725865, 27.917076792035783, 34.998430660792756, 47.43297897066389, 83.93653883252824, 55.00184277125767, 12.795265776770455, 20.00627476828439, 36.90408876964024, 41.09611068453108, 57.60149390356881, 74.43391145978654, 71.5677934374128, 66.47538225991386, 37.06015225819179, 11.20413785321372, 0.4469216769295079, 0.007764863831523273, 0.08657984701650483, 0.04542425540941102, 0.07806532497384719, 0.02154174809610205, 0.03668122312852314, 0.06224963042352881, 0.07231138194245951, 0.012819934453416084, 0.007794182481510299, 0.040566178770469766, 0.04205198725685477, 0.06237066750015531, 0.05141733114474586, 0.033674715885094235, 0.007827345032377966, 0.045056465680577924, 0.010296615389441805, 0.05421930418482848, 0.029980018069701533, 0.03912454291379877, 0.04889037852574672, 0.03799860565257924, 0.06583391702068703, 0.03601812817422407, 0.040739130561373064, 0.039585956904504976, 0.1426823301506894, 0.11006036813237838, 0.05881410584385906, 0.06518316122570209, 0.024694635699103986, 0.02473169219280992, 0.026445135607251098, 0.0367730153458459, 0.027355585413585817, 0.06030224849070821, 0.03627185616642237, 0.0159581088727074, 0.008051953694250966, 0.022927761044619337, 0.058425943101091046, 0.05732164092894111, 0.03768532264179417, 0.016325649239921143, 0.03279150417074561, 0.0151593527157924, 0.04271716870633619, 0.01926951073775334, 0.06197226566395589, 0.08709180847342525, 0.017210402925099646, 0.12418980816645281, 0.14734723126249655, 0.01574789363491748, 0.10538399977875607, 0.09676615042345864, 0.1122194869177682, 5.801441405500684, 115.7105884552002, 126.94358825683594, 117.24911417279924, 106.37016677856445, 90.9198397227696, 63.34460040501186, 37.29694339207241, 26.307924372809275, 36.50135728291103, 49.06863355636597, 54.22599649429321, 40.87259060995919, 40.28357791900635, 19.367622409548076, 0.45469394272991587, 0.09371264784463815, 0.0510679500709687, 0.05537925979920796, 0.11991427758974688, 0.7743417205555099, 2.1861119398048947, 2.2629153728485107, 1.9744821872029985, 10.54444374356951, 26.653119564056396, 43.401734897068565, 57.0414308820452, 75.48752239772251, 83.57352324894497, 86.30383178165981, 86.21366500854492, 89.3196348462786, 92.59734330858502, 94.45924513680595, 90.62337398529053, 94.79995700291225, 91.44560991014752, 88.71600314549038, 85.41307967049735, 84.82294137137276, 75.84484045846122, 69.00451265062604, 70.45629010881696, 65.89642361232212, 66.90764359065464, 70.54744352613176, 79.70144503457206, 82.6785466330392, 85.63310132707868, 84.26755101340157, 82.82076236179897, 75.02072851998466, 73.76333386557442, 70.1530568259103, 80.35750089372907, 84.06018897465297, 95.15468338557652, 49.516017641339985, 79.62605707986015, 68.72368730817522, 49.61205564226423, 95.09107957567487, 87.23696095602853, 96.77432237352643, 93.70788083757672, 97.13291195460728, 90.17593778882707, 76.66038526807512, 66.28430679866246, 67.17905412401471, 71.8374252319336, 81.35291372026715, 84.92807456425258, 89.02229363577706, 84.03147206987653, 80.72989654541016, 79.26889187949044, 82.46067196982247, 82.40760162898472, 90.39721706935337, 87.42778628213065, 83.08104188101632, 78.64441558292934, 81.9956498827253, 85.25190925598145, 83.8687938962664, 65.04147556849888, 38.43557596206665, 13.973385827881948, 3.3570108583995273, 1.0585323252848216, 2.6344472765922546, 2.233916631766728, 0.8129639338169778, 0.4802246370485851, 0.3160518407821655, 0.2124236250030143, 0.08669014966913632, 0.1192662495055369, 1.5801918932369776, 20.431607007980347, 32.04931640625, 28.356508663722447, 28.870696204049246, 50.15611696243286, 52.491785185677664, 16.679084709712438, 31.507773808070592, 52.87545428957258, 51.444636072431294, 68.4085031236921, 82.6596405846732, 82.11122621808732, 79.01103033338273, 45.36214828491211, 13.374100225312368, 0.390617166778871, 0.041550682192402225, 0.010623134922103157, 0.03835164403010692, 0.07652426338089363, 0.014202226485524858, 0.02013402372332556, 0.052136055792548826, 0.005780753222227628, 0.0332155749867005, 0.029458095718707358, 0.03757940671805825, 0.09363202431372233, 0.06017110124230385, 0.04265507257410458, 0.04278238609965358, 0.02630671955245946, 0.04928065151242273, 0.04026305342891386, 0.032102825053568394, 0.017358148836397698, 0.026175265266959156, 0.031100024934858084, 0.049513677401202064, 0.05253345678959574, 0.09774361404457263, 0.02222455618903041, 0.04666276502289942, 0.09236574904727084, 0.057883474709732194, 0.046119618096521924, 0.08929784795535461, 0.10612741631588765, 0.16783886668937548, 0.10259125142225198, 0.12653463520109653, 0.1068465073726007, 0.18354763090610504, 0.341079767793417, 0.13314063501145157, 0.10760135043944631, 0.13364724282707485, 0.1113552979326674, 0.2184043683643852, 0.17891023760395391, 0.09145883949739592, 0.12209597123520714, 0.13601017317601613, 0.13734932988882065, 0.12949010304042272, 0.1316167132130691, 0.26306395551988054, 0.31313842854329516, 0.18454030049698694, 0.3489990585616657, 0.10968912805297545, 0.2428092509508133, 0.16025528790695326, 0.17409628948995046, 11.594515442848206, 142.2269014630999, 133.66376086643763, 129.7599432809012, 119.08395276750836, 99.15875652858189, 59.647318022591726, 43.13381930759975, 41.619959694998606, 71.32030555180141, 103.70904145921979, 88.3492077418736, 56.55198587690081, 51.228943143572124, 25.09208689417158, 0.6089073376996177, 0.18477016101990426, 0.3265274443796703, 0.13847951138658182, 0.21369055844843388, 0.5532177974070821, 3.6008961030415128, 10.843026944569178, 14.92837837764195, 16.130302088601248, 29.208719117300852, 43.18875871385847, 56.66034303392683, 74.36927236829484, 84.50424139840263, 87.69019195011684, 90.28357928139823, 91.80112143925258, 97.87006023951939, 96.96616213662284, 93.26349490029472, 98.19369343348912, 95.84906550816127, 92.60848127092633, 87.52394935062954, 88.13126359667096, 81.46590532575334, 73.33082934788295, 74.57001972198486, 70.54415007999965, 71.42652266366142, 76.44826371329171, 85.64929062979562, 89.15482357570103, 89.74022320338658, 89.35142285483224, 88.45835699353898, 79.42660903930664, 77.20412349700928, 73.31204836709159, 84.69590050833565, 90.68078695024762, 98.42829241071428, 56.205236026218955, 87.84165573120117, 77.50789873940604, 53.57784768513271, 98.86865534101213, 93.4816335950579, 100.14160006386894, 99.42268385205949, 99.97797693525041, 95.32052993774414, 80.87352970668248, 69.7325518471854, 70.69307776859829, 77.13068103790283, 86.36465631212506, 89.16152163914272, 92.86065919058663, 88.44146592276437, 85.4893569946289, 84.34398814610073, 86.79877976008824, 86.73871258326939, 95.4751968383789, 92.11062894548688, 84.91842351640973, 79.00544398171562, 83.89856692722866, 87.8152664729527, 88.2894879749843, 68.09265191214425, 41.451507568359375, 15.402363640921456, 7.996283105441502, 7.267820937292917, 6.962518393993378, 6.0932891964912415, 2.45728753720011, 0.6244985525097165, 0.31857373831527575, 0.45658013437475475, 0.18790633630539688, 0.2599826737173966, 2.7709098969187056, 30.842647075653076, 46.25501612254551, 54.394594533102854, 65.14533724103654, 105.14932659694126, 73.40653691973004, 20.656304802213395, 32.53342866897583, 54.72307062149048, 62.84911046709333, 78.83391380310059, 93.63221495492118, 91.64555822099958, 89.12447384425572, 57.35441596167428, 19.48680485997881, 1.273586128439222, 0.15735320720289434, 0.1622273549437523, 0.1693072436111314, 0.13989859952458314, 0.07445825995611292, 0.07384884729981422, 0.12256676597254616, 0.18162574831928524, 0.11156273965856858, 0.1666311150682824, 0.09225363470613956, 0.16775247561080114, 0.1538640715714012, 0.10734907111951283, 0.1526191226605858, 0.20866622376654828, 0.18313063042504446, 0.1145981592791421, 0.16097935262535298, 0.11672148534229823, 0.1294295098632574, 0.11997525074652263, 0.18856929216001714, 0.33124809392860954, 0.20235108477728708, 0.11401875822671823, 0.12339400872588158, 0.25215292243020876, 0.3471642998712403, 0.15341821978134768, 0.15389592200517654], [0.0669211811785187, 0.020134634404842342, 0.04710078651883772, 0.032325686487768374, 0.03993002844176122, 0.016033590804519396, 0.007337899911882622, 0.021786288724147847, 0.11116207151540689, 0.05439418301518474, 0.023835635810558285, 0.009934884978325238, 0.025312501205397502, 0.00295388579252176, 0.07617481106093951, 0.05508927768096328, 0.021216896063249027, 0.02789530573811914, 0.043538423388132026, 0.07554435024836234, 0.037269672445420704, 0.06546104845723935, 0.025902312681345, 0.09356883234743561, 0.042335428297519684, 0.19050174632242747, 2.0138602341924394, 88.43277372632707, 109.62465436117989, 97.54295989445278, 91.57274804796491, 57.195757320949006, 33.91980620792934, 22.083702768598283, 28.56172023500715, 69.35407652173723, 59.009709630693706, 57.26636144093105, 37.57091086251395, 29.962581293923513, 11.953008617673602, 0.08970888411360127, 0.041959913447499275, 0.038241053000092506, 0.1762816607952118, 0.08784421559955392, 0.2768838410930974, 0.4555157572031021, 3.3906688008989607, 5.2587931752204895, 15.04937778200422, 38.08468151092529, 53.33147151129586, 73.2822961807251, 86.07034451620919, 89.72473566872733, 87.24415234157017, 85.76225444248745, 84.2812806538173, 85.48828002384731, 84.42677593231201, 83.99347237178257, 83.9125258581979, 86.78323663984025, 86.47311074393136, 86.04380934579032, 86.66662502288818, 82.09053448268345, 72.37147072383335, 63.1448883329119, 65.56004742213658, 63.55701378413609, 65.374648639134, 69.38882446289062, 78.22588389260429, 83.28937666756767, 81.89344188145229, 80.68493475232805, 80.18771471296037, 73.175995690482, 73.76582826886857, 74.93357031685966, 71.90027168818882, 73.56103011540004, 81.872451373509, 73.23288059234619, 39.13968556267874, 39.05223553521292, 80.02801036834717, 84.44056810651506, 72.13125760214669, 75.86213452475411, 82.58947767530168, 87.36084038870675, 85.81984111240932, 72.68357685634068, 66.17887483324323, 66.42733546665737, 61.71879141671317, 64.5204301561628, 72.50910064152309, 76.76458045414516, 70.62470749446324, 66.43067060198102, 67.45209053584507, 74.32376861572266, 78.77380493709019, 85.0029969896589, 77.39249610900879, 86.978654725211, 87.20902224949428, 84.80791241782052, 84.27004541669572, 81.24848229544503, 74.95076710837228, 62.201024191720144, 36.035049779074534, 9.310299498694283, 0.9939668412719453, 4.090335462774549, 3.0939062450613295, 1.9158406938825334, 1.1085864965404784, 0.32063282068286625, 0.160914986793484, 0.2012399158307484, 0.023912510435496057, 0.07735882752708026, 1.6235786165509904, 13.580383556229727, 29.772443839481898, 50.67325053896223, 70.75088678087506, 63.70423916407994, 40.270574365343364, 18.034593139375957, 13.088880147252764, 23.910278218133108, 42.975000858306885, 56.348619052342, 74.48719024658203, 67.21451772962297, 67.7238415309361, 62.5314735685076, 19.987745659691946, 1.026387027331761, 0.08003707309918744, 0.06221992416041238, 0.10071528530014412, 0.008037908019364944, 0.01711076175394867, 0.053813584348452945, 0.01812458467403693, 0.04621464692588363, 0.003526260402785348, 0.04177665470966271, 0.022562682063185742, 0.056226509157568216, 0.047073875819998126, 0.04568353721073695, 0.03560193854251078, 0.011441228478880865, 0.0385666242800653, 0.0677643898608429, 0.012154433244307126, 0.018286337244457433, 0.027939978787409406, 0.06020965560206345, 0.0367207070812583, 0.05524053670732038, 0.05498065779517804, 0.02799405633205814, 0.03318736828597529, 0.015069843768807394, 0.03241704783535429, 0.030636046081781387, 0.01730760815553367, 0.06248839332589081, 0.03517959799085345, 0.015056410471775701, 0.028781599697789977, 0.02225964662751981, 0.018915727668042694, 0.01723780725816531, 0.055835662808801444, 0.08253315916018826, 0.01122981817128935, 0.054615049556429894, 0.06589922601623194, 0.06346381455659866, 0.03344411236633148, 0.010628458877493228, 0.01995471745197262, 0.0641398254249777, 0.04181833711585828, 0.043940224684774876, 0.04522686278713601, 0.03158918761515191, 0.02156395654726241, 0.1254356527434928, 0.15963818744889327, 0.2568531887871878, 3.5110984529767717, 108.54591873713902, 124.90426417759487, 112.90630940028599, 103.39220360347203, 76.05596147264752, 60.04327501569475, 38.334538732256206, 31.70893805367606, 44.30859988076346, 50.20967715127127, 49.01545899254935, 44.61407743181501, 37.53212601797921, 15.366048880985804, 0.2681906675653798, 0.1619554388203791, 0.02430138224735856, 0.3325806552810328, 0.44244188017078806, 1.1509228476456232, 1.6439373812505176, 1.7630349333797182, 5.661791733333042, 16.165169886180333, 41.568765367780415, 59.98011589050293, 76.68730953761509, 85.21978773389543, 90.18732588631767, 89.4947919845581, 86.51416764940534, 88.66378048488072, 89.49222809927804, 86.97559056963239, 87.28744656699044, 87.92618751525879, 89.38307884761265, 88.67577307564872, 87.20930017743791, 89.78311443328857, 86.56027589525495, 75.95836707523891, 66.4759520121983, 69.68750667572021, 67.57870755876813, 67.72695432390485, 73.8687241418021, 83.77070617675781, 87.48320511409214, 85.62320709228516, 85.35717446463448, 84.01968792506626, 78.3655148914882, 78.64672238486153, 78.98814991542271, 76.93358148847307, 77.07447011130196, 86.1451140812465, 76.95041002546037, 46.95318848746163, 47.880324840545654, 82.41951778956822, 88.47189903259277, 75.23742198944092, 78.9663256236485, 86.66966833387102, 89.67636925833565, 87.3050046648298, 75.14628941672188, 69.70336941310337, 70.88691861288888, 65.75563921247209, 67.84954139164516, 75.2456556047712, 78.13621044158936, 75.0040181023734, 69.74035467420305, 68.42337226867676, 76.9623053414481, 81.42844758714948, 89.00744533538818, 78.75899832589286, 86.52404798780168, 88.98460660661969, 89.2348598752703, 85.67752810886928, 83.10861928122384, 78.11302430289132, 65.09023107801164, 41.936502252306255, 12.719456587518964, 1.2047343658549445, 0.33407242809023174, 1.111286957349096, 2.1892570853233337, 1.7791191445929664, 1.094828194805554, 0.2715062882219042, 0.2863291571182864, 0.0907765861068453, 0.004930666739320648, 1.6633251351969582, 15.6657646383558, 32.90900312151228, 39.34512989861624, 69.88755920955113, 68.04168687547956, 31.43474129268101, 22.11256037439619, 29.328384467533656, 39.24323804037911, 52.93366977146694, 65.31072521209717, 82.79827799115861, 77.27557182312012, 79.76347855159214, 74.77230957576207, 25.521297965730938, 2.496954368693488, 0.050302243658474514, 0.011353393817054374, 0.045181821632598124, 0.054741742222436836, 0.0132068164613364, 0.03521828466494169, 0.06908061209001712, 0.07492121761398655, 0.017715185481522764, 0.026998635281675627, 0.07881717570126057, 0.0433991710389299, 0.06781333259173802, 0.04431885061785579, 0.029260723452482904, 0.04365542996674776, 0.04746590621237244, 0.05000923527404666, 0.009158320309195136, 0.05021312826180032, 0.029254541998463016, 0.028135464726282016, 0.01607135806365737, 0.02052132472661989, 0.02165199985860714, 0.04752314742654562, 0.03393511048385075, 0.055303847417235374, 0.022268757656482712, 0.041581626781927686, 0.19917160538690432, 0.1347641386091709, 0.15730281919240952, 0.07599091450018541, 0.15354308379547937, 0.12392319818692547, 0.125184744064297, 0.07678437978029251, 0.20283616946211883, 0.17578586882778577, 0.1631028822490147, 0.1711544602044991, 0.15037245250173978, 0.1599219643643924, 0.1258823594876698, 0.1823655143380165, 0.08794706115233046, 0.13809389993548393, 0.11250316883836474, 0.24873845279216766, 0.16613658517599106, 0.16646902662302765, 0.19823179367397512, 0.25227638866220203, 0.3640473639326436, 0.4646943818245615, 7.120886078902653, 132.32161903381348, 134.30382892063685, 125.82865251813615, 119.67445237295968, 84.57432092939104, 56.29778603145054, 34.280695642743794, 49.52805192129952, 95.52022116524833, 82.30476134163993, 81.6308764048985, 59.83351584843227, 48.86560024533953, 21.73747229576111, 0.686417641384261, 0.2967817448079586, 0.22470932932836668, 0.33469725027680397, 0.2818221375346184, 0.7860613773976053, 2.6026360349995747, 12.36488219669887, 12.2587936265128, 20.436627081462316, 41.2148380279541, 56.001302923474995, 75.47889273507255, 85.14309351784843, 94.41372748783657, 91.0133763722011, 88.33508205413818, 90.32907608577183, 93.05450698307583, 90.18548461369106, 92.72214685167584, 93.99038069588798, 94.77146938868931, 92.2308258329119, 92.62628950391496, 95.36255959102085, 89.88325187138149, 80.50811699458531, 69.13568074362618, 73.93038940429688, 72.67448166438511, 72.79442841666085, 78.56310776301792, 88.4015554700579, 89.85348578861782, 91.21017714909145, 90.874801499503, 87.32554353986467, 81.98879895891461, 83.46968242100307, 82.20567308153424, 79.3693767275129, 82.48050212860107, 90.8015535899571, 80.24321692330497, 55.444575037275044, 55.358153343200684, 85.14899948665074, 94.29621955326625, 78.32091440473283, 83.14475686209542, 90.80471502031598, 97.30075263977051, 94.21325806209019, 79.57017966679165, 70.67128821781704, 73.41500677381242, 67.55518095833915, 71.42885725838798, 79.25788593292236, 83.96615205492292, 78.54261752537319, 75.68692180088588, 75.27925709315709, 81.6543196269444, 85.5297885622297, 92.65329020363944, 80.42953286852155, 90.02349431174142, 93.24367863791329, 94.44004726409912, 90.82587923322404, 89.63797351292202, 81.45437826429094, 66.9208938053676, 42.60982438496181, 13.831102354185921, 4.378442083086286, 11.813566088676453, 9.379349827766418, 8.047448771340505, 3.8669274279049466, 1.9305011757782526, 0.5286682375839779, 0.5049990905182702, 0.1707514782569238, 0.25065241008996964, 3.8674950088773454, 26.56077105658395, 48.21239314760481, 72.16834708622524, 80.76088551112584, 75.73358590262276, 61.50257042476109, 29.072021995271953, 25.14853058542524, 39.70795440673828, 61.99220303126744, 77.77092974526542, 94.19499124799455, 86.93103177206856, 90.8320561817714, 84.63520799364362, 36.46930871691023, 4.862404959542411, 0.13559995804514202, 0.24007936886378697, 0.22441489941307477, 0.1360354825322117, 0.21362445556691714, 0.1191310039056199, 0.1506012137979269, 0.12211213393935136, 0.13466678240469523, 0.21440418729824678, 0.12879828230610915, 0.10651615581342153, 0.15581874097032206, 0.17421269895774977, 0.13480156660079956, 0.17022808348493917, 0.152103544612016, 0.15361511707305908, 0.04918430971779993, 0.1408471914806536, 0.09058698306658439, 0.08946358691900969, 0.08012503837900502, 0.10565335103975874, 0.1529457965599639, 0.11991506469036851, 0.10788047939006772, 0.11571479721793107, 0.10650920082948037, 0.10985489415803126], [0.02738747655946229, 0.06345493931855474, 0.021975800162181258, 0.026843639223703315, 0.04918881858299885, 0.0651684912985989, 0.02529622145396258, 0.020148457859509757, 0.03334264763231788, 0.027823184250987003, 0.022791701202679957, 0.06888872238674335, 0.03599281881802848, 0.03689884966505425, 0.039724954803075106, 0.0483780642306166, 0.036399570027632375, 0.04072109170790229, 0.02374465104990772, 0.04388783499598503, 0.0241751764302275, 0.06324577411370617, 0.014524808818740504, 0.025451254831360917, 0.043216950459671874, 1.0788888101066862, 86.61748041425432, 105.49802889142717, 96.49324689592633, 88.37358897072929, 61.35556043897356, 43.39596094403948, 14.556126032556806, 29.49572835649763, 58.51824964795794, 57.69002785001482, 62.30254432133266, 42.531705788203645, 28.91045205933707, 5.981984266213008, 0.1212046340640102, 0.03048008480774505, 0.027242317562922835, 0.14255137289209024, 0.2436344852404935, 0.022523316854078854, 0.29918237456253594, 1.333664704646383, 4.219932394368308, 19.01837294442313, 43.08686685562134, 73.64185156141008, 88.0223297391619, 91.35788195473808, 83.9436468396868, 84.93095111846924, 86.64582211630685, 84.91647107260567, 83.27095004490444, 81.78427178519112, 74.39941365378243, 74.5915174484253, 74.63205323900495, 81.74098450796944, 80.88129779270717, 82.98924922943115, 82.02863992963518, 83.299715587071, 70.39882850646973, 63.21471078055245, 60.01269599369594, 66.00658730098179, 68.25071648189, 78.79990931919643, 78.62036091940743, 86.06179128374372, 80.59014047895158, 86.33084637778146, 82.71888787405831, 81.60762773241315, 78.41652161734444, 88.77133859906877, 79.63604164123535, 81.79235254015241, 69.34988675798688, 97.64249978746686, 42.0322380065918, 32.15045785903931, 94.12393896920341, 74.09524236406598, 72.87329741886684, 59.91144684382847, 71.24043600899833, 64.66498047964913, 71.14100728716168, 61.1548547744751, 66.95568343571254, 64.87105015345982, 65.82477378845215, 61.3121828351702, 62.63485581534249, 59.94916861397879, 64.2626519884382, 60.11682169778006, 69.44492421831403, 73.34880433763776, 80.45025239671979, 79.61969252995083, 84.90759822300502, 85.40902192252022, 84.29708780561174, 77.52820832388741, 76.81722695486886, 75.19864409310478, 76.87423692430768, 66.46354252951485, 69.55978488922119, 59.09427615574428, 22.55404543876648, 0.8947968312672206, 1.4005166888237, 1.081695122378213, 1.0932093730994632, 0.7751063480973244, 0.49099021937165943, 0.05645522974165423, 0.1683419868350029, 0.061155580915510654, 0.05964010687811034, 0.3958427278058869, 6.476118436881474, 19.59416495050703, 19.373663868222916, 33.740862301417756, 44.134752477918354, 40.58959742954799, 22.764119012015207, 22.872094018118723, 18.355912583214895, 33.43763249261038, 53.56976693017142, 70.76358808789934, 76.85953453608921, 76.49819346836635, 65.81263528551374, 42.09280545370919, 5.801259449550083, 0.16054403169878892, 0.05413631595937269, 0.032441787222134214, 0.07860448889966522, 0.03846190936331238, 0.030809727297829728, 0.039680266486746926, 0.009246890333348086, 0.04458887702120202, 0.040011798696858544, 0.016782445799825445, 0.01697978244296142, 0.00830769439094833, 0.022273130814677904, 0.011261000248071338, 0.06561608013830014, 0.050313693936914206, 0.038515245608453236, 0.09941919520497322, 0.031841463542410305, 0.041058988576488833, 0.027403262676671147, 0.061096650149141035, 0.014826985907607844, 0.013863193918950856, 0.01946474052965641, 0.05328985370163407, 0.031612987230931006, 0.04450535275308149, 0.015229844022542238, 0.011607101453202111, 0.050743908887462955, 0.041714846954814026, 0.02480056688987783, 0.07336547252322946, 0.027992970676028302, 0.07048919650592975, 0.03430458637220519, 0.04458459546523435, 0.04865882845063295, 0.023622658935242465, 0.039899416334394894, 0.051465965142207484, 0.034915831073054245, 0.11865830927022866, 0.032448935588555675, 0.009825517855850714, 0.014779524079390934, 0.03517543178583894, 0.04422486673242279, 0.029656000634921447, 0.049981985307697735, 0.04084205753835184, 0.08316191684986864, 1.9021577366760798, 105.11293193272182, 119.70018850054059, 113.02365752628872, 100.87960992540631, 84.20585795811245, 64.50842366899762, 30.14385632106236, 30.298332146235875, 36.46673093523298, 55.0880560193743, 48.62313938140869, 46.67400639397757, 35.49409777777535, 9.867948021207537, 0.23917990284306662, 0.05674048925616911, 0.11939080139356, 0.09721622270132814, 1.2702050698654992, 0.40417663061193054, 0.9687655078513282, 0.8464959944997514, 5.025627263954707, 21.82157850265503, 50.32795633588518, 79.39414705548967, 86.91673237936837, 90.04358155386788, 84.26182569776262, 85.3896017074585, 86.06805161067417, 88.14290182931083, 87.62377411978585, 86.08658940451485, 78.95929404667446, 78.561051096235, 79.9289221082415, 86.38466712406704, 85.06313364846366, 88.03252969469342, 86.3153657913208, 87.64158930097307, 73.99920436314174, 65.99608162471226, 64.75225680215019, 69.96410751342773, 73.02942344120571, 82.54829570225307, 83.23493753160749, 89.65132100241524, 84.23284476143974, 91.25541687011719, 85.03198487418038, 85.35682705470494, 82.36928926195417, 91.98514447893415, 83.78214291163853, 86.59108420780727, 74.66092995234898, 102.25579793112618, 48.28922285352434, 37.258856841496055, 96.32640675136021, 77.4895554951259, 75.89928654261998, 62.06067058018276, 73.89172267913818, 67.35063294001988, 73.06662409646171, 64.50710351126534, 69.2377428327288, 66.54614271436418, 68.50329044886998, 64.70049272264752, 65.93922451564244, 62.9927088873727, 66.6680280140468, 63.29458032335554, 72.78190081460136, 77.37567452022007, 83.50520161220005, 83.1766004562378, 87.53273882184709, 87.55123492649624, 85.97020707811627, 78.94370923723493, 79.24559456961495, 80.0089167186192, 80.30430548531669, 70.2336003439767, 73.18702248164585, 64.90421390533447, 29.89540958404541, 3.6651890873908997, 0.264265206775495, 1.3597240320273807, 1.2978276333638599, 1.180736916405814, 1.247862268771444, 0.8904996418527195, 0.39533236090626034, 0.09970437668796096, 0.09981516110045568, 0.19243494687335833, 7.420822875840323, 24.35903283527919, 22.540421758379253, 20.72302314213344, 38.26402146475655, 30.395558289119176, 18.384110110146658, 33.348167487553184, 29.073380368096487, 49.583898067474365, 61.20279734475272, 78.65792982918876, 85.81066254207066, 87.02713925497872, 77.99658639090401, 55.13821506500244, 8.377285838127136, 0.10045941652996199, 0.023250558812703406, 0.037004165085298676, 0.04595274258671062, 0.019542346276076775, 0.03113541392875569, 0.036852118958319934, 0.014242098899558187, 0.009283226731765484, 0.04180946187781436, 0.026025644902672087, 0.062019966675766876, 0.02702395651223404, 0.010444322284976286, 0.05795510086630072, 0.023157173734424368, 0.05204846031431641, 0.06819347505058561, 0.025358952016436627, 0.05590507694120918, 0.018280220251264315, 0.02981703056554709, 0.07693811545946769, 0.06076399835624865, 0.020334194946501936, 0.04668871220201254, 0.0069557901255653375, 0.0376181341042476, 0.03634684446400829, 0.0935147734624999, 0.10684812228594508, 0.1216824719948428, 0.10071851512683289, 0.14950941024082048, 0.2289792416351182, 0.08705520829451935, 0.08783460754368987, 0.09997180090951067, 0.17364833424133913, 0.09622740718935217, 0.21406896385763372, 0.09713336000485079, 0.1368087546101638, 0.13720299702669891, 0.20534916461578437, 0.11782850165452276, 0.12887183550213063, 0.059443053523344655, 0.1427163247551237, 0.15212547486381872, 0.11335189401039056, 0.1269684633506196, 0.17184773300375256, 0.19035352713295392, 3.2507023343018124, 123.24427005222866, 133.675169808524, 125.80736323765346, 115.14861815316337, 86.461396081107, 62.367614201136995, 25.56332414490836, 45.40916327067784, 79.05849347795758, 78.45288848876953, 85.99100303649902, 66.81004224504743, 46.83555548531668, 11.790603160858154, 0.5094767702477319, 0.1639973542519978, 0.22016997076570988, 0.26979524003607885, 0.660015843808651, 0.24856178941471235, 3.174178783382688, 7.892968603542872, 11.07522531918117, 23.31880760192871, 47.92023181915283, 79.91686698368618, 87.07321970803397, 91.9305316380092, 86.49171107155937, 86.60539054870605, 86.28443241119385, 90.45988287244523, 92.94173771994454, 91.55374472481864, 82.86625221797398, 82.53269004821777, 84.74926962171281, 91.6856632232666, 90.32105786459786, 91.74334716796875, 88.8971357345581, 91.65551498958042, 80.5679965700422, 70.58667305537632, 68.059328351702, 75.52153382982526, 81.35405322483608, 87.70048223223004, 86.84238665444511, 96.93449919564384, 89.77745859963554, 95.09604058946881, 89.17720372336251, 89.79659393855503, 87.18771212441581, 95.92283453260148, 91.06882299695695, 89.39724622453961, 80.09628336770194, 104.83781106131417, 51.2195074898856, 40.78585277284895, 100.57027612413678, 82.00143078395298, 77.82015078408378, 65.1273830958775, 77.75858279636928, 72.8074562890189, 76.62072495051792, 68.73933465140206, 72.64099134717668, 71.90610122680664, 73.34361403329032, 69.23115594046456, 69.18134430476597, 67.57631737845284, 71.04479558127267, 66.11563232966832, 77.91595254625592, 81.1419038772583, 87.93631104060582, 86.45551095690045, 89.6351316996983, 92.51718888963971, 92.45751776014055, 84.08690479823521, 84.63373497554234, 83.82042748587472, 84.89125605991909, 70.87846960340227, 73.51991067613874, 64.48497349875313, 27.30564226422991, 5.35361567565373, 3.571429878473282, 5.051175355911255, 4.994921437331608, 3.7674053396497453, 2.810102948120662, 1.1659236827066966, 0.4381735420652798, 0.18973219261637755, 0.23114509827324323, 1.0615708593811308, 13.21404152257102, 36.534983089991975, 33.43113245282854, 48.76910366330828, 58.10728107179914, 54.70782279968262, 33.56066424506051, 34.16626228604998, 28.821984120777675, 51.58816501072475, 73.1305683680943, 93.24106611524309, 94.40452807290214, 96.38126277923584, 89.12532847268241, 68.36301326751709, 11.5149507522583, 0.2708868400326797, 0.11062715521880559, 0.11441131787640707, 0.19003627129963466, 0.24280737819416182, 0.10851102162684713, 0.09664721002003976, 0.07304056281489985, 0.09314244772706713, 0.1664950687970434, 0.08877507065023695, 0.15572545597595827, 0.1302640807947942, 0.12768965108054026, 0.17349289543926716, 0.1292695655886616, 0.12982529933963502, 0.27716090051191195, 0.20604607436273778, 0.13758980269942964, 0.13231369081352437, 0.17503459485513823, 0.167891317446317, 0.2307329832443169, 0.10602928658149072, 0.09571535073752914, 0.12862650438078813, 0.11632328028125422, 0.1144084951707295], [0.02519914005616946, 0.04495201539248228, 0.05634533081735883, 0.050363807140716484, 0.01620833732054702, 0.035742972046136856, 0.025403148394876292, 0.016557294309937527, 0.02137264868776713, 0.004707625917425113, 0.03683796811050602, 0.03429931415511029, 0.030718243813940456, 0.043147858631397994, 0.09580957211021866, 0.021682971589533345, 0.025896843689094697, 0.049980811442115476, 0.053769581352493594, 0.04474033960806472, 0.03553126912031855, 0.10810879963849272, 0.0753046984651259, 0.0456221162208489, 0.16237611696124077, 79.90891824449811, 108.43800626482282, 98.52778366633824, 94.236617905753, 67.01229735783168, 42.18453209740775, 18.04169593538557, 47.83580425807408, 69.60592787606376, 65.38505704062325, 61.18034076690674, 49.289443833487375, 24.348546266555786, 6.453375245843615, 0.35358552102531704, 0.17455565769757542, 0.13151126887117112, 0.10811524572116987, 0.1625285702092307, 3.5718204975128174, 4.854321164744241, 3.267570606299809, 4.6018184167998175, 18.89044271196638, 65.19529478890556, 84.7390557697841, 93.27193696158272, 90.6041761125837, 90.95956257411412, 89.14236545562744, 90.97397313799176, 84.36755643572126, 84.33062676021031, 83.6508914402553, 79.99817480359758, 71.46387617928642, 67.15586798531669, 65.26231711251395, 66.89187117985317, 69.27580506461007, 80.76374122074672, 82.08395453861782, 78.64094843183244, 64.97911548614502, 61.03814588274275, 63.20838097163609, 65.20666204180036, 69.54768112727574, 77.94435678209577, 77.20998777662004, 76.8218822479248, 74.41045434134347, 79.91384451729911, 75.75412477765764, 79.6585190636771, 78.19486713409424, 83.73661831447056, 77.11643028259277, 87.98242623465401, 73.90092209407261, 86.14740698678153, 60.26952920641218, 39.91962432861328, 89.70743465423584, 69.91396931239537, 71.52854306357247, 60.43428489140102, 72.6633437020438, 73.6998690196446, 81.66793809618268, 73.9532698222569, 67.42208126613072, 63.532924379621235, 63.586279596601216, 60.64387730189732, 60.928322655814036, 60.83129106249128, 61.434693472726, 59.047389711652485, 68.64825071607316, 74.24819305964878, 82.47759778159005, 86.6560846056257, 85.78553785596574, 78.79230798993791, 71.04549734933036, 66.56630638667515, 72.98650441850934, 77.43371977124895, 77.86171490805489, 67.871490750994, 74.68390764508928, 82.69427040645054, 85.32998616354806, 50.64440161841256, 5.3039160796574185, 0.9474672164235796, 1.5077119767665863, 0.4644165081637246, 0.13633996833648, 1.860561694417681, 1.4274728766509464, 0.07491143313901764, 0.08800911317978587, 0.037638425693980286, 0.07477302556591374, 4.312101985727038, 23.959495782852173, 46.02615983145577, 42.95249216897147, 43.35392781666347, 76.84421375819615, 35.677558013371055, 17.687845025743755, 15.644122736794607, 24.447556359427317, 47.18530348369053, 59.271628924778526, 59.76915468488421, 74.42239134652274, 80.4506345476423, 50.024420806339805, 4.415505511420114, 0.008513974973798862, 0.03622468780460102, 0.018194955540820956, 0.03814774086432798, 0.052325526518481116, 0.01694438496737608, 0.04151144251227379, 0.06935606338083744, 0.051131827357624254, 0.02562183853504913, 0.025069828244990537, 0.0324089122004807, 0.0027214510773774236, 0.0530466531802501, 0.03946868230455688, 0.01319435516571892, 0.021507003710472157, 0.026168644461514692, 0.16572345234453678, 0.08485340287110635, 0.011798609480527895, 0.0505967414272683, 0.01625182632622974, 0.04119709759418454, 0.015019013014222895, 0.048760435677000454, 0.032394109959048886, 0.0682043723229851, 0.026474918205557123, 0.07500689623079129, 0.07230537690754447, 0.02463647167730544, 0.017689998261630535, 0.06378908388848815, 0.002828014365929578, 0.022377655741625598, 0.04680014122277498, 0.054939402866044214, 0.03341586495350514, 0.011086933963399912, 0.028176156471350362, 0.044131130512271605, 0.054810325149446726, 0.04103317031902926, 0.02976067823224834, 0.039409486909529994, 0.05899415511105742, 0.05089412636256643, 0.0431457992776164, 0.06736011869673218, 0.10569977640573468, 0.03261141079877104, 0.07362263050994702, 101.98323399680001, 126.4045192173549, 111.44768796648297, 105.60048007965088, 81.59854643685478, 57.074896880558555, 35.7006642477853, 31.795133931296213, 39.915306023189, 70.10600362505231, 53.66966812951224, 51.126033374241416, 35.458248547145296, 9.559009398732867, 0.319266712559121, 0.14783816491918905, 0.1490764506161213, 0.08946509326675109, 0.20292109490505286, 4.220398357936314, 4.635342172213963, 2.2121579136167253, 5.974185347557068, 24.07803726196289, 69.2069901057652, 87.7594654900687, 94.18390887124198, 92.41805894034249, 93.0472947529384, 91.89145496913365, 91.51608548845563, 84.95631204332624, 85.49103151048932, 88.97179412841797, 83.22013092041016, 74.50271947043282, 71.08000905173165, 68.70737988608224, 69.89112363542829, 73.60509559086391, 83.6701796395438, 85.26010813031877, 81.2128380366734, 69.58924525124687, 64.33972835540771, 65.82164709908622, 69.75359099251884, 72.25116266523088, 81.39410264151437, 83.95535455431256, 79.9975425175258, 77.73238808768136, 82.71430901118687, 81.34825147901262, 84.97206360953194, 83.2945669719151, 86.4318106515067, 81.88786247798375, 90.23922198159354, 77.50775977543422, 90.78030599866594, 63.520042419433594, 42.82374552318028, 94.09774426051548, 74.36081641060966, 74.36489500318254, 64.15260641915458, 76.93754890986851, 76.59689262935093, 85.80912699018205, 76.6557925088065, 68.08820506504604, 67.74208055223737, 67.57769312177385, 63.076045581272666, 63.43319688524519, 62.639997482299805, 64.42007037571499, 62.620549474443706, 71.42803042275565, 77.02944578443254, 85.62594468252999, 88.12672642299107, 86.82512038094657, 79.77075331551688, 75.74342455182756, 69.3737746647426, 76.13500417981828, 80.31716660090855, 82.33450657980782, 69.61699635641915, 75.86534459250313, 87.48048142024449, 89.65271064213344, 58.620179721287315, 8.552923270634242, 0.06139525305479765, 1.467621956552778, 1.1368808639901025, 0.2968593149312905, 3.3185940512589047, 2.9026974652494704, 0.3811043772314276, 0.04305507914562311, 0.03197863278910518, 0.1164628549345902, 3.863110261304038, 29.270408698490687, 41.394765104566304, 28.919010502951487, 38.316727025168284, 49.062046664101736, 22.562079293387278, 28.02896363394601, 28.16194520677839, 43.014928681509836, 62.8336090360369, 68.14277621677944, 65.74860068729946, 83.91465895516532, 92.2912265232631, 62.94371019090925, 6.353223042828696, 0.059669338166713715, 0.055129175540059805, 0.0038198455419790533, 0.06708054191299848, 0.026964910394911255, 0.042535341677388976, 0.04272317034857614, 0.024526167328336408, 0.039089082673724206, 0.06693861274314777, 0.04066827793472579, 0.03455518971064261, 0.04903534074713077, 0.0065608280378260785, 0.025074293005413244, 0.06631377020052501, 0.04260386692892228, 0.023299810277032, 0.020626616398138658, 0.035990976595452855, 0.07182301993348769, 0.013253686267749538, 0.03866847577903952, 0.07726036531052419, 0.013618768641858228, 0.07253244186618499, 0.04524131558303322, 0.07802121341228485, 0.09880920579390866, 0.20573598385921546, 0.21766012401453086, 0.10923346464655229, 0.08372187108865806, 0.2533481754362583, 0.06944725848734379, 0.14314863298620495, 0.08823690417089633, 0.192514837586454, 0.09923583468688385, 0.1307661152843918, 0.1684861212436642, 0.08850001969507762, 0.18464803828724793, 0.09859007290963616, 0.07922551807548318, 0.13368175311812333, 0.10908681287297181, 0.11054667418024369, 0.11643655491726738, 0.24739913323095866, 0.21377998936389173, 0.13947503082454205, 0.24971418614898408, 119.87261499677385, 137.53086417061942, 125.28805487496513, 118.485504422869, 93.16125215802873, 62.28080340794155, 27.912087985447474, 66.55213900974819, 89.49574388776506, 88.57130690983364, 81.51975386483329, 77.90473120553153, 42.74593264716012, 13.26955154963902, 0.4623303658195904, 0.6703272962144443, 0.2994506944503103, 0.3992681082870279, 0.22907350371990884, 6.291010609694889, 12.069599390029907, 9.268447024481636, 9.720584545816694, 22.209359203066143, 73.23692444392613, 90.63198280334473, 97.65064307621547, 96.32212666102818, 97.80501120431083, 94.58607755388532, 94.79988752092633, 85.50319780622209, 87.414598601205, 92.20556218283517, 89.2419331414359, 77.8940657206944, 77.0656806400844, 73.19203213282994, 75.58495003836495, 76.89053739820207, 90.1002858025687, 90.22877189091274, 85.38455731528146, 72.83479050227574, 68.58765547616142, 70.60384205409459, 74.18840381077358, 76.60004016331264, 84.16595445360456, 89.37636688777378, 84.11410699571881, 82.29697935921806, 87.02021884918213, 83.97919382367814, 90.31363024030412, 87.18753147125244, 90.60216113499233, 83.47438635144914, 97.07039901188442, 81.69780840192522, 94.42182908739362, 65.94934804098946, 47.34992715290615, 97.79233769008091, 78.00448649270194, 76.58145373208183, 67.1701465334211, 79.18540927342006, 82.01361792428153, 88.04713480813163, 79.0846951348441, 74.11000728607178, 69.28940963745117, 69.97106266021729, 66.96784973144531, 66.99348163604736, 67.10087299346924, 68.5642956324986, 67.19099807739258, 76.82124996185303, 81.53269835880825, 88.35776792253766, 93.28084455217633, 92.42862020220075, 84.97683702196393, 78.43817915235246, 73.39341177259172, 80.9914892741612, 86.27528163364956, 85.49914700644356, 70.34511893136161, 77.3424551827567, 93.28568744659424, 94.43656621660504, 58.9304723739624, 6.561631653990064, 2.827992171049118, 4.754763901233673, 3.1831539017813544, 1.275877839752606, 5.896344244480133, 4.199935044561114, 0.5494290207113538, 0.13976966430033955, 0.2151289712637663, 0.3691489158996514, 8.270051683698382, 39.97718320574079, 69.85304055895124, 60.48254707881382, 61.59905311039516, 102.64727333613804, 46.001424244471956, 29.21190139225551, 23.63163113594055, 41.13381855828421, 66.13874898638043, 78.08767032623291, 79.83139719281877, 94.24718611580985, 100.59236444745744, 77.93823541913713, 8.917983361652919, 0.2593648268708161, 0.14575546953294957, 0.13231906481087208, 0.12809926910059793, 0.10845724094126906, 0.17079186466123375, 0.11385212359683854, 0.14696035773626395, 0.10242854551013027, 0.11355706264397927, 0.13331858760544232, 0.1700245908328465, 0.09509038605860301, 0.17636136151850224, 0.10347025282680988, 0.10751383977809123, 0.267942378031356, 0.13368027391178267, 0.2802911454013416, 0.1254157716674464, 0.21157095075717994, 0.14451768595193112, 0.14762704553348677, 0.15911348988967283, 0.09000719524919987, 0.16140810533293656, 0.1260278509663684, 0.17774137961012976], [0.02385088418876486, 0.062077547157449384, 0.16729033898030007, 0.028889527477856194, 0.03048700586493526, 0.026420401309483817, 0.05859877954104117, 0.015398882362725479, 0.02219052765784519, 0.02117291003066514, 0.03638960913355861, 0.0529613070456045, 0.03499791345426014, 0.023914383192147528, 0.033500641118735075, 0.021899593894236853, 0.08789164519735745, 0.00968821459848966, 0.03864793652402503, 0.0912558761026178, 0.13119201814489706, 0.10601574980786868, 0.17516652920416423, 0.3187321626714298, 39.0773914882115, 108.07047435215541, 90.7437584740775, 83.31108978816441, 77.83078847612653, 67.2689916065761, 27.274840899876185, 50.16225222178868, 76.27850532531738, 55.41471515383039, 34.8389938218253, 51.365906034197124, 27.92857084955488, 8.693167448043823, 0.19558328150638513, 0.08015412717525448, 0.19607612863183022, 0.0495048768020102, 0.04403053430308189, 0.09702737283493791, 4.222366000924792, 3.9217691251209805, 1.1061957733971732, 18.94776013919285, 63.75906045096261, 90.29864297594342, 91.80254581996373, 90.1432465144566, 86.91830962044853, 88.55813312530518, 84.35577923910958, 89.45465918949672, 84.7460526057652, 84.1776065826416, 84.31437492370605, 77.25603348868233, 70.97627939496721, 65.16259656633649, 59.851893833705354, 60.52919033595494, 61.38370064326695, 64.99757684980119, 68.19224044254848, 67.6984041758946, 60.553363118852886, 59.922890526907786, 60.3082515171596, 64.45918873378209, 70.0140164239066, 75.90294129507882, 71.15804427010673, 65.81208637782505, 63.20742906842913, 72.79664489201137, 76.96434811183384, 80.8315486907959, 77.39674145834786, 77.42241505214146, 73.50024032592773, 71.76253059932164, 72.90020084381104, 82.00584289005825, 76.91923345838273, 43.5299117905753, 79.59273351941789, 76.81086935315813, 73.65064103262765, 73.19960566929409, 78.8024593080793, 80.1235133579799, 83.39352321624756, 80.95473330361503, 72.69322790418352, 61.62967382158552, 64.07373046875, 59.52707944597517, 58.662292752947124, 59.00644397735596, 59.5367374420166, 56.957083225250244, 64.94620186941964, 72.00564111982072, 79.60428142547607, 80.11047853742326, 72.60840429578508, 63.61373192923409, 60.91981111254011, 59.89446544647217, 69.5877583367484, 77.86700248718262, 76.15327794211251, 72.69504833221436, 81.70024721963065, 76.36061218806675, 73.53621809823173, 84.60934679848808, 74.27129581996373, 17.267536333629064, 0.4585439775671278, 1.0035076950277602, 0.6421831835593496, 1.601091206073761, 2.0678551197052, 0.7081788022603307, 0.0574387696438602, 0.1361904735011714, 0.15854809380003385, 0.021040980770651783, 3.1298918340887343, 14.785485199519567, 37.40445286887032, 38.49475029536656, 50.65027632032122, 69.80470194135393, 28.30983935083662, 21.852880137307302, 13.722808599472046, 23.624582188470022, 34.3304169518607, 48.155622891017366, 64.60476739065987, 72.14299310956682, 76.78736359732491, 48.16722638266427, 0.6014319988233703, 0.01964485934669418, 0.0652148284550224, 0.06343925158892359, 0.034828880203089545, 0.07886452387486186, 0.04040152546284454, 0.02956799464300275, 0.07604740932583809, 0.014627598392378007, 0.055450014038277526, 0.04723745704229389, 0.058876700699329376, 0.023966906891603555, 0.01326569973025471, 0.06312265393457242, 0.043213428862925084, 0.026406484556251338, 0.030964837010417665, 0.10023895371705294, 0.05297981408823814, 0.07322289195976087, 0.07018846978566476, 0.04167419931452189, 0.03985295704166804, 0.0884734211223466, 0.009848758528408195, 0.017127021149333035, 0.02556134883447417, 0.02833525088083531, 0.1687790990940162, 0.04648137904171433, 0.004328627638252718, 0.019355435323502337, 0.0654873349038618, 0.011288776927228485, 0.06765509144003902, 0.01811848803689437, 0.01982268980438156, 0.03879377405558314, 0.03756345096709473, 0.041370398830622435, 0.02305198723583349, 0.05555800627917051, 0.07787236997059413, 0.023207509158445255, 0.019873488328552673, 0.03399186993816069, 0.0899089773052505, 0.11305795942566224, 0.20480842648872308, 0.22594716719218663, 51.40584775379726, 126.77170372009277, 102.72972760881696, 96.86892209734235, 92.04330784933907, 87.78461796896798, 46.54175785609654, 31.16662767955235, 60.23939486912319, 70.38951792035783, 38.68442916870117, 46.408550466809956, 36.137421063014436, 10.386781300817217, 0.10110506295625653, 0.15819440063621315, 0.04034311716843929, 0.012164799563054527, 0.07039857815418925, 0.13618034975869314, 3.1724675723484586, 5.6400768756866455, 1.187122745173318, 24.628959928240093, 67.50249276842389, 95.6208449772426, 93.56537328447614, 93.04810074397496, 87.9028137751988, 89.18181037902832, 86.58537973676408, 91.36113371167863, 85.7522976739066, 82.34324741363525, 86.6882825578962, 82.51518058776855, 73.47910390581403, 68.65920802525112, 62.45267404828753, 63.87615844181606, 63.81042153494698, 68.0242885862078, 69.7641453061785, 72.58584349496024, 64.04606969015938, 62.400235993521555, 63.07873453412737, 70.48397868020194, 73.1775381905692, 78.65523392813546, 74.39172894614083, 69.27744483947754, 65.9030521937779, 74.17327063424247, 78.83068983895438, 84.13012954166958, 79.812317439488, 80.5470199584961, 74.52491896493095, 75.72470610482353, 77.2738903590611, 85.19106388092041, 80.44344316210065, 47.03840119498116, 83.4960994720459, 82.5000057220459, 75.62108761923653, 76.8523223059518, 82.17890167236328, 84.13154002598354, 85.69236946105957, 85.67170551845005, 76.4218327658517, 63.28171225956508, 65.76537363869804, 61.025194440569194, 61.24364580426897, 61.38471508026123, 61.225580487932476, 59.80386093684605, 67.33838326590401, 75.0353753226144, 81.11049801962716, 82.44480228424072, 76.86426625932965, 67.43371949877057, 63.6512313570295, 61.71444879259382, 72.88495649610246, 82.36630848475865, 78.31835746765137, 72.76851163591657, 86.58047430855888, 80.43392413003104, 77.0830511365618, 88.60174696786063, 84.55059283120292, 26.025280339377268, 1.8727023686681474, 0.22405523514109, 0.49517352346863064, 1.6084201442343848, 1.934381093297686, 0.44859955832362175, 0.08422118465283088, 0.08626489820224897, 0.17287797986396722, 0.008446460739443344, 3.7965669291360036, 17.818842887878418, 38.48784031186785, 28.144185611179896, 47.56668663024902, 48.70168876647949, 25.512298311505997, 31.55341305051531, 22.521182196480886, 39.05767944880894, 47.032658508845735, 58.624459811619346, 72.61579717908586, 81.81970759800502, 90.5116400037493, 62.32674489702497, 0.9559185057878494, 0.044150085388017554, 0.054751116183719466, 0.03929703330088939, 0.055971105183873854, 0.08315689569073063, 0.05997961866004126, 0.016828852506088357, 0.0983802020283682, 0.03349764538662774, 0.035635980644396374, 0.0706860123734389, 0.04306908071573291, 0.01843421207740903, 0.006791888719557652, 0.030666464806667397, 0.05837554151990584, 0.011222087961089398, 0.06862813101283141, 0.08878874313086271, 0.030914533816810166, 0.036400448730481524, 0.013673546773913716, 0.04973855069173234, 0.03958542764719043, 0.039268375374376774, 0.03167329203071339, 0.05528821397040572, 0.17198998108506203, 0.13394704673971447, 0.35530074898685726, 0.13175905628928117, 0.1582749698843275, 0.08414153821234192, 0.20306550072772162, 0.12008829468062945, 0.22971170661704882, 0.13790146740419523, 0.10891274149928774, 0.2025078535079956, 0.18297371241663182, 0.13174739905766078, 0.06361041883272783, 0.09568298461713962, 0.14177366319511617, 0.09109559934586287, 0.11057786643505096, 0.1250299159437418, 0.28581113634364946, 0.16939087983752998, 0.3016816633088248, 0.3228721762342112, 67.69373498644147, 142.4018987928118, 119.09513936723981, 112.32195200238908, 102.52491555895124, 91.4904396874564, 45.04722465787615, 67.8615756716047, 94.99814741952079, 76.36369024004254, 49.51841476985386, 77.36285509381975, 46.81843164988926, 15.838111230305262, 0.4576656275561878, 0.7939811295696667, 0.32956532708236147, 0.10706582346132823, 0.1430976614356041, 0.2944907663123948, 12.527065311159406, 11.468816450663976, 2.738715418747493, 24.028036287852697, 68.70980480739048, 98.06951522827148, 99.71324362073625, 97.80376052856445, 92.11413083757672, 95.20958805084229, 91.12940434047154, 96.19951180049351, 86.6394853591919, 84.50539479936872, 92.13148743765694, 87.75658893585205, 79.46436555044991, 73.15771497998918, 65.38188866206578, 67.25513689858573, 69.21626595088414, 71.83368015289307, 74.54199068886894, 76.0900354385376, 68.64925820486886, 67.87997450147355, 67.56599235534668, 74.28289931161063, 77.19762693132672, 84.6567474092756, 77.27678775787354, 73.30544063023159, 69.99458231244768, 79.69073091234479, 83.34596974509103, 87.87196377345494, 84.57163197653634, 85.19169616699219, 81.0273072378976, 80.33815016065324, 82.93373312268938, 90.17222050258091, 86.13087027413505, 53.196384634290425, 88.56993116651262, 86.08969524928501, 80.9735768181937, 79.59812532152448, 85.93849549974713, 86.70336709703717, 88.17367540087018, 88.81602941240583, 79.08468818664551, 68.04015827178955, 70.087952205113, 65.32133511134556, 66.22076552254813, 66.46079799107143, 65.79419476645333, 63.19174003601074, 71.11789063044957, 78.5187852042062, 86.95802552359444, 87.65634032658168, 82.30533109392438, 70.1257712500436, 67.61638763972691, 65.97108200618199, 77.9615535736084, 87.78834915161133, 81.2709527696882, 72.60021931784493, 90.87524618421281, 84.50185816628593, 79.67697347913469, 94.73834037780762, 87.06818226405552, 21.97119927406311, 2.9707967596394673, 2.956977444035666, 2.7400093036038533, 4.604183844157627, 6.261065176555088, 1.8231934138706751, 0.3754638784698078, 0.49065203751836506, 0.3446304058390004, 0.259362167013543, 7.49378330366952, 26.971465178898402, 57.92965037482125, 57.85284846169608, 68.52611528124127, 94.36579186575753, 41.75959416798183, 31.912020002092632, 19.995155913489207, 36.625333990369526, 51.81409611020769, 66.44768674033028, 85.39215864453996, 90.84374305180141, 99.06265599387032, 70.10633713858468, 1.8662650798048293, 0.1986503005027771, 0.21720376850238868, 0.19041215255856514, 0.11537479689078671, 0.29831982084683006, 0.14262089559010097, 0.1125646848231554, 0.24158957068409237, 0.08565309031733445, 0.13277366970266613, 0.10919592808932066, 0.18859411297099932, 0.16334738555763448, 0.1413640451750585, 0.16866294746952398, 0.17977416196039744, 0.10828026543770518, 0.08931232110730239, 0.29565901362470215, 0.13214968889951706, 0.1938301505787032, 0.15197383585785115, 0.11735896899231843, 0.0969255179432886, 0.105966094615204, 0.08563943819275924, 0.13647513251219476], [0.029366225469857454, 0.02868623160091894, 0.03225819939481361, 0.0028842420184186524, 0.024185044025736194, 0.029369292448141744, 0.03119360509195498, 0.060415170288511684, 0.05433839386595147, 0.0011473168394461805, 0.03184659326715129, 0.055150386544742754, 0.02945996169000864, 0.0322628202182906, 0.016119223620210375, 0.05596322739230735, 0.05969493929296732, 0.09260201494076423, 0.006966667890083045, 0.10293163851435695, 0.12049503571220807, 0.2591113533292498, 0.4584316664508411, 7.931279233523777, 93.56728403908866, 94.23426941462925, 107.49309989384243, 77.96160221099854, 46.7934250831604, 29.952989305768693, 25.55394755090986, 115.52035372597831, 63.59464522770473, 22.26164960861206, 64.75834342411586, 30.56965582711356, 9.74139700617109, 0.17463347209351404, 0.05306128578792725, 0.06239890134228127, 0.0907201116372432, 0.16703451770756925, 0.18352492712438107, 0.1773037380938019, 4.04260915517807, 1.9268012600285667, 4.426464123385293, 53.72225904464722, 91.340421131679, 91.00927693503243, 88.02592195783342, 84.38022300175258, 81.73616940634591, 80.77024473462785, 82.69020571027482, 82.826571055821, 89.44648115975517, 81.73227841513497, 82.89660889761788, 78.2257171358381, 73.65754059382847, 64.27096898215157, 59.10788072858538, 56.71750238963536, 58.02390268870762, 59.15561485290527, 59.88940020969936, 58.13797126497541, 57.30905812127249, 58.94898932320731, 61.219208989824565, 60.37227916717529, 64.14903504507882, 62.8222348349435, 60.94868087768555, 57.50320816040039, 60.498687744140625, 58.301354680742534, 63.085161617824006, 64.20674678257534, 65.63938890184674, 60.358174324035645, 58.961996350969585, 59.99142060961042, 68.34492710658482, 66.38898141043526, 79.70596831185478, 42.779134614127024, 71.66169834136963, 77.82503536769322, 70.87662833077567, 71.04651178632463, 78.77630628858293, 80.44544424329484, 75.18828432900565, 80.91306495666504, 72.80942262922014, 61.57028062002999, 61.21105180467878, 59.98924582345145, 56.368970326014924, 57.00264603751046, 57.69182048525129, 59.86043316977364, 58.92242635999407, 63.876867158072336, 67.85678141457694, 66.32835142953056, 59.88772569383894, 58.88541330610003, 58.54381207057408, 64.31911999838692, 71.03450529915946, 77.95036002567836, 73.53837898799351, 71.49523339952741, 78.17448806762695, 72.01988492693219, 72.94286278315953, 74.35058171408517, 78.78688144683838, 78.27315943581718, 27.56514184815543, 0.9804808220693043, 0.21901720762252808, 0.9517336274896349, 0.2889631214950766, 0.19973993274782384, 0.1608077511191368, 0.11475249885448388, 0.03985846335334437, 0.06649864385170595, 0.1398531919611352, 2.2959914037159512, 11.718926412718636, 36.37146765845162, 30.618574619293213, 30.908477783203125, 56.796444347926546, 48.324408531188965, 33.69843660082136, 14.581378391810826, 13.98021069594792, 27.7102358681815, 50.109119347163606, 79.29045908791679, 71.77551678248814, 80.71035126277378, 17.939988204411097, 0.32579644503337996, 0.07300180489463465, 0.023407532800255076, 0.05879373622259923, 0.07635437178292445, 0.05506279106651034, 0.017035259466086115, 0.047263550106436014, 0.02293693653440901, 0.05778132126267467, 0.06714949464159352, 0.08093949074723891, 0.011388691208724464, 0.055441237187811306, 0.04270978963800839, 0.025003525195643306, 0.061675108037889004, 0.030613145524902, 0.00965591802793954, 0.014493867621890135, 0.038114099098103385, 0.007033455667884222, 0.03853660589084029, 0.031918168533593416, 0.07760320869939667, 0.02006607353022056, 0.03474687585341079, 0.01628630099418972, 0.02995205224890794, 0.05607760464772582, 0.057304996464933665, 0.03600274578535131, 0.01471476978622377, 0.06999357417225838, 0.030841265605496507, 0.09388864625777517, 0.05790361362908568, 0.024673170243789042, 0.026993225661239455, 0.02020589754517589, 0.05170589851747666, 0.015204195398837328, 0.06105492703084435, 0.07655492637838636, 0.07584680723292486, 0.04092823487839528, 0.06480685927506004, 0.14019712779138768, 0.25769202091864174, 0.5119689479470253, 14.084671650614057, 121.6457952771868, 103.71261283329555, 122.74393027169364, 89.11578164781842, 66.07317883627755, 51.134075914110454, 39.36300413949149, 87.26361424582345, 56.70705577305385, 15.93759206363133, 45.98103822980608, 38.42939553941999, 13.16631087235042, 0.059730548810745986, 0.07610672007181815, 0.13940438175840036, 0.0741344155477626, 0.5510426312685013, 0.18872668514294283, 0.18947730772197247, 1.7356708645820618, 0.3115725597100598, 6.730879349367959, 57.18816293988909, 95.27162156786237, 92.23154844556535, 90.64801924569267, 85.88463306427002, 86.18191868918282, 83.6226053237915, 83.90884331294468, 84.985397202628, 89.55080836159843, 81.76059232439313, 85.64049421037946, 80.76161507197789, 77.58258492606026, 67.23889895847866, 62.80530902317592, 60.10990824018206, 61.977125440325054, 62.208264214651926, 61.747953006199424, 62.29391465868269, 60.30306816101074, 63.51617922101702, 63.72930826459612, 65.2670418875558, 66.13402421133858, 66.49827657427106, 64.3299036026001, 59.31544426509312, 63.034953934805735, 60.68759536743164, 65.3090159552438, 67.7900161743164, 69.20657321384975, 63.966783796037944, 61.58077934810093, 61.935477937970845, 69.99575655800956, 70.33487728663853, 83.267594064985, 46.46578625270298, 75.36440031869071, 79.87483733040946, 74.76018496922084, 73.32269995553153, 82.28290230887276, 82.70103795187813, 77.191422189985, 84.89953136444092, 75.9054148537772, 63.59841809953962, 62.47093391418457, 63.27717508588518, 58.98384148733956, 58.76179095676967, 60.90703337533133, 63.37698595864432, 60.837287357875276, 66.52946008954729, 69.2018484388079, 69.43755912780762, 63.18610504695347, 60.511868476867676, 60.00936780657087, 68.06239250728062, 75.32407297406877, 81.58375372205461, 73.82804243905204, 73.19568688528878, 82.88360186985561, 76.50889369419643, 77.09559263501848, 78.04784325190953, 80.66265882764543, 83.79675497327531, 37.069056374686106, 2.625366849558694, 0.1974150953548295, 0.8431668302842549, 0.7447180215801511, 0.5258610567876271, 0.2375047355890274, 0.10904763426099505, 0.027649289296407784, 0.04287900609363403, 0.06075449886598757, 2.396120156560625, 13.10202613898686, 39.81368861879621, 25.502369335719518, 35.79831770488194, 38.501608167375835, 23.669681208474294, 27.4489141191755, 18.28770211764744, 24.820440122059413, 38.739740303584504, 57.625433921813965, 86.1009999683925, 81.23787934439522, 96.72551127842495, 25.629398039409093, 0.35719904569642885, 0.047001907003245184, 0.0770648183034999, 0.016055039296458875, 0.029796796651290994, 0.08819207336221423, 0.05639671288164599, 0.031927030200936964, 0.03056905771206532, 0.03409210313111544, 0.03972346202603408, 0.022333111613988876, 0.03380770535607423, 0.0266604551247188, 0.049836045995886834, 0.03990141122734972, 0.022795874193044643, 0.04756599012762308, 0.06583682793591704, 0.01703103049658239, 0.02933288225904107, 0.014135851341831897, 0.008292029561874057, 0.01756753965413996, 0.045928373001515865, 0.015324148515771543, 0.04168884549289942, 0.14708660596183368, 0.09888902186815228, 0.17662586803947175, 0.0929477217474154, 0.10659944598696061, 0.13373765083295958, 0.1811519001743623, 0.0957145229248064, 0.16288241265075548, 0.1225381317947592, 0.07266329734453134, 0.07700801135173865, 0.09727497026324272, 0.2022824984576021, 0.14015241233365877, 0.21522110274859838, 0.20868804545274802, 0.24746275267430715, 0.13023475451128824, 0.2519551430429731, 0.3641957188291209, 0.534155088875975, 0.9485588435615812, 22.163035563060216, 139.1100229535784, 118.19195692879813, 134.79331561497278, 105.00822257995605, 71.6232192175729, 46.42635522569929, 36.663507393428254, 149.9260196685791, 83.91670867374965, 29.47026320866176, 98.08220958709717, 47.96634006500244, 19.467871018818446, 0.35024601593613625, 0.2559073381125927, 0.575018150465829, 0.325664510684354, 1.183442588363375, 0.4602718534214156, 1.0645869203976221, 19.167272840227398, 7.148975908756256, 6.2580791882106235, 56.78283282688686, 99.6156700679234, 96.3933526447841, 95.28159918103898, 90.90078081403459, 90.1619232722691, 87.7053668158395, 88.6515030179705, 88.5358224596296, 95.4250794819423, 83.0416316986084, 90.12652914864677, 84.48286873953683, 80.27345548357282, 71.87720366886684, 66.78746059962681, 63.19579083578927, 64.876601764134, 65.64349528721401, 66.46234049115861, 64.60662950788225, 63.704426765441895, 65.32372529166085, 67.53984628404889, 68.83441380092076, 71.626359803336, 68.16888754708427, 68.43057755061558, 62.94089617047991, 66.97818170275006, 64.94143540518624, 70.49853515625, 72.86189542497907, 73.52321801866803, 68.12056282588414, 66.28882312774658, 65.9800660269601, 75.00481714521135, 72.06050409589494, 86.95458616529191, 51.28856216158186, 80.29754488808769, 84.84424454825265, 78.21613556998116, 78.2945112500872, 87.17443411690849, 85.57193633488247, 80.72400447300502, 87.87917600359235, 79.1322694505964, 67.98046629769462, 67.57741519383022, 65.01500293186733, 62.13113226209368, 60.844200815473286, 64.29113960266113, 67.65196936471122, 64.26699461255754, 70.59669930594308, 73.54279804229736, 73.27363177708217, 67.9073017665318, 64.12188843318394, 64.68651294708252, 72.42920330592564, 78.6403647831508, 84.36388778686523, 75.68419810703823, 73.67570318494523, 86.04420539311, 81.69616862705776, 80.23999295915876, 81.07502746582031, 87.19311782291958, 88.1694369997297, 35.552782263074604, 1.9829461787428175, 0.9266935139894485, 2.7569001572472707, 2.181553921529225, 1.612652899963515, 0.3907326262976442, 0.3854662717453071, 0.40840490800993784, 0.23924365799341882, 0.6789765549557549, 4.593713777405875, 21.091781411852153, 57.94208765029907, 45.47881548745291, 46.107189723423545, 78.36679336002895, 65.5265223639352, 48.52058049610683, 24.916667461395264, 22.67854152406965, 41.47754941667829, 69.2540363584246, 101.03783430371965, 90.73043182918003, 105.6013763972691, 31.000861031668528, 0.4621481927377837, 0.12270578422716685, 0.145847031048366, 0.11496059197400298, 0.1927524876913854, 0.2897105685302189, 0.15307494891541346, 0.11475970489638192, 0.09448921760278088, 0.08837784267961979, 0.18463692388364247, 0.10757824632206134, 0.09288077069712536, 0.2772965260914394, 0.09744765064013855, 0.1331492524061884, 0.18439208130751336, 0.09738258591720036, 0.14725649755980286, 0.07773540089172976, 0.07494240147726876, 0.10734924753861767, 0.08548028101878506, 0.1832901540079287, 0.1553372796624899, 0.12399010173976421, 0.09206743791167225], [0.06554021313786507, 0.025214915995353034, 0.020752481251422848, 0.05501211128596749, 0.04159846802109054, 0.040313105564564466, 0.01767995424701699, 0.050627943860100846, 0.01961149917250233, 0.04741158948412963, 0.00952214908985687, 0.019318456861323545, 0.02393542117040072, 0.04427106478916747, 0.09464612882584333, 0.06468359660357237, 0.05942425810332809, 0.03357695595228246, 0.02034725165659828, 0.06845626487795796, 0.11533154706869807, 0.04264710318031056, 0.45243642958147184, 72.9419664655413, 97.3854511805943, 103.04232706342424, 85.6212407520839, 68.33790247780937, 38.252876554216655, 28.914700882775442, 68.68725095476422, 97.39561639513288, 94.18759836469377, 76.28315367017473, 38.94899572644915, 8.460553918566022, 0.33653162898761885, 0.1376014327896493, 0.19817843368010862, 0.16500525016869816, 0.13434762667332376, 0.0813550255926592, 0.5135682821273804, 0.12711782247892447, 1.8594819009304047, 2.8407145398003713, 24.199893031801494, 85.44051115853446, 89.64898640768868, 82.98341274261475, 80.15076419285366, 77.36598178318569, 74.94654955182756, 71.75462354932512, 75.89366544995988, 79.04261684417725, 83.46463108062744, 81.51723166874477, 82.28290925707135, 78.2071932383946, 71.85469845363072, 66.15506335667202, 62.3041215624128, 62.12372548239571, 60.40935475485665, 57.36979232515608, 59.487842968532014, 57.4629989351545, 56.64994852883475, 56.39385182516915, 61.47978033338274, 61.06274250575474, 60.82467637743269, 59.192891938345774, 61.92725821903774, 63.28609657287598, 59.11241790226528, 57.309617451259065, 56.76200212751116, 55.115039348602295, 58.035120555332725, 58.786213874816895, 62.792677198137554, 65.51671150752476, 78.18145016261509, 72.30464989798409, 87.58516992841447, 35.56858594076974, 60.03006649017334, 84.53314590454102, 70.80402660369873, 72.26970045907157, 76.77755968911308, 78.84710843222481, 73.28445707048688, 77.727586882455, 69.79694775172642, 59.97367491040911, 58.39944934844971, 61.19136755807059, 56.44972576413836, 57.707686696733745, 59.287443024771555, 59.685512270246235, 59.28828375680106, 59.35743222917829, 55.67782606397356, 58.199514933994834, 57.08234882354736, 58.735790797642295, 64.88874026707241, 70.96234130859375, 72.77500820159912, 77.87541675567627, 69.13834190368652, 72.10390254429409, 76.82323714665004, 75.61860711233956, 62.417335510253906, 70.04301820482526, 78.94006143297467, 76.52685478755406, 56.761988231113975, 25.23558803967067, 1.400442538516862, 0.23081812581845693, 0.44563465884753634, 0.10400062293878623, 0.07463915060673441, 0.10392360242881946, 0.041851731216801066, 0.1449787640678031, 0.03374598581077797, 0.416311008057424, 0.12448198534548283, 4.513664884226663, 30.71363639831543, 27.9292083467756, 50.85004397800991, 106.51836490631104, 70.67033631461007, 73.6400728225708, 27.11602939878191, 13.805585094860621, 35.56531681333269, 59.34238937922886, 69.37317711966378, 77.15905053274972, 71.98335129874093, 2.290955045393535, 0.1444892824760505, 0.06378761825284787, 0.07289843008454357, 0.010385315183417072, 0.037105409295431206, 0.02141479928312557, 0.028975840524903367, 0.02547238950085427, 0.01614090790306883, 0.026264847156458666, 0.06109407850142036, 0.04548927263489791, 0.012004091936562742, 0.019112097398777093, 0.06857171761138098, 0.06919454490499836, 0.08262437462274518, 0.03538104146718979, 0.048306628063853295, 0.07627420965582132, 0.02456092698100422, 0.06105843505689076, 0.05314124096184969, 0.06451923506600515, 0.011509653646498919, 0.03699433650555355, 0.055571980707879574, 0.03281954463039126, 0.037390003845627816, 0.040768049723867855, 0.05994806678167411, 0.07810829659657818, 0.022608466213569045, 0.0354536786409361, 0.04443996572600944, 0.06029014342597552, 0.034263572323002985, 0.012888569966889918, 0.03257018640371306, 0.01069769828713366, 0.06069226363407714, 0.102839038840362, 0.05167516088113189, 0.03389560956774013, 0.014424499290596162, 0.05958764933581863, 0.07271315609770161, 0.07255636022559234, 1.2168731944901603, 101.9893901007516, 108.92369924272809, 114.92192622593471, 94.08615466526577, 91.73965767451695, 56.63681990759713, 37.02795778002058, 36.46698107038225, 97.33474322727749, 86.25650760105678, 45.60029779161726, 51.96080732345581, 10.486178755760193, 0.2458844802209309, 0.09672452908541475, 0.08292185116027083, 0.11015203821339778, 0.09475373769445078, 0.08594184089452028, 0.24010431181107247, 0.5977485850453377, 1.9183133840560913, 2.053258691515241, 29.05652403831482, 86.06600884028843, 90.82731056213379, 87.21535900660923, 84.42942319597516, 80.39541026524135, 80.37810230255127, 74.76288087027413, 79.94114398956299, 82.33702182769775, 88.88412870679582, 82.53414916992188, 83.22532122475761, 81.31619943891252, 75.9204021181379, 70.69840008871896, 66.0334837777274, 64.13976614815849, 64.91435132707868, 61.30455371311733, 61.11518056052071, 60.98071207318987, 60.79472269330706, 58.635959080287385, 64.49337387084961, 62.79158633095877, 63.2574838910784, 61.96855136326381, 63.82830619812012, 64.32977158682687, 62.454292978559224, 59.09205968039376, 60.367297308785574, 58.07938405445644, 63.27518790108817, 59.89188071659633, 64.50524139404297, 68.95983573368618, 82.12299646650041, 75.79560552324567, 91.00521223885673, 37.483439990452354, 61.64468193054199, 86.36187703268868, 74.75404276166643, 75.48028237479073, 79.34307779584611, 80.91396822248186, 76.26474789210728, 82.51923833574567, 72.23621014186314, 62.359366689409526, 61.42065116337368, 64.74842139652797, 62.34446280343192, 60.740978377205984, 62.00859383174351, 63.03564180646624, 62.71527426583426, 62.22136851719448, 58.98707239968436, 60.082080704825266, 59.53017834254673, 62.796450069972444, 70.05164786747524, 73.05091421944755, 77.07246903010777, 82.17855426243374, 69.74495438167027, 73.48011834280831, 80.10034111567906, 78.78821550096784, 65.89506871359688, 72.1711402620588, 84.2629929951259, 76.21628420693534, 63.290939467293875, 33.13627174922398, 2.9264605215617587, 0.2045257623706545, 0.4718725766454424, 0.36022908453430447, 0.22575071773358754, 0.21468784207744257, 0.08860956238848822, 0.14376965537667274, 0.053272367854203494, 0.5035407287733895, 0.09882428284202303, 4.863584416253226, 36.93302454267229, 27.79150026185172, 50.31582130704607, 96.8981740134103, 45.351416792188374, 44.98311710357666, 28.558148860931396, 27.10719997542245, 46.85626111711775, 68.27441678728376, 78.33250399998256, 84.32047544206891, 87.32112448556083, 4.447287440299988, 0.1690799750919853, 0.048086443450301886, 0.024175441058884774, 0.03639482706785202, 0.12256183980831079, 0.04854645287351949, 0.05533924998183336, 0.036175826497908146, 0.026220236871657625, 0.027010977833664844, 0.05157647474801966, 0.05340745739106621, 0.029402611910232475, 0.02543176560928779, 0.03780913831932204, 0.028505497013351748, 0.05549328760909183, 0.045003841897206645, 0.049631969803678136, 0.03869599037404571, 0.010763467838322478, 0.04868438547211034, 0.06888740602880716, 0.09151364477085215, 0.04001363752675908, 0.016726269885631542, 0.11057572904974222, 0.16299496803964886, 0.1073636935491647, 0.17326733682836803, 0.18368291721812316, 0.1750131260071482, 0.06836504941540104, 0.13150271932993615, 0.11379176112157957, 0.16512661294213363, 0.1183523985424212, 0.09896359965205193, 0.11226069434945073, 0.09347352531871625, 0.1439210365393332, 0.21349731167512281, 0.17648405422057423, 0.1240768049444471, 0.09165779275021382, 0.28323693733130184, 0.27530060176338467, 0.32100924476981163, 2.6618550973279134, 116.89540917532784, 121.99377495901925, 127.12067004612514, 110.52177797045026, 93.4563421521868, 57.43070370810372, 43.362616539001465, 91.41897746494838, 112.64892727988106, 111.49415057046073, 115.13372121538434, 57.97377143587385, 15.45271897315979, 0.7177551569683212, 0.29894135892391205, 0.46911636739969254, 0.2692277133464813, 0.45719472425324575, 0.43274265634162085, 1.135212970631463, 1.5186196714639664, 8.990975056375776, 6.981833517551422, 28.53524759837559, 94.23137896401542, 96.21801485334123, 92.89108535221645, 87.38074002947126, 83.99633502960205, 81.79916177477155, 79.33682441711426, 82.76991544451032, 86.95985984802246, 92.21656118120465, 86.95035471235002, 84.91044698442731, 87.10742568969727, 78.93770599365234, 74.41525554656982, 68.8728095463344, 68.42722851889474, 68.17191696166992, 64.89065102168492, 64.15480204990932, 63.99217251368931, 64.52168778010777, 63.36262403215681, 66.73707921164376, 69.06363487243652, 67.58660766056606, 67.61736038752964, 68.06895160675049, 70.47479316166469, 66.15640435900006, 63.98778125217983, 63.48170920780727, 61.305130413600374, 63.3441835130964, 66.17401804242814, 69.78141157967704, 73.12384946005685, 86.26658248901367, 79.88653114863804, 93.11320536477226, 43.39310870851789, 66.42425046648297, 89.42068944658551, 78.86734853472028, 79.55777713230678, 83.53705215454102, 84.4874962397984, 79.10747132982526, 85.94138595036098, 75.9763490131923, 66.46293108803886, 62.92812538146973, 69.02689974648612, 65.30244295937675, 65.36337171282086, 64.58481216430664, 65.64314092908586, 65.45055770874023, 64.95651994432721, 61.12806946890694, 63.453249386378694, 64.03420216696603, 65.78040259225028, 72.40716361999512, 77.86369514465332, 82.16896574837821, 85.0657878603254, 71.3357652936663, 75.37359973362514, 83.57135541098458, 82.99378640311105, 70.01268931797573, 77.52294158935547, 87.21055780138288, 81.74485465458461, 73.36090809958321, 36.612149783543174, 2.110549194472177, 0.8860362385000501, 1.5415077975818088, 0.6782034050141061, 0.35725555409278187, 0.46672276726790835, 0.2163117527961731, 0.2968430300908429, 0.1973311741437231, 0.5907241734010833, 0.45078590671930996, 8.730279513767787, 50.638148239680696, 42.520977769579204, 67.29788916451591, 134.07785960606165, 94.46030821119035, 97.97793102264404, 39.44175502232143, 24.188289540154592, 53.97876569202968, 77.47554097856793, 90.0681573322841, 95.28788035256522, 96.72665078299386, 4.895975615297045, 0.34241754029478344, 0.11059020220169, 0.2977700989161219, 0.07813173998147249, 0.18439052067697048, 0.11538266789700304, 0.14975147082337312, 0.11004200018942356, 0.12343823563839708, 0.1199748164841107, 0.08587127325258084, 0.07856015342154674, 0.16106397951287882, 0.10702275005834443, 0.22931462792413576, 0.09914552846125194, 0.17117890103587083, 0.13577155955135822, 0.12547683981912477, 0.11639464859451566, 0.11580031977168151, 0.14843372867575713, 0.17671699529247625, 0.25136818311044146, 0.08879538598869528, 0.10902341734617949], [0.03509677600647722, 0.028814949693956544, 0.023548693529197147, 0.013648167019709945, 0.08230491355061531, 0.03930221391575677, 0.014547168243942516, 0.01169140518842531, 0.05895055245075907, 0.016369465638750365, 0.0833158085920981, 0.04125679171245013, 0.04654030980808394, 0.024924056870596747, 0.02816463155405862, 0.02159472132500793, 0.13059998277042592, 0.021766765575323786, 0.1790728960186243, 0.12106162602347986, 0.3432863636740616, 0.5229234344192913, 28.496516602379934, 102.82652296338762, 97.62642165592739, 89.68189307621547, 71.16189357212612, 39.00666230065482, 27.81890743119376, 35.08938952854702, 77.7875428880964, 56.82371950149536, 39.02294192995344, 38.298008578164236, 7.334866711071559, 0.1590066613363368, 0.046191644588751454, 0.09191100844847304, 0.03233828688306468, 0.021868516990382756, 0.029281683399208953, 0.09512742728527103, 0.08698331750929356, 0.41165443935564583, 0.24933906484927448, 2.4502655139991214, 52.61420897075108, 94.49742548806327, 83.95903015136719, 78.7275229862758, 72.04116031101772, 69.39111042022705, 66.16802869524274, 68.06905582972935, 70.60320281982422, 77.31799057551792, 80.58269895826066, 82.96408285413469, 82.92925153459821, 80.33999838147844, 72.58377987997872, 69.1322135925293, 66.01149272918701, 63.880799838474815, 62.97092628479004, 61.105355807713096, 56.40666082927159, 55.8985355922154, 57.4216502053397, 58.64653423854283, 59.53709180014474, 58.102490288870676, 62.083321707589285, 59.011794090270996, 60.63961110796247, 57.04115642820086, 57.16518872124808, 54.77376120431082, 57.37591368811471, 55.82819550377982, 59.823649406433105, 53.70213706152779, 57.33871303285871, 63.846475737435476, 78.94432762690953, 69.6972758429391, 89.84303569793701, 39.56525577817644, 46.680912903376985, 82.8291210447039, 62.84287793295724, 75.03505570547921, 71.37554373059953, 78.73427663530622, 71.38566030774797, 77.75708198547363, 68.90656389508928, 62.60823031834194, 57.65250757762364, 62.06451988220215, 57.84987810679844, 59.38706629616873, 59.31995364597866, 62.879529680524556, 58.514817237854004, 56.8826402255467, 58.51229504176548, 59.18147604806082, 57.3490172113691, 66.72649710518974, 70.32448972974504, 76.35692269461495, 75.66619532448905, 72.00379984719413, 66.0617629459926, 68.2580954687936, 75.65571049281529, 75.88163811819894, 67.25237151554653, 57.37503126689366, 68.71622494288853, 75.44383212498256, 66.17177377428327, 45.82935210636684, 26.574806417737687, 4.289118647575378, 0.37091109848448206, 0.09794366652412073, 0.2508274721247809, 0.07945366190480334, 0.05815048502492053, 0.2289227603801659, 0.05344372508781297, 0.08184518571943045, 0.0596320458820888, 0.11521762103906699, 1.249411717057228, 28.426560401916504, 31.276371002197266, 23.66213893890381, 118.28602164132255, 134.9723012106759, 95.73100866590227, 17.86423373222351, 25.66503187588283, 48.500663484845845, 76.00054264068604, 70.3592585154942, 84.55496324811662, 32.4213090624128, 0.34548815552677425, 0.16423143526273115, 0.05899961731795754, 0.08107006802622761, 0.05350233355004873, 0.05373260797932744, 0.04376039594145758, 0.09773281855242592, 0.06667994840868882, 0.041535605144287856, 0.030431569553911686, 0.024329502434868897, 0.070682850400252, 0.01059830647760204, 0.08469825583909239, 0.029378690158150027, 0.03239211506609406, 0.10583582946232387, 0.05580207193270326, 0.13376471080950328, 0.044493166264146566, 0.037998914386012723, 0.07680554328752415, 0.03801389304654939, 0.0783203523606062, 0.004337564368532705, 0.048675880035651584, 0.006251503006621663, 0.049143007291214805, 0.008712650875427892, 0.07537133060395718, 0.05472421905558024, 0.050784617595906766, 0.04875395906024745, 0.07213272367204938, 0.0671183770256383, 0.05867163384599345, 0.07165654815201249, 0.05252514812829239, 0.03746989455872348, 0.06328584839190755, 0.006690761556715837, 0.14805187630866254, 0.03019963271383728, 0.15900961974901812, 0.0595255633816123, 0.24167305763278688, 0.5513511747121811, 42.32041106905256, 122.16471454075405, 107.02329049791608, 102.27595465523856, 79.45916829790387, 58.13068955285208, 43.58816201346261, 30.961791310991558, 53.65692513329642, 72.01677908216203, 47.020217759268625, 47.934802191598074, 10.384060212544032, 0.16587423639638083, 0.01892529840448073, 0.04093472506584866, 0.050871344549315314, 0.10037560388445854, 0.03926176305062004, 0.02899226446502975, 0.1444525330194405, 0.6079682995166097, 0.7058804684451648, 3.75278502702713, 56.70608997344971, 95.34848948887416, 86.99068900517055, 80.98000390189034, 73.28840364728654, 72.00369562421525, 67.12402439117432, 70.21311010633195, 74.07528713771275, 79.26434775761196, 82.48590087890625, 84.81601401737758, 83.19547871180943, 83.3188578741891, 75.00269099644252, 72.08855397360665, 68.57672595977783, 67.9241303035191, 66.96413244519914, 63.46742371150425, 58.48085444314139, 58.291349274771555, 59.542330741882324, 61.127694266183035, 61.995579855782644, 60.190674100603374, 65.92659269060407, 63.07766451154436, 62.54047148568289, 58.358114515032085, 60.89356081826346, 56.92079625810896, 59.18991810934884, 58.009884698050364, 63.710721833365305, 57.7647522517613, 60.96851103646414, 65.86276653834751, 81.51726640973772, 73.41035148075649, 90.53691755022321, 41.77095447267805, 50.76983397347586, 86.0508200781686, 66.79102502550397, 77.1303266797747, 74.46659578595842, 81.4348121370588, 73.4744347163609, 82.46251324244908, 73.51779842376709, 64.79992839268276, 59.80012280600411, 64.70517580849784, 60.32259954724993, 62.54679434640067, 61.4491457257952, 64.4854598726545, 61.90667070661272, 59.20667021615164, 60.431637627737864, 61.248982020786826, 60.28047261919294, 69.73314939226422, 74.09601361410958, 79.54337351662772, 79.99684074946812, 74.0309784752982, 66.50210503169468, 70.96086134229387, 76.20059517451695, 80.55234922681535, 71.64716965811593, 60.7859262738909, 72.3206377029419, 78.57597582680839, 73.54362487792969, 54.36363336018154, 31.383446216583252, 6.705456759248461, 0.768585735133716, 0.25455344361918314, 0.46831433900765007, 0.17880853877535888, 0.061228937336376736, 0.06071025159742151, 0.06305642213140215, 0.09549691674432584, 0.018243212951347232, 0.1841373864029135, 0.9831017042909349, 32.30949170248849, 27.306830406188965, 25.33172505242484, 97.06618840353829, 120.46984045846122, 68.1923724583217, 19.994980471474783, 35.0930130141122, 54.75281585965838, 81.98672144753593, 78.8842465536935, 98.1646569115775, 45.20742579868862, 0.13276170034493717, 0.1399892789444753, 0.054125008173286915, 0.06474283949605056, 0.053538173769733736, 0.04332310387066432, 0.03475946607068181, 0.06560865017984595, 0.007496883211258266, 0.05050803993695548, 0.05822396358208997, 0.10910672787576914, 0.017486921212236797, 0.017417710640334656, 0.07410103841019527, 0.01821704355201551, 0.039492811009820016, 0.05198815551453403, 0.07327541057020426, 0.07015553369585957, 0.04191638542605298, 0.025023808303688253, 0.10069644916802645, 0.032773404249123166, 0.016927467393023626, 0.036813042126595974, 0.12951518169471196, 0.12175025764320578, 0.10041098270033087, 0.155672177406294, 0.20324627602738993, 0.21383135446480342, 0.1327784601598978, 0.14966624682503088, 0.10786576875086341, 0.12902765428381308, 0.11796472434486661, 0.18011553292827948, 0.14366653162453855, 0.14348925756556646, 0.20177821123174258, 0.12392245179840497, 0.17740216638360704, 0.19569883602006094, 0.3098660169967583, 0.17822053389889853, 0.4956393241882324, 0.7395726633923394, 53.47859614236014, 137.36050823756625, 121.6960585457938, 116.42623206547329, 93.19999531337193, 58.83303778512137, 41.105257987976074, 53.315021651131765, 111.66522911616734, 76.53491469791958, 58.54418727329799, 59.64650508335659, 15.511017833437238, 0.8635139784642628, 0.20643150939473084, 0.4808256019439016, 0.1582822980625289, 0.5702105941517013, 0.2584015242755413, 0.40417337364384104, 0.2902265265583992, 2.4935360721179416, 1.3063110581466129, 3.1055698820522855, 57.58819505146572, 100.3827303477696, 89.84543282645089, 84.33149528503418, 77.79172570364815, 75.40117018563407, 71.52838325500488, 75.83964320591518, 78.25070980616978, 84.57862881251744, 86.57146249498639, 86.82022190093994, 85.56040927342006, 86.93459619794572, 78.1730706351144, 76.2285269328526, 71.52684075491769, 70.6178287778582, 68.40979548863002, 68.69501904078892, 61.66810430799212, 62.31263310568673, 61.702935627528596, 64.20373821258545, 65.62555503845215, 64.28052970341274, 69.75652313232422, 65.51271629333496, 66.23564161573137, 63.49921866825649, 64.36557565416608, 60.67251082829067, 62.79698508126395, 63.33760356903076, 66.23758016313825, 60.646302223205566, 62.88505349840437, 72.20410251617432, 85.0807751246861, 78.38012000492641, 94.37268447875977, 47.02394199371338, 55.8295955657959, 89.9448059626988, 69.81242138998849, 81.10289669036865, 78.6892523084368, 82.55619580405099, 76.03932053702218, 87.12658882141113, 76.83290903908866, 68.30221652984619, 62.645820072719026, 67.20394951956612, 63.58249282836914, 65.19976942879813, 65.51228550502232, 68.15377521514893, 63.55558245522635, 62.5772830418178, 63.895620346069336, 65.35936260223389, 62.34261458260672, 73.97590705326625, 78.3135632106236, 84.05930655343192, 81.38666806902204, 73.82119846343994, 66.35255895342145, 72.95365333557129, 80.9668162209647, 83.68257522583008, 76.37345940726144, 64.94711208343506, 76.1216150011335, 83.91363062177385, 78.80704511914934, 61.16179602486746, 35.05755288260323, 6.815180540084839, 2.0526672261101857, 1.0085936678307397, 0.7916468062571117, 0.34906115808657234, 0.33791402195181164, 0.5193706250616482, 0.24502371783767427, 0.4129772569452013, 0.11727431496339184, 0.3874321776841368, 2.381218441895076, 49.746336528233115, 44.594966411590576, 28.01022434234619, 129.0094266619001, 144.44416890825545, 117.77172987801688, 26.48031439099993, 38.329223360334126, 67.47349793570382, 96.44340746743339, 88.31272969927106, 108.38003049577985, 50.12387037277222, 0.4558158868125507, 0.29489669310195105, 0.22018922758953913, 0.1531220663871084, 0.25347351442490307, 0.16114962420293263, 0.10441993043891021, 0.2342942607189928, 0.27764735583748135, 0.1118262012356094, 0.36626430068697247, 0.13129176279263838, 0.1749862153083086, 0.10907172225415707, 0.16455006173678807, 0.08032709932220833, 0.11372079314397913, 0.15338624721126898, 0.15529413840600423, 0.23928013603602136, 0.12051259619849068, 0.12105395857776914, 0.16566243847565992, 0.11938888792480741, 0.13860388685550007, 0.13597862129764898], [0.05708128346928528, 0.020627045571537952, 0.03595680217923863, 0.03212951522852693, 0.05341692973992654, 0.01298546900839678, 0.02774483890139631, 0.07971301834498133, 0.030677474037344967, 0.08649110820676599, 0.0204553032693054, 0.0158644303280328, 0.05030793656728097, 0.044240052346140146, 0.022567560729969825, 0.08476952237210103, 0.026955672140632356, 0.03127939905971289, 0.04412293380924633, 0.06467937611575637, 0.11905046179890633, 0.46636656352451866, 76.16479110717773, 105.84690489087785, 96.33423737117222, 77.82652228219169, 57.19766460146223, 37.536635398864746, 33.09524958474295, 55.02079745701381, 48.389794554029194, 36.74587481362479, 38.269048486437114, 9.068432705742971, 0.29259485804608887, 0.023882447941494838, 0.12440134824386664, 0.0767681220812457, 0.07318641391715833, 0.01492793156233217, 0.0978601456486753, 0.09267820085265807, 0.07013812248728105, 0.21888805526707852, 0.3560142421296665, 16.856322833469935, 78.8846356528146, 86.27274554116386, 85.42312676565987, 76.38053962162563, 69.03279876708984, 65.30750819614956, 63.80721146719796, 62.98881789616176, 65.05097375597272, 72.86234705788749, 79.81292193276542, 78.70057092394147, 77.21667889186314, 78.06527628217424, 74.73171125139508, 68.07991586412702, 69.23868778773716, 69.43512031010219, 70.7182788848877, 64.8730581828526, 61.177123750959126, 53.82090956824166, 55.43262413569859, 56.583968435014995, 57.35437427248274, 56.11411387579781, 57.45341736929757, 55.981233051845, 61.896331787109375, 61.000729833330425, 59.81501974378313, 57.36197560174124, 58.61656665802002, 55.683332511356895, 59.83311980111258, 57.813014439174104, 60.14608751024519, 54.178602831704275, 67.2713678904942, 61.41368906838553, 80.95545591626848, 57.54482092176165, 43.85689401626587, 80.99216324942452, 66.89450454711914, 72.44441986083984, 72.1459321975708, 76.2621909550258, 72.18304252624512, 76.72433648790631, 69.29606601170131, 68.67122840881348, 57.276293890816824, 57.39281170708792, 56.63650376456124, 61.42775222233364, 57.41409056527274, 61.29797376905169, 59.935091563633506, 57.52689456939697, 56.22220005307879, 54.45485625948225, 61.28424412863595, 72.54448086874825, 73.4725934437343, 75.83042989458356, 68.74358000074113, 68.4671528679984, 66.79868194035122, 67.21193994794572, 74.03830187661308, 75.62742437635148, 69.26652921949113, 58.986238615853445, 62.793184416634695, 72.83568681989397, 73.39514882223946, 72.91246441432408, 68.09750870295933, 35.509623527526855, 2.0241559445858, 0.869735601757254, 1.0524130250726427, 0.08615190176559345, 0.13819478452205658, 0.03564686434609549, 0.18807508796453476, 0.1259115772055728, 0.04487174130710108, 0.13612252500440392, 0.319610702672175, 2.155172262872968, 31.674415928976877, 74.06469808306012, 108.38918127332414, 95.37938117980957, 117.4581993647984, 61.11030292510986, 30.821496759142192, 47.62466239929199, 47.458881855010986, 73.3359432220459, 68.6651417868478, 79.66183335440499, 2.9262032210826874, 0.20858227541404112, 0.08359863555857114, 0.011083600660120803, 0.04089566519750016, 0.031922599367265186, 0.022165335348940322, 0.013967954636817532, 0.03418654842036111, 0.01527886648130204, 0.030203079671732018, 0.020014085873429264, 0.032175000823502026, 0.04899867271472301, 0.04229757622150438, 0.06666515634528228, 0.04202483567808356, 0.021903671889698932, 0.011084075634633856, 0.05493361156966005, 0.04625363554805517, 0.01589476253970393, 0.06778498339865889, 0.07312875879662377, 0.020812916669196317, 0.03130125127998846, 0.014866374865440386, 0.014264705990042006, 0.040325712745210955, 0.017708250853632177, 0.051369847264140844, 0.0464039785521371, 0.03364058896633131, 0.03171456731589777, 0.021712009495656406, 0.03291092633402773, 0.06538837057139192, 0.02486424909771553, 0.05153098576036947, 0.027573622463803207, 0.04247421245755894, 0.07092217648667948, 0.02462031745484897, 0.05202368700078555, 0.053153915995998044, 0.1803863633956228, 0.06035641594124692, 1.5907868104321616, 98.97254480634416, 114.17111083439418, 109.37768759046281, 84.42984703608921, 75.08620139530727, 51.775749002184185, 42.135943344661165, 38.210763522556846, 69.0965415409633, 45.84296015330723, 38.32279627663748, 14.159033008984157, 0.40261613577604294, 0.04799644595810345, 0.15389349284980977, 0.0909336262515613, 0.13644556195608207, 0.10246464357312236, 0.06763991261167185, 0.03147572638200862, 0.014452580462342926, 0.6240776436669486, 1.0156501063278742, 21.542745556150162, 82.73229094914028, 88.39851910727364, 88.13812841687883, 79.1178171975272, 72.68404933384487, 69.67846012115479, 66.51287473951066, 64.22487463269914, 68.48877566201347, 74.42533043452671, 82.82058865683419, 80.21557004111153, 78.17997019631522, 81.07770252227783, 77.35872091565813, 73.47525460379464, 73.22700936453683, 72.68652984074184, 73.30509322030204, 69.91359410967145, 63.612800870622905, 57.4830653326852, 59.20541954040527, 58.60033566611153, 59.03719670431954, 58.39557920183454, 59.69300937652588, 59.76544434683663, 65.05089732578823, 63.57356439317976, 63.17450850350516, 60.95419774736677, 61.257993834359304, 57.76714243207659, 62.72855922154018, 60.60241740090506, 63.707463128226145, 58.47159249441964, 68.34369727543422, 65.49226774488176, 85.33480126517159, 61.135198320661274, 47.559595993586946, 83.65325382777623, 69.51378086635044, 74.93905244554792, 74.4412487574986, 78.7714147567749, 73.83650534493583, 80.21096338544572, 73.86108112335205, 72.02659688677106, 58.98562717437744, 59.131004333496094, 61.10452897208077, 63.83515017373221, 60.07562582833426, 64.32112802777971, 61.52435997554234, 60.52137361254011, 57.88925354821341, 56.283959116254536, 65.96134063175747, 77.47097601209367, 77.52420616149902, 79.48987238747733, 68.76939950670514, 69.66017246246338, 68.79065404619489, 70.47514057159424, 75.45044681004116, 79.12666920253209, 72.12282943725586, 62.10704285757882, 66.912291935512, 76.03694425310407, 75.72578307560512, 79.29608712877545, 73.12386335645402, 44.67506871904646, 3.20720357128552, 0.6547571431313242, 1.3173953890800476, 0.10078548653317349, 0.38133980174149784, 0.15953047680003302, 0.3020720380757536, 0.04948731292305248, 0.19610576704144478, 0.1485177855938673, 0.2144672774842807, 2.0590028975691115, 29.72919477735247, 52.00892012459891, 113.8861791065761, 92.05282688140869, 99.11260659354073, 36.1396792275565, 32.32603188923427, 58.79644857134138, 54.52414716993059, 81.48779215131486, 77.63191713605607, 95.93937819344657, 5.6122749618121555, 0.3063861365829195, 0.07295600378087588, 0.08080290843333517, 0.05094820560355272, 0.03461091439904911, 0.00985832417583359, 0.01764452623735581, 0.06345271372369357, 0.019078947570441023, 0.04726212518289685, 0.038273673571114025, 0.022496112688843693, 0.07014338113367558, 0.06005188263952732, 0.031225184111722877, 0.011293664923869073, 0.07251600774803332, 0.02466955704481474, 0.059240789019635746, 0.035015338233539035, 0.03295259516952293, 0.04941590389768992, 0.01642950580987547, 0.048664864019623826, 0.04631593863346747, 0.20123655029705592, 0.11478126873927456, 0.18448430778724806, 0.12482683041266032, 0.11318194134426968, 0.09741563735795872, 0.11307131978017942, 0.16977157869509288, 0.13789936394563743, 0.22597580136997358, 0.17206878614212784, 0.11727746336587838, 0.17724176070519856, 0.09908237720706634, 0.09777487415288176, 0.27011056882994516, 0.10732400603592396, 0.14910047075578145, 0.1765029989182949, 0.34600617630141123, 0.3371873380882399, 2.6601634281022206, 114.11818640572685, 128.59289605276925, 121.9503070286342, 101.91885198865617, 78.19861221313477, 53.363857064928325, 50.71388013022286, 78.8820856639317, 65.75613253457206, 54.40325198854719, 61.59835134233747, 19.13789585658482, 0.7207446194120816, 0.16208328838859284, 0.3741292272295271, 0.22031601864312375, 0.311218934399741, 0.07249426748603582, 0.27466234458344324, 0.21379498498780386, 0.47122286579438616, 1.9747305853026254, 2.3212118446826935, 22.23227957316807, 88.57503114427838, 93.09197861807687, 93.68354824611119, 80.82018838609967, 76.11142199380058, 71.95102133069719, 70.42258439745221, 68.09702232905796, 72.96766090393066, 78.66947078704834, 88.79567119053432, 81.90217576708112, 79.84704453604562, 82.43926456996373, 81.9712825502668, 74.47784491947719, 75.74828134264264, 76.09093870435441, 78.52218287331718, 72.57852704184396, 68.40256936209542, 58.66441890171596, 60.8763153893607, 61.95282758985247, 62.9000894001552, 62.0058353969029, 63.65036283220564, 64.042831829616, 68.9397554397583, 67.3700601032802, 66.47576441083635, 64.84698854173932, 64.72928605760846, 61.6674998147147, 68.53020777021135, 65.30060863494873, 67.42715345110211, 61.35002967289516, 74.5682270867484, 68.95283889770508, 90.87696933746338, 67.74268504551479, 51.896487849099294, 86.85308688027519, 75.43860707964215, 77.67882442474365, 79.03823253086635, 80.50433717455182, 77.28629289354596, 83.26377255575997, 78.02705424172538, 75.27503258841378, 63.369203976222444, 61.66410214560372, 63.00340216500418, 66.78192288534981, 63.08459881373814, 65.66050447736467, 66.50822639465332, 63.21891444069998, 60.60890007019043, 58.747574942452566, 68.97872788565499, 81.65190165383476, 80.14153698512486, 82.90995638711112, 72.45156260899135, 70.92470291682652, 70.74721118382045, 71.53185040610177, 77.85519054957798, 83.72843333653041, 76.33814171382359, 66.2309237888881, 70.45420564923967, 79.85846042633057, 81.96528625488281, 84.84368174416679, 77.76837975638253, 46.813091959272114, 3.253068630184446, 1.8028065306799752, 2.945302733353206, 0.2597885855606624, 0.45267103984951973, 0.24924841257078306, 0.4410063443439347, 0.2469804228416511, 0.25633921208126204, 0.34819483171616283, 0.3812667370906898, 3.233776956796646, 59.19712339128767, 87.99544021061489, 110.06435721261161, 96.26298359462193, 127.35182271684918, 84.17538315909249, 43.38225909641811, 66.12144797188895, 65.49383803776333, 94.89108262743268, 86.9706642968314, 106.29084614345005, 5.619808111871992, 0.45139867812395096, 0.23542814701795578, 0.1859289766954524, 0.14703065396419593, 0.08275923345770154, 0.13242670760623046, 0.09508807903953961, 0.11318757997027465, 0.11260377522557974, 0.13577219737427576, 0.1502844329391207, 0.09580941604716436, 0.22990791180304118, 0.1144458960209574, 0.1851881928741932, 0.13672813107924803, 0.27556840596454485, 0.11460946367255279, 0.0843501470184752, 0.09802513822380986, 0.07753198966383934, 0.07141260802745819, 0.14110487193933555, 0.10222479501473052, 0.13708137640995638], [0.052785824319081645, 0.01978410660688366, 0.033649983283664496, 0.11702726036310196, 0.03502200484009726, 0.03907364260937486, 0.017194348786558424, 0.0455574043361204, 0.016320027577291642, 0.13458795020622866, 0.033262733170496564, 0.011391560563684573, 0.020205565063016753, 0.02100294888285654, 0.034738448448479176, 0.05876648625625031, 0.01969207011695419, 0.1092250711683716, 0.13237197697162628, 0.21327894553542137, 0.4795803001948765, 17.887209687914165, 102.72308513096401, 82.66408048357282, 83.13494600568498, 67.64224188668388, 41.571944168635774, 31.055331434522355, 50.912074020930696, 54.260049615587505, 34.073809555598665, 54.60424600328718, 23.249377727508545, 0.062450856768659184, 0.03888343906562243, 0.05960510804184845, 0.03445888523544584, 0.047214855040822706, 0.13461430450635298, 0.048438721868608675, 0.11095477906720978, 0.060431746899017265, 0.14307457767426968, 0.22273581022662775, 9.804481438228063, 51.757690634046284, 89.20589283534459, 89.39640549251011, 85.322190284729, 82.48549093518938, 75.15247331346784, 63.55251135144915, 60.97416687011719, 59.281036785670686, 59.72886902945382, 68.21380765097481, 80.40306718008858, 76.06577927725655, 79.51790142059326, 76.49279471806118, 77.04138278961182, 72.23010267530168, 71.73297296251569, 72.61417824881417, 77.01850931985038, 69.1227640424456, 62.02236516135079, 53.330498763493125, 54.96628189086914, 53.77632645198277, 57.75966269629342, 51.72611454554966, 56.978271756853374, 56.58135938644409, 60.7624066216605, 58.94769695826939, 57.17482239859444, 56.79811886378697, 57.9714229447501, 54.82380213056292, 57.10752214704241, 62.02465806688581, 64.46157196589878, 59.16786452702114, 58.39903940473284, 57.47031191417149, 73.60573482513428, 63.8964958190918, 43.23863983154297, 75.20510591779436, 66.84502642495292, 70.42543315887451, 68.38043240138462, 75.12892586844308, 70.65238911764962, 74.44204085213798, 72.38422066824776, 71.94775567735944, 68.09010192326137, 56.97737543923514, 54.73805788585118, 58.682609285627095, 59.587883131844656, 61.11287375858852, 59.80195018223354, 56.36397804532732, 55.28291130065918, 56.67835276467459, 67.08544104439872, 72.22868524278913, 72.25547054835728, 66.39647851671491, 68.68254702431815, 68.79253700801304, 66.19598129817417, 69.38717773982457, 69.84641197749546, 72.50849614824567, 71.14713559831891, 61.992091860089985, 53.931715965270996, 65.53817449297223, 70.41100175040108, 71.49550437927246, 68.93699700491769, 79.84361907414028, 39.37997511454991, 0.29307618364691734, 0.3925230902220522, 0.11928229007337775, 0.06608916832400219, 0.12575569057038852, 0.153664853689926, 0.0640404268300959, 0.022658128191583922, 0.0278945474752358, 0.058928852900862694, 0.10898060857185296, 3.127407201698848, 32.35633993148804, 59.49181733812605, 95.8579592023577, 74.38423183986119, 99.08193724496024, 30.395756312779017, 18.188775403159006, 35.15530708857945, 66.09706674303327, 67.16896533966064, 82.24311692374093, 38.060467038835796, 0.5401386278016227, 0.039004896833960495, 0.1311194963221039, 0.043880527173834186, 0.04660033640850868, 0.10150864201464824, 0.036778918600508144, 0.05202935276819127, 0.04631002859345504, 0.05822551742728267, 0.05206658059198942, 0.04381047521850892, 0.07069984091711895, 0.018254084778683524, 0.03431779405634318, 0.05605979649616139, 0.09047270419874362, 0.007441761570849589, 0.014899502641388347, 0.016519667846815925, 0.05543965280854276, 0.0658815298229456, 0.022463093478498713, 0.013741966004350355, 0.023608928779140115, 0.03925561552335109, 0.05231928738898464, 0.02583651344424912, 0.17875964354191506, 0.04399731322856886, 0.020805602061695287, 0.027217629066269313, 0.07034063126359667, 0.08462371876729385, 0.12239287101796695, 0.020423415516104017, 0.09688202384859324, 0.030353653377720287, 0.02646309812553227, 0.03581264062917658, 0.07056825262095247, 0.05106011977685349, 0.10619420451777321, 0.09005303707505975, 0.3536233832793576, 0.5875328332185745, 26.151292869022914, 121.78396715436662, 94.17721775599888, 95.45287227630615, 82.40721947806222, 60.20323644365583, 36.442311491285054, 45.97638293675014, 48.835549286433626, 37.56869438716343, 47.03638621738979, 29.110820736203873, 0.19729312189987727, 0.18266212913606847, 0.210223882326058, 0.05397058038839272, 0.2971601773585592, 0.2912046212170805, 0.3829284150685583, 0.1659360916486808, 0.03251600538247398, 0.10511359678847448, 0.8558930531144142, 13.578914880752563, 54.56955017362322, 89.3521454674857, 90.51541287558419, 86.88087967463902, 85.52947589329311, 77.22360624585832, 65.83946922847203, 64.36528382982526, 62.144549233572825, 63.08477946690151, 72.59659235818046, 81.97914791107178, 80.85390799386161, 77.95400782993862, 78.87517915453229, 79.61559309278215, 75.26877920968192, 76.15560558864048, 75.8674429484776, 80.57454177311489, 73.43651144845145, 65.36363574436733, 56.41939687728882, 57.96943228585379, 55.99349662235805, 60.80786868504116, 55.31333746228899, 58.23718459265572, 59.44628579275948, 62.54589802878243, 60.59014688219343, 59.638021332877024, 59.08270740509033, 62.12782491956438, 58.5897605078561, 60.92923981802804, 65.71900136130196, 67.3962687083653, 62.46320751735142, 62.46279757363455, 60.87718391418457, 76.83841896057129, 65.51228550502232, 44.86267008100237, 78.55529798780168, 69.05085713522774, 73.46067033495221, 71.37794085911342, 76.40452480316162, 72.072767666408, 77.16133649008614, 75.73284939357212, 76.12155941554478, 72.16196169172014, 59.199221747262136, 56.81324161802019, 60.44914013998849, 63.58769008091518, 64.00889682769775, 60.403691973005024, 58.20519856044224, 57.422657694135395, 59.30313900538853, 71.40618528638566, 72.7823177065168, 72.71109172276088, 68.77042089189801, 70.50493444715227, 73.40767642429897, 70.12648691449846, 70.29880918775285, 73.18472957611084, 75.54879856109619, 75.31201784951347, 66.56226253509521, 56.83918619155884, 69.0094667162214, 73.34428106035504, 75.89901556287492, 74.272768838065, 82.05148560660226, 48.31013693128313, 0.7637388780713081, 0.3729522403861795, 0.4402562917343208, 0.26037033434425083, 0.5499016610639436, 0.2701262565595763, 0.04061485008735742, 0.05121418454551271, 0.18885006995073386, 0.05304202896409801, 0.17704924674970762, 2.6177759425980702, 33.35994121006557, 61.416808809552876, 100.49610410417829, 69.59526239122663, 73.58599499293736, 22.28830984660557, 32.49552624566214, 44.242626735142295, 75.17631258283342, 76.10659299577985, 95.2955025264195, 51.600386892046245, 0.5272088444658688, 0.027286929544061422, 0.12915817728000029, 0.034917327242770364, 0.0879056773015431, 0.05234786049861993, 0.01187883352395147, 0.028543627288724695, 0.04024604934134653, 0.03645832437489714, 0.07961375545710325, 0.05924958283347743, 0.07520491989063365, 0.024217581476217935, 0.08425574244133063, 0.08024835533329419, 0.07351365778595209, 0.05721068009734154, 0.042042525086019716, 0.008292671625635453, 0.05261729318382485, 0.041839921314801486, 0.03351858497730323, 0.036090310729507885, 0.045054277405142784, 0.08632995613983699, 0.22892278752156667, 0.18524889461696148, 0.3660712981862681, 0.22639973647892475, 0.09475768676825932, 0.12262353221220629, 0.11188019226704325, 0.12030767862285886, 0.20328491181135178, 0.09265721376453127, 0.12684693772877964, 0.09467818282012429, 0.1064329267080341, 0.10967491952968494, 0.117816830852202, 0.11896265936749321, 0.30295720057828085, 0.24314642857228005, 0.4396216443606785, 0.7284905037709645, 33.03393520627703, 136.01318304879325, 105.73479570661272, 112.3035809653146, 89.131178855896, 59.42610822405134, 43.376241956438335, 72.37910679408482, 72.55645956311906, 49.54647159576416, 81.93679864065987, 35.70953014918736, 0.5067311461482729, 0.30744323985917227, 0.277939994420324, 0.12589735511158193, 0.47508253582886284, 0.30131883706365314, 0.5875541120767593, 0.30938705269779476, 0.26338995088424, 0.6220971356545175, 1.7325483007090432, 12.987958431243896, 56.76102590560913, 92.64169366019112, 94.7345883505685, 90.92893491472516, 90.14256559099469, 81.69688429151262, 69.2866164616176, 67.49038205827985, 66.02489580426897, 66.46600219181606, 76.42810004098075, 85.73605973379952, 83.70182173592704, 80.40742370060512, 83.76534911564418, 84.16228580474854, 77.9417234148298, 78.86001818520683, 78.3531470979963, 82.50795446123395, 77.46272850036621, 69.89928776877267, 58.448976108006065, 61.05373764038086, 58.200536319187705, 62.781838008335654, 57.928389276777, 62.812813077654155, 62.03480243682861, 67.06638213566372, 63.17183344704764, 62.753753389631, 63.67088086264474, 64.92861597878593, 61.40742874145508, 63.28608267647879, 69.24902670724052, 70.3524284362793, 66.48520006452287, 65.77255807604108, 65.10528087615967, 80.31094101497105, 70.96935898917062, 50.26155935014997, 82.62977027893066, 73.78123937334333, 75.88929503304618, 74.87433692387172, 82.04411356789726, 74.00825091770717, 78.86777932303292, 78.21729591914585, 79.48892743246896, 74.90770217350551, 62.93793623788016, 59.69787311553955, 62.894259861537385, 65.35076768057687, 66.02068519592285, 64.56223746708461, 61.14400863647461, 60.722072328839985, 61.656792640686035, 74.21194430759975, 78.95847415924072, 77.58319636753627, 70.08677795955113, 71.97030258178711, 76.27175167628697, 71.40327399117606, 71.8550111225673, 76.28549521309989, 80.13310187203544, 78.92726285117013, 69.41546385628837, 60.08195563725063, 73.03110490526471, 78.00899587358747, 79.95395646776471, 78.86494445800781, 87.6047499520438, 48.936402388981406, 0.7971609075154577, 1.4384589557136809, 0.74874368842159, 0.39519269125802176, 0.4254802146128246, 0.3911977213408266, 0.26098818119083134, 0.22762042097747326, 0.3659341526882989, 0.29656816912548883, 0.22518325889749186, 5.720922206129346, 51.496361936841694, 66.9280504499163, 103.91300582885742, 84.53441742488316, 115.55331598009381, 42.439444133213584, 31.011245114462717, 52.67858403069632, 85.3330989565168, 84.36588886805943, 104.40518147604806, 54.303121498652864, 0.7489596796887261, 0.10692169583801713, 0.2508858804191862, 0.09174008547727551, 0.21096580608614854, 0.22056778227644308, 0.08006903888391596, 0.22615428322127887, 0.24336114419358118, 0.12156159776662077, 0.1175792757421732, 0.1508527331586395, 0.13233203840042862, 0.11905403089310442, 0.14425357298127242, 0.29566579897488865, 0.18481635568397387, 0.1968652784292187, 0.12893164157867432, 0.1394240049911397, 0.14150955022445746, 0.11674467766923563, 0.09069180315626518, 0.14952854492834636, 0.1132865035906434], [0.02584796881170145, 0.012444304252442504, 0.04073945625818201, 0.004134172648524067, 0.0737197899392673, 0.030239306656377654, 0.0574659314006567, 0.027483584259503653, 0.04975765484518238, 0.03141617136342185, 0.019877501863187978, 0.07684107138110058, 0.029635871893593242, 0.07612563762813807, 0.06966687991682972, 0.024767079490369985, 0.04931134843666639, 0.010377841968355435, 0.06441330217889377, 0.08181349134870938, 0.20055504329502583, 57.744748388017925, 93.85648196084159, 87.69918291909354, 67.12689399719238, 46.71415308543614, 31.271913732801163, 52.70122126170567, 71.60640457698277, 50.504906109401155, 60.72847856794085, 35.622868742261616, 0.4545627140573093, 0.10682783408888749, 0.06811570815209832, 0.034309800913823504, 0.25826975277491976, 0.09496594952153307, 0.11938153260520526, 0.24578394847256796, 0.03703925213111298, 0.039941923160638125, 0.2925509704010827, 14.242955088615417, 56.50185809816633, 83.26275811876569, 87.34607546670097, 83.75223091670445, 87.48207950592041, 80.95080062321254, 80.44469383784703, 71.69416727338518, 60.47079767499651, 58.02268327985491, 57.41754729407174, 67.59024851662772, 79.25964382716587, 77.13027804238456, 76.78743307931083, 71.75275448390416, 78.72855826786586, 73.30241121564592, 75.53669479915074, 76.37670421600342, 76.97488158089774, 70.45911107744489, 62.024908202035085, 53.375151361737935, 54.370849064418245, 53.04737704140799, 53.462292194366455, 53.501900400434224, 54.703240462711875, 51.20243229184832, 57.67453684125628, 54.84826673780169, 56.23148284639631, 55.171198163713726, 57.3205817086356, 53.50220612117222, 67.82727241516113, 70.17010075705392, 73.98318181719098, 66.51867648533413, 72.5671250479562, 65.48288072858537, 77.39610917227608, 61.59767041887556, 33.43958841051374, 75.75314508165631, 65.18562289646694, 66.84858390263149, 66.59803186144147, 71.49852684565953, 70.92914976392473, 69.20562131064278, 69.51483004433769, 72.1942777633667, 71.57886191776821, 65.2341421672276, 51.55770410810198, 54.56113937922886, 58.45050471169608, 56.78820725849697, 55.86605971200125, 53.76607438496181, 53.242767333984375, 55.19525282723563, 66.40364905766079, 70.6183498927525, 68.64828545706612, 68.91157354627336, 71.91946956089565, 68.03865051269531, 71.31515693664551, 70.05591406141008, 71.28642613547188, 71.80685315813336, 69.90545776912144, 65.3722654070173, 56.10660982131958, 54.17291225705828, 67.28641074044364, 69.03812108721051, 74.54959896632603, 67.28938456944057, 85.64794962746757, 23.075212444577897, 0.4819478988647461, 0.3589613639882633, 0.3249823387180056, 0.18985352824841226, 0.2557564319244453, 0.1562876222389085, 0.05609331951875772, 0.043740104351724894, 0.16575204581022263, 0.15782525044466766, 0.08179182572556393, 5.813329773289817, 22.810711894716533, 30.99118219103132, 65.17570086887905, 73.62484237125942, 76.57867445264543, 21.290452991213115, 36.57935081209455, 58.0513584954398, 73.98978955405099, 72.4674322945731, 83.33417170388358, 4.299319905894143, 0.1363366028027875, 0.09711035766771861, 0.054104278928467205, 0.056938275428754945, 0.06725191271730832, 0.04396773249443088, 0.03471928322687745, 0.00481456854946113, 0.06341365046266999, 0.06320713154439415, 0.05738825949707201, 0.027889743447303772, 0.014223759794341666, 0.07722145811255489, 0.03212301486304828, 0.04065553165440049, 0.030780662250305926, 0.09292330805744443, 0.047733581491879055, 0.06307148560881615, 0.054533225018531084, 0.030874588460262333, 0.05203663684161646, 0.011563498792903764, 0.022331503485994678, 0.005384510399640671, 0.013097842041003917, 0.025419300920995216, 0.05159922602719494, 0.017797130459387387, 0.039429446017103534, 0.023845997040293047, 0.040658965041594844, 0.07189759771738734, 0.01779944426380098, 0.06439359073660203, 0.03668735369241663, 0.019811239525941864, 0.037807689647057226, 0.016799359981502806, 0.04395291668229869, 0.017758143533553396, 0.012923606122577829, 0.030978319501238208, 0.07400777377188206, 79.22871739523751, 107.37561280386788, 103.15677084241594, 77.42486776624406, 67.14559854779924, 47.021461486816406, 46.69705704280308, 57.067180906023296, 45.92569235392979, 48.02504539489746, 40.53264651979719, 0.5853694464479173, 0.09954649515982185, 0.04136891283893159, 0.5243407040834427, 0.5704633891582489, 0.43691217260701315, 1.0261746730123247, 2.5084849042551856, 0.2601298343922411, 0.12746443173715047, 0.6838469707540104, 16.943050248282297, 60.0063453401838, 85.7044037410191, 86.97929395948137, 82.40511417388916, 90.77382332938058, 85.05344091142926, 83.64864022391183, 75.12679277147565, 65.28804629189628, 60.09236403873989, 60.4840270451137, 70.08421407427106, 81.38067872183663, 81.48388031550816, 77.76090349469865, 74.28158610207694, 80.73529529571533, 77.25837503160749, 78.33469268253872, 77.07795810699463, 80.16691875457764, 73.89512729644775, 63.97920022691999, 56.902004855019705, 56.51587956292288, 56.76418038776943, 57.35843202045986, 56.294478688921245, 57.0275171143668, 54.848075662340435, 58.67339597429548, 57.97032512937273, 60.488404410226, 58.83428151266915, 60.364615304129465, 57.258485657828196, 71.36519091469901, 75.56122194017682, 77.26953383854458, 70.19920676095145, 75.6955931527274, 68.70681708199638, 81.99776213509696, 64.3943064553397, 35.42725610733032, 79.76274899074009, 67.17931815556118, 69.26791191101074, 70.05978420802525, 74.34671156747001, 73.07872091020856, 71.00823416028703, 71.32434245518276, 76.3055477142334, 73.49521677834647, 68.13709953853062, 54.60118532180786, 56.66395957129342, 58.557777949741904, 59.796627862112864, 58.95226887294224, 57.16473708833967, 55.12066738946097, 58.37052399771554, 71.67622007642473, 73.62728813716343, 72.86475808279855, 71.86982468196324, 74.23996639251709, 73.29164150782994, 75.07918371473039, 74.07081944601876, 74.52366828918457, 73.70330837794712, 72.50520965031215, 69.55402483258928, 58.6264956338065, 57.70418133054461, 71.36559391021729, 72.24162973676408, 77.65941115788051, 70.08107348850795, 89.94160979134696, 28.56762794085911, 0.38190955402595655, 0.16467065098030226, 0.785198877964701, 0.5684081337281636, 0.946896487048694, 0.5367473640612194, 0.3329403059823172, 0.15152337002967084, 0.5404442942568234, 0.2937055384474141, 0.30522345325776506, 7.126709972109113, 24.729837349482946, 34.291329860687256, 73.4372479575021, 75.53323459625244, 62.74544334411621, 20.46409157344273, 45.95386382511684, 60.007783617292134, 83.21615655081612, 78.57057707650321, 99.6503346306937, 7.908648082188197, 0.30560419282742907, 0.05678744048678449, 0.04310922963278634, 0.01709671099005001, 0.056064797299248834, 0.03098416847309896, 0.054917238519660065, 0.01465176441706717, 0.016667396794738512, 0.049408959091774056, 0.0342412247721638, 0.028645658599478856, 0.031076154072902033, 0.04608628506373082, 0.04671771278870957, 0.03752000776252576, 0.09780189341732434, 0.08968741526561123, 0.008494178714629794, 0.01769460890708225, 0.011963010033858674, 0.03778517924781356, 0.05852127727121115, 0.04598863369652203, 0.18106739542313985, 0.05721938570163079, 0.09032018988260201, 0.11604489093380314, 0.08744361530989408, 0.13013051796172345, 0.1405595333448478, 0.09552867218319859, 0.16922052683574812, 0.17154513352683612, 0.08514800920550313, 0.2006913609802723, 0.1276121623814106, 0.1293997357466391, 0.17209530329065664, 0.07801163249782153, 0.17703008492078098, 0.07092092119689498, 0.20731436487819466, 0.07429341665868248, 0.3783990038292748, 93.5312784739903, 120.96717861720494, 113.16689464024135, 92.20583316258022, 69.04801532200405, 48.54908548082624, 69.55819375174386, 91.39404732840401, 67.28130381447929, 88.92556081499372, 58.04792261123657, 0.7019768293414796, 0.17934859836740152, 0.1447806182716574, 0.5055001207760402, 0.8578153156808445, 0.9466653508799416, 0.749241190297263, 1.5705454051494598, 0.19062169774302415, 0.20105330512991973, 0.6273617531572069, 17.599291971751622, 65.6646317073277, 91.80795151846749, 88.50989873068673, 86.69255570002964, 94.86448492322648, 86.48411669049943, 87.47036484309605, 80.16769000462124, 67.47565882546562, 63.430424554007395, 63.96636690412249, 75.68482344491142, 87.23148577553886, 83.5263797215053, 79.80277061462402, 76.8545457295009, 86.4504040309361, 79.56979751586914, 82.45693383898053, 78.80437006269182, 83.18010234832764, 77.11346340179443, 68.78874329158238, 61.22859600612095, 60.98281042916434, 61.07995319366455, 60.42162527356829, 60.30676460266113, 60.42070811135428, 57.763553687504356, 63.658693722316194, 60.946631159101216, 64.2422103881836, 62.744950022016255, 62.46914822714669, 58.87376117706299, 74.74727521623883, 77.93818678174699, 79.87034879411969, 73.28793811798096, 79.25426592145647, 71.87095029013497, 85.95590768541608, 68.77841132027763, 40.05773367200579, 82.19217273167202, 73.12771265847343, 71.46983773367745, 75.22496386936733, 77.14577252524239, 76.39921637943813, 73.88634477342877, 72.47169848850795, 77.49474579947335, 78.87370613643101, 70.51967157636369, 56.521326950618196, 59.78624030521938, 62.04819161551339, 61.50710759844099, 61.241547448294504, 58.72460419791085, 57.7933406148638, 59.66898250579834, 74.76272106170654, 76.66408865792411, 76.67982632773263, 75.45131533486503, 79.96515696389335, 77.43274007524762, 79.89713409968785, 77.2230087007795, 76.11842577798026, 78.11452511378697, 76.54790088108608, 74.17629310062954, 63.84487765175955, 60.0216383252825, 75.98654896872384, 76.70686176845005, 81.26091957092285, 75.65759345463344, 94.91962582724435, 29.282460348946707, 0.809716628066131, 0.9291765178952898, 1.025304845401219, 0.8258213038955415, 0.7712658398917743, 0.687863246670791, 0.6168941291315215, 0.39147782059652464, 0.5369715520313808, 0.5149190010769027, 0.33867851378662245, 11.77574530669621, 37.74719360896519, 39.62557309014456, 74.55668612888881, 80.8015672138759, 89.47694901057652, 29.94861888885498, 51.290729999542236, 74.54638195037842, 94.93473815917969, 88.37930038997105, 105.6225892475673, 7.452663864408221, 0.48692856303283144, 0.22945269622973033, 0.1726519734199558, 0.1482905713575227, 0.15294453448482923, 0.1118336244087134, 0.15191073210111686, 0.06914329515503985, 0.1427392999508551, 0.1416684359844242, 0.12845092665936264, 0.06672330679638044, 0.12259970206235137, 0.13708580045827798, 0.1652931525771107, 0.1260272945676531, 0.17230151008282388, 0.26211292083774296, 0.09770127345940896, 0.13201555609703064, 0.1633281015924045, 0.15971856670720236, 0.12419363510395799, 0.18056230752595834], [0.08815746129091297, 0.014741353091916867, 0.013618122337252965, 0.1311418336949178, 0.01254833724150168, 0.03657194845644491, 0.01243740864031549, 0.07795186713337898, 0.03724387454401169, 0.019610734124268805, 0.007057168346364051, 0.035342792448188574, 0.08695706498942204, 0.0453868647372084, 0.010624123886892838, 0.09130661016596214, 0.11513025287006583, 0.047904246619769504, 0.23517396779997007, 0.5773930230310985, 7.5428792749132425, 91.76870114462716, 88.01112229483468, 89.60582419804165, 74.55718639918736, 36.922668252672466, 32.382173333849224, 57.79373666218349, 61.90872042519705, 54.92416885920933, 42.21818569728306, 5.69772390808378, 0.0152151791844517, 0.15640612159456524, 0.11171076885823693, 0.14969478600791522, 0.28670199854033335, 0.10993021833045141, 1.8939955575125558, 1.2408910542726517, 0.25833149946161676, 1.2804850382464272, 21.770500557763235, 69.66627298082624, 78.6675113950457, 82.3568172454834, 83.76277133396694, 85.5750630242484, 81.60673836299351, 86.10125010354179, 80.03647327423096, 78.58757931845528, 62.80813694000244, 57.65830932344709, 54.23155505316598, 62.171431813921245, 74.02234881264823, 78.84986686706543, 77.5119981765747, 74.5051165989467, 74.49189417702812, 72.99537726811, 77.21013368879045, 72.19732802254813, 73.66954708099365, 71.20258917127336, 61.83231108529227, 53.317679337092805, 53.580793721335276, 54.74737194606236, 52.61846821648734, 53.42068638120379, 53.071674891880576, 53.65131098883492, 52.67190681185041, 55.179310185568674, 55.08501965659005, 54.42305435453142, 53.345506872449604, 58.41569423675537, 70.52336801801408, 71.23903942108154, 72.73625809805733, 72.08304405212402, 74.44827338627407, 68.6918784550258, 78.0770743233817, 59.53245040348598, 27.081913743700298, 75.16809981209892, 62.470190456935335, 66.66494301387242, 60.297857012067524, 69.55475439344133, 68.98860822405133, 70.14210646493095, 64.75898960658482, 69.33478137425014, 70.46516990661621, 69.8297085080828, 59.888253756931846, 51.75645732879639, 56.21243783405849, 55.970928873334614, 54.43508863449097, 52.016042028154644, 52.05068574632917, 54.54581165313721, 62.755907331194194, 66.01845482417515, 67.11003766741071, 66.47952338627407, 64.5824636731829, 62.89192526681082, 64.13909217289516, 71.53846509116036, 72.19562571389335, 68.60524136679513, 70.83253506251744, 64.74948447091239, 54.224850041525706, 55.650516169411794, 58.12583276203701, 57.713630880628315, 64.32804148537772, 68.29772799355644, 72.24586118970598, 75.33124351501465, 6.564880805356162, 0.721807313816888, 0.4619216706071581, 1.5220647837434496, 0.47993568969624384, 0.3838523897741522, 0.09620206390640565, 0.48380181938409805, 0.13580594770610332, 0.14411906019917556, 0.05458755871014936, 0.12042112967797688, 19.610107592173986, 37.60937261581421, 59.46493475777762, 68.38968740190778, 76.85753345489502, 65.18501145499093, 38.94143956048148, 60.951508794512065, 55.23518759863717, 69.19396223340715, 89.38474641527448, 42.78248711994716, 0.821854371045317, 0.13041417274091924, 0.2213391273149422, 0.051658859077308855, 0.12279228387134415, 0.04050162973414574, 0.10470593973462071, 0.004066113889816084, 0.043736555613577366, 0.025145744439214468, 0.08105705372456994, 0.04043637162872723, 0.04070861005623426, 0.03094146487170032, 0.05927484469222171, 0.03192004468291998, 0.0533687571462776, 0.05307695994685803, 0.01963581786757069, 0.019914476932691674, 0.05661488224619201, 0.04227955433140908, 0.013941376420137073, 0.013661494295644974, 0.031157812369721274, 0.03230874686102782, 0.018300382919343453, 0.04413737303444317, 0.029916459694504738, 0.03655263056446399, 0.02801100444048643, 0.0550269135273993, 0.07848404214850493, 0.05624302809259721, 0.03092480344431741, 0.020481038406225185, 0.09026267046907119, 0.024699195454429303, 0.025151091295161417, 0.12178199951137815, 0.20634908096066543, 0.08429500926285982, 0.29994768063936916, 0.7884125826614243, 12.760597739900861, 111.14848463875907, 96.43588951655796, 99.74620587485177, 81.79677159445626, 42.35646874564034, 35.22233288628714, 40.865051814488, 44.40899092810494, 59.335163252694265, 45.91995661599295, 7.536928142820086, 0.14304264581629209, 0.15624336818499224, 0.24529266197766575, 0.6037161648273468, 0.5659455401556832, 0.8811352614845548, 2.394728345530374, 3.358202040195465, 0.46606751957109993, 1.7683556250163486, 26.61251950263977, 75.08404050554547, 84.84941400800432, 87.46284689222063, 87.679929460798, 87.45894200461251, 82.61117689950126, 88.51686082567487, 84.20105675288609, 82.96252645765031, 65.46830340794155, 61.79414463043213, 57.961459227970664, 63.52161271231515, 76.27342619214738, 80.2978297642299, 80.24915763310024, 77.61817359924316, 77.3858744757516, 76.43347099849156, 80.54076657976422, 74.82363591875348, 76.16474941798619, 73.3766040802002, 64.69796357836042, 56.724276883261545, 54.819855553763254, 57.60132714680263, 55.79973915645054, 58.6004398890904, 57.37121670586722, 56.78508751732962, 56.16254281997681, 57.16637338910784, 57.81125654493059, 56.2740683555603, 57.37519802365984, 62.53956821986607, 75.20510591779436, 73.58464704241071, 75.52888502393449, 74.80251339503697, 75.92984472002301, 70.77137701851981, 79.4195635659354, 62.64364528656006, 29.849572317940847, 78.12331458500454, 68.01672199794224, 69.5261069706508, 62.4030430657523, 72.9097546168736, 72.82488931928361, 70.65054089682442, 65.9218818119594, 71.62553991590227, 72.9818421772548, 73.93292549678257, 63.842716761997764, 52.61793320519583, 57.526759079524446, 58.92477485111782, 56.30647127968924, 55.043452058519634, 54.88551255634853, 57.68714782169887, 65.92293793814522, 67.74823665618896, 70.173581804548, 70.86116858891079, 68.16300242287772, 68.15449782780239, 69.11947059631348, 73.56694303240094, 75.03486810411725, 72.16069711957658, 74.48616886138916, 69.20016697474888, 56.82152039664132, 58.04221814019339, 60.345903805324006, 61.12143393925258, 68.31749561854771, 72.26307882581438, 74.64255891527448, 82.11206000191825, 10.673490030424935, 0.6952186205557415, 0.20186813069241388, 2.6804473911012923, 0.7869208369936261, 1.1500282670770372, 0.2210905256548098, 1.0082545088870185, 0.4679286597030503, 0.4128637787486826, 0.17626095190644264, 0.22136126112725052, 20.122829062598093, 32.81377805982317, 62.5499210357666, 77.04468318394252, 72.46638311658586, 53.72600759778704, 52.526970863342285, 68.46789632524762, 62.296200616019114, 77.17160592760358, 98.86031750270298, 56.88613516943795, 0.7993357479572296, 0.12375573574432305, 0.1824110033256667, 0.10547777331833329, 0.10702199009912354, 0.06456092425755092, 0.06182859265910728, 0.060523281273032935, 0.0754289992951921, 0.03615751962310501, 0.15450774346079144, 0.018485531377206956, 0.06967468985489436, 0.0651656821636217, 0.04257643036544323, 0.08618861729545252, 0.03260847274214029, 0.05519267623978002, 0.03757461965350168, 0.02448228307600532, 0.029255546230290617, 0.03810552580814276, 0.02216821742643203, 0.045396720458354266, 0.18806313217750617, 0.10962419903704099, 0.1620719704244818, 0.25104397907853127, 0.07598824785756213, 0.08506022713014058, 0.16820333498929227, 0.2049856326941933, 0.165499142238072, 0.11601635175091879, 0.17871606802301748, 0.10088322950260979, 0.1979317862008299, 0.19310748364244187, 0.20547362150890486, 0.27875578350254465, 0.27695758427892414, 0.2585449122956821, 0.6697521156498364, 1.0276660387005125, 15.760253190994263, 128.56201825823103, 111.31380312783378, 114.44723919459751, 95.38691997528076, 54.66830492019653, 47.280525071280344, 79.22078255244664, 84.0152063369751, 79.3198013305664, 65.65139538901192, 10.15139717715127, 0.28088244795799255, 0.2893026332770075, 0.2908144364399569, 1.1068331620522907, 1.2204978742769785, 1.5384510244641985, 5.421642013958522, 7.280406296253204, 1.9147276793207442, 2.600771746465138, 25.29376530647278, 83.19249793461391, 89.08352810995919, 91.9060183933803, 91.05633708408901, 90.59228774479458, 83.2650579724993, 92.6926656450544, 88.04493222917829, 85.82320404052734, 69.47274480547223, 65.00386496952602, 60.95811653137207, 67.19794627598354, 80.49888283865792, 85.46752575465611, 81.27710887363979, 82.004640851702, 81.26976462772915, 79.04066440037319, 83.80178546905518, 77.1039652143206, 79.26354871477399, 79.64925016675676, 70.36731842585972, 60.139952250889365, 59.82759598323277, 61.11328370230538, 59.55861037118094, 61.24680028642927, 60.33202130453927, 60.044039317539756, 57.69379029955183, 60.85127408163888, 58.610535621643066, 59.840609959193635, 60.53764629364014, 65.22772897992814, 77.27792031424386, 76.8081942967006, 77.87432588849748, 77.93600504738944, 78.47931248801095, 74.28042575291225, 81.63201590946743, 67.37332575661796, 34.803353037152974, 79.92073018210274, 71.05513450077602, 72.84615080697196, 66.73149980817522, 76.1366856438773, 74.74122333526611, 75.27828434535435, 67.1219538279942, 74.02156366620744, 76.26873615809849, 77.59166622161865, 67.0062871660505, 56.82741246904646, 60.36908994402204, 62.34421961648123, 60.22108636583601, 57.0491920198713, 58.22938871383667, 60.683919770377024, 70.90664454868862, 71.90220328739711, 73.87437302725655, 77.0699815750122, 71.63218934195382, 72.89345414297921, 72.96233163561139, 78.81256893702916, 79.11583001273019, 75.12892586844308, 77.8482562473842, 73.27296475001744, 60.66317244938442, 62.497246742248535, 64.33342633928571, 63.42481735774449, 72.61567211151123, 75.3779354095459, 77.74501991271973, 82.58878980364118, 11.336298670087542, 1.1475361436605453, 2.337862116949899, 5.788008366312299, 2.2298834196158817, 0.8961635636431831, 0.6410943791270256, 1.5186255340065276, 1.1787833869457245, 0.5017648126397813, 0.40275146280016216, 0.45386409440210884, 29.818329742976598, 54.39974662235805, 70.59275272914341, 76.69156878335136, 86.3699369430542, 78.64462402888707, 55.10555853162493, 78.62579441070557, 74.20663588387626, 86.80863230569022, 108.95926012311662, 61.189957073756624, 0.8690962589212826, 0.22922641837171145, 0.2903592480080468, 0.19436512115810597, 0.24541224698935235, 0.2314329328281539, 0.2964762954839638, 0.060572427564433644, 0.21109079223658356, 0.13470391184091568, 0.21791623027196952, 0.19868181166904314, 0.15967166636671337, 0.1540174883391176, 0.14054695330560207, 0.18055244162678719, 0.14946693394865307, 0.16637158899434976, 0.10049841872283391, 0.10534727746354682, 0.1489835184599672, 0.08897833260042326, 0.12393816666943686, 0.13282042076545103], [0.031721885316073895, 0.0112145307773192, 0.09438354934432677, 0.007348196680790612, 0.014877146608861429, 0.010259611482199813, 0.03025612753948995, 0.03898794024384447, 0.027798417722806334, 0.03382713520633323, 0.007936890270294887, 0.05024594221530216, 0.07550743794334785, 0.026140807562374642, 0.01687284362768488, 0.056308801884629896, 0.0678106320223638, 0.07110217825642653, 0.14759216883352824, 0.2413387841411999, 26.961416346686228, 94.52106325966972, 79.19823564801897, 76.77995681762695, 62.43005766187395, 44.66042191641671, 82.44968686785016, 147.2665410723005, 95.59430285862514, 47.37810557229178, 18.408706733158656, 0.11553265127752509, 0.04701111472344824, 0.07019148926649775, 0.061182505185050626, 0.6931710732834679, 0.22393776715866157, 0.2718025637524468, 2.675783629928316, 3.9966872079031805, 1.4450943768024445, 26.387477772576467, 78.66209180014474, 82.34478991372245, 77.6997662952968, 80.32779734475272, 80.0257522038051, 81.04911763327462, 79.80575139181954, 82.1815002986363, 84.5397675377982, 81.65568842206682, 70.31024592263358, 58.06777361461094, 56.02162293025425, 54.354600702013286, 66.28310476030622, 70.8079662322998, 74.19991697583879, 72.70076669965471, 69.15209238869804, 72.45086778913225, 72.4689747946603, 74.37550490243095, 72.42389488220215, 68.3383263179234, 65.98135839189801, 61.04419081551688, 57.41098819460188, 57.720954281943186, 56.62828057152884, 55.96443578175136, 51.66561310631888, 52.7889735358102, 52.58660725184849, 54.38592318126133, 56.444219316755024, 55.9581024987357, 53.40262106486729, 58.07035139628819, 64.51760223933628, 70.77678966522217, 70.79470212118966, 70.76205253601074, 75.33028466360909, 71.62979221343994, 66.99050780705043, 53.07957846777779, 24.960536650248937, 73.94394533974784, 69.24262046813965, 68.97735909053257, 59.68173939841134, 64.32424082074846, 68.02137729099819, 67.03223173958915, 64.80937099456787, 63.129734311785015, 67.28910664149693, 72.18930285317558, 66.9157382420131, 56.51485122953142, 51.88920266287667, 55.97936051232474, 53.17543581553868, 52.418530327933176, 49.36329276221139, 52.906491892678396, 55.186494622911724, 60.03267901284354, 61.05651691981724, 64.65364796774728, 64.36009352547782, 63.89494637080601, 63.72602871486119, 64.15332208360944, 67.91363852364677, 68.95359625135148, 67.53737272535051, 66.32506493159703, 54.741615363529746, 54.39032139096941, 55.08804212297712, 56.425017969948904, 62.80872753688267, 68.9643520627703, 70.12584768022809, 77.88087109157017, 55.373974391392295, 2.175198708261762, 0.6665513845426696, 1.0326105505228043, 1.2158413869994027, 1.0547319863523756, 0.3440065064600536, 0.24088804689901216, 0.14970562899751322, 0.05237048964149185, 0.1174541674554348, 0.014098198585478323, 0.7913650242345673, 22.769842590604508, 36.58512823922293, 77.36085401262555, 60.074507168361116, 39.746134757995605, 17.61494278907776, 30.868980748312815, 55.81595625196184, 67.0232685634068, 80.12980842590332, 61.41578047616141, 2.4886401976857866, 0.1084803111319031, 0.05413034824388368, 0.10065482104463236, 0.0955849430922951, 0.02824071059668703, 0.0650120550500495, 0.04254389800397413, 0.0366542377908315, 0.08347795132015433, 0.017562104588640586, 0.07256386482289859, 0.018963686523160765, 0.055504171310790947, 0.10799481254070997, 0.015809787902981043, 0.026903195938627635, 0.05365719220467976, 0.025091548150937473, 0.05486376656751547, 0.031885276548564434, 0.017441662926492945, 0.04416418195302997, 0.012720892089419067, 0.04847518973318594, 0.03280577715486288, 0.08622827766729252, 0.016154817870951126, 0.03674405547124999, 0.016063237695821693, 0.027329069961394583, 0.07852429284581117, 0.05864567988153015, 0.014289224852940865, 0.012852197945384043, 0.013310536476118224, 0.05155167429308806, 0.032767938649547954, 0.06364058649965695, 0.05299407010897994, 0.054027818209890804, 0.06761100023452725, 0.17135099108730042, 0.2894517481327057, 39.06809827259609, 109.28284467969621, 88.87718050820487, 90.546144757952, 74.60798467908586, 55.46411337171282, 62.588407107761924, 112.478196144104, 72.33351966312954, 53.05754920414516, 22.624906642096384, 0.06306700727769307, 0.06963537553591387, 0.2675034744398934, 0.673588498362473, 0.8947353288531303, 1.0366842576435633, 2.5587140832628523, 3.5868607418877736, 1.1551370386566435, 2.008426091500691, 30.906768526349747, 84.30441120692662, 86.84220600128174, 83.36102649143764, 85.7095593043736, 85.12757124219621, 84.13673033033098, 84.79487064906529, 83.3273068836757, 87.45194516863141, 85.21388176509312, 73.96585995810372, 60.44162218911307, 58.94497326442173, 56.90880366734096, 69.97290393284389, 74.07642664228166, 77.15611144474575, 74.85800170898438, 72.846116065979, 75.0887930733817, 76.47828687940324, 77.26730346679688, 76.38474328177315, 73.62204224722726, 68.62722546713692, 63.62928894587925, 60.59256485530308, 60.91707352229527, 59.44269357408796, 58.663460050310405, 54.880558490753174, 54.76561791556222, 53.623462608882356, 57.926791191101074, 58.567845889500205, 58.368036542619976, 56.78449692044939, 58.485593114580425, 67.262606212071, 74.06950623648507, 73.05841827392578, 71.59264019557408, 77.1223223549979, 74.86303220476422, 70.52730764661516, 57.80370732716152, 27.623732532773698, 72.24364471435547, 74.44397939954484, 71.4781060900007, 63.03060436248779, 66.69305542537144, 70.1910982131958, 69.95784718649728, 67.61102363041469, 63.78083610534668, 71.3940120424543, 74.25147260938371, 70.09807573046002, 59.494937079293386, 56.417875221797395, 57.920489174979075, 56.09770917892456, 54.345561095646445, 51.65325573512486, 56.37136050633022, 57.34221492494856, 63.131707600184846, 63.97471169063023, 66.97778565543038, 66.00910949707031, 65.82696941920689, 67.48947184426444, 70.1183853149414, 72.4639720916748, 70.52277742113385, 70.31702736445835, 68.80647509438651, 58.85490376608712, 58.41650717599051, 57.58463409968785, 58.6529335294451, 66.82065909249442, 74.38702501569475, 74.2039886202131, 79.01264926365444, 62.10436085292271, 4.458611701216016, 0.22231576990868362, 0.7387371967945779, 3.05091079218047, 3.3770205846854617, 1.1868176758289337, 0.2998884581029415, 0.2834051325917244, 0.27005061347569737, 0.09500389998512608, 0.03793195994304759, 0.6298271694353649, 25.701949392046245, 34.86480637959072, 79.71943392072404, 65.7540202822004, 35.59420394897461, 24.317871706826345, 40.5228009223938, 60.26984882354736, 75.11588409968785, 83.41661902836391, 79.87414945874895, 4.33721798658371, 0.14072795930717671, 0.05935576677854572, 0.09540931108806815, 0.040001786912658384, 0.03189883367823703, 0.07356222732258694, 0.06540417365197625, 0.005745239123435957, 0.05917315264897687, 0.032536225726029704, 0.03682078421115875, 0.04642374427723033, 0.016209596003006612, 0.03254874808979886, 0.017902944602870514, 0.00968320361737694, 0.06597328132816724, 0.05043626789535795, 0.029195278749934266, 0.01756904600188136, 0.11068922081696135, 0.07002329400607518, 0.02223840169608593, 0.18802756337182863, 0.13968445387269768, 0.21831808585141385, 0.09656982310116291, 0.07601745200476476, 0.1971626260450908, 0.10967553699655191, 0.13555982948413917, 0.12052210925945214, 0.06889492419681378, 0.11191108596644231, 0.17043551164013998, 0.1885659537677254, 0.19135279208421707, 0.1796618779855115, 0.12140100209840707, 0.16423646999256952, 0.18369491371725286, 0.2466143396283899, 0.46678057845149723, 50.70874888556344, 126.69628797258649, 101.5436075755528, 103.30480916159493, 81.7653865814209, 64.50720078604562, 102.91630063738141, 162.47939954485213, 112.4117922101702, 69.01814501626151, 31.535695144108363, 0.4164308373417173, 0.1412039516227586, 0.3185846491583756, 1.3020508353199278, 2.6763425256524767, 1.2884993510586875, 3.491830446890422, 11.049641183444432, 14.599516664232526, 5.5750842945916315, 30.442580223083496, 88.30926254817417, 92.46188817705426, 88.55961309160504, 93.39952673230852, 89.79182052612305, 89.71035289764404, 87.57982676369804, 85.97777366638184, 89.61144529070172, 89.55793026515416, 76.2812498637608, 63.96756894247872, 62.623113359723774, 58.95684078761509, 72.54902499062675, 78.00683498382568, 79.68531131744385, 79.16258444104875, 76.84005178724016, 76.80021776471818, 79.96075180598667, 81.98137828281948, 78.58306298937116, 77.02006571633476, 72.95130484444755, 66.86995656149728, 64.1887787410191, 64.05825683048793, 64.95544297354562, 62.60435322352818, 58.655073574611116, 58.11485113416399, 57.24160153525216, 61.00247383117676, 61.84032930646624, 61.94349615914481, 58.36575058528355, 63.98733656747, 70.10243225097656, 77.79890319279262, 75.48871053968156, 75.82961695534843, 81.53821522848946, 76.11935683659145, 73.02944428580147, 64.36969593593052, 32.68495498384748, 82.25384494236538, 77.59477206638881, 74.86524868011475, 66.23384898049491, 70.6873802457537, 72.96608366285051, 72.72994913373674, 68.8156258719308, 65.54532418932233, 75.11486271449498, 77.62880434308732, 72.8955386025565, 62.29688153948103, 58.39484964098249, 60.3390667779105, 58.15823221206665, 56.233980723789756, 54.60710171290806, 59.377053941999165, 61.816358021327424, 67.10033103397915, 68.01947348458427, 71.7878498349871, 71.28179168701172, 70.73031316484723, 70.80366529737199, 74.29440552847726, 76.76854787554059, 72.79849311283657, 74.53301361628941, 72.3596796308245, 61.286002022879465, 60.79258264814104, 63.19580473218645, 63.269302776881624, 68.75318935939244, 77.11231000082833, 77.38510322570801, 78.81786346435547, 62.29395634787423, 4.144429794379643, 2.6300434214728217, 3.751684606075287, 4.982658301080976, 5.38968551158905, 1.0381017987217223, 0.8147308932883399, 1.2142119258642197, 0.692135465996606, 0.21514529681631497, 0.13859431951173715, 1.6943375510828835, 37.910941805158345, 51.5945017678397, 88.2632863180978, 69.55663735525948, 49.14043624060494, 27.77053928375244, 46.84234387534005, 72.40165369851249, 86.41478756495884, 94.18410342080253, 93.6460210255214, 4.801866173744202, 0.34975046824131695, 0.14426053475056375, 0.17326368630996772, 0.13298972882330418, 0.11635751915829522, 0.13568736692624433, 0.16140590687947615, 0.12859743594058923, 0.17944387825472013, 0.1226352301559278, 0.135866554453969, 0.12911244401974337, 0.12892976882202284, 0.15567945130169392, 0.07957047849361386, 0.10352158400097064, 0.15445994745407784, 0.09448648989200592, 0.1480595301836729, 0.11551952841026442, 0.18285885000867502, 0.17927876354328223, 0.11275752447545528], [0.08174163449023451, 0.028633061596857648, 0.06699138919689826, 0.0047358652726481, 0.03626980699066605, 0.07379651189382587, 0.054832940721618276, 0.06444118996816021, 0.019542548140244823, 0.026994845663596476, 0.027560988141755973, 0.0860099047422409, 0.04270177274676306, 0.03861312767756837, 0.05227356430675302, 0.04390751929687602, 0.014207139079059874, 0.014440853680883135, 0.07090843615255185, 0.07191965689084359, 63.56920092446463, 92.50603703090123, 81.01805918557304, 64.75576564243862, 29.98974527631487, 19.3527341570173, 63.03660760607038, 114.18468761444092, 77.888076373509, 42.902138573782786, 2.7652303959642137, 0.018673390582469956, 0.12450926245323249, 0.19103404347385677, 0.25478205563766615, 0.3168505850647177, 0.15322847424873284, 0.39880686732275145, 1.6904770668063844, 0.8919028522712844, 23.189089945384435, 82.3191510609218, 83.98184108734131, 77.95895494733537, 75.65480027879987, 71.92153317587716, 77.39244747161865, 78.96846566881452, 81.35244124276298, 79.77253205435616, 79.54605552128383, 80.46375969478062, 71.33577224186489, 59.338123185294016, 53.981270517621724, 55.43934999193464, 58.37046146392822, 65.7755458014352, 65.99422645568848, 67.68028327396938, 65.00822149004254, 68.1843820299421, 68.48800441196987, 73.32493727547782, 75.05924238477434, 72.45166683197021, 68.5171868460519, 67.53002153124127, 65.3436735698155, 63.21768460954939, 60.6412786756243, 58.541804041181294, 52.12472227641514, 51.95580809456961, 52.58473818642752, 56.623646123068674, 54.21015807560512, 53.20225238800049, 53.256649834769114, 52.23783894947597, 49.43431724820818, 55.08232028143746, 55.85023518971035, 61.60466030665806, 64.38768482208252, 65.45065498352051, 66.26450443267822, 52.31696156093052, 20.180799620492117, 52.49815320968628, 65.74705123901367, 71.15197154453823, 61.09112589699881, 60.889982495989116, 66.90876919882638, 65.47152737208775, 65.99499075753349, 65.64049366542271, 62.964381081717356, 70.72339275905064, 67.74299771445138, 64.53853716169084, 55.532289096287315, 53.134854861668174, 51.90776130131313, 49.94538157326834, 50.914766447884695, 49.986191817692344, 50.661129406520296, 54.13882092067173, 56.646533489227295, 58.92089775630406, 55.38739831107003, 57.51281404495239, 60.34702941349575, 64.97931698390416, 65.47049903869629, 66.28366756439209, 64.84927449907575, 64.16693360464913, 50.70865855898176, 53.854163646698, 51.472755432128906, 58.13358347756522, 68.89985193525041, 68.9164650780814, 75.24771921975272, 73.32425635201591, 68.49502904074532, 48.9865961756025, 1.6783117481640406, 0.693801893719605, 0.9040016201989991, 0.6746394133993557, 0.268540303089789, 0.20677818650645868, 0.604963909302439, 0.17643012425729207, 0.0959418932242053, 0.31592547042029245, 0.029195499273815324, 7.952195916857038, 22.193955046789988, 45.17279250281197, 43.660704680851524, 29.567840235573904, 34.911949907030376, 30.88610805783953, 46.4510178565979, 56.42854070663452, 63.8981842313494, 79.67908573150635, 22.690073796680995, 0.9123106343405587, 0.14884876140526362, 0.14473416576428072, 0.06132441399885075, 0.04492425313219428, 0.04310154522370015, 0.17186300004167215, 0.029849098130528415, 0.07071241417101451, 0.04614056786522269, 0.05017140853617873, 0.008287401953046876, 0.04422227133597646, 0.018226488759475093, 0.04562572602714811, 0.02120477912415351, 0.023820153337770274, 0.058786285908094475, 0.021973947761580348, 0.033565814407276254, 0.0794397790783218, 0.018404814547726085, 0.08894785280738558, 0.02066917241817074, 0.09380943407969815, 0.04900345638660448, 0.04377639240452221, 0.015028497237446052, 0.030416624820125953, 0.046933605668268034, 0.04405478514464838, 0.03515254479965993, 0.04482440670420017, 0.05722965193646295, 0.03941699829218643, 0.03530801413580775, 0.05913290195167065, 0.06727936624416284, 0.0214246244701956, 0.025332407726507102, 0.011994905420579016, 0.04015076945402792, 0.27356471919587677, 80.39042145865304, 104.71095085144043, 90.14014066968645, 74.74342591421944, 43.93143776484898, 27.767469917024883, 60.88347898210798, 124.77191489083427, 82.21558816092355, 46.4916022845677, 4.400419235229492, 0.1251136064529419, 0.0944774110934564, 0.9268145646367754, 0.1030570724979043, 1.3378495829445975, 0.8906674299921308, 2.4154443996293202, 0.4977976626583508, 1.8772903510502406, 26.320993934358867, 87.67123031616211, 89.02835941314697, 83.24431759970528, 80.68926348005022, 76.61454105377197, 82.34444250379289, 82.36241749354771, 83.45502172197614, 83.95953042166573, 82.44823469434465, 82.36118071419853, 74.54941136496407, 62.348854064941406, 58.20554597037179, 57.95141908100673, 60.36685957227434, 67.91833550589425, 69.59540830339704, 69.71883610316685, 68.20335061209542, 70.47888565063477, 71.92479188101632, 74.70478698185512, 77.91199207305908, 76.13285718645368, 73.17121532985142, 71.2290757043021, 69.38325895581926, 65.9789821079799, 63.48389094216483, 61.350307600838796, 55.87228182383946, 55.69950096947806, 55.89062506811959, 58.893007687159944, 56.39473077229091, 55.31274339130947, 56.11982529503958, 55.0498548235212, 51.311334882463726, 58.85277761731829, 58.407849720546174, 64.32857649666923, 67.53680297306606, 66.62430994851249, 70.1811831338065, 56.71197509765625, 24.832114832741873, 60.013891083853586, 69.5580825805664, 73.69704110281808, 63.318287576947895, 64.76044178009033, 68.5285540989467, 67.93264879499162, 65.76381029401506, 65.9865973336356, 65.45992388044084, 74.51956885201591, 70.67170510973249, 66.16195596967424, 58.379542759486604, 56.35078689030239, 53.72099794660296, 53.56522280829293, 53.046953201293945, 53.28828150885445, 52.10338435854231, 56.95782320840018, 58.53639139447893, 61.2217937197004, 58.61195305415562, 58.902346066066194, 61.9745546068464, 67.97007874080113, 69.47268227168492, 69.2499647140503, 68.13374355861119, 66.59844180515834, 52.40391479219709, 57.24616302762713, 54.08042825971331, 63.331148692539756, 73.27544525691441, 70.86027921949113, 78.20091206686837, 75.5461790902274, 69.59617260524205, 55.82353673662458, 3.8660037517547607, 0.7058516985603741, 0.9314051525933402, 1.3195843973330088, 1.3237703612872531, 0.7073165199586323, 0.7824910346950803, 0.5147075152822903, 0.3369890701557909, 0.6974046975374222, 0.1977972869894334, 7.938742467335292, 26.200152601514542, 45.41141101292202, 54.5474305834089, 29.87882423400879, 32.22833326884678, 40.24599163872855, 51.883446080344065, 65.76751368386405, 70.51256356920514, 94.0796650477818, 37.62810843331473, 0.7571444947804723, 0.1469854771026543, 0.11614528697516237, 0.03487219787868006, 0.08409772520618779, 0.03888724225440195, 0.1207081771322659, 0.02431269172978188, 0.05218608757214887, 0.023337896447628736, 0.07870058981435639, 0.0116276152631534, 0.07471321948937007, 0.05272468152855124, 0.01698611826369805, 0.023568443987252455, 0.010170073697476514, 0.01879897554005895, 0.06322132649698428, 0.050997077088270865, 0.03762879388939057, 0.04507680816043701, 0.05163803144491144, 0.14778834687811987, 0.28785466668861254, 0.20303902429129395, 0.19129723363689013, 0.04760133162406938, 0.1220378614962101, 0.1186160636799676, 0.10316618092890296, 0.11212376598268747, 0.07907437440007925, 0.13892332757157938, 0.1635588306401457, 0.19520408899656363, 0.11623022598879677, 0.12489287901137557, 0.14541594418031828, 0.06287864595651627, 0.12995817006698676, 0.1400207086865391, 0.502071239054203, 91.40683896200997, 115.70043018886021, 102.73486232757568, 87.3551915032523, 49.09250756672451, 28.73804293360029, 74.7277021408081, 121.49889646257672, 89.24616459437779, 67.77762753622872, 5.017872640064784, 0.22207322078091757, 0.4173917786351272, 1.1140157537800925, 0.7274900174566677, 1.8652647563389368, 1.1892363003322055, 5.269427827426365, 8.28017520904541, 7.550667337008885, 26.926114286695206, 93.75512858799526, 93.70672743661063, 87.2408311026437, 83.22943455832345, 81.2345858982631, 85.57564667293003, 86.3927617754255, 87.63762187957764, 87.90396022796631, 85.6896527154105, 86.2956884929112, 78.0257271357945, 66.53915977478027, 60.27395520891462, 60.397723470415386, 63.07152925218855, 73.63413906097412, 73.4093439919608, 72.70180892944336, 71.4355136326381, 74.75077016013009, 77.09068025861467, 79.81636823926652, 82.17604596274239, 77.97410202026367, 76.60161740439278, 74.21660654885429, 71.53565107073102, 68.86442307063511, 66.84664535522461, 63.791181973048616, 57.36984443664551, 59.204432896205354, 57.88511937005179, 61.20128958565848, 61.13373919895717, 58.4413400377546, 59.10157176426479, 57.355051721845356, 56.19736024311611, 61.60941982269287, 61.64931637900216, 68.68012210300991, 71.14241082327706, 69.39508478982108, 72.90006187983921, 59.94732734135219, 29.44329377583095, 64.51737989698137, 72.54427937098912, 75.80975900377545, 66.86536380222866, 66.50494684491838, 72.86678695678711, 71.03849356515067, 71.47878701346261, 68.97067492348808, 70.30420793805803, 76.85306576320103, 73.21236951010567, 70.38698877607072, 61.547004154750276, 57.591578824179514, 57.65265348979405, 57.46339498247419, 57.223112378801616, 56.604298864092144, 55.793388502938406, 59.47895622253418, 62.21007769448416, 66.39212894439697, 61.701990672520225, 63.3939882005964, 65.98627771650041, 72.496871812003, 72.72855254581997, 72.09409168788365, 70.55543395451137, 71.83030332837785, 56.527562958853586, 60.73195961543492, 56.452862875802175, 65.68057087489537, 77.28445162091936, 74.89741883959088, 77.66838823046002, 76.93916089194161, 71.13271113804409, 57.04498488562447, 3.153885700872966, 4.555565995829446, 4.74454744373049, 3.5375241892678395, 1.5850173085927963, 0.8697115001933915, 2.1353668570518494, 1.027701648218291, 0.6402981589947427, 1.1351129817111152, 0.3152881903307778, 12.848407336643763, 38.05919899259295, 58.52978365761893, 54.959785325186594, 39.20709351130894, 49.92477669034685, 46.3570191519601, 63.277967180524556, 74.66663442339215, 80.69418280465263, 103.45920508248466, 38.670967033931184, 1.1486989898341042, 0.3054526352456638, 0.21999021326856955, 0.14460744256419794, 0.25702301253165516, 0.16221476133380616, 0.310053211237703, 0.08714069013616868, 0.21826615078108652, 0.09521649179181882, 0.1317677279668195, 0.10501318717641489, 0.22461964056960174, 0.14814882539212704, 0.13639419685517037, 0.07513120384620768, 0.15972946397960186, 0.11982184754950659, 0.1441423339503152, 0.12222957478037902, 0.16895178625626223, 0.124669559566038, 0.22484122296529158], [0.03127035079523921, 0.06939670084310429, 0.017449817221079553, 0.04903709815282907, 0.022315942981679524, 0.04168026202491351, 0.05629456961261375, 0.04542043525725603, 0.03164538727807147, 0.07475253380835056, 0.03590961346136672, 0.011092550537016774, 0.038836060357945304, 0.020436102424615195, 0.06514335836150817, 0.0721307627058455, 0.04352782806381583, 0.11339420745415346, 0.29353177919983864, 6.084540980202811, 91.20718247549874, 78.16305828094482, 84.48713493347168, 56.181320326668875, 43.55471338544573, 38.40180424281529, 51.16322013310024, 35.98370953968593, 29.175645692007883, 17.527626514434814, 0.08043489818062101, 0.10110233524548155, 0.14424165790634497, 0.4064502657524177, 0.44204564286129816, 0.30127921061856405, 0.669948510825634, 0.5233949891158513, 0.6700007851634706, 12.111042789050511, 78.90285382952008, 83.67784350258964, 84.55074569157192, 76.06122820717948, 69.95649923597063, 62.836395263671875, 65.94897283826555, 73.12092426845005, 77.66629682268415, 78.46080248696464, 81.21232386997768, 78.73163631984166, 74.73794378553117, 58.364124706813264, 53.472297600337434, 53.34031656810215, 53.34381151199341, 54.190755231039866, 59.77276079995291, 57.824499811444966, 60.434938022068565, 60.30477046966553, 64.45233086177281, 67.10175541469029, 70.29322283608573, 70.7193489074707, 72.11230291639055, 69.05841677529472, 70.34417397635323, 65.78978266034807, 61.76895046234131, 57.540572098323274, 52.498733384268625, 50.65452861785889, 53.357520307813374, 50.46258463178362, 52.82562528337751, 50.501588344573975, 54.02166387013027, 50.82163974217006, 54.296579769679475, 57.820723465510774, 58.362144470214844, 55.49113144193377, 62.00146497998919, 60.636595589774, 68.9206965310233, 60.15109716142927, 27.308081081935338, 66.9668561390468, 67.55842576708112, 67.44371795654297, 56.68650300162179, 59.866533688136506, 67.04528740474156, 65.54849951607841, 55.45512587683541, 57.981664589473176, 63.03373105185372, 63.52660151890346, 66.23696872166225, 68.38327421460832, 60.78061785016741, 52.31952197211129, 50.26488406317574, 48.62168720790318, 50.30059085573469, 49.407281807490754, 49.075783252716064, 50.204219341278076, 52.48763711111886, 51.921306814466206, 50.94045393807547, 52.243053572518484, 55.14476721627371, 63.34306485312325, 67.46185275486538, 64.68979249681745, 66.3750363758632, 63.52240480695452, 51.667377948760986, 51.52711466380528, 55.12396083559309, 65.57234573364258, 70.14877673557827, 73.1378014428275, 73.55688204084123, 61.074630873543875, 70.08743109021867, 67.18599537440709, 53.577680928366526, 1.2886880380766732, 2.4986733964511325, 3.3340770261628285, 0.380021082503455, 0.47676524839230944, 0.17889454987432274, 0.17183383660657064, 0.17557974345982075, 0.026360203378966877, 0.018697402240442376, 0.029715070500969887, 17.770853417260305, 29.074827330453054, 35.96723536082676, 24.79108919416155, 32.5066294670105, 18.263645717075892, 37.17240388052804, 61.59361267089844, 62.40209811074393, 72.7807126726423, 62.8479014805385, 1.079512085233416, 0.05783590261957475, 0.06673212096627269, 0.05875357373484543, 0.013911922063146318, 0.037852232078356404, 0.04661384943340506, 0.02852206344583205, 0.05518728867173195, 0.052637564417506964, 0.015599993356902684, 0.037372433181319914, 0.06208008487841912, 0.027576686049412404, 0.047206899217729054, 0.010269421402231922, 0.03169017398197736, 0.06948652530887298, 0.049237890235547505, 0.032662087186638794, 0.017043776776907698, 0.02931673312559724, 0.01929295921166028, 0.037831876027796946, 0.014360925648361444, 0.029505291221929447, 0.08379948192409106, 0.035879327050809345, 0.05232075641730002, 0.0173487613044147, 0.037219800121550045, 0.026142050977796316, 0.049323819910309145, 0.05055306073544281, 0.02179087731721146, 0.07078739907592535, 0.08649573581559317, 0.038392491838229556, 0.041752091741987636, 0.09518463457269327, 0.1524106224200555, 0.5007039638502258, 10.336289610181536, 108.62239755902971, 84.34559317997524, 94.82611697060722, 68.39489160265241, 58.214995520455496, 40.33523082733154, 41.30819749832153, 39.59210014343262, 37.770404066358296, 20.671022823878697, 0.10778938606381416, 0.10363990693752255, 0.49744211030857904, 0.3737765247268336, 0.53814568902765, 1.2932378053665161, 2.0546188013894215, 1.110993504524231, 0.7270191684365273, 14.825970615659442, 84.90173394339425, 87.0148617880685, 88.22449452536446, 78.7071647644043, 75.09444195883614, 65.59424645560128, 68.76796817779541, 74.85834911891392, 79.95923015049526, 81.73305661337716, 85.25597395215715, 81.36539268493652, 76.08551216125488, 62.238301277160645, 58.02131795883179, 56.08679008483887, 57.57239137377058, 56.565524441855295, 62.03159236907959, 61.66293484824044, 63.410976546151296, 63.92220415387835, 66.77850437164307, 71.2401511328561, 74.88442570822579, 74.86708300454276, 73.73190021514893, 71.24381283351353, 71.86860179901123, 67.02989019666398, 65.55443327767509, 60.79291616167341, 55.79266241618565, 52.34723833629063, 55.65041194643293, 54.173311778477256, 55.47333015714373, 54.06153263364519, 56.68317134039742, 52.370653765542166, 56.88209479195731, 60.44886916024344, 61.114951269967214, 58.563301767621724, 65.94938973018101, 64.23977851867676, 71.29035186767578, 63.5669983455113, 29.950175285339355, 71.2638931274414, 70.60900456564767, 70.11862850189209, 58.862088203430176, 63.151815686907085, 69.09515190124512, 67.96538870675224, 60.84786946432931, 61.593626567295615, 66.62889575958252, 64.80261734553746, 69.06709507533482, 69.88298729487828, 64.01184981209892, 55.087083271571565, 53.28590522493635, 53.67268017360142, 52.01858506883894, 51.69767209461757, 52.057401180267334, 53.39937973022461, 54.489503451756065, 53.19907706124442, 54.61371987206595, 55.583862100328716, 59.31042071751186, 65.21096992492676, 69.7450863974435, 69.64130115509033, 70.14288466317313, 66.57642296382359, 56.18520784378052, 53.7822185243879, 58.103998047964915, 69.4876070022583, 73.64407498495919, 76.26684624808175, 76.31605339050293, 62.83411625453404, 72.64765466962541, 71.77888665880475, 61.881803103855674, 3.41034979053906, 1.259526557156018, 5.838607319763728, 0.9757386765309742, 1.0055971486227853, 0.41183340975216454, 0.756047927907535, 0.5620430952736309, 0.33352723877344814, 0.09817054149295602, 0.13431530126503535, 19.58946102006095, 32.27873202732631, 39.33000367028372, 23.4165427003588, 31.767007623400005, 30.02865866252354, 48.194126333509175, 67.71781049455915, 70.31335176740373, 78.8560438156128, 76.40682465689522, 3.1031833929674963, 0.1936464168663536, 0.04182705629084792, 0.007699362301666821, 0.022070907023070113, 0.056715783796140125, 0.10395550036004611, 0.03160055646938937, 0.02429613547532686, 0.0015885087902591164, 0.03220694964485509, 0.03072843880259565, 0.005345257572896246, 0.046784969179758, 0.03250777136002268, 0.02046109117301447, 0.06266836116888694, 0.10912316877927099, 0.03349974884518555, 0.002400342437405405, 0.010323432789716338, 0.012471451590369855, 0.04836279380002192, 0.14764533883758954, 0.155221250174301, 0.15163059213331767, 0.21960922942629882, 0.1277373656630516, 0.11368913270000901, 0.12706941579069408, 0.16531350862767014, 0.14640843735209533, 0.17269571178725787, 0.1090163809380361, 0.16639178219650472, 0.1373051301177059, 0.18466029262968472, 0.1723574892218624, 0.1457657561238323, 0.21683867595025472, 0.28943774316992077, 0.6578199416399002, 11.21111558164869, 123.81466157095772, 96.77193914140973, 106.89558260781425, 75.65081896100725, 62.19911343710763, 55.23496525628226, 73.48646204812187, 51.308607714516775, 49.02106966291155, 28.617067847933086, 0.2988852305071694, 0.13512108874108109, 0.4730664182986532, 1.2375132526670183, 1.8054711648396082, 1.7022380871432168, 3.8694361618586948, 3.4597957772868018, 3.418454429933003, 15.34863669531686, 87.84053012302944, 91.56005368913922, 92.37238843100411, 82.97684669494629, 78.72692544119698, 69.99454062325614, 73.30589921133858, 80.96091720036098, 83.66544791630336, 85.10703931535993, 89.57045091901506, 86.15642574855259, 81.87240968431745, 64.25236170632499, 59.844091006687705, 58.76880168914795, 59.67604187556675, 59.366367612566265, 66.4293018068586, 65.63243375505719, 68.44212545667375, 66.36726828983852, 70.58652019500732, 74.11291858128139, 77.94869245801652, 77.9885264805385, 76.46150697980607, 74.78020272936139, 76.3656565802438, 71.03980677468437, 71.04595593043736, 65.06644739423479, 58.375255720955984, 55.719633374895366, 58.649216243198936, 56.168097904750276, 59.369779178074424, 55.55323791503906, 59.4134555544172, 55.62287623541695, 61.31485789162772, 64.11310591016496, 65.6505685533796, 61.00400938306536, 69.27367891584123, 67.69808455875942, 74.34222997937883, 66.80917372022355, 34.143628529139924, 72.697007724217, 73.40312535422188, 74.86895206996373, 62.736202239990234, 64.68722861153739, 73.306656564985, 71.78767613002232, 63.42005784170968, 64.59766633169991, 69.18011447361538, 67.72378594534737, 71.2539085660662, 75.32512215205601, 65.61295795440674, 56.28787095206124, 56.52676739011492, 56.56276600701468, 54.907666887555806, 56.33689396721976, 54.68557119369507, 55.651829378945486, 58.168310574122835, 55.18642166682652, 57.385446616581504, 60.209712164742605, 62.80443355015346, 70.09799930027553, 72.23051956721714, 71.7825483594622, 73.62275096348354, 69.81281743730817, 59.60186290740967, 58.30719116755894, 61.69475759778704, 73.80132661546979, 77.73797443934849, 79.81431852068219, 77.5173760822841, 63.80954606192452, 74.87991632734025, 72.13043771471295, 62.13113921029227, 2.5555702405316487, 7.164880769593375, 10.425059795379639, 4.0543555191584995, 1.5751309990882874, 0.6181816086173058, 1.5864725219351905, 2.1308364144393375, 0.44826726615428925, 0.12904358628605092, 0.19764309669179575, 28.986484459468297, 44.872606004987446, 48.51942014694214, 36.022143500191824, 44.92457158224923, 28.847470113209315, 52.95287111827305, 78.53471742357526, 80.59537247249058, 90.4714446749006, 85.10420445033482, 2.38729789853096, 0.2436505529497351, 0.14994630536862782, 0.11572785223168985, 0.06032762570040567, 0.20292470471135207, 0.1551714049918311, 0.10419785271265677, 0.1329958899212735, 0.12817757204174995, 0.10532254486211709, 0.12076818676931517, 0.0932906126337392, 0.1838238082293953, 0.13972353748977184, 0.1135135210518326, 0.1286044791340828, 0.17604513705841132, 0.19438882917165756, 0.06167613262576716, 0.06801691345338311, 0.08006185998341867, 0.11685054270284516], [0.05497064601097788, 0.04050754995218345, 0.04572421877778002, 0.015024044351386172, 0.011741043417714536, 0.050576178423528156, 0.028053105842056017, 0.014921838317864707, 0.056221284437924623, 0.01901558257772454, 0.007351803094414728, 0.0669067758800728, 0.09579995726900441, 0.04425218115959849, 0.010073941400540727, 0.006226869216854019, 0.05374268422435437, 0.2514343267040593, 0.38665590648140225, 20.2542907169887, 98.1383718763079, 75.83494622366769, 85.73498971121651, 50.54721369062151, 32.52567447934832, 30.01543276650565, 68.90950298309326, 75.49081584385463, 46.498672076633994, 2.700099068028586, 0.08839592563786677, 0.2011337522417307, 0.23845123765724047, 0.6446643418499401, 0.17484452362571443, 1.3011590774570192, 0.6457850645695413, 1.2114728157009398, 2.260027310677937, 59.300227710178916, 86.94824940817696, 79.37564400264195, 74.43230642591203, 67.75214154379708, 61.42587620871407, 60.89608996255057, 58.4130608694894, 57.210164410727366, 62.073830468314036, 67.61316367558071, 74.33524009159633, 72.46080371311733, 66.6304452078683, 55.905268396650044, 54.662638664245605, 54.397596154894146, 53.948846748897004, 53.13296842575073, 54.26547615868704, 54.13565254211426, 56.499057974134175, 56.544464451926096, 58.9452303477696, 60.83791964394705, 67.5114837374006, 67.1246497290475, 66.94642148699079, 70.04577663966587, 68.79840128762382, 62.10370077405657, 61.20951625279018, 53.89435550144741, 52.254667486463276, 50.223194871629985, 51.06906509399414, 50.91472823279244, 55.61493444442749, 51.56178617477417, 51.56917905807495, 51.01463638033186, 64.19730418069022, 67.51788997650146, 67.22826821463448, 65.15294551849365, 61.321236337934224, 60.196309089660645, 67.54706546238491, 60.88516044616699, 36.067636830466135, 64.82724176134381, 62.33891119275774, 60.14585821969168, 53.18334633963448, 60.721634592328755, 61.91166646139962, 61.75399793897356, 62.86724526541573, 60.30112266540527, 64.05554703303746, 57.5018185206822, 61.225733348301475, 65.03399235861642, 63.768079212733674, 55.32703236171177, 49.85082701274327, 48.600203377859934, 48.416298457554404, 48.59196628843035, 49.55529580797468, 47.684896332877024, 49.90325117111206, 50.16682761056082, 52.63234029497419, 53.337214197431294, 56.33826971054077, 57.314599309648784, 68.13170773642403, 68.71028423309326, 66.10168729509626, 60.304638453892295, 51.24596970421927, 49.205096176692415, 56.0512569972447, 67.90580095563615, 69.80324976784843, 72.93832560947963, 67.96191460745675, 62.92825044904436, 73.71093055180141, 68.90388883863176, 78.49500152042934, 52.759092807769775, 1.2481710293463297, 0.9622642738478524, 1.1547636815479823, 1.6208937891892023, 0.12630841162587914, 0.4857688109789576, 0.3178595666374479, 0.9204768304313932, 0.28062577173113823, 0.05448189384437033, 2.385508737393788, 25.193019901003154, 38.14991814749581, 47.90600190843855, 38.28688103812081, 18.732147114617483, 28.557096208844865, 48.18873453140259, 59.755939211164204, 61.79680579049246, 73.80128492627824, 28.97681256702968, 0.6772541616644178, 0.1322301902941295, 0.09606637047337634, 0.03507516127345817, 0.10439204943499394, 0.06501810758241586, 0.12668658633317265, 0.05072446546650358, 0.042014016437211206, 0.07199979866189615, 0.03757774091458746, 0.05083053406061871, 0.08020734467676707, 0.05507137453449624, 0.008106536747488593, 0.031667877321264574, 0.05191088055393525, 0.09104210364499263, 0.0338513453357986, 0.037887773742633205, 0.029393489006906748, 0.0695243604215128, 0.038240991931940825, 0.09654560618634735, 0.05655320002032178, 0.04604607168585062, 0.05638332538572805, 0.12212090061179229, 0.034404107103390355, 0.03216784227905529, 0.007855174297999059, 0.018598683876916766, 0.02966020755203707, 0.042213400559765954, 0.048878276853689125, 0.026626233211053268, 0.03693845236141767, 0.04763615404122642, 0.023784399631300142, 0.25118340445416315, 0.5052032481346811, 30.193754809243337, 113.32015800476074, 84.16509287697929, 93.75048719133649, 57.96488468987601, 42.082855633326936, 40.87437629699707, 75.10609408787319, 76.23428698948452, 51.20834868294852, 3.0641590527125766, 0.07097137027553149, 0.15984518134168216, 0.9198862335511616, 0.867216445505619, 0.4940551891922951, 2.779034512383597, 2.726666808128357, 0.46517521888017654, 3.713877720492227, 64.63127476828438, 89.45716748918805, 82.07529013497489, 80.02156244005475, 70.1865540913173, 65.9186578478132, 63.64219869886126, 63.04609884534563, 60.75773743220738, 65.91409982953752, 70.32681042807442, 76.62699222564697, 75.09894439152309, 70.81617205483573, 60.034221512930735, 58.327389580862864, 57.66132831573486, 57.6062707901001, 56.11752544130598, 57.73448937279837, 58.49543176378523, 59.37792246682303, 59.350136620657786, 62.318205560956685, 62.80888039725167, 69.63390827178955, 69.40725803375244, 70.26470048086983, 72.50282641819545, 69.05346270969936, 66.29975959232875, 64.3988436290196, 56.47286673954555, 53.99874523707798, 52.678681305476594, 54.47942508969988, 54.307787214006694, 57.3429479598999, 54.98743915557861, 53.10984829493931, 54.05573088782174, 67.63689872196743, 70.23189108712333, 69.97263990129743, 67.22350869859967, 65.04304586138043, 64.10657460348946, 68.41728564671108, 62.786229269845144, 39.89975595474243, 67.78197016034807, 64.14408792768205, 61.941821643284385, 56.94661923817226, 64.19061306544712, 66.06348609924316, 65.06817054748535, 65.80323437282017, 62.62722669328962, 65.82626765114921, 61.34955024719238, 62.77192292894636, 67.43510219029018, 67.83189296722412, 57.35869952610561, 51.940084321158274, 53.24970858437674, 51.12596041815621, 51.0504925591605, 51.16169152941023, 49.75553594316755, 52.094643524714876, 54.0865808895656, 54.5070789200919, 57.19916888645717, 58.24122844423567, 61.57361575535366, 71.2389907836914, 70.83700970241001, 70.90010629381452, 63.542089053562705, 53.4943060193743, 52.587562629154746, 58.62477248055594, 70.642258644104, 71.36496162414551, 74.5515444619315, 70.84692478179932, 66.3370783669608, 76.35618618556431, 72.64923191070557, 78.97838074820382, 60.93859904153006, 2.996115126780101, 1.2241732542003905, 1.5251096146447318, 0.9824770178113664, 0.6613134198955127, 1.06335882629667, 1.4650780473436629, 0.9462626810584749, 1.0023763328790665, 0.06383542104491166, 2.215039896113532, 29.225745677947998, 36.095221178872244, 41.183258465358186, 32.99530322211129, 26.10057101930891, 44.00225727898734, 53.640801838466096, 66.19074235643659, 70.23774147033691, 83.20107895987374, 41.81765331540789, 0.4741955005696842, 0.16977269149252347, 0.03490499486880643, 0.07846419499920947, 0.10587385456476893, 0.03079753741621971, 0.08711766065763575, 0.04557598601760609, 0.05894640660179513, 0.039686529364969046, 0.03154166302244578, 0.01960317015514842, 0.037996522550071986, 0.07851642862494503, 0.03093180592570986, 0.04145181964018515, 0.0652868685179523, 0.06309849808790854, 0.02546814696065017, 0.010944394960201212, 0.08445876011891024, 0.03238900737570865, 0.18733351704265389, 0.1909655114369733, 0.11976741547031061, 0.16261395705597742, 0.10608048883399793, 0.15728828497231007, 0.1517084879534585, 0.08776015868144375, 0.09559855450476919, 0.09613061416894197, 0.13748681465429918, 0.17591169636164392, 0.14939703127103193, 0.17258259999964917, 0.2678687162697315, 0.09427511266299657, 0.10008973029575177, 0.38078052603772705, 0.7692319176026753, 37.190153053828645, 128.85374532427107, 96.83174228668213, 107.60382638658795, 67.95136724199567, 45.6283164024353, 46.84586661202567, 93.55624335152763, 92.30582468850272, 68.81129019601005, 4.291424580982753, 0.19613962593887532, 0.37251510098576546, 1.7622988585914885, 2.9346229178564887, 0.6979573507394109, 3.2238015149320876, 5.978277402264731, 5.636363497802189, 3.750940714563642, 68.86980097634452, 95.8221412386213, 87.7557829448155, 83.97142573765346, 75.80313042231968, 68.85094356536865, 66.51472990853446, 65.62533269609723, 62.42819554465157, 68.63022014072963, 73.88991614750454, 80.95817266191754, 79.42596285683769, 73.4079543522426, 62.19635500226702, 60.730500493730815, 60.40396990094866, 60.23634460994175, 58.78508826664516, 61.87192971365792, 60.90995856693813, 62.80205726623535, 62.13308470589774, 66.1159449986049, 66.8148295538766, 73.21116747174943, 74.90582615988595, 72.03166212354387, 75.61300686427525, 72.74552699497768, 71.2584387915475, 67.13990102495465, 59.2616582598005, 57.94162906919207, 55.63188457489014, 55.678948198046, 56.061113016945974, 61.203499112810405, 58.63329097202846, 57.47034665516445, 57.24667372022356, 70.81270490373883, 74.55160699571881, 73.46124703543526, 71.00517695290702, 68.1713124683925, 66.77629484449113, 73.33298328944615, 65.5286693572998, 44.36336210795811, 71.3698809487479, 68.40383393423897, 67.35967254638672, 59.11107689993722, 66.98802035195487, 67.44980457850865, 66.94539315359933, 66.74475697108677, 64.95787484305245, 66.4120911189488, 62.943515641348704, 65.25848170689174, 69.62607765197754, 72.09046472821916, 59.722865785871235, 55.75198071343558, 55.456908089774, 55.28199066434588, 55.05799116407122, 55.53175755909511, 52.92917081287929, 55.535582542419434, 56.86281354086739, 56.49116482053484, 58.924788747514995, 60.99103709629604, 62.61749921526228, 74.36899444035122, 75.97378512791225, 73.98819841657365, 66.75151062011719, 58.157645089285715, 54.53045266015189, 62.74851444789341, 74.73504638671875, 75.63847201211112, 76.80032198769706, 72.43816648210797, 67.533933367048, 80.94446386609758, 73.75742094857353, 84.66301468440464, 60.22598484584263, 1.921201229095459, 2.8186831048556735, 7.425091675349644, 3.7200894100325446, 1.535053789615631, 1.391765758395195, 2.949043469769614, 3.712352156639099, 1.043526713337217, 0.1834448328507798, 4.329579310757773, 40.701178550720215, 51.966213021959575, 65.61045660291398, 49.558978353227886, 27.168337174824305, 41.42845344543457, 64.18243503570557, 76.20898859841483, 77.78767490386963, 95.05180835723877, 42.344972951071604, 0.7263351508549282, 0.2975375513945307, 0.14213627230908188, 0.11594487487205438, 0.24325236145939144, 0.15546727340136254, 0.2557006563459124, 0.11584298605365412, 0.14421964623034, 0.13517041823693685, 0.1515781685177769, 0.13317723519035748, 0.13402704601841314, 0.25518011142100605, 0.2605784817465714, 0.1225418501666614, 0.2168535901499646, 0.28438412291663034, 0.12379183380731515, 0.1327254937163421, 0.10320409746574503, 0.18944709934294224], [0.06276452993707997, 0.06603328417986631, 0.04625463638720768, 0.05076493668769087, 0.0047572353089760456, 0.03588807336719973, 0.08001445752701589, 0.028341705445200205, 0.08659832352506262, 0.06180599744298628, 0.05164631635748914, 0.07266485797507422, 0.007716302776576153, 0.07072508241981268, 0.06904454116842576, 0.10082879063806363, 0.03559928547058787, 0.1270474312560899, 0.04676491168460675, 56.80648449489048, 83.14559759412492, 71.98561641148159, 65.42878900255475, 46.48300041471209, 35.66758040019444, 39.54970570972988, 43.474805627550396, 60.07067176273891, 19.14606867517744, 0.06943536376846687, 0.046920791534440856, 0.4964423296707017, 0.3566701412200928, 0.5601441200290407, 0.2499739836369242, 1.4808622917958667, 0.9840914968933377, 0.49330711790493553, 29.397143840789795, 85.94609682900565, 80.53318609510148, 74.80373627798897, 69.23740237099784, 63.933161463056294, 62.9917847769601, 60.995671544756206, 59.51990195683071, 56.20091424669538, 53.061488832746235, 52.575806277138845, 60.4449781690325, 59.53486837659563, 58.4537147794451, 59.309899602617534, 55.26917471204485, 54.72278574534825, 53.73106936046055, 53.14491932732718, 54.54567616326468, 55.80124691554478, 55.00809962408883, 54.66616487503052, 55.32095963614327, 55.89993218013218, 60.137096541268484, 62.20301832471575, 68.14162281581334, 66.10413306100028, 65.45493507385254, 62.49172987256731, 59.12673119136265, 51.0294360433306, 48.12809065410069, 52.40672186442784, 54.109040941510884, 56.19835383551461, 60.662873676845, 59.97828156607491, 51.43716328484671, 50.19553756713867, 63.43655981336321, 68.27728639330182, 66.78788443974086, 65.90009920937675, 66.9372707094465, 64.07829543522426, 67.41460500444684, 61.07807718004499, 38.511099406651084, 64.48135348728725, 58.872711999075754, 55.86109522410801, 54.050137587956016, 60.54437214987618, 63.767704010009766, 64.89493111201695, 60.13864598955427, 63.68777888161795, 59.903199332101, 63.03763593946184, 60.30930069514683, 63.092894962855745, 60.542197363717214, 52.67674970626831, 50.218171324048726, 49.57814843314034, 48.54587541307722, 48.40838098526001, 47.230598790305, 49.54479013170515, 50.23715727669852, 53.78553976331438, 55.719074044908794, 58.95283167702811, 58.295059612819124, 61.05086803436279, 63.35084683554513, 64.86260114397321, 69.55323273794991, 61.28755841936384, 50.725487095969065, 49.219538007463726, 58.43207114083426, 69.74181379590715, 68.16665022713798, 67.51954364776611, 66.87291649409703, 68.61689349583217, 66.47052546909877, 69.70735767909459, 66.3998692376273, 77.49418299538749, 52.80127879551479, 1.3322973208768027, 2.6882862618991306, 0.562456513089793, 1.4564956107309885, 0.14068669080734253, 0.887041718832084, 0.797736793756485, 1.2632758702550615, 0.043603481325720034, 0.03880028120641198, 9.825843674795967, 27.412378753934586, 48.580633776528494, 38.14008297239031, 33.40788378034319, 18.663757732936315, 40.16083799089704, 57.97454268591744, 60.04489394596645, 69.44851643698556, 67.57570593697685, 2.7582648268767764, 0.2989979758858681, 0.07047955452331475, 0.09452248617474522, 0.08286495599895716, 0.08048213778861932, 0.024949676656563367, 0.03896439168602228, 0.0371861379992749, 0.04536561980577452, 0.012523552901776773, 0.010646183060349097, 0.011461095136058117, 0.020724289817735553, 0.015512930528659905, 0.03138019543673311, 0.02263515638852758, 0.01753097679466009, 0.022617667148421918, 0.022102845666397895, 0.04823650825502617, 0.061581592341618877, 0.03482365209077086, 0.046504228708467314, 0.03687091777101159, 0.015369391534477472, 0.033965525816061666, 0.04712975657145892, 0.02187156361261649, 0.015340280685839909, 0.053927788577441654, 0.05610890207546098, 0.018310508358159235, 0.00986714004206338, 0.06178940726178033, 0.034043119688119204, 0.06379040703177452, 0.03685280427868877, 0.02533738817354398, 0.05362503303747092, 0.04882644017093948, 72.20922333853585, 92.68933745792934, 83.14925234658378, 75.49003069741386, 59.426865577697754, 41.31473575319563, 35.47675507409232, 48.978310448782786, 66.32100023542131, 20.224396092551096, 0.06503257394901343, 0.18216401657887868, 1.0899949627263206, 1.0545455792120524, 1.251315523471151, 1.0119677782058716, 4.263091564178467, 2.1176198550633023, 1.0519342507634843, 34.37949902670724, 90.16330596378872, 84.1928995677403, 79.18495069231305, 72.57694285256522, 69.34245218549455, 67.79430321284703, 66.56528500148228, 61.97937665666853, 60.0498480115618, 57.62996762139456, 56.545947892325266, 63.75751100267683, 64.77654770442417, 61.04735919407436, 61.871436391557964, 56.75892060143607, 55.43156106131417, 55.13427891050066, 55.9800066947937, 57.14722762789045, 57.45473057883126, 57.781441824776785, 59.2973997933524, 59.193037850516184, 59.70991434369768, 59.629231861659456, 64.90036460331508, 70.66533361162458, 69.22217886788505, 68.84070192064557, 64.59688118525914, 61.87821783338274, 53.478165354047505, 50.359900678907124, 53.516144207545686, 55.44233424322945, 59.981595856802805, 61.82527950831822, 61.94973564147949, 54.59881946018764, 52.770668506622314, 66.71319825308663, 69.73891639709473, 70.31656183515275, 67.45648874555314, 70.24395315987724, 67.06496470315116, 68.76217338017055, 61.477459635053364, 42.653344426836284, 67.9973851612636, 62.68802343096052, 59.06437805720738, 56.77100004468645, 64.12206213814872, 67.36639145442417, 67.35943630763462, 63.958390372140066, 65.51343195778983, 61.430448123386924, 64.17279788425991, 63.46125371115548, 67.59265954153878, 62.87791075025286, 54.82037319455828, 51.820728165762766, 52.968747752053396, 49.99282039914812, 51.65984957558768, 50.23679944447109, 52.13624586377825, 53.993471554347444, 57.97923271996634, 58.737944739205496, 62.40032632010323, 60.48668820517403, 64.98285361698696, 64.76074750082833, 68.39177880968366, 69.61074992588588, 63.83617850712368, 53.3394341468811, 52.016980034964426, 60.135366439819336, 72.84994452340263, 70.53801482064384, 71.11415944780622, 70.2204613004412, 70.04435225895473, 70.07897513253349, 71.00847039903913, 69.62754372188023, 80.52927425929478, 61.289191246032715, 3.5237048736640384, 2.099618158170155, 0.30230314710310524, 2.0629570739609853, 0.3501079747719424, 1.7856502341372626, 0.8751215413212776, 1.5181302577257156, 0.3369266992168767, 0.04916831664741039, 10.13885133607047, 30.563517093658447, 45.94739505222866, 28.066487380436488, 25.670753717422485, 26.699774980545044, 50.34209244591849, 63.59157412392752, 67.2519198826381, 76.24573067256382, 82.70242064339774, 5.719361901283264, 0.42159223609736984, 0.09203394542315177, 0.10672349575906992, 0.06639338271426302, 0.07299491097884518, 0.08105355926922389, 0.09067051751273018, 0.02518640734654452, 0.01912824822855847, 0.020853761084643856, 0.03660948501367654, 0.014400301035493612, 0.019433846830257347, 0.020079591644129584, 0.03408784193119832, 0.03349763860127755, 0.007807909244937556, 0.010767263393583042, 0.028133688660870706, 0.05850259041679757, 0.07142533734440804, 0.12548533507755824, 0.1828099547752312, 0.24490345429096902, 0.20810112623231752, 0.11444516320313726, 0.11078139979924474, 0.18047867129955972, 0.09414385006363903, 0.19832488867853368, 0.285074274454798, 0.09087650038834129, 0.14875126949378423, 0.24448398394244059, 0.2424126879445144, 0.16767808103135654, 0.21290906252605574, 0.13470820018223353, 0.2539985648223332, 0.1640951582895858, 82.51001807621547, 104.5235162462507, 94.69537966591972, 85.3971335547311, 64.44783537728446, 48.642344202314106, 56.32247298104422, 57.07361493791853, 76.74572999136788, 30.339781624930247, 0.10874506192547934, 0.26483151210205896, 1.138887373464448, 2.4879668738160814, 1.6917805054358073, 0.695809326001576, 6.137547918728419, 8.80871251651219, 2.4367655983992984, 36.1210788999285, 97.01010949271065, 89.45157418932233, 82.80527482713971, 77.49757371629987, 72.17327335902623, 71.0839764731271, 69.18590232304165, 65.60398088182721, 64.90166391645158, 61.02887003762381, 57.92918484551566, 68.6861183983939, 68.50679928915841, 63.40302780696324, 65.94844477517265, 61.03944519587925, 59.53270748683384, 58.7560031073434, 59.91947201320103, 58.860955647059846, 61.94590718405587, 61.64265305655343, 60.90064798082624, 62.47749996185303, 63.51249667576381, 63.97272450583321, 67.55208206176758, 76.4014675957816, 72.35373197283063, 72.33634063175747, 68.25448240552629, 65.88405581883022, 57.20569324493408, 52.60939039502825, 58.17406715665545, 59.30541801452637, 63.31619616917202, 64.03905895778111, 65.9875214440482, 57.02251788548061, 55.570184571402415, 69.77066271645683, 72.84107167380196, 73.97338485717773, 71.73507826668876, 73.72130421229771, 71.90070942470005, 73.26461996350969, 64.86418533325195, 44.940965856824604, 71.05346693311418, 66.07458237239292, 63.10304628099714, 60.220363753182546, 68.18275615147182, 70.95437172480992, 69.42369052342006, 66.79511056627545, 67.94812938145229, 63.60951437268938, 67.64449310302734, 67.23226342882428, 68.8064056124006, 66.8969155720302, 57.62490585872105, 54.26922818592617, 56.78813777651106, 54.16315003803798, 54.62645592008318, 53.41376597540719, 55.258286884852815, 58.50775786808559, 59.5265930720738, 62.53348854609898, 65.35016318729946, 64.34629440307617, 67.50086688995361, 70.78992176055908, 70.83887181963239, 73.8441275187901, 67.56758349282401, 57.63298313958304, 54.82766880307879, 63.43477412632534, 76.89975070953369, 72.92487389700753, 76.32567664555141, 71.13544178009033, 71.74020603724888, 71.98600551060268, 74.39648151397705, 72.05104064941406, 83.40621757507324, 59.22792475564139, 1.9467217453888483, 5.811148473194667, 3.4913531924997057, 5.167945044381278, 1.1744288206100464, 2.906791691269193, 4.71039400781904, 4.1435234887259345, 0.42124830026711735, 0.07375385239720345, 16.179931334086827, 42.975959709712434, 62.8007926940918, 55.76357725688389, 44.75757162911551, 27.04692782674517, 53.56149162564959, 74.5636899130685, 75.89686162131173, 85.87560735430036, 90.36745793478829, 5.192912093230656, 0.6200445400817054, 0.13894077949225903, 0.4404746171619211, 0.1900351449315037, 0.18102839323026793, 0.18402519742293016, 0.222549525222608, 0.17420872274254048, 0.12037812412849494, 0.13624010155243532, 0.15443541162780353, 0.07202964063201632, 0.07347004834030356, 0.059780482202768326, 0.14169405746672833, 0.12722847796976566, 0.11330400979412453, 0.08885597916586058, 0.11500844226351806, 0.12510668539575168, 0.19086332406316484], [0.044055012453879626, 0.06662987930966274, 0.03677811114383595, 0.05343136217977319, 0.026905536884441972, 0.041533376156751595, 0.030422667174467018, 0.041283743123390844, 0.01833362434990704, 0.05873280377792461, 0.027425384614616632, 0.02313830197921821, 0.06548117380589247, 0.004051172548705446, 0.0370072151002075, 0.019322080238323127, 0.09707024946276631, 0.1620153941746269, 5.510475167206355, 86.41887310573033, 75.11409146445138, 84.47901248931885, 71.83336053575788, 35.28005504608154, 27.489515917641775, 60.145462172372, 47.79271847861153, 49.936533042362754, 4.193628685814994, 0.0033707662577009095, 0.07829783178333725, 0.5150562822818756, 0.8193535080977848, 0.12441905800785337, 0.4638347593801362, 3.5375039960656847, 1.8691865801811218, 6.247592619487217, 63.8963429587228, 83.18848187582833, 78.52899905613491, 76.88139356885637, 73.9240665435791, 76.0362355368478, 74.59303215571812, 74.17572334834507, 72.29891068594796, 69.05906295776367, 62.972885676792686, 54.38366501671927, 54.06916870389666, 54.5885500226702, 54.90260165078299, 55.62634686061314, 53.96671404157366, 51.04339844839913, 54.9921361378261, 54.588463170187815, 58.29241929735456, 59.15611512320382, 61.63421099526541, 62.75657435825893, 61.35047435760498, 57.97200311933245, 59.34103448050362, 60.23369039808001, 60.91622584206717, 61.87357643672398, 62.08641365596226, 57.385008880070274, 52.48490994317191, 49.70116976329258, 51.52668387549264, 50.41896036693028, 51.58933925628662, 58.00333602087838, 62.80669171469552, 62.92133699144636, 58.41210896628243, 46.10040480749947, 53.46854557309832, 61.38439546312605, 64.60143920353481, 68.16699068886894, 64.42439215523856, 63.48780972617013, 64.75195108141217, 57.391536712646484, 43.689348629542756, 64.92671217237199, 59.0784273147583, 57.844451563698904, 56.06957592282976, 59.86888912745884, 63.14938381740025, 64.36970288412911, 62.07986150469099, 61.724544525146484, 61.02509021759033, 62.26781027657645, 61.91605772290911, 63.51266343252999, 59.524828229631694, 51.43975148882185, 51.141038009098594, 50.74712378638131, 46.86612408501761, 48.81750134059361, 47.470130988529746, 48.443441595349995, 51.51379844120571, 55.959127358027864, 56.099866594587056, 57.55613953726632, 56.950267042432515, 56.647631304604666, 56.53384760447911, 64.09727791377476, 65.78942830221993, 56.77116332735334, 50.281316552843364, 49.411217961992534, 59.819035802568706, 69.22806399209159, 67.7103967666626, 65.14678941454206, 67.52428926740373, 72.16435882023403, 67.48048782348633, 64.56250149863106, 65.0148709160941, 68.9565075465611, 76.30504049573625, 68.21442604064941, 8.009586300168719, 0.8101563187582153, 0.3872692749968597, 1.2843424826860428, 0.25518800956862314, 0.1450166263218437, 1.4797539455550057, 0.2402314692735672, 0.12167799366371972, 1.063212371298245, 21.23820948600769, 29.83903537477766, 53.48398099626814, 51.8670448575701, 27.25296449661255, 24.419179916381836, 43.62769031524658, 63.775326183864046, 57.014708110264365, 73.02572005135673, 27.79774669238499, 0.42851340185318676, 0.0798548593052796, 0.07494888148669686, 0.0759567366912961, 0.06302115866648299, 0.06509196611919574, 0.05701623231704746, 0.0565769860654005, 0.0012252662002408344, 0.02040288643911481, 0.030874666491789476, 0.00789437665870147, 0.08994538749435119, 0.032898872159421444, 0.002722909503583131, 0.01969867735169828, 0.01879786274262837, 0.06102863379887172, 0.06165455521217414, 0.014022984674998691, 0.09563741420528718, 0.04788549869720425, 0.03221170278266072, 0.05259994982874819, 0.0394168116950563, 0.024012830141665678, 0.053916077063019784, 0.04172519800652351, 0.0071738055474790076, 0.024913676981148974, 0.05472581361287406, 0.025235158391296864, 0.048363686073571444, 0.04432899471638458, 0.0483309739003224, 0.028478138481399844, 0.037264217023870776, 0.20363935136369296, 0.19843136439366, 9.020405888557434, 103.31819139208112, 82.80779702322823, 94.78599112374442, 81.9633685520717, 48.35010644367763, 34.88832950592041, 47.23360736029488, 44.06075068882534, 52.73224496841431, 4.892622675214495, 0.0360763464788241, 0.23345195448824338, 1.3690505772829056, 2.0652126329285756, 0.9206498840025493, 2.2070885513510023, 4.631209296839578, 0.028897398484072516, 8.298633967127119, 68.73442227499825, 86.81918661934989, 84.27333886282784, 80.58234460013253, 77.77914251599992, 78.32263060978481, 79.65867887224469, 77.92318562098912, 75.51782349177769, 72.39421912602016, 66.13697024754116, 58.46152455466134, 56.17749881744385, 57.34463289805821, 56.725544929504395, 57.360151699611116, 56.522629737854004, 54.013239179338726, 56.92558356693813, 59.92874091012137, 61.526937757219585, 62.173043795994346, 64.35921110425676, 65.06015232631138, 62.91307558332171, 60.411244664873394, 62.81264632088797, 62.73595905303955, 63.21648257119315, 64.83081313541958, 63.830543518066406, 60.15958786010742, 54.94310964856829, 52.12500715255737, 54.034917558942524, 53.22939552579607, 55.58445617130825, 60.781653131757466, 65.07696696690151, 64.86646434238979, 62.16588020324707, 48.468805994306294, 55.27633483069283, 62.047802516392295, 68.02884660448346, 69.94688987731934, 65.38432053157261, 65.54474054064069, 68.5970424924578, 61.04614325932094, 47.42146233149937, 69.34711442674909, 61.561692646571565, 60.48954391479492, 58.459808349609375, 63.688709940229145, 65.97693933759416, 67.62216854095459, 65.17784786224365, 63.358281408037456, 62.31592655181885, 63.47826290130615, 63.74202346801758, 65.25047043391636, 60.696113858904155, 55.22192348752703, 52.11435209001814, 53.139916624341694, 49.94030591419765, 52.44877931049892, 50.37835509436471, 50.233217648097444, 54.41007511956351, 59.61008262634277, 58.63099806649344, 60.088605063302175, 60.51900427682059, 61.255089487348286, 63.052755219595774, 67.36224337986538, 68.0411240713937, 60.17713900974819, 52.25069659096854, 51.979762009211946, 62.94972038269043, 70.53499930245536, 70.86596979413713, 68.09710570744106, 73.0573204585484, 74.41262912750244, 70.86924934387207, 68.70677539280483, 67.46825204576764, 73.39826161520821, 79.06296116965157, 77.55692522866386, 15.179503645215716, 0.09122162365487643, 0.4758142679929733, 1.0477138715130943, 0.7613771419439996, 1.1495734857661384, 1.7122073407684053, 1.9452719603266035, 0.22303892539015838, 0.8938562188829694, 23.59726013456072, 35.132211276463096, 45.082789012363975, 34.579791273389546, 23.55451307977949, 32.96598877225603, 49.713666098458425, 71.5225189753941, 63.478429658072336, 79.57788521902901, 39.68014424187796, 0.21976147911378316, 0.1057395249871271, 0.07860142870673112, 0.04934909873242889, 0.027716725499236157, 0.07635634631982871, 0.03572238190099597, 0.02880679370303239, 0.024721424261640226, 0.020706035529396365, 0.038220975148890696, 0.017049048994002596, 0.062173329160681794, 0.012643676500634422, 0.052688715779887776, 0.054123471291469674, 0.03349320437493069, 0.016967470425048044, 0.03204305629645075, 0.03455309643011008, 0.07810568423675639, 0.07169833233846085, 0.1338569237185376, 0.20369921172303812, 0.16773917632443563, 0.06491601520351001, 0.11456047344420638, 0.1810469850897789, 0.0849277770945004, 0.15911196997123106, 0.17516511785132544, 0.0868132562775697, 0.0860408323683909, 0.13595906591841153, 0.11500358395278454, 0.13782325945794582, 0.11741412031863417, 0.3214360161551407, 0.3471841402351856, 9.260571241378784, 116.98643057686942, 95.61243765694755, 105.49000372205461, 89.34229987008231, 52.02233362197876, 38.763881819588796, 85.10154329027448, 69.51867934635708, 74.44682121276855, 7.05411171913147, 0.1330163273960352, 0.4457142102931227, 1.4985177729810988, 3.0833191445895602, 1.3613277631146568, 3.0603859637464796, 9.915556209427969, 7.209424802235194, 9.118550062179565, 71.57503346034459, 91.10156985691616, 87.95302145821708, 83.14249174935478, 81.46368190220424, 84.17438956669399, 81.90216187068394, 80.70546667916435, 79.82757568359375, 74.01626913888114, 69.14422702789307, 61.309882981436594, 60.276248114449636, 60.039821760995046, 60.721898623875205, 60.988723346165244, 60.31610992976597, 56.559524672372, 59.95125307355608, 61.68419633592878, 63.79921409061977, 65.20976093837193, 66.70063591003418, 69.19856888907296, 68.26543971470424, 62.68115861075265, 65.91202926635742, 65.30887004307338, 66.94886725289481, 68.83943040030343, 66.35487965175084, 63.25092479160854, 57.30513933726719, 56.05283076422555, 57.99983760288784, 56.81908852713448, 57.67678458350045, 63.14909894125802, 67.47718742915562, 68.94616862705776, 65.99346910204206, 51.906402928488596, 59.670427731105256, 68.49994836534772, 69.80320807865688, 73.92212104797363, 69.37361485617501, 70.34643908909389, 71.74476405552456, 61.975068773542134, 51.512773581913535, 72.13154247828892, 64.6963585444859, 64.19128704071045, 61.48289312635149, 65.74831581115723, 68.39041696275983, 71.65298530033657, 68.37399142129081, 66.56494453975132, 65.51300116947719, 65.65885775429862, 65.88854435511998, 68.56653990064348, 64.94223444802421, 58.736263275146484, 55.52709879193987, 56.19148554120745, 52.5490209715707, 54.88188212258475, 52.87979343959263, 53.5829233442034, 57.614209106990266, 64.24342632293701, 62.83824348449707, 64.41946588243756, 63.659854071480886, 67.33096953800747, 66.5564329964774, 70.56572423662458, 71.81100818089077, 61.98518535069057, 55.26497105189732, 55.82860892159598, 66.78340979984829, 73.79477446419853, 72.88073893955776, 71.1064122063773, 73.8785627910069, 74.65260601043701, 74.3906797681536, 71.8744591304234, 72.38893849509103, 76.53690188271659, 83.77138710021973, 80.5473187310355, 10.690636447497777, 1.9954166752951485, 1.7632353454828262, 4.845781394413539, 0.9868657823119844, 1.267107258949961, 6.121248313358851, 2.403062275477818, 0.32116796768137384, 1.7299933178084237, 34.25403887884957, 45.167126246861045, 73.09500748770577, 73.60098225729806, 37.42143079212734, 36.51369380950928, 58.25347464425223, 79.89054720742362, 71.75308799743652, 90.45888233184814, 39.307248319898335, 0.5068520882299968, 0.2086119545357568, 0.1748231090605259, 0.2078334577381611, 0.12609745508858136, 0.18933111056685448, 0.24982291460037231, 0.14777320197650365, 0.11848357293222632, 0.09830124769359827, 0.149441461744053, 0.05543043491031442, 0.16150586865842342, 0.1975204718432256, 0.15453765328441346, 0.10026631903435503, 0.1838013215788773, 0.1318987530789205, 0.0981437461450696, 0.1317261066287756, 0.21442267059215478], [0.020845357428437898, 0.06314183611954961, 0.015748377091118267, 0.026289416909483925, 0.06854874241564955, 0.03985752358234354, 0.015030112150790436, 0.040322123294962306, 0.02887519681826234, 0.038328190467187336, 0.04494456847065261, 0.0056436607348067415, 0.03341132555423038, 0.04630293111715998, 0.12583345068352564, 0.08253279953662838, 0.19399531957294258, 0.3164205295698983, 36.80244009835379, 90.68213490077427, 70.13194125039237, 70.34375013623918, 51.70951877321516, 38.62757205963135, 36.71432999202183, 55.893254961286274, 45.93929692677089, 23.925008399145945, 0.12739991662757738, 0.1189457502748285, 0.44735140672751833, 1.0556964831692832, 0.09431416913866997, 0.6664189345070294, 2.5127400244985307, 4.502993753978184, 1.0622080309050423, 32.52454192297799, 79.92159870692662, 81.34160900115967, 80.9562897000994, 79.40005302429199, 79.30807971954346, 76.71633216312954, 76.92636231013707, 78.09823853628976, 78.47961820874895, 75.60812228066581, 70.39519459860665, 65.10999175480434, 54.457322869982036, 53.355651242392405, 54.19946479797363, 54.120422090802876, 54.80966602052961, 51.5860458101545, 55.6158516066415, 58.32210200173514, 62.18302835736956, 62.86944784436907, 61.962805203029085, 61.77462714059012, 63.45980848584856, 63.25671264103481, 60.343638692583355, 58.25067799431937, 59.44067859649658, 59.38254301888602, 55.790334769657676, 50.94254534585135, 50.174060685294016, 49.22269943782261, 48.241940362112864, 47.74261154447283, 48.30940389633179, 59.24355820247105, 65.37246690477643, 64.05668653760637, 60.90615095411028, 52.710479736328125, 47.61214174543108, 54.88472393580845, 62.77528585706438, 62.700161933898926, 64.84232630048479, 63.417834418160574, 63.50203268868582, 59.49972438812256, 45.01987654822213, 64.5071382522583, 58.01345607212612, 56.36220972878592, 58.343168939862935, 62.2699225289481, 61.13595567430769, 59.2886381149292, 58.4132901600429, 58.489442416599815, 58.33983380453927, 62.846393721444265, 62.33528423309326, 60.24111802237374, 52.272621631622314, 50.742524078914094, 50.10746914999825, 51.02111904961722, 48.252644062042236, 47.197132791791645, 46.03575529370989, 49.19892965044294, 52.0988576071603, 54.12594590868269, 56.38804660524641, 58.10144111088344, 61.64725276402065, 60.6133052280971, 61.78345830099923, 61.30937576293945, 59.52360534667969, 52.54499101638794, 51.45549610682896, 49.81599569320679, 58.831807953970774, 66.99092469896588, 66.35722814287458, 67.55834933689663, 62.366509437561035, 70.35738945007324, 70.27547018868583, 61.46122169494629, 62.34735325404576, 64.63733359745571, 69.91023118155343, 68.27678612300328, 80.52262483324323, 26.109179837363108, 0.4493941771132605, 0.8981619306973049, 1.2065795468432563, 0.1755728902561324, 0.23123900751982415, 0.8318190106323787, 0.3485286438039371, 0.1610696656363351, 6.530199306351798, 22.72688708986555, 32.90659557070051, 57.08651426860264, 28.67263432911464, 19.213268177849905, 40.94651249476841, 57.98757055827549, 60.178209032331196, 58.427881377083914, 62.78654888698033, 2.4309189064162116, 0.3486748816711562, 0.019653366479490484, 0.039590336848050356, 0.05683699729187148, 0.04603330504947475, 0.07127219877604928, 0.037222514261624644, 0.08921474777162075, 0.011396867555699177, 0.09763717225619725, 0.025878986343741417, 0.012525457040672856, 0.04600020611126508, 0.06297275197825261, 0.07845421374908515, 0.02131525141053966, 0.053731793737305064, 0.025186507430459772, 0.03708512449104871, 0.018183283042162657, 0.013038281933404505, 0.01343448955698737, 0.03457086726224848, 0.029168639465102127, 0.02183803210833243, 0.05185412449230041, 0.025121003356097, 0.06813409645110369, 0.07730738100196634, 0.050683559982904365, 0.04487099152590547, 0.021331838199070523, 0.06487918432269778, 0.036427630843328576, 0.15135282703808375, 0.0459519012032875, 0.13775954501969473, 0.35625490493008066, 50.56808607918875, 101.09879084995815, 78.64779240744454, 79.2832954951695, 60.554787499564036, 53.674570083618164, 23.871880735669816, 33.59952899387905, 51.82368809836251, 26.12730073928833, 0.08802240568080119, 0.21273068924035343, 0.9789568867002214, 1.3582966114793504, 1.1885236757142204, 1.7183632275887897, 2.2812996549265723, 1.4585492376770293, 1.4555856138467789, 37.34538275854928, 79.53134618486676, 86.78134672982353, 84.0733071735927, 84.44218703678676, 82.54475212097168, 79.92364842551095, 81.19541890280587, 82.08620575496128, 80.71108777182442, 78.47402490888322, 74.73057869502476, 67.90144443511963, 57.887516498565674, 58.588231904166086, 57.44585425513131, 57.91166843686785, 56.79395341873169, 54.398273604256765, 57.264933586120605, 61.59471048627581, 65.81391375405448, 66.51459094456264, 67.36888585771833, 67.53986018044608, 66.76670633043561, 66.72187655312675, 63.50782748631069, 61.57650620596749, 61.77953256879534, 62.85249423980713, 57.7572968346732, 52.092430523463655, 51.6200989314488, 53.06972939627511, 51.76064361844744, 49.68179471152169, 51.04153980527605, 61.322111810956685, 67.69733415331159, 69.06259264264787, 63.65633133479527, 55.518663678850444, 49.510879448481965, 58.59934207371303, 64.15970052991594, 66.21002360752651, 66.29934270041329, 65.8479390825544, 66.70818860190255, 63.29676900591169, 46.62263836179461, 67.00502954210553, 60.72649138314383, 60.148123332432334, 60.66363797869001, 65.5093047278268, 63.8074893951416, 60.625506264822825, 59.94883510044643, 61.056016649518696, 61.2513860974993, 65.54237120492118, 65.08636787959507, 61.793825013296946, 54.38463429042271, 52.126577445438926, 54.334912981305806, 53.67780099596296, 50.29839175088065, 50.659868308476035, 49.32417093004499, 52.14293697902134, 55.79259293419974, 56.77273709433419, 60.10667037963867, 61.5265417098999, 65.92270169939313, 63.36827291761126, 63.89088862282889, 64.12834330967495, 63.92201655251639, 53.156105927058626, 52.34113434382847, 51.96046338762556, 62.57881164550781, 70.75645923614502, 69.18802152361188, 70.28706673213414, 67.02868815830776, 72.25588049207414, 71.97203268323625, 63.75856018066406, 64.85909925188336, 67.33957835606166, 72.1872114453997, 69.41233021872384, 85.74924741472516, 36.06939819880894, 1.5164152468953813, 0.4840573285307203, 0.9628808179071972, 0.6492929277675492, 1.0862436954464232, 0.5841854842645782, 0.6865539997816086, 0.18607125191816262, 6.320427111216953, 27.259890113558086, 33.27427339553833, 44.230338845934185, 16.28699438912528, 22.48224970272609, 51.8914920943124, 61.56188024793352, 68.78636700766427, 64.38056291852678, 76.95733737945557, 4.636558975492205, 0.4928077161312103, 0.034213886596262455, 0.0927552960014769, 0.036597172995763164, 0.06082693247922829, 0.0836167253021683, 0.030267007848513976, 0.020275589876941273, 0.047631061635911465, 0.015439753919573767, 0.01105776713562331, 0.020224211205329214, 0.03722174073170338, 0.04108308335500104, 0.06955099292099476, 0.021480452635192444, 0.017502880355875407, 0.051473897216575484, 0.03736514910789473, 0.037715256214141846, 0.1093871256868754, 0.1418174829866205, 0.1061281966311591, 0.10453368004943643, 0.20578877388366631, 0.14441572928002902, 0.09931075173829283, 0.12109541706740856, 0.09140983569834914, 0.22745114006102085, 0.13967742424990448, 0.11631629137056214, 0.10013030668986694, 0.18609509563871793, 0.20757980777748994, 0.17176801870976174, 0.26085011288523674, 0.42133922395961626, 56.523960317884175, 114.90126923152378, 89.95670127868652, 91.40239211491176, 70.05428123474121, 51.7466082572937, 53.009599685668945, 77.50951072147915, 65.64205701010567, 37.86234610421317, 0.1921584845653602, 0.2036879751831293, 1.4318018215043204, 2.0611809406961714, 1.4596702860934394, 3.2471958824566434, 9.845988239560809, 14.481457216399056, 3.2136525852339606, 38.10899673189436, 84.44322231837681, 91.03437382834298, 90.31728499276298, 87.69509043012346, 87.20226860046387, 82.72768429347447, 86.4153642654419, 85.54957008361816, 85.39639009748186, 82.96285302298409, 77.48433739798409, 71.5776320866176, 60.08346339634487, 60.87994234902518, 61.404475757053916, 59.75528608049665, 62.47349779946463, 56.183849470955984, 61.01238196236746, 63.10551289149693, 68.363082749503, 68.89415441240583, 70.8753776550293, 69.98871803283691, 70.14802633013043, 70.1492005756923, 67.00525883265904, 63.05047621045794, 65.11521680014474, 66.93464429037911, 61.58703967503139, 56.293165479387554, 53.728672231946675, 55.620520796094624, 54.75990997041975, 51.80314227512905, 53.25578130994524, 65.16266604832241, 71.68856702532086, 70.89845957074846, 66.54434313092912, 57.71303333554949, 52.434358324323384, 61.78600134168352, 70.33709376198905, 68.0316606249128, 69.8738295691354, 70.86403819492885, 69.17702252524239, 67.75901331220354, 51.67729650224958, 70.21379797799247, 65.18562984466553, 64.39368111746651, 65.56446647644043, 67.94474560873849, 67.98505905696324, 63.800047874450684, 63.60407393319266, 63.362158502851216, 63.182429449898855, 68.86935629163469, 68.62034675053188, 66.1198012488229, 55.79327733176095, 55.383184228624614, 55.84379768371582, 56.43997744151524, 54.73806830814907, 53.47886364800589, 51.27329349517822, 54.914010592869346, 59.46861035483224, 59.7305782863072, 64.30124228341239, 63.66093799046108, 68.77567373003278, 65.70530646187919, 66.93232359204973, 68.2279611315046, 66.6250673021589, 56.666846547807964, 57.707617214747835, 54.31580890927996, 65.09398310525077, 73.05012907300676, 74.28198214939663, 74.2650146484375, 70.45114844185966, 72.82821750640869, 75.39035878862653, 67.5103233882359, 68.10256004333496, 72.29656219482422, 75.73023687090192, 72.6553602218628, 89.91217027391706, 30.31562273842948, 1.545046601976667, 2.1958978261266435, 5.626106653894697, 0.6801750106470925, 2.315955315317426, 3.236731461116246, 0.9965521139757973, 0.34001837617584635, 10.785032936504908, 37.08284854888916, 46.113081795828684, 79.32336575644356, 40.948624747140066, 29.810554708753312, 56.965528760637554, 73.78285830361503, 76.5541056224278, 74.77240685054234, 83.58176381247384, 4.139854405607496, 0.6713819024818284, 0.14244352653622627, 0.12412195466458797, 0.1262829258505787, 0.16874529447938713, 0.21009798693869794, 0.08751100740794625, 0.23849862654294285, 0.1321847555892808, 0.13348744783018315, 0.0825389606345977, 0.13403863539653166, 0.11254398271973644, 0.12084278490926538, 0.18114170857838222, 0.20635688411337988, 0.1773315580295665, 0.09739985463342496, 0.13685417574431213, 0.09243964829615184], [0.03182594883920891, 0.06513432706040995, 0.022790221996339302, 0.041450784874281714, 0.04094442133126514, 0.05038697232625314, 0.022521247322271978, 0.016326568654871414, 0.059294366144708226, 0.05010813853836485, 0.08731365549777236, 0.0776398495904037, 0.06676971859165601, 0.1421270849449294, 0.01969277748971113, 0.05976054684392043, 0.08999012330813067, 3.813339880534581, 77.72580119541713, 69.71010916573661, 81.03581183297294, 64.44664028712681, 56.45240082059588, 17.665072304861887, 96.10144492558071, 110.12581402914864, 43.31644923346383, 7.313862306731088, 0.14636380331856863, 0.24237726841654095, 0.6087020944271768, 1.3170620926788874, 1.7558348625898361, 0.5942369220512254, 1.7530526518821716, 1.8862939136368888, 11.470838376453944, 70.93720272609166, 74.80666146959577, 78.56200994764055, 80.01649025508335, 83.86094938005719, 77.37923894609723, 81.99787330627441, 76.33649499075753, 74.33120318821499, 72.58218874250139, 76.71195479801723, 74.32410907745361, 72.25120435442243, 64.84697464534214, 56.67063331604004, 52.49165316990444, 54.020579951150076, 50.812343052455354, 51.164835589272634, 55.71877179827009, 60.3477589743478, 63.24298994881766, 67.28816168648856, 65.02950382232666, 64.43409878867013, 62.041576930454795, 63.21396732330322, 58.19788210732596, 59.4154566356114, 55.444533348083496, 53.01936190468924, 48.415759972163606, 49.74544368471418, 47.18280560629708, 49.437509945460725, 48.92280823843819, 48.74170691626412, 50.6422963142395, 58.357461384364534, 62.40936592647007, 61.973929268973215, 64.95358780452183, 58.236750330243794, 51.29725088391985, 52.33191755839756, 53.500236306871685, 60.08189310346331, 59.92012514386858, 59.62969044276646, 60.51554407392229, 60.71265057155064, 47.41432653154646, 60.05149473462786, 53.437337739127024, 54.240764890398296, 57.84058141708374, 62.65574904850551, 56.96759932381766, 57.60478734970093, 59.86962563650948, 62.22203554425921, 62.08022975921631, 61.00910241263253, 60.476682799203054, 54.46158906391689, 50.327119077954976, 48.281472137996126, 51.54432882581438, 51.4055871963501, 48.768422739846365, 46.07792043685913, 45.97035537447248, 46.883150645664756, 49.64139788491385, 52.03955473218645, 56.30273314884731, 57.301977906908306, 56.068307876586914, 57.88552931376866, 56.0557142666408, 55.718740531376426, 51.418208599090576, 49.53255435398647, 51.13109861101423, 48.61034427370344, 58.916513442993164, 65.26220594133649, 64.34155573163713, 66.09422492980957, 65.13895184653146, 61.15514659881592, 66.54363441467285, 60.181030000959126, 61.01502922603062, 60.9141274860927, 66.63752542223249, 68.53594003404889, 67.71774101257324, 81.536728313991, 38.163446290152415, 0.4914224733199392, 0.4993540591427258, 0.9818419090339116, 0.19783793123705046, 0.6676900748695646, 0.1794768821980272, 0.006834486723944012, 0.30234725187931744, 17.417862347194127, 33.36561788831438, 40.08486986160278, 51.429106848580496, 31.082088947296143, 33.73812818527222, 44.5779641696385, 55.34171390533447, 55.59913076673235, 65.83854511805943, 22.296755381992885, 0.47489775717258453, 0.0917238684903298, 0.08933072297700814, 0.08829025737941265, 0.045633580069988966, 0.047014795775924406, 0.06402283920241253, 0.01701206205013607, 0.026539083869595612, 0.044481549744627306, 0.01486571499013475, 0.016668787791526744, 0.08043027735714402, 0.02427981501179082, 0.04710535645218832, 0.008708636492623814, 0.04867560522896903, 0.07912553594048534, 0.09470882546156645, 0.04345330795539277, 0.02911570355562227, 0.02510037080251745, 0.03988483122416905, 0.038306341639586856, 0.015229038262207593, 0.0665175546226757, 0.11586206645837852, 0.029672499213899885, 0.01340669930712985, 0.07258071284741163, 0.03252183399828417, 0.07231534458696842, 0.03150588047823735, 0.083487145469657, 0.024050575348415544, 0.07886153153542962, 0.16563820120479378, 6.744067030293601, 92.56101812635148, 78.12239742279053, 89.16810158320835, 74.60671315874372, 71.66699286869594, 25.843972308295115, 79.15009157998222, 93.21458653041294, 51.413011346544536, 8.324108668736049, 0.22180992205228123, 0.8115181113992418, 1.70806827715465, 1.9506272843905856, 2.0674434389386858, 2.235112156186785, 0.6274598421795028, 0.3848653882741928, 15.430356195994786, 74.71955885205949, 78.06538050515312, 80.73048714229039, 82.94152900150844, 86.04616478511265, 80.29134709494454, 84.29483658926827, 80.30623013632638, 79.91742283957345, 75.5358054297311, 80.39458342960903, 76.69719682421002, 75.25958674294608, 67.78631973266602, 61.06500761849539, 56.47455167770386, 57.863687651497976, 54.49659408841814, 54.55384724480765, 59.569790022713796, 64.45921652657645, 67.17762279510498, 69.24823461260114, 69.01778370993478, 67.80284254891532, 64.88093744005475, 66.3814982005528, 61.79922376360212, 60.510444096156526, 58.04921497617449, 54.93623093196324, 51.71007462910244, 51.43928248541695, 50.78464753287179, 50.85472011566162, 52.03642109462193, 50.316759313855854, 51.65119559424264, 63.14293588910784, 66.45571885790143, 64.01813098362514, 67.40323775155204, 62.074059758867534, 54.47563484736851, 54.091736452920095, 57.54435191835676, 62.88937527792794, 62.22600991385323, 61.17205851418631, 64.54932076590401, 62.49920613425118, 50.22874995640346, 63.80182661328997, 56.4502329826355, 57.62573616845267, 61.59024279458182, 64.94611154283795, 59.87010506221226, 59.647359711783274, 61.33594567435128, 66.7969170979091, 63.83572687421526, 63.68436731610979, 61.81941522870745, 58.42228807721819, 53.59856373923165, 51.05124643870762, 52.51316826684134, 53.24856213160923, 51.48486614227295, 48.7222762789045, 49.77277789797102, 49.930627073560444, 52.42015273230416, 54.66716888972691, 57.93027571269444, 58.4225104195731, 57.85820552280971, 58.26456049510411, 59.60618468693325, 58.25728573117937, 54.25778797694615, 51.44279827390398, 52.411745412009104, 51.20445769173758, 60.73706654139927, 68.07258551461356, 67.22437027522496, 68.58542510441372, 68.21652439662388, 64.76767485482353, 69.31598649706159, 64.09101063864571, 64.09189305986676, 63.70132786887032, 69.37665121895927, 73.55838979993547, 68.48177882603237, 82.07448414393834, 47.897507735661094, 1.8394148520060947, 0.7468765771814755, 0.397762873343059, 1.008385113307408, 0.9959725907870701, 0.7970453937138829, 0.05830339289137295, 0.05055589361914566, 22.599578721182688, 41.95839950016567, 37.329561710357666, 40.317679677690776, 41.012895584106445, 54.2708158493042, 51.216568401881624, 61.25818838391985, 61.95498153141567, 74.68164948054722, 35.693302631378174, 0.5434250171695436, 0.027239235317600623, 0.04038661126313465, 0.07004740914063794, 0.015795048426038454, 0.025326779278527414, 0.03406667163861649, 0.01920193204257105, 0.006707270313719553, 0.018311325992856706, 0.022791531568925296, 0.04834229186443346, 0.03127119896401252, 0.027176194325355545, 0.057447102053889205, 0.0009782094795290114, 0.02496303361840546, 0.041792009957134724, 0.06275116958256279, 0.036226709838956594, 0.16573311468320234, 0.13056118413805962, 0.1703376126076494, 0.14633275355611527, 0.12017255515924521, 0.20225355215370655, 0.1845099971230541, 0.24004318937659264, 0.1845401240778821, 0.17575749249330588, 0.18420929754418985, 0.12569572164544038, 0.14416195718305452, 0.23859060875007085, 0.17983737428273472, 0.24203056416341237, 0.21062560219849857, 7.133072350706373, 104.31208951132638, 88.57204341888428, 101.55204268864223, 83.61521938868931, 76.36699758257184, 27.13946567262922, 121.69865717206682, 129.39445413861955, 66.13083498818534, 12.513087272644043, 0.2645144191171442, 0.7310334358896527, 2.3192025125026703, 4.941581853798457, 6.543912444795881, 6.157983873571668, 7.709015045847211, 6.63546017238072, 15.271084376743861, 78.86398560660226, 77.18352903638566, 83.58741964612688, 83.50527109418596, 91.42293793814522, 83.466201373509, 88.50887039729527, 82.1429864338466, 82.18739931924003, 80.33569744655064, 83.62728146144322, 78.91057327815464, 78.29387201581682, 69.54713916778564, 65.45529638017926, 59.50052343096052, 61.29522228240967, 57.5943546295166, 57.70866639273507, 63.54279082162039, 67.19848128727504, 71.13732474190849, 73.80006899152482, 71.37335504804338, 72.26009110042027, 69.21620341709682, 69.74280044010708, 66.07822322845459, 63.80771173749651, 59.933736664908274, 57.417741843632285, 54.97900404248919, 53.87818704332624, 52.511250564030235, 53.94690820149013, 54.08186306272234, 53.939647333962576, 55.83613729476929, 65.31734684535435, 69.02766404833112, 66.06938511984688, 71.69964245387486, 64.41827079227993, 58.15124579838344, 57.375072956085205, 60.43315928322928, 67.2404067175729, 63.651432854788645, 64.69295392717633, 66.65562547956193, 65.82368986947196, 53.19049951008388, 67.33099733080182, 60.32847077505929, 61.117695808410645, 65.0526899610247, 67.54873997824532, 61.825112751552034, 62.06513132367815, 64.802047593253, 69.25864996228898, 67.42857783181327, 66.84375490461076, 66.48604774475098, 59.682878902980256, 56.944614682878765, 52.903396470206125, 58.09112303597586, 55.62531852722168, 53.64027724947248, 52.08811221803938, 51.87235675539289, 52.50291619982038, 55.84651442936489, 57.452472414289204, 62.9751091003418, 63.5285678591047, 61.22504547664097, 62.69052478245327, 62.586822918483186, 61.79626383100237, 57.693296977451865, 55.287632601601736, 56.50072206769671, 54.42234216417585, 64.18937628609794, 71.93142046247209, 72.38102449689592, 71.15412548610142, 71.8831513268607, 69.55929851531982, 72.33819580078125, 64.59428950718471, 67.87178952353341, 66.33234664372036, 73.75342573438371, 76.52973134177071, 73.96312236785889, 88.10853603907994, 44.91808543886457, 1.3518148107188088, 4.020868676049369, 4.162182007517133, 0.9850559937102454, 2.598685549838202, 0.8115957900881767, 0.10258153480078493, 0.4872582224862916, 31.06196001597813, 50.113819803510395, 53.75656230109078, 74.03698866707938, 42.99806887762887, 51.23274033410208, 59.038169452122276, 71.35575526101249, 70.66274888174874, 85.03160272325788, 34.98201206752232, 0.6733757640634264, 0.3084067867270538, 0.15472387043493135, 0.23811804982168333, 0.14311037718185357, 0.15439133399299212, 0.20144780538976192, 0.05581125929685576, 0.1590070277452469, 0.12066487302737576, 0.13931847922503948, 0.09786309727600642, 0.14846922962793282, 0.14596646678234848, 0.3024997594101088, 0.07798831803458077, 0.13315861618944577, 0.1380122857434409, 0.2369153057890279, 0.0982820587232709], [0.05705344996282032, 0.1228362393698522, 0.03820456138678959, 0.03307133540511131, 0.017931169963308742, 0.011442671213964266, 0.12129240935402257, 0.04948271245562604, 0.017523083736055663, 0.04118261765688658, 0.02751620652686272, 0.1448429213570697, 0.11937193812004157, 0.11228293672736202, 0.07647040127111332, 0.19817945148263658, 0.3911723169897284, 27.47907624925886, 87.04789352416992, 71.81196703229631, 69.57439695085797, 47.71945319856916, 25.90587728364127, 39.877017974853516, 51.99941151482718, 38.95465850830078, 27.661817346300396, 0.34662668300526484, 0.04299780400469899, 0.11982857861689158, 1.268797082560403, 1.8543736721788133, 1.1098426005670001, 0.9331363396985191, 0.8313734573977334, 1.5300382758889879, 48.71418857574463, 78.99752998352051, 78.33881991250175, 78.4988716670445, 78.68634796142578, 72.67282104492188, 80.42314747401646, 77.39353833879743, 74.59011391230992, 74.51636573246547, 76.11067853655133, 71.22634506225586, 75.90120424543107, 71.63437107631138, 72.67455114637102, 62.627657481602256, 52.81721796308245, 51.62066868373326, 52.39538240432739, 52.00645003999983, 52.15260539736067, 58.80869824545724, 59.73446927751814, 62.724841935294016, 60.35284505571638, 60.90088421957833, 58.613439968654085, 58.488191740853445, 55.89204944883074, 51.25595426559448, 50.24036387034825, 49.54565518242972, 47.39424623761858, 50.0919885635376, 49.24802909578596, 50.27481998716082, 48.10872949872698, 49.69285971777779, 56.88323082242693, 62.784686769757954, 63.039018630981445, 59.746121406555176, 61.025270870753694, 63.61270359584263, 58.248197487422395, 52.87704542704991, 51.9095504624503, 54.13411351612636, 56.80236073902675, 56.120384625026155, 60.00021008082798, 60.67214952196394, 51.32282025473458, 59.72490855625698, 54.75746767861502, 54.18924399784633, 55.32338455745152, 58.67021369934082, 56.77734375, 55.49367100851876, 58.092568261282786, 58.59450612749372, 60.83892018454415, 58.94494547162737, 59.39659922463553, 51.99272387368338, 50.785057476588655, 46.22886310304914, 46.097417082105366, 46.25159066064017, 49.204119954790386, 44.86151320593697, 45.503318309783936, 45.74734251839774, 48.869866439274375, 47.221312522888184, 49.04184825079781, 47.243755204336985, 47.46439177649361, 49.363198961530415, 49.469555037362234, 49.14376790182931, 48.79577432359968, 49.18325451442173, 49.28916590554373, 49.158630098615376, 54.82889863422939, 65.70557744162423, 65.72232954842704, 64.81925133296421, 63.30612128121512, 65.92054080963135, 62.829989024571006, 65.89634718213762, 62.92866734095982, 62.263787269592285, 61.2238712310791, 63.90920407431466, 71.51610578809465, 63.589434078761506, 73.12471798488072, 30.694063322884695, 0.6568530563797269, 0.6888661757111549, 1.3609408353056227, 0.09824982830988509, 0.29493262831653866, 0.04882287446941648, 0.11737120976405484, 3.7536305359431674, 19.530387435640606, 30.88042790549142, 34.44502401351929, 17.76020356587001, 14.343147243772234, 37.77122742789132, 52.73296758106777, 63.88951982770647, 58.85814162663051, 59.458097730364116, 2.65370203767504, 0.23129323603851454, 0.02552259769955916, 0.0415354830079845, 0.011084185896574386, 0.05403619133202093, 0.017982046519007002, 0.04230971182031291, 0.012844015661227916, 0.011163844211426164, 0.06263877025672368, 0.052598036359995604, 0.032854221162519286, 0.023077201597126465, 0.034454108348914554, 0.01836897772071617, 0.014592748833820224, 0.07767362027828183, 0.026286821513037597, 0.026974448900935904, 0.05416987290871995, 0.04503783989431603, 0.022331113328358958, 0.008512792626528867, 0.044035799734826596, 0.02755348354444972, 0.07111082279256412, 0.023628945562190244, 0.04703409331185477, 0.08633547941488878, 0.013675210032878178, 0.1158551454011883, 0.0030540708518986192, 0.14167587272822857, 0.10308651413236346, 0.12281521835497447, 0.30511163068669184, 37.1363878931318, 99.92109898158482, 79.33922849382672, 78.56237820216587, 55.558674880436485, 38.602985858917236, 38.97632646560669, 52.32562943867275, 47.31111798967634, 31.6431142943246, 0.36285992765000885, 0.12050306956682887, 0.36032340090189663, 1.2515047533171517, 2.0583530238696506, 2.888118407555989, 1.2570888251066208, 0.4209493648793016, 2.80216897385461, 53.75728491374424, 82.90350151062012, 79.08947549547467, 78.67277118137905, 79.2548495701381, 74.21017946515764, 81.91892092568534, 80.47575923374721, 77.25845840999058, 77.15076133183071, 76.72073037283761, 74.45638193402971, 79.4904282433646, 74.52420330047607, 74.38672624315534, 66.99196692875454, 56.441697120666504, 55.22231258664812, 55.63495567866734, 53.858061586107524, 55.35423455919538, 60.8850006375994, 62.018029485430034, 65.90280205862862, 63.574863706316265, 63.60889598301479, 61.030461175101145, 60.66719545636858, 57.538042954036165, 54.82882915224348, 52.68923561913626, 50.796685286930625, 49.110805647713796, 51.507597173963276, 51.28473023005894, 52.93173469815935, 50.27743598393032, 53.20048407145909, 59.41018295288086, 65.37214033944267, 65.79962130955288, 63.04838480268206, 62.773006847926546, 66.45073699951172, 59.631545611790244, 55.852590629032676, 55.158927645002095, 57.673598834446494, 59.78429480961391, 57.73996455328805, 63.96057210649763, 62.893926348005024, 53.719024658203125, 62.510323251996724, 57.59870072773525, 56.87675857543945, 60.077578272138325, 63.39377280644008, 58.49074172973633, 57.20533888680594, 60.75735528128487, 61.06852340698242, 63.84733036586216, 60.40513719831194, 61.73234735216413, 55.416823932102744, 54.12957286834717, 49.69317238671439, 48.18840101787022, 49.23731844765799, 50.42050634111677, 47.33193826675415, 47.9420804296221, 49.38873359135219, 51.210061413901194, 50.0298820904323, 50.86205741337368, 50.992141587393625, 51.21095425742013, 51.95058652332851, 50.690652302333284, 50.73871299198696, 51.83077873502459, 52.13115978240967, 51.26676566260201, 53.19753108705793, 57.31731605529785, 66.67719268798828, 68.1527190889631, 68.2488682610648, 67.30731787000383, 68.24337918417794, 66.21418557848249, 70.17558983394078, 65.37809494563511, 66.95671871730259, 64.80156121935163, 66.21841703142438, 72.40944262913295, 66.75535297393799, 74.23005131312779, 38.25166061946324, 1.1003730744123459, 0.20942331956965582, 1.196808099746704, 0.9440332864012037, 1.0241358109882899, 0.31737647684557097, 0.2284732445010117, 3.6412427723407745, 31.242168494633265, 35.86979034968785, 37.67517900466919, 23.858510664531163, 24.968525341578893, 45.98361253738403, 58.15047107424055, 73.04142298017229, 63.59515939440046, 75.99791622161865, 5.767111659049988, 0.4355179731334959, 0.13961285485752992, 0.07095138063388211, 0.016737000916951468, 0.07756580106381859, 0.02201710767777903, 0.006966611062775233, 0.0159440021296697, 0.01460712359819029, 0.017780021198892167, 0.0262080758277859, 0.05687129384438906, 0.007901676847333354, 0.04099325888923236, 0.017810173598783355, 0.022630413428747227, 0.036258231183247905, 0.07412489570145096, 0.036992131266742945, 0.14775015892727034, 0.2439358633543764, 0.17218625412455626, 0.14912054182163306, 0.07852167370063917, 0.13979215095085756, 0.15282404023621762, 0.1304942805852209, 0.09252542869320937, 0.26486872296248165, 0.12958824634552002, 0.2549143156835011, 0.16854085187826837, 0.2807563490101269, 0.3017351318682943, 0.24857639148831367, 0.5585702444825853, 43.83702564239502, 112.70406123570034, 92.60040746416364, 89.6644183567592, 66.62899998256138, 36.65193864277431, 58.489178385053364, 69.04156739371163, 52.27672454289028, 43.6921591758728, 0.5966489783355168, 0.1967143586703709, 0.3906145340629986, 3.476308171238218, 4.22492641210556, 5.62810035262789, 7.179591843060084, 3.4899542161396573, 2.3422735716615404, 58.09160940987723, 85.00339998517717, 81.16222735813686, 81.49665110451835, 81.67592157636369, 74.49827262333461, 82.75016866411481, 83.8171340397426, 77.87880052839006, 74.451094354902, 77.72371673583984, 77.94553797585624, 83.6439710344587, 77.01477118900844, 78.43387126922607, 70.06430748530796, 60.29608522142683, 58.900956426348, 58.68411009652274, 57.290899004255024, 58.50311647142683, 64.61622497013637, 64.23034286499023, 69.27911240713937, 66.72703906467983, 66.90224484034947, 63.709144592285156, 65.29980959211076, 62.44223090580532, 57.54467848369053, 55.90720694405692, 53.880281925201416, 51.496935163225444, 53.573915004730225, 54.32351793561663, 55.20471279961722, 52.59643200465611, 54.98928737640381, 63.448225838797434, 69.44412517547607, 69.43152114323208, 67.93394810812813, 66.37322289603097, 69.33446175711495, 64.02629511696952, 60.30490248543875, 58.1674177306039, 60.94317095620291, 62.98687934875488, 60.72685268947056, 67.51104600088937, 67.84390640258789, 56.90223067147391, 64.97187546321324, 61.99569797515869, 60.705299377441406, 62.152497972760884, 68.04031808035714, 60.9509459904262, 59.80848843710763, 62.366182872227256, 63.274826594761436, 67.8082274028233, 65.1028003692627, 66.36184174673897, 58.13937827519008, 56.67233215059553, 51.28457042149135, 51.32372352055141, 50.925365924835205, 54.287842409951345, 50.78634984152657, 51.09831353596279, 52.21298524311611, 53.08598818097796, 52.04806627546038, 53.78035988126482, 54.40230703353882, 53.89745092391968, 56.16205644607544, 53.34143870217459, 55.1636871610369, 53.01400484357561, 55.273131711142405, 54.29685769762312, 56.4044999395098, 60.74787793840681, 71.48857007707868, 71.88051101139614, 72.20055893489292, 69.73940971919468, 67.92056587764195, 68.07551070622036, 73.22815581730434, 69.29686505453927, 70.64721965789795, 66.31332247597831, 69.90069130488804, 77.54448795318604, 69.67103249686105, 80.23264176504952, 37.67728083474295, 1.4200982323714664, 5.467025910105024, 3.319306024483272, 1.3161675121103014, 1.6841902498688017, 0.5315680791224752, 0.2872128268437726, 6.142213199819837, 35.77299846921648, 44.547020367213655, 49.450131348201204, 26.900475433894567, 22.23678026880537, 54.97015898568289, 68.76955931527274, 82.54432133265904, 72.49834483010429, 84.14711788722447, 4.440817798886981, 0.6364469027944973, 0.2659904770553112, 0.17704016795115812, 0.17189889454415866, 0.15530487282999925, 0.17776990522231373, 0.05992714076169899, 0.07492918361510549, 0.11808539501258306, 0.08671459050050803, 0.12035117271755423, 0.0898532560095191, 0.053944572141127925, 0.09258317880864654, 0.06963804896388735, 0.09472480496125561, 0.21080256413136209, 0.17520265440855706, 0.14632846521479742], [0.023494344570540955, 0.05776416789740324, 0.06892378229115691, 0.025773511467767612, 0.04881240128140364, 0.08808217104524374, 0.08550778882844107, 0.027385888787518655, 0.08579166073884283, 0.041631946938910654, 0.0386026171701295, 0.05174014757254294, 0.03234879060515335, 0.062065516731568744, 0.07117651855306965, 0.06790011043527297, 0.9040705593568938, 71.56764752524239, 74.46118313925606, 73.83391366686139, 62.00124263763428, 56.97938346862793, 23.23015206200736, 38.16701071602957, 39.55771350860596, 33.63465561185564, 12.50395039149693, 0.22962854536516325, 0.2356295904942921, 1.7789337145430701, 0.9170740587370736, 1.1629850289651325, 1.057527333498001, 1.4175394496747424, 0.22811834354485783, 27.15113169806344, 81.20039381299699, 78.56759629930768, 80.87060451507568, 73.95328371865409, 77.83759771074567, 74.96262768336705, 78.82506874629429, 73.97165475572858, 71.97918237958635, 67.60891137804303, 71.3316867010934, 79.67345769064767, 73.1044361931937, 71.56098420279366, 72.02041299002511, 65.85995251791817, 55.635904107775005, 50.647882665906636, 52.83737816129412, 49.42278323854719, 52.335120677948, 52.63138491766793, 55.20831544058663, 53.47984334400722, 52.56209748131888, 51.18961981364659, 50.38537972314017, 50.05387422016689, 49.23287507465908, 49.132636887686594, 49.133588790893555, 47.86256524494716, 48.49043573651995, 48.21853535515921, 48.652624062129426, 50.33126367841448, 50.36530637741089, 53.54771334784371, 58.87629726954869, 59.84693281991141, 61.55602986471993, 57.520352840423584, 59.06196008409773, 62.9561961037772, 60.37580190386091, 54.91323239462716, 53.7298812185015, 51.48356335503714, 52.534231730869834, 50.6895683833531, 57.107747963496614, 59.523028646196636, 53.132329191480366, 62.908732959202354, 54.24221706390381, 55.60223313740322, 59.060292516435894, 57.01395770481655, 53.74616779599871, 57.38220528193882, 57.37068864277431, 59.11715657370431, 58.537037576947895, 57.97890962873186, 56.94010877609253, 57.43684938975743, 54.91673081261771, 54.13156352724348, 51.88002061843872, 53.41431140899658, 49.49075746536255, 46.19395535332816, 43.59870937892369, 44.90696832111904, 44.8813989503043, 45.155369894845144, 46.989451135907856, 46.84900024959019, 46.73031806945801, 46.86964682170323, 44.75972209657942, 46.77677025113787, 47.85927874701363, 48.3616543497358, 47.65326813289097, 48.19307368142264, 51.59737832205636, 63.346969740731375, 63.87510231563023, 66.6661867414202, 65.52168641771588, 67.43251746041435, 65.02165235791887, 68.82043402535575, 65.64246000562395, 64.23720073699951, 61.66695090702602, 67.76815714154924, 65.1431416102818, 75.82857472555978, 64.24787317003522, 69.18453352791923, 20.73141482898167, 0.2997791868235384, 0.918821422117097, 0.5439931952527591, 1.1414837198598045, 0.2301747389137745, 0.017258960587371672, 0.8691586841429982, 16.610888140542166, 17.72656559944153, 40.65650510787964, 54.43208006450108, 25.51312862123762, 19.44507919039045, 44.36985172544207, 57.586735929761616, 51.177793979644775, 64.42595549992153, 31.261428901127406, 0.282911729067564, 0.022339011475976025, 0.04065440528626953, 0.020301090919279625, 0.0629415325820446, 0.015546222849349891, 0.04934865429199167, 0.02671006112359464, 0.032996842438088994, 0.01698224213240402, 0.08844211351658617, 0.003619573386718652, 0.01693247158878616, 0.03468764313895788, 0.056451616542679925, 0.011246290457035815, 0.06700193363108806, 0.047918299080005715, 0.06608325828398977, 0.020294705904754143, 0.03497076526816402, 0.0700819669291377, 0.03664653641836984, 0.03125585728724088, 0.03955158571313534, 0.11425659832145486, 0.026598898427827016, 0.02231114065008504, 0.040370608014719825, 0.027099229794527804, 0.020914941194600294, 0.03459878897826586, 0.10424224247357675, 0.028580078189926486, 0.03640341732118811, 1.8501852112157005, 88.98179258619035, 81.54566369737897, 82.5125263759068, 70.42594732557023, 71.6150620324271, 34.73900229590279, 34.96556568145752, 35.19975471496582, 41.36597524370466, 13.67276246207101, 0.18128003472728388, 0.3402425098632063, 3.078636493001665, 2.4932631381920407, 2.919833460024425, 3.378768273762294, 0.19000714857663425, 0.6716652044228145, 31.36078119277954, 85.28290516989571, 81.23890767778668, 84.9019284929548, 77.42775126865932, 81.62198965890067, 77.82706424168178, 80.8606824874878, 75.23121724809918, 73.2873683656965, 69.32423400878906, 77.03248909541539, 80.97363935198102, 75.12898840223039, 76.01188904898507, 76.41016674041748, 69.56107030596051, 57.65411261149815, 52.577505111694336, 55.76528998783657, 50.52872453417097, 55.81765856061663, 58.170704228537424, 58.16338777542114, 55.83096783501761, 55.32518414088658, 53.34239755358015, 52.459312779562815, 53.08525167192732, 50.733984742845806, 50.74041530064174, 51.9126215662275, 51.25070490155901, 49.925360339028494, 49.2945681299482, 51.73347616195679, 52.35183456965855, 52.63751670292446, 56.599393435886924, 61.717290605817524, 61.947748456682476, 65.06830256325858, 63.08122893742153, 61.783208165849956, 62.24677807944161, 62.762862477983745, 56.81474937711443, 55.984589031764436, 54.519467558179585, 55.12265110015869, 53.54548992429461, 59.50827762058803, 61.38628537314278, 56.35440690176827, 66.94254439217704, 58.531221934727256, 56.945292132241384, 61.520628792899, 61.688504219055176, 58.44236142294747, 59.271698406764436, 60.352310044424875, 59.90214320591518, 60.865226064409526, 61.16269929068429, 60.59715066637312, 59.62796034131731, 57.52919789722988, 57.86351047243391, 55.61748095921108, 55.94512326376778, 52.416445868355886, 47.22009311403547, 45.76425443376814, 47.44545793533325, 48.41169875008719, 48.565420695713584, 48.497918946402415, 47.87353297642299, 48.42933675221035, 47.87894214902605, 47.487814153943745, 49.17478813443865, 51.00446074349539, 49.3242369379316, 49.709445067814414, 50.58714846202305, 53.13653979982649, 65.55204309735979, 67.97805527278355, 68.91383171081543, 67.4302453994751, 69.44031756264823, 68.59840433938163, 72.00241715567452, 69.8113374710083, 66.73471682412284, 65.84704276493618, 71.59503732408795, 67.080000604902, 76.40640081678117, 68.34328038351876, 72.08677523476737, 29.454449108668737, 0.38816515835268156, 0.5067170869026865, 0.4037956739110606, 1.8383066143308366, 1.0635250402348382, 0.055904978553631475, 0.3765168562531471, 16.37426028932844, 26.836484261921473, 40.89356027330671, 43.20115430014474, 24.489414044788905, 31.837257385253906, 51.293738569532124, 61.83280440739223, 57.99410533905029, 71.8782320022583, 47.9104939188276, 0.3964220881462097, 0.020805152532245432, 0.05199863888057215, 0.021250373284731592, 0.04012360091188124, 0.019931993314198086, 0.02372188789636961, 0.020559970688607012, 0.033004438637622764, 0.01666826192688729, 0.10991569768105235, 0.021515700833073685, 0.03833091139261212, 0.018298681492784193, 0.01690740480885974, 0.024368613193343793, 0.030160362499633005, 0.020372866353552257, 0.03538036293217114, 0.08537933536406074, 0.16623141723019735, 0.15779017018420355, 0.1205302109675748, 0.08511303072529179, 0.1752676987754447, 0.23169780575803348, 0.06872769924146788, 0.24444810301065445, 0.15504035273832933, 0.08311505722148077, 0.10743343337838139, 0.07887314126959868, 0.15118875727057457, 0.2565311560673373, 0.1191962654037135, 1.858925610780716, 98.37008040291923, 91.35360881260463, 95.42779622759137, 80.2199821472168, 76.33337524959019, 33.65324204308646, 52.879077775137766, 59.100599016462056, 54.15539584841047, 20.608843394688197, 0.3740567596895354, 1.0543995584760393, 6.954136695180621, 4.599755236080714, 3.7743639605385915, 5.965757616928645, 5.118570710931506, 1.2809865027666092, 34.67311947686331, 86.89119774954659, 83.6620363507952, 86.06141608101981, 80.74182660239083, 84.92405155726841, 81.4466449192592, 83.11540767124721, 78.293427331107, 75.01668466840471, 70.64534364427838, 78.77746663774762, 80.03304086412702, 77.27413354601178, 78.57910251617432, 78.80057634626115, 70.83559226989746, 61.50063187735421, 56.97782359804426, 59.02784442901611, 53.53643989562988, 59.71618161882673, 60.181912422180176, 61.13967990875244, 58.53232669830322, 58.36835615975516, 57.20319536754063, 54.29590579441616, 54.4910181590489, 53.05193853378296, 53.48270947592599, 55.31330966949463, 52.682464599609375, 53.9131885937282, 53.613318238939556, 53.894240856170654, 54.93522344316755, 55.74041543688093, 58.674702235630576, 65.23050825936454, 65.17506163460868, 68.99101230076381, 65.74025590079171, 66.28657191140312, 68.75150094713483, 64.62662642342704, 59.92368262154715, 58.304391043526785, 56.31899193355015, 58.217295374189106, 56.28815582820347, 63.24254526410784, 63.57052108219692, 59.95018999917166, 69.88812896183559, 61.116931506565635, 60.07127625601632, 64.33799825395856, 65.60879598345075, 62.508162362234934, 63.22939232417515, 62.17349542890276, 64.39897564479283, 62.08068139212472, 63.21375887734549, 64.45827851976667, 64.28640093122209, 60.864315850394114, 61.07110118865967, 56.85824510029384, 57.9041748046875, 55.86251960481916, 50.83042573928833, 48.728161403111045, 50.356162548065186, 50.72596999577114, 50.165629046303884, 51.34355367933001, 50.9289824622018, 52.305448395865305, 51.752639293670654, 52.40419966833932, 52.43199593680245, 52.30930117198399, 51.4948194367545, 52.76832348959786, 54.79202454430716, 55.89665263039725, 69.95754146575928, 69.76282514844621, 73.49658557346889, 68.61799131120954, 73.54329136439732, 69.16400160108293, 77.06228297097343, 71.58297525133405, 70.64370386941093, 69.03946903773716, 77.216935975211, 70.11046436854771, 83.17069448743547, 69.82206548963273, 75.77333654676164, 26.83242998804365, 0.9922585615089962, 4.371376199381692, 2.53604428257261, 2.932251410824912, 1.5771902714456831, 0.08274215473128216, 1.8954481652804782, 24.276109559195383, 33.31992653438023, 53.45832477297102, 76.16212994711739, 37.194533893040244, 31.62977375302996, 57.25637340545654, 71.84682614462716, 66.40874903542655, 80.69175788334438, 46.206378732408794, 0.35676958731242586, 0.2081326645399843, 0.21076487829642637, 0.12779197416135243, 0.1625744934592928, 0.07694130457405533, 0.12290368575070586, 0.130136068378176, 0.16974317521921226, 0.09183533143784318, 0.26402283406683374, 0.1726025624998978, 0.16157706055258, 0.07885262915598494, 0.12611787899264268, 0.19208163368914807, 0.11412302191768374, 0.13496167372379983, 0.16030427813529968], [0.08317071066371032, 0.043910925542669635, 0.0813225916187678, 0.06046387553215027, 0.01852213155611285, 0.027880869905597398, 0.06511687513973032, 0.0653871288523078, 0.06380549765058927, 0.014333246508613229, 0.07635885011404753, 0.08579799147056681, 0.14905788589801106, 0.040724294393190315, 0.27258722164801186, 0.479192775275026, 13.788910286767141, 84.86023235321045, 67.02684688568115, 75.9250921521868, 49.606500557490754, 22.73912286758423, 26.68395914350237, 66.00019495827812, 44.49288347789219, 31.849983010973247, 1.3478254590715681, 0.05673697105209742, 0.26135125170860973, 1.456932695848601, 0.666324753846441, 2.0247636948313033, 2.078456550836563, 0.753282870565142, 6.521453261375427, 68.91237258911133, 79.48109681265694, 82.39989607674735, 76.33916309901646, 76.66073267800468, 75.11536298479352, 75.77742903573173, 73.69566535949707, 72.31644793919155, 72.80925587245396, 77.36732278551374, 68.21870613098145, 70.1326082774571, 79.76323536464146, 70.3209114074707, 68.48561423165458, 68.34933921269008, 58.6693034853254, 51.187733377729145, 51.49916206087385, 50.24702024459839, 49.49314764567784, 52.47381019592285, 52.771467549460276, 49.737505367824006, 51.35089445114136, 49.406861441476, 49.34915665217808, 50.29367044993809, 49.543011392865864, 49.4885653087071, 49.97206265585763, 48.05105945042202, 48.23155280521938, 45.81530632291521, 48.567942891802105, 50.018660749707905, 48.53569630214146, 54.890911306653706, 55.935006686619346, 58.64474160330636, 61.29336016518729, 62.66211359841483, 57.329034192221506, 58.57687854766846, 62.38613115038191, 59.314582688467844, 54.712022985730854, 55.52633101599557, 51.28624841145107, 49.88817705426897, 58.689418520246235, 59.068359375, 48.796295438494, 60.629140172685894, 56.541796343667166, 54.85787609645298, 56.02191128049578, 59.034466062273296, 54.408855710710796, 52.39346817561558, 54.131122316632954, 54.34754828044346, 56.16100031988961, 61.34467955998012, 58.55556147439139, 60.55393287113735, 59.49185902731759, 58.70583711351667, 61.49688679831368, 60.3569028036935, 59.30904497419085, 51.64601918629238, 43.90288414273943, 44.8432012285505, 43.48145157950265, 46.913173811776296, 45.749083042144775, 44.77085311072213, 44.72226088387625, 45.76791613442557, 46.01758228029524, 45.59633037022182, 46.15155397142683, 46.44911405018398, 47.5657069342477, 46.605702127729145, 49.96380124773298, 57.34402840478079, 64.84552247183663, 64.4348978315081, 66.87864180973598, 63.82131631033761, 66.37167344774518, 65.36881215231759, 65.35907772609166, 64.080491065979, 62.04807349613735, 61.396339416503906, 70.12153284890312, 62.39290564400809, 73.50799451555524, 63.40910748073033, 75.01531587328229, 14.436366881643023, 1.7054667196103503, 0.8535509673612458, 0.8237918870789664, 0.8289380595088005, 0.08890817207949502, 0.10915474779903889, 13.612280998911176, 30.473968710218156, 27.573905263628276, 61.82803794315883, 36.51365212031773, 14.233693139893667, 37.59798451832363, 54.02842446735927, 54.11209120069231, 55.314463070460725, 61.401098932538716, 7.021420444761004, 0.46337237847702845, 0.16510476411453315, 0.06201537299369063, 0.07591281511953898, 0.01669213787785598, 0.026694135906706964, 0.11720517224499158, 0.07872200437954494, 0.07886554846274, 0.028052583370091658, 0.0742215190881065, 0.04038863669016531, 0.017065783363900015, 0.018570680736697147, 0.004335524522632892, 0.0332387198161866, 0.03575880566079702, 0.010028277690123235, 0.06284831544118268, 0.0394116921483406, 0.04849191222872053, 0.020268982642197182, 0.08064369019120932, 0.023384678044489453, 0.06608401145786047, 0.06357170162456376, 0.02118893533146807, 0.026287359252039875, 0.06656799691596202, 0.029096986167132854, 0.0887028066707509, 0.06494745851627418, 0.20893307801868233, 0.48872081828968866, 19.020000559943064, 99.7942943572998, 75.7777486528669, 85.8038672038487, 59.916192463466096, 40.384754112788606, 37.216153212956016, 45.857506207057405, 44.43313591820853, 40.290203026362825, 1.3387693507330758, 0.19707145807998522, 1.156782676066671, 4.592795312404633, 3.5976517285619463, 3.9997200965881348, 3.244159519672394, 0.4722547818507467, 8.796114563941956, 72.90727410997663, 81.52285276140485, 85.44868918827602, 79.25339739663261, 79.82355267660958, 79.17475073678153, 80.10667787279401, 76.68240410940987, 79.64120415278843, 76.44899327414376, 79.94895376477922, 70.16500077928815, 74.1224445615496, 81.07736206054688, 72.21524742671421, 73.27410425458635, 73.09948907579694, 61.4124105998448, 53.52644143785749, 52.617995738983154, 52.8081818308149, 52.84803669793265, 54.518713678632466, 57.04783017294747, 53.15946190697806, 53.60046059744698, 51.65411731175014, 52.279139041900635, 51.90899460656302, 50.78050293241228, 52.376611845833914, 50.46674312864031, 49.458708899361746, 50.64218861716134, 48.51186745507376, 50.90607425144741, 51.89782885142735, 50.546195779527935, 57.44233499254499, 58.30675343104771, 61.72993632725307, 64.17786312103271, 65.22039863041469, 61.88510349818638, 61.0504025050572, 66.30497768947056, 62.66158553532192, 57.69394315992083, 57.7307790347508, 53.134170464106965, 51.919590609414236, 61.161017826625276, 61.28393145969936, 51.323073863983154, 63.33676978519985, 57.4969756262643, 55.733644417354036, 59.052489689418245, 60.422813415527344, 56.58126211166382, 55.93454810551235, 58.230215549468994, 58.354744638715474, 58.10752078465053, 64.80030359540666, 60.24855259486607, 64.45153181893485, 62.973365102495464, 62.002750396728516, 65.94135066441127, 62.72106211526053, 62.26159858703613, 55.59995412826538, 46.60302012307303, 47.44899804251534, 46.3187450000218, 47.43833950587681, 47.47772536958967, 47.78673260552542, 47.25656073434012, 47.14176607131958, 49.70457785470145, 49.08264807292393, 49.9012257712228, 48.912795884268625, 50.89484248842512, 49.729754652295796, 52.821004731314524, 60.064209938049316, 68.1378846849714, 66.2210920878819, 69.42460073743547, 67.04442582811627, 68.70899881635393, 68.19626344953264, 69.04188701084682, 66.80046762738908, 64.70580114637102, 61.38586153302874, 74.39253493717739, 66.0213383265904, 76.15126296452114, 67.15292194911412, 79.21101338522774, 21.907770906175884, 0.5368472986987659, 0.3347437706376825, 1.4259765169450214, 1.60002216058118, 0.3133263827434608, 0.09212843820984874, 8.317985568727766, 36.341767583574565, 32.99927411760603, 51.52670472008841, 35.787183216639924, 24.589056423732213, 54.85422134399414, 60.481219972882954, 63.25544112069266, 60.64734445299421, 73.04852403913225, 14.655826602663312, 0.3961765398936612, 0.1885909102857113, 0.0726136150104659, 0.03408793692610093, 0.06458606397999184, 0.022996856265568306, 0.08933335569288049, 0.05635058267840317, 0.06137307174503803, 0.07482280289488179, 0.05103832183937941, 0.03905234678781458, 0.05009634220706565, 0.021466305180053626, 0.13048676241721424, 0.027365911020232097, 0.014794948876702359, 0.04655084406424846, 0.15336526690849236, 0.09518051586513009, 0.24348591321281024, 0.17935497659657682, 0.1745258564395564, 0.10836902460349457, 0.195415466225573, 0.15758955452058995, 0.15251537465623446, 0.11620121183139936, 0.18632400621260914, 0.1842543522694281, 0.24401856320244925, 0.2563276227031435, 0.38182989401476725, 0.8432563969067165, 22.26491699899946, 112.35730443681989, 84.96014050074986, 96.8102445602417, 68.15111405508858, 35.499666758946006, 35.45615713936942, 93.53329345158168, 61.87470204489571, 51.42427090236119, 2.6513075147356306, 0.24918837579233305, 1.1145034304686954, 4.9607944914272855, 4.853631556034088, 5.742522418498993, 7.057885893753596, 3.1793408606733595, 10.318028007234846, 76.46197250911167, 82.4761803490775, 88.95484052385602, 83.91206727709088, 84.08512605939592, 81.65735598972866, 84.85743917737688, 79.0876133782523, 83.70879077911377, 80.35586111886161, 84.02962384905133, 74.52356406620571, 78.33341421399797, 81.05433573041643, 73.98580128805978, 74.99741731371198, 75.00060653686523, 66.53174604688371, 57.35974175589425, 56.64951079232352, 56.77194847379412, 56.13615703582764, 58.19597135271345, 60.60109724317278, 56.79237617765154, 57.5169551713126, 54.806202343532014, 53.975850922720774, 55.133681365421836, 54.2442980493818, 54.42862680980137, 54.189417702811106, 52.18689823150635, 53.81526068278721, 51.3192731993539, 54.06235946927752, 55.70241921288626, 53.42797156742641, 60.927891867501394, 59.96498271397182, 65.37086881910051, 66.54621914454869, 69.19175965445382, 64.82824230194092, 63.802132334027974, 69.56796986716134, 64.06853321620396, 61.2862799508231, 60.365643637520925, 55.91383899961199, 54.19288485390799, 65.257203238351, 66.86364759717668, 55.31186791828701, 65.29441084180559, 61.67965221405029, 58.212073802948, 62.247570174080984, 62.911213466099326, 60.546442713056294, 60.43429183959961, 60.47657857622419, 62.73518085479736, 62.76366152082171, 68.12157031467983, 62.172564370291575, 67.89975602286202, 66.23345293317522, 63.76244422367641, 68.44566903795514, 66.47358962467739, 66.00462096078056, 59.030192920139854, 48.66019759859358, 49.99158361979893, 47.40523133959089, 51.598330225263325, 51.08360072544643, 50.38378163746425, 50.762899671282085, 50.74644981111799, 52.148822103227886, 52.11553675787789, 51.69587598528181, 51.840801511492046, 53.46354981831142, 52.339765548706055, 55.445210797446116, 62.197619574410574, 71.83060904911586, 69.25468948909214, 73.0457239151001, 70.50143255506242, 72.93549074445451, 70.45424733843122, 71.55543954031808, 69.51275948115757, 68.78443540845598, 64.0580483845302, 77.4601993560791, 67.8242221559797, 80.16828754970005, 70.00052302224296, 84.65768541608537, 19.66891540799822, 3.656461715698242, 5.0794588668005805, 2.160551254238401, 1.8342128225735255, 0.2579169417066233, 0.2605684665696961, 19.535346712384904, 43.345190456935335, 43.410493101392476, 82.58205699920654, 54.171046665736604, 21.511732271739415, 54.87762287684849, 66.61333874293736, 71.77550288609096, 71.0734430040632, 84.57148606436593, 12.241004501070295, 0.6303430731807436, 0.3627174895788942, 0.14241512306034565, 0.13097013719379902, 0.17433670801775797, 0.08500546935413565, 0.16417855024337769, 0.2257537982825722, 0.20788041236145155, 0.1794025283306837, 0.13683954652931007, 0.12280642454113279, 0.10654088841485125, 0.12870358595890657, 0.20822094194591045, 0.18045927876872675, 0.07801089289465121, 0.19931421987712383], [0.022501408654664243, 0.05025585900459971, 0.037198721431195736, 0.044975709835333486, 0.0535344757538821, 0.00998551641324801, 0.08130927876170192, 0.02723000893768455, 0.050736166802900176, 0.02892482826220138, 0.03796066197433642, 0.03520182679806437, 0.012214112095534801, 0.010879438802866, 0.11628168608461108, 0.1427381464413234, 38.66134030478341, 82.16276795523507, 62.97506046295166, 62.33565248761858, 52.66470847811018, 22.31907994406564, 47.61051934106009, 55.49449437005179, 30.493569578443253, 16.46377566882542, 0.026728439244574735, 0.15620516666344234, 0.44164411297866274, 0.731442891061306, 2.9207640843732015, 4.090330685888018, 2.577692653451647, 0.5146792339427131, 34.52313913617815, 82.54593331473214, 72.78331824711391, 73.11560889652797, 67.85348102024624, 75.54430307660783, 73.0827647617885, 72.6872455051967, 73.46196964808873, 70.49634647369385, 69.00737530844552, 72.74078832353864, 73.34268992287772, 66.47924545833042, 67.67519719260079, 80.95285034179688, 65.98155294145856, 72.95803764888218, 59.204286984034944, 51.587567465645925, 49.18540150778634, 48.95035089765276, 47.406495911734446, 49.993584700993125, 50.18105057307652, 50.105440276009695, 48.972932543073384, 49.48646000453404, 46.57772520610264, 48.77495404652187, 47.45807238987514, 48.33242327826363, 46.362431798662456, 46.611024447849815, 45.83898230961391, 47.11608900342669, 48.29661226272583, 46.46234689440046, 46.13997132437569, 51.508392742701936, 52.732630593436106, 57.72144065584455, 60.24117360796247, 61.67794990539551, 60.64091736929757, 58.639252526419504, 56.9309058870588, 61.73580060686384, 58.03323759351458, 57.03508717673165, 49.92916447775704, 53.15550490788051, 63.1323607308524, 57.759343079158235, 46.67433295931135, 59.74472481863839, 49.39864519664219, 57.79868030548096, 57.40437698364258, 61.77612100328718, 57.121220520564485, 58.865826334272114, 55.14333241326468, 56.57694728033883, 54.86987910951887, 51.13449975422451, 54.9746926852635, 57.887929916381836, 58.51739501953125, 60.571748052324565, 58.525698116847444, 61.12361567361014, 56.67748771395002, 56.293071678706575, 46.68008606774466, 45.17789248057774, 45.608639104025706, 45.09623030253819, 42.87889684949602, 46.33179719107491, 44.518129757472444, 46.723025935036794, 45.13418483734131, 46.27569048745291, 45.411991187504356, 47.60679510661534, 45.55902549198696, 48.819839409419465, 47.92403595788138, 50.91784797395979, 60.177048683166504, 61.87696715763637, 60.12784154074532, 63.245275906154085, 61.533844266619, 61.648343631199424, 57.6477689061846, 59.67315142495291, 55.95821019581386, 55.91128553662981, 56.84237194061279, 69.13448565346854, 63.025511332920615, 72.53271756853376, 61.78800937107631, 77.89749813079834, 7.323310119765146, 0.8322256973811558, 1.287167251110077, 0.40739988908171654, 0.09712457976170949, 0.07725522201508284, 0.9151020731244768, 35.06078379494803, 31.921643257141113, 34.587576729910715, 46.34305327279227, 20.34326239994594, 9.605676974569048, 31.647561141422816, 55.17028794969831, 54.35965551648821, 64.26574393681118, 46.96749482836042, 1.5793303166116988, 0.2024427412876061, 0.017984686020229543, 0.0732503387012652, 0.025698892971766845, 0.026103807047807744, 0.032145182602107525, 0.052380056985254796, 0.06094140812222447, 0.04315809093947921, 0.013056894148966032, 0.020407076392854964, 0.02854749493833099, 0.0711091739524688, 0.04452396836131811, 0.028254993758829575, 0.05078065495139786, 0.0329971409934972, 0.029748607094266584, 0.04488638070012842, 0.02311925550124475, 0.08793351759335824, 0.09186159752841506, 0.03874030888878873, 0.08022216388157435, 0.04288602214572685, 0.035798493174037764, 0.032950505281665494, 0.030453703366219997, 0.02519140306061932, 0.0642267321901662, 0.03726821359513061, 0.07616863639226981, 0.061850475413458686, 53.68882431302752, 90.53890473502022, 71.21711785452706, 68.97124467577252, 61.1245675768171, 27.838336331503733, 29.273622240339005, 46.1977664402553, 38.501910414014546, 17.89772752353123, 0.0591728337375181, 0.07623198442161083, 3.0480207758290425, 1.8437359801360538, 4.626902716500418, 3.876002209527152, 0.8270336017012596, 1.0835309667246682, 39.46439225333077, 84.13711248125348, 77.23923969268799, 79.26686300550188, 72.6804084777832, 77.67993613651821, 77.36553015027727, 77.75290611812046, 74.31609780447823, 74.62035247257778, 73.28061471666608, 75.90514387403215, 74.69325297219413, 70.09965297154018, 72.4848861694336, 81.61147703443254, 69.74671227591378, 75.09867341177804, 61.85845715659005, 54.76286990301949, 51.636618273598806, 53.947776726314, 50.07804352896554, 53.18217209407261, 52.338351590292795, 53.4598776953561, 49.994751998356406, 52.09338937486921, 49.18037796020508, 51.735755171094624, 49.807949679238455, 49.99159056799752, 48.09522220066616, 49.177452768598286, 47.931904792785645, 50.650272846221924, 50.91062184742519, 48.2184658731733, 47.78110803876604, 53.25013242449079, 55.35673243658883, 60.062743868146626, 60.86380863189697, 63.5166516985212, 63.37336594717843, 59.65268898010254, 60.93962737492153, 64.33647659846714, 62.05807890210833, 59.67167145865304, 53.71356684820992, 55.95371471132551, 65.26284517560686, 60.06195177350725, 50.03432893753052, 63.98379298618862, 52.52614055361067, 61.340969221932546, 62.53572586604527, 63.21105602809361, 58.962399346487864, 61.78541769300188, 59.29079205649239, 60.97408349173409, 58.674438204084126, 54.63879592078072, 55.65163830348423, 60.39058767046247, 60.61909307752337, 62.8830246244158, 59.984361239842, 64.27601337432861, 59.66181891305106, 60.546665055411204, 50.411616121019634, 48.78623792103359, 48.11399623325893, 47.94365072250366, 45.79560817990984, 47.33954654421125, 46.3464092527117, 48.81376668385097, 47.12298509052822, 49.24053198950631, 47.75413860593523, 49.151640210832866, 47.7631573677063, 50.71341807501656, 49.686477797372, 54.041038921901155, 62.245110511779785, 65.60717010498047, 62.538157735552105, 65.07368741716657, 62.37696647644043, 62.51221316201346, 60.006713594709126, 61.06724493844168, 57.90204518181937, 59.792153222220286, 57.741500105176655, 71.22324616568429, 65.4322908946446, 75.97717584882463, 64.78193255833217, 83.65886102403913, 10.842750753675189, 0.6397179301295961, 0.5385972676532609, 1.4545526121343886, 1.3640188872814178, 0.11846021775688444, 0.17825365997850895, 32.2991076196943, 40.21571486336844, 30.71033947808402, 32.57960639681135, 21.10033290726798, 21.548747062683105, 41.572152614593506, 59.81279632023403, 62.03791522979736, 69.18159443991524, 64.50431033543178, 4.285137329782758, 0.29269091146332876, 0.06005990292344775, 0.1032843410170504, 0.02650607144460082, 0.06046194170734712, 0.040570124451603205, 0.002538424525742552, 0.047586295288056135, 0.07001141285789864, 0.039173567068896124, 0.04092934089047568, 0.033280303834804466, 0.07324158559952464, 0.03097509645989963, 0.07628965989819594, 0.047665575319635015, 0.0351553200078862, 0.07636196458978312, 0.17264528306467192, 0.1644759928541524, 0.12186715565621853, 0.11982887717229979, 0.09158818184265069, 0.1958474080477442, 0.18383086499358925, 0.16181456137980732, 0.0924295788364751, 0.12062515158738409, 0.13149442763200828, 0.1804247141948768, 0.14219602410282406, 0.25037366790430887, 0.1541491648448365, 59.79200036185128, 103.95069980621338, 82.71936729976109, 79.93040207454136, 70.76545020512172, 32.98400892530169, 63.76445920126778, 76.19460582733154, 45.99972888401577, 27.648223195757183, 0.17222301715186664, 0.31667579444391386, 3.854018977710179, 6.0895558425358365, 6.79022695337023, 15.036714690072195, 11.321175915854317, 1.346143669315747, 43.34373828342983, 87.79522786821637, 83.97166892460415, 85.31900800977434, 79.05376175471714, 83.17143794468471, 82.43918119158063, 81.44814573015485, 77.57134968893868, 78.07193960462297, 76.39259474618095, 79.39185414995465, 78.1202643258231, 72.12438583374023, 75.94898700714111, 81.09577478681291, 72.43618624550956, 79.93240315573556, 65.44949463435582, 56.24620260511126, 53.98549154826573, 55.34933607918875, 53.07689298902239, 56.89597034454346, 55.762198039463584, 56.30345228740147, 53.103369099753245, 54.14346579142979, 51.54870619092669, 53.56721346718924, 52.7987322807312, 53.70926243918282, 52.00945513589041, 51.68152448109218, 51.78222472327096, 53.5212094443185, 52.34336471557617, 50.18538972309658, 51.06100170952933, 57.19611515317644, 58.591275215148926, 62.342711857386995, 64.63706261771065, 66.079744883946, 66.7734808240618, 62.06666687556675, 61.850661277770996, 67.77639770507812, 64.04308196476528, 63.827180589948384, 55.588458333696636, 58.19592618942261, 69.6128065926688, 63.86445072719029, 53.3452775818961, 67.5524572644915, 54.63685737337385, 63.66358525412423, 62.96349171229771, 66.14895589011056, 63.5599250793457, 63.78446306501116, 61.17820766993931, 63.045313698904856, 61.796687671116416, 57.132275104522705, 58.33849975040981, 62.04758712223598, 63.18529905591692, 65.82036168234688, 64.85040705544608, 67.73278386252267, 62.016195161002024, 61.99577440534319, 53.39341122763497, 50.79466683523995, 52.640198707580566, 50.54032802581787, 47.79713405881609, 50.6647389956883, 50.23595176424299, 52.66746343885149, 50.49225691386631, 52.84994397844587, 49.939433915274485, 51.83011865615845, 50.59255416052682, 53.985189301627024, 53.08492858069283, 56.47765404837472, 66.77220235552106, 66.49961757659912, 64.68818051474435, 68.84435667310441, 68.40580722263881, 67.460143498012, 64.29548222678048, 65.44096224648612, 60.973409516470774, 62.267671312604634, 62.31268869127546, 78.01760469164167, 69.4922900881086, 80.2286604472569, 68.80707263946533, 85.61565440041679, 8.061254841940743, 2.4031610701765334, 5.932354152202606, 1.9287613034248352, 1.1798667630978992, 0.14994095851268086, 1.9395407821450914, 45.167136669158936, 46.0896246773856, 47.22761801310948, 60.84361021859305, 28.14446701322283, 17.622752564293997, 44.68797847202846, 71.54864420209611, 67.79904188428605, 79.74491991315568, 68.10239328656877, 2.824800559452602, 0.288237061883722, 0.1394479844186987, 0.1763827625129904, 0.18170407840183803, 0.18710637065981114, 0.14338473603129387, 0.1313439964183739, 0.19942913656788214, 0.17832901807768003, 0.12242763915232249, 0.10584797523915768, 0.08863578776695899, 0.13990505917796067, 0.11625472110296999, 0.15624232324106352, 0.1581049697207553, 0.2243800905666181], [0.03427286146740828, 0.022657580274556364, 0.03118308779916593, 0.08222675988716738, 0.05638193099626473, 0.03652084119884031, 0.036917302424886396, 0.051816733820097785, 0.04629720428160258, 0.07317967606442315, 0.10770522058010101, 0.14289655722677708, 0.06046765497220414, 0.029195010728601898, 0.04691113598112549, 1.2201912850141525, 73.27317319597516, 69.22829328264508, 76.0116389138358, 61.16635404314314, 38.96410805838448, 31.82555661882673, 78.67050606863839, 42.85310166222708, 33.169994831085205, 2.9422731016363417, 0.047919496694313626, 0.14199904538691044, 2.2437177172728946, 5.178822449275425, 4.239401246820178, 3.9132575818470547, 0.9524235618965966, 7.6934128659112115, 63.97243962969099, 69.49992615836007, 74.02546855381557, 74.28128732953752, 74.65472521100725, 67.42997441973004, 71.66135093144008, 73.35015228816441, 73.46285206930978, 67.48523344312395, 69.35523687090192, 71.18020902361188, 66.11068521227155, 70.71515914372036, 62.348791531154085, 75.47133309500558, 71.76818643297467, 66.92141492026192, 61.49747044699532, 48.951090880802695, 51.24993712561471, 49.44623340879168, 47.621799741472515, 48.21163231985909, 49.149958746773855, 47.93222093582153, 48.256948471069336, 49.19387136186872, 47.15234817777361, 48.078181743621826, 46.45706278937203, 47.45369849886213, 45.27964537484305, 44.92057636805943, 44.46133518218994, 49.80278716768537, 48.117393902369905, 46.056613785879954, 45.37740305491856, 47.64731352669852, 50.55942862374442, 52.78261246000017, 58.15878806795393, 58.46719428471157, 62.702475684029714, 56.88788958958217, 56.79275138037545, 60.13542202540806, 62.17237676892962, 58.17274699892317, 55.14020572389875, 50.188603264944895, 60.85697160448347, 55.61686256953648, 46.38570826394217, 60.15427943638393, 52.652441433497835, 58.97892911093575, 61.46798924037388, 58.80033956255232, 54.75117608479091, 56.0231237411499, 57.35782057898385, 55.69967467444283, 53.24185364586966, 50.386567865099224, 51.52883781705584, 54.99596459524972, 53.510964325496126, 56.0969101360866, 60.201617513384136, 61.87905856541225, 57.200600215366904, 53.25210223879133, 48.07899120875767, 44.1998918397086, 45.2846793447222, 44.18253523962838, 43.82376847948347, 45.40471642357962, 43.60309369223458, 46.66152742930821, 46.65831388745989, 46.80370494297573, 44.75545242854527, 46.81416198185512, 46.80005366461617, 48.77713925497872, 47.91666044507708, 49.27511664799282, 51.51423270361764, 54.53577845437186, 53.075197628566194, 49.27630826405117, 46.412733282361714, 47.565762519836426, 46.58336366925921, 48.400282859802246, 47.440958976745605, 49.356448786599294, 48.15861061641148, 51.99094860894339, 56.79106296811785, 64.20255007062639, 66.19347994668144, 70.78695487976074, 59.31836945669991, 0.4248871478651251, 2.165509445326669, 1.7523944186312812, 0.44222757167049814, 0.17119552514382771, 0.07518420421651431, 11.649552992412023, 62.91336045946394, 28.15701719692775, 59.14541489737374, 58.7221862248012, 25.63844633102417, 34.67788594109671, 45.16445466450283, 56.33225951875959, 54.13018083572388, 63.65749168395996, 29.95156839915684, 0.371046886912414, 0.05496723637250917, 0.02924315957352519, 0.029468222853860686, 0.03298755668635879, 0.03110702063090035, 0.034452048995132954, 0.010841378925501235, 0.03073344299835818, 0.03206514261130776, 0.062370301091245244, 0.04376360880477088, 0.030438558464603763, 0.0327564205176064, 0.055323267089469094, 0.02885379582377417, 0.013011810585989483, 0.04649907862767577, 0.04143285797908902, 0.04109220286565168, 0.014896598511508532, 0.03810713393613696, 0.0298993097219084, 0.04415435676595994, 0.03868124241541539, 0.042450348380953074, 0.0205629392793136, 0.054426257365516255, 0.0039418588608636385, 0.021398047949852686, 0.05950978744242873, 0.13558216685695307, 3.2973842407975877, 89.67331899915422, 74.59210109710693, 85.740145274571, 71.5455105645316, 52.72797530038016, 34.30111639840262, 54.23117985044207, 41.14873286655971, 38.15015091214861, 3.340206857238497, 0.3167572186461517, 1.1110349765845706, 2.4563586499009813, 3.6938347731317793, 4.982196245874677, 3.496826635939734, 0.7972867893321174, 10.353132912090846, 70.85326848711286, 74.69370460510254, 79.29007693699428, 77.70970221928188, 80.13842419215611, 72.83727100917271, 76.48089940207345, 75.16220773969377, 76.31058515821184, 70.59346839359829, 74.96794305528913, 73.59666742597307, 72.54901109422956, 74.09827177865165, 67.47199712480817, 77.67585754394531, 74.32809734344482, 71.10852445874895, 63.77923107147217, 52.06977244785854, 54.76851531437465, 51.27235548836844, 50.51657560893467, 50.63390289034162, 51.14798968178885, 50.75367941175188, 52.28702872140067, 51.01649154935564, 49.92071894236973, 50.37389782496861, 49.78248105730329, 49.34408099310738, 46.8283189364842, 47.7232642854963, 49.264402525765554, 51.42498309271676, 52.15607254845755, 47.142200333731516, 48.84027753557478, 48.224344049181255, 53.02211339133126, 55.152007239205496, 60.61889157976423, 61.266783305576865, 66.63095242636544, 58.64476244790213, 58.899518149239675, 62.97081511361258, 65.9081313269479, 58.96018981933594, 58.567554065159385, 53.13971165248326, 64.67748028891427, 59.67970357622419, 49.60312025887625, 63.01371329171317, 54.247435161045615, 61.837181772504536, 63.35611357007708, 62.69930035727364, 58.09359312057495, 58.52622617994036, 58.0123165675572, 56.91080822263445, 53.252216884068076, 53.09633404867989, 53.937305791037424, 55.58204862049648, 54.422574928828645, 59.21287495749337, 60.70982960292271, 63.48705237252371, 60.28032670702253, 55.49814564841134, 50.026335035051616, 46.53027595792498, 46.73571334566389, 46.34891407830374, 45.268827029636924, 47.305611542293, 47.3624130657741, 46.96906859534127, 47.83893442153931, 47.462911810193745, 48.98434495925903, 48.01952852521624, 50.24691949571882, 50.04841293607439, 51.5904301234654, 50.025622844696045, 53.92975309916905, 57.35675403050014, 54.296941076006206, 51.25992168698992, 47.530559471675325, 49.946371691567556, 48.83553539003645, 50.39763287135533, 49.59926748275757, 50.47052642277309, 52.755986962999614, 53.52782760347639, 60.59161990029471, 65.57884924752372, 70.0134744644165, 71.75444289616176, 67.1384141104562, 0.9948805293866566, 0.8321979588695935, 1.8615001354898726, 1.2506930083036423, 0.4035091692847865, 0.04300465042303715, 8.425232751028878, 71.53170449393136, 34.60591997419085, 44.916185106549946, 36.50124263763428, 28.135408299309866, 45.71426214490618, 53.65381234032767, 63.29729012080601, 58.41430459703718, 69.08242280142647, 46.80607427869524, 0.4811340911047799, 0.024461426605869616, 0.031648664602211544, 0.02522667670356376, 0.01686357144665505, 0.06728787507329669, 0.013104187191597052, 0.08043537994048425, 0.05452461101646934, 0.029205565340816975, 0.043170138328735314, 0.0450909182961498, 0.04714978013985923, 0.07443997343736035, 0.058450051450303624, 0.06418445267315422, 0.009451690861689193, 0.1659016627818346, 0.18361776428563253, 0.2716862628502505, 0.11771510488220624, 0.23461846475090298, 0.09285374464733259, 0.1446315169866596, 0.11349028801279408, 0.10524137850318636, 0.1731491360281195, 0.3157834666115897, 0.19984282579805168, 0.14825969801417418, 0.16327470088643686, 0.22382628385509762, 3.5471235598836626, 98.55006653921944, 86.88848100389752, 95.1083458491734, 79.57871205466134, 54.21592160633632, 44.83232382365635, 107.5879636492048, 59.23656831468855, 52.27636323656355, 4.984722784587315, 0.2304909090910639, 1.459239280649594, 6.088470620768411, 9.616558722087316, 9.197799478258405, 14.281638315745763, 5.576079624039786, 14.124897377831594, 75.31510979788644, 76.5448019845145, 82.61810425349644, 82.04934556143624, 82.9076704297747, 76.56299236842564, 82.37024811335972, 78.8584895815168, 79.89306940351213, 74.95552662440709, 77.52102388654436, 75.43060970306396, 75.610887663705, 74.20212650299072, 72.23529992784772, 81.37120137895856, 75.73565646580288, 74.97516918182373, 67.82704312460763, 54.734291962214876, 56.97718783787319, 55.60665566580636, 53.37871578761509, 54.33690711430141, 53.531089782714844, 53.77426978519985, 53.49747092383248, 54.79683269773211, 50.607260022844585, 53.18736934661865, 51.21064853668213, 50.61249896458217, 50.21026427405221, 49.74309866768973, 50.94638075147356, 54.287025996616904, 55.06398398535592, 49.62004607064383, 50.509262629917686, 51.851116112300325, 57.258860860552105, 58.31286784580776, 63.833079610552105, 65.11869784763881, 70.98795931679862, 60.74323654174805, 62.305281911577495, 64.84987899235317, 69.12709971836635, 63.060891560145784, 60.54883289337158, 57.52971206392561, 66.82653032030377, 61.899951798575266, 54.32433087485177, 66.43103885650635, 59.50432409558977, 65.11338247571672, 67.31996359143938, 63.20750549861363, 59.69432258605957, 61.39350455147879, 62.239538056509836, 58.5318820135934, 56.31060545785086, 54.58077151434762, 55.42611367361886, 56.51577533994402, 55.456185477120535, 60.59134892054966, 62.45297976902553, 64.89570931025914, 61.14312621525356, 58.25531939097813, 53.213935783931184, 49.20017685209002, 48.5482690674918, 48.0541444505964, 47.983040060315815, 50.621246746608186, 49.647852761404856, 49.6176871572222, 49.586357729775564, 50.654212474823, 50.80553034373692, 52.34846816744123, 52.81390019825527, 52.85651697431292, 54.31247724805559, 54.933229310171946, 57.66287081582205, 62.75331565311977, 58.98361219678606, 55.15394926071167, 51.40982559749058, 53.126916544778005, 51.9547415460859, 54.99795872824532, 52.20995235443115, 53.411740575517925, 55.84807429994856, 57.675658975328716, 64.48778751918248, 70.3773307800293, 72.995988709586, 77.11023248944963, 66.70931421007428, 0.6168499972139085, 5.995983149324145, 4.992034895079477, 1.332916036248207, 0.6222454905509949, 0.09930758297975574, 15.315865516662598, 76.10241712842668, 43.74747725895473, 75.80080277579171, 78.31704425811768, 35.39380400521414, 48.90906122752598, 60.646017347063335, 74.6994160243443, 66.7850148337228, 82.40412752968925, 45.82090309688023, 0.4385715164244175, 0.19785927794873714, 0.07270306628197432, 0.1988792246473687, 0.1313953208071845, 0.15699837410024234, 0.11824114594076361, 0.1558250920580966, 0.13553437085023948, 0.15614038013986178, 0.08543399135981287, 0.15768210669713362, 0.11051501373627357, 0.17654711726520741, 0.19049663016838686, 0.16664102167955466, 0.09718578362039157], [0.045607178272413354, 0.009243274589867463, 0.10750564307506595, 0.0614524060594184, 0.08221474303198711, 0.10041177658630268, 0.0808931535908154, 0.05616402965305107, 0.009023269788095993, 0.07546019154999938, 0.07393801358661481, 0.17805053373532637, 0.18323686186756405, 0.38067757870469776, 0.527390963264874, 18.818111964634486, 78.22514738355363, 62.85780266353062, 64.21441064562116, 52.49581166676113, 24.27500479561942, 35.60740900039673, 46.31178290503365, 32.917712688446045, 18.310976845877512, 0.10680882153766495, 0.24392636386411531, 0.15648670441337995, 1.7120897642203738, 1.8635298780032565, 4.4168621471949985, 0.7388378913913454, 0.2149884330907038, 32.862943513052805, 71.84457492828369, 73.64708355494908, 80.65151391710553, 76.68513475145612, 79.6359235218593, 75.65873295920235, 70.48745277949742, 65.96222305297852, 73.12987354823521, 65.30695234026227, 71.97566659109933, 70.15515518188477, 72.50374358040946, 69.347795350211, 66.96827357155937, 67.44041061401367, 75.31797245570591, 63.693802969796316, 61.271021706717356, 45.404824120657786, 51.16179575238909, 49.06771986825125, 51.25436312811715, 47.297794818878174, 49.5230005809239, 46.22079624448504, 49.81235831124442, 47.719171796526226, 47.81632498332432, 45.52435050691877, 46.23011377879551, 45.23922075544085, 46.43988684245518, 45.05335296903338, 45.95624705723354, 46.15110233851841, 47.12334639685494, 42.960663250514436, 44.084631647382466, 43.39454698562622, 50.75629540852138, 50.028197152274, 55.961479323250906, 54.82387508664812, 63.26369558061872, 56.52083362851824, 55.20408398764474, 55.93232120786394, 62.216796602521626, 58.91912596566336, 56.59885842459542, 50.474010944366455, 60.89390127999442, 53.66327231270926, 43.521514892578125, 59.37069634028843, 53.87363944734846, 61.18648297446114, 58.87546348571777, 58.347601890563965, 56.68281350816999, 55.33993169239589, 56.203255789620535, 54.80427769252232, 56.21129138129098, 54.58642039980207, 55.28234849657331, 53.966641085488455, 56.03372321810041, 55.53653791972569, 57.652326924460276, 58.28114931924002, 55.401329449244905, 53.88933890206473, 49.10088014602661, 45.95211982727051, 47.37920338766915, 43.53364297321865, 45.997196265629356, 43.31701898574829, 45.86497899464199, 44.08554880959647, 44.245482444763184, 43.394352436065674, 46.62816217967442, 43.86361639840262, 48.030930519104004, 46.16643353870937, 47.32048763547625, 44.98864092145647, 47.935882636478965, 45.52929762431553, 47.4621753011431, 41.83749737058367, 46.076301506587434, 46.49965524673462, 50.08734021868025, 49.0692206791469, 54.7278961454119, 53.69977467400687, 54.14698505401611, 52.10721976416451, 52.42964397157942, 49.91999980381557, 62.24854292188372, 60.06566905975342, 79.63253280094692, 16.95477707045419, 0.8982133365103177, 0.6960293341960225, 1.8659947514533997, 0.14778293216867106, 0.057104319733168395, 0.6844377304826463, 49.04338380268642, 53.96692943572998, 28.435660805021012, 78.91271332332066, 39.46094594682966, 19.083962202072144, 31.160891941615514, 39.046875, 54.44723408562796, 54.25725643975394, 66.20478466578892, 11.69125086920602, 0.3682563437947205, 0.04878335998260549, 0.12050866069538252, 0.032000142349196334, 0.06639106212449924, 0.025955211271398833, 0.12563031086964266, 0.03593208993385945, 0.02441644821582096, 0.06920543539204768, 0.026010216712685566, 0.04870524363858359, 0.05965627636760473, 0.04369052040523716, 0.036428210990769525, 0.029286480641790798, 0.08322418600853, 0.016899599959807735, 0.0440474467884217, 0.10362650587090425, 0.05155083290966494, 0.08138717458184276, 0.08510142777647291, 0.01881897875240871, 0.007010301508541618, 0.013488303321147603, 0.10072454730314867, 0.16727743324424538, 0.19933625869452953, 0.3421849656317915, 0.4488720308457102, 26.912066766193934, 93.69978618621826, 70.22275420597622, 74.18078858511788, 61.07619421822684, 38.789023876190186, 34.576445715767996, 40.572369371141704, 39.896875926426475, 22.302901063646587, 0.04951915317880256, 0.5010876889739717, 2.4106518796512058, 2.4535504920142035, 7.213172486850193, 3.7799420612198964, 2.1990801010813033, 0.45403744652867317, 41.674711499895366, 78.24937575204032, 76.84698608943394, 81.91608606066022, 78.5855712890625, 81.13002245766776, 77.16023172651018, 75.94464438302177, 71.53461578914097, 76.81838730403355, 69.59162848336356, 75.95403139931815, 71.65089389256069, 75.89732020241874, 71.61510372161865, 69.1409752709525, 69.72262981959751, 75.86726924351284, 67.7512799671718, 63.19298376355852, 48.88796649660383, 51.869365555899485, 50.24241358893258, 52.87941128867013, 49.70096131733486, 52.823662417275564, 49.05968427658081, 52.921110902513774, 49.100720337459016, 50.29541792188372, 46.847683565957205, 47.95708506447928, 47.51915747778756, 48.616778305598665, 47.34109251839774, 49.317372117723735, 48.9610823903765, 50.873775550297324, 46.531293869018555, 47.92739888599941, 45.37236908503941, 52.30333266939436, 51.824584415980745, 57.4693078994751, 57.850805691310335, 65.4337500163487, 60.75600733075823, 57.21662276131766, 58.39087527138846, 65.36055769239152, 60.992294720241, 60.175978660583496, 52.368645736149375, 64.78633076804024, 56.63291154588972, 46.84802402768816, 61.99435697283064, 56.86952897480556, 62.576101848057334, 62.315864018031526, 60.136547633579795, 57.9881020954677, 58.30155617850167, 59.729543004717144, 57.3537836756025, 59.71015753064837, 57.12230443954468, 57.544577734810964, 57.879334994724815, 59.337400572640554, 57.76808738708496, 59.11710793631417, 59.70657920837402, 57.17447846276419, 54.89281163896833, 50.46605525697981, 47.68916252681187, 50.18285015651158, 46.73025206157139, 49.04515559332711, 46.555595193590435, 47.07539687837873, 45.117794036865234, 47.461692401341026, 45.86043834686279, 48.38892255510603, 45.94812808718, 50.18143619809832, 49.278750555855886, 48.7825414793832, 48.69541801725115, 48.646207400730674, 47.1633471761431, 49.13464491707938, 45.55988359451294, 48.87960433959961, 49.185227802821565, 53.80303185326712, 51.087606361934114, 57.820494174957275, 57.29673549107143, 58.330683026994976, 54.74512767791748, 56.87148836680821, 52.25959375926426, 65.39289460863385, 61.47084494999477, 83.8328161239624, 20.683088370731898, 0.6406166904738971, 1.7069359379155296, 2.5160460642405917, 0.5673763262374061, 0.0903046310746244, 0.3231397090213639, 46.83274841308594, 64.66734981536865, 31.261574813297816, 63.87075274331229, 36.82636274610247, 28.211531026022776, 44.57082836968558, 45.06964302062988, 62.87131690979004, 61.184752873011995, 75.13162871769497, 25.05392391341073, 0.23828217387199402, 0.0946695925667882, 0.08360168218080487, 0.036249532364308834, 0.058951658462839465, 0.06178367364087275, 0.08460909633764199, 0.08984623995742627, 0.034802084855203114, 0.014849504788539239, 0.05116488219105771, 0.047382029106042216, 0.11845776146011693, 0.01798797521873244, 0.03478435812784093, 0.042809032169835906, 0.14944621148918355, 0.09384166449308395, 0.25648764840194155, 0.19947474769183568, 0.15163110781993183, 0.14381833347891057, 0.16165666628096784, 0.15642925963870116, 0.09190271675054516, 0.2721758394369057, 0.29724529279129847, 0.2500624374619552, 0.2761298529803753, 0.6190643555351666, 0.6331845064248357, 29.139951058796473, 103.03354454040527, 80.1648759841919, 82.98866558074951, 70.7901371547154, 36.33431911468506, 51.035352434430806, 65.72319112505231, 46.480367047446116, 31.939156191689626, 0.20773934493107454, 0.6401117518544197, 1.6438107937574387, 6.229220713887896, 4.991719620568412, 13.346553223473684, 8.638382639203753, 0.783314830490521, 50.23434673036848, 78.9879206248692, 78.44773292541504, 83.98990794590541, 82.97219140189034, 84.42305864606584, 82.26999255589077, 80.74570369720459, 76.37912913731166, 80.80852930886405, 72.99717685154506, 80.27306638445172, 74.24995790209088, 78.9443484715053, 73.22804464612688, 70.84254046848842, 76.23811544690813, 77.06334604535783, 71.07228960309709, 67.22493307931083, 50.968354429517476, 54.03450414112636, 52.67700678961617, 54.610294410160606, 52.87297378267561, 54.83997406278338, 52.360210623059956, 55.40774958474295, 52.75493083681379, 53.00647299630301, 50.26017318453108, 50.923427377428325, 50.57654898507254, 51.44464649472918, 51.18374858583723, 51.27700730732509, 52.1744053704398, 52.25294085911342, 47.45473378045218, 49.00871229171753, 49.50069686344692, 55.996758801596506, 55.63427128110613, 60.86543451036726, 59.67773723602295, 68.60909066881452, 62.293483870370046, 59.26441669464111, 60.045797211783274, 67.69327640533447, 62.722403117588584, 64.17361082349504, 55.24007913044521, 68.39530154636928, 59.21967724391392, 50.33658252443586, 65.35287298474992, 61.437653405325754, 66.43285233633858, 65.50145326341901, 63.70911679949079, 60.599394934517996, 60.25725868770054, 61.64978885650635, 60.03713975633894, 61.2785952431815, 59.34411253247942, 61.357054301670615, 61.63753918239048, 61.69365283421108, 59.04955060141427, 62.28388145991734, 64.398836680821, 61.14334855760847, 58.54452773502895, 53.29008804048811, 49.98205416543143, 52.14126941135952, 49.48433038166591, 52.38724953787667, 48.427189758845735, 50.26936217716762, 48.31696006229946, 49.85894250869751, 47.32950292314802, 51.76615701402937, 48.37356356212071, 52.12328052520752, 52.74361916950771, 53.192191396440776, 50.60329954964774, 53.86933503832136, 50.75822005953108, 53.30444649287632, 47.80960260118757, 50.25594173158918, 52.728840351104736, 56.36052826472691, 54.098844460078645, 60.20497349330357, 59.85318619864327, 59.567705563136506, 57.32377093178885, 59.716056551252095, 55.50047329493931, 68.2464085987636, 65.15395995548793, 87.0884849003383, 20.95492795535496, 1.6647349681173051, 5.928676383835929, 5.861963255064828, 0.665122281227793, 0.14948753427181924, 1.17978164766516, 58.412053380693706, 67.60762596130371, 43.243600845336914, 99.75442559378487, 55.89044788905552, 26.389817578451975, 46.65290124075753, 52.40330682482038, 72.84471252986363, 70.7455644607544, 86.97188023158482, 22.46459780420576, 0.6530217762504305, 0.3378670130457197, 0.19548114841537817, 0.08914149313100747, 0.1198814364948443, 0.23332379279392107, 0.20109285015080655, 0.22535207841013158, 0.15298672579228878, 0.14755038464707987, 0.11752430083496229, 0.18775313666888646, 0.22898423565285547, 0.1626240536570549, 0.100145845141794, 0.20723946818283626], [0.053949993635926924, 0.011131803787845587, 0.00852708681486547, 0.05027944488184793, 0.03516665493537273, 0.04157213407701679, 0.02707403409294784, 0.05519208591431379, 0.08131968748888799, 0.037675164972565005, 0.0036641985144732253, 0.037995287616338046, 0.08498161884823016, 0.04948919925040432, 0.12012308995638575, 54.596078395843506, 73.03385639190674, 65.51619039263043, 64.43679468972343, 55.24628734588623, 24.646406854901993, 41.427470275333945, 40.72259289877755, 37.97995131356375, 8.399911778313772, 0.0587952086435897, 0.3281385036451476, 1.3186310827732086, 0.5690187066793442, 23.34121033123561, 6.29183440549033, 0.40779949192489895, 10.645990797451564, 60.50299562726702, 77.79799992697579, 75.45066915239606, 76.53938933781215, 74.30941363743374, 76.50972052982875, 73.24697153908866, 77.36975465502057, 69.3781520298549, 69.55143315451485, 67.04412010737828, 68.73895250047956, 68.54833562033517, 67.62933213370187, 65.86698409489223, 68.974260193961, 65.52492427825928, 69.28226688929966, 66.71797166551862, 58.72324235098702, 48.73874698366438, 49.383779525756836, 50.69521032060896, 49.03092220851353, 47.772843156542095, 50.77086925506592, 47.99870477403913, 48.513225827898296, 48.39226116452898, 47.80053172792707, 45.50705296652657, 46.89377791540963, 44.608546665736604, 45.20770025253296, 44.63854898725237, 46.44432326725551, 45.79115785871233, 46.31050443649292, 44.251676763807026, 46.27527012143816, 46.434429032461985, 48.00753246034895, 49.199026925223215, 53.72241537911551, 58.632040296282085, 61.057746750967844, 56.75131927217756, 55.268792561122346, 55.519813605717246, 58.352653230939595, 60.26720155988421, 62.159599031720845, 50.40771470751081, 60.47288908277239, 54.64567811148507, 45.01694440841675, 60.787885665893555, 53.489133085523335, 60.37259183611189, 56.59399468558175, 56.170123304639546, 54.486328125, 55.10107694353376, 54.13553442273821, 56.81410666874477, 55.90246827261788, 54.83552374158587, 56.334500312805176, 53.50642367771694, 55.99162408283779, 57.04347365243094, 56.929703848702566, 58.18526070458548, 52.122992174965994, 49.137670857565745, 45.37409223828997, 47.13197258540562, 50.1551650592259, 43.73667975834438, 43.79103899002075, 41.03674527576992, 42.497826371874126, 41.950447286878315, 45.05940137590681, 45.12725748334612, 45.65031787327358, 46.579316343579976, 45.723141942705425, 46.69263798849923, 45.62005499431065, 44.70990003858294, 47.019623688289094, 45.724917207445415, 45.20172132764544, 46.9858797618321, 50.20853417260306, 54.83833081381661, 58.849935804094585, 57.98037222453526, 59.692335401262554, 59.82415662493025, 63.4960572378976, 60.108018330165315, 63.56532382965088, 57.169903073992046, 60.90811729431152, 57.82206446783883, 76.34609740121024, 32.4376859664917, 0.10335902736655303, 0.7786873302289418, 1.7145494265215737, 0.9606695537056241, 0.04688308873612966, 0.015423428367025085, 9.27435038770948, 77.03437205723354, 35.08518239430019, 37.65379939760481, 42.689746039254324, 16.502518824168614, 11.819774304117475, 36.982943875449045, 51.752715723855154, 54.42873798097883, 53.80571385792324, 51.60972874505179, 2.8790953031608035, 0.20668762922286987, 0.0705171317926475, 0.06039307718830449, 0.030812261626124382, 0.02139369514770806, 0.05950021331331559, 0.046417929232120514, 0.023972323297389915, 0.018622705712914467, 0.03998198726081422, 0.038911265786737204, 0.04737809021025896, 0.059902564223323546, 0.022542088525369763, 0.05835034751466342, 0.0674763246040259, 0.039207337756774256, 0.017466465077762092, 0.03702086043943252, 0.05614114605954715, 0.10778737760015897, 0.05822785158774682, 0.0379078074890588, 0.012556006383549954, 0.0741999281038131, 0.03811490994745067, 0.03303032135590911, 0.06751937765095915, 0.04288547592503684, 0.15193388371595315, 69.18106637682233, 81.11481979915074, 72.47975145067487, 74.16285528455461, 70.14465645381382, 31.48376430783953, 38.53458431788853, 45.43138360977173, 45.35525567190987, 11.04012736252376, 0.22875646501779556, 0.26856741734913414, 2.830352170126779, 2.5110442297799245, 26.456101655960083, 2.3223061859607697, 0.6916091399533408, 14.822694540023804, 72.71762997763497, 80.51732335771833, 78.24632549285889, 78.26131970541817, 80.04468604496547, 80.50524738856724, 77.47346346718925, 76.79746627807617, 73.53181988852364, 73.1493979862758, 70.28527409689767, 71.36530208587646, 70.20246546609062, 69.14449105943952, 68.19958468845913, 67.75340611594063, 67.83505439758301, 72.16977841513497, 69.38909544263566, 61.20242214202881, 50.9701748575483, 51.117598261152, 52.511757782527376, 51.616850648607524, 51.00550297328404, 51.747212750571116, 50.89045817511422, 51.58818585532052, 52.13041632516043, 49.49587133952549, 49.11032969611031, 49.38614886147635, 47.02633564812796, 46.62382302965437, 48.13226304735456, 48.697523321424214, 48.25202219826834, 46.69475024087088, 46.55910750797817, 48.4872465133667, 49.51790060315813, 50.35154547010149, 54.255668776375906, 56.28474773679461, 61.43917506081717, 62.6171726499285, 58.574543952941895, 57.740958145686555, 56.896123204912456, 60.384987422398154, 64.58194255828857, 64.23287895747593, 52.71266147068569, 62.956953457423616, 56.7576664515904, 48.94137382507324, 64.31228991917202, 55.57696253912789, 64.72451959337506, 59.55374663216727, 57.77119323185512, 57.460129329136436, 56.80352456229073, 57.18968806947981, 59.453595297677175, 58.005948543548584, 57.83055864061628, 57.9279202733721, 56.164505686078755, 59.794286319187705, 60.77336393083845, 60.93459687914167, 59.36381762368338, 53.71199655532837, 51.6881217956543, 47.497142110552105, 49.55331557137625, 52.192772933415, 45.92479951041085, 47.125931126730784, 44.49972397940499, 45.04397290093558, 45.009541102818076, 45.97028589248657, 48.201877049037385, 47.417540073394775, 47.810113293784006, 49.053392682756694, 48.698329312460764, 48.213428429194856, 47.53415863854544, 48.966825076511924, 48.44440392085484, 47.870017187935964, 48.64111089706421, 53.961058207920615, 58.05446086611067, 62.29372010912214, 62.38356726510184, 62.1926029750279, 65.4648779460362, 66.40218993595668, 63.817592075892854, 67.4314682824271, 61.53764493124825, 64.16489083426339, 61.957010405404226, 80.03552137102399, 37.289651257651194, 0.14784914361579077, 1.9612910321780612, 3.021184878689902, 1.5675573540585381, 0.2063617967069149, 0.011059591546654701, 7.675226824624198, 81.65537575313023, 44.29231677736555, 40.1759329523359, 29.916778768811906, 20.408245427267893, 19.506503002984182, 49.68127359662737, 59.93554319654192, 59.17686939239502, 58.48585714612688, 68.85796124594552, 9.705846548080444, 0.29764386426125256, 0.049045654479414225, 0.09985191055706569, 0.022672699731109396, 0.03693216573446989, 0.02169086634447532, 0.05923321656882763, 0.04327023920736142, 0.04686378441484911, 0.018514964529978375, 0.03812612273863383, 0.061123479423778396, 0.03949449716934136, 0.03096027046974216, 0.0819290458623852, 0.12534896310951027, 0.11886302328535489, 0.10571361173476491, 0.09951230378023215, 0.10728635412773915, 0.2436447718313762, 0.12518402481717722, 0.17791891151240893, 0.19276767330510275, 0.1789937381233488, 0.13286899030208588, 0.13359898541654858, 0.11726045927831105, 0.19054297411016055, 0.3326324682150568, 76.16389478955949, 91.4681568145752, 80.63436576298305, 82.09168788364956, 73.64213643755231, 34.64020586013794, 59.711074692862375, 57.28077547890799, 58.216419901166645, 13.91619781085423, 0.2660165328000273, 0.7879959078771728, 5.9617141996111185, 3.3791593270642415, 32.30549648829869, 18.752673830304825, 2.041551845414298, 23.405126810073853, 73.7465261731829, 82.12541443961007, 79.15845026288713, 83.97038350786481, 81.1243874686105, 84.26385457175118, 79.54919610704694, 80.22585337502616, 74.45796612330845, 75.60387693132672, 71.82637759617397, 74.36395004817417, 73.97216197422573, 72.75325339181083, 68.71290370396206, 71.42566803523472, 72.00550215584892, 76.84276158469063, 72.41233307974679, 64.87879044669015, 53.842216219220845, 52.875363962990896, 55.80785117830549, 56.954838957105366, 52.41841915675572, 55.01863309315273, 53.861389773232595, 54.00085054125105, 54.00345264162336, 54.067820753370015, 53.71432420185634, 53.53613764899117, 49.23005410603115, 49.48915243148804, 50.71765300205776, 54.098382404872346, 50.93268237795149, 50.739824703761506, 50.457547187805176, 50.564865589141846, 54.011036600385395, 52.377282346997944, 56.600810868399485, 61.112276213509695, 64.27889687674386, 65.08443628038678, 63.60610280718122, 61.17501149858747, 58.631373269217356, 63.81445843832833, 65.88702269962856, 67.4835102898734, 55.851148877825054, 66.75194835662842, 60.77801922389439, 52.225036893572124, 65.94554737636021, 60.299330030168804, 67.16610268184117, 61.380705969674246, 60.80704879760742, 61.84372697557722, 59.55553231920515, 58.533605166843955, 63.54316602434431, 61.68232727050781, 60.792534010750906, 60.98301887512207, 59.18023926871163, 61.936763354710166, 62.90673187800816, 64.32588754381452, 64.09106622423444, 58.3237487248012, 53.89822564806257, 49.794616086142405, 52.40172610964094, 54.39004693712507, 48.996257645743235, 49.84672062737601, 46.68532500948225, 49.81227493286133, 46.56697634288243, 48.983848163059776, 50.45681415285383, 50.36479915891375, 50.09510483060564, 51.729564326150076, 52.577855995723176, 51.5050367627825, 49.5293790272304, 51.5212573323931, 50.04915986742292, 50.53576305934361, 51.574737616947715, 56.88661459514073, 64.15534400939941, 65.87922682080949, 64.95879200526646, 65.53731291634696, 68.15899331229073, 69.5271075112479, 66.62799944196428, 70.91716412135533, 64.70618329729352, 67.68903800419399, 65.28676782335553, 83.63771070752824, 39.90812158584595, 0.273113981953689, 4.794730373791285, 5.463621727057865, 2.2107819531645094, 0.3220120923859732, 0.08682231472006866, 12.000709738050189, 91.1684045791626, 48.68832043239048, 54.40318945475987, 53.61078214645386, 25.39218827656337, 20.011709996632167, 52.7027324948992, 66.42409760611397, 70.93214443751744, 66.84741660526821, 79.39329937526158, 7.693820204053607, 0.43491464693631443, 0.3283497994499547, 0.18682381510734558, 0.1617201907294137, 0.10890387983194419, 0.11759326713425772, 0.0988238485796111, 0.11165278804089342, 0.09887968522629567, 0.14903860193278107, 0.1771456530051572, 0.1253972476614373, 0.07583517714270524, 0.06454294986490693, 0.1254139667642968], [0.10529567487537861, 0.00342504375813795, 0.08305890844868762, 0.03989301096381886, 0.03226997876273734, 0.025889164369021143, 0.037781851033547094, 0.021251106102551733, 0.0553317487772022, 0.02493519671926541, 0.029784209826695066, 0.11776360656533923, 0.09312034105615956, 0.2737836145928928, 6.0432756287711005, 75.52258995601109, 66.67314883640834, 66.61640984671456, 46.96273878642491, 18.84572410583496, 27.268663951328822, 43.03987271445138, 29.662144660949707, 34.83613463810512, 3.5184948103768483, 0.19795872404107026, 0.8504757923739297, 4.599482953548431, 2.4712857689176286, 6.673116368906839, 1.4577655025890894, 2.1729527030672346, 38.95397758483887, 72.67383548191616, 71.97304712023053, 79.16934503827775, 75.97233295440674, 77.29790333339146, 72.86261108943394, 75.96398816789899, 72.60503441946847, 73.99579974583217, 75.18460873195103, 71.26529666355678, 68.60891001565116, 68.93596867152623, 67.75288500104631, 65.84044892447335, 65.11538355691093, 64.95144081115723, 63.80051340375628, 64.79176425933838, 54.88580438068935, 47.873935971941265, 49.05804450171334, 47.71203947067261, 48.99110903058733, 48.27124091557094, 48.935596397944856, 47.251558031354634, 48.662090982709614, 46.547347681862966, 45.39736870356968, 44.83680541174752, 45.479597159794395, 45.27832869121006, 43.97340488433838, 42.732810974121094, 44.994929041181294, 45.37751770019531, 45.449671268463135, 45.813541480473106, 46.52501617159162, 48.62698520932879, 50.123679297310964, 50.560293674468994, 54.462888377053396, 54.06338085447039, 55.95232159750802, 54.60666050229754, 59.320919445582796, 58.75991494315011, 56.97920281546456, 55.40256970269339, 62.62334959847586, 55.06778812408447, 57.71898794174194, 55.6721076965332, 45.3503954069955, 58.25970023018973, 56.7063227381025, 59.31980078560965, 56.30652339117867, 55.33230951854161, 52.842846393585205, 55.00924955095564, 53.54046637671334, 55.6221466745649, 55.01558630807059, 57.074976784842356, 54.377237933022634, 57.37382228033883, 53.775662899017334, 56.24915558951241, 58.49872520991734, 53.54161630358015, 48.947060925619944, 46.46466759272984, 46.39155864715576, 44.1211131640843, 49.66928447995867, 47.653813566480366, 44.3058831351144, 42.834178243364605, 42.25154052461897, 43.755127225603374, 42.977891308920725, 43.602395398276194, 45.838176318577354, 47.19166803359985, 45.73834807532174, 46.930777072906494, 45.20761687414986, 45.1066004889352, 45.310488428388325, 45.522738524845664, 46.242849826812744, 51.897662094661165, 61.21205234527588, 62.71526036943708, 63.78122520446777, 61.619432176862446, 62.14635576520647, 63.595631871904644, 64.37487234388078, 64.27943188803536, 63.30061830793108, 62.91684150695801, 66.40438556671143, 63.80603722163609, 73.83706814902169, 44.01770659855434, 0.13668952243668692, 0.690652242728642, 1.1068883133786065, 0.6995006650686264, 0.2804825194180012, 0.12682685309222766, 0.15981391444802284, 40.95187650408064, 67.86643246241978, 31.041772024972097, 61.67469814845494, 33.76198482513428, 17.041909217834473, 22.466216734477452, 27.34739225251334, 48.596698011670796, 56.13315193993704, 63.25687939780099, 46.2107560975211, 0.66438099529062, 0.08769565035722085, 0.04080814775079489, 0.04347613726609519, 0.08873738481530122, 0.03818807298583644, 0.027214353438466787, 0.07463296915271453, 0.047849061366702826, 0.015399917128628917, 0.014025904071916426, 0.06172673776745796, 0.029529735445976257, 0.05164659455684679, 0.031674910336732864, 0.05683579628488847, 0.037134121504745314, 0.12266724343810763, 0.005035723892173597, 0.06242359323160989, 0.01613856865359204, 0.036342210069830926, 0.03558043237509472, 0.05780942618314709, 0.014758728677406907, 0.06188986437129123, 0.07031268919152872, 0.047285175017480335, 0.286662399236645, 8.933454394340515, 90.5660513469151, 70.8395527430943, 80.8048815046038, 57.28473595210484, 34.51729222706386, 33.57270894731794, 29.766715049743652, 36.60413156236921, 51.92580924715315, 3.667462016854967, 0.1833358329853841, 2.7707626819610596, 4.176912188529968, 2.084422664982932, 1.1122582937989915, 0.7158377798540252, 2.898383068186896, 52.97518525804792, 76.07122666495187, 74.37071064540318, 79.62417411804199, 78.24196897234235, 79.75153459821428, 78.21874114445278, 77.27013833182198, 76.07006631578717, 76.9925925391061, 76.48045471736363, 72.21058518545968, 71.34228965214321, 70.73736558641706, 70.95508738926479, 67.96950898851667, 66.54600375039237, 67.94460664476667, 66.25771604265485, 66.09542001996721, 58.68655586242676, 50.82243878500802, 52.022406578063965, 49.59484148025513, 50.79705701555525, 50.89890718460083, 52.1684889793396, 49.49161556788853, 51.590388434273855, 48.065001010894775, 48.45545155661446, 47.45747137069702, 47.38758291516985, 47.195715359279085, 46.336369105747764, 45.617838518960134, 48.88416930607387, 47.78009360177176, 47.914454392024446, 49.442700249808176, 48.7923002243042, 51.61945969717843, 52.76563106264387, 53.31801979882376, 56.691133975982666, 54.806633131844656, 56.99848059245518, 59.62614686148507, 63.561669077192036, 59.661276953560964, 58.50194917406355, 59.202230317252024, 64.54828548431396, 58.63852991376604, 59.195462771824424, 57.52558830806187, 47.66384676524571, 61.38912718636649, 58.871287618364605, 60.59810256958008, 58.529790605817524, 57.16031455993652, 56.316792828696116, 58.51037039075579, 57.37298502240862, 59.045534542628694, 59.055456570216585, 59.04895305633545, 56.7554360798427, 58.65409387860979, 55.668800354003906, 60.04897253853934, 59.64153017316546, 56.74377005440848, 50.45838097163609, 48.73510612760271, 49.014170101710725, 45.21023634501866, 51.369894300188335, 49.487033230917795, 45.72667857578823, 45.628000259399414, 45.19393587112427, 45.711145877838135, 45.57250499725342, 45.401197160993306, 46.79652050563267, 49.39035946982247, 48.93877172470093, 48.659450667245046, 48.170679637363975, 48.52531916754586, 48.562307902744834, 47.074101039341514, 49.45530775615147, 56.83165087018694, 66.48127433231899, 66.2718208857945, 64.74498898642403, 66.09230722699846, 65.05870015280587, 67.46848828451974, 67.05490371159145, 66.57704830169678, 65.41879749298096, 64.6877566746303, 68.91545064108712, 66.6943130493164, 74.7859697341919, 47.482067993709016, 0.2393227480351925, 0.9417364725044796, 2.6894096987588063, 2.0080954006740024, 1.004804076892989, 0.048448828647711446, 0.08777980227023363, 38.57637425831386, 75.4428802217756, 38.3619841166905, 48.67217976706368, 31.671143327440532, 28.034115723201207, 37.22717653002058, 39.15006269727434, 57.80353709629604, 62.27097865513393, 68.42816652570451, 61.57034315381731, 2.050500908068248, 0.19946474608566078, 0.02071472247397261, 0.020528138914544667, 0.032629218950335465, 0.11395178682037763, 0.024775859733511294, 0.03590143372171691, 0.03636049319590841, 0.008041331228534026, 0.038811962186758, 0.0630314452573657, 0.03592814425272601, 0.026768055511638522, 0.0709532941026347, 0.2795805021056107, 0.09616938565990754, 0.138213539229972, 0.11701849369066102, 0.19510656994368347, 0.10509671483721052, 0.16235614089029177, 0.13785471634141036, 0.26512819475361277, 0.13799749368003436, 0.14161944575607777, 0.20313511842063495, 0.19891203860087053, 0.5445243524653571, 9.965361765452794, 101.69559247153146, 83.15287235804966, 88.12760884421212, 64.50853484017509, 32.65569264548165, 38.26510190963745, 58.75754560743059, 42.706546783447266, 58.32472842080252, 5.332587386880602, 0.44106787389942576, 2.4462262221745084, 12.16808749948229, 5.359618050711496, 17.19943356513977, 3.1784395490373885, 4.621262516294207, 62.985809326171875, 79.29658045087541, 75.89935602460588, 82.7108210154942, 80.79274300166539, 82.78156757354736, 78.58615493774414, 81.32988044193813, 79.55843026297433, 79.61777482713971, 79.04667459215436, 75.77435098375592, 72.85790021078927, 73.74410125187465, 70.83392470223563, 71.66960539136613, 69.03593240465436, 72.4565236227853, 69.03479290008545, 69.73623439243862, 61.73872579847063, 53.20303406034197, 55.41069909504482, 53.15302440098354, 53.03877864565168, 54.028622491019114, 54.917679241725374, 52.797492027282715, 54.060601575034006, 51.52574586868286, 52.312257630484446, 49.67662525177002, 50.37474203109741, 51.73406328473772, 49.73125893729073, 47.76411969321114, 50.074774401528494, 50.24442856652396, 50.76444911956787, 51.81440530504499, 50.256716455732075, 53.16307497024536, 53.878016812460764, 57.48892266409737, 61.223377908979145, 58.299888610839844, 59.531852858407156, 63.51463672092983, 66.01228482382638, 63.824463844299316, 58.588204111371724, 62.74108682359968, 67.6761977331979, 57.7936498097011, 62.65679822649275, 61.7607307434082, 51.637688296181814, 63.571813447134836, 62.994452885219026, 62.093174253191265, 62.793920925685335, 60.46596867697579, 58.587363379342214, 61.59221608298165, 58.96240629468645, 62.73790454864502, 61.42337485722133, 63.008550780160085, 60.13868767874581, 62.754295349121094, 58.07274505070278, 63.44197246006557, 63.269212450299946, 58.81513922555106, 53.100291047777446, 51.118880203792024, 51.92050429752895, 48.72030993870327, 53.706649916512625, 52.10705648149763, 48.562808173043386, 46.84111751828875, 47.12164756229946, 49.523118700299946, 46.515882764543804, 48.405452319553916, 50.104599543980186, 52.551598753247944, 50.11182567051479, 52.08365842274257, 50.481118951525005, 50.48448882784162, 50.969983782087056, 49.8695524079459, 50.64560713086809, 61.072463035583496, 67.77535547528947, 68.81961413792202, 68.34149469648088, 68.29853398459298, 66.91994885035923, 69.52090971810478, 67.68682847704206, 70.3484193256923, 67.05089460100446, 68.4398672921317, 70.89540931156704, 70.33142403193882, 78.4501508985247, 51.20782061985561, 0.5075408284153257, 4.554372208459037, 7.175890624523163, 4.347957296030862, 0.7692863632525716, 0.3182677190218653, 0.6557108376707349, 49.180888652801514, 80.55143206460136, 45.37177848815918, 83.78964001791817, 50.421239376068115, 26.72907727105277, 33.67477798461914, 42.81276389530727, 67.34325395311627, 68.83719308035714, 80.10005623953683, 63.31704384940011, 1.5468313119241168, 0.32678444630333353, 0.11457071932298796, 0.10635317848729235, 0.2872198021837643, 0.13592517987958022, 0.1287881721343313, 0.13597521505185536, 0.10579182646636452, 0.052526871607239754, 0.1516539744500603, 0.15433204360306263, 0.16996277629264764, 0.08602854409920317, 0.11720604076981544], [0.10339340195059776, 0.02324575139209628, 0.07034063126359667, 0.037866728979029825, 0.08127027656883001, 0.038413702842912505, 0.08038569082106863, 0.08017054772270577, 0.08115320213671241, 0.052867350301572254, 0.08117011122937713, 0.052986687647977045, 0.15279527035142693, 0.26780764811805313, 36.00639888218471, 71.29600770132882, 62.54944161006382, 52.92249706813267, 36.84064129420689, 62.768198694501606, 38.71057871409825, 50.231383323669434, 33.044274125780376, 36.323750904628206, 0.4511883051267692, 0.15327043485428604, 0.40157683725867954, 0.6015983756099428, 1.1311879009008408, 2.485077725989478, 1.0187482429402215, 26.60986876487732, 63.22646713256836, 72.2233281816755, 76.48425538199288, 73.60570008414132, 73.23807089669364, 75.20267404828752, 73.59069892338344, 76.9347835268293, 74.05850028991699, 75.10887336730957, 73.1637738091605, 73.97796372004917, 70.09615107945034, 72.07027326311383, 70.10546166556222, 72.42367948804582, 66.62144729069301, 62.73145662035261, 65.7647066116333, 61.12825012207031, 52.89414841788155, 48.12679134096418, 49.260629653930664, 48.105998856680735, 46.75136763708932, 49.27671820776803, 48.13620267595564, 47.51754896981375, 45.92192990439278, 46.508020877838135, 45.58486236844744, 45.60176386151995, 46.00916453770229, 45.58140216554914, 42.27043267658779, 45.4874382019043, 44.99369921003069, 46.353333132607595, 45.25998197283064, 46.13133471352713, 47.85063518796648, 47.78954662595476, 51.210464409419465, 51.343887192862375, 55.10895620073591, 53.336425576891216, 54.80938114438738, 58.011941364833284, 56.44651917048863, 59.88333443232945, 55.71643720354353, 55.117405210222515, 54.57941314152309, 56.02585438319615, 63.114093916756765, 52.26523917061942, 46.61358485903059, 59.1378413609096, 57.442654609680176, 58.85582787649972, 53.54561151776995, 54.666265623910085, 53.573022161211284, 55.740926129477366, 52.90666559764317, 55.773964813777376, 56.6021796635219, 54.44019208635603, 55.04227433885847, 56.029359749385286, 56.41850750786917, 55.51552309308733, 55.073527336120605, 57.993334089006694, 53.05501658575875, 48.450129236493794, 43.77909503664289, 43.82644353594099, 45.36188077926636, 48.54125486101423, 41.31931114196777, 44.70410871505737, 43.82617950439453, 43.27735866819109, 41.53885684694563, 43.23478010722569, 45.37343910762242, 46.33389207295009, 44.78114339283535, 46.05822229385376, 44.10609463282994, 45.163148403167725, 43.92073406491961, 45.59082044873919, 51.07170193535941, 58.86584717886788, 62.06551347460066, 62.06911958966936, 59.35251290457589, 62.56952885219029, 64.15450327736991, 66.0003547668457, 63.44475173950195, 63.928763253348215, 66.9849909373692, 66.82760034288678, 65.53932094573975, 63.195137705121724, 62.74814619336809, 44.96811246871948, 0.43199833056756426, 1.2587079725095203, 2.450021458523614, 0.8488431828362601, 0.816687788282122, 0.03863499007586922, 0.021812961935730915, 8.727032099451337, 67.22183418273926, 50.68213381086077, 30.344211101531982, 47.941680908203125, 22.311789546694072, 11.75843734400613, 16.47687997136797, 30.25677149636405, 56.81538166318621, 52.003257342747276, 72.97151715414864, 16.914018937519618, 0.20580651078905376, 0.08619055112025567, 0.08667894705597844, 0.021063304572765316, 0.11048969759472779, 0.07734128061149802, 0.0695012223773769, 0.03400416838537369, 0.06186646848384823, 0.06574273548488106, 0.03825417926002826, 0.011580801435879298, 0.07956397134278502, 0.02534751530869731, 0.06184644491544791, 0.07132177932986192, 0.009344238904304802, 0.00506384450376832, 0.07072041409888438, 0.02765440714678594, 0.07773388775863818, 0.020387069787830114, 0.06831098374511514, 0.08871335789029088, 0.04953234389956508, 0.09707402211746999, 0.30308137248669353, 0.1514502918081624, 47.01624686377389, 79.27627781459263, 69.78979805537632, 59.47845595223563, 51.95580809456961, 51.9501314163208, 31.238277503422328, 48.82211494445801, 45.003339835575645, 38.45578479766846, 0.2559246000434671, 0.15351702805076325, 1.4653173259326389, 1.2382605097123554, 2.0114752650260925, 0.5026078245469502, 1.9471953085490634, 39.610182830265586, 74.6026554107666, 78.45368753160749, 78.75828960963658, 75.52575833456856, 76.49356596810478, 78.423018183027, 77.58188315800258, 78.236862046378, 76.77602413722447, 78.45134598868233, 75.11177076612199, 76.61030960083008, 72.96701472146171, 74.77600601741246, 73.79155050005231, 71.73595373971122, 68.57715674809047, 67.36079815455845, 67.48419121333531, 64.16989353724888, 55.17755923952375, 50.75753566196987, 51.904412269592285, 51.40684134619576, 50.6189329964774, 52.742180892399375, 50.321487562997, 49.08313792092459, 49.23660625730242, 48.09648677280971, 48.69431325367519, 48.60971198763166, 46.14778109959194, 47.985398973737446, 45.26043707983834, 47.61901003973824, 46.396029812949045, 49.24071611676897, 47.82785899298531, 47.645159585135325, 49.058197362082346, 49.88293463843209, 52.09559890202114, 54.619511195591514, 57.57241221836635, 56.56334965569632, 57.45189918790545, 61.06750896998814, 60.062236649649485, 62.025436265128, 58.60760348183768, 57.44699028560093, 58.597952433994834, 59.836246490478516, 64.59565135410854, 54.83883803231375, 47.747127873556956, 61.13082095554897, 60.79741859436035, 61.67442716870989, 55.485152517046245, 58.36934975215367, 55.99396562576294, 57.95240919930594, 55.06919166019985, 58.1826342855181, 58.58747455051967, 59.15342617034912, 56.910221099853516, 58.01908411298479, 58.6715338570731, 57.69207756859915, 57.666834763118196, 59.46940244947161, 56.372753620147705, 51.330765519823345, 45.890857560294016, 45.40628324236189, 46.728212765284944, 50.6844162940979, 44.18204886572701, 46.62059906550816, 47.01010465621948, 46.2325873374939, 44.08242212023054, 46.12922246115548, 46.61982781546456, 49.2187111718314, 47.54796470914568, 47.92534221921648, 46.18329681668963, 46.64218711853027, 46.40924876076834, 47.00196484157017, 54.57568195887974, 61.298821449279785, 64.24718529837472, 64.3065298625401, 61.44478225708008, 64.31016377040318, 65.35870947156633, 66.87787750789097, 66.08546325138637, 67.03684534345354, 68.23923805781773, 69.48970535823277, 67.29387310573033, 64.42315537588937, 64.23715209960938, 48.90346792766026, 0.9450560829469136, 0.2945088967680931, 2.4489809657846178, 2.774934423821313, 1.4027961322239466, 0.34963745144861086, 0.15607654356530734, 7.526543191501072, 68.61230768476213, 61.359208243233816, 33.258018084934776, 33.063319138118196, 26.74467076574053, 19.798850195748464, 29.62165403366089, 37.47864573342459, 60.87380708966936, 57.08762945447649, 78.6781073978969, 25.61750967161996, 0.2420139807675566, 0.014436331244983842, 0.14411581680178642, 0.07226458338222333, 0.03834401729649731, 0.036463864613324404, 0.06608813016542367, 0.05736378473894937, 0.06838695252580301, 0.028596912643739154, 0.09436763769813947, 0.050287180181060515, 0.11655832481171403, 0.02239062254583197, 0.22328318442617143, 0.15065940496112618, 0.1851478200405836, 0.12180435045489243, 0.15367518099290983, 0.2121218397681202, 0.15071887177016052, 0.16357647255063057, 0.16979319682078703, 0.11766904592514038, 0.19597979022988252, 0.2820392958819866, 0.3433500916830131, 0.4222830390291554, 51.31188031605312, 93.83034978594098, 79.21160398210797, 68.93796280452183, 47.27446624210903, 74.02450275421143, 52.979114464351106, 73.09925283704484, 51.561310223170686, 49.74083008084978, 1.156588886465345, 0.3800252622791699, 3.9217947466032843, 4.050395480224064, 8.220914891787938, 6.3827038151877264, 4.64160076209477, 47.153543267931255, 78.72971861703056, 81.1408269064767, 78.15328911372593, 78.73720877511161, 78.15836129869733, 81.36016069139752, 79.75933742523193, 84.24002919878278, 79.03021430969238, 80.90444919041225, 79.57196535382951, 81.93069117409843, 76.88213007790702, 78.3603732245309, 74.86777782440186, 77.34995923723493, 71.72875540597099, 69.53213105882917, 72.35134179251534, 68.76683562142509, 57.32368755340576, 53.107131549290244, 55.04466799327305, 53.066769463675364, 51.902181897844585, 56.40739039012364, 53.26131902422224, 52.345490864345, 50.63463939939226, 51.807203497205464, 53.5219772202628, 50.50124440874372, 50.08057267325265, 51.72250495638166, 47.7533916745867, 50.19672223499843, 50.052953583853586, 52.493473597935264, 50.18843650817871, 50.373526096343994, 51.47594812938145, 52.937637192862375, 56.6354615347726, 58.78972271510533, 61.25064958844866, 59.50235775538853, 61.39208711896624, 62.41308321271624, 63.965901374816895, 64.61013139997209, 61.0177320752825, 58.37886183602469, 62.31717722756522, 62.391634123665945, 67.00449453081403, 57.18650579452515, 52.09611654281616, 64.59716606140137, 63.33420589991978, 65.22511645725795, 59.20382145472935, 61.562568119594026, 60.722920009068076, 61.24238123212542, 58.4321197782244, 62.02598517281668, 63.69260787963867, 61.57624912261963, 58.37237916673933, 61.842066356113975, 61.59843472072056, 61.23680877685547, 60.69668361118862, 62.941716057913645, 59.702841077532085, 54.297017506190706, 49.15194245747158, 48.82790626798357, 49.72303574425833, 54.033090182713096, 47.60849046707153, 50.30991881234305, 50.02364260809762, 48.30503347941807, 45.62744092941284, 47.7318731035505, 50.22010292325701, 51.852377210344585, 49.588657583509175, 51.655249868120464, 47.74123580115182, 49.934160232543945, 48.68529449190412, 49.21000855309622, 56.59565877914429, 64.90108026776994, 67.86233302525112, 67.27655124664307, 64.11073657444545, 67.82031726837158, 67.58354350498745, 69.32272624969482, 69.52361256735665, 68.87940338679722, 69.65273788997105, 70.77496923719133, 70.32153674534389, 67.39883954184396, 64.77021789550781, 52.68672384534563, 1.6430771074124744, 5.110426987920489, 10.10102447441646, 6.79074763400214, 2.6468196298394884, 0.2725676255566733, 0.2949025827859129, 11.553228378295898, 80.87956769125802, 64.48313917432512, 46.35528210231236, 60.79914174761091, 31.407493931906565, 17.683478082929337, 27.838734115873063, 43.32115663800921, 73.43889468056815, 67.11755561828613, 91.55727440970284, 25.254850183214458, 0.33982398946370396, 0.17056926446301596, 0.23090033712131636, 0.16142386091606958, 0.1718792441700186, 0.14787363872996398, 0.13567922450602055, 0.10079187833304916, 0.2148402953254325, 0.11296772105353219, 0.13682171462902, 0.13466366114360945, 0.23136179521679878, 0.0947257209835308], [0.010404144530184567, 0.018804615862401466, 0.040233313239046505, 0.040026071680975814, 0.03695523253242884, 0.03944507267858301, 0.0008718395204466235, 0.05897986516356468, 0.0423091147094965, 0.06953783612698317, 0.04003563902473875, 0.08064742891916207, 0.0337149971164763, 1.924480995961598, 71.04765129089355, 66.2111770084926, 66.03220530918666, 45.32476697649275, 35.9796587399074, 100.5894809450422, 90.81467873709542, 24.104817356382096, 43.15842982700893, 25.70420581953866, 0.2716958980475153, 0.1578254947172744, 2.9028166702815463, 0.3949966760618346, 0.7235542429344994, 0.8733580016664096, 14.414911712918963, 65.96128504616874, 60.25926671709333, 81.1241512298584, 71.10593278067452, 72.6301382609776, 73.22799600873674, 74.20015321459088, 68.41222040993827, 71.02470139094761, 65.94028064182827, 69.89578587668282, 68.09705707005092, 68.59691047668457, 64.24749796731132, 65.74408435821533, 64.56141063145229, 63.60769394465855, 65.66959966932023, 64.7877482005528, 60.32398918696812, 58.832502773829866, 50.53435604912894, 48.78148882729666, 49.73659862790789, 49.221837861197336, 47.53231389181954, 47.83474465778896, 46.88687835420881, 47.38137469972883, 46.32920898709978, 46.87823132106236, 45.95228658403669, 43.47958598818098, 44.57434068407331, 45.310040269579204, 42.94259793417794, 45.90661954879761, 44.71535784857613, 46.13830375671387, 45.54076910018921, 44.06271702902657, 46.1598014831543, 47.065349783216206, 48.65727240698678, 51.5032753944397, 50.655358927590505, 51.82168006896973, 52.22226456233433, 53.198066098349436, 54.5019337790353, 56.37742280960083, 59.1907935823713, 58.00042472566877, 59.375928333827424, 49.02596466881888, 62.53794928959438, 51.9878705569676, 43.62952463967459, 60.79404871804373, 55.53326184409005, 57.363153321402415, 51.39721114294869, 51.871415274483816, 49.61611686434065, 53.157221112932476, 52.248726776668, 53.52794919695173, 54.69255065917969, 56.09411348615374, 54.99869523729597, 55.56371232441494, 54.44729314531599, 58.0794917515346, 53.579001086098806, 51.72441571099417, 52.51871987751552, 51.611938272203716, 45.67666891642979, 44.4563706942967, 40.279843262263704, 47.86262777873448, 42.92491824286324, 43.20419413702828, 42.79578249795096, 45.197166783469065, 41.96343347004482, 42.57877288545881, 43.68859474999564, 45.77898114068167, 45.76872559956142, 47.432579449244905, 44.9807060786656, 45.49702671595982, 43.4745693887983, 48.89760364804949, 52.04354647227696, 57.8078692981175, 59.62730721064976, 59.85871696472168, 61.56968307495117, 61.56372152056013, 62.39189120701381, 62.08528109959194, 59.94737597874233, 64.48004027775356, 61.69457694462368, 67.25740895952497, 62.85034029824393, 65.62033694131034, 61.35519218444824, 59.78323868342808, 3.2725090384483337, 0.6728898244244712, 0.7921041388596807, 0.6804361109222684, 1.7320448820080077, 0.18815326876938343, 0.050489380223942656, 0.36818384911332813, 33.02744211469378, 69.65287685394287, 40.868230615343364, 52.583060196467805, 52.6477027620588, 27.92544068608965, 13.361907005310059, 18.145441225596837, 34.16016524178641, 50.07448952538626, 62.97238540649414, 44.76239367893764, 0.22279942966997623, 0.05688002659007907, 0.029957697660263096, 0.003767587743433458, 0.03362729985799108, 0.03642675553315452, 0.06982057488390378, 0.07945868306394134, 0.023392579584781612, 0.04002101320241179, 0.05235445585900119, 0.013690975794036473, 0.022216897225007415, 0.05026283434459141, 0.011930363169605178, 0.05381028327558722, 0.048813643000487766, 0.025050420447119644, 0.015478272656244891, 0.04568041594965117, 0.03757610564519252, 0.04669612519709127, 0.0333063901135964, 0.029831965121307542, 0.036274000337081294, 0.11652878139700208, 0.13423840967672213, 2.9434734029429297, 84.12701674870083, 71.80771473475865, 76.23175784519741, 47.750018324170796, 43.57377576828003, 109.71548816135952, 64.68226064954484, 26.743538209370204, 53.02025474820818, 21.12590401513236, 0.37953405720846994, 1.3567891780819212, 3.674450601850237, 1.8814918398857117, 0.5381839584027017, 0.8689600633723396, 24.236631631851196, 74.72033010210309, 67.91979462759835, 82.0524514062064, 74.69810281481061, 76.03389399392265, 73.79555266244071, 77.86930928911481, 70.82642064775739, 75.75866889953613, 68.86125469207764, 69.6123410633632, 72.459976877485, 72.02101053510393, 68.24700614384243, 68.61961024148124, 66.76276670183454, 65.82036168234688, 67.98573303222656, 66.65846034458706, 63.20357281821114, 60.385605812072754, 51.075224672045024, 51.97246640069144, 51.845408167157856, 51.8233893258231, 51.78097057342529, 50.278266293661936, 48.79185206549508, 49.60291181291853, 50.660837582179475, 49.11693395887102, 48.47105721064976, 46.71039758409773, 46.89447273526873, 46.89694629396711, 46.387573855263845, 49.711289814540315, 48.277786118643625, 48.826537472861155, 48.22683845247541, 46.69761984688895, 48.26135015487671, 50.2605414390564, 51.48198611395699, 52.23500408445086, 52.50115483147757, 52.9974889755249, 54.302197388240266, 55.13901063374111, 56.703070981161936, 58.56751932416643, 63.31202725001744, 59.22663933890206, 61.87020656040737, 52.68199559620449, 64.316757610866, 52.77908624921526, 46.10591472898211, 64.83544758387974, 56.89133937018258, 58.99632740020752, 52.936233656747, 53.858231816973, 52.99254880632673, 54.805260862622944, 55.10217128481184, 57.44553811209542, 55.85087789808001, 60.195683751787456, 56.64247226715088, 58.26971953255789, 57.40542963572911, 61.12338638305664, 55.78623880658831, 52.57303394590105, 54.0360084261213, 55.92587327957153, 49.038026741572786, 45.98795516150338, 43.24487931387765, 49.58054208755493, 44.52695049558367, 44.654724393572124, 44.49852194104876, 46.31502423967634, 44.956057344164165, 45.34781762531826, 45.73221976416451, 47.8238742010934, 47.40923350197928, 48.7410329410008, 46.480578967503135, 48.46289307730538, 45.00106430053711, 50.775649615696494, 55.444679260253906, 59.723018646240234, 62.62653187343052, 64.57708576747349, 63.526080404009136, 65.40713841574532, 64.72699315207345, 65.23403794424874, 62.975588526044575, 64.1322968346732, 63.99591064453125, 70.43193667275565, 63.733977454049246, 66.46349389212472, 61.250594002859934, 64.59517887660435, 5.670815706253052, 0.40140704065561295, 0.2357833193881171, 2.5597463250160217, 3.129798684801374, 1.0095768379313605, 0.13067015686205455, 0.15203936876995222, 34.36475494929722, 75.49510288238525, 49.20588479723249, 39.41206884384155, 29.224401201520646, 17.962238073349, 16.54424623080662, 31.013906274523052, 42.00274290357317, 57.654161248888286, 67.66977759769985, 56.13569150652204, 0.39523058065346306, 0.03443698212504387, 0.06798406557313033, 0.02117992777909551, 0.024021518782579472, 0.09843262564390898, 0.05891157061393772, 0.026040721950786452, 0.051431040944797654, 0.009394475092579211, 0.00911140046082437, 0.0003991292204383561, 0.08618926868907043, 0.028069356755752648, 0.10234154375003916, 0.16539016951407703, 0.17151313381535666, 0.12801350227424077, 0.1115948615063514, 0.16893725203616278, 0.06131659049008574, 0.10623794967042548, 0.10284979362040758, 0.15528649810169423, 0.09493682679853269, 0.16657808077122482, 0.2761618526918547, 3.377660253218242, 96.1478727885655, 84.5084033693586, 85.391818182809, 61.8098475592477, 46.28010606765747, 100.4572011402675, 117.73109681265694, 36.249113355364116, 59.72747244153704, 32.0845958845956, 0.4707842064755303, 1.1367757724864143, 11.76007798739842, 6.130785584449768, 6.631082373006003, 1.8144157763038362, 29.152647154671804, 74.2019111088344, 69.6918145588466, 82.89546244485038, 77.74181679316929, 77.66400391714913, 79.44502871377128, 81.80460916246686, 75.248886517116, 79.49392318725586, 72.64283261980329, 73.30824770246232, 75.48889119284493, 76.31590053013393, 70.85076018742153, 74.05177443368095, 71.28484889439174, 69.488614491054, 73.15333066667829, 69.6928150994437, 64.46672058105469, 63.38888127463204, 55.0342561176845, 53.53124611718314, 55.35254962103707, 54.638986996241975, 52.6539318220956, 52.3162875856672, 52.50552524839129, 52.60747616631644, 53.39145878383091, 51.555925369262695, 51.81615277699062, 48.473273686000276, 48.37098578044346, 50.29685967309134, 50.17085756574358, 53.22043929781233, 50.07934284210205, 51.89483765193394, 52.888183389391216, 48.232647146497456, 51.32565859385899, 52.740329197474885, 53.63359308242798, 55.515679427555625, 55.471579211098806, 57.106472969055176, 58.84796251569475, 58.8270206451416, 59.103795187813894, 62.939110483442036, 63.10628414154053, 61.869087900434224, 64.64239883422852, 57.48337800162179, 65.82493359701974, 56.87108537128994, 49.16819429397583, 66.8765504019601, 59.58538178035191, 61.61622905731201, 56.51261738368443, 56.87696702139718, 56.024641922542024, 58.356648445129395, 57.71514906202044, 61.44444874354771, 59.692689759390696, 62.453049251011436, 59.353951181684224, 60.966496058872764, 59.92024326324463, 64.66427871159145, 59.76572227478027, 56.68070125579834, 56.56538200378418, 57.58265733718872, 49.772524288722444, 48.213213035038535, 45.386147362845286, 52.64114018848964, 45.48888342721121, 49.46571963174002, 47.0120918410165, 50.62483549118042, 47.514036655426025, 48.19795479093279, 48.43315478733608, 51.701993874141145, 50.45371525628226, 50.82483243942261, 49.61525181361607, 51.32788896560669, 47.58134732927595, 53.67550809042794, 58.26429993765694, 63.953088896615164, 66.36826188223702, 64.78180749075753, 67.03488595145089, 67.30771391732353, 69.17116519383022, 68.11631052834647, 65.22600582667759, 69.42798451014927, 66.85701901572091, 73.07479517800468, 67.59680761609758, 68.33438668932233, 63.34320381709507, 63.65952055794852, 6.248878470488957, 2.2869190105370114, 7.367926239967346, 7.419429762022836, 5.428242368357522, 0.9851229786872864, 0.1322391740977764, 0.5475916564464569, 41.09890733446394, 81.52635465349469, 54.49935252325875, 69.35807868412563, 66.34550653185163, 37.42661762237549, 20.8206661769322, 30.6029828616551, 50.0626289503915, 65.80602754865373, 77.85673999786377, 66.30818775721959, 0.632948919066361, 0.1439395605453423, 0.17046757920512132, 0.08498486903096948, 0.09688865992107562, 0.16616264092070715, 0.16054450667330197, 0.12936526616769178, 0.10128819277243954, 0.12110973415630204, 0.0850747749209404, 0.051104797915156396, 0.13134437639798435, 0.1206042119967086], [0.017759641399607062, 0.051458915163363726, 0.07124338139380727, 0.038193847318845134, 0.03252506382497294, 0.021961003009762083, 0.030995913914271762, 0.04308967425354889, 0.017136661435610483, 0.0664269837683865, 0.04174114018678665, 0.04589609848335385, 0.11528869079692022, 17.527669940676006, 79.39742660522461, 62.07157925197056, 62.451291356767925, 36.08131783349173, 30.90792540141514, 2.8201335413115363, 43.80992419379098, 30.244817120688303, 56.66153812408447, 5.58274815763746, 0.10871895868331194, 0.5576042820300374, 1.2047478279897144, 1.5290336097989763, 0.4217040315270424, 5.879294233662741, 67.6238569532122, 83.01122638157436, 77.47355379377092, 77.25468553815568, 77.86342416490827, 75.41018894740513, 74.07538441249302, 75.94301155635289, 71.84212221418107, 71.54430157797677, 66.6029303414481, 62.402980531964985, 60.56548077719552, 61.024242537362234, 60.812169619968955, 59.39288888658796, 57.501418999263215, 58.33985464913504, 58.355001722063335, 56.65287719454084, 56.96371875490461, 52.516388756888254, 49.65880312238421, 48.64477607182094, 48.28605100086757, 46.49926267351423, 48.0486866406032, 46.3835369518825, 47.767604214804514, 45.82456827163696, 45.72479561397007, 44.687175955091206, 45.96809026173183, 43.51947212219238, 45.44916752406529, 43.91524151393345, 44.446879455021445, 47.60800061907087, 49.52389342444283, 46.54253952843802, 45.700914655412944, 43.51133925574166, 44.72056204932076, 42.55485718590872, 46.28680413109915, 45.746407985687256, 47.83321605409895, 44.844604764665874, 48.90409326553345, 47.90352487564087, 52.93902335848127, 52.280014514923096, 56.87499720709664, 57.06033345631191, 59.430999755859375, 52.24213293620518, 56.713830266680034, 47.4938382421221, 42.68628583635603, 61.86008998325893, 52.10034799575806, 52.87125757762364, 50.675748416355674, 54.37152998788016, 50.64573219844273, 52.93057434899466, 50.213873863220215, 55.814003808157786, 52.398154735565186, 54.228716714041575, 55.14005981172834, 56.46802384512765, 53.18781403132847, 52.230310576302664, 57.29634986604963, 57.10213381903512, 55.430160999298096, 54.20977592468262, 51.880684171404155, 46.902153968811035, 43.414272921425955, 43.612102031707764, 42.61906896318708, 39.581069878169465, 41.2189861025129, 43.656900542122976, 43.86604131971087, 42.85449825014387, 41.65443318230765, 45.22510896410261, 45.834542410714285, 44.31590243748256, 43.63740389687674, 43.369509152003694, 44.64159229823521, 48.94162743432181, 54.26834576470511, 56.89899975912911, 55.89526299067906, 58.714140210832866, 58.7556973866054, 58.5849940436227, 56.90218898228237, 56.29054948261806, 55.51015213557652, 56.75232328687395, 59.02401597159249, 59.961675371442524, 62.49620451245989, 61.6030205317906, 61.155229977199006, 71.43932819366455, 37.671600682394846, 0.18015247237469467, 0.6967240454895156, 0.3963001961154597, 0.7002038444791521, 0.98044282410826, 0.2309752745287759, 0.06115001692835774, 8.281530976295471, 62.94277218409947, 56.7599732535226, 31.978257179260254, 72.50757203783307, 140.61988040379114, 71.77911594935826, 13.221154740878514, 18.5455584526062, 47.96564871924264, 51.291577679770334, 59.99700696127755, 2.7399682658059255, 0.2037233811404024, 0.04976702541378992, 0.05850246149514403, 0.03358583119032638, 0.030305867549031973, 0.03352242209283369, 0.05276848096400499, 0.01655734859273902, 0.01766331826469728, 0.034865568591547866, 0.037153710810733695, 0.026506290272144333, 0.019082827094410146, 0.040475726659808836, 0.015670041919552853, 0.07206588797271252, 0.06338004262319633, 0.038582820910960436, 0.08946896091635738, 0.009551108964452786, 0.02810804682251598, 0.03207687787445528, 0.08089444959270102, 0.023389597423374653, 0.2082570671503033, 0.13120877795985766, 24.707474572317942, 89.0796788079398, 68.70988818577358, 66.84286553519112, 46.06444787979126, 40.484095982142854, 10.911132318632943, 44.88221883773804, 37.78661073957171, 59.6502571105957, 5.037502603871482, 0.16680861982916081, 1.1801098414829798, 2.287962325981685, 1.0525441723210471, 1.5316923814160484, 12.444364377430507, 75.91306482042584, 83.68605627332414, 83.51464421408517, 79.7776598249163, 80.34730788639614, 77.41117981501988, 79.52203559875488, 77.4706563949585, 75.41858237130302, 71.667569569179, 70.21288776397705, 65.193113054548, 65.44270624433244, 63.970765113830566, 62.372005462646484, 62.344170979091096, 61.31539290291922, 59.74243886130196, 62.31393241882324, 58.42836080278669, 59.46173163822719, 55.45439979008266, 51.74363095419747, 50.07231821332659, 50.897649560655864, 49.54381390980312, 50.95874507086617, 49.558919293539866, 48.94716167449951, 47.514849594661165, 50.23368317740304, 46.69236700875418, 49.03736318860735, 45.04612684249878, 48.495817116328645, 46.487850257328574, 47.80298444202968, 50.525521414620535, 53.428635120391846, 49.28986419950213, 49.252913679395405, 45.59040355682373, 47.7620769228254, 44.535958835056846, 48.91447734832764, 48.06987517220633, 49.396470410483225, 47.62570462908064, 51.12633562088013, 50.49089159284319, 56.51769304275513, 55.23507990155901, 60.11657851082938, 58.977115631103516, 60.49344880240304, 54.12200975418091, 61.28712068285261, 49.521461554935996, 44.998976366860525, 64.18075357164655, 54.32048852103097, 55.68596587862287, 52.38936873844692, 56.36096600123814, 54.95224305561611, 53.36554547718593, 54.30347238268171, 56.23261887686593, 55.36466033118111, 54.731564794267925, 56.95125021253313, 58.849122864859446, 55.15513392857143, 55.71910531180245, 58.49461882455008, 59.80040768214634, 59.28749861036028, 56.811640058244976, 54.0434638432094, 49.88076680047171, 46.06019558225359, 45.850269658224924, 45.92319100243704, 42.56818730490548, 43.87892327989851, 45.227419240134104, 45.39590263366699, 44.730855805533274, 44.881006377083914, 46.57564769472395, 47.828942911965505, 46.118991238730295, 46.738701071058, 46.50244147436959, 47.5147488457816, 52.104298046657014, 55.80175065994263, 58.80695424761091, 58.595569201878135, 61.33559826442173, 59.72753497532436, 60.08472102028983, 59.05733258383614, 57.65686757223946, 59.04967566898891, 59.45973055703299, 61.620682852608816, 61.72531577519008, 64.35640403202602, 65.30149105616978, 65.2511235645839, 72.13767773764474, 46.67090054920742, 0.621806722666536, 0.19826563900070532, 0.5561097136565617, 2.315120880092893, 2.3168277485030035, 0.9313114604779652, 0.17757131159305573, 7.184783015932355, 65.76690224238804, 64.32645729609898, 37.973145553043906, 53.12103142057146, 107.19626590183803, 55.54597009931292, 21.425081287111553, 29.31154203414917, 55.31804139273507, 57.699814387730186, 70.12611171177456, 6.360669774668557, 0.3596123776265553, 0.12113820548568453, 0.0731800017612321, 0.04057423298114112, 0.030242047937852994, 0.030535660218447447, 0.05262919468805194, 0.017980904883838127, 0.04199989273079804, 0.06894969554351908, 0.022701439081824253, 0.020985725967745696, 0.011075678763778081, 0.17221473902463913, 0.17287633780922207, 0.1583127100020647, 0.1553252831633602, 0.10096324235200882, 0.16414527488606317, 0.11568036835108485, 0.1993131206503936, 0.13690377665417536, 0.14481050095387868, 0.11349891219288111, 0.3108265240277563, 0.3202552566570895, 30.1331421988351, 103.74870872497559, 78.04318795885358, 80.24261937822614, 51.81278984887259, 44.08804668698992, 7.390013694763184, 63.735228129795615, 48.64215660095215, 71.20045607430595, 7.109801096575601, 0.1682890203914472, 2.373074936015265, 3.396056694643838, 6.299179954188211, 3.066668003797531, 16.24256934438433, 79.57154151371547, 91.12963363102504, 86.46763556344169, 84.6898694719587, 82.6798459461757, 79.53864874158586, 82.82611247471401, 81.01120131356376, 78.00370829445976, 75.29980986458915, 72.65187222617013, 68.43779672895158, 68.00593144553048, 67.9937026160104, 66.43181010654995, 67.49400206974575, 65.72719328744071, 62.719498770577566, 65.83792672838483, 63.45340919494629, 63.29836709158761, 58.405466488429475, 54.527242592402864, 53.8305675642831, 54.4720322063991, 50.81085613795689, 53.882133620125906, 53.086742060525076, 52.13308790751866, 50.93376977103097, 52.78609698159354, 49.54631873539516, 51.720517771584646, 47.420506954193115, 51.20899486541748, 49.741156646183555, 51.32902152197701, 53.07479463304792, 55.21409634181431, 51.187347752707346, 51.91215603692191, 48.20303739820208, 50.58961854662214, 47.382663590567454, 52.00420924595424, 50.9760182925633, 53.699687821524485, 50.56589044843401, 54.992174352918354, 54.62768227713448, 60.400391578674316, 59.08878707885742, 62.89768532344273, 63.08917767660958, 63.688126291547505, 57.53546864645821, 62.758429527282715, 51.97487047740391, 49.43488005229405, 66.86172989436558, 57.94312293188912, 59.031791005815776, 56.55384104592459, 59.04110854012625, 57.97444888523647, 55.88509430204119, 57.46387440817696, 62.0129086630685, 57.34412220546177, 58.52725451333182, 60.28662872314453, 62.560676847185405, 58.06837115968977, 57.766548361097065, 61.74862698146275, 61.98607472011021, 61.69812747410366, 60.60359164646694, 57.49868835721697, 51.26322555541992, 48.308983530317036, 49.21196099690029, 47.25431646619524, 45.62149674551827, 45.41598640169416, 46.60644905907767, 47.95090116773333, 47.32355873925345, 47.973006861550466, 50.08404677254813, 48.81325946535383, 48.598935331617085, 50.59306137902396, 48.92270401545933, 49.19340583256313, 55.75562851769583, 59.74057674407959, 62.78076798575265, 61.47041416168213, 64.09444304874965, 63.67231913975307, 64.59284428187779, 61.497901235307964, 61.362036160060335, 62.50356960296631, 61.529098646981375, 65.1698226928711, 65.76827798570905, 68.3908338546753, 68.3932796205793, 68.34884589059013, 75.09602614811489, 45.37279292515346, 0.5615598154919488, 3.2191855226244246, 5.9771109734262735, 6.86093008518219, 3.9947629911558966, 0.8490529858640262, 0.16945249081722327, 10.706608619008746, 75.17651408059257, 70.50099481855119, 47.781000341687886, 88.47426142011369, 154.54156902858188, 82.33660493578229, 22.664542640958512, 29.868266446249827, 65.10421085357666, 66.21044744764055, 82.16879899161202, 7.371258769716535, 0.3952533522886889, 0.10582791095865623, 0.19371291329818113, 0.1374719004545893, 0.07573925264711891, 0.15928963758051395, 0.16914702792252811, 0.10004723364753382, 0.1297494526952505, 0.23439161692346844, 0.1548384614288807, 0.1820460736219372, 0.131686534466488], [0.06381965867642846, 0.09110410138964653, 0.038678674160369804, 0.04126485949382186, 0.03605547813432557, 0.001783885951486549, 0.021017997093232613, 0.051414952879505496, 0.07343426918877022, 0.033630807884037495, 0.09119991731962987, 0.09867619257420301, 0.437765009701252, 42.88648080825806, 74.3045151574271, 63.27455561501639, 52.18826355252947, 31.945777824946813, 18.037097964967998, 71.72446141924176, 42.63132905960083, 37.18930537360055, 45.42181594031197, 0.14323468479726995, 0.0279452289521162, 1.686459162405559, 0.8116966475333486, 0.6056563407182693, 1.5185382472617286, 40.790351731436594, 80.6562317439488, 70.54713085719517, 78.86636883871896, 70.67781257629395, 77.39644963400704, 73.5636009488787, 77.16749259403774, 73.56621347154889, 75.19671249389648, 69.52699634007045, 69.36844539642334, 65.34516048431396, 62.30089065006801, 55.651092869894846, 54.80208553586687, 51.746997356414795, 55.89443962914603, 52.12571586881365, 52.8802033833095, 51.376651423318044, 50.22920158931187, 46.18812928880964, 49.58816426140921, 47.70693949290684, 48.33780813217163, 49.173447132110596, 48.29311384473528, 44.091301918029785, 45.73310913358416, 45.169433048793245, 46.56887320109776, 46.81233460562569, 45.344291414533345, 43.491943359375, 44.60905735833304, 42.087820121220176, 44.43790585654122, 48.884256158556255, 52.88462938581194, 48.14065299715315, 47.002697876521516, 43.80080120904105, 43.13020624433245, 41.62391669409615, 43.01170124326433, 43.1874281338283, 43.61226878847395, 44.85211229324341, 47.85413360595703, 45.78535611288888, 50.58650575365339, 48.39342846189226, 54.309169905526296, 51.41986574445452, 57.42666680472237, 52.26434980119978, 61.941599300929475, 38.300520351954866, 40.31136376517159, 63.33768694741385, 51.252525329589844, 51.97346346718924, 52.26145587648664, 53.28962598528181, 50.122428621564595, 50.61010183606829, 51.332412242889404, 55.02526862280709, 51.960949761526926, 53.239567688533235, 52.02493919645037, 54.93440702983311, 52.08465896333967, 53.40071031025478, 52.87848717825753, 54.34376498631069, 55.22942059380667, 53.65284306662423, 50.32152925218855, 48.6040735244751, 45.17383473260062, 43.79716035297939, 43.56392322267805, 41.31955432891846, 40.30988727297102, 42.06654821123396, 44.133036272866384, 41.372256415230886, 41.39351442881993, 42.57810238429478, 44.88576936721802, 46.04022298540388, 43.67857892172677, 43.97690677642822, 45.46379695619856, 47.76648555483137, 51.55604348863874, 51.43370655604771, 53.73143761498587, 54.07219464438302, 51.83070577893938, 53.23461709703718, 51.04610824584961, 50.04818017142159, 52.606565952301025, 54.06259570802961, 54.066326890672954, 54.348323004586355, 57.80141789572579, 56.005805356161936, 64.4801583971296, 61.56736237662179, 74.089857510158, 35.31238848822457, 0.10987349280289241, 0.7914972028562001, 1.568541175552777, 1.1181864099843162, 0.6232198125549725, 0.021223092784306834, 0.29171496097530636, 31.82770708629063, 78.29524081093925, 42.022461891174316, 61.33245767865862, 106.41764381953648, 116.82912336077008, 53.65279790333339, 8.335921474865504, 45.57771267209734, 47.9134156363351, 65.59595571245465, 17.956512757710048, 0.4520704820752144, 0.050775752535888126, 0.10643882996269635, 0.016637600625732114, 0.061454509517976215, 0.009426598636699575, 0.02268231626866119, 0.029481868193085705, 0.05994659436068364, 0.045435166252510886, 0.0259757098143122, 0.020618853957525322, 0.08818560013813631, 0.07583143841475248, 0.06762383133172989, 0.053799474212740145, 0.08476104068436793, 0.028758621109383445, 0.03564684059736984, 0.04368167909394417, 0.03360224495242749, 0.0780689754922475, 0.0374986508728138, 0.04299364458503468, 0.06608387575085674, 0.24551535717078618, 57.06968920571463, 82.84089824131557, 70.34885011400495, 62.62874834878104, 46.15935679844448, 26.703377621514456, 49.933583532060894, 40.93609367098127, 45.532532010759624, 48.16778918675014, 0.05189773054527385, 0.21703535611076014, 2.7888078050954, 2.7208083910601477, 0.2712765091231891, 1.8546066539628165, 51.63533285685948, 83.26161861419678, 75.81471306937081, 79.64392784663609, 74.43483557019914, 80.07593209402901, 75.78598226819719, 78.17013154711042, 78.46722957066127, 75.90368475232805, 73.13734980991909, 72.35939475468227, 67.03609493800572, 65.18032142094204, 58.472405433654785, 57.73051152910505, 54.49679211207798, 57.61656107221331, 54.40678514753069, 54.997774600982666, 53.70965501240322, 52.712484291621614, 49.459591320582796, 51.17136342184884, 51.08636958258492, 50.84510380881173, 51.1776967048645, 50.42310496738979, 48.02090079443795, 47.4411952154977, 47.11493560246059, 49.90904596873692, 47.49222278594971, 47.669999395098, 44.24528442110334, 45.618807792663574, 44.32111011232649, 45.56287131990705, 50.86900561196463, 54.60116447721209, 51.49477079936436, 49.447296483176096, 45.617084639413015, 46.2779278073992, 46.29681995936802, 46.2957638331822, 46.11343615395682, 45.35114581244332, 47.277096135275706, 48.9001327923366, 48.306006227220806, 55.04986524581909, 51.76861320223127, 56.584697995867046, 54.83704539707729, 57.4923620223999, 55.735815729413716, 63.4255747113909, 45.916496413094656, 45.67938566207886, 64.76406179155622, 53.95274468830654, 54.72457838058472, 54.386569363730295, 54.70833349227905, 54.580007212502615, 52.39576802934919, 54.393899713243755, 56.22455201830183, 55.87936551230294, 56.744006293160574, 53.46957738058907, 56.9047771862575, 55.95568452562605, 53.77947746004377, 54.12285396030971, 58.23663221086775, 55.86355488640921, 57.08037206104824, 54.37709549495152, 50.28932087762015, 47.907124042510986, 45.426123823438374, 47.28125810623169, 42.26326213564192, 41.947998046875, 45.42823954990932, 46.1146833556039, 44.343455518995015, 43.01424775804792, 46.0995432308742, 46.61343894686018, 46.58160924911499, 46.2425024168832, 46.81391532080514, 46.82169730322701, 50.27740124293736, 52.79581751142229, 54.45339713777815, 54.903199195861816, 55.1862792287554, 54.183643749782014, 53.73506457465035, 53.079279695238384, 53.80319166183472, 53.59203938075474, 55.89150748934065, 56.71577228818621, 58.353966440473286, 58.91814626966204, 59.36763218470982, 64.95740931374687, 63.63780048915318, 75.51349476405552, 44.9734764780317, 0.7343124427965709, 0.5724903089659554, 1.09139361338956, 3.660383105278015, 1.0963769916977202, 0.06251220990504537, 0.10719231595950467, 30.93641996383667, 84.03261157444545, 48.908550534929546, 59.97641250065395, 100.53402737208775, 102.94456590924943, 52.53219938278198, 15.613588878086635, 53.23308154514858, 51.620599201747346, 72.52680465153286, 27.227567093712942, 0.39638571866921013, 0.1000840916697468, 0.07890216899769646, 0.023169855553922907, 0.0644006407154458, 0.03173771553805896, 0.035446021373250654, 0.03497908410749265, 0.030442151307527508, 0.051063794043979475, 0.009153886931017041, 0.051512570319963355, 0.033000903470175605, 0.2289633367742811, 0.17219519721610205, 0.13211980621729577, 0.13753367428268704, 0.1408050815973963, 0.1157153807580471, 0.16063784595046723, 0.1251056268811226, 0.2076865549066237, 0.18485472005392822, 0.15007127794836247, 0.180604756676725, 0.5331532997744424, 67.98405156816754, 93.6135173525129, 81.31417751312256, 72.30797113691057, 45.77897071838379, 27.916298593793595, 90.60185541425432, 58.88778264181954, 52.311302253178184, 56.82280233928135, 0.3174722045660019, 0.4537454050566469, 4.946188943726676, 6.931474711213793, 3.5631296038627625, 5.482733615807124, 52.81299693243844, 87.26625456128801, 79.33969402313232, 81.29282569885254, 77.71389893123082, 84.89245809827531, 78.65467807224819, 81.91851098196847, 80.24504429953438, 80.40754181998116, 76.27215467180524, 75.84024769919259, 70.753402028765, 67.27451542445591, 62.003632817949565, 60.122998646327424, 57.29735040664673, 61.43499224526541, 58.30539158412388, 58.975760732378276, 57.73266894476754, 56.19881589072091, 51.48048530306135, 54.41219432013375, 54.29105942589896, 54.14316007069179, 52.92569671358381, 52.61809648786272, 50.0577825818743, 51.61243159430367, 49.7777111189706, 52.68724148614066, 50.67362226758684, 51.43681240081787, 47.178480352674214, 48.17746107918875, 48.335977281842915, 47.62355068751744, 52.81886468614851, 58.31495925358364, 54.47796596799578, 52.72543225969587, 49.4837258883885, 47.53059073856899, 47.462234360831125, 47.7984298978533, 47.73931115014212, 47.34624113355364, 51.06480584825788, 53.34792831965855, 51.046174253736226, 58.15106514522007, 55.372577803475515, 59.84996223449707, 59.24856785365513, 61.02001108442034, 57.055372442517964, 65.09704726082938, 51.009258474622456, 50.331569399152485, 68.73220579964774, 57.464940956660676, 56.28233323778425, 57.78293568747384, 57.343764373234336, 56.8409023966108, 54.5977702822004, 57.635956968579976, 60.30124078478132, 58.46933432987758, 58.80493232182094, 57.20695434297834, 58.99055344717843, 57.380037443978445, 57.508124010903494, 57.796748706272666, 61.609009878976, 58.054314953940256, 60.5647303717477, 55.691368103027344, 54.35950265611921, 50.02768298557827, 49.313658305576865, 48.43202917916434, 45.77216148376465, 45.44243819372994, 47.0652733530317, 48.11364882332938, 48.26759311131069, 44.93286773136684, 48.899681159428184, 49.50525835582188, 50.406550884246826, 49.14901726586478, 49.169073241097585, 50.67126682826451, 52.78648260661534, 57.241900307791575, 58.40705067770821, 58.71082592010498, 60.072596413748606, 57.498907225472585, 57.6921192577907, 55.58263921737671, 57.74389375959124, 57.72442838123867, 59.28346170697893, 59.368813378470286, 60.766380991254536, 62.6113292149135, 63.47571986062186, 67.30326012202671, 68.50253309522355, 80.98538875579834, 44.23813125065395, 0.7344556408269065, 5.311383656093052, 6.57951067175184, 6.468444585800171, 2.120491632393428, 0.1493791179465396, 0.4781558652009283, 40.16189064298357, 90.66224915640694, 54.849079677036826, 70.92393861498151, 104.9511500767299, 122.49986784798759, 67.72980308532715, 17.132809025900706, 63.32494395119803, 61.431761332920615, 85.16047096252441, 30.537537779126847, 0.43220824216093334, 0.19350103395325796, 0.25240905582904816, 0.19182140193879604, 0.1460052654147148, 0.08457296434789896, 0.08444900278534208, 0.1178283795182194, 0.14365323233817304, 0.10356608911284379, 0.11220315457986933, 0.2063171219612871, 0.14587111904152802], [0.032874217589518855, 0.06040176922189338, 0.07749750651419163, 0.03752135804721287, 0.1299337563770158, 0.05657767477844443, 0.05744039812790496, 0.03718028563473906, 0.05010187566014273, 0.06363025241132293, 0.08223647650863443, 0.11747147009841033, 4.543031445571354, 72.77291679382324, 60.16916247776577, 65.5088391985212, 38.70651749202183, 18.08834614072527, 27.283824920654297, 69.27658326285226, 35.81478146144322, 67.0493243081229, 25.68617524419512, 0.18657011086387293, 1.0582831672259738, 1.194698344383921, 2.461618001971926, 0.9076788457376617, 12.709658758980886, 73.89103480747768, 75.53652804238456, 76.29612595694405, 74.27480466025216, 72.71592766898019, 71.19099957602364, 73.43257181985038, 73.35006890978131, 72.29621478489467, 75.66665390559605, 74.96278749193463, 75.24883093152727, 65.45538670676095, 61.88708373478481, 56.54972423825945, 53.80659975324358, 53.21714585168021, 51.526444162641255, 50.39757033756801, 48.813030174800325, 48.36874846049717, 46.36842461994716, 45.454910210200715, 47.86810990742275, 48.025528294699534, 49.697501114436555, 47.23257555280413, 44.87923111234392, 45.748336110796245, 44.85967540740967, 43.79774052756173, 45.98790652411324, 45.264446190425325, 44.98843594959804, 42.97461175918579, 43.587164946964805, 41.45084054129464, 46.05148948941912, 47.243025643484934, 52.67066308430263, 50.09964895248413, 48.38603557859148, 44.98966230664934, 43.074353149959016, 40.3344943182809, 45.12756667818342, 41.04378727504185, 44.99733311789376, 41.53827319826399, 45.27168273925781, 43.619314261845176, 49.40761879512242, 48.36377007620675, 51.594463552747456, 45.31632144110543, 56.81706312724522, 48.535272462027415, 68.07753263201032, 21.760269335338048, 25.32193156651088, 69.50043337685722, 45.61845690863473, 55.181651728493826, 46.416464465005056, 50.09349979673113, 45.655793053763254, 51.46674871444702, 51.863602025168284, 58.35505035945347, 51.91415711811611, 57.813299315316335, 52.82897431509835, 55.50282178606306, 50.38533108575003, 53.423385756356375, 47.22761453901018, 48.57092366899763, 53.795798778533936, 51.317140102386475, 52.0136935370309, 47.805079323904856, 47.002826418195454, 43.448058537074495, 41.75319487707955, 41.564304624285015, 39.35294662203108, 40.89447396142142, 41.49705301012312, 42.21287032536098, 39.8147725377764, 40.13631084987095, 43.73555415017264, 46.025068964277, 43.55778796332223, 44.148231983184814, 42.41444798878261, 45.175884451184956, 47.06026370184762, 47.87875802176339, 46.95998729978289, 48.45959268297468, 45.79608760561262, 46.7429325239999, 45.61289487566267, 48.47209596633911, 49.37705714362008, 52.5444073677063, 53.09114721843174, 55.933095932006836, 50.361606461661204, 55.14928354535784, 57.499807017190115, 60.40623501368931, 59.71739060538155, 70.94006538391113, 29.837159361158097, 0.3504302517643997, 1.329983570746013, 2.4456037070069994, 1.7256585104124886, 0.08069207652338914, 0.0842302566660302, 5.951852100236075, 61.03356007167271, 56.99897391455514, 41.39049891063145, 72.90489782605852, 71.81016744886125, 18.72284173965454, 22.42765944344657, 32.4509778703962, 55.069077014923096, 55.15609972817557, 47.034235749925884, 1.0566672767911638, 0.07092067013893809, 0.058818109200469086, 0.024067738891712258, 0.0107011291298217, 0.03835503670520016, 0.05212985398247838, 0.022254148797531213, 0.05555665260180831, 0.09981667423354727, 0.06297840417495795, 0.02710706178498055, 0.01675654442182609, 0.019619926577433944, 0.023040292684787085, 0.02714460512756237, 0.046577279788575, 0.05687604019684451, 0.02849001284422619, 0.06288173329085112, 0.04034154975254621, 0.030970472243747542, 0.05424397911078163, 0.07755858823657036, 0.19538095593452454, 6.875186051641192, 86.3168943950108, 66.96325697217668, 76.14042377471924, 45.98172957556588, 29.202604702540807, 25.334511280059814, 54.079267910548616, 41.375925064086914, 73.00039386749268, 26.891034569059098, 0.4318027224923883, 1.3772723589624678, 1.6508225032261439, 3.339733511209488, 2.0089163737637654, 19.567475182669504, 82.64998953683036, 76.0519801548549, 80.41813782283238, 75.25829437800816, 76.9192681993757, 75.25307628086635, 75.8043463570731, 73.11533791678292, 75.58767373221261, 77.98649760654995, 74.89561925615583, 75.24815695626395, 67.87181731632778, 65.88543851034981, 59.24424607413155, 57.01172038487026, 55.497106892721995, 55.58530037743704, 50.947885036468506, 51.225378717694966, 51.85545526232038, 49.02142054694039, 48.09786251613072, 50.698997088841026, 51.36790711539132, 50.16692835944039, 49.84143999644688, 47.31976154872349, 46.876188550676616, 48.376777103969026, 46.10494892937796, 47.669436591012136, 47.97757182802473, 46.440988131931846, 44.8442781993321, 46.302284717559814, 45.22216640199934, 49.016400473458425, 50.79959658214024, 54.07371629987444, 51.42429174695696, 51.296017578669954, 48.43946722575596, 45.88963120324271, 43.94656746728079, 46.90805993761335, 45.83838129043579, 48.322195529937744, 44.91200229099819, 46.91153056280953, 48.2283844266619, 51.27864360809326, 51.36199767248971, 50.85560948508126, 49.928928239004954, 56.88420704432896, 54.46858589989798, 64.92810876028878, 42.57559061050415, 43.449833801814485, 66.69181169782365, 49.71530934742519, 54.92989764894758, 50.40905570983887, 53.876901626586914, 50.89088201522827, 53.017232281821116, 52.576990944998606, 57.96409606933594, 54.982047353472026, 58.51185730525425, 55.31865978240967, 56.66440773010254, 53.490154470716206, 55.655911445617676, 50.50050442559378, 51.794210365840364, 56.729762486049104, 54.57822152546474, 54.08298519679478, 49.77330248696463, 49.62181438718523, 46.978952407836914, 44.555896690913606, 44.67771945680891, 41.12075594493321, 43.65023374557495, 44.33564574377877, 44.61591523034232, 43.31223862511771, 43.58407647269112, 45.720338344573975, 47.13793066569737, 45.09195021220616, 45.06675951821463, 45.15642602103097, 48.15089464187622, 47.4493419783456, 50.86105339867728, 49.13195596422468, 50.66664627620152, 49.21506684167044, 48.82371997833252, 47.69856343950544, 50.6528263092041, 52.46027510506766, 53.47469820295061, 54.66951043265206, 58.250497341156006, 52.835085255759104, 57.35929707118443, 60.262108530317036, 62.56215681348528, 63.389221736363, 72.8293570109776, 38.003199986049104, 0.935193657875061, 0.7243393350924764, 1.7633784349475587, 2.097321778535843, 0.5536499970725605, 0.14252598211169243, 4.873910742146628, 63.32606955936977, 65.62742410387311, 48.27464205878121, 69.46964590890067, 77.5800210407802, 25.210159369877406, 28.641885076250347, 43.12579761232649, 60.51712131500244, 59.96496186937605, 56.65241166523525, 2.0129319982869283, 0.06672485385622297, 0.05044252398822989, 0.04846368177926966, 0.03404486691579223, 0.03154226691861238, 0.006216993563741977, 0.0328973861677306, 0.019582254313198582, 0.11177419831178018, 0.016639970409284745, 0.06286320249949183, 0.012141688660319363, 0.14715154176311834, 0.23530386654394014, 0.22654583863914013, 0.10640334258122103, 0.22533085383474827, 0.10141677515847342, 0.23982385971716472, 0.16515744557338102, 0.16597426602882998, 0.22673873257424149, 0.30418230912515093, 0.6005478405526706, 8.718442388943263, 101.34606334141323, 76.11153316497803, 84.70322390965053, 54.504247529166086, 28.189093555722916, 39.96589238303048, 89.09927272796631, 51.337755407605854, 83.29291330065045, 32.39529848098755, 0.42232190551502363, 2.4602528980800082, 3.7107584135872975, 6.280544885567256, 3.7994929892676215, 20.574649572372437, 89.06940242222377, 79.23812525612968, 86.01771191188267, 79.1578596660069, 82.50122165679932, 76.57994597298759, 82.04933861323765, 75.19991561344692, 78.07751900809151, 77.87620190211705, 79.05834061758858, 75.55568422589982, 71.64844812665666, 69.63482543400356, 63.915652002607075, 59.03652967725481, 59.098153250558035, 60.158733231680735, 56.77834776469639, 54.24098028455462, 54.14684956414359, 51.327340057918, 50.27088730675833, 53.86218881607056, 54.84408392224993, 52.29325430733817, 52.95696013314383, 48.79638229097639, 50.03747647149222, 50.55213301522391, 49.361260414123535, 51.59496034894671, 51.02249479293823, 48.458018915993826, 47.633729798453196, 49.1892786026001, 48.577503613063264, 51.06429862976074, 52.12955822263445, 59.31265803745815, 55.75384977885655, 53.479714802333284, 53.10836485454014, 48.2449836730957, 45.956174101148335, 50.54756804874965, 48.836188520704, 51.06790474482945, 47.4573324067252, 50.51523460660662, 50.41010141372681, 55.74424042020525, 54.42509365081787, 55.055990082877024, 53.09622982570103, 60.480782236371724, 56.53702987943377, 66.69586944580078, 40.560272557394846, 44.984902790614534, 69.15990216391427, 54.659310477120535, 56.63219935553414, 52.99869796207973, 56.458212988717214, 53.661288602011545, 55.225342001233784, 55.932974338531494, 61.963791847229004, 57.426659856523784, 61.870880535670686, 58.09858887536185, 59.41552611759731, 56.80289922441755, 59.42539950779506, 53.47773456573486, 54.168302127293174, 58.51149599892752, 57.7350035394941, 57.86345836094448, 53.206511633736746, 53.7640837260655, 50.235371589660645, 48.50523887361799, 47.03953375135149, 44.01645939690726, 48.31429542813982, 46.56142125810896, 48.989173957279746, 45.353372710091726, 45.53504031045096, 48.16458606719971, 49.74388034003121, 47.61628981998989, 48.20672689165388, 49.41695369992937, 51.10481704984392, 51.73553630283901, 54.949244907924104, 53.47806460516793, 54.21603972571236, 50.82748665128435, 52.75682422092983, 50.922482422419954, 54.01960025514875, 55.40515443256923, 57.99186454500471, 58.394585609436035, 61.87204088483538, 55.62838268280029, 61.299988746643066, 63.62614141191755, 66.66002368927002, 66.51524407523019, 74.37427507128034, 37.824450629098074, 0.9910276447023664, 4.802884084837777, 8.421342628342764, 6.869341313838959, 0.6771738231182098, 0.140972516898598, 7.915341803005763, 74.36304678235734, 69.45928614480155, 57.90146500723702, 73.81652232578823, 79.45186574118478, 25.19948172569275, 32.45354870387486, 50.0265782220023, 71.6265960420881, 70.19769205365861, 66.22857529776437, 2.549777397087642, 0.11439219675958157, 0.15089602369282926, 0.1458010942276035, 0.0746852434905512, 0.11444536676364285, 0.13307103088923863, 0.13809219002723694, 0.09083806816488504, 0.31349522939750124, 0.09823490053947483, 0.19427984287696226, 0.0820374825437154], [0.06165685544588736, 0.03711641513343368, 0.15603421655084404, 0.0438786103124065, 0.047355427140636105, 0.052216326485254934, 0.025246688397601247, 0.02927092183381319, 0.07414753162967307, 0.11090244366122143, 0.13729841262102127, 0.41787123147930416, 25.596277713775635, 72.30305876050676, 59.85153252737862, 60.198803492954795, 49.451145785195486, 20.79335801942008, 39.89840105601719, 42.23172426223755, 33.26677628925869, 74.12624522617885, 5.967419973441532, 0.011709158209019473, 1.0935353956052234, 2.577393880912236, 0.9845888359206063, 0.3853633515536785, 46.31862340654646, 79.2832260131836, 70.31128815242222, 71.84294210161481, 70.4481120790754, 71.6801666532244, 72.25503281184605, 73.71034690311977, 73.86831419808524, 75.32783889770508, 73.36695303235734, 73.66217504228864, 68.57096590314592, 65.1064064843314, 61.82930946350098, 59.2434470312936, 52.94760438374111, 48.553528853825156, 48.465092182159424, 46.13926955631801, 48.69651583262852, 45.592112813677105, 47.238926206316265, 47.2983124596732, 46.54782363346645, 45.76378195626395, 48.83174514770508, 45.782003607068745, 45.66491256441389, 44.54465103149414, 44.36058630262102, 43.10097517286028, 45.32220309121268, 44.31632627759661, 44.29091671534947, 42.262574263981406, 44.12087345123291, 42.23188407080514, 47.88150256020682, 46.53606380735125, 52.31230626787458, 49.6523517199925, 51.824303013937815, 44.5078637940543, 48.39357437406267, 45.176190171922954, 47.85678434371948, 44.60972091129848, 46.72014243262154, 41.40814733505249, 42.73550687517439, 39.66639028276716, 51.45479086467198, 46.198534216199604, 59.1409888948713, 42.96084042957851, 59.623777525765554, 43.25310945510864, 76.19523116520473, 5.87544276033129, 6.345873585769108, 77.4358320236206, 41.696233545030864, 58.84199401310512, 43.850724015917095, 53.61269637516567, 41.07967472076416, 53.93234825134277, 54.92248044695173, 59.58524281638009, 49.76575674329485, 54.54439422062465, 50.14898811067854, 55.4818833896092, 49.83885179247175, 51.99165037700108, 45.34311369487217, 42.11545658111572, 44.80818925585066, 46.56264066696167, 46.74272060394287, 45.83057151521955, 44.107824734279085, 45.355248723711284, 40.7575249671936, 42.79542466572353, 36.62134919847761, 37.24518278666905, 39.31637825284685, 41.097455160958425, 37.89655555997576, 39.86993081229073, 41.967956747327534, 45.61821372168404, 43.48270225524902, 41.861298424857004, 41.182007789611816, 42.80532237461635, 43.87417071206229, 43.55486624581473, 43.206719807216096, 46.78229406901768, 43.851342405591694, 47.09129088265555, 49.32886791229248, 51.40048721858433, 52.37143891198294, 54.60546541213989, 54.50643621172224, 58.49089459010533, 52.78731986454555, 55.236017908368794, 55.480194977351594, 55.88932228088379, 62.196118763514924, 63.78072493416922, 61.83431911468506, 25.39515515736171, 0.0748336933819311, 1.6598098895379474, 1.0910625968660628, 0.6022141054272652, 0.21370830892452172, 0.1196775638631412, 33.41904953547886, 67.59671728951591, 46.776005949292866, 35.22602237973894, 31.28624439239502, 22.22521846635001, 18.379277638026647, 22.46817786352975, 54.79867049625942, 44.8824793951852, 58.31059578486851, 11.765706028257098, 0.3115501951958452, 0.013078109394492847, 0.08028000899191413, 0.05389063199982047, 0.04441128744344626, 0.020958431896620562, 0.032337062127356014, 0.1047606635838747, 0.05234947880463941, 0.021874603449500034, 0.010491058080723243, 0.08911749334739787, 0.04340910818427801, 0.024585101487381116, 0.06662713802818741, 0.024606714524062615, 0.03550289278583867, 0.008414027613720723, 0.06528091776583876, 0.04483007586428097, 0.03084948266457234, 0.14216695566262516, 0.05354957655072212, 0.3344529505286898, 31.93301398413522, 83.31939288548061, 68.09386089869908, 70.41660894666398, 62.921323095049175, 30.14232771737235, 35.93061140605381, 42.30762638364519, 40.34049408776419, 82.25214958190918, 5.255001195839473, 0.048300063237547874, 1.296383710844176, 3.6112565185342516, 0.5525621154478618, 3.0058575868606567, 57.01759161267962, 80.34067235674176, 76.02248505183628, 72.70927129473004, 75.38572434016636, 73.56794357299805, 75.14120333535331, 77.03290598733085, 74.79445348467145, 75.97540405818394, 75.38370241437639, 75.22485964638847, 71.7480366570609, 66.36967931474958, 62.131257329668315, 61.85790130070278, 56.65053217751639, 52.62898431505476, 51.580997943878174, 49.90344224657331, 50.629761763981406, 49.79050970077515, 48.03547464098249, 48.73909786769322, 50.22623470851353, 48.14753866195679, 51.58149821417672, 47.16738060542515, 48.988333225250244, 47.55790410723005, 48.267047677721294, 46.34937613351004, 46.8598290170942, 49.0358623777117, 47.318677629743306, 45.14412770952497, 47.10853978565761, 44.13315091814314, 49.61987236567906, 48.87829807826451, 54.80451740537371, 53.917357512882774, 53.81815808159964, 48.27303007670811, 49.347985880715505, 46.74860920224871, 49.37572308949062, 47.71793849127633, 50.18745681217739, 44.030453068869456, 46.02138294492449, 42.91832787649972, 52.86142240251814, 47.99826356342861, 58.92154393877302, 46.368674755096436, 61.24446569170271, 46.80163785389492, 75.73672648838588, 20.977744102478027, 18.938473871776036, 76.1214690889631, 44.68714121409825, 59.566315923418315, 49.18125690732683, 55.43704319000244, 45.520390033721924, 54.13875491278512, 57.187697410583496, 61.33440317426409, 53.60988582883562, 56.47375610896519, 53.57294920512608, 55.94071115766253, 51.68084008353097, 54.94767114094326, 47.62035799026489, 46.00259849003383, 47.87250116893223, 48.60010610307966, 48.7550995690482, 47.72604703903198, 46.676865577697754, 46.287321771894185, 42.32972512926374, 45.78004421506609, 40.02645983014788, 40.46422413417271, 43.54175846917288, 43.28364331381661, 42.3377502986363, 41.31523254939488, 44.710799830300466, 47.173474175589426, 44.82980857576643, 43.88834503718785, 44.62863390786307, 45.964765548706055, 46.00793123245239, 45.798432622637065, 46.228084904806956, 47.78861904144287, 46.84043659482683, 49.70575557436262, 51.55210386003767, 53.60559531620571, 57.05099160330636, 58.07482951028006, 58.27293307440621, 60.40111419132778, 56.01644999640328, 57.597641127450125, 60.11043630327497, 56.1650823865618, 64.34306349073137, 65.00738770621163, 66.94090461730957, 32.81079033442906, 0.919048975620951, 1.4417858400515147, 1.8872078188828059, 1.462457490818841, 0.3922481749738966, 0.041367104543106895, 34.697174140385215, 75.48088686806815, 57.02209751946585, 38.98793690545218, 34.34703009469168, 19.668482882635935, 20.790893145969935, 32.103241375514436, 59.693864004952566, 52.735375131879536, 66.8081453868321, 18.65782744543893, 0.4595851216997419, 0.11163931912077324, 0.08121097260820014, 0.09819042256900243, 0.045575117492782216, 0.18831321304397924, 0.08800995456320898, 0.0814280698874167, 0.06543085364890949, 0.029825810808688402, 0.03795898599284036, 0.02137840605740036, 0.10539000481367111, 0.10296905293528523, 0.2533733626561505, 0.19851380639842578, 0.21325876590396675, 0.18365497514605522, 0.09871940168419055, 0.09988271604691233, 0.12223838216492108, 0.30852121487259865, 0.36476112848946024, 0.36680737297449795, 39.36529704502651, 94.55794429779053, 76.36581638881138, 77.66061319623674, 66.56249877384731, 31.714545249938965, 55.14491660254342, 60.65350750514439, 46.7722157069615, 90.67882755824498, 7.377883877073016, 0.16578344841088566, 3.8502009425844466, 8.073012062481471, 6.371605804988316, 5.791429051331111, 61.82632868630545, 85.83119446890694, 79.60371167319161, 76.00159181867326, 78.4200165612357, 75.33651719774518, 77.75474044254848, 77.37350668225969, 77.92363030569894, 78.40884385790143, 76.79965496063232, 78.27266611371721, 76.77262646811349, 70.40656879970005, 67.96129621778215, 65.00781849452427, 59.27431092943464, 55.98368229184832, 55.245099203927175, 53.35005446842739, 53.63176570619856, 51.61828892571585, 52.50585181372506, 50.88633441925049, 53.446676118033274, 50.53276143755232, 53.64253888811384, 50.280923979622976, 51.481972217559814, 50.68181766782488, 50.33327170780727, 49.36361585344587, 48.79254688535418, 51.77300098964146, 49.38655185699463, 47.06353282928467, 50.82346364430019, 46.989002977098735, 54.02460643223354, 50.25118568965367, 57.02226080213274, 56.45510714394705, 56.78271123341152, 51.06108161381313, 52.886571407318115, 50.52176243918282, 52.788289138248985, 49.398912702287944, 52.88968072618757, 45.69946248190743, 48.33665125710623, 44.35318299702236, 55.697791712624685, 51.85669551576887, 64.94793891906738, 48.42389978681292, 65.80722958700997, 48.334782191685264, 82.15732056753976, 13.349684255463735, 13.569103155817304, 82.66927078792027, 46.95917436054775, 66.2322369984218, 51.35625498635428, 59.236978258405415, 45.88550397327968, 57.72183322906494, 61.43980734688895, 65.9028159550258, 54.634752069200786, 60.90506703513009, 56.3461628641401, 60.244091851370676, 54.956672532217844, 58.110463346753804, 52.26109804425921, 47.40162869862148, 53.179997307913645, 50.845909799848286, 53.21598202841622, 50.179546288081575, 50.84743840353829, 51.570433207920615, 46.115062032427105, 48.6868508883885, 42.342666149139404, 42.760169506073, 46.13953011376517, 45.53042670658657, 44.0896760395595, 46.27148682730538, 47.888728686741416, 49.96691404070173, 47.45712743486677, 47.30260992050171, 45.26026684897286, 48.07024342673165, 50.2346316065107, 47.80726800646101, 48.62506750651768, 50.57079587663923, 49.61022826603481, 52.55560438973563, 55.28544739314488, 57.36392804554531, 60.394791330610005, 60.281452315194265, 61.01966367449079, 63.07908194405692, 57.32958657400948, 60.701026235307964, 62.99644701821463, 60.61053984505789, 69.15453120640346, 68.96547072274345, 68.39183439527238, 31.573326587677002, 0.6556530264871461, 8.226956350462777, 5.221319368907383, 1.5362458399363925, 0.6441162484032767, 0.18061486684850284, 44.08859212057931, 82.22520446777344, 61.583148683820454, 47.37988083703177, 43.262458256312776, 29.295019217899867, 27.872524942670548, 34.481147697993684, 68.52555247715541, 60.19504451751709, 79.12531430380685, 22.850464275905065, 0.6672452815941402, 0.25883890794856207, 0.22765704829777988, 0.171687978718962, 0.2714766226708889, 0.24271930434874125, 0.18027945341808455, 0.24866359680891037, 0.1281374299100467, 0.15406619358275617, 0.09960299677082471, 0.1556165511054652], [0.11312191813652005, 0.04398618186158793, 0.17481742293706962, 0.03243012320516365, 0.013210070884919592, 0.01352250572693135, 0.019358312311981405, 0.04626244293259723, 0.07800205836870841, 0.05073968500697187, 0.1228510992867606, 0.4994281008839607, 54.50244794573103, 72.51007338932583, 62.22821944100516, 44.70050259998867, 21.162936176572526, 20.990726811545237, 43.84015233176095, 28.97611427307129, 60.118781089782715, 62.522301946367534, 1.0823951533862521, 0.11887997309012072, 0.7026801716004099, 1.1455459190266473, 1.4641296182359969, 12.877038257462637, 75.27581078665597, 72.255526133946, 80.2167442866734, 76.9422528403146, 74.46629006522042, 71.17353180476597, 69.84871877942766, 70.66533361162458, 65.22767339433942, 69.0950059890747, 68.97244671412876, 65.14749118259975, 68.095458984375, 63.47888823917934, 59.06803280966622, 55.77796697616577, 52.584022521972656, 49.24157769339425, 49.10254423958914, 47.647379534585134, 47.01181391307286, 44.58569056647164, 47.522464820316856, 46.74449586868286, 48.34453051430838, 45.19116701398577, 47.62487779344831, 45.36179392678397, 44.37462166377476, 42.85067326681954, 44.95484488351004, 43.200879846300396, 47.567947728293284, 44.29218128749302, 44.844872270311626, 42.99590451376778, 44.269766398838584, 40.518493039267405, 45.248454911368235, 42.64763648169381, 49.67051083700997, 48.30089235305786, 52.15047924859183, 45.53245905467442, 52.70154782703945, 47.85887575149536, 51.778924328940256, 45.11076940808977, 48.868556703839985, 44.29857015609741, 43.86728852135794, 43.63662569863455, 53.07863003867013, 49.9750851222447, 59.283420017787385, 45.09582730701992, 57.60428360530308, 44.31821271351406, 68.51752730778286, 4.951467837606158, 3.8792643887656073, 77.33001790727887, 41.37810679844448, 55.98468630654471, 44.87211268288748, 51.7724347114563, 40.034439836229595, 56.49338129588536, 53.33693279538836, 60.6179118837629, 51.826290198734824, 53.08399057388306, 45.98234796524048, 46.96815838132586, 41.170748233795166, 43.744444370269775, 39.49063559940883, 41.01140866960798, 41.77628026689802, 39.57785981042044, 37.64563873835972, 39.94011456625802, 39.55139759608677, 39.60857432229178, 38.374428340366904, 41.374802930014475, 37.32398230688912, 36.80562932150704, 39.40102468218122, 41.88860484531948, 39.90263598305838, 39.110120977674214, 39.93953091757638, 45.83698122841971, 45.78154502596174, 41.55661991664341, 41.58120264325823, 42.13132974079677, 42.307515212467735, 44.09014156886509, 43.11026838847569, 46.25508560453142, 45.65426097597395, 49.36516530173165, 53.94732856750488, 53.64263963699341, 56.429666314806255, 57.13392877578735, 59.287449972970144, 55.93609407969883, 57.1423465183803, 55.00321504047939, 57.005995069231304, 52.7784400667463, 55.869596345084055, 61.64102717808315, 63.046453203473774, 65.42696857452393, 23.505986860820226, 0.19659178810460226, 0.3443947641977242, 2.0561302517141615, 0.1659452383007322, 0.2557664471013205, 7.237951500075204, 60.097908701215474, 62.36426516941616, 47.635195868355886, 27.944515228271484, 30.29941953931536, 21.08340883255005, 20.29048909459795, 30.135049479348318, 54.79455368859427, 47.50723089490618, 42.21936689104353, 1.100438105208533, 0.08000032364257745, 0.06756889035126992, 0.06162842482860599, 0.06459852188293423, 0.0226289206517062, 0.013007097312116196, 0.05144796360816274, 0.09038490176733051, 0.14795681355254992, 0.008118823320338768, 0.018332528515851924, 0.1274725470159735, 0.034155871852168014, 0.0448901058573808, 0.032607146206178834, 0.09178583909358297, 0.045580128473894935, 0.09230827713119132, 0.016893963030140315, 0.047651397330420356, 0.05995557816433055, 0.11112296754228217, 0.8321072523083005, 68.70849854605538, 79.30091612679618, 71.1761165346418, 53.50848729269845, 34.613764490400044, 24.80170430455889, 32.037872723170686, 34.837798731667654, 68.3011395590646, 68.77711200714111, 0.762821335877691, 0.21286296285688877, 2.3847405271870747, 2.916503970112119, 0.6214032386030469, 19.071167094366892, 78.87084347861153, 73.60651997157505, 82.78633403778076, 79.69677584511894, 77.65126092093331, 74.66216673169816, 72.60438823699951, 72.03655365535191, 69.27943202427456, 69.69130734034947, 72.18571063450405, 66.56210272652763, 68.96877111707414, 66.00195980072021, 60.631988934108186, 58.352917262486045, 56.89816944939749, 52.57997519629342, 51.750679901668, 49.0254887172154, 48.36402368545532, 47.479410307747976, 50.44712488991873, 50.11132540021624, 51.649246624537874, 47.00477191380092, 50.94778081348964, 47.545807293483186, 46.80331931795393, 43.54455164500645, 48.28371640614101, 46.957367828914094, 49.05222538539341, 47.062990869794575, 47.97825969968523, 45.507674830300466, 45.133486543382915, 43.441885062626426, 47.13040229252407, 46.66879177093506, 52.51616988863264, 51.34123992919922, 54.880020005362375, 49.604350090026855, 55.27808230263846, 51.25464105606079, 52.509770597730366, 48.36633048738752, 53.21939706802368, 47.11578675678798, 47.203295843941824, 46.34441859381539, 54.473675455365864, 52.267493861062185, 61.07902908325195, 46.78247124808175, 58.27516344615391, 46.394261496407644, 70.38072150094169, 11.571699295725141, 10.126899565969195, 77.32895483289445, 44.12682458332607, 57.6920428276062, 50.12372446060181, 52.96500267301287, 44.19217586517334, 57.910754748753135, 58.1646523475647, 61.85640048980713, 53.785661356789724, 55.09638690948486, 48.03804547446114, 49.934066431862966, 42.00938538142613, 45.110220500401084, 41.046312945229666, 41.874041421072825, 44.85938705716814, 41.60921083177839, 40.28218480518886, 42.250894342150005, 43.197631563459126, 41.857800006866455, 40.516460691179546, 44.7485910824367, 40.834702083042686, 38.5039427621024, 42.84300940377371, 42.65097509111677, 42.07863112858364, 41.718752656664165, 42.031584875924246, 47.6640100479126, 47.4850036076137, 45.132819516318186, 44.052034173692974, 44.62294680731637, 46.206284931727815, 47.453427519117085, 43.958633014133994, 48.81186287743704, 48.681177684238975, 53.26629046031407, 57.05907930646624, 56.239049434661865, 61.180542264665874, 59.18888282775879, 62.44605936322893, 58.30530820574079, 58.102959292275564, 57.68969086238316, 60.015551703316824, 54.97099624361311, 59.68681158338274, 63.26004777635847, 65.95898519243512, 68.42193399156842, 29.94415467126029, 1.5555114575794764, 1.0433774356331145, 1.990289556128638, 0.3728667178324291, 0.28962596878409386, 6.826686322689056, 63.80760056631905, 69.44916261945451, 56.81810188293457, 33.48885808672224, 20.77334894452776, 26.48869218145098, 36.69835260936192, 36.89499357768467, 60.24855954306466, 53.543506213596885, 54.28378118787493, 1.7716629675456455, 0.0917827585445983, 0.041204181499779224, 0.06917535593467099, 0.044170078422342024, 0.04899075760373047, 0.04095376475847193, 0.11717913007097584, 0.055970453790255954, 0.06985327348645244, 0.06187020721180098, 0.06196407574628081, 0.24739834613033704, 0.17787100694009236, 0.396264695163284, 0.14422814148877347, 0.3152372459215777, 0.11289354360529355, 0.18153642596943037, 0.15252682832734926, 0.20501195985291684, 0.14579470242772782, 0.2026582168681281, 1.3008728985275542, 81.89797905513218, 90.77536582946777, 79.24941607883999, 63.890388352530344, 33.282208238329204, 32.19128894805908, 61.222690037318635, 43.27993992396763, 75.08023289271763, 77.65248380388532, 1.7206370255776813, 0.37795345059462954, 4.719831832817622, 6.5915679676192145, 4.969422851290021, 20.13590383529663, 83.61490671975272, 78.35505090441022, 86.56104019709996, 79.76109531947544, 83.035489491054, 76.35237857273647, 76.86227212633405, 76.3814081464495, 71.95802511487688, 74.37221840449742, 75.19898455483573, 69.78103637695312, 74.0002326965332, 69.16201441628593, 64.38536412375313, 62.050171852111816, 59.397571972438264, 54.993734223502024, 55.842025893075125, 52.79584183011736, 52.7194116456168, 49.85042054312569, 53.84738915307181, 53.47297852379935, 56.04689005443028, 49.253563335963655, 52.80518020902361, 51.897293840135845, 49.185741969517295, 47.48798091070992, 52.3898412159511, 48.17767647334507, 52.15471417563302, 49.58567680631365, 49.33937011446272, 49.59434815815517, 48.1105568749564, 45.1177419253758, 49.5927083832877, 47.41914510726929, 55.65045016152518, 52.48919003350394, 59.361677578517366, 51.31114728110177, 58.525170053754536, 54.356785910470144, 55.404598576681956, 49.3788115637643, 55.21391568865095, 49.396699701036724, 48.7899169921875, 48.66653782980782, 60.34308978489467, 55.37140008381435, 68.90437521253313, 47.11254889624459, 64.2060033253261, 46.114051069532124, 78.8097757611956, 6.402593902179173, 5.780291957514627, 84.95874391283307, 45.828532218933105, 64.3023817879813, 51.0753219468253, 57.25600515093122, 43.21107632773263, 62.04502323695591, 58.83402442932129, 67.76429394313267, 56.54433591025216, 58.76498017992292, 52.46063641139439, 53.51524788992745, 43.260179247174946, 50.1776042665754, 43.596357413700645, 44.71939475195748, 46.89186716079712, 44.15056310381208, 42.9623064994812, 43.856143610818044, 45.78002684456961, 44.389855589185444, 43.942711217062815, 47.774309226444785, 42.66179691042219, 41.532791069575715, 44.45228167942592, 46.98180116925921, 43.86403676441738, 43.2842686516898, 43.50845922742571, 50.185556479862754, 50.65981272288731, 46.74234887531826, 46.577874592372346, 47.65360164642334, 49.06866829735892, 48.42713417325701, 47.944922242845806, 52.14011948449271, 48.822514465876985, 55.93771300997053, 60.05239800044468, 59.56893539428711, 63.70815794808524, 62.65358121054513, 65.11964975084577, 62.55021286010742, 61.58291939326695, 61.14677401951381, 63.92995834350586, 56.45845964976719, 61.95669078826904, 66.54532977512905, 68.18809236798967, 70.21955803462437, 30.064573901040212, 2.7697330457823615, 4.863704706941332, 5.144890487194061, 0.6849298040781702, 0.2568801673395293, 9.256913883345467, 72.71897097996303, 74.29450280325753, 63.73714583260672, 41.83276217324393, 45.60876069750105, 30.55526610783168, 34.56302874428885, 45.09343712670462, 70.02655792236328, 63.661570276532856, 62.86325005122593, 2.249953942639487, 0.2107160102043833, 0.21791575529745646, 0.19419685804418155, 0.17789335788360663, 0.14425777989838803, 0.15703105234674045, 0.18457140454224177, 0.26185822593314306, 0.35037900879979134, 0.06686159901853118, 0.15991728247276374], [0.05652237756709967, 0.03986192048926439, 0.13778003677725792, 0.08675520082137414, 0.05485302535817027, 0.07304006748433624, 0.12279913707503251, 0.10490233491041831, 0.20002695306071214, 0.07262413230325494, 0.3870346104460103, 8.404109358787537, 70.5136057989938, 62.38865334647042, 64.5021424974714, 39.82608420508248, 21.278102568217687, 38.93636737551008, 62.77983692714146, 35.24559892926897, 73.54623740059989, 33.05737148012434, 0.049827201291918755, 0.22396760912878172, 1.6464023632662637, 4.212899948869433, 1.0821983239480426, 41.51364183425903, 78.36660575866699, 74.92487117222377, 80.65706552777971, 70.05309309278215, 73.82803549085344, 71.0969626562936, 70.04785415104458, 69.87956183297294, 73.67572402954102, 68.24183668409074, 70.74741268157959, 67.14136709485734, 64.63453347342355, 60.62215028490339, 58.614642007010325, 55.27230487551008, 51.97663879394531, 47.83415753500802, 46.918402331215994, 46.5888214792524, 47.32571962901524, 43.17087752478463, 46.94581992285592, 45.665423257010325, 47.99198934010097, 45.55142763682774, 48.32787568228585, 45.03755276543753, 43.7255973815918, 43.29248489652361, 45.97909620829991, 44.163667406354634, 45.04183980396816, 43.78941658564976, 44.83885860443115, 41.58761930465698, 42.54894774300711, 41.55450071607317, 46.597923619406565, 43.82856273651123, 47.19297776903425, 44.70797538757324, 47.605214391435894, 45.47458403451102, 54.480397837502615, 51.143063408987864, 51.10418823787144, 49.561309473855154, 50.72046702248709, 45.223236424582346, 48.98146145684378, 49.470201219831196, 57.285969257354736, 52.693706784929546, 56.57356350762503, 50.55480807168143, 57.22262600490025, 48.26881946836199, 59.410898617335725, 7.807705521583557, 5.417279848030635, 65.09143311636788, 41.79363686697823, 55.56062732424055, 45.77808134896414, 47.82638944898333, 43.849396909986226, 56.50479718617031, 52.15306050436837, 57.347512926374165, 50.125944410051616, 51.00190380641392, 47.19321400778634, 45.71007585525513, 38.039354937417166, 42.55041381290981, 40.751636368887766, 45.477679456983296, 45.1616336958749, 47.88895102909633, 40.88418367930821, 37.72734260559082, 37.530878816332134, 36.5357334954398, 36.337042808532715, 38.971125738961355, 38.07328993933541, 38.06801625660488, 38.892569405691965, 42.21462821960449, 40.08437653950283, 40.611043044498985, 38.04330498831612, 45.07875558308193, 44.37096691131592, 42.95532008579799, 43.91677359172276, 43.50383520126343, 43.96488986696516, 43.943360873631065, 45.164176736559185, 49.26459012712751, 51.26500429425921, 54.54952546528408, 53.524245807102744, 56.64887155805315, 58.17635658809117, 59.21534851619175, 57.6778997693743, 58.157815320151194, 55.633152621132986, 57.921441078186035, 56.30559580666678, 53.75787203652518, 56.942624023982454, 61.63959584917341, 61.14280659811837, 62.21906866346087, 54.18629101344517, 9.0797860622406, 1.127064579299518, 1.2551939210721423, 0.612381816974708, 0.04170510658462133, 0.11679654488606112, 36.804389068058555, 61.413522311619346, 60.56759997776577, 38.62801327024187, 44.05968414034162, 18.335747173854283, 11.971513407570974, 20.786234378814697, 40.93292529242379, 48.766348702566965, 56.06658819743565, 11.673355783735003, 0.5305327432496207, 0.2392936253121921, 0.09999193982886416, 0.06611776178968803, 0.056036750054253, 0.04153857373499444, 0.03077516272397978, 0.028276583046785424, 0.07901646143623761, 0.01868166701335992, 0.03350992687046528, 0.07963215054145881, 0.031337478264634094, 0.13639311119914055, 0.05663690749289734, 0.033580650575459, 0.09072399964290005, 0.06224412750452757, 0.05006687682388084, 0.1467484241085393, 0.16546372271009854, 0.4021853474634034, 10.72447156906128, 84.70009722028459, 68.85609912872314, 75.14513601575578, 48.49204077039446, 32.281962939671104, 32.26473140716553, 48.21228545052664, 41.384790965488975, 82.32889243534633, 35.327014446258545, 0.08717923092522792, 0.3694778968180929, 3.735639912741525, 3.87069639137813, 2.101289851324899, 46.63567318235125, 79.7928694316319, 79.15193285260881, 81.45626122610909, 74.71832207271031, 77.64807864597866, 72.77227061135429, 72.21554619925362, 73.16428102765764, 76.39399133409772, 72.1081965310233, 74.31461783817836, 69.391909463065, 68.31326416560582, 63.9158604485648, 60.40458134242466, 57.97175645828247, 56.507027557918, 50.38422979627337, 49.79842022487095, 49.080834593091694, 49.50655419485909, 47.28688267299107, 48.81559406008039, 47.97172144481114, 50.76551219395229, 48.551781381879536, 50.93682697841099, 47.84352718080793, 44.70245851789202, 46.434943199157715, 47.80647243772234, 45.9676490511213, 47.10648659297398, 46.17779731750488, 47.45588370731899, 42.76557173047747, 45.62757294518607, 45.54290567125593, 47.93817554201399, 45.23811599186489, 49.278104373386924, 48.12907729830061, 49.80555949892317, 48.85833937781197, 57.679834842681885, 53.19568286623274, 51.47931800569807, 51.3341840335301, 52.2164489201137, 47.237873554229736, 50.641354833330425, 52.34679365158081, 59.18771553039551, 54.460390499659944, 58.68335274287632, 52.54411901746477, 60.44084399087088, 52.08968251092093, 60.600603921072825, 12.00193783215114, 10.006483810288564, 65.16748114994594, 46.01459455490112, 57.71296385356358, 47.52551507949829, 49.60391582761492, 45.54894365583147, 57.26449237551008, 55.662470545087544, 60.19721235547747, 51.30086742128645, 53.244011061532156, 48.36506591524397, 47.698514802115305, 40.54813405445644, 45.652954714638845, 44.599663393838064, 47.374499457223074, 48.43115718024117, 51.47542701448713, 44.123072556086946, 40.453777517591206, 39.29607909066336, 38.394459996904644, 38.06341307503836, 41.98118264334542, 41.341006892068044, 39.899981771196636, 40.642841475350515, 44.395601749420166, 41.44508743286133, 42.070866516658235, 40.790987491607666, 46.82502549035208, 44.67364086423601, 45.56332990101406, 45.74073130743844, 45.2108199937003, 46.50311197553362, 45.88162687846592, 48.22672380719866, 52.207836627960205, 54.242863246372764, 57.75766856329781, 56.07572855268206, 60.117905616760254, 60.44986275264195, 61.66815294538225, 60.04364327022007, 61.40988145555769, 57.26598971230643, 60.50699084145682, 58.27830055781773, 57.31387669699532, 59.36740289415632, 64.35231154305595, 64.80031054360526, 65.0027254649571, 59.210498673575266, 13.38509748663221, 0.5978351661137172, 0.6912882743137223, 1.252377512199538, 0.04252359962889126, 0.04136351848553334, 37.65141616548811, 66.86575290134975, 65.33289691380092, 44.84993403298514, 36.96220350265503, 16.481271232877457, 17.747010673795426, 32.921082564762656, 47.20581109183175, 56.86645092282976, 64.98699474334717, 18.104775156293595, 0.5712703030024255, 0.15988083157156194, 0.1043995540323002, 0.1163352903510843, 0.13185985945165157, 0.07420144123690468, 0.0012265267910801672, 0.05505027548809137, 0.06119569590581315, 0.033698339081768475, 0.06010021468890565, 0.2803628258407116, 0.14341157887663158, 0.25594169912593706, 0.18522802287978785, 0.122370750776359, 0.2091351728886366, 0.1657996111150299, 0.2856456823647022, 0.4303365983068943, 0.29394237431032316, 0.48414586377995356, 12.585398043904986, 98.26375906808036, 77.47444316319057, 84.68965407780239, 54.388504437037874, 33.328740324292866, 56.215776443481445, 85.34573078155518, 49.202292578560964, 91.12164320264543, 42.84625768661499, 0.1615370134157794, 0.5804072384323392, 4.988057051386152, 10.295504552977425, 3.455528063433511, 48.758330481392996, 84.77815328325543, 75.28202942439488, 84.70077119554792, 75.75097029549735, 78.22357709067208, 76.02264486040387, 76.29119968414307, 76.67576857975551, 80.452406338283, 72.89601802825928, 77.34856264931815, 71.5582674571446, 70.05314173017229, 66.59566947392055, 65.23793588365827, 59.69901262010847, 62.129388264247346, 53.06774915967669, 54.748313426971436, 52.90789195469448, 53.76994105747768, 50.0403356552124, 51.49265507289341, 50.169342858450754, 55.32765769958496, 50.40491458347866, 54.88769081660679, 48.85196440560477, 48.05226148877825, 49.40450600215367, 51.588991846357075, 47.55497196742466, 49.92626013074602, 48.611820765904014, 50.856300830841064, 45.671398707798545, 48.09721285956246, 45.51724597385952, 50.95255422592163, 45.96828828539167, 53.273276873997276, 48.97343628747122, 53.66876138959612, 49.46595587049212, 60.60997009277344, 54.446303027016775, 56.262749740055625, 53.3216050692967, 56.28658206122262, 47.83667973109654, 54.24711901800973, 53.32877213614327, 63.28772245134626, 56.778521469661165, 62.57673413412911, 54.12164497375488, 63.271276065281455, 50.31913212367466, 71.29653576442173, 9.76558542251587, 7.300423622131348, 74.38371767316545, 47.12646961212158, 63.21877547672817, 49.909018175942556, 52.60607263020107, 48.68499919346401, 62.99682222093855, 57.89608710152762, 64.53559112548828, 55.571866035461426, 57.953812735421316, 52.29647479738508, 50.17131267275129, 42.74806227002825, 49.74253238950457, 46.28536237989153, 49.7723262650626, 50.514470304761616, 55.01248741149902, 46.55057512010847, 42.70130089351109, 42.679869174957275, 40.587565081460134, 40.79923847743443, 45.73474543435233, 42.89352280752999, 42.06394611086164, 42.86141518184117, 46.97110789162772, 43.058229855128694, 45.76902437210083, 42.53184822627476, 49.41484839575631, 47.372974327632356, 46.58528484616961, 48.33804784502302, 47.49341092790876, 49.199412550245015, 48.337898458753315, 50.095886502947124, 55.20303133555821, 56.17770726340157, 58.03715290342058, 58.69325392586844, 62.804468291146414, 63.68365165165493, 66.5744218826294, 63.508063725062776, 65.42807333809989, 60.873285974775044, 64.79575252532959, 62.63393170492989, 58.77033724103655, 61.63786574772426, 69.35376385280064, 67.40329333714077, 67.79591519492013, 62.35245323181152, 12.221134390149798, 3.917022636958531, 5.358766462121691, 1.9448565883295876, 0.24497863597103528, 0.22309342532285623, 46.02301229749407, 71.0441563470023, 73.3403205871582, 52.80491270337786, 60.02138124193464, 26.956469229289464, 20.29421854019165, 37.05009126663208, 56.91260780606951, 64.28312138148716, 75.16486889975411, 22.659020560128347, 0.6565006524324417, 0.3244904822536877, 0.20790364540049008, 0.15477652475237846, 0.21722492522427014, 0.25786181752170834, 0.1694723583225693, 0.1373004075139761, 0.21383971401623317, 0.12598454686147825, 0.23263803816267423], [0.04173783911392093, 0.03415885062089988, 0.027286537690088153, 0.05477862738605056, 0.06472915344472442, 0.09222270707998957, 0.004418135737068951, 0.11110143762614046, 0.05287627982241767, 0.12731765104191645, 0.21491268144122191, 24.633286918912614, 79.26646695818219, 63.04177706582205, 65.09859670911516, 27.632627964019775, 21.597577265330724, 44.03530291148594, 43.440943581717356, 41.652199336460654, 85.54274000440324, 12.441347122192383, 0.05206519977322646, 0.5035119588885988, 2.1360147765704562, 8.0304673739842, 7.0212167756898065, 64.00928592681885, 70.52849578857422, 93.84162671225411, 66.55117321014404, 70.10575348990304, 70.84689004080636, 69.97544697352818, 70.59577519553048, 71.64732946668352, 69.71462549482072, 67.05750233786446, 67.52648489815849, 61.1776031766619, 60.58573477608817, 57.14476449148995, 52.97482395172119, 49.13976573944092, 48.838158335004536, 48.676369530814036, 45.64816393171038, 45.74978133610317, 47.04300437654768, 46.969099862234934, 46.919201374053955, 47.85565873554775, 46.235449995313374, 47.18742963245937, 47.0741149357387, 46.11146633965628, 43.38228341511318, 43.80346236910139, 44.97625575746809, 44.42543036597115, 43.3375370161874, 42.39355822971889, 40.989469732557026, 41.76386036191668, 42.063841887882774, 43.58083166394915, 45.04524442127773, 43.88829639979771, 44.94156340190342, 43.43828936985561, 46.413674763270784, 51.73491096496582, 55.437397548130576, 54.62299919128418, 51.1106778553554, 48.46544654028756, 48.29600429534912, 49.41919101987566, 52.60975864955357, 52.49812194279262, 57.047038078308105, 56.58838401521955, 57.54143020084926, 56.71640110015869, 57.45382036481585, 56.066789695194785, 40.54726552963257, 6.663659002099719, 8.76305764062064, 51.632713385990684, 47.73576062066214, 51.97925131661551, 45.39667388371059, 43.82953895841326, 47.46425976072039, 55.96819823128836, 49.524779319763184, 53.760595730372835, 51.49477079936436, 50.59017787660871, 46.36751440593174, 46.531877517700195, 41.56160872323172, 44.36346633093697, 48.15655394962856, 51.84668663569859, 54.603287151881624, 52.73796680995396, 45.16121332986014, 39.33329364231655, 38.114301681518555, 38.24120010648455, 36.341844013759065, 37.822188990456716, 37.46009751728603, 37.77461814880371, 38.6822578566415, 42.2979405948094, 40.23932831627982, 41.50027697426932, 39.91534423828125, 41.25757987158639, 43.33848544529506, 42.184556416102815, 43.00586823054722, 42.74757589612688, 46.6390187399728, 45.55231353214809, 51.22079985482352, 53.355797154562815, 52.26549972806658, 57.29771171297346, 55.15780551092965, 58.0505177634103, 58.887942450387136, 59.923710414341514, 60.10400921957833, 57.998385429382324, 56.9708753994533, 57.72062771660941, 56.174219267708914, 54.99238974707467, 55.06356709344046, 58.329064096723286, 58.93235533578055, 62.91859940120152, 64.33482987540108, 41.67633737836565, 1.252944441778319, 0.6754582694598606, 0.8369854848299707, 0.17216687516442367, 0.33923833231840816, 7.786041906901768, 64.08426393781389, 58.69702679770333, 52.87162235804966, 47.00781522478376, 46.20286989212036, 25.86566284724644, 13.639150551387242, 30.146083218710764, 48.28677361352103, 47.57958248683384, 37.8030640738351, 0.34941429485167774, 0.15120861120522022, 0.043777206646544595, 0.030921074894389937, 0.01842955223816846, 0.07658346556127071, 0.010971594884592508, 0.127742291827287, 0.03488154809123703, 0.02271653648598918, 0.031601988178278716, 0.09793019760400057, 0.011543671151490083, 0.010868432116694748, 0.028942582130964314, 0.04417398678404944, 0.060726726427674294, 0.05290249163018806, 0.0412527408583888, 0.06432617828249931, 0.12697359307536057, 0.19029753442321504, 32.45994104657854, 89.86495031629289, 70.20115920475551, 71.0645979472569, 36.274630614689414, 30.92147786276681, 37.537312848227366, 45.839044843401226, 47.464746134621755, 95.67021192823137, 12.519789678709847, 0.00926680363980787, 1.1451038398912974, 7.164211571216583, 9.717590740748815, 8.741120440619332, 68.84900501796177, 71.44077341897147, 92.07507501329694, 68.84262657165527, 72.57392733437675, 73.0022142955235, 73.03551701136998, 71.56959302084786, 74.70505101340157, 69.86617960248674, 71.17631108420235, 69.45295633588518, 65.21632698604039, 62.124600955418174, 59.29790006365095, 54.86120775767735, 52.560388224465505, 51.311463424137656, 52.011602129255024, 49.94062900543213, 49.67942884990147, 49.689698287418906, 49.24563544137137, 48.216113907950266, 50.80820540019444, 48.31191567012242, 50.080367701394216, 49.71807473046439, 48.289274965013774, 46.908532415117534, 46.15436451775687, 46.360889298575266, 46.252146516527446, 45.83703333990914, 45.17599562236241, 44.37365933826992, 45.0301251411438, 44.42904690333775, 45.05941874640328, 47.18278823580061, 46.31546197618757, 47.30266898018973, 46.97935192925589, 47.73775475365775, 54.601626532418386, 57.77887099129813, 58.23882436752319, 55.12440204620361, 53.4581858089992, 50.97018527984619, 53.63819626399449, 54.08451727458409, 54.77724225180489, 61.274287360055105, 57.97354561941964, 61.438716479710166, 57.896889618464876, 61.84610325949532, 57.14140851157052, 43.62793697629656, 10.593750766345433, 12.182551043374197, 53.074787684849326, 50.890173298971995, 56.144043241228374, 48.969673837934224, 46.703723839351106, 49.0344796861921, 59.10596302577427, 52.89350918361119, 55.723774501255576, 53.50476653235299, 51.69952031544277, 49.750126770564485, 49.43324722562517, 44.918137550354004, 46.76415579659598, 50.61145326069423, 56.10755477632795, 56.853829520089285, 54.239983218056814, 48.72150502886091, 41.457125186920166, 39.71580587114607, 40.421096665518625, 37.71171958105904, 40.93675374984741, 41.45527696609497, 41.47725064413888, 40.34915154320853, 43.57647166933332, 42.89705944061279, 43.11823449816023, 41.70242438997541, 43.08361162458147, 44.94320317677089, 45.38067218235561, 45.90735258374895, 45.75687892096383, 47.5269637789045, 48.86722959790911, 53.11203350339617, 55.65018612997872, 55.128404208592, 59.10864503043038, 56.92816482271467, 60.678243092128206, 60.982998030526296, 61.508295740400044, 60.70996856689453, 60.18267672402518, 58.98302854810442, 60.4451379776001, 58.83300304412842, 58.25784853526524, 58.19029467446463, 61.673829623631065, 61.79960591452462, 65.68685204642159, 66.95726067679269, 47.42135810852051, 2.5579571638788496, 0.37288913662944523, 1.6810911361660277, 0.6895982335720743, 0.3357497937977314, 6.252883238451822, 69.09495040348598, 64.28233623504639, 60.59319019317627, 48.566890239715576, 39.64095292772566, 28.312582152230398, 22.803815807615006, 37.0230210849217, 53.39775037765503, 54.104403018951416, 49.266546045030864, 0.8009863793849945, 0.08151885108756167, 0.033981725839631896, 0.043962429743260145, 0.029240608281855072, 0.015614877022536737, 0.027734944164486866, 0.06437712947704963, 0.08505782511617456, 0.02198978646525315, 0.05366413361792054, 0.18793943524360657, 0.07676318913166012, 0.09245711378753185, 0.180415879668934, 0.137765231143151, 0.21562160125800542, 0.1507781214479889, 0.28651968975152287, 0.15920851193368435, 0.22163701775882924, 0.3125216673527445, 39.61937877110073, 104.67411845070976, 78.23203999655587, 81.35622106279645, 41.17506653921944, 32.25665065220424, 58.276667731148855, 61.75517913273403, 54.050825459616526, 105.33939456939697, 15.518798078809466, 0.2098652765687023, 1.5237243175506592, 11.98549839428493, 10.299330404826573, 8.893831423350743, 73.15039157867432, 74.96722044263566, 96.41227953774589, 69.6105762209211, 75.02967779976981, 76.30621474129813, 75.71047619410923, 77.0868170601981, 76.74258940560478, 73.66317558288574, 73.89091668810163, 74.17960739135742, 67.2411779676165, 67.42996747153146, 63.88341930934361, 59.33381530216762, 55.759318011147634, 54.09666272572109, 55.04638072422573, 51.33466693333217, 51.32085738863264, 53.295959268297466, 53.1552860396249, 51.035126617976594, 53.44425119672503, 52.23645625795637, 51.33740104947771, 52.980048997061594, 50.09153345652989, 49.756216866629465, 49.908167021615164, 50.11169018064226, 48.80833666665213, 48.56908239637102, 46.91272565296718, 46.81884159360613, 47.53046219689505, 47.3219120161874, 47.95654657908848, 49.69610800061907, 48.352055413382395, 48.58606379372733, 47.98779957635062, 50.12719855989729, 57.02070093154907, 59.3785617010934, 58.940866879054475, 57.73463528496878, 56.65806402478899, 53.639634541102815, 55.2114907673427, 57.29448427472796, 57.24692038127354, 63.37832696097237, 61.036985533578054, 65.97708524976457, 59.12470926557268, 64.33539962768555, 59.504393577575684, 47.96441193989345, 8.187255212238856, 10.748710359845843, 58.75697585514614, 50.81543847492763, 60.12410340990339, 51.04917587552752, 49.25340352739607, 50.893397263118196, 61.37971237727574, 53.59441566467285, 58.68472153799874, 56.97158064161028, 56.89284712927682, 51.28167649677822, 53.374539920261924, 45.99525077002389, 50.10678127833775, 53.978800433022634, 58.43987396785191, 60.29025568280901, 58.19146892002651, 51.52934503555298, 44.87630244663784, 42.908947808401926, 43.06308317184448, 41.45842450005667, 43.56873137610299, 44.175517559051514, 43.9394142968314, 43.71199975694929, 46.23323351996285, 45.91918189185006, 45.32944311414446, 45.17131948471069, 44.67077473231724, 48.37953206471035, 46.00606216703142, 47.89252587727138, 48.57053804397583, 50.65990999766758, 49.06565625326974, 56.258660725184846, 58.1062388420105, 57.70358725956508, 62.196410587855745, 59.229258809770855, 62.48473998478481, 64.67283889225551, 65.28856740679059, 64.46300329480852, 63.49796104431152, 62.33904320853097, 63.574273109436035, 60.28815732683454, 59.980470248631065, 60.37931769234793, 63.16059126172747, 65.57204696110317, 68.85023484911237, 70.93593120574951, 49.176695414951865, 2.497828973191125, 2.632814232792173, 3.292626678943634, 0.7050895137446267, 0.4304327060069357, 9.870299117905752, 77.80705342973981, 70.3121566772461, 67.76933138711112, 61.79574271610805, 61.974082129342214, 37.12527772358486, 26.424252850668772, 43.3060165132795, 63.8714336667742, 61.726295471191406, 59.67272758483887, 1.3221101760864258, 0.29129380785993164, 0.20323020831814834, 0.19895348351980957, 0.10689465621752398, 0.13134950612272533, 0.1339923728789602, 0.22310029209724494, 0.23344421918903077, 0.09152359887957573, 0.1731661536863872], [0.02449854077505214, 0.034761511853763034, 0.03822156547435692, 0.08654554707131215, 0.08755487469690186, 0.06037350145301648, 0.021779813803732395, 0.12943797798029014, 0.03493909125349351, 0.15223029495349952, 0.44739963699664387, 51.2852235521589, 67.61928503853935, 58.286555017743794, 53.64742694582258, 23.731068543025426, 54.54068388257708, 37.70981230054583, 34.259899684361045, 61.53706823076521, 69.19328130994523, 2.134954959154129, 0.06161528839064496, 1.4992862003190177, 7.019560933113098, 12.320649095943995, 21.797725336892263, 70.7338775907244, 72.7149132319859, 60.649345534188406, 67.454147202628, 76.02529907226562, 68.43400996071952, 70.94694410051618, 66.54914433615548, 72.0586211340768, 68.92210006713867, 69.75344508034843, 60.72216265542166, 58.04986810684204, 51.73361512592861, 51.970885685511995, 47.266368116651265, 45.59704603467669, 44.471781798771445, 48.22042179107666, 46.583096163613455, 46.797416823250906, 46.82274648121425, 47.638058526175364, 44.51156370980399, 47.574798652103965, 44.747225761413574, 46.40899167742048, 45.544753892081125, 44.54180227007185, 44.28790119716099, 44.72196558543614, 45.03751802444458, 44.12422595705305, 41.34564828872681, 44.37118925367083, 41.99690989085606, 40.743291582380024, 40.52414539882115, 43.78389624186924, 47.52875294004168, 49.377098832811626, 47.33806310381208, 43.800412109919954, 46.35040099280221, 54.985639572143555, 53.92280837467739, 56.03403588703701, 51.2396468435015, 50.792474678584504, 50.239658628191265, 54.66761704853603, 50.66916847229004, 56.47384296144758, 59.347975730895996, 53.25406510489327, 54.83162580217634, 58.6560880116054, 54.150493894304546, 53.87172521863665, 30.151933601924352, 19.251151493617467, 21.337377650397165, 42.08749008178711, 53.056607723236084, 47.35181706292288, 45.99352066857474, 43.12420647484915, 45.90450382232666, 51.605111667088096, 54.312977518354145, 54.06917565209525, 52.15999480656215, 51.73218379701887, 50.03529473713466, 46.50777421678816, 47.08229643957955, 48.5598795073373, 51.62790870666504, 52.425593171800884, 44.52148921149117, 52.70021377290998, 48.30395998273577, 43.2854220526559, 39.27681868416922, 37.36539009639195, 36.215702942439485, 36.866603238242014, 37.84325245448521, 38.73708609172276, 38.784924439021516, 40.54714046205793, 40.62297657557896, 41.328614779881065, 38.34363045011248, 41.71467753819057, 44.40441901343209, 44.08416959217617, 45.5008100100926, 43.827312060764854, 49.029973779405864, 49.31407867159162, 56.916780199323384, 58.547842025756836, 55.75644145693098, 58.83203724452427, 57.742809840611045, 59.54909133911133, 59.17702225276402, 57.321811539786204, 56.54268223898751, 59.271476064409526, 57.45300742558071, 57.49106618336269, 56.64843382154192, 59.46296146937779, 58.996563638959614, 57.53691039766584, 58.29405212402344, 60.73187623705183, 61.52489498683384, 61.084031786237446, 15.334934847695486, 0.46610209771565025, 0.8078691672001566, 0.5767144880124501, 0.13616494701376983, 0.12074040754565171, 42.634292466299875, 61.29184545789446, 56.49540669577462, 37.08133036749703, 39.40996701376778, 18.633875267846243, 19.258268186024257, 21.27368525096348, 45.171493189675466, 46.54665981020246, 56.51214838027954, 11.893547671181814, 0.36941878284726826, 0.08302201649972371, 0.049880296657127995, 0.046337186957576444, 0.06241053821785109, 0.013632080650755336, 0.022035182154338275, 0.035628869597400935, 0.03200562491214701, 0.02102218535063522, 0.03618429461494088, 0.005620410308308367, 0.05143840644242508, 0.11093492513256413, 0.04784850496798754, 0.0394523058618818, 0.05201417054714901, 0.07758676779589482, 0.01276539296044835, 0.1209349435354982, 0.5563098000628608, 62.232436997549875, 74.20077160426548, 64.91320487431118, 65.32159219469342, 29.89698335102626, 39.211627210889546, 32.2910372870309, 42.64697987692696, 69.49946062905448, 75.3521089553833, 1.5546131857803889, 0.1625021616263049, 2.694790210042681, 11.562835999897548, 13.065368311745779, 23.071142537253245, 74.02635792323521, 75.35572896684918, 63.04167284284319, 67.96673665727887, 76.76444149017334, 69.87573337554932, 70.7906721660069, 68.18787697383335, 74.61754540034703, 70.48074081965855, 71.15770380837577, 64.21961484636579, 61.77608626229422, 54.01201977048601, 54.01620258603777, 49.816989285605295, 48.00332185200283, 46.55498375211443, 49.91653960091727, 49.61089876719883, 50.58116953713553, 49.69649362564087, 50.239384174346924, 47.778047357286724, 50.29570974622454, 46.98978117534092, 50.95436075755528, 48.10795130048479, 47.15839311054775, 47.2425149508885, 47.31538765771048, 46.45750399998256, 47.32653604234968, 44.50503240312849, 45.4675281388419, 42.944328035627095, 44.55249554770333, 42.90995182309832, 45.5605263028826, 47.54775973728725, 50.664930071149556, 49.42189734322684, 46.472658021109446, 47.40131950378418, 56.278675011226106, 56.04350628171648, 59.850573675973074, 53.995455265045166, 53.975774492536274, 52.77834974016462, 57.46367638451712, 54.27862562452044, 59.78187683650425, 59.893374579293386, 56.96811349051339, 57.447268213544575, 59.31404767717634, 56.887253829411094, 53.51461212975638, 32.17440135138375, 22.37052266938346, 24.42335057258606, 43.42682484218052, 55.59802252905709, 50.61252328327724, 48.451894078935894, 44.40601362500872, 50.26888969966343, 54.25763511657715, 58.56665079934256, 56.89974321637835, 53.98104470116751, 53.816396713256836, 53.54245356151036, 49.474821771894185, 48.74613986696516, 51.991167477199006, 54.56042718887329, 52.981059959956575, 43.89663076400757, 54.91590050288609, 50.33316401072911, 45.73064252308437, 40.07915844236101, 40.40468849454607, 37.58242750167847, 39.047486441476, 39.295130661555696, 41.34308440344674, 40.84936278206961, 42.77240875789097, 42.162673064640586, 44.441348688943044, 42.33407122748238, 43.2797349521092, 46.328875473567415, 45.885427543095176, 46.91984755652291, 47.55991561072213, 50.25050476619175, 52.20500871113369, 58.82519326891218, 60.27626895904541, 57.82395090375628, 61.146113940647666, 58.29441343035017, 61.48638807024275, 60.666632652282715, 59.680315017700195, 59.23426846095494, 60.76596409933907, 60.145406586783274, 60.286864961896626, 59.84428555624825, 62.50260380336216, 61.43799386705671, 60.838725634983604, 60.95530945914132, 63.30430780138288, 63.10014888218471, 63.618665150233674, 20.067467553274973, 0.054524621194494624, 1.7387342602014542, 1.2472992475543703, 0.3062380259590489, 0.08905465421932084, 43.3936437198094, 68.27767549242292, 61.536936214991975, 45.84787947790963, 34.942341327667236, 19.373537063598633, 28.848583562033518, 27.65245291164943, 52.08429765701294, 53.0249274117606, 65.81626224517822, 17.47853054319109, 0.325737575335162, 0.026632365471284305, 0.051538643028054915, 0.09316584361451012, 0.06410774428929601, 0.052210175565310886, 0.03826449638498681, 0.0009454246818287564, 0.04838603023173554, 0.03588666879971113, 0.1445754292820181, 0.12539917470089026, 0.09961310015725237, 0.18783872707613877, 0.243931737861463, 0.23683257879955427, 0.1724988959197487, 0.18029444904199668, 0.11458488713417735, 0.24356142058968544, 1.184516845004899, 75.8483840397426, 84.0163527897426, 74.80369458879743, 69.9793518611363, 36.44930485316685, 65.8822909763881, 51.8527524130685, 52.90452902657645, 75.04932035718645, 82.92048290797642, 2.482243078095572, 0.23145285461630138, 3.4507268582071577, 17.39214880125863, 16.1269200529371, 23.331832000187465, 80.57710565839494, 76.30164977482387, 73.90201296125139, 69.38988058907645, 79.87858240944999, 72.59729412623814, 75.35615280696324, 72.93574782780239, 78.60552651541573, 72.89926978519985, 73.94094371795654, 67.77051258087158, 63.96681158883231, 57.59572689873831, 57.37217903137207, 51.75966739654541, 51.338637828826904, 48.96709605625698, 54.583352770124165, 51.845484597342356, 53.28292792184012, 53.13903767721993, 51.75017615727016, 49.68353523526873, 53.0007198878697, 49.53474651064192, 51.74322101048061, 50.479361057281494, 50.81323937007359, 51.070253235953196, 50.40519598552159, 49.37086977277483, 49.852164540972026, 45.954371043613975, 49.31357492719378, 46.500808647700715, 47.36425086430141, 44.90932723454067, 48.466422762189595, 51.03736393792288, 52.86382647923061, 52.08492994308472, 47.45260763168335, 50.0422568321228, 60.104613712855745, 59.53197792598179, 60.79094982147217, 55.44597857339041, 55.793336391448975, 55.523457935878206, 59.23927116394043, 57.41172470365252, 61.167576926095144, 62.98057038443429, 58.6932122366769, 57.92591919217791, 62.77462577819824, 60.42905289786202, 55.13867017201015, 34.348920004708425, 20.899024486541748, 25.359879153115408, 47.8510868208749, 57.62867873055594, 53.879705224718364, 50.303554262433735, 46.351328577314106, 51.393785681043354, 57.37654250008719, 60.727498871939524, 60.397834641592844, 57.3242746761867, 56.50119454520089, 55.97123806817191, 51.80057838984898, 51.501753738948274, 55.85035330908639, 56.18261963980538, 55.832628454480854, 49.31923770904541, 57.30431944983346, 52.909003666469026, 48.923805304935996, 43.00656305040632, 42.71644796643938, 40.70946427753994, 43.870971066611155, 42.16470193862915, 44.09523112433297, 43.57691287994385, 44.73925270353045, 45.650064264025005, 48.066911765507285, 44.32404225213187, 46.36876160757882, 48.55222954068865, 48.70843199321202, 50.01232399259295, 50.31361525399344, 52.67367512839181, 55.52925968170166, 60.37922041756766, 61.030968393598286, 61.56367288316999, 62.71612889426095, 62.05022743770054, 65.08584676470075, 64.94568075452531, 62.282985142299104, 62.16517148699079, 62.82946790967669, 63.36042145320347, 63.92779050554548, 62.398992265973774, 65.07987131391252, 64.78362097058977, 62.37939139774868, 64.24346801212856, 67.86260400499616, 66.85660907200405, 66.75538771493095, 20.46549163545881, 1.444549377475466, 3.949791644300733, 1.415900000504085, 0.31626690924167633, 0.4483956721212183, 52.97440011160714, 74.13315173557827, 69.22561822618756, 51.258493832179475, 53.43639973231724, 27.88329291343689, 32.028944287981304, 33.35514347893851, 62.92415101187569, 60.724427768162315, 78.51416465214321, 21.489265271595546, 0.6674894456352506, 0.2503982037305832, 0.14239739972565854, 0.27202607318758965, 0.20485327765345573, 0.09326575111065592, 0.17611387265580042, 0.1634865938020604, 0.12944759960685456, 0.13061955172036374], [0.050993694591202905, 0.0238754895648786, 0.03557674792994346, 0.09285972932619707, 0.03129409273554172, 0.06477646090622459, 0.013743986342368382, 0.11443863569625787, 0.14448892963784082, 0.23372581122176989, 5.937230050563812, 70.73906094687325, 59.893124444144114, 58.789729663303916, 26.077584641320364, 52.98363774163382, 114.8477611541748, 42.37872729982649, 39.92856666019985, 75.572616985866, 44.514607020786826, 0.15068680420517921, 0.11094402428716421, 0.5677831215517861, 0.37362469573106083, 2.1686304892812456, 38.71628318514143, 70.4357442855835, 71.08958366939, 69.35735607147217, 70.16452830178397, 73.41396454402378, 68.39088249206543, 69.44390978131975, 68.60136427198137, 68.77308205195835, 64.91491413116455, 63.54841191428048, 58.0047812461853, 50.97489268439156, 48.30335201535906, 48.01220164980207, 48.79716048921858, 51.27352278573172, 52.2834712437221, 50.5330810546875, 46.55794368471418, 44.81371654782976, 48.17252785818917, 47.530740124838694, 48.068329198019846, 46.4268867628915, 46.477400166647776, 46.8541384424482, 44.81439399719238, 43.39421694619315, 43.47662605558123, 41.95799650464739, 49.26687955856323, 43.8500257219587, 40.64359188079834, 43.313746384211946, 42.25140503474644, 38.82392815181187, 38.29507991245815, 45.90678630556379, 53.00075462886265, 55.97475038255964, 55.185303006853374, 51.3096603666033, 50.17620073046003, 55.285496030535015, 57.01334973743984, 55.107312951769146, 56.10423353740147, 50.399474143981934, 56.10642569405692, 55.64549262183053, 56.22538580213274, 55.95017113004412, 46.754643712724956, 53.45289128167288, 55.53993558883667, 55.26043387821743, 52.56019714900425, 53.391135692596436, 28.416758230754308, 34.06212963376726, 24.839558090482438, 30.105238233293804, 53.64292103903634, 47.90575524738857, 50.42128453935896, 46.781731264931814, 48.973995617457796, 48.04588999067034, 50.21182067053658, 49.00831624439785, 52.84977374758039, 49.94840751375471, 52.361332757132395, 46.23045424052647, 49.39603614807129, 49.721246583121165, 54.29718426295689, 41.0249923978533, 39.28385026114327, 53.12003435407366, 48.33940969194685, 42.94492905480521, 38.15875973020281, 37.94058282034737, 34.022299085344585, 36.486304010663716, 38.36929014750889, 39.18158320018223, 38.03391797201974, 40.47178724833897, 41.761372906821116, 42.61727285385132, 41.33747373308454, 39.1723872593471, 45.11750568662371, 44.516990252903526, 44.10015044893537, 46.73223924636841, 50.65857941763741, 53.79737949371338, 58.33754784720284, 61.49546936580113, 55.65516104016985, 58.0321432522365, 60.04349735804966, 56.0673177582877, 58.21190357208252, 58.88934598650251, 58.880146571568076, 56.26666157586234, 55.84429447991507, 58.99461119515555, 57.95571654183524, 58.17688812528338, 59.40665326799665, 56.72165393829346, 58.63065760476248, 60.75586836678641, 61.86553042275565, 62.9709540775844, 38.155129296439036, 0.7016727370875222, 0.1977977483932461, 1.7243230449301856, 0.21316940284201077, 0.31133148978863445, 12.763000948088509, 62.84963158198765, 58.486941065107075, 52.08215413774763, 52.18229504993984, 45.564174107142854, 10.510540008544922, 15.80052147592817, 35.227019446236746, 50.226477895464214, 48.54751866204398, 40.845857415880474, 0.9812242793185371, 0.16790437246007578, 0.059443704916962554, 0.06874478475323745, 0.055591810893799574, 0.03139480429568461, 0.08600617958498852, 0.06454938916223389, 0.09994234570435115, 0.012805021950043738, 0.024648329076756324, 0.04180855942623956, 0.016643890645354986, 0.10908464834626232, 0.01872843164684517, 0.06409210405711617, 0.004280380829836109, 0.08348105901053973, 0.1607599686831236, 0.2852731666394642, 7.155178913048335, 82.6005392074585, 67.76398822239467, 70.28807422092983, 38.04477105821882, 50.292551789964946, 96.7141648701259, 40.74093961715698, 46.47606611251831, 84.44443825313023, 46.30304901940482, 0.13612085580825806, 0.056716004320021184, 2.036442748137883, 0.6712473896997315, 2.582608938217163, 41.88573176520211, 72.78768866402763, 76.91247286115373, 71.17836775098527, 74.51845714024135, 74.78676182883126, 70.48990549360002, 71.22311414991105, 72.91496576581682, 71.62446294512067, 70.25430597577775, 65.60908085959298, 60.682926177978516, 52.46763672147478, 50.98506832122803, 50.19450575964791, 51.9645801952907, 53.37442874908447, 55.56494562966483, 53.98781572069441, 50.55884150096348, 47.00533471788679, 49.216296672821045, 49.74808747427804, 50.469345229012625, 49.07400451387678, 49.02654831750052, 49.02309158870152, 48.50585378919329, 46.29350219454084, 46.05697856630598, 44.95235742841448, 51.527385643550325, 45.93445403235299, 43.87376424244472, 44.70252105167934, 44.820362499782014, 43.02668155942644, 42.69821241923741, 47.650124073028564, 55.74484143938337, 58.904534748622346, 57.76507534299578, 54.718050548008506, 53.37865325382778, 55.622740745544434, 58.60319832393101, 57.057283197130474, 57.60815027781895, 53.14824751445225, 56.74810573032924, 58.50480488368443, 60.667445591517854, 56.19532094682966, 46.228470529828755, 55.96066638401577, 57.325775487082346, 57.98786238261631, 55.368443625313894, 53.7392578125, 31.51798071180071, 36.80882201875959, 27.263711622783116, 32.28474221910749, 55.858649458204, 51.571805477142334, 52.54814897264753, 49.21998616627285, 50.87285838808332, 49.803200585501536, 52.485021114349365, 52.96919938496181, 55.077453068324495, 52.887255804879324, 54.29868507385254, 49.97896569115775, 52.74031530107771, 51.73065171922956, 55.22914613996233, 42.78655181612287, 41.979883330208914, 53.93592657361712, 52.2729377746582, 45.144798210689, 41.624938079289024, 39.55469104221889, 36.923130307878765, 40.09747736794608, 40.947836126599995, 42.23758159364973, 40.316373416355674, 43.357718058994834, 43.617358343941824, 44.83863973617554, 43.50068766730172, 41.724387645721436, 47.123169217790874, 46.82066202163696, 45.93639257975987, 47.953034264700754, 53.66383164269583, 54.714593819209504, 62.75998592376709, 64.17044244493756, 58.1771035194397, 60.965467725481304, 62.869684083121165, 58.230205127171104, 60.170489583696636, 61.19035312107631, 61.7743353162493, 59.35953753335135, 60.05811636788504, 60.498097147260395, 59.95539419991629, 60.450752122061594, 62.64531980242048, 58.78963933672224, 61.45569092886788, 61.80018261500767, 64.5548654283796, 63.89747551509312, 43.969746657780235, 1.3474800033228738, 0.8140954045312745, 1.8923801013401575, 0.6736847417695182, 0.30720292989696774, 11.514157789094106, 68.38770021711076, 63.45227663857596, 57.63181931631905, 50.33551597595215, 27.347633702414377, 13.457511612347194, 29.988421644483292, 41.74215766361782, 57.23994786398751, 54.28534800665719, 50.81602907180786, 1.210081004670688, 0.15043159361396516, 0.06373690454555409, 0.09796221767153059, 0.020106850092166235, 0.04001122194209269, 0.009585087453680379, 0.05240958343659129, 0.04524236052696194, 0.02838373899326793, 0.1492798618440117, 0.10946800027574811, 0.17392219097486564, 0.1830601849194084, 0.0600759909887399, 0.14449613567973885, 0.20847779459186963, 0.28662372274058207, 0.4105520642229489, 0.4435402383761746, 9.512191568102155, 95.44503470829555, 75.44055257524762, 80.35309573582241, 36.944499492645264, 64.13941179003034, 119.05256080627441, 60.45918723515102, 53.80037069320679, 91.21178218296596, 53.79055636269705, 0.4585114078862326, 0.2725526163620608, 3.3496954909392764, 2.1467829644680023, 2.9973610256399428, 44.01210982458932, 74.21599510737828, 76.60001931871686, 72.00475869859967, 76.35509531838554, 78.56478227887834, 74.18514510563442, 73.93463475363595, 74.95888955252511, 73.9966960634504, 72.37430558885846, 70.61210346221924, 63.67024857657296, 56.06097752707345, 51.71701240539551, 53.01230253492083, 54.83297375270298, 56.909859793526785, 57.4025148664202, 57.42783062798636, 52.423046657017295, 49.395191941942485, 53.35868065697806, 53.05335596629551, 52.40428304672241, 51.52865021569388, 50.97307225636074, 52.36015851157052, 51.111292770930696, 49.46156460898263, 49.37361083711897, 46.82947928564889, 56.59763206754412, 47.078064986637656, 45.03309549604143, 48.17658560616629, 48.22668906620571, 44.72493594033377, 44.69185209274292, 49.54846920285906, 58.561356272016255, 60.703993116106304, 58.850734846932546, 57.2335763658796, 54.88481426239014, 60.34338855743408, 61.76353086744036, 58.524954659598215, 60.06716292245047, 55.05488531930106, 60.445332527160645, 61.61962672642299, 61.97991861615862, 60.6246794291905, 49.88244479043143, 58.505332946777344, 58.72962774549212, 58.67462580544608, 57.43742609024048, 54.878168310437886, 34.14762026923043, 36.20906046458653, 30.293336391448975, 35.61014659064156, 60.45522676195417, 54.700214522225515, 56.62799916948591, 53.738309383392334, 53.78420918328421, 52.3089085987636, 56.187931537628174, 56.01214211327689, 57.98286315373012, 56.00313377380371, 57.15566621507917, 52.562239919389995, 53.971442290714805, 55.27116537094116, 57.67598901476179, 46.11911283220564, 42.72642905371529, 56.908727237156455, 55.498975958142964, 48.68654864174979, 43.796177182878765, 42.67885473796299, 38.74109172821045, 43.43581233705793, 43.51599107469831, 46.46536588668823, 42.81902422223772, 46.1391271182469, 45.216041564941406, 48.101677077157156, 46.6844356400626, 41.56433241707938, 49.8976856640407, 48.38228007725307, 48.4086971282959, 52.01505190985543, 55.15814249856131, 59.72035748617989, 64.46104390280587, 64.78130722045898, 59.258698327200754, 64.06808158329555, 64.87323883601597, 60.735482352120535, 63.48676749638149, 64.33457279205322, 65.0034897668021, 63.309067317417686, 61.50311933244978, 63.98661395481655, 63.41575690678188, 63.247249194553916, 64.67542362213135, 60.37239728655134, 65.25509793417794, 66.52516610281808, 66.62641525268555, 66.92523642948696, 45.584414209638325, 1.621764811021941, 3.8490114978381564, 3.889073508126395, 1.0653611017124993, 0.38879163616469925, 16.396266971315654, 76.38115801130022, 69.01949991498674, 67.62938771929059, 67.43083599635533, 59.707086426871165, 17.782357897077286, 28.87145529474531, 48.02073403767177, 66.32862935747418, 62.94668401990618, 59.074529375348774, 1.646654561161995, 0.35274321479456766, 0.2518491558730602, 0.19589494621115072, 0.15208161436021328, 0.13955927773245744, 0.17910011884357246, 0.14926844888499805, 0.23332810827663966, 0.19818489333348616], [0.048348232438521724, 0.002255545184847766, 0.018294544125507985, 0.09786712098866701, 0.0506781215247299, 0.056806778734815974, 0.0486104556891535, 0.08244625239499978, 0.12813194734709604, 0.27446331669177326, 23.436103616441997, 74.24945763179234, 56.862584250313894, 54.75055769511631, 29.707589353833878, 33.78731448309762, 38.85276665006365, 38.061735085078645, 53.213286127362935, 84.21507126944405, 18.41033434867859, 0.19128963404468127, 0.027897684003359506, 0.8219953434807914, 0.1337450197232621, 6.499004934515272, 52.84914493560791, 74.8534436907087, 72.72636386326381, 70.64359269823346, 75.68540014539445, 67.65349796840123, 67.42399896894182, 66.014737537929, 65.71265765598842, 67.34084987640381, 65.35684735434396, 56.784010546548025, 48.7162070274353, 48.900480202266145, 51.20324523108346, 55.34741837637765, 59.02492618560791, 59.96121679033552, 59.2978583744594, 56.83945369720459, 56.20542015348162, 48.887170927865164, 47.2967004776001, 45.47740152903965, 47.76812880379813, 46.01773166656494, 46.35099506378174, 45.571087564740864, 46.09254986899239, 41.88181298119681, 43.317244802202495, 43.55835771560669, 48.139878273010254, 43.84111813136509, 41.37703330176217, 41.44287095751081, 42.033898626055034, 36.79558917454311, 39.595956393650596, 45.68370744160244, 57.01217201777867, 57.09283365522112, 60.56195109231131, 59.20485673631941, 57.24333163670131, 52.99723884037563, 55.91255358287266, 53.75887605122158, 54.32695034572056, 52.516114303043906, 57.64545515605381, 53.58352436338152, 59.125028882707866, 42.854571206229075, 35.97532653808594, 53.46843440192086, 56.83538205283028, 55.071595736912315, 60.526814052036826, 46.903637409210205, 29.628452845982142, 42.107980319431846, 33.30422360556466, 24.18356302806309, 47.857920374189106, 54.64609500340053, 53.51663058144705, 51.44161013194493, 50.559821196964805, 50.58836439677647, 49.619938373565674, 51.17789472852434, 52.54481731142317, 52.51687513078962, 50.3049612726484, 50.883871282849995, 51.07659346716744, 53.601099831717356, 44.20613479614258, 43.92578540529524, 58.243986879076274, 50.54114096505301, 49.25585624149868, 40.502310684749055, 39.49145201274327, 37.253739493233816, 36.52484219414847, 34.836530685424805, 38.66001667295183, 38.50695480619158, 37.818714891161235, 40.18693542480469, 41.72768804005214, 41.91728353500366, 39.29821566173008, 40.84439482007708, 42.226822308131624, 44.37511498587472, 44.12246806280953, 45.62919534955706, 49.94745908464704, 56.927841731480186, 56.51790843691145, 58.36661911010742, 59.92719146183559, 57.76943186351231, 61.54072298322405, 57.880898339407786, 59.213243212018696, 58.863602910723, 57.003476347242085, 58.687917709350586, 57.99894823346819, 58.32873753138951, 56.538193702697754, 57.33969620295933, 60.572151047842844, 59.03414644513811, 58.899879455566406, 56.984035287584575, 59.52748244149344, 61.59293869563511, 53.58853054046631, 4.9430014576230725, 1.9858724560056413, 0.5149205752781459, 0.6675783608640943, 0.031279409237738164, 0.31899874550955637, 49.17772374834333, 60.65276404789516, 55.96536684036255, 42.16470193862915, 53.85528578077044, 29.15531873703003, 5.622620829514094, 15.493876627513341, 43.67873525619507, 47.59366301127842, 60.605474608285085, 8.480756674494062, 0.3040556673492704, 0.054937184056533236, 0.07432665130389587, 0.0766216738681708, 0.08554393438888447, 0.024497450030009662, 0.04422696340563042, 0.08197512517550162, 0.03069017960556916, 0.01942827266507915, 0.06791471929422446, 0.041535547468811274, 0.058058088911431174, 0.03175906903509583, 0.022836029895448258, 0.019217193991478, 0.14114744322640554, 0.31718746413077625, 0.4176365126456533, 27.176609005246842, 83.42935507638114, 61.3581451688494, 61.01693303244454, 31.816596916743688, 47.323006357465474, 40.222339970724924, 37.39045919690813, 61.69621671949114, 86.42536272321428, 19.400129556655884, 0.19903782542262757, 0.2244936908994402, 1.1415636241436005, 1.048724617276873, 8.205816456249782, 57.38892418997628, 76.463869367327, 75.83783667428153, 71.76305171421596, 77.36298710959298, 72.18291051047188, 71.13952732086182, 66.97798020499093, 69.02325194222587, 69.28069659641811, 68.42813873291016, 59.4324380329677, 51.52685063225882, 50.417827810559956, 54.78036894117083, 57.658774852752686, 63.03146593911307, 62.78958524976458, 63.68887669699532, 59.467700140816824, 58.76542486463274, 52.62934214728219, 49.819355147225515, 47.82922778810774, 49.84847157342093, 47.22633259637015, 49.413003649030415, 48.2512127331325, 48.68286262239729, 43.63395759037563, 47.398373467581614, 47.41388532093593, 50.75562143325806, 46.66100631441389, 43.601419176374165, 44.25920513698033, 43.602798393794465, 39.30528197969709, 41.93474088396345, 47.77423627035958, 59.92562811715262, 58.291099139622276, 60.685962540762766, 60.37115355900356, 58.77381828853062, 55.83504295349121, 57.670402663094656, 54.97823279244559, 57.54092298235212, 55.48552424567086, 60.27985422951834, 55.07239825384957, 61.19194425855364, 45.084300245557515, 38.731808934892925, 55.64390843255179, 58.316612924848286, 56.12453964778355, 62.79795782906668, 47.90628678458077, 31.450065544673375, 42.59944377626692, 36.006186962127686, 26.226237876074656, 48.733813762664795, 58.16968284334455, 54.08831099101475, 55.122953346797395, 53.89559575489589, 52.089248248508994, 52.50960384096418, 56.46617215020316, 54.30781500680106, 55.82124383108956, 53.12242106028965, 53.44578327451433, 54.19647707257952, 55.52652209145682, 45.23036527633667, 47.91905409949166, 59.48632826123919, 53.177183287484304, 51.94015727724348, 42.895808764866416, 41.377905300685335, 38.9979909488133, 37.86136293411255, 38.847496441432405, 40.212605544498985, 40.930840832846506, 39.40333495821272, 42.652830260140554, 44.177876472473145, 42.191758223942344, 41.32830558504377, 41.571183340890066, 45.68017428261893, 45.18542085375105, 46.51019218989781, 47.92228153773716, 53.32034397125244, 58.16171325956072, 60.8162065233503, 62.16428906576974, 59.023967334202354, 60.01341165815081, 63.642101424080984, 59.44185284205845, 62.123204367501394, 60.89502688816616, 59.518123217991416, 60.398383549281526, 60.97675159999302, 60.50171021052769, 61.25877898080008, 61.89222540174212, 62.574774742126465, 61.00111893245152, 60.439551625932964, 59.97897638593401, 61.92193589891706, 65.2548200062343, 58.44345923832485, 7.713828410421099, 1.929196868624006, 2.8151901151452745, 1.4688472279480524, 0.15146082267165184, 0.28402387510452953, 48.44811078480312, 66.25405434199742, 61.63688605172293, 50.494007859911235, 48.467440673283164, 27.669958897999354, 15.047480923788887, 25.107447624206543, 51.09520074299404, 53.23976918629238, 69.01571314675468, 11.554266265460424, 0.6160759244646344, 0.053647814850722036, 0.0825846463974033, 0.050633741941835196, 0.06042750605515071, 0.038890967411654334, 0.07584561979664223, 0.05483776849827596, 0.05240624504429953, 0.15072272584906646, 0.18258237412997655, 0.0761929415166378, 0.21175587869116239, 0.1320489671613489, 0.1540060346680028, 0.14661278495831148, 0.2075882623238223, 0.47955022752285004, 0.43161704816988533, 33.42513615744454, 95.4825688770839, 67.54165281568254, 71.51918384007045, 40.42045048304966, 43.85360404423305, 47.14146729878017, 54.67252595084054, 66.69371550423759, 97.29681301116943, 23.560504164014542, 0.32092146947979927, 0.4584115275314876, 4.687540948390961, 1.9776514342853, 9.946498274803162, 61.45227241516113, 80.71774414607457, 79.24823488507951, 74.84585625784737, 78.61089747292655, 74.41432448795864, 73.38849939618791, 70.33138929094586, 70.36462947300502, 72.97726331438336, 70.28737245287213, 62.71667085375105, 54.75343772343227, 54.722629410879954, 57.21355513163975, 61.02652849469866, 64.48946203504289, 64.75461224147251, 66.594404901777, 60.9819974899292, 61.93454687935965, 56.75624901907784, 51.81571504047939, 49.4092446735927, 52.64399937220982, 50.75469732284546, 52.77499723434448, 49.7693315914699, 50.64208092008318, 47.13524171284267, 49.411631379808696, 50.85116263798305, 53.42609902790615, 48.58650153023856, 45.01191738673619, 46.83294643674578, 46.763568673815044, 42.79171085357666, 44.204536710466655, 49.871963432856965, 63.04761355263846, 60.55549621582031, 62.44720581599644, 65.49585996355329, 61.13885307312012, 57.75820357458932, 58.72939150674002, 57.47279936926705, 58.66573211124965, 58.46975816999163, 62.72165271214077, 57.20485946110317, 61.65714005061558, 47.305118220193044, 39.36148943219866, 57.27804136276245, 59.669253485543386, 59.27925109863281, 64.70887919834682, 50.58111047744751, 34.87726449966431, 43.87547697339739, 38.94166885103498, 31.67320694242205, 50.750167097364155, 61.56555584498814, 56.52359206335885, 58.00864444460188, 55.91327619552612, 56.10762078421456, 55.65876715523856, 58.665099825177876, 60.214652333940776, 58.00272805350167, 57.634042739868164, 57.582831042153494, 58.0872528893607, 57.612065587724956, 47.63594279970442, 48.38783516202654, 59.96641404288155, 56.29570157187325, 54.21198545183454, 45.66185883113316, 43.53399385724749, 41.468099866594585, 39.86210019247872, 41.79649257659912, 44.308613777160645, 43.94562251227242, 43.33127668925694, 45.73077801295689, 48.01130185808454, 45.64923048019409, 43.77722944532122, 44.097826276506694, 45.64766018731253, 47.5620903968811, 48.15192992346627, 49.25271218163626, 54.657493523189, 61.1964327948434, 63.69400446755545, 62.32389613560268, 60.41122382027762, 64.31915473937988, 66.80743667057583, 61.738864762442454, 63.71796185629708, 64.84813499450684, 61.714615549360005, 62.636627605983186, 62.85992881229946, 63.453388350350515, 64.26339544568742, 64.39648818969727, 66.15210342407227, 64.59995923723493, 62.43524101802281, 62.68228421892439, 64.87949916294643, 69.04040704454694, 62.35511439187186, 7.78992942401341, 4.958328749452319, 6.403369929109301, 2.319257880960192, 0.2739323766103813, 0.5243445581623486, 61.4014116014753, 71.76245416913713, 69.60384341648647, 57.4200382232666, 71.08732550484794, 41.05115931374686, 11.827085546084813, 27.252472911562236, 62.59564018249512, 59.753173828125, 80.13205964224679, 14.684324639184133, 0.7727145392979894, 0.1514419593981334, 0.1650068922234433, 0.2249472372766052, 0.18801007073904785, 0.18528316063540323, 0.1424792039075068, 0.19648455243025506, 0.1439159610973937], [0.05771324384425368, 0.0345600615920765, 0.0683531750525747, 0.015881941620526568, 0.0597664365278823, 0.06838908312576157, 0.015607638750225306, 0.04080835470397558, 0.11625501965837819, 0.10870368486004216, 45.3793693951198, 67.28694575173515, 60.642383439200266, 37.645513670785085, 21.851320266723633, 7.837293556758335, 37.43239504950387, 47.43971177509853, 58.371809414454866, 73.39470413752964, 4.756851834910257, 0.11552175400512558, 0.14948727642851217, 0.4742827873144831, 0.8269314957516534, 16.151527098246984, 66.34066363743374, 73.40563365391323, 70.09957654135567, 71.31018202645438, 72.89667115892682, 67.4582188470023, 68.64381776537213, 65.73537826538086, 66.38163021632603, 59.3522002356393, 53.57251146861485, 46.52128151484898, 52.57667827606201, 56.02570499692644, 62.137955393110005, 62.87277603149414, 63.9758095060076, 59.81451252528599, 66.70105280194963, 66.37651634216309, 61.6192376273019, 58.580908502851216, 52.914867946079795, 47.030858925410676, 46.03115211214338, 44.90350464412144, 47.83737455095564, 46.07728467668806, 45.38671711512974, 41.97702414648873, 43.0236382484436, 44.309489250183105, 44.28458343233381, 44.36140619005476, 43.154066358293804, 39.2376377923148, 42.14131430217198, 37.679695333753315, 40.03580168315342, 43.785827841077534, 54.74437379837036, 56.438438415527344, 57.40624257496425, 57.4444055557251, 58.66409928458077, 56.23220198495047, 59.74354362487793, 55.27404539925711, 57.69571842466082, 55.5358430998666, 57.94957433428083, 57.19078935895647, 56.33475739615304, 55.705045631953645, 58.557479177202495, 52.80288035529, 57.78095197677612, 50.46138606752668, 59.80730029514858, 39.117520809173584, 34.09038100923811, 42.32371841158186, 40.17860106059483, 26.29729015486581, 43.19620023454939, 54.91740826198033, 50.15354265485491, 49.431214877537315, 51.670900685446604, 54.12989943368094, 47.234361239842, 49.231499331338064, 50.08389738627842, 49.46084547042847, 51.431111403873985, 51.71142257962908, 50.79013660975865, 46.27425568444388, 44.45687096459525, 55.513528960091726, 49.48988199234009, 51.3756091935294, 46.1637167930603, 40.21271324157715, 39.34447676794869, 36.59440408434187, 34.968820912497385, 37.00277403422764, 36.49875865663801, 36.716126101357595, 38.54935966219221, 40.03667368207659, 42.13710716792515, 42.057154246738975, 40.12119504383632, 40.392720222473145, 41.51600422177996, 44.825973170144216, 43.89205884933472, 48.09007011141096, 52.24962656838553, 56.768884318215505, 56.868194920676096, 56.24832875388009, 61.65468733651297, 51.913656847817556, 60.45158590589251, 56.591076442173545, 59.32467842102051, 57.181058406829834, 60.16950988769531, 57.13836867468697, 56.982843671526226, 58.961885179792134, 57.900113582611084, 57.858302797589985, 57.86547333853585, 58.49418108803885, 59.13948808397566, 63.84433569226946, 61.538881710597444, 65.27999332972935, 59.440268652779714, 16.679637091500418, 0.6184119848268372, 0.804532837654863, 1.9380163039479936, 0.25276816370231764, 0.16250711493194103, 16.76003122329712, 66.54191820962089, 60.65516117640904, 51.02524627958025, 41.02819551740374, 38.47464220864432, 20.99369890349252, 13.36508059501648, 31.492390496390207, 45.15285464695522, 54.651802948543, 30.286565371922084, 0.2746467654194151, 0.1041337311533945, 0.055681085746203146, 0.046575953252613544, 0.02449594028959317, 0.09547854880137102, 0.06986987045300858, 0.029846278817525933, 0.09145807953817503, 0.07217860621001039, 0.028791248465755155, 0.09500734015767064, 0.07688287592359952, 0.048352127229528766, 0.07931038923561573, 0.02906977352020996, 0.03462406780038561, 0.08049389680049249, 0.07669114906873022, 53.102604797908235, 76.69965648651123, 66.83021286555699, 49.81637784412929, 32.101698875427246, 16.11193973677499, 34.60048648289272, 54.41597066606794, 64.20120906829834, 80.22822271074567, 4.790954462119511, 0.06166748808962958, 0.3755414757345404, 0.896674527653626, 0.7818521804043225, 18.247082948684692, 69.7697525024414, 77.39496271950858, 72.13615608215332, 72.20166369846889, 76.79996068137032, 70.53426974160331, 71.51081820896694, 69.26765482766288, 69.00975854056222, 61.40232181549072, 55.582396030426025, 49.48809630530221, 55.38298273086548, 59.066295760018484, 63.42715890066964, 64.79111112867082, 69.38670526232038, 64.80757141113281, 70.08883462633405, 69.1669476372855, 66.44594969068254, 62.76589189256941, 55.39880725315639, 51.315354415348594, 47.665955543518066, 48.439137186322895, 49.24349887030465, 49.380433968135286, 47.58403628213065, 44.857434613364084, 45.048489230019705, 46.50257001604353, 47.2329820224217, 45.65063401630947, 46.41949387959072, 42.4202184677124, 44.603599548339844, 40.93992212840489, 41.82787411553519, 46.197408608027864, 55.781614780426025, 59.90701389312744, 59.121547835213796, 58.798331533159526, 59.49009418487549, 60.51065254211426, 61.7413661139352, 57.75363860811506, 57.97639090674264, 57.0478058542524, 60.68108490535191, 59.928164209638325, 58.301563126700266, 57.20940705708095, 60.26976544516427, 56.420776094709126, 59.433563641139436, 51.28579330444336, 62.5196407863072, 42.32319382258824, 35.667653356279644, 43.12398065839495, 41.38321372440883, 29.602431842258998, 46.37786374773298, 54.56052098955427, 51.70882395335606, 52.003490107400076, 53.7029048374721, 55.652961935315815, 48.91382769175938, 51.685752459934776, 53.279804706573486, 53.69984763009207, 54.234376021793906, 54.2489846093314, 53.52100099836077, 49.09961209978376, 47.23042161124093, 57.84729337692261, 53.208953925541465, 51.83279718671526, 46.62876667295183, 42.89629513876778, 42.298760482243125, 39.51319292613438, 36.89991637638637, 39.38660717010498, 37.92487294333321, 41.62551825387137, 41.16843100956508, 42.181572164808, 43.21287938526699, 44.095950262887136, 43.01523787634713, 42.23524352482387, 42.90739836011614, 47.70877381733486, 43.53532443727766, 49.068049907684326, 53.57446043831961, 58.117762429373606, 57.161738940647666, 59.84706483568464, 65.43088735852922, 55.59916203362601, 61.7151575088501, 59.0808869770595, 61.904350008283345, 59.49542345319475, 62.29494299207415, 60.2525269644601, 58.36761270250593, 61.60346521650042, 59.95136424473354, 62.323659896850586, 59.128843443734304, 60.12783459254673, 63.21150071280343, 67.4044884272984, 63.515505245753694, 66.9673911503383, 62.336924007960725, 21.716884783336095, 0.4244349721286978, 0.7292444376008851, 1.7866332956722804, 0.8181091834391866, 0.3076042155069964, 17.172950506210327, 71.76928424835205, 65.00783933912004, 58.53270190102713, 48.02889469691685, 37.02915634427752, 22.049078157969884, 22.069860219955444, 39.672198976789204, 51.91209697723389, 61.395165170942036, 38.36686175210135, 0.3494880651789052, 0.07186831214598247, 0.055883184008832486, 0.053840990377856154, 0.012304401357791253, 0.035122119289423735, 0.08197703864425421, 0.036512725920017274, 0.0184116338246635, 0.1937356035092047, 0.11105925988938127, 0.14802027014749392, 0.2295042648911476, 0.13771074478115353, 0.2430789821914264, 0.10745739923524004, 0.13941529260150023, 0.2733911227967058, 0.25904770674450056, 63.4294934953962, 87.14857292175293, 75.04665224892753, 55.5017135483878, 31.401681763785227, 13.62507176399231, 54.37120689664568, 69.1282044819423, 70.60739258357457, 89.95785467965263, 6.360052253518786, 0.28206231178981916, 1.2642183282545634, 4.964572140148707, 2.886768502848489, 20.07170942851475, 73.60317093985421, 78.37921673910958, 75.4265866960798, 73.39507934025356, 80.46511459350586, 74.00273404802594, 76.31945105961391, 72.79418522971017, 74.23413685389927, 64.21848923819405, 58.19572121756417, 52.49594368253435, 58.96355969565255, 61.520858083452495, 66.23320279802594, 67.18848282950265, 72.12868676866803, 66.31714398520333, 70.01077161516461, 71.30375494275773, 69.49203300476074, 65.45618574959892, 58.40870434897286, 52.04600960867745, 50.467364992414204, 49.61827775410244, 50.92150967461722, 50.34381907326834, 50.86361033575875, 46.94208179201399, 47.77258607319423, 49.00843436377389, 48.3697246823992, 48.02728966304234, 49.26314490182059, 43.35576908929007, 47.531511374882285, 43.860576561519075, 44.65083687646048, 48.90702887943813, 57.02163199016026, 61.9850880759103, 60.063549859183176, 61.32036086491176, 63.444119453430176, 61.93076705932617, 63.480090277535574, 59.46660927363804, 62.21278749193464, 59.06689330509731, 63.50053187779018, 64.8812153679984, 59.31316525595528, 57.61622061048235, 61.92304066249302, 59.41241332462856, 62.354280608040945, 55.44358491897583, 64.85591697692871, 45.7053337097168, 39.123722076416016, 46.22162308011736, 43.739941937582834, 34.31614187785557, 50.905410698481965, 57.26466955457415, 55.53177840369088, 53.03688873563494, 57.07362188611712, 57.06368248803275, 52.856565611703054, 54.11734403882708, 54.89194311414446, 56.48966400963919, 57.127678871154785, 56.42431967599051, 55.45369107382638, 52.87875815800258, 48.70219251087734, 58.783177512032644, 56.80672420774187, 54.783909048352925, 50.40414333343506, 44.09094755990164, 44.40199409212385, 42.47127730505807, 40.49522352218628, 42.08297722680228, 41.342618874141145, 43.874059540884836, 43.93094791684832, 45.78983770098005, 46.79777812957764, 46.784305572509766, 46.562123026166645, 44.20199019568307, 46.237774167742046, 49.94424901689802, 46.897978101457866, 52.25889546530587, 55.761214869362966, 60.191410609654014, 61.68650313786098, 62.0492616380964, 63.49388939993722, 57.9838011605399, 63.219088145664756, 61.52971703665597, 65.52872494288853, 62.619604519435335, 64.8767476763044, 62.14245087759835, 61.76397555215018, 63.58199255807059, 62.28657736097063, 64.05125999450684, 63.73732648577009, 63.88078594207764, 65.96613488878522, 70.45986148289272, 66.8610281263079, 70.33201462881905, 66.95935208456856, 24.281541313443864, 1.7533401335988725, 4.412224658897944, 4.352071063859122, 0.7478049216525895, 0.2920352023627077, 21.71844117982047, 80.0603333881923, 71.97748701913017, 65.3459803717477, 55.01933833530971, 50.08926139559065, 30.01536328451974, 24.454202311379568, 46.77981703622, 60.962632860456196, 69.9064861025129, 49.00170155933925, 0.43091853708028793, 0.1639649202781064, 0.09423821392868247, 0.15303239119904383, 0.1902300337595599, 0.19261519291571208, 0.15592308608548983, 0.1731722197894539, 0.2108843411718096], [0.03413223847746849, 0.07384077273309231, 0.0392541057829346, 0.06775843910872936, 0.05101474614015647, 0.0035558585243831787, 0.02524874435870775, 0.031239965997104133, 0.17860470685575688, 1.5294146750654494, 62.15602765764509, 64.0203891481672, 54.12380586351667, 38.74582692555019, 16.877639906747, 31.850139345441544, 55.57479122706822, 44.29841729572841, 72.81256321498326, 51.798594679151265, 0.3771865431751524, 0.013197173630552632, 0.20812811835535935, 0.6782177899565015, 1.8556738538401467, 32.30742808750698, 71.90018830980573, 73.95343657902309, 70.9754456111363, 68.14676448277065, 71.4192201069423, 64.21518884386334, 64.04350580487932, 57.824207987104145, 54.185762950352256, 48.08032178878784, 54.33851214817592, 58.77645860399519, 60.649310793195454, 66.75844492231096, 63.58871841430664, 63.95660468510219, 62.90284088679722, 64.85073362077985, 76.90326649802071, 64.7994281223842, 63.85099901471819, 60.703694343566895, 62.34127358027867, 54.610072067805696, 46.8603709765843, 44.22269582748413, 46.30504662649972, 47.05962446757725, 47.074993882860454, 42.3491210256304, 43.85165854862758, 44.22204964501517, 46.247345311301096, 43.63032715661185, 42.59754344395229, 41.12712744304112, 39.7488306590489, 39.08693831307547, 38.78331593104771, 42.015635286058696, 52.947941371372764, 58.22402123042515, 58.25976971217564, 58.80530752454485, 59.88029112134661, 50.42149298531668, 52.89413104738508, 53.32635416303362, 51.217436926705496, 57.00326790128435, 55.7701016153608, 54.12113428115845, 57.12792205810547, 55.335363251822336, 58.866555895124165, 54.29960223606655, 54.74595103945051, 51.57778092793056, 57.3318065234593, 41.13106707164219, 36.42476381574358, 43.15236752373831, 37.7142904145377, 33.64897584915161, 46.14950772694179, 54.7617894581386, 51.52236557006836, 55.516117164066856, 51.714385986328125, 47.39451721736363, 48.04941620145525, 43.244938373565674, 48.853635447365896, 45.32930415017264, 49.38844524111067, 49.31506878989083, 46.000746795109336, 45.74607794625418, 53.85083893367222, 51.432518414088655, 52.343889304569785, 47.49101032529558, 45.562221663338796, 42.673334394182476, 39.48715802601406, 35.559497697012766, 35.91457148960659, 36.35431603022984, 36.17754690987723, 38.88918910707746, 37.05451032093593, 38.53018263408116, 42.24411290032523, 40.56373970849173, 40.48136534009661, 40.12109776905605, 40.13042572566441, 42.38264955793108, 43.9141298021589, 43.293363843645366, 51.30671433040074, 54.078986508505686, 58.97863033839634, 50.68814400264195, 58.67194380078997, 59.83052117483956, 56.77954980305263, 59.909021922520225, 55.15206977299282, 59.01649802071707, 57.710344382694785, 59.98302023751395, 56.921112401144846, 58.596840722220286, 57.067180906023296, 59.04767458779471, 62.269060952322825, 62.11962604522705, 61.58228015899658, 61.089715412684846, 62.584849630083355, 64.65715680803571, 56.52484968730381, 30.79254014151437, 0.3553339157785688, 1.3602148571184702, 0.6914718044655663, 0.2361113503575325, 0.24132049083709717, 2.0806699863501956, 56.5107934815543, 56.99325902121407, 60.98171261378697, 43.352308886391775, 58.59072630746024, 38.73242037636893, 14.116859180586678, 20.703971181597026, 41.48318787983486, 48.12306710651943, 56.76413869857788, 3.4874024902071272, 0.26336951340947834, 0.004385355710318046, 0.023000069128881608, 0.09528690337070397, 0.01697094113166843, 0.007013009287350411, 0.03937924460374883, 0.07235775981098413, 0.015082681651360222, 0.038911812007427216, 0.023341407866350243, 0.010043542183536504, 0.04172529639410121, 0.0610017366707325, 0.05347567390916603, 0.06500626036099025, 0.15006660962743418, 2.6255379489489963, 73.87101009913853, 71.0183298928397, 60.318951742989675, 41.42069925580706, 26.46424147060939, 29.201249803815568, 50.475400584084646, 54.09186846869332, 78.7528213773455, 54.81310885293143, 0.23261133102434023, 0.013121332075180752, 0.7668437457510403, 1.3479494409901756, 2.374197070087705, 36.381049224308555, 75.29978901999337, 77.06462451389858, 72.775723866054, 69.77520683833531, 72.88629749843052, 67.19830063411167, 66.4822609765189, 61.68530804770333, 55.51907362256731, 51.271341051374165, 56.44298948560442, 61.49415615626744, 63.7281687600272, 71.02093546731132, 64.04884202139718, 67.52237851279122, 64.72543675558907, 68.19998073577881, 74.29673317500523, 64.94759150913784, 66.56535448346818, 63.35621779305594, 65.06462696620396, 54.05009242466518, 49.151671477726524, 46.969221455710276, 47.16702624729702, 50.399158000946045, 48.511929988861084, 45.0631742477417, 47.32703283854893, 47.16131830215454, 48.634117535182405, 44.75199222564697, 44.50339610236031, 43.83370787756783, 41.8448520387922, 41.654638154166086, 40.857075282505576, 44.93836028235299, 53.16980777468, 59.69457272120884, 59.18485287257603, 58.999718121119905, 62.810610498700825, 53.20232881818499, 51.81183099746704, 52.08014610835484, 54.072681018284385, 59.355410303388325, 58.50488131386893, 57.042021478925435, 58.97817175728934, 56.94980846132551, 58.72452081952776, 56.49347857066563, 58.28348043986729, 54.13826159068516, 58.86448533194405, 44.09392138889858, 39.02236522947039, 44.222664560590474, 38.91197225025722, 35.39867469242641, 48.473787852696006, 56.77238621030535, 54.2243150302342, 56.99995361055647, 53.22739791870117, 45.75014264242989, 48.84188951764788, 45.853674275534495, 49.82242625100272, 47.40772226878575, 49.19444111415318, 50.07533025741577, 49.30435814176287, 49.787987504686626, 55.162898540496826, 52.923125880105154, 54.96997485842024, 51.282506806509836, 46.54176827839443, 45.159427642822266, 41.43679823194231, 37.85752058029175, 38.359750270843506, 37.65151344026838, 37.85765607016427, 40.337197167532786, 39.45044721875872, 39.903473240988596, 44.98895011629377, 43.0261013848441, 42.769549574170796, 41.70761469432286, 42.783706528799875, 44.45054810387747, 44.758047580718994, 44.23076268604824, 53.77092770167759, 57.00812816619873, 61.94147423335484, 54.96092830385481, 61.703039850507466, 59.49789701189314, 58.470390456063406, 63.349790709359304, 59.24729633331299, 62.49987316131592, 59.317327226911274, 62.04194518498012, 59.271080017089844, 60.425384249006, 60.060673304966514, 63.367070879255024, 63.93944263458252, 65.46142469133649, 63.98521736689976, 64.41904899052211, 64.64780453273228, 66.88490213666643, 59.40750789642334, 35.7111108643668, 0.6744287418467658, 0.5743947667734963, 1.5973916160208839, 1.2868350403649467, 0.16225456419800008, 1.9268928893974848, 61.69775921957833, 63.79523972102574, 66.16531889779228, 50.396062578473774, 47.44150788443429, 22.52952003479004, 17.44710210391453, 28.3587737764631, 49.08736937386649, 55.721012592315674, 65.89543696812221, 4.274758458137512, 0.3272436245211533, 0.004632640164345503, 0.0736854017845222, 0.020467545737379363, 0.05065953305789402, 0.04272205076579537, 0.04316867947844522, 0.04148188552686146, 0.1349032111465931, 0.09173211269080639, 0.14062868963394845, 0.1476342651460852, 0.11460673596177783, 0.09832621099693434, 0.11367084618125643, 0.2517198270985058, 0.38897608912416864, 3.377551470484052, 85.29437664576939, 79.96794319152832, 69.02481528690883, 50.75510031836373, 26.507513114384242, 46.254564489637104, 75.87233448028564, 57.637266704014365, 87.5114495413644, 60.73385647365025, 0.4797644817403385, 0.1528771152453763, 1.6610922664403915, 3.7358757172312056, 3.7819205607686723, 39.35759149278913, 79.21739183153424, 78.71114608219692, 76.17155865260533, 71.17740195138114, 76.13789463043213, 68.99598721095494, 70.91370391845703, 62.357608795166016, 59.8847588130406, 53.63639668055943, 60.13927132742745, 63.973217827933176, 65.70079708099365, 73.69488716125488, 68.84182058061872, 69.9570620400565, 65.70816217150006, 68.53537028176444, 76.95791407993862, 67.74809769221714, 68.53062466212681, 66.37621062142509, 68.64098984854562, 58.43152223314558, 51.67519119807652, 48.90400293895176, 50.483863489968435, 51.79116358075823, 52.05643538066319, 47.185411180768696, 50.5280887739999, 50.81600475311279, 50.73203229904175, 47.944029399326865, 47.02664136886597, 45.540241037096294, 43.573841776166645, 43.596093382154194, 43.49850593294416, 46.40118885040283, 57.02217047555106, 60.823439598083496, 61.8138427734375, 62.36733627319336, 63.683005469185964, 54.2675119808742, 54.84119347163609, 57.05368403026036, 56.6332346371242, 60.570024899074006, 60.383507456098286, 58.86880711146763, 62.162684031895225, 60.806777817862375, 63.71148613521031, 58.747908455984934, 60.37855339050293, 55.785182680402485, 61.96994795118059, 47.171320234026226, 40.63628932407924, 46.56855705806187, 39.12874214989798, 38.64061035428728, 50.045362676892964, 59.24264104025704, 57.23338181631905, 59.208678245544434, 56.961491857256206, 50.41024732589722, 52.21554218019758, 48.189512729644775, 51.986776215689524, 46.83236973626273, 52.49427958897182, 50.80251135144915, 52.934128352573936, 51.33592108317784, 57.75815841129848, 55.25374623707363, 58.47570582798549, 53.232226916721885, 49.75650174277169, 46.239274978637695, 45.03585045678275, 40.52847760064261, 41.90778187343052, 40.65362855366298, 41.38321025030953, 44.10585491997855, 41.09846264975411, 43.184200695582796, 47.58225406919207, 45.37235171454293, 44.25457068852016, 45.22870118277413, 44.545307636260986, 46.24167210715157, 47.400190421513145, 46.86948353903634, 55.40751682009016, 59.36967495509556, 63.12366853441511, 58.24052667617798, 63.601857457842144, 57.81719030652727, 64.58248451777867, 64.99332455226353, 61.46388980320522, 64.07808004106793, 63.06939615522112, 64.7291123526437, 60.4007111958095, 63.58623790740967, 63.47947883605957, 67.33499254499162, 66.35448360443115, 68.58368805476597, 66.46364675249372, 67.02522100721086, 66.74893978663853, 71.57473468780518, 62.004994664873394, 40.67614419119698, 1.3042610138654709, 7.612668718610491, 6.480633897440774, 0.7474170167531285, 0.31454809861523764, 2.894094292606626, 71.66966792515346, 66.49189812796456, 74.72902924673897, 58.315890312194824, 74.54864011492047, 52.297704628535676, 23.546830109187535, 31.91937119620187, 57.617276736668174, 60.99708897726876, 78.01888316018241, 6.355083857263837, 0.4292327303971563, 0.2060156488525016, 0.13231211661228112, 0.2121106439403125, 0.08104355087769882, 0.143470719988857, 0.14453585711973055, 0.19934377686253615], [0.04538196910704885, 0.08910239594323294, 0.07313561878566231, 0.006299109447614423, 0.08938267840338604, 0.11228976957499981, 0.054297077868665965, 0.179122442645686, 0.33949411287903786, 8.533816593033926, 71.31494154248918, 54.52246570587158, 45.89459569113595, 32.89792421885899, 28.07146576472691, 29.499973705836705, 49.55887413024902, 49.93270458493914, 78.81477151598249, 25.098784957613262, 0.13588233717850276, 0.13387774117290974, 0.17205775316272462, 0.24437115713953972, 3.751369331564222, 48.397854464394705, 73.14137976510185, 72.80905437469482, 67.6450559071132, 71.10954584394182, 70.60386289869035, 66.44163485935756, 63.050962584359304, 58.479666301182334, 56.90524271556309, 60.226158550807405, 62.12716484069824, 63.12592669895717, 64.29430798121861, 67.52630424499512, 63.28602014269148, 65.61653627668107, 58.75564874921526, 64.3972246987479, 47.95905835287911, 57.775223187037874, 66.93927873883928, 61.62881224496024, 62.4420085634504, 56.34462036405291, 49.56816734586443, 44.74723270961216, 45.38560887745449, 44.19562217167446, 45.15010316031319, 41.374709129333496, 43.234245095934185, 44.071819169180735, 44.58192464283535, 43.30752427237374, 43.866426944732666, 42.776956353868755, 39.753663131168906, 36.36002050127302, 37.98701415743147, 39.78677477155413, 44.550237383161274, 49.39821440832955, 54.70074953351702, 57.739655358450754, 56.56031676701137, 58.640419823782786, 40.03598233631679, 37.754162652151926, 53.959428855351035, 56.2384102003915, 55.80370657784598, 53.12238284519741, 53.30149698257446, 55.92364985602242, 60.40289293016706, 57.32284334727696, 53.13058519363403, 51.44371543611799, 58.30206339699881, 44.4446108681815, 38.302837576184956, 41.49212326322283, 40.79521199635097, 36.162201813289094, 43.72588225773403, 52.21676853724888, 50.4640611239842, 51.01106153215681, 52.45395919254848, 36.06172043936593, 30.57411309650966, 38.80210386003767, 41.94877277101789, 46.85596234457833, 44.014621598379954, 47.24375173023769, 48.17417458125523, 53.7517854145595, 48.34656286239624, 52.04042673110962, 48.82974754061018, 48.43242522648403, 44.543316977364675, 42.72816610336304, 37.89667020525251, 35.96182271412441, 34.186387743268696, 36.45867449896676, 36.76153605324881, 37.45592164993286, 35.78751673017229, 39.30347892216274, 41.277500356946675, 44.533103125435964, 41.91528940200806, 40.83135652542114, 40.18665402276175, 44.92716326032366, 42.756889956338064, 46.02959224155971, 45.08913619177682, 53.4577967098781, 57.991687365940635, 57.72949014391218, 49.50863518033709, 63.73033659798758, 58.516283307756694, 56.8054770060948, 54.92319958550589, 57.47927509035383, 59.61145836966378, 58.88290500640869, 57.834359305245535, 59.6961430140904, 59.858661379132954, 60.78771890912737, 57.70959397724697, 56.825008392333984, 57.81530039651053, 63.74696363721575, 62.690899985177175, 59.02899782998221, 56.322236742292134, 58.74697739737374, 7.973504304885864, 2.0078823949609483, 0.3920372048658984, 2.527313219649451, 0.20038388962192194, 0.24981588497757912, 28.870741367340088, 66.34301212855748, 61.15813432421003, 50.30055264064244, 54.528357778276714, 48.488983563014436, 14.520677191870552, 24.38815447262355, 33.990382535117014, 41.702212469918386, 63.03757340567452, 13.394004208700997, 0.5043377631476947, 0.06776369775512389, 0.07135626247950963, 0.062177244307739396, 0.08102581397231136, 0.07353252105947052, 0.04244141546743257, 0.03033509205228516, 0.07536342567098991, 0.06658717231558901, 0.09273154049047402, 0.08549254214657204, 0.05255124458510961, 0.045200349031282325, 0.1617553931261812, 0.1583993046411446, 0.41871611614312443, 10.975940772465297, 80.20090934208461, 61.258945737566265, 56.68341105324881, 43.80772161483765, 34.17435693740845, 25.03594892365592, 57.00708941050938, 56.21261501312256, 85.55988121032715, 26.998484986168997, 0.05570541461929679, 0.15976374356874398, 1.7101934488330568, 1.2154060389314378, 5.545831509998866, 52.72978530611311, 73.50874492100307, 75.7679933820452, 68.23244966779436, 71.63682379041398, 72.06124755314418, 69.39849635532924, 66.64261150360107, 61.83128275190081, 57.8489852632795, 62.50110994066511, 65.77775532858712, 65.9255713054112, 68.42458820343018, 68.84379386901855, 63.877026966639924, 65.9319428035191, 59.79063156672886, 65.1438433783395, 53.311839376177105, 60.10855334145682, 66.9955244064331, 65.39554187229702, 64.09196949005127, 59.0561374936785, 51.35193320683071, 45.91980375562395, 48.61738974707467, 47.52657815388271, 45.52935320990426, 45.04281949996948, 45.3739914894104, 46.8688234601702, 47.03993327277047, 45.108344486781526, 46.26173503058297, 44.050019196101594, 42.396605014801025, 40.42319502149309, 40.300889355795725, 40.98893472126552, 47.324173654828755, 53.47491707120623, 57.47632210595267, 58.61678900037493, 60.23637935093471, 59.17122050694057, 42.85059336253575, 42.54258666719709, 56.47061899730137, 59.43888596126011, 56.628318786621094, 55.78491864885603, 54.275485038757324, 57.61148541314261, 63.13041523524693, 60.1217896597726, 54.42104632513863, 53.71032551356724, 62.8326849256243, 46.465914794376914, 40.203492982046946, 40.738841261182515, 41.39971569606236, 37.948587145124165, 46.640001910073416, 55.25183548246111, 50.90314211164202, 52.18245833260672, 56.86370638438633, 41.36865030016218, 33.943433557237896, 43.082763944353374, 45.43362440381731, 49.80203676223755, 45.496661935533794, 48.50143820898873, 48.91423763547625, 54.4619642666408, 49.53523635864258, 52.55102205276489, 50.04438992909023, 50.37432861328125, 46.21158988135201, 44.45350456237793, 40.45302363804409, 38.09673316138131, 36.799435002463206, 37.69004814965384, 39.80812658582415, 40.502849170139854, 38.26821122850691, 42.01187631062099, 43.475038392203196, 46.58015707560948, 44.74926505770002, 42.822758878980366, 41.79529053824288, 45.806176389966694, 45.04954535620553, 48.50527014051165, 47.43513638632638, 54.60270697729928, 59.154621260506765, 59.85176181793213, 54.18932737622942, 65.48925917489188, 58.31798866816929, 58.74316283634731, 58.13706799915859, 61.698502676827566, 61.062256131853374, 60.38680785042899, 61.77648230961391, 62.53220312935965, 61.34597887311663, 61.42800235748291, 60.02362551007952, 60.788698605128694, 62.3249522617885, 67.04991490500313, 64.44440296718052, 61.76627540588379, 60.79739080156599, 60.90117604391915, 12.474461368152074, 0.9181627546037946, 0.6199919400470597, 2.307442469256265, 0.4953141159244946, 0.3577241503766605, 28.286696638379777, 71.72783824375698, 63.27975981576102, 56.665321418217246, 54.92616299220494, 38.82195486341204, 15.670819452830724, 30.65319401877267, 41.70370633261544, 48.9724565914699, 70.99900695255825, 17.731738533292496, 0.6521790357572692, 0.07095995731651783, 0.08771246445498296, 0.0166103727117713, 0.060354319268039296, 0.043213001385863335, 0.059989966319075654, 0.016570975272251025, 0.0954316756022828, 0.2421953124659402, 0.21147269888647965, 0.14436782470771245, 0.1428358961961099, 0.2837426359100001, 0.20496719011238643, 0.3475654497742653, 0.621158586016723, 14.5405855178833, 93.70077283041817, 68.69054440089634, 66.13323211669922, 44.99221229553223, 38.46770790645054, 41.23053748267037, 69.12964275905064, 62.10468047005789, 91.87115928104946, 31.66478225163051, 0.2120152690580913, 0.26984534306185587, 2.654572299548558, 2.442674172776086, 5.779741312776293, 55.5718069757734, 75.02128437587193, 77.84500449044364, 69.82425417218889, 73.6612022944859, 75.05253737313407, 73.55220590318952, 71.16821643284389, 66.31323214939663, 62.4962739944458, 64.6647720336914, 69.45111506325858, 70.26331084115165, 70.88319437844413, 72.4860256740025, 65.22782625470842, 66.89663764408657, 63.72846058436802, 66.45429447719029, 57.104027203151155, 63.69456727164132, 70.43598747253418, 65.97730759211949, 66.73285470690045, 61.76360729762486, 53.404476233891074, 49.65410614013672, 50.2991977419172, 49.237853458949495, 50.338625294821604, 47.39523983001709, 47.79622037070138, 49.30994449343, 49.65217106682913, 47.20613418306623, 48.4133802141462, 46.938253334590364, 44.99586704799107, 42.484944411686485, 42.24288306917463, 44.52069016865322, 49.414195265088765, 56.519774028233115, 59.42540645599365, 61.9398900440761, 61.89382348741804, 59.93648815155029, 44.09806946345738, 44.91338498251778, 57.903657163892476, 62.240462166922434, 59.229251861572266, 61.11724417550223, 58.00158507483346, 59.45476259504046, 63.87553310394287, 62.976985113961355, 58.75868511199951, 57.167474678584504, 63.11095333099365, 50.224918024880544, 41.128711632319856, 44.599868365696494, 44.10684503827776, 40.682956899915425, 50.50775487082345, 58.55315044948033, 54.26255791527884, 54.46635900224958, 58.372650146484375, 40.25957536697388, 36.074008328574045, 46.38625022343227, 45.58921888896397, 51.12045397077288, 46.635645389556885, 51.53676223754883, 50.41593442644392, 55.955545561654226, 52.01563555853707, 57.22809076309204, 54.04724713734218, 52.67824009486607, 48.985119683401926, 47.781392914908274, 42.871222564152305, 40.87085356031145, 38.299988814762656, 41.13269642421177, 41.968137400490896, 42.95364556993757, 41.22592387880598, 45.67101655687605, 45.555839742933, 48.332638672419954, 48.52284560884748, 46.550186020987375, 44.98714705875942, 47.786906310490195, 46.78913457053048, 49.53935316630772, 49.49631602423531, 56.69646324430193, 63.69303171975272, 61.433553968157085, 59.44962092808315, 66.20204707554409, 60.86499677385603, 62.072475569588796, 59.66271523066929, 65.24853883470807, 63.638613428388325, 65.64899131229946, 64.82304504939488, 63.74891608101981, 64.53896100180489, 63.56373964037214, 63.69651276724679, 64.90623583112443, 65.25547313690186, 70.80293573651994, 67.89466994149345, 67.43740899222237, 59.919937542506624, 60.045241355895996, 12.36668872833252, 3.6450631959097723, 4.460608005523682, 4.498065309865134, 0.6147402961339269, 0.3701609101678644, 35.36989525386265, 77.12392044067383, 72.54357760293144, 64.24207837241036, 73.21236951010567, 66.37623841421944, 24.165878125599452, 35.41001067842756, 48.483973911830354, 56.80019290106637, 82.43977873665946, 23.883256673812866, 1.0151744804212024, 0.3728998031999384, 0.20014044482793125, 0.14172155170568398, 0.15203187774334634, 0.2708130425640515, 0.16846662014722824, 0.22905282197254045], [0.09336924127170018, 0.02299864081266735, 0.07794316831443991, 0.03239976894110441, 0.09155781740056616, 0.1146409341267177, 0.033860050940087864, 0.23738230073026248, 0.6769078916737011, 18.889866011483328, 71.94415651048932, 47.44236251286098, 39.85265064239502, 23.256866148539952, 33.41500220979963, 44.52305255617414, 43.611709458487375, 55.11583144324166, 75.23562240600586, 10.3319365637643, 0.15196566629622663, 0.195176703323211, 1.151779647384371, 0.22978357704622404, 11.984175630978175, 62.93954821995327, 67.90748241969517, 74.1318176814488, 66.89705453600202, 67.99887207576207, 70.40105887821743, 71.06100572858537, 65.36398315429688, 64.76338781629289, 64.72469329833984, 66.15388216291154, 65.4684979575021, 73.68215111323765, 69.4540194102696, 67.04198006221226, 60.310342924935476, 62.29117706843785, 62.791461263384136, 64.46068954467773, 65.2151596886771, 61.00307832445417, 62.655047280447825, 60.07357610974993, 58.18984651565552, 59.53809234074184, 52.92354277202061, 47.17617007664272, 42.73255041667393, 44.43026283809117, 43.969173431396484, 43.026264667510986, 42.48440940039498, 43.07416902269636, 44.12886735371181, 43.64046457835606, 42.93634455544608, 39.992642947605674, 38.24863120487758, 38.376050744737896, 37.96142741612026, 39.71542719432286, 40.118203844342915, 44.72674594606672, 49.874954632350374, 57.387541498456685, 55.37680925641741, 57.442790099552695, 57.24068089893886, 58.503248487200054, 54.80865853173392, 52.38178130558559, 52.90724924632481, 47.95605673108782, 50.96023893356323, 52.92461974280221, 55.9337386403765, 47.82246371677944, 46.84978192193167, 51.96676540374756, 56.30592584609985, 42.97219031197684, 39.89804669788906, 41.31843219484602, 36.22054236275809, 34.05266271318708, 42.905953134809224, 54.76210560117449, 45.07532664707729, 48.88682004383632, 50.597268513270784, 54.61072867257254, 44.81957735334124, 48.597278186253135, 51.44043588638306, 53.34093843187605, 50.479868275778635, 48.5127602985927, 48.701049532209126, 50.71610702787127, 49.40664952141898, 50.42022841317313, 48.44676978247506, 46.601251806531636, 43.33761692047119, 40.05020877293178, 33.62121779578072, 35.99953753607613, 37.96479729243687, 37.9461726461138, 36.60893276759556, 38.44329193660191, 37.96076038905552, 39.42060123171125, 41.129576683044434, 42.703048365456716, 41.23518235342843, 41.06009122303554, 41.564589500427246, 44.43691226414272, 46.54697247913906, 47.361516748155864, 44.96926586968558, 43.93185813086373, 52.34907613481794, 56.64760003771101, 56.75730167116438, 49.24128586905343, 61.39771515982491, 60.04247597285679, 58.027720723833355, 56.877342224121094, 55.895533970424104, 60.04683944157192, 61.170314516339985, 58.73159408569336, 56.642166546412874, 54.69551753997803, 60.20554324558803, 62.367760113307405, 64.28342710222516, 58.28872980390276, 57.83542585372925, 53.88964809690203, 56.658967290605815, 50.30061864852905, 55.21889407294137, 1.3698773043496268, 1.2061285653284617, 4.246415019035339, 0.5903342600379671, 0.03792315595118063, 4.252923309803009, 62.69746603284563, 59.04287338256836, 57.280872753688264, 46.18473856789725, 47.458999974387034, 24.659818615232194, 15.84164091518947, 37.57175159454346, 43.64580079487392, 57.86454575402396, 31.729487351008824, 0.22250974949981484, 0.03807235223108104, 0.04705318050192935, 0.011599565473651248, 0.04282099474221468, 0.04982773394190839, 0.08992999153477804, 0.02141103341377207, 0.14688778163066932, 0.01009581228052931, 0.07392778806388378, 0.05253966199234128, 0.11061486694961786, 0.12627926176147802, 0.051367041521838734, 0.20589035057595798, 0.6181625010711806, 23.659236328942434, 81.73911544254848, 53.88573626109532, 48.99165446417672, 32.01301901681082, 25.779310635157994, 29.848644733428955, 54.248706681387766, 56.45609726224627, 84.38494777679443, 9.677114009857178, 0.15115085430443287, 0.3110883842621531, 1.6731012506144387, 1.1592333274228233, 13.720054507255554, 65.45487948826381, 69.71969767979213, 76.01390402657645, 68.38066169193813, 68.46124689919608, 72.31236934661865, 74.37374700818742, 68.41745240347726, 66.5399032320295, 68.49054745265416, 67.96703542981828, 67.8537381035941, 75.63306631360734, 70.58074624197823, 67.37223488943917, 62.57933970860073, 66.10168034689767, 64.22247055598667, 65.29990686689104, 66.90968636104039, 63.64448465619768, 62.73756408691406, 64.00465147835868, 61.903884478977744, 63.291384152003694, 56.40377037865775, 49.67507580348423, 45.61432620457241, 46.768835408346995, 46.6862074307033, 45.43354449953352, 45.12553433009556, 46.07695116315569, 45.47615432739258, 45.018698828560964, 43.99846703665597, 43.26500129699707, 41.56287676947457, 41.59914289202009, 40.549096379961284, 40.83543511799404, 41.39415366309029, 45.46694449016026, 50.957754952566965, 60.739553996494834, 58.99450697217669, 59.314249174935476, 60.07158892495291, 61.13913100106375, 58.98300075531006, 54.159797532217844, 54.514492647988455, 50.08311571393694, 50.21848051888602, 54.110910006931846, 56.75568274089268, 49.90439762387957, 48.69493511744908, 53.129730565207346, 58.25780684607369, 45.37993914740426, 39.18024219785418, 39.584543977464946, 37.08605514253889, 37.15002720696585, 44.357879979269846, 57.75637967245919, 46.43284484318325, 50.245894636426655, 53.39611060278756, 58.551031248910085, 49.00977189200265, 49.314148153577534, 53.01233032771519, 54.43377195085798, 54.40019130706787, 51.59922654288155, 50.05084480558123, 53.38343014035906, 52.6059684072222, 53.530850069863455, 53.06767272949219, 48.55848639351981, 46.78563962663923, 43.87493848800659, 38.07358523777553, 38.599278994968955, 39.40312998635428, 38.59575278418404, 39.42541285923549, 40.063879353659495, 40.55631903239659, 40.96717643737793, 43.61670868737357, 43.419873169490266, 43.69134971073696, 43.285397733960835, 42.62224776404244, 45.938584736415315, 48.11969028200422, 47.1110063961574, 45.32343292236328, 45.52157122748238, 52.99907316480364, 58.19292456763131, 59.18544346945626, 53.617254393441335, 64.2313711983817, 60.70511177607945, 59.23390020642962, 57.28355128424508, 59.013371331351145, 61.93488039289202, 62.33275508880615, 59.43168762751988, 60.00325339181082, 57.57577862058367, 62.223397391183035, 65.98977266039167, 66.51256207057408, 58.13184642791748, 58.91899394989014, 54.99662120001656, 59.57669653211321, 53.45408984592983, 60.896430424281526, 4.130080895764487, 0.79909234387534, 0.9332025647163391, 1.3202834512506212, 0.06483941538525478, 3.857210372175489, 66.15297194889614, 65.01327977861676, 64.33236326490129, 51.48700271333967, 45.89617640631539, 25.88467311859131, 25.864255837031774, 42.88889530726841, 48.13783202852522, 65.61049829210553, 37.72484472819737, 0.384321284613439, 0.08257429195301873, 0.026770186111597077, 0.08641761607889618, 0.07955359654234988, 0.056314901914447546, 0.0769003482003297, 0.044645985921046565, 0.23120513505169324, 0.08386960851826838, 0.16748547208096298, 0.1895430170531784, 0.24285897399697984, 0.28313901115741047, 0.19185456873050757, 0.5252613403967449, 0.8629061196531568, 27.667381116322108, 93.64995370592389, 59.89008808135986, 54.92787224905831, 33.042867115565706, 45.6472293989999, 61.378364426749094, 62.54839938027518, 63.917632239205496, 89.90090029580253, 12.318556819643293, 0.2021552731416055, 0.5356529142175401, 3.2980408455644334, 4.302381455898285, 16.87914592879159, 68.05674362182617, 73.33484540666852, 77.53986045292446, 70.27815219334194, 70.91437094552177, 73.90242290496826, 78.02995858873639, 71.32383523668561, 70.53440175737653, 70.79629325866699, 71.52501337868827, 71.71039826529366, 76.60962867736816, 69.46910394941057, 67.02064909253801, 62.52864565168108, 69.20796285356793, 67.18369552067348, 71.27990177699498, 69.76131738935197, 65.1403067452567, 66.57263619559151, 64.98576491219657, 65.04907689775739, 65.65466799054826, 59.75420910971505, 53.24590444564819, 47.80562128339495, 50.75492313929966, 50.46754911967686, 49.213486126491, 49.20529767445156, 49.145216601235525, 47.67803151266915, 45.52512175696236, 46.687593596322195, 46.35191570009504, 43.01792682920183, 44.58974136625017, 42.521141052246094, 44.063800948006765, 45.340483801705496, 47.97487940107073, 53.453700746808735, 63.584820474897114, 61.456184250967844, 62.155652454921174, 62.64996119907924, 62.57118252345494, 60.28791413988386, 56.300283908843994, 58.65936756134033, 53.857787132263184, 53.703168869018555, 58.8168762751988, 60.63701942988804, 53.09553847994123, 50.759109428950715, 56.6246223449707, 60.0549201965332, 46.77640199661255, 40.852058683122905, 40.23141084398542, 38.34903962271554, 37.531215803963796, 47.39199154717581, 59.75903810773577, 49.77455316271101, 54.32620341437203, 55.55007995877947, 58.32412392752511, 45.34732430321829, 52.39672340665545, 54.04955046517508, 57.81592920848301, 54.8000670841762, 52.36594636099679, 51.25038528442383, 54.37076221193586, 54.06012909752982, 54.647022587912424, 56.108979157039094, 50.60062449319022, 48.064521585192, 45.00554241452898, 39.953885895865305, 40.822070258004324, 41.00714594977242, 42.924466609954834, 42.3575005531311, 45.2943616594587, 44.430585929325645, 43.425035681043354, 45.406151226588655, 48.28400475638253, 47.44785853794643, 46.52463402066912, 44.88272953033447, 48.47802972793579, 51.22739369528634, 49.72217764173235, 46.66680111203875, 47.977405071258545, 56.52600308826992, 62.14421572004046, 62.315384592328755, 57.282950265066965, 65.10512801579067, 58.69980607713972, 60.11994143894741, 60.00808933803013, 60.876502990722656, 64.95738846915108, 64.37150246756417, 62.44419724600655, 62.32245091029576, 61.76993015834263, 66.84740270887102, 68.5061114174979, 68.8180160522461, 59.26063687460763, 61.17462239946638, 56.52586759839739, 63.17994199480329, 54.36736454282488, 61.73949704851423, 3.2264533383505682, 3.3865721864359717, 13.4914014509746, 2.8679202113832747, 0.12044392845460347, 5.947017456804003, 75.86089774540493, 69.79843466622489, 69.86439391544887, 61.70581912994385, 62.35784503391811, 37.78985554831368, 26.144924845014298, 48.95745890481131, 58.756190708705354, 73.57810878753662, 49.99986239842006, 0.397722812635558, 0.17760568617710046, 0.1063860874356968, 0.15268110004918917, 0.15741679950484208, 0.10531876542206321, 0.19542674347758293, 0.10396428738853761], [0.13068923726677895, 0.08242996755455222, 0.09128830329115901, 0.04663085352097239, 0.011154316731595566, 0.1190033850393125, 0.05687340748097215, 0.10774125078959124, 0.20311291675482476, 28.916882617133005, 65.26530483790806, 53.28644718442644, 37.069560119083945, 29.047112703323364, 39.565669195992605, 56.342594964163645, 45.398254598890034, 64.81431116376604, 61.61055932726179, 1.4343946938003813, 0.019858567343492593, 0.27505638343947275, 1.2654118984937668, 0.9012045360037259, 21.35689687728882, 67.57572678157261, 68.7721232005528, 71.464494568961, 66.56386756896973, 64.97760077885219, 62.737883704049246, 69.78868634360177, 67.32946177891323, 67.8795645577567, 66.52818856920514, 68.3740678514753, 64.04285962241036, 51.825630119868684, 52.57156440189907, 59.73804759979248, 60.14844989776611, 64.10702623639787, 61.20224148886544, 61.28476524353027, 56.3178767476763, 55.595152923039024, 59.336038725716726, 59.911287035260884, 59.788164956229075, 62.74742358071463, 55.02278464181082, 45.03505488804409, 43.99855736323765, 46.055543763296946, 42.8376419203622, 42.08794171469552, 42.85358108792986, 44.0878312928336, 44.58912297657558, 43.29243973323277, 43.291758809770855, 40.221756322043284, 38.80563701902117, 39.80203996385847, 39.494314670562744, 39.004928725106375, 38.42017180579049, 39.48716844831194, 44.67304679325649, 47.57648359026228, 57.45025941303798, 53.93329668045044, 57.81753076825823, 53.499489375523154, 50.88167217799595, 53.920011724744526, 49.63472066606794, 42.59734194619315, 43.63554525375366, 45.125485692705425, 49.00967114312308, 44.14247192655291, 51.60885327202933, 53.616250378744944, 59.219844000680105, 37.88746384211949, 39.411443505968364, 48.49978453772408, 38.20331505366734, 37.6883145741054, 37.50263091496059, 52.74434873035976, 49.27933420453753, 43.55702713557652, 45.84863335745675, 53.715029444013325, 55.55832052230835, 54.03129407337734, 53.98088141850063, 52.359300409044536, 51.05094419206892, 51.64839547021048, 48.44185740607125, 52.42425911767142, 52.12144272668021, 49.07571029663086, 47.23769984926496, 48.55475868497576, 42.06808723722185, 40.08434874670846, 35.122883319854736, 35.42855889456612, 35.41879320144653, 36.23343127114432, 36.64857571465628, 38.158325467790874, 36.345908709934776, 39.28221048627581, 42.484510149274556, 43.37608214787075, 44.39167949131557, 42.304044587271555, 39.635995388031006, 42.028034346444265, 43.85554606573922, 41.23847232546125, 42.67686755316598, 43.40118251528059, 47.78858082635062, 53.203364099775044, 54.00055524281093, 57.61713777269636, 49.657806055886404, 57.611874512263704, 66.58281530652727, 61.66321277618408, 58.140003613063264, 55.03132050377982, 57.827397210257395, 59.51884583064488, 60.933638027736116, 65.13071128300258, 62.84526811327253, 58.20732123511178, 55.88183907100132, 55.46728869846889, 56.12696804319109, 58.777980259486604, 58.746768951416016, 60.51691286904471, 55.2755948475429, 52.63182265417916, 0.6158484252435821, 1.1369362324476242, 1.4455398214714867, 0.002790974623556914, 0.045580596663057804, 39.62967600141253, 65.77737317766461, 60.766207286289756, 46.83379759107317, 52.49446024213518, 27.150032145636423, 9.347252624375479, 18.606935364859446, 43.08102342060634, 49.18100677217756, 51.32010350908552, 0.9865766721112388, 0.05389063199982047, 0.050263740188841305, 0.0318737448459225, 0.03495332013283457, 0.050845923234841654, 0.0897636893870575, 0.037768029275217226, 0.1028526434674859, 0.05172909423708916, 0.06958557785089527, 0.00688443411075111, 0.042117018053042035, 0.07906353141048125, 0.053268517167972665, 0.09551493184907095, 0.2387662407542978, 36.45031581606184, 77.9185789653233, 58.27869313103812, 43.859482220241, 40.03574957166399, 37.96943174089704, 53.99746676853725, 55.8571903364999, 69.37890938350132, 67.80454485757011, 1.2126311021191734, 0.027515940201867903, 0.43793002941778725, 1.0989261120557785, 1.2521202117204666, 24.2137234210968, 69.92371763501848, 70.0621257509504, 72.4991021837507, 68.40745394570487, 65.61805098397392, 62.27279213496617, 70.80852208818708, 69.51724106924874, 70.75028923579625, 68.69256632668632, 70.42212581634521, 66.96641840253557, 54.25494268962315, 56.31298868996756, 62.80996431623186, 62.39030006953648, 65.30775833129883, 63.72950281415667, 64.21929522923061, 60.70843996320452, 58.47425365447998, 63.063260895865305, 63.26095799037388, 64.73823533739362, 63.47219712393624, 55.98428331102644, 47.882030623299734, 45.56421232223511, 47.1162314414978, 45.21808780942644, 44.75467075620379, 46.30513347898211, 45.63603932516915, 46.49136257171631, 46.241880553109304, 46.495413371494834, 42.41144984109061, 41.24382243837629, 43.664335114615305, 40.82423462186541, 41.29567684446062, 40.66661821092878, 42.75728947775704, 45.48656620298113, 50.94747856685093, 59.80279786246163, 56.87145709991455, 57.705748149326865, 56.22998898369925, 53.48522819791521, 54.83630541392735, 51.46304185049874, 46.75444221496582, 44.24849101475307, 48.765834535871235, 51.14073576245989, 44.403901372637065, 53.14401953560965, 55.56091914858137, 58.8652218409947, 41.61971998214722, 37.60532876423427, 44.43605416161673, 38.01671770640782, 38.3695889200483, 39.27096135275704, 54.231450830187114, 51.88349124363491, 46.23999064309256, 49.114887714385986, 54.29039587293352, 54.29239695412772, 56.85134553909302, 53.22197137560163, 55.667469773973735, 52.278016907828196, 52.88821118218558, 51.439247744424, 54.47242825371878, 53.87033905301775, 52.60108034951346, 52.0791004044669, 50.33479683739798, 44.34406696047102, 42.12637914930071, 37.65411901473999, 35.84162930079869, 37.318173612867085, 39.12701552254813, 38.97574629102434, 39.98703922544207, 38.446220602308, 43.18366568429129, 43.672693797520225, 45.20191935130528, 46.07826089859009, 43.351537636348176, 41.92384263447353, 44.67337335859026, 45.3313364982605, 43.0214113507952, 43.887031827654155, 44.15810884748186, 48.381981304713655, 56.082235540662495, 55.67629051208496, 59.816979135785786, 54.19673415592739, 60.92086723872593, 65.74382727486747, 61.45264761788504, 59.236213956560405, 59.06300231388637, 60.114459310259136, 62.993348121643066, 64.15617779323033, 65.98046207427979, 62.5147978918893, 57.002659933907644, 57.43745388303484, 56.58780384063721, 57.01474979945591, 61.42119312286377, 59.52945572989327, 64.21285424913678, 56.55169057846069, 61.726003646850586, 1.506525137594768, 0.7566243569765772, 0.6981786074382919, 0.1108229939958879, 0.010169800587131508, 38.91453960963658, 69.56219591413225, 65.47222219194684, 54.55122429983956, 54.056543827056885, 24.083628824778966, 17.342893021447317, 25.576784542628697, 49.32281603131975, 56.50648212432861, 57.111367974962505, 1.3803645244666507, 0.18151478070233548, 0.0814659253561071, 0.02244649820828012, 0.02612034124987466, 0.03024352035884346, 0.1327967263225998, 0.031469331189457855, 0.28750891238451004, 0.19079830683767796, 0.1590481876794781, 0.10569077903138739, 0.09171456577522413, 0.2771558793527739, 0.11306950809167964, 0.29889953402536257, 0.3432264354612146, 42.225022724696565, 87.72602381025041, 67.07463659558977, 53.76759604045323, 40.82457855769566, 58.83354500361851, 75.0510504586356, 61.86374473571777, 76.4769389288766, 75.23070308140346, 2.099731066397258, 0.14777711033821106, 1.9744144422667367, 5.078032749039786, 2.9421721356255666, 24.890609979629517, 74.3982185636248, 72.41591835021973, 75.54622077941895, 68.76898956298828, 67.36029093606132, 63.58320154462542, 73.98475905827114, 72.50095735277448, 73.75911630902971, 70.42903927394322, 72.24513162885393, 64.79149327959333, 53.53630093165806, 58.26743704932076, 64.5637104851859, 64.77677699497768, 70.50697026933942, 66.30493600027901, 66.74913433619908, 62.863534927368164, 60.47842679704939, 64.67563901628766, 66.16666684831891, 67.18320914677211, 66.42073467799595, 58.691364015851704, 48.95118120738438, 47.797839300973074, 50.907856464385986, 47.84741817201887, 47.8178779057094, 47.58665575299944, 49.217179094042095, 49.15770251410348, 47.133581093379426, 47.79279143469674, 44.62032733644758, 43.82297985894339, 45.175891399383545, 44.73659501756941, 43.88150800977434, 44.313578265053884, 44.9949220929827, 48.60720716203962, 53.476886885506765, 62.550303186689106, 60.405970982142854, 60.44750036512102, 59.74405084337507, 54.836072649274556, 57.12719944545201, 54.97811814716884, 47.677017075674875, 47.56156580788748, 50.57951586587088, 52.505233424050466, 48.32383183070591, 53.906896999904085, 58.74015426635742, 62.45926094055176, 45.40743316922869, 39.22713906424386, 45.593794277736116, 37.70462894439697, 39.448213372911724, 43.8893038885934, 57.18520648138863, 54.14380625316075, 49.09764575958252, 52.99262523651123, 58.4238931110927, 58.575419425964355, 57.51843861171177, 59.99734047480992, 57.44419016156878, 56.361278670174734, 55.738952841077534, 54.04530511583601, 57.61249985013689, 56.29193564823696, 54.748619147709434, 53.47344752720424, 54.067886761256624, 47.828206402914866, 44.443106583186555, 41.001028060913086, 38.02358947481428, 40.243726525987896, 41.33932195390974, 43.28264972141811, 43.68503032411848, 43.24985074996948, 44.90016950879778, 47.03598322187151, 49.037974630083355, 48.37392486844744, 45.549270221165244, 44.12125907625471, 46.6651474407741, 49.01530613218035, 45.178344113486155, 45.80007587160383, 45.46186188289097, 50.011559690747944, 57.33083724975586, 57.135832582201274, 61.34764644077846, 57.79238871165684, 65.05699784415108, 67.33700752258301, 62.37099797385079, 60.40330287388393, 60.6948492867606, 65.518524987357, 66.54092461722237, 66.83449990408761, 67.8826356615339, 62.48994418552944, 57.3118964603969, 59.35130391802107, 58.0022486277989, 59.34829534803118, 64.08226980481828, 61.378128187997, 67.03685923985073, 60.06646115439278, 60.17190701620919, 0.9071520854319844, 3.8523726889065335, 4.7057856151035855, 0.14504341488437994, 0.15547958202660084, 47.29839931215559, 75.5247300011771, 72.07673508780343, 61.17642198290144, 68.74575478690011, 38.08280202320644, 17.382784366607666, 32.97742550713675, 60.77735219682966, 65.26870945521763, 67.9394302368164, 2.6806108908993855, 0.3781889836703028, 0.2643375386084829, 0.11597713242684092, 0.21120496253882134, 0.15379476600459643, 0.1796472216291087, 0.13599358978016035], [0.11798786238900252, 0.12359925199832235, 0.030710830818861723, 0.0030537231027015616, 0.06678838509001903, 0.04756978653105242, 0.07780421791332108, 0.0751993694741811, 0.0651442404570324, 40.910833495003835, 63.940776688711985, 51.71699850899832, 37.01004532405308, 25.346260683877126, 41.697557176862446, 52.846626213618684, 46.36487756456648, 74.94963455200195, 39.03616087777274, 0.059732679410704544, 0.07721478811332158, 0.3486540642167841, 0.5538783648184368, 4.44339644908905, 46.157466888427734, 67.66469151633126, 66.20009463174003, 68.82298401423863, 67.39538628714425, 65.79171425955636, 60.31624889373779, 59.18836866106306, 65.96282059805733, 65.89011464800153, 63.1957699911935, 61.10413292476109, 51.03036362784249, 57.7035698890686, 63.36638995579311, 61.4296212877546, 62.84273896898542, 60.90412902832031, 57.09816639763968, 55.8101475579398, 53.11100517000471, 53.39287969044277, 58.14275509970528, 59.02482196262905, 58.90235301426479, 60.53810487474714, 52.11178820473807, 44.94385283333914, 45.07676145008632, 44.56108004706246, 42.49464062282017, 40.50717094966343, 41.696910994393484, 44.20261205945696, 43.75639527184622, 42.54236085074288, 41.90900475638253, 39.39744288580758, 39.20753124782017, 41.392218589782715, 38.070423807416645, 37.107163769858225, 38.25356789997646, 37.06342485972813, 42.77420139312744, 43.38551432745797, 49.559450830732075, 53.65545211519514, 55.7638829776219, 53.03080906186785, 54.65703494208199, 46.41564457757132, 43.12460947036743, 42.92458125523159, 41.939118249075754, 41.22891855239868, 44.251339776175364, 45.304023129599436, 55.38885743277413, 51.58616392953055, 61.9983035496303, 34.30103996821812, 20.21091137613569, 55.968896525246755, 45.755881854466026, 42.77296461377825, 37.136884689331055, 53.239182063511436, 47.62340824944632, 45.125426633017405, 45.683036940438406, 51.87970447540283, 47.55543054853167, 52.57509061268398, 49.15769556590489, 49.10538257871355, 49.166200160980225, 50.33385188238961, 49.65210853304182, 51.13543081283569, 51.722369466509136, 50.86305100577218, 49.06115729468209, 46.568654332842144, 41.57375764846802, 36.694628374917166, 34.081021785736084, 33.13662610735212, 35.606797558920725, 34.59030042375837, 35.1959992136274, 38.297039304460796, 35.81152623040335, 43.09751149586269, 43.01697145189558, 44.70530380521502, 44.27687440599714, 41.18270608357021, 41.14875371115548, 41.30777713230678, 42.80770560673305, 42.54936463492257, 43.66240004130772, 43.711343152182444, 42.01694849559239, 52.73120273862566, 57.345334666115896, 58.291425704956055, 62.194062096732004, 53.79091419492449, 55.282067094530376, 59.75773879459926, 58.44859395708357, 63.22959382193429, 64.54977934701103, 65.50273868015834, 63.3035226549421, 60.27869388035366, 56.63165739604405, 60.08024638039725, 60.57948834555489, 63.87618623461042, 61.00503771645682, 63.750896317618235, 59.17440973009382, 66.01655796595982, 59.58142825535366, 64.92876883915493, 42.115098748888286, 0.2502145107303347, 0.847294494509697, 0.4086922811610358, 0.44404759258031845, 10.814598390034266, 65.27187783377511, 58.64868123190743, 52.77085610798427, 44.53611169542585, 51.751437255314414, 22.448903560638428, 12.487893973078046, 35.65097073146275, 46.84781905582973, 65.12287371499198, 7.28000373499734, 0.5167966431805066, 0.08563109221202986, 0.1114701060578227, 0.02541666311611022, 0.11590695833521229, 0.07638413911419255, 0.030040875875524113, 0.143975753603237, 0.060055743503783426, 0.045336235846791945, 0.05194446803735835, 0.03016926148640258, 0.049788823351264, 0.08140850772282907, 0.03121782200677054, 0.050138777787131925, 46.615502561841694, 74.33028602600098, 58.37992491040911, 37.37832416806902, 23.8803870677948, 33.87359026500157, 57.41561222076416, 53.054749080113, 79.61529432024274, 43.05009698867798, 0.11401176931602613, 0.10601000940161091, 0.620023749768734, 0.5270859482032912, 5.869271457195282, 49.49315111977713, 70.83868421827043, 69.56996400015694, 70.80976581573486, 68.39322403499058, 66.7657961164202, 61.62598432813372, 61.04432283129011, 67.17671258108956, 67.51064995356968, 62.21411459786551, 61.71638734000069, 54.723650796072825, 57.28586850847517, 65.27287837437221, 61.85602528708321, 66.88859163011823, 64.03116580418178, 62.03637967790876, 56.950770786830354, 55.86320052828108, 55.783004420144216, 60.397355215890066, 62.041243416922434, 62.426236152648926, 62.9095458984375, 53.01142358779907, 46.995152132851736, 47.44805656160627, 47.018776008060996, 45.103852476392476, 42.02560247693743, 44.44469077246529, 47.137816020420615, 45.37913315636771, 44.26533692223685, 44.79762799399239, 41.484504563467844, 41.34336233139038, 42.06056233814785, 39.07087060383388, 39.14496619360787, 40.849237714494976, 39.85320997238159, 45.863731792994905, 46.118098395211355, 51.2771532194955, 55.276442527770996, 59.58665330069405, 55.99938522066389, 54.875809397016255, 47.785155364445274, 44.161430086408345, 44.738384178706575, 43.95442587988717, 42.84133836201259, 47.61864873341152, 48.490560804094585, 58.32310949053083, 53.7713098526001, 61.48674937656948, 36.53635883331299, 19.991129432405742, 47.535114015851704, 43.88477713721139, 43.43088606425694, 40.47220066615513, 54.873040539877756, 49.030901363917756, 45.99563292094639, 47.66930110113961, 56.63555186135428, 49.034194810049875, 55.49969162259783, 51.82460873467581, 49.961463178907124, 52.102745124271934, 53.026053019932334, 51.75072506495884, 53.928172383989605, 54.16248301097325, 52.56778458186558, 50.77557665961129, 50.83301394326346, 43.15987505231585, 38.6293751171657, 36.904359749385286, 35.60925374712263, 38.04800891876221, 36.78966930934361, 37.24687467302595, 39.13578067507063, 38.182011876787456, 45.486329964229036, 45.66930035182408, 46.8018810408456, 47.87485313415527, 42.30165788105556, 43.282799107687815, 43.413682324545725, 44.30550445829119, 44.61249671663557, 45.981934547424316, 44.97177069527762, 44.326168400900706, 54.06101499285017, 58.83143275124686, 59.541747093200684, 64.6771467753819, 55.844589778355186, 59.3603435243879, 62.48264857700893, 61.63230718885149, 65.3638094493321, 67.99924727848598, 65.810898235866, 62.94514151981899, 60.14480904170445, 60.53287982940674, 60.42778832571847, 63.84017372131348, 66.45217527662004, 65.0826644897461, 65.47631468091691, 60.54024491991316, 68.2934479032244, 63.38440663473946, 68.21498189653668, 51.94792883736746, 0.7075137836592538, 1.0214977754013879, 0.3939945884048939, 0.462236293724605, 10.800200854028974, 70.86477470397949, 64.29883820669991, 58.17618635722569, 52.62900168555123, 42.439822810036794, 16.900869471686228, 21.870495557785034, 41.56323460170201, 52.222584179469514, 72.59001241411481, 8.919286148888723, 0.527915280844484, 0.06961048687142984, 0.27134235416139874, 0.02140752029871302, 0.1678883047508342, 0.05100403207221201, 0.051022912309105904, 0.3047499715217522, 0.16500706864254816, 0.1957249189061778, 0.15011391708893435, 0.11543346302849905, 0.1593478016023125, 0.171049083716103, 0.2359066227717059, 0.11673726806683199, 54.72270584106445, 83.36939907073975, 64.33265508924211, 51.75613076346261, 34.73525374276297, 60.044143540518625, 69.51983274732316, 60.921256337847026, 86.12035070146833, 47.576292514801025, 0.2166567878531558, 0.13291765483362333, 1.4649678532566344, 2.639513381889888, 6.567567586898804, 53.267530713762554, 71.91215310777936, 70.66019889286586, 74.52537754603794, 70.67248330797467, 68.72233240944999, 63.0917763028826, 59.24420438494001, 70.07366670880998, 69.98215893336705, 64.10642174312046, 62.6184789112636, 56.08457013538906, 61.04201602935791, 69.10386494227818, 67.66285024370465, 69.51757458278111, 66.05501624516079, 63.97453798566546, 61.544593129839214, 59.60847759246826, 58.038327148982454, 64.63419301169259, 63.459099769592285, 64.49182442256382, 66.11021968296596, 56.469396114349365, 49.08234582628523, 49.762081146240234, 50.653239727020264, 47.17589214869908, 45.09403814588274, 46.42037977491106, 48.3345251083374, 48.044753960200715, 45.95375265393938, 46.172937052590505, 43.8112929889134, 43.84569352013724, 45.533563818250386, 41.242735045296804, 41.73062712805611, 43.009248529161724, 41.06224863869803, 45.900915077754426, 48.56537553242275, 54.02335923058646, 59.13426998683384, 63.42644323621477, 58.46199703216553, 58.084866183144705, 51.42921454565865, 47.842940058027, 48.17415721075875, 47.16279479435512, 45.9306811605181, 49.10236358642578, 49.2237868309021, 61.80033547537667, 55.40436928612845, 68.28912612370083, 39.00296238490513, 27.089688777923584, 51.68134035382952, 44.005832127162385, 46.384606974465505, 43.90455518450056, 57.91072348185948, 52.61146443230765, 49.26532663617815, 51.54194211959839, 58.14103889465332, 50.286979334695, 56.78920085089547, 53.624147006443565, 52.639622007097515, 54.68103402001517, 55.47342395782471, 54.27656200953892, 55.18847138541085, 56.275148800441194, 54.96430165427071, 54.232496534075054, 53.9210331099374, 46.610058648245676, 40.706810065678184, 39.683646133967805, 37.59625094277518, 41.934066908700125, 38.27086196626936, 41.06307894842965, 41.40371091025216, 38.91320555550711, 46.566479546683176, 48.14078501292637, 48.78132554462978, 49.65641989026751, 45.27325998033796, 46.43331732068743, 45.91311264038086, 47.18173558371407, 45.10865715571812, 48.0205533845084, 47.91194609233311, 47.16350698471069, 56.77627720151629, 59.943325178963796, 60.72516427721296, 67.9883872440883, 59.88276468004499, 64.13577788216728, 66.60799557822091, 63.65078667231968, 67.1909077508109, 69.06054292406354, 67.73312432425362, 66.23924773080009, 63.67627266475132, 62.70567185538155, 64.18235165732247, 67.52863883972168, 68.33777046203613, 67.92980698176792, 69.17139448438371, 65.59087657928467, 69.33192566462925, 64.33118207114083, 70.7714534487043, 51.277535370418, 0.527033619582653, 5.2968341282435825, 1.452237884913172, 0.6571271302444595, 14.582359824861799, 78.19908469063895, 70.86888108934674, 65.00161375318254, 60.58462306431362, 66.8634113584246, 32.986715248652864, 25.684372186660767, 50.113809381212505, 60.70824541364397, 83.35548182896206, 12.77212827546256, 1.1625933242695672, 0.34407916398985045, 0.4172842986881733, 0.19055894682449953, 0.5251261762210301, 0.1504114004118102, 0.13771541310208185], [0.043362082314810584, 0.16656229804669107, 0.17032478829579695, 0.019079227466136217, 0.041437017398753336, 0.12989813328853675, 0.09408598459724869, 0.014475221479577678, 0.30906298437288826, 42.4295186315264, 56.338356563023154, 46.58977338245937, 41.50230584825788, 35.00934280667986, 53.80287899289812, 51.60562235968453, 47.40482139587402, 80.20119421822685, 20.491740192685807, 0.027509387249925306, 0.1500752405928714, 0.4781872406601906, 0.5202889272144863, 13.26975565297263, 60.93233871459961, 63.11159256526402, 70.69969940185547, 61.64347294398716, 62.67561394827706, 62.449352809361045, 61.359910011291504, 60.763351576668875, 61.639915466308594, 61.40822083609444, 65.07421548025948, 58.40273584638323, 64.70671830858502, 68.07987417493547, 61.94751221793038, 59.67629895891462, 59.91389260973249, 62.972295079912456, 59.973285811288015, 53.81512171881539, 47.29345219475882, 49.08412109102522, 51.422297613961355, 57.24191420418875, 56.385187421526226, 51.02667760848999, 47.558293206351145, 42.46784836905343, 45.61534758976528, 46.2395772252764, 44.91203008379255, 39.39518472126552, 41.859411988939556, 45.173945903778076, 43.46630450657436, 41.99751785823277, 43.35579340798514, 39.74622508457729, 38.23840693065098, 39.07231930324009, 37.45067923409598, 36.56982830592564, 37.59582362856184, 36.37158577782767, 38.7174574307033, 39.338803563799175, 41.77777412959507, 45.09500394548689, 47.318236419132774, 43.971841539655415, 44.74189649309431, 41.41706534794399, 41.925027302333284, 42.25076232637678, 42.0518354007176, 42.12654938016619, 44.98801210948399, 48.19866350718907, 52.61698825018746, 53.40197835649763, 56.006781578063965, 37.84242909295218, 6.9292851601328165, 32.440399238041465, 57.847540037972585, 36.95186805725098, 39.24520090648106, 50.89662817546299, 50.201627663203645, 42.003208432878765, 42.768132141658235, 49.76631259918213, 51.46651247569493, 51.42477464675903, 50.71496752330235, 45.42094046728951, 48.06426797594343, 52.725331510816304, 51.75929914202009, 50.75011498587472, 50.304933479854036, 52.54110697337559, 48.51956953321184, 40.30203928266253, 38.3417648587908, 33.83892222813198, 35.083094460623606, 36.46930871691023, 35.14532252720424, 34.917317390441895, 37.35196965081351, 36.16821895326887, 39.001319135938374, 46.5715343611581, 42.81326069150652, 42.21973861966814, 44.24565614972796, 40.17413336890084, 40.33780860900879, 40.58470937183925, 42.984759603227886, 40.94340317589896, 41.82388237544468, 42.17553070613316, 42.08262286867414, 43.69635588782174, 51.77523830958775, 55.711656842912944, 58.24446283067976, 59.569067410060335, 58.720039231436594, 58.0733391216823, 59.52535629272461, 58.67293739318848, 59.708809580121724, 56.822076252528596, 57.51607275009155, 58.81021295275007, 64.14088480813163, 60.74387577601841, 61.52475602286202, 58.77402673448835, 66.70001752035958, 61.080015727451865, 63.40702996935163, 60.386036600385395, 64.40456894465855, 60.48040008544922, 67.55798803056989, 21.19335539000375, 0.2596932921026434, 0.235682163387537, 0.058703966039632044, 0.7863429422889436, 51.513614313943044, 60.42744091578892, 59.206510407584055, 42.08018405096871, 56.298407895224436, 33.59404339109148, 17.384436300822667, 29.45361532483782, 46.35791894367763, 63.66835171835763, 20.0033061504364, 0.6135731616190502, 0.12948559756789887, 0.18796440533229283, 0.06694238539785147, 0.18082297353872231, 0.05165859444865158, 0.04142765700817108, 0.04291397100314498, 0.14878795109689236, 0.09140961856714316, 0.03488084241481764, 0.07541832593934876, 0.05762343294918537, 0.036002257240137885, 0.09605176161442484, 0.3492332345673016, 49.75728688921247, 68.41885593959263, 51.85862364087786, 58.11159242902483, 37.89943906239101, 39.75293009621756, 63.19475555419922, 53.21172278267996, 89.52674674987793, 19.934843812670024, 0.1639252666916166, 0.09423911638025727, 0.39843079607401577, 0.7375652853931699, 18.65274657521929, 65.98385279519218, 65.03537505013603, 71.36549663543701, 63.15350409916469, 66.16793836866105, 63.72700841086251, 62.60420036315918, 60.749330111912315, 61.710995537894114, 61.624462672642295, 66.52991172245571, 60.90988213675362, 67.16786752428327, 69.02893556867326, 65.6206704548427, 63.23634052276611, 63.59993280683245, 64.66499437604631, 61.744909695216585, 55.418592248644146, 51.217589787074495, 51.85227993556431, 54.92239359446934, 59.0957213810512, 59.241084643772666, 54.30866616112845, 50.13876731055123, 46.29703882762364, 47.509277139391216, 46.34290736062186, 45.92209666115897, 42.727092606680735, 44.00221906389509, 47.04047870635986, 44.79328536987305, 43.86832727704729, 45.60665191922869, 43.101965291159495, 41.30043983459473, 41.266900879996165, 41.06542049135481, 38.44333362579346, 41.05213900974819, 38.64529691423689, 40.527317251477925, 41.101075172424316, 45.13413272585188, 46.50730868748256, 48.23625326156616, 45.4351669039045, 45.38442768369402, 42.61923919405256, 43.515751361846924, 43.73163536616734, 43.11378417696272, 43.753122670309885, 47.72509166172573, 50.41361720221383, 55.744723320007324, 56.126439980098176, 58.71568965911865, 40.017083236149375, 8.18539570059095, 28.885959659303936, 53.1001729284014, 36.96589994430542, 42.16608463014875, 54.75060633250645, 54.21955898829869, 43.99271045412336, 42.971742153167725, 52.54450811658587, 53.37118741444179, 55.13232299259731, 54.37540708269392, 48.57652044296265, 50.62355702263968, 53.02371842520577, 54.31869241169521, 53.16471127101353, 53.76112379346575, 55.215232372283936, 50.088024616241455, 44.26399939400809, 40.42899676731655, 35.45851952689034, 37.95593139103481, 37.76615176882063, 37.24038505554199, 37.22563402993338, 40.64539493833269, 38.16862964630127, 41.24432270867484, 48.0998740196228, 45.72151606423514, 44.82141515186855, 45.43503836223057, 42.96259832382202, 42.85496377944946, 42.26221295765468, 44.92488772528512, 42.71384934016636, 43.282945019858225, 42.85033975328718, 45.3693014553615, 45.65883983884539, 53.41630206789289, 56.40450688770839, 59.75491087777274, 60.989855902535574, 61.60905851636614, 60.14856801714216, 61.29326983860561, 59.70340388161795, 61.712419918605256, 61.1400968006679, 60.7834666115897, 61.90334251948765, 63.80948352813721, 62.49922003064837, 63.06335817064558, 59.860926491873606, 67.60741056714738, 63.81613990238735, 65.84044892447335, 63.127719334193635, 67.78691727774483, 62.90830911908831, 74.04249858856201, 33.983976296016145, 0.22172844356724195, 0.22487714460917882, 0.0420909826643765, 0.5413548882518495, 53.38820007869175, 68.55434581211635, 63.83839498247419, 52.45082208088466, 52.97593566349575, 26.35198811122349, 19.960526091711863, 35.10088184901646, 52.79183619362967, 73.64604132516044, 22.677019868578228, 0.5446824239833015, 0.18368487139897688, 0.1837170339588608, 0.04653796207691942, 0.04796256670462234, 0.040180991403758526, 0.04346456145867705, 0.17039030763719762, 0.38189001221741947, 0.21181221066841058, 0.10851039058927979, 0.16052060866994516, 0.21753492073288985, 0.086121503396758, 0.1332252211868763, 0.5733153532658304, 58.99421514783587, 74.70050689152309, 63.25382913861956, 57.72809355599539, 50.935218470437185, 82.47634710584367, 68.31323637281145, 60.69104167393276, 92.59236145019531, 24.54817843437195, 0.324924391827413, 0.38078801706433296, 1.5071088948420115, 2.477013038737433, 20.378350802830287, 69.07006890433175, 70.47917747497559, 75.85529749734062, 65.74366746629987, 66.8865419115339, 63.59235232216971, 63.08141653878348, 61.032260758536204, 64.14267744336809, 65.6600319998605, 69.38081318991524, 62.41384751456124, 69.38961655752999, 71.28124277932304, 68.13509845733643, 64.79111112867082, 65.65517520904541, 67.85783754076276, 64.95159367152623, 59.85365172794887, 53.71390036174229, 52.297138350350515, 57.655217375074116, 62.397130148751394, 62.16467121669224, 55.861439159938264, 53.30266775403704, 47.475043364933555, 52.1279080254691, 50.91669109889439, 49.1603740964617, 44.799073219299316, 45.957862513405935, 50.152844360896516, 45.75274474280221, 46.554601601191926, 48.328928334372385, 44.4011881010873, 43.63235255650112, 44.78197022846767, 42.95499004636492, 40.35140970775059, 42.661553723471506, 40.38160310472761, 42.08284173692976, 43.68958139419556, 46.24763018744332, 50.109970501491, 52.696673665727886, 48.207383496420725, 50.38652965000698, 44.914246559143066, 45.36306892122541, 46.76689338684082, 44.0779196875436, 46.55704736709595, 50.399415084293906, 51.9040926524571, 57.93631717136928, 57.8644380569458, 62.01232501438686, 43.88983195168631, 11.841615966388158, 36.682552405766074, 57.441504682813374, 38.628152234213694, 48.52660805838448, 57.77969087873186, 57.30340576171875, 47.374732221875874, 47.54675224849156, 54.78215115410941, 56.576328890664236, 56.49775866099766, 56.54660102299282, 50.54799536296299, 53.37206288746425, 57.007902349744526, 57.348120893750874, 56.04527807235718, 55.34750175476074, 58.123393944331575, 51.185346671513145, 46.28442784718105, 44.10814782551357, 37.410303252083914, 39.84783206667219, 40.76035288402012, 40.070653847285676, 39.632135663713726, 43.324300697871614, 40.47953796386719, 41.25841365541731, 51.57957703726632, 47.08281408037458, 45.7562118938991, 47.93209934234619, 45.92078692572457, 45.986238956451416, 44.67097275597708, 46.380448477608816, 43.80236802782331, 45.6097160748073, 44.757592473711284, 47.17434964861189, 47.77966628755842, 56.47972461155483, 61.40937423706055, 64.00622177124023, 61.619258471897666, 63.758587973458425, 61.871575355529785, 63.430132729666575, 62.103902271815706, 63.311700684683665, 63.37170532771519, 63.96950054168701, 65.22971616472516, 67.11148984091622, 65.24027047838483, 67.26328018733433, 61.04520525251116, 70.71674333299909, 67.54378591264997, 68.41746629987443, 65.18125247955322, 69.46064104352678, 66.58121027265275, 77.52917412349156, 34.87645503452846, 0.4651013399873461, 0.8472748984183583, 0.13063686793403967, 1.0799152978828974, 61.504995346069336, 72.81682246071952, 71.75180258069719, 58.79663617270333, 71.35817323412213, 50.459732396262034, 27.3262870992933, 44.319411277770996, 59.878220558166504, 81.17192009517125, 29.677996976034983, 0.6298664159008435, 0.4616458054099764, 0.3531156490956034, 0.11630467485104289, 0.26159210449882914, 0.22573870766375745, 0.10540375871849911], [0.06434077357075044, 0.053840410230415206, 0.024895848473533988, 0.018921946441488605, 0.04130535785640989, 0.019225090442757522, 0.009778435159075474, 0.08150401152670383, 0.8926909299833434, 50.522321769169395, 55.327661173684255, 43.70669480732509, 18.145620141710552, 17.282483645847865, 38.67822790145874, 46.896157673427034, 53.845832756587434, 71.52312346867153, 8.64030989578792, 0.14063771414969647, 0.21052728247429642, 0.508604282779353, 1.91333869099617, 37.74897929600307, 59.63729177202497, 50.70636912754604, 63.03053488050188, 56.16675342832293, 59.307842935834614, 57.73353746959141, 60.186164719717844, 60.78457832336426, 62.7710405077253, 63.680177552359446, 63.71161815098354, 62.1050626209804, 60.08569376809256, 59.86150319235665, 62.655123710632324, 64.96204376220703, 62.74885490962437, 60.83149256025042, 62.10017803737095, 52.38552638462612, 48.30673926217215, 45.450921944209504, 47.10914427893502, 47.768573488507954, 47.15605851582119, 44.46293674196516, 43.358173166002544, 44.88473408562796, 44.00545692443848, 41.21021747589111, 42.835439341408865, 41.71161338261196, 42.66782794679914, 43.48623194013323, 42.7952926499503, 42.94277163914272, 43.305839334215435, 40.541859831128804, 39.54775326592581, 37.307549817221506, 37.88866935457502, 36.96825190952846, 36.33672319139753, 37.72976057870047, 37.591918740953716, 37.684649399348665, 40.69113492965698, 42.61178725106375, 44.616266114371165, 41.48778758730207, 41.777398926871165, 40.60739524023873, 41.62994425637381, 40.85063430241176, 44.5861873626709, 44.20900092806135, 44.456905705588206, 47.1298360143389, 52.548923696790425, 51.151776450020925, 53.83932229450771, 38.84979976926531, 14.809133393423897, 6.1548085468156, 30.041690008980886, 42.61410447529384, 31.453925268990652, 51.687555517469136, 50.598342009953086, 46.1860100882394, 39.460331031254356, 50.99958658218384, 49.192662375313894, 53.149400915418354, 49.46821403503418, 46.454846314021516, 45.57024335861206, 49.25564432144165, 49.236140727996826, 48.531704562050955, 50.57261977876936, 47.19662209919521, 44.209209374019075, 39.444836548396516, 33.53636986868722, 33.80041183744158, 34.402059827532085, 35.476567472730366, 35.6093544960022, 36.14359106336321, 36.308273792266846, 38.35128041676113, 43.71801689692906, 43.52109105246407, 43.18878303255354, 42.29636335372925, 41.680721691676546, 39.67333500725882, 38.92627511705671, 37.571115834372385, 42.39020224979946, 42.97777318954468, 43.326162815093994, 43.441388266427175, 42.53280707768032, 42.951401301792686, 41.278768403189524, 46.9155535697937, 53.30358144215175, 56.24227339880807, 57.39978422437395, 59.21596690586635, 60.697760581970215, 57.85860851832798, 61.39137840270996, 59.91197490692139, 59.47189685276577, 56.47912359237671, 57.24597890036446, 54.69406884057181, 58.5218140738351, 59.69064004080636, 61.4642094203404, 63.13648796081543, 62.954674448285786, 61.10910088675362, 66.17681816646031, 64.82382324763707, 65.87467575073242, 60.3103985105242, 3.2196988207953314, 0.3558815206800188, 0.33317744040063446, 0.25434779322573114, 19.732025895799907, 68.59861973353794, 55.700115885053364, 49.92730236053467, 47.35467972074236, 33.89803055354527, 18.408300263541086, 25.851783820561, 41.767084326062886, 58.4371919631958, 29.85372039249965, 0.3059338522808892, 0.12198699851121221, 0.039077255808349164, 0.06755728061710085, 0.04140024758609278, 0.03844161098822951, 0.026150274822222333, 0.05179027434704559, 0.0523087667035205, 0.08126349800399371, 0.024137446490515555, 0.046200563931571584, 0.09707964717277459, 0.02941320723454867, 0.065190326555499, 1.137297973036766, 60.309835706438335, 62.14646693638393, 52.290124143872944, 24.63151686532157, 16.55285852296012, 44.29422753197806, 54.44040053231375, 60.579613413129536, 76.59968580518449, 9.638613172939845, 0.14956958272627421, 0.18861186344708714, 0.3060025471661772, 2.747386987720217, 42.60093763896397, 64.77089881896973, 58.57647555215018, 68.35014520372663, 60.032644271850586, 62.95671721867153, 59.651209013802664, 63.71615532466343, 63.93325873783657, 65.87732301439557, 67.7208468573434, 67.24399198804582, 65.5352840423584, 62.90426526750837, 63.235339982169016, 63.50263718196324, 66.02115767342704, 64.92715685708183, 64.21012360709054, 64.80967671530587, 56.368397099631174, 50.513653891427175, 48.490717138562886, 50.17405721119472, 49.55952378681728, 49.045822620391846, 47.44260222571236, 45.74490370069231, 47.35749026707241, 45.84345694950649, 44.64939512525286, 45.98909814017159, 43.40170015607561, 45.882408550807405, 44.48032808303833, 44.44729634693691, 45.13363592965262, 45.404309953962056, 40.86286660603115, 42.401270730154856, 39.40894215447562, 40.55571453911917, 39.38255984442574, 39.39051900591169, 40.80550922666277, 40.28674629756382, 40.50613219397408, 42.32758508409773, 43.746820654187886, 46.491581439971924, 43.412636620657786, 43.272043296269004, 44.202417509896414, 42.85509926932198, 43.51091888972691, 47.07574776240757, 45.74461882455008, 46.417826311928884, 50.750139304569785, 55.57084812436785, 52.78316484178816, 57.097742557525635, 42.76871231624058, 16.227608135768346, 7.4870035988943915, 29.260431085314067, 44.46016093662807, 34.13750369208199, 53.636146545410156, 54.95075614111764, 48.119023254939485, 42.01131003243582, 53.35199301583426, 51.73227064950125, 55.770963191986084, 54.3027845110212, 47.63727685383388, 46.84408787318638, 51.838296685900005, 51.13368681498936, 52.16168669291905, 50.72460814884731, 48.82228170122419, 46.03702333995274, 40.18820347104754, 36.45625305175781, 36.790892192295615, 35.9280093056815, 38.302674293518066, 38.00511074066162, 38.73556791033064, 38.725944655282156, 39.528572763715474, 46.38685124261038, 45.20472642353603, 45.45626163482666, 44.555031640189036, 43.220036029815674, 42.891083989824565, 41.01202358518328, 40.709547655923025, 44.59095730100359, 45.08418212618147, 44.26821347645351, 44.83240720203945, 45.825641768319265, 45.320528575352256, 44.51444721221924, 48.8864552634103, 51.894087246486116, 57.64333248138428, 58.83234991346087, 61.756221362522666, 62.095251764569966, 60.97840527125767, 62.22942842755999, 62.32360431126186, 60.24657235826765, 58.4802360534668, 59.92463452475411, 57.396827765873496, 61.23450197492327, 62.15413079942976, 62.6631349836077, 64.85112271990094, 65.11012377057756, 64.32579721723283, 66.10781560625348, 68.89910847800118, 66.01814910343715, 69.48667594364711, 9.533155151775905, 0.6845182318772588, 0.6717458143830299, 0.42649402735488756, 21.47926160267421, 74.52367523738316, 60.254680906023296, 57.679532596043174, 51.352940695626394, 30.421718256814138, 22.002928222928727, 35.00691441127232, 46.471987519945415, 68.2176708493914, 35.74650846208845, 0.2680401684982436, 0.11291040520050696, 0.05423979254971657, 0.04364854283630848, 0.02901674940117768, 0.03293318906798959, 0.08310432958283595, 0.12140377052128315, 0.13337686019284384, 0.12442711900387492, 0.15907656401395798, 0.15493310349328177, 0.20827013573476247, 0.13268521587763513, 0.20503494861934865, 1.9889518107686723, 68.97344030652727, 70.82794925144741, 61.9180588041033, 26.622144494737896, 24.66974585396903, 54.94856398446219, 62.463367325919016, 66.90425981794084, 83.25295421055385, 12.402524931090218, 0.337753209152392, 0.8274684069412095, 1.8257488310337067, 4.879083675997598, 42.58678068433489, 70.02615492684501, 61.293916021074565, 79.45297745295933, 66.54070922306606, 70.14033467429024, 65.25677939823696, 68.22060993739537, 67.71268272399902, 68.49602263314384, 70.53367914472307, 69.63890402657645, 68.38693591526577, 63.49794714791434, 65.93213040488106, 66.82814925057548, 69.16573865073067, 67.69642393929618, 66.10209029061454, 67.26231438773019, 58.745122228349956, 52.60716002328055, 49.941448892865864, 52.16831180027553, 51.0690928867885, 50.72216933114188, 49.58370699201311, 47.958266258239746, 49.581059728349956, 49.27650628771101, 44.33807066508702, 48.130651065281455, 46.206451688494, 47.00720378330776, 47.269668510981965, 47.701394830431255, 46.82291671207973, 48.157790728977744, 43.126506328582764, 43.917722020830425, 41.99945987973894, 42.558897563389365, 40.90828698022025, 42.925411564963206, 42.328061035701204, 43.301732948848176, 43.07231732777187, 44.94507571629116, 45.96916723251343, 48.87200648444039, 44.452667304447715, 45.83092587334769, 46.85390567779541, 45.94056149891445, 45.36873517717634, 49.06987380981445, 47.204661164964946, 48.25622238431658, 52.53526701245989, 58.79498250143868, 57.2052937235151, 59.591433661324636, 46.57341037477766, 19.882664578301565, 11.20820689201355, 36.5555671283177, 47.592447076525005, 38.852394921439036, 57.38674592971802, 56.114965030125205, 51.17457348959786, 44.797520296914236, 56.71985782895769, 55.16178682872227, 57.831013747623985, 56.51532023293631, 50.91966492789132, 50.13001952852522, 53.91354990005493, 53.800103187561035, 54.053104468754356, 53.76280525752476, 50.553244726998464, 48.728102343423025, 43.479839597429546, 39.898317677634104, 39.68041869572231, 38.789322648729595, 41.44373600823538, 41.076204095567974, 41.16971295220511, 42.41819306782314, 41.70230974469866, 46.848121302468435, 46.04115056991577, 46.953674861363, 46.510765416281565, 45.68885258265904, 45.19334180014474, 42.310054779052734, 42.29141971043178, 45.96315009253365, 47.491354261125835, 47.37337384905134, 47.05806112289429, 47.492702211652485, 46.51246772493635, 46.73508105959211, 51.24584811074393, 57.117207935878206, 61.66667992728097, 62.59199237823486, 65.1828088760376, 65.6649443762643, 63.206379890441895, 66.05457850864956, 65.29969842093331, 63.76473018101284, 61.78520924704415, 63.11765834263393, 61.33101940155029, 64.37089797428676, 65.74524470738002, 66.63653877803257, 68.31756510053361, 68.70992987496513, 66.29543086460659, 70.24978964669364, 74.21753065926688, 68.16666412353516, 73.89254951477051, 11.867532747132437, 0.5094101109674999, 0.8199629953929356, 0.413173000727381, 26.98858901432582, 81.99124472481864, 66.50953960418701, 64.30682168688092, 60.808945655822754, 48.422517095293315, 29.814518656049454, 41.50009979520525, 53.54101528440203, 75.5190463747297, 43.69186040333339, 0.3243651161236422, 0.2161833875413452, 0.10200731097055332, 0.18232457153499126, 0.15446852413671358, 0.06886063103697129, 0.19728374454591954], [0.043601544108241796, 0.028958442887025218, 0.08383678099406616, 0.024683645128139427, 0.07853977701493672, 0.12833580640809877, 0.08503949109997068, 0.07171388436108828, 1.4337583908012934, 44.172053882053916, 48.6627128464835, 44.028160163334434, 43.07478741237095, 40.484901973179404, 41.38164690562657, 46.652991567339214, 62.8915570122855, 63.39309188297817, 2.868229840482984, 0.20180753751524858, 0.22975125163793564, 0.7135718528713498, 12.75876602104732, 59.18409551892962, 65.8825272151402, 60.28468322753906, 54.891501903533936, 50.99759592328753, 53.19392844608852, 55.93098715373448, 56.94892604010445, 63.83071722303118, 63.65635912758963, 65.07541751861572, 63.52965177808489, 63.039095061165945, 62.5896577835083, 63.47950662885393, 60.20514719826834, 60.53369276864188, 61.320617948259624, 60.876065254211426, 60.17447784968785, 55.09268699373518, 47.27635962622506, 42.80536753790719, 45.883395195007324, 44.78562150682722, 45.88276290893555, 45.73406451089041, 44.138122354234966, 43.28678042548043, 43.6275999886649, 42.42762872150966, 41.24152258464268, 39.132337842668804, 41.776540824345176, 43.112616879599436, 42.36394500732422, 44.51507255009243, 48.50210176195417, 44.55456611088344, 40.55229949951172, 38.074050767081125, 36.557519572121755, 37.35540553501674, 36.862382207598, 37.81077310017177, 37.01348468235561, 37.45723485946655, 39.11818436213902, 38.89748525619507, 41.480175835745676, 41.02966506140572, 41.30670016152518, 41.050308159419465, 40.64214318139212, 42.78318541390555, 42.76802444458008, 42.16523347582136, 43.67347894396101, 44.24297414507185, 50.5389210156032, 52.6361757005964, 52.826865536826, 44.89417668751308, 18.959167344229563, 9.705442684037344, 8.824564831597463, 29.766020229884557, 30.33308356148856, 45.418682302747456, 52.15170213154384, 48.650143555232454, 42.3159225327628, 43.57423782348633, 48.75741679327828, 47.60658666065761, 44.34574147633144, 42.45238862718855, 40.10034697396414, 42.37220294134957, 44.39856168201992, 43.438369274139404, 41.904860155923025, 39.08679240090506, 39.01941919326782, 34.63853481837681, 33.99949509756905, 35.133104119982036, 33.76002890723092, 36.00251483917236, 35.27482305254255, 36.62041119166783, 37.95361416680472, 41.41204874856131, 42.26071214675903, 43.378256934029714, 45.84829984392439, 41.19796085357666, 41.019729137420654, 40.70670236860003, 39.10858195168631, 38.340250151497976, 42.3701879637582, 41.808603286743164, 42.500887053353445, 44.11499874932425, 42.34100900377546, 45.68916177749634, 43.096253871917725, 42.96643372944423, 40.706632886614116, 47.78000674928938, 48.45220674787249, 49.23220804759434, 50.12945325034005, 50.829435620989116, 51.431722845349995, 49.367871625082834, 50.30505507332938, 53.170728410993306, 51.94073050362723, 52.67678792136056, 51.06770324707031, 51.6532244682312, 53.88484689167568, 54.014746938432964, 57.0201416015625, 60.32303033556257, 61.19195120675223, 66.30688149588448, 63.18782820020403, 67.14242322104317, 18.201210941587174, 1.3721556620938438, 0.05175089895991342, 0.11519053392112255, 3.778222816331046, 56.22490637642996, 59.17089394160679, 54.333412170410156, 48.50736154828753, 44.85369300842285, 14.914907557623726, 24.39043869291033, 42.67537369046892, 60.53813961574009, 37.481984342847554, 0.2759462956871305, 0.04323510127142072, 0.02725725551135838, 0.06711820739188365, 0.043525029106863906, 0.02236634286652718, 0.03997870993667415, 0.11068335148905005, 0.04742661224944251, 0.03638852687020387, 0.021498706923531632, 0.08762926927634648, 0.08600921263652188, 0.03912445131157126, 0.04044501616486481, 1.9325943206037794, 53.44095427649361, 57.45899677276611, 50.6199300629752, 43.902911935533794, 34.144615173339844, 44.721576486315044, 57.00516823359898, 68.244567326137, 71.12658282688686, 2.625240696328027, 0.17305863302733215, 0.1899404078722, 0.451974700071982, 14.975791147777013, 62.62690707615444, 68.23489543369838, 66.45449597494942, 62.17540618351528, 59.14856937953404, 59.20885195050921, 62.31402274540493, 61.92579909733364, 67.0362686429705, 66.94992337908063, 66.72694873809814, 64.4575628553118, 65.60443251473563, 64.5364249093192, 65.64946378980363, 62.670069285801475, 64.88764939989362, 63.54572296142578, 64.2131460734776, 62.790370396205354, 56.41094091960362, 48.28887891769409, 47.047280992780415, 47.778863770621165, 48.12449148723057, 47.40741307394845, 47.61141218457903, 46.935578278132844, 45.04133605957031, 45.919101987566265, 46.24412482125418, 43.13023056302752, 41.60993691853115, 43.604024750845774, 44.64745657784598, 42.989689350128174, 45.58073513848441, 49.25991398947579, 44.39953442982265, 41.79123626436506, 39.88672808238438, 39.47732285090855, 38.26919092450823, 39.61803429467337, 39.54874685832432, 39.1814546585083, 39.699939659663606, 40.71631520135062, 42.697944913591655, 43.038371903555735, 42.67310857772827, 42.5611765725272, 43.99905415943691, 43.68112543651036, 45.22919797897339, 44.70866673333304, 44.72958428519112, 45.8127007484436, 46.81832047871181, 51.84478630338396, 55.07864815848214, 54.88753795623779, 47.14170701163155, 20.24680577005659, 12.1204662833895, 9.44483312538692, 33.324519293648855, 34.262456621442524, 45.844033649989534, 55.3162522315979, 49.596495151519775, 44.624687331063406, 46.54407855442592, 50.177256856645855, 49.44470827920096, 46.830483300345286, 44.41257619857788, 42.94952528817313, 43.9452612059457, 46.86040224347796, 45.948430333818706, 42.87007958548409, 40.543669836861746, 39.979740142822266, 37.95307220731463, 36.84981986454555, 36.77117667879377, 36.83766746520996, 38.25693082809448, 38.196794169289724, 38.70276199068342, 39.98979071208409, 42.835884026118684, 43.24210350854056, 45.30349159240723, 47.638489314488, 42.84675448281424, 43.15851320539202, 41.45481143678938, 41.24016768591744, 40.872072969164165, 42.93051849092756, 44.167200565338135, 44.362781933375764, 44.889573505946565, 44.1775290625436, 46.867458139147075, 45.034495558057515, 44.092486585889546, 43.18575709206717, 48.46498795918056, 48.84319230488369, 50.59280776977539, 51.8519047328404, 53.027623312813894, 52.34040130887713, 50.58641195297241, 50.89662817546299, 55.50595194952828, 53.60105814252581, 53.89975772585188, 51.026225975581575, 53.93281378064837, 56.43756294250488, 56.61284167425973, 58.49724524361746, 62.29012789045061, 63.544284684317454, 70.45624841962541, 66.05287619999477, 71.51297909872872, 27.188829149518693, 1.8543797518525804, 0.13708554261497088, 0.07612785643764905, 4.099901395184653, 61.442447662353516, 65.09008516584123, 60.40225369589669, 57.07805136271885, 43.8494907106672, 20.027411188398087, 34.853869915008545, 45.42303882326399, 68.81167234693254, 43.647749764578684, 0.22244980771626743, 0.02022284226092909, 0.11744192668369838, 0.024115955590137413, 0.025656659255868623, 0.03791705592136298, 0.04270625786323633, 0.14194400262619766, 0.07925404368766717, 0.15294385594981058, 0.10901729017496109, 0.18994071999830858, 0.2680270049188818, 0.22369899068559917, 0.15675517357885838, 2.5800715429442267, 63.89846910749163, 64.9046516418457, 60.94552639552525, 60.56678009033203, 60.5284538269043, 56.14523138318743, 64.53050504411969, 73.0518661226545, 77.96894645690918, 3.486824704068048, 0.22780697739550046, 0.7964398147804397, 2.5615641474723816, 15.926563535417829, 63.63691111973354, 71.2771919795445, 68.05835560389927, 66.12796538216728, 63.383697918483186, 64.25141675131661, 65.68189798082624, 64.90953622545514, 72.13579477582658, 69.45395687648228, 67.89076505388532, 66.65409687587193, 69.51959650857108, 68.56739452907017, 69.472307068961, 64.9214871270316, 66.77512754712785, 66.5220672062465, 65.96532889774868, 66.97743824550084, 61.2005808694022, 51.43564510345459, 48.9991272517613, 51.10013396399361, 51.364922864096506, 49.917019026620046, 50.41518749509539, 48.885746547154014, 47.309276717049734, 48.6079923084804, 46.9978688785008, 44.99489777428763, 44.90228870936802, 46.74285956791469, 48.1020314352853, 45.13377141952515, 46.850316933223176, 51.671842166355674, 47.04043354306902, 44.20013155255999, 41.745729037693565, 41.84527587890625, 40.8857296534947, 42.12051486968994, 42.27792978286743, 40.94650207247053, 41.30191632679531, 44.18591206414359, 44.49117422103882, 45.28918177740914, 45.45769991193499, 44.70714507784162, 46.7860460962568, 45.542224747794016, 46.88748632158552, 47.2940080506461, 45.48385293143136, 47.571473939078196, 48.851943561008994, 54.12531362261091, 57.4846008845738, 57.83949054990496, 52.612722056252615, 26.811241456440516, 14.48373622553689, 13.408011777060372, 39.87934562138149, 37.5942394392831, 49.30415316990444, 58.309081077575684, 54.08517040525164, 47.79861402511597, 49.168920380728586, 54.09000982557024, 51.2369509424482, 47.747951235089985, 46.0894718170166, 45.64272696631295, 46.675878933497835, 49.251951353890554, 48.83973557608468, 45.49545989717756, 42.6122909954616, 42.496016366141184, 39.85695505142212, 39.04347733088902, 38.95106976372855, 39.65308100836617, 41.42701864242554, 40.81963838849749, 41.85800150462559, 41.8052716255188, 44.35604912894112, 45.33443192073277, 45.62526614325387, 48.636261054447715, 45.094204902648926, 46.045395919254844, 44.492421422685894, 44.0070550101144, 41.81090314047677, 45.13694674628121, 46.13257496697562, 47.139480113983154, 47.07762030192784, 46.6961989402771, 49.95152725492205, 47.244550773075645, 47.16034208025251, 45.11147812434605, 50.44738892146519, 53.2382093157087, 52.85012463160923, 56.15576485225132, 55.26576314653669, 57.43652629852295, 53.0768096106393, 55.07064730780465, 58.53046458108084, 56.31565679822649, 57.36658225740705, 55.61058834620884, 56.85144976207188, 60.045102391924175, 59.82920101710728, 59.91382312774658, 65.59150886535645, 68.13600172315324, 72.15137958526611, 71.3040189743042, 75.40747220175606, 31.438757351466588, 2.886019617319107, 0.5611026457377842, 0.17800980806350708, 5.617093971797398, 68.95221355983189, 67.81035355159214, 69.35297175816127, 63.47863810403006, 62.496482440403526, 24.41524028778076, 37.28450264249529, 56.564829621996196, 75.30882862636021, 55.184173924582346, 0.3344641056443964, 0.1611486335418054, 0.21270392781921796, 0.1395920781152589, 0.12629760934838227, 0.1393272458974804, 0.08062293380498886], [0.009547249796534223, 0.008888294754017676, 0.05830546242317983, 0.10617551766335964, 0.06515055083270584, 0.07676521116601569, 0.03258512095947351, 0.11381633765995502, 2.6219368278980255, 50.88552842821394, 42.022701604025706, 42.85391460146223, 19.509720018931798, 18.190694843019756, 37.244203090667725, 48.83225236620222, 66.9853105545044, 45.8502105985369, 0.5941242309553283, 0.10164417259927307, 0.2799649329057762, 0.941586434841156, 29.307876859392437, 66.95638520377022, 65.95252336774553, 69.80874579293388, 68.45757130214146, 60.07488237108503, 56.41028084073748, 59.8040554864066, 61.908268792288645, 65.96767044067383, 67.70653356824602, 64.57088102613176, 62.09316035679409, 63.1674838747297, 59.11680221557617, 57.030650751931326, 58.01836150033133, 58.527414321899414, 57.021517344883506, 57.91329778943743, 55.52002552577427, 50.214481830596924, 44.30486522402082, 45.34763697215489, 43.91747188568115, 45.691576276506694, 44.88876404081072, 44.08737618582589, 43.0775215285165, 43.60447985785348, 42.83759675707136, 44.05317367826189, 42.279673780713765, 41.200990268162315, 42.309207098824636, 44.79326799937657, 41.98639726638794, 41.29410307747977, 48.195575032915386, 49.24390533992222, 45.38255514417376, 39.3790579523359, 37.722374643598286, 37.928468636104036, 36.96930456161499, 37.06617982046944, 38.32524899074009, 36.33996105194092, 36.64384746551514, 38.25066007886614, 39.55038315909249, 41.86534922463553, 41.83186585562569, 42.336416244506836, 40.73222657612392, 41.07823644365583, 40.15314286095755, 42.81794377735683, 41.843274797712056, 43.66112157276699, 47.97800956453596, 52.97728361402239, 50.122042996542795, 44.544595445905415, 24.194284098488943, 17.994564567293438, 20.839481898716517, 26.71084519795009, 41.37223557063511, 42.66528838021414, 52.229323932102744, 47.93389892578125, 45.979711123875205, 40.45686946596418, 41.42482648577009, 41.52187544958932, 40.789347716740195, 40.83006763458252, 40.6030387197222, 40.14796992710659, 38.34150430134365, 37.4972425869533, 38.021508489336284, 37.271745749882285, 36.5665557043893, 34.13049643380301, 34.45435197012765, 34.20376866204398, 33.82401834215437, 34.41640090942383, 35.15101310185024, 35.46573175702776, 39.76121582303728, 40.929947989327566, 39.96368285587856, 44.775970458984375, 45.82963350840977, 41.942213671548025, 40.271759033203125, 41.02595819745745, 39.18383094242641, 38.7622628893171, 42.58276809964861, 42.576803071158274, 42.63764844621931, 41.64872523716518, 42.394965239933555, 42.630953856876914, 43.04315921238491, 45.15671437127249, 44.07204845973423, 41.80240549360003, 42.2543545450483, 45.18382624217442, 43.01844446999686, 45.24705832345145, 44.92542273657662, 46.60526786531721, 46.11691720145089, 46.49612903594971, 45.13484491620745, 47.38385173252651, 47.593492780412944, 47.43445198876517, 47.782549789973665, 51.70257404872349, 50.16496549333845, 55.4733510017395, 60.58572782788958, 64.78584439413888, 61.97303295135498, 69.46419852120536, 35.214113167354036, 1.4409609586000443, 1.411144609962191, 0.025221572423885976, 1.6208792413984026, 48.787690094539094, 60.277352878025596, 54.47645126070295, 50.961381912231445, 39.11569690704346, 20.817572491509573, 21.690757819584437, 35.70838022232056, 53.105040141514365, 43.391962255750386, 0.2850605137646198, 0.07462130513574396, 0.013229046964884868, 0.052556055398391824, 0.07290670821177107, 0.027580414599339877, 0.022054269344412854, 0.037888448884976764, 0.10824086969452244, 0.04181445250287652, 0.025380252927009548, 0.011946664125259434, 0.036089021512972455, 0.048521150302674086, 0.19129575443054947, 3.437720916100911, 62.311646461486816, 51.03015170778547, 48.56976331983294, 26.466527427945817, 22.916929006576538, 42.74633911677769, 56.25914362498692, 73.93985285077775, 52.09377499989101, 0.48920485803059166, 0.2812790109642914, 0.5370313716786248, 0.9855479044573647, 33.10168709073748, 70.38437625340053, 68.12132017953056, 72.27168764386857, 69.50908388410295, 63.92006410871233, 60.612249101911274, 60.82657323564802, 65.22989681788853, 68.34991591317313, 69.3885326385498, 67.77689797537667, 65.49727044786725, 64.84920501708984, 60.76323345729283, 60.59876959664481, 59.779118401663645, 60.89374841962542, 59.795863560267854, 59.38678142002651, 57.94895594460623, 53.18142516272408, 47.44870274407523, 47.867640904017854, 46.5030529158456, 48.14437028339931, 46.913628918784006, 47.9519989831107, 45.13675914491926, 45.57710817881993, 46.1029235294887, 46.66742297581264, 45.42937905447823, 43.25885908944266, 44.73293679101126, 46.85025439943586, 44.00555419921875, 42.65028027125767, 49.14079754693167, 50.20783587864467, 46.999953338078086, 42.17721217019217, 39.33460685185024, 40.27847099304199, 39.63952159881592, 39.611398765019004, 39.825865336826865, 38.14042690822056, 39.44802924564907, 41.60615362439837, 42.47782250813076, 44.828613485608784, 42.87688534600394, 45.15607513700213, 42.194356850215364, 42.21030644008091, 41.92217854091099, 43.64042983736311, 44.14825977597918, 45.70924554552351, 48.390694345746724, 53.28175367627825, 53.76456662586757, 46.51486137935093, 27.56329189028059, 20.957099267414637, 21.614770582744054, 28.324925627027238, 44.003191811697825, 43.45772000721523, 52.37308216094971, 50.388343129839214, 47.89311647415161, 44.76738248552595, 42.83690888541085, 42.178622654506135, 42.9351737839835, 42.387204102107454, 41.8722904750279, 40.26305294036865, 40.86588907241821, 39.69495432717459, 40.21668413707188, 40.043462072099956, 39.83438382829939, 37.312660217285156, 36.524529525211875, 36.779212270464214, 36.499328408922466, 37.70320456368582, 38.36691038949149, 37.7154403414045, 42.44428355353219, 41.73583132880074, 40.55936929157802, 45.06233351571219, 46.991156918661936, 43.864429337637766, 43.63778257369995, 42.24487720217024, 41.122194222041536, 41.21357345581055, 44.22430433545794, 44.12580667223249, 43.92274556841169, 42.993771416800364, 43.83231823784964, 43.49181134360177, 45.19074664797102, 45.72273547308785, 46.03898620605469, 43.9867593220302, 43.9065180506025, 46.25798300334385, 45.43155036653791, 47.02376481464931, 47.91669518607003, 48.366855076381135, 49.171449525015696, 47.27261454718453, 47.894836153302876, 48.550072125026155, 50.707453046526226, 51.007017680576865, 50.463196073259624, 54.457322869982036, 52.76797955376761, 57.463190010615754, 63.893577575683594, 67.76637840270996, 66.1947306224278, 70.06791360037667, 44.33657332829067, 2.505959016936166, 0.6569919117859432, 0.0925178358863507, 1.4081549303872245, 53.59671204430716, 66.26315648215157, 60.77504539489746, 57.7267803464617, 45.026571137564524, 25.672779117311748, 26.60158130100795, 41.47365495136806, 60.66862678527832, 51.603593485695974, 0.26983766204544474, 0.06578591066811766, 0.032908792341394086, 0.01858995113122676, 0.024787035205268433, 0.08399761414953641, 0.009773241821676493, 0.09934892611844198, 0.2146985765014376, 0.09259616596890347, 0.22322696101452622, 0.14847473933228425, 0.1644657469753708, 0.1125115758872458, 0.3697421997785568, 3.813278215272086, 72.97479670388358, 59.33150850023542, 62.28373554774693, 29.66008104596819, 28.503669772829326, 56.156470094408306, 62.84287098475865, 81.95500292096818, 57.02629770551409, 1.1674793192318507, 0.2554053036229951, 0.7783689615981919, 2.17386508839471, 35.530367374420166, 75.74624552045549, 71.53301075526646, 77.85258497510637, 76.15122822352818, 65.97058173588344, 63.84576007298061, 63.857314927237375, 67.31539167676652, 70.94317817687988, 71.68175084250313, 70.0492159979684, 67.7882513318743, 68.39300864083427, 62.59701592581612, 65.40698555537632, 63.54286725180489, 63.20360061100551, 60.90066187722342, 62.742393084934776, 61.791810035705566, 54.655752999441965, 49.88587720053536, 50.407725129808696, 49.377269063677105, 50.455153533390586, 49.747847761426655, 49.45404665810721, 46.991104807172505, 48.64172581263951, 49.22843517575945, 48.65711259841919, 49.86460529054914, 46.61441169466291, 47.37749065671648, 49.308547905513215, 45.805474621909006, 44.21359716142927, 51.974745409829275, 51.567261355263845, 47.4631793158395, 44.652994292122976, 43.04729686464582, 44.01602166039603, 44.509058884211946, 41.76052870069231, 42.956470012664795, 41.2285919870649, 41.5322664805821, 44.42725774220058, 44.65500232151577, 48.010676520211355, 45.64022214072091, 45.39746945244925, 43.84421355383736, 47.06556517737252, 44.537820952279226, 46.93694012505667, 47.405696868896484, 48.57569360733032, 52.618853841509136, 57.420083386557444, 54.201351233891074, 48.68107693535941, 31.24233177730015, 26.111912216459, 25.188894408089773, 31.694999967302593, 47.77088029044015, 46.73513664518084, 55.66301597867693, 51.88842446463448, 51.446008341653005, 45.3544670513698, 45.106603963034495, 45.70935671670096, 44.21278074809483, 45.476022311619346, 46.05696814400809, 43.0878951890128, 43.59896298817226, 42.63386862618582, 41.273939405168804, 41.86154856000628, 42.75397866112845, 39.40141378130232, 39.71866505486624, 39.53777912684849, 39.06137589045933, 39.55057076045445, 40.785609585898264, 40.104328291756765, 43.896696771894185, 42.629790033612935, 42.722419943128315, 46.72280011858259, 48.83998571123396, 45.98443242481777, 45.560078144073486, 45.47403860092163, 45.036055428641184, 43.010568686894004, 47.75623001371111, 46.224301610674175, 46.43181650979178, 45.67684609549386, 46.307224886757986, 47.488328320639475, 47.5377265385219, 48.52779967444283, 48.3054712159293, 46.27273055485317, 44.870563234601704, 48.29709168842861, 46.73228440965925, 50.11924982070923, 50.1081292288644, 50.61065421785627, 50.375290938786094, 50.161307266780305, 50.43914140973772, 52.37576763970511, 53.852746214185444, 53.23195593697684, 54.11781999043056, 55.54708875928606, 56.21986198425293, 60.504037857055664, 68.61481598445347, 71.83547278812954, 68.54842594691685, 73.83642891475132, 48.8381062235151, 4.97007771900722, 2.194587222167424, 0.13520981398011955, 2.107950133936746, 61.359284673418315, 71.19707230159214, 66.48085049220494, 64.33985342298234, 54.54755565098354, 30.161383152008057, 32.189412934439524, 50.044376032693044, 67.37619536263603, 62.301210267203196, 0.6443290912679264, 0.20832710553492817, 0.16076973958739213, 0.12800345995596477, 0.17583119496703148, 0.18744266618575367, 0.11954636233193533], [0.018581343914515207, 0.05347184697166085, 0.05860495420971087, 0.05156824751091855, 0.054020561277866364, 0.02856385102495551, 0.06269665607916457, 0.053939391526260545, 2.966176858970097, 44.623374121529714, 44.09577655792236, 33.24021680014474, 27.925527538572037, 36.577172551836284, 41.71877350125994, 50.88790123803275, 70.42645454406738, 36.049849442073274, 0.1927598158695868, 0.2319835504250867, 0.5204117691942624, 4.71721453326089, 54.88451548985073, 70.87685762132917, 68.28441524505615, 68.1639404296875, 61.20169258117676, 64.99544375283378, 62.774424280439106, 63.21646867479597, 65.40921592712402, 64.75874641963414, 60.008040700639995, 66.26726286751884, 59.91453879220145, 58.43033409118652, 57.94386638913836, 57.70522008623396, 52.89769894736153, 52.62571171351841, 51.77550234113421, 49.8230550629752, 45.53217417853219, 45.156596251896445, 44.71152939115252, 42.076063769204275, 44.03810650961739, 44.890268325805664, 42.83654063088553, 42.81407363074166, 42.984415667397634, 43.10102033615112, 43.87829794202532, 43.55268798555647, 41.546819482530864, 42.874859946114675, 42.55332163402012, 41.50309794289725, 42.92592920575823, 42.62462404796055, 45.50210932322911, 45.61592081614903, 46.15877662386213, 45.731003829411094, 38.440519605364116, 37.63920818056379, 37.507296630314414, 36.029244559151785, 37.891914163317, 35.769524369921, 38.01353195735386, 38.11761597224644, 35.55971309116909, 36.53130054473877, 38.33230488640921, 43.4597384589059, 41.85760545730591, 38.492363589150564, 38.774564674922395, 41.500110217503135, 41.58553831917899, 40.994243144989014, 45.09597321919033, 46.876195498875205, 53.244104862213135, 51.33200577327183, 37.74352496010916, 36.94680629457746, 30.28669043949672, 36.29114648274013, 40.099749428885325, 31.463444301060267, 46.44581018175398, 49.728278160095215, 42.326365675245015, 41.149764674050466, 40.67615113939558, 40.50406510489327, 40.3469454901559, 39.49944244112287, 40.83391693660191, 41.01220771244594, 41.3717075075422, 38.938094002859934, 37.825051648276194, 34.09721108845302, 34.782807213919504, 35.17515114375523, 33.74807105745588, 34.228997571127756, 36.25945922306606, 34.079812799181255, 35.976782185690745, 38.5440616607666, 40.647753851754324, 39.38028083528791, 38.55969163349697, 42.56876400538853, 45.39646543775286, 40.82767745426723, 41.173663003104075, 40.800635065351216, 40.50711188997541, 40.904864992414204, 39.82420819146292, 41.850903919764924, 40.774016516549246, 41.96746342522757, 42.592262813023154, 43.84562403815133, 44.037276199885774, 42.2650408744812, 41.59227459771292, 44.27147218159267, 44.00389010565621, 43.426244667598176, 44.84815182004656, 44.95369495664324, 45.01026371547154, 44.76305028370449, 44.73657417297363, 45.43876954487392, 44.75970820018223, 46.594560691288535, 48.11141150338309, 49.17708798817226, 51.227091448647634, 51.61351898738316, 51.641822474343435, 56.66773591722761, 58.45199162619454, 64.55520589011056, 64.34138897487095, 65.2619627543858, 49.3338497706822, 4.658920015607562, 0.865279635148389, 0.0233696417084762, 0.08317791670560837, 28.203205347061157, 67.03038351876395, 55.19384234292166, 55.31306300844465, 42.26647915158953, 21.45986918040684, 18.34018533570426, 31.19359016418457, 52.79292706080845, 48.67629657472883, 1.5384276828595569, 0.19438008964061737, 0.03990882422242846, 0.10288520636303083, 0.024042197137272785, 0.020792876137420535, 0.04811509459146431, 0.019789886028905, 0.013350078952498734, 0.05778214907539742, 0.05680318928456732, 0.028276089412559356, 0.06484567826347691, 0.04085950945903148, 0.11406834556588105, 3.2563779268945967, 54.06471143450056, 51.217075620378765, 43.87129763194493, 32.77952691486904, 31.02692719868251, 50.30141074316842, 59.671782629830496, 76.36482974461147, 37.79017169134957, 0.19580038557095186, 0.17673663209591592, 0.8987853143896375, 6.297944911888667, 59.80085236685616, 72.84861046927315, 70.76014872959682, 71.10593278067452, 67.36029093606132, 68.23274149213518, 65.06017317090715, 66.61182403564453, 66.04788044520787, 67.55584103720528, 63.71351500919887, 66.85751233782086, 62.80157784053257, 60.5874787739345, 60.826594080243794, 59.70418207986014, 55.29103027071272, 54.40111889157976, 53.344151973724365, 52.93525743484497, 49.15918595450265, 48.98465067999703, 47.078766754695344, 45.80732979093279, 47.20135382243565, 46.26615061078753, 45.631071363176616, 44.949772698538645, 45.355603081839426, 45.07582344327654, 46.508079937526155, 44.95552928107125, 42.759978430611746, 44.27240324020386, 44.52198600769043, 46.39496326446533, 44.19460078648159, 43.427891390664236, 45.712038721357075, 44.831556047712056, 47.51338699885777, 46.35862765993391, 38.96200622831072, 38.81042432785034, 38.435707977839876, 39.16298982075283, 40.587710993630544, 38.8711724281311, 39.47487013680594, 40.896145003182546, 38.146364143916536, 39.201625279017854, 39.95199251174927, 44.800417695726665, 45.42925746100289, 41.897210189274375, 40.72552503858294, 43.579191889081685, 43.19929913112095, 44.098858083997456, 47.628299781254356, 49.58556563513619, 53.76225634983608, 52.31255987712315, 40.51961169924055, 41.059663908822195, 33.1733021736145, 38.590576376233784, 42.69260522297451, 32.850388118198936, 48.087683405194966, 51.488729340689524, 43.235791070120676, 42.801111766270225, 42.33765302385603, 41.85404797962734, 42.14373574938093, 41.89874574116298, 43.795861039842876, 42.78596816744123, 42.93306153161185, 42.394322531563894, 39.46046304702759, 35.97517020361764, 37.62935216086251, 37.85681186403547, 36.38691002982003, 36.731023039136616, 38.38366249629429, 36.76125465120588, 37.982073988233296, 41.378568853650776, 41.180975982121055, 39.55172416142055, 39.56296287264143, 42.386658668518066, 47.19390882764544, 41.92075763429914, 42.78374474389212, 41.892402035849436, 41.66522026062012, 42.06727082388741, 42.46025398799351, 45.12928288323538, 42.41487877709525, 43.33116551807949, 43.95753867285592, 44.74133368900844, 45.757538999829976, 45.392904485974995, 43.6435843195234, 46.6598459652492, 45.630866391318186, 45.301115308489116, 46.38108076368059, 46.36912291390555, 47.301192487989155, 46.09580510003226, 46.39397662026541, 47.5998295375279, 49.105726514543804, 48.93568672452654, 49.05228444508144, 50.370020730154856, 53.68504449299404, 53.98091615949358, 56.82318449020386, 59.275728361947195, 61.05391829354422, 68.94794736589704, 67.75965254647392, 67.83271980285645, 56.25732667105538, 7.5732446398053845, 0.6694129024233136, 0.4415166298193591, 0.11575094956372466, 31.31773362840925, 71.56523650033134, 58.96563025883266, 62.207895960126606, 45.410611970084055, 21.909768513270787, 25.747013671057566, 39.25722129004342, 59.43859413691929, 60.56785706111363, 1.9661204644611903, 0.16415448939161642, 0.07421602295445544, 0.07291526453835623, 0.05961247014680079, 0.06224356432046209, 0.04258531917418752, 0.10650834587535687, 0.12052183784544468, 0.318388145416975, 0.215098287910223, 0.18326572674725736, 0.19222390891185828, 0.18302910801555428, 0.20892452847744736, 5.097104685647147, 66.11169964926583, 62.279941831316265, 50.649407795497346, 40.50685828072684, 57.84077249254499, 57.55599709919521, 67.44234221322196, 82.60267230442592, 44.09499141148159, 0.36763008311390877, 0.4844840999160494, 1.1030723409993308, 6.7759788036346436, 62.15053163255964, 76.99345411573137, 73.93004894256592, 75.65883023398263, 67.76054191589355, 71.33818326677594, 68.11269051688058, 70.29518917628697, 70.83188888004848, 70.95156465257917, 65.05345426286969, 71.3205417905535, 66.22906167166573, 62.972010203770225, 64.28807544708252, 61.91236822945731, 59.072333744594026, 59.45636762891497, 57.197754928043906, 55.92929874147688, 49.800456047058105, 51.01094341278076, 50.84579862867083, 47.574388708387104, 48.27075801576887, 48.87096772875105, 47.38501555579049, 46.67432253701346, 47.55511440549578, 47.141536780766074, 49.511574268341064, 47.478038038526265, 46.40538208825247, 49.04052114486694, 47.599489075796946, 47.32784577778408, 45.41791105270386, 45.04591492244175, 48.670640741075786, 46.35528557641165, 47.00232267379761, 47.77582393373762, 41.11021900177002, 42.08139998572213, 41.8390919821603, 43.18675763266427, 44.604030336652485, 40.68726478304182, 43.6699457849775, 43.28071117401123, 41.02675029209682, 42.890653201511924, 43.433679240090505, 47.35316848754883, 47.53449215207781, 45.50160557883126, 44.29209096091134, 45.99118259974888, 46.5887450490679, 45.64655194963728, 49.66500438962664, 53.5449583871024, 58.09674065453665, 56.98515394755772, 42.00272553307669, 41.01499394008091, 34.2057523727417, 40.23842505046299, 46.29423522949219, 36.85184179033552, 50.486503805433, 54.71228354317801, 45.58264936719622, 45.470689569200786, 46.423958097185405, 44.52814558574131, 44.61497374943325, 42.00822850636074, 45.28586401258196, 45.36996848242623, 45.753463881356375, 44.67223732812064, 42.436334814344136, 39.068848678043906, 38.621996130262104, 40.17680842535836, 39.71379089355469, 39.628592082432334, 41.99258811133248, 40.22092253821236, 40.51914964403425, 43.45680979319981, 44.47993203571865, 40.41937003816877, 40.17423759187971, 43.7477308682033, 47.63451494489397, 44.93448666163853, 44.503236293792725, 44.365397930145264, 45.312169892447336, 47.07046365737915, 44.690372126443044, 47.799322741372244, 44.87974180494036, 45.36367341450283, 46.2368882724217, 47.434285231998985, 48.38925954273769, 47.32957935333252, 46.70404345648629, 48.40633474077497, 47.017250878470286, 47.0720408984593, 48.567713601248606, 49.1829696382795, 50.14591700690133, 48.97163322993687, 49.05140202386038, 50.613860811506, 51.02033042907715, 50.36527511051723, 51.88285895756313, 54.71190139225551, 56.40129334586007, 56.22026150567191, 58.068635191236226, 61.647815568106516, 63.14391558510916, 71.62407384599958, 71.47775173187256, 70.47202777862549, 58.899886403764995, 8.951656069074359, 2.0582865817206244, 1.1335228213242121, 0.1271250013794218, 41.09957088742937, 78.08499526977539, 68.56171090262276, 67.77504280635289, 58.002974714551655, 30.027772767203196, 26.75835871696472, 45.98768070765904, 66.15793296269008, 74.34326526096889, 4.018848921571459, 0.682877099939755, 0.19588403536805085, 0.26947394013404846, 0.1425948669867856, 0.314458640558379, 0.17573727214975016], [0.040738044905343225, 0.03871164756960102, 0.05456649698317051, 0.019962783537006805, 0.09501170992319073, 0.059207018331757615, 0.002282164113629343, 0.13148253969848156, 2.736906281539372, 34.32865905761719, 39.93663004466465, 28.494348764419556, 17.06481569153922, 33.45953321456909, 48.65138380868094, 53.52337033408028, 69.10127326420375, 19.940579550606863, 0.464086577296257, 1.1661863029003143, 1.9783701385770525, 18.30257647378104, 71.92509760175432, 66.89498397282192, 68.78754125322614, 68.35016604832241, 65.55200140816825, 66.11024052756173, 62.027444294520784, 61.273557799203054, 62.83579771859305, 67.99386937277657, 64.13339465005058, 62.70483112335205, 63.30683694566999, 61.40629618508475, 59.08848135811942, 55.35345983505249, 53.03336252485003, 49.399711745125906, 45.29176650728498, 43.71046073096139, 44.976766450064524, 44.630030495779856, 45.997446400778635, 46.45774718693325, 45.00488928386143, 44.20636408669608, 45.71851791654314, 43.673604011535645, 43.028439453669954, 43.32460641860962, 41.90246302740914, 43.495712757110596, 40.955201217106406, 40.258039815085276, 41.66256604875837, 41.90695851189749, 42.84969009671892, 41.49013260432652, 46.509556429726736, 41.40545490809849, 41.091160093035015, 41.742480754852295, 45.29201316833496, 43.15716872896467, 38.48119783401489, 35.884461471012656, 36.30388600485665, 37.042847769601, 37.63930892944336, 37.3386812210083, 35.20696694510323, 37.56039823804583, 35.979123728615896, 37.862877641405376, 41.1378241947719, 42.30729634421212, 46.13834197180611, 46.58919668197632, 47.11159004483904, 46.940542766026084, 45.792189666203086, 46.35933985028948, 46.676764828818186, 53.47188418252127, 46.17711639404297, 38.09371069499424, 40.82157693590437, 37.12111922672817, 39.88854851041521, 33.15667860848563, 50.58969497680664, 47.45284039633614, 45.56357308796474, 38.36304024287632, 41.15092502321516, 36.41505023411342, 37.176399094717844, 37.076480524880544, 43.04982948303223, 38.48318501881191, 40.01656559535435, 38.27908863340105, 36.446803501674104, 36.42315183367048, 35.584914207458496, 36.00349800927298, 35.06692252840315, 35.7025784764971, 35.03925480161394, 34.55268635068621, 41.158689635140554, 39.51580197470528, 37.340588501521516, 38.80967044830322, 38.78348963601248, 38.748633997780935, 42.87457159587315, 39.81917422158377, 42.50881494794573, 39.427830832345144, 38.58493096487862, 38.48163557052612, 39.794911112104145, 43.75785786764962, 43.09399223327637, 42.167502062661306, 41.97895574569702, 42.08240747451782, 42.05373920713152, 42.19467299325125, 44.07574837548392, 42.61225625446865, 43.090139457157676, 42.72453219549996, 44.41780471801758, 43.54053906032017, 44.32762057440621, 45.756448132651194, 46.25289692197527, 48.16083056586129, 46.54085111618042, 48.47461468832833, 48.50232757840838, 48.00423901421683, 50.98179571969168, 52.28895684650966, 54.51301962988717, 57.21980503627232, 62.268810817173545, 63.21581554412842, 66.16517993382045, 64.09105927603585, 55.76023517336164, 17.362700598580496, 1.14078531733581, 0.2098097452627761, 0.23061307253582136, 13.192279764584132, 65.16247844696045, 54.80138029370989, 53.75402273450579, 51.223085812159944, 44.14514350891113, 19.72081845147269, 32.965373856680735, 51.84132262638637, 46.08688013894217, 2.1842194242136816, 0.08738287285502468, 0.07352698421371834, 0.029359626716801097, 0.08169597586882965, 0.031882097612002065, 0.05929351797593491, 0.06189859711698123, 0.009737166659241276, 0.11850257191274848, 0.043515912988888364, 0.10441000347158738, 0.0501992318646184, 0.05986419985336917, 0.13043390453926154, 4.2509773799351285, 44.49228245871407, 51.134968757629395, 39.800553049360005, 24.54546342577253, 42.74775307519095, 55.42237901687622, 60.3748847416469, 74.02671922956193, 22.18525763920375, 0.5732849006141935, 0.8118291518517903, 1.4424906479460853, 23.158759321485245, 75.1468869618007, 70.65320205688477, 71.15592506953648, 71.19101347242082, 67.80027171543666, 68.26122910635812, 64.58718150002616, 64.97107642037528, 65.32008443559918, 69.39601584843227, 64.79163224356515, 65.25824546813965, 65.05455902644566, 62.45237527574812, 59.63287271772112, 57.77339581080845, 56.43894215992519, 53.74060228892735, 48.76811007090977, 46.78898171016148, 46.78656721115112, 46.71446575437273, 46.32077734810965, 45.89536346708025, 46.56259897777012, 47.64356844765799, 46.82354899815151, 45.47099528993879, 45.01045479093279, 44.41345861979893, 43.40403822490147, 45.538656847817556, 43.213355336870464, 42.77372544152396, 44.45788540158953, 43.97472504207066, 44.01283938544137, 44.307241507938926, 48.245490891592844, 41.712304728371755, 42.27346556527274, 41.32008934020996, 46.15053258623396, 45.28665958132063, 40.28589514323643, 39.66880130767822, 38.6658079964774, 38.347007274627686, 40.149922370910645, 39.961515017918174, 39.35633386884417, 39.9584230695452, 38.233890601566856, 39.191397530691965, 42.048364775521414, 44.336337089538574, 47.97115169252668, 48.588120460510254, 49.99479021344866, 52.35296712602888, 49.0245680809021, 49.7120680127825, 47.55986697333199, 55.29700919560024, 46.64409439904349, 39.69951581954956, 42.87185137612479, 40.24650927952358, 38.41849381583077, 34.56584276471819, 52.52051598685128, 49.25064509255545, 47.602129391261506, 41.26123809814453, 43.31225599561419, 39.16244438716343, 39.15691362108503, 39.29371670314244, 44.463746207101, 41.207653590611045, 41.94298144749233, 39.804180009024485, 39.39240196772984, 37.81379904065813, 38.77343211855207, 38.46591527121407, 38.26174940381731, 40.20394808905465, 38.167253902980256, 37.57021951675415, 42.36714117867606, 40.516005584171836, 37.771592208317344, 39.455547196524485, 39.469978604997905, 41.21216644559588, 43.649962765829905, 41.245177337101524, 44.21474708829607, 42.34831850869315, 41.676511083330425, 40.673316274370464, 42.69994599478585, 45.038414342062815, 43.85217271532331, 43.991230487823486, 43.05439444950649, 44.032989161355154, 43.7226687158857, 44.85398135866438, 45.35460254124233, 44.52973672321865, 43.69704723358154, 44.54804870060512, 44.92037834439959, 45.15100990022932, 47.15372739519392, 48.669612407684326, 47.97461189542498, 50.991669109889436, 49.16692624773298, 50.72572333472115, 50.103810923440115, 50.38688053403582, 52.70074878420149, 54.967563833509175, 56.73680101122175, 61.46052687508719, 63.279912676130024, 66.10441098894391, 68.96283735547746, 68.21467617579869, 58.340570313589915, 20.972696236201696, 1.464863087449755, 0.1590570764882224, 0.2515174336731434, 13.99871461732047, 71.03028079441616, 61.39670072283064, 60.8331184387207, 56.44236067363194, 34.426361152103965, 21.638641119003296, 39.87292895998274, 56.35857234682356, 58.16584396362305, 3.2608807938439504, 0.23236499567117008, 0.14360045588442258, 0.06076995589371238, 0.10158197129411356, 0.0899428158466305, 0.0193793757352978, 0.13068869443876402, 0.1198502645960876, 0.16244751241590294, 0.16976084427109786, 0.3022236499403204, 0.07968304066785745, 0.18501124451203005, 0.3226269536784717, 6.193157391888755, 59.22531223297119, 59.09513773236956, 42.25472627367292, 26.969465834753855, 55.09355551855904, 63.21935912540981, 66.28523785727364, 80.94709028516496, 26.727421862738474, 0.7360942214727402, 2.1378653858389174, 5.976684962000165, 23.15445143835885, 78.57709448678153, 72.28287424360002, 75.19966547829765, 75.56125668116978, 69.8355380467006, 71.002425466265, 65.60195200783866, 68.86754281180245, 67.49439116886684, 69.83967917306083, 67.57379518236432, 67.11717346736363, 67.61755493709019, 65.7033748626709, 63.463421549115864, 61.03096144539969, 58.842383112226216, 54.43618992396763, 51.021647112710134, 49.87087951387678, 49.5645021711077, 51.70466545649937, 48.476924964359824, 47.879098483494346, 48.4524290902274, 48.70153938020979, 49.351390498025076, 48.267408984048025, 46.95812865665981, 46.89569909232003, 44.219089712415425, 48.277879919324604, 46.18655899592808, 45.28685065678188, 46.80066510609218, 45.341185569763184, 46.23221213476998, 46.280939851488384, 50.42979260853359, 41.64412552969796, 41.961206572396414, 42.46008375712803, 46.417065484183176, 46.83112253461565, 43.53615127290998, 41.6518554006304, 40.570552417210166, 41.5125162260873, 43.49390622547695, 42.94581495012556, 40.164715085710796, 44.53899867194039, 40.46180963516235, 42.037150382995605, 44.19961043766567, 46.5275696345738, 50.89803171157837, 52.501596042088096, 52.494161469595774, 53.43762608936855, 50.48783438546317, 51.91051626205444, 51.995572635105674, 57.47953564780099, 51.23298699515206, 43.77688898359026, 41.194028173174175, 40.17842388153076, 38.54258516856602, 37.40479680470058, 56.68806982040405, 53.399838311331614, 51.00885895320347, 43.31763390132359, 46.756950514657156, 39.9686473437718, 40.232637201036724, 42.22482817513602, 47.64699738366263, 43.5660354750497, 46.10603632245745, 43.44555718558175, 42.849391324179514, 42.35411678041731, 40.884284428187776, 43.055554798671174, 40.557336943490164, 42.24961239950997, 40.72955846786499, 40.58521311623709, 45.30062198638916, 43.10904203142439, 37.7966091973441, 40.338138648441856, 40.22754417146955, 40.95508657182966, 46.6257198878697, 44.19140114103045, 46.24998910086495, 45.53152104786464, 45.16199847630092, 43.03414739881243, 45.31585938589913, 48.59857749938965, 46.352475030081614, 47.45265974317278, 46.03437607628958, 45.70080695833479, 45.82423823220389, 46.69881841114589, 47.60111148016793, 47.16070338657924, 46.664473465510774, 47.20018999917166, 47.83788524355207, 47.73892205102103, 47.853869574410574, 51.26383352279663, 50.15589114597866, 53.59282452719552, 50.73293209075928, 54.68765912737165, 52.50281892504011, 52.87155287606375, 54.928556646619526, 56.820669242313926, 60.03775814601353, 64.13460363660539, 66.09669848850795, 70.42878913879395, 71.1500677381243, 71.36669172559465, 58.53608567374093, 23.38824095044817, 2.694850138255528, 1.0195648734058653, 0.42187849645103725, 18.311190502984182, 77.18736444200788, 65.69956030164445, 66.37341049739292, 69.60886001586914, 59.84552928379604, 25.82482133592878, 48.25049359457833, 61.60243688310896, 72.64200578417096, 5.781762804303851, 0.4689073786139488, 0.213389071768948, 0.17955925634929112, 0.1952464295817273, 0.23718362567680223, 0.14032417668827943], [0.04595760429011924, 0.03277170451890145, 0.03209702018648386, 0.051973315953676186, 0.03685602732002735, 0.06099143650914941, 0.11114685876028878, 0.08978490717709064, 4.59386533498764, 42.66538218089512, 34.46931144169399, 36.286928926195415, 33.70577737263271, 34.44842515672956, 50.578782830919536, 54.74292509896414, 68.71635695866176, 9.068798354693822, 0.30506532745701925, 0.1505318810897214, 0.7920779202665601, 50.77886315754482, 70.9922741481236, 70.1395981652396, 66.57747214181083, 62.00721114022391, 63.49604334150042, 65.18924290793282, 63.299652508326936, 61.02739701952253, 61.20890481131417, 64.08886364528111, 60.61079692840576, 66.53930568695068, 60.43135275159563, 59.43089553288051, 57.71017067773001, 60.808473178318565, 55.07949583871024, 50.41869633538382, 48.69807570321219, 50.01461689812796, 47.69224057878767, 48.067992210388184, 44.8758681842259, 44.230116503579275, 42.53947734832764, 45.693059716905864, 42.83791290010725, 44.43768004008702, 42.42739248275757, 42.866942473820274, 41.01830128261021, 44.54795142582485, 41.539541244506836, 42.89977271216256, 41.677456038338796, 42.18946531840733, 38.9916090284075, 46.391037532261436, 47.031685761043, 46.56652818407331, 42.699574266161235, 43.056242670331685, 39.01912389482771, 38.699781213487896, 41.281856877463206, 39.18786784580776, 36.03886086600167, 37.03527423313686, 37.87819494519915, 36.90574244090489, 34.91420112337385, 37.05040046146938, 35.818655082157676, 38.72872393471854, 35.74847827638899, 37.78919199534825, 41.417430128370015, 44.51799774169922, 46.1941568510873, 53.024253436497276, 52.2451936176845, 56.115430559430806, 47.513178552900044, 56.37448719569615, 41.01891967228481, 32.65228802817208, 44.644958700452534, 41.426132747105186, 32.733825138636995, 39.06935589654105, 54.59855195454189, 46.93567207881382, 47.37941878182547, 46.43005861554827, 46.92188685280936, 42.34153011866978, 40.46975142615182, 37.039797510419575, 39.3087282861982, 36.99745866230556, 35.825172492435996, 34.977037157331196, 35.3089143889291, 34.35422842843192, 36.68555055345808, 34.12623371396746, 34.661217212677, 36.25801747185843, 37.05263083321707, 39.14396217891148, 41.76509714126587, 37.91786221095494, 39.9030042375837, 39.566485609327046, 39.2880539212908, 39.87011841365269, 41.870619433266775, 39.60446793692452, 41.27446052006313, 41.41434165409633, 37.58535269328526, 37.06644037791661, 39.971645491463796, 41.7854379926409, 40.38385084697178, 41.45192098617554, 41.510581152779714, 42.72752339499337, 41.96245377404349, 42.83752727508545, 42.39742490223476, 42.91045209339687, 44.60554504394531, 46.488736152648926, 44.87782757622855, 46.512915883745464, 46.97285188947405, 48.257771832602366, 51.40958588463919, 50.950567041124614, 51.88827160426548, 52.79643937519619, 49.803415979657856, 51.64899301528931, 52.06132343837193, 56.753448895045686, 57.76153176171439, 62.057536942618235, 59.22249126434326, 66.47658429827008, 64.2788621357509, 59.63306031908308, 65.2549798148019, 24.51326894760132, 0.7497877095426831, 0.1625624019652605, 0.17334694255675587, 3.9616669842175076, 59.5261344909668, 60.0199499130249, 57.27665172304426, 48.82510961805071, 42.165966510772705, 26.746821233204432, 34.10764033453805, 48.49587270191738, 60.20946202959333, 8.373072624206543, 0.41064070803778513, 0.18478514307311603, 0.07415371986904315, 0.08284411818853446, 0.08310050943068095, 0.030008899912770306, 0.03947149143953409, 0.05442179599776864, 0.028171291375266652, 0.039389955279018195, 0.13706015183457307, 0.013309148023836315, 0.14773000643721648, 0.21063263182129177, 7.878642286573138, 54.997868401663645, 47.38806928907122, 40.33737434659685, 23.447797434670584, 36.18812206813267, 59.45445687430245, 59.92467621394566, 76.47363158634731, 9.625016416822161, 0.30010420509747093, 0.28156350712691036, 1.556970687849181, 56.51063019888741, 71.25388077327183, 72.26328032357353, 68.83101613180978, 67.5320017678397, 67.63610662732805, 67.31928961617606, 64.9551511492048, 65.51011766706193, 62.803259304591585, 65.47286142621721, 61.40904767172677, 67.09873989650181, 62.48163414001465, 61.11445099966866, 60.837989125932964, 62.06712545667376, 57.09227432523455, 53.72583736692156, 52.02974040167672, 52.97023466655186, 50.403170585632324, 50.159730025700156, 46.61692694255284, 47.3443512235369, 44.05035618373326, 46.95342125211443, 44.41583490371704, 45.3732202393668, 43.63070930753435, 46.247300148010254, 43.72404793330601, 45.97880090985979, 43.50268874849592, 44.12520217895508, 43.01837498801095, 45.02978120531355, 41.61975819723946, 47.961257457733154, 50.565053190503804, 47.693241119384766, 42.313897132873535, 42.171789101191926, 39.572273458753315, 40.267934049878804, 44.00630113056728, 41.00205292020525, 37.57242904390608, 39.6012578691755, 39.55177974700928, 40.08922290802002, 38.636778422764365, 41.13990865434919, 39.464746611458914, 40.04821811403547, 38.59605850492205, 41.072354793548584, 43.09524638312203, 45.94101660592215, 47.465020588466096, 54.499085017613, 54.056467396872385, 58.04981599535261, 50.93068477085659, 57.84336069652012, 44.28346477236067, 37.98096227645874, 44.14104754584176, 43.82998364312308, 34.771214144570486, 41.476246629442485, 53.533792631966726, 50.16386767796108, 50.75572565623692, 49.288544041769846, 47.674265589032856, 46.48731872013637, 40.521887234279085, 39.437811919621055, 40.854622568402974, 38.40967307771955, 38.038086891174316, 37.00858620234898, 37.172223227364675, 35.832770347595215, 38.27409635271345, 36.9769093649728, 38.37086044039045, 38.74049765723092, 39.981529303959434, 43.03767360959734, 41.991452080862864, 37.90046044758388, 40.013070651463096, 39.74210480281285, 40.429319858551025, 40.540171418871196, 44.536799567086355, 41.958302225385395, 43.71507780892508, 43.87538317271641, 40.65605347497122, 39.46394756862095, 40.85157925742013, 42.71744850703648, 42.01234878812517, 44.53980118887765, 42.3640318598066, 45.100722312927246, 43.86748654501778, 45.30450255530221, 44.430526869637625, 44.61675248827253, 45.06761762074062, 48.90364163262503, 46.8527592250279, 49.71651485988072, 49.29837574277605, 50.98645101274763, 52.5266512462071, 54.845845290592735, 54.91000148228237, 54.83182382583618, 53.09945378984724, 53.51522357123238, 53.26276772362845, 60.363628659929546, 61.24186706542969, 64.894284929548, 62.12537220546177, 68.9495176587786, 66.81480176108224, 61.123740741184776, 65.97996875217983, 29.970464025224956, 1.5498653948307037, 0.2094041441700288, 0.3276595122047833, 4.239640091146741, 65.30940505436489, 66.39063508169991, 63.5050482068743, 55.05743530818394, 39.98500687735421, 20.77923927988325, 39.3382477079119, 52.793538502284456, 69.51913792746407, 10.602230174200875, 0.5375112859266145, 0.16008941323629447, 0.11196112792406764, 0.02716755148555551, 0.04635989073930042, 0.06409741698631219, 0.1117682136329157, 0.14801556111446448, 0.16448011834706577, 0.18196707857506617, 0.2703757403152329, 0.1697627305984497, 0.37094445526599884, 0.39629476783531054, 10.521109955651418, 71.4986241204398, 53.41194554737636, 53.09997490474156, 47.02697140829903, 48.96245813369751, 67.66872841971261, 65.51686436789376, 82.72836521693638, 11.919006739343915, 0.5242998834167207, 1.51962987439973, 4.201676871095385, 57.74955654144287, 74.08428505488804, 76.20112323760986, 71.92655672345842, 70.417526108878, 65.10041018894741, 71.04282924107143, 66.61273424965995, 67.50301388331822, 67.27736418587821, 69.16306359427315, 61.79791750226702, 66.41874749319894, 65.78746891021729, 63.976483481270925, 62.38959830147879, 64.97227151053292, 59.78416974203927, 55.535919530051096, 54.71848828451974, 56.002383368355886, 52.373790877205984, 52.551675183432444, 50.28975166593279, 49.00468928473336, 46.23767341886248, 50.22215959003994, 47.271992683410645, 48.55753449031285, 45.050709179469514, 48.671780245644705, 46.10111352375576, 48.609371525900706, 46.990708759852815, 47.77423974445888, 45.30837270191738, 47.55616358348301, 43.42542478016445, 51.75591189520699, 51.93326466424124, 47.58249030794416, 42.84073386873518, 43.88816785812378, 40.516974857875276, 38.30580793108259, 44.13721214021955, 44.98552812848772, 41.67031676428658, 41.170550210135325, 43.72165427889143, 42.583963189806255, 40.90436472211565, 42.37900522777012, 41.25287594114031, 41.99698632104056, 40.0218323298863, 42.96810824530465, 47.922840867723735, 49.59357343401228, 51.30579716818673, 57.46478809629168, 56.84406035287039, 60.52702944619315, 54.00037806374686, 59.83658695220947, 50.16310337611607, 41.055428981781006, 44.88221188953945, 46.181538922446116, 39.718762329646516, 46.33884266444615, 58.07506922313145, 53.328577586582725, 52.60223027638027, 50.40415375573294, 51.57057217189244, 47.99483115332467, 42.957918712071006, 41.91700560706002, 44.034243311200825, 41.34492915017264, 40.44514438084194, 40.08457803726196, 40.286207812173025, 38.03991774150303, 41.856222765786306, 39.94057662146432, 40.266999517168315, 42.390448910849436, 41.76214415686471, 44.20272670473371, 43.38858890533447, 38.00875507082258, 39.2796813419887, 40.61046634401594, 41.457722731998985, 41.440633637564524, 44.80799470629011, 42.895381450653076, 45.67725951331002, 46.44589703423636, 42.337093693869456, 42.28036860057286, 44.751016003744944, 46.099550179072786, 44.339588846479145, 46.61725698198591, 43.915064334869385, 46.2452643258231, 46.63450241088867, 47.349117687770296, 47.6461740221296, 46.48648493630545, 47.49040930611746, 52.23870400020054, 47.56502948488508, 52.42479760306222, 50.71025317055838, 53.985085078648154, 55.97612265178135, 56.46764169420515, 56.44921159744263, 57.45988266808646, 54.7937650680542, 55.788413592747276, 54.23859357833862, 62.15012863704136, 64.04222038814, 67.54885809762138, 67.12792927878243, 72.15128231048584, 69.51885305132184, 61.88632638113839, 64.65975543430874, 32.68638283865792, 1.8807429543563297, 0.38900157489946907, 0.27382454382521765, 5.1706405111721585, 73.87485940115792, 71.3408305304391, 71.56436797550747, 61.399090903145925, 57.40384892054966, 36.346287386757986, 48.388748850141255, 60.205647468566895, 83.94799641200474, 16.84620451927185, 0.6972963490656444, 0.26722500366824015, 0.17391535134187766, 0.11331749228494507, 0.10835890086101634, 0.13378356051232132], [0.014748788139383708, 0.04028084122442773, 0.06780114610280309, 0.0572778211374368, 0.15894226836306707, 0.027673211048490236, 0.11519639646368367, 0.12434348277747631, 7.191583131040845, 39.38956710270473, 39.36093357631138, 43.11793572562081, 34.957860129220144, 41.66729777199881, 52.501561301095144, 57.26515245437622, 60.79300648825509, 2.5600587768214087, 0.023680955271369646, 0.5484957907881055, 10.92026138305664, 73.67877428872245, 62.5650611604963, 69.77847249167306, 64.39030429295131, 68.35884434836251, 58.49963542393276, 76.27038288116455, 61.372250011989046, 64.19182205200195, 56.645178590502056, 68.8525972366333, 73.77882140023368, 64.25567599705288, 60.98727812085833, 61.04542064666748, 59.416839327131, 57.046746253967285, 53.75553049360003, 57.76935543332781, 53.92309325081961, 56.54398850032261, 54.187847409929546, 53.202738761901855, 50.37604481833321, 47.674640791756765, 43.56722709110805, 43.8979891368321, 44.078652722494944, 43.039025034223286, 42.344886098589214, 42.9917425428118, 42.511417048318044, 43.919969763074604, 38.680322783333914, 40.48174401691982, 41.57165581839425, 41.39152029582432, 41.68439728873116, 41.90688208171299, 45.2291910307748, 43.14182015827724, 44.606232915605815, 41.6164230619158, 36.475857394082205, 39.401368618011475, 40.578879833221436, 44.40563842228481, 39.23897532054356, 36.72418253762381, 37.1300094468253, 38.29675095421927, 36.29570797511509, 38.58807849884033, 37.1905768939427, 37.04087100710188, 36.17375666754586, 36.04951940264021, 35.67625175203596, 35.70009102140154, 36.10272870744978, 41.06290871756417, 43.0427770614624, 46.79443257195609, 47.29618631090437, 44.90533202035086, 40.211354868752615, 41.74364457811628, 40.73099327087402, 42.241830417088096, 35.46048934119088, 34.542187622615266, 46.193618365696494, 50.067666394369944, 47.21777936390468, 46.1362818309239, 43.14956045150757, 44.27223995753697, 36.58506917953491, 35.790226527622764, 35.21313694545201, 35.01135778427124, 35.42614092145647, 34.544219970703125, 33.94175556727818, 35.758202280317036, 34.18843051365444, 36.78643492289952, 35.15243748256138, 37.8643992968968, 39.929212842668804, 42.62388753890991, 38.699850695473806, 37.6095289502825, 37.814118657793315, 36.878616673605784, 37.67812851497105, 42.15095145361764, 44.29857015609741, 41.96964168548584, 39.55349942616054, 40.14018447058541, 37.664721965789795, 37.98170573370797, 37.36598069327218, 41.369244371141704, 40.64904621669224, 41.67958913530622, 41.64849247251238, 43.36410345349993, 41.165874072483604, 42.35840381894793, 46.181459018162315, 42.64197022574288, 44.97964300428118, 47.96403326307024, 49.603877612522666, 51.322250502450125, 52.05431270599365, 52.74566888809204, 51.724933351789204, 55.1407824243818, 53.20089054107666, 53.73839970997402, 52.28905759538923, 54.16599185126168, 55.11343778882708, 59.72674982888358, 61.41965062277657, 59.287366594587056, 65.47996248517717, 63.20420510428292, 63.07368319375174, 72.83358151572091, 47.39801563535418, 33.66162851878575, 1.7085279439176833, 0.05792230726884944, 0.11924920470586844, 1.2897292907748903, 53.172569683619905, 59.387094088963096, 59.61261871882847, 42.41944374356951, 66.10095078604562, 32.02109282357352, 20.309596640723093, 45.02770021983555, 62.94287640707833, 16.74246965135847, 0.354220738368375, 0.17768883385828563, 0.0946859045486365, 0.06213645078241825, 0.10522990447602101, 0.05606682951162968, 0.13165130492831978, 0.06556544106985841, 0.0807782911828586, 0.05927046814135142, 0.1473896261304617, 0.028889690326260667, 0.13715731804924353, 0.19536332759474004, 9.561025244849068, 51.89062704358782, 49.139008385794504, 51.675250257764546, 36.316625526973176, 47.261890002659385, 61.19930934906006, 62.34866646357945, 68.49994141714913, 2.36044528228896, 0.03165645757690072, 0.6194997036031314, 13.389209951673235, 75.3338212966919, 67.23882252829415, 72.80556637900216, 67.05312497275216, 71.0770491191319, 62.05308314732143, 77.97172573634556, 62.76332105909075, 64.66602965763637, 58.46096869877407, 67.67308494022915, 68.80147239140102, 67.17692102704729, 62.64017118726458, 64.1757230758667, 61.15552180153983, 60.20794037410191, 56.51288488933018, 60.2124080657959, 56.09401273727417, 60.99799919128418, 57.158369064331055, 57.0448876108442, 52.726933070591514, 50.40352841785976, 44.36000265393938, 45.96886498587472, 45.55923741204398, 44.78052847726004, 44.18218435559954, 43.66431079592024, 43.85055031095232, 44.49650348935808, 40.727255140032085, 42.71388060706002, 43.681716033390586, 43.79215070179531, 43.38283232280186, 44.72032928466797, 46.882445403507774, 44.776543685368125, 45.87497745241438, 41.05171864373343, 38.16012852532523, 39.335854053497314, 41.15825537272862, 47.55614621298653, 39.691278730119976, 38.7261392048427, 39.027225494384766, 39.04173680714199, 39.73724453789847, 39.88716581889561, 40.691232204437256, 40.01073605673653, 39.858125822884695, 40.295459338596885, 37.68743910108294, 36.65031623840332, 38.9695519719805, 42.17868518829346, 46.06270040784563, 49.951412609645296, 49.69657005582537, 44.756692681993755, 42.949532236371724, 44.96016372953142, 42.16344084058489, 44.83987998962402, 38.82005800519671, 39.27485581806728, 47.93454858234951, 50.94851384844099, 49.72642993927002, 48.42892680849348, 45.31846496037075, 45.396069390433176, 39.07417447226388, 38.32372038705008, 37.31637750353132, 38.34921680177961, 37.48045573915754, 35.564159938267295, 37.41844654083252, 37.12546532494681, 36.33832475117275, 38.48816340310233, 35.98693697793143, 41.43824345724923, 41.971437794821604, 42.38667951311384, 39.6161652292524, 39.24262659890311, 37.18228074482509, 38.00452709197998, 40.03736155373709, 41.36052785600935, 45.08374786376953, 43.21938289914812, 42.94609982626778, 42.30689682279314, 40.32486758913313, 41.342844690595356, 40.21493319102696, 43.888807092394146, 43.072296483176096, 44.81466497693743, 43.95524229322161, 45.567064557756694, 42.71859495980399, 45.549999782017295, 46.957291398729595, 45.60617944172451, 45.31306273596627, 50.653284890311106, 51.12955263682774, 53.4441956111363, 53.31454222542899, 55.44314023426601, 53.743711607796804, 56.102326256888254, 55.32994018282209, 55.85190275737217, 54.11830636433193, 56.876366002219065, 57.23907586506435, 61.33361107962472, 64.25266742706299, 62.70297595432827, 68.50098364693778, 66.94420501164028, 63.44982392447335, 72.00042302267892, 51.11029917853219, 38.37430327279227, 2.4627030066081455, 0.027480742894113064, 0.1390724288565772, 0.9339168178183692, 58.00822755268642, 65.40040561131069, 66.05019419533866, 50.590049334934776, 54.079893248421804, 29.359161513192312, 29.008765595299856, 47.98743479592459, 70.8487799508231, 22.355707372937882, 0.5773118159600666, 0.12253917673868792, 0.03141086182690092, 0.010474829219414719, 0.1182680566396032, 0.05455241059618337, 0.21862725354731083, 0.19572187906929425, 0.2162361911364964, 0.18477071741861956, 0.25474004074931145, 0.11045935350869383, 0.3455372271793229, 0.3187708934502942, 13.932824850082397, 63.75179958343506, 58.178816250392366, 59.40673664637974, 48.10387965611049, 61.571399280003135, 66.66589491707938, 68.01073265075684, 75.98623629978725, 3.822601394993918, 0.17931910923549108, 0.9794998232807431, 11.81448325089046, 79.02325916290283, 68.0611001423427, 77.23432731628418, 69.05998706817627, 75.21934277670724, 63.03940078190395, 76.14457184927804, 65.01649679456438, 68.25607354300362, 61.3414694922311, 69.23320565904889, 67.63812160491943, 70.77258600507463, 66.61470753805978, 65.4715690612793, 65.71364430018834, 62.48173836299351, 59.00741672515869, 63.521939277648926, 58.0062438419887, 62.95287486485073, 58.12379346575056, 58.70961693355015, 54.73042181559971, 53.63056366784232, 47.356767654418945, 48.53404263087681, 48.84174360547747, 46.02016353607178, 47.168353353227886, 46.71020998273577, 46.950388363429475, 47.24572154453823, 42.32302359172276, 45.234725270952495, 46.34673581804548, 45.22497347423008, 45.29887451444353, 45.3481685093471, 49.04248053686959, 46.11916841779436, 46.40229361397879, 42.21581636156355, 39.563438824244905, 42.37390872410366, 40.29994092668806, 48.30242443084717, 43.018948214394705, 41.299710273742676, 42.700619970049175, 42.90122488566807, 42.726474217006135, 43.4204637663705, 42.850937298366, 41.924051080431255, 43.83124474116734, 43.644636971609934, 41.334034374782014, 39.900787762233186, 41.38948447363717, 46.41354622159685, 47.29197917665754, 51.457577092306956, 52.16882944107056, 49.21875980922154, 44.77294799259731, 47.766593251909526, 46.75086736679077, 46.634384291512625, 42.71653829302107, 41.74619804109846, 52.65144436700003, 55.913741724831716, 53.70399917875017, 51.37827730178833, 47.761851106371196, 48.99221726826259, 43.058584213256836, 40.9542110988072, 40.73612798963274, 40.77117817742484, 40.275987012045725, 39.06529467446463, 39.55059855324881, 41.58005966459002, 38.388321263449534, 41.76650415148054, 39.271590164729524, 42.857888971056255, 44.53779663358416, 42.857135091509136, 40.58818694523403, 38.93989358629499, 39.43188163212368, 38.89851706368582, 38.344863755362375, 42.61748824800764, 47.436526026044575, 45.07691083635603, 43.660638672964915, 45.55952228818621, 44.22326905386788, 42.270324979509624, 40.59313406263079, 47.079034260341096, 44.207812786102295, 45.14200503485543, 44.481283460344585, 47.96669094903128, 44.01357242039272, 46.72983169555664, 49.75980561120169, 46.57293789727347, 48.98164211000715, 52.66982930047171, 55.04972628184727, 55.74328851699829, 56.42895065035139, 57.62784842082432, 56.591232776641846, 59.263499532427105, 57.36510576520647, 60.077140535627095, 58.013185092381065, 59.318355560302734, 60.59462152208601, 65.00116212027413, 66.8096045085362, 65.19047968728202, 70.15222304207938, 71.80107225690568, 65.05427415030343, 70.10918590000698, 55.03591673714774, 41.11149052211216, 2.491681771618979, 0.25424354310546604, 0.17811656876334123, 1.2120288887194224, 67.18750313350132, 69.93372304098946, 75.12918295179094, 56.411958830697195, 82.10146399906704, 42.37951939446585, 34.342986243111746, 56.21269144330706, 79.70355033874512, 30.628885746002197, 0.6177694393055779, 0.2303336789565427, 0.18934983813336917, 0.10659666399338416, 0.30989169276186396, 0.11183156166225672], [0.13947421658251966, 0.019148232781195214, 0.0569277513506157, 0.08290322537400893, 0.06757242551871709, 0.024555737884449105, 0.08320271716053997, 0.19147658401301929, 7.321754591805594, 49.41395902633667, 34.10143559319632, 49.617186886923655, 50.3496208190918, 40.575850418635774, 54.19843993868147, 60.51109722682408, 49.295884813581196, 0.5390188278896468, 0.15081812787268842, 8.376626627785818, 46.07209089824131, 71.4852488381522, 65.90986837659563, 67.99644715445382, 61.65206091744559, 68.55474185943604, 57.015566212790354, 59.717883927481516, 67.7823384148734, 64.43203517368862, 58.05121953146798, 54.45012106214251, 51.384482043130056, 56.615464619227815, 63.220137323652, 58.458008766174316, 61.036464418683735, 59.05041217803955, 58.07417637961251, 56.84818410873413, 57.04812547138759, 58.50838320595877, 59.204571860177175, 56.57268108640398, 56.54546499252319, 46.35189138139997, 45.00476769038609, 44.72651318141392, 42.28892878123692, 42.69811167035784, 41.77083287920271, 42.033829144069124, 43.02249526977539, 42.62222344534737, 40.797675132751465, 42.664802006312776, 41.994144507816856, 40.647736481257844, 43.140142168317524, 43.00410338810512, 46.33466679709298, 46.60568128313337, 46.32275758470808, 40.25624370574951, 33.578371729169575, 44.51750094549996, 40.40076276234218, 44.356334005083355, 43.50667701448713, 39.359262534550254, 37.51210478373936, 35.25210591724941, 36.507294518607004, 36.58810206821987, 37.23301649093628, 38.1830541065761, 35.41409969329834, 37.50073058264596, 33.79243877955845, 36.5534861428397, 34.63429641723633, 35.88533346993582, 34.56698226928711, 36.5064503124782, 35.69319840839931, 37.5282940864563, 34.41624804905483, 38.385423864637104, 39.22796937397548, 38.2765907560076, 39.68057155609131, 38.9558744430542, 36.42620209285191, 35.830411434173584, 35.44328212738037, 36.6055976322719, 37.38630070005144, 36.966348103114534, 34.05791555132185, 35.67351763589041, 35.61400978905814, 34.65202474594116, 33.93096154076712, 35.91514471599034, 34.80572237287249, 35.14571510042463, 34.34635264532906, 35.84368944168091, 36.004488127572195, 41.75817673546927, 42.89483254296439, 41.94264445986067, 41.94293628420149, 44.201639311654226, 38.00364119665963, 36.78750841958182, 39.34469911030361, 41.89608458110264, 42.36455992289952, 37.9210444859096, 39.491966179439, 39.9212258883885, 38.305658544812886, 37.462157658168245, 40.119395460401265, 40.70216866901943, 41.2611095564706, 40.9412978717259, 41.80100195748465, 42.19281087602888, 41.095912660871235, 44.28748083114624, 42.96775736127581, 48.59080941336495, 47.908041204724995, 51.2286547933306, 50.60221563066755, 52.250505515507285, 52.67143433434622, 52.769296237400596, 52.92291743414742, 53.66059725625174, 56.772580759865896, 54.7091394833156, 55.7826361656189, 55.49753768103463, 58.59055955069405, 61.41958114079067, 69.71907234191895, 63.479319027491975, 64.48308358873639, 65.75982897622245, 77.07025255475725, 44.50186749867031, 52.961962836129324, 47.0761889730181, 5.65849655015128, 0.016975894437304566, 0.06293954447443996, 0.0291153371467122, 37.081601347242085, 63.71194471631731, 54.281172139304026, 49.48385443006243, 62.36551584516253, 27.046648161751882, 31.881100518362864, 54.448352745601106, 57.64140783037458, 22.07404998370579, 0.3481327864740576, 0.07968806861234562, 0.08801388328096696, 0.018253928715629236, 0.01648394637075918, 0.043311008983956914, 0.07338687351771764, 0.0454750708969576, 0.06552542107445852, 0.042528437583574226, 0.10260746162384748, 0.009271756945444005, 0.052699077009622536, 0.20024192652532033, 11.089507341384888, 61.83061572483608, 39.38138559886387, 58.89134706769671, 54.81227159500122, 45.371698583875386, 62.67551667349679, 67.30338518960136, 55.369166237967356, 0.5419847315975598, 0.3406333460339478, 11.247945376804896, 50.75337716511318, 73.62445327213833, 68.94907992226737, 70.78789288657052, 64.94574328831264, 71.54621233258928, 60.16308280399868, 62.17957510266985, 69.48168018886021, 62.55324922289167, 59.39627960750035, 51.81848737171718, 52.96893882751465, 60.62472111838204, 65.58088506971086, 62.41241618565151, 61.9952324458531, 60.50480215890067, 59.98697376251221, 59.741507802690776, 60.6747898374285, 62.50928102220808, 61.78016485486712, 61.03649915967669, 59.175243513924734, 49.61157274246216, 45.77186965942383, 47.83415406090872, 44.522263935634065, 43.87520251955305, 44.764926297324045, 45.05247402191162, 44.59239905221121, 42.988549845559255, 42.584279332842144, 44.35196358816964, 42.283936500549316, 44.55173471995762, 43.42958675112043, 45.75228616169521, 47.78547845567976, 47.67160095487322, 46.172586168561665, 42.198320797511506, 35.629299300057546, 45.56852715356009, 41.4654734475272, 44.6736512865339, 43.343484674181255, 41.592225960322786, 39.94171960013253, 38.618299688611714, 38.27034779957363, 38.83809552873884, 39.97546700068882, 39.340151514325825, 37.02120065689087, 39.86884341921125, 38.23767736979893, 38.78442069462368, 37.632933957236155, 38.02605261121477, 36.83694832665579, 39.06620141438076, 36.688555649348665, 38.42867292676653, 38.45312016350882, 40.86344678061349, 40.725042138780864, 39.89024387087141, 39.29036767142159, 40.59954724993025, 38.60320125307356, 38.494583538600374, 36.74428367614746, 38.61644799368722, 39.9950852394104, 36.84871162687029, 35.998193059648784, 38.34377983638218, 39.14774547304426, 37.04281997680664, 36.7971316746303, 38.66012784412929, 37.53417921066284, 39.05550118855068, 36.89002908979143, 38.01045043127877, 38.503237519945415, 41.93794400351388, 41.74530867167881, 42.00891637802124, 42.28077507019043, 44.28664009911673, 38.84439754486084, 36.55803026471819, 39.031272820064, 41.73421587262835, 44.98149817330496, 41.06813376290457, 40.83786003930228, 42.331535134996685, 40.85450097492763, 39.3405510357448, 42.02964980261666, 43.59411661965506, 43.365583419799805, 43.19270181655884, 43.40336077553885, 43.137456689562114, 43.96674156188965, 45.88814776284354, 45.734693322862896, 50.16689709254673, 51.24026870727539, 54.41948298045567, 52.85809768949236, 56.553458895002095, 55.1319443157741, 55.282230377197266, 55.67679425648281, 55.96002714974539, 59.180406025477815, 57.280952657972065, 58.236062458583284, 57.11169801439558, 61.007976804460796, 63.53605801718575, 67.50905881609235, 65.79835673740932, 66.63184874398368, 66.89187812805176, 74.09474904196603, 49.32609558105469, 55.736079760960166, 52.37159872055054, 6.342881517750876, 0.3213785578097616, 0.043263158694441826, 0.026317630395559326, 41.68337590353829, 69.46683883666992, 62.79683916909354, 57.02032225472586, 60.98110812050955, 23.35216416631426, 33.8642657824925, 58.37914671216692, 65.31346975054059, 28.991030318396433, 0.4221281701964991, 0.08215319990579571, 0.10199570802173444, 0.06901581878108637, 0.1466531442212207, 0.03665571699717215, 0.17163639648684434, 0.13167277377630981, 0.1687107163348368, 0.168960946479014, 0.12863494535642012, 0.08650060769702707, 0.2338122565831457, 0.4313093732510294, 15.552396093096052, 74.71504252297538, 51.63026762008667, 62.63258375440325, 63.74959700448172, 55.99875293459211, 69.04942580631801, 73.1820684160505, 62.24096243722098, 0.8888694207583154, 0.7442939643348966, 15.083043541227068, 53.26715203693935, 74.00436687469482, 72.93656771523612, 73.79952008383614, 67.61194774082729, 74.37977804456438, 63.358983176095144, 66.28714861188615, 69.42168944222587, 66.33786351340157, 62.46844645908901, 53.86136198043823, 60.25496578216553, 63.254940850394114, 66.78265939440045, 65.23596259525844, 67.05006776537213, 63.75186211722237, 63.11494854518345, 63.09250586373465, 63.6295599256243, 63.58315290723528, 64.3363515308925, 62.488637924194336, 63.373706408909385, 52.30407960074288, 49.2367000579834, 51.32967117854527, 45.497391496385845, 47.46012905665806, 46.44592482703072, 47.14794301986694, 47.004719802311485, 45.21135153089251, 44.55200569970267, 48.371159485408235, 44.946566104888916, 45.952022552490234, 46.20576729093279, 47.98488828114101, 50.015975270952495, 49.817777906145366, 46.023067883082796, 43.88167129244123, 38.35959046227591, 48.50624636241368, 42.515902110508506, 44.67115340914045, 47.08945655822754, 45.15144763674055, 43.3124748638698, 40.45567437580654, 40.83080414363316, 41.53031403677804, 41.970795086451936, 44.24192844118391, 39.54258380617414, 43.23072235924857, 38.7842504637582, 42.92804493222918, 41.13248103005545, 41.10841941833496, 39.0212014062064, 41.99629497528076, 40.36378444944109, 41.9926541192191, 41.35674456187657, 43.996955803462434, 42.90522009985787, 44.23266996656145, 43.274694034031455, 42.634976863861084, 42.81831898008074, 41.46507045200893, 38.841701643807546, 40.85554667881557, 41.946816853114534, 41.57466091428484, 38.24080058506557, 41.172454016549246, 40.409003325871055, 39.791589873177664, 39.21027231216431, 42.48467690604073, 40.01177133832659, 41.32406718390328, 39.808262075696675, 40.53657920019967, 41.42416640690395, 42.91090372630528, 43.62353876658848, 43.48858043125698, 44.803332465035574, 45.454687867845806, 40.20364931651524, 38.49944032941546, 39.65810455594744, 42.79515368597848, 46.868573325020925, 42.27344124657767, 43.417274543217246, 45.53429685320173, 42.91562850134713, 42.061743531908306, 45.593380859919954, 45.28058685575213, 45.32992948804583, 44.429713930402485, 44.334245681762695, 45.36337464196341, 45.33934777123587, 48.556599957602366, 47.696489402226035, 54.03095013754708, 52.27726650238037, 56.590520586286274, 56.5711281640189, 57.53175483431135, 56.86727428436279, 57.93526104518345, 58.708067485264365, 57.19974211284092, 61.09420394897461, 59.614216804504395, 60.88483388083321, 59.88955307006836, 63.05536079406738, 67.97956303187779, 67.51169218335832, 67.08150141579765, 70.36398329053605, 69.0842501776559, 75.9225491115025, 56.3878173146929, 61.3542263848441, 55.26460974557059, 7.337659018380301, 0.5700857979910714, 0.17618806367473944, 0.1686918937734195, 48.74944026129586, 75.53798716408866, 69.75876045227051, 65.1386947631836, 79.8629698072161, 36.968192849840435, 46.47882454735892, 65.90172508784703, 70.84212357657296, 38.480635029929026, 0.46951306611299515, 0.18787585651235922, 0.15962412820330688, 0.12444176178957735, 0.3197942871068205, 0.08189258817583323], [0.05632396374962159, 0.03671603876032999, 0.09091046785137483, 0.09462554207337753, 0.07103308303547756, 0.06935182253697089, 0.1521787941455841, 0.14898400700518064, 9.793350424085345, 43.515810421534944, 32.721332277570454, 43.6822440964835, 41.32995925630842, 52.243303707667756, 49.83439104897635, 70.52470902034214, 35.588332721165244, 0.08059784157999925, 0.1205533490117107, 3.049680743898664, 54.521680559430806, 68.71612071990967, 66.25446428571428, 64.7762211390904, 64.98830100468227, 63.89361926487514, 67.89674050467355, 54.09548153196062, 56.69274595805577, 59.237096377781455, 56.53452157974243, 32.887543610164094, 44.019245624542236, 62.9476637159075, 59.78569834572928, 60.54963193620954, 60.272697584969656, 60.23583044324602, 58.17196185248238, 60.954510416303364, 59.054094723292756, 58.77089309692383, 55.09031418391636, 59.73168999808175, 56.4755973815918, 48.53936147689819, 42.63897902624947, 44.199975218091694, 43.29434701374599, 44.25764526639666, 41.912708146231516, 43.70890433447701, 40.928481919424875, 42.62623603003365, 40.93992212840489, 41.23867382322039, 42.02182265690395, 42.345032010759624, 42.06293167386736, 42.52702617645264, 44.70292057309832, 46.38459307806832, 38.04873500551496, 34.693349157060894, 31.574744020189556, 41.03852054050991, 49.338484219142366, 46.18067387172154, 41.67708778381348, 42.56728751318795, 36.78969362803868, 35.763833795275005, 37.288209506443565, 37.183927467891145, 36.437235832214355, 37.64090354101998, 36.408199310302734, 38.90893588747297, 35.981729303087505, 36.54802138464791, 34.20377213614327, 37.75534037181309, 36.455294200352256, 37.608330386025564, 36.79302876336234, 38.79004178728376, 38.353514262608115, 38.96420880726406, 38.13790818623134, 36.38373122896467, 36.041275365012034, 35.68274136951992, 34.27380302974156, 35.73224033628191, 34.62933540344238, 35.27607025418963, 33.14577341079712, 36.17164788927351, 34.66472952706473, 37.02306277411324, 35.185437951769146, 35.41128914696829, 33.646467549460276, 34.141915798187256, 34.689604078020366, 35.51411553791591, 35.00721318381173, 37.58338982718331, 37.69290733337402, 39.96935258592878, 37.335134165627615, 41.38237994057791, 41.25442886352539, 43.52095208849226, 38.128218923296245, 39.068935530526296, 39.08348853247506, 42.85889298575265, 42.65757587977818, 38.15282596860613, 41.43538427352905, 40.088993617466514, 38.36851889746529, 36.32937894548689, 41.33700472967965, 40.5955867767334, 41.839192731039866, 42.765241691044395, 43.02998195375715, 44.28474671500069, 42.68977383204869, 49.81035723005022, 50.280524458204, 48.4712587084089, 49.13666336877005, 51.52592304774693, 51.84188543047224, 52.87578085490635, 53.303178446633474, 53.35805531910488, 56.92739357267107, 54.759218624659944, 56.566184520721436, 54.36491877692086, 57.46106038774763, 57.078697545187815, 61.21615873064314, 57.78128549030849, 72.44232845306396, 71.93070479801723, 64.2757215499878, 71.95181342533657, 42.868033340999055, 53.98196186338152, 62.19449288504464, 47.6468688419887, 11.249016267912728, 0.6428673639893532, 0.11931485975427286, 0.15690259209700994, 23.364052534103394, 65.1893332345145, 54.17142186846052, 55.20318767002651, 33.31929772240775, 20.35946559906006, 21.133210045950754, 38.02745614733015, 55.380217347826274, 27.230445384979248, 0.37130481164370266, 0.06020075322261878, 0.044817102274724414, 0.05456274129184229, 0.07376168947666883, 0.06777359079569578, 0.04897101902003799, 0.010896558241386498, 0.12783594323056086, 0.013877170043997467, 0.08902121601360184, 0.0640291835048369, 0.1872467595551695, 0.2104660921863147, 13.999366010938372, 56.346058641161235, 39.614289215632844, 45.573126861027305, 46.08041484015328, 59.32490076337542, 55.504291330065044, 75.31287942613874, 39.39213446208409, 0.09493578185460397, 0.19348206211413654, 4.17952253988811, 59.8288049697876, 70.16010924748012, 70.75937747955322, 66.83960683005196, 69.2139869417463, 66.62941687447685, 68.42288589477539, 57.63187837600708, 61.06925991603306, 60.58531788417271, 58.57010405404227, 35.86602095195225, 45.56196457999093, 63.602218764168875, 62.714857373918804, 63.2325815473284, 62.898651123046875, 63.11546271187918, 62.072843824114116, 63.80826759338379, 62.79859011513846, 60.5477420261928, 58.84002767290388, 62.15566635131836, 58.05799749919346, 50.37519366400582, 43.95962313243321, 45.385195459638325, 46.42256498336792, 45.42538036618914, 44.48177330834525, 45.497110094342915, 42.959589753832134, 44.100855691092356, 41.097514220646445, 44.436665603092735, 44.056752000536235, 45.914644718170166, 42.672295638493125, 43.33351400920323, 45.24130868911743, 46.27995320728847, 39.25511251177107, 36.382536138807026, 33.658404554639546, 42.49875743048531, 50.09287793295724, 47.14159236635481, 41.43726028714861, 44.6422905921936, 37.679556369781494, 38.75316422326224, 38.95223011289324, 39.0252799987793, 37.968135901859824, 38.72555208206177, 38.62733234677996, 38.437156677246094, 37.490026882716585, 39.3038124356951, 38.062961442129954, 39.74041291645595, 38.447936807359966, 39.677816595349995, 39.328933647700715, 41.740472725459504, 41.41109684535435, 42.42446034295218, 39.63685349055699, 38.674663475581575, 38.36338070460728, 39.360937050410676, 36.624434198652, 37.513963426862446, 37.042976311274934, 37.854275771549766, 36.28553581237793, 37.56690870012556, 36.9770587512425, 37.12127556119646, 38.13772405896868, 36.956582409994944, 35.88873808724539, 37.98375545229231, 38.21720450265067, 36.377269404275076, 38.30490466526577, 40.62732267379761, 37.98594413484846, 40.89451217651367, 37.94746848515102, 42.20941012246268, 41.96542065484183, 43.30936901909964, 38.586254596710205, 38.28283371244158, 38.84755550112043, 42.989817891802105, 44.9837771824428, 39.23536573137556, 42.24333470208304, 42.726046902792795, 40.94777359281267, 39.37189435958862, 42.41732106889997, 42.38957691192627, 44.661172321864534, 44.59879834311349, 45.238668373652864, 45.621319566454204, 46.352812017713276, 51.90369660513741, 51.971702098846436, 50.90188448769705, 51.342153617313926, 53.54297815050398, 53.18046283721924, 55.253503050122944, 54.73552526746477, 55.90000166211809, 58.859566007341655, 57.654922076633994, 57.214243003300254, 57.461466857365195, 58.855278968811035, 59.73567131587437, 61.38379791804722, 61.32655865805489, 72.82821750640869, 72.54342474256242, 67.19480569022042, 69.31037930079869, 47.316822460719514, 58.70947796957833, 65.01183455330985, 54.04900850568499, 12.862557343074254, 0.6130033550517899, 0.11936718837491103, 0.14116222171911172, 26.687494039535522, 71.57283782958984, 60.92172186715262, 60.91478756495884, 40.62983792168753, 22.364484684807913, 27.944388423647197, 45.71636397497994, 62.052200726100374, 35.71635675430298, 0.49436910663332256, 0.05650124798661896, 0.06387834517019135, 0.03209439425596169, 0.12805281659322126, 0.04843164135568908, 0.09759696905634233, 0.10987903643399477, 0.20393348272357667, 0.13613507790224894, 0.15835952891835145, 0.14961333466427668, 0.40928781777620316, 0.3943860488278525, 20.35878641264779, 71.95866434914726, 48.53906617845808, 55.65923963274275, 53.62161438805716, 71.5334415435791, 61.31128651755196, 83.73654883248466, 43.90593787602016, 0.2480609491467476, 0.6781737123216901, 6.807277398450034, 62.39856842585972, 72.03319072723389, 74.63883468082973, 69.15047345842633, 70.67205251966203, 70.21374239240373, 71.28607872554234, 62.38750689370291, 64.00961944035122, 63.91070488521031, 59.47790009634835, 41.28314924240112, 48.56585495812552, 63.86133793422154, 67.43922942025321, 65.64946378980363, 65.24687126704625, 63.66056973593575, 62.735618591308594, 66.35320513589042, 66.07016331808907, 62.95506354740688, 59.53028951372419, 64.1877920968192, 60.89918885912214, 54.34872947420393, 47.24699306488037, 47.65897260393415, 47.23887756892613, 47.776112283979145, 45.54616437639509, 50.94579362869263, 44.40219906398228, 47.35981443950108, 45.74389968599592, 47.05281523295811, 45.90069620949881, 48.08735336576189, 45.0385776247297, 45.55509975978306, 45.37076752526419, 48.683272566114155, 43.39247989654541, 38.218062605176655, 37.74871179035732, 44.870434692927766, 53.04484789712088, 47.93741818836757, 42.4939284324646, 47.20141288212368, 41.19093969890049, 40.23934916087559, 43.613422189440044, 41.726093428475515, 40.26897627966744, 43.00743504932949, 39.49260541370937, 41.92719514029366, 38.8192137990679, 41.128607409340994, 39.41191945757185, 43.28578335898263, 40.9260014125279, 40.805693353925435, 41.22339473451887, 44.22554806300572, 44.113657746996196, 45.686886242457796, 41.96351684842791, 42.232749121529714, 41.688903195517405, 40.71672861916678, 37.52672379357474, 39.674978256225586, 39.5226285798209, 39.887829371861045, 38.84205947603498, 40.571393149239675, 39.93686975751604, 41.421185629708425, 41.53827667236328, 39.40819869722639, 39.741083417619976, 40.387901646750315, 41.01945815767561, 40.04391370500837, 40.61974566323416, 41.715570381709504, 39.62775829860142, 40.74953801291329, 39.09907334191458, 42.97538995742798, 44.266785621643066, 45.749562467847554, 39.09834030696324, 40.116616180964876, 38.104806968144004, 44.85174751281738, 46.10961811883109, 40.35219138009207, 43.42474038260323, 46.12016201019287, 43.154153210776194, 41.594994817461284, 44.822283676692415, 44.89718525750296, 46.672700132642476, 46.13209901537214, 47.93064022064209, 48.13588653291975, 47.229803221566335, 55.170760427202495, 54.76623283113752, 52.60722255706787, 53.063545499529155, 56.35282618658883, 56.23741660799299, 59.17696666717529, 58.50461033412388, 57.85022551672799, 60.30912004198347, 60.72715146200997, 59.79317460741316, 59.553211620875764, 61.66630472455706, 62.420816557747976, 63.070591245378765, 64.44828701019287, 77.18693365369523, 70.67188576289585, 68.15057209559849, 70.03500693184989, 55.79878030504499, 60.95347513471331, 67.74601323263985, 58.11460099901472, 14.106508101735797, 0.8750047790152686, 0.4909312682492392, 0.27429558283516337, 30.954464435577393, 79.18882083892822, 65.65459156036377, 69.42426722390312, 50.10962656566075, 29.863524300711497, 31.407056195395334, 53.13882228306362, 69.23911162785122, 46.175302914210725, 0.556475145476205, 0.18106750398874283, 0.097217199791755, 0.10103254113346338, 0.2493162660726479, 0.2046980695532901], [0.0032480292388104965, 0.047011671122163534, 0.07918822579085827, 0.04096910982791867, 0.06002874459539141, 0.030828444686319147, 0.1135241672662752, 0.1880916306482894, 7.11804643699101, 38.04767540522984, 32.85916369301932, 43.48166697365897, 34.08171313149588, 49.36580106190273, 50.958491461617605, 70.86132144927979, 35.097122873578755, 0.15787186580044882, 0.22074120225650923, 4.507137051650456, 64.50371279035295, 68.00708484649658, 70.1701146534511, 65.03976631164551, 68.18770326886857, 63.675348554338726, 65.17228930337089, 65.95628234318325, 61.97950867244175, 63.828757831028526, 65.69616958073208, 63.43085534232003, 58.150123664310996, 55.20028679711478, 57.208163329533164, 57.63168035234724, 61.5547513961792, 61.34428351266043, 57.24719483511788, 57.688280378069194, 59.47193159375872, 58.13644960948399, 55.37972749982561, 55.39284222466605, 54.70242057527815, 48.49996171678816, 42.41165133884975, 44.64862387520926, 41.61106947490147, 43.06582771028791, 41.93332692555019, 41.30204834256853, 42.64036866596767, 40.49752337591988, 42.04511301858084, 41.77251781736101, 39.78599309921265, 40.019313607897075, 40.596226011003765, 41.77735028948103, 44.57955878121512, 45.71886532647269, 45.13166264125279, 38.856244223458425, 33.26154082162039, 38.74628203255789, 42.86117199489048, 42.11902448109218, 42.550476346697124, 41.97598539079939, 42.06741673605782, 40.193491050175254, 36.438580308641704, 37.05880083356585, 35.400981494358604, 38.006142548152376, 37.3608147076198, 36.736585072108674, 36.48798547472273, 38.039337566920686, 36.41755853380476, 36.47003132956368, 37.23008435113089, 37.71231017793928, 37.22676658630371, 36.15365900312151, 35.57723644801548, 35.53935834339687, 38.47823095321655, 34.94780261175973, 37.20122848238264, 37.58694383076259, 34.12246084213257, 34.51097284044538, 33.99476337432861, 32.29577943256923, 34.160102707999094, 33.103861876896445, 36.68966736112322, 35.49510179247175, 34.520286900656565, 35.324870926993235, 33.39066614423479, 36.28105075018746, 34.986476285117014, 37.07461493355887, 37.22560971123831, 38.98651599884033, 36.841992718832834, 39.51478058951241, 43.82822922297886, 43.84206656047276, 38.66345255715506, 34.28299897057669, 29.81460898263114, 36.17202309199742, 35.76028673989432, 42.10864039829799, 41.87774133682251, 40.652850355420796, 39.57654660088675, 39.2226505279541, 37.97660575594221, 38.459349223545615, 39.10699776240757, 43.06685604367937, 41.60303040913173, 40.73965767451695, 40.68668113436018, 44.52415384565081, 48.71681499481201, 50.846215520586284, 52.829794202532085, 53.51527220862252, 53.935634749276296, 51.280609948294504, 52.69890056337629, 52.82429470334734, 52.613976206098286, 53.6160558291844, 54.950120380946565, 55.079676491873606, 58.67479256221226, 58.29550429752895, 56.92474283490862, 61.039285387311665, 59.70637076241629, 64.13801520211356, 58.973238536289756, 73.26737145015171, 61.152520179748535, 39.75448301860264, 55.915885244097026, 60.25280489240374, 57.73667458125523, 53.22240216391427, 18.3171329498291, 0.3349796565515654, 0.1932331347571952, 0.28200680762529373, 14.685632637568883, 62.634723799569265, 52.59207201004028, 56.07082312447684, 36.38900143759591, 16.814948047910416, 30.27593810217721, 43.593261991228374, 52.2331280708313, 31.730324608939036, 0.864371158182621, 0.061463486536272934, 0.1270485304828201, 0.026470483979210258, 0.09540116188249417, 0.05885661606277738, 0.052960367274603674, 0.03980003809556365, 0.038249168278915543, 0.06131574910666261, 0.00958677870221436, 0.03911709599196911, 0.055071496670799594, 0.2816280765192849, 13.104673402650015, 51.45984220504761, 40.6192558152335, 44.994696276528494, 35.578952653067454, 54.54225764955793, 56.65785557883126, 77.07991749899728, 38.72999892915998, 0.26159481863890377, 0.33635029728923527, 5.39861307825361, 68.9035553250994, 70.40605463300432, 72.80595547812325, 67.27820491790771, 69.36950847080776, 66.14142404283795, 66.57124655587333, 67.83394963400704, 65.92448738643101, 64.33250222887311, 67.49127837589809, 64.83522524152482, 59.659699712480815, 54.471497195107595, 59.907187598092214, 60.85313619886126, 62.80473927089146, 63.08330644880022, 61.289121764046804, 58.672728947230745, 61.95325837816511, 60.281084060668945, 56.86558934620449, 58.133753708430696, 58.07036876678467, 52.086128507341655, 43.42808246612549, 47.48923853465489, 44.61194780894688, 45.26250764301845, 44.65521771567208, 43.14456122262137, 45.17573159081595, 42.863847051348, 42.81864207131522, 43.802548680986675, 41.75328172956194, 42.74301092965262, 43.028793811798096, 43.81251587186541, 46.24429505211966, 47.752092361450195, 45.07381888798305, 39.91163737433297, 36.14601251057216, 41.7064265523638, 44.44555582318987, 43.16834143229893, 44.52373695373535, 44.45653050286429, 42.52340269088745, 42.25726236615862, 37.7906094278608, 38.993436404636924, 37.65717274802071, 40.37512738364083, 38.323897566114155, 39.35518046787807, 39.35252973011562, 38.13588278634207, 39.658229623522075, 39.711223534175325, 40.14730984824044, 39.47000987189156, 40.057122230529785, 38.32750368118286, 38.17399712971279, 38.15139463969639, 40.00993701389858, 36.82125929423741, 39.67679868425642, 38.95418603079659, 37.1537583896092, 36.35697371619088, 35.23430463245937, 35.53225381033761, 36.72437361308506, 36.13139697483608, 38.715070724487305, 38.96957976477486, 35.748714515141074, 35.657269273485454, 36.5854617527553, 37.83250706536429, 37.58321264811924, 38.381178515298025, 40.19279275621687, 40.3653130531311, 36.030634198869976, 40.59621211460659, 43.943937574114116, 44.77366713115147, 41.009800161634175, 37.07088375091553, 30.36403431211199, 36.927483354296, 36.909932204655235, 43.39043712615967, 44.162656443459646, 41.22750459398542, 41.75637020383562, 40.422639165605815, 40.19446379797799, 39.66493810926165, 41.77400125776018, 44.23842307499477, 42.54034239905221, 42.92039843967983, 41.69193261010306, 47.547686781202046, 51.476990359170095, 52.48457990373884, 55.84017072405134, 55.71731962476458, 55.191528592790874, 54.35907186780657, 55.237011500767295, 53.35606118610927, 54.952187470027376, 55.39202928543091, 57.06125061852591, 58.10742698396955, 61.1327942439488, 60.831680161612375, 60.7821603502546, 63.880980491638184, 63.55088547297886, 66.94681058611188, 61.341518129621235, 71.38919694083077, 58.8364701952253, 43.24415670122419, 61.86419636862618, 61.67252336229597, 60.790011814662385, 58.420655250549316, 22.055501767567225, 0.42965054512023926, 0.1693502084485122, 0.3760203314679009, 16.738889592034475, 70.83577987125942, 61.12569318498884, 63.283761978149414, 43.550276960645405, 17.317808287484304, 32.137138162340435, 50.02723830086844, 61.73486260005406, 40.35612406049456, 0.7542272827454976, 0.03982429572248033, 0.12618140344108852, 0.06451031233050994, 0.15388848526137217, 0.01695398284521486, 0.167689887540681, 0.10219511589301483, 0.13467857534331934, 0.20724705420434475, 0.18864750010626657, 0.10114251130393573, 0.16900382989219256, 0.35022446566394394, 20.489987509591238, 67.18157632010323, 49.1666761125837, 56.79648603711809, 43.68958139419556, 64.60899189540318, 63.109952790396555, 82.54730905805314, 41.525485038757324, 0.5310220484222684, 0.6949101313948631, 6.127077417714255, 72.75221811022077, 72.76657308850969, 77.44648361206055, 70.27244772229875, 73.28527695792062, 68.0062997000558, 68.4802085331508, 69.69407272338867, 67.8140013558524, 67.64640385763985, 69.97932406834194, 66.08517142704555, 60.82314082554409, 57.448303495134624, 61.333062171936035, 62.6474528993879, 63.95529842376709, 63.93269593375069, 62.13588482992989, 62.2301093510219, 64.25490474700928, 63.6364803314209, 59.72343553815569, 61.005454608372276, 60.7658668245588, 54.96043150765555, 45.34047337940761, 49.33793878555298, 46.13368667875017, 48.44722488948277, 45.55094126292637, 43.77549239567348, 46.29438808986119, 44.98323522295271, 45.022301469530376, 47.860293184007915, 43.63446133477347, 43.73156935828072, 45.422719206128804, 46.13423558643886, 49.7687931060791, 49.261703150612966, 46.85531268801008, 41.733399459293906, 39.57952042988369, 43.47254746300833, 45.57353680474417, 45.66299138750349, 43.86095176424299, 43.15849583489554, 44.89994716644287, 44.19196741921561, 41.79563099997384, 42.45740870067051, 39.958284105573384, 42.865538937704905, 41.8381678717477, 40.95440217426845, 42.070772715977256, 41.32739537102835, 41.94489915030343, 43.22660902568272, 42.8288038117545, 42.435869285038535, 42.390240464891704, 39.56005505153111, 41.02406481334141, 39.9891688483102, 42.43991313661848, 38.64314644677298, 42.34567124502999, 40.54227672304426, 39.59730087007795, 39.981522355760845, 40.761874539511545, 36.602220807756694, 38.39530767713274, 38.8882372038705, 41.925013405936106, 41.119244711739675, 37.04527963910784, 38.18355437687465, 39.48027583530971, 41.23916367122105, 39.77344812665667, 41.8295590536935, 43.50320986339024, 40.880990982055664, 37.380043847220286, 41.58870322363717, 45.957845142909456, 48.12840332303728, 43.99712603432791, 39.67821959086827, 33.318432671683176, 37.86703961236136, 37.121456214359824, 43.77227190562657, 47.52959367207119, 44.392419474465505, 42.87135110582624, 42.90417092187064, 42.557191780635286, 43.18887683323452, 43.374022006988525, 46.26856163569859, 45.552900654929026, 44.821898051670615, 44.07036004747663, 49.3700464112418, 54.27072204862322, 55.35185827527727, 60.10792800358364, 57.71384974888393, 57.502026966639924, 55.31670733860561, 57.482620647975374, 56.65262358529227, 56.80810342516218, 55.62586048671177, 62.2693875176566, 58.53637054988316, 64.80230467660087, 61.58539990016392, 64.37817273821149, 64.76754978724888, 65.94328921181815, 67.81142357417515, 70.51441179003034, 71.95289039611816, 58.7789808000837, 48.81767504555838, 63.364548683166504, 64.8601553780692, 66.09830352238247, 62.187357085091726, 25.598839862006052, 0.6265112502234322, 0.3436841751847948, 0.42148728030068533, 19.66596589769636, 78.82923071725028, 65.28544766562325, 72.012193271092, 52.05579962049212, 24.47008068220956, 41.17639364515032, 58.819252559116904, 69.65617724827358, 50.80476604189192, 0.8852868101426533, 0.2392911554447242, 0.2671775333583355, 0.14786626983966145, 0.26714252095137325, 0.18110308636512074], [0.017918126823912774, 0.030753412283957005, 0.07035457515822989, 0.025345325336924622, 0.054165435289697986, 0.12286281080118247, 0.05008150264620781, 0.2899818739720753, 12.856507199151174, 38.45302636282784, 35.224365234375, 32.93994344983782, 35.534595353262766, 44.01308952059065, 53.435836928231375, 69.47314085279191, 25.68718794413975, 0.026029341222186173, 0.15045129827090672, 4.2702621051243375, 62.09116622379848, 64.97908769335065, 68.01155253819057, 63.26465443202427, 64.89624432155064, 64.46790177481515, 66.23109749385289, 61.061735016959055, 62.07766587393624, 61.57631165640694, 63.36063684735979, 58.07224825450352, 54.477173873356406, 55.32025439398629, 55.80982446670532, 57.61435849325997, 58.9314729145595, 57.13435609000069, 56.18628134046282, 55.895690304892405, 58.380411284310476, 55.34339189529419, 59.26315212249756, 55.797658170972554, 53.1416779926845, 44.921611649649485, 43.498248849596294, 42.28389481135777, 42.23500381197248, 42.86367334638323, 41.354187624795095, 40.27822085789272, 41.921768597194124, 40.940022877284456, 38.63420411518642, 38.70044824055263, 40.720147132873535, 38.209280082157676, 42.249126025608604, 43.48944895608084, 43.8115222794669, 45.22046061924526, 44.85136536189488, 41.76094559260777, 41.234341621398926, 37.30610806601388, 35.57756648744856, 38.94269371032715, 41.5102858543396, 44.67541265487671, 41.54427644184658, 44.74907398223877, 37.740697043282644, 37.93164048876081, 36.253136362348286, 35.72666788101196, 37.256775856018066, 37.660869189671104, 36.96011209487915, 36.36454030445644, 35.4478714125497, 37.8049817766462, 37.401180267333984, 40.113305364336284, 39.34522369929722, 38.051976340157644, 38.206493854522705, 38.126315116882324, 37.55318948200771, 34.732616901397705, 35.84668411527361, 35.09234251294817, 36.59104115622384, 33.58604948861258, 34.48061268670218, 34.770922320229666, 35.23145587103707, 35.960770062037874, 34.85725368772234, 35.77848754610334, 35.87770087378365, 34.724779333387104, 36.39866985593523, 34.46249178477696, 34.64724785940987, 39.26397493907383, 42.99329546519688, 40.489807401384624, 39.365196296146934, 38.04304095676967, 42.56559215273176, 38.272651127406526, 39.08825847080776, 41.181438037327354, 36.062001841408865, 35.0405193737575, 35.291349342891145, 42.988264969417024, 40.19793094907488, 39.899346011025564, 39.83831303460257, 38.861955642700195, 38.5907882962908, 37.043518270765034, 39.32763433456421, 40.23699024745396, 41.36479752404349, 40.09682076317923, 43.27008390426636, 47.58456781932286, 53.53279209136963, 57.380259786333355, 56.56363453183855, 52.99791281563895, 54.44775520052229, 53.846666540418354, 53.54339851651873, 54.90520027705601, 56.8944799559457, 55.99224247251238, 56.83551754270281, 57.807966572897776, 57.33337681634085, 60.11111027853829, 58.45632035391671, 60.176638739449636, 63.816410882132395, 62.40469673701695, 57.03940895625523, 44.973858628954204, 58.039511816842214, 57.76726055145264, 60.2093300138201, 62.154617173331125, 61.04919351850237, 49.1985752923148, 32.28716714041573, 1.6139841313873018, 0.22931226662227086, 0.38088472187519073, 8.334097572735377, 59.990461758204866, 51.530533177512034, 56.41007586887905, 41.82113783700125, 33.221446241651265, 25.676312276295253, 37.09143304824829, 53.31380224227905, 40.71774305616106, 1.037969348686082, 0.0395680741140885, 0.07974520126091582, 0.14184858703187533, 0.05499113776854106, 0.04119600515280451, 0.032857698654489856, 0.07929958695811884, 0.04651283931785396, 0.08018905137266431, 0.016132575493039827, 0.10449999078576054, 0.09153252840042114, 0.3300899975001812, 20.76601164681571, 52.12915522711617, 43.27202592577253, 39.11148977279663, 35.64425182342529, 50.67316716057913, 58.55280998774937, 73.7874093736921, 27.90849576677595, 0.03418236864464624, 0.22094181792012282, 5.259693835462842, 65.70211029052734, 66.03761100769043, 71.18899849482945, 65.97630705152238, 69.86677019936698, 64.95687430245536, 66.96204103742326, 62.63641916002546, 64.25716985974992, 62.8139317376273, 66.53642218453544, 59.031061444963726, 57.62509346008301, 55.80708687646048, 57.87685101372855, 58.442451749529155, 59.77686718532017, 56.299693311963765, 56.96422249930245, 56.51813077926636, 60.370764459882466, 58.04025527409145, 60.645760263715474, 57.59185675212315, 54.301999364580425, 47.56340708051409, 45.55469329016549, 43.857602732522146, 44.16597073418753, 43.555095536368235, 43.49649095535278, 42.06883069447109, 43.28009625843593, 42.05972508021763, 40.147170884268625, 40.70627505438668, 43.1914997782026, 40.370750018528526, 44.8375176021031, 46.6189558165414, 44.332529476710725, 47.61369814191546, 45.94498402731759, 40.98351512636457, 43.31477471760341, 40.60629742486136, 39.49005889892578, 40.761916228703086, 46.11669485909598, 44.34885079520089, 42.32461820329939, 46.63054888589041, 41.86725650514875, 37.987715925489155, 37.95133168356759, 37.92352499280657, 40.10155943461827, 38.115382126399446, 38.65636886869158, 39.85886580603463, 38.248141356876914, 40.41187640598842, 38.761779989515034, 41.69543102809361, 41.07102073941912, 40.565845012664795, 39.58728156770979, 40.027262347085134, 39.01451029096331, 37.035635539463584, 39.33277252742222, 36.97366108213152, 38.97921691622053, 35.87587349755423, 36.16908400399344, 36.82231889452253, 36.59052351542881, 37.90737043108259, 37.65235417229788, 37.47317055293492, 38.28174979346139, 36.567820276532856, 36.54879263469151, 37.25506659916469, 36.26720299039568, 42.824534143720356, 45.01409217289516, 41.85366235460554, 41.60776560647147, 37.760120732443674, 44.998298917497905, 41.62936060769217, 40.38207905633109, 40.07643474851336, 35.94241639545986, 35.268152781895225, 34.653449126652305, 44.85814332962036, 42.98278284072876, 41.24176924569266, 41.41857310703823, 39.195246832711355, 40.19947692326137, 38.37056861604963, 41.37991680417742, 42.345831053597585, 42.8724558694022, 42.920975140162874, 43.40120335987636, 50.87120124271938, 55.65247556141445, 58.25579881668091, 60.015586444309776, 56.510289737156455, 57.26062222889492, 55.401562213897705, 55.45273222242083, 56.305825097220286, 58.00833177566528, 57.64789397375924, 60.39906447274344, 58.779328210013254, 60.20959404536656, 62.721583230154856, 60.95156438010079, 62.445281164986746, 65.4305260522025, 62.10247789110456, 59.2472893851144, 48.60999686377389, 57.08684778213501, 60.74167319706508, 64.2562665939331, 65.99051611764091, 65.66925920758928, 54.77384805679321, 38.57389027731759, 1.5003028086253574, 0.11347111939851727, 0.26745491847395897, 9.732221041406904, 68.78496347154889, 57.10699755804879, 63.315251214163645, 46.047911167144775, 31.732773848942347, 35.07586833408901, 45.46419995171683, 60.60145160130092, 52.18191984721592, 1.117197920169149, 0.11284502835146018, 0.011567664997918265, 0.04764074093795248, 0.02520087032046701, 0.023909323017245958, 0.172714127227664, 0.26477085107139176, 0.14437218090253218, 0.1779138089290687, 0.14007144953523362, 0.2759974572275366, 0.23229152389935084, 0.6412470766476223, 30.64436285836356, 66.48924391610282, 52.67558240890503, 48.52248082842146, 50.453260149274556, 59.84925351824079, 63.94416046142578, 82.47841766902378, 33.810121944972444, 0.14826801685350283, 0.4938806699854987, 7.232589662075043, 69.10996546064104, 68.90553556169782, 74.60936042240688, 69.920090675354, 71.6528880255563, 67.96166447230748, 71.35664463043213, 64.48266669682094, 66.8846103123256, 65.23715768541608, 68.13179806300572, 61.4180177961077, 57.34421253204346, 56.46920851298741, 59.446855545043945, 60.24555097307478, 61.32814284733364, 58.25908531461443, 58.40634890965053, 57.93986770084926, 61.64133984701974, 59.74803910936628, 63.73092024666922, 60.70265906197684, 56.64193378176008, 49.2419251033238, 48.194616181509836, 45.42543942587716, 47.337059089115684, 45.6643636567252, 46.07683999197823, 44.032030309949604, 46.36306755883353, 43.16680588041033, 44.28755031313215, 42.492365087781636, 45.45016459056309, 41.92694500514439, 47.3494234085083, 49.92056955610003, 48.08771814618792, 49.256728240421836, 45.40663412639073, 40.02551140104021, 44.33513157708304, 43.61327975136893, 42.202580043247764, 42.63802364894322, 47.56809711456299, 46.08338866915022, 42.09491423198155, 49.13613530567714, 43.97831378664289, 41.531401429857524, 41.603280544281006, 40.98278209141323, 43.481184073856895, 42.47184705734253, 41.33875914982387, 44.12630694253104, 38.88965116228376, 42.6789276940482, 42.289946692330496, 44.92402614865984, 45.06550884246826, 42.499532154628206, 41.50796863010952, 42.00956950868879, 42.03092132295881, 39.73997517994472, 41.80253056117466, 40.365889753614155, 43.391152790614534, 35.710687024252756, 40.14485018593924, 40.52457618713379, 40.54661239896502, 39.31812572479248, 40.3676233291626, 41.63652420043945, 42.23210293906075, 38.83951990944998, 40.54081760134016, 39.78454439980643, 41.13456201553345, 44.1203419140407, 45.05143526622227, 40.93743119921003, 42.37426308223179, 39.91163042613438, 46.27488797051566, 43.49751581464495, 41.15820673533848, 42.53180306298392, 37.61035578591483, 35.45557001658848, 35.072046824863975, 47.105083056858604, 44.76287657873971, 43.38652181625366, 45.145510401044575, 43.05044092450823, 42.17629848207746, 41.546888964516775, 44.087595054081504, 42.506588050297324, 44.82876634597778, 42.78343207495553, 45.797428607940674, 51.064600876399446, 57.36391067504883, 59.26678603036063, 59.962995529174805, 57.19534042903355, 59.49543734959194, 57.468171869005474, 58.22578607286726, 58.129963466099326, 61.672175952366416, 60.03991903577532, 61.87582070486886, 61.028675488063264, 62.37397180284773, 65.31050286974225, 63.202968324933735, 64.37123843601772, 67.75725541796002, 65.28152193341936, 61.917169434683665, 55.966888495853965, 61.09069510868618, 56.998122760227744, 70.02169418334961, 67.57758889879499, 67.76194545200893, 58.749589920043945, 41.679530075618196, 1.4829764983483722, 0.3077161195022719, 0.4946575111576489, 11.324277418000356, 76.29559094565255, 65.32315553937639, 69.24076529911586, 56.71825974328177, 47.63733243942261, 33.18533297947475, 53.22494520459856, 67.44389166150773, 61.081078801836284, 1.63121012704713, 0.24344691101993832, 0.14942398268197263, 0.350780402975423, 0.1837997066655329, 0.20891931732850416], [0.013744369714653917, 0.06529160469238247, 0.018603554062013115, 0.07383436736251626, 0.03646779672375747, 0.10134744245026793, 0.05035608201952917, 0.4912033336503165, 13.802881377083914, 43.636618750435964, 39.36855922426496, 28.76795666558402, 30.08983060291835, 45.307459013802664, 53.38813754490444, 69.55105100359235, 13.677879810333252, 0.16903375328651496, 0.04604143050632306, 4.049369318144662, 61.0915219443185, 62.08654567173549, 70.66579219273159, 64.25207683018276, 67.12806824275425, 64.1810940333775, 64.69223826272147, 65.11994852338518, 64.21625191824776, 59.88622488294329, 62.17125810895647, 59.032277379717144, 61.13566384996687, 60.31831250871931, 62.398971421378, 60.44725717817034, 61.70386668613979, 59.501093183244976, 57.95919064113072, 56.92686550957816, 57.7156389100211, 54.44569853373936, 55.20879486628941, 50.98895583833967, 45.01989391871861, 42.451280389513286, 43.403280871255056, 43.271796635219026, 42.86411803109305, 42.553307737622944, 40.996299811771934, 40.804466996874126, 43.03565863200596, 41.67697661263602, 40.24304560252598, 38.99889421463013, 39.40923397881644, 38.09556586401803, 40.04770394733974, 41.7267951965332, 40.87691586358206, 44.83455072130476, 44.45205586297171, 38.604733330862864, 42.6047556740897, 43.299620696476524, 35.726129395621165, 43.075364112854004, 43.65061937059675, 44.37957225527082, 42.77751915795462, 41.70621115820748, 43.326051643916536, 35.157655579703196, 34.38762147086007, 36.57806886945452, 36.41761759349278, 36.28430945532662, 36.39967734473092, 36.500005858285085, 39.61402518408639, 35.53351838248116, 38.831748349326, 36.46299627849034, 38.74785927363804, 37.86629268101284, 37.71347747530256, 34.86576523099627, 35.22891630445208, 34.927222047533306, 38.30374084200178, 35.875758852277485, 36.655113969530376, 34.94978979655674, 33.89871495110648, 33.34922708783831, 36.30033894947597, 35.288253920418875, 35.861066886356895, 33.525374344417024, 33.56771319253104, 35.517117159707205, 34.78870276042393, 36.64182553972517, 40.50013589859009, 42.597821371895925, 42.77845369066511, 41.3381199155535, 41.946285315922324, 40.055440766470774, 42.13102054595947, 40.54296459470476, 40.46710763658796, 39.413941383361816, 36.209202902657644, 35.85900674547468, 35.5621588570731, 39.44514921733311, 38.719573157174246, 37.599051066807334, 37.066680090767996, 36.015309946877615, 36.72766011101859, 36.44969742638724, 40.106412751334055, 42.374593121664866, 41.56141069957188, 40.5994291305542, 48.53846515927996, 51.13885627474104, 53.95769875390189, 52.87526321411133, 49.601622922079905, 56.82705116271973, 55.8959994997297, 56.41205610547747, 55.83330590384347, 53.9373266356332, 55.514428751809255, 54.044169085366384, 56.90405804770333, 56.5669766153608, 59.87344714573452, 60.20434120723179, 60.300198554992676, 59.96448939187186, 57.90852090290615, 55.46614571980068, 60.701088769095286, 56.759921142033164, 53.57432842254639, 65.2220106124878, 66.27288396017892, 61.36717782701765, 61.783826555524556, 58.105703830718994, 43.09504835946219, 5.43459779875619, 0.0887392982840538, 0.36194363396082607, 4.372137461389814, 58.85508441925049, 54.43505736759731, 56.50138562066214, 49.591099875313894, 28.469778197152273, 18.421725920268468, 39.47548157828194, 48.45837674822126, 49.257416112082346, 2.417979189327785, 0.2765820829996041, 0.05321328781012978, 0.026664529727505784, 0.037762828304299285, 0.041133264412305186, 0.023235875314899852, 0.0806124707950013, 0.020889396047485725, 0.10419817162411553, 0.04485503238226686, 0.0968251151165792, 0.10197511448391847, 0.6721419702683176, 21.101706913539342, 56.205117906842915, 45.4261029788426, 36.59603691101074, 33.59938655580793, 50.02360439300537, 58.99127605983189, 75.70995507921491, 15.079887322017125, 0.15751887831304753, 0.01916497224010527, 5.116603936467852, 66.02265153612409, 64.89249229431152, 73.3782855442592, 65.96920599256242, 70.32540689195905, 65.62839685167584, 67.81613445281982, 65.68074457986015, 64.3460442679269, 62.40383516039167, 63.15099579947335, 59.5890017918178, 62.57857540675572, 63.137384278433665, 62.97927107129778, 63.08284786769322, 63.35204192570278, 61.213900566101074, 61.93267086574009, 59.525335448128835, 60.240687234061106, 56.24764435631888, 55.69903891427176, 53.1546676499503, 48.13641112191336, 42.74565124511719, 44.415529182979036, 44.679619789123535, 44.276130948747905, 43.30558225086757, 43.1267078263419, 42.26731988361904, 44.352192878723145, 43.70069851194109, 43.47440610613142, 41.856188024793354, 41.78362103870937, 40.158746583121165, 42.14307567051479, 43.571628774915425, 42.4459684916905, 46.13613591875349, 45.73806667327881, 38.00456878117153, 42.75027527127947, 42.64817149298531, 39.09397683824812, 43.804014750889365, 45.19313335418701, 44.14218357631138, 43.41687502179827, 41.63193491527012, 43.83591740471976, 37.95157487051827, 36.6870687348502, 38.26254844665527, 38.95761844090053, 38.82397331510271, 38.910638196127756, 37.481376375470845, 40.56995487213135, 37.78955330167498, 39.73085566929409, 38.41896629333496, 41.24001482554844, 38.993877615247456, 38.35632133483887, 36.53436470031738, 38.24553230830601, 36.80419799259731, 39.546116965157644, 38.539878845214844, 39.616957323891775, 36.571256160736084, 38.106745515550884, 35.83149882725307, 37.08462381362915, 37.95090784345354, 38.02097347804478, 36.61976153509957, 37.95846400942121, 37.913154806409565, 38.23159074783325, 38.678891454424175, 43.3759640284947, 43.415061541966026, 42.36758238928658, 40.96815613337925, 40.36945417949131, 41.570366927555625, 42.9195681299482, 40.9283082144601, 41.681416511535645, 41.31540278026036, 36.22701460974557, 35.30192450114659, 36.66319472449166, 41.76778262002127, 40.845721926007954, 40.4615421295166, 39.700307914188926, 38.96585553033011, 38.153628485543386, 38.72985301698957, 41.423947538648335, 43.98897927148001, 44.482561928885325, 43.04329817635672, 49.89628560202462, 54.27237571988787, 56.48996278217861, 53.10015903200422, 51.4542350087847, 58.63846737997872, 58.70259230477469, 57.59718949454171, 58.934384209769114, 55.89867108208792, 58.58139487675258, 56.707820074898855, 57.859699385506765, 60.38704408918108, 63.89417512076241, 61.4147938319615, 63.027012143816265, 60.10737214769636, 59.77654756818499, 58.160302775246755, 63.26263945443289, 58.49342373439244, 57.57732112067086, 65.47224998474121, 69.4536303111485, 63.91367176600865, 66.44588715689522, 61.8729441506522, 49.11070837293352, 6.275602110794612, 0.04114017189879503, 0.2308787325663226, 4.499187009675162, 66.52129595620292, 60.45087718963623, 64.51481601170131, 54.92149380275181, 30.1832560811724, 10.897533825465612, 48.62110355922154, 55.36199222292219, 60.75138677869524, 3.1211525201797485, 0.3930780775845051, 0.07085882167198829, 0.10642859086926494, 0.00846983542266701, 0.056465105818850655, 0.07405758502760104, 0.2601688637265137, 0.12255789073450224, 0.19505677904401506, 0.09177806986761944, 0.16144489550164767, 0.1648696788719722, 0.775613078049251, 32.54271841049194, 67.78019836970738, 59.30265957968575, 41.133599690028596, 43.78426797049386, 63.80096503666469, 62.83062131064278, 83.85737105778286, 19.34261757986886, 0.3566540192280497, 0.11870428680309228, 5.665928951331547, 70.3096205847604, 67.82924570356096, 79.34168120792934, 70.38507802145821, 73.60622814723423, 68.92071042742047, 70.7745315006801, 69.03171484810966, 67.17720590318952, 64.28427478245327, 64.53099141802106, 60.15232004438128, 66.07010078430176, 64.36568682534354, 66.0745962687901, 64.70263276781354, 66.75793770381382, 63.557173592703684, 63.72140121459961, 61.655764307294575, 62.66112000601632, 59.0608275277274, 59.75980935777937, 55.24047865186419, 51.13511119570051, 46.01969105856759, 48.74244689941406, 48.663866247449604, 46.57758971623012, 45.43945394243513, 44.38261209215437, 45.063813482012065, 46.5247278213501, 45.83421237128121, 45.65756484440395, 44.48563650676182, 44.2738310950143, 42.60110092163086, 44.593729632241384, 44.61013432911464, 44.76563501358032, 47.570879868098665, 47.25231538500105, 39.0381098474775, 42.01372453144619, 44.44897781099592, 41.66744368416922, 45.614958490644185, 46.03241321018764, 46.357929365975515, 42.67842394965035, 43.06508077893938, 45.251970699855256, 40.966735226767405, 37.92873614174979, 41.07824339185442, 41.14515107018607, 40.46850422450474, 41.77337939398629, 40.78721809387207, 42.253089972904746, 41.239674363817485, 42.09524079731533, 40.400213854653494, 44.174523966653005, 43.5492833682469, 41.864411217825754, 39.485035351344514, 40.129091671534944, 40.35995946611677, 42.086430481501985, 40.72695984159197, 41.62613664354597, 40.51463678904942, 39.92761475699288, 39.00264624186924, 40.10483203615461, 40.9737355368478, 40.964126178196494, 39.886724608285085, 39.30711283002581, 40.53861502238682, 40.25603525979178, 43.86189324515206, 44.17550366265433, 45.30459983008248, 42.99661670412336, 43.997264998299734, 42.818742820194785, 41.48511600494385, 44.366266454969136, 41.5374185698373, 43.87430967603411, 40.09074108941214, 36.48360810961042, 35.35960497174944, 36.952079977308, 44.71380145209176, 42.832180636269705, 41.994342531476704, 43.20042126519339, 41.76556961877005, 41.321069036211284, 41.72839675630842, 44.30675860813686, 46.06800535746983, 47.410859380449565, 44.509100573403494, 53.22923571722848, 55.86847768511091, 57.21140813827515, 57.68556015832083, 56.843900544302805, 59.654829025268555, 60.977293559483115, 60.26884133475167, 59.96505914415632, 57.33179610116141, 61.8623411996024, 56.65741089412144, 60.44688892364502, 60.93237345559256, 65.23913097381592, 63.6918157849993, 65.61008140019008, 61.203061376299175, 61.89569255283901, 58.878604071480886, 65.28341879163469, 59.99900804247175, 62.69491604396275, 66.46400111062187, 69.08208233969552, 68.34700461796352, 71.66774327414376, 63.302139963422505, 54.19191905430385, 6.99078540291105, 0.09902052195476634, 0.48419352407966343, 5.286236822605133, 74.43068749564034, 66.39788900102887, 73.2677674974714, 66.08831201280866, 40.997484479631694, 26.697054760796682, 59.30919088636126, 63.19957760402134, 72.18165983472551, 4.195691432271685, 0.5177739507385662, 0.2052884493023157, 0.23748318531683513, 0.1192266366311482, 0.12393382404531751], [0.03287834647510733, 0.06187762359955481, 0.05465144956750529, 0.028618279711476395, 0.07909599252577339, 0.090371202145304, 0.06498000105576855, 0.5031655260494777, 14.535758256912231, 46.490233489445274, 33.682261194501606, 28.62481335231236, 26.159163440976823, 47.527234758649556, 58.71723910740444, 60.567912646702354, 3.361570179462433, 0.09280809281127793, 0.1282602718898228, 4.369356444903782, 53.55028418132237, 60.602806500026155, 66.54445430210659, 65.73731681278774, 65.22689519609723, 63.4709256035941, 65.35110119410923, 62.81603009360177, 60.85788181849888, 59.83173016139439, 58.833058629717144, 57.356232915605815, 61.115243094308035, 60.53923743111746, 58.38572665623256, 56.93323005948748, 57.910396916525706, 57.696788447243826, 57.83349078042166, 57.31878559929984, 53.034776483263286, 50.482588495527, 49.2576766695295, 43.74471535001482, 41.558902399880544, 41.807401248386924, 42.580645424979075, 40.7144113949367, 42.10263020651681, 42.182711669376914, 44.564008712768555, 41.152464049203054, 42.115939480917795, 41.722098214285715, 39.50687006541661, 38.776631764003206, 39.433816705431255, 38.97320672443935, 40.47863817214966, 41.892110211508616, 42.59911373683384, 44.6611966405596, 45.753224168504985, 41.09813608442034, 41.166888509477886, 40.16648687635149, 41.4509517124721, 39.4299430847168, 47.20703744888306, 44.69996758869716, 43.19409145627703, 43.161261217934744, 45.093388489314485, 44.331799915858674, 36.49620519365583, 35.47666474751064, 35.64811502184187, 35.12359203611101, 35.3205109323774, 33.97239364896502, 36.02172660827637, 36.559242725372314, 36.77425820486886, 37.912991523742676, 38.53576898574829, 38.48155566624233, 37.236365522657124, 36.266271931784495, 35.1770966393607, 36.16750676291329, 37.034238951546804, 35.01878193446568, 36.98307589122227, 34.94969946997506, 36.6152834211077, 35.84782361984253, 36.50937897818429, 35.43597609656197, 36.149305956704275, 34.817767075129915, 34.57143259048462, 35.1412022454398, 36.46928439821516, 37.49539089202881, 38.24387168884277, 39.78625018256051, 41.84833656038557, 39.72290345600673, 40.53754152570452, 39.11414745875767, 36.71092537471226, 39.63683264596121, 37.897007192884175, 37.99993085861206, 38.15756811414446, 34.406381607055664, 40.39517641067505, 38.7631869997297, 38.443562916346956, 37.280517850603374, 36.6646260534014, 34.88550158909389, 37.2577486038208, 36.666835580553325, 40.29309695107596, 42.87141363961356, 42.842839172908235, 39.9551956312997, 47.9204854284014, 52.04259804316929, 56.3626891544887, 42.54960434777396, 38.440116609845845, 52.650360448019846, 54.80149493898664, 56.241262435913086, 57.790043694632395, 56.454586029052734, 55.11488996233259, 59.62452098301479, 58.728099141802105, 58.9577579498291, 58.76186738695417, 61.22154358455113, 58.23000710351126, 60.11397988455636, 58.818370137895855, 60.72062710353306, 63.56330190386091, 64.50292764391217, 60.336461203438894, 54.322006702423096, 64.05379608699253, 70.62428365434918, 66.83805738176618, 57.74773611341204, 54.76839024680001, 9.271069969449725, 0.2341532882835184, 0.03436669607513717, 1.593288379056113, 53.418695722307476, 56.267783709934776, 54.19916255133492, 48.206129346575054, 40.27543115615845, 39.96054574421474, 39.07221508026123, 46.531387669699534, 45.38887105669294, 2.7941349021026065, 0.06651325949600764, 0.05247401372928705, 0.04012920221846018, 0.03609272970684937, 0.05235514796472021, 0.014865850697138479, 0.07124460275684084, 0.0385037172984864, 0.11698753892311028, 0.03719285888863461, 0.12059312473450388, 0.07771347063992705, 0.5868199371865818, 23.978771822793142, 57.319351877485005, 44.37391642161778, 32.01613528387887, 31.454484598977224, 57.043984345027376, 62.18969167981829, 65.52839142935616, 2.979123524257115, 0.1289840651942151, 0.045246309600770473, 5.064032563141414, 57.421806539808, 63.251786368233816, 70.58916051047188, 67.00884410313198, 67.93972206115723, 65.72058555058071, 66.78882244655064, 63.21562099456787, 61.8604165485927, 61.94277354649135, 59.76801518031529, 59.07254913875035, 63.63629967825753, 63.284019061497276, 59.57676601409912, 59.37605340140206, 60.15205601283482, 59.84783608572823, 60.34426403045654, 59.48445919581822, 55.27713387353079, 53.156731264931814, 49.862927300589426, 45.28339392798287, 43.6279057094029, 43.60093627657209, 44.06516974312918, 42.554249218532014, 44.68706825801304, 42.401475702013286, 44.41864545004708, 42.378383363996235, 44.56225429262434, 44.11643007823399, 40.99667501449585, 40.57276889256069, 41.048668384552, 42.90655762808663, 42.95979472569057, 43.20389189038958, 44.39179413659232, 46.31743179048811, 46.84229176385062, 39.339901379176546, 39.9118458202907, 39.64603206089565, 41.540277753557476, 40.72391653060913, 46.38929353441511, 45.76627288545881, 43.364673205784385, 44.76840387071882, 46.91139507293701, 46.91542502811977, 38.65957546234131, 37.290655272347585, 37.40645047596523, 36.869319983891074, 38.15754379544939, 37.33098609106881, 37.78569705145699, 37.59359673091343, 38.32562419346401, 39.5059563773019, 38.45020539419991, 41.5206595148359, 39.443429538181846, 38.41967153549194, 38.54040343420846, 37.60917806625366, 39.06461375100272, 37.948191097804475, 39.19684144428798, 37.83293090547834, 39.06856032780239, 38.419372762952534, 37.869728565216064, 38.31964179447719, 37.894047260284424, 37.29849978855678, 37.214575971875874, 35.68193885258266, 38.807922976357595, 39.101856095450266, 37.92175667626517, 39.60566997528076, 41.702813489096506, 40.77228988919939, 41.51995774677822, 40.5945098059518, 37.5287526675633, 37.80236577987671, 38.0755272592817, 39.692331382206504, 37.69715963091169, 34.52531739643642, 41.52440111977713, 41.46419497898647, 39.3099615914481, 39.40137904030936, 38.64667960575649, 37.25460454395839, 40.0482736996242, 37.173647608075825, 41.82855156489781, 44.19739743641445, 44.30591440200806, 42.23543460028512, 50.171041693006245, 54.564880984170095, 56.87319414956229, 45.418216773441856, 46.071639265332905, 54.137441703251426, 56.25267832619803, 57.793000153132844, 59.86143371037075, 57.50215550831386, 57.54913922718593, 59.77034977504185, 62.3104305267334, 59.99041312081473, 60.43641104016985, 61.629284722464426, 60.52917643955776, 61.33559826442173, 61.022665296282085, 62.483294759477886, 66.18069526127407, 67.04316820417131, 62.67298058101109, 59.239180837358745, 65.74708598000663, 72.49537100110734, 70.54343441554478, 61.34173352377755, 59.03480652400425, 10.352132371493749, 0.10518763174435922, 0.06505755082304988, 1.653740529503141, 59.15534387316023, 63.79951286315918, 61.522212982177734, 54.93192652293614, 31.480033125196183, 43.84855270385742, 48.4170731816973, 51.75543246950422, 57.76088905334473, 4.018096779073987, 0.18090618907340936, 0.11915000288614205, 0.06320026477000543, 0.039716839524252076, 0.027413111612466828, 0.07709379853414637, 0.1671512664428779, 0.14518068251865252, 0.24447728001645633, 0.07952329316841704, 0.23272733337112836, 0.1382229844374316, 0.5886950822813171, 36.2136219569615, 66.22685214451381, 51.077653067452566, 42.16942323957171, 39.261654240744456, 67.96071951729911, 68.16119589124406, 74.0883844920567, 4.783415232385908, 0.2682517357170582, 0.22470766013222082, 5.996047854423523, 64.2730325971331, 66.23136152539934, 73.31552246638707, 69.60314859662736, 72.86427170889718, 67.4418419429234, 70.8867518561227, 65.78040259225028, 63.91820893968855, 63.27935682024275, 63.78145449502127, 62.49134772164481, 66.89391395023891, 65.31651306152344, 63.051462854657856, 60.98242827824184, 62.83235141209194, 63.27970423017229, 65.06609998430524, 63.30195236206055, 58.14749724524361, 55.4177063533238, 53.38111291612898, 47.243439061301096, 45.58857618059431, 47.4224385534014, 45.187088421412874, 44.46134907858712, 46.28610931124006, 44.93718951089041, 47.440528188432964, 44.40897355760847, 47.29430334908621, 45.99296481268746, 42.60135105678013, 42.5890805380685, 43.42862095151629, 43.94223179136004, 45.482567514692036, 46.86826760428292, 45.25472913469587, 48.63506596429007, 47.90899658203125, 40.42361886160714, 40.803883348192485, 38.98192323957171, 41.05178117752075, 41.272730418613975, 48.305276666368755, 46.81637845720564, 44.00979260035923, 43.879340171813965, 47.01528801236834, 48.05463777269636, 40.226481097085134, 39.70097146715437, 41.479428904397146, 39.42880358014788, 41.38403013774327, 38.682664326259065, 42.020172459738596, 39.424822262355256, 40.70974915368216, 42.361978667122976, 41.66943781716483, 44.349757535117014, 40.74821090698242, 40.22463982445853, 42.15254259109497, 39.250856740134104, 41.938131604875835, 40.62815645762852, 43.15018926348005, 39.71533339364188, 42.23550408227103, 40.814336912972585, 41.67506585802351, 39.9661077771868, 41.58856078556606, 40.35406391961234, 39.32904134477888, 39.740722111293245, 42.366943155016216, 40.20232915878296, 38.96891968590872, 40.963038785117014, 42.16731446129935, 41.276829855782644, 43.04787009102957, 40.14263023648943, 39.70002998624529, 39.5976448059082, 39.91170685631888, 40.017375060490195, 39.39826624734061, 35.10611036845616, 43.13096707207816, 44.21952050072806, 42.464638301304404, 42.22440780912127, 41.33394752229963, 39.62811265672956, 42.079551764896934, 41.868680885859895, 43.315778732299805, 46.80352776391165, 47.58216721670968, 43.57056222643171, 51.6612218448094, 56.267293861934114, 57.91711582456316, 48.787613664354595, 45.21533979688372, 55.998301301683696, 59.84015137808663, 58.911976269313264, 62.996780531747, 60.27965273175921, 59.20734419141497, 62.00605773925781, 65.07528550284249, 61.83625766209194, 63.11323234013149, 64.1126959664481, 60.39835575648716, 63.84375899178641, 61.899805886404856, 64.90374837602887, 68.75578798566545, 70.15408515930176, 65.28883838653564, 63.42275374276297, 69.93334089006696, 73.72467408861432, 71.29613276890346, 67.62874153682164, 62.2001348223005, 11.666291202817645, 0.23095480991261347, 0.1637182863695281, 1.900453473840441, 68.16326645442417, 70.32779707227434, 69.69617107936314, 63.93234852382115, 63.39961624145508, 53.60320860998971, 56.53602933883667, 60.95369747706822, 70.59338501521519, 5.352802302156176, 0.33255291676947046, 0.14482515731028148, 0.17867437883147172, 0.12995814292558602, 0.15515877066978387], [0.024933101742395332, 0.032622861077210734, 0.021429703304810182, 0.04276936501264572, 0.09385535054441009, 0.024444744822436144, 0.10554334015718528, 0.08381643851420709, 17.615005322865077, 48.93937621797834, 37.7587901524135, 28.702589750289917, 33.670254707336426, 39.13450568062918, 66.919663974217, 50.19092743737357, 1.4186225001301085, 0.05916380922177008, 0.046218395831861665, 2.31520881823131, 44.86100598743984, 62.40828895568848, 65.23665741511753, 65.73009763445172, 63.72470160893032, 62.66454546792166, 60.48745945521763, 59.982832636152, 58.849428585597444, 56.50652033942086, 59.680676324026926, 63.23305402483259, 60.5331369127546, 59.134367261614116, 57.55965185165405, 52.60457876750401, 52.89638573782784, 51.30729103088379, 50.25896419797625, 48.574613162449424, 44.15387044634138, 42.98297391619001, 43.28452573503767, 41.97153854370117, 43.197235516139436, 41.34725332260132, 41.38465894971575, 40.12321696962629, 42.238717624119346, 40.83882931300572, 41.798108032771516, 42.26816061564854, 42.61392034803118, 42.27915613991873, 42.05869327272688, 40.55697563716343, 39.19328049251011, 39.27611691611153, 38.81687225614275, 38.36226551873343, 41.77539784567696, 46.6852833202907, 52.15022563934326, 41.45009708404541, 40.864954539707725, 41.85863379069737, 38.101318972451345, 41.56582627977644, 40.93236596243722, 44.52578667231968, 45.89479718889509, 43.805439131600515, 44.71825177328927, 45.5342447417123, 41.88937609536307, 38.11048364639282, 35.40035963058472, 35.58101626804897, 37.02237490245274, 34.02691616330828, 35.65540368216378, 36.880940846034456, 37.959304741450715, 37.70182534626552, 36.12389292035784, 36.96325268064226, 35.02879081453596, 37.17805276598249, 35.142484188079834, 37.01854297092983, 37.28275169645037, 36.67978007452828, 34.72023868560791, 34.95690475191389, 35.8762070110866, 36.358523164476665, 37.00130449022566, 34.63011360168457, 34.90049927575247, 35.582280840192524, 33.466748918805806, 37.75139726911272, 39.72017281396048, 34.73546913691929, 37.01927947998047, 42.62203931808472, 41.094727993011475, 42.27070018223354, 40.143182618277415, 38.785011291503906, 33.9115343775068, 35.315866061619346, 34.34667921066284, 37.52176277978079, 33.45559011186872, 32.69422040666853, 39.68294089181082, 36.69008772713797, 37.92963940756661, 38.30887903485979, 36.53415625435965, 36.10167605536324, 36.68259756905692, 36.64646693638393, 39.02685376576015, 39.62929385049002, 41.43661410467965, 38.63388449805123, 45.22683211735317, 53.08297266278948, 53.723860604422434, 54.08883558000837, 56.357026372637065, 52.870517594473704, 51.03457423618862, 52.30534764698574, 54.33798061098371, 53.82786818913051, 54.339071478162495, 56.70975167410714, 56.17418452671596, 58.282368728092735, 56.9671060017177, 58.79648331233433, 60.57992608206612, 61.10680103302002, 59.967720304216655, 57.646115234919954, 60.25033828190395, 60.56374372754778, 66.73141642979213, 64.14733273642403, 54.13269260951451, 58.55350480760847, 72.33160196031842, 67.26641382489885, 55.065595967429026, 14.033681426729474, 0.3862278051674366, 0.008763245839093412, 0.27994628676346367, 46.12534189224243, 57.70239216940743, 55.67225708280291, 51.65021589824131, 39.32305199759347, 12.808612397738866, 30.817491122654506, 50.45669603347778, 42.22967801775251, 3.789798515183585, 0.15248233000082628, 0.1080632224412901, 0.07479349018207618, 0.09604110182928187, 0.04190849067111101, 0.0268350370960044, 0.06621099928660051, 0.018143744806626012, 0.03756535765049713, 0.020877482668895806, 0.037485151418617794, 0.02145791339821049, 0.019449743209406734, 28.042561258588517, 57.80783455712454, 44.80159888948713, 35.45881829942976, 32.731758049556184, 46.46100589207241, 69.59040560041154, 56.91594641549246, 1.764452148761068, 0.01977216947956809, 0.054328395652451685, 2.779046888862337, 49.73476777757917, 64.84097834995815, 68.10917472839355, 66.60534136635917, 64.69684491838727, 64.93676621573312, 62.85215377807617, 62.84748458862305, 60.371500968933105, 58.03694445746285, 63.450206075395855, 66.94139793940953, 62.15834835597447, 62.06484644753592, 59.83675370897566, 56.297070366995676, 54.45464086532593, 53.273071902138845, 53.06239904676165, 49.18845524106707, 47.583115645817344, 43.98104790278843, 44.3417705808367, 42.86799512590681, 43.97165393829346, 44.49523196901594, 43.31516381672451, 43.93341800144741, 44.722896644047324, 43.26108946119036, 45.39536762237549, 43.459568228040425, 43.124362809317454, 42.60037136077881, 42.589073589869905, 41.834328992026194, 40.9506744657244, 40.132704734802246, 42.197163922446116, 40.67035286767142, 43.20517035893032, 47.044286319187705, 52.260017599378315, 41.36253241130284, 39.994025639125276, 42.80739293779646, 39.36535957881382, 43.445494651794434, 41.9406190599714, 46.93974372318813, 46.84273297446114, 45.57215411322457, 45.23334257943289, 45.314553124564036, 43.770451477595735, 40.94856916155134, 39.13231004987444, 39.61657517296927, 39.40706614085606, 37.005692277635845, 38.65825183050973, 38.415985516139436, 40.12748663766043, 38.94306891305106, 38.496584619794575, 40.50269978387015, 39.08173758643014, 39.123892307281494, 38.161646706717356, 39.297975948878694, 39.5286283493042, 37.77222102028983, 37.64899819237845, 36.403568335941856, 37.67279577255249, 37.32152611868722, 38.724561963762554, 37.59290191105434, 37.429230145045686, 37.483193329402376, 36.955262252262656, 40.40006794248308, 39.582931995391846, 34.58709383010864, 37.39324195044381, 42.397796630859375, 39.73170682362148, 41.18702438899449, 40.526733602796284, 41.49855382101876, 36.331098624638145, 33.97454064232962, 34.029341084616526, 36.2976256779262, 33.540861879076274, 34.005432333265034, 40.44218097414289, 38.92817892347063, 40.82498502731323, 39.41422973360334, 39.75998946598598, 38.018552030835835, 38.793112891060964, 38.707660470690044, 41.14906638009207, 40.90458706447056, 43.32671519688198, 42.002524035317556, 46.398635387420654, 54.00320945467268, 54.66129418781826, 54.191140856061665, 56.356599058423726, 54.25100653512137, 52.082800320216585, 54.820189067295615, 57.04794134412493, 56.65299183981759, 56.572031429835725, 57.21134213038853, 59.16723224094936, 58.770434515816824, 57.56928900309971, 60.725476946149556, 61.76881149836949, 62.153706959315706, 61.36972781590053, 61.37140233176095, 62.13501630510603, 63.86748014177595, 68.94269452776227, 66.0855188369751, 59.02380057743618, 61.77598203931536, 74.38637883322579, 70.43954495021275, 57.76085778645107, 16.52392622402736, 0.373339982437236, 0.057453012093901634, 0.23936940410307475, 51.3879839352199, 65.17902210780552, 62.76054177965437, 58.84713568006243, 42.23286029270717, 17.597051177706035, 39.68020330156599, 56.43614898409162, 53.53889260973249, 5.064512857369014, 0.42476772570184296, 0.07449052429624967, 0.04563499142282775, 0.07573622638093573, 0.012114357269768204, 0.1089837976864406, 0.15735868976584502, 0.13749233792935098, 0.13866832054087094, 0.12297010075833116, 0.10427405898060117, 0.16474751542721475, 0.13086448929139546, 37.72063759395054, 70.79898915972028, 54.28384372166225, 42.388878617967876, 47.7284163747515, 53.36263765607561, 74.32369913373674, 63.37005165645054, 2.3121559534754073, 0.17006125886525425, 0.16169235722294875, 3.596323536975043, 56.063256536211284, 67.87791088649205, 72.54691968645368, 69.82098851885114, 69.00893170492989, 66.96573053087506, 66.33997576577323, 62.97560937064034, 62.59966318947928, 60.174158232552664, 65.13520676749093, 68.5188683101109, 64.9279420035226, 65.37355082375663, 64.73336465018136, 59.041351727076936, 58.35548114776611, 56.41357776096889, 55.073166029793875, 53.80777399880545, 48.55417851039341, 46.55665479387556, 46.74733073370797, 45.19994606290545, 47.99087415422712, 47.08774382727486, 46.823295388902935, 45.48944623129708, 48.61482238769531, 44.83668034417288, 47.20286158152989, 46.554876055036274, 47.08295999254499, 45.490745544433594, 46.24155746187483, 44.32513311931065, 42.914596693856375, 41.09460987363543, 41.95275756290981, 43.81670216151646, 44.880989006587434, 49.9434152330671, 54.29004151480538, 42.69217096056257, 40.00631700243269, 42.26825441632952, 39.34179476329258, 42.84311015265328, 42.20674548830305, 48.84498841421944, 47.22784730366298, 46.011620725904194, 46.46255881445748, 46.74695553098406, 44.893586090632844, 44.588740825653076, 40.300948415483745, 40.58796112877982, 41.811125482831685, 38.509754930223735, 40.812922954559326, 40.35014860970633, 42.90565436226981, 42.180707114083425, 41.28410809380667, 42.2880220413208, 41.23506770815168, 41.95928192138672, 39.37111268724714, 41.24232857567923, 42.242962973458425, 41.91170413153512, 38.95312990461077, 38.28991045270647, 39.51288373129708, 40.92948246002197, 43.1177203314645, 39.72115250996181, 39.91769620350429, 40.33757931845528, 37.86183193751744, 43.31551470075335, 41.486314569200786, 33.908685616084504, 37.334199632917134, 44.097808906010215, 41.17983300345284, 41.91995164326259, 41.57337897164481, 43.02531623840332, 36.2046275138855, 33.74984632219587, 34.109095982142854, 38.13725505556379, 34.16773183005196, 34.174242292131694, 41.097660132816856, 39.79063449587141, 42.41753298895699, 43.255117484501426, 42.30527441842215, 40.87339660099575, 40.86095585141863, 40.47769669124058, 42.09640462057931, 42.47518219266619, 44.97830547605242, 44.27981696810041, 49.894798687526155, 57.06757695334298, 57.46152591705322, 56.55939613069807, 59.46911062513079, 56.50507164001465, 55.75485379355294, 60.00860350472586, 59.59135723114014, 58.218045779636924, 60.32230772290911, 60.66185923985073, 62.06305381229946, 61.48678411756243, 57.479723249162944, 62.12897137233189, 63.62188911437988, 65.29223605564663, 63.82313673836844, 62.80451692853655, 65.74037402016776, 64.78471183776855, 74.51100172315324, 69.72915417807442, 61.08307988303048, 68.36251299721854, 73.8239221572876, 69.69749123709542, 62.980327197483604, 18.40525347845895, 0.6186867100851876, 0.3370916646506105, 0.39264367946556633, 59.01950659070696, 72.11515167781285, 69.43548161642892, 68.84445394788469, 57.32050180435181, 20.477286202566965, 48.7531783921378, 65.09298256465367, 65.75885622841972, 7.193764865398407, 0.5877495844449315, 0.24967542822871888, 0.19169028183179243, 0.19459202326834202, 0.14927623846701213], [0.0653587118057268, 0.03808563455407109, 0.03994950239679643, 0.0130927674472332, 0.01359500125649252, 0.11790489112692219, 0.07616869746042149, 0.06439903937280178, 31.10518823351179, 47.92226069314139, 38.947699887411936, 21.31815024784633, 40.94162443705967, 53.293471813201904, 55.87357071467808, 58.83435794285366, 2.8948014889444624, 0.053720007584031136, 0.04972082735704524, 1.9633455276489258, 34.99249689919608, 60.440899576459614, 60.243800027029856, 65.25775909423828, 63.760887827192036, 62.48703983851841, 59.30066544669015, 56.733674321855815, 57.24198021207537, 60.30784852164132, 63.20782511574881, 58.482487269810264, 57.0070789882115, 55.43563270568848, 48.51944099153791, 46.42905112675258, 44.02898699896676, 44.01485783713204, 41.57476166316441, 44.01785945892334, 40.62333788190569, 41.5454854284014, 42.04252828870501, 42.29531070164272, 40.58457735606602, 39.30453157424927, 40.092613628932405, 40.3933664049421, 42.0273117337908, 40.58124222074236, 40.084015233176096, 42.35050024305071, 40.66580874579293, 39.55415950502668, 40.27913802010672, 39.65458876746041, 40.10527672086443, 40.25443022591727, 38.570364066532676, 39.2832909311567, 39.914652892521445, 42.49801049913679, 48.81225197655814, 48.85541418620518, 39.74786833354405, 42.62694474628994, 42.99806887762887, 42.29812124797276, 48.86302593776158, 47.555711950574604, 44.70106192997524, 47.857086590358186, 48.141191482543945, 44.1066643851144, 42.928677218300955, 42.66566705703735, 40.09888090406145, 35.692753723689485, 34.67247329439436, 36.66396597453526, 35.59963049207415, 36.262446948460166, 36.80283614567348, 37.33501257215227, 36.90748643875122, 37.263995034354075, 34.94649635042463, 36.866964544568745, 35.676446301596506, 36.68149280548096, 35.72312082563128, 34.643777234213694, 38.25682313101632, 36.330310004098074, 35.206841877528596, 34.57002905436924, 35.278828689030235, 34.734888962336946, 34.5925099509103, 35.18385376249041, 39.958009651729036, 39.110996450696675, 35.33475126538958, 34.54600913184029, 36.72816732951573, 39.28220353807722, 40.32450975690569, 41.233372347695486, 43.24225984300886, 37.78067002977644, 37.018383162362234, 35.61351646695818, 33.32996320724487, 34.36348690305437, 33.71765879222325, 34.47964688709804, 42.903097425188335, 36.90612806592669, 37.75457954406738, 36.6770007950919, 36.643569537571494, 36.33914463860648, 35.95497873851231, 37.22593627657209, 41.004585538591655, 39.166648047310964, 40.1348934173584, 37.577991076878135, 40.866875716618125, 45.660285064152305, 52.297909600394114, 53.918080125536235, 54.389560563223704, 55.137874603271484, 56.081505979810444, 55.805040631975444, 54.687978744506836, 54.36274746486119, 54.181663513183594, 56.34758724485125, 54.60804666791643, 59.901177406311035, 60.023785318647114, 60.07789094107491, 57.39876283918108, 60.81654003688267, 58.17427212851388, 59.68955612182617, 57.105726037706646, 61.279269218444824, 58.32479790278843, 61.709856033325195, 64.8717588697161, 58.55199704851423, 51.96929107393537, 70.36799934932164, 69.44948918478829, 17.238053389957972, 0.33991686733705656, 0.11072390074176447, 0.021030807834384695, 36.40013939993722, 62.06711156027657, 55.52137347630092, 49.94278294699532, 34.20571763174874, 44.71595886775425, 37.59330490657261, 40.70939826965332, 57.67030191421509, 7.03256448677608, 0.31331001647881096, 0.06475514812128884, 0.08015862586242811, 0.018717149305822592, 0.05367261191297855, 0.0383116409980825, 0.05370092039395656, 0.055945497272270064, 0.02136587690828102, 0.026604967923568826, 0.02009585952120168, 0.05430148834628718, 0.2174780730690275, 42.61125223977225, 55.863891874040874, 44.899596282414024, 31.25646788733346, 44.679317542484824, 59.000009945460725, 63.1304360798427, 66.50784424373082, 3.7492427485329762, 0.0774870231481535, 0.10922971234789916, 1.9862993359565735, 40.68370035716465, 62.77204104832241, 64.33073043823242, 66.93870203835624, 66.11288779122489, 64.1100764955793, 61.965028626578196, 58.092078413282124, 57.85934502737862, 61.769075529915945, 64.23656845092773, 60.83979565756661, 60.4717287336077, 57.44836950302124, 50.8728792326791, 47.304673535483225, 45.2233475957598, 46.06782123020717, 44.53356865474156, 43.83838748931885, 43.24464654922485, 43.51683528082711, 43.26369503566197, 43.199250493730815, 42.89950520651681, 40.476783003125874, 41.67315510341099, 43.341049330575125, 43.37509202957153, 44.48408358437674, 41.99859135491507, 44.50635950905936, 43.513976097106934, 42.4594167300633, 42.97285386494228, 41.21818011147635, 41.38802187783377, 41.28056451252529, 40.95283535548619, 40.79047679901123, 40.71789244243077, 44.93565048490252, 51.89240230832781, 50.217493874686106, 40.94662019184658, 42.42284836087908, 42.631349904196604, 41.63821261269705, 51.34754889351981, 48.26267031260899, 45.22120060239519, 48.54326983860561, 47.055264472961426, 44.13884496688843, 44.69751834869385, 44.39790160315377, 41.66202756336757, 37.90995168685913, 37.47415372303554, 38.884856905256, 37.24828168324062, 39.00474112374442, 38.20123059409005, 40.29533427102225, 39.40748650687081, 39.03101226261684, 38.178030558994834, 40.53598165512085, 38.10385853903634, 38.89309399468558, 39.151382855006624, 38.15647724696568, 40.3213518006461, 39.88869094848633, 36.66836765834263, 37.85783324922834, 37.5892402103969, 38.02881799425398, 36.36488424028669, 38.13373926707676, 41.50504343850272, 40.30803210394723, 36.77621759687151, 37.05124814169747, 36.99836540222168, 40.48902225494385, 41.37926714760916, 42.049309730529785, 44.5942507471357, 39.278316020965576, 36.592284883771626, 35.86994668415615, 34.148989064352854, 33.4513760294233, 34.50779403959002, 35.31717927115304, 43.219487122126985, 37.9249597958156, 39.339866638183594, 37.65247923987252, 38.9628712790353, 39.86624479293823, 39.81318140029907, 38.09584379196167, 41.78676509857178, 41.399927616119385, 41.426021575927734, 41.396967683519634, 42.91548606327602, 47.3259801864624, 56.42820719310215, 55.2888103212629, 55.95797743116106, 56.411462034497944, 56.556092262268066, 57.30299234390259, 56.4978038242885, 56.24529586519514, 56.908452783312114, 58.20810638155256, 56.73894453048706, 60.39349201747349, 61.253706795828684, 61.76597663334438, 59.52241720472063, 62.54087448120117, 60.40628365107945, 62.696312631879536, 59.29845591953823, 62.713280132838655, 60.85074601854597, 64.42986038752964, 67.81433486938477, 62.34726987566267, 57.732279845646445, 72.18644714355469, 71.55031176975795, 20.550000837871007, 0.4591881515724318, 0.13126626344663755, 0.03397675896329539, 40.649206025259836, 69.08902359008789, 61.073713711329866, 58.207870142800466, 37.440951756068635, 44.92809084483555, 48.313638823372976, 48.56444794791085, 69.58852958679199, 9.704429984092712, 0.4298401549458504, 0.0723355852865747, 0.1398571953177452, 0.044636893551796675, 0.029017007244484763, 0.17159621364303998, 0.18263413278119905, 0.1367991736957005, 0.10984176450542041, 0.13552090871546948, 0.1457265503704548, 0.22496814972587995, 0.3609243929386139, 52.49147251674107, 65.11988598959786, 53.36819274084908, 29.1257107257843, 51.67179005486624, 70.28281443459647, 65.75489575522286, 72.8062264578683, 4.2757294688905985, 0.2634788661130837, 0.1886409997407879, 2.912650542599814, 45.82917840140206, 66.07784802573067, 66.18611485617501, 69.9163178035191, 69.3994482585362, 66.2573686327253, 63.48505823952811, 60.2501437323434, 59.39165210723877, 64.26928056989397, 67.78174086979458, 63.35339682442801, 63.5391013281686, 59.763915743146626, 54.78159529822213, 52.20967790058681, 47.90006814684187, 49.390672138759065, 47.56594664709908, 48.386407307216096, 45.826294898986816, 45.56470564433506, 47.14713702883039, 48.1143227985927, 45.50030279159546, 41.74986668995449, 43.8202804837908, 46.82310778754098, 46.226684842790874, 45.73002413340977, 43.59735448019845, 46.96083150591169, 46.79471397399902, 43.00248098373413, 44.35051141466413, 43.775099822453086, 44.443422726222444, 43.34751810346331, 43.01402194159371, 42.81183978489467, 44.31654167175293, 44.80550377709525, 54.694298131125315, 52.95390639986311, 40.38441712515694, 43.724437032427105, 41.89170721599034, 43.34158781596592, 50.50559745516096, 51.3341840335301, 47.03056362697056, 49.904137066432405, 48.592570781707764, 45.47324998038155, 45.358121803828645, 46.15625442777361, 45.02064432416643, 39.726728439331055, 41.3533364704677, 42.63608510153634, 39.91240167617798, 41.341573170253206, 41.596085684640066, 42.41628231321062, 40.9723493712289, 41.584954670497346, 38.701271602085654, 44.032749448503765, 40.36576121194022, 42.670548166547505, 41.40766790934971, 40.965765953063965, 43.36214753559658, 42.902736118861604, 37.85147564751761, 39.46064370019095, 39.25851712908064, 41.33784198760986, 39.80777570179531, 42.5853146144322, 45.02243001120431, 41.459352084568565, 37.16973229816982, 37.70700175421578, 38.39463717596871, 41.06201934814453, 42.50212035860334, 42.624575410570415, 46.10605369295393, 41.020038332257954, 37.515564986637656, 36.55177688598633, 33.91316373007638, 34.742340905325754, 33.52002075740269, 35.65620967320034, 46.4249655859811, 39.828550815582275, 41.866374083927695, 40.358847754342214, 41.54376227515084, 41.12006459917341, 41.982276984623496, 40.04747813088553, 43.35960449491228, 42.2166987827846, 44.27166673115322, 41.993355887276785, 46.61624254499163, 51.156244141714915, 59.074202810014995, 57.979698249271934, 59.2664247240339, 58.56455939156668, 58.856890950884136, 59.87255777631487, 58.15384789875576, 57.72292062214443, 59.1027182170323, 60.08870233808245, 57.10411752973284, 62.498059681483674, 62.44299520765032, 65.18412903376988, 63.62648187364851, 65.8082092830113, 62.69237300327846, 66.80228110722133, 61.02655628749302, 66.78535529545375, 63.834323338099885, 67.73595918927873, 69.14863218579973, 65.74721104758126, 64.0452220099313, 76.83291598728725, 69.41714532034737, 23.119686126708984, 0.9442271845681327, 0.2339292631617614, 0.06664342286863498, 46.68671464920044, 77.63304274422782, 69.21340329306466, 66.72219617026192, 50.06615516117641, 57.19589628492083, 54.07524490356445, 56.94415610177176, 81.54569149017334, 13.555696606636047, 0.6171099575502532, 0.23210327114377702, 0.23162194554294857, 0.24314992981297628, 0.23696074049387658], [0.043612743328724585, 0.04667243075424007, 0.04570534871891141, 0.0400936503761581, 0.03130172625450151, 0.08172112237662077, 0.051214086157935004, 0.17817429852272781, 30.40636968612671, 53.9966573034014, 30.97670909336635, 26.45742528779166, 35.19697543552944, 48.00767489842006, 59.88105542319161, 59.75262492043631, 5.370633551052638, 0.09673675628645079, 0.16071594533111366, 1.1219830576862608, 29.92706905092512, 58.68946715763637, 64.32107939038957, 65.8979800088065, 63.009940419878276, 61.89470590863909, 56.77829565320696, 57.563459464481895, 60.1905003956386, 61.58547633034842, 58.03479051589966, 57.459100995744976, 53.646245752062114, 47.470388071877615, 43.46061740602766, 43.69132191794259, 43.55785397120884, 41.551999364580425, 42.101660932813374, 41.409265995025635, 40.272495542253765, 40.00580978393555, 41.10441378184727, 39.86233990533011, 40.930059160505024, 39.78358554840088, 41.49802575792585, 42.848345620291575, 44.27934449059622, 44.91942644119263, 45.027658530644004, 45.63563632965088, 42.71711846760341, 42.806899615696494, 40.78124611718314, 41.057468278067454, 40.00859948566982, 38.409117221832275, 36.45965419496809, 38.82616547175816, 40.08784369059971, 42.38500847135271, 46.836861746651785, 48.33235032217843, 48.91879217965262, 37.95062296731131, 44.30340610231672, 50.80131278719221, 50.49410513469151, 49.84308671951294, 52.66283246449062, 50.71165323257446, 48.6792391368321, 46.01075220108032, 40.57557249069214, 40.62606504985264, 45.199876580919536, 38.07511731556484, 39.20855958121163, 34.588038785117014, 34.801251207079204, 35.89838218688965, 36.839984689440044, 35.914679186684744, 37.84206778662545, 36.97759028843471, 35.366160597120015, 33.69990961892264, 35.410802773066926, 38.1215694972447, 37.20958716528756, 34.7071795463562, 36.81190354483468, 34.44805690220424, 38.13283947535923, 34.904866218566895, 35.918959277016775, 34.808515548706055, 36.87708112171718, 41.419573647635325, 37.758842263902935, 35.88427734375, 36.302527632032124, 35.4122063091823, 37.369117804935996, 42.505038602011545, 40.740505354745046, 40.64326878956386, 42.13491153717041, 38.54962369373867, 40.23135525839669, 38.148670945848735, 34.68237795148577, 35.14597218377249, 36.42061226708548, 40.082677704947336, 42.258019719805034, 36.52725321905953, 37.61313853945051, 35.202134472983225, 37.15510981423514, 35.24873604093279, 37.565428733825684, 37.465562275477815, 41.62258611406599, 40.192678110940115, 41.01662329265049, 39.57785981042044, 40.63457659312657, 39.1903691973005, 42.18438965933663, 44.4936477797372, 48.804199014391216, 47.948351178850444, 54.3231531551906, 55.141855921064106, 58.091366222926546, 55.77760566983904, 58.72650105612618, 57.09050948279244, 57.830284186771934, 58.50074018750872, 57.19462129047939, 56.31068188803536, 57.58475569316319, 55.21171658379691, 57.08374193736485, 56.18138633455549, 55.457953793661936, 54.975248541150776, 57.163608006068635, 56.8660375050136, 60.82869938441685, 63.56266961778913, 64.15678228650773, 48.31590741021292, 70.97161715371269, 27.349146672657557, 0.5128664055040905, 0.27369923197797363, 0.28398945980838364, 30.71153804234096, 64.68674918583461, 56.53277063369751, 52.563302993774414, 38.186555998665945, 15.106674364634923, 14.971191440309797, 44.1382543700082, 55.31892728805542, 10.48608842917851, 0.5451476818748883, 0.08591139502823353, 0.17081919605178492, 0.06839274721486227, 0.0880532790241497, 0.037069816741028, 0.008467835440699543, 0.06611543441457407, 0.03316322601001177, 0.02802002725989691, 0.0351098378055862, 0.046499909833073616, 0.14701529193137372, 37.86551100867135, 63.46893841879708, 34.64268984113421, 26.948973860059464, 40.12846980776106, 55.233599935259136, 64.49043478284563, 66.453585760934, 6.4135807412011285, 0.1845980573977743, 0.09628413950226136, 1.0980824487549918, 33.46510566983904, 61.84090600694929, 65.2421464920044, 66.016266141619, 64.6925161906651, 61.80545629773821, 57.946850640433176, 57.23344782420567, 62.194103785923545, 65.57973166874477, 59.63126073564802, 58.83749852861677, 54.410940170288086, 48.724534443446565, 45.97279419217791, 45.534751960209434, 46.40158837182181, 44.73742880140032, 44.86342396054949, 43.252501487731934, 42.63904850823538, 41.02308859143938, 42.937553542000906, 41.771017006465364, 44.35955796922956, 42.23764065333775, 42.859751088278635, 45.63587951660156, 46.91374356406075, 45.54388536725725, 48.68118463243757, 47.57114042554583, 44.876660278865266, 43.7393478666033, 42.54817649296352, 42.69601331438337, 41.47836235591343, 40.31224618639265, 37.81970500946045, 40.72299242019653, 43.28920187268938, 44.7007805279323, 47.832722731998985, 49.9295778955732, 49.33190080097744, 39.09425824029105, 46.74417625154768, 51.383040291922434, 52.520821707589285, 54.70229550770351, 52.64015701838902, 52.021513734545024, 50.21910238265991, 46.32268810272217, 43.11466659818377, 42.826239926474436, 45.23370735985892, 41.11821290424892, 42.04688480922154, 36.19003629684448, 38.14671850204468, 37.51030172620501, 37.13215296609061, 37.75403758457729, 40.640645844595774, 39.262922286987305, 38.03773600714547, 36.8091972214835, 37.472767557416645, 38.90342596599034, 38.505829198019846, 38.526732853480745, 39.877101353236604, 37.59102242333548, 39.4403897012983, 38.33176292691912, 38.231764452798025, 38.29576431001936, 40.26469966343471, 43.915863377707346, 40.30926888329642, 37.50650453567505, 37.32617793764387, 35.71387277330671, 36.60624728884016, 43.23134422302246, 40.48353665215628, 40.43873119354248, 40.46466881888253, 39.622866766793386, 40.55847644805908, 37.9826784815107, 34.65436976296561, 34.94903244291033, 35.404903752463206, 41.60107101712908, 43.95416532244001, 38.803688049316406, 40.64780248914446, 37.708301067352295, 38.83257865905762, 36.43082959311349, 39.009215763636995, 37.76840993336269, 42.24168103081839, 40.4214996610369, 42.85638121196202, 40.50191116333008, 42.11177403586251, 40.86048684801374, 43.19949715478079, 47.17984914779663, 49.86999709265572, 50.53290387562343, 55.50139045715332, 56.37752703257969, 58.55344922201974, 56.87723452704293, 60.585039956229075, 58.96388626098633, 58.56034183502197, 60.6013890675136, 59.585326194763184, 59.177216802324565, 58.610688482012065, 57.78301559175764, 59.07802431924002, 57.611756392887656, 57.303642000470845, 60.05702550070626, 59.202188628060476, 60.30245671953474, 62.50789138248989, 67.18149294172014, 66.63919298989433, 55.30498572758266, 70.38350772857666, 29.62514897755214, 0.47114610991307665, 0.21511027083865233, 0.24345698047961506, 33.36072635650635, 71.7085986818586, 64.08384009769985, 59.85453414916992, 44.33297416142055, 23.659029620034353, 25.59966322353908, 51.166989530835835, 66.07743113381522, 13.632312655448914, 0.6361227259039879, 0.132145902674113, 0.1707630269229412, 0.06200984293328864, 0.10700586810708046, 0.21480357301022324, 0.15170755157513277, 0.20269811472722463, 0.15994086835001195, 0.17830682998257025, 0.10655857103743724, 0.16454927463616642, 0.6006672627159527, 50.40355621065412, 73.33433818817139, 43.4516681262425, 35.72974245888846, 48.077358382088796, 63.197180475507466, 69.21517508370536, 72.18209062303815, 7.26855788060597, 0.25011978724173134, 0.16122195603592054, 1.2767378964594431, 40.01900093896048, 63.82060064588274, 70.83932345254081, 68.711409841265, 67.68719673156738, 64.56833103724888, 58.994409697396414, 58.49450070517403, 63.333087239946636, 66.49016802651542, 61.86024979182652, 61.92311709267752, 57.673574515751426, 52.69230324881417, 48.6291287285941, 48.22414255142212, 48.90299892425537, 46.77926812853132, 47.93972151620047, 45.010784830365864, 44.71951287133353, 43.047546999795095, 46.604124886649, 44.038314955575125, 46.55256577900478, 44.30115141187395, 46.56115027836391, 48.91054119382586, 48.41475943156651, 49.044936725071494, 52.294445923396516, 49.343782220567974, 47.904754706791465, 47.14269365583147, 44.7881749698094, 45.44097907202584, 43.61928994315011, 41.707791873386924, 40.39560372488839, 43.55487666811262, 45.670978341783794, 46.0432836668832, 51.062568528311594, 51.60728645324707, 50.41019868850708, 38.082489354269846, 48.46428271702358, 53.11648382459368, 52.99589783804757, 53.93868153435843, 54.8979046685355, 52.04163224356515, 51.02070215770176, 48.845881257738384, 43.55793040139334, 43.18908180509295, 47.23918328966413, 42.564626353127615, 45.382520403180806, 39.06925514766148, 39.50082860674177, 40.87246206828526, 39.98855740683419, 39.380364213671, 43.32182713917324, 41.775366578783306, 40.56773144858224, 38.77744817733765, 40.19290740149361, 43.4544335092817, 42.388225487300325, 39.73069586072649, 41.63376923969814, 38.807391439165386, 41.69292272840227, 39.796366759708945, 40.52867215020316, 39.93566077096121, 42.02474090031215, 45.7822711127145, 40.572018487112864, 37.835626806531636, 37.6530316216605, 35.648643084934776, 38.04890176228115, 44.951683453151155, 42.53038215637207, 42.37246697289603, 42.50542770113264, 39.133084774017334, 40.77429444449288, 38.13663666588919, 35.289678301130024, 35.30493654523577, 36.06385006223406, 43.112933022635325, 44.806969846997944, 41.224179880959646, 43.055478368486675, 39.9599586214338, 41.807925837380544, 39.8552770614624, 42.17989764894758, 41.7633045060294, 45.37608289718628, 43.15895094190325, 44.44254725319998, 43.069857665470664, 43.39014877591814, 43.71407726832798, 45.768214906964985, 48.91340732574463, 53.11273179735456, 53.19039181300572, 57.99928522109985, 59.38114643096924, 61.26906926291329, 59.9532333101545, 63.45594528743199, 61.718207768031526, 60.65211091722761, 64.18890380859375, 61.38441630772182, 60.85711751665388, 61.40438543047224, 60.311920166015625, 60.6956205368042, 61.221668652125764, 58.43746294294085, 61.8887026650565, 61.258209228515625, 63.72713347843715, 66.14359882899693, 72.26954759870256, 68.04658535548619, 61.7789489201137, 75.48666776929582, 29.309732028416224, 0.7034254744648933, 0.6466033778020314, 0.3920780255326203, 39.02175726209368, 78.39959580557687, 72.83344949994768, 66.84230273110526, 58.881209645952495, 21.875282866614207, 27.38441572870527, 60.2855795451573, 77.79761777605329, 19.405378920691355, 0.8184778179441179, 0.2477114221879414, 0.3525295576878956, 0.1388255235339914, 0.17590666163180554], [0.02053196245937475, 0.030685382362987314, 0.030685199158532277, 0.01680658637945141, 0.02567724261565932, 0.036083861254155636, 0.052605727554431984, 0.2281790588583265, 28.330192361559185, 53.123744692121235, 38.93878534861973, 39.62818561281477, 35.953724588666645, 51.092247758592876, 57.02832657950265, 61.75385897500174, 7.769362756184169, 0.3211750515869686, 0.21645301021635532, 0.6367678769997188, 19.86835823740278, 56.79583290645054, 61.651373045785085, 64.83518355233329, 62.30086285727364, 60.02062388828823, 60.658607482910156, 61.34378324236189, 59.933048793247764, 59.56472478594099, 56.23034681592669, 49.731828689575195, 44.673300402505056, 42.986635616847444, 41.614762442452566, 43.160139083862305, 41.953567028045654, 41.63438415527344, 40.89062813350132, 40.265206881931846, 39.923709869384766, 40.75066014698574, 40.77215092522757, 41.48724215371268, 40.62350811277117, 40.98623882021223, 44.859852586473735, 49.6531959261213, 47.6731538772583, 51.50638123920986, 51.50591570990426, 46.846029894692556, 45.290970938546316, 42.37629543031965, 41.91971887860979, 41.03151675633022, 39.73231479099819, 39.52405643463135, 36.53711271286011, 36.364901610783164, 38.90192862919399, 40.10693734032767, 43.66977208001273, 49.86697810036795, 50.84980426515852, 47.97602932793753, 41.23634965079171, 46.64376435961042, 51.25035054343087, 55.7117680140904, 53.735307761601035, 55.335095746176584, 51.96526459285191, 45.47745016642979, 41.47514533996582, 44.455575125558035, 42.7472562789917, 42.32029642377581, 39.20427254268101, 37.08862945011684, 35.80211836951119, 34.23624106815883, 36.32840272358486, 34.75145346777779, 38.66337265287127, 37.45891284942627, 36.502965790884836, 35.363714831215994, 36.34890685762678, 35.90384694508144, 36.102829456329346, 35.18033102580479, 36.75421960013253, 38.17746775490897, 37.12369353430611, 38.52667031969343, 37.60071863446917, 38.923610482897075, 39.89010490689959, 35.616511140550884, 35.115438325064524, 35.040175437927246, 34.94985580444336, 34.96598604747227, 40.12847328186035, 39.624315466199604, 41.380333696092876, 40.960808413369314, 39.81142350605556, 40.839968817574636, 41.7535457611084, 40.30669457571847, 40.289244174957275, 38.51953451974051, 41.14892046792166, 47.48466314588274, 42.71122986929757, 37.62456137793404, 38.184266567230225, 36.82370506014143, 35.273145062582834, 35.03999131066458, 35.40292698996407, 37.239811829158235, 39.3823687689645, 40.34324557440621, 40.88324914659773, 41.19952767235892, 41.82139144624983, 40.551771436418804, 41.857671465192524, 38.72312716075352, 40.63412496021816, 43.09495108468192, 45.67535918099539, 45.2579322542463, 48.61697285515921, 51.513537883758545, 53.51685987200056, 55.1134968485151, 55.16695628847395, 55.42386940547398, 53.29465300696236, 52.27609920501709, 50.55351570674351, 51.43390110560826, 50.779561451503206, 53.395054476601736, 54.60036196027483, 54.7889221736363, 55.884729521615164, 56.963618006025044, 59.615981646946494, 61.292046955653596, 65.38008907863072, 63.64115646907261, 51.05914306640625, 35.841139452798025, 0.4695887906210763, 0.18631727514522417, 0.1572570452200515, 20.60781158719744, 67.10039356776646, 56.22816855566842, 56.81889050347464, 33.200462681906565, 25.26722492490496, 28.66711572238377, 37.535030364990234, 55.147230352674214, 18.42870885985238, 0.2942362885390009, 0.023792606512350694, 0.12343651215944972, 0.009144280571490526, 0.19292104936071805, 0.03572410198726824, 0.018636269627937248, 0.014381697301619818, 0.06045103764959744, 0.07862289755472116, 0.07388293689915112, 0.05001054823930774, 0.1287402675620147, 36.30159657342093, 62.65581158229283, 43.761047090802876, 39.1558644430978, 36.664038930620464, 57.58294916152954, 63.38870756966727, 70.65154838562012, 8.536991051265172, 0.38356325243200573, 0.11225219909101725, 0.6171325391956738, 25.362997157233103, 61.718103545052664, 64.58302647726876, 66.48652717045375, 63.10442202431815, 61.101951190403526, 62.22902543204171, 64.10434423174176, 63.23723684038435, 61.15758541652134, 59.21443830217634, 52.001499448503765, 46.604948248182026, 45.8070136478969, 44.07605757032122, 44.01836667742048, 43.69512605667114, 44.050672326769146, 42.992492948259624, 42.69717018944876, 43.120763642447336, 42.84666763033186, 43.539729595184326, 43.716429233551025, 43.810136113848, 44.83976534434727, 47.942709241594585, 50.46194192341396, 51.69405903135027, 54.14800991330828, 51.96641104561942, 47.379953793116975, 47.33945969172886, 46.044704573495046, 44.03949267523629, 44.22634015764509, 41.01352787017822, 41.25924049104963, 38.487708296094624, 38.601224490574424, 40.35889291763306, 42.24920245579311, 44.76244231632778, 50.45669255937849, 52.86173507145473, 49.27601643971035, 42.19499955858503, 47.21289825439453, 53.178975922720774, 57.25469194139753, 56.293457303728374, 56.38272081102644, 52.59009524754116, 47.42418255124773, 42.638961655753, 44.71474640710013, 43.15794345310756, 44.048469747815815, 41.83315822056362, 39.604360239846365, 39.8737245287214, 36.54406091145107, 39.956251757485525, 38.639679295676096, 41.111077104296, 39.373714787619456, 38.521546023232595, 36.861586638859336, 38.5218482698713, 38.77957432610648, 39.734058788844514, 38.670067242213655, 38.508743967328755, 40.564000265938894, 39.90599543707711, 39.691365582602366, 40.19179916381836, 41.36575984954834, 40.75696563720703, 36.27724313735962, 35.79833854947771, 35.72877318518502, 36.71164451326643, 34.7745075907026, 41.600327559879844, 40.754842962537495, 43.24038035529, 43.07086168016706, 40.01741327558245, 41.94758115495954, 43.410628591264995, 40.43445805140904, 41.45076411111014, 39.42407533100673, 43.48760420935494, 49.213201250348774, 44.76041691643851, 39.47841371808733, 40.14607654299055, 38.93746171678816, 37.12557302202497, 38.37296574456351, 38.21846560069493, 39.45382751737322, 41.96040752955845, 41.879898752485005, 42.864114556993755, 41.1631885937282, 43.60179090499878, 42.56951093673706, 43.37467861175537, 40.73110096795218, 42.60881689616612, 45.51205219541277, 46.986480781010215, 46.75344514846802, 49.41450793402535, 53.68288360323225, 55.92067602702549, 56.40399619511196, 56.83255761010306, 56.38263048444475, 55.57696948732649, 54.330563408987864, 53.24796806062971, 53.07293251582554, 53.307020800454275, 57.8034884589059, 57.64813021251133, 58.37497084481375, 58.02145692280361, 58.628934451511924, 62.25922925131661, 65.16855117252895, 66.97472149985177, 67.82641083853585, 54.768550055367605, 38.08615105492728, 0.48838019371032715, 0.02267193468287587, 0.23049973004630633, 21.51313407080514, 75.2016248703003, 62.636259351457866, 64.85572937556675, 36.81807007108416, 19.69296486037118, 27.86924191883632, 44.68707173211234, 65.3626629965646, 23.051651103155955, 0.3680371769836971, 0.028880889727068797, 0.14274791734559195, 0.028971850738993714, 0.09253277044211115, 0.12110270453350884, 0.06863775942474604, 0.1262877570199115, 0.2110811841807195, 0.1807299056755645, 0.2231001699609416, 0.24283541526113236, 0.3164107586656298, 48.28037779671805, 70.28613567352295, 51.29826184681484, 56.164255550929475, 49.23313563210623, 66.50830282483781, 68.6260929107666, 76.50097969600132, 9.464441810335432, 0.38022518583706444, 0.17177227990967886, 0.8065644800662994, 29.43313898359026, 67.03125899178642, 68.59472179412842, 68.15028027125767, 67.48293358939034, 64.58075441632951, 64.59651987893241, 66.55408450535366, 66.44066905975342, 65.42887238093785, 62.004730633326936, 55.58233002253941, 49.7439671925136, 48.179538590567454, 46.57091249738421, 48.35103055409023, 47.11366408211844, 46.00043065207345, 46.991111755371094, 44.51767465046474, 45.06805535725185, 45.63857889175415, 44.92904274804251, 45.30156346729824, 45.74289914539882, 46.644417490277974, 49.178797245025635, 52.12284973689488, 52.69992194856916, 56.08629328863961, 57.819903578077046, 50.97942290987287, 50.44772938319615, 48.40188789367676, 45.78710011073521, 45.662140233176096, 44.07974706377302, 42.69573538643973, 41.19207225527082, 40.073697158268516, 43.42119680132185, 44.57617153440203, 49.07860769544329, 53.19776732581002, 55.34261022295271, 50.75404419217791, 42.78248711994716, 49.14729758671352, 54.244350160871235, 59.02614212036133, 59.10046700068882, 57.97984068734305, 55.697260175432476, 48.61739322117397, 43.99943283626011, 47.554322310856406, 45.590903827122276, 47.00659234183175, 45.0846962928772, 42.28894962583269, 40.95499971934727, 38.72180700302124, 43.44627979823521, 39.144643102373394, 44.45703077316284, 42.53738246645246, 41.06157466343471, 40.252172061375205, 43.937882219042095, 40.74233273097447, 42.10842500414167, 40.41885239737374, 41.364939962114605, 43.38977357319423, 42.12029252733503, 41.92510373251778, 42.366633960178916, 42.306101254054475, 43.04287781034197, 38.208731174468994, 36.958107539585654, 36.09490850993565, 37.064293384552, 35.86199099676949, 43.516696316855295, 40.69367797034127, 44.115019593920024, 44.15895305361067, 41.69729661941528, 42.671173504420686, 43.99342611857823, 41.83318253925869, 42.286344051361084, 40.57909870147705, 44.61245155334473, 49.67332485743931, 45.62646818161011, 41.20165034702846, 42.547596318381174, 42.85494988305228, 38.229749475206646, 38.83188383919852, 40.49923958097185, 41.19065134865897, 43.92546231406075, 45.21779945918492, 45.15123224258423, 44.340162072862896, 45.73894909449986, 44.80459008898054, 47.32730381829398, 43.24665110451834, 44.49758046013968, 47.44722972597395, 49.808154651096885, 50.667792728969026, 51.012155873434885, 56.461617606026785, 58.54731396266392, 59.73282255445208, 58.921307700020925, 58.73956366947719, 57.53152901785714, 56.29364837918963, 55.33520344325474, 57.50360073362078, 55.521015644073486, 60.71663188934326, 60.716951506478445, 61.93711771283831, 60.78442546299526, 61.745569774082725, 66.08101640428815, 70.98729923793248, 71.42662688664028, 71.59544031960624, 62.24211583818708, 41.048612798963276, 0.7922469569104058, 0.19243391550012998, 0.4482085864458765, 26.431442499160767, 83.91794545309884, 68.87066950116838, 71.90070247650146, 49.722420828683035, 36.911794321877615, 39.80426686150687, 54.69448225838797, 76.4023083278111, 30.273474965776714, 0.3575358161968844, 0.24620968848466873, 0.17859699869794504, 0.14882646474455083, 0.27894240777407375], [0.037129721205149374, 0.09458546779517617, 0.04332645583365645, 0.05698219021516187, 0.023066996430445994, 0.013100500201939471, 0.07673190188195024, 0.221758027694055, 27.9865448815482, 52.10699047361101, 36.62029307229178, 32.01965454646519, 29.329624720982142, 51.555067266736714, 56.03293112346104, 63.435482842581614, 9.105124405452184, 0.3252738102206162, 0.19505726758922848, 0.3335237375327519, 13.793054018701826, 49.674613748277935, 58.713153566632954, 61.655069487435476, 60.000460215977256, 61.179110935756135, 64.26166534423828, 59.59390722002302, 58.516651562282014, 55.788149561200825, 50.41789729254586, 43.527500765664236, 43.82884413855416, 42.4449644769941, 41.553475856781006, 41.73478215081351, 43.56928375789097, 40.845780985695974, 42.6744704246521, 43.914515427180696, 43.48184415272304, 43.435378074645996, 43.371260098048616, 45.58924320765904, 48.580241203308105, 47.599728788648335, 48.414085456303184, 52.07203756059919, 54.211926392146516, 52.170406682150706, 48.37898663112095, 50.26022529602051, 48.92645604269845, 43.7660984311785, 43.01775312423706, 39.42129257747105, 39.54828827721732, 38.85135269165039, 38.17716898236956, 37.95929779325213, 38.710912227630615, 39.204946517944336, 40.11883613041469, 44.94700384140015, 52.04252508708409, 52.45956291471209, 49.91453504562378, 45.35660014833723, 45.48516961506435, 49.29377256120954, 46.78080368041992, 49.485351766858784, 50.87175015040806, 46.90703507832119, 44.9510372706822, 42.16128689902169, 43.43959215709141, 41.82862104688372, 37.43938146318708, 35.399261815207346, 38.411594254629954, 37.21807091576712, 38.40163401194981, 38.20928703035627, 35.50627449580601, 36.42240490232195, 36.13523932865688, 35.283178261348176, 34.26591682434082, 35.146677425929475, 36.20787927082607, 35.816535881587434, 36.31477730614798, 36.0645101411002, 36.426327160426546, 37.90868016651699, 36.9770587512425, 41.34253896985735, 36.92406136648995, 33.70884152821132, 33.95171928405762, 35.54182147979736, 35.97668143681118, 37.78405032839094, 40.27733496257237, 40.066134044102256, 46.986946310315815, 46.974432604653494, 49.87093162536621, 52.00972958973476, 53.86893899100167, 46.33467721939087, 40.493083477020264, 43.38278715951102, 47.32552507945469, 49.423867157527376, 41.18392549242292, 37.04141991479056, 37.268796239580425, 35.36535113198416, 35.952762263161794, 35.48920624596732, 35.89198637008667, 37.133841378348215, 40.611783027648926, 39.56257029942104, 39.78055960791451, 39.34277793339321, 40.59976264408657, 40.42261484691075, 39.58961616243635, 39.701645442417686, 39.57287795203072, 40.415444305964876, 40.58368798664638, 39.75179753984724, 42.77581684929984, 42.08900478907994, 44.75759594781058, 44.631145681653706, 46.06859595435006, 45.64995656694685, 44.17416960852486, 45.128966740199495, 47.29503638403756, 49.78381511143276, 52.99734653745379, 53.19353239876883, 53.766487802777974, 55.53974451337542, 53.98187848499843, 57.95641483579363, 53.985616615840364, 62.26504489353725, 60.93149103437151, 67.34747845785958, 61.09269618988037, 31.135656084333146, 0.715872412281377, 0.2481608023600919, 0.34573590223278317, 12.707975557872228, 66.09954030173165, 60.660045760018484, 53.42354556492397, 43.934022494724815, 30.079185962677002, 28.245370490210398, 40.46647882461548, 54.90934835161482, 22.056905303682598, 0.6638586861746651, 0.1338774019054004, 0.12999895002160752, 0.028179849398189356, 0.11247585101851396, 0.058596567516880374, 0.04241073550656438, 0.025343169291902865, 0.04514699921544109, 0.02607386838644743, 0.01043951147169407, 0.06353491824120283, 0.16269207000732422, 38.58086626870291, 60.550215584891184, 43.79059430531093, 37.1159462928772, 36.679338863917756, 57.02055849347796, 62.84271117619106, 69.58240822383335, 10.459645322390966, 0.3382348061672279, 0.13021381492061274, 0.3946450049323695, 17.51583194732666, 55.520953110286165, 61.157613209315706, 63.139871733529226, 62.28222778865269, 63.19591590336391, 66.35257979801723, 60.85416453225272, 59.6581711087908, 58.79559394291469, 52.19420426232474, 46.604670320238384, 45.25417675290789, 43.17169393811907, 44.15343618392944, 43.38683101109096, 45.2484062739781, 44.000318731580464, 44.9878523009164, 46.77022157396589, 46.924450738089426, 47.30132450376238, 46.73269782747541, 47.000286851610454, 48.82596772057669, 50.24180909565517, 51.371676513126914, 56.868844577244346, 56.46715532030378, 54.929807322365896, 50.233123847416465, 52.96545778002058, 49.96060855048043, 46.212691170828684, 43.41926867621285, 42.22760745457241, 41.189372880118235, 39.8364509173802, 41.311251231602256, 40.28388016564505, 40.15296220779419, 41.95900051934378, 40.700921467372346, 47.82027850832258, 53.53883702414376, 55.15013469968523, 51.14591564450945, 44.65447425842285, 46.00968565259661, 49.20662825448172, 48.7720879146031, 50.329648222242085, 52.41552870614188, 47.89752163205828, 46.70400871549334, 44.61253840582711, 45.52696302958897, 43.06100566046578, 40.4486323765346, 37.5978490284511, 40.46760443278721, 38.06313862119402, 41.06964152199881, 40.92542471204485, 38.30175713130406, 38.926441873822895, 38.622989722660606, 36.12226356778826, 36.091097423008506, 37.38714838027954, 40.21970312935965, 38.29749093736921, 38.70852552141462, 37.607500076293945, 40.25831079483032, 40.346764836992534, 40.92519194739205, 43.28855916431972, 39.76983158929007, 35.494521617889404, 36.02652433940342, 36.98809943880354, 37.661293029785156, 38.94681051799229, 41.86228854315621, 39.84608112062727, 48.47857516152518, 47.957630498068674, 50.422635963984895, 54.431562423706055, 55.65445927211216, 46.221119335719514, 41.42586176736014, 47.426218373434885, 48.97195979527065, 49.82994072777884, 42.46742452893938, 39.41186039788382, 39.149739606039866, 38.52512434550694, 37.885730266571045, 39.05456665584019, 38.91501208714077, 39.01486117499215, 41.12915979112898, 41.438378947121755, 42.0338499886649, 40.85871853147234, 41.57016542979649, 41.4674710546221, 43.48055873598371, 42.15546778270176, 41.2217549596514, 42.32896430151803, 41.92428731918335, 42.163308824811665, 43.20101186207363, 43.83100502831595, 46.18619768960135, 46.64590440477644, 48.812456948416575, 47.78123310634068, 46.465768882206504, 47.365487643650596, 49.10570566994803, 52.067580291203086, 54.27618333271572, 56.603812490190776, 56.60389239447457, 59.36348411015102, 55.562517234257285, 60.549659729003906, 56.81252595356533, 64.23745087214878, 63.809601647513254, 71.17335809980119, 64.64112036568778, 32.6041648047311, 0.8439017108508519, 0.07949830272368022, 0.43626520303743227, 13.634673305920192, 75.12287398747036, 65.49550560542515, 60.65886456625802, 49.08868258340018, 26.692078113555908, 30.792105879102433, 48.66759743009295, 63.975316183907644, 27.957063674926758, 0.6005051742706979, 0.12394180361713682, 0.13295589706727437, 0.05705919036907809, 0.07489372337503092, 0.2615535637097699, 0.1776251465614353, 0.10265777499548026, 0.10935162473469973, 0.1213845679802554, 0.08510335481592587, 0.1776206275182111, 0.5205709263682365, 49.67758757727486, 69.20684419359479, 49.7946959904262, 41.18953963688442, 42.376830441611155, 67.00871208735875, 67.15390859331403, 76.2740306854248, 11.752547008650643, 0.48197031766176224, 0.31015607714653015, 0.43118712838206974, 21.533942188535416, 62.41724518367222, 66.07302597590855, 67.67731639317104, 65.83762100764683, 64.95947987692696, 69.87126568385533, 64.1189215523856, 63.9250876562936, 62.542291913713726, 55.16634832109724, 48.55017287390572, 47.425832748413086, 45.39745555605207, 46.43313666752407, 47.328238351004465, 49.209417956215994, 44.86574465887887, 47.61692558016096, 49.14489698410034, 49.302263259887695, 48.1506792477199, 49.87233863558088, 51.30527605329241, 53.0327649797712, 52.624495778764995, 54.598016943250386, 58.91429001944405, 57.102991921561106, 57.33359221049717, 53.469160488673616, 54.969603129795615, 52.5720785685948, 49.039628301348, 45.51129484176636, 42.37768507003784, 42.41340923309326, 42.194579192570274, 42.34506675175258, 42.31270899091448, 41.34215334483555, 44.40667717797415, 44.93829427446638, 49.48157542092459, 54.989909240177695, 55.42931679316929, 53.29465995516096, 45.16696991239275, 46.74973828451974, 51.95849009922573, 49.44745281764439, 53.925111702510286, 54.893120833805625, 48.971706186022075, 47.582465989249094, 46.504796913691926, 49.35461793627058, 44.97161783490862, 42.07798147201538, 40.76707526615688, 44.133269037519185, 40.26496369498116, 44.141749313899446, 44.033777781895225, 38.88148702893938, 41.018964835575645, 42.858806133270264, 39.85780273165022, 37.55752863202776, 39.67111158370972, 41.29502023969378, 42.54802015849522, 40.89076362337385, 40.69024208613804, 41.63100733075823, 41.770179748535156, 42.601868697575156, 45.95555223737444, 41.055873666490825, 37.40682915278843, 38.01456029074532, 37.81034231185913, 39.251061711992534, 39.57931545802525, 43.73543950489589, 41.580382755824495, 53.11355515888759, 49.5353718485151, 53.018920694078716, 57.175246238708496, 56.4021931375776, 49.37057447433472, 45.83623429707119, 48.689341817583355, 50.60748931339809, 53.941061292375835, 43.83105713980538, 42.41500037057059, 43.33035952704293, 39.19055332456316, 40.62867062432425, 39.63685349055699, 39.994925430842805, 41.58279725483486, 42.89988735743931, 43.44263546807425, 44.00833000455584, 43.42787749426705, 44.23627608163016, 44.63510268075125, 44.58324132646833, 43.1657532283238, 43.081839833940776, 44.0533960206168, 44.47547476632254, 44.37031378064837, 45.59250886099679, 47.050831522260395, 46.67325946262905, 50.2892062323434, 50.88293675013951, 50.64105953489031, 47.80586794444493, 52.054135526929585, 52.706630434308735, 54.99720137459891, 57.22019066129412, 58.222120898110525, 58.324749265398296, 63.131853512355256, 58.42427526201521, 64.60255091530937, 59.99149703979492, 69.85087966918945, 67.00627326965332, 78.48156370435441, 67.20811149052211, 41.33092505591256, 1.3723510801792145, 0.3360538589102881, 0.4885621496609279, 16.991842235837662, 83.08091681344169, 75.46441268920898, 67.60654899052211, 64.39612688337053, 43.26925359453474, 40.77273457390921, 61.03891713278634, 75.13456085750035, 36.65909876142229, 0.718948238662311, 0.3142074740358761, 0.22414883226156235, 0.1396942926304681, 0.17390647610383375], [0.06500906949596745, 0.06639745392437492, 0.08177490984754902, 0.014587914271812354, 0.020703177200630307, 0.018009688339329193, 0.0751088054052421, 0.1861297416367701, 36.19112368992397, 50.855922154017854, 42.716989925929475, 36.90702090944563, 23.79539496558053, 51.2168984413147, 57.0034624508449, 63.524065426417756, 11.074412379946027, 0.549634535397802, 0.5387936628290585, 0.21547730400093965, 7.113514040197645, 42.407433782305034, 57.32332624707903, 59.55897167750767, 61.83658422742571, 61.97998809814453, 60.19951220921108, 57.60841430936541, 55.73484298161098, 48.89109318596976, 44.10898855754307, 43.541536126817974, 43.586334637233186, 42.45950705664498, 41.607737813677105, 40.93469360896519, 42.45008529935564, 40.49835021155221, 43.2362322807312, 45.912379605429514, 48.527323722839355, 53.320072991507395, 54.7577942439488, 53.07643093381609, 50.81962129047939, 50.36390631539481, 52.19106715066092, 53.601200580596924, 50.19477326529366, 44.12240552902222, 48.2687360899789, 47.66142531803676, 48.71488339560372, 45.56649480547224, 42.80903966086251, 39.64702912739345, 39.58298063278198, 40.72291251591274, 38.74668502807617, 37.474094663347515, 40.798182351248606, 39.25545644760132, 39.36785050800869, 41.125873293195454, 46.670330796922954, 49.927660192762104, 52.003292083740234, 46.5497065952846, 46.93360151563372, 43.84091315950666, 47.521377427237375, 46.90888329914638, 48.918573311397004, 47.08926548276629, 44.06902946744646, 43.43148708343506, 43.2595226424081, 39.67039244515555, 38.27495098114014, 34.93400001525879, 36.90205642155239, 35.40611621311733, 34.75581693649292, 37.529089655194966, 37.91165052141462, 36.202171325683594, 34.964044025966096, 34.30422919137137, 35.47426414489746, 33.83297109603882, 35.52768884386335, 34.413197789873394, 34.422956534794395, 39.445659909929546, 38.86885172980172, 37.216469355991904, 37.14906488146101, 37.437675680433, 36.73076248168945, 33.74716779163906, 36.71010896137783, 35.76231908798218, 37.84654937471662, 40.69891691207886, 39.65077073233468, 40.54928398132324, 42.833639757973806, 46.34754180908203, 51.10438278743199, 49.614887033190044, 44.501332487378804, 37.09428528376988, 42.264717783246724, 46.91022082737514, 48.070660318647114, 44.29023926598685, 39.10452420370919, 36.65089293888637, 37.222378798893516, 36.70477621895926, 35.62660687310355, 36.92028849465506, 35.48934520993914, 39.52798564093453, 41.43364722388131, 38.36239406040737, 40.069882597242085, 39.886293819972444, 40.30587468828474, 40.34029606410435, 39.734572955540244, 39.82229396275112, 38.362800530024934, 39.51343263898577, 40.57776812144688, 41.23045063018799, 42.17154938834054, 38.756572314671104, 39.805552278246196, 40.8964125088283, 41.070878301348, 42.26700026648385, 43.381286348615376, 42.89047602244786, 44.84461866106306, 48.78016519546509, 51.711950642721995, 54.04244940621512, 56.25196613584246, 56.32668011529105, 55.99655730383736, 57.54008225032261, 56.741390296391074, 58.22778367996216, 65.53385271344865, 62.70614433288574, 65.47987910679409, 28.794705493109568, 0.7273489907383919, 0.3471094471003328, 0.26170194574764793, 6.866611974579947, 65.55212647574288, 58.231775420052664, 55.15929242542812, 35.70485053743635, 25.478323357445852, 30.739956174577983, 37.77106067112514, 54.05864218303135, 31.061004638671875, 0.3684264932359968, 0.041973457006471496, 0.09777459595352411, 0.03255329088174871, 0.02354863246104547, 0.03438536935885038, 0.06607633044144937, 0.03221259166353515, 0.014654037509379643, 0.026320473457287465, 0.03817569989977138, 0.09398155127252851, 0.35161581529038294, 45.332858153751914, 59.53702926635742, 50.3557665007455, 36.09739249093192, 29.834501675197057, 56.71597031184605, 62.46892588479178, 71.11636202675956, 12.32962008884975, 0.6666844859719276, 0.7492779940366745, 0.27015755059463636, 8.096463101250784, 50.281146321977886, 59.86230918339321, 63.97785227639334, 64.51984650748116, 63.2240561076573, 61.630868911743164, 57.9222331728254, 57.235091073172434, 50.46023614065987, 47.516350405556814, 44.824361188071116, 45.04206562042236, 44.674432958875386, 44.52195126669747, 43.58873176574707, 45.836084910801475, 43.24995149884905, 46.18401942934309, 46.58663279669625, 51.500642027173726, 53.689671993255615, 55.83353866849627, 56.61305359431675, 53.45521892820086, 52.636957372937886, 54.29670483725411, 55.66595506668091, 51.773306710379465, 47.389104570661274, 51.41952528272356, 49.48933655875069, 50.52951315471104, 48.10094404220581, 45.11355216162545, 42.07762016568865, 41.407129423958914, 41.438917432512554, 40.771126065935405, 39.942376204899375, 40.72034168243408, 40.739508288247244, 41.07762500217983, 43.28498084204537, 47.928663458142964, 53.008595670972554, 51.910189696720664, 48.35609579086304, 46.088238511766704, 46.78264147894723, 48.75267464773995, 49.455106258392334, 50.44918850490025, 49.498945917402, 46.68699605124337, 45.50177928379604, 44.20145171029227, 40.84766394751412, 42.232929774693076, 38.25872346333095, 39.34572744369507, 39.49014227730887, 36.60742848260062, 39.386190278189524, 39.07610259737287, 38.89446973800659, 36.886447293417795, 37.759210518428254, 36.86682210649763, 36.41555050441197, 38.26185710089547, 38.053821086883545, 38.83384323120117, 42.11945179530552, 39.71567038127354, 40.19434220450265, 40.25891181400844, 39.653411047799246, 39.957502433231895, 36.567611830575125, 36.96748413358416, 36.861148902348106, 39.5694385937282, 41.11239726202828, 42.0130227633885, 39.99259778431484, 44.03591782706124, 47.39161287035261, 52.033759934561594, 50.674772194453645, 44.0728440284729, 40.571400097438264, 45.21383203778948, 49.22390147617885, 51.03443874631609, 46.39038092749459, 39.7308417728969, 39.00951453617641, 38.94387837818691, 38.22698061806815, 38.684887749808176, 38.36315141405378, 37.87436301367623, 39.50020326886858, 42.668970925467356, 40.35407086781093, 41.39026962007795, 41.411034311567036, 41.67657014301845, 42.432353496551514, 41.05361202784947, 40.88448592594692, 39.95160688672747, 41.733427252088276, 42.03945371082851, 42.06878205708095, 42.99874285289219, 42.39465951919556, 42.7219683102199, 43.160139083862305, 43.587627002171104, 43.92136982509068, 44.83439786093575, 46.06070627485003, 47.63525840214321, 52.66999953133719, 52.906748976026265, 56.56370748792376, 58.94326400756836, 58.050972870418, 57.324385847364155, 60.18232931409563, 60.012876646859304, 62.076651436941965, 66.72842175619942, 66.6834738595145, 67.98157800946916, 32.499927929469514, 0.5955812356301716, 0.2055636223937784, 0.2778710281210286, 8.348581961223058, 72.41634219033378, 67.54367474147251, 61.81196675981794, 42.460479804447715, 25.907207863671438, 37.124655859810964, 45.87060356140137, 61.73379257747105, 39.25912162235805, 0.2465828556035246, 0.003753902540276093, 0.050116640582148514, 0.027161916252225637, 0.07599762521151986, 0.10457412073654787, 0.22723544734929288, 0.1431843510695866, 0.21897154221577303, 0.08691522652017218, 0.0768534139330898, 0.18957524746656418, 0.8048661340560231, 57.57385744367327, 67.80205045427594, 57.80441951751709, 50.60751015799386, 36.487495626722065, 64.2933074406215, 70.1788832800729, 77.1982592173985, 14.127789565495082, 0.9862997212580272, 0.916149188365255, 0.36029642234955517, 10.787589005061559, 54.590221064431326, 64.88302884783063, 67.39835316794259, 67.32509136199951, 67.65670108795166, 65.67712456839425, 62.14294419969831, 59.83856718880789, 53.46641942432949, 49.52480016435896, 49.055296489170615, 48.69132900238037, 46.98294414792742, 46.97835833685738, 46.776613916669575, 47.81187466212681, 44.55842236110142, 48.58686631066458, 49.356810092926025, 54.50245836802891, 58.44154848371233, 58.36206109183175, 58.48193836212158, 55.81163099833897, 57.20131240572248, 55.26895236968994, 57.76411649159023, 56.644379547664094, 50.5651330947876, 54.41384104319981, 50.96213231767927, 52.12404135295323, 51.11861617224557, 44.924484729766846, 44.413625376565115, 42.94929947171892, 44.66483054842268, 42.43252720151629, 42.92219802311489, 44.30084221703665, 42.728259904044016, 42.65189920152937, 45.57472494670323, 49.94889736175537, 54.85910940170288, 54.79197243281773, 49.96476009913853, 47.60826117651803, 48.04750197274344, 53.357339654650005, 52.021531105041504, 52.455091748918804, 50.87650966644287, 47.59069265638079, 47.79829788208008, 48.24480996813093, 45.85625900541033, 43.35896178654262, 39.43506738117763, 40.800023623875205, 41.8470824105399, 41.52569348471505, 42.36246851512364, 43.169091837746755, 41.091528347560335, 39.720211029052734, 40.240544251033235, 40.808472633361816, 39.208118370601106, 41.17657082421439, 39.99086420876639, 40.343797956194194, 44.034722736903596, 44.028806345803396, 42.73643445968628, 42.193905217306956, 41.60029281888689, 41.44481645311628, 37.26963002341134, 38.69212082454136, 37.084036690848215, 40.27021305901663, 42.413645471845356, 43.172583307538716, 42.61822475705828, 45.84926216942923, 49.55767209189278, 53.86577408654349, 52.59722062519619, 48.67379869733538, 42.954187529427664, 45.58259725570679, 49.201767989567344, 53.18693161010742, 49.45254584721157, 42.22747891289847, 40.63596970694405, 41.63604130063738, 40.49653673171997, 40.61229372024536, 41.10484457015991, 39.36099263599941, 43.454200744628906, 45.975441455841064, 40.59334250858852, 42.06195197786604, 42.52848877225603, 44.22816405977522, 46.39674547740391, 43.93502998352051, 43.38205759865897, 42.02463320323399, 43.59436328070504, 43.78035960878645, 44.947243554251536, 45.304561614990234, 42.99499429975237, 43.24657814843314, 45.46297706876482, 44.82032775878906, 45.87296594892229, 47.259308746882844, 48.11518437521798, 49.44926282337734, 55.41891186577933, 55.78153487614223, 59.149785314287456, 64.31042085375104, 61.84144101824079, 61.2908935546875, 62.91217926570347, 64.24654606410435, 66.147538457598, 71.59206349509103, 71.37304237910679, 69.25440461294991, 37.689117091042654, 1.1410359953130995, 0.5852660919938768, 0.3294254945857184, 10.353204999651227, 80.38040215628487, 72.21343394688198, 69.9011151450021, 53.917413098471506, 38.39440093721662, 38.77090297426496, 55.922555514744346, 72.2154906136649, 47.91681677954537, 0.39310831310493605, 0.10080558474042586, 0.13720895456416266, 0.1665193196386099, 0.13932199403643608], [0.02113866776094905, 0.1421241265322481, 0.011108255230023392, 0.0567522414826921, 0.04408626577683857, 0.11879096286637442, 0.06413433607667685, 0.2717343845537731, 32.42444617407662, 52.41058506284441, 44.66691848209926, 43.39866031919207, 26.887272119522095, 52.0150797026498, 54.040886061532156, 65.90709604535783, 14.404211487088885, 0.4233327598444053, 0.7837371506861278, 0.16235937071698053, 2.9954572192260196, 32.591758796146934, 56.96799189703805, 59.328562464032856, 62.467286109924316, 56.62101970400129, 57.303162574768066, 51.70159435272217, 49.59686688014439, 44.98996802738735, 46.710258620125906, 43.25827891486031, 41.54352603639875, 41.3114527293614, 42.82344675064087, 40.72116156986782, 42.47213888168335, 42.40288618632725, 46.04009444372994, 47.269223826272146, 51.609527247292654, 49.639403751918245, 52.25655392238072, 51.49769599097115, 58.32506193433489, 56.10547031675066, 52.29054798398699, 50.73764296940395, 49.123433998652864, 53.25819928305489, 53.28291055134365, 51.98811721801758, 49.07608549935477, 45.66447830200195, 44.10148797716413, 39.9850172996521, 38.160548891339985, 38.58481979370117, 37.4772560937064, 39.4734422819955, 38.35573073795864, 38.30516869681222, 39.33242859159197, 39.04677772521973, 39.38292462485177, 41.66624859401158, 44.95072112764631, 45.842466831207275, 44.110475472041536, 44.20657253265381, 44.564720903124126, 46.559447969709126, 48.827412945883616, 47.99962541035244, 45.408902713230674, 43.608235359191895, 40.04246847970145, 38.7242215020316, 39.769390378679546, 37.37896340233939, 37.19812958581107, 38.87757171903338, 42.49034663609096, 42.24878556387765, 42.597546918051584, 40.37847294126238, 39.764818464006694, 35.557600838797434, 33.95043386731829, 38.07160152707781, 38.81211274010794, 37.66384996686663, 39.770873819078716, 36.411673409598215, 34.939416136060444, 35.177857467106406, 35.55644048963274, 37.87974091938564, 37.15708657673427, 35.23610768999372, 38.0918242590768, 35.52685853413173, 39.21830790383475, 40.56532737186977, 40.14631972994123, 40.62190655299595, 46.61253220694405, 44.13305016926357, 40.678787980760845, 37.83024890082223, 37.62011800493513, 43.23644767488752, 46.80217286518642, 49.35425662994385, 46.41924721854073, 39.093271596091135, 38.91007191794259, 37.26000329426357, 36.896001066480366, 36.34770481927054, 37.158347674778526, 36.944621086120605, 38.903915813991, 38.63889067513602, 40.276202406202046, 38.779445784432546, 40.220926012311665, 38.00779969351632, 38.983524799346924, 38.61038569041661, 39.29826429912022, 40.36578900473458, 39.982046944754465, 40.03875814165388, 40.898107869284495, 42.034044538225444, 40.42776346206665, 40.70714357921055, 42.11486945833479, 40.16557318823678, 42.53222342899868, 42.455685547419954, 42.465684005192344, 44.269415514809744, 44.27716623033796, 48.31499719619751, 51.46106856209891, 51.861587047576904, 53.788697719573975, 54.44621964863369, 54.77608190264021, 54.5139923776899, 57.371821199144634, 59.605316162109375, 61.3827348436628, 64.02854633331299, 73.24392127990723, 29.930581365312847, 0.5146537210260118, 0.16182252738092626, 0.28839600192649023, 6.187941900321415, 62.02404662540981, 59.66787774222237, 51.397624560764854, 44.50525821958269, 28.3122364793505, 35.438776220594136, 48.05711480549404, 50.9361286844526, 25.237543957574026, 0.44294619453804834, 0.08258430712989398, 0.06909653730690479, 0.09414972617690053, 0.11792634640421186, 0.05657769852717008, 0.03842417603092534, 0.016203709711719836, 0.09836121661854641, 0.041013720112719705, 0.0628861098417214, 0.040233913742538006, 0.7114814764686993, 43.87200287410191, 58.344412667410715, 55.21762602669852, 40.57019458498274, 27.64882074083601, 59.35179724012102, 58.37724985395159, 72.50350039345878, 15.072621243340627, 0.3783863016537258, 0.9880904023136411, 0.2704082014305251, 3.4391628844397406, 39.98261669703892, 60.559630393981934, 62.074490547180176, 64.63219887869698, 60.50500365665981, 58.22981950214931, 53.484217235020225, 50.1940541267395, 46.68433141708374, 48.50334548950195, 47.32349273136684, 44.797895499638145, 41.972751004355295, 43.585250718253, 43.92411436353411, 44.54083299636841, 43.77895607267107, 48.40515007291521, 50.323902062007356, 53.805675642830984, 52.68011263438633, 54.52795825685774, 54.274432386670796, 60.57988439287458, 57.967438152858186, 52.56163542611258, 52.26605905805315, 50.92077316556658, 56.27584709439959, 55.69579063143049, 54.36167744227818, 52.106031622205464, 47.01132753917149, 47.55438484464373, 42.91449594497681, 40.59663595472063, 41.126113006046836, 38.786904675619944, 40.26109702246529, 40.201484952654155, 40.03431476865496, 41.45803887503487, 41.329069886888774, 42.26656947817121, 43.70967558452061, 47.752835818699424, 48.091292994362966, 44.871282373155864, 46.05596760341099, 46.60137687410627, 47.449293340955464, 48.9042079108102, 49.31891114371163, 47.81819404874529, 46.094988686697825, 42.75656339100429, 40.10797957011631, 41.39536264964512, 39.503920555114746, 39.291305678231375, 42.294671467372346, 44.543379511152, 43.211124965122764, 43.16919606072562, 41.00112533569336, 41.65880012512207, 37.675748756953645, 35.94296530314854, 40.422458512442454, 41.52616596221924, 39.74636057444981, 42.21046624864851, 36.47676760809762, 37.41803312301636, 40.60270173209054, 38.83233894620623, 39.41994115284511, 38.03686400822231, 38.03061410358974, 39.24875838415963, 37.58859750202724, 39.91173464911324, 41.28587988444737, 42.251116684504915, 41.87163734436035, 48.399938923971995, 45.31770413262503, 41.86886501312256, 41.167496476854595, 41.08271108354841, 44.94634028843471, 47.52660247257778, 51.72266476494925, 48.56593486240932, 41.20779602868216, 40.04955564226423, 38.932122026171, 39.173158509390696, 39.040361063820974, 37.5255252293178, 38.88691357203892, 40.601336411067415, 42.86348227092198, 40.68932492392403, 39.80019521713257, 42.329461097717285, 41.05561310904366, 41.16058301925659, 41.012621130262104, 41.30657161985125, 40.8240852355957, 42.680244377681184, 41.54581546783447, 42.16053301947457, 44.066125120435444, 43.31192248208182, 43.51209660938808, 43.1378562109811, 43.41427639552525, 44.505748067583355, 44.31329686301095, 46.26467064448765, 45.46303612845284, 46.09598227909633, 50.22920158931187, 52.89796992710659, 54.63285173688616, 57.254281997680664, 57.59381267002651, 58.353278568812776, 58.24563012804304, 58.589927264622276, 61.07458223615374, 65.29419544764927, 65.76953560965401, 74.31553500039237, 32.50915513719831, 0.45233250515801565, 0.2204772385635546, 0.3521280006638595, 6.154270929949624, 67.82047012874058, 65.70317336491176, 59.117045402526855, 53.55345950807844, 30.098790305001394, 39.44869974681309, 56.0996025630406, 59.00864655630929, 35.44542217254639, 0.5653500035405159, 0.01841394932541464, 0.17336778715252876, 0.014251428756064602, 0.13256537302264146, 0.12773866845028742, 0.2579583594841616, 0.14289776501911028, 0.2735403733594077, 0.06909083761274815, 0.1430107139583145, 0.1444016428930419, 1.5010825267859866, 57.46758822032383, 67.75333663395473, 58.47556686401367, 50.50396115439278, 41.21484497615269, 68.53254931313651, 64.76490947178432, 81.39828545706612, 17.762293236596243, 0.5276504893388066, 2.476475639002664, 0.24962521663733891, 4.464986673423222, 46.87826953615461, 66.14963681357247, 65.92259747641427, 68.17580100468227, 62.91736262185233, 61.1430914742606, 56.96939890725272, 53.20146376746041, 49.906308378492085, 51.63460677010672, 50.50489568710327, 46.281540870666504, 45.964070728846956, 46.42822081702096, 46.742595536368235, 45.92967019762312, 46.02912671225411, 50.75801508767264, 54.14123889378139, 56.60142925807408, 55.471811975751606, 58.491888182503835, 55.85628012248448, 60.83097839355469, 58.34680979592459, 56.67287758418492, 53.56993021283831, 52.68227699824742, 57.58919906616211, 58.65497629983084, 56.95810113634382, 54.201472827366416, 49.601306779044016, 49.87000751495361, 44.94675718035017, 42.63478578839983, 42.67164250782558, 40.88478469848633, 44.713269914899556, 41.516577448163716, 41.223311356135774, 43.74584443228585, 42.59060566765921, 45.22499431882586, 47.208020618983674, 49.868663038526265, 50.68260628836495, 47.95655700138637, 48.979502064841135, 48.5828537259783, 50.27933284214565, 53.76361124856131, 50.090029171534944, 51.69630677359444, 48.82338646480015, 44.1883613041469, 43.22938135692051, 43.921348980494905, 44.560065610068186, 39.909483432769775, 42.983877182006836, 47.00480318069458, 46.419532094682964, 44.614619391305105, 43.236399037497385, 43.52963386263166, 39.37104320526123, 38.6747260093689, 42.84758479254586, 43.45040702819824, 41.570832456861226, 42.30156755447388, 38.11264453615461, 41.55811725343977, 40.952345507485525, 38.324067796979634, 41.3012249810355, 41.25217069898333, 38.30717325210571, 40.876825537000386, 39.05954156603132, 39.85224069867815, 45.298179694584434, 43.01185410363333, 42.804474694388254, 51.556846005576, 47.37333563395909, 45.7379971912929, 43.66198314939226, 42.38010304314749, 43.76795012610299, 49.78543404170445, 56.04514258248465, 50.6071766444615, 43.23125042234148, 42.4006210735866, 41.41107252665928, 42.253194195883616, 40.75782721383231, 41.28944778442383, 41.61690248761858, 44.00778457096645, 44.06189019339425, 43.88427339281355, 42.32399633952549, 43.85004309245518, 41.93574142456055, 42.48373889923096, 45.0974497113909, 43.007243973868235, 43.93244177954537, 44.395970003945486, 44.966066224234446, 46.08448648452759, 46.849545683179585, 46.96244696208409, 44.79508147920881, 45.86552790233067, 45.842268807547434, 47.4438042640686, 48.716894899095806, 49.00680501120431, 48.23776796885899, 48.65004628045218, 55.56205517905099, 55.37986993789673, 57.77931220190865, 59.54664557320731, 60.29372978210449, 61.06673771994454, 62.64839785439627, 63.14003849029541, 68.01973751613072, 67.71348871503557, 71.65381213596889, 77.16979244777134, 36.96428796223232, 0.797262470637049, 0.5224768498114177, 0.3764762798590319, 7.9420584951128275, 76.48751408713204, 71.21224021911621, 67.63244492667062, 62.25337886810303, 45.098439829690115, 50.08187198638916, 65.02494580405099, 70.80480480194092, 43.90573985236031, 0.5590640551277569, 0.14451593533158302, 0.21039343465651783, 0.13982032372483186, 0.169116968821202], [0.015246359564896141, 0.040735629320676835, 0.02557350818200835, 0.07580671938402311, 0.0615438793652824, 0.05616499317277755, 0.02335096163941281, 0.7982128539255687, 40.304731709616526, 46.8688998903547, 39.12826272419521, 41.280731269291465, 31.481207370758057, 53.0648204939706, 52.49044418334961, 67.48175934382847, 14.966753278459821, 0.37516874287809643, 0.563124842941761, 0.28392440187079565, 0.5353251546621323, 17.73906193460737, 60.273656436375205, 57.184018339429585, 62.24131679534912, 57.55247436250959, 54.69055305208479, 52.16961458751133, 52.132330553872244, 47.05511508669172, 48.323748452322825, 43.0762882232666, 42.70504944665091, 41.300009046282085, 42.089261872427805, 40.937090737479075, 42.15059362139021, 42.90377834865025, 45.17863941192627, 48.47289848327637, 51.22956500734602, 49.244912828717915, 46.95788894380842, 44.71144253867013, 44.34592907769339, 47.42321327754429, 54.16722168241228, 48.38052913120815, 53.849504879542756, 51.01582104819161, 51.12077011380877, 47.818037714277, 49.67540584291731, 44.149878706250874, 43.11829703194754, 40.20396893365042, 39.123857566288535, 37.34253052302769, 37.48615673610142, 39.22946323667254, 38.67758171898978, 37.77714729309082, 39.46678243364607, 38.0372531073434, 39.667328289576936, 40.496779918670654, 43.599195752825054, 41.78081396647862, 45.962055751255576, 43.05359888076782, 45.289195673806326, 45.83915254047939, 46.885123934064595, 46.15977716445923, 46.168347767421174, 46.32716621671404, 46.08576842716762, 44.15145247323172, 42.19115373066494, 40.091286523001536, 39.639271463666645, 37.521464007241384, 40.75005912780762, 39.04811872754778, 39.28962768827166, 39.54941735948835, 43.686458178928916, 42.40352542059762, 36.94704948152815, 37.744264943259104, 37.93098040989467, 44.15560054779053, 42.72576897484915, 38.81820978437151, 37.419092723301475, 34.81193058831351, 36.35641786030361, 38.24466378348214, 39.05926363808768, 38.80513327462332, 41.09745168685913, 39.883267879486084, 41.25074979237148, 41.41202442986624, 42.54388945443289, 44.97443185533796, 45.035377979278564, 40.83005026408604, 40.0671762738909, 40.866816656930105, 42.702944142477854, 43.29151214872088, 45.14800827843802, 43.45017078944615, 37.4021669115339, 37.280080114092144, 37.12535067967006, 38.17502893720354, 37.2482191494533, 35.944368839263916, 37.760985783168245, 36.74536759512765, 37.21042442321777, 37.294316973005024, 38.39559602737427, 39.09961877550398, 38.70182745797293, 37.54100581577846, 38.20623329707554, 39.0800769669669, 40.513125555855886, 40.19387320109776, 41.33649403708321, 39.3028153691973, 40.7722864151001, 41.25321292877197, 41.145140647888184, 39.87319646562849, 40.92080415998186, 40.99305847712925, 44.04232406616211, 43.48047188350132, 44.3064216205052, 41.941397258213584, 42.71424191338675, 42.238828795296804, 46.870793274470735, 49.9322703225272, 53.153722694941926, 53.079873766217915, 56.915407930101665, 55.465009689331055, 58.722054209027974, 53.56288473946707, 64.86041940961564, 60.33578722817557, 75.49054486410958, 22.69112123761858, 0.41796750202775, 0.2881824533854212, 0.17177257846508706, 1.880080704178129, 59.14588042667934, 63.835740770612446, 53.253606523786274, 44.565801348005024, 33.699169635772705, 36.92000361851284, 36.108332429613384, 50.313792433057515, 28.413862568991526, 0.20260196631508215, 0.057406376382069926, 0.04413547652906605, 0.0751041370843138, 0.018810707410531383, 0.03605590561138732, 0.05175437984455909, 0.08704707265964576, 0.07189436789069857, 0.0527215365187398, 0.05443874240985938, 0.035034184543682, 1.398912632039615, 50.020828587668284, 56.49197081157139, 45.69550895690918, 35.196732248578755, 32.351319858006065, 59.54392187935965, 57.94510316848755, 73.75408581324986, 16.66655363355364, 0.45194462739995545, 0.771662104342665, 0.27010530339820044, 0.8974822014570236, 21.30934340613229, 64.54633304050991, 60.209489822387695, 64.49579184395927, 57.33845247541155, 56.272261823926655, 52.40273012433733, 53.756617886679514, 50.1889819417681, 51.28889914921352, 45.35117360523769, 46.81908130645752, 42.91952644075666, 43.72801188060215, 43.93730204445975, 46.17742558888027, 44.54278196607317, 47.91502414430891, 50.816289629255024, 54.03319093159267, 52.099840777260916, 49.057182925088064, 47.015621525900706, 47.39150169917515, 54.2563670703343, 59.18686785016741, 48.979585443224224, 55.72450753620693, 52.37117140633719, 53.67989935193743, 50.23514229910714, 50.47595991407122, 47.07132870810372, 44.7073153087071, 41.82236419405256, 40.96080493927002, 39.41458061763218, 39.25856229237148, 38.41030536379133, 41.22779641832624, 40.79301636559622, 41.04352324349539, 39.20767715999058, 40.64591952732631, 41.96141849245344, 44.943460260118755, 46.0076185635158, 45.32612187521798, 46.04210247312273, 47.31459208897182, 47.07776621409825, 49.81242431913103, 47.34994452340262, 48.36922441210066, 46.56913375854492, 47.279309136526926, 44.35777575629098, 44.708458287375315, 43.159176758357454, 41.17694255283901, 40.97732775551932, 44.01908234187535, 42.15415457316807, 42.080430712018696, 40.51878833770752, 43.612317425864084, 42.19207089287894, 37.45687355313982, 38.71039458683559, 37.878038610730854, 41.9492313521249, 43.17218031202044, 40.33129814692906, 41.293870312826975, 37.726995195661274, 37.305138792310444, 40.47785302570888, 41.15618828364781, 40.96268095288958, 42.393037114824565, 42.39155714852469, 42.339734009334016, 42.80110829217093, 43.5549704687936, 45.7698894228254, 45.20354870387486, 41.81991147994995, 42.52241257258824, 43.77198008128575, 43.81703914914812, 44.87590292521885, 47.09274653026036, 46.0447427885873, 40.996567317417686, 39.50408731188093, 39.45333072117397, 40.3142854826791, 38.612115791865754, 38.41315412521362, 39.25832257952009, 39.310051918029785, 38.7242180279323, 39.915406772068565, 40.495873178754536, 41.40449605669294, 40.54916933604649, 40.073311533246724, 41.20474229540144, 40.171385356358115, 41.897613184792654, 43.765247276851106, 43.52217844554356, 41.562623160226, 44.266184602464946, 43.26549809319632, 43.13560152053833, 42.31563070842198, 43.62576913833618, 42.459795406886506, 45.281913961683, 44.28240169797625, 45.65730776105608, 45.099297932216096, 46.050124168395996, 45.41490943091256, 47.82650409426008, 52.73796680995396, 55.891163553510395, 55.481063502175466, 59.14373343331473, 58.66862951006208, 59.2705727985927, 57.04566928318569, 66.38132449558803, 65.56720406668526, 77.98357241494315, 24.68824369566781, 0.49059569197041647, 0.21959491233740533, 0.16239134328705923, 2.528449032987867, 65.35844544001988, 69.80630697522844, 59.720190729413716, 49.65479053769793, 41.17015763691494, 44.544491222926546, 44.326088496616904, 59.56134101322719, 36.88961219787598, 0.22507507327411855, 0.03341699471431119, 0.12490866173590932, 0.07945355333920036, 0.046609082724899054, 0.17373571598104068, 0.19076676853001118, 0.20384102554193564, 0.15571504724877222, 0.22829145139881543, 0.1755971818098, 0.25371667423418587, 2.3087385254246846, 64.37418447222028, 63.05324854169573, 51.59175722939627, 51.04948854446411, 44.19966949735369, 68.29718603406633, 62.64225564684187, 81.1519718170166, 18.78681901523045, 0.5522520520857402, 2.5354263271604265, 1.1891905942133494, 0.9350752128022057, 26.071973970958165, 68.80796200888497, 63.58935764857701, 67.71765763419015, 64.16069412231445, 59.55337837764195, 56.48968138013567, 56.029762744903564, 51.41195869445801, 53.72164412907192, 47.900151525224956, 49.02638850893293, 45.229065963200156, 46.94429131916591, 45.79184225627354, 48.61822353090559, 46.81058713368007, 51.27511739730835, 53.65744277409145, 56.720768042973106, 54.60026815959385, 50.93824093682425, 49.81090613773891, 53.12041303089687, 52.71859870638166, 56.68436990465437, 52.05474696840559, 59.30276380266462, 55.9740903036935, 58.02355180467878, 52.928364821842735, 55.52960361753191, 49.87022985730852, 46.768303871154785, 45.32481908798218, 42.9945878301348, 41.2832430430821, 41.82352801731655, 42.6998348236084, 44.33066388538906, 43.995687757219585, 45.3374856540135, 41.1997778075082, 43.07602071762085, 45.057038988385884, 48.49534116472517, 47.27839197431292, 48.810792854854036, 46.94169269289289, 50.61242600849697, 50.77673353467669, 52.872584683554514, 50.21236263002668, 51.43950482777187, 49.07380301611764, 48.56657062258039, 47.45360122408186, 46.22630616596767, 44.76873391015189, 43.74734871728079, 44.42276225771223, 43.8378073147365, 42.4986184665135, 43.332089628492085, 40.71927513395037, 43.833461216517854, 43.52416215624128, 38.150241238730295, 38.59873703547886, 38.50156300408499, 43.357137884412495, 46.32678059169224, 43.38961376462664, 41.56635781696865, 37.75880057471139, 39.228261198316304, 41.769887924194336, 42.013679368155344, 42.53752837862287, 44.644402844565256, 42.13675280979702, 45.2652348109654, 45.960023403167725, 46.731318610055105, 49.19942644664219, 48.086154801504954, 45.13478585651943, 45.469015053340364, 45.556020396096365, 43.90846354620797, 48.21326167242867, 48.861507756369456, 50.18123817443848, 44.36231640407017, 41.07995959690639, 41.61909811837332, 42.63248593466622, 40.66161898204258, 40.54374974114554, 41.46016502380371, 41.27328627450125, 41.427136761801584, 41.22828279222761, 42.998266901288716, 42.26810155596052, 43.395047255924766, 42.39550025122506, 43.61094168254307, 43.47120993477957, 44.20207357406616, 46.886899198804585, 45.51878847394671, 43.66183376312256, 45.47578607286726, 46.936623982020784, 44.395323821476524, 44.07001611164638, 45.78360169274466, 45.680730138506206, 47.88454587118966, 47.74995231628418, 48.34520101547241, 48.13810995646885, 47.46199812207903, 46.43836866106306, 51.154090200151714, 55.33363662447248, 59.71344402858189, 58.76202719552176, 62.38018349238804, 62.57372556413923, 64.56519739968437, 60.568336486816406, 70.75133146558488, 68.16041074480329, 82.12534495762416, 29.513456685202463, 0.6282890119722911, 0.9198276081255504, 0.33105362579226494, 3.4777340718678067, 72.71070262363979, 77.3590474809919, 69.02350902557373, 61.23437690734863, 47.24148314339774, 49.80427755628313, 52.811245986393516, 70.68360042572021, 49.035514967782156, 0.23717618893299783, 0.22795679792761803, 0.1973316626889365, 0.16806191472070559, 0.1303525346198252], [0.053633545259279866, 0.06198118161410093, 0.031809273841125627, 0.053558299118386846, 0.03319435380399227, 0.022484112797038894, 0.10572899412363768, 0.7480634163532938, 44.31724343981062, 44.32602596282959, 51.52450214113508, 32.91032327924456, 26.19671150616237, 51.83516999653408, 51.25299433299473, 69.7145004272461, 14.20994506563459, 0.38855488172599245, 0.2463339146758829, 0.6397806810481208, 0.15518752698387417, 7.625697459493365, 49.910157680511475, 56.90424564906529, 60.999625069754465, 55.85906287602016, 57.97115543910435, 56.63500990186419, 56.41747917447771, 53.91747563225882, 52.194106987544465, 50.41358246122088, 46.610270568302695, 41.451087202344624, 40.79215478897095, 40.38397938864571, 41.880471978868755, 43.06894397735596, 43.76908963067191, 44.75305182593209, 48.609868322099956, 50.20595639092581, 53.515800271715435, 53.8118873323713, 51.21214934757778, 39.612513950892854, 40.41770594460623, 54.91450391496931, 52.165945938655305, 51.670362200055806, 49.136041504996165, 47.2118421282087, 44.73699106488909, 41.94629226412092, 41.13162292752947, 37.692462648664204, 37.654619285038535, 38.106359890529085, 39.73281158719744, 38.622551986149375, 38.9165163721357, 38.23220566340855, 36.89045292990548, 39.41570969990322, 39.6212408883231, 42.03516667229788, 41.35454198292324, 41.68931661333357, 43.47299909591675, 44.289429800851, 46.52263988767351, 45.515203203473774, 48.50127492632185, 46.20830338341849, 46.83252954483032, 45.852319376809255, 48.80931288855416, 46.61755575452532, 44.31574610301426, 43.791511467524934, 39.33010789326259, 40.659819398607524, 39.015826974596294, 37.16600111552647, 36.649968828473774, 36.998695441654746, 41.94432592391968, 47.483002526419504, 34.79196146556309, 35.00297130857195, 39.67897694451468, 42.2443665095738, 42.20360490253994, 49.410026345934185, 39.691184929439, 31.457402842385427, 38.20444066183907, 40.03254992621285, 39.74095835004534, 38.80450446265084, 40.75795228140694, 38.23818111419678, 40.896023409707205, 43.594290324619834, 43.06738063267299, 42.84165450504848, 42.16228396551949, 44.68270826339722, 45.01754542759487, 39.614049502781455, 43.12333447592599, 39.563900879451204, 42.831537927900044, 35.92909322466169, 37.020193168095176, 36.175330434526714, 36.661158902304514, 36.58839736665998, 36.641717842647004, 35.435131890433176, 37.51381056649344, 36.80584471566336, 37.61367702484131, 40.42965337208339, 39.84325320380074, 37.9773005758013, 38.45681313105992, 38.10943794250488, 38.178169522966655, 39.91143587657383, 40.61812673296247, 39.1798426764352, 42.59380531311035, 42.66635145459856, 41.79631887163435, 41.70271968841553, 43.0346302986145, 40.917875494275776, 44.08318989617484, 44.72478655406407, 47.95244714191982, 47.52776976994106, 50.452273505074636, 45.494716439928325, 47.34737021582467, 44.272288594927105, 45.12943574360439, 42.96765661239624, 48.69916657039097, 49.14286463601248, 52.18355962208339, 52.074955804007395, 54.28312110900879, 54.082714217049734, 64.35335377284459, 61.26753371102469, 75.34705066680908, 16.477522679737636, 0.5359695457986423, 0.32873241177627016, 0.23988443932362966, 3.5897900589874814, 56.780967235565186, 65.87644059317452, 50.61675821031843, 47.63206570489066, 20.969877004623413, 25.194699628012522, 41.85362066541399, 48.181365966796875, 18.44657962662833, 0.9471634498664311, 0.09661202797932283, 0.06336107078407492, 0.027593052314062203, 0.11497683610234942, 0.009997138869948685, 0.03221897667806063, 0.02811073212485228, 0.02739953582308122, 0.020366700166570287, 0.04092602963958468, 0.03866448260045477, 1.6733356437512805, 55.29148885181972, 47.79343066896711, 55.61295420782906, 39.93257229668753, 29.78999498912266, 57.71581956318447, 55.36654676709856, 73.91726425715855, 15.913921288081578, 0.34889518842101097, 0.5292187737567084, 0.5625073217919895, 0.4692439319831984, 7.860529201371329, 57.09745420728411, 60.64400931767055, 62.90218080793108, 57.066743169512065, 60.95221751076834, 58.23697962079729, 57.509378160749165, 56.481392179216655, 55.66137620380947, 53.46777432305472, 48.41048976353237, 43.25348465783255, 42.80047600609915, 42.43873194285801, 44.47803865160261, 46.26744644982474, 45.25394746235439, 47.39601802825928, 50.78478649684361, 52.5517064503261, 55.92267710821969, 54.939538274492534, 51.66756902422224, 42.20098195757185, 45.60998010635376, 55.43263108389718, 54.665879998888286, 53.51998308726719, 51.21505716868809, 47.01796654292515, 45.84925522123064, 44.06622586931501, 42.08746576309204, 38.99072313308716, 40.76157924107143, 41.849205085209434, 41.1874760219029, 41.11179971694946, 40.08650268827166, 41.853433064052034, 39.292935030800955, 39.99005821772984, 42.500233922685894, 43.78993075234549, 43.249663148607524, 43.20685182298933, 45.07858535221645, 47.2786351612636, 47.915208271571565, 48.54766457421439, 51.41154180254255, 49.17494099480765, 48.63400288990566, 48.66857712609427, 48.87506021772112, 46.20773363113403, 45.81281886781965, 45.51044021333967, 42.61548021861485, 42.88771063940865, 39.121064390454976, 35.759307043892996, 38.250965799604145, 36.81866414206368, 42.59622328622, 47.2923126901899, 35.17595713479178, 35.975597517830984, 39.66700519834246, 41.938871588025776, 44.343789032527376, 49.25916010992867, 40.91567291532244, 33.69378130776541, 39.463145051683696, 41.369692529950825, 41.40968288694109, 40.32455492019653, 42.44359915597098, 40.915120533534456, 42.773190430232454, 45.409170218876426, 44.32583836146763, 46.31877626691546, 44.92126771381923, 46.23859405517578, 46.50383458818708, 41.661864280700684, 43.24072081702096, 41.57515771048409, 43.995527948652, 38.02164397920881, 40.02069282531738, 38.538662910461426, 39.09046452386038, 38.80249990735735, 37.454320090157644, 36.57545287268502, 38.34458930151803, 39.681287220546174, 39.39588301522391, 41.39512988499233, 40.73391498838152, 40.310457025255474, 40.11885697501046, 40.01823663711548, 40.192830971309114, 40.31919091088431, 42.15965059825352, 41.51365225655692, 45.991366727011545, 44.273542744772776, 44.499821254185264, 43.391232694898335, 45.050549370901926, 42.64124413899013, 45.54178006308419, 48.044086933135986, 51.26926701409476, 50.5516813823155, 52.44476672581264, 48.673416546412874, 49.7144581930978, 46.19552912030901, 47.80508279800415, 45.83356271471296, 51.67622995376587, 50.999096734183176, 55.1809777532305, 54.53092166355678, 57.210317271096365, 54.77374035971505, 67.16786752428327, 63.59216472080776, 77.42886298043388, 19.211640562329972, 0.5393072324139732, 0.3026601922299181, 0.2621003272277968, 4.443762966564723, 62.84234292166573, 70.98388072422573, 57.68848534992763, 55.16702924455915, 26.125600167683192, 30.923732553209575, 47.76893826893398, 57.059489250183105, 30.654851164136613, 0.7574300765991211, 0.04603219564471926, 0.08068047357457024, 0.03556613224957671, 0.07680819635944706, 0.12816177574651583, 0.11675496426011835, 0.15899262923215116, 0.1439264105366809, 0.08144514861383609, 0.19614238079105104, 0.21852516116840498, 2.392086075884955, 69.39114516122001, 57.54525865827288, 62.54549503326416, 43.007747718266074, 39.97150305339268, 65.6139029094151, 60.76331683567592, 82.03005041394914, 19.175702742167882, 0.5241819811718804, 0.7687998265028, 1.3982427822692054, 0.6801706137401717, 10.022213663373675, 62.1712372643607, 64.88545376913888, 65.49183000837053, 60.27893706730434, 63.17826053074428, 62.27515452248709, 60.718563488551546, 59.849003383091514, 58.95971734183175, 55.46143136705671, 50.650265898023335, 45.78874683380127, 45.16449287959507, 44.43179838997977, 47.09442799431937, 48.28657211576189, 48.04969760349819, 49.91425016948155, 54.01886722019741, 54.07404286520821, 57.935469491141184, 57.47652012961251, 53.79738644191197, 43.62692253930228, 44.510945320129395, 57.158111980983186, 57.95125927243914, 54.771919931684224, 54.563508714948384, 50.57207434517996, 49.14243732179914, 46.247188976832796, 44.87465919767107, 41.07784734453474, 43.296577385493684, 43.825668811798096, 45.11746399743216, 42.25627224785941, 42.20098543167114, 44.36184740066528, 40.31403882162911, 43.31286743709019, 44.179429394858225, 46.4906017439706, 44.28462859562465, 44.53067473002842, 48.41019099099295, 49.59937170573643, 50.75868558883667, 49.42546871730259, 53.77890770775931, 52.08658708844866, 52.73126874651228, 52.15325852802822, 52.62639263698033, 49.65928602218628, 49.75120374134609, 47.99017586026873, 45.70539276940482, 43.59334189551217, 41.07267093658447, 37.747155393872944, 38.16132361548287, 39.00363983426775, 42.213019711630686, 47.37890461512974, 36.49755661828177, 37.4545841217041, 41.39533485685076, 42.01370021275112, 46.41645404270717, 49.94392939976284, 41.34945590155465, 35.640892369406565, 42.78948048182896, 44.80280787604195, 42.82183824266706, 43.17204829624721, 45.99543489728655, 43.63896376746041, 44.50853429521833, 48.306666306086946, 47.17079564503261, 48.84653786250523, 47.431895051683696, 47.95469488416399, 48.459134101867676, 42.91279363632202, 47.39104659216744, 42.78494330814907, 46.2377324785505, 40.44029106412615, 42.76546403339931, 41.55900314876011, 41.296031202588765, 41.61720126015799, 39.19612577983311, 39.207927295139854, 39.79673848833357, 40.304300921303884, 40.34016752243042, 44.59899289267403, 43.91806943075997, 42.34207207815987, 42.71481166567121, 41.68953548158918, 41.73153386797224, 43.20015375954764, 44.00592245374407, 43.388581957135884, 48.14332110541207, 48.954582350594656, 46.26028980527605, 44.616266114371165, 46.972848415374756, 45.442639691489084, 49.40329354149954, 51.064180510384695, 52.03482648304531, 52.92115606580462, 55.622056347983225, 50.951425143650596, 52.35757030759539, 49.1910469191415, 49.652233600616455, 48.75911562783377, 55.361085483006065, 54.31249114445278, 58.19648551940918, 58.46007932935442, 61.5741924558367, 61.459665298461914, 69.5015937260219, 68.06022466932023, 80.87253611428397, 22.598498276301793, 0.6610717528632709, 1.632839588182313, 0.3027900095496859, 6.0939180084637234, 68.22158963339669, 77.8904526574271, 65.56021417890275, 64.60178661346436, 36.64366333825247, 41.62298910958426, 58.10350819996425, 68.40371581486293, 47.304305280957905, 0.9904307510171617, 0.18669273571244308, 0.17099454307130404, 0.12722247972020082, 0.1912891183580671], [0.027375642908737063, 0.03816372375669224, 0.05057027177619083, 0.1318867565797908, 0.07793331598596913, 0.21172377041407994, 0.1510332641857011, 2.426516354084015, 43.61010789871216, 50.92184318814959, 39.91322503771101, 14.037117310932704, 34.56284809112549, 45.91350173950195, 54.600612095424104, 68.60896560123989, 12.251704726900373, 0.2918214909732342, 0.17283880125199044, 0.4225419137094702, 0.3790684736200741, 1.060105875134468, 33.4471549987793, 57.29983786174229, 62.66011251722063, 56.35987860815865, 60.14142526899065, 58.77201175689697, 58.50290107727051, 57.766117572784424, 56.19167314256941, 49.63568646567208, 45.57519742420742, 40.49087047576904, 40.62938628877912, 40.03331422805786, 42.052773407527376, 40.421308585575645, 46.05753442219326, 45.432325090680806, 50.11833960669381, 48.20237731933594, 51.81872361046927, 49.55965232849121, 52.82547589710781, 43.688643387385774, 40.126614638737266, 52.40781620570591, 50.73240402766636, 49.25897945676531, 46.84731183733259, 43.600724356515066, 39.357754775456016, 38.947567871638704, 39.05597366605486, 38.64601952689034, 38.84482833317348, 38.073811054229736, 40.58455303737095, 39.33812264033726, 38.902404580797466, 37.824203968048096, 38.34664249420166, 38.487673555101665, 39.24860552379063, 39.76107338496617, 40.736687319619314, 45.05399567740304, 45.9029335294451, 43.68394987923758, 44.998899936676025, 45.12922034944807, 46.10860368183681, 45.25262383052281, 46.33562217439924, 46.06150531768799, 47.10872391292027, 45.065887519291465, 45.91482189723423, 44.5304593358721, 45.976177964891704, 48.15328482219151, 43.619838850838796, 38.028234345572336, 39.72496012278965, 36.03470931734358, 40.63306883403233, 53.86595473970686, 36.15050452096121, 31.669802325112478, 40.40756504876273, 44.7071659224374, 35.289136341639924, 31.43724959237235, 38.91824994768415, 35.98983437674386, 39.50405951908657, 38.709814412253245, 42.27215930393764, 39.012672492435996, 41.42237377166748, 41.58155700138637, 43.24705410003662, 43.88263709204537, 43.089729513440815, 42.0481459072658, 42.65635299682617, 41.397030217306956, 39.72132274082729, 41.48259033475603, 40.71790286472866, 38.477959973471506, 37.867147309439524, 36.930238315037315, 36.659505231039866, 35.86463131223406, 37.72409432274954, 36.74090685163225, 37.259673254830496, 36.658928530556814, 36.79634305409023, 36.736293247767854, 38.29955802645002, 38.869612557547434, 40.10429007666451, 37.94304595674787, 39.91963822501046, 39.29724291392735, 38.12293481826782, 37.24178164345877, 39.57302386420113, 40.37844862256731, 44.00472041538784, 44.61052342823574, 47.120188440595356, 45.960169315338135, 45.021811621529714, 42.89222002029419, 44.98366948536464, 47.46725443431309, 51.3743758882795, 51.238583769117085, 54.65464128766741, 51.06239134924752, 51.57975769042969, 47.84804698399135, 47.49163218906948, 43.69847856249128, 44.020426818302695, 44.603488377162385, 50.03718812125069, 48.499537876674104, 54.26606328146798, 55.41966574532645, 64.87372520991734, 57.411742074149, 75.09756170000348, 14.090608886310033, 0.5594440347382, 0.22629844477134092, 0.33739977383187836, 5.728008934429713, 65.1087897164481, 58.29983302525112, 54.050773348127095, 37.65886116027832, 26.66942698614938, 26.312539713723318, 31.04764325278146, 47.693480832236155, 38.255322320120676, 1.2595351338386536, 0.08116878808609077, 0.03634197597524949, 0.039084892719984055, 0.06422026575143848, 0.04285410725112472, 0.06653371054146971, 0.028505191672593355, 0.14161409890013082, 0.08406174927949905, 0.09430520569107362, 0.04917263891547918, 3.21985884649413, 55.80506147657122, 53.96402161461966, 49.99095480782645, 22.998247248785837, 34.68106126785278, 54.95741251536778, 57.78498888015747, 75.94456795283726, 12.691041929381234, 0.36208897616182056, 0.05861009071980204, 1.5596476984875542, 0.4249425706054483, 1.1064335320677077, 38.86952917916434, 59.69271060398647, 64.4622528893607, 60.45759609767369, 64.84552942003522, 60.72289916447231, 61.81504481179373, 59.092219488961355, 58.27612229755947, 52.99460547310965, 48.01427568708147, 43.94837399891445, 43.11237369264875, 42.25247505732945, 42.303544316973, 44.114581857408794, 50.12306090763637, 47.099177088056294, 51.26304490225655, 50.231428486960276, 53.07275186266218, 52.961354868752615, 53.81990902764456, 44.03505972453526, 41.947744437626426, 54.81208399363926, 52.715864590236116, 52.20252473013741, 48.1260096686227, 45.308765275137766, 41.241904735565186, 40.28648921421596, 40.58281251362392, 39.13484614236014, 40.22601209368025, 41.51099457059588, 42.830106598990305, 41.11173370906285, 41.2744778905596, 41.191061292375835, 39.730122634342735, 40.29996871948242, 39.74616949898856, 40.75333520344326, 43.28253507614136, 46.02428034373692, 47.1694199017116, 46.88215357916695, 47.180589130946565, 48.24017899377005, 50.69665902001517, 48.42706816537039, 49.95785011563982, 47.65060002463204, 49.38962296077183, 47.357247080121724, 48.90453100204468, 48.0888090133667, 47.34049497331892, 49.18550225666591, 47.310555185590474, 38.99159165791103, 40.42018297740391, 36.222477436065674, 40.8866468157087, 53.00151893070766, 37.35249423980713, 33.03878852299282, 40.33004399708339, 44.61265999930245, 36.29274456841605, 34.859358991895405, 39.861443587711875, 37.65489026478359, 40.46065623419625, 39.75069972446987, 44.44904381888253, 40.811161586216514, 43.56631340299334, 44.42592716217041, 45.79604244232178, 45.724993637629915, 47.06712852205549, 44.665452412196565, 45.05720921925136, 44.574865273066926, 42.238460540771484, 42.9269505909511, 43.2299302646092, 40.24415731430054, 39.87195273808071, 39.6088661466326, 39.61189556121826, 37.783289500645225, 39.616658551352366, 39.29060043607439, 38.3150177683149, 37.688741888318745, 38.719736439841135, 37.599693775177, 40.78940330232893, 40.83665452684675, 40.967343194144114, 40.11067199707031, 41.937068530491416, 41.65345696040562, 40.58091218130929, 39.152216638837544, 42.48127923692976, 44.11341456004551, 47.0485976764134, 47.23960018157959, 49.98378774097988, 48.19266026360648, 47.26445041384016, 44.59139503751482, 48.18194266727993, 49.776213782174246, 52.747961793627056, 54.60362761361258, 58.03166382653372, 54.14200666972569, 53.63661902291434, 50.876315116882324, 50.21500989368984, 46.557842935834614, 46.53242295128958, 46.182730538504465, 52.40166704995291, 52.06371361868722, 57.18299348013741, 58.667816570826936, 69.23645741598946, 60.40715912410191, 78.18277032034737, 15.928217206682477, 0.6276822931000164, 0.36872700282505577, 0.5348937149558748, 6.5880395855222424, 71.32082666669572, 66.1408542905535, 60.83177048819405, 48.44867011478969, 20.458314146314347, 31.62388515472412, 49.18283414840698, 55.78257710593087, 50.49051986421858, 1.448331043124199, 0.09427159785159997, 0.005349497568594026, 0.028400955123028586, 0.09103329626045056, 0.12084775178560189, 0.2711882995707648, 0.11529380695096084, 0.3754580702100481, 0.20384620954947813, 0.3501579963735172, 0.3030982272965567, 5.009353714329856, 66.12421335492814, 66.6420486995152, 55.44294915880476, 23.672594240733556, 47.90530014038086, 60.52862753186907, 64.31707027980259, 83.62409918648856, 16.36389705113002, 0.4867860163961138, 0.2752137492809977, 1.6705269430364882, 0.6030379012227058, 1.4609778502157755, 41.453908170972554, 63.95009422302246, 68.72472258976528, 62.88622774396624, 67.75763756888253, 63.9383795601981, 63.564239910670686, 61.75348377227783, 60.50328050340925, 56.909199714660645, 49.7719406400408, 44.979236534663606, 45.58724907466343, 44.55295760290963, 45.29351397923061, 46.45356089728219, 51.48176724570138, 49.015542370932444, 54.08390583310808, 52.20394911084856, 56.824219771793906, 53.364451135907856, 54.452820437295095, 45.29664414269583, 44.39654670442854, 56.27797671726772, 56.55857971736363, 55.67350775854928, 53.76179082053048, 48.057608127593994, 42.629988057272776, 41.87676164082119, 44.09594331468855, 42.082219873155864, 42.246305056980674, 42.47587353842599, 44.18234069006783, 43.41432850701468, 43.646453925541465, 42.41824517931257, 44.31735461098807, 42.4785590171814, 43.02684136799404, 43.40677581514631, 46.35082483291626, 47.74088839122227, 49.71184914452689, 49.149805886404856, 50.637599331992014, 52.13177817208426, 52.34364264351981, 50.05087259837559, 53.23519032342093, 50.22769035611834, 53.703683035714285, 51.43760102135794, 52.85282053266253, 49.446907384055, 49.498876435416086, 51.3125855582101, 47.69983148574829, 40.31415694100516, 42.16249588557652, 36.74837963921683, 42.20133978979928, 55.32604571751186, 39.179992062704905, 34.30164098739624, 40.696214062826975, 45.28036798749651, 37.999479225703645, 38.22551454816546, 42.031668254307334, 38.89027650015694, 43.8419588633946, 40.87338617869786, 47.93452773775373, 43.82603359222412, 45.855928965977256, 46.93102373395647, 48.389186586652485, 49.3948757989066, 48.35915299824306, 48.162088189806255, 46.62530994415283, 46.57415383202689, 45.48954003197806, 46.7559187071664, 45.23645537240164, 43.97970690046038, 42.28499262673514, 42.21677868706839, 41.383908544267925, 39.44778953279768, 42.61270093917847, 41.076839855739046, 41.01229109082903, 39.83007247107369, 41.20250844955444, 40.80735397338867, 44.218318462371826, 43.11043861934117, 43.52378000531878, 40.78236477715628, 44.403018951416016, 44.95518881934029, 41.99474900109427, 41.988537311553955, 43.43226180757795, 43.735481194087434, 49.46569183894566, 49.33787625176566, 52.066183703286306, 50.31442124502999, 49.01481281008039, 47.21865831102644, 49.46015412466866, 53.171016761234824, 54.91420514242989, 57.10060521534511, 60.050264903477256, 56.59290729250227, 56.471602167402, 53.47107819148472, 52.48148448126656, 49.64942305428641, 48.62987218584333, 50.1383330481393, 55.47025210516793, 56.080894538334434, 61.04797758374895, 63.112551416669575, 71.46446677616665, 64.55026572091239, 81.63059847695487, 18.994627475738525, 0.768412030168942, 0.4440203697553703, 0.43701045161911417, 7.301299963678632, 79.94352722167969, 70.144364629473, 69.73952783857072, 54.97011382239205, 40.00921787534441, 38.95486348015921, 47.27476501464844, 69.4080501283918, 63.55850764683315, 1.6467544415167399, 0.2923089233892304, 0.1353109564099993, 0.2078259259994541, 0.15923357701727323], [0.024632761787090982, 0.04679097082199795, 0.05878204506422792, 0.04857421852648258, 0.04249415120908192, 0.07940601517579385, 0.013476618099957705, 1.6407327417816435, 43.27125814982823, 46.17602900096348, 28.416091203689575, 26.492499794278825, 41.213948658534456, 42.331253732953755, 56.2181145123073, 66.6326825278146, 16.949800423213414, 0.35209507814475466, 0.31768483029944555, 1.4606638784919466, 0.2844999081322125, 0.2091440074145794, 11.964332444327217, 47.055212361471995, 56.79323080607823, 54.36199011121477, 57.971092905317036, 60.81486552102225, 59.51359299251011, 59.66652979169573, 56.076326097760884, 48.694170815604075, 43.756534235818044, 40.6370883669172, 41.561851910182405, 41.3087603024074, 43.030499594552175, 46.01491069793701, 44.82570219039917, 47.79322222300938, 50.052616596221924, 51.19175638471331, 53.71668658937727, 51.59129517418997, 46.01597029822213, 46.391433579581125, 52.494126728602815, 50.53185469763619, 48.431066853659495, 47.31344911030361, 41.63927221298218, 39.35743168422154, 39.24035801206316, 36.80649437223162, 36.18224041802542, 36.88868808746338, 39.414684840611045, 39.184365953717915, 40.62390068599156, 38.725454807281494, 40.500320025852744, 38.12518603461129, 38.59384202957153, 36.811813218253, 39.342156069619314, 38.78008849280221, 41.0278376851763, 40.53121171678816, 46.27051755360195, 44.20056928907122, 45.241409437997, 44.39676557268415, 46.98148850032261, 47.66637938363211, 47.20358419418335, 45.54329129627773, 45.633465017591206, 47.78620801653181, 46.80194010053362, 46.465622970036094, 48.61310965674264, 48.68053844996861, 45.727352551051546, 38.65728603090559, 39.619100843157085, 36.93701975686209, 34.16430984224592, 49.04956422533308, 40.10127108437674, 37.821997914995464, 42.2494386945452, 46.431305817195344, 32.44222661427089, 34.85449525288173, 37.421330043247764, 38.4127129146031, 39.50781502042498, 40.87029423032488, 42.34952402114868, 42.972746167864116, 42.199762548719136, 43.1809732573373, 42.49095460346767, 41.46087721415928, 42.790060656411306, 42.27621357781546, 43.6865485055106, 41.543758801051546, 42.215239661080496, 41.61135087694441, 39.82472930635725, 38.29137304850987, 40.70614651271275, 38.016912255968364, 36.57602957316807, 35.78631121771676, 37.917448793138774, 36.442130838121685, 37.62104558944702, 36.63784074783325, 38.08716549192156, 38.73755162102835, 37.97965948922293, 36.66933693204607, 39.38021830150059, 39.53115054539272, 39.75706774847848, 37.85680144173758, 37.639896052224294, 36.99600648880005, 39.22647203717913, 39.203094823019846, 44.616960934230256, 46.206507274082725, 49.29443611417498, 48.22320801871163, 48.3033207484654, 46.42198828288487, 47.42537069320679, 48.272460324423655, 49.93967015402657, 47.470919609069824, 50.26711443492344, 51.45906400680542, 55.39635453905378, 53.642163685389924, 52.970992020198274, 46.79660735811506, 45.7964072227478, 44.791072368621826, 48.604261125837056, 46.73007835660662, 54.515597411564414, 55.47948626109532, 63.88429478236607, 58.838950702122276, 79.04559067317417, 11.961353404181343, 0.5963260499494416, 0.16312991508415767, 0.06111926572131259, 10.170845185007368, 68.11119665418352, 61.504634039742605, 53.26540803909302, 43.79293932233538, 25.4246381010328, 30.913417952401296, 32.976348536355154, 47.07425389971052, 43.4376779283796, 0.5808596312999725, 0.15906958867396626, 0.04581110179424286, 0.04233976074361375, 0.08633613759385687, 0.04791164604414787, 0.1343378150569541, 0.04741798806935549, 0.06302370317280293, 0.03335344312446458, 0.14733311773410865, 0.08522638000015702, 3.0610301920345853, 54.65025350025722, 53.921654973711284, 33.26655394690377, 26.069578579493932, 43.87268032346453, 50.341637338910786, 60.69903210231236, 72.21351037706647, 18.768916981560842, 0.4602645252432142, 0.29137167653867174, 1.6734189135687692, 0.7497514486312866, 0.8008198397500175, 12.716302973883492, 49.29444653647286, 58.24988242558071, 57.58599247251238, 60.62772274017334, 62.66938836233956, 61.96277046203613, 60.31289291381836, 57.777078356061665, 51.3208087512425, 46.999661513737266, 42.56908362252371, 43.516171727861675, 43.94365964617048, 45.38330554962158, 46.03073174612862, 47.63608176367623, 48.3688839503697, 51.68616587775094, 53.49680042266846, 54.50237151554653, 53.56579256057739, 46.8353887285505, 47.3625659261431, 54.90454714638846, 52.28667088917324, 51.40506260735648, 48.93887594767979, 43.78758226122175, 41.066549573625835, 41.07332754135132, 39.577220576150076, 38.75969205583845, 38.42116887228829, 40.40461206436157, 40.13610587801252, 42.32052571432931, 41.528073242732454, 40.578355244227815, 39.33761542184012, 41.92636135646275, 40.32877942493984, 40.54829386302403, 39.15874794551304, 42.74482788358416, 43.32979324885777, 47.85841369628906, 47.93916566031319, 48.2593560218811, 47.57403087615967, 50.87958424431937, 48.71173933574131, 50.55942167554583, 47.48297473362514, 49.2057249886649, 50.45708513259888, 50.00760963984898, 50.54571982792446, 49.14539725439889, 51.29729604721069, 47.2092296055385, 40.883169242313926, 40.05704927444458, 35.97533001218523, 37.88077967507498, 49.63915014266968, 42.92946931294033, 38.87416362762451, 44.14621353149414, 45.57220622471401, 34.44835567474365, 35.82109042576381, 39.50486551012312, 38.18065350396292, 42.87872314453125, 42.73985992159162, 45.5307810647147, 45.15210771560669, 45.491610595158164, 46.46211065564837, 46.39620351791382, 45.4500013078962, 44.2383952822004, 44.54474483217512, 45.20186029161726, 46.14152077266148, 45.6479937008449, 44.30505977358137, 41.97164971487862, 40.00060558319092, 41.569494928632466, 38.843733991895405, 38.78557756968907, 37.06960528237479, 41.27745866775513, 38.38187680925642, 39.37071663992745, 38.413386889866416, 39.85973085675921, 41.28650174822126, 40.10218129839216, 39.977235317230225, 41.060709612710134, 41.681468623025076, 41.52941771915981, 39.66095331736973, 40.79149123600551, 39.20475891658238, 40.77340507507324, 41.920844486781526, 46.79652050563267, 46.56610434395926, 52.27769729069301, 49.99382788794381, 49.95006813321795, 48.56534773962838, 48.79434994288853, 50.422851358141216, 52.6401743888855, 50.77091441835676, 54.127255644117085, 54.64524037497384, 57.02670070103237, 56.524026325770784, 54.660957200186594, 49.932232107434956, 48.77342544283186, 47.402146339416504, 49.46233933312552, 49.60141447612217, 57.360262870788574, 57.26052495411464, 68.91680553981236, 63.42906270708357, 81.55054828098842, 13.70112066609519, 0.6646823191217014, 0.23454936274460383, 0.15159753390720912, 12.33444561277117, 72.85935238429478, 66.4146341596331, 60.633719035557334, 51.08595616476876, 26.509550673621042, 34.72032553809029, 39.923932211739675, 55.49067980902535, 56.48986203329903, 0.4949547094958169, 0.14161431603133678, 0.04295402492529579, 0.04031543293967843, 0.04871243950245636, 0.14441866055130959, 0.16403490437992982, 0.1638491079211235, 0.2672656343451568, 0.14419933089188167, 0.25859808229974335, 0.30344265167202267, 5.9926979541778564, 67.47338676452637, 61.65231105259487, 42.8053605897086, 37.96301507949829, 57.28364855902535, 57.32610552651541, 67.07172530038017, 76.72466305324009, 21.622785329818726, 0.497599150453295, 0.5959581754037312, 3.0534058468682423, 0.852568231523037, 0.6027347317763737, 16.62258890696934, 54.16157974515642, 60.00571305411202, 59.07871913909912, 62.311069761003765, 63.544791902814595, 65.30214418683732, 62.81737109592983, 61.853037561689106, 54.0074964932033, 48.536071504865376, 44.52888904299055, 45.37709733418056, 45.83961459568569, 48.041943413870676, 49.57772806712559, 48.56521224975586, 53.056934288569856, 54.0576103755406, 55.46257781982422, 57.17205701555525, 55.80020121165684, 47.46232121331351, 50.461403438023154, 57.81516490663801, 55.29302440370832, 54.03106130872454, 53.21042694364275, 45.99585178920201, 43.68963003158569, 43.47439915793282, 40.043632302965435, 40.054231779915945, 40.75151130131313, 44.31988722937447, 43.31190858568464, 45.087051732199534, 43.85642153876168, 44.99118743624006, 40.85694326673235, 43.823584352220806, 41.50645392281668, 44.61943449292864, 41.20275163650513, 45.01780251094273, 45.30658006668091, 50.22480337960379, 50.189846992492676, 50.4220974785941, 49.32333367211478, 54.75068276269095, 53.12705203465053, 54.59583173479353, 51.693927015577046, 51.39579718453543, 54.655673095158164, 52.09089844567435, 52.0018572807312, 51.627064500536235, 52.80766766411917, 49.54976156779698, 41.21599490301949, 41.5089761189052, 37.363079820360454, 40.56817960739136, 52.251176016671316, 44.64147070475987, 40.944261278424946, 44.931679589407786, 48.79293598447527, 34.0841623714992, 37.33325467790876, 40.83327770233154, 38.82403237479073, 43.956868171691895, 44.36280625207083, 47.85329634802682, 47.17163985116141, 47.25692204066685, 47.92162145887102, 47.55530200685774, 46.91159309659685, 47.620264189583914, 49.55281182697841, 49.61601611546108, 48.393320764814106, 48.315799713134766, 47.133914606911794, 44.53881107057844, 41.30774239131382, 43.78057847704206, 40.98756940024239, 42.072426387241904, 40.01718398502895, 43.348775727408274, 40.34238052368164, 41.44235679081508, 39.365130288260325, 42.33818456104824, 42.56716939381191, 41.868166719164165, 41.418510573250906, 44.09508868626186, 44.462384360177175, 43.52905021395002, 41.39572048187256, 40.939619881766184, 39.802012171064106, 43.08633531842913, 43.552128655569895, 49.592284543173655, 49.58430453709194, 55.02385466439383, 53.078869751521516, 52.74821540287563, 50.602319853646414, 51.77469982419695, 51.48744739804949, 53.500451701028005, 53.84024640492031, 57.693109376089915, 57.83749294281006, 60.108532496861045, 59.57749557495117, 58.010252952575684, 52.367933545793804, 50.91526671818325, 50.901286942618235, 53.504627568381174, 52.75573335375105, 59.7204269681658, 62.09980283464704, 71.38661915915353, 65.99373313358852, 83.48323140825543, 16.55298706463405, 0.928667453782899, 0.26989615176405224, 0.24531711637973785, 14.824801581246511, 81.5350399017334, 73.90334701538086, 68.20525441850934, 61.14380019051688, 38.10508142198835, 41.431955337524414, 46.66048519951956, 64.14187840053013, 67.34161417824882, 1.0133846678904124, 0.32145447230764795, 0.10084776926253523, 0.14077165696237767, 0.1225917496319328], [0.029288136267236302, 0.06060157064348459, 0.05331600444125278, 0.03813840761514647, 0.04065439510824425, 0.06188228513513293, 0.09950745225484882, 3.2402135942663466, 48.1279308455331, 42.763553278786794, 36.88720464706421, 18.14819966043745, 27.913048573902675, 45.04474067687988, 53.38443068095616, 70.9351669039045, 21.20190862246922, 0.05943000529493604, 0.009214406317499067, 1.3563797771930695, 0.5550895226853234, 0.7140177860856056, 1.5322797213281905, 22.812733820506505, 51.795909200395855, 49.38238641193935, 57.717177936008994, 56.172120911734446, 57.978430203029085, 53.652179513658794, 53.46082265036446, 44.35027865001133, 43.53509514672415, 41.008924688611714, 43.618723664964946, 41.54975162233625, 45.87599188940865, 48.43568740572248, 50.39003849029541, 49.48781490325928, 50.84025049209595, 51.868549142565044, 52.51100042888096, 48.260453837258474, 53.7444828578404, 52.66360024043492, 51.569429193224224, 47.62113618850708, 47.56277479444231, 40.93252577100481, 38.86083698272705, 36.70174333027431, 37.328307560511995, 37.43176623753139, 38.32203197479248, 38.95569378989083, 43.47162682669503, 43.19358423777989, 45.01921646935599, 43.130487646375386, 39.670611313411165, 37.41629259926932, 40.1472681590489, 39.4820476259504, 38.07473863874163, 37.58585296358381, 38.282691274370464, 39.473313740321565, 46.00319603511265, 45.23109483718872, 45.82783045087542, 46.04692799704415, 45.71809755052839, 45.34014333997454, 46.15307215281895, 44.63999421255929, 45.73247684751238, 45.86057383673531, 47.260288442884175, 46.127815450940815, 45.95034108843122, 49.352092266082764, 49.81826775414603, 45.09626504353115, 40.30655213764736, 39.575737135750906, 35.032216276441304, 36.20554467609951, 42.22477258954729, 37.8686272757394, 40.66502359935215, 42.24434913907732, 32.56398337227957, 37.68764407294137, 35.39827517100743, 43.6979991367885, 43.10031509399414, 43.343707016536165, 44.402855668749126, 46.27432516642979, 44.2116516658238, 44.717657702309744, 43.35813842500959, 42.56147187096732, 42.456029483250205, 43.69422973905291, 43.53184338978359, 43.242555141448975, 42.97231190545218, 43.202741963522776, 41.90119498116629, 39.03187383924212, 38.74469436917986, 36.43507146835327, 37.07434742791312, 38.23112521852766, 37.94919858660017, 36.94168894631522, 39.195708887917654, 37.75760201045445, 37.97625139781407, 37.8938318661281, 39.95014429092407, 39.002528122493196, 42.84837341308594, 42.554558413369314, 45.28904281343733, 43.66009323937552, 41.13240112577166, 38.148559774671284, 39.02394594464983, 39.82768923895699, 42.962841510772705, 45.42481061390468, 48.5322847366333, 50.223941802978516, 48.75384194510323, 47.268258026668, 47.37799440111433, 46.74210568836757, 50.74225309916905, 53.18295724051339, 54.77875001089913, 51.1043758392334, 55.192497866494314, 56.30082586833409, 53.69133261271885, 52.00051280430385, 50.57199444089617, 46.71772793361119, 48.27284247534615, 48.218066351754324, 54.25110033580235, 55.28366865430559, 64.96662262507847, 59.00453322274344, 72.70708956037248, 12.231320449284144, 0.8833866949592317, 0.3832503935056073, 0.30792841953890665, 17.90614526612418, 67.78107384272984, 61.02198437282017, 54.344859327588765, 45.75496816635132, 29.922121933528356, 33.8330614226205, 48.348504883902415, 47.143895694187705, 46.19591474533081, 0.7338926196098328, 0.07111798812236104, 0.06236386179391827, 0.04803062715966787, 0.08614052951868091, 0.04565843820039715, 0.09364164594028677, 0.0654229690719928, 0.10293776568557535, 0.053406768678022284, 0.23576413041778974, 0.1307895654546363, 5.340798854827881, 57.30157838548933, 52.17828246525356, 42.83609594617571, 30.01382425853184, 42.26398474829537, 48.15300342014858, 62.66419805799212, 73.24763856615338, 24.449041536876134, 0.22874528276068823, 0.07652735071522848, 2.4191534348896573, 3.608434464250292, 1.6911064216068812, 1.4109800245080675, 23.708401782172068, 53.50306074959891, 51.74962377548218, 60.06391116550991, 56.781130518232075, 60.81921509334019, 54.866891384124756, 54.94035816192627, 45.77262006487165, 45.407551288604736, 42.19101129259382, 46.47957495280674, 43.765702383858816, 48.20911707196917, 49.863705498831614, 52.946579524448936, 52.31816012518746, 53.39035054615566, 54.08687271390642, 55.51828152792794, 48.86304330825806, 55.973715100969585, 54.252625465393066, 52.38626636777605, 50.775823320661274, 50.8345182282584, 41.960230350494385, 41.700308663504465, 38.22880104609898, 39.67116369519915, 39.64158868789673, 42.375621455056326, 42.44964756284441, 45.93533297947475, 44.9847012928554, 47.994296142033164, 46.46439661298479, 40.90137004852295, 39.30912780761719, 41.83876889092581, 40.347647258213584, 39.85950156620571, 38.446675709315706, 39.75395148141043, 41.4766183580671, 46.88995293208531, 48.49730403082711, 48.437876088278635, 48.02732787813459, 48.97354745864868, 49.79036726270403, 47.28107050486973, 46.834940569741384, 48.2366110937936, 48.238372462136404, 49.68947941916329, 49.72424473081316, 49.3974883215768, 51.17098821912493, 51.48088829857962, 47.491131918770925, 41.45763240541731, 38.35631438664028, 38.63387407575335, 40.42638771874564, 45.7186256136213, 39.004466669900076, 41.43385566983904, 43.59114973885672, 36.48225668498448, 38.15839147567749, 38.1758314541408, 45.544385637555806, 46.166280678340364, 45.90121037619454, 48.403291429792134, 48.25695194516863, 47.4439605985369, 46.63346018110003, 46.11807407651629, 44.308811800820486, 45.45489978790283, 46.160141944885254, 46.230322224753245, 42.862349714551655, 44.65796225411551, 44.79799624851772, 42.845086915152415, 39.75130074364798, 41.53181484767369, 39.255241053445, 37.3795678956168, 39.997840200151714, 41.28042902265276, 37.58333771569388, 39.03764431817191, 39.25563015256609, 39.81378589357649, 40.04134634562901, 41.61643695831299, 41.64836393083845, 45.14704247883388, 44.18672847747803, 47.638263498033794, 44.11386619295393, 43.53643614905221, 40.81921802248274, 42.303092684064595, 41.18580845424107, 44.27079125813076, 48.02465629577637, 50.41912364959717, 52.860279423849924, 51.47049726758684, 50.578001158578054, 48.92998225348336, 49.61441108158657, 51.89607790538243, 56.921633516039165, 56.81480843680245, 54.450444153376985, 58.1512770652771, 60.95742171151297, 56.72740009852818, 54.42479140417916, 53.318881375449045, 48.92874894823347, 51.73041548047747, 49.9694709777832, 56.51250621250698, 59.255147797720774, 67.85730947766984, 62.304628780909944, 74.78261375427246, 13.939848610333033, 0.944645813533238, 0.34613558650016785, 0.5392361762268203, 20.229483910969325, 73.00864137922014, 66.22661590576172, 61.41112518310547, 55.093378339494976, 35.208881173815044, 37.2030211176191, 51.648860999516074, 55.800951617104666, 57.34561606815883, 0.6654685512185097, 0.04064098386360066, 0.09771246928721666, 0.06234948363687311, 0.038149942710463486, 0.11262355452137333, 0.18032141402363777, 0.2040868859205927, 0.1789436622389725, 0.213129423558712, 0.2919530453426497, 0.2063471403505121, 8.59663873059409, 73.88821383884975, 58.753154345921104, 52.40463045665196, 25.834140607288905, 42.23472588402884, 60.45041166033064, 64.97596100398472, 81.36168929508754, 26.412011861801147, 0.35691587946244646, 0.09863408947629587, 6.4643047622271945, 5.808166393211909, 1.45484193946634, 2.5296617107731953, 29.969689301082067, 55.654299463544575, 54.85952281951904, 60.89538819449288, 61.27039636884417, 62.60515921456473, 58.639731952122276, 57.23889173780169, 48.831845896584646, 48.01980297906058, 44.59123522894723, 48.85115841456822, 44.89805725642613, 51.747358662741526, 52.64461081368582, 56.91882644380842, 54.75257614680699, 54.80260665076119, 56.49033451080322, 57.03239474977766, 50.686049120766775, 60.181544167654856, 57.36847216742379, 55.42621789659773, 54.413698605128694, 53.96124580928257, 46.023463930402485, 43.02155378886631, 39.536257471357075, 41.94582673481533, 42.851225648607524, 43.05949442727225, 42.23880795070103, 49.524369376046316, 46.76211650030953, 49.97730507169451, 47.89196654728481, 43.83229044505528, 41.611871991838726, 44.63416467394148, 42.39806066240583, 40.69941023417881, 41.19904129845755, 41.721188000270296, 43.01670742034912, 50.64004857199532, 48.94587278366089, 49.52939987182617, 51.68441840580532, 51.38934925624302, 52.67258773531233, 50.515283243996755, 48.811324392046245, 51.47131020682198, 50.49329219545637, 51.85845341001238, 51.55142641067505, 50.66946029663086, 54.00650290080479, 53.94916289193289, 47.24608285086495, 41.325314385550364, 39.19625084740775, 39.57161685398647, 42.520234312329976, 46.22956139700753, 40.84638895307268, 42.179744788578574, 46.71230139051165, 38.69642175946917, 38.38804333550589, 39.3413987159729, 45.39575324739729, 46.54754570552281, 50.5008796283177, 49.30628626687186, 51.243968623025076, 49.08975955418178, 50.59144939695086, 49.01698064804077, 48.140083244868684, 48.23936952863421, 47.942340987069265, 48.66706589290074, 46.72684397016253, 47.75922816140311, 47.40481097357613, 45.42351130076817, 43.06393780027117, 42.984415667397634, 41.74749040603638, 40.00483703613281, 42.79128353936331, 41.90659373147147, 39.50333343233381, 41.57792656762259, 41.80569893973214, 41.17011942182268, 42.64907823290144, 43.41877882821219, 44.42881761278425, 47.542711871010916, 46.58237702505929, 49.514231954302105, 46.06421511513846, 45.11322559629168, 41.4677072933742, 44.64101907185146, 43.31327738080706, 48.441853931971956, 50.43645593098232, 53.931722913469585, 55.517652715955464, 53.6936811038426, 53.863241468157085, 50.53113555908203, 51.58962413242885, 52.19958216803414, 58.95729242052351, 59.487620626177105, 57.91160242898123, 61.25224767412458, 64.71163763318742, 58.76527200426374, 57.67132329940796, 55.131829670497346, 52.22291074480329, 53.552511078970774, 53.42825296946934, 60.67829867771694, 62.165866306849885, 69.79992852892194, 68.38881192888532, 77.75987516130719, 17.206753492355347, 1.1478482697691237, 0.47044618747064043, 1.1674418640988213, 23.53681775501796, 78.33743027278355, 75.31638131822858, 69.76463168007987, 63.68702152797154, 46.871762548174175, 47.358344895499094, 63.36840493338448, 64.05822903769356, 72.50697449275425, 1.3620429933071136, 0.17732636045132363, 0.11403550447097846, 0.23704599163361958, 0.10119796797100987], [0.043406349939427206, 0.05387282045558095, 0.12340601879571166, 0.0598885321191379, 0.04622948309406638, 0.10169699655047484, 0.17140885655369076, 8.805699603898184, 57.830457891736714, 35.19255290712629, 36.338227476392476, 18.97641451018197, 26.632400035858154, 45.444922174726216, 53.04280512673514, 68.06058597564697, 29.12812522479466, 0.4338934245918478, 0.09432072378695011, 1.0903941584484917, 2.089212796517781, 1.3896560030324119, 0.10865784981953246, 9.570755328450884, 44.79895857402256, 52.428045885903494, 59.57636301858084, 55.25912414278303, 56.65996783120291, 50.330367360796245, 46.31646599088396, 42.69970975603376, 43.77948760986328, 42.88654681614467, 45.86138677597046, 45.90042870385306, 51.14235816683088, 50.93775108882359, 53.61321749005999, 51.2298081942967, 52.92588778904506, 52.234462124960764, 52.83088854381016, 53.87033210481916, 50.80154207774571, 46.50032227379935, 48.00098030907767, 46.801068101610454, 41.2228354045323, 36.9079589162554, 37.41883216585432, 37.87090628487723, 39.49522488457816, 38.16421059199742, 41.91362530844552, 45.6879562650408, 50.54330880301339, 50.15137134279524, 51.10333708354405, 45.8650415284293, 42.31632900238037, 39.04191051210676, 38.38159193311419, 38.558232511792866, 37.97939198357718, 37.7757055418832, 38.45939091273716, 37.47729083469936, 41.441352776118684, 46.89505638395037, 45.1190516608102, 47.58995614733015, 47.11427552359444, 46.499856744493755, 48.76077972139631, 46.71386126109532, 47.5582515171596, 49.7206038747515, 48.11788722446987, 48.78112057277134, 47.70407683508736, 48.994815894535606, 46.45728165762765, 50.98448467254639, 43.112853118351524, 39.88724224908011, 38.97085475921631, 33.69357981000628, 37.04908725193569, 40.372525283268516, 42.783320903778076, 39.09976121357509, 36.474742208208355, 36.773990699223106, 37.485955238342285, 41.62866578783308, 48.643164089747835, 47.91801534380232, 45.71605825424194, 43.917124475751606, 43.16161905016218, 43.32217454910278, 42.43080404826573, 41.10870776857649, 42.553943497794016, 42.0432265826634, 43.59760461534773, 42.317517144339426, 40.870700699942454, 43.40337814603533, 42.82685831614903, 39.82802275248936, 39.07441071101597, 35.76304170063564, 36.807074546813965, 36.68992791857038, 37.79048088618687, 37.39304740088326, 39.24751465661185, 39.01434700829642, 38.34786537715367, 36.60742153440203, 37.22436598369053, 41.1399781363351, 43.457459449768066, 46.029439381190706, 46.66048172542027, 49.17176914215088, 48.492242268153596, 42.96539844785418, 41.46915946687971, 39.944391182490754, 41.1437475340707, 43.005253314971924, 46.59109354019165, 48.55600936072213, 51.03894812720162, 47.56327159064156, 50.84179646628243, 47.48250573022025, 51.28152363640921, 52.27725608008248, 58.519104276384624, 59.540718759809224, 61.71931253160749, 56.401008469717844, 57.610290322984966, 52.47009290967669, 52.32495198931013, 51.31884935923985, 48.19970226287842, 47.797384193965364, 52.60770893096924, 57.87034055164882, 63.14061519077846, 61.09780311584473, 75.27288559504917, 10.333562442234584, 0.8557838361178125, 0.222770931199193, 0.616683837558542, 27.85898290361677, 69.23136438642229, 59.02327251434326, 57.98660128457205, 47.700880663735525, 31.752166271209717, 18.301214626857213, 42.22938619341169, 49.03626537322998, 61.52178914206368, 3.9567294205938066, 0.1897302655769246, 0.07192297492708478, 0.08831510533179555, 0.05110397349510874, 0.02429923807669963, 0.007613308794264282, 0.10544646571257285, 0.029795436188578606, 0.03879050351679325, 0.06717013567686081, 0.14686503713684423, 13.730227538517543, 69.15579577854702, 43.023672989436555, 41.66142307009016, 24.689110483442033, 33.5877274785723, 51.95911543709891, 57.95560884475708, 74.0913096836635, 32.94658940179007, 0.712224716586726, 0.08532402118934052, 2.8712273367813657, 3.92197322845459, 1.9768628137452262, 0.8474614141242844, 8.178686346326556, 49.46989549909319, 55.319094044821604, 59.8986691066197, 57.90983411243984, 58.098116397857666, 52.676075731004985, 47.802932330540244, 44.323347432272776, 46.42006363187517, 44.16283014842442, 47.07154062816075, 47.1067784173148, 53.7725362096514, 52.87332466670445, 56.387563705444336, 52.725227287837434, 56.655277797154014, 53.16314097813198, 55.46535015106201, 54.99765648160662, 54.57053334372384, 49.92775051934378, 50.23478446687971, 47.32758174623762, 44.096926484789165, 40.62688841138567, 39.53893600191389, 39.38901819501604, 40.77883856637137, 39.949796880994526, 44.817628383636475, 48.17234720502581, 52.61945833478655, 52.20880242756435, 51.37857607432774, 47.6187355858939, 46.436916487557546, 40.010128089359824, 40.11629656382969, 41.03130831037249, 41.43268837247576, 39.34681831087385, 38.54602105276925, 38.306009428841726, 43.62844072069441, 49.226534843444824, 47.196854863848, 50.514921937670024, 49.01409019742693, 49.729855401175364, 50.72869716371809, 49.84679705756051, 50.057918071746826, 50.562513623918804, 50.84769548688616, 50.43863071714129, 50.30195965085711, 50.70821040017264, 48.21466520854405, 52.14657436098371, 45.56264897755214, 39.24506541660854, 40.93859154837472, 39.12094974517822, 40.666423661368235, 41.42876264027187, 42.18527555465698, 41.40302651269095, 37.57916879653931, 36.3908566066197, 37.83984088897705, 44.29367515019008, 48.54662234442574, 49.621345383780344, 47.49471024104527, 47.392516136169434, 46.19175277437483, 47.33734743935721, 45.79389197485787, 44.735427720206125, 44.896552971431184, 43.55327163423811, 45.68263741901943, 45.35750688825335, 44.982682841164724, 44.58212961469378, 44.25881603785923, 42.20935106277466, 39.908215386526926, 38.33925655909947, 37.87841728755406, 38.32652398518154, 40.339424065181184, 40.27955838612148, 40.44764225823538, 41.41683953148978, 41.003376552036826, 39.47232709612165, 40.85897214072091, 42.23025124413626, 44.48941632679531, 48.409027167728965, 48.88152551651001, 52.48639338357108, 51.19941329956055, 45.80374799455915, 43.942985670907156, 41.67365884780884, 42.49843781335013, 43.84199013028826, 46.86477613449097, 51.351724760872976, 51.81091730935233, 49.663329873766216, 53.31963872909546, 50.6166227204459, 54.68283012935093, 54.57901014600481, 60.48691749572754, 61.534698895045686, 61.66900757380894, 59.919346945626394, 60.045901434762136, 56.336959975106375, 55.81848539624895, 54.86191994803292, 50.86541339329311, 48.80764879499163, 56.02948134286063, 59.78181430271694, 67.91393034798759, 63.91567979540144, 78.19011456625802, 11.716177531651088, 0.8292101249098778, 0.6035128757357597, 0.40155599266290665, 30.71916021619524, 75.78618376595634, 63.31567505427769, 65.96729523794991, 55.409132276262554, 40.47650507518223, 26.473522526877268, 49.92497818810599, 54.82887084143502, 71.78623785291398, 5.612380487578256, 0.308146093572889, 0.03595684289133974, 0.07910119688936643, 0.04411404839317713, 0.0912571381777525, 0.11090348860515015, 0.18428743763693742, 0.13574227397995337, 0.1221226512321404, 0.293763132499797, 0.22601998757038796, 18.436991112572805, 83.25940908704484, 49.887673309871126, 50.01656239373343, 26.812975031988962, 38.490202699388774, 59.83947045462472, 63.30430780138288, 79.48529352460588, 38.60451446260725, 1.4758388527802058, 0.19293896268521035, 5.243905791214534, 5.639408111572266, 3.4223115486758093, 0.7640391162463597, 12.189567855426244, 50.998040607997346, 57.394350733075825, 63.05676433018276, 61.51444489615304, 60.964550563267295, 55.83547026770455, 49.37068911961147, 46.39786761147635, 49.23148543494088, 49.17900569098336, 49.65702438354492, 48.990535804203574, 56.272491114480154, 56.56609072004046, 61.074005535670686, 55.996098722730366, 59.041018213544575, 55.50068521499634, 55.94473416464669, 56.83148063932146, 57.10949543544224, 51.57179505484444, 53.365493365696494, 51.93931654521397, 45.73950842448643, 41.13284233638218, 41.67853995731899, 40.812210764203755, 44.99079138892037, 41.21551547731672, 44.915386063711985, 51.051208223615376, 54.578370911734446, 54.53516353879656, 54.297413553510395, 50.237018312726704, 48.64231988361904, 44.16501188278198, 41.70968178340367, 43.11298166002546, 42.54177025386265, 40.832131249564036, 41.846085344042095, 41.011283602033345, 45.67448370797293, 51.77059691292899, 50.361582142966135, 52.74497754233224, 52.99960470199585, 51.61703477587019, 52.26080969401768, 53.00969696044922, 52.19378042221069, 55.06397703715733, 52.93128653935024, 53.01188216890608, 51.5986533164978, 53.70991209575108, 50.23324891499111, 54.579802240644185, 46.27985940660749, 40.404844829014365, 41.25686420713152, 41.53267642429897, 42.45150620596749, 43.09051465988159, 46.943356786455425, 45.59124428885323, 39.9007009097508, 37.191834517887656, 39.05710622242519, 47.73761926378523, 51.98922198159354, 53.64548145021711, 50.644835880824495, 48.41366161618914, 49.1121049608503, 49.545276505606516, 47.72832604816982, 47.915500095912385, 47.09230184555054, 47.23899916240147, 47.56619678224836, 48.34068816048758, 47.49717685154506, 48.50599275316511, 47.54894093104771, 45.577577182224815, 42.81140204838344, 40.80486304419381, 41.51171718324934, 39.95972238268171, 43.34749378476824, 42.04448420660836, 43.15057488850185, 43.90970727375576, 42.63950708934239, 41.41321952002389, 41.572107451302664, 43.929659026009695, 47.419315338134766, 51.15727942330496, 51.06278739656721, 54.533836432865684, 53.34705632073538, 46.26028633117676, 45.506069796425955, 43.695546422685894, 44.12425722394671, 47.0666629927499, 49.315631593976704, 52.8108742577689, 53.417736870901926, 52.44251203536987, 56.71821457999093, 52.47218779155186, 58.35953194754464, 56.394980907440186, 62.619375228881836, 63.01648562295096, 65.08499908447266, 61.07313701084682, 62.41600840432303, 59.31233842032296, 58.55987630571638, 57.321325165884836, 52.66282204219273, 51.40986033848354, 58.705718994140625, 63.406696455819265, 70.67777783530099, 66.22813061305455, 81.01055513109479, 14.553982513291494, 1.119282922574452, 1.0825219580105372, 1.5443349544491087, 34.42166764395577, 82.92817456381661, 71.94904804229736, 73.09264510018485, 66.16158076695034, 46.67536129270281, 27.981021063668386, 61.96934345790318, 63.7946560723441, 86.75134440830776, 8.05815941946847, 0.4955410180347306, 0.19175482408276626, 0.18516772825803074, 0.10702330645705972], [0.066632362747831, 0.029991865291127136, 0.05253243898706777, 0.03501250534983618, 0.09775909142834799, 0.08867066446691751, 0.24257195368409157, 9.57146578175681, 55.74515758241926, 46.79462712151663, 32.5351413999285, 38.793335233415874, 42.13492890766689, 41.09245245797293, 59.24429471152169, 65.54862458365304, 40.357399054935996, 0.11944166437855788, 0.06075166258960962, 1.8836453471864973, 2.7097349166870117, 2.9513578712940216, 0.35062073011483463, 4.491208740643092, 46.51783868244716, 57.70593922478812, 59.200868470328196, 52.415278570992605, 52.73570169721331, 47.060013566698345, 44.93647732053484, 41.85295363834926, 46.83707366670881, 45.2507130759103, 50.59206083842686, 51.73294809886387, 54.57404218401228, 53.58119324275425, 54.02623231070382, 52.49151073183332, 56.51853724888393, 53.569457735334126, 53.1652740750994, 50.140024934496196, 49.88948678970337, 48.64566544124058, 46.047824314662385, 38.63892541612898, 39.03648396900722, 37.25758184705462, 36.161826610565186, 36.28957271575928, 37.8399520601545, 42.402066298893516, 48.30359867640904, 46.57520301001412, 51.5189505304609, 49.508305140904014, 50.18304818017142, 47.87421389988491, 42.61565392357962, 36.736706665584016, 38.43316493715559, 37.37069157191685, 36.28713737215315, 37.138712065560476, 39.10950606209891, 39.35544449942452, 39.27816663469587, 42.712153979710166, 44.62410020828247, 45.00382620947701, 47.39645576477051, 47.14017145974295, 48.54513195582798, 47.17522859573364, 49.0006662777492, 46.692036969321116, 48.43145942687988, 46.26156827381679, 47.57399613516671, 48.32543339048113, 50.56669296537127, 48.48606531960623, 48.231135913303916, 43.56552478245327, 37.34530980246407, 32.96875068119594, 35.40835353306362, 45.82788603646414, 42.28107731682913, 37.38357353210449, 37.49530403954642, 35.38121734346662, 46.800460134233745, 41.79325124195644, 44.05703340257917, 44.5578282901219, 46.10252053397042, 46.311331272125244, 43.86893177032471, 42.23244340079171, 47.00736706597464, 41.80971152441842, 43.2400016784668, 43.202088832855225, 43.21196569715227, 42.37999187197004, 43.5667268208095, 43.80405644008091, 40.85129090717861, 36.68629053660801, 36.86425822121756, 35.00436094829014, 35.81275258745466, 35.83065462112427, 39.12421192441668, 37.10803229468209, 39.08832795279366, 39.22598218917847, 41.9462297303336, 40.10824360166277, 41.3641791343689, 38.70789670944214, 41.53943007332938, 43.94665779386248, 48.70451668330601, 51.26992014476231, 51.21071801866804, 47.90527582168579, 48.96595655168806, 42.50982938494001, 39.93147448131016, 40.97051157270159, 41.75210748400007, 43.519499914986746, 47.23320089067732, 48.12802117211478, 49.54195874077933, 47.13770832334246, 48.02460765838623, 49.843194416591096, 52.58170877184187, 55.745744705200195, 60.92192336491176, 59.779708998543875, 57.0458151953561, 57.56525557381766, 55.60205595833914, 51.750624316079275, 51.70883437565395, 50.25510447365897, 54.84112398965018, 59.24963787623814, 64.48985113416398, 59.996659551348, 66.83646624428886, 5.8491082191467285, 0.5144281217030117, 0.2736760532217366, 0.6291384835328374, 40.034356457846506, 66.20133141108921, 59.27358831678118, 58.183436802455354, 43.452519280569895, 33.08940267562866, 34.79571349280221, 43.147927624838694, 49.043411595480784, 58.518152373177664, 4.907530903816223, 0.23198564031294414, 0.02925054881987827, 0.07354699421141829, 0.03794196154922247, 0.07133304301117148, 0.05032686430162617, 0.04481414046936801, 0.10484506655484438, 0.0812009506459747, 0.08953790685960225, 0.29317457122462137, 12.990090659686498, 67.06602082933698, 50.83403532845633, 45.46011093684605, 31.354055336543492, 43.812522820064, 48.345357349940706, 64.18907056535993, 72.19002546582902, 44.854895046779085, 0.12585536736462796, 0.09928228040891034, 1.628412391458239, 4.197164450372968, 1.2005854227713175, 1.6435427452836717, 5.534897650991168, 51.90160519736153, 61.34052453722273, 61.15539673396519, 54.50189208984375, 55.24366092681885, 48.612578119550435, 45.8651943887983, 44.95316341945103, 48.54940162386213, 48.19314316340855, 52.60492270333426, 53.685444014413015, 55.440468651907786, 55.33118043627058, 56.39895180293492, 52.60730593545096, 58.37783350263323, 55.571417876652305, 54.31858818871634, 51.73410497392927, 51.9845632144383, 51.335570199149, 48.29570204871041, 39.39213446208409, 40.12018755504063, 39.972277777535574, 38.639627184186665, 37.74352148600987, 39.35610457829067, 43.05165338516235, 50.087948186056956, 50.476463658469065, 53.82423775536673, 51.182911327907014, 53.23004518236433, 49.72734015328543, 43.459679399217876, 39.29709005355835, 39.06706299100603, 37.340956756046836, 39.70703724452427, 39.244169098990305, 39.82451738630022, 39.65649604797363, 41.35608448301043, 44.71043157577515, 46.84150314331055, 47.808998107910156, 49.5893280846732, 49.51907137462071, 51.369095257350374, 50.04070738383702, 51.53031778335571, 49.06269632066999, 50.64004162379673, 48.05713217599051, 50.09171758379255, 50.154404231480186, 53.00228670665196, 49.858139991760254, 50.071053641183035, 43.89683920996529, 38.33240910938808, 35.717503207070486, 38.108882086617605, 47.159914766039165, 43.50183064596993, 41.29029893875122, 38.46786424091884, 36.591631753104075, 47.472104276929585, 46.650462423052105, 46.57650579724993, 45.61364875520979, 47.625676836286274, 49.76151139395577, 46.26040097645351, 46.476472582135884, 48.755304540906636, 44.69010462079729, 44.70287193570818, 45.2258871623448, 45.330422810145784, 46.02454090118408, 45.32190779277256, 46.312505517687114, 41.09965079171317, 39.09239959716797, 39.112083843776155, 37.0652174949646, 36.37375708988735, 37.40908036913191, 40.96795116152082, 39.05543865476336, 41.10682828085763, 40.86534711292812, 43.3760404586792, 42.41500384466988, 42.07772091456822, 40.736902713775635, 45.724111216408865, 45.7376115662711, 51.329497473580496, 51.940188544137136, 55.094868728092735, 51.17502859660557, 51.9884819984436, 44.84499038968767, 41.26047379629952, 42.62644100189209, 43.61241122654506, 46.24978412900652, 49.934802940913606, 50.78177097865513, 51.683334486825125, 50.76131200790405, 49.892293861934114, 52.879796913691926, 55.42542232785906, 57.68255506243025, 62.933920179094585, 60.163791520254954, 61.05092361995152, 61.161059515816824, 58.705684253147666, 54.56941468375069, 54.24405486243111, 53.89095088413784, 57.81513016564505, 62.03745664869036, 66.55148587908063, 62.5825080871582, 70.18396936144147, 6.560035305363791, 0.3754812761076859, 0.48928313383034294, 1.1593157287154878, 45.01295266832624, 73.01530470166887, 66.80331638881138, 64.22984259469169, 51.84581463677542, 34.635991777692524, 30.562419278281077, 55.82850469861712, 53.02776575088501, 70.85034329550606, 5.931480850492205, 0.3083175186600004, 0.10451032487409455, 0.015607348676504833, 0.05590337381831237, 0.1830119410795825, 0.27078799105116297, 0.1584509275853634, 0.19140470001314366, 0.2579463358436312, 0.45724618434906006, 0.4224870880799634, 19.75675800868443, 77.24421460287911, 61.48916040148054, 47.802522386823384, 51.45659392220633, 64.23799977983747, 52.47736767360142, 72.33081681387765, 77.03974996294293, 50.13518898827689, 0.2107313722372055, 0.22161484323441982, 5.469836890697479, 11.518881695611135, 7.025410882064274, 1.6961586305073328, 8.12127251284463, 54.671813760484966, 62.369253976004465, 64.99023955208915, 56.49774476460048, 59.99474879673549, 53.07272754396711, 50.363107272556846, 46.3320369039263, 52.12119606563023, 51.214160851069856, 56.05903550556728, 55.61137349264962, 60.09184292384556, 59.01321152278355, 59.40424224308559, 55.11052301951817, 61.99255044119698, 57.041847773960654, 57.66019228526524, 55.004837444850374, 55.52015059334891, 52.7235631942749, 52.564914975847515, 41.888420718056814, 42.72593920571463, 41.29113619668143, 41.26654999596732, 39.38693373543875, 41.70538779667446, 47.48342636653355, 53.83715098244803, 52.4674699647086, 58.30279295785086, 52.2900025503976, 55.35571452549526, 51.523956707545686, 44.543772084372385, 41.95013114384243, 40.83862086704799, 40.090463161468506, 41.8726726259504, 42.04642970221383, 43.41713557924543, 41.72640609741211, 44.054684911455425, 46.38388088771275, 47.79156507764544, 50.18679673331124, 52.408993925367085, 52.65852458136422, 55.18940244402204, 51.07098279680525, 54.811083453042166, 50.967958382197786, 52.965016569410054, 50.254486083984375, 52.7910475730896, 54.440720149448936, 54.40420389175415, 51.634558132716585, 51.41246591295515, 44.674644878932405, 39.15991871697562, 37.04135390690395, 40.95299168995449, 47.24704170227051, 45.87832995823452, 43.958410671779085, 40.15389674050467, 37.55646555764334, 50.23277991158621, 48.885055201394216, 51.638143403189524, 50.467337199619834, 51.94883905138288, 51.55288553237915, 49.52350432532174, 48.99145644051688, 53.73782648359026, 48.14730937140328, 47.68964195251465, 48.385104519980295, 49.62765434810093, 49.38651016780308, 48.51423331669399, 48.46606840406145, 43.48500905718122, 41.58991568429129, 42.39063303811209, 39.53027854646955, 38.771608216421946, 39.63596064703805, 43.117067200796946, 41.49450649533953, 43.618723664964946, 43.975416387830464, 45.5788243838719, 43.86882407324654, 44.532658440726145, 43.60129410879952, 46.52408858707973, 47.44078527178083, 52.753475189208984, 54.0714442389352, 55.98465851375035, 52.583230427333284, 54.06785896846226, 46.39628689629691, 43.20035873140608, 43.41521440233503, 44.87472173145839, 47.72158282143729, 52.53729936054775, 52.42118106569563, 54.96506595611572, 51.74316195079258, 51.272591727120535, 55.57599326542446, 58.393557276044575, 61.691839354378835, 65.27999332972935, 63.86195632389614, 61.96643911089216, 64.36319242204938, 61.57650620596749, 57.17449583326067, 56.869900703430176, 57.98173059735979, 60.53702095576695, 65.87942137037004, 70.22203854152134, 65.30033765520368, 73.20784623282296, 8.296036209378924, 0.4844316084470068, 0.7622452325054577, 2.148060347352709, 48.92148808070591, 80.91687256949288, 70.74847575596401, 72.55133179255894, 60.44945975712368, 47.14715092522757, 44.638972827366416, 60.27480288914272, 61.3546849659511, 83.2345414842878, 9.077679021017891, 0.5357123538851738, 0.12502650969794818, 0.21487928394760403, 0.19025079693113053], [0.0767085806333593, 0.05648733462606158, 0.10417865017162901, 0.037879580432283025, 0.06729033815541438, 0.03189872171995895, 0.2585254247699465, 9.16783537183489, 57.46496180125645, 38.134229115077424, 27.95250391960144, 25.903289079666138, 33.441450527736116, 43.73440422330584, 56.51111657278878, 62.12339196886335, 49.09302520751953, 0.5885770171880722, 0.04702378297224641, 1.1505360284021922, 2.179482489824295, 1.5450507274695804, 2.168661104781287, 6.855632083756583, 51.809201104300364, 58.24151332037789, 56.25497123173305, 52.55464553833008, 49.74030201775687, 43.38778638839722, 45.3654591015407, 45.61327355248587, 50.36957951954433, 51.095513411930625, 53.75920956475394, 55.03788307734898, 55.42654793603079, 55.548318590436665, 54.53879049846104, 54.43227808816092, 52.062640122004915, 52.79889556339809, 49.05178417478289, 47.056153842381065, 44.98019538606916, 41.860766887664795, 40.707994733537944, 39.92004816872733, 39.91262749263218, 37.09454584121704, 38.19925730569022, 39.58395685468401, 44.804937498910085, 44.9045399257115, 46.020639487675254, 49.69411734172276, 50.19069119862148, 51.07858412606375, 51.57439368111746, 48.715421880994526, 41.4129763330732, 35.79202611105782, 37.051286356789724, 37.935027735573904, 36.11820929391043, 38.65302678516933, 37.17603431429182, 36.96380853652954, 39.125497341156006, 40.36156449999128, 45.28473493031093, 42.87291097640991, 46.41985518591744, 45.47292341504778, 46.36910554340908, 46.66569287436349, 46.40005281993321, 46.80592141832624, 47.664590222494944, 46.01127331597464, 48.65577507019043, 48.22985397066389, 46.45709753036499, 47.99146127700806, 49.37145342145647, 49.42605236598423, 42.102175099509104, 33.66352537700108, 36.68795463017055, 44.82732459477016, 40.18010534558977, 35.174084595271516, 37.98285566057478, 44.18737465994698, 48.595572403499055, 47.32969399860927, 45.04086358206612, 43.39426210948399, 43.406779289245605, 45.23259217398507, 45.91232054574149, 42.11672115325928, 44.04570089067732, 41.86233023234776, 44.53603873934065, 42.59667144502912, 42.68517759868077, 44.06839370727539, 43.42494535446167, 43.31545564106533, 40.0655642918178, 35.69360835211617, 37.024608748299734, 35.22039086478097, 35.10012796946934, 36.43596083777291, 37.70801619121006, 37.091519900730674, 39.35251930781773, 42.623185770852224, 48.632686206272666, 48.02001142501831, 46.69185631615775, 43.55526924133301, 41.00867802756173, 44.85736860547747, 45.591796670641216, 52.2749388558524, 53.792008536202566, 50.22290652138846, 53.063305786677766, 49.469152041843955, 45.809845038822715, 42.48988458088466, 40.77885593686785, 40.82999815259661, 43.31109912054879, 44.48549754279, 45.35266399383545, 45.53343875067574, 47.80661834989275, 48.598831108638215, 54.85342230115618, 54.57377815246582, 57.048219272068565, 59.0015663419451, 59.50249671936035, 57.18287188666207, 56.45750079836164, 56.37699896948678, 58.32290799277169, 57.968817370278494, 56.96707820892334, 59.74999850136893, 60.97904450552804, 68.11139815194267, 72.60529150281633, 2.5601415038108826, 0.44407185699258533, 0.2825423888862133, 0.7728694081306458, 45.17439406258719, 66.40315573556083, 59.896633284432546, 60.69777447836739, 41.20266478402274, 33.89480658939907, 32.93929726736886, 29.499765259878977, 50.10530826023647, 66.66378961290631, 11.233712860516139, 0.49224219790526796, 0.13760536829275744, 0.14056745863386563, 0.054768140627337356, 0.0669229860816683, 0.0336209623409169, 0.1361857508974416, 0.056173620745539665, 0.08282545847552163, 0.07982692401856184, 0.31532040717346327, 13.436273574829102, 67.74016979762486, 46.39464712142944, 37.386866978236604, 23.24762330736433, 38.51356949125017, 47.341141155787874, 60.770966802324565, 67.68473012106759, 52.35597917011806, 0.7610764152237347, 0.05040110281801649, 0.709877473967416, 1.543885384287153, 1.4537975383656365, 2.7735054833548407, 7.960222823279245, 52.58649608067104, 60.414419991629465, 58.06343446459089, 55.77136966160366, 53.675574098314556, 45.672986371176584, 46.17412519454956, 47.57560811723982, 52.03065061569214, 53.41972752979824, 55.80729879651751, 57.074049200330464, 55.96464422770909, 55.377524920872276, 56.27213675635201, 55.07999610900879, 53.11636223111834, 55.23096309389387, 51.23520694460188, 50.71539831161499, 48.133690902165, 45.259610244206016, 44.20687130519322, 40.33124603543963, 41.27657972063337, 40.041697229657856, 39.09132262638637, 41.34954275403704, 47.77858584267752, 46.743408475603374, 48.4499694279262, 51.39795112609863, 51.89418452126639, 50.78614834376744, 52.58624594552176, 51.20642055783953, 43.50822646277291, 37.88741520472935, 39.5647485596793, 41.3864654813494, 36.331828185490195, 38.92160940170288, 39.21722745895386, 40.16158144814627, 39.21124158586775, 42.59995446886335, 46.436402320861816, 46.19195079803467, 47.807229791368755, 47.47361898422241, 49.40635422297886, 49.18590177808489, 50.24530751364571, 48.22747073854719, 49.789040156773154, 48.51520953859602, 49.626431465148926, 50.37168482371739, 48.77368252617972, 49.886568546295166, 51.781950269426616, 51.11658729825701, 41.98987136568342, 35.22698817934309, 40.84603112084525, 45.99532720020839, 42.70784609658377, 39.239503383636475, 38.33704008374895, 43.19594662530081, 49.0857469694955, 48.30040945325579, 47.98347084862845, 45.111860275268555, 48.103125776563374, 49.136632101876394, 47.67119795935494, 44.853988306862966, 47.01055628912789, 45.47988551003592, 46.8595232963562, 45.35218109403338, 45.03882775987898, 45.02470554624285, 45.612033299037385, 44.73923185893467, 42.09053339276995, 36.622818742479595, 37.669557912009104, 36.956745692661826, 36.7347993850708, 38.281051499503, 40.373873233795166, 38.28518567766462, 40.0077657018389, 44.28707436152867, 48.54732411248343, 49.72909457342965, 48.70173740386963, 44.896202087402344, 43.12879228591919, 46.544346060071675, 47.692143304007395, 53.80459867204939, 55.837492193494526, 53.81842906134469, 54.45367159162249, 51.44430603299822, 48.085744857788086, 45.037556239536826, 42.27248239517212, 42.91812290464129, 45.49195105688912, 47.17130633762905, 47.380186557769775, 48.64483513150896, 49.13588169642857, 50.901328631809776, 58.217149462018696, 58.25649363654, 59.55560180119106, 63.35078430175781, 61.97898060934884, 59.08106068202427, 58.55442196982247, 59.88472407204764, 60.07698767525809, 60.72068268912179, 61.618271827697754, 63.219921929495676, 65.68236351013184, 71.34284550803048, 75.64470454624721, 3.4357144066265652, 0.4992097754563604, 0.41993585069264683, 2.082209663731711, 49.5281526701791, 71.6803959437779, 67.0211980002267, 67.6996270588466, 51.45153215953282, 35.38203028270176, 27.230169194085256, 40.1564884185791, 53.33718293053763, 80.57315908159528, 13.279718501227242, 0.4910546530570303, 0.13869372489196913, 0.07557943729417664, 0.01409608155622014, 0.18018120154738426, 0.13580315214182648, 0.19496350762035164, 0.2069969190550702, 0.261938781610557, 0.21217719465494156, 0.6866274986948285, 21.365663766860962, 81.99551786695207, 54.25040551594326, 40.5790604863848, 39.155937399183, 49.1496947152274, 55.78738178525652, 68.75033364977155, 71.98588739122663, 59.80925273895264, 1.3081766494682856, 0.11164054048380681, 4.879924842289515, 9.611529963357107, 4.861599837030683, 5.8020424246788025, 9.491914119039263, 56.960932527269634, 62.671854972839355, 60.6755610874721, 57.26560408728463, 55.51336915152413, 48.14931740079607, 48.96341003690447, 51.145172187260215, 54.497024876730784, 53.96048150743757, 57.55230760574341, 57.34244074140276, 57.60675368990217, 58.34691401890346, 58.63356195177351, 56.67221750531878, 55.357680865696494, 58.3019939150129, 53.772147110530305, 52.82192884172712, 50.881331716264995, 46.984851428440635, 46.528438159397666, 43.56662259783064, 43.27676459721157, 42.14945759092058, 41.67398541314261, 45.7054830959865, 49.50554323196411, 49.469864232199534, 51.952208927699495, 52.75817564555577, 54.13966860089983, 52.88120739800589, 56.36381476266043, 54.189810276031494, 45.14257826123919, 42.07086999075753, 40.682852676936555, 43.82507126671927, 38.03115953717913, 41.1569630077907, 41.404867785317556, 41.76408270427159, 41.785639490400044, 45.32372127260481, 49.68366725104195, 47.53326232092721, 51.30168383462088, 51.14173282895769, 51.249242305755615, 52.64955793108259, 52.77041489737374, 51.792497634887695, 50.96101018360683, 50.57050405229841, 51.30515445981707, 52.42717736107962, 50.75129965373448, 51.58714362553188, 52.79989957809448, 53.028714179992676, 43.0592269216265, 36.950725078582764, 44.10945061274937, 49.436558042253765, 46.04700790132795, 41.20639944076538, 40.0322858946664, 44.957387924194336, 51.88068069730486, 50.77668489728655, 48.76161697932652, 49.07535941260201, 49.288901873997276, 52.93115104947771, 51.763624395642964, 47.52926710673741, 48.13725185394287, 47.2315229007176, 48.88934571402413, 47.5313480922154, 47.62969636917114, 47.87914712088448, 48.99027872085571, 47.37688616343907, 45.481452328818186, 39.32154771259853, 39.31141376495361, 39.323180539267405, 38.340767792293, 40.171531268528526, 41.72258458818708, 40.47294064930507, 42.58196210861206, 46.73876707894461, 51.24978426524571, 52.07823882784162, 49.562237058367046, 46.91148887361799, 46.204440185001914, 48.1401492527553, 48.845110007694785, 55.06675979069301, 57.148113523210796, 56.21467167990548, 57.13425881522042, 54.594782556806294, 49.62725135258266, 47.653511319841655, 43.42129407610212, 45.094521045684814, 47.442355564662385, 49.34313256399972, 50.52873148236956, 48.76617499760219, 52.22960533414568, 52.63374383108956, 60.64607988085066, 59.089030265808105, 62.318469592503135, 65.71698638371059, 65.19612857273647, 61.597496713910786, 61.31590012141636, 62.01478467668806, 63.58457728794643, 63.68226201193673, 64.00235857282365, 65.1134033203125, 69.59057235717773, 74.45775767735073, 78.28734765733991, 4.649112633296421, 0.4435860530606338, 0.8795613859380994, 4.105454308646066, 53.38666105270386, 79.2843724659511, 70.77945082528251, 75.76481110709054, 55.446426732199534, 54.321124281202046, 48.28857319695609, 45.77159520557949, 62.204609462193076, 94.12532860892159, 16.684803077152797, 0.6932532574449266, 0.24569516895072802, 0.2384656768824373, 0.17238872897412094], [0.12256637242223535, 0.12016133219003677, 0.07812462214912687, 0.03235701105690428, 0.07269146333315543, 0.024860910705423782, 0.20145877051566327, 8.414913807596479, 61.430698258536204, 34.120365960257395, 58.942805426461355, 31.459702696119034, 26.110835245677404, 41.6942845753261, 58.44682216644287, 61.0632358278547, 57.94155263900757, 2.994920036622456, 0.10739314875432424, 0.14952512511185237, 2.6752431903566634, 0.29562600968139513, 2.5656440428325107, 7.009250240666526, 48.75229597091675, 58.58272198268345, 54.402630124773296, 53.10337952205113, 46.69188410895211, 45.83531366075788, 48.5793240410941, 52.20809371130807, 53.61747326169695, 56.49344382967268, 54.24617406300136, 53.63830048697335, 53.9689930507115, 54.43024574007307, 53.69348308018276, 52.33420351573399, 49.498970236097065, 49.89135585512434, 46.763877868652344, 43.84372023173741, 41.51508705956595, 37.434719221932546, 39.112264496939524, 38.606842109135215, 37.7772410937718, 36.59459515980312, 40.81420142310006, 46.093213421957834, 45.077894006456646, 45.513042313711985, 50.263550009046284, 48.78146798270089, 50.22267723083496, 51.54921688352312, 49.00823981421334, 46.21158988135201, 39.36275747844151, 37.08498511995588, 37.992166246686665, 35.621013573237825, 36.06602484839303, 36.872286864689414, 35.90346132005964, 37.272235597882954, 37.76146173477173, 39.10612228938511, 42.708613872528076, 41.845564229147776, 43.850519044058665, 44.38039561680385, 44.61870493207659, 45.73326894215175, 44.79758977890015, 44.82636226926531, 47.05012628010341, 47.102769306727815, 47.09207950319563, 45.967947823660715, 48.481215476989746, 47.68069267272949, 48.217406272888184, 49.0353273664202, 44.86152015413557, 33.69393764223371, 36.292727197919575, 41.26447595868792, 39.06259877341134, 35.085015637534006, 39.858264786856516, 44.682499817439485, 48.62232991627285, 47.55104970932007, 48.1036434173584, 46.70259475708008, 44.7006311416626, 46.05319874627249, 44.185620239802766, 43.8561748777117, 43.66250426428658, 44.40414803368704, 43.739212376730784, 43.30863945824759, 44.523799487522666, 41.17737681525094, 39.92691993713379, 40.55951867784773, 35.58862107140677, 35.26273666109358, 34.5154891695295, 34.45933035441807, 36.64382314682007, 36.89290564400809, 36.49086202893938, 38.709883894239155, 41.69264480045864, 48.47578893389021, 52.30623006820679, 49.50283343451363, 50.38264560699463, 47.367391450064524, 45.00284998757498, 43.68847663061959, 46.01671722957066, 47.832073075430735, 51.833040373665945, 53.23484638759068, 54.79795135770525, 51.53066519328526, 50.868606090545654, 48.30218471799578, 46.55994129180908, 40.512979643685476, 40.131262983594624, 40.90989548819405, 41.83565957205636, 43.679864338466096, 44.145341532570974, 44.01233564104353, 44.92431449890137, 54.22434977122715, 57.825569834027974, 57.75170006070818, 58.144096102033345, 61.4776611328125, 58.75852530343192, 55.13848951884678, 58.62318134307861, 56.943739209856304, 61.65979426247733, 60.54279490879604, 67.07524108886719, 60.79523686000279, 51.97903939655849, 2.524634037699018, 0.37554899390254703, 0.34057553485035896, 1.115595600434712, 48.80645717893328, 65.64545467921666, 57.608112062726704, 68.42081533159528, 32.40790946143014, 55.95584780829293, 34.87125778198242, 32.03098011016846, 51.18036133902413, 62.459976605006624, 9.97999554021018, 0.508457610649722, 0.07748452613928489, 0.17154712841979095, 0.07654596293079001, 0.058878302041973384, 0.009460053805794035, 0.05972087290138006, 0.021168090735695193, 0.080859518609941, 0.03674432349258235, 0.2363014215869563, 13.235870156969343, 73.18869004930768, 41.85733447756086, 56.55851023537772, 27.63186366217477, 31.09590891429356, 45.90757145200457, 62.232728821890696, 63.7470053264073, 63.97170312064034, 3.4600335359573364, 0.3561643340757915, 0.3858128674328327, 2.3381404791559492, 0.5522119913782392, 3.0491921986852373, 7.371451582227435, 51.62428522109985, 61.60920442853655, 57.13050331388201, 54.49404409953526, 49.01785264696394, 48.17976788112095, 51.51845720836094, 54.592225619724815, 56.39484889166695, 59.50494943346296, 57.90910802568708, 55.796449184417725, 55.12580558231899, 56.769089290073936, 55.86822754996163, 55.03450972693307, 52.157267638615195, 51.383151463099885, 48.43358557564871, 45.72734212875366, 43.376248904636924, 40.734793935503276, 39.8944787979126, 40.84261955533709, 39.90917076383318, 38.704102993011475, 42.0546007837568, 47.98613200868879, 48.285314491816926, 48.180917807987754, 52.17821645736694, 50.77243954794747, 51.25705208097185, 53.836890425000874, 51.49798434121268, 47.15917130878994, 41.97240012032645, 38.29118544714791, 39.6286997795105, 37.12856422151838, 36.131581102098735, 38.32215356826782, 37.667466504233225, 39.91981887817383, 39.00973687853132, 42.79277740206037, 43.88183110100882, 42.5684826033456, 45.21935585566929, 45.52320752825056, 46.13169254575457, 48.967325346810476, 46.14574180330549, 47.2687200818743, 49.003640106746126, 48.781019823891775, 47.95751237869263, 49.48408719471523, 51.13974217006138, 51.53949635369437, 49.62460061482021, 51.57734319141933, 47.111885343279155, 35.19682604925973, 39.534027099609375, 41.74551016943795, 41.0043215070452, 37.63081128256661, 38.99502406801496, 47.44886950084141, 50.781798771449495, 48.20799841199602, 49.97325079781668, 48.47999259403774, 47.73544100352696, 46.209338665008545, 45.741999353681294, 48.065668037959504, 46.86837182726179, 46.650292192186626, 46.119640895298545, 45.71035725729806, 46.77857330867222, 43.86046539034162, 41.36112192698887, 40.60381344386509, 37.11692598887852, 37.36724179131644, 35.802226066589355, 35.94747815813337, 37.037660939352854, 39.600955622536794, 38.74239798954555, 39.543897015707834, 41.52315044403076, 49.584419182368684, 54.05770765032087, 52.05702945164272, 52.02508510862078, 49.3090238571167, 45.81611231395176, 45.01662826538086, 47.455577986580984, 52.03808518818447, 52.84346825735909, 54.569793360573904, 55.9885390826634, 54.15078224454607, 53.19944531576974, 50.85339648383004, 48.333444663456504, 43.57267795290266, 41.633995056152344, 43.5152267728533, 42.33106960569109, 43.58330174854824, 46.00865731920515, 46.93611328942435, 47.85827125821795, 55.58126694815499, 61.21969536372593, 60.864941188267295, 61.16463783809117, 63.55759048461914, 61.85559449877058, 58.109236989702495, 62.0661735534668, 59.984493255615234, 65.42249393463135, 63.25447532108852, 70.65768364497593, 64.24986730303083, 55.745459829057964, 2.7290658908230916, 0.356526861765555, 0.8460716658404895, 2.5039761747632707, 55.686883040836875, 71.05726759774345, 64.63977936335972, 72.70528997693742, 41.69043527330671, 49.88352176121303, 27.510634967258998, 37.426364013126914, 52.92188215255737, 75.7974328994751, 12.676700847489492, 0.637096776493958, 0.03781759625832949, 0.15703635849058628, 0.054794216728104014, 0.15096914262643882, 0.18862354782010826, 0.18638736781265053, 0.08349244482815266, 0.20139990081744535, 0.14488304991807255, 0.30919334452067104, 19.442272118159703, 87.06392996651786, 48.76652240753174, 75.43052632468087, 42.75702544621059, 41.09520741871425, 54.31375919069563, 70.80775778634208, 70.13907705034528, 70.80555520738874, 4.356570890971592, 0.4166643890951361, 1.3544132198606218, 5.290556865079062, 1.3542947747877665, 5.43222542319979, 9.567838822092328, 55.52231843130929, 63.27302006312779, 58.76682145254952, 58.35935129438128, 51.417322703770225, 51.35704013279506, 53.962937695639475, 58.534362520490376, 59.52625955854143, 63.311221258980886, 60.679820333208355, 58.56159945896694, 56.880892753601074, 59.08927345275879, 59.93457044873919, 58.18244668415615, 55.25805412020002, 53.87312528065273, 52.469526631491526, 47.932325158800396, 47.00691195896694, 41.668784686497276, 42.73314101355416, 43.06758560453142, 42.144621644701274, 39.671959263937815, 45.35627358300345, 50.87255614144461, 50.411591802324565, 50.919661453792024, 53.58829777581351, 52.73704617364066, 52.42709745679583, 55.64112567901611, 52.08630221230643, 49.66162061691284, 44.078944546835764, 40.37088203430176, 41.54875455583845, 38.88324492318289, 37.98728861127581, 41.80700520106724, 39.941809926714214, 40.65442759650094, 39.96156712940761, 44.91738019670759, 47.586350032261436, 44.99803488595145, 47.79268026351929, 49.3821189062936, 49.16297272273472, 51.38607318060738, 48.04505273274013, 51.79503720147269, 53.46152094432286, 51.50848306928362, 50.66676786967686, 51.987651688711985, 53.64328581946236, 53.34777545928955, 52.135839394160676, 52.967649936676025, 47.327140535627095, 36.680554798671174, 39.88143702915737, 43.883550780160085, 44.62593105861119, 40.64951869419643, 40.30860185623169, 47.97634547097342, 52.26757376534598, 51.459060532706125, 53.28045783724104, 51.305915287562776, 50.8893256187439, 49.64206838607788, 47.91648326601301, 49.113779476710725, 47.24044091360909, 48.33454942703247, 47.86810643332345, 48.64194468089512, 49.69156040464129, 45.482067244393484, 43.796253613063264, 44.263919489724294, 39.56558581760952, 39.449724606105256, 37.61010217666626, 37.35076413835798, 40.304137638636995, 41.6528559412275, 39.65120846884591, 41.820668833596365, 43.487413133893696, 51.06472594397408, 56.07478707177298, 55.14643478393555, 54.70924718039376, 50.32784169060843, 46.61733341217041, 48.79934222357613, 50.172129086085725, 53.66165338243757, 54.88503313064575, 56.11189045224871, 58.92184965951102, 56.035171917506624, 55.18162046160017, 52.52298607145037, 52.03236334664481, 43.92300612585885, 43.98249660219465, 44.68277774538313, 44.97346952983311, 45.7311566897801, 48.51757887431553, 48.53288228171212, 50.18467058454241, 58.440110206604004, 62.78463813236782, 63.87927123478481, 64.37697069985526, 65.9495495387486, 65.48682730538505, 61.02106721060616, 63.63142204284668, 63.21654510498047, 69.10864530290876, 65.42299420492989, 75.46883869171143, 64.94840444837297, 57.96953303473336, 4.033018469810486, 0.4022607462746756, 1.2224775680473872, 5.468375163418906, 61.35052299499512, 80.12948880876813, 70.19942910330636, 82.66282980782645, 48.058903966631206, 67.96189376286098, 45.43926286697388, 46.302448000226704, 64.03732190813336, 88.11198234558105, 15.820438487189156, 0.7369784340262413, 0.25810907568250385, 0.24195014419300215, 0.1910901176077979], [0.03050498365025435, 0.08763834128954581, 0.1761292889714241, 0.06083972964968, 0.08308375640107052, 0.06750487057226044, 0.16851380547242506, 13.800746543066841, 51.78366300037929, 37.49911860057286, 35.87028019768851, 14.99811223575047, 29.113732031413488, 38.51705748694283, 59.22802897862026, 54.92635406766619, 66.12913962772915, 9.559969118663243, 0.17387402855924197, 0.18314345473689692, 1.054829152567046, 0.34378709537642343, 2.5451188470636095, 4.4523500714983255, 42.819566181727815, 58.19622148786272, 55.969883169446675, 52.9974125453404, 49.708718981061665, 52.99228477478027, 53.573623180389404, 55.79357263020107, 54.365422521318706, 54.70379979269845, 51.351398195539204, 50.994062764304026, 53.038858549935476, 53.02741139275687, 49.80612925120762, 48.4967759677342, 46.21159682955061, 46.56259897777012, 41.595046928950715, 39.745895045144216, 36.55816575459072, 38.48355327333723, 39.2962840625218, 37.36601543426514, 38.500941140311106, 43.27822024481637, 45.70714371544974, 51.846016134534565, 52.86098119190761, 54.329125131879536, 47.476981912340435, 46.31688635689871, 51.64069339207241, 48.07301575796944, 45.16364867346627, 41.021282059805735, 40.48534318378994, 36.7241130556379, 37.057529313223704, 37.76421322141375, 37.144996711185996, 35.24666895185198, 37.43462542125157, 37.885935238429475, 40.530850410461426, 34.513039929526194, 40.16227626800537, 40.85301753452846, 41.071976116725374, 43.19493566240583, 41.647106306893484, 44.37954446247646, 44.86968428747994, 44.44994708469936, 47.00103725705828, 46.68891722815377, 48.36831419808524, 46.22693497794015, 46.229919229234966, 47.36824260439192, 48.23763942718506, 47.93552133015224, 50.12041711807251, 37.497892243521555, 37.9378000668117, 41.20393977846418, 34.87225137438093, 35.29697390965053, 44.805048670087544, 49.34642253603254, 47.28683403560093, 49.0880502973284, 44.90078442437308, 45.95634085791451, 44.530369009290425, 44.57899945122855, 43.08519581386021, 43.71419538770403, 45.47496965953282, 43.23358849116734, 42.9657667023795, 43.063882214682444, 41.414960043770925, 42.06867783410208, 40.10945953641619, 37.92436572483608, 36.13296379361834, 35.031952244894846, 35.375856808253694, 34.73282882145473, 35.56795712879726, 35.16878659384591, 37.19635779517037, 37.204858916146414, 40.22683892931257, 49.84848199571882, 50.66700758252825, 49.352564743586946, 51.68953227996826, 49.96683413641793, 45.93647943224226, 44.55220719746181, 43.1599896975926, 43.26545292990548, 49.67020164217268, 50.82285567692348, 52.43733562741961, 52.33434247970581, 50.32570859364101, 48.19286176136562, 49.148895672389436, 48.00420774732317, 45.69411236899239, 41.74290459496634, 38.598688398088726, 42.18645674841744, 42.31664514541626, 42.21399940763201, 42.81958702632359, 47.52673101425171, 55.775295393807546, 54.38926873888288, 58.13857923235212, 60.14043862479073, 62.88245487213135, 61.72280052730015, 63.15746457236153, 61.13521221705845, 60.326316833496094, 60.8395802634103, 65.23651845114571, 48.0523796081543, 36.03817646844046, 1.0125623920134135, 0.1898487920739821, 0.35417628075395313, 2.3166505694389343, 54.86367089407784, 59.774442264011924, 65.38038090297154, 60.01677458626883, 37.080708503723145, 61.91489737374442, 46.05107607160296, 29.731932367597306, 42.987528460366384, 69.50144781385148, 9.065603920391627, 0.41944144293665886, 0.06836796033063106, 0.05143705615773797, 0.04840425568233643, 0.057566415651568344, 0.041240398306399584, 0.20679443063480513, 0.02248217897223575, 0.08110594895801373, 0.03740359829472644, 0.2667410724929401, 19.401203053338186, 65.30925914219448, 43.19083969933646, 47.54366030011858, 22.055149146488734, 34.635967458997456, 43.22972181865147, 64.45996693202427, 59.27478340693882, 72.53846372876848, 10.388560039656502, 0.31984181169952663, 0.15537995951516287, 2.297114623444421, 0.23748638800212316, 1.800664639898709, 4.707226932048798, 45.655400480542866, 61.165339606148855, 58.111981528145925, 56.40450341360909, 52.047180380140034, 54.93429238455636, 54.57832227434431, 57.59649120058332, 57.35610089983259, 57.37740060261318, 54.11120530537197, 53.766908168792725, 54.681186880384175, 54.18723944255284, 52.88964598519461, 50.16252320153372, 48.24542835780552, 48.622215270996094, 41.89162383760725, 41.63542291096279, 38.56961018698556, 40.526563371930806, 42.01890788759504, 40.029124464307515, 41.37735639299665, 43.274951117379324, 48.57155248097011, 53.40149198259626, 53.736200605119976, 53.31332976477486, 47.542572907039094, 48.93431445530483, 52.713008880615234, 50.5947219984872, 49.707947731018066, 42.324857916150776, 41.713659627096995, 37.55148022515433, 38.627766609191895, 38.40074116843087, 38.19598470415388, 35.736496107918875, 38.421721254076274, 38.01012734004429, 42.26831695011684, 37.42851448059082, 41.03715521948678, 42.13152429035732, 43.19785043171474, 42.9531626701355, 43.75244869504656, 46.46353503635952, 46.9369227545602, 45.1035224369594, 46.84793022700718, 48.779157706669395, 51.02641705104283, 48.81099435261318, 47.38820130484444, 48.76534468787057, 52.06044449125017, 50.17204223360334, 49.57529272351946, 38.185871601104736, 39.16015148162842, 42.27131857190813, 37.97756460734776, 37.08813960211617, 43.83278029305594, 49.226673807416645, 48.74061952318464, 51.32935503550938, 48.16773360116141, 48.26451505933489, 47.0954841205052, 46.965695244925364, 46.2473383631025, 44.00901092801775, 46.95768744604928, 44.95726980481829, 45.05954728807722, 45.58444547653198, 44.10898160934448, 43.30134732382638, 43.22363519668579, 39.89206429890224, 37.949900354657856, 37.48716769899641, 35.24885416030884, 36.62925624847412, 36.677695614951, 38.654701301029746, 38.92286702564785, 39.897907733917236, 42.07254103251866, 51.36521468843733, 51.569703647068565, 50.88733843394688, 53.07074383326939, 52.73312391553606, 48.191732679094585, 47.9589193889073, 44.28438540867397, 47.88063056128365, 51.907396520887104, 52.40153156008039, 54.247872897556846, 55.96093736376081, 52.67434562955584, 51.15880107879639, 50.67237854003906, 50.527373109545024, 45.64197656086513, 44.8438196182251, 41.38308865683419, 45.69850363050188, 44.42192152568272, 44.82043545586722, 44.908250263759065, 51.792918000902446, 58.53051321847098, 58.21925476619175, 62.12047372545515, 63.228905950273784, 63.84705243791853, 65.6345112664359, 65.22565841674805, 63.97940172467913, 64.22556945255825, 63.99889142172677, 67.57594912392753, 50.73700026103428, 39.65641961778913, 1.1762328552348273, 0.23611824427332195, 0.7751562339918954, 4.334815646920886, 61.224482672555105, 67.46853692190987, 70.35010773794991, 67.52080821990967, 42.8972817829677, 73.29112039293561, 45.0680136680603, 33.29682377406529, 50.79353427886963, 76.13226658957345, 11.782194103513445, 0.6544260180422238, 0.16794501670769282, 0.11282872315496206, 0.037474132009914944, 0.11491130319024835, 0.1414783647550004, 0.24350103097302572, 0.1218404620885849, 0.14985956145184381, 0.18507820234767028, 0.5193872898817062, 28.687097004481725, 76.32004860469273, 53.02130740029471, 50.92418820517403, 24.302580458777292, 43.648778097970144, 52.225099427359446, 72.3979503086635, 63.24191297803606, 80.29586342402867, 12.67841010434287, 0.2913549302944115, 0.3776726728039128, 3.460402007613863, 1.6648889141423362, 5.175655807767596, 7.095750101975032, 48.10212871006557, 62.382587569100515, 60.208836691720144, 59.26480579376221, 53.84581538609096, 58.053609711783274, 56.724936962127686, 58.58864879608154, 58.41342217581612, 60.52958638327462, 57.824496337345664, 54.80389206750052, 58.10447399956839, 57.301522799900596, 54.33116095406668, 52.382830483572825, 51.776367391858784, 53.40442064830235, 44.0660000528608, 43.64806243351528, 41.466453143528526, 42.81761026382446, 43.62604011808123, 40.9823374067034, 43.52644116537911, 46.78613294873919, 50.061621461595806, 56.59550244467599, 54.484618868146626, 53.779248169490266, 51.10539722442627, 48.39677749361311, 55.88844680786133, 53.29060568128313, 49.90334497179304, 44.34749589647566, 44.487981523786274, 40.67810705729893, 40.01059709276472, 41.838814054216655, 39.869496549878804, 39.456645011901855, 39.684983662196565, 41.87870018822806, 43.81821686880929, 38.62378529139927, 43.47169630868094, 44.287612846919465, 46.21854502814156, 46.13805014746529, 46.557019574301584, 48.82305989946638, 51.87598371505737, 50.02052634102957, 51.0165992464338, 51.096423625946045, 54.38574252809797, 52.10059118270874, 49.82525416782924, 52.29873991012573, 53.57223006657192, 54.16893788746425, 54.018460750579834, 40.13502890723092, 40.06738819394793, 45.193974086216514, 42.00105101721627, 39.791291100638254, 46.374153409685405, 51.96929802213396, 51.25865364074707, 54.71140807015555, 50.70191533224923, 50.46765334265572, 47.972353730882915, 48.343516077314106, 49.775887216840474, 46.60575076511928, 50.73573221479143, 47.17884165900094, 46.18771587099348, 49.25428247451782, 46.66348682131086, 47.84397881371634, 45.54497970853533, 42.73616695404053, 40.79779325212751, 38.920223236083984, 38.26433065959385, 39.723299503326416, 39.1279604775565, 39.064707551683696, 41.32233708245413, 41.652928897312705, 44.619285106658936, 53.737409591674805, 53.95794194085257, 54.314613819122314, 54.35234601157052, 54.27952889033726, 51.50997345788138, 49.24457236698696, 48.37921939577375, 48.28685351780483, 53.30129548481533, 54.73561559404646, 55.477624143872944, 58.595673424857004, 54.403686250959126, 53.14726434435163, 53.77939060756138, 52.50803702218192, 48.41168485369001, 46.84016214098249, 42.797981602805, 47.792857442583355, 47.844593729291645, 47.431346143995015, 49.14345523289272, 53.31893001283918, 60.502245221819194, 60.40015533992222, 64.37604658944267, 64.77344185965401, 66.82860783168248, 68.54432650974819, 68.19000312260219, 67.79934760502407, 66.30938284737724, 67.61612360818046, 72.3567474910191, 50.92362192698887, 45.917326722826274, 2.0612293609551022, 0.3014726745230811, 1.2376399487257004, 7.507525971957615, 67.40466908046177, 74.41896588461739, 76.98596395765031, 74.4550061907087, 53.68385287693569, 73.69540827614921, 54.93059594290597, 44.01833541052682, 57.39174863270351, 91.06352152143205, 14.977139098303658, 0.8710836608495031, 0.47738570081336157, 0.2885503007897309, 0.1511696632951498], [0.06515646765806846, 0.06910239984946591, 0.06069058765258108, 0.04070480347477964, 0.13333542884460517, 0.04334789414757064, 0.11463306312050138, 19.981160504477366, 50.26333114079067, 34.94118792670113, 32.056386198316304, 15.476940393447876, 19.928159645625524, 34.16285766874041, 62.40431458609444, 55.471766812460764, 67.41979530879429, 26.539452246257238, 0.17148732234324726, 0.18704321262027535, 2.4030731320381165, 0.26407646547470776, 1.5699015025581633, 1.0979848482779093, 31.805156707763672, 60.50526768820626, 56.61348785672869, 54.35201249803816, 53.35752378191267, 57.039089339120046, 55.12398168018886, 53.67194019045149, 54.11427640914917, 51.705846650259836, 52.649766377040315, 56.9858591897147, 52.52332305908203, 49.527523858206614, 48.657383578164236, 45.32398183005196, 41.470983369009836, 38.32804216657366, 40.07382917404175, 37.23411430631365, 40.528543608529226, 38.40875244140625, 41.74903290612357, 39.59880862917219, 39.0550217628479, 43.443625586373464, 51.72246674128941, 32.35184792109898, 45.02860695975167, 57.696222169058665, 39.66278069359915, 50.878587177821565, 50.74876356124878, 49.939715317317415, 40.73522124971662, 38.88832753045218, 38.70236594336373, 38.544311795915874, 40.47063732147217, 38.690098898751394, 36.33160931723458, 35.90979807717459, 36.46454920087542, 36.563977922712056, 35.98168066569737, 37.20354570661272, 39.020100116729736, 40.90272842134748, 40.894154344286235, 41.67140415736607, 42.54025207247053, 45.11708879470825, 41.84327827181135, 41.13916867119925, 44.838233266557964, 46.128843784332275, 46.27510336467198, 47.678028038569856, 47.06598206928798, 46.95715938295637, 47.220471790858674, 46.069186551230295, 51.671612875802175, 40.31568554469517, 37.93466295514788, 39.97062758037022, 32.533630166734966, 36.36183050700596, 44.01999602999006, 47.79036998748779, 47.161123752593994, 47.98568384987967, 46.85253688267299, 46.53828723090035, 43.68452657972063, 45.22371585028512, 43.00128241947719, 43.99927650179182, 42.739912033081055, 43.468312535967144, 42.16987487248012, 42.25624792916434, 40.64087860924857, 39.1265013558524, 39.86024849755423, 35.12759419849941, 34.89296742847988, 33.98507758549282, 35.22188472747803, 36.15256813594273, 35.562026841299875, 36.197568144117085, 36.09132671356201, 37.92910092217581, 40.43757431847708, 48.11990567616054, 53.383947781154085, 51.51936394827706, 51.19445923396519, 53.835594585963655, 51.00884853090559, 47.05547986711775, 49.48523712158203, 40.653937748500276, 46.75129120690482, 50.99122095108032, 50.17617988586426, 50.74287148884365, 51.00447463989258, 53.060502188546316, 50.67733260563442, 48.302361897059846, 49.77662025179182, 47.984290736062185, 41.79141344342913, 43.04713705607823, 42.419294357299805, 41.429151739392964, 41.872557980673655, 46.846200125558035, 49.47372743061611, 54.896396909441265, 55.696992669786724, 58.964824267796104, 60.37840747833252, 61.73233345576695, 62.78927258082798, 64.46656772068569, 62.39691475459507, 60.93046270098005, 53.96236099515642, 65.32351684570312, 41.116201400756836, 0.15825582162610122, 0.02275184914469719, 0.44825499824115206, 4.408658495971134, 61.079751695905415, 57.91258212498256, 66.83945396968296, 59.33328723907471, 41.879245621817454, 34.08774764197213, 34.45242037091936, 53.86256054469517, 42.52839149747576, 64.78749806540353, 6.169174381664821, 0.46550379267760683, 0.10969066832746778, 0.1552726152752127, 0.06761254729436976, 0.1273534641202007, 0.09299316323761429, 0.10647481946008545, 0.08047602418810129, 0.05716470256447792, 0.052236472189958603, 0.1314643413892814, 26.912688629967825, 61.83015019553048, 41.802575724465505, 41.490215982709614, 19.3454715524401, 27.30335283279419, 43.09054592677525, 65.53112207140241, 60.873508317129954, 71.21336582728794, 29.156798703329905, 0.20558427699974605, 0.20335938781499863, 3.05192740048681, 1.1936513377087457, 1.6644636626754488, 1.8212394501481737, 35.213032722473145, 63.15438652038574, 58.48613507407052, 56.93286527906145, 56.67344386237008, 58.59448528289795, 56.43940074103219, 56.64865268979754, 54.4163111277989, 54.50503614970616, 56.0268931388855, 56.945729868752615, 56.38669170652117, 51.07913303375244, 50.57247386659895, 47.66107095990862, 42.90152713230678, 39.94556195395333, 41.8022700037275, 39.66212061473301, 43.44821834564209, 40.443459442683626, 44.218325410570415, 42.251769815172466, 41.118661063058035, 45.1201251574925, 53.401210580553325, 34.504764625004356, 42.8357172693525, 58.31019278935024, 40.61476380484444, 52.62529482160296, 51.563307830265586, 52.95980889456612, 41.46644272123064, 40.436584200177876, 40.54571260724749, 39.99506439481463, 42.445054803575786, 40.25043848582676, 37.911515031542095, 38.36610092435564, 38.410951546260286, 37.93660497665405, 37.39333227702549, 39.18307358877999, 39.311483246939524, 44.271131719861714, 43.39463036400931, 44.02113206045968, 45.67977476119995, 47.69664921079363, 45.48837273461478, 43.341546126774375, 46.200514452798025, 49.729143210819785, 48.539104393550325, 49.1728252683367, 50.56023808888027, 49.83568688801357, 48.155855655670166, 50.09090117045811, 52.65649223327637, 42.43051222392491, 38.31154714311872, 41.83165740966797, 35.14249113627842, 38.08957999093192, 44.424575737544465, 50.172882965632844, 49.556772300175254, 50.56257963180542, 50.15378584180559, 48.57922676631382, 47.16624110085623, 47.88172837666103, 45.02360078266689, 44.410675866263254, 46.70046166011265, 46.35120003564017, 45.594850403921946, 45.400585719517295, 41.62845039367676, 41.760170868464876, 40.73348420006888, 37.048395906175884, 36.083586420331685, 36.170042855399, 36.13466262817383, 38.11477415902274, 37.68165472575596, 38.20504168101719, 36.923345702035085, 39.67253596442086, 41.26486158370972, 50.25221054894583, 53.014880316598074, 51.50113187517439, 51.36503056117466, 56.329250948769705, 54.33545841489519, 49.49460676738194, 51.242492130824495, 44.64921794618879, 49.02957425798689, 51.77133689607893, 53.293232100350515, 52.39287410463606, 53.12319231033325, 55.213147912706646, 53.293155670166016, 52.82324552536011, 52.479712690625874, 50.35710750307356, 44.35472897120884, 44.58931057793753, 43.93479721886771, 44.394451822553364, 43.095875195094514, 49.15511778422764, 53.01745115007673, 57.27875007901873, 57.86009543282645, 60.50496196746826, 62.07833290100098, 64.33624035971505, 65.27931240626744, 67.66453170776367, 63.87513010842459, 64.27058683122907, 57.25731488636562, 65.74930245535714, 43.37060349328177, 0.10793031778718744, 0.040780656904514344, 0.7368130343300956, 6.130623170307704, 66.90267562866211, 65.08328982761928, 72.89901270185197, 67.69212995256696, 45.18872472218105, 53.230316162109375, 39.86141926901681, 47.014179774693076, 50.35398081370762, 78.30637877328056, 9.25313753741128, 0.5794554437909807, 0.08159625836248909, 0.16759741678833961, 0.0728220541828445, 0.2338956349662372, 0.1756049171090126, 0.18089982441493443, 0.1484340950846672, 0.22734435221978597, 0.2029997913965157, 0.3508242091962269, 36.25163902555193, 74.84796156202043, 49.83305352074759, 45.2025203704834, 24.648194278989518, 35.4784573827471, 47.03847067696707, 72.11299078805106, 67.2355568749564, 78.88449668884277, 32.13257319586617, 0.14315483479627542, 0.3399970158934593, 5.44869612795966, 1.9887353309563227, 3.401093052966254, 2.6604055293968747, 38.39041267122541, 65.64528792245048, 60.90997246333531, 59.37480967385428, 60.41756057739258, 61.09749044690813, 58.43685844966343, 59.0336183820452, 58.041269711085725, 55.29533467973982, 57.81134339741298, 60.171295574733186, 59.48987879071917, 55.248142514910015, 54.04065677097866, 49.2439991406032, 46.506012848445344, 41.06597982134138, 44.20623207092285, 42.29108272280012, 46.74365513665335, 42.224887234824045, 46.482062407902305, 45.266158921378, 42.67638465336391, 48.18407923834664, 57.346251828329905, 36.40946735654558, 44.82197100775582, 59.00183732169015, 41.59758302143642, 54.06661524091448, 54.077013220105854, 54.10612964630127, 43.22209964479719, 42.58086429323469, 41.999178477696006, 42.02861452102661, 44.81725665501186, 42.19921364103045, 39.30438566207886, 39.49660757609776, 40.844040461948936, 41.03056485312325, 38.42459780829293, 40.19081251961844, 42.47494942801339, 45.251112597329275, 45.39083044869559, 46.462951387677876, 48.78883307320731, 50.17187895093645, 45.96264982223511, 44.94087553024292, 50.189923422677175, 52.10521520887102, 51.863577706473215, 52.74966410228184, 53.95832756587437, 52.8273275920323, 51.000225816454204, 52.11212171827044, 56.47186967304775, 42.83579369953701, 40.784247738974436, 43.75256681442261, 38.891308307647705, 38.50456462587629, 46.18536043167114, 52.09907994951521, 51.89764125006539, 55.80987657819475, 51.6458420072283, 51.35724857875279, 51.13897786821638, 51.627502237047466, 47.57412467684065, 47.021392004830496, 48.45040716443743, 47.48087985174996, 48.28299379348755, 48.97425964900425, 45.06328541891915, 43.64669016429356, 42.85712466921125, 39.67626019886562, 37.44166047232491, 39.413135392325266, 37.74250357491629, 39.85895960671561, 39.896295751844136, 38.95248024804251, 39.40206343787057, 40.89031546456473, 43.79594441822597, 52.229865891592844, 56.112307344164165, 54.33579887662615, 53.47223506655012, 58.03340087618147, 54.35886689594814, 51.3123562676566, 53.90152951649257, 45.72461496080671, 50.703826086861746, 54.174315793173655, 54.66873223440987, 54.47508246558053, 54.02227183750698, 57.899891240256174, 55.388218198503765, 53.75761842727661, 53.94683871950422, 51.89960759026663, 44.96959938321795, 46.00440502166748, 46.74260595866612, 46.51378788266863, 45.31515414374215, 52.74075303758894, 54.97310849598476, 59.63483905792236, 60.6801746913365, 62.93929808480399, 66.42532743726457, 67.36514772687639, 68.48816422053746, 70.74075630732945, 66.75432464054653, 65.25217969076974, 60.696259771074565, 67.11242089952741, 48.28671107973371, 0.23544918160353387, 0.2131657251822097, 1.666125150663512, 8.563963958195277, 74.24856131417411, 71.73912906646729, 79.53575134277344, 75.5454912185669, 56.16959524154663, 54.28447600773403, 46.63192810331072, 72.877014705113, 56.801502636500764, 91.12719481331962, 11.14801812171936, 0.8774510334644998, 0.317267612687179, 0.28495004826358383, 0.2256184034049511], [0.12212503967540604, 0.04106937016227415, 0.11411554446177823, 0.18832564380552086, 0.14019008459789412, 0.06924954695361, 0.18446659802326135, 28.29722489629473, 55.18242645263672, 35.382805006844656, 27.752505234309606, 21.274708373206003, 47.09080103465489, 34.397456645965576, 57.48210995537894, 55.55690656389509, 62.17783110482352, 39.6313088280814, 0.25352733582258224, 0.09513651286917073, 1.0079676785639353, 0.16122670578105108, 0.6628039170588765, 0.3769536428153515, 21.553593431200298, 56.12939296449934, 58.55390780312674, 56.82763828550066, 55.429466179439, 55.275094577244346, 55.3625237601144, 54.50928149904524, 52.04526962552752, 54.577683040073936, 52.41080740519932, 52.63372646059309, 49.028063024793354, 47.811106886182515, 44.350598267146516, 43.505419390542166, 40.72866562434605, 42.81416743142264, 44.865855830056326, 46.6716057913644, 44.35908201762608, 41.24324573789324, 40.678506578717915, 38.37538719177246, 41.6381778717041, 46.657879625047954, 48.58113752092634, 42.57950244631086, 33.643670899527415, 38.53467811856951, 45.339438097817556, 50.80240018027169, 52.60357127870832, 48.359455244881765, 42.20248276846749, 40.417511395045686, 36.31700420379639, 41.24860627310616, 40.97834914071219, 36.14616884504046, 36.56837613242013, 35.50442280088152, 36.52042661394392, 36.98968015398298, 34.387558937072754, 37.49704108919416, 38.00203963688442, 40.554370062691824, 43.171551500047954, 42.07985053743635, 44.126366002219065, 43.37855223246983, 45.58820445196969, 42.11906269618443, 45.252338954380576, 46.19309377670288, 44.964666162218364, 46.4801481791905, 47.517458643232075, 45.72309330531529, 44.78914771761213, 48.15369129180908, 50.06221553257534, 44.69833476202828, 36.529879638126914, 39.05159977504185, 35.650050095149446, 38.016544001443044, 47.449995109013145, 50.54727275030953, 47.34850624629429, 47.036896909986226, 45.71093395778111, 45.21169546672276, 43.292849676949636, 43.976781708853586, 42.51149000440325, 42.07603250231062, 41.999890668051584, 41.5580130304609, 40.14479112625122, 40.60490778514317, 38.541355337415425, 40.589917046683176, 37.56256260190691, 34.42432880401611, 33.185138429914204, 34.036532470158164, 35.48644781112671, 34.21819659641811, 35.42574487413679, 38.21768045425415, 37.48458644321987, 38.288962023598806, 39.50115864617484, 41.03065865380423, 47.80795240402222, 50.64677790233067, 51.71070344107491, 47.927669865744456, 50.5943363734654, 51.688385827200754, 47.271245752062114, 47.268733978271484, 41.59022487912859, 47.314251627240864, 46.66540452412197, 50.52757808140346, 50.781354086739675, 52.69401250566755, 53.92388881955828, 53.94916984013149, 52.16800607953753, 48.5922337940761, 48.85221454075405, 48.46754142216274, 44.33632319314139, 45.19565902437483, 43.19699580328805, 42.58142709732056, 40.521581513541086, 48.63214424678257, 49.9669314111982, 55.925324371882844, 56.849146434238975, 62.7378420148577, 57.29099975313459, 58.170231751033235, 59.258517674037385, 63.7751316343035, 57.4175785609654, 60.070143699645996, 24.420072759900773, 0.13040121272206306, 0.16326726414263248, 0.20843435477997574, 10.99734730379922, 66.08667918613979, 51.74335650035313, 64.24456582750592, 52.35016352789742, 41.23137821469988, 40.28695821762085, 36.025978905814036, 39.12107828685215, 51.87378461020333, 47.30786623273577, 3.3966633592333113, 0.4018866020653929, 0.0789801665980901, 0.07133746027414288, 0.04424845600234611, 0.12874903423445566, 0.05066638965425747, 0.07579368472631488, 0.11753214469977788, 0.12421510395194803, 0.09367244464478322, 0.16921433859637805, 34.393603869846885, 64.2841636112758, 42.06300810405186, 36.21968426023211, 16.276306322642736, 42.75313445499965, 40.667830671582905, 61.385798999241416, 61.50213963644845, 66.99290493556431, 42.74044009617397, 0.6130925416946411, 0.10319190419145993, 1.3462913185358047, 1.5940135972840446, 1.0472508392163684, 1.082337613616671, 23.475155966622488, 59.98087324414934, 59.09491539001465, 60.04618631090437, 57.45013434546334, 57.36518914358956, 56.565128394535606, 54.96765763419015, 53.94025182723999, 57.178727286202566, 56.48882327760969, 54.123093673161094, 50.59060519082205, 51.29617738723755, 46.474276951381135, 45.2354166167123, 43.1711346081325, 44.87003517150879, 46.93273993900844, 48.54655286243984, 47.47304228373936, 43.756318841661724, 43.680010250636506, 41.56492648805891, 43.037788254874094, 49.24840777260916, 50.37036466598511, 45.540293148585725, 36.46898215157645, 40.52265848432268, 45.58910424368722, 50.49266338348389, 53.17007180622646, 49.66980906895229, 43.57942812783377, 43.392980166843955, 39.40927219390869, 43.52517659323556, 42.24558939252581, 37.987781933375764, 38.7522748538426, 37.92682191303798, 37.642039571489605, 39.78224107197353, 36.46180466243199, 40.85378878457205, 39.772075857434956, 42.50236701965332, 43.579414231436594, 44.21511534282139, 46.620665073394775, 45.02031775883266, 46.79095152446202, 44.36555773871285, 45.88883910860334, 47.587062222617014, 47.642408098493306, 48.765653882707866, 48.45244298662458, 49.84297554833548, 49.90801068714687, 50.541960852486746, 51.631368909563335, 45.45361089706421, 37.30842529024397, 41.43786130632673, 38.32063538687569, 40.248201165880474, 48.25033378601074, 51.26283645629883, 49.57058531897408, 48.5800153868539, 47.572999068668906, 47.95254441670009, 46.269808837345664, 46.34208747318813, 43.21453653063093, 43.292641230991904, 44.69477033615112, 44.464896133967805, 43.391882351466585, 42.18723842075893, 40.76513671875, 41.17987469264439, 38.74900572640555, 37.87135444368635, 34.82169280733381, 35.2901542527335, 37.15735755647932, 35.77182422365461, 37.25208234786987, 39.19677196230207, 38.39974410193307, 38.64909757886614, 40.69030809402466, 42.747440406254356, 49.14590099879673, 52.39775174004691, 51.428026403699604, 48.48460272380284, 51.85760920388358, 54.44633776800973, 49.239201409476145, 48.90095962796892, 44.2921257019043, 48.95943219321114, 49.24840777260916, 52.37939807346889, 52.91997834614345, 55.69131251743862, 55.95255783626011, 56.369911806924, 52.259732723236084, 52.588778563908164, 52.62382527760097, 51.255019732883994, 46.58725118637085, 48.300663062504356, 46.56467301504952, 46.31483316421509, 44.2457777432033, 51.635812282562256, 52.24383871895926, 58.59017045157296, 58.45540319170271, 63.79794257027762, 59.76507609231131, 61.672217641557964, 62.965451104300364, 64.55824225289481, 59.83905356270926, 62.38593660082136, 27.403731720788137, 0.07821626508874552, 0.12591452204755374, 0.15529978381735937, 13.674536858286176, 70.406144959586, 58.24975388390677, 69.48304898398263, 61.434353010995046, 47.22397368294852, 49.14443492889404, 44.99003403527396, 45.125176497868125, 56.31431232179914, 62.229365893772666, 4.696034252643585, 0.5266050025820732, 0.03897140434544001, 0.11083162496132509, 0.10505398070173604, 0.1720411426254681, 0.16245541056352003, 0.2162442792739187, 0.30260240818773, 0.212403784639069, 0.2300114291054862, 0.4545957180006163, 46.41776377814156, 71.68205656324113, 50.44501263754708, 41.31288753237043, 31.52815634863717, 61.802621432713096, 48.79223074231829, 67.60789694104875, 65.23439925057548, 73.4951959337507, 46.31377703802926, 1.7093863721404756, 0.14778153438653263, 5.713136315345764, 2.8921791953699927, 1.2988670404468263, 1.740833050438336, 27.4769674709865, 62.495968273707796, 61.212316376822336, 61.78473676953997, 58.354188782828196, 59.97842747824532, 60.00096048627581, 57.42374161311558, 54.184571334293906, 57.77704014096941, 58.95486749921526, 58.092797551836284, 53.53144414084298, 52.61452163968767, 47.74304233278547, 48.449271133967805, 45.42423391342163, 47.79136010578701, 50.29719318662371, 50.57603134427752, 49.97412974493844, 46.231711864471436, 46.348521505083355, 44.69730295453753, 45.520372663225444, 52.800003801073345, 54.632778780800955, 46.95480046953474, 37.19235563278198, 42.180731432778494, 46.62765496117728, 52.46220670427595, 55.755819593157085, 52.219224725450786, 46.96453489576067, 45.28793804986136, 39.70474433898926, 45.492718832833425, 45.24111761365618, 40.43378407614571, 39.9191483770098, 39.051287106105256, 41.00483219964163, 42.423960072653635, 39.05495922906058, 42.960850851876394, 41.110549041203086, 43.65443393162319, 47.29129130499703, 45.43982219696045, 50.05635472706386, 47.99234022412981, 50.381381034851074, 46.91820430755615, 48.68570443562099, 50.50175510134016, 49.00661393574306, 50.50525351933071, 51.35188456944057, 52.39720630645752, 52.23516041891915, 54.53463894980294, 54.20075716291155, 48.88994325910296, 38.56728254045759, 42.580568994794575, 41.14195837293352, 41.24088682447161, 50.192813873291016, 54.79852110998971, 54.214455536433626, 53.65208918707711, 50.6784964288984, 50.77823781967163, 48.838818413870676, 50.156735352107454, 46.86676331928798, 46.98047753742763, 48.27373879296439, 44.5688168661935, 43.84211867196219, 45.94937876292637, 44.28695624215262, 44.56079517092024, 41.48780148369925, 40.34076854160854, 36.10804407937186, 38.6482811655317, 38.63549995422363, 36.88106591360909, 39.84580666678292, 41.42803307941982, 41.474634647369385, 40.61440944671631, 43.07025718688965, 45.52623346873692, 50.87165287562779, 55.546977588108604, 53.25150121961321, 51.031697681971956, 53.129952907562256, 55.22703388759068, 51.739305700574604, 50.804564544132774, 45.0295067514692, 50.7350617136274, 51.060150555201936, 54.443541118076865, 55.27619934082031, 55.7051568031311, 58.1165360723223, 59.16630813053676, 55.40826027733939, 53.94230154582432, 54.083596638270784, 54.34001990727016, 49.06823056084769, 49.61613423483712, 46.96468080793108, 47.748670373644146, 46.05378586905343, 54.22606945037842, 55.75136579786028, 62.098524366106304, 61.50637108939034, 66.66319901602608, 63.83690111977713, 65.05695615495954, 66.63934585026333, 67.82125527518136, 62.66093240465437, 63.87407398223877, 31.6438820702689, 0.1789168193936348, 0.2637190675096852, 0.41266135818191935, 15.828642572675433, 78.38111359732491, 65.61787033081055, 75.55995736803327, 68.93372440338135, 55.449007987976074, 58.579928806849885, 43.86681604385376, 55.88704327174595, 67.42172690800258, 77.67268916538784, 8.420998692512512, 0.7067734748125076, 0.23532427687730106, 0.34742719147886547, 0.1926180020506893], [0.0788211722725204, 0.017022462295634404, 0.1093085581170661, 0.026898680288078528, 0.11617210267909936, 0.029735314593251263, 0.1799489390105009, 29.453146321432932, 50.83011654445103, 33.84329611914498, 25.336484568459646, 47.40872975758144, 89.78899260929653, 43.5064685685294, 51.725044522966655, 58.42212132045201, 52.45148910794939, 55.43958623068673, 2.071168541908264, 0.0664047888879265, 0.3883528954216412, 1.175212447132383, 0.37227679948721615, 0.46972596326044624, 11.642704674175807, 46.49791472298758, 54.89140810285296, 55.48315143585205, 51.18823364802769, 52.78818838936942, 54.724654810769216, 56.14526612418038, 53.564465454646516, 52.9290075302124, 51.33085584640503, 49.74877882003784, 45.08432803835188, 43.254328863961355, 45.23696953909737, 47.274282114846365, 49.2396183013916, 49.03970125743321, 49.01473290579659, 50.46375887734549, 49.23373665128435, 44.517007623400005, 40.57992206301008, 39.64211327689034, 44.310885838099885, 46.4560900415693, 48.042266505105154, 45.89449494225638, 48.06270810535976, 51.901674679347444, 48.85732841491699, 49.44067137581961, 49.72888265337263, 49.56051390511649, 43.29758834838867, 41.05259411675589, 39.664291926792686, 45.14160551343645, 37.19885567256382, 36.21411875316075, 35.957497460501536, 34.02624913624355, 35.53670760563442, 35.13335425513131, 34.458843980516704, 35.27146359852382, 36.77989319392613, 38.9739362852914, 40.77131714139666, 40.12875468390328, 43.177839619772776, 40.84375558580671, 43.205545561654226, 43.61432892935616, 43.231879234313965, 45.5893509047372, 44.19747039249965, 46.329313210078645, 46.854715142931255, 47.463057722364155, 46.69929436274937, 47.78255326407296, 48.497984954289024, 43.09740032468523, 41.226639543260845, 42.54391029902867, 37.32397188459124, 42.91432571411133, 47.70329516274588, 46.768373353140696, 45.09829044342041, 46.27985940660749, 46.99238674981253, 44.64363506862095, 44.822335788181846, 43.15133571624756, 42.28747313363211, 42.31118038722447, 42.84951639175415, 42.79557057789394, 39.95889554704939, 38.7962326322283, 36.515826906476704, 39.75054339000157, 35.678607191358296, 35.973669392721995, 32.890350682394846, 32.4207775252206, 34.30977037974766, 35.234711102076936, 34.62342248644148, 37.82616336005074, 41.239038603646414, 37.297756331307546, 37.72677632740566, 38.982993262154714, 44.269227913447786, 50.526525429316926, 51.04241180419922, 50.36579622541155, 44.675176416124614, 52.57047006062099, 51.29271718433925, 48.149209703717915, 45.01378992625645, 46.13256107057844, 47.834636960710796, 48.49564688546317, 50.9693341255188, 53.71533863885062, 49.460817677634104, 53.21019070489066, 54.125153814043315, 55.01218516486031, 50.87856633322579, 52.119924545288086, 50.8636520249503, 50.04703719275338, 44.759232248578755, 46.93057904924665, 44.733933857509065, 41.823729515075684, 43.35354913984026, 50.07686580930437, 49.355316230228965, 52.745450019836426, 53.60848576681954, 56.17296511786324, 54.026864596775596, 59.45424148014614, 56.69255140849522, 63.73949432373047, 16.07600712776184, 0.24812589851873262, 0.032918570031012805, 0.34556284866162706, 15.87180130822318, 67.20669405800956, 48.922064781188965, 66.2450008392334, 42.776845182691304, 38.05171578271048, 39.01307896205357, 29.45683581488473, 27.314124277659825, 58.354126249040874, 51.57981327601841, 8.44332846573421, 0.5410370081663132, 0.12711136282554694, 0.20923489039497717, 0.006826428696513176, 0.12019950657018594, 0.08573327280048813, 0.08444267883896828, 0.026714838010125926, 0.007018960463548345, 0.0977339381352067, 0.26984794863632744, 39.36370938164847, 57.89325223650251, 44.33471815926688, 29.909097535269602, 36.51806770052229, 93.04698208400181, 45.12278284345354, 57.94493988582066, 62.47757639203753, 60.12370041438511, 60.18626894269671, 3.280668612037386, 0.03768607581566487, 0.4499826298228332, 1.0058986353022712, 1.7841482290199824, 1.5905189790896006, 13.21433334691184, 50.55408198492867, 56.67914833341326, 55.02301740646362, 50.83482394899641, 53.2813333102635, 55.98011786597115, 57.71700423104422, 57.00931283405849, 53.86163296018328, 53.48598207746233, 51.77639518465315, 48.272092069898335, 45.61196034295218, 47.197928360530305, 49.93462576184954, 50.22872216360909, 54.38112892423357, 52.60419314248221, 53.4016900062561, 51.513777596609934, 45.71554408754621, 43.11866181237357, 42.09250668116978, 47.036285468510215, 50.58807952063424, 50.47388935089111, 48.48776068006243, 47.87240389415196, 51.516932078770225, 49.872272627694265, 51.18471091134207, 51.03629044124058, 51.18855673926217, 45.670551027570454, 42.143068722316194, 40.81503868103027, 45.95895685468401, 38.40908595493862, 35.60073872974941, 36.681277411324636, 36.211940492902485, 37.24426909855434, 37.11238881519863, 35.04394136156355, 36.55713742119925, 38.74833175114223, 41.98077964782715, 43.96032837459019, 43.35849625723702, 46.09730243682861, 42.85925429207938, 44.12114790507725, 44.18159375871931, 44.58721917016165, 46.630097252982004, 47.996245111737935, 49.128384590148926, 47.97814505440848, 49.16354942321777, 49.15808466502598, 51.44635227748326, 50.84034081867763, 46.29201528004238, 41.195838178907124, 44.195722920554026, 40.17574882507324, 44.64135258538382, 50.900533063071116, 48.81284952163696, 48.85850266047886, 47.256213324410574, 49.689218861716135, 47.1289918082101, 46.37312855039324, 44.52038097381592, 43.50899076461792, 44.74119472503662, 44.85775770459856, 44.38148648398263, 41.752239499773296, 40.43150506700788, 39.637402398245676, 40.684558459690635, 36.590509619031636, 37.19866459710257, 34.63586323601859, 36.33872774669102, 36.482076031821116, 36.82906559535435, 36.17312438147408, 38.91763155800955, 44.21096726826259, 38.693701539720806, 38.61964763913836, 39.955199105399, 46.20382874352591, 51.11306456157139, 53.19400487627302, 51.108926909310476, 47.05756780079433, 53.66034712110247, 52.29120111465454, 50.19769845690046, 48.42023808615548, 47.4710898399353, 48.832179410117014, 49.68443502698626, 54.511824539729524, 54.97476216724941, 51.16374124799456, 53.76486192430769, 55.77124111992972, 56.52782004220145, 55.33264650617327, 53.752733843667166, 53.531200953892295, 52.68363537107195, 46.944669995989116, 49.710758277348106, 45.90333652496338, 45.343304770333425, 46.030193260737825, 51.05146530696324, 51.03996951239449, 54.87184544972011, 56.85111624853951, 59.38434260232108, 57.20474134172712, 64.06731033325195, 59.872356278555735, 66.23490510668073, 18.244927270071848, 0.24086918362549373, 0.0869977567344904, 0.6811762026378086, 18.771161249705724, 74.30316025870187, 57.39957925251552, 71.03619371141706, 48.761092390332905, 43.30389731270926, 49.873092515128, 30.147587503705704, 31.36885847364153, 66.29352705819267, 63.62746156964983, 9.920126387051173, 0.7478124126791954, 0.13925728893705777, 0.3130797216934817, 0.03647692980510848, 0.18468125936176094, 0.2001620222415243, 0.20683598411934717, 0.2589939667710236, 0.18396841761256966, 0.17267184092530183, 0.3123728239110538, 50.89526285443987, 68.13567515781948, 48.26105833053589, 35.36510099683489, 56.785879611968994, 96.55169514247349, 55.55487421580723, 63.15143353598458, 66.68531513214111, 63.08154855455671, 65.37268229893276, 4.034075464521136, 0.23085853936416761, 2.884332073586328, 5.4272409592356, 2.665691371474947, 3.4977559575012753, 15.511891569410052, 55.14554194041661, 58.438011850629536, 58.6137387411935, 53.785421643938335, 55.3938809803554, 56.82774945667812, 58.713959557669504, 60.5657309123448, 57.48940903799874, 57.56728097370693, 54.95712069102696, 50.53754527228219, 48.96271521704537, 50.39068814686367, 52.56704459871565, 53.95237990788051, 56.861298833574565, 57.23264530726841, 56.18021208899361, 55.189034189496724, 49.59215600149972, 44.176924569266184, 45.151409421648296, 48.68113252094814, 54.90331384113857, 53.599039690835134, 49.547204630715505, 48.025177410670686, 54.38528394699097, 51.743790762765066, 54.105799606868196, 52.224265643528526, 52.51463433674404, 49.76058380944388, 44.83862236567906, 44.574066230228965, 50.292586530957905, 40.23858485903059, 39.06084435326712, 39.87140383039202, 37.03588220051357, 38.645679065159385, 38.47169269834246, 37.316603319985525, 39.087730407714844, 40.864381313323975, 43.33223901476179, 46.59031534194946, 44.774566922869, 47.59446900231497, 43.00002479553223, 46.351814951215474, 45.89410236903599, 46.98141554423741, 49.089631012507844, 48.59043768474034, 50.49256610870361, 51.69393743787493, 52.27068655831473, 50.40491458347866, 53.17032541547503, 53.51758943285261, 48.94298580714634, 43.54839052472796, 46.786303179604666, 41.75260080610003, 46.827610220227925, 51.959268297467915, 52.13722208568028, 51.196526323046, 50.58408778054373, 52.87849760055542, 51.73237139838082, 49.178435938698904, 48.05203914642334, 45.78204877035958, 47.403535979134695, 46.8109449659075, 47.554047857012065, 43.84753131866455, 43.08092614582607, 43.42532403128487, 42.39962748118809, 39.76714611053467, 40.549148491450715, 36.41193049294608, 37.30541672025408, 39.38731241226196, 39.60620151247297, 38.57895203999111, 40.922461305345806, 46.5732992036002, 43.14541932514736, 40.35152782712664, 42.41563960484096, 48.14500256947109, 52.9456067766462, 54.96632705415998, 52.11069386345999, 47.866098403930664, 55.44385589872088, 51.81045178004673, 51.58439908708845, 50.46188286372593, 49.119713238307405, 51.55672093800136, 51.38082034247262, 55.47725241524832, 58.78267724173409, 51.87177310671125, 55.65570647375924, 57.631343364715576, 59.79953220912388, 59.06980460030692, 56.30889620099749, 56.34646511077881, 55.64773341587612, 50.654827390398296, 52.222208976745605, 48.72939818246024, 47.33207723072597, 49.327113492148264, 54.34958062853132, 54.932593550000874, 59.3359067099435, 60.50771345411028, 62.65388693128313, 61.18775449480329, 67.85298769814628, 63.979971476963584, 68.90832873753139, 21.9180976663317, 0.26955050602555275, 0.24971063062548637, 1.196099926318441, 22.413667508534022, 80.34864888872418, 63.91531848907471, 77.86552946908134, 56.32657936641148, 50.36713375364031, 57.24815716062273, 36.18819155011858, 43.056954860687256, 73.49944823128837, 79.29986694880894, 14.010951263563973, 1.1203025707176753, 0.24214132821985654, 0.513226789023195, 0.16115338328693593], [0.07289076942418303, 0.019355335239587084, 0.15418598215494836, 0.028137960038813095, 0.047283583852861605, 0.1027110196383936, 0.24580634012818336, 27.773879630225046, 56.63994312286377, 32.784599099840435, 25.36354259082249, 64.30904511043003, 89.14481816973004, 42.666209016527446, 41.50677006585257, 60.43756444113595, 45.18147080285208, 64.9288661139352, 5.428353539534977, 0.28565485615815434, 0.15657985370073998, 1.8987418285437991, 1.0572744842086519, 0.2183011496173484, 5.882993280887604, 43.7029948915754, 50.934686933244976, 49.922598430088584, 55.517840317317415, 57.031748567308696, 54.98943328857422, 54.158751828329905, 52.94958462033953, 52.27206924983433, 49.936800548008506, 45.737205096653526, 43.72626093455723, 47.0480626651219, 46.90876865386963, 49.10878719602312, 49.10478155953543, 50.56215926579067, 50.00076566423689, 49.60321058545794, 47.88652958188738, 44.79089171545846, 41.15440607070923, 44.75667878559658, 45.66481876373291, 49.6015499659947, 50.80533232007708, 46.3252763066973, 50.32709475925991, 50.719706194741384, 50.53470345905849, 50.35995626449585, 51.00109086717878, 47.032015800476074, 40.848501205444336, 40.24428933007376, 42.2020901952471, 43.25249801363264, 35.14247376578194, 35.72588620867048, 35.52520833696638, 34.465448243277415, 34.80572237287249, 35.36751202174595, 35.679618154253276, 34.3039026260376, 36.28143637520926, 39.28926290784563, 40.96244818823678, 41.2074590410505, 42.30744225638253, 41.36430767604283, 42.85193089076451, 43.6949280330113, 43.26524795804705, 47.086013725825715, 48.0602901322501, 46.67576081412179, 47.61540045057024, 46.480057852608816, 48.38846744809832, 45.2691535949707, 46.776082379477366, 46.06146362849644, 41.253456115722656, 42.81680427278791, 39.947153091430664, 42.583852018628804, 49.02596466881888, 46.779723235539024, 45.51630449295044, 44.966451849256245, 42.830318519047324, 43.19001286370413, 43.777330194200786, 42.25570249557495, 41.98782164709908, 41.504862785339355, 42.277266229902, 40.951240743909565, 38.89564398356846, 37.51093748637608, 36.85335997172764, 38.683522428785054, 36.10862077985491, 34.367297989981516, 33.22997862952096, 34.081897258758545, 32.96237570898873, 35.03147629329136, 33.426803725106375, 35.33384452547346, 42.740196909223286, 42.38604375294277, 37.0938857623509, 41.624861649104524, 40.53629084995815, 47.67624929973057, 51.37118319102696, 50.25353765487671, 48.680295263017925, 46.28972584860665, 49.12280518668038, 52.03101887021746, 51.91490404946463, 50.63428156716483, 47.12852280480521, 46.08095332554409, 44.24432904379708, 49.74991832460676, 49.58662176132202, 53.00347484861101, 51.338818481990266, 52.24737535204206, 55.459888866969514, 53.45046288626534, 51.88567992619106, 51.46145766122, 51.74319321768624, 49.3754312651498, 45.59160906927926, 48.12127447128296, 44.76665987287249, 46.027674538748606, 44.32708556311471, 48.145950998578755, 49.58864368711199, 52.16993767874581, 54.20670829500471, 58.19910846437727, 58.120583398001536, 55.315519196646555, 7.485639146396092, 0.2609215219105993, 0.15224759759647505, 0.4863382375666073, 20.47389200755528, 69.59722178322929, 51.10703699929373, 64.25484221322196, 47.37896714891706, 41.0552031653268, 35.801649366106304, 55.933617046901155, 44.477955273219514, 50.733950001852854, 57.71484334128243, 6.220402147088732, 0.5304714579667363, 0.17968285828828812, 0.09405950137547084, 0.09996779755290065, 0.14319857316357748, 0.07178861820804221, 0.10128311054514987, 0.03191682842693158, 0.03541385202801653, 0.09002219765846219, 0.214619852868574, 36.22151163646153, 65.95292636326381, 38.76365947723389, 32.672701835632324, 70.49957738603864, 89.42829772404262, 49.471830572400776, 47.22155918393816, 65.97916276114327, 52.60839332853045, 70.05573340824672, 5.715380149228232, 0.1940814663789102, 0.15384134064827645, 1.835646105664117, 2.088831731251308, 0.7649451504860605, 6.97037376676287, 46.2305827822004, 51.653304372514995, 51.730026381356375, 57.492389815194265, 58.339951923915315, 55.66823754991804, 55.954885482788086, 52.901725428445, 53.43241146632603, 51.293405055999756, 47.8861265863691, 46.697890826633994, 48.856234073638916, 49.15642751966204, 50.64257771628243, 50.422646386282786, 53.49062694822039, 53.72554554258074, 52.049605301448274, 50.00431619371687, 48.75991814477103, 44.3331617627825, 46.2495687348502, 48.526729651859824, 50.97928047180176, 53.7920571735927, 47.59108870370047, 51.919462067740305, 51.112407956804546, 53.06393459865025, 51.86848313467843, 52.17030593327114, 48.612984589168, 42.30660152435303, 40.0478880746024, 43.878318786621094, 43.47255441120693, 35.87727008547102, 37.28757374627249, 37.78425530024937, 35.50477368491036, 36.03710991995675, 36.29106657845633, 36.003612654549734, 35.840392521449495, 38.4695839200701, 39.88514041900635, 42.15535313742501, 43.19403239658901, 43.43988050733294, 42.46713270459856, 43.79113279070173, 46.22867202758789, 44.2025008882795, 48.04672724860055, 49.165651253291536, 48.90334286008562, 48.7287381035941, 48.90740408216204, 49.866450037275044, 48.919382776532856, 47.863207953316824, 48.974930150168284, 43.050916876111714, 44.92603070395333, 42.59930828639439, 44.976519789014546, 50.34329448427473, 49.428247996738975, 47.05373239517212, 47.286500522068565, 48.144929613385884, 46.51189797265189, 45.350551741463796, 46.35846437726702, 44.35784523827689, 44.16984782900129, 46.731815406254356, 42.922965799059185, 40.789959158216206, 39.889469146728516, 39.368003368377686, 40.52931138447353, 38.19825676509312, 35.295851775578086, 35.15228809629168, 35.803125858306885, 35.200425216129844, 36.86293111528669, 35.52186277934483, 37.60624245234898, 45.89391129357474, 42.756667613983154, 38.91358075823103, 42.93635497774397, 40.84324141911098, 49.28995452608381, 53.617855412619456, 52.05103315625872, 49.45475537436349, 45.892768314906526, 49.30144337245396, 52.30001490456717, 52.51429040091378, 51.81338391985212, 49.26871040889195, 48.2578204699925, 46.81529801232474, 51.64079066685268, 51.556206771305625, 53.06162779671805, 51.48864943640572, 54.486418451581685, 57.464100224631174, 55.56644296646118, 52.74943481172834, 55.32920019967215, 55.89435625076294, 52.76292126519339, 49.830347197396414, 49.82242972510201, 47.143836634499685, 47.94120148250035, 46.06545884268624, 51.59587403706142, 51.5590729032244, 56.72422129767281, 56.95307411466326, 62.05324990408761, 61.814044271196636, 58.59415871756417, 8.732859901019506, 0.33066962925451143, 0.24394965118595532, 0.7312834081905228, 22.76942048754011, 75.59191213335309, 58.20643186569214, 68.73836190359933, 53.113822664533345, 45.12981442042759, 45.88077572413853, 41.31899152483259, 45.685618196214946, 58.04330553327288, 69.10977091108049, 9.280143448284694, 0.6713136147175516, 0.12924863956868649, 0.24616639795047895, 0.05058892470385347, 0.2006698785615819, 0.19452342337795667, 0.2707496945347105, 0.1296892123562949, 0.12203733223889555, 0.22693035086350782, 0.4181638429207461, 49.61835071018764, 75.04203864506313, 48.492422921316965, 37.9211938721793, 74.50841699327741, 92.81439113616943, 55.12803942816598, 52.966552121298655, 71.35441425868443, 56.937360763549805, 76.07355431147984, 8.267686690602984, 0.3122744634747505, 0.8806408537285668, 4.5447645868573865, 4.900521908487592, 1.8302675485610962, 8.660598635673523, 51.26033510480608, 54.98144980839321, 52.81767307009016, 58.453297887529644, 61.00913715362549, 58.736923354012625, 59.2455940246582, 57.72541502543858, 56.88335241590227, 54.1676663671221, 49.89133153642927, 49.43409143175398, 52.775462763650076, 51.21661009107317, 52.91097000667027, 52.98453753335135, 56.038114479609895, 53.81798437663487, 52.73169953482491, 52.8337025642395, 50.85019336427961, 45.301216057368684, 49.48280872617449, 50.115886892591206, 54.32895837511335, 55.026199681418284, 47.52059575489589, 54.512776442936485, 54.27105903625488, 54.923057147434776, 55.595361368996755, 55.31556783403669, 51.50597824369158, 46.53857210704258, 42.75845330102103, 47.21404470716204, 47.4574088369097, 39.22583280290876, 38.43736512320382, 40.197402885981965, 36.836486271449495, 39.029952662331716, 38.85732814243862, 38.67528533935547, 37.380564962114605, 39.784259523664204, 42.17640617915562, 43.97651767730713, 44.47333819525582, 45.884347098214285, 44.78257819584438, 47.38280602863857, 48.060842514038086, 46.36003814424787, 51.48569645200457, 51.554285594395225, 50.918855462755474, 53.34517683301653, 50.33973353249686, 53.616396290915354, 50.19433205468314, 50.97036593300955, 52.95182541438511, 42.792409147535054, 47.95582396643502, 46.32803126743862, 47.01534359795706, 54.10379505157471, 51.26196098327637, 51.960209778376985, 50.98959159851074, 50.985811778477256, 48.46339334760393, 49.25123221533639, 48.13101584570748, 46.248328481401714, 47.85377924782889, 48.57910169873919, 45.7848801612854, 44.055730615343364, 41.69713681084769, 41.92171648570469, 44.20967490332467, 40.25712612697056, 38.128733089991975, 37.77876969746181, 38.178100040980745, 36.536980697086875, 38.501882621220176, 36.25770827702114, 39.556167534419465, 48.53055463518415, 45.34859929765974, 41.426382882254465, 46.73065505708967, 43.06949635914394, 51.44538300377982, 55.46138620376587, 52.63933365685599, 49.92150408881051, 48.78206900187901, 52.31560666220528, 52.13740273884365, 52.71086188725063, 54.045259952545166, 51.96624428885323, 49.8688645362854, 47.924049854278564, 51.99857425689697, 52.6961212839399, 54.452983719961985, 52.793177195957725, 54.57580355235508, 59.86936855316162, 58.46067687443325, 55.81624460220337, 57.02987602778843, 57.97914239338466, 55.36380222865513, 52.78946338381086, 52.139490672520225, 50.138711724962505, 50.87590517316546, 48.594853264944895, 52.84679991858346, 55.282153947012766, 57.922521523066926, 59.81807695116316, 65.20204843793596, 66.78035259246826, 63.039831570216585, 11.577657376016889, 0.33473665959068705, 0.6488894437040601, 1.3267215000731605, 27.036144222532, 83.58999047960553, 66.4004876273019, 76.82402924128941, 60.47765554700579, 55.16315214974539, 55.13293095997402, 61.32102789197649, 60.402844292776926, 62.78176852634975, 81.48558262416294, 11.856818624905177, 0.7340519396322114, 0.3591544207717691, 0.34875641443899696, 0.19325068167277745], [0.07523795776069164, 0.051044523649449856, 0.08614330472690718, 0.06859522206442696, 0.0350057166069746, 0.06656932684459857, 0.5160563343337604, 34.45818042755127, 50.19511720112392, 42.16938155038016, 24.674390724727086, 46.996197836739675, 79.80318055834088, 34.4729905128479, 46.42889826638358, 62.61405290876116, 46.78767544882638, 62.616943359375, 16.577241488865443, 0.3635162338614464, 0.06205836497247219, 0.5779258087277412, 1.0342022308281489, 0.7818295444761003, 6.429147745881762, 48.31097766331264, 56.65938418252127, 57.500835350581575, 55.8169845853533, 52.842408657073975, 53.72745977129255, 51.07564156396048, 50.726147174835205, 47.99145432880947, 46.872603280203684, 45.260871342250276, 49.06703894478934, 45.986683641161235, 48.13963508605957, 51.24392345973423, 56.55738115310669, 51.63421072278704, 48.75867441722325, 49.507408823285786, 47.80407183510916, 42.411053793770925, 44.205582414354595, 45.89617640631539, 48.60473360334124, 49.02481821605137, 49.30271141869681, 49.25672476632254, 50.89399133409773, 49.57004335948399, 50.54281200681414, 48.954443386622835, 48.819481577192036, 43.72173418317522, 41.596248967306956, 39.10260302679879, 41.527809211185996, 43.69617523465838, 43.15126276016235, 39.199096134730745, 33.03781577519008, 34.77632801873343, 35.641750471932546, 34.589487484523225, 35.39224760872977, 36.259824003492085, 35.796514647347585, 36.86447014127459, 39.55762318202427, 43.647662912096294, 40.19546433857509, 43.511002268110005, 42.21145984104702, 43.74954434803554, 41.59133311680385, 46.005009514944895, 47.11815956660679, 47.28846338817051, 44.45440782819475, 46.45285218102591, 44.79037754876273, 47.6949851172311, 45.017191069466726, 46.46576540810721, 41.31965855189732, 42.43942676271711, 39.046638761247905, 44.09429659162249, 46.74453755787441, 44.61862850189209, 46.43175745010376, 44.35549674715315, 44.45884772709438, 43.9856858253479, 45.966172558920725, 44.065482412065776, 38.79066365105765, 43.7189826965332, 42.86269017628261, 39.76320995603289, 37.998457840510774, 39.19425324031285, 37.80495745795113, 36.83850472314017, 34.56246594020298, 30.986519949776785, 33.76570211138044, 34.23153018951416, 34.84469134466988, 34.029657227652415, 34.433111327035085, 34.299021516527446, 41.39715528488159, 46.05228853225708, 38.12138884408133, 39.959493092128206, 41.288666112082346, 43.46254900523594, 49.551971094948904, 51.59107978003365, 49.89155387878418, 49.508228710719514, 48.183495589665, 48.997355461120605, 49.838049275534495, 51.11539568219866, 52.40796906607491, 49.24359614508492, 47.13751029968262, 47.02752031598772, 48.65951667513166, 49.836023875645225, 52.57458339418684, 52.452416692461284, 51.673620905194966, 56.82754101072039, 53.95045525687081, 53.43623644965035, 49.652952739170615, 56.980502128601074, 52.506939206804546, 52.933117389678955, 48.79849454334804, 51.156664507729666, 51.415050642830984, 50.45561211449759, 54.58383566992623, 55.2946572303772, 57.99357380185808, 57.56920562471662, 59.256905691964285, 49.83980022157942, 4.68329690183912, 0.20370723200695856, 0.11472127267292567, 0.7135822751692363, 31.221355165754044, 65.00994464329311, 55.39966882978167, 63.592477389744346, 60.05882508414132, 41.00472102846418, 43.897280420575825, 53.76310750416347, 33.729988370622905, 48.33105795724051, 57.46275574820382, 4.530615883214133, 0.4300392371203218, 0.09566942748746701, 0.13393229538840906, 0.036045174580067396, 0.09527974482625723, 0.02938294118004186, 0.06544283657733883, 0.042969037512583394, 0.0061969699953416625, 0.06391599707837615, 0.42948647535273005, 44.385002272469656, 59.16269506726946, 46.64449044636318, 27.34896080834525, 70.17445727757045, 91.49767971038818, 40.3817629132952, 52.75106763839722, 67.52657522474016, 52.52090508597237, 69.32250390733991, 17.802896772112163, 0.4308180867561272, 0.05180890013330749, 1.0678455169711794, 0.7505211244736398, 0.7083391536559377, 7.523829919951303, 47.112288338797434, 56.965591294424875, 57.9093268939427, 58.16107749938965, 55.58884048461914, 54.75683886664254, 52.67561714989798, 52.48790461676461, 51.5464653968811, 49.587462493351524, 49.19049106325422, 49.779309204646516, 48.97151163646153, 51.35897520610264, 53.88778597967965, 56.85856819152832, 51.93538039071219, 51.21442835671561, 50.885247026171, 49.70386219024658, 45.1337297303336, 45.71579769679478, 49.1290967805045, 49.97311530794416, 50.666350977761404, 50.22250005177089, 51.380434717450825, 52.37653888974871, 51.59666265760149, 51.38016373770577, 50.153445380074636, 50.67321579796927, 46.29428039278303, 42.86378104346139, 42.21814053399222, 43.154358182634624, 45.93563175201416, 45.232418469020296, 41.223217555454795, 35.48491225923811, 34.854599475860596, 36.749258586338584, 36.30383389336722, 36.702775137765066, 35.79624366760254, 37.600072452000205, 38.82628359113421, 42.04093367712838, 45.562100069863455, 41.68809025628226, 44.73158189228603, 43.82004771913801, 45.86733095986502, 43.83817556926182, 46.87579945155552, 47.932057653154644, 48.695327690669465, 47.65800680433001, 46.94342279434204, 46.990194593157085, 49.70434161594936, 47.16162402289254, 47.526703221457346, 42.07169335229056, 41.90547507149832, 42.83839579990932, 47.223157269614084, 50.47191258839199, 47.618961402348106, 48.96960435594831, 46.95693704060146, 47.60038191931588, 46.48372302736555, 48.02108492170061, 44.587111473083496, 40.642480169023784, 45.93316861561367, 45.02991669518607, 42.54159654889788, 40.9450672694615, 40.567988531930105, 39.60731322424752, 38.44697448185512, 34.97607830592564, 32.448615482875276, 36.08973557608468, 35.78437614440918, 35.4454916545323, 35.34721980776106, 36.08818960189819, 36.028268337249756, 41.46657473700387, 47.892261845724924, 39.610353061131065, 41.94137988771711, 42.1974001611982, 44.974397114345, 50.81157527651106, 51.40600061416626, 51.0623322895595, 50.71728822163173, 48.250601291656494, 50.63756806509835, 50.76242371967861, 52.31988327843802, 52.8562251499721, 50.85933371952602, 49.89593471799578, 49.91355882372175, 51.13660158429827, 55.30392612729754, 53.23441559927804, 52.652434485299246, 52.468717166355674, 59.63993903568813, 56.432556765420095, 55.63633142198835, 52.31184768676758, 59.39058903285435, 56.05443927219936, 54.68064144679478, 52.78406810760498, 53.71610294069563, 55.46427665437971, 52.51606913975307, 56.22314848218645, 58.06838853018624, 60.56504304068429, 62.38364369528634, 63.578525406973704, 52.79618924004691, 5.437239851270403, 0.5188936963677406, 0.16836815114532197, 1.1557293725865228, 35.12241084235055, 71.33784280504499, 61.91656494140625, 68.46808392660958, 65.24824006216866, 47.44148356573922, 56.40214797428676, 59.460995129176546, 37.57427379063198, 55.527918679373606, 67.48708861214774, 6.300723322800227, 0.619118366922651, 0.07984147180936166, 0.18619645519980363, 0.08943453883486134, 0.17270892964942114, 0.105165647209755, 0.12778586734618458, 0.19157282742006437, 0.1876010498298066, 0.16875392544482434, 0.5327676747526441, 57.61183977127075, 68.85915633610317, 57.038300718579976, 36.32405315126692, 58.19710390908377, 85.02807998657227, 50.217962878090994, 59.90943186623709, 74.0533447265625, 59.23351110730852, 73.28780610220772, 20.86973782948085, 0.614028811454773, 0.13169454117970808, 1.6005444696971347, 6.217959855284009, 1.996602211679731, 8.773128185953412, 51.261683055332725, 58.9214049748012, 60.16258948189871, 60.48158127920968, 57.7888103893825, 57.726662227085654, 55.0443240574428, 55.488571030753, 53.9498542376927, 51.369654587336946, 50.56156866891043, 53.54303026199341, 51.907653604234966, 54.79342113222395, 55.371031829289024, 59.517497880118235, 54.863938399723594, 51.82258333478655, 54.557533264160156, 55.30027832303728, 47.419631481170654, 50.07921430042812, 52.87483589989798, 53.40300668988909, 52.35445751462664, 53.14415155138288, 54.0060338973999, 55.66954033715384, 52.66634477887835, 55.12676443372454, 51.4005115372794, 54.21235370635986, 48.489386558532715, 46.00192451477051, 43.394626889910015, 45.770031860896516, 48.02386767523629, 47.16084235055106, 44.23921864373343, 37.64255721228463, 37.12726490838187, 40.06242718015398, 38.06602212360927, 38.693889141082764, 39.59141574587141, 38.579223019736155, 39.39592470441546, 43.949298109327046, 48.13242285592215, 42.14154011862618, 47.17597900118147, 46.31647293908255, 47.86868660790579, 45.10388374328613, 51.52936240604946, 52.10996777670724, 50.60483857563564, 49.38138239724295, 49.788011823381694, 50.01327589579991, 52.59987136295864, 48.848514625004356, 51.85742507662092, 43.75479023797171, 46.28491422108242, 44.84084926332746, 50.64634016581944, 52.93299927030291, 50.29977444240025, 50.778908320835654, 50.733769348689485, 49.37231499808175, 48.96888869149344, 51.435127462659565, 47.77272503716605, 44.308141299656455, 49.35120289666312, 48.91360534940447, 44.965326241084504, 43.11999586650303, 43.073588848114014, 42.332434926714214, 42.58380685533796, 37.72457027435303, 34.329531056540354, 37.57662922995431, 37.54634550639561, 39.5120256287711, 37.261653491428916, 38.52616657529558, 38.620460578373496, 43.129174436841694, 49.41783264705113, 40.97529540743147, 43.00261994770595, 44.13603094645909, 46.324359144483296, 53.62864596503121, 55.646444525037495, 52.69576345171247, 52.07337508882795, 51.50549534388951, 54.23874643870762, 51.21275731495449, 52.88280200958252, 55.48068829945156, 54.14798559461321, 51.53303105490548, 51.26403154645647, 52.11943817138672, 55.40057904379708, 55.18452480861119, 53.787290709359304, 51.930214405059814, 62.140602656773154, 60.065710748944966, 59.11307103293282, 54.69765758514404, 61.57101712908064, 58.809504236493794, 57.654057025909424, 54.875159740448, 55.62785461970738, 56.35871478489467, 56.24327393940517, 58.03764622552054, 62.11479704720633, 62.36654417855399, 66.40964535304478, 67.11468601226807, 59.06380830492292, 6.902333966323307, 0.3252053867493357, 0.743199351642813, 1.8976034096309116, 39.654439381190706, 79.38422502790178, 66.69418798174176, 76.20864118848527, 72.36052731105259, 58.02511167526245, 62.71081352233887, 66.55193056379045, 47.46908181054251, 62.24996035439627, 80.51022924695695, 10.320370418684822, 0.8529028307114328, 0.45332417051706997, 0.27954679248588427, 0.1320323294826916], [0.1261655121509518, 0.04626380678798471, 0.05236721571002688, 0.021870364301971028, 0.13571302912064961, 0.08280075980084282, 0.1577583197504282, 35.46880633490426, 60.286211831229075, 42.309676102229524, 31.15277644566127, 21.852850607463292, 39.865810530526296, 38.7282167162214, 45.9953167779105, 59.2744151524135, 48.984560353415354, 59.715660503932405, 30.299152033669607, 0.10084410517343453, 0.3644114929650511, 1.314265985574041, 0.4988617141331945, 0.8448019368307931, 8.250905053956167, 52.05667509351458, 55.57102182933262, 56.13656350544521, 53.13955879211426, 51.67564630508423, 50.13334076745169, 49.99702058519636, 47.955959456307546, 50.30941506794521, 50.90562956673758, 50.77652161461966, 49.97190979548863, 51.50547797339303, 51.36859498705183, 50.92162431989397, 50.954565729413716, 50.62762519291469, 49.79875373840332, 46.75710684912545, 41.3448874609811, 43.22029658726284, 44.10621970040457, 56.86380018506731, 53.7377153124128, 46.20203958238874, 51.067077909197124, 47.69671869277954, 49.44772032329014, 46.602193287440706, 46.784434114183696, 46.09209476198469, 42.07676553726196, 41.36395679201399, 41.21873596736363, 38.37777042388916, 45.7287734576634, 47.99749231338501, 46.554386207035606, 42.03208862032209, 33.21571397781372, 33.870321137564524, 34.47227832249233, 34.402935300554546, 35.54383298328945, 34.50294072287423, 35.10649599347796, 36.404151984623496, 39.67299107142857, 39.94459615434919, 41.33577837262835, 40.80900764465332, 42.045672348567415, 41.38542325156075, 43.038430963243755, 44.58077124186924, 46.26303781781878, 45.35880272729056, 46.023384026118684, 46.24395111628941, 45.702606541769846, 46.92338766370501, 45.976615701402935, 47.093302386147634, 43.026278563908164, 39.156573159354075, 38.93284463882446, 40.92937476294381, 47.58600262233189, 47.29582500457764, 45.596479756491526, 44.42953675133841, 44.78401299885341, 44.23744337899344, 45.80093744822911, 42.46421793528965, 40.25526748384748, 42.936094420296804, 41.166982310158865, 40.69400453567505, 38.3374673979623, 37.89311620167324, 37.660118784223286, 34.599041257585796, 33.93580790928432, 32.126146112169536, 34.21018532344273, 32.300625801086426, 33.6441433770316, 33.67407274246216, 32.86779682976859, 34.787514618464876, 38.62009927204677, 49.2191732270377, 43.73149292809622, 39.36455358777727, 40.667914049965994, 40.368168762751985, 46.26368400028774, 50.310592787606375, 49.70978552954537, 50.61187015260969, 51.86063861846924, 51.654291016714915, 50.70026513508388, 47.11309780393328, 51.13405506951468, 51.3345696585519, 49.43764543533325, 46.685946873256135, 47.91777563095093, 49.86644656317574, 52.678253991263254, 52.911842005593435, 50.23923478807722, 48.804893834250315, 54.15281111853463, 53.44134684971401, 64.87205764225551, 64.02302251543317, 52.474713461739675, 56.23811837605068, 54.826442446027485, 55.83921882084438, 54.45073250361851, 58.80097879682268, 54.337278842926025, 59.31329032352993, 64.33478123801095, 55.17103140694754, 64.58263737814767, 30.454496383666992, 0.42176507253732, 0.15024704565959318, 0.10563355138791458, 1.468424256358828, 38.63451678412301, 63.26191684177944, 57.06237622669765, 62.807761737278526, 59.311365672520225, 45.926449707576204, 37.590668065207346, 38.177165508270264, 42.25209985460554, 49.17980473382132, 68.5305621283395, 6.3471238272530695, 0.5582119237099374, 0.04493580519088677, 0.1380989753774234, 0.06914147668118988, 0.12108936453504221, 0.06509712298533746, 0.05930784185017858, 0.10051139231239047, 0.09497751175825085, 0.1252032137875046, 0.26877545618585175, 45.762510435921804, 65.59437152317592, 50.81841925212315, 29.71834863935198, 35.518239293779644, 55.52378102711269, 40.856345721653526, 55.8030812399728, 63.086808340890066, 57.15232413155692, 65.42311232430595, 33.53883300508772, 0.2600212145064558, 0.30464778414794375, 1.1270720703261239, 0.39460244721599985, 1.2199132485049111, 9.691352605819702, 54.717974117824006, 58.30939374651228, 55.33140972682408, 56.11960990088326, 52.4212783404759, 54.52303545815604, 51.88625315257481, 51.445184980119976, 51.374653816223145, 52.67532532555716, 51.435853549412315, 51.646839073726106, 54.20240388597761, 52.47231633322579, 53.61953340257917, 51.99031979697091, 52.113622529166086, 51.81620141438076, 47.89094168799264, 45.54427794047764, 45.44266053608486, 48.27523612976074, 53.094242640904014, 54.05272926603045, 48.610750743321006, 52.340005261557444, 49.792684486934114, 50.34463201250349, 48.66016633169991, 48.99785573141915, 47.29310131072998, 43.545051915305, 43.236468519483296, 43.221950258527485, 41.53118256160191, 46.24783168520246, 49.44363478251866, 48.190617493220735, 43.651727608272004, 35.52429812295096, 36.110382148197715, 36.77984455653599, 35.4872225352696, 37.66709130150931, 36.19734927586147, 36.06780358723232, 39.68022414616176, 40.57186910084316, 42.390858854566304, 44.10315554482596, 41.48511253084455, 43.757642473493306, 44.176153319222585, 43.39309481212071, 45.41400269099644, 48.04687663487026, 48.26020022800991, 48.53099584579468, 49.998979977199006, 47.70560891287667, 47.71413435254778, 48.26967062268938, 48.93238633019583, 43.84681218011038, 41.19910035814558, 42.71900142942156, 46.36376585279192, 49.86659942354475, 47.90037734167916, 47.4347368649074, 47.072259766714915, 47.17960248674665, 46.365707874298096, 49.31041349683489, 45.40442112513951, 41.58515269415719, 43.12985188620431, 43.83508709498814, 43.7005421774728, 41.263624804360525, 39.8534323147365, 41.012742723737446, 37.15143769127982, 35.345475809914724, 33.967554228646414, 36.68766280582973, 34.92072548185076, 35.06151335580008, 34.30756780079433, 34.682513441358296, 36.08306877953665, 40.04812431335449, 49.24655955178397, 46.57101672036307, 40.760665552956716, 42.29758971078055, 43.26031821114676, 47.2116163117545, 51.48416437421526, 50.67480346134731, 51.87831136158535, 50.7680378641401, 51.153798375810894, 51.16056939533779, 48.95938702992031, 51.62927055358887, 53.91821214130947, 50.888088839394705, 47.47863210950579, 48.44559553691319, 52.23557036263602, 54.498320715767996, 55.15633249282837, 50.57836593900408, 49.883403641836985, 56.077166829790386, 56.15171752657209, 63.67702307019915, 66.89690167563302, 57.086920738220215, 59.36231681278774, 60.327553612845286, 58.63388156890869, 57.57138041087559, 61.404253414699006, 59.61599554334368, 58.82201099395752, 68.24790940965924, 58.5502530506679, 67.16139875139508, 32.794239725385395, 0.2606892186616148, 0.42878272597278866, 0.16353040002286434, 1.9620683618954249, 44.02379322052002, 68.96617943899972, 62.788501330784385, 71.84296294621059, 64.27191393715995, 54.10578918457031, 42.93849154881069, 45.55804579598563, 46.43712840761457, 54.20288678577968, 78.9906234741211, 8.939171024731227, 0.6404869545783315, 0.12725694929914816, 0.11903227706040655, 0.05390757162656103, 0.1802948425923075, 0.15397042515022413, 0.13010888626532896, 0.317998964871679, 0.199920192360878, 0.1959520381476198, 0.22993312616433415, 52.82174818856375, 78.3596853528704, 57.961313315800254, 45.362151759011404, 31.581685270581925, 48.457855633326936, 54.41543912887573, 58.21132339750017, 70.51819161006382, 62.42350551060268, 72.37661239079067, 37.30811262130737, 0.5631153434514999, 0.3381378028009619, 3.8131331716265, 4.313167665685926, 2.610123153243746, 11.15658698763166, 59.464441435677664, 60.36068262372698, 59.132387025015696, 58.02229070663452, 55.04308727809361, 56.282611165727886, 54.554667132241384, 53.253227846963064, 55.78384862627302, 56.76862376076834, 55.30521501813616, 53.90636893681118, 55.93917907987322, 55.8129164150783, 54.35378081457955, 54.86013078689575, 53.713083948407856, 57.00643975394112, 51.65446472167969, 47.82882479258946, 47.46021590914045, 50.28209475108555, 53.95406832013811, 56.279147488730295, 50.93946034567696, 54.132869788578574, 51.0094564982823, 52.87164320264544, 51.371464593069895, 52.068796225956504, 52.09429611478533, 44.8091515813555, 44.865418093545095, 46.07923364639282, 43.955787726810996, 47.912404673440115, 53.435166427067344, 49.66463960920061, 46.69406236921038, 35.45766837256295, 36.5544102532523, 38.19332006999424, 37.78621121815273, 39.6552905355181, 37.81547008241926, 39.053156171526226, 40.893956320626394, 43.03805923461914, 43.103629384722026, 46.1578803062439, 44.1489372253418, 46.97351196834019, 47.025755473545615, 45.58257988521031, 48.643653937748496, 51.47755316325596, 50.9510429927281, 49.86689472198486, 53.134642941611155, 49.32329545702253, 50.798898288181846, 49.48815189089094, 53.02970082419259, 47.55751500810896, 44.167270047324045, 44.276971680777415, 49.32766587393624, 52.257940087999614, 51.48545673915318, 52.392835889543804, 49.79442501068115, 49.851528780800955, 50.352473054613384, 50.320566926683696, 46.7069547516959, 44.53777926308768, 46.90739985874721, 45.527421610695974, 47.07474027361189, 44.35924877439226, 42.93757438659668, 43.924823079790386, 38.253897939409526, 37.88650499071394, 36.06095266342163, 38.56687259674072, 36.768157686506, 38.496282373155864, 38.99850511550903, 37.11209004265921, 40.008509159088135, 43.04220036097935, 52.503843784332275, 48.47689717156546, 43.55759341376168, 43.75093746185303, 43.586556979588096, 49.35552815028599, 54.69773054122925, 52.56388316835676, 54.51441274370466, 54.38303273064749, 54.31582975387573, 54.31847006934029, 49.72365065983364, 51.74534021105085, 54.66822154181344, 54.083075523376465, 50.75100782939366, 50.27061980111258, 53.559018066951204, 57.360408782958984, 57.67415816443307, 50.265961033957346, 51.88052436283657, 58.78073869432722, 58.15008544921875, 63.039539745875764, 66.5104011808123, 58.99855777195522, 60.40281649998256, 63.4918327331543, 60.549777848379954, 60.254868507385254, 62.45118713378906, 63.3842259815761, 61.45322431836809, 70.36394854954311, 62.74328940255301, 71.74968338012695, 36.94836616516113, 0.7124893452439989, 0.421693066401141, 0.4789119160601071, 3.039608027253832, 48.802569661821636, 75.80232443128313, 69.76464557647705, 78.846205166408, 70.37681661333356, 60.46801144736153, 54.43366077968052, 52.29986204419817, 54.3467492376055, 63.33859716142927, 91.75564547947475, 13.384510363851275, 0.8809225271855081, 0.31026385564889225, 0.27969229753528324, 0.34581925347447395], [0.06612458106662546, 0.04445478832349181, 0.05714526932154383, 0.13239580712148122, 0.07448416642312493, 0.08930060959288053, 0.09269905223378114, 13.207309586661202, 64.2562665939331, 45.14904703412737, 37.16650138582502, 24.797024692807877, 25.045671190534318, 41.51401356288365, 47.24169506345476, 60.81155817849295, 51.81449910572597, 52.97209678377424, 46.657382828848704, 1.184123728956495, 0.41654341987201143, 0.39424529352358406, 0.3489878220217568, 0.6240776436669486, 9.714821015085493, 55.50558369500296, 52.54780156271798, 52.1096898487636, 53.529443059648784, 52.55518749782017, 51.90087216241019, 50.529148374285015, 52.04586369650704, 51.78401041030884, 50.34694923673357, 48.226126262119834, 52.00080810274397, 50.37331417628697, 50.28200442450387, 49.10476418903896, 49.73934664045061, 51.52738911764962, 46.455506392887656, 43.61824423926217, 43.22826964514596, 47.86752278464181, 49.468940121786936, 67.01675810132707, 49.11567980902535, 48.250910486493794, 49.97781923839024, 49.913527556828086, 51.15527139391218, 46.48136411394392, 42.88540383747646, 42.146087714603965, 41.757127557482036, 43.674778257097515, 39.018383911677766, 42.97040809903826, 45.318881852286204, 45.13333020891462, 44.98311015537807, 37.28211941037859, 34.4483973639352, 34.63165610177176, 34.89053208487374, 34.59161363329206, 34.10324559892927, 35.19471379688808, 34.53802565165928, 36.3448143686567, 36.77826731545584, 41.411326135907856, 39.68423673084804, 41.160482270377024, 39.96363074438912, 42.874707085745676, 43.871460914611816, 45.13001939228603, 44.66408014297485, 44.99176066262381, 46.47096266065325, 45.35121182032994, 46.19412211009434, 46.37137760434832, 46.165707451956614, 43.37927484512329, 44.05679716382708, 39.58673960821969, 42.042285101754324, 40.12218516213553, 46.1636438369751, 45.096355370112825, 44.01332228524344, 43.61064638410296, 45.92360094615391, 44.36588430404663, 47.45012712478638, 42.719143867492676, 39.28365223748343, 44.04022571018764, 40.0607978275844, 39.728719098227366, 39.977947507585796, 38.68016644886562, 37.59390592575073, 35.042926924569265, 31.827988488333567, 33.21633236748831, 31.995530400957378, 34.322756562914165, 32.783476965767996, 35.09784548623221, 32.220231669289724, 36.00202151707241, 37.619041034153526, 45.71666622161865, 46.52137878962925, 40.20888131005423, 40.67059258052281, 43.21443578175136, 41.15007734298706, 48.516654763902935, 48.940338543483186, 49.35160936628069, 51.445886748177664, 51.36668423243931, 52.153932503291536, 49.87367268971035, 46.09311614717756, 49.1680657523019, 54.33889429909842, 50.93927621841431, 47.11719029290335, 46.134023666381836, 49.13829966953823, 52.36000912530081, 52.977665764944895, 47.43070690972464, 48.41065999439785, 49.54845183236258, 54.269370623997276, 49.34461253029959, 58.6232647214617, 52.542541776384624, 58.89955289023263, 57.27120433534895, 60.42011751447405, 53.31707484381539, 67.84815870012555, 67.22184807913644, 60.38013063158308, 59.5563383102417, 65.49410901750836, 11.782145466123309, 0.03483466810679861, 0.5247915227498327, 0.09989195769386632, 3.67640825680324, 45.107409954071045, 61.42766189575195, 61.219535555158345, 60.4410593850272, 62.64024761744908, 37.513963426862446, 64.94435364859444, 50.06467172077724, 29.83894852229527, 58.46579074859619, 68.22833633422852, 5.4140901906149725, 0.5766647649662835, 0.15127111785113811, 0.08753238126103367, 0.05811501121414559, 0.13402978729988846, 0.09474037055458341, 0.06296141365809099, 0.12192449186529432, 0.023560433881357312, 0.14115357718297414, 0.16736537138266222, 22.353751455034526, 73.66735145023891, 48.93621826171875, 39.46127946036202, 26.539462668555124, 30.909954275403702, 46.962651933942524, 52.57684850692749, 64.90828554970878, 56.79827867235456, 59.610186849321636, 51.648503167288645, 1.2641792446374893, 0.519402489066124, 0.6564863760556493, 0.41715212006654057, 0.6078166876520429, 10.412829228809901, 58.744684491838726, 55.975816931043354, 55.256417819431846, 54.907732895442415, 53.86046566282, 54.716824190957205, 51.31215129579817, 53.306058474949424, 52.544153758457725, 52.833320413317, 52.30454513004848, 53.289226463862825, 50.65107536315918, 51.19734968457903, 49.40228952680315, 54.09817395891462, 53.068836552756174, 49.2762804712568, 45.586109570094514, 44.791464941842214, 48.58799539293562, 50.580738748822895, 63.2730131149292, 50.224275316510884, 50.87492895126343, 52.226753098624094, 51.29051807948521, 52.514689922332764, 46.9822666985648, 44.13973086220877, 43.63504498345511, 44.46421521050589, 46.3278089250837, 41.20456164223807, 44.16787454060146, 48.62950740541731, 46.78292635508946, 46.02459648677281, 40.44359145845686, 35.059012004307334, 35.64351184027535, 35.88883536202567, 36.44355174473354, 35.73294905253819, 37.068660327366416, 34.47930295126778, 37.48312732151577, 38.963107517787385, 43.295319761548726, 41.650563035692485, 41.362872873033794, 42.51359530857631, 44.0382524217878, 45.208030291966026, 47.74736063820975, 45.846486364092144, 47.64294310978481, 47.921958446502686, 48.05064255850655, 47.31110756737845, 47.64283888680594, 48.377993038722444, 46.287106377737864, 45.12841783251081, 41.59236145019531, 43.001112188611714, 44.97476536887032, 49.06741067341396, 47.11796154294695, 46.183011940547395, 46.082367283957346, 47.864684445517405, 47.45783962522234, 48.07000371388027, 45.84090001242501, 41.71650838851929, 46.22288070406233, 42.49572106770107, 42.05673040662493, 42.112732887268066, 40.48681967599051, 39.682273864746094, 37.43476785932268, 33.73678370884487, 35.85539020810808, 34.59264196668352, 34.378529753003804, 34.13781636101859, 37.92861802237374, 33.25987672805786, 36.69584083557129, 39.18435900551932, 46.64880180358887, 48.67102984019688, 41.93378550665719, 41.9971148627145, 44.1172708102635, 43.23376219613211, 50.16702216012137, 49.92984192711966, 52.100903851645334, 53.61545828410557, 50.76338257108416, 52.01181752341134, 51.22183861051287, 48.62053728103638, 51.86154883248465, 55.9582553591047, 53.478686468941824, 49.49597208840506, 48.75491544178554, 51.828676904950825, 54.46821069717407, 53.84076057161604, 48.46645055498396, 51.08444840567452, 51.50217757906233, 55.66825144631522, 52.47735377720424, 59.74439130510603, 55.390747342790874, 61.50813593183245, 59.232441084725515, 63.99238095964704, 56.106251989092144, 65.8899062020438, 68.40691893441337, 65.88740485055106, 60.667369161333355, 67.77782903398786, 11.97763911315373, 0.011282069608569145, 0.3259038435561316, 0.2616701903087752, 4.663157113960811, 50.172129086085725, 69.104462487357, 66.51046371459961, 66.90735871451241, 67.80358600616455, 45.78767333711897, 65.47436918531145, 55.75705984660557, 28.679348026003154, 62.890813555036274, 76.69774573189872, 8.703213674681527, 0.7932072739515985, 0.15282705293170043, 0.06903144544256584, 0.07600768788584641, 0.1897546521254948, 0.2634477349264281, 0.06747762739126172, 0.3077931467975889, 0.12176621678684439, 0.3200649140136582, 0.2547920708145414, 29.00910779408046, 85.66316618238176, 58.01152447291783, 52.669360297066824, 34.54219109671456, 34.798214844294954, 55.68819625037057, 58.03562082563128, 70.62672942025321, 62.01584775107247, 65.80863312312535, 53.89641564232962, 2.414310757602964, 0.5913648733070919, 2.807659787791116, 2.218993203980582, 1.5653163428817476, 11.473130413464137, 61.85444804600307, 56.808683599744526, 58.66594055720738, 57.3740758895874, 57.22977917534964, 55.80389070510864, 53.49428170067923, 55.462265150887625, 55.492260524204795, 54.465872628348215, 54.944436754499165, 57.581264223371235, 53.25716052736555, 53.70683404377529, 50.76286840438843, 55.60390417916434, 56.079491002219065, 49.579437323978965, 48.47014699663435, 46.09924445833479, 53.23780632019043, 54.016720226832796, 66.74165112631661, 54.57246841703142, 51.05998379843575, 55.20373657771519, 51.84013795852661, 55.88916594641549, 49.27594348362514, 47.87559311730521, 46.22233874457223, 45.55546106610979, 48.11379473549979, 44.17595182146345, 46.59008257729666, 50.62723956789289, 50.344972474234446, 51.256794997623985, 41.58705997467041, 37.15818439211164, 37.19849436623709, 37.84156404222761, 39.96503775460379, 38.732100759233745, 38.96639401572091, 37.35419307436262, 39.3310215813773, 41.196130003247944, 44.82048756735665, 42.779092924935476, 44.47676018306187, 44.76510695048741, 47.03228678022112, 46.83261292321341, 50.63267305919102, 48.03781965800694, 49.79129832131522, 50.030594280787874, 50.566564423697336, 52.26184497560774, 52.04901817866734, 51.356525966099326, 48.41350180762154, 45.68744904654366, 44.60754612513951, 45.684100014822825, 46.510011536734446, 54.79852110998971, 52.18120070866176, 50.07888078689575, 49.075182233537944, 54.04098333631243, 50.693233558109824, 51.86023562295096, 49.025453976222444, 44.468311173575266, 49.946534974234446, 44.773139068058555, 45.658940587724956, 46.07810803822109, 42.96435621806553, 41.57968446186611, 39.82966252735683, 36.30410834721157, 37.99431324005127, 35.72879402978079, 37.566724572862896, 35.05737222943987, 39.80382217679705, 35.196207659585134, 38.898468426295686, 40.06832272665841, 49.043241364615305, 52.314623492104666, 43.67214836393084, 43.6988468170166, 45.81241239820208, 43.926167556217735, 52.01702867235456, 51.60625464575631, 53.87771456582205, 56.216968059539795, 53.88858502251761, 54.663382121494834, 54.47339057922363, 50.161050183432444, 53.19438355309622, 58.9949586050851, 55.42013474873134, 52.13226454598563, 51.27559682301113, 54.55567809513637, 56.84600237437657, 55.868446418217246, 49.217523029872346, 51.86575596673148, 54.10504225322178, 59.23142664773123, 55.19202538899013, 61.23399475642613, 58.1415183203561, 61.728907993861604, 62.840543338230674, 66.09173747471401, 59.950322014944895, 65.34138761247907, 68.60980633326939, 69.77386583600725, 63.418411118643625, 73.93264756883893, 14.426939913204738, 0.07902708729462964, 0.9844625741243362, 0.5866184394274438, 6.088005525725229, 54.5093857220241, 74.78321824754987, 70.50960363660539, 73.23811258588518, 74.93647466387067, 51.71800947189331, 79.8867882319859, 67.1715361731393, 40.673163414001465, 74.57857990264893, 88.77732794625419, 12.022150141852242, 0.9545593730040959, 0.26861030076231274, 0.1128130422106811, 0.12732788334999764], [0.07583326367395264, 0.007733771660631257, 0.04384159961981433, 0.06338891786124025, 0.10331237808402095, 0.0315345248340496, 0.13657062953071936, 11.81587723323277, 64.89306899479458, 44.69857447487967, 29.607302529471262, 21.22183953012739, 30.66235521861485, 40.24168028150286, 42.67523125239781, 54.234049456460134, 57.81713819503784, 45.26314687728882, 61.46703733716692, 3.3830694258213043, 0.501887491771153, 0.18865052637244972, 0.1408783769501107, 0.222429343100105, 8.3434385572161, 58.01868806566511, 54.43493577412197, 53.89278520856585, 53.59225130081177, 55.60511663981846, 53.254172801971436, 54.56153195244925, 53.52611139842442, 54.226479394095286, 51.99806009020124, 53.87033210481916, 50.57668447494507, 51.638014861515586, 46.169591494968955, 46.75293792997088, 49.1688300541469, 46.975891726357595, 44.82936041695731, 43.91012069157192, 46.72350883483887, 45.602104323250906, 48.787776947021484, 29.410880429404124, 44.72151395252773, 52.63049554824829, 47.15495375224522, 48.89728403091431, 44.187471934727256, 42.228496823992046, 40.89711080278669, 42.63716902051653, 42.120167459760395, 41.352033683231895, 38.41712849480765, 41.95779848098755, 44.70664133344378, 45.264130047389436, 44.91333287102835, 39.08529159000942, 34.07949318204607, 35.717947891780305, 35.774346419743125, 33.88904653276716, 33.70566272735596, 36.56437397003174, 34.22257743562971, 35.927189418247764, 36.135611057281494, 39.00608907427107, 41.00605508259365, 40.244713170187815, 42.60635028566633, 41.09977238518851, 43.86869205747332, 44.7589612688337, 45.47466393879482, 43.47220005307879, 44.931241852896555, 43.73009286608015, 46.415606362479075, 45.445005553109304, 45.158534799303325, 45.889697211129324, 43.19945893968855, 39.98490612847464, 44.24785525458199, 47.49279253823416, 45.01415123258318, 44.86980240685599, 44.32864890779768, 45.69412973948887, 45.2996700831822, 44.193568978990825, 42.54337876183646, 41.7665319442749, 42.73636845179966, 42.616904599326, 39.945944104875835, 39.148561886378694, 39.24619102478027, 37.45038740975516, 36.10875974382673, 36.40371772221157, 32.65490402494158, 30.931945323944092, 32.55116047177996, 33.827016489846365, 33.71451473236084, 33.74440588269915, 35.3186696597508, 37.04174995422363, 38.99193559374128, 45.273965222494944, 45.36631025586809, 42.975198881966726, 38.00369330814907, 41.495618207114084, 43.56934629167829, 44.6877943447658, 45.980166230882915, 49.02185828345162, 49.07371268953596, 48.69672427858625, 51.704311098371235, 52.08187968390328, 51.2976747240339, 50.52964169638497, 47.789675167628694, 51.431712423052105, 52.43852029527937, 50.16912399019514, 49.94695881434849, 51.799459729875835, 51.290660517556326, 48.47380174909319, 44.58071218218122, 47.068598066057476, 46.57141276768276, 44.45708288465227, 49.69287708827427, 51.2205844606672, 56.21758992331368, 52.08806358064924, 56.02761575153896, 63.790959630693706, 62.387854303632466, 45.56626551491873, 59.87819971357073, 59.90715980529785, 49.371019159044536, 1.3945433007819312, 0.16445718386343547, 0.4336313743676458, 0.8630937210151127, 4.005022440637861, 55.086072308676584, 60.337857791355674, 61.409818921770366, 60.301963397434776, 53.20882190976824, 48.010256154196604, 50.34599733352661, 23.263579845428467, 44.62508685248238, 50.41147715704781, 66.19063118525914, 4.061409677777972, 0.32954765803047587, 0.057579884571688514, 0.05003417822133217, 0.01891627049605761, 0.09863193173493658, 0.07376082773719515, 0.02251275715285114, 0.037465959055615325, 0.10272241224135671, 0.12274741913591113, 0.13095731288194656, 13.62320009299687, 75.06405748639787, 48.39292124339512, 36.2842503956386, 18.439457723072596, 25.271932329450333, 48.40932594026838, 48.51410477502005, 61.47303363255092, 62.307963916233604, 50.949094023023335, 65.05990219116211, 4.912385957581656, 0.8106114800487245, 0.1388732245458024, 0.19747807697526046, 0.333133688462632, 8.781126431056432, 60.71463080814907, 57.15485674994332, 56.85748774664742, 54.20375878470284, 57.80726133074079, 56.53189516067505, 55.44412687846592, 54.636322362082346, 56.036537238529746, 53.489251204899375, 54.66929851259504, 52.929778780256, 50.24898311070034, 46.67927312850952, 47.46831056049892, 51.72796971457345, 49.90192753928048, 47.59089762823922, 46.77015904017857, 48.54293979917254, 48.46176052093506, 50.23715727669852, 32.62533596583775, 48.04022373471941, 54.5740248135158, 49.383213247571675, 50.3829721723284, 46.18950155803135, 44.87042427062988, 44.09375810623169, 44.130868434906006, 44.447369303022114, 42.58499847139631, 39.903035504477366, 44.27848291397095, 46.272407463618684, 46.538874353681294, 46.34726388113839, 42.26858098166329, 36.72014910834176, 37.25462538855416, 37.4706483568464, 34.38683979851859, 36.05647802352905, 36.11671543121338, 36.20974486214774, 36.50116620744978, 38.96985421861921, 41.02980055127825, 40.96461255209786, 43.3907220023019, 43.38944353376116, 42.68527487346104, 46.419910771506174, 46.779038837977815, 46.9236273765564, 46.7985771724156, 46.120405197143555, 47.346981116703574, 48.3175402368818, 47.93784550258091, 47.90382364818028, 47.52570268086025, 45.27612263815743, 44.05323273794991, 46.05566883087158, 49.57228067943028, 48.144783701215474, 46.04745953423636, 47.575031416756765, 47.69677427836827, 46.756992203848704, 47.716607911246165, 45.00163057872227, 43.37139906202044, 45.04317385809762, 44.32614408220564, 43.91913250514439, 41.81868512289864, 42.033290658678325, 40.27149152755737, 38.1083470753261, 38.04295757838658, 34.13945613588606, 32.78144114358084, 33.97612830570766, 34.73297473362514, 34.21608434404646, 35.1673378944397, 35.91437346594674, 37.2141695022583, 40.9273806299482, 45.56858968734741, 46.283865043095176, 44.87281445094517, 40.13938890184675, 43.87529284613473, 45.11534827096121, 45.62254244940621, 47.188374587467735, 50.39497518539429, 50.204115118299214, 51.154083251953125, 53.819422653743196, 52.857302120753694, 52.99076311928885, 49.30040461676461, 50.93051453999111, 51.86458172116961, 55.08269201006208, 51.74332870755877, 51.05453641074044, 52.82697670800345, 52.92833702904837, 50.061124665396555, 46.9515243938991, 48.755155154636924, 52.60583291734968, 49.20691313062395, 52.23789800916399, 53.02392339706421, 57.89115040642874, 54.09853179114205, 59.114662170410156, 60.892073903764995, 64.41683946337018, 50.6725800377982, 61.273474420819966, 63.44252136775425, 54.588779313223704, 1.5611939983708518, 0.1550259135131325, 0.0824524609904204, 1.0105095250265939, 5.555890330246516, 59.639272008623394, 65.6973716190883, 66.14997727530343, 65.56912176949638, 61.64963599613735, 52.322770254952566, 65.80553422655377, 38.017693928309846, 43.30168431145804, 58.87502574920654, 78.19126101902553, 6.564988936696734, 0.46468591370752876, 0.07358287514320441, 0.12401376904121467, 0.05158629993508969, 0.23384102646793636, 0.22506106831133366, 0.16850209395800317, 0.29755228917513576, 0.13892997721476213, 0.22771781789405005, 0.1881070469639131, 19.23255464008876, 89.33467074802944, 56.588043553488596, 42.191237109048025, 28.996727841241018, 42.683916500636506, 54.59458105904715, 54.94948462077549, 63.869439533778596, 67.63104833875383, 56.54380784715925, 72.18368176051548, 6.5423169646944315, 1.8152984146560942, 0.4306753229882036, 1.436339320881026, 0.5805447910513196, 10.310309427125112, 64.3279025214059, 59.79403618403843, 58.74297523498535, 58.447468348911826, 60.71917493002755, 59.34456416538784, 58.054158619471956, 57.49016639164516, 57.879560811179026, 56.42398268835885, 57.047937870025635, 54.27539471217564, 51.25772605623518, 47.78232397351946, 50.403684752328054, 54.66599464416504, 52.78748662131173, 50.395308698926655, 50.25702217647007, 51.32671124594552, 50.52964864458357, 52.84604951313564, 39.878570897238596, 52.71946375710623, 58.633832931518555, 53.604417596544536, 52.07610920497349, 48.31212411608015, 48.018010343824116, 46.31402022497994, 46.37606416429792, 46.716835090092246, 44.99047524588448, 41.51889814649309, 45.96393871307373, 48.383225032261436, 48.39699288776943, 48.856421675000874, 42.08819532394409, 37.82963745934622, 38.19401488985334, 41.36826467514038, 35.525642599378315, 37.630609784807476, 39.133505140032085, 37.62648950304304, 38.32037830352783, 40.732365540095735, 41.92920664378575, 44.891133376530235, 44.7749525478908, 48.03923709051949, 45.27152640478951, 50.12546845844814, 49.429158210754395, 49.491045815604075, 48.610785484313965, 49.73654651641846, 50.17228194645473, 50.628003869737896, 50.35992499760219, 49.24764347076416, 50.038108757564, 47.71828590120588, 45.14798048564366, 51.74066754749843, 52.3843868800572, 52.07630375453404, 50.05196693965367, 50.17223678316389, 52.62757383074079, 52.18910081045968, 50.209944656917024, 48.702171666281565, 47.583417892456055, 48.53695045198713, 49.102742263248985, 46.681736264910015, 43.0760554586138, 45.72280842917306, 42.974691663469585, 39.95386505126953, 40.83851316996983, 36.808551039014546, 33.36072983060564, 34.84033829825265, 37.824040685381206, 36.58600718634469, 36.637649672372, 38.505023206983296, 39.8473665373666, 43.554734230041504, 48.79262331553868, 49.62780373437064, 47.323256492614746, 42.884865352085654, 46.03959764753069, 47.920937061309814, 48.26071092060634, 47.908329554966514, 52.65881987980434, 51.849643094199045, 52.356958866119385, 55.698906898498535, 53.721314089638845, 53.50006260190691, 51.219149657658164, 53.28675985336304, 53.03835480553763, 55.83331980024065, 53.319385119846885, 52.02333068847656, 56.063034193856375, 55.34995099476406, 51.7693636076791, 48.29405879974365, 50.05091428756714, 52.78811543328421, 48.391406536102295, 53.94866262163435, 56.247032914842876, 57.8977164540972, 56.003953661237446, 59.49316528865269, 60.819972446986604, 64.96772044045585, 57.08290467943464, 62.970537185668945, 63.52739361354283, 56.670192105429514, 2.4730716730867113, 0.23446728714874812, 1.7340846125568663, 1.999981858900615, 7.314901062420436, 63.958251408168245, 74.40226936340332, 72.1418536049979, 73.16890157972063, 64.46933310372489, 61.54926926749093, 67.69977297101701, 33.86881685256958, 58.47813074929373, 67.98464911324638, 89.95275470188686, 9.872866477285113, 0.7345371193119458, 0.37711611124021666, 0.2585742792912892, 0.20656577790422098], [0.07202609189386878, 0.025517072728169814, 0.022461783905912722, 0.06655052463923182, 0.06501835185502257, 0.07232111891997711, 0.17387006591473306, 8.134767651557922, 68.48571150643485, 47.544306482587544, 43.117081097194124, 37.95402063642229, 44.99723236901419, 37.251620292663574, 38.443562916346956, 54.88551950454712, 64.36635385240827, 43.4637336730957, 65.62486716679165, 7.652256948607309, 0.08696856615798813, 0.20913141380463326, 0.11056958152247326, 0.24792697919266565, 4.266860527651651, 57.2871469770159, 52.70126642499651, 57.667331559317454, 51.56276934487479, 57.03486483437674, 53.97356843948364, 57.619138853890554, 52.52493504115513, 52.85016284670149, 50.03814002445766, 52.31176430838448, 46.84578323364258, 42.9709153175354, 39.72460923876081, 48.81946420669556, 49.01606695992606, 51.2060592515128, 45.02597706658499, 48.78028678894043, 48.79346752166748, 50.277894565037315, 36.499797412327354, 28.999958753585815, 50.88760246549334, 47.18070030212402, 49.40030929020473, 46.85817881992885, 46.01053333282471, 43.5948600769043, 43.61462075369698, 41.649996757507324, 42.8999742099217, 42.57446847643171, 39.943234307425364, 40.52164057322911, 45.84072283336094, 45.04873936516898, 42.24255302974156, 47.25737714767456, 42.36512272698538, 36.74103886740548, 34.60699347087315, 32.97889505113874, 35.35972309112549, 34.1751594543457, 36.0426094191415, 34.53535406930106, 38.75826072692871, 38.79470750263759, 39.21805082048689, 41.70549896785191, 41.66116598674229, 41.34426212310791, 42.380742277417866, 42.839059352874756, 42.09218011583601, 43.50807012830462, 44.54662084579468, 43.32980019705636, 45.77328014373779, 46.439306667872835, 47.48244667053223, 47.149770396096365, 41.61077070236206, 41.71894025802612, 44.041497230529785, 47.501220703125, 44.64879758017403, 42.55421795163836, 42.129380771092, 44.10330145699637, 44.15381833485195, 42.60956382751465, 38.64840623310634, 39.9494286264692, 43.1695226260594, 40.8184745652335, 38.96069301877703, 41.01721041543143, 40.12242487498692, 38.93482487542288, 37.268626008714946, 34.57906518663679, 32.26460633959089, 33.04366963250296, 32.684760434286936, 34.30518109457833, 33.6400717326573, 35.20161683218819, 34.230950014931814, 38.588339056287495, 40.32256773539952, 43.95981420789446, 45.660611629486084, 43.62695380619594, 40.95963069370815, 41.18638515472412, 44.60080637250628, 39.06865760258266, 42.231918811798096, 45.74095017569405, 49.189525263650076, 49.632973194122314, 49.146178926740376, 45.4487749508449, 45.60878154209682, 44.69922065734863, 49.401282038007466, 56.58585139683315, 49.8649457522801, 49.09340041024344, 47.07044628688267, 51.29627813611712, 52.099601064409526, 50.53579780033657, 47.75117519923619, 49.639921392713276, 43.78037003108433, 47.35135848181588, 51.90280376161848, 52.30464587892805, 49.85511405127389, 55.099405901772634, 62.654296875, 51.87584475108555, 39.07503604888916, 54.62640380859375, 57.30529567173549, 64.68511635916573, 28.010806253978185, 0.15332170496029512, 0.03414628075967942, 0.20308540894516877, 0.6324445775577, 3.273655925478254, 58.68090697697231, 56.07699659892491, 59.67042078290667, 56.243927070072715, 39.69395726067679, 43.75907032830374, 34.74838931219918, 15.976086820874896, 34.09870842524937, 51.90680592400687, 54.552540983472554, 1.4119817593267985, 0.2052108384668827, 0.09267073696745293, 0.032499785002853186, 0.038982562853821685, 0.07611735950091056, 0.05859167527939592, 0.029483157409621135, 0.10564144275018147, 0.08471988075013671, 0.14836622801210197, 0.09539589645074946, 12.298853465488978, 78.12662887573242, 52.44558661324637, 44.00001995904105, 31.356935364859446, 47.76950454711914, 45.64785821097237, 46.324366092681885, 57.78841781616211, 72.2420883178711, 48.98802750451224, 72.10785606929234, 8.100143909454346, 0.24735923537186214, 0.33979969791003634, 0.19478388583021505, 0.33058587089180946, 5.164827040263584, 60.90977791377476, 56.11052165712629, 61.0381041935512, 54.1698967388698, 58.54035186767578, 55.880477224077495, 59.523508071899414, 52.86596999849592, 57.03285333088466, 53.281611238207134, 52.81664821079799, 47.35517999104091, 43.45975930350167, 41.642888750348774, 50.32336705071585, 50.560269355773926, 52.790373597826274, 46.7019624710083, 50.59603520802089, 48.73379291806902, 51.68195179530552, 37.155405112675254, 31.630472046988352, 51.782711097172324, 51.85794619151524, 49.54289327348982, 48.252188955034526, 46.27041680472237, 44.625448158809114, 44.938857078552246, 45.228388513837544, 44.36792707443237, 42.9995835849217, 41.17793614523751, 41.46038041796003, 46.03947605405535, 48.08453934533255, 45.571532249450684, 48.35118341445923, 43.6775540624346, 37.73620503289359, 36.4505728994097, 36.13770593915667, 37.44568695340838, 35.83692537035261, 37.268198694501606, 35.72474323000227, 39.41114125932966, 41.37973615101406, 40.34567049571446, 43.7077613558088, 44.34538017000471, 44.86584193365914, 43.40767560686384, 44.78706325803484, 43.905830178942, 44.87383583613804, 47.175701073237825, 49.26055669784546, 46.53304828916277, 49.39716870444161, 49.513780321393696, 48.68289736339024, 46.16713530676705, 42.70658152444022, 45.99636248179844, 49.25287546430315, 49.13957813807896, 45.56576177052089, 45.84585755211966, 47.1867869240897, 48.93100711277553, 45.828532218933105, 43.05680547441755, 43.21323026929583, 45.7219294820513, 43.29729304994856, 41.75882639203753, 43.025764397212434, 41.39387573514666, 41.60829366956438, 38.40907900674002, 35.10387999670846, 34.43084274019514, 33.74489573069981, 34.69405092511858, 35.87128421238491, 34.966059003557476, 34.17224815913609, 36.429474694388254, 38.60566438947405, 42.9248765536717, 46.13003192629133, 46.698700291769846, 44.648088863917756, 41.00840357371739, 43.959216662815635, 46.37641852242606, 39.98107419695173, 43.89662034170968, 46.83487456185477, 48.853781359536306, 53.20400333404541, 51.500624656677246, 46.18349136625017, 44.67545434406826, 46.45973784582955, 47.773590087890625, 55.43917628696987, 52.281557015010286, 51.948231084006174, 50.3700624193464, 53.805797236306326, 54.31790379115513, 52.07833957672119, 48.1180921963283, 51.104226452963694, 48.02380861554827, 47.85751737867083, 55.041805335453574, 53.627398763384136, 53.655584130968364, 56.49721670150757, 60.59872095925467, 55.360675539289204, 43.37955972126552, 55.6411326272147, 60.182537760053364, 67.45651653834751, 31.525220734732493, 0.05252684107316392, 0.061399453186563084, 0.26144746797425406, 1.0743897429534366, 3.8400678634643555, 66.43581921713692, 62.53359276907784, 65.83058248247418, 63.74791554042271, 44.400712149483816, 50.14135898862566, 45.16058104378836, 20.033671515328543, 41.45165000643049, 59.790138244628906, 66.99527427128383, 2.3106382063456943, 0.3475263661571911, 0.08693313305931431, 0.10141366068273783, 0.08224004560283252, 0.20864090083965234, 0.1980254647455045, 0.12076206638344697, 0.22321951070002147, 0.1757952868938446, 0.2683352769485542, 0.33522042791758266, 14.448986547333853, 93.25109931400844, 59.827422278267996, 56.69035577774048, 49.37379149028233, 62.033739362444194, 49.26096664156233, 53.425511905125205, 64.52175726209367, 76.87470245361328, 55.623091629573274, 78.47681113651821, 9.04937640258244, 0.5562571457454136, 0.45248718400086674, 0.6267183933939252, 0.4811593326074736, 6.033407015459878, 64.69330828530448, 57.66564662115914, 62.67113930838448, 56.49374607631138, 61.723953928266255, 58.14084087099348, 63.67423684256417, 54.28275980268206, 59.196372985839844, 55.085283688136506, 56.04522596086775, 48.40418774741036, 45.42719384602138, 47.21806076594761, 55.05852617536272, 52.599732398986816, 54.56865038190569, 50.10309525898525, 53.17262874330793, 53.30459935324532, 51.75717299325125, 38.333739689418245, 33.10426834651402, 53.616080147879465, 53.633110182625906, 54.83687516621181, 49.494749205453054, 48.579664502825054, 46.9297695841108, 48.231743880680625, 46.72993244443621, 45.89595058986119, 45.01532200404576, 43.930603981018066, 42.56199993406023, 49.56275469916207, 49.87632690157209, 46.81369645254952, 51.03913572856358, 47.497614588056294, 39.76211908885411, 38.98420224870954, 36.707927227020264, 37.595142705099924, 37.31587723323277, 39.26240464619228, 38.793380396706716, 41.42114046641758, 42.08647911889212, 41.52172258922032, 47.2677230153765, 48.02375650405884, 47.06054857798985, 46.312446457999094, 47.155120509011404, 47.020801407950266, 48.617584296635215, 48.89962557383946, 50.74371222087315, 49.77933699744088, 51.61094120570591, 50.709030287606375, 52.61873919623238, 46.35865545272827, 46.113408361162456, 51.41966077259609, 52.87038210460118, 51.2059828213283, 49.637708391462056, 49.134109905787874, 51.677317346845356, 52.60829257965088, 50.53272669655936, 46.11530869347708, 46.08006395612444, 48.751503876277376, 45.0783873285566, 43.49554600034441, 47.29621410369873, 43.78167976651873, 44.5828035899571, 41.383377007075715, 38.83788013458252, 36.098104681287495, 36.38626037325178, 36.3500428880964, 37.91392953055245, 37.13476548876081, 37.45725222996303, 37.9328043120248, 42.8137331690107, 46.3484138080052, 49.742615767887656, 49.57037339891706, 49.35191856111799, 45.750573430742534, 46.266098499298096, 48.1546744619097, 42.483454023088726, 45.681174823216026, 50.186063698359895, 52.38144431795393, 53.54094580241612, 51.271247250693186, 48.36674043110439, 50.105381216321675, 48.22480957848685, 45.11537953785488, 54.19624778202602, 53.696762629917686, 52.67509256090437, 52.63487638745989, 56.13294696807861, 56.7393023627145, 53.63905436652047, 50.35028089795794, 52.26161221095494, 48.51517479760306, 50.11307634626116, 53.75969246455601, 55.56482056209019, 52.40098960059029, 57.059214796338765, 62.11775003160749, 59.712943758283345, 49.483482701437815, 58.051500933510916, 62.766343525477815, 68.55196952819824, 36.01813786370413, 0.28554167651704376, 0.18655367674572126, 0.28001753294042175, 1.9064578030790602, 5.20396146603993, 70.02655097416469, 68.30176489693778, 71.59332806723458, 69.92413452693394, 51.261179310934885, 58.105464117867605, 50.358785493033274, 23.48792675563267, 49.90275090081351, 65.95226628439767, 80.28787994384766, 4.232618067945753, 0.657193626676287, 0.24662394768425397, 0.1905684056026595, 0.14044178037771157], [0.04021652289001005, 0.04984654632530042, 0.08369889589292662, 0.07405751717409917, 0.05448071997878807, 0.10848135607583181, 0.06189605939601149, 2.430870703288487, 61.57716628483364, 50.83510882513863, 41.145904949733186, 24.616055386407034, 20.292479753494263, 38.192722524915425, 37.07675150462559, 55.70599058696202, 60.05048029763358, 45.030403069087434, 63.480375153677805, 24.04112321989877, 0.15098196693829127, 0.22204320239169256, 0.14267364490245069, 0.22771154823047773, 1.8399361840316226, 50.15861831392561, 58.407113211495535, 60.19935934884207, 55.03193194525582, 57.38079827172415, 53.96252775192261, 56.11339821134295, 53.663011755262104, 53.82997349330357, 48.787589345659526, 47.963699749537874, 36.69889804295131, 43.98974357332502, 47.3933082308088, 49.43639128548758, 49.937811510903494, 49.03849574497768, 47.92958409445626, 49.67289406912667, 48.18158483505249, 45.65862444468907, 37.528617177690776, 48.22155087334769, 51.19205515725272, 49.241397040230886, 48.30904606410435, 43.99865116391863, 43.39780569076538, 42.70643213817051, 45.50300216674805, 42.77743925367083, 43.65685190473284, 42.00319801058088, 39.586788245609824, 39.921462127140586, 43.418782302311485, 43.498954091753276, 44.421848569597515, 48.04387501307896, 45.456153937748496, 39.377710001809255, 36.819807120731895, 36.6551765033177, 35.7991931779044, 34.650853974478586, 34.55484029224941, 36.230255944388254, 37.279027462005615, 39.48830795288086, 39.776001589638845, 38.93898337227957, 41.02299131665911, 41.07529388155256, 41.407480307987754, 44.240990434374126, 42.13564109802246, 41.8883512360709, 43.68723290307181, 45.79382944107056, 45.68877615247454, 47.13363667896816, 46.9120968409947, 47.62801490511213, 44.452549185071675, 43.32442923954555, 44.284670284816194, 44.59446266719273, 45.730791909354075, 42.13159029824393, 42.74942064285278, 42.080455030713765, 41.20654535293579, 38.98385831287929, 42.75550726481846, 43.254380975450786, 41.33452074868338, 41.13268600191389, 40.53150006702968, 40.631359577178955, 38.85681744984218, 37.55560745511736, 34.897191933223176, 33.389947005680625, 33.35724530901228, 32.12664638246809, 32.13858338764736, 34.84377070835659, 32.4683518409729, 34.586075919015066, 33.69495555332729, 41.71509443010603, 46.29592016765049, 44.10158177784511, 44.56933798108782, 43.44789178030831, 39.80392639977591, 41.599351337977815, 44.73053618839809, 42.368013177599224, 41.208115645817344, 41.35455240522112, 46.380816732134136, 47.78088569641113, 48.79002121516636, 46.326596464429585, 32.71120180402483, 31.110107558114187, 43.85051556995937, 48.56337097712925, 49.94561433792114, 54.61265332358224, 51.79612112045288, 50.15941735676357, 50.26066650663103, 48.21399818147932, 48.06738771711077, 51.96975312914167, 42.369479247501914, 48.28959110804966, 49.89613274165562, 56.88017014094761, 56.04019546508789, 53.65965230124337, 45.497374125889365, 47.88703332628523, 52.4145142691476, 59.39138807569231, 51.12253148215157, 59.25900404793875, 12.81454963343484, 0.15366203098424844, 0.14770643413066864, 0.12563861613827093, 0.8790755548647472, 4.080510709966932, 60.88153348650251, 57.92296273367745, 64.60687269483293, 58.30294581821987, 57.29683971405029, 37.99009568350655, 35.78137452261788, 31.4575001171657, 41.86717312676566, 53.53738832473755, 59.403359821864534, 1.0200193290199553, 0.1551113139305796, 0.014465482805722525, 0.11013205535709858, 0.08247522584029607, 0.12668984330126218, 0.02673108722748501, 0.06944937551660196, 0.11093962059489318, 0.027462838051308478, 0.0800917155242392, 0.14609631124351705, 4.294082701206207, 76.71030112675258, 55.76930257252285, 44.80981513432094, 33.982930592128206, 30.999832698277064, 44.07968800408499, 43.28067643301827, 57.91394397190639, 68.14361000061035, 49.40545095716204, 69.32941736493791, 25.015314510890416, 0.21732164360582829, 0.24671104443924768, 0.204437254262822, 0.2629602210862296, 2.118669250181743, 55.15680497033255, 59.15777574266706, 62.121515955243794, 55.76252113069807, 58.665613991873606, 55.241923877171104, 56.45995698656355, 54.79186820983887, 56.04494455882481, 50.08249732426235, 49.78218228476388, 40.47953448976789, 48.219893727983745, 47.9052688734872, 50.00822108132498, 50.853323527744834, 50.28172302246094, 50.307712759290425, 49.699130467006135, 50.90611941473824, 47.19009774071829, 38.37376478740147, 49.840630531311035, 51.53763771057129, 50.386946541922434, 47.790071214948384, 47.7956679889134, 46.72157376153128, 43.332072257995605, 46.6022766658238, 44.41797147478376, 45.065554005759104, 45.40155846732003, 41.86969184875488, 42.826399735042024, 44.62877982003348, 45.19986615862165, 46.47054924283709, 48.68785490308489, 46.42154359817505, 41.309038230351035, 38.3958739553179, 38.20701844351632, 37.644287313733784, 36.02709756578718, 36.50236129760742, 36.315562452588765, 38.49791867392403, 38.71683209283011, 41.838529178074424, 41.15418720245361, 43.22289521353585, 43.51764474596296, 44.71948160443987, 44.51037904194423, 43.369741916656494, 43.74143232618059, 44.98048721040998, 48.31929465702602, 48.75898361206055, 49.63616936547415, 49.27870886666434, 49.27695097242083, 44.94354016440255, 44.20351879937308, 47.07185329709734, 45.8517461504255, 47.698935168130056, 45.740429060799734, 46.10800961085728, 45.82729891368321, 43.563652242933, 44.21014390672956, 44.3287079674857, 44.83263649259295, 44.24845279966082, 41.62183918271746, 42.59370109013149, 42.51714931215559, 43.79524612426758, 39.9458190373012, 36.909796714782715, 33.72425958088466, 35.24191985811506, 34.56550925118582, 33.64678716659546, 37.28607988357544, 33.53311116354806, 36.40100792476109, 34.42285231181553, 44.381152970450266, 47.714651993342805, 46.190189429691856, 47.38066250937325, 43.59223713193621, 40.614294801439556, 42.05971465791975, 45.450991426195415, 43.975176674979075, 43.17202050345284, 43.073950154440745, 46.947386741638184, 50.57033034733364, 50.81972551345825, 49.38992173331124, 35.95092446463448, 31.878491469791957, 39.942546435764854, 48.97178609030587, 47.93702561514718, 54.13863679340908, 54.20795202255249, 52.4616300037929, 51.97160829816546, 51.67191859654018, 47.060684067862375, 53.57581186294556, 46.176359040396555, 49.588640213012695, 50.538848059517996, 57.426208223615376, 57.951832498822895, 55.36484445844378, 49.5968599319458, 50.76675592150007, 56.03320557730538, 61.736335618155344, 52.8789700780596, 62.708187103271484, 15.348919834409442, 0.14399872879896844, 0.4862160469804491, 0.10317104602498667, 1.3972660175391605, 4.6078915766307285, 68.5648306437901, 61.90927628108433, 72.41197177342006, 63.385678155081614, 61.49924223763602, 44.43033926827567, 43.57650293622698, 19.780215127127512, 41.68263244628906, 62.83187893458775, 69.56537818908691, 1.4771357774734497, 0.30890108591743876, 0.06752416810819081, 0.07303952465632133, 0.0676901445591024, 0.17510398184614523, 0.10677146818488836, 0.13644766541463987, 0.15494150375681265, 0.13211383510913166, 0.26692376126136097, 0.21793639633272374, 6.604665756225586, 90.81386579786027, 60.76258727482387, 58.70613588605608, 30.053265707833425, 31.255946772439138, 51.5998831476484, 50.41344002314976, 66.4866383416312, 74.42813750675747, 54.40710823876517, 76.88268593379429, 29.99322979790824, 0.23849895223975182, 0.26814023884279387, 0.2987174152263573, 0.35273181540625437, 2.7897861983094896, 58.34655271257673, 60.996289934430806, 66.07817459106445, 57.82425662449428, 61.37193734305245, 58.27137320382254, 61.106856618608745, 57.74410220554897, 58.09155035018921, 51.32235472542899, 53.242364338466096, 44.2999632699149, 50.54092557089669, 48.18822036470686, 51.72801487786429, 52.06862946919033, 53.15564734595162, 51.14542927060808, 53.55565166473389, 52.7537704876491, 48.59784099033901, 36.503931590488975, 51.50452259608677, 54.89435761315482, 52.75765453066145, 51.3474828856332, 48.56544501440865, 48.069166455950054, 45.74412897654942, 49.82563631875174, 45.61461108071463, 46.41030141285488, 47.31397022519793, 43.54140758514404, 44.719116824013845, 48.70042766843523, 48.39430046081543, 48.844397817339214, 52.5490140233721, 49.63640560422625, 46.25159066064017, 40.46616268157959, 40.053210394723074, 39.94628456660679, 38.67540693283081, 38.17880528313773, 38.18049716949463, 40.78171512058803, 42.62825100762503, 44.236640862056184, 42.64930404935564, 46.93855905532837, 46.022314003535676, 46.88855287006923, 48.33348287854876, 45.42756904874529, 45.59343644550869, 48.22873878479004, 50.53442553111485, 52.5263420513698, 52.88504975182669, 52.35462427139282, 52.68437188012259, 46.96443067278181, 47.0930209841047, 50.7081652368818, 48.3314505304609, 50.67860412597656, 48.29319722311837, 49.84474039077759, 48.56723764964512, 47.35973106111799, 45.73070158277239, 47.409813676561626, 48.94688722065517, 46.29043109076363, 45.21347073146275, 44.699248450142996, 45.332740034375874, 44.140978063855854, 42.002669947487966, 39.4269449370248, 36.18461322784424, 37.369298458099365, 36.45529767445156, 35.61284943989345, 41.06333255767822, 35.94310079302107, 39.43195458820888, 36.01987143925258, 45.84811224256243, 51.957698004586355, 49.61504684175764, 49.49921689714704, 46.54539523805891, 42.26264722006661, 45.43191167286464, 47.327619961329866, 46.96058831896101, 46.88025672095162, 43.90870673315865, 49.77870123726981, 52.642599310193745, 51.91733244487217, 48.30156632832119, 34.39757823944092, 32.020627294267925, 42.76638119561331, 54.548709051949636, 48.80630431856428, 54.464535100119456, 53.47721345084054, 54.013933999197825, 55.26884119851248, 50.93050064359392, 49.8428087915693, 51.70983144215175, 44.19052914210728, 50.503936835697715, 52.440712451934814, 58.301646505083355, 58.107169900621685, 56.81379052570888, 52.56483507156372, 54.12038387571062, 54.94628150122506, 61.64861461094448, 56.76607377188546, 66.06439631325858, 18.086720262254985, 0.12104451337030955, 0.4992466877613749, 0.2736489661037922, 2.154564295496259, 5.82268899679184, 75.22954273223877, 66.52003833225795, 76.96605736868722, 70.60637814658028, 67.75061988830566, 50.937577383858816, 54.52169792992728, 40.37825754710606, 58.76423672267369, 68.6382383619036, 85.67429719652448, 3.1571904378277913, 0.4699574794088091, 0.16640019603073597, 0.1923862009176186, 0.22504509559699468], [0.012157510400616696, 0.09111072389142853, 0.05267110779615385, 0.01115136849693954, 0.09004305582493544, 0.029055649813796793, 0.21987452304788999, 2.183926297085626, 55.05191149030413, 51.89495229721069, 35.727741377694265, 24.265414544514247, 28.68849011829921, 29.836509704589844, 26.60729272024972, 56.88706970214844, 59.10571983882359, 44.59540067400251, 59.66646725790841, 35.404764788491384, 0.23341477076922143, 0.13052984939089843, 0.2074419158910002, 0.16833351871797017, 0.13763903720038279, 38.62721422740391, 60.24109022957938, 54.2924143246242, 56.374768597739084, 51.44628626959664, 49.15933881487165, 51.067432267325266, 52.503235816955566, 52.59773479189192, 50.94048867906843, 46.266946179526194, 52.21323537826538, 55.1819817679269, 50.08642305646624, 48.43774059840611, 49.190939222063335, 50.86742837088448, 49.800515106746126, 50.21315819876534, 50.652183600834434, 46.673255988529746, 43.444560119083945, 50.17865344456264, 50.27469144548689, 48.580404485974995, 49.39419834954398, 46.89492436817714, 49.44002866744995, 48.04141535077776, 48.056305340358186, 47.40270914350237, 45.85290649959019, 44.45440435409546, 40.76911456244332, 40.756892681121826, 42.964700153895784, 45.58568572998047, 43.56478827340262, 44.434952872140066, 46.804337229047505, 43.68657977240426, 35.66518327168056, 35.035078934260774, 33.69678292955671, 34.66906520298549, 35.356874329703196, 33.12562363488333, 35.835299491882324, 38.249173164367676, 39.70229162488665, 41.21419184548514, 39.63204533713204, 40.9743469783238, 43.2005741255624, 42.373648166656494, 43.84608261925833, 40.71012088230678, 43.20181090491158, 43.70618411472866, 44.82127618789673, 46.32431050709316, 48.45295715332031, 45.93589925765991, 45.565136432647705, 43.507135595594136, 44.96520464760916, 46.29241827556065, 46.770061765398296, 43.302024773189, 46.26437187194824, 44.28520877020699, 43.63734483718872, 42.6238944871085, 43.56344032287598, 41.085424355098176, 43.2801171030317, 40.69025598253523, 41.127520016261506, 40.28030184337071, 40.58284725461687, 39.70964281899588, 35.82403646196638, 32.5884028162275, 35.41033376966204, 34.59397949491228, 33.982895851135254, 31.887972286769322, 34.67914703914097, 36.55292681285313, 38.697714124407085, 42.75290863854544, 41.03093658174787, 44.66976029532296, 42.47435188293457, 43.27255398886544, 39.59482731137957, 40.37040955679757, 44.546454089028494, 41.111448832920615, 41.14344181333269, 43.004902430943076, 44.57710606711251, 46.75942407335554, 48.296521936144146, 48.34937688282558, 53.019949027470176, 46.46297223227364, 36.384412152426584, 33.43357821873256, 43.2336927141462, 47.163996832711355, 43.65600422450474, 48.703182629176546, 50.06459181649344, 48.061731883457725, 51.383974824632915, 44.31716353552682, 40.38359376362392, 54.53878007616316, 54.74325513839722, 56.093356132507324, 48.967617171151296, 51.11050067629133, 52.9598297391619, 63.55161503383091, 50.86325250353132, 58.07464190891811, 47.03100831168038, 51.69092191968645, 5.450893061501639, 0.1561880268688713, 0.1842764996524368, 0.5111175764884267, 0.6850473263434002, 4.102195603506906, 66.09721960340227, 56.198635237557546, 63.95073345729283, 61.07303278786795, 59.37162739889962, 31.266025134495326, 33.96829421179635, 27.69969023977007, 37.87137876238142, 56.27058035986764, 52.590202944619314, 0.2669461800583771, 0.0683810899832419, 0.04447416728362441, 0.0051208970003894395, 0.021523069723376205, 0.029093620633440356, 0.0774783378999148, 0.04917792809594955, 0.054627029092184136, 0.025434272796181694, 0.01194403225755585, 0.12202262159969125, 3.3001570062977925, 69.32155200413295, 56.93102748053414, 39.64958259037563, 21.8589928150177, 37.7447269984654, 33.98513664518084, 36.45474181856428, 64.56588527134487, 64.51312065124512, 49.65940066746303, 66.02054623195103, 36.762519223349436, 0.3009295208113534, 0.2094111330807209, 0.2691656138215746, 0.09424134876046862, 0.17512918263673782, 42.38977493558611, 61.770263671875, 56.67559085573469, 58.62132617405483, 53.03191382544381, 52.73447534016201, 54.5570364679609, 54.61192028863089, 53.205834184374126, 52.59978451047625, 50.06714527947562, 55.54868337086269, 54.538915566035676, 50.98742028645107, 51.33497265407017, 51.67307199750628, 50.46118456976754, 50.60335166113717, 52.83285140991211, 51.906666960035054, 48.94946500233242, 43.66661759785244, 51.034244196755544, 54.36508900778634, 49.114620208740234, 51.285859312329976, 48.30466175079346, 50.463411467415945, 50.192813873291016, 49.99985545022147, 50.28126096725464, 47.41301679611206, 45.91906724657331, 42.2917914390564, 43.680774552481516, 45.18509428841727, 46.49116802215576, 46.1364346912929, 46.80927045004708, 47.39405516215733, 44.251152174813406, 37.65710326603481, 35.55738197054182, 36.25459548405239, 36.18612098693848, 35.95415537697928, 35.70847749710083, 38.306238719395225, 40.14055619921003, 42.49453639984131, 42.96881348746163, 41.70242438997541, 41.98324973242623, 45.45610877445766, 44.47480773925781, 44.72306340081351, 42.80039610181536, 44.39462552751814, 44.616033349718364, 47.25951371874128, 49.36525910241263, 50.36119999204363, 48.501375675201416, 45.36890888214111, 44.18233026776995, 48.19399084363665, 47.83771848678589, 48.78326409203665, 47.34872511454991, 49.85791070120675, 46.931068897247314, 46.547979967934744, 44.223564352308, 45.85045378548758, 42.583535875592915, 44.38234111240932, 43.99205732345581, 43.74674769810268, 42.904719829559326, 42.01968955993652, 41.42154346193586, 38.09496137074062, 34.995668751852854, 36.510091168539866, 35.63520179476057, 35.26773588997977, 34.46116467884609, 35.72400324685233, 37.4668094771249, 41.05642604827881, 46.56236968721662, 44.56871264321463, 48.45844623020717, 44.14649493353707, 45.62756947108677, 41.04971061434065, 41.69123779024397, 46.035029206957134, 43.32096903664725, 41.75801345280239, 44.7651868547712, 46.95302867889404, 49.015146323612754, 50.28866079875401, 50.19101081575666, 55.43209259850638, 47.288199356624055, 42.85010004043579, 37.59598691122872, 44.53545161655971, 43.586873122623985, 44.15987021582467, 49.938096387045725, 51.85132455825806, 50.26142038617815, 51.93768719264439, 49.12938860484532, 41.05106551306588, 53.05114643914359, 56.19804116657802, 59.5647873197283, 51.54837267739432, 54.66966329302107, 57.62781367983137, 64.59082235608781, 52.71321732657296, 60.0442408152989, 50.41048009055001, 56.59139953340803, 7.172034808567592, 0.15157913203750337, 1.6646064264433724, 0.4707101104514939, 0.5102180019021034, 5.210982620716095, 71.41439110892159, 62.57332256862095, 72.1474608012608, 67.1331821169172, 67.07357352120536, 37.912939412253245, 45.19860506057739, 27.38797320638384, 44.82155064174107, 63.90032427651541, 63.73415115901402, 0.59836431486266, 0.1118020521742957, 0.01574902848473617, 0.05047061873067703, 0.07234469122652497, 0.17220773654324667, 0.19598072660820826, 0.14507783018052578, 0.20271969214081764, 0.18415371195546218, 0.08256668557545968, 0.3366721400192806, 4.2338570186070035, 81.49425397600446, 64.12935079847063, 51.44254119055611, 30.51696068899972, 42.28843198503767, 42.59706401824951, 39.46537889753069, 67.14169366019112, 73.82058007376534, 54.864171164376394, 72.9717742374965, 39.89187669754028, 0.5019216899360929, 0.40164580355797497, 0.4227711228387696, 0.3145916334220341, 0.23703062960079738, 44.29287263325283, 61.44050216674805, 58.77528435843331, 58.31887108939034, 57.167697020939414, 55.76267051696777, 57.155555043901714, 56.13025106702532, 55.39150122233799, 53.59733738218035, 52.09703370503017, 55.97122417177473, 53.24652630942208, 50.55846282414028, 52.33145897729056, 55.36293717793056, 54.57876695905413, 52.57862377166748, 53.26586662020002, 54.90773984364101, 50.15919501440865, 45.47271844318935, 53.89142683574131, 54.89960697719029, 50.732758385794504, 53.26413304465157, 51.22310318265642, 53.093936920166016, 52.503913266318186, 52.477020263671875, 54.00475542885916, 48.296907561165945, 49.60379770823887, 45.740533283778596, 45.598699705941335, 48.22935370036534, 50.68859910964966, 46.50584609167916, 49.39419487544468, 52.14454896109444, 45.427287646702354, 39.254990918295725, 37.26440497807094, 37.91767808369228, 37.14033794403076, 37.58488021578108, 36.774918283735005, 40.81615386690412, 42.82228987557547, 45.28873014450073, 45.13740880148751, 44.62198100771223, 45.26219497408186, 47.90754440852574, 47.0457523890904, 48.07402672086443, 44.87259210859026, 48.052070413317, 46.0863937650408, 49.48674488067627, 50.67130504335676, 51.976736068725586, 50.916402748652864, 47.80729232515608, 46.77622481754848, 51.06902340480259, 51.9983206476484, 52.789043017796104, 49.124413694654194, 53.12644406727382, 50.156933375767295, 49.41576555797032, 46.469201292310444, 48.33303124564034, 45.10703822544643, 50.09957947049822, 45.99608107975551, 46.064975942884175, 45.743687765938894, 45.050486837114605, 44.022219453539165, 40.26238243920462, 37.54284708840506, 39.192578724452424, 38.382404872349326, 38.08297225407192, 36.226045336042134, 40.22591481889997, 40.31229134968349, 44.306814193725586, 49.204780033656526, 46.66443525041853, 51.56650052751814, 46.445174421582905, 49.39435468401228, 43.58675847734724, 43.87194381441389, 46.98907593318394, 44.22436339514596, 41.62501103537423, 47.53162949425833, 52.24086488996233, 52.28844615391323, 54.30661991664341, 52.72474786213466, 54.15070928846087, 43.68551322392055, 44.83480085645403, 40.68108436039516, 47.30777243205479, 44.98040035792759, 45.41075440815517, 51.83780336380005, 50.81868328366961, 50.112009797777446, 53.24288545336042, 48.10157980237688, 43.82854536601475, 55.70318351473127, 54.75447995322091, 58.72240161895752, 54.09207344055176, 57.71823753629412, 59.230203764779226, 68.2003698348999, 56.63996049336025, 62.42367226736886, 54.54186160223824, 61.324675696236746, 8.422647152628217, 0.1635437807334321, 1.175152410353933, 0.9107160227639335, 1.0365876342569078, 6.0781555856977185, 78.57827568054199, 65.78869179316929, 76.98135730198452, 74.44049140385219, 72.21638693128313, 42.380592891148154, 51.711255822862896, 37.899140289851594, 56.37450456619263, 68.33766623905727, 76.8728333881923, 1.4023746805531638, 0.2219811842909881, 0.12199294247797557, 0.19940527927662643, 0.16299728862941265], [0.06092243628310306, 0.05325735865959099, 0.05680564558133483, 0.0904257767168539, 0.11730532401374408, 0.07710670427020107, 0.18340440573436873, 2.231199017592839, 57.04661076409476, 52.31986590794155, 45.153552940913606, 47.6832982472011, 29.265777724129812, 38.88930375235421, 24.97995512826102, 39.65165662765503, 61.98102337973458, 50.69295563016619, 54.247650555201936, 43.42570270810808, 0.9479493562664304, 0.5725014912230628, 0.3240617024047034, 0.15202237825308526, 0.13022722277258122, 23.84978720120021, 63.685527665274485, 52.29517201014927, 51.85519470487322, 49.3988744871957, 56.833874293736045, 53.004694257463726, 53.0726580619812, 46.64613022123064, 47.464985847473145, 49.265809535980225, 53.55737134388515, 47.131239550454275, 51.56556946890694, 49.786101068769185, 51.930950914110454, 52.09738111495972, 50.36492770058768, 48.05324813297817, 53.08344166619437, 47.00481012889317, 50.68475328172956, 50.22882638658796, 52.36124243055071, 51.28131171635219, 49.43086746760777, 49.291646412440706, 47.36253465924944, 48.22588307516915, 52.49691990443638, 48.96198565619332, 48.2904874256679, 43.01144763401577, 39.95383031027657, 41.28857231140137, 45.37784079142979, 43.76467752456665, 43.998157841818674, 42.69923380443028, 45.87377193995884, 41.86593982151577, 36.52576977866036, 34.39016798564366, 34.08140741075788, 33.9608770098005, 35.833593709128245, 33.40132120677403, 34.81079108374459, 34.72914975030081, 38.7613457271031, 40.102382796151296, 40.2847695350647, 39.700332232883994, 41.270124844142366, 44.225221497671946, 43.47529894965035, 43.17071424211775, 42.99429253169468, 42.164319787706646, 43.117682116372244, 45.623963356018066, 47.51721198218209, 47.258356843675884, 44.898561000823975, 44.775918347494944, 43.20915515082223, 44.814876896994456, 47.78294931139265, 45.60880238669259, 45.50239072527204, 42.90477194104876, 40.92972912107195, 40.91559648513794, 43.34143842969622, 40.9353780065264, 42.15912600925991, 39.83510296685355, 41.59239271708897, 38.66933420726231, 39.702315943581716, 35.75693770817348, 35.833131653921946, 32.94996970040457, 32.9810767854963, 32.307716437748496, 32.963529109954834, 33.25135128838675, 34.012884276253835, 33.164043698992046, 38.46149621691023, 45.14382893698556, 42.40795489719936, 43.58736297062465, 44.332539899008616, 44.59183624812535, 40.02531337738037, 41.55476822171892, 43.00560767310006, 38.33125570842198, 40.937236649649485, 41.63243171146938, 43.69190556662423, 46.57776689529419, 45.62375143596104, 44.46435070037842, 48.55144786834717, 53.28157302311489, 61.1530065536499, 55.38485179628645, 46.482989992414204, 73.12878268105644, 41.96189444405692, 37.539181913648335, 44.735101154872346, 47.7393285206386, 50.0991347857884, 41.96975980486189, 55.630390712193076, 57.80335296903338, 50.16290882655552, 48.483299936567036, 49.01909637451172, 56.78546966825213, 48.73452247892107, 52.27530016217913, 49.50009931836809, 53.474750314440044, 47.01278666087559, 43.164262839726035, 1.0586446906839098, 0.19864115385072573, 1.1449782294886452, 0.3717089199594089, 0.13570310893867696, 7.758053694452558, 67.79752022879464, 55.86116470609392, 61.22007751464844, 60.73433589935303, 62.924908365522114, 33.91091251373291, 31.69705663408552, 26.959227664130076, 41.655270440237864, 52.29361908776419, 42.03672306878226, 0.34007018910987036, 0.0539413219583886, 0.050509882159531116, 0.03876112634316087, 0.0645280017384461, 0.051018108281173875, 0.0690213759828891, 0.030860142449715307, 0.055568822127367766, 0.07638910599052906, 0.07771545196218149, 0.22593830552484306, 2.7936218210629056, 65.97175598144531, 58.02010202407837, 50.34126213618687, 39.40813963753836, 35.33712060110909, 41.780115672520225, 26.21848021234785, 48.70299850191389, 65.69528021131242, 53.82562739508492, 59.74036134992327, 48.465641089848106, 1.2476049682923724, 0.7531436351793153, 0.22426028842372553, 0.07123194129339286, 0.11405951103993825, 27.40882475035531, 65.1590599332537, 52.654946259089876, 54.06178624289376, 54.19782502310616, 58.80907344818115, 54.55052947998047, 53.09190804617745, 49.260990960257395, 49.756258555821006, 51.62935740607125, 53.61078562055315, 48.398153236934114, 53.720789500645225, 52.77519178390503, 52.97969463893345, 51.3034347806658, 51.36711849485125, 50.574509688786094, 53.94616821834019, 48.80942753383091, 51.514576639447895, 52.53221327917916, 53.2912449155535, 52.10870667866298, 53.05832392828805, 51.22336721420288, 50.34061942781721, 48.204055309295654, 52.42857394899641, 51.812195777893066, 51.23228522709438, 45.66660097667149, 42.10429082598005, 43.24967009680611, 48.803323541368755, 46.547132287706646, 47.24459593636649, 43.800558022090364, 48.790563174656455, 42.70077977861677, 37.86637258529663, 36.10283987862723, 35.17134353092739, 35.53221212114607, 38.719642639160156, 33.868667466299875, 37.185695784432546, 35.566046374184744, 39.89256109510149, 41.53662300109863, 42.46760170800345, 42.34224578312465, 44.08876582554409, 44.63838570458548, 44.91603224618094, 45.23537145342146, 45.93951579502651, 42.69833401271275, 44.902632645198274, 47.149099894932334, 49.14534861700875, 48.88072647367205, 44.587410245622905, 47.530423981802805, 45.838718278067454, 46.828131335122244, 50.06991761071341, 47.51394632884434, 47.30558374949864, 46.87787001473563, 44.601567200251985, 43.68655892780849, 45.52312067576817, 42.525841508592876, 45.3629264831543, 42.367398262023926, 44.202094418661936, 40.989546162741526, 41.544175692967, 38.649410247802734, 37.43398271288191, 34.63435547692435, 36.839411463056294, 36.092685086386545, 35.01043714795794, 35.85492467880249, 35.47224221910749, 35.45659834997994, 40.33888905388968, 47.38856955936977, 46.59870876584734, 46.06215150015694, 47.40941415514265, 46.40342269624983, 41.556571279253276, 42.86834600993565, 44.14522688729422, 41.487978662763325, 42.33455760138375, 43.44990675789969, 44.525668552943635, 47.40259449822562, 47.749809878213064, 48.90161623273577, 50.74628305435181, 53.98685686928885, 60.287309646606445, 54.40305049078805, 49.62126200539725, 63.088969230651855, 45.71729850769043, 40.49502549852644, 46.00991494315011, 48.002693040030344, 52.26605905805315, 43.49634851728167, 54.54970611844744, 60.37544754573277, 53.869665077754426, 51.90446090698242, 53.268499987465994, 59.36550603594099, 51.94526072910854, 55.700751645224436, 53.597531931740896, 57.97160012381417, 50.25466673714774, 47.95686272212437, 1.3639281264373233, 0.08633928599634341, 1.887900901692254, 0.3790870654795851, 0.22171785842095101, 9.054779495511736, 74.35807882036481, 60.23820672716413, 66.98194067818778, 65.89076777866909, 70.27333014351981, 36.49519770486014, 43.31454195295061, 26.269869089126587, 46.950096539088655, 61.115131923130576, 51.28293759482247, 0.17032949732882635, 0.11057950848979609, 0.08029305043497256, 0.008818032452836633, 0.06256329680659942, 0.12247844785451889, 0.14818507273282322, 0.20023910381964274, 0.17114962903516634, 0.2189541988606964, 0.1988185771874019, 0.2768678276666573, 3.991648461137499, 78.8458160672869, 67.08751855577741, 58.28825037819998, 60.2389988218035, 42.88201659066336, 52.18187468392508, 34.37402384621756, 50.68975945881435, 71.90935298374721, 58.75718430110386, 65.80861227852958, 53.34954030173165, 1.8871502791132246, 1.2880434840917587, 0.7563729190400669, 0.5836403763719967, 0.20229883758085115, 28.911718368530273, 67.98618466513497, 53.71757248469761, 58.09846033368792, 54.795234612056184, 58.528797013419016, 56.4721337045942, 53.765869413103374, 52.31822613307408, 52.06727457046509, 52.63129111698696, 54.162472588675364, 50.10250813620431, 58.88236999511719, 54.198592799050466, 56.125119822365896, 54.0031920841762, 54.27038853509085, 52.76086112431118, 56.92628880909511, 50.07736260550362, 55.83873592104231, 54.692797320229666, 55.55344983509609, 54.5573456627982, 54.66409431185041, 53.24531732286726, 52.34388583047049, 50.48782048906599, 56.76011221749442, 53.345232418605256, 53.38746704374041, 48.313079493386404, 44.70022119794573, 45.39952959333147, 50.205848693847656, 50.71343197141375, 49.74583625793457, 48.87664440699986, 52.34407690593174, 46.36383186067854, 41.75250700541905, 37.816005093710764, 37.99104758671352, 36.73293031964983, 40.97512517656599, 35.21384913580758, 39.470072405678884, 36.89542784009661, 42.2878691809518, 44.6587369782584, 42.756143024989534, 45.028030259268625, 46.02476324353899, 48.908404622759136, 47.72306278773716, 48.53901754106794, 47.52823529924665, 45.81242976869856, 48.24561595916748, 49.6233742577689, 52.80345010757446, 52.62767110552107, 46.30476869855608, 50.82296684810093, 48.88126843316214, 48.987895488739014, 52.51749699456351, 50.66267538070679, 49.60059806278774, 49.180624621255056, 47.216417516980854, 46.72890758514404, 48.891510077885215, 46.047619342803955, 47.896541936056956, 44.30838796070644, 46.37155825751168, 44.00324044908796, 46.866874490465435, 40.740296908787315, 40.220564705984934, 37.19882787976946, 39.10182135445731, 36.88516187667847, 37.10755286897932, 36.97702401024954, 37.5580393246242, 37.458308356148855, 42.91446467808315, 50.3789769581386, 50.52443749564034, 47.08576706477574, 48.075642177036826, 48.443851539066856, 43.91702720097133, 45.293156147003174, 47.52915940965925, 43.43751464571272, 45.087242807660786, 46.42066465105329, 47.286705493927, 49.86616863523211, 51.25667340414864, 48.19613436290196, 53.47002901349749, 58.38903399876186, 59.715007373264854, 51.77752079282488, 47.84668166296822, 71.27961690085274, 47.36876719338553, 44.292980330330984, 47.800833974565776, 49.95454624720982, 51.364321844918386, 43.87726960863386, 54.18387304033552, 56.93512691770281, 55.83875676563808, 55.44717018944876, 56.28339283806937, 64.38707338060651, 55.54176991326468, 60.03126852852957, 54.10576833997454, 59.98533398764474, 54.748313426971436, 53.46104499271938, 2.278782452855791, 0.23188909835049085, 3.379230546099799, 0.7730436559234346, 0.6517010214073318, 9.517276780945913, 80.79594612121582, 66.49362822941372, 73.30234173366001, 71.32830987657819, 73.75861603873116, 46.53561217444283, 47.89775787081037, 36.070516858782085, 58.84470381055559, 67.28277683258057, 64.24690737043107, 0.5759806931018829, 0.25333748172436443, 0.21630082838237286, 0.2279946601816586, 0.15597493973161491], [0.037455987983516285, 0.06511830006326948, 0.060440296440252235, 0.02012631726185126, 0.08360222500881978, 0.10127203006829534, 0.1488652362355164, 1.879719180720193, 52.32072401046753, 56.412413937704905, 47.442115851810996, 53.55822944641113, 29.15880673272269, 45.736176763262065, 54.66383375440325, 46.60240173339844, 57.36169419969831, 56.950086389269146, 50.800260135105674, 56.07183061327253, 3.9769838537488664, 0.779066875576973, 0.27675991345729145, 0.3430126155061381, 0.2747254211987768, 8.842147248131887, 59.16570363725935, 46.36530835287911, 52.240079743521555, 51.875341006687705, 52.120737484523225, 46.61805255072457, 50.48946721213204, 44.16186087472098, 49.06855365208217, 48.58092907496861, 47.9493065561567, 51.180486406598774, 51.884550843920024, 49.780816963740754, 49.63560308728899, 46.633098874773296, 50.32716771534511, 51.5405490057809, 52.6105820110866, 48.73239633015224, 52.31319216319493, 49.296492780957905, 50.549694197518484, 47.393513202667236, 51.55352824074881, 49.67445393971035, 57.25585229056222, 55.70750182015555, 50.074732712336946, 47.88116209847586, 46.883004733494346, 43.07162250791277, 41.20879656927926, 43.83030326025826, 45.55469329016549, 43.26932307652065, 42.80647577558245, 41.25519316537039, 45.74039431980678, 39.41056455884661, 36.43671471732003, 37.08208772114345, 35.71650614057268, 32.08275808606829, 33.62773173195975, 34.03405543736049, 36.60423231124878, 34.37822750636509, 37.41870015008109, 37.96425533294678, 41.632014819553916, 39.137872082846506, 42.23554924556187, 40.37330000741141, 42.74191658837454, 42.70420871462141, 42.4757137298584, 39.381611415318076, 40.52914115360805, 45.286065510341096, 47.96691676548549, 44.72321278708321, 47.28595161437988, 42.94868803024292, 42.85277509689331, 47.62520088468279, 45.27352401188442, 45.20678309031895, 45.67766945702689, 44.119883332933696, 43.0363187108721, 41.95967449460711, 41.808888162885395, 41.32990019662039, 41.9679810660226, 40.45896087374006, 40.1626410484314, 38.45648309162685, 38.068929944719585, 35.79872417449951, 33.46308721814837, 32.089862619127544, 32.53866761071341, 31.911905356815883, 33.52153199059622, 32.205835001809255, 33.35057851246425, 36.22354398454939, 44.65284490585327, 42.98676415852138, 44.17747000285557, 43.7863107408796, 45.84017045157296, 43.706034728458945, 41.89160994121006, 42.73833131790161, 43.68286943435669, 42.23539291109358, 45.193977560315815, 44.693752425057546, 44.39431633268084, 46.50672503880092, 45.275115149361746, 45.46063552583967, 50.31733948843819, 49.665105138506206, 51.754904406411306, 49.65257058824812, 45.75235564368111, 36.30608510971069, 52.98943601335798, 53.74273191179548, 43.388703550611226, 47.58458171572004, 41.32501213891165, 43.10202782494681, 46.80462210518973, 40.855557101113455, 47.088320527757915, 51.552340098789756, 51.39439017432076, 55.873900754111155, 54.17050470624651, 56.935415267944336, 50.710162843976704, 50.00796052387783, 51.52768441608974, 32.25316265651158, 0.17749199084937572, 0.027824597300163338, 2.2922678206648146, 1.2517114622252328, 0.5526820261563573, 8.558423638343811, 71.90576771327427, 52.228931358882356, 64.85527774265834, 60.94485936846052, 66.19416781834194, 40.27898168563843, 36.18108006886074, 30.256087098802837, 36.0306967326573, 57.74741302217756, 30.636751106807164, 0.27696187262024197, 0.03962377844644444, 0.06294518310044493, 0.034980817764465294, 0.04615339217707515, 0.0507356545089611, 0.01853429768899722, 0.04315346333065203, 0.026955899449863603, 0.07505153704966817, 0.08460087927856616, 0.11909349448978901, 2.8392593264579773, 64.87020942143032, 60.04937553405762, 54.153839451926096, 47.4192145892552, 30.84446750368391, 52.09389659336635, 49.70137473515102, 49.876997402736116, 64.27186529976981, 61.21577657972063, 55.27412182944161, 60.85593632289341, 4.401424986975534, 0.9052011072635651, 0.31810774760586874, 1.7850839559520995, 0.11194566411099263, 10.202827743121556, 64.06098052433559, 47.980611664908274, 55.692886284419465, 52.86288152422224, 52.77237776347569, 48.84711456298828, 52.70348637444632, 47.22357416152954, 51.338749000004356, 49.084572723933626, 49.70174993787493, 53.19831623349871, 54.71581670216152, 51.065955775124685, 52.34443473815918, 48.59379366465977, 51.73024524961199, 51.87201281956264, 53.196144921439036, 49.62526764188494, 52.96788270132882, 50.848463262830464, 52.927930559430806, 48.357096331460134, 54.11787905011858, 51.86945588248116, 56.18060466221401, 57.94112185069493, 53.7201954296657, 48.489987577710835, 49.31198378971645, 46.61205278124128, 44.456287315913606, 44.32013736452375, 46.995322363717214, 43.988631861550466, 47.135099274771555, 44.34121125085013, 48.240738323756624, 42.878907271793906, 40.24162469591413, 38.731954847063335, 36.99808052607945, 35.99151931490217, 36.29013204574585, 34.75939873286656, 38.23263645172119, 34.78435318810599, 38.471741335732595, 40.27045624596732, 42.98793840408325, 40.6510021345956, 43.06684214728219, 42.098443916865754, 44.20011418206351, 44.90139239174979, 43.69956942967006, 39.60707351139614, 41.92651769093105, 46.307617459978374, 48.79533658708845, 47.87404366901943, 48.99734851292202, 46.38864735194615, 46.729140349796836, 48.99982554571969, 48.45302316120693, 47.41359002249581, 47.71138981410435, 46.94536828994751, 43.497425488063264, 45.33824300765991, 44.21771396909441, 44.60673666000366, 44.52681500571114, 41.0362936428615, 42.505399908338276, 39.733089515141074, 40.336655208042686, 36.09435265404837, 35.64330339431763, 33.42631040300642, 35.3068334034511, 33.42639378138951, 35.095038414001465, 34.60382856641497, 34.10803985595703, 37.89961971555437, 47.03931835719517, 43.889571394239155, 47.02593960080828, 46.941129888807026, 48.21003076008388, 44.076345920562744, 43.04315226418631, 44.95535557610648, 43.81964472361973, 43.38480561120169, 45.34120988845825, 46.582179001399446, 47.75142880848476, 49.031544072287424, 48.474798815590994, 49.06227248055594, 52.140751770564485, 51.76414203643799, 53.919219630105154, 50.8837879044669, 45.32736907686506, 34.38624225343977, 52.76816020693098, 57.729021140507285, 46.31262016296387, 48.81588588442121, 42.22513736997332, 45.84372445515224, 51.95842061723982, 44.37684856142317, 49.03023086275373, 54.57693263462612, 53.73997695105416, 59.277118001665386, 57.46234927858625, 59.22437422616141, 53.92436129706246, 54.0390864780971, 52.56212527411324, 36.48018959590367, 0.32676938282591955, 0.017918790091893504, 5.050649464130402, 1.2803469427994318, 0.6661522973861013, 9.052921720913478, 77.84499754224504, 57.51882423673357, 68.44220188685826, 66.44681126730782, 71.84677055903843, 42.58261176518032, 42.654664584568565, 28.770973920822144, 42.1728869165693, 65.34762014661516, 40.70445115225655, 0.2640435429556029, 0.03537923317136509, 0.03649106029687183, 0.038821397216192315, 0.08047869761607476, 0.12381616607308388, 0.13207328585641726, 0.16859007280852112, 0.2220350056886673, 0.1460074367267745, 0.224111743537443, 0.17418193418000424, 3.761936673096248, 75.45030089787075, 69.03244440896171, 62.23078332628523, 62.219117300851, 44.65879256384713, 58.56228038242885, 62.43128054482596, 60.06598172869001, 69.00693757193429, 67.94515555245536, 59.66971901484898, 67.46873841966901, 5.524892245020185, 1.225812703371048, 1.463032997080258, 1.9862761029175349, 0.2688814704971654, 12.067184891019549, 69.09066336495536, 51.643535205296104, 57.87010431289673, 51.22724430901663, 55.80297701699393, 48.629093987601145, 55.742305346897666, 49.46178000313895, 52.84625448499407, 50.0053653717041, 53.88922773088728, 55.625982080187114, 55.47029032026018, 52.92828491755894, 53.539083685193745, 49.76245634896414, 52.120376178196494, 56.07174028669085, 54.556442396981375, 51.736613273620605, 56.255005972726, 51.83288056509835, 53.96006808962141, 50.264922278267996, 54.863924503326416, 55.2886574608939, 57.48778315952846, 59.00969573429653, 55.1722160748073, 49.923432213919504, 50.11297559738159, 50.61420127323696, 46.12298992701939, 48.025434494018555, 51.00812244415283, 49.216425214494976, 48.69825635637556, 47.6405668258667, 53.020223481314524, 44.84060607637678, 41.408571175166536, 40.25132090704781, 39.986118589128765, 37.155905382973806, 38.38527447836739, 36.64206525257656, 39.868346623011995, 35.73072910308838, 40.25836290631975, 42.86978776114327, 46.50436612537929, 43.51066528047834, 46.26485129765102, 45.21072619301932, 46.69858912059239, 48.15592166355678, 46.28238507679531, 42.58667993545532, 44.08661535808018, 48.393028940473286, 51.181497369493755, 48.59275838306972, 50.37123319080898, 49.59805849620274, 50.21303660529, 52.69797992706299, 51.56887681143624, 50.96075657435826, 49.40428713389805, 49.566378184727256, 45.69282695225307, 48.007435185568674, 47.72064134052822, 47.970508984157014, 47.10082033702305, 43.70957483564104, 45.73841755730765, 43.820909295763286, 43.55630452292306, 38.941710540226524, 36.75400768007551, 36.170803683144705, 37.7555696623666, 34.46535096849714, 36.68266357694353, 37.38237844194685, 36.78138010842459, 40.79616389955793, 51.04367637634277, 48.818449769701274, 51.062714440482004, 48.491220882960725, 51.377742290496826, 47.64575365611485, 47.33792066574097, 45.98810454777309, 44.58108391080584, 46.925590242658345, 47.155447074345176, 50.03193875721523, 49.30890573774065, 48.39780930110386, 49.64087677001953, 51.589068276541575, 53.622680936540874, 54.9645483153207, 58.33578300476074, 54.56262281962803, 44.91600792748587, 43.49322182791573, 51.73782920837402, 54.20519706181118, 47.682273387908936, 50.013849122183665, 45.18443768365042, 44.604905809674946, 52.62705271584647, 48.280923230307444, 53.55224009922573, 55.9899982043675, 55.54529612404959, 61.399167333330425, 59.79888602665493, 61.04537895747593, 55.84477390561785, 57.10088314328875, 58.15306970051357, 41.98929813929966, 0.9481707215309143, 0.09282942595226423, 10.168527960777283, 2.919403540236609, 0.6710492031914848, 10.10001698562077, 86.23109803880963, 60.823307582310264, 76.56473636627197, 70.22904232570103, 80.06514154161725, 53.784212657383506, 58.19776398794991, 42.03235265186855, 53.46497767312186, 74.19301046643938, 53.00380836214338, 0.3350999743810722, 0.13288063396300587, 0.2681709629084383, 0.11514504493347236, 0.20771383201437338], [0.01963970926590264, 0.018412761889132004, 0.04934766702353954, 0.07286551435078893, 0.012351747835054994, 0.02248913734885199, 0.09863198601773807, 0.8578223181622369, 50.358681270054404, 55.66481556211199, 40.01727431161063, 26.705693108694895, 23.438459055764334, 42.63234002249581, 46.085942132132395, 46.74819925853184, 55.37403692517962, 58.026376247406006, 47.48461103439331, 59.11846283503941, 12.155273284230914, 0.451792445565973, 0.40872191957065035, 0.31430173612066675, 0.08863772837711231, 1.8489566828523363, 49.86036341530936, 45.60244131088257, 57.333123207092285, 45.367845807756694, 52.252221720559255, 44.942209584372385, 46.564513206481934, 43.30773619243077, 50.45287799835205, 48.2496007510594, 50.49653353009905, 51.25319235665457, 53.13036285127912, 47.84423589706421, 52.650888511112754, 46.733031341007774, 48.24328136444092, 51.09640278135027, 50.49517168317522, 48.423270974840435, 47.88390316282, 50.46562794276646, 49.03212077277047, 47.89511408124651, 49.24605580738613, 56.18126474108015, 56.211041246141704, 42.29382726124355, 48.27451351710728, 47.326470034463064, 51.19127695901053, 42.53103528703962, 40.929878507341655, 42.24285875047956, 44.737671988351, 42.03141117095947, 44.01867239815848, 40.85556404931204, 45.57685456957136, 44.49876512799944, 38.406310149601524, 34.841582025800435, 37.30603163582938, 33.75290700367519, 33.857157775333945, 34.69193867274693, 35.53806945255825, 33.82107925415039, 35.85678332192557, 37.005546365465435, 38.05720138549805, 38.465522697993684, 39.94768810272217, 42.58724621364048, 45.93151494434902, 40.191212041037424, 42.38740907396589, 41.19080768312727, 44.22711140768868, 45.37281376974923, 46.63980041231428, 45.64120531082153, 48.3178459576198, 42.57461091450283, 44.11328949247088, 43.710683073316304, 46.69346482413155, 45.64493301936558, 44.11407811301095, 39.79203803198678, 42.752807889665874, 42.55673667362758, 40.69882311139788, 40.594280515398296, 42.50966262817383, 39.97968108313424, 39.89540638242449, 39.083794253213064, 37.91939776284354, 36.352572032383506, 33.248853410993306, 34.63020045416695, 34.71598291397095, 34.29532160077776, 33.772768429347444, 31.97999770300729, 33.343505246298655, 38.026268005371094, 44.872029304504395, 43.081360408238, 44.73042849131993, 43.08272572926113, 45.87066956928798, 41.37430613381522, 41.75229855946132, 39.17030279976981, 44.16487291881016, 44.3948061806815, 47.894405364990234, 47.15528726577759, 47.54479285648891, 52.36423363004412, 48.781527042388916, 46.915779386247905, 48.922870772225515, 50.32620538984026, 53.53063120160784, 49.99357427869524, 43.34564903804234, 27.997531720570155, 47.564518792288645, 59.03126989092146, 56.65678208214896, 50.365834440503804, 42.439155782972065, 44.874780791146414, 42.54250676291329, 51.369387081691194, 51.421929359436035, 52.23884643827166, 53.364079407283235, 56.22902318409511, 54.2657401902335, 55.162620612553184, 53.97850513458252, 51.8333808353969, 51.43350158418928, 26.13819030353001, 0.2741672040096351, 0.24341713690332004, 2.5946377898965562, 0.875536533338683, 0.8014028913208416, 12.702644552503314, 70.05706746237618, 54.153940200805664, 59.91706098828997, 59.206079619271414, 63.998634338378906, 44.41475098473685, 35.89458499635969, 22.041323968342372, 38.72408601215908, 58.83846432822091, 20.064559732164653, 0.4640366371188845, 0.20849188097885676, 0.108683885208198, 0.019900977478495667, 0.06691770029387303, 0.06288691729839359, 0.0903588053105133, 0.02546937171635883, 0.056074228936008046, 0.014685553764658315, 0.047456766345671246, 0.1326429702873741, 1.1060849279165268, 60.03736904689244, 60.80052443913051, 48.471592221941265, 34.34790209361485, 30.561130387442454, 50.18282583781651, 52.55749429975237, 51.817177636282786, 60.99220439365932, 63.20933287484305, 52.7879695211138, 65.19854654584611, 12.283625619752065, 0.48994250702006475, 0.4189119413495064, 0.9970669320651463, 0.0741074505661215, 1.8655934929847717, 55.62177494594029, 47.03237015860421, 59.05664471217564, 45.10961948122297, 53.389721734183176, 46.57680804388863, 49.046051910945344, 44.633011272975374, 52.72202416828701, 51.21521350315639, 53.987513474055696, 52.755326884133474, 55.78996304103306, 48.42590781620571, 55.50407941000802, 47.16572346006121, 49.1427013533456, 52.48862722941807, 51.78362825938633, 50.360310622623985, 51.81189700535366, 52.09957674571446, 52.301647731236045, 49.420900276729036, 50.43045268739973, 53.57505103519985, 59.049376896449495, 45.25119597571236, 47.631294454847065, 48.96184321812221, 51.60045984813145, 43.9537866456168, 42.184111731392996, 42.49502624784197, 46.93651281084333, 44.602022307259695, 47.68419109072004, 43.0803668158395, 47.65868077959333, 45.99467754364014, 40.46407127380371, 36.08092526027134, 38.849820613861084, 34.08465221949986, 36.708792277744834, 35.86341537748064, 37.88595955712454, 36.31463834217617, 37.94178138460432, 38.70404393332345, 40.36163050787789, 38.938601221357075, 40.631599290030344, 43.42152336665562, 47.1588134765625, 43.75413015910557, 43.905785015651155, 44.07365001950945, 46.01850291660854, 46.84103413990566, 49.28685562951224, 47.228688035692485, 47.83926446097237, 46.49665709904262, 45.46859816142491, 45.978425707135884, 48.25940465927124, 47.64176539012364, 47.43810674122402, 41.886895588466096, 45.300496918814524, 44.392641816820415, 44.20440469469343, 42.674029214041575, 45.00731420516968, 42.118829931531636, 42.22181960514614, 40.65043238231114, 39.767333711896626, 38.48851081303188, 35.89712108884539, 36.55184636797224, 36.66177729197911, 35.70303010940552, 35.51788146155221, 34.51830318995884, 36.33368682861328, 39.3507753099714, 48.21478680201939, 45.443376200539724, 46.98762723377773, 45.22252076012747, 48.34816442217146, 42.742871965680806, 43.51889194761004, 41.035654408591135, 46.11885574885777, 45.34751885277884, 49.62777246747698, 47.89309562955584, 51.529324190957205, 53.26317071914673, 51.049936703273225, 49.73431614467076, 51.10920831135341, 53.11515324456351, 55.106163024902344, 52.584845883505686, 43.801951135907856, 32.91684068952288, 47.96902206965855, 55.973871435437886, 57.75189808436802, 53.03810814448765, 47.67288637161255, 47.99787793840681, 45.75045531136649, 54.19199548448835, 55.07103293282645, 56.23378964832851, 56.82022108350481, 58.71524497440883, 57.42543002537319, 56.72687898363386, 58.65951347351074, 54.748396805354524, 55.37104572568621, 29.167311327798025, 0.20460209756025247, 0.34255799704364365, 3.359887412616185, 1.3989849367312022, 0.6337786859699658, 14.254133003098623, 76.39212226867676, 59.93241650717599, 67.35906110491071, 65.35237966264997, 73.41636862073625, 50.24546732221331, 41.97224031175886, 20.76276683807373, 43.34285238810948, 67.72840649741036, 28.78225953238351, 0.463135054068906, 0.07327216038746492, 0.09940480347722769, 0.05002110963687301, 0.03975810802408627, 0.1626240536570549, 0.23913308392677987, 0.27792598945753916, 0.13551037785198006, 0.13341044767626695, 0.1554788492087807, 0.265592774110181, 1.8914942060198103, 71.38980838230678, 69.45834118979317, 54.992962973458425, 35.2969183240618, 37.25272853033883, 56.41924401691982, 54.747205189296174, 59.859689712524414, 65.34033843449184, 69.61776760646275, 56.14151062284197, 72.90477275848389, 13.439636502947126, 0.6389199729476656, 0.7664457985333034, 1.5751704084021705, 0.1939672553645713, 2.3995343276432584, 65.26779924120221, 51.14228173664638, 59.99234472002302, 47.10510042735508, 55.86268636158535, 48.38118921007429, 52.481984751565115, 45.20999663216727, 55.81224591391427, 50.35763209206717, 54.74405418123518, 57.37902648108346, 59.128905977521626, 52.20171526500157, 57.75410761151995, 49.02785110473633, 51.152443477085654, 55.108949252537315, 54.189657415662495, 52.07122809546334, 54.37979487010411, 55.02021728243147, 53.26075969423567, 50.65088776179722, 53.14253262111119, 52.30753285544259, 61.12373379298619, 49.50937516348702, 50.97225931712559, 50.17804200308663, 55.18657452719552, 46.50808688572475, 45.29411847250802, 46.30639110292707, 50.096101897103445, 45.77125126974923, 51.08784260068621, 46.060754912240164, 51.7661326953343, 49.13715321677071, 43.74484389168875, 39.61765909194946, 42.28014278411865, 36.850045680999756, 39.590331826891216, 38.12070792061942, 41.05629750660488, 37.206696714673726, 40.39754922049386, 40.81800208772932, 41.55337163380214, 41.51060199737549, 43.07050384793963, 45.419870444706504, 50.206540039607454, 45.55540200642177, 46.2191286768232, 46.200302532741, 48.07800803865705, 51.848229135785786, 52.174332414354595, 48.63800157819475, 49.51982178006853, 51.62813104901995, 49.12830121176583, 49.45324761526925, 52.93734189442226, 49.72197266987392, 48.4345201083592, 45.510273456573486, 48.31235688073294, 46.349216324942454, 46.67342274529593, 45.066068172454834, 46.72472129549299, 45.076240335192, 44.86408403941563, 43.506739548274446, 43.4744999068124, 39.75756801877703, 37.44214684622628, 38.52940443583897, 38.96865218026297, 38.6700325012207, 38.85997888020107, 35.830678939819336, 37.764178480420796, 42.680828026362825, 50.64531530652727, 48.14466210774013, 51.394504819597515, 49.29723276410784, 51.08906200953892, 44.44285297393799, 46.12372991016933, 42.98874092102051, 50.196388721466064, 48.25326245171683, 52.782518659319194, 50.61410052435738, 51.73033905029297, 53.867340905325754, 52.53358554840088, 50.79910673413958, 53.066453320639475, 56.338151591164724, 56.13931499208723, 53.30213621684483, 45.629681723458425, 34.39656727654593, 50.78824322564261, 56.43732670375279, 57.63836451939174, 53.427519934517996, 50.45959690638951, 51.97445011138916, 50.53532184873308, 57.67862933022635, 56.60170371191842, 59.49123368944441, 58.931452069963726, 61.825765882219585, 57.95564011165074, 59.69388484954834, 59.269356863839285, 58.84201485770089, 57.809012276785715, 35.908884389059885, 0.4654475014124598, 0.7119688274604934, 9.455524665968758, 1.519008879150663, 1.06722625877176, 15.74647317613874, 81.85966668810163, 64.06091799054826, 72.49975531441825, 71.14605167933873, 76.18392644609723, 60.67949376787458, 50.89819846834455, 31.095182827540807, 56.906156403677805, 77.79198278699602, 38.741303648267476, 0.6274996857557977, 0.32672736793756485, 0.3272234856017998, 0.2567669062742165, 0.12668958545795508], [0.06293080494339977, 0.004516327387786337, 0.04801038646006158, 0.01895233123962368, 0.05438235954248479, 0.04513938265985676, 0.12267044612339564, 0.9935676455497742, 49.63077756336757, 54.20385258538382, 40.66994987215315, 27.51880952290126, 23.525361912591116, 45.32407215663365, 48.11714029312134, 55.0528564453125, 53.43014635358538, 58.2668707711356, 49.37749835423061, 58.30257756369454, 18.457625525338308, 0.29210609570145607, 0.5896155014634132, 2.255583720547812, 0.1873272880911827, 0.08660109194793872, 32.21713277271816, 48.55301816122872, 51.15101214817592, 43.523957184382844, 48.48451934541975, 42.4614907673427, 48.18905414853777, 43.593015330178396, 52.22765289034162, 48.76948928833008, 51.280523095812114, 52.69733027049473, 54.18813228607178, 49.84998280661446, 51.53030041285923, 48.17663771765572, 48.70798036030361, 49.96068498066494, 51.468398911612375, 44.519828592027935, 47.43531356539045, 48.55589124134609, 52.30402054105486, 46.54737547465733, 52.398224217551096, 49.34202432632446, 37.398522581372944, 46.81907088415963, 48.6802396774292, 49.06883158002581, 46.78015749795096, 41.454398018973215, 40.408739294324604, 41.77408811024257, 44.317041942051475, 42.8394831929888, 42.634573868342805, 43.453624044145855, 43.3999457359314, 45.109032358442036, 40.06338255746024, 34.72614812850952, 38.074623993464876, 35.64512382234846, 36.60949557168143, 34.16070372717721, 36.03728015082223, 34.97525494439261, 36.68050616128104, 37.579561369759695, 37.951449802943635, 37.359060287475586, 42.08705929347447, 41.08193288530622, 41.81283473968506, 40.854931763240266, 40.226686068943565, 41.68740585872105, 45.05981131962368, 48.185541834150044, 46.52398436410086, 44.786868708474294, 37.5573445047651, 41.84512301853725, 43.25371394838606, 44.91948550088065, 46.1084577696664, 43.038886070251465, 41.02256747654506, 40.112131118774414, 41.752058846609934, 42.22471352985927, 43.74937411717006, 39.92886195863996, 40.56796768733433, 37.827480043683735, 38.991570813315256, 38.45188685825893, 36.713228702545166, 33.40089041846139, 33.66890328271048, 34.12998921530587, 35.17924015862601, 32.76666579927717, 36.47182049070086, 34.509909766060964, 34.47385556357247, 39.95894071034023, 42.59076547622681, 44.079767908368794, 44.16510220936367, 43.43120220729283, 44.13205657686506, 41.249457427433555, 38.58254425866263, 41.88057620184762, 44.35069554192679, 50.07194301060268, 47.29281990868704, 50.4258599281311, 47.3825489452907, 54.53324931008475, 51.018450941358296, 49.65652411324637, 51.153430121285574, 49.2097167287554, 50.05173764910017, 49.97599186216082, 50.54452126366751, 58.31695338657924, 53.6479480607169, 49.188590730939595, 51.04782445090157, 51.27313368661063, 50.54350682667324, 48.91153131212507, 51.10415697097778, 47.5123621395656, 51.0030711037772, 52.952548027038574, 52.233468532562256, 52.77825246538435, 53.23454066685268, 56.02711200714111, 53.78013406481062, 51.50198302950178, 55.07225234167916, 18.76078585215977, 0.46815838451896397, 0.3391536511480808, 4.112837638173785, 0.9865434510367257, 0.4840851756078856, 20.07593219620841, 68.57961641039167, 55.56214203153338, 59.62408324650356, 60.351253918239046, 57.31887592588152, 36.2877905028207, 38.64368840626308, 30.18610484259469, 40.44203158787319, 59.47390488215855, 21.98679624285017, 0.5724835778985704, 0.04494559305853077, 0.17827895576400415, 0.043844306974538734, 0.06539492521967206, 0.03291827826095479, 0.06435468353863273, 0.07814118518893208, 0.070996822124081, 0.1040406497195363, 0.03202127871502723, 0.13155149242707662, 1.333196895463126, 60.33585671016148, 59.39103371756417, 47.2888629095895, 27.442909138543264, 27.825926848820277, 54.111184460776194, 48.646328994206016, 58.68402671813965, 60.033929688589915, 63.93872697012765, 51.88168471200125, 64.09429018838065, 19.72240264075143, 0.2428088981126036, 1.0134670691830772, 1.3880558546100343, 0.10992670351905481, 0.07304654749376432, 37.098106792994905, 51.40329776491438, 51.5893531526838, 47.0595827783857, 50.7332239151001, 45.8380686214992, 51.73166615622384, 45.85829482759748, 53.65428829193115, 49.96851907457624, 54.835238865443635, 53.052560397556846, 54.96213729040963, 50.8312143598284, 53.869407994406565, 48.40067890712193, 47.97219392231533, 53.12709024974278, 53.427707535879954, 47.53660787854876, 48.8077460697719, 50.113500186375205, 53.47634492601667, 49.77353177751814, 50.55839334215437, 51.55509505953108, 39.241775444575715, 48.11183534349714, 50.822258131844656, 49.03896822248186, 47.562597615378245, 43.425935472760884, 42.34964214052473, 44.24334239959717, 48.06107875279018, 44.86125264848982, 45.42168392453875, 46.65361343111311, 46.091188022068565, 46.760431562151226, 42.01423869814192, 38.534546102796284, 38.93376874923706, 36.651031902858186, 38.695254462105886, 35.66777842385428, 37.389319692339214, 36.94244977406093, 38.15511540004185, 37.50970418112618, 39.81405687332153, 38.527538844517295, 43.67250272205898, 43.41962998253958, 44.13062872205462, 42.937484060014995, 42.47837141581944, 43.67069966452462, 45.13987193788801, 51.31575393676758, 50.09719623838152, 45.65313189370291, 41.73511566434588, 44.0414833341326, 47.94654812131609, 46.515952246529714, 49.054292474474224, 47.5369622366769, 43.465331758771626, 41.680072035108296, 45.6947238104684, 45.17656537464687, 45.41485037122454, 42.45074190412249, 43.13442727497646, 41.393549169812886, 39.64373915536063, 40.55257395335606, 38.12135757718767, 36.364585467747276, 35.439022881644114, 36.177904742104666, 35.88347830091204, 33.683751583099365, 37.63118301119123, 34.78532246180943, 37.44143812997, 42.291885239737375, 45.49239921569824, 45.25446162905012, 46.68857676642281, 46.12310804639544, 47.84306512560163, 44.168736117226736, 40.40624836512974, 44.59173897334507, 45.782278060913086, 50.48323467799595, 51.72005919047764, 51.48883008956909, 49.12070683070591, 55.776639870234895, 51.49490281513759, 50.92222881317139, 53.02634137017386, 52.44528089250837, 51.22637231009347, 50.14547232219151, 51.58122376033238, 58.218657221112935, 56.32425519398281, 53.069041524614605, 52.60318912778582, 54.12934010369437, 50.80397047315325, 49.19779709407261, 51.99658359800066, 51.906701701028005, 53.808326380593435, 54.365273135049, 55.83895826339722, 54.27973733629499, 55.839121546064106, 58.61176545279366, 58.014369760240825, 55.61269017628261, 58.1953182220459, 22.427049739020212, 0.5203852249043328, 0.5580010350261415, 4.94789776631764, 1.6161948527608598, 0.5230778689895357, 22.36826797894069, 74.46115534646171, 61.9415020261492, 64.22465229034424, 67.18579387664795, 63.974579674857004, 43.82110037122454, 39.08915826252529, 20.80788322857448, 45.93995005743844, 67.31334890638078, 28.18138974053519, 0.5949695770229612, 0.10525785333343915, 0.13952668091016157, 0.06823050270655326, 0.07706765457987785, 0.1460197860641139, 0.1323034313640424, 0.16108509552265915, 0.1573673885847841, 0.2128699246261801, 0.11745293252170086, 0.21887874576662267, 1.9603350034781863, 70.84087290082658, 69.46825626918248, 55.088806424822124, 37.60048239571707, 33.73125989096505, 60.21918255942208, 56.31076526641846, 68.07252992902482, 65.60369600568498, 69.4896775654384, 57.52054738998413, 72.33950901031494, 21.67642194884164, 0.31056186822908266, 1.557264574936458, 4.664291841643197, 0.3778479519699301, 0.15882646957678453, 43.430000168936594, 56.53426797049386, 54.68594639641898, 48.98674556187221, 54.255547182900564, 48.08638409205845, 52.25540052141462, 44.947017737797324, 55.79351704461234, 51.14000620160784, 55.27100208827427, 56.36661836079189, 57.5005122593471, 52.74665553229195, 54.33873101643154, 51.734160559517996, 51.60678965704781, 55.005497523716514, 56.87542799540928, 49.81626667295183, 51.12546362195696, 52.93771709714617, 55.58515099116734, 51.91994496754238, 52.85479729516165, 54.5263705934797, 45.554665497371126, 48.67876665932791, 52.60152850832258, 51.69016456604004, 54.32297945022583, 46.18392562866211, 45.77297789709908, 46.144046442849294, 49.80142879486084, 49.07193742479597, 48.697127274104524, 50.56979881014143, 49.566694327763145, 49.85288715362549, 44.721020630427766, 38.529314109257285, 42.320216519492014, 37.93402719497681, 39.551460129874094, 38.91943114144461, 39.42158440181187, 37.49920197895595, 40.34011888504028, 40.983275413513184, 41.7503148487636, 40.47430944442749, 44.72649928501674, 46.072511264256065, 46.8779672895159, 44.639806611197336, 45.503978388650076, 45.4104243687221, 48.6617922101702, 53.4211414882115, 52.6629957471575, 47.463905402592246, 43.14257056372506, 47.98264748709542, 48.49976716722761, 48.746323994227815, 50.22116599764143, 49.04897362845284, 44.27883727209908, 43.72522565296718, 47.6467924118042, 48.168400628226145, 49.7830924987793, 44.367312158857075, 46.14552640914917, 43.9490236554827, 43.08155843189785, 42.835901396615164, 40.133541992732454, 38.5064823286874, 37.651447432381765, 37.34299952643258, 38.241634368896484, 37.02983031954084, 40.74403156552996, 37.445343017578125, 40.14017404828753, 44.87759133747646, 48.8232718195234, 49.66711664199829, 50.944247654506135, 48.41434601375035, 50.23413133621216, 44.845164094652446, 42.65648848669869, 46.147159235818044, 47.65177427019392, 53.83966623033796, 50.76110356194632, 54.234612260546, 51.482649666922434, 56.73202065059117, 52.540829045431956, 53.13287115097046, 54.354169913700645, 52.53211947849819, 53.20836680276053, 52.87225464412144, 53.41712890352522, 60.803817885262625, 56.23509243556431, 55.1888986996242, 56.615544523511616, 55.32726860046387, 52.128908566066194, 50.58961507252285, 53.32605191639492, 53.52427012579781, 55.16247122628348, 55.89733355385916, 58.18935319355556, 55.07418046678816, 56.69023071016584, 61.0148138318743, 60.87711443219866, 58.77607645307268, 64.04631982530866, 25.68481339727129, 0.5692255784358297, 1.6524354623896735, 9.885663322040013, 1.72627711721829, 0.6234765159232276, 23.448226485933574, 81.83614008767265, 65.86453138078961, 72.16496331351144, 71.90909590039934, 67.3872013092041, 49.91529239927019, 56.67015389033726, 40.72896439688546, 58.10927520479475, 80.80612523215157, 37.87064920152937, 0.594713525048324, 0.21971242103193486, 0.2570848677839552, 0.13829604908823967, 0.12973191935036862], [0.046693869068154266, 0.07956589838223797, 0.06364271031426531, 0.026388252320300256, 0.005226266703435353, 0.05822189405028309, 0.05858714945082154, 0.4615109126482691, 43.99215807233538, 57.71813678741455, 37.592679568699424, 35.92603601728167, 50.90092216219221, 41.96507324491228, 43.94395841870989, 54.17625781467983, 56.31070968082973, 58.38512911115374, 51.16765308380127, 54.74553762163435, 24.462965726852417, 0.16812702694109508, 0.8749373597758157, 0.6214091554284096, 0.18177274614572525, 0.2253901306539774, 16.34918597766331, 48.855949197496685, 44.63323361533028, 44.17140422548567, 43.79546499252319, 48.74386085782732, 46.82984059197562, 49.50541121619088, 50.55053492954799, 51.390766688755576, 54.28099148614066, 51.12105846405029, 51.44759600503104, 51.457500662122456, 51.487905979156494, 49.15521853310721, 46.59585305622646, 51.196488107953755, 48.639332158224924, 45.86282505307879, 42.99112415313721, 48.421513080596924, 48.09589270183018, 48.558733054569785, 47.129155090876985, 35.77476678575788, 48.32849407196045, 52.399335929325645, 46.58758469990322, 47.74690900530134, 41.53666469029018, 41.177050249917166, 39.777047293526785, 41.71406957081386, 44.41672774723598, 42.58973714283535, 42.98157385417393, 41.75764519827706, 44.123082978384836, 42.39887012754168, 44.915597983769004, 37.250463417598176, 35.51245491845267, 34.17085157121931, 36.18321663992745, 35.44528668267386, 35.59922749655587, 33.09310606547764, 36.83894593375069, 35.87534196036202, 37.74484164374215, 38.860934257507324, 41.120266096932546, 41.06677886417934, 42.9620737348284, 40.20173856190273, 40.36222457885742, 43.39583240236555, 48.991053444998606, 46.05391788482666, 48.92785957881382, 41.33441652570452, 35.83622012819563, 40.52503824234009, 40.93742077691214, 42.220384802137104, 45.41398879459926, 46.60290200369698, 45.42044019699097, 41.483441489083425, 40.60525866917202, 41.162601470947266, 44.15665667397635, 40.226772921425955, 41.94090393611363, 38.831487791878835, 39.23590769086565, 37.319914136614116, 35.78026628494263, 34.73034136635916, 33.687437602451865, 32.78910500662667, 34.20138195582798, 34.93707111903599, 36.35468775885445, 35.38064064298357, 37.74496671131679, 41.60346119744437, 44.63029105322701, 43.987089361463276, 42.17708362851824, 44.31272711072649, 44.9840863772801, 43.69778721673148, 38.93323721204485, 42.83421645845686, 45.75046225956508, 46.96275963102068, 47.90723521368844, 48.228512968335835, 46.572857992989675, 51.152005740574424, 48.139423166002544, 49.06817150115967, 50.6733478137425, 51.43427630833217, 51.58048725128174, 51.277848039354595, 51.08640432357788, 48.8006762777056, 50.24158327920096, 53.90293652670724, 52.91200876235962, 52.80950893674578, 52.39033801215035, 51.950864451272146, 46.68035704748971, 50.9861626625061, 50.02794006892613, 51.60376371656145, 49.67198732921055, 50.997550759996685, 53.73824684960501, 53.85222509929112, 56.305592332567485, 51.32079485484532, 56.88038900920323, 16.538493122373307, 0.5346357088003839, 0.4303257146051952, 2.229662597179413, 2.176529939685549, 0.3807674710239683, 30.22289902823312, 63.271859713963096, 56.845804350716726, 60.89827169690813, 63.89780902862549, 52.761243275233674, 37.550875731876914, 38.30210106713431, 36.82839856828962, 42.44108738218035, 52.06099339893886, 11.924012916428701, 0.6204675659537315, 0.208004285714456, 0.09854925902826445, 0.08337061386555433, 0.12006043403276376, 0.059527890756726265, 0.029635603872260878, 0.01919195588145937, 0.05161949726087706, 0.047266651011471233, 0.029398269286113124, 0.056403650902211666, 0.6015849677579743, 54.03008508682251, 65.42175047738212, 43.11277321406773, 37.373755727495464, 50.14173766544887, 49.310639313289094, 52.27632849557059, 64.09372043609619, 62.15062195914132, 62.99243790762765, 56.66062791006905, 61.45466259547642, 25.567449637821742, 0.21067153901926108, 1.707113008413996, 1.1345954494816917, 0.03721915212060724, 0.1579007442508425, 19.373618704932078, 52.79982662200928, 45.850853306906565, 47.25096048627581, 47.69563824789864, 53.26199994768415, 47.9632967540196, 49.992486885615754, 50.160862582070486, 52.31291423525129, 56.99348831176758, 52.42140340805054, 53.348379952566965, 53.65965230124337, 55.112235750470845, 53.00023003986904, 48.03847973687308, 52.666883264269146, 50.50132778712681, 46.23146172932216, 46.05936527252197, 49.65774004799979, 50.62596109935215, 50.087750162397114, 48.91218444279262, 38.2401578766959, 49.402112347739084, 55.979502950395855, 48.55070093699864, 49.77062395640782, 44.30330187933785, 43.30939333779471, 42.500595229012625, 44.477295194353374, 46.95394584110805, 45.33711392538888, 46.95117698396955, 44.068525723048616, 47.414152826581685, 45.32455505643572, 46.11066729681832, 38.04246425628662, 37.52718932288033, 35.89079475402832, 37.0320120538984, 35.619109766823904, 36.023963928222656, 35.094659737178254, 36.53539650780814, 37.56095061983381, 39.65399122238159, 41.51802614756993, 42.33407817568098, 44.1108854157584, 43.91309104646955, 42.64591332844326, 42.84802252905709, 45.10225091661726, 49.65790333066668, 49.20644760131836, 49.0827488218035, 43.74394409997122, 40.16115760803223, 42.34254455566406, 41.913100719451904, 44.19717856815883, 47.85580464771816, 47.903879233769004, 47.792506558554514, 43.64488710675921, 44.3888133593968, 44.367308684757774, 44.616926193237305, 42.063022000449045, 44.72563076019287, 40.797623021262034, 39.8837889943804, 38.43141399111067, 38.625897543770925, 36.644469329289024, 36.87085206168038, 34.49510315486363, 36.18139968599592, 35.39285905020577, 38.357391357421875, 37.29938220977783, 39.67532219205584, 44.4540638923645, 47.83705145972115, 46.29878282546997, 45.17205251966204, 46.73763452257429, 46.67824479511806, 44.25339991705758, 42.041593755994526, 44.374121393476216, 48.50020490373884, 49.01637962886265, 48.546455587659565, 50.3921993800572, 49.32362897055489, 52.868176051548545, 46.92948470796858, 48.79379408700125, 52.913846560886924, 52.73251247406006, 51.92612191608974, 52.5682327406747, 51.566882678440635, 50.89709717886788, 51.08955533163888, 56.313756465911865, 55.09202691486904, 54.07392821993147, 55.68045595714024, 53.79263039997646, 47.68423972811018, 51.24274921417236, 52.9958735193525, 54.12149558748518, 52.329954692295615, 53.8127350125994, 55.30856057575771, 56.97347402572632, 59.663034847804475, 54.704442501068115, 61.738892555236816, 19.37201714515686, 0.6591775002224105, 1.1925720870494843, 3.9575983796800887, 3.371555826493672, 0.4100209070103509, 31.96819966179984, 69.87070287976945, 61.86040265219552, 64.97300801958356, 69.3143675667899, 58.337130955287385, 45.36698423113142, 48.63395772661482, 34.04309504372733, 46.6099648475647, 64.58802223205566, 16.715614863804408, 0.6707488564508302, 0.3171740562788078, 0.09622630117727177, 0.07915435332272734, 0.0505153138323554, 0.2088244581328971, 0.12743154993014677, 0.14592274198574678, 0.1818635884140219, 0.17299417220056057, 0.11829994778547968, 0.13837572267012938, 0.6787944904395512, 64.77377537318638, 74.00673621041435, 52.34030403409685, 45.31439331599644, 61.819832120622905, 57.06311968394688, 54.838111945560996, 65.7876078741891, 67.30712332044328, 68.74792957305908, 61.137873377118794, 66.11974566323417, 30.280197347913468, 0.2906967784677233, 2.015625945159367, 2.7112680801323483, 0.48799608860697063, 0.3543311224452087, 22.422342334474834, 58.8285561970302, 51.43764965874808, 51.71622725895473, 51.15350655147007, 54.47381789343697, 51.26028994151524, 50.28768457685198, 50.6574399130685, 53.6030626978193, 57.10350261415754, 55.21732030596052, 56.214275632585796, 56.29452385221209, 56.19226026535034, 54.147346360342844, 49.86730119160244, 54.073994227818076, 55.05872767312186, 49.28617123195103, 48.28365387235369, 52.36188861301967, 54.048945971897666, 51.95409536361694, 51.96461146218436, 43.32328626087734, 49.774963106427876, 57.973156520298545, 51.69076211111886, 51.533295086451936, 45.40951762880598, 45.156776905059814, 44.78729254858834, 46.74063614436558, 49.4029426574707, 48.944952147347585, 49.965579986572266, 47.060458251408164, 51.23579406738281, 48.769965239933555, 49.6886317389352, 42.07921130316598, 38.9332789012364, 37.468727179935996, 39.89583369663784, 37.84314823150635, 39.524542808532715, 36.74791758401053, 39.368500164576936, 39.268477371760774, 42.400909423828125, 42.91187647410801, 44.99548142296927, 44.69302633830479, 47.07722078050886, 44.300501755305696, 44.868478775024414, 48.521431650434224, 50.769382340567454, 52.29831954411098, 52.32847820009504, 48.0174822807312, 43.69733558382307, 50.02188123975481, 46.310945647103445, 47.224717140197754, 50.734446798052105, 51.20869609287807, 51.035797119140625, 45.54467051369803, 46.63492972510201, 44.70174632753645, 48.75870221001761, 45.32014642442976, 47.61044985907418, 43.49203716005598, 43.19464731216431, 39.48987477166312, 40.93036140714373, 39.5263979775565, 39.50353145599365, 37.10455124718802, 37.76174313681466, 38.718319007328574, 40.58002281188965, 41.361253942762104, 41.82767261777605, 46.789502825055806, 50.67973320824759, 50.051706382206504, 47.78096907479422, 50.20754405430385, 49.843270846775596, 47.807264532361714, 42.781201703207834, 46.610656193324495, 51.19290631158011, 50.04396261487688, 53.957518100738525, 51.7426894732884, 51.48862164361136, 52.33009365626744, 48.79465218952724, 51.72043786730085, 54.14259031840733, 55.67109325953892, 52.940131596156526, 55.80052777699062, 53.73958090373448, 52.8539913041251, 54.60056693213326, 57.93546254294259, 56.660252707345144, 55.759318011147634, 58.150158405303955, 56.31842565536499, 49.49834837232317, 53.80579376220703, 55.12288039071219, 57.71760177612305, 54.22334228243147, 55.28632634026663, 58.13708536965506, 60.773718288966585, 62.40640599387032, 59.41590826851981, 63.40798882075718, 22.175095898764475, 0.8769719877413341, 1.5324070687804903, 6.1907572235379895, 4.133467274052756, 0.5403117356555802, 34.67914703914097, 75.78572518484933, 66.67321137019566, 71.51160335540771, 73.69169098990304, 64.98030362810407, 53.58017185756138, 54.234254428318565, 51.72941146578108, 55.828751359667095, 73.51928533826555, 24.570683649608068, 0.7759326409016336, 0.4975973048380443, 0.1593900064804724, 0.170527168150459, 0.29488173819014], [0.01867143640161625, 0.03865270662520613, 0.005570630010749612, 0.07037824245968036, 0.007504529452749661, 0.023396818732310618, 0.04743056810860123, 0.19571147034210817, 43.890669209616526, 54.68409122739519, 38.04076542173113, 45.420745917728965, 89.39893463679722, 52.018849100385395, 32.46278633390154, 52.42463084629604, 58.2248272214617, 53.47091143471854, 53.19398750577654, 54.591926847185405, 36.15392303466797, 0.03017963967951281, 0.44413023814558983, 0.12443740559475762, 0.16484633726733072, 0.06257525259362799, 6.7977058206285745, 45.76244790213448, 43.57001679284232, 44.31842810767037, 44.85321705681937, 49.548750604902, 49.581907408578054, 51.155490262167795, 47.57534408569336, 50.24698550360543, 56.17266634532383, 52.57569510596139, 52.41778687068394, 49.85361671447754, 50.486813000270296, 48.80240985325405, 47.92247608729771, 53.123015131269185, 46.88151087079729, 41.284153257097515, 41.16902508054461, 45.820041520254954, 47.687734672001426, 50.96294525691441, 40.48524243491036, 48.73207671301705, 51.87241581508091, 47.830363818577354, 48.685621057237896, 44.42236621039254, 41.50650256020682, 43.17900344303676, 40.206234046391074, 43.10213899612427, 46.11219590050833, 43.24794694355556, 41.90778882162911, 43.92295054027012, 45.42317083903721, 44.82848146983555, 44.21046004976545, 40.2005295753479, 34.708367688315256, 35.22311108452933, 35.56104367119925, 36.145883968898225, 34.539752279009136, 34.35612528664725, 35.39544725418091, 35.822556495666504, 35.13375725064959, 38.96271841866629, 39.715236118861604, 40.32346057891846, 41.18331057684762, 41.053893429892405, 42.80178574153355, 44.00623859677996, 44.68204818453108, 49.32371582303728, 43.48619372504098, 31.464156491415842, 36.23232650756836, 32.71474885940552, 36.957388401031494, 43.660628250667024, 44.8067752974374, 47.95372213636126, 44.214705399104524, 44.20026009423392, 42.26415845326015, 41.51763357434954, 41.478414467402864, 41.72268533706665, 41.701396056583945, 38.38045590264456, 39.26104627336775, 36.284587383270264, 36.62076554979597, 33.73833315713065, 34.03472593852452, 34.27490431921822, 32.864194188799175, 35.6659962109157, 35.37734719685146, 36.708872182028635, 41.16169820513044, 44.59196131569998, 44.55970777784075, 43.01645381110055, 44.54946960721697, 43.58920076915196, 43.74264826093401, 41.08401039668492, 38.36757741655622, 41.141840253557476, 47.47148936135428, 43.84048237119402, 44.527176312037874, 51.51948206765311, 46.08746378762381, 43.32553400312151, 51.36496455328805, 45.2216591835022, 50.83873578480312, 48.77914728437151, 48.73386934825352, 50.22265638623919, 49.22310243334089, 50.51979957308088, 47.79985080446516, 49.72004801886422, 48.42158951078142, 52.16531017848423, 52.46172727857317, 53.73223318372454, 54.92282090868269, 50.0709285736084, 46.96239832469395, 47.98823731286185, 46.67996447426932, 50.594235624585835, 53.604785851069856, 55.89311947141375, 55.639465059552876, 53.067043917519705, 59.66197177342006, 12.111968636512756, 0.331400384328195, 0.36931711116007393, 3.526284609522138, 1.3929020059960229, 0.20463396156472818, 40.14948116030012, 59.95645032610212, 58.81146362849644, 55.5679646219526, 64.8860582624163, 48.52070903778076, 38.42774881635393, 31.60654592514038, 22.60491841179984, 39.08157777786255, 52.272639002118794, 6.844570985862187, 0.5862352028489113, 0.10113090156976666, 0.143394710496068, 0.11407625728419848, 0.06940903660974332, 0.028530307646308626, 0.06915106438100338, 0.07597896549850702, 0.04342015473438161, 0.03626441602994289, 0.05439493279638035, 0.020373527925195437, 0.3215670276965414, 53.41881384168352, 65.27329526628766, 39.35096638543265, 40.17059326171875, 77.39524064745221, 53.481465748378206, 38.038677488054546, 59.459014892578125, 64.5755432673863, 59.34024933406285, 58.72697353363037, 59.6178229195731, 39.75478526524135, 0.07204676007053681, 0.7216679155826569, 0.15242113971284457, 0.17249255840267452, 0.2454076058098248, 7.479123473167419, 51.297073704855784, 45.909162589481895, 49.569807120731895, 47.257457051958355, 52.42019442149571, 51.386497020721436, 52.325427940913606, 48.61030953271048, 52.55748387745449, 56.80623088564192, 54.60495819364275, 53.449601309640066, 52.02080849238804, 52.48095294407436, 50.33034304210118, 47.69003452573504, 54.342389242989675, 49.3453768321446, 44.33049712862287, 42.14319726399013, 47.36321905681065, 49.07631131580898, 53.16983904157366, 43.4774181502206, 50.400196756635395, 54.95427540370396, 50.17262935638428, 51.07473829814366, 45.09767205374581, 42.74592569896153, 43.887545994349885, 42.288977418627056, 44.067719732012065, 47.75010865075247, 45.54224211829049, 44.93579292297363, 46.495166710444856, 48.61132049560547, 46.644935131073, 47.197070258004324, 42.03596918923514, 36.12342391695295, 37.151701722826274, 36.17415271486555, 36.1497471673148, 36.26445497785296, 37.02688775743757, 36.863994189671104, 37.66567039489746, 38.29877288000924, 40.505211557660786, 41.125039509364534, 42.49752065113613, 42.329228333064485, 43.9979042325701, 44.775386810302734, 45.53774663380214, 46.709588118961875, 47.69464465550014, 46.03618608202253, 36.693624360220774, 37.988657406398225, 35.903242451804026, 39.6037974357605, 42.615014689309255, 47.30720962796892, 48.16203260421753, 46.68756232942854, 46.1388908794948, 43.97541986192976, 44.813622747148784, 44.926419803074424, 42.65892383030483, 43.097942284175325, 41.444997106279644, 42.016243253435405, 38.47971091951643, 38.483883312770296, 35.50716386522566, 37.88953787939889, 35.795364720480784, 35.851412364414756, 37.93772711072649, 38.08188138689314, 40.20604991912842, 43.27763659613473, 46.812800134931294, 45.715947083064485, 44.35019179752895, 47.371577739715576, 44.94644103731428, 47.409177916390554, 43.051535265786306, 40.89814608437674, 44.67876863479614, 50.35549552100045, 48.4671870640346, 46.938461780548096, 52.092301981789724, 48.01380320957729, 46.01631423405239, 49.19881847926548, 47.18668270111084, 52.511465958186555, 51.85505921500069, 50.29701253346035, 50.87362616402762, 50.45314202989851, 52.59322541100638, 50.923316206250874, 52.15112543106079, 50.35205268859863, 55.05968305042812, 54.78898123332432, 56.56518398012434, 56.97446066992623, 52.35334580285208, 49.35877643312727, 49.73437867845808, 50.1064373425075, 54.65437030792236, 57.40810816628592, 58.005503858838765, 59.229182379586355, 56.08047417231968, 64.54559653145927, 14.203087193625313, 0.507081324500697, 0.8336053490638733, 4.113588043621608, 1.9504047249044691, 0.18433470438633645, 43.174514906747, 63.80731569017683, 64.26655687604631, 63.61501039777483, 72.47171933310372, 52.077981744493755, 45.52068533216204, 36.48128741128104, 27.05449788911002, 47.5906058038984, 62.19889804295131, 9.868580307279315, 0.764023591365133, 0.07387443485536746, 0.18345737217792443, 0.07940993032285146, 0.023101038532331586, 0.21388129464217595, 0.18587986433080264, 0.2282471837741988, 0.14993550309113093, 0.1597971139209611, 0.13443749185119355, 0.10560754992599998, 0.39475826599768227, 61.378440856933594, 74.28196130480084, 51.616183621542795, 56.6951813016619, 98.3137513569423, 63.01046848297119, 43.9970635005406, 63.3447254725865, 70.20027678353446, 63.26318836212158, 63.96913923536028, 64.03613376617432, 46.33279773167202, 0.09277868510356971, 1.1120345400912421, 0.3759083460484232, 0.24735866540244647, 0.33741812141878263, 9.315531492233276, 56.719979422433035, 52.820594787597656, 52.29002339499337, 50.16769960948399, 55.3189411844526, 52.732474258967805, 54.03819363457816, 49.900433676583425, 52.92836134774344, 56.71576533998762, 55.92885405676705, 54.7759325163705, 55.75770255497524, 53.866114548274446, 52.202941622052876, 51.70765665599278, 57.317138876233784, 50.62039559228079, 46.977666991097585, 45.962458746773855, 49.19466693060738, 52.898730754852295, 55.09733533859253, 46.05492884772164, 52.80820614950997, 57.37967961175101, 53.871704374040874, 53.79455852508545, 49.910157680511475, 43.98594985689436, 46.34529754093715, 44.53467689241682, 46.683803353990825, 51.77599218913487, 49.81403282710484, 47.402799470084055, 51.08982283728463, 51.272153990609304, 51.108127866472515, 51.96585866383144, 44.92695481436593, 38.16235542297363, 39.03210660389492, 38.36544779368809, 38.71293067932129, 37.681029387882774, 37.617960589272634, 39.302342891693115, 40.30685785838536, 41.2897743497576, 43.81263746534075, 42.03386388506208, 44.54146180834089, 45.09291253771101, 46.620800563267295, 47.16447973251343, 46.849465778895784, 49.94538157326834, 50.295987674168174, 50.33896575655256, 41.16836500167847, 39.47584635870797, 39.475696972438264, 41.90546464920044, 48.2196991784232, 48.5634126663208, 51.50454691478184, 49.16289629255022, 48.79540606907436, 47.14189461299351, 46.19634205954415, 47.85967132023403, 46.99751452037266, 47.655251843588694, 44.88073192323957, 44.4978722844805, 41.939041818891255, 40.75230687005179, 39.445614746638704, 39.28809561048235, 38.57264307567051, 36.879415716443745, 40.12986292157854, 39.47377232142857, 43.45245327268328, 44.33167832238333, 50.71366821016584, 49.21757861546108, 48.567369665418354, 52.116596358163015, 48.664654867989675, 49.353627817971365, 45.05936663491385, 43.00028187888009, 46.204426288604736, 52.24184806006295, 50.51961197171892, 50.27342687334333, 55.47008882250105, 49.18318503243582, 49.01110594613211, 48.05599614552089, 46.66594648361206, 55.345497199467246, 51.2686972618103, 52.291684014456614, 52.27045031956264, 53.28001315253121, 54.553322655814036, 52.307977540152415, 54.67711871010916, 52.12963465281895, 56.30156237738473, 56.68908078329903, 59.15512153080532, 58.45600768498012, 53.605550152914866, 49.81045797892979, 50.60264989307949, 50.2543123790196, 55.479065895080566, 58.85254832676479, 59.67709800175258, 61.42982278551374, 58.41108063289097, 66.11412457057408, 17.08901105608259, 0.4330926447042397, 3.1841954801763808, 8.771867087909154, 2.5125830386366164, 0.5866826016988073, 47.19872045516968, 70.06901836395264, 68.40201350620815, 66.08383737291608, 76.7512538092477, 58.05837270191738, 54.44832842690604, 43.976211956569124, 36.33549336024693, 56.33219003677368, 75.06972026824951, 14.705028533935547, 1.0283453336783817, 0.3982854538730213, 0.2874223313161305, 0.2323317474552563, 0.15701104913439068], [0.032014601930443726, 0.02768667827227286, 0.008051711966150572, 0.041458927294505496, 0.019015295896679163, 0.011930160457268357, 0.19345610136432306, 0.10606358652668339, 35.03141723360334, 56.95198324748448, 40.59302289145333, 60.92311150687081, 100.70741966792515, 62.70011329650879, 29.964203698294504, 48.527907371520996, 57.94119480678013, 50.218709809439524, 53.12496410097395, 48.833440508161274, 48.66557550430298, 0.7472300125019891, 0.11017078613596303, 0.025894209276884794, 0.1320014697100435, 0.10345002569790397, 1.2938785595553262, 39.34950031552996, 43.83489949362618, 44.43483475276402, 44.860898290361675, 51.82830170222691, 48.00955786023821, 50.80496406555176, 50.089601857321604, 50.48280388968331, 54.641491821834016, 52.27407380512783, 50.18028974533081, 50.096254757472444, 51.83255052566528, 49.70616899217878, 49.66619947978428, 51.56146655763899, 47.90384101867676, 37.57944325038365, 42.32328067507063, 49.59389999934605, 48.89505018506731, 49.69371434620449, 48.24833617891584, 48.40516744341169, 47.550504275730674, 50.76861456462315, 46.30051987511771, 42.558383396693635, 39.96131699425833, 45.20823526382446, 40.39233807155064, 43.61704567500523, 43.31322526931763, 41.99906383241926, 43.50100728443691, 42.025324548993794, 42.63951403754098, 44.44680997303554, 45.50669166019985, 43.3092474256243, 34.901221888405935, 35.469608851841514, 34.19907167979649, 34.10113682065691, 34.06847333908081, 34.135269846235005, 34.14245080947876, 35.104884011404856, 35.99668877465384, 37.35578768593924, 38.787453583308626, 39.421709469386506, 40.61005640029907, 41.71582399095808, 41.727225984845845, 42.21997485842024, 46.52515166146414, 40.62634645189558, 33.536119733537944, 38.546028000967844, 41.42226607458932, 36.93335805620466, 33.15999984741211, 37.88363191059658, 45.79299565723964, 48.99879721232823, 44.72401530402047, 44.16091939381191, 40.45855093002319, 41.00615235737392, 40.38842623574393, 41.67998170852661, 41.22143881661551, 37.32111964906965, 37.91577775137765, 36.127287115369526, 35.44158329282488, 35.74684892381941, 35.28960534504482, 35.38011952808925, 34.45628704343523, 35.830084868839805, 36.12844051633562, 39.49052790233067, 45.67339978899275, 43.891430037362234, 43.88609034674508, 43.34877920150757, 42.019356046404155, 43.71402168273926, 44.848645142146516, 42.871378898620605, 38.19037403379168, 42.790505341121126, 44.79289279665266, 46.847457749503, 49.26850891113281, 48.67861032485962, 52.49837555204119, 42.028694425310405, 42.56240292957851, 49.71389191491263, 45.55536726542881, 50.94439009257725, 48.12891748973301, 51.26363549913679, 47.96823692321777, 46.69344745363508, 44.53986719676426, 48.289935043879915, 47.53668430873326, 49.677288804735454, 50.28119843346732, 52.39073405947004, 51.04954760415213, 53.93188272203718, 52.02646085194179, 49.47673600060599, 48.89233691351754, 53.23591641017369, 55.94653722218105, 54.559221676417756, 57.625732694353374, 55.28387015206473, 56.16896295547485, 8.23525423663003, 0.23201134321945055, 1.625124482171876, 2.20997422507831, 1.2776795944997241, 0.10162094634558473, 46.90167106900896, 56.33991295950753, 62.61859703063965, 55.04638072422573, 65.71092060634068, 33.81521150044033, 43.6440429006304, 44.662933690207346, 29.309471470969065, 46.49936689649309, 42.64753573281424, 1.9895122264112746, 0.1052702230268291, 0.09697794155882937, 0.0438349872960576, 0.03791921705539737, 0.038294460491410325, 0.07124247894223247, 0.0013698210885715006, 0.05071038586486663, 0.019488251768052578, 0.13059038828526223, 0.006185307674708643, 0.10645468732608215, 0.05421626434794494, 43.51989596230643, 65.792297908238, 44.56702423095703, 61.623066084725515, 90.58118452344621, 63.69801357814244, 36.045760427202495, 56.74267223903111, 64.9360158102853, 55.08919899804251, 58.799477985927034, 54.76621546064104, 52.642891134534565, 0.6547879757625716, 0.18484562768467835, 0.1169386301189661, 1.1665179708174296, 0.09017218103898422, 1.4355165021760123, 45.02695676258632, 44.755862372262136, 48.325273581913535, 47.212988580976216, 54.452757903507774, 50.29607800074986, 53.13020304271153, 50.70305831091744, 51.381539481026785, 56.16818128313337, 53.90034137453352, 52.19503804615566, 52.10921042306082, 54.10931192125593, 51.70782688685826, 53.3664105279105, 51.6896573475429, 48.73430708476475, 39.47395992279053, 43.33018234797886, 50.01358509063721, 51.485067640032085, 52.37737267357962, 50.75793865748814, 51.76533017839704, 49.85485001972744, 53.83393396650042, 49.02295957292829, 43.74692487716675, 43.652766363961355, 44.90008613041469, 41.64579309735979, 44.3034199987139, 46.02920314243862, 45.88213062286377, 47.13226440974644, 45.8731118610927, 43.63702522005354, 45.31976427350725, 47.4900028364999, 45.28473493031093, 36.193861280168804, 37.389990193503245, 35.832718236105784, 35.418470110212056, 35.41331454685756, 36.57902772086007, 36.85553823198591, 37.78214652197701, 37.183791978018625, 39.196292536599294, 40.540848868233816, 40.812766620091026, 43.51326738085066, 43.38517386572701, 42.86328077316284, 43.42521980830601, 47.16197143282209, 43.17610257012503, 35.42310108457293, 41.426476682935444, 41.0847920690264, 39.43830871582031, 36.87489938735962, 40.67638042994908, 47.409837995256694, 50.01900815963745, 47.4125269481114, 46.36592674255371, 43.054648058755056, 43.35438987186977, 44.277638707842144, 44.09913601194109, 42.351198537009104, 39.91516011101859, 40.32909556797573, 37.185112135750906, 37.53285557883126, 36.58970362799508, 37.312469141823904, 37.48246029445103, 35.79426343100411, 37.9162780216762, 38.63297428403582, 41.852783407483784, 48.09273474557059, 45.26915012087141, 47.76449489593506, 45.39395366396223, 45.44548150471279, 46.62308999470302, 47.92274359294346, 43.44046068191528, 39.92962278638567, 44.153411865234375, 48.13391324451992, 48.89622095652989, 50.89919900894165, 51.427776268550325, 53.95093815667288, 43.49087333679199, 42.53272022519793, 47.70765168326241, 48.08192334856306, 52.08783081599644, 49.36532163619995, 53.8828249658857, 51.13016407830374, 48.15194729396275, 46.256853921072825, 48.658738476889475, 49.267060211726594, 51.39264270237514, 53.8602363722665, 56.293297495160786, 52.62609733854021, 55.4565224647522, 56.25610726220267, 51.53535522733416, 50.36777646200997, 55.461827414376394, 58.69178785596575, 55.90583120073591, 59.57741914476667, 58.073505878448486, 61.07087884630476, 10.546141709600176, 0.29712511066879543, 2.514579560075487, 1.765040140066828, 1.1269009709358215, 0.2595681973866054, 51.19589056287493, 61.19080475398472, 65.6531046458653, 60.324190684727256, 72.4147788456508, 38.81389495304653, 48.55330303737095, 50.60884421212332, 32.10115691593715, 51.596596649714876, 53.507406847817556, 2.3757990641253333, 0.16440186968871526, 0.1218661649950913, 0.05649447620713285, 0.06516508505280529, 0.014726577991885799, 0.17266515057001794, 0.10984263303024427, 0.16736680987690175, 0.18088622657316072, 0.23974713097725595, 0.12476593868008681, 0.2474590071610042, 0.10719544400594064, 51.166909626552034, 76.51611982073102, 50.962778500148225, 74.0588824408395, 103.18188163212368, 68.55613149915422, 39.79751321247646, 58.68805667332241, 69.16090270451137, 59.18030180249895, 64.65598256247384, 57.85134070260184, 59.992184911455425, 0.8438089415431023, 0.20151507535151073, 0.877557102058615, 0.9736529141664505, 0.0841767406091094, 2.2230833045073917, 49.881843771253315, 50.31397656032017, 52.79320151465279, 49.79797901426043, 57.06213998794556, 51.39713818686349, 55.3718204498291, 53.17530379976545, 52.42126096997942, 56.60367005211966, 55.82677807126726, 53.543318612234934, 54.339404991694856, 54.99341460636684, 53.44976111820766, 55.56237827028547, 56.194997855595176, 51.085660866328645, 40.03447110312325, 46.65217515400478, 55.22667605536324, 55.01966142654419, 54.69545848029, 52.73399938855852, 53.855747835976736, 51.852634293692454, 55.75195639474051, 52.11589459010533, 46.69703619820731, 45.95012222017561, 48.807645320892334, 45.17022514343262, 48.39121546064104, 49.54640211377825, 48.52411365509033, 49.02891765322004, 49.886043957301546, 46.95793063299996, 48.91151394162859, 50.55043765476772, 48.95891802651541, 40.061100074223106, 38.28514051437378, 38.466783796037944, 36.42393698011126, 38.29986374718802, 39.03364910398211, 37.86029291152954, 39.018220629010884, 39.761980124882285, 41.39312532969883, 42.16975327900478, 42.10744530814034, 45.03472832271031, 47.33308124542236, 45.279881613595144, 46.53037323270525, 49.96695572989327, 45.55955008098057, 43.4947122165135, 44.40732683454241, 44.59862811224801, 42.63472325461251, 41.6150403703962, 42.37320695604597, 49.54148626327515, 51.54012516566685, 49.943925925663535, 49.61387259619576, 47.07026563371931, 44.62612560817173, 45.0362742968968, 47.56350088119507, 46.03270156042916, 41.2413523537772, 43.235499245779856, 41.28102656773159, 39.219232014247346, 39.846171447208945, 38.97463805334908, 38.41692352294922, 38.79772302082607, 39.63445288794381, 41.33013643537249, 44.452907017299104, 51.8829562323434, 48.39891059058053, 51.148826939719065, 49.88634272984096, 48.122966357639854, 49.265920707157676, 51.41325453349522, 45.023381914411274, 42.49035358428955, 48.424473013196675, 49.16711037499564, 51.83980791909354, 51.86530433382307, 53.51617547443935, 55.03534698486328, 47.193992206028526, 48.385052408490864, 48.283719880240305, 50.00053289958409, 54.076241970062256, 51.057722159794395, 54.53270387649536, 52.12784549168178, 51.519169398716514, 48.9691527230399, 52.688391413007466, 51.54219920294625, 51.89435822623116, 56.188695839473176, 57.22872999736241, 54.57690831593105, 58.59693799700056, 56.792577675410676, 52.18603318078177, 51.07946654728481, 55.86966930116926, 60.325774874006, 58.01049266542707, 60.860577719552175, 61.846902302333284, 64.79680865151542, 11.684148941721235, 0.27176250304494587, 5.165939620562962, 5.374216650213514, 1.8939708045550754, 0.49443554878234863, 57.1835423878261, 66.6006304877145, 71.10968480791364, 65.47227777753557, 77.77138832637242, 43.350596155439106, 58.19436284473964, 61.66391454424177, 46.02211250577654, 59.242842538016184, 69.0063956124442, 5.094136067799159, 0.3382755182683468, 0.2841623233897345, 0.21254299288349493, 0.21190573993538106, 0.07344435221914734], [0.0674676868532385, 0.026631340883406143, 0.03489853860810399, 0.02100258077760892, 0.11270954526428666, 0.0352882110912885, 0.15512825016464504, 0.08981510877077069, 24.91747692653111, 62.4062739780971, 35.188773087092805, 49.32252073287964, 94.785080909729, 69.04833493913922, 30.585383074624197, 48.50871992111206, 58.94977446964809, 52.220895767211914, 57.06699330466134, 48.6373484475272, 53.243340560368125, 3.9828611612319946, 0.20062223183257238, 1.398706574525152, 1.1625599946294511, 0.16397319840533392, 0.15839477202722005, 28.719371386936732, 46.39963245391846, 44.98242923191616, 44.00584602355957, 50.02855151040213, 49.8620275088719, 48.98785727364676, 48.8854512487139, 53.04688719340733, 51.64402505329677, 54.365429469517295, 51.00736856460571, 51.8585923739842, 49.18764925003052, 50.89460972377232, 50.46768460954939, 50.87272637231009, 43.66999789646694, 39.560232230595176, 45.46208075114659, 49.71247795649937, 48.30299765723092, 48.98516484669277, 50.20408385140555, 50.138951437813894, 48.6236709186009, 46.86831971577236, 44.41120392935616, 43.330536706107004, 42.65628351484026, 44.51573262895857, 38.83507306235177, 41.19289214270455, 43.827999932425364, 42.540828772953574, 44.66025863374983, 43.87825625283377, 44.047274657658164, 46.556772913251606, 44.89683437347412, 44.21006052834647, 37.58730166299002, 35.80136448996407, 36.71854060036795, 34.731800488063264, 35.74821424484253, 36.87462840761457, 36.70078100476946, 35.31392404011318, 36.31415891647339, 37.148588929857524, 36.63250800541469, 39.12345109667097, 38.70370694569179, 41.5085904938834, 41.98004313877651, 43.206532205854145, 37.81385462624686, 33.376081875392366, 42.29946225030081, 44.65940400532314, 41.417412757873535, 39.735698563711985, 35.77868904386248, 41.00926167624337, 46.00817789350237, 45.208054610661094, 49.649138178144185, 45.444859640938894, 42.915128231048584, 40.77483292988369, 41.98521954672677, 39.64111621039254, 39.9196069581168, 36.74352632250105, 38.18468345914568, 36.989357062748496, 35.794464928763254, 37.46093824931553, 36.99685416902815, 37.38482420785086, 36.50102724347796, 35.272596154894146, 36.168357917240684, 40.5564614704677, 47.25685255868094, 45.51692983082363, 42.940829617636545, 43.43070888519287, 44.312883445194785, 45.1616267476763, 45.05485030582973, 42.81841972896031, 39.244502612522666, 42.63931948798043, 40.66578095299857, 44.25683927536011, 44.70618622643607, 48.195762634277344, 48.157029901232036, 48.50188636779785, 32.716736044202534, 41.5791459764753, 51.61566250664847, 45.38338892800467, 47.95282581874302, 51.11366558074951, 50.39917189734322, 50.90256888525826, 44.93215554101126, 43.154479776109966, 44.9944600377764, 45.64204256875174, 48.20319373267037, 50.402579988752095, 53.267145088740754, 51.39216675077166, 53.43465920857021, 56.232292311532156, 50.25333615711757, 51.954077993120464, 57.89539922986712, 55.71277550288609, 56.59430040631975, 55.55568715504238, 52.92398050853184, 5.459546608584268, 0.13358518401426928, 1.0932258750711168, 1.3901744037866592, 0.49099993599312647, 0.8270363158413342, 53.96878807885306, 56.766045979091096, 60.841755049569265, 51.683386598314556, 57.98980093002319, 34.07037019729614, 48.98892034803118, 21.678225006375992, 26.956347635814122, 48.272158077784944, 36.69942610604422, 0.22279907683176653, 0.037225323396601846, 0.023915017622389963, 0.08253792247601918, 0.09031299741140433, 0.0824528681114316, 0.04259797724496041, 0.044473702487136633, 0.015030738099345138, 0.03616140762876187, 0.06539790398840394, 0.06401722093245812, 0.12216301049504961, 0.07904377247073821, 32.26100369862148, 73.82819529942104, 40.08953210285732, 49.4076361656189, 89.13216550009591, 72.36900411333356, 32.262740748269216, 54.42523608888899, 65.49585996355329, 56.87264176777431, 61.185850688389365, 52.632444517953054, 59.35315213884626, 4.384353697299957, 0.15903496981731483, 1.7052518682820457, 1.216887308018548, 0.5464656140123094, 0.11782804025071007, 34.393930435180664, 49.91750887462071, 47.63765205655779, 48.389183112553184, 52.527947085244314, 51.80149902616228, 51.76642451967512, 50.30463818141392, 54.30083554131644, 53.799071380070274, 56.50341102055141, 52.99976798466274, 52.02435554776873, 51.92643458502633, 53.20975991657802, 52.13932738985334, 53.911187512534006, 45.31619637353079, 41.50178125926426, 47.46600375856672, 50.734231403895784, 50.6373040335519, 50.52882528305054, 51.9947840145656, 53.730120931352886, 51.69973223549979, 49.27861854008266, 46.63657644816807, 45.27686956950596, 43.94312116077968, 46.521361419132774, 40.3301169531686, 44.34505360467093, 47.08519383839199, 46.42709173474993, 47.51161173411778, 48.44371952329363, 44.24234185900007, 48.611685276031494, 47.29418175561087, 44.66594920839582, 39.51561437334333, 38.46028028215681, 38.16856711251395, 36.499953746795654, 35.79974903379168, 36.47802870614188, 38.26098510197231, 37.94043690817696, 37.874967506953645, 38.84282725197928, 38.922516141619, 40.2744653565543, 40.68043122972761, 43.10952493122646, 42.864809376852854, 43.46610300881522, 39.19765785762242, 38.556533677237375, 44.946333340236116, 46.44196435383388, 42.83235434123448, 40.79007380349295, 38.8800904410226, 42.088344710213796, 46.7093379838126, 48.53032881872994, 51.34280327388218, 47.650613921029226, 43.92513574872698, 42.93946777071272, 43.6488892691476, 40.28769472667149, 42.62706981386457, 39.61610269546509, 39.46974584034511, 38.99067102159773, 37.85713495526995, 39.27115242821829, 36.95113154820034, 40.42473404748099, 36.57323292323521, 37.96239668982369, 38.67405203410557, 41.967122963496614, 50.59699405942644, 46.625869274139404, 45.02754388536726, 46.47382531847273, 47.38432421003069, 47.17724009922573, 46.77054466520037, 43.12957048416138, 40.42299352373396, 44.80335330963135, 42.37479114532471, 47.28192860739571, 47.84420115607125, 50.485072476523264, 49.09478310176304, 50.46103170939854, 35.60127374104091, 42.435243947165354, 52.53287335804531, 48.32141038349697, 48.96091215951102, 52.18572746004377, 51.49769251687186, 52.54450116838728, 46.492036546979634, 45.24646077837263, 45.238901138305664, 47.64682020459856, 50.53946644919259, 50.955180644989014, 54.88673196520124, 53.93796934400286, 55.45126962661743, 58.35416099003383, 51.8950982093811, 52.60071904318673, 59.994262422834126, 57.405651978084016, 60.276873452322825, 60.78487709590367, 60.92870480673653, 8.034891639436994, 0.3155141424919878, 1.6696165118898665, 1.0122890238251006, 0.9398137756756374, 0.8881926770721162, 60.467233249119346, 60.74477209363665, 67.50754410879952, 56.83454132080078, 65.34946836744035, 37.93258891786848, 55.853782245091026, 31.42507287434169, 28.314743041992188, 58.41961302076067, 46.29548590523856, 0.4018767225955214, 0.026099289700921093, 0.06136831521455731, 0.04735862643324903, 0.017106298689863512, 0.060776809097400734, 0.1881379203072616, 0.17516487357871874, 0.054044995323887894, 0.11286140140146017, 0.11568308249115944, 0.2769482476370675, 0.33673269248434473, 0.16027754385556492, 37.485802377973286, 85.28829002380371, 46.27529444013323, 62.69584015437535, 93.92073890141079, 78.1439368384225, 41.06112650462559, 59.49035126822335, 71.42944785526821, 61.25299807957241, 67.95905889783586, 57.95600836617606, 66.53503254481724, 4.6635436075074335, 0.25181237927504946, 2.4435198988233293, 4.8204096129962375, 0.3895855764193194, 0.24185732060245105, 41.777037620544434, 53.53472021647862, 52.04075329644339, 50.01291806357247, 55.50635494504656, 53.24978501456124, 53.8846766608102, 50.686709199632915, 55.9856173651559, 54.971680641174316, 59.6860750743321, 53.349491664341514, 54.90924760273525, 52.64417655127389, 55.13388286318098, 55.12621900013515, 58.025045667375835, 46.94258901051113, 43.54761927468436, 50.433673177446636, 54.1877292905535, 53.67560189110892, 53.11965567725045, 56.14481796537127, 53.76746402468, 55.70895399366106, 52.46329409735543, 48.30189636775425, 47.38934775761196, 46.66330616814749, 49.1015819140843, 43.319544655936106, 45.979276861463276, 47.613517488752095, 48.88510036468506, 52.186981609889436, 53.016276904514854, 48.377763748168945, 52.60029867717198, 49.594539233616416, 47.83207654953003, 42.11610623768398, 41.23126009532383, 41.78595563343593, 39.93011958258492, 38.52796615873064, 39.783967699323384, 40.905799525124685, 39.85906730379377, 40.39268895557949, 41.03203787122454, 40.77814027241298, 42.19580902372088, 42.30194623129708, 46.06290190560477, 46.80124180657523, 47.0976311138698, 41.992977210453574, 41.84432397569929, 48.78593220029558, 50.10961961746216, 45.02587284360613, 42.04871218545096, 42.82769904817854, 47.74769762584141, 48.01821878978184, 49.79341752188546, 54.82406963620867, 48.24486207962036, 47.758026123046875, 45.7006402015686, 47.106097493852886, 43.36576754706246, 45.15872240066528, 41.248936312539236, 41.79547119140625, 41.15843949999128, 40.447617939540315, 43.44707189287458, 40.25721992765154, 43.515278884342735, 40.2286593573434, 39.98340879167829, 41.91715151923043, 44.85833093098232, 52.32516390936715, 49.895090511866975, 49.68918759482247, 48.95433221544538, 50.13417107718331, 50.77601439612252, 49.290232454027446, 46.26146752493722, 42.61179767336164, 47.80921350206648, 45.00687646865845, 49.290927273886545, 50.86045585359846, 51.8589745249067, 51.27201502663748, 53.27353743144444, 40.10230984006609, 46.01409428460257, 53.56494140625, 48.44999374662127, 50.17973736354283, 54.88324049540928, 53.33077669143677, 54.771138259342735, 48.208575112479075, 47.086013725825715, 48.01392132895333, 52.13217074530465, 53.136939321245464, 52.13613816670009, 57.706710474831716, 55.28108392442976, 56.81052834647042, 60.76382405417306, 53.58624805722918, 54.44669907433646, 62.31909493037632, 58.69200325012207, 63.81591756003243, 61.64400100708008, 63.90306881495884, 8.754541754722595, 0.229184376341956, 2.9442138203552792, 4.0323966060365946, 1.006902432867459, 1.5628662343536104, 64.54313686915806, 66.03038488115583, 71.90333584376744, 63.491881370544434, 70.7433340890067, 44.720711435590474, 64.88746874673026, 32.84370742525373, 40.76356642586844, 64.86494268689836, 60.251165117536274, 1.3662771603890826, 0.2750438983951296, 0.17859127186238766, 0.11225416005722114, 0.1559430757271392, 0.22758498787879944], [0.1353946469191994, 0.09612343526844468, 0.09856125552739416, 0.042009375257683654, 0.14623770437070302, 0.04005407142852034, 0.3255663130964552, 0.25648363147463116, 13.266790509223938, 59.50574847630092, 44.45279237202236, 51.714969635009766, 69.5323325565883, 68.07120977129254, 32.86198466164725, 48.93224736622402, 55.94938598360334, 50.97861691883632, 56.820137705121724, 49.76232433319092, 56.202050277165, 8.903941052300588, 0.43670087680220604, 2.3499280980655124, 0.4785358990941729, 0.1927881379212652, 0.5163636292730058, 16.233411618641444, 45.51730155944824, 41.33319016865322, 44.34047474179949, 45.85353878566197, 49.94555180413382, 47.1516672543117, 51.90936286108834, 52.85925109045846, 51.372329643794465, 50.724354539598735, 49.112219606127056, 48.65472936630249, 52.10759496688843, 51.2040581703186, 49.77382707595825, 49.63243123463222, 36.638288906642366, 42.29233339854649, 50.07037966591971, 50.499590737479075, 49.877032143729075, 47.874373708452495, 51.79825421742031, 48.41029521397182, 48.25265448434012, 47.33026375089373, 42.670152119227815, 40.593130588531494, 42.94046483721052, 44.68854127611433, 39.14299290520804, 42.49494981765747, 43.601561614445274, 43.7750928742545, 43.037829944065635, 44.855093070438926, 42.77384008680071, 45.45496232169015, 46.93524129050118, 44.72789239883423, 37.72455290385655, 35.828851563589915, 35.98148264203753, 34.80727529525757, 35.19050318854195, 34.148217814309255, 35.03493997028896, 36.63827501024519, 34.7851939201355, 36.92498547690255, 37.43574408122471, 36.79562738963536, 39.20219503130232, 42.5706330708095, 38.37803792953491, 34.69834838594709, 38.454023429325645, 48.45312738418579, 45.07103960854666, 38.31222806658064, 37.514467171260286, 38.63224472318377, 37.669161864689414, 39.16582815987723, 48.91463368279593, 45.619089194706504, 41.542970180511475, 41.85373878479004, 42.30978032520839, 41.788856506347656, 41.25986582892281, 39.09918451309204, 38.81861972808838, 38.09690339224679, 36.23640857424055, 36.2732583454677, 35.089705671582905, 35.85101979119437, 34.289398261478965, 36.36360577174595, 35.86011150905064, 34.259847572871614, 36.412204946790425, 40.89204904011318, 45.05638585771833, 48.41255337851388, 45.33982024874006, 41.62455245426723, 42.18993432181222, 43.30845880508423, 44.91019923346383, 41.49505887712751, 40.09641776766096, 44.59585230691092, 39.51003844397408, 41.45186192648751, 41.00621836526053, 43.44080809184483, 47.985266957964214, 49.560350622449604, 49.8179863521031, 47.85425519943237, 44.33104951041085, 45.73911932536534, 48.5828572000776, 49.18309817995344, 51.115812574114116, 48.80366052900042, 45.92931236539568, 39.99172578539167, 43.10740573065621, 42.098075662340435, 46.31094217300415, 46.82437930788313, 49.85845266069685, 48.67709214346749, 53.78342056274414, 52.69695854187012, 55.293385710035054, 53.79172018596104, 58.046460015433176, 51.079907757895334, 55.417324202401296, 55.832319259643555, 52.26232787540981, 5.569903109754835, 0.19173157747302735, 2.970603947128568, 0.5896149043525968, 0.6281748552407537, 4.969815858772822, 63.44477258409773, 54.45136478969029, 59.89459746224539, 50.98968192509243, 58.809316635131836, 36.828829356602256, 45.94758265359061, 26.46468789236886, 28.411225727626256, 43.49257217134748, 32.730483055114746, 0.16370007448962756, 0.0851036940834352, 0.04228854152773108, 0.06222521673355784, 0.047389845829457045, 0.026417581996481334, 0.035018968395888805, 0.04442483778776867, 0.0622355779632926, 0.024121958928714906, 0.20988100501043455, 0.09577943837004048, 0.31286945726190296, 0.33061056956648827, 17.805517980030604, 69.70796217237199, 48.32225806372506, 52.101873125348774, 73.84685816083635, 74.51516369410923, 34.40153176443917, 55.09522656032017, 63.02586569104876, 57.58779553004673, 62.22750377655029, 53.41459628513881, 61.309341021946494, 9.717014040265765, 0.3489590792783669, 3.0789893312113623, 2.067021987267903, 2.700282543897629, 0.5402309085641588, 20.200317110334122, 50.752230712345664, 45.050195012773784, 50.25081048692976, 48.04737343106951, 50.802063192640034, 50.22350754056658, 52.49563796179635, 54.09699623925345, 52.14048426491873, 53.547536168779644, 50.05642073495047, 51.28994485310146, 53.28515829358782, 52.99208327702114, 51.68510627746582, 52.73985324587141, 39.794900689806255, 44.8259071622576, 51.76356881005423, 53.157005718776155, 51.263329778398784, 48.95942177091326, 54.18381398064749, 50.30163655962263, 50.51642969676426, 48.88307843889509, 43.908032757895334, 43.32679162706648, 45.773478167397634, 48.191725730895996, 41.92390864236014, 44.044481481824604, 45.93846314293997, 46.888459069388254, 45.646350451878135, 46.73133945465088, 47.19833830424717, 48.03514460154942, 47.90160369873047, 46.194288866860525, 39.887367316654746, 38.37675946099417, 35.949989931924, 36.21627964292254, 37.135686125074116, 36.53730378832136, 36.988200187683105, 36.941379751477925, 35.053533349718364, 38.48875399998256, 38.386650221688406, 38.046223231724326, 40.89207683290754, 44.03722061429705, 42.07607419150216, 37.91913720539638, 40.46390799113682, 51.5593021937779, 47.07020657403128, 41.2117634500776, 38.83960676193237, 39.8754893711635, 40.01800387246268, 41.676271370479036, 51.724016189575195, 45.640777996608186, 45.03355407714844, 44.563237462724956, 44.70883696419852, 42.9431676864624, 41.397492272513254, 41.3969920022147, 40.52323171070644, 39.75552524839129, 37.8596328326634, 37.42048236301967, 37.4644192968096, 37.133035387311665, 34.99684647151402, 37.53089966092791, 38.14603410448347, 37.29078033992222, 36.981776578085764, 41.28184992926461, 46.83570834568569, 49.96050780160086, 46.83607660021101, 45.28285196849278, 44.2092684337071, 45.98001684461321, 44.648252146584646, 44.16648142678397, 41.27843141555786, 46.128558908190044, 41.53381940296718, 43.452303886413574, 42.97088057654244, 45.76421274457659, 50.35102782930647, 51.38092109135219, 49.471198286329, 50.93959583554949, 50.34240511485508, 46.58552803312029, 48.59566273008074, 50.97655330385481, 52.8137195450919, 51.14953565597534, 46.72469697679792, 42.11146136692592, 44.06395033427647, 44.54187175205776, 49.05320160729544, 48.352663380759104, 52.28655971799578, 51.638855593545095, 57.15698289871216, 53.8874385697501, 58.57785824366978, 54.272629329136436, 59.68897942134312, 53.72752577917916, 59.531526293073384, 59.67862660544259, 58.552497318812776, 7.247383679662432, 0.12328496814838477, 3.1386808710438863, 0.38484066245811327, 0.6609782778791019, 5.583488575049809, 70.75348540714809, 57.644840240478516, 66.52456160954067, 54.99286569867815, 64.27928597586495, 39.483854157584055, 55.31926774978638, 27.234320742743357, 28.901692117963517, 51.755734716142925, 40.339691570826936, 0.17164426749306066, 0.050665789150765965, 0.031054328994027207, 0.1024186863963093, 0.041682816709258726, 0.06241268917386021, 0.20873327659709112, 0.15955969451793603, 0.18260871485940047, 0.17915384524634906, 0.3131423369050026, 0.2404338355575289, 0.47251273372343605, 0.41539145740015165, 19.329900639397756, 83.8870746067592, 56.216839517865864, 68.5760519845145, 72.86965656280518, 79.73075253622872, 44.5867988041469, 59.694197518484934, 66.39911188398088, 63.02933979034424, 65.93647302900041, 59.92028495243618, 66.59594045366559, 10.792026298386709, 0.44535548239946365, 4.370055607386997, 5.177116232258933, 3.823829923357282, 0.613139984863145, 24.91324199948992, 57.694422585623606, 52.37561477933611, 51.75004761559622, 50.96090596062796, 53.203947748456685, 52.79032843453543, 54.38704184123448, 56.1535518510001, 52.68822118214199, 56.228707041059224, 52.50705732618059, 52.78125408717564, 55.55003479548863, 54.957085950034006, 54.93931940623692, 54.316604478018625, 40.5308712550572, 48.24499062129429, 52.1692602293832, 57.75450018474034, 53.259429114205496, 50.839896133967805, 56.418973037174766, 53.595551695142476, 51.96289873123169, 52.05118254252842, 45.40872206006731, 45.41351631709507, 48.117994921548025, 50.8073924609593, 43.64441115515572, 46.04185233797346, 48.95751101630074, 50.2388665335519, 48.668247086661204, 51.631361961364746, 48.80967419488089, 49.68237141200474, 52.28018821988787, 47.783821310315815, 40.66684750148228, 40.503425870622905, 39.12399653026036, 38.45605230331421, 38.287742614746094, 38.9700904573713, 39.74365077699934, 39.49041673115322, 38.74395438602993, 41.96353074482509, 40.4656902040754, 39.84407656533377, 42.89210884911673, 45.56945473807198, 44.05643238340105, 39.88268770490374, 43.64087799617222, 54.550456523895264, 49.27685717173985, 42.96368224280221, 40.415041310446604, 41.26945781707764, 42.24241753986904, 45.71312264033726, 55.01265416826521, 47.03117159434727, 46.840405327933176, 46.94333246776036, 46.95602682658604, 47.10694864818028, 45.54576138087681, 43.88477713721139, 41.87362452915737, 41.32414361408779, 39.57061283929007, 39.14001212801252, 38.33420869282314, 39.14492450441633, 38.94736637387957, 39.960299083164756, 42.09790890557425, 38.22362811224801, 40.182624067579, 45.012758118765696, 49.75913858413696, 53.7415646144322, 48.13935368401663, 46.48182616915022, 47.58085053307669, 50.47203070776803, 48.7578684261867, 44.84092221941267, 44.22558280399868, 49.3107122693743, 43.93107645852225, 44.14937148775373, 45.91365459987095, 47.04915005820138, 52.796317781720845, 53.080919470105854, 51.929596015385215, 51.527326583862305, 44.695628438677105, 49.06624337605068, 50.73324475969587, 53.818453380039756, 55.985429763793945, 53.38261372702462, 49.93790183748518, 43.314312662397114, 47.35376950672695, 47.61701243264334, 50.16349594933646, 51.28228446415493, 55.03355434962681, 54.19790145329067, 59.612493651253835, 55.94293458121163, 59.41755499158587, 57.43268394470215, 63.997321128845215, 56.23418916974749, 62.06497151511056, 60.09577560424805, 62.30301679883684, 8.376128094536917, 0.31649861537984436, 8.831104823521205, 2.9114474185875485, 0.7845279425382614, 6.620710449559348, 75.13972336905343, 62.11911882672991, 71.23441192081997, 61.05373764038086, 68.87787478310722, 47.661376680646626, 61.372027669634136, 39.49944591522217, 42.62149388449532, 59.682913643973215, 53.07945687430245, 0.7560749064598764, 0.28853705578616684, 0.17086152306624822, 0.18089894231941017, 0.13801907109362738, 0.15242978424898215], [0.08893857723368065, 0.0543876758643559, 0.05405845745865788, 0.025732375282262052, 0.04752527463382908, 0.04210541510422315, 0.10865796517048563, 0.03586285900590675, 4.436810425349644, 57.29530416216169, 46.06143930980137, 29.66962092263358, 32.69753122329712, 51.71030739375523, 31.509684562683105, 40.228496074676514, 59.54546437944685, 50.43173115594046, 58.48636436462402, 49.405808789389475, 57.2185126713344, 18.12727689743042, 0.4285981373063156, 1.8627981458391463, 0.12941842260105269, 2.608061275311879, 0.04190235671454242, 3.114548474550247, 41.35214832850865, 40.29723807743618, 41.44520902633667, 41.25799328940255, 47.59798131670271, 43.493927070072715, 52.08640990938459, 50.17023222787039, 51.52128165108817, 48.73617615018572, 48.50149726867676, 48.24643932070051, 48.92782136372158, 50.40517861502511, 50.92525127955845, 43.451351983206614, 37.48421124049595, 45.74666506903512, 51.912180355616975, 47.32687997817993, 45.06830549240112, 49.399444239480154, 50.761708055223735, 49.24738638741629, 47.77143962042672, 43.90547929491316, 44.5472218649728, 42.279194355010986, 40.64814642497471, 41.94924872262137, 40.06530720846993, 41.204620701926096, 45.026845591408865, 43.00911998748779, 42.365939140319824, 41.58413478306362, 45.76395913532802, 43.73210784367153, 45.08988312312535, 43.10048532485962, 40.15236813681466, 35.39755950655256, 36.05018295560564, 36.864407607487266, 36.814696720668245, 34.926794733319966, 36.629645347595215, 36.454272815159385, 33.18954358782087, 36.32914618083409, 36.45874398095267, 36.1300698689052, 42.610769339970176, 40.14645869391305, 43.06515373502459, 44.08004583631243, 47.29604387283325, 53.101583412715364, 43.682351793561665, 41.0630407333374, 39.220673765454976, 37.641303062438965, 41.53381940296718, 43.873399462018696, 50.873021670750205, 49.852737767355784, 41.627359526497976, 40.93957124437605, 44.62336022513253, 39.54093360900879, 38.85155071531023, 41.2295160974775, 38.56606660570417, 36.33900220053536, 35.7500034059797, 35.64438383919852, 35.482560294015066, 34.45117664337158, 36.65682322638375, 35.373035839625764, 37.66921397617885, 37.12558691842215, 38.90334606170654, 43.10059997013637, 45.586703641074045, 43.50537770135062, 45.877350262233186, 42.82094539914812, 41.78570549828665, 43.827975613730295, 45.274069445473806, 41.60638638905117, 39.403359276907786, 42.23396158218384, 39.267191955021445, 38.81032705307007, 40.5709901537214, 41.87111970356533, 48.11159215654646, 48.046379838671, 50.836637428828645, 44.93364245550973, 29.342888832092285, 48.801850523267476, 45.85214914594378, 51.64396946770804, 48.67353466578892, 50.85057898930141, 44.81202813557216, 38.81443691253662, 38.99159165791103, 42.28708750861031, 45.80895219530378, 47.130864347730366, 48.162216731480186, 47.44233819416591, 52.61992733819144, 50.170867988041465, 55.73428365162441, 51.44050536836897, 58.25346769605364, 51.90704911095755, 56.36271694728306, 52.77791200365339, 58.40120029449463, 9.632503969328743, 0.1281415554029601, 1.8276467749050684, 0.12155923646475587, 0.5185367869479316, 10.94420313835144, 63.63479886736189, 54.75344467163086, 57.750675201416016, 54.01482336861746, 57.676096711839946, 37.20542866843087, 48.48989725112915, 20.805581637791224, 36.80506999152047, 48.58437885556902, 33.16860171726772, 0.179861435134496, 0.056240364842649014, 0.053608076447354894, 0.024681648538847054, 0.014280626117917044, 0.04575681899275098, 0.028366651785160815, 0.06641475656735045, 0.0413616321581815, 0.03374014362426741, 0.07927380262741021, 0.1509793885052204, 0.19452554040721484, 0.05174080914418612, 6.389582097530365, 68.07396125793457, 50.58014815194266, 38.588620458330425, 42.9311785697937, 64.05585275377545, 35.12681600025722, 43.68661798749651, 65.52042879377092, 57.577258586883545, 64.27953611101422, 52.990631103515625, 62.97531059810093, 20.139407464436122, 0.5168611311486789, 2.4077768453529904, 0.3047157462154116, 3.866722890308925, 0.15548368037811347, 4.610649577208927, 47.765286990574424, 43.3547477040972, 47.971325397491455, 44.64949240003313, 50.138927119118826, 46.15975979396275, 53.99723400388445, 52.392658710479736, 53.50086511884417, 52.052471433367046, 50.2855167388916, 50.7644282749721, 50.41613939830235, 52.169520786830354, 52.51935911178589, 47.557171072278706, 39.101074423108784, 47.48982913153512, 52.507237979343955, 50.26073946271624, 46.02921009063721, 51.72792107718331, 53.023516927446636, 50.78462321417672, 50.36117219924927, 47.13539457321167, 47.15061807632446, 44.03581012998308, 42.115567752293174, 44.67778199059622, 41.69948877607073, 42.47542537961687, 48.18274171011788, 46.94824137006487, 45.870343003954204, 45.53925091879708, 48.0393100466047, 46.263687474387034, 47.73544795172555, 46.1428096635001, 41.729445934295654, 37.73794903073992, 38.24174901417324, 37.85581479753767, 36.967595304761616, 36.636075905391145, 38.771486622946604, 38.343130179813926, 34.82329089300973, 37.15868813650948, 38.82395941870553, 38.346062319619314, 44.48551491328648, 42.966829776763916, 46.498595646449495, 45.60335152489798, 46.864397457667756, 54.72408158438546, 46.476354462759836, 41.183661460876465, 39.54064525876726, 39.28066103799002, 42.52006755556379, 46.2337372643607, 53.33011661257063, 50.20610577719552, 40.88489586966378, 42.26403338568551, 46.79374817439488, 41.008778776441304, 42.662589005061555, 41.525238377707346, 39.917793478284565, 38.26365321023123, 37.863784381321494, 35.940311091286794, 37.77475711277553, 36.58914082390921, 38.654812472207205, 36.26431253978184, 38.93692670549665, 37.70968723297119, 41.08028963633946, 45.912945883614675, 46.798188073294504, 45.97947835922241, 48.94418784550258, 45.08662441798619, 44.36735732214791, 47.144385542188374, 47.512045996529714, 44.667606353759766, 41.41068690163748, 45.62883056913103, 40.955465248652864, 42.290099552699495, 41.42793927873884, 44.88103069577898, 50.82316834586007, 50.55512074061802, 50.99208600180489, 49.13792446681431, 33.079501492636545, 48.62655094691685, 48.75264685494559, 52.446399552481516, 52.99458462851388, 53.0686628477914, 48.2700388772147, 40.61349923270089, 41.20988743645804, 43.973950317927766, 47.14235666819981, 48.29890864236014, 51.12767314910889, 50.29759965624128, 54.23335116250174, 53.20756775992257, 57.707797867911204, 54.51744910648891, 60.5478948865618, 54.632848262786865, 57.837489468710764, 55.032314096178325, 65.33892100197929, 11.58419041974204, 0.03153686917253903, 1.8718490430286951, 0.2333699060337884, 0.44381333515048027, 11.472436462129865, 70.55008384159633, 58.67652266366141, 65.8152825491769, 57.07902411052159, 65.64252948760986, 40.7579870223999, 59.888719286237446, 26.31346903528486, 36.2552034514291, 57.852514948163716, 40.36739751270839, 0.20053763208644731, 0.034984861833176444, 0.02150508006369429, 0.11573309052203383, 0.0289448484379266, 0.04999277401449425, 0.21588297294718878, 0.14473564497062139, 0.07927602143692118, 0.11555976553687028, 0.12487260438501835, 0.26798577713114874, 0.21177790393786772, 0.20417672395706177, 7.310342175619943, 85.03591755458287, 59.85727868761335, 46.35981232779366, 42.08818142754691, 67.82258238111223, 43.70225838252476, 51.84757253101894, 71.48141343252999, 63.98637771606445, 68.23709801265171, 58.749673298427034, 67.12348937988281, 23.29840247971671, 0.7301039514797074, 3.72668194770813, 1.216813700539725, 6.984147701944623, 0.22218930455190794, 6.806530032839094, 55.64491592134748, 48.652700492313926, 51.62113421303885, 46.84884738922119, 50.95009803771973, 48.03790651048933, 56.877394335610525, 55.54087012154715, 55.59034824371338, 51.24761642728533, 51.83634771619524, 52.09937872205462, 53.12252180916922, 54.09072896412441, 55.74231924329485, 49.439834117889404, 42.92557832172939, 49.408928530556814, 56.28559194292341, 52.40734372820173, 46.149285384586875, 54.54099655151367, 55.760982104710166, 54.70990725925991, 55.75462102890015, 49.89951304027012, 51.24112680980137, 48.628440856933594, 44.96842861175537, 48.068120752062114, 44.51917893545968, 45.137252467019216, 50.07281848362514, 49.474186011723106, 49.49541275841849, 47.595862116132466, 52.50034884044102, 50.02595635822841, 49.87475313459124, 48.28182649612427, 43.838144302368164, 39.93666825975691, 40.12458576474871, 40.473868233816965, 39.390039580208914, 39.188208307538716, 40.896374293736045, 41.399104254586355, 37.629932335444856, 39.96451316561018, 40.181786809648784, 40.276577608925955, 46.63703850337437, 44.85140010288784, 46.32054805755615, 46.45439468111311, 47.09402847290039, 57.54410178320748, 48.537054674965994, 42.59934302738735, 42.23589318139212, 41.48672103881836, 46.948543616703574, 50.01131302969796, 56.40469101497105, 52.74891717093331, 42.25129386356899, 44.84576163973127, 49.169448443821494, 44.635755811418804, 44.235862663814, 45.68581274577549, 43.58277715955462, 40.428830010550364, 40.58010619027274, 38.458501543317524, 40.187765734536306, 37.972415992191856, 42.32141160964966, 39.57916954585484, 41.934195450374055, 40.7575284412929, 44.13282435280936, 49.18595041547503, 50.829616274152485, 48.137647901262554, 50.19569737570626, 46.755946499960764, 47.09905896868025, 49.78130333764212, 50.37940427235195, 47.04629782267979, 43.06742927006313, 48.389158793858115, 42.62632288251604, 43.63457945414952, 43.96702296393258, 46.374334062848774, 53.789187567574636, 52.42056615012032, 53.84958825792585, 47.28615311213902, 32.03556939533779, 52.139956201825825, 49.02849381310599, 56.920407158987864, 53.645474502018516, 54.946500369480674, 50.77353736332485, 43.08342054912022, 42.781469208853586, 46.03424753461565, 48.52831384113857, 51.73129095349993, 53.90789754050118, 52.08522176742554, 57.61092260905674, 54.98820693152291, 59.747448512486045, 56.998723779405864, 62.414160183497835, 56.72245645523071, 59.2811062676566, 56.22336040224348, 67.80444758278983, 12.92285989012037, 0.5249853666339601, 7.938706857817514, 1.6796220264264514, 0.6380003680075917, 14.106330054146902, 75.96109076908657, 63.57336984361921, 69.05916023254395, 63.339646339416504, 71.86671883719308, 48.50416190283639, 65.36351067679269, 33.13314158575875, 50.03668785095215, 64.41093349456787, 52.04867771693638, 0.36555751147014753, 0.1329057261879955, 0.12809401723955358, 0.19530186589275086, 0.1425675084548337, 0.09864032521311726], [0.06493281573057175, 0.11799067152397973, 0.09322816705597298, 0.057405738559152396, 0.10881077125668526, 0.024273024572591697, 0.033818310858415704, 0.04564843320154718, 0.42283482370632036, 38.09921366827828, 47.61380583899361, 36.28948238917759, 22.764544589178904, 32.40283032826015, 34.779010023389546, 36.384540694100515, 61.52743107931954, 46.880381788526265, 58.173653738839285, 49.774977002825054, 54.463736057281494, 36.577825682503835, 0.02727941476872989, 1.3066675875868117, 1.137277888400214, 4.837185604231698, 0.05451600379975779, 0.3555108777114323, 26.66632287842887, 40.27401719774519, 38.842917578560964, 41.036321435655864, 45.337155614580425, 49.33608709062849, 52.276321547372, 51.31347145353045, 50.73454407283238, 46.50132628849575, 48.73125682558332, 47.06887251990182, 48.451570987701416, 48.17247922079903, 50.374262605394634, 40.87153795787266, 38.543780258723665, 48.03515502384731, 49.36025292532784, 48.90237011228289, 45.577792576381135, 52.27777024677822, 50.108837945120676, 48.457890374319895, 48.07292195728847, 48.18625055040632, 47.868884631565635, 47.03892230987549, 41.78218970979963, 43.09947088786534, 43.7269036429269, 37.829957076481406, 44.36710371289934, 46.17042875289917, 43.37272269385201, 43.29584782464163, 44.80317613056728, 44.410144329071045, 45.75874103818621, 43.434450490134104, 40.78044360024588, 37.762531757354736, 37.90939235687256, 36.871473925454275, 36.41310821260725, 36.342702116285054, 37.283408301217214, 34.78045872279576, 35.53485591070992, 35.9577545438494, 35.23949146270752, 39.602869851248606, 42.62377289363316, 46.141055243355886, 47.32233238220215, 41.7471673148019, 36.491438729422434, 39.807959829057964, 37.836266040802, 42.126802989414756, 36.4858523777553, 40.742075647626606, 39.9891688483102, 40.62939671107701, 46.534663745335166, 39.11380352292742, 43.584055628095356, 46.33938809803554, 43.05665956224714, 38.85194328853062, 42.196632385253906, 36.91652604511806, 38.41617659160069, 36.968939781188965, 36.21302441188267, 35.63182497024536, 37.14110919407436, 36.856768063136506, 36.29988036836897, 35.0556629725865, 35.956844329833984, 34.92097561700003, 43.22637973512922, 45.15361200060163, 45.462028639657156, 42.27915961401803, 47.190521580832346, 44.54849338531494, 45.86589963095528, 41.269697529929026, 46.14763518742153, 39.757050377982004, 42.12413140705654, 43.05245590209961, 40.63481283187866, 42.60823324748448, 47.40131255558559, 43.43504803521292, 48.043520654950825, 45.94492844172886, 54.60100466864449, 29.535857677459717, 33.26186738695417, 54.71064029421125, 47.7126578603472, 50.00481646401541, 49.092445032937185, 47.905803884778706, 40.16589627947126, 38.94495187486921, 39.11117015566145, 41.07081576756069, 45.25525719778878, 45.41117477416992, 47.438634804316926, 46.33417694909232, 51.78586905343192, 50.39318602425711, 56.745593956538606, 53.974881649017334, 58.72005312783377, 49.56299441201346, 58.21040276118687, 54.03930882045201, 62.83959838322231, 16.67120545251029, 0.29158077389001846, 0.8916941891823496, 0.19526701633419308, 0.6026356113808495, 15.50304651260376, 64.36791024889264, 55.50788702283587, 55.96531125477382, 53.12986258098057, 52.80571174621582, 39.28110572269985, 46.25109733854021, 19.99126492227827, 34.32140513828823, 50.669387340545654, 19.23453140258789, 0.48998332768678665, 0.19146599886672838, 0.06063331251165696, 0.04752252656700356, 0.034044225700199604, 0.03298384170713169, 0.03143973009926932, 0.099179333075881, 0.05928435775318316, 0.07321297177778822, 0.12486552047942366, 0.08551250464682068, 0.08129570127597877, 0.01991809013166598, 0.8080831500036376, 49.04691001347133, 57.1650949205671, 41.89455597741263, 32.518510886601035, 46.23426532745361, 38.1789095061166, 42.46615648269653, 65.57688985552106, 54.066681248801096, 64.98263822283063, 55.041798387254985, 60.81245449611119, 41.09628438949585, 0.07670005144817488, 1.7640344968863895, 0.26590340744171825, 4.181663019316537, 0.19875152435685906, 0.29355425227965626, 35.32440539768764, 44.12962123325893, 43.35271883010864, 45.357882090977256, 49.69782073157174, 52.92839956283569, 55.59808506284441, 53.97181749343872, 53.7992068699428, 49.14060994556972, 50.233794348580496, 48.41302238191877, 51.251239912850515, 51.41602686473301, 50.9160727092198, 42.62240062441145, 40.80873319080898, 51.94557339804513, 51.209092140197754, 49.67486040932791, 45.56665113994053, 53.42509848730904, 51.26371887751988, 50.42686741692679, 49.5112372807094, 50.650821753910606, 49.867617334638325, 50.60951471328735, 42.2162367275783, 43.9641637802124, 43.34401273727417, 40.72454186848232, 47.035625389644075, 47.330802236284526, 45.967579569135395, 45.89935868127005, 47.6301896912711, 47.476988860539024, 50.28919928414481, 47.64779642650059, 42.22211837768555, 38.73463685171944, 38.03881645202637, 38.429430280412944, 37.82860565185547, 38.85279444285801, 38.53907285417829, 37.156513350350515, 37.135540212903706, 37.916566371917725, 37.70658138820103, 41.692231382642476, 44.89271756580898, 49.26076166970389, 48.223013469151084, 42.387284006391255, 37.18353489467076, 40.60115923200335, 40.455997467041016, 43.9700072152274, 37.92264951978411, 42.41789776938302, 40.85391732624599, 43.1453845841544, 47.91768530436924, 40.49744694573538, 43.169467040470664, 46.37859330858503, 42.5134528705052, 39.78923095975603, 42.560314995901926, 39.12516035352434, 39.474873610905235, 39.24628829956055, 37.3016369002206, 37.75132778712681, 39.10611186708723, 37.12910965510777, 37.7035346031189, 36.7340316091265, 38.18619121823992, 36.01714774540493, 43.92073059082031, 48.610021182468955, 48.571441309792654, 45.38650866917202, 49.6727933202471, 46.710223879132954, 47.20859037126814, 43.83176238196236, 48.24109615598406, 42.7125917162214, 42.911039216177805, 43.41433892931257, 40.84402656555176, 44.33380447115217, 48.08253826413836, 47.135613441467285, 51.04921061652047, 48.06981611251831, 54.72967141015189, 32.72751270021711, 35.665568896702354, 56.07195568084717, 51.2328063419887, 52.1174509865897, 51.372107301439556, 50.47065496444702, 41.56438800266811, 40.84134108679635, 40.89444269452776, 41.06794616154262, 46.290184429713655, 47.98940461022513, 49.025763171059744, 47.93089382989066, 53.15719332013811, 52.30003227506365, 60.60871941702706, 56.76760932377407, 61.793387276785715, 54.136361258370535, 61.060310636247905, 56.782596588134766, 67.69490923200334, 19.009715488978795, 0.16915183195046016, 1.0342460913317544, 0.16425844095647335, 0.7118507080844471, 16.48725536891392, 70.88332639421735, 59.10847132546561, 63.79589285169329, 56.32570736748831, 60.61678627559117, 42.03927305766514, 55.46371732439314, 21.754137550081524, 38.40517411913191, 60.379630361284526, 23.85250915799822, 0.44521375000476837, 0.25313294412834303, 0.12256831303238869, 0.12246736059231417, 0.02768030682844775, 0.04132973422695484, 0.15256863965519837, 0.1633746898067849, 0.13583437832338469, 0.21910543074565275, 0.2990705519914627, 0.1887965471084629, 0.1834476962685585, 0.1797984263726643, 0.811614137675081, 60.163673400878906, 65.06677395956856, 51.39606121608189, 31.072976384844097, 47.89272042683193, 46.488246304648264, 45.98033993584769, 71.79209518432617, 59.18416500091553, 68.21753188541958, 60.14268984113421, 65.37817137581962, 45.769337041037424, 0.12161820115787642, 2.1132948185716356, 1.8798954912594386, 10.850456305912562, 0.17123777073408875, 0.7916810044220516, 41.452073846544536, 51.15383659090315, 50.301400320870535, 48.38111972808838, 51.92695917401995, 54.28230816977364, 58.49425057002476, 55.224483898707796, 54.741142886025564, 50.1874463898795, 53.53149972643171, 51.79502330507551, 53.426936285836355, 53.82107285090855, 54.91938155038016, 44.179745537894114, 43.23406444277082, 53.49588326045445, 52.90605763026646, 53.806241921016145, 46.64849260875157, 55.40937198911394, 53.88453074863979, 53.43972791944231, 51.55074896131243, 52.522871426173616, 52.30900934764317, 52.62483971459525, 45.870405537741526, 46.86020769391741, 47.94398076193673, 40.925581046513145, 49.98128638948713, 53.442482880183626, 49.99659327098301, 47.933079038347515, 50.5523727280753, 50.649654456547324, 52.982261998312815, 50.29439306259155, 44.40683698654175, 41.239177567618235, 41.78372873578753, 40.41845635005406, 40.23162276404244, 42.17110122953142, 40.87624536241804, 40.60521003178188, 40.10119118009295, 41.40857812336513, 40.056573322841096, 45.99030017852783, 47.57411772864205, 51.11925540651594, 50.742610931396484, 42.291308539254324, 37.9082042149135, 40.66992902755737, 42.21946069172451, 46.181545870644705, 39.31356770651681, 44.31827177320208, 43.73551940917969, 44.91096700940813, 47.069713251931326, 41.73959725243704, 45.54011944362095, 50.56707511629377, 48.08128758839199, 43.06333678109305, 45.02164486476353, 41.994478021349224, 43.467628138405935, 39.62748384475708, 39.899630887167795, 39.822540623801096, 40.29478883743286, 40.50663941247122, 39.214086873190745, 39.018529823848176, 40.867528847285676, 40.13200296674456, 47.16982289722988, 51.800891058785574, 51.282607555389404, 48.191447802952354, 53.970507758004324, 49.74978978293282, 51.1162120955331, 47.96204260417393, 51.092727184295654, 45.45571967533657, 46.04959610530308, 46.50257349014282, 43.57199355534145, 46.40093524115426, 51.177561214991975, 49.284211839948384, 52.69137219020298, 51.214727129255024, 57.918463775089805, 32.497450896671836, 37.25592817578997, 57.861415590558735, 51.71607092448643, 54.10824884687151, 53.74047374725342, 53.83919375283377, 43.57972342627389, 41.67419038500105, 41.4983696937561, 43.552034854888916, 50.23042099816458, 49.89608757836478, 51.209547247205464, 50.58217007773263, 56.14830943516323, 54.06812647410801, 60.65007509504046, 58.21464811052595, 62.780364990234375, 55.605540479932515, 64.1336030960083, 59.704640660967144, 70.27744347708565, 21.134172371455602, 0.30978022302900043, 3.1687596227441515, 0.5128820389509201, 0.6946490311196872, 19.62957991872515, 76.63059139251709, 63.681059973580496, 65.99553271702358, 62.304552350725444, 64.45294925144741, 49.1416209084647, 59.644469261169434, 29.694113322666713, 48.660572801317485, 69.74135521480015, 33.185909679957796, 0.5685409637434142, 0.3584057795149939, 0.26454978436231613, 0.1955261081457138, 0.13327012663441046, 0.2038771914584296], [0.028006554947101643, 0.09826550246881587, 0.0476113637643201, 0.12141801975667477, 0.09983546965356384, 0.047179218381643295, 0.03751313081011176, 0.21014651576323168, 0.5285855105945042, 24.140268802642822, 52.4624742099217, 41.41640526907784, 29.36030796595982, 25.045858791896276, 34.26045554024832, 36.41070760999407, 67.55817563193185, 45.82648944854736, 56.32075677599226, 51.24183900015694, 53.972196170261924, 44.38318531853812, 1.5093298213822501, 2.341901191643306, 0.811577496784074, 3.676929371697562, 1.3027790933847427, 0.11615246587565967, 15.282425573893956, 38.99797010421753, 37.075441769191194, 38.89629711423601, 48.516380310058594, 54.22587142671858, 52.63596725463867, 52.07980564662388, 50.531979765210835, 46.23646443230765, 47.30160937990461, 46.24529559271676, 47.19887331553868, 47.793948309762136, 43.767432485307964, 36.294690064021516, 38.304473876953125, 45.231834820338655, 49.381934779030935, 49.146029540470664, 49.856580121176584, 49.57098136629377, 48.784955978393555, 48.56812701906477, 50.91319962910244, 47.77903400148664, 48.71087775911604, 48.131467478615896, 46.9294638633728, 41.65513495036534, 42.39574343817574, 38.3930356161935, 42.52838454927717, 44.661835874829976, 42.70276696341378, 42.92505373273577, 44.82526445388794, 45.064935616084504, 43.53547729764666, 43.697742053440635, 42.08290427071707, 40.8530661719186, 38.10928855623518, 34.9579713003976, 36.43294184548514, 35.26171875, 35.243611744471956, 34.16583497183663, 34.56205947058541, 36.71745320728847, 37.53819179534912, 41.5943729536874, 46.11207430703299, 46.98614379337856, 43.920237268720356, 37.34595945903233, 38.45843553543091, 37.185299737112864, 37.27566105978829, 46.92513166155134, 40.43758474077497, 41.639980929238455, 43.73196193150112, 37.696714946201865, 37.56077691486904, 35.94326407568795, 34.48445504052298, 37.76100662776402, 44.99660703114101, 45.36824532917568, 48.35363960266113, 39.912759508405415, 36.314051219395225, 36.0515204838344, 36.08107117244175, 36.19026211329869, 37.9208117212568, 36.20959200177874, 37.30375262669155, 35.47520909990583, 35.7065806388855, 35.82197284698486, 40.44906316484724, 45.766345841544016, 45.5968827520098, 44.81871577671596, 46.14550903865269, 45.367762429373606, 43.93138912745884, 43.25315809249878, 46.54661117281233, 40.73489815848214, 42.92410182952881, 41.37803036825997, 43.41681596211025, 46.68363659722464, 48.31180797304426, 49.69232470648629, 49.83221973691668, 49.92122963496617, 46.30877433504377, 40.521734373910085, 47.277634620666504, 47.952485357012065, 49.008538586752756, 47.4848507472447, 48.90257855824062, 41.63764980861119, 39.15733398709978, 36.77471331187657, 37.53798334939139, 39.546683243342805, 47.404616424015586, 44.408480235508506, 51.517609528132844, 45.3656918661935, 49.62692478724888, 46.552774224962505, 56.321097237723215, 51.8724297114781, 59.78423922402518, 49.708784988948274, 57.115099157605854, 53.73090607779366, 66.18475995744977, 18.382411275591167, 0.8143709440316472, 0.2997745999268123, 0.20459039961653097, 0.31962804602725164, 34.280000822884695, 61.40061950683594, 52.456439699445454, 49.76692404065813, 58.3105263028826, 49.70645734242031, 40.37720142092024, 43.52885913848877, 28.46634578704834, 33.415356567927766, 51.845706939697266, 9.045963100024633, 0.6041195403252329, 0.07611386504556451, 0.1134434894525579, 0.01692514680325985, 0.0417266568568136, 0.1182791031897068, 0.03322675385113273, 0.08871245543871607, 0.03832340679530587, 0.04201540743399944, 0.08622624884758677, 0.11561930019940649, 0.15517004792179379, 0.2569027218435492, 0.518303316618715, 32.97424323218209, 62.3672251020159, 43.77288334710257, 28.93726168360029, 39.42904329299927, 38.04969385692051, 42.76461982727051, 73.68390900748116, 51.59570033209664, 64.91369124821254, 55.9805451801845, 58.8775965826852, 48.18461077553885, 1.385719848530633, 3.0267655849456787, 0.6733638761298997, 4.412356674671173, 2.3523456369127547, 0.3206773597214903, 20.30139602933611, 43.826499121529714, 41.74359246662685, 43.871777057647705, 50.31360830579485, 55.94248642240252, 54.26231472832816, 53.03275803157261, 51.99264049530029, 48.20490993772234, 49.837191173008506, 48.891673360552105, 49.077634947640554, 49.18525212151663, 46.268763133457725, 39.98797375815255, 41.09922695159912, 47.59604971749442, 52.979447977883474, 51.836966105869834, 51.38108784811837, 49.84239884785244, 52.29247610909598, 49.13576357705252, 51.90450259617397, 49.977669852120535, 50.02556031090872, 50.11202369417463, 50.13643618992397, 42.82105657032558, 44.27524157932827, 41.451858452388215, 45.30711507797241, 45.974326269967214, 46.62643207822527, 46.59392840521676, 47.888676575251985, 47.91465936388288, 46.60202305657523, 46.37445913042341, 43.8074506350926, 43.688257762363975, 39.588487080165315, 36.61768402372088, 37.323787757328574, 36.19949974332537, 36.784607546670095, 38.30393539156233, 37.11290298189436, 36.696282046181814, 38.6600409916469, 43.348459584372385, 49.498876435416086, 48.65769624710083, 46.0514269556318, 36.59705829620361, 37.868092264447895, 37.27255868911743, 37.81646020071847, 47.1011642728533, 40.94494915008545, 42.28005245753697, 45.18702936172485, 38.94742543356759, 37.44546808515276, 36.16482823235648, 36.17060565948486, 41.97871603284563, 48.69832583836147, 47.33926166806902, 48.82869141442435, 40.31206553322928, 38.744868074144634, 37.97478532791138, 36.93289600099836, 37.979621274130686, 38.77867800848824, 38.28596387590681, 38.78676571164812, 37.943105016435894, 37.11438642229353, 37.00007813317435, 42.421875613076345, 49.232461656842915, 48.34629883084978, 46.48098891122, 47.84341253553118, 48.05587107794625, 46.71486874989101, 46.574779169900076, 47.81814888545445, 43.45264434814453, 46.05611004148211, 43.38122728892735, 46.15354115622384, 49.73299598693848, 50.43770660672869, 51.57166651317051, 52.09429611478533, 52.31312962940761, 48.58756807872227, 40.07334280014038, 49.00989695957729, 48.0142548424857, 49.882107802799766, 49.30766895839146, 50.62474863869803, 43.68419654028756, 41.55130454472133, 38.94279793330601, 38.02938427243914, 42.927416120256694, 49.778725555964876, 47.382646220070974, 52.267632825034006, 48.25789342607771, 50.05056687763759, 49.47431802749634, 57.385818345206125, 55.027314867292134, 63.023454666137695, 51.72598947797503, 59.67136573791504, 57.64152594975063, 71.14309869493756, 24.017752953938075, 0.8923827122364725, 0.9794758302824838, 0.07696194560932261, 0.3601490988263062, 38.461749826158794, 69.59241362980434, 57.71667071751186, 55.25225237437657, 62.666435377938406, 57.84577866962978, 42.22279930114746, 55.72353131430489, 34.855190072740825, 38.18713617324829, 62.362083435058594, 10.843100769179207, 0.6042512304016522, 0.2655169410364968, 0.1021892601358039, 0.05430859600060752, 0.05711774115583726, 0.09387368456061397, 0.0785757325855749, 0.22870750193084988, 0.15180376784077712, 0.20087252983025142, 0.26189733669161797, 0.2910401443285601, 0.3535010027033942, 0.4978765355689185, 0.7134192639163562, 38.72271721703665, 75.18242699759347, 55.94217027936663, 41.44992685317993, 38.749954155513215, 49.19874552318028, 48.196252482278005, 77.96463857378278, 56.93624210357666, 68.34467697143555, 61.32527324131557, 63.35938617161342, 53.33791249138968, 2.23025666815894, 3.450450667313167, 1.1109917674745833, 10.478429777281624, 4.2658499990190775, 0.2621766488466944, 27.494827815464564, 51.57110718318394, 47.540412017277305, 48.39425182342529, 52.0883206639971, 59.63605499267578, 57.23846789768764, 55.66597938537598, 57.25375393458775, 50.90510845184326, 51.730457169669016, 50.724232946123394, 51.21206596919468, 52.742635999407085, 48.101322719029014, 41.831473282405305, 43.313343388693674, 48.908078057425364, 55.982848508017405, 53.89515801838466, 54.48352105276925, 53.17944145202637, 54.337577615465435, 51.04620899472918, 55.10551336833409, 52.15376227242606, 51.690511975969585, 52.34275327410017, 52.07757874897548, 45.2646198953901, 47.72321564810616, 45.73607948848179, 47.62284891945975, 50.02180828366961, 50.238922119140625, 51.17059564590454, 50.563673973083496, 52.030355317252024, 48.38628223964146, 49.54169818333217, 47.01587513514927, 48.09704957689558, 41.44957249505179, 38.71331977844238, 39.59424366269793, 40.31281246457781, 39.68439653941563, 40.271380356379915, 38.6106219291687, 41.103149209703716, 40.25727898733956, 44.553169522966655, 51.78415979657854, 52.473580905369346, 45.76088455745152, 36.30106851032802, 39.59202718734741, 36.60150514330183, 38.0397891998291, 50.12101813725063, 42.24088198798043, 44.20682961600167, 47.960083212171284, 39.55674076080322, 36.53333984102522, 36.27760444368635, 36.45022896357945, 41.89960731778826, 49.42426667894636, 48.66314363479614, 52.6855912889753, 44.61783293315342, 39.936640466962544, 40.44010346276419, 39.30422237941197, 40.196596894945415, 41.556460108075825, 41.62378467832293, 39.45424440928868, 42.50001505443028, 40.165771211896626, 41.098646777016775, 45.578400543757844, 52.783710275377544, 50.90140158789498, 51.44482019969395, 52.30349595206124, 51.34995297023228, 49.26769944599697, 49.78427021844046, 49.366061619349885, 45.98076377596174, 48.33709594181606, 45.24222237723214, 47.28188344410488, 52.2000789642334, 51.05320235661098, 54.57266296659197, 52.949890341077534, 54.74684388296944, 48.33548395974295, 41.26747758047921, 49.690316677093506, 49.92710086277553, 52.00228806904384, 52.11451884678432, 53.62008578436715, 45.758737564086914, 43.508678095681326, 40.60512317929949, 39.389490672520225, 43.695282391139436, 52.20432778767177, 48.270247323172434, 55.28308500562395, 50.36996167046683, 52.3011474609375, 51.4616174697876, 59.343480246407644, 56.28681482587542, 65.21284593854631, 54.30328130722046, 59.921757970537456, 59.208747727530344, 70.95849895477295, 26.811185870851787, 0.9883539995976857, 4.605015456676483, 0.8463134957211358, 0.8956364776406969, 41.596599851335796, 73.7090892791748, 60.9650855745588, 61.416892187935964, 67.81056894574846, 61.62311472211565, 50.469765595027376, 58.68354034423828, 40.2867636680603, 47.35944618497576, 73.0265051977975, 17.174545117786952, 0.8206542868699346, 0.4623070242149489, 0.2610509321093559, 0.20145065523684025, 0.2559202845607485, 0.23631971489105905], [0.0396327351086906, 0.06220435856708458, 0.0541686922577875, 0.061675352310495715, 0.07665718160569668, 0.05721478523420436, 0.04053892201877066, 0.06505742868674652, 0.45179116992013796, 9.68850644997188, 60.436279024396626, 42.14668525968279, 49.632511138916016, 29.71424225398472, 37.51339714867728, 28.68411796433585, 56.18333183016096, 47.617203508104595, 48.851363386426655, 54.944151878356934, 47.87435286385672, 54.73516743523734, 2.3968273528984616, 2.8033295401505063, 0.15712930421744073, 1.5263722326074327, 1.4182350294930595, 0.49574729268039974, 7.96805431161608, 35.58842652184622, 37.72613361903599, 40.541328293936594, 50.19560704912458, 53.932897159031455, 51.84210082462856, 51.09924112047468, 47.12348188672747, 47.31819820404053, 45.34976659502302, 47.922267641339985, 46.4122052192688, 44.548865113939556, 40.632002285548616, 36.12813479559762, 39.81012071881975, 43.90064682279314, 49.71355492728097, 48.29360021863665, 48.39498485837664, 48.06217656816755, 50.54644591467721, 48.658043657030376, 48.54571907860892, 49.100755078451975, 48.95063577379499, 49.14033896582467, 52.10373524257115, 46.15921088627407, 41.082936900002615, 38.623246806008474, 43.33185338973999, 43.70711864743914, 44.67758049283709, 42.63323981421334, 44.29330342156546, 44.48105069569179, 45.38677270071847, 45.037462438855854, 42.52301011766706, 42.15655517578125, 37.22753088814871, 36.42430523463658, 35.738872391836985, 35.506819929395405, 35.15436560767037, 35.05948448181152, 36.04690687997, 36.85945354189192, 38.73757593972342, 45.40518542698452, 47.134755338941304, 46.24574375152588, 41.695472717285156, 36.2689539364406, 34.684879302978516, 34.927100454057964, 36.52761452538626, 45.60258722305298, 46.87069599969046, 44.761007513318745, 44.79662050519671, 36.09183393205915, 36.70493950162615, 35.39417920793806, 38.597204957689556, 38.98799596514021, 44.43684278215681, 46.32057237625122, 47.378720487867085, 42.061330114092144, 37.51877505438668, 35.87038442066738, 37.98596845354353, 34.10887711388724, 35.52306481770107, 36.02035433905465, 36.747657026563374, 35.71637759889875, 35.00179706301008, 35.828181062425884, 41.30132572991507, 44.369952474321636, 45.51452922821045, 46.48618963786534, 44.412930556706016, 42.42179570879255, 44.140599387032644, 44.18173967088972, 44.12557390757969, 39.08064324515206, 40.911142689841135, 44.18638106754848, 47.54443849836077, 51.16952214922224, 49.5823312486921, 44.15359251839774, 47.98217848369053, 45.104220730917795, 42.1330737386431, 47.290130955832346, 48.310105664389475, 49.67983184541975, 49.10130746023995, 43.297265257154194, 40.35862193788801, 38.10789196831839, 39.90881987980434, 36.25727054050991, 40.251459871019634, 40.07759509767805, 43.78068617412022, 46.95696830749512, 47.95796748570034, 49.11409214564732, 49.08601794924055, 43.5740259034293, 48.969211782727925, 50.54697745186942, 52.530358110155376, 44.89706366402762, 56.63685464859009, 54.54042679922921, 62.739718028477256, 17.425279549189977, 1.2056336147444588, 0.501667320728302, 0.4287516219275338, 0.7428199691431863, 48.08032178878784, 57.56172241483416, 52.045533657073975, 51.44416012082781, 58.6007456098284, 41.853193351200645, 48.73288270405361, 35.87715891429356, 21.935944114412578, 38.288753577641074, 50.275976862226216, 3.5848933160305023, 0.29698731377720833, 0.13202485202678613, 0.1314969789236784, 0.11420504323073796, 0.026057844781982045, 0.04463826079985925, 0.02866965838308845, 0.12246493143694741, 0.08530762099793979, 0.04858510562085679, 0.07295622769743204, 0.1637506524899176, 0.06303742315088, 0.10948201880923339, 0.4284509766314711, 14.462962848799569, 69.88168103354317, 49.29698610305786, 44.61402532032558, 33.683022022247314, 44.3234030178615, 30.749735764094762, 65.45039790017265, 49.7848608153207, 58.062552043369834, 60.969893727983745, 53.402909415108816, 59.35297843388149, 3.0268524374280656, 2.938382978950228, 0.15297699560012135, 5.206879709448133, 5.033100051539285, 0.3859620365713324, 10.501918162618365, 40.47864859444754, 39.73212718963623, 46.4336438860212, 51.910175800323486, 57.614664213997976, 55.38514709472656, 53.369492053985596, 48.16114670889718, 49.169184412275044, 48.07814005443028, 50.58930587768555, 47.18835721697126, 47.595208985464915, 41.629725388118196, 38.03397355760847, 41.143949031829834, 46.39339644568307, 51.22363124574934, 50.676015922001426, 50.85351460320609, 49.68512289864676, 51.31374590737479, 50.726345198495046, 50.02332993916103, 51.474332673209055, 51.81938368933541, 51.37364980152675, 53.95186226708548, 46.9137852532523, 42.71702814102173, 41.911464418683735, 44.641220569610596, 46.32025623321533, 46.048262051173616, 45.209326131003245, 47.84625434875488, 47.05372197287423, 47.160731179373606, 46.58557667051043, 44.52476181302752, 45.106062003544395, 38.766633306230815, 38.95079530988421, 38.4980228969029, 36.805730070386616, 37.17454392569405, 37.597612789699006, 38.52005216053554, 38.166086605616975, 42.385046686444966, 47.842446735927034, 48.255034242357524, 49.901316097804475, 44.32498025894165, 36.09701381410871, 33.06818287713187, 35.37268148149763, 37.71833426611764, 47.797154903411865, 46.78557014465332, 46.49069207055228, 47.239457743508474, 35.66634362084525, 36.2690303666251, 36.07124989373343, 35.905556201934814, 39.5546041897365, 46.40076501028878, 47.6474038532802, 47.83764900479998, 41.61390086582729, 38.38873815536499, 36.81606551579067, 37.803366320473806, 36.905586106436594, 36.72178888320923, 37.35917493275234, 37.78622511454991, 37.55341182436262, 36.833734784807476, 37.21251930509295, 42.56112446103777, 46.82695708956037, 47.3755590575082, 48.419678756168906, 46.13256801877703, 46.99752146857125, 47.66870355606079, 45.46123654501778, 46.24024077824184, 42.162012985774446, 42.34852695465088, 45.81161682946341, 49.51279715129307, 51.47181395121983, 51.79805966785976, 45.72347545623779, 50.56081478936331, 45.41513524736677, 42.836665698460166, 50.428142411368235, 49.67946359089443, 50.619565282549175, 49.90151064736502, 44.800890173230854, 42.037518637520925, 40.13986832754952, 40.812648500714985, 37.56714841297695, 40.6486154283796, 41.83583327702114, 46.42430203301566, 48.126624584198, 51.09440170015608, 50.66668101719448, 50.1705379486084, 45.30015645708357, 51.56001785823277, 50.78496020180838, 55.78538070406233, 46.87702580860683, 57.88859346934727, 56.317400796072825, 66.62900693075997, 21.78825146811349, 1.0666109089340483, 0.2570799280490194, 0.5169552032436643, 1.2924642754452569, 53.56705365862165, 63.51234381539481, 58.88741438729422, 54.452744007110596, 65.99660968780518, 46.52686786651611, 52.040944371904644, 44.30944756099156, 23.111582790102275, 43.593168190547395, 57.45305258887154, 5.795397341251373, 0.2643735823886735, 0.1178860142827034, 0.08570885232516698, 0.12631575337478093, 0.0953901017616902, 0.03986166603863239, 0.09613796270319394, 0.22078145295381546, 0.21793539210089616, 0.19941492804459163, 0.1819962148687669, 0.27927714266947334, 0.1381031008703368, 0.34110202374202864, 0.41124208005411284, 15.068502698625837, 82.94815758296421, 55.20193004608154, 65.21938419342041, 41.64366694859096, 51.51807853153774, 39.57707118988037, 65.86627537863595, 59.42794254847935, 58.07836961746216, 66.39737483433315, 57.64013978413173, 65.06815665108817, 3.5400099073137556, 4.429126586232867, 0.18248623928853444, 8.253204039164952, 5.744631631033761, 0.6467907620327813, 14.585283279418945, 48.55342810494559, 45.0410338129316, 49.102898597717285, 52.236435413360596, 59.39967032841274, 57.588215896061485, 56.16076060703823, 50.38606412070138, 52.48952007293701, 50.185678073338096, 55.00396892002651, 49.35877990722656, 49.6952360016959, 43.360976764133994, 40.080996240888325, 45.0178233555385, 48.193438461848665, 52.934739794049946, 53.59027453831264, 52.5050492967878, 51.83172369003296, 54.13129949569702, 52.361812182835166, 51.68016958236694, 55.45364591053554, 53.29343359810965, 52.15326200212751, 57.2407990183149, 49.45764929907662, 45.39423506600516, 43.236604009355815, 47.911616052900044, 48.28781931740897, 50.54643201828003, 48.99265847887312, 51.01531730379377, 49.43828466960362, 50.1623911857605, 51.21398714610508, 47.908753395080566, 47.04870189939226, 40.699952193668906, 40.95579181398664, 39.48538623537336, 38.85427440915789, 38.85972874505179, 39.34690516335623, 41.303062779562815, 42.75715051378523, 45.72882556915283, 52.14743593760899, 52.41433361598423, 53.115142822265625, 43.186215673174175, 37.23196383884975, 32.93545143944876, 35.29866579600743, 39.255949769701274, 49.423481532505576, 50.18571628843035, 48.70377670015608, 49.38917480196272, 35.06787095751081, 35.38604286738804, 34.706231117248535, 36.20432179314749, 40.1777776990618, 47.23622335706438, 49.74594742911202, 50.16810955320086, 43.85343033926827, 41.623774256025044, 38.7814051764352, 40.31508452551705, 38.92914819717407, 38.40616076333182, 40.46195902143206, 39.02675996507917, 40.17921597617013, 38.64003365380423, 41.00182362965175, 45.49544947487967, 49.9687796320234, 49.63957398278372, 52.42065647670201, 49.74361630848476, 49.23034593037197, 51.02567706789289, 50.629282338278635, 49.34527260916573, 45.04550150462559, 44.177987643650596, 49.41013056891305, 51.79738221849714, 54.23019320624215, 55.06704814093453, 48.797414098467144, 50.98407820292881, 47.259822913578574, 43.02500704356602, 52.06674998147147, 50.994302477155415, 54.846130166734966, 52.252572604588096, 46.805938788822715, 44.41331270762852, 42.04128803525652, 43.5511975969587, 39.4587607383728, 43.25177192687988, 44.05233989443098, 48.84876823425293, 50.38462584359305, 51.15919017791748, 54.6697883605957, 53.26205900737217, 48.32438768659319, 53.251813888549805, 52.81780855996268, 57.16082525253296, 49.275217396872385, 60.373411723545615, 59.57335444859096, 65.8335771560669, 28.488901376724243, 0.8612377920321056, 1.3037263282707758, 0.6383010404450553, 1.8911960848740168, 57.91082770483834, 66.42463956560407, 63.37249047415597, 60.713685853140696, 69.83432211194719, 52.05050161906651, 60.76271234239851, 48.519159589494976, 31.862152780805314, 52.86423989704677, 69.75189563206264, 9.246102486337934, 0.7432239417518888, 0.24842678808740207, 0.3120029409016882, 0.18895228446594306, 0.17857581483466284, 0.1316946768867118], [0.017005514187206115, 0.014903176908514329, 0.025844126607158353, 0.029101946258119175, 0.07005275599658489, 0.015002938519631113, 0.04209237366116472, 0.09588843823543616, 0.026752406797770942, 0.7608630838138717, 42.93919331686837, 45.072193009512766, 39.078065463474815, 38.56471170697893, 37.90510184424264, 32.62123652866909, 45.39080613000052, 56.023314816611155, 41.55623776572091, 60.77360016959054, 44.08549322400774, 57.366325174059185, 9.63605797290802, 1.0434497403247016, 0.4775861129164696, 2.2456173981939043, 4.164087550980704, 0.12395430223218032, 2.299625094447817, 35.87764181409563, 41.378336088997976, 46.76455879211426, 53.20357254573277, 51.26743616376604, 50.27809953689575, 47.11164215632847, 48.19450153623308, 44.19293669291905, 44.1404013633728, 45.932557174137656, 43.922551018851145, 39.727381569998606, 37.82090357371739, 36.97448444366455, 40.91429369790213, 42.11211102349417, 46.75782946177891, 51.3829847063337, 50.98698949813843, 52.18710667746407, 50.86174821853638, 47.77028969355992, 46.748015131269185, 46.98899255480085, 47.584814480372835, 46.44895076751709, 50.205855642046245, 47.69133036477225, 45.36591420854841, 38.97437054770333, 40.577455452510286, 45.302161012377056, 44.965326241084504, 43.78021022251674, 45.34141138621739, 45.27545213699341, 44.18869481767927, 44.02901826586042, 42.66391263689314, 40.647840704236714, 36.915601934705464, 37.05757795061384, 35.78230210712978, 35.13412203107561, 34.766548429216655, 35.54852649143764, 34.93788405827114, 35.623073714120046, 40.1663270677839, 47.930122579847065, 48.5385103225708, 47.241431031908306, 43.72553832190377, 34.13245235170637, 34.92519664764404, 33.75898667744228, 36.740496907915386, 43.77610731124878, 51.49188034875052, 46.13526044573103, 40.54787697110857, 36.11318574632917, 36.79472759791783, 36.44418403080532, 35.97211299623762, 37.23403787612915, 42.38770089830671, 50.88382959365845, 53.37152787617275, 46.953369140625, 38.68678460802351, 36.23692274093628, 35.19073942729405, 35.070566858564106, 35.52338096073696, 37.410511698041645, 36.643673760550364, 35.390204838344026, 34.24944959368025, 36.77122531618391, 40.05741058077131, 41.93586649213518, 43.98075260434832, 43.054363182612825, 42.76972327913557, 43.0134209224156, 43.074756145477295, 44.408000809805735, 43.8803893498012, 39.32343067441668, 38.612501416887554, 44.275529929569785, 46.949763025556294, 46.16987637111119, 28.672328608376638, 34.028104305267334, 41.958086831229075, 37.85949386869158, 51.99771615437099, 50.75437075751168, 48.57381411961147, 47.191883427756174, 42.53185517447335, 39.07921191624233, 41.35163416181292, 44.375910554613384, 41.074189117976594, 36.372964995247976, 37.25197465079171, 38.770114353724885, 41.02843175615583, 42.05282899311611, 47.68158204214913, 47.81187118802752, 47.592311586652485, 46.17121737343924, 45.112520354134695, 44.31998103005545, 45.75869934899466, 47.51182018007551, 56.75539091655186, 53.18244654791695, 61.01816981179373, 7.520262888499668, 2.020850339106151, 0.3780287951231003, 0.5787892852510724, 3.0762571692466736, 54.593702111925396, 56.20565291813442, 45.591282503945486, 47.778485093797954, 55.79495184762137, 45.095625809260774, 46.87836333683559, 33.55943441390991, 54.125223296029226, 33.84392493111746, 40.99892970493862, 1.0456674098968506, 0.2410346647458417, 0.04981928618092622, 0.0345070001536182, 0.07900287716516427, 0.027217225337933217, 0.05532074972454991, 0.0787152936682105, 0.01942931760900787, 0.038396864996424744, 0.02195455862342247, 0.06311576001878295, 0.04858227952250412, 0.05553364687200103, 0.07406668418220111, 0.104451760516635, 1.6566693037748337, 54.668391772678916, 51.904172556740896, 41.44017505645752, 40.58041538511004, 48.72050448826381, 33.950319222041536, 51.46537297112601, 57.87624304635184, 44.862142017909456, 66.64295196533203, 49.61462300164359, 62.88510908399309, 10.781318255833217, 1.3026738933154514, 0.22161628172865935, 2.3712419143744876, 3.983968096120017, 0.33796151940311703, 2.927040479012898, 38.79007305417742, 42.64406163351876, 48.59706974029541, 55.453433990478516, 53.17711727959769, 50.974621704646516, 49.80900927952358, 49.11006566456386, 46.15606682641165, 46.14096144267491, 46.453095367976594, 45.784970487867085, 42.88402809415545, 40.43946075439453, 38.383888312748496, 41.75382716315133, 44.65816027777535, 49.35572964804513, 53.10248667853219, 52.394715377262656, 50.77306488582066, 51.15906163624355, 48.64654786246163, 47.38697842189244, 50.4962660244533, 48.395787375313894, 48.77694123131888, 50.17036076954433, 49.51262692042759, 47.14794301986694, 42.708843163081575, 43.897846698760986, 47.79718617030552, 48.62317412240164, 47.46166460854666, 47.90729079927717, 47.68105050495693, 46.61801086153303, 45.6061064856393, 45.603011063167024, 43.19470637185233, 40.23288038798741, 38.77600295203072, 37.915659632001606, 37.56856237139021, 35.5030574798584, 36.309121472494944, 36.71921457563128, 37.81562294278826, 43.03708301271711, 47.70772463934762, 50.80967147009713, 49.23448010853359, 43.74246413367135, 33.208119596753804, 34.449283259255544, 33.38644511359078, 36.019735949380056, 46.38317217145647, 52.8270149230957, 48.77942521231515, 42.99345874786377, 36.16232688086373, 36.54890033176967, 35.64336940220424, 35.515932491847444, 37.71150071280343, 40.44314677374703, 52.67687477384295, 55.94014835357666, 46.88478694643293, 39.90626989092146, 37.721429688589915, 37.61204767227173, 36.805076939719065, 36.222658089229036, 38.966074398585725, 37.97664049693516, 37.61130768912179, 37.11885758808681, 39.3483156476702, 42.65311166218349, 44.83124337877546, 47.584585189819336, 45.8370680809021, 45.9006336757115, 45.10881349018642, 46.011971609933035, 47.374131202697754, 45.95262009756905, 42.212359632764546, 41.43031556265694, 46.272494316101074, 50.446106978825156, 48.49674470084054, 31.483583654676163, 35.741161823272705, 42.31107269014631, 38.07713924135481, 53.283747809273855, 54.393316064562114, 51.69336421149117, 47.752613476344514, 43.736297607421875, 40.195773533412385, 41.79064219338553, 45.61698389053345, 41.81751435143607, 37.70624440056937, 38.39601639338902, 40.32005943570818, 43.41830287660871, 44.06627450670515, 49.08637925556728, 49.059326444353374, 50.500671182359966, 47.4390412739345, 47.91611501148769, 46.86324405670166, 47.8190313066755, 49.125733852386475, 60.718417576381135, 57.82319007601057, 66.34242153167725, 13.207952295030866, 2.2845928839274814, 1.0944320389202662, 0.5986035934516362, 3.885388357298715, 60.634184564862935, 60.361648423331125, 56.51810993467058, 58.55574907575335, 57.63325064522879, 49.654102666037424, 50.38616834368025, 41.77419580732073, 40.92681782586234, 39.958989347730366, 52.76966796602522, 1.5508355370589664, 0.22488786546247347, 0.04253149438383324, 0.09522793189223323, 0.05476377425449235, 0.039107979873993566, 0.03591845477265971, 0.20415853921856197, 0.18402398963059696, 0.1403605325945786, 0.12032781754221235, 0.2312068992427417, 0.11533317555274282, 0.2826494888535568, 0.22754522572670663, 0.19376731823597634, 2.081175684928894, 69.07721165248326, 59.60585117340088, 52.63445602144514, 51.28603996549334, 54.503146239689414, 42.61908285958426, 56.9944680077689, 66.1459959575108, 51.17621673856463, 69.62402793339321, 54.010366099221365, 67.93070329938615, 14.157648580414907, 1.3914820764745985, 1.607770813362939, 9.807166048458644, 10.507265669958931, 0.23812184961778776, 4.056314042636326, 44.682364327566965, 46.82769012451172, 52.30200208936419, 56.87558780397688, 55.810873644692556, 51.69700854165213, 53.18173088346209, 53.077771936144146, 48.753004687173025, 48.934609753744944, 49.31312676838466, 48.698440483638215, 44.59268045425415, 42.115355832236155, 40.67201348713466, 44.85405431474958, 47.43840551376343, 51.17678301674979, 55.84190777369908, 54.295568806784495, 55.18029335566929, 54.244992869240896, 51.632991313934326, 49.25026988983154, 51.66868073599679, 50.30865771429879, 52.214010102408274, 52.35944979531424, 51.50115966796875, 49.19823135648455, 44.58868524006435, 45.7937947000776, 52.54564414705549, 53.57089948654175, 50.22231592450823, 52.21796015330723, 51.15235662460327, 49.30052968433925, 50.25418036324637, 49.30982289995466, 46.46462590353829, 41.511473996298655, 41.703112261635916, 40.462445395333425, 40.4035906791687, 38.61774035862514, 38.5199270929609, 38.44707523073469, 40.919570854731965, 44.659751415252686, 51.53330203465053, 54.948279108319966, 53.19196557998657, 46.459546770368306, 33.119898319244385, 33.59299768720354, 32.52395827429635, 35.59832075663975, 47.42363016945975, 55.9070714541844, 51.57624190194266, 44.304764475141255, 34.89029584612165, 38.53478234154837, 35.53759002685547, 35.83889865875244, 37.6688665662493, 41.75534534454346, 52.88271515710013, 57.35697289875576, 49.711060523986816, 41.500290870666504, 41.27958829062325, 40.11869369234358, 38.90254701886858, 39.05273927961077, 41.13832793916975, 37.63009909221104, 40.510561670575825, 39.05514683042254, 41.062724590301514, 44.71304757254464, 48.43642044067383, 51.51199885777065, 48.32603440965925, 49.37720305579049, 49.19299241474697, 49.09328229086739, 52.09543909345354, 49.936533042362754, 45.23639283861433, 43.00156382152012, 50.41016047341483, 52.479438236781526, 50.26426567350115, 30.42493874686105, 35.71246228899275, 44.09879902430943, 38.55411917822701, 55.54841586521694, 55.757389886038645, 53.90597983769008, 48.92770324434553, 45.57798365184239, 43.60351405824934, 43.76261738368443, 45.96466479982649, 43.94385419573103, 39.20372363499233, 39.85913678577968, 42.325740337371826, 44.6669671194894, 46.23708282198225, 52.17201519012451, 51.4658419745309, 51.648999963487896, 50.30157055173601, 50.07171024594988, 49.47637122017996, 49.109346526009695, 52.25511564527239, 61.36321040562221, 60.16357612609863, 65.7779985155378, 22.47410293987819, 2.2421361335686276, 1.6638448387384415, 1.0581482201814651, 5.243990038122449, 64.51173795972551, 67.98966571262905, 56.62806517737252, 58.84316825866699, 64.24457972390312, 57.17843198776245, 56.652310916355674, 47.084495544433594, 70.48802947998047, 46.797726018088206, 64.34467547280448, 4.672931926591056, 0.4386541891310896, 0.24900869971939496, 0.20261882112494536, 0.13487746752798557, 0.15405651767339024, 0.10166946838476829], [0.0172043758377965, 0.03323948656075767, 0.014227133809721895, 0.07576964423060417, 0.03407525849927749, 0.06371819054973976, 0.09274445301187889, 0.05073894540380154, 0.019606310075947216, 0.061073098198643753, 31.026972361973353, 54.02897684914725, 39.47453314917428, 37.2862674849374, 34.004445689065115, 39.92241055624825, 35.817995003291536, 61.29752213614327, 47.327842303684776, 52.538675103868755, 46.890661648341585, 58.655469621930806, 29.031095368521555, 0.9171221532991954, 0.26991357654333115, 2.1048972691808427, 5.973324205194201, 0.26733622912849697, 0.5445089361497334, 27.275601727621897, 49.35505567278181, 50.620517185756135, 53.401151520865305, 47.7594644001552, 48.9037458556039, 45.185521602630615, 42.82515600749424, 41.21236446925572, 39.996033668518066, 39.91131428309849, 39.75808565957205, 36.652550084250315, 38.246049949101035, 36.71840163639614, 38.72864055633545, 41.116079807281494, 45.64310564313616, 46.55919088636126, 49.57342365809849, 49.3827303477696, 49.82650136947632, 50.15230587550572, 49.54377916881016, 47.75576795850481, 48.91959817068917, 46.42276995522635, 48.781756332942415, 48.941248757498606, 47.05243655613491, 40.08837522779192, 39.13637127195086, 43.51908997126988, 45.97084174837385, 45.88949571337019, 43.57415097100394, 44.47493628093174, 42.60088900157383, 43.94437183652605, 43.81382213320051, 41.00633301053728, 37.91815403529576, 36.40724393299648, 35.49062367847988, 34.89976624080113, 35.36292621067592, 34.226114068712505, 35.68351261956351, 34.75191899708339, 41.49937718255179, 46.08205461502075, 50.6202392578125, 46.19057158061436, 41.888267857687815, 35.9790472984314, 34.6048013142177, 35.19737843104771, 37.280938216618125, 43.82872601917812, 48.011576311928884, 43.518419470105854, 38.853214808872764, 38.58716133662632, 36.20265422548567, 37.04071814673287, 35.96466800144741, 38.31642477852957, 42.061819962092805, 50.52321808678763, 53.15619625364031, 49.400086947849815, 42.994490555354524, 36.02871649605887, 36.54316806793213, 35.55798993791853, 35.0474397795541, 37.04137822559902, 37.64178943634033, 37.43323578153338, 35.51687049865723, 38.36054931368147, 40.59567362921578, 41.288468088422505, 42.1649694442749, 44.05680411202567, 41.45707654953003, 42.6838435445513, 40.63003594534737, 42.942518029894146, 43.45784854888916, 38.07358523777553, 38.475993633270264, 43.44157239368984, 47.64559384754726, 47.64182792391096, 49.65561042513166, 40.54731069292341, 42.404484272003174, 46.539020265851704, 49.15656648363386, 45.98493616921561, 45.32450294494629, 43.00633028575352, 38.532531125204905, 39.44710166113717, 39.20577335357666, 38.91488701956612, 37.18551860536848, 41.39426483426775, 39.866529669080464, 39.442588806152344, 37.26241084507534, 39.43243053981236, 42.20305946895054, 46.74034432002476, 46.54383536747524, 48.364138330732075, 45.850321769714355, 48.765379428863525, 43.307899475097656, 49.8863913672311, 54.44939150129046, 55.869971547807964, 52.92601980481829, 0.3702332420008523, 0.8028930085045951, 2.7191592795508246, 1.067467600107193, 11.078243442944117, 58.678516796657014, 52.042479923793245, 43.780039991651265, 39.35436405454363, 54.44268996374947, 47.01618432998657, 47.19776507786342, 30.95893907546997, 32.56649167197091, 44.419576508658274, 40.73066323144095, 0.16422908753156662, 0.04935408935749105, 0.02357176541616874, 0.0330873047267752, 0.035341635545981784, 0.012131710802870137, 0.05524602605562125, 0.03939459306587066, 0.032180167867669036, 0.056863029287861924, 0.03933599817433527, 0.04199115659243294, 0.05432145084653582, 0.054827739750700336, 0.06355500966310501, 0.03197363537869283, 0.08577971173716442, 38.8880808694022, 61.69823169708252, 42.75097703933716, 39.45509556361607, 45.01950134549822, 44.36353928702218, 44.13431126730782, 66.09278665270124, 46.51370103018624, 57.51358182089669, 51.49676145826067, 64.44212395804269, 33.17630379540579, 1.272791645356587, 0.25751576466219767, 2.9244713825838904, 9.302458456584386, 0.25404717507106916, 0.32567992699997766, 33.62189177104405, 51.20372118268694, 53.98225368772234, 55.399116447993684, 50.97110939025879, 51.95302186693464, 48.97511427743094, 45.81033141272408, 42.92376136779785, 43.31866570881435, 41.97513771057129, 41.087595667157856, 39.40448488507952, 39.31348432813372, 39.046878474099294, 41.7538480077471, 44.322753361293245, 47.7936703818185, 49.30700193132673, 51.971083709171836, 50.43263789585659, 52.57395110811506, 51.064548764910015, 50.423838002341135, 48.69759627750942, 49.59441416604178, 47.338115215301514, 49.33151865005493, 49.08695248195103, 49.63677385875157, 40.53027718407767, 41.38307128633772, 46.209046840667725, 48.49163777487618, 48.9750691141401, 46.669997283390586, 47.15005874633789, 45.23519080025809, 47.492024762289866, 46.11636829376221, 43.11088677815029, 40.197121483939036, 39.22567646844046, 37.43974276951381, 37.60732289722988, 38.22782482419695, 35.889981814793174, 38.188425064086914, 36.74671901975359, 44.88042967660086, 48.357686928340364, 52.25926719393049, 49.361698150634766, 43.59023257664272, 35.30136169706072, 33.560723304748535, 34.88299328940255, 35.36106061935425, 44.73385047912598, 50.398282527923584, 45.76029396057129, 38.67047718593052, 36.39929519380842, 35.623466287340435, 35.49564027786255, 35.993006229400635, 37.06975466864449, 42.506984097617014, 49.35226597104754, 53.874004227774485, 50.94000577926636, 45.30222007206508, 37.44815008980887, 36.76009777614048, 37.200606618608745, 35.83315944671631, 37.6262081010001, 39.65069430215018, 37.69690254756382, 36.31148386001587, 39.35160909380232, 43.92019557952881, 43.81169945853097, 46.25105912344796, 45.93940462384905, 44.27104834147862, 44.97741263253348, 43.664418492998394, 45.01338345663888, 44.81813907623291, 39.48094286237444, 41.36797979899815, 45.10035058430263, 49.29239681788853, 50.54565034593855, 49.08847761154175, 41.131404059273855, 43.21370622089931, 49.70717995507376, 52.17864029748099, 48.146079540252686, 47.56285122462681, 45.52170671735491, 41.95097534997122, 41.63872330529349, 41.71387849535261, 40.19746541976929, 39.45480373927525, 41.981995582580566, 40.7422319820949, 40.79744931629726, 40.66092416218349, 41.11455120359148, 45.20690468379429, 49.41023479189192, 49.34858342579433, 48.908182280404226, 48.72132090159825, 50.24610308238438, 47.242838042122976, 50.89598546709333, 59.31391566140311, 57.144305910382954, 58.7665296282087, 2.791572536740984, 1.4107587678091866, 6.459632967199598, 1.2145657411643436, 13.97295503956931, 64.24388490404401, 57.01294674192156, 47.907422815050396, 45.36613655090332, 59.42088317871094, 50.11479255131313, 53.90987777709961, 43.405671051570344, 42.857597146715435, 49.2907257761274, 50.14149100439889, 0.6079687880618232, 0.0687434548246009, 0.008546444570778735, 0.02788525154548032, 0.062209997193089554, 0.03138566103630832, 0.040005325472780635, 0.1662809909986598, 0.12578085064888, 0.09027176962367126, 0.21335952835423605, 0.11401398134018693, 0.1568543075450829, 0.14535118479813847, 0.14568555328462804, 0.17431380067552837, 0.13603126204439572, 48.04924944468907, 71.93278925759452, 53.43501704079764, 48.046143599918906, 50.62245225906372, 52.52984741755894, 45.27679313932146, 72.24422836303711, 56.98471621104649, 63.70009108952114, 54.77195814677647, 69.80524390084403, 37.82338408061436, 2.198173361165183, 0.5854141754763467, 6.381211689540318, 13.491947753088814, 0.38370726470436367, 0.7899019941687584, 38.34323787689209, 52.52508095332554, 57.118993622916086, 57.16750941957746, 53.50746243340628, 54.34419230052403, 51.19016177313668, 46.53268698283604, 44.72430712836129, 42.92236130578177, 44.943599224090576, 43.021974154881065, 41.65648637499128, 40.485127789633616, 41.908282143729075, 43.654757022857666, 45.65738071714129, 49.066872188023154, 49.946448121752056, 52.71993970870972, 53.33415004185268, 54.305515153067454, 54.51635823931013, 53.58475072043282, 50.93614605494908, 50.91398477554321, 51.079907757895334, 51.33660200663975, 51.65875176021031, 51.55918754850115, 44.00280966077532, 41.83505160467965, 48.95860535757882, 51.91978168487549, 53.19974408830915, 51.116712365831646, 48.52927269254412, 48.73962940488543, 50.5215505191258, 48.21236882890974, 47.07825606209891, 42.977429253714426, 42.380405289786204, 40.93173367636544, 39.749119009290425, 39.56024612699236, 38.96011631829398, 42.3097733770098, 41.007878984723774, 48.01544993264334, 51.32592609950474, 55.91752849306379, 54.78772013528006, 45.42262887954712, 35.903027057647705, 34.03085579190935, 35.741109711783274, 36.372527258736746, 46.16359172548567, 51.76934276308332, 48.662504400525776, 39.83111817496163, 36.918450696127756, 35.852492809295654, 35.633558545793804, 35.31524767194475, 37.448987347739084, 41.86985513142177, 50.109369482312886, 54.567538670131135, 51.87069613592965, 47.40541894095284, 39.30246448516846, 39.290107113974436, 39.565068176814485, 37.35134778703962, 38.84308433532715, 41.785521371024, 39.62520483561924, 38.09893226623535, 40.719698974064414, 46.45263678686959, 47.16270794187273, 48.16349172592163, 50.12020867211478, 48.03709009715489, 47.402222769601, 46.10162421635219, 48.64269161224365, 48.22808218002319, 40.19092716489519, 43.49528544289725, 48.4087735584804, 51.08677952630179, 52.3853075163705, 47.69026729038784, 41.04982525961739, 43.97473199026925, 50.879924706050325, 54.07045064653669, 52.1741760798863, 50.37855659212385, 47.50134229660034, 43.81767838341849, 42.58553000858852, 45.20337847300938, 42.379932812282014, 42.131277629307334, 42.616661412375315, 43.35402856554304, 43.0296310697283, 41.91706466674805, 43.95378317151751, 47.93198817116873, 49.837892941066194, 51.71139478683472, 50.900307246616904, 51.4095789364406, 51.531922817230225, 49.05078363418579, 52.39157826559884, 62.703649929591585, 57.60610750743321, 64.39739145551408, 12.505389537130084, 1.6974380761384964, 7.252313860825129, 2.0117432049342563, 15.902712106704712, 66.85977050236293, 60.39723014831543, 52.7156526701791, 50.822633334568565, 64.85274859837124, 56.79828562055315, 58.132357120513916, 43.53471646990095, 45.529377528599326, 59.42102909088135, 62.15519387381417, 1.6543070248195102, 0.2473046268735613, 0.2624219256852354, 0.17978652486843721, 0.1392463238111564, 0.07188167928584985, 0.14336446140493664], [0.0613052657406245, 0.051816024751003296, 0.06242596131882497, 0.04946754380528416, 0.01550557860173285, 0.05847699607589415, 0.12153513490089349, 0.07766810378858022, 0.09161847164588315, 0.2909967452287674, 16.484634160995483, 56.57916375568935, 31.233806337629044, 30.275281497410365, 24.37730486052377, 36.658021790640696, 30.29069607598441, 51.18523897443499, 57.47985526493618, 52.3620171546936, 47.56671094894409, 50.04186078480312, 47.60790681838989, 6.639467980180468, 0.3728020670158522, 1.2206395523888725, 3.152263513633183, 0.059586984371500354, 0.051656372246465514, 15.905744995389666, 51.966153962271555, 51.55621024540493, 53.839669704437256, 49.22537102018084, 49.057082176208496, 43.43413087299892, 38.96116202218192, 41.45322724751064, 39.33431502750942, 38.41818462099348, 39.423439570835654, 38.95543670654297, 39.02889653614589, 38.140892437526155, 39.53976283754621, 43.00313064030239, 44.77783257620675, 44.028531891959055, 47.22342824935913, 47.154519489833284, 49.782293455941335, 48.62391063145229, 49.71444429670061, 49.82681056431362, 47.29906633922032, 51.02639273234776, 49.3203251021249, 48.573115825653076, 45.051664556775776, 41.89386115755354, 38.70264387130737, 42.20120777402605, 44.18318142209734, 43.914619650159565, 44.4682799066816, 43.785039220537456, 45.19735785893032, 43.65845693860735, 44.08223451886858, 42.2291464805603, 39.601410729544504, 37.53738580431257, 33.92607348305838, 34.8233117376055, 35.358743395124165, 34.541475432259695, 35.30877195085798, 37.395281246730256, 42.020703996930806, 46.98819351196289, 46.95481089183262, 47.86805084773472, 41.4546342577253, 35.140976428985596, 34.293865953172954, 39.420198236192974, 35.508070605141775, 39.645295551845, 48.53329917362758, 42.930657454899375, 36.373951639447895, 38.161559854234966, 36.65375212260655, 34.12414230619158, 36.09208754130772, 35.49179792404175, 41.010321276528494, 47.653295925685335, 50.37962314060756, 53.3149938583374, 44.15307140350342, 37.84511457170759, 35.34211982999529, 35.155717032296316, 34.555549008505686, 35.08682564326695, 36.912926878247944, 36.983819348471506, 36.938266958509175, 37.809178488595144, 38.409690448216026, 44.88675601141793, 42.14688328334263, 44.887628010341096, 41.85947799682617, 44.39717551640102, 42.493171078818186, 45.2324914251055, 39.45358085632324, 38.79388414110456, 41.23941033227103, 42.389347621372764, 47.669384479522705, 49.912721565791536, 47.26414121900286, 43.53699895313808, 49.08332552228655, 49.1872775214059, 48.7816173689706, 48.46826750891549, 42.925623485020225, 39.062751633780344, 37.24273007256644, 36.61440794808524, 35.953509194510325, 38.99072313308716, 44.34820113863264, 49.772517340523855, 48.29410743713379, 48.12722907747541, 41.00635732923235, 38.260568210056846, 37.26825428009033, 43.10870156969343, 43.46493918555123, 46.99205323628017, 47.016229493277415, 44.6610472542899, 47.46398183277675, 53.213550158909385, 52.42818832397461, 58.712528228759766, 41.44313151495797, 3.588956709418978, 0.8094293091978345, 0.964851609298161, 0.022718777347888266, 32.39188344138009, 58.69576917375837, 51.10710995537894, 50.51242058617728, 47.5797700881958, 53.2153115272522, 49.36876794270107, 41.26698773247855, 32.19213662828718, 27.29220792225429, 43.969559056418284, 30.497575214930944, 0.3751996840749468, 0.10435556460704122, 0.04313824039750865, 0.03386252420023084, 0.05073447385802865, 0.029130244561071907, 0.046424402456198416, 0.016363477567210793, 0.02846907664622579, 0.04455808170938066, 0.019180683718462075, 0.05493786598422697, 0.04318459112463253, 0.08800153394362756, 0.026098495814949274, 0.1488943046757153, 0.20026724945221627, 20.036435161318096, 65.92948314121791, 36.51909255981445, 35.180112157549175, 39.28735562733242, 39.33196653638567, 34.925078528267996, 57.874363558632986, 62.7180118560791, 56.10047108786446, 51.87895059585571, 54.68809338978359, 52.54458107267107, 9.193947570664541, 0.349977153220347, 1.2216007922376906, 7.26497608423233, 0.9869923698050636, 0.013401075099994029, 20.325806788035802, 53.44536638259888, 53.894522258213584, 57.476155349186485, 51.0288975579398, 51.279185567583355, 44.36369562149048, 41.42121689660208, 42.820080348423545, 41.914566789354595, 41.38393633706229, 41.9214802469526, 40.962343965257915, 39.58435637610299, 40.268114703042166, 40.3732305254255, 44.28634827477591, 47.4152124268668, 46.33312777110508, 49.06119203567505, 48.68677793230329, 50.935225418635774, 51.22863047463553, 52.74926110676357, 50.327101707458496, 50.0567855153765, 51.87045989717756, 50.986086232321604, 49.77366031919207, 45.971936089651926, 43.308722836630686, 39.32442079271589, 45.67786748068673, 47.92011022567749, 46.870365960257395, 46.757645334516255, 47.15313332421439, 48.628586769104004, 46.382369654519216, 46.79796225684029, 44.20383146830967, 41.52054486955915, 39.19252661296299, 37.20385142735073, 38.628350257873535, 37.51299067905971, 37.24430731364659, 36.54794495446341, 39.47603048597063, 44.16106530598232, 49.319731031145366, 50.45039054325649, 51.086345263889854, 42.694832120622905, 35.56697048459734, 34.35517338344029, 38.208140577588765, 35.94701610292707, 40.698819637298584, 51.73562315532139, 46.43354313714163, 37.991804940359934, 37.295011792864116, 36.36936582837786, 33.78747429166521, 34.9899434362139, 34.980903829847065, 39.083047321864534, 47.220826148986816, 53.6019092968532, 53.842035566057476, 45.48757369177682, 39.555875710078645, 37.59818949018206, 37.523461614336284, 36.908883026668, 37.36807557514736, 39.433045455387656, 37.60705886568342, 38.23829575947353, 37.95529910496303, 40.61714356286185, 46.273540019989014, 44.68483441216605, 46.47290120806013, 45.10346337727138, 45.940815108163015, 46.80168996538435, 47.436154297419954, 42.58774995803833, 40.75063582829067, 43.14219536100115, 43.92944710595267, 49.649259771619526, 50.38348981312343, 49.44374942779541, 44.0666948727199, 50.773586000714985, 50.77461780820574, 50.479996817452566, 50.2659193447658, 45.616664273398264, 42.058818340301514, 40.42406702041626, 38.571701594761436, 38.40819658551897, 40.05194929667881, 45.40899651391165, 52.22952890396118, 52.273889677865164, 48.41200794492449, 44.10851608003889, 39.95624828338623, 40.22873231342861, 44.21279811859131, 46.452949455806184, 47.3630245072501, 49.43856954574585, 45.55095515932356, 51.37761722292219, 53.40673439843314, 57.10778270448957, 59.33860261099679, 47.69577373777117, 7.937798380851746, 0.8726620418684823, 0.8115985042282513, 0.5562933523740087, 39.42992571422032, 64.59602655683244, 59.067615917750764, 51.47074045453753, 48.079449789864675, 60.411057063511436, 50.71094799041748, 45.127132415771484, 40.6455408505031, 24.09113461630685, 50.882248878479004, 38.427338872637065, 0.44788997354251997, 0.17698304887328828, 0.05302160506003669, 0.0410771801003388, 0.04163728022415723, 0.12409356475940772, 0.08429048343428544, 0.2001690925764186, 0.11880219940628324, 0.13109790533781052, 0.1436053549072572, 0.16929116233118943, 0.10708805905388934, 0.15225860343447753, 0.1659494995006493, 0.28685464177812847, 0.39340597284691675, 23.901610340390885, 75.61701597486223, 44.117093631199424, 39.038071632385254, 35.28065606525966, 51.78982605252947, 38.28863893236433, 62.744630404881065, 67.67712879180908, 61.39490808759417, 57.67654487064907, 60.1356235231672, 56.78770003999983, 13.709721667425972, 0.6761364244988987, 3.68769690820149, 10.992117047309875, 0.9007968178817204, 0.2559942177363804, 23.228025913238525, 56.390099797930034, 54.476659706660676, 59.59014129638672, 53.21236201695034, 53.14088589804513, 47.95518820626395, 43.92827633449009, 45.348012174878804, 43.45769221442086, 41.53767217908587, 43.96094329016549, 42.74312557492937, 43.40627901894705, 42.403952734810964, 42.458492619650706, 46.8964147567749, 50.616831166403635, 49.11982440948486, 52.12391628537859, 51.07250445229666, 54.0679076058524, 51.865627425057546, 55.094938210078645, 53.97522211074829, 52.31087841306414, 53.91709000723702, 54.42240122386387, 52.21278027125767, 48.23727117265974, 46.816204752240864, 42.32535818644932, 46.57879522868565, 50.619266510009766, 48.9928252356393, 52.70093985966274, 49.894739627838135, 50.595632212502615, 48.38232871464321, 48.941022941044395, 46.34327214104788, 43.49064404623849, 42.43394463402884, 40.15870489392962, 40.87305266516549, 39.86248581750052, 39.32305547169277, 39.71637214933123, 43.62376805714199, 48.680656569344656, 53.35345213753836, 51.69990941456386, 55.60487345286778, 45.26366451808384, 35.42326436723982, 33.18439497266497, 39.48867620740618, 35.968927247183665, 40.776948656354634, 55.09025512422834, 48.79395736966814, 38.197002615247456, 37.31256641660418, 35.58338212966919, 33.838807582855225, 35.601232051849365, 35.57376234872, 40.76742615018572, 47.6769962310791, 54.48335082190377, 55.91345337459019, 47.67466163635254, 42.59942293167114, 39.1620900290353, 38.55078751700265, 38.4866486958095, 39.17230388096401, 40.37403999056135, 39.02789946964809, 40.13905191421509, 41.62169327054705, 41.267991747174946, 49.54961565562657, 46.27053492409842, 50.97460780824934, 48.28684656960623, 49.158987930842805, 50.579092025756836, 50.11912822723389, 45.406891209738596, 42.9741427557809, 48.01501219613211, 46.2999918120248, 52.350194794791086, 52.812232630593435, 53.436274664742605, 47.333571093423025, 53.689157826559885, 54.70616218021938, 53.22743960789272, 52.184563636779785, 47.63512291227068, 43.403579643794465, 41.98151615687779, 39.72979606900896, 40.119885308401926, 42.458499567849294, 49.650604248046875, 53.235419613974436, 53.93990094321114, 50.654938561575754, 45.555891854422434, 40.836751801627024, 43.221297127859934, 46.313374042510986, 48.16633701324463, 49.76546491895403, 52.334808009011404, 47.41330167225429, 54.94818878173828, 54.65543338230678, 60.46640641348702, 58.331377846854075, 53.97041743142264, 11.48856931073325, 0.9924386718443462, 2.991268975394113, 0.808620984000819, 43.513204847063335, 70.32932567596436, 61.930503027779714, 60.959228243146626, 56.66244486400059, 64.94213022504533, 57.73729297092983, 52.820233481270925, 45.86390549795968, 38.77442223685128, 58.14262655803135, 50.71795177459717, 0.6902311710374696, 0.38062628145728794, 0.25641683648739544, 0.11591211520135403, 0.1466293412127665, 0.21268087119928428, 0.14556322699146612], [0.06464008893817663, 0.02992421534976789, 0.01556827184478087, 0.08689129459006445, 0.022066053801349232, 0.06288412173411675, 0.07985863195998327, 0.11736989340611867, 0.05292006568717105, 0.3608900319252695, 5.816165506839752, 61.77138928004673, 37.388128076280864, 26.289516857692174, 17.81688175882612, 43.25586788994925, 38.55308737073626, 44.21175241470337, 56.37545994349888, 49.46906866346087, 50.36864151273455, 51.757732323237825, 51.828843661717, 34.99214948926653, 0.0567012393980154, 1.8035037389823367, 6.907045713492802, 0.5378558731504849, 0.07142007191266332, 8.752820338521685, 55.035743032182964, 52.00872557503836, 51.904412269592285, 51.32622834614345, 47.62200123923165, 40.53674943106515, 40.791876861027305, 38.92995071411133, 38.97426285062517, 38.59719453539167, 37.47605405535017, 39.14383711133684, 39.25407723018101, 38.46326453345162, 37.52196427753994, 38.263271059308735, 41.50135741915022, 41.13900886263166, 42.33540875571114, 41.902775696345735, 43.52318940843855, 43.94705384118216, 45.32359273093087, 47.40277862548828, 48.37499489103045, 50.476369857788086, 48.26240628106253, 47.721485546657014, 47.054295199257986, 40.92349311283657, 39.49185848236084, 42.01750782557896, 44.948212827954976, 44.02497441428048, 44.68955223900931, 44.852692467825754, 45.7080191884722, 44.675853865487234, 42.71638890675136, 41.410019874572754, 37.67107956750052, 35.310095582689556, 34.67141022000994, 36.251215185437886, 35.7312502179827, 33.86734730856759, 37.01576369149344, 38.839745725904194, 42.797443117414204, 46.62000846862793, 47.5181291443961, 45.442716121673584, 46.21938576017107, 37.37935944965908, 34.85960565294538, 39.804600375039236, 34.77778019223894, 37.34481995446341, 46.21045732498169, 42.79645299911499, 37.39527082443237, 39.16586984906878, 39.601796354566304, 37.61228043692452, 35.89333779471261, 35.40701947893415, 39.34451150894165, 49.48989241463797, 53.29568134035383, 50.42134359904698, 47.09616504396711, 38.25149733679635, 35.37679481506348, 35.101392541612896, 34.817485673086985, 37.153261593409944, 35.73379325866699, 38.2551520892552, 37.54764134543282, 39.212895257132395, 40.01274061203003, 43.97995356151036, 43.18633726664952, 41.98066847664969, 42.83550187519619, 43.66746875217983, 43.87248577390398, 42.07252018792288, 36.86181592941284, 38.8421984400068, 40.578751291547505, 40.03767422267369, 45.4352502822876, 46.08476788657052, 46.850171021052766, 48.8075932094029, 46.475374766758506, 47.873498235430034, 46.38775798252651, 42.967865058353965, 40.30811548233032, 39.72334466661726, 37.39861290795462, 35.90143244607108, 37.464832714625764, 43.23215021405901, 49.3120185307094, 52.764005184173584, 53.729794366019114, 52.389459065028596, 49.67236600603376, 46.7594518661499, 42.365320750645225, 38.29939126968384, 40.58263880865914, 42.847939150674, 42.92507457733154, 45.22527224676949, 51.3469409261431, 53.79070227486746, 54.794095107487266, 51.19700574874878, 34.03034162521362, 12.383880308696202, 0.3629700674542359, 0.3112158945628575, 2.5585295217377797, 51.21762105396816, 52.60769850867135, 53.36785575321743, 47.19421802248274, 40.71899720600673, 52.74529021126883, 51.1363479750497, 41.8197204044887, 31.37018210547311, 38.61448165348598, 44.270829473223, 28.669172389166697, 0.13625796059412615, 0.0746337358972856, 0.04828843993267842, 0.047760800924152136, 0.02115447253787092, 0.007684035043764327, 0.026663057306515317, 0.09492735444967236, 0.0671293285808393, 0.04477893467992544, 0.07222741323390178, 0.030246431274073463, 0.05365790127377425, 0.06177136501563447, 0.039351268604929955, 0.08811505963759762, 0.2500167856259005, 7.749165211405073, 68.305753162929, 44.36151041303362, 28.193085295813425, 24.716786895479473, 49.08771678379604, 38.19174630301339, 47.96079887662615, 61.54005595615932, 57.84337459291731, 54.13305044174194, 56.33339902332851, 56.64877775737217, 37.02060658591134, 0.08049332683107682, 0.518282906285354, 8.47518595627376, 3.353880912065506, 0.13435935175844602, 11.494252937180654, 55.780190399714876, 54.106279032570974, 56.24629987989153, 53.67985418864659, 49.55307238442557, 42.5598703111921, 42.46030609948294, 41.3699426651001, 39.983082226344514, 39.64595563071114, 40.02560520172119, 41.0609701701573, 40.29645293099539, 40.95706680842808, 40.479218346732004, 41.70599923815046, 44.26970386505127, 43.77945286887032, 45.45763390404837, 44.68830156326294, 45.97332225527082, 46.36603791373116, 47.208031041281565, 50.58905226843697, 50.168682779584614, 51.188768659319194, 50.08470337731497, 50.446357113974436, 47.94736800874983, 44.269158431461875, 41.94862685884748, 44.36269508089338, 48.59061138970511, 46.78265190124512, 46.96594885417393, 46.54368598120553, 49.87466975620815, 48.7169748033796, 45.08255624771118, 44.481213978358674, 40.495296478271484, 37.61605678285871, 36.56067752838135, 38.749509470803396, 38.460773604256765, 35.50909546443394, 40.50045204162598, 42.10677480697632, 44.761212485177175, 50.588816029684885, 49.79370934622628, 51.06896087101528, 46.90011467252459, 37.1806583404541, 35.63910320826939, 39.80115754263741, 35.79078933170864, 37.99092251913888, 48.8434111731393, 43.65541015352522, 36.59149626323155, 38.852110045296804, 40.137300968170166, 37.039985111781526, 33.586945806230815, 34.880676065172466, 39.12293345587594, 49.25876406260899, 54.01922505242484, 52.14994076320103, 49.71984304700579, 38.478644371032715, 36.67065361567906, 37.17728846413748, 36.587094579424175, 37.252092770167756, 37.092558656420024, 39.515357289995464, 40.21869216646467, 39.78373146057129, 41.79722213745117, 46.00602742603847, 46.29646907533918, 45.072731494903564, 46.146721499306814, 45.25070265361241, 46.551985604422434, 42.87434230531965, 39.60415874208723, 43.02206795556204, 43.14721890858242, 41.20903280803135, 47.18770408630371, 46.820047106061665, 49.1797456741333, 49.611148902348106, 50.36136327471052, 49.972284998212544, 49.91456631251744, 45.375606945582796, 42.737914425986155, 41.91414989743914, 39.74276488167899, 38.17235040664673, 39.26390198298863, 44.75882230486189, 52.152775628226145, 54.34248651776995, 54.76086187362671, 54.33776869092669, 52.65434871401106, 48.8402601650783, 45.33770799636841, 39.50640106201172, 41.76428072793143, 42.079391956329346, 45.408888816833496, 46.69119623729161, 56.430249963487896, 55.73753888266427, 58.97084140777588, 52.140022209712434, 37.207280363355366, 15.568684407642909, 0.41816528141498566, 0.9956883660384587, 4.614040298121316, 56.42293698447091, 56.8810247693743, 57.8192434992109, 50.17721516745431, 42.77288818359375, 58.52347469329834, 51.85470833097185, 54.06482260567801, 30.66390814099993, 29.952888556889125, 54.89210639681135, 32.36243002755301, 0.08908649108239583, 0.05151772718610508, 0.044226932871554575, 0.020148495178935782, 0.043105541794959984, 0.01050594768353871, 0.032763619774154255, 0.21903801150619984, 0.1355139740875789, 0.12508208171597548, 0.1802503035536834, 0.13169882952102593, 0.21087116402174744, 0.22054553989853176, 0.18669445919139044, 0.17934456786939076, 0.32985736855438774, 9.394894685064044, 82.01022720336914, 50.81233263015747, 34.8283109664917, 27.348873955862864, 57.76723623275757, 43.785595076424734, 54.34993846075875, 67.33343614850725, 62.326036180768696, 59.60603182656424, 62.831635747637065, 61.84490122113909, 45.362426212855745, 0.1170162952372006, 5.488740333489009, 18.636487790516444, 2.2603656010968343, 0.13699072413146496, 13.572684952190944, 57.78026063101632, 54.595734460013254, 59.4949301310948, 56.59526968002319, 54.28763048989432, 44.09030137743269, 44.16450466428484, 42.49222959790911, 42.098728793007986, 41.10536568505423, 42.5330467905317, 44.08089004244123, 42.36690493992397, 42.516364165714805, 42.191845076424734, 42.83931296212332, 45.986409187316895, 45.45205102648054, 46.6854361806597, 46.98104728971209, 47.949897153036936, 47.803404808044434, 49.54360893794468, 51.986064025333945, 54.29693412780762, 54.83430780683245, 52.159626552036826, 52.63106182643345, 51.53261763708932, 46.45196975980486, 43.66454356057303, 47.35718107223511, 50.74543537412371, 50.6215420450483, 51.4102737562997, 51.016974449157715, 51.67394747052874, 52.6795255116054, 47.015989780426025, 47.56365721566336, 42.9916661126273, 38.25255346298218, 37.75309610366821, 41.45976202828543, 40.343113558632986, 38.590482575552805, 41.59772545950753, 45.94995893750872, 48.161778994968955, 54.91370487213135, 51.966685499463765, 52.7395509992327, 49.641693183353965, 39.2487062726702, 35.53539787020002, 40.26096153259277, 35.86901909964425, 38.5150077683585, 51.24055705751692, 44.99806267874581, 36.57366023744856, 37.12113312312535, 39.496965408325195, 37.24156624930245, 34.648373467581614, 34.46823794501168, 39.574347496032715, 49.732325485774446, 56.69739082881382, 54.253240380968364, 51.186694622039795, 40.72807502746582, 38.576631341661724, 37.53579814093453, 37.35880320412772, 41.03370543888637, 38.325318472726, 42.32964869907924, 42.33570058005196, 41.835923603602815, 44.35096999577114, 48.38704654148647, 50.253978865487234, 46.87054313932146, 48.81007024220058, 49.076863697596956, 48.78881222861153, 47.317037854875835, 42.57717479978289, 45.10316807883126, 45.459207671029226, 44.53226934160505, 49.23637349264962, 49.71630641392299, 50.08841718946184, 51.60209962299892, 52.92506790161133, 51.105814116341726, 52.05804736273629, 46.82444878986904, 42.87002052579607, 43.02883202689034, 41.375428267887656, 39.82993350710188, 41.32647820881435, 46.612938676561626, 53.33235740661621, 56.45886264528547, 57.336989879608154, 56.32530089787075, 54.48775945390974, 51.68830592291695, 45.93857084001814, 42.04297992161342, 46.25428308759417, 44.27638108389718, 47.59154381070818, 47.79898227964129, 58.17749261856079, 58.939949716840474, 62.987164224897114, 55.455063343048096, 45.482848916734966, 21.678676639284404, 0.7932638366307531, 1.804336545722825, 3.6858508586883545, 63.68103912898472, 59.542692048209055, 65.25576496124268, 54.67238351276943, 49.091878754752024, 61.5646664755685, 60.89480454581124, 55.12738629749843, 43.25819901057652, 52.03345768792288, 59.76848765781948, 45.8273058618818, 0.25950099527835846, 0.1556953833039318, 0.20138893569154398, 0.13869517695690903, 0.12572979767407688, 0.12753384586955818, 0.06662833224982023], [0.005343512041560773, 0.00773846373028521, 0.04437764906989677, 0.0433097095893962, 0.047664716972836425, 0.05297587179977979, 0.04759586941716926, 0.14758474566042423, 0.06284992356917687, 0.022124238179198334, 0.7598433271050453, 46.78598356246948, 42.501967498234336, 40.207571574619834, 28.677121128354752, 36.00259474345616, 41.286477429526194, 41.999195848192485, 60.252700669424875, 49.84597717012678, 53.10290357044765, 49.14163827896118, 45.468629428318565, 49.94269609451294, 6.098770890917097, 2.047020946230207, 3.566531398466655, 1.8759806156158447, 0.049824510900569816, 4.307777600628989, 52.40831300190517, 53.33479969842093, 54.8815381867545, 47.15202508653913, 46.08491379874093, 40.10934141704014, 42.13987602506365, 40.78894819532122, 46.727820192064556, 47.262320790972026, 48.76888132095337, 43.46624892098563, 43.410517420087544, 39.41065488542829, 39.60943242481777, 35.78948654447283, 38.57713508605957, 37.59273515428816, 40.035759993961875, 39.22854954855782, 40.19383498600551, 41.05477237701416, 43.36578491755894, 45.97905451910836, 49.591315269470215, 49.89719581604004, 49.61159011295864, 46.81774377822876, 46.947636876787456, 41.535354954855784, 37.94397006716047, 38.789340019226074, 47.18042932237898, 42.70726939610073, 45.23075090135847, 46.20847708838326, 44.87207794189453, 45.15473066057478, 43.368550300598145, 38.7661052431379, 37.442282336098806, 33.7396046774728, 33.7974762235369, 35.8287855557033, 35.125256129673545, 34.98021943228585, 40.78587361744472, 41.729147161756245, 45.74137054170881, 46.573226247514995, 47.78553056716919, 45.789764744894846, 49.303197792598176, 35.11359357833862, 36.43499156406948, 37.378713267190115, 38.097160475594656, 37.83117995943342, 44.43004049573626, 42.88290248598371, 37.693414551871165, 38.67620250156948, 35.75733028139387, 40.88485418047224, 34.98643112182617, 36.45002399172102, 40.35380336216518, 48.72833858217512, 50.96392147881644, 51.17405932290213, 47.23833908353533, 42.323089599609375, 37.92399052211216, 35.69883687155587, 37.587183543613975, 33.362671852111816, 33.57546738215855, 36.64849233627319, 40.3763815334865, 39.58555841445923, 43.70412049974714, 41.252295766557964, 43.240401199885774, 42.346869809286936, 41.591121196746826, 41.65008360998971, 41.801366737910676, 40.615055629185264, 35.70378051485334, 39.30901663643973, 40.08952862875802, 39.22471761703491, 44.51971742085048, 46.748956612178254, 48.86003473826817, 47.458899225507466, 48.279054164886475, 48.1310019493103, 46.162500858306885, 43.14812912259783, 40.848706177302766, 38.35986144202096, 36.41935811723982, 37.403820582798545, 36.896605559757774, 46.66844088690621, 51.811045851026265, 49.46530621392386, 50.43045616149902, 51.785104751586914, 52.625395570482524, 50.01735101427351, 48.97396782466343, 44.974932125636506, 42.196476050785606, 40.230229650224956, 41.522664070129395, 44.76539182662964, 52.34000178745815, 55.362964970724924, 54.62324585233416, 53.13167953491211, 18.77614484514509, 1.45707383113248, 0.325811182813985, 0.5419237177286829, 12.892634357724871, 55.13751329694475, 50.73508950642177, 53.70715366091047, 53.29218292236328, 54.146575110299246, 54.10035569327218, 53.21331739425659, 34.86815888541085, 32.0098853792463, 34.73783152444022, 43.80629028592791, 21.676948274884904, 0.20083294409726346, 0.025294357178998843, 0.09262606900717531, 0.0882305937952229, 0.1336837344403778, 0.03681067403938089, 0.05435190349817276, 0.044778510595538785, 0.009031015265333866, 0.007751251570880413, 0.10172219055571727, 0.09058578884495155, 0.02582238464882331, 0.07463668073926653, 0.06978658027946949, 0.055139672476798296, 0.017940206353419592, 2.4804914806570326, 60.49438680921282, 46.85402727127075, 35.19147941044399, 29.22847979409354, 47.52837773731777, 42.135067871638704, 50.6378355707441, 65.02193028586251, 55.96900074822562, 57.39204740524292, 55.53070143290928, 49.55071347100394, 57.12592792510986, 6.805349273341043, 1.3605938596384866, 4.914146023137229, 6.289369532040187, 0.025562794114063894, 6.467224308422633, 57.6866579736982, 54.08483689171927, 60.20434815543038, 48.1532153402056, 48.20562212807791, 41.540114470890586, 44.58248744692121, 42.493195397513254, 48.14409235545567, 47.400878293173655, 49.29906014033726, 45.32563550131661, 45.55682291303362, 40.685444355010986, 41.17149863924299, 37.78855276107788, 40.88567059380667, 39.87996401105608, 41.10288517815726, 41.159196853637695, 41.76779304231916, 41.788734912872314, 46.02249118259975, 47.716229234422954, 52.083126885550364, 51.08797114236014, 52.460848331451416, 49.14761025565011, 48.795485973358154, 43.892830099378315, 40.88792528424944, 40.26238938740322, 49.825219426836284, 44.85277237210955, 47.26133762087141, 47.09015832628523, 49.92261232648577, 46.17175585883004, 46.07024962561471, 39.25045027051653, 39.922414030347554, 35.178243092128206, 37.12169592721121, 38.61173711504255, 37.05361747741699, 37.453437668936594, 43.558097158159526, 44.77464682715279, 48.393456254686626, 49.919805254255024, 51.81356109891619, 48.057059219905305, 52.45111737932478, 35.99207517078945, 34.91764048167637, 38.4768100466047, 36.39447314398629, 36.585763999394004, 45.0607145854405, 43.44066565377371, 37.30181060518537, 38.50615576335362, 34.19021272659302, 38.52611446380615, 35.020623207092285, 37.389114720480784, 40.98046139308384, 48.79990502766201, 53.414690085819785, 51.835312434605186, 48.97811589922224, 43.81731012889317, 38.84656538282122, 36.47787931987217, 38.78509814398629, 35.53983082090105, 35.44505391802107, 37.87647874014718, 40.57213660648891, 41.45229271480015, 45.35459559304373, 43.78738423756191, 46.06951659066336, 45.051456110818044, 44.889069761548726, 45.323822021484375, 43.650758334568565, 42.32580981935774, 39.907913139888215, 42.1480644771031, 42.59735236849104, 41.44337122780936, 45.725810050964355, 49.01578555788313, 51.599125794001985, 48.56308957508632, 49.99700321469988, 49.85491950171334, 47.69165345600673, 44.69304370880127, 43.4969356400626, 40.58788469859532, 39.12209619794573, 38.587130069732666, 39.96275874546596, 47.70055062430245, 53.13987146105085, 52.23314544132778, 52.19756024224417, 53.28876788275582, 54.72112512588501, 52.127821172986714, 51.55631446838379, 46.461759771619526, 43.17303146634783, 41.52386263438633, 43.957622051239014, 48.46616915294102, 56.31408650534493, 58.58284705025809, 57.57033470698765, 50.81510843549456, 26.086153507232666, 0.7747638779027122, 0.6072434612682888, 0.2548338957130909, 14.459650295121328, 58.73470687866211, 54.935911314828054, 58.17982721328735, 58.652210916791645, 54.21406296321324, 60.28082002912249, 56.03060695103237, 44.67598588126046, 34.26971401487078, 35.17416449955532, 52.48578194209507, 27.834645101002284, 0.22139111666807107, 0.007739244893725429, 0.07597336758460317, 0.04896916322676199, 0.01555887922378523, 0.024501338035666516, 0.0364860561011093, 0.1331563363117831, 0.072985771112144, 0.10421834447021995, 0.22093814026032174, 0.20115741954318114, 0.17286037866558346, 0.22255130298435688, 0.28322089676346096, 0.15398616716265678, 0.1246225099478449, 3.917844695704324, 73.68515968322754, 54.75850990840367, 54.049991675785606, 39.91907889502389, 50.70238780975342, 50.417244161878315, 53.74351011003767, 70.3957712990897, 61.09900515420096, 62.397234371730256, 58.62823268345424, 55.37298774719238, 60.82690674918038, 9.201105952262878, 3.4653497764042447, 14.360631517001561, 5.600954174995422, 0.15007243145789417, 9.730450987815857, 58.581360135759624, 54.363320691244944, 62.03169659205845, 51.60725866045271, 51.33413192204067, 45.34695952279227, 47.47272266660418, 43.54378386906215, 52.36637020111084, 50.434770992824006, 50.87788888386318, 47.65168046951294, 46.56635447910854, 44.45789582388741, 43.71659599031721, 38.31282213756016, 42.56920869009835, 40.788103989192415, 42.37147338049752, 44.23758234296526, 44.80174480165754, 44.45834050859724, 48.34500299181257, 48.69901718412127, 53.7158910206386, 53.296414375305176, 54.04329013824463, 51.44555670874459, 50.333316871098106, 47.18451138905117, 42.91045904159546, 44.06239741189139, 53.29916933604649, 47.15899412972586, 50.85469232286726, 50.572908129010884, 52.8126460484096, 51.15759904044015, 48.83275958469936, 42.10568741389683, 41.66843032836914, 38.99960987908499, 40.10528366906302, 40.20407315662929, 40.74842630113874, 40.91887256077358, 46.561459473201204, 46.559830120631624, 51.54979705810547, 50.939307485307964, 53.79214402607509, 50.64911944525582, 55.24033621379307, 37.46427685873849, 35.52732753753662, 38.87673793520246, 36.56033706665039, 37.52489294324602, 47.12254735401699, 47.41178001676287, 37.42866734095982, 39.369657039642334, 33.91173587526594, 39.875979219164165, 34.68009199414934, 37.65555034364973, 39.51874106270926, 50.945810999189106, 54.27885838917324, 54.531890937260215, 50.70797068732125, 45.593665736062185, 42.37091752461025, 39.985097203935894, 41.867961747305735, 36.97307743344988, 37.6947659764971, 40.11240209851946, 43.401745319366455, 42.572189467293875, 48.234352929251536, 46.14183691569737, 48.37615524019514, 47.63994148799351, 46.86387286867414, 46.757843358176096, 48.03778491701399, 45.72437524795532, 41.65525654384068, 43.79426295416695, 44.641203199114116, 43.54312031609671, 48.38426726205008, 51.50205945968628, 55.48317575454712, 50.1351056098938, 52.99162469591413, 52.038099084581646, 50.433099951062886, 46.21337556838989, 45.6885781288147, 41.24639674595424, 41.8163401058742, 40.74347570964268, 39.707606996808735, 50.950414180755615, 55.3254759652274, 53.10386937005179, 53.24487611225673, 55.51391111101423, 57.967514583042686, 52.06700359072004, 53.9245662689209, 48.0770491872515, 46.60107462746756, 43.96243020466396, 45.147970063345774, 48.73404652731759, 57.2383463042123, 61.363821847098215, 60.25665419442313, 53.872468675885884, 36.056523186819895, 1.9924901809011186, 0.6872145129101617, 1.119108023388045, 17.74539348057338, 67.56400517054966, 59.52147919791085, 65.32143933432442, 62.81803812299456, 63.08914293561663, 65.21461772918701, 64.02660778590611, 47.92425830023629, 42.60731608527047, 45.40509510040283, 59.37813091278076, 38.14938313620431, 0.3649809466941016, 0.15758443836654934, 0.25307258165308405, 0.12959047194038117, 0.24593151626842363, 0.18112349669848168, 0.11967893450387887], [0.1380864360502788, 0.0283887228329799, 0.0468450127435582, 0.03881799775574889, 0.044135008339903185, 0.06801181087004286, 0.03771758019658072, 0.10197653262210743, 0.036052675784698555, 0.020379836604531323, 0.07179358508437872, 33.85045971189226, 52.47367818014962, 34.22032969338553, 24.382297141211374, 30.784442016056605, 44.74156297956194, 39.2216534614563, 55.34629624230521, 51.65073006493704, 53.11338145392281, 50.58555037634713, 50.809900760650635, 42.39906815120152, 20.248014756611415, 0.1630117278546095, 4.503173538616725, 8.029577136039734, 0.1588680637734277, 3.96291983127594, 39.3022768838065, 54.90107652119228, 52.78001730782645, 52.545345374516074, 46.97987304415022, 47.44817468098232, 50.3038843018668, 49.62605626242501, 51.101996081215994, 52.84941591535296, 51.257267475128174, 52.323902811322895, 51.66261148452759, 48.75474868501936, 44.21129730769566, 40.127618653433665, 37.388506753104075, 36.0565961429051, 38.12315716062273, 36.91709232330322, 38.827002729688374, 41.5277293069022, 45.19630520684378, 46.525436537606375, 49.24352666309902, 50.273670060294016, 49.600045680999756, 50.66755301611764, 47.16438940593174, 40.178889410836355, 39.796074935368125, 35.37418576649257, 45.48342909131731, 44.91206135068621, 45.07607010432652, 41.403846400124685, 45.6077948978969, 44.6306871005467, 44.32586962836129, 41.20781339917864, 37.170517444610596, 35.852246148245676, 35.639329024723594, 34.67218494415283, 37.69974088668823, 39.30363525663103, 43.05818816593715, 44.886683055332725, 45.292395319257466, 47.863190582820344, 45.30088601793562, 46.75506060464041, 49.67966856275286, 40.46257046290806, 36.61179889951433, 37.851583344595774, 37.174523081098286, 37.98520762579781, 45.228096689496724, 42.150326115744456, 36.6677041053772, 38.61474221093314, 35.83739784785679, 39.58902556555611, 39.23055410385132, 36.25133677891323, 40.47508416857038, 49.306928975241526, 51.50464766366141, 48.51431322097778, 47.04954263142177, 45.47269412449428, 42.637780461992534, 36.09720836366926, 36.3961615562439, 35.76173196520124, 33.60289192199707, 34.83688504355294, 37.893748487745015, 37.10532944543021, 44.73249210630144, 42.54244770322527, 44.11716658728463, 45.95171683175223, 44.32708208901541, 42.9135023525783, 43.30366454805647, 39.80271741322109, 35.97008064814976, 39.617190088544575, 40.397497109004426, 40.1026086126055, 44.419927392687114, 45.85911471503121, 48.37065921510969, 49.065930707114084, 47.14988851547241, 49.08257164273943, 47.040600299835205, 42.879567350660054, 43.00324875967843, 40.43698024749756, 38.28153787340437, 37.489669050489155, 37.3962470463344, 42.29323666436331, 51.45059067862374, 51.802940777369905, 50.744789191654746, 53.094235692705425, 53.003367151532856, 52.81877088546753, 53.302553108760286, 51.481656074523926, 49.38553394590105, 44.448828424726216, 40.935968603406636, 48.35818025044033, 54.32912860597883, 57.50276000159127, 51.083750111716135, 45.08520698547363, 12.788031833512441, 0.7044653158102716, 1.1657326072454453, 0.23632071912288666, 36.24413497107369, 58.63985701969692, 46.376981326511924, 53.23368951252529, 50.9917003767831, 51.1073705128261, 56.6535233770098, 42.7997464452471, 31.66991002219064, 41.78327710287911, 45.13025215693882, 43.31557028634207, 14.074222428458077, 0.5400732713086265, 0.18810822761484555, 0.043671450178538046, 0.03127844911068678, 0.07083960556026016, 0.027781859772013764, 0.13040277335260594, 0.07208362487809998, 0.037924496057842455, 0.015777552400582602, 0.059791874805731435, 0.011739855981431901, 0.10315147707504885, 0.04481142293661833, 0.10552052102450814, 0.026171652067984854, 0.020662770440269793, 0.1259967740625143, 43.2770425251552, 59.8038192476545, 36.06250211170742, 34.63728414263044, 40.01829917090279, 47.15118088041033, 44.95289938790457, 62.011366162981304, 57.76958472388131, 57.95036990301949, 55.32414885929653, 54.61370250156948, 48.371340138571604, 24.037319081170217, 0.13478450823043073, 1.6142276440347945, 12.682049223354884, 0.02883719207186784, 4.870988590376718, 45.138607365744456, 55.733609676361084, 54.903755051749094, 52.935646533966064, 50.38708897999355, 47.612555163247244, 51.64249644960676, 51.623830114092144, 53.38599402563912, 54.500627517700195, 54.68980612073626, 53.516974517277305, 55.34559794834682, 48.5800119127546, 47.48212010519845, 41.83264057976859, 38.95133032117571, 39.233732904706685, 39.23393440246582, 38.17496987751552, 40.791911602020264, 42.16173505783081, 48.57027053833008, 49.10996838978359, 50.51014505113874, 53.13533428737095, 51.26022045952933, 51.71553243909563, 48.960731506347656, 42.704590865543906, 41.928063665117534, 37.864076205662315, 47.62200818743025, 46.965240137917654, 47.0456759589059, 45.289570876530235, 47.87681600025722, 45.747908796582905, 44.99004445757185, 42.95398950576782, 39.688826016017366, 38.570405755724224, 37.77714034489223, 37.343923636845176, 39.5038024357387, 42.86193977083479, 46.56357519967215, 45.890951360974995, 47.39186300550188, 49.236741747174946, 48.06197854450771, 48.45979765483311, 51.608481543404714, 41.301725251334055, 35.285835947309224, 36.831837926592144, 36.826112610953196, 37.70881870814732, 46.24202993937901, 44.00690562384469, 36.327548095158164, 38.885871342250276, 35.934300899505615, 38.10664824077061, 38.02101516723633, 35.928572109767366, 40.62408133915493, 49.65017693383353, 52.08685459409441, 51.29042080470494, 46.919663429260254, 47.280938489096506, 42.18310076849801, 37.57915490014212, 37.65531757899693, 37.05462844031197, 34.686800479888916, 36.855506965092246, 39.369038649967735, 38.778493881225586, 45.32043130057198, 44.85263688223702, 47.096158095768516, 48.86746236256191, 46.853172642844065, 46.48657873698643, 45.706327302115305, 43.46524143218994, 38.809173652103965, 42.50580985205514, 43.09732042040144, 41.62429884501866, 47.16434076854161, 48.34174428667341, 51.220806803022114, 49.19061265672956, 47.804579053606304, 51.78649091720581, 48.11780732018607, 43.81209550585066, 46.81473173413958, 41.38314424242292, 41.00702783039638, 38.87134960719517, 39.69489526748657, 43.728126525878906, 52.6277232170105, 51.943933623177664, 52.4032929284232, 52.9157121522086, 54.526523453848704, 55.03754608971732, 53.85459443501064, 54.089440073285786, 51.387309959956575, 45.36823838097708, 41.63253246034895, 50.70305136271885, 55.99666152681623, 60.514758927481516, 51.319346155439106, 45.77848434448242, 15.009427377155848, 0.8496667615004948, 0.9190032695020948, 0.2149369865655899, 38.6575813293457, 62.32360431126186, 53.24206556592669, 58.12904282978603, 57.256116322108674, 56.24281535829817, 63.388533864702495, 46.37411172049386, 42.136304650987896, 42.87801442827497, 50.30139684677124, 52.03378425325666, 18.839371715273174, 0.4980535517845835, 0.05952538696250745, 0.08319099207541772, 0.08518037532589265, 0.0841845234057733, 0.01062267691096557, 0.059015433969242234, 0.1589557576392378, 0.13587089707808836, 0.11609970299260956, 0.09712182490953378, 0.12998303159007005, 0.17040527611970901, 0.1750179843178817, 0.21863211185804435, 0.16260581463575363, 0.1327652558684349, 0.34692312138421194, 54.50842687061855, 67.62867900303432, 45.74915599822998, 33.49494123458862, 44.757165159497944, 53.83406250817435, 49.98006698063442, 66.74989863804409, 64.62333297729492, 62.079771178109304, 60.09972218104771, 62.27020740509033, 54.32147863933018, 24.849077122552053, 0.4621441758104733, 13.719786133084979, 18.389493227005005, 0.21145283138113363, 7.116090953350067, 47.98903635569981, 56.99908855983189, 59.14592211587088, 55.09936073848179, 52.23631034578596, 49.69085168838501, 54.58326939174107, 52.61742598669869, 56.587671824863975, 56.57671798978533, 55.22284412384033, 56.17008508954729, 56.55428920473371, 50.87803132193429, 49.69141796657017, 44.810871260506765, 41.1750283241272, 40.71334137235369, 42.297054699489046, 40.669519083840505, 43.709602628435405, 46.49880756650652, 50.782316412244526, 49.752047947474885, 52.43823889323643, 55.313504219055176, 54.16461958203997, 53.72651481628418, 54.29044451032366, 45.62955665588379, 43.39117016111101, 39.54143040520804, 51.18798698697771, 48.66490500313895, 51.128305435180664, 47.39482641220093, 53.41615615572248, 49.55078295298985, 50.064348629542756, 47.53178582872663, 42.00996208190918, 41.639140197208945, 40.129605838230674, 39.307161467415945, 43.34357500076294, 45.64194876807076, 48.598035539899556, 49.742278780256, 50.233012676239014, 51.885582651410786, 52.29019362585885, 49.6007022857666, 55.27000502177647, 44.20743063517979, 35.73552336011614, 37.73938730784825, 37.32612582615444, 37.14358970097133, 48.645814827510286, 46.30500841140747, 36.55444152014596, 37.35534300122942, 35.28465822764805, 38.0965872492109, 37.55589233125959, 35.53191682270595, 39.509836946214946, 52.390470027923584, 53.96393476213728, 51.778698512486045, 49.61407061985561, 49.60757405417306, 44.9937686920166, 39.64716461726597, 39.4389305795942, 39.52026619229998, 37.48143196105957, 37.6340526172093, 41.53911740439278, 40.27587236676897, 50.29579312460763, 47.2573458807809, 50.41473238808768, 50.6392252104623, 50.45974281855992, 50.77922446387154, 48.694514751434326, 45.40903125490461, 41.52169132232666, 44.635877404894146, 45.448993819100515, 46.22988101414272, 50.78874002184187, 49.61432075500488, 52.00301762989589, 51.03950745718819, 49.75818668093, 52.599892207554404, 49.38664218357631, 48.070823601314, 48.428020068577354, 44.186752796173096, 42.61807884488787, 40.54968350274222, 41.5519437789917, 46.4709279196603, 54.87732757840838, 54.88017981392996, 53.650612694876536, 55.122737952641074, 55.87406403677804, 58.05272381646292, 55.79947859900338, 55.144211360386436, 53.337975025177, 48.07943589346749, 44.6326117515564, 53.72354098728725, 58.603879247392925, 63.73154558454241, 53.05297728947231, 50.72884654998779, 18.9491080897195, 0.8198478615709713, 3.9956384641783576, 0.6278037237269538, 45.676467418670654, 69.25888620104108, 56.46543564115252, 63.670616831098286, 61.92875902993338, 61.75161470685686, 67.68519565037319, 52.33640956878662, 44.65594032832554, 50.722579274858745, 55.190413406917024, 61.73531423296247, 25.934311049325125, 0.6253116545932633, 0.30001591412084444, 0.3044512804065432, 0.217604131304792, 0.1635748576372862, 0.12457102271062986, 0.20053888059088162], [0.03560548388798322, 0.03713258123025298, 0.09994890713798148, 0.008817247048552548, 0.04210227009441171, 0.057877130407307825, 0.009386632075932409, 0.17968204404626573, 0.030948080588132143, 0.07087630073406867, 0.16723057361585753, 16.340842928205216, 55.39561455590384, 38.98794732775007, 32.93539237976074, 26.6166467326028, 46.8767409324646, 44.1096625328064, 53.61669158935547, 50.609730107443674, 53.91597829546247, 47.32717180252075, 49.642440114702495, 46.90726784297398, 30.228165762765066, 0.05847213776516063, 1.6413707818303789, 11.041851384299141, 0.08711769458438669, 2.5010273158550262, 27.16435933113098, 52.513491358075825, 55.17999110903059, 51.54751804896763, 50.0966716493879, 51.30147538866316, 53.5662476675851, 53.26874664851597, 54.50287873404366, 51.697911807468955, 51.54476656232561, 50.58998332704817, 50.56575148446219, 50.03334576742989, 48.16509328569685, 43.93306016921997, 38.2797452381679, 36.928490843091694, 37.939085483551025, 38.07404381888253, 41.10687344414847, 42.73934922899519, 46.613247871398926, 48.080203669411794, 50.117144516536165, 47.0073219026838, 48.929645265851704, 49.112407207489014, 44.68085656847273, 41.33747373308454, 43.02383974620274, 37.45456675120762, 38.79525988442557, 46.055550711495535, 47.227666650499614, 43.913417611803325, 43.11488199234009, 42.66194977079119, 41.56009749003819, 39.51161221095494, 35.15992069244385, 34.95595284870693, 35.025580746786936, 38.28856945037842, 38.78779404503958, 41.55825621741158, 44.06744180406843, 45.846969263894216, 46.30305944170271, 46.48646409170968, 48.03199011938912, 48.4516578401838, 48.93864665712629, 43.931031295231406, 36.04079941340855, 35.638019289289204, 35.258876936776296, 36.94451338904244, 44.19088697433472, 40.28873348236084, 35.77592018672398, 37.32810606275286, 36.37105424063546, 37.18258646556309, 40.85908331189837, 39.1362635748727, 40.73630516869681, 51.165127413613455, 49.77078723907471, 48.97458968843733, 47.25646693365914, 49.667512689317974, 45.2123555455889, 43.15093272072928, 37.76018674033028, 35.56622007914952, 34.471854482378276, 34.639594418661936, 34.37480204445975, 35.54854733603341, 40.35861151559012, 42.97402811050415, 43.02467005593436, 43.36265127999442, 45.58284739085606, 43.98693650109427, 44.19231135504586, 39.90524155752999, 38.134281226566856, 41.52810450962612, 39.99260125841413, 40.53053774152483, 45.45948212487357, 48.28538744790213, 48.6264328275408, 48.57545042037964, 48.398893220084055, 44.21648413794381, 47.32745320456368, 51.494329588753835, 47.54884713036673, 43.27682018280029, 41.033114842006135, 37.0078010559082, 38.240727628980366, 41.999873297555105, 48.01646784373692, 49.41903815950666, 50.36174542563302, 52.26595483507429, 49.02967153276716, 50.469251428331646, 50.970445837293354, 52.77557740892683, 51.77861860820225, 50.76442132677351, 40.195335796901155, 43.554202692849294, 50.6569778578622, 56.24538271767752, 51.93442848750523, 41.61259460449219, 0.6095351182988712, 0.029841179626860788, 1.6693868956395557, 1.4491177094834191, 53.90872090203421, 44.77851002556937, 52.22168091365269, 50.9403566632952, 48.085915088653564, 48.74336406162807, 50.46354348318917, 37.57120268685477, 30.368925843920024, 50.75222723824637, 33.043801648276194, 44.97164562770298, 8.159140195165362, 0.7285209021397999, 0.06786714041871683, 0.20176264563841478, 0.01653525379619428, 0.08184599996145282, 0.015321894083172083, 0.007932573091238737, 0.01783890277147293, 0.01969983764658017, 0.047480331866868904, 0.06137853395193815, 0.04413820084716592, 0.08209995526288237, 0.0832812168768474, 0.04665821883827448, 0.05553259175004704, 0.13971721354339803, 0.07103724245514188, 21.310905013765606, 66.82152066911969, 38.71328156335013, 28.47209194728306, 39.76878588540213, 52.58513075964791, 50.695446559361045, 59.94857801709856, 55.88734899248396, 60.526445797511506, 53.069187436785015, 53.61222389766148, 51.18056631088257, 34.87140369415283, 0.5888154815350259, 1.3118593032870973, 13.888105375426155, 0.12183230609766074, 2.879952971424375, 32.96446016856602, 52.34907613481794, 57.47047519683838, 53.373323985508506, 51.934056758880615, 52.11717653274536, 54.497452190944124, 55.66209186826433, 56.20391934258597, 53.46482481275286, 53.25056321280343, 52.71183116095406, 52.35565955298287, 51.03038099833897, 50.49086380004883, 45.989435127803254, 42.28748008183071, 39.95756149291992, 39.75964553015572, 39.86569241115025, 42.71687180655343, 44.88679770060948, 47.69492258344378, 49.51010472433907, 51.58005993706839, 51.221011774880544, 50.47986132758004, 50.01260192053658, 46.76624373027256, 42.37084109442574, 44.831170422690256, 40.350443908146445, 43.5591150692531, 48.111039774758474, 48.57124328613281, 47.306146553584504, 48.591869013650076, 46.30436222893851, 45.15626968656267, 41.330160754067556, 37.69321652821132, 36.4084598677499, 38.25916119984218, 39.44919654301235, 40.83626542772566, 45.3498534475054, 46.77840307780674, 47.643967969076975, 48.099300793239046, 49.160179546901155, 50.38334737505232, 51.03425461905343, 50.43481615611485, 44.5946363721575, 36.29629162379673, 36.45135804585048, 37.15914324351719, 35.74373960494995, 46.381219727652415, 42.79086664744786, 35.957702432359966, 38.142883096422466, 37.23513569150652, 37.09874602726528, 40.395971979413716, 38.15270784923008, 41.371492113385884, 53.44476536342076, 51.32475880214146, 50.48114327022007, 50.25080353873116, 50.39087227412632, 45.95077187674386, 42.96867799758911, 38.58467040743147, 36.841513293130056, 35.77641698292324, 35.96851035526821, 38.07144866670881, 36.373520851135254, 42.706908089774, 45.604049818856375, 46.30884034293038, 45.68194954735892, 47.21086938040597, 48.274621214185444, 46.69261714390346, 41.41219118663243, 38.437500613076345, 42.01236963272095, 40.592967305864605, 42.65736395972115, 46.5064297403608, 49.32983718599592, 50.608750411442344, 50.67285796574184, 50.05708776201521, 47.35945660727364, 48.81056703839983, 52.53151151112148, 48.68162931714739, 44.33899130140032, 41.58835233960833, 39.49354689461844, 37.95435414995466, 44.34145443780081, 50.20014769690377, 50.82175438744681, 52.997141565595356, 53.42341354915074, 50.685819830213276, 52.18117986406599, 52.60755607060024, 55.576754093170166, 54.658417633601594, 52.32438571112496, 41.16497080666678, 46.13901594706944, 53.25541305541992, 59.23027324676514, 53.87469904763358, 43.085835048130576, 0.6343932758484567, 0.12251758575439453, 0.9964849118675504, 2.206162052495139, 63.428597177777974, 50.86943292617798, 55.871361187526155, 56.49704647064209, 53.78451490402222, 52.44609383174351, 56.71257264273507, 43.770913532802034, 37.435275077819824, 47.27944115230015, 38.67061267580305, 52.72005087988717, 11.168832319123403, 0.8466267617685455, 0.21997977739998273, 0.23250474674361093, 0.014368813617953231, 0.08818408021969454, 0.025503276414903145, 0.0774039433204702, 0.0911824314721993, 0.11573746028755393, 0.2629321025950568, 0.1213748785001891, 0.08884073926934175, 0.15674637976501668, 0.145736891244139, 0.4019132549209254, 0.15821591019630432, 0.29614042064973284, 0.2757578529417515, 26.55687485422407, 74.97586400168282, 51.09503051212856, 42.395472458430696, 39.937119892665315, 62.27273654937744, 54.17249536514282, 63.728266034807476, 61.45020880017962, 65.53349835532052, 56.91514042445591, 57.98661518096924, 57.156506947108674, 39.68222870145525, 0.8370788512485368, 5.245193379265921, 20.757838828223093, 0.3295413612255028, 4.307096677167075, 39.32574095044817, 49.82410771506173, 62.354933738708496, 54.836902959006174, 54.00500903810774, 52.782716682979036, 59.87783145904541, 55.59619862692696, 59.60288429260254, 53.620057991572786, 55.30294990539551, 52.979201316833496, 54.990329606192454, 52.46437801633562, 51.81144189834595, 49.830621651240754, 42.33938659940447, 40.973902293613975, 43.19893782479422, 43.376610210963655, 45.95851911817278, 46.1581825528826, 50.2835955619812, 52.0621155330113, 55.18941634041922, 52.9594441141401, 54.191561222076416, 52.62470769882202, 50.24984816142491, 43.93985898154122, 47.45989629200527, 41.91492114748274, 44.400607926504954, 51.60876989364624, 51.617614950452534, 50.94227089200701, 50.4760537147522, 47.41659164428711, 47.76337276186262, 45.40990325382778, 40.2265088898795, 37.472020626068115, 40.91042007718767, 42.01839024680001, 44.15247733252389, 48.74294369561331, 48.92010538918631, 49.60103579929897, 50.80903223582676, 53.20166179112026, 53.45891884395054, 52.64700446810041, 52.81009953362601, 45.0146723474775, 37.387752873556956, 36.067199093954905, 35.951483794621055, 36.22027138301304, 48.276191507067, 45.219341959272114, 36.37454571042742, 36.6744647026062, 37.38421276637486, 36.486713954380576, 41.629030568259104, 37.6017678124564, 41.302770955221995, 55.78546060834612, 53.77752154214041, 52.97706127166748, 51.92535761424473, 53.80917058672224, 50.220519815172466, 46.92597586768014, 41.504932267325266, 38.496410914829795, 36.83608327593122, 36.979171003614155, 40.53344556263515, 38.63178614207676, 44.8499687739781, 49.107279436928884, 49.593399729047505, 49.138845103127615, 50.054145199911936, 52.12488555908203, 49.37242269515991, 43.09122685023716, 41.7347091947283, 45.52621957233974, 43.43222706658499, 44.69552768979754, 49.75150598798479, 53.78985112054007, 52.41161339623587, 52.984481947762625, 51.73318781171526, 50.20692913872855, 50.29342726298741, 54.81376198359898, 51.58715404782976, 47.347943442208425, 44.04853922980172, 40.5777507509504, 40.63453837803432, 46.07880285808018, 52.2867751121521, 53.24814176559448, 53.96802725110735, 55.362690516880576, 51.518057686941965, 54.42282158987862, 56.063173157828196, 56.860586643218994, 55.01701416288103, 55.33532503673008, 42.59072378703526, 49.98266908100673, 54.05978168760027, 64.33462142944336, 54.24546534674508, 46.91396938051496, 1.0240927104439055, 0.21172938868403435, 6.793376658643995, 2.271879417555673, 66.56723049708775, 53.89154495511736, 62.234709058489116, 60.184073311941965, 59.03173542022705, 58.845641817365376, 61.48162855420794, 49.60289444242205, 43.15134961264474, 54.4482797895159, 43.827607359204976, 64.95043332236153, 15.197876419339861, 1.1328380980661936, 0.4105016897831644, 0.3539553497518812, 0.14005980587431363, 0.1655343717762402, 0.13848252408206463, 0.13413653442902224], [0.03787097321557147, 0.052181653345802, 0.04494520629357014, 0.03670408297330141, 0.00940962169053299, 0.09316935842590672, 0.052267888361322026, 0.036463250539132526, 0.03887621945302401, 0.053056169633886645, 0.17769792622753552, 4.025202180658068, 50.26573174340384, 40.486308983394075, 38.075026988983154, 17.663045167922974, 45.505024092538015, 41.58174112864903, 49.340481826237266, 54.23551205226353, 56.047769001552034, 51.92447171892439, 52.9952620778765, 43.655802726745605, 52.1463485445295, 2.805273298706327, 0.5396612648453031, 11.839859809194293, 0.22574980849666254, 1.9326707507882799, 19.40353764806475, 49.73483725956508, 50.698875495365684, 57.3969076701573, 50.395683901650564, 52.705317224775044, 51.53773498535156, 51.50433152062552, 47.289186000823975, 48.359531675066265, 47.21174485342843, 49.13589906692505, 49.069668837956016, 50.54597691127232, 49.083638191223145, 47.019745281764436, 39.5509911264692, 37.56775985445295, 38.14234808513096, 39.5268565586635, 43.28725290298462, 47.09145763942173, 47.16175603866577, 49.8548013823373, 50.01966823850359, 51.455972058432444, 48.06105443409511, 49.326658385140554, 47.55942228862217, 41.23505728585379, 43.536623750414165, 39.70991727284023, 38.26366015842983, 45.56669977733067, 46.51559441430228, 45.91562441417149, 45.66417258126395, 44.76936967032296, 43.28408105032784, 37.38296209062849, 32.3153976712908, 35.8233242716108, 37.53848361968994, 40.20605686732701, 41.13968631199428, 43.512631620679585, 46.05499832970755, 47.715246064322336, 45.45473997933524, 46.666620458875386, 48.107833181108745, 48.70427697045462, 51.82210043498448, 46.572496686662944, 37.445085934230256, 37.57692105429513, 37.598099163600374, 36.88491868972778, 44.19049440111433, 40.925674847194124, 37.698584011622835, 39.10820327486311, 38.24853393009731, 37.19784470966884, 36.98233243397304, 39.61245836530413, 42.556472642081125, 52.75336054393223, 49.936842237200054, 49.061779158455984, 48.367970262254985, 45.50168548311506, 46.300936767033164, 44.39552184513637, 42.17374154499599, 40.1405040877206, 36.49834871292114, 35.340108326503206, 34.27426855904715, 33.95525244304112, 37.499365261622835, 44.66418784005301, 44.54300430842808, 42.01626409803118, 44.6350679397583, 42.82906436920166, 43.88143505368914, 34.37326996667044, 38.655635833740234, 39.47620071683611, 38.7323647907802, 45.914342471531455, 46.79951865332467, 46.37432016645159, 46.89064427784511, 45.000991344451904, 42.42261907032558, 40.693778719220845, 36.91295119694301, 46.348674365452354, 47.61610916682652, 46.058434213910786, 43.01638780321394, 37.827195167541504, 36.88391120093209, 36.07685361589704, 40.424268518175396, 48.08715534210205, 51.44321863991873, 51.24509423119681, 52.31640223094395, 49.37413542611258, 47.38380656923567, 55.96099294934954, 52.878431592668804, 52.45246532985142, 46.82384777069092, 43.35269103731428, 51.180538518088206, 50.504530906677246, 58.617282322474885, 31.965013912745885, 0.050782911080334864, 0.24071933595197542, 3.0712648885590688, 7.161555188042777, 38.72397484098162, 37.452030658721924, 52.94872304371425, 50.32558700016567, 53.1611260005406, 52.36988251549857, 53.54682745252337, 41.52936908176967, 32.31659970964704, 43.3122490474156, 41.428474290030344, 42.110766547066824, 0.9735603077071053, 0.16546467265912465, 0.033150357593383105, 0.1012956973697458, 0.03519853251054883, 0.05915649461426905, 0.02877263625019363, 0.07151477504521608, 0.016680860625846044, 0.021580891084990332, 0.04274602001532912, 0.03683430741408041, 0.054392866657248566, 0.0665873351639935, 0.12230698205530643, 0.078871478858803, 0.025158819809023823, 0.05098939946453486, 0.2812129487948758, 6.58377035175051, 61.68977573939732, 46.60403456006731, 33.0749191556658, 28.394671644483292, 52.99903842381069, 44.766170024871826, 56.472001688820974, 59.89171395983015, 61.134065764290945, 55.48174442563738, 57.50356599262783, 47.96655198505947, 55.13219097682408, 4.297942425523486, 1.0292421941246306, 14.197477391787938, 0.4728160117353712, 3.0691237577370236, 25.43211088861738, 51.16145529065813, 52.135571888514924, 59.820328167506624, 54.30039780480521, 53.895199707576204, 53.799245085035054, 51.77084704807827, 49.84025880268642, 48.1886442048209, 47.545831612178254, 48.758868966783794, 49.60310288837978, 49.99834769112723, 51.98109258924212, 46.91428552355085, 41.710904666355674, 40.252859933035715, 41.90540211541312, 39.19445473807198, 43.79047966003418, 48.31619923455374, 49.13153559820992, 50.75351612908499, 51.47571883882795, 52.11517545155117, 49.50162097385952, 50.791626998356406, 49.44998543603079, 42.762045519692556, 44.732082162584575, 41.55636978149414, 41.375532490866526, 47.84979445593697, 49.17061226708548, 48.34469032287598, 48.46394572939192, 47.70552206039429, 44.65299081802368, 39.895899704524446, 35.84894575391497, 37.39306477137974, 39.68072441646031, 41.3891544342041, 44.159251826150076, 46.20158100128174, 48.46167366845267, 50.47527551651001, 47.417487961905344, 49.067997796194895, 49.180040972573416, 50.36242287499564, 54.31633697237287, 47.11845139094761, 36.551071643829346, 36.5406528200422, 38.76458706174578, 35.85890599659511, 45.69588763373238, 44.012658732278005, 38.006399631500244, 38.5662750516619, 39.163820130484446, 35.70003890991211, 35.55792045593262, 37.24617290496826, 42.27343429837908, 53.707379477364675, 50.2805175100054, 49.85699006489345, 50.148060526166645, 48.44609580721174, 47.43238837378365, 47.000724588121685, 42.80703163146973, 40.84922729219709, 39.167738914489746, 36.33289473397391, 35.9091032573155, 36.73558800561087, 39.153974533081055, 46.47786569595337, 45.527928829193115, 44.21521609170096, 46.51620932987758, 45.90971149717058, 46.33817911148071, 36.97124310902187, 41.33136279242379, 41.767810412815635, 42.16162388665335, 48.40601164954049, 50.04478945050921, 49.11655180794852, 48.55305290222168, 45.52357578277588, 41.60869319098336, 43.17744704655239, 39.63939653124128, 48.02117872238159, 49.50492484228951, 46.46076617922102, 44.110510213034495, 39.860654967171804, 38.13399635042463, 38.70575319017683, 43.035620416913716, 50.54993043627058, 52.431658949170796, 52.62683384759085, 53.680350984845845, 51.076193945748464, 48.211173738752095, 56.608999320438926, 55.70514638083321, 53.81401000704084, 49.42436047962734, 45.011229515075684, 52.752738680158345, 54.14155156271798, 60.144746507917134, 33.60934679848807, 0.07037708895014864, 0.5960343341742242, 1.2976958347218377, 9.553623676300049, 45.411949498312815, 42.63048137937273, 58.42372635432652, 55.86730343954903, 58.6515508379255, 57.371557167598176, 58.99291583469936, 47.93035881859915, 40.234825883592876, 40.93898064749581, 47.20504331588745, 48.597604751586914, 1.827937296458653, 0.15888776843036923, 0.05585059057921171, 0.02759072833162333, 0.037289000515426905, 0.06480859632470778, 0.023264709660517316, 0.053698657479669364, 0.10698950184243065, 0.11847382916935853, 0.10432568192481995, 0.13488470071128436, 0.1481408051082066, 0.16998381087822573, 0.2734524080795901, 0.18152125392641338, 0.11182829790881701, 0.21910568858895982, 0.4186552922640528, 9.16611569268363, 73.38485854012626, 52.70620659419468, 49.086090905325754, 26.701788221086773, 60.27488626752581, 51.40808159964425, 61.343685967581614, 65.59659494672502, 67.08141803741455, 58.99198477608817, 63.57703154427664, 52.294310433524, 63.278641155787874, 5.808131652218955, 1.7975656347615379, 27.166230133601598, 0.6556386958275522, 4.39983298097338, 32.500751291002544, 49.9030635697501, 54.39421238218035, 62.11515140533447, 55.46647923333304, 56.37968792234148, 55.309797355106895, 52.2303592136928, 50.57318953105381, 49.779764311654226, 49.6512782233102, 49.86666543143136, 51.70545060294015, 51.67957203728812, 53.49136693137032, 50.14874144962856, 44.30842617579869, 42.81564392362322, 44.61282328196934, 42.124788011823384, 46.944155829293386, 50.549318994794575, 52.459656715393066, 53.831814765930176, 55.41863393783569, 56.051218782152446, 51.01526171820504, 52.97004359109061, 53.23851156234741, 45.82880319867815, 49.14074196134295, 44.31820229121617, 43.3975625038147, 49.471743719918386, 52.94672196252005, 51.44854096003941, 52.3248964037214, 50.09671333857945, 48.91764572688511, 43.827690737588064, 37.82955060686384, 39.87096609388079, 43.480996472494944, 46.16407115118844, 48.2801832471575, 49.684382915496826, 51.124876499176025, 54.11741352081299, 50.743333544049946, 53.926775796072825, 52.085089751652305, 52.55215808323452, 56.55449070249285, 49.678334508623394, 36.40395048686436, 37.23342643465315, 39.63859748840332, 35.757924352373394, 48.35538707460676, 45.546768869672505, 36.91029698508126, 38.388578346797395, 39.29130220413208, 35.61489568437849, 35.284849303109304, 38.255680152348106, 43.51159981318882, 57.816033431461875, 51.89307975769043, 51.720833914620535, 51.99373483657837, 50.053895064762656, 49.81015225819179, 48.341327394757954, 46.037818908691406, 42.90041194643293, 42.38128423690796, 38.932375635419575, 39.655992303575786, 38.31704316820417, 41.731068338666645, 48.980179514203755, 48.837255069187705, 46.113047054835725, 50.11134277071272, 47.35888685498919, 49.18991436277117, 38.02745614733015, 43.94312463487898, 45.291228021894185, 44.36556468691145, 50.49167326518467, 51.86218111855643, 49.870959418160574, 48.48904957090105, 46.96637964248657, 42.61377443586077, 42.501547132219585, 41.98231519971575, 51.96735600062779, 49.94664961951119, 50.41731364386422, 46.43074648720877, 40.246658665793284, 41.40416949135916, 40.44706208365304, 44.753819601876394, 53.342661585126606, 54.09555796214512, 55.889593260628835, 54.7505715915135, 53.728585379464285, 51.48187494277954, 58.32447133745466, 56.37278488704136, 56.57768031529018, 51.01764495032174, 47.1945550101144, 54.72103827340262, 56.00777169636318, 60.43725177219936, 36.375938824244905, 0.14935676700302533, 1.3133432865142822, 6.206410646438599, 8.403346793992178, 49.75305543627058, 46.002563749040874, 64.75948987688336, 59.048341614859446, 66.04599053519112, 61.28459848676409, 64.91216264452252, 54.31280728748867, 46.85127925872803, 50.88818958827427, 54.33273124694824, 58.78437260219029, 3.3313055634498596, 0.48416969392980846, 0.22399576833205564, 0.24428414180874825, 0.11235615744122437, 0.22843117532985552, 0.07336680245186601, 0.1365919355303049], [0.02678997897809105, 0.0343423807727439, 0.056944931857287884, 0.04235974020723786, 0.04650122619100979, 0.039020391181111336, 0.04855721443891525, 0.08208377898803779, 0.0437743398360908, 0.024111487437039614, 0.031163535812603574, 0.18988069679055894, 35.026761940547395, 41.777096680232454, 27.484441995620728, 23.91267534664699, 39.126449244362966, 52.0777177129473, 55.545435088021414, 57.070616790226524, 55.20958696092878, 49.45650979450771, 53.768005984170095, 45.424827984401155, 51.43211889266968, 13.694201128823416, 1.4238770753145218, 10.21281577859606, 1.0186486882822854, 4.364494442939758, 22.595493180411204, 50.988153321402415, 46.426025186266216, 52.30459724153791, 51.886412961142405, 52.20585639136178, 49.549091066632954, 49.48765162059239, 51.663149969918386, 52.37438842228481, 50.58037396839687, 53.368925775800435, 49.47783729008266, 53.66414431163243, 52.680268968854634, 46.69969041006905, 39.1599326133728, 36.96841866629464, 39.5281662940979, 42.81043277468, 45.4293338911874, 49.00814601353237, 49.68179471152169, 47.339126178196494, 47.377382959638325, 50.292652538844514, 48.68136875970023, 46.8666729927063, 48.84228556496756, 44.636468001774375, 40.6561472756522, 41.078479630606516, 37.27371209008353, 41.19331250871931, 45.031493936266216, 46.726336751665386, 46.20733410971505, 42.2120087487357, 38.63837650844029, 37.574211256844656, 34.53721271242414, 34.07191269738333, 39.35770961216518, 40.55855287824358, 42.4457357270377, 45.31861434664045, 43.98808990206037, 45.18327733448574, 43.605834756578716, 48.54025084631783, 46.56111901147025, 49.785107476370676, 47.228927748543875, 45.710690770830425, 38.6286073412214, 36.91103002003261, 38.444000652858186, 36.868104049137656, 43.14157002312796, 39.50875302723476, 37.892754895346506, 38.60213817868914, 37.464662483760286, 38.64018998827253, 37.759203570229666, 37.116877351488384, 43.166871888296946, 50.61790118898664, 49.41792297363281, 50.526549748011995, 48.95851155689785, 46.47528444017683, 44.50120741980416, 47.489655426570344, 45.19412694658552, 42.48845672607422, 38.311581884111675, 36.471552985055105, 34.18748903274536, 36.29121943882534, 36.310861996241975, 40.576573031289236, 41.45446055276053, 45.863526821136475, 43.89715535300118, 44.22956412179129, 39.72374071393694, 35.481007371629985, 37.80025700160435, 38.88064282281058, 44.90460245949881, 48.25467641013009, 45.52505922317505, 47.77303770610264, 44.92074312482561, 45.418070861271445, 47.18601219994681, 49.680985246385845, 47.65821177618844, 44.68670347758702, 47.29474803379604, 46.93423727580479, 41.2995365687779, 39.61500835418701, 35.74846090589251, 36.85892200469971, 37.90027979442051, 42.66622291292463, 48.997226919446675, 50.642049653189524, 49.320425851004465, 55.61261722019741, 47.82891511917114, 44.85767085211617, 59.87259946550642, 53.91328934260777, 50.31436218534197, 42.57014322280884, 48.91881649834769, 51.800053800855366, 56.297532422201975, 15.41058509690421, 0.29870623296925, 0.27745196489351137, 0.689744200025286, 32.03862312861851, 37.122481073652, 40.22068977355957, 52.8685964175633, 50.31424059186663, 52.92827102116176, 52.771113191332134, 47.806732995169504, 36.259361948285786, 27.24543786048889, 26.40876705305917, 40.86631638663155, 26.223446437290736, 0.187270209725414, 0.08870768533753497, 0.10912369803658553, 0.10069213368530784, 0.03684553377596395, 0.0595002608107669, 0.05763233532863004, 0.10401305370032787, 0.06808718932526452, 0.05158415576443076, 0.016232496559885994, 0.03927645333377378, 0.03168582796518292, 0.021093426438580667, 0.03739511999966843, 0.019778668148709194, 0.05973396184188979, 0.08376802504062653, 0.04624992735417826, 0.5775653709258352, 45.845346859523225, 51.17467771257673, 26.724691220692225, 27.581147023609706, 50.90622016361782, 54.18568304606846, 60.88186700003487, 61.68923377990723, 60.378032275608604, 52.74187169756208, 57.86381619317191, 49.708993434906006, 56.770958355494905, 14.954791954585485, 1.0012688551630293, 7.257463778768267, 0.6050079869372504, 6.5877633946282526, 28.473844630377634, 49.79634271349226, 48.304300444466726, 53.02633442197527, 51.9343763760158, 53.17758975710188, 50.76539060047695, 49.63447747911726, 52.59252711704799, 54.03715835298811, 53.157512937273296, 52.84999261583601, 52.024018560137065, 52.88204118183681, 54.724154540470664, 48.36617067881993, 41.664504596165244, 38.41485643386841, 40.09795331954956, 43.50926521846226, 48.63150153841291, 50.065411703927175, 52.555406366075786, 48.319659437452046, 49.7227543422154, 50.83688061577933, 51.735789912087576, 49.212343147822786, 50.47844736916678, 45.405122893197195, 43.556648458753315, 42.50915540967669, 38.27375936508179, 42.63935422897339, 46.089131355285645, 49.6167630468096, 48.49910361426217, 45.76788139343262, 42.798301219940186, 40.23064654214041, 35.82118770054409, 36.916675431387766, 41.0800325529916, 43.18528461456299, 43.299186434064595, 47.2400552885873, 44.979107992989675, 48.77565928867885, 47.178136416843955, 48.76016133172171, 48.90468733651297, 52.18528624943325, 48.40470886230469, 46.7147193636213, 38.09762947899954, 37.376441206250874, 37.3519800731114, 35.50459997994559, 43.44446284430367, 42.62902920586722, 36.35420833315168, 37.36210707255772, 36.804767744881765, 38.28967073985508, 39.671427726745605, 37.04232318060738, 43.969604219709126, 53.424990790230886, 50.269740853990825, 51.51533399309431, 49.96902976717268, 46.89458390644619, 48.03115633555821, 49.75933313369751, 45.87067651748657, 42.52900293895176, 39.486091477530344, 37.737705843789236, 36.26813057490757, 37.28758764266968, 37.15826777049473, 41.31214754922049, 44.1744510105678, 47.70671020235334, 46.11176858629499, 47.242914472307476, 42.2998548235212, 38.705603803907124, 40.330162116459434, 41.110635893685476, 47.779061794281006, 50.19844191414969, 47.74159710747855, 49.317611830575125, 46.54211221422468, 46.62915577207293, 46.30187824794224, 49.59877068655831, 49.16289281845093, 47.454976967402864, 50.01801109313965, 47.95731088093349, 43.777656759534565, 42.328328541346956, 37.52940232413155, 38.7119266646249, 39.9342155456543, 43.159468582698274, 50.38169717788696, 52.95926693507603, 50.85742991311209, 55.90632104873657, 50.16012954711914, 45.60033253261021, 60.51755210331508, 54.26816511154175, 53.83180781773159, 46.03498404366629, 53.2371358190264, 54.70321614401681, 58.96827752249581, 17.46682803971427, 0.28303144978625433, 0.6235262389693941, 0.13333663663693837, 34.751283236912315, 38.75929600851876, 46.36554111753191, 58.28486313138689, 55.571556840624126, 57.09775297982352, 58.677266120910645, 53.77212279183524, 42.71310935701643, 37.22249691826956, 29.96147653034755, 48.23407847540719, 32.2384672164917, 0.16150189244321414, 0.039449632433908324, 0.08439260973994221, 0.020323567391772355, 0.01244856375602207, 0.06150907730417592, 0.027905178422640477, 0.024758764043716446, 0.1528653223067522, 0.1730058565735817, 0.09070268007261412, 0.12959930646632398, 0.10787587892264128, 0.09872438213122742, 0.13180016194071087, 0.18602874848459447, 0.19026928022503853, 0.18588758605931485, 0.08495248255452939, 0.9009212883455413, 58.221526827131, 60.184434618268696, 37.79051562717983, 37.162815366472515, 55.17249400275094, 62.336152757917134, 65.57004587990897, 68.39239719935826, 65.69006211417062, 59.20531531742641, 61.210169383457725, 55.24121863501412, 62.9951685496739, 19.233838319778442, 1.8664691831384386, 20.4689188344138, 2.1747021291937148, 9.558582953044347, 34.66136312484741, 49.47102458136422, 48.193209171295166, 55.037049293518066, 53.144419057028635, 55.168599537440706, 51.94346114567348, 50.53836515971592, 53.94059576307024, 54.62047699519566, 53.560991355351035, 54.378644943237305, 52.99760709490095, 55.61726556505476, 56.97969266346523, 50.71121202196394, 44.446990626198904, 39.81946604592459, 42.94295229230608, 45.86716420309884, 50.117634364536826, 51.87108523505074, 55.97242273603167, 50.58914606911795, 51.59720809119088, 52.240979535239084, 53.620436668395996, 50.99664749417986, 52.482123715536936, 48.288649627140586, 46.03218739373343, 46.25623900549752, 40.32598624910627, 44.70988266808646, 47.61093623297555, 52.30972501209804, 52.16666160311018, 47.49110065187727, 44.7260684967041, 43.47445126942226, 39.12783888408116, 38.9968375478472, 45.21742425646101, 46.17778689520699, 47.20258017948696, 49.3886502129691, 48.904718603406636, 51.740257603781565, 49.205346311841694, 52.56721830368042, 51.13885974884033, 53.68898064749581, 50.31835739953177, 47.81700243268694, 39.08516304833548, 36.55089446476528, 37.174759319850374, 35.04935053416661, 47.29802758353097, 43.70079231262207, 38.33383696419852, 38.13688680103847, 37.43739775248936, 37.39392287390572, 38.755992140088765, 34.95186035973685, 44.57478189468384, 54.81104176385062, 52.154001985277446, 54.18206303460257, 51.87384366989136, 48.38972159794399, 49.91302033833095, 51.19825642449515, 47.28234897341047, 46.11456176212856, 40.981201376233784, 41.21575519016811, 38.78326729365757, 40.146510805402485, 38.82568257195609, 45.17726714270455, 46.26600122451782, 50.88274914877755, 48.91872617176601, 50.58293437957764, 45.98818097795759, 40.22348294939314, 43.007303033556255, 44.2294807434082, 49.380503450121196, 53.57652752740042, 50.92025899887085, 52.411505699157715, 48.64054461887905, 48.50839682987758, 49.1255601474217, 52.153734479631694, 49.4559782573155, 49.520784105573384, 53.50634029933384, 50.12473889759609, 44.977707930973594, 43.298929350716726, 38.309900420052664, 39.596633843013215, 42.58276809964861, 45.2742292540414, 53.68860197067261, 53.86720888955252, 53.16490582057408, 58.38662297385079, 50.54334701810564, 46.02443667820522, 60.67200360979353, 57.69146612712315, 55.91263696125576, 46.77460936137608, 55.394384724753245, 55.51314333506993, 59.13515935625349, 20.168958153043473, 0.21050337090023927, 1.9877332704407829, 1.7317780277558734, 39.08249494007656, 47.30013288770403, 53.08019685745239, 62.28439562661307, 60.66382558005196, 63.04926722390311, 63.707393646240234, 59.72574234008789, 48.811230591365266, 39.511938776288716, 36.18724659511021, 55.250379834856304, 42.28791087014334, 0.20918524877301284, 0.15225005389324256, 0.1968747236366783, 0.14869774665151322, 0.11540975501494748, 0.14705429412424564, 0.18156915849872998, 0.21953019366732665], [0.012395692307368984, 0.05994223816586392, 0.01395312016497233, 0.02128988946788013, 0.11891681754163333, 0.04734978512195604, 0.011271846630344433, 0.03555978794715234, 0.025313680159992406, 0.012320665842188256, 0.12465201265045575, 0.05033335788175464, 17.029588324683054, 50.74908317838396, 25.80155529294695, 21.373647247041973, 31.247410910470144, 45.72324616568429, 42.10679912567139, 56.343178612845286, 51.8153189931597, 50.90161003385271, 46.159294264657156, 44.860005446842735, 47.55815076828003, 29.474800382341655, 0.5937692214335714, 7.139459916523524, 1.0029097156865256, 7.20539528131485, 32.42921611240932, 47.46752888815743, 50.760085650852744, 51.391298225947786, 51.29272413253784, 50.53620774405343, 54.8085160936628, 54.0108003616333, 54.535167012895855, 52.0507378578186, 53.90503140858242, 52.83832311630249, 52.288616384778706, 50.82341848100935, 47.41921806335449, 41.47173377445766, 39.05054712295532, 37.604234422956196, 38.97368267604283, 43.991393770490376, 48.69247892924717, 51.819567816598074, 49.632604939596995, 48.60343081610543, 46.889428343091694, 43.61977284295218, 46.821040698460166, 53.94759954724993, 50.78254222869873, 47.26091725485665, 42.34677600860596, 41.64727306365967, 37.99350030081612, 38.501017570495605, 43.537968226841514, 43.764156409672324, 45.09242616380964, 42.3739469391959, 39.305893421173096, 33.88868522644043, 32.784720693315776, 37.305618218013215, 40.0319002696446, 42.10904686791556, 45.13451835087368, 44.18847942352295, 44.751710823604036, 44.620931829724995, 44.48395504270281, 47.31836496080671, 46.95591565540859, 48.85443449020386, 48.42085647583008, 44.69236625943865, 37.528710978371755, 37.12856074741909, 37.37301574434553, 36.05571372168404, 41.53424324308123, 39.991468702043804, 36.51704631532942, 39.70828444617135, 36.527652740478516, 37.95193270274571, 37.58372681481497, 41.21643958772932, 45.11151286533901, 49.656468527657644, 52.75479882104056, 49.65062509264265, 50.98088550567627, 49.87184878758022, 43.40607752118792, 45.901839188167024, 46.56546858378819, 45.359400272369385, 40.64942489351545, 37.14982223510742, 35.89642626898629, 32.96564136232649, 33.53678676060268, 35.979311329977854, 41.06762307030814, 41.2041551726205, 44.99402577536446, 43.19470289775303, 38.51246125357491, 35.53517552784511, 39.560927050454275, 42.369413239615305, 46.3974472454616, 46.93227440970284, 46.31824472972325, 44.8804018838065, 47.31056560788836, 47.22986575535366, 48.1159382547651, 48.36639302117484, 51.54522166933332, 52.1635661806379, 51.05968155179705, 44.88992786407471, 43.266564641680034, 38.479596274239675, 37.71922710963658, 35.47682803017752, 38.559997354234966, 37.84839759554182, 42.02410166604178, 46.909932477133616, 52.964752537863596, 50.30470071520124, 52.66199173246111, 50.733856201171875, 54.59914255142212, 56.516240869249614, 53.69339622770037, 47.25378145490374, 53.340507643563406, 51.17480625425066, 53.95843873705183, 8.472745401518685, 0.049209194989608865, 0.28257485000150545, 1.195125224334853, 50.05663612910679, 56.15522984095982, 53.05455453055245, 46.76040724345616, 54.781814166477744, 48.77799040930611, 59.24908202035086, 41.58806051526751, 36.39027990613665, 27.35988858767918, 27.576726232256206, 47.550813470567974, 13.005867413112096, 0.36528867589575903, 0.11231510607259614, 0.005815308466221073, 0.05583732521959713, 0.03659561236522027, 0.05444903578609228, 0.03647841240412422, 0.052703847110803635, 0.07811761966773442, 0.05234894954732486, 0.06382951100489923, 0.03599300202248352, 0.057527528809649606, 0.09860825764813594, 0.06033261971814292, 0.043653363827615976, 0.05277668445238045, 0.08596761843987874, 0.12406282712306295, 0.07482414639421872, 22.953017950057983, 61.715609141758506, 29.225047383989605, 27.784322772707256, 43.619279520852224, 49.33187300818307, 53.181692668369834, 60.74746104649135, 58.82142039707729, 55.68193244934082, 53.09204701014927, 50.09770345687866, 52.270151547023225, 28.61676386424473, 0.48430252394505907, 4.64423108952386, 1.7990623201642717, 8.603250810078212, 36.827887875693186, 47.15929985046387, 49.743730953761506, 52.44554144995553, 53.293447494506836, 52.57030330385481, 55.30221687044416, 55.511847496032715, 56.17142609187535, 54.43173265457153, 55.85538380486624, 55.41215474264962, 55.2134883744376, 52.43835006441389, 50.62003081185477, 43.213563782828196, 40.94427170072283, 39.23898226874215, 41.36259494509016, 44.554541792188374, 51.72629867281233, 53.948600087847026, 52.57658794948033, 49.96348510469709, 49.02383157185146, 44.48779739652361, 48.69286108016968, 53.98511981964111, 50.95776537486485, 50.39213684626988, 44.71732766287667, 44.029876368386404, 39.279240131378174, 41.15160942077637, 45.164374760219026, 46.8253937448774, 47.11939982005528, 46.274234839848106, 40.44482476370675, 36.888521330697195, 35.97334977558681, 40.29096385410854, 42.64820623397827, 45.280406202588765, 47.304148946489605, 48.99506255558559, 47.36781529017857, 46.33648027692522, 46.934918199266704, 50.18728310721261, 50.22032873971121, 50.45032800946917, 50.75199099949428, 45.797119413103374, 38.134392397744314, 36.87137317657471, 37.703996658325195, 36.17509766987392, 41.510925088609966, 39.93427807944161, 36.11472477231707, 38.33315256663731, 36.49263381958008, 38.557409150259836, 36.92405094419207, 38.42518493107387, 45.26651675360543, 51.556439535958425, 51.393483434404644, 51.65432228360857, 52.42248385293143, 50.35433169773647, 45.49772848401751, 47.08252225603376, 47.14940561567034, 45.840246881757466, 41.64964239937918, 39.740652629307334, 36.300443172454834, 35.34143195833479, 35.178646087646484, 38.266390800476074, 42.52813788822719, 44.854245390210835, 46.4816107749939, 46.36266108921596, 40.83981943130493, 36.17913804735456, 41.17601844242641, 44.68544585364205, 48.76361458642142, 49.10333980832781, 47.56786434991019, 48.05832379204886, 49.578026839665, 49.7387421471732, 50.00885336739676, 49.26043163027082, 50.794844014304026, 53.326076235089985, 52.99024895259312, 47.58672176088606, 45.50294658115932, 40.839864594595774, 38.4318447794233, 37.124468258449006, 39.981084619249614, 39.71635825293404, 43.03031546728951, 48.97416932242257, 55.93012210300991, 51.647749287741526, 53.53015872410366, 51.07756274087088, 53.08591175079346, 57.88827732631138, 55.736621720450266, 50.268729891095845, 54.828506061008994, 54.05980600629534, 55.79447937011719, 10.064007077898298, 0.05716126239193337, 0.6822099643094199, 1.5892022954566138, 56.58005312510899, 56.4184102330889, 56.72414486748831, 52.91513892582485, 59.904957226344514, 52.231495244162424, 67.76020840236119, 44.25481040137154, 48.60900674547468, 31.809402057102748, 23.82823215212141, 55.9611736025129, 16.664861747196742, 0.3556387137089457, 0.12808016155447277, 0.007708768493362835, 0.027159512541922073, 0.09341557164277349, 0.04985566922862615, 0.03398455193798457, 0.03620004002004862, 0.14091454286660465, 0.12810700439981051, 0.21959755862397806, 0.21683061495423317, 0.16362562562738145, 0.21828103783939565, 0.11794857521142278, 0.12734700446682318, 0.28462584423167364, 0.13837649620005063, 0.34250596697841373, 0.1882359143346548, 30.616827147347585, 71.16547884259904, 37.87652390343802, 30.812165328434535, 43.62485545022147, 57.29274722508022, 51.51765469142369, 65.52660574231828, 62.14784267970494, 59.53247124808175, 59.98220035008022, 56.752743652888704, 56.92974901199341, 37.362781047821045, 0.7457438579627446, 15.562351124627249, 2.595101365021297, 10.533932856151036, 44.92279631750924, 46.29915107999529, 52.95406968252999, 56.14199004854475, 53.98639481408255, 54.565902369362966, 57.508596488407676, 58.10164955684117, 59.366583006722585, 55.97464963368007, 57.886314460209434, 57.446802684238975, 56.87896115439278, 53.92723090308053, 52.87251172746931, 45.45525067193167, 44.037953649248394, 42.1045583316258, 44.13626023701259, 46.787588596343994, 54.360544885907856, 57.56719759532383, 54.049863134111675, 51.89898225239345, 50.85147530691964, 46.31504855837141, 51.36075047084263, 57.61292716435024, 55.18952056339809, 52.18140915461949, 45.02414969035557, 46.425160135541645, 41.69959647314889, 42.46500655582973, 47.45849622998919, 48.587828636169434, 50.2689973967416, 47.97785323006766, 44.31400557926723, 40.39074345997402, 36.61180932181222, 44.495141642434255, 45.579783235277446, 49.586048534938264, 51.27373817988804, 49.89808865955898, 51.408276149204795, 49.97868081501552, 50.44587421417236, 53.035856928144185, 52.820824078151155, 52.05816548211234, 55.33641242980957, 47.920867579323904, 38.46904196058001, 36.6046769959586, 37.010434423174175, 34.78630910600935, 44.729553018297466, 42.52474021911621, 36.333037172045024, 37.7719396182469, 36.72214324133736, 36.54599945885794, 36.29218871252877, 39.985399450574604, 46.47666365759713, 52.61374691554478, 56.02980790819441, 52.16015461512974, 54.25283391135079, 51.782711097172324, 46.48435878753662, 49.777679852076936, 51.3455547605242, 47.838350772857666, 44.63879912240164, 43.02295732498169, 39.10887377602713, 36.33328035899571, 38.124994959150044, 40.75837959562029, 45.13020004544939, 46.94579907826015, 49.26635149547032, 46.74440554210118, 43.76650142669678, 37.731421198163716, 43.95495394298008, 47.35407870156424, 51.78528887884957, 52.13922316687447, 50.824349539620535, 48.512402466365266, 49.894878591809956, 53.02985715866089, 52.092378411974224, 52.28644159861973, 53.14897360120501, 53.5691693850926, 55.39461748940604, 49.21270792824881, 48.38077579225813, 41.68085718154907, 40.780791010175435, 38.39138194492885, 42.16238471439907, 41.05608558654785, 45.5025748525347, 51.731648785727366, 59.09513773236956, 54.27750696454729, 56.18141065325056, 50.666052205221995, 55.49455690383911, 58.46763896942139, 59.282940592084614, 51.81625352587019, 57.56471708842686, 54.83398471559797, 58.93573216029576, 11.666238222803388, 0.11734595469066075, 2.4065142273902893, 1.3455063892262322, 60.79592473166329, 64.19287817818778, 61.76107120513916, 58.253797735486714, 65.74199989863804, 59.93841975075858, 69.86063494001115, 52.066242762974326, 50.09371171678816, 37.48620537349156, 37.58048895427159, 64.2169884272984, 24.1670332636152, 0.5580150399889264, 0.21205998451582023, 0.16034024049128803, 0.15369750479502337, 0.19211805744894914, 0.11673075413065297, 0.1424287480435201, 0.1493937335908413], [0.03792639934856977, 0.08197475876659155, 0.03721910123048084, 0.04855330268453274, 0.054517041958336315, 0.05943307905857052, 0.0408151705882379, 0.014139317807608416, 0.038996086056743345, 0.09142605268529483, 0.07653549313545227, 0.07322741100298506, 6.021321926798139, 47.46621567862374, 29.853793348584855, 30.5733140536717, 28.662026166915894, 44.35775491169521, 40.315449305943076, 56.054286411830354, 49.364366258893696, 54.89563608169556, 44.6277619089399, 49.6189968926566, 42.383177621024, 42.70059565135411, 0.23415700665542058, 3.3390082929815565, 0.4518256394990853, 2.730554542371205, 22.877666473388672, 33.944739818573, 53.31159271512713, 51.18050030299595, 55.754482064928325, 53.28773260116577, 54.497281960078645, 49.942004748753135, 52.5613887650626, 50.424223627362935, 51.58424622671944, 48.56457996368408, 47.553696972983225, 43.34782729830061, 41.06908219201224, 37.30436059406826, 38.270688261304585, 40.00460079738072, 38.9791648047311, 40.0760178565979, 42.89316497530256, 51.88906022480556, 48.96474756513323, 51.39246552331107, 50.71049983160836, 47.11499466214861, 41.65660449436733, 41.892547948019846, 49.2510724067688, 49.649395261492046, 43.488910470690044, 41.005005904606406, 37.2242374420166, 36.34798622131348, 40.16166482652937, 44.83834096363613, 43.65949222019741, 40.24100283214024, 35.244650500161306, 34.80796316691807, 35.39492613928658, 38.961641447884695, 41.162181104932515, 42.626795360020225, 45.966592924935476, 44.68684591565813, 47.6590108190264, 46.527580056871685, 45.65569230488369, 48.60888862609863, 48.148410660879954, 47.5613226209368, 49.30078329358782, 44.10778999328613, 37.126851490565706, 37.85731560843331, 37.46638216291155, 37.659410067967, 41.31047650745937, 41.510779176439556, 37.56828791754586, 39.627084323338096, 37.120076996939524, 39.00072506495884, 39.406687464032856, 42.04056542260306, 47.30882855824062, 50.22976439339774, 50.590511390141074, 49.1520015171596, 48.74496214730399, 49.72847965785435, 46.35045657839094, 49.79382051740374, 46.24035194941929, 45.62635006223406, 42.67208024433681, 39.91050829206194, 36.63863631657192, 34.50008501325335, 34.32758903503418, 33.75988646915981, 39.99038478306362, 40.30315794263567, 43.47117519378662, 40.01488413129534, 36.15834903717041, 34.944860049656455, 38.69652598244803, 44.03999294553484, 47.024838311331614, 46.89502511705671, 43.77634702410017, 44.73941946029663, 47.59972531454903, 44.82083150318691, 45.919921875, 45.93539898736136, 47.93746335165841, 45.970174721309114, 46.92864745003836, 43.305109773363384, 41.10356262751988, 37.329054491860525, 36.59149973733084, 36.340687138693674, 37.16069269180298, 35.30599961962019, 37.500720160348074, 39.247726576668875, 44.36951126371111, 50.19608300072806, 52.625986167362754, 52.82872417994908, 52.60822657176426, 46.953435148511616, 57.312000683375764, 48.960276399339946, 53.264230319431846, 52.371775899614605, 45.727901458740234, 7.073072050298963, 0.40138473042419975, 0.8374224070991788, 6.62761652469635, 55.2260229246957, 46.880503382001606, 50.66014276232038, 49.82631376811436, 53.37480395180838, 52.534259523664204, 48.32788610458374, 43.227352482931956, 30.774228164127894, 23.6177590574537, 34.61265277862549, 44.521520478384836, 3.8366410987717763, 0.5104291077171053, 0.14114493264683656, 0.04524002975917288, 0.023669639003596137, 0.037059757459376536, 0.0234323960196759, 0.06237455550581217, 0.019614900329283307, 0.0565646367280611, 0.11226714043212788, 0.0426669605076313, 0.03907571553385683, 0.06663551115031753, 0.0779812748410872, 0.01727795447888119, 0.04517794719764164, 0.07847087856914316, 0.041680831994329176, 0.09380445363266127, 0.21090571502489702, 9.327287844249181, 57.764019216809956, 31.074640478406632, 23.537213802337646, 41.077809129442485, 49.63516187667847, 43.590826647622244, 61.32948384966169, 54.18203524180821, 58.8078853062221, 50.03461728777204, 53.73870195661272, 48.4363648550851, 47.43924971989223, 0.28126696018236025, 1.9652447743075234, 2.2990077904292514, 3.2684445594038283, 27.362344775881084, 35.79817526681082, 54.246132373809814, 54.79739202771868, 58.07007346834455, 54.76698671068464, 55.2683687210083, 51.2699305670602, 53.85083545957293, 52.52147136415754, 54.153759547642295, 49.672529288700645, 48.719896520887104, 45.44340399333409, 43.20960678373064, 38.51825257710048, 39.79303857258388, 40.38744306564331, 39.24984230313982, 42.58474138804844, 46.146346296582905, 52.4431790624346, 50.032817704336985, 52.96110473360334, 50.38984394073486, 48.78932639530727, 42.405179091862266, 45.530346802302766, 50.84445762634277, 50.99024820327759, 45.62476239885603, 43.51605013438633, 40.234926632472444, 37.40498440606253, 42.024535928453716, 46.9609009878976, 46.92785882949829, 45.1277369090489, 39.53221361977713, 37.02482066835676, 37.21319328035627, 41.56610420772007, 44.35162660053798, 46.456576415470664, 46.780445848192485, 48.079064164842876, 51.8747365134103, 48.39202492577689, 49.15839385986328, 49.75344453539167, 50.91104916163853, 50.2872120993478, 51.60842943191528, 45.18002905164446, 36.61402232306344, 35.791987895965576, 37.99000188282558, 38.28362233298165, 40.86437783922468, 42.74704088483538, 36.81754548209054, 38.6784085546221, 37.31581122534615, 37.75767496653965, 39.353502477918354, 40.85991709572928, 47.199359689440044, 51.568032605307444, 52.72016552516392, 51.34561729431152, 48.83355515343802, 50.28835160391671, 49.88595015662057, 51.545617716653005, 47.415472984313965, 48.482132639203755, 44.95907286235264, 41.99053839274815, 37.588392530168804, 34.61445583615984, 35.20872483934675, 37.32634816850935, 41.95967449460711, 40.95678540638515, 45.38395868028913, 43.339479037693565, 37.853931835719514, 37.46331105913435, 41.51545878819057, 45.54732819965908, 48.89556435176304, 47.402934959956575, 46.64845439365932, 47.68367344992501, 50.08257375444685, 47.1778689111982, 48.2879513331822, 48.619224071502686, 50.02267680849348, 47.651753425598145, 48.02450343540737, 45.57086174828665, 42.056282247815815, 39.62455170495169, 39.03162022999355, 38.17168337958199, 38.81174448558262, 36.90521437781197, 39.76109075546265, 41.671563965933665, 46.9794214112418, 52.49260854721069, 55.538240228380474, 54.43162843159267, 55.359605516706196, 47.54774236679077, 59.56473868233817, 52.840171337127686, 57.72377872467041, 54.422505446842735, 48.131759302956716, 9.031523874827794, 0.5401849310312952, 0.8273966450776372, 8.886314341000148, 60.24095126560756, 52.29379626682827, 56.815155846732004, 54.92185858317784, 59.576682635716026, 58.93809454781668, 57.560638495853965, 43.98467833655221, 45.474917548043386, 24.704554591860088, 32.03844942365374, 53.64597824641636, 5.373182671410697, 0.48397563291447504, 0.11350773314812354, 0.01562333496154419, 0.05795073788613081, 0.04762022203898855, 0.031690272369555066, 0.03936735667022211, 0.03473867575771042, 0.16643980890512466, 0.16330788124884876, 0.21447072444217546, 0.18231642911476748, 0.22206412841166767, 0.17645818846566336, 0.09864704270980187, 0.12219980066376072, 0.1386575996875763, 0.21441655020628655, 0.23830242135695048, 0.3472472168505192, 12.380797914096288, 69.67481231689453, 41.815197127205984, 40.42391416004726, 40.44335869380406, 59.70794800349644, 49.528375012534006, 67.58122975485665, 60.14387798309326, 65.21196351732526, 52.63090896606445, 61.324599266052246, 53.11354126249041, 56.605622495923726, 0.32112294009753634, 10.507464562143598, 1.868235545498984, 3.3097626737185886, 32.720644405909944, 39.087713037218364, 56.55388968331473, 55.502380575452534, 59.998709269932334, 57.567541531154085, 58.00092499596732, 53.86231388364519, 57.487922123500276, 53.42541463034493, 56.530689648219514, 52.06216069630214, 51.80661290032523, 47.06898716517857, 45.83338206154959, 40.71121522358486, 43.19404976708548, 43.75568308149065, 42.280340807778494, 44.854398250579834, 49.18531812940325, 57.92520005362374, 53.03975139345442, 54.94278655733381, 53.52415548052107, 50.74250670841762, 44.00135401317051, 49.15777199608939, 53.83799866267613, 52.812333379473, 49.17857142857143, 46.21849986485073, 42.69745853969029, 39.288064343588694, 43.298491614205496, 48.83193622316633, 50.04009941646031, 47.12704283850533, 42.211817673274446, 39.51019825254168, 39.56458527701241, 43.78287485667637, 48.36617415291922, 51.21657535008022, 49.449061325618196, 52.15583978380476, 55.35516561780657, 51.6304725919451, 51.63038921356201, 53.57162209919521, 54.129774366106304, 52.68876314163208, 54.25674227305821, 46.474954400743755, 36.09795182091849, 35.984088216509136, 38.01467146192278, 38.843056542532786, 43.51610571997506, 45.004996980939595, 37.522356850760325, 39.03986774172102, 37.949434825352256, 38.293926511492046, 39.45890665054321, 40.405206135341096, 46.63404730388096, 54.05337544849941, 52.93591056551252, 52.57500376020159, 50.04469217572893, 52.73241867337908, 48.94172818320138, 53.5536401612418, 49.41629014696394, 50.21249464579991, 47.58000980104719, 44.469200542994905, 41.405107498168945, 37.13671793256487, 37.34574406487601, 39.29427603312901, 43.82564449310303, 44.42548942565918, 48.525572776794434, 44.848603452954976, 41.287860121045796, 39.881183419908794, 43.76592820031302, 48.87088087626866, 50.27113744190761, 51.08156142915998, 49.946396010262625, 49.60899496078491, 54.000624724796836, 49.78178971154349, 50.407613958631245, 49.60253661019461, 51.82722125734602, 49.74831329073225, 51.02030611038208, 47.03531966890608, 44.419489656175884, 40.99858924320766, 40.694206033434185, 39.96276569366455, 40.67783260345459, 37.70657444000244, 41.160225187029155, 42.94151054109846, 48.065497807094026, 53.00200183050973, 54.76953322546822, 56.51966980525425, 59.359926632472444, 49.81980330603463, 62.30339200156075, 55.00984014783587, 60.148192814418245, 55.2826646396092, 51.3749178477696, 11.240596788270132, 1.2652323309864317, 2.4046801200934818, 8.533424019813538, 65.29653699057442, 56.03822565078735, 61.86858763013567, 61.09137603214809, 62.547496114458355, 61.56294332231794, 59.57707173483712, 53.91928563799177, 40.173914500645225, 34.10888058798653, 44.82428823198591, 62.25399030957903, 8.272674628666469, 0.7296893394419125, 0.26357863790222574, 0.1942441112228802, 0.19794823388968194, 0.16122186104101793, 0.1649742546890463, 0.15994101762771606, 0.19533879176846572], [0.02989217492618731, 0.10098466370254755, 0.042349999837045155, 0.06635227027748312, 0.011888815622244562, 0.0497578991177891, 0.08071670734456607, 0.05310730403289199, 0.16749810640301022, 0.022244494940553392, 0.04371465928852558, 0.08654158442680325, 1.2989798401083266, 45.205098152160645, 41.40773391723633, 35.894605840955464, 23.8962949684688, 42.60480778557913, 58.21856689453125, 52.13065256391253, 53.608954770224436, 53.2087003162929, 50.601506914411274, 49.87079266139439, 43.49118947982788, 47.57923855100359, 4.264611916882651, 1.8438540995121002, 1.66373453608581, 0.4642962174756186, 8.221445560455322, 40.73242807388306, 62.63064520699637, 54.27817746571132, 54.97045428412301, 48.65238434927804, 48.20853689738682, 45.44168084008353, 46.037756374904085, 42.260385581425254, 42.73461403165545, 38.71464341027396, 39.55170679092407, 35.68181378500802, 38.02487489155361, 37.84560094560896, 37.80873727798462, 36.470882483891074, 37.38313232149397, 39.22189317430769, 37.882547991616384, 44.592760358537944, 48.716995647975374, 48.9244202205113, 48.1077115876334, 49.61415747233799, 46.96081413541521, 46.49542031969343, 48.392511299678254, 51.54927246911185, 44.26677172524588, 43.21152796064104, 39.123367718287874, 37.77452434812273, 37.183875356401714, 38.52395357404436, 40.41444376536778, 38.683171544756206, 35.5789908681597, 34.54107591084072, 34.67888648169381, 40.59180000850132, 42.58178492954799, 45.778136934552876, 44.569796562194824, 46.60239825929914, 47.901926789964946, 47.879723821367534, 46.30299343381609, 47.23177303586687, 48.898423535483225, 49.95319134848458, 46.70908090046474, 37.180661814553396, 35.861890247889924, 39.1138139452253, 38.07443291800362, 37.01080962589809, 38.00417620795113, 41.33833530970982, 36.410933426448274, 39.77097109385899, 39.204355921064106, 39.57283973693848, 37.573849950517925, 38.66545016424996, 46.062728200639995, 48.80337912695748, 49.98903015681675, 49.940754073006765, 50.714734758649556, 48.25037200110299, 48.425449235098704, 48.00765405382429, 46.96827302660261, 46.41175706045968, 45.33722162246704, 42.233794825417654, 37.60498135430472, 34.18856600352696, 34.67204598018101, 34.21408673695156, 37.14428799492972, 39.71652153560093, 40.17092677525112, 37.13403245380947, 35.70607689448765, 37.53260544368199, 39.16869081769671, 43.76740121841431, 47.22573505129133, 44.50499071393694, 43.34201513017927, 46.02953665597098, 46.13229703903198, 42.9131167275565, 42.913172313145225, 40.2929162979126, 44.45644365038191, 43.404173714774, 41.80090468270438, 36.75441762379238, 37.189277580806184, 34.9511273247855, 34.79179470879691, 36.05957344600132, 36.85765395845686, 36.154194014413015, 38.44399717875889, 37.05939143044608, 41.431920596531455, 42.1266188621521, 48.96387209211077, 50.241795199257986, 54.5330547605242, 51.84081193378994, 54.84907620293753, 52.333616392953054, 56.515872614724294, 50.9469644001552, 29.75742530822754, 3.3064355722495486, 1.3778217009135654, 0.6801060172063964, 20.141319956098283, 55.41863741193499, 44.130208356039866, 54.153915882110596, 48.372507435934885, 51.935342175619944, 42.24935531616211, 43.14478356497628, 38.55321938650948, 28.869334357125418, 28.37443675313677, 40.54358645847866, 34.34987538201468, 0.4818293995090893, 0.06644290219992399, 0.08802162536552974, 0.05689335980319551, 0.0725090391933918, 0.08304255575473819, 0.04430700000375509, 0.08099582950983729, 0.039511908377919874, 0.05599830765277147, 0.08133840148470231, 0.029205480523939644, 0.0284950781081404, 0.02467003880467798, 0.0472099424472877, 0.03379437892830797, 0.024739673460966775, 0.06988937833479472, 0.04495621891692281, 0.027888360932203274, 0.04920628407437887, 2.199501769883292, 55.7116186278207, 47.495811530521934, 35.255694661821636, 32.334651129586355, 49.55355181012835, 55.58632523672921, 56.00680242265974, 58.79319681440081, 60.42466858455113, 55.466513974326, 56.048515932900564, 48.12672185897827, 53.91755206244332, 4.1473172051565985, 1.046072251030377, 2.7605553439685275, 0.10448483231344394, 10.479585783822195, 43.1325477872576, 61.29478454589844, 56.23736102240426, 56.79157018661499, 49.941893577575684, 51.66155883244106, 47.22134378978184, 47.480035645621165, 44.71958582741873, 46.52742372240339, 39.863468987601145, 41.799428190503804, 37.62850448063442, 39.589970520564485, 39.22309521266392, 38.42911066327776, 38.15328107561384, 40.23526362010411, 40.747714110783164, 41.27299792425973, 46.47966875348772, 50.35621465955462, 51.09564890180315, 51.74686534064156, 51.596683502197266, 47.09754426138741, 48.332603931427, 51.93950414657593, 53.31948586872646, 46.29602786472866, 44.750484466552734, 41.503455775124685, 40.52160930633545, 38.41621133259365, 39.8344463620867, 43.59298406328474, 41.73567846843174, 38.525079182216096, 35.665579319000244, 38.14174359185355, 43.37977164132254, 45.7387614931379, 48.46983780179705, 47.259840284075054, 48.98879180635725, 50.51689870016915, 50.8057005746024, 51.165547779628206, 49.45327888216291, 49.54516186032976, 51.12832627977644, 49.09083652496338, 38.59466886520386, 35.666291509355815, 38.0887496812003, 37.85782977512905, 38.061839308057515, 41.12410845075335, 43.07230690547398, 35.39607606615339, 39.23907954352242, 39.00409494127546, 38.24226318086897, 36.67116778237479, 38.110914434705464, 45.44510977608817, 51.310904094151084, 51.22478117261614, 53.09257507324219, 52.387854031154085, 50.61521918433053, 49.385117053985596, 47.77394792011806, 49.50279521942139, 48.60034234183175, 47.0834880556379, 44.94157035010201, 39.61123200825283, 36.59835066114153, 36.04595845086234, 36.039003304072786, 38.793397767203196, 41.35328435897827, 41.438917432512554, 38.481850964682444, 38.46576241084507, 39.174624579293386, 42.43407664980207, 45.50400965554373, 51.084872245788574, 44.99516527993338, 46.23042297363281, 47.8233322416033, 49.33566672461373, 46.9512916292463, 46.21295520237514, 41.52464778082711, 46.41653394699097, 44.95387213570731, 44.10416650772095, 38.61325182233538, 40.11464984076363, 37.570678097861155, 38.15182542800903, 36.51417670931135, 38.31321471078055, 37.16142920085362, 41.43855612618582, 39.11891392299107, 42.25922523226057, 44.6068617275783, 51.113092354365754, 51.43637466430664, 56.72255720411028, 53.7776848248073, 57.10158838544573, 56.0826871735709, 57.745050634656636, 53.22954143796648, 32.92164189474923, 3.4761107989719937, 2.23713755607605, 0.13663156197539397, 22.385520356042043, 61.054557527814595, 48.06521987915039, 61.31828335353306, 52.54561635426113, 58.37740271432059, 46.802457741328645, 46.19581399645124, 44.92991822106497, 35.46942125047956, 21.51909909929548, 46.52557897567749, 41.20796625954764, 1.1712227697883333, 0.11363179649093322, 0.08699606039694377, 0.027756472384291034, 0.03896122292748519, 0.02578786078707448, 0.05079901271632739, 0.018295151414349675, 0.017471886572561095, 0.23851268578852924, 0.2094872375684125, 0.13540983253291675, 0.19008762282984598, 0.12501847584332737, 0.25695735748325077, 0.1515741515904665, 0.11840456431465489, 0.2714676931500435, 0.16203361962522778, 0.11525730176695756, 0.1910853407212666, 2.9937410141740526, 68.04857948848179, 56.062881333487375, 45.01650319780622, 33.84669031415667, 53.38801942552839, 68.98562049865723, 61.89650549207415, 64.58028193882534, 65.21740395682198, 61.37987913404192, 60.173380034310476, 52.699956689562114, 59.67413112095424, 5.097324422427586, 5.2651025738034924, 6.079355452741895, 0.7385480212313789, 13.799235309873309, 47.130819184439524, 64.53199890681675, 59.8341064453125, 59.90472098759243, 53.785414695739746, 53.2299930708749, 50.18316977364676, 49.431815896715435, 45.956584044865195, 48.143282890319824, 43.18044866834368, 43.62363951546805, 40.18908589226859, 41.33977011271885, 41.3229797908238, 40.68852240698678, 39.05416366032192, 42.72423342296055, 42.983446393694194, 42.00269774028233, 50.84051104954311, 53.4664055279323, 55.22805527278355, 52.66961738041469, 54.22685807091849, 49.55885328565325, 48.42457376207624, 53.09539256777082, 58.29035568237305, 48.27862685067313, 47.86174883161272, 43.54569462367466, 43.017534255981445, 41.29770919254848, 43.168713160923545, 46.5258777482169, 45.71976859228951, 42.50404500961304, 40.47042540141514, 40.184524399893625, 46.21443516867501, 48.93736471448626, 51.324532985687256, 49.51589952196394, 53.27616037641253, 53.35301092692784, 53.601697376796174, 53.37578364780971, 53.13272871289934, 51.346760272979736, 55.21997104372297, 51.46772493634905, 38.148174149649485, 35.85605376107352, 39.10062279020037, 38.00008371898106, 36.955140658787315, 39.476805210113525, 45.2463252885001, 35.681598390851704, 39.239958490644185, 38.7470498085022, 38.58766508102417, 35.97538907187325, 37.51508208683559, 45.98375497545515, 52.42059046881539, 52.19797713415963, 54.08623347963606, 55.00559479849679, 52.83742332458496, 51.04544121878487, 49.99140644073486, 52.07808944157192, 49.351466928209575, 49.761754580906455, 46.586063044411794, 42.89149393354143, 39.136920179639546, 39.513265882219585, 37.37109456743513, 40.25485406603132, 41.662722383226665, 42.36759281158447, 41.32134696415493, 39.99536664145333, 41.90414449146816, 43.77182027271816, 47.69653803961617, 51.70432152066912, 48.612560749053955, 46.41439042772566, 50.419755935668945, 51.29614264624459, 49.17197411400931, 48.13559818267822, 44.231797967638286, 49.19625111988613, 47.49301488058907, 46.080651078905376, 40.835886750902446, 41.76424251283918, 39.70893062864031, 39.34632846287319, 39.42823730196272, 41.072792530059814, 38.35259015219552, 43.44923278263637, 40.954231943402974, 44.9597954750061, 45.67092275619507, 53.95964077540806, 52.20310490471976, 58.533084051949636, 54.828669343675884, 59.89435427529471, 55.46837609154837, 61.900910649980815, 52.842940194266184, 39.261216504233225, 6.017390549182892, 3.8325794424329485, 1.6821423768997192, 23.669406754629954, 67.36238929203579, 51.34153522763933, 65.68258585248674, 57.095797061920166, 62.33927249908447, 53.20043543406895, 53.04388209751674, 48.505311829703196, 41.37159286226545, 37.59839793613979, 52.48682764598301, 51.18942526408604, 1.9918342275278909, 0.34709215802805765, 0.23355737168874058, 0.18743887996034964, 0.13965546685670102, 0.14013372547924519, 0.2027048050825085, 0.16417089636836732, 0.08531641481178147], [0.06521433990980897, 0.024894455780408213, 0.02453960571438074, 0.03979836889941778, 0.053214112230177434, 0.06899107939430646, 0.08261398625160966, 0.019698692618736198, 0.051559077110141516, 0.05348078327785645, 0.03394581437376993, 0.05340453969048602, 0.026946004712954164, 28.413836513246807, 45.819117409842356, 35.37698936462402, 28.37643609728132, 35.039977414267405, 51.873857566288535, 54.336292198726106, 51.16958120891026, 51.68528345652989, 48.57441166469029, 50.25375999723162, 44.988293511526926, 49.82176617213658, 15.971627814429146, 1.745883196592331, 1.7213644151176726, 0.02854750511635627, 3.1253996065684726, 33.71885388238089, 58.41086523873465, 52.9533748626709, 57.18868752888271, 51.08057478496006, 45.313368456704275, 39.562334060668945, 40.505347047533306, 37.77537897654942, 39.67215381349836, 39.350816999162944, 38.96310404368809, 38.556412083762034, 39.06085130146572, 38.14832353591919, 40.89869499206543, 40.66599287305559, 39.379863943372456, 38.64207642418997, 38.33681774139404, 38.502577441079275, 41.9710556438991, 45.269650391169954, 48.101694447653635, 47.375350611550466, 52.546314648219514, 49.44208880833217, 52.038998876299175, 49.54191010338919, 47.1362943649292, 42.09174237932478, 40.58729062761579, 36.898846353803364, 37.38259036200387, 36.83818858010428, 38.68077789034162, 35.933237825121196, 35.29227692740304, 33.492078576769146, 36.90958826882498, 41.15439912251064, 43.67533758708409, 46.991514750889365, 45.89155238015311, 47.8009694644383, 46.10804435185024, 47.87489134924752, 46.90769863128662, 49.76112229483468, 49.394392899104524, 46.10872874941145, 42.05043881280081, 36.692700249808176, 36.880881786346436, 37.56520291737148, 38.314677306583945, 38.226087774549214, 39.70875692367554, 40.53023896898542, 37.4082396371024, 39.42185885565621, 39.44050782067435, 38.601287024361746, 39.009816782815115, 40.133027826036724, 45.15339313234602, 50.035638672964915, 49.91395834514073, 49.29490164348057, 48.61228976930891, 47.78408186776297, 48.01895529883248, 48.64276456832886, 46.93931293487549, 45.70215490886143, 44.547673497881206, 45.90288489205496, 38.94278403690883, 35.95202228001186, 32.83771807806832, 33.96232918330601, 34.49850082397461, 38.032486643110005, 37.67545345851353, 35.44358089991978, 34.70290640422276, 37.35806322097778, 39.5793536731175, 41.960084438323975, 48.06151301520211, 45.02288511821202, 45.771616050175254, 46.730787072862896, 45.35911192212786, 43.73459529876709, 40.41737937927246, 38.02928352355957, 37.42131267275129, 35.32535382679531, 35.683741910117014, 36.650465624673025, 35.80996635981968, 36.018370628356934, 36.45667689187186, 36.875521251133506, 37.71809802736555, 36.38429750714983, 37.16051551273891, 39.108637537275044, 40.70927667617798, 40.379796573093955, 44.22884150913784, 45.42019701004028, 51.373625482831685, 52.59565033231463, 54.72406768798828, 51.81911965778896, 56.096632208142964, 37.24250078201294, 8.49820099558149, 0.1631319506892136, 1.9803605803421565, 0.48235887395484106, 30.167931829180034, 49.45645768301827, 44.87539223262242, 50.885354723249165, 48.739730153764995, 47.863096782139365, 46.1762443951198, 52.43161725997925, 33.7498220035008, 30.078140258789062, 26.99631541115897, 43.77279302052089, 16.40605698313032, 0.4506125274513449, 0.05187705219058054, 0.0908292539949928, 0.04971631849184632, 0.0565558496995696, 0.003287086562652673, 0.03434673696756363, 0.07948450132140092, 0.022912972373887897, 0.039428703021258116, 0.09234241422797952, 0.009321709845348128, 0.019567640365234444, 0.03593362681567669, 0.06361427291163377, 0.0243873339745083, 0.03842546185478568, 0.05156862749052899, 0.042219948422695906, 0.0329146548839552, 0.07404775984053101, 0.1496545895934105, 35.594207423073904, 52.81753410611834, 34.6902745791844, 33.04774475097656, 47.20095082691738, 55.59050110408238, 59.564558029174805, 57.635811056409565, 57.976588930402485, 53.07751137869698, 54.702212129320415, 48.13655703408377, 54.67612164361136, 17.91561566080366, 1.1097895119871413, 2.301423809358052, 0.1219873106373208, 4.423763445445469, 36.81698267800467, 58.6441718510219, 53.62647812707083, 58.64898000444685, 54.25170135498047, 46.72089631216866, 41.9342371395656, 42.379196303231375, 39.39592470441546, 40.41971397399902, 40.69121135984148, 41.31639289855957, 40.36866555895124, 41.62937797818865, 39.80082402910505, 44.09116990225655, 41.32022483008248, 41.988210746220176, 39.49758032390049, 40.98063857214791, 41.841138226645334, 44.325282505580354, 47.718595096043174, 50.10495737620762, 49.89495849609375, 52.99206938062395, 50.96901103428432, 52.560103348323274, 50.453044755118235, 49.0343268258231, 44.52698176247733, 42.37812628064837, 39.02233396257673, 40.09082794189453, 39.163149629320415, 41.9440792628697, 39.27479675837925, 37.87748622894287, 36.43826763970511, 39.57995816639492, 46.1949246270316, 47.627493790217805, 48.965077604566304, 49.47775738579886, 49.25715902873448, 48.9187331199646, 51.499697072165354, 50.290286677224294, 50.56893375941685, 51.223370688302175, 48.46281664712088, 44.10096338817051, 37.17909499577114, 37.68334313801357, 37.74006475721087, 39.936220100947786, 36.8967410496303, 39.87819569451468, 42.75197063173567, 37.3332963671003, 38.024708134787424, 36.932743140629356, 38.75113187517439, 38.401286602020264, 37.2463709286281, 44.505157470703125, 49.70660672869001, 50.04373679842268, 51.483285427093506, 51.69006034306118, 48.572101388658794, 48.50972046170916, 49.84035955156599, 48.05510330200195, 48.63170303617205, 47.11788163866316, 47.177785532815115, 39.55957909992763, 37.962803159441265, 34.25482055119106, 36.094064303806846, 37.38322959627424, 39.37563943862915, 40.450602190835134, 37.32728270121983, 37.150381565093994, 38.549613271440776, 41.588324546813965, 46.01014770780291, 49.67872708184378, 47.40569339479719, 47.297117369515554, 48.930631910051616, 48.81766809735979, 46.175483567374094, 43.15380580084664, 39.23290259497506, 39.804221698216026, 37.336996282849995, 37.13278872626168, 37.92976794924055, 37.967930930001394, 37.34971843447004, 37.363750321524485, 38.076791831425254, 38.393424715314595, 39.034555843898225, 39.537886823926655, 41.39500829151699, 42.13336903708321, 40.91358150754656, 45.591807092939106, 48.306152139391216, 54.3482882635934, 53.90858541216169, 57.78259522574288, 52.56593288694109, 55.5268486567906, 39.083794253213064, 10.006417802401952, 1.1051626631191798, 4.726853856018611, 0.30684387630649973, 35.047908782958984, 52.33816051483154, 49.179318359919954, 56.945806298937114, 54.68510219029018, 51.64835030691964, 50.598873547145296, 53.26151009968349, 41.887145723615376, 34.873335293361116, 20.948850018637522, 52.4873001234872, 21.85016339165824, 0.3636033577578408, 0.018006914827440466, 0.01596219026084457, 0.057192868553102016, 0.055253880098462105, 0.03600674235661115, 0.019564756591405188, 0.07501364765422684, 0.047421628409730535, 0.17456537431904248, 0.18654493721468107, 0.1222629179911954, 0.089424774715943, 0.2490226775407791, 0.22635540100080626, 0.12687835390014307, 0.13390319980680943, 0.11395678083811488, 0.16959794158382074, 0.14516017719038896, 0.18242640607059002, 0.21977310920400278, 45.25496537344796, 61.96085275922503, 44.533481802259175, 37.992593560900005, 48.256826877593994, 64.02554471152169, 62.981779370989116, 63.84794875553676, 61.70168495178223, 59.119352204459055, 59.357473918369834, 53.81384672437395, 59.2228456224714, 22.802210773740494, 3.2105456548077718, 6.447263436658042, 0.15632689584578785, 6.1187534758022855, 44.20264680044991, 57.74923345020839, 57.76105581011091, 60.77567768096924, 58.22324650628226, 50.42911515917097, 45.69331680025373, 44.20170879364014, 41.86310495649065, 43.44215604237148, 43.60291998726981, 42.29176712036133, 43.30223321914673, 43.01423386165074, 41.00573893955776, 45.42884751728603, 44.004862853458945, 42.888947418757844, 42.16970116751534, 42.733967849186485, 43.46676656178066, 47.366258893694194, 49.30829777036394, 51.75994879858834, 52.3873815536499, 55.45270095552717, 52.03805044719151, 53.281663349696565, 53.85709578650338, 51.37579679489136, 46.394174643925254, 43.49188429968697, 42.07962819508144, 42.736507415771484, 41.87679638181414, 44.076818398066926, 40.79700810568673, 39.14639752251761, 38.38178300857544, 44.19277341025216, 48.50582947049822, 51.030530384608674, 52.64967605045864, 51.68706566946847, 53.40278434753418, 52.03282192775181, 53.74426051548549, 51.36406476157052, 53.52784497397286, 54.11619063786098, 50.07196038109915, 44.070471218654085, 36.35005678449358, 37.38864919117519, 36.81087868554251, 38.60880150113787, 36.59541852133614, 41.23906987054007, 46.02873761313302, 37.7634072303772, 38.515740803309846, 38.66908059801374, 38.53016526358468, 38.63869612557547, 37.450856413160054, 44.01323195866176, 51.001229831150596, 52.30241550718035, 52.13692331314087, 51.772542408534456, 50.43712643214634, 49.849239349365234, 51.70501634052822, 50.47988564627511, 50.83989265986851, 48.74573687144688, 50.886984075818745, 41.33584090641567, 41.176758425576345, 37.1104850087847, 39.36366769245693, 40.65260716847011, 42.090377058301655, 41.63200439725603, 40.41084459849766, 39.54743364879063, 41.72353996549334, 44.13136870520455, 47.433420181274414, 52.39509752818516, 50.36589002609253, 49.611030782972065, 51.294902392796104, 51.45272377559117, 50.11361830575125, 44.85692392076765, 40.880230154309956, 40.03141042164394, 39.21856846128191, 38.7218382699149, 40.52565663201468, 39.1366422516959, 39.157823835100444, 40.14870296205793, 40.94177729742867, 40.46335908344814, 41.09234823499407, 39.91211680003575, 45.46916443961007, 44.69531576974051, 43.132130895342144, 46.725461278642925, 49.94938720975603, 54.81596803665161, 56.1036742074149, 59.31642396109444, 55.04941013881138, 57.732092244284495, 45.47350358963013, 15.262395654405866, 2.6708790702479224, 6.1403862578528265, 0.7706657978040832, 36.85414859226772, 58.809476443699424, 52.52447646004813, 61.62327453068325, 59.09398433140346, 57.5463217326573, 57.86722428458077, 61.738454818725586, 46.88388368061611, 42.47949007579258, 37.04679782049996, 58.72414561680385, 30.95326934541975, 0.41843932813831736, 0.2132560381931918, 0.1352056206337043, 0.18433057889342308, 0.11431412452033587, 0.08048463479748794, 0.09093741247696535, 0.2664814107120037, 0.16379133744963578], [0.019112601211028438, 0.05185118304299457, 0.02187508181668818, 0.015620346014787043, 0.032617965447051187, 0.07817607545959097, 0.015095868979447653, 0.06731439222182546, 0.07255072838493756, 0.11242573442203657, 0.042865883226373365, 0.11313316146177904, 0.20941303297877312, 14.496492249625069, 55.966263157980784, 45.4041987827846, 21.606304202760967, 27.4870753628867, 47.041475772857666, 55.665479115077424, 45.755847113473074, 52.77581712177822, 50.89959505626133, 46.879242283957346, 46.006416525159565, 49.0065062386649, 31.299914973122732, 0.08241447660007648, 1.9284840268748147, 0.08158611426396029, 1.7702138338770186, 28.14529732295445, 60.497520446777344, 55.66185562951224, 58.14418990271432, 53.190739222935264, 53.09270361491612, 50.67193385532924, 49.14925003051758, 45.955857958112446, 45.23884555271694, 40.93497501100813, 41.58116095406668, 41.67142500196184, 43.85466364451817, 44.87672976085118, 48.503380230494905, 45.98265716007778, 47.95887769971575, 44.49769857951573, 43.365496567317415, 40.80727754320417, 43.41467939104353, 41.810517515454976, 45.22392429624285, 47.943525654929026, 51.43309511457171, 46.5394857951573, 48.833166054316926, 46.81525979723249, 51.225239753723145, 43.157780170440674, 40.629945618765696, 37.91249472754342, 35.95916155406407, 37.088553019932334, 36.08962440490723, 35.433971541268484, 37.75916535513741, 33.950774329049246, 40.6177202633449, 41.86354269300188, 46.873614243098665, 45.74379893711635, 47.71442270278931, 46.94415235519409, 46.36420011520386, 45.31193365369524, 47.809307302747456, 46.747344630105154, 47.574979305267334, 45.29345144544329, 41.475458008902415, 38.03577314104353, 39.00710003716605, 36.79801409585135, 39.050352573394775, 38.46541847501482, 41.31221355710711, 42.242379324776785, 36.59889956883022, 36.91046026774815, 40.342324938092915, 39.24748338971819, 39.139088017599924, 39.50717231205532, 41.40876919882638, 47.99638407570975, 48.259494985852925, 50.705420698438374, 49.87538194656372, 49.73014027731759, 48.09507628849575, 49.39865214484078, 46.98611600058419, 46.00103514535086, 44.881360735212056, 45.49195105688912, 44.2536952154977, 37.975031988961355, 32.59453112738473, 32.72501482282366, 36.065757342747276, 35.28836161749703, 34.95335422243391, 33.37328175136021, 34.91533020564488, 35.7711433001927, 39.544901030404226, 40.86263731547764, 47.19993986402239, 46.213170596531455, 43.822556018829346, 46.4386431149074, 46.435766560690745, 43.401290212358745, 42.6767702783857, 38.465456690107075, 37.6245196887425, 36.4372809955052, 38.38034125736782, 35.87773561477661, 37.20177739007132, 37.49869476045881, 39.828429222106934, 39.23759610312325, 41.77906649453299, 38.32736471721104, 40.925685269492014, 37.631929942539756, 43.49887766156878, 40.651099409375874, 43.14259835651943, 44.172165053231375, 51.459737982068745, 49.75706107275826, 55.981288637433735, 49.04399177006313, 50.04804468154907, 15.61677462714059, 12.924284270831517, 1.1270101879324232, 3.883547518934522, 0.6827821050371442, 38.08388941628592, 54.02096210207258, 46.5018196105957, 45.14015333993094, 49.88074248177664, 55.90213475908552, 50.99531691414969, 45.49636663709368, 30.30770526613508, 18.56098345347813, 33.9762533732823, 44.703931535993306, 3.911403715610504, 0.17369940078684262, 0.07596653473696538, 0.07252383125679833, 0.03834287057231579, 0.08953574233289276, 0.024203552764707377, 0.07406329829245806, 0.020132223909188594, 0.07461413302059684, 0.1377340049615928, 0.01820407505147159, 0.009559370976473604, 0.03483830166182347, 0.039918106581483564, 0.06533729724053826, 0.0696541370291795, 0.05405946847583566, 0.03459120974210756, 0.0964160534952368, 0.0430661256957267, 0.1885398437402078, 0.14304686630410807, 18.815238884517125, 64.61799676077706, 42.801111766270225, 26.988182544708252, 40.4172716821943, 50.72267654963902, 61.73214585440499, 51.21834019252232, 59.72625650678362, 54.07606479099819, 52.61546312059675, 51.546434129987446, 55.311162676130024, 35.339747020176475, 0.16378548847777502, 2.7906495119844164, 1.6559773066214152, 2.170425512960979, 32.99073130743844, 59.0284697668893, 58.66758728027344, 57.59923921312605, 53.96065868650164, 55.138458251953125, 50.355492046901155, 50.824804646628245, 48.15369476590838, 45.87399775641305, 43.302195004054475, 43.62134313583374, 42.61298928941999, 45.25756399972098, 46.90658344541277, 50.60770123345511, 49.167443888528005, 51.320708002362935, 46.01839869362967, 45.73596831730434, 42.621035303388325, 43.2967962537493, 43.67163419723511, 47.17367914744786, 50.3130316053118, 52.68648413249424, 47.576139654432026, 49.99547808510916, 49.162468978336875, 51.857737745557515, 45.67616517203194, 43.37094395501273, 40.36687292371477, 38.54960284914289, 40.18118231637137, 38.90542704718453, 36.81384209224156, 37.51007243565151, 37.37639604296003, 42.352021898542134, 46.043082169124055, 48.43393645967756, 49.48032474517822, 50.80438389096941, 49.28054666519165, 50.49725614275251, 48.52849102020264, 50.049403054373606, 48.947411809648784, 50.72684894289289, 47.956428459712434, 41.73302425657, 38.20765767778669, 38.90793187277657, 37.96579783303397, 39.903883184705464, 37.657242230006624, 42.75748750141689, 44.98713663646153, 37.1361586025783, 37.08869545800345, 40.96190970284598, 37.56558854239327, 39.147293840135845, 39.47863606044224, 41.76733446121216, 49.13560029438564, 50.11086334500994, 49.63861860547747, 50.40940311976841, 49.53440604891096, 50.784828186035156, 49.47046872547695, 48.290150438036235, 47.734336239951, 46.07524190630232, 47.90590810775757, 45.833871909550254, 39.032634666987825, 35.6545455796378, 34.15416199820382, 38.34320313589913, 37.2799585206168, 37.42770848955427, 35.62704113551548, 36.79085397720337, 38.29671621322632, 41.35230466297695, 44.98173441205706, 50.506323541913716, 48.28210094996861, 47.48863404137747, 48.13606718608311, 47.56814227785383, 46.248766217912944, 45.06276430402483, 41.58040360042027, 40.03437382834298, 39.13621841158186, 40.484766483306885, 37.0684414591108, 39.792104039873394, 38.95755590711321, 42.39172737939017, 41.306835651397705, 44.26363113948277, 39.9407503264291, 41.9310861315046, 40.58984061649868, 46.09406110218593, 42.53390836715698, 43.392757824489046, 46.65741409574236, 54.658615657261436, 52.61000531060355, 57.81788512638637, 50.54306214196341, 50.79955836704799, 19.118043116160802, 14.74630778176444, 3.1616322909082686, 4.397496649197169, 0.706567797277655, 43.771952288491384, 56.31867926461356, 51.55625888279506, 49.388330595833914, 54.88930974687849, 58.57603086744036, 57.9429110118321, 48.80768701008388, 44.299928528921946, 21.817967176437378, 32.25471557889666, 56.55827052252633, 5.699302451951163, 0.18298203125596046, 0.2111520639487675, 0.027854693720915487, 0.024183508840256503, 0.05629260525373476, 0.01843190166567053, 0.04650914130200233, 0.021434924631778682, 0.009556533003758107, 0.23315315480743135, 0.16383875347673893, 0.1197029682142394, 0.10027725701885563, 0.24430650632296289, 0.14686589209096773, 0.14558405801653862, 0.14901964366436005, 0.1065889558355723, 0.3315482778208596, 0.11224886748407568, 0.4269667219902788, 0.4408237912825176, 25.323824950626918, 74.93017264774868, 54.04726798193795, 31.34945215497698, 38.3217887878418, 59.87270368848528, 66.95561395372663, 58.16785546711513, 61.26149572644915, 62.87579154968262, 56.11344337463379, 55.82009390422276, 59.409071241106304, 40.62761102403913, 0.21135433523782662, 6.508058871541705, 0.9810807555913925, 2.9813499876431058, 36.77824647086007, 58.653607504708425, 61.082649094717844, 62.24857766287667, 56.63625015531267, 56.96212414332798, 54.26350287028721, 53.501865659441265, 49.282634598868235, 47.54794386454991, 45.7632017816816, 44.865796770368306, 44.81548833847046, 47.92246913909912, 49.877306597573416, 52.753930296216694, 52.476488726479666, 54.04627786363874, 48.335692405700684, 47.387888635907856, 45.55771575655256, 46.44455255780901, 44.7668822152274, 50.66898781912667, 53.782875129154746, 54.760531834193635, 49.659779344286235, 52.170833996364046, 49.59438984734671, 55.65437241962978, 49.195851598467144, 46.04613937650408, 43.02687610898699, 40.364027636391775, 42.73950208936419, 41.32833685193743, 39.85210173470633, 39.661418846675325, 40.378948892865864, 44.89267587661743, 48.61892877306257, 53.474013805389404, 53.871687003544395, 54.114092281886506, 52.88455295562744, 52.84422908510481, 50.50313431876046, 52.71190064293997, 52.93997526168823, 54.445041928972515, 49.727524280548096, 41.52495697566441, 38.165805203574045, 39.50265598297119, 37.66531951086861, 40.564285142081125, 37.858667033059255, 43.616663524082725, 46.66837140492031, 37.303790841783794, 36.21321548734392, 42.13872609819685, 37.287420885903494, 38.49585853304182, 39.68437222072056, 41.62533412660871, 50.63535853794643, 51.3503212247576, 52.735329968588694, 53.08023507254464, 52.47583906991141, 51.077489784785676, 52.26269612993513, 50.06180558885847, 49.41687726974487, 49.23742961883545, 50.59091091156006, 47.527516160692485, 42.25140503474644, 36.840207031794954, 37.958001954214915, 40.67181198937552, 38.73040887287685, 38.17454603740147, 36.57474763052804, 38.8345901625497, 39.96104254041399, 42.671500069754465, 46.79559292112078, 51.48339312417166, 50.896534374782014, 49.604655810764854, 52.08795935767037, 50.9782521384103, 49.09842395782471, 47.262129715510774, 44.44742488861084, 41.68812152317592, 41.694270678928916, 42.88233968189785, 40.13438272476196, 41.01464653015137, 41.128308636801584, 44.43368135179792, 44.058346612112864, 46.06278378622872, 42.205369744982036, 43.74758843013218, 41.17791877474104, 47.78645120348249, 45.28869192940848, 44.70756891795567, 48.581029823848176, 54.84647062846592, 55.243521962847026, 58.97781045096261, 53.86598948069981, 50.69057934624808, 25.640793085098267, 16.15647942679269, 4.792924276420048, 7.564348340034485, 0.41921041533350945, 50.81088045665196, 61.4516053880964, 54.81860835211617, 53.753334862845286, 58.60370554242815, 66.13401726314, 60.34229074205671, 57.84042855671474, 42.824780804770334, 26.093770469938004, 43.696269035339355, 63.37335205078125, 8.768705657550267, 0.5343901876892362, 0.2879671406533037, 0.12183799222111702, 0.10708076480243887, 0.21636182868054935, 0.10807815699705056, 0.24799556551235064, 0.17100207481001103, 0.17258008942008018], [0.012615886250776904, 0.01943331926928035, 0.028117286773132424, 0.06251968736095087, 0.019046282894643288, 0.04808383448315518, 0.007044824946206063, 0.0373631542149399, 0.017531528104362742, 0.0358991300953286, 0.008385833635527109, 0.027487591008788774, 0.06435413392526762, 4.014216210160937, 45.266006061008994, 39.2421749659947, 33.292286600385395, 28.890274490628922, 38.87066173553467, 56.19609914507185, 53.538989884512766, 37.06583935873849, 52.502058097294395, 46.022862911224365, 49.65356765474592, 46.65797689982823, 39.08641372408186, 2.4566641535077776, 1.9584173006670815, 2.482091303382601, 0.791002903665815, 19.89718805040632, 57.20851073946272, 52.24105943952288, 55.34044585909162, 52.89223418916975, 53.491516317640034, 50.11169712884085, 52.29963622774397, 50.56062718800136, 50.121448925563264, 47.992840494428364, 48.759744439806255, 46.99926546641758, 48.90101521355765, 50.197417054857524, 52.514655181339805, 52.1117708342416, 53.76810673304966, 50.82939740589687, 50.42961890356881, 45.9255325453622, 45.03351238795689, 45.43761961800711, 45.66872712544033, 45.72943006243025, 50.701706886291504, 48.028144291469026, 50.92470237186977, 51.07662125996181, 49.48912116459438, 45.737291949135916, 41.74323810849871, 38.24751254490444, 36.91614736829485, 36.71763386045183, 35.844561440604075, 34.90458481652396, 34.9861740384783, 37.05071660450527, 43.12797934668404, 43.44297245570591, 46.938770975385395, 45.702151434762136, 47.26720884868077, 45.81050164358956, 46.54783405576433, 46.654693875994, 47.57865490232195, 46.56944990158081, 47.432468278067454, 43.495865617479595, 39.75736999511719, 38.58937086377825, 37.941322803497314, 37.270203249795095, 41.179263251168386, 38.484397479466026, 44.64719254629952, 43.62591505050659, 38.86989743368966, 38.22886010578701, 36.76219613211495, 37.58975437709263, 39.299768584115164, 40.38192272186279, 39.10243974413191, 47.59109912599836, 49.752777508326936, 49.579319204602925, 49.04795571735927, 48.20543105261666, 50.2324081829616, 47.28224127633231, 47.269136973789756, 46.83750098092215, 45.539403779166086, 46.13242905480521, 44.50457729612078, 40.690863949911936, 34.064533710479736, 32.6290636743818, 33.0985951423645, 33.1655410357884, 34.629328455243794, 34.385665552956716, 35.57152502877371, 36.49276236125401, 39.60050398962838, 40.4590095111302, 46.40749086652483, 45.91727808543614, 44.65580136435372, 48.63418006896973, 47.195784841264995, 45.412772859845845, 42.50846406391689, 40.3449444089617, 35.54435409818377, 35.52928692953927, 36.54813602992466, 37.468463148389546, 37.11738804408482, 42.78798661913191, 45.00282914297921, 47.199651513780864, 45.76318441118513, 43.99842882156372, 43.411681243351524, 44.1948161806379, 43.19980634961809, 45.63855804715838, 45.4110358101981, 47.53201164518084, 48.67721373694283, 52.419617721012656, 53.245494501931326, 50.990571294512065, 41.47011137008667, 13.862204228128705, 6.5737831848008295, 4.176242990153177, 3.338328238044466, 3.779379257134029, 54.03020320619856, 44.761796133858816, 48.78240598951067, 49.931631088256836, 51.25595079149519, 50.11518859863281, 46.69613293239048, 42.209913866860525, 25.375965969903127, 28.944244623184204, 37.03227955954415, 29.055789266313823, 0.454928851553372, 0.23762423917651176, 0.06480578718973057, 0.04039182919742806, 0.047269348188170364, 0.05613316648772784, 0.02852495400501149, 0.04320636870605605, 0.05159524641931057, 0.08853192441165447, 0.07772968762687274, 0.020452027641502873, 0.06641481763550214, 0.056459005789033005, 0.035191916794117005, 0.05375967134854623, 0.12939466030469962, 0.054282262056533775, 0.07899557612836361, 0.09493944594370467, 0.053150343509124856, 0.06343436613678932, 0.11318606683718306, 7.219070204666682, 56.21231624058315, 41.659779821123394, 24.10793709754944, 43.191121101379395, 44.75249597004482, 61.677414894104004, 57.631590025765554, 42.49306338174002, 58.235471861703054, 49.244808605739046, 55.40805530548096, 49.41411883490426, 45.518083231789724, 2.7737406364509036, 2.0563630163669586, 2.748796820640564, 0.910374746790954, 23.41293137414115, 55.20623098100935, 51.83500323976789, 58.56105749947684, 55.62659352166312, 55.63299976076399, 52.84889827455793, 54.63561364582607, 52.20643309184483, 50.83222532272339, 50.55151115145002, 49.01558058602469, 48.853572913578574, 50.188679695129395, 51.330046381269185, 54.21805122920445, 53.557072571345735, 55.41012586866106, 53.23256737845284, 52.19191483088902, 47.39186300550188, 46.50109352384295, 46.59032923834664, 49.23648813792637, 48.16967909676688, 51.67462491989136, 49.59581422805786, 51.57091958182198, 53.6571683202471, 50.432120255061555, 48.56739745821272, 43.50332798276629, 40.34805025373186, 39.55883911677769, 37.16394444874355, 39.4777501651219, 38.707514558519634, 37.49345929282052, 40.405748094831196, 44.83056245531355, 47.55785199574062, 49.440733909606934, 49.118247168404714, 50.04162107195173, 47.6433287348066, 49.45512710298811, 50.43246766499111, 50.10235180173601, 49.410825388772146, 49.89610842296055, 45.38751268386841, 39.85491575513567, 39.12597329275948, 39.51201868057251, 37.523069041115896, 39.152174949645996, 38.701855250767295, 46.19557428359985, 46.96777623040335, 38.2798216683524, 36.99876839773995, 36.17137690952846, 38.62906244822911, 39.29555450166975, 39.40238652910505, 38.65099443708147, 47.766565459115164, 50.91214002881731, 51.34510312761579, 51.1236640385219, 49.596185956682476, 50.802834442683626, 48.2984048979623, 48.22711985451834, 47.31364713396345, 46.456149101257324, 48.12322344098772, 48.40608460562569, 42.09782900129046, 35.545417172568186, 34.28862006323678, 35.38304124559675, 37.10528775623867, 36.60247094290597, 35.619102818625315, 37.64914410454886, 38.48411955152239, 41.0067776952471, 42.49380683898926, 47.808945996420725, 48.07714646203177, 48.39073256083897, 48.59706279209682, 49.487898281642366, 48.36407579694475, 46.584350313459126, 42.47302825110299, 37.91288035256522, 38.568467208317344, 38.07221644265311, 37.54186044420515, 39.48702948434012, 44.885981287275044, 47.87184109006609, 49.82722398212978, 48.020668029785156, 46.778309277125764, 45.46590573447091, 45.52664688655308, 44.26692458561489, 48.34054919651577, 47.07185329709734, 49.70018311909267, 48.60168334415981, 54.43004771641323, 54.17509051731655, 52.68659182957241, 41.10012674331665, 17.059238025120326, 6.598139226436615, 5.788892958845411, 2.7697723465306416, 3.7826262371880666, 57.72437626974923, 48.76413222721645, 54.29280342374529, 52.43944787979126, 57.278670174734934, 53.886205264500205, 52.750209535871235, 46.04303353173392, 34.316537925175254, 20.55242054803031, 41.82805129459926, 36.96283231462751, 0.7280711148466382, 0.24457194922225817, 0.02901217946782708, 0.05358198338321277, 0.020291862843026007, 0.029576479723410945, 0.029034340421536138, 0.058068395858364444, 0.045222944247403314, 0.05963220873049327, 0.25435012738619533, 0.16872020225439752, 0.15436753098453793, 0.11487661648009505, 0.18229455314576626, 0.14720252688441957, 0.2541160328047616, 0.0831407465572868, 0.22019200958311558, 0.22025735250541142, 0.1550071859466178, 0.21029675698706082, 0.2991676910647324, 8.977322714669363, 67.5897274017334, 50.54119307654244, 43.231312956128804, 42.99039806638445, 51.65366915294102, 67.22252900259835, 63.630379813058035, 46.16177824565342, 62.04320975712368, 54.23048503058297, 61.56780011313302, 54.99680185317993, 50.45516742978777, 3.213545539549419, 5.72875543151583, 5.781550884246826, 1.4005080035754611, 29.66381570271083, 55.31513009752546, 53.23463099343436, 59.723157610212056, 57.15545776912144, 57.73775850023542, 55.98967858723232, 56.985880034310476, 53.28781597954886, 53.04718944004604, 51.408196244921, 51.841041224343435, 50.48018789291382, 52.697754110608784, 55.23618813923427, 56.38646241596767, 57.097363880702424, 58.932737486703054, 54.88095453807286, 54.850820200783865, 50.67466797147478, 48.721869809286936, 49.976707526615684, 51.15197447368077, 48.631477219717844, 55.586297443934846, 51.835037980760845, 53.9799781526838, 55.10991505214146, 52.77980538776943, 51.627981662750244, 47.28966195242745, 41.739718845912385, 42.49752759933472, 40.45961400440761, 41.83446448189871, 41.49919305528913, 39.6545227595738, 43.51691518511091, 47.48378767286028, 50.13844769341605, 52.70524079459054, 50.719098227364675, 54.29182720184326, 50.8398231778826, 50.74792282921927, 52.995071002415244, 51.951618330819265, 51.3769154548645, 50.998127460479736, 45.25158160073416, 39.90876082011631, 39.5226320539202, 38.66566208430699, 37.667157309395925, 41.18524217605591, 39.30557727813721, 48.16367237908499, 48.12677049636841, 39.728340421404155, 37.4448253767831, 35.72254065104893, 37.637804644448416, 39.266240051814485, 40.20723806108747, 37.13403245380947, 49.60641023090908, 53.890818868364605, 52.856704575674875, 51.951524530138286, 51.09072262900216, 52.43146787370954, 51.53262805938721, 51.12745428085327, 51.796030793871196, 48.375894682747976, 52.16680056708199, 49.37984684535435, 45.76914596557617, 38.305818353380474, 36.99645117350987, 38.44810356412615, 39.45031520298549, 38.06276689256941, 36.47867488861084, 39.88492502485003, 40.22645330429077, 44.55633442742484, 45.38841594968523, 51.2338034084865, 49.45960521697998, 49.247841494424, 52.08511059624808, 53.61465229306902, 50.494754791259766, 49.834095750536235, 46.026430811200825, 39.85371371677944, 41.21274314607893, 40.86101838520595, 41.06865835189819, 41.029196058000835, 46.55844395501273, 49.22034747259957, 51.53665106637137, 50.648129326956614, 47.62298093523298, 46.936488492148264, 48.783753940037315, 46.30861452647618, 50.49407386779785, 47.97824927738735, 50.57889747619629, 50.61254412787301, 56.707503931862966, 54.781498023441856, 54.02326542990548, 42.009520871298655, 24.937138591493877, 7.84466472693852, 8.128939849989754, 7.696358033588954, 3.649576050894601, 66.26935427529472, 52.04974773951939, 61.05015236990792, 58.31347928728376, 61.503320830208914, 58.34740039280483, 57.8744295665196, 51.664296422685894, 36.79472064971924, 38.39657572337559, 49.04905700683594, 46.78084189551217, 1.3328583879130227, 0.4869174893413271, 0.15242359600961208, 0.14772626092391355, 0.1229106882320983, 0.13044284763080732, 0.06888391157346112, 0.11728936487010547, 0.1357834203434842, 0.1821202239287751], [0.09857638007295982, 0.029626467398234775, 0.047553634004933495, 0.18904030402856214, 0.08853284721927983, 0.06238425855657884, 0.0317869975364634, 0.007541094856735851, 0.039704283233731985, 0.039884396961757114, 0.06546368117311172, 0.03357613831758499, 0.03749800626454609, 0.1449705809354782, 36.11450590406145, 56.42593513216291, 32.44799361910139, 19.675227846418107, 40.060373987470356, 46.65705973761422, 60.537729672023225, 51.387817178453716, 50.717837129320415, 49.293310506003245, 50.649525914873394, 45.43358618872506, 42.25785296303885, 11.035006540162222, 2.0846397961888994, 3.1583809682301114, 0.41783974745443886, 12.445496933800833, 47.296380860464915, 46.46364273343767, 51.60310016359602, 55.742847306387766, 53.76911769594465, 52.64659105028425, 53.19739212308611, 53.90687615530831, 56.17977435248238, 51.21932683672224, 50.38144356863839, 51.921775817871094, 52.231564726148335, 52.918592180524556, 49.86163146155221, 50.33016586303711, 52.18563365936279, 51.67891890662057, 49.20817075456892, 50.89556162697928, 49.04565586362566, 48.39161845615932, 44.428136689322336, 49.37624767848423, 48.29440968377249, 49.10189110892159, 44.782703263419016, 44.591579164777485, 48.83432640348162, 47.23130055836269, 43.062072208949495, 39.36047152110508, 36.446212904793875, 37.4251446042742, 34.72296585355486, 33.97465876170567, 34.2109044619969, 36.23502240862165, 45.248875277382986, 43.937729358673096, 43.719389166150776, 45.9176150730678, 46.77931676592146, 47.01642056873867, 46.947164399283274, 45.95484699521746, 48.24935756410871, 48.85160309927804, 41.94616024834769, 38.040803636823384, 38.41826452527727, 37.96619735445295, 38.50621829714094, 39.4062670980181, 38.61720534733364, 38.789013453892295, 45.23268597466605, 47.15421724319458, 43.26116589137486, 38.62347262246268, 38.16455800192696, 38.01592908586775, 38.882407665252686, 40.232428755079, 39.827873366219656, 42.27735308238438, 48.25261626924787, 49.46898528507778, 48.61070558003017, 48.549551010131836, 50.052866731371196, 47.588229519980295, 46.44491386413574, 48.32030214582171, 45.6912636075701, 45.72714410509382, 45.33115931919643, 46.0236827986581, 38.36447504588536, 34.118410042354036, 31.384641306740896, 32.4092435155596, 34.82111610685076, 33.719131810324534, 35.1106892313276, 36.711880752018516, 39.60710825238909, 40.74577556337629, 44.74248014177595, 45.838176318577354, 46.434265749795095, 46.4127402305603, 46.35781819479806, 45.15679080145699, 44.10379130499703, 40.21159110750471, 39.47047192709786, 36.977541651044575, 36.37504250662667, 36.40402691704886, 39.45542212894985, 46.255429540361675, 49.03816223144531, 48.08587687356131, 45.74543176378523, 49.00162165505545, 47.395979813167024, 46.66863543646676, 45.517235551561626, 48.670039721897666, 48.51048823765346, 51.33624070031302, 48.751778330121724, 55.323210852486746, 47.50216218403408, 55.456699643816265, 35.33180175508772, 3.5071377626487186, 0.3516573959163257, 1.0739547205822808, 0.8453936193670545, 8.765456506184169, 51.76872437340872, 44.39409746442522, 51.274582386016846, 47.491517543792725, 51.86108330317906, 49.635332107543945, 49.26539959226336, 33.94162007740566, 28.9110061781747, 38.452515670231406, 46.42706046785627, 12.831874098096575, 0.43307975253888537, 0.1385752662484135, 0.006251054749424968, 0.023009673792070577, 0.032764681681458435, 0.047663556677954536, 0.07372171697872025, 0.04009488870256713, 0.09237558101969105, 0.034860462615532536, 0.050159730948507786, 0.034570768874670775, 0.03805037787450211, 0.06427895224520139, 0.06075243611953088, 0.06883496884256601, 0.04413280649376767, 0.00968476933693247, 0.04585316418004887, 0.08719651999750308, 0.030191849917173386, 0.031645821540483406, 0.037064005088593276, 0.5620525404810905, 42.96554783412388, 62.47715950012207, 29.574371542249406, 28.394362449645996, 49.57705756596157, 51.7605220249721, 66.77000672476632, 50.09740468433925, 58.406668526785715, 51.922651290893555, 56.223853724343435, 49.37706756591797, 47.66266557148525, 11.88167233126504, 1.657067522406578, 1.452131164925439, 0.18076837861112185, 15.767274345670428, 49.42760181427002, 45.49045719419207, 51.01830850328718, 55.83569608415876, 54.951836585998535, 54.39460495540074, 54.57721751076834, 56.37650564738682, 56.862361907958984, 53.90142181941441, 52.02259070532662, 52.90269470214844, 53.36306149618966, 53.44449438367571, 52.94408859525408, 51.17579984664917, 54.649242537362234, 55.36957270758492, 51.875924655369346, 53.86456509998867, 50.38880865914481, 50.909972190856934, 46.46690838677542, 49.499046666281565, 51.66046796526228, 50.797442640577046, 46.49168913705008, 46.47669839859009, 51.37693282536098, 49.21781485421317, 45.03348459516253, 41.297233240945, 38.24629661015102, 39.46271078927176, 37.211935656411306, 35.55517939158848, 36.42839772360665, 39.67335932595389, 47.1699583871024, 46.249798025403706, 47.98204299381801, 49.095873968941824, 48.1599759374346, 49.2140211377825, 50.44647523335048, 48.924611295972554, 50.934085914066856, 50.15690558297293, 46.24547624588013, 39.68325356074742, 38.15514666693551, 37.890833718436106, 38.68995646068028, 39.625274317605154, 38.47329773221697, 40.80081919261387, 49.09362275259835, 49.08663633891514, 42.12644168308803, 38.55490779876709, 37.991384574345176, 37.827042307172505, 38.64432764053345, 38.817278725760325, 38.744621413094656, 42.4260619027274, 49.695673738207134, 53.92723090308053, 49.620410851069856, 49.10550764628819, 51.65052509307861, 50.497805050441194, 49.101258822849815, 48.52125794546944, 45.754731927599224, 47.96793467657906, 47.33586399895804, 46.25606530053275, 39.73018169403076, 34.84639712742397, 35.571021284375874, 34.646348067692344, 37.77898856571743, 36.66579335076468, 37.20572049277169, 39.49032640457153, 40.98848308835711, 41.756835733141216, 48.327656814030235, 48.87088087626866, 47.37284926005772, 47.59759569168091, 47.97011293683733, 48.56776223863874, 45.07789748055594, 42.90210035869053, 41.59952851704189, 37.991325514657156, 38.775457518441335, 38.28963599886213, 40.47703313827515, 47.50045987537929, 52.44229664121355, 50.62156636374337, 47.39416633333479, 50.91758394241333, 48.90194974626814, 49.07409136635916, 49.198589188711985, 49.550984450748985, 50.37781660897391, 52.36639451980591, 51.259643759046284, 58.86966173989432, 49.066795757838655, 53.75525951385498, 36.60412114007132, 4.926854712622506, 0.44218430827770916, 1.463747467313494, 0.5550994564379964, 10.11259583064488, 57.11050987243652, 48.19519983019148, 54.85473551068987, 54.923751967293875, 56.32030166898455, 57.253486428942, 53.57031583786011, 44.00398390633719, 38.14722919464111, 34.19346795763288, 54.410217557634624, 14.662778275353567, 0.363615734236581, 0.07444855690534626, 0.019535759397383248, 0.02088646138353007, 0.03199850707980139, 0.028423189019252146, 0.04093225519838078, 0.0634338233087744, 0.05782378398414169, 0.006037677538448146, 0.1798393013221877, 0.10074619257024356, 0.10746859506304775, 0.310247109404632, 0.20289835041122778, 0.20406036877206393, 0.0674653323367238, 0.08654252759047917, 0.09388469718396664, 0.16792793119592325, 0.23457530992371695, 0.10420890604811055, 0.13617246518177645, 0.6981501089675086, 52.410442624773296, 70.64658737182617, 42.697910172598704, 28.50502119745527, 52.412183148520334, 58.46411623273577, 71.02952344076974, 62.091228757585796, 62.875576155526296, 57.86439636775425, 60.11527224949428, 54.87841149738857, 54.16217381613595, 14.655824865613665, 5.142342669623239, 7.629397375243051, 0.6253127402492932, 21.09811990601676, 52.112420490809846, 47.146383149283274, 53.333931173597065, 57.52240603310721, 58.191190992082866, 55.47786733082363, 55.66871002742222, 59.63764613015311, 59.79307038443429, 56.194851943424766, 55.70278746741158, 56.600338390895296, 56.79361295700073, 57.36852427891323, 54.10168627330235, 53.615058762686594, 57.33004168101719, 56.56561476843697, 53.19487687519619, 56.2655394417899, 53.66524907520839, 53.972609588078086, 47.934579849243164, 52.076070989881245, 52.64685855593, 51.60584470203945, 49.12755428041731, 48.76560524531773, 53.0366872378758, 52.94480773380825, 47.39122029713222, 43.453231470925466, 41.61830254963466, 42.5218289239066, 39.66851643153599, 37.33320256641933, 38.525020122528076, 44.26979766573225, 50.940485204969136, 48.44584219796317, 49.601185185568674, 51.87436131068638, 52.26643773487636, 54.042602266584126, 54.98130737032209, 50.80570404870169, 53.99583741596767, 52.883767809186665, 44.850316183907644, 38.44939592906407, 38.956899302346365, 36.82095009940011, 38.64750991548811, 40.02246461595808, 38.43540573120117, 39.98602131434849, 51.622357095990864, 48.59858792168753, 44.465187958308626, 38.238538946424214, 37.87668718610491, 37.26133387429373, 38.87726947239467, 39.069550446101594, 39.55799491064889, 42.48699760437012, 50.113090242658345, 53.95744514465332, 50.373216901506694, 50.94198254176548, 53.80014835085188, 52.23203372955322, 49.726193700517925, 51.84000594275338, 48.92285687582833, 51.17321859087263, 50.525865350450786, 50.25044570650373, 41.649149077279226, 36.18729523250035, 35.40425409589495, 36.38014248439244, 38.4732004574367, 38.651682308741975, 39.02084009987967, 41.69330835342407, 44.77599130358015, 43.2003378868103, 49.6900908606393, 52.08559349605015, 51.677984373910085, 48.93507528305054, 50.16116830280849, 49.00890336717878, 47.30352013451712, 45.03956426892962, 44.324177742004395, 40.40501158578055, 41.786935329437256, 40.303178787231445, 42.47408785138811, 51.069197109767366, 53.9523104258946, 52.45437608446394, 48.940338543483186, 51.97307089396885, 50.874720505305696, 50.20322574887957, 50.37903601782662, 52.72559206826346, 52.58619383403233, 55.151354108537944, 53.87748874936785, 59.41706166948591, 50.7110070501055, 53.877975123269216, 40.733532837459016, 8.231390169688634, 0.933384086404528, 5.038936972618103, 1.4309004013027464, 10.162014893123082, 64.13940484183175, 51.536949838910786, 59.74050726209368, 58.25939450945173, 63.25762980324881, 59.92678151811872, 60.47944818224226, 45.607239042009624, 42.667855739593506, 48.19763169969831, 60.76922280447823, 21.631684235164098, 0.49651951981442316, 0.27026891176189693, 0.08152970764786005, 0.097625847506736, 0.11595261017126696, 0.12027546178017344, 0.18101949085082325, 0.17923366810594285, 0.13013080294643128, 0.12081999970333916], [0.004319342310606901, 0.01815915433689952, 0.04901888966560364, 0.07565546035766602, 0.07757258641400508, 0.040353495361549516, 0.05951008599783693, 0.04570531818483557, 0.034817915077188184, 0.1253104494618518, 0.13280162534543447, 0.0685041898063251, 0.114840993391616, 0.12352255039981433, 14.525207417351858, 56.12820829663958, 36.53876291002546, 29.653622695377894, 29.429275785173687, 46.52386277062552, 56.38560083934239, 54.2728898865836, 50.93584380831037, 49.49718107495989, 50.511579854147776, 43.86662149429321, 50.12107024874006, 18.541455541338237, 0.5485119670629501, 1.5068745017051697, 0.06769876873918942, 3.226695873907634, 36.05617925098964, 59.52239636012486, 55.49674906049456, 56.89014080592564, 52.82423216956002, 54.88025277001517, 51.658414772578645, 52.222483430589946, 52.16135665348598, 51.873968737465994, 51.61181320462908, 51.752451692308696, 52.219464438302175, 50.277467250823975, 51.101516655513215, 47.77011251449585, 51.41761800221035, 50.661799907684326, 49.356577328273225, 50.33297988346645, 50.58641195297241, 49.044356550489155, 48.03560318265642, 47.59146390642439, 51.046625886644634, 50.00222826004028, 46.17312465395246, 47.038140637534006, 50.32818910053798, 48.28552641187395, 44.501599993024556, 40.514866079602925, 36.91296509334019, 35.73431089946202, 35.44097532544817, 33.55957685198103, 33.89903804234096, 35.09744943891253, 44.49392223358154, 44.69745928900582, 45.94626249585833, 45.94462619509016, 46.06221750804356, 46.467700481414795, 46.54720524379185, 49.15528106689453, 46.8493789264134, 39.73958608082363, 38.81300558362688, 38.54517337254116, 39.18938602719988, 40.08995941707066, 40.370468616485596, 37.20353181021554, 40.5230302129473, 43.87612315586635, 50.398094926561626, 49.60911308016096, 42.59711960383824, 41.013771057128906, 35.43781736918858, 39.00332716533116, 40.51554700306484, 40.99131447928292, 38.45899486541748, 39.170215947287424, 42.504951749529155, 48.301274503980366, 48.7202821459089, 49.749449321201865, 48.465839113507954, 48.389870984213694, 46.485682419368196, 46.591395786830354, 44.36794444492885, 46.31104987008231, 45.36742196764265, 44.07796137673514, 39.95763444900513, 34.88651255198887, 32.50426013129098, 34.685813835689, 31.751867498670304, 36.01721722739083, 33.664783000946045, 38.8954633304051, 38.55234738758632, 41.10161713191441, 44.58569751467024, 45.93079233169556, 46.40824474607195, 44.758579117911204, 45.83922897066389, 44.59697444098336, 42.82640668324062, 40.4197348185948, 38.26517833982195, 35.7896637235369, 37.117391518184114, 35.73637451444353, 37.794205120631624, 44.62896047319685, 50.53593329020909, 49.45575244086129, 48.52070556368147, 50.58194773537772, 49.208347933632986, 50.21305397578648, 49.30021006720406, 49.678473472595215, 50.28201137270246, 51.55602611814226, 52.12009130205427, 50.87794099535261, 47.523312500544954, 49.553892271859304, 26.4025171484266, 0.6745763910668237, 0.2549871632031032, 0.7156659747873033, 0.7356594705155918, 10.24707213469914, 52.14102275030953, 43.567675249917166, 52.30434363228934, 45.35216719763619, 54.64280155726841, 44.85898406164986, 43.42689779826573, 25.79996762956892, 22.824768100466045, 34.06303289958409, 39.57378469194685, 2.481031051703862, 0.48150728536503656, 0.009847292892767914, 0.04827138834765979, 0.08638278687638895, 0.013500225181425256, 0.08177933389587061, 0.08388485520013741, 0.04520433881719198, 0.0723513001576066, 0.050790005163954835, 0.016036313426281725, 0.01893352733791939, 0.006191301683429629, 0.10589030903897115, 0.05685078512345042, 0.020042937182422196, 0.024635713414422104, 0.04425871545182807, 0.07433284632861614, 0.05622562027669378, 0.06731987478477613, 0.11555230165166513, 0.19317013956606388, 0.1255660400326763, 19.848423855645315, 65.57365199497768, 31.655092988695415, 25.054021188191005, 45.254749979291645, 47.15076398849487, 65.18720013754708, 57.0160664830889, 57.3298054422651, 53.2137725012643, 56.077208518981934, 47.94052055903843, 53.26199299948556, 20.58745857647487, 0.960703426173755, 0.8765332198568753, 0.11255372648260423, 4.438926151820591, 41.14675957815987, 57.90418522698538, 57.40785108293806, 57.54941020693098, 54.184262139456614, 55.706254618508474, 53.13513626371111, 54.15930073601859, 54.79232679094587, 53.624150480542866, 54.5739483833313, 53.2615761075701, 55.158420426504954, 52.43890939440046, 51.784503732408794, 49.72918490001133, 52.156034333365305, 53.818161555698936, 51.75674915313721, 52.7344788142613, 52.99647453853062, 52.29225376674107, 49.66264547620501, 49.90061432974679, 53.7911365372794, 52.67856318610055, 47.35628822871617, 47.316061632973806, 51.958656855991904, 50.042670249938965, 45.28874751499721, 40.78326109477452, 37.85076345716204, 39.02401890073504, 38.579410621098106, 37.472903047289165, 36.683994156973704, 39.40322378703526, 46.92061880656651, 47.007919447762625, 48.36009447915213, 46.49793209348406, 49.52795812061855, 49.465886388506206, 49.47561386653355, 51.579146248953684, 49.91283621106829, 43.61158091681344, 38.09728206907, 39.617110184260774, 38.307551928928916, 39.16393824986049, 40.95028189250401, 37.92139884403774, 40.5068096433367, 45.776625701359336, 51.309139251708984, 50.678715297154014, 45.767474923815044, 40.25600399289812, 35.94582448686872, 39.504184586661204, 40.42848607472011, 39.656978947775706, 37.82132741383144, 39.31892129353115, 44.322110652923584, 49.93780108860561, 49.77095399584089, 50.15898309435163, 50.24045072283064, 50.853118555886404, 46.9542168208531, 47.69184800556728, 47.56449099949428, 47.168495791299, 46.29270315170288, 45.80511678968157, 40.21442597252982, 36.07605457305908, 34.31084040233067, 35.36546230316162, 34.08323131288801, 36.372714860098704, 35.05787597383772, 40.03011458260672, 40.72969395773751, 44.048306465148926, 46.522667680467876, 48.212407044001985, 50.1358699117388, 48.09573984146118, 47.31294536590576, 47.937178475516184, 44.75475760868618, 41.61061784199306, 40.17054809842791, 37.90455641065325, 38.41947003773281, 37.214909485408235, 39.881853921072825, 47.53718457903181, 50.52844313212803, 50.456268719264436, 50.0028327533177, 51.48763847351074, 52.152991022382466, 52.801049504961284, 51.122517585754395, 51.150386810302734, 53.059036118643625, 54.21819714137486, 54.23526539121355, 52.885841846466064, 48.84957422528948, 48.192034925733296, 29.37092481340681, 0.8177985772490501, 2.538294196128845, 0.11199248981262956, 0.7858445718884468, 12.426616941179548, 54.68719359806606, 49.118299279894146, 56.974988733019146, 50.86055660247803, 58.45778642381941, 51.72427674702236, 46.62842621122088, 36.366617815835134, 24.59071704319545, 36.399607862745015, 48.736506189618794, 4.143500472818102, 0.38343139950718197, 0.025419584209365503, 0.018036185131807412, 0.05699349460857255, 0.04816951309995992, 0.04436298253546868, 0.034453545164849074, 0.046396093975220404, 0.030906530496265208, 0.04818160459399223, 0.13352970699114458, 0.21294285356998444, 0.1286154714013849, 0.18359677041215555, 0.20282493292221002, 0.16728424573583262, 0.22068804582314833, 0.19667873558189186, 0.1481644045561552, 0.22447608970105648, 0.23300835543445178, 0.2623372987977096, 0.33135709379400524, 0.28661693739039557, 23.62073462350028, 75.15557221003941, 46.32309109824044, 40.28852503640311, 40.9509072303772, 57.11728089196341, 69.24940190996442, 64.97094440460205, 61.19528634207589, 60.754888670785085, 60.36419841221401, 52.86432327542986, 58.6612366267613, 25.307316030774796, 1.857675152165549, 6.446061398301806, 0.29679292706506594, 7.082674026489258, 44.705713748931885, 59.911912373134065, 58.65290573665074, 60.66428416115897, 56.34873717171805, 57.01459346498762, 53.72554554258074, 56.82291351045881, 56.07551315852574, 55.881370067596436, 56.49526078360421, 55.64918906348092, 56.616218498774934, 55.480566705976216, 53.01499496187483, 51.12380647659302, 53.602006571633474, 54.54173306056431, 53.335386821201865, 54.78741094044277, 56.00761188779558, 57.27463674545288, 51.9743389402117, 52.914534432547434, 57.718209743499756, 55.56050225666591, 49.880290848868235, 50.27504927771432, 54.324810300554546, 53.26014477866036, 48.67337138312203, 43.928123474121094, 40.0698687008449, 41.90796252659389, 40.995358330862864, 38.62178768430437, 39.425739424569265, 41.29206378119332, 49.30429908207485, 50.7001748085022, 52.2391973223005, 49.835579190935405, 52.43517821175711, 52.78329338346209, 52.31552675792149, 54.46702602931431, 51.41009657723563, 43.11910302298409, 37.399901798793245, 38.58142212459019, 37.39104631968907, 41.417103563036235, 40.755124364580425, 38.0596158845084, 40.209947858537944, 47.41142565863473, 54.20726415089199, 52.163521017347065, 49.61991058077131, 40.4410206249782, 35.22343070166451, 38.95626701627459, 41.42390584945679, 38.951170512608115, 36.61701699665615, 39.524706091199604, 43.75988326753889, 51.859356675829204, 50.78154516220093, 52.372220584324424, 52.860004970005576, 53.23508262634277, 50.551299231392996, 49.527704511369976, 48.79110860824585, 48.59163277489798, 48.12030867167881, 49.130493368421284, 41.98878744670323, 38.43849073137556, 37.92251055581229, 36.85424934114729, 36.64355216707502, 38.97814689363752, 37.646114689963206, 44.04795905521938, 44.46919706889561, 45.99988521848406, 48.410545349121094, 50.187331744602744, 53.0509032521929, 49.48699501582554, 49.32661322184971, 48.98693663733346, 46.10744333267212, 44.2531532560076, 43.4398318699428, 39.84088734218052, 42.47284412384033, 39.7243834223066, 42.326254504067556, 50.59438501085554, 54.71054996762957, 53.62591184888567, 52.23655005863735, 53.2342905317034, 52.72666903904506, 53.65369769505092, 54.20253937585013, 51.5307867867606, 54.86090203693935, 55.524263926914756, 57.58919211796352, 54.03556374141148, 49.14156879697527, 48.6079888343811, 36.27642672402518, 1.7310173085757663, 3.8768055949892317, 1.6936808377504349, 1.4587835222482681, 14.23760758127485, 61.76430211748396, 54.59437608718872, 63.07284940992083, 56.59713874544416, 63.997314180646626, 54.99844510214669, 55.54249600001744, 36.42838382720947, 32.52656732286726, 43.93761471339634, 57.54689843314034, 6.795385990824018, 0.7101032904216221, 0.118485635678683, 0.1410965531000069, 0.1932047177106142, 0.2222661961402212, 0.1352084026272808, 0.23161518733416284, 0.19263534540576593, 0.19230234756001405, 0.2147539992417608], [0.04341169340269906, 0.05199529370293021, 0.03659484222797411, 0.032573324628174305, 0.025595399418047497, 0.04507917964032718, 0.023912603734061122, 0.034366597687559466, 0.04885467401306544, 0.12708666415086814, 0.008776117648397173, 0.03114200589646186, 0.08522423582949809, 0.11050356006515877, 1.6287178950650352, 45.450734342847554, 49.50413274765015, 36.47220958982195, 21.74549225398472, 40.082521370479036, 56.34402976717268, 55.03495788574219, 51.46629013334002, 50.95255422592163, 49.588185106004985, 45.92839867728097, 45.461865356990266, 23.082944052559988, 0.24244563760501997, 0.5977036388857024, 0.07421310525387526, 0.2259089792413371, 22.678838559559413, 63.14092785971505, 51.49461099079677, 56.568001474652974, 52.66345432826451, 55.786853722163606, 52.936178071158274, 53.79293612071446, 52.141300678253174, 54.62518787384033, 51.92016730989729, 52.29739195959908, 50.327410902295796, 52.65735728400094, 50.201242038181846, 53.50777857644217, 52.27425445829119, 51.63328661237444, 51.08660582133702, 51.27397789273943, 46.053296021052766, 49.29596471786499, 47.93764400482178, 46.66420248576573, 47.400124413626536, 49.552999428340364, 51.449284417288645, 52.34187085287911, 48.82095806939261, 49.528691155569895, 44.39051219395229, 40.75051770891462, 36.653706959315706, 37.11296551568167, 34.560315472739084, 35.00874873570034, 33.3041159084865, 34.956731046949116, 42.34918703351702, 45.92720358712332, 46.76192889894758, 46.914261204855784, 45.34629249572754, 46.230381284441265, 47.74449103219168, 44.16191646030971, 40.977470193590435, 39.427427836826865, 38.32590906960623, 38.70925855636597, 38.420984745025635, 38.77467584609985, 37.76144436427525, 42.667734146118164, 44.79712077549526, 42.285649231501985, 46.973379952566965, 46.85993671417236, 43.36104277202061, 44.04183769226074, 43.139756543295725, 40.20059905733381, 40.23676095690046, 39.90255260467529, 41.10314226150513, 39.534985951014924, 39.85706622259957, 43.1423864364624, 46.61318186351231, 48.58039058957781, 48.39150728498186, 48.61049018587385, 45.77587182181222, 47.372098854609895, 46.23149994441441, 46.99445383889334, 46.88673939023699, 46.68283060618809, 41.1271448135376, 33.028255053928916, 31.227528640202113, 32.60446010317121, 33.68375505719866, 34.88886799131121, 34.36742653165545, 37.346779346466064, 38.19762100492205, 40.59284223828997, 46.73195784432547, 47.07638004847935, 43.83359670639038, 47.51488780975342, 45.539247444697786, 45.102959632873535, 41.518720967429026, 40.13985790525164, 39.13743782043457, 38.161490372249055, 36.51511819022042, 37.219651630946565, 35.14939417157854, 39.70957681110927, 46.83095230375017, 50.466232436043875, 49.49045521872384, 50.21464163916451, 50.99145718983242, 52.59172807421003, 50.78591557911464, 51.20365864889962, 50.426933424813406, 52.67589507784162, 49.14259713036673, 52.218957219805034, 49.79425825391497, 50.16442700794765, 23.431279829570226, 0.19217683215226444, 1.3772927692958286, 0.4293924303991454, 0.21470518543251924, 25.12066830907549, 51.77054827553885, 45.4892829486302, 49.77699892861502, 49.666605949401855, 48.894966806684224, 45.625992230006624, 37.61048085348946, 23.207353285380773, 27.230381114142283, 40.3826835496085, 18.543573004858835, 0.3811508704509054, 0.025942919609536017, 0.030971473082900047, 0.032696566943611415, 0.08177575801632234, 0.025208985599290048, 0.036907928463603766, 0.04073306106563125, 0.009680912713520229, 0.025642214941659143, 0.04759603565824883, 0.06651031465402671, 0.0016686543780711613, 0.01726104538621647, 0.050095226016959975, 0.014182658383755811, 0.03338146662073476, 0.0638891678037388, 0.013309153112848955, 0.046706343934472115, 0.034509541267263036, 0.04037247398602111, 0.04556575370952487, 0.03946579174537744, 0.1119015525494303, 3.232603579759598, 53.997769015175955, 52.028333391462056, 31.762018816811697, 35.79546199526106, 47.35469709123884, 59.93283339909145, 60.806381770542686, 55.85874325888497, 55.089845180511475, 53.52648312704903, 50.6100948878697, 52.54551213128226, 27.102087838309153, 0.4524952449968883, 0.515550744320665, 0.05406225386208721, 0.2876680152756827, 26.23006980759757, 63.819746017456055, 54.692599296569824, 59.77542890821184, 54.680947167532786, 55.688616616385325, 53.02242953436715, 55.03690685544695, 51.36298084259033, 55.203260626111714, 52.118072850363596, 53.275180680411204, 52.44273090362549, 54.80474322182791, 51.43116004126412, 54.29677779333932, 54.54525579724993, 52.9397668157305, 52.92396661213466, 52.771523135049, 49.128186566489084, 50.897041593279155, 48.890242031642366, 50.51430354799543, 49.74443619591849, 50.70053958892822, 52.6850562776838, 53.77581575938633, 51.44587632587978, 52.43928459712437, 46.1381231035505, 43.388623646327424, 39.279959269932334, 38.81483990805489, 37.441132409232004, 37.3752634865897, 36.15640006746565, 36.41840968813215, 45.81779725211007, 50.10927568163191, 48.77520765577044, 49.058461393628804, 49.539297580718994, 48.610920974186485, 50.29377119881766, 47.202455111912315, 43.02358961105347, 38.45449938092913, 38.21512699127197, 39.81488718305315, 39.49768802097866, 39.123430252075195, 38.280144759586875, 42.99518537521362, 45.60867384501866, 45.996032442365376, 47.23464264188494, 50.54443441118513, 45.06037759780884, 46.3322696685791, 42.2467497416905, 39.25329903193882, 38.47419057573591, 39.225784165518625, 40.21639231273106, 37.9605449948992, 39.3964319229126, 43.94116524287632, 47.58375488008772, 49.81166001728603, 49.507561683654785, 49.58029890060425, 46.57584571838379, 46.890578269958496, 47.66004262651716, 47.5817676952907, 47.09808274677822, 48.60081134523664, 42.967677456992014, 35.162901469639365, 33.11582667487008, 34.82965544291905, 36.48366716929844, 36.413222857883994, 36.74069145747593, 39.33669478552682, 40.3354184286935, 41.398221833365305, 47.31636735371181, 46.950172969273154, 46.416394983019146, 49.63409532819475, 47.542590277535574, 47.62319285529, 43.13458708354405, 43.11258561270577, 40.84097630637032, 39.220586912972585, 37.785950660705566, 39.45543949944632, 36.34165988649641, 41.72740316390991, 50.47887120928083, 52.44816092082432, 50.731386116572786, 50.92418473107474, 52.50973238263811, 52.050327914101736, 53.695595332554404, 53.86778211593628, 50.725994314466206, 54.370182037353516, 51.22711229324341, 54.479977471487864, 51.89806856427874, 53.537291049957275, 26.531480925423757, 0.1883911495762212, 2.4429377700601305, 0.09689217473247222, 0.1308218501508236, 27.91734082358224, 55.875349453517366, 51.2815375328064, 54.82229437146868, 55.766839436122346, 56.11868231637137, 50.63683155604771, 43.390631675720215, 34.19834906714303, 20.782322543007986, 47.468647548130576, 23.571525744029454, 0.3543453716806003, 0.010881989246367343, 0.047692815107958655, 0.03451503740091409, 0.036391525994986296, 0.0172883649024048, 0.00731431318646563, 0.026730776797713976, 0.027397266123443842, 0.09982381920729365, 0.030727482068219354, 0.12193982675671577, 0.07645740054015603, 0.11318010929971933, 0.11716110818088055, 0.10265758500567504, 0.14507233404687472, 0.07812945331845965, 0.11045705327498061, 0.21684189220624311, 0.1306319281991039, 0.08572579534458262, 0.1903294391397919, 0.20171110411839827, 0.275536976222481, 3.4699601233005524, 63.9606693812779, 61.71083572932652, 48.49106454849243, 30.832061495099747, 51.2670818056379, 65.30499989645821, 65.89775766645158, 62.28468745095389, 61.743547848292756, 57.7532182421003, 53.320347445351736, 57.21725157329014, 31.07685000555856, 1.032071088041578, 3.3381126267569403, 0.3479768048439707, 0.935307651758194, 30.954492228371755, 65.4462776184082, 56.17942346845354, 61.600213459559846, 57.710198470524375, 58.03624268940517, 55.82934890474592, 56.232584135872976, 54.06412083762032, 57.25936460494995, 54.84181880950928, 54.3903352873666, 54.58667400905064, 55.16858564104353, 53.395148277282715, 56.82415723800659, 56.26497663770403, 56.89212104252407, 56.1102089881897, 54.13775437218802, 50.71870565414429, 53.37534243719918, 52.353081771305625, 52.60067735399519, 52.11326469693865, 53.107854161943706, 55.59309278215681, 55.37669461114066, 53.27718870980399, 55.18209293910435, 47.411262375967844, 46.933907236371724, 41.4491799218314, 41.11801488058907, 39.61765909194946, 39.545074735369, 38.28182274954659, 38.291428634098594, 47.40988315854754, 50.78907353537423, 51.215668610164094, 51.39739874431065, 52.18209702627999, 51.474999700273784, 53.15117965425764, 47.92496006829398, 42.79142945153372, 38.87566443852016, 38.77849735532488, 39.53872060775757, 38.941557679857524, 38.543849740709575, 37.30853993552071, 43.811143602643696, 47.05087668555123, 47.07420178822109, 48.32261937005179, 49.33136926378523, 47.704945359911235, 48.27414526258196, 44.89555590493338, 39.510462284088135, 37.48011875152588, 40.00666093826294, 39.95285061427525, 37.66178635188511, 38.794512953077046, 42.955723081316265, 48.028932912009104, 50.1295678956168, 50.767502852848594, 51.36558641706194, 46.04995393753052, 49.5697272164481, 50.365174361637656, 50.841174602508545, 50.279405798230854, 51.371944018772666, 46.098872729710166, 37.89597885949271, 33.949659143175396, 35.74691840580532, 38.60444498062134, 39.1896778515407, 38.49712657928467, 42.74182973589216, 42.84192201069423, 44.32168333871024, 50.065470763615195, 49.71884945460728, 48.77361651829311, 50.91593721934727, 49.2465352330889, 50.96899366378784, 45.16434696742466, 44.54710374559675, 44.23265259606497, 41.8801280430385, 39.73472581590925, 41.97137178693499, 39.987087862832205, 43.90665354047503, 52.78335244315011, 54.03241273335048, 51.18352624348232, 52.434730052948, 53.7805301121303, 55.257859570639475, 55.428993701934814, 55.371556418282644, 52.34808949061802, 54.60345390864781, 53.62929562159947, 55.90469169616699, 53.81199850354876, 53.38829387937273, 29.637742587498256, 0.714739910193852, 4.389697296278817, 0.7805767517004694, 0.5951870339257377, 31.568973541259766, 62.44547571454729, 56.288117613111226, 59.10922173091343, 61.19147872924805, 58.32521479470389, 55.487160546439036, 48.32816055842808, 35.240429469517295, 39.02721159798758, 52.2189850125994, 35.591987473624094, 0.5062841272779873, 0.11829138467354433, 0.1434179435351065, 0.29472203818815096, 0.18031731567212514, 0.15599514650447027, 0.10876646291996751, 0.12689040468207427, 0.09796957977648292, 0.1688680686056614, 0.10646272118070296], [0.01325224946984755, 0.016472999904570833, 0.039254760569227595, 0.0374059290625155, 0.12342532990234238, 0.0034256376883214606, 0.025891941273584962, 0.1113663851948721, 0.05196473587836538, 0.06281047354319266, 0.03722199518233538, 0.03677850130147167, 0.04727837948926857, 0.08586511893996171, 0.1183347294905356, 22.106015171323502, 47.533776487622944, 35.833482537950786, 25.84585005896432, 29.954580443246023, 54.597485406058176, 54.044075284685405, 55.18324286597115, 49.578933579581125, 53.31775229317801, 45.786203793116975, 48.606008597782676, 29.730608735765728, 0.13658604584634304, 0.16299078826393398, 0.3176056859748704, 0.11144846079072782, 17.17779687472752, 66.0249444416591, 50.303491728646414, 53.249489716121126, 48.0049546786717, 51.400063378470286, 52.119476386478965, 53.16483286448887, 52.62281778880528, 52.86626877103533, 53.56090450286865, 55.154741355351035, 53.152135031563894, 51.53000858851841, 52.05954122543335, 50.819534437997, 48.29513577052525, 49.86282655170986, 46.58883884974888, 49.04093108858381, 48.03989716938564, 47.53290101460048, 45.40692942483084, 46.207837854112896, 48.1998724937439, 49.81123965127127, 48.7016019139971, 49.404832567487446, 50.54580668040684, 49.54438713618687, 45.07972138268607, 39.911884035382954, 39.57248885290963, 35.43481922149658, 35.16643115452358, 34.28648001807076, 34.27454648699079, 35.051966530936106, 41.55804429735456, 46.45135831832886, 45.46661097662789, 48.47474670410156, 45.62561355318342, 46.462194034031455, 42.735444341387065, 40.435416902814595, 38.10816642216274, 38.499523707798545, 38.022238050188335, 39.33587489809309, 40.223806040627615, 40.16567046301705, 41.87256840297154, 40.58111367906843, 36.67701816558838, 37.864618165152415, 37.95085225786482, 36.29513474873134, 36.58964456830706, 35.7525429725647, 40.59106002535139, 42.52732147489275, 42.671850953783306, 40.31441402435303, 40.69674907411848, 40.15448038918631, 40.226182324545725, 40.30763258252825, 42.81470244271414, 44.98328733444214, 46.43713188171387, 47.76017311641148, 45.95198433739798, 47.76757642201015, 44.435473987034385, 46.29589932305472, 45.9226907321385, 45.72326353618077, 39.99158334732056, 33.27232442583357, 33.38423906053816, 34.37980127334595, 32.91678510393415, 34.6597580909729, 33.59305674689156, 37.80833428246634, 39.48323924200875, 44.26777573994228, 45.148320947374614, 44.90078789847237, 47.330090045928955, 47.56951454707554, 45.6602121080671, 45.07500008174351, 41.93804127829415, 42.16871452331543, 42.26071562085833, 40.06931284495762, 38.34613527570452, 38.43879645211356, 35.891440936497276, 36.69925587517874, 38.98677308218819, 48.474131788526265, 50.95536824635097, 50.6877965927124, 48.77761173248291, 50.75214385986328, 50.586953912462505, 51.79393591199602, 52.46651806150164, 52.19074405942644, 49.94870976039341, 50.09077262878418, 49.251874923706055, 54.073427949632915, 33.774554116385325, 0.6924703365990094, 1.3350358882120676, 0.2097508077110563, 0.6208048249994005, 33.16475588934762, 48.93690960747855, 47.093886034829275, 47.110863958086284, 48.85141897201538, 44.68236780166626, 47.84957906178066, 30.97529513495309, 22.67170623370579, 34.29392153876168, 34.73401696341378, 2.8803922278540472, 0.255182038460459, 0.037749786861240864, 0.16572945059410163, 0.038978091308048794, 0.03657107314627085, 0.00864462519530207, 0.049532669596374035, 0.0609845154519592, 0.04693694406055978, 0.040489141297127516, 0.02866773134363549, 0.049883302567260604, 0.021874065710497752, 0.05728144451443638, 0.0551746102449085, 0.1005126272461244, 0.028863546371992146, 0.007976481092295476, 0.02772639801592699, 0.03329823751534734, 0.03327942852463041, 0.025303252773093324, 0.03904709492677024, 0.059828821037496836, 0.06816070180918489, 0.05366919209648456, 28.441790853227886, 55.96684333256313, 29.451252937316895, 29.6873596736363, 44.1696115902492, 58.10183368410383, 61.93688147408621, 58.98867743355887, 53.39282063075474, 57.278103896549766, 50.849158082689556, 52.9517559323992, 34.042296000889365, 0.06169545730309827, 0.2131593469530344, 0.10742791688867978, 0.16570651611047132, 19.222078493663243, 67.39958994729179, 54.04286282403128, 54.55147443498884, 49.739106927599224, 52.775983878544395, 53.86224440165928, 55.34216206414359, 54.33516311645508, 54.382014819553916, 54.4281439099993, 54.680578913007466, 54.931245599474224, 52.77752637863159, 53.57695484161377, 52.85958807809012, 51.80527884619576, 52.313233852386475, 50.12372098650251, 51.668482712336946, 52.27153771264212, 48.964973381587434, 47.712946210588726, 48.18063988004412, 49.64528887612479, 52.70503582273211, 51.25276851654053, 51.42036601475307, 52.471624987465994, 51.43118435995919, 47.97829096657889, 41.172763211386545, 41.94290501730782, 37.54696389607021, 36.912489141736714, 36.62785618645804, 36.650232860020225, 37.16774163927351, 42.51833050591605, 49.535062653677805, 48.56366280147007, 51.05515827451433, 49.14304181507656, 47.61053671155657, 44.792785099574495, 41.6670754296439, 40.57586778913225, 39.4849728175572, 39.63725996017456, 40.51992089407784, 41.31830712727138, 40.01276840482439, 42.13918815340315, 42.94735050201416, 42.36481353214809, 40.52453449794224, 40.413745471409385, 38.96845415660313, 38.564412934439524, 39.071284021650044, 42.413437025887625, 44.43948309762137, 41.63292155947004, 39.56849363871983, 39.63542563574654, 37.87909126281738, 40.40468154634748, 38.917607239314485, 42.612596716199604, 46.01793663842337, 46.968130588531494, 48.85912799835205, 48.0169472694397, 49.14027295793806, 46.586278438568115, 47.205064160483225, 47.43307277134487, 47.82067455564226, 41.145199707576204, 35.214269501822336, 34.46260295595442, 35.64566578183855, 34.05132865905762, 36.06526402064732, 35.82573182242257, 40.02065461022513, 40.8903397832598, 47.35238334110805, 48.13637638092041, 48.015401295253206, 48.83736276626587, 49.190484115055625, 47.85394947869437, 45.670773369925364, 43.66296979359218, 45.313351086207796, 43.33105782100132, 42.31259781973702, 40.10197980063302, 38.456253801073345, 37.49300071171352, 38.751093660082134, 41.444413457598, 50.24740239552089, 52.514220918927876, 53.00559752328055, 50.736565998622346, 52.772006034851074, 51.34467928750174, 51.95655502591814, 53.90775510243007, 53.80194446018764, 51.87832178388323, 51.8329952103751, 51.34507533482143, 55.628796100616455, 35.73490844454084, 0.7815123157841819, 2.2812308243342807, 0.10539607770208802, 0.26374105204428944, 36.8985857963562, 53.547237396240234, 50.849140712193076, 55.05964136123657, 53.91661752973284, 49.63781261444092, 49.16202081952776, 41.46681792395455, 30.51584550312587, 32.51802451269967, 44.034799167088096, 5.012029639312199, 0.18729659116693906, 0.018636902361842136, 0.06574659634913717, 0.06209338416478463, 0.03256329588059868, 0.043442190159112215, 0.011879567189940383, 0.09266828745603561, 0.046021851378359964, 0.06433892117014953, 0.08436646578567368, 0.15000980267567293, 0.10750720370560884, 0.16715293563902378, 0.0762410903615611, 0.12237707472273282, 0.17353239974805287, 0.09588572409536157, 0.19825657377285616, 0.14374682945864542, 0.2081516363791057, 0.08772162467773471, 0.1576912940612861, 0.16342483354466303, 0.19614890829793044, 0.22354032205683844, 34.37660162789481, 62.884775570460725, 46.00311960492815, 36.84583159855434, 41.57789530072893, 67.62204347337995, 65.08797986166817, 65.39080320085797, 58.230670656476704, 63.70202268872942, 54.85037899017334, 59.367611340114046, 39.09566872460501, 0.19183737465313502, 0.5962090705122266, 1.5260222171034132, 0.22000432679695742, 22.082870721817017, 70.08685438973563, 56.13831445149013, 56.02921036311558, 53.49548026493618, 55.51513399396624, 57.50150237764631, 56.77796561377389, 57.79985455104283, 54.83789307730538, 56.57895530973162, 56.56497206006731, 56.80163812637329, 55.13158995764596, 56.65632350104195, 52.85002735682896, 54.20399154935564, 54.3897933278765, 52.02108989443098, 53.3770169530596, 54.43561322348458, 51.89354528699602, 50.704819679260254, 50.10624974114554, 52.86938156400408, 55.19675363813128, 52.623835699898855, 53.196023327963694, 54.71337788445609, 54.73211022785732, 50.883777482169016, 43.49838433946882, 43.55697849818638, 39.990690503801616, 38.28845827920096, 39.06392935344151, 40.433023248400005, 39.85794169562203, 45.10104887826102, 51.64598791939871, 50.172806535448345, 55.274007184164866, 50.283762318747385, 50.19240740367344, 43.332569054194856, 41.5311929838998, 39.76974126270839, 38.76259640284947, 38.50796924318586, 40.857863903045654, 41.002646991184776, 39.92097922733852, 44.72886514663696, 46.50968149730137, 44.32866975239345, 42.18595995221819, 41.6241112436567, 41.22823762893677, 40.2985234941755, 41.32931307383946, 44.89714356831142, 46.39546353476388, 42.43173163277762, 38.425709520067485, 39.22769144603184, 38.237548828125, 40.69675949641636, 38.38291903904506, 42.49492202486311, 45.485162666865754, 46.70390796661377, 50.4635226385934, 47.785801546914236, 50.96147918701172, 48.96040494101388, 49.967636653355186, 49.58209848403931, 50.371650082724436, 42.811395100184846, 36.91890580313546, 37.27255174091884, 38.321264198848176, 36.64080762863159, 38.9601788520813, 38.40595926557268, 42.57756389890398, 43.7004587990897, 49.82496929168701, 50.12385647637503, 50.71196242741176, 51.39187840053013, 52.79653664997646, 50.10594402040754, 48.11822073800223, 45.96217734473092, 48.04734911237444, 46.96108858925955, 44.121029785701204, 42.06226117270333, 41.56526000159127, 40.2269674709865, 41.497317041669575, 42.37530531202044, 52.6954334122794, 56.171450410570415, 54.38838284356253, 51.34306730542864, 54.971343653542654, 53.21663863318307, 52.23403828484671, 55.004959038325715, 56.4651438168117, 54.513207231249126, 55.37081296103341, 54.198360034397666, 59.489482743399485, 35.59170954568045, 1.6428356575114387, 4.286209523677826, 0.3273606853825705, 0.8165027382118362, 40.89293493543352, 57.988258429935996, 57.618906089237754, 58.635305949619834, 60.83548082624163, 53.97362402507237, 57.62477731704712, 42.049257619040354, 34.86046028137207, 45.260134833199636, 53.66803182874407, 10.218417763710022, 0.6413875605378832, 0.1475720163434744, 0.21720052510499954, 0.19838930879320416, 0.08224145695567131, 0.1920901018061808, 0.1216643008270434, 0.15062051133385726, 0.12685126678219863, 0.14962670180414403, 0.11661832087806293], [0.07392158625381333, 0.05498472561261483, 0.04224795834826572, 0.059952327981591225, 0.051907040045729706, 0.05583101484392371, 0.06708388030529022, 0.08715432190469333, 0.01163930811786226, 0.02150794517781053, 0.03221486475584762, 0.012468842623223151, 0.05391951723556433, 0.030598305964044163, 0.048112628116671524, 3.152282621179308, 48.80355283192226, 42.77868298121861, 32.321067401341026, 25.159288133893693, 45.791487898145405, 57.00567545209612, 55.8848545891898, 49.77741929462978, 48.635232721056255, 48.95856714248657, 46.89328459330967, 36.42381191253662, 0.8043083782706941, 0.4464320189186505, 0.41328582753028187, 0.11033056077680417, 13.795639617102486, 66.11921065194267, 50.97104685647147, 51.239459242139546, 45.094642639160156, 43.80792311259678, 44.28507675443377, 49.39120020185198, 51.42501088551113, 53.56520196369716, 52.1301349231175, 52.36008208138602, 52.328943729400635, 50.52231134687151, 49.29369265692574, 48.7470292363848, 45.39656966073172, 43.59826122011457, 40.7453065599714, 43.476897035326274, 40.27526439939226, 38.24551493780953, 39.43204491479056, 44.94886595862252, 48.082107475825715, 46.39479998179844, 49.70124619347708, 48.2606657573155, 50.976456029074534, 50.61498294557844, 47.21578523090908, 39.78208473750523, 38.07117073876517, 35.806068420410156, 34.440167222704204, 35.225337982177734, 34.689208030700684, 34.587927613939556, 37.2964083807809, 43.122160230364116, 46.22799457822527, 44.60745232445853, 44.92538104738508, 40.278995582035606, 40.1252041544233, 38.843852111271445, 38.92961720057896, 41.0106964792524, 39.482499258858816, 38.72730997630528, 41.11314071927752, 39.57884645462036, 36.446581159319194, 36.1418331691197, 34.585714612688335, 36.146408557891846, 34.96499940327236, 35.53749622617449, 34.64547259466988, 35.408256258283345, 32.97424670628139, 36.22623641150338, 37.80113247462681, 40.30716010502407, 42.01062216077532, 39.91249200275966, 40.267934049878804, 41.87867586953299, 40.28198330742972, 39.75262090138027, 43.70471804482596, 46.52968883514404, 48.918729645865305, 47.77627209254673, 45.494459356580464, 47.46352672576904, 44.496711935315815, 46.48343120302473, 39.675131116594585, 31.689191273280553, 32.53388377598354, 33.839245319366455, 32.69004801341465, 33.41695812770298, 36.48418481009347, 36.11026750292097, 41.45896993364607, 44.341054916381836, 45.39916133880615, 44.326442854745046, 46.778681005750386, 46.88349110739571, 43.85743250165667, 44.673025948660715, 43.73877464021955, 44.99041271209717, 42.70256199155535, 40.837849617004395, 40.1549528666905, 38.688976764678955, 36.2715664591108, 38.49420486177717, 36.43015909194946, 40.54259286608015, 45.81704684666225, 46.62936421803066, 51.78893320901053, 51.284434931618826, 51.952681405203684, 51.060133184705464, 50.62175049100603, 48.48351533072335, 46.55382340294974, 44.55996138708932, 50.46327597754342, 50.531430857522146, 45.4335549218314, 2.513707561152322, 0.03467460848124964, 0.2074170543679169, 1.0940077645438058, 32.59897797448294, 48.842382839747835, 44.639434882572715, 46.668385301317485, 49.19193281446184, 57.155832971845356, 44.12216234207153, 24.071938480649674, 25.842989138194493, 37.40675967080252, 16.4589900970459, 0.21124974585005216, 0.02728679553339524, 0.06826818854148899, 0.013180278956757059, 0.04037318644779069, 0.0251346079832209, 0.09218949279082672, 0.02679939704414989, 0.04356999901522483, 0.045807386815015755, 0.012149675865657628, 0.04328754185033696, 0.027647302885140692, 0.06652471995247261, 0.086671327107719, 0.027861416306612746, 0.02609023974010987, 0.02310129128662603, 0.057307635966156206, 0.031047933801476444, 0.01760760714699115, 0.0796757803431579, 0.045632470665233474, 0.0560006011011345, 0.009669608320109546, 0.03762789822316595, 0.06407694558479957, 5.7407558390072415, 57.94410957608904, 40.75613880157471, 28.227558783122472, 45.12047256742205, 48.87134640557425, 61.60804407937186, 60.76773588997977, 54.63108342034476, 55.64265080860683, 55.48289087840489, 51.99145582744053, 39.260598114558626, 0.7289167323282787, 0.5579726994037628, 0.3279615417122841, 0.09566258106912885, 14.986484425408499, 69.1888553074428, 53.276125635419575, 53.06452519553048, 46.09426607404436, 46.858644349234446, 46.462718623025076, 51.644264766148154, 53.14228596006121, 54.41176005772182, 55.0945908001491, 54.391592911311555, 54.170251096997944, 53.01650619506836, 51.125974314553396, 51.46502208709717, 46.936471121651785, 46.90974834987095, 43.55415405545916, 45.88494116919381, 43.49611575262887, 40.2828483581543, 41.9415396962847, 47.26780639375959, 47.450088909694124, 48.76048789705549, 52.956630093710764, 50.59694194793701, 51.546364648001536, 50.70840147563389, 48.9575457572937, 41.103159632001606, 39.66234990528652, 36.23045744214739, 37.75292934690203, 36.888865266527446, 36.804270948682515, 36.70654106140137, 40.31109625952584, 45.34304421288626, 48.97825486319405, 49.59368460518973, 47.4129855292184, 42.840626171657014, 39.51329714911324, 38.86391156060355, 38.01332351139614, 40.7324732371739, 40.57510348728725, 39.776241302490234, 42.424568040030344, 40.6637590272086, 41.92926222937447, 38.543755940028596, 37.79508406775338, 37.308595521109446, 37.064682483673096, 36.612066405160085, 36.93683215550014, 37.93799809047154, 36.09283447265625, 38.565184184483115, 41.072056021009175, 41.91668946402413, 40.739490917750764, 38.53895820890154, 39.28922469275338, 40.70423228400094, 40.66665295192173, 41.00457511629377, 44.07015854971749, 48.530314922332764, 50.89842775889805, 49.192037037440706, 47.29883010046822, 48.527160440172466, 46.312505517687114, 46.75029761450631, 41.08891929898943, 33.37472002846854, 33.93950087683541, 34.52651596069336, 34.99250037329537, 35.6865177154541, 37.99747814450945, 37.76390055247715, 43.16496460778372, 47.345876353127615, 49.44449635914394, 46.71790163857596, 48.85189839771816, 48.296994413648335, 46.86788545336042, 47.28911999293736, 44.423564774649485, 45.426742213112966, 45.925122601645334, 42.91492673328945, 44.036299977983745, 41.50272968837193, 38.36177914483206, 39.9325201851981, 38.806088651929585, 41.378593172345845, 47.584008489336284, 47.99395220620291, 52.289061069488525, 52.068198680877686, 54.411308424813406, 52.90381336212158, 52.442067350660054, 49.45647505351475, 49.296329498291016, 47.26284885406494, 53.48083346230643, 51.420411178043906, 46.92329733712332, 2.9709248670509885, 0.24359941855072975, 0.04898219109912004, 1.0179739530597414, 37.454295771462576, 53.922186510903494, 50.5377641405378, 52.77334703717913, 55.00147451673235, 63.018403325762065, 46.909168175288606, 36.76397834505354, 21.630501304353984, 39.668648447309224, 25.877212490354264, 0.22669196794075624, 0.08822709255452667, 0.08726486882993154, 0.01610965627644743, 0.045649800449609756, 0.011686341620848646, 0.05207795283890196, 0.03753290332055517, 0.0029679855381670806, 0.022629129301224436, 0.05545356956177524, 0.04243724926241806, 0.11896871189985957, 0.14459217552627834, 0.16381024143525533, 0.19964158588222095, 0.24213329436523573, 0.13181605323084764, 0.16715536479439053, 0.25431883335113525, 0.060109245990003855, 0.12481620455426828, 0.07695676160178014, 0.24260085927588598, 0.12141189937080656, 0.22392110233860357, 0.3585212661751679, 8.32913829599108, 67.75678294045585, 52.45298644474575, 45.04815224238804, 38.13066816329956, 56.824827739170615, 65.72318417685372, 64.33769948141915, 60.044949531555176, 58.449886322021484, 60.89566612243652, 58.12971680504935, 46.91965300696236, 0.8816013879009655, 1.7564750739506312, 0.5761870220303535, 0.18665574198322638, 18.304178033556255, 71.45900549207414, 57.30150890350342, 54.26909964425223, 47.06071186065674, 48.46313279015677, 49.25033589771816, 54.32828787394932, 55.719664641789024, 57.7786625453404, 56.9937037059239, 57.151643208095, 56.72718123027256, 55.07780395235334, 54.27075331551688, 55.6123114994594, 49.78833491461617, 49.877838134765625, 45.873268195560996, 48.82886859348842, 44.41821118763515, 41.18744475500924, 43.280329023088726, 50.13364996228899, 52.38473776408604, 49.312028953007285, 55.86308935710362, 52.24697583062308, 54.732732091631206, 54.34693683896746, 52.34523030689785, 45.47822141647339, 43.39679820196969, 39.15283850261143, 39.476874692099436, 40.20012657982962, 40.130498681749614, 38.88280718667166, 42.92389685767037, 46.874659946986604, 52.59235341208321, 50.011465890066965, 50.0896817616054, 42.61950322559902, 40.452808243887766, 38.69435814448765, 39.96224110467093, 41.43643345151629, 41.63609341212681, 40.04260744367327, 43.73654079437256, 42.98172671454293, 45.354366302490234, 42.605221203395296, 39.98424257550921, 41.08913121904646, 39.438044684273855, 39.37448256356375, 38.36617040634155, 38.77308818272182, 37.686570576259065, 38.90838350568499, 41.56821298599243, 42.25319766998291, 42.24995633534023, 38.73318120411464, 39.36063827787127, 40.37897668566023, 39.55404485974993, 39.30374642780849, 42.96043048586164, 49.23153059823172, 51.39963606425694, 50.72694969177246, 47.67212554386684, 51.729064055851524, 48.309289251055034, 48.61425610951015, 44.12921128954206, 34.77082851954869, 36.97489786148071, 37.13736758913313, 37.10704565048218, 37.8305789402553, 40.53013127190726, 38.86704172406878, 46.36133050918579, 48.611160687037874, 52.06241430555071, 49.206426756722585, 51.11899484906878, 50.91321005140032, 48.36329412460327, 48.90231800079346, 47.170024394989014, 47.78999131066458, 47.3265186718532, 45.31001942498343, 46.07793433325631, 42.25166211809431, 39.560798508780344, 42.69628082002912, 40.60797541482108, 43.4847207069397, 49.392749650137766, 49.784436975206646, 55.948795386723106, 54.76716388974871, 54.23387575149536, 55.304096358163015, 54.73913138253348, 51.591357707977295, 50.69592598506382, 50.025657585689, 54.34177780151367, 55.48006990977696, 49.553728989192415, 3.98377354655947, 0.8647226393222809, 0.36921218250479015, 1.9001275599002838, 41.08981214250837, 59.50778429848807, 54.54415798187256, 57.76064239229475, 58.651932988848, 66.52459635053361, 54.82423291887556, 36.204436438424246, 37.21590307780674, 50.0550137247358, 37.238762651171, 0.22285318321415357, 0.19921959138342313, 0.12921943542148384, 0.11268236315143959, 0.14469044096767902, 0.06963559945247003, 0.1771184844630105, 0.16159976433430398, 0.08700432495347091, 0.12028425559401512, 0.1317740926252944, 0.12747884382094654], [0.0767313726246357, 0.09883260846670185, 0.020940286173884357, 0.05075289947646005, 0.024772285550300564, 0.010416152903677096, 0.06825951007860047, 0.06038149459553616, 0.056371057472590885, 0.04129326296970248, 0.03701640246436, 0.0300522277663861, 0.059155836435300965, 0.07254201599529811, 0.03424579470551439, 0.05496883771515318, 26.277178594044276, 49.07931293760027, 28.034068822860718, 25.648449999945505, 35.29198510306222, 49.64554248537336, 53.008654730660574, 54.4729528427124, 49.31256743839809, 47.52283654894148, 46.784972599574495, 41.45576333999634, 2.62930582676615, 0.5069989232080323, 0.41590187858257976, 0.24438635632395744, 12.643164498465401, 64.75303500039237, 53.225949219294954, 51.592531953539165, 45.825058119637625, 43.69897188459124, 41.07728106634957, 40.321410860334126, 41.762658323560444, 46.66739170891898, 49.83853217533657, 49.41211775371006, 47.858670779636924, 46.20236267362322, 44.43893766403198, 42.280187947409495, 39.15882437569754, 38.93943847928728, 39.20847272872925, 38.090212277003694, 38.714316844940186, 41.23525183541434, 42.18498025621687, 41.81961965560913, 45.444310733250205, 48.531096594674246, 50.28911937986101, 44.359207085200715, 40.983859062194824, 51.77111802782331, 44.15555885859898, 40.63045283726284, 36.59641211373465, 37.3278420312064, 33.49340568270002, 33.05976513453892, 34.58805615561349, 35.70864772796631, 35.89481776101248, 41.521302223205566, 43.360806533268516, 46.17778689520699, 42.60194860185896, 38.98215600422451, 37.65760701043265, 40.38417741230556, 39.68256221498762, 38.29313441685268, 42.23662621634347, 40.972960812704905, 37.86910670144217, 34.74628053392683, 33.91296223231724, 35.66336284364973, 34.326324462890625, 33.29224838529314, 35.44160066332136, 35.11143616267613, 33.49323197773525, 34.67994608197893, 34.66668891906738, 34.4605393409729, 32.45781489780971, 34.61470249720982, 39.6217793737139, 40.49137074606759, 42.01756688526699, 39.39625126974923, 38.87362166813442, 39.63208702632359, 39.23549427304949, 42.57896743501936, 47.78378656932286, 48.532673835754395, 46.35067892074585, 44.15110158920288, 43.89849982942854, 41.992935521262034, 36.37108898162842, 34.199009146009175, 33.63339451381138, 33.904999596732004, 32.96485274178641, 33.814454146793906, 35.41122661318098, 37.08246987206595, 44.33404418400356, 45.58918414797102, 47.54409108843122, 44.28575072969709, 47.30640363693237, 45.86666740689959, 45.710329464503694, 41.944204330444336, 43.34930379050118, 40.80268825803484, 42.735882077898296, 41.98843308857509, 43.548911639622276, 40.20098468235561, 38.745427404131206, 38.799706731523784, 36.9620749609811, 36.66330589566912, 40.86974532263619, 42.67527641568865, 46.92434651511056, 46.5073538507734, 50.29557425635201, 47.50110953194754, 46.36375543049404, 43.35307666233608, 43.04810285568237, 40.9459879057748, 50.471471377781455, 48.92950282778059, 51.0601783479963, 4.581155342715127, 0.06009524102721896, 0.48419884379420963, 0.6804463160889489, 36.385047912597656, 48.573140144348145, 46.388449328286306, 52.01457943235125, 45.063677992139546, 46.896459920065745, 32.6704923084804, 20.43534861292158, 26.510047469820293, 40.30911602292742, 8.51989153453282, 0.4422895354884011, 0.02713851018675736, 0.08551114757678338, 0.030326498406273977, 0.08405623278979744, 0.026894240972719023, 0.060654516730989726, 0.06614706771714346, 0.025720200667689954, 0.09384147450327873, 0.007000335949539606, 0.030402005783149173, 0.018723512267959968, 0.012836301566234656, 0.029090794535087686, 0.036665162204631736, 0.012304033252543636, 0.05621441087818571, 0.05391964954989297, 0.05072444171777793, 0.03487560412447367, 0.03126215409221394, 0.031363391516996283, 0.03683170862495899, 0.04892827470653823, 0.02827668991605086, 0.029889270796307495, 0.21521047689020634, 33.53304515566145, 55.885545934949604, 22.495479072843278, 35.308980396815706, 46.89937121527535, 53.18728249413626, 60.29097829546247, 57.20442172459194, 54.641620363507954, 52.80993972505842, 52.457141467503135, 46.64991004126412, 2.778114093201501, 0.6465000233479908, 0.61605247429439, 0.20268967375159264, 13.822231241634913, 67.22922706604004, 56.35963889530727, 52.64942244121006, 46.9948742049081, 43.91815628324236, 40.9349958556039, 42.3281374658857, 46.51830768585205, 49.763401303972515, 51.86553015027727, 52.558390617370605, 48.98434843335833, 48.84966802597046, 46.70122596195766, 42.56214584623064, 41.39382014955793, 41.375171184539795, 40.71197257723127, 41.98146057128906, 41.13162292752947, 41.942498547690256, 44.34442479269845, 43.410493101392476, 47.442751611982075, 49.02993903841291, 54.22927256992885, 45.769920689719065, 44.26141119003296, 54.321568965911865, 47.30718183517456, 43.109504086630686, 39.95435489927019, 39.02625274658203, 34.66579260144915, 36.285719939640586, 36.857917990003315, 38.109166962759836, 36.902011258261545, 45.213442938668386, 45.13552236557007, 47.645691122327534, 43.55116285596575, 38.7722543988909, 39.914354119982036, 39.94269929613386, 39.99273327418736, 40.07052183151245, 40.50207792009626, 43.704499176570344, 41.012346676417756, 39.12845032555716, 37.32021638325283, 36.824570110866, 38.48017644882202, 34.65184409277779, 37.40617254802159, 36.378905705043245, 35.22608838762556, 36.7694604737418, 36.81014912469046, 35.679017135075156, 35.232713494982036, 38.494173594883506, 41.54278257914952, 40.66998808724539, 42.17804247992379, 38.86553743907383, 39.258607455662315, 38.31167915889195, 39.1851476260594, 43.91999755586897, 48.45230402265276, 49.1060391834804, 47.56387955801827, 46.63492972510201, 45.107138974326, 41.95723915100098, 36.504233837127686, 35.69734648295811, 35.506357874189106, 33.46695736476353, 35.26591198784964, 35.26030479158674, 36.31810549327305, 39.343830585479736, 44.15819917406355, 48.5077680179051, 48.437952518463135, 47.26919950757708, 49.250530447278706, 46.82674864360264, 46.669705459049766, 44.847658497946604, 44.6621971811567, 42.94169814246041, 44.03086301258632, 43.76331915174212, 45.93685116086687, 42.01848404748099, 41.790353843144004, 38.895980971200125, 38.321632453373496, 38.03688137871878, 42.42364392961775, 43.7672518321446, 48.23888315473284, 49.68316003254482, 51.792077268872944, 49.57016495295933, 48.41947031021118, 45.58256251471383, 45.34029967444283, 43.18725790296282, 53.30387674059187, 51.558659485408235, 50.84699371882847, 4.730767863137381, 0.06380270208631243, 0.3660276548138687, 1.7595036200114658, 42.7903733253479, 52.851017475128174, 50.79645947047642, 55.91049344199044, 51.97405753816877, 52.7876638003758, 37.451627663203645, 28.658253295081003, 24.720254046576365, 49.82576486042568, 11.77764390196119, 0.3378053477832249, 0.03079124739659684, 0.0796323608873146, 0.04753257227795465, 0.10755535255053214, 0.047567041856901984, 0.0219927974643984, 0.055842590651341846, 0.0820736823869603, 0.051137530444456, 0.028003282711974213, 0.02362250117585063, 0.08525992677147899, 0.22816518960254534, 0.11446629278361797, 0.12387741064386708, 0.11582478774445397, 0.11952420137822628, 0.19813701590257032, 0.1570583837372916, 0.19419892079063825, 0.11902284542364733, 0.1542093101888895, 0.12296247402472155, 0.11177873092570476, 0.18773758464625903, 0.12152826812650476, 0.35359301205192295, 41.59412629263741, 61.41596112932478, 36.05988264083862, 34.25861774172102, 47.205689498356406, 59.60455880846296, 63.34337057386126, 63.68816103254046, 59.32119042532784, 57.96510008403233, 57.95655032566616, 51.60751921789986, 2.660713855709348, 0.9863160060984748, 1.0841561960322517, 0.4438944879387106, 15.9857291834695, 70.73831748962402, 59.258441243852886, 54.97720445905413, 49.05258321762085, 47.15920952388218, 43.841746943337576, 44.64401721954346, 49.0129576410566, 52.0793331691197, 55.32874509266445, 54.929247992379324, 50.6160877091544, 50.69966064180647, 49.61449098587036, 45.21442263466971, 42.91515949794224, 42.89003133773804, 43.52306086676461, 43.44590112141201, 43.447183064052034, 45.65232590266636, 46.72200107574463, 45.58182947976248, 49.64494841439383, 53.797195366450715, 55.23591715948922, 47.37097324643816, 45.772964000701904, 55.998610496520996, 49.003494194575715, 44.66274608884539, 39.67478370666504, 40.95776162828718, 37.65914256232125, 37.82938037599836, 39.81148256574358, 40.8343859400068, 39.761542388371055, 46.740861960819785, 47.58005496433803, 51.13550724302019, 44.90464414869036, 40.442740304129465, 39.99861145019531, 40.42877789906093, 40.06039135796683, 38.40193625858852, 41.78020599910191, 44.29690606253487, 45.682675634111675, 39.94539867128645, 40.03687170573643, 41.31916175569807, 39.79559898376465, 36.725985595158164, 39.47564833504813, 38.11157103947231, 38.19233342579433, 39.48832184927804, 40.24124254499163, 37.67187166213989, 36.690014771052766, 39.5271692276001, 41.51439223970686, 40.27231141499111, 42.837961537497385, 37.86688675199236, 37.7339677129473, 38.92314147949219, 37.25131804602486, 42.95879418509347, 49.64501094818115, 51.476312909807476, 48.33309030532837, 46.698491845812114, 46.990083421979634, 43.02487850189209, 39.3995030266898, 37.85876430783953, 38.02717127118792, 36.945948192051475, 38.00946031297956, 37.82348830359322, 38.782711437770296, 40.69722155162266, 48.6864652633667, 52.164556298937114, 51.980738231113975, 48.02181795665196, 51.6429237638201, 50.561016287122456, 50.11918381282261, 47.19674021857125, 47.8509304864066, 45.383076259068076, 46.24867589133126, 45.8567453793117, 48.08408076422555, 44.37657410757882, 44.24357863834926, 42.31161117553711, 40.72082110813686, 40.46353626251221, 43.89786754335676, 46.349789551326204, 49.303138732910156, 50.57330070223127, 53.833246094839915, 50.96007217679705, 51.976819447108674, 47.841032777513774, 47.37287357875279, 44.33443328312465, 56.35436173847744, 53.15009226117815, 53.5010666166033, 5.527681512492044, 0.24967523823891366, 0.6882934378726142, 3.050342994076865, 45.107667037418906, 58.653162819998606, 56.74484007699149, 62.410380363464355, 54.56336627687727, 58.10012442725045, 42.084589208875386, 33.2259521484375, 36.47763613292149, 60.73242514474051, 19.101086037499563, 0.539909337248121, 0.13398978087518895, 0.12952769388045582, 0.08240985577659947, 0.19182973434882505, 0.07603883942855255, 0.19538907121334756, 0.22985536605119705, 0.1358238338891949, 0.17564534422542366, 0.10052930563688278, 0.16453783453575202], [0.0036611853949060397, 0.0265606273564377, 0.028320993163755963, 0.03036314608263118, 0.0029717883028622183, 0.07543865484850747, 0.035582953132689, 0.05657591737274613, 0.02956191496923566, 0.062303255046052594, 0.03912911284714937, 0.023443870046841245, 0.08160948979535274, 0.0607530264449971, 0.056879660181168995, 0.1323460026511124, 6.441066946302142, 48.6734756061009, 40.90982253210885, 29.605370930262975, 28.795167548315867, 48.089472566332134, 55.20868716921125, 56.14408493041992, 48.27685853413173, 50.82044117791312, 43.60540049416678, 46.75840268816267, 7.064882295472281, 0.27042920887470245, 0.2990525843841689, 0.3300549308104174, 9.446622286524091, 62.47574206760952, 52.37188707079206, 52.07300683430263, 48.79964099611555, 47.921510287693565, 44.20247309548514, 40.050295625414165, 37.95014354160854, 42.52173859732491, 40.17594337463379, 43.12041275841849, 40.01318529673985, 41.124441964285715, 37.821629660470144, 37.908951146262034, 37.80051408495222, 39.6234712600708, 39.43302113669259, 40.539768423352925, 40.143689836774556, 43.21323374339512, 43.46127053669521, 45.977181979588096, 47.35677807671683, 50.07686233520508, 48.317085129874094, 46.91452176230294, 42.39810235159737, 48.32875462940761, 49.726707867213655, 42.65011004039219, 37.6478830065046, 35.27740430831909, 34.81959792545864, 34.37663289478847, 36.6671586717878, 37.754836627415244, 36.655061858040945, 42.53542307444981, 42.47283370154244, 45.631318024226594, 40.69342088699341, 37.64725072043282, 38.99497890472412, 40.04808609826224, 40.40534162521362, 42.03867898668562, 39.08534370149885, 34.4888219833374, 34.12795686721802, 34.98086214065552, 35.049221992492676, 32.985739026750835, 34.9187730380467, 34.01934610094343, 33.684790338788716, 35.08300413404192, 34.51089293616158, 34.40995298113142, 33.500267028808594, 33.62420899527413, 35.20670291355678, 34.582455907549175, 33.53171457563128, 35.167935439518516, 40.00489956992013, 42.025762285505024, 39.890935216631206, 40.738841261182515, 40.82842785971505, 41.0055513381958, 42.685622283390586, 46.66138846533639, 45.178052289145334, 41.86820493425642, 41.59154156276158, 38.59270599910191, 35.807419845036094, 33.05115284238543, 32.87817743846348, 32.44896289280483, 32.80068070547921, 34.250939982278005, 34.45512669427054, 35.47617489950997, 40.4306434903826, 46.41828489303589, 44.65326179776873, 40.36943333489554, 45.73657628468105, 44.51921020235334, 44.2570720400129, 43.53161757332938, 42.72236435753958, 43.833676610674175, 45.03712545122419, 44.09348017828805, 43.18200853892735, 40.52906819752285, 39.26177930831909, 36.89145694460188, 36.853696959359304, 38.01412255423409, 38.0703786441258, 38.60919754845755, 41.218253067561555, 40.401947430201936, 43.59360940115792, 42.6044464792524, 41.0446696962629, 39.83507864815848, 44.28601128714425, 44.38146216528756, 50.96801396778652, 47.67067337036133, 51.59107978003365, 6.363707874502454, 0.2837010552840573, 0.5423944581832204, 1.4257475520883287, 33.314632007053916, 46.267943246024, 47.76371322359358, 46.74553115027291, 45.93413094111851, 41.19035257611956, 26.50300373349871, 20.850899526051112, 27.27975501332964, 29.69393961770194, 0.13815602660179138, 0.10362973569759301, 0.037857857133660994, 0.07534625873501812, 0.034944010632378716, 0.09116087441465684, 0.06460329198411532, 0.03389707859605551, 0.053744397525276454, 0.06630357860454492, 0.14447413757443428, 0.03974069681550775, 0.02397780755667814, 0.010264431625338537, 0.02339753458675529, 0.03393406214724694, 0.030750470834651163, 0.04824477959690349, 0.05477435600810817, 0.06102378227348838, 0.05802247260830232, 0.04818318218791059, 0.05310976032965949, 0.040153001834239276, 0.02991679896201406, 0.0018833078710096224, 0.03536760986649564, 0.06122213163013969, 0.020074422903625027, 9.524773018700735, 62.177073751177105, 33.4775116784232, 25.388609954289027, 48.59483242034912, 47.750702721732004, 60.49617944444929, 60.45644269670759, 52.33437374659947, 56.696921825408936, 49.99285166604178, 52.193540709359304, 7.229515518460955, 0.24565790380750382, 0.46289713254996706, 0.3981224426201412, 10.843026944569178, 64.27203900473458, 54.47759771347046, 53.86982141222273, 51.64579336983817, 49.07418169294085, 45.62245559692383, 41.88027742930821, 39.85793822152274, 43.53808287211827, 43.587234428950715, 44.336326667240684, 43.505624362400596, 41.75997631890433, 40.28610358919416, 39.62918267931257, 39.91403102874756, 42.1459869657244, 40.760234764644075, 42.785394941057476, 42.268344742911204, 44.9174496786935, 44.913027150290354, 48.39008290427071, 49.40925856998989, 50.237344878060476, 50.630533014025005, 48.63578510284424, 44.80305453709194, 48.92647341319493, 51.49318313598633, 45.03245278767177, 38.832182611737935, 37.550646441323416, 36.46367025375366, 36.06240831102644, 38.83867570332119, 39.315075465611045, 39.50046035221645, 45.12529114314488, 46.00412361962454, 46.95969894954136, 41.63521793910435, 40.1333543913705, 40.36964178085327, 40.25708096367972, 41.649062224796836, 43.74648714065552, 43.42450066975185, 39.93486172812325, 38.180108070373535, 37.38576916285923, 38.132499013628276, 36.63121911457607, 36.48810011999947, 36.64227022443499, 37.14037615912301, 37.41648367473057, 36.40979044778006, 36.225437368665425, 36.319446495601106, 35.72919007710048, 37.79855121885027, 36.45274421146938, 36.88754163469587, 38.33836024148123, 41.110899925231934, 40.615177222660606, 40.654649938855854, 40.07465253557478, 39.99686745234898, 39.919412408556255, 41.77814933231899, 46.98645298821585, 47.220190388815745, 42.87067365646362, 44.186836174556184, 40.32613216127668, 36.91568531308855, 35.867619037628174, 34.032804761614116, 32.97691828863961, 34.31210844857352, 36.40696600505284, 35.51265294211251, 37.55898775373186, 42.656012535095215, 46.450191020965576, 46.97121211460659, 43.76124858856201, 47.16998617989676, 47.49481793812343, 45.05586126872471, 46.3742333139692, 44.655384472438264, 46.029877117701936, 46.71304832186018, 45.49728379930769, 44.74695825576782, 43.954339027404785, 39.45381014687674, 39.08908183234078, 39.18881280081612, 38.89624500274658, 39.275203227996826, 38.957330090659006, 42.77805764334542, 42.575361319950645, 44.04841068812779, 45.19771916525704, 42.4238315309797, 42.27769007001604, 46.02815743855068, 45.93097645895821, 53.33003323418753, 51.565770966666086, 52.78489146913801, 6.95730767931257, 0.21020937524735928, 0.4365889456655298, 1.6465030035802295, 37.92183310644967, 50.54297181538173, 53.145454338618684, 51.30343130656651, 51.9350642476763, 45.03425237110683, 39.01419414792742, 24.27174609048026, 27.926944971084595, 40.52684129987444, 0.7202743132199559, 0.08087009018553154, 0.053017893473484685, 0.06193436269781419, 0.05463380426434534, 0.010479014084142233, 0.016799565238345946, 0.07263712624886207, 0.028259500927690948, 0.01923979938562427, 0.013683694265117603, 0.10805975512734481, 0.02830034534313849, 0.11234487340386425, 0.0747580367273518, 0.10983073152601719, 0.11384588107466698, 0.12478979597134249, 0.12168969160744122, 0.1113376153100814, 0.13299576778497013, 0.20378480213029043, 0.14718302578798362, 0.1202852191137416, 0.07702654214309794, 0.1553041400121791, 0.2209836428186723, 0.2174098938703537, 0.4316956768078463, 13.48424220085144, 70.39588941846574, 49.092754227774485, 39.80248464856829, 40.27863427570888, 61.146009717668804, 66.86881010872978, 67.14949648720878, 57.76443263462612, 62.4428562436785, 54.35230779647827, 59.60735198429653, 7.9673638343811035, 0.3791895785502025, 0.6517566069960594, 0.3364734649658203, 11.936954804829188, 66.89730467115129, 56.77660724094936, 57.340026242392405, 54.34503303255354, 52.12835618427822, 48.798942702157156, 44.61657530920846, 42.10251556124006, 47.857618127550396, 44.812080247061594, 46.608933040073936, 43.819571767534526, 43.13244703837803, 41.55682488850185, 40.56878410066877, 41.840957573481965, 43.91408463886806, 44.42641006197248, 44.96447508675711, 43.95998791285923, 46.80927392414638, 47.59424665996006, 51.17570604596819, 52.58344234739031, 52.1113087790353, 54.37142923900059, 49.62788363865444, 46.7699818611145, 52.5364898954119, 54.67620849609375, 47.671072891780305, 41.562591893332346, 40.26406042916434, 38.89920146124703, 37.48367622920445, 40.767137799944194, 41.020236355917795, 42.44384581702096, 47.60275820323399, 47.59883941922869, 47.81617212295532, 40.8180958884103, 39.286872727530344, 40.95132759639195, 40.88891887664795, 42.77195017678397, 46.89642170497349, 44.798590319497244, 42.33877168382917, 40.508032526288716, 39.57531329563686, 41.300172328948975, 38.18601403917585, 38.056409290858674, 37.89751788548061, 39.77234683718, 41.20406484603882, 39.6642085484096, 39.222198895045686, 39.488596303122385, 37.142853191920686, 40.26900059836251, 37.42318173817226, 37.71350874219622, 38.74672324316842, 43.58637285232544, 42.079829692840576, 40.561703886304585, 39.952777658190044, 39.48121036802019, 39.70076649529593, 41.51977014541626, 47.809588704790386, 46.978104727608816, 43.51339244842529, 46.37419509887695, 40.85758250100272, 39.79681144441877, 36.720079626355854, 36.6771536554609, 35.18669557571411, 36.817357880728586, 38.015727588108604, 37.752540247780935, 39.8110031400408, 44.748837743486675, 49.32325029373169, 49.42592035021101, 45.66128560474941, 50.32589619500296, 48.50400556836809, 48.21713181904384, 47.9665241922651, 47.23284305844988, 49.781411034720286, 49.837945052555625, 48.854542187282014, 46.28524426051548, 45.80338668823242, 42.81473370960781, 41.48159326825823, 42.01759467806135, 40.01669413702828, 42.19376277923584, 40.35473094667707, 44.503955432346885, 43.87741552080427, 48.15901708602905, 47.52689777101789, 44.0513219833374, 44.90380689076015, 48.57089935030256, 47.87989057813372, 56.92603519984654, 52.43117604936872, 55.30432217461722, 8.204807230404445, 0.24610565549560956, 0.7187728509306908, 2.43127977848053, 41.72199051720755, 56.38559736524309, 55.01014239447457, 57.53299161366054, 55.40950747898647, 53.85328817367554, 37.27424015317644, 31.830441202436173, 37.048757212502615, 50.9466586794172, 2.212939585958208, 0.30236310245735304, 0.18585378144468578, 0.17828247057540075, 0.10325109958648682, 0.14053712811853203, 0.1597742744322334, 0.18593027948268823, 0.22386958795998776, 0.11096398000206266, 0.18039199523627758, 0.14489345864525863, 0.15593576111963817], [0.044640296404915195, 0.05014713733856167, 0.0629669369331428, 0.009737545790682946, 0.04989435590271439, 0.04423310075487409, 0.024816716023321663, 0.03540569942976747, 0.05464112226452146, 0.037684257341814895, 0.04069478490522929, 0.04912897857970425, 0.034910256907876046, 0.022408374718257358, 0.04754140341122236, 0.015016373513000352, 0.08050674146839551, 30.04895782470703, 46.2692460332598, 28.94008265222822, 24.75040749141148, 39.169298785073416, 55.95628554480416, 57.621282373155864, 50.29497671127319, 48.307583468300955, 47.87649290902274, 45.849599157060894, 12.26725913797106, 0.3006406006004129, 0.26299783906766344, 0.15621378405817918, 5.8784917167254855, 63.82306030818394, 54.40853609357561, 53.91753816604614, 52.6001284463065, 49.45350469861712, 47.66949217660086, 47.553002153124126, 40.24673857007708, 38.441360337393625, 39.611322334834504, 38.267401763371055, 40.841629437037874, 38.34867136819022, 38.26945148195539, 37.7427328654698, 37.38171141488211, 40.96280254636492, 39.78381483895438, 42.12785564150129, 43.58825234004429, 45.66474233354841, 48.181056771959575, 45.941044398716514, 49.127356256757466, 49.33420065471104, 50.17694418770926, 46.27688557761056, 44.82000119345528, 48.035349573407856, 47.850141865866526, 41.61813926696777, 37.31051322392055, 35.89686747959682, 33.30129493985857, 34.615675245012554, 37.15299408776419, 36.75260066986084, 37.316516467503135, 41.55116210665022, 43.24588680267334, 46.635697501046316, 44.48251676559448, 39.92756264550345, 40.02137722287859, 43.09515258244106, 43.26340668542044, 36.446574211120605, 33.54464864730835, 35.99553884778704, 35.08845499583653, 34.14923919950213, 34.74618673324585, 35.298023087637766, 35.001338481903076, 35.33871521268572, 34.35083770751953, 33.55148220062256, 32.60802105494908, 34.71020201274327, 34.7622127532959, 34.521256174360005, 33.340090206691194, 34.762681756700786, 35.163057804107666, 34.64303377696446, 33.25824390138899, 36.069453784397666, 40.18025473185948, 40.7140987260001, 40.54487534931728, 40.42460897990635, 40.384778431483674, 45.54680361066546, 46.683667864118306, 42.96752459662301, 41.07348040172032, 39.219628061567036, 36.462926796504426, 34.16936118262154, 34.66455234800066, 32.75677503858294, 31.945274080548966, 33.363665444510325, 34.71716758183071, 34.20815992355347, 40.39911951337542, 43.83005312510899, 44.373013155800955, 42.139132567814414, 40.57723658425467, 42.62954684666225, 43.78006778444563, 41.42980139596121, 42.19187634331839, 43.21012095042637, 41.938551970890586, 40.74293375015259, 39.67264018739973, 38.80360814503261, 35.77500302450997, 36.508486134665354, 37.67626987184797, 36.453133310590474, 35.84632975714547, 38.14627034323556, 37.193317958286826, 36.66453225272042, 36.9290258543832, 38.635319301060264, 40.12782709939139, 43.841455118996755, 48.671762875148225, 46.426247528621126, 52.03860977717808, 46.252719742911204, 47.67057956968035, 5.423272669315338, 0.1960691668625389, 0.37994728503482683, 0.8052425310015678, 33.160329886845176, 48.17465053285871, 47.46281453541347, 43.51465007237026, 53.676414830344065, 35.97618464061192, 20.765186548233032, 20.108347279684885, 37.644012859889436, 15.378420148577009, 0.03393273561128548, 0.055278629663267305, 0.03998282185888716, 0.036385256331413984, 0.06483898790819304, 0.03863647606756006, 0.04573385397504483, 0.058321570844522545, 0.014446268390331949, 0.04624063142442277, 0.03316935996658035, 0.058880961899246485, 0.02494154271802732, 0.06404299847781658, 0.0394282585808209, 0.08389168804777519, 0.01996447308920324, 0.03116632459153022, 0.026934737638969506, 0.02587305425134088, 0.015339191637134977, 0.009838457518656338, 0.03485640836879611, 0.038783775842083354, 0.10162481399519102, 0.02414169242339475, 0.07208897851939712, 0.030016821809113026, 0.02922567372609462, 0.5113920303327697, 38.47106736046927, 51.49111604690552, 17.749416487557546, 36.63828195844378, 50.726894106183735, 58.2202935218811, 62.70937524523054, 53.72408642087664, 53.99950953892299, 51.130080699920654, 52.46064335959298, 12.32867773941585, 0.5212915305580411, 0.1727145207779748, 0.2132457923144102, 7.007207904543195, 65.09668595450265, 56.265605449676514, 57.42490196228027, 54.506999015808105, 52.898438930511475, 48.39654125486101, 48.974089418138774, 42.75907516479492, 38.80832249777657, 41.13794926234654, 41.01741191319057, 42.23860992704119, 40.18727241243635, 39.66131462369646, 40.41691037586757, 41.0433669090271, 41.61456094469343, 42.42247315815517, 45.22222546168736, 46.502094064440044, 48.55398743493216, 49.49577406474522, 47.21021277563912, 51.27414812360491, 51.34846258163452, 51.89330904824393, 46.633800642830984, 47.896625314440044, 52.04070813315255, 48.910478660038535, 43.54406179700579, 38.96844720840454, 37.70415299279349, 36.34395974023001, 37.88597692762102, 38.17576544625418, 39.53591700962612, 39.450864110674175, 42.183218887874055, 44.66245773860386, 50.50647292818342, 43.281968797956196, 39.86423676354544, 41.059458936963765, 43.60842643465315, 43.727688789367676, 42.09275681631905, 37.0804305757795, 37.01768486840384, 36.510587964739116, 36.45089946474348, 36.07723924091884, 36.58731344767979, 36.27072920118059, 37.62474203109741, 36.36082649230957, 36.08662278311593, 35.74119309016636, 36.77289635794503, 35.00443737847464, 36.15147379466465, 34.9492825780596, 35.628962312425884, 35.71980653490339, 36.36544009617397, 34.762278761182515, 39.07476854324341, 40.86410338538033, 40.22776651382446, 39.90239627020699, 40.34047671726772, 40.19920594351632, 44.85224778311593, 46.87832859584263, 43.89361524581909, 41.88459573473249, 40.46494327272688, 37.780725615365164, 35.98894848142351, 36.261453356061665, 34.30195713043213, 34.91698040281023, 35.60914952414376, 36.39679731641497, 35.64196586608887, 42.19851187297276, 45.86864416939871, 46.922366278512136, 45.45039735521589, 43.810566902160645, 45.99341644559588, 46.78032078061785, 43.30958093915667, 44.62685169492449, 44.355878898075645, 44.34974363871983, 42.90623801095145, 41.21267018999372, 40.09489958626883, 38.45099401473999, 37.2459887777056, 39.517195088522776, 38.168942315237864, 37.83596379416329, 38.99666384288243, 38.42345135552542, 37.92439004353115, 38.90786239079067, 39.97834355490548, 41.36408185958862, 44.679234164101736, 50.60542222431728, 48.58192266736712, 54.8056013243539, 49.449686663491384, 49.56236212594168, 6.2566960624286105, 0.31272571640355246, 0.41161844985825674, 0.8413587244493621, 37.52561208180019, 51.22677183151245, 52.84371491840908, 47.226235321589876, 58.15230539866856, 40.468611921582905, 30.190284184047155, 18.133903741836548, 42.41020611354283, 20.67052255358015, 0.024506235362163613, 0.04369784179808838, 0.018724031347249235, 0.09593852090516261, 0.03140145054619227, 0.03012359268697245, 0.015495911174054657, 0.02555041084997356, 0.05318052813942943, 0.04271062762875642, 0.043050119054636786, 0.013441582792438567, 0.022136377170681953, 0.15249879126037869, 0.16740391217172146, 0.14778921540294374, 0.07826351148209401, 0.23961153253912926, 0.15709723665245942, 0.112596216345472, 0.16643277928233147, 0.19555639794894628, 0.10877619311213493, 0.1391823243881975, 0.15598628483712673, 0.15138830084885868, 0.11801576374896935, 0.13760519187365258, 0.1883964692907674, 0.6909862448062215, 47.66320058277675, 57.74752419335501, 38.532572814396445, 34.94929994855608, 51.02200494493757, 64.57188156672886, 67.41662693023682, 59.385329246520996, 58.968374797276084, 58.35133307320731, 55.989220006125315, 14.494916745594569, 0.5152593542422567, 0.43107289022633005, 0.41964834183454514, 8.267515591212682, 69.21300029754639, 59.62975992475237, 58.423636027744834, 57.1424993787493, 55.74910068511963, 50.14822728293282, 52.908430440085276, 45.16212701797485, 41.745892320360454, 43.258633272988455, 43.748234612601145, 45.23292916161673, 42.224439076014924, 42.83987576620919, 43.35170439311436, 42.30911677224295, 44.719269684382844, 44.82848146983555, 47.17935235159737, 49.909341267177034, 51.9731890133449, 52.37595524106707, 50.0425625528608, 53.95828587668282, 54.64142581394741, 54.70960848672049, 48.06570277895246, 48.30958454949515, 53.62563739504133, 52.845212255205425, 46.26336438315255, 41.13024023600987, 39.202167238507954, 38.53063774108887, 39.953892844063894, 41.80186006001064, 41.703515257154194, 41.17077602658953, 43.93012802941458, 46.24407270976475, 51.931319168635774, 46.14756570543562, 41.24072354180472, 40.69172552653721, 44.39312819072178, 47.981931822640554, 43.113686902182444, 38.50958122525896, 39.63847936902727, 39.51651416506086, 38.61053160258702, 37.92186089924404, 38.919517993927, 38.55337224687849, 39.67408193860735, 38.7862480708531, 37.95903723580496, 36.90978281838553, 39.16726296288626, 40.44218444824219, 38.81997462681362, 37.23075137819563, 37.891785621643066, 37.09876339776175, 37.99055079051426, 36.046326705387656, 39.24043444224766, 41.24610492161342, 39.57034533364432, 40.674612113407676, 39.73163734163557, 39.315916197640554, 46.423367500305176, 48.28538744790213, 45.109536102839876, 45.60270881652832, 41.85787991115025, 39.90061058316912, 37.01071235111782, 38.65706021445138, 37.62025696890694, 36.272035462515696, 38.43042387281145, 39.276693616594585, 38.40849188395909, 44.68259709221976, 47.490127904074534, 48.78200994219099, 47.89300877707345, 45.04640129634312, 46.53998953955514, 50.38122122628348, 45.97967638288225, 47.4526423726763, 47.13044398171561, 45.96351834705898, 45.18993023463658, 43.82591199874878, 42.430835315159385, 40.70763342721121, 39.41621344430106, 41.634363310677664, 39.89960309437343, 38.99955081939697, 41.61238268443516, 40.897232396262034, 39.32873214994158, 40.419533320835654, 40.448201588221956, 43.581387519836426, 48.37999759401594, 53.608593463897705, 51.90546492167881, 58.7912791115897, 51.56849813461304, 50.99685594013759, 6.8994899817875455, 0.403784627360957, 0.5568885632923671, 1.8581917073045457, 42.279586928231375, 58.553185190473286, 57.472382477351594, 53.04634870801653, 62.86096409388951, 47.5091347013201, 32.3208589553833, 27.928926944732666, 52.00960104806082, 30.446287087031774, 0.13199351727962494, 0.1728537290224007, 0.12108570044594151, 0.3041011834783213, 0.14739114604890347, 0.20216694394392626, 0.06220623810908624, 0.09539220522024802, 0.13717814907431602, 0.1465429908462933, 0.09776565286197833, 0.11542750549103532, 0.13439648119466646], [0.06158351259572165, 0.12121916828410965, 0.010377344093285501, 0.03015779085191233, 0.034417460672557354, 0.07193367542432887, 0.021911078099427477, 0.017574623559734652, 0.038508436509541104, 0.08230490676526513, 0.055795239085065465, 0.12163972428866796, 0.057764866788472445, 0.09396234194615058, 0.09644689291183438, 0.08387902658432722, 0.028588098473846912, 8.073403767177037, 49.76766054970877, 36.722066811152864, 29.62232106072562, 29.777140821729386, 44.57918010439192, 56.18573243277413, 47.795011384146555, 48.72024393081665, 46.029147556849885, 46.24582018171038, 10.118000660623823, 0.2194690712328468, 0.4517001105206353, 0.2546551967305796, 6.253062154565539, 62.10848808288574, 54.64404875891549, 56.1723884173802, 56.1935248374939, 53.39583962304251, 52.53021567208426, 48.70381838934762, 47.90716225760323, 41.79344926561628, 37.326799801417756, 40.20609508241926, 41.99557931082589, 41.310257639203755, 39.03628594534737, 39.19416291373116, 37.189562456948416, 38.762954235076904, 41.16132647650582, 44.976491996220176, 44.083738803863525, 47.08889375414167, 51.23899023873465, 51.305838857378276, 49.91892283303397, 52.04778487341744, 46.94213042940412, 44.86425427028111, 49.60910613196236, 51.82383401053292, 45.37863288606916, 38.838151114327566, 36.3156110899789, 35.67325707844326, 34.394958768572124, 35.76732873916626, 37.81163815089634, 38.77248021534511, 39.740277426583425, 38.9122189113072, 42.099569525037495, 48.390961851392476, 47.88553598948887, 45.42185762950352, 43.62846851348877, 39.30691828046526, 33.87272868837629, 33.958128997257774, 35.71143395560128, 33.70764296395438, 34.20147575650896, 34.55242926733834, 35.540261609213694, 33.242798055921284, 35.15421969549996, 34.29253189904349, 33.930287565503804, 33.82556779044015, 35.18690749577114, 34.57735940388271, 33.049606868198936, 34.29420641490391, 34.50461176463536, 33.71803052084786, 33.8555075781686, 34.61383744648525, 34.388854776109966, 34.41049146652222, 35.48599617821829, 38.06222145898001, 40.9206235068185, 40.344520568847656, 41.02782031467983, 46.01882600784302, 48.805005005427766, 41.89717892238072, 39.89174468176705, 38.034525939396445, 37.89517286845616, 35.32158442905971, 36.49512822287423, 34.54121487481253, 33.20215456826346, 33.468642302921836, 33.673304966517854, 32.576497077941895, 35.30057307652065, 41.08036606652396, 43.53110688073294, 44.88965688432966, 46.0979243006025, 42.06099312646048, 42.80232770102364, 43.0672208241054, 43.55141993931362, 41.19304847717285, 40.44568286623274, 39.01197419847761, 38.16406467982701, 35.72184930528913, 37.69013500213623, 36.08997181483677, 37.218640668051584, 37.517451422555105, 37.973023959568565, 37.506553173065186, 38.25563498905727, 38.22897475106375, 40.716381209237234, 36.52436971664429, 45.1531777381897, 47.419082573481965, 50.972624097551616, 47.428181239536826, 52.58919892992292, 42.64558676310948, 42.33830268042428, 5.2656393221446445, 0.11533217132091522, 0.33734079556805746, 1.4883810026305062, 45.07207836423601, 45.134035451071604, 47.48616395677839, 49.77613387789045, 50.26865346091134, 27.47456513132368, 36.244576181684224, 33.204680238451274, 34.404710565294536, 0.551371476479939, 0.11188447382301092, 0.043673302579138956, 0.0016117345138419686, 0.06422609436724867, 0.04330056293734482, 0.06377383042126894, 0.04824689323348658, 0.04733172251975962, 0.0015764587504755972, 0.0732076181364911, 0.05796111947191613, 0.012530675823135036, 0.07988602441868611, 0.08722782081791333, 0.05973433503615005, 0.030000852487449135, 0.0735203752826367, 0.006938697828445584, 0.044459147910986624, 0.038701537397823164, 0.027291340021682636, 0.015348195796832442, 0.05377214282218899, 0.05972567692931209, 0.06905245967209339, 0.040256678592413664, 0.06801259118531432, 0.0527928268004741, 0.16979638593537466, 0.0686124229271497, 11.631760392870222, 59.35402761186872, 28.22716620990208, 27.92579504421779, 47.46427365711757, 48.27547236851284, 61.31690066201346, 53.191934313092915, 54.64651884351458, 50.40370907102312, 50.617560727255686, 10.548592686653137, 0.2736137637070247, 0.46588724638734547, 0.23064208669321878, 7.558300801685878, 65.18287140982491, 57.53032003130232, 57.7910338129316, 58.974850518362864, 56.34982109069824, 54.07967785426548, 51.59599215643746, 48.90601096834455, 44.7842492376055, 38.489264692579, 40.811147689819336, 42.89043433325631, 42.04180915015084, 39.284437383924214, 40.56129741668701, 38.722564356667654, 42.40033272334507, 42.46674707957676, 46.54828916277204, 46.26838098253523, 50.30591664995466, 52.0669584274292, 51.64755473818098, 50.70059517451695, 53.860729694366455, 49.034424100603374, 46.352002552577424, 50.760335786002024, 54.012895243508474, 48.071678229740684, 40.78525522777012, 38.89536605562483, 37.326636518750874, 35.94147491455078, 38.08303826195853, 39.60513148988996, 41.08230808803013, 41.85711213520595, 43.36159862790789, 45.587287289755686, 48.88675403594971, 48.87888867514474, 45.44761112758091, 46.12310109819685, 42.91595506668091, 38.78193323952811, 35.561047145298545, 36.269666126796174, 35.77100086212158, 38.39463370186942, 36.30199262074062, 36.89774506432669, 36.48576899937221, 38.61289051600865, 37.15196575437273, 35.68742445537022, 35.48269925798689, 37.57234566552298, 35.90772403989519, 35.75623941421509, 35.893730367933, 35.95583684103829, 35.00773082460676, 36.135138579777305, 35.71006863457816, 35.55133703776768, 35.88848100389753, 36.786674635750906, 39.46247107642037, 41.35012640271868, 41.70367506572178, 41.34326158251081, 44.43316371100289, 47.64843913487026, 42.30051142828805, 42.12852266856602, 39.32014070238386, 37.9006723676409, 37.36510174615042, 36.81961604527065, 35.60437611171177, 35.13502182279314, 35.385094438280376, 36.57684251240322, 34.533526693071636, 39.08610452924456, 43.5976219858442, 45.82260193143572, 46.962582451956614, 47.60087524141584, 45.38529968261719, 44.88867024012974, 44.2144900049482, 44.80243614741734, 45.10462372643607, 43.23705564226423, 40.703975200653076, 41.05504335675921, 38.98071077891758, 40.78451524462019, 38.719812870025635, 39.88214921951294, 38.041230951036724, 39.60044840403965, 38.82793378829956, 39.67451272691999, 39.42697967801775, 41.97677401133946, 38.60385090964181, 45.538834026881624, 50.68686900820051, 53.88869966779436, 50.8365193094526, 56.07126086098807, 45.61639676775251, 45.162623814174104, 5.834227783339364, 0.05304360655801637, 0.40647078465138164, 1.5937465259007044, 49.67936979021345, 50.12060819353376, 53.01594686508179, 55.39131014687674, 53.83790486199515, 36.005988938467844, 44.10045269557408, 30.172795568193706, 43.65754325049264, 1.0202298377241408, 0.1555601241333144, 0.03815524546163423, 0.03619093747277345, 0.11246310813086373, 0.020570170766274844, 0.051872295660099814, 0.017632872398410524, 0.03294882590749434, 0.02883678495085665, 0.030774569005838463, 0.04370107841012733, 0.026763514416026216, 0.0617538791682039, 0.1672562900930643, 0.2736573527966227, 0.1319945486528533, 0.1335125807672739, 0.09012342151254416, 0.12576183809765748, 0.147552827373147, 0.09918980287121874, 0.0909021965094975, 0.2795845461743218, 0.12155672588518687, 0.17323304366852554, 0.1046863639993327, 0.18175453426582472, 0.22268625002886566, 0.3817058578133583, 0.15708560656223977, 15.12185617855617, 68.96982724325997, 45.520365715026855, 40.26660346984863, 40.29254456928798, 56.47211980819702, 65.73182773590088, 59.38168144226074, 58.098105975559776, 55.95198808397566, 57.385596002851216, 12.940043653760638, 0.33256844165069716, 1.005864979965346, 0.33148009862218586, 8.975882700511388, 66.84654808044434, 60.50922121320452, 59.81810474395752, 62.58926868438721, 57.722281387874055, 57.7368552344186, 53.447475160871235, 52.27953856331961, 46.75030108860561, 40.14917891366141, 44.427990777151926, 45.94395916802542, 44.56081601551601, 43.17693982805525, 44.660564354487825, 41.93040173394339, 43.55655813217163, 45.26201432091849, 50.23636170795986, 49.18217406954084, 52.277329036167686, 54.22361673627581, 55.23549679347447, 53.453777176993235, 56.674694538116455, 50.533147062574116, 48.866017137254985, 52.99100978033883, 57.01688984462193, 49.30929136276245, 43.838641098567415, 40.87254892076765, 40.66103185926165, 37.94360876083374, 40.29771402903965, 42.809192521231516, 43.63479137420654, 44.244652135031565, 45.090807233537944, 47.84398923601423, 52.50486516952515, 51.584367820194785, 47.29205213274275, 49.11806998934065, 46.09210518428257, 39.35672296796526, 37.82298455919538, 38.85409723009382, 38.90178619112287, 40.04574108123779, 38.37863894871303, 39.395354952131, 37.56178787776402, 39.82971811294556, 38.71827036993844, 38.50464105606079, 37.131020409720286, 39.16219425201416, 37.978092670440674, 35.08397340774536, 37.764320918491904, 36.782095772879465, 36.451924324035645, 37.26785823277065, 38.65018149784633, 37.4095458984375, 37.94015203203474, 39.24258838381086, 40.84106663295201, 41.36896991729736, 42.770303453717915, 40.977616105760845, 46.16405725479126, 50.47764832632882, 44.88807964324951, 43.408426012311665, 41.57443162373134, 40.16128614970616, 39.94737890788487, 39.59981959206717, 38.42884315763201, 37.40064525604248, 38.44827726909092, 38.600470611027305, 36.44845369883946, 39.30271462031773, 44.78455148424421, 47.94005502973284, 47.99068307876587, 49.752812249319895, 48.966012137276785, 47.286441462380544, 48.16818870816912, 47.130596842084614, 46.68533543178013, 44.65269204548427, 43.36753238950457, 41.79286561693464, 41.134457792554585, 42.10103212084089, 40.77035481589181, 40.24323320388794, 41.458615575517925, 41.41974040440151, 40.58631787981306, 40.90244007110596, 42.01833813531058, 43.91310494286673, 40.34537172317505, 47.686577796936035, 53.907411166599815, 55.778807708195274, 53.06694316864014, 57.430217334202354, 47.74465084075928, 46.41430357524327, 7.407474517822266, 0.1838803980499506, 1.1199128202029636, 1.876226625272206, 55.43435076304844, 54.248293263571604, 59.14221177782331, 57.27336869921003, 62.197828020368306, 38.34441907065255, 51.464591298784526, 44.29876817975725, 52.63066577911377, 4.272363066673279, 0.3866465969809464, 0.22224035752671106, 0.17858067314539636, 0.20759050148938382, 0.12045249156653881, 0.16014360104288372, 0.21747860232634203, 0.10473953400339399, 0.06581539301467793, 0.12943830367709908, 0.14555995645267622, 0.12644691419388565, 0.1268986285265003], [0.022496146615594625, 0.03616907846714769, 0.147002603326525, 0.04108139380280461, 0.03949440556711384, 0.049514444145773134, 0.01963419107986348, 0.06979105861059257, 0.027234351561803902, 0.059260072984865735, 0.09600511911724295, 0.04842678643763065, 0.059034086896904876, 0.026896834672827805, 0.022358711043904935, 0.08607169214103903, 0.09261149407497474, 0.30963566792862757, 31.211134365626744, 46.395803996494834, 35.81532689503261, 30.54796702521188, 34.186214038303916, 56.58282893044608, 54.51635129111153, 48.68964753832136, 43.60345152446202, 46.70017678397042, 10.806362169129507, 0.5064672231674194, 0.8850672362106187, 0.36967773895178524, 6.654771821839469, 57.77937126159668, 50.99717903137207, 56.995843751089915, 55.23451362337385, 54.88168062482561, 49.94312688282558, 54.45656551633562, 53.317335401262554, 49.235848903656006, 41.97673579624721, 36.46315261295864, 38.933060032980784, 39.38922316687447, 39.82023729596819, 39.32526499884469, 37.52993386132376, 39.96822350365775, 41.083169664655415, 42.20803785324097, 45.63912085124424, 48.77073648997715, 48.65828684398106, 49.703434876033235, 51.118289606911794, 46.37084606715611, 46.07460962023054, 50.40339987618582, 53.57867799486433, 47.506772313799175, 41.525012561253135, 36.98718575068882, 37.252770219530376, 34.60812950134277, 35.81575420924595, 35.79018483843122, 34.84915903636387, 40.258248261043, 40.256657123565674, 37.85748931339809, 43.55202095849173, 43.661462034497944, 44.429019110543386, 40.91953263963972, 37.1871931212289, 35.230972971235005, 35.456553186689106, 35.48299108232771, 35.028613635471885, 34.71373169762747, 34.81614119665963, 34.08593763623919, 35.39968565532139, 34.936807087489534, 35.228732177189414, 34.69602768761771, 35.01369932719639, 35.09099108832223, 35.577573435647146, 34.46648352486746, 33.79825094767979, 34.31721884863717, 33.683536188943044, 36.5607122693743, 35.001526083265034, 35.459662505558555, 35.19672877447945, 33.8592700277056, 35.14845963886806, 32.85984461648123, 36.48237827845982, 39.79783282961164, 41.972090925489155, 46.94858877999442, 45.505281175885884, 40.294424057006836, 38.741508620125906, 37.00373983383179, 39.01709502083914, 36.219691208430696, 35.67874615533011, 35.16392285483224, 31.87736586162022, 33.27029207774571, 34.487974303109304, 33.479505811418804, 34.79853446143014, 37.83163159234183, 41.6193447794233, 43.00822714396885, 47.48340899603707, 43.51665462766375, 45.279214586530415, 42.336107049669536, 43.34453732626778, 39.27563401630947, 39.516541957855225, 36.996784687042236, 35.43390553338187, 33.42827674320766, 34.87251888002668, 35.37119804109846, 36.07638808659145, 35.25230394090925, 36.790520463671, 36.34195518493652, 38.15654672895159, 36.56116042818342, 39.86633511951992, 38.04775183541434, 48.70481892994472, 50.631776741572786, 53.53139550345284, 47.374416078839985, 53.617924894605366, 43.68468638828823, 40.729999678475515, 4.356191345623561, 0.3613801784813404, 0.1650370598903724, 1.9448294469288416, 42.90495606831142, 46.52820539474487, 44.27389015470232, 53.02781438827515, 40.87346955708095, 24.825864928109304, 21.85137411526271, 30.668514796665736, 19.037199088505336, 0.06775222372795854, 0.05340834966461573, 0.03988868869575007, 0.04435973235272935, 0.05691385156075869, 0.038963686009602885, 0.04279461669336472, 0.04932297174153583, 0.046296912511544566, 0.03754296938755682, 0.10204574319400958, 0.06322794899876628, 0.06253120210021734, 0.10682203939982823, 0.008134091206427132, 0.0908385431393981, 0.03145959760461535, 0.026260002416425517, 0.016536585421168377, 0.08713108208030462, 0.029137325073991503, 0.052433359303644726, 0.02545211317815951, 0.06643445443894182, 0.0742379328502076, 0.025092655859355415, 0.016781619683440243, 0.046509093804551024, 0.01558488407837493, 0.060195073884512694, 0.042297569436154196, 0.6381315152559961, 40.22569942474365, 50.092217854091096, 26.671679939542496, 41.943012714385986, 44.005439553942, 61.2815899167742, 60.58279568808419, 53.84590571267264, 48.52654899869646, 51.40453107016427, 13.017501303127833, 0.7189865080373627, 0.6771790885499546, 0.5113017037510872, 7.989578093801226, 61.160941396440776, 53.18260635648455, 59.893999917166575, 57.50338533946446, 56.8651168687003, 52.0026285307748, 55.56620325360979, 54.892075129917686, 50.392699650355745, 43.49344417027065, 39.59700557163784, 40.85053702763149, 40.13666868209839, 39.81747191292899, 42.04200369971139, 40.23328685760498, 41.37639059339251, 42.83962563105992, 44.41759974615914, 47.89511060714722, 49.74034718104771, 52.438784326825825, 52.93544503620693, 52.14145701272147, 47.85679824011666, 47.909569808415, 51.371822425297324, 54.51494080679757, 49.1683714730399, 42.34164476394653, 39.20361941201346, 39.03439950942993, 37.28099380220686, 38.01367439542498, 38.225445066179546, 39.44402708326067, 43.68439456394741, 42.29511615208217, 40.75125421796526, 46.32372338431222, 45.32850163323538, 47.35489511489868, 45.15211813790457, 40.803532464163645, 38.60453878130232, 39.202243668692454, 37.941631998334614, 36.69911691120693, 37.95545891353062, 37.756323541913716, 37.43424327032906, 37.08373097011021, 36.74323102406093, 38.904565470559255, 36.936019216264995, 37.53308834348406, 37.368704387119834, 38.25585733141218, 36.045624937329976, 35.24113471167428, 35.883596420288086, 34.977797985076904, 39.38909809929984, 36.887270654950825, 34.55595200402396, 36.08570214680263, 35.76072447640555, 36.730463709150044, 34.17836604799543, 37.68513229915074, 40.71352549961635, 43.12633262361799, 47.090575218200684, 46.90938009534563, 42.766787665230886, 39.597714287894114, 38.64718682425362, 39.651851177215576, 37.97610201154436, 37.70586919784546, 35.6122727394104, 35.26128101348877, 35.594422817230225, 36.11755963734218, 35.713754653930664, 36.684612546648296, 40.41083765029907, 45.33397681372506, 44.63728094100952, 48.62755148751395, 46.71589013508388, 46.60359682355608, 43.71242707116263, 44.513609954289024, 41.71822459357125, 40.92535523005894, 38.6372925894601, 38.22985022408621, 35.99117190497262, 36.809225014277864, 36.17646993909563, 37.88882221494402, 37.36340291159493, 39.39900623049055, 38.05944217954363, 39.40309524536133, 37.469918795994346, 41.08790833609444, 39.40237610680716, 51.777823039463584, 52.456721101488384, 55.2970404624939, 49.64240884780884, 56.788016183035715, 46.0566520009722, 46.594508579799104, 4.460063440459115, 0.27039387077093124, 0.07909891701170377, 2.4004084978784834, 46.69914150238037, 54.003101757594514, 49.67494378771101, 58.106732164110454, 45.628986903599326, 34.72467163630894, 25.87523225375584, 32.468869481767925, 25.79001954623631, 0.027326720533892512, 0.026882341164829474, 0.05949773666049753, 0.052009631147874255, 0.09128752297588758, 0.07403318490833044, 0.059005934478981156, 0.07050193260822978, 0.040228393860161304, 0.02921959405232753, 0.08630004631621496, 0.0576633308082819, 0.017469811951741576, 0.06548890910510506, 0.1471168686236654, 0.1738846001348325, 0.20843416479017052, 0.12786148328866276, 0.14353381017489092, 0.16857960979853356, 0.0739875737843769, 0.20893899484404496, 0.10170592607132026, 0.13253079487809113, 0.18511932156980038, 0.2839346341788769, 0.10134303197264671, 0.1503186582454613, 0.11698238205696855, 0.16888489627412387, 0.20313061294811113, 0.738690079322883, 51.58427054541451, 58.84134783063616, 44.775567463466096, 42.40850380488804, 45.09692164829799, 66.85357270921979, 64.86048889160156, 60.90128026689802, 54.18547807421003, 58.629372188023154, 15.321978194372994, 0.8597578800150326, 1.8388900458812714, 0.6254737430385181, 9.788898365838186, 62.00612722124372, 55.18690456662859, 62.362083435058594, 60.44127477918352, 57.615838459559846, 53.73811135973249, 58.28129175731114, 57.75649431773594, 52.54949344907488, 46.76702887671334, 39.48276329040527, 42.274921212877544, 42.189222131456646, 43.354872771671836, 44.84471246174404, 42.89786890574864, 45.450234072549, 46.4215852873666, 47.526710169655935, 51.12699917384556, 53.63405166353498, 54.52712794712612, 54.94155672618321, 54.191352776118684, 49.0707597051348, 50.210726329258506, 54.83484281812395, 57.29338298525129, 51.137199129377095, 45.532875946589876, 40.732563563755576, 41.86390399932861, 39.152188846043174, 41.81973777498518, 39.698411055973594, 40.48922375270298, 45.730461869921, 43.800530229296, 42.50064386640276, 48.98399060113089, 49.233549049922395, 48.33163813182286, 45.42836461748396, 42.02789885657174, 40.108830724443706, 40.90138741901943, 40.51682547160557, 39.78544766562325, 40.86301251820156, 41.011943680899485, 38.79356452396938, 40.733925410679404, 41.450562613351, 41.41299370356968, 38.48044395446777, 37.70450735092163, 39.76960577283587, 40.80526603971209, 37.30460378101894, 35.37092706135341, 37.89305714198521, 35.883287225450786, 41.351158210209434, 38.37111404963902, 36.95826734815325, 39.003334113529746, 37.39925561632429, 38.095760413578574, 35.48052447182791, 40.19442558288574, 40.62785768508911, 43.80207967758179, 48.79765033721924, 46.89344440187727, 45.33767325537545, 42.42567975180489, 42.13147912706648, 41.89113746370588, 40.07900210789272, 39.30485119138445, 38.99918256487165, 36.98269721439907, 38.215516090393066, 38.10351807730538, 37.877600874219624, 39.93374654224941, 42.46242182595389, 46.966466494968955, 48.16701446260725, 51.7077956199646, 47.21782452719552, 50.44602012634277, 45.544462067740305, 47.44330399377005, 45.328411306653706, 44.478591033390586, 41.5354973929269, 40.08082601002285, 38.56723737716675, 39.17079612186977, 39.28912394387381, 39.56319563729422, 39.465305941445486, 40.14881760733468, 39.920218399592805, 40.01399476187569, 40.425331592559814, 42.59817573002407, 40.65731804711478, 53.209693908691406, 55.94970907483782, 58.07748024804251, 50.84517329079764, 58.44457789829799, 46.18085452488491, 44.41157913208008, 5.6239718198776245, 0.4172741478042943, 0.7466230764985085, 2.95957151055336, 53.95433929988316, 57.805659770965576, 55.32089362825666, 62.695075852530344, 50.88768236977713, 36.2540465763637, 34.31270946775164, 42.969786235264365, 36.92575325284685, 0.23897072406751768, 0.12829560999359402, 0.12104132425572191, 0.19798157710049832, 0.32945288025907105, 0.11599283372717244, 0.10066144354641438, 0.17095486234341348, 0.1371175151850496, 0.15184864614691052, 0.20605101409767354, 0.17849041441721575, 0.08939211682549544, 0.23036063036748342], [0.05663355892258031, 0.052050339856318066, 0.04431784638602819, 0.03860445939270513, 0.041064807014273744, 0.083921007545931, 0.013965811314327376, 0.010211290459015539, 0.015984844848779694, 0.033417483259524615, 0.02578949605646942, 0.07115816418081522, 0.0335287901439837, 0.06638882295893771, 0.046022713117833645, 0.028714689359601055, 0.17150094732642174, 0.09891673323831388, 6.971847219126565, 47.28460366385323, 33.4911162512643, 33.28703376225063, 29.848634311131068, 42.45813478742327, 47.31908409936087, 51.890488079616, 48.089208534785676, 49.87953002112252, 13.680789368493215, 0.29877739772200584, 0.6853003927639553, 0.14654407650232315, 7.781246781349182, 58.655691964285715, 51.3222713470459, 58.04324647358486, 54.441501821790425, 55.15464408057076, 52.61131852013724, 52.509082726069856, 53.60094002314976, 54.29922703334263, 49.85652800968715, 42.31442519596645, 38.35732882363455, 38.22682080950056, 37.48659447261265, 37.50778995241438, 37.51421703611101, 39.39511523927961, 37.27589382444109, 40.04561253956386, 39.24928992135184, 43.336546897888184, 48.38851955958775, 46.425451959882466, 46.05205576760428, 49.89950956617083, 52.92187173025948, 50.311871256147114, 46.01274980817522, 39.433757645743235, 37.08994613374983, 37.92082214355469, 36.43723235811506, 34.4985807282584, 35.131189891270225, 37.356607573372976, 37.308456557137625, 42.68382269995553, 39.92509603500366, 37.38636670793806, 40.71816689627511, 42.16326366152082, 40.27557359422956, 36.03448002679007, 36.311264991760254, 35.23034415926252, 35.537662982940674, 35.273273604256765, 34.45524133954729, 34.37839078903198, 33.374848570142476, 36.811062812805176, 34.711786202022004, 34.19271060398647, 32.36586243765694, 34.62203632082258, 35.10907030105591, 34.63259758268084, 36.68468202863421, 35.07621921811785, 35.31940616880144, 35.54489605767386, 34.96434279850551, 35.746400765010286, 33.58147757393973, 33.452640601566856, 34.86091538837978, 33.44416379928589, 34.242226941244944, 34.50529963629586, 33.90280049187796, 35.96354239327567, 36.278466020311626, 39.45640182495117, 45.90605674471174, 41.435797691345215, 38.98038073948452, 37.30876227787563, 39.1137375150408, 37.690225328717915, 34.5345515523638, 34.04889678955078, 34.30055706841605, 31.783332415989467, 33.58048398154122, 33.83931827545166, 34.405943870544434, 35.15692254475185, 38.687062535967144, 41.74390513556344, 42.11107226780483, 41.32194798333304, 41.281116894313264, 41.622120584760395, 40.925077302115305, 37.88181495666504, 37.989765644073486, 36.56266123907906, 35.515102182115825, 34.0773983001709, 36.16309813090733, 34.66487543923514, 37.14166504996163, 36.41096469334194, 37.74940661021641, 36.43464762823922, 39.0055262701852, 35.36354112625122, 42.14398241043091, 35.95026438576834, 49.76554829733712, 50.33031872340611, 56.04233203615461, 47.545404297964915, 56.38478790010725, 44.7636513028826, 50.84393998554775, 4.1080416440963745, 0.1932669258011239, 0.1611302588135004, 2.0411670889173235, 42.52684899738857, 45.74775941031319, 46.16142041342599, 51.151123319353374, 31.824677671704972, 30.99904407773699, 33.73369523457119, 28.680166176387242, 5.382064640522003, 0.3381348172468798, 0.0646821241825819, 0.052425929345190525, 0.026907597934561114, 0.049126847979745696, 0.06379398969667298, 0.056937786883541515, 0.06098334837172713, 0.07137159058558089, 0.006925385395464088, 0.0010431012820585497, 0.05117356065394623, 0.07519759171243225, 0.03377260473955955, 0.05881510329033647, 0.053199523727276495, 0.05298771902120539, 0.06603850211415972, 0.10470521370215075, 0.05941720133913415, 0.03418965611074652, 0.06976354401558638, 0.051094046527785916, 0.020509168771760802, 0.05244571203365922, 0.09240422876817839, 0.027682834371392216, 0.025788318798212067, 0.08399613494319574, 0.044602881983986924, 0.08386434987187386, 0.035797071643173695, 10.31628314086369, 58.987656048366, 28.660608734403336, 31.45034694671631, 44.477065903799875, 48.86922025680542, 57.66985375540597, 56.12474809374128, 51.320537771497456, 54.74286951337542, 16.950661999838694, 0.29956381980861935, 0.7857949031250817, 0.5767700736011777, 10.274203981672015, 62.8005564553397, 52.76223339353289, 60.71149022238595, 57.04699638911656, 56.31363139833723, 53.938480036599294, 55.11305216380528, 55.05337061200823, 56.76702914919172, 50.93704237256731, 43.74736956187657, 40.95133454459054, 40.26496022088187, 38.46202775410244, 40.26022154944283, 38.797194957733154, 41.221237318856375, 40.09750863483974, 42.314918518066406, 44.304368427821565, 47.06001704079764, 51.05743728365217, 49.488207476479666, 50.31286137444632, 51.005971976688926, 53.63541351045881, 54.039635385785786, 48.31297527040754, 43.3686649458749, 39.6760448047093, 39.927354199545725, 38.150883947099956, 37.76690217426845, 37.526473658425466, 40.07459347588675, 39.93286412102835, 45.1680121421814, 42.66538565499442, 40.20426770618984, 43.6266758782523, 43.2067163331168, 42.92406014033726, 39.09616552080427, 39.51773009981428, 38.68589523860386, 38.306530543736045, 36.978955609457834, 37.73955406461443, 37.27085638046265, 38.04867941992623, 38.94393743787493, 38.6231495312282, 37.006018842969624, 36.164140360695974, 36.773038796016145, 37.565036160605295, 37.4622688293457, 38.10843045370919, 38.682306494031636, 37.45656783240182, 37.584303515298025, 36.61722196851458, 36.11732339859009, 36.19350344794137, 35.79610817773001, 36.62321131569998, 33.68284484318325, 36.52832324164254, 35.19723946707589, 35.85243374960763, 36.39889914648873, 37.205442564828054, 40.56393425805228, 46.1812401499067, 41.71264866420201, 41.09359891074044, 38.138081891196116, 39.65196234839303, 38.8560323034014, 35.97924879619053, 35.943774768284385, 34.09874664034162, 34.7022636958531, 36.253709588732036, 35.927689688546316, 37.01013912473406, 37.31355653490339, 40.108615330287385, 43.10428598948887, 44.47618695667812, 43.63176890781948, 43.93179907117571, 42.78982441765921, 43.45833144869123, 40.364243030548096, 38.88073314939226, 36.59495299203055, 38.145481722695486, 35.52396808351789, 38.24697058541434, 36.482315744672505, 39.6065628187997, 37.279541628701345, 39.80032723290579, 37.0622957774571, 39.978409562792095, 37.56425796236311, 42.77096005848476, 39.24656970160348, 50.7982451575143, 51.32672166824341, 58.358913557870046, 49.96926948002407, 56.96752984183175, 45.85762432643345, 54.783314977373394, 4.927323716027396, 0.24565879947372846, 0.1423982682504824, 2.572958541767938, 46.9854976109096, 50.8486647605896, 51.91169398171561, 57.511452198028564, 38.29734155109951, 40.19298035757882, 30.240894862583705, 35.848772048950195, 7.683665411812918, 0.416940552847726, 0.08360102400183678, 0.08628000239176409, 0.07541864485080753, 0.013935480798993791, 0.03294410669643964, 0.10071277472057513, 0.013343220659797745, 0.05019301648384758, 0.0816636233191405, 0.09612581692636013, 0.03495644139392035, 0.005782701041815537, 0.016684153217024038, 0.17923839070967265, 0.12529510099972996, 0.14194939019424574, 0.19028488653046743, 0.14882525695221765, 0.233016877834286, 0.07214516121894121, 0.11438056666936193, 0.15923546334462507, 0.14782988679196152, 0.07774618281317608, 0.2963541048978056, 0.10526155813464097, 0.12835051704730305, 0.17586126763905796, 0.1229241503668683, 0.32756942989570753, 0.2247533391096762, 14.195670860154287, 67.81318146841866, 43.37539775030953, 45.80014187949044, 44.08890131541661, 54.03580692836216, 56.570944036756245, 63.47281551361084, 57.1684022630964, 61.61975874219622, 19.621943848473684, 0.36938686455999103, 1.1332465218646186, 0.8637378407376153, 12.287481001445226, 63.587016105651855, 56.1744589805603, 62.87622233799526, 59.0834994997297, 59.8952089037214, 56.02902276175362, 57.65760408129011, 57.993695395333425, 60.22368499210903, 53.660017081669395, 48.434401988983154, 43.874472958701, 42.87306383677891, 41.139953817640034, 41.88222639901297, 42.14095299584525, 45.9931697845459, 42.82536097935268, 45.31615815843855, 45.76255907331194, 47.915604318891255, 53.979133946555, 51.518116746629985, 52.184178011757986, 55.03947074072701, 56.90794209071568, 55.659760747637065, 49.62904051371983, 44.54409864970616, 41.80217272894723, 42.55090366091047, 40.59789705276489, 38.34236935206822, 40.95618438720703, 42.3308298928397, 42.22513389587402, 46.04210942132132, 44.84323944364275, 42.61574077606201, 47.154582023620605, 46.051239354269846, 44.43610627310616, 41.74577420098441, 42.43757854189192, 41.04307508468628, 40.64112179619925, 41.29066024507795, 39.41194377626692, 38.668472630637034, 39.872796944209504, 42.08240747451782, 39.60804973329817, 37.398376669202534, 37.99906580788748, 39.348006452832905, 39.063522883823936, 39.0113662311009, 40.14036512374878, 40.19585343769619, 39.62232480730329, 39.06131683077131, 37.73740707124983, 39.211095673697336, 37.232318196977886, 37.663537297930034, 38.07494361060006, 35.71535273960659, 37.80910900660923, 37.00487239020211, 38.176540170397075, 38.4754238809858, 38.30196557726179, 41.59078768321446, 48.09702525820051, 46.12407732009888, 42.93038647515433, 42.04125329426357, 41.336170945848735, 40.58455651147025, 37.890993527003694, 37.42205613000052, 38.63676105226789, 37.38276406696865, 38.223027093069895, 39.286042417798726, 39.23255171094622, 39.3330191884722, 43.04559803009033, 45.45832872390747, 46.961460317884175, 47.00313213893345, 45.455528599875315, 45.63296127319336, 46.115878445761545, 43.08831902912685, 41.52654463904244, 40.27373579570225, 40.07597616740635, 36.99859469277518, 40.50176872525896, 38.39453990118844, 41.6664605140686, 39.36958408355713, 41.31310640062605, 38.23652744293213, 43.85009172984532, 38.790858200618196, 46.32739550726754, 41.33163377216884, 54.2841077532087, 54.1601379939488, 61.66661044529506, 52.163218770708355, 58.89451544625418, 46.10634899139404, 53.46003402982439, 5.583575861794608, 0.25215984348739895, 0.863134921661445, 3.6713629961013794, 54.36948026929583, 57.56247976848057, 54.550088269369944, 61.225948742457796, 42.64195285524641, 44.130969183785574, 43.893559660230366, 46.35074840273176, 13.041741830962044, 0.6660667476909501, 0.335964455136231, 0.21136585676244327, 0.159394430528794, 0.21618801515017236, 0.19835321073021206, 0.2342794415141855, 0.1524375874016966, 0.14373329947037355, 0.13686043183718408, 0.15772371446447714, 0.15130575027848991, 0.10906229740274803, 0.13019130112869398], [0.048721131536045244, 0.036793340862329514, 0.031004246324300766, 0.04603239241987467, 0.10092155316046306, 0.04112475219049624, 0.049612098905657015, 0.046348898471998315, 0.05667666285963995, 0.03979143427152719, 0.007572163278902215, 0.06516139382230383, 0.05905592215380498, 0.015785525187051723, 0.07592976492430482, 0.025659202065851008, 0.030131144781730006, 0.023053364661921347, 0.12038697222513811, 25.489919900894165, 47.011522088732036, 26.678070545196533, 29.691914217812673, 40.69174984523228, 43.31625815800258, 50.810407979147776, 46.17285714830671, 48.11452777045113, 20.87088254519871, 0.22249358679567063, 0.2350314754460539, 0.27725556971771376, 6.066131293773651, 56.6532940864563, 54.62399278368269, 56.31233903339931, 56.719739709581646, 55.102459635053364, 56.772493907383506, 53.272359711783274, 52.62144204548427, 53.77835880007063, 52.366536957877024, 45.76687043053763, 42.36907972608294, 37.501880509512766, 38.466554505484446, 38.58904429844448, 38.97687189919608, 39.48922511509487, 37.60004465920584, 36.942647797720774, 39.40750387736729, 41.83946371078491, 44.19703960418701, 47.46944311686924, 48.87542847224644, 50.581621170043945, 46.066442012786865, 40.43724080494472, 39.484507288251606, 37.16138751166207, 38.28161082948957, 37.86250591278076, 37.19435323987688, 34.97232975278582, 36.224655696323936, 35.89085381371634, 37.816647802080425, 42.78622872488839, 39.026634897504536, 38.038823400224956, 41.810430662972585, 39.37163380214146, 35.50334930419922, 36.36834096908569, 34.90910114560808, 33.81971393312727, 34.487435817718506, 34.64934968948364, 34.582917962755474, 36.092768464769634, 35.361470563071116, 33.76170342309134, 34.33813640049526, 34.60083736692156, 35.70194966452462, 34.67588833400181, 35.596205030168804, 34.07496295656477, 35.00122036252703, 35.68776491710118, 35.10943855558123, 34.978124550410676, 34.715482643672395, 35.65582057407924, 35.24361869267055, 34.5902795791626, 32.95286015101841, 34.369097573416575, 34.60044131960188, 34.572672843933105, 34.412093026297434, 35.54900939123971, 34.587951932634624, 35.158100264413015, 39.03904785428728, 41.63069118772234, 35.795937946864534, 34.62481560025896, 37.83456373214722, 41.33081041063581, 33.798271792275564, 33.93368870871407, 35.996848583221436, 32.54549421582903, 34.139404024396626, 34.00713116782052, 35.05302960532052, 33.953362533024375, 34.29002707345145, 35.69050250734602, 39.62580585479736, 39.99590860094343, 40.08064883095877, 39.22971337182181, 39.13607249941145, 36.41379261016846, 35.14247029168265, 33.84533888953072, 34.00635296957833, 33.07169171742031, 34.20940017700195, 34.43235397338867, 35.30531522205898, 34.444895471845356, 38.539930956704275, 35.32889740807669, 37.19414826801845, 35.55175392968314, 37.28697967529297, 36.747399943215505, 42.41093914849417, 46.56754609516689, 51.98615435191563, 46.617388997759136, 54.350536005837576, 48.867302553994314, 55.953193596431184, 2.3630936316081455, 0.11996565626135894, 0.12174485650445734, 3.2082464524677823, 47.060538155691965, 44.492706298828125, 46.63907779966082, 46.23991073880877, 29.117022003446305, 26.674363681248256, 36.52716984067644, 23.558345011302404, 0.18958333560398646, 0.052266127562948635, 0.05028225401682513, 0.015306007882047976, 0.012337269594094582, 0.06589201318898372, 0.04050949734768697, 0.0417929225867348, 0.005740483865208391, 0.04842941236815282, 0.05101471560608063, 0.02207747693838818, 0.0029160163290466046, 0.06874000786670617, 0.07778834019388471, 0.04664241575769015, 0.027163639731173004, 0.01835278108982103, 0.021950122700738053, 0.038365923799574375, 0.07592809572815895, 0.04141824233478733, 0.036923453344830444, 0.04827861135293331, 0.05755486020020076, 0.08531988891107695, 0.044626359295632155, 0.03613787603431514, 0.02821686178711908, 0.03420190027515803, 0.015390475313844425, 0.02729731282618429, 0.0600134368453707, 0.27248598422322956, 36.40156378064837, 51.04961361203875, 24.269866602761404, 43.57119451250349, 45.79576798847744, 46.20875154222761, 55.58485916682652, 51.73257637023926, 54.60057388033186, 23.635515178952897, 0.4160650798252651, 0.5070772532905851, 0.9339285429034914, 7.275657636778695, 60.78735065460205, 55.473371846335276, 59.492310660226, 57.97133609226772, 56.88504082815987, 57.603342124394004, 56.61852877480643, 54.63957759312221, 55.761763777051655, 53.75003794261387, 47.85275786263602, 42.62367214475359, 39.97477218082973, 40.779429163251606, 40.493660177503315, 40.00340918132237, 40.40641164779663, 39.73231479099819, 39.896139417375835, 40.95819936479841, 44.31465176173619, 45.65515034539359, 48.25555188315255, 52.068042346409385, 51.62043244498116, 48.92026172365461, 44.55780744552612, 42.07061638150896, 39.685379709516255, 39.22380740301949, 41.45344264166695, 39.02763891220093, 37.32453121457781, 38.79081998552595, 38.59262956891741, 40.10786492483956, 45.17761107853481, 40.80921956471035, 41.574911049434114, 43.930739470890586, 41.92806019101824, 38.06370142527989, 37.925894328526084, 38.10672467095511, 36.290781702314106, 36.964162894657676, 37.447486536843435, 37.38185732705252, 37.92078740256173, 37.68569162913731, 36.02899442400251, 37.79308646065848, 37.20315660749163, 37.00007813317435, 36.266237190791536, 38.888504709516255, 36.241067341395784, 36.92420380456107, 37.03923123223441, 37.001981939588276, 35.85953828266689, 36.20993593760899, 37.52619225638253, 37.4817932673863, 36.22105652945382, 36.41402537482125, 35.323008809770855, 35.831964356558665, 37.398178645542686, 35.918288775852744, 36.92222009386335, 35.837470803942, 35.88527093614851, 40.7535262789045, 42.38949005944388, 38.71629013334002, 36.75321558543614, 41.64735296794346, 42.86547987801688, 35.538555826459614, 35.67056117738996, 37.759220940726145, 34.05042539324079, 36.35100868770054, 36.26548331124442, 36.421001366206575, 36.82006420407976, 37.337295055389404, 39.37543099267142, 41.797840527125764, 42.01638569150652, 41.83969994953701, 41.42818593978882, 42.38202422005789, 39.094411100660054, 37.01536069597517, 36.41803795950753, 35.53590508869716, 35.273676599775044, 37.2149407523019, 35.85621009554182, 38.01984439577375, 35.845065185001914, 38.75591570990426, 37.51266411372593, 38.40817921502249, 37.9164274079459, 39.775563853127615, 38.299561500549316, 44.66238130841936, 48.400797026497976, 54.583342347826274, 48.7136674608503, 56.06720658711025, 51.21959434236799, 60.32412815093994, 2.398501434496471, 0.2694422389779772, 0.09845703933387995, 4.078609509127481, 54.044547762189595, 49.723820890699116, 52.39969376155308, 49.343705790383474, 35.70161615099226, 33.87898901530674, 37.53137213843209, 31.852289812905447, 0.3058271051517555, 0.04023438871705106, 0.05087030299806169, 0.0756059680134058, 0.02918797092778342, 0.041887228776301653, 0.03189611953816243, 0.02841504490269082, 0.04923099631975804, 0.02229299832002393, 0.04947133342336331, 0.06960106880537101, 0.013531561624923987, 0.03254503650324685, 0.023776338635278598, 0.11500955506094865, 0.15097218246332236, 0.12075519960905824, 0.23927970177360944, 0.17801842545824392, 0.1942183676042727, 0.15705761020737036, 0.17747175693511963, 0.13757509206022533, 0.1159338147512504, 0.15066285191902093, 0.1649668315159423, 0.14432419490601334, 0.11203024350106716, 0.13057883961924485, 0.1905037954981838, 0.13135030679404736, 0.08929748833179474, 0.5240366118294852, 46.94418362208775, 57.38092333929879, 36.986442293439595, 42.208861214774, 51.120777062007356, 53.946456568581716, 62.114956855773926, 55.22176020486014, 59.628828866141184, 28.19622414452689, 0.37579733771937235, 1.4486023485660553, 1.298929899930954, 9.629588331495013, 62.69652107783726, 57.72362239020211, 62.457947731018066, 60.694210052490234, 59.46844359806606, 60.62892477852957, 57.18432753426688, 55.785026345934185, 58.04475770677839, 58.11965233939034, 50.97549717766898, 45.9638866015843, 42.05184929711478, 43.960126876831055, 42.73758091245379, 42.7656238419669, 45.00302716663906, 42.441948958805625, 41.671775885990684, 44.61956303460257, 47.423053468976704, 48.00147363117763, 50.53526973724365, 53.64920915876116, 55.37760135105678, 50.59006323133196, 44.94641671861921, 43.978914805821006, 40.71747555051531, 41.685575008392334, 43.78702640533447, 40.839607511247905, 40.65593188149588, 40.28026015417916, 39.63251086643764, 41.885488578251426, 48.50019448144095, 42.65803446088518, 44.26145287922451, 47.70441729681832, 44.832240445273264, 39.32427140644619, 40.14461047308785, 41.23085709980556, 37.41381904057094, 39.80612897872925, 39.39442389351981, 39.772888796670095, 41.05863210133144, 40.76706484385899, 36.800018651144846, 39.92173310688564, 39.8525116784232, 39.85417577198574, 38.45825488226754, 41.355810029166086, 38.60571650096348, 39.01408645084926, 39.23108911514282, 39.709528173719136, 39.05982991627285, 38.32137884412493, 38.535866260528564, 38.9978380884443, 38.573855536324636, 36.554570061819895, 38.17568901606968, 38.17822510855538, 39.11406408037458, 37.81471620287214, 39.697334085192, 38.34013550622122, 37.314390318734304, 42.45846830095564, 45.72650834492275, 41.44938836778913, 38.14019066946847, 43.81195306777954, 45.33115931919643, 38.45139701025826, 37.76282010759626, 41.063144956316265, 36.81191396713257, 39.759478773389546, 38.57419599805559, 40.46778161185128, 37.58639144897461, 38.1274094581604, 41.228724002838135, 44.80868257795061, 44.3437751361302, 44.31618731362479, 42.95177303041731, 44.17864772251674, 42.81471981321062, 39.68041522162301, 38.520010471343994, 38.91679777417864, 36.248390742710654, 39.629759379795615, 37.80138955797468, 39.305584226335796, 37.29480334690639, 43.02824490410941, 39.31153883252825, 40.844735281808035, 39.362205096653526, 41.08060577937535, 40.14415536608015, 46.46772480010986, 50.189537797655376, 57.554114137377056, 49.7732503754752, 58.43224484579903, 51.672120094299316, 58.73697199140276, 3.298551103898457, 0.4270622597209045, 0.3339158222079277, 4.903348088264465, 61.551909582955496, 54.09825733729771, 56.61823000226702, 54.59511259623936, 40.63577863148281, 39.22824730191912, 47.37467663628714, 43.70892170497349, 0.9242488337414605, 0.2023645740534578, 0.255931873938867, 0.16625227539667062, 0.10089834047747509, 0.11414561713380472, 0.1224798456366573, 0.08975507199232068, 0.12713530154100486, 0.15262923283236368, 0.14273692507828983, 0.12705767713487148, 0.0778206791728735, 0.1321361724819456, 0.10436177998781204], [0.04743867660207408, 0.041101179883948395, 0.010139375925064087, 0.029155567487967864, 0.055402024649083614, 0.045115209849817414, 0.0766731339639851, 0.02396830467374197, 0.011069924786819943, 0.10903430783322879, 0.025810612066249763, 0.04200080196772303, 0.04159021024991359, 0.015778096924935068, 0.04783696987267051, 0.0803091927830662, 0.025479680359629647, 0.08326437563768455, 0.09064609703740903, 7.866899830954416, 47.6889123916626, 33.70908471516201, 29.943880217415945, 34.58517612729754, 46.13636520930699, 55.22966030665806, 47.488474232809885, 49.7648743220738, 28.227392026356288, 0.21002470515668392, 0.19423766514020308, 0.31396800545709475, 1.68045374751091, 49.08462483542306, 59.63979312351772, 54.0431546483721, 55.891187872205464, 55.247173241206575, 55.58642945970808, 55.02100937707083, 54.212235586983816, 54.52850716454642, 50.44247654506138, 47.91523259026663, 43.59804582595825, 40.17420285088675, 38.574703216552734, 38.03894846779959, 38.69906554903303, 38.62183632169451, 38.76248523167202, 37.10359239578247, 38.02285991396223, 36.532040527888704, 36.88292108263288, 38.77413388660976, 39.49725028446743, 39.29988322939192, 40.544260433741975, 38.386469568525044, 37.152688367026194, 38.107468128204346, 37.72576536451067, 38.26148189817156, 37.56805167879377, 36.03635951450893, 36.95467165538243, 36.41418170928955, 38.6608122416905, 40.599682739802766, 38.72356489726475, 39.04966122763497, 37.22068691253662, 36.85327659334455, 35.406616483415874, 35.48055573872158, 35.73751401901245, 35.67663390295846, 34.35964107513428, 35.51557813371931, 34.853105613163535, 34.08318962369646, 34.5029650415693, 35.83481311798096, 35.55771895817348, 34.25295843396868, 34.912276472364155, 35.21395683288574, 35.11900275094168, 35.757469245365684, 35.746039458683555, 36.11568014962332, 35.820062092372346, 35.731437819344656, 34.49287625721523, 34.705425126211985, 35.936305454799104, 35.21324116843087, 33.80418470927647, 35.07290840148926, 32.27133566992623, 34.0770891053336, 33.624882970537456, 35.18231821060181, 33.32466867991856, 35.07465934753418, 34.050168309892925, 37.0244836807251, 38.061005524226594, 34.46600062506539, 36.852300371442524, 39.432847431727815, 36.54935891287667, 34.417408398219514, 35.64241055079869, 32.956223079136436, 34.15328305108206, 34.63478626523699, 35.502136843545095, 35.106297969818115, 35.057445185525076, 34.97777714048113, 34.44874129976545, 35.180268492017476, 37.603143555777415, 35.02500752040318, 36.46955190386091, 36.10982976640974, 33.9341264452253, 33.16186891283308, 35.18259613854544, 33.72070905140468, 34.96432195390974, 35.40479605538504, 36.183699539729524, 38.113683291843955, 39.89949887139456, 38.403242519923616, 41.03236791065761, 36.8374069077628, 39.58505467006138, 38.38061571121216, 40.93508618218558, 43.99217891693115, 47.393030302865164, 47.642526217869346, 53.461170060294016, 52.20601619992937, 52.2448079926627, 0.9648759279932294, 0.18280011601746082, 0.011172138453860368, 4.5430366567202976, 52.73834548677717, 42.301675251552034, 49.6712577683585, 38.92698383331299, 30.943389007023402, 29.769626344953263, 31.89208562033517, 9.305935161454336, 0.2981453559228352, 0.03613877509321485, 0.06971630440758807, 0.03672394708597234, 0.08465004592601742, 0.01746844979269164, 0.02583209957395281, 0.12749160027929715, 0.03953920244904501, 0.04141259692343218, 0.036522903945297, 0.03085393724696977, 0.061219091793256145, 0.06161908818674939, 0.06025819121194737, 0.1348937659391335, 0.033960677683353424, 0.023948428686708212, 0.012612876947969198, 0.14377653572176183, 0.03589735911892993, 0.014783590200490184, 0.038936690493885956, 0.02041351399384439, 0.018690978210153322, 0.05091949339423861, 0.041842442072395764, 0.06210170978946345, 0.027512118353375366, 0.02850657927670649, 0.10778133863849299, 0.07769492627786738, 0.0922666693638478, 0.1519426368176937, 12.326178124972753, 60.0385502406529, 29.88990661076137, 32.15323713847569, 45.84846660069057, 49.61217723573957, 61.19243063245501, 52.86049829210554, 53.689602511269705, 33.83418355669294, 0.1453647826399122, 0.30595439832125393, 0.2343569573547159, 2.3606357063565935, 54.509656701769146, 59.0732022694179, 56.68766335078648, 57.02031878062657, 58.38861015864781, 57.57968003409249, 55.96625620978219, 55.34439590999058, 56.46401820863996, 52.64092132023403, 50.60360179628645, 46.70073611395699, 42.64886631284441, 40.21969965526036, 40.61054277420044, 40.352761132376536, 40.76072113854544, 40.55447081157139, 37.490183217184885, 40.747210366385325, 39.495697362082346, 40.782618386404856, 43.78603628703526, 41.80133547101702, 42.017737116132466, 42.17573915209089, 40.82482869284493, 40.44336564200265, 39.640674999782014, 39.480793476104736, 40.431755202157156, 39.509183815547395, 37.512639795030864, 38.4792731830052, 38.035675866263254, 40.98220886502947, 43.99469416482108, 41.95904915673392, 43.66779184341431, 39.67121580668858, 39.84809609821865, 38.784375531332834, 37.782837867736816, 36.992803369249614, 37.645016874585835, 36.532554694584434, 37.43864148003714, 39.161648818424766, 35.61263057163784, 37.52717195238386, 39.08797706876482, 37.0944242477417, 37.123311383383616, 37.60804898398263, 36.978990350450786, 37.925817898341585, 37.27396222523281, 39.159675530024934, 37.589921133858816, 37.68676165172032, 37.72370522362845, 36.46137040002005, 36.364439555576865, 36.448846272059846, 36.95119408198765, 36.17773103713989, 36.238548619406565, 33.814488887786865, 35.656199250902446, 33.66779504503523, 35.87956299100603, 35.74029677254813, 36.46119669505528, 34.794066769736155, 38.66269867760794, 39.5765882900783, 37.02799252101353, 38.575304235730854, 39.65273012433733, 37.377462591443745, 36.43701001576015, 38.834829875401084, 35.429041794368196, 36.89134924752371, 35.664457184927805, 38.29246391568865, 36.984889371054514, 37.67690910611834, 37.134525775909424, 37.67577654974801, 38.403781005314414, 40.058303424290244, 39.376063278743196, 38.06765147617885, 37.213366985321045, 36.52310167040144, 34.778117179870605, 37.08592660086495, 35.35896921157837, 37.03842176709856, 36.83213322503226, 37.43411472865513, 39.5295489856175, 41.60846390042986, 39.27670751299177, 42.36607115609305, 37.93875544411795, 41.945455006190706, 39.61926065172468, 42.28847714832851, 46.932076386043, 49.536511353084016, 50.85875701904297, 56.208307129996165, 53.425744669778005, 54.40524959564209, 1.3194474961076463, 0.010939496785535343, 0.5096269164766584, 5.479346803256443, 58.11175571169172, 46.05937222072056, 55.125586714063374, 42.900078432900564, 38.35557440349034, 29.848161833626882, 38.20251601082938, 13.85259747505188, 0.39244573722992626, 0.06481511704623699, 0.03975693076582892, 0.07638673790331398, 0.01770440864908908, 0.02168803515711001, 0.049092273227870464, 0.10616350080817938, 0.061194101348519325, 0.03664331337703126, 0.03178654970335109, 0.0238802342209965, 0.015895381702908447, 0.014808901253023317, 0.07818322721868753, 0.15104513854852744, 0.1136796942778996, 0.12560782421912464, 0.1491817728217159, 0.34813015375818523, 0.11918490672750132, 0.16752203154776776, 0.19664892075317247, 0.07359090221247502, 0.1256453064935548, 0.11124276289982454, 0.18523311189242772, 0.21911556805883134, 0.17908555748207228, 0.11590386421552726, 0.16658394331378595, 0.17978644344423497, 0.20098693083439553, 0.28462644134249004, 16.88826891354152, 69.65944290161133, 42.5601795060294, 42.805923393794465, 46.29962355749947, 56.44269071306501, 64.56933157784599, 58.73976516723633, 60.105892181396484, 39.64218623297555, 0.48544577402727945, 0.5841550858957427, 0.4522536593888487, 3.9965951442718506, 58.334164074489046, 61.98011316571917, 60.160414695739746, 59.77433804103306, 60.52133192334856, 59.26735578264509, 57.393166065216064, 56.51658827917916, 59.347607476370676, 54.52066264833723, 52.559425898960654, 49.75434085300991, 45.884843894413535, 42.34398283277239, 43.364468233925955, 43.41112191336495, 43.24648782185146, 44.112869126456125, 41.370008672986714, 43.29992989131382, 41.50731897354126, 41.002810273851665, 44.73920406614031, 45.51834031513759, 43.776360920497346, 45.51411233629499, 42.54515750067574, 42.665917192186626, 41.65439149311611, 42.523027488163535, 43.65077917916434, 42.623932702200754, 41.336719853537424, 40.77941526685442, 39.515280859810964, 43.244243553706575, 44.96216481072562, 43.71242707116263, 45.33034985406058, 43.57883405685425, 41.957041127341135, 40.29573726654053, 40.95133801868984, 40.63704667772566, 39.66670642580305, 38.79744856698172, 40.61568096705845, 40.02800233023507, 37.75063296726772, 38.887542384011404, 40.92714091709682, 39.10723400115967, 37.729583399636404, 37.707710470472065, 39.23411505562918, 40.68976960863386, 39.00978551592146, 40.51600905827114, 39.59521293640137, 41.55301380157471, 38.98349700655256, 37.941906452178955, 38.54830353600638, 38.1198011807033, 38.53147847311837, 38.631299768175396, 38.646425996507915, 35.34912361417498, 37.92577273505074, 36.54139975139073, 37.80481849397932, 37.42566224506923, 38.29908207484654, 36.49856758117676, 41.13414512361799, 41.70733329227993, 39.47756256375994, 40.83562271935599, 41.37682138170515, 40.76541812079293, 39.756880147116526, 41.727851322719026, 37.17106982639858, 38.873051915849956, 37.964133739471436, 40.043830326625276, 38.987728459494456, 39.87581941059658, 39.02740614754813, 39.0649403163365, 38.9710875238691, 42.292621748788015, 41.65090697152274, 40.282844884055, 40.18248510360718, 38.7498151915414, 38.2628367968968, 39.66044609887259, 37.13281304495675, 39.59014422552926, 38.6914051600865, 40.422930989946636, 42.60769476209368, 45.537927286965505, 41.81279305049351, 44.8259071622576, 39.48139796938215, 43.27921731131417, 42.13421671731131, 45.98184074674334, 48.81440939222063, 52.46568080357143, 53.55538763318743, 58.26688119343349, 55.397737230573384, 56.812779562813894, 1.7725035910095488, 0.21294075011142663, 0.6057048152600015, 6.839802350316729, 66.42520236968994, 50.60558898108346, 60.342026710510254, 47.74731894901821, 44.968199321201865, 37.381159033094136, 48.275906630924766, 20.11472225189209, 0.404571212295975, 0.20808509923517704, 0.16562427766621113, 0.10961248752261911, 0.14385976482714924, 0.09128390638423817, 0.11581883020699024, 0.28875231423548287, 0.09712189276303564, 0.12118555365928582, 0.08759776489543063, 0.11482348718813487, 0.14477443003228732, 0.10075521708599158, 0.14805229700037412], [0.08653000183403492, 0.03037878292213593, 0.04499250018436994, 0.05026524653658271, 0.05206667219421693, 0.050709072899605544, 0.11028888515595879, 0.07086693016546113, 0.043030472073171816, 0.003779575336791043, 0.02600390972968723, 0.05076491633164031, 0.03695002816883581, 0.06486604109938655, 0.030405971820333173, 0.04040578327008656, 0.045116427820175886, 0.009887163610463696, 0.056910065335354636, 0.17653199950499193, 17.40565436226981, 46.087800775255474, 31.890727247510636, 32.46630212238857, 36.425427368709016, 43.998810972486226, 52.60623591286795, 47.23053625651768, 43.686048235212056, 2.740835270711354, 0.19499682368976728, 0.10528070639286723, 2.5106379772935594, 49.0569293158395, 57.958648681640625, 55.03524971008301, 52.573423045022146, 53.079401288713726, 55.25406585420881, 56.61087185995919, 53.97070230756487, 52.42385612215315, 49.775331360953196, 48.76491737365723, 41.86728777204241, 39.78499255861555, 38.84361934661865, 37.560155051095144, 38.56659814289638, 37.03381858553205, 39.13754204341343, 37.76463706152779, 38.301892621176584, 38.221585341862266, 37.11726645060948, 37.76670067650931, 38.24219717298235, 39.74053103583199, 37.24547461100987, 38.33328110831124, 38.92380503245762, 38.73806578772408, 39.12674454280308, 37.125906535557334, 37.7027633530753, 37.39384296962193, 39.1721579687936, 35.49868706294468, 36.78582695552281, 39.88580397197178, 37.093812806265696, 36.50201736177717, 35.577222551618306, 36.565742765154155, 35.832085950034006, 35.970591340746196, 36.17914499555315, 36.15042461667742, 35.58526161738804, 36.0697351864406, 34.73828315734863, 36.07960857663836, 34.28165796824864, 34.33854981831142, 34.95218692507063, 38.13866206577846, 36.61088868549892, 38.29175172533308, 37.078016076769146, 37.15615551812308, 38.2098776272365, 36.90487739018032, 38.67003597532, 35.972192900521414, 34.818051951272146, 35.25168555123465, 34.240931102207725, 34.84418065207345, 33.98419516427176, 34.067705563136506, 34.956275939941406, 33.03108991895403, 35.02748802730015, 35.03479058401925, 34.4301791872297, 34.477597168513704, 33.34736844471523, 33.291831493377686, 34.13545397349766, 36.52701003210885, 38.53263534818377, 36.2777225630624, 33.96171079363142, 35.117984839848106, 34.34016180038452, 33.45655243737357, 33.97580868857247, 33.23568657466343, 35.93264722824097, 36.50532123020717, 34.86855493273054, 34.52114152908325, 34.05613681248256, 33.62865236827305, 34.03829383850098, 36.0340700830732, 34.05062689099993, 33.98138114384243, 33.80209330150059, 31.97472402027675, 34.995505469185964, 35.27595908301217, 35.710040841783794, 38.30360535212925, 40.338524273463655, 39.26207460675921, 42.53895970753261, 42.37881415230887, 42.05362456185477, 41.6882917540414, 43.31145347867693, 43.07628127506801, 44.34628690992083, 43.34678159441267, 45.32408257893154, 46.06505584716797, 51.864529609680176, 50.13580390385219, 47.625065394810264, 0.6696534837995256, 0.16388486671660626, 0.3175238003688199, 10.309876033238002, 56.58222096306937, 37.79821423121861, 55.08991813659668, 27.38474750518799, 33.14995970044817, 35.81577852794102, 33.65001113074166, 3.897967202322824, 0.2568718892123018, 0.11838590460164206, 0.0714236477922116, 0.07437940061624561, 0.08047789694475276, 0.06615751037108046, 0.02220373534198318, 0.007792892416806093, 0.042837428860366344, 0.04989438643679023, 0.06381570960261992, 0.04468711192852684, 0.055551125934081416, 0.02163943847907441, 0.04506627729694758, 0.03647117243547525, 0.0035336208114001367, 0.08545155863144568, 0.030916386217411076, 0.058038051772330485, 0.11928412211792809, 0.05299402600420373, 0.060277203763169904, 0.03990581491962075, 0.009586339350789785, 0.029810421634465456, 0.1080649798469884, 0.050523717488561354, 0.03283108990373356, 0.10766127186694316, 0.03436885381649647, 0.062301049807241986, 0.027535339518051063, 0.06995664829654352, 0.4719187170267105, 25.903445414134435, 49.911693232400076, 27.35334685870579, 43.16587482179914, 42.5154504776001, 52.22468253544399, 58.966241700308665, 52.155662604740684, 47.84743901661464, 2.643236964941025, 0.3966526543455464, 0.21206959257168428, 3.195574023893901, 52.53334583554949, 59.81979315621512, 58.523537227085654, 53.8652286529541, 55.77556637355259, 55.395388739449636, 59.465205737522666, 54.72899048668997, 54.25548464911324, 52.25411857877459, 50.67524814605713, 44.00016587121146, 42.26448849269322, 41.50752394539969, 39.542232922145296, 40.89179195676531, 39.7298447063991, 41.47502722058977, 39.80975593839373, 41.618285179138184, 39.88774946757725, 38.805272238595144, 38.95166730880737, 39.69076108932495, 40.708852836063926, 39.36056184768677, 40.29963173185076, 40.72609479086739, 41.644938468933105, 41.254929133823936, 40.2386543410165, 39.096832547869, 40.44981704439436, 39.75189134052822, 38.64733968462263, 40.55673592431204, 43.140691076006206, 39.72381714412144, 38.445279121398926, 37.062153339385986, 38.84617280960083, 38.51400375366211, 37.82387392861502, 38.37832975387573, 39.23582431248256, 38.117397103990825, 38.135069847106934, 36.822791372026714, 38.47400297437395, 36.07874700001308, 36.68370580673218, 37.057581424713135, 37.4676502091544, 39.08881780079433, 39.32923936843872, 38.065233503069194, 38.056103570120676, 38.58047716958182, 37.33012451444353, 37.99222878047398, 37.28252935409546, 35.73856667109898, 37.271926403045654, 36.33871037619454, 35.8751335144043, 37.12284585407802, 34.688085896628245, 34.79519932610648, 34.365300382886616, 35.940088748931885, 34.68883282797677, 35.77989803041731, 36.24891185760498, 34.80905750819615, 35.28280305862427, 36.48971210207258, 39.154419217790874, 41.211419514247346, 37.76337596348354, 37.63463626589094, 37.40656859534127, 36.69386059897286, 35.50673655101231, 35.60591861179897, 35.949350697653635, 38.44953836713518, 37.96930667332241, 36.590860503060476, 36.83096592766898, 36.27084732055664, 34.92792728969029, 35.86817141941616, 39.41743632725307, 36.41935116904122, 35.937319891793386, 36.80986772264753, 35.672551836286274, 37.3935546193804, 37.1302422114781, 37.912612846919465, 39.79396963119507, 42.03573989868164, 42.785488741738455, 44.56745154517037, 44.596140657152446, 45.434534617832725, 44.14617531640189, 45.62498821531023, 43.685582705906455, 46.86603028433663, 45.68021249771118, 49.75290257590157, 48.37061405181885, 54.46383333206177, 52.571425437927246, 51.18643059049334, 0.7149148636630603, 0.13088979864759104, 0.47136340396744864, 11.707637327057974, 61.63489191872733, 44.93954842431204, 60.27357305799212, 33.68491193226406, 42.98422459193638, 34.36193050657, 41.93776682444981, 5.0048938393592834, 0.34771271901471273, 0.061815137309687476, 0.07279575416552168, 0.036841007947389565, 0.03004460781812668, 0.033263727224298885, 0.032955821603536606, 0.058356481471232007, 0.03812319486002837, 0.03761960991791316, 0.03296672226861119, 0.021265969412135224, 0.026772571162187626, 0.01862184058076569, 0.05798939402614321, 0.1769641584583691, 0.09004224158291306, 0.24903803957360132, 0.13757849830601895, 0.15545195208064147, 0.29444918568645206, 0.18548745395881788, 0.09786769774343286, 0.12221149860748223, 0.08935620875230857, 0.08134199772030115, 0.15348145924508572, 0.16206981268312248, 0.14718738198280334, 0.20748174589659485, 0.2092542015016079, 0.18493490932243212, 0.2105168058936085, 0.18135745557291166, 0.5250263501490865, 37.45405258451189, 60.899293082101, 44.42987721306937, 47.56052357809884, 47.20326805114746, 57.007617473602295, 64.7281882422311, 57.562201840536936, 56.89604330062866, 4.299131436007364, 0.5173419682042939, 0.24231652596167155, 4.463012516498566, 58.23508971078055, 62.286528723580496, 60.5570456641061, 56.47571202686855, 59.02830301012312, 57.36146490914481, 60.55059773581368, 56.93739897864205, 57.08368982587542, 54.961234024592805, 54.274283000401084, 46.40754645211356, 44.56678799220494, 43.76570585795811, 41.547267641339985, 42.501727785382954, 42.68171044758388, 45.32777902058193, 42.44744150979178, 44.47518989018032, 43.6528844833374, 41.48010287966047, 42.6437211717878, 43.23272691454206, 44.56601674216134, 41.964534759521484, 44.67468656812395, 42.95848151615688, 44.83225781576974, 44.13546814237322, 42.92288589477539, 42.004153387887136, 43.426407950265066, 43.1803548676627, 40.02149534225464, 40.586898054395405, 45.32666383470808, 41.220445224217, 40.76940986088344, 40.09668527330671, 42.22060019629342, 41.63551671164376, 40.080669675554546, 40.74764462879726, 41.17220388139997, 40.47584499631609, 41.250221729278564, 39.28718887056623, 39.9692587852478, 37.26831681387765, 38.74605969020298, 39.50154774529593, 42.15594720840454, 42.05870369502476, 40.59997109004429, 40.52893965584891, 40.74893699373518, 39.80709825243269, 39.726426192692344, 42.215010370527, 40.98344564437866, 37.870451177869526, 38.8015375818525, 38.118623461042134, 37.633302211761475, 39.39777292524065, 36.35206828798567, 37.28091389792306, 36.55601181302752, 38.94562585013253, 37.3006328855242, 37.766415800367085, 38.87828738348824, 36.94734130586897, 37.25644581658499, 37.99924646105085, 43.05154568808419, 43.69671024594988, 39.903077193668906, 40.21398128782, 40.476894174303325, 39.46365574428013, 37.269706453595845, 38.268464837755474, 38.1847494670323, 42.30870335442679, 39.508138111659456, 38.88821635927473, 39.456488677433555, 38.71919100625174, 37.07116167885916, 37.46284900392805, 42.20351457595825, 38.59658656801496, 39.25395563670567, 38.832387583596365, 36.50912536893572, 40.379303250994, 40.78362587520054, 39.37443740027291, 42.45655754634312, 44.143361295972554, 43.56637246268136, 47.643443380083355, 47.65859392711094, 47.320758615221294, 45.29195063454764, 48.52541644232613, 46.67294331959316, 49.496406350817, 47.13768400464739, 51.21318462916783, 49.69183833258492, 57.00180530548096, 52.88148185185024, 53.16512816292899, 1.1996669577700751, 0.28610488772392273, 1.0474095621279307, 13.53948906489781, 68.99327741350446, 45.797633579799104, 65.54692227499825, 37.218494755881174, 46.081634249006, 41.23845842906407, 51.823316369737896, 7.2008815578051975, 0.44450544086950167, 0.17047830005841597, 0.26642229674117907, 0.17558074769164833, 0.15192764119378158, 0.15784738425697598, 0.08647677076182195, 0.13605875628335135, 0.1153764118041311, 0.18075418365853174, 0.14119298649685724, 0.08899936718600136, 0.17786933774394648, 0.08127003908157349, 0.15727010023381027], [0.054279439350856204, 0.056511612609028816, 0.02645424833255155, 0.0061132141771460214, 0.03784010326489806, 0.05312552948349288, 0.025053592598331825, 0.02600152637543423, 0.02899505663663149, 0.08017691916653089, 0.024582777504942248, 0.07097653392702341, 0.028064439073204994, 0.02370915179406958, 0.08935544879308768, 0.007430323166772723, 0.12983386245157036, 0.04215539599369679, 0.07091873631413494, 0.06924893627209322, 4.396370606763022, 46.33621277127947, 35.26800339562552, 25.181796823229107, 29.270234993525914, 46.9129445212228, 56.9629614012582, 45.45036608832223, 49.90059348515102, 7.647406237465995, 0.5592304319143295, 0.27312144583889414, 0.24291339250547545, 33.791017872946604, 60.26740305764334, 55.11981970923287, 53.92636932645525, 51.911152022225515, 50.35367161887032, 51.320621149880544, 51.063871315547395, 49.99064908708845, 49.374604429517476, 46.393559728349956, 43.37379619053432, 42.34336791719709, 38.88675028937203, 38.925601141793386, 38.1076592036656, 38.710450172424316, 37.37756334032331, 39.73252323695591, 38.456545625414165, 37.87500919614519, 37.316902092524934, 39.28712286267962, 37.612721647535054, 39.26072665623256, 38.74031005586897, 38.2137964112418, 37.171844550541465, 41.093981061662944, 37.62742403575352, 37.5751770564488, 38.108823026929585, 38.574341910226, 38.0807592528207, 38.60428864615304, 38.853138378688264, 36.752656255449565, 36.363393851688926, 35.41607298169817, 36.76606280463082, 36.44203008924212, 37.47799260275704, 35.30204956872122, 36.265465940747944, 35.96894114358084, 36.91082157407488, 35.220071247645784, 36.80130754198347, 37.08432156699044, 35.8803585597447, 38.87710966382708, 42.742802483694895, 45.42245170048305, 44.734903131212505, 45.121719769069124, 45.05177920205252, 44.92224393572126, 43.398906980242046, 44.08587537493025, 40.45029647009713, 42.542527607509065, 42.23169994354248, 39.1495589528765, 36.650312764304026, 35.87577622277396, 36.45890726361956, 33.75341074807303, 33.858345917293, 33.196199962071006, 35.58553259713309, 33.959219864436555, 35.19244868414742, 33.09526000704084, 34.63355990818569, 32.772585664476665, 34.5655300957816, 31.951725482940674, 35.27797406060355, 35.8399269921439, 34.7089513369969, 34.50614731652396, 35.706035205296104, 35.06046417781285, 34.2264267376491, 33.25301538194929, 35.21893521717617, 33.28002997807094, 35.49402482169015, 34.240496839795796, 34.09731878553118, 34.66055365971157, 34.94640254974365, 32.92248610087803, 34.64044557298933, 33.69119657788958, 35.77372803006853, 35.49203763689314, 36.99179935455322, 39.042403834206716, 39.85749353681292, 38.95589528764997, 42.896142278398784, 40.40652976717268, 44.67255694525582, 40.33353894097464, 46.10278109141758, 42.632447719573975, 44.967556612832205, 44.18095799854824, 47.205501896994456, 44.40954678399222, 48.654253414699006, 45.5227107320513, 53.43477732794625, 50.717538356781006, 48.2469083241054, 0.04238278325647116, 0.17084776237607002, 0.1098931296063321, 26.025806665420532, 48.521886757441926, 36.87142876216343, 43.279547350747244, 23.68408829825265, 31.732360431126185, 34.519077914101736, 24.316878114427837, 0.7058021383626121, 0.03716131040294256, 0.10131339356303215, 0.07238251955381461, 0.04570469393261841, 0.07576558659119265, 0.056245572598917146, 0.07436521244900567, 0.09967707243881055, 0.05577810946851969, 0.0310994651434677, 0.04598380931253944, 0.016834194273022667, 0.05640804102378232, 0.03529468092269131, 0.05082212022638746, 0.041291488600628715, 0.019676429884774343, 0.051589716358908584, 0.017908040400860564, 0.055906271162842, 0.00900230135968221, 0.08058254740067891, 0.038004305346735885, 0.038754157788519344, 0.018769545779962624, 0.044628357581262074, 0.026441300188058188, 0.05552056810951658, 0.02410253756014364, 0.013431042599092637, 0.04238527687266469, 0.08040905956711088, 0.017408949056906358, 0.08615586441010237, 0.20781781072063105, 7.651582104819162, 58.1392115184239, 33.45578466142927, 34.31095157350813, 40.61836297171456, 48.25796290806362, 64.03924655914307, 49.937418937683105, 54.45010021754673, 8.698824150221688, 0.4767429381608963, 0.05561189892302666, 0.4148187738444124, 36.92249454770769, 62.61782578059605, 57.63787119729178, 55.834907463618684, 53.900973660605295, 52.031091826302664, 53.03260169710432, 53.12695475987026, 53.67020314080374, 49.98421505519322, 49.459403719220845, 47.224202973502024, 43.499416146959575, 41.25965738296509, 41.711516107831685, 40.244970253535676, 41.269388335091726, 40.758306639535085, 41.45092044557844, 39.64157826559884, 39.44290147508894, 40.52591718946184, 41.02407176154, 40.0873121534075, 39.624426637377056, 40.73257746015276, 41.54484619413103, 40.24332700456892, 42.60838610785348, 41.008942059108186, 41.429957730429514, 40.693726607731406, 40.16144595827375, 40.318826130458284, 40.627628394535606, 41.219462054116384, 40.47040455681937, 38.55433457238333, 38.31673049926758, 39.42947408131191, 39.44484349659511, 39.98359291894095, 38.400497981480186, 38.83621604101998, 37.542576108660015, 39.366537298474995, 36.46221808024815, 38.45904350280762, 38.0782196862357, 38.120947633470806, 39.670663424900596, 41.78860289709908, 46.85931485039847, 45.61724097388131, 46.75804485593523, 45.8133156640189, 44.59363235746111, 44.258201122283936, 43.73951462336949, 40.61443723951067, 42.741214820316856, 41.94482619421822, 38.7159184047154, 38.184051173073904, 37.26851136343819, 36.93127359662737, 36.22901569093977, 34.72305965423584, 33.87115839549473, 37.05255787713187, 35.57844196047102, 35.38551480429513, 35.28532178061349, 35.19681910106114, 34.92757293156215, 35.67939928599766, 33.97119508470808, 37.96167755126953, 36.759465490068706, 37.31240660803658, 37.87369251251221, 38.23957422801426, 37.67604405539376, 34.714600222451345, 36.48456348691668, 37.475442613874165, 36.70831632614136, 39.1435626574925, 37.42656898498535, 36.88875062125069, 36.16185787745884, 38.45487110955374, 35.53113167626517, 35.63638298852103, 35.6962035042899, 37.5279084614345, 36.80655690601894, 39.281150885990684, 41.1072347504752, 41.86827094214303, 40.45629971367972, 43.98581436702183, 43.40638324192592, 45.866938386644634, 42.46382188796997, 47.79591812406267, 44.73593841280256, 48.044041769845144, 45.46454388754708, 49.57657814025879, 47.04689884185791, 51.88589184624808, 47.70164843967983, 55.83459479468209, 51.68178503853934, 49.58853251593453, 0.11016237908708197, 0.06860105746558734, 0.6816757129771369, 29.103068283626012, 54.20539855957031, 40.631581919533865, 48.72815792901175, 33.61866780689785, 32.94909422738211, 37.210570335388184, 33.17780113220215, 0.9058787194745881, 0.07556981566761221, 0.06035271792539528, 0.06416244099714927, 0.04367532800616963, 0.05453760835475155, 0.07151932122984103, 0.07275223971477576, 0.044387525147093196, 0.06147137111318963, 0.04052330892799156, 0.02404025143810681, 0.004321550093923828, 0.10571483988314867, 0.01597946067340672, 0.032900894193777015, 0.1906239233378853, 0.07911429940057652, 0.12387271518153803, 0.14137180761567184, 0.14426124042698316, 0.1476955097168684, 0.1256832501717976, 0.12905333004891872, 0.11669580957719258, 0.16436214824872358, 0.1255467424967459, 0.0879704841811742, 0.20332939656717436, 0.06430738286248275, 0.20796651845531805, 0.17339404645775044, 0.24096195293324335, 0.16747929741229328, 0.307947608509234, 0.38520557859114235, 12.667841894286019, 68.03000695364815, 44.41513313565935, 38.858557973589214, 42.7478677204677, 55.745445932660786, 67.08403750828334, 55.244258471897666, 62.27020045689174, 10.644179923193795, 0.7534462617976325, 0.7469608240893909, 0.5402133752192769, 40.41836602347237, 62.564150946480886, 61.54361343383789, 58.05948093959263, 57.600812980106895, 54.02899769374302, 55.00256538391113, 54.249279907771516, 56.23938294819423, 52.01863023212978, 51.17693935121809, 49.03380223682949, 47.644138199942454, 43.431466238839285, 44.24606261934553, 41.81965787070138, 43.605379649571006, 42.24754531042916, 44.624378136226106, 42.39033773967198, 41.62274244853428, 42.54481356484549, 45.56185688291277, 43.29047686713082, 43.26331288473946, 43.8775440624782, 44.37255457469395, 41.7692208971296, 45.16361740657261, 42.60896628243582, 42.182687350681846, 44.865049839019775, 42.856242247990195, 41.73382677350725, 44.43018640790667, 44.01015738078526, 43.044562748500276, 42.024330956595286, 40.95769214630127, 42.34639038358416, 42.666757924216135, 43.261523723602295, 39.399523871285574, 41.30820097242083, 38.98675223759243, 42.98430797031948, 39.08932154519217, 41.22727877753121, 41.188924721309114, 39.13860511779785, 41.83384609222412, 45.14886638096401, 48.54818916320801, 48.463153634752544, 49.777679852076936, 48.740605626787456, 45.998971530369346, 47.503812381199424, 45.85215956824166, 43.23657274246216, 45.83368083408901, 44.729209082467214, 42.91202933447701, 39.40125397273472, 39.80772706440517, 40.70866870880127, 38.087863785879954, 37.286170210157124, 35.10825041362217, 39.02140637806484, 37.720383984701975, 37.05525030408587, 36.95798247201102, 38.07157720838274, 37.400881494794575, 40.02121046611241, 35.80867746898106, 40.3769964490618, 40.49503244672503, 39.204883984157014, 38.49764769417899, 41.32609953199114, 39.70933015005929, 37.10575328554426, 37.405543736049104, 40.58482749121529, 39.15006617137364, 39.73633084978376, 39.209525380815776, 39.677076612200054, 37.86031028202602, 39.92387662615095, 36.736817836761475, 38.68924427032471, 38.53778396333967, 40.15055465698242, 39.2867546081543, 41.06863055910383, 43.75091314315796, 45.37388031823294, 41.51639332090105, 46.333843435559956, 44.91931874411446, 48.56604950768607, 43.279898234776084, 50.56399359021868, 47.22580105917794, 50.19080236979893, 47.587552070617676, 51.95744092123849, 49.046489647456575, 54.56563138961792, 50.3470847266061, 61.014063426426475, 52.38785750525338, 53.69941684177944, 0.2846033440104553, 0.3622899582343442, 2.18264348592077, 31.391853536878312, 59.597297940935405, 46.17557736805507, 55.06171192441668, 34.45805188587734, 41.76943629128592, 44.75406973702567, 43.94886384691511, 0.838015935250691, 0.10340767832739012, 0.1891612596809864, 0.12495197941149984, 0.1014505729877523, 0.16783047999654496, 0.15071443415113858, 0.15303046415959085, 0.17673356511763164, 0.1653291963573013, 0.11485195851751737, 0.16995714445199284, 0.12616703206939356, 0.14921149265553268, 0.14241874643734523, 0.13296494872442313], [0.05310173326038888, 0.07407963741570711, 0.06020643934607506, 0.047023457275437455, 0.025750034156122377, 0.06835218439144747, 0.022979004009227668, 0.05881210416555405, 0.054733341958905966, 0.0518556851228433, 0.042684286899332485, 0.040713576932570765, 0.033027430796729665, 0.023155774255948405, 0.027472198441890732, 0.07863980664738587, 0.03419678072844233, 0.03226545632683805, 0.05742223374545574, 0.10357189737260342, 0.257490306028298, 29.986278125217982, 45.425435951777864, 32.92728730610439, 29.637836388179235, 30.434297970363072, 54.449127469744, 50.32551751817976, 52.03009475980486, 18.342471293040685, 0.273568437567779, 0.06282562523015908, 0.1198339933263404, 14.182967816080366, 64.3199815750122, 56.21736063276018, 56.801064899989534, 53.388776779174805, 49.45786816733224, 48.0977200780596, 49.97865302222115, 46.640585558755056, 46.97325141089303, 44.62329421724592, 44.81348030907767, 42.17298419134957, 40.943014076777864, 39.855964933122905, 38.61397443498884, 39.72275406973702, 39.52184343338013, 37.64426646913801, 40.83608824866158, 40.21229634966169, 38.40135955810547, 36.92458248138428, 40.115243911743164, 39.97627646582467, 38.58058139256069, 40.266801493508474, 39.00665535245623, 38.835809571402415, 39.91580976758684, 39.03593853541783, 38.71419872556414, 37.88000842503139, 40.72809934616089, 39.47403982707432, 38.03678410393851, 37.90178060531616, 36.73647390093122, 35.99781090872628, 38.12705857413155, 36.36217791693551, 36.68398720877511, 36.89373247964041, 36.12144020625523, 34.996902057102744, 37.082372597285676, 39.137938090733115, 36.46229798453194, 38.63518033708845, 38.687354360307964, 38.308479513440815, 44.00912209919521, 51.925249917166575, 53.182001863207134, 52.60223027638027, 52.48082092830113, 52.68452821459089, 48.236572878701345, 48.22851644243513, 51.45258133752005, 52.12602506365095, 51.30273996080671, 47.2946194921221, 37.89859485626221, 36.202094895499094, 37.67112473079136, 36.91617168698992, 35.373466627938406, 35.228450775146484, 33.63532263892037, 35.80821541377476, 36.00488070079258, 33.567841734204976, 34.97263547352382, 34.630408900124685, 34.480977467128206, 34.21945422036307, 34.15050377164568, 35.28541210719517, 34.897087710244314, 36.19906548091343, 35.18933241707938, 34.92481797082083, 34.16943413870675, 35.88487836292812, 36.43216364724295, 36.83711508342198, 36.61587749208723, 36.91736330304827, 34.7057968548366, 34.87974500656128, 34.77966662815639, 34.762928417750764, 34.15812247140067, 34.5561535017831, 33.82727009909493, 36.53645263399397, 37.43843650817871, 36.882080350603374, 39.756880147116526, 41.06881816046578, 41.528194836207796, 42.79227713176182, 41.521840708596365, 43.13960715702602, 42.25338527134487, 45.88561861855643, 44.86843013763428, 45.65800952911377, 45.04824256896973, 44.53114720753261, 45.10516916002546, 50.13192680903843, 48.93443257468087, 55.704395975385395, 29.664979525974818, 0.33877635853631155, 0.045561777494315586, 0.2844876673604761, 39.014843804495676, 41.63214683532715, 53.71745783942086, 28.72970335824149, 23.058258840015956, 38.319297858646934, 31.902174404689244, 6.117278286388942, 0.13682965348873818, 0.09016262048057147, 0.03260437099795256, 0.06287289876490831, 0.09445525692509753, 0.021171888835462074, 0.01720292546919414, 0.05006054948483195, 0.07329263857432775, 0.0017437878185384242, 0.08623253886720963, 0.01250730877343033, 0.012458843561554593, 0.04425662217129554, 0.06262388319841453, 0.030119769142142365, 0.023983995796048214, 0.04961369685562594, 0.002791843148380784, 0.08502162527292967, 0.03640860132873058, 0.04501773150903838, 0.011415804619900882, 0.021931220411456058, 0.04553590834672962, 0.013445847385030772, 0.041601250014666996, 0.022932648193091154, 0.04375221959448286, 0.03177478051345263, 0.01851836229408426, 0.05303221734772835, 0.024004087217950394, 0.06035462460879769, 0.04634690357904349, 0.10571728939456598, 0.43905930167862345, 38.6514321735927, 50.72379520961216, 28.358275243214198, 35.28272662843977, 40.55391148158482, 58.19210468019758, 54.22691018240792, 56.06199196406773, 21.009796142578125, 0.4995677705321993, 0.029480270243116787, 0.316058409001146, 16.445133652005875, 64.11570453643799, 58.91652039119175, 59.17786993299212, 55.09530993870327, 51.2734637260437, 50.43566036224365, 52.88911097390311, 49.83061817714146, 49.048282282693044, 47.62767791748047, 47.884021282196045, 43.90392289842878, 44.274373054504395, 43.20080689021519, 40.7948819569179, 42.014228275844026, 40.510929925101145, 41.286915166037424, 42.40349415370396, 40.81615386690412, 40.358986718314036, 39.692984512874055, 39.55881827218192, 41.52241740907942, 41.1880145072937, 40.7080329486302, 41.11159127099173, 41.11146967751639, 42.2616605758667, 40.787436962127686, 40.4899811063494, 40.160282135009766, 41.348177433013916, 41.67114707401821, 41.156535693577354, 40.9562851360866, 37.651575974055696, 39.155885287693565, 40.19640234538487, 38.54489197049822, 37.23837355204991, 39.037918772016255, 39.76207739966256, 38.62902423313686, 39.855245794568745, 40.759581633976524, 40.205077171325684, 40.20947885513306, 39.680755683353965, 40.294740200042725, 46.150435311453684, 54.459629671914236, 53.22271483285086, 53.64553356170654, 53.16645179476057, 52.542833600725444, 48.65541723796299, 47.75321102142334, 48.78593914849417, 50.81726932525635, 51.20991202763149, 47.31538070951189, 38.90448556627546, 37.15294197627476, 37.575368131910054, 37.321998596191406, 36.15050799506051, 35.79457262584141, 35.76284715107509, 37.044143608638215, 36.64731114251273, 36.21732882090977, 36.57168000085013, 36.941946029663086, 36.83316503252302, 36.354295185634065, 36.07954256875174, 37.39950227737427, 37.199234349387034, 37.463571616581504, 37.66639300755092, 37.249289172036306, 36.93347617558071, 38.02129656927926, 38.54357876096453, 39.205693449292866, 38.06744303022112, 38.25487068721226, 38.047011852264404, 35.493906702314106, 36.85399573189871, 38.25169883455549, 36.35568135125296, 36.72794498716082, 37.00566101074219, 38.477108819144114, 38.86117397035871, 39.221212250845774, 41.899457931518555, 42.758366448538645, 43.593248094831196, 45.30639246531895, 43.72979409354073, 46.10684926169259, 44.481026376996724, 47.42310905456543, 46.98007454190935, 47.273021016802105, 46.2028351511274, 47.39325611931937, 47.12262378420149, 52.355819361550466, 51.01165560313633, 58.17286859239851, 30.888710158211843, 0.43515471262591227, 0.08715025747993163, 0.5060311151402337, 43.52388422829764, 47.14609479904175, 55.47002976281302, 35.68896000725882, 28.426744529179164, 33.8971655028207, 41.18041665213448, 9.153344903673444, 0.18504815681704453, 0.14924223029187747, 0.048087993902819495, 0.07887013535946608, 0.11269451571362359, 0.060953689606062005, 0.05404932437730687, 0.025302525044285824, 0.013385322909536106, 0.0365420318474727, 0.04802596901676484, 0.04228543723002076, 0.016212937787973454, 0.06513875110873155, 0.024298418745664612, 0.05277013998212559, 0.11979398690164089, 0.17873419847871574, 0.17701375936823233, 0.29751613682934214, 0.13588786045355455, 0.14154871526573384, 0.16097420932991163, 0.1566279889749629, 0.13732497048165115, 0.20633286397371972, 0.1512292115283864, 0.14612064350928577, 0.09667002236736671, 0.11538615556699888, 0.11722136209053652, 0.10009768951152052, 0.09144008478948049, 0.206964783636587, 0.11135531150336776, 0.29394905109490665, 0.6868092917970249, 51.16191387176514, 59.174326351710725, 38.154552595955984, 42.0972557749067, 42.171848160879954, 63.68444374629429, 60.64716379983084, 62.24103191920689, 24.47413148198809, 0.6133694925478527, 0.10157657015536513, 0.3777224229914801, 19.31267431804112, 67.42583329336983, 60.54956245422363, 61.73345906393868, 58.804633549281526, 54.38950845173427, 51.63185180936541, 56.1386444909232, 52.42300149372646, 51.4090439251491, 50.42385884693691, 50.966287340436665, 47.016229493277415, 46.34268849236624, 45.12046561922346, 43.192597593579976, 44.93321861539568, 43.94212062018258, 43.4352946962629, 46.3315817969186, 45.580262660980225, 41.60772391727993, 41.24078260149275, 44.66243689400809, 44.863952023642405, 43.02831786019461, 44.13313007354736, 43.21752078192574, 44.36148262023926, 44.20201104027884, 42.791585786002024, 41.94641733169556, 42.34441014698574, 45.784386839185444, 45.390382289886475, 43.90257494790213, 42.86771719796317, 41.486099175044465, 40.506531715393066, 42.450457027980256, 40.101892948150635, 40.62450517926897, 40.843613147735596, 42.57815449578421, 39.86555692127773, 40.39674322945731, 42.630081857953755, 41.07844488961356, 42.467254298073904, 41.74538857596261, 41.88139261518206, 47.387919902801514, 55.93731001445225, 55.08525936944144, 56.76763711656843, 55.28934185845511, 56.028939383370535, 49.758881500789094, 49.80940532684326, 52.83015898295811, 53.28288623264858, 54.98119272504534, 48.88982513972691, 40.13416733060564, 38.927821091243196, 40.10956028529576, 40.62073925563267, 38.86895942687988, 37.72172498703003, 37.03014646257673, 39.49264710290091, 39.380763735089985, 37.07856845855713, 39.79567888804844, 39.47145857129778, 39.45015886851719, 38.24419130597796, 39.94990805217198, 38.56361389160156, 39.66240201677595, 41.45899077824184, 39.62110539845058, 38.402443477085654, 39.875517163957866, 41.876768589019775, 39.98571559361049, 41.84980263028826, 40.766255378723145, 41.364863531930105, 40.9258520262582, 37.397914613996235, 39.18217727116176, 39.70822191238403, 38.79855333055769, 39.10415594918387, 38.69414275033133, 40.2747745513916, 42.310628005436485, 40.32375240325928, 45.76713098798479, 45.15962566648211, 45.22961139678955, 47.643144607543945, 45.737875597817556, 48.880490234919954, 46.68746852874756, 49.349101066589355, 49.10373585564749, 48.64282710211617, 49.43779134750366, 48.845214230673655, 49.310097353799, 53.4408917427063, 53.40420525414603, 57.388132095336914, 33.82881607328142, 0.5198326259851456, 0.3773449132485049, 1.3902596277850015, 47.07712697982788, 50.91870955058506, 62.305511202131, 38.43225472314017, 35.15194068636213, 44.49943562916347, 50.247815813337056, 12.576445290020533, 0.29096642828413416, 0.24872591346502304, 0.17774230241775513, 0.23131361923047475, 0.1652861229543175, 0.22557174733706883, 0.17096869088709354, 0.11233680562249251, 0.18244298946644577, 0.14269393309950829, 0.2645485358578818, 0.1476248199386256, 0.11343120118337018, 0.16806207756911004, 0.1301771876003061, 0.11434651778212615], [0.014994679052116615, 0.003325337490033624, 0.12789220735430717, 0.048990150314888785, 0.09411447628268174, 0.04125043723200049, 0.04710844378652317, 0.03847192793286272, 0.05700705852359533, 0.050352696129786115, 0.0175377485741462, 0.046232353297195265, 0.05251797601314528, 0.08701134100556374, 0.02827377730448331, 0.03912618157586881, 0.028488537030560628, 0.1117479322212083, 0.029191713048411266, 0.039429340844175646, 0.1676745797906603, 4.694157804761614, 46.838577951703755, 43.996604919433594, 43.378437587193076, 29.586534363882883, 48.37177092688424, 52.48612240382603, 53.27571221760341, 33.24523687362671, 0.06645094962524516, 0.13109692824738367, 0.1259636344122035, 2.6923374959400723, 47.17020157405308, 61.89795766557966, 57.154029914310996, 54.49414137431553, 52.31413017000471, 46.984406743730815, 47.42773308072771, 45.616938727242605, 45.4610732623509, 42.831193992069785, 44.41492121560233, 43.80651610238211, 42.81427165440151, 41.71414252689907, 43.02964496612549, 41.48253127506801, 41.31070579801287, 39.22777829851423, 39.78768498556954, 38.99752541950771, 40.923652921404155, 41.213007177625386, 39.235105173928396, 39.91397196905953, 39.77609191622053, 38.74972139086042, 38.45666027069092, 41.097232818603516, 39.49693414143154, 40.11954484667097, 38.62518882751465, 38.32632596152169, 39.881621156420024, 39.75707469667707, 38.34865052359444, 37.53777837753296, 38.45732034955706, 38.024854046957834, 37.042601108551025, 38.8590304510934, 37.51296983446394, 36.971486295972554, 37.66463163920811, 39.71253326960972, 37.8035261290414, 39.36804505756923, 38.0777576310294, 37.599318572453086, 36.409460408346995, 39.281668526785715, 39.370258058820454, 48.233300277165, 49.67052820750645, 52.48911707741873, 50.673031670706614, 57.29540491104126, 49.81002024241856, 50.38165896279471, 55.5459040914263, 53.41264384133475, 52.82641042981829, 44.18901443481445, 39.327828884124756, 38.197290965488975, 37.69943169185093, 39.27333763667515, 38.93413700376238, 36.0225499698094, 36.92284543173653, 34.61292028427124, 35.916944299425396, 33.53332655770438, 33.93452596664429, 34.17367253984724, 33.969228744506836, 34.61168350492205, 35.45613629477364, 36.219861439296174, 35.24378892353603, 35.23707348959786, 36.30907283510481, 35.02154384340559, 36.08232879638672, 35.240901947021484, 34.99902473177229, 35.20179748535156, 35.891861302512034, 36.78062275477818, 35.465221064431326, 34.517611844199045, 33.63375929423741, 36.3614935193743, 36.99649633680071, 35.805578572409495, 36.82260029656546, 39.00827080862862, 38.799835273197715, 41.25852482659476, 41.19143302100045, 41.56725760868618, 40.32137959344046, 41.424753529684885, 41.82073484148298, 42.032981463841026, 43.18463148389544, 43.36003180912563, 42.31975099018642, 44.79454299381801, 42.954687799726216, 48.08176006589617, 45.43033790588379, 51.43104192188808, 47.008510044642854, 60.221579687935964, 7.236177538122449, 0.6986689982669694, 0.25544061458536554, 2.1135831688131606, 53.22215550286429, 43.952563762664795, 50.703225067683626, 22.464047159467423, 34.80920342036656, 36.512397970472065, 20.827171427862986, 0.7477719719920839, 0.029295790142246654, 0.05770210908459766, 0.030312059181077138, 0.020746186142787337, 0.05183442662070904, 0.05901586144630398, 0.03677825702886496, 0.006110532267484814, 0.03757841266425593, 0.0438810225043978, 0.07693495348628078, 0.05753523018211126, 0.048569207545369864, 0.05304201878607273, 0.06462174813662257, 0.03674183666173901, 0.04885616000475628, 0.0034089641745335287, 0.06398250029555388, 0.022295028836067234, 0.1175273135304451, 0.04343140145231571, 0.034355127053069215, 0.062318142104361735, 0.04010094462760857, 0.029408586411071674, 0.008251543073648853, 0.034983419946261814, 0.04726293942491923, 0.04470363086355584, 0.009871929651126266, 0.029738479959113256, 0.005601537280849048, 0.10926220738994223, 0.04710157361945935, 0.05128529840814216, 0.18520287637199673, 9.524644477026802, 57.34364972795759, 42.00358016150338, 48.975117751530235, 34.28810937064034, 54.91400364467076, 57.7160210609436, 58.65066146850586, 36.53440638950893, 0.04072428760784013, 0.5940375413213457, 0.2037557065486908, 2.9683651072638373, 50.77279043197632, 62.228747504098074, 59.90498501913888, 55.217528751918245, 53.28327185767037, 48.036833013807026, 48.5156055859157, 47.527088846479145, 48.3941684450422, 45.62749998910086, 45.85470955712454, 45.80084364754813, 45.05111912318638, 44.37686940601894, 45.24547413417271, 42.544810090746196, 41.45897340774536, 41.645459583827424, 42.07302393232073, 41.56979022707258, 42.77813407352993, 43.07382508686611, 42.07400710242135, 41.62675503322056, 40.88683441707066, 40.50914076396397, 39.09773233958653, 43.378823212214876, 42.16722066061837, 41.992077418736045, 40.85455656051636, 39.81479338237217, 41.48694338117327, 42.10730634416853, 41.94658408846174, 40.01982430049351, 41.16574553080967, 39.45255947113037, 40.73474529811314, 42.30645908628191, 40.54001161030361, 40.31981972285679, 40.41108431134905, 41.95598152705601, 39.1085923739842, 40.51290321350098, 40.513716152736116, 38.991741044180735, 38.48524863379342, 40.9650468145098, 42.4253705569676, 50.175321783338276, 50.48493351255144, 53.45938784735543, 52.95122439520699, 57.036695684705464, 51.27996723992484, 51.2667795589992, 57.62724045344761, 55.78839274815151, 53.73285157339913, 47.17219570704869, 40.47486530031477, 39.2178111076355, 38.27258511951992, 38.938198225838796, 39.1204251561846, 35.758028575352256, 38.625699520111084, 36.12820427758353, 36.917196546282085, 35.91713537488665, 35.92345476150513, 36.07126031603132, 35.43130343300955, 36.10894734518868, 38.171943937029155, 37.98476641518729, 38.21888944080898, 37.22350093296596, 37.74450813020979, 38.325287205832346, 36.364800861903596, 36.317414147513254, 38.543207032339915, 39.675353458949495, 37.79794325147356, 40.363478728703086, 36.365554741450715, 37.28129604884556, 36.86958401543753, 37.08329323359898, 37.91852923801967, 37.52442046574184, 38.28466803686959, 41.0044778415135, 40.90747056688581, 42.66212347575596, 42.18216970988682, 44.242129938943044, 42.44303287778582, 44.37467724936349, 42.613823073250906, 44.78635106767927, 44.427045822143555, 45.57423857280186, 44.40822662625994, 48.57384886060442, 44.97502940041678, 50.327202456338064, 47.030431611197336, 55.48301247188023, 48.86583300999233, 63.358462061200825, 6.777904757431575, 0.640029676258564, 0.7073551693132946, 2.3114005540098463, 57.907204219273154, 46.78072725023542, 57.00229862758091, 30.220581804003032, 36.15019185202462, 37.07725177492414, 30.634343555995397, 1.2227227091789246, 0.06634702520178896, 0.02236612743165876, 0.04436443120773349, 0.013665031159429677, 0.08212466072291136, 0.07198647901948009, 0.04302168843735542, 0.012561924057081342, 0.05317633818568928, 0.07890171437923398, 0.08251743071845599, 0.035969477213386974, 0.053877733049115965, 0.05080958429191794, 0.018454697049622024, 0.04272302446354713, 0.15494150375681265, 0.12200902375791754, 0.20177536138466426, 0.15332368628254958, 0.2547504630471979, 0.20984793321362563, 0.15302525301064762, 0.1901095395109483, 0.1590318214148283, 0.17277455755642482, 0.13131552508899144, 0.18989763302462442, 0.09759003442845174, 0.183203165818538, 0.12593859647001537, 0.13571729032056673, 0.0754871836730412, 0.3457483872771263, 0.1677631421812943, 0.1897933693336589, 0.29730994360787527, 12.994590486798968, 67.2695266178676, 50.17680869783674, 52.60289035524641, 41.712082386016846, 59.04598617553711, 61.05220208849226, 63.80278546469552, 44.036369459969656, 0.1112696464572634, 1.1429941930941172, 0.2923239325838429, 3.617194188492639, 52.67989724023001, 63.74112715039934, 63.890714917864116, 58.118728228977744, 57.79353863852364, 50.8595004762922, 51.473123686654226, 50.75408240727016, 50.15504346575056, 47.63510206767491, 49.91952732631138, 49.43857996804373, 47.220763615199495, 47.431311403002056, 47.70162412098476, 46.209689549037385, 44.74392884118216, 45.36711277280535, 45.062125069754465, 43.270827361515586, 45.62629100254604, 48.25154277256557, 45.048704624176025, 45.019411018916536, 43.19117668696812, 42.71777507237026, 41.54557575498308, 46.03296559197562, 44.52305603027344, 44.975866658346995, 43.34216104234968, 42.452419894082205, 44.27209057126726, 44.24125446592058, 43.553678103855674, 43.8436507497515, 45.42186805180141, 43.45458984375, 43.05526644842965, 44.25618267059326, 43.07776818956648, 40.97667462485177, 44.419020652770996, 45.32543747765677, 40.22849260057722, 42.57468039648873, 42.221868242536274, 41.868628774370464, 40.219070843287874, 43.54678201675415, 43.975683893476216, 50.40245839527675, 52.9561402457101, 53.9897403717041, 53.58712700435093, 59.73275307246617, 53.95339434487479, 53.55813911982945, 58.49854455675398, 55.82968936647688, 54.88744762965611, 46.676264558519634, 42.325000354221885, 40.318311963762554, 40.539535658700125, 41.8221001625061, 41.14197226933071, 37.57452392578125, 41.438069752284456, 37.35453353609358, 40.23438119888306, 36.78285312652588, 37.81967374256679, 38.17952789579119, 37.91918236868722, 38.71702664239066, 40.94013752256121, 40.62399101257324, 40.348984786442344, 39.484865120479036, 40.20382302148001, 41.274387563977925, 38.74254042761666, 38.80002982275826, 39.871984004974365, 40.64704166139875, 40.25733457292829, 42.458346707480295, 39.3287912096296, 39.211272852761404, 38.78150939941406, 39.98175164631435, 41.63878583908081, 39.054861954280305, 40.4927464893886, 43.144335406167166, 43.32558611461094, 46.34621817725045, 45.074645723615376, 46.05185774394444, 44.78184863499233, 45.90255832672119, 45.60605090005057, 45.92667899812971, 48.67150231770107, 47.49236174992153, 46.77520343235561, 49.62252310344151, 47.15093074526106, 52.91880757468087, 50.3470812525068, 57.21072026661464, 51.43611063276018, 63.936024120875764, 9.903420312064034, 0.9006962318505559, 1.2115995117596217, 2.829923553126199, 65.72697789328438, 51.18849767957415, 61.22772053309849, 32.697159494672505, 46.20253985268729, 45.9225343976702, 42.584255014147075, 1.194765112229756, 0.2471324418272291, 0.11869410877781254, 0.11763089868639197, 0.09825185034424067, 0.2788393518754414, 0.14816642659051077, 0.1175306790641376, 0.10854975919106177, 0.18268495505409582, 0.12250389291771821, 0.2062001425240721, 0.18290984870067664, 0.17313627100416593, 0.14678935334086418, 0.14871612137981824, 0.10433379720364298], [0.05166141715432916, 0.036213817673602273, 0.036798602901399136, 0.08245847281068563, 0.006628725220382745, 0.008511762101469296, 0.03225517991398062, 0.05309243054528322, 0.0797839727518814, 0.023100789170712233, 0.017840704281947443, 0.028948929826063768, 0.021454999090305397, 0.024272722624508396, 0.032849186432680914, 0.030868322189365114, 0.06989128501819712, 0.02000969066284597, 0.1166377134088959, 0.03143235442361661, 0.18462602661124297, 0.09693106157439095, 21.095040116991314, 43.137387207576204, 33.984198638371055, 44.21799189703805, 22.427893945149012, 54.43394218172346, 45.89771890640259, 41.804288455418174, 1.5884211659431458, 0.9182227913822446, 0.22230743749865464, 0.11461201496422291, 25.339989934648784, 64.12343788146973, 55.944810594831196, 58.96808992113386, 51.99009050641741, 51.22616733823504, 46.81718097414289, 46.69469118118286, 47.91554178510393, 49.07853821345738, 45.02613687515259, 44.730101925986155, 44.99806267874581, 45.356714793613975, 44.38817759922573, 45.729513440813335, 40.83036988122122, 41.05252810886928, 44.025047370365684, 49.54710388183594, 51.2795329775129, 51.23259789603097, 47.78525958742414, 42.23093911579677, 39.38334846496582, 39.029042448316304, 39.16943774904524, 40.2250462940761, 38.60558795928955, 39.151007652282715, 37.834518568856375, 38.29857833044869, 39.28397185461861, 39.91715771811349, 38.05293519156319, 39.36120455605643, 36.79403625215803, 37.46550668988909, 37.62480803898403, 39.21849203109741, 37.562864848545615, 38.11930438450405, 36.366016796657014, 37.79289191109793, 38.233108929225374, 39.41498361315046, 37.93501383917672, 38.39996297018868, 38.26770748410906, 40.985623904636924, 42.286337103162495, 45.312305382319856, 48.020247663770405, 50.78375816345215, 52.7520021711077, 55.73903969355992, 53.4159060205732, 50.922544956207275, 53.63428095408848, 50.792158535548616, 46.41982739312308, 42.43288155964443, 42.805503027779714, 41.66499097006661, 41.533649172101704, 39.25501871109009, 38.85032088415963, 39.577425548008506, 35.636046000889365, 36.501451083592, 35.83146408626011, 35.58558470862252, 35.27818250656128, 35.03830637250628, 34.97438294546944, 36.025402205330984, 34.53372819083077, 36.19715125220162, 34.462033203669954, 35.710951055799214, 35.70302663530622, 36.58691740036011, 35.99786649431501, 34.73304074151175, 35.30934170314244, 36.253657477242605, 34.55090413774763, 36.00019761494228, 35.61299882616316, 35.463616030556814, 34.42061499186924, 35.26922280447823, 35.684315136500764, 36.648311683109824, 35.744993754795615, 38.884902068546836, 38.734647274017334, 39.76928962979998, 40.29227706364223, 41.97850063868931, 40.45341968536377, 40.71099982942854, 38.87541082927159, 40.20581715447562, 38.726295539310996, 42.13501228604998, 42.80878605161394, 43.535293170383994, 44.59399018968855, 46.81606578826904, 48.20595564161028, 50.90543154307774, 51.650723116738455, 33.66370603016445, 0.27365371584892273, 0.26307049659746035, 1.0386369185788291, 11.90890840121678, 54.94416577475411, 45.56746060507638, 34.374183654785156, 17.711819784981863, 39.23463617052351, 31.01584482192993, 9.346458792686462, 0.33510301421795574, 0.07425933384469577, 0.05430436194209116, 0.04185253867347326, 0.04648258004869733, 0.006450111478833216, 0.0831799115985632, 0.018827049926455532, 0.05599588867542999, 0.016611063121152774, 0.02500109264760145, 0.09450852870941162, 0.00872565245455397, 0.09302780923566648, 0.07017909243170704, 0.03336410969495773, 0.0510678448980408, 0.07004440323050533, 0.011905853636562824, 0.04881451152531164, 0.045099796926868815, 0.02890972068001117, 0.03274410849969302, 0.02806725329719484, 0.02434345311485231, 0.03535952851442354, 0.020692938107198904, 0.050935924119715176, 0.025887149120015756, 0.04855039855465293, 0.04805215368313449, 0.0386753154120275, 0.039033354592642615, 0.07356182020157576, 0.01851271349005401, 0.10950024425983429, 0.04624430229887366, 0.13962132297456264, 0.07288532757333346, 29.953006676265172, 49.655853612082346, 34.53367607934134, 58.25074052810669, 33.11407225472586, 61.51325675419399, 53.01810775484358, 47.68502140045166, 1.3786912028278624, 1.163295743720872, 0.9077645582812173, 0.12911557885152952, 28.143805197307042, 64.14860425676618, 57.183862004961284, 62.39325305393764, 53.81810597011021, 53.90570190974644, 49.83279991149902, 47.42734745570591, 50.54260008675711, 50.127872535160606, 46.1584153175354, 47.52710621697562, 48.58176285879952, 46.652623312813894, 47.41912773677281, 47.918209893362864, 42.837436948503765, 44.472539152417866, 46.16796561649868, 51.10252414430891, 52.9459993498666, 53.481132234845845, 50.44844157355172, 45.3024319921221, 41.3139089175633, 43.2834974016462, 40.48185518809727, 42.49938971655709, 40.55313328334263, 42.26678139822823, 41.14871549606323, 41.80213451385498, 41.542299679347444, 42.199693066733225, 41.69453818457467, 41.01457357406616, 38.99821329116821, 39.99783672605242, 39.940034661974224, 40.8399201801845, 38.80491440636771, 42.10520451409476, 39.332518918173655, 42.27401099886213, 40.30097620827811, 43.15515375137329, 39.3382477079119, 39.457124437604634, 40.552195276532856, 41.43966783796038, 43.86561747959682, 46.90698296683175, 49.35189771652222, 52.602192061288015, 52.5234238079616, 55.82472487858364, 52.08948796136038, 51.474544593266074, 54.28326007298061, 50.755517210279194, 47.8902816091265, 43.79818173817226, 43.91988638469151, 41.66248614447457, 40.81705018452236, 40.52039337158203, 39.64876965114048, 40.32359259469168, 37.333376271384104, 38.0065907069615, 37.29277794701712, 37.26102120535714, 37.12295355115618, 36.016716957092285, 37.117735454014365, 37.664127894810264, 36.639421463012695, 39.29576989582607, 36.907635825020925, 37.95411096300398, 38.2878155708313, 38.55746473584856, 36.9008126940046, 37.62726770128523, 37.27139139175415, 38.78614732197353, 37.046665804726736, 37.59575067247663, 37.454090799604145, 37.25332260131836, 37.35111154828753, 38.084417479378835, 37.23774821417672, 38.89436204092843, 39.55762665612357, 40.59405469894409, 40.35110398701259, 43.3559775352478, 42.885938848767964, 42.04538399832589, 42.76220185416085, 43.21731928416661, 40.51681504930769, 41.64077302387783, 41.08630677631923, 44.318956170763286, 44.68912492479597, 45.981726101466585, 46.51937076023647, 48.927303722926546, 51.51654297964913, 52.507581915174214, 53.272213799612864, 36.00512388774327, 0.42627654331071035, 0.03891658550128341, 2.0733229177338734, 13.264191014426094, 60.26547840663365, 50.900633811950684, 40.24458115441458, 24.534132650920323, 39.089651584625244, 39.84699828284127, 12.998647366251264, 0.21525515163583414, 0.09594603907316923, 0.10758319284234728, 0.021550594496407678, 0.0422230628984315, 0.040787689919982634, 0.05420353503099509, 0.024338243662246635, 0.050532891282013485, 0.02200586604885757, 0.02521957753093115, 0.0035938781137312098, 0.018721541123730794, 0.05919717278863702, 0.04505043689693723, 0.05316886751513396, 0.020644015732354352, 0.19661865809134074, 0.12216032349637576, 0.22296121955982276, 0.1521200601543699, 0.12483475570167814, 0.1418049165180751, 0.18845137634447642, 0.08366686225469623, 0.20424858081553662, 0.11275548887039934, 0.13171124671186718, 0.10926796815225057, 0.11214295495301485, 0.13080051700983727, 0.12581295892596245, 0.12149767976786409, 0.10794774256646633, 0.16779086712215627, 0.2712639426546437, 0.09358072706631251, 0.25898870133927887, 0.24189016169735364, 41.30426134381975, 55.557733399527415, 45.916496413094656, 54.133463859558105, 32.66930764062064, 66.50200080871582, 55.336871010916575, 52.36703722817557, 1.6357365527323313, 1.5561661081654685, 0.5422083767397063, 0.12590469686048372, 28.60264686175755, 65.12233870370048, 59.99465847015381, 66.10928862435478, 55.97304459980556, 56.652776445661274, 52.22576992852347, 51.519290992191856, 53.998463835035054, 54.506193024771555, 48.886545589991975, 51.41485609327044, 49.782376834324424, 49.14563001905169, 49.971864632197786, 51.03908014297485, 45.15822213036673, 46.366083077022004, 51.50257362638201, 57.29655483790806, 56.01067951747349, 57.55349922180176, 53.7708477973938, 47.591119970594136, 43.470070430210654, 45.37434932163784, 43.85824544089181, 45.294538838522776, 43.29588951383318, 45.67317049843924, 43.72702523640224, 43.77775056021554, 44.00644356863839, 45.09062310627529, 43.817803450993125, 43.35022095271519, 41.0632769720895, 43.147972788129536, 43.73484890801566, 43.26576907294137, 41.0834059034075, 44.32683195386614, 40.22167294366019, 43.52687542779105, 40.99057102203369, 44.4509128843035, 40.87929909569876, 41.1528114591326, 41.25030858176095, 42.16637992858887, 46.20693111419678, 47.042830671582905, 52.27877426147461, 53.046213218144004, 54.1966438293457, 56.84969186782837, 54.00319903237479, 53.160274846213206, 55.54851313999721, 52.32771042415074, 48.738708768572124, 45.11456312452044, 45.02813448224749, 43.86848013741629, 43.410413197108674, 42.35626377378191, 39.89070592607771, 42.57592064993722, 38.82262189047677, 40.666517462049214, 38.946893896375386, 39.34335115977696, 38.86682285581316, 38.746775354657856, 40.597316878182546, 40.42056860242571, 38.33727632250105, 41.792851720537456, 37.527175426483154, 39.38682951245989, 41.31666040420532, 41.14744397572109, 41.67409658432007, 38.95209114892142, 38.95016997201102, 40.99238450186593, 38.69472639901297, 39.79846511568342, 39.670038087027415, 40.52799470084054, 38.21782636642456, 39.17898457390921, 39.92749663761684, 39.66837746756417, 40.32359606879098, 43.93058313642229, 43.84495006288801, 44.868899141039165, 45.677068437848774, 45.48580190113613, 44.784777300698416, 45.53075327192034, 42.69392538070679, 44.72390413284302, 42.65088823863438, 46.198207650865825, 47.954851218632285, 47.55180358886719, 49.01977382387434, 52.02803461892264, 53.61448206220354, 55.03186593736921, 54.13632651737758, 37.43560859135219, 0.31923365433301243, 0.30563961235540255, 2.349512291806085, 13.515296305928912, 67.35268265860421, 52.72944484438215, 44.41928121021816, 29.609498160226003, 47.9074957711356, 50.29460498264858, 19.63951757975987, 0.5203866362571716, 0.20031391909079893, 0.28061190247535706, 0.17359135087047303, 0.22290861952517713, 0.058206722007266114, 0.125296485211168, 0.14847393866096223, 0.11950881220400333, 0.11778116705162184, 0.06122981943190098, 0.1788534035107919, 0.11570043941693646, 0.14221545734575816, 0.15867222499634537, 0.1539798296455826, 0.1366610782487052], [0.037022943541939766, 0.04081815953499504, 0.016197623252602558, 0.03845696284302643, 0.06034541010324444, 0.012720741115377417, 0.10048603545874357, 0.04853769637910383, 0.0516628013657672, 0.02391094641227807, 0.03650801349431276, 0.08395440503954887, 0.033844464990709505, 0.020255517114752104, 0.03464084457872169, 0.015873610906835114, 0.06803788018545934, 0.02547670159089778, 0.06837874225207738, 0.06045270684574332, 0.03354391468954938, 0.045644704651619704, 3.438118266207831, 50.04542521068028, 40.278505734034944, 25.49727283205305, 18.50917247363499, 39.07017578397478, 48.583816051483154, 54.501089572906494, 14.024541940007891, 1.408518408026014, 0.8339730607611793, 0.3324046975799969, 2.7362748639924184, 51.800488063267295, 60.205056871686665, 58.51639447893415, 57.91740070070539, 52.72709287915911, 54.25609956468855, 53.135226590292795, 52.31489099775042, 51.86196572440011, 49.945513589041575, 48.20425680705479, 49.89890507289341, 49.34565823418753, 49.93264205115182, 48.67108889988491, 47.96290765489851, 48.987252780369346, 52.180120263780864, 51.68125697544643, 55.75116082600185, 53.282187938690186, 52.18102352959769, 46.602853366306846, 42.3946282523019, 39.90061058316912, 39.18650599888393, 38.29312399455479, 40.36261715207781, 39.33813306263515, 37.93365546635219, 37.22074249812535, 39.19957556043352, 39.07115200587681, 39.86862455095564, 40.03701066970825, 36.58672979899815, 38.013653550829204, 37.655057021549766, 37.41065066201346, 39.10186651774815, 39.173078605106895, 39.663496358054026, 39.440188203539165, 39.28722708565848, 40.38643210274832, 39.16042593547276, 39.25901739937918, 40.84843519755772, 44.84237091881888, 48.156456674848286, 53.31993750163487, 50.04180867331368, 53.061454091753276, 49.50631100790841, 58.740189007350374, 56.97803899220058, 52.27332339968, 56.81074374062674, 52.95869370869228, 47.49852132797241, 45.67242704119001, 46.80127307346889, 48.45607342038836, 47.73115743909563, 47.4754706791469, 43.40804386138916, 37.670808587755474, 38.58000121797834, 36.256540979657856, 36.806859152657644, 34.4573119027274, 35.55107648032052, 37.352730478559224, 33.7819504737854, 34.75170012882778, 34.09942061560494, 37.25845732007708, 36.537751947130474, 37.30185924257551, 36.15936347416469, 35.78452900477818, 35.421443939208984, 34.69981792994908, 36.31656299318586, 37.57247420719692, 36.87841517584664, 35.24449763979231, 37.403170926230295, 37.30014998572213, 37.31314659118652, 35.88692808151245, 35.79295369556972, 36.90723977770124, 40.222065516880576, 42.221548625401084, 42.18829454694475, 43.975888865334646, 44.084037576402935, 43.82208006722586, 43.95001377378191, 43.83291578292847, 41.66543912887573, 42.952902112688335, 41.36304657799857, 41.281238487788606, 42.00834315163748, 43.928252015795024, 47.043473379952566, 48.990699086870464, 51.77741656984602, 51.83896023886544, 53.93914358956473, 4.149564513138362, 0.4292565334056105, 0.3044775261410645, 0.8071280983941895, 23.917999403817312, 48.81700801849365, 39.918304170881, 29.165466581072124, 43.244761194501606, 38.41550261633736, 11.836866872651235, 0.6603360580546516, 0.13201383261808328, 0.049666222251419506, 0.05559383971350534, 0.01073815593762057, 0.05169682650427733, 0.02260792508189167, 0.04183974828837173, 0.05420991665284548, 0.03661102189549378, 0.009652523656508752, 0.030600833506988626, 0.018630863400176167, 0.014744872992326106, 0.06874412657426936, 0.07936023441808564, 0.009377616041872119, 0.021735887142962644, 0.11645068201635565, 0.010387112453047718, 0.06091468741319009, 0.06323212877448116, 0.034381715447774956, 0.025756274981956397, 0.07346232661179133, 0.1371218713798693, 0.02288905231814299, 0.06049102371824639, 0.039019342844507525, 0.03610802049349461, 0.02370680745558015, 0.03533306225602116, 0.07376869874341146, 0.006541616591026208, 0.004565994030729468, 0.027126890274563005, 0.10075547492929868, 0.023953787417017987, 0.03208587524880256, 0.12585177112902912, 5.78474314723696, 59.93587671007429, 38.360948835100444, 34.06630897521973, 30.97209201540266, 47.4039945602417, 54.15366227286202, 56.17674841199602, 14.093532340867178, 1.4757656795637948, 2.4076213794095174, 0.8819744193128177, 3.6235005472387587, 52.94271980013166, 62.398672648838584, 60.24803147997175, 61.2634551184518, 55.69786466870989, 56.78976365498134, 54.87501035417829, 53.81785930906023, 52.13303232192993, 52.23700169154576, 51.64841978890555, 51.85252659661429, 50.8183810370309, 51.784590584891184, 51.69540350777762, 50.02110651561192, 51.10818345206124, 53.452901703970774, 54.48229122161865, 57.160005365099224, 55.63475070680891, 55.047871112823486, 49.62186997277396, 44.374479225703645, 41.721556254795615, 41.084128516060964, 41.97020101547241, 41.775967597961426, 42.944977692195344, 39.943731103624614, 39.86628300803048, 40.784786224365234, 40.908182757241384, 42.33381414413452, 42.80984912599836, 39.83438382829939, 42.04725653784615, 39.115599632263184, 40.23064654214041, 40.344218322208945, 41.630882263183594, 40.036722319466726, 41.66645703996931, 41.309194564819336, 41.797910009111675, 40.74961791719709, 41.245642866407124, 43.39164958681379, 45.50013950892857, 47.962039130074636, 52.695155484335764, 51.08078670501709, 54.27760771342686, 54.52185773849487, 58.199945722307476, 51.81149400983538, 53.36829696382795, 58.11578566687447, 53.66841745376587, 48.94235699517386, 45.034467765263145, 47.303693839481895, 48.58437885556902, 47.75678586959839, 46.9542897769383, 44.21486520767212, 38.60660934448242, 39.86128725324358, 37.54817983082363, 37.28997087478638, 36.915105138506206, 39.04119137355259, 37.795733724321636, 36.49652133669172, 37.16411815370832, 36.769446577344624, 39.001499789101736, 38.73474107469831, 38.47041422980172, 37.91253294263567, 37.16341985974993, 38.81289093835013, 36.907618454524446, 38.89059264319283, 38.82854175567627, 38.569728306361604, 37.96705198287964, 38.360639640263145, 39.194458212171284, 39.9427444594247, 38.553882939474924, 36.31585080283028, 38.111765589032856, 40.72513593946184, 43.61405447551182, 45.26276820046561, 45.35255282265799, 45.588708196367534, 46.81051070349557, 46.62907239368984, 45.121566908700125, 44.093160561152864, 43.51963193075997, 44.08371448516846, 43.10275738579886, 43.576155526297434, 47.18410839353289, 49.4792651448931, 51.43134069442749, 53.1536671093532, 54.31359938212803, 55.37047597340175, 4.143770149775913, 0.7414031880242484, 0.3242647743650845, 0.622915937432221, 27.045324529920304, 53.488205501011436, 45.00615038190569, 31.64798150743757, 42.96431105477469, 41.232649735042024, 22.921540873391287, 0.9093761603747095, 0.09396912729633705, 0.04265728459826537, 0.08970503003469535, 0.029273008328995535, 0.08614597136953048, 0.04231701964246375, 0.04937432327174714, 0.03510568856394716, 0.03628085693344474, 0.02878250554203987, 0.04613266971760562, 0.03526389578889523, 0.022200539442045347, 0.0597269797165479, 0.01965515611560217, 0.018242933055652038, 0.0168610116732972, 0.21196357826037066, 0.11442020668515138, 0.08297451904841832, 0.11077016325933592, 0.0964845312493188, 0.08743374941072293, 0.14848666797791207, 0.21249968877860478, 0.11811036510126931, 0.18523915085409368, 0.15990045480430126, 0.1850934558148895, 0.12061312794685364, 0.11545320839754172, 0.14822501130402088, 0.11524417889969689, 0.18464997889740126, 0.06163225176611117, 0.2873365102069718, 0.09961834523294653, 0.1869347962949957, 0.3514020767595087, 9.364115033830915, 72.7408230645316, 48.75585344859532, 38.343731198992046, 29.604578835623606, 52.107918058122905, 56.44036654063633, 66.19870499202183, 16.375530072620936, 2.7692996518952504, 3.6103143862315585, 0.8596418776682445, 3.982637516089848, 53.41711500712803, 62.91599382672991, 64.20386328016008, 63.35798263549805, 58.01535293034145, 59.357543400355745, 57.93548338753836, 56.686777455466135, 57.017470019204275, 54.39838130133492, 54.09890004566738, 56.78038011278425, 54.62999602726528, 55.87257364818028, 54.84997252055577, 53.368710381644114, 55.7156138420105, 58.571215765816824, 56.66722175053188, 60.28514180864607, 58.3866160256522, 56.167316232408794, 52.985194138118196, 47.76579073497227, 44.709312915802, 43.75596100943429, 44.58983864103045, 44.57368060520717, 44.94972406114851, 41.98056425367083, 42.080163206372944, 44.50566816329956, 43.85557733263288, 45.90724836077009, 45.475876399448936, 42.056056431361604, 43.34390851429531, 41.915921688079834, 42.71864012309483, 44.045176301683696, 44.238770484924316, 43.767786843436106, 43.30945587158203, 43.959501538957866, 44.39671346119472, 43.07308510371617, 41.6350268636431, 46.82995523725237, 47.930421352386475, 51.83197035108294, 55.320038999829976, 51.803010259355815, 55.558386530194966, 55.55979701450893, 57.64987073625837, 50.17830603463309, 55.294681549072266, 58.99570206233433, 54.910307203020366, 49.73117903300694, 46.40550020762852, 49.37648391723633, 50.95281825746809, 50.529131003788535, 50.38418115888323, 46.42134557451521, 40.57307808739798, 41.58872754233224, 39.09774276188442, 39.255852494921, 38.67166880198887, 41.454182624816895, 40.99364907400948, 39.17957864488874, 38.454263142177034, 39.04645115988595, 42.41553885596139, 40.440527302878245, 40.43560797827584, 41.54090656552996, 41.37735291889736, 41.26478862762451, 38.215634209769114, 43.071077074323384, 42.873925413404194, 41.49845654623849, 39.97907658985683, 40.8798063141959, 40.97571577344622, 42.1082443509783, 40.12938696997506, 39.11104161398751, 41.22383941922869, 44.275463921683176, 46.89590406417847, 47.29151712145124, 48.38670955385481, 48.79382535389492, 48.622197900499614, 48.67626878193447, 46.65718133108956, 45.5656749180385, 45.93965823309762, 45.41159861428397, 45.70219659805298, 45.40232624326433, 49.154245785304475, 52.7756746837071, 53.17523084368025, 56.61500603812081, 56.59475898742676, 57.97920492717198, 6.895404441016061, 0.5360265970230103, 0.5770291654126984, 2.7261945477553775, 29.747680459703716, 59.42753260476248, 50.66528442927769, 39.4504576410566, 53.991098744528635, 47.800490038735525, 37.98758043561663, 1.3272081996713365, 0.25208534034235136, 0.1377016388412033, 0.15524738734321936, 0.11809922355626311, 0.31205079119120327, 0.14508339416767868, 0.21089886182120868, 0.1546987782099417, 0.1252635084092617, 0.04965250227334244, 0.19216030303921017, 0.25023435109427994, 0.12321714178792068, 0.12130718784672873, 0.17988831869193486, 0.1187655720859766, 0.10176248196512461], [0.05682891933247447, 0.11260521371981927, 0.1478806004992553, 0.061313550653202195, 0.02934556407853961, 0.08962037600576878, 0.03427688857274396, 0.013993895030580461, 0.028972278216055462, 0.03312779291133795, 0.03153508123276489, 0.03625117102637887, 0.0576323556846806, 0.018011128529906273, 0.0180551417038909, 0.07050961362464087, 0.007686731372294682, 0.06605827462460313, 0.1286198818790061, 0.053074764886072705, 0.07065511867403984, 0.09924365819564887, 0.16931223762886866, 19.17545086996896, 46.320009572165354, 45.475636686597554, 17.837712458201818, 28.558166231427872, 46.10400744846889, 55.895982129233225, 35.296623025621685, 2.1651785373687744, 2.2407918742724826, 0.04208016003082905, 0.15548108837434224, 14.345066683632986, 66.8059080668858, 54.17152956553868, 63.98477268218994, 51.681458473205566, 59.278695242745535, 54.41214568274361, 59.19245420183454, 52.54605409077236, 54.37860672814505, 51.58004604067121, 55.49756894792829, 51.960869857243125, 54.43148946762085, 51.639293330056326, 54.70124980381557, 52.51498869487217, 53.42595311573574, 53.790302753448486, 55.581433704921174, 57.691667624882285, 55.15629775183541, 48.68580518450056, 43.00067445210048, 40.25319692066738, 38.28903150558472, 37.83839218957083, 39.567805767059326, 39.76356084006173, 39.22486352920532, 40.25504861559187, 40.360407624925884, 40.679062434605186, 40.05671228681292, 39.64174154826573, 39.431443895612446, 38.15375702721732, 37.490499360220774, 38.21377556664603, 38.470129353659495, 39.36059658867972, 39.36451884678432, 40.12594413757324, 38.74297816412789, 39.32261426108224, 39.69260583605085, 42.241385732378276, 41.83646208899361, 45.14792490005493, 50.10363721847534, 54.57552215031215, 53.29710572106497, 53.88665689740862, 53.52539225987026, 61.31432982853481, 73.33245522635323, 54.56106294904436, 55.4017984526498, 53.03594725472586, 50.2161146572658, 52.31533915655953, 52.79002618789673, 55.09037324360439, 52.369246755327495, 51.809218474796836, 50.40986170087542, 40.77926935468401, 38.01278155190604, 38.98224980490548, 37.65975052969796, 37.434632369450156, 35.24878467832293, 36.00376551491873, 35.681692191532676, 35.21802152906145, 35.97939818246024, 37.59320068359375, 35.60524811063494, 35.646353653499055, 33.492894990103586, 35.26195151465279, 35.08784008026123, 35.960822173527305, 35.600561550685335, 37.88723802566528, 35.0918596131461, 36.33281830378941, 35.06604358128139, 35.58776296888079, 36.78903007507324, 38.545993259974885, 38.45623295647757, 40.293833460126606, 47.04451560974121, 48.70001425061907, 50.20191601344517, 50.3593795640128, 49.60083082744053, 49.683875696999685, 50.32823773792812, 49.387347425733296, 46.54413414001465, 46.707385540008545, 43.996236664908274, 42.99296889986311, 40.63066823141915, 45.50847387313843, 46.233983925410676, 52.71438809803554, 51.58481250490461, 58.285585744040354, 17.25714703968593, 0.5247808833207402, 0.300493168511561, 0.822648854127952, 1.1333676810775484, 35.15598106384277, 57.62314101627895, 29.685480185917445, 44.2005032811846, 54.79704809188843, 34.901822907584055, 8.810872537749153, 0.47894492000341415, 0.10447092234556164, 0.024062035804880515, 0.09902278147637844, 0.014055799476669302, 0.17172974933470997, 0.12094444302575928, 0.01900023072292762, 0.016365811727674942, 0.06345581462872879, 0.07658474120710577, 0.07889433191823107, 0.030000944089676653, 0.021351846500432918, 0.06976273655891418, 0.01824987955790545, 0.06079453243208783, 0.017003931504275118, 0.02941232853169952, 0.016954427285652076, 0.1137307540380529, 0.06824883672275714, 0.06206365076026746, 0.04680379174117531, 0.0408601031771728, 0.04395885725638696, 0.031194741638111215, 0.03348725701549223, 0.026343194202386906, 0.04693825702582087, 0.041367803434176106, 0.03978407895192504, 0.008014390843787363, 0.031816863255309205, 0.02832012463893209, 0.02844462902950389, 0.010095814825035632, 0.05091247734214578, 0.020634865687627877, 0.05977911834738084, 0.25725702568888664, 26.661306279046194, 49.75804424285889, 38.40417010443551, 26.328313861574443, 36.54699305125645, 49.62363134111677, 62.88493537902832, 36.494447299412315, 0.9392577026571546, 3.3849030988556996, 0.29484678006597925, 0.2699946479073593, 16.89551067352295, 67.21592126573834, 56.82056501933506, 66.62934044429234, 55.866257735661094, 60.5595053264073, 57.63207639966692, 59.20601708548409, 54.57935060773577, 56.574577944619314, 53.82468938827515, 56.7884886605399, 54.49585410526821, 56.07097945894514, 53.22544894899641, 56.89012343542916, 55.13938931056431, 56.414814540318076, 55.62750373567854, 59.280522618974956, 59.786587715148926, 58.08209037780762, 51.34234469277518, 45.94946908950806, 42.65608549118042, 40.91146578107561, 40.90030002593994, 42.72541809082031, 42.04836130142212, 40.32270322527204, 40.72292641230992, 42.290193353380474, 41.855441093444824, 42.32823821476528, 40.434009892599924, 41.90669795445034, 38.942176069532124, 39.87256070545742, 38.52404737472534, 39.59476130349295, 41.55995852606637, 41.590596607753206, 41.60101195744106, 41.609151772090364, 42.08664240155901, 40.408173016139436, 41.54512412207467, 44.510361671447754, 47.757227080208914, 52.5641576222011, 56.522449084690635, 54.03458751950945, 55.2194047655378, 55.49851042883736, 62.69944626944405, 56.30600922448294, 47.58627012797764, 57.09383419581822, 49.931071758270264, 52.473108427865164, 51.97306741986956, 51.282451220921104, 54.18053443091256, 54.16715567452567, 54.11651720319475, 51.15443761008126, 40.94347960608346, 39.06074013028826, 38.3179429599217, 38.51938165937151, 38.80786739076887, 37.35704183578491, 37.51426567350115, 36.7273404938834, 37.70472274507795, 38.52744851793562, 40.21766035897391, 37.89420359475272, 40.306093556540354, 35.5631559235709, 36.68456390925816, 38.41358838762556, 38.268912996564595, 37.46677473613194, 38.9935336794172, 37.74763829367501, 38.73898989813668, 36.75784655979702, 36.345325061253135, 39.33646896907261, 40.94115195955549, 39.40446751458304, 41.419994013650076, 48.354480334690635, 50.639364174434114, 50.23675080708095, 50.97497606277466, 49.78456204278128, 52.12102236066546, 52.03368003027779, 50.34549706322806, 48.62909051350185, 48.52292551313128, 46.25512729372297, 45.329849583762034, 43.11599717821394, 47.59163066319057, 50.82032653263637, 55.53309856142317, 53.761043889181956, 59.93239566258022, 17.90836868967329, 0.667596654168197, 1.1431015644754683, 0.9023063683084079, 1.105789195213999, 37.60677746364048, 63.39031260354178, 34.78968940462385, 51.84471334729876, 54.661540848868235, 38.48175368990217, 14.70321158000401, 0.6255399680563382, 0.11005269390131746, 0.08047067054680415, 0.06787173410079309, 0.021644615701266696, 0.18057472471679958, 0.08376816753298044, 0.02994616256494607, 0.01360802912885057, 0.05504361566688333, 0.061049173053886206, 0.024126722244545817, 0.04427228615220104, 0.00786295285381909, 0.035706527930285246, 0.12003173200147492, 0.03917997243947216, 0.02313334188823189, 0.09735273037637983, 0.1827852561005524, 0.19317304369594368, 0.11621889445398535, 0.13429349314953598, 0.19125027901359967, 0.11383776579584394, 0.11820198089948722, 0.1034762646470751, 0.19741797234330857, 0.20407541867877754, 0.26028543604271753, 0.11958771225597177, 0.12499798408576421, 0.10081251936831645, 0.14626922910766943, 0.08683019251163517, 0.12501059126641068, 0.15263419970870018, 0.18848936073482037, 0.13326355841542992, 0.165275225681918, 0.41888273720230373, 37.63538319723946, 57.717181410108296, 55.853063106536865, 29.533137457711355, 41.432007449013845, 54.904613154275076, 67.7824148450579, 40.99649783543178, 6.22768429347447, 7.7089394841875345, 0.1958825018789087, 0.3079108047698225, 16.55582540375846, 68.76526532854352, 59.086584499904085, 69.04123388017926, 57.400666645595, 62.216664586748394, 60.395305497305735, 63.318183353969026, 57.25178064618792, 60.48259571620396, 56.18225138528006, 62.02749293191092, 56.76552833829607, 60.28186920710972, 56.84991768428257, 60.30666037968227, 58.12871279035296, 59.30002621241978, 60.187477929251536, 60.60587065560477, 62.86669635772705, 60.15498815264021, 53.881925174168174, 48.00882829938616, 44.502961839948384, 44.41167640686035, 43.43273775918143, 43.88551017216274, 44.794355392456055, 42.35159111022949, 43.121086733681814, 45.345243317740305, 45.377896377018516, 44.49192810058594, 43.43802186420986, 43.99847745895386, 41.94003888538906, 41.82827363695417, 41.275259562901084, 42.07297876902989, 46.07875074659075, 44.532588958740234, 43.680628640311106, 42.685288769858225, 43.13725519180298, 42.735333170209614, 45.441875389644075, 44.5439145224435, 49.81591578892299, 53.96334416525704, 58.035936968667166, 55.81285388129098, 56.935696669987266, 56.58700132369995, 65.375718661717, 57.56242765699114, 47.58656195231846, 58.16930416652134, 53.381581919533865, 54.23228461401803, 54.3487468447004, 54.12008162907192, 57.13980695179531, 55.235451630183626, 54.78371449879238, 51.18797309058053, 43.35438987186977, 39.59132889338902, 41.317237104688374, 41.702907289777485, 40.7841191973005, 38.91758986881801, 39.50882945741926, 38.92686571393694, 39.217491490500315, 39.49965436117989, 42.24103832244873, 39.49528047016689, 41.83949497767857, 37.43894372667585, 39.498869214739116, 40.4218818119594, 40.790101596287315, 40.23539216177804, 41.45198351996285, 39.76146248408726, 40.40300703048706, 38.98739147186279, 40.01037127631051, 41.78848130362374, 43.3703498840332, 41.730818203517366, 45.61479868207659, 51.301739420209614, 52.80108424595424, 53.17385510035923, 54.45464433942522, 53.00333935873849, 54.41633197239467, 55.01900134767805, 52.72377511433193, 49.34663793018886, 51.68306350708008, 47.94326857158116, 47.53424549102783, 43.67074482781546, 50.074982847486226, 51.6229372705732, 57.82937049865723, 54.832195554460796, 62.67913668496268, 20.736929961613246, 0.3353413428579058, 0.8247231628213609, 1.9592808314732142, 3.697678864002228, 41.119105747767854, 70.93830054146903, 38.523158005305696, 55.191222872052876, 58.363422938755576, 48.186615330832346, 23.998443910053798, 0.534281784934657, 0.1278260773313897, 0.08008906923766647, 0.194224637267845, 0.11729114263185433, 0.2574280436549868, 0.1480702238955668, 0.10452146641910076, 0.08735645070139851, 0.11250300598996026, 0.20476996712386608, 0.16448109543749265, 0.13112359467361653, 0.19553024720932755, 0.21453962288796902, 0.23775503358670644, 0.1027290483138391, 0.11284323701901094], [0.022204714128747582, 0.027313380535425882, 0.05088925448113254, 0.026504782228065387, 0.02967341523617506, 0.10534516721963882, 0.03869850095361471, 0.044789319658385854, 0.07590245388980423, 0.06431540314640317, 0.06399701415960278, 0.017758501460775733, 0.03812814477298941, 0.07100649124809674, 0.06237708644143172, 0.006125098717997649, 0.03971595064337764, 0.04770741378888488, 0.09208776003548078, 0.030856831198824302, 0.030591625786785568, 0.05537690528269325, 0.0753829131967255, 2.7837104329041074, 49.07995217187064, 33.41923018864223, 30.536571979522705, 18.52553721836635, 37.242709227970664, 49.097881998334614, 55.906279359545024, 2.886172477688108, 3.169686121600015, 0.11236055434814521, 0.029225290353809084, 0.18493653780647687, 46.87778663635254, 65.27005740574428, 54.963325432368684, 62.68425055912563, 52.62712567193167, 61.084254128592356, 54.83091708592006, 58.15039116995675, 54.16065216064453, 56.56348167146955, 51.51613303593227, 56.425268105098176, 53.779915196555, 55.956983838762554, 52.181878158024375, 55.50648348672049, 55.29598433630807, 54.142493043627056, 55.76805189677647, 54.1838105065482, 52.14207887649536, 47.6588579586574, 42.1682767868042, 41.51250580378941, 38.11677524021694, 38.30896241324288, 40.501813888549805, 41.952382360185894, 40.702609879629954, 39.09217725481306, 39.079232760838096, 38.1960437638419, 39.06968246187483, 38.20271403448922, 39.02492911475045, 36.95439372743879, 37.49045419692993, 37.95381219046456, 38.866937501089915, 37.845993518829346, 39.296416078295024, 40.59792831965855, 42.142540659223286, 40.06819071088518, 40.32372808456421, 40.0199111529759, 39.27246216365269, 46.75846522194998, 53.9388621875218, 55.27204779216221, 54.59423017501831, 55.87989010129656, 51.752819946834016, 49.45433153424944, 67.26836626870292, 67.16911125183105, 58.898531505039756, 56.48862872804914, 54.12690476008824, 54.7207464490618, 54.964131423405235, 51.43298394339425, 51.531016077314106, 52.086531502859934, 52.32222482136318, 42.9570814541408, 38.76113380704607, 38.358864375523154, 38.11228322982788, 36.76211970193045, 37.648626463753835, 36.39875323431832, 35.63520874295916, 35.92170034136091, 35.941916125161306, 36.49993290219988, 36.41186795915876, 38.13130392347063, 36.907114710126606, 35.9560626574925, 37.85021802357265, 36.77425125667027, 35.95124755586897, 35.42034264973232, 35.550305230276926, 36.55619246619088, 34.67308473587036, 36.48844405582973, 36.08329112189156, 36.21968078613281, 38.725885595594136, 42.176840441567556, 51.49103961672102, 50.38217312949044, 53.40096739360264, 51.37953839983259, 53.94588334219796, 50.0938333102635, 51.00648614338466, 51.2783830506461, 50.3803596496582, 46.53056083406721, 47.31102418899536, 43.805380071912495, 44.38382107870919, 45.73037154333932, 51.732513836451936, 51.77837542125157, 55.615604945591514, 39.51249463217599, 0.31942171709878103, 0.29626391402312685, 0.14908312740070478, 1.1308150866201945, 2.9364229355539595, 47.21977349690029, 46.056513037000386, 20.36682547841753, 27.058623382023402, 28.917290823800222, 36.901403290884836, 5.172642460891178, 0.45026959585292, 0.18176948917763575, 0.0700519010424614, 0.0419424818828702, 0.060349902005067894, 0.02635605413732784, 0.07484936075551168, 0.06741549393960408, 0.1101407745320882, 0.11520501385842051, 0.0231681778760893, 0.04420630540698767, 0.039485272485762835, 0.06311395511563335, 0.018877532931842973, 0.007115004550931709, 0.051769534924200604, 0.05422676128468343, 0.037999158658619435, 0.09299628449870007, 0.015527366361181651, 0.07198018221450703, 0.01880210528283247, 0.13325575526271546, 0.08624102734029293, 0.06474560113357646, 0.06087109832359212, 0.08129070047289133, 0.023644205814759647, 0.019237353266882043, 0.0627800819597074, 0.0133646920522941, 0.08804688043892384, 0.06006484944373369, 0.013208619668148458, 0.005100387855366404, 0.011500750418885477, 0.014943617595625775, 0.09505747032484838, 0.06431730982980557, 0.028242810662569742, 4.320028577532087, 58.31308323996407, 33.87056432451521, 28.104150090898784, 27.47585575921195, 41.951611110142295, 54.10473305838448, 60.24941417149135, 3.1287156343460083, 3.55547616311482, 1.7391989209822245, 0.26462567171880175, 0.4015219302049705, 50.3405499458313, 65.13064874921525, 54.679623535701204, 65.61607074737549, 55.10743454524449, 60.51640565054757, 57.11251790182931, 58.94996207101004, 56.77619729723249, 58.186549595424104, 54.44454860687256, 59.26693194253104, 56.685054302215576, 59.67577089582171, 55.595653193337576, 57.700603008270264, 56.29519435337612, 56.970871925354004, 57.52847875867571, 55.74006455285208, 54.76199095589774, 48.71919475282942, 47.10024363654, 44.19762325286865, 41.34652028764997, 40.88375289099557, 42.82961327689034, 44.09519985743931, 43.363731724875315, 41.651695592062815, 42.04009294509888, 40.59639624186924, 41.720621722085134, 41.311438832964214, 41.96105023792812, 39.835599763052805, 39.877299376896445, 40.78874669756208, 40.6539169039045, 39.18363291876656, 41.948241233825684, 41.08973918642317, 42.07367358888899, 40.825707639966694, 43.2970290184021, 41.50160755429949, 42.02835396357945, 48.73670768737793, 57.05752985818045, 56.81113978794643, 54.37002917698452, 55.340035915374756, 54.766698360443115, 54.87071984154837, 67.84492083958217, 57.18435532706124, 59.96825531550816, 58.03382471629551, 55.19096231460571, 56.6913354737418, 55.11488996233259, 51.76939834867205, 52.66087654658726, 52.225175857543945, 54.86508137839181, 44.91940559659685, 40.42944145202637, 40.708526270730154, 40.253683294568745, 37.68930121830532, 39.16550506864275, 38.19385160718645, 38.05102791104998, 37.566870485033306, 38.33391686848232, 37.48869282858712, 38.592556612832205, 40.01320614133562, 39.23983689716884, 37.31678744724819, 39.93182536533901, 37.60081243515015, 39.200596945626394, 37.85773597444807, 38.40545204707554, 37.385727473667686, 37.90702996935163, 38.38314485549927, 38.02550022942679, 38.870529719761436, 41.41524839401245, 45.22748524802071, 53.0796548979623, 52.16888502665928, 52.580951418195454, 52.78685780933925, 55.64515910829817, 51.56913389478411, 53.10796880722046, 52.8690619468689, 52.76412330354963, 48.121545451028005, 49.68702670506069, 43.662955897195, 46.252163887023926, 47.64627824510847, 54.87885965619768, 55.502800941467285, 56.792834758758545, 42.53291130065918, 0.5621878675052098, 0.8119529709219933, 1.8606114174638475, 1.75971554006849, 3.7583926575524464, 52.7611460004534, 51.74466970988682, 25.012024538857595, 38.691926274980815, 33.122257232666016, 42.66218253544399, 7.542845402445112, 0.7377538095627512, 0.18511295691132545, 0.07515659462660551, 0.04239175688209278, 0.09083691465535335, 0.032612065585064035, 0.04970690042578748, 0.0670934272930026, 0.07205357256212405, 0.08149498701095581, 0.041973552001374106, 0.08645485408071961, 0.049422896201057095, 0.036719377152621746, 0.025004956904532652, 0.030767166188785007, 0.05723083258739539, 0.08883464602487427, 0.16217854113451072, 0.1945533739136798, 0.13914010593933718, 0.16760611560727867, 0.13119112247867243, 0.3427343618656908, 0.18633616556014332, 0.11852337579642024, 0.12492301953690392, 0.107753321927573, 0.13945584185421467, 0.21230520707155975, 0.16641169041395187, 0.15602407923766545, 0.17575580972645963, 0.14076698864144938, 0.09153689138059105, 0.15702286921441555, 0.23178699240088463, 0.06411153051470007, 0.16445915161498956, 0.17117784252124174, 0.15221580144550118, 7.14570243869509, 67.99381378718785, 44.66313518796648, 43.69017546517508, 30.03079523359026, 47.9586067199707, 58.23773002624512, 67.81065232413155, 3.8583186098507474, 8.722600885799952, 1.0924349746533801, 0.24026968436581747, 0.7466104286057609, 50.98581525257656, 66.37329237801688, 56.72990492412022, 67.24001067025321, 56.96176978519985, 66.52626391819545, 60.52804388318743, 61.40043190547398, 58.70570509774344, 62.07455308096749, 55.65432030814034, 62.34979207175118, 59.79313291822161, 63.216739654541016, 56.54227229527065, 60.795980317252024, 58.78018978663853, 57.45402533667428, 59.108228138514924, 57.963046891348704, 56.45750079836164, 52.94532190050398, 48.56239128112793, 46.46940279006958, 44.03893334524972, 44.433632714407786, 45.136686188834055, 47.20168386186872, 46.092681884765625, 43.43505150931222, 44.177428313664024, 42.69163247517177, 44.30279813494001, 43.285859789167134, 45.40826347896031, 41.30984769548689, 42.67132636478969, 42.52686289378575, 43.58887072971889, 42.61166565758841, 43.59812225614275, 44.30031762804304, 45.749211583818706, 43.555602754865376, 45.20060614177159, 45.52814074925014, 44.37808534077236, 50.40277106421334, 56.19485541752407, 57.32294757025582, 56.74196004867554, 58.53470298222133, 55.13356672014509, 53.77447475705828, 71.29490293775285, 58.95692416599819, 58.801520756312776, 59.9572354725429, 56.39360863821847, 60.31641565050398, 57.53603145054409, 55.44555125917707, 53.70962027141026, 53.486972195761545, 55.149186270577566, 46.54229634148734, 42.34032113211495, 40.62101718357631, 41.71318367549351, 40.07572603225708, 41.008083956582205, 41.37410463605608, 40.26751715796334, 39.200072356632774, 41.03465039389474, 39.96659067698887, 40.77864749091012, 42.92943804604666, 41.10697419302804, 40.4315641266959, 40.626541001456125, 38.5349907875061, 41.95110389164516, 39.32181869234358, 40.81581687927246, 39.39418765476772, 39.415424823760986, 42.133730343409944, 40.36776576723371, 40.856748717171804, 43.032292229788645, 48.573209626334055, 56.01242004122053, 53.63309628622872, 56.01409455708095, 55.43426043646676, 57.81994179316929, 53.9858980178833, 53.86766052246094, 55.73392581939697, 55.374738693237305, 50.11864880153111, 51.55379574639456, 45.91620806285313, 48.774724755968364, 50.54820033482143, 55.306017535073416, 56.49295745577131, 60.44877883366176, 44.89406899043492, 1.0017732509544917, 0.8843075484037399, 1.822626267160688, 3.493182522909982, 4.737608798912593, 57.91673019954136, 54.88804864883423, 29.347238404410227, 40.65496608189174, 38.48993519374302, 52.315908908843994, 11.430009024483816, 1.0412017809493201, 0.36439385105456623, 0.1456362237887723, 0.26343807258776253, 0.19588605740240642, 0.0937555448285171, 0.09637882906411376, 0.18041822740009852, 0.12962035462260246, 0.3063000169183527, 0.08529543450900487, 0.18634144456258842, 0.12687848960714682, 0.13844700955918857, 0.15002639964222908, 0.2115213091352156, 0.11214883106627635, 0.2570138658796038], [0.08048361699495997, 0.021535098452919295, 0.02125711283380432, 0.03541782485055072, 0.026249727699905634, 0.018367459498611943, 0.03025005804374814, 0.023032477657709802, 0.009810780075245669, 0.019817846760685955, 0.0191375458546515, 0.062401188005294116, 0.10206031134085995, 0.032619624465171776, 0.11726469333682742, 0.017247576466096298, 0.08878737927547523, 0.042888875385480266, 0.05220338003709912, 0.06002989810492311, 0.021370263637176583, 0.015403482830151916, 0.05817216421876635, 0.15917181675987585, 17.185787303107126, 45.35497426986694, 32.52821752003261, 24.985937527247838, 24.140181950160436, 48.264897210257395, 60.217514991760254, 12.099804077829633, 3.4065402235303606, 1.1776476821729114, 0.21074605573500904, 0.052410194118108065, 1.6451426765748431, 60.525785718645366, 59.7132842200143, 55.08439084461757, 55.63786697387695, 53.82858385358538, 55.93502058301653, 59.353548186165945, 58.89953204563686, 59.57779434749058, 56.98221138545445, 54.75530331475394, 56.28333725248064, 58.03349815096174, 56.530297074999126, 55.78056560243879, 57.28002854755947, 57.69108050210135, 56.86410590580532, 54.51201214109148, 48.40425375529698, 44.25764874049595, 43.27732045309884, 39.39511176518032, 40.824919019426616, 39.531136648995535, 41.081547260284424, 40.78651632581438, 40.95743158885411, 39.71226576396397, 38.7694855417524, 40.941436835697715, 38.49935695103237, 39.991625036512104, 37.63618918827602, 39.82506629398891, 38.64439017432076, 39.346523012433735, 39.95552567073277, 40.955096994127544, 42.66773762021746, 44.7957832472665, 45.8193883895874, 44.58699335370745, 44.16182960782732, 40.834479740687776, 41.9967292376927, 40.9679720061166, 48.62319844109671, 57.72942761012486, 52.85242101124355, 54.56076765060425, 55.22950397218977, 48.51193346296038, 16.751241752079554, 18.340847151620046, 73.61170332772392, 52.82725811004639, 55.08504397528512, 53.09323515210833, 53.67668233598982, 51.58145999908447, 53.791681970868794, 50.66468688419887, 49.43670048032488, 41.30477203641619, 40.937914099012104, 38.31728288105556, 37.12513181141445, 35.067589555467876, 36.215953077588765, 35.77255378450666, 36.55235358646938, 36.322576659066335, 36.34345946993147, 35.5737692969186, 35.27898154939924, 37.2238552910941, 36.90731968198504, 34.925384249006, 36.265903677259175, 36.24652515138899, 37.32629605701992, 36.719839913504465, 37.45141921724592, 35.82918855122158, 37.0998785836356, 34.77978822163173, 37.40597105026245, 37.73817137309483, 36.90317160742623, 39.79962893894741, 49.29268864222935, 50.003704752240864, 51.90057686397007, 49.75251347678048, 51.776871136256624, 51.649788584027974, 51.9123158454895, 50.05743517194475, 52.447247232709614, 47.53015300205776, 49.297673974718364, 45.157086099897114, 46.878432818821494, 45.44398764201573, 55.97660902568272, 49.56802143369402, 58.98190293993269, 12.34432942526681, 0.3739230068666594, 0.5768117627927235, 2.2143663551126207, 1.71287773336683, 4.413485322679792, 55.71606894901821, 32.41311018807547, 28.63016172817775, 28.737198727471487, 28.387330872671946, 30.068252972194127, 0.2530543426317828, 0.0471161112322339, 0.03767255261274321, 0.03202076981376324, 0.046797284590346475, 0.09006764593401126, 0.03049637982621789, 0.12894039468041488, 0.01833936305982726, 0.056306725567472835, 0.01724354427174798, 0.04381860067535724, 0.04765129215749247, 0.0637511062834944, 0.020945441343688538, 0.05163574817457369, 0.039916966642652235, 0.022745119773649743, 0.02893371707094567, 0.03622613647686584, 0.039708551218999286, 0.08982010957385812, 0.037803533620068004, 0.022065531329384873, 0.12376234467540469, 0.03248555612351213, 0.008953783561342528, 0.015154239954426885, 0.04891556574563895, 0.024017038755118847, 0.019256835703604987, 0.09936147901628699, 0.15170300539050782, 0.16595768263297422, 0.0490570131556264, 0.08071682269551925, 0.026953365121568953, 0.048320212334926636, 0.0239689424966595, 0.06394746074719088, 0.05598854014117803, 0.12494100071489811, 0.22281073406338692, 24.90169061933245, 50.509262629917686, 31.17044571467808, 36.65441220147269, 31.1160170010158, 55.29827724184309, 64.56828934805733, 14.543381299291338, 2.7360138722828458, 3.6670941965920583, 0.9048179792506355, 0.6501365367855344, 2.3961334015641893, 63.45268658229283, 57.97528961726597, 56.23315388815743, 56.329389912741526, 56.06409726824079, 56.93232331957136, 62.20302527291434, 60.99250316619873, 62.02203164781843, 58.656720297677175, 57.41925655092512, 58.22114815030779, 59.657907077244346, 57.9442902292524, 57.97031123297555, 57.83007574081421, 59.44709873199463, 58.576003074645996, 55.899761949266704, 50.21137251172747, 45.11623764038086, 44.703316620418, 40.57134798594883, 43.9867627961295, 41.63798679624285, 43.11977352414812, 42.190775053841726, 43.008710043770925, 43.20907872063773, 40.35477263586861, 43.24859312602452, 40.92185681206839, 41.449784415108816, 39.4092617716108, 41.46978827885219, 41.39276054927281, 42.888297762189595, 41.40677159173148, 41.78911706379482, 43.261728695460725, 46.36715657370431, 46.59657219478062, 46.07749659674508, 45.91691330501011, 42.56497376305716, 42.852264404296875, 43.498686586107524, 53.437209197453086, 61.527194840567454, 55.369996547698975, 56.66734334400722, 54.737335273197715, 50.742541449410574, 24.801994391850062, 24.053656033107213, 65.28675392695835, 50.81095341273716, 56.202415057591026, 53.731020723070415, 55.44431447982788, 51.071590764181956, 54.25503996440342, 52.799764088221956, 51.85454157420567, 43.31166887283325, 40.83236748831612, 40.15788500649588, 38.492578983306885, 36.9946585382734, 37.505667277744834, 37.85066270828247, 38.554893902369905, 37.45029360907418, 38.1377066884722, 37.17162568228585, 37.35817091805594, 38.15863813672747, 37.21930769511631, 36.517841884068076, 38.188768999917166, 37.85210793358939, 39.39037309374128, 38.372646127428325, 40.12637839998518, 37.07847465787615, 39.70209360122681, 36.268484933035715, 38.92491327013288, 37.17180980954851, 38.63952643530709, 41.663837569100515, 50.760961123875205, 53.63707412992205, 53.58549417768206, 51.3562410899571, 55.056684902736116, 51.91022443771362, 54.40022604806082, 53.18859222957066, 54.28742899213518, 49.20981747763497, 50.56784289223807, 46.06476402282715, 50.010659899030415, 46.37883302143642, 57.71450982775007, 53.33726978302002, 62.685549872262136, 13.444854600088936, 0.37561554461717606, 2.533854080098016, 3.6479267222540717, 1.2901532394545419, 6.253475572381701, 61.2596891948155, 37.52270426068987, 33.65671961648123, 32.20450789587838, 32.765793800354004, 37.07272154944283, 0.4586886412331036, 0.031630761455744505, 0.055238110944628716, 0.040577852965465615, 0.07503136420356375, 0.04050804528274706, 0.05812773374574525, 0.12532598791377886, 0.029915458855352232, 0.04116163396143487, 0.022940824540065866, 0.02630688070452639, 0.04736697241397841, 0.06146467397255557, 0.026364276285416315, 0.06599385450993266, 0.03425535526392715, 0.08454479157392468, 0.03542406398004719, 0.1777281617479665, 0.1908290037619216, 0.22808832515563282, 0.1619456679161106, 0.15351902294371808, 0.2132555903600795, 0.12367418940578188, 0.12097201868891716, 0.05709976676319327, 0.15274020044931344, 0.21754862714026654, 0.15818658391279833, 0.2088621032557317, 0.33588772639632225, 0.23084410013897078, 0.18712907444153512, 0.2548823431134224, 0.10250548459589481, 0.1451034788042307, 0.12287024754498686, 0.1731182084019695, 0.22393240673201426, 0.1619607585349253, 0.3129920278276716, 32.89366149902344, 61.856754847935264, 47.466528347560335, 39.31719814028059, 35.94598082133702, 58.14384249278477, 73.1686097553798, 15.212255716323853, 7.873166237558637, 5.614363764013563, 0.5680470445326397, 0.4153667044426714, 2.510606493268694, 64.91830485207694, 60.08668041229248, 55.37343938010079, 58.48322377886091, 56.723985058920725, 59.6247433253697, 64.27014214651925, 64.47529465811593, 65.09313542502267, 61.94340583256313, 61.449625151497976, 60.6775552204677, 63.45229748317173, 59.56978307451521, 59.53802285875593, 60.88773822784424, 63.82123293195452, 62.115255628313335, 59.600188391549246, 53.05709409713745, 47.590887205941335, 46.776294299534385, 43.88009752546038, 46.63656255177089, 45.128376143319265, 46.27949462618147, 43.18567023958479, 46.34631545203072, 44.7725693157741, 43.17249992915562, 47.27522359575544, 43.42323957170759, 45.645092827933176, 41.65619455065046, 43.41298403058733, 43.66170869554792, 44.27649572917393, 43.94301693780081, 44.30324976784842, 47.63800988878523, 48.55599199022566, 49.26468392780849, 48.12752437591553, 48.135841369628906, 45.26252848761422, 44.145025389535085, 44.65275110517229, 54.234334332602366, 63.961357252938406, 56.46893753324236, 56.60828365598406, 57.11106225422451, 53.589006492069785, 29.923681804112025, 26.705133778708323, 66.21613107408795, 52.650596686771934, 58.093673024858745, 55.61454881940569, 56.97363730839321, 52.64056348800659, 57.30306877408709, 53.68657309668404, 54.353426456451416, 43.129087584359304, 43.98438651221139, 41.51095288140433, 41.28332642146519, 37.79752288545881, 38.68007264818464, 38.66131946018764, 40.71790286472866, 39.28671291896275, 39.733975410461426, 40.19101749147688, 39.48575101579939, 40.608315876552034, 40.0405090876988, 37.52363184520176, 40.44660002844674, 39.50199243000576, 43.10860429491316, 40.21724694115775, 42.00386503764561, 39.223098686763215, 41.19763081414359, 37.137999875204905, 41.22441611971174, 40.911312920706614, 41.54535688672747, 42.99285772868565, 53.68644455501011, 53.022634506225586, 56.530022621154785, 52.73192535127912, 55.62450211388724, 53.16463484082903, 56.92866856711251, 53.600884437561035, 57.045905521937776, 50.67875351224627, 54.49317557471139, 48.885131631578716, 52.9216285433088, 48.46206971577236, 60.96103477478027, 56.72744178771973, 65.56493200574602, 14.571647439684186, 0.31856318031038555, 1.8693366178444453, 6.327349254063197, 5.658445741449084, 5.743619799613953, 69.61443941933769, 41.563387462071006, 40.268201555524556, 41.25953926358904, 40.27309308733259, 47.35999161856515, 0.7750557022435325, 0.2106532457151583, 0.2839097726557936, 0.13957557614360536, 0.1379584643457617, 0.13255397363432816, 0.13276961206325463, 0.2172305027821234, 0.07361232356301375, 0.11812130308576993, 0.16896543838083744, 0.13194652194423334, 0.15581992162125452, 0.3054802380502224, 0.23734867253473826, 0.22785300921116555, 0.11483860494835035, 0.19599303523344652, 0.14431690743991307], [0.09958496131002903, 0.011375210414241468, 0.10837506356516055, 0.03095600926982505, 0.030454483681491444, 0.09828794162188258, 0.029858953851674284, 0.056352299372000356, 0.04048946360126138, 0.022899980124618326, 0.03498588302837951, 0.08457966148853302, 0.009497290959448686, 0.057361742348543236, 0.14813359906630857, 0.050617111048528125, 0.01716505134079073, 0.02066598499992064, 0.011654991606649543, 0.052494322282395194, 0.054729260570768795, 0.060625963977405, 0.10745090565511159, 0.06269113958946296, 0.25572361797094345, 33.742981501988, 30.243323257991246, 20.670178617749894, 28.488698141915457, 30.388071605137416, 60.56125627245222, 31.259337493351527, 0.3918019974870341, 2.463329864399774, 0.5083984423960958, 0.11952806902783257, 0.032614348855401785, 2.236856588295528, 58.66702447618757, 56.470726694379536, 56.752385820661274, 54.92051410675049, 56.32619374138968, 54.93845435551235, 55.95570189612252, 55.532532283238, 54.31751469203404, 56.432178088596885, 58.0997040612357, 56.95769119262695, 58.82628413609096, 57.8590532030378, 57.15425225666591, 55.78949751172747, 53.616740226745605, 49.07346255438668, 43.89755834851946, 41.99154935564314, 41.70056922095162, 39.219343185424805, 40.140257426670615, 39.908812931605745, 42.24269546781267, 40.72582033702305, 41.49013955252511, 42.03526394707816, 38.95237602506365, 39.89082751955305, 41.1255328314645, 40.247603620801655, 38.962808745247976, 38.97123343603951, 41.51937757219587, 40.33225352423531, 42.20918083190918, 42.02661691393171, 46.907726424080984, 49.23748867852347, 48.82752064296177, 49.15045901707241, 47.82827935900007, 45.42278521401541, 44.296437059129985, 41.45838975906372, 39.79812812805176, 52.99784333365304, 53.280436992645264, 58.247572149549214, 53.27368681771414, 55.26824712753296, 21.862499918256486, 22.49022970880781, 63.83874934060233, 62.71042442321777, 55.55614226205008, 50.762076309749055, 51.625125953129356, 52.03049428122384, 50.87667294910976, 48.02307210649763, 45.72140489305769, 37.87781974247524, 39.379999433244976, 38.41181312288557, 37.19109106063843, 37.2456031526838, 38.03811468396868, 35.71223299843924, 38.25572531563895, 34.37808854239327, 35.42049551010132, 34.32025521142142, 35.015540599823, 35.435250009809224, 36.52713509968349, 36.7945191519601, 37.816946574619834, 37.29706151144845, 36.859957286289756, 36.92342560631888, 37.17331409454346, 36.12724542617798, 36.47690657206944, 35.729422841753276, 37.044907910483225, 36.91396910803658, 39.15570116043091, 38.793171950748985, 46.85349920817784, 50.992593220302034, 51.1995974268232, 51.18856716156006, 53.40304837908064, 51.91821486609322, 51.164543764931814, 49.399624892643516, 49.89346463339669, 48.340993881225586, 50.4570642880031, 46.44603599820818, 48.751538617270334, 45.70446171079363, 52.57590702601841, 49.68762425013951, 52.619152614048545, 3.634045958518982, 0.1155514195561409, 1.976422254528318, 1.2257669972521918, 1.651262411049434, 12.892386828150068, 62.45309094020298, 21.391325201307023, 30.39779908316476, 29.63035317829677, 40.287468910217285, 8.740771293640137, 0.23026395269802638, 0.01830277984429683, 0.12633841644440377, 0.03145564513813172, 0.014695921779743262, 0.07557605140443359, 0.028680467445935522, 0.06206846157354968, 0.03030545703534569, 0.08048158138990402, 0.03293973693091955, 0.03406543331220746, 0.020112524341259683, 0.024964331316628625, 0.03300648781337908, 0.07911254199487822, 0.02266698476991483, 0.05786591422344957, 0.040599756075867584, 0.09235213084944657, 0.04736708437225648, 0.06627052716378655, 0.08810616404350315, 0.12418864108622074, 0.02188087480940989, 0.06023005236472402, 0.09475119318813086, 0.062375451172036786, 0.06767798521156822, 0.006857646396383643, 0.018429850793576667, 0.04480587930551597, 0.19730794110468455, 0.2328172256903989, 0.025356063153594732, 0.04312136523159487, 0.05238907810832773, 0.03370236957977925, 0.03351720076586519, 0.09351745367582355, 0.09835680614092521, 0.046900550834834576, 0.027126165938430598, 1.1580021934849876, 48.29818255560738, 30.2548086302621, 28.899939434868948, 35.735106468200684, 36.16428974696568, 67.44280774252755, 32.65385137285505, 0.24306180168475422, 3.2530065306595395, 3.5439315140247345, 1.0220434261219842, 0.21114405723554747, 2.817752697638103, 62.572975158691406, 54.94970348903111, 56.66911513464791, 55.23033775602068, 56.95161499295916, 57.23924609592983, 58.11150557654244, 56.23972340992519, 56.672196660723, 58.481709071568076, 59.47065312521798, 58.9180212020874, 61.71050916399275, 59.82237788609096, 58.47784587315151, 58.01557527269636, 55.18666137967791, 51.883821283067974, 46.34946993419102, 45.145190783909385, 43.058889933994834, 40.14775105885097, 42.73107392447335, 41.90298414230347, 43.824956621442524, 43.50231007167271, 43.842056138174875, 43.724145208086284, 41.62384721211025, 41.32688120433262, 42.43548366001674, 44.04524230957031, 40.74143988745553, 41.3584121295384, 43.336223806653706, 42.58793061120169, 44.301495347704204, 44.99894857406616, 47.54827042988369, 50.98258434023176, 50.466069153376985, 51.08852005004883, 50.49419893537249, 48.08678708757673, 46.50031532560076, 40.8602853502546, 44.706314768110005, 55.58770792824881, 54.473658084869385, 59.02145903451102, 55.56825992039272, 55.621087074279785, 19.092968804495676, 19.53462062563215, 67.50243023463658, 57.870573316301616, 58.10651329585484, 51.600918429238455, 55.5062437738691, 53.367699418749126, 52.28211287089756, 49.91921465737479, 47.54497698375157, 38.940588406154085, 41.00928946903774, 40.6110326222011, 38.87983683177403, 38.17086696624756, 39.32352794919695, 37.66098036084856, 38.964094161987305, 36.91315616880144, 36.47670160021101, 36.44835294995989, 37.14754670006888, 38.39276811054775, 39.16171482631138, 39.26628521510533, 39.245489256722585, 38.14805950437273, 39.32372944695609, 39.897751399448936, 39.18283040182931, 38.23448467254639, 38.26788118907383, 36.973984173366, 38.89609561647688, 39.21153341020857, 41.733072893960134, 40.10297686713082, 50.002718108040945, 52.167412008558, 52.75405536379133, 52.611169133867534, 54.1179381098066, 53.56152984074184, 54.38369975771223, 51.69658817563738, 50.88888440813337, 50.221454347882954, 53.323606150490896, 48.74723768234253, 50.41962044579642, 48.277167728969026, 53.745521613529746, 52.248396737234934, 56.438782351357595, 4.080877661705017, 0.09896420354821853, 2.394474519150598, 3.383813751595361, 0.6308376437851361, 13.977206468582153, 69.43947683061872, 27.90860867500305, 38.368206228528706, 33.359722341809956, 45.30700738089425, 12.093820810317993, 0.34723921013729914, 0.031067387400461093, 0.08448195923119783, 0.04096150005768452, 0.07131298551602022, 0.028420144093355963, 0.055663912024881156, 0.034123956957565885, 0.05185024666466883, 0.006750164753092187, 0.049303650456879816, 0.07226003719759838, 0.006135920079291931, 0.04644262112144913, 0.022309379851711646, 0.10370289534330368, 0.07219209548618112, 0.10824879498354026, 0.04851214275030153, 0.30444045098764555, 0.13442161413175718, 0.23691647286925996, 0.1723150536417961, 0.1388703611280237, 0.24508337463651383, 0.11728970413761479, 0.1951559130102396, 0.218565913981625, 0.1661381593772343, 0.06057472101279667, 0.18633469992450305, 0.13136404034282478, 0.3333061992057732, 0.2238085740911109, 0.15862832378063882, 0.1554816040609564, 0.09898061052496944, 0.11836196588618414, 0.23139428347349167, 0.19233969412744045, 0.18895012672458375, 0.20295323032353604, 0.2377051476921354, 3.4496972220284596, 58.73489448002407, 44.13668755122593, 32.53067370823452, 39.98467683792114, 43.2032596043178, 71.7777818952288, 41.20355762754168, 1.1744023306029183, 12.696125405175344, 3.976633838244847, 0.5232787696378571, 0.14204353014273302, 3.286456895726068, 63.85198565891811, 58.056465421404155, 57.144931248256135, 57.9625118800572, 59.10788767678397, 59.845584869384766, 60.02900341578892, 57.565929549080984, 57.5546943119594, 58.883655411856516, 60.7704039982387, 59.740847723824636, 63.98304952893938, 61.78778008052281, 61.221585273742676, 59.91174561636788, 57.69366523197719, 52.17906066349575, 47.23342670713152, 47.251669202532085, 46.57021420342581, 43.44055100849697, 44.69085502624512, 43.63947098595755, 46.10431316920689, 44.98151554380144, 46.62121745518276, 46.54957110541207, 43.97852223260062, 43.46032905578613, 44.360158988407676, 45.148998396737234, 43.420112882341655, 44.39107499803816, 46.78196750368391, 43.05545057569231, 47.01322439738682, 46.67423915863037, 51.57264273507254, 52.616203103746685, 52.867449964795796, 54.39911781038557, 53.22042540141514, 50.00400352478027, 50.16398927143642, 44.89176913670131, 45.12062195369175, 55.44361618586949, 53.858370780944824, 61.82269477844238, 56.423885413578574, 58.1262218611581, 26.270147017070226, 23.193121637616837, 68.16544124058315, 58.089059420994346, 58.6884457724435, 51.83091769899641, 56.23948022297451, 55.557809829711914, 53.94243008749825, 50.7510529926845, 50.51147215706961, 37.922114508492605, 42.50305836541312, 40.78934076854161, 41.3892308643886, 39.82436800003052, 42.4022330556597, 40.34021963391985, 42.18051256452288, 38.95634692055838, 38.65269674573626, 39.45530053547451, 39.17978014264788, 39.63506085532052, 41.958764280591694, 39.55709511893136, 42.03085878917149, 41.5635472706386, 41.2797828401838, 41.78484044756208, 42.44252913338797, 40.54661587306431, 42.0407669203622, 38.34036479677473, 43.67005000795637, 40.570312704358784, 44.02816711153303, 41.95672151020595, 53.05458927154541, 54.35199512754168, 55.16897474016462, 55.12497179848807, 55.95373903002058, 54.52281311580113, 57.3451783316476, 54.83039249692644, 54.7092992918832, 50.924028396606445, 56.37742975779942, 49.77425439017159, 53.74213089261736, 50.324218205043245, 56.41550588607788, 53.017214911324636, 59.73204435620989, 5.209978171757289, 0.18850057013332844, 4.390290932995932, 4.759935966559818, 3.5418266441140855, 15.718960046768188, 78.4570643561227, 30.640954766954692, 45.264824867248535, 40.11555658067976, 56.51308986118862, 20.506277561187744, 0.40187281423381394, 0.10433437395840883, 0.219281510582992, 0.19063560771090643, 0.12186929982687746, 0.18282352547560418, 0.13570749227489742, 0.11873985560876982, 0.16246663353272847, 0.14527749589511327, 0.11355643839176212, 0.26852545674358097, 0.10427755343594722, 0.2268256257687296, 0.11567187309265137, 0.20466330141893455, 0.15477724399949822, 0.14308578707277775, 0.11715855688921042], [0.020606616578463997, 0.04325384580131088, 0.016666492646826164, 0.06647861349795546, 0.026649469642766883, 0.04443690214040024, 0.039151643602443595, 0.08633749466389418, 0.188556915681277, 0.039265959789710383, 0.033727268422288556, 0.020939633083928908, 0.05373863676296813, 0.09228255386863436, 0.05515374868576016, 0.046209564698593955, 0.0423012301325798, 0.04031397408938833, 0.06531643907406501, 0.05584556602739862, 0.08141420063163553, 0.042822317885501046, 0.07004652025976352, 0.032688265067658255, 0.255217186574425, 9.545319710459028, 43.72065026419503, 23.762071405138286, 26.400071382522583, 32.2373902457101, 44.81410564695086, 57.43774223327637, 1.6147217260939735, 2.25570661681039, 2.5935475741113936, 1.734145300728934, 0.3531466174338545, 0.07543332834861108, 2.8565998588289534, 48.78109277997698, 64.83972072601318, 54.80661228724888, 56.776506492069785, 54.79228162765503, 58.402054922921316, 57.17558670043945, 60.40844454084124, 59.10143974849156, 57.128398009708945, 57.01356513159615, 56.20316546303885, 51.50007574898856, 52.25790534700666, 47.78464814594814, 47.33253928593227, 41.025638580322266, 40.976407119206016, 41.66203451156616, 39.71916879926409, 40.353608812604634, 41.91007825306484, 40.046369893210276, 41.862997259412495, 40.31210027422224, 41.90887968880789, 41.86053759711129, 41.089478628976, 41.58626788003104, 41.696612221854075, 42.144090107509065, 39.74285520826067, 39.984774112701416, 37.94409513473511, 43.65434013094221, 42.590053285871235, 46.03824969700405, 51.94926983969552, 53.941808223724365, 52.5968245778765, 52.05170018332345, 48.50897353036063, 50.490387848445344, 46.124674865177695, 42.47064501898629, 41.214608737400596, 48.28106219427926, 47.939589500427246, 55.89680201666695, 50.13014112200056, 61.07337324959891, 39.249064104897634, 50.60724612644741, 14.4712199143001, 19.061578580311366, 64.97464084625244, 49.72832679748535, 56.93577657427107, 47.11268438611712, 52.392384256635395, 41.045058795383994, 39.89232833044869, 37.8524101802281, 40.781749861580984, 37.194037096840994, 40.08807298115322, 36.38010426930019, 39.055918080466135, 35.683794021606445, 37.5688715662275, 35.22968408039638, 36.71261031287057, 36.661158902304514, 35.77981465203421, 35.608280999319895, 37.535561902182444, 36.51637234006609, 36.45661783218384, 36.060285636356895, 36.46734932490757, 37.458662714277, 37.10488823481968, 36.277006898607524, 36.75188847950527, 35.36134549549648, 38.76328427450997, 36.89714057104928, 39.98667097091675, 38.10269124167306, 47.606888907296316, 51.521590845925466, 52.58940390178135, 50.902169363839285, 51.4706084387643, 50.86254726137434, 51.097674301692415, 47.633000237601145, 50.77627147947039, 52.87217126573835, 50.3094220161438, 50.33404990604946, 50.90847832815987, 49.15911994661604, 52.80819225311279, 50.15602663585118, 48.04022373471941, 0.9976820647716522, 0.10945874505809375, 1.6957761538880212, 5.048148112637656, 0.3917197861841747, 29.252555302211217, 42.87801442827497, 17.269839661461965, 28.725694247654506, 21.280807154519216, 39.02026687349592, 1.1784602957112449, 0.195943203621677, 0.05404681379773787, 0.04413114747564707, 0.032746897278619666, 0.03870291482391102, 0.045061123823480945, 0.026678673789969513, 0.05125059812728848, 0.046352979860135486, 0.0369505336774247, 0.027153777224676948, 0.03831668929862125, 0.006869504644003297, 0.09787087328732014, 0.04702613748876112, 0.019274654033194696, 0.013852218615024217, 0.10786110042993512, 0.038567849035773955, 0.038302765760038576, 0.03450089333845036, 0.02843152142928115, 0.08527463062533311, 0.044387297837861946, 0.06036921989704881, 0.03455326606386474, 0.06403041165322065, 0.16872664833707468, 0.03820059534960559, 0.016525481195588197, 0.06641023073877607, 0.06104718494628157, 0.042182439006865025, 0.015146745535145913, 0.026639006632779325, 0.02986225492454001, 0.016767160102192844, 0.026960562681779265, 0.08086074675832476, 0.06076929771474429, 0.08782537946743624, 0.05309692244710667, 0.04489269107580185, 0.2703966391938073, 15.44692243848528, 52.49771894727434, 19.920170954295568, 37.22678048270089, 37.423021929604666, 52.98214735303606, 60.518094062805176, 1.4341053664684296, 2.052579070840563, 4.785172692367008, 2.450300906385694, 1.75904167337077, 0.10755061637610197, 4.52917890889304, 53.72714015415737, 63.88906819479806, 55.960836614881245, 57.840088094983784, 54.558672768729075, 58.377847399030415, 59.19734573364258, 60.66386726924351, 61.715650830950054, 59.389692715236116, 59.878074645996094, 58.251671586717876, 53.14473172596523, 56.08559152058193, 51.20937006814139, 49.70567567007882, 46.201303073338096, 44.3511506489345, 44.292441844940186, 43.046226842062815, 43.990886551993235, 43.12173639025007, 42.160564286368235, 43.893782002585276, 42.129512786865234, 44.45955296925136, 43.80031483513968, 43.25800098691668, 43.25225135258266, 42.3822465624128, 43.559108121054514, 40.73463412693569, 42.15383843013218, 40.727856159210205, 44.53093876157488, 43.2436112676348, 47.29849311283657, 53.68964420046125, 56.51591082981655, 54.06933546066284, 53.067679677690776, 51.837181500026155, 52.51555149895804, 47.0562858581543, 45.206248079027446, 43.330425534929546, 51.290007386888774, 50.76493896756853, 59.570860045296804, 50.143902029309956, 60.3150885445731, 44.458757400512695, 52.36613743645804, 18.509707484926494, 22.459741013390676, 66.79495770590646, 50.7633513041905, 57.56428977421352, 47.772853578839985, 52.83332388741629, 45.303971018110005, 40.97943653379168, 39.028132234300884, 42.08048629760742, 38.15100901467459, 40.455465929848806, 38.2022693497794, 41.23616204942976, 38.12276111330305, 38.99959945678711, 36.583811555589946, 38.51269749232701, 38.20362772260393, 38.497998578207834, 37.02025917598179, 39.19904402324131, 38.484105655125205, 39.60475281306675, 38.371833188193186, 38.49495179312569, 39.95827715737479, 40.49303831372942, 39.25595324380057, 38.754852635519846, 38.74415240968977, 39.91256843294416, 39.80397851126534, 42.186255250658306, 38.6535826410566, 51.16152477264404, 53.29366636276245, 53.88811254501343, 53.38732460566929, 53.803275040217805, 51.326631341661724, 53.52673673629761, 51.0145252091544, 52.67494317463466, 54.319373335157124, 52.16913168770926, 51.38142483575003, 55.171205111912315, 49.52685683114188, 56.28860051291329, 52.44197702407837, 49.25054781777518, 1.1622813067265918, 0.11203907124165978, 4.431737371853419, 3.166766792535782, 0.3554337689919131, 30.87685305731637, 51.35477154595511, 24.480506454195293, 36.30522353308541, 25.003622429711477, 46.95820508684431, 1.637762495449611, 0.21067185114536965, 0.03130334456052099, 0.05376059415617159, 0.009167857967051012, 0.03997452676828418, 0.03727709901119981, 0.051411936791347604, 0.03478792382936392, 0.002737054838300017, 0.010220143644671355, 0.030903765466064215, 0.11596246249973774, 0.004932968245287026, 0.05379421556634562, 0.06525449561221258, 0.049857548770627806, 0.03438241094616907, 0.16265116791640008, 0.0034442874353512055, 0.13855009259922163, 0.11746145492153508, 0.12468908780387469, 0.19329554640821048, 0.38097135722637177, 0.20285368923630032, 0.1668811687933547, 0.356132551495518, 0.35485275302614483, 0.22798635491303035, 0.11128283717802592, 0.1491702648677996, 0.1513905128730195, 0.1398552411368915, 0.1144865131271737, 0.1071561025455594, 0.15240477344819478, 0.10441133340022393, 0.14267920888960361, 0.2414947657712868, 0.20176131570977823, 0.25794476164238794, 0.19685913090194973, 0.2168966635529484, 0.5027683930737632, 23.094384261540004, 68.35584272657121, 34.98677505765642, 43.008425167628694, 43.04314184188843, 53.03667334147862, 68.58106858389718, 1.807950803211757, 8.2635429586683, 10.434565799576895, 3.226261828626905, 0.9497733669621604, 0.0714113459523235, 5.066565181527819, 52.63607842581612, 66.66711780003139, 57.1608704158238, 58.19117709568569, 56.258163928985596, 60.80884838104248, 61.2443962097168, 63.322803906032014, 65.3220021384103, 62.44423198699951, 63.612502098083496, 60.74186774662563, 54.80742522648403, 58.339618410382954, 52.541770526341026, 52.88100937434605, 47.17731305531093, 46.08084910256522, 47.69432503836495, 45.88535458700997, 46.29415879930769, 46.296326637268066, 43.6809413092477, 47.19623647417341, 45.47096054894583, 45.88904755456107, 46.30549478530884, 45.57155656814575, 44.72350461142403, 44.425843783787315, 46.49461432865688, 43.79850482940674, 42.845781735011506, 42.059992585863384, 46.571871348789756, 45.35417175292969, 49.66536569595337, 55.97871780395508, 57.13010726656233, 56.27418647493635, 54.741719586508616, 53.787669386182515, 54.33132076263428, 50.31228814806257, 45.959867068699424, 46.00356081553868, 54.523983887263704, 53.31938859394619, 60.250685691833496, 52.88445915494646, 63.14798028128487, 45.46865374701363, 51.20784841264997, 21.5576685496739, 25.02513231549944, 68.02717208862305, 52.600340366363525, 58.71448762076241, 50.12002107075283, 53.634360858372276, 44.655394894736155, 42.77081067221505, 42.27540063858032, 44.9202949660165, 40.12699678965977, 43.17180510929653, 40.61206790379116, 43.187237058367046, 39.663135051727295, 41.76045574460711, 39.39247144971575, 40.7293951851981, 41.945934431893484, 40.62713507243565, 38.832241671425955, 41.77015890393938, 41.11572544915335, 40.73018033163888, 39.887700830187114, 39.54686042240688, 41.21589068004063, 42.424345697675435, 40.70920719419207, 40.14863000597273, 40.41202579225813, 42.466868673052105, 41.85336010796683, 45.70405871527535, 41.22919995444161, 51.59209769112723, 55.826454980032786, 56.922620160239084, 55.065036637442454, 54.661408833095, 53.7371803011213, 53.88887684685843, 53.18988459450858, 57.38065235955374, 57.496979100363596, 54.60463857650757, 54.065357616969514, 57.22590902873448, 52.42060089111328, 57.812260559626985, 55.77274540492466, 51.09181349618094, 1.5542706613029753, 0.19194608953382286, 8.518627830914088, 13.438996400151934, 1.0787865413086755, 36.54558604104178, 58.098647935049875, 27.65498205593654, 46.666471072605674, 32.92877074650356, 58.160677977970664, 3.6353183473859514, 0.4533832573464939, 0.1733840312808752, 0.2162800244987011, 0.13635690457054547, 0.08372990494327885, 0.16423614429576056, 0.07749687547662429, 0.164530519928251, 0.1820593321962016, 0.2048059023384537, 0.12812423918928417, 0.20365803821810655, 0.07001507016164915, 0.15858018850641592, 0.1461696880204337, 0.12745835206338338, 0.05243807172934924, 0.2087146575961794, 0.26520427209990366], [0.11095794104039669, 0.009056378904330944, 0.09061692003160715, 0.04979234494801078, 0.03213256524343576, 0.023797532676586082, 0.027761692014921988, 0.01626991606982691, 0.03339768360768046, 0.012944315859515752, 0.058109270807887824, 0.03655719031978931, 0.08848988238189902, 0.05267699748011572, 0.09757878431784255, 0.04119107559589403, 0.053207944346857924, 0.12032110004552773, 0.0318103900312313, 0.05997283330985478, 0.051894782310617824, 0.11197197091366563, 0.05111189878412655, 0.0848092505974429, 0.07138837754194226, 0.6665008472544807, 25.040508678981237, 32.39863361631121, 24.734834841319493, 33.3368627684457, 26.64006563595363, 55.989751543317524, 13.465668797492981, 1.9208101757935114, 1.6341682140316283, 1.6895936684949058, 4.751435279846191, 0.30357716445411953, 0.11747027587677751, 3.4024271070957184, 55.07458693640572, 54.13453388214111, 57.23815522875105, 60.18105779375349, 62.039964948381694, 60.96668366023472, 58.0721891948155, 58.13816581453596, 55.022590092250276, 52.8054963520595, 49.46262073516846, 46.68975796018328, 44.15334933144705, 42.68940905162266, 42.17514508111136, 39.47684342520577, 41.2924667767116, 42.79327767235892, 41.190616607666016, 41.309545448848176, 39.18612732206072, 40.298735414232524, 40.61968312944685, 42.538257939474924, 43.12406403677804, 39.86717585154942, 41.26382630211966, 41.27920266560146, 42.79196793692452, 41.713221890585764, 41.37302071707589, 39.517622402736116, 39.70174619129726, 40.9449074608939, 45.48325538635254, 52.01141800199236, 56.81180681501116, 54.246990476335796, 53.4239798273359, 51.975089345659526, 58.16919299534389, 55.06512348992484, 49.589890888759065, 52.63933713095528, 45.104519503457205, 45.07172748020717, 43.36044522694179, 52.58023575374058, 51.865703855242046, 59.154920033046174, 55.19680922372, 42.0580609866551, 20.56823812212263, 33.024791376931326, 58.80632890973772, 52.176760809762136, 52.665691648210796, 45.043361459459575, 41.981043679373606, 36.834790910993306, 41.76924521582467, 42.490280628204346, 43.20674760001046, 40.026953152247835, 38.95318896429879, 37.741659368787495, 37.31987244742257, 36.39565086364746, 36.78310326167515, 36.544036592756, 35.137571811676025, 35.575530665261404, 36.3132243837629, 36.57312175205776, 37.473493644169395, 37.69765295301165, 36.95179510116577, 36.04332160949707, 37.09813458578927, 37.94539097377232, 38.61503750937325, 36.065399510519846, 36.39152363368443, 38.771615164620535, 37.30354765483311, 37.240774154663086, 38.5615085874285, 38.15710258483887, 48.792425291878835, 51.645887170519146, 50.13718659537179, 52.58010026386806, 52.02465779440743, 50.94861459732056, 50.64093794141497, 52.78610045569283, 50.82972049713135, 53.38996492113386, 53.26259054456438, 52.6772916657584, 51.147419929504395, 51.77147586005074, 53.123348644801546, 54.8530262538365, 33.91464369637625, 0.054913703352212906, 0.22644852314676556, 2.421585955790111, 2.8284711624894823, 0.05617181923506515, 42.3922450201852, 29.213117327008927, 25.720332588468278, 25.986896753311157, 27.514663185392106, 24.528772115707397, 0.055225636078310866, 0.11678553904805865, 0.14864335528441838, 0.015904111055923358, 0.04328395240008831, 0.02273297230047839, 0.09181321798158543, 0.040047194476106336, 0.10759985087705509, 0.041229066771588156, 0.043215230373399596, 0.009912299940229526, 0.04835307039320469, 0.04567218192719987, 0.0672912270362888, 0.037963711989245245, 0.06372899282723665, 0.08432757894375495, 0.08568924266312804, 0.04119956746165242, 0.08999671188316175, 0.06398676828082119, 0.037348226444529634, 0.05469715907903654, 0.022644571061911326, 0.06832727537091289, 0.025323267859805907, 0.0175762554364545, 0.02732701230395053, 0.04772309473316584, 0.0344968594477645, 0.01520725728810898, 0.040502237022987435, 0.10150377691856452, 0.021006083714642694, 0.01462870610079595, 0.03135805144639952, 0.0411767313655998, 0.03340146304773433, 0.009598411336940314, 0.05188559155379023, 0.05274125474638172, 0.043897134318415604, 0.10908648717616286, 0.06450613255479506, 1.7191987484693527, 43.341195242745535, 35.71177789143154, 26.318602016993932, 40.34532308578491, 33.46656826564244, 65.72048827580043, 13.141946145466395, 1.0824816801718302, 2.45507236463683, 2.2328687565667287, 5.193464475018637, 2.9773102615560805, 0.3349205425807408, 5.464698697839465, 58.64406762804304, 54.3197728565761, 58.84047930581229, 59.86431721278599, 62.51469366891043, 60.40535259246826, 60.867393902369905, 61.439626693725586, 57.972840377262656, 55.791613238198416, 51.57820476804461, 49.59265627179827, 47.82220663343157, 46.52138573782784, 44.49052456447056, 43.009206839970176, 44.918634346553254, 44.544748306274414, 43.21731581006731, 41.922894205365864, 43.32030895778111, 42.42346327645438, 43.717398507254465, 44.71680654798235, 44.7314464024135, 43.67200245176043, 43.92995432444981, 43.61231395176479, 45.372212750571116, 43.10875368118286, 44.09677709851946, 42.487553460257395, 40.75330393654959, 44.282811641693115, 46.22865118299212, 54.52879898888724, 59.02858093806675, 57.508064951215474, 54.55760274614607, 53.140920639038086, 56.13145310538155, 57.74195868628365, 52.76201799937657, 51.79882049560547, 47.93207849775042, 45.77690710340227, 45.20614038194929, 52.42576687676566, 54.087216649736675, 60.990731375558035, 58.344419615609304, 47.99618605204991, 19.22128118787493, 28.068048988069805, 62.14632102421352, 53.08419207164219, 55.81716871261597, 48.81572607585362, 44.526818479810444, 38.706597396305625, 42.75520501817976, 43.355637073516846, 44.09117685045515, 39.90033960342407, 40.656859466007774, 39.13565213339669, 38.43869570323399, 39.05887106486729, 38.8732499395098, 38.15605688095093, 37.17665270396641, 38.08541801997593, 39.18449102129255, 37.98463092531477, 39.563869612557546, 40.29410096577236, 37.81274291447231, 37.66167518070766, 38.77096898215157, 39.0959084374564, 40.20586231776646, 38.41306379863194, 39.182590688977925, 40.02941976274763, 39.33454431806292, 38.94551815305437, 39.717629773276194, 40.32322434016636, 50.656147548130576, 54.50222907747541, 53.976931367601665, 55.07773099626814, 56.07158742632185, 54.07724945885794, 52.38997670582363, 53.334393228803364, 54.390821661267964, 53.22229446683611, 56.03542900085449, 55.05614989144461, 54.14003685542515, 52.55049746377127, 55.628056117466514, 55.019261905125205, 35.624675273895264, 0.11895444909376757, 0.18192937916943006, 3.139705947467259, 0.9096705902900014, 0.06414829354201045, 48.735724517277305, 37.18630027770996, 31.475030422210693, 29.455765792301722, 32.02593919209072, 32.6633426121303, 0.03672518201970628, 0.05885935055890253, 0.023812029577259506, 0.033290756666766744, 0.036967154392706494, 0.025740487168409994, 0.15503598297280924, 0.01091286598239094, 0.04373813999284591, 0.06511278357356787, 0.02741261967457831, 0.0315814149965133, 0.023452797871349112, 0.020050241611897945, 0.0987701832449862, 0.03734672348946333, 0.023019819586936916, 0.04629046303619232, 0.08242409144129072, 0.04539175358201776, 0.2747683860361576, 0.19193334664617265, 0.2125380802899599, 0.20068676051284584, 0.11567310802638531, 0.1360720827111176, 0.15370270237326622, 0.13178393138306482, 0.10239000472107104, 0.1299164401633399, 0.09855816140770912, 0.08869111551237957, 0.1747520664440734, 0.1213075542556388, 0.2259071743381875, 0.3932874192084585, 0.0951776931594525, 0.15534011593886785, 0.12350512562053544, 0.21347749845257827, 0.1681719459593296, 0.17296647440109933, 0.09221474786422082, 0.19854227772780828, 0.22791679150291852, 3.7172836405890326, 59.66605036599295, 47.681894711085725, 37.87910515921456, 47.66682059424264, 36.23169422149658, 69.13065024784633, 16.777980157307216, 3.3666297708238875, 10.620080964905874, 6.289891515459333, 11.226390327726092, 1.5083571821451187, 0.20645656090761932, 5.516453657831464, 61.455711773463655, 58.89741979326521, 62.07575511932373, 61.17071056365967, 67.25450461251395, 65.40487330300468, 64.22257477896554, 65.65386199951172, 60.63383020673479, 57.757731097085134, 55.04047475542341, 52.40612084524972, 49.55101919174194, 47.951936449323384, 46.240741048540386, 44.77079405103411, 47.73507969720023, 47.3327442577907, 46.45845937728882, 45.00392695835659, 44.83922685895647, 45.93143851416451, 44.26295369012015, 47.394110747746055, 47.55820982796805, 44.264794962746755, 45.76729774475098, 44.55523313794817, 48.00894294466291, 45.575794969286235, 47.160505362919395, 44.43577970777239, 45.08007574081421, 47.43590068817139, 48.19514077050345, 56.258403641836985, 60.840441840035574, 59.10423987252371, 57.41683162961687, 55.86341939653669, 59.266389983040945, 61.093377113342285, 55.553067684173584, 55.5472902570452, 49.405079228537424, 48.14004155567714, 46.98352779660906, 54.88976832798549, 55.72546986171177, 62.04355716705322, 61.20502771650042, 49.39260026386806, 22.934624331338064, 35.69214228221348, 61.483831133161274, 55.83862822396414, 56.92954404013497, 49.286355359213694, 45.26054130281721, 39.96389825003487, 45.58936480113438, 46.38066039766584, 46.43630157198225, 42.292534896305625, 41.84710325513567, 41.61143772942679, 39.8015570640564, 41.230593068259104, 40.80367142813546, 41.34177814211164, 38.89987196241106, 39.77628646578108, 39.706825324467246, 40.61002165930611, 41.910578523363384, 43.82390396935599, 40.67443493434361, 40.11785643441336, 41.498397486550466, 42.36816256386893, 43.62058230808803, 40.96869461877005, 41.02101802825928, 43.0504652432033, 41.519704137529644, 41.27375875200544, 41.703737599509104, 42.121984413691926, 51.8799580846514, 56.24323572431292, 53.63620907919747, 57.143249784197124, 56.66690560749599, 55.02124214172363, 55.67631483078003, 58.17924356460571, 53.87478937421526, 56.1344165120806, 59.61694744655064, 57.360631125313894, 55.508950097220286, 56.605261189596995, 57.308040210178916, 57.780333587101524, 39.24076100758144, 0.3330871952431542, 0.6326426012175423, 11.389018126896449, 9.441825423921857, 0.15835851111582347, 55.77866179602486, 41.8410861151559, 39.45249693734305, 37.948729583195274, 40.985978262765066, 42.48960665294102, 0.14974586612411908, 0.15084668062627316, 0.1739764330642564, 0.12493445963731833, 0.16265210429472582, 0.0808100737631321, 0.1926329569625003, 0.1416376983480794, 0.15607224165328912, 0.08374865286584411, 0.09335785545408726, 0.1458474788814783, 0.10443495998957328, 0.12327329734606401, 0.15284208926771367, 0.13637930979686125, 0.12381558253296784, 0.1258080191910267, 0.2238570214914424, 0.13172803366822855], [0.05951804521360567, 0.024001987152067677, 0.05360372703788536, 0.038437872260276756, 0.03329523839056492, 0.04916591802611947, 0.03937053221410938, 0.08775515109300613, 0.015343223831483295, 0.06043959754918303, 0.06599108608705656, 0.02465769794902631, 0.03128730399268014, 0.01268559554591775, 0.03248052478634885, 0.052867594574178965, 0.007394331973046064, 0.03366262778373701, 0.038553372491151094, 0.010016726479599518, 0.050821431513343535, 0.018936236388981342, 0.0756971834759627, 0.043215376258428605, 0.06521277927926608, 0.040427815302142074, 5.100835868290492, 39.48418419701712, 34.30510466439383, 41.14674915586199, 23.94420279775347, 52.622411319187705, 46.09206696919033, 0.008121500140987337, 1.6322472542524338, 2.3702502761568343, 2.995566870485033, 3.0126188354832784, 0.503891721367836, 0.013377846301799374, 23.18083027430943, 61.464570726667134, 56.01078026635306, 62.40637125287737, 57.828512396131245, 59.02473163604736, 56.2704622404916, 52.02628019877842, 48.78448002679007, 45.66652454648699, 45.30071578707014, 40.93981443132673, 42.346216678619385, 44.528027466365266, 43.29714713777815, 47.024942534310476, 43.81846352985927, 42.4568042073931, 41.2699476650783, 42.01939426149641, 41.463211808885845, 42.38322625841413, 40.83232927322388, 43.04944733210972, 44.100039277757915, 43.363738673073904, 42.12848792757307, 42.64314794540405, 42.64560413360596, 42.573374135153635, 41.072459016527446, 39.8584315436227, 39.497180802481516, 40.755965096609934, 44.51804985318865, 56.03037766047886, 57.72226749147688, 54.53077922548567, 55.444703578948975, 55.8144519669669, 59.127634457179475, 54.78376661028181, 54.471521513802664, 51.352047852107454, 52.780496733529226, 50.45718240737915, 50.61042145320347, 49.11794492176601, 55.775698389325825, 52.803710665021626, 62.42878614153181, 37.52661262239729, 47.6306517464774, 63.25614288875035, 50.138343470437185, 51.1884559903826, 45.286597047533306, 42.55297074999128, 40.40407705307007, 42.398456709725515, 43.53861788340977, 46.56732027871268, 47.18589060647147, 45.284529958452495, 40.64106968470982, 39.009431157793315, 35.69139187676566, 37.730913979666575, 36.91528926576887, 36.32620014463152, 36.72921303340367, 37.30192872456142, 36.42973525183541, 37.9526309967041, 37.22974041530064, 36.80878727776663, 35.87939970833914, 39.11329630443028, 38.58155761446272, 44.75286422457014, 45.90754018511091, 44.452229567936485, 37.027912616729736, 37.71186201913016, 37.022055285317556, 37.4012428011213, 36.79164259774344, 39.50797135489327, 42.419937065669465, 49.17326995304653, 49.110392229897634, 52.839803082602366, 49.251360757010325, 52.42991495132446, 49.21147114889962, 52.89779622214181, 49.008819988795686, 56.2789876801627, 54.699537072862896, 57.086979797908235, 50.79718208312988, 57.54079096657889, 49.866363184792654, 58.38578919001988, 10.506814905575343, 0.3132542409002781, 0.17457833433789866, 2.905745335987636, 1.167744436434337, 3.192929800067629, 52.184424672807964, 16.716803005763463, 29.7451582636152, 18.63084237916129, 29.54105840410505, 9.775391067777361, 0.2075901622218745, 0.05426620452531746, 0.028727228686745678, 0.03811491673280086, 0.010553803910235209, 0.03459127081025924, 0.09696856420487165, 0.023774879784988504, 0.02078835539785879, 0.05713455525359937, 0.048394142117883475, 0.035998535475560596, 0.07272102710391794, 0.0550598496172045, 0.07405702862888575, 0.029251675188009228, 0.09653785731643438, 0.05180659650691918, 0.01719594673652734, 0.06451335895274367, 0.050054239109158516, 0.031086766360593692, 0.036336096469312906, 0.04992602313203471, 0.0678596290360604, 0.0325957671739161, 0.024425616920260445, 0.030193631071597338, 0.012421026260458996, 0.0675678996901427, 0.04719604944278087, 0.09426145375307117, 0.04655705265966909, 0.03166872549003788, 0.025121909200346897, 0.03275747563956039, 0.05220684056569423, 0.023264886079622165, 0.050110116467944214, 0.04960277922717588, 0.01650970016739198, 0.06084745137819222, 0.051593044573175054, 0.036999876743980815, 0.10659650114497968, 0.08524724495198045, 17.92378674234663, 47.49521051134382, 35.99446882520403, 45.39643069675991, 28.546027728489467, 59.5338956287929, 46.177790369306294, 0.07053427837256875, 0.47447364564452854, 4.975321871893747, 7.955471123967852, 6.838876937116895, 1.2029631180422646, 0.10975657443382911, 27.466303723199026, 66.46001979282924, 56.140228680201936, 67.29993193490165, 58.60165582384382, 62.12634495326451, 59.498015131269185, 55.00093603134155, 51.32667303085327, 48.6045355796814, 47.799065658024375, 44.75705746241978, 45.10818120411464, 45.628135749271934, 44.855280671800884, 48.97252607345581, 46.41018329347883, 45.16566712515694, 43.61011484691075, 44.12906190327236, 42.91639975139073, 44.52865975243704, 43.70640298298427, 45.120316232953755, 45.069490160260884, 44.90147229603359, 43.686183725084575, 45.50670903069632, 44.68719679968697, 45.25981174196516, 43.231038502284456, 41.990114552634104, 41.1143844468253, 40.4339473588126, 45.93877928597586, 56.647065026419504, 58.88333579472133, 56.990861892700195, 57.89418676921299, 56.75890670503889, 58.93769155229841, 56.86134399686541, 54.46226303918021, 53.08377170562744, 53.321917738233296, 50.38289226804461, 51.83149439947945, 51.33289861679077, 55.91676419121878, 53.76547336578369, 60.969747815813335, 39.10569497517177, 51.72059767586844, 67.35114015851701, 52.2210555757795, 55.04291704722813, 48.41175433567592, 45.501490933554514, 40.72663675035749, 42.53851849692208, 44.81844479697091, 47.89074713843209, 47.17466231754848, 47.59354141780308, 43.078452587127686, 42.024261474609375, 38.46913923536028, 39.91042838777815, 37.97253063746861, 39.16427871159145, 38.22623021262032, 39.680317946842735, 39.89629922594343, 37.96382107053484, 38.681927817208425, 39.48997204644339, 38.12121166501726, 40.34096656526838, 39.883121967315674, 47.36824260439192, 46.74043117250715, 45.46165343693325, 38.3601393699646, 40.085290227617534, 39.797506264277864, 40.4159654208592, 39.24771268027169, 40.59099749156407, 44.859929016658235, 50.696665968213765, 50.56100239072527, 55.238574845450266, 52.05284316199166, 54.15254013878958, 51.1799270766122, 55.50783143724714, 52.56849677222115, 59.15526049477713, 56.199003492082866, 57.49014207295009, 53.858575752803254, 60.31088488442557, 50.832635266440256, 57.867186069488525, 11.662590418543134, 0.5217677535755294, 0.9781800998108727, 2.1978863137108937, 1.1279411379780089, 3.841599941253662, 60.18470559801374, 23.775222608021327, 33.121809073856895, 21.310474225452968, 39.027284554072786, 14.78623560496739, 0.32518372791154043, 0.003967804767723594, 0.051454572539244375, 0.006568085818019296, 0.06586956046521664, 0.06334397848695517, 0.04338754094871027, 0.011773328962070602, 0.09435937314161233, 0.013257731184629458, 0.0225943577741938, 0.03709846788219043, 0.06178622493254287, 0.03972625419763582, 0.032994674518704414, 0.027422709490305612, 0.044790856540203094, 0.06967344135046005, 0.03911189502105117, 0.07290570397994348, 0.24175374901720456, 0.0721227220658745, 0.27202797308564186, 0.13004860521427222, 0.16091979082141603, 0.1702705326357058, 0.1441360642867429, 0.23078072496822902, 0.1300737110099622, 0.15837619373840944, 0.1461869499513081, 0.12733093675758156, 0.10834431914346558, 0.07584752648004464, 0.15260297352714197, 0.19120913265006884, 0.15072298369237355, 0.12766865720706327, 0.10838049184530973, 0.1293697716402156, 0.11965613572725228, 0.1834753533559186, 0.15743539136435303, 0.11228909782533135, 0.17536709058497632, 0.16453999227711133, 26.810228756495885, 62.631020409720286, 43.777792249407085, 58.642879486083984, 34.775073868887766, 63.50078896113804, 55.323457513536724, 0.214103867698993, 5.285999281065805, 6.1563471385410855, 7.444119317190988, 6.418990782329014, 1.1433463799101966, 0.26827271601983477, 29.355461597442627, 67.11021832057408, 58.56665079934256, 68.74726254599435, 62.7967905317034, 64.78503840310233, 61.0473244530814, 57.499813965388704, 54.1546037537711, 52.042556353977744, 51.68364020756313, 46.72705589021955, 47.6843717438834, 51.25127812794277, 48.912365095955984, 51.68716294424874, 49.096912724631174, 48.15570626940046, 47.12604577200753, 45.89557886123657, 45.9410582951137, 47.252141680036274, 46.41096496582031, 47.91723019736153, 48.719048840659006, 47.90928145817348, 46.889994621276855, 46.63899094717843, 48.985255173274446, 48.12382446016584, 44.76212269919259, 44.3438515663147, 42.42467226300921, 42.74507801873343, 47.774403027125764, 58.99684156690325, 60.78870555332729, 59.22907815660749, 58.83245413643973, 58.47758184160505, 59.518894468035015, 58.829028674534385, 57.48838765280587, 56.32918841498238, 57.57999617712838, 53.354261602674214, 55.080729143960134, 54.209643908909385, 57.949129649571006, 54.97393880571638, 59.74918556213379, 46.124726976667134, 50.317780699048726, 66.66963999611991, 52.551956585475374, 56.82584565026419, 48.595968450818745, 45.9850994518825, 43.571284839085166, 46.76493746893746, 46.77039180483137, 50.060884952545166, 50.138617924281526, 49.91915559768677, 43.9696215902056, 44.01794283730643, 39.087035587855745, 40.943830490112305, 40.17482818875994, 40.434371198926655, 40.627079486846924, 42.304927008492605, 41.77427223750523, 41.79894181660244, 41.9047976221357, 41.1727180480957, 41.44385412761143, 43.45294312068394, 43.053060395377024, 50.45779037475586, 49.283895696912495, 48.67383343832833, 42.11181919915335, 42.287733691079275, 41.329285281045095, 42.41717863082886, 42.230202606746126, 43.93677050726754, 46.00386653627668, 52.53597572871617, 52.65619693483625, 56.624604974474224, 53.06236777986799, 57.124729360852925, 51.340996742248535, 56.856421198163716, 52.8416200365339, 61.5851845060076, 56.62792273930141, 60.427677154541016, 54.63413715362549, 61.3205623626709, 52.7731385912214, 62.25477545601981, 13.446133068629674, 0.5009488335677555, 1.7581100719315665, 9.397816402571541, 3.3795822986534665, 3.884530689035143, 65.86549023219517, 26.473647594451904, 45.73906026567732, 31.06750120435442, 48.79732724598476, 21.10896256991795, 0.45437701259340557, 0.05451313020395381, 0.15962720875229153, 0.09919725997107369, 0.13476280868053436, 0.1556009855121374, 0.1521330066025257, 0.08190996545766081, 0.2033541359539543, 0.1033678347510951, 0.09851787678365197, 0.07212605367281608, 0.14583802010331834, 0.21125532340790543, 0.20112018154135772, 0.09275442747665302, 0.19832384373460496, 0.15005549522382872, 0.10626306225146566, 0.17784572472529753], [0.008001400290855339, 0.001836496588241841, 0.08327526612473385, 0.02538440386498613, 0.01426393585279584, 0.06019898224622011, 0.03225897971008505, 0.027858878585643003, 0.08429223405463354, 0.02629666875249573, 0.06445589382201433, 0.03292256660227265, 0.06714578305504151, 0.07588407916149922, 0.01728644295196448, 0.03465178934857249, 0.045425568374672105, 0.030867545266768763, 0.047513349380876334, 0.04198149086109229, 0.014635957943807756, 0.026276460283302834, 0.08962761597441775, 0.06071143903370414, 0.11800812344465937, 0.0912877604631441, 2.381974058491843, 37.702210971287315, 44.684799671173096, 37.48947450092861, 37.98117767061506, 25.24517481667655, 69.76610469818115, 3.0687685310840607, 1.4596266427210398, 0.4063544566077845, 5.140488369124276, 7.486384340694972, 0.8535756660359246, 0.1856513608779226, 7.627576947212219, 57.330396039145334, 57.57534435817173, 64.6391818182809, 59.386913435799734, 58.354258264814106, 49.608140332358225, 49.551370075770784, 42.71037176677159, 45.01308121000017, 46.96161665235247, 51.186034543173655, 50.17556497028896, 53.73928560529436, 51.57271569115775, 50.30587496076311, 47.29617588860648, 45.624939577920095, 43.23457860946655, 40.70685870306832, 40.75086164474487, 41.28520590918404, 42.545119285583496, 43.64433125087193, 42.32469810758318, 39.66831840787615, 41.483535289764404, 41.58637210300991, 43.736572061266216, 40.867049421582905, 39.212196963174, 40.48420715332031, 38.643716199057444, 39.52013765062605, 46.072066579546245, 53.48911918912615, 55.063758168901714, 53.77836922236851, 53.77717065811157, 54.54086800983974, 58.285936628069194, 57.30942290169852, 52.84487179347447, 56.53107527324131, 55.123484883989605, 53.33588014330183, 51.95721163068499, 54.522055762154714, 54.038603578295024, 55.621000221797395, 54.51879358291626, 44.52014820916312, 56.90662888118199, 50.46473509924752, 52.675648416791645, 48.51789501735142, 44.44103602000645, 41.391780853271484, 41.18229613985334, 43.86113241740635, 47.98740005493164, 48.50504084995815, 47.58343178885323, 47.340199674878804, 42.56441443307059, 39.4346296446664, 37.60136481693813, 38.09172351019723, 38.25740677969796, 37.84178638458252, 38.50168112346104, 36.35812016895839, 37.63585914884295, 36.37277044568743, 37.008367334093364, 40.83989586148943, 40.4568520954677, 40.44850036076137, 43.670772620609824, 50.283220359257285, 51.65380464281355, 51.40868956702096, 44.799681186676025, 37.69187899998256, 38.05027403150286, 37.11829825810024, 35.742131096976145, 38.22297150748116, 42.7639354297093, 48.465418747493196, 47.21959979193551, 48.688890184674946, 48.481951986040386, 48.48482159205845, 48.0917272567749, 50.934388160705566, 51.75020047596523, 53.267447335379465, 56.73989643369402, 56.451970032283235, 54.70973702839443, 53.01807648794991, 53.24664790289742, 34.653699261801584, 0.03583645381565605, 0.2694706288831574, 0.5046440809965134, 0.9846964244331632, 1.0536571868828364, 13.735532488141741, 32.759415354047505, 20.93832870892116, 50.03151144300188, 29.419447558266775, 27.953923089163645, 6.807147988251277, 0.5980646737984249, 0.14359308699412004, 0.06692503525742463, 0.10075744268085275, 0.040022295633597035, 0.037426051018493514, 0.0382822197196739, 0.06664051873875515, 0.044114730320870876, 0.06990301688866955, 0.03372816748118826, 0.012370312553165215, 0.016409371979534626, 0.0316513482082103, 0.03580014540680817, 0.04482397583446332, 0.05512725867863212, 0.049275474290230444, 0.040460853172200065, 0.022144268532948833, 0.02770139739316489, 0.027613922354898283, 0.07438586705497333, 0.03847733924963644, 0.04024118085258773, 0.046353593934327364, 0.06596122376088585, 0.024538671032392552, 0.05682843078726104, 0.09541467830006566, 0.002207421784987673, 0.018536762467452457, 0.05992967848266874, 0.05433313861223204, 0.03253511292859912, 0.032759538386017084, 0.02732824893402202, 0.01777257936607514, 0.0675407922161477, 0.06807189514594418, 0.08430428483656474, 0.03161678024168525, 0.03588059251861913, 0.040128116562430344, 0.18548521479325636, 0.2683071313159806, 4.526919007301331, 51.51800904955183, 44.6512086050851, 45.05949865068708, 42.066211223602295, 33.39301116125924, 74.92067446027482, 2.293131568602153, 0.976088149206979, 3.2736856724534715, 5.861918526036399, 7.845177156584604, 2.3118118005139485, 0.2653395991240229, 8.711305720465523, 64.19345487867082, 58.26781920024327, 67.25956984928676, 62.104604039873394, 61.1260266985212, 52.7448524747576, 51.66159009933472, 44.536052635737825, 47.40504721232823, 46.42189448220389, 51.60385404314314, 50.659218651907786, 55.21837643214634, 53.12568323952811, 52.76593678338187, 48.16639954703194, 49.06756353378296, 44.2236442565918, 43.7556483404977, 43.58428839274815, 44.52443872179304, 44.04561751229422, 46.048817907060894, 43.41556181226458, 41.220278467450825, 43.331050872802734, 44.65186520985195, 45.14270680291312, 43.03543628965105, 42.56502934864589, 42.38437965938023, 40.58309391566685, 41.413483551570344, 47.44653490611485, 56.73259040287563, 57.139692306518555, 54.69447878428868, 54.90623208454677, 57.55807113647461, 60.56934397561209, 57.73695945739746, 57.01355818339756, 57.12860298156738, 54.00902509689331, 53.761558055877686, 52.99876396996634, 55.52347878047398, 54.59315667833601, 57.810502665383474, 51.13338456835066, 45.10795538766043, 62.25911808013916, 52.63390016555786, 55.770209312438965, 50.633360930851524, 46.545895508357454, 42.09362881524222, 43.51060969488961, 46.29389476776123, 47.55959251948765, 51.95538078035627, 49.33233158929007, 48.20461116518293, 44.444986070905415, 40.343137877328054, 38.72353710447039, 39.93254797799246, 38.82765586035592, 38.47421489443098, 40.77113996233259, 37.960298333849224, 40.059418610164094, 39.30660213742937, 39.41014419283186, 41.825754914964946, 42.24634674617222, 42.90180853434971, 44.90664522988455, 53.20804023742676, 52.87062529155186, 52.791412353515625, 46.25192764827183, 38.76774501800537, 39.43863180705479, 38.88157040732247, 38.47903347015381, 40.32068477358137, 45.47649131502424, 51.15920754841396, 50.32626097542899, 52.49381405966622, 49.533714703151155, 50.77807106290545, 49.8289714540754, 53.701094831739155, 53.13701227733067, 55.98040969031197, 56.164391040802, 56.97331769125802, 54.80162000656128, 53.62892389297485, 53.75834451402937, 37.299239771706716, 0.10393536822604281, 0.43339060300162857, 1.257380866578647, 1.293986908027104, 0.9295967753444399, 14.741256441388812, 43.119398321424214, 24.321722745895386, 63.27072715759277, 34.08037212916783, 38.708108629499165, 9.55642032623291, 0.5684654020837375, 0.0665661513007113, 0.13263343008501188, 0.06737824915243046, 0.07274023643029587, 0.013513399786981089, 0.021233708464673588, 0.037270646143172464, 0.056520138401538134, 0.04293286481073924, 0.043842457966612916, 0.09025608867939029, 0.0158901841246656, 0.029264587709414105, 0.08903113619557448, 0.07618701112057481, 0.0655154398243342, 0.04356972420854228, 0.038110435009002686, 0.06051688947315727, 0.14646220446697303, 0.10672137872981173, 0.1689530619020973, 0.17663757955389364, 0.16326613777450152, 0.13724459122334207, 0.2176266722381115, 0.08092406764626503, 0.1578484292009047, 0.20845138600894383, 0.12562018712716444, 0.10916676465421915, 0.15287167339452676, 0.12739591327096733, 0.1333271371466773, 0.17139975061374052, 0.12106268453810896, 0.10823217087558337, 0.20039070211350918, 0.2095015003745045, 0.2764433633003916, 0.09728591503309351, 0.1630848739296198, 0.11541986518672534, 0.27958099065082415, 0.4772612846323422, 6.186802395752498, 66.2260878426688, 51.34816380909511, 51.531829016549246, 51.514851093292236, 34.605197361537385, 80.38220173971993, 4.45870897599629, 2.9530297815799713, 5.474000598703112, 11.007285833358765, 15.11863568850926, 3.735740227358682, 0.235999446362257, 8.900287168366567, 66.77945627485002, 60.94892406463623, 69.83789348602295, 65.96336255754743, 64.85973848615373, 55.544913973127095, 54.36253901890346, 47.19292218344552, 49.91402782712664, 51.10858644757952, 56.34970644542149, 54.74608652932303, 58.76943397521973, 57.73395436150687, 55.53543315614973, 52.3955317905971, 51.88675342287336, 46.931892258780344, 46.93103068215506, 46.27779926572527, 46.927775451115195, 46.87484060014997, 48.60907275336129, 45.94260079520089, 42.453774792807444, 45.88918651853289, 46.35916267122541, 48.12776061466762, 46.06312772205898, 44.18341418675014, 45.914061069488525, 41.62544182368687, 44.32131508418492, 49.15253305435181, 56.78895418984549, 57.92472062792097, 57.87260913848877, 55.19740676879883, 59.50508144923619, 60.99187088012695, 60.04882662636893, 56.734042576381135, 59.887155941554475, 57.33317879268101, 56.310369219098774, 55.2735138620649, 56.8195366859436, 57.37480197634016, 58.91765294756208, 53.01383113861084, 48.809583868299214, 59.64535168239048, 54.427556787218364, 55.558160713740754, 52.01743514197213, 49.34634610584804, 44.33304711750576, 45.08654451370239, 47.08439826965332, 52.65565150124686, 53.03786495753697, 51.825390407017295, 50.73070171901158, 46.360527992248535, 43.4204672404698, 40.030222279684885, 41.88209785733904, 40.08140271050589, 40.29847833088466, 43.24406637464251, 39.45105866023472, 42.16503545216152, 41.513103348868235, 41.684960092817036, 45.24422345842634, 45.35866723741804, 45.53118058613369, 47.39239454269409, 55.98678813661848, 57.28179339000157, 55.62450211388724, 48.40097073146275, 42.353154454912456, 43.24905865533011, 41.254783221653526, 39.22743436268398, 42.1917200088501, 47.76544679914202, 52.99059983662197, 51.90861940383911, 54.77512305123465, 51.651289394923616, 51.923620564596995, 52.41599423544747, 56.03675610678536, 55.51383468082973, 58.229135104588096, 59.701229095458984, 57.206999506269185, 55.431206703186035, 54.0058011327471, 53.96066910879952, 38.510793685913086, 0.11301513708063535, 0.47470722453934805, 2.8023376848016466, 7.651387555258615, 1.7496309897729327, 17.32461404800415, 46.706364154815674, 32.0630738394601, 66.43775081634521, 37.484701088496614, 53.42633874075753, 11.925654428345815, 0.8731075408203262, 0.29385869737182346, 0.292818123208625, 0.14109222404658794, 0.21360390952655248, 0.08951525736067976, 0.1513810676655599, 0.09810362436941691, 0.16205523775092193, 0.15150454746825354, 0.1769429881657873, 0.1488467258002077, 0.14404420421591826, 0.08644031986062016, 0.1455100705581052, 0.18818784691393375, 0.14739814853029592, 0.11756219023040362, 0.143571726711733, 0.17161876814705984], [0.004215197363269648, 0.022132813165496503, 0.08555793935166937, 0.03267629910260439, 0.05092916591092944, 0.0443919424100646, 0.04597064573317766, 0.016750573313661983, 0.02164184388571552, 0.023637093071426665, 0.04417273149426494, 0.09810063202998467, 0.02013527392409742, 0.05112617855359401, 0.08535833470523357, 0.026892040822921053, 0.017948499747685025, 0.03039889470008867, 0.04720833092661841, 0.10037220442401511, 0.05564687740323799, 0.024712716961013417, 0.04059119296393224, 0.10717614647001028, 0.0604484456458262, 0.12739948236516543, 0.07385914067604712, 22.207759380340576, 59.74341855730329, 31.407667636871338, 53.27347142355782, 21.65905145236424, 51.91215603692191, 17.744889736175537, 1.4459662671600069, 5.240779970373426, 9.801997457231794, 10.630538872310094, 3.0280038842133115, 0.3331407723682267, 0.665239369230611, 42.51965413774763, 59.0964162009103, 66.80127361842564, 57.444575786590576, 59.10811696733747, 51.24531657355172, 50.33399084636143, 52.02023526600429, 54.15463154656546, 57.75217253821236, 60.55743476322719, 58.210312434605186, 57.717591353825156, 54.139345509665354, 55.067027296338765, 51.371068545750205, 48.84137882505144, 44.4099497795105, 42.642953395843506, 41.68663808277675, 40.897249766758506, 41.73740856988089, 41.605715887887136, 42.150367804935996, 47.65775319508144, 44.86867332458496, 42.203174114227295, 42.59718213762556, 41.965847969055176, 40.510638100760325, 43.18707030160086, 39.834185804639546, 41.434262139456614, 43.77221632003784, 53.398003986903596, 55.598053795950754, 55.15105186189924, 49.16705478940691, 52.52192299706595, 48.398438113076345, 62.04715633392334, 51.67550039291382, 52.6960483278547, 55.57520464488438, 58.71514769962856, 56.09415170124599, 59.8351069859096, 54.55682454790388, 57.16597734178816, 49.06344672611782, 47.17235204151699, 57.97756862640381, 53.15855516706194, 53.00006675720215, 47.04390069416591, 47.00888524736677, 44.51533310753958, 46.424864837101524, 47.048830441066194, 48.814513615199495, 48.83654635293143, 49.21820395333426, 49.797926902770996, 48.1781941141401, 40.46736124583653, 38.902415003095356, 38.365089961460654, 36.48825645446777, 38.402367046901155, 37.77567080089024, 37.04757601874215, 37.570507866995676, 38.33659887313843, 43.14300830023629, 41.173739433288574, 41.651935304914204, 43.64480025427682, 48.11020599092756, 50.00151259558541, 51.5299391065325, 50.494400433131624, 51.40413154874529, 44.54418550218855, 37.8479494367327, 39.05912814821516, 38.262308733803884, 37.66339485985892, 43.32187230246407, 50.89676366533552, 52.51731981549944, 52.94925805500576, 49.08587203707014, 50.49313586098807, 49.08773068019322, 52.3169059753418, 50.66607999801636, 54.256825651441304, 49.72427947180611, 57.52338225500924, 53.83351360048567, 56.626800605228965, 42.84876251220703, 0.6870820628745216, 0.10366052761673927, 0.11232850713921444, 0.6125081330537796, 0.8232953080109188, 0.19514690206519195, 18.917698757989065, 21.445630584444316, 32.75014645712716, 37.96750014168875, 31.365665776388987, 26.164911338261195, 1.3200163798672813, 0.11516742301838738, 0.006792734767909029, 0.00736759090796113, 0.054576980349208624, 0.027348476062927927, 0.050832715550703664, 0.08994168947849955, 0.06117719225585461, 0.018808486904682856, 0.02860411529296211, 0.06042293272912502, 0.0833947222147669, 0.044381011210914166, 0.05147718132606574, 0.026252197567373514, 0.01688440077539001, 0.032864623104355166, 0.05788651454661574, 0.030757276540888206, 0.005806855192141873, 0.02368796114543719, 0.06461988895067147, 0.09447517192789487, 0.05190872959792614, 0.02892311496127929, 0.008215603618217366, 0.05401959775813988, 0.08296510776770966, 0.058910030339445384, 0.04611500745107021, 0.013134445612584906, 0.023489340374778424, 0.022058847759451185, 0.05891363336039441, 0.021184494319771017, 0.07049034323011126, 0.018988195208034346, 0.0513120869706784, 0.012153016802455698, 0.030557118888412203, 0.014033071946219673, 0.06317629891314677, 0.11694491335323878, 0.05526103525023375, 0.030175829705383097, 0.025301727765638913, 0.27849818446806496, 33.01467827388218, 62.75406605856759, 32.68182482038225, 60.11360468183245, 23.274620532989502, 63.437817437308176, 17.112049545560563, 1.1145428397825785, 2.191307238170079, 7.628383806773594, 3.8793052094323293, 3.6763782926968167, 0.12005869698311601, 0.9098349043301174, 47.057870047433035, 62.719137464250835, 67.63440431867326, 60.99330220903669, 62.35676111493792, 53.861174379076274, 52.016625676836284, 54.664601530347554, 54.5908568246024, 58.16160903658186, 61.55127729688372, 61.18860217503139, 60.33896950313023, 56.75895881652832, 55.654410634722026, 53.72416632516043, 51.21072844096592, 46.97591951915196, 43.92758846282959, 43.36611148289272, 43.79545109612601, 45.024083682468955, 44.48890910829817, 45.302553585597444, 48.81779316493443, 44.61466455459595, 43.026348045894075, 44.32344470705305, 43.64256988252912, 42.75031696047102, 43.959894112178254, 40.78497382572719, 41.44213792255947, 45.71131958280291, 56.655785015651155, 59.59614453996931, 57.5989647592817, 53.01574536732265, 54.14385141645159, 53.58032819202968, 60.63377462114607, 51.967689514160156, 56.86555807931082, 56.36259535380772, 59.22900172642299, 56.26583474023001, 59.97392504555838, 55.57524633407593, 56.808329241616384, 47.93367658342634, 49.96300915309361, 60.30761228288923, 55.935472215924946, 52.826090812683105, 48.015067781720845, 47.33049304144723, 46.42919703892299, 46.71997914995466, 48.22652925763811, 49.49234512874058, 50.17327206475394, 50.39631271362305, 51.0467335837228, 48.16807058879307, 42.90580722263881, 40.69453607286726, 40.393387249537874, 40.511451039995464, 40.43388482502529, 40.23605571474348, 39.16234711238316, 38.504446506500244, 39.67894567762102, 43.512603827885215, 42.83586318152291, 44.520120416368755, 45.94929191044399, 50.75250169209072, 52.19897420065743, 52.58081940242222, 52.113570417676655, 52.445607457842144, 45.187963894435335, 38.7681097984314, 40.43472555705479, 39.303378173283164, 39.8488221849714, 45.81160640716553, 52.93343005861555, 53.544305256434846, 55.51659311567034, 51.37625190189907, 52.203917843954905, 49.43028729302542, 52.00309406008039, 52.29938261849539, 56.03897953033447, 50.94787114007132, 59.00658988952637, 53.504405226026265, 56.29808132989066, 43.89172880990164, 0.8913208320736885, 0.42596387437411715, 0.7828845307230949, 1.3693102662052428, 0.6385208315082959, 0.2712843801294054, 23.540005241121563, 26.99007245472499, 40.111231327056885, 46.531516211373464, 34.993250778743196, 38.896178994859966, 2.6534110818590437, 0.1424342848892723, 0.05691497453621455, 0.04712351744196244, 0.05239907292915242, 0.03174967132508755, 0.06079258503658431, 0.03142660044665847, 0.03266947643299188, 0.05480099529294031, 0.08578738596822534, 0.05601134231047971, 0.05675148152347122, 0.04587066699085491, 0.03718696581199765, 0.029729272238910198, 0.021991187640066658, 0.04384089733607002, 0.02452192478813231, 0.032807446351008754, 0.05391814659482666, 0.16330564208328724, 0.09459375270775386, 0.1706602152969156, 0.11483659648469516, 0.1384646107575723, 0.08437160229576485, 0.17494729453963892, 0.13860730667199406, 0.1839731266455991, 0.10510134923138789, 0.12427841126918793, 0.15886843018233776, 0.15942503245813505, 0.13885224424302578, 0.13575226201542787, 0.09452287293970585, 0.127858144896371, 0.11497516690620355, 0.11436861088233334, 0.13415478702102387, 0.15106020202594145, 0.0967259065115026, 0.12498705967196397, 0.19501722045242786, 0.13764171062835626, 0.2078371082565614, 0.5350461953452655, 41.26015417916434, 74.48434148515973, 38.2832783971514, 71.42106137956891, 30.601655755724224, 65.00998633248466, 21.686675752912247, 1.8116166293621063, 13.35065700326647, 23.143480232783727, 22.992367335728236, 5.674598566123417, 0.549146750143596, 0.8803184681705066, 47.02443184171404, 65.26150417327881, 71.92201260157994, 62.701746123177664, 66.22075162615094, 56.85501071384975, 56.35248919895717, 57.96479436329433, 59.265722955976216, 64.02368259429932, 65.12915488651821, 63.49584184374128, 61.11028902871268, 59.896633284432546, 59.261039870125906, 56.069106919424875, 53.3501934323992, 50.5353079523359, 47.07894045966012, 46.60061257226126, 47.37239415305001, 45.96402556555611, 47.00527218409947, 47.770348753247944, 52.62984241758074, 48.81861652646746, 46.287502425057546, 47.3999993460519, 46.75959777832031, 44.62013626098633, 47.99346235820225, 44.373436995915, 45.12997422899519, 46.82300703866141, 57.35536091668265, 61.134211676461355, 59.021278381347656, 52.99230561937605, 53.1678865977696, 56.937489305223735, 58.636910983494346, 52.10525689806257, 56.89963551930019, 59.891290119716096, 62.39181477682931, 59.118914467947825, 61.762446948460166, 57.00766263689314, 58.53505039215088, 48.407623631613596, 49.27367489678519, 60.6222197668893, 58.89614132472447, 56.49855422973633, 51.22900915145874, 50.26570395060948, 47.42603424617222, 49.756644180842805, 49.754215785435264, 52.40461656025478, 52.46704612459455, 52.12249537876674, 54.70964322771345, 51.625949314662385, 46.20228624343872, 42.08786528451102, 41.75057193211147, 42.33583606992449, 43.77177510942732, 43.0027311188834, 42.06331035069057, 40.93664952686855, 42.61857911518642, 48.184694153921946, 44.8066919190543, 46.557002203805105, 50.87640544346401, 53.467496395111084, 54.138813972473145, 56.30846888678414, 54.18202134541103, 55.70390612738473, 48.886767932346885, 41.529379504067556, 43.51405252729143, 43.47298867361886, 41.35542440414429, 48.066064085279194, 55.47644642421177, 57.73943649019514, 56.56695924486433, 53.9589216368539, 53.59104578835623, 52.65756572995867, 54.62823118482317, 55.69158002308437, 59.30976063864571, 53.542880875723704, 61.0771461214338, 55.29617541176932, 55.85954230172293, 48.441200801304404, 1.1442265212535858, 0.5550904454929488, 1.0461953644241606, 4.09544803415026, 4.90380015543529, 0.40578595282776014, 25.30972010748727, 32.896788188389365, 45.331770760672434, 44.799851417541504, 42.098436968667166, 50.571692194257466, 2.644903664078031, 0.3707807926195008, 0.17426481044718198, 0.12812902964651585, 0.1697163323738745, 0.13794965696121964, 0.10406304816050188, 0.17331245940710815, 0.1434382317321641, 0.1330675296485424, 0.1915056931653193, 0.1440572320882763, 0.16867179556616715, 0.07864473959697144, 0.16423945554665156, 0.09520028159022331, 0.0691861514268177, 0.12698434107005596, 0.22804264617817743, 0.15466623567044735, 0.11198598266180072], [0.059968958874898295, 0.028699432499706745, 0.0451761626505426, 0.06810278884534325, 0.02371276668938143, 0.02098665725705879, 0.06923913822642394, 0.01585629130048411, 0.03860976214387587, 0.1606151285980429, 0.014484800697703446, 0.02935788288180317, 0.01943131080562515, 0.03940534784591623, 0.07881124530519758, 0.001908320580176743, 0.03915302442120654, 0.032989381945558956, 0.026086431462317705, 0.019339974903102432, 0.06133042581911598, 0.018388487298839858, 0.08063695912382432, 0.09160416134233985, 0.030727797587003027, 0.06457392498850822, 0.08950192414756332, 7.707553318568638, 58.327063015529085, 40.317936761038645, 37.78165667397635, 47.69522830418178, 28.953459671565465, 42.24366126741682, 0.22730639497084276, 0.9546782523393631, 2.5717024377414157, 3.6189868237291063, 2.3870531916618347, 0.23958243695752962, 0.048901309724897146, 22.926764181682042, 63.7715950012207, 64.01432337079729, 65.58317797524589, 60.6137638092041, 58.60161413465227, 60.45886066981724, 58.27508701596941, 60.36867305210659, 58.9719809123448, 61.69591794695173, 58.65059198651995, 58.476025445120676, 56.85730709348406, 56.90626410075596, 55.50593457903181, 52.47842379978725, 45.62152453831264, 40.844641481127056, 42.22824321474348, 43.40182522365025, 41.15397180829729, 47.33383512496948, 52.90285103661673, 55.33163901737758, 53.68468318666731, 45.26101378032139, 39.78827558244978, 42.43542112622942, 40.33373349053519, 41.77486283438546, 37.56390013013567, 39.71689673832485, 38.690821511404856, 49.59408412660871, 54.85939080374581, 55.773468017578125, 52.57032414845058, 53.15847526277815, 44.75618893759591, 48.19374418258667, 63.51368481772286, 58.745309829711914, 57.1318165234157, 52.89716741016933, 52.91880062648228, 53.92924588067191, 54.21969795227051, 53.23892150606428, 40.91800056185041, 47.44785853794643, 59.672011920383994, 49.809596402304514, 53.94288172040667, 45.30326925005232, 47.13584620612008, 45.02659893035889, 49.21771757943289, 47.63247217450823, 50.06188549314226, 50.3956561088562, 52.51977252960205, 51.0726329939706, 52.39610849108015, 44.21501806804112, 37.33154889515468, 38.55793373925345, 37.40452929905483, 37.53934867041451, 37.71320996965681, 37.05366958890642, 39.54236146381923, 41.762991837092805, 43.17700931004116, 44.33787611552647, 46.52968883514404, 44.10565342221941, 48.61838681357247, 48.76609509331839, 51.747879777635845, 52.8824337550572, 50.7328382900783, 48.801009791237966, 42.297638348170686, 37.9206553867885, 37.403632981436594, 36.552725315093994, 41.28205837522234, 52.140390464237754, 52.55535772868565, 51.28948279789516, 54.80816520963396, 50.979318686894004, 51.73488317217146, 50.42543956211635, 51.26056786945888, 50.51092324938093, 53.40884665080479, 55.789247376578196, 53.054377351488384, 48.02744252341134, 1.1114099621772766, 0.09441649900483233, 0.09087564543421779, 0.6319291080747331, 1.3275305309465952, 0.49828224522726877, 0.6026647612452507, 14.422141313552856, 31.56781666619437, 32.46409259523664, 20.52538858141218, 42.08930703571865, 16.31446235520499, 0.22579288189964636, 0.028208419115149548, 0.029677859640547206, 0.04894155024417809, 0.04325400186436517, 0.03740233961226685, 0.07973869411008698, 0.037243528491152186, 0.10464749751346451, 0.05187578672277076, 0.06893613841384649, 0.062195551182542524, 0.06689217380647149, 0.04860764994685139, 0.04837277844282133, 0.039809323847293854, 0.06444874206291777, 0.05784259297485862, 0.011414429738319345, 0.05356504036379712, 0.010569766446548914, 0.02661197379763637, 0.0336558560042509, 0.05321873983900462, 0.07007484909679208, 0.07036224260394063, 0.06028010789304972, 0.024438042592789446, 0.009461393912455865, 0.027986483881250024, 0.04273379620696817, 0.013666839455254376, 0.04937624352584992, 0.011947836294504148, 0.026732987125537226, 0.03953025596482413, 0.05313705440078463, 0.02961356844753027, 0.04854495331112828, 0.014646812807768583, 0.03692404367029667, 0.05929147558552878, 0.04102440703926342, 0.015012073297319668, 0.11781669514519827, 0.054262957735253234, 0.09482043768678393, 0.07151214232934372, 12.242323790277753, 71.7170546395438, 35.4437198638916, 50.00653266906738, 51.22526059831892, 38.132016113826204, 45.00221422740391, 0.3623315660016877, 1.7998976239136286, 1.6481686170612062, 3.453509177480425, 3.1181593665054868, 0.8172277935913631, 0.2366686447390488, 27.5996743951525, 66.91393171037946, 64.92068808419364, 66.55710002354213, 64.30693285805839, 60.88839830671038, 60.53218500954764, 59.678091594151084, 62.57116862705776, 62.13962296077183, 63.81088011605399, 60.231425285339355, 60.50003569466727, 58.28507852554321, 59.91786697932652, 57.50880146026611, 55.81726598739624, 47.24844871248518, 42.38548789705549, 42.77542775017874, 44.71967962809971, 43.348518644060405, 46.88625301633562, 53.38444110325405, 57.67103842326573, 54.046587058476035, 48.0999539239066, 42.16515357153756, 43.93722908837454, 41.674315452575684, 43.265956674303325, 38.96773154394967, 42.06624596459525, 40.37952559334891, 54.08896064758301, 57.93198496954781, 57.75553546633039, 53.74958978380476, 53.58586590630667, 44.22481850215367, 55.99988896506173, 63.36830071040562, 54.3346072605678, 56.93218435559954, 55.42781598227364, 54.75984396253313, 55.37444339479719, 53.658981800079346, 54.20307786124093, 42.596285820007324, 48.47640037536621, 60.12052508762905, 49.99674613135201, 56.17763778141567, 48.03716305324009, 50.06335851124355, 48.78188487461635, 51.455433573041645, 47.558918544224326, 50.264929226466585, 53.043479101998464, 53.33389643260411, 53.90897798538208, 52.42823001316616, 44.971346855163574, 39.54088844571795, 40.18073068346296, 39.61940656389509, 39.64978061403547, 38.0155782018389, 38.35856212888445, 41.76809876305716, 43.78056805474417, 45.20779405321394, 45.18444810594831, 48.079387256077354, 46.51975638525826, 53.09562185832432, 52.967556135995046, 54.810079438345774, 54.06985657555716, 52.74282012666975, 50.804918902260916, 43.42726952689034, 38.62338924407959, 39.05988897596087, 38.92767170497349, 43.03994567053658, 55.37445034299578, 54.886964729854036, 55.03724384307861, 56.63477713721139, 52.86326020104544, 52.8798941884722, 52.76982430049351, 52.51682301930019, 53.09843240465437, 56.36306783131191, 57.49746200016567, 53.060741901397705, 50.7892541885376, 1.4221046332802092, 0.16096339348171437, 1.7269764968327113, 2.1474669277668, 1.4724166478429521, 0.3109256444232804, 0.802362285554409, 19.221507004329137, 34.96499245507376, 39.245103631700786, 20.234488351004465, 47.68365260532924, 22.429653576442174, 0.2009714330945696, 0.0199453909881413, 0.04464876452194793, 0.03411831154621073, 0.030479117895343473, 0.08679994342050382, 0.03818932149027075, 0.1055884627359254, 0.035625687268163474, 0.09475924061345202, 0.04962289779047881, 0.04608068375715187, 0.012021359804618572, 0.033135806409908194, 0.037410261508609564, 0.04077747457527688, 0.012357330481920923, 0.0855590792905007, 0.07589852517204625, 0.09727684301989419, 0.018098722311801145, 0.14522093321595872, 0.09554666014654295, 0.29165391996502876, 0.17208009053553852, 0.12030770576425961, 0.11012942942657641, 0.14524525191102708, 0.10188637567417962, 0.12663291421319756, 0.22671298895563397, 0.16100236853318556, 0.12081891404730932, 0.08404172571109873, 0.13649387364940985, 0.1490632463246584, 0.10759195951478821, 0.12859445038650716, 0.07572021295449563, 0.12476158248526709, 0.08665428909340075, 0.21982166516993726, 0.09653228654393128, 0.1777062722082649, 0.13109562546014786, 0.16355869493314198, 0.12671636044979095, 0.19721803521471365, 12.831915787288121, 79.33556679316929, 48.4977000781468, 55.5529009274074, 57.77117586135864, 41.35102619443621, 51.45919949667794, 0.25287026965192383, 4.0833169136728555, 7.169440524918692, 10.537634508950369, 5.6755878158978055, 1.4275547351155962, 0.2935585949037756, 27.744398423603602, 72.6720358984811, 67.89168221609933, 70.96675341469901, 66.99897071293422, 66.65656348637172, 63.88654599870954, 63.156686374119346, 65.80110127585274, 64.29418291364397, 67.68361146109444, 63.12681606837681, 63.67145756312779, 62.41686303274972, 61.4270087650844, 61.33792591094971, 57.38619007383074, 50.22492497307913, 44.2930463382176, 45.49797861916678, 47.53076791763306, 45.53649248395647, 50.817908559526714, 57.10740055356707, 60.19152872903006, 57.403765542166575, 50.878375257764546, 43.887323651994976, 47.724369049072266, 43.390082768031526, 46.886298179626465, 41.40786940710885, 44.15224804197039, 42.074434416634695, 53.69320862633841, 59.02423136574881, 58.74196774618966, 56.950009959084646, 54.70959806442261, 49.48448671613421, 56.42300646645682, 60.51185458047049, 56.61047581263951, 60.13392816271101, 56.537637846810476, 54.694589955466135, 56.7569751058306, 55.305663176945274, 54.38582590648106, 40.5956632069179, 44.06166785103934, 62.46443040030343, 52.29760387965611, 57.02484205790928, 49.994453225817, 51.453074659620015, 49.931777000427246, 54.381483282361714, 50.56446259362357, 52.08577067511422, 54.58799416678292, 56.73173230034964, 55.77879728589739, 55.921211038317, 47.889948095594136, 41.87415606634957, 43.816716057913645, 41.181302547454834, 41.89683151245117, 40.25184202194214, 40.56413228171212, 45.146194798605784, 47.05010543550764, 48.50570092882429, 49.25505025046212, 49.84532403945923, 48.83174514770508, 55.241701534816194, 54.29380743844168, 55.859219210488455, 55.9669406073434, 55.962035179138184, 54.1294721194676, 47.38115235737392, 41.51241200310843, 41.03570304598127, 41.95732600348336, 45.10698611395699, 58.519389152526855, 55.932203088487896, 56.1785375731332, 58.97732407706124, 54.05101306097848, 56.50657939910889, 54.80001149858747, 54.578985827309744, 55.48897750037057, 58.4413400377546, 58.61528124128069, 54.29237263543265, 51.75865643365042, 1.7192918977567127, 0.16980557329952717, 1.1694724751370293, 4.151874354907444, 6.470255025795527, 1.5476351316486086, 0.9713892127786363, 23.83111912863595, 43.662782192230225, 43.8970685005188, 30.504638058798655, 59.16319533756801, 27.52699797494071, 0.24358060956001282, 0.09152344960187163, 0.2181055144007717, 0.10565586840467793, 0.10297296808234283, 0.19896714921508515, 0.1463351419993809, 0.13851136182035717, 0.19170447678438254, 0.17129281349480152, 0.1610775909253529, 0.1139120382389852, 0.11958460456558637, 0.15213724066104206, 0.12325629325849669, 0.16574581685875142, 0.20299983210861683, 0.153282512777618, 0.1523361871285098, 0.1991423469569002, 0.17843238610242093], [0.06200972079698529, 0.02524584871051567, 0.08088378302220788, 0.03110219963959285, 0.06814970954188279, 0.02508025393555207, 0.020013563401464905, 0.03335637100307005, 0.032697391363659074, 0.003211871167877689, 0.06609199781502996, 0.026038818660059145, 0.07797847927681037, 0.037722849021000524, 0.04188639417822872, 0.028327295057741658, 0.060735574524317465, 0.035367097572556565, 0.02942263547863279, 0.012113617666597878, 0.029467055773628608, 0.10707946201520306, 0.0551781759464315, 0.044429428077169826, 0.05421248830056616, 0.05322886697415795, 0.055656166547643285, 0.17268512664096697, 19.659762893404277, 58.87885420663016, 25.050371646881104, 52.2133708681379, 25.63483326775687, 41.41214254924229, 5.925373383930751, 2.489472678729466, 1.0101072894675391, 2.546439221927098, 2.0805599008287703, 0.7812569694859641, 0.2565438582428864, 3.3940232608999525, 55.61109903880528, 60.55791418892996, 68.67746789114815, 61.839537211826865, 64.73212092263358, 58.014678955078125, 62.48921462467739, 62.99657208578927, 64.81909847259521, 57.70999697276524, 59.381709235055105, 54.96540641784668, 58.694226673671174, 58.0529774257115, 58.21368925912039, 56.25274780818394, 47.09377138955252, 43.37936864580427, 44.65204586301531, 41.99533959797451, 45.179664271218435, 52.914346831185476, 56.11660827909197, 58.910510199410574, 57.718227113996235, 52.048184394836426, 45.24581112180437, 40.46689224243164, 40.25267580577305, 39.53898811340332, 41.280217102595735, 41.54654850278582, 41.72746222359793, 42.23212725775582, 53.920532839638845, 57.24681963239397, 55.287142753601074, 54.92194890975952, 50.93348142078945, 41.90702451978411, 44.13499566486904, 55.036535126822336, 54.74232060568673, 59.48194394792829, 53.041533606392996, 54.51394026620047, 49.63899033410208, 49.293578011649, 35.87665169579642, 51.72973803111485, 61.46992778778076, 53.1063985143389, 52.17580195835659, 47.49377918243408, 49.624055181230815, 48.07974508830479, 52.412978717258994, 51.54503754207066, 54.47920969554356, 53.10198988233294, 53.28167029789516, 53.136529377528596, 53.9394736289978, 48.58402449744088, 37.17293889181954, 38.942589487348286, 37.72872877120972, 37.754899161202566, 37.388704776763916, 36.20046901702881, 38.055123874119346, 42.59529570170811, 45.13348306928362, 44.850590637751985, 45.34592424120222, 46.969735622406006, 48.7935265813555, 50.15479333060128, 51.98359394073486, 54.16886840547834, 52.51001378468105, 50.37830645697457, 45.34853676387242, 40.11974287033081, 38.379497051239014, 37.177326679229736, 40.09950276783535, 46.44973243985857, 53.60634224755423, 53.89739186423165, 53.886566570826936, 54.86529329844883, 53.75051042011806, 52.91091094698225, 55.33874355043684, 52.56711408070156, 55.88698768615723, 51.861871923719136, 56.43304313932146, 6.056749488626208, 0.37422376072832514, 0.5378740036061832, 1.3188605904579163, 0.5355309407625879, 0.6548060519354684, 0.11579710351569311, 0.5427790518317903, 19.857941150665283, 40.31134639467512, 24.29088316644941, 30.02356215885707, 39.640615940093994, 2.8904169585023607, 0.28427819002951893, 0.1411511751690081, 0.16784038660781725, 0.05470061621495655, 0.0189905514208866, 0.08398548872875315, 0.007540435829598988, 0.02729547060360866, 0.051740856641637425, 0.010079003271779843, 0.059057245297091346, 0.06218295757259641, 0.07794590959591524, 0.0654457610632692, 0.03216599666380456, 0.048276660564754686, 0.059041082592947144, 0.04780486498826316, 0.04785638275955405, 0.06249649503401347, 0.021602203869926076, 0.040821820231420655, 0.008434209789681648, 0.026097988610022833, 0.037109633175922294, 0.01733966893516481, 0.02704756274553282, 0.029062896567795957, 0.025409350204946737, 0.03673872557867851, 0.05722121096083096, 0.05959410220384598, 0.019648711729262556, 0.08042132748024804, 0.04554200159119708, 0.07872551240559135, 0.019783789391762445, 0.08279237989336252, 0.030065482947975397, 0.04367129072280867, 0.07027084393692867, 0.023167014188532318, 0.015453171949567539, 0.1461282702428954, 0.029044918782476867, 0.026958781527355313, 0.032624662587685246, 0.058422794698604515, 0.7377615720033646, 34.04615919930594, 65.59367670331682, 26.705571515219553, 60.454372133527485, 30.1240713255746, 54.43041944503784, 3.6283245512417386, 1.4033890089818408, 1.7533998446805137, 1.8333104252815247, 3.3643427278314317, 2.053587428161076, 0.07136627087103468, 4.773452818393707, 61.89059257507324, 64.04870305742536, 71.11104665483747, 64.54870237622941, 66.63930416107178, 60.042350905282156, 65.2601979119437, 65.14794281550816, 66.58473995753697, 60.02491787501744, 62.99418885367257, 56.860499790736604, 60.519455909729004, 58.365806170872276, 59.671497753688264, 57.44336332593645, 48.70888362612043, 43.208331789289204, 46.28795058386666, 44.19636910302298, 46.112619740622385, 54.500901971544536, 59.54210145132882, 59.27374117715018, 60.48358236040388, 52.170500482831685, 46.17423636572701, 42.68651165281023, 42.504138810294016, 42.0757372038705, 43.062381403786794, 43.76551478249686, 42.79732499803816, 44.43346248354231, 54.94842849458967, 58.43731008257185, 57.316305092402864, 56.76256840569632, 53.58377449853079, 42.06925106048584, 52.76249047688076, 59.32740906306675, 53.99593121664864, 54.84891292027065, 53.758737087249756, 54.57143313544137, 49.83260883603777, 48.66057627541678, 39.167599950517925, 52.51118803024292, 61.94900608062744, 56.062940393175396, 53.43407208578927, 48.33500453404018, 51.77426208768572, 48.60910749435425, 53.824849196842735, 53.9623783656529, 54.716362135750906, 52.36319834845406, 56.020191601344514, 54.482079301561626, 55.9097569329398, 48.61141082218715, 39.13933120455061, 41.30947249276297, 39.26926251820156, 39.76248386928013, 40.094347204480854, 38.414432593754356, 41.07214287349156, 44.636759826115195, 47.00799240384783, 46.751315525599885, 47.60688543319702, 47.419621058872764, 51.77411617551531, 52.41036966868809, 54.90797955649239, 55.12223768234253, 53.95340476717268, 51.422898633139475, 47.67414746965681, 42.045443058013916, 39.40244558879307, 39.3919677053179, 41.71591779163906, 48.24670335224697, 55.94085706983294, 54.78609773090908, 56.54904331479754, 56.14751386642456, 58.72563253130232, 55.07980503354754, 57.231446743011475, 54.3711130959647, 58.12958478927612, 52.477114064352854, 60.15669046129499, 7.191178832735334, 0.19794431195727416, 1.9903790141854967, 3.0932835127626146, 2.4662813288824896, 0.4622242972254753, 0.15934784231441362, 0.9484818705490657, 23.494751623698644, 45.26212201799665, 32.52731772831508, 28.961568219321116, 50.342707361493794, 4.232472155775342, 0.06195524800568819, 0.05998616652297122, 0.12414494343101978, 0.013997807633131742, 0.0623825690043824, 0.03957228103120412, 0.07023621150957686, 0.044217959245932956, 0.05290612857788801, 0.0784586581534573, 0.0397327409924141, 0.06662101085696902, 0.0367790407368115, 0.015117073198780417, 0.028750448155083826, 0.04698699958888548, 0.02474620096784617, 0.04715204305414643, 0.037201564492923875, 0.009211517454657172, 0.03399160870217851, 0.12003022565373353, 0.1404586351875748, 0.13052204623818398, 0.12132328269737107, 0.13386727816292218, 0.23915514988558634, 0.0809663539486272, 0.12658233621290751, 0.09759542199649981, 0.13742870491530212, 0.16684987475829466, 0.11414822270827633, 0.1678260966603245, 0.19023247648562702, 0.21326101864022867, 0.1076523627021483, 0.23933455454451696, 0.10822871034698826, 0.1625831379954304, 0.11442874265568596, 0.1423137906406607, 0.3030393575983388, 0.16730965008693083, 0.1439113470592669, 0.13016430900565215, 0.11652561942381517, 0.10512528116149561, 0.8020685613155365, 40.877808707101, 77.8684755052839, 34.14123487472534, 67.07424054827008, 35.424918038504465, 52.500223772866384, 6.704536122935159, 4.5617073348590305, 6.225148635251181, 5.048271443162646, 8.128186838967459, 3.1520869859627316, 0.2984645116542067, 4.527503090245383, 62.991520745413645, 65.70081792558942, 75.62876537867955, 69.29270308358329, 69.72122628348214, 62.98109149932861, 67.81571061270577, 68.02401760646275, 69.61769117627824, 60.093552180698936, 63.848275320870535, 60.0262519291469, 63.367404392787385, 61.19020026070731, 62.73436791556222, 62.371748379298616, 52.9403087752206, 47.55727876935686, 50.13997629710606, 47.903444971357075, 49.712147917066304, 58.20129714693342, 63.479027203151155, 62.44362054552351, 62.450777190072195, 56.73684270041329, 49.630280767168315, 45.34858887536185, 45.79421854019165, 43.78957292011806, 45.79972498757498, 47.906248569488525, 46.06951659066336, 45.69516849517822, 58.3392710004534, 61.210238865443635, 60.36803381783621, 58.42119721003941, 55.92551892144339, 47.42399842398507, 53.812992095947266, 56.771618434361045, 53.59777511869158, 59.766340664454866, 53.175967352730886, 55.04613406317574, 50.79561873844692, 51.48868417739868, 37.34187044416155, 48.60504974637713, 67.08308560507638, 58.583812849862234, 56.21281998498099, 50.40458106994629, 53.63744238444737, 50.686212403433665, 55.70632757459368, 56.5457672391619, 57.58080564226423, 54.824573380606516, 57.30624062674386, 58.53679438999721, 57.73175525665283, 52.476342814309255, 40.99411112921578, 43.09635462079729, 40.750931126730784, 41.941529273986816, 43.123351846422466, 40.64006914411272, 43.14710078920637, 47.17823369162423, 49.12649120603289, 49.18732268469674, 50.38838481903076, 50.7445946420942, 54.91723108291626, 54.64886038643973, 57.01238393783569, 57.71826185498919, 55.7589567048209, 55.17411988122122, 49.05466072899954, 44.12014389038086, 42.29499108450753, 39.984850542885916, 43.55014494487217, 50.840434619358604, 56.61484622955322, 57.35598278045654, 57.053624970572336, 60.12102535792759, 58.15540429524013, 57.29438699994768, 60.41191864013672, 56.30384833472115, 60.49899346487862, 56.152019773210796, 62.087462833949495, 8.17537726674761, 0.3845845019178731, 1.2117293562207903, 3.542837824140276, 5.963733954089029, 4.133847253663199, 0.7070790869849068, 1.1311687933547157, 33.32388353347778, 51.07098279680525, 37.115807328905376, 41.28980909075056, 58.37253202710833, 5.0077265330723355, 0.627592075083937, 0.21241567257259572, 0.2835738978215626, 0.11714660110218184, 0.15033374886427606, 0.1792371150638376, 0.2072133445846183, 0.10575040868882622, 0.16409734317234584, 0.22989097556897573, 0.10210349330944674, 0.12245548622948782, 0.16246997192502022, 0.11591656639107636, 0.11488756803529603, 0.10760605268712554, 0.11316178206886564, 0.12871003204158374, 0.11777887360325881, 0.19785479961761407, 0.11377211074743952], [0.0413882884063891, 0.06108238734304905, 0.05146998206951788, 0.06356872964118208, 0.02454123759110059, 0.14406247037862027, 0.006286543403153441, 0.027982935143102492, 0.05279894718634231, 0.015590154599132282, 0.1269743801759822, 0.05695386816348348, 0.030406066815235784, 0.0091045701576929, 0.010878866288944014, 0.025355800221275007, 0.010532328276894987, 0.01662408760083573, 0.060423271996634345, 0.056465180457702706, 0.04811937954010708, 0.028262854587020617, 0.01577919445532773, 0.027831881373588527, 0.14662601639117512, 0.14407939304198536, 0.07756756525486708, 0.10535670231495585, 2.181093169110162, 39.16965314320156, 36.30297231674194, 43.514775139944895, 50.593266350882395, 26.61497221674238, 27.931101730891637, 1.0204040855169296, 0.21604290365108422, 1.7670896415199553, 1.5129023896796363, 1.2628001357827867, 0.34490048991782324, 0.030255449004471302, 16.243323223931448, 64.63433197566441, 61.77820546286446, 68.90669591086251, 59.94588211604527, 66.20907170431954, 62.706985064915244, 62.123204367501394, 59.18202495574951, 58.948113850184846, 59.16052028111049, 61.620106152125764, 61.28470270974295, 58.30306393759591, 58.87708936418806, 57.470145157405305, 48.8144337109157, 42.716645990099224, 44.72052730832781, 43.22431264604841, 49.10101216179984, 58.618706703186035, 59.40722302028111, 59.332043511526926, 56.27050045558384, 53.047245025634766, 49.60208150318691, 45.26665571757725, 43.242864336286274, 40.16626453399658, 41.46813113348824, 40.102115290505544, 39.477020604269846, 40.30404731205532, 46.58647298812866, 55.823126792907715, 55.699129240853445, 55.86357225690569, 55.23401682717459, 56.01518195016043, 50.799652167728965, 47.97653307233538, 52.42263323920113, 53.083274909428184, 50.90695667266846, 51.64754778998238, 47.24729183741978, 51.180743489946636, 34.23665101187569, 52.95833240236555, 57.93302025113787, 51.834225041525706, 53.942930357796804, 51.87821408680507, 51.31005988802229, 52.42177513667515, 53.30877522059849, 53.277942589351106, 55.442087582179475, 54.805997371673584, 56.00345686503819, 54.30700554166521, 53.84466545922415, 46.31311348506382, 36.304997716631206, 38.358718463352744, 38.00560058866228, 36.565871306828086, 37.50005660738264, 37.18154770987374, 39.860870361328125, 45.768770762852256, 45.6177864074707, 49.09110403060913, 46.91912146977016, 46.8593669618879, 47.05998577390398, 52.25735991341727, 53.89116627829415, 55.328946590423584, 53.29481281552996, 52.54843037469046, 48.98709297180176, 45.039289815085276, 38.531287397657124, 37.1699025290353, 40.09523657390049, 48.05792079653059, 52.29074253354754, 52.906422410692485, 53.288420472826274, 53.082187516348704, 55.17145872116089, 57.98290831702096, 54.07438680103847, 55.48674018042428, 52.91223805291312, 58.882119859967915, 25.89783126967294, 0.10424440700028624, 0.05385680363646575, 1.2685303368738718, 3.4109551523412978, 3.393266124384744, 0.16326296223061426, 0.029885403146701198, 4.698626364980425, 35.484797613961355, 34.97947250093733, 23.285770654678345, 43.50805275780814, 18.10365128517151, 0.32678805610963274, 0.0853674610012344, 0.03593121462368539, 0.08693461905100516, 0.04435702160532985, 0.02956802856975368, 0.07451708215687956, 0.035709296353161335, 0.082013089209795, 0.03173725413424628, 0.03033705980383924, 0.0298171255604497, 0.05908389136727367, 0.018915541070912565, 0.027724990055763295, 0.009662096089284335, 0.025212556389825683, 0.05881158169358969, 0.029693269170820713, 0.0511184500397316, 0.03702934891251581, 0.058048643703971586, 0.09299080872109958, 0.047465502484036345, 0.012720115166822714, 0.03904351226187178, 0.03786364843004516, 0.0962727265432477, 0.07510592163141284, 0.021563033739637052, 0.025565694851268615, 0.05321070259170873, 0.08557816648057529, 0.018528185784816742, 0.043360864344452105, 0.07784043811261654, 0.02413510554470122, 0.024811080789991787, 0.02801330467419965, 0.05787178355136088, 0.038927710082914145, 0.08839625812002591, 0.03916163842326828, 0.03782646471102323, 0.043116659591240544, 0.09157048564936433, 0.08356262570513145, 0.08085784941379513, 0.11116514527904135, 0.08658371466611113, 7.125417172908783, 60.00978469848633, 32.57583005087716, 49.196796553475515, 49.23855522700718, 32.66505534308297, 30.375283445630753, 1.1441968828439713, 1.2556200410638536, 2.0642064469201222, 3.2035399164472307, 3.892742156982422, 0.5628735678536552, 0.052977540995925665, 21.563425132206508, 68.82581193106515, 65.18345505850655, 68.830230985369, 62.917147227696006, 66.42864867619106, 65.60918508257184, 65.39836978912354, 61.77016639709473, 61.58264146532331, 59.79784379686628, 63.37818104880196, 61.13898508889334, 61.07511724744524, 61.87598746163504, 59.29494707924979, 50.6435991014753, 44.846380029405864, 45.08685023444039, 45.16112300327846, 50.47187784739903, 57.63886478969029, 60.740714345659526, 60.53840364728655, 57.45492860249111, 56.19113118307931, 52.99399403163365, 47.782542841775076, 44.31218862533569, 42.777359349387034, 43.43466935838972, 43.30164609636579, 42.162200587136404, 42.958460671561106, 48.18986013957432, 58.16291529791695, 57.44605575289045, 57.16376086643764, 56.412618909563335, 56.19622073854719, 49.00452600206648, 49.69525684629168, 54.38560356412615, 57.11179528917585, 52.90534543991089, 52.32346854891096, 49.18341432298933, 50.295765331813264, 36.92364794867379, 55.615907192230225, 58.90444442204067, 54.58065339497158, 55.496488503047395, 53.59218181882586, 53.02318688801357, 54.94782747541155, 55.19306761877877, 55.30765730994088, 55.52017838614327, 57.02120120184762, 56.943586349487305, 56.13725137710571, 54.23601232256208, 47.73449257441929, 37.93668835503714, 40.24747855322701, 39.78147677012852, 38.211527824401855, 39.55066108703613, 39.594910689762656, 40.94366373334612, 48.19362606321062, 48.27813005447388, 48.81817878995623, 48.265505177634104, 48.499530928475515, 50.51369558061872, 54.029702935900005, 54.8674750328064, 55.74806887762887, 54.85169914790562, 54.255960600716726, 51.61862938744681, 44.95780481610979, 40.87127045222691, 40.379598549434114, 42.52215896333967, 49.27877140045166, 56.27404751096453, 55.061350618089946, 55.67175333840506, 53.47966269084385, 57.240100724356516, 58.515581539699006, 58.014977727617534, 57.27929203850882, 55.7351313318525, 61.323862757001606, 29.369965962001256, 0.04389325649078403, 0.44281610580427305, 5.92931865794318, 2.9852045008114407, 0.6626890546509198, 0.5611074226243156, 0.1590536566717284, 6.522772550582886, 41.95090586798531, 42.72080448695591, 22.685309069497244, 46.02059779848371, 25.37999939918518, 0.23352339065500669, 0.0467153888062707, 0.048353830352425575, 0.05180915119126439, 0.021073640357436876, 0.033939687202551534, 0.010512092666301345, 0.06816434554223504, 0.036532691812941005, 0.04772685042449406, 0.0349049575493804, 0.02868923411837646, 0.03865784652797239, 0.044330032874963114, 0.024261182440178733, 0.0537985446197646, 0.03554916887411049, 0.05862050623233829, 0.07800280475722891, 0.00988537397435201, 0.014796516292595437, 0.10872124534632478, 0.13219090311654977, 0.09897387267223426, 0.1950812605874879, 0.2146762798407248, 0.07118592304842812, 0.2966094511960234, 0.13919957274837153, 0.13592707977763244, 0.08616869550730501, 0.10369264946452209, 0.20491039673132555, 0.12882914207875729, 0.11200667119451932, 0.25250508210488726, 0.2282532091651644, 0.08634530460195881, 0.1600819222096886, 0.11343311465212277, 0.17451335782451288, 0.17294511411871227, 0.09502287860959768, 0.09839493302362305, 0.16393859311938286, 0.11838279691125665, 0.2426729468362672, 0.23330161826951162, 0.1468346251973084, 0.2789682735289846, 9.709860001291547, 71.26255212511334, 45.37755938938686, 59.85411030905587, 62.04659352983747, 39.31935903004238, 34.815710408346995, 1.2982714495488574, 3.0935597036566054, 6.309752072606768, 7.993532487324305, 7.250674520220075, 0.6574235143406051, 0.12251259173665728, 20.360695430210658, 74.10228088923863, 68.86407566070557, 71.87247889382499, 63.41005938393729, 70.70239530290876, 67.10447216033936, 66.65506962367466, 61.291095052446636, 64.4139073235648, 63.717058590480256, 67.55649416787284, 64.9305614743914, 63.977761949811665, 62.96648638589041, 62.58002063206264, 52.65351145608084, 48.03444978169033, 48.10420969554356, 47.39335339409964, 53.414544173649375, 62.96722984313965, 63.10049629211426, 65.0371537889753, 60.05560111999512, 58.66874762943813, 56.062071868351524, 51.01194395337786, 47.59565714427403, 45.632349831717356, 46.73034586225237, 47.078124046325684, 44.85666683741978, 43.899132115500315, 50.92383732114519, 59.81063543047224, 59.39458424704415, 61.12601975032261, 59.60628196171352, 59.96227291652134, 55.02375738961356, 55.032984597342356, 58.925518308367046, 58.91384533473423, 54.36087492534092, 55.861671924591064, 49.95718656267439, 53.23012856074742, 29.258874688829692, 50.631596088409424, 63.75516945975167, 53.591855253492085, 59.46111324855259, 56.58815125056675, 56.01627629143851, 57.6630653653826, 57.73862702505929, 56.86586380004883, 58.51456710270473, 57.931936332157676, 59.82107162475586, 57.32839148385184, 57.36860070909773, 49.917995248522075, 40.77811942781721, 42.13139227458409, 41.8162602015904, 40.45534781047276, 41.470389298030305, 41.44522639683315, 42.11994511740548, 50.76620353971209, 50.73170920780727, 53.32926893234253, 49.400090421949116, 51.20473561968122, 52.456707205091206, 55.99111686434065, 58.42506735665457, 57.63946580886841, 56.60350676945278, 56.16446399688721, 53.14675712585449, 48.38477100644793, 42.596886839185444, 41.66758612224034, 45.42331327710833, 53.14987339292254, 56.984396593911306, 56.10376453399658, 57.54742649623326, 55.78821209498814, 56.420981066567556, 60.58864607129778, 58.30233437674386, 58.68897383553641, 57.084117140088765, 61.19413294110979, 30.562412330082484, 0.23123811185359955, 0.2505229456084115, 4.265688453401838, 10.173590591975621, 7.191290872437613, 1.7200944146939685, 0.23430671862193517, 8.878325649670192, 51.099734442574636, 45.57604857853481, 34.34634222303118, 56.33373253686087, 30.83347545351301, 0.36583098822406357, 0.2114683969744614, 0.117617327986019, 0.1604763139039278, 0.1586765811911651, 0.06868437478052718, 0.12077797124428408, 0.1996451142643179, 0.21090110098677023, 0.16521524318626948, 0.15854406330202306, 0.13599971016602858, 0.2442964097218854, 0.12274214013346604, 0.1426943809326206, 0.1655558134828295, 0.0950474687186735, 0.10539403531168189, 0.14288476428815297, 0.14222988300025463, 0.14462998349751743, 0.1868266649544239], [0.09130980606589999, 0.009225827758200467, 0.033344523781644445, 0.05744438112846442, 0.07777481020561286, 0.07328149702932153, 0.018044875469058752, 0.009933259038786803, 0.030496512140546526, 0.025786522376750196, 0.06540855020284653, 0.06254104085798774, 0.048443922839526615, 0.04478574717151267, 0.02858940126108272, 0.057808795145579746, 0.07434102946094104, 0.07166202392961298, 0.06304772331246308, 0.021687980874308517, 0.026474309220377888, 0.0568492346709328, 0.03149456590680139, 0.06945156039936201, 0.14177225184227737, 0.038008084786789756, 0.07411095180681773, 0.08539629195417676, 0.5512023855532918, 16.98337585585458, 53.82601996830532, 27.014007261821202, 55.044980662209646, 36.879912512642996, 19.47602125576564, 1.0767017560345786, 3.1811699739524295, 0.4946706475956099, 2.324160920722144, 1.0666371818099702, 0.13219994120299816, 0.0743923606351018, 0.049454953588013134, 35.21884141649519, 70.4355080468314, 61.74654252188546, 70.35512433733258, 61.80333709716797, 65.43763405936105, 61.51566777910505, 61.993557929992676, 59.4110723223005, 63.6801358631679, 62.466111864362446, 62.6426933833531, 60.49494961329869, 59.771871430533274, 59.07766996111189, 50.45630693435669, 45.83613702229091, 46.55590786252703, 46.88935191290719, 55.569642611912315, 57.83386945724487, 58.91701371329171, 58.077466351645334, 57.556382724217, 54.48249619347708, 50.38747807911464, 47.632545130593435, 43.31767559051514, 41.699408871786936, 40.547175203050884, 40.86878299713135, 41.149934904915945, 40.031045641217915, 40.65793991088867, 44.24386004039219, 54.148597036089214, 55.23144251959664, 53.31594228744507, 51.6193276814052, 56.39738498415266, 59.28207206726074, 57.46247434616089, 54.86599159240723, 54.70940351486206, 54.56972735268729, 57.177758012499126, 58.350311688014436, 49.84163454600743, 57.63716942923409, 56.303903920309885, 56.85390247617449, 54.28827667236328, 53.3482722554888, 53.06433412006923, 54.5086144719805, 55.14612211499895, 57.38494982038225, 56.696758542742046, 54.97469615936279, 55.85490437916347, 54.37491723469326, 54.74845586504255, 42.868436336517334, 38.22128656932286, 39.361941065107075, 37.97427116121565, 38.953553744724815, 36.78516340255737, 39.8771048273359, 41.1308308328901, 46.991841316223145, 47.70138093403408, 48.78515747615269, 48.157415526253835, 49.24906437737601, 48.51072447640555, 52.29139566421509, 52.22358124596732, 54.87709828785488, 53.989521503448486, 54.414052963256836, 50.77235269546509, 47.62979711805071, 41.55718272072928, 39.739214352199006, 37.41642461504255, 48.0566041128976, 52.678528445107595, 56.485971042088096, 52.54983738490513, 54.80393028259277, 54.341121196746826, 56.77494314738682, 53.576291288648335, 57.291017123631065, 48.23021180289132, 51.051208223615376, 3.925941518374852, 0.34309808377708706, 1.445686167904309, 6.891717553138733, 3.349224099091121, 1.1109312964337212, 0.15167351625859737, 0.07691502491278307, 17.15249327250889, 42.82115731920515, 23.459428719111852, 33.811299664633616, 42.993139130728586, 2.1501606575080325, 0.2718757098274571, 0.021891833149961064, 0.09156608874244349, 0.06819435714610986, 0.03688349102490714, 0.03149345310937081, 0.0528046740218997, 0.032531699897455316, 0.07324385190648691, 0.06988790591380425, 0.0327542084934456, 0.040385929335440905, 0.03815891633608511, 0.02377262195971395, 0.02702329833326595, 0.04167326972154634, 0.05494015943259001, 0.04175111465156078, 0.01764663478492626, 0.0225952602257686, 0.06322291426892791, 0.050190315914473364, 0.039261976789150915, 0.007097527609273259, 0.014982434887705105, 0.04402510941560779, 0.061954006286604066, 0.053194356683109484, 0.04098074331081339, 0.03652999124356678, 0.03750289850203054, 0.05812413751014641, 0.010733089825537587, 0.05625019681506923, 0.03977307311392256, 0.04398645327559539, 0.008918137572306608, 0.06332589552870818, 0.09411786895777498, 0.054708388833595176, 0.059718050195702484, 0.0318916683484401, 0.04556660866364837, 0.01948719155708594, 0.06729350012860127, 0.031440859860075374, 0.12268769448356968, 0.02235801893818591, 0.11054924582796437, 0.03172203798645309, 0.8250744811126164, 28.88033856664385, 56.51098108291626, 35.03264011655535, 65.4143853868757, 37.04379619870867, 30.60747139794486, 0.802255565566676, 1.0313304534980228, 0.6685496973139899, 2.9259137851851325, 3.9953544565609524, 2.468513003417424, 0.44554625930530684, 0.15520503318735532, 42.84657382965088, 74.75333404541016, 63.214474541800364, 71.61935601915631, 61.82092298780169, 67.83101054600307, 62.04890727996826, 62.61928490230015, 61.22966602870396, 65.4108418055943, 64.92980412074498, 64.70430728367397, 61.41226468767439, 61.38669531685965, 60.185393469674246, 52.79825632912772, 45.612033299037385, 47.401177065713064, 47.69284507206508, 56.99625716890608, 59.451656750270296, 61.398500306265696, 60.55987358093262, 62.18679428100586, 55.96938289914812, 51.66011708123343, 48.90447541645595, 45.14346068246024, 44.28193964276995, 42.25075190407889, 43.87215920857021, 43.201119559151785, 42.128606046949116, 42.47822550364903, 49.08727557318551, 57.07226351329258, 58.306913239615305, 55.73689270019531, 54.60368667330061, 60.03304726736886, 58.40313189370291, 56.588727951049805, 54.05078724452427, 55.793739386967246, 55.438022886003765, 57.86346878324236, 57.58945614950997, 51.69518116542271, 60.85165623256138, 57.71045207977295, 59.38081986563546, 53.88380813598633, 54.56930698667254, 54.31286634717669, 56.313523701259065, 56.591986656188965, 58.384406498500276, 57.54903500420706, 57.842196873256135, 57.24784449168614, 56.35279144559588, 55.50234930855887, 46.510147026606965, 40.565261363983154, 41.042196137564524, 41.059132371629985, 42.03620195388794, 40.06165940420968, 43.032042094639365, 42.18593563352312, 48.674747126443044, 49.71360009057181, 50.42249352591378, 49.72473457881382, 51.02960280009678, 49.91287442616054, 54.44750506537301, 53.73039885929653, 56.12386219842093, 55.50513901029314, 55.7676489012582, 53.67505298342024, 48.91425848007202, 43.83759192058018, 41.333794661930625, 40.38403844833374, 50.67367090497698, 55.01647220339094, 57.25190918786185, 54.778093406132285, 56.497119426727295, 55.43480587005615, 58.443438393729075, 55.68516683578491, 61.217708178928916, 51.048814569200786, 52.86689758300781, 4.836771752153124, 0.5983781569770404, 2.6828579817499434, 6.037921173231942, 2.5118599917207445, 0.6620099768042564, 0.270562581717968, 0.216934417241386, 22.377757481166295, 49.17627157483782, 31.65893186841692, 31.678643907819474, 52.3718592779977, 3.2537413026605333, 0.35703342886907713, 0.050511934727962525, 0.04592422715255192, 0.021151682062606727, 0.012521620773311173, 0.030777018517255783, 0.03797384251707366, 0.061341533437371254, 0.06301962517734085, 0.07498134260198899, 0.032739297686410804, 0.031157761479594877, 0.04674554629517453, 0.013941211027226277, 0.026598920480215123, 0.02071102106544588, 0.052163682345833094, 0.03212055856628077, 0.04318477093641247, 0.014023992299501385, 0.06734948605298996, 0.029217215787087168, 0.16213378496468067, 0.17389085622770445, 0.09578129077064139, 0.08944464222128902, 0.2196122964045831, 0.14739310022975716, 0.10371241518961531, 0.09642953598605734, 0.1258607277912753, 0.28028834983706474, 0.1642832210553544, 0.16265461487429483, 0.1135854118370584, 0.08891942897545439, 0.13400934982512677, 0.16910252959600516, 0.1402891507106168, 0.20043609610625676, 0.11761755868792534, 0.09241457642721278, 0.08547966355191809, 0.10193868393876723, 0.09265884903392621, 0.13464694204074995, 0.2371670694223472, 0.13723796872156008, 0.10090570936777762, 0.2170188541391066, 0.6667235153062003, 36.60862357275826, 72.37419441768101, 37.76500184195382, 71.49375343322754, 48.945792879377095, 29.73008762087141, 1.6885258172239577, 7.147853340421404, 3.0049093748841966, 6.982996038028172, 4.231720881802695, 3.218586240495954, 0.313361612281629, 0.21083502524665423, 42.072360379355295, 79.20756707872663, 63.91196945735386, 72.42433956691197, 63.2814690726144, 70.58431066785539, 66.18172359466553, 65.71953637259347, 63.37005165645054, 68.90541744232178, 67.106584412711, 66.93862560817173, 63.17373725346157, 64.59365027291435, 64.28971522194999, 54.37962116513933, 49.448915413447786, 51.18992553438459, 52.563716411590576, 60.26483917236328, 63.100829805646626, 62.9640406199864, 60.922166551862446, 62.45873287745884, 61.11932168688093, 56.307478768484934, 51.77884095055716, 47.21189076559884, 46.18493659155709, 44.9005377633231, 46.05697856630598, 44.33749743870327, 45.13501862117222, 44.16120426995413, 49.68659244264875, 57.13368558883667, 58.269507612500874, 57.5991975239345, 57.2780795778547, 59.76390879494803, 58.96661690303257, 60.11162444523403, 57.10732759748186, 60.393082073756624, 60.21695218767439, 62.10417325156075, 61.975332805088584, 43.81958218983242, 60.69525923047747, 61.37161772591727, 61.41975484575544, 57.92812524523054, 57.410230840955464, 56.71882602146694, 58.48271656036377, 58.52592740740095, 58.48532213483538, 57.12492391041347, 56.7992444719587, 57.99191665649414, 57.04989031382969, 58.00108480453491, 46.36015278952462, 42.51358141217913, 43.58560160228184, 43.276504039764404, 43.409360545022146, 42.38213191713606, 46.10892677307129, 45.86504847662789, 51.35836376462664, 52.737174715314595, 53.87712744304112, 54.769519329071045, 54.51229006903512, 52.84229401179722, 56.49258920124599, 54.758020060403005, 57.451975618089946, 57.45242725099836, 60.16434737614223, 54.76660803386143, 51.820665631975444, 47.06406436647688, 44.29292821884155, 41.94693149839129, 53.279144627707346, 57.889868463788716, 61.68615572793143, 56.794481481824604, 57.78034053530012, 55.311958244868684, 60.061034611293245, 57.06858444213867, 62.54791995457241, 51.63297741753714, 54.81681571687971, 5.653833440371922, 0.4729881424989019, 3.6775759884289334, 14.872169188090734, 9.372719509260994, 2.748641788959503, 0.7477931422846658, 0.2790365070104599, 28.15090799331665, 55.66300555637905, 34.459702083042686, 44.6645039830889, 61.7443607875279, 4.744420204843793, 0.6678991722209113, 0.19667562789150647, 0.19494323299399444, 0.12901751697063446, 0.16062418025519165, 0.15059756327952656, 0.12264221906661987, 0.17060457542538643, 0.20803176638271126, 0.11831448200557913, 0.11315140726843051, 0.10547594127378293, 0.17417851436351026, 0.12945840188435145, 0.16078333742916584, 0.08319121599197388, 0.1441786898566144, 0.2243327966758183, 0.1444538358066763, 0.10527058943573918, 0.19058053780879292, 0.14082716112690313], [0.027704199742791907, 0.022417767339253, 0.05071623144405229, 0.07034711127302476, 0.02039406887654747, 0.04865720335926328, 0.04472602251917124, 0.03946122520470193, 0.0171934310679457, 0.05467597860842943, 0.05641017162374087, 0.03926069775064077, 0.03098117613366672, 0.05815308381404195, 0.03375823336786457, 0.04435705892475588, 0.019917136789964776, 0.03936359080086861, 0.03933704311826399, 0.04447575505556805, 0.040828683613134284, 0.03722600871697068, 0.05064740424443569, 0.03263754118233919, 0.016386108406420265, 0.08365991405610528, 0.016333199638341154, 0.09749648480543069, 0.06893172793622528, 2.2966477913515906, 49.922094685690745, 34.613781860896516, 36.87328045708792, 58.84113938467843, 23.058559349605016, 2.964268058538437, 0.6444579586386681, 0.10930709926677601, 1.4184191567557198, 3.3503240857805525, 0.708354189991951, 0.549508273601532, 0.35361374808209284, 0.9998660790068763, 42.6028344971793, 68.35633604867118, 58.72793933323452, 70.23763724735805, 61.125165121895925, 65.99817303248814, 60.60563441685268, 65.57230404445103, 61.57087121691023, 64.93588379451207, 64.08435426439557, 63.5164224079677, 60.67406027657645, 59.79089559827532, 51.8285414150783, 44.321322032383506, 44.68182931627546, 51.03568942206246, 54.91182885851179, 59.88712814876011, 61.08799225943429, 59.147659165518625, 56.823080267224995, 54.3798782484872, 50.9950007711138, 50.93484674181257, 49.095498766217915, 44.39367362431118, 42.50751216070992, 40.143807956150596, 40.03121934618269, 42.13904571533203, 42.93041426794869, 40.35427931376866, 42.596192019326345, 50.24945906230381, 52.992791993277415, 55.24278545379639, 55.40346949441092, 54.699571813855854, 54.967331068856375, 54.953775133405415, 52.55169950212751, 55.81664759772164, 52.687505517687114, 56.48165273666382, 53.302862303597585, 52.5884485244751, 60.310342924935476, 54.533058234623496, 56.00931767054966, 55.33406046458653, 56.103587354932515, 56.21809366771153, 57.82488543646676, 53.50980050223214, 54.74533264977591, 53.317189489092144, 54.83320999145508, 53.69609907695225, 48.01182297297886, 38.40846061706543, 39.53737265723092, 38.59197643824986, 37.72980226789202, 38.716571535382954, 39.387201241084504, 38.99135889325823, 40.87871544701712, 46.528455529894146, 49.133140632084434, 49.00561686924526, 50.06009633200509, 50.05394370215279, 48.67837061200823, 51.80747447695051, 53.64607899529593, 54.970280579158235, 53.83011245727539, 54.330469608306885, 52.619308948516846, 50.813399178641184, 46.81469004494803, 40.72093227931431, 41.02581575938633, 49.51651791163853, 54.914552552359446, 51.873068945748464, 56.41549893787929, 50.15936524527413, 56.49187701089041, 52.62430470330374, 59.55255849020821, 48.61543035507202, 57.581767967769075, 33.76849528721401, 0.0440875583860491, 0.10522989769067083, 1.5993034562894275, 10.405353835650853, 0.8277445978352002, 0.1270361675747803, 0.10707301593252591, 2.485691338777542, 40.98981714248657, 35.10226454053606, 19.909649644579204, 45.30116741997855, 14.96926852634975, 0.10749406048229762, 0.01747018514600183, 0.01968871136861188, 0.12657895710851463, 0.03993889010910477, 0.033981878510011096, 0.04753139841237238, 0.03801851047735129, 0.07676960807293653, 0.07481506081031901, 0.02335156044656677, 0.02091464094285454, 0.03524131414347461, 0.0215386098716408, 0.016481649529721056, 0.04175875834854586, 0.02542488356786115, 0.0894166390810694, 0.05553384703983154, 0.03977358201518655, 0.008536465865160738, 0.021332092649702514, 0.034283718027706654, 0.032566386607608626, 0.05329404026269913, 0.01844339774522398, 0.0618958015527044, 0.06528161665690796, 0.09172727473612342, 0.055443255829491785, 0.010858240520714648, 0.045453289922858985, 0.00909503165166825, 0.057048198101775985, 0.00719762551930866, 0.015803058531933596, 0.017551312489168983, 0.040751700422593524, 0.020391442946025302, 0.03195609185578568, 0.047175096281405, 0.03813064856720822, 0.013780485589190252, 0.04141737041728837, 0.0481112371198833, 0.019438053747372966, 0.07687018731875078, 0.013709505737226988, 0.08641067466565541, 0.01638627125482474, 0.13396704995206424, 0.0740598106224622, 4.82997293983187, 62.65842410496303, 32.413902282714844, 48.24574450084141, 54.443464687892366, 26.67243208203997, 4.458899617195129, 0.8533986498202596, 0.3045563447688307, 0.9112554852451596, 3.043587390865598, 2.5575828296797614, 2.7182180157729556, 1.204429947904178, 2.2912735768726895, 52.03680671964373, 67.61992427280971, 59.57549449375698, 70.73189735412598, 62.839515004839214, 69.24052211216518, 63.189697265625, 66.75216375078473, 63.296643938337056, 67.18600232260567, 63.09488909585135, 66.07420716966901, 62.455383845738, 62.29152447836739, 53.371677262442454, 46.957722187042236, 46.81919247763497, 52.498243536267964, 57.58045128413609, 61.83833517347063, 61.116333961486816, 60.26704869951521, 58.160823890141074, 55.95050464357649, 53.1118563243321, 54.09458174024309, 50.35235840933663, 46.71118967873709, 45.345086983272004, 44.132515157972065, 42.215847628457205, 44.72743034362793, 42.384143420628135, 41.67674732208252, 45.90017856870379, 54.258712087358745, 55.57210227421352, 57.74838924407959, 57.554214886256624, 58.05444002151489, 58.08717993327549, 59.229251861572266, 55.663849762507844, 59.1355345589774, 56.07733358655657, 57.93769986288888, 53.2173091343471, 52.944814682006836, 62.2961311340332, 57.00605412891933, 59.35605648585728, 57.654463495527, 55.94076326915196, 58.365618569510325, 58.11609486171177, 56.77590199879238, 56.64354228973389, 56.60578577859061, 56.44949994768415, 55.77016762324742, 51.1703177179609, 39.55955478123256, 39.58828558240618, 40.55063540594918, 39.51122311183384, 40.840809549604145, 41.50985854012625, 39.68805129187447, 43.12030853543963, 49.14662708554949, 51.12261138643537, 48.950430801936555, 51.96508046558925, 53.5157516343253, 50.97838415418352, 53.17069714409964, 55.15977185113089, 56.079560484204976, 54.20358507973807, 56.91827406202044, 54.753920623234336, 53.27987766265869, 48.129469871520996, 43.92370094571795, 43.53086369378226, 51.36682319641113, 58.73441505432129, 54.7697104045323, 56.40029975346157, 53.490220478602815, 56.11991562162127, 54.38476630619594, 58.90229048047747, 50.42625944955008, 57.27509185246059, 38.309737137385774, 0.07972541517977204, 0.3190004282764026, 3.1668801350252966, 2.6730154241834367, 0.6824030482343265, 0.42635937886578695, 0.4300635829567909, 4.3889599187033514, 45.509106159210205, 46.1955360685076, 23.47929883003235, 46.604611260550364, 23.016633919307164, 0.17879181967249938, 0.0187509590094643, 0.030170588022364036, 0.07470871401684624, 0.04893309909052082, 0.019357810196067606, 0.056973091060561795, 0.03395322058349848, 0.06435412713991744, 0.07171399292669126, 0.056505007070622275, 0.035940313778285465, 0.008056637282217187, 0.028576258037771498, 0.034497022296168973, 0.052778621669858694, 0.020006002825019614, 0.04721042759982603, 0.030430460149156194, 0.013504746769155775, 0.010183463737900769, 0.06930228269525937, 0.052923210696982484, 0.12552143314055034, 0.17617624359471457, 0.10109078657946416, 0.17323209371949944, 0.11925383231469563, 0.12212683100785528, 0.1278945550854717, 0.09939191131187336, 0.14618829345064505, 0.1784765858735357, 0.10522302413093192, 0.09661749697157315, 0.0853613813274673, 0.18438484812421457, 0.14215410420937197, 0.11520316824316978, 0.05925439364675965, 0.10965683657143797, 0.11294380269412484, 0.08560008316167764, 0.18037086565579685, 0.13402787383113587, 0.1729983655469758, 0.08138614320861441, 0.12632118165493011, 0.2911626063287258, 0.10674793659044163, 0.1719394845089742, 0.17124735164855207, 5.741990447044373, 72.13382843562535, 44.660050187792095, 49.713964870997835, 71.93745844704765, 36.761327607291086, 5.776476962225778, 1.551633928503309, 2.260165188993726, 5.945052853652409, 10.918548652103969, 4.3465589710644315, 2.7716765872069766, 1.0127894026892525, 2.0191360882350375, 50.78906658717564, 72.65481131417411, 62.318754468645366, 71.19503647940499, 64.92588533673967, 70.47797543661935, 65.76467881883893, 69.63836206708635, 67.5311610358102, 69.65906075068882, 67.23696041107178, 68.99382632119315, 65.03320721217564, 64.03158269609723, 56.42620958600725, 49.28693553379604, 48.32507903235299, 56.15914862496512, 59.81456116267613, 65.3538874217442, 65.73002120426723, 62.85534994942801, 61.89703355516706, 57.65683283124651, 55.42903886522566, 57.08692421231951, 55.31919131960188, 49.57501826967512, 47.70931230272566, 44.77927432741438, 43.85088382448469, 47.74988630839756, 45.36088718686785, 44.17843927655901, 47.05663674218314, 54.78897081102644, 57.071082319532124, 58.89139570508684, 62.370657512119834, 59.20932442801339, 59.27820886884417, 60.13289982931954, 55.028961590358186, 61.558572905404226, 56.12623153414045, 60.43479905809675, 55.94598831449236, 56.0680125781468, 61.96397944859096, 58.39464814322335, 61.03100313459124, 59.16628728594099, 60.42677388872419, 60.70206151689802, 60.651325770786826, 57.020926748003276, 58.675035749162944, 57.86303104673113, 59.52699606759207, 58.567991801670615, 52.247326714651926, 42.05335358210972, 41.75794744491577, 43.64351831163679, 42.00920820236206, 42.190028122493196, 44.42028522491455, 42.6403408731733, 44.76404735020229, 51.578194345746724, 54.246604851314, 52.35434634344918, 54.669781412397114, 55.068090370723176, 52.83867400033133, 56.90701103210449, 57.70967040743147, 59.2638886315482, 55.34739405768258, 60.65709277561733, 57.74547447477068, 56.67695965085711, 49.894131660461426, 45.45110259737287, 45.316269329616, 53.151613916669575, 59.887010029384065, 57.23253413609096, 59.46551145826067, 53.58444152559553, 61.21711758204869, 55.80701739447457, 59.655864306858604, 52.3433403968811, 60.74999713897705, 37.478093351636616, 0.21216840084109986, 0.30214708404881613, 7.684295092310224, 24.103752544948033, 5.241238985742841, 1.7853853340659822, 0.8809828896607671, 5.024598496300833, 56.152919564928325, 46.48275375366211, 34.39890534537179, 57.55178301674979, 29.522211415427073, 0.1757364579077278, 0.13765791404460156, 0.13543279415794782, 0.296196060521262, 0.13825881108641624, 0.12931468816740171, 0.16277615406683513, 0.1541671460228307, 0.12144175491162709, 0.20861131671283925, 0.14428454131952353, 0.11579577358705656, 0.11155850560005222, 0.19164126446204527, 0.16477059918854917, 0.14481211586722306, 0.09672741285924401, 0.15876597139452184, 0.14953564240464143, 0.11624151681150709, 0.04565349846546139, 0.1623623427003622, 0.1466040997100728], [0.032720329239964485, 0.026142782099278908, 0.10663869245243923, 0.007436702244116792, 0.03518184054909008, 0.046794567057596784, 0.0196247170346656, 0.04003125908119338, 0.019399455282837152, 0.01891380062858973, 0.012029905953178448, 0.007957557598794145, 0.03953105663614614, 0.01746032603218087, 0.037920716617788584, 0.02282504950250898, 0.06426726787218026, 0.06855871688042368, 0.051883332032178126, 0.03848217041896922, 0.021793956169858575, 0.04361401218920946, 0.06470359303057194, 0.04099024958642466, 0.008598449190945497, 0.047199533720101626, 0.04065204059172954, 0.019813894294202328, 0.04228614629911525, 0.06700388102659158, 13.733774593898229, 57.62009423119681, 25.58047751017979, 56.43740313393729, 55.82724012647356, 12.721673062869481, 0.07515452509479863, 0.47820889949798584, 0.6495058249150003, 3.0370141778673445, 2.5454664741243636, 2.28270405956677, 0.7507411326680864, 0.024163261355300034, 0.39725532914911, 49.25278513772147, 70.30390221732003, 58.68159484863281, 64.88361944471086, 64.95722171238491, 66.95837238856724, 61.632487842014854, 63.99295766013009, 63.521876743861604, 63.636056491306846, 62.248070444379536, 59.79890687125069, 60.69971302577427, 52.24097606113979, 45.45858580725533, 48.04175928660801, 52.63960811070034, 60.294556617736816, 60.37960951668875, 61.872895513262065, 59.675624983651296, 58.56756101335798, 56.47004924501692, 51.385322775159565, 48.4217597416469, 48.7803840637207, 46.501788343702046, 43.490404333387104, 42.65245853151594, 40.79385362352644, 41.86692993981497, 41.927608558109824, 42.627226148332866, 40.08381373541695, 39.16380623408726, 42.365494455610005, 42.50520535877773, 44.7953976222447, 45.58218036379133, 46.833526611328125, 46.613967009953086, 51.687965461185996, 54.94483627591814, 58.742190088544575, 53.98691245487758, 48.56470503125872, 54.84097807747977, 53.38439246586391, 58.08866337367466, 52.76492929458618, 55.78452607563564, 54.380420207977295, 54.44340215410505, 55.038119316101074, 56.27279683521816, 57.40774685995919, 56.83502074650356, 54.94569090434483, 49.80941227504185, 41.54874413354056, 39.41835696356637, 41.39685303824288, 38.98959405081612, 38.93363673346383, 38.597531523023335, 39.14401429040091, 39.478948729378835, 40.567311082567485, 45.67725951331002, 48.12099306924002, 50.62245225906372, 49.887183461870464, 52.18080118724278, 51.61071538925171, 51.53694289071219, 51.88193484715053, 55.69459554127285, 55.05178642272949, 55.757011209215435, 53.753428663526265, 52.091110365731375, 48.37242405755179, 45.506636074611116, 42.26182038443429, 48.33632121767317, 54.30616133553641, 57.908517428806846, 55.69943496159145, 57.002284731183735, 55.99259335654122, 55.37326567513602, 53.37075662612915, 51.8686637878418, 51.97962304524013, 4.959009672914233, 0.022259393873225366, 0.7702373436519078, 1.0899348173822676, 1.271888705236571, 0.44130978520427433, 0.24956249286021503, 0.028001433704048395, 14.257027796336583, 52.87322391782488, 18.573187964303152, 28.34055733680725, 43.03313991001674, 1.9530155105250222, 0.20057005248963833, 0.03173601580783725, 0.03415342912610088, 0.06152572176818337, 0.022342219250276685, 0.02916214588497366, 0.04037115423540984, 0.030994417744555643, 0.016602147171007733, 0.11201462362493787, 0.022992247316454138, 0.055573463306895325, 0.011965214424500508, 0.07012257046465363, 0.05564900800319655, 0.023466621326016526, 0.037520618444042544, 0.038438672931598764, 0.060115142459315915, 0.05521225197506802, 0.02306463852125619, 0.04167435198490109, 0.06689226201602391, 0.022926493880472014, 0.04437551846993821, 0.045231195233230076, 0.04810133729396122, 0.0349533540595855, 0.008045673852653375, 0.04398943204432726, 0.05499114794656634, 0.03580520388537219, 0.025684309557878544, 0.0388612136510866, 0.013461247585447771, 0.016628011229581068, 0.018436603913349763, 0.03453559361930404, 0.05054209560954145, 0.03987387288361788, 0.05158600137968149, 0.057074294558593204, 0.012116938247345388, 0.044783938875687976, 0.017918842678357447, 0.05938475379454238, 0.03697865895394768, 0.017379520993147577, 0.06106811775160687, 0.03481387100847704, 0.01593988172576896, 0.06745320691594056, 0.12875006560768398, 23.823415313448223, 60.07947513035366, 27.811154978615896, 75.32726914542062, 51.73743316105434, 17.1114467893328, 0.11220528517982789, 0.3523594353880201, 0.6669442291770662, 1.8802313932350703, 2.4505801371165683, 5.962817660399845, 5.167494714260101, 0.14062256924808025, 0.9378094375133514, 56.469566345214844, 70.58519308907645, 60.123248781476704, 67.96647262573242, 64.32441452571324, 67.3185670035226, 62.59479250226702, 67.06932817186627, 64.08282566070557, 65.7447930744716, 64.79239654541016, 64.81671524047852, 63.39880330221993, 53.131728172302246, 47.10814026423863, 49.20386634554182, 56.438799721854075, 61.968148367745535, 62.29196221487862, 62.91525731767927, 63.87576239449637, 60.343263489859446, 57.92826073510306, 54.447348730904714, 50.81626878465925, 50.883398805345806, 48.9731444631304, 45.39288364137922, 43.94399315970284, 43.91503306797573, 43.86068425859724, 43.90639993122646, 44.897497926439556, 42.917025089263916, 42.514769554138184, 47.12480204445975, 46.20064646857125, 49.07370226723807, 48.1417612348284, 46.98920447485787, 48.67887435640608, 53.295889786311555, 56.88510683604649, 59.23246192932129, 57.00329221997942, 50.574426310403005, 55.59614304133824, 54.92481504167829, 59.95192704881941, 56.52709742954799, 58.62564100537981, 54.17610842841012, 54.41539396558489, 57.60093457358224, 58.900067056928364, 59.23396968841553, 56.423166275024414, 55.71367876870291, 51.190981660570415, 44.372797761644634, 40.035992758614675, 42.81705093383789, 41.84547390256609, 40.707626479012625, 42.56771830150059, 41.666564737047466, 40.56918362208775, 42.42579787118094, 46.5585481779916, 50.15217733383179, 53.28412996019636, 52.589970179966514, 52.789644036974224, 52.914079325539724, 54.09876108169556, 54.25271579197475, 56.98413603646414, 55.9258211680821, 57.21879754747663, 56.49940538406372, 54.572659492492676, 49.47021859032767, 46.43995632444109, 44.95565782274519, 50.389739717756, 56.21910115650722, 58.70914445604597, 57.95973607472011, 58.51537309374128, 56.92159530094692, 56.20749419076102, 55.5772647857666, 52.95643554415022, 55.364868777138845, 5.83599088873182, 0.05072922199698431, 1.402727518762861, 2.283746723617826, 0.6613098372306142, 0.14406457383717808, 0.11930112620549542, 0.17957928670304163, 17.886054549898418, 60.66192872183663, 26.973431519099645, 25.98946758678981, 56.08136701583862, 3.7544043915612355, 0.3878455955002989, 0.07922178613288061, 0.042042094216282876, 0.022233065018164258, 0.043432069809309075, 0.03425290575250983, 0.06179780073996101, 0.05876213684678078, 0.03920741239562631, 0.09195652457752398, 0.03961716951536281, 0.04030246274279697, 0.055509928680424175, 0.01568467283089246, 0.05911496148577758, 0.009506173831011568, 0.062748848992799, 0.05265087388189776, 0.017805953110967363, 0.021697765349277427, 0.05536714794912508, 0.014388530149257608, 0.0185277294700167, 0.08108996945832457, 0.08033510603542839, 0.20845137243824347, 0.09893415801759277, 0.1220474016985723, 0.15706823606576237, 0.18312395364046097, 0.184986464413149, 0.10339339516524758, 0.15032829344272614, 0.12245229711490017, 0.10918180777558259, 0.17463202002857411, 0.11704769783786365, 0.10867096590144293, 0.1407422356839691, 0.1307776096676077, 0.12532468512654305, 0.14417806560439722, 0.16309635474213532, 0.14381437083440168, 0.1183083209076098, 0.15508631670049258, 0.20682584680616856, 0.14783664500074728, 0.1981323611523424, 0.08973744365253619, 0.14834842325321265, 0.13151649359081471, 0.21016271917947701, 27.80936234337943, 78.43190492902482, 34.7768109185355, 68.57178579057965, 69.34867082323346, 22.653587068830216, 0.21516086240964277, 1.1511644061122621, 2.1339924165180753, 6.780068687030247, 8.863251532827105, 5.993208646774292, 1.883252991097314, 0.1165697377707277, 0.9069161723767007, 54.685894284929546, 74.71153368268693, 62.67422430855887, 69.3501785823277, 67.0560223715646, 69.16307749067033, 64.91720703669957, 69.76439544132778, 68.20049490247453, 69.52220208304269, 66.04315567016602, 66.31920065198625, 67.59649494716099, 56.71816941670009, 50.22807945523943, 53.66842440196446, 59.24139731270926, 66.64203480311802, 65.80604144505092, 65.31142698015485, 64.43024948665074, 63.35537011282784, 61.757569313049316, 56.517373425619944, 52.215142658778596, 53.51425082342965, 52.41064412253243, 47.75849165235247, 47.42299093518938, 45.94007512501308, 46.55112402779715, 47.64322451182774, 48.02002879551479, 45.31195102419172, 43.39628056117466, 48.37607881001064, 48.23517976488386, 48.59990113122122, 49.3599784714835, 49.129412923540386, 51.80802685873849, 55.24291399547032, 59.75138814108712, 60.82362025124686, 58.37936905452183, 50.13282312665667, 58.12295273372105, 57.403369494846885, 62.80963775089809, 57.429532936641145, 61.620849609375, 56.88009718486241, 56.26305546079363, 59.99510315486363, 60.11989974975586, 61.10631465911865, 59.18001692635672, 59.20787920270647, 52.513001510075156, 45.89664193562099, 42.80196986879621, 44.88313947405134, 43.55147899900164, 42.42939008985247, 44.56651701245989, 43.78166239602225, 43.55609260286604, 44.80506256648472, 49.209417956215994, 51.512283733912874, 56.096906661987305, 55.91679893221174, 56.157112802777974, 55.84349891117641, 55.268938473292756, 55.6903258732387, 60.61365263802664, 57.366978304726736, 59.533645493643625, 57.35266848972866, 57.08264759608677, 51.8724227632795, 50.48502036503383, 47.04087127958025, 52.27811418260847, 59.18763215201241, 60.73601736341204, 59.27516555786133, 61.40808187212263, 58.33014106750488, 56.900590896606445, 58.03559650693621, 55.7216066632952, 56.21766635349819, 7.140505186149052, 0.15467386240405695, 1.9029014110565186, 6.386103655610766, 8.012042488370623, 2.1238219908305576, 0.4299464678125722, 0.25947960785457064, 24.327885798045568, 64.66888536725725, 30.467319284166607, 40.94290637969971, 63.1305125100272, 6.588460385799408, 0.7245545121175903, 0.23779034454907688, 0.15995990804263524, 0.13650657582495893, 0.10438155249825545, 0.196389109694532, 0.17116899442459854, 0.12708681342857225, 0.13090786124978745, 0.278680113277265, 0.0693706925958395, 0.14579485170543194, 0.14339694966162952, 0.13804429902562074, 0.18149964937141963, 0.16669003904930182, 0.12252213193901948, 0.1325465233198234, 0.1528159656694957, 0.12209004083914415, 0.12095054984092712, 0.14340281220419065, 0.14728230903191225], [0.038980259227433374, 0.028921883420220444, 0.06309466436505318, 0.06473218649625778, 0.03976699683283057, 0.04675235539408667, 0.017839101242965887, 0.0242386584702347, 0.025706825046134845, 0.028536774085036347, 0.08873378857970238, 0.014820865521739637, 0.03896119917875954, 0.006903241405130497, 0.007254572418917502, 0.027158258948475122, 0.03311390669218131, 0.01495232489625258, 0.04030507170994367, 0.02014368266931602, 0.11349286644586495, 0.0535430626145431, 0.053868586397064586, 0.06456256631229605, 0.023120622749307325, 0.012310889000738305, 0.0910941269248724, 0.02223851195802646, 0.030161322626684393, 0.09497239560421024, 1.161184468439647, 44.84678649902344, 35.13248920440674, 14.472674693380084, 50.17772586005074, 36.48370885848999, 1.1106445746762412, 0.13565531293196337, 0.13536210437970503, 0.20270903914102487, 1.1134491498981203, 3.669216436999185, 11.244093469211034, 0.4356733576527664, 0.0761165791856391, 3.6940314940043857, 69.7493039539882, 64.73388576507568, 64.26940563746861, 65.59366975511823, 63.68089321681431, 67.24105290004185, 66.20616040910993, 62.23259680611746, 65.65582139151437, 62.39594200679234, 63.28347710200718, 60.4622027533395, 54.72965056555611, 46.68718365260533, 49.31021894727434, 57.045426096235005, 60.67812497275216, 61.857991627284456, 62.47211510794503, 59.82324641091483, 57.51655217579433, 54.246563162122456, 51.47500664847237, 50.4310884475708, 48.65832158497402, 47.772759778159006, 44.58277232306344, 42.93022666658674, 42.33615916115897, 42.27669300351824, 42.79727636064802, 41.57434824534825, 43.86166742869786, 43.65848820550101, 44.143013886043, 43.876234327043804, 46.34044769832066, 46.75899675914219, 49.93608488355364, 52.81607845851353, 54.83692727770124, 56.756502628326416, 57.22133363996233, 50.912973812648225, 46.97069099971226, 53.042485509599956, 52.74833352225167, 55.03178950718471, 54.08574710573469, 58.169342381613596, 55.692167145865305, 60.45429570334298, 55.67574160439627, 55.42011737823486, 53.82578372955322, 52.15960570744106, 47.27666882106236, 42.44645139149257, 38.367518356868196, 39.8388272012983, 38.94737679617745, 38.606140341077534, 39.590856415884836, 40.64311940329415, 37.873008114951, 39.31016656330654, 40.456278869083945, 44.740777833121165, 48.70969656535557, 53.675264903477256, 53.584590911865234, 51.72985962459019, 51.29980434690203, 54.12298945018223, 55.64159120832171, 58.189287185668945, 52.99856942040579, 53.553456033979145, 54.45717348371233, 55.61381231035505, 50.43574374062674, 46.589776856558665, 45.302751609257285, 48.81181076594761, 51.4989675113133, 55.174696581704275, 56.249485628945486, 59.283385276794434, 57.05113751547677, 60.932547160557334, 51.05868101119995, 55.47605732509068, 7.311775241579328, 0.3394884946090834, 0.37254984197872026, 0.6563025202069963, 2.113336507763181, 0.019593750392752032, 0.1618934885731765, 0.1169608182140759, 1.3496408930846622, 42.68631362915039, 40.10764953068325, 21.736315420695714, 47.0789543560573, 17.68397487912859, 0.07337477523833513, 0.015378256594496114, 0.04281599393912724, 0.029368729264076267, 0.06356765077050243, 0.0086745061811858, 0.03739870944991708, 0.02712690214892583, 0.045037232605474334, 0.01584603694001479, 0.03816987467663629, 0.020930915605276823, 0.05305228841357997, 0.04056137474253774, 0.04462216255654182, 0.030520997076694454, 0.019076406456796185, 0.05090096938822951, 0.009939519372502608, 0.05183508140700204, 0.014008842308872511, 0.05852068016039474, 0.06486977982733931, 0.03265609572242413, 0.03234974055417946, 0.039015264849045446, 0.0487763269671372, 0.018156168782817464, 0.05420368770137429, 0.035814075730741024, 0.01606337001015033, 0.020694215449371507, 0.013753353518300822, 0.05458780976810625, 0.04545365972444415, 0.027193369743015085, 0.014692993901137794, 0.024028068341846977, 0.01368553055051182, 0.037855146386261494, 0.05925535038113594, 0.075091482406216, 0.01880673798067229, 0.09372756882969822, 0.10013283084013633, 0.03130736488050648, 0.0159504787464227, 0.08956991335643189, 0.010431268119386264, 0.011910891759076288, 0.04861874399440629, 0.007600865310191044, 0.04796840210578271, 0.12221893535128661, 2.1364609811987196, 63.049163000924246, 32.65392780303955, 29.47594336100987, 66.86716338566372, 34.199676173073904, 2.2007565711225783, 0.2620465601129191, 0.081391476493861, 1.2328675133841378, 1.099789859993117, 5.167023973805564, 9.005670496395656, 1.4545457725014006, 0.2747849422906126, 4.819807291030884, 73.95729282924107, 65.5778556551252, 66.81334958757672, 64.37702628544399, 66.81806741441999, 67.62439891270229, 67.7325337273734, 65.381562096732, 69.00382477896554, 63.243914059230256, 66.00022275107247, 61.696459906441824, 56.80974667412894, 46.26421553747994, 52.17630917685372, 58.04547684533255, 63.62269510541643, 62.9672645841326, 63.61783136640276, 59.889018058776855, 60.452725410461426, 57.65738868713379, 55.75916167667934, 53.34377677100045, 51.97837584359305, 48.93795183726719, 46.34179217474801, 44.36447729383196, 44.8290581703186, 43.91201754978725, 43.778153555733816, 43.51135662623814, 45.31873594011579, 43.63325234821865, 43.60739810126168, 44.45846905027117, 46.32069049562727, 46.27579123633248, 51.934296471732004, 53.228214332035606, 56.36166776929583, 56.9047771862575, 60.447854723249165, 53.8353305544172, 47.64460372924805, 55.58911146436419, 55.429500920431956, 56.71740511485508, 58.02036952972412, 58.91788223811558, 56.26723827634539, 61.05722563607352, 57.71974529538836, 57.514676162174766, 55.18783909933907, 55.86416285378592, 51.31411068780081, 44.50950009482247, 40.75138970783779, 41.20672600609915, 41.68704455239432, 40.70813717160906, 41.97655861718314, 40.97636890411377, 39.66330180849348, 40.41378368650164, 42.59006370816912, 47.103026390075684, 50.178156648363384, 55.05659805025373, 54.30230508531843, 53.152624879564556, 52.44048316138131, 54.94268233435494, 56.877738271440776, 59.59479658944266, 54.61391789572579, 55.091759409223286, 57.069710050310405, 57.049198968069895, 53.27834905896868, 48.96413959775652, 46.83310277121407, 50.08664539882115, 54.44107798167637, 57.63857643944876, 57.67335564749581, 59.712985447474885, 58.23879657472883, 61.84018339429583, 52.072965145111084, 60.317270278930664, 9.641883168901716, 0.5464336957250322, 0.8005000054836273, 1.7801980695554187, 2.627063512802124, 0.2631676085293293, 0.34508222873721806, 0.18796374036797456, 2.7804877715451375, 46.44375351497105, 50.653823375701904, 20.226991244724818, 48.27876928874424, 24.65909947667803, 0.04079310462943145, 0.009054908179678023, 0.018337676900305917, 0.06296806330127375, 0.07915224986416952, 0.04440348429073181, 0.0030805720972628997, 0.029676533104585748, 0.01480246365203389, 0.0369489289421056, 0.049735029094985554, 0.06158689170011452, 0.019818871348564113, 0.024934411314981322, 0.04849281128762024, 0.01244451544646706, 0.05765417737088033, 0.03099618193560413, 0.03933017973655036, 0.007442260294088295, 0.02002489663261388, 0.0030830046453047544, 0.05519240821844765, 0.040909944966967614, 0.1158622700188841, 0.11936465065394129, 0.12724062374659947, 0.21331938622253283, 0.17737951688468456, 0.16793459440980638, 0.14575738300170216, 0.15176844330770628, 0.13174293429723807, 0.16735842318407126, 0.1689565224306924, 0.20254883702312196, 0.07581682955580098, 0.11954146330910069, 0.07684495260140725, 0.11883805319666862, 0.1606707006160702, 0.1430884740714516, 0.09553149488887616, 0.13944711589387485, 0.23126973158546857, 0.14196593287800038, 0.13463862320142134, 0.12271286813276154, 0.12550228488232407, 0.1092818034812808, 0.23134407188211167, 0.09431674757174083, 0.09939993159579379, 0.2900418293263231, 3.610673086983817, 73.5468418938773, 46.72639928545271, 28.3772577217647, 61.97833442687988, 52.569382667541504, 2.7788210724081313, 0.29458225997430937, 0.38521985496793476, 3.5405175600733076, 6.108692484242575, 10.247912866728646, 19.29102373123169, 1.100318357348442, 0.20800170728138515, 5.205428838729858, 74.26056780133928, 70.60347379956926, 69.28360094342912, 67.06968252999442, 65.96855981009347, 73.36762700762067, 69.37299646650041, 65.88787732805524, 70.8173463003976, 67.51946026938302, 67.58644785199846, 63.82620784214565, 59.321753229413716, 50.287851333618164, 54.68276759556362, 61.387848717825754, 65.5095270701817, 65.7720786503383, 65.08661801474435, 63.78130163465227, 63.229635511125835, 59.48745386941092, 57.84297854559762, 55.25783525194441, 53.87848581586565, 51.56912694658552, 50.238397530147004, 46.990100792476106, 47.581052030835835, 45.415489605494905, 46.53710951123919, 46.082794598170686, 48.1266975402832, 49.37556675502232, 48.487586975097656, 48.264758246285574, 51.803371565682546, 51.457868916647776, 55.541335650852744, 56.473297527858186, 58.47912434169224, 59.469562258039204, 61.62246853964669, 53.158061844961985, 50.1014381136213, 56.42349631445748, 57.722590582711355, 58.788298334394185, 59.33906119210379, 60.14497579847063, 57.85732657568795, 64.65114661625454, 59.66928127833775, 60.72184303828648, 58.12455081939697, 58.000004359654014, 51.61810827255249, 45.19808394568307, 42.477117265973774, 43.68612813949585, 44.282287052699495, 42.18136371885027, 43.28675958088466, 44.54569673538208, 40.86979743412563, 42.791200160980225, 45.485826219831196, 51.71599102020264, 54.18240697043282, 58.451936040605815, 57.184831278664724, 54.242863246372764, 55.50550726481846, 58.50965472630092, 60.03934233529227, 61.779622895377024, 55.84382895060948, 55.86534752164568, 59.212228775024414, 59.67429787772042, 54.016299860818044, 51.99396760123116, 51.150379862104145, 51.990969453539165, 57.41296148300171, 60.2934171131679, 58.7836708341326, 62.31682981763567, 60.11851705823626, 64.4051456451416, 55.453569480351035, 61.15847478594099, 9.275509868349348, 0.36928573570081163, 1.0789138887609755, 4.107926998819623, 8.631028839520045, 2.2773530781269073, 0.7705475155796323, 0.35950259066053797, 3.013403113399233, 58.7826702935355, 52.34087378638131, 34.93242277417864, 61.49007061549595, 32.18661281040737, 0.1717894739870514, 0.14451049348073347, 0.11386086312787873, 0.20652440083878382, 0.25965798114027294, 0.10997971746006183, 0.13543938951832907, 0.17369471889521393, 0.1564794983714819, 0.11430405506065913, 0.11855453412447657, 0.12212308549455234, 0.1320863137287753, 0.09473344271204301, 0.21476580575108528, 0.1455139789198126, 0.10576090562556471, 0.07087134064308234, 0.0918890442699194, 0.1145831500845296, 0.09354243733521019, 0.17050977051258087, 0.12909431356404508, 0.22428524494171143], [0.0180546904781035, 0.01893363251084728, 0.06798298670245068, 0.026059498711090003, 0.06681986232953412, 0.01415354329427438, 0.06513873753803116, 0.054191908333450556, 0.04005964559369853, 0.020435208454728127, 0.04157386773398944, 0.025844146963208914, 0.07232630971286978, 0.035135628921645026, 0.01439705933444202, 0.0411432456624295, 0.0037049967047226217, 0.0517311332348202, 0.01416030659207276, 0.03973882745153137, 0.05830977112054825, 0.0380892409676952, 0.026992613283385123, 0.06036476870732648, 0.008792666269333234, 0.05668333625154836, 0.0134150334134964, 0.02496695894348834, 0.014602972660213709, 0.06468797315444265, 0.06856400266821895, 10.769042525972639, 49.18084348951067, 29.436321258544922, 27.423954452787125, 64.68228149414062, 13.318859440939766, 0.024352652353367636, 0.258448343191828, 0.44967253931931084, 1.1782709572996413, 6.936859565121787, 16.061838013785227, 2.718021729162761, 0.057045246474444866, 0.03483873253156032, 17.420822279793875, 72.65664563860211, 63.57503046308245, 64.82726955413818, 68.22195093972343, 61.738760539463584, 67.41957991463798, 65.43131814684186, 64.29774039132255, 61.58657414572579, 63.49885041373116, 62.89270346505301, 54.90151078360421, 48.03249733788626, 54.3851067679269, 61.178596769060405, 61.419636726379395, 60.50192560468401, 59.8949031829834, 60.993983132498606, 59.58696596963065, 55.5335293497358, 50.839552198137554, 49.79388305119106, 49.50834683009556, 47.65260457992554, 45.63468442644392, 41.9407719203404, 44.19505589348929, 41.04593079430716, 42.82812636239188, 42.562173639025005, 42.04390055792672, 42.19283519472395, 45.006685393197195, 44.987279074532644, 52.12065410614014, 51.9691173689706, 54.37842607498169, 55.130943775177, 57.461355686187744, 56.74545499256679, 61.31491347721645, 54.115832805633545, 48.424514702388215, 58.602281161717, 58.21788944516863, 58.85156863076346, 60.68464238303048, 58.47770690917969, 58.15483454295567, 58.86625712258475, 56.763857296534944, 55.28301899773734, 50.38387196404593, 48.13212060928345, 43.58481298174177, 41.678064005715505, 41.8813613482884, 40.6483097076416, 41.526652336120605, 39.41353491374424, 39.355423654828755, 39.72959457124983, 40.438828468322754, 40.48359571184431, 39.298799310411724, 44.85794530596052, 51.287617206573486, 52.61352457318987, 54.22078881944929, 55.33468927655901, 55.85229185649327, 52.431509562901084, 54.61015544618879, 55.8445063999721, 56.43102816173008, 52.90186786651611, 56.36950881140572, 53.69319820404053, 54.5622615133013, 49.53339161191668, 46.58935301644461, 45.23811946596418, 49.484142780303955, 50.566057205200195, 54.56216076442173, 52.37553834915161, 60.8698605128697, 52.902923992701936, 61.47176906040737, 14.160062210900442, 0.48967641272715157, 0.32084069667117937, 0.19835288503340312, 1.0082814331565584, 0.9062784580247742, 0.04467249967690025, 0.03455515578389168, 0.06120007924203362, 17.536780766078405, 52.852639879499165, 18.216135672160558, 34.1669397354126, 37.69088888168335, 1.39235939511231, 0.22144488378294877, 0.02378672531007656, 0.07898360677063465, 0.06998691095837525, 0.01360867458528706, 0.06435907366020338, 0.03316099023712533, 0.034633418012942584, 0.01241795504133084, 0.07325131579169206, 0.04460055800154805, 0.03262803151405283, 0.0665175953347768, 0.03638615878298879, 0.009507520723023584, 0.01661880181304046, 0.08896802565348999, 0.010927130484820476, 0.011726280192046292, 0.014356357411348393, 0.07096641018454518, 0.024694160724590932, 0.02083160521994744, 0.026387889304065278, 0.03505803844226258, 0.03628160671464034, 0.05406810622662306, 0.046456934817667515, 0.0684636269829103, 0.038548320797937255, 0.03947209194302559, 0.023281689999358993, 0.016232783240931373, 0.021874567826411555, 0.12783996015787125, 0.04484077636152506, 0.02062961721925863, 0.015032861913953508, 0.01575462470230247, 0.015134628596050399, 0.015896352007985115, 0.024286462958636026, 0.014370333536395004, 0.02852487258080925, 0.03804011503234506, 0.004698962721574519, 0.03930237676416125, 0.020991846353613904, 0.047707088092075925, 0.040589113254100084, 0.03420209365763834, 0.0032801960395382984, 0.0361795177284096, 0.03080684013132538, 0.18117786092417582, 20.69163986614772, 59.32808303833008, 19.351092645100184, 46.45206356048584, 75.2142914363316, 14.102445142609731, 0.03955777734518051, 0.1374401721571173, 0.3582891529159886, 1.8780131808349063, 3.3587735295295715, 12.718008756637573, 6.777347598757062, 1.5766685051577431, 0.1041185658957277, 21.967351709093364, 73.87112127031598, 64.83514881134033, 68.23911993844169, 66.69691167558942, 64.46107864379883, 70.18360805511475, 66.45220306941441, 64.7893601826259, 66.2044928414481, 65.8831456048148, 65.00174576895577, 56.92631312779018, 50.97834941319057, 54.107522760118755, 62.52805505480085, 61.504231044224326, 63.67921870095389, 63.032355308532715, 63.95024708339146, 61.33582755497524, 56.835583550589426, 52.02235794067383, 52.318174021584646, 52.20775324957711, 50.16102933883667, 47.11068677902222, 43.7317465373448, 44.99581841060093, 43.124724115644185, 44.27685703550066, 46.130678108760286, 44.875135149274556, 45.434774330684114, 47.36665494101388, 49.88172565187727, 53.64396326882498, 52.163941383361816, 57.196003981998985, 55.97594199861799, 59.77888216291155, 58.695248058864046, 63.13223566327776, 55.30413109915597, 49.602272578648154, 56.45010791506086, 57.945665972573416, 59.541851316179546, 60.19565595899309, 60.82346044267927, 57.868516649518696, 58.86249814714704, 57.86776624407087, 57.81772184371948, 54.638997418539866, 49.16658926010132, 45.19205985750471, 42.42468268530709, 43.5249924659729, 42.76095812661307, 43.01667267935616, 42.690538133893696, 41.290799209049766, 42.12036548342024, 42.3678742136274, 43.90092127663748, 40.039046491895405, 45.72044256755284, 52.58304630007063, 55.55564546585083, 55.115407603127615, 56.61183418546404, 57.195062501089915, 54.61420277186802, 56.46078034809658, 58.38981219700405, 57.191220147269114, 53.95696919304984, 57.77479239872524, 56.58743211201259, 56.19565793446132, 52.57501418249947, 49.06297772271292, 47.415174211774556, 51.20758785520281, 53.96054056712559, 56.93366084780012, 55.260593686785015, 63.23086534227644, 54.486682483128135, 63.13659218379429, 19.91175147465297, 0.6969267917530877, 0.6320892966219357, 1.0115395954677036, 2.0163717908518652, 0.7528421484998294, 0.2188452939902033, 0.1539495534130505, 0.04305971014712538, 22.465728623526438, 60.79684884207589, 26.024660212653025, 32.12185212544033, 50.38661650248936, 2.3690378155027116, 0.28226904783930096, 0.07229629810899496, 0.027805757775370563, 0.06364847786192383, 0.03410581971651741, 0.00999828813863652, 0.024787895248404572, 0.04479828989133239, 0.04395242813708527, 0.03799635630899242, 0.027625705115497112, 0.04072789062878915, 0.08350881109280245, 0.04345117396275912, 0.009311134877082492, 0.008691284655859428, 0.0176328350789845, 0.028575348800846508, 0.02707073132374457, 0.05015998879181487, 0.01740363782404789, 0.02397757855110935, 0.023836297382201468, 0.023613283277622292, 0.12416984566620418, 0.1263360008597374, 0.20337097719311714, 0.14457411292408193, 0.15473901533654758, 0.1838019322603941, 0.13829918392002583, 0.09993912944836275, 0.10490942560136318, 0.07049354591539927, 0.2173796176378216, 0.22745867179972784, 0.1717021736715521, 0.08759363940251724, 0.07850016414054803, 0.16232310980558395, 0.10020742219473634, 0.14282798447779246, 0.13043228962591716, 0.13038027313138756, 0.14881726380969795, 0.20342536856021198, 0.22968825644680432, 0.23730622338397162, 0.08480790031275579, 0.13777345498757704, 0.08714525667684418, 0.16889573926372187, 0.21512513075556072, 0.17905347634639057, 0.28949929986681255, 29.658455167497905, 70.55721964154924, 41.19383362361363, 41.766181060246055, 77.88517202649797, 23.533569472176687, 0.09176068580044167, 0.6308633738330433, 2.8773817036833083, 4.995117289679391, 20.769525698253087, 32.02708217075893, 7.458454319408961, 1.0051606063331877, 0.06763730025185005, 20.345147098813737, 74.8461411339896, 71.23889350891113, 69.3507135936192, 68.68100452423096, 64.4470363344465, 72.88006496429443, 70.42339733668736, 68.64770875658307, 66.80532441820417, 70.34547328948975, 68.13364628383091, 61.22383649008614, 52.814237185886924, 59.85991900307791, 65.45323276519775, 65.25503540039062, 65.68417004176548, 63.6985763822283, 64.94094903128487, 63.77943951742989, 59.60747010367257, 55.894978114536826, 54.2946377481733, 55.07297842843192, 52.325452259608674, 48.624709674290244, 46.49248123168945, 48.19490800585066, 46.27506167548043, 46.72307457242693, 49.730654444013325, 47.22963299070086, 47.21818930762154, 49.65144845417568, 52.894735540662495, 55.63456310544695, 55.35476262228829, 61.24454212188721, 59.508930751255576, 63.54731409890311, 61.17323970794678, 65.35736152103969, 56.79393604823521, 51.88107327052525, 57.822415351867676, 59.55201653071812, 62.55180399758475, 63.60966028485979, 63.03896304539272, 60.606648853846956, 60.936709131513325, 61.16077463967459, 60.36540045057024, 55.54332978384835, 52.41465323311942, 46.86796883174351, 45.39867843900408, 45.4452348436628, 44.29193115234375, 44.93734237125942, 44.53158494404384, 43.05068063735962, 44.72359493800572, 45.56887108939034, 45.62647860390799, 43.14487736565726, 48.30829913275582, 54.258600916181294, 56.5999492917742, 58.6567758832659, 59.86105850764683, 61.304678780691965, 53.820777552468435, 57.310079506465364, 59.6740060533796, 60.69418920789446, 54.70120464052473, 58.6286495753697, 57.84480939592634, 59.66559178488595, 54.45172609601702, 50.93634407860892, 50.16697352273123, 54.88613442012242, 55.44830969401768, 59.840026310511995, 57.24111516135079, 65.50905459267753, 56.46595328194754, 65.4904681614467, 18.24651493344988, 0.48073087845529827, 0.6004850353513445, 0.7541648032409805, 5.16441318818501, 5.161084566797529, 0.47202842256852556, 1.005806571670941, 0.1621954637978758, 30.299440383911133, 63.78999383108956, 29.84287425449916, 46.85618468693325, 55.454993861062185, 4.405521818569728, 0.915141373872757, 0.3222271337040833, 0.17785956683967794, 0.17617214524320193, 0.1316267012485436, 0.16193529990102562, 0.05202702200040221, 0.13170690408774785, 0.11902885724391256, 0.16747956882630075, 0.13415420348090784, 0.14707593939134053, 0.2252211482929332, 0.14723175817302295, 0.16299765503832273, 0.11350886630160467, 0.1508446043091161, 0.10249880781131131, 0.11262548834617649, 0.08769850698964936, 0.16186992983732904, 0.06935517449996301, 0.1386242021939584, 0.11416262122137205], [0.010646801375384842, 0.029793308981295143, 0.012438363678354238, 0.016525481195588197, 0.08325917127409152, 0.05976318634514298, 0.02851280483550259, 0.054855708964169025, 0.0471942275762558, 0.011486202628085656, 0.021158138323309164, 0.08120213129690715, 0.028242388274520636, 0.10103967253650938, 0.008842882949725857, 0.06887435101504837, 0.025095824617892504, 0.03761285510180252, 0.038206983756806166, 0.06095674301364592, 0.023013281902032237, 0.008762775105424225, 0.03358262511236327, 0.037090291535215716, 0.00981599376869521, 0.06605045111583811, 0.04810684699831264, 0.06408810748585633, 0.058462495782545636, 0.11919579042920045, 0.18647796580834047, 1.53202719773565, 42.06852497373308, 46.056127411978586, 24.882485798427037, 36.389977659497944, 54.87151888438633, 1.5533979024205888, 0.21406487907682145, 0.1959626775767122, 0.3775668756238052, 1.3227411593709673, 4.609122276306152, 5.211504169872828, 1.9680114601339613, 0.03211742373449462, 0.5878142895443099, 42.743188108716694, 74.79751764025006, 60.33375835418701, 66.42832905905587, 66.25420025416783, 64.92259189060756, 63.808545521327424, 68.09195709228516, 62.29230267660958, 65.71873038155692, 62.05206176212856, 56.0636317389352, 46.54228591918945, 57.44692080361502, 60.0187200818743, 63.55601324353899, 61.86156300136021, 62.17833832332066, 59.63517951965332, 58.53150681086949, 52.14284665243966, 52.49087149756295, 50.668348584856304, 51.54573583602905, 48.39661768504551, 46.72800431932722, 44.381389209202354, 43.16940450668335, 43.63493381227766, 44.37124483925955, 43.26266322817121, 45.48824766704014, 45.00688689095633, 49.232579776218955, 48.41980382374355, 49.58861242021833, 51.947400774274556, 54.18499864850725, 55.2865104675293, 59.405659675598145, 56.28584555217198, 64.58596556527274, 48.98026984078543, 43.78916645050049, 63.40293748038155, 57.98375947134835, 60.255709239414756, 56.90491615022932, 57.66213083267212, 53.70988777705601, 55.81068951742989, 49.54266050883702, 48.42795058659145, 44.84290940420968, 46.22833503995623, 43.06284693309239, 43.063927377973286, 40.96200697762625, 40.3062116759164, 39.28807823998587, 41.915449210575645, 39.38776057107108, 41.10864176068987, 40.75035442624773, 41.80141190120152, 40.40763800484793, 42.35205316543579, 46.68315717152187, 51.79640599659511, 54.56523881639753, 55.48980781010219, 55.32949202401297, 56.249878202165874, 56.81577771050589, 57.8903409412929, 53.62655455725533, 54.91350337437221, 54.94854661396572, 57.67527335030692, 55.038814135960166, 52.631037507738384, 50.37101084845406, 49.41675220217024, 49.49798011779785, 50.00074829374041, 52.152997970581055, 58.11856147221157, 54.86215966088431, 61.21017633165632, 35.307573386601035, 0.056348234947238646, 0.3181953329060759, 0.44100810853498323, 1.4153846395867211, 1.5371758128915514, 0.19004248668040546, 0.05069393139066441, 0.194501968100667, 6.829767848764147, 48.51289231436593, 26.053547348294938, 15.64349045072283, 48.395179407937185, 18.31587185178484, 0.17226743405418737, 0.038535940926522017, 0.011448571075951415, 0.05970699007489851, 0.04428699339873024, 0.007775494778927947, 0.07416889869741031, 0.044470879781459055, 0.028075000470770255, 0.061485769626285346, 0.024687528044783642, 0.1014624269945281, 0.0570247479315315, 0.07208184711635113, 0.07527243412498917, 0.016371874438066567, 0.0779590392485261, 0.01736922252790204, 0.06970904408288853, 0.02040927654265293, 0.02339725978007274, 0.02158347121439874, 0.04895508362512503, 0.04242914076894522, 0.010029613555941199, 0.0029267123734046307, 0.03648744709789753, 0.043328613575015745, 0.024044042752523507, 0.05206717770280583, 0.03770128857078297, 0.04020062481452312, 0.026226593048444817, 0.016536008666402528, 0.0357545444608799, 0.06388511016432728, 0.01185222138052008, 0.06698731120143618, 0.07607438787817955, 0.008302189775609543, 0.02033286332152784, 0.029927458747157028, 0.03528388882321971, 0.08327188702034098, 0.02049618839685406, 0.029219753508056914, 0.020863491276811277, 0.010129353114669877, 0.05193968436547688, 0.057640484534204006, 0.007481436361558735, 0.05117014762280243, 0.017770413143028106, 0.08092931272195918, 0.06739644746163062, 0.09862163835870368, 2.715577266045979, 57.82204014914376, 46.20571517944336, 22.653564487184795, 59.14571366991316, 53.5006080354963, 2.007970550230571, 0.18683423740523203, 0.28089338594249313, 0.10023136769554444, 0.22139678922082695, 2.9536685815879276, 7.639883943966456, 5.884950067315783, 0.49116435859884533, 0.9258444224085126, 49.55168969290597, 71.59691333770752, 66.25701427459717, 69.61624595097133, 65.55327987670898, 65.99818692888532, 67.85664245060512, 68.37520040784563, 64.36240032741001, 66.74292264665876, 65.14880439213344, 58.89363997323172, 49.856726033346995, 59.411120959690635, 63.696915762765066, 65.88684204646519, 62.95382676805769, 60.8873074395316, 61.906476157052175, 60.95250933510916, 54.38083015169416, 55.950862475803916, 53.0192403112139, 54.703560079847065, 49.86647783006941, 47.28530543191092, 45.22863517488752, 44.70132943562099, 46.79549217224121, 46.04886654445103, 42.93404817581177, 46.66433450153896, 46.96092183249337, 50.18690095629011, 49.63666616167341, 51.12585619517735, 54.11791379111153, 59.01057815551758, 57.384418283190044, 61.89932646070208, 57.65060377120972, 64.87946442195347, 52.58839293888637, 44.65053810392107, 63.415965352739605, 58.51508126940046, 61.29202611105782, 58.13171788624355, 59.67406163896833, 56.422488825661794, 57.40917124067034, 53.298026357378276, 51.83774777821132, 46.517289774758474, 49.40341860907418, 46.11999525342669, 43.662618909563335, 44.09884071350098, 40.93011474609375, 41.624392645699636, 43.38529198510306, 40.87694713047573, 42.82270329339163, 42.32111631120954, 42.55545820508684, 42.72661318097796, 46.326123986925396, 50.390924385615754, 54.52735723767962, 54.99733339037214, 56.0891489982605, 56.437444823128835, 58.464463642665315, 58.466694014413015, 59.45805604117257, 55.87164953776768, 55.36097778592791, 55.50465611049107, 59.2100053514753, 57.06822313581194, 54.99677753448486, 51.14877135413033, 51.37815918241228, 51.84998355593, 51.5389335496085, 54.72501264299665, 59.44243649074009, 57.04046508244106, 61.54833820887974, 41.721153259277344, 0.06943362671881914, 0.18891804558890207, 1.1932109956230437, 1.2744303345680237, 0.6611612109201295, 0.1305531502834388, 0.08662912222955908, 0.0882375148524131, 10.061301623071943, 52.9244738306318, 40.34175171170916, 14.73447847366333, 52.666455950055806, 25.142464808055333, 0.17215413227677345, 0.06290562450885773, 0.021408687378945093, 0.04395611258223653, 0.02321790940394359, 0.05845464513237987, 0.10579243714788131, 0.024709230987355113, 0.033411254308053424, 0.021813119695122753, 0.045750763067709546, 0.012320599685023938, 0.06484339160046407, 0.029725173887397562, 0.06036895526839154, 0.040670863153146844, 0.06949446416859116, 0.03585832639198218, 0.03169796017131635, 0.03953118555779968, 0.048688660242727826, 0.09737836542938437, 0.029633955032165562, 0.015503388629960162, 0.03862482222861477, 0.1087660693696567, 0.1357961089483329, 0.10323698605809893, 0.09305644341345344, 0.14674995759768145, 0.12456277172480311, 0.12264939796711717, 0.14250584319233894, 0.09870080982467958, 0.10144045603062425, 0.13677147589623928, 0.16448892573160784, 0.11471770357872758, 0.22630403589989456, 0.07387780038905994, 0.11618294566869736, 0.14465247014803545, 0.16497903157557758, 0.1578152081263917, 0.13548392855695315, 0.07664207741618156, 0.1150031496903726, 0.19900631425636156, 0.14036011190286704, 0.184756943157741, 0.22229017556778022, 0.1289666946977377, 0.12904589330511435, 0.1462169683405331, 0.26655889941113337, 0.27006817396198, 4.485813898699624, 70.866685458592, 57.74352550506592, 38.81057024002075, 44.4507600239345, 72.51560415540422, 3.438528209924698, 0.3160856318260942, 1.1012748203107288, 1.1325566960232598, 4.26194337436131, 8.005205460957118, 14.534889732088361, 8.43359317098345, 0.41084738980446545, 1.4582015020506722, 46.70816721235003, 79.32847268240792, 69.5759950365339, 73.9128452028547, 67.11875070844377, 69.10150255475725, 69.00522136688232, 71.99370411464146, 67.78973824637276, 70.20263917105538, 66.9309686933245, 62.466125760759624, 51.56206062861851, 64.03103378840855, 65.58999415806362, 67.89753954751151, 64.21466772896903, 63.934954098292756, 66.28660665239606, 65.53092752184186, 57.09510571616036, 58.70818560464041, 55.605179173605784, 59.29929665156773, 54.36268493107387, 51.800189290727886, 48.88045201982771, 47.078005926949636, 48.95782715933663, 48.62222569329398, 46.206757409232004, 49.344442299434114, 51.21302134650094, 55.318621567317415, 52.19778953279768, 54.28076914378575, 58.03932768957955, 59.50485910688128, 59.28398977007185, 64.11259869166783, 59.75841971806118, 67.91255460466657, 54.102207388196675, 46.16045461382185, 65.4110016141619, 62.29867417471749, 63.64921637943813, 61.597218785967144, 61.22908238002232, 58.419335092817036, 61.03790269579206, 54.833866596221924, 53.26494945798601, 49.21734585080828, 53.035495621817454, 48.66819150107247, 46.75838879176548, 46.28094332558768, 44.19977024623326, 44.58968578066145, 45.911309582846506, 42.81346913746425, 44.519852910723, 43.769774028233115, 45.17510625294277, 44.52391413279942, 48.11669560841152, 52.16210011073521, 57.45812129974365, 57.606319427490234, 58.68501336233956, 59.17037977491106, 61.730033602033345, 62.72307709285191, 60.217035566057476, 56.450948647090364, 58.406341961451936, 58.459071840558735, 61.380414145333425, 58.47927025386265, 57.14136682237898, 54.11997045789446, 53.089132240840364, 54.625344208308626, 54.61377545765468, 58.1398229598999, 61.66725662776402, 57.86403506142752, 63.56105068751744, 40.283643926892964, 0.1452598946967295, 0.8508821534258979, 0.6710251016276223, 4.941730371543339, 5.137585759162903, 0.8800659445779664, 0.5600003791706902, 0.2931738384068012, 11.81049759047372, 62.91219316210066, 35.75974130630493, 27.20345163345337, 62.86907958984375, 33.16988365990775, 0.2070873406316553, 0.13637879411024706, 0.11335939182234661, 0.16928352202687943, 0.1282197633492095, 0.2080268402184759, 0.15572131691234453, 0.12651551408427103, 0.1253742588950055, 0.10514018179050513, 0.12418876322252409, 0.23509607197982924, 0.11735119298100471, 0.13627311906644277, 0.12427983619272709, 0.13426876733345644, 0.12872253065662725, 0.08958523467715297, 0.11391492879816464, 0.1606223482106413, 0.12647330920611108, 0.1535420117101499, 0.08238510960446936, 0.07758004351386003, 0.2642468863299915], [0.01507605066789048, 0.018452242449192063, 0.06657058213438306, 0.037148564122617245, 0.04202343450327005, 0.019878090492316654, 0.03162886155769229, 0.011423196410760283, 0.0406500015939985, 0.018500912069742168, 0.05975321188036885, 0.08557973389646836, 0.03885245715667095, 0.012476543147516037, 0.04432207026651927, 0.059563357782151015, 0.016871647709714513, 0.024030192156455348, 0.023028691432305744, 0.06713076028972864, 0.044091269972601106, 0.04017570222328816, 0.06024132961673396, 0.03750686453921454, 0.12218777702323028, 0.09308063997221844, 0.15278137395424501, 0.04521568053002868, 0.0930090273863503, 0.16218501435858862, 0.24256923954401696, 0.10589082472558532, 23.790112597601755, 45.181380476270405, 47.657294613974436, 30.842879840305873, 51.908845220293315, 30.721220357077463, 0.16434058440583094, 0.10479064804634877, 0.28126104335699764, 0.5870126411318779, 7.201524266174861, 8.454328332628522, 3.6467789666993276, 0.6415690279432705, 0.03713236070637192, 1.9373388545853751, 60.74762780325753, 66.68814304896763, 61.41764954158238, 64.77484539576939, 66.88186577388218, 66.28267397199357, 64.76416601453508, 67.17393330165318, 65.3595779963902, 65.55684430258614, 53.469261237553184, 54.72729860033308, 62.231457301548545, 65.41128649030412, 64.58577796391079, 64.02705941881452, 60.78435598100935, 62.393461499895366, 59.891248430524556, 55.869585922786165, 51.407960006168906, 50.93392610549927, 48.589193957192556, 48.14566264833723, 45.21094158717564, 45.049802439553396, 44.214038372039795, 44.07247577394758, 46.55503933770316, 45.179302964891704, 46.053483622414724, 46.11889048985073, 48.36310999734061, 49.58792107445853, 52.68996517998831, 53.47481632232666, 58.98948342459542, 54.10690089634487, 59.221935408455984, 57.03404147284371, 63.668310029166086, 46.40307181222098, 40.82945271900722, 66.05457850864956, 54.256346225738525, 58.65266949789864, 54.05955934524536, 56.21445975984846, 51.17734234673636, 52.85444293703352, 50.25820337023054, 52.21123777117048, 48.2529046194894, 48.19140263966152, 43.36405481610979, 44.63785764149257, 42.17978300367083, 42.662290232522146, 40.00424991335188, 42.12617417744228, 41.606400285448345, 42.00065149579729, 41.39900697980608, 41.43315390178135, 39.934187752859934, 43.994968618665425, 43.87845080239432, 52.88010263442993, 53.609545367104666, 59.64106464385986, 55.81143297467913, 57.3924434525626, 55.58385167803083, 59.70746857779366, 54.549539361681255, 56.04631335394723, 53.90299211229597, 57.84401035308838, 54.68934406552996, 59.723095076424734, 51.31752920150757, 51.775356428963796, 49.11909832273211, 55.85062081473214, 50.10645818710327, 60.7664087840489, 55.164013726370676, 60.24298013959612, 2.7372769245079587, 0.09062424820980855, 0.15120634489825793, 0.5231482737830707, 1.3164453314883369, 0.8549831105130059, 0.09030692452298743, 0.1135728182271123, 2.5728465020656586, 31.684740952083043, 41.86325086866106, 13.666669760431562, 42.848019054957796, 41.24504879542759, 2.303619657244001, 0.20478394494525023, 0.1169765330851078, 0.15692752147359507, 0.11126632842102221, 0.026347282375874262, 0.01754581805185548, 0.0619034825691155, 0.06044314628733056, 0.013583338087690728, 0.049744830533329926, 0.024922201077320745, 0.024578117665701678, 0.03630274647314634, 0.04941731185785361, 0.020054772529484968, 0.02611637012367802, 0.009834042800191258, 0.02598345698788762, 0.029075568209269216, 0.04173948456134115, 0.018520162108221223, 0.04155288403853774, 0.012282305713077741, 0.05236375178875668, 0.021237979842615978, 0.04499163844489625, 0.0358792999094086, 0.042808547017297575, 0.04403856476502759, 0.050527161053780995, 0.04206926615110465, 0.007650621434939759, 0.013611137667404754, 0.019685878484909023, 0.014423296587275607, 0.029079174622893333, 0.054302394190537076, 0.012279663667348879, 0.017728678150368587, 0.02542829150999231, 0.020414122979023626, 0.04030212686796274, 0.006976471024764968, 0.02508369580443416, 0.03874274482950568, 0.02171243358004306, 0.01699212838762573, 0.05178982312125819, 0.0358788486836212, 0.05888325534760952, 0.030767122084008794, 0.017463601659983397, 0.045188559485333304, 0.029855540820530484, 0.09518033944602523, 0.24105230665632657, 0.09230399557522365, 31.778760501316615, 58.84835161481585, 33.47609077181135, 34.57352747235979, 72.37204047611782, 27.401364122118267, 0.1270633496876274, 0.11960869255874838, 0.2768162047224385, 1.0255266449281146, 0.6541184516889709, 3.0417107258524214, 4.905576288700104, 1.1710137810025896, 0.20002422534993716, 4.0555857845715115, 69.35219355991909, 68.01178877694267, 67.42174080439976, 65.44331768580845, 70.95705372946603, 66.91146509987968, 69.40209552219936, 68.21591295514787, 68.73940413338798, 66.55854524884904, 57.60116733823504, 55.346139907836914, 64.54988356998989, 65.64252253941127, 68.51911844526018, 61.995169912065776, 62.25018269675118, 65.64921365465436, 61.56523622785296, 57.48078284944807, 52.931189264569966, 52.10336351394653, 51.78816890716553, 50.32538897650582, 48.2584353855678, 46.99288354601179, 45.33617244447981, 46.648603779929026, 47.50957938602993, 48.79181732450213, 48.45898471559797, 48.390367780412944, 50.298072133745464, 50.927078655787874, 54.81308453423636, 54.415380069187705, 57.34150273459298, 55.32496179853167, 62.6809640611921, 61.95710073198591, 62.850131852286204, 49.021733215876985, 42.40045084272112, 64.77100304194859, 56.63527740750994, 60.72922202519008, 55.21766424179077, 56.26241275242397, 51.76826926640102, 52.903549330575125, 50.93785183770316, 52.61503233228411, 49.530244077954976, 48.9550895690918, 44.57462208611624, 46.610510281154085, 42.7125951903207, 43.65060200010027, 42.09552567345755, 43.994857447487966, 42.84026139123099, 43.272352491106304, 43.25318935939244, 44.25219440460205, 40.31687716075352, 45.60751696995327, 46.44432326725551, 54.725478172302246, 55.96627358027867, 58.7913624899728, 57.10926614488874, 59.4032347542899, 57.82807813371931, 61.391802242824006, 58.67281927381243, 56.83933557782854, 55.05057396207537, 59.54072570800781, 57.67896979195731, 61.13045964922224, 52.63115562711443, 53.85564361299787, 49.53168930326189, 57.822252069200786, 52.50280850274222, 61.92504869188581, 56.779105118342805, 64.2519587108067, 4.100790764604296, 0.17563360556960106, 0.4230323045381478, 0.545393202986036, 1.2672047508614404, 0.9830020410673959, 0.6255740576556751, 0.3496542791170733, 5.748560837336949, 35.01076718739101, 55.48354400907244, 18.01157202039446, 36.35421180725098, 52.90477916172573, 2.6897794732025693, 0.29515266365238596, 0.051030919022325955, 0.121970035135746, 0.0065295484216351595, 0.0032994812770214465, 0.03029446137536849, 0.030598248288567578, 0.020176522067881057, 0.05381372005545667, 0.02804482262581587, 0.011599229598817016, 0.019006147548290234, 0.032113569655588696, 0.04071925287800176, 0.02385960506009204, 0.015253937104716897, 0.017410611467702047, 0.014302234065585902, 0.019668507988431623, 0.03915085650182196, 0.03493876216400947, 0.05739100756389754, 0.02704323029943875, 0.03563332757247346, 0.10553031907017742, 0.15631264661039623, 0.12591738546533243, 0.14221405956361974, 0.08333409511085067, 0.12433086202612945, 0.2064207885414362, 0.12477132624813489, 0.14244453076805386, 0.15494853337960585, 0.12771186631705078, 0.22227390429803304, 0.14948997699788638, 0.0751301928290299, 0.1477345254804407, 0.1367655862122774, 0.16581041339252675, 0.15392975376120635, 0.12740583345294, 0.20928213000297546, 0.2401192667228835, 0.13810221877481255, 0.1085743900122387, 0.19762892888060637, 0.11781977569418293, 0.19954580387898854, 0.19902664316552027, 0.1271074273224388, 0.16934708718742641, 0.22617979613798006, 0.37265737620847567, 0.32641727743404253, 0.26390229910612106, 36.09104183741978, 66.96819714137486, 58.47096020834786, 41.94197048459734, 65.19515582493374, 43.302101203373496, 0.20137330224471434, 0.27853018417954445, 1.0618558440889632, 2.6634573084967474, 15.014593362808228, 23.43807864189148, 11.492680038724627, 2.006032871348517, 0.1415706862296377, 3.2192523990358626, 65.80823707580566, 74.44027600969586, 70.5007655279977, 70.70552894047329, 68.34222425733293, 70.7457173211234, 69.81154591696603, 72.45256314958844, 71.01835073743547, 71.23570428575788, 58.51091235024588, 59.02157020568848, 67.92222649710519, 69.43409197671073, 69.32585988725934, 64.35939870561872, 64.54185840061733, 66.62701279776437, 64.55031435830253, 61.02473585946219, 56.216075216020855, 55.66513170514788, 54.14469562258039, 52.57422208786011, 48.90106037684849, 49.22240761348179, 48.01995236533028, 51.07419981275286, 51.2790743964059, 51.75664840425764, 50.58158990315029, 50.92955221448626, 53.07700068610055, 54.55738040379116, 57.54605770111084, 57.49739599227905, 61.8980063029698, 57.433913775852744, 63.02718584878104, 63.86026096343994, 63.94336141858782, 51.3419451713562, 42.74152748925345, 65.43083872113908, 58.97765759059361, 62.81648867470877, 57.771881103515625, 60.0013495853969, 53.79611144747053, 56.627967902592246, 53.71680818285261, 57.39066123962402, 52.47104828698294, 52.05600111825125, 47.11210421153477, 49.767104693821494, 45.977793421064106, 47.63851710728237, 44.865126269204275, 46.93557480403355, 46.17173154013497, 46.853540897369385, 45.50143187386649, 46.46157217025757, 44.20612784794399, 47.69330712727138, 49.183445589882986, 57.60069833483015, 59.9470911026001, 63.90283257620675, 59.621019090924946, 60.098784174237935, 58.32502719334194, 64.8360937663487, 59.043728010995046, 58.885239601135254, 56.8726487159729, 62.158577646527974, 59.430700983319966, 63.29874229431152, 54.65813970565796, 58.87226731436593, 52.026995863233296, 60.75523608071463, 54.45386961528233, 66.62047454289028, 57.89483642578125, 62.82739734649658, 3.770394367831094, 0.1601824268166508, 0.25141587055155207, 3.628840454987117, 4.602789427552905, 2.1421595896993364, 0.4475702207003321, 0.40648321541292326, 5.1248844521386285, 49.74241427012852, 49.40252576555525, 23.67323694910322, 52.3379624911717, 59.9181935446603, 4.874352387019566, 0.6466649344989231, 0.2933988949017865, 0.2950774276895182, 0.19853621162474155, 0.1333962120115757, 0.11270174889692239, 0.1673648828374488, 0.14207780973187514, 0.15194539166986942, 0.2463874646595546, 0.06220988184213638, 0.07450984218823058, 0.09312598646751472, 0.1656164066599948, 0.15308951027691364, 0.19389238581061363, 0.10128031498087303, 0.19764013827911445, 0.07892956824174949, 0.14457993475454195, 0.10266125588012592, 0.15789926504450186, 0.12947560953242437, 0.15140738125358308, 0.17419101297855377], [0.028916594239750078, 0.047329873511833806, 0.0853438140558345, 0.022565114611227597, 0.03835620717810733, 0.02761322516016662, 0.04149465894858752, 0.0843382455142481, 0.013892635553410011, 0.01881839181961758, 0.015634663103680526, 0.06341930944472551, 0.0045130822940596515, 0.0787266455590725, 0.05980066183422293, 0.08760854681687695, 0.0032204622693825513, 0.029550349339842796, 0.039094470241772275, 0.04368600814736315, 0.03717165806197694, 0.04926379330988441, 0.03951218318460243, 0.05197358397500856, 0.02664679621479341, 0.06835786372955356, 0.09095112566969224, 0.024939837898792963, 0.018766624686707343, 0.028015330101230314, 0.10813618531184536, 0.15172356500157289, 0.362114461937121, 38.359851019723074, 50.11680058070591, 39.936400754111155, 32.04126344408308, 58.05222354616438, 9.587931275367737, 0.044877271367503066, 0.1225287951529026, 0.2874918675848416, 0.25736464134284426, 2.8283697622162953, 4.32094487122127, 1.133984767964908, 0.09334777920906033, 0.063633930071124, 7.977238093103681, 75.77534457615444, 53.76921844482422, 72.3945665359497, 65.43450736999512, 66.12502629416329, 67.89958231789726, 65.55647604806083, 65.82822009495327, 67.66161346435547, 59.13365854535784, 59.607553482055664, 64.24747017451695, 66.434221131461, 64.65614237104143, 63.90841197967529, 66.77994959694999, 64.34908757890973, 58.94608497619629, 54.31461729322161, 51.45524249758039, 50.90818302971976, 52.37113666534424, 49.62039695467268, 47.030608790261404, 45.950361933027, 45.73279993874686, 44.49064268384661, 46.71869720731463, 46.35570246832711, 48.80070407049996, 49.57391350609915, 56.504012039729524, 54.900117669786724, 54.06436749867031, 52.78994280951363, 59.2816412789481, 56.42474699020386, 63.255343845912385, 58.780578885759624, 67.86589050292969, 38.92727565765381, 36.71776935032436, 67.86910057067871, 57.05091169902256, 64.36934157780239, 55.925918442862375, 63.74278082166399, 58.02518810544695, 61.272091729300364, 59.01554611751011, 59.76402691432408, 56.65485743113926, 52.46922091075352, 46.40586846215384, 42.443460191999165, 40.356902258736746, 41.36772271565029, 42.606944356645855, 40.67248249053955, 40.741043840135845, 44.74953603744507, 46.85554892676217, 47.121525968824116, 44.3496915272304, 43.32941804613386, 44.075067452022004, 47.947503498622346, 53.90794617789132, 53.682845388139995, 55.254343782152446, 60.745487758091514, 61.450472831726074, 58.077355180467876, 56.27703523635864, 57.46718522480556, 56.68652384621756, 57.07123170580183, 59.482604026794434, 56.108294759477886, 57.54025942938668, 54.2510621207101, 55.31207636424473, 49.667206968579976, 62.54942076546805, 51.82972955703735, 66.15115846906389, 14.7744688306536, 0.21055412531963416, 0.09661790409258433, 1.0091891501631056, 1.263915321656636, 0.2750482138778482, 0.2602047717997006, 0.3450255574924605, 4.966820316655295, 29.285211835588726, 60.00544902256557, 16.395054510661534, 30.260224751063756, 45.78797210965838, 12.851932678903852, 0.4526016664292131, 0.08778571909559624, 0.14138877099113806, 0.08005056916070835, 0.062466103450528214, 0.0874603751248547, 0.07091460403587137, 0.04444462386891246, 0.08442264169986759, 0.0267199456824788, 0.0659703364861863, 0.029073464750711406, 0.017831817169540694, 0.06933652157230036, 0.020430445138897215, 0.037667063264442344, 0.017453650943934917, 0.05813289061188698, 0.027997793363673345, 0.05747659118579967, 0.01018896750507078, 0.0860115671530366, 0.06293995838080134, 0.08073787085179772, 0.024624395450311046, 0.05303503666073084, 0.015318491230053561, 0.04268653624291931, 0.03603071499882, 0.05494578109521951, 0.06407765126121895, 0.016521684792158858, 0.011123008277666355, 0.07842797479991402, 0.05551020687978182, 0.0559428713417479, 0.0320626591731395, 0.03543039810444627, 0.05238088819065264, 0.023076083710683242, 0.10259598759668213, 0.06447269434907607, 0.09356801132006304, 0.03375357522496155, 0.03302271497835006, 0.08293122172887836, 0.0616343959367701, 0.03655017426769648, 0.006096082440178309, 0.03484271213944469, 0.03640900166439159, 0.05406355664932302, 0.08898165063666445, 0.05864727443882397, 0.09862632025033236, 0.021797245368361473, 0.04657344945839473, 0.1461013052612543, 1.7307153876338686, 49.00937931878226, 56.74046966007778, 27.54793984549386, 49.70521708897182, 64.64635930742536, 10.371167830058507, 0.05114745401910373, 0.08489283932639019, 0.13978338427841663, 0.33244454115629196, 0.8922287662114415, 0.5750673306839806, 1.9513776898384094, 0.3620718770793506, 0.19925416952797345, 12.429684570857457, 82.83430440085274, 56.5501515524728, 75.8561521257673, 63.42608887808663, 70.03292942047119, 67.56313664572579, 69.45176819392613, 67.21263476780483, 68.99427100590297, 60.461563519069124, 61.06966985974993, 64.44961411612374, 68.71502985273088, 65.44402640206474, 65.12698704855782, 68.21430792127336, 64.05352510724748, 60.431415285382954, 57.87898758479527, 53.916266645704, 53.37624222891671, 51.78501442500523, 50.05326625279018, 48.78801318577358, 47.83710009711129, 48.65810966491699, 47.073562553950715, 47.77310718808855, 46.25331033979143, 48.689334869384766, 49.698376587459016, 55.24891029085432, 55.53743771144322, 55.196572984967915, 54.615491662706646, 58.60888195037842, 58.101458481379915, 63.4955222266061, 59.80151244572231, 68.87406022208077, 39.39903054918562, 39.451680524008616, 67.95648806435722, 57.92987271717617, 65.11603668757847, 57.61384432656424, 62.09794071742466, 56.88958147593907, 62.620076996939524, 59.07049247196743, 60.94734682355608, 56.76714032036917, 54.75102322442191, 49.01519496100289, 44.67965105601719, 42.689214502062114, 43.971737316676546, 43.29690047672817, 42.465711797986714, 42.713963985443115, 43.035095827920095, 46.77057940619332, 46.590721811567036, 45.91957099097115, 46.324425152369905, 46.21292740958077, 51.36984913689749, 56.00454078401838, 56.4880450793675, 57.815571376255576, 62.66809599740164, 60.64405100686209, 60.24386256081717, 58.04836729594639, 58.63675117492676, 59.00162887573242, 59.05565806797573, 61.505954197474885, 58.46838937486921, 59.911036900111604, 56.562693050929475, 56.966550145830425, 51.029099055698936, 63.004777908325195, 56.15438216073172, 67.5658950805664, 19.07823862348284, 0.19573306132640156, 0.21924572464610848, 0.273389711443867, 0.5664383737104279, 0.6764392139656203, 0.7777220191700118, 0.6383514691676412, 8.130588310105459, 31.514788014548166, 70.65582152775356, 28.21503118106297, 20.637108666556223, 56.74318640572684, 16.891225372041973, 0.2725469980921064, 0.076222566355552, 0.09170480165630579, 0.06510795918958527, 0.010020858757863087, 0.04992353969386645, 0.046039045455732515, 0.04214947238298399, 0.0759405264897006, 0.008814250468276441, 0.05323018333209412, 0.030205841309257915, 0.05215488174664123, 0.0156006125201072, 0.024764036260811344, 0.04437035821112139, 0.08363898803613015, 0.007725467240171773, 0.06488803241934095, 0.020240972716627375, 0.014907718004126633, 0.05756490930382695, 0.0073506139617945465, 0.0314663490280509, 0.014301721771646823, 0.0701169046972479, 0.1225146409124136, 0.13247735346002237, 0.14598747422652586, 0.14579149974243982, 0.1682097946426698, 0.08802493661642075, 0.09733044728636742, 0.21212502888270787, 0.17037183791399002, 0.12423673564834253, 0.12359915700341974, 0.11694294560168471, 0.07525483971195561, 0.1381405017205647, 0.26362643390893936, 0.17028764528887613, 0.25645944848656654, 0.19092481290655477, 0.19133466162851878, 0.1462425219693354, 0.14313578153295176, 0.10480111105633633, 0.07475209954593863, 0.08482819529516356, 0.18460771973643983, 0.17435692836131367, 0.21591041290334292, 0.14113722448902472, 0.1407671786312546, 0.10570675174572638, 0.22865794173308782, 0.27380948034780367, 1.3721989797694343, 62.020982469831196, 66.81649017333984, 52.05194684437343, 45.14447859355381, 74.14801393236432, 17.02827685219901, 0.1841201109013387, 0.29166143813303536, 0.9224427363702229, 0.8071041053959301, 6.900915231023516, 10.934550353458949, 2.8596383929252625, 0.7287939446313041, 0.29113133943506647, 10.693583352225167, 85.83782305036272, 60.56214564187186, 78.52045972006661, 66.53433077675956, 68.46388026646206, 71.6607255935669, 71.68071556091309, 69.6259456362043, 71.09605939047677, 64.3837035042899, 64.58597946166992, 67.96213694981166, 71.16157395499093, 67.6945618220738, 65.86726202283586, 71.52486746651786, 68.66711507524762, 62.78825119563511, 59.55134950365339, 55.070789745875764, 56.241099153246196, 55.9140613419669, 54.84653663635254, 51.7650522504534, 50.550930976867676, 51.5289420400347, 49.94148710795811, 51.04447194508144, 48.4464293207441, 52.525702817099436, 55.227898938315256, 59.30134637015206, 60.78401551927839, 59.09098270961216, 58.81891904558454, 64.54639557429722, 62.570897647312705, 66.2638304574149, 62.59372247968401, 71.06085981641496, 40.86473567145211, 40.07523965835571, 69.37604672568185, 60.449626513889854, 68.51930604662213, 60.56264591217041, 66.26663058144706, 61.28969151633126, 66.58075169154576, 64.02422455378941, 63.985085351126536, 60.87015928540911, 57.812656606946675, 51.87549386705671, 46.36646522794451, 45.46166385923113, 46.47879328046526, 47.245478357587544, 45.65381281716483, 46.080984592437744, 47.770612784794395, 52.06678819656372, 50.817008767809185, 48.898336683000835, 49.8150611604963, 48.99006680079869, 53.7814542225429, 59.6187470299857, 57.902319635663716, 60.98404026031494, 65.72221837724958, 64.67397839682442, 60.66067804609026, 59.57581411089216, 60.34465312957764, 60.3200078691755, 59.916442598615376, 61.763516971043174, 58.602739742824006, 61.00068814413888, 57.39309310913086, 60.34405558449881, 54.11326544625418, 67.46442358834403, 56.7700446673802, 69.5154275894165, 17.105599880218506, 0.24472779514534132, 0.5086062369602067, 4.690232941082545, 7.2396347011838635, 1.056845324380057, 0.6485015388045992, 0.5726085911904062, 7.381307601928711, 47.1530499458313, 70.25702966962541, 25.419378314699443, 41.896928787231445, 60.83327824728829, 24.062815495899745, 0.7034439306174005, 0.20113767417413847, 0.26936765440872734, 0.16448942784752163, 0.1969777388232095, 0.18390352252338613, 0.122044334720288, 0.1812186273080962, 0.2152874091906207, 0.0643838673297848, 0.13172928217266286, 0.13978619341339382, 0.14525731626365865, 0.1467891904924597, 0.11461225923682962, 0.11794542680893626, 0.23192294367722102, 0.12605025619268417, 0.18088721723428794, 0.11356286411838871, 0.08491715123610837, 0.21244398105357373, 0.09640483052602836, 0.1696069118167673, 0.1192331098552261, 0.14868797574724468], [0.0514179146848619, 0.024230622919276357, 0.004292675460289631, 0.03148280010957803, 0.052579349505582025, 0.0355250164201217, 0.056013337203434536, 0.05459550774789282, 0.043617085952843936, 0.0665126827412418, 0.021599335363134742, 0.01696423550934664, 0.07591042667627335, 0.04681908931317074, 0.03242492901959589, 0.03232393926009536, 0.03183721252051847, 0.053860613610595465, 0.04141899211598294, 0.025099800833101784, 0.021131244587845037, 0.016470555482166152, 0.04357889460931931, 0.013981956206927342, 0.03692030154966882, 0.06230811335678611, 0.05932040831872395, 0.07762547821870872, 0.0798172548945461, 0.1874459638659443, 0.20329245712075913, 0.20344098843634129, 0.3200489820114204, 10.002259305545262, 45.43183524268014, 40.19548518317086, 38.63552079881941, 40.409520966666086, 57.07316330501011, 3.825622992856162, 0.2214389398161854, 0.3736692619110857, 0.0503201196635408, 0.1978064879242863, 1.0355324851615089, 1.6019702617611205, 0.5999656032238687, 0.028457112377509475, 0.02556649043357798, 18.635735648018972, 83.20130825042725, 49.83555487224034, 73.18928064618791, 65.35818140847343, 67.4833504813058, 68.76291683741978, 70.33004828861782, 64.2091508592878, 62.28626469203404, 66.76634502410889, 69.88857364654541, 64.9660667691912, 68.23533317020961, 64.94438144138881, 65.56600202832902, 63.006424631391255, 62.599385261535645, 55.59734507969448, 52.65831960950579, 49.50510549545288, 49.77733939034598, 47.81363950456892, 47.713880743299214, 44.237328733716694, 47.27622413635254, 43.44183642523629, 44.94716017586844, 47.13770137514387, 48.7997591154916, 57.66140822001866, 60.823919023786274, 59.388587951660156, 62.63511984688895, 56.35893365315029, 61.2836674281529, 58.81322847093855, 64.64960411616734, 58.11633110046387, 66.91678047180176, 40.11551489148821, 35.654225962502615, 68.43386404854911, 57.604165485927034, 62.51292187826974, 61.00668443952288, 59.52118042537144, 58.835282053266255, 63.85282639094761, 59.59398365020752, 62.910219873700825, 59.02884496961321, 57.06938348497663, 45.12759099687849, 43.63610110964094, 42.66500350407192, 44.763192721775596, 42.51891415459769, 43.33515725816999, 45.725448744637625, 57.556514739990234, 59.7281950541905, 59.673471042088096, 52.30294009617397, 47.324086802346365, 44.398186479296, 46.80027600697109, 50.62924412318638, 54.976377623421804, 57.34769357953753, 58.93239007677351, 59.22373499189104, 61.412063189915244, 59.17682770320347, 58.12440143312727, 56.91446992329189, 57.25266306740897, 63.17414024897984, 64.0470563343593, 57.07290622166225, 57.27832276480538, 54.16316046033587, 61.44617884499686, 53.79645538330078, 62.99638448442732, 28.09461542538234, 0.15404306910932064, 0.019148935064939514, 0.4607241377234459, 0.78107088804245, 0.7283406832388469, 0.2677297522979123, 0.4234545704509531, 6.996057782854352, 19.176922151020594, 55.6886374609811, 12.401507888521467, 20.7496851171766, 44.0630818094526, 34.45817000525338, 0.6226788844381059, 0.18576804175972939, 0.025300888078553335, 0.05875830312392541, 0.02835285716823169, 0.027210931925635253, 0.04353883390181831, 0.06738539412617683, 0.04137289923216615, 0.059428851785404344, 0.05645231204107404, 0.040704654197075536, 0.06276003124990634, 0.04653652358267989, 0.030940776158656393, 0.10528017035020248, 0.009953533665144017, 0.02249431117836918, 0.00804913098857339, 0.03151201443480594, 0.025388768541493585, 0.042777772061526775, 0.040413019846060445, 0.060318546901856146, 0.08857685700058937, 0.021028694197801606, 0.05065949913114309, 0.026669428750340427, 0.021455633520547832, 0.035691148934087584, 0.028373031710673655, 0.0724627495344196, 0.015234761705089892, 0.01892105586427663, 0.03141670740608658, 0.04554442735388875, 0.02448734494724444, 0.06222740161631789, 0.03975821998236435, 0.04501035583338567, 0.04739414095612509, 0.028860350472054312, 0.06286774189876658, 0.09187889338604041, 0.016680879285559058, 0.036166248976119926, 0.041242196424199004, 0.08604849981410162, 0.015640919196552465, 0.006076925700264317, 0.058017756789922714, 0.05610770106847797, 0.07196246566517012, 0.03353116162387388, 0.15514758841267653, 0.05466945110155003, 0.16122627151863916, 0.13542735230709824, 0.20589096125747475, 0.38093205647809164, 16.873801027025493, 58.480833598545615, 37.967316014426096, 30.69507428577968, 68.4727600642613, 52.64673696245466, 6.6966277701514105, 0.06577388702758721, 0.418510194335665, 0.21308282177363122, 0.15718277277691023, 0.9176369713885444, 1.4173991829156876, 1.431790204984801, 0.1556929134364639, 0.05818352968032871, 26.673957211630686, 85.04745156424386, 56.22925247464861, 77.91048431396484, 64.8745173045567, 72.59846837180001, 70.71633338928223, 71.58688708714077, 66.370589528765, 65.62568010602678, 67.45459883553642, 71.96243722098214, 64.87512179783413, 68.01059368678501, 64.17607048579625, 67.79610279628209, 65.525132724217, 64.18905666896275, 56.85009833744594, 54.116663115365164, 50.489112854003906, 53.30879953929356, 49.86728382110596, 50.59466641289847, 47.13460595267159, 49.301568440028596, 46.36102131434849, 46.51746000562395, 49.38766009466988, 51.8221629687718, 56.83172035217285, 62.879897935049875, 59.92603806086949, 63.18306868416922, 58.79268959590367, 60.46491949898856, 59.06908198765346, 66.43502017429897, 60.42633615221296, 66.09570489610944, 39.96979379653931, 37.66481924057007, 67.26462118966239, 58.703488622392925, 63.96290670122419, 62.1477176121303, 62.17471136365618, 59.41278852735247, 62.74447059631348, 59.319891112191335, 63.78767313276018, 60.37146622794015, 58.74354498726981, 45.293729373386924, 45.534814493996755, 43.406702859061106, 44.350407191685264, 44.55946806498936, 44.290048190525596, 46.860947677067344, 57.53737940107073, 60.117210796901155, 62.39198848179409, 53.04026208605085, 48.1898010798863, 46.76291901724679, 48.77187599454607, 53.36719914845058, 56.51810646057129, 59.26318686349051, 59.889747619628906, 60.535964829581125, 63.152288164411274, 59.32635988507952, 58.976240158081055, 58.94001225062779, 59.61666257040841, 61.23083332606724, 64.44761303492955, 60.151159695216585, 57.7215553011213, 55.895964758736746, 63.782677377973286, 57.124496596200125, 65.13299029214042, 33.586963176727295, 0.10376590410513536, 0.14532088142420563, 0.6919691434928349, 0.8596660335149083, 0.3862823322415352, 0.6757940628698894, 0.914205538375037, 10.514834863798958, 26.482516969953263, 57.08286993844168, 28.71326392037528, 14.865658726011004, 46.2506491797311, 44.04457180840628, 1.3487719339983804, 0.32191025785037447, 0.14883770128445967, 0.07815627580774681, 0.0559011516161263, 0.002436637911679489, 0.03144102270847984, 0.04280975480963077, 0.003761547933598714, 0.05223311683429139, 0.03360928136057087, 0.026562252447807362, 0.09582568731691156, 0.0678143436089158, 0.03444427637649434, 0.13677481428853103, 0.062312869887266836, 0.03555229013519628, 0.012557753611222973, 0.03145046452326434, 0.011370812659151852, 0.031177818974746124, 0.03128128877973982, 0.04031165349962456, 0.040504459225173504, 0.043026343187583346, 0.049409963323601654, 0.1509707575397832, 0.1133640669286251, 0.12065388076007366, 0.09414612994130168, 0.18424002160983427, 0.12438549766583101, 0.09696671180427074, 0.1583787314593792, 0.16947463820023195, 0.1646449209323951, 0.10368215931313378, 0.16404270753264427, 0.1984109676309994, 0.1643946636468172, 0.1467659574534212, 0.2154862199510847, 0.11715211080653326, 0.09368983549731118, 0.12892505978899343, 0.15187690034508705, 0.10888724893863712, 0.10264448249446494, 0.11391807720065117, 0.11777413742882864, 0.1374575969363962, 0.18876597232052258, 0.13096154694046291, 0.13465912852968487, 0.19251692747431143, 0.34727395113025394, 0.42784287354775835, 0.30243714419858797, 0.5795007699302265, 19.073807409831456, 75.40327548980713, 53.01314674104963, 49.86430651800973, 53.704763480595176, 72.71847765786308, 7.923082096236093, 0.3651664581682001, 0.487238952091762, 0.5578102309788976, 0.681123819734369, 4.271263948508671, 4.841931223869324, 2.3441035534654344, 0.15701072343758174, 0.28254105895757675, 23.57510927745274, 93.0359136036464, 62.94784436907087, 80.74000617436, 66.59004143306187, 74.72652094704765, 72.53178650992257, 77.50640487670898, 69.79100009373256, 67.36355658939907, 71.18894290924072, 75.9781972340175, 67.57223878587995, 68.10738904135567, 67.42545809064592, 69.83342579432896, 70.09130123683384, 66.45994336264474, 60.950341497148784, 58.538802419389995, 53.38695287704468, 55.96857690811157, 53.41062886374337, 52.091169425419395, 50.566776343754356, 51.81764316558838, 48.81595884050642, 50.438071387154714, 52.16828053338187, 55.534658432006836, 62.710202080862864, 66.19222927093506, 65.03635474613735, 67.68488992963518, 61.37357016972133, 63.2053793498448, 61.02996785300118, 68.73703479766846, 63.17031873975481, 67.732999256679, 43.46366419110979, 39.05772461209978, 67.15914058685303, 59.626522064208984, 65.169586454119, 63.12963703700474, 64.13718836648124, 62.07418482644217, 65.4309915815081, 63.192205565316335, 65.71962669917515, 62.305941990443635, 61.76630319867815, 48.73797920772007, 47.851462023598806, 46.46804094314575, 46.2175201688494, 46.991396631513325, 47.56011363438198, 51.14873661313738, 65.09704726082938, 64.70978941236223, 68.51068333217076, 56.11861630848476, 50.31788144792829, 49.76281418119158, 51.32688842500959, 55.76761416026524, 60.644773619515554, 60.32752582005092, 61.53838838849749, 62.26246016366141, 65.1635137285505, 62.60151835850307, 62.06137234824044, 58.15537302834647, 58.180546351841514, 64.5160527910505, 67.30777645111084, 60.9596312386649, 60.69365419660296, 57.981904302324565, 66.27014636993408, 57.30932215281895, 68.36196408952985, 30.121243408748082, 0.22541571142418043, 0.26182967317955835, 2.2163489801543097, 4.980209061077662, 1.5146907908575875, 0.6319207485233034, 0.7399046027234623, 10.582921998841421, 32.814834186008994, 68.41697297777448, 21.186864035470144, 31.97024938038417, 57.98015683037894, 54.823312282562256, 2.0337329506874084, 0.3796962813607284, 0.2091836202889681, 0.1653756895767791, 0.08709560826952968, 0.08662220117236887, 0.18128714577427932, 0.14561607129871845, 0.11367069690355233, 0.1942337839198964, 0.13198616196002277, 0.10449146838592631, 0.19851029158702918, 0.11351069156080484, 0.14151010662317276, 0.2250822793160166, 0.11162732262164354, 0.0921882985691939, 0.10982347798666783, 0.07045488977538687, 0.06252697482705116, 0.07177065738609859, 0.0896615766521011, 0.1979118101298809, 0.15508563816547394, 0.13162210078111716, 0.1297426266329629], [0.04472162900492549, 0.017203810957393477, 0.026994097578738416, 0.04416249918618372, 0.06328960069056068, 0.03020810422354511, 0.02469855932784932, 0.01699520893661039, 0.029426995066127608, 0.06244331145925181, 0.030599228771669523, 0.02752397575282625, 0.013545382535085082, 0.04766049987769552, 0.040206483964409144, 0.01191179421065109, 0.03581053717061877, 0.02012665822569813, 0.060995874128171375, 0.07563148771545716, 0.05078355229592749, 0.05586091109684535, 0.036668826293732436, 0.012547578978618341, 0.08759032136627606, 0.04983233440933483, 0.08170424042535679, 0.033167178476495404, 0.12188149988651276, 0.0749497635822211, 0.13839943068368094, 0.1679281618978296, 0.20333167644483702, 0.40604664598192486, 29.842408725193568, 49.65580497469221, 28.981728417532786, 15.38541351045881, 58.945334570748464, 56.30294854300362, 4.194913234029498, 0.3100943033184324, 0.3314062740121569, 0.017036226378487687, 0.06405798053102833, 0.22619461534278734, 0.6854504847100803, 0.3263756153838975, 0.10223051506493773, 0.08748102973082236, 26.103544848305837, 84.11753245762416, 51.89247873851231, 70.53756318773542, 67.18264634268624, 67.988783291408, 67.65734727042062, 71.08532442365373, 67.6706600189209, 68.82135118756975, 66.05935192108154, 71.60302775246757, 64.36275468553815, 68.14074734279087, 66.41723278590611, 64.45775045667375, 54.665056637355256, 51.7526844569615, 48.94676562717983, 52.009337016514365, 49.49573237555367, 49.42088985443115, 47.620865208762034, 46.29956797191075, 48.524749415261404, 47.65889269965035, 48.109333992004395, 45.341991560799734, 49.1915089743478, 60.81210708618164, 64.67254706791469, 64.36652755737305, 63.76903806413923, 60.87107644762312, 63.19941084725516, 60.54188469478062, 64.44808551243374, 60.97789805276053, 52.15100383758545, 29.86598743711199, 33.98781517573765, 73.78981345040458, 59.18240015847342, 67.06110150473458, 51.583349909101216, 58.41308866228376, 63.08411938803536, 65.13557502201625, 64.04351275307792, 63.364694595336914, 63.027588844299316, 53.21317843028477, 43.796701771872385, 43.74598339625767, 41.904627391270225, 44.04945986611502, 43.16994646617344, 43.64967788968767, 47.34371893746512, 58.901130131312776, 59.72647190093994, 60.24521051134382, 58.33859702519008, 56.27903631755284, 50.13513340268816, 49.048726967402864, 49.97376496451241, 55.12147338049752, 55.62816034044538, 61.295792034694124, 62.066771098545615, 62.04883084978376, 60.02083928244454, 59.68265656062535, 58.153913906642366, 61.97783415658133, 59.73742226191929, 60.36080074310303, 59.51436424255371, 63.46558938707624, 57.68855135781424, 51.55663755961827, 64.44907910483224, 37.06347349711827, 0.21901570127478667, 0.009427154187246092, 0.07592361061168568, 0.3940014008964811, 0.13007719867995807, 0.01352451164608023, 0.1087167195177504, 7.5967903477805, 16.235047919409617, 58.84707314627511, 52.54170451845442, 44.10833542687552, 33.074825354984824, 48.092199734279085, 8.101334656987872, 0.5551737695932388, 0.1129103848444564, 0.11314990770603929, 0.08550701529851981, 0.0515105889977089, 0.11096376287085669, 0.04207087088642376, 0.032419266644865274, 0.037258337517934184, 0.026400562641876082, 0.089869771551873, 0.03029277521584715, 0.01156672353057989, 0.05201288811596377, 0.008700774816263999, 0.02384921838529408, 0.026849021702738743, 0.07985477788107735, 0.05146667081862688, 0.09160507057926484, 0.12559056228825025, 0.03951574210077524, 0.055042635183781385, 0.015538835299334355, 0.11024638172239065, 0.06634734411324773, 0.030348089390567372, 0.04511925391852856, 0.044772369853620014, 0.006136108372759606, 0.043609676350440295, 0.039241179690829346, 0.026601539625387107, 0.04487898127575006, 0.03365907904558948, 0.0359270450259958, 0.0470508938389165, 0.011965713995907987, 0.016724928082632165, 0.04998048574530652, 0.02715521232624139, 0.015089170142476047, 0.04472666712743895, 0.011090894911571272, 0.024621092681107775, 0.0806416885129043, 0.056288313519741805, 0.045268012543341944, 0.05088439277772393, 0.03363781375810504, 0.02445766412919121, 0.05312930553087166, 0.012899100830379342, 0.08541830363018171, 0.052329546838466606, 0.05642699929220336, 0.04979246708431414, 0.0787572610591139, 0.06092641928366252, 0.2080496797072036, 0.5561194845608303, 44.8755589893886, 58.477456774030415, 27.088335616247996, 25.61016889980861, 87.81736482892717, 41.2491204398019, 9.472757935523987, 0.3501478454896382, 0.28374437295964783, 0.09114621805825404, 0.05915952766580241, 0.5945739096828869, 0.9404784142971039, 1.1805340072938373, 0.23692643376333372, 0.08958026101546628, 36.527343545641216, 85.43112414223808, 54.898971217019216, 75.79580007280622, 66.54647622789655, 69.48835045950753, 71.50378663199288, 72.26149463653564, 69.41729123251778, 69.3757757459368, 69.27246298108781, 70.6644650868007, 63.616386141095845, 70.65651634761265, 67.56841032845634, 64.57463305337089, 59.16117341177804, 53.91767018181937, 52.04014532906668, 54.23982688358852, 51.77023908070156, 50.4463849067688, 50.09471573148455, 47.494331564222065, 48.68614217213222, 49.959542001996724, 49.17571224485125, 46.10747807366507, 48.860264028821675, 63.257129532950266, 65.04228850773403, 64.477705683027, 64.3392697743007, 62.98649024963379, 61.74982207162039, 61.09775447845459, 65.95713697160993, 61.08625520978655, 58.44863564627511, 31.854742527008057, 34.45728063583374, 71.69486904144287, 57.677468981061665, 67.02863952091762, 55.552442346300396, 58.836963517325266, 61.161128997802734, 66.51889187949044, 63.728127070835654, 64.34671129499162, 63.33569976261684, 56.430850982666016, 46.13237346921648, 46.14028746741158, 45.39403009414673, 46.61831310817173, 44.53962400981358, 45.816355500902446, 48.285863399505615, 59.912968499319895, 59.96651826586042, 63.209603854588096, 60.89341490609305, 56.576638085501536, 51.20554855891636, 52.843061787741526, 51.747108527592246, 57.27167681285313, 58.05000707081386, 62.66811684199742, 63.70976298195975, 64.92652457101005, 58.779626982552664, 60.729180335998535, 58.275021008082796, 61.71554660797119, 60.353449548993794, 63.153170585632324, 58.7454696382795, 64.85032367706299, 58.63630649021694, 55.785474504743306, 63.48104912894112, 43.37714522225516, 0.5572339104754584, 0.03511245355808309, 0.051555128036332984, 0.4910341884408678, 0.10688533993171793, 0.11466913404209272, 0.16508128680288792, 13.283352409090314, 23.809308733258927, 52.53383220945086, 56.928769315992085, 25.09161615371704, 29.868811879839214, 55.339907373700825, 11.959297605923243, 0.6839647644332477, 0.09766071742134434, 0.08979746007493564, 0.10297678823449782, 0.049806417764297554, 0.061627162753471305, 0.04321411079061883, 0.09017669329685823, 0.044532429693000655, 0.04203585508678641, 0.05813871244234698, 0.0764534921784486, 0.06989097967743874, 0.0639899777514594, 0.046893924940377474, 0.019813799299299717, 0.028608189895749092, 0.04754029061379177, 0.017950570975829448, 0.02392440176169787, 0.015374767228162714, 0.05772338115743228, 0.034573184459337165, 0.03176772714193378, 0.055322069475161176, 0.03125522964234863, 0.014169585558452776, 0.1381112840026617, 0.11691405358059065, 0.15023500844836235, 0.17611745532069886, 0.14027980049805983, 0.11324949629072632, 0.08675849171621458, 0.18983873618500574, 0.1483572849205562, 0.2488002809030669, 0.08680742087640933, 0.12645264102944306, 0.08397960583014147, 0.1371698845177889, 0.154114288144878, 0.16902759218854563, 0.11708954987781388, 0.19078469542520388, 0.14087490285081522, 0.16734477105949605, 0.2552263875092779, 0.11058862121509654, 0.13557454012334347, 0.0776765447642122, 0.19789074840290205, 0.11407523948167052, 0.187235061611448, 0.15083794109523296, 0.13295515067875385, 0.1456446647644043, 0.19711944407650403, 0.23318776009338243, 0.3159479435001101, 0.6196502298116684, 56.37935093470982, 69.18888310023716, 42.16175242832729, 27.21378881590707, 74.015456199646, 73.52775519234794, 11.629377160753522, 0.6195111572742462, 0.3967827973621232, 0.1907473759991782, 0.31883492001465386, 3.055525481700897, 2.4618086431707655, 1.3075213474886758, 0.1944352409669331, 0.08428992025021996, 30.75648593902588, 92.1899356842041, 64.30877413068498, 79.66248648507255, 68.00239481244768, 71.10370935712541, 74.58579213278634, 74.68830585479736, 72.74703475407192, 72.37116500309536, 71.01718344007219, 71.71957683563232, 64.8115040915353, 71.02329785483224, 70.72561618259975, 69.06906141553605, 60.876106943402974, 56.71104403904506, 54.86088466644287, 58.61466979980469, 56.13637242998396, 54.40526001793997, 53.20891571044922, 51.40278707231794, 52.17136205945696, 52.71719169616699, 52.01664999553135, 49.42118515287127, 50.85228477205549, 66.38573660169328, 68.53961563110352, 67.17542021615165, 67.31148678915841, 66.41400882175991, 67.56668022700718, 63.60411562238421, 69.46706117902482, 60.832423618861604, 58.060623918260845, 34.796467372349326, 36.90552704674857, 72.82965578351701, 59.57934379577637, 70.64538533346993, 54.6150678225926, 61.808145250592915, 64.11580875941685, 69.33316939217704, 67.86584881373814, 68.63393742697579, 68.3295646395002, 58.97779655456543, 48.198576654706685, 48.350922857012065, 47.38451181139265, 50.85861458097185, 49.11089250019619, 49.15226207460676, 51.55416400091988, 62.284006527491975, 61.95521082196917, 65.77289853777204, 64.47891466958183, 63.50763988494873, 55.96943153653826, 56.82862145560128, 54.867113726479666, 60.116627148219514, 61.18098694937569, 67.94252218518938, 66.2291658946446, 65.48026125771659, 62.223140307835166, 60.998860767909456, 59.93751648494175, 62.99592590332031, 58.668038913181846, 62.64227649143764, 60.536694390433176, 67.17102200644356, 60.35606207166399, 56.94814089366368, 68.39841433933803, 41.88124670301165, 0.6268422667469297, 0.2058191586818014, 0.29467809626034325, 2.183684630053384, 0.27544027141162325, 0.15166090907795088, 0.19893231322722776, 12.259524055889674, 29.549385820116314, 72.43287890298026, 62.60236603873116, 49.43511281694685, 45.25054284504482, 63.39693423679897, 15.067357982907977, 1.0126705233539854, 0.26475956024868147, 0.21902188951415674, 0.22482254968157836, 0.12522331199475698, 0.14505931974521705, 0.1528018657118082, 0.22801732325128146, 0.16992571470992907, 0.20071462116071156, 0.13334412766354425, 0.16460176610520907, 0.1588642504066229, 0.14109648524650506, 0.17714901853884968, 0.13137636253876345, 0.08546132275036403, 0.2278234250843525, 0.12936532045049326, 0.23701667892081396, 0.16341285061623367, 0.13104792444833688, 0.11786588893405028, 0.11254012864083052, 0.22091694282633917, 0.12433828519923346, 0.1607412411166089], [0.021251314752069966, 0.015391430351883173, 0.04064736548545105, 0.04288174058975918, 0.03418531348662717, 0.13379394209810666, 0.10052682219871453, 0.013998104492202401, 0.030400584252285104, 0.06656569668224879, 0.037202198923166306, 0.06706719512918166, 0.04658913379535079, 0.05884588163878236, 0.02545495793622519, 0.01987440774350294, 0.0425968780182302, 0.00471739936619997, 0.03426698874682188, 0.035833888953285556, 0.05354472163266369, 0.018655965803191066, 0.012442041338155312, 0.015633694494941404, 0.056516738941094706, 0.06912564645920481, 0.05407618757869516, 0.08669914025813341, 0.0445643378022526, 0.09433303241218839, 0.08912488937910114, 0.06170948262193373, 0.027774801311482276, 0.07392195944807359, 0.909773184784821, 38.17172506877354, 42.340849195207866, 36.59464727129255, 17.327200514929636, 60.32548304966518, 63.48095185416085, 14.130306550434657, 1.8486416254724776, 0.05060377783541169, 0.1293066136006798, 0.08024783286132983, 0.911774320261819, 1.203648709825107, 0.43044641241431236, 0.10598728526383638, 0.1711543516388961, 29.251217773982457, 91.12684045519147, 53.73905978884016, 62.94306400844029, 69.26277024405343, 73.1030604498727, 67.2217994417463, 70.75948865073067, 72.42197717939104, 71.98133632114956, 67.22823347364152, 72.34181581224713, 66.70605550493512, 62.70767988477434, 61.738232476370676, 57.12018871307373, 52.21476745605469, 51.91809327261788, 49.04446077346802, 46.97469663619995, 48.8228132384164, 48.2601237978254, 45.381676197052, 50.258557728358674, 47.022197995867046, 48.96919788633074, 45.13820437022618, 47.12953724179949, 60.265672956194194, 66.20685522896903, 61.964118412562776, 70.95511518205915, 62.76382827758789, 66.64034639086042, 58.66240392412458, 66.66303225925991, 47.565675667354036, 54.5432790347508, 39.4803592136928, 35.30904293060303, 72.98073046548026, 56.23836851119995, 58.19054480961391, 52.71453053610665, 69.43074989318848, 59.18964712960379, 66.65346458980015, 58.45747375488281, 62.49106979370117, 51.34964724949428, 45.35922309330532, 42.877621855054585, 46.04075799669538, 45.3566244670323, 45.18203708103725, 43.39698927743094, 46.33320072719029, 51.258709226335796, 58.71612739562988, 60.88598033360073, 65.51812199183873, 61.411257198878694, 59.089620862688335, 54.9364150592259, 51.03294835771833, 49.89020592825753, 53.79053551810128, 58.960530281066895, 56.81035464150565, 59.72379684448242, 63.6845132282802, 63.87386553628104, 61.457024982997346, 64.09694440024239, 59.30538327353341, 61.72394003186907, 67.30725533621651, 64.62252003805978, 55.10469000680106, 69.13488864898682, 68.6267113004412, 35.48600312641689, 1.2592633941343852, 0.07091792885746274, 0.050752271831567795, 0.23349562500204357, 0.20127300119825772, 0.015861198805006485, 0.17863936642450945, 10.403690610613141, 13.42575226511274, 67.99081911359514, 31.649496214730398, 62.350139481680735, 61.81391225542341, 42.85056904384068, 32.75971760068621, 0.11878679666135993, 0.025202978868037462, 0.1168043887508767, 0.02937378774264029, 0.08146147416638476, 0.04903951373749545, 0.07558932354939835, 0.035395497655762095, 0.044863368184970956, 0.009259902938668216, 0.04707223715792809, 0.037489487257386954, 0.05106541234999895, 0.04765376881031053, 0.048874626335288794, 0.10826881855194058, 0.039821876745138846, 0.06526356084006173, 0.10113656733717237, 0.05384228298706668, 0.0221936353482306, 0.07911444189293043, 0.06629967024283749, 0.032277934585830996, 0.06329761418913092, 0.011269008657628936, 0.023553645138495734, 0.048332805944872756, 0.04776868210839374, 0.02899845948975001, 0.017013430994536196, 0.01734605903870293, 0.022191781251292144, 0.04211835476702877, 0.027196697957281555, 0.008392880221695771, 0.03986444463953376, 0.06104762599404369, 0.008823654963634908, 0.01763069090832557, 0.07966676939811025, 0.013115135354122944, 0.053035664305623086, 0.008125623937563171, 0.03656143116365586, 0.024303960680429424, 0.01633043121546507, 0.04267699943323221, 0.026042828802019358, 0.04723001690581441, 0.09455048931496483, 0.07941831701568194, 0.04538002171154533, 0.06732229036944253, 0.07500097262007849, 0.040658856475991864, 0.03455566807783075, 0.0999298674453582, 0.0883292934990355, 0.043806855234184434, 0.06688176507928542, 0.129208307447178, 3.808139588151659, 56.408262389046804, 44.21599081584385, 20.12814964566912, 32.87630489894322, 93.10600008283342, 49.53834915161133, 15.962697642190115, 2.0074835249355862, 0.1132775197869965, 0.1360997940812792, 0.1624196653387376, 0.7161273243171828, 0.33559701485293253, 0.5954044908285141, 0.49787289862121853, 0.08600598280983311, 42.36161388669695, 94.07698999132428, 57.92487696238926, 68.1636347089495, 70.19622598375592, 72.25735351017543, 71.54142502376011, 72.88346263340541, 76.01114559173584, 71.8834570475987, 66.17580372946603, 72.9962180001395, 67.76499571119035, 65.68348217010498, 65.40743718828473, 59.72308118002755, 53.88468708310808, 52.87956762313843, 50.65346901757376, 51.847541264125276, 51.531561510903494, 49.59318780899048, 48.31043222972325, 50.40663078853062, 47.834894044058665, 49.975064277648926, 47.7219614982605, 52.04509939466204, 63.62462670462472, 67.79072489057268, 64.68087795802525, 70.2897070475987, 64.08659853254045, 64.99523530687604, 58.808656556265696, 66.15787042890275, 50.162498882838655, 54.062897954668315, 36.052937916346956, 35.55460616520473, 71.16978672572544, 57.417630672454834, 60.822348730904714, 51.96313149588448, 66.88412393842424, 61.34353310721261, 67.94013200487409, 62.5253244127546, 63.342752184186665, 56.44564369746617, 48.233699798583984, 44.706161907741, 46.682792391095845, 46.63849762507847, 46.462287834712434, 44.63094070979527, 46.97896630423409, 53.53717293058123, 60.69771194458008, 64.00888293130058, 65.81959738050188, 61.89858300345284, 59.083617619105745, 55.868995325905935, 52.348023482731406, 51.6836575780596, 56.23130219323294, 60.76578344617571, 59.39966338021414, 61.595968110220774, 63.5848274230957, 64.53812026977539, 62.26286315917969, 63.68406854357038, 62.04455075945173, 59.8085926600865, 63.9840361731393, 65.27194731576103, 55.792460918426514, 66.25258827209473, 69.95317104884556, 41.27621841430664, 2.0547603709357123, 0.049648994247296026, 0.19318805289055618, 0.18513385578989983, 0.15601865095751627, 0.03313899213182075, 0.3460598077092852, 18.59404993057251, 17.115521907806396, 54.437180042266846, 53.42163481031145, 63.91333825247628, 60.684725761413574, 42.51094804491316, 42.58180577414376, 0.11796286515891552, 0.06226796443973269, 0.1079975131100842, 0.09995203518441745, 0.07557793773178544, 0.08774372456329209, 0.05684017622843385, 0.09861375378178698, 0.043889242956148725, 0.017924968153238297, 0.028631107416003942, 0.06114089063235691, 0.044062666328889985, 0.10790075401642493, 0.030866795485573154, 0.03674056101590395, 0.035379857423582246, 0.08587009260164839, 0.08638723806611129, 0.021642668305763176, 0.06946430328701224, 0.04361688917768853, 0.029700861977679387, 0.043852367970560274, 0.05022276345906513, 0.011906286202637213, 0.03807022163112249, 0.021492522076836655, 0.1587689569486039, 0.0725845397849168, 0.08166855626872607, 0.14305150748363563, 0.13830415079636232, 0.325076519378594, 0.1729156928403037, 0.109804818273655, 0.18940623796411923, 0.15343907794782094, 0.10831709631851741, 0.1746791782123702, 0.22044257899480207, 0.18912128039768764, 0.17982201224991254, 0.0582068780703204, 0.10567770366157804, 0.16973875117089066, 0.06828528762395893, 0.08848604187369347, 0.15812300518155098, 0.2606952169111797, 0.10358844684170825, 0.16089920406895025, 0.12166401584233556, 0.16141991184226104, 0.20715022725718363, 0.26009669474193026, 0.16659961747271673, 0.21436460156525883, 0.19984419643878937, 0.2876684223966939, 0.1604764767523323, 0.144825903698802, 3.2137073022978644, 71.43927260807583, 60.66010134560721, 49.9486472266061, 30.772807257516043, 70.62513133457729, 80.76515170506069, 26.203074319022043, 3.4954630519662584, 0.1328798604330846, 0.15703698274280342, 0.22744510109935487, 4.4921728031975885, 2.9282394775322507, 1.2101835991655077, 0.3828910413597311, 0.2586469096796853, 33.31435407911028, 99.67392376491001, 64.78981181553432, 72.72965730939592, 69.65352998461042, 76.53447001320976, 73.18741852896554, 75.54793698447091, 75.82139723641532, 74.01866626739502, 65.50532341003418, 76.36578164781842, 70.2767972946167, 68.50354058401925, 65.31489413125175, 61.47729982648577, 57.419690813337056, 57.27402877807617, 54.22385992322649, 53.54390573501587, 54.047410420009065, 52.682704312460764, 50.95110900061471, 52.96656254359654, 51.788287026541575, 53.39137193134853, 52.36250352859497, 53.72489936011178, 67.66877705710274, 69.39805861881801, 66.39398411342076, 71.74975981031145, 66.84500558035714, 66.70858464922223, 60.57893248966762, 65.47675936562675, 53.343842778887065, 58.570840563092915, 40.53698566981724, 39.1739957673209, 70.12043503352574, 59.45507526397705, 60.5426698412214, 55.51043006352016, 68.89270918709892, 63.718635831560405, 70.22397708892822, 63.9461406980242, 65.36285754612514, 56.331311089651926, 49.242150919778005, 48.532135350363596, 50.28685079302107, 50.77103253773281, 49.325605733054026, 48.15216963631766, 51.2148973601205, 55.78344215665545, 65.6710101536342, 66.36676107134137, 70.63230882372174, 65.44234493800572, 61.19700949532645, 57.36675248827253, 55.04880217143467, 53.37412650244576, 60.245967864990234, 63.49728012084961, 59.499154635838096, 62.562393052237375, 67.56449154445103, 66.2652062007359, 62.63763509477888, 63.435149329049246, 62.61940996987479, 61.94901997702462, 65.56315326690674, 64.73298249925885, 57.200763498033794, 70.19192504882812, 70.04002353123256, 38.51575122560774, 2.4797189278262, 0.17588832761560166, 0.31894248138581005, 1.6606324911117554, 0.9532434493303299, 0.18972877279988357, 0.34288667940667694, 17.4800226688385, 24.794547660010203, 79.23609638214111, 42.999628748212544, 65.82524626595634, 69.35359014783586, 53.576881885528564, 50.19047580446516, 0.1738954566951309, 0.10807939871613469, 0.1518490668386221, 0.15238915357206548, 0.17767782802028315, 0.12360677016632897, 0.16324589028954506, 0.23544950730034284, 0.08920429833233356, 0.0904449453311307, 0.1412779933639935, 0.17729308509400912, 0.13116019485252245, 0.21572970545717648, 0.19119611834841116, 0.22148600300507887, 0.20440408747111047, 0.16685543874544756, 0.2007710209914616, 0.12364554165729455, 0.12619365778352531, 0.18586936060871395, 0.12659722327121667, 0.15214323891060694, 0.19744995848408767, 0.12142842848386083, 0.10728888506335871, 0.11658908958945956], [0.030415033655507222, 0.04840696982241102, 0.03118828877008387, 0.021608595669801747, 0.020993313685591732, 0.04193427500181964, 0.04985684309420841, 0.0317885004915297, 0.007790981492559824, 0.03165565012022853, 0.009371010503465576, 0.06176697489406381, 0.004293613110868526, 0.030253935871379714, 0.07724753421332155, 0.05127220946763243, 0.009458417688230318, 0.03157796125326838, 0.05475699568965605, 0.009323164454794355, 0.0029482654021454175, 0.10571505701435463, 0.020946789932038103, 0.03642423816823533, 0.06554808414408139, 0.07423283026686736, 0.03826593827190144, 0.04067071048276765, 0.05339752703106829, 0.0017262850077323882, 0.060102474210517745, 0.08703679285411324, 0.05026657307254417, 0.07538598696035997, 0.17121700756251812, 0.9522166358573096, 43.41492257799421, 54.65482194083077, 37.40115247453962, 15.452091898236956, 52.057290009089876, 76.68148694719586, 32.28941835675921, 5.52081104687282, 0.1168430923883404, 0.1067697379205908, 0.14386967143842153, 0.49876612211976734, 1.3736598385231835, 0.42854005470871925, 0.2071378372077431, 0.17284637370279857, 19.315090554101126, 79.25181320735386, 64.79085404532296, 56.46747146333967, 65.29882294791085, 74.70555128370012, 70.34084578922817, 66.70001057216099, 68.07751873561314, 71.9841433933803, 67.61274678366524, 68.45719609941754, 66.5200800214495, 56.99196318217686, 52.56172922679356, 51.52519696099417, 50.43402058737618, 48.666815757751465, 53.95266825812203, 50.891184261866975, 46.53079359872, 48.234721183776855, 50.751768657139365, 50.96267080307007, 50.96665906906128, 46.74380104882376, 45.75415522711617, 53.740042958940776, 69.0505931036813, 64.72653457096645, 68.27237401689801, 63.755106925964355, 66.60145037514823, 57.65171548298427, 60.62183066776821, 51.95579767227173, 78.01042025429862, 37.07346848079136, 29.203441960471018, 79.49590342385429, 55.251984868730815, 64.83223751613072, 65.35007980891636, 66.20522240230015, 62.07704053606306, 62.75087683541434, 55.43552500861031, 51.84209387642996, 43.57142727715628, 47.42696877888271, 43.84567962374006, 47.84324925286429, 45.24771840231759, 47.61461183003017, 48.410795484270366, 50.13873951775687, 50.0832963671003, 59.63873699733189, 61.34971005575997, 63.54818957192557, 63.52382918766567, 62.81866346086775, 60.41514260428292, 56.1006760597229, 52.817495891026084, 56.4404742377145, 59.02132701873779, 63.26370252881731, 61.60718250274658, 62.56567260197231, 64.15576090131486, 63.35992118290493, 59.1316922051566, 65.91943604605538, 64.19337844848633, 56.98564379555838, 68.89614159720284, 76.26252446855817, 54.67572907039097, 17.463847262518748, 0.13967894416834625, 0.059816302066402774, 0.07406715237136398, 0.09504593522953135, 0.07760548179170915, 0.058991223839776855, 0.2425650597683021, 11.648092133658272, 18.906515632356914, 60.015002795628135, 37.29621730531965, 11.436241558619908, 23.152542420795985, 35.81975984573364, 42.665427344185964, 0.39231220153825624, 0.08399025204458407, 0.032582956432764015, 0.020935597496905496, 0.0432245161251298, 0.023773505751575743, 0.08725209201553039, 0.051842083888394494, 0.02200801530852914, 0.014426680780681116, 0.03265418903902173, 0.06413975078612566, 0.052988506121827025, 0.015672939264082482, 0.021167010168677995, 0.039985101736549816, 0.01393679206791733, 0.02404423274232873, 0.0019384008857222007, 0.0706508167620216, 0.04721906874328852, 0.039369975815394094, 0.04980882317093866, 0.04971750932080405, 0.0018124609695015742, 0.025462281025413955, 0.030796743530247892, 0.03476512844541243, 0.008861307719988483, 0.015783455655244843, 0.03516304173639842, 0.05277174471744469, 0.017450689138578515, 0.05205446195655635, 0.04492327943444252, 0.03094441649903144, 0.043527811100440364, 0.02464194406223084, 0.007292544086729842, 0.032811883970030715, 0.05677090798105512, 0.07270265237561294, 0.034926548533673794, 0.03852917932506118, 0.09605551391307797, 0.03218251220615847, 0.07374120450445584, 0.09043870959430933, 0.04845079639926553, 0.046402719869677506, 0.07305887647505317, 0.011597696109674871, 0.0920661079830357, 0.08087656340960946, 0.050620944771383486, 0.007990680285729468, 0.03138484000893576, 0.022513211771313633, 0.07326943267668996, 0.04210017342120409, 0.037825928668358495, 0.049306116931672604, 0.0630675908178091, 0.13524929114750453, 5.574124574661255, 62.18031855991909, 52.052850110190256, 19.506652389253887, 26.425586904798234, 87.08865860530308, 70.98623616354806, 32.48197031021118, 8.914164458002363, 0.4521031603217125, 0.423313028046063, 0.17328374380511896, 0.14840293675661087, 0.5019905748111861, 0.2999188021889755, 0.19983969096626553, 0.1357099757130657, 30.168029103960308, 87.43401186806815, 67.82987798963273, 60.92728737422398, 68.97612231118339, 74.86587401798793, 72.39692892347063, 67.39856856209892, 69.41687434060233, 72.0347957611084, 70.3182294028146, 72.14350727626255, 67.97451863970075, 57.35868215560913, 54.05567530223301, 53.53613764899117, 52.82886661802019, 51.568522453308105, 53.73269871303013, 49.4960172516959, 48.131415367126465, 49.725387709481375, 51.40485416139875, 52.7941186768668, 52.32764789036342, 47.052374022347585, 46.68287924357823, 56.42216573442732, 68.59392275129045, 66.6129218510219, 70.2440573828561, 64.80774511609758, 65.86314868927002, 57.7391550881522, 63.46991811479841, 49.08902651923043, 74.26410443442208, 38.71661669867379, 31.623534270695277, 75.65411240713937, 56.37121112006051, 63.53283405303955, 67.9167652130127, 69.27137906210763, 62.22335570199149, 66.01190962110246, 59.074202810014995, 55.13269124712263, 45.48291839872088, 47.52039425713675, 45.86273125239781, 49.55878380366734, 47.08425235748291, 49.389223439352854, 47.19664641789028, 50.621375288282124, 51.2598626273019, 61.76015404292515, 60.93691757747105, 64.69423239571708, 63.27927344185965, 65.26716000693185, 60.75539588928223, 56.4710602079119, 55.418456758771626, 57.85839312417166, 59.88348729269845, 66.65893977028983, 63.05749389103481, 64.77300412314278, 62.62514918191092, 63.7051146371024, 58.90967641557966, 64.88924748556954, 63.46816716875349, 59.799344607761924, 67.25408772059849, 74.42374624524797, 62.37928022657122, 22.811380658830913, 0.22345406668526785, 0.036978570744395256, 0.133809019146221, 0.07507101779005357, 0.1416048165410757, 0.03511804129396166, 0.46587264431374414, 17.6210606779371, 20.039619173322404, 50.2981207711356, 61.18724727630615, 10.954612408365522, 29.42786530085972, 40.302647250039236, 52.8602203641619, 2.345609358378819, 0.07570529196943555, 0.018236590449565222, 0.08225889530565057, 0.018816507188603282, 0.025266520279858793, 0.014355487190186977, 0.039528932821537764, 0.03797762534980263, 0.05328053402315293, 0.049298133967178207, 0.03973117018384593, 0.019923197804018855, 0.04562975652515888, 0.014604955678805709, 0.03317708169509258, 0.03137168660759926, 0.027867251707773124, 0.023834134551829526, 0.04981186979317239, 0.0068983241466672295, 0.023086621359522854, 0.06132222233074052, 0.051860044710338116, 0.02476432972720691, 0.004917232594120183, 0.02003503733846758, 0.03139283315145543, 0.06833790122930493, 0.10984580857413155, 0.18475306193743432, 0.11707189439662866, 0.16004372068813869, 0.1273389027587005, 0.146677680047495, 0.1411519894110305, 0.13432690421385424, 0.11697637023670332, 0.09040470141917467, 0.07966220285743475, 0.19815932613398346, 0.18212928915662424, 0.11421775897698742, 0.26894338003226687, 0.1874016419585262, 0.12274108161883694, 0.17163940918232712, 0.1569363831409386, 0.09849559369363955, 0.10177467523940972, 0.17844362264232977, 0.22442885009305819, 0.09860001344765935, 0.139862026487078, 0.15845790292535508, 0.08805150804775101, 0.11284694182021276, 0.11677135766616889, 0.1903044961925064, 0.12704048305749893, 0.13501181746167795, 0.12345244416168757, 0.22259962824838503, 0.2858845538326672, 5.547298882688795, 80.44720908573696, 71.0984912599836, 49.9924521446228, 27.808155093874248, 66.8513353892735, 91.15357712336949, 49.76163993562971, 9.663085596902029, 0.35907793630446705, 0.49338517657348085, 0.31445695779153277, 2.1547497255461554, 3.7304826123373847, 1.4576338125126702, 0.5248984055859702, 0.2648786838565554, 24.425820657185145, 87.17837374550956, 74.91576903206962, 67.80098737989152, 68.84062549046108, 75.17342908041817, 73.86206081935337, 68.53384862627301, 68.40224279676164, 71.90383611406598, 72.80615697588239, 73.07094587598527, 70.50489970615932, 63.62707247052874, 57.81671782902309, 56.10242005756923, 56.6494517326355, 55.139667238507954, 59.68501894814627, 54.17553172792707, 52.43303121839251, 52.518525327954976, 58.779911858694895, 56.89672074999128, 56.25556182861328, 50.12375920159476, 49.273511614118306, 58.57925483158657, 70.6292724609375, 69.43202836172921, 73.31047807421002, 68.42369188581193, 67.06447138105119, 59.66110324859619, 63.90575081961495, 53.244174344199045, 74.03817680903843, 39.435352257319856, 33.26029361997332, 80.31969574519566, 59.769780022757395, 65.36587306431362, 69.88979652949742, 70.11960819789341, 65.95111288343156, 67.36165973118374, 59.98149858202253, 55.96979979106358, 48.127281188964844, 51.399736813136506, 48.11010176794869, 53.364902768816265, 49.65810830252511, 52.80523232051304, 52.76485981260027, 55.34350306647164, 54.6020746912275, 63.730211530412944, 64.57250690460205, 67.61638763972691, 65.24356392451695, 70.05780397142682, 66.64282689775739, 61.77751759120396, 57.47540494373867, 62.97181565420968, 63.65314211164202, 71.4196092060634, 66.41719804491315, 66.36284228733608, 66.36960288456508, 64.55710969652448, 60.852045331682476, 64.20812252589634, 61.923249108450754, 58.29220390319824, 69.98430592673165, 75.56930964333671, 59.441519328526084, 20.621238980974468, 0.3489690673138414, 0.1341280663119895, 0.24288874811359815, 0.6626218525426728, 0.44257916137576103, 0.1147104703954288, 0.5478224126355988, 18.84789194379534, 31.33870676585606, 69.51898506709507, 49.914882455553325, 18.031252792903356, 35.82919897351946, 47.17090334211077, 63.263000760759624, 2.878798919064658, 0.22841548760022434, 0.17288788647523948, 0.14281427807041577, 0.11660935064511639, 0.08418540550129754, 0.12748500491891587, 0.13436742632516793, 0.21955053614718573, 0.10220997580992323, 0.1453148696039404, 0.15079733755971703, 0.08115984499454498, 0.16300283904586518, 0.11101177600877625, 0.11870063628469195, 0.13858961047870771, 0.15736335808677332, 0.16538601687976293, 0.1228751465678215, 0.14093964866229466, 0.135466530919075, 0.16898249675120625, 0.16075240980301583, 0.13281792375658238, 0.15610820400927747, 0.12276928153421197, 0.10825089165674788, 0.14990291983953544], [0.02032398638714637, 0.02530005687315549, 0.028466966402317797, 0.017280419257336428, 0.04733269961018648, 0.04413082517151322, 0.07354729955217668, 0.040457334968128374, 0.012963867846078106, 0.06565846143556492, 0.027433286154908792, 0.02812413319147059, 0.04156416468322277, 0.014828738224293505, 0.0035733749058895876, 0.048932491801679134, 0.014017502112048013, 0.07507814240774938, 0.04235238488763571, 0.0405546640312033, 0.0592477915010282, 0.06681625930858509, 0.02059327488365982, 0.08095015053238187, 0.06615971560989108, 0.007677548248986048, 0.05465476760374648, 0.05690565825040851, 0.012603775248862803, 0.011477350290598614, 0.015095553460663982, 0.0270625821181706, 0.05537276961175459, 0.026193073418523585, 0.021579659543931484, 0.08004086610994168, 5.299697654587882, 56.88334894180298, 59.701152665274485, 47.78542981828962, 18.176656007766724, 36.93077680042812, 77.37009511675153, 50.06157977240426, 6.991367748805454, 0.7154322873268808, 0.11293293934847627, 0.029539211187511683, 0.5251586916191238, 0.37898960070950644, 0.16225794330239296, 0.10439588315784931, 0.24398922334824288, 8.465831075395856, 62.83695111955915, 70.7409439086914, 59.370286396571565, 55.313135964529856, 65.40456063406808, 74.87960365840367, 72.61148929595947, 68.17753110613141, 71.43855694362095, 65.55639266967773, 64.06539957863944, 60.37705257960728, 62.21631022862026, 59.56553772517613, 56.790090220315115, 51.29526717322213, 51.01165212903704, 47.48830400194441, 47.573950971875874, 49.61538035529, 54.57380247116089, 54.31091390337263, 54.79572098595755, 48.944385869162424, 47.977912289755686, 45.38585901260376, 53.90312760216849, 61.5413761138916, 66.95223018101284, 62.43749918256487, 68.88819285801479, 62.42545100620815, 71.97199099404472, 62.77770383017403, 66.4967896597726, 39.756630011967246, 30.241648742130824, 80.38766997201103, 61.59176445007324, 71.08756869179862, 61.03132275172642, 66.22899913787842, 56.792473452431814, 57.30806105477469, 49.53023018155779, 49.92810835157122, 47.92941386359078, 50.10703141348702, 48.84518643787929, 50.40253482546125, 50.65942709786551, 54.75881215504238, 58.4421877179827, 63.083987372262136, 61.403009687151226, 64.18401227678571, 63.23903642381941, 68.32051113673619, 62.61839553288051, 65.10267530168805, 62.046489306858604, 59.965045247759136, 59.39375046321324, 64.48620332990373, 62.56303923470633, 59.901948656354634, 62.15975884028843, 67.14530672345842, 66.12623528071812, 64.20893546513149, 68.8874146597726, 57.73995065689087, 53.26148230688912, 67.04603086199079, 62.16537993294852, 27.20763271195548, 1.553503862449101, 0.33316777806196896, 0.07102916110306978, 0.05647315663684692, 0.0686782408239586, 0.05068085262817996, 0.025133546075916717, 0.039957671958420954, 9.146214314869471, 38.94233587809971, 62.02056557791573, 31.75765187399728, 14.769697155271258, 38.32532889502389, 47.98849787030901, 42.46640314374651, 2.63322091954095, 0.0761442973411509, 0.08334053440817765, 0.02663669961371592, 0.02732552122324705, 0.005681502208712378, 0.03520934496607099, 0.027506595078323568, 0.01803950486438615, 0.07899575933281865, 0.017501957548250045, 0.05588287188272391, 0.04164815714050617, 0.092813080043665, 0.0293768445428993, 0.0522779408576233, 0.020250210970906273, 0.026050416519865394, 0.004990412595881415, 0.05057566952226417, 0.03825909185356327, 0.12358277716806956, 0.027540479420817325, 0.041790910730404515, 0.03261482382991484, 0.1224194560199976, 0.07759930033768926, 0.03863882379872458, 0.021631117943408232, 0.011641895032620855, 0.018837114297119633, 0.0684933875288282, 0.08837727949555431, 0.021010053144501786, 0.05946222213762147, 0.018741612189582417, 0.031173164224518195, 0.028308542046163763, 0.03065977105870843, 0.08481825475714036, 0.025809550158945576, 0.05982211711151259, 0.031249231392783777, 0.024809811929506913, 0.042953546558107646, 0.013964907166415026, 0.04416294701929603, 0.10339013819715806, 0.008849272205095206, 0.023482207275394882, 0.0041722011436442176, 0.016730303776317408, 0.053490069029586654, 0.01304703503514507, 0.027888003004980937, 0.02320972627161869, 0.03416948665731719, 0.040883929934352636, 0.03583541565707751, 0.05231054785794445, 0.056186774146876166, 0.017196301271074584, 0.07773314815546785, 0.05242757818528584, 0.05724346012409244, 0.10386823397129774, 11.517894182886396, 72.73978083474296, 56.239914485386436, 24.68917301722935, 22.98964885302952, 70.91049385070801, 83.08698953901018, 40.27341617856707, 12.182445083345685, 2.147594600915909, 0.322018742029156, 0.058598270639777184, 0.25457768089004923, 0.5028783700295857, 0.20977070235780307, 0.1861701008996793, 0.2889346773070948, 14.53988982949938, 75.83275754111153, 72.68454960414341, 60.106038093566895, 61.0708441053118, 67.34450462886265, 74.20264761788505, 69.50759696960449, 68.79604584830147, 72.45984486171177, 69.40601430620465, 66.97174072265625, 62.39509432656424, 63.650633811950684, 58.05264391217913, 55.87147235870361, 52.209267956869944, 51.47003173828125, 52.227166516440256, 50.03965473175049, 51.71052973611014, 55.97761651447841, 55.01823009763445, 55.99857228142874, 51.113196577344624, 50.914999212537495, 48.33124555860247, 59.72713197980608, 65.52550792694092, 68.10643713814872, 64.1461237498692, 68.11099515642438, 60.81917340414864, 68.34508691515241, 64.3989964893886, 68.0975364957537, 37.06696496691023, 30.74563980102539, 77.18537725721086, 62.14889185769217, 72.28306184496198, 62.82329790932791, 66.69479942321777, 60.13488006591797, 59.89506299155099, 51.81467628479004, 51.04368679864066, 49.22249099186489, 51.10327802385603, 47.1091616494315, 49.94561781202044, 49.54887914657593, 54.195942061288015, 57.603609630039756, 60.120941979544504, 61.04389899117606, 65.1427594593593, 65.51220907483781, 67.84257929665702, 60.54740851266043, 65.55713612692696, 63.18065071105957, 61.5455241884504, 59.38483592442104, 65.02709974561418, 64.29428018842424, 63.11643545968192, 64.10733890533447, 67.73507676805768, 65.96394620622907, 63.28333118983677, 66.97440188271659, 60.5096242087228, 51.6718247958592, 63.65163435254778, 66.27157075064522, 35.72123786381313, 2.4228963426181247, 0.5876941074218068, 0.0033836804754433353, 0.10575169790536165, 0.01719175508644964, 0.03230308787897229, 0.2923283294907638, 0.5754212545497077, 15.89100091797965, 36.50259753635952, 62.18503638676235, 54.05918066842215, 14.002612556729998, 30.560251440320695, 45.91823346274239, 54.68836089542934, 5.831458926200867, 0.09755638587687697, 0.0687762348513518, 0.040426655007260184, 0.06879897255982671, 0.029951336394463266, 0.022678119529570853, 0.04101990835208978, 0.06009965829019036, 0.0471205284952053, 0.01147651145168181, 0.07485235988029412, 0.03903139362643872, 0.02909782755055598, 0.06974514893123082, 0.06792329597686018, 0.018045486150575534, 0.0031227108182585134, 0.024441991666597978, 0.0746666652017406, 0.038012627578739605, 0.010683240402223808, 0.02007130842788943, 0.030931748250233274, 0.027692267704488974, 0.05082935680236135, 0.014694953171004142, 0.058840494070734294, 0.04412383286814604, 0.06833782659045287, 0.21391815266438893, 0.1318132576665708, 0.1385590356907674, 0.12085113088999476, 0.15511366166174412, 0.08274713517831904, 0.10855964544628348, 0.12921484852475779, 0.09666419375155653, 0.1986270538930382, 0.09627487071390663, 0.16234985765601906, 0.1643278550888811, 0.14893239763166222, 0.1398058980703354, 0.20245392354471342, 0.08948850272489445, 0.18955337149756296, 0.14072692793394836, 0.10261175675051552, 0.12000973389617034, 0.23110118348683628, 0.1066460409866912, 0.24382477360112326, 0.09442205620663506, 0.11920117799724851, 0.13066875907991612, 0.15087154214935644, 0.09655076983783926, 0.07572934603584663, 0.15873968494789942, 0.11514841046716486, 0.1752359161951712, 0.14328142228935445, 0.22167186731738703, 0.21984613314270973, 10.479282668658666, 85.80657005310059, 75.31759030478341, 60.71411664145333, 31.97438703264509, 55.68641056333269, 91.05783789498466, 65.6435022354126, 14.996217114584786, 1.487112630690847, 0.34353088055338177, 0.14424734402980122, 0.8780185601540974, 3.483110023396356, 0.5407095743077142, 0.18256437938128198, 0.28413314638393267, 10.55951612336295, 70.7962098802839, 76.54308577946254, 70.32327379499162, 61.62923608507429, 67.53844969613212, 73.65024498530796, 71.06869738442558, 68.60392815726144, 76.60847527640206, 70.83620371137346, 70.25340965815953, 64.54104546138218, 67.41926029750279, 63.745851925441194, 61.743881361825125, 55.384865692683626, 55.5332271030971, 54.39622041157314, 52.12114742824009, 56.150046484810964, 60.153911181858604, 58.98047855922154, 62.479369027274, 56.60667862210955, 54.415922028677805, 50.6854897907802, 59.90240723746163, 68.60999393463135, 72.41668960026333, 65.87598896026611, 71.17818014962333, 64.43234089442662, 70.24132674080985, 63.50084454672677, 65.63380949837821, 42.46474947248186, 33.93231643949236, 77.73997552054269, 66.07787581852504, 73.50968292781285, 65.20794745853969, 70.51619052886963, 61.63902609688895, 60.76381015777588, 54.179460934230256, 52.26390164239066, 52.66515316282, 52.701853547777446, 52.169968945639475, 52.229323932102744, 52.91888747896467, 59.304841314043315, 62.31906018938337, 65.67128113337925, 65.60446725572858, 71.07583318437848, 71.00486428397042, 73.47717925480434, 64.7248044695173, 67.45611354282924, 66.61263697487968, 64.95378930228097, 64.25537722451347, 69.24526078360421, 67.19033799852643, 62.860019138881135, 66.62551198686872, 71.99148763929094, 67.79776341574532, 63.057250704084126, 66.67983300345284, 60.19607285090855, 54.1372332572937, 65.83461243765694, 65.40552643367222, 31.711415086473735, 2.0132036294255937, 0.5652559857283319, 0.19597770034202508, 0.3011281415820122, 0.20030501671135426, 0.14530095963605813, 0.6132240689226559, 0.4301142016691821, 16.668657200677053, 50.8501238822937, 68.3401745387486, 45.90334694726126, 23.90134804589408, 49.438711983816965, 58.981201171875, 66.65169279915946, 6.620589290346418, 0.28680369736892836, 0.18627606092819146, 0.09398652493421521, 0.11424365187329905, 0.1298192468072687, 0.18599285398210796, 0.20959676669112273, 0.14157869294285774, 0.20487922483256885, 0.10866012969719512, 0.189151312357613, 0.11943652108311653, 0.13996907217161997, 0.1569649087531226, 0.13816522753664426, 0.11296382626252514, 0.13685228941696032, 0.11320154422095843, 0.11328226953212704, 0.1903020263250385, 0.24043196280087742, 0.14221693655209883, 0.2416398636996746, 0.09791743436029979, 0.3008849003485271, 0.10907060267137629, 0.14531343110970088, 0.13595213129052094, 0.0993462594758187], [0.11866094198610101, 0.019870679193575467, 0.016429025746349777, 0.0359171044879726, 0.03987816122493573, 0.10786793327757291, 0.05367357882538012, 0.05823047751826899, 0.006272564309516123, 0.04201196726145489, 0.12007614890379564, 0.045103345665016344, 0.05333187198266387, 0.07670162564941815, 0.002491820408197652, 0.06227705002363239, 0.040516102886093516, 0.05367582816896694, 0.04983597135703478, 0.06571267638355494, 0.014330116765839713, 0.030310339094804864, 0.02041171587604497, 0.041812593316925425, 0.005088219177975718, 0.022341411793604493, 0.035422119977218766, 0.05176903959363699, 0.010626728613195675, 0.039717172006411214, 0.05432130156883171, 0.0870352050821696, 0.022913971516702856, 0.0406604951380619, 0.03083754044824413, 0.030708717182278633, 0.14968246381197656, 3.504696990762438, 41.73894412176949, 61.81011159079415, 49.7469653402056, 22.709881373814174, 26.448472533907207, 75.07242311750139, 68.87315000806535, 22.285193579537527, 4.222449379307883, 0.09734639964465584, 0.09295095157410417, 0.07471091925565686, 0.2735374149467264, 0.18182765319943428, 0.07785303850791284, 0.19164794124662876, 1.102990699665887, 33.98742955071585, 64.20780290876115, 76.38730716705322, 69.38869244711739, 62.88593591962542, 69.8692854472569, 75.9086388179234, 65.74836444854736, 67.67580168587821, 68.43829699925014, 64.88163920811245, 68.24765232631138, 62.30134228297642, 63.954186711992534, 66.4147870200021, 62.96514538356236, 53.71593270983015, 49.3826539175851, 53.64181974955967, 59.97072887420654, 58.641781670706614, 62.0862260546003, 54.119004658290315, 50.28216075897217, 51.08598395756313, 49.29890033176967, 50.82692732129778, 61.24776608603341, 62.599670137677876, 68.70858887263707, 63.97782448359898, 70.99344144548688, 59.38850457327706, 74.96458707536969, 35.82066658564976, 25.64015211377825, 85.71051815577916, 59.51218945639474, 69.51940890720913, 60.04972294398716, 59.53648035866873, 53.611567292894634, 55.60579408918108, 48.55394227164132, 54.311639990125386, 52.31161492211478, 56.4412385395595, 57.27497025898525, 58.243243421827046, 54.8046007837568, 60.49820137023926, 60.63765866415841, 65.42877510615757, 63.44168758392334, 65.72048132760185, 63.954186711992534, 66.70564556121826, 65.50797762189592, 69.13993304116386, 66.35235050746373, 65.21889781951904, 62.17550345829555, 64.91463620322091, 65.20450115203857, 72.68482058388847, 65.14277335575649, 64.86728422982353, 66.01612022944859, 66.8789336340768, 52.62926571709769, 65.82175827026367, 67.81724616459438, 43.215707302093506, 6.779189739908491, 0.06290318856814078, 0.03313442898382034, 0.4333345288676875, 0.015717559726908803, 0.021765038703701327, 0.0692124989415918, 0.14370775941227162, 0.712578857583659, 15.578938211713519, 52.05618177141462, 53.987478733062744, 22.14134849820818, 27.642113992146083, 46.121304988861084, 45.70327009473528, 34.09762798036848, 1.5323001316615512, 0.09765383707625525, 0.019776257653055445, 0.02938364346378616, 0.044416233963732205, 0.11502289505941526, 0.03738204802253416, 0.03114531036200268, 0.03274181165865489, 0.05423565687877791, 0.06275740531938416, 0.07370080452944551, 0.12059890585286276, 0.06898647892688002, 0.07564212714454957, 0.11450104734727315, 0.02786237304098904, 0.05053913380418505, 0.05667220827724252, 0.017132983775809407, 0.04142980117883001, 0.07473979770605053, 0.07066555454262666, 0.010602270818448492, 0.046445131701018126, 0.06805827016276972, 0.015191330374883754, 0.058251864942056794, 0.04130535785640989, 0.0194257128917213, 0.032318395628992996, 0.12697636149823666, 0.026843472982623746, 0.01575878242562924, 0.022545552446639965, 0.03322301512317998, 0.053008926633213244, 0.03289037011563778, 0.01858441428547459, 0.06676353035228592, 0.058313170580991676, 0.05962261424532958, 0.04940742560263191, 0.062377805688551495, 0.060450603387185504, 0.01668439240061811, 0.09372539073228836, 0.03302117809653282, 0.01958035271880882, 0.030563734604844024, 0.03957005882901805, 0.004439062605212841, 0.038903221754091125, 0.019314555284966315, 0.047029964426266294, 0.04322281639490809, 0.037567237192498784, 0.01484120121624853, 0.017365339611257826, 0.030920664380703653, 0.04463132277929357, 0.024657826870679855, 0.052371208888611624, 0.05112986299874527, 0.03548986830615571, 0.07318721458848033, 0.07729673478752375, 0.1316346943910633, 8.758911303111486, 59.022494316101074, 65.97851657867432, 33.741102014269146, 18.091703857694352, 52.55649375915527, 85.670975957598, 56.72928653444563, 21.766458443232946, 7.280877905232566, 0.266666623630694, 0.17356553939836367, 0.07531782811773674, 0.2230220977216959, 0.25887758444462505, 0.29687834105321337, 0.38660420211298124, 3.1081546119281223, 45.392286096300396, 74.42507335117885, 74.40022659301758, 66.58965233394078, 63.49556391579764, 71.89758968353271, 73.29599108014787, 68.05759825025285, 70.30990546090263, 70.35374859401158, 65.21282509395054, 67.71556622641427, 64.00333132062639, 67.77601555415562, 68.65656770978654, 62.20180933816092, 52.27353184563773, 51.26844712666103, 53.9059624671936, 60.99209322248186, 61.18028518131801, 61.672724860055105, 53.07226201466152, 51.615735462733674, 50.61618150983538, 51.772156783512656, 54.43417147227696, 65.68521921975272, 64.83161912645612, 70.70986461639404, 65.09788799285889, 70.93784890856061, 59.207913943699424, 69.60753290993827, 38.279700074877056, 29.126077243259974, 84.11537156786237, 60.55970682416643, 71.1700507572719, 62.848992347717285, 62.270818846566335, 54.78330455507551, 58.094729151044575, 50.54607766015189, 54.48893369947161, 51.4321015221732, 56.93006862912859, 57.602511814662385, 60.671468598502024, 57.50315604891096, 60.402156421116416, 61.99967234475272, 67.43212836129325, 65.40981347220284, 66.40551117488316, 65.0976448059082, 66.48854909624372, 65.09605366843087, 67.99268817901611, 68.37141363961356, 66.44848578316825, 65.13875729697091, 65.5968381336757, 65.67463711329869, 71.23314040047782, 66.13257898603166, 67.63518946511405, 64.47730268750871, 68.74173177991594, 58.838693618774414, 63.68217168535505, 69.26110962459019, 53.36643137250628, 10.883446352822439, 0.0800708302163652, 0.24058126764638083, 0.447280404823167, 0.14425992406904697, 0.07958357421947376, 0.06924376583525113, 0.03525654046929308, 1.4975107184478214, 16.088208164487565, 41.3996844291687, 70.91369697025844, 39.8643479347229, 22.264606067112513, 38.34466920580183, 48.331353255680625, 45.92719316482544, 4.19766993182046, 0.13362038641103677, 0.03554611885920167, 0.027203785255551338, 0.02736008070808436, 0.006563763125866119, 0.023379836697131395, 0.05677576968446374, 0.04544389221285071, 0.050951303115912845, 0.02110198276516582, 0.081929547978299, 0.11747300358755247, 0.06158275942185095, 0.03187359896089349, 0.03926117272515382, 0.020464085208784257, 0.036562398076057434, 0.04421049875340291, 0.0334896827781839, 0.01263893099634775, 0.05081227807594197, 0.017700457878943, 0.03966940314109836, 0.015156942220138652, 0.01599917890104864, 0.06401840836874076, 0.036197563367230554, 0.07328961230814457, 0.029331769461610487, 0.015370670572987624, 0.26989360047238214, 0.16604784636625222, 0.0629415800794959, 0.12921893330557005, 0.09415027579026562, 0.20227731445005961, 0.15526200298752102, 0.10441150981932878, 0.1260516946869237, 0.10762729761855942, 0.19676918429987772, 0.1227576243025916, 0.1253371566001858, 0.23260549562317984, 0.13597341014870576, 0.17365574384374277, 0.1442848534456321, 0.199772285297513, 0.2207253109663725, 0.18237452528306416, 0.16029441223612853, 0.06797286295997244, 0.11922423461718218, 0.1119502510077187, 0.22870345786213875, 0.1322058987404619, 0.09479083998927049, 0.21161110645958356, 0.10790236892976932, 0.09439939992236239, 0.13638608157634735, 0.2094915666218315, 0.08008470625749656, 0.0958822974935174, 0.11480079697711126, 0.18077297907854828, 0.22414370253682137, 6.883975088596344, 69.87555272238595, 84.20614283425468, 61.38823086874825, 35.375394753047395, 44.452438013894216, 88.83146830967495, 82.40121623447963, 35.04364953722273, 9.244772774832589, 0.2846913907144751, 0.21097264571913651, 0.3180036874754088, 1.293231291430337, 1.4608833981411797, 0.3684175637151514, 0.30826071170823915, 2.239895773785455, 38.82933732441494, 71.48529052734375, 80.80058751787458, 74.29662200382778, 63.47941630227225, 71.33002608163017, 73.43026501791817, 69.69970771244594, 73.70523997715541, 73.42097527640206, 70.69405746459961, 73.50607681274414, 66.84439413888114, 70.71009390694755, 72.95730113983154, 69.01586600712368, 59.503914151872905, 54.96048361914498, 57.75956194741385, 65.93699414389474, 64.4057570866176, 67.06997435433524, 57.74729142870222, 53.824772766658235, 54.31758417401995, 53.85810674939837, 56.84945910317557, 67.30400357927594, 69.04131031036377, 76.02704307011196, 71.1490671975272, 73.43514265332902, 61.229457582746235, 73.92265605926514, 38.54280056272234, 30.92232206889561, 89.06738744463239, 64.32113497597831, 76.14073644365583, 66.86967168535504, 63.34175859178816, 59.03382682800293, 64.05813871111188, 54.44273165294102, 58.44663456508091, 57.31591599328177, 62.948302950177876, 63.41692420414516, 65.59191186087472, 62.212669372558594, 66.62831905909947, 65.38107572283063, 70.8837502343314, 68.73934159960065, 68.21009036472866, 68.19055203029087, 69.25806631360734, 67.78323473249162, 73.65708201272147, 75.17198385511125, 72.18525205339704, 69.99899441855294, 68.6347851072039, 71.72170298440116, 80.26714651925224, 68.65790176391602, 67.94216087886265, 67.13439110347203, 68.40790557861328, 61.63802555629185, 70.38888563428605, 69.02105631147111, 47.540266105106895, 8.786667619432722, 0.17468319513968059, 0.19975111500493117, 0.8797883966139385, 0.24422635776656015, 0.2754572076456887, 0.30908779161317007, 0.4986011566860335, 1.4391574668032783, 25.142562082835607, 62.04104886736189, 62.82388850620815, 36.35148811340332, 37.62346356255667, 55.44077784674508, 60.114167485918315, 51.44694287436349, 3.822962701320648, 0.3532155565917492, 0.08201392380786793, 0.11888654130910124, 0.11681339969592434, 0.2301355738724981, 0.10414827215884413, 0.18987517351550715, 0.20045096959386552, 0.1846427321434021, 0.1459834708699158, 0.11943407835704939, 0.2087194887655122, 0.15609571896493435, 0.3009903175490243, 0.18597363787037985, 0.281106635928154, 0.17251869557159288, 0.25182584140981945, 0.1381430530122348, 0.16793306092066423, 0.3269164620765618, 0.17722591012716293, 0.09940653374152524, 0.09035388593162809, 0.10281307130519833, 0.11328128565635, 0.13954996823200158, 0.2510339096188545, 0.1118241927719542, 0.09549489470997027], [0.03209275220121656, 0.05152102825897081, 0.04281123062329633, 0.10618414184344666, 0.01862160478984671, 0.02053246966430119, 0.07235045877418347, 0.03217894311196037, 0.0845906605411853, 0.04177149445084589, 0.01820842276460358, 0.08885475780282702, 0.04449629091790744, 0.045334200241736004, 0.09007564586188112, 0.02612699258939496, 0.07155982977045433, 0.062245620281568596, 0.12578916948820862, 0.04557616582938603, 0.030473991563277583, 0.033224853953080516, 0.022521243929596882, 0.04622232454961964, 0.07956195609377963, 0.030580507990505015, 0.07807948599968638, 0.06890748388000897, 0.014841389509716203, 0.038550583712224445, 0.06418732966163329, 0.05709318497351237, 0.06632436213216611, 0.03783891582861543, 0.03856015444866248, 0.06525269070906298, 0.014111946553124912, 0.15725853799709252, 0.931446733219283, 30.741991996765137, 58.489400727408274, 51.46030078615461, 27.41316216332572, 21.839021955217632, 46.10083212171282, 60.53741700308663, 54.351282937186106, 18.139502252851212, 0.5173089642609868, 0.23407539246337755, 0.09167797916701861, 0.2022204396447965, 0.54424137622118, 0.35151395361338345, 0.064715311330344, 0.0680167098928775, 6.172933791364942, 37.84777225766863, 70.22085734776088, 92.84117644173759, 77.96901593889508, 66.36825493403843, 74.15800544193813, 77.68698160988944, 65.74049908774239, 66.687100819179, 68.84162603105817, 71.61422824859619, 68.39664949689592, 65.81094687325614, 64.44177654811314, 59.97309820992606, 52.35192837033953, 57.96932111467634, 65.4223827634539, 63.65027945382254, 63.40796102796282, 56.942453793116975, 57.6333201272147, 54.97462667737688, 57.60789319447109, 54.330375807625906, 53.50363745008196, 56.86915724618094, 67.19865499223981, 64.14670739855084, 73.42735372270856, 66.59296662466866, 68.69098908560616, 34.011845520564485, 33.825077942439485, 74.98019967760358, 62.96624319893973, 68.5807420185634, 59.62822437286377, 59.678230558122905, 54.81226117270333, 55.574968406132285, 56.921727316720144, 56.88994625636509, 60.03973838261196, 62.40259838104248, 59.03579316820417, 59.393493379865376, 60.30619485037667, 61.65927314758301, 64.39050579071045, 69.39912169320243, 69.44254793439592, 67.8016335623605, 67.7249949319022, 71.05103506360734, 67.24135167258126, 64.50995227268764, 64.94672298431396, 67.8045518057687, 67.6714312689645, 69.46897193363735, 69.08847468239921, 64.77326120649064, 64.39655767168317, 70.88374328613281, 60.630752154758994, 56.693746498652864, 68.6097160066877, 50.89200414930071, 16.800900527409144, 0.2496122159063816, 0.356828972697258, 0.20832459495535918, 0.21122763917914458, 0.29515678914529936, 0.09052740769194705, 0.19269272232694284, 0.01741873353187527, 2.0826949519770483, 32.06269863673619, 65.54669298444475, 38.18416581835066, 15.781224591391426, 27.444107702800206, 47.033867495400564, 51.66693673815046, 26.27669048309326, 0.7717619304146085, 0.16646437187279972, 0.030927049395229136, 0.05009308523897614, 0.0393379930672901, 0.03967043451432671, 0.041022866764771085, 0.059009462861078124, 0.09919457297239985, 0.037587684845285754, 0.0213798920490912, 0.05375043987961752, 0.009646152212683643, 0.03691880198727761, 0.011887586625692035, 0.011800287158361502, 0.0849911861919931, 0.058200642333499024, 0.054834101016500165, 0.043171173094638755, 0.04658997178609882, 0.05798497676317181, 0.006170333255015845, 0.024959717278501818, 0.03769775340333581, 0.04267354568998728, 0.0750771788880229, 0.028841758612543344, 0.03384977113455534, 0.051650682730334144, 0.023805934636454498, 0.03274752153083682, 0.04180952973131623, 0.0656638965010643, 0.05163957511207887, 0.01770107025679733, 0.022440980022240962, 0.03284337478024619, 0.02026204631796905, 0.04788100001003061, 0.03960038934435163, 0.020819946291989515, 0.020638093817979097, 0.05229984736070037, 0.060481775285942216, 0.05016339164493339, 0.09186849822955472, 0.012456753673697156, 0.03912557428702712, 0.013245764371406819, 0.07031750000481095, 0.051826311341886006, 0.007174445914902857, 0.1618888202522482, 0.02819950825401715, 0.08499622770718165, 0.017242066761744872, 0.020486432759623443, 0.07047403124826294, 0.02060192959782268, 0.07652276381850243, 0.016399592593578354, 0.09053863744650568, 0.053630719160927195, 0.020175158212493573, 0.029105634095945528, 0.13094480069620268, 0.053852362624768696, 0.08897368463554553, 0.12870847141104086, 3.899607411452702, 47.31248331069946, 69.18092741285051, 44.80111946378435, 19.10077510561262, 41.3543370110648, 75.34053325653076, 70.89792455945695, 46.74344321659633, 20.202550956181117, 1.7476377253021513, 0.17305750665920122, 0.1496698566313301, 0.23932079385433877, 0.32832447652305874, 0.41479890633906635, 0.28197939481054035, 0.04385861049273184, 10.517214621816363, 50.61837714059012, 79.38516303471157, 89.17832238333565, 73.69577653067452, 67.5494556427002, 75.88598769051688, 78.0073491505214, 67.52119037083217, 70.34202003479004, 74.52764960697719, 71.85851301465715, 68.90546607971191, 67.83979306902204, 65.88222844260079, 65.00091893332345, 55.08665248325893, 59.64576162610735, 67.01762662615094, 64.02063928331647, 63.74355207170759, 60.74204839978899, 57.191709995269775, 55.86658777509417, 58.71671799251011, 54.08814076014927, 56.6549060685294, 60.666889735630576, 68.03946345193046, 64.2440516608102, 72.43029417310441, 66.1567656653268, 68.27894701276506, 35.21026733943394, 33.272314003535676, 76.18015357426235, 66.13682433537075, 68.84535721370152, 61.52832044873919, 59.9974308013916, 57.14334011077881, 56.95667328153338, 55.12543385369437, 58.358031136649, 60.664687156677246, 61.52284526824951, 60.124638421194895, 58.72332572937012, 57.91717488425118, 60.79383332388741, 64.07430716923305, 68.87822914123535, 69.02070890154157, 68.74816581181118, 70.34482015882219, 69.72656944819859, 66.24167265210832, 65.65428583962577, 68.00803674970354, 66.84215681893485, 67.03343377794538, 68.01479734693254, 70.34584849221366, 65.19135516030448, 66.81047998155866, 71.80326788766044, 64.63605512891496, 55.65200655800955, 65.99123178209577, 59.57705783843994, 25.167339359010967, 0.7189106749636787, 0.5453408743653978, 0.5862744493143899, 0.32854882734162466, 0.31502000615000725, 0.05083876808307, 0.18536351275231155, 0.08110935520380735, 2.658370141472135, 27.644632714135305, 64.55959715162004, 62.13064588819231, 25.09319165774754, 17.34131404331752, 48.67476102284023, 56.04298864092146, 40.68039301463536, 2.5318186921732764, 0.16616536863148212, 0.008849502058832772, 0.046051113201039176, 0.02285010101539748, 0.08612909620361668, 0.05983765556343964, 0.11119966914079019, 0.1239218275461878, 0.06830269204718725, 0.02428429843192654, 0.02581196913628706, 0.11907054643545832, 0.03859565879351326, 0.06104027067444154, 0.03861302589731557, 0.05641349305265716, 0.0047229290025175685, 0.05860667090330805, 0.09415833000093699, 0.02060701182511236, 0.02990662432940943, 0.03970412038532751, 0.03848344945747938, 0.09217126734022583, 0.04470719317240374, 0.03370217280462384, 0.03395991093878235, 0.015886275762958185, 0.03284861646326525, 0.022833709305684482, 0.026381495807852064, 0.10666388645768166, 0.14706432287182125, 0.07924419135919639, 0.11615075596741267, 0.1374994082642453, 0.08227356523275375, 0.1538160177213805, 0.10470168532005378, 0.16582809601511272, 0.10228858409183365, 0.13049267924257688, 0.14840797148644924, 0.1291086577943393, 0.16430270858108997, 0.1547929724412305, 0.09310518936919314, 0.06924077349581889, 0.1265310932482992, 0.2665225299341338, 0.16451472363301686, 0.119703972446067, 0.24479008466005325, 0.13234649119632586, 0.16003339338515485, 0.13644520911787236, 0.11573959088751248, 0.11026830518884317, 0.166217140853405, 0.11292489870850529, 0.11625415113355432, 0.15559329092502594, 0.14750219509005547, 0.1683234085461923, 0.05520210448386414, 0.3263685857611043, 0.13227850198745728, 0.3373122699558735, 0.21706063832555497, 3.0449353413922444, 53.34254346575056, 87.73506341661725, 64.8098921094622, 40.35680498395647, 39.90290348870413, 62.00732231140137, 69.7004233769008, 68.58101299830845, 31.108172484806605, 1.5587392215217863, 0.4590237832495144, 0.3097467305404799, 1.2747572255986077, 1.048548849565642, 0.9367181360721588, 0.21666355963264192, 0.20093020530683653, 7.470426934106009, 42.27843700136457, 75.63135010855538, 94.06091185978481, 77.61409500667027, 66.67924240657261, 79.45387377057756, 82.4268411908831, 71.6392765045166, 71.48601313999721, 73.72204766954694, 76.1006383895874, 72.41375051225934, 70.04642282213483, 70.0602775301252, 70.50463567461286, 56.47106715611049, 63.51460197993687, 70.42197295597622, 71.09555912017822, 69.43779536655971, 68.02842276436942, 64.12423692430768, 61.78556360517229, 63.55904265812465, 60.50394753047398, 59.41651970999581, 63.318002700805664, 69.93072836739677, 69.267397744315, 74.96559456416539, 70.51361274719238, 67.96811934879848, 40.66769518171038, 44.15079239436558, 72.52610983167375, 70.1379861831665, 68.70284966060093, 64.3323563167027, 64.9365508215768, 61.59243147713797, 58.06715522493635, 60.730097498212544, 60.433902740478516, 65.16980184827531, 64.93695381709507, 63.50686168670654, 61.85628931862967, 63.72838415418352, 64.27297701154436, 68.90542439052037, 74.27532577514648, 77.39135660443986, 74.22702189854213, 76.48673588888985, 76.02895382472447, 69.22460378919328, 66.31159932272774, 69.36536039624895, 70.05376706804547, 70.06532192230225, 73.36184610639299, 69.47371060507638, 62.25033555712019, 69.03468867710659, 73.97387817927769, 64.90843841007778, 64.96548312050956, 73.5065701348441, 53.68540927342006, 20.202577011925833, 0.5730089268514088, 0.4459826116050993, 0.4377658782260758, 0.8478388424430574, 0.9663451462984085, 0.5359057635068893, 0.6301445066928864, 0.31155749623264584, 4.671042450836726, 43.95453705106463, 74.46157223837716, 46.32785408837454, 24.764232669557842, 38.39817728315081, 58.18521901539394, 69.89017173222133, 45.093336377825054, 1.9608170347554343, 0.34461040262665066, 0.25603729113936424, 0.12490011219467435, 0.09030258189886808, 0.18773340487054416, 0.17865261142807348, 0.19677288910107954, 0.19870600822780812, 0.16357044715966496, 0.1437971903277295, 0.1848924330302647, 0.1916903361145939, 0.18004421889781952, 0.14647078114960874, 0.17194088229111262, 0.18828605807253293, 0.17454907590789454, 0.11082706520599978, 0.14392831043473311, 0.19308591979954923, 0.16843874592866215, 0.10180670209228992, 0.09959394511367593, 0.18098234784390244, 0.14730681771678583, 0.20664007748876298, 0.08820744896573679, 0.06451135727443866, 0.16086400167218276, 0.14227614551782608, 0.09238802535193306], [0.05642487208491989, 0.010102428845129907, 0.028842996938952377, 0.008214360202795692, 0.06958364402609211, 0.03306840413383075, 0.03740218694188765, 0.0438455283375723, 0.012317045857863767, 0.06683320232800075, 0.08870110354785408, 0.03810129853497658, 0.07886643734361444, 0.03782779124698468, 0.06328601802566222, 0.07655120122113399, 0.11724843563778059, 0.03243076102808118, 0.018404758568587046, 0.01287121813012553, 0.004870517154423786, 0.048281091398426464, 0.07800192944705486, 0.06373100129089185, 0.12758185900747776, 0.07202400200601135, 0.08156347833573818, 0.016642821952700615, 0.12408391599144254, 0.11002252623438835, 0.041924348034496815, 0.009085996957894946, 0.06717854951109205, 0.04680318105965853, 0.10671094964657511, 0.02543665954310979, 0.1547414037798132, 0.08896131494215556, 0.1557522445384945, 0.27033472965870586, 22.183079378945486, 47.08176837648664, 55.30638231549944, 28.294084310531616, 25.324085508074077, 37.76529366629464, 57.609776156289236, 73.53066648755754, 29.75392689023699, 3.2562532935823714, 0.09526783653667995, 0.2121153665440423, 0.4417572111955711, 0.5634575965149062, 0.08344669799719538, 0.6602173415677888, 0.1878509678478752, 0.11312685787145581, 1.5490228171859468, 24.554873023714336, 65.11327130453927, 91.99242619105748, 72.19332586015973, 71.39517933981759, 79.21072850908551, 73.3825169972011, 72.40774726867676, 66.1247900554112, 66.17126655578613, 73.67878123692104, 74.20684432983398, 66.74991253444126, 57.49661431993757, 60.627055713108604, 68.630859375, 67.62560789925712, 68.15030111585344, 60.19729573386056, 59.555740765162874, 60.88604286738804, 61.565347399030415, 65.07567460196358, 64.79764243534633, 63.98907361711775, 63.32094178880964, 66.69738415309361, 65.4326730455671, 69.4327231815883, 63.8768949508667, 42.93286003385271, 48.41078158787319, 69.18368584769112, 72.2356959751674, 70.19257123129708, 69.06590693337577, 61.536310877118794, 62.98674038478306, 61.534330640520366, 63.83021000453404, 67.40601703098842, 67.38030869620187, 65.72835363660539, 65.01984582628522, 63.11592129298619, 64.91139139447893, 63.83144678388323, 64.65430109841483, 68.23999541146415, 69.59985515049526, 67.15407535008022, 67.76623249053955, 69.06884602137974, 67.26683071681431, 72.46293681008476, 71.68133395058769, 68.26634992871965, 64.01320471082414, 67.28363840920585, 66.84060737064907, 68.84820597512382, 65.36087730952671, 49.45238951274327, 64.97009672437395, 57.96733740397862, 30.47319746017456, 1.0036514358861106, 0.5577194701348032, 0.037423662575227876, 0.7245570634092603, 0.3928888477385044, 0.6641543103115899, 0.5265617934720856, 0.05339139985984989, 0.03921738686040044, 9.84595697266715, 49.7184499331883, 52.33891439437866, 23.186960322516306, 19.645734480449132, 43.10276780809675, 46.766521658216206, 55.19509996686663, 18.372263431549072, 0.11009825074246951, 0.046580160169729164, 0.03036663035995194, 0.06660811869161469, 0.06813432715301003, 0.039480522740632296, 0.043566762403185876, 0.11677827872335911, 0.08439253510109015, 0.04530994261481932, 0.07045604328491858, 0.05433838029525109, 0.059923320609544, 0.09284119853483778, 0.02761886378617159, 0.12117726196135793, 0.03415601095184684, 0.02050969294006271, 0.04666559112125209, 0.032023022550025156, 0.041647553244339566, 0.09129868487694434, 0.005259061573139791, 0.03958914262641754, 0.07324517504977328, 0.07942681905946561, 0.04483378405815788, 0.04634043714031577, 0.02591876037019704, 0.07124779187142849, 0.04804553118135248, 0.018574185370068465, 0.04060541166524802, 0.0781140641442367, 0.09910366285060133, 0.044994861486234834, 0.02322227747312614, 0.07526319247803517, 0.038176581995295625, 0.03026726229914597, 0.05125330548201289, 0.018471772383366312, 0.024353605695068836, 0.08927621625896011, 0.08917379139789514, 0.07060101229165282, 0.024799094468887364, 0.03544252352522952, 0.06716695334762335, 0.04070920038170048, 0.04168439091050199, 0.030698488266872506, 0.01918298564851284, 0.054424944400255165, 0.04262748673292143, 0.022442488066319908, 0.041719355820012946, 0.04556827785979424, 0.02372083447075316, 0.018791326754061238, 0.029389309231191874, 0.07057480726923261, 0.08083919648613248, 0.04302230251154729, 0.042991035617887974, 0.04240449298439281, 0.0073803448218054, 0.01970215993268149, 0.07529405225068331, 0.07127101812511683, 0.08372626121022872, 0.147212039945381, 1.0661599274192537, 34.91189432144165, 63.56048093523298, 53.3279835156032, 20.152148723602295, 22.905167443411692, 53.33980587550572, 85.01790087563651, 71.95621858324323, 25.45313787460327, 4.361227052552359, 0.12132002572928156, 0.16920994168945722, 0.35402228044612066, 0.02903318012665425, 0.22028547099658422, 0.28237234801054, 0.696961912725653, 0.1236873801265444, 4.874272916998182, 36.550338608878, 74.83910260881696, 88.15625626700265, 73.03947748456682, 73.63782855442592, 78.8026191166469, 71.39016274043492, 71.04294736044747, 70.07755075182233, 69.57867009299142, 77.11971678052629, 75.13330323355538, 66.23710073743547, 59.767987387520925, 63.666628565107075, 70.08283833095005, 72.37112331390381, 69.65239742824009, 61.34055233001709, 61.36503083365304, 62.48214830671038, 62.100907598223, 64.83073670523507, 62.430703844342915, 62.09369536808559, 66.24880845206124, 67.40327944074357, 69.67397853306362, 67.73520183563232, 62.575358390808105, 42.84959977013724, 48.773824964250835, 69.53250626155308, 68.05229677472795, 70.64344678606305, 68.0085231236049, 61.020580836704795, 61.5156260899135, 60.768444606236045, 63.990039416721885, 65.6810086114066, 65.63140542166573, 66.68851825169155, 65.97648075648716, 65.8873770577567, 65.9464020047869, 65.19145243508476, 66.1981143951416, 68.95522212982178, 71.29691096714565, 69.66912174224854, 67.90858718327114, 67.39471231188092, 68.51720074244908, 70.90574823107038, 69.94552803039551, 71.45485741751534, 69.43290383475167, 70.0685041972569, 69.60014002663749, 70.95793615068708, 66.70882088797433, 53.97565289906093, 61.361000878470286, 63.538462093898225, 42.86804028919765, 3.060776148523603, 0.3696514389344624, 0.2658192962408066, 0.8749489220125335, 0.5888891432966504, 0.6689556783863476, 0.3515427777809756, 0.2297402322292328, 0.1937468671905143, 7.893292563302176, 48.94741528374808, 72.97882665906633, 44.94030925205776, 14.113480619021825, 21.71731730869838, 48.838276454380576, 60.048618180411204, 30.971418040139334, 0.8346697262355259, 0.16580722427793912, 0.010289697724926685, 0.0624507957005075, 0.08857707413179533, 0.03161254618316889, 0.05964057506727321, 0.03079726260953716, 0.05564316242401089, 0.02511531044729054, 0.038169979849564176, 0.06505490453647715, 0.06747858412563801, 0.08575704866754157, 0.01142242712168289, 0.07211727342967476, 0.06411963222282273, 0.04700083491791572, 0.07743610588035413, 0.010951625598993684, 0.0454630235077015, 0.09375640656799078, 0.02032773190044931, 0.02223765870024051, 0.006795461206430835, 0.03241273235263569, 0.03977748019886868, 0.024953050671943595, 0.046154657644884925, 0.02214086059081767, 0.008913521837842251, 0.015687683830037713, 0.06009668630680867, 0.24681111478379794, 0.16256495325693063, 0.14862327064786637, 0.19763891691608088, 0.17953123285302094, 0.08581350278109312, 0.10209149681031704, 0.15031880752316543, 0.08650550671986171, 0.10521606914699078, 0.14177708301161016, 0.19549626617559365, 0.17048778597797665, 0.1394197709326233, 0.15708481946161815, 0.1459748941872801, 0.1475033350288868, 0.09708686000002281, 0.07256910989859275, 0.0843274500221014, 0.14259682116763933, 0.10825452860444784, 0.11522819261465754, 0.11351023694234234, 0.1802619065025023, 0.19338936065988882, 0.12560722710830824, 0.17398416836346897, 0.1850062504942928, 0.1162975366626467, 0.15165322806153977, 0.11548296894345965, 0.16789879490222248, 0.14817853165524347, 0.20773086324334145, 0.1114469680136868, 0.2174754946359566, 0.174007564250912, 0.29959041838135037, 0.7004990886364664, 37.328161648341585, 77.90556498936245, 73.84938730512346, 40.667368616376606, 40.836949825286865, 52.32800572259085, 69.79046508244106, 89.42649119240897, 44.75076239449637, 6.650858248983111, 0.23042061286313192, 0.40533412992954254, 1.117319187947682, 1.1732129944222314, 0.2485620065459183, 1.0796837274517332, 0.46954623290470665, 0.07670695214931454, 3.0597855959619795, 27.420410871505737, 66.86035415104458, 95.23428889683315, 73.20579651423863, 72.23728711264474, 81.81353759765625, 78.84639276776994, 77.15313066755022, 73.14775126320976, 70.78585706438336, 81.966675894601, 81.68402317592076, 70.92620372772217, 66.05197988237653, 68.60809707641602, 75.85103130340576, 77.52275398799351, 73.65657479422433, 63.519597734723774, 64.07179886954171, 66.61809825897217, 66.76553903307233, 72.10620239802769, 69.46902751922607, 69.08895410810197, 71.23222323826381, 74.32516520363944, 71.49202333177838, 70.70283998761857, 62.51216452462332, 52.5636191368103, 57.82948514393398, 71.487715448652, 76.3180683680943, 77.13671207427979, 74.95000975472587, 65.81239209856305, 67.39477484566825, 64.72002410888672, 71.53080817631313, 73.23531246185303, 72.31389100211007, 71.56887735639299, 71.089430809021, 70.29281984056745, 73.6631269454956, 69.13192176818848, 69.86399091993059, 72.19935689653668, 75.1405085154942, 70.13173280443463, 68.95575019291469, 70.63191277640206, 70.2322107042585, 78.05661187853131, 76.17109312329973, 75.69410623822893, 73.4581411906651, 69.27755601065499, 74.82399722508022, 83.96802112034389, 71.82198633466447, 56.82779809406826, 70.99029391152519, 61.43166405814034, 35.56851993288313, 1.7208637105567115, 0.7544304632714817, 0.16799925879708358, 1.3585351301091058, 1.2021756917238235, 3.0982792675495148, 1.8730226371969496, 0.6812163176281112, 0.423077684960195, 15.582601649420601, 62.82440962110247, 59.78332206181118, 31.40064995629447, 26.944042376109532, 54.095742089407786, 58.057726519448416, 70.46227945600236, 31.500384398869105, 0.6041321339351791, 0.2507590486535004, 0.18365398448492798, 0.1587230744106429, 0.23440763034990855, 0.13651318475604057, 0.20443492010235786, 0.18554113964949334, 0.14515036557401928, 0.1532572577042239, 0.16281715115266188, 0.12296463176608086, 0.18318548319595201, 0.17166921044034616, 0.15017033049038478, 0.16887565462716989, 0.108765716531447, 0.14658432719962938, 0.14257246176046984, 0.12145958681191717, 0.17572978112314427, 0.17659867235592433, 0.10519956038998705, 0.110741311950343, 0.1556874444442136, 0.09510237577238254, 0.16507353793297494, 0.10487210617533751, 0.10259534977376461, 0.0980508139889155, 0.1635612869369132, 0.07079799100756645, 0.11599858770413057], [0.047979601326265504, 0.06601498409041337, 0.03856421548074909, 0.03847241987075124, 0.06040423908936126, 0.050005204776035886, 0.006918458825176848, 0.03302242320829204, 0.0856421726888844, 0.05085893075114914, 0.030037774970488887, 0.04389376539204802, 0.04253990821806448, 0.11922052981598036, 0.03114087274298072, 0.026759685782183493, 0.06462587362953595, 0.16281777540487902, 0.10607997993273394, 0.10501247471464531, 0.07736303444419589, 0.029129627094204937, 0.015865103774038807, 0.10381491468953234, 0.02489962282457522, 0.04617191279040916, 0.013604112285455423, 0.01967546297237277, 0.14944695787770407, 0.04529084185404437, 0.01821005973033607, 0.06432511976787023, 0.21782162891966955, 0.11248815964375224, 0.04449091013520956, 0.010954369424975343, 0.07639751303941011, 0.05747158359736204, 0.2455829664000443, 0.05422022020710366, 0.21044048427471093, 8.591924377850123, 34.39775194440569, 57.88864210673741, 59.16939313071114, 47.23627199445452, 15.608134542192731, 40.02135290418352, 72.32899638584682, 59.157845224652974, 14.503821730613708, 0.268563481846026, 0.35276910769087927, 0.3770512432924339, 0.5250351439629282, 0.20484337104218348, 0.15491957350500993, 0.2126799076795578, 0.03953262065936412, 0.2612446131450789, 0.979166961141995, 28.94248672894069, 74.63794531141008, 88.72538321358817, 64.30074896131242, 74.05062103271484, 74.84605080740792, 75.04558917454311, 73.60588768550328, 68.32352665492466, 68.2916761125837, 66.7963056564331, 64.84812109810966, 68.6446932383946, 66.90694182259696, 67.74740287235805, 68.25241879054478, 64.67351981571743, 64.3345866884504, 65.86084883553642, 63.18882179260254, 70.62426280975342, 66.1831271307809, 70.76109368460519, 67.7373766217913, 68.5766773223877, 67.180680002485, 75.72511604854039, 53.7619297845023, 52.05899231774466, 33.748237814222065, 51.06081410816738, 81.31513636452812, 66.04815837315151, 72.75113419124058, 69.1809413092477, 67.57080050877163, 62.71996429988316, 69.0308324268886, 66.0999641418457, 69.21445941925049, 67.93657452719552, 69.141357421875, 64.9829022543771, 64.70609297071184, 63.799498966761995, 67.5249354498727, 66.57506111689976, 73.04159668513707, 72.76573930467877, 70.47646072932652, 70.67270565032959, 71.89503274645124, 62.15075397491455, 67.84854779924665, 66.39618669237409, 72.13366167885917, 69.7912710734776, 58.44386223384312, 57.031696455819265, 58.65907573699951, 72.25923647199357, 46.83641011374337, 6.543267130851746, 0.13474474607833795, 0.03967806464061141, 1.4716404037816184, 0.6372501796909741, 0.9813505411148071, 0.7392060916338647, 0.3372330442070961, 0.16081981547176838, 1.7796130095209395, 29.21084874016898, 63.001380239214214, 34.20058291299002, 15.476080553872244, 24.69044974872044, 50.7857140813555, 54.55812038694109, 38.70030927658081, 10.805669086320059, 0.08726948965340853, 0.13127515225538186, 0.021820318951670612, 0.1304370936538492, 0.06301547932837691, 0.08520685176232032, 0.044079297222197056, 0.06913686942841325, 0.06335928623697587, 0.08577745221555233, 0.08635589653359992, 0.05627489548974803, 0.03124343670372452, 0.03200956380793026, 0.03313845269648092, 0.09949690103530884, 0.14750064803021296, 0.0202576528037233, 0.08725133884165968, 0.04095381225592323, 0.053999808284321, 0.04860962787643075, 0.01631642286000507, 0.04940686581124153, 0.07343171111174993, 0.10439047523375068, 0.028840608495686735, 0.06119817255863121, 0.07480566310031073, 0.046331334593040605, 0.02299798941904945, 0.04931660369038582, 0.03270886539082442, 0.05529491450371487, 0.012225370687831725, 0.1026907857241375, 0.04700733867606946, 0.051100462076387236, 0.02991778962314129, 0.033954899957669635, 0.029918797247643982, 0.05915795346455915, 0.04568734718486667, 0.03520283102989197, 0.023454970879746333, 0.11793603588427816, 0.051721101094569476, 0.024708442190395932, 0.024803250495876585, 0.022743165592796037, 0.047089180177343745, 0.039656086891357384, 0.03086869538362537, 0.10348507203161716, 0.04899349209985562, 0.0164172921795398, 0.0719491256667035, 0.0804202893216695, 0.04118202393874526, 0.03324210909860475, 0.09269516422812428, 0.014605853041367871, 0.05924990853028638, 0.0780619051573532, 0.06241750677249261, 0.06038086355796882, 0.13511237635144166, 0.02844879693085594, 0.07744168343820743, 0.012422228115610778, 0.03281698655337095, 0.12033061310648918, 0.14980864418404444, 0.01622218282760254, 0.3152581448001521, 16.011566059929983, 54.3088572365897, 64.9582986831665, 48.44299691064017, 36.97830942698887, 20.784551177706035, 72.04880332946777, 87.20410987309047, 59.56557246616909, 10.376550078392029, 0.4633731927190508, 0.3296156200979437, 0.15806664606290205, 0.33765069608177456, 0.12785089814237185, 0.6182173267006874, 0.22173954440014704, 0.23252206295728683, 0.3310530015400478, 3.7991729378700256, 42.47687060492379, 80.65816334315709, 84.50209440503801, 68.57973452976772, 78.79443413870675, 76.86260563986642, 73.23985658373151, 72.18350110735211, 70.32879066467285, 70.7222740990775, 75.13525567735944, 66.83447905949184, 70.97671713147844, 69.2431971686227, 69.6258761542184, 67.41450078146798, 65.42717007228306, 65.8956801550729, 66.2629758289882, 66.0273346219744, 70.4561858858381, 68.85411194392613, 73.70812347957066, 68.12165369306291, 71.84014892578125, 66.04118932996477, 76.16360991341728, 55.18583801814488, 50.90009880065918, 44.177497795649934, 52.08433239800589, 82.08164078848702, 66.53187111445835, 71.63241168430874, 67.40712179456438, 67.79053728921073, 62.774730001177105, 69.10863140651158, 67.15588882991246, 71.10662760053361, 68.19455419267926, 70.29981667654855, 65.55560752323696, 65.79510498046875, 66.85581697736467, 67.94239016941616, 70.21806417192731, 73.69772897447858, 70.87118789127895, 71.11404827662876, 70.52400725228446, 71.54579544067383, 66.02310316903251, 70.51806654248918, 70.25314562661308, 71.30656896318708, 75.00444194248745, 68.74426787240165, 62.93824890681675, 57.89915820530483, 71.6339750289917, 59.87779671805245, 12.70681607723236, 0.05904645659029484, 0.07792011847985642, 1.284769471202578, 1.2646807091576713, 0.12202024672712598, 0.59281004433121, 0.1592965857791049, 0.2398678016449724, 1.8949348671095712, 26.390204940523418, 74.20516286577497, 55.99441378457205, 22.127611909593853, 8.680967279842921, 39.179682867867605, 59.52935150691441, 47.27201352800642, 18.840323618480138, 0.18731611940477574, 0.20802143907972745, 0.11864868764366422, 0.10951060548956905, 0.040266551276935, 0.0543869260831603, 0.053866096173546145, 0.095459882303008, 0.09317347034811974, 0.008647728644843613, 0.06174606244478907, 0.049258395563811064, 0.04411915436919246, 0.0353140157780477, 0.08707877381571702, 0.08986395650676318, 0.12813961479280675, 0.05823426374367305, 0.1450764595397881, 0.004725657137376922, 0.06251153137002673, 0.022563294441040074, 0.04096667388720172, 0.08001036596085344, 0.0949323009699583, 0.061366082834345956, 0.023787926317059567, 0.03404218330979347, 0.042534049068178446, 0.05941840913146734, 0.043382326407091956, 0.023378849428679262, 0.04922027885913849, 0.04883296089246869, 0.18273584518049443, 0.14069180696138314, 0.1290305041308914, 0.12439677491784096, 0.18070456917796815, 0.1465731178011213, 0.08891216186540467, 0.14700234548321792, 0.1820199228823185, 0.15489264923546994, 0.19920857197472028, 0.11532237327524594, 0.19569331274500915, 0.18136348096387728, 0.10807506287736551, 0.08564429650349276, 0.1332361048885754, 0.21653224953583308, 0.13513725144522531, 0.17638253181108407, 0.2070600228118045, 0.11269421715821538, 0.22947682493499347, 0.21201539119439466, 0.10626939976853983, 0.18618148671729223, 0.19561966455408505, 0.101112757543368, 0.23022807176624024, 0.19048334445272172, 0.15175837384802954, 0.15114869656307356, 0.38554074774895397, 0.18614192812570504, 0.20076032727956772, 0.1190991670425449, 0.17816217988729477, 0.2176210946802582, 0.23283321197543824, 0.19157556870153972, 0.28945780066507204, 16.323229244777135, 71.12893826620919, 86.21476977212089, 69.06032058170864, 60.01921340397426, 24.96956409726824, 53.44555745806013, 81.51630755833217, 76.16600009373256, 23.097279923302786, 1.2285624529634203, 0.6558536014386586, 1.13948926116739, 1.663533364023481, 0.23080640073333467, 0.4315697949911867, 0.45776523649692535, 0.16477467039866106, 0.3656981039260115, 2.772757900612695, 33.06826972961426, 79.91550513676235, 96.6396871294294, 70.61079720088414, 76.61679921831403, 72.2066455568586, 77.9991294315883, 78.01986285618374, 71.12322684696743, 76.19818414960588, 81.9568372453962, 68.7591300691877, 77.73337473188127, 70.96664919172014, 73.4483094896589, 73.9662560054234, 75.59723445347377, 74.39000579289028, 73.26174340929303, 71.87158257620675, 76.51274994441441, 71.9521677834647, 77.64355536869594, 73.85131890433175, 75.11067989894322, 69.74992929186139, 77.4604355948312, 56.455322538103374, 56.133933612278526, 44.163695199149, 50.46003116880144, 83.59966932024274, 68.19196946280343, 75.12388842446464, 72.83993911743164, 73.10944584437779, 67.52190603528703, 73.69545691353935, 70.44854286738804, 76.3114675794329, 73.20485850742885, 75.71649333408901, 68.97574016026088, 69.01057147979736, 70.50056403023856, 74.60571261814663, 74.00675705501011, 78.85431371416364, 77.65936252049038, 74.62698105403355, 74.94328389848981, 75.58568654741559, 65.02767644609723, 71.78514698573521, 68.50590991973877, 70.2173832484654, 87.82536220550537, 78.60750675201416, 65.72858987535749, 59.43562030792236, 78.86021968296596, 53.80903162275042, 8.285144908087593, 0.16485893087727682, 0.17285353903259548, 2.9372172015053883, 2.273246475628444, 3.6821809070450917, 5.5357175384249, 0.6671303106205804, 0.3714849219790527, 3.3573506687368666, 40.29325328554426, 74.1056160245623, 42.75375631877354, 23.284671102251323, 32.253572600228445, 61.57076699393136, 69.21722480228969, 53.27455186843872, 17.38610213143485, 0.48221795580216814, 0.2095893028059176, 0.28831009939312935, 0.20976080931723118, 0.14519683165209635, 0.16062681297106401, 0.12804540699081762, 0.15409865469804832, 0.22381833142467908, 0.13339705339499883, 0.15985039249062538, 0.18080358100788935, 0.11884217868958201, 0.132765296580536, 0.14321400304990156, 0.16858545877039433, 0.21906323943819317, 0.14729953025068554, 0.18212002036826952, 0.1878306253680161, 0.18558295097734245, 0.09111801814287901, 0.11499975701527936, 0.14764694018023355, 0.20328762595142635, 0.24251514673233032, 0.12081949758742537, 0.17995227740279265, 0.13343809119292668, 0.13792983016797475, 0.23298170257891926, 0.20421584828623704, 0.09424561674573592, 0.13512893260589667], [0.018822493563805307, 0.056088556202926805, 0.052790648703064234, 0.024921824490385394, 0.011778521451300808, 0.055202396253922155, 0.047671017170484574, 0.010913733659046037, 0.028990700441811765, 0.05072706425562501, 0.11508244329265185, 0.1074219322098153, 0.03905098971777728, 0.030933101927595477, 0.022004047575007592, 0.027330846026805893, 0.08195499304149832, 0.06211151462048292, 0.03049293965367334, 0.07258958808545556, 0.18555198263909134, 0.15609023640198366, 0.005965698119585535, 0.044963750655629804, 0.11975684389472008, 0.13664111574845655, 0.08152185699769429, 0.032323318400553296, 0.013716360637252884, 0.11763669337545123, 0.03147104449037995, 0.045331764301019054, 0.0706165846703308, 0.04568615296323385, 0.12453288904258183, 0.18094327779752867, 0.08751731099826948, 0.2588560613138335, 0.06345185876957007, 0.17223977696682724, 0.04874215255092297, 0.28050238692334717, 3.2270812817982266, 25.079161507742747, 60.40651988983154, 57.27893073218209, 51.95784739085606, 22.39751468385969, 21.650161232267106, 45.31328855242048, 75.19405828203473, 46.72537095206124, 5.818465360573359, 0.07800729665905237, 0.34122793270008905, 1.040052396910531, 0.36002256561602863, 0.2656197798039232, 0.4438776602702481, 0.2849397345313004, 0.11671855407101767, 0.5295215089406285, 4.545619649546487, 46.04520831789289, 83.26532200404576, 78.86497919900077, 67.36757264818463, 68.14281095777238, 73.19451263972691, 74.02288382393974, 78.68022659846714, 71.99709483555385, 69.54372760227749, 62.773263931274414, 74.36473519461495, 72.8212971006121, 68.96192019326347, 62.026707785470144, 68.67311137063163, 65.541745867048, 66.2370034626552, 67.32369477408272, 72.58229296548026, 69.21772507258824, 69.259108543396, 69.65430123465401, 73.70826939174107, 63.868925367082866, 63.236736570085796, 60.29853098733084, 47.17944615227835, 52.82772363935198, 73.45780072893415, 79.80361134665353, 75.82692105429513, 67.00086757114956, 67.50341687883649, 75.49504034859794, 72.99408490317208, 74.62233270917619, 74.6300938470023, 73.53628758021763, 71.07239382607597, 71.35863876342773, 72.75814492361886, 72.49359921046666, 67.05129064832414, 67.82927349635533, 70.5773207800729, 71.0662863595145, 69.08723790305001, 69.33130032675606, 67.92743069784981, 74.33225236620221, 66.33745356968471, 54.04371745245797, 36.54608283724104, 46.661412784031455, 57.412666184561594, 71.90976292746407, 51.655670234135215, 16.67512423651559, 0.08785190340131521, 0.0333405814931861, 0.7851435095071793, 1.0278941350323814, 0.4316117555967399, 2.0994212201663425, 0.7872126613344465, 0.4104125845645155, 0.14613331854343414, 12.317976645060948, 53.518562180655344, 56.81020525523594, 22.940063033785137, 19.195081268038066, 41.838101863861084, 59.42003549848284, 46.656809602464946, 22.879177706582205, 1.9504060276917048, 0.1293818224221468, 0.14752404391765594, 0.049745319078543355, 0.08592560355152402, 0.05734932515770197, 0.06253117495881659, 0.11549064995987074, 0.05997611741934504, 0.12323143173541341, 0.022992645955777595, 0.03774031111970544, 0.11219678992139441, 0.06202972400933504, 0.05536119719701154, 0.1527309859437602, 0.002464443852659315, 0.20015345912958893, 0.025057012414825813, 0.03324719471856952, 0.10600637245391097, 0.10702509100415877, 0.015772782299401503, 0.04153682650732143, 0.10128528185720954, 0.04102179467944162, 0.04379590707165854, 0.04801319220236369, 0.06362888855593545, 0.05544551195842879, 0.021243252059710876, 0.10133450957281248, 0.09065279417804309, 0.034215552399733236, 0.05702421867421695, 0.04483289856995855, 0.019717223410095488, 0.06332497950643301, 0.018112757808661888, 0.0334066470552768, 0.08931008872709104, 0.003982558663535331, 0.05348480699051704, 0.07571107308779444, 0.040390685865921636, 0.04677955447030919, 0.030087219817297797, 0.09284944952066455, 0.05602361361629196, 0.06581403594464064, 0.036023712517427545, 0.03761856158130935, 0.03897478684250798, 0.0777183628774115, 0.036644019053450654, 0.005897389151089425, 0.1694824956357479, 0.09011917388332741, 0.009123315535751837, 0.04124442541173526, 0.11984753688531262, 0.05373346293345094, 0.04919073544442654, 0.020334250925640975, 0.015670800182436193, 0.04631774014394198, 0.03764727718329855, 0.068699322906988, 0.05771441092448575, 0.042380323567028554, 0.18303510626511915, 0.07457688144807305, 0.12448148322956902, 0.09073774676237788, 0.09754835880760636, 0.12440689866031919, 0.08882181492767163, 0.05905057529785803, 6.376475623675755, 42.104603494916645, 74.25926848820278, 60.20643956320626, 29.673789841788157, 13.894567200115748, 39.59796094894409, 72.19893305642265, 94.64526230948312, 44.51636144093105, 5.068615768636976, 0.3558270478887217, 0.5391123571566173, 0.12745580077171326, 0.5533003072653497, 0.1747449825384787, 0.9628528079816273, 0.5169859273093087, 0.4135163665882179, 0.35448498704603737, 11.237661174365453, 65.4260583605085, 86.20834963662284, 74.54602759225028, 62.365668705531526, 70.26820932115827, 75.86672728402274, 77.2548314503261, 80.85611752101353, 70.84679971422467, 70.89531203678676, 69.1069221496582, 75.72043296269008, 77.57714448656354, 71.50656591142926, 68.49757902962821, 71.25490910666329, 71.78458418164934, 69.92458615984235, 72.4141674041748, 73.72429193769182, 71.60603632245744, 70.29597432272774, 70.87918526785714, 75.58251122065953, 68.97619179316929, 57.27943447657994, 59.71872465951102, 47.2551189831325, 51.46532433373587, 71.89481040409633, 73.47197505405971, 75.6098106929234, 69.58534731183732, 69.75136756896973, 72.18407780783517, 76.5489639554705, 73.68825163160051, 75.80401979173932, 71.94797107151577, 74.00644438607353, 74.66838536943708, 73.99871104104179, 74.40507643563407, 69.95763179234096, 69.557783808027, 73.30148710523332, 75.74282700674874, 69.08189473833356, 69.94257504599435, 72.91167231968471, 74.30907317570278, 74.23802784511021, 66.66727760859898, 56.56614630562918, 56.57439729145595, 59.492123058864046, 73.61275945390973, 63.0683330808367, 29.639809676579066, 1.3377618619373866, 0.09512549346046788, 0.9722429726805005, 1.2331217740263258, 0.17698382240320953, 0.9214579377855573, 0.608734012714454, 0.19685742099370274, 0.3464258366397449, 10.882333772523062, 50.312343733651296, 68.09405544825962, 34.36852087293352, 13.541133182389395, 21.014406272343226, 53.22301360539028, 54.49918924059187, 28.521516220910208, 4.383706212043762, 0.25948031353099005, 0.09612110789333071, 0.10567665193229914, 0.0812260021588632, 0.018459209307496036, 0.10209580550768546, 0.036579273241971216, 0.06434610007064683, 0.07813226245343685, 0.09381369527961526, 0.041373394562729766, 0.08070893133325235, 0.08180650243801729, 0.073596031937216, 0.0656171590089798, 0.09987301299614565, 0.1598275937139988, 0.05517696476142321, 0.06375846838844673, 0.08700549881905317, 0.0995795058884791, 0.039361446630209684, 0.13112736732832023, 0.07484020731811013, 0.07636285347065755, 0.03582977703107255, 0.052584082287337096, 0.03647251932748726, 0.04700177808159164, 0.038692780903407505, 0.04613716161942907, 0.09910983751927104, 0.03969559459281819, 0.066454946196505, 0.07193357364407607, 0.1537706780114344, 0.21127630371068204, 0.13260031757610186, 0.12257223496479647, 0.21721667423844337, 0.2081704182284219, 0.2195691687187978, 0.13633055027042115, 0.13109794604991162, 0.22713297499077661, 0.152969341725111, 0.2481196288551603, 0.15177801065146923, 0.20858412102929183, 0.09873665682971478, 0.13925563331161225, 0.12600763062281267, 0.20431499582316193, 0.16426392351942404, 0.17372800782322884, 0.36992005737764494, 0.2703589126467705, 0.07260177457439047, 0.16057548858225346, 0.18910257997257368, 0.15526019808437141, 0.2100755274295807, 0.11253980972937175, 0.11673862513686929, 0.10717835849417107, 0.09271250758320093, 0.12018680439463683, 0.11928253434598446, 0.1960243699806077, 0.19129014973129543, 0.2537247080888067, 0.27317266166210175, 0.22347571195236274, 0.24372000779424394, 0.21815477604312555, 0.19383996219507285, 0.34503787968839916, 6.809907725879124, 49.135954652513774, 89.883634022304, 77.60495812552315, 68.50555556161063, 34.5633726801191, 37.44486011777605, 57.40525245666504, 90.23827007838658, 64.64480291094098, 10.842860187802996, 0.8738734711493764, 0.9794471689632961, 2.1790638608591895, 1.398104469691004, 0.33373801889164106, 1.2701486157519477, 0.6029804700187275, 0.32079159787722994, 0.3182680175772735, 7.316632900919233, 54.06802225112915, 87.51979432787213, 81.15531390053886, 70.27601909637451, 71.08763122558594, 74.40163012913295, 81.52967589242118, 83.80471066066197, 76.37730870928083, 81.98156588418144, 69.54452664511544, 87.42427744184221, 85.1079842703683, 75.18401118687221, 68.20569910321916, 77.25884750911167, 75.4455691746303, 75.96109771728516, 75.84274210248674, 79.42733860015869, 76.31408010210309, 78.44577353341239, 76.44653361184257, 81.12738909040178, 67.35300922393799, 65.50442014421735, 69.03065872192383, 62.52393477303641, 62.5742883682251, 73.72176279340471, 85.67548533848354, 84.92692811148507, 73.85632855551583, 72.0997336251395, 85.49536023821149, 80.38566889081682, 81.73258413587297, 81.96699551173619, 80.08091395241874, 77.02527686527797, 80.62845979418073, 83.34432997022355, 81.73311219896588, 72.45099980490548, 75.34324305398124, 76.30914688110352, 79.09865406581334, 70.31418555123466, 74.0436658859253, 75.05567101069859, 88.02413627079555, 82.39735998426164, 86.33594635554722, 66.09799780164445, 56.261412211826865, 68.19924422672817, 74.84797545841762, 59.08557006290981, 19.862752778189524, 0.5410739204713276, 0.1782116043780531, 1.2659931587321418, 1.7932183423212595, 1.8379125211920058, 7.115799129009247, 1.7397812668766295, 0.5475682605590139, 0.5754280941826957, 17.16114204270499, 63.01481110709054, 64.9998836517334, 31.36029829297747, 27.269086054393224, 49.9249712399074, 69.96025821140834, 62.44034794398716, 32.926665442330496, 3.502305290528706, 0.5154820765767778, 0.32632795508418766, 0.23290103833590234, 0.23525113080229076, 0.12231589800545148, 0.26073815460715977, 0.1978778833789485, 0.161096114931362, 0.20626765675842762, 0.20669290822531494, 0.1571289242378303, 0.15212711691856384, 0.11764892057648726, 0.16011629679373332, 0.2074126846023968, 0.19866605608591012, 0.28184982176337925, 0.1378330032208136, 0.11245337115334612, 0.2852855702596051, 0.24267286541206495, 0.19436904309051378, 0.20168757252395153, 0.1540582954351391, 0.19557246565818787, 0.09168329209621463, 0.13448629208973475, 0.23197513659085545, 0.16292236479265348, 0.09089388445551906, 0.18685999459453992, 0.1543506354625736, 0.17269400187901088, 0.12011099846235343, 0.19069253679897102], [0.1074372942426375, 0.27497951899256023, 0.17420362015920027, 0.06357753702572413, 0.010947457697641636, 0.04483348211007459, 0.017873857502958605, 0.1334657482802868, 0.0561024152806827, 0.076316041339721, 0.03410086641088128, 0.14517929830721446, 0.048581797762640884, 0.08819288081888642, 0.027593757990481596, 0.07690513865756136, 0.0767452215243663, 0.01678968407213688, 0.02185024064965546, 0.11708162458879606, 0.07883105852774211, 0.08746562020054885, 0.09640799928456545, 0.09868892189115286, 0.1237768924662045, 0.044538716319948435, 0.11848756271813597, 0.08827847801148891, 0.05318905732461384, 0.07606329383062464, 0.08420069968061787, 0.10957401458706174, 0.16660923909928116, 0.09765083795147282, 0.04901019763201475, 0.18730472001646245, 0.26026106306484764, 0.1776449190718787, 0.19244466349482536, 0.17465095115559442, 0.2502428192113127, 0.12026410310396127, 0.28987583251936094, 0.24931830167770386, 14.779478481837682, 47.18184675489153, 59.88600948878697, 71.00947788783482, 45.203176975250244, 24.058789014816284, 22.919895887374878, 56.94821384974888, 70.70085975102016, 35.157867499760215, 3.491476957287107, 0.290760587900877, 0.9548670479229519, 1.9754649230412074, 1.5659917294979095, 0.508246396269117, 0.17905164430184023, 0.2769897739802088, 0.13826795773846762, 0.05673572254766311, 8.058783888816833, 47.48451375961304, 92.54981068202427, 100.54706219264439, 80.47739206041608, 72.68429946899414, 73.27418068477085, 69.82419858660016, 76.86695521218437, 81.26804147447858, 74.20657335008893, 80.04028783525739, 76.10567583356584, 72.578492300851, 72.8514175415039, 66.25447123391288, 66.11823790413993, 72.01982934134347, 66.99619838169643, 70.50401728493827, 67.37010874067033, 69.9083343233381, 61.068474769592285, 76.84096894945417, 53.77118478502546, 31.338571275983536, 28.49237026487078, 16.294882331575664, 82.45791353498186, 81.74390275137765, 74.8680557523455, 81.82504381452287, 75.33024297441754, 68.0422010421753, 69.87478147234235, 67.36816324506486, 69.14935479845319, 68.36179038456508, 68.79626819065639, 70.43350001743862, 72.0666115624564, 70.19896357400077, 64.14011355808803, 64.38382857186454, 62.39464964185442, 66.10563387189592, 62.42597212110247, 59.966511317661826, 50.42055150440761, 44.847126960754395, 52.48188400268555, 72.2170261655535, 72.02276842934745, 68.6161083493914, 49.21363203866141, 12.744369353566851, 0.47927962775741306, 0.14703195675143174, 0.524244949221611, 0.7775308351431574, 0.9612628647259304, 0.2599888890981674, 0.4276185498705932, 0.5102447090404374, 0.22821561832513126, 6.140706309250422, 39.95613363810948, 59.69578865596226, 45.15710347039359, 24.007040568760463, 37.78558240618025, 53.00087969643729, 51.795961311885286, 31.197682653154644, 10.921673604420253, 0.15066845661827497, 0.08413551960672651, 0.1114164407231978, 0.06367569390152182, 0.0703211844499622, 0.08266580597098384, 0.21139905069555553, 0.04232621718464153, 0.13622131970311913, 0.02828788404752101, 0.12033425005418913, 0.09998828252511364, 0.14018975890108518, 0.07635802230132477, 0.09989566928041832, 0.03564668792699065, 0.14010176647986683, 0.22736559036586965, 0.08330953892852579, 0.03718857393999185, 0.2536631513919149, 0.14110199495085649, 0.07820475713482924, 0.016399356802659373, 0.10402065329253674, 0.09747051048491683, 0.04122443916276097, 0.05239324431334223, 0.06220739840396813, 0.04293321425627385, 0.08252828049340419, 0.0770280688468899, 0.07155891374817916, 0.06628358896289553, 0.026457383164337704, 0.08455792122653552, 0.07016298401036433, 0.13032673671841621, 0.11197640853268759, 0.16504863569779055, 0.05023551991741572, 0.06119337531604937, 0.05360842250021441, 0.03361300312514816, 0.038461576881153245, 0.04110325959378055, 0.03532490287242191, 0.05319051617490394, 0.031046237463929822, 0.06272769227091755, 0.12923976433064255, 0.052528649368988614, 0.05767242317753179, 0.09576222393661737, 0.023556830860408287, 0.08150409973625626, 0.055333146559340615, 0.05939567820834262, 0.01814690338713782, 0.16334012523293495, 0.04376420930826238, 0.11515378446451255, 0.046618273481726646, 0.05917539181453841, 0.04139441557760749, 0.04858471546322107, 0.06108064350805112, 0.13247626780399255, 0.1274408187185015, 0.09068904830408947, 0.07205983544034616, 0.06636330325688634, 0.1148834154009819, 0.2202604194836957, 0.08595121146312781, 0.17562326469591685, 0.12800951248833112, 0.13957248202392034, 0.1504618562757969, 0.2805882894567081, 0.6716846919485501, 24.661936078752788, 62.55885641915457, 71.18802574702671, 55.55432183401925, 22.536707946232386, 19.77391311100551, 40.85620328358242, 86.20971843174526, 77.30880505698067, 33.42462893894741, 1.4516618358237403, 0.3986925748842103, 0.8219399207404682, 0.741916431912354, 0.9738883929593223, 0.4425136963171618, 1.182846563202994, 0.5082820057868958, 0.6239350970302309, 0.2632752241832869, 17.95510401044573, 67.96953678131104, 100.53139400482178, 93.09636293138776, 70.59059183938163, 66.47104658399309, 76.77810859680176, 79.29730306352887, 80.84925964900425, 80.6594626562936, 76.77980395725795, 83.0973493031093, 77.17082772936139, 75.55195999145508, 73.73748656681606, 68.39969280787876, 71.46493230547223, 74.79942144666398, 74.29315485273088, 75.6902847290039, 72.55539648873466, 71.25292887006486, 63.88031346457345, 71.40540013994489, 71.71824278150285, 54.33136592592512, 42.88547331946236, 32.14711577551705, 84.58121354239327, 78.46479770115444, 76.59826142447335, 76.42526517595563, 75.09876373835972, 74.61291790008545, 69.83312007359096, 74.23321969168526, 75.63626943315778, 73.53778839111328, 70.14080020359584, 70.15355709620884, 73.4156390598842, 74.3874488558088, 67.83019760676792, 71.03552668435233, 68.51107243129185, 70.34079715183803, 71.70655591147286, 73.82210172925676, 64.86886841910226, 64.50517886025565, 60.10227216993059, 77.96348517281669, 77.67115361349923, 70.98308862958635, 64.39727333613804, 25.0573684828622, 2.0423350376742224, 0.19346550585968153, 0.22839581008468354, 1.118173056415149, 0.6912326887249947, 0.38691906950303484, 0.33480500163776533, 0.40883699910981314, 0.40545735188892906, 2.8694694425378526, 34.45703744888306, 66.8342011315482, 59.54776423318045, 28.17648778642927, 23.318682534354075, 42.65601600919451, 58.6458602632795, 39.48818635940552, 14.335894192968096, 0.3213465580982821, 0.2764069666819913, 0.06127308961004019, 0.17017526631908758, 0.1006640355501856, 0.04242570398907576, 0.14157443174294063, 0.07364047598093748, 0.1345237607934645, 0.03061112349054643, 0.09507583148245301, 0.07148689404129982, 0.14779851133269922, 0.09862507174589805, 0.0225305483410401, 0.0513810634479991, 0.15735324791499547, 0.19562606992466108, 0.047811365353741815, 0.04216664271163089, 0.13681977401886666, 0.042372075973876884, 0.09601045240248952, 0.03667904163843819, 0.03447796903284533, 0.0684870635824544, 0.0601487842255405, 0.023978860982294594, 0.027062081698594347, 0.10482501584504332, 0.07401232674185719, 0.0307931744360498, 0.03603295755705663, 0.12718316540122032, 0.04745331260242632, 0.04018242989799806, 0.015487678847940905, 0.27470313810876434, 0.2732726777238505, 0.2826351039111614, 0.11102230687226568, 0.14923245938760893, 0.17793867045215198, 0.15073749077107224, 0.391016172511237, 0.1326547632259982, 0.11160455777176789, 0.1057246650702187, 0.42489026912621086, 0.250962174896683, 0.25961751331176075, 0.21048524044454098, 0.15053114827190126, 0.2519886355314936, 0.18946361488529614, 0.22023682003574713, 0.25719210345830235, 0.24030347540974617, 0.23086073781762803, 0.23775772058538028, 0.07989257906696626, 0.14421537145972252, 0.10968850380075829, 0.21582531104130404, 0.12327327020466328, 0.14293463661202363, 0.1381440165319613, 0.24340123204248293, 0.307555442409856, 0.1473830443407808, 0.1582538267331464, 0.11549674320433821, 0.18809001573494502, 0.31422696156161173, 0.2667324686689036, 0.28145863275442806, 0.19090939659093106, 0.21691848523914814, 0.17787096622799123, 0.35953165910073687, 0.7776621995227677, 24.86667343548366, 75.19151524135044, 88.653719493321, 86.31790883200509, 58.190589972904746, 38.85022708347866, 35.906876359667095, 67.61976446424211, 85.87439141954694, 49.65590919767107, 6.429310160023825, 0.5829322572265352, 1.3880175309521812, 4.076022607939584, 4.182522424629756, 1.5579646059444971, 0.749204440840653, 0.32790139636823107, 0.39392260941011564, 0.27274567314556664, 12.031471150262014, 57.63689150129046, 101.93326950073242, 100.11915738242013, 76.64015211377824, 71.41490527561733, 84.04044219425747, 79.56815774100167, 83.47087056296212, 97.28662000383649, 75.71547889709473, 88.53808757237026, 89.67909295218331, 94.23564515795026, 84.76520878928048, 78.7581923348563, 75.70386845724923, 82.39022418430874, 76.959470476423, 79.62726606641496, 74.1910649708339, 75.59287098475865, 60.501578194754465, 80.65060370309013, 73.10422079903739, 51.79283809661865, 36.828099795750205, 24.455826452800206, 91.0098466873169, 78.82004519871303, 76.91432108197893, 87.97365760803223, 83.84277984074184, 73.4524645124163, 75.69746916634696, 78.14741788591657, 80.8128719329834, 77.25267056056431, 75.9014960697719, 76.08235767909459, 76.1218512398856, 77.27782998766217, 77.53940187181745, 77.8720955167498, 75.01998506273542, 75.95186356135777, 79.62580694471086, 78.18796062469482, 67.74888283865792, 66.6489760535104, 73.8849412373134, 97.21391405378068, 104.62459169115338, 79.64210047040666, 60.46191092899868, 15.697785411562238, 0.7926649887646947, 0.28116987539189203, 1.5670272282191684, 2.6563317137105122, 1.9431831581251962, 1.7141344887869698, 3.232607488121305, 0.9743744411638805, 0.4920336976647377, 9.16147950717381, 49.845654078892295, 67.65860489436558, 54.11595092500959, 34.6563013621739, 46.67954063415527, 60.547325134277344, 70.07557051522392, 45.15626968656267, 14.804849828992571, 0.323740402502673, 0.28912895545363426, 0.21119023832891667, 0.257949239973511, 0.13614706083067826, 0.1372869453792061, 0.22585712559521198, 0.21842435800603457, 0.2445359868662698, 0.07655962862606559, 0.16132076430533612, 0.11221213838351624, 0.3160649229373251, 0.17651232198945113, 0.2015781383961439, 0.14321329737348215, 0.17925198855144636, 0.36553169999803814, 0.19679498220128672, 0.1489876982356821, 0.21730421882654938, 0.16479976262365068, 0.14029976299830846, 0.13494815730622836, 0.11383302962141377, 0.12766882005546773, 0.17231917913470948, 0.16750635738883699, 0.16320844872721604, 0.2990507116275174, 0.1868437776075942, 0.13155720569193363, 0.13275444002023765, 0.194172240793705, 0.16443481934922083, 0.1457696102027382, 0.1402521434106997], [0.1779553217015096, 0.3412123535360609, 0.3897393324545452, 0.039067155814596584, 0.14636300264724664, 0.09963897269751344, 0.02279920579998621, 0.11267169658094645, 0.10414202963667256, 0.10595822360898767, 0.08865959077541317, 0.09161556751600333, 0.050181260864649496, 0.04397938972605126, 0.10274268008236374, 0.07919649713273559, 0.0395878025197557, 0.07158340886235237, 0.14579725371939795, 0.05208052787929773, 0.04162253226552691, 0.1026882751445685, 0.14508080216390745, 0.08744346603218998, 0.19191337057522365, 0.06718053761869669, 0.06470061426184007, 0.03052729388166751, 0.08841762518776314, 0.07119088992476463, 0.14497239940932818, 0.2625689777944769, 0.09254115034959146, 0.21602124481328897, 0.3667957293135779, 0.529107711144856, 0.33451939267771585, 0.2452309424323695, 0.20265406423381396, 0.20754119913492883, 0.19594205011214527, 0.5477964111736843, 0.09250465873628855, 0.2338043584355286, 0.5155761486717633, 1.0263282933405466, 18.626786368233816, 43.08506032398769, 64.6467136655535, 65.1283905846732, 48.82728787830898, 21.236891065325054, 36.51413154602051, 66.18963064466203, 64.72519356863839, 32.37091030393328, 1.9826908324445998, 0.22924601446305, 0.8521124731217111, 3.973859335694994, 2.718213673148836, 0.46002573519945145, 0.10480210850281374, 0.11538828616695744, 0.1583759087537016, 0.18151053307311876, 3.508552372455597, 29.264870984213694, 65.26700714656285, 90.17456204550606, 92.06700815473283, 81.78835037776402, 64.88620417458671, 80.40449156079973, 64.78622654506138, 65.11784321921212, 80.65375818525041, 67.72967106955392, 69.00888306753976, 64.15032741001674, 66.49434389386857, 52.370928219386506, 53.6405725479126, 52.12926639829363, 55.650783675057546, 63.45992660522461, 69.60424641200474, 43.40606362479073, 4.527105740138462, 1.7375174569232124, 0.6109343660729272, 0.1751292912023408, 19.069304977144512, 89.70457199641636, 80.41540023258754, 69.03703022003174, 73.84761551448277, 80.75588975633893, 76.54953370775495, 74.21117305755615, 78.49677331107003, 77.49220275878906, 73.63344424111503, 70.49727753230503, 69.06665733882359, 68.37093421391079, 64.08290209089006, 57.171772139413015, 50.54305519376482, 33.03636360168457, 27.89228388241359, 28.664023774010793, 37.45299645832607, 41.566132000514436, 47.21296773638044, 45.49632147380284, 23.40087103843689, 5.3159286464963635, 0.15387206471392087, 0.14740726804094656, 0.18563717949603284, 0.16949361003935337, 0.3669924773275852, 0.7752089968749455, 0.7981365323066711, 0.9179707020521164, 0.3452877162822655, 3.7807749765259877, 34.23720339366368, 62.17073699406215, 52.17362022399902, 29.31296294076102, 18.018162386757986, 38.8743269102914, 51.83625044141497, 40.36035898753575, 14.862453869410924, 2.0186937919684818, 0.10383815451392106, 0.36726877678717884, 0.12236544463251318, 0.036016811816287894, 0.20359965706510202, 0.08487134333699942, 0.06738092258040394, 0.17296856428895677, 0.2289224618247577, 0.13898957973080023, 0.20642935165337153, 0.16616515150027616, 0.1297959459147283, 0.17847810579197748, 0.05462272378749081, 0.12338901470814433, 0.59175777222429, 0.19625594041177205, 0.6526159580264772, 0.3341698385775089, 0.04702302301302552, 0.1513047596173627, 0.11898969220263617, 0.05436530795746616, 0.06450959308339016, 0.040995345384414704, 0.12173777259886265, 0.22625476068684033, 0.1127394890146596, 0.07306406048259564, 0.24689555168151855, 0.050862951071134636, 0.30139453443033354, 0.32915402629545754, 0.28313797978418215, 0.1696167912866388, 0.032572540920227766, 0.1539188293474061, 0.10880938025989703, 0.39104013836809565, 0.047240239035870345, 0.09547511541417666, 0.03565109161926167, 0.19911625050008297, 0.08474599077765431, 0.14324592133717878, 0.026977256339575564, 0.03771806874179414, 0.15277833411736147, 0.08429663774690457, 0.04340814466455153, 0.060475804177778106, 0.08520791706229959, 0.09043222958488123, 0.03524475770869425, 0.0858702893768038, 0.09529062174260616, 0.033050199039280415, 0.04180183853687985, 0.08986793272197247, 0.14681874747787202, 0.16150204172091825, 0.09691571989761931, 0.01615660750706281, 0.08269243168511561, 0.04909939784556627, 0.029589402422841107, 0.09370893625808613, 0.05666840848113809, 0.10582424008420535, 0.08342701369630438, 0.18985595740377903, 0.14464579336345196, 0.40474700714860645, 0.2766453767461436, 0.24665915008102143, 0.1551272323621171, 0.13246645618762287, 0.09994512091257743, 0.18940657723162854, 0.04499717868332352, 0.18581871475492204, 0.2197363461766924, 5.887710673468454, 31.227448735918315, 64.18736130850655, 72.80717836107526, 46.30523075376238, 23.0953083719526, 20.967879397528513, 57.16789851869856, 89.84454345703125, 71.18276596069336, 22.005160331726074, 0.32421776545899256, 0.6499300450086594, 1.2315942559923445, 1.4749010631016322, 0.6900155597499439, 0.7673188831124986, 0.1728389776710953, 0.23958783809627804, 0.7022062284605843, 0.1709335292024272, 8.529255969183785, 53.35894816262381, 82.22774750845772, 95.75879451206752, 85.3605443409511, 79.32667309897286, 68.06949356624058, 86.35091277531215, 79.303042275565, 63.12650339944022, 97.86072186061314, 101.78890677860805, 99.00252628326416, 87.2052424294608, 75.34482724325997, 70.63918059212821, 67.7928579875401, 66.4449074608939, 63.65272521972656, 72.84368419647217, 74.68817383902413, 66.80961145673479, 19.61961967604501, 6.026334617819105, 3.5678984565394263, 0.5566460277353014, 36.93383748190743, 90.18900735037667, 74.17843314579555, 80.65147222791398, 78.94684982299805, 79.98343767438615, 80.39247812543596, 75.88679368155343, 74.97589179447719, 74.79412691933769, 76.132308278765, 77.76819215502057, 75.39677197592599, 75.66157477242606, 73.15292767116001, 70.01902607509068, 68.51765237535749, 65.73084803989956, 61.59791360582624, 55.85242734636579, 53.4825496673584, 57.89196334566389, 74.82132911682129, 77.74262278420585, 42.80880689620972, 13.788786087717328, 0.8780931990061487, 0.37163064415965763, 0.4634849067245211, 0.6460134323154176, 0.9262009518487113, 0.42396469307797296, 0.8753187507390976, 0.3952101974615029, 0.1883766289268221, 1.0497419855424335, 26.689898116247996, 67.68942710331508, 66.05075699942452, 38.32684360231672, 17.642990929739817, 32.36888837814331, 59.97359848022461, 52.47943128858294, 20.293957982744487, 3.4353059828281403, 0.2196774629077741, 0.3149262054690293, 0.2049536465534142, 0.1385674359542983, 0.0976724900039179, 0.05719134184931006, 0.12657560514552252, 0.11421359277197293, 0.18102854250797204, 0.10320609235869986, 0.15627448580094747, 0.07061172635959727, 0.062126483102994304, 0.0747229428961873, 0.046721366699784994, 0.20323456451296806, 0.21551007724234036, 0.18578800425997802, 0.2962429065789495, 0.1920603412602629, 0.07382516642766339, 0.111868867517582, 0.07037613900112254, 0.08495993965438434, 0.06737117881753615, 0.03434990233342562, 0.19952802626149996, 0.026045536156743765, 0.11185197878096785, 0.12344222542430673, 0.1290102159338338, 0.022391467321930186, 0.16773876920342445, 0.15660694081868443, 0.15733086983008043, 0.11121468512075287, 0.05836221509213958, 0.08363082525985581, 0.2169462644628116, 0.38002015969582964, 0.4640546590089798, 0.12449090129562787, 0.36812587508133476, 0.2368688668523516, 0.19357766769826412, 0.2814014186816556, 0.2391908136861665, 0.2160341776907444, 0.1692057754844427, 0.1937399868454252, 0.17752251135451452, 0.15838209699307168, 0.2848254149513585, 0.15798933378287724, 0.16584188384669168, 0.1754125388605254, 0.24488581238048418, 0.1940489781222173, 0.11068007416490998, 0.21098332586033003, 0.2613083411540304, 0.22093890021954263, 0.2337478500391756, 0.23629156925848552, 0.11815995244043213, 0.1377355655921357, 0.10024341169212546, 0.14587600449366228, 0.12935263184564455, 0.30374715104699135, 0.2072159501590899, 0.24070020126444952, 0.27821341689143864, 0.4030752054282597, 0.3400920922202723, 0.2168406301311084, 0.11274302418210677, 0.1646491957030126, 0.24545895734003612, 0.5057026499084064, 0.1578651618744646, 0.23004432448319026, 0.47598498740366524, 4.5670574477740695, 37.460194792066304, 79.42417022160122, 89.66191005706787, 80.17029557909284, 61.67633097512381, 32.7549580846514, 46.6918181010655, 73.23354761941093, 76.0908066885812, 39.83113554545811, 3.327791294881276, 1.2174723680530275, 2.007397106715611, 6.297278753348759, 6.338863287653242, 1.4296185672283173, 0.16266890482178756, 0.23711604358894484, 0.6606744027563504, 0.6262159517833165, 3.673657638686044, 39.7782667023795, 70.88402121407645, 94.13554940904889, 81.35656152452741, 94.15428870064872, 65.95703969682965, 79.99898079463414, 87.31179305485317, 48.92631013052804, 108.01971776144845, 121.64854676382882, 129.8963920048305, 112.57171889713833, 94.31215177263532, 78.8989975793021, 75.08490903036935, 72.46568829672677, 69.9895726612636, 83.2489173071725, 89.7281472342355, 60.54799910954067, 12.452272295951843, 2.9172697918755666, 1.876640260219574, 0.33029344944017275, 25.80631480898176, 105.42225878579276, 87.13217517307827, 83.9123660496303, 80.30088002341134, 94.49325656890869, 87.26919364929199, 83.52021666935512, 79.7762701851981, 81.61820983886719, 79.21555750710624, 84.61758736201695, 82.91285378592355, 85.83926132747105, 82.09644739968437, 80.77816568102155, 78.8582672391619, 73.82336630140031, 68.57286276136125, 65.19881752559117, 76.44738824026925, 78.48491273607526, 75.6999010358538, 61.24764796665737, 24.61407514980861, 6.137915304728916, 0.4307397295321737, 0.2417027231838022, 0.388075483164617, 1.057887988431113, 1.7134523711034229, 1.0527021352733885, 3.4720005052430287, 1.1025907439844949, 0.5154970586299896, 6.311722321169717, 43.09395054408482, 72.17169611794608, 59.588286127362935, 37.054812567574636, 25.712309156145366, 45.92760310854231, 67.4947316305978, 60.36837427956717, 24.637197017669678, 2.924054273537227, 0.6554810042892183, 0.45506284864885466, 0.20518388705594198, 0.19709536965404237, 0.2799100801348686, 0.10025410540401936, 0.23479615950158664, 0.23918530398181506, 0.3036917825894696, 0.24619394647223608, 0.264480465224811, 0.1759499657366957, 0.14216249090220245, 0.14669102004596166, 0.256019052118063, 0.19821863009461335, 0.5452250348670142, 0.30514976435473984, 0.7090081891843251, 0.6741720384785107, 0.13401830648737295, 0.0898507929274014, 0.11440588959625789, 0.18524824322334357, 0.16254471934267453, 0.1511612223195178, 0.2650320327707699, 0.17751347326806613, 0.1452056933194399, 0.2494917352284704, 0.3964263493461268, 0.16938703932932445, 0.34466959802167757, 0.3608175643852779, 0.3786739462188312, 0.2412394466144698, 0.09304423656846796, 0.143847347636308], [0.1397339055048568, 0.09712568577378988, 0.27863847836852074, 0.059035192908985276, 0.055511316284537315, 0.12009532430342265, 0.16879891231656075, 0.07269060837903193, 0.06301083814884935, 0.07812420824276549, 0.0534467208199203, 0.032567974379552264, 0.15638527699879237, 0.04123477325109499, 0.1446362803024905, 0.09259775374084711, 0.09168766864708491, 0.08642174157180957, 0.0989216933293002, 0.05064069014042616, 0.05074107261108501, 0.027659725164994597, 0.01854875048489443, 0.08772466451461826, 0.09140130651316472, 0.06667287128844432, 0.05269778100773692, 0.1409226038626262, 0.2210454980709723, 0.20383282883891038, 0.3647948923919882, 0.290909078504358, 0.39273093906896456, 0.42582135487880024, 0.44902513548731804, 0.39865018001624514, 0.43481332808732986, 0.3939294490431036, 0.22822579635041101, 0.34916733524629046, 0.32485086577279226, 0.11047778251980032, 0.332773142095123, 0.34368821925350596, 0.13021149433084897, 0.26842378505638664, 0.3552488274872303, 4.974538028240204, 21.97498777934483, 63.3567111151559, 70.19837297712053, 63.79036903381348, 33.146061761038645, 23.264479637145996, 30.9473876953125, 67.45221560341972, 69.41857664925712, 28.675945145743235, 2.6772318950721194, 0.4812684953212738, 0.7656723228948457, 4.241987713745662, 0.7208974797810827, 0.399810149201325, 0.5744853104863847, 2.2292902171611786, 0.05878845722015415, 0.10265391413122416, 0.8810459119932992, 12.518074342182704, 43.56551088605608, 73.75773361751011, 79.4669919695173, 66.52565247671944, 64.14834717341832, 53.52695907865252, 37.79180451801845, 31.928184986114502, 44.91689729690552, 55.131906100681846, 74.5410874230521, 70.18146106175014, 63.58172157832554, 54.802095958164756, 43.3386105128697, 30.132492542266846, 7.423137494495936, 0.24774510466626712, 0.24201726487704686, 0.06924384047410317, 0.0938753266153591, 0.056429350416042974, 0.07122197361396891, 8.36418240410941, 44.421059949057444, 62.49156311580113, 65.56498064313615, 65.65507098606655, 71.78817640032086, 69.86334473746163, 62.85440499441964, 64.46694292340959, 73.67682184491838, 74.83888026646206, 70.80457551138741, 70.65353557041713, 57.26898091179984, 45.737403120313374, 25.07641175815037, 11.126943366868154, 12.415475504738943, 13.845770869936262, 11.560287748064313, 16.241596596581594, 5.3262510640280585, 1.00189799283232, 0.3893442079424858, 0.18013503402471542, 0.5078358554414341, 5.899442706789289, 1.246854345713343, 0.9130957807813371, 0.31043365225195885, 0.8089322958673749, 0.8594409227371216, 1.3130619930369514, 25.562038728169032, 58.58595984322684, 53.32396745681763, 24.404154436928884, 19.03544987951006, 34.25224624361311, 50.50501380647932, 49.60982527051653, 17.448177337646484, 4.229737171104976, 0.1702596489340067, 0.09753341068114553, 0.3814614766410419, 0.03560942617644157, 0.04447859472462109, 0.31429839772837503, 0.16213298429335865, 0.14112635435802595, 0.1864731346390077, 0.11353593984884874, 0.20323160610028676, 0.2193739949060338, 0.29590385620083126, 0.23364832252264023, 0.1702318289982421, 0.1114748218762023, 0.2553405985236168, 0.3414293218936239, 0.265248458300318, 0.2404168721820627, 0.48900466305868967, 0.25673821781362804, 0.26570956355759073, 0.2157644871622324, 0.046878043828266006, 0.07560622585671288, 0.0451582900381514, 0.04063441903729524, 0.11775691621005535, 0.054719513415225914, 0.13859522874866212, 0.0516156635380217, 0.15920250011341913, 0.21431143156119756, 0.17857817613652774, 0.16197586272444042, 0.06399280724248715, 0.10246013810059854, 0.2117585385484355, 0.09447433054447174, 0.13788142347974436, 0.1940142506999629, 0.28150737871016773, 0.056701677053102424, 0.02470759571796017, 0.02886515110731125, 0.3126105282987867, 0.05736225124980722, 0.08490997912096125, 0.02421256710243012, 0.0976998010384185, 0.082518631725439, 0.07968283032200166, 0.03871247538232377, 0.009062971720205886, 0.08769097525094237, 0.07984438950994185, 0.051730213819869926, 0.06352789540375982, 0.07804214621761016, 0.13846955049250806, 0.07854830620012113, 0.09509836563042232, 0.17203871347010136, 0.1583312747201749, 0.05983028667313712, 0.07570264568286282, 0.11299680306443147, 0.1950460174786193, 0.19395623595586844, 0.30145522260240143, 0.2530991259430136, 0.33031147133026806, 0.39422040485910004, 0.3367763358567442, 0.351942597755364, 0.4826660060456821, 0.39322010853460854, 0.12364001838224274, 0.40306825722966877, 0.23372225569827215, 0.1301482277257102, 0.4357949782695089, 0.29878787430269377, 0.1901624516717025, 0.43593141809105873, 1.1801180924688066, 8.844121405056544, 31.7996780531747, 71.18192522866386, 68.41084466661725, 41.436370917728965, 15.005480800356183, 23.100925990513392, 45.5842787197658, 90.74814973558698, 72.9880816595895, 19.68577000073024, 0.500074391918523, 1.2564149584089006, 1.0917537254946572, 0.3553458037120955, 1.0872047181640352, 0.6623973931585039, 1.614330238529614, 3.7852248634610857, 0.3006427719124726, 0.23873497386063847, 2.9875677568571906, 26.856404747281754, 63.402131489345, 92.98792934417725, 76.32466220855713, 74.34529413495744, 62.4370128086635, 67.92186519077846, 78.64861229487828, 60.366706711905344, 81.70907838003976, 86.19337626865932, 95.90482480185372, 78.79113374437604, 79.87085601261684, 69.12248611450195, 66.21892424992153, 52.44069855553763, 27.532949107033865, 3.5312241273266927, 0.17372936489326612, 0.09027412414018597, 0.28471394521849497, 0.08519176792885576, 0.44432044508201735, 28.803124972752162, 65.99217673710415, 67.9476569039481, 71.74223491123745, 77.38861206599644, 71.88936301640102, 79.66277830941337, 75.83198629106793, 75.75952352796281, 73.32868235451835, 70.79938520703996, 69.88675321851457, 73.59602124350411, 63.87044007437569, 65.46109117780412, 53.117303712027415, 41.74453394753592, 20.15834825379508, 29.113045896802628, 48.06970841544015, 34.593739782060894, 15.420378582818167, 5.009972538266863, 0.4582598071013178, 0.2815276261951242, 0.08737101884824888, 10.648219432149615, 2.724909999540874, 0.8361099032419068, 0.27025770236338886, 0.4295334299760205, 0.5796486905642918, 0.9313813767262867, 16.417467662266322, 58.9415408543178, 68.8477473940168, 34.84578916004726, 19.63856393950326, 27.65705783026559, 47.46283538000924, 61.831553731645855, 27.24546217918396, 6.990358088697706, 0.12658119627407619, 0.19354633295110293, 0.31040165254047936, 0.058364148916942735, 0.12446863177631583, 0.5087786391377449, 0.11054870299994946, 0.17860812667225087, 0.1470754372754267, 0.19392329986606324, 0.3211558626166412, 0.16073799771921976, 0.17810193954833917, 0.2377014293202332, 0.27763853488223894, 0.2239559247557606, 0.42340688300984247, 0.19193923633013452, 0.42972168273159433, 0.3761703962726252, 0.6915493203060967, 0.4050580747425556, 0.12898858423743928, 0.28290763071605135, 0.14771507866680622, 0.004977464451388056, 0.006738838307293398, 0.07314840917076383, 0.04057869774156383, 0.13989436546606676, 0.04844722391239234, 0.05247889918142131, 0.2090686357447079, 0.07898866864187376, 0.2868673710950783, 0.1838471091219357, 0.20281197290335382, 0.12941106728145055, 0.17773250437208585, 0.14235078436987741, 0.24163997226527759, 0.16820475991283143, 0.28335139261824743, 0.12839342760188238, 0.13381408101746015, 0.24627689059291566, 0.46429095204387394, 0.2551826355712754, 0.29568012963448254, 0.23101924359798431, 0.181600778230599, 0.2084104839180197, 0.1579235294567687, 0.11338181061936276, 0.24632856781993592, 0.18311646261385509, 0.29474508123738424, 0.32029374316334724, 0.14924911063696655, 0.2170343790203333, 0.2440644864525114, 0.20031211418764933, 0.1621499748102256, 0.19417521277708666, 0.20760335294263704, 0.18108091184071132, 0.19010560400784016, 0.2355810073869569, 0.5037289272461618, 0.26943241379090715, 0.4060735431100641, 0.4355215015155928, 0.39836516816701206, 0.40115107010517803, 0.4161421614033835, 0.3656073702233178, 0.5439084055168288, 0.5149393571274621, 0.2547709819461618, 0.42065669915505816, 0.3477590765271868, 0.19030450976320676, 0.45883797322000774, 0.46549575882298605, 0.22361686080694199, 0.23748923784920148, 0.9361588060855865, 9.443784815924507, 42.60430056708199, 82.4028490611485, 83.35830279758999, 75.62169906071254, 41.739065715244834, 32.94420616967337, 41.04257481438773, 74.09187248774937, 76.04731791360038, 33.70160150527954, 3.040649171386446, 1.3905420069183623, 1.5556581297091074, 8.049697382109505, 4.523635114942278, 0.9494992388146264, 0.9055212672267641, 4.063451145376478, 0.14450924497629913, 0.45041200678263393, 1.3223527116434914, 18.358228070395334, 53.23650005885533, 82.2114678791591, 92.29513141087124, 73.82884843008858, 75.1338243484497, 73.08859430040631, 74.35966300964355, 64.66427871159145, 91.01361955915178, 109.50663225991386, 116.40998717716762, 106.43787697383335, 105.73817253112793, 86.45170334407261, 70.73626777103969, 49.52321250098092, 15.18611833027431, 1.1393670162984302, 0.5514248907566071, 0.13988175828542027, 0.4753297397068569, 0.19995174423924514, 0.17567180709115096, 14.309781125613622, 56.73321226664952, 82.7186585835048, 89.99489552634103, 74.65716402871269, 78.36372920445034, 88.94078431810651, 86.06248610360282, 82.75864546639579, 86.64935180119106, 80.35264410291398, 78.19668061392647, 82.15057386670793, 74.9237038748605, 82.51328372955322, 66.51948247637067, 54.32314273289272, 26.890754904065812, 37.67797565460205, 50.1373290334429, 25.324342591421946, 8.236384187425886, 2.2053434678486417, 0.3262929155358246, 0.16337481194308826, 1.1031981685331889, 11.012236424854823, 4.6511823279517035, 1.8250375092029572, 1.9836333990097046, 1.7361892653363091, 1.4695000329187937, 2.244150459766388, 32.696996212005615, 66.90232821873256, 60.22064168112618, 29.223383290427073, 25.807148592812673, 42.14788382393973, 59.681558745247976, 69.28034223828996, 35.48108727591378, 7.24032952104296, 0.20150105681802544, 0.30325030056493624, 0.48734936330999645, 0.27178090491465157, 0.267448078840971, 0.6414581281798226, 0.24058395464505467, 0.3839087353221008, 0.20184257706361158, 0.36236068872468813, 0.47135645576885765, 0.38649389946034973, 0.3613966261701924, 0.3480596403990473, 0.41100095584988594, 0.371013557272298, 0.45683613206659046, 0.4883523466331618, 0.45852807270629065, 0.5289385116526059, 0.7425669027226312, 0.33503687062433785, 0.35511586176497595, 0.32683471217751503, 0.21816793962248734, 0.2545629159680435, 0.1132552841944354, 0.1118762024811336, 0.18826771048562868, 0.14421123239610875, 0.19671209236340864, 0.14061790092715196, 0.23040337807365827, 0.21811120052422794, 0.35125575746808735, 0.30960383106555256, 0.3350202058042799, 0.2573180395577635, 0.32381574703114374, 0.20432583881275995], [0.8068569015179361, 0.20659848329211983, 0.22352323654506887, 0.4602745675614902, 0.06978824947561536, 0.12916197707610472, 0.030228894536516497, 0.0879787215963006, 0.03238679195887276, 0.04837592684530786, 0.1838974157082183, 0.12685969418713025, 0.07448069232382945, 0.12210259373698916, 1.097265709723745, 0.33068347136889187, 0.19347643027348177, 0.14385744423738547, 0.1279229178492512, 0.16772617559347833, 0.04315873554774693, 0.08160777310175554, 0.12225941675049917, 0.029130872205964158, 0.03799284828294601, 0.22310633105891092, 0.24637896940112114, 0.25070677431566374, 0.44646903978926794, 0.43345142688070026, 0.21893977320619992, 0.27547134831547737, 0.39308396726846695, 0.26295935256140573, 0.1495162227324077, 0.4047157402549471, 0.25110578004802975, 0.30067148751446177, 0.16350127729986394, 0.16751160924988134, 0.1860205924936703, 0.2763157987168857, 0.21873598199869904, 0.08226370611893279, 0.276101897337607, 0.143402242234775, 0.07356392366013356, 0.30458066346389906, 0.2902386859059334, 9.23101360457284, 44.13364771434239, 65.59071677071708, 75.49161488669259, 66.05509267534528, 37.70512226649693, 18.28668941770281, 32.09830468041556, 59.71538257598877, 70.80432537623814, 28.709032467433385, 2.609154096671513, 1.3411802670785358, 0.4208753231380667, 1.8973801987511771, 1.3977027769599641, 1.3861376089709145, 0.3347484661000115, 0.15810144133865833, 0.157950901559421, 0.8070044964551926, 0.11211559642106295, 5.4648871677262445, 25.594307899475098, 45.028030259268625, 51.41889647075108, 36.12339612415859, 19.358223233904155, 29.67504746573312, 24.438013008662633, 21.43461421557835, 11.61699025971549, 7.418500440461295, 6.77697456734521, 2.987098102058683, 1.226159244775772, 0.26132142330918995, 0.3679995318608624, 0.16341990738042764, 0.10940775315144233, 0.37865293877465384, 0.3391513984118189, 0.016038086099017943, 0.07874727980898959, 1.2366120495966502, 0.5804014844553811, 12.054195233753749, 58.114503724234446, 45.63364567075457, 105.15507275717599, 84.80565425327846, 78.73147651127407, 77.53985350472587, 100.4651220866612, 79.57230581556047, 51.63926553726196, 57.018060616084504, 44.59787423270089, 17.87211298942566, 14.027642573629107, 17.639702694756643, 22.06581810542515, 13.54345909186772, 2.3478390787328993, 0.19858274555632047, 0.2778739865337099, 0.910141222178936, 1.5112363419362476, 2.1609611979552676, 0.7902575465185302, 4.171922079154423, 2.0932158274309973, 0.6383712823901857, 0.3989410272666386, 1.1757893647466386, 22.82668580327715, 57.52594614028931, 51.72692401068551, 29.87554121017456, 22.64615249633789, 32.359647274017334, 49.558318274361746, 58.00923156738281, 38.73591532026018, 7.670999714306422, 0.20512976710285458, 0.1008123429492116, 0.12543828545936517, 0.0811812731304339, 0.10426312778145075, 0.05856838795755591, 0.13273465393909387, 0.11740681928183351, 0.05867736068155084, 0.07085257236446653, 0.0951241296050804, 0.0789341279970748, 0.0980832004653556, 0.06381674776119844, 0.11581853165158204, 0.07836370396294765, 0.17784123282347405, 0.06009220119033541, 0.11869132678423609, 0.18473467363842896, 0.20728068239986897, 0.21373243762978486, 0.22311395779252052, 0.07646787033549376, 0.08974017136331115, 0.1260304701115404, 0.12228711454996041, 0.13426268765968935, 0.10404629513089146, 0.10862739716789552, 0.1641340519168547, 0.17763430678418704, 0.22544878322098935, 0.045342861741249046, 0.32220582770449774, 0.4964228964277676, 0.17858930411083357, 0.10235533158161811, 0.28365285215633257, 0.20863005785005434, 0.18364372503544601, 0.38974022812076975, 0.4447731093636581, 0.12571271216230734, 0.35606084391474724, 0.398367312337671, 0.009532551031692751, 0.1159388901931899, 0.05494736886716314, 0.06524155594940696, 0.05195063252800277, 0.10844062361866236, 0.11112572239445788, 0.034384894384337325, 0.0744786567187735, 0.19625325341309818, 0.7281305545142719, 0.16463603212365083, 0.08198481465556792, 0.08611008365239416, 0.11097302487386124, 0.12932224704750947, 0.05205273847760899, 0.030416475542421852, 0.09200893462236438, 0.045451624119388204, 0.011274501398604895, 0.32260705903172493, 0.19519826716610364, 0.2764752544462681, 0.5942796426159995, 0.6552170270255634, 0.18014241648571833, 0.257459853376661, 0.43565617714609417, 0.3353603961212294, 0.07990941352077893, 0.44350077477949007, 0.22748863590615137, 0.3211909021650042, 0.2439253053494862, 0.2194203795599086, 0.11674429768962519, 0.22357205035431044, 0.16692293940910272, 0.04809280132342662, 0.20375698219452584, 0.1108921163582376, 0.051177044931266985, 0.2020947342472417, 0.8899643591472081, 12.466653329985482, 52.57688324792044, 73.32431888580322, 71.53787449428013, 39.47881323950631, 21.94767267363412, 22.158439329692296, 52.76802819115775, 90.02019391741071, 80.00818715776715, 17.17593128340585, 0.4337587489613465, 0.8506649136543274, 0.39879411086440086, 0.904430020068373, 0.9822456645114082, 2.2669307802404677, 0.25010483232992037, 0.8579272468175206, 0.3514544868043491, 0.6973832558308328, 0.6520312779716083, 14.47903229509081, 43.25227219717843, 62.319087982177734, 68.37843826838902, 65.00843688419887, 43.243823187691824, 47.21298163277762, 48.82678065981184, 50.449313572474885, 40.67334406716483, 32.97436829975673, 26.712630884987966, 14.461807710783821, 7.834859950201852, 1.0171311582837785, 0.09605632815510035, 0.3468435699386256, 0.16214344730334623, 1.3339570718152183, 0.9169487740312303, 0.27818331707801136, 0.06883106726620879, 0.2008947722081627, 3.4096940542970384, 29.340595926557267, 81.910722051348, 53.35768011638096, 98.97905526842389, 102.17451790400914, 97.70957769666398, 99.58973244258335, 109.15663760049003, 83.55165031978062, 67.68898936680385, 79.41338661738804, 69.56512805393764, 55.85003021785191, 32.185007776532856, 22.189205953053065, 28.652269159044536, 18.33721498080662, 5.372469612530299, 1.898575288908822, 0.028142770852095315, 1.3425053102629525, 2.40906269635473, 1.8312954476901462, 1.4797238728829791, 4.299185284546443, 1.4260272170816148, 0.44593695976904457, 0.19192633059407982, 0.9015128080333982, 11.660977567945208, 63.31994819641113, 74.58795302254813, 42.08515201296125, 24.45543040548052, 21.307335376739502, 42.170277867998394, 70.07147802625383, 50.91457189832415, 12.730999282428197, 0.20931229766990456, 0.1329845990985632, 0.24430001952818461, 0.140439649777753, 0.06392067218465464, 0.13356184240962776, 0.2602141084415572, 0.12044882747743811, 0.3158425534410136, 0.1432640246514763, 0.1348779967853001, 0.1588875920112644, 0.1661616095474788, 0.055004620259361606, 0.1464308425784111, 0.20341219141014985, 0.14637992531061172, 0.10743662249296904, 0.14410706370004586, 0.30402727744409014, 0.15907165142042295, 0.2670226645256792, 0.20113099738955498, 0.16338447428175382, 0.0741240203912769, 0.07259158297841038, 0.17898455075919628, 0.23277222524796212, 0.13473857140966825, 0.15459919641060488, 0.11464980936476163, 0.15288288279303483, 0.2067087995154517, 0.04343247014497008, 0.1862250215240887, 0.4559526794723102, 0.08648260616298233, 0.19813588953443936, 0.17715786663549288, 0.1469631397298404, 0.24313771618264063, 0.373246073190655, 0.7840231124843869, 0.2254546864756516, 0.40881523170641487, 0.8015013060399464, 0.1595641728490591, 0.1840960229081767, 0.12754244969359466, 0.32015260787946836, 0.32464168699724333, 0.12337785959243774, 0.27900320451174465, 0.34199693000742365, 0.24815955385565758, 0.4321957028337887, 0.9621291096721376, 0.3158335696373667, 0.34688962889569147, 0.1315078761960779, 0.36472815168755396, 0.42865776696375435, 0.14729700610041618, 0.15326753072440624, 0.2024510736976351, 0.1787754534078496, 0.10608019706393991, 0.47593879273959566, 0.220479762713824, 0.3969254254230431, 0.6103355182068688, 0.5715456796543938, 0.20130717222179684, 0.35521004242556437, 0.37100294498460634, 0.2732277044228145, 0.16011552326381207, 0.5476633640272277, 0.33278150164655274, 0.2911728657782078, 0.23882185348442622, 0.3733422080320971, 0.3786879511816161, 0.3066719083913735, 0.32538088304655893, 0.1263566283243043, 0.4298436019037451, 0.33075555892927305, 0.1325737325740712, 0.4772927686572075, 0.9904233685561589, 15.064471006393433, 59.837490218026296, 82.90860148838588, 89.69760990142822, 77.92328289576939, 46.43729863848005, 27.65352988243103, 41.61392865862165, 71.37444591522217, 83.26842784881592, 34.474717140197754, 3.8601212331226895, 2.102927020617894, 1.3872821075575692, 4.752847935472216, 4.020199477672577, 4.66054241997855, 0.6455521913511413, 0.6109198182821274, 0.3122517189809254, 0.7877153200762612, 0.21948390400835446, 8.336725728852407, 30.251480443137034, 55.69200733729771, 66.25072615487235, 70.82017421722412, 60.46070194244385, 71.18501717703683, 54.44721671513149, 42.33715622765677, 24.803514310291835, 17.37193649155753, 12.936267307826451, 5.039083319050925, 2.760647407599858, 0.30255955191595213, 0.24478519920791897, 0.3492013434214251, 0.23225037753582, 0.9227284810372761, 0.47664300352334976, 0.2228825366390603, 0.19828585934426102, 2.1796525035585677, 1.0082657997097288, 18.344522748674663, 89.48177800859723, 56.902466910226, 119.53996304103306, 129.61127962384904, 127.53337914603097, 142.61199842180525, 133.686856678554, 79.74159172603062, 65.58426189422607, 89.77094118935722, 77.98239816938127, 67.80922794342041, 42.12411751065935, 29.869694301060267, 33.269965512411936, 18.244562489645823, 3.0128835184233527, 1.2724500979696, 0.2680731995829514, 2.504141194479806, 4.887841446059091, 4.988420529024942, 3.8564278313091824, 7.764729176248823, 5.760803997516632, 0.8200691182698522, 1.0870230879102434, 2.0590888815266744, 29.972051688602992, 67.739912714277, 59.46200261797224, 35.014390672956196, 29.320991584232875, 38.63362046650478, 54.50789533342634, 74.10685975211007, 52.935132367270334, 13.861184579985482, 0.14543738588690758, 0.31706603350383894, 0.5256026163697243, 0.20675850899091788, 0.2495274261704513, 0.3333047607115337, 0.20752111449837685, 0.2792852036654949, 0.45069541728922297, 0.15255173056253366, 0.28226855929408756, 0.29136019572615623, 0.2702460044196674, 0.1483947807656867, 0.18723303957709245, 0.22250931523740292, 0.2650746176285403, 0.21874029748141766, 0.1858051847666502, 0.37500366887875963, 0.28582880539553507, 0.2849924974143505, 0.19214400462806225, 0.15122959150799684, 0.13060930584158215, 0.2888380267790386, 0.3554506780845778, 0.19180800765752792, 0.31960747284548624, 0.1735700313001871, 0.17978049947747163, 0.3532426437096936, 0.46447361367089407, 0.09137588180601597, 0.3468178127493177, 0.6620044399585042, 0.1424630954861641, 0.27774188933627947, 0.45866225979157854, 0.29327352877174107, 0.3624240096126284, 0.40905578594122616], [0.07335591196481671, 0.07696097530424595, 0.08712438493967056, 0.05338215482022081, 0.00184186507249251, 0.038361547248704095, 0.06426644684480769, 0.007941328737485622, 0.015945791765781384, 0.05079061245279653, 0.019255378549652438, 0.02479976282588073, 0.1408887313944953, 0.07161700313112565, 0.06842204635696751, 0.06182276404329708, 0.11220637083585773, 0.10982489612485681, 0.05012445052021316, 0.04756116574364049, 0.02553087073777403, 0.1402422503701278, 0.018765790088634406, 0.023883755817743282, 0.060044384827571254, 0.012380347237922251, 0.030869831929781606, 0.06775822197752339, 0.08794782789690153, 0.013594313391617366, 0.05313881180648293, 0.08103616163134575, 0.06664378927754504, 0.06362547552479164, 0.04007715518985476, 0.057823797554842064, 0.052481151917683225, 0.02741987321392766, 0.07906568915184055, 0.07694857846945524, 0.05075294358123626, 0.04555375721039517, 0.03649164383698787, 0.07084288966975041, 0.039988636903996976, 0.05614212993532419, 0.06552419292607478, 0.05861777173621314, 0.06547316030732223, 0.2666137250406401, 0.4757463059255055, 13.599153246198382, 41.36845575060163, 63.90259633745466, 69.80203383309501, 59.5197490964617, 30.430889878954204, 24.66360364641462, 25.201859746660503, 58.72002533503941, 71.70131696973527, 40.765980924878804, 3.9995277183396474, 0.9578834346362523, 0.5836909679429871, 1.297133139201573, 1.729690636907305, 2.0921080240181515, 0.6918210057275636, 0.5591049843600818, 0.1520382288311209, 0.8183783718517849, 1.4847001944269453, 0.2704527404691492, 0.39675326751811163, 1.7477968824761254, 5.589831846100943, 1.7737694659403391, 0.9189831848655428, 0.030391291715204716, 0.2346247344144753, 0.0972102176664131, 0.28090478533080643, 0.07790713810494967, 0.13451017652239117, 0.058474241223718436, 0.05499645069773708, 0.3131489051239831, 0.618510399545942, 1.0913860137973512, 1.914012449128287, 0.8707350024155208, 0.13959420871521744, 0.16768336003380163, 0.18987691056515488, 0.16637500881084374, 0.3343012843813215, 5.063801969800677, 8.369547281946454, 10.156145402363368, 12.133547135761805, 11.300945367131915, 10.138415336608887, 7.864023276737758, 6.595181899411338, 5.331008843013218, 5.242446669510432, 8.818207229886736, 11.100814666066851, 2.660757064819336, 0.2726580064211573, 0.47385759013039724, 0.1688246423644679, 0.4248090891965798, 0.4090350499110562, 1.5100018424647195, 1.7955096193722315, 1.1374597357852119, 0.15378051676920482, 0.3239729500242642, 0.6027555220893451, 1.4558862320014407, 23.260397570473806, 52.463238511766704, 55.10047245025635, 21.355500289372035, 16.88012215069362, 28.63462941987174, 53.206914629255024, 59.73838111332485, 44.190918241228374, 13.844934480530874, 1.199961279119764, 0.14669612262930187, 0.04348963672029121, 0.27228744487677303, 0.032518587208219936, 0.03461792366579175, 0.2585846744477749, 0.06350831966847181, 0.0545232776951577, 0.08320043049752712, 0.02622237934597901, 0.05609114820669804, 0.0076901757856830955, 0.0868949383231146, 0.020937304012477398, 0.0437176618059831, 0.06738242214279515, 0.030540681377585446, 0.025697493493290882, 0.024871641736743704, 0.047680767718702555, 0.03276604553684592, 0.08104287912803036, 0.10426315492285149, 0.02716414863243699, 0.030623635676290308, 0.04113883179213319, 0.04811198011572872, 0.07480504563344376, 0.016607030926804458, 0.14317331809018338, 0.023128466614122902, 0.0012682870167606908, 0.026013027544000318, 0.03954640170559287, 0.05587382361825023, 0.07014473141836268, 0.09067783212023121, 0.024586422934329936, 0.099868222538914, 0.01832701711516295, 0.05287218825625522, 0.02193470808145191, 0.049332006435309134, 0.11825303387429033, 0.12746863865426608, 0.2329541269157614, 0.033132641044046195, 0.05184400414249726, 0.03716997529513069, 0.05092598018901689, 0.04228397498705557, 0.03391012343178902, 0.10366341139056853, 0.02170994335652462, 0.0169332552967327, 0.13478955653096947, 0.23168697633913585, 0.5959985075252396, 0.09197547606059484, 0.07182681972959212, 0.1834606020046132, 0.11327196937054396, 0.1634821290416377, 0.05413170870659607, 0.0415761985017785, 0.030725287007434026, 0.029486695969743387, 0.04154519284410136, 0.03599741589277983, 0.1526892560401133, 0.07108447527779, 0.23202086985111237, 0.3322709176157202, 0.08123761189303227, 0.06963739078491926, 0.2236888533724206, 0.03791249616603766, 0.00896588184072503, 0.1516064362866538, 0.1377964030419077, 0.05836463746215616, 0.06405441822218043, 0.15946153764213833, 0.08167610836348363, 0.13101983309856483, 0.07203433609434537, 0.19828334876469203, 0.09216524194926023, 0.09766923303582839, 0.06873159403247492, 0.0975503401298608, 0.1439493450203112, 0.40881694161466187, 0.714873554451125, 15.729762758527484, 48.93445689337594, 75.89740358080182, 68.11622020176479, 38.23329653058733, 17.269209112439835, 25.981162752423966, 45.211709363119944, 93.0432300567627, 74.84914970397949, 28.021025317055837, 0.855172720338617, 1.0234293746096748, 0.37209782909069744, 0.6645404238786016, 0.7860790735908917, 0.8810553572007588, 0.10561588912137918, 1.0278808900288172, 0.4413791857659817, 1.1800037728888648, 1.437636137008667, 0.79549817102296, 2.304941334894725, 5.467889223779951, 12.688210538455419, 19.467820644378662, 7.761721474783761, 1.5144223081214088, 1.0448638073035648, 0.5159230157732964, 0.40119341069034165, 0.3493514625089509, 0.3707060180604458, 0.4025188609957695, 0.2520208795155798, 2.5350439591067175, 3.1403345423085347, 3.076540091208049, 4.485226775918688, 4.405750674860818, 0.6119717104094369, 0.7850672421710831, 0.5202667798314775, 0.696316978761128, 6.808977535792759, 14.845041683741979, 39.11721508843558, 31.598444325583323, 30.63773775100708, 36.83542319706508, 40.8657431602478, 28.555701357977732, 20.257108211517334, 23.19458944456918, 26.9553279876709, 20.243918793542043, 17.203418357031687, 5.589174372809274, 2.6604272425174713, 0.9981936258929116, 0.384037548410041, 0.6846808631505285, 2.1019447190420966, 1.7867344788142612, 2.6074094474315643, 0.22395971098116466, 0.4271917784852641, 0.1364375145307609, 0.4352141794349466, 1.7113832192761558, 13.544723664011274, 55.079905782427105, 78.20551177433559, 40.019337926592144, 19.00167121206011, 21.27084343773978, 46.2511042867388, 67.75464289528983, 59.69516331808907, 19.939504316874913, 1.952863518680845, 0.11791338638535567, 0.05369147518649697, 0.14268158376216888, 0.012932533098916923, 0.09604038936751229, 0.19409382928694996, 0.05504186165386012, 0.09114826044866017, 0.10813184268772602, 0.05296022817492485, 0.018143332596602182, 0.03532046186072486, 0.11160809293921505, 0.02830956324136683, 0.025208023775901114, 0.030426175200513432, 0.06923064296799046, 0.14923330077103206, 0.02809676108881831, 0.046969615521707704, 0.1500488320099456, 0.11864249940429415, 0.14246818449880394, 0.150809198351843, 0.04976727647174682, 0.05443176367719259, 0.05994168855249882, 0.16194824634918145, 0.05010678146832755, 0.10762562163706337, 0.07228377235255071, 0.06759155342089278, 0.08074775710701942, 0.1210994611361197, 0.08902272914669343, 0.035674931947141886, 0.12612636068037578, 0.11382747920496122, 0.12246035811092172, 0.0827214526278632, 0.11077643292290823, 0.10098861956170627, 0.19517139717936516, 0.21899162685232504, 0.1992683509098632, 0.21347481145390443, 0.15265199089688913, 0.09117445190038, 0.10443998793406145, 0.12612811130072388, 0.1365860187049423, 0.12665835927639688, 0.18020299609218324, 0.11634214355477265, 0.09959912233586822, 0.2549661286175251, 0.1662520311240639, 0.382597914231675, 0.16096743755042553, 0.1669074823813779, 0.20986645721963473, 0.12330992466637067, 0.14820850933236734, 0.09696694929152727, 0.24333012157252856, 0.187622532248497, 0.1828704529574939, 0.21851419604250363, 0.07087057389851127, 0.1533555502870253, 0.15954089909791946, 0.276712633137192, 0.2892939751701695, 0.17063809505530766, 0.16388382177267755, 0.2322877241032464, 0.11327242398900644, 0.17220525310507842, 0.16464574874511786, 0.10228110663592815, 0.1495225466787815, 0.08333139454147645, 0.2881464638880321, 0.25255605365548817, 0.15756139531731606, 0.18006792691137108, 0.26391719973513056, 0.1285469393645014, 0.11708569579890796, 0.23580378400427954, 0.20261842757463455, 0.13092901797166892, 0.48021198915583746, 0.9900642335414886, 20.178395543779644, 56.731975487300325, 87.13746970040458, 84.07096563066754, 70.57832826886857, 42.914735657828196, 35.09807825088501, 37.70990262712751, 73.78873647962297, 86.57052448817662, 50.75213691166469, 6.564131702695574, 1.335133705820356, 2.111087028469358, 3.5590820610523224, 6.809218551431384, 10.106153113501412, 4.721881985664368, 2.512199802058084, 0.23742594410266193, 0.9370824822357723, 1.5797189814703805, 0.2849557750991413, 0.4735115372708866, 2.470062017440796, 14.306032572473798, 22.60956675665719, 9.036151375089373, 0.4944689869880676, 1.1257602721452713, 0.6202430522867611, 0.8124137233410562, 0.6494759150913784, 0.3213501679045813, 0.31431324407458305, 0.19936021098068782, 2.893956414290837, 1.4700087713343757, 3.21500791822161, 4.805026735578265, 3.970261037349701, 0.5766041310770171, 0.40548650175333023, 0.5418921794210161, 0.30630142827119144, 1.7562575084822518, 7.800312638282776, 17.29593014717102, 15.057574919291906, 15.890300886971609, 20.010679926191056, 20.1823125907353, 14.308373246874128, 14.028843743460518, 14.272936565535408, 22.003998245511735, 23.514441081455775, 27.382876702717372, 6.028523734637669, 1.9060999708516257, 0.9387732829366411, 0.35670132668954985, 2.650356045791081, 2.605701276234218, 2.8962430230208804, 2.393076194184167, 1.6404068278414863, 1.2734009155205317, 1.155173516699246, 0.7653748531426702, 3.033283212355205, 34.09442138671875, 65.60619735717773, 70.8855150767735, 30.325166089194163, 24.458032505852835, 38.17883655003139, 62.892126764569966, 74.6500768661499, 62.619312695094514, 22.84166090829032, 2.4816778855664388, 0.2486931537943227, 0.20245908041085514, 0.29047326903258053, 0.07287007410611425, 0.11693271329360348, 0.5729200659053666, 0.11830139985041958, 0.2008349389902183, 0.15995002857276372, 0.09441796464047261, 0.07834904760654483, 0.19370999559760094, 0.20566450698035105, 0.10325797993157591, 0.227258883948837, 0.08467990825218813, 0.16655999102762767, 0.1525756014244897, 0.09185074775346688, 0.14063395506569318, 0.18696195126644202, 0.21411215939692088, 0.2838307911796229, 0.16615851542779378, 0.10687368948544775, 0.08605595012860638, 0.19465803115495614, 0.16469376188303742, 0.1320315966648715, 0.20659304144127028, 0.2532606172774519, 0.1311983149498701, 0.194543738716415, 0.13523447194269725, 0.1630763379590852, 0.15271537963833126, 0.15401594127927506, 0.12811708743018763, 0.16549669951200485, 0.29997243359684944, 0.1404025610536337, 0.13596372066863946, 0.18452587484249047], [0.037394831622285504, 0.04849157974656139, 0.04539951941530619, 0.005586874139096055, 0.034547892066517046, 0.032436043423201354, 0.04555457823776773, 0.1947408259979316, 0.018896654048668485, 0.019731275870331695, 0.06345558392682246, 0.03479168630604233, 0.09058622989271368, 0.0660087415682418, 0.07893159706145525, 0.049015982143048725, 0.05160562800509589, 0.026097181153350642, 0.07804882978754384, 0.047832128525312455, 0.03483154684571283, 0.10291181850646224, 0.04402720948149051, 0.02757738663681916, 0.00197128502519003, 0.06019473461700337, 0.04439250898680516, 0.018140248654942428, 0.033547395574195046, 0.039713786116668155, 0.0759834913270814, 0.06163351384124585, 0.03261250663282616, 0.0823341855513198, 0.020386413305199573, 0.03234482117529426, 0.056790409077491076, 0.013681874943098851, 0.052573833015880415, 0.05639679091317313, 0.09065140996660505, 0.03233818171013679, 0.07161093024270875, 0.023420886369422078, 0.026955154757680636, 0.03047578628840191, 0.0948979670980147, 0.13209009995417936, 0.04210707412234374, 0.03444655964683209, 0.04878282733261585, 0.37543676421046257, 0.24374953763825552, 13.641725727490016, 47.90072475160871, 67.32395185743059, 67.97276769365583, 62.11754158564976, 41.87111275536673, 11.642078467777797, 27.396380526678904, 47.75303384235927, 61.689977237156455, 45.86526387078421, 11.270940440041677, 1.3446444869041443, 0.4237875411553042, 0.4171931578644684, 0.03694127167442015, 2.0480416800294603, 1.4553369986159461, 1.1873329281806946, 2.229420495884759, 1.4808830278260368, 0.834889354450362, 0.5830110215715, 0.46817428937980105, 3.1542556924479346, 2.696785862956728, 0.33583010520253864, 0.4274723662861756, 0.335732531866857, 0.14209196397236415, 0.24195573532155581, 0.3216635696589947, 0.3661604848291193, 1.1342017906052726, 2.7003411693232398, 9.263947197369166, 4.013078442641667, 4.314489994730268, 2.8102175933974127, 0.709750343646322, 0.2986993119120598, 0.1905380886580263, 0.03913491092888372, 0.13200189040175506, 0.3005438415067536, 0.534257629087993, 0.10440741146781615, 0.11654874389725071, 0.09180498056645904, 0.10727708533938442, 0.16232308266418322, 0.053207045287958214, 0.030032594355621507, 0.05309112775804741, 0.048542527548436604, 0.41229644204889027, 0.8013549053243229, 0.05525272998160549, 0.16739127784967422, 0.6182929426431656, 0.3967504176710333, 2.195526966026851, 0.5725405748401369, 0.4657900258898735, 0.09584525626684938, 0.3862147501536778, 5.409195184707642, 33.61626720428467, 61.887062890189036, 51.947518893650596, 24.85170180456979, 14.808740820203509, 34.827612672533306, 61.62620667048863, 65.56546006883893, 44.79407051631382, 20.410639081682476, 1.8731023243495395, 0.13354390194373472, 0.12397904161896024, 0.10757703174437795, 0.09335997926869563, 0.04543969886643546, 0.1077371524380786, 0.08169946353882551, 0.08685973592634712, 0.038796556049159596, 0.03131284744345716, 0.014770747228924717, 0.06825734555189099, 0.01786171511879989, 0.03282558698473232, 0.03492304390030248, 0.09344934233065162, 0.026552586716466715, 0.046518555975386074, 0.019624579631324326, 0.05540477950125933, 0.028090221707576087, 0.030687149946710894, 0.06301861416016306, 0.04697265535859125, 0.03399831262816276, 0.043285360360252004, 0.0313637341771807, 0.031196543148585727, 0.03634742121877415, 0.015127205422946384, 0.05651431317840304, 0.018234244414738247, 0.01766639881368194, 0.030202838791800395, 0.026064448624051044, 0.01680293077203844, 0.0293791549546378, 0.0868750572470682, 0.033061164165181775, 0.05426260828971863, 0.05889143169458423, 0.01499013795650431, 0.05817018968186208, 0.025433585779475312, 0.035592971702239344, 0.02666598857779588, 0.06037136406770774, 0.06673925236931869, 0.040375975226717334, 0.026622991510001675, 0.021532769381467785, 0.01801190205982753, 0.04439312984634723, 0.0475737118561353, 0.024353756669110486, 0.02279338057685111, 0.042735862346099954, 0.09928000731659786, 0.005044960450114948, 0.04022462120545762, 0.038342107220419815, 0.06235924775579146, 0.025995290638612847, 0.04029191830860717, 0.04938863357529044, 0.039878619236073325, 0.10188925944800888, 0.03368675648900015, 0.06541024654039315, 0.0546261944941112, 0.04232449709836926, 0.05009820478569184, 0.027646783805851425, 0.02297146209249539, 0.023329318068655472, 0.06617182745997395, 0.050646576431712935, 0.027192134809281145, 0.07644066108124596, 0.021364650456234813, 0.05353610423792686, 0.04576340078243187, 0.01965143435102488, 0.05784331900732858, 0.030632778935666596, 0.06767284870147705, 0.06375976439033236, 0.02853991909484778, 0.03491898626089096, 0.10408326850405761, 0.08127082618219511, 0.045479220138596635, 0.10475853298391614, 0.024373400257900357, 0.05301501987768071, 0.06624591669866017, 0.2220801961209093, 0.7817350924015045, 16.73381393296378, 60.22144072396414, 80.75085926055908, 63.966415541512625, 47.72726992198399, 23.433150632040842, 16.255352292742046, 55.54151630401611, 93.25790854862758, 87.50889955248151, 34.75161675044468, 4.834348133632115, 1.5643898440258843, 0.2490457748728139, 0.2426968312689236, 0.7992288651210921, 0.4487627052835056, 1.08530883703913, 0.6532646917871067, 1.335547340767724, 3.232780541692461, 1.966443772826876, 0.7327911672847611, 2.0870145601885657, 3.402770174401147, 4.248466040406909, 0.7124971619674138, 0.5762154119355338, 0.4686927986996514, 0.15371032910687582, 1.3922480068036487, 1.0501561633178165, 0.7578878977469036, 3.013376840523311, 4.025916542325701, 6.231712077345167, 6.939902876104627, 4.949265258652823, 5.363536834716797, 2.44573398573058, 0.6552506823624883, 0.43795985781720703, 0.4578781990068299, 0.4530344089227063, 0.20698087848722935, 0.18457567931285926, 0.4202429013592856, 0.2818645052611828, 0.40356380492448807, 0.6411237461226327, 0.25886523510728565, 0.16349460051528045, 0.15550144442490169, 0.4232345622565065, 0.28184689049209866, 1.2929782250097819, 0.6508072007979665, 0.2361601505960737, 0.640082330576011, 0.8997283694999558, 0.8671508718814168, 0.3116090106112616, 0.20196313916572503, 0.6126220726541111, 0.20606296988470213, 0.35496340851698605, 0.8700694409864289, 19.79079375948225, 63.84410640171596, 79.01733234950474, 40.389075892312185, 19.90460525240217, 17.750733171190532, 44.780403409685405, 66.77307782854352, 57.63160392216274, 27.679365021841868, 2.6207410863467624, 0.027612122540761317, 0.1533056101096528, 0.05095402743401272, 0.051187148317694664, 0.041356495648090325, 0.048287228747670136, 0.07472174867455449, 0.07648188886897904, 0.058178399955587726, 0.10131566665534462, 0.02437220773260508, 0.09929689605321203, 0.05690059977184449, 0.02679503067130489, 0.051739869373185296, 0.031752565276942084, 0.02023927298640566, 0.013395656997870122, 0.02742054157092103, 0.05979706559862409, 0.035999037591474395, 0.0372958333630647, 0.00840685295406729, 0.03938091040721961, 0.020240926915513616, 0.013101863209158182, 0.13593410940042563, 0.07666322056736265, 0.03154832623632891, 0.031361742676900964, 0.02307897766253778, 0.04146829786311303, 0.03979133927662458, 0.025677456354190196, 0.021533240963305746, 0.048054918713335476, 0.02733993500338069, 0.07672909953232322, 0.04765842016786337, 0.017444209129150425, 0.030765924469700882, 0.024500717176124454, 0.048669369492147646, 0.03360138999830399, 0.049143940276865444, 0.12285264634660312, 0.16144033574632236, 0.15443790863667214, 0.1774857754686049, 0.17698923711265835, 0.12140918523073196, 0.13801761902868748, 0.3533705339900085, 0.06837634702346154, 0.0823505518159696, 0.1294132928763117, 0.1627347498599972, 0.27037690739546505, 0.10983139649033546, 0.13749233792935098, 0.1387275837893997, 0.2585698552429676, 0.12280398181506566, 0.18043162168136664, 0.16449006567043917, 0.14473298511334828, 0.2104777901300362, 0.10413314761327845, 0.1417139656841755, 0.14213077617543085, 0.1725238931498357, 0.18979343718716077, 0.13539968164903776, 0.11840423861784594, 0.11833219176956586, 0.16053312085568905, 0.16417849596057618, 0.15240357922656195, 0.21624395357710974, 0.16789399087429047, 0.1706328024821622, 0.2249937712081841, 0.07261715696326324, 0.1308631593627589, 0.26344168239406174, 0.16329464981598513, 0.16846736653574876, 0.1482289196657283, 0.1420592043016638, 0.15941964489008698, 0.20077653069581303, 0.25083995716912405, 0.25455227653895107, 0.1493335882467883, 0.1615876049867698, 0.1127754852973989, 0.6168940205659185, 1.2711416653224399, 21.824079854147776, 69.86297648293632, 91.56628622327531, 86.03434589930943, 77.95391750335693, 54.75157560620989, 19.310574225017003, 40.098481382642476, 60.53939723968506, 78.96474143436977, 61.88144179752895, 17.478666033063615, 2.5887248728956496, 0.7753615315471376, 1.0592288821935654, 3.3220342780862535, 7.619989514350891, 7.097754657268524, 1.917306329522814, 9.137409210205078, 4.795941965920584, 2.283939753259931, 0.48277305173022406, 2.420156798192433, 4.828394395964486, 5.194689529282706, 0.5431757505450929, 0.39654191743050304, 0.9644949712923595, 0.5475728745971407, 0.6282972629581178, 0.49420294697795597, 1.5536523801939828, 4.0040909477642606, 10.546390976224627, 18.079532350812638, 13.531603728021894, 12.916952184268407, 9.818553277424403, 3.8892498186656406, 0.5458743657384599, 0.4146287568977901, 0.25529342676912037, 0.4394041603165013, 0.31192838347383905, 0.8697058004992348, 0.5396958972726549, 0.21670010552874633, 0.43816244123237474, 0.8425351956060955, 0.5532493357147489, 0.3033462454165731, 0.26383599266409874, 0.32119548906173023, 0.23903160222939082, 1.4063911736011505, 1.993256219795772, 0.33784141870481627, 1.1842676869460513, 3.514563867024013, 4.878472234521594, 8.1925836120333, 4.1513032998357495, 2.728876118149076, 1.059198375259127, 0.7741173154541424, 10.888643605368477, 46.89152669906616, 77.66767951420375, 69.45948764256069, 34.005758898598806, 23.48655101231166, 46.08672033037458, 75.90316363743374, 80.47819110325405, 65.5427325112479, 32.53784772327968, 4.314267652375357, 0.2500834177647318, 0.27550030819007326, 0.1605954917946032, 0.12975686229765415, 0.22841035787548336, 0.16452988210533345, 0.1496426338063819, 0.24995009920426778, 0.20143337973526546, 0.13507421554199286, 0.1909277577485357, 0.21504997621689523, 0.1163396058338029, 0.10479982862515108, 0.18960321668003285, 0.1741316547351224, 0.13993365264364652, 0.15275056846439838, 0.17722350811319693, 0.13102615704493864, 0.11042535211890936, 0.12794963855828556, 0.14017838665417262, 0.12369554968816893, 0.1512621340474912, 0.11066753483776536, 0.2586982069270951, 0.16186893917620182, 0.10494233454976763, 0.19461585341819695, 0.17429374318037713, 0.1398249106215579, 0.07575173090611186, 0.12394629551896028, 0.08272380714437791, 0.1588798567120518, 0.12732552204813274, 0.19533881890986646, 0.1417152141886098, 0.1481384980891432, 0.16467366367578506, 0.14886721755777085, 0.14336786765073026, 0.06920057029596396, 0.14257514875914368], [0.026542500293414508, 0.013872810456502651, 0.05065860007224338, 0.010832284859913801, 0.03423500260604279, 0.023777210552777563, 0.03773655542837722, 0.05980874318629503, 0.026322899219979132, 0.007531859146963272, 0.030350342126829282, 0.021716837272314087, 0.01763635328305619, 0.06122050314609494, 0.019402159244886467, 0.03413838939741254, 0.043903444694089036, 0.05572655777047787, 0.0873266833701304, 0.022843164691169347, 0.021572470465408902, 0.030533648362117152, 0.029223074936973195, 0.030115901492536068, 0.00447653215711138, 0.01926021141532276, 0.05680293822661042, 0.015633007478235022, 0.04468410601839423, 0.022892390710434744, 0.0957196865762983, 0.01797715767419764, 0.0395063240347164, 0.04846911684476903, 0.04433175974658557, 0.06453772514526333, 0.0481590772313731, 0.02160908930402781, 0.03418548312038183, 0.04579806035118444, 0.06457382320825543, 0.05042003733771188, 0.07742218234177146, 0.045340673465813906, 0.019318319457982267, 0.02767921269073018, 0.0571360955280917, 0.08082253845142466, 0.09129355515220336, 0.0406296692921647, 0.036852234309273105, 0.14635882287153176, 0.07687252826456513, 0.2899213486484119, 0.5766955975975309, 23.46339614050729, 56.761484486716135, 64.18761144365583, 54.11503028869629, 61.21563066755022, 25.028340646198817, 16.24855695452009, 15.207701172147479, 38.49857527869088, 61.81062575748989, 57.33096579142979, 36.09119817188808, 15.629451615469796, 4.02374392747879, 0.3823864555784634, 1.0928221195936203, 2.452106135232108, 1.8500004325594221, 2.1990258182798113, 0.5555207995431763, 1.386427479130881, 0.5955324353916305, 0.9561705951179776, 0.3647079313439982, 1.1276455138410841, 0.7237861390624727, 0.17724068861986908, 1.7313777463776725, 4.715193910258157, 4.269152998924255, 1.2057833267109734, 3.89234220130103, 1.1853782044989722, 3.9431105170931136, 2.733627817460469, 2.0190103692667822, 3.6026726705687384, 1.6490430044276374, 0.6513967663049698, 0.6714267943586621, 0.29216018851314274, 0.2614820732602051, 0.16732620634138584, 0.3695138048912798, 0.22202421698187078, 0.09709608129092626, 0.1788151069943394, 0.2491974410201822, 0.1397023129143885, 0.4812897741794586, 0.266178946942091, 0.49086227480854305, 0.10752868612429925, 0.5172507730977876, 0.5310724771448544, 0.19047384496246064, 0.9092948990208762, 1.1824544242450168, 1.5719075777700968, 0.35763998489294735, 0.6636633766548974, 6.113312602043152, 15.56324917929513, 46.03632852009365, 55.093770912715364, 41.158741746629985, 18.85447015081133, 17.821891410010203, 38.31517062868391, 52.32999985558646, 63.561460631234304, 43.775655678340364, 25.278494903019496, 4.314102632658822, 0.05597418912553361, 0.0421469584107399, 0.06660139440957989, 0.03903350047767162, 0.06149100113127913, 0.01422267668281815, 0.03457477901663099, 0.0444217097413327, 0.050413065390395265, 0.08602648135274649, 0.022771893069148064, 0.025086883222684264, 0.022849882187853967, 0.03644140171153205, 0.010776962203505849, 0.036079121687050374, 0.016382583416998386, 0.07444050948002509, 0.01613059077811028, 0.04311124488179173, 0.05617220939270087, 0.047391979822090695, 0.054243761979575665, 0.013611548181091036, 0.01764678066995527, 0.00729159328953496, 0.01158295408822596, 0.03065174738211291, 0.015786663429545503, 0.02915154377530728, 0.05387318686449102, 0.0355195949253227, 0.03883392297263656, 0.03214720802913819, 0.07549222518822976, 0.051254774510328255, 0.03603921704260366, 0.004552710435486266, 0.025984449345352392, 0.024550884662728225, 0.02491475415549108, 0.018380894491981183, 0.040817664204431434, 0.022939632014770592, 0.02011383561018322, 0.028061115947951163, 0.07753935855414186, 0.06952168699353933, 0.06226427320923124, 0.060545862918453555, 0.038903798508856974, 0.02585274739457028, 0.024086069515241042, 0.054575355257838964, 0.020726367831230164, 0.05915239626275642, 0.042761046173317094, 0.004519916413950601, 0.0577343666393842, 0.0017744533605374663, 0.07976558445287601, 0.02678399599556412, 0.015629608017791594, 0.0053323352975504735, 0.04178536031395197, 0.022330748615786433, 0.032955390733799765, 0.027859384094231894, 0.021082863344677856, 0.01534606858954898, 0.06647551259292023, 0.056285565452916284, 0.023307336926726357, 0.025612408594627465, 0.009760003603462662, 0.04835300253970282, 0.05427987361326814, 0.022761384258046746, 0.04664019016282899, 0.010861103938493346, 0.017472137630517994, 0.03184471033247454, 0.06788001222802059, 0.08179790539933102, 0.016138778999447823, 0.015922623187569634, 0.029640438434268748, 0.061303352271871905, 0.05636203634951796, 0.025095648198787655, 0.07937935553491116, 0.02128183186453368, 0.04983184247144631, 0.10258422179945878, 0.057582320512405465, 0.014164071613257485, 0.08960033886666809, 0.047034883805151494, 0.1469467327530895, 0.03065815953803914, 0.4392295868269035, 1.719837874174118, 28.188327516828263, 68.85476507459367, 73.95040716443742, 55.594614437648225, 35.19411972590855, 11.665381857327052, 13.823620881353106, 31.39692919594901, 82.66318416595459, 93.75603880201066, 67.30658136095319, 28.75226763316563, 4.616631976195744, 1.1217045869146074, 0.7454070331794875, 1.4151858559676578, 1.467428166951452, 0.19902441757065908, 2.1208705263478413, 1.3831443467310496, 1.0153163756643022, 0.6530289958630289, 0.681544728577137, 0.5316010287829808, 0.7192361546414239, 0.9289325709853853, 0.42873066876615795, 1.1717676605497087, 1.4240780302456446, 3.4644923252718787, 2.686621516942978, 1.9597609085696084, 1.193969000663076, 2.0300306464944566, 3.881589863981519, 1.544732955949647, 1.95546236208507, 2.8720042322363173, 3.0579805842467715, 2.6351103952952792, 0.7332399774874959, 1.360592014023236, 1.00260714335101, 0.8324386488114084, 0.7908904839839254, 1.0245324011359895, 0.7177209045205797, 1.0691432016236442, 0.6051369085907936, 1.0859943202563693, 1.3876996508666446, 0.5027007024203027, 0.671127044728824, 0.658980345087392, 0.3053393198975495, 0.3778945266136101, 0.8898030849439758, 1.0885980491127287, 0.9537264576980046, 0.13780515614364827, 0.5029056742787361, 1.7371144614049365, 5.230147055217198, 32.309585503169465, 69.01887457711356, 76.46730177743095, 38.335514954158235, 22.133910451616558, 25.339753695896693, 39.802901540483745, 66.20577130998883, 58.55054487500872, 35.16317939758301, 6.741970411368778, 0.08075471209096056, 0.0823666195252112, 0.014775917665766818, 0.037370078664805205, 0.07059004038040127, 0.03862800116517714, 0.09993104131094047, 0.05023384393591966, 0.05550829341102924, 0.01333920712516244, 0.03864705782117588, 0.025747189398056695, 0.052577140874096324, 0.03166940063238144, 0.058758798454489024, 0.013413804416943873, 0.018848790188453028, 0.022502092278695533, 0.0679390990574445, 0.00909348119915064, 0.03691944659554532, 0.028768958590392555, 0.02132931404880115, 0.010826175500239645, 0.07017791856612478, 0.02014144180741693, 0.0854658010814871, 0.04526300834757941, 0.019311506966395036, 0.04747825215703674, 0.0179337008989283, 0.04744040347369654, 0.021871443172650676, 0.018820612325466106, 0.1062945666323815, 0.0463791272070791, 0.024101504490577748, 0.03708552482670971, 0.10283561902386801, 0.0049842769429752866, 0.06553445916090693, 0.013277102511243095, 0.0739246125199965, 0.06050340698233672, 0.0895018834354622, 0.03945688936593277, 0.03519791843635695, 0.15036086312362126, 0.21106418009315217, 0.13003561805401528, 0.056767040331448824, 0.10470515263399907, 0.15802288055419922, 0.21970806483711514, 0.1383118046713727, 0.17670729224170956, 0.14802161364683084, 0.14891881336058888, 0.10273809997098786, 0.08671193742858511, 0.14298301615885325, 0.07697597092815808, 0.13804960516946657, 0.11575018960450377, 0.15809194184839725, 0.14284432360104152, 0.13491541120622838, 0.09725175079490457, 0.11021073827786104, 0.10738512847040381, 0.18695698439010552, 0.10607225820422173, 0.13177528684692724, 0.19972527639142104, 0.0815790303583656, 0.09547225878174816, 0.12691270134278707, 0.2573259105639798, 0.13125361555388995, 0.10174419544637203, 0.21171034899141106, 0.12384147542927947, 0.14258547606212751, 0.1367238155965294, 0.10823777557483741, 0.09175872483423778, 0.08769301085599832, 0.17375295077051434, 0.1511146476758378, 0.1175745531384434, 0.15906099842063018, 0.13957804601107324, 0.11904879260276045, 0.22402757805372986, 0.18017884024551936, 0.1833459838692631, 0.21303058814789566, 0.24620314740708896, 0.3310651880289827, 0.2290067087326731, 0.7943851564611707, 2.325797438621521, 37.68482657841274, 79.61020823887416, 84.6811772755214, 70.83965001787458, 79.7402229309082, 39.581379073006765, 21.59774923324585, 24.334981645856583, 54.55674464362008, 79.11454459599086, 73.65788800375802, 49.52401154381888, 21.847477912902832, 6.167393905775888, 0.8353976043207305, 1.7608096642153603, 4.993233025074005, 3.670448873724256, 3.3828218962465013, 1.60425600196634, 3.2762017888682227, 1.676211220877511, 3.2820000605923787, 1.8148562269551414, 2.6314562942300523, 4.918071755341121, 4.3713610001972745, 4.0678428411483765, 14.158640435763768, 12.669268880571638, 10.559623820441109, 14.645708288465228, 8.978126100131444, 10.591503892626081, 8.299284492220197, 6.219968753201621, 11.91308947971889, 6.875709772109985, 8.380466376032148, 3.6285577501569475, 0.3326761930116585, 1.3243008128234317, 0.8258879088929721, 0.9590939411095211, 0.8806433507374355, 0.6356499769857952, 0.7348591248903955, 1.5533821604081561, 0.9161389831985746, 1.7519134730100632, 1.7026206723281314, 1.7739731350115366, 1.0618775572095598, 2.2936055660247803, 3.083407951252801, 1.5179911851882935, 5.049432226589747, 5.5563050508499146, 4.591292764459338, 0.6175111617360796, 1.067353063396045, 11.738733121326991, 27.269581113542827, 64.90529087611607, 70.95423970903668, 57.39295761925833, 29.833674839564733, 27.704989978245326, 51.87912777491978, 68.12218870435441, 84.47575378417969, 66.47092846461705, 40.333115100860596, 8.970963375908987, 0.16660098811345442, 0.22781615118895257, 0.23531580876026834, 0.1624463317649705, 0.26268196744578226, 0.12564305375729287, 0.13489367094423088, 0.1963486825781209, 0.2003603173153741, 0.23846241991434777, 0.062150788227362294, 0.14611703370298657, 0.08777121880224772, 0.11536916505013194, 0.15302389594061033, 0.08922058995813131, 0.11334714426526002, 0.14068321670804704, 0.1234783370579992, 0.11371503238167081, 0.2202662955969572, 0.19083219287650927, 0.14868573658168316, 0.07253674377820321, 0.16134122892149858, 0.08194276584046227, 0.12868822392608437, 0.103646909418915, 0.1408379226922989, 0.1510329113474914, 0.18409450298973493, 0.10369129917983498, 0.07817273028194904, 0.07471406765814338, 0.10968110098370484, 0.25714425316878725, 0.10595083436263458, 0.12303217314183712, 0.12094227171369962, 0.07633647881448269, 0.08862294988440615, 0.06865350822252886, 0.12237951744879995, 0.1819231773593596, 0.2180391808173486, 0.10791432471679789, 0.20646654894309385], [0.04228017179827605, 0.014255516929551959, 0.020173841854557395, 0.014980882738849946, 0.04706345012943659, 0.019899498272155012, 0.02548026050707059, 0.026100020822403685, 0.14976947914276803, 0.01276957443250077, 0.03999230099309768, 0.03358397539705038, 0.03152455376195056, 0.04142097343823739, 0.007211823864573879, 0.02970768803996699, 0.04537622530811599, 0.052139570603945425, 0.017649935857791985, 0.043532153724559715, 0.037418434462909184, 0.05468168169526117, 0.0360734355635941, 0.05872635090989726, 0.06906484293618373, 0.046389590217066665, 0.06843979004770517, 0.06425805336662702, 0.049584886258734126, 0.033101496286690235, 0.020549707846449952, 0.07881998483623777, 0.06495833543262311, 0.08420350203024489, 0.028271322704053352, 0.05237868295184203, 0.006873789592646062, 0.11091906776917831, 0.033750087554965696, 0.04814169655687042, 0.06816372129001788, 0.057217037970466275, 0.060295856690832546, 0.04967900924384594, 0.02239157588753317, 0.08465189832661833, 0.05510906036943197, 0.02365921500937215, 0.021251050123412694, 0.04229980520904064, 0.010242492043679314, 0.12343259022704192, 0.05423568741285375, 0.13086553423532418, 0.030236714652606418, 0.5456538689988, 4.082486603941236, 34.88198580060686, 64.24276624407086, 62.49514838627407, 64.5339582988194, 70.84903008597237, 50.22961500712803, 24.551306860787527, 11.467392069952828, 16.960062912532262, 32.698840958731516, 68.11381612505231, 70.6071424484253, 55.6295291355678, 47.68954815183367, 30.09705672945295, 18.364014182771953, 7.187675637858255, 1.3463146601404463, 0.370635803256716, 0.2713836905147348, 0.7155660401497568, 0.9864867797919682, 1.6905033396823066, 1.5806009684290205, 1.0068995015961784, 1.0036665265049254, 0.3757525815495423, 2.2448945684092383, 2.2166992127895355, 1.2156160048076083, 1.3639192240578788, 0.7168780554618154, 3.8613024268831526, 1.21834425841059, 1.1796846985816956, 2.3280569059508185, 1.994739443063736, 2.2300608158111572, 1.7452696923698698, 2.713434615305492, 3.1085061473505835, 0.31387591468436377, 1.7146359533071518, 1.6068160874503, 1.6383083633014133, 0.7805840798786708, 0.811263416494642, 2.429841935634613, 1.7233413947480065, 0.5300220506531852, 0.797502509185246, 1.7485323058707374, 1.3910093818392073, 0.29398010085736004, 0.05253846777070846, 2.692064562014171, 9.478727306638445, 30.28105197634016, 46.81150776999337, 61.90020888192313, 84.65018136160714, 33.69725888116019, 13.852118049349103, 19.221948214939662, 36.92709425517491, 56.31535802568708, 57.8341578074864, 50.13244097573416, 24.411925997052872, 2.8027597878660475, 0.10187876929662057, 0.19078213056283339, 0.029650857339480093, 0.09046170514609132, 0.014539687395361918, 0.10469009594193526, 0.02954077860340476, 0.060443329491785595, 0.059510622040501664, 0.01871793301376913, 0.034262096509337425, 0.06853192831788744, 0.007690132529075656, 0.028269473696127534, 0.09244414698332548, 0.031315520871430635, 0.05462424370593258, 0.030867443486515964, 0.04263871648748006, 0.023627768303932886, 0.10977849111493145, 0.06431892474314996, 0.032714419199952056, 0.03274243251819696, 0.024717107082584074, 0.02773237251676619, 0.05385252208049808, 0.04160777073619621, 0.01325773457730455, 0.02566345817675548, 0.022131255927628705, 0.017424663927938257, 0.051756591868719885, 0.11553141634379115, 0.08123679086565971, 0.0182620304237519, 0.037160068683858426, 0.05481208934049521, 0.05585924529337457, 0.059587642550468445, 0.029890515908066715, 0.0715244577399322, 0.044632143806666136, 0.06298513524234295, 0.015897619172132442, 0.013820462327982699, 0.02698120371704655, 0.026993914374283383, 0.031408778724393675, 0.03317943960428238, 0.026374886876770427, 0.02972549619153142, 0.018966784035520892, 0.019702585713405694, 0.030967703820871453, 0.024683964039598192, 0.028540000519050018, 0.027871543441766074, 0.03000160905399493, 0.011988402510594045, 0.024489545097042407, 0.09106813224830798, 0.029641364634569203, 0.08121911502842392, 0.009858744867545153, 0.0502404494743262, 0.020886480043243085, 0.061188991979828904, 0.05924058545913015, 0.046390859077551534, 0.04124145682102867, 0.0554800968883293, 0.026601493824273348, 0.006995392821928752, 0.03130187553220561, 0.02157618714097355, 0.028482535388320684, 0.08372358099690505, 0.005514788699136781, 0.08300039158867938, 0.05439154690663729, 0.047736180281000476, 0.02745689238820757, 0.03364419537995543, 0.0949467605512057, 0.011442705988883972, 0.029517382715961764, 0.027947018588227884, 0.028200371689828377, 0.03754155803471804, 0.056956718010561805, 0.0871525780696954, 0.015781852616263286, 0.0481031014850097, 0.027893851976841688, 0.08074730927390711, 0.040429257189056704, 0.060663086628275256, 0.012698722654022276, 0.02600129906620298, 0.12107645879898753, 0.012712036359256931, 0.07775650333080973, 0.08435386539037738, 0.548489222569125, 6.394638649054936, 46.352732113429475, 74.42269011906215, 70.07405580793107, 53.57787200382778, 38.266460282461985, 19.838878767830984, 15.814949410302297, 25.45631320135934, 48.21739585059029, 76.37710721152169, 98.93346118927002, 81.49970831189836, 47.140525817871094, 28.096602610179357, 11.988103100231715, 1.590042701789311, 3.6171631387301852, 1.9547651537827082, 0.681707956961223, 0.2862389391022069, 0.5430159962603024, 0.32419293107731, 0.0728708001385842, 0.61944216383355, 0.3395582480090005, 1.2876704526799065, 0.9512941539287567, 1.032290716256414, 1.0287232505423682, 0.7089839247720582, 0.20885385226990494, 0.7022410780191422, 1.6122025698423386, 0.7842193448117801, 1.5026967887367522, 0.8193710414426667, 1.5100856551102229, 0.9099925958684513, 2.4305371897561208, 2.8925976072038924, 1.2374767746244157, 1.1876685044595172, 0.9926929324865341, 1.7912238836288452, 0.28388309265886036, 1.0139380267688205, 0.678284937781947, 2.2620081986699785, 1.510552270071847, 1.291788128869874, 1.0777047936405455, 1.6046451010874339, 1.3019699539457048, 0.5749640847955431, 0.10908077391130583, 2.069731350455965, 1.7506483580384935, 6.672177493572235, 31.318424974169048, 64.75189549582345, 83.56070382254464, 57.261810370853965, 27.663474491664342, 17.094203097479685, 21.009280238832744, 42.604647977011545, 63.696116719927105, 65.28717081887382, 35.47550439834595, 5.195798201220376, 0.12253217425729547, 0.16015464759298734, 0.033163643309048245, 0.035787850352270265, 0.13488807981567724, 0.042013626279575486, 0.03490364458411932, 0.023399670275726488, 0.12873785197734833, 0.10156978480517864, 0.04005937757236617, 0.06357330296720777, 0.02069461578503251, 0.030983191382672106, 0.08024376165121794, 0.039730590036404986, 0.0014319270807651005, 0.02096893561870924, 0.017695475735568574, 0.024869499262422323, 0.05883190381739821, 0.07944357208907604, 0.07595672312059573, 0.031880000938794444, 0.006246133250117834, 0.04218069856454219, 0.018680842593312263, 0.02238040041577603, 0.0016965069683335188, 0.012493695664618696, 0.05444276272984488, 0.12303430374179568, 0.020845761156773994, 0.055586609922881634, 0.024491078586184552, 0.031801314625356875, 0.04730867947052632, 0.07801233138889074, 0.03073759563267231, 0.035914610871779065, 0.0271640434595091, 0.06354407846395459, 0.054649458067225556, 0.06645245597298656, 0.015280944494796651, 0.035558661579021385, 0.026030067254656127, 0.039078304144952974, 0.016438140167987773, 0.1411723726029907, 0.13923826281513485, 0.13161717461688177, 0.1289300945188318, 0.11509974593562738, 0.07803949314568724, 0.08708533524934735, 0.1339447668620518, 0.1655985340476036, 0.10402101970144681, 0.19807419713054383, 0.18863029245819363, 0.2057200518569776, 0.18017164777432168, 0.10310074301170451, 0.12408891000917979, 0.09755701012909412, 0.12718039697834424, 0.1029373382085136, 0.2140508605433362, 0.10868807855461325, 0.1271974282073123, 0.14846177931342805, 0.15668921997504576, 0.15527022683194705, 0.16300567532224314, 0.19096944694008144, 0.10867838228919677, 0.25186435505747795, 0.1454458132918392, 0.14286268475864614, 0.09748547896742821, 0.16344589527164186, 0.2243776206991502, 0.11955500686807291, 0.13062365007187637, 0.06291259306349925, 0.18064879359943525, 0.16072374848382814, 0.1586698501237801, 0.15669813592519077, 0.1876848896167108, 0.11482720556003706, 0.20852542775017874, 0.19449611912880624, 0.2289134237383093, 0.1972909505878176, 0.2019757056342704, 0.11976748332381248, 0.12485072841601712, 0.07873322734875338, 0.328576565853187, 0.19400959594973496, 0.29204947873950005, 0.12624302799148218, 0.9551564838205064, 8.21655489717211, 58.380056926182334, 94.74106407165527, 80.14946487971714, 78.93090370723179, 97.78332587650844, 72.15438120705741, 36.86342096328735, 19.1149685382843, 28.670824323381694, 48.19830220086234, 86.67674160003662, 89.47298853737968, 73.8765686580113, 60.707460267203196, 42.10810191290719, 23.702337741851807, 9.185787779944283, 1.7611805243151528, 0.531128931258406, 0.46421240483011517, 1.2711628356150217, 2.067288624388831, 3.683362969330379, 2.6409193064485277, 2.061904421874455, 2.823969381196158, 3.894947341510228, 7.874213678496225, 5.252660521439143, 7.829449040549142, 9.150880898748126, 12.146276235580444, 14.863926887512207, 9.453253473554339, 10.962834732873098, 12.790795479501996, 12.104211841310773, 10.804633804730006, 13.1258601972035, 13.47570981298174, 11.496256623949323, 9.647686651774816, 12.214155793190002, 9.437776361192975, 9.569097314562116, 8.424475397382464, 6.094520764691489, 11.191626753125872, 8.016368610518319, 3.78459301165172, 3.9918842656271796, 5.439078084060124, 4.307443652834211, 0.9874798293624605, 0.20031751532639774, 4.533326983451843, 17.82028463908604, 46.3787704876491, 71.31153692517961, 82.22837284633091, 98.16906901768276, 45.79570198059082, 26.987373079572404, 30.764122009277344, 51.59385905947004, 75.67836162022182, 78.37752832685197, 75.38174302237374, 42.308279514312744, 7.799128838947841, 0.22952709080917494, 0.3872474804520607, 0.14193765153842314, 0.19116311440510408, 0.23107841185161046, 0.18210036999412946, 0.08915393067789928, 0.1489067082958562, 0.2718518796776022, 0.14784374247704232, 0.1871555508779628, 0.19792523155254976, 0.2304227298923901, 0.09664463837231908, 0.3700034086193357, 0.1484458337404898, 0.08947964105755091, 0.10105593702090637, 0.10880215386194841, 0.16981336288154125, 0.17299859624888214, 0.23260459995695523, 0.2025733185665948, 0.09442440393779959, 0.0936581954093916, 0.2848703611109938, 0.09292557436440672, 0.14408385780240807, 0.13929288488413605, 0.14348511850195272, 0.08487941111837115, 0.26414803734847475, 0.1694946549832821, 0.17790966986545495, 0.1907248350658587, 0.13723541742988996, 0.11674653685518674, 0.1794923935085535, 0.16801980483744824, 0.06344626764101641, 0.10523164152566876, 0.17469939855592592, 0.0923735521999853, 0.15987036856157438, 0.12679002221141542, 0.07322912091123206, 0.10424400666462523, 0.14767481439879962, 0.13556746978844914], [0.009174843485067998, 0.05381221370771527, 0.05270583521840828, 0.09586034010031394, 0.08782976280365672, 0.03681406671447413, 0.044993344960468154, 0.007173140583160732, 0.023675180938360945, 0.1278773881494999, 0.03539071737655571, 0.0781230479478836, 0.06145739329180547, 0.03639566166592496, 0.029894034112138406, 0.013407501674789404, 0.047562794227685244, 0.04643118441370981, 0.05112460435235074, 0.037803255420710356, 0.004669759422540665, 0.01904179438549493, 0.11132392247340508, 0.07654378483338015, 0.06923155899026565, 0.07077389622905425, 0.04452445012118135, 0.02268583108005779, 0.024687656966437186, 0.022365046864641563, 0.019280333371300782, 0.04437911131286195, 0.03150591779766338, 0.045381365210882256, 0.007885362320978726, 0.03036357695236802, 0.03156629723629781, 0.0723217770989452, 0.02814226534350642, 0.08335082778441054, 0.05737056330378566, 0.019589439999046068, 0.033191066301826916, 0.03432802975709949, 0.037894189291234524, 0.056323733047715256, 0.04365333329354014, 0.04772562227611031, 0.031454257534018586, 0.04030733462423086, 0.03617205384320446, 0.04829314218035766, 0.03479532325374229, 0.04457609002877559, 0.05538729365382876, 0.07747649228466408, 0.1635309157094785, 0.36436548829078674, 13.23626012461526, 49.47575283050537, 68.35498114994594, 60.78783008030483, 57.035702092306956, 65.09237112317766, 55.11130121776036, 48.230576583317344, 19.400742735181534, 14.925305536815099, 16.055221591676982, 25.999057837894984, 28.9108533178057, 34.741937909807476, 36.84711354119437, 48.24661997386387, 60.724858556474956, 50.70238086155483, 45.30725056784493, 38.20871727807181, 30.44105509349278, 20.89798746790205, 15.852565220424108, 7.688482250486102, 3.377385799373899, 1.2638102301529475, 0.45898887940815514, 0.2121381110378674, 0.43745000660419464, 0.0857936352757471, 0.5756641700863838, 0.9468311305556978, 0.5312676238162177, 0.9320639286722455, 0.955928385257721, 0.20861883488084587, 0.27866933814116884, 1.1597465170281274, 1.3600865325757434, 1.036580468927111, 1.4624128703560149, 1.1806447442088808, 0.9054802294288362, 1.08296523136752, 1.4808226653507777, 0.7840773952858788, 0.06423713413200208, 0.04234990823481764, 0.779674842953682, 2.5722854350294386, 7.0903313755989075, 15.01725799696786, 25.751001937048777, 41.1688756942749, 49.292924880981445, 41.3416565486363, 35.63229744774954, 23.8764648096902, 12.840532422065735, 27.255656923566544, 25.35581271989005, 50.99435806274414, 52.324194635663716, 53.00887359891619, 47.655578408922466, 33.77049289430891, 4.908709926264627, 0.15361944612647804, 0.12768899968692235, 0.04000154942540186, 0.10338819080165454, 0.06368439950581108, 0.04016848600336483, 0.04480879022074597, 0.045825011762125153, 0.036554727237671614, 0.04792531852477363, 0.08360413847757237, 0.018053869450730935, 0.03496406812752996, 0.06796547371361937, 0.03818205098754593, 0.03205208759754896, 0.0574537313410214, 0.027191591981266226, 0.01427666177707059, 0.024332163988479545, 0.016385596112481186, 0.11058112340314047, 0.02813045883418194, 0.02427683454672141, 0.019692685887483612, 0.034178100659378936, 0.01772213537645127, 0.07072129619440862, 0.06348592122750622, 0.053361439146101475, 0.03717842984146305, 0.008880817298112171, 0.01003713850929801, 0.03549777663179806, 0.023693937342613935, 0.029189314427120343, 0.10503941934023585, 0.057415278761514595, 0.02313930621104581, 0.006254323591877307, 0.055047849725399695, 0.04379496730065771, 0.055297876309071264, 0.04984179658016988, 0.04604760856766786, 0.0586322991709624, 0.056198875818933756, 0.07395100074687175, 0.03726829841200795, 0.07629084733447858, 0.009699934594599264, 0.05802942080689328, 0.02548557343626661, 0.03473606339788862, 0.10975380601095301, 0.05283959482663444, 0.017116222264511243, 0.054564634404544315, 0.06489540809499365, 0.04065195577485221, 0.12565819865890912, 0.04137936227821878, 0.01804000019494976, 0.04599185673786061, 0.03083101294136473, 0.03356386022642255, 0.038199312918420346, 0.04538303440702813, 0.032769176975956986, 0.019534037614773427, 0.04982850747182965, 0.007254854859119015, 0.11759178792791707, 0.054420045377420526, 0.07324937518153872, 0.11748121386127812, 0.07082399925483124, 0.06738653406500816, 0.03608175440292273, 0.03390931936779192, 0.04665984732231923, 0.03184261705194201, 0.03835680089624865, 0.008388428183804666, 0.002806064182160688, 0.08449968935123511, 0.06381237121032816, 0.023858889205647365, 0.03299873894346612, 0.03907874180004001, 0.05865125065403325, 0.04990952116038118, 0.04799132641138775, 0.021045479457825422, 0.04556417950828161, 0.03577137212934239, 0.04213044626106109, 0.06577305921486445, 0.04783660007108535, 0.04047195400510516, 0.014052495859297258, 0.034611477583114586, 0.12059175409376621, 0.12900488264858723, 0.028332870919257402, 0.04431713053158351, 0.04482270697397845, 0.07491471046315772, 0.5796856571521077, 21.17928355080741, 61.344158445085796, 82.27748271397182, 69.73057855878557, 57.13286917550223, 47.07545246396746, 19.62290096282959, 8.780840686389379, 13.089775596346174, 35.79994705745152, 44.79689843314034, 64.18397058759416, 77.76938724517822, 70.17840385437012, 76.2726410457066, 72.00348717825753, 57.33513123648507, 36.70200388772147, 20.898281029292516, 10.728320002555847, 4.363026201725006, 1.0351934347833907, 2.9389868208340237, 2.3132687509059906, 2.7094276760305678, 1.2370782302958625, 0.6673940164702279, 0.2719139792025089, 0.39264704499925884, 0.2246641931789262, 0.24558600623692783, 0.6068416056888444, 0.6379038531865392, 1.3833748315061842, 0.9672501491648811, 0.7432246474283082, 0.4543754383921623, 0.6911294971193586, 1.3359146182026183, 0.7200311262692723, 0.5585616677999496, 0.7027657755783626, 1.5372483347143446, 0.42851741878049715, 0.38807705736586023, 0.5390879298959459, 0.1785334606787988, 0.22487943805754185, 1.435731244938714, 1.8363044474806105, 3.223898789712361, 0.9560720175504684, 8.893990363393511, 18.037295988627843, 42.481036049979075, 53.634003026144846, 62.71220316205706, 53.41677107129778, 34.85738222939627, 51.61143800190517, 22.407117094312394, 24.53763106891087, 39.37161990574428, 59.22872379847935, 62.01873820168631, 46.26250975472586, 8.621785998344421, 0.3225965281682355, 0.06408162069107805, 0.035652611537703445, 0.032062981477273364, 0.09499678893813066, 0.06998390504824263, 0.04338929835440857, 0.08621340417968375, 0.03901748026588133, 0.023397154607144848, 0.06275162420102529, 0.03780941651867969, 0.015854954586497376, 0.06661804565893752, 0.017362667879621898, 0.014808305838544453, 0.03784532459186656, 0.06873988573040281, 0.06855834368616343, 0.030004787990557294, 0.017455148809988583, 0.053219581222427745, 0.08766848181507417, 0.07396282082689659, 0.023083427155922567, 0.018406622843550782, 0.01721549024140196, 0.07341551448085479, 0.02113867284996169, 0.029124202206730843, 0.005378619867510029, 0.030312724145395414, 0.06413905868040663, 0.06132543180137873, 0.045157469010778835, 0.032478509537343464, 0.033115823553608995, 0.06766278602715049, 0.053171425592154264, 0.015447504485824277, 0.016507759557238648, 0.04562159374888454, 0.041184280067682266, 0.020310000084074478, 0.036496078063334735, 0.09882762801966496, 0.048391221024628193, 0.009081361715548804, 0.033794575703463385, 0.034320331777312925, 0.05388778215274215, 0.0927913465670177, 0.09447566047310829, 0.16200164705514908, 0.22140388669712202, 0.2252675872296095, 0.1762791909277439, 0.13849044937108243, 0.23139295354485512, 0.11007329422448363, 0.206926432837333, 0.1680384645504611, 0.15739756982241357, 0.14814053369419916, 0.12633400596678257, 0.12345434405973979, 0.14642166878495896, 0.16099221764930657, 0.10072304095540728, 0.12158309375601155, 0.17626856506935187, 0.06259503867477179, 0.24541368548359188, 0.24857926847679274, 0.1363387062613453, 0.2663377784192562, 0.23377005170498574, 0.24829944063510212, 0.11258234030434064, 0.08594212587922812, 0.11489433981478214, 0.18934671687228338, 0.21573168677943094, 0.1238875479570457, 0.07472820154258183, 0.13301106196429047, 0.19454337230750493, 0.2179576616202082, 0.15284483054918901, 0.0892686845202531, 0.19789613597095013, 0.11177423223853111, 0.12923980504274368, 0.10892502976847546, 0.14819710994405405, 0.11761169614536421, 0.1515560754175697, 0.22436343931726047, 0.20691981033555099, 0.13798093742557935, 0.17878545501402446, 0.11965503650052206, 0.2345091120472976, 0.2489056166793619, 0.19118402685437882, 0.09540311606334788, 0.28424323190535816, 0.5151248414601598, 0.5908746453268188, 23.8597127028874, 77.07242039271763, 94.1714368547712, 81.87775979723249, 71.66127450125558, 92.69953741346086, 77.52794429234096, 69.27526310511998, 28.115498236247472, 25.090874433517456, 26.261362757001603, 39.25374024254935, 42.50560140609741, 44.35624367850167, 54.48823193141392, 69.45583983830043, 85.65740612574986, 74.91588020324707, 64.5095909663609, 56.59235143661499, 45.49851015635899, 31.028236934116908, 22.886884995869227, 13.18507100854601, 6.23719550882067, 2.787105496440615, 1.6125059021370751, 0.3288664088717529, 0.6854297486799104, 0.8000796937516758, 1.4673989628042494, 1.3740291787045342, 2.175257985080991, 2.7543718814849854, 2.8952190322535376, 2.698063028710229, 1.840996435710362, 2.0072520630700246, 3.4586158863135745, 2.720734566450119, 2.47116938659123, 2.677890888282231, 2.7393922167164937, 3.6294045618602206, 2.2921683745724812, 1.4193016865423747, 0.17938120876039776, 0.17761272937059402, 1.6107850287641798, 4.368867031165531, 15.06410448891776, 29.337476185389928, 46.633345535823274, 66.87813459123883, 78.56248242514474, 65.40956333705357, 52.98946033205305, 36.81339045933315, 22.685378551483154, 43.783795492989675, 39.48184960229056, 72.89685181209019, 69.13618796212333, 77.6182986668178, 69.05271230425153, 56.68867431368147, 11.878102694238935, 0.5332129565732819, 0.5353113125477518, 0.08616959117352962, 0.1641548965126276, 0.17459179647266865, 0.2673951531095164, 0.10309219347046954, 0.22579375042447022, 0.21312288248113223, 0.16645145256604466, 0.18807729998869555, 0.07933598357651915, 0.08680567025606122, 0.14316539280116558, 0.13488432073167392, 0.16512132036898816, 0.28131187920059475, 0.20520433810140404, 0.2790935310934271, 0.10322156974247523, 0.08402911174510207, 0.24357431275503977, 0.21062024177185126, 0.15173548007650034, 0.09986157968108143, 0.08352236822247505, 0.1082623792546136, 0.2184179119233574, 0.10452855711004563, 0.09974457310246569, 0.14208564002599033, 0.14214849951011793, 0.15101556799241475, 0.13706045038998127, 0.10928565756018672, 0.16105091092841967, 0.16553370681192192, 0.18125534962330545, 0.16890880784818105, 0.06935823469289712, 0.10410443879663944, 0.1506093426474503, 0.14141953576888355, 0.111478485965303, 0.13250738541994775, 0.11494266507881028, 0.12865144732807363, 0.11531262951237814, 0.11755125224590302, 0.150686614215374, 0.16597307180719717], [0.0036214181538006024, 0.034864292945712805, 0.08344031298266989, 0.08361399759139333, 0.020723750382395725, 0.034612549668444056, 0.013809217306386148, 0.04617554634543402, 0.03526156162843108, 0.01104684781083571, 0.04975134786218405, 0.029803717708481208, 0.006813074279177401, 0.04960247388641749, 0.08964111203593866, 0.0389948579083596, 0.12485965793686253, 0.042814453664634905, 0.022606103215366602, 0.011136305019525545, 0.04532005957194737, 0.022090034925245812, 0.022344745096883604, 0.031212749957506145, 0.02917103808639305, 0.04140588960477284, 0.0683774733915925, 0.04511168486039553, 0.05821197386831045, 0.029914111963340213, 0.12977682479790278, 0.08387412756149258, 0.11006163020751306, 0.07385289815387555, 0.009459597490993994, 0.12717091105878353, 0.11524610593914986, 0.08855684700288943, 0.031685441200222285, 0.07360912766307592, 0.054277213755995035, 0.09038580421890531, 0.08151084437434163, 0.09056895439113889, 0.06852021001811538, 0.12885176443627902, 0.05048441674028124, 0.04992889333516359, 0.037756789342633316, 0.03884087795657771, 0.07852481531777553, 0.07437309702592236, 0.04689376887732318, 0.05694906413555145, 0.030561285093426704, 0.16516861425978796, 0.10580111561076981, 0.07274776816900287, 0.39816804017339436, 0.5941316676991326, 20.132372413362774, 60.699150221688406, 71.27578149523053, 60.37679549625942, 58.09469093595232, 59.18745149884905, 77.73699474334717, 61.680527687072754, 42.14465638569423, 21.557347195489065, 25.52801513671875, 21.45105365344456, 24.969505037580216, 20.49883951459612, 19.503244297845022, 30.501063210623606, 35.21665620803833, 32.829790183476035, 28.576825618743896, 39.039016587393625, 39.57507358278547, 46.99606234686715, 48.331363677978516, 42.41524355752127, 44.23846476418631, 33.1563173021589, 31.214538982936315, 20.932716301509313, 18.752602611269268, 12.767644950321742, 6.885275270257678, 6.789949025426592, 5.88602226121085, 4.898115660463061, 3.758936354092189, 7.374502709933689, 9.017108968326024, 11.264831236430577, 13.448089855057852, 16.572508028575353, 14.940777438027517, 23.863662753786357, 30.534657750810894, 36.20935228892735, 40.3375688961574, 50.196301868983674, 52.42545073372977, 62.398234912327354, 53.440853527614046, 43.48950801576887, 41.36552708489554, 33.8511996950422, 17.458465882710048, 13.748212082045418, 20.16101462500436, 27.887560844421387, 45.0960704939706, 48.42597382409232, 49.583957127162385, 48.44667598179409, 49.33567019871303, 33.07105595724923, 10.253310748508998, 0.34167136890547617, 0.11273418287081377, 0.12149690623794283, 0.09777902678719588, 0.0275584894365498, 0.1371041209037815, 0.010866982596261161, 0.061353489224399836, 0.09577312120901686, 0.014840390366901244, 0.15680910354214056, 0.039544542519641776, 0.020391276704945734, 0.052926613550101004, 0.1327160077967814, 0.01780065375247172, 0.030127344985625575, 0.02889861984710608, 0.04326028849131294, 0.043507719678538184, 0.02109078863369567, 0.06880855347429003, 0.0906290454523904, 0.08033016630049263, 0.03840753495959299, 0.10294836440256663, 0.06459956682686295, 0.1381316671946219, 0.029235906034175838, 0.05800559065703835, 0.07555565464177302, 0.20488584733435086, 0.07016482284026486, 0.1396482065320015, 0.03560822516945856, 0.021662895434669087, 0.09767025762370654, 0.0857178700555648, 0.09387929604521819, 0.12530004073466572, 0.05892119902585234, 0.08972309263689177, 0.025135883629055958, 0.06148887053132057, 0.008377700545159834, 0.044894611329904625, 0.07081954127975873, 0.07237302684890372, 0.049108212015458515, 0.06549133826047182, 0.06481301358767919, 0.03147369756230286, 0.036511436703481844, 0.050796834618917534, 0.035896334531051774, 0.056626814284494946, 0.07853500012840543, 0.05523857234844139, 0.03498714849618929, 0.02551564441195556, 0.04088410296078239, 0.06705804847713027, 0.10446683756474938, 0.03464774188718625, 0.018558275420218706, 0.09281884759132351, 0.015765528760052154, 0.04606051430372255, 0.04705862235277891, 0.07431680576077529, 0.021049669411565577, 0.0410074470564723, 0.009090888347210628, 0.037564770717705996, 0.06196695952011006, 0.04532026652512806, 0.049927868747285435, 0.029127560955073153, 0.0787740344447749, 0.0536239880935422, 0.054592885210045745, 0.03429212507658771, 0.03779808837654335, 0.03987407983679857, 0.023857428659019724, 0.09085807816258498, 0.03525106469169259, 0.046382010980908356, 0.05989496463111468, 0.039867789817175696, 0.06329272195164647, 0.07117503256137882, 0.038598685059696436, 0.026317012928692356, 0.014817885056670223, 0.06708082011235611, 0.07451938239059278, 0.02717309511665787, 0.05700417474976607, 0.06298522345189538, 0.06323543324002198, 0.0357335641581033, 0.020514413847454956, 0.0347382856000747, 0.04961046702893717, 0.06449431247477021, 0.08192393649369478, 0.021352937245475392, 0.1526790237320321, 0.09729952644556761, 0.007521276545178677, 0.4015186189540795, 2.02956685423851, 30.164384773799352, 70.29288932255336, 82.41860062735421, 67.29729856763566, 56.570711272103445, 54.57464320319039, 45.41150481360299, 26.65578940936497, 11.030559693064008, 12.425879563604083, 15.253406422478811, 24.456071376800537, 30.501817090170725, 37.762111391339985, 48.737124579293386, 63.117436000279014, 68.29441370282854, 70.02935804639543, 64.29336302621024, 61.58863081250872, 61.3022677557809, 52.217081206185476, 44.27728434971401, 31.871220179966517, 21.80221561023167, 17.555926527295792, 7.910237482615879, 8.00957761492048, 5.814936109951564, 1.4369292663676398, 2.194466931479318, 2.9237049094268253, 2.1555457285472324, 1.7601425285850252, 0.04264685890770384, 2.5341958446162085, 3.1509164316313605, 2.505325210945947, 2.0810189161981856, 1.7733835152217319, 9.040963871138436, 2.003656370299203, 4.58476927450725, 9.924998811313085, 19.63250858443124, 29.06578251293727, 39.16240617207119, 44.87759133747646, 54.21072782788958, 54.72378976004464, 57.406732422964915, 55.44427626473563, 38.74157115391323, 24.643618890217372, 22.734028100967407, 17.062875407082693, 18.32746318408421, 31.79479694366455, 49.3873404775347, 57.92183017730713, 64.5009126663208, 48.430587427956716, 17.34528320176261, 0.5284426382609776, 0.1913057831781251, 0.06142437577779804, 0.047879425808787346, 0.03467668140573161, 0.05424609953271491, 0.03485758562705346, 0.03818896525938596, 0.06914468615182809, 0.050093295584831915, 0.0037201662032332805, 0.04388573832277741, 0.05508041940629482, 0.009293411542395396, 0.01854969704124544, 0.029928927775472403, 0.03879050351679325, 0.07067153922149114, 0.04059988839019622, 0.045758393193994246, 0.03839602700567671, 0.05945579641099487, 0.0528706411964127, 0.019408230436965823, 0.04068950590278421, 0.020777851675770113, 0.00590912441423695, 0.0597977644896933, 0.025141734297254255, 0.027506035286933184, 0.05318183431934033, 0.059875083555068286, 0.09540990141353436, 0.07877902167716197, 0.08018196746706963, 0.02701894722745887, 0.039626964168356996, 0.05008980112948588, 0.029683372737573724, 0.05818355003637927, 0.04511317424476147, 0.047563513474805016, 0.0842319122914757, 0.06076857168227434, 0.06154949084988662, 0.02161229707832847, 0.05754631744431598, 0.05249781334506614, 0.0380130346997508, 0.025801529875025153, 0.051399241401148696, 0.03579326506171908, 0.0374938807716327, 0.22324855199881963, 0.09162595588713884, 0.1680753497140748, 0.22795812785625458, 0.10611351313335554, 0.11430254871291773, 0.11455554727997098, 0.14703377522528172, 0.19596201261239393, 0.15449795898582253, 0.14045525608318193, 0.07716829489384379, 0.1295686231127807, 0.08289483868117843, 0.1070922998977559, 0.07827356737107038, 0.1776666050510747, 0.11323540311838899, 0.08007600743855749, 0.17615801814411366, 0.19915690831840038, 0.17168453176106724, 0.09813037900520222, 0.09254337594445262, 0.13640254283589975, 0.13800171416785034, 0.18413288093038968, 0.13574221969715186, 0.09411051363817283, 0.13069220925016062, 0.12873914119388374, 0.12775598466396332, 0.10291888884135655, 0.12553326679127558, 0.24166285246610641, 0.21993055646972998, 0.1162627956696919, 0.12901761196553707, 0.22547771595418453, 0.150724164343306, 0.2492733555180686, 0.1933447809091636, 0.17253360977130278, 0.14752054267695972, 0.13580749476594584, 0.18712553248873778, 0.17763592169753142, 0.16877740275646957, 0.10551885861371245, 0.07571451326033898, 0.14138977522296564, 0.34985300845333506, 0.13973195132400307, 0.26539162918925285, 0.11009068507701159, 0.36545730541859356, 0.31829334050416946, 0.1851134318858385, 0.5898435977952821, 2.046038861785616, 34.81006152289254, 82.05494580950055, 96.39309556143624, 74.47448893955776, 74.12722492218018, 77.8301145008632, 99.88619818006242, 82.6195981161935, 65.0011065346854, 32.30799783979143, 35.304401533944265, 29.0531576360975, 29.843179975237163, 27.310766560690745, 29.626698425837926, 44.241674831935335, 49.85574286324637, 50.10868508475167, 48.07475280761719, 61.136956214904785, 65.58051681518555, 75.32900619506836, 78.59224155970982, 68.40419524056571, 69.95339339120048, 56.82664121900286, 51.63760839189802, 37.65872914450509, 30.789882455553325, 20.65240338870457, 12.46909475326538, 11.926359670502798, 10.11177681173597, 9.04250202860151, 8.496492607252938, 13.327988505363464, 16.642274890627178, 19.145554508481705, 20.40933803149632, 26.614496265138897, 25.62011350904192, 36.255794048309326, 44.12550095149449, 54.760233061654226, 59.73453875950405, 69.40993309020996, 73.12203598022461, 85.34130477905273, 77.94988754817417, 66.63878999437604, 61.95894200461251, 49.55544866834368, 29.703250203813823, 24.772834539413452, 37.024507999420166, 48.02769960675921, 71.76804746900285, 65.07001876831055, 71.37028394426618, 67.75921480996269, 77.05998311723981, 60.16935007912772, 21.203551871435984, 0.5195937816585813, 0.5877488244857106, 0.20748355079974445, 0.2005551518606288, 0.20607647273157323, 0.2468354877616678, 0.20932689974350588, 0.2162063220249755, 0.15123789677662508, 0.1195164117962122, 0.32859732902475763, 0.08989170180367571, 0.14123227367443697, 0.16329469052808626, 0.15079117646174772, 0.09780253802559205, 0.14049391900854452, 0.1700544056615659, 0.18064715154469013, 0.21331963049513952, 0.12777256805981907, 0.11583274017487254, 0.24433153069445065, 0.12649621654834065, 0.14190875951732906, 0.1748728456773928, 0.14615851933402674, 0.2434129842690059, 0.11335977180195705, 0.19825527098562035, 0.1478467687432255, 0.21855085050421102, 0.18199397570320539, 0.21174925618938037, 0.23468762104000362, 0.07740717314715896, 0.3757890324507441, 0.17638132401875087, 0.2250074233327593, 0.2180490331458194, 0.08333499077707529, 0.3005494326353073, 0.20198307452457293, 0.20824000877993448, 0.14045555463859014, 0.10853972365813595, 0.12637071471129144, 0.24309738406113215, 0.12112539474453245, 0.21124712670488016, 0.22792968366827282, 0.1389298957905599, 0.1285321337303945], [0.07825331310076372, 0.008060051161529762, 0.04919055563264659, 0.07728659747434513, 0.06308871361293963, 0.04533523840031453, 0.03452762422551002, 0.03375277455363955, 0.07758579070546798, 0.015643748687580228, 0.024822315633563057, 0.043452982258583815, 0.025870799818741422, 0.0994758800204311, 0.1611673068255186, 0.16784695482679776, 0.11106673055993659, 0.0925260733014771, 0.08962443364518029, 0.060361728870442936, 0.09104877364422594, 0.018872104651693786, 0.11154868041298219, 0.11388277980898108, 0.07701118689562593, 0.050981212939534865, 0.020947695776287998, 0.06912952089416129, 0.08192466931151492, 0.10358067761574473, 0.22937786738787377, 0.15833151899278164, 0.08390771504491568, 0.2585301473736763, 0.16806005553475448, 0.19676910287567548, 0.11477727895336491, 0.21425856011254446, 0.08557848539203405, 0.11392115774963583, 0.07026392966508865, 0.10599584159042154, 0.12026691223893847, 0.05895767028310469, 0.15825907859419072, 0.0309709438255855, 0.023784954333677888, 0.04599672183394432, 0.07389666366257838, 0.04284402082807251, 0.08880035965038197, 0.004763486312835344, 0.08168017278824534, 0.07238104713282414, 0.05625853601044842, 0.015654016618749926, 0.08966465041573558, 0.09284612469907318, 0.15442973907504762, 0.15101917779871396, 0.31885915728552, 1.1084338533026832, 20.981598615646362, 53.28721843447004, 70.99594279697963, 70.50982597896031, 65.44116374424526, 62.972996847970144, 67.21858242579869, 74.09697246551514, 81.71026652199882, 65.97620977674211, 63.12652424403599, 67.58530834742955, 48.95076778956822, 41.72788258961269, 29.02226594516209, 19.401074511664255, 15.206306321280342, 15.01719720023019, 21.55193975993565, 7.484233004706247, 7.266720950603485, 10.718262485095433, 24.959369352885656, 43.814416204180034, 43.684092317308696, 34.23260021209717, 33.157012122017996, 36.61634649549212, 42.75625419616699, 36.28419133595058, 44.78251566205706, 49.555730070386616, 66.29777935573033, 49.9464932850429, 51.61413042885916, 38.96614040647234, 49.45091996874128, 37.27514689309256, 51.657626152038574, 54.78701489312308, 37.46471806934902, 39.101633753095356, 24.84880093165806, 18.537698302950176, 16.027468749455043, 28.11663600376674, 21.693674325942993, 24.190149920327322, 28.791557959147863, 31.62429162434169, 40.06190953935896, 55.328449794224326, 53.033171449388774, 55.00426769256592, 53.77818162100655, 59.04297065734863, 55.33233731133597, 36.33280093329293, 12.929827196257454, 0.9646990746259689, 0.09901109710335732, 0.012242373079061508, 0.14765952021947928, 0.007902485152174319, 0.010150434349530509, 0.03646838704922369, 0.0746980949438044, 0.03941746987402439, 0.0798025985381433, 0.03577675630471536, 0.05355710828942912, 0.0605635116142886, 0.056896179116197994, 0.1473056370658534, 0.012765683034168822, 0.06811163015663624, 0.10211209034813301, 0.049888557820980034, 0.034525008473013125, 0.050189437211624215, 0.0338890006366585, 0.10399635495351893, 0.08518645499965974, 0.07464259756462914, 0.13674090110829898, 0.09659325291535684, 0.09249701843197856, 0.13767875864037446, 0.07612615331475224, 0.1315974835306406, 0.0772774779636945, 0.10857654096824781, 0.029168385014470135, 0.1457005760499409, 0.039945010494972975, 0.0591929183740701, 0.13359285145998, 0.13495716825127602, 0.13453970636640275, 0.07336218162838902, 0.16156116926244327, 0.17133577833218233, 0.08268769551068544, 0.09767662228218146, 0.0905461556145123, 0.17618001624941826, 0.03937660510252629, 0.08068961344127144, 0.030339000413992574, 0.00476785480610228, 0.06405668452914272, 0.030059589871338437, 0.07939706529889788, 0.08460957131215505, 0.05638188010613833, 0.022076776350981424, 0.007910861666979534, 0.0513696674523609, 0.05987978580274752, 0.04576194532481687, 0.08342008585376398, 0.01848902752889054, 0.028205230000561902, 0.026379789292280163, 0.08039688664887633, 0.02545604868126767, 0.057964966765471866, 0.1011698359091367, 0.10211986635944673, 0.13736192349876675, 0.08303874917328358, 0.0924270682569061, 0.09839612724525587, 0.10727278342736618, 0.10984823772949831, 0.06479757013065474, 0.06961559624012027, 0.058591967049453936, 0.031214551467980658, 0.03658817222874079, 0.051592583169362376, 0.06387688631990127, 0.08317753672599792, 0.03597007771687848, 0.1638780813664198, 0.19669818239552633, 0.13217157843921865, 0.1792359072715044, 0.0764844740874001, 0.10361628713352339, 0.12431988332952772, 0.17705447146935122, 0.06564324868044683, 0.1285916683929307, 0.04392423500706043, 0.13202751188405923, 0.049314330598073344, 0.06081932610166924, 0.10315628788833107, 0.06446684537721531, 0.051392350878034315, 0.0952367799888764, 0.048670421221426556, 0.18319405987858772, 0.051410328663353405, 0.06642809656581708, 0.03338689150820885, 0.05131953389250806, 0.04084264786381807, 0.08504400335784469, 0.02456258769546236, 0.003695351329432534, 0.2696704167340483, 0.0824788220758949, 0.25438158426965984, 3.727194377354213, 30.590656757354736, 66.95109067644391, 82.96865476880754, 74.23928546905518, 67.84793635777065, 56.07759414400373, 52.22741665158953, 39.96484667914254, 37.967270851135254, 22.981898137501307, 24.516369581222534, 28.838663271495275, 20.8398015158517, 31.167193957737513, 24.73407575062343, 20.039228337151663, 21.22151470184326, 30.08036368233817, 34.2623975617545, 27.75330080304827, 36.24985333851406, 38.53554316929409, 56.17093276977539, 57.43381650107247, 67.30394799368722, 49.845911162240164, 47.749872412000386, 56.101204122815815, 53.49964223589216, 51.98132535389492, 54.98262752805437, 53.44391768319266, 50.93352310998099, 56.91520643234253, 63.44315365382603, 63.24213532039097, 70.55680274963379, 62.06389454432896, 48.983865533556255, 76.61215087345668, 74.6827472959246, 74.4624685559954, 62.261591638837544, 55.41702195576259, 46.24886001859392, 52.92976140975952, 42.17267847061157, 33.428398336683, 38.29338455200195, 32.93254361833845, 26.459603548049927, 33.91626957484654, 40.130206857408794, 46.293144362313406, 57.465764318193706, 68.38001550946916, 65.44040639059884, 50.79037284851074, 21.310583659580775, 1.5580727372850691, 0.23058593113507542, 0.051033110690436194, 0.25866859565888134, 0.026004601835406253, 0.14071309939026833, 0.04973343114501663, 0.08123790366309029, 0.045867647510021925, 0.02447286161727139, 0.046929466604654274, 0.1321312870298113, 0.04132720668401037, 0.03715622139030269, 0.176599934431059, 0.021279338248340145, 0.07311578520706721, 0.19034166634082794, 0.07942443740155015, 0.05858021482293095, 0.08956017637891428, 0.1242219978677375, 0.12480097822844982, 0.08411959438983883, 0.07562627656651394, 0.07829051039048604, 0.07098664409880127, 0.1876436618289777, 0.11998411241386618, 0.12436605085219656, 0.007383637412983392, 0.13756787244762692, 0.06597084538745028, 0.15499278743352207, 0.12501865226243222, 0.08324347675911017, 0.15545842530471937, 0.22997856086918286, 0.06879997000630413, 0.18381584222827638, 0.12574403333876813, 0.14456043365810597, 0.09672091927911554, 0.08260730946702616, 0.09107913130096026, 0.054902534665805955, 0.035126126038708856, 0.0210658473827477, 0.07149576927934374, 0.09400323046637432, 0.11194579981799636, 0.015457300835156014, 0.048359760748488564, 0.0910779099379267, 0.055425763196711025, 0.1458448190242052, 0.09320492723158427, 0.13751513670597756, 0.09065841923334769, 0.19303766238902295, 0.13051667224083627, 0.10322484028126512, 0.11642985099128314, 0.16787427264664853, 0.11373473703861237, 0.14689357631972857, 0.07711240396435771, 0.1338607370853424, 0.19547819000269684, 0.22655594881091798, 0.21159292172108377, 0.17174307576247624, 0.14677707185702665, 0.21152791806629725, 0.1585656814277172, 0.21053395925887994, 0.11640439235738345, 0.15693736023136548, 0.14755560936672346, 0.15113762287156923, 0.07964338708136763, 0.13016369832413538, 0.15121486729809216, 0.1896264904311725, 0.13217594820473874, 0.2522442803851196, 0.25137317712817875, 0.16062198180173123, 0.3725992664694786, 0.20519103881503853, 0.15002099850348063, 0.1604063298021044, 0.3190645362649645, 0.15345123729535512, 0.17004273485924515, 0.14256377651223115, 0.1884269897959062, 0.18927053096038954, 0.11496584383504731, 0.2442068973822253, 0.14431419329983847, 0.11306484655610152, 0.16846805864146777, 0.11993523075112275, 0.19848365230219706, 0.18722630850970745, 0.12073450429098946, 0.08737707138061523, 0.17003551524664673, 0.1209723986685276, 0.17420598146106514, 0.1527098427925791, 0.1302898922669036, 0.28729986931596485, 0.1263061181775161, 0.5116041132381984, 3.327134907245636, 32.91301570619856, 81.20130402701241, 96.88401358468192, 89.82891001020158, 77.54460607256208, 76.13785988943917, 77.91839136396135, 85.83596093314034, 98.58954620361328, 83.11007840292794, 84.56986018589565, 90.78815746307373, 70.2037856238229, 59.637319564819336, 43.01517881665911, 28.9729927948543, 22.10095861979893, 26.899269921439036, 29.08373144694737, 15.70498548235212, 17.145951543535503, 21.706511122839792, 41.30978168760027, 58.69346932002476, 66.10757936750139, 52.75674431664603, 54.80819647652762, 60.00308663504464, 63.3158209664481, 56.04802261080061, 67.41177013942173, 70.67552661895752, 90.75857203347343, 72.53871386391776, 74.54123333522251, 60.641883168901714, 75.97511918204171, 61.33618886130196, 70.19808115277971, 78.09332615988595, 58.1078508240836, 59.706572260175435, 40.881112575531006, 32.49872589111328, 29.167575359344482, 42.81803410393851, 36.90061814444405, 38.72555208206177, 46.18965094430106, 50.862724440438406, 64.87977709089006, 79.3414727619716, 73.2494728905814, 76.55150699615479, 75.73923478807721, 88.0519151687622, 76.37432098388672, 64.04427705492292, 26.948308570044382, 1.4103883419718062, 0.6387218950050217, 0.15732435589390142, 0.3173553336943899, 0.08552608891789402, 0.2450242606656892, 0.06972068095845835, 0.15230188039796694, 0.11671501211822033, 0.23008196960602487, 0.14815470150538854, 0.22358450825725282, 0.1342605570597308, 0.18771633292947495, 0.3406972640327045, 0.09322780064706292, 0.271789725869894, 0.18490808004779474, 0.13095025611775263, 0.08229637079473053, 0.16083493323198386, 0.1930621439324958, 0.16892891962613377, 0.12315323735986437, 0.14642443720783505, 0.18146731039243086, 0.18274784167962416, 0.14582738067422593, 0.15402389370969363, 0.1487857119313308, 0.18205196330589907, 0.16130982632083551, 0.21097611981843198, 0.2022819420588868, 0.14520946597414358, 0.1232325988156455, 0.20091073135180132, 0.2282511464187077, 0.11279897617974452, 0.22888579379234994, 0.15283372971628392, 0.30002131525959286, 0.25044993524040493, 0.17552487711821282, 0.16019458616418497, 0.12071098626724311, 0.21417151764035225, 0.1922088318637439, 0.20144154929688998, 0.1724130069570882, 0.18618329162044184, 0.15111984525408062, 0.07975457861487355, 0.21169593690761498, 0.24715746619871684], [0.01820714881510607, 0.02972665648641331, 0.03623834332185132, 0.015987779512735348, 0.05361290083133748, 0.04635396373591252, 0.02833330857434443, 0.010731002482186471, 0.02885281534067222, 0.010686049537201012, 0.035517505037465265, 0.04614625059600387, 0.05569319420361093, 0.03890776115336588, 0.05823331379464694, 0.005608498626055994, 0.06137880536594561, 0.0992673390677997, 0.05620569509587117, 0.03337477287277579, 0.030449360742100647, 0.036230261969779215, 0.05088583127196346, 0.06984845588782004, 0.00757596392317542, 0.030595391656139066, 0.037992220638053756, 0.1153535180326019, 0.045353317965886424, 0.14430637657642365, 0.11680330309484686, 0.08041192298488957, 0.05227581025766475, 0.1277988137943404, 0.07488016624535833, 0.04746118700131774, 0.1219847457749503, 0.04742499394342303, 0.06559037044644356, 0.055299243557133844, 0.05692763599966254, 0.053588137695831914, 0.023349087186423794, 0.027291979540937712, 0.08802870927112443, 0.03593347753797259, 0.04746766022539564, 0.05282013104962451, 0.0010127243294846267, 0.053224405606410334, 0.03230547971491303, 0.04861299341012325, 0.035265497131539245, 0.11064784375152417, 0.03673453901761344, 0.0787205658853054, 0.06547216286084481, 0.08567706974489347, 0.10834875676248755, 0.09766237983214003, 0.17340156462575707, 0.11287751660815307, 0.26332809563194004, 0.24489618039556912, 8.264188272612435, 30.223034518105642, 51.95740270614624, 61.112276213509695, 69.34421702793666, 70.39671625409807, 70.81981985909599, 76.82790633610317, 67.57524735586983, 61.98864555358887, 57.708517006465364, 66.90477398463658, 59.87676838466099, 74.45697947910854, 73.25714370182583, 54.87111588886806, 55.21639966964722, 47.99025576455252, 46.220271655491416, 27.830477918897355, 16.31889704295567, 20.947885956083024, 11.62058334691184, 43.605688844408306, 85.85294233049665, 24.428679840905325, 14.414612071854727, 20.72346956389291, 14.886378254209246, 14.549152646745954, 26.19130059650966, 17.73503371647426, 13.60587215423584, 14.307900769369942, 15.73037246295384, 29.63842351096017, 108.32054696764264, 21.542339086532593, 20.94273212977818, 30.95218195234026, 39.58283124651228, 44.55794293539864, 51.764774322509766, 47.877187728881836, 53.62459863935198, 57.538386889866416, 52.83374425343105, 60.633573123386924, 55.53904969351632, 52.28359631129673, 56.826835768563406, 56.059560094560894, 41.51795319148472, 20.453266280038015, 5.924969519887652, 0.231483877237354, 0.20353409701160022, 0.03221583506092429, 0.18671622659478868, 0.09497372553284679, 0.04730886606765645, 0.07365228927561215, 0.03361780715308019, 0.07832380610385112, 0.11152302500392709, 0.04538438129904015, 0.024343319104186127, 0.024569790344685316, 0.034065158505524905, 0.04162968063194837, 0.01574303362784641, 0.0313933013406183, 0.06108656033341374, 0.028640128539076874, 0.039609844729836495, 0.011723080051264592, 0.041460006165185144, 0.08484935201704502, 0.016839300249037997, 0.043088015235428295, 0.08422475374702897, 0.08621017435299498, 0.08929600912545409, 0.017424365372530053, 0.04759955386232052, 0.03640715944181595, 0.03671947893287454, 0.025384497163551192, 0.08512989910585539, 0.023130727832072547, 0.05538248962589672, 0.17341960008655274, 0.10543586021023137, 0.031056975280599933, 0.09821340455008404, 0.02771092063215162, 0.08918722639126436, 0.04844097799754568, 0.03350523140813623, 0.14281167249594415, 0.06056854634412697, 0.0714384059288672, 0.08526597251849515, 0.03324073167251689, 0.02635626957219626, 0.0666516942105123, 0.10891403071582317, 0.06487112332667623, 0.043565021960863044, 0.10015738702246121, 0.021041236917621324, 0.030885651973741393, 0.01782584436503904, 0.04429990592013512, 0.024259599757247736, 0.0760626627930573, 0.056996955137167654, 0.05522434346910034, 0.01930578182717519, 0.03374799427443317, 0.02756478454518531, 0.007816044031642377, 0.049009810867054124, 0.012859274217459773, 0.013360020338690706, 0.0647368480318359, 0.05189196299761534, 0.052568129929048676, 0.01964541744174702, 0.06493348069489002, 0.0411256749981216, 0.08527028121586357, 0.0445546992123127, 0.05176660026024495, 0.022626864690599695, 0.01589280496617513, 0.08233715753470149, 0.05477747726919396, 0.03816708589770964, 0.004814492214271533, 0.02806095140320914, 0.11429313064685889, 0.12955741371427262, 0.07221532173986946, 0.0588897896398391, 0.08966182092470781, 0.07750284658478838, 0.04246003786101937, 0.08531235717236996, 0.07288680677967412, 0.05686086476115244, 0.04958950029686093, 0.09290693500744444, 0.054476580915174315, 0.00950780401139387, 0.01785121139671121, 0.05118845110493047, 0.007101545384752431, 0.03651605752695884, 0.06293145633701767, 0.03643486402662737, 0.04378086055762001, 0.048052903464330096, 0.06663709213691098, 0.029875947761216333, 0.01544287518065955, 0.04757942172831722, 0.06048528331198862, 0.06289575182433639, 0.0882551906896489, 0.1315554143594844, 0.04118240052568061, 0.15197531506419182, 0.1616226988179343, 0.12390627552356039, 0.7262861877679825, 15.030353614262172, 46.67435032980782, 67.88126686641148, 74.34553037370954, 82.38849408285958, 77.9645412990025, 71.56597300938198, 66.58694948468889, 56.12605435507638, 53.62805536815098, 43.57024608339582, 45.275122097560335, 39.24718114307949, 32.565640517643516, 25.01081555230277, 23.272411005837576, 28.03387427330017, 16.60348309789385, 15.802310637065343, 17.590580667768204, 22.04135697228568, 36.36111831665039, 26.807451214109147, 43.872753279549734, 65.66443020956856, 38.385691370282856, 36.23922954286848, 36.28293023790632, 35.85734265191214, 40.56680038997105, 61.46952479226248, 41.81743444715227, 35.87778425216675, 29.85205282483782, 32.86193602425711, 36.96334995542254, 92.75294821602958, 35.01770148958479, 22.586999007633754, 27.39059615135193, 18.896730831691197, 12.134900297437396, 16.147481509617396, 34.48089061464582, 31.89611210141863, 36.94976622717721, 46.512985365731375, 52.77417039871216, 56.244288376399446, 58.71819795880999, 67.85220255170549, 70.43814141409737, 59.268363271440776, 33.378850732530864, 11.849001901490347, 0.9137440259967531, 0.36947895533272196, 0.08310976464833532, 0.15457324923149177, 0.01172641505088125, 0.037943450933588405, 0.07252995164266654, 0.029423235982124294, 0.014720912224480083, 0.06279161705502442, 0.02654522461151438, 0.05044602183625102, 0.04956148697861603, 0.006904807124686028, 0.0836467504767435, 0.08669012252773557, 0.051624026482126543, 0.14695753503058637, 0.031031357190970863, 0.031215280893125703, 0.015925529013786997, 0.022526008941765343, 0.08253746785755668, 0.037746177054941654, 0.04218539741954633, 0.05337040937904801, 0.08974525359060083, 0.06575474555471114, 0.03169033683038183, 0.004811524047649333, 0.04251713997551373, 0.10428822679179055, 0.05165547997291599, 0.07539392582007817, 0.043669560458511114, 0.02353176916949451, 0.1337575726211071, 0.03237934842971819, 0.020120605693331788, 0.05279243664283838, 0.05570964189246297, 0.0740310475230217, 0.03678293213514345, 0.10756171042365686, 0.1248878442815372, 0.004667412539544914, 0.05714815988072327, 0.018303544892530357, 0.016229288785585334, 0.04393531548391495, 0.08531698478119713, 0.08175163609640938, 0.04078764920788152, 0.030136410213474716, 0.1293440144509077, 0.03221760264464787, 0.02143461929102029, 0.08676456460463149, 0.10145364675138678, 0.16720777483923094, 0.12882167819355214, 0.12659627332219056, 0.1156822953905378, 0.08253403447036232, 0.15319965008114064, 0.12750274182430335, 0.08791793164397989, 0.17558034057063715, 0.10480779462627002, 0.154063967987895, 0.14907204013850006, 0.15588770726961748, 0.1228806698428733, 0.11629118557487216, 0.131581415821399, 0.14819991907903127, 0.1423726196267775, 0.17291642565812382, 0.06470385087387902, 0.13187081100685255, 0.15624069475701877, 0.133653797475355, 0.10803727526217699, 0.09738968339349542, 0.15795923396945, 0.1532969112907137, 0.16799886524677277, 0.16656342441482203, 0.1491455797638212, 0.1080543879153473, 0.24280048427837236, 0.126847969102008, 0.14181189185806684, 0.2740606740117073, 0.15615205094218254, 0.13939148959304604, 0.11241740201200758, 0.14758318502988133, 0.13951008394360542, 0.07567769595022712, 0.11004662101290055, 0.1128622834969844, 0.13745686411857605, 0.2191681952348777, 0.19716125540435314, 0.2906640459384237, 0.19044998767120497, 0.12117233579712254, 0.23939600267580577, 0.057166656745331626, 0.1986550095358065, 0.13486848372433866, 0.09960045226450477, 0.10404805932193995, 0.14645873036767754, 0.21259639358946256, 0.1335726853992258, 0.2759611148919378, 0.23686281431998524, 0.28049655152218683, 0.8595301636627742, 16.985953637531825, 51.07144137791225, 78.4026460647583, 90.05788094656808, 98.16990280151367, 92.53978443145752, 87.02142783573696, 87.47667380741665, 75.41244711194719, 75.37416948590959, 69.70600972856793, 81.78477900368827, 79.74718502589634, 98.36427170889718, 97.7914205278669, 80.25138105664934, 81.12729876382011, 73.28552709306989, 71.93665940420968, 45.240297726222444, 28.270048754555837, 35.780572005680625, 22.06377533503941, 55.98929296221052, 99.26854501451764, 40.04026937484741, 23.034150327954972, 30.782673699515207, 22.86347825186593, 23.09676401955741, 41.633609431130544, 26.741559709821427, 22.05778251375471, 19.27970164162772, 23.639830010277883, 41.30067259924752, 129.6624322618757, 30.02356215885707, 33.33700520651681, 44.22591284343174, 58.06645693097796, 63.605630329677034, 74.76308236803327, 64.30812794821603, 69.60646288735526, 73.00443771907261, 73.70122391836983, 76.40214851924351, 70.53829274858747, 71.63510063716343, 82.15424946376255, 85.20924731663295, 67.4290086201259, 37.934940883091514, 12.00659920488085, 0.5493897199630737, 0.8357027279479163, 0.11757710443011352, 0.37785872710602625, 0.13740454906863825, 0.18189051268356188, 0.13952666733946117, 0.09481115532772881, 0.1337601374834776, 0.18553697344447884, 0.12828214785882405, 0.16686216981283256, 0.17247146953429493, 0.08685776817479304, 0.1830681644912277, 0.19856282376817294, 0.1412635948508978, 0.2007329144648143, 0.0988679194290723, 0.09377928676881961, 0.13990269787609577, 0.12602740313325608, 0.18501777201890945, 0.19018279415156158, 0.13179610430129937, 0.1686269308307341, 0.1843071287231786, 0.15455115613128456, 0.1551417258701154, 0.12882118964833872, 0.148599169084004, 0.18106719186263426, 0.13722306809255055, 0.2190646372203316, 0.0802644637546369, 0.10080843458750419, 0.27769167774489945, 0.2041563814772027, 0.16814781725406647, 0.13692595117858478, 0.17827537309910568, 0.19587255455553532, 0.1865874542189496, 0.1320654284209013, 0.26740866952708786, 0.09151043530021395, 0.20103932730853558, 0.21920060206736836, 0.12954059961651052, 0.21941187073077473, 0.1563558014375823, 0.2876937453235899, 0.13867254102868692, 0.11286634113639593, 0.2311886330800397, 0.1210448390671185, 0.09359714761376381], [0.06212250688778503, 0.04909973032772541, 0.03885085581402693, 0.027120364464021156, 0.0493092314074082, 0.03072022513619491, 0.05582583422905632, 0.04961718452562179, 0.04466562611716134, 0.04708778578788042, 0.06104673032781907, 0.03672153150130596, 0.025013621796720793, 0.09370452578046493, 0.0289618152060679, 0.05985852051526308, 0.15185110244367803, 0.014521909777873328, 0.08791548891791276, 0.04052123939618468, 0.019482925268156186, 0.05862322715776307, 0.022618740930088928, 0.09668704002563443, 0.00526241650472262, 0.06434547581842967, 0.25573721581271713, 0.07160764613321849, 0.185316300285714, 0.15348550331379684, 0.1113833621410387, 0.06342175217079264, 0.1890378070196935, 0.0530715520227594, 0.07574349349098546, 0.08915102654801947, 0.10036057433379547, 0.13559082496379102, 0.09302451155547585, 0.10840662222887788, 0.14779775137347834, 0.017584360537252257, 0.04051268646227462, 0.09800209517457656, 0.05438765550830534, 0.03198385750874877, 0.04298422312630074, 0.0671531723013946, 0.06698938073324305, 0.05034335609525442, 0.04461641536493387, 0.0463228495126324, 0.1181464631642614, 0.09745990498257534, 0.010225638930153633, 0.05420868850446173, 0.0328481889862035, 0.01105009120822485, 0.22630710287817887, 0.08272109300430332, 0.03825778228097728, 0.07407021934964828, 0.07888840152216808, 0.07318148775292294, 0.37440927220242365, 0.018521722738764117, 0.33796578060303417, 2.2207322078091756, 12.463828018733434, 19.915675469807216, 41.08528539112636, 56.826467514038086, 69.06950610024589, 73.49682876041958, 76.24785682133266, 73.73187937055314, 71.33307634081159, 67.56083679199219, 67.30036272321428, 69.46926375797817, 55.18987144742693, 57.896889618464876, 66.20858533041817, 65.71080943516323, 64.7288761138916, 48.44206237792969, 54.838865825108115, 41.2189895766122, 58.58894756862095, 69.8187234061105, 62.902868679591585, 72.75442068917411, 64.37141214098249, 56.4666029385158, 49.116138390132356, 57.626309394836426, 71.1600592476981, 77.85069506508964, 69.38755294254848, 67.39883954184396, 38.569200243268696, 65.99684592655727, 73.50860595703125, 67.06265095302037, 73.43073054722377, 75.76931353977749, 71.67068236214774, 70.68411459241594, 71.46805204663957, 69.7150354385376, 73.6695053918021, 62.57870742252895, 57.97460174560547, 45.027575152260916, 19.564959934779576, 3.674284279346466, 0.50234183881964, 0.2584163706217493, 0.2718604563602379, 0.0381350251180785, 0.1124486621203167, 0.026661564529474293, 0.19468395119266851, 0.14067168161273003, 0.12468656365360532, 0.0302803512396557, 0.04966906192047255, 0.0806946074590087, 0.04951467484767948, 0.05836471210100821, 0.10809934086033277, 0.0561711407000465, 0.03158656507730484, 0.10382335566516433, 0.0872023825400642, 0.034377647630338154, 0.0935541759910328, 0.13088850943105562, 0.021388841925987175, 0.03957016060927084, 0.0733385414683393, 0.0529791287678693, 0.04958435360874448, 0.060453934994127066, 0.06623456480779819, 0.05627980808328305, 0.06304103295717921, 0.04125739560861673, 0.11170078082276241, 0.020442897952826958, 0.09673978255263396, 0.037610999308526516, 0.08101637555020196, 0.11799501414809908, 0.04847917951909559, 0.052946650689201694, 0.048798884863832166, 0.05706303087728364, 0.16416820936969348, 0.13187644284750732, 0.14836952569229261, 0.0631867212110332, 0.10631213390401431, 0.09367197645562035, 0.0957957978493401, 0.016557904991454313, 0.05468309304809996, 0.002258834383350664, 0.03358326632795589, 0.037721261249056885, 0.09713220649531909, 0.07491017106388297, 0.16316219978034496, 0.1120328897876399, 0.07052722839372498, 0.027142374443688562, 0.028817606158554554, 0.03983854835054704, 0.08737025210367781, 0.04710435222036072, 0.01763443642162851, 0.07136604695447854, 0.038910912948527505, 0.030924694878714423, 0.031103811160262142, 0.040110260913414617, 0.03469797722729189, 0.05312678138060229, 0.08455465747309582, 0.02490687127491193, 0.053035328430788856, 0.03196144549708281, 0.0601777033880353, 0.0064512102814790395, 0.055897361998047145, 0.04931046634114214, 0.012305325013585389, 0.005535495043399611, 0.04520651012925165, 0.0469283538072237, 0.029003925089325224, 0.09407681080379657, 0.1137871335127524, 0.06008701039744275, 0.04537411845688309, 0.04072877950966358, 0.08051305862941913, 0.052712657888020785, 0.09140837006270885, 0.02281208778731525, 0.05620905045153839, 0.05576995347759553, 0.03481177433526941, 0.07577070274523326, 0.05506207860474076, 0.1037295956962875, 0.06780578728233065, 0.06371484537209783, 0.055004430269556384, 0.05276478973350354, 0.05417487031913229, 0.03414479476798858, 0.029476090467401912, 0.018180482388873185, 0.040442464873194695, 0.08449949936142989, 0.062176701479724476, 0.01343984913546592, 0.051604555919766426, 0.12380533665418625, 0.01876839396676847, 0.04420083641473736, 0.038262918791068454, 0.03348036988505295, 0.17223964125982352, 0.017080563552943722, 0.18813919595309667, 0.07770941300051552, 0.04291612535182919, 0.05610970274678298, 0.3852538088602679, 0.1018343252528991, 1.4128931675638472, 5.053017931325095, 19.493028708866664, 33.6748856816973, 57.150805950164795, 76.34505517142159, 88.62904644012451, 88.8877626146589, 84.06476088932583, 88.7052890232631, 79.02878298078264, 68.66955389295305, 63.21416882106236, 57.9093234198434, 48.94158227103097, 43.07277243477957, 38.50949089867728, 26.1604870728084, 26.30576000894819, 26.559791360582622, 22.465983969824656, 44.67653131484985, 77.50321565355573, 35.4606283051627, 22.38161894253322, 32.6777149609157, 20.638204744883947, 16.00133831160409, 29.171987465449742, 19.42143620763506, 22.515324865068706, 19.813971212932042, 23.483030012675695, 38.71518536976406, 70.70140865870884, 37.92528983524868, 32.96749305725098, 45.4090382031032, 50.54534115110125, 54.9248080934797, 60.31900038037981, 65.06614862169538, 71.92643860408238, 77.6622599193028, 81.9685171672276, 79.80138097490583, 79.41158703395298, 66.81779643467495, 40.025334221976145, 14.694227559225899, 1.828198288168226, 0.24662750320775167, 0.32818969232695444, 0.023262029447193657, 0.10881087303693805, 0.03203268488869071, 0.06309528183192015, 0.06598000561020204, 0.028975365550390313, 0.05043583024027092, 0.029885063879191875, 0.015661646745034626, 0.03827988216653466, 0.055647657718509436, 0.07844455819576979, 0.02074370440095663, 0.06466127280145884, 0.04234540615496891, 0.06159873892154012, 0.028247434878721833, 0.06216781945633037, 0.027046482178515623, 0.025819271869425262, 0.019211758925978626, 0.048446413063045056, 0.024100859882310033, 0.0126204943517223, 0.09750725994152681, 0.02807712598171617, 0.05752519464918545, 0.03841818456671067, 0.06472498723970992, 0.04103067670283573, 0.03321938496083021, 0.02561358585288482, 0.02982729340770415, 0.04462190471323473, 0.06427835513438497, 0.08206159089292799, 0.050435592753014395, 0.010560907323711684, 0.052258795992072136, 0.03751290350088051, 0.039123036566057375, 0.014463978154318673, 0.041224347560533454, 0.06712247537715094, 0.03491747991314956, 0.02907664029459868, 0.02241235093346664, 0.057304263647113524, 0.03932282441694822, 0.04305559143956218, 0.025660930633811013, 0.06667115459484713, 0.02261565868476672, 0.023975013688738857, 0.11565942876040936, 0.07676716534686939, 0.014410843773345863, 0.13182106081928524, 0.1415307612291404, 0.1526629560227905, 0.09896921113665615, 0.10507506278476544, 0.14339158923498221, 0.10940402120883976, 0.11019524053803512, 0.09354020495499883, 0.12003880233636924, 0.20506792542125496, 0.07377993528332029, 0.16255358101001807, 0.14109366254082747, 0.12621898071042129, 0.08835743234625884, 0.1634544176714761, 0.056023413448461463, 0.11836591495999269, 0.13175566361418792, 0.08630354077156101, 0.1506714964551585, 0.14767493653510297, 0.23221482230084284, 0.1456138321331569, 0.15069235462163175, 0.20350061809378012, 0.12166762564863477, 0.1858215510313, 0.1547427744205509, 0.1172949695693595, 0.11999942016388689, 0.19535352954907076, 0.07002395897039346, 0.12920082999127253, 0.12396777793765068, 0.1731334211570876, 0.13330108140196117, 0.14175470492669515, 0.26405502376811846, 0.21575973741710186, 0.15442189521023206, 0.2386924432856696, 0.12078083466206278, 0.1575734189578465, 0.09072529564478568, 0.15718852675386838, 0.10305128459419523, 0.1456255843596799, 0.19439275110406534, 0.16558778605290822, 0.07065366660909993, 0.19683919554310186, 0.19273495434650353, 0.07176521553524903, 0.10541172471961804, 0.26179544787321773, 0.10742508061230183, 0.24899664893746376, 0.1340371969022921, 0.33554376342466896, 0.1503979789891413, 0.13041542124535355, 0.07159837734486375, 0.5287766946213586, 0.20593203976750374, 1.0366586361612593, 4.749192314488547, 19.2211491721017, 36.49168886457171, 61.083420344761436, 81.71745095934186, 96.53065599714006, 103.43402481079102, 100.75256211417062, 101.19250120435441, 91.79956504276821, 83.26886558532715, 77.89833191462925, 80.7632965360369, 67.67698287963867, 77.44972842080253, 84.04714025769914, 84.22503498622349, 89.82515103476388, 64.59633922576904, 74.73103032793317, 64.51332214900425, 80.80135876791817, 91.35472747257778, 88.23724446977887, 95.76773684365409, 85.05184977395194, 77.0154938016619, 67.20219162532261, 75.98720904758999, 93.36951746259416, 104.59295654296875, 93.11775643484933, 90.29523141043526, 61.741977555411204, 88.59615366799491, 97.48226737976074, 95.31668758392334, 105.52461964743478, 97.74448544638497, 90.91202994755336, 90.31623581477574, 87.40205710274833, 89.07031263623918, 94.61942890712193, 89.64982713971818, 89.12892069135393, 73.95980112893241, 41.93499449321202, 14.076248696872167, 1.7441154228789466, 0.3768899690892015, 0.45602900109120775, 0.196039080619812, 0.2456363263939108, 0.11047957385224955, 0.37725963496736115, 0.24854241045457975, 0.14142655182097638, 0.11462152802518435, 0.12395116740039416, 0.2062275553388255, 0.1343535434986864, 0.15299782662519387, 0.1486311009419816, 0.10617547695125852, 0.1692881224943059, 0.13797154650092125, 0.17075241463524954, 0.12422186216073376, 0.12227476521262101, 0.25045631346958025, 0.10427001491189003, 0.09077099497829165, 0.20720974834901945, 0.14510168747178145, 0.0717287782047476, 0.1374389100819826, 0.15958055268440927, 0.10830778003271137, 0.09478687055941139, 0.18866968820137636, 0.17674265748688153, 0.1345102579465934, 0.11255445930042438, 0.12799021495240076, 0.2570265137723514, 0.15074867302817957, 0.26474691235593384, 0.22432892902621202, 0.11453122858490263, 0.0930247897548335, 0.16911363042891026, 0.20913081669381686, 0.19780993488218102, 0.20362864408109868, 0.17351512424647808, 0.1349056674433606, 0.09071129746735096, 0.16583260148763657, 0.11787757330707141, 0.10775846522301435, 0.17328896852476255, 0.1765088207487549, 0.13510582170316152, 0.19287595392337867, 0.23283641466072627, 0.2559078537992069, 0.17196195758879185, 0.08283191812889916], [0.038793353363871574, 0.07142611765967948, 0.04041250076677118, 0.02260818292519876, 0.022577706524836164, 0.024506313393690755, 0.038766323921403716, 0.052308966871351004, 0.03519885820735778, 0.03534926227959139, 0.07355125541133539, 0.10006224284214632, 0.027861416306612746, 0.06062151278768267, 0.0384446304690625, 0.027111187277893935, 0.03576967239912067, 0.07520261287157025, 0.024927659891545773, 0.025552329407738786, 0.01666405500977167, 0.05240848760253616, 0.04499666638938444, 0.036151724934045754, 0.031265156609671454, 0.09237682273877518, 0.09283186867833138, 0.1280642838350364, 0.0693880088095154, 0.09124981678490128, 0.035982427054217885, 0.05099920090287924, 0.10224150733223983, 0.10592644781406436, 0.029573137938444103, 0.05477999463411314, 0.033906503447464535, 0.05975213300968919, 0.06622746733150311, 0.04403294988774827, 0.09213907085359097, 0.057171576124216826, 0.0923209860920906, 0.05858227078403745, 0.03755162410171969, 0.0265195369720459, 0.05923054314085415, 0.017182925649519478, 0.01579749454478068, 0.04591447999700904, 0.07283986572708402, 0.0564067450218967, 0.02019302573587213, 0.04038122708776167, 0.01946145642016615, 0.021706099455643977, 0.03782435446711523, 0.0039629875931755775, 0.02548810437188617, 0.033541736592139514, 0.04290471578549061, 0.026400701741554906, 0.04445510044960039, 0.06926137381898505, 0.07376631030014583, 0.03339192623804722, 0.023510927966396724, 0.06124643675450768, 0.41530123938407215, 0.23423815944365092, 0.04595664416306785, 1.0760379859379359, 1.4271027765103748, 5.89223438501358, 11.972226466451373, 9.24024168082646, 31.08862372807094, 59.267710140773225, 65.79211725507463, 86.28056921277727, 79.4666028703962, 74.2394105366298, 66.96802343641008, 75.04763194492885, 72.13346712929862, 74.34302207401821, 72.82370117732457, 72.25374044690813, 67.82012271881104, 67.80296761648995, 76.22833238329206, 66.11024052756173, 72.60115732465471, 83.44832365853446, 84.00322069440568, 80.8559090750558, 75.18862479073661, 74.10342039380754, 73.52223832266671, 66.28179849897111, 65.43520218985421, 63.81933607373919, 60.293986865452354, 62.71790763310024, 51.64298629760742, 40.43939822060721, 53.76376410893032, 48.15508093152727, 30.35892391204834, 21.868550062179565, 17.91630526951381, 8.490172352109637, 1.4543726103646415, 0.19089365457849844, 0.17551491622413906, 0.24538665264844894, 0.03578265616670251, 0.06746656048510756, 0.06045403677437987, 0.03287467560065644, 0.30361681804060936, 0.06924940446125609, 0.06516733100371701, 0.0431861619332007, 0.08102453154112611, 0.03994962453309979, 0.02610976288893393, 0.030878272905413593, 0.08587993135941879, 0.04179532460070082, 0.09141368299190487, 0.057854942312198024, 0.021097955659830143, 0.03261526148500187, 0.03241835740794029, 0.043295446783304214, 0.04098718260814037, 0.0406437285377511, 0.03740537944915039, 0.18946664115147932, 0.07632533726947648, 0.06520169880241156, 0.04491182915600283, 0.02918499555172665, 0.005329487146809697, 0.028305398732689873, 0.03580353808190141, 0.04581015523789184, 0.024332929036713073, 0.053930034528353384, 0.03342454680906875, 0.02965380557413612, 0.05991424859634467, 0.030534947756677866, 0.0130947122982304, 0.09867203993988888, 0.07283962145447731, 0.18674860628587858, 0.03431666429553713, 0.13342395052313805, 0.22825117356010846, 0.1340559787516083, 0.08094736175345522, 0.10726460708039147, 0.0673794908715146, 0.05023009842261672, 0.12471783054726464, 0.0030598699938439366, 0.033415837812104394, 0.018579376162961125, 0.05548887713147061, 0.06394978133695466, 0.09141718423260109, 0.05358264495485595, 0.015259458683431149, 0.02263795704181705, 0.04556225246882864, 0.0397332431083279, 0.016455242643132806, 0.012123601461228515, 0.03573985757040126, 0.03371090894298894, 0.016688653600535223, 0.06516247947833367, 0.01768246652292354, 0.025877184833266904, 0.07002021345709052, 0.06864596969847168, 0.08891141547688416, 0.05519093579745718, 0.039928790115352185, 0.021706798346713185, 0.03207352591146316, 0.03154003793107612, 0.06768223962613515, 0.029995902574488094, 0.039614319668284485, 0.05569611190419112, 0.02897688207615699, 0.09286101175738232, 0.0893758251996977, 0.08120653498917818, 0.11711713911167212, 0.06188904334391866, 0.09373433382383414, 0.06942332655723606, 0.0035604992798263474, 0.1101206016859838, 0.04855334339663386, 0.04697370708787015, 0.043311911435531716, 0.03269871450694544, 0.02766129088455013, 0.03181577420660427, 0.022236391536093185, 0.048598784886832745, 0.14449186090912136, 0.06083031158362116, 0.0965234384472881, 0.07078967895358801, 0.052090000228158066, 0.04204279650002718, 0.02310336590744555, 0.04209042287298611, 0.03341369703412056, 0.059734891434865336, 0.040313027533037324, 0.0019358531987693692, 0.042376286283667595, 0.025611348383660828, 0.060431522982461114, 0.05146632815844246, 0.05132722508694444, 0.0421724611494158, 0.14944762284202234, 0.053023521921464374, 0.0558076223491558, 0.07634434303534882, 0.09634674792843205, 0.09892673484448876, 0.04549180357051747, 0.03667259894843612, 0.004612201841415039, 0.23700929645981106, 0.4371514783373901, 0.20633048910115445, 0.17625521150018486, 1.6216475601707185, 5.09578800201416, 16.622326612472534, 34.45849657058716, 36.38557597569057, 61.207306725638254, 80.96817806788853, 84.95665250505719, 98.66576794215611, 93.78894547053746, 86.84009374891008, 79.69428144182477, 81.77286979130336, 76.52586119515556, 75.19770608629499, 70.3391365323748, 67.84240559169224, 68.76296547480992, 72.52428245544434, 71.19134698595319, 70.19887324741909, 69.15236336844308, 68.09986414228166, 71.45314121246338, 71.69844736371721, 74.5280248097011, 69.65132740565709, 69.40943281991142, 73.06737450190953, 67.06552055903843, 75.04675647190639, 75.00357341766357, 78.46919591086251, 74.7187806538173, 69.68210097721645, 78.99258286612374, 73.57323115212577, 54.74429389408657, 42.05925260271345, 34.00859028952462, 18.922824791499547, 6.149852744170597, 1.4178534213985716, 0.5105040179831641, 0.44382614589163233, 0.15347170191151754, 0.13565382015492233, 0.03684750831286822, 0.10349054780921765, 0.27758655909981045, 0.04255820830751743, 0.028800761526716605, 0.023209853496934687, 0.07777137003306832, 0.07474354321935348, 0.053804790534611256, 0.040038495657167265, 0.053659092102731974, 0.02421077576998089, 0.07042319540466581, 0.04078955249860883, 0.04533542839011975, 0.024475124531558583, 0.02173833835071751, 0.026425553086612905, 0.011459122295491397, 0.06254000269940921, 0.05700606107711792, 0.07773369776883296, 0.014723824836047632, 0.06410647542881114, 0.007974361518530973, 0.022046914024810706, 0.04658218559675983, 0.03543441503175667, 0.08015376076634441, 0.03161952830851078, 0.034428144206425974, 0.04644644805895431, 0.056164433381387165, 0.05078928591683507, 0.09146495988326413, 0.02648924377613834, 0.08495822974613734, 0.018171871779486537, 0.06853492065731968, 0.10369938053190708, 0.07706941198557615, 0.13967494081173623, 0.22228146317814076, 0.11401370992617947, 0.029440691295479025, 0.11104906150805098, 0.06634152228278772, 0.04453659589801516, 0.07354333690766778, 0.008149082589495395, 0.061452507839671204, 0.045775193721055984, 0.04139378793271525, 0.0430831433539944, 0.17876526181186947, 0.09880525672010013, 0.048121554244841845, 0.04489910323172808, 0.15891899461192743, 0.1447427695883172, 0.1079887260815927, 0.12437536035265241, 0.14444785112781183, 0.07923735172620841, 0.1923378485121897, 0.16546531048204216, 0.16810920861150536, 0.13026503074382031, 0.1722550168633461, 0.10561465418764523, 0.14544699394277164, 0.14264936691948346, 0.10221126502645866, 0.11136143867458616, 0.22748913802206516, 0.1178259232214519, 0.1329108966248376, 0.11097968808774437, 0.11823525625680174, 0.1373483527983938, 0.10353663390768425, 0.1874373329005071, 0.12685959919222764, 0.18206060784203665, 0.20508484808462007, 0.18292495289019176, 0.14784238540700503, 0.35987657202141626, 0.12703766035182135, 0.20164273492991924, 0.20821376304541314, 0.17597167885729245, 0.18110723899943487, 0.25516811492187635, 0.11417309780205999, 0.16309802393828118, 0.14603695300008568, 0.1536845854882683, 0.17375938328249113, 0.12122979414250169, 0.21279063102390083, 0.13162610413772718, 0.1264584492892027, 0.08716111404023, 0.24685258684413774, 0.16374491208365985, 0.0819566622376442, 0.2001532827104841, 0.11637692525982857, 0.17240128187196596, 0.15501919601644787, 0.18892029832516397, 0.13908247117485317, 0.2509379376258169, 0.11998077402157442, 0.14880699078951562, 0.4704861396125385, 0.19389267079532146, 0.2061002893107278, 0.1633223747568471, 0.16954542297337735, 0.1900749477956976, 0.1382190625050238, 0.11691545136272907, 0.07626175853822913, 0.31762411498597687, 0.6936568500740188, 0.6872748753854206, 0.098484221446727, 0.7125753292015621, 2.5789381180490767, 12.530292749404907, 29.525345052991593, 35.54897117614746, 63.33929892948696, 85.79860046931675, 97.28862803322929, 114.86448546818325, 113.72112464904785, 105.02623231070382, 97.39740903036935, 105.36920928955078, 100.18315029144287, 104.62718336922782, 92.05846881866455, 91.18126569475446, 85.60383551461356, 87.18139621189663, 95.67934186117989, 88.40266718183244, 97.18360601152692, 107.21843065534318, 104.74268327440534, 104.22582762581962, 100.1706018447876, 94.85754367283413, 95.78473213740757, 94.65069580078125, 99.33761705671037, 99.1677474975586, 90.77252401624406, 92.08744280678886, 80.90716593606132, 74.12498760223389, 79.24925627027238, 72.45389720371791, 50.13265984398978, 37.33958796092442, 26.61740061214992, 14.379553198814392, 3.360017257077353, 0.4534431855593409, 0.5502359345555305, 0.6351663172245026, 0.2547206075063774, 0.2749732221875872, 0.15754682038511547, 0.3393541718167918, 0.5683579764195851, 0.15909131536526339, 0.19288313282387598, 0.11350773314812354, 0.14813872879104956, 0.12951064908078738, 0.15746002218552999, 0.14771731783236774, 0.18091438577643462, 0.1752324556665761, 0.1715710535645485, 0.190625986084342, 0.1470682176628283, 0.1224698576011828, 0.16474577837756701, 0.30959346305046764, 0.14234648245785916, 0.1569073147007397, 0.189479655453137, 0.24296935807381356, 0.2057674000305789, 0.20550893247127533, 0.10992574678467852, 0.06977108932499375, 0.14597492132868084, 0.08364100328513555, 0.1208326340253864, 0.18110318136002335, 0.208112932741642, 0.12109838905079023, 0.17504699847527913, 0.13318089927945817, 0.136947718581983, 0.13611953945032187, 0.2124903928488493, 0.21249774816845143, 0.14271438414497034, 0.2427120575947421, 0.18671888645206178, 0.2372370942362717, 0.27146842596786364, 0.217069662841303, 0.19159291205661638, 0.16090400809688227, 0.15557510618652615, 0.11530786619654723, 0.23252974397369794, 0.14249550231865474, 0.18077995441854, 0.0860879701961364, 0.13044609102819646, 0.14352504350245, 0.2058911376765796, 0.12227309601647512, 0.13573855560805115, 0.16717497445642948], [0.08328397172902312, 0.013824104364695293, 0.0399588051119021, 0.02197812414462013, 0.01743512863426336, 0.04409202993182199, 0.03190709823476417, 0.03826341412163206, 0.019706807897559235, 0.05446854706055351, 0.04776423431134649, 0.09683337288775615, 0.06020941132945674, 0.06426941204283919, 0.03565756484333958, 0.05625203903764486, 0.020425936273698295, 0.08205188105681113, 0.04938735792945538, 0.08774606550910644, 0.15859890250223024, 0.0366694505459496, 0.04571401021842446, 0.0064781324305970755, 0.06911037263593503, 0.028586300356047492, 0.04043872953791704, 0.042871216511619945, 0.11615317155207906, 0.14428908750414848, 0.08040283740098987, 0.06505012086459569, 0.06971283030829259, 0.016079517447256615, 0.05866057372518948, 0.07134966033377818, 0.05717028012233121, 0.05982705684644835, 0.0891880609893373, 0.09552903180675847, 0.06901119117225919, 0.1926672908344439, 0.1146152855030128, 0.09121031926146575, 0.07349756293530975, 0.023244294238143733, 0.0533654900001628, 0.031122148569141115, 0.035823371660496504, 0.07128851075789758, 0.041182743185865026, 0.039752869733742306, 0.047838343906083276, 0.06216359218316419, 0.04463022694523845, 0.02758093028595405, 0.015982690500095487, 0.022981772432103753, 0.02609157475775906, 0.07399950243000473, 0.06700412529919829, 0.11756681783923081, 0.009113745647482574, 0.02771639640975211, 0.13574801438621112, 0.13155082746275834, 0.1169975676706859, 0.041020189944122515, 0.03288976621947118, 0.039496943288083584, 0.07510987749057156, 0.04320185984085713, 0.14930164281811031, 0.23805719880121096, 0.2150016373821667, 0.14253029759441102, 0.19579100821699413, 0.5071482551949364, 4.290752777031489, 8.547600950513567, 9.57927816254752, 9.148457714489528, 16.781155484063284, 20.18459333692278, 24.88836223738534, 28.77837722642081, 31.57911443710327, 45.146906988961355, 46.49963092803955, 49.375632762908936, 46.721268040793284, 45.69061047690255, 49.30797815322876, 46.76209218161446, 43.072105407714844, 35.16920695986067, 37.21771655763899, 43.58360052108765, 44.32336827686855, 37.296880858285085, 29.03734701020377, 22.351762533187866, 15.979757206780569, 8.703257969447545, 3.072753540107182, 0.5697295942476818, 0.383112406624215, 0.26040882085050854, 0.1747577389968293, 0.31289019329207285, 0.21430727892688342, 0.21185738752995217, 0.007442823478153774, 0.09808653207229716, 0.17597664573362895, 0.04075172417131918, 0.009369598302458013, 0.17275943979620934, 0.11452552889074598, 0.13260628868426594, 0.05954666582069226, 0.06516178058726446, 0.17881001798169954, 0.10613272924508367, 0.011508810566738248, 0.05518514450107302, 0.1278504638799599, 0.09083078069878475, 0.028944088478705714, 0.04546429915353656, 0.047454428792532, 0.018972731394959346, 0.01779985477748726, 0.059266525852893076, 0.006231781386304647, 0.12253425057445254, 0.034796812638108215, 0.10480105677353484, 0.07307335641235113, 0.015256334029670273, 0.10083025627370391, 0.011972451000474393, 0.027722635539248586, 0.027463131517704045, 0.055178922334952016, 0.05372633831575513, 0.08745337942881243, 0.064466797879764, 0.0993598641029426, 0.2138961274176836, 0.10699442800666605, 0.06353927443602256, 0.12366791974220957, 0.06830579295222249, 0.006099690126055586, 0.08919024587209735, 0.0691456361008542, 0.025444167533091137, 0.057297403658074994, 0.09290960165006773, 0.052058719763798375, 0.06154389293598277, 0.07379390631935426, 0.1511883501495634, 0.03421804601592677, 0.11700287381453173, 0.08981788397899695, 0.054206384878073416, 0.09163141809403896, 0.02924367526013936, 0.02917148931218045, 0.062195313695286, 0.1060142841722284, 0.03233023267239332, 0.06972493537302528, 0.02761878745098199, 0.0020421537670439905, 0.006795392928844584, 0.07805561513773032, 0.04120274300553969, 0.016905883194080422, 0.026493138567145382, 0.02150051691569388, 0.03732869481401784, 0.033616931842906136, 0.09118310322186776, 0.10324682481586933, 0.15429874110434735, 0.17503004867051328, 0.06896359872605119, 0.07389292493462563, 0.09980530877198492, 0.08118455045457397, 0.04967402879680906, 0.05310500040650368, 0.013951316109991499, 0.052267396423433504, 0.06732950998204094, 0.04644671608028667, 0.0848461968292083, 0.03636565345472523, 0.08181553373911551, 0.04023388320846217, 0.11315925791859627, 0.07626521906682424, 0.09920660339828048, 0.08256589168948786, 0.023384433771882738, 0.06850480048784188, 0.07895738817751408, 0.04524710687941738, 0.0540286765566894, 0.05467482509889773, 0.10268870940698044, 0.10178818487163101, 0.030664025473275354, 0.06292761582881212, 0.19359963866216795, 0.0238247097004205, 0.08409967938704149, 0.12979917574141706, 0.06619822925754956, 0.0658586835488677, 0.05941226838954857, 0.03157926743317928, 0.08715693426451512, 0.038765889658991776, 0.02455120866319963, 0.12279829569160938, 0.04973198925810201, 0.059289154995765, 0.050015698320099285, 0.11296248276318822, 0.11251796768712145, 0.0719679007306695, 0.0542990184788193, 0.10301262166883264, 0.01761547476053238, 0.012613700519848083, 0.048074491055948396, 0.17348415590822697, 0.17074052670172282, 0.10685367270239762, 0.03877952142751642, 0.14428211216415676, 0.08917343855968543, 0.06626363324799708, 0.03175055342061179, 0.2679662081812109, 0.18750832123415812, 0.08853716270199843, 0.08305910522384302, 1.1129008936030524, 3.4202946169035773, 9.896258456366402, 18.615809951509746, 21.32545975276402, 23.43934495108468, 32.03905739103045, 39.55573327200753, 44.47903919219971, 49.9447214944022, 55.38152708326067, 69.93539060865129, 69.40270696367536, 70.05684512002128, 70.6491790499006, 67.22796944209507, 68.66548919677734, 69.66965675354004, 68.17025634220668, 61.503355571201865, 60.50346115657261, 67.7758071081979, 67.37320068904332, 59.73658152988979, 48.64038481031145, 42.67798621313912, 36.04958193642752, 24.249739408493042, 12.104836310659136, 4.362376545156751, 3.4808084326131, 1.393542000225612, 0.33615460778985706, 0.3999253644474915, 0.3039665621306215, 0.1632863309766565, 0.02272236849447446, 0.06562395792986665, 0.12023500752236162, 0.15853928641549178, 0.056092912397746525, 0.14355918738458837, 0.11865928636065551, 0.05086484418383666, 0.10978183629257338, 0.04691673728770443, 0.13409260607191495, 0.03740368989695396, 0.00703205110039562, 0.05544376812343087, 0.08261112283383097, 0.04218594703291144, 0.08621655258217029, 0.08318525845451014, 0.054609760375959535, 0.07771135361066886, 0.03809351573831268, 0.0764517890555518, 0.048044910321810415, 0.09143512469849416, 0.05714782061321395, 0.10661540513059922, 0.036590981363717995, 0.04683707727651511, 0.06657986449343817, 0.02775570224704487, 0.027552674391439984, 0.01812303252518177, 0.07660775032958814, 0.15354050536240849, 0.07607036416551896, 0.05471439726118531, 0.0410084512882999, 0.10749201809189149, 0.07820517104119062, 0.0664642353409103, 0.04938630620017648, 0.09331657338355269, 0.0689512968861631, 0.09631974902004004, 0.08998291726623263, 0.07966497128031083, 0.08478523724313293, 0.12156836954610688, 0.03106102274198617, 0.07850117515772581, 0.07535713565136705, 0.06026619113981724, 0.04050173151439854, 0.064528252796403, 0.03919926658272743, 0.03644626002226557, 0.08167025939162288, 0.06165025330015591, 0.034378977558974705, 0.014168916353290635, 0.14667696080037526, 0.02484022726171783, 0.05372362078300544, 0.03324989528794374, 0.12746413318174227, 0.09584908998970475, 0.0992965092882514, 0.07814130732523543, 0.13450742167021545, 0.09706993055130754, 0.11230504339826958, 0.14731003397277423, 0.10479155728327376, 0.14648976655943052, 0.1630059467362506, 0.22888359533888952, 0.2405440296445574, 0.2451771753174918, 0.15734722252402986, 0.2145888709596225, 0.18964174389839172, 0.16204928021345819, 0.14553685912064143, 0.2577156610786915, 0.34901121790919987, 0.2446925656071731, 0.15686961529510363, 0.17670383171311446, 0.12146922200918198, 0.1390140341328723, 0.14815201450671467, 0.24466637415545328, 0.3711416646838188, 0.14530329379652226, 0.14729209350688116, 0.15628322533198766, 0.18038614626441682, 0.12771152704954147, 0.24243404822690146, 0.2069052489740508, 0.1743731860603605, 0.15621142275631428, 0.20729523019066878, 0.18702500074037484, 0.22090576056923183, 0.3468605875968933, 0.19548201694020204, 0.12595815184925283, 0.17942881477730616, 0.1741036990923541, 0.11130801761256796, 0.17459666835410254, 0.1258497355239732, 0.19822682679763862, 0.18889716028102807, 0.17520295296396526, 0.2040642907044717, 0.13469936565629073, 0.14289334097078868, 0.0907324609745826, 0.3055139476699488, 0.25138967909983223, 0.13477785858724797, 0.15138987505010196, 0.20187482104769774, 0.1286374966480902, 0.08570721705577203, 0.11646778109882559, 0.26351941536579815, 0.22827220814568655, 0.31540435552597046, 0.1085694231359022, 0.38673496938177515, 0.22268451297921793, 0.15539667861802237, 0.1562971488705703, 0.2347314272608076, 0.3459539833877768, 0.31106520550591604, 0.12638496394668305, 0.44335334269063814, 1.2047993966511317, 5.097977118832724, 9.606224145208087, 12.293637973921639, 16.128551142556326, 25.716617039271764, 30.48904630116054, 38.35641166142055, 42.772068296160015, 52.37272432872227, 66.79811913626534, 67.8451292855399, 72.66251686641148, 71.31249577658517, 69.98648766108921, 69.16472421373639, 66.5990879876273, 61.9818571635655, 57.75947162083217, 58.10726022720337, 67.49883106776646, 65.0120985848563, 61.763655935014995, 46.8316193308149, 38.77099330084664, 32.76493222372872, 17.764638253620692, 8.14367003100259, 2.990664916379111, 1.2331754054341997, 0.40057466817753656, 0.20721491878586157, 0.4939692052347319, 0.502485525395189, 0.5313691326550075, 0.1533586172653096, 0.3775140584579536, 0.7454393314463752, 0.28616451738136156, 0.15888810769787856, 0.1742568037339619, 0.25165259784885813, 0.18667096830904484, 0.2563908078840801, 0.13368596003523894, 0.3464397058955261, 0.19562795625201293, 0.1765738379742418, 0.3111343889364174, 0.23021827372057097, 0.15761865010218962, 0.19467518452022756, 0.19002240204385348, 0.17941821606031486, 0.14389679926846707, 0.08866232527153832, 0.1443295824740614, 0.11503459300313677, 0.1995597817003727, 0.16018301035676683, 0.2138578716133322, 0.10624225158244371, 0.13757848473531858, 0.2311237651322569, 0.19250100904277392, 0.15817587663020405, 0.13882069236465863, 0.12283959133284432, 0.2611647902854851, 0.19378234100128922, 0.08581600657531194, 0.20017567436609948, 0.26441027756248203, 0.1318694403661149, 0.12130716070532799, 0.21159494375543936, 0.18998615470315727, 0.18054470632757458, 0.18235844400312218, 0.14765661608959946, 0.22596985740321024, 0.19378192030957767, 0.2410815650863307, 0.10996591605778251, 0.26714490939463886, 0.18443135491439275, 0.17697418720594474, 0.10198284978313105, 0.20984475766973837, 0.20227720588445663, 0.128836700958865, 0.24910453600542887, 0.18437020533851214, 0.19719439505466393, 0.13316694859947475, 0.2886574278984751, 0.09328145241098744, 0.19155684113502502, 0.1257710118911096], [0.06223306059837341, 0.06312094402632543, 0.032192659697362354, 0.018887156254744956, 0.050646481436810324, 0.028910232973950248, 0.011150918967489685, 0.018938763931925808, 0.046318391537559886, 0.019817259827894822, 0.05122173324759517, 0.028350324536274587, 0.038865881972014904, 0.026276170209582363, 0.026964593179790036, 0.0472291178469147, 0.030648683796503713, 0.012827459406772894, 0.016703381203114986, 0.021076900718201484, 0.07729697906013046, 0.09180428167538983, 0.022083142705793892, 0.07888718015913453, 0.012898553761520555, 0.014669140002557209, 0.031236128881573677, 0.01119774382095784, 0.04178761983556407, 0.024235725502616594, 0.05279500489788396, 0.055464208990867646, 0.026328941574320197, 0.01302696651379977, 0.039176260852920156, 0.05127930694392749, 0.0168386963528714, 0.006304795571070696, 0.037216434587857554, 0.044439955547984154, 0.07508192863315344, 0.07785789003329617, 0.027463905047625303, 0.024104963322835307, 0.028024856732892137, 0.013630309674356664, 0.04158995919195669, 0.05688238449926887, 0.031073236372321844, 0.06318277213722467, 0.06892651000193187, 0.010036471000473415, 0.04355551568525178, 0.057415448395269256, 0.07232415875686066, 0.008219334712651159, 0.010376460301423711, 0.05003216636500188, 0.03340879461861082, 0.043839167071772475, 0.07217880977051598, 0.018971708503418734, 0.03219699553613152, 0.09098291503531591, 0.00927565767363246, 0.04633809619450143, 0.05822042841464281, 0.040860856351043494, 0.11787413991987705, 0.038606634097439904, 0.04550242264355932, 0.06246572347091777, 0.04498168094349759, 0.059220806163336547, 0.037942324565457444, 0.06388864533177444, 0.07491513794021946, 0.035936052578368356, 0.22762644636843885, 0.17101563193968364, 0.34967026540211266, 0.30620599910616875, 0.34135484588997705, 0.22740103703524384, 0.10626633279025555, 0.0490792046434113, 0.1277997773140669, 0.25002984063965933, 0.20175301044115, 0.3416888751089573, 0.31236039314951214, 0.1583516714828355, 0.4180282716240202, 0.49781210188354763, 0.33779579401016235, 0.37755232783300535, 0.15265300869941711, 0.10207698294626814, 0.12972858095807688, 0.06889011338353157, 0.06233972630330494, 0.24955318335975918, 0.25781456434300964, 0.2966421294425215, 0.29045972547360827, 0.10511001412357603, 0.030377198542867388, 0.04218505136668682, 0.10009894480130502, 0.0724009010674698, 0.049744589653398306, 0.05431046875725899, 0.020021088354821717, 0.038006734502102645, 0.04476784402504563, 0.04028550276000585, 0.02493126630516989, 0.035992133497659645, 0.0832193209124463, 0.005879480491525361, 0.06104892199592931, 0.05672185668455703, 0.031184943592441932, 0.03671777920265283, 0.01859043289109, 0.015039243535803897, 0.052176143641450574, 0.029890068074954406, 0.043758418011878214, 0.033487803236182244, 0.042779118953538794, 0.024317875737324357, 0.028122966111238514, 0.05568684311583638, 0.036852644822959385, 0.024197259352409413, 0.021893748315051198, 0.003359311738417351, 0.01712717381971223, 0.00928645146944161, 0.011060297223074096, 0.07857436194483723, 0.01854489810232605, 0.04769724254895534, 0.018020677213956202, 0.04999286222404667, 0.026972906930106025, 0.05198317506749715, 0.032863011583685875, 0.05509160505607724, 0.037376273689525466, 0.037701600696891546, 0.05825282846178327, 0.04330021349181022, 0.04540201642417482, 0.08595005116824593, 0.02653805080002972, 0.014826714493600386, 0.05506694709349956, 0.04019559008468475, 0.014675479215968932, 0.01533301018311509, 0.08412934493805681, 0.013796892565941172, 0.06741047278046608, 0.08899002375879458, 0.03772326971271208, 0.025880367162504365, 0.03303922712802887, 0.027463908440300396, 0.007209781474167747, 0.015501456501494561, 0.018698180859376277, 0.03893962176516652, 0.04188470462603228, 0.017413490152518665, 0.026180890322263752, 0.01241672265210322, 0.017144936170162897, 0.007246768418034273, 0.010561881021463444, 0.011420954700692423, 0.030373042515878166, 0.009243134642019868, 0.06117487845144101, 0.04486161417194775, 0.023412389414651052, 0.033115969438638, 0.05006555028791938, 0.036450246415500126, 0.045321009520973475, 0.01409763709775039, 0.02725507232493588, 0.044697747964944155, 0.04377221941415753, 0.03401482817051666, 0.07087718961494309, 0.05366614208157573, 0.007716565708895879, 0.055607172926621776, 0.04410436909113612, 0.03745505160519055, 0.01717838116123208, 0.04845985144908939, 0.004912088450510055, 0.020014506565140824, 0.10329605931682245, 0.09305715587522302, 0.014292403789503234, 0.04807313398591109, 0.0462826870248786, 0.020788964383038025, 0.062063833964722495, 0.035287383278565745, 0.019348538015037775, 0.07065356482884713, 0.02932213426434568, 0.06348532411668982, 0.005441763912261064, 0.03612475995240467, 0.028288238582068255, 0.049864914268255234, 0.029512174959693636, 0.036656663553523164, 0.030640219072146074, 0.08865655093852963, 0.02839792037515768, 0.02024172928317317, 0.02988544385880232, 0.11163669997560126, 0.040904428477266004, 0.049683921837380955, 0.04344104682760579, 0.019433173384251337, 0.1157008193965469, 0.03147921744467957, 0.06228182012481349, 0.037342282477766275, 0.037884391245565245, 0.04857914469071797, 0.02674240349525852, 0.058930969930120876, 0.0875777481123805, 0.05869739103530135, 0.11417081792439733, 0.08517728120620761, 0.005972442333586514, 0.0568046040300812, 0.05148544588259288, 0.04077307427568095, 0.029972316697239876, 0.1187507121690682, 0.050414246041327715, 0.08161026332527399, 0.16633057833782264, 0.1630350151764495, 0.12448159179517201, 0.07610798214695283, 0.19357751842056, 0.3309683475111212, 0.4941697801862444, 0.16253386278237614, 0.3703925077404295, 1.1189107596874237, 1.0655949520213264, 1.6776363615478789, 1.9552541332585471, 1.810582976256098, 3.49551950607981, 2.7062304190226962, 2.4161272772720883, 1.859533361026219, 1.2143992015293665, 0.4813332004206521, 0.46093339792319704, 0.17834684997797012, 0.20611235366335937, 0.5709226759416717, 0.3908019997179508, 0.19373609205441816, 0.2769618997616427, 0.23812125250697136, 0.16317737182336195, 0.06888500401484114, 0.06453730445355177, 0.1023376625297325, 0.02801270586704569, 0.09740098100155592, 0.023812731861003807, 0.12022611871361732, 0.01232276251539588, 0.11169028388602392, 0.01492855411821178, 0.05739740614912339, 0.11267987971327134, 0.0999457790915455, 0.06169667188078165, 0.031177686660417488, 0.025558234358738576, 0.05286685497100864, 0.02471929875069431, 0.019846311304718256, 0.040930582609559805, 0.03083014102386577, 0.10200746024825744, 0.028859872104866163, 0.0068954662419855595, 0.046916058752685785, 0.04464638964938266, 0.030993980089468614, 0.002603674997642104, 0.02299317860576723, 0.022171929012984037, 0.05721150791006429, 0.07302630000880786, 0.04867584610890065, 0.045176814044160504, 0.020104230946994255, 0.08776875572013003, 0.03808626559163843, 0.046344352287373373, 0.05938754935881921, 0.03089757722669414, 0.08750735010419573, 0.022839656665122936, 0.05821047430591924, 0.02889432811311313, 0.060354407477591715, 0.06631300345595394, 0.01368465948118163, 0.05536690028384328, 0.021876033462051834, 0.08636467677674123, 0.0334110643182482, 0.0837254673242569, 0.054036897008440325, 0.08929658588021994, 0.06482677427785737, 0.01924275610196803, 0.024709234380030205, 0.043988095330340524, 0.07426333720130579, 0.046965086300458224, 0.030934319897953953, 0.043192027868436914, 0.07283295145524399, 0.012474661061008061, 0.041967394296079874, 0.033110737933644226, 0.028333116888201663, 0.01853212807327509, 0.04756059577422483, 0.16311681935829775, 0.09937337373516389, 0.08816897603017942, 0.08923364497189011, 0.14231558197310992, 0.06927463239324944, 0.11703043590698924, 0.08760722367359058, 0.14056861214339733, 0.11591226447905813, 0.09657965507358313, 0.15105127250509603, 0.08752001835299389, 0.1303084705557142, 0.11406529215829712, 0.12337534901286874, 0.11150228897375719, 0.06240436354918139, 0.14109930795218262, 0.04703008316989456, 0.15099173784255981, 0.13984031336648123, 0.153560427150556, 0.16263294246579918, 0.11888153372066361, 0.10366491773830992, 0.14552784817559378, 0.07475435228220054, 0.1459736999656473, 0.07375516196978943, 0.2124654363308634, 0.20334694348275661, 0.13206198146300657, 0.10970070386039359, 0.13549322448670864, 0.19193288524235996, 0.12321601541978972, 0.09158048725553922, 0.12477847800723144, 0.24109980410763196, 0.13158301716404303, 0.1722059587814978, 0.16048691262091908, 0.1250902512776, 0.12580032460391521, 0.16580043892775262, 0.10779142166887011, 0.13376522649611744, 0.15345505066215992, 0.21904905805630343, 0.10618177375623158, 0.1109893572117601, 0.18289758078753948, 0.13087203460080282, 0.14352657699159213, 0.22924916286553654, 0.11737080264304366, 0.17633639142981597, 0.23072668643934385, 0.1393832793193204, 0.16168436408042908, 0.1033611511811614, 0.08164741311754499, 0.09396566676774196, 0.27562713995575905, 0.15113896637090615, 0.13643632030912808, 0.11490192583629064, 0.22658326663076878, 0.1619418952614069, 0.23742200859955379, 0.18902681475239141, 0.14532191279743398, 0.14904308026390417, 0.14803419368607657, 0.16267000404851778, 0.08595509268343449, 0.0843069175524371, 0.21725730491536005, 0.14320721769971506, 0.28464611885803087, 0.38377612243805614, 0.6098204287035125, 0.4893076696566173, 0.39263806119561195, 0.11065593867429666, 0.15721009059676103, 0.3874385016305106, 0.2554280752582209, 0.41835535264440943, 0.6091013444321496, 0.45298978845988, 1.0750851056405475, 0.7431832839335714, 0.7421014276998383, 0.581353984773159, 0.3871947447104113, 0.08602013026497193, 0.1468309068254062, 0.11745017766952515, 0.1576479221028941, 0.40031970185892923, 0.6777266391686031, 0.6075180779610361, 0.42965396493673325, 0.2993398761110646, 0.13125672324427537, 0.14287438270236763, 0.26270948882613865, 0.3650062696209976, 0.1937977708876133, 0.3440220041998795, 0.10465771625084536, 0.3081123025289604, 0.34157930527414593, 0.1782031769731215, 0.20164448555026734, 0.3115693027419703, 0.1963902089212622, 0.15852031457637036, 0.11673041486314364, 0.19209539437932627, 0.10210811413292374, 0.10490622970142535, 0.0972546006419829, 0.12458433556769576, 0.21771515320454324, 0.1884932012430259, 0.31210949804101673, 0.09015027114323207, 0.1514651110129697, 0.14105673666511262, 0.10033389433686223, 0.1502327692828008, 0.14940891920455865, 0.05636800067233188, 0.11258912565452711, 0.10622007705803428, 0.1468241757580212, 0.10251864817525659, 0.07205995757664953, 0.1418772754924638, 0.18659870432955877, 0.09741128794848919, 0.08296063622193676, 0.15746486692556314, 0.22546873215053762, 0.1701913611697299, 0.09019374488187687, 0.1289083949689354, 0.06113945213811738, 0.12375241092273168, 0.2226034958979913, 0.15898102628333227, 0.15674674617392675, 0.15514084377459117, 0.13793037299598965, 0.07584920924689088, 0.1666007845529488, 0.18073713885886328, 0.13968548524592603, 0.22075374158365385, 0.130318105752979, 0.11990639301283018, 0.17846581073743956, 0.15652420025851044, 0.10254076163151435, 0.12502596686993325, 0.11805229607437338, 0.13750409015587398, 0.07703498311872993, 0.10448915458151273, 0.08786745542394263, 0.14009723386594228, 0.06954002100974321, 0.12451942690781184], [0.015225416581545557, 0.04694495077377983, 0.0429790221553828, 0.10046354202287537, 0.03291304675596101, 0.014121408723959965, 0.01538792232583676, 0.06808775929468018, 0.04686909055869494, 0.03354687988758087, 0.04300135613552161, 0.046132975058364015, 0.02857353711234672, 0.025114981357806494, 0.08792511054447719, 0.024032271866287504, 0.04419208670567189, 0.05072684033906885, 0.023870225829471434, 0.07219845335930586, 0.02573168826555567, 0.11006106702344758, 0.0870656780898571, 0.028881418984383345, 0.0052409065205470794, 0.03358281849484358, 0.029693455767950842, 0.0489954123539584, 0.042759081814438105, 0.0432367161847651, 0.050997474031256776, 0.03691487666219473, 0.026035634634484137, 0.0642887842176216, 0.046170131635985205, 0.031668416756604395, 0.012170377969076591, 0.04088804524924074, 0.036625104889805825, 0.0334495745732316, 0.04116288585854428, 0.016334729734808207, 0.01184764550998807, 0.005238679229348365, 0.02368518932988601, 0.026258855692244003, 0.023466528027451465, 0.015398049460990089, 0.0316271482567702, 0.020330671653417603, 0.019818679662421346, 0.037934076972305775, 0.006602292040562523, 0.06144379545003176, 0.027824252943641374, 0.11014673885490213, 0.029543706482010226, 0.0235420659384025, 0.07797145643936736, 0.06016244992081608, 0.09232315061880009, 0.025770317264167324, 0.04477813061592834, 0.01768084312789142, 0.06917297427675553, 0.07291193971676485, 0.042795318977109024, 0.036844102067074606, 0.10109174331384045, 0.04177370986768177, 0.05729918820517404, 0.03948769146310432, 0.05997751520148345, 0.06424845209611313, 0.022922892555860535, 0.05447623146963971, 0.03637208257402692, 0.020472689032820717, 0.059019457681902816, 0.08063557491238628, 0.03773945277290685, 0.08966531538005386, 0.09878129764859166, 0.07877927952046905, 0.042116387015474696, 0.06335837700005088, 0.03563497301989368, 0.004043487715534866, 0.04763685632497072, 0.023821975204295347, 0.03310149967936533, 0.09969227840857846, 0.07092433422803879, 0.05833722464740276, 0.02765473284359489, 0.03811622969806194, 0.06364922425044434, 0.165151840874127, 0.0398458493873477, 0.06922811881772109, 0.05013841137822185, 0.058945565218372006, 0.07818048593721219, 0.06582578138581344, 0.0664839603539024, 0.05417622738916959, 0.009273446497640439, 0.051665468008390496, 0.03369462410254138, 0.07770950799541813, 0.08620942117912428, 0.0533858256946717, 0.02613755568329777, 0.05161943280005029, 0.061315477692655156, 0.09026818017342261, 0.06831520423293114, 0.08384126611053944, 0.045716167959783754, 0.042985855003020594, 0.051249051067445955, 0.05386472214013338, 0.0429443320525544, 0.038152229373476336, 0.05345492770097085, 0.05357899782913072, 0.057597662189177105, 0.038855690376034806, 0.004730934443484459, 0.033284005243331194, 0.05146290155659829, 0.0494618000063513, 0.043574599482651265, 0.038576456252485514, 0.01830882389497544, 0.030741317397249595, 0.04760398130331721, 0.028840282798877785, 0.053863124190164466, 0.017507212801969478, 0.06289391977978603, 0.05669997732288071, 0.039630614686757326, 0.00806546926365367, 0.027236378685172116, 0.02261389110104314, 0.05231282434293202, 0.030932681235883917, 0.08874712857816901, 0.03492537127541644, 0.026578552555292845, 0.07733888538288218, 0.01572256731534643, 0.11399586445518903, 0.07470658341688768, 0.02189194510823914, 0.05340213428384491, 0.038551092613488436, 0.0193098937493882, 0.025724897826356546, 0.051893550769558976, 0.03898406920156308, 0.07009240958307471, 0.01593499118462205, 0.05367732094600797, 0.018674114918602363, 0.07083374980304923, 0.020064886093937924, 0.013584136214506413, 0.02373104981545891, 0.03263106795826128, 0.01726972554544253, 0.024861124443954656, 0.018314018080543195, 0.03209847225142377, 0.07027968524822167, 0.021912857557513883, 0.07052197653268065, 0.053473628126084805, 0.0602507476827928, 0.01429443430554654, 0.023365835127021586, 0.0015785703726578504, 0.02090916855792914, 0.02431677990326924, 0.015148587757721543, 0.05959533713757992, 0.016473990565698062, 0.009047129623857992, 0.010672931758952993, 0.05768733059189149, 0.04692342425031321, 0.014623552627329315, 0.035594827495515347, 0.016960500174068978, 0.11612206750682422, 0.09336434224886553, 0.03662332034270678, 0.07599252262817961, 0.0878742475594793, 0.05828639558915581, 0.05915680674037763, 0.05286700085603765, 0.05299264518544078, 0.013889034228798534, 0.00804027949925512, 0.019687176183132187, 0.016906222461589744, 0.019897593285090158, 0.056347559804895093, 0.020167597636048282, 0.04649541453857507, 0.04200094785275204, 0.061872154607304504, 0.025998557784727643, 0.038139337208122015, 0.024305762190903937, 0.037786434537598064, 0.03886170219630003, 0.054956973530352116, 0.02396974486431905, 0.0377163825822728, 0.03690578090026975, 0.0396508078889123, 0.05498281214386225, 0.07035114855638572, 0.0008416195851168595, 0.06162873016936438, 0.024271043250337243, 0.06851172154503209, 0.02251593439307596, 0.0916284868227584, 0.02910451790583985, 0.027591310175401822, 0.0926659329395209, 0.043710289523005486, 0.06426293881876127, 0.04194600347961698, 0.007599405611732176, 0.018287319423896924, 0.08159963068153177, 0.024130326961832385, 0.039357426310224194, 0.0152022513960089, 0.18464756331273488, 0.08794957173189946, 0.053864359123898406, 0.06579253995524985, 0.09509259808276381, 0.017275681386568716, 0.06085430458188057, 0.019702056456091147, 0.11879512907138892, 0.028255802911839316, 0.06793078700346605, 0.09158233965614013, 0.010442354533422207, 0.03695642675406166, 0.038632058804588656, 0.10438315384089947, 0.08864876135651555, 0.03264260983892849, 0.017437590020043508, 0.07468138262629509, 0.12225215642579965, 0.12607590481638908, 0.03836252773180604, 0.21680784331900732, 0.11788958337690149, 0.0786198034350361, 0.1841124298849276, 0.029657527338713408, 0.03696380242971437, 0.14179064014128276, 0.1725804422582899, 0.18081331120005675, 0.04749911032351, 0.08941330747412783, 0.23192126091037477, 0.2091510370373726, 0.09427617117762566, 0.06145524912114654, 0.038188989008111615, 0.04599455391455974, 0.09501863098038094, 0.09059794140713555, 0.07318629178085498, 0.07307119867099182, 0.027171193522268107, 0.06595676578581333, 0.06064114959112235, 0.07483226845839194, 0.03293571661093405, 0.06251185706683568, 0.11950182329331126, 0.12070251815021038, 0.034822291628058465, 0.022131240660590783, 0.03544222836249641, 0.026032699970528483, 0.031097168302429572, 0.03600314612101231, 0.034068340834762366, 0.05718000352914844, 0.016373372304120233, 0.01812686285536204, 0.0262051140224295, 0.026375394081696868, 0.06617008362497602, 0.06063127690660102, 0.011814086016134491, 0.041848711735968075, 0.059981884967003546, 0.039098738227039576, 0.016953005754788007, 0.023106957054031745, 0.08673696858542305, 0.032957785962415595, 0.036636558560920615, 0.016605295573494265, 0.01716842026715832, 0.04793905546622617, 0.011076624471960323, 0.023649724000798802, 0.06553036759474448, 0.016953535012102554, 0.02510193143306034, 0.04767277457618287, 0.02880380136360015, 0.03500843074704919, 0.05854620664779629, 0.00843421318235674, 0.010044362362740296, 0.026358798811478273, 0.02669719949231616, 0.04922171735337802, 0.022564176536564316, 0.05365192677293505, 0.00679517282904791, 0.0059357272278118345, 0.02817740836845977, 0.06598926761320659, 0.01973194762000016, 0.04138268370713506, 0.02549041647996221, 0.017096073167132478, 0.042273959810180325, 0.05969078665865319, 0.028983982945127145, 0.022459146101027727, 0.053955686544733386, 0.04391897975334099, 0.07396858837455511, 0.16090501232870988, 0.1869625619479588, 0.2199239611093487, 0.0700571732595563, 0.07664054392703942, 0.1740426445113761, 0.08448861565973077, 0.12989095438803944, 0.11160943643855196, 0.1587386400039707, 0.15944922901690006, 0.0944018562191299, 0.08116462866642646, 0.1374695934355259, 0.13699802516826562, 0.19365706986614636, 0.17742459875132355, 0.07368938478508166, 0.28991030209830826, 0.18042921966740064, 0.18103737703391484, 0.278371054146971, 0.14963959396949836, 0.08929496418152537, 0.10541690872716052, 0.11960487919194357, 0.09612927066960505, 0.11592130256550652, 0.10212431076381888, 0.11734609039766447, 0.0924783790750163, 0.09670420696160623, 0.14483555246676716, 0.11969026603869029, 0.13905915671161242, 0.08078869312469449, 0.10843244727168765, 0.14541952684521675, 0.20408759159701212, 0.13368399228368485, 0.09916739085955278, 0.09752565502588238, 0.06776711078626768, 0.07034228688904218, 0.1227658074349165, 0.17152276901262148, 0.14526226956929478, 0.18108180750693592, 0.10569380529757057, 0.07932934750403677, 0.15298967063426971, 0.10564047923045498, 0.18165029771625996, 0.15341967184628758, 0.2869819349476269, 0.0656609788004841, 0.10124100744724274, 0.2608262284525803, 0.18470085545309953, 0.1903393186096634, 0.14639211179954664, 0.13058778271079063, 0.1981026413185256, 0.1706488701914038, 0.1854865447218929, 0.10837084307734456, 0.10997305424617869, 0.3471166124301297, 0.30909498408436775, 0.22500846827668802, 0.15053922283862317, 0.250775007797139, 0.16712424717843533, 0.09452503068106514, 0.14832232679639543, 0.19977300454463276, 0.1452621610036918, 0.19805126264691353, 0.1391206184136016, 0.17406294627913407, 0.14273841785533087, 0.22757197357714176, 0.3567249397081988, 0.3762640883880002, 0.24192294850945473, 0.12676503855202878, 0.10301898632730756, 0.13021528055625303, 0.15311780518719129, 0.14816046905304703, 0.24138926714658737, 0.17987079891775334, 0.1515336294791528, 0.24227537959814072, 0.13352795637079648, 0.08007872157863208, 0.19595403304057463, 0.21002568224711077, 0.16220680890338762, 0.09935742816222565, 0.193245280534029, 0.49303928656237467, 0.3907883475933756, 0.2644484926547323, 0.20457274413534574, 0.1314881443977356, 0.22294991516641208, 0.2682515728686537, 0.44414519305740086, 0.2487053402832576, 0.22359197214245796, 0.0918350735945361, 0.18145283045513289, 0.2103558031043836, 0.15724506229162216, 0.2114991888936077, 0.20531819627753325, 0.15832066243248327, 0.2726497825767313, 0.23088082245418004, 0.10915372321116072, 0.17882527144891874, 0.1737943006945508, 0.23542621997850283, 0.13957919952060494, 0.14174709176378592, 0.12648310725178036, 0.1344832115407501, 0.10505986360034772, 0.12377952518207685, 0.11942797154188156, 0.1089122597394245, 0.145646510379655, 0.09053585545292922, 0.18975698628595897, 0.1555473676749638, 0.19137785716780595, 0.10809643673045294, 0.11525109995688711, 0.2602481437580926, 0.15027441776224545, 0.11692371591925621, 0.09068482103092329, 0.07853811460414103, 0.13780811455632958, 0.09841443412005901, 0.10254405252635479, 0.2068278824112245, 0.16128784178623132, 0.11320668751639978, 0.11821249819227628, 0.13448435147958143, 0.2212610686463969, 0.1413218267261982, 0.11814540464963232, 0.07961883768439293, 0.08152938873640128, 0.09406359972698347, 0.10176710957395178, 0.1084468797115343, 0.11385704976107393, 0.09884647772248302, 0.08880353519426924, 0.16528425019766602, 0.16616995552820818, 0.14208574859159334, 0.13075293813432964, 0.18186832458845206, 0.06793251048241343, 0.1569622896079506, 0.1703739549432482, 0.12480905279517174, 0.12267997275505747, 0.09178365421082292, 0.20313697760658606], [0.02532510838604399, 0.018063538574746678, 0.04283726940463696, 0.022965163591184785, 0.04795403073408774, 0.02740515409303563, 0.03220044249402625, 0.01567839807830751, 0.05313878466508218, 0.041731101261185746, 0.017315172124654055, 0.03924317458378417, 0.020320559785302197, 0.1353962482618434, 0.04502570090283241, 0.013186154221849782, 0.0063408418957676205, 0.0845048665734274, 0.03287365779812847, 0.06963844251419817, 0.07040284613945655, 0.07758249981062752, 0.03521472235609378, 0.08170941764754908, 0.11404116345303399, 0.04628184564145548, 0.03284413134679198, 0.10485641166035618, 0.01523942154433046, 0.018174173709537302, 0.008465868537314236, 0.08995133824646473, 0.006599333627881216, 0.03352468500712088, 0.031113639740007262, 0.052631915613476715, 0.0772636765614152, 0.02792521216906607, 0.03760285010295255, 0.049746815248259475, 0.04316298996231385, 0.05894530737506492, 0.0196999224634575, 0.018480596731283834, 0.06285920592823199, 0.0676144879045231, 0.008663487620651722, 0.017823533953300545, 0.07095919057194676, 0.022818113178280846, 0.02019211819528469, 0.05308900394343904, 0.00863977027724364, 0.026362590125894973, 0.021912883002577082, 0.03382571028279407, 0.015042057759793741, 0.01298366834609104, 0.04821166708799345, 0.09103897559855666, 0.018585119961893985, 0.0181506794345166, 0.03485275445772069, 0.026458287312250053, 0.05668273574805685, 0.0950583117082715, 0.07930807543120214, 0.10246084377701793, 0.04154852445104292, 0.019615192099341323, 0.05381744182003396, 0.03610886866226792, 0.04919828075383391, 0.04569901798718742, 0.024874939416934336, 0.04698796310861196, 0.03962717790688787, 0.015077626565471292, 0.07940846468721117, 0.05483399923624737, 0.04839601826721004, 0.06365136842110328, 0.1627688394593341, 0.06774935352482966, 0.09737708978354931, 0.04780473267393453, 0.012743871525994368, 0.06671629074428763, 0.08311741852334567, 0.07834892547024147, 0.015234256196501, 0.07012244832835027, 0.00891939879927252, 0.018241660802492073, 0.046037081096853526, 0.03703781024419835, 0.05539273550467832, 0.0684849126264453, 0.042460699432662556, 0.0454054871307952, 0.014022222171271486, 0.0295576775180442, 0.058560130186378956, 0.03464168935481991, 0.09922159223684243, 0.05152226658537984, 0.06647174672356673, 0.08576899766921997, 0.06709693531904902, 0.04415822441556624, 0.01153366784897766, 0.043551536077367406, 0.05127757667962994, 0.03643888434661286, 0.06987257780773298, 0.074183914677373, 0.021123288764751384, 0.061350910791328976, 0.05515300908258983, 0.05710234519626413, 0.11010131772075381, 0.009301109522181963, 0.04941792593204549, 0.010634716666702713, 0.01545089716091752, 0.013499054708518088, 0.04058337624051741, 0.044907330468829186, 0.040388887748122215, 0.03668055816420487, 0.056831382414592166, 0.02924518839323095, 0.03766688005998731, 0.04531450237014464, 0.034813365499888144, 0.06556515608515058, 0.039644833388073106, 0.02086858537846378, 0.007576170876356108, 0.03130871855786868, 0.04082329943776131, 0.025806439075885073, 0.050405547222388644, 0.024079633610589162, 0.04189640935510397, 0.07477511545377118, 0.04924471629783511, 0.02535634644196502, 0.025534838471295576, 0.0471722871464278, 0.06891270859965257, 0.03134664188006094, 0.040354031404214244, 0.04238401140485491, 0.06650207045355014, 0.04075097439012357, 0.013037602550217083, 0.039564165752381086, 0.03945911835346903, 0.08079704589077405, 0.05020570169602122, 0.024677216008837734, 0.09993910230696201, 0.01797405507282487, 0.06156524643301964, 0.02399379893073014, 0.09262368734925985, 0.024771751203973378, 0.04316051330949579, 0.014903176908514329, 0.04398476711607405, 0.0029877582606526887, 0.02952447340690664, 0.04477384227461048, 0.05527216322453959, 0.026087289809116294, 0.03318828430825046, 0.04001837370118924, 0.06491475991372551, 0.03400400892964431, 0.04568573905687247, 0.025379550643265247, 0.07104155793786049, 0.019168142694979906, 0.022951382544956038, 0.04034739193905677, 0.05903491470962763, 0.022329330477597456, 0.03520700062758156, 0.17259916982480458, 0.04977169034204312, 0.03957120894587465, 0.037510386135961325, 0.06148248551679509, 0.07396719737776689, 0.06479173472949437, 0.04340783253844295, 0.032062794880143235, 0.02153847586097462, 0.030947924525077854, 0.08162388152309827, 0.024314483062231114, 0.02638299876291837, 0.08816113895071404, 0.024676345787676315, 0.03316676796280912, 0.037120937569332976, 0.03557989972510508, 0.04268643446266651, 0.012241805654152163, 0.08107130974531174, 0.04917086793908051, 0.04022685019299388, 0.04135427005322916, 0.05096032423898578, 0.005768037900062544, 0.025410166143306663, 0.017657621963215724, 0.038251298878874095, 0.03185129890750561, 0.02280068670266441, 0.0880480068070548, 0.04254200149859701, 0.0535459226396467, 0.021094384869294505, 0.010246119661522763, 0.010475780864778374, 0.01863069037374641, 0.03478154560018863, 0.06416223065129348, 0.025150663818099668, 0.035420918970235755, 0.031061073632112572, 0.02595890250190028, 0.04615787050819822, 0.03758024810148137, 0.030104661559952155, 0.05742774344980717, 0.029831714063350643, 0.029754361071224724, 0.05016822959961636, 0.017724079379279698, 0.05198129891817059, 0.03274655122576015, 0.02831860980950296, 0.06414156247462545, 0.10458030897591795, 0.02503503636190934, 0.04237661198047655, 0.05356575621824179, 0.06896283198148012, 0.05871449011777129, 0.042121038373027525, 0.07252112390207392, 0.08217581547796726, 0.10702906721936804, 0.037123777238386016, 0.07418871870530502, 0.010543734450558466, 0.05593655078804918, 0.07169466824936015, 0.0569836829922029, 0.07658502619181361, 0.06612247760806765, 0.06251881205077682, 0.19273063886378491, 0.08753726671316794, 0.09158533878092255, 0.03514243462788207, 0.09063735072101865, 0.025406917656904886, 0.015178149832146508, 0.05255695106461644, 0.10556738065289599, 0.00865628497142877, 0.04281760206712144, 0.06500291518334832, 0.05760476645082235, 0.13098385717187608, 0.10163247465555157, 0.06632957328110933, 0.04644064997721996, 0.0658430704580886, 0.015009961357074124, 0.018873205574761544, 0.055952235125005245, 0.05291282232584698, 0.12343951128423214, 0.04005524868677769, 0.06006685790738889, 0.04878034728712269, 0.05327140433447702, 0.022923270839133432, 0.06235282202916486, 0.009867330880037375, 0.030782575719058514, 0.04287171862753374, 0.04844227060675621, 0.029630755739552633, 0.01622323116420635, 0.012327411328442395, 0.0341954372291054, 0.044011928872870545, 0.02019704266318253, 0.032958362717181444, 0.012457063255299414, 0.03432441655812519, 0.010689839155280163, 0.024006602886532034, 0.024513373550559794, 0.0436863847342985, 0.03798180173284241, 0.03854144723819835, 0.035676984515573294, 0.02150315641691642, 0.009722280449100902, 0.05069036568914141, 0.024599808733910322, 0.041126265323587825, 0.021715598945905055, 0.009673538734205067, 0.03908508949513946, 0.04090246072571192, 0.044327264452087026, 0.030358267415847098, 0.032849298390958986, 0.03519616103065865, 0.017193982377648354, 0.012304357253015041, 0.07839195137577397, 0.014420962426811457, 0.038925935713840384, 0.05367667633774025, 0.04727317173300045, 0.02367076028271445, 0.029920836245375018, 0.031228027173451016, 0.05396319453471473, 0.04464404870356832, 0.0498508210959179, 0.027550294429862072, 0.03297111239018185, 0.019170086697808335, 0.013363112762038196, 0.015856443970863308, 0.014047763077542186, 0.09770629461854696, 0.023271449209590043, 0.008766149120804454, 0.04473777474569423, 0.021701497291879993, 0.018217019803289856, 0.1492610935653959, 0.11386623712522642, 0.15846931588436874, 0.15230823148574146, 0.14258998153465136, 0.12342010518269879, 0.12893782981804439, 0.07377266817327056, 0.0849096602095025, 0.19432527758181095, 0.09658531405563865, 0.22381670294063433, 0.08880903811327048, 0.2417043245264462, 0.10001669278634445, 0.10367181165409939, 0.06781973796231405, 0.1577418992029769, 0.15573635324835777, 0.185671241953969, 0.18917337831641945, 0.1358136830053159, 0.12058244459331036, 0.18489634139197214, 0.32562605131949696, 0.1143395153007337, 0.1624853475285428, 0.24536295820559773, 0.06151417988751616, 0.14196385656084332, 0.11085770106209175, 0.17148095768477234, 0.11774553039244243, 0.08179534732231072, 0.11476378967719418, 0.15885240318519728, 0.17055337317287922, 0.12159268824117524, 0.13090049235948495, 0.10071021664355483, 0.09387842073504414, 0.08952888912920441, 0.10531287573810134, 0.12247546230043684, 0.1253830934209483, 0.16834860933678492, 0.08505726193210908, 0.13633487932384014, 0.22072930075228214, 0.1754043557282005, 0.08676213544926473, 0.13102541065641812, 0.07816005524780069, 0.11198265784020935, 0.2359351755252906, 0.0638926826151354, 0.17649819489036286, 0.10227229925138609, 0.08833423323397126, 0.14831107668578625, 0.10817852589700903, 0.11626595764287881, 0.14894261636904307, 0.21226817263024195, 0.12220794308398451, 0.27493514280234066, 0.27315577971083776, 0.1373158102588994, 0.08144896876599107, 0.1872622301535947, 0.20759675758225576, 0.09325982071459293, 0.2010513645197664, 0.09400584961154632, 0.24962084687181882, 0.0983722699540002, 0.12528230382927827, 0.11809843645564147, 0.16337041503616742, 0.27314866866384235, 0.1858487467148474, 0.19050672676946434, 0.2884246903870787, 0.1921439774866615, 0.2267083613468068, 0.11899731893624578, 0.22091308874743326, 0.10536047496965953, 0.15272376633116178, 0.37566795466201647, 0.2109954444957631, 0.28533078783324783, 0.17142101590122494, 0.13855143609855855, 0.15292815464947904, 0.10363439723317112, 0.10846817892576967, 0.24838987578238758, 0.21020031001951012, 0.22991195587175234, 0.1596881276262658, 0.18827308448297636, 0.2612584281180586, 0.3502627893217972, 0.2305645708526884, 0.08656588955117123, 0.146346242832286, 0.14683273886995657, 0.15695952118507453, 0.2733442767390183, 0.20749280601739883, 0.23198314330407552, 0.1482089435947793, 0.2233953055526529, 0.2429329071726118, 0.19672794294144424, 0.09071597935897963, 0.19192071232412541, 0.18512138431625708, 0.11959795813475337, 0.19526346081069537, 0.07577184946941477, 0.0974197628508721, 0.09730019140988588, 0.09592469914683274, 0.05836862724806581, 0.1760458427348307, 0.11730070997561727, 0.08282048481383494, 0.18916216891791138, 0.14437720206167015, 0.06230971469943013, 0.09433231995041881, 0.0843628424086741, 0.10347150133124419, 0.12070656221892152, 0.12346343642898969, 0.1564075465181044, 0.0920699213498405, 0.15830265411308833, 0.1676325649023056, 0.09387122826384646, 0.18869308408881935, 0.14370603593332426, 0.1122314902022481, 0.14346265899283545, 0.1043353917609368, 0.11144376532839877, 0.10227423307618924, 0.1954964290239981, 0.12834640512509005, 0.06530847985829626, 0.07964302745780774, 0.13567404049847806, 0.11691652344805853, 0.16792493207114084, 0.10326768976769277, 0.1533682117504733, 0.13667007562305244, 0.16071966370301588, 0.27527446459446636, 0.1324359628238848, 0.22713610982256277, 0.1038286414529596, 0.1554880772850343, 0.09609923192432948, 0.13986385853162833, 0.08888729355697121, 0.10176107061228581, 0.12441424040922097, 0.11694059787052018, 0.08369883482477494, 0.07283153331705502, 0.10382469237915107, 0.14187487347849778, 0.0690812770543354], [0.04744803359998124, 0.026861320149951746, 0.02771157881111971, 0.14867724132324966, 0.041779792934123955, 0.057917577879769463, 0.013394300776001598, 0.01793198420533112, 0.059526784744645865, 0.03889478077845914, 0.059248022202934535, 0.02948512855385031, 0.054468387604824135, 0.025941861094906926, 0.007046966996443058, 0.037545201767768176, 0.05910403707197734, 0.020266460188265358, 0.08099614842129604, 0.014771899042118872, 0.020013157976791263, 0.13003854932529585, 0.03027209346847875, 0.05485294732664313, 0.013936887910988714, 0.02355993346178106, 0.03226607379370502, 0.007384243853656309, 0.03720922515328441, 0.05485668944727097, 0.15980035731835024, 0.018604629540017674, 0.008517837534392518, 0.005070805000806493, 0.009245060833304055, 0.011276961088047495, 0.05227973558274763, 0.05746561248919793, 0.045542116942150254, 0.05329589605597513, 0.031604084851486344, 0.011599618908283966, 0.039268002180116515, 0.06373174089406218, 0.11288879386016301, 0.059072173067501614, 0.02338865595603628, 0.043598154825823646, 0.025136804740343775, 0.06435500923544168, 0.026240910137338296, 0.04946893480207239, 0.05677837186626025, 0.06868303806654044, 0.05051705766735332, 0.027749544541750635, 0.035079955123364925, 0.0659903125571353, 0.04453269771433302, 0.03923490324190684, 0.047775555668132644, 0.04774719290435314, 0.07312277411775929, 0.07240273989737034, 0.03274041387651648, 0.04011169262230396, 0.04044659375878317, 0.046421057278556485, 0.07469710428267717, 0.08402866391198975, 0.04547942369910223, 0.038788115073527606, 0.05229599667446954, 0.07584974528955561, 0.006711560351374958, 0.03328755398147872, 0.08457482353385005, 0.09591907409152814, 0.10836728755384684, 0.10917460851903472, 0.08850863030446426, 0.08903496313307967, 0.06047863366880587, 0.031991260325802226, 0.08922318196190254, 0.058508120477199554, 0.051241794135421515, 0.07698777065213237, 0.027630795824474523, 0.022014227296624864, 0.060130199151379723, 0.05373620082225118, 0.033652320836803744, 0.024976533072601472, 0.028690496193511144, 0.061551451816090515, 0.0799929683229753, 0.0745645999642355, 0.032972021627106836, 0.08904005893106971, 0.03616607594969017, 0.014590650464275053, 0.012569978267752697, 0.0880392672760146, 0.12292862869799137, 0.09726154884057385, 0.013323660191547657, 0.04811967809551528, 0.049977065928812535, 0.05360690936712282, 0.03412301040121487, 0.05925978121480771, 0.026529156902272786, 0.05967940084104027, 0.017907366954854557, 0.02273628524770694, 0.0497726063643183, 0.027839065363098468, 0.02797530501681779, 0.030609861415411745, 0.07624220315899168, 0.013237911176734736, 0.02698162949777075, 0.06472977091159139, 0.028041321385119642, 0.013961559444266771, 0.029977337856377875, 0.03663981552901013, 0.0559252497873136, 0.03096215001174382, 0.042680921365639994, 0.02173863520978817, 0.02347480785101652, 0.08130228306565966, 0.05727264391524451, 0.030913739930838346, 0.027287440141662955, 0.07145457541836159, 0.006211229832842946, 0.046374095869915824, 0.037898983141141276, 0.02138690131583384, 0.05789470446429082, 0.0546850302655782, 0.0735632044130138, 0.04991579421662858, 0.016890288763014332, 0.08090804743447474, 0.07178876070039612, 0.01743479275942913, 0.03813120157324842, 0.03013714642396995, 0.06472113994615418, 0.023592048524213687, 0.028123939808990275, 0.04119570320472121, 0.04758658027276397, 0.041967133060097694, 0.05781758895942143, 0.04226146458781191, 0.04948100594005414, 0.015722404466941953, 0.03048676159232855, 0.03249210737911718, 0.049069223393286975, 0.050903897266834974, 0.05503561234633837, 0.02301767371994044, 0.0643265854035105, 0.03431796369009784, 0.007652485709903496, 0.0255914299881884, 0.019223431424636925, 0.03023353571604405, 0.024766370421275496, 0.019316256711525575, 0.0611291994739856, 0.018744857283309102, 0.040264237472521405, 0.05610085465013981, 0.034638568093734126, 0.028428990493661592, 0.02204584702849388, 0.017615540917696695, 0.032576632486390214, 0.03157281795782702, 0.0162333226762712, 0.03237878524565271, 0.022486390978364006, 0.014722997023324882, 0.01391784567385912, 0.02702787844464183, 0.06475184365574803, 0.020575907779857516, 0.027126679928707223, 0.02486565875421677, 0.017126408771478703, 0.021397069163088287, 0.08545324139829193, 0.052643311609114916, 0.04271651731271829, 0.04973140911066106, 0.04165687970817089, 0.055743996120457134, 0.024361145915463567, 0.031095241262976612, 0.11625529107238565, 0.03619495100740876, 0.02955289723883782, 0.027182530146092176, 0.022168476966076663, 0.0144076868891716, 0.040555064366864305, 0.012254713934713175, 0.02766905162882592, 0.03246766994042056, 0.013340263095285212, 0.011403831021328057, 0.016419175114216547, 0.06166775950363704, 0.025238459464162588, 0.023105389638138667, 0.01637185917102865, 0.05128325601773603, 0.03726457664743066, 0.05124104096155081, 0.0210896181607885, 0.023918946340147938, 0.027228390631665076, 0.02128194043013666, 0.03816394767324839, 0.03402681449162109, 0.011684054957835801, 0.062595629000238, 0.0357955619027572, 0.03948928941307323, 0.03208788371245776, 0.06891965001289334, 0.04256198435489621, 0.017020989874643937, 0.04548735577347023, 0.030277158732392957, 0.03959898138418794, 0.015653545036911964, 0.05822380073368549, 0.1271409062402589, 0.07651597168296576, 0.00818731973413378, 0.053262067692620416, 0.05381193890103272, 0.028051792876794934, 0.016076838930270503, 0.021309989371470044, 0.005607200503748442, 0.06912702388529267, 0.09007778324718986, 0.0362132510968617, 0.024424191996721283, 0.06662650020526988, 0.058448836872620244, 0.009448094626090356, 0.009398898292732025, 0.043157907735024176, 0.06387332401105336, 0.05901003961584397, 0.15144801193049975, 0.027248256440673555, 0.07671654663447823, 0.025693250953086784, 0.033990146459213326, 0.030406368763319085, 0.0700622419161456, 0.0728260643248047, 0.04729245909090553, 0.024913600645959377, 0.06495654410017387, 0.06437679020954029, 0.01672917740818645, 0.029017299014542784, 0.05704730243555137, 0.10926917594458375, 0.079731053805777, 0.044872399486069164, 0.06732492987066507, 0.04805032163858414, 0.09445674291678838, 0.04651209971468363, 0.012902096562486674, 0.06742014190448181, 0.07840274008257048, 0.0338426600875599, 0.03077028744987079, 0.09249337469892842, 0.03917344493259277, 0.03843872721440025, 0.034109236140336306, 0.08893992073301758, 0.021819920312347155, 0.0655979768240026, 0.037166189069726636, 0.016789923255730952, 0.01025527564343065, 0.010055786347948015, 0.02236506382801703, 0.02372967917472124, 0.03231876543057816, 0.01594984601251781, 0.038871795404702425, 0.03883613160412226, 0.10164900376860585, 0.040266483423433135, 0.01111900492105633, 0.026139435225299427, 0.06651354448071548, 0.02213738140250955, 0.03984074680400746, 0.03657078476888793, 0.025650791624294858, 0.03839996250878487, 0.03636831331199833, 0.013556077095147754, 0.07080687303096056, 0.016142322648582712, 0.08158431614616088, 0.02640669490210712, 0.039205370005220175, 0.04158836463466287, 0.07281714158930949, 0.012298178343501474, 0.025810266013390253, 0.04218474602592843, 0.013863247353583574, 0.029054499696940184, 0.07357885143054382, 0.11682458195303168, 0.059307292236813476, 0.054599056486040354, 0.078958222775587, 0.07194882711129529, 0.04032487814713802, 0.06773493465568338, 0.03264801437035203, 0.02783952676691115, 0.014376869524962135, 0.05389937153086066, 0.04146210962374296, 0.03591179834412677, 0.042510687107486386, 0.030975110030600002, 0.009332691934624953, 0.02687043966060238, 0.01246922938818378, 0.21442231775394507, 0.09760040244353668, 0.1485303384917123, 0.16415769207690442, 0.11084274615028075, 0.0986894511484674, 0.17772442980536393, 0.07711801544896194, 0.13707198548529828, 0.11689402322684016, 0.18249119259417057, 0.10996196698397398, 0.15907916958842958, 0.15056394865470274, 0.12081086662198816, 0.13087848068348, 0.12388606875070504, 0.10694593310888324, 0.24655533422316822, 0.1213833601879222, 0.1374801785818168, 0.17768781605575765, 0.11415285031710352, 0.12844701829765523, 0.10250163730233908, 0.10035845051918711, 0.11594837611275059, 0.068217976950109, 0.11849620725427355, 0.09689473959484271, 0.2943547064704554, 0.11003303674182721, 0.07924494453306709, 0.0887790604361466, 0.08570585320038454, 0.13045810109802655, 0.3352087571152619, 0.14667835858251366, 0.12511995754071645, 0.14296985257949146, 0.04805061001596706, 0.13247892766126565, 0.1636180803179741, 0.16767456621995994, 0.21492010461432592, 0.1275306838963713, 0.1681892214609044, 0.19729025848209858, 0.11948190150516373, 0.11701748945883342, 0.1348301600664854, 0.09373141612325396, 0.07843625971249171, 0.11470129660197667, 0.09107822884938546, 0.11806080490350723, 0.09495121174092803, 0.17692705616354942, 0.18790249579719134, 0.06762760398643357, 0.15833033834184917, 0.15682120860687324, 0.21923881715961865, 0.12408194823988847, 0.12425432327602591, 0.13027720366205486, 0.1456589682825974, 0.20580961847943918, 0.18184051822338784, 0.21470200988863195, 0.2459112416420664, 0.16094105610890047, 0.24363206965582712, 0.17206791761730397, 0.062025428882666996, 0.1311508853520666, 0.12294162942894868, 0.24510734049337252, 0.15684634154396399, 0.17361736590308802, 0.10406730257506881, 0.1334605642727443, 0.21535161217408522, 0.148048836471779, 0.14805579824107035, 0.17390731748725685, 0.20315138969038213, 0.2126678568976266, 0.11995931874428477, 0.19770368986896106, 0.19488102490348475, 0.3353330104478768, 0.13133209491414682, 0.0972770330096994, 0.14159253505723818, 0.1499546513493572, 0.2602995495711054, 0.23407579958438873, 0.15193809063306876, 0.17826500508402074, 0.11811556267951216, 0.29876648687890595, 0.29440073828612057, 0.13857114075550012, 0.3016534633934498, 0.1567457148006984, 0.104393833982093, 0.11800407937594823, 0.13553137172545704, 0.22769130074552127, 0.1791581335876669, 0.13819236893739018, 0.11974867433309555, 0.2576483232634408, 0.21141100648258412, 0.16171424676265034, 0.11776714851813656, 0.09749039156096322, 0.08549674906368766, 0.08192050989185061, 0.18593728196408066, 0.15694371131914003, 0.11054610421082803, 0.18097009350146565, 0.07580859892602478, 0.05159720738551446, 0.10103350465318986, 0.1583921800234488, 0.15406769993049757, 0.16002461314201355, 0.14813119705234254, 0.1589951262410198, 0.10830082504877023, 0.19772172532975674, 0.1423415427229234, 0.1322033881608929, 0.10748200291501624, 0.18046178934829576, 0.18668992657746586, 0.08901603879140955, 0.16655807755887508, 0.11534251219459943, 0.22243064588734082, 0.17488705420068332, 0.10203141253441572, 0.2071526835539511, 0.04112279461696744, 0.15873755434794085, 0.15532630096588815, 0.132097509556583, 0.13426532037556171, 0.12306926186595644, 0.15081800573638507, 0.07146197823541504, 0.13111070250826223, 0.11169842630624771, 0.10983347280749253, 0.08622651347624403, 0.2149978240153619, 0.12568322303039686, 0.1918469691382987, 0.20621572168810026, 0.0828388798981905, 0.12425200268626213, 0.16827836739165442, 0.1491755438702447, 0.05270026783858027, 0.07281480064349515, 0.13605955695467337, 0.17493593586342676, 0.08365027885884047, 0.21385200907077107, 0.10673632007092237, 0.16478288067238672, 0.14533567348761217, 0.04945026830370937], [0.05992296098598412, 0.021976500749588013, 0.025368958711624146, 0.026503874687477946, 0.040319721280996285, 0.0752071047733937, 0.028007918802489127, 0.009808154992892273, 0.08110705497009413, 0.062404743528791835, 0.030218567233532667, 0.03128369418638093, 0.032204350855733664, 0.05033159369070615, 0.03605556973655309, 0.02730594888063414, 0.08550129524831261, 0.03085917214463864, 0.03973553316401584, 0.003675298923293927, 0.022785368774618422, 0.025825831606718044, 0.0371995899560196, 0.05914269321198974, 0.041912073336009464, 0.019249139420155967, 0.024841660666944723, 0.012143558872464513, 0.03335993331191795, 0.006542411749251187, 0.020268850327868546, 0.0558032559763108, 0.061751585719840865, 0.034234558165605576, 0.055411751448575935, 0.024209447537681887, 0.022984400058963468, 0.03318847429805568, 0.023032762642417635, 0.012573180953040719, 0.06779489679528133, 0.004176668872657631, 0.059521750014807494, 0.015418251144832798, 0.10266185299094234, 0.03742527748857226, 0.004477105519202138, 0.0070007082956310895, 0.015313032415828534, 0.07860400713980198, 0.028890321363828013, 0.018242985642115985, 0.001387483673170209, 0.06772185250052384, 0.026236733754298518, 0.03936994528131826, 0.018853892771793262, 0.061905192477362495, 0.04026462423748203, 0.031736287221844704, 0.03325249746974025, 0.018552170301388417, 0.027658067843211547, 0.04659853829070926, 0.040259189171982665, 0.09554243965872697, 0.03970430698245764, 0.06786518623786313, 0.0230796697682568, 0.026083905615710785, 0.10976349549101931, 0.030775081299777542, 0.01691304173852716, 0.008258151156561715, 0.03456979856959411, 0.05374603618734649, 0.04085155702861292, 0.006984214805665293, 0.045750257559120655, 0.08480614290705749, 0.06932998728007078, 0.07845067179628781, 0.05019233455615384, 0.06329838093370199, 0.03628334715696318, 0.046057413398687325, 0.1263047746781792, 0.09295474458485842, 0.040251029788383415, 0.012587348764230098, 0.022988825803622603, 0.05055329483002424, 0.033072967281831164, 0.03722080435337765, 0.1089966491396938, 0.0703160615105714, 0.03300680333216276, 0.07010858585791928, 0.13488050736486912, 0.08074090390333108, 0.04364822053217462, 0.04044052426304136, 0.10263708646276168, 0.0791521141571658, 0.10081070767981665, 0.07849386055022478, 0.05432352716369288, 0.029605090152472258, 0.01874998870438763, 0.05349067631842835, 0.059401628960456164, 0.026497206384582177, 0.0277312122218843, 0.029525274078228643, 0.022204568243718574, 0.0411483143190188, 0.01319414227535682, 0.021641082230157087, 0.048300324473530054, 0.034989635327032635, 0.11100361323250191, 0.028264337186036364, 0.039744673030717034, 0.03371782660750406, 0.05990704255444663, 0.048739787856382985, 0.020991162729582617, 0.03439307412398713, 0.03643538649859173, 0.012998778472787567, 0.04030074265652469, 0.03485953641523208, 0.07569187733211688, 0.009041330693954868, 0.04390784838636007, 0.01018831187060901, 0.04289629516590919, 0.015755031823313663, 0.026840231281572154, 0.023017483730135218, 0.027190967729049068, 0.02655856291364346, 0.05773894675076008, 0.015055716669719135, 0.022513601928949356, 0.04488120008526104, 0.023432965989091566, 0.05812191191528525, 0.024567213607952, 0.014597410369398338, 0.0576223133664046, 0.05737842073930161, 0.039139406223382266, 0.01878461434638926, 0.042007373579378636, 0.028188505808689764, 0.11887571189020361, 0.05667125493554132, 0.03530820073293788, 0.022987785948706523, 0.015329285025862711, 0.016049331120614494, 0.031284145412168333, 0.0667132916195052, 0.0410584016436977, 0.08760266391826527, 0.015201516881851214, 0.035776474712682624, 0.0405170630131449, 0.11306443943509034, 0.04900215020669358, 0.03549998187060867, 0.03651490741010223, 0.06938122345932893, 0.030284419057092497, 0.07318247841405016, 0.029747843742370605, 0.023381795966997743, 0.004855066487964774, 0.036633715499192476, 0.03983739484101534, 0.09509821635271822, 0.05984418307031904, 0.02459212771749922, 0.04879140740792666, 0.06612572779080697, 0.017154886886211376, 0.008122073503078094, 0.031808032122041495, 0.011426611986410404, 0.08091101941785642, 0.03672143989907844, 0.03811708804486053, 0.041308160206036906, 0.021732638656560863, 0.037783085967281034, 0.09170599587793861, 0.013405609410256147, 0.043854430717016966, 0.08991099255425589, 0.01992043955916805, 0.008502817313585962, 0.029703518442277397, 0.028015530269060816, 0.017255561126928245, 0.018978863655190383, 0.03645770351535507, 0.01737667793141944, 0.03615969432783978, 0.05396557958530528, 0.057786607050469944, 0.027003220482064143, 0.005262503442021885, 0.017715188874197856, 0.02797290130651423, 0.03931502126423376, 0.004029464517121336, 0.044057916583759446, 0.04461526185540216, 0.053924053242164, 0.03516072453930974, 0.07820449250617198, 0.01358663322337504, 0.06479826902172395, 0.04187228064984083, 0.016765046465609754, 0.06329005530902318, 0.01837356461744223, 0.01639539415815047, 0.013083096626879913, 0.03401095712823527, 0.06120868306607008, 0.031245200894773006, 0.044730527991695065, 0.008164145218740617, 0.04690373994942222, 0.017388041696644256, 0.027858339150303175, 0.0798517991123455, 0.019262038370860473, 0.06552223874522106, 0.05171863461977669, 0.07180908282420465, 0.0685241183798228, 0.042470310881201706, 0.05799453053623438, 0.02191290505496519, 0.039895833669496436, 0.031374112370290926, 0.03857397281431726, 0.028869687113910913, 0.05236997056220259, 0.03855352855420538, 0.07357351814529725, 0.05054213971431766, 0.021970054666910852, 0.06547700760087796, 0.04331982654652425, 0.04519748222082853, 0.05173732825954046, 0.007372760496634457, 0.08273063320666552, 0.09857025290174143, 0.11601409901465688, 0.019552788930013776, 0.0673391723207065, 0.01517049256446106, 0.07536479631172759, 0.028568383638880084, 0.0742360804496067, 0.1395744497754744, 0.0239473040149148, 0.07858449925801583, 0.10288294005606856, 0.06239960701870067, 0.026546983713550226, 0.03281001460605434, 0.04417276881369097, 0.05050185169758541, 0.09698704071342945, 0.06498194166592189, 0.039123447079743655, 0.03457362550709929, 0.05051051998244865, 0.05419289220922759, 0.046719293775303025, 0.03504828450136951, 0.047563320092324696, 0.025914416049740145, 0.03639654036877411, 0.04291971819475293, 0.036579721075083525, 0.021112013209078993, 0.04668353158714516, 0.07497098137225423, 0.07223695343626396, 0.09507329376148325, 0.03675130222524915, 0.10606156449232783, 0.04084148756893618, 0.07469850885016577, 0.04140587942674756, 0.03278626248772655, 0.03689155541360378, 0.0355039343370923, 0.0319637626941715, 0.03571645150493298, 0.03307930140623024, 0.028987250091241937, 0.010138791536779275, 0.047612225503793786, 0.01294832260880087, 0.031917832658759186, 0.02427009160497359, 0.052361743325101476, 0.02462868039895381, 0.055953805933573415, 0.04218539063419614, 0.024801467645115087, 0.07695720943489245, 0.05005519584353481, 0.04882637231743761, 0.035935190838894675, 0.037041331840945144, 0.01890871500862496, 0.01775269489735365, 0.06024589615740946, 0.04641236863764269, 0.018694693189380423, 0.027147373550438454, 0.018636352748477032, 0.03144743825708117, 0.022393837105482817, 0.012815994709464056, 0.05875989089586905, 0.02293891955300101, 0.07232023003910269, 0.013192490042586411, 0.02652010863779911, 0.013702669496914106, 0.03145820660782712, 0.08133545664272138, 0.03724757934521351, 0.03116852304499064, 0.03872239217162132, 0.05722845092947994, 0.06084088994456189, 0.008681535803978997, 0.07346803987664835, 0.03219459012949041, 0.04478215093591383, 0.08153692726045847, 0.10586008030389037, 0.1527826360293797, 0.14140692858823709, 0.08345764276704618, 0.08307256057326283, 0.23847227224281856, 0.11101187778902905, 0.07896496062832219, 0.1463464056806905, 0.17124351114034653, 0.11945433941270624, 0.17157901956566743, 0.10204872196274144, 0.1393323349101203, 0.1679820782904114, 0.07851340914411203, 0.1333584040403366, 0.0942951226606965, 0.12915506958961487, 0.09906890828694616, 0.20602826960384846, 0.09284999913402966, 0.12892028290246213, 0.21287832488971098, 0.16789825207420758, 0.08489030160542045, 0.09185312941138234, 0.10288420891655342, 0.07553095596709422, 0.059012048079499176, 0.06382216925599746, 0.15311169837202343, 0.16720951188887867, 0.1294159120214837, 0.15853032975324563, 0.09941853702600513, 0.11249733343720436, 0.1925445438495704, 0.12959515383200987, 0.09342868772468396, 0.1645617868219103, 0.10985255321221692, 0.14920879208615848, 0.11677202263048717, 0.22165395399289473, 0.17528922190623625, 0.07155391973044191, 0.12595192289778165, 0.11047662901026861, 0.1049854215234518, 0.17418938449450902, 0.17491051794162818, 0.17669231018849782, 0.1563000665711505, 0.12384454240756375, 0.10545210433857781, 0.08911393782390015, 0.18710056240005152, 0.09014389969940696, 0.11995294051510946, 0.14609629767281668, 0.11654133429484707, 0.12388640801821436, 0.08974196269576039, 0.13978577272168227, 0.1719619304473911, 0.15897391523633683, 0.13148194258766516, 0.11071623329605375, 0.18981269401099, 0.18969259331268923, 0.20051761530339718, 0.11958034336566925, 0.15388112994177, 0.16915787091212614, 0.1495473946311644, 0.10156470257788897, 0.14997289037065847, 0.14992832419063362, 0.1309829479349511, 0.1878268662840128, 0.14254855018641266, 0.21657254094524042, 0.18747276599918092, 0.10490658932498523, 0.19566979472126278, 0.40344663549746784, 0.26389119827321594, 0.11299964612615959, 0.10723905345158917, 0.10916358232498169, 0.15731018808271202, 0.10387902267809425, 0.11918193474411964, 0.24821964491690907, 0.18697424632097992, 0.22043340520134994, 0.20210928203804152, 0.16581985859998635, 0.1812687303338732, 0.15198391888822826, 0.18470333889126778, 0.16973989110972199, 0.2564784474670887, 0.20461755458797726, 0.1282087710819074, 0.10831326259566204, 0.14604551611202105, 0.18953750734882696, 0.21049749478697777, 0.16978269309869834, 0.16513552889227867, 0.09581069169299943, 0.1345174911298922, 0.17031127187822545, 0.0691218330924, 0.10098135245165654, 0.21540418506733008, 0.16734478463019642, 0.11203708313405514, 0.20012810906129225, 0.14691990347845213, 0.4645229567374502, 0.16782045124896935, 0.18500325136951037, 0.12343301091875349, 0.1396893664662327, 0.09951627999544144, 0.07095654428537403, 0.08004469983279705, 0.13180571235716343, 0.11836045953844275, 0.13435236284775393, 0.1289230106132371, 0.13082878477871418, 0.11384242054607187, 0.08103556452052933, 0.08466968951480729, 0.10980675209845815, 0.11847480625978538, 0.16462003226791108, 0.1274990505938019, 0.10895742981561593, 0.13943950273096561, 0.1505926371152912, 0.13176054906632217, 0.10780363529920578, 0.14029487754617417, 0.0808273967621582, 0.11656896424080644, 0.08494911023548671, 0.09711245434092623, 0.09209611280156033, 0.08495936968496867, 0.17833452778203146, 0.08180830055581671, 0.21495198218950204, 0.10015892729695354, 0.09497360339654343, 0.09135602108602013, 0.20325114790882381, 0.13730351520436151, 0.13191340943532331, 0.16248606677566255, 0.14805609679647855, 0.184334541537932, 0.14545779622026853, 0.06542109631534133, 0.09725031230066504, 0.18991735125226633, 0.14327705252383435, 0.15012051244931562, 0.2016884003366743, 0.0769049758091569, 0.12002524520669665, 0.14362345822155476], [0.012275092885829508, 0.026931263539674025, 0.06318734546325036, 0.04425188599686537, 0.037228336092084646, 0.04308810344498072, 0.010281110864265688, 0.0237171500256019, 0.03332397434860468, 0.01398649051718946, 0.03621484226148043, 0.022482597967609763, 0.06346960924565792, 0.028523800495479788, 0.028626598550805023, 0.08112876809069089, 0.05628241026507957, 0.049629740816141875, 0.004783960258854287, 0.019687613838219216, 0.01812052703462541, 0.010630228157554353, 0.04857834062672087, 0.03900170771937285, 0.03233341160895569, 0.003266035225741299, 0.03985909099823662, 0.01166339695919305, 0.03579716324540121, 0.02244888156253312, 0.01248193156373288, 0.048371211026928256, 0.012703927017615309, 0.029272112662770917, 0.03311408311128616, 0.04130909997703774, 0.010239187578138496, 0.09471915276455027, 0.04093677084892988, 0.045007095472621064, 0.045911053395164866, 0.011462729557284286, 0.014774290878059608, 0.0670322302196707, 0.12942336233598845, 0.024735620910567895, 0.024107677462909902, 0.04081660229712725, 0.02257525362074375, 0.02168592660953956, 0.01291298704953598, 0.027950317964756062, 0.02871613803186587, 0.09149030995156084, 0.025906933504821997, 0.04169248922594956, 0.027074861905670593, 0.03887253500787275, 0.02485377760604024, 0.021912514897329465, 0.04665562004915305, 0.06426460122955696, 0.09260145175669875, 0.0630034828292472, 0.07890763798994677, 0.08502383051174027, 0.05998814784522567, 0.06092935734029327, 0.06073156438235726, 0.04490042637501444, 0.057890198991767, 0.04869400370599968, 0.03724837662386043, 0.0428761053564293, 0.07323947535561663, 0.028362505936196873, 0.0304269928352109, 0.23611800000071526, 0.08134695781128747, 0.051508356617497544, 0.04322827181645802, 0.08782122683312212, 0.05294862861878105, 0.011888077715411782, 0.029327810209776674, 0.01777176173137767, 0.048255592052425654, 0.03250687908647316, 0.03566547316898193, 0.0657683637525354, 0.009201585398321705, 0.013912295257406575, 0.05380384058558515, 0.017803632521203587, 0.05503125615151865, 0.04475390013041241, 0.04048686820481505, 0.09750158738877092, 0.05597171247271555, 0.043457117929522476, 0.056859232884432585, 0.011651481036096811, 0.10652845086795942, 0.02835441440609949, 0.06587238995624439, 0.03241921575473888, 0.01673614257015288, 0.03737514732139451, 0.053012651790465624, 0.034325271512248685, 0.016780934363071407, 0.11570320783981256, 0.029340074730238745, 0.08915532846003771, 0.04112825682386756, 0.07618038861879281, 0.01869728688948921, 0.07088056871933596, 0.02286265560958002, 0.02225753807994936, 0.033578499619449885, 0.03394506798524942, 0.017594927023830156, 0.03052025068817394, 0.006416071497369558, 0.08620117697864771, 0.042841584887355566, 0.028632196464708874, 0.023334262892603874, 0.04952180964340057, 0.032568160976682387, 0.020166707058836306, 0.03632320769663368, 0.019512550107070377, 0.035288764097328694, 0.026560623963762606, 0.0753456616242017, 0.04745968743892653, 0.02890333566548569, 0.06274189400885787, 0.012754644117584186, 0.046322802015181096, 0.02858186952237572, 0.04671092404584799, 0.044102326700729985, 0.06139975852732148, 0.12571956536599568, 0.011376824479417076, 0.023441084660589695, 0.04508667066693306, 0.008219354220532944, 0.025470589686717306, 0.0359671566236232, 0.06904515184994255, 0.04173869067536933, 0.03941883372941187, 0.022114701369511228, 0.048004405173872194, 0.020266310910561254, 0.049405159295669625, 0.07533148024231195, 0.04225981914039169, 0.06090666034391948, 0.006158431750788752, 0.02575070590579084, 0.027739247772842646, 0.08674508386424609, 0.017303379186029946, 0.018249180666836243, 0.011041389844779457, 0.04487222645963941, 0.030738864493157183, 0.011239696792992098, 0.11130535096994468, 0.008242095321682947, 0.056774768845311234, 0.028886650489377122, 0.011910409151044275, 0.025790965084784796, 0.0488149831071496, 0.019999326040436114, 0.011649138393944927, 0.02645314740948379, 0.014477046738777841, 0.039731614624283144, 0.027715431193688085, 0.04124175876911197, 0.03993021503889135, 0.04509933891573122, 0.04475626821762749, 0.07561069740248577, 0.03716357331722975, 0.021992634615993926, 0.055045179690101316, 0.02702236025860267, 0.07665714089359556, 0.0095761409694595, 0.015111836604773998, 0.05831693645034518, 0.07008871835257326, 0.05749724579176732, 0.061652132842157564, 0.03516012742849333, 0.03090786381757685, 0.011590315345009523, 0.0394941748652075, 0.005950805548179362, 0.03549063165805169, 0.022213292507720844, 0.0673424835715975, 0.04067543647917254, 0.01689554232039622, 0.045279998864446364, 0.02869913394429854, 0.03897658496030739, 0.015083236353737968, 0.013107786819870983, 0.02020337000223143, 0.039823355951479504, 0.015080143930390477, 0.048607897612133195, 0.03326127432020647, 0.011694522208667226, 0.033881563892854114, 0.05333504413387605, 0.028136032999360135, 0.033071806986949275, 0.04309026457901512, 0.015896869390936832, 0.020798060144963007, 0.06299622928989784, 0.045440027955919504, 0.03377269294911197, 0.027408546768128872, 0.03011332984481539, 0.03691859503409692, 0.06090938126934426, 0.0773840079616223, 0.01850763974445207, 0.029033899373774017, 0.019140020811132023, 0.03664972892563258, 0.0211722026579082, 0.02130809795510556, 0.06593585333653859, 0.03828925612781729, 0.016161218152514527, 0.042058613151311874, 0.05014419928193092, 0.037066525846187554, 0.07523216307163239, 0.04743561301646488, 0.035019416229001114, 0.02441388844246311, 0.056747885287872384, 0.018956234512318457, 0.02165221529347556, 0.11153065852288689, 0.027881619686793004, 0.012138538561495287, 0.021454632681395327, 0.01899092291880931, 0.02855792741424271, 0.01113477407488972, 0.037953496644539494, 0.09413702400135142, 0.03210415158952985, 0.14083633492035524, 0.0484627555789692, 0.03228705070380654, 0.057420876675418446, 0.03726265300065279, 0.019371867745316455, 0.03453080655474748, 0.07247144835335867, 0.0201490888970771, 0.0637015528710825, 0.050751952920109034, 0.06404223173324551, 0.022776622458228042, 0.051209672287638695, 0.0273423149649586, 0.06303056316184145, 0.05828639558915581, 0.02960580261424184, 0.12089143587010247, 0.07177204838288681, 0.06066140386142901, 0.02168312425991254, 0.008154317487164267, 0.014746408177805799, 0.027619393043486134, 0.008892533901546682, 0.03046629697616611, 0.028796707279980183, 0.07512242360306637, 0.02111290717896606, 0.03507762435557587, 0.01293187407178006, 0.0029724369399316075, 0.03168201459837811, 0.06288934645376035, 0.01424441609664687, 0.07436758053622075, 0.03667759296617337, 0.014506936206349304, 0.007682638957963458, 0.04434046535087483, 0.012352106610446103, 0.0741278405434319, 0.05653850634449294, 0.01840937091037631, 0.010901901704658355, 0.03913354368082114, 0.010754523898607917, 0.03240335160600288, 0.0201376929014389, 0.007797556496890528, 0.04293238983622619, 0.01496712544134685, 0.03058353764936328, 0.004666240370300199, 0.042213322528238804, 0.041961294266262224, 0.05163731559046677, 0.04510880447924137, 0.045122748373874595, 0.02378026396036148, 0.049024175453398905, 0.022522687512849058, 0.03787485782855323, 0.022612065841842974, 0.015301190283415573, 0.041737628768065145, 0.01344393306810941, 0.04794640060780304, 0.03205507654430611, 0.03741485519068582, 0.07535377690302474, 0.015985496242397597, 0.014250918158463069, 0.007299389656899231, 0.05887260234781674, 0.01922436441028757, 0.025646191156868423, 0.03109335832829986, 0.03263410100979464, 0.03746593191421457, 0.004103110587623502, 0.02632459216485066, 0.03635112941265106, 0.036013914471758265, 0.13071793929806777, 0.11548895362232413, 0.11908961326948234, 0.16400149331561156, 0.07995066166456256, 0.13791788795164653, 0.0897366836933153, 0.14552095425980432, 0.16745254956185818, 0.08225027112556355, 0.11078747947301183, 0.18866960677717412, 0.14456630977136747, 0.18772944222603524, 0.15211431974811213, 0.14527864940464497, 0.19888096169701644, 0.1457768026739359, 0.10210223123431206, 0.15201562004429953, 0.1808703217123236, 0.07116634052778993, 0.19869679372225488, 0.16372558740632875, 0.13620290426271303, 0.11538387568933622, 0.06845780515245029, 0.22172563443226473, 0.09941395691462926, 0.094898014595466, 0.06272496456014258, 0.1320137240524803, 0.11398476362228394, 0.11846228050334112, 0.1270687101142747, 0.1488937075648989, 0.08856477907725743, 0.1640052388289145, 0.15895555407873221, 0.1152067237666675, 0.06539065044905458, 0.21561020186969213, 0.11879445053637028, 0.12916671325053486, 0.1649173256009817, 0.162222578057221, 0.14917626311736448, 0.15057924283402307, 0.15731294293488773, 0.08286640806389706, 0.08339102419891528, 0.20125601068139076, 0.04660465867657747, 0.15202973357268743, 0.1503796178315367, 0.16763225277619703, 0.06964956370315381, 0.13728887241865906, 0.07414071913808584, 0.1086116415847625, 0.1717717642230647, 0.21364278958312102, 0.18024380318820477, 0.1593052710273436, 0.15286263530807837, 0.20728437363037042, 0.10556381834404809, 0.15123556261616095, 0.1358659980552537, 0.127870914925422, 0.14363195347998822, 0.18101341117705616, 0.21854068604963167, 0.09017551943127598, 0.16897545355771268, 0.13320122818861688, 0.07121266411351306, 0.33930930708135876, 0.12509991361626557, 0.09925010427832603, 0.12250990473798343, 0.2161474930388587, 0.20201658058379376, 0.13297583242612226, 0.13398957731468336, 0.10530861453818423, 0.12306419999471732, 0.09360763776515212, 0.18198163993656635, 0.15630480274558067, 0.09258605579712562, 0.18741628474422864, 0.17193720463131154, 0.12689241314572947, 0.13746098961148942, 0.0860078419957842, 0.13074539282492229, 0.1983853190072945, 0.31397365086844986, 0.12272509533379759, 0.17112928655530724, 0.18467346977974686, 0.2720967765365328, 0.17851444812757628, 0.2471373544207641, 0.12169332855514117, 0.16493860445916653, 0.09508424531668425, 0.10839508713356086, 0.19926413042204721, 0.11003866179713181, 0.2365586677832263, 0.12613786863429205, 0.17128967866301537, 0.10132975304233176, 0.26239405146666933, 0.13726492013250077, 0.13510844084833348, 0.13357007982475416, 0.1862429484192814, 0.14976231381297112, 0.12926899561924593, 0.1717027300702674, 0.1345053996358599, 0.14039279014936515, 0.24043364556772368, 0.1112724013094391, 0.1867885584277766, 0.16127452892916544, 0.09759237537426607, 0.07823050753878695, 0.1298631615936756, 0.08075703946607453, 0.15444565750658512, 0.08378408596451793, 0.15650081794176782, 0.10498474977378335, 0.1023432333022356, 0.11410816200077534, 0.11354756993906838, 0.11688562296330929, 0.07854175155184098, 0.09702518116682768, 0.16987675162298338, 0.20101059813584599, 0.10602846555411816, 0.1912797817162105, 0.09635324150856052, 0.08692524169704743, 0.10583515092730522, 0.12739556043275765, 0.1299537324479648, 0.09728894129927669, 0.09710507866527353, 0.12477941438555717, 0.14941916508334024, 0.1365275289863348, 0.09178357957197086, 0.11185038422367402, 0.11748296448162623, 0.16947328113019466, 0.06400356880788292, 0.1086862940075142, 0.13622579803424223, 0.08675704643662487, 0.09882077481597662, 0.13716790319553443, 0.08334298391959497, 0.07463052642664739, 0.06250274434153523, 0.1536050204719816, 0.08026063003178154, 0.16433033852704934, 0.17613410657005651, 0.09280845243483782, 0.14698755341981137], [0.04462150777024882, 0.019880288945777074, 0.07949655888868229, 0.06484345945396594, 0.018541050808770315, 0.026448904869279692, 0.01751248841173947, 0.022811446571722627, 0.03880441687735064, 0.011520467798358627, 0.009868658264167607, 0.0742387810189809, 0.0556383855374796, 0.010299963111590062, 0.056348872770156176, 0.041187886481306384, 0.07176413666456938, 0.05430625844746828, 0.040288071015051434, 0.033322505320289304, 0.049131485766598156, 0.06293472687580756, 0.035727643940065584, 0.04289847665599414, 0.02157263840282602, 0.06003019666033132, 0.08786126718457256, 0.01905637949572078, 0.021404327791450278, 0.053910862521401474, 0.0056844822496974045, 0.028976943144308667, 0.08205694971340043, 0.08852750714868307, 0.044203248606728654, 0.0368178970446544, 0.048497913870960474, 0.03240954323804804, 0.025672480996165956, 0.03895099740475416, 0.0894667896042977, 0.033465489612093995, 0.020608781105173484, 0.029883808589407375, 0.033473048492201736, 0.05076546933768051, 0.02133675418528063, 0.015893821072365557, 0.020036504670445408, 0.022433058125898242, 0.032908958582473655, 0.08409642920430217, 0.018970970596585954, 0.03895686673266547, 0.041078822155083926, 0.006390721429072852, 0.05322586784937552, 0.02347317597429667, 0.031277319349880726, 0.009433138017941798, 0.06770587978618485, 0.012009118184713381, 0.032687030133924315, 0.031238283230257884, 0.0742393374176962, 0.07153992833835737, 0.06152970476874283, 0.05727700011006423, 0.03775322024843522, 0.03707198805308767, 0.03369404056242534, 0.07406445180198976, 0.013938038876014096, 0.014076624564560396, 0.04853416460433176, 0.020558930833690932, 0.04912977246567607, 0.05780291224696806, 0.009227923583239317, 0.05319665013147252, 0.03359941885407482, 0.02039174998312124, 0.027790270213569914, 0.04793317596028958, 0.06146956621004002, 0.05959995796105691, 0.03747489196913583, 0.027168798293652277, 0.0207294873959784, 0.05646803030478103, 0.057143159077635834, 0.05677736084908247, 0.0627905721110957, 0.05786756984889507, 0.037834444282842536, 0.015051407972350717, 0.11474804766476154, 0.13561582219387802, 0.04201449480439935, 0.011386628462267774, 0.07242357092244284, 0.043772154953330755, 0.06473414067711149, 0.058733251611036916, 0.028568984142371585, 0.053017109765538147, 0.03251455331753407, 0.044520490869347534, 0.021979913780731813, 0.08168073597231082, 0.04194865994421499, 0.03956547532496708, 0.05284717745546784, 0.06082854060722249, 0.00972078597572233, 0.03117940335401467, 0.04394957489733185, 0.01400292887618499, 0.054113948052482944, 0.06472678535750934, 0.03797242437888469, 0.016983293861682926, 0.07989247050136328, 0.030027111792670827, 0.013659785235566753, 0.029719141711081778, 0.03647560666182211, 0.03981601759525282, 0.024818222371063063, 0.013672417013107665, 0.002221985478951995, 0.016348585419889008, 0.029936568079782382, 0.0640255669131875, 0.012606014414424343, 0.04057157312386802, 0.02814665885775217, 0.02638534819042044, 0.035206786889050684, 0.06302980320262057, 0.07486268039792776, 0.0074782268909205285, 0.0166648675554565, 0.020284880717684115, 0.005139428215833115, 0.028717244043946266, 0.04077724726604564, 0.06615005327122551, 0.03766337881929108, 0.02989735554105469, 0.017450283713904873, 0.009787066972681453, 0.044179174184267006, 0.0646604857008372, 0.014016240036913326, 0.06278894362705094, 0.05432845332792827, 0.03018472869215267, 0.0106865457159334, 0.03957077129078763, 0.05391504908246653, 0.11932269004838807, 0.028752205560782125, 0.031916702897953134, 0.07360696992171661, 0.03894094830112798, 0.048825127205678394, 0.018963510104055916, 0.04427590274385043, 0.04413982254586049, 0.06327281373419932, 0.05581411253660917, 0.06892838954393353, 0.025622282975486348, 0.07727169005998544, 0.015761506743729115, 0.07456056946622473, 0.048015424582575045, 0.023946603427508047, 0.0630070451380951, 0.05661589665604489, 0.04361260083637067, 0.028178812935948372, 0.0520727620460093, 0.02633036989053445, 0.05563448735379747, 0.02528895264757531, 0.005877887630569083, 0.014151777406888348, 0.07170158252120018, 0.0775056014369641, 0.016892008849286606, 0.03557108894788793, 0.038930519217891354, 0.08283175528049469, 0.031095390540680716, 0.03577001845198018, 0.02215237363374659, 0.06341226625123195, 0.01583011681213975, 0.02990351663902402, 0.042989542840846946, 0.045721016092492, 0.07549508860600845, 0.04626444121822715, 0.08061208403004066, 0.048640803167862554, 0.025258175995466963, 0.028160828365279094, 0.022550566820427775, 0.04209171548219664, 0.015551352574090873, 0.003444039133942819, 0.01565647461185498, 0.04135202070964234, 0.04570403575365033, 0.03599846422938364, 0.022607633311833655, 0.01947358692996204, 0.053852885096733055, 0.027882316881524663, 0.012638025152097856, 0.07369111504937921, 0.00690400433294209, 0.029229476914874146, 0.07050996646285057, 0.03985255331333194, 0.07804410718381405, 0.00736126017623714, 0.032210264288421185, 0.054640813531087976, 0.03905075562319585, 0.025920716247388294, 0.03991019147049103, 0.028304620113755976, 0.020860493848366395, 0.04330959763111813, 0.023716683532776575, 0.034330899960228374, 0.018134691453139697, 0.0675337625933545, 0.01805938933310764, 0.05465249451143401, 0.01020448305644095, 0.05626529082655907, 0.0394137006119958, 0.01788218312763742, 0.0245359619813306, 0.03895776239889009, 0.014960548740678599, 0.07965292728372983, 0.03729103612048285, 0.05620889099580901, 0.06388717291078397, 0.02963482016431434, 0.10731500866157667, 0.018015057247664248, 0.012305485317483544, 0.02727834946875061, 0.01663140220833676, 0.01619360632529216, 0.045733158476650715, 0.05860788548099143, 0.02643067093699106, 0.06509068368801049, 0.03873507059844477, 0.08320864077125277, 0.016749363824991242, 0.013719771972059138, 0.03598809621429869, 0.05431389196642807, 0.08536872307636909, 0.07953659245478255, 0.05080401012673974, 0.03275663764881236, 0.07806662776108299, 0.07204316383493797, 0.10900202313704149, 0.07361530911709581, 0.013063894934020936, 0.05570710077881813, 0.037399075858827145, 0.049264760222285986, 0.05046682571992278, 0.016110658811937486, 0.07393690757453442, 0.03817307736192431, 0.06893178221902677, 0.021274303518501774, 0.042898880384330235, 0.018913960084319115, 0.012013125782167273, 0.05357671455879297, 0.029715182459247962, 0.07343643371547971, 0.014593239075371196, 0.04631512778412018, 0.03414977860770055, 0.06087179042931114, 0.030675964296928475, 0.050039009390664954, 0.042898042393582206, 0.03360301508967366, 0.008862188119175178, 0.08486288879066706, 0.03544900014198252, 0.03543142608499952, 0.015212203808394926, 0.02103933532323156, 0.012044572487606533, 0.07302735173808676, 0.008882902096956968, 0.03654388424807361, 0.05412043484726122, 0.013941937907865005, 0.02157058583439461, 0.03389498531552298, 0.030703299080154726, 0.06750555589262928, 0.059490286345992766, 0.023068553668313792, 0.01712431209827108, 0.06980260727660996, 0.019646114636478678, 0.018721495322617035, 0.01544506345609469, 0.043847489303776195, 0.05142444558441639, 0.02973511442542076, 0.12382019657109465, 0.06028542760759592, 0.013323969773149915, 0.029163543667112077, 0.029846940389169112, 0.014902635776836957, 0.018692374295954193, 0.020691908430308104, 0.011742898362821766, 0.03588122694886156, 0.026693952702251927, 0.0124063028987231, 0.043591437329139025, 0.03167173479284559, 0.010069154335984161, 0.03841888685045498, 0.03589774249121547, 0.04334994671600206, 0.021912591232519065, 0.03815661610237189, 0.039928284606763294, 0.10780365565525633, 0.03980817712311234, 0.10742231218942574, 0.12473942153155804, 0.14119716627257212, 0.1856538307453905, 0.16711925316069806, 0.15169009965445313, 0.05952635726758412, 0.09721260610967875, 0.15475524589419365, 0.17036013997026853, 0.0957824374948229, 0.12747858597763947, 0.12152818670230252, 0.13774849846959114, 0.27598850056529045, 0.1000900152804596, 0.15716092394930975, 0.15079994313418865, 0.10946179168032748, 0.16942209244838782, 0.20970915923161165, 0.1250194665044546, 0.13085587189665862, 0.15585684749696935, 0.08914090280554124, 0.14068757290286676, 0.10793546786797897, 0.11504820441561085, 0.10603334422090224, 0.2534850766616208, 0.10352715477347374, 0.08701391265328441, 0.13455502768712385, 0.19302460737526417, 0.11375423813504831, 0.10595048152442489, 0.17988831869193486, 0.11979637534490653, 0.08548286623720612, 0.15370655645217213, 0.23159610692943844, 0.0894407406449318, 0.09055587902132954, 0.13246257496731623, 0.0891824427193829, 0.07568104791321925, 0.14615159827683652, 0.1203671997146947, 0.11651810125580855, 0.15551255882850715, 0.12081600991742951, 0.1275668362421649, 0.1455195564776659, 0.1499106687094484, 0.2283049135335854, 0.12526428193918296, 0.23015747698290007, 0.1579575647733041, 0.2317817812519414, 0.06001032915498529, 0.20014746088002408, 0.11404515323894364, 0.12291769071349076, 0.11417841751660619, 0.10475020057388715, 0.11970991641283035, 0.18403289201004164, 0.16571290791034698, 0.12173256144991942, 0.10278855583497457, 0.05176348239183426, 0.14644544465201242, 0.17809524919305528, 0.09945805490549121, 0.16401158991668904, 0.13953605826411927, 0.10965011228940316, 0.216014188049095, 0.12724917328783444, 0.2244201512741191, 0.06521254857735974, 0.07410118090254919, 0.0918923080233591, 0.14023079669901303, 0.15177518794579165, 0.115166608776365, 0.1545038079576833, 0.06365410291722842, 0.191916003291096, 0.19655146955379418, 0.2105039544403553, 0.22103553717689856, 0.1835185760366065, 0.2232679852417537, 0.12089941544192177, 0.1539849050875221, 0.18166886243437017, 0.22070640698075294, 0.11415825145585196, 0.1443934461900166, 0.15594284502523287, 0.2666406493101801, 0.17303629565451825, 0.09583923766123396, 0.15190527667956694, 0.0944128959838833, 0.09449436768357243, 0.12140689178236894, 0.08706155259694372, 0.1738348635179656, 0.18139033737991536, 0.3201511965266296, 0.17080205625721387, 0.16088555194437504, 0.14826822041400842, 0.1000303245548691, 0.13288987560995988, 0.08998839304383312, 0.18682378796594484, 0.16075929014810494, 0.10142633571688618, 0.09236971169177975, 0.18296440291617597, 0.0813254550365465, 0.10707250703126192, 0.12677780858107976, 0.17216830008796283, 0.15466152663741792, 0.21858693499650272, 0.12130763567984104, 0.07110627660793917, 0.10780655299978596, 0.12993035013122217, 0.14460665546357632, 0.13442217053047248, 0.1496426880891834, 0.07822637526052338, 0.21420560723968915, 0.09767741616815329, 0.10055016380335603, 0.1720960768205779, 0.05159329563113196, 0.14121487603655883, 0.14375463261135987, 0.07795824536255427, 0.15476444682904653, 0.19911239642117703, 0.1959902396691697, 0.11376407010746853, 0.09987767453172378, 0.18882326781749725, 0.16981653842542851, 0.10289824780608926, 0.18969636596739292, 0.13239758488323006, 0.08124415297061205, 0.1489763395594699, 0.13183996480490479, 0.05518863895641906, 0.06101783152137484, 0.20181091661964143, 0.1648265104740858, 0.11407403168933732, 0.15998106476451668, 0.10872408162270274, 0.15016364013510092, 0.11512274827275958, 0.12907891081912176, 0.155309921130538, 0.11168779366250549, 0.12536207240607056, 0.09015382666672979, 0.1621123703994921, 0.18687944140817436, 0.16887954941817693, 0.14236540001417908], [0.018051479311127747, 0.011961207675215389, 0.08567797219646828, 0.012734469575142222, 0.02099507109129003, 0.06495125152702842, 0.012826204965157168, 0.02009615977294743, 0.05519428776044931, 0.05569072772881814, 0.025636450786675726, 0.029828636907041073, 0.07255428390843527, 0.0850531364391957, 0.0468019902307008, 0.03369283277009215, 0.029464606262211288, 0.06482637394219637, 0.07713330962828227, 0.03269282143030848, 0.04015783978892224, 0.009171958863069969, 0.0411016786071871, 0.03594126711998667, 0.013242364910963391, 0.0032888329421569195, 0.03865460991593344, 0.05975611601024866, 0.06621607472854, 0.028119079801919203, 0.015153050821806704, 0.02788622524323208, 0.02971062609659774, 0.025311451172456145, 0.04221436407949243, 0.01527295813762716, 0.032624279215399704, 0.05993502533861569, 0.03274982176455004, 0.049955664934324365, 0.027850603851090585, 0.034302805217781236, 0.028671680417444025, 0.045853802002966404, 0.028554073335336785, 0.03983799195183175, 0.0445418477590595, 0.02475526280302022, 0.003934464101413531, 0.02407159636329327, 0.053950933406927755, 0.06932659460497753, 0.012024224918734814, 0.013896040102866079, 0.08413290724690471, 0.01788637986672776, 0.017442080225529413, 0.03039106779864856, 0.03724878713754671, 0.009723182900675705, 0.046052066542740376, 0.00625556064603318, 0.03736528142222336, 0.053780078289232085, 0.013314696743951311, 0.04795634453850133, 0.03275161988234945, 0.041634006292692254, 0.01305803663230368, 0.010601011287820126, 0.13161403978509562, 0.04016562258558614, 0.01651688415690192, 0.003961637308488467, 0.023623452821214284, 0.013111135390188013, 0.028748711105436087, 0.05510693316214851, 0.05451873829588294, 0.055202375897871594, 0.03587069608537214, 0.018058290106377432, 0.03189977684191295, 0.02366704530348735, 0.047141244169324636, 0.027691696038735763, 0.02807827270589769, 0.006021770133104707, 0.023428789606051784, 0.07303258324308054, 0.03678356995806098, 0.03007686198023813, 0.06840050965547562, 0.05933206555034433, 0.03889114722343428, 0.044857943297496865, 0.0396779187555824, 0.04837320591988308, 0.05130543393482055, 0.009216239210218191, 0.042811763273285966, 0.06745444863502469, 0.05981053451874426, 0.031086057291499207, 0.05520315960581813, 0.08794839108096701, 0.03757452126592398, 0.019799721394000307, 0.07055434265307017, 0.04247373409037079, 0.0652210506211434, 0.03180976238633905, 0.048655194895608087, 0.05077843614188688, 0.04423645271786621, 0.028164899575390985, 0.04023668555808919, 0.03502582499225225, 0.0424385384789535, 0.06181190748299871, 0.005879809156925018, 0.05567007651552558, 0.037842763122171164, 0.05870434601924249, 0.03283294230433447, 0.013442134950309992, 0.09451392984816007, 0.04548635154164263, 0.021362575835415294, 0.0042829766503668255, 0.051951470518750806, 0.00811244169848838, 0.012982044102890151, 0.03540163839768086, 0.016433302213304808, 0.011269306364868368, 0.02657495123068137, 0.07174786539482218, 0.06039832904934883, 0.011038021766580641, 0.019126996331449066, 0.010704318244409348, 0.03435574791261128, 0.02317266638523766, 0.029438964423856566, 0.05437178457421916, 0.04758531819762928, 0.06475572487605469, 0.010411538865550287, 0.042687055322208574, 0.001638419387745671, 0.030406463758221695, 0.030868060953382934, 0.018337553067665015, 0.023886661643960645, 0.04576397753719773, 0.02832934762617307, 0.07310370049838509, 0.010942565460157181, 0.029215224286807433, 0.05293522076681256, 0.04046170812632356, 0.01823149125890008, 0.0596047348475882, 0.017916345669488822, 0.1332477621201958, 0.06387590244412422, 0.021777198051235507, 0.04602426017767616, 0.04117228356855256, 0.0053105941873842055, 0.02913079078176192, 0.05372777680999466, 0.0199944897820907, 0.026721986376547387, 0.007191042033290225, 0.018043347068929246, 0.041131540933357816, 0.023330096687589372, 0.0059582545904309624, 0.02718192624992558, 0.07684052855308567, 0.03002600578059043, 0.03524028277024627, 0.05354360883523311, 0.05979019882423537, 0.00643208237930334, 0.029581385531595776, 0.1194187163242272, 0.023338641139811704, 0.057170619389840534, 0.03807172458618879, 0.03521088184788823, 0.03545652848801442, 0.0265231501710202, 0.04094674192102892, 0.027958996427644576, 0.013460425709906434, 0.01989602417285953, 0.02250940858253411, 0.041804881766438484, 0.0178950956490423, 0.007548557045603437, 0.04961111842255507, 0.08912512686635767, 0.03234652090551598, 0.00839531107340008, 0.054078352105404646, 0.019331082701683044, 0.02782727242447436, 0.013009170236598169, 0.09933844275240387, 0.012869498892022031, 0.03410478834328907, 0.04581987525203398, 0.04190757804151092, 0.06660516706428357, 0.0483788174044873, 0.025056610382827263, 0.08579525697444167, 0.035363562405109406, 0.03440411388874054, 0.050939628920916996, 0.015445438346692493, 0.011133461957797408, 0.05364081236932959, 0.019031962413074713, 0.03406730267618384, 0.024081107727917175, 0.03309214946680835, 0.06939868895070893, 0.017314054238210832, 0.03170880316091435, 0.05756182875484228, 0.04306682458679591, 0.023976275763873543, 0.029818445311060975, 0.042112923094204495, 0.018535291742799536, 0.062402158310370784, 0.04835928238130041, 0.06681235094687768, 0.051626835617103746, 0.014936866172190224, 0.07918342176292624, 0.02942078307803188, 0.05133816985679524, 0.11800053742315088, 0.032145311523761065, 0.04103993870584028, 0.033142486587166786, 0.05079598305746913, 0.07738733956856386, 0.04348750951300774, 0.03475614803444062, 0.07013650078858648, 0.03102798487192818, 0.0810777558279889, 0.0252442524568843, 0.029851720668375492, 0.03704859895099487, 0.04141437468518104, 0.0162903280995254, 0.0040378198277072185, 0.07778358366340399, 0.05224674181746585, 0.040286839473992586, 0.023129959391163926, 0.048282516321965625, 0.009082661110109516, 0.0807094130931156, 0.01984150897312377, 0.029126444764967476, 0.02435039113541799, 0.060267059664641104, 0.008454006897019488, 0.00802088187940951, 0.06970080666776214, 0.009843263242925917, 0.008731112965116543, 0.07454985539828028, 0.03830609397430505, 0.007153418962843716, 0.04783521246697221, 0.03700156629617725, 0.013029329512002212, 0.04714585481477635, 0.05427746820662703, 0.04337881498837045, 0.05000180531559246, 0.035986823961138725, 0.04981000042919602, 0.018016975805429474, 0.018309353152289987, 0.017896839484040226, 0.04127593657800129, 0.025883223794932877, 0.06327708850481681, 0.028214527626654932, 0.026825089772631015, 0.04866884702018329, 0.04040934218625937, 0.018210259898166572, 0.02220236979025815, 0.0058600391909879234, 0.016682992922142148, 0.11398484504648618, 0.007600054460843759, 0.04881619768483298, 0.046655854143734486, 0.049386825279465744, 0.015875336082120026, 0.018385036948270032, 0.026463512031893646, 0.037218677146094184, 0.025325009998466288, 0.025753579501594816, 0.02995780961854117, 0.060675748091723235, 0.027714732302618877, 0.023489143599623015, 0.05347668492634382, 0.02849288983270526, 0.0603158599031823, 0.024908565916121006, 0.0134765578799748, 0.03969668024884803, 0.03165136177891067, 0.06128235161304474, 0.048208209952073436, 0.025977575785613487, 0.008547715975769928, 0.006853692657646856, 0.0367778872272798, 0.019533121592498252, 0.03439018017213259, 0.022498645320800797, 0.04024700607572283, 0.022491027068878924, 0.06223428874675717, 0.030663526750036647, 0.08567037938960961, 0.012386513424904218, 0.09984665191067116, 0.023413654882460833, 0.10287039394357375, 0.02833468939310738, 0.023127099366060326, 0.0007098160661241439, 0.031501286796161106, 0.02921575015144689, 0.024219091216634427, 0.11813116898494107, 0.17036535111921175, 0.24777862429618835, 0.08210097985076052, 0.13177209773233958, 0.2580024099775723, 0.12635224498808384, 0.1140467817229884, 0.13249446611319268, 0.11422276656542506, 0.11738742675100054, 0.21148455967860563, 0.25928060710430145, 0.19300547268773827, 0.13487376272678375, 0.15444273980600493, 0.1753140427172184, 0.1479239860283477, 0.09784613390054021, 0.11751725764146873, 0.09640550227569682, 0.05566377631787743, 0.1121712905753936, 0.09537988980965954, 0.16165129228362016, 0.10773457400500774, 0.13028355474982942, 0.12492042753313269, 0.21493561592485222, 0.10339043675256626, 0.12245471269956656, 0.15797747299075127, 0.09753119187163455, 0.08881843582327877, 0.08395384864083358, 0.1688458669398512, 0.10213149644966636, 0.13085849104183062, 0.20535664207168988, 0.1363076972109931, 0.1571068311376231, 0.16831195487507752, 0.11804137166057314, 0.25204698954309734, 0.149716281997306, 0.13242273139102118, 0.15408181345888547, 0.10413088130631618, 0.16532390378415585, 0.09430262725800276, 0.15026220413190977, 0.144858324101993, 0.16763826459646225, 0.06351182090916804, 0.17369480031941617, 0.09415856070284333, 0.13205210199313505, 0.11431759861963135, 0.11129738496882574, 0.088551737634199, 0.12576285590018543, 0.13911272026598454, 0.08612560853362083, 0.2110700833478144, 0.15424876021487371, 0.18127494571464403, 0.09641787196908679, 0.12145601771771908, 0.17966289578803948, 0.15483726720724786, 0.17505491019359656, 0.17086349081780228, 0.0961062547617725, 0.12425547678555761, 0.05823271668383053, 0.11772963910230569, 0.1700801628508738, 0.11450118305427687, 0.19028799422085285, 0.1436448185039418, 0.05937750704054322, 0.1493935707424368, 0.1709703193711383, 0.07069346268794366, 0.1144390699586698, 0.14177436887153558, 0.1194183634860175, 0.12861966474780015, 0.1422709207981825, 0.14023323942508015, 0.11053225531109742, 0.12574277126363345, 0.14855886410389627, 0.15006223986191408, 0.16983213116015705, 0.08087477207716022, 0.186870986861842, 0.15726153712187493, 0.19306909213108675, 0.11670547191585813, 0.15603167882987432, 0.1784706147653716, 0.13292051825140203, 0.12026470021477767, 0.14834812469780445, 0.16963769016521318, 0.08896563042487417, 0.16748509210135254, 0.20520739150898798, 0.08402982420687165, 0.1500181079443012, 0.13566747227949755, 0.16989885829389095, 0.13427358493208885, 0.1016218148704086, 0.2050021889486483, 0.1200211061430829, 0.15683097951114178, 0.18735421236072267, 0.13565973698028497, 0.17213706033570425, 0.1512830736381667, 0.1531699573887246, 0.15610786474176816, 0.12073253653943539, 0.13799760224563734, 0.1721025907567569, 0.13876468608421938, 0.15967739320227078, 0.07448986611728158, 0.1334384847432375, 0.11318507617605583, 0.12166185810097627, 0.21658775370035852, 0.15075923103306973, 0.09986858894782406, 0.11626808824283735, 0.1045562345534563, 0.1705362605197089, 0.11438089236617088, 0.1924647752727781, 0.12269282420831067, 0.14474825215126785, 0.08786668867937156, 0.13946147369486944, 0.09263672200696808, 0.1687809582799673, 0.16350031378013746, 0.11524470815701143, 0.07716919734541859, 0.17910459717469557, 0.1589977318154914, 0.15478442289999553, 0.11699600704014301, 0.08195760540132012, 0.08881728231374707, 0.16991308038788183, 0.22857092640229634, 0.14921598455735616, 0.11998363743935313, 0.13683626241981983, 0.20663186721503735, 0.10254049700285707, 0.21361149554806097, 0.15758886241487094, 0.258817764797381, 0.12128791745219912, 0.18397565079586847, 0.11741796082683972, 0.11409368206347738, 0.12069592278982912, 0.07805531658232212, 0.131719972672207, 0.1247445105441979, 0.09043955776308264, 0.09686795781765666], [0.05650215043819376, 0.012102426927802818, 0.042399451469204257, 0.02063408537235643, 0.04687101420547281, 0.06829217475439821, 0.060892180406621525, 0.029712777052606856, 0.04478315177506634, 0.03200377929689629, 0.01799018893923078, 0.015578629681840539, 0.03900383153398122, 0.03856589146224516, 0.014737821317144802, 0.04909915018028446, 0.0309631135314703, 0.027022897997604947, 0.01675741633932505, 0.027377278178132007, 0.02962571761703917, 0.030092899155403887, 0.045657165947237184, 0.027697558581296886, 0.047082740880016766, 0.03676419099792838, 0.04297466596056308, 0.06627611150699002, 0.028200860235041807, 0.04187744090865765, 0.032722537871450186, 0.013600147096440196, 0.0195689669011959, 0.08037890547088214, 0.024765598587691784, 0.011934792306939406, 0.05131822771259716, 0.020016740641689727, 0.019204708947134868, 0.05367930566093751, 0.04058087583897369, 0.043832222265856605, 0.05902078082518918, 0.018554236440520202, 0.01642144481385393, 0.016958830977923105, 0.03161610170666661, 0.01728132849426142, 0.023328268035714115, 0.025804747827351093, 0.047878597996064594, 0.026890339396361793, 0.05321949640555041, 0.03268659247883728, 0.04360976116731763, 0.024246402251135026, 0.07087063496666295, 0.02168116668638374, 0.04381397985188024, 0.02621977886052004, 0.0350225849875382, 0.0422586079553834, 0.09790405364973204, 0.03158667025023273, 0.06277547470693078, 0.024934441849057163, 0.04378898601446833, 0.006453851054954741, 0.1031830832362175, 0.0700479316126023, 0.027774716494604945, 0.030937587044068744, 0.07068895721541983, 0.03747316849018846, 0.044960832955049615, 0.02590965443024678, 0.033748126588761806, 0.0716424821210759, 0.05100732296705246, 0.03622526116669178, 0.029548527473317723, 0.04885108456281679, 0.03085109418524163, 0.025164010601916482, 0.04312816075980663, 0.03867266573277967, 0.008313381362573376, 0.0481450247711369, 0.019193438480475118, 0.03180895492966686, 0.04063454795894878, 0.04619255721835153, 0.03637371784342187, 0.0524311608501843, 0.05819948882396732, 0.03693324799782463, 0.01958728225768677, 0.036484522611967156, 0.046544937416911125, 0.036868400406092405, 0.035548222317759476, 0.041387257033160756, 0.05825534582670246, 0.0779429715392845, 0.028979684425784007, 0.03333546873182058, 0.006254163287979151, 0.021059996714549403, 0.04601682343387178, 0.032592106477490494, 0.031541432320539436, 0.10314340250832693, 0.07433155032673053, 0.055546148879719634, 0.02942241495475173, 0.024222885923726217, 0.03434804654014962, 0.04126809610586081, 0.030303472320416143, 0.039779973815062215, 0.019151269225403666, 0.026808055150987845, 0.03764528229034372, 0.0873057980622564, 0.03270322676481945, 0.04109393652262432, 0.10813157127371856, 0.019073914536940198, 0.07349017368895666, 0.010929440896558975, 0.0355114151856729, 0.011074799212760158, 0.04209798853844404, 0.024505270146099583, 0.017302293530000106, 0.045154792190130265, 0.03231664500864489, 0.03717581069629107, 0.02025750861503184, 0.015956772158720663, 0.020615988843409077, 0.04457791868065085, 0.04479709566969957, 0.011108453701516348, 0.08582820663494722, 0.01549879664422146, 0.019216518849134445, 0.03261692050312247, 0.0073920105351135135, 0.03476240073463746, 0.038079585414379835, 0.04312289532806192, 0.04048009642532893, 0.04103157576173544, 0.02988089428150228, 0.0411507265110101, 0.043025908925171406, 0.015717854889641916, 0.052649951074272394, 0.030080851766147783, 0.03720482824636357, 0.042104896024933884, 0.038342819682189395, 0.04827363429857152, 0.023425932973623276, 0.055659630468913486, 0.06014142890593835, 0.01867161112438355, 0.01935545907222799, 0.0420977069464113, 0.03368538584826248, 0.0520552897692791, 0.04255221684330276, 0.010016588228089469, 0.057776578302894316, 0.07175663885261331, 0.04919377528131008, 0.020326403668150306, 0.01907520036080054, 0.038615346487079344, 0.0961181494806494, 0.047682023008487055, 0.034111984207161834, 0.047242206787424426, 0.06805979008121149, 0.022066092817112803, 0.03881551092490554, 0.02314265308502529, 0.019841553077899983, 0.05508111151201384, 0.016646396135911345, 0.0406146567048771, 0.03490648425317236, 0.0381298071837851, 0.04803537351212331, 0.04187273866097842, 0.028269919832902293, 0.008345789891401572, 0.0379793963262013, 0.010238453063980808, 0.033436421171895096, 0.05694521005664553, 0.0349648518354765, 0.03610789157184107, 0.025024731111313616, 0.052589266294879575, 0.08072932131056275, 0.09431442019662686, 0.011158348925943886, 0.02745724013740463, 0.007511857630951064, 0.03994833192388926, 0.05765708150076015, 0.02006913541949221, 0.04372687291886125, 0.036971948242613246, 0.03120978475947465, 0.020731387294030616, 0.05658656358718872, 0.038223556974636655, 0.03684700958962951, 0.0548684722078698, 0.024304327089339495, 0.03727154859474727, 0.007729127936597381, 0.020501752384006977, 0.03685772705024906, 0.020222156940560256, 0.018257696281320283, 0.020443847901853066, 0.05281881129901324, 0.04787404163341437, 0.0560265075681465, 0.06779189088514873, 0.055071500063474686, 0.02643693211887564, 0.05253464083320328, 0.04576558227251683, 0.0735320800117084, 0.025489285022818615, 0.04666347069931882, 0.03560925315001181, 0.021046950182478343, 0.019662396084251146, 0.11167613643088511, 0.04047510240759168, 0.020463423637141074, 0.037094182933547666, 0.05234207259491086, 0.039388028239565234, 0.08223725003855568, 0.036039145796426704, 0.01438585841762168, 0.041710090424333296, 0.03800579812377691, 0.036020248596157343, 0.023161881071116244, 0.019816952790798883, 0.05925946230334895, 0.01631995802745223, 0.01995896847386445, 0.025755798311105797, 0.055716702049332004, 0.03834732176203813, 0.03178289579227567, 0.02663234681157129, 0.05101027459438358, 0.04441617628825562, 0.03842968912795186, 0.03953121269920042, 0.022961660654151013, 0.01638555370404252, 0.051319567819259, 0.06585639010050467, 0.044462706827159436, 0.0687524386282478, 0.0596175863008414, 0.04440554025183831, 0.04923012100958398, 0.13330109497266157, 0.0367851645153548, 0.044529193080961704, 0.04622386143143688, 0.05612762285662549, 0.00966374238487333, 0.039960891607084444, 0.06390946278614656, 0.09334231021681003, 0.026560087921097875, 0.02746990160085261, 0.025984898874802247, 0.021750750452546135, 0.009754739019886723, 0.057367652388555665, 0.012524115237673479, 0.019660765903868845, 0.047046391759067774, 0.0317518528151725, 0.018023895166282142, 0.025352198896663528, 0.0322281301154622, 0.03371182496526411, 0.05517544484298144, 0.025365033386541263, 0.09155348834714719, 0.017274819647095034, 0.03678226377815008, 0.033807016643030305, 0.0130350088501083, 0.01101712288800627, 0.035304292371230464, 0.019961451912032704, 0.026408540517357842, 0.043337763619742224, 0.008459056045727005, 0.03870136097871831, 0.03824873062382851, 0.063347574722554, 0.049501857321177206, 0.09733535987990242, 0.016260053563330854, 0.0400910380163363, 0.03352607261123402, 0.014579563202070338, 0.005526415820765708, 0.022889367836926664, 0.05527049742106881, 0.04691322926165802, 0.047747084338750155, 0.03168753787342991, 0.024969114988510097, 0.05779299885034561, 0.02111600469132619, 0.02552719138163541, 0.02390717715024948, 0.033697294137839756, 0.04646117226885898, 0.021506803542641655, 0.013596931688620575, 0.031566107246492586, 0.05437545884134514, 0.06441484923873629, 0.05005186762926834, 0.03873505024239421, 0.04862815188243985, 0.028843882427151715, 0.049898349081299136, 0.016604128493262187, 0.035679830969976525, 0.026745568861120513, 0.04307785078084894, 0.004213332240137139, 0.12238558355186667, 0.1291199079049485, 0.14515625525798115, 0.1455763362880264, 0.16784926184586116, 0.1251028584582465, 0.10568267732326474, 0.10720020053642136, 0.2196689405079399, 0.22088225611618587, 0.2556402938706534, 0.06618635489472321, 0.15150414034724236, 0.1724462416023016, 0.133645573630929, 0.1396796769861664, 0.14123700984886714, 0.1116164999880961, 0.2024803999811411, 0.20364407396742276, 0.16694210123802933, 0.07424363932971444, 0.164173067680427, 0.08444104356957333, 0.12429074703582696, 0.1778690256178379, 0.1439742065433945, 0.13930701198322432, 0.10867929152612175, 0.20165507069655828, 0.1167250680071967, 0.19741859659552574, 0.08779908623546362, 0.11984596268406936, 0.09619282225945167, 0.12734389677643776, 0.1309737198586975, 0.13473334669002465, 0.18603936077228614, 0.15461111148553236, 0.10628932834203754, 0.1048061525715249, 0.18393932203097002, 0.09335209469177894, 0.13086629419454507, 0.13305554672011308, 0.1503603881491082, 0.1570024588810546, 0.07887341268360615, 0.13387672337038176, 0.10230916405894927, 0.19051366139735493, 0.1240559739193746, 0.12924076856247016, 0.1863598328615938, 0.14973821224910872, 0.17519885461245263, 0.10452907279665981, 0.1279586087912321, 0.16035459829228266, 0.1501097644546202, 0.1451133039913007, 0.2124225122055837, 0.105488460244877, 0.14188226951020105, 0.09180721973202058, 0.14569121226668358, 0.12019840734345572, 0.2614672811967986, 0.12003113489065852, 0.06578813626297883, 0.09505029820970126, 0.1322793840829815, 0.18544026863362106, 0.15077615369643482, 0.10569854147200074, 0.17180046625435352, 0.14769046141632966, 0.08387929799833468, 0.11480765018079962, 0.09197702312043735, 0.10744978607233081, 0.11639977831925664, 0.18019313019301209, 0.19525628191019806, 0.1473797330898898, 0.12926307879388332, 0.1355131191334554, 0.12209701617913586, 0.1599289939871856, 0.12845498429877417, 0.12554602324962616, 0.08226082234510354, 0.12188240912343774, 0.14228378582213605, 0.12428568516458784, 0.14688631599502905, 0.20349722541868687, 0.14215774115707192, 0.19462095600153717, 0.11057655007711478, 0.1298149584659508, 0.13598153899822915, 0.23595889710954257, 0.10199525340327195, 0.13114722126296588, 0.13943696500999586, 0.16352069697209767, 0.11628471235079424, 0.277851649160896, 0.17575776390731335, 0.2347045572740691, 0.11003136754568134, 0.16815966447549208, 0.12211255463106291, 0.10769539539303098, 0.08263730750020061, 0.1920095325580665, 0.15014525183609553, 0.10436783930552856, 0.1169039841209139, 0.10562799418611185, 0.12555772119334765, 0.1084247866113271, 0.08704172580369882, 0.1449965416852917, 0.20259011909365654, 0.14297327239598545, 0.19991468265652657, 0.10338819758700472, 0.09324665034988097, 0.1394296639731952, 0.1629739198833704, 0.12638280620532377, 0.09075929024921996, 0.16627750332866395, 0.0771037255014692, 0.09326799706156765, 0.13867273101849215, 0.12099852226674557, 0.11756243450301034, 0.1777362363146884, 0.2239318774746997, 0.13784995302557945, 0.21741091167288168, 0.08932981374008314, 0.11609441041946411, 0.09168874751776457, 0.18006939254701138, 0.16848696262708732, 0.13044375686773232, 0.18051354799951824, 0.11979207343288831, 0.1531317422964743, 0.1304790542594024, 0.20881962696356432, 0.07388905049966914, 0.11166345461138658, 0.18380067018525942, 0.14005392976105213, 0.19830730105085032, 0.14900968277028628, 0.1532406471669674, 0.17151966132223606, 0.1505056353552001, 0.143504850300295, 0.23729846094335827, 0.159478880997215, 0.21515057581876004, 0.09219055809080601, 0.07191157553877149, 0.1320667312081371, 0.12615316281361239, 0.08042005183441298, 0.19765077770820685, 0.23443555885127612], [0.07169195410928556, 0.04256480706057378, 0.038943614943751266, 0.03835485350074513, 0.08295874310923473, 0.014769218828795212, 0.07178918139210769, 0.020491340264145817, 0.019563884673906223, 0.02736920870042273, 0.029416080830352645, 0.0686972669458815, 0.016691951280725852, 0.0360065659375063, 0.016459815969158496, 0.06035975433353867, 0.013426073178249811, 0.02733438628326569, 0.006679821027708905, 0.050978522548185926, 0.01328971902174609, 0.02284916633340929, 0.012547193061826485, 0.06822516942130667, 0.011661250244027801, 0.06555341742932796, 0.018803272363064543, 0.04004486031564219, 0.015220855129882693, 0.047547642540718825, 0.07372810877859592, 0.0306896571336048, 0.045292629793818505, 0.0295311705475407, 0.05546354063387428, 0.029675824035491263, 0.06020212386335645, 0.06351321190595627, 0.03442710944052253, 0.006025682311571602, 0.06251042535794632, 0.025879698805510998, 0.03652544845161693, 0.05539090685280306, 0.04405852047992604, 0.04839407087170652, 0.012474620348906942, 0.06872691892619644, 0.004939689982815513, 0.023947877377005558, 0.008956534172674375, 0.07270315449152674, 0.038836382662079165, 0.023958421811195355, 0.01277398066927812, 0.07223816801394735, 0.06499121045427662, 0.022370668527271067, 0.04262922038989408, 0.06212026772222348, 0.03624599041151149, 0.012581417519998337, 0.05822757338838918, 0.055748637299984694, 0.050369608615125926, 0.026655213441699743, 0.02993835262688143, 0.013906035771859544, 0.03109295799263886, 0.03672493435442448, 0.02272743884740131, 0.00818235455413482, 0.04434403783774801, 0.01690354903361627, 0.0012259127168882905, 0.05700703816754477, 0.11379910287048135, 0.04233212722465396, 0.038521905429661274, 0.08506971983505146, 0.034586090195391855, 0.028287441303421344, 0.04014532421050327, 0.03262696282139846, 0.009863645586717342, 0.013293402618728578, 0.07665532241974558, 0.013687406699838383, 0.026076643594673703, 0.027209303441590497, 0.0607143228075334, 0.01148478448989668, 0.0206167318392545, 0.03583875744204436, 0.014927899331918784, 0.02780815809299903, 0.00965941248328558, 0.06453925184905529, 0.017838110581838658, 0.026696855135794197, 0.01277295353689364, 0.042992178949394395, 0.02422422942306314, 0.049215071102870364, 0.08819711487740278, 0.03941146483910935, 0.004110996860877744, 0.0504715347529522, 0.0020005277640718433, 0.06918325408228806, 0.03166193335450121, 0.09321704586701733, 0.02083624809581254, 0.062426985906703134, 0.06478452868759632, 0.019034944574481676, 0.03902863538158791, 0.05055473332426377, 0.042034403021846495, 0.04726405222234981, 0.04609851905011705, 0.006819792199946407, 0.03255774885682123, 0.0290252718010119, 0.06120725814253092, 0.02356496819161943, 0.045828194091362615, 0.07556170717413936, 0.013163848231280488, 0.05186349506090794, 0.030677429932568754, 0.025720711265291487, 0.03959719683708889, 0.004999338299967349, 0.006362851451350642, 0.03025622253439256, 0.043688420339354446, 0.05200550565496087, 0.030110466427036693, 0.008118143088982573, 0.018219983304983804, 0.011248850230393665, 0.06272930039891175, 0.06182385648467711, 0.05239222990348935, 0.023495974750923257, 0.019141233692477857, 0.08774540054478816, 0.03163037469078388, 0.032225778991622586, 0.0236126759887806, 0.03130628940250192, 0.02033435949124396, 0.04319071151050074, 0.024042417661153843, 0.03010737230735166, 0.014345541563151138, 0.031239898143602268, 0.03564850979351571, 0.02323315099679998, 0.009537936903403273, 0.04095088437731777, 0.03189174298729215, 0.02677797230093607, 0.030158001197768108, 0.01810550087663744, 0.014795564647231783, 0.025596551231241653, 0.039615466392466, 0.022843553152467524, 0.03835531151188271, 0.04347953672653862, 0.02454880325655852, 0.02623475412838161, 0.10427456109651498, 0.06587802858224936, 0.03606134746223688, 0.05800654739141464, 0.031502949206956794, 0.037719388492405415, 0.05175691756552883, 0.005006498540751636, 0.0426506451331079, 0.03942227390195642, 0.026998587784224322, 0.03168686612376145, 0.07925208272146327, 0.0555826133516218, 0.040972906231348, 0.012841334599735481, 0.02635902103169688, 0.11656266743583338, 0.032529752501951795, 0.030967222061008215, 0.03363474677982075, 0.038979587477764914, 0.008976025939253824, 0.04644401890358754, 0.11899787533496108, 0.04184112910713468, 0.0468310043880982, 0.01841957268438169, 0.010939072701148689, 0.019982328738218973, 0.029313547403684685, 0.01831833695593689, 0.05876401638878243, 0.027186467345537882, 0.011257035059056111, 0.07231024878897838, 0.031657665369233916, 0.041587954120976586, 0.0853501854996596, 0.03679513219477875, 0.1130239444651774, 0.05066209452758942, 0.023356081186128513, 0.03351799465183701, 0.028905520548245738, 0.023310887361211435, 0.01648577841530953, 0.022125598641910722, 0.032960120122879744, 0.0259297254960984, 0.06493185899619545, 0.025955219753086567, 0.02582402670356844, 0.005155883538204112, 0.06758342457136937, 0.05924575589597225, 0.05394062306731939, 0.09020489999758345, 0.015993767584274923, 0.004811746691952327, 0.019861714049641575, 0.07737312425992318, 0.04117753882227199, 0.043669764019016705, 0.027762282340388213, 0.037317909499896426, 0.006431797818679894, 0.030793449242732356, 0.04976697452366352, 0.08418539871594735, 0.11409328851316657, 0.0674831574516637, 0.043501829994576316, 0.022687023605353067, 0.06271156349352427, 0.06144488789141178, 0.00674521059928728, 0.04899082545723234, 0.07804416825196572, 0.005936818396938699, 0.05122352118736931, 0.06564063632062503, 0.09548583626747131, 0.03177743358537555, 0.0077943054659824285, 0.05582302848675421, 0.02277242741547525, 0.0024967359703233732, 0.07452596418027367, 0.03177661255800298, 0.01468555546099586, 0.0544323065052075, 0.046050363419843574, 0.03426220168226531, 0.015342034698863114, 0.07480279968253203, 0.04356953761141215, 0.07260474655777216, 0.06584017989890915, 0.03113676082076771, 0.029372434065278088, 0.04180936688291175, 0.013094015951667513, 0.0365058862870293, 0.010703556588850915, 0.07567603353943143, 0.03238926861169083, 0.04029614218909826, 0.015184852061793208, 0.05165389559364744, 0.03276450865502868, 0.04567444484148707, 0.0548116957901844, 0.048906361418110986, 0.04822131585595863, 0.04639726444812758, 0.07194419271711792, 0.042028526908585, 0.03779228011678372, 0.01978356038619365, 0.021070498740300536, 0.03352167231163808, 0.053423063696495125, 0.056808142590203455, 0.034405772906861136, 0.03677935625559517, 0.10481224581599236, 0.05723663406180484, 0.020003217438768064, 0.056368102452584674, 0.03333546533914549, 0.025019051773207526, 0.0470916602228369, 0.038313076099646945, 0.03356917315561857, 0.015917903976514935, 0.05402241028579218, 0.005642890597560576, 0.0112024070528735, 0.10981185468179838, 0.0026999712031933343, 0.03807189761261855, 0.017886714045224444, 0.02241735512922917, 0.04639156136129584, 0.006274387872378741, 0.07654199350093092, 0.02320876275189221, 0.01633237861096859, 0.017264192092365453, 0.04548107932454773, 0.0020878942367354675, 0.016808913754565374, 0.012224305387852448, 0.0019486128377528594, 0.019614823994093707, 0.026234776180769716, 0.07323053226407085, 0.03918837270300303, 0.04598023004031607, 0.05168960689167891, 0.018507948477885554, 0.009260770615323313, 0.03422156421999846, 0.03814985789358616, 0.015455965817506825, 0.011777711450122297, 0.031780945004097054, 0.04611463086413486, 0.028278957919350693, 0.020194068983463303, 0.04113639245874115, 0.01643675086753709, 0.06279633965875421, 0.05810703842767647, 0.0112740722252056, 0.07111139276197978, 0.06256476244223969, 0.1298698383782591, 0.19242232612201146, 0.12166393441813332, 0.07487180669392858, 0.1661241137023483, 0.10381009030554976, 0.24192859392080987, 0.17971458658576012, 0.11286780677203621, 0.12160392478108406, 0.13309407393847192, 0.185007349721023, 0.09469787390636546, 0.06823778338730335, 0.1468465267015355, 0.1918773946485349, 0.08365097774990968, 0.07952228215123926, 0.10070976202509233, 0.1469179085854973, 0.11232696007937193, 0.10476788319647312, 0.13390649748700006, 0.1186768604176385, 0.1124584533806358, 0.19662833400070667, 0.10450617223978043, 0.08392264281532594, 0.13279299437999725, 0.17457035476607935, 0.12728620772915228, 0.09339682372020823, 0.10374888644686767, 0.17296401810433182, 0.14106282990958008, 0.2259140953953777, 0.17104816090847763, 0.1828027487333332, 0.15894057202552045, 0.13474670025919164, 0.18278874377054827, 0.10149186862898724, 0.09678894241473504, 0.2183136482323919, 0.10380882144506488, 0.13338683465761797, 0.15869068114885262, 0.10585071652063302, 0.13635374259735855, 0.11921607862625803, 0.13678108395210334, 0.1649925344224487, 0.10954984516969749, 0.13305323970104965, 0.13102337505136216, 0.18555365183523723, 0.17465931070702417, 0.11124201651130404, 0.14721703396311828, 0.1595589481294155, 0.15019952106688703, 0.14184874988027982, 0.12419294299823896, 0.16263732580201967, 0.07355200179985591, 0.13552419282495975, 0.16227042834673608, 0.16356451676360198, 0.16528932563960552, 0.13365253540022032, 0.14248566356088432, 0.10491616345409836, 0.16324698951627525, 0.11699697055986949, 0.10810889463339533, 0.17905530839094094, 0.27932176313229967, 0.11329400140259947, 0.15270791575312614, 0.09039787535688706, 0.18780569599143096, 0.11900601775518485, 0.15815268430326665, 0.13864491108272756, 0.1040182105664696, 0.09609196481427976, 0.1651938964745828, 0.07817452839974846, 0.09703430067747831, 0.07375996599772147, 0.17622465028294496, 0.1596848570874759, 0.12267193890043668, 0.09723086548703057, 0.16893163376620837, 0.13876216193395002, 0.181270833792431, 0.13173445260950498, 0.18345822713204793, 0.09741421243441956, 0.10967393565390791, 0.14173349392201218, 0.2521740384399891, 0.18748773448169231, 0.20199811086058617, 0.12717135889189585, 0.053870903594153266, 0.19945255959672586, 0.0917924005272133, 0.21063478956265108, 0.13764230773917266, 0.15269601424889906, 0.09918231184461287, 0.2833648547530174, 0.14793640321918897, 0.21301120918776306, 0.114412661375744, 0.11603826843202114, 0.11207476896899086, 0.2153485994786024, 0.2525016080055918, 0.16173608201955045, 0.09685680270195007, 0.10787007744823184, 0.17200425746185438, 0.15242518378155573, 0.1362414179103715, 0.1411189040435212, 0.09059152246585914, 0.05183081681440983, 0.28821293317845886, 0.18540286778339318, 0.09057765999542815, 0.10348276501255375, 0.10191956282194171, 0.073387395989682, 0.09590728115290403, 0.20241258719137736, 0.13093870745173522, 0.13218102364667825, 0.1361316173736538, 0.09536207148006984, 0.1655342224985361, 0.09145265804337603, 0.20387831782656057, 0.16935033058481558, 0.06943353850926672, 0.21126315370202065, 0.10156021746141569, 0.21540687206600392, 0.08985306601971388, 0.13703681022993155, 0.1440995048199381, 0.07536409742065839, 0.089572973549366, 0.1599715652742556, 0.13780963447477135, 0.12375634642583982, 0.18288862412529333, 0.10262486604707581, 0.07818882513259139, 0.21499042798365864, 0.10991216251360518, 0.151757043919393, 0.18390325110937866, 0.08571841288357973, 0.07815043362123625, 0.12092863315982477, 0.13442002635981354, 0.07679535847689424, 0.0927088570648006, 0.18804546312562057, 0.11781178255166326, 0.11805081686803273, 0.13392047530838422, 0.16490520696554864], [0.07583652742739234, 0.024525843327865005, 0.04719339297818286, 0.00783551883484636, 0.01789029671012291, 0.0564326005987823, 0.020197471836581826, 0.02311691964444305, 0.018319213962448493, 0.03695369225793651, 0.014375464957473534, 0.018711257925523177, 0.050335220460380824, 0.03614072248871837, 0.009463573706203272, 0.07279614771583251, 0.04187870637646743, 0.03479298909327813, 0.046529992683125396, 0.10301723570695945, 0.020073581520201902, 0.04459783707612327, 0.054898846827979596, 0.01874740857497922, 0.016189850633963943, 0.05679225130006671, 0.025411245013986315, 0.012233885454146989, 0.031709780251341205, 0.033477421650396924, 0.0464223023903157, 0.021208441516916667, 0.01597324020362326, 0.06419754161366395, 0.02656891057267785, 0.03047459545944418, 0.03675202486504402, 0.13617694351289952, 0.02911879767530731, 0.04576946688549859, 0.0502846797795168, 0.016872283836294497, 0.008369423266101097, 0.0518104539785002, 0.0064411264029331505, 0.038523632301283736, 0.039001130964607, 0.012369963955799384, 0.0198719684101109, 0.04426890365513308, 0.0151826722680458, 0.034659422867532284, 0.040036266669631004, 0.03762768448463508, 0.013611353102273174, 0.054278296019349775, 0.024467887955584695, 0.004777365746641797, 0.019683759759313295, 0.012004263266654951, 0.030143355019390583, 0.013818800765355783, 0.040380935317703655, 0.045238157002521415, 0.008421131875365973, 0.12126237739409719, 0.01760830094904772, 0.04485657265675919, 0.026181651977822185, 0.057487359536545615, 0.04629709232332451, 0.06483081834656851, 0.1214084659836122, 0.06599920815122978, 0.025286535366571376, 0.026606023045522825, 0.045507057037736685, 0.018786695752558962, 0.012873861024023166, 0.018942061612116437, 0.07371028366365603, 0.01742937126463013, 0.04530815467504518, 0.03648962519530739, 0.03749610636649387, 0.023204533782388483, 0.009684124728664756, 0.04720517573878169, 0.0271087191067636, 0.011159564351796039, 0.0600669529022915, 0.04610830691776105, 0.06422496799911771, 0.006457638128527573, 0.01842808151351554, 0.011094584445735174, 0.047363803655441315, 0.015376590791025331, 0.01868964488884168, 0.025495846456448947, 0.08830929707203593, 0.02561542298644781, 0.029557820010398115, 0.03866136473204408, 0.03601271685745035, 0.03354373487776943, 0.013095479890970247, 0.015695023882601942, 0.029160568291055303, 0.061718493566981385, 0.05767163607691016, 0.046093501283654144, 0.03856750976826463, 0.02886101882904768, 0.0640321419175182, 0.00865437913619514, 0.03299541072919965, 0.016103413754275868, 0.04732789897492953, 0.010495326914159315, 0.02330380684829184, 0.030723434606833116, 0.02694275961922748, 0.04326961495514427, 0.013450651412962802, 0.03886141042624201, 0.02661760224561606, 0.026068786159157753, 0.027473392663523555, 0.019351248762437274, 0.051509442273527384, 0.03151388719145741, 0.06568087344723088, 0.0456977219853018, 0.03681939660704561, 0.04885545772101198, 0.03503717349043914, 0.057470070464270454, 0.03016110888815352, 0.027351327606343796, 0.057979365278567584, 0.062292554548808506, 0.010720168822444975, 0.03409901740295546, 0.02355171979538032, 0.033304378257266114, 0.06328383992825236, 0.034745647705027034, 0.07851500370140586, 0.008168466638640633, 0.034494440470423014, 0.053008349878447394, 0.05079899236027684, 0.046859862482441325, 0.022669663286900947, 0.02724347955414227, 0.03906168003699609, 0.05034485226497054, 0.03126748398478542, 0.029822360458118573, 0.03986325720325112, 0.024785262532532215, 0.06147197500935622, 0.031454606979553185, 0.01329592676899795, 0.04338330010484372, 0.024555673423622335, 0.029662534927151034, 0.040217954598899396, 0.033785496904913864, 0.051434572719569714, 0.019063692406884263, 0.023924639248954396, 0.06048452335276774, 0.00832123201273914, 0.05596843854125057, 0.06741925302360739, 0.03210409052137818, 0.04410802639488663, 0.03380579188732164, 0.022857880419386283, 0.030541614363236085, 0.020441992108577063, 0.039121574323092184, 0.05602984256776316, 0.012843846875642027, 0.044876124643321545, 0.06488455832004547, 0.010529706587216683, 0.03918558392407639, 0.002258015052315646, 0.05866226327738591, 0.06071731514696564, 0.05600683683795588, 0.04499336870919381, 0.005905107486926551, 0.019611984325040663, 0.04412282185096826, 0.038554715990488014, 0.06007734127342701, 0.044721360983593125, 0.03694836236536503, 0.029589107260107994, 0.036747678848249574, 0.040150498040020466, 0.03419158315019948, 0.023623042307528, 0.02922443879236068, 0.0011987786315980234, 0.05427717643656901, 0.06487400710050549, 0.06702224896954638, 0.0198496021995587, 0.06956651780222144, 0.05686825740018061, 0.02445243771321007, 0.01698989770375192, 0.015532265384016293, 0.023966676189697216, 0.054897167453808446, 0.01965722055839641, 0.08772684261202812, 0.05727642335529838, 0.06442229955324105, 0.021493509345288788, 0.018367038806900382, 0.026288570437048162, 0.02468021004460752, 0.051241458260587285, 0.02537244638162, 0.023371232873094932, 0.07568675439272608, 0.0340844899682062, 0.017560533780072416, 0.0382929677143693, 0.04493631409215076, 0.022194571726556336, 0.019288733634831648, 0.04526512537683759, 0.03303627210802265, 0.024820305473570312, 0.08791500715804951, 0.052675915216760974, 0.01012205207786922, 0.08650683664849826, 0.004395036284612226, 0.05388602813971894, 0.02574677888437041, 0.03641337821526187, 0.03693038797272103, 0.04613371126885925, 0.04123332118615508, 0.014764599701655763, 0.01809143484570086, 0.0370783493188875, 0.01533790581327464, 0.01698064587877265, 0.056870625487395694, 0.035625527812434096, 0.07965201126145464, 0.04358001079942499, 0.045394532182919126, 0.038431178512317796, 0.03715521715847509, 0.03483519057876297, 0.042986547108739614, 0.09086220365549837, 0.0619038354073252, 0.053109767115009685, 0.05026100569271615, 0.07208551120545183, 0.06581202069563524, 0.014841996798557895, 0.04027616272547415, 0.02536874497309327, 0.030780139778341566, 0.013135215749831071, 0.04550375257219587, 0.038181972956018786, 0.041368078240858655, 0.03211829225931849, 0.04356392951948302, 0.03986070251890591, 0.023645322004865323, 0.014246243052184582, 0.03731839465243476, 0.07000165552433048, 0.03583329523514424, 0.020079298177734017, 0.08094420656561852, 0.06131911464035511, 0.013493678166664072, 0.027824481949210167, 0.012773324186647577, 0.07450938756976809, 0.03208682859050376, 0.002308886731043458, 0.029194932697074752, 0.023931321122550538, 0.012892886297777295, 0.04802885618326919, 0.06942996941506863, 0.061062587691204886, 0.02763509434381766, 0.009774167173808175, 0.04264347980331097, 0.07084954609828335, 0.03306553732337696, 0.03725430362724832, 0.026119589772341505, 0.024314069155869738, 0.029441766773483584, 0.03864699336034911, 0.03235314001462289, 0.04567303688132337, 0.03751148197001644, 0.050143398610608916, 0.004224339774477163, 0.03858394727909139, 0.009934871407624866, 0.02226857445202768, 0.03675828095791595, 0.04148765985987016, 0.018402290397456715, 0.009708077014823045, 0.01493285094121737, 0.04522392133783017, 0.04946908747245159, 0.01810520062489169, 0.08265768390681062, 0.04435215650924614, 0.0274982457049191, 0.05851707035409553, 0.054905560931989124, 0.03837183044691171, 0.024871655307444077, 0.03465069690719247, 0.042306431103497744, 0.043505792639085224, 0.06026382983795234, 0.017668449685775807, 0.037226402267281494, 0.05511188307510955, 0.009872854155089174, 0.02658050673614655, 0.018323069737691964, 0.07465077391160385, 0.016030255804902742, 0.07123589715255157, 0.044692886261535544, 0.056015725646700175, 0.01678804201739175, 0.21729230375162192, 0.10099083837121725, 0.12516096819724354, 0.17499986743288382, 0.11384152487984725, 0.26722902059555054, 0.1094885395307626, 0.0868230475378888, 0.11309544170009238, 0.12112018359558922, 0.1518388616719416, 0.13873004008616718, 0.08260097873530217, 0.15985845348664693, 0.04796520620584488, 0.2998044011848313, 0.22064128118966306, 0.15899836963840894, 0.20730243623256683, 0.148518029866474, 0.16002113904271806, 0.11685405751424176, 0.12325758247503213, 0.1611816239144121, 0.0753646402486733, 0.12418321280607156, 0.07206866996628897, 0.10562999586441688, 0.1418633655245815, 0.1265481109065669, 0.13748169850025857, 0.09374272051666464, 0.09531948662229947, 0.19942072273365088, 0.16245779900678567, 0.10951274287487779, 0.10069977398961782, 0.27090418338775635, 0.14413904984082493, 0.19531631868864807, 0.10104678358350482, 0.16672980120139463, 0.11058573065591709, 0.13296132534742355, 0.1433973703533411, 0.13021636621228286, 0.1594998612999916, 0.14897339471748897, 0.11085994701300349, 0.11147818062454462, 0.09218939779592411, 0.11523651145398617, 0.12438374704548291, 0.1482414182807718, 0.10078994450824601, 0.13534170761704445, 0.15581046284309455, 0.12955038409147943, 0.1458702233753034, 0.13999292946287564, 0.16034876289112227, 0.08799963404557534, 0.08961484594536678, 0.18497277157647268, 0.12712055018969945, 0.26221054845622604, 0.10736077584858451, 0.17675692029297352, 0.13376613573304244, 0.14166870739843163, 0.21882790992302553, 0.07851585865552936, 0.21829857118427753, 0.14461912693721907, 0.17146649131817476, 0.06385969224252872, 0.1196170656808785, 0.17415733050022805, 0.12779101064162596, 0.06992898442383323, 0.20319892785378865, 0.10649195246930633, 0.214795159175992, 0.13824066706001759, 0.12396948784589767, 0.14778002803879126, 0.16422690264880657, 0.15415159400020326, 0.09933547076902219, 0.09717420781297342, 0.14977080907140458, 0.17970168084970542, 0.1134456471939172, 0.10829371400177479, 0.18563982578260557, 0.10987140291503497, 0.1361676204417433, 0.16249908107732022, 0.0641555402960096, 0.08677247632294893, 0.10962742207837955, 0.19900506575192722, 0.1560225457485233, 0.12364539237959044, 0.19134979295943463, 0.08716722085539784, 0.08423467392900161, 0.11577757527785641, 0.09680096605526549, 0.20775797750268662, 0.14787304161914758, 0.14202268554696015, 0.12077102304569312, 0.11665397110794272, 0.1671739566539015, 0.12140907666512898, 0.14181128117655004, 0.14196669283722127, 0.19803471996315888, 0.11031405880515065, 0.09993154342685427, 0.11394091668937888, 0.14717647113970347, 0.1314606230173792, 0.14321820996701717, 0.22028424963355064, 0.12032251139836651, 0.12990215021584714, 0.08415590958403689, 0.10748847613909415, 0.16100135073065758, 0.12867596958364758, 0.16455934409584316, 0.1326546139482941, 0.10415949512805257, 0.10350928216108254, 0.14719264741454804, 0.1267035768500396, 0.11830894515982696, 0.08783946585442338, 0.19916270300745964, 0.1380768958479166, 0.08128827810287476, 0.1899878103286028, 0.12873059165264877, 0.12259843998721667, 0.20050792582333088, 0.09681885223835707, 0.1977490567203079, 0.09615044096218688, 0.1193375363945961, 0.133134501054883, 0.1269996759614774, 0.14088197318570955, 0.18246049566992692, 0.11995045707694121, 0.08410688542893954, 0.2199386310364519, 0.10985737081084933, 0.08089955896139145, 0.10472149854259831, 0.16295520588755608, 0.10521809118134634, 0.15997582647417272, 0.08083034838948931, 0.15411082761628286, 0.1468428626124348, 0.10990087169089488, 0.12093121159289565, 0.10026726898338113, 0.1328081799937146, 0.09688927060259239, 0.17690832859703473, 0.112076411023736, 0.07738600285457713, 0.12577315606176853], [0.044353958019720655, 0.05063102101641042, 0.029055171446608644, 0.05253197419057999, 0.018138737218188386, 0.06400945170649461, 0.08988212088921241, 0.11458889049078737, 0.017435739315780144, 0.014172021499169725, 0.006124560130826596, 0.018198107335982577, 0.012525124558513718, 0.01926131233839052, 0.03535335723842893, 0.028161807152043496, 0.07594541872718505, 0.026058238332292864, 0.04094515414908528, 0.03565710683220199, 0.01798169028812221, 0.022841510762061392, 0.04154863301664591, 0.10600593819149903, 0.030262641475668976, 0.008408278725775225, 0.044371528684028556, 0.06631712216351714, 0.040157887286373546, 0.020409115390586, 0.03380472319466727, 0.05565307242795825, 0.028038267977535725, 0.016430006229451725, 0.030733426034982716, 0.05857920380575316, 0.0967372041195631, 0.06625685468316078, 0.028629621424313103, 0.04910773704094546, 0.02384758141956159, 0.029430197751415626, 0.052016569168439934, 0.05609761803810086, 0.017517855623736978, 0.041913498259548626, 0.014446034295750516, 0.04475962357329471, 0.05840673377471311, 0.01974809675344399, 0.027208294120750258, 0.04258255414398653, 0.016464224750442163, 0.08911644840346915, 0.028543827456555197, 0.0670100896220122, 0.023883947503886054, 0.0345113665264632, 0.015347228884430868, 0.018592689020027007, 0.021281021015186394, 0.017474631246711527, 0.07753069366195373, 0.02390407624521426, 0.015333264633747084, 0.03781980488981519, 0.02865692228078842, 0.048485662921198776, 0.03156155427651746, 0.05642937416476863, 0.06529566911714417, 0.023516530969313214, 0.06568231194147042, 0.08957610159580197, 0.07802947796881199, 0.05578028756592955, 0.02594319950523121, 0.025395314708085995, 0.016489003152985657, 0.07836409072790827, 0.012395175772586038, 0.09071979951113462, 0.03375432500615716, 0.047384644858539104, 0.06435367252145495, 0.0319130048821015, 0.0652365687170199, 0.01647849943089698, 0.05729692868356194, 0.03751027417768325, 0.02822168617110167, 0.00846410180175943, 0.00918219201931996, 0.02239103814853089, 0.061744440746094496, 0.030234662084175006, 0.046080799108105044, 0.01922736523140754, 0.013308881698841495, 0.010310468530016286, 0.04675331212846296, 0.05572751789752926, 0.0348275977719043, 0.031423682746078284, 0.016335338719987443, 0.018716938959966813, 0.015265950567222067, 0.011622073328388589, 0.036699190735816956, 0.02003133253726576, 0.009955283437323357, 0.025499909184873104, 0.02373250188039882, 0.0757595883416278, 0.02951809178505625, 0.03669183202353971, 0.048825052566826344, 0.0110933410303135, 0.011863857407921126, 0.01734997927477317, 0.03876512969977089, 0.017571819513770084, 0.01207694030433361, 0.010898603176298951, 0.07014003595603363, 0.04338089469820261, 0.05371389737618821, 0.038268638841275654, 0.018048378406092525, 0.024955082884324447, 0.044456589833966324, 0.03709743311628699, 0.04948172179449882, 0.017091783129477074, 0.02955028827169112, 0.0530018698690193, 0.05363517374332462, 0.03352440341508814, 0.02695910383148917, 0.08259796603981938, 0.011373201950586267, 0.042883470854056735, 0.06668178723858935, 0.08117224861468587, 0.020647752763969556, 0.03302667423018387, 0.016190184812460626, 0.0349055139480957, 0.04011745677728738, 0.054431702609040906, 0.012571739066126091, 0.004584603277700288, 0.014930995147941368, 0.027775478150163378, 0.01965669130108186, 0.02308910310135356, 0.021486125187948346, 0.06129969496812139, 0.0660903218335339, 0.048111413538988144, 0.024529008693726997, 0.0278214014002255, 0.06783925941480057, 0.042883284256926606, 0.02203072757194085, 0.03425967074664576, 0.018693256391478435, 0.019358115536825996, 0.02857576949255807, 0.030549380196524516, 0.010724374043223048, 0.020453282931287373, 0.011677130507970495, 0.01706678929206516, 0.07616569155028888, 0.025462160585448146, 0.09785372670739889, 0.02375806399088885, 0.009955036620210325, 0.034938789305410216, 0.02766827300989202, 0.012008911231532693, 0.019775535013260584, 0.027602309228054116, 0.01196328059969736, 0.045049714257142374, 0.028477900994143317, 0.03412252864135163, 0.03466132615825959, 0.04490062654284494, 0.05116607641269054, 0.022469890703048025, 0.012974126447391297, 0.04314797737502626, 0.005973890581766942, 0.06845906722758498, 0.05773161857255867, 0.056630458017545085, 0.04626470245420933, 0.07778118164943797, 0.088366789344166, 0.03413377535928573, 0.019839619253096834, 0.007805128099529871, 0.04573952313512564, 0.04238836420699954, 0.11681732162833214, 0.08759194306497063, 0.03565445376027908, 0.013172273939874555, 0.020070095546543598, 0.05013291185189571, 0.04081745385857565, 0.07130317389965057, 0.027794663727815663, 0.0679688663887126, 0.0024589131561307503, 0.10086214741958038, 0.02002338519585984, 0.009004470127235566, 0.05065909879548209, 0.014599556236394813, 0.030146191295768534, 0.02140518613824887, 0.020736091238047396, 0.011236754495517483, 0.035314677349690876, 0.08438456909997122, 0.02431307510206742, 0.0761305909337742, 0.017878534305574637, 0.027866021863051822, 0.04823433015761631, 0.03191241455663528, 0.04258082387968898, 0.026403931568243673, 0.04084826613377247, 0.04992242350376078, 0.04548718613971557, 0.046805929126484055, 0.024994553266359226, 0.023970908551876034, 0.01640569092705846, 0.04000898616920624, 0.025623981009370515, 0.06438830494880676, 0.0644685552854623, 0.027878593420609832, 0.02944232995754906, 0.0491028956935874, 0.06197063717991114, 0.06353718454816512, 0.004738679072553558, 0.025031658953854015, 0.052045064246548076, 0.009658968891017139, 0.0720653926421489, 0.021915005120847906, 0.10121018160134554, 0.02605701527292175, 0.02805647985743625, 0.034551335631736686, 0.0424193596866514, 0.01143003095473562, 0.07525437152279274, 0.05770416504570416, 0.008135910528445882, 0.015244807416040982, 0.07312001926558358, 0.025013535283505917, 0.08045296078281743, 0.025676648897518004, 0.052011558187327216, 0.020808155049702952, 0.03736941370048693, 0.05228630719440324, 0.0240294118411839, 0.10655656935913221, 0.04762480554303952, 0.03505474415474704, 0.02292751507567508, 0.04003679931962064, 0.02644074209300535, 0.022763787968350307, 0.06546058026807648, 0.021093080385721157, 0.01635259386551167, 0.08659498513277088, 0.05898858433855431, 0.04914117185398936, 0.07048688948686634, 0.0336613792793027, 0.006511523987033537, 0.050594661717436144, 0.061450146537806304, 0.024289962502994707, 0.03432097638558064, 0.02630178490653634, 0.03955601315413203, 0.0384190768402602, 0.07939363869705371, 0.06474044426743474, 0.058877352092947276, 0.0318103391411049, 0.023182374525016973, 0.019391144925196255, 0.0549271587016327, 0.0282130127972258, 0.05764222836920193, 0.04599262008975659, 0.030931510762976747, 0.018227460760889307, 0.018642161008236662, 0.026776498183608055, 0.027894123390849148, 0.02740186489453273, 0.005436649454558002, 0.041670582722872496, 0.015546713090900863, 0.0977510032909257, 0.004365243084196533, 0.026365533271538358, 0.042867511710418124, 0.039038087374397686, 0.03277578590703862, 0.0327637961932591, 0.004822401388082653, 0.03164163497941835, 0.028374624571629932, 0.05093401404363768, 0.029273619010512317, 0.04107520556343453, 0.031413304552968056, 0.09388920944184065, 0.06513786222785711, 0.024479672412521074, 0.06177267458822046, 0.009388492958221053, 0.032431351353547404, 0.03878069868577378, 0.046633177503411255, 0.012613995682581194, 0.0329935786846493, 0.011946372355201414, 0.01763659416298781, 0.033121808232473474, 0.050365734180169444, 0.09379366492586476, 0.04434954075674925, 0.0049533705210446245, 0.07593676062034709, 0.014426039565088493, 0.1958969682455063, 0.13934492852006639, 0.16828830114432744, 0.10602846555411816, 0.09522556380501815, 0.10088791817958866, 0.12194453578974519, 0.13484098948538303, 0.1308880615979433, 0.1281474722283227, 0.062292927743068764, 0.1249679114137377, 0.11943285699401583, 0.1181223208882979, 0.11317603808960744, 0.1303842764879976, 0.08767939265817404, 0.06943657834615026, 0.10351113456168345, 0.1469008502151285, 0.09355955677373068, 0.12163950715746198, 0.07603393362036773, 0.15443172039730207, 0.10973342281899282, 0.15605027068938526, 0.09308808350137301, 0.14592848239200457, 0.12218533429716315, 0.10959882182734353, 0.3010287226310798, 0.17670548733855995, 0.12767599895596504, 0.07355505520743982, 0.18184673360415868, 0.1337737353252513, 0.21137907462460653, 0.13629597212587083, 0.08877224794455937, 0.12155941288386073, 0.09106351821018116, 0.14765833956854685, 0.10297103425753967, 0.1490985844284296, 0.1364846998559577, 0.07337861574654068, 0.05511216127446719, 0.09121654821293694, 0.10502067141767059, 0.05305992193253977, 0.12303784569459301, 0.19152585922607354, 0.09724889416247606, 0.18756569815533503, 0.08910064532288484, 0.1135683466813394, 0.1593213930193867, 0.12196204199322633, 0.1181624765907015, 0.14484395273029804, 0.14748200188790048, 0.09036607242056302, 0.19322412381214754, 0.12970164311783655, 0.17353244046015398, 0.07217061306749072, 0.14468237997165748, 0.11011482056762491, 0.11478818979646478, 0.21193744109145232, 0.14460177001144203, 0.07995254799191441, 0.13993608179901326, 0.20622587257197925, 0.13024383330983774, 0.1303421530340399, 0.11653438609625612, 0.053832980271961005, 0.11140337213873863, 0.1675300518316882, 0.15098423324525356, 0.1915515892739807, 0.19086896947452, 0.1351912628327097, 0.17328200675547123, 0.09389582515827247, 0.14010529486196382, 0.07416873584900584, 0.2059645008827959, 0.11166069975921086, 0.11767579056322575, 0.09479377804590122, 0.1284389437309333, 0.13835329030241283, 0.18627555881227764, 0.13866500928997993, 0.164975625329784, 0.09790726312037025, 0.15292522337819847, 0.15720023826829024, 0.08552586500133787, 0.1794786328183753, 0.1406971945294312, 0.22499579324253968, 0.20398395215826376, 0.12020251926566873, 0.06381805733378444, 0.06657581363937684, 0.1811892060296876, 0.1016523896583489, 0.10706851724535227, 0.1765254448567118, 0.11671092733740807, 0.2486197091639042, 0.16363170530114854, 0.10547116438725165, 0.12944207633180277, 0.12106344449732985, 0.1761782927704709, 0.09721589700451919, 0.14968869276344776, 0.09898119406508547, 0.11982741153665952, 0.07668454692299877, 0.20308128345225537, 0.17020513543060847, 0.12671469125364507, 0.1559518695409809, 0.07072384748607874, 0.07130957927022662, 0.1769868079572916, 0.14175750049097197, 0.15456643673990453, 0.1683145740202495, 0.10573049368602888, 0.2768034482640879, 0.1043750046353255, 0.08985497948846646, 0.1585726567677089, 0.20241945396576608, 0.07207183193947587, 0.13435317708977632, 0.2092426528355905, 0.16507246584764548, 0.1254504040947982, 0.11474498068647725, 0.1000988023089511, 0.13953247559922083, 0.24126029121024267, 0.1427447825138058, 0.08963649799781186, 0.11217310904924359, 0.096397576986679, 0.17727232192243847, 0.08235448731907777, 0.10092599756483521, 0.15989951842597552, 0.1658348542238985, 0.20309346994119032, 0.14121478104165622, 0.1661964048232351, 0.14935558635209287, 0.14979090727865696, 0.132894136809877, 0.09414910192468337, 0.11695164442062378, 0.09534698764660529, 0.17215703640665325, 0.10089829976537398, 0.13340683786996774, 0.2273669202945062, 0.15775498135813645, 0.135784614565117, 0.09357377886772156, 0.1717890261539391, 0.09492198045232467], [0.07366453683269875, 0.01882672931865922, 0.04638593291331615, 0.017213510615485053, 0.024054229259490967, 0.02323715604974755, 0.0875446627448712, 0.016096976153286438, 0.045608026441186666, 0.03379299471686993, 0.022376030650255934, 0.024879643360951116, 0.006775899041843201, 0.033795980270951986, 0.02803439523891679, 0.03959552085559283, 0.047795016052467484, 0.03615302772128156, 0.02520568622276187, 0.10959906609995024, 0.024977535608091524, 0.04014524957165122, 0.03386648005938955, 0.05020534885781152, 0.06271278485655785, 0.010668009835561472, 0.021189661363938024, 0.06346407239990574, 0.05948265961238316, 0.03878496327836599, 0.03018279147467443, 0.05056228881169643, 0.049740847532770464, 0.06746869108506612, 0.022226827585005333, 0.05953591104064669, 0.01646017559271838, 0.03727030348298805, 0.06508902806256499, 0.1557081669036831, 0.04973330222336309, 0.03154885549364345, 0.030145533116800443, 0.07703202470604863, 0.04369325829403741, 0.019143863015675118, 0.0038377694685810377, 0.009122321481949516, 0.07811753824353218, 0.004171749069688043, 0.04398535744154027, 0.02691236464306712, 0.056213053808148415, 0.009679039108699985, 0.02250949339941144, 0.034905412167842896, 0.0200010902314846, 0.06065626735133784, 0.053239184099116495, 0.02775027566323323, 0.028684355451592376, 0.0572161694456424, 0.00802653916512749, 0.019054355765027658, 0.037664878381682296, 0.034193808745060644, 0.036938367544540336, 0.04569173391376223, 0.036088719564889155, 0.023778141842090657, 0.0170521346319999, 0.033245783365730724, 0.02907077775203756, 0.023749444899814467, 0.033109184088451524, 0.03372356701376183, 0.016421717924198935, 0.023622085573151708, 0.0745093332869666, 0.05966306171779122, 0.03601233009248972, 0.042365358477192264, 0.018510949299005524, 0.03038902540824243, 0.03271925715463502, 0.019448730495891402, 0.029294097197375128, 0.12396027334034443, 0.0670004476393972, 0.005122324892519308, 0.031026244429605346, 0.052511180484933515, 0.08083785298679556, 0.11036734416016511, 0.01390719267406634, 0.04162295974258866, 0.0526480376055198, 0.025278435354786258, 0.030803349068654434, 0.03803325165063143, 0.04889193915628961, 0.03443743674350636, 0.032658840396574566, 0.05715702833341701, 0.018447723405967866, 0.04858523454251034, 0.00951188794403736, 0.046188391013337035, 0.07058102265000343, 0.01698147878050804, 0.028977272233792713, 0.05353770897324596, 0.07598613082830395, 0.02937330598277705, 0.005969257883927119, 0.0026114728493017276, 0.019775475641446452, 0.015251353582633393, 0.05541261997339981, 0.04780774536941733, 0.0263524612944041, 0.013550375704653561, 0.006859641713422856, 0.016355689681534256, 0.042531820080642185, 0.043444693953331025, 0.05414531333371997, 0.06311158702841826, 0.018515005242079496, 0.06340472772717476, 0.03512893517368606, 0.033645827256675274, 0.036978981258081536, 0.04043971002101898, 0.039222709967621734, 0.013155726167107267, 0.011224205838516355, 0.03789305953042848, 0.04005557099091155, 0.013332275889946945, 0.02041510515846312, 0.040975315030664206, 0.029007355083844492, 0.0444715108190264, 0.02169482729264668, 0.0328835304826498, 0.04065669534195747, 0.07304263913205691, 0.023309224950415746, 0.04073413654363581, 0.035667651266391785, 0.008026476400638265, 0.09313805760549647, 0.06251487654766866, 0.017987871742142097, 0.02496410740007247, 0.016726410681647912, 0.013313353244614388, 0.02387733178745423, 0.034901619157088656, 0.03533065684938005, 0.040607426914253404, 0.02643081682202007, 0.033476078151060004, 0.05475950626922505, 0.053903229002441676, 0.025638557637908628, 0.06126990049545254, 0.0522975708757128, 0.053346864213900905, 0.02920700383505651, 0.03336583995925529, 0.023260528188464896, 0.020437432353251746, 0.05679853453433939, 0.009490147682039865, 0.010468423000669904, 0.0438658097492797, 0.026217115610571842, 0.006348369393630752, 0.08170006743499211, 0.019871166042451347, 0.032169782889208624, 0.03138263477012515, 0.01725501660257578, 0.04884171738688435, 0.043367978784122636, 0.031072099826165607, 0.06237581079559667, 0.029094519692340066, 0.0775295469377722, 0.037570996276502094, 0.028026505572987453, 0.033818707801401615, 0.012118413212842174, 0.0661934388003179, 0.04027120941983802, 0.03487392135762742, 0.013357194240338035, 0.03565116625811372, 0.06606483605823346, 0.044361533863203864, 0.05987561959773302, 0.011706718875627433, 0.029616472577410083, 0.016857410348685722, 0.025851661738540446, 0.025792708919782723, 0.07193625385739974, 0.02002163457551173, 0.06835429463535547, 0.05438342144978898, 0.07672768139413425, 0.03451691694291575, 0.09968921821564436, 0.04875225254467555, 0.04763836606538721, 0.07075738068670034, 0.015633222913103442, 0.0010148951114388183, 0.015318852549950992, 0.01456335639314992, 0.003194143804388919, 0.049277632031589746, 0.015259692778012581, 0.04599329183942505, 0.04065505667988743, 0.012223969513018216, 0.016065005279545273, 0.03766952295388494, 0.013421006217998053, 0.031515318900346756, 0.049332871567457914, 0.04569225977840168, 0.05887408833950758, 0.020729343207286935, 0.012081844416180891, 0.08641199780894177, 0.021921804041734765, 0.05049765495849507, 0.010515707561613193, 0.03696148183995059, 0.06043520064226218, 0.02441857542310442, 0.07493120564946107, 0.0507797287510974, 0.018424887309915254, 0.0852137388927596, 0.011889506879794811, 0.033715007294501574, 0.029409644925700765, 0.04326059043939624, 0.0204381583857217, 0.07079009964529957, 0.03505847270467451, 0.037769209926149676, 0.03613547741302422, 0.1038355692955, 0.023154926087175096, 0.012984445268687392, 0.0688989275534238, 0.02832080826296338, 0.044629260032836876, 0.12506498263350554, 0.09164248500019312, 0.041510051515485556, 0.018747474732143537, 0.02559284812637738, 0.1455750335007906, 0.03826994841386165, 0.07112551307571785, 0.009953920430104648, 0.014850795701412218, 0.029083164408802986, 0.10800754864301, 0.051156529424978156, 0.057486687786877155, 0.040216760377266576, 0.03736878605559468, 0.025559313229418228, 0.03710687493107148, 0.04438789155600326, 0.013034474503781115, 0.05590644758194685, 0.0397272686074887, 0.019461441153128232, 0.03924739507160016, 0.024303673999384046, 0.03844444726460746, 0.029392366031450883, 0.02160867370132889, 0.08453734125941992, 0.025338209200916544, 0.02133644714818469, 0.12815437971481256, 0.0243497838465763, 0.02320331072301737, 0.019814155530184507, 0.051692538162959475, 0.029029492288827896, 0.03634480885895235, 0.03507357689418963, 0.0640655801232372, 0.015569689982969846, 0.005528348373315696, 0.013515555832002844, 0.02107035624794662, 0.0843897463221635, 0.086074820187475, 0.03577321095924292, 0.03292799148974674, 0.058224031435591836, 0.057267100284142156, 0.044642108093414984, 0.053749567962118557, 0.047802944734160385, 0.01451494122323181, 0.056121183559298515, 0.012650968207578574, 0.0771700387288417, 0.04588289758456605, 0.01806862758738654, 0.046092456339725425, 0.07606031506189279, 0.012178787562463964, 0.006560220324900001, 0.05109864699521235, 0.03231896220573357, 0.035722880624234676, 0.026274587526651363, 0.015825195736917, 0.095381470796253, 0.011230237166663366, 0.017697594461164305, 0.03134677419438958, 0.03446596235569034, 0.04813718090632132, 0.058236876103494845, 0.034588261507451534, 0.04380905708031995, 0.00639032236566501, 0.051682916536395035, 0.019401451872129525, 0.046416022548718114, 0.0639784833682435, 0.02486230170221201, 0.013183770019428005, 0.04390838782169989, 0.044649578763970306, 0.0464182888556804, 0.014065002107859721, 0.010285680797616286, 0.17733902191477163, 0.13677519426814147, 0.1251688256327595, 0.09759985283017159, 0.12017810557569776, 0.10586140344717673, 0.15734107499676092, 0.10519312109266009, 0.1638626107679946, 0.12337277057979788, 0.10931454958128077, 0.1315226275473833, 0.14814855397811957, 0.10285574437252112, 0.1629175879061222, 0.12365791813603469, 0.16466732615871088, 0.1295578751180853, 0.21693675140185015, 0.16617428458162717, 0.15290304885378905, 0.12252473751349108, 0.12696342862078122, 0.12628945335745811, 0.17999237882239477, 0.17140405252575874, 0.08042382448911667, 0.14920017469142163, 0.16068522126546927, 0.10897172654845885, 0.1765811118696417, 0.194270519805806, 0.12144700677267142, 0.10164253054452793, 0.1573275857205902, 0.13236473021762712, 0.14707315739776405, 0.11463173319186483, 0.2058139203914574, 0.27747536078095436, 0.136990507000259, 0.16005729138851166, 0.10458432590322835, 0.12953560559877328, 0.11545600396181856, 0.17060319121394837, 0.14677661045321397, 0.11431518303496496, 0.13958397640713624, 0.15228380422507012, 0.09679300683949675, 0.06396451233220951, 0.09152253357959644, 0.09801687366728272, 0.1411625338452203, 0.09126631197120462, 0.09813014151794569, 0.2092590598123414, 0.19057033264211246, 0.12290937187416212, 0.1541806488697018, 0.2580601940197604, 0.13796724458890303, 0.12782902217337064, 0.07725451633866344, 0.15138716091002735, 0.12752290788505757, 0.10369217449000903, 0.11438906192779541, 0.12523526778178556, 0.18657237717083522, 0.24895558399813517, 0.1047301362933857, 0.12001851413931165, 0.12616072169372014, 0.13900376111268997, 0.1018092737400106, 0.16130423519228185, 0.14010488774095262, 0.14893174623804434, 0.10288353038153478, 0.1929641363344022, 0.1080853630389486, 0.13412889412471227, 0.11316881169165884, 0.14752910578889505, 0.1123393229874117, 0.23164137878588267, 0.23026729109031813, 0.10833308260355677, 0.08754518521683556, 0.1377679995660271, 0.18795209670705454, 0.13480924761721066, 0.12113539635070733, 0.05095445830374956, 0.17225348337420396, 0.11308286844619683, 0.17629130956317696, 0.16405754030815192, 0.2054005161459957, 0.15146226116589137, 0.14160962056900772, 0.10945991213832583, 0.113524669382189, 0.11154538273279156, 0.08171714616141149, 0.13518823656652654, 0.22112006906952175, 0.10711465084127017, 0.10758530308625527, 0.08676225758556809, 0.15294211890016282, 0.05123836414090224, 0.07784775272011757, 0.09475843315677983, 0.21660521919173853, 0.0977377040045602, 0.14105056199644292, 0.18511964726660932, 0.11704024752335888, 0.11003872286528349, 0.1399583648890257, 0.11170166291828666, 0.19888451722051415, 0.0968826955982617, 0.1581516529300383, 0.16851756455642836, 0.12418879036392484, 0.1132670771330595, 0.11856733129492827, 0.16686197982302733, 0.17317044202770504, 0.11122740765235253, 0.09747956214206559, 0.13902371004223824, 0.10798828503383057, 0.12606955372861453, 0.12170980338539396, 0.15060581426535333, 0.07440082875213452, 0.12746103906205722, 0.14384209577526363, 0.1530563434852021, 0.0966688756431852, 0.09915188633437667, 0.13743988717240946, 0.22044635164950574, 0.11573760956525803, 0.09689445461013488, 0.15378623003406183, 0.11705978933189597, 0.10517441388219595, 0.18571819657725946, 0.08653795426445347, 0.14316778124443122, 0.07306500364627157, 0.12581437027880124, 0.15831257429506096, 0.0630156353914312, 0.13023254248712743, 0.21849400284034864, 0.12724991967635496, 0.22339442345712865, 0.06792245459343706, 0.12893070520034858, 0.11039560514369182, 0.13864104343312128, 0.09136440777885062, 0.09070827120116778, 0.09953846130520105, 0.13401228109640734, 0.11877672720168318, 0.14942926168441772, 0.08490299021026917, 0.10145595377045018], [0.02931340491133077, 0.04752859267007027, 0.0350140524096787, 0.007353203421059463, 0.08250605847154345, 0.0492278547026217, 0.010403371848432081, 0.030551955236920288, 0.029490122571587563, 0.047203550647412024, 0.06316299284143106, 0.02955538746235626, 0.029674324473100047, 0.03295552644080349, 0.07919309767229216, 0.028079207387885878, 0.06979402380862407, 0.05304948267127786, 0.08318927538182054, 0.0627464401934828, 0.0745736380506839, 0.053410212243241925, 0.0176147368536996, 0.028105872117781212, 0.03890906733327678, 0.023154159342604022, 0.03494673834315368, 0.059951805509626865, 0.07924590805279356, 0.0374590922812266, 0.055248882688049755, 0.025933793313535194, 0.03706722812993186, 0.034464344049670866, 0.036530255872224054, 0.03395786854837622, 0.06636012771299907, 0.022523651032575538, 0.015293188659208161, 0.013449184929153748, 0.03744052417044129, 0.021191223690818464, 0.028429862411160554, 0.037169904048953734, 0.026248065289109945, 0.07534429098346404, 0.038164670313043256, 0.027865187264978886, 0.0884146871311324, 0.030906652632568563, 0.042658187049840174, 0.01791275621924017, 0.06819810944476298, 0.03167675255930849, 0.051617573614099195, 0.025688933774030635, 0.014465891623071261, 0.018042076512106826, 0.037852422068161626, 0.04788354112367545, 0.0370127349825842, 0.01564159264255847, 0.03889490630743759, 0.044624337261276584, 0.03728642547503114, 0.022366210552198545, 0.034551990418029685, 0.030678563086049895, 0.027355222397350838, 0.017343702825850675, 0.1167084981820413, 0.0184078934003732, 0.04658183954390032, 0.02497378839845104, 0.009433910699694284, 0.03301020957795637, 0.02547186702888991, 0.08533129508474044, 0.029115072518054928, 0.049130342435091734, 0.022980791949001805, 0.04352264744894845, 0.005821856753235417, 0.042316069693437645, 0.011478035610967448, 0.05640647021521415, 0.034956665310476503, 0.0058613882034218735, 0.02897355386189052, 0.04935921568955694, 0.004649450021263744, 0.027992224287507788, 0.027137980929442813, 0.054737620122198544, 0.017012031516060233, 0.05825879278459719, 0.09305884542741946, 0.06076171847858599, 0.037299663693244965, 0.029197894502431154, 0.030070975688951354, 0.024615516819592034, 0.017839844238811305, 0.02306830430669444, 0.06792274636349507, 0.0340703323350421, 0.010315276798792183, 0.036826103925704956, 0.03236771833949855, 0.03427890721442444, 0.012711686065553554, 0.06627802497574262, 0.021159644671050564, 0.06257025179054056, 0.054813517656709464, 0.050925522177879295, 0.020300286855282526, 0.020495306301329817, 0.014212383306585252, 0.0683726490076099, 0.0511097647914929, 0.026199604318078076, 0.055574827162282806, 0.059558343408363204, 0.035532792431435416, 0.09744093314345394, 0.03764077003246971, 0.09230108465999365, 0.01441230601631105, 0.024128343943240385, 0.03813418034198029, 0.03381316756297435, 0.024649599633578743, 0.009176583079222058, 0.024665723321959376, 0.04084470043224948, 0.03387083625420928, 0.025814265977325182, 0.008742060279473662, 0.08689151172127042, 0.0280314520932734, 0.05448536115831562, 0.022131065937823484, 0.00905789458192885, 0.06107910323355879, 0.03425483957731298, 0.011704250704497099, 0.02144923832799707, 0.010570747777819633, 0.037782617778118165, 0.023193566960149577, 0.012686530227905937, 0.03697810934058257, 0.05680512650204556, 0.020905455275039588, 0.006377098566320325, 0.02174106436515493, 0.014865019491740634, 0.03797883314213582, 0.026285771480096237, 0.024748326478792087, 0.050501271550144465, 0.044139591843954155, 0.03275664782683764, 0.03433451994455286, 0.01860321479450379, 0.05857623860772167, 0.012861018900626471, 0.0355651789078755, 0.007988540355914404, 0.02610015483306987, 0.06403062878442661, 0.023848974112687365, 0.01659712431553219, 0.037525503896176815, 0.025877912562074404, 0.014992913164730583, 0.010050533638734902, 0.05127790576911398, 0.049336871531392844, 0.05996582404311214, 0.03751253030662026, 0.08127999997564725, 0.04236522277018853, 0.05079111796138542, 0.030381653125264814, 0.015438656389181103, 0.07880280432956559, 0.03852604788595012, 0.04360644991642662, 0.055249517118292193, 0.014619715511798859, 0.059826724364289215, 0.03603574972865837, 0.11487703717180661, 0.020920562857229794, 0.05346462396638734, 0.0038209311980088906, 0.017145560422380055, 0.04213653611285346, 0.02564152453227767, 0.00567621472457956, 0.02457412957612957, 0.07020026272428886, 0.06815812337611403, 0.059850405236440044, 0.03822386910074523, 0.02961356844753027, 0.018887140987707034, 0.008533810248731502, 0.028240522303219353, 0.05069272359833121, 0.016121344042143652, 0.09256424768162624, 0.05103935321260776, 0.008542417465443057, 0.029960198061806814, 0.05746582283505371, 0.023034238456083194, 0.06173954850861004, 0.029167421494743655, 0.046422292212290425, 0.07827140284436089, 0.025454099589426602, 0.020050097423206483, 0.03156643633597663, 0.019326064935220138, 0.0201966813432851, 0.01084765452625496, 0.026194413525185416, 0.05646460370293685, 0.034619372338056564, 0.01870957006966429, 0.03721746935376099, 0.04911121792559113, 0.04265346444611039, 0.0418706894852221, 0.03501037135720253, 0.033793249167501926, 0.04420640718724046, 0.0392739834663059, 0.0737302325932043, 0.025172365064333593, 0.024937217057283436, 0.026566874967621903, 0.08637399984789745, 0.042997044045478106, 0.053686318320355246, 0.07287399603852204, 0.043827106111816, 0.03655612841248512, 0.05334650119766593, 0.0755922616060291, 0.08198946262044565, 0.011655777859102403, 0.059715003573468754, 0.024747936321156364, 0.04414476567347135, 0.015728820015543273, 0.015953613578208854, 0.01335336730283286, 0.041186447987066846, 0.029636448648359095, 0.023883257094504576, 0.03198512976190873, 0.016741966096950427, 0.01545347729032593, 0.04373575494225536, 0.02207713427820376, 0.02704017180284219, 0.003028930493331115, 0.006612846228693212, 0.02500242936158819, 0.10318018589168787, 0.04064592020586133, 0.035814642307481596, 0.046272987366787026, 0.014584655607385295, 0.050639200756060224, 0.03200565205354776, 0.029115927472178425, 0.006109086987895093, 0.020321409650413052, 0.02795767498069576, 0.0270361769279199, 0.013241641422999757, 0.0098528229531699, 0.04743987760905709, 0.028955331803964715, 0.03899408098576324, 0.03285378011475716, 0.029997324105352163, 0.024475151672959328, 0.049491621620420895, 0.0665848245844245, 0.018617385998368263, 0.0823446282052568, 0.02294459380209446, 0.01146036571091307, 0.050924480626625676, 0.0487367649828749, 0.027813893410244157, 0.024253725340323787, 0.04465916307110872, 0.049581103426005156, 0.03329696526218738, 0.032176575024745295, 0.00803212690100606, 0.08384430594742298, 0.03587419393339327, 0.023084879220862473, 0.03842788083212716, 0.08573928462075335, 0.020536652832691158, 0.04494204092770815, 0.05595696112141013, 0.03943507107240813, 0.06448340163167034, 0.06839553599378892, 0.026493459174941694, 0.004255233049791838, 0.01334200777845191, 0.035243461706808636, 0.03234343696385622, 0.025443970757935728, 0.01078067803090172, 0.05104084598964878, 0.020977235798324858, 0.04093470810247319, 0.017152479783232723, 0.04667308893320816, 0.020131294316213046, 0.03697740366416318, 0.019081917857485156, 0.035497338976711035, 0.05132331672523703, 0.035105749632098844, 0.053551958208637576, 0.025898536633966223, 0.04326741310900875, 0.03716234516884599, 0.029183224575327973, 0.0287577899039856, 0.041134886110999754, 0.023941166665671126, 0.059590132773986886, 0.02302482887171209, 0.015268537481980664, 0.023490890827296034, 0.02960571101201432, 0.07974811896149601, 0.043715076587562046, 0.1188420836946794, 0.0768418177696211, 0.10898407588579825, 0.10968932482813086, 0.25401313975453377, 0.11103934488658394, 0.18318063845591886, 0.10490617541862385, 0.2812271166060652, 0.11601879447698593, 0.11335984644080911, 0.1507838075714452, 0.0638384065989937, 0.20274515077471733, 0.17604908613221987, 0.10750911717436143, 0.17258181289902755, 0.13531847457800592, 0.20313040938760552, 0.12232813877718789, 0.17719310974436148, 0.1181618794798851, 0.15738788034234727, 0.1425450218043157, 0.1681339887103864, 0.11208635834710938, 0.11366560110556227, 0.1483081318438053, 0.17951003541903837, 0.08051729947328568, 0.15294646152428218, 0.08344504915710006, 0.1986211370676756, 0.13383412494191102, 0.1419210952839681, 0.09711330929504973, 0.2605613283813, 0.1625092319611992, 0.15449744329920836, 0.1369675046631268, 0.11218797575150218, 0.09167225233146123, 0.1543528881988355, 0.14004201468612465, 0.17173605971038342, 0.1252833894853081, 0.16902723935033592, 0.08682931041611092, 0.15186399460903235, 0.11943030570234571, 0.14522030896374158, 0.11906294684324946, 0.13190281071833201, 0.12167122188423361, 0.15758211777678557, 0.17090671349849018, 0.10664299436445747, 0.08236816658505372, 0.17360975274017879, 0.24146021476813725, 0.09743568128240959, 0.10585426525878054, 0.10311649180948734, 0.23308958964688437, 0.12021986262074538, 0.12766383960843086, 0.19338694507522242, 0.0967130618435996, 0.09995058990482773, 0.15283511392772198, 0.19667789419846876, 0.13780115278703825, 0.12740634913955415, 0.13348756996648653, 0.1379185936280659, 0.09868506102689675, 0.12658290618232318, 0.1566628385335207, 0.19375947437116078, 0.13971023820340633, 0.10817848518490791, 0.09259134158492088, 0.15261819985296043, 0.1456769494605916, 0.0867994005924889, 0.08271250953631741, 0.11198014047529016, 0.09918356034904718, 0.13267612350838526, 0.11670218780636787, 0.1398399876696723, 0.11662351845630578, 0.12607652906860622, 0.09639579922493015, 0.08869628594922167, 0.12410932034254074, 0.097815016284585, 0.18242864523615154, 0.08595453628471919, 0.11860432502414499, 0.13420586713722774, 0.11551722139120102, 0.10126709711870976, 0.1138391432219318, 0.15257189662328788, 0.12830721294241293, 0.12105349717395646, 0.13210419991186687, 0.11983426474034786, 0.10961121866213423, 0.09889082677130188, 0.11850160839302198, 0.09208912389086825, 0.16947022772261075, 0.14528479693191393, 0.21188927867582866, 0.10768291034868785, 0.11646175570785999, 0.16609410888382367, 0.12930178243134702, 0.21892399048166616, 0.11546981893479824, 0.1213627327233553, 0.15325242653489113, 0.15326522370534285, 0.1334982636783804, 0.0916313434551869, 0.1273440189127411, 0.14902931957372598, 0.1137677002698183, 0.12753622074212345, 0.11887333701763834, 0.15163321127848967, 0.24457452765532903, 0.14166147421513284, 0.08561830182692834, 0.1140484916312354, 0.1221045343471425, 0.1534561634595905, 0.10201883928052016, 0.12266980830047812, 0.11456465321992125, 0.20239767299166747, 0.11458456143736839, 0.13526917222355092, 0.11249764556331293, 0.1418109554797411, 0.09191056061536074, 0.0851561991231782, 0.06917581055313349, 0.10347434439297233, 0.0662601048659001, 0.13977046497166157, 0.16791965306869575, 0.12617517448961735, 0.08676586060651711, 0.1295337328421218, 0.07007707469165325, 0.13048621958919934, 0.12208550822521959, 0.17270420704569134, 0.15649317763745785, 0.08085117941456181, 0.10514550829040152, 0.10845514426806144, 0.09890405820416552, 0.11695205154163496, 0.12915638594755105, 0.05467120511457324, 0.13926050519304617, 0.11893524655273982, 0.07793043899749007, 0.1532211053584303, 0.12812081937279018, 0.15604382460670813, 0.20972787322742598], [0.030942944078040973, 0.04352623350652201, 0.08640044914292437, 0.05297880646373544, 0.061572031783206124, 0.043174653979284425, 0.030614373673285757, 0.03751211300758379, 0.12050248602671282, 0.043875102286360095, 0.023314945000622953, 0.05282384602885161, 0.05056189186871052, 0.01861742671046938, 0.05322957943592753, 0.07350798523319618, 0.06861290468701295, 0.07188251388392278, 0.038421332969197204, 0.011173869566326695, 0.044280696593757184, 0.026691920489871075, 0.03781132998743227, 0.04037417032356773, 0.06943008476602179, 0.015920021005773118, 0.010544178890995681, 0.02824422201540853, 0.0505168167874217, 0.019894868966990283, 0.025217660669503466, 0.05642569650496755, 0.03603601774999073, 0.03366890083998442, 0.014204262090580804, 0.04733900320050972, 0.029733723428632532, 0.01746122509108058, 0.05056342196517757, 0.025391591247171164, 0.03990805408518229, 0.016723316561962877, 0.05415504691856248, 0.0476522794259446, 0.037507638069135804, 0.03240108529904059, 0.04280618910810777, 0.020632869098335505, 0.015126762678846717, 0.03140420200569289, 0.07499533399407353, 0.10033402325851576, 0.08665841458631413, 0.04345856660178729, 0.034665974123137336, 0.007854278631774443, 0.018669124293540205, 0.05871525007699217, 0.07928456419280597, 0.047300177426742654, 0.04021534563175269, 0.04574796411075762, 0.04349865445068904, 0.04290068868015494, 0.031819146525646956, 0.04025338091222303, 0.04037982591294816, 0.0062332605926453, 0.011957870979261185, 0.03053260681086353, 0.01733761467039585, 0.022242961451411247, 0.05956458593053477, 0.03311555553227663, 0.1134877706478749, 0.12007035421473639, 0.00881030987615564, 0.06738164861287389, 0.04570050397887826, 0.0062580254244884205, 0.021104944570522224, 0.04639094728710396, 0.0025998762617486394, 0.044092596508562565, 0.025425115966105034, 0.049282754970980544, 0.02310029892916126, 0.04019033143829022, 0.061330663306372504, 0.02847130224108696, 0.0741733702431832, 0.05747182108461857, 0.0941598770607795, 0.042335353658667634, 0.028311517422220538, 0.03346983562888844, 0.0066135896486230195, 0.043459123000502586, 0.08331377977239234, 0.03101406472602061, 0.05158149590715766, 0.019560378344197358, 0.07303781474807433, 0.03702734044886061, 0.05593215388112834, 0.014358951111457177, 0.06034300130392824, 0.04633421836686986, 0.01738983133275594, 0.025036454500098313, 0.04617472531806145, 0.10730491206049919, 0.023028270740594183, 0.06206717235701425, 0.04111320352447884, 0.04309488879516721, 0.03601665236055851, 0.03155243815854192, 0.040352609873350175, 0.001577754964403409, 0.027130333839782646, 0.030036801272737126, 0.018428415692012225, 0.06371842803699629, 0.02806577748352928, 0.007880120637959667, 0.06081602842147861, 0.02799442782998085, 0.006163302359969488, 0.02970547940848129, 0.11593970443521227, 0.02261601491565151, 0.018927644439307705, 0.01447808150468128, 0.016492763933326517, 0.03579543976645384, 0.029404650907963514, 0.03964168159291148, 0.05603547101574285, 0.042727709747850895, 0.018006702785247138, 0.08264498851661171, 0.08452906313219241, 0.050106957887432406, 0.008319405905370201, 0.020090460078790784, 0.04606850066089204, 0.00422032199899799, 0.015304615188922201, 0.016530671988480856, 0.014375631198553103, 0.04120119933837226, 0.032575139709349187, 0.0487853107707841, 0.046097450357462676, 0.025594551249274185, 0.04851530133081334, 0.03342776645773223, 0.02698117827198335, 0.0196232615770506, 0.020881357103852288, 0.07695148259933506, 0.0506088905967772, 0.16640266589820385, 0.03941785663898502, 0.06628451855587107, 0.017916589942095534, 0.045033436202044995, 0.013055536230759961, 0.033795925988150496, 0.02664948151712971, 0.10105726016419274, 0.02815764942871673, 0.017657554109713862, 0.025267799318368946, 0.016560047465775694, 0.02838296376700912, 0.051421086836074076, 0.11130522883364133, 0.011266533701148416, 0.010324493000682975, 0.021718307996967008, 0.006712150252756796, 0.03372033718707306, 0.056978553267461915, 0.025867988987426673, 0.022786819143220782, 0.015125904332048126, 0.02706946585593479, 0.04241146832438452, 0.06972528142588479, 0.06353725240166698, 0.028537642609860216, 0.01902784200917397, 0.0489960671402514, 0.017141304311475584, 0.06032549510044711, 0.007641769097452717, 0.045990950893610716, 0.01691087890815522, 0.06487203256360122, 0.017647791687133055, 0.026273673200713735, 0.017151322881025926, 0.045684816249247105, 0.01924515811593405, 0.04609916365838476, 0.050933942797460725, 0.018000850420711294, 0.05217440998447793, 0.03610761337248342, 0.01884357225415962, 0.01311975872210626, 0.02825178937720401, 0.04597636239070978, 0.037770214157977273, 0.026804508109177862, 0.021157878783664534, 0.05809923527496202, 0.020949191946004118, 0.04385001006137047, 0.11545760530446257, 0.034417107834347656, 0.014561196955453073, 0.028835271817765067, 0.04061407995011125, 0.02136752744471388, 0.03533406648784876, 0.004718819624810878, 0.01278570745073791, 0.025419848838022778, 0.03887124239866223, 0.055881368927657604, 0.03182545690132039, 0.013832911749237349, 0.05814535530017955, 0.07200473161148173, 0.01696779951453209, 0.026595436202894365, 0.07075583362685782, 0.02932002062776259, 0.08848963132394211, 0.010877265794468778, 0.025389070489576886, 0.008957915839606097, 0.00645752447391195, 0.03764203889295459, 0.02225529552171273, 0.0767742967499154, 0.030771305252398764, 0.04446320555039814, 0.011174819515352803, 0.041785031224467924, 0.046705410948821476, 0.03660363943449088, 0.05441580453355398, 0.005562041029666683, 0.02064242965674826, 0.03994950239679643, 0.010072352780428315, 0.013837417221761175, 0.0537826804710286, 0.06387920012431485, 0.02984736447355577, 0.05707630980759859, 0.010931159286493701, 0.03283717975552593, 0.03517828841826745, 0.01951397503060954, 0.04749102218608771, 0.02429660875350237, 0.016112516301551034, 0.007693719434817987, 0.08346634158598525, 0.039176637439855506, 0.009100182580628564, 0.03760735896815147, 0.06224462962044137, 0.05995145945676735, 0.011756184078486902, 0.028941560935761248, 0.07562493306717702, 0.02657220994920603, 0.034901388455182314, 0.0632673040298479, 0.03224561596289277, 0.04894550610333681, 0.04875017962019358, 0.07329339174819843, 0.04048529739624687, 0.07181677741131612, 0.020400718519730226, 0.03243328178567546, 0.05027800978028348, 0.03837491438857146, 0.0367948539954211, 0.037026217473404746, 0.024532684657190527, 0.022664664180151055, 0.045813693798014095, 0.0747171685631786, 0.019246978286121572, 0.02018683240748942, 0.060038922620671134, 0.014050854652720903, 0.016359553938465457, 0.07792170625180006, 0.049236848684293885, 0.018481024208345583, 0.028391068867806877, 0.03287100811888065, 0.041904931754938195, 0.029054452199488878, 0.10077798872121743, 0.05831488048923867, 0.0723960834688374, 0.007446518101330314, 0.027651718451774547, 0.07500116939523391, 0.029900873745126382, 0.017049381476161734, 0.021069123010550226, 0.06456340091036898, 0.022408849692770412, 0.014001257135532796, 0.03229100995564035, 0.015938582331208245, 0.02983547654002905, 0.018381968273648193, 0.003475036521974419, 0.01628468438450779, 0.014322987059131265, 0.03515492985025048, 0.059422025723116736, 0.06469570845365524, 0.03228132047557405, 0.029984472652098963, 0.016894570318982005, 0.027793969925759093, 0.021083402780017683, 0.055864045928631506, 0.02850258270544665, 0.05244367642860327, 0.03898019815928169, 0.03721466361145888, 0.08651072465415512, 0.08297539435859237, 0.018631331589339033, 0.010154270616892194, 0.050236731102424007, 0.04185453695910318, 0.035276981336729865, 0.08862210850098304, 0.1760488147182124, 0.2070843686482736, 0.07565925336842026, 0.1124595051099147, 0.13168661589069025, 0.08484883633043085, 0.1549569879259382, 0.20165600707488401, 0.11536833723740918, 0.1497726139745542, 0.13471505338592188, 0.10698007020567145, 0.095770943111607, 0.16257163004151412, 0.23708692086594446, 0.1582744541977133, 0.16634903449032987, 0.16189072015030043, 0.08257780676441533, 0.09921832848340273, 0.12991972427283013, 0.10727186061974082, 0.13889723111476215, 0.18515137556408132, 0.060456716987703524, 0.10453548495258604, 0.14863935192780836, 0.08516208880714007, 0.13426845520734787, 0.16699927459870065, 0.13955960342926638, 0.13213777382458958, 0.15279140270182065, 0.18251937893884523, 0.17909498911883148, 0.1349889644022499, 0.12561953573354653, 0.11771754760827337, 0.1692837527287858, 0.1678995005786419, 0.1333340582038675, 0.10537531453051738, 0.07904828472861222, 0.11959358836923327, 0.18236554147941725, 0.10688085481524467, 0.1121155149968607, 0.1213908919266292, 0.09375240999673094, 0.10982497754905905, 0.22024294042161532, 0.15227555323924336, 0.1295181265366929, 0.18306101273213113, 0.1666419987699815, 0.19277137810630457, 0.1710914514426674, 0.1984939660344805, 0.09602890855499677, 0.14806225789444788, 0.14805582538247108, 0.11224287601986102, 0.15994979787085736, 0.058140551272247515, 0.19457389281264373, 0.10041404967861516, 0.07282121279942137, 0.10409867124898092, 0.11327464958386761, 0.12899456891630376, 0.06467818189412355, 0.22961356331195149, 0.13015371028866085, 0.19388998379664762, 0.17580416213188851, 0.12727564972426209, 0.2088012658059597, 0.1446740339909281, 0.1120426674772586, 0.13221009208687715, 0.14188738566424164, 0.18156288883515767, 0.11218793503940105, 0.05204322202397244, 0.16548360378614493, 0.1525219293045146, 0.18667873074965818, 0.12334786834461348, 0.09322609752416611, 0.13364564148443087, 0.13940867009971822, 0.10896955523639917, 0.13964440673589706, 0.1190959100744554, 0.11522798905415194, 0.0946196388187153, 0.193496596334236, 0.11175481935164758, 0.14895112519817694, 0.129403806956751, 0.16088758754943097, 0.1252907176635095, 0.09101767638432127, 0.16618117849741662, 0.08227252707417522, 0.12861414147274836, 0.19459623018545763, 0.15184488706290722, 0.17747513603951248, 0.08174567177359547, 0.19145556299814157, 0.1975058561989239, 0.13506338612309524, 0.17985292630536215, 0.10786615551582404, 0.27810726687312126, 0.1813140564731189, 0.08817042809511934, 0.1536978847746338, 0.12165283358522824, 0.12591731761183056, 0.11711616202124528, 0.1696936964456524, 0.14136712572404317, 0.09001265745609999, 0.20506648692701543, 0.16919759235211781, 0.14537555777600833, 0.09332439010696751, 0.23747941266213143, 0.1255908201315573, 0.07879183920366423, 0.1961412951350212, 0.13895922207406589, 0.13279585779777595, 0.0770463417949421, 0.2366877794265747, 0.16339048610201903, 0.09359469810234648, 0.06050685394023146, 0.1620191125465291, 0.15788740425237588, 0.08786312637052365, 0.10211102504815374, 0.1416235441075904, 0.13962421353374208, 0.12878920350755962, 0.0852578097422208, 0.18439142991389545, 0.11680236671652112, 0.12647409630673273, 0.09484926185437612, 0.0902812826846327, 0.12607598624059133, 0.061864202176885943, 0.10500114317983389, 0.12322738766670227, 0.1393673744584833, 0.13526716375989573, 0.08487092264528785, 0.12418512627482414, 0.15795102369572434, 0.277406177350453, 0.12179172970354557, 0.08538630391870226, 0.11247139304344143, 0.2126213772488492, 0.09331430029124022, 0.1388156304934195, 0.11125697820846524, 0.19714837680969918, 0.11264969169029168, 0.09408797270485333, 0.1698175969400576, 0.08745272803519454], [0.02152647596916982, 0.03510700831455844, 0.04039248398372105, 0.06704454563025918, 0.067687728974436, 0.053548480716667006, 0.038447022305003235, 0.02776406519114971, 0.02587768355650561, 0.06610235904476472, 0.028154663874634674, 0.027298900598127927, 0.04093606177983539, 0.07336011888193232, 0.01073060299469424, 0.007305273403679686, 0.06077139438795192, 0.045656382239290645, 0.037671945323901515, 0.09959068136023623, 0.0024863079472977135, 0.020110829700050608, 0.027121183795056174, 0.05191026647974338, 0.054231755302420685, 0.03331493626215628, 0.05313610445175852, 0.03530213462987116, 0.012063259342020112, 0.07905445939728192, 0.0427040594097759, 0.04234237310343555, 0.013467057541544949, 0.040214422824127335, 0.04401659380112376, 0.087507214397192, 0.017933773841442804, 0.025118263770959208, 0.02183302621623235, 0.028153374658099244, 0.020551975849749785, 0.08711360301822424, 0.07377125682043177, 0.030296439304947853, 0.023770518501156142, 0.057226992079189846, 0.023824979418090413, 0.004617291702223676, 0.05768941369439874, 0.022714967373758554, 0.0058386721232506844, 0.04241859972743051, 0.03987349968935762, 0.05395870263289128, 0.031526613115732155, 0.06192194550697293, 0.015503824588709643, 0.024455519958532283, 0.03223072211923344, 0.033068777328091006, 0.01232036983128637, 0.023929095527689372, 0.05621064840150731, 0.02066114534890013, 0.015488119895703025, 0.019812666145818572, 0.03064840898982116, 0.03859918378293514, 0.04536197607272437, 0.08449812872069222, 0.00247935890053798, 0.1087266600557736, 0.032169952522963285, 0.1074564221448132, 0.008733556539352452, 0.032336356450936625, 0.009475254686549306, 0.023682471797136322, 0.0279374716005155, 0.05540176680577653, 0.033260775596967766, 0.025423368738432015, 0.029853732524705783, 0.02708945719392172, 0.08095456779535327, 0.0393143495145653, 0.038213867494570355, 0.029226596533719982, 0.02220354535217796, 0.008563424909620412, 0.03701604623347521, 0.031047621675367867, 0.010020226872126971, 0.04555673937180212, 0.02809914105039622, 0.05666380801371165, 0.018542245030403137, 0.014701227923589093, 0.037371741075600894, 0.026665498336244906, 0.056236042574580224, 0.030433503378714834, 0.010864855388977697, 0.028906480675297122, 0.021802054485306144, 0.03476087063817041, 0.022000744805804322, 0.00548768589007003, 0.018254671711474657, 0.04361967117126499, 0.017573548081730093, 0.013463319661760969, 0.0627894660990153, 0.13481323740312032, 0.030221871699073484, 0.03529842982866934, 0.039221383431660276, 0.03918983155329313, 0.05628245436985578, 0.01782058402230697, 0.06296883004584483, 0.056314484615411074, 0.015010331158659287, 0.029048867856285403, 0.026265510424439396, 0.0355081989296845, 0.008183219686283596, 0.03576785731794579, 0.0279835576989821, 0.041431215924343893, 0.04899060832602637, 0.03759160677769354, 0.059398019154156954, 0.04438872276140111, 0.0660274623494063, 0.033125719986855984, 0.02845862042158842, 0.039592053541647534, 0.021290773259741918, 0.022777005830513578, 0.01517211935216827, 0.048651313675301414, 0.006317466788459569, 0.04326490931478994, 0.03210603113153151, 0.023361506073602607, 0.0413203636583473, 0.02921343973970839, 0.013983160606585443, 0.0428926751815847, 0.057064306523118696, 0.07774800807237625, 0.032734737931085486, 0.015682372597179244, 0.037161300224917274, 0.08358762972056866, 0.02394192323221692, 0.03442229862724032, 0.06695394084921905, 0.0422262791544199, 0.06497149901198489, 0.07948639443410294, 0.023739794435511743, 0.03673672390037349, 0.019640123172264014, 0.028652091111455644, 0.05651728516178472, 0.008748463953712156, 0.06020921455430133, 0.024908238522974507, 0.02837458555586636, 0.04176472606403487, 0.013574019257378365, 0.022111200128815005, 0.01875414982038949, 0.0500633823685348, 0.022580422361248305, 0.04777832409100873, 0.07775428452129875, 0.07190345347459827, 0.03965950331517628, 0.03457169846764632, 0.027941330768434063, 0.10820104647427797, 0.03366837158266987, 0.025370702546622072, 0.02818840233209942, 0.026136680373123715, 0.041440043664936504, 0.05215483085651483, 0.019843797332474163, 0.030899243030164922, 0.03311488038993307, 0.02788165022086884, 0.04535219159775546, 0.021067637018859386, 0.030760424943374734, 0.053195951240403314, 0.03162122803873249, 0.07544517557003669, 0.03940149037433522, 0.0260946909298322, 0.026396771327459385, 0.09791716973164252, 0.05325706349685788, 0.03633605236453669, 0.029873847695333616, 0.025784990583945597, 0.09420459930385862, 0.010044586279296448, 0.023986962690417255, 0.023705182364210486, 0.040043262365673266, 0.03617119888908096, 0.01917762861454061, 0.023592565907165408, 0.05667844062138881, 0.021886676283819333, 0.007690173241176775, 0.03673659497871995, 0.068666393602533, 0.028410047492278472, 0.025619838553081666, 0.0015912094656544337, 0.032686205713876655, 0.04153264673160655, 0.00904145198208945, 0.01339289196766913, 0.04339004474292908, 0.07268697143133197, 0.01506651725087847, 0.030300273027803217, 0.05512664121176515, 0.04105834736089621, 0.02588016869101141, 0.029853138806564466, 0.04124317351462586, 0.003094462981347793, 0.055387395434081554, 0.030622132721224, 0.027095913454624157, 0.021327120684353367, 0.012191002889137183, 0.03089439489745668, 0.03816210884334786, 0.02900812861376575, 0.05929465791476624, 0.06627845923815455, 0.04357208551040717, 0.0346789952101452, 0.022609148141262785, 0.051688324460493665, 0.008034500925402557, 0.08270853332110814, 0.07774070703557559, 0.04150292011243956, 0.021764149822826897, 0.04729760577902198, 0.08129880218101398, 0.047967913560569286, 0.04861400442730103, 0.03357614849561027, 0.031818244074072154, 0.06178238442433732, 0.033168240383799584, 0.016925536960895573, 0.03349835106304713, 0.011513154887195145, 0.009060479800349899, 0.041150679013558795, 0.0727703905265246, 0.04935946674751384, 0.050978373270481825, 0.02731318206393293, 0.05279826865132366, 0.04458463278466037, 0.04504055742706571, 0.05701858004821198, 0.017150223654295717, 0.05800121410616806, 0.038890465295740535, 0.012880463169754615, 0.036829170903989246, 0.029271420557051897, 0.013643877830223312, 0.029555309430829117, 0.005318708618038467, 0.012076523005297142, 0.06728210074028798, 0.004224153601431421, 0.06131649549518313, 0.030536946042307785, 0.04753140519772257, 0.07215702201106719, 0.0373398601077497, 0.002852677841604288, 0.05363770128626909, 0.030692605368260826, 0.018100897016535913, 0.019088818558624814, 0.020505874484245266, 0.0516227915483926, 0.010155754064076712, 0.015850242160792862, 0.048287510339702876, 0.03552334722397583, 0.04420655985761966, 0.0313569081148931, 0.03974898512076054, 0.009534288081340492, 0.03096322888242347, 0.05669884756207466, 0.06129751008536134, 0.03135709131934813, 0.06813702093703405, 0.028160490794107318, 0.0052039276342839, 0.022365241943459426, 0.0416721840655165, 0.03355587047657796, 0.016292328081492866, 0.012077411038002797, 0.032995868740337234, 0.010020376997999847, 0.061012545733579567, 0.0052775037308622685, 0.08823237155697175, 0.08878122496285609, 0.01637264118263764, 0.01041927162025656, 0.022777309474934424, 0.05243359000555106, 0.02644557156600058, 0.005712627882270941, 0.08089609843279634, 0.008533847568157529, 0.04693604500166007, 0.08692461744483028, 0.03659205684172256, 0.022152682367180074, 0.01313930137881211, 0.035738239264381785, 0.05060826973723514, 0.021279407798179557, 0.027000597944217067, 0.0243644435956542, 0.007185641742710556, 0.0610968197828957, 0.03475305052208049, 0.024705102101766636, 0.007749469568287688, 0.036188454034605196, 0.13551381123917444, 0.15931984595954418, 0.14424885037754262, 0.18537073236490997, 0.1337731382144349, 0.08704390390110867, 0.10889962541737727, 0.22002929688564368, 0.041701768192329576, 0.13201451115310192, 0.12678494676947594, 0.1613526011684111, 0.13002444936760835, 0.15068744202809675, 0.11338115244039468, 0.1387528252920934, 0.08391148091426917, 0.11883164782609258, 0.20430449210107327, 0.1394660198794944, 0.08067902829498053, 0.14216479792126588, 0.11147389906857695, 0.15069512304450783, 0.1311157236674002, 0.24026838157858166, 0.15031009513352597, 0.1599196166332279, 0.1297232883849314, 0.11816862411797047, 0.13015634300453321, 0.18443486972578935, 0.25818583156381336, 0.11484173978013651, 0.10275306845349924, 0.14326416035848005, 0.1291320672524827, 0.08007956974740539, 0.11949244593935353, 0.0662687901141388, 0.1037257823294827, 0.13956887221762113, 0.10819271406424896, 0.10529177329902138, 0.1436553629381316, 0.17393083551100322, 0.11648165035460677, 0.09679170405226094, 0.13930686270552023, 0.14122813461082323, 0.11574682407081127, 0.11999418187354292, 0.1596605519631079, 0.18243547129843915, 0.10945605805941991, 0.13264990491526468, 0.18421867489814758, 0.0664164393341967, 0.15616273108337606, 0.11924027518502303, 0.09006906407220022, 0.07838858584208147, 0.16574762176190103, 0.10480563009956054, 0.16523676631706102, 0.07388698096786227, 0.13806096384567873, 0.17866562572973116, 0.27916019037365913, 0.11466089662696634, 0.09107573184051684, 0.18640020569520338, 0.16052075794764928, 0.18425566862736428, 0.1147138766412224, 0.19253956340253353, 0.0716730026262147, 0.14277832928512776, 0.15320970597011702, 0.14343319700232574, 0.142435221267598, 0.09622617904096842, 0.1955776768071311, 0.08251248419817005, 0.12603602052799293, 0.056621664203703403, 0.10935337535504784, 0.18397951844547475, 0.14719063895089285, 0.12232835590839386, 0.10833680776080915, 0.10387235267886094, 0.1011414731453572, 0.1178619670016425, 0.17526360042393208, 0.13162306430084364, 0.13988421458218778, 0.18384111087237084, 0.12958794779011182, 0.11803754472306796, 0.16198507722999367, 0.21697451866098813, 0.12110934060599123, 0.09421869247619595, 0.16419080458581448, 0.12066499516367912, 0.05279460456222296, 0.20920284997139657, 0.09393526161355631, 0.2455172570688384, 0.13906427286565304, 0.1379150381045682, 0.17122382005410536, 0.19565622402088984, 0.16197553702763148, 0.12495940258460385, 0.1282649537814515, 0.1674251774592059, 0.218001535694514, 0.1287247562514884, 0.14392999320157937, 0.16629557950156076, 0.11668255100292818, 0.10769520540322576, 0.0934668756755335, 0.197617271648986, 0.09447054431906768, 0.12242103022124086, 0.09941107992615018, 0.06403543281235866, 0.15606298643563474, 0.07703395174550158, 0.1718877394284521, 0.15756405517458916, 0.13941115353788647, 0.15154197545988218, 0.1809749382414988, 0.15918485820293427, 0.1259486795003925, 0.13518450462392398, 0.0727378615577306, 0.1116744875907898, 0.1215714229536908, 0.12315546295472554, 0.1169174462556839, 0.05587455304339528, 0.11985787775899683, 0.06432433945259877, 0.17146754983280385, 0.15685991224433693, 0.14232531216527733, 0.2048813690032278, 0.09007791895419359, 0.09304560042385544, 0.09994531768773283, 0.18418510098542484, 0.11106223187276296, 0.1322254812611001, 0.14833857092474187, 0.07431443088821002, 0.2800811252423695, 0.27369377655642374, 0.10983641764947347, 0.1527429824428899, 0.12131507242364542, 0.07779866071151835, 0.1429808719881943, 0.08928162418305874, 0.10220798091696841, 0.07446957113487379, 0.17831736084605965, 0.15482205445212976, 0.09100890292653016, 0.10635656437703542, 0.12383285803454262, 0.14070832250373705], [0.018280944587396722, 0.012092219216616025, 0.019360325864649246, 0.06270802154072694, 0.02092107684750642, 0.00624279019289783, 0.06942490075847932, 0.08028611580708198, 0.021670500115890588, 0.040627165497945886, 0.03306216500433428, 0.05951184340353523, 0.03529059953455414, 0.029286433144339492, 0.0889848872487034, 0.06157020652400596, 0.05303818167054227, 0.020298680423625877, 0.03571551512660725, 0.02733578236906656, 0.048518497230751176, 0.027883019165268967, 0.026274802961519787, 0.06352482164012534, 0.006380061219845499, 0.026284546724387577, 0.04748309689706989, 0.04656255218599524, 0.07232721894979477, 0.04862465742709381, 0.029000400099903345, 0.04490479274785944, 0.010557648659284626, 0.04282939161307045, 0.01931845855766109, 0.048401273520929475, 0.1384476880942072, 0.04203235723876527, 0.03488175843709281, 0.027786840219050646, 0.06146682492856469, 0.02292120809267674, 0.030954343466354266, 0.0462768143042922, 0.03578720574400254, 0.044914214206593375, 0.06271880346217326, 0.04410884742225919, 0.018410899310505817, 0.05019840405189565, 0.01726465010350304, 0.049792724927621226, 0.0669329334050417, 0.04743997599663479, 0.033040825077997785, 0.02252395637333393, 0.03399654843711427, 0.04367870032521231, 0.0030610220190802856, 0.025085918006620238, 0.0431619619817606, 0.03200114658102393, 0.07549086811819247, 0.05580961724211063, 0.019873686800045625, 0.044559537166995664, 0.031056191572653394, 0.011240297296483601, 0.08626131553735052, 0.025671888974362185, 0.03887801757082343, 0.05509242269077471, 0.034106040240398476, 0.030448539714728082, 0.015885787217744758, 0.07287785690277815, 0.049661448757563315, 0.0833434656794582, 0.018448254359619956, 0.05529325548559427, 0.06529191681849104, 0.022106114508850232, 0.11178846111787216, 0.0249631404876709, 0.05359792895615101, 0.08763167129031249, 0.011425721409198428, 0.054662923594670634, 0.034257604607513974, 0.01763863316071885, 0.005668844986108265, 0.031043896518115486, 0.038025540100144486, 0.04418392053672245, 0.029874665330031087, 0.05173672775604895, 0.019191933829071264, 0.04176634097737925, 0.033806623092719486, 0.009538484820430832, 0.056721676872777085, 0.07085120172372886, 0.09620337347899165, 0.07778174483350345, 0.04894376566101398, 0.004894577582100672, 0.06372750005019562, 0.005154474729871643, 0.04593991148950798, 0.016756909134398614, 0.024556536859433566, 0.03414236900529691, 0.06191045790910721, 0.03398044001577156, 0.06645331771246024, 0.040417080878147056, 0.0599180483924491, 0.061751382159335275, 0.026133279216342738, 0.04244609396638615, 0.03272290088768516, 0.01778908642674131, 0.09121949305491787, 0.06558993618403162, 0.003204021577922893, 0.07197916441197906, 0.029421549822602953, 0.06302857505423681, 0.01031661860179156, 0.016880774005715336, 0.005733199791783201, 0.018005074301202382, 0.04077692496191178, 0.008778659610210784, 0.07620331631707293, 0.023813798857320632, 0.07844775409570762, 0.015339992308456982, 0.03122566926426121, 0.04126163984515837, 0.030439722152160745, 0.041815544944256544, 0.05922551519636597, 0.03226935451052018, 0.027081572617005025, 0.004078691384555506, 0.059056682113025866, 0.07461650789316211, 0.017952375878979052, 0.08289625681936741, 0.0724761506010379, 0.13257622958293983, 0.023506322409957647, 0.020093233590679507, 0.08933083154261112, 0.029787619465163777, 0.04989795553098832, 0.0202842106643532, 0.010940208399136151, 0.034160981220858436, 0.07669262827507087, 0.047245161807430644, 0.003605830084000315, 0.03803325165063143, 0.06815589778125286, 0.011495836129012917, 0.07094857828425509, 0.031244566464530568, 0.07856135442852974, 0.028336931951344013, 0.03112526304487671, 0.06392494016992194, 0.06390853997852121, 0.03670496167615056, 0.029500185245914117, 0.07372783736458846, 0.0226153414696455, 0.007374189661017486, 0.0522929025547845, 0.014424088776909878, 0.03855719942865627, 0.04477760814396398, 0.02518586621486715, 0.029277958241956573, 0.026461177871429493, 0.031295802643788714, 0.03277341442714844, 0.05124563464362707, 0.08780498949012586, 0.03160023755793061, 0.07023522084844963, 0.02811567355612559, 0.019231302430853248, 0.040128398154463084, 0.017912785056978464, 0.014958645449951291, 0.04068294446915388, 0.03004400052928499, 0.03849570040724107, 0.04698682316978063, 0.04323529804657612, 0.026088353412758027, 0.021978800983301232, 0.050131914405418296, 0.030092539531844, 0.01873611775226891, 0.035012457852384875, 0.013287289866379328, 0.023832422947244983, 0.017566854333771125, 0.009483662583599133, 0.04479399137198925, 0.06228056483502899, 0.020810892938503196, 0.05502149881795049, 0.04002419553164925, 0.029249707436455146, 0.04238531758476581, 0.035568289990936, 0.02643791938732777, 0.08847437107137271, 0.030367118905165365, 0.05137638155637043, 0.0793677865128432, 0.047322820140314956, 0.006101930563870285, 0.026632765806945305, 0.0037651272058220847, 0.10996107131774936, 0.016030449187383056, 0.010889668566440898, 0.08320633375218936, 0.027735634573868344, 0.03843050336997424, 0.011495799657755663, 0.05859400943986007, 0.012183187862059899, 0.015449786059824484, 0.03332264781264322, 0.04116161021270922, 0.04554358257779053, 0.029386717227420638, 0.043138148795281134, 0.03917748221595373, 0.038696746940591505, 0.04062583896198443, 0.03029553685337305, 0.02650490097169365, 0.01638223566780133, 0.031932461873761246, 0.02901639656296798, 0.023993074594597732, 0.034242340962269475, 0.03248875880880015, 0.008953341665411634, 0.04464122599789074, 0.025257076768736755, 0.058799062722495625, 0.05220593472144433, 0.05989728522087846, 0.05367547533075724, 0.007220139311227415, 0.040328067261725664, 0.08169335672365767, 0.02274595606806023, 0.013697404065169394, 0.061036213035030026, 0.0542637753699507, 0.029486390628984997, 0.006491745115324322, 0.06087424672607865, 0.037953455932438374, 0.04282548325136304, 0.01815023329774184, 0.0442996650402035, 0.03144134161993861, 0.012570922279597392, 0.03279717333082642, 0.05938606336712837, 0.02705306396819651, 0.03453951215903674, 0.03783856977575591, 0.03042153062831078, 0.06139521912804671, 0.010027236138869609, 0.03446463242705379, 0.020341107522004416, 0.02954941974686725, 0.04419806459918618, 0.028087931651888148, 0.053207866315330775, 0.042845476285687516, 0.021473553630390337, 0.01664898813968258, 0.02837420387991837, 0.014077211497351527, 0.01733538568285959, 0.008161800032082413, 0.01747330471075007, 0.06785341365528957, 0.0063207771911818, 0.01736821829607444, 0.047839273499058824, 0.012962934012258691, 0.04653186543977686, 0.007809419833522822, 0.031160007430506603, 0.034356477337756326, 0.03865408744396908, 0.04407152799623353, 0.08331187987434012, 0.031288681418768, 0.02606009242923132, 0.026996728598273227, 0.10772976997707572, 0.04542170751041599, 0.027898104695071067, 0.07614025327243976, 0.03532691133607711, 0.019832365713747482, 0.020827089569398334, 0.014653552356841308, 0.02970899421987789, 0.07262462763381855, 0.0722691227814981, 0.04735360188143594, 0.05632645397314003, 0.12276801945907728, 0.04765423360679831, 0.022107342657233988, 0.09797775612345763, 0.039135816773133617, 0.01676074624992907, 0.018395467727844204, 0.007986972940021327, 0.030469380917825868, 0.06337406472968203, 0.04018885901729975, 0.017820952127554586, 0.035796399893505235, 0.03299097650285278, 0.04050344481532063, 0.014614753724474992, 0.01587773809608604, 0.04209632273497326, 0.02565520888726626, 0.030100529281688587, 0.014026479130344731, 0.03873898574550237, 0.0416906096839479, 0.030874792020767927, 0.03602431980626924, 0.0751815986420427, 0.06490582360752992, 0.15164154368851865, 0.21394103286521776, 0.07019326024289642, 0.09349949285387993, 0.16274918908519403, 0.19305477504219326, 0.14063912550253527, 0.08177183608391456, 0.15482636993484838, 0.0909235839332853, 0.16279193679136889, 0.07471860705741815, 0.23926938804132597, 0.12044818965452057, 0.13540690126163618, 0.12676461786031723, 0.09131180095885481, 0.09912285182092871, 0.1181197560259274, 0.1720461637846061, 0.12903568813843386, 0.12791330979338714, 0.10673601473016398, 0.16937797410147531, 0.1246098620550973, 0.10705540794879198, 0.2041128602411066, 0.1368730661592313, 0.09170499164611101, 0.0949628214750971, 0.10819851553865842, 0.17626509097005638, 0.12880866389189446, 0.12205344066023827, 0.2349033137517316, 0.1491650537188564, 0.09391659511519329, 0.11225105236683573, 0.1155978584928172, 0.1634578239172697, 0.16279337528560842, 0.12796038655298098, 0.18211949111095496, 0.15711083449423313, 0.1095086716647659, 0.15359465245689663, 0.11698098427483014, 0.12247741648129054, 0.13577230593987874, 0.07778589746781758, 0.28526676126888817, 0.15364486404827662, 0.12422776541539601, 0.13971253165176936, 0.10294036447469677, 0.15088566924844468, 0.1808989830315113, 0.1267952062189579, 0.12484319667731013, 0.09006407005446297, 0.11249858194163867, 0.1642127755497183, 0.18607359964932713, 0.07397101074457169, 0.12833576569599764, 0.10887397000832216, 0.19932305440306664, 0.12674637883901596, 0.11166603304445744, 0.2115822144384895, 0.09801119432917663, 0.1762964664293187, 0.13600759474294527, 0.12976086565426417, 0.11150525417178869, 0.1195172124675342, 0.06660109585417168, 0.10209904211972441, 0.13470908227775777, 0.1263292155095509, 0.16272234623985632, 0.10898734642458813, 0.11006970477423497, 0.07944503772471632, 0.11838707168187414, 0.1796266891594444, 0.1657424106129578, 0.12781802990606853, 0.12680589993085178, 0.11138115690222808, 0.12711947810436997, 0.1360392009041139, 0.14488831534981728, 0.15905779573534215, 0.09722680106226887, 0.13898926760469163, 0.1755684254957097, 0.12470721825957298, 0.0970629280699151, 0.17780068357075962, 0.10018689651042223, 0.08424783750836339, 0.1486123598047665, 0.18311646261385509, 0.11960612769637789, 0.08128550289464848, 0.1166408753820828, 0.1305561629789216, 0.09799733864409582, 0.13928905794663088, 0.15470573997923306, 0.11476995077516351, 0.20803719466286047, 0.10908988663660628, 0.09144152328372002, 0.08244278508105449, 0.1156753200505461, 0.1902878585138491, 0.1266769239945071, 0.04702688726995673, 0.16513322187321527, 0.15299328044056892, 0.07155712920108012, 0.1849879707608904, 0.13267309724220208, 0.15419616018022808, 0.18309677152761392, 0.09397137324724879, 0.13518618739077023, 0.13476472214928695, 0.07728367977376495, 0.1462315432727337, 0.15002660320273467, 0.09032246976026467, 0.17323668061622552, 0.1498743670859507, 0.2031918710895947, 0.08294566773942538, 0.11780646283711706, 0.14282136197601045, 0.1205613828663315, 0.08444341165678841, 0.07275511670325484, 0.1688497345894575, 0.07882172188588552, 0.17088107844548567, 0.099155536852777, 0.2535471761865275, 0.16524870853338922, 0.3097078097718102, 0.18260966480842658, 0.07381933102650301, 0.18696121844862187, 0.13329186689640793, 0.1089927339926362, 0.05322621390223503, 0.08668651950678655, 0.10077503030853611, 0.16378661484590598, 0.11878535816712038, 0.11951101065746375, 0.07596461448286261, 0.13131779139595373, 0.17486253194510937, 0.14367672322051867, 0.12757720425724983, 0.22124563876007283, 0.15760094033820288, 0.12086706289223262, 0.15038823522627354, 0.08854104392230511, 0.10010908211448363, 0.08220124018511601, 0.14451281407049724], [0.04658597521483898, 0.046193853220237155, 0.029730944827731167, 0.04000712698325515, 0.037924499450517554, 0.09030442751411881, 0.008958530761966748, 0.025793480753366436, 0.028440235515258143, 0.017584421605403935, 0.037081277197492976, 0.042406705008553605, 0.028282471034409742, 0.0497558397640075, 0.017033181452591504, 0.020458361765901958, 0.05739102113459792, 0.034964509175292084, 0.03910355582567198, 0.03263272697638188, 0.000930268011870794, 0.035665910824068954, 0.0571956369759781, 0.02272682816588453, 0.020071888575330377, 0.0398360106295773, 0.044305822745497735, 0.025456632221383706, 0.025944330962374806, 0.051716124040207694, 0.009781067026779056, 0.01390721048561058, 0.08059593489659683, 0.04696111008524895, 0.014390550487275635, 0.04475844970771244, 0.04064284644222685, 0.02240894638401057, 0.013645912587110485, 0.01608983287587762, 0.027088602239798223, 0.014534462675718325, 0.03187344289783921, 0.018780699199331657, 0.035562586904104264, 0.032815439493528435, 0.009618216925965888, 0.04376393110890474, 0.05237847939133644, 0.055876727748130045, 0.028147885309798375, 0.07704639607774359, 0.06631911705647196, 0.015153044036456516, 0.044025435112416744, 0.03812968504748174, 0.06451646664312907, 0.03218075480046017, 0.042812865892691274, 0.053516898304224014, 0.04192693664559296, 0.04682685514645917, 0.05186423466407827, 0.04070284250857575, 0.030848943229232515, 0.051922005135565996, 0.03017895096646888, 0.03068177934203829, 0.05215469854218619, 0.05120226607791015, 0.06823254509695939, 0.047941050359180996, 0.04059604788199067, 0.03815740320299353, 0.028007698278608065, 0.05053229756387217, 0.027583171147853136, 0.023092606038387333, 0.041077417587595325, 0.002612203122615548, 0.02280771462912006, 0.046620366762259176, 0.07360966370574065, 0.07028259616345167, 0.005846049919325326, 0.026495114800387194, 0.00922683029369052, 0.04834640717932156, 0.04009770123021943, 0.011790172745739775, 0.03661819740331598, 0.02524025079661182, 0.03239528721730624, 0.02103483833239547, 0.0863356219072427, 0.06732698583177157, 0.02521855803206563, 0.05427112729687776, 0.06940639710852078, 0.06582421396992036, 0.016086450378809656, 0.025520533256764923, 0.012717826807472323, 0.03484454757667013, 0.029880280207310404, 0.049894885160028934, 0.01081703054452581, 0.061619271391204426, 0.039093455831919394, 0.08197468412773949, 0.05977590887674263, 0.01400771678891033, 0.027011473164228455, 0.07066013983317784, 0.0511881864762732, 0.047230817577136416, 0.02951853283281837, 0.01664023843061711, 0.021291146454002177, 0.05157427629455924, 0.03840477332206709, 0.010066131462476082, 0.05699365067162684, 0.09575132666421787, 0.017261016548478177, 0.02465846130092229, 0.028964777011424303, 0.07551843021064997, 0.0419229536450335, 0.04486949535618935, 0.03911675333178469, 0.020784467392201935, 0.03823291736521891, 0.05228270078077912, 0.036541465270732126, 0.026885258865409663, 0.010721045828956579, 0.0677295538729855, 0.007715014408209494, 0.03754390576588256, 0.021455426567367146, 0.04562882353950824, 0.014606409440083163, 0.022656947540651475, 0.015832554449194243, 0.040921378282031844, 0.014968306092279298, 0.04089560412934848, 0.018906528429527367, 0.030483894781874757, 0.032777760443942885, 0.027475845567615967, 0.02482388474579368, 0.07588427593665463, 0.03293165897152253, 0.022414296632632613, 0.005571713970441903, 0.02743961688663278, 0.0031905380268913825, 0.029353631859911338, 0.014871884569791811, 0.041608642653695176, 0.013814944990112312, 0.03722634119912982, 0.03961449948006442, 0.05224132710801704, 0.06911991283829723, 0.023476539811651622, 0.03549891996330448, 0.011343488902119654, 0.06644244758146149, 0.011922481137194803, 0.03637637770069497, 0.043412986011909585, 0.04501724974917514, 0.01569097302854061, 0.004483665680579309, 0.04834575917837875, 0.011880022656571652, 0.02962310186454228, 0.01608637404362006, 0.09468456783464976, 0.04942229569756559, 0.08193611619727952, 0.02520584567849125, 0.02422866364941001, 0.0516674221892442, 0.06370283530226775, 0.019640920450910926, 0.034832825884222984, 0.0338348806835711, 0.04953372471832803, 0.023476147957678353, 0.032648265428308926, 0.0353664767130145, 0.04197604222489255, 0.025455991005791084, 0.028554667053478103, 0.02940118020134313, 0.05446295253932476, 0.03698696082990084, 0.07532595696726016, 0.03803475460569773, 0.012420953317944492, 0.03177814943982022, 0.07017776928842068, 0.050505183304526975, 0.062468145840934346, 0.041365869609372954, 0.008571395999751985, 0.03163692933906402, 0.006489749798285109, 0.06634172584329333, 0.01578959300448852, 0.038495547736861875, 0.03209887597975986, 0.017160988612366573, 0.007653246517293155, 0.06468635824109827, 0.014713521281789457, 0.060704558688615046, 0.03317733953839966, 0.05733226000198296, 0.027614639905680503, 0.06298257037997246, 0.040595399881047864, 0.06516701209225825, 0.06648663378187589, 0.08467654950384583, 0.04263491669137563, 0.012767292010331792, 0.025196168072787777, 0.0409245640039444, 0.018420855115566934, 0.014609914073454482, 0.03388922794588974, 0.051726736327899356, 0.01908662180150194, 0.08756459131836891, 0.0625981938626085, 0.08431940938213042, 0.013373730986911272, 0.0448627948228802, 0.041993151485387764, 0.05389996185632689, 0.041664065394018374, 0.07593316438474826, 0.040767995441066365, 0.0010965012458785037, 0.04723523484010782, 0.02045970526523888, 0.03622646556634988, 0.018858932590644275, 0.04769080664430346, 0.057797585747071674, 0.07602957064019782, 0.020665068977645466, 0.05512825273243444, 0.007695333499993596, 0.007945788408895689, 0.04276402494204896, 0.007201314205303788, 0.018747009935655763, 0.030610153185469762, 0.027626164822972248, 0.14245664940348693, 0.023573634780145118, 0.035840209506984265, 0.010038298804179897, 0.01769939936431391, 0.01546021514306111, 0.024533726208444153, 0.034652542522443194, 0.07324005889573268, 0.0443845599490617, 0.02785480228651847, 0.04552297207659908, 0.03182153157623751, 0.07054337752716881, 0.01667600231511252, 0.05966095147388322, 0.03310953014131103, 0.03875850719798889, 0.044743264093995094, 0.00551419922183933, 0.04865922200094376, 0.06349734775722027, 0.019600430570010628, 0.02959367719345859, 0.051134768806930096, 0.09078579382704836, 0.010102407640910574, 0.02681436891933637, 0.05062264110893011, 0.05560603638046554, 0.03198658861219883, 0.012956712694306458, 0.006004529406449625, 0.05548758112958499, 0.0032192313644502845, 0.018520993313619068, 0.05314217734017542, 0.025027618277817965, 0.05750338653368609, 0.020682000122698288, 0.021122864680364728, 0.1076016557802047, 0.04495152684726885, 0.06477661696927887, 0.02837939467281103, 0.017225848078461628, 0.052461114778582535, 0.015028514200821519, 0.0511826632012214, 0.08054862743509666, 0.01442664346125509, 0.05325125862977334, 0.08792602656675236, 0.022779133037797043, 0.07816333935729095, 0.024591372847290974, 0.017575264775327275, 0.016913728755233542, 0.03373047789292676, 0.029278565530798266, 0.01956606955666627, 0.002297882589378527, 0.0194090701240514, 0.028235448557617407, 0.038384010150496445, 0.04713028922144856, 0.02253156783990562, 0.0536691208503076, 0.022778488429529325, 0.021799245350328938, 0.008494362767253603, 0.09352483613682644, 0.0034058600888654056, 0.029384559486061335, 0.024056442979989306, 0.03161576583183237, 0.06221967310245548, 0.023638046413127865, 0.033454578768994124, 0.016390386569712843, 0.010428727005741425, 0.024290301770504032, 0.08139890645231519, 0.05388547174100365, 0.04752608887585146, 0.031204794134412493, 0.019881703691290956, 0.14730284150157655, 0.171742302232555, 0.1362313348799944, 0.17047463596931525, 0.14928808568843774, 0.19499895428972586, 0.23891481278198107, 0.12534653395414352, 0.0733758405383144, 0.05187006667256355, 0.16568943059870175, 0.16373485619468348, 0.0828627779015473, 0.09282437086637531, 0.06806884852371045, 0.13063275601182664, 0.21643280344349997, 0.07431837317666837, 0.126261904835701, 0.11029835071946893, 0.09775675048253366, 0.16352277328925474, 0.16271448880434036, 0.1542555998478617, 0.10881980934313365, 0.19620688232992375, 0.1537336842822177, 0.11319755443504878, 0.06330013155405011, 0.18044999640967163, 0.1863562094845942, 0.10117320822817938, 0.154971644282341, 0.14767972699233464, 0.07309569378516503, 0.11830806306430272, 0.2570300692958491, 0.09053694110895906, 0.1152332816272974, 0.1862356745238815, 0.07770122308284044, 0.13851996564439364, 0.19403725303709507, 0.11663623420255524, 0.27285958560449736, 0.0892448882971491, 0.20903563180140086, 0.10106754675507545, 0.13886680560452597, 0.14105400895433767, 0.173723502350705, 0.1929898935237101, 0.21401856227644853, 0.08218035487724201, 0.10478477193308727, 0.10677101356642586, 0.14087902834372862, 0.135885729853596, 0.12918461300432682, 0.15121520656560147, 0.11955337838402816, 0.09072436605181013, 0.14448821039072104, 0.16956838459840842, 0.12746671161481313, 0.0998577323875257, 0.16529953080628598, 0.12667435913213662, 0.094783946073481, 0.2586814878242356, 0.10723260736891202, 0.14229983996067727, 0.12249121788356986, 0.1617321465164423, 0.12986346014908381, 0.09967914875596762, 0.1218758544751576, 0.14025204841579708, 0.12510228848883084, 0.1855155045964888, 0.12670008918004377, 0.14876788003104074, 0.12435450218617916, 0.09082876544977937, 0.16940928170723574, 0.08711175740297351, 0.10065142158418894, 0.1311398795140641, 0.10899056946592671, 0.20723038938428673, 0.06551155181867735, 0.09336349408009223, 0.14089577458798885, 0.08805793377437762, 0.17099296887006077, 0.13810805417597294, 0.09574993566742965, 0.2541624717414379, 0.27163493846143993, 0.12140819456960474, 0.13205622748604842, 0.0910353386508567, 0.13067677936383656, 0.11093871135796819, 0.1444937065243721, 0.13916754589549132, 0.06846309772559575, 0.15580366392220768, 0.1228816197918994, 0.13900933867054327, 0.16832363924809865, 0.11799076651888234, 0.11869661935738154, 0.21649041106658323, 0.1458127378885235, 0.18002247863582202, 0.25380482950380867, 0.0907890440097877, 0.16975085623562336, 0.11459984204598836, 0.16356884581702097, 0.12580516934394836, 0.17555218136736325, 0.21711650889899048, 0.10058470123580524, 0.10823987224804503, 0.1872053960604327, 0.22761499269732408, 0.1307711771556309, 0.10709456620471818, 0.1682199455265488, 0.15206412172743253, 0.14147817476519517, 0.06859938148409128, 0.10270077375961201, 0.12262590708477156, 0.09129102421658379, 0.15210619089858873, 0.20257255860737391, 0.10955728869885206, 0.1274721398949623, 0.11736185955149786, 0.11941057390400342, 0.18948272243142128, 0.18407003501696245, 0.10810721186654908, 0.0708468658849597, 0.1000225960410067, 0.17573542653449944, 0.1040962285229138, 0.07873270487678902, 0.15309307937111172, 0.13432045813117707, 0.16395570577255317, 0.13812575036925928, 0.07119043530630213, 0.09138407172369105, 0.08010234138263123, 0.05579006864822336, 0.1717683986893722, 0.2105312179774046, 0.07637877190219504, 0.1161139929401023, 0.12458128216011183, 0.16488652011113508, 0.17322876889790806, 0.17433750868907996, 0.11280648756240096, 0.09648054146340915, 0.055510210272456915, 0.12341274986309664, 0.14738459140062332, 0.2490751961512225, 0.10533840901085309, 0.10707852563687734, 0.12749987840652466], [0.04836427979171276, 0.024023259224902307, 0.05362035453851734, 0.01801512510116611, 0.03483918036467262, 0.0617499640211463, 0.00935159676841327, 0.00973058826223548, 0.045021711116922755, 0.013178357006316739, 0.0484333885833621, 0.028328307771256993, 0.008924196041854364, 0.011752323214230793, 0.06499106796192271, 0.026185461951951896, 0.049656777043959925, 0.02689245472928243, 0.011956523239080395, 0.023715952411293983, 0.015783604932948947, 0.04159791501505034, 0.030417279606418948, 0.08838901815137692, 0.036615978593805006, 0.023764632209869366, 0.030606943714831556, 0.07170747220516205, 0.03648435637088759, 0.018033808562904596, 0.015561998788533466, 0.015764785764206733, 0.04780065467847245, 0.04573305669639792, 0.02534926762538297, 0.045285915689808984, 0.018898964460406984, 0.06355691634650741, 0.03386375234861459, 0.011468838916958442, 0.03123245800712279, 0.06423605526132242, 0.028812523931264877, 0.06689114243324314, 0.041102241791252575, 0.031266035312520604, 0.024253224920747534, 0.10111213329115085, 0.05450112013412373, 0.037127088489277024, 0.03815298594002213, 0.027016399328463843, 0.015390700926738126, 0.04066564182617834, 0.060519583257181306, 0.012386412492820194, 0.07956988138279744, 0.02703624138874667, 0.03862391299168978, 0.019100238302988664, 0.01323419450117009, 0.024087660679859773, 0.05499149739210095, 0.015355444247169154, 0.030507707968354225, 0.025854436946766715, 0.03208440961316228, 0.029954515331025635, 0.03874371174190726, 0.021136506626914655, 0.02198690438776144, 0.018505641458822147, 0.05927155379738126, 0.0418190801117037, 0.024267574240054404, 0.0455179441321109, 0.07716000998126608, 0.01665696262248925, 0.010801379286151911, 0.041556636337190866, 0.01448368959661041, 0.028673617634922266, 0.06004395056515932, 0.05664624413475394, 0.03477138114560928, 0.04327309923246503, 0.06266639341733285, 0.01666294051600354, 0.028300038306042552, 0.07433430517890624, 0.006832830674414123, 0.03341222461313009, 0.039732337264078, 0.025528148116011704, 0.014803625643253326, 0.05071589556921806, 0.0029192998024102834, 0.004300971399061382, 0.03254881255062563, 0.0297152638834502, 0.03207273881084152, 0.030420119275471995, 0.049595624075404236, 0.02924077452293464, 0.011281657398545315, 0.04238245416698711, 0.007331179022522909, 0.04763191319735987, 0.014587025390937924, 0.02754467785624521, 0.04162039148754307, 0.02707763372122177, 0.04153078415298036, 0.016985510974856358, 0.0525234382200454, 0.011499603694703962, 0.026617381721735, 0.05525552893855742, 0.0514986399960305, 0.011785494246786194, 0.02725796288411532, 0.08114666105913264, 0.010121532998579954, 0.015315863603193845, 0.029745255131274462, 0.04998282669112086, 0.030299394324954067, 0.03726540446015341, 0.048570028572742424, 0.04992782464250922, 0.005297458173507559, 0.057381921979997835, 0.05354330688714981, 0.02583781792782247, 0.015855097078851292, 0.043574399314820766, 0.06433405607406582, 0.014160705231396216, 0.03532304707914591, 0.02670176942566676, 0.03120548963280661, 0.03566154784389904, 0.018502884910308888, 0.029605076581771885, 0.013972679785053645, 0.05400869709306529, 0.035868891182222536, 0.022258243756368756, 0.035491031993712695, 0.048235914536884854, 0.09050545708409377, 0.032909369096159935, 0.07659549598715135, 0.047884138234491856, 0.039486694016626904, 0.0373826824527766, 0.02523863927594253, 0.023493218202409998, 0.029611180004264628, 0.013835648789868822, 0.0778099854609796, 0.028401618391009312, 0.04560242513460772, 0.04703839183119791, 0.06306470704397985, 0.04993478301912546, 0.042316680374954424, 0.03603765641206077, 0.04182801302522421, 0.01287806878930756, 0.04603716252105577, 0.01158430437291307, 0.02631689757773919, 0.024474790353061895, 0.03984244314155408, 0.05696270947477647, 0.01822981358106647, 0.038499218611312766, 0.06339565571397543, 0.040191240675215206, 0.011817800147192819, 0.05696583752121244, 0.02024354097167296, 0.07177000599248068, 0.055796379023896794, 0.022460708427908163, 0.03680595482832619, 0.0549593416175672, 0.022595974383875728, 0.015927147319806472, 0.08307751387889896, 0.06667086282478911, 0.058196021510022025, 0.014137764810584486, 0.04861183990059154, 0.0540926861576736, 0.05328714634690966, 0.0231909444223025, 0.024883527973932878, 0.05472158633970788, 0.0656432622511472, 0.021542869375220368, 0.04078544396907091, 0.041906387212553194, 0.019255721209836856, 0.008428452420048416, 0.021729812558208193, 0.0514693713880011, 0.0633804090321064, 0.032867710438690016, 0.011648324151922549, 0.03671326694477882, 0.04289595929107495, 0.03867986838200262, 0.03457835828885436, 0.04482134311859097, 0.0763391861692071, 0.08441852299230439, 0.06958956763680492, 0.04484182469812887, 0.05986295813428504, 0.07497089994805199, 0.03345154232478567, 0.06129252285297428, 0.04401285168049591, 0.04639756978888597, 0.015551897098443337, 0.007214788214436599, 0.04183319364009159, 0.04412461318341749, 0.04401036145697747, 0.024277005876813616, 0.04665761494210788, 0.006398422377450126, 0.03121465664090855, 0.03908368153497577, 0.012506380028623556, 0.05246831742780549, 0.009526679159275122, 0.04255306161940098, 0.03302605337064181, 0.04811198011572872, 0.024279194152248756, 0.0297338387795857, 0.01206701757785465, 0.04360879425491605, 0.037850362714380026, 0.015630225484658564, 0.005861826706677675, 0.021717106989984, 0.06572633529348032, 0.04313619461442743, 0.03307215982515897, 0.10483045091054269, 0.04741473449394107, 0.05199460159721119, 0.03403196117973753, 0.015531748001064574, 0.05154598816963179, 0.08640437786068235, 0.042215850071183274, 0.02712155020396624, 0.06996129626142127, 0.02851476240903139, 0.048463603747742515, 0.03000523243099451, 0.02039194166926401, 0.01675130782781967, 0.038344129254775386, 0.03949364221521786, 0.008914424289417053, 0.019133398309350014, 0.018098255818975822, 0.046347463370433876, 0.03328507732866066, 0.03836372534611395, 0.014621671388990112, 0.04974179069644638, 0.05310307336705072, 0.060412347582834106, 0.04298661156956639, 0.008855546957680156, 0.025587070400693586, 0.03602669467883451, 0.02703730668872595, 0.06866312306374311, 0.04742792860737868, 0.023382457538640926, 0.051080194235380204, 0.016985343037439243, 0.021195313560643365, 0.03471218914325748, 0.028688128106296062, 0.028396588750183582, 0.09611364400812558, 0.0351686260796019, 0.08246099017560482, 0.04203432499031935, 0.07407458232981817, 0.015013681425313865, 0.023989814233833125, 0.033081082560654194, 0.027233388042077422, 0.038456284308007786, 0.05707362959427493, 0.02608764434366354, 0.05144158877166254, 0.029635206929274967, 0.02278064956356372, 0.013383252529560455, 0.010664976784028113, 0.04297810952578272, 0.060281193549079556, 0.03865863023591893, 0.06206574743347509, 0.022383565781638026, 0.024609708559832404, 0.0376604068359094, 0.00974715469471578, 0.027481881136606847, 0.01612515571261091, 0.03660523059910961, 0.04946280084550381, 0.05003347254491278, 0.021332820378510014, 0.05970938530351434, 0.05013729179544108, 0.02429692936129868, 0.06001687701791525, 0.051849045657685826, 0.033889329726142545, 0.06014267062502248, 0.04522346332669258, 0.01413252906474684, 0.03165796731731721, 0.014914157301453608, 0.03174916920917375, 0.0454253173167152, 0.06655796816838638, 0.03727135521226695, 0.03121482627466321, 0.01815428415180317, 0.04440098388918808, 0.03892419866419264, 0.05378121483538832, 0.021832993985818963, 0.03259992320090532, 0.08279550115444831, 0.01374209747051022, 0.006416600330599717, 0.12456876997436796, 0.04891572520136833, 0.08938098885118961, 0.111882221086749, 0.16831751886223043, 0.10399584605225495, 0.07134054082312755, 0.14869375686560357, 0.11442954332700797, 0.10831230586128575, 0.09728684462606907, 0.13260508089193276, 0.09049875315810953, 0.09845237101295165, 0.11219497823289462, 0.05625160477523293, 0.1745157734091793, 0.2040614408573934, 0.09574359815035548, 0.12090943061879703, 0.14178405835160188, 0.12979437171348504, 0.08245725144765206, 0.12862950350557054, 0.12558843168829167, 0.16980896597462042, 0.23366002046636172, 0.07058986396129642, 0.1772885253386838, 0.1698169048343386, 0.096752918990595, 0.0944432264992169, 0.09866625203617982, 0.11832350652132716, 0.13412555573242052, 0.11106475602303233, 0.11976510845124722, 0.09236317739955016, 0.12457706167229585, 0.13046244372214588, 0.0996248930958765, 0.17334953456052712, 0.2793532742985657, 0.21902332800839627, 0.13343053231281893, 0.07757969067565032, 0.15987880953720637, 0.14517247224492685, 0.07515212308083262, 0.2094038049025195, 0.1459995521498578, 0.13605167237775667, 0.10339429761682238, 0.04509981389024428, 0.12252279690333776, 0.15052436292171478, 0.11193611033793006, 0.14049826163266385, 0.09794346974896533, 0.07642464765480586, 0.07630028575658798, 0.19655996481222765, 0.07469299914581434, 0.1388470602354833, 0.10348622554114886, 0.09032320257808481, 0.07989748487515108, 0.08734166542334215, 0.1208019642425435, 0.18124663723366602, 0.07943306158163718, 0.18473924696445465, 0.17693542928567954, 0.109301386001919, 0.0936021212754505, 0.14486870568777832, 0.1600226318197591, 0.11062315186219555, 0.14466106040137156, 0.18741179284240517, 0.1710916142910719, 0.11258698826921837, 0.06745317977453981, 0.06785337294318847, 0.12450060434639454, 0.1651237088122538, 0.08327517791518144, 0.06625723466277122, 0.19687397724815778, 0.11479523298995835, 0.11954301036894321, 0.12153441565377371, 0.1274279129824468, 0.13310746821974004, 0.12926567079765455, 0.2597204606447901, 0.12019485181995801, 0.14288671846900666, 0.0862477176955768, 0.12696089089981147, 0.08865186904690095, 0.13675828517547675, 0.07757750579289027, 0.14445417507418565, 0.2325850852898189, 0.1297490048621382, 0.10087247472256422, 0.13885307205574854, 0.061505861048187525, 0.09894485851483685, 0.2056999672204256, 0.14957444103700773, 0.12691924242036684, 0.13371038729591028, 0.13608430991215364, 0.08688374249530689, 0.1461848464927503, 0.17137153712766512, 0.10666239368064062, 0.06302002551300184, 0.17734445019492082, 0.19656993927700178, 0.15894042274781636, 0.09300691714244229, 0.19042371479528292, 0.06752585766038724, 0.12547795261655534, 0.1178248647068228, 0.13310077786445618, 0.1175922764731305, 0.11776975409260818, 0.14194911878023828, 0.10946749137448412, 0.13021217286586761, 0.15238645300269127, 0.08859462104737759, 0.11136569987450327, 0.13961216275181088, 0.18875021673738956, 0.1339826833988939, 0.1262313707598618, 0.1332934818097523, 0.1410298395369734, 0.11684491086219038, 0.1791447393063988, 0.16948317417076655, 0.12015469611755439, 0.08785260907773461, 0.177100856123226, 0.11092353252960102, 0.06654260613556419, 0.1570610978773662, 0.16926281313811029, 0.10993573482015304, 0.18334926797875337, 0.15245792988155568, 0.23460462263652257, 0.12213614050831113, 0.1218407606439931, 0.07910957679684673, 0.15269657064761433, 0.11311171975518976, 0.1850520244666508, 0.11940355785191059, 0.1802015168858426, 0.11269532995564596, 0.1156557375299079, 0.11402174378080027, 0.09909593433673893, 0.0921190744265914, 0.14068139823419706, 0.28145078888961245, 0.1341351366468838, 0.1528179741331509, 0.1156689418213708, 0.0941487830132246, 0.24517549255064555, 0.1842701349939619], [0.011597202475448804, 0.025243782571383884, 0.031124866101890802, 0.02330412406341306, 0.04117566267294543, 0.03740864320259009, 0.09177943372300693, 0.08620940760842391, 0.04196313648883786, 0.05656030767464212, 0.037217235259179554, 0.046022153326443264, 0.04192319452496512, 0.056584792610790045, 0.05512710600825293, 0.056818242583956034, 0.022182032399411713, 0.02786715840920806, 0.07985100522637367, 0.03808134960542832, 0.05278108814465148, 0.03809945970507605, 0.03225665233497109, 0.02076103418533291, 0.03547246049025229, 0.02763981355487236, 0.044319746284080405, 0.036558896835361204, 0.02485568428944264, 0.005831883804473493, 0.016720772055642943, 0.04801449838227459, 0.01953718432092241, 0.03961927636659571, 0.07247365359216928, 0.059631116289113245, 0.01281477589093681, 0.043712270845259936, 0.05438106354059918, 0.048589190401669057, 0.05688048120854156, 0.011181011995566743, 0.006735827732232532, 0.014684257762772697, 0.022382970367159163, 0.06853794692350285, 0.023772803467831442, 0.06657911810491766, 0.005396926742313164, 0.0132503792577024, 0.024008173695100204, 0.014177103726459401, 0.061383256555667946, 0.0407149645366839, 0.023151411275778497, 0.015390059711145503, 0.04037980216422251, 0.03176242099808795, 0.03767900208809546, 0.049497555409158976, 0.00856650376226753, 0.041627030952700546, 0.030276958564562455, 0.011937754112295806, 0.028117948344775608, 0.027385698797713433, 0.01473860502509134, 0.018897931390841092, 0.024828166301761354, 0.04136919443096433, 0.04428302396887115, 0.022658808422940116, 0.027124827528106313, 0.038736702475164614, 0.023421593742179017, 0.0454475596946265, 0.06815917510539293, 0.014207690388762524, 0.028968641268355504, 0.006061918201989361, 0.08987044330154147, 0.03315669171778219, 0.008465159468219748, 0.017677966139412353, 0.03963652133409466, 0.04958085236804826, 0.033022345176764896, 0.01698862205791686, 0.04724116862884589, 0.01255628203840128, 0.03952990312661443, 0.05443012162244745, 0.0338074712614928, 0.056328476007495604, 0.0573224483856133, 0.030765184866530553, 0.04003110980348928, 0.06571363990328141, 0.023783529410138726, 0.019473670050501823, 0.06858344269650322, 0.02252130669408611, 0.022010848192231994, 0.043257621848689656, 0.04684343175696475, 0.048521129946623526, 0.028037540248728225, 0.031324273973171196, 0.044050785180713446, 0.02368572197987565, 0.035535370864506276, 0.024695600915168012, 0.02986007004177996, 0.060619572177529335, 0.05182747502944299, 0.02676466283654528, 0.08056278167558567, 0.026697262256805385, 0.04272562664534364, 0.0328632999610688, 0.01438484909678144, 0.028811350065682615, 0.06212629311318908, 0.07983132771083287, 0.02967192924448422, 0.04496910429692694, 0.017016576004347632, 0.0428469894187791, 0.037540635227092674, 0.015650640907032148, 0.03296461881005338, 0.02332674472459725, 0.07466868723609618, 0.03591827156820467, 0.046117504459938834, 0.007638468024586993, 0.030855704830693345, 0.02702900650911033, 0.09942759546850409, 0.040359232375132184, 0.06911778902368886, 0.09127223558191742, 0.10626452110175576, 0.042068227992526123, 0.02643160561897925, 0.0445124264806509, 0.022721893519961407, 0.031973503064364195, 0.003196858368547899, 0.011195586927767311, 0.05816529065902744, 0.010851611233582454, 0.03563833516091108, 0.03849725764510887, 0.07476982288062572, 0.02250652141602976, 0.06794743825282369, 0.03542055934667587, 0.060221937085900984, 0.06635678253535714, 0.038394327275455, 0.013296352549722152, 0.0188224715114172, 0.03142163696299706, 0.010719272308051586, 0.068465981499425, 0.0342261646874249, 0.07231790944933891, 0.03225178723888738, 0.032567635112042935, 0.038285256163882356, 0.043890464319182296, 0.03386851227177041, 0.03398651968953865, 0.036630288897348304, 0.05159603012725711, 0.019475290052858845, 0.03723238355347088, 0.03878829488530755, 0.012985237458321666, 0.0416439705794411, 0.03547470983383911, 0.0453491144414459, 0.07621301936783961, 0.03719871125317045, 0.031571851045425446, 0.04780404735356569, 0.019809307397476265, 0.02870886752914105, 0.025087700857381736, 0.01770579794953976, 0.047312638722360134, 0.011517633218318224, 0.04460704818900142, 0.036979992275259325, 0.0633084639640791, 0.07157620282045432, 0.029610749134527783, 0.0061742051454660085, 0.07498812795217548, 0.03127979939537389, 0.04553056488345776, 0.05952865071594715, 0.03186914437849607, 0.01750879378856293, 0.02488965175247618, 0.04717196484229394, 0.03008830886600273, 0.037052106977041276, 0.03464929573237896, 0.026585398973631005, 0.033356086018362215, 0.0921002993626254, 0.037862447423062155, 0.03412089676463178, 0.051441833044269254, 0.03581481872658644, 0.018259268786226, 0.04084700745131288, 0.018311860339183892, 0.06545040224279676, 0.03901382635480591, 0.0234381194625582, 0.019989156496844122, 0.03480743510382516, 0.02190300353270556, 0.02399137825705111, 0.07389071969581501, 0.09352740778454713, 0.028103336093149016, 0.0456823599524796, 0.025047412840649486, 0.043306710464613776, 0.0323622730959739, 0.025442052200170498, 0.053445027875048776, 0.043048151303082705, 0.020648380408861806, 0.04460272252825754, 0.013491049691635584, 0.013601080082090837, 0.026316317430298244, 0.017109112913853357, 0.07519136276096106, 0.014691562192248446, 0.03350430181516068, 0.06289915807013001, 0.01618476671033672, 0.03978361076276217, 0.030962044838815928, 0.019265958606930714, 0.002621105077975829, 0.018205552561474696, 0.009170969050111515, 0.03598749231813209, 0.05181579744177205, 0.050192768818565776, 0.020963938208296895, 0.02414357875074659, 0.035015155029084, 0.01845857996626624, 0.08892947807908058, 0.016996024874970317, 0.0029887646129022217, 0.008787443246027189, 0.03367231387112822, 0.07711855149162666, 0.01609893881582788, 0.026394978298672607, 0.04232079229716744, 0.02252375620550343, 0.01866270535226379, 0.041466744017920325, 0.04351410808573876, 0.041347725582974296, 0.02337284948277686, 0.04134148984615292, 0.010409532098232635, 0.04114729312381574, 0.01758559886366129, 0.05996671970933676, 0.019902778988970176, 0.05756486180637564, 0.03765401842870882, 0.02277491763899369, 0.04356749522100602, 0.057771435007452965, 0.05104467971250415, 0.02582731420573379, 0.03483062743076256, 0.03213733195194176, 0.025697793745036637, 0.048469442541577985, 0.014649652476821626, 0.02703467397285359, 0.023139523342251778, 0.03267109473901136, 0.018305902801720158, 0.021032317574801188, 0.02376312586212797, 0.03209339002413409, 0.00649371456321595, 0.027699366877121583, 0.03624357143417001, 0.08783153378005538, 0.00936252627122615, 0.05384007774825607, 0.01769253598260028, 0.06177919530974967, 0.041504121119422574, 0.0077890391860689434, 0.027219968315746104, 0.016525270849732415, 0.009766453078814914, 0.06297101492860488, 0.029702449749623026, 0.02120561372222645, 0.05534868501126766, 0.028907654540879384, 0.01631579182243773, 0.03510328654998115, 0.05703472239630563, 0.05307049350813031, 0.03688741295731493, 0.005302684165404311, 0.04536414399210896, 0.028554612770676613, 0.001927961200375908, 0.058209510786192756, 0.03917898517102003, 0.025065027609733597, 0.020650699302288036, 0.029938705465091125, 0.03742432075419596, 0.04862100690869348, 0.06340930105320045, 0.06665478833019733, 0.03635377569922379, 0.0005974950368649193, 0.07111669212047543, 0.05150159501603671, 0.019896455042596375, 0.047411643766931126, 0.05448670465765255, 0.049825331927942376, 0.027625983314854757, 0.03827832832134195, 0.04141508714695062, 0.004554933485841113, 0.08550428758774485, 0.012485611768040274, 0.058317859257970533, 0.08021172122763735, 0.14515659452549048, 0.15480412755693707, 0.06166322010436228, 0.1239633538893291, 0.1265682905380215, 0.15166584881288664, 0.17347815765866212, 0.11158239003270864, 0.13706833496689796, 0.20153339579701424, 0.15346157816903933, 0.1125934479225959, 0.1766189741236823, 0.06702584520514522, 0.14083672847066606, 0.1607187408953905, 0.05944773541497333, 0.16957780266446726, 0.19026214203664235, 0.13508611704621995, 0.06333826522209815, 0.1667083730655057, 0.1629408887986626, 0.1163083796522447, 0.09244049646492515, 0.14067719131708145, 0.11758029354470116, 0.15568219258316926, 0.07320052066019603, 0.14717594188238892, 0.19259835167654923, 0.19108365795442037, 0.1731444677071912, 0.1367489756750209, 0.19882097920136793, 0.16234972194901534, 0.10895163512655667, 0.10640542568372828, 0.2666428749050413, 0.15673071917678627, 0.09598783004496779, 0.15976835760687078, 0.11608248177383627, 0.1330111976712942, 0.19337713345885277, 0.07644956346069064, 0.11439576585377965, 0.11471402591892652, 0.10031534318945237, 0.10261962775673185, 0.12920351698994637, 0.21145994242812904, 0.1478537576539176, 0.09589781558939389, 0.20665697301072733, 0.08942056101347719, 0.10833511820861272, 0.07654713679637228, 0.13373556094510214, 0.08634216977017266, 0.056234909421099086, 0.13347318502409117, 0.09348181023129395, 0.09338154311158828, 0.09606837893703155, 0.09346932518695082, 0.13020181842148304, 0.09026625991931983, 0.10547930002212524, 0.1860888802579471, 0.10737381729164294, 0.1135393800213933, 0.09647385789347546, 0.09228387022657053, 0.1563647716705288, 0.11473187138991696, 0.12098784212555204, 0.0896638904565147, 0.12679591189537728, 0.13836186698504857, 0.16403599003595964, 0.12067908155066626, 0.09684186814618961, 0.11073331202247313, 0.19754074646958283, 0.2052942304206746, 0.08712646125682763, 0.16145047305950097, 0.08443046520863261, 0.12447297440043517, 0.1159011365047523, 0.11045324669352599, 0.10646418681634323, 0.2563107136104788, 0.10761871415057353, 0.12145934253931046, 0.1606966477951833, 0.18522380239197186, 0.13005889180515492, 0.16125182514744146, 0.1754440771681922, 0.11367903609893151, 0.08329007854419095, 0.1849517777029957, 0.11704954345311437, 0.16251850074955396, 0.13930309005081654, 0.17191121674009732, 0.09870987505252872, 0.1464995238929987, 0.15196075370269163, 0.17952729734991277, 0.16890845500997134, 0.12836868821510247, 0.1349963875753539, 0.13197620106594904, 0.10294866974332503, 0.1055409720699702, 0.17802712427718298, 0.0653819041326642, 0.11669833372746195, 0.1329813421304737, 0.2240782239075218, 0.12208810022899083, 0.10279335307755641, 0.10512492153793573, 0.14698391647211143, 0.30968083121946877, 0.04204547332067575, 0.11760265805891582, 0.13052495036806377, 0.11478863762957708, 0.10403526893683843, 0.09510543596531663, 0.18395575614912169, 0.11384983014847551, 0.10772662835993937, 0.19927034580281802, 0.20683363638818264, 0.1113834028531398, 0.18213660376412527, 0.15897477019046033, 0.10608337939317737, 0.13535768033138343, 0.13673266369317258, 0.0917583584253277, 0.1328350906925542, 0.13598946428724698, 0.12663166570876325, 0.13535035215318203, 0.11950839151229177, 0.1414557695388794, 0.14198414475790092, 0.1651205061269658, 0.1171328675534044, 0.1269726159849337, 0.1352259088307619, 0.1546248993171113, 0.1492052637040615, 0.10908840743026563, 0.09921087138354778, 0.09239390146519456, 0.27910756319761276, 0.2037533995296274, 0.1162701238478933, 0.1474507214235408, 0.17708704115024634, 0.1446887446301324, 0.0864925534863557, 0.12023838662675448, 0.17786188742944173, 0.15305407717823982, 0.20422153440969332, 0.10662712343037128, 0.10189931533698525], [0.07652958309543983, 0.028804405259766748, 0.03915136879576104, 0.060760626037205966, 0.03373797231220773, 0.003247997644523691, 0.01562257669866085, 0.017201013696779097, 0.05122895625286868, 0.040808232567672215, 0.07160069114927735, 0.04329557231228266, 0.005198321238692317, 0.06144937300788505, 0.07612698112747499, 0.03178381859990103, 0.06694855328117098, 0.0291289926639625, 0.02643559710122645, 0.0886462711329971, 0.043449352096234045, 0.033800672340605936, 0.012623001538616205, 0.032786757818290165, 0.02616560971364379, 0.05954104076538767, 0.051516885802681954, 0.03347902299304094, 0.04779921957690801, 0.04319085739552975, 0.04040749317833355, 0.03570793589044895, 0.013700801829275275, 0.10555208647357565, 0.02574752696922847, 0.03675030477877174, 0.049062302336096764, 0.013631271497745599, 0.05995432287454605, 0.0332857592563544, 0.029182847988392626, 0.020364874907370125, 0.04722127737477422, 0.009883746338476027, 0.057646638846823146, 0.01625831481734557, 0.033563480246812105, 0.06178596708923578, 0.029677001293748617, 0.06561652797141246, 0.010021521177675043, 0.026173948909022977, 0.014578696373584015, 0.07407563405909709, 0.06002358094389949, 0.03551564245883908, 0.03819185242589031, 0.011586483318491705, 0.01802656350524298, 0.018819441852558936, 0.008962957354794656, 0.023860646611345664, 0.04145668134359377, 0.03172286579917584, 0.027807820521827255, 0.042074351771069426, 0.005260952989504273, 0.008712828990870287, 0.04179877495127065, 0.002759289158607966, 0.05567134537601045, 0.0024357333396827535, 0.022777803109160492, 0.044198946694710424, 0.008716421833794032, 0.022309386637061834, 0.040826756573681316, 0.02125644956582359, 0.029147757549903223, 0.03992987916405712, 0.045215239482266564, 0.020774947545890297, 0.059451616635279994, 0.028928210759269338, 0.058542820758053234, 0.025241609562986662, 0.07500348319964749, 0.022782513838527457, 0.006122869730461389, 0.031336321362427304, 0.03663763064625008, 0.052883628356669626, 0.015182329607861382, 0.05634487280622125, 0.0474611564672419, 0.08962957694062165, 0.06396352845643248, 0.020196333594088043, 0.04493918429527964, 0.08520639714385782, 0.033146299953971586, 0.022900945340682353, 0.06535660834716898, 0.08109831543905394, 0.02487734821625054, 0.04440512973815203, 0.05325141130015254, 0.05801930384976523, 0.0264780174142548, 0.011849715889963721, 0.03869412440274443, 0.021680944466165135, 0.019553693077926124, 0.029164405406585762, 0.05102425580844283, 0.010740917575146471, 0.03265078279322811, 0.04347551301387804, 0.026464816515466998, 0.04456145742109843, 0.05861384980380535, 0.013758442530940686, 0.024351261356579404, 0.02507440835636641, 0.050387993521456204, 0.027614668743418794, 0.060692887886294296, 0.058089125103184154, 0.008385608870802181, 0.024071157011868696, 0.038874842026936154, 0.044866099288421016, 0.04164495784789324, 0.03850641108251043, 0.04327639012730547, 0.07085084210016898, 0.021808369949992214, 0.012898379886922027, 0.017343129463759915, 0.041129386584673605, 0.06986088664936167, 0.02111914461212499, 0.03168706629159195, 0.10071754482175622, 0.021862223578084792, 0.03555584565869399, 0.03959253530151077, 0.06941676512360573, 0.03209513046645692, 0.02721706927487893, 0.05587719932996801, 0.02788148737246437, 0.05454778977270637, 0.0160272380204073, 0.05602764750697783, 0.020147770842803375, 0.11000607854553632, 0.06016953382641077, 0.06183547978954656, 0.012865597315664803, 0.005779133643954992, 0.08941985533705779, 0.027757256092237573, 0.0290461571088859, 0.08088242595217057, 0.03828458780688899, 0.018074893858283758, 0.036297949230564494, 0.012973148508795669, 0.016551606490143707, 0.02461283321359328, 0.00655320384872279, 0.04927264479920268, 0.07518374959805182, 0.028477334417402744, 0.02971279401598232, 0.0159826837147453, 0.023654840154839412, 0.051029765512794256, 0.02237628849356302, 0.040710058728499074, 0.01718737175022917, 0.031046688689717224, 0.11215722454445702, 0.004584635084029287, 0.07345020797635828, 0.039664565186415396, 0.022426299917112504, 0.01158560037479869, 0.028373759439481155, 0.02315982511000974, 0.08825096341648273, 0.053344265424779484, 0.05433540491919432, 0.02177571884489485, 0.02997426748541849, 0.09570961711662156, 0.03387163353285619, 0.02125123841688037, 0.06912603322416544, 0.045071600404168875, 0.015478957976613725, 0.03164046450651117, 0.019614971575460265, 0.03810947827462639, 0.041431741788983345, 0.04393274722886937, 0.003242413725404601, 0.06467130154903446, 0.03898303782833474, 0.019646245254469768, 0.009242608777380415, 0.018800130745928203, 0.05165387523759689, 0.02433912066875824, 0.04220040322148374, 0.02833929325320891, 0.06125710332500083, 0.0206399241661919, 0.014619717208136405, 0.031187980036650385, 0.02017882399793182, 0.05706551431545189, 0.03807718340041382, 0.01148877088313124, 0.035443700783486874, 0.04977301687800458, 0.031989217935396094, 0.031007425260863135, 0.01813261004696999, 0.061941392320607386, 0.05498586555144616, 0.013748932014485555, 0.03336348544274058, 0.005388558709195682, 0.06808296205209834, 0.015427197629053677, 0.02365295891650021, 0.043558124652398486, 0.06990938154714448, 0.05011667790157454, 0.0792203408532909, 0.030050843554948057, 0.031746936828962395, 0.009480153709383947, 0.04164571102176394, 0.040626151088093004, 0.03098365617915988, 0.017056329674752693, 0.01560904162137636, 0.016317267636103288, 0.012655857052387936, 0.12297594973019191, 0.01693333332825984, 0.05605544030134167, 0.03502679869000401, 0.04502072724114571, 0.039635194798133204, 0.03318829448627574, 0.006815067475794682, 0.05378532675760133, 0.03522797414500799, 0.012832747739074486, 0.026425758343456045, 0.007935936080424913, 0.00921601614183081, 0.019456881397802914, 0.04381070252774017, 0.07073141315153667, 0.020306697314871208, 0.04096615141523736, 0.07292614145470516, 0.05417901277542114, 0.018394281987899115, 0.018923934549093246, 0.03292511450126767, 0.04545146805633392, 0.02621154483806874, 0.02164095500484109, 0.01341849479026028, 0.028870745628540005, 0.027099967701360583, 0.08262816763349942, 0.012396955230672444, 0.03209482851837363, 0.05431505226130996, 0.022482445297230567, 0.04352033364453486, 0.01554921009976949, 0.029566339017557244, 0.026422494590016346, 0.03219250363430806, 0.04066965536081365, 0.028556034301540682, 0.026293503386633735, 0.018314433683242117, 0.11315872187593154, 0.009498263809031673, 0.046790061585072956, 0.042913926898368766, 0.06049312039145401, 0.043798794238162894, 0.0378244223206171, 0.03767274260254843, 0.04676498293078371, 0.05944211035966873, 0.06400681899062224, 0.018243233307397792, 0.015061901516414114, 0.018998030573129654, 0.022365459074665393, 0.009014736362067717, 0.044982535897621086, 0.019263705870668803, 0.020847011357545853, 0.034206178438450606, 0.08454051001795701, 0.03733635547437838, 0.018017225167048827, 0.01656177094472306, 0.021276934538036585, 0.02079739178796964, 0.03109912248328328, 0.017043071100488305, 0.04966434949476804, 0.029628957621753216, 0.09978348708578519, 0.029756308466728245, 0.02909536786111338, 0.005958719811003123, 0.04742882766627839, 0.04813929454290441, 0.01654760991888387, 0.023376678116619587, 0.04832453460299543, 0.06238443497568369, 0.02037344141198056, 0.016584269469603896, 0.03194896723808987, 0.033258098776319196, 0.07300215094749417, 0.05772164410778454, 0.02294095855073205, 0.026069381573636616, 0.032309527176299264, 0.012716833601838775, 0.010832622431085577, 0.03441264307392495, 0.043949612216757875, 0.01850561940643404, 0.01256318952489112, 0.02518399685089077, 0.1196883525699377, 0.13115742642964634, 0.10586298443377018, 0.1255110651254654, 0.11215272585728339, 0.06952980227236237, 0.12267320097557136, 0.2691259602350848, 0.11236802501870052, 0.10205385168748242, 0.1624198688992432, 0.1509889829903841, 0.14174827241471835, 0.11595621997756617, 0.1886515441749777, 0.10317922915731158, 0.18186486405985697, 0.1020336313439267, 0.131001173385552, 0.1292254472417491, 0.19093120470643044, 0.09392217267304659, 0.10827031811433178, 0.11639090308121272, 0.10076631113354649, 0.1375776297811951, 0.09535437689295836, 0.1519754236297948, 0.19766624830663204, 0.18556388414331845, 0.1683336544249739, 0.2055121622979641, 0.07274611254355737, 0.2481159104832581, 0.16975998931697436, 0.11214052579764809, 0.058476018985467296, 0.1604965478181839, 0.16594134350972517, 0.17475142862115586, 0.11443558228867394, 0.1384509043501956, 0.13747819725956234, 0.11196481236921889, 0.14496256065155777, 0.08472990949771234, 0.12056073147271361, 0.15627128311565944, 0.12220076418348721, 0.1139417037900005, 0.1263557733701808, 0.1558531155543668, 0.13835679154310906, 0.10508509831769125, 0.11003832252962248, 0.14336210010307177, 0.11289842227207762, 0.1400300996111972, 0.15099146642855235, 0.1291533461106675, 0.16197863114731653, 0.21144158127052443, 0.1058581057669861, 0.1474796270153352, 0.1556026004254818, 0.1276685893535614, 0.11608158610761166, 0.11695172584482602, 0.1519466537450041, 0.11416066704051835, 0.13567805742578848, 0.09527881523328167, 0.0776665024459362, 0.1334672953401293, 0.08378959566886936, 0.052022329930748255, 0.2124334094779832, 0.08039909188768693, 0.0998092374897429, 0.138012326455542, 0.0736418669777257, 0.15552247901047977, 0.10545935787792717, 0.11250928922423295, 0.13773764190929277, 0.10567904037556478, 0.15460313191371305, 0.05606443089033876, 0.12298055019761835, 0.1493535100349358, 0.14114631685827458, 0.15484821876244886, 0.08486657323581831, 0.1345258235399212, 0.10642565959798438, 0.1839025861450604, 0.12616154950644287, 0.06452688894101552, 0.094847511234028, 0.19314830430916377, 0.16962572080748423, 0.08526431689304964, 0.1388200002589396, 0.19859717121081694, 0.10445933975279331, 0.13773450707750662, 0.14148270737911972, 0.12196133631680693, 0.19684287320290292, 0.11265653810862984, 0.11935862526297569, 0.208851816664849, 0.11219165341130324, 0.13573118671774864, 0.20524765577699455, 0.12234141092215266, 0.1189687933240618, 0.12860787180917604, 0.11578670835920743, 0.10436108788209301, 0.2025385368615389, 0.16961349360644817, 0.0982225104900343, 0.17352086465273583, 0.16795644323740685, 0.08929442813886063, 0.15354119746812753, 0.12994103027241571, 0.0937150295025536, 0.14460182429424354, 0.16473542393318244, 0.07558264676481485, 0.09326128635023322, 0.1301974215145622, 0.159904593867915, 0.19046767029379094, 0.1866091809102467, 0.06873902399092913, 0.07916674337216786, 0.13544145226478577, 0.21328689796583994, 0.0859230522598539, 0.11375280642615897, 0.14094091073742934, 0.09460981363164526, 0.12590401832546505, 0.15716143963592394, 0.16694241336413793, 0.11775235645473003, 0.12749048748186656, 0.1500057450362614, 0.16806899862630026, 0.14091119090361254, 0.13229443398969515, 0.17139927563922747, 0.11933729212198939, 0.17439133008675917, 0.1126150864043406, 0.16603107298059122, 0.10748756690216915, 0.13165188846843584, 0.1178980107818331, 0.13989247913871491, 0.1284713912755251, 0.2462555303105286, 0.16306214300649507, 0.1289674410862582, 0.08217234137867178, 0.1904217199023281, 0.09025253994124276, 0.08851997540997607, 0.12427876410739762, 0.11014435719698668, 0.10976344120821782, 0.07655779658151524, 0.11171738457466875], [0.048512858604746203, 0.043512269255838225, 0.0528824375277119, 0.02766725011835141, 0.016447191825136542, 0.00862920972784715, 0.013569450172196542, 0.026846365238140737, 0.02806244248391262, 0.04990306829235383, 0.00872029542058174, 0.019393384090757797, 0.10077819228172302, 0.04567960849297898, 0.04633033714656319, 0.03556247155315109, 0.004329877414940191, 0.025880567330334867, 0.03246397192456892, 0.03129682723166687, 0.04989291401579976, 0.04668720246159604, 0.03756528301164508, 0.03418241614209754, 0.019632516794704964, 0.10069532958524567, 0.08564926337982927, 0.04506112721615604, 0.041463073143469434, 0.021226495637425354, 0.013854011643810995, 0.06114553859723466, 0.03191181066046868, 0.01756520719001336, 0.10095234507960932, 0.016334656792293702, 0.016235850219215666, 0.0322320961526462, 0.044166058102356534, 0.019862202594855, 0.0482233378903142, 0.026358676675174917, 0.04714705242908426, 0.04381140820415957, 0.039985308689730506, 0.021502557609762465, 0.029780433779316287, 0.06361850018479995, 0.015844723974753703, 0.02614518072056983, 0.039734925875174146, 0.021020251525832073, 0.12402145005762577, 0.08103536774537393, 0.03363147284835577, 0.04854192365227001, 0.011687243224254676, 0.03600017074495554, 0.048996525151388984, 0.010821583514500941, 0.012376476195640862, 0.037143061203616004, 0.028192446400810565, 0.033120875246822834, 0.04371731575312359, 0.004340131351325128, 0.02789679342614753, 0.02352598974747317, 0.036494978836604526, 0.034245818454240046, 0.02978988577212606, 0.07827905671937124, 0.03386045127574887, 0.047473112254270484, 0.019416355893814137, 0.029424036653446298, 0.02831787190267018, 0.004144130574007119, 0.07483661786786147, 0.03415174975192972, 0.05095462793750422, 0.031189174258283207, 0.0453979587847633, 0.012119324994273484, 0.03132108146590846, 0.03328113504020231, 0.015625497791916132, 0.015578741640118616, 0.032746089821947474, 0.04588391199441893, 0.0026407546039471136, 0.03625359678907054, 0.014962111067559038, 0.025347138721761957, 0.011568720968041037, 0.0448715309612453, 0.049295640350984674, 0.10520146707338945, 0.010029949430775429, 0.03713424024837358, 0.032279970190886936, 0.026062932098284364, 0.030761910935065577, 0.04060680266203625, 0.04704698886988418, 0.028895491800670112, 0.06566057167947292, 0.035116864035704305, 0.07456695448075022, 0.024044989308874522, 0.060191952623426914, 0.023119309784046242, 0.08519969321787357, 0.02208832840967391, 0.029292896190392118, 0.039679754192807844, 0.008113373835970248, 0.05080280572708164, 0.05987385540668454, 0.016042533896065185, 0.061903753983122964, 0.02671042922884226, 0.010205959718275284, 0.038296346818762164, 0.07361140754073858, 0.03784813033416867, 0.028235414630866477, 0.02087323843235416, 0.008605716300995221, 0.029389509399022375, 0.02155405163232769, 0.03786243045968669, 0.03700491486649428, 0.024077894864603877, 0.005437568021339497, 0.08483557097081627, 0.0183258619092937, 0.06166154412286622, 0.02125158786241497, 0.04656226720128741, 0.028076287990968143, 0.025329881879900183, 0.029369899736983434, 0.027033534034022262, 0.05531990494845169, 0.015326954258073653, 0.014214131382427045, 0.017206024677891816, 0.06846071606768028, 0.03062504024377891, 0.03697333245405129, 0.010658923403492995, 0.0486922361222761, 0.053515833004244735, 0.020652989357975975, 0.03622854866885713, 0.04299119507361736, 0.04750848767746772, 0.02231301849574915, 0.06489443100456681, 0.02869116115782942, 0.019398887009759034, 0.04296980764982956, 0.014586828615782517, 0.10886250276650701, 0.06915911180632454, 0.03719816163980535, 0.06210065806018455, 0.03142479554350887, 0.06954010243394546, 0.015628914215735028, 0.043684450909495354, 0.003564315615221858, 0.038461274933069944, 0.012820181270529116, 0.042170910696898184, 0.0272476067433932, 0.01842349800946457, 0.03414613487465041, 0.02126872256797339, 0.027188952480043684, 0.028937930773411478, 0.010999671815495406, 0.029530247739915336, 0.1184394545853138, 0.03351921262219548, 0.06941358279436827, 0.01789915159211627, 0.01694508216210774, 0.006313468096777797, 0.0763722172539149, 0.03135522534804685, 0.048237916215189865, 0.0348879907812391, 0.057988552642720084, 0.05577550728672317, 0.03966964062835489, 0.02600720401720277, 0.035324631458414454, 0.06393823267093726, 0.021180811570957303, 0.027543410692097883, 0.008532727137207985, 0.0676843159432922, 0.005130937198243503, 0.039447505226624865, 0.0162417059764266, 0.056339651479252746, 0.01170122274197638, 0.008566536840849688, 0.014097731244484228, 0.07197292867515769, 0.03641871150050845, 0.005668757200640227, 0.024526228396488086, 0.010783087678386696, 0.07143143737422568, 0.05445134619783078, 0.007355749623716942, 0.04723338243950691, 0.08029414966170277, 0.03369630008403744, 0.03704227839729615, 0.011016705588969802, 0.060751852579414845, 0.022692655446007848, 0.017981412088764564, 0.08664107801658766, 0.07945818094802753, 0.03046518417873553, 0.030843206215649843, 0.027064509157623564, 0.10127753977264677, 0.0166927061509341, 0.018714689616379992, 0.01020458822936884, 0.04456725889550788, 0.031249054973678927, 0.012808005807788243, 0.008121410235097366, 0.02849104761012963, 0.03437917772680521, 0.018389111551057016, 0.10995383134910039, 0.05999156766171966, 0.037283860612660646, 0.03894412384501525, 0.05656220418001924, 0.030938112908708196, 0.03312216107068317, 0.029550043999084404, 0.03273229859769344, 0.0347750859468111, 0.012624002377768713, 0.0359087211878172, 0.06134116702846118, 0.047500480964247666, 0.04488671996763774, 0.0626903660595417, 0.027155475258561115, 0.03967807821131178, 0.057337980052190166, 0.06343855948320457, 0.014807808811643293, 0.03428845080946173, 0.05696190880345447, 0.025964135703231608, 0.07262705678918532, 0.03724472949813519, 0.03588087411065187, 0.00671695258435128, 0.06568060203322343, 0.008284792137731398, 0.08771117523844753, 0.061649608691888194, 0.08615412057510444, 0.048692344687879086, 0.05690378549375704, 0.0337409510809396, 0.049827221647969315, 0.07803624296294791, 0.0717270275843995, 0.04830269595342023, 0.05739564874342509, 0.04319555625053389, 0.06627850673560585, 0.02761862799525261, 0.018181674914168458, 0.013293147319927812, 0.05343960977292486, 0.07617500105074473, 0.053659716354949136, 0.08040492050349712, 0.015302618599629827, 0.04453439065920455, 0.07186976421092238, 0.06979392881372146, 0.049598253398601494, 0.07261749623077256, 0.033007149385022264, 0.07060004877192633, 0.022136080311611295, 0.020680717691513043, 0.07331070796187435, 0.04199321594621454, 0.02439756628258952, 0.07660734320857696, 0.07029447052627802, 0.044059969152190855, 0.023556406776021634, 0.01155573211144656, 0.014410126222563642, 0.020846139440046887, 0.03958429449370929, 0.03111041330599359, 0.04567183248166527, 0.04474889254197478, 0.011618372768030634, 0.03830851634432163, 0.0021001812336700304, 0.041471120568790605, 0.025354782418747033, 0.04141797431345497, 0.03279644051300628, 0.0469208729586431, 0.04061424958386591, 0.02879083455939378, 0.02113286459020206, 0.005826758320576378, 0.05800291044371469, 0.06101912073791027, 0.014197060289526624, 0.027310350876567618, 0.028935162350535393, 0.013086730181904776, 0.014507131285167165, 0.06005102090005364, 0.060092540457844734, 0.08748280070722103, 0.018280864859532033, 0.11505121711109366, 0.05964425951242447, 0.05695074011704751, 0.046941927900271754, 0.07860879759703364, 0.048157940685216866, 0.05264983233064413, 0.033790494315326214, 0.04239221489323037, 0.02605171252175101, 0.04318694903382233, 0.028961859310844114, 0.1533819724406515, 0.09779569160725389, 0.1296577826142311, 0.07814790947096688, 0.12554014713636466, 0.18344163016549178, 0.11782638462526457, 0.21101626195013523, 0.16600100030856474, 0.11487534083425999, 0.14706664346158504, 0.14175569558782236, 0.12416555732488632, 0.06791071593761444, 0.1552891715296677, 0.2399332124207701, 0.1287154738924333, 0.09299992144640003, 0.1521631335573537, 0.12753869060959133, 0.09700270808701004, 0.16099865016128334, 0.17929981169956072, 0.19087154790759087, 0.16611709765025548, 0.15339307327355656, 0.11688721073525292, 0.2586865361247744, 0.15415144472249917, 0.12382728047668934, 0.11700470585908208, 0.13435646119926656, 0.08801876873310123, 0.07361671368458442, 0.16287390382162162, 0.10706330609640904, 0.0995086193350809, 0.18010631842272623, 0.12436903640627861, 0.1887738976095404, 0.15224986390343734, 0.19126011777137006, 0.11944322500910078, 0.12043434754014015, 0.174841633066535, 0.09731106832623482, 0.09152233001909085, 0.28122527099081446, 0.1177325432321855, 0.09214470947959594, 0.11571664283318178, 0.12386118008622102, 0.2707905152014324, 0.1651646787566798, 0.0997622421543513, 0.1393898068261998, 0.19572126838777745, 0.09603795342679534, 0.1420295794627496, 0.08993805253079959, 0.1633582692593336, 0.09646461624652147, 0.0779579875192472, 0.09331788295613867, 0.1797306542950017, 0.10766244573252541, 0.14583796582051686, 0.1268092111817428, 0.10277706823710885, 0.0949360193418605, 0.22053074783512525, 0.15031447846974644, 0.2036962125982557, 0.10997734937284674, 0.11963519613657679, 0.12818431667983532, 0.16958168388477393, 0.07550302746572665, 0.12115690591079847, 0.179450677175607, 0.12851663599056856, 0.13886224584920065, 0.14815922054861272, 0.09668539797088929, 0.19637967805777276, 0.11056594457477331, 0.11938265897333622, 0.10690868832170963, 0.08231418233897005, 0.12265308919761862, 0.09263187726693493, 0.2456474815096174, 0.12066248458411012, 0.10975498666188546, 0.16152554617396422, 0.1434881311974355, 0.15128733483808382, 0.16882063900785788, 0.12324258685112, 0.12162523078066961, 0.13613460292773588, 0.15364479619477475, 0.12769944912620954, 0.11962835650358881, 0.17080505538199628, 0.11297244365726199, 0.1307775689555066, 0.08084662644458668, 0.1429124078048127, 0.10604392258184296, 0.08494232488530022, 0.10676354289587055, 0.19291734455951623, 0.11971653891461236, 0.17107743290918215, 0.12362260717366423, 0.12029530214411871, 0.1057184429040977, 0.16557887010276318, 0.16775884026927607, 0.19991457409092359, 0.11980567127466202, 0.19633732390190872, 0.08359294264976468, 0.17463596910238266, 0.1284428792340415, 0.09040220441030604, 0.14560267701745033, 0.15726289419191225, 0.08377065097114869, 0.11801596730947495, 0.16770838440528937, 0.10332818794995546, 0.08001167553343944, 0.11593380118055002, 0.1321020285998072, 0.08985720508332763, 0.13446692670030252, 0.09934115689247847, 0.14652259408363275, 0.11801481379994325, 0.09446833229490689, 0.08289344089904002, 0.12403800631208078, 0.21629250954304421, 0.09718351731342928, 0.1455233155616692, 0.1478956096938678, 0.14653739971773966, 0.09430378755288464, 0.15724173747003078, 0.10983129471008267, 0.26635221764445305, 0.08520283483500991, 0.1723179577716759, 0.21278335712850094, 0.13942096515425614, 0.139496933934944, 0.1146633257823331, 0.12536086461373738, 0.12112466192671231, 0.15815941537065165, 0.10089565347880125, 0.07407688934888158, 0.2398951601769243, 0.11587361512439591, 0.1504441193704094, 0.1703688930720091, 0.17759854798870428, 0.14678860695234366, 0.2489746372614588, 0.1396993137896061, 0.09824406076222658, 0.07856936792709998, 0.053031610058886666, 0.10853997471609286], [0.0180120937459703, 0.05107715779117175, 0.006689901089495314, 0.03728456628908004, 0.04864122046689902, 0.07915312517434359, 0.015565869830814856, 0.042671978274094205, 0.01846353496823992, 0.006963094979125474, 0.02516140163476978, 0.014809237127857549, 0.015590465028903313, 0.010291942827669638, 0.01959618124445634, 0.07192810465182577, 0.06777957547456026, 0.04221296290467892, 0.04066327713163836, 0.009774079812424523, 0.05313145987955587, 0.020587831336472715, 0.019068454026377628, 0.006532919468424682, 0.02548493561334908, 0.03745611351249473, 0.004627957848632442, 0.0020844084751193543, 0.06887628483985152, 0.031881011955972226, 0.03072065261325666, 0.01758500005650733, 0.03226774638252599, 0.018829864150445377, 0.029942620612148727, 0.04890822399673717, 0.06895992785160031, 0.018806860116975646, 0.044641270102666955, 0.00841059846737023, 0.05727799755654164, 0.03151766663151128, 0.017947166426373378, 0.021650690286021148, 0.06115005764045885, 0.07150437988873039, 0.04407853726297617, 0.02166724993315126, 0.03076148685067892, 0.021104796989155666, 0.007524705691529172, 0.08171924283461911, 0.11030611316008226, 0.05827413446136883, 0.036558279368494234, 0.015825109223702123, 0.020005895955754176, 0.00975250663967537, 0.06650331895798445, 0.03697051314104881, 0.017445327015593648, 0.0173087735394282, 0.03788372628124697, 0.008838687058804291, 0.013512419303879142, 0.027087740500324538, 0.045617017030183754, 0.03267829738823431, 0.052076785758669884, 0.04076574270480445, 0.10996850806155375, 0.04937564302235842, 0.0592021057382226, 0.01914832099074764, 0.022698063370106474, 0.02373755187727511, 0.02051312123824443, 0.08435506639736039, 0.07143307264362063, 0.013121695091415728, 0.0019020320448492254, 0.010473009049227195, 0.02340906798573477, 0.0626180749386549, 0.02081658584730966, 0.03094733759228672, 0.08850320202431508, 0.013157359740164663, 0.020364662865176797, 0.0449454302101263, 0.0564603628590703, 0.04081440045099173, 0.05356548141155924, 0.033386860974133015, 0.06641187957887139, 0.02619904961570033, 0.06899546273052692, 0.08413628635129758, 0.08428550977259874, 0.048738023665334494, 0.047082550890211544, 0.06197257100471428, 0.025268759445420334, 0.07304762636444398, 0.06709040102681943, 0.005521179226759289, 0.024852145729320388, 0.09487075784376689, 0.056893342839820046, 0.04560675758070179, 0.01595837010868958, 0.05707144471151488, 0.10556944339935269, 0.01873153933723058, 0.024540028102429848, 0.07014397824449198, 0.04167021970663752, 0.056025866352553876, 0.014680461359343358, 0.051351743949843306, 0.03706978281427707, 0.04523124273068138, 0.04785664738821132, 0.04418962701622929, 0.03678997532863702, 0.05497546021693519, 0.06698475312441587, 0.05656294717586466, 0.054341494770986695, 0.044761017962758026, 0.06156884266861847, 0.047256927604654005, 0.044615400955080986, 0.04203085767637406, 0.020737465271460157, 0.0043191981219154385, 0.08366289282483713, 0.02298543991387955, 0.030769412139696733, 0.041031382379255125, 0.055620431500886164, 0.07545572000422648, 0.03405114336471472, 0.043772731708096604, 0.05873532792819398, 0.051642133189099174, 0.03704229536067162, 0.0250386190268078, 0.05655018732483898, 0.010228208033367991, 0.02239739602165563, 0.012410702350150262, 0.04584099126181432, 0.036217074641691785, 0.04121126201269882, 0.03789793819721256, 0.050503551427807124, 0.048011740137423785, 0.016120463642956953, 0.011315262693512653, 0.0066605438478291035, 0.030088614206761122, 0.009311848187020846, 0.026754057334203805, 0.02328023623808154, 0.04073220271883266, 0.023285092852477516, 0.03226123244634696, 0.07641136193914072, 0.028070924171645726, 0.010643315401726534, 0.025921544060111046, 0.009178452443198433, 0.0498609143043203, 0.03359555798981871, 0.056046205439737866, 0.00013171033970138524, 0.04818705662286707, 0.021143344563565085, 0.04706019316134708, 0.004684477695263922, 0.02594690430643303, 0.009230256895534694, 0.026847618831587688, 0.061206878162920475, 0.009744728083855339, 0.054236695037356446, 0.011221739363723567, 0.022002882191113064, 0.03842373837583831, 0.028847834893635342, 0.09199416970035859, 0.02679903742059001, 0.07866452567811523, 0.0671942847381745, 0.026022062237773622, 0.0351561240718833, 0.02046274340578488, 0.04703200342399733, 0.03552919280316148, 0.028058444216315235, 0.04036053516236799, 0.014658697348620211, 0.04613918026110955, 0.04326402382659061, 0.01014385255984962, 0.013776684944917048, 0.049909629725984166, 0.045771699265709946, 0.08261581151080982, 0.025621992901765873, 0.026076080410608223, 0.010469207556785216, 0.020207258007888283, 0.022853666716920476, 0.0344427394946771, 0.04124401829072407, 0.09023315419575997, 0.01727147786212819, 0.015249947318807244, 0.04900712386838027, 0.039176226926169226, 0.025067663718281046, 0.027540269074961543, 0.05613279329346759, 0.006936537542579961, 0.06032707608704056, 0.07728083671203681, 0.003784092259593308, 0.005574925137417657, 0.03308817325159907, 0.011362896699990545, 0.041824674632932456, 0.015689690597355366, 0.026511611683028083, 0.024410405861479894, 0.031197065620550087, 0.02751588761540396, 0.01320085213852248, 0.019581138123092905, 0.018544049933552742, 0.02371201690818582, 0.019356692309624383, 0.0049905504233070785, 0.04977664025500417, 0.022964542731642723, 0.11059674327926976, 0.031733277919037, 0.013623674450043057, 0.031563993609909496, 0.022296660712787082, 0.08058880349355084, 0.0437957272598786, 0.03356655740312167, 0.03569312007831676, 0.05185670631804636, 0.041523612037833245, 0.02878927392885089, 0.025710825010069778, 0.10241018435252564, 0.01576951176061162, 0.05796553673488753, 0.016797843455736126, 0.04308746562206319, 0.023741609516686628, 0.024671937006392648, 0.03754732558237655, 0.04403209832629987, 0.0632470158327903, 0.03849627376933183, 0.03600758374003427, 0.04570975580385753, 0.00862350664101541, 0.020440353446507027, 0.04616183654538222, 0.02544727861615164, 0.042544372978487184, 0.018179790283154165, 0.01693641218090696, 0.019986072555184364, 0.023741265160164664, 0.02014033749167408, 0.014129727563288594, 0.05602832943467157, 0.045289993685271056, 0.05435887883816447, 0.014913634829489248, 0.02624139528987663, 0.00912544019852898, 0.024728823686018586, 0.009652465981032168, 0.0015724112890893593, 0.016852207681430236, 0.0982897804517831, 0.02401222794183663, 0.03091555501201323, 0.024640782071011405, 0.013214915624952741, 0.03772565137062754, 0.043771221967680116, 0.0732185086235404, 0.06248787763927664, 0.06540029243166957, 0.025282766104542782, 0.034034108743071556, 0.0123713744604694, 0.0456862750995372, 0.0424627825351698, 0.016784520420644964, 0.08460419052945715, 0.005936974884077374, 0.030537763677005256, 0.04629349608772567, 0.025002422576238, 0.03510614318240966, 0.09372269694826432, 0.02474261830294771, 0.01247816569437938, 0.07318633249295609, 0.026546527398750186, 0.01855077930460019, 0.05488170364073344, 0.028885174675711563, 0.033104393631219864, 0.015714397753721902, 0.02446310767637832, 0.012292609267335917, 0.05488964928580182, 0.03649827990947025, 0.018580516101792455, 0.018138538746695434, 0.033104397023894956, 0.03625208365597895, 0.08626147838575499, 0.02875524539766567, 0.07639660380248513, 0.050691023868109496, 0.016136197173701863, 0.0232135362457484, 0.03580222850931542, 0.022715888485046368, 0.07161966298839875, 0.04995962418615818, 0.03598822174327714, 0.03494711493008903, 0.00893018496156271, 0.048739730180906396, 0.030052570426570516, 0.02553413449121373, 0.011174095179220396, 0.016393156688926474, 0.02425480930001608, 0.09626528979944331, 0.10769743099808693, 0.0765662511278476, 0.08782095541911465, 0.13882635134671414, 0.15756058107529367, 0.13910166014518055, 0.07378700561821461, 0.20070362889340945, 0.07387383095920086, 0.10434736790401594, 0.14916609866278513, 0.08661073393055371, 0.08981937675603799, 0.10104658002299921, 0.14937845298222133, 0.12621112327490533, 0.19728012116891996, 0.15804057674748556, 0.12986173667013645, 0.15380342411143438, 0.1476674997912986, 0.11963697389832564, 0.10568897412823779, 0.07389643974602222, 0.11740793207926409, 0.10283107962459326, 0.13239938978637966, 0.16204683748739107, 0.11386692923094545, 0.08276425461683955, 0.11413812610719885, 0.09608171215014798, 0.19457454420626163, 0.10915957896837167, 0.10836930280285222, 0.16048965390239442, 0.13666780931609018, 0.14865980297327042, 0.09823462912546736, 0.10351638642272779, 0.09511503723583051, 0.07446016663951532, 0.15558993896203382, 0.07438622667853322, 0.12419881911150046, 0.15600449671702726, 0.0835339440298932, 0.16529609741909163, 0.1408356970974377, 0.09370185235249144, 0.17971033895654337, 0.13979466153042658, 0.12148467903690678, 0.088679960396673, 0.0688389857698764, 0.11569397976355893, 0.07243872260940926, 0.13515684753656387, 0.1156679918723447, 0.18913170269557408, 0.11451222960438047, 0.09732432011514902, 0.12237837750996862, 0.07052628523004906, 0.08145093651754515, 0.13141754961439542, 0.14277325384318829, 0.11669551102178437, 0.15236240572163037, 0.22648557115878376, 0.1692632066884211, 0.12876827748758451, 0.08023884227233273, 0.05821638434593167, 0.1947933988911765, 0.14200318445052418, 0.14936367448951515, 0.1274315770715475, 0.12360568451029913, 0.11161478329449892, 0.16268675029277802, 0.12044753826090268, 0.13404360227286816, 0.1317369496183736, 0.1539487934538296, 0.21218012592622212, 0.14774710551968642, 0.07517329337341444, 0.15550388715096883, 0.17588106729090214, 0.12370701692998409, 0.1913692940558706, 0.09171969549996511, 0.16479068382510118, 0.14848060187484535, 0.11152981035411358, 0.19378626293369702, 0.135576779288905, 0.1458133485700403, 0.13199817202985287, 0.2015218199895961, 0.1344603177692209, 0.21138237230479717, 0.24747559055685997, 0.10907973575272731, 0.08254983755094664, 0.16102809858109268, 0.13575207202562264, 0.13919335736760072, 0.08158097775386912, 0.19348407057779177, 0.1290813535451889, 0.10197788969214473, 0.06720082581575428, 0.13488654632653507, 0.0920496874355844, 0.16044208859758718, 0.12850458520863736, 0.10495119621711117, 0.10552790348551103, 0.09379814325698785, 0.15510025380977563, 0.15850861663264887, 0.09548616874963045, 0.09405626476343189, 0.22521050886384078, 0.13961308555943625, 0.1312390406216894, 0.11445815036339418, 0.10758927930146456, 0.11976585483976773, 0.1003220131886857, 0.2475759865982192, 0.1081508823803493, 0.10619317314454488, 0.13361954502761364, 0.11222774468894516, 0.08489063408757959, 0.19739221515400068, 0.09699342572795493, 0.17757907403366907, 0.1965817864984274, 0.12276195335601058, 0.14315174067659037, 0.18616923237485544, 0.15367101478789533, 0.11021416487970523, 0.09078407713345119, 0.05396751341010843, 0.11549244129231998, 0.1480783527450902, 0.10892384911754302, 0.08794191107153893, 0.13145467905061586, 0.1729789323040417, 0.12684723628418787, 0.17754809212471756, 0.07825741823762655, 0.15558159298130445, 0.19578502353812965, 0.10635833535343409, 0.1254094477210726, 0.1310240671570812, 0.12630047276616096, 0.14532012146498474, 0.11669742449053697, 0.07621135017169373, 0.20006294255810125, 0.12058856497917857, 0.1055674281503473, 0.09580662048288754, 0.08638613883938108, 0.13700095643954618, 0.09044508103813444, 0.10049022880515882], [0.024761897179165056, 0.06362799288971083, 0.07123783776270491, 0.030039247391479354, 0.012368959723971784, 0.04002918276403632, 0.03058987855911255, 0.10701420051710946, 0.019220454352242605, 0.023445647808590105, 0.05913279338606766, 0.06211160283003535, 0.005058467113745532, 0.027729583737839545, 0.04645349464512297, 0.10537211863057953, 0.031969784692462, 0.03012914988877518, 0.030713504246835197, 0.01940042389157627, 0.03309843270108104, 0.02319073916545936, 0.013360848999582231, 0.022945440274530222, 0.04443763495822038, 0.044606118596025875, 0.06416236635829721, 0.05071988196245261, 0.0549990528795336, 0.03448524292824524, 0.028603748884052038, 0.041898570489138365, 0.007487036819968904, 0.03433594486809202, 0.021568806376308203, 0.020465542362736802, 0.0229935450146773, 0.03420007501595786, 0.023752047081610987, 0.023226626882595674, 0.03578862388219152, 0.07204414092536483, 0.013433230874527777, 0.06966492573597602, 0.06920135061123542, 0.028074886816154634, 0.03813802424286093, 0.03895632729732564, 0.028608593624085188, 0.07191566031958375, 0.042781812737562826, 0.02138240771767284, 0.0920097827911377, 0.025402106843622665, 0.04921626532450318, 0.0765843273007444, 0.048784099585775814, 0.0277584978113217, 0.029173409566283226, 0.01680368055323405, 0.01589463870706303, 0.09945757314562798, 0.008974980147156333, 0.0370292539176132, 0.02122050926222333, 0.04242907291544335, 0.037151464859821966, 0.007233732912157263, 0.038609945348330905, 0.014372050229992186, 0.03771905940292137, 0.04828279112864818, 0.06305618464414563, 0.04007882099332554, 0.0546359823617552, 0.03493058581703475, 0.014264095308525222, 0.03271380851843527, 0.01772749749943614, 0.06267803707825285, 0.021933978656306863, 0.04938825359568, 0.01812654733657837, 0.02314427648005741, 0.04323737436373319, 0.023159842073385204, 0.012297416687943041, 0.0295688224557255, 0.0228287543037108, 0.030635187734982798, 0.03503296996599861, 0.02159941678733698, 0.05399657506495714, 0.02624235880960311, 0.017806102388671467, 0.0363270617755396, 0.07864140799002987, 0.030746793174850087, 0.03236843080126813, 0.028808181307145526, 0.03029543168044516, 0.012431759836285241, 0.025727791778211082, 0.01518895210964339, 0.02856878058186599, 0.02643010944926313, 0.04100532663453903, 0.01983021306140082, 0.037527637888810465, 0.04434835332046662, 0.014697168587840028, 0.03574840032628604, 0.04492321497361575, 0.024544911858226572, 0.060858226514288356, 0.03431745478883386, 0.022050825779193213, 0.047700787894427776, 0.02913334546610713, 0.02511420952422278, 0.046528866314994435, 0.0460618442323591, 0.05266554380900093, 0.030601915770343373, 0.023583917978352735, 0.08982451326612916, 0.01216433137389166, 0.038066917165581665, 0.04231438014124121, 0.047924412680523734, 0.012684617607322122, 0.02384438891229885, 0.08837510139814445, 0.03418686733181987, 0.029133508314511607, 0.026732720800542405, 0.05560346473274486, 0.02816449584705489, 0.007613577663765422, 0.08161915891936847, 0.04043579826663647, 0.05955810592110668, 0.009463225108837443, 0.04624485191223877, 0.029165738727897406, 0.013205014102693115, 0.03238570291016783, 0.019545503160251037, 0.0642340060855661, 0.02794104578372623, 0.02657589439435729, 0.041655336041003466, 0.04069645410137517, 0.02304952754639089, 0.05558937156040754, 0.027326628931664994, 0.005469309465427483, 0.022351586426209127, 0.03874239877664617, 0.044587655658168454, 0.01565241697244346, 0.04429307985784752, 0.09268533904105425, 0.02407023081156824, 0.0449341326020658, 0.020170949599040405, 0.013294970034621656, 0.03260883915105036, 0.09133447081382785, 0.021833319682627916, 0.03470046745081033, 0.04959358847034829, 0.0389354148480509, 0.05833411017166717, 0.01551667773830039, 0.030564067087003162, 0.017730637420234934, 0.023969441219898205, 0.018972068126978617, 0.020365354970895817, 0.040810352989605496, 0.015174049784296324, 0.041613487393728325, 0.10070453052009855, 0.01983709679916501, 0.034078203341258426, 0.06686737335153989, 0.01595613094312804, 0.04366406432486006, 0.07888572809419461, 0.01830930565483868, 0.08823108234043632, 0.07879084854253701, 0.04950168090207236, 0.024862696948860372, 0.06918602250516415, 0.02677233876394374, 0.024067462388692156, 0.033019464795610735, 0.07414061057248286, 0.025094871276191304, 0.008800817171244748, 0.06157860678753682, 0.027941174705379775, 0.06169622404766934, 0.02971535548567772, 0.025192812717120563, 0.0020435426434102866, 0.049139377128865035, 0.01966280659793743, 0.012997153381417905, 0.012254269494275962, 0.021927059295454195, 0.06615580724818365, 0.046269469162715335, 0.051605373554463894, 0.049175393767654896, 0.06276499134089265, 0.029116358341915265, 0.08800637868366071, 0.043390740241323195, 0.07495384157768317, 0.029748888686299324, 0.03498898732608982, 0.04531380008640034, 0.030230550161961998, 0.06146499966936452, 0.014433281230075019, 0.05926778114267758, 0.04848881132368531, 0.031722784374973605, 0.02237313500206385, 0.030859236605465412, 0.011593459506652184, 0.03657326142170599, 0.026719631860032678, 0.022370529427592243, 0.03360468767849462, 0.03528896087248411, 0.04438876347350223, 0.01500753898705755, 0.03168077966464417, 0.038424681539514234, 0.02585954631545714, 0.027823353884741664, 0.01582237133490188, 0.035639610806746144, 0.01499859759184931, 0.04544405506125518, 0.028725403427545513, 0.07549940408872706, 0.02467728895135224, 0.03005300129630736, 0.020991259420822774, 0.045494914653577974, 0.007266589274097766, 0.06689340195485524, 0.046335229384047646, 0.05387815374082752, 0.026786996816684092, 0.030276924637811523, 0.002921663224697113, 0.06180721202066966, 0.018868901966405765, 0.050697459772761376, 0.028151071031710932, 0.041945097635367086, 0.020693620034892644, 0.090475920454732, 0.0494607957745237, 0.052409803960472345, 0.037484608590602875, 0.09060324755098138, 0.061364359355398586, 0.007567315994362746, 0.0897430076396891, 0.044143333964582, 0.015713237458840013, 0.05342632066458464, 0.02720855874940753, 0.035156524407544305, 0.07171478681266308, 0.016756266222468445, 0.03437704712684665, 0.045962326893849034, 0.06191807785736663, 0.030719631418053592, 0.03407815245113202, 0.030771481671503613, 0.027600292282711183, 0.033020007623625655, 0.029242114629596472, 0.03162264617692147, 0.040001037131462774, 0.027938514848106673, 0.028333639360166023, 0.03477753206555333, 0.014933349664456077, 0.0531532849584307, 0.02758660792772259, 0.02821116378929998, 0.06873090871210609, 0.0424300025084189, 0.030195575074425766, 0.11011655761727265, 0.019043724817622985, 0.016562169584046518, 0.020653335410835486, 0.04565601243770548, 0.0374019121352051, 0.02768739921573017, 0.03976831319076674, 0.020540196481826048, 0.0005953721234358714, 0.02927224158442446, 0.02412888846759285, 0.014101243511374508, 0.043157029032175026, 0.021346212963440588, 0.016682121004643183, 0.04429038268114839, 0.02378578214640064, 0.007824011729098856, 0.01684021287863808, 0.026638353542823876, 0.012676402244583836, 0.022200551316408173, 0.030022175450410162, 0.05241031964708652, 0.031465290513421805, 0.028806003209735666, 0.020119379241285578, 0.04202988737129739, 0.020716191502287984, 0.017842719530952827, 0.028652823929275786, 0.024675200759832348, 0.021580835105851293, 0.0758841877271022, 0.02383464345309351, 0.03227974288165569, 0.02174847905657121, 0.010235900075973144, 0.06885203399828502, 0.0393069195561111, 0.055612204263785055, 0.02995658147015742, 0.06742996030620166, 0.13341219829661505, 0.04737272299826145, 0.04333839465730956, 0.026688465050288608, 0.16051071562937327, 0.1220685855618545, 0.13010113739541598, 0.08537491810108934, 0.15824989123003824, 0.15054235767040933, 0.09794500323810748, 0.32154417463711327, 0.14208087671015943, 0.048545899867479286, 0.19198320539934294, 0.14890892032001699, 0.09976486129952328, 0.1209266654082707, 0.07836714413549219, 0.20614796318113804, 0.17305012419819832, 0.16552993415721826, 0.11122271897537367, 0.16810091691357748, 0.10989922963614975, 0.10651404556951352, 0.06930247268506459, 0.15198991713779314, 0.10417381221694605, 0.14820544235408306, 0.14697470196655818, 0.15523372164794377, 0.22223312434341225, 0.05432568151237709, 0.1681831417871373, 0.11024086523268904, 0.13673904192234787, 0.15774261845009668, 0.20858736442668097, 0.15441884180264814, 0.0923293185021196, 0.12723280702318462, 0.15931156783231668, 0.12940923523690018, 0.1207632063222783, 0.15175025856920651, 0.10226267762482166, 0.20185358290161404, 0.11937329519007887, 0.14129805085914476, 0.2133602611720562, 0.31518806570342606, 0.12729163600930146, 0.0969933850158538, 0.16848388207810266, 0.0830332598249827, 0.25534743815660477, 0.08342346495815686, 0.1274426236216511, 0.11104889865964651, 0.10139788474355425, 0.07595056880797658, 0.13951969199946948, 0.16187073050865106, 0.10033308009483985, 0.15008300303348474, 0.08171587051557642, 0.17830407513039453, 0.09434484570686306, 0.10806415203426566, 0.18406311395977223, 0.0826361607760191, 0.15659744132842335, 0.10555953678808042, 0.13358553685247898, 0.14761274201529367, 0.16267436024333748, 0.10984749134097781, 0.12125187367200851, 0.11626005438821656, 0.06093046335237367, 0.16017931912626537, 0.11307268363556691, 0.07718181809676544, 0.11769016193492071, 0.10645305205668722, 0.1466389899807317, 0.07567452040633985, 0.13169045639889582, 0.11505796174917902, 0.09134175149457795, 0.1787967322660344, 0.11032835553799357, 0.21616436141942227, 0.2197462392172643, 0.09156880966786828, 0.1626465538782733, 0.10550264162676674, 0.18962054646440915, 0.192703497463039, 0.13669363435889992, 0.1627980436065367, 0.11185402117137398, 0.19771814266485827, 0.11675976828805038, 0.080925886120115, 0.11711480495120798, 0.08658587240747043, 0.17914914978402002, 0.13663479180208274, 0.09912346928779568, 0.12330389927540507, 0.12465992436877318, 0.17580625201974595, 0.09439860603639058, 0.11642975599638053, 0.15842164201395853, 0.06582852945263896, 0.11660386808216572, 0.10744426279727902, 0.10413034526365143, 0.2277285387473447, 0.14659316172557219, 0.15299467822270735, 0.11470563922609602, 0.11019046365150384, 0.15070319761122974, 0.13405747152864933, 0.08687205133693558, 0.19133909924754075, 0.1539974037025656, 0.07011632794248206, 0.2293053184236799, 0.18179287149437837, 0.09761853289923497, 0.0971534853535039, 0.11302105390599795, 0.08107719264392342, 0.14449760131537914, 0.09438380040228367, 0.12596634855227812, 0.127594493329525, 0.1562613493629864, 0.18277027404734067, 0.10404611192643642, 0.1870946455746889, 0.12119001841970853, 0.1902943453086274, 0.11736717926604406, 0.16447082241731031, 0.0948039289297802, 0.13993367978504725, 0.11158800151731287, 0.1628606588180576, 0.11159726352031742, 0.17997415337179387, 0.1568490828254393, 0.11138464457222394, 0.17811214471501963, 0.06699940948081867, 0.09742332515972, 0.15328116927828106, 0.09350264125636645, 0.1278387659362384, 0.1090881699430091, 0.12195890716144017, 0.24952381636415208, 0.09517260414681264, 0.13308959560734884, 0.13170366069035871, 0.09006845339068345, 0.14400680336569036, 0.13037537410855293, 0.10628669562616519, 0.08381745631673507, 0.18255671193557127, 0.23297969411526406, 0.10042013613773243, 0.0819030918979219, 0.1071019350950207], [0.042435179730611186, 0.015665466897189617, 0.024131349853373, 0.07166169823280402, 0.028417150057586174, 0.07318496863756861, 0.012820100694495653, 0.05435001717082091, 0.05416712144921933, 0.07389848213642836, 0.012789102670337473, 0.019306195733536567, 0.012384008782516633, 0.06989795501743044, 0.011104284951995527, 0.02871223645550864, 0.034432839668755016, 0.04928208322131208, 0.03270638873800635, 0.035205840332699675, 0.02465687013630356, 0.06963891070336103, 0.03734758183626192, 0.0658502493585859, 0.05136964709631034, 0.02612544213687735, 0.022941933944821358, 0.004099706886336207, 0.038705591644559584, 0.04108643192531807, 0.05967202516538756, 0.040968200590993674, 0.04562511873830642, 0.027641129912808537, 0.05089943250641227, 0.04947002385077732, 0.044101254615400515, 0.044494211208075285, 0.01947672854709838, 0.04343345741342221, 0.025852294472445334, 0.07257973575698477, 0.02619376722058015, 0.02279764516944332, 0.03024935576000384, 0.013321315004889454, 0.015922875941864083, 0.02806968754157424, 0.056586797681770155, 0.014043356840764838, 0.034652315213211944, 0.08066315057554416, 0.04912824236920901, 0.013652761549954968, 0.01905796387498932, 0.08394968922116927, 0.06672812439501286, 0.04969504641901169, 0.05427077445866806, 0.03987961668255074, 0.07562146575323173, 0.02404553383322699, 0.055914990337831635, 0.013429858555485095, 0.014385564951226115, 0.04854337910988501, 0.025002695686583008, 0.025511113494368534, 0.05881912021764687, 0.06175410308476005, 0.03174646185444934, 0.08854537297572408, 0.02142659731076232, 0.055731762134070904, 0.01609191088937223, 0.03437178169510194, 0.03222509027857866, 0.05448983270408852, 0.039543623104691505, 0.02552461464490209, 0.04208355609859739, 0.028090218314900994, 0.04893866307767374, 0.04374661150255373, 0.06016913349074977, 0.029990820347198417, 0.04725322958880237, 0.04298172611743212, 0.020514127166409577, 0.043402485682496, 0.14184751494654588, 0.027357195237917558, 0.03857915342918464, 0.06756019153233085, 0.07430823586348977, 0.02958551441718425, 0.04737795111058014, 0.03435806850237506, 0.06683360266366176, 0.08938499220779964, 0.029819938088102, 0.037078037192778926, 0.060195019601711204, 0.02495256551940526, 0.019532622869259546, 0.03493170200714043, 0.010987766918593218, 0.023304412440795983, 0.041678996557103734, 0.05401072252009596, 0.05214830334963543, 0.07038639166525432, 0.014105926251171954, 0.08848096643175397, 0.02383175628658916, 0.051547453805272064, 0.016680390740345632, 0.016846932071660246, 0.029845359402575662, 0.03006048553756305, 0.02003344617384885, 0.08738065404551369, 0.019917540518300872, 0.1239582784473896, 0.008387876874102014, 0.023068607951115285, 0.035188754820930104, 0.027689982737813677, 0.05223141710406967, 0.05688762278961284, 0.0916902877922569, 0.020237147475459745, 0.06121808077607836, 0.031334397715649435, 0.07972075364419393, 0.03180477176127689, 0.049879244927849085, 0.012218812646876489, 0.03883467275383217, 0.034616681946707625, 0.05845378339290619, 0.05325074972850936, 0.03659410262480378, 0.060814671351441314, 0.02417694401395108, 0.04553158947133592, 0.036940606710101874, 0.06532547037516322, 0.10316278146845953, 0.05612125141280038, 0.007101368541563196, 0.008547560760884412, 0.037787923921964, 0.04810918455145188, 0.01582199814064162, 0.01446992890643222, 0.012841839260155601, 0.036823912257594724, 0.045686203853360245, 0.054684738495520184, 0.002383147511864081, 0.03320670314133167, 0.020676912806395973, 0.09235746413469315, 0.05980757610606296, 0.009146702941507101, 0.06650502886623144, 0.008373517376769866, 0.03299552608015282, 0.02303853358275124, 0.043503848636256795, 0.025641091966203282, 0.008989269246480294, 0.06265264629785504, 0.1334476585366896, 0.02239456822696541, 0.019470139972067306, 0.03410529045920287, 0.043099394267691035, 0.030752981414220164, 0.043112038767763546, 0.010011472922217633, 0.042934913986495564, 0.039683760942092965, 0.07044003664382867, 0.015199564397335052, 0.02486769775194781, 0.04133742881406631, 0.01973605784587562, 0.0926954559981823, 0.012796030512877872, 0.04906252285997782, 0.030541865421192985, 0.04669016765962754, 0.04240853026775377, 0.00226777556651671, 0.0024351237183769365, 0.04740401024797133, 0.01046517790694322, 0.01566498853000147, 0.03163589796583567, 0.0402132353878447, 0.0235140271750944, 0.016366890598354594, 0.04523452005482145, 0.01853413992960538, 0.029678928333201578, 0.016340305596323948, 0.024866586650854776, 0.028584057797810862, 0.011374251983527626, 0.026548515506354824, 0.03158520122191735, 0.02513938826242728, 0.025099412371803607, 0.0706139248130577, 0.020251345820724964, 0.054992270922022204, 0.018152414787826792, 0.05612968221040709, 0.028007659262844493, 0.01828453573398292, 0.06921225466898509, 0.1051737896299788, 0.04341625315802438, 0.002336239113771756, 0.013364036417832332, 0.04133301494377, 0.008606326982512005, 0.07111969803060804, 0.05825800568397556, 0.02170561599944319, 0.06140927837363311, 0.007666959710020039, 0.027025344116347175, 0.05096619017422199, 0.038275994160877805, 0.04503072884732059, 0.06675924201096807, 0.04195976756247027, 0.02266382279672793, 0.015676265782011405, 0.01223115943970957, 0.08109628661934819, 0.05724314121263368, 0.028124224793698107, 0.01603026598292802, 0.04788515942969492, 0.05360257352835365, 0.007124469266273081, 0.030285949153559547, 0.03834740997159055, 0.017692417238972018, 0.027501524725396718, 0.03493329656443425, 0.02622128520826144, 0.06020196780030217, 0.042408503126353025, 0.027729587130514637, 0.03093270837728466, 0.05341879910390292, 0.03400348985035505, 0.026869359093585184, 0.014203585251899702, 0.03429957878376756, 0.07825615616249186, 0.05143926818189876, 0.014112059359571763, 0.0165813297166356, 0.0730068056977221, 0.03325848214860473, 0.012763845052437058, 0.0167092725834144, 0.026511475976024355, 0.05133944210995521, 0.014644205536959427, 0.028828418614076715, 0.051673189736902714, 0.05895406726215567, 0.03907650263447847, 0.07112613732793502, 0.02028193587570318, 0.02776613811563168, 0.004776844971014985, 0.036922279479248185, 0.04339905568797674, 0.011350066450956677, 0.022155191250411526, 0.027821092666792016, 0.021165878711534396, 0.06635214135582958, 0.020734344010374377, 0.01803899765945971, 0.07368177162217242, 0.019657111992793422, 0.06710194969283682, 0.025430712183671336, 0.03593368109847818, 0.017629469545292, 0.03383212583139539, 0.020243081264197826, 0.009180747587899012, 0.03182671219110489, 0.06224285185869251, 0.0031829288927838206, 0.06948325477008309, 0.06352537125349045, 0.020489338585840802, 0.028279760287010243, 0.05382096341678074, 0.07451805924730641, 0.01593526259862951, 0.0716354050008314, 0.017824663714106594, 0.03698504736114826, 0.05591566887285028, 0.08408640724207674, 0.06309569573828153, 0.07255309647215263, 0.07376518393201487, 0.03545168035530618, 0.07553009422762053, 0.007062334118277899, 0.032859347494585175, 0.04557348222338727, 0.039355984423309565, 0.03051305143162608, 0.01886743463442794, 0.01961572135665587, 0.055739697601114, 0.007687398881119276, 0.020762940868735313, 0.031758495673005066, 0.03236676839047244, 0.025073779015136615, 0.055653401517442296, 0.0075276954864550915, 0.015517583582550287, 0.049802299056734355, 0.07729788151170526, 0.0282679334216352, 0.023191219228985052, 0.06389781233987638, 0.007932623133196362, 0.0682191847424422, 0.05561280476727656, 0.028574442956596613, 0.037673237933112044, 0.025411239924973676, 0.05264544899442366, 0.08966764954051801, 0.12181211289550577, 0.10477427499634878, 0.10668483283370733, 0.11798871734312602, 0.11691048448639256, 0.10323553399315902, 0.24835784892950738, 0.09858821372368506, 0.0991344004869461, 0.16521144339016505, 0.12010086114917483, 0.13890887477568217, 0.17434152561639035, 0.17555113642343453, 0.14714478355433258, 0.07910315785557032, 0.11066594706582171, 0.07890336321932928, 0.10009263442563159, 0.10121041908860207, 0.1232891750655004, 0.05678414959194405, 0.21821748624954904, 0.12915150049541677, 0.14733048501823628, 0.12548880917685373, 0.21317753169153417, 0.09792155306786299, 0.10539199292127575, 0.12880284206143447, 0.07601349614560604, 0.11228062970829861, 0.14320662058889866, 0.11625374401254313, 0.12415132166019507, 0.13039505162409373, 0.11142278502562217, 0.11330044748527662, 0.09110361962978329, 0.08303457618291889, 0.23016057110258512, 0.14191930395151886, 0.1671559483345066, 0.15089808643928596, 0.15757656736033304, 0.12781167881829397, 0.09827930387109518, 0.16394095442124776, 0.17525937993611607, 0.10260066948831081, 0.14493711558835848, 0.07013420734022345, 0.17570544885737555, 0.0869346936898572, 0.18246941162007196, 0.12707735465041228, 0.17716319992073945, 0.12497789944921221, 0.12845574425799505, 0.06854534295520612, 0.1530776766261884, 0.08705708783652101, 0.13228011690080166, 0.30474888586572235, 0.11221120200519051, 0.09249998363001005, 0.11261570387120758, 0.07687672839633056, 0.1649417257202523, 0.12396433097975594, 0.11229776271751948, 0.07996268530509301, 0.18059223092028073, 0.10607515554875135, 0.11257460500512805, 0.07944026083818503, 0.145980675305639, 0.10727656286742006, 0.11881522727864129, 0.17771563599152224, 0.0948155861614006, 0.1891233567148447, 0.10526780065681253, 0.19733158126473427, 0.16255316031830652, 0.16953704985124723, 0.09702449584645884, 0.1404191715908902, 0.057923732192388604, 0.08551808220467397, 0.1284167149237224, 0.21936431899666786, 0.10696052839713437, 0.14764544740319252, 0.1332334586020027, 0.13241046347788402, 0.08223477338573762, 0.11688798426517419, 0.158388258091041, 0.15717667953244277, 0.26005039151225773, 0.1865293173385518, 0.1425265520811081, 0.14954525046050549, 0.10340659945671048, 0.1037978156070624, 0.13528167083859444, 0.09055100035454546, 0.10487837583890983, 0.13667059130966663, 0.1304393463901111, 0.1820450151073081, 0.16407799135361398, 0.10617317671754531, 0.14309968346995966, 0.129695074898856, 0.12344185901539666, 0.08648827871573822, 0.16789093746670655, 0.0939708643459848, 0.14854350207107408, 0.11238943279853889, 0.16665470094553061, 0.06652847903647593, 0.22526694940669195, 0.08152853378227778, 0.12624494146023477, 0.11606152861246041, 0.20084431634417602, 0.16667464987507888, 0.20555762414421352, 0.18773511477879115, 0.12052980384656362, 0.1309458999229329, 0.10722513669835669, 0.0878393572888204, 0.11379741331828491, 0.23723798990249634, 0.17054016888141632, 0.1408400804336582, 0.08751977408038718, 0.18105111058269227, 0.1463142159794058, 0.18403423550937856, 0.15292341847504887, 0.09537089243531227, 0.13238474700067723, 0.19421344144003733, 0.18013964806284222, 0.22784334687250002, 0.22451643539326532, 0.09525127349687473, 0.10648751485028438, 0.1172711258488042, 0.16949126230818884, 0.11203651316463947, 0.10706746551607337, 0.11646346561610699, 0.16042649586285862, 0.1389003252344472, 0.09681780729442835, 0.09443998310182776, 0.14744285041732447, 0.14194863023502485, 0.22361691508974346, 0.1711968415017639, 0.1324891328279461, 0.19173016612018856, 0.08832364808768034, 0.08530024532228708, 0.18577910188053334, 0.13247238658368587, 0.10686381680092641, 0.08109984892819609, 0.1844508152987276, 0.29043985796826227, 0.17427872041506426], [0.02574044984898397, 0.020201151192720448, 0.03762699577159115, 0.039447111676314046, 0.03939584157030497, 0.02673723645109151, 0.03243977536580392, 0.05073509132489562, 0.02455152927099594, 0.0847438805337463, 0.031928231207919974, 0.018417202900829058, 0.050966977274843624, 0.05663909237565739, 0.056206187033759694, 0.02094581793062389, 0.049708128574171236, 0.03815792906763298, 0.02026717265003494, 0.0639109080657363, 0.002189791324781254, 0.013821683691016265, 0.00506857898186094, 0.04649854937036123, 0.05381621027897511, 0.01993590676491814, 0.04313181806355715, 0.05488746101036668, 0.05258674553728529, 0.04790715414232441, 0.034336161999297996, 0.016187691196267093, 0.006311521549443049, 0.044542984305215735, 0.046921744876142056, 0.026121772958764007, 0.0018759260461333074, 0.034435513096728494, 0.05622687217380319, 0.00911213327864451, 0.012784266411992056, 0.04346786253154278, 0.011373865218566996, 0.017804083746990988, 0.04173945402726531, 0.01886220652210925, 0.015716250154322813, 0.05155092790456755, 0.03010293808100479, 0.03277679013886622, 0.02495923891131367, 0.022792208407606398, 0.028522562169070755, 0.05032035375812224, 0.053342355348701985, 0.03836198151111603, 0.024594850339261547, 0.03936044579105718, 0.06484715068446738, 0.06560174947870628, 0.0424655475653708, 0.0177902976117496, 0.007785837348949696, 0.014547437961612428, 0.022130472219682167, 0.03393530047365597, 0.04243219417652913, 0.025291234221575514, 0.03903417222734008, 0.04171302169561386, 0.01881518234897937, 0.03142823910872851, 0.02827213185706309, 0.06970928157014505, 0.04236868329878364, 0.03775956455085959, 0.050792105229837556, 0.010114298118943614, 0.04127946835277336, 0.030992283751921992, 0.027968475561855093, 0.0027917911980434185, 0.00439932759452079, 0.04779794732374804, 0.030693830123969486, 0.07324125990271568, 0.023369365205456103, 0.036144847981631756, 0.012327281558620078, 0.03899131595556225, 0.05908062082848378, 0.0283510963698583, 0.041771416419318745, 0.07536508129643542, 0.06542467219488961, 0.01751319408815886, 0.055422170353787284, 0.05233524653262325, 0.01969985630629318, 0.06764173787087202, 0.028562100404607396, 0.04768522569377508, 0.020842108942036117, 0.0354986587273223, 0.06280284002423286, 0.030095087430839027, 0.042113560917122025, 0.019853198435157537, 0.0615189296326467, 0.024840556351201873, 0.009902951424010098, 0.014345163279878241, 0.04798967078594225, 0.04413392607654844, 0.03847121886376824, 0.0280749037795301, 0.07637322148574249, 0.07336965908429452, 0.01087393842837108, 0.05292177898809314, 0.08720983963991914, 0.06623971488858972, 0.040173133968242576, 0.04510874341108969, 0.04675142919378621, 0.024541105276771953, 0.06321056493158851, 0.04769829427823424, 0.03398809049810682, 0.0478045460768044, 0.026954578002914786, 0.04407723108306527, 0.021844546044511453, 0.05059575415881617, 0.0528029166162014, 0.04977155802771449, 0.07135018959109272, 0.029106607793697288, 0.016805222524063926, 0.05403200137828078, 0.023694329196587205, 0.1441010111676795, 0.06424496442611728, 0.028155988714258586, 0.012611121238608445, 0.0249117058369198, 0.030082714344773973, 0.03592227153213961, 0.04409689163523061, 0.04329170805535146, 0.04880877111905387, 0.04312286479398608, 0.03389046287962368, 0.03614245614569102, 0.06715975409107548, 0.02897566071312342, 0.011675755626388958, 0.04965375417045184, 0.03497250571048685, 0.034949805321437974, 0.09160574911428349, 0.047743620417479954, 0.05581920833459922, 0.04801496657143746, 0.02358056092634797, 0.10020499303936958, 0.008366229910669582, 0.038808413448610475, 0.046596400905400515, 0.032747755625418255, 0.022474419924297502, 0.016920926315443854, 0.061199502487267764, 0.01838455518840679, 0.016966344056917087, 0.051354190068585534, 0.0439314749757094, 0.018062612374446223, 0.07073529437184334, 0.042793656566313336, 0.0460891043767333, 0.03758643973352654, 0.013557060970924795, 0.08786176930048636, 0.03914603211783937, 0.07065198384225368, 0.04138082452118397, 0.020206755891974484, 0.03369994720976267, 0.02995252043807081, 0.041900721445147476, 0.0340122463447707, 0.03606407856568694, 0.030314535833895206, 0.023755672154948115, 0.02214399372626628, 0.03210915917796748, 0.017796428175643086, 0.028499030574624027, 0.03806884420503463, 0.04602540011650749, 0.10435434324400765, 0.02339554308647556, 0.01900978958500283, 0.0350530071050993, 0.027369451276691895, 0.058744868130556176, 0.035888680656041415, 0.032502943583364995, 0.07356538929577384, 0.022693617269396782, 0.06462077783154589, 0.06376145394252879, 0.0548418668497886, 0.056521186738141944, 0.047487948422453234, 0.019004276487976313, 0.027820086738626872, 0.02061106267917369, 0.026489457514669214, 0.034318404737859964, 0.005682662079509879, 0.03219453923936401, 0.031728005701942105, 0.057074633826102526, 0.061742377999637804, 0.027828824573329518, 0.03888853486361248, 0.04683374227689845, 0.05594090698286891, 0.06386328169277736, 0.025528819865680168, 0.044493407144078186, 0.020983527514285276, 0.051023906362908225, 0.039410348649003675, 0.08562812022864819, 0.01009144336317799, 0.018913551266970377, 0.09956010657229594, 0.053160260298422406, 0.028161018355084316, 0.05903212593070098, 0.02782810871888484, 0.010126917173952928, 0.03973862389102578, 0.009664460783824325, 0.021406471962109208, 0.05982987955212593, 0.015833774115890265, 0.060175715280430656, 0.028368307410606315, 0.06045485780175243, 0.07319311105779239, 0.021617457337145294, 0.02850123242075954, 0.0715109006102596, 0.02763043450457709, 0.0283812419843993, 0.006408651716940637, 0.027067594795620868, 0.039855101212326965, 0.026373312675527165, 0.013860848732292652, 0.029463527391531637, 0.025555348888571774, 0.008004272190321769, 0.04749337670260242, 0.03510508806045566, 0.053967642331761975, 0.029683467732476335, 0.05713349673897028, 0.02630738790945283, 0.06493323642228331, 0.028051014257861034, 0.048096224532595704, 0.025005207962489555, 0.06799849801297699, 0.036403495352715254, 0.05012085767728942, 0.026999895660472766, 0.02613311297526317, 0.06486243807843753, 0.007308447251229414, 0.03573043271899223, 0.023396671150944064, 0.022265005357829586, 0.013244492966415626, 0.05389728842835341, 0.0519272264625345, 0.03711604533184852, 0.04867485544777342, 0.016911126573437026, 0.04555818125871675, 0.028136094067511812, 0.04065217290605817, 0.04176892280312521, 0.08701474046600716, 0.030075131715940576, 0.04080420885501163, 0.0028143020213714665, 0.010168970229902437, 0.056238593866250346, 0.012226351170933672, 0.03752650812800441, 0.011765995694856559, 0.01253746117332152, 0.030223137166883265, 0.006817701888004584, 0.0526445736842496, 0.051161374165011306, 0.03312756560210671, 0.06658985252891268, 0.013232971441798975, 0.03268795972689986, 0.029589890968054533, 0.026067746304241673, 0.05113168486527034, 0.0028191003241642776, 0.0299580471057977, 0.015320920385420322, 0.013202930152017091, 0.023669432050415447, 0.024536194379574487, 0.10563064047268458, 0.047765177475022416, 0.02297378607493426, 0.017751677094825676, 0.03204327682033181, 0.011256561780880605, 0.031013433688453267, 0.006996587891730347, 0.034066210234803815, 0.07663679841373648, 0.026955573753054653, 0.04119394240634782, 0.03570587653666735, 0.026448999864182303, 0.056432566672031365, 0.03176106732072575, 0.008873963246255048, 0.08877583739480802, 0.06741807915802513, 0.05791242779897792, 0.0579481798091105, 0.046294049093765874, 0.05174266154478703, 0.05049825206931148, 0.13419050510440553, 0.02178110641294292, 0.025518533274797455, 0.016101576620712876, 0.11666230351797172, 0.10431225371680089, 0.15545192493924073, 0.1603787677096469, 0.07743368351033755, 0.1362337911767619, 0.10776117936308895, 0.1256213542073965, 0.08962724278015749, 0.14904565869697503, 0.14321449159511498, 0.08254611917904445, 0.16894976422190666, 0.14511900368545735, 0.1548846425222499, 0.09144946892878839, 0.1140333738710199, 0.13016615462090286, 0.05807689790214811, 0.1000691842553871, 0.08940831345639058, 0.0733846275668059, 0.11027630511671305, 0.16663908106940134, 0.11470726771014077, 0.11506748838084084, 0.09282880170004708, 0.12151693659169333, 0.1377158337937934, 0.12157852042998586, 0.07553952586437974, 0.13395945035985538, 0.16828014515340328, 0.12918700144759246, 0.1332482099533081, 0.09451969739581857, 0.13385719513254507, 0.13672923030597822, 0.16648209520748683, 0.09736905592892851, 0.05656949843146971, 0.10097165618624006, 0.17427454063934938, 0.14231502557439463, 0.09408490572656904, 0.06450376446757998, 0.10604371902133737, 0.07888555846043996, 0.10558304802647658, 0.13239637709089688, 0.17023172043263912, 0.11165271340204136, 0.16317794179277761, 0.15520525031856128, 0.12406243357275214, 0.12780204362102918, 0.14430861574198517, 0.10797098239085504, 0.1595728580972978, 0.15067874320915767, 0.14144373232764856, 0.13158204007361615, 0.07766588497906923, 0.14355038000004633, 0.11386663067553725, 0.1743210202881268, 0.13618332174207481, 0.11070999077388219, 0.13372101315430232, 0.1354809972856726, 0.08657881564327649, 0.07013172390205519, 0.13603465471948895, 0.1674849699650492, 0.15809504953878267, 0.1638394591531583, 0.09717011624681098, 0.12894810283822672, 0.07979202696255275, 0.09905628075024911, 0.1594014194394861, 0.16169087801660809, 0.12416190680648599, 0.09129216415541512, 0.120765160503132, 0.10177692797567163, 0.0817802974155971, 0.15140155942312308, 0.15782158635556698, 0.13338668537991388, 0.13196645730308124, 0.12240892515650817, 0.09826675097325019, 0.13499451481870242, 0.19960683131856577, 0.07526532986334392, 0.13618862788592065, 0.1417924721858331, 0.158162048086524, 0.12520660646259785, 0.11026293797684567, 0.14615117758512497, 0.10333358908870391, 0.13007061689027719, 0.14607799079801354, 0.1069702518039516, 0.19644720586282866, 0.08070842921733856, 0.13617944052176817, 0.1167497666818755, 0.11894600811813559, 0.04715621265183602, 0.10314199115548815, 0.1445838702576501, 0.08256011057112898, 0.12266503141394683, 0.17140566743910313, 0.2291480340063572, 0.12164771743118763, 0.1619580579655511, 0.2051033449492284, 0.17985855814601692, 0.11241989223552601, 0.15029372886887618, 0.13863015973142215, 0.1257925893047026, 0.1457024488065924, 0.08728030550160579, 0.08933904860168695, 0.07899246843797819, 0.17233118920453958, 0.10558251876916204, 0.11415515733616692, 0.16490375490060874, 0.19328747184148856, 0.19195261704070227, 0.15575372374483518, 0.1053492994979024, 0.09525575182799782, 0.0982735702501876, 0.11861933421875749, 0.211299116058009, 0.13680477839495453, 0.12264795947287764, 0.08878944880728211, 0.05588504998013377, 0.12202644853719644, 0.11185784810887915, 0.12145559702600751, 0.12192119418510369, 0.1114140794213329, 0.15148621345204966, 0.10271014432821955, 0.08306475742054836, 0.16322896762617997, 0.17455831755484852, 0.11458836123347282, 0.21397402323782444, 0.09637436430369105, 0.06749839056283236, 0.14292824481214794, 0.1278895746384348, 0.12603360494332655, 0.1199176838355405, 0.15082749165594578, 0.21906625213367598, 0.11384195914225918, 0.1545374768653086, 0.2026845711682524, 0.11032875587365457, 0.17462300908352646, 0.13515152782201767, 0.21858367802841322, 0.11107988735394818, 0.11084429321012326, 0.12475407788796083], [0.05626101266326649, 0.060100452176162174, 0.007452897178674383, 0.028182841737621596, 0.05110058421269059, 0.0333341557665595, 0.028658947707819085, 0.033586021180131605, 0.02003197375285838, 0.02123709605075419, 0.057847010237830024, 0.057365983192409785, 0.03452284733897873, 0.04741559284073966, 0.019829017143430452, 0.06227411196700164, 0.028177023299836686, 0.07059457299432584, 0.044485515781811306, 0.050052848112370284, 0.04646922987220543, 0.021459697945309535, 0.05405570599915726, 0.04377217870205641, 0.027258744895724312, 0.037272074459386725, 0.04755277226545981, 0.03153721861807363, 0.04689608607441187, 0.025450415144275342, 0.023732798739469478, 0.02767336880788207, 0.044305130639778714, 0.0245557921672506, 0.022023726786885942, 0.008812033355103006, 0.030999289625989537, 0.0050386309906441185, 0.06662331109068223, 0.015230534431923713, 0.06408484373241663, 0.0015946747651988907, 0.0460080771174814, 0.05491995265973466, 0.01820399871628199, 0.05006706681368606, 0.04022954058434282, 0.041253249759652784, 0.0636577737916793, 0.03945853481335299, 0.02510657430892544, 0.008903120744175144, 0.056113451652761014, 0.052498437597283294, 0.06973133395825114, 0.09821505339017936, 0.0301186461666865, 0.08541894823844944, 0.017499964351632764, 0.028381947660818696, 0.015561764693952032, 0.042208386185978136, 0.020036170491948724, 0.07179026026278734, 0.04142215748184493, 0.024639262152569633, 0.027557403780519962, 0.037572156571383984, 0.015224176558798977, 0.033911456753100665, 0.024870286363043954, 0.01939807616041175, 0.02526077308825084, 0.010287301648142082, 0.044822248962840865, 0.04278065922803112, 0.033351617865264416, 0.10143012194229023, 0.04880435724875756, 0.02992144353421671, 0.032689028419554234, 0.08429258010749306, 0.03930029705432909, 0.028796089813113213, 0.03040921182504722, 0.015457716437854936, 0.06530584035707371, 0.02251956794810082, 0.01896398507856897, 0.005490597653468805, 0.05327078686761005, 0.041389893141708205, 0.06415383038776261, 0.08045207868729319, 0.04524156324831503, 0.025518509526071802, 0.017811188008636236, 0.0158139744640461, 0.028920119229171957, 0.04163777216204575, 0.01419211970642209, 0.046434617800904174, 0.01728041416832379, 0.004917663463857025, 0.009907424666120537, 0.0488928008957633, 0.027213605353608727, 0.04833009859014835, 0.03709267319313117, 0.044607991352677345, 0.007003333802068872, 0.028227921907923052, 0.032136877333479266, 0.0426694201970739, 0.04362682293036154, 0.08528624714485236, 0.054922660014459064, 0.025568281766027212, 0.05146407542218055, 0.04242796690336295, 0.01870463033472853, 0.0032062302094085938, 0.014521483997149127, 0.02519279405740755, 0.053659716354949136, 0.03657049299882991, 0.04932573677173682, 0.04687557735347322, 0.07916236682129757, 0.03690144845417567, 0.0961731718853116, 0.018788510833733847, 0.055032012718064446, 0.016730882227420807, 0.06068385658519609, 0.015434339210124952, 0.029765366909227202, 0.036179137748799155, 0.036501394385205846, 0.06934792774596385, 0.02828319537054215, 0.09299152796821934, 0.04322936425783804, 0.04733405668022377, 0.019078701601496766, 0.03274866486234324, 0.01906753291508981, 0.05690994659172637, 0.0515831311765526, 0.026148917752185037, 0.03025691124743649, 0.028419777684445893, 0.028958856793386594, 0.03167362451287253, 0.042649060753839355, 0.04584789535562907, 0.0506589461251029, 0.019656082315902625, 0.02960229798087052, 0.030427118364189352, 0.029316010485802377, 0.049846882200134654, 0.04883569538859384, 0.032768067571201494, 0.033627666266901154, 0.014672890604872788, 0.02138578173305307, 0.008231291347848517, 0.013436999288387597, 0.03881385869213513, 0.043508747659091435, 0.030720635649881194, 0.019250438814716678, 0.061390883289277554, 0.043133449940277, 0.02020253031514585, 0.06285877845117024, 0.009478810210047024, 0.028329773406897272, 0.02423021919094026, 0.041406822590423484, 0.07401693399463381, 0.030179259699902365, 0.05264440744317003, 0.02823206945322454, 0.010132229254980172, 0.05429356644994446, 0.04886113366644297, 0.025006207105304514, 0.05625255811693413, 0.03607004288850086, 0.05225080284955246, 0.0376349515946848, 0.06274896434375218, 0.05494659872991698, 0.04197234081636582, 0.01822371524758637, 0.05892125330865383, 0.06230332289955445, 0.04758978635072708, 0.06947330066135951, 0.06897020087178264, 0.059831698025975905, 0.04610234598762222, 0.03627872633348618, 0.01286255069343107, 0.028136906613196646, 0.026687360734545758, 0.046347032500697036, 0.03636851008715374, 0.08628961044762816, 0.03969991346821189, 0.024655397715313093, 0.030797137080558708, 0.04262233665212989, 0.02588882340517427, 0.03337414862055864, 0.0013758077818368161, 0.01776320710113006, 0.008660786203108728, 0.05802913582218545, 0.04378168158499258, 0.022950756596401334, 0.0443690452458603, 0.02837647866856839, 0.0644732303917408, 0.04285096902666347, 0.03892510790111763, 0.043090261186340025, 0.03815834636666945, 0.05611281382984348, 0.013910306301633162, 0.033957027164953094, 0.051034756137856414, 0.02968705379004989, 0.04596286972186395, 0.016801643251840557, 0.03242691373452544, 0.03264026550043907, 0.07523414439388684, 0.010716884712954717, 0.0233776501180338, 0.05862205329218081, 0.014411345889259661, 0.02054106500664992, 0.056261002485241206, 0.017344861424395015, 0.02553465187416545, 0.04634129209443927, 0.01906362794605749, 0.02996996896607535, 0.016753867601177523, 0.026733304340658442, 0.04759075665580375, 0.04331305815971323, 0.03457111832020538, 0.05500032513269356, 0.04319997351350529, 0.04652378748037985, 0.012803180575636881, 0.015285203998376216, 0.03804638808859246, 0.04867577486272369, 0.013558133904423033, 0.04422047321817704, 0.0019997459645050442, 0.05429603631741234, 0.053238512349448035, 0.051262801579598866, 0.054890616198203394, 0.021804916206747293, 0.034157351058508666, 0.044392444525978396, 0.015399415012715119, 0.010516096871080143, 0.010602261488591986, 0.01721580745652318, 0.05738554535699742, 0.012195253911029016, 0.04607764731294342, 0.01762668076636536, 0.06788596976548433, 0.029192506934383085, 0.06617351022682019, 0.04651516330029283, 0.04769920012248414, 0.03487771436838167, 0.004636771594440299, 0.04941841447725892, 0.03246057585680059, 0.008525346372542637, 0.028030685348702327, 0.03742713328184826, 0.05450143226023231, 0.01272389036603272, 0.06694443457360778, 0.032818767707794905, 0.11444316831018243, 0.03977483730497105, 0.04009602864139846, 0.06776607262768916, 0.031159172832433666, 0.04194304506693568, 0.04703573875927499, 0.03080882823893002, 0.016034082742407918, 0.030695953938577856, 0.10164451186678239, 0.04698941517355187, 0.023988759111879126, 0.08284861009035792, 0.050145658132221015, 0.09241292080176727, 0.0208317019111876, 0.031655639942203245, 0.027104600399200405, 0.09268706252000161, 0.012615220438289856, 0.04695701173373631, 0.04702722653746605, 0.021453148386042033, 0.028987786133906672, 0.059920301128711016, 0.07440100517123938, 0.062203992158174515, 0.04154498928359576, 0.040712718585772176, 0.011232351651415229, 0.02880080563149282, 0.018750558673803295, 0.019209875991301875, 0.029663868248462677, 0.014717039485861148, 0.05904445491198983, 0.055656132620892355, 0.020759069826453924, 0.007896325750542539, 0.05007629828261478, 0.04441964699487601, 0.07344899339867489, 0.018669838451647332, 0.047541172709316015, 0.031039492825844457, 0.0778966818803123, 0.06423475925943681, 0.08324207219162158, 0.03852139992107238, 0.02595705688664956, 0.025112335071233765, 0.06053514206515891, 0.03056853184742587, 0.020256880970139588, 0.12648411148360797, 0.08889997537646975, 0.08349564072809049, 0.11543023320181028, 0.16129177728933947, 0.10316263897610561, 0.08894860598125628, 0.1723954871829067, 0.07595436181873083, 0.07342476291315896, 0.20508473951901707, 0.16250208020210266, 0.13671981223991939, 0.13490633240767888, 0.1187283747962543, 0.16375146673194, 0.11800109382186617, 0.13385898646499428, 0.1748392717646701, 0.1528331461761679, 0.18542859783130033, 0.06135545019060373, 0.11495190672576427, 0.11817736364901066, 0.18988993843751295, 0.14947457425296307, 0.1231813829924379, 0.15434279159775802, 0.08336253251348223, 0.12900321345244134, 0.11312450335494109, 0.10343441939247505, 0.06450788317514317, 0.15648057045681135, 0.1805460091148104, 0.11244138143956661, 0.127796398209674, 0.06435858511498996, 0.1587585617921182, 0.1171650979667902, 0.1774128329541002, 0.12467931689960615, 0.1822147574275732, 0.10561920715762035, 0.15505880889083656, 0.20283504309398787, 0.09035715647041798, 0.08805466323558774, 0.1260139545691865, 0.13315573920096668, 0.1224096172622272, 0.09337359068116971, 0.1519368692700352, 0.11704108890678201, 0.1933539682733161, 0.21072799313281262, 0.10639536979475192, 0.09654926349009786, 0.11949860703732286, 0.1430703436157533, 0.11431191249617509, 0.12258975473897797, 0.1696569469890424, 0.13657449718032563, 0.07281575059252125, 0.09384160342493228, 0.14640260195093496, 0.09325744584202766, 0.10401412578565733, 0.18799208956105368, 0.17178690912468092, 0.10575261392763682, 0.08465454461319105, 0.08450766892305442, 0.09604192964200463, 0.15398642500596388, 0.11604782220508371, 0.2502462390278067, 0.12599362566002778, 0.13364296805645737, 0.10151402279734612, 0.24553435615130834, 0.09314867667853832, 0.1724823803773948, 0.10606822770621095, 0.13745451638741152, 0.22285897790321282, 0.07256886562598602, 0.1557412115590913, 0.08737560574497495, 0.09688262774475984, 0.17467039796922887, 0.1178146731108427, 0.1126236766576767, 0.13688960884298595, 0.14646350725420884, 0.1318566703370639, 0.11974420957267284, 0.10176452435553074, 0.12384053905095373, 0.08791488502174616, 0.1865665146282741, 0.07959911945675101, 0.13355391712060996, 0.16703682472663267, 0.11206282675266266, 0.1035794901794621, 0.13229744668517793, 0.1835628572319235, 0.1463960608733552, 0.0956474429528628, 0.06442688644996711, 0.13762624002993107, 0.07868216758860008, 0.07286705462528126, 0.13758231167282375, 0.13103458444987023, 0.16869972406753472, 0.12120524474552699, 0.10294020841164248, 0.1177930821265493, 0.15771867973463877, 0.14175148867070675, 0.1595552840403148, 0.14517442642578057, 0.08482162707618304, 0.09829437413385936, 0.21434362126248224, 0.11350170097180776, 0.07090084334569317, 0.2047322948596307, 0.14918399841657706, 0.14979499205946922, 0.08521501453859465, 0.13545773710523332, 0.17254846968821116, 0.2066276738686221, 0.06786659080535173, 0.11281922366470098, 0.12220746810947146, 0.14129062768604073, 0.2189711079533611, 0.13971082174352237, 0.20369127286331995, 0.13175453724605696, 0.2606608287564346, 0.12463025881775788, 0.1400954153920923, 0.22402974936578954, 0.07935565430670977, 0.12742845581046172, 0.09329024622482912, 0.09333709228251662, 0.1198823864438704, 0.11364867844219718, 0.09763878038419144, 0.13961288199893065, 0.13906728556113584, 0.12091529316135816, 0.1781757098755666, 0.14348167154405797, 0.10390792826988868, 0.13561728782951832, 0.1717846699591194, 0.14303306490182877, 0.11824656065021243, 0.12744469993880816, 0.18394722017858708, 0.13301999148513588, 0.1819082224475486, 0.10749325302562543, 0.06943587266973086, 0.13302767250154698, 0.1206812257213252, 0.11606711974101407, 0.08977457308875662]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.035231502527104955, 0.028547111566045454, 0.008811317500658333, 0.06298653980983154, 0.014811430492305329, 0.07750074991158076, 0.017629004748804227, 0.017991847957351377, 0.06001424430204289, 0.05801703754280295, 0.10010517375277621, 0.063509127125144, 0.043758665677160025, 0.06989739861871515, 0.021455287467688322, 0.029284563780363117, 0.035506142968578, 0.045531769283115864, 0.03469261680064457, 0.04905587321679507, 0.023752603480326276, 0.018043805080066835, 0.032654066902718375, 0.03757619385474494, 0.03755097949345197, 0.03446704461904509, 0.04613025752561433, 0.03650259878486395, 0.0338629414992673, 0.014432380474837763, 0.039473584720066617, 0.03403862439362066, 0.04868345587913479, 0.01707496733537742, 0.031676762737333775, 0.025776261230930686, 0.03553105538178768, 0.06624356896749564, 0.06564189161040954, 0.022283492044412663, 0.034796663360404115, 0.030018246732652187, 0.004697939830033907, 0.07619428501597472, 0.047558217508984466, 0.021458437566512396, 0.013577136277620281, 0.009450863048966442, 0.024885041107024466, 0.0682814878278545, 0.0216619353076177, 0.024328445616577352, 0.025101427620808994, 0.06828190173421587, 0.0608695512637496, 0.04960615493889366, 0.04017201438546181, 0.04027522634714842, 0.018566092143633535, 0.020562096199552928, 0.03493454846154366, 0.028776368192796196, 0.03632273950747081, 0.06672106084546872, 0.03553492303139397, 0.029884782287159135, 0.007140990745808397, 0.009006766120104917, 0.02344696586286383, 0.03347932154844914, 0.040161290139492066, 0.04574739753401705, 0.020270848613498465, 0.05836093944630452, 0.018724289190556322, 0.018487770542768494, 0.021056471725127528, 0.038825678772159984, 0.0241558992503477, 0.007666485583675759, 0.0147793154298727, 0.05543867571811591, 0.011519703598293875, 0.03348167606496385, 0.007138912732313786, 0.014732747571542859, 0.031515264617545266, 0.03257400994854314, 0.04500782489776611, 0.016712644902457083, 0.031565452460199594, 0.049167641505066834, 0.024645833764225245, 0.042501554026135376, 0.04104335852233427, 0.0481286042236856, 0.020979356220258132, 0.025970819273165295, 0.025856867798471024, 0.016832791401871612, 0.024606875676129545, 0.015283399095226611, 0.03136901996497597, 0.04782903779830251, 0.032246969640254974, 0.023453082856056944, 0.03885449954707708, 0.019467625999823213, 0.05552049007798944, 0.025651917992425815, 0.047560344716267924, 0.032270202679293494, 0.02472022664733231, 0.1002648805401155, 0.028133698838895986, 0.029224608426115344, 0.04087503434025815, 0.016173236704032336, 0.016650828665920665, 0.10756899788975716, 0.0195440901110747, 0.02448185729528112, 0.05793224102152245, 0.01242237739331488, 0.04404856297852738, 0.038089342747948, 0.04250946913712791, 0.041994878357010226, 0.07020245439239911, 0.030452275050005743, 0.04570601029055459, 0.0484107458697898, 0.04857306501695088, 0.026143282518855164, 0.036536678206175566, 0.04416210224319782, 0.023222250331725394, 0.0445945597519832, 0.011122432371069278, 0.1225747319736651, 0.032540527638047934, 0.024229155587298528, 0.03171246046466487, 0.02718188044881182, 0.032053814469171424, 0.022846640486802374, 0.0354980582238308, 0.02139687069159533, 0.06674957288695232, 0.0019099458835885993, 0.022181562513911297, 0.04176206959943686, 0.00791758340450802, 0.017504463038806404, 0.006892128273778195, 0.01893677412798362, 0.036627893668732474, 0.03529121021607092, 0.01681254052424005, 0.0434792449564806, 0.03959290510309594, 0.026863937598786185, 0.07492920397115604, 0.060534809582999775, 0.0041363265731238896, 0.012872023042291403, 0.04001984951485481, 0.056041448909257136, 0.013555254371437644, 0.07182760004486356, 0.08842210351888623, 0.02746129947315369, 0.048076879499214034, 0.021962516142853668, 0.01072295251235898, 0.08197988170598235, 0.04019046714529395, 0.047662396383072646, 0.03194681288940566, 0.022573815126504217, 0.017169728143406764, 0.1302346188042845, 0.0622248842513987, 0.032317330329013724, 0.009970839700794645, 0.0034404386575001156, 0.04411776676507933, 0.026983671888176883, 0.028276662774650112, 0.06817118517522301, 0.05899363263909306, 0.016965224474136318, 0.0161038480166878, 0.07072521134146623, 0.03406888705545238, 0.05260279967582651, 0.04808435356244445, 0.05465521204418369, 0.03331701257931335, 0.07637634953217846, 0.033593369714383564, 0.05939671636692115, 0.08130273089877196, 0.0582218872649329, 0.020751105521672537, 0.004108286113478243, 0.015247206037331904, 0.019266601518860886, 0.028401888108679225, 0.055204550602606366, 0.03999169370425599, 0.052947162983140776, 0.03809816370319043, 0.044895113445818424, 0.014716991988409842, 0.017349159943738153, 0.034936312652592144, 0.037191406823694706, 0.05913193843194416, 0.05201802123337984, 0.028213224839419127, 0.008723725415101009, 0.022796688435067023, 0.04605373234621116, 0.020078434741922786, 0.035468121258808036, 0.02151052700355649, 0.01652830220492823, 0.022457938308694532, 0.05016259436628648, 0.054499250770147355, 0.049731453215437274, 0.012091202262256826, 0.054388113519442935, 0.02595421891393406, 0.019047197220580916, 0.008443228368248259, 0.048898836464754174, 0.01623189096738185, 0.015849361761606166, 0.04074420261063746, 0.012341088049912026, 0.063079485536686, 0.034835224505513906, 0.060302608114268096, 0.0783238128892013, 0.03873755742928811, 0.02433652357597436, 0.03624152225841369, 0.023040138318070343, 0.015366923363347138, 0.0861798981204629, 0.014361259826858128, 0.023701815134180442, 0.02657027612440288, 0.010710830484250826, 0.03234117065689393, 0.012879428403851177, 0.05250760799806033, 0.011271132472237306, 0.03479347763849156, 0.07093346052403961, 0.011608376250868397, 0.04893296677619219, 0.012554494946795915, 0.028559369301157336, 0.04403087357059121, 0.03199225777227964, 0.03034479171037674, 0.052729835002017875, 0.03185616061091423, 0.020200951024889946, 0.05030486619632159, 0.03992182495338576, 0.028447217640600035, 0.021094030334747264, 0.021486427136031643, 0.01843290080848549, 0.03876621535580073, 0.062348357268742154, 0.02607038919813931, 0.023574028330455934, 0.02416447762932096, 0.021067694694335972, 0.07028441463730165, 0.047785119619220495, 0.011957475732612823, 0.06808072967188698, 0.04584700647475464, 0.006720871548168361, 0.0354356058607144, 0.019814523635432124, 0.05754451932651656, 0.021981649134042006, 0.047704601261232576, 0.03970940617312278, 0.015332723502069712, 0.03048491936975292, 0.046475828625261784, 0.045996036513575485, 0.007005952523156468, 0.03041610913351178, 0.0052130598674661344, 0.06894951233906405, 0.03504101399864469, 0.05642713839188218, 0.027074799141181365, 0.003113060990082366, 0.07322023888783795, 0.04217785211013896, 0.04830074177256652, 0.0326155973598361, 0.0263116694654205, 0.06805410395775523, 0.00968680833466351, 0.007247781131549605, 0.017555244599602053, 0.04281212289684585, 0.027441001098070825, 0.023275184544867704, 0.0665694082688008, 0.04914391992081489, 0.016244745813310146, 0.03402482299134135, 0.03254585413794432, 0.051365955865808895, 0.04641704035124608, 0.023949748437319483, 0.05179449822753668, 0.04000816174915858, 0.020659666142559478, 0.02336106332950294, 0.006938395032193512, 0.0677108805892723, 0.055140228875513585, 0.061508968738572936, 0.021687441438968693, 0.011895183673394578, 0.03670043584757617, 0.013217414330158914, 0.11234641367835657, 0.030398762385760034, 0.04624896722712687, 0.06338880251028708, 0.06005756197763341, 0.0296937780720847, 0.030706657828497033, 0.0312507275624999, 0.03970358094998768, 0.012951226738680686, 0.05797404556402138, 0.03865374478378466, 0.12609806577009813, 0.07127797989440815, 0.101562375202775, 0.17190474351601942, 0.11663909762033395, 0.2632159745054585, 0.12037513857441288, 0.07471621182880231, 0.09977848628269774, 0.09177654316382748, 0.2052684189485652, 0.11214727722108364, 0.09461775249136345, 0.14618287874119623, 0.11554387424673353, 0.0912295218024935, 0.11477411698017802, 0.13331210081066402, 0.08631211066884653, 0.1136016356093543, 0.12441645243338176, 0.15008221593286308, 0.07312865023102079, 0.2243078537285328, 0.15372508045818123, 0.1243275236338377, 0.24135297909379005, 0.12074135749467782, 0.1909418577062232, 0.08295014607054846, 0.08976502610104424, 0.1412601207516023, 0.1247929579445294, 0.07600426128400223, 0.13735595239060266, 0.11738285342497484, 0.07951835343348128, 0.25413052631275995, 0.14952346948640688, 0.0834788198449782, 0.1046210482184376, 0.17900759380842957, 0.11035357668463673, 0.20678869022854737, 0.1177754130746637, 0.08933042442159993, 0.08262936864048243, 0.29971733157123837, 0.14920975560588495, 0.12442473056060926, 0.11355288965361458, 0.128170623843159, 0.08772297496242182, 0.14459608388798578, 0.17054783632712706, 0.13850670707012924, 0.13077257493776934, 0.11139261057334286, 0.15947362913617066, 0.09306646537567888, 0.1767697310341256, 0.14600702960576328, 0.12198982121688978, 0.13433493806847505, 0.10559372138231993, 0.1295031580541815, 0.06586612029267208, 0.08521002730620758, 0.19501062509204659, 0.17801257648638316, 0.10203369919742857, 0.1479210683277675, 0.18610198955450738, 0.11401702117707048, 0.1001590494332569, 0.15728346737367765, 0.07610751395778996, 0.07752458684678588, 0.11066883762500115, 0.21541335886078222, 0.07246656290122441, 0.056790466752967665, 0.11608918569982052, 0.07331935928336211, 0.12836522768650735, 0.1337081752717495, 0.1583915829126324, 0.18454507738351822, 0.10108836420944758, 0.14733765034803323, 0.1277377727840628, 0.19304146218512738, 0.10408121254295111, 0.13991972910506384, 0.12002863788178988, 0.12770581378468446, 0.13350715248712472, 0.10057730520410196, 0.12907330611986773, 0.11352522578090429, 0.11046281403728894, 0.08655068358140332, 0.14204241734530243, 0.09131921056125845, 0.10443179801638637, 0.10821686991091285, 0.14648105416979107, 0.10863776518298046, 0.10606566284384046, 0.13297265688223497, 0.12579813972115517, 0.13935955773506845, 0.16961923401270593, 0.15302902566535131, 0.08566342440566846, 0.09964571733559881, 0.1618265171668359, 0.09976782649755478, 0.12204744241067342, 0.1553688043994563, 0.08151328710040875, 0.08742177326764379, 0.13907939062586852, 0.08458317629992962, 0.12138160956757409, 0.10148542933166027, 0.09612088397677455, 0.1276677343994379, 0.13843779505363532, 0.20318767774317945, 0.1033657720046384, 0.09609775271798883, 0.1428949830255338, 0.14185379818081856, 0.10630315688571759, 0.10930594575724431, 0.08523608305092369, 0.131246667355299, 0.11192809683935982, 0.23423476676855767, 0.14830772472279413, 0.1340953880654914, 0.11001010904354708, 0.17699617174054894, 0.13676280421870096, 0.18713267067713396, 0.10549835328544889, 0.0916818536019751, 0.14245343314749853, 0.0818373757813658, 0.12985780116702828, 0.16692197588937624, 0.1409613210707903, 0.10700522349881274, 0.08469204045832157, 0.13227445791874612, 0.09297917863087994, 0.17479009154651845, 0.132523222427283, 0.15639295801520348, 0.12073526425021035, 0.118906544521451, 0.17968767588692053, 0.1074287039893014, 0.09783865644463471, 0.16287245175668172, 0.2289635810468878, 0.1871077005884477, 0.08245069679937192, 0.12329358554312161, 0.1432257281350238, 0.11565838381648064, 0.16636219806969166, 0.11838667813156332, 0.14955400356224605, 0.15603697140301975], [0.03649053443223238, 0.0435257856734097, 0.0671946375763842, 0.06846182207976069, 0.025279753409059982, 0.04152644152886101, 0.015336575884638088, 0.035854563915303776, 0.030455966280507188, 0.06915506095226322, 0.008471703938474613, 0.019579085554661493, 0.022960705616112267, 0.05003745893814734, 0.006762849965265819, 0.04104799630918673, 0.042453866585024765, 0.08137211788977895, 0.10789651995790855, 0.021387320311207856, 0.06549343493367944, 0.017292039169530784, 0.05722870198743684, 0.02316369445595358, 0.018687080026471188, 0.027379081384944062, 0.042865974828600883, 0.019406673199098026, 0.02054502934749637, 0.0597883260675839, 0.054921822023711035, 0.05776391683944634, 0.03451566165313125, 0.02484596088262541, 0.0321284770699484, 0.040611375988061936, 0.026342965196818113, 0.02925769379362464, 0.03838812207270946, 0.02377336156288428, 0.05871301769678082, 0.09535598502095256, 0.09524842364979641, 0.039445035359156985, 0.004228294361382723, 0.020952747469501834, 0.06461857937808548, 0.05016054179785507, 0.004673505359927991, 0.03753731379817639, 0.05529641745878117, 0.04359717773539679, 0.047655098738947084, 0.05771294528884547, 0.035376264580658505, 0.05112450596477304, 0.024477044785661355, 0.026222079094233255, 0.06336835146482502, 0.03669622893046055, 0.07445175959063427, 0.09615852909960917, 0.06889138902936663, 0.03003060964069196, 0.036940406542271376, 0.03494530324158924, 0.018225871292608123, 0.00962052564136684, 0.03797090106776782, 0.06775943655520678, 0.07351266712482486, 0.02032741977434073, 0.038335203126605065, 0.02720725256949663, 0.012981966071363007, 0.08305022998579911, 0.01017642139257597, 0.09244420126612697, 0.033657650729375224, 0.007475242185007248, 0.018812279915437102, 0.03345649563042181, 0.03513877732413156, 0.01231680837060724, 0.033117455430328846, 0.0644255904480815, 0.013661771646833845, 0.02719294565862843, 0.06288192328065634, 0.06648757016020161, 0.05501570073621614, 0.0230759038989033, 0.030085380987397263, 0.0431581452222807, 0.04831757961905428, 0.02029156598395535, 0.03017534116016967, 0.05867019535175391, 0.05448029589440141, 0.06007795874029398, 0.02165172844459968, 0.013391239734898721, 0.04012203349598816, 0.02212416354034628, 0.017713538337764994, 0.04470854006441576, 0.04459895665890404, 0.04789982596412301, 0.023347772524825165, 0.05998454482427665, 0.01672682798068438, 0.042426273958491426, 0.042462738430393596, 0.032882444826619964, 0.044575269001403024, 0.01729465152935258, 0.11314260666923863, 0.10140700425420489, 0.02322922906439219, 0.03561952617019415, 0.006295917364436069, 0.05021615792065859, 0.015557340645630444, 0.05688702567879643, 0.052145294046827724, 0.053725266230425665, 0.06197580083140305, 0.026207884141643132, 0.02069558609010918, 0.025263538118451834, 0.05073865024106843, 0.030700055682765584, 0.04563158856970923, 0.03753150553841676, 0.027225981832348874, 0.043763103296181986, 0.014149751979857683, 0.05795732646116188, 0.026535984660897936, 0.03886629927105137, 0.035516962209450345, 0.04178771483046668, 0.02244814365570034, 0.046383473223873546, 0.049773267935961485, 0.10007733346096107, 0.036598258651793, 0.02510128852113017, 0.04525009582617453, 0.024202891193064194, 0.04575673078319856, 0.036181210673281124, 0.058976424991020134, 0.02222489545653973, 0.03908929980493017, 0.007508402191368597, 0.047443277069500515, 0.014201012756010252, 0.07189027632453612, 0.010417805136447507, 0.04494742849575622, 0.016984033464853252, 0.0464528262881296, 0.050184069999626706, 0.021283109206706285, 0.02992096177435347, 0.03103240892024977, 0.04116958639185343, 0.055638304113277366, 0.008323208245980953, 0.0356497718686504, 0.022652876330539584, 0.057929981499910355, 0.03701795291687761, 0.04726341439943228, 0.0420568421749132, 0.07750977442732879, 0.08689440228044987, 0.02979378734848329, 0.033334559494895596, 0.04698837022962315, 0.024130510166287422, 0.021306941052898765, 0.01697639824955591, 0.0477933502489967, 0.09425966920597212, 0.00987995502405933, 0.03137684686641608, 0.05358718435413071, 0.045042735524475574, 0.03540530927213175, 0.0698733716937048, 0.03343947457947901, 0.06786410058183329, 0.016810711872364794, 0.018111879105812738, 0.046950535116983313, 0.0304552063212863, 0.025384074775502086, 0.06583019186343465, 0.028231669117563536, 0.022682394300188338, 0.039942432061902115, 0.04083832898842437, 0.05283184934939657, 0.058184215000697544, 0.00954304966476879, 0.016074833859290396, 0.03082968301272818, 0.04981462125267301, 0.029699301347136497, 0.05943672279162066, 0.024949284802590097, 0.014497821784711309, 0.02128851373812982, 0.002774472863945578, 0.09405993563788277, 0.07876456209591456, 0.04132178858188646, 0.022000490355172327, 0.022862418122323494, 0.020230389266674007, 0.09395805360483271, 0.08477083194468703, 0.03113525447302631, 0.0565325555923794, 0.061483035130160194, 0.019800907133945396, 0.01552962079378111, 0.039548952997262986, 0.03504915302619338, 0.08973605944109814, 0.04923346957990101, 0.04256955680570432, 0.11003908248884336, 0.023430848959833384, 0.05054269950570805, 0.035761424805969, 0.02302470843174628, 0.04705776400598032, 0.054801589011081626, 0.01780876224594457, 0.022124584232057844, 0.0643674535676837, 0.013639224776332932, 0.011640059595395411, 0.038993198890239, 0.016760949810434665, 0.09784994726734501, 0.06426407197224242, 0.021278688551059792, 0.07135175022163562, 0.05480850328292165, 0.06010128677423511, 0.059254006881799014, 0.02628232621853905, 0.013407477926063751, 0.025576234196445773, 0.016707454109564424, 0.024875663753066744, 0.016431125812232494, 0.0770247100985476, 0.0384412140452436, 0.010088498521197056, 0.007304577905285571, 0.05030571775776999, 0.01648830935092909, 0.023746096329497438, 0.02231603967291968, 0.043436928120042594, 0.04307971675215023, 0.06578903192920343, 0.019694307586178184, 0.04092996175001774, 0.030197366406874995, 0.01675447658635676, 0.032763860654085875, 0.031521676773471494, 0.024032748537138104, 0.047989311162382364, 0.018493012225787555, 0.010989202868326433, 0.04985263617709279, 0.02637311420403421, 0.04960350865232093, 0.06541787327400275, 0.028521768283098936, 0.019110311155340502, 0.03646183240094355, 0.041807707864791155, 0.028909849601664712, 0.01426354908783521, 0.041623010632715056, 0.05334533751010895, 0.05806408716099603, 0.045493306525583775, 0.0793439360069377, 0.06982369614498955, 0.028357695122914653, 0.010145995034171002, 0.05122305978355663, 0.03780717735311814, 0.029895034951290915, 0.020556985134524957, 0.016296845428379517, 0.06038078213376658, 0.021905023870723586, 0.006927205565651613, 0.051743587745087485, 0.0043384464640569475, 0.04906804274235453, 0.006400062311773321, 0.030948229865836244, 0.007899947431204575, 0.022985811411802257, 0.044245789359722815, 0.037484438956848214, 0.02339642178932471, 0.05764228943735361, 0.06097833399793931, 0.007963520225270517, 0.023055088140868714, 0.02827522767308567, 0.056813940671937804, 0.05285662605560251, 0.02030696703254112, 0.014663728685783488, 0.05126058277008789, 0.06193066468196256, 0.03586595991094198, 0.05015864868515304, 0.015372517884575894, 0.057476754034204144, 0.044109861832112074, 0.05107949873698609, 0.008399150733436857, 0.03213277219661644, 0.10243966669908591, 0.01905157886046384, 0.05603379503424678, 0.04000290310276406, 0.017374281006466066, 0.05210661755076476, 0.014511825051158667, 0.027261533674650958, 0.04758714345682945, 0.10928129458001681, 0.051201495940663984, 0.029113949542599063, 0.0582565807604364, 0.070882862167699, 0.0477519799689097, 0.16517189836927823, 0.14601739762084825, 0.12924535545919622, 0.1962992309459618, 0.11352489329874516, 0.15234815648623876, 0.07149266158895833, 0.14347495404737337, 0.17477262605513844, 0.1730541004134076, 0.06500440796038934, 0.06740898678877524, 0.12295133247971535, 0.11075729823538236, 0.10866690826203142, 0.15933842424835476, 0.13484683845724377, 0.16073383151420526, 0.15950082481971808, 0.1488459115581853, 0.11350086637373481, 0.12712411928389752, 0.10716336965560913, 0.14552962593734264, 0.060731272612299235, 0.10073523422969238, 0.11831486198518958, 0.14322770945727825, 0.1412124875932932, 0.11712344948734556, 0.10376977854009185, 0.09278851707598992, 0.12259256387395517, 0.22158383418406757, 0.15765744873455592, 0.20295252464711666, 0.1490247326769999, 0.08846774178424052, 0.13183992409280368, 0.07470713981560298, 0.12399593714092459, 0.19874163131628717, 0.14949056053800241, 0.11202708152788025, 0.1265479073460613, 0.08792591800114938, 0.2765985578298569, 0.2374019239630018, 0.1612253487110138, 0.10041504033974238, 0.16698729167027132, 0.10539532452821732, 0.10835426646683897, 0.15858283479298863, 0.1963702735624143, 0.18863425510270254, 0.09266447408923081, 0.09120234647499663, 0.1326941182570798, 0.14044019260576793, 0.1274764553776809, 0.19870727030294283, 0.1630792963717665, 0.10751629607485873, 0.1105484790833933, 0.09407668188214302, 0.19167330488562584, 0.20821851279054368, 0.156254238315991, 0.15516174265316554, 0.11122879864914076, 0.11206070293805429, 0.1906011924147606, 0.08481559489986726, 0.08078781102917024, 0.2274288298296077, 0.12574369407125882, 0.12828957103192806, 0.2046359157455819, 0.0802419228213174, 0.04939822806045413, 0.1083339172016297, 0.11889701788978917, 0.0733989378703492, 0.12870042398571968, 0.14692367613315582, 0.13712970167398453, 0.14331670611032418, 0.16576492440487656, 0.1437207737139293, 0.2003442496061325, 0.11100910936615296, 0.125933778871383, 0.1897974405437708, 0.1749958097934723, 0.10910796959485326, 0.1489509894911732, 0.1668607856013945, 0.14861026991690907, 0.09073478834969656, 0.1273210844291108, 0.07262777603630509, 0.12376609018870763, 0.17176576597349985, 0.13680958242288657, 0.0885725754446217, 0.17325356256748947, 0.14842390348868711, 0.0971773358594094, 0.14506082609295845, 0.09631715023091861, 0.08459174619721514, 0.08596285512404782, 0.14667461306921073, 0.14681110717356205, 0.0590253405805145, 0.13565867846565588, 0.16736371575721673, 0.16284574461834772, 0.11747304429965359, 0.12658488750457764, 0.12483406359595911, 0.05947924658123936, 0.1590271530939, 0.17742974204676493, 0.10687768605670758, 0.1762692571750709, 0.11163548539791789, 0.1844240538775921, 0.14421144952731474, 0.16259370957102093, 0.09224625903048686, 0.08902370623712029, 0.07553154629256044, 0.12109627202153206, 0.1274897546640464, 0.10031064094177314, 0.17453270964324474, 0.12801310872392996, 0.09275927221668617, 0.09367854467460088, 0.12146156813417162, 0.09485537545489413, 0.21079450313534054, 0.13448291298534187, 0.23906531184911728, 0.07765183251883302, 0.14003578573465347, 0.17833824615393365, 0.048665294889360666, 0.16066667011805943, 0.14034322995160306, 0.1999571860900947, 0.1510953094278063, 0.1250380990760667, 0.07652500976941415, 0.16134160890110902, 0.18533358935798916, 0.08847917509930474, 0.07534448775861945, 0.0930944617305483, 0.15614924180720532, 0.13000616963420594, 0.17951331952852861, 0.11443628796509334, 0.141607774953757, 0.1034629585753594, 0.16978886776736804, 0.12443439289927483, 0.09580858823444162, 0.13457710721663066, 0.11316469298409564, 0.09923090173729829, 0.19173468516341277, 0.17939289313341888, 0.11708727000015122], [0.0503566723449954, 0.025594669992902448, 0.05217474585931216, 0.026181109149807265, 0.030309833586215973, 0.017294558230787516, 0.03111029795504042, 0.015910229745454023, 0.06739425579352037, 0.015490700025111437, 0.044956771922963004, 0.010349769278296402, 0.03231977644775595, 0.04587912492986236, 0.07000838659171547, 0.0611019902197378, 0.05390554619953036, 0.053583537228405476, 0.01545995899609157, 0.034380833352250714, 0.038326263427734375, 0.05182178890598672, 0.02795754775537976, 0.061032521804528575, 0.014892223656975796, 0.03304755953805787, 0.03643042301493032, 0.04228835153792586, 0.03716634852545602, 0.019106317976755754, 0.009072019984679562, 0.053258885363382955, 0.03080488255779658, 0.01717274253522711, 0.06731951516121626, 0.057174941657909324, 0.010178493468889167, 0.02616692946425506, 0.007259808164755148, 0.02036088003244783, 0.059338660910725594, 0.01349332363211683, 0.03604569365935666, 0.016046142006026845, 0.011870981177448161, 0.006834642362913915, 0.04079569663320269, 0.0015746421850053594, 0.02559887521368052, 0.040522623607622724, 0.04584913028936301, 0.029204238804855516, 0.026994207840678946, 0.04349593352526426, 0.03011471066357834, 0.02761171881242522, 0.04633837439385908, 0.018220622824238877, 0.019453412387520075, 0.07600179820188455, 0.051462932090674124, 0.026152001693844795, 0.01198965440770345, 0.03900593159986394, 0.019133920781314373, 0.028610781899520328, 0.07119989408446209, 0.014103374959501837, 0.011274740582198968, 0.02113015723547765, 0.026645523961633444, 0.023458870759766017, 0.05966508375214679, 0.061767334517623694, 0.01942040165886283, 0.0703088826100741, 0.05209755910826581, 0.02417759540756898, 0.012094918937821473, 0.028406914356829863, 0.029655210141624724, 0.02748664784511285, 0.04874265127416168, 0.07988615334033966, 0.05340211053511926, 0.0370057596425925, 0.030032716491924863, 0.04162922940616097, 0.06259172063853059, 0.010618050998475934, 0.017212465671556335, 0.04446015214281423, 0.03465258323454431, 0.011622521161500896, 0.08830291884286062, 0.03811732213944197, 0.027594046367864524, 0.025236932760370628, 0.005241308128461242, 0.008774411980994046, 0.09178235142358712, 0.022375233371609023, 0.025210602208971977, 0.07967264551137175, 0.02188179761703525, 0.05676643982795732, 0.024340265696602206, 0.021839453639196496, 0.019873096474579403, 0.012157394201494753, 0.06162700669041701, 0.05646389463384237, 0.008253071473778358, 0.031229116222155944, 0.022587833659989492, 0.11113995805914913, 0.02097268113201218, 0.018553802178108265, 0.04151228050302182, 0.008816191926598549, 0.008221338935462492, 0.030209810739117007, 0.03606155441541757, 0.032785994466394186, 0.002570573939010501, 0.05332846912954535, 0.01472076803578862, 0.019644062068047266, 0.06275045033544302, 0.013387447572313249, 0.008868476442460502, 0.042495084194732566, 0.0672668337023684, 0.04884541201006089, 0.02092047464767737, 0.02006355277262628, 0.03898346530539649, 0.08693622039364916, 0.02544358908198774, 0.042920084603663, 0.012856399773487022, 0.01167143929550158, 0.025930063067270175, 0.015408022229426672, 0.015843149773510437, 0.024982977458941083, 0.11650277993508748, 0.04222874902188778, 0.01517548318952322, 0.11591468006372452, 0.038000634472284994, 0.04303441775430526, 0.03759781876578927, 0.031245021082993065, 0.04553131127197828, 0.038071707622813325, 0.07717947715095111, 0.020169372005122047, 0.027738036587834358, 0.02865900538329567, 0.036363689095846245, 0.0288936902901956, 0.03501355368643999, 0.1070003244759781, 0.03746021186400737, 0.014177540533377655, 0.007966317485884895, 0.0031649167566294117, 0.05600741359272173, 0.049104490250881226, 0.04714464023709297, 0.0161896199320576, 0.036652982501046996, 0.022604880155995488, 0.01901356054336897, 0.0038628968925747487, 0.03639434191531368, 0.028458360881943787, 0.06733125381703887, 0.03577706503814884, 0.03320008063954966, 0.006536507222335786, 0.02680560733590807, 0.00962356717458793, 0.009577280908290828, 0.012725825887173414, 0.0693189814420683, 0.012986242538318038, 0.045952430460602045, 0.01104428549297154, 0.0878922219521233, 0.055173076755766354, 0.06266644770013434, 0.01067370783338057, 0.050861957017332315, 0.02837709613543536, 0.012691284213880343, 0.056235055306128094, 0.0024271598376799375, 0.017398426675104668, 0.030853984744421074, 0.020176367701164315, 0.055886213667690754, 0.044274613527315, 0.038993036041834524, 0.05216493085026741, 0.06336975603231362, 0.02962636561798198, 0.0339257467005934, 0.0022803645115345716, 0.0417498016862997, 0.05162382631429604, 0.039130520807313066, 0.07310545790408339, 0.04790354094335011, 0.01605837599241308, 0.03693377386246409, 0.01232272180329476, 0.042904383303331475, 0.012293185173932995, 0.05415966434936438, 0.032292933602418215, 0.020026094246921793, 0.03344239567273429, 0.017969361306833367, 0.014924128373552645, 0.08537416492721864, 0.06106613642935242, 0.02180619863793254, 0.02951977794457759, 0.03567133231886795, 0.021340153645724058, 0.026147021246807914, 0.022246262524276972, 0.04381890601611563, 0.019812208134680986, 0.04305411223322153, 0.016420074173116257, 0.09722567469413791, 0.036629949629838975, 0.017746527014034133, 0.00987411877473018, 0.04970594708408628, 0.06420187745243311, 0.1065416212326714, 0.03708856127091816, 0.042351441723959785, 0.03092293408034103, 0.023733541735314896, 0.045785147829779556, 0.01992641406000725, 0.009050888707861304, 0.08015748592359678, 0.07813400628843478, 0.10094694394086089, 0.03756182587572506, 0.0268283857564841, 0.027095891402236054, 0.07503456688885178, 0.12184120847710542, 0.061416179074772766, 0.040376541803457906, 0.024775642602305328, 0.013096940437597888, 0.03200002021289297, 0.0397791799290904, 0.013123272685334086, 0.05727102221654994, 0.06998028167124305, 0.009089114826305636, 0.016553435142018964, 0.027714381160746728, 0.013201947124408824, 0.04966518070016589, 0.059515636414289474, 0.015367705374956131, 0.052883214450308254, 0.05209646327421069, 0.0635232881509832, 0.014379125653899141, 0.02567830282662596, 0.08783806128693478, 0.05666278681850859, 0.004178963169189436, 0.018822374820177044, 0.043257808445819786, 0.061030764398830276, 0.047787192543702464, 0.028574273322841952, 0.003988961913689438, 0.02072188101841935, 0.05557207909545728, 0.039879701499428065, 0.044898180424102714, 0.04874191167099135, 0.033225240718041144, 0.022595407807135155, 0.053272449278405735, 0.08260916186762707, 0.02907341386058501, 0.012396331826624061, 0.06484900308506829, 0.046163132547267845, 0.028478813623743396, 0.007129992541324879, 0.029100151532994847, 0.059994960336812904, 0.02885767025873065, 0.0351344380926873, 0.034539848033870967, 0.04967690578528813, 0.04787425197927015, 0.0434330604704363, 0.023618506300928335, 0.01651382226763027, 0.02972053949322019, 0.043831757469368834, 0.035378863369779925, 0.01484851073473692, 0.00796157367793577, 0.019484513040099825, 0.003952911772233034, 0.02432877809873649, 0.024656812460826974, 0.01278153870121709, 0.005165843584109098, 0.026711962717984403, 0.031358472138111076, 0.010859208281284996, 0.01378035157852407, 0.03338399416367922, 0.013763329679412501, 0.05564788842041578, 0.022816995291837623, 0.01284358139881598, 0.0025692781491670758, 0.08499628198998314, 0.05450062819623521, 0.055063418711402586, 0.0416818260481315, 0.010911135718093386, 0.06614921867315258, 0.04643394605123571, 0.029363304376602173, 0.02274364056730909, 0.06056364732129233, 0.0038843339342357858, 0.056830893869378736, 0.03527750041601913, 0.014243946211146457, 0.03836931986734271, 0.03174685540476015, 0.1238466730075223, 0.1246260247592415, 0.14568700534956797, 0.22018295792596682, 0.09289263148925134, 0.20011850100542816, 0.09603561248098101, 0.14612167488251412, 0.1582747527531215, 0.13170480062919004, 0.14903725843344415, 0.1043308727177126, 0.09305718301662377, 0.1478015783109835, 0.10098309628665447, 0.19568698879863533, 0.12978029889719828, 0.1199150239782674, 0.09168505628726312, 0.09621480000870568, 0.14933608525565692, 0.12602063135376998, 0.1027698621952108, 0.1465298951204334, 0.11752559005149774, 0.11241820268332958, 0.12850681080349854, 0.11599894054234028, 0.12033220087843281, 0.08591615834406444, 0.10232793912291527, 0.17873224429786205, 0.12599348995302403, 0.10286969505250454, 0.13606607089085238, 0.14292718629751885, 0.11746167205274105, 0.17434299125203065, 0.10837652241545064, 0.12655459770134517, 0.173910669450249, 0.14554597863129207, 0.10446392664951937, 0.09394453040191106, 0.16701701150408813, 0.12623436988464423, 0.11136389497135367, 0.13581746923071997, 0.08545820827462844, 0.1324056458792516, 0.1698368809052876, 0.10741636822266237, 0.0744920102879405, 0.17417129475091184, 0.1332431887941701, 0.07335423598332064, 0.1423553984080042, 0.12096588473234858, 0.16332165550972733, 0.1242227985390595, 0.10411431148116078, 0.10115466386611972, 0.15165850706398487, 0.10581491022769894, 0.05882709300411599, 0.1055405717343092, 0.17196370820913995, 0.14218830237431185, 0.13523890956171922, 0.11024396613772426, 0.08257368127150194, 0.07256102854652063, 0.11530029374573912, 0.12109882331320218, 0.07420992970998798, 0.0742651896019067, 0.15405939466186933, 0.12867081271750586, 0.172601368278265, 0.0738126610272697, 0.13025593837457045, 0.11094950685011488, 0.19694947105433258, 0.25984715670347214, 0.1505093944392034, 0.07481035856263978, 0.10952072923204728, 0.12989104938294205, 0.20457889166261467, 0.12401801667043141, 0.08253202600670712, 0.09165456292352506, 0.13337406462856702, 0.10390792826988868, 0.11816555713968617, 0.13537422301513807, 0.10426232711012874, 0.11147746137742486, 0.12546895524220808, 0.13173126349491732, 0.1445110770208495, 0.09911157456891877, 0.15543494799307414, 0.12144073710909911, 0.10503905971667596, 0.19383927008935384, 0.1675077008881739, 0.1111989566790206, 0.07430109088974339, 0.08041963792805161, 0.16860596409865788, 0.0776397410248007, 0.08564154165131704, 0.07703010445194584, 0.14246291906705924, 0.21625628934374877, 0.06632259794111763, 0.11213201018316404, 0.14842483986701283, 0.13226179645529815, 0.1267089508473873, 0.08307506436748163, 0.12178898842207023, 0.13121025716619833, 0.08737685424940926, 0.21679087994354113, 0.1052288052492908, 0.10598075775695698, 0.126665131055883, 0.15953017824462482, 0.07576424987720591, 0.09854695200920105, 0.11237063737852232, 0.08870980236679316, 0.19158725307456084, 0.10139049549720117, 0.1810619400015899, 0.12554743460246495, 0.10685754035200391, 0.13224059902131557, 0.12567771332604544, 0.12330159225634166, 0.08460334914603404, 0.05114923178085259, 0.09770797060004302, 0.17908046846943243, 0.23341040100370133, 0.12182527647486754, 0.10230756271630526, 0.1437701710632869, 0.09326152383748974, 0.13182178006640502, 0.06841384286859206, 0.17268728438232625, 0.10824981957141842, 0.1428086869418621, 0.0920227292392935, 0.11120697017759085, 0.0664018304752452, 0.07189820161355392, 0.1885212790220976, 0.17601007036864758, 0.17930260726383754, 0.20629470316427095, 0.07964042866868631, 0.11702138424984046, 0.17853599839976855, 0.17339184800429003, 0.2179900955940996, 0.13306309202952044, 0.14082543764795574, 0.1125709612720779, 0.1449592358299664, 0.08458264025726489, 0.10453040951064654, 0.08139044512063265], [0.03213912667706609, 0.018543566477351954, 0.028747635627431527, 0.03754880139604211, 0.039614574118916474, 0.055028694681823254, 0.03746761468106082, 0.03520307530249868, 0.024591530606682812, 0.07011071645787784, 0.0509251218422183, 0.057900105603039265, 0.03430817582245384, 0.04157502463619624, 0.04395274704854403, 0.05291575698980263, 0.04770934422101293, 0.026195868982800415, 0.015363671484270265, 0.01576513351340379, 0.016345825478700653, 0.024138903644468104, 0.02874528111091682, 0.019626778084784746, 0.027087637023734193, 0.02439347471642707, 0.07203660918665783, 0.016145382841516818, 0.048191694409719536, 0.03168107482737728, 0.04352707828262022, 0.03154964598694018, 0.002992028578384114, 0.0978275148996285, 0.019395205957282866, 0.008446927232268666, 0.04781867656856775, 0.05675474527691092, 0.04238258648131575, 0.02428209319311593, 0.061064697935112884, 0.040589038615248034, 0.042288812941738536, 0.021526450524106622, 0.038857858295419385, 0.04415097766156707, 0.007621690398082137, 0.028456961403467824, 0.03177334541188819, 0.0027926720213145018, 0.015531155979260802, 0.04660048568621278, 0.030907192067908387, 0.025704855598243218, 0.017181310736175095, 0.01696099041561995, 0.04936337850189634, 0.07213530210512024, 0.050692611640053134, 0.030865692866167853, 0.05973801269595112, 0.013923948248183089, 0.0011849914361456676, 0.01670827852961208, 0.010690672905184329, 0.025697211901258146, 0.024016255047172308, 0.05602449231914111, 0.03657062192048345, 0.07382760236838035, 0.0119169485322865, 0.013815394519562168, 0.08484093818281378, 0.05684618804869907, 0.029171156830021312, 0.0306545633024403, 0.07998701078551156, 0.040472992163683684, 0.0328225369698235, 0.06056029535830021, 0.024078865169680545, 0.046072755075458965, 0.06633915419557265, 0.049125311097928455, 0.02252100474600281, 0.046472520767045875, 0.08209633867123298, 0.026630004169419408, 0.035750150946634154, 0.02775015352692987, 0.03539110753419144, 0.03868267412430473, 0.0024696516089274412, 0.016451412312952534, 0.014573503884353807, 0.05117841557200466, 0.017018190917692015, 0.041985426364200454, 0.03978174479146089, 0.033011196846408505, 0.04520997065784676, 0.021444200205483606, 0.03982466891674059, 0.017523555317893624, 0.05767844856849738, 0.014095691398584416, 0.0753879818533148, 0.013302095500486237, 0.009100343732695495, 0.09069776747907911, 0.07275456708988973, 0.027266247796693018, 0.028669213942651237, 0.034065328139279566, 0.025596739524709325, 0.02811357518658042, 0.06474956377808537, 0.06967620298798595, 0.02601078328942614, 0.03359241298000727, 0.06168190695877586, 0.0221205401633467, 0.013793352309481373, 0.04164705112842577, 0.07469339269612517, 0.04122338064813188, 0.037920102543596707, 0.025595625030941198, 0.03252645482176116, 0.0522092663283859, 0.05251332465559244, 0.0064225973079114086, 0.04659672320953437, 0.013582268546867584, 0.044953650661877224, 0.018671824862914424, 0.02202122638534222, 0.065285620013518, 0.027008467254095843, 0.033575544599443674, 0.07982034222888094, 0.023818304329844456, 0.02039725290212248, 0.038730778864451816, 0.04044720783297505, 0.049051676477704725, 0.032004834418850284, 0.033716866480452676, 0.020628406034250344, 0.03600683395883866, 0.07565151806920767, 0.023044842262087122, 0.05157307528757623, 0.04604215993146811, 0.09576755722186395, 0.020940869714000394, 0.04575363666351352, 0.018695008708164096, 0.0363036183906453, 0.007082219859252551, 0.05271246789821556, 0.08163803576358727, 0.042749331266220124, 0.026999927890886153, 0.031344663950481584, 0.07184040400066546, 0.046768657197909694, 0.022362129164061377, 0.040630605670490434, 0.0016853898081795446, 0.07324197236448526, 0.03965128964877554, 0.06039888544806412, 0.009062051457086844, 0.03365746752492019, 0.052230826778603454, 0.022163812037823454, 0.03183584866513099, 0.09188610621328865, 0.029004115079130446, 0.021981735647256886, 0.05286082958004304, 0.06347528179841382, 0.02839259217892374, 0.06294554950935499, 0.034561174389507086, 0.06038515189928668, 0.025068433855527213, 0.057008408808282444, 0.014734764516885792, 0.055634806265256236, 0.006284340284764767, 0.06404966847704989, 0.02395308852594878, 0.03954224567860365, 0.011682109258669828, 0.048312840051949024, 0.02938531944528222, 0.04986772679590753, 0.03405443425955517, 0.05691809918997543, 0.02340497133055968, 0.028096803497256975, 0.0081273041599031, 0.03788232171375837, 0.026778179254116755, 0.02776239769134138, 0.026402800111100078, 0.03496069920116237, 0.036540549248456955, 0.031238887126424482, 0.032092518106635125, 0.038017363753169775, 0.05992338167769568, 0.04570016471136894, 0.023897421513018862, 0.0004499113908553097, 0.030818795918353965, 0.017529366970328347, 0.028715045590485846, 0.06782149536801235, 0.11162393673190049, 0.01714584879976298, 0.024801864588100995, 0.024435689772612283, 0.018017929147130678, 0.038759155198931694, 0.013025640826007085, 0.011373949187275554, 0.036690230680895705, 0.05889695496963603, 0.013199489979472543, 0.027591118489259055, 0.056763864787561555, 0.04966318580721106, 0.04528555945892419, 0.007193995356958891, 0.02452136160406683, 0.011643844972630697, 0.005439369107729622, 0.005040524951514921, 0.025660667701491287, 0.020498590410820076, 0.025226683488913944, 0.05072990392467805, 0.0870186827544655, 0.04809688271156379, 0.08194131377552237, 0.08378930389881134, 0.08585642690637282, 0.06022958417556115, 0.03614138745303665, 0.024217025077502643, 0.021429649022008692, 0.005994761046687407, 0.04764349918280329, 0.014350774764482464, 0.006589992745180747, 0.031160713106926, 0.053856983448245695, 0.03507277283019253, 0.004738607402292213, 0.03275728904243026, 0.031919060807142935, 0.04748414523367371, 0.04256614377456052, 0.014683077111840248, 0.026417738059535623, 0.008242458337917924, 0.046563698910176754, 0.0768537667712995, 0.06822269955383879, 0.04908748955598899, 0.01373242580198816, 0.03482478863692709, 0.02933492125677211, 0.040518175810575485, 0.03684902823130999, 0.049955685290374925, 0.06088489294052124, 0.08732511595423732, 0.09809814859181643, 0.021467004071122835, 0.07071275343852383, 0.05671141742329512, 0.035870964106704505, 0.04407135496980377, 0.01999898168391415, 0.06555496448917048, 0.049568961041846445, 0.04996335952143584, 0.03000251150556973, 0.015316199478028076, 0.07636550654258047, 0.050047748921705146, 0.02547768546667482, 0.04182109196803399, 0.016391350089439323, 0.010594376063506519, 0.02065313863568008, 0.036596860869654586, 0.00808938592672348, 0.05093098099210432, 0.07169420684554748, 0.04144544141100986, 0.016999675393370644, 0.06920462115002529, 0.024716654160459126, 0.03658491526065128, 0.08180257372025933, 0.03708539590505617, 0.0064890165563805825, 0.030371848294245343, 0.06254059981022562, 0.0016773765216515, 0.03912331137273993, 0.041320580789553266, 0.04559701042515891, 0.005516080460178533, 0.05288197273122413, 0.022306591072785, 0.04107241678450789, 0.04272256984508463, 0.05288925001929913, 0.033942492944853644, 0.02112529213939394, 0.028211514931172132, 0.015066540999604123, 0.027389157629970993, 0.046770438352333646, 0.053855714587760825, 0.011811103854727532, 0.018619523383677006, 0.04063847328403166, 0.011128679982253482, 0.039858381929142137, 0.05470754066482186, 0.08386590371706656, 0.08030850067734718, 0.0331708934557225, 0.11023583728820086, 0.041844430180000405, 0.03236923825794032, 0.040323599108627865, 0.04465653035523636, 0.031583786476403475, 0.04928341654262372, 0.03698293711724026, 0.04860550577619246, 0.03436174276950104, 0.021658517187461257, 0.013120869823199297, 0.1105790538713336, 0.09687753194676978, 0.14558723356042588, 0.16388729587197304, 0.13861669759665216, 0.17917148715683393, 0.09678605864090578, 0.12573694943317346, 0.08399817054825169, 0.11365679372102022, 0.1733895138438259, 0.14860587300998823, 0.13013283855148725, 0.14810630838785852, 0.18833128921687603, 0.1659119493727173, 0.1444355153611728, 0.10765549753393445, 0.1111692911280053, 0.10201733971812896, 0.16746914652841433, 0.10530828205602509, 0.08296675660780498, 0.1815058376107897, 0.15369932326887334, 0.13773943324174198, 0.20407198529158319, 0.08943090867251158, 0.11191527931285755, 0.12096994237176009, 0.09999521715300423, 0.1619656439870596, 0.15342391947550432, 0.15458591069493974, 0.04728236248982804, 0.1281483271824462, 0.08409959117748908, 0.07330276910215616, 0.10432817214833838, 0.11465454553919179, 0.06269673071801662, 0.1273809719298567, 0.08912851275610072, 0.0714545686330114, 0.1714276791151081, 0.2122555383081947, 0.146485817485622, 0.1155672837048769, 0.12859549533043588, 0.07069763567830835, 0.09162420526679073, 0.11862085413719926, 0.09293313324451447, 0.11506792264325277, 0.16612236308200018, 0.07628957168864352, 0.10980114061385393, 0.17108375685555594, 0.12646323974643434, 0.08173446916043758, 0.17728313777063573, 0.06989030792777028, 0.1431640764432294, 0.0874813147155302, 0.06572835054248571, 0.07636499085596629, 0.1431238664580243, 0.13506323684539112, 0.13559398693697794, 0.12002599159521715, 0.11947183204548699, 0.20585114482258046, 0.19758441698338303, 0.22170066434357846, 0.25685047464711325, 0.12950739211269788, 0.19251394192022936, 0.1310265777366502, 0.15129357736025537, 0.11453542193131787, 0.12482168711721897, 0.1069686436759574, 0.1727435485060726, 0.12950117673192704, 0.0804729029270155, 0.14911656560642378, 0.11110968861196723, 0.09619295796645538, 0.16541323970471108, 0.10972325157906328, 0.12564384085791452, 0.08100752745355878, 0.07552753615060023, 0.10670571135623114, 0.1593036154018981, 0.22137259266206197, 0.21536869768585476, 0.18711622298828193, 0.15259511609162602, 0.14423128989126, 0.10991600302181073, 0.14373582362064294, 0.1689415675188814, 0.10442525015345641, 0.220441995454686, 0.1828537338546344, 0.10134180382426296, 0.12212799808808736, 0.10013682741139616, 0.23847479639308794, 0.10794711831424918, 0.10791448756520237, 0.11647722630628518, 0.12191374387059893, 0.1864141020923853, 0.11288025788962841, 0.21202673629990645, 0.1623597235551902, 0.17788054714245455, 0.12173641552882535, 0.07140693547470228, 0.07152492592909507, 0.10748616233468056, 0.1546787614268916, 0.14357004394488676, 0.09174313888485942, 0.12562026855136665, 0.17977401268269333, 0.12062981990831238, 0.11966080404818058, 0.1497263650276831, 0.08413841016590595, 0.16281815538448946, 0.22228970059326716, 0.08175456736768995, 0.11402888196919646, 0.19124886766076088, 0.0850167398207954, 0.12106965987810067, 0.11740124172398023, 0.15945051823343548, 0.10539024908627782, 0.07024102910820927, 0.09751584340951272, 0.10253629008574144, 0.0979251628741622, 0.12614344619214535, 0.15047453130994523, 0.10124285984784365, 0.11059561012578861, 0.1748569408165557, 0.05828894009547574, 0.10547054013503449, 0.1535927118467433, 0.19394103677145072, 0.09627161374581711, 0.09324536113334553, 0.09922726478959833, 0.10391177556344441, 0.12450717256537505, 0.12386607910905566, 0.21065108797379903, 0.20379740931093693, 0.09677958541682788, 0.24204489482300623, 0.19176261366478034, 0.1370531086410795, 0.20185724699071475, 0.11275534637804542, 0.10104569792747498, 0.11460216263575213, 0.142117137621556, 0.12320723517664842, 0.04906733367326004, 0.08515376996781145, 0.15528493747115135], [0.06295428904039518, 0.031169968324580362, 0.01298179813394589, 0.035675111758921824, 0.008165709241958601, 0.037551193231982846, 0.0045777068174045, 0.044866994954645634, 0.05708506290933915, 0.05724078669611897, 0.04638653341680765, 0.06303702281521899, 0.02673224243335426, 0.02630026838076966, 0.0436747376807034, 0.039432031235524585, 0.015557008163471307, 0.02801034626151834, 0.04543966154700943, 0.04626812566337841, 0.013597699281360422, 0.04570297384634614, 0.016804745853213326, 0.034870487970433066, 0.06986537176583495, 0.0490765413934631, 0.037820968577372174, 0.02212481663030173, 0.06733499933034182, 0.02425882113831384, 0.04382377789754953, 0.0340341358844723, 0.017798345037070767, 0.03257780295929738, 0.03071398939937353, 0.005283476959448308, 0.07294246022190366, 0.036726148932107856, 0.04437699428360377, 0.06329352940831866, 0.033221861613648276, 0.030603951375399317, 0.03099314888407077, 0.05772971867450646, 0.07657969290656702, 0.021842123674494878, 0.03776128124445677, 0.055953582017017264, 0.021657881060881273, 0.05741502091820751, 0.0539137123684798, 0.021580051397904754, 0.038831276686063836, 0.03814209884564791, 0.020081432170367668, 0.04342513518141849, 0.057416011579334736, 0.031080099754035473, 0.033166242098169665, 0.058007151287581236, 0.028820035313921313, 0.038764505447553735, 0.025718548434919546, 0.05596678291580506, 0.05024935185377087, 0.033184104532535584, 0.03719540339495454, 0.025083700893446803, 0.04598106124571391, 0.0893990175266351, 0.05093473668343254, 0.025096911970259886, 0.0617056828258293, 0.02409970128376569, 0.05909201343144689, 0.03570471624178546, 0.023821759769426923, 0.03912373206445149, 0.06810669720705066, 0.09086296361471925, 0.06853190117648669, 0.03569366629900677, 0.05014254026381033, 0.05745212999837739, 0.03822203705619488, 0.013440383481793106, 0.10776776115276984, 0.003651348757557571, 0.015579644091693419, 0.04432776317532573, 0.04967972509829061, 0.0666321116898741, 0.0016462551949579002, 0.05379334704152175, 0.032513532122331004, 0.03667142508285386, 0.008139904555199402, 0.05862701338316713, 0.04683630374659385, 0.013988698300506388, 0.021544988100816096, 0.1103479177025812, 0.011375611598071243, 0.030472868587821722, 0.08695570791938476, 0.03218135869662676, 0.06634606846741267, 0.03553539461323193, 0.0490335188806057, 0.040185422237430296, 0.03825040999799967, 0.03207378375477024, 0.0018013637413137726, 0.05342203571594187, 0.0329908136544483, 0.012740478850901127, 0.040062773640134504, 0.0030052506813912517, 0.049523516158972464, 0.015931254153006842, 0.06445348502269813, 0.045554951432027986, 0.019606902097750987, 0.03766064771584102, 0.014032879411908132, 0.0039335875189863145, 0.01755699352361262, 0.08039145158337695, 0.09028089591967207, 0.04386783517631037, 0.031976865205381594, 0.02331610699184239, 0.03597171637894852, 0.077586082475526, 0.05659462797588535, 0.01541533853326525, 0.06656611737396036, 0.030822256446949074, 0.0564210044353136, 0.045859372775469504, 0.07027557332600866, 0.0661904261048351, 0.03149480000138283, 0.05950014545981373, 0.10196456326437847, 0.04414336449865784, 0.06439310897673879, 0.022389068700639263, 0.017569208850285838, 0.06815749912389688, 0.049740138463675976, 0.055314042405890565, 0.019983395734535794, 0.04144918013896261, 0.018418780494747416, 0.013426225848629006, 0.04950252907084567, 0.024459063607667173, 0.033267014726464234, 0.017025641232196773, 0.044093098624476364, 0.027860710630193353, 0.029026265854814222, 0.02886451667706881, 0.03273775062656828, 0.07076633056359631, 0.09672503798667874, 0.014947408910042473, 0.011332203168421984, 0.031122213029967885, 0.06913651659020356, 0.0328958832126643, 0.01729208666698209, 0.03545882532905255, 0.033312948154551644, 0.025789399365229265, 0.05723396741918155, 0.011464827926829457, 0.04724202358296939, 0.04450593290052243, 0.027781228734446422, 0.036926656030118465, 0.062107606258775504, 0.06417582849306719, 0.023788194338391935, 0.0164891320746392, 0.04675301357305475, 0.07084168187741723, 0.018940165106739317, 0.028220274818262885, 0.029851313547364304, 0.01133963227870741, 0.03696566840101566, 0.057711907130266936, 0.031834450882992575, 0.0731989803857037, 0.010476473818666168, 0.036601647934211154, 0.02771361102350056, 0.06204336256320987, 0.027994526217558553, 0.026225941654826914, 0.05626535189471074, 0.023931015781792145, 0.04693879646116069, 0.04006817477888294, 0.015656075972531523, 0.033711919960166724, 0.031335551225181134, 0.04586622258648276, 0.044388176540711095, 0.016167148548577513, 0.025861037396160618, 0.01391252426297537, 0.043186548698161326, 0.04258882041488375, 0.01681697983959956, 0.03492123560447778, 0.03454720674614821, 0.028160339820065668, 0.07509532291442156, 0.06696226647389786, 0.02457095742491739, 0.05590085984606828, 0.03653046961075493, 0.04063471759270344, 0.040660742803343704, 0.06929996889084578, 0.047585073925022564, 0.02756295250063496, 0.06957624120903866, 0.04002102677311216, 0.03380522870325616, 0.020820431444527845, 0.012815597766478146, 0.05767648760229349, 0.018247898235650997, 0.03151281510612794, 0.057043835121606074, 0.043104147405496666, 0.05376004793548158, 0.009475002780423632, 0.021521970496645997, 0.05162865069827863, 0.017423235611724, 0.03944164946941393, 0.04040533543697425, 0.0059659101617788625, 0.03067615767940879, 0.006678432151342609, 0.05677369336730667, 0.04434728802048734, 0.021830793836020997, 0.039445391590041776, 0.05850143012191568, 0.031940539833158255, 0.007919851407807852, 0.003402704476944304, 0.014050645155033894, 0.01918081264011562, 0.048962483049503396, 0.018449170381895134, 0.03888479952833482, 0.01914741175382265, 0.019819207223398343, 0.02145277688811932, 0.02978570938908628, 0.03161180657999856, 0.030880664741354327, 0.021656680053898265, 0.03439416317269206, 0.0858374075698001, 0.0664875226627503, 0.04018916096538305, 0.064316597368036, 0.037789355630853345, 0.005764316559569644, 0.12283093322600637, 0.030321002272622924, 0.05576436574171696, 0.06045546169791903, 0.06167185785514968, 0.04288424438397799, 0.011686104981760894, 0.06422671183411564, 0.052803540868418555, 0.07596900460443326, 0.01995978780489947, 0.03444872756621667, 0.03525167876588447, 0.08772111577647072, 0.010324376801561033, 0.051719808485358953, 0.03018005019319909, 0.023666020715609193, 0.04775301134213805, 0.028534107442413057, 0.020028794816296016, 0.05551936370985849, 0.012971478464481021, 0.026372211752459407, 0.019061339586707096, 0.023775269942624227, 0.04084306516285453, 0.008352830540388823, 0.03157214620815856, 0.020785310471962606, 0.048957353324762413, 0.02149944143768932, 0.035192646219262054, 0.008646783784830143, 0.020042575862524763, 0.01954309266459729, 0.033343122606830936, 0.04770284385553428, 0.026583448185452392, 0.09597719740122557, 0.03511379366474492, 0.0920318216085434, 0.05358722506623183, 0.05905371012964419, 0.10659423483801739, 0.0422734203748405, 0.01767529610411397, 0.07054837154490606, 0.02268834165962679, 0.05483173292928508, 0.06653433479368687, 0.002391720801824704, 0.03859658160113862, 0.03505152450608356, 0.03248612948560289, 0.05925054635320391, 0.06869823046560798, 0.055982185660728385, 0.0361873446298497, 0.006337546760083309, 0.035968093001948934, 0.0408031198063067, 0.027986441472811357, 0.09245308328952108, 0.05652744283101388, 0.08862203386213098, 0.012105853529646993, 0.013192788597994616, 0.039151718241295645, 0.02960569065596376, 0.046867828483560255, 0.010829025347317969, 0.026981140952557325, 0.02572465525008738, 0.034868689852633646, 0.09339291535850082, 0.10398259426334075, 0.1989900836987155, 0.0880341443366238, 0.13731965076710495, 0.21218583919107914, 0.14066735255931104, 0.1992699522525072, 0.09997571605656828, 0.11142439315361635, 0.18552200496196747, 0.19594278292996542, 0.042790643870830536, 0.18370259473366396, 0.11268619008894477, 0.12184564609612737, 0.12123549383665834, 0.10788507985749415, 0.14026229429457868, 0.14901266832436832, 0.12537819439811365, 0.12904530976499828, 0.0907497839736087, 0.10792780720761844, 0.2096071754183088, 0.09850107625659023, 0.17571885670934403, 0.14798075226800783, 0.12597035190888814, 0.08743992407939263, 0.1020339841821364, 0.1451127475925854, 0.16580620647541114, 0.13494837443743432, 0.18224506080150604, 0.13451807467000826, 0.18396509279097828, 0.2529833950102329, 0.07885294128209352, 0.13252432165401323, 0.13324183172413281, 0.12762377890092985, 0.08149037975817919, 0.13942262077970163, 0.13920018342988832, 0.1808481200465134, 0.14665972601090158, 0.08510305626051766, 0.16942354451332772, 0.11027884962303297, 0.09534092832888875, 0.13107729144394398, 0.16263405526322977, 0.09313760977238417, 0.1695109669651304, 0.1175415220537356, 0.08395046275109053, 0.0819172461384109, 0.12821793130465917, 0.1516199391335249, 0.1364007107913494, 0.12301991879940033, 0.11690125641013895, 0.13715602883270808, 0.11671064235270023, 0.13870390291724885, 0.10717602433370692, 0.2196601466940982, 0.10709849492247615, 0.1669862060142415, 0.11210706045052835, 0.10317376016506127, 0.12644269370606967, 0.07235075732959168, 0.1309430229344538, 0.17532541496413095, 0.1331914844257491, 0.13943777925201825, 0.1543176993727684, 0.12428744935563632, 0.17695229766624315, 0.14329115248152188, 0.09553126418696982, 0.15063968673348427, 0.15886395185121469, 0.15229076599436148, 0.19929663224944047, 0.1198647173919848, 0.06808140142155544, 0.0954908167145082, 0.1259528999882085, 0.13552187223519596, 0.13972850436610834, 0.11647637135216168, 0.10334039479494095, 0.1730982187603201, 0.22084937430918217, 0.20842276540185722, 0.12514867314270564, 0.12605778793139116, 0.10423316367502723, 0.21249151921698026, 0.10187946818768978, 0.09940688657973494, 0.20193430142743246, 0.15748333664877073, 0.19831621700099536, 0.15663636209709303, 0.25867494674665586, 0.1447266475962741, 0.12488120820905481, 0.11658135429024696, 0.048183199151286056, 0.11233147233724594, 0.12443098665348121, 0.1049674946282591, 0.19347035059971468, 0.16152731036501272, 0.1269372914518629, 0.21755842518593582, 0.1455816017197711, 0.1399103517511061, 0.1721773517451116, 0.07697217113205365, 0.0785305489386831, 0.10550958304000752, 0.20912962247218403, 0.17222551416073525, 0.1453321451055152, 0.10093743766524962, 0.11394409223326615, 0.14242160985512392, 0.0671822407415935, 0.15949135247085774, 0.13580127938517503, 0.09361086759184088, 0.16871729812451772, 0.20759158714541368, 0.14870462699660233, 0.1036466108635068, 0.223290336185268, 0.1779021109853472, 0.17340605652758054, 0.10588040242769889, 0.24483443370887212, 0.14559388320360864, 0.1472728366830519, 0.10904054357005016, 0.1304264542247568, 0.1859151210103716, 0.12318816834262439, 0.1256101040967873, 0.11377070617995091, 0.11792654996471745, 0.06228421535342932, 0.14610393797712667, 0.24286619360957826, 0.11329100227781705, 0.11533477689538683, 0.08993625441300017, 0.08760828218821969, 0.12024504984063761, 0.14755014037447317, 0.1135855611147625, 0.23014784178563527, 0.1910051785941635, 0.1745242958090135, 0.12035582746778216, 0.13958297217530863, 0.1401580034622124, 0.16149270507906163, 0.11884889618626662, 0.11267083484147276, 0.12626128058348382, 0.13322322629392147, 0.13308804854750633], [0.010025851079262793, 0.04872962000912853, 0.0372700252836304, 0.03675896967095988, 0.02666297757865063, 0.051537299528717995, 0.030213281445737396, 0.028538229542651346, 0.0314375316458089, 0.01751431536727718, 0.038310864075486145, 0.03380042128264904, 0.043179763347974846, 0.035982260813138316, 0.012430474860593677, 0.03389239331175174, 0.05375582744766559, 0.01755332773817437, 0.01893327627996249, 0.026448467214192663, 0.03059624321758747, 0.05212092785430806, 0.044623896213514466, 0.03598882903211883, 0.09300608932971954, 0.051656670801873715, 0.04007161495142749, 0.03027128261913146, 0.04680945411590593, 0.11877674077238355, 0.015301234388191785, 0.059099687662507804, 0.05340243623192821, 0.018170658898140703, 0.0035588491674778716, 0.04149026543434177, 0.05653505938659821, 0.017856597268421735, 0.03330347241301622, 0.03561509194384728, 0.0426420582724469, 0.0534860283535506, 0.013464555443663682, 0.037437053463820896, 0.05552624405494758, 0.05044735176488757, 0.06835130229592323, 0.06265164885137763, 0.03868311517206686, 0.03854188828596047, 0.011592037975788116, 0.016234259054596935, 0.039844549992786985, 0.025891693608303155, 0.023525243358952657, 0.011659519131561475, 0.05825449087257896, 0.05609825925369348, 0.005615357766925756, 0.021255180705338717, 0.05007703110043492, 0.03848488795171891, 0.02387875671099339, 0.015599481062963605, 0.02186251025913017, 0.04262793117335864, 0.010392455068150801, 0.09017418950263943, 0.04970997418942196, 0.020169022559587444, 0.030391627590038946, 0.026555935286783745, 0.058329089012529166, 0.01717624716859843, 0.022336431346567612, 0.06049484387040138, 0.04862947163305112, 0.038427639952195544, 0.010106501751579344, 0.05983808304050139, 0.011878335648881537, 0.043968824935810905, 0.025227655490328158, 0.05248776424143996, 0.043197344190308025, 0.03328873463241117, 0.02642633849089699, 0.028557903665517057, 0.05666624056175351, 0.043688868172466755, 0.06024639827332326, 0.02195929649419018, 0.07020598955984626, 0.022785636795950786, 0.043548523381884606, 0.03421013429760933, 0.02781401215387242, 0.053169447662574906, 0.04009777247639639, 0.06322219502180815, 0.044930305664560626, 0.05739053258938449, 0.09664077750806298, 0.016967741839055504, 0.037142660867955, 0.004181220146295215, 0.044547822259898694, 0.06127064009862287, 0.04911039689821856, 0.03367785071688039, 0.08815429253237587, 0.028851458270634924, 0.008280717534944415, 0.02840139277811561, 0.0510691510779517, 0.051054179202765226, 0.01268927999106901, 0.04087905126756855, 0.039305230003914664, 0.049109413022441525, 0.07097718532064132, 0.016844492738268206, 0.041585463897458146, 0.027270814337368523, 0.05398181353562644, 0.06240527278610638, 0.0299627663168524, 0.016171265559803163, 0.03619295611445393, 0.023654612845608165, 0.019754093306671296, 0.06269580112504107, 0.06435837476913418, 0.04940933228603431, 0.02371523146783667, 0.02956729575193354, 0.035843727711055956, 0.035463083136294565, 0.056996378382401805, 0.04993414858888302, 0.015582868829369545, 0.02601435747263687, 0.018745554478040764, 0.050289222571466646, 0.020548963154266988, 0.03318465753857579, 0.04720831735591803, 0.05782986365790878, 0.06945806755019085, 0.030225922553134815, 0.05029659146176917, 0.0344831021502614, 0.047871978886957677, 0.018573550939826027, 0.05388943777818765, 0.02537419360929302, 0.026001161662861705, 0.03152101520182831, 0.02865478489547968, 0.02931191213428974, 0.00982168922200799, 0.025679785425641706, 0.009636786733088749, 0.017757817836744443, 0.038101098367146084, 0.032342565046357255, 0.04886881807552917, 0.04071137508643525, 0.04949394899553486, 0.052225032089544196, 0.04288570323426809, 0.020143338312794055, 0.052284295338072946, 0.028296703306425895, 0.008874827530235052, 0.016304350025685768, 0.01858770857299013, 0.03278847451188734, 0.04342335741966963, 0.04568400200722473, 0.022671040712988803, 0.047700109359409125, 0.015967906918376684, 0.022020878636145165, 0.07960777756358896, 0.023497660910444598, 0.05285277197669659, 0.03064699424430728, 0.07163125915186745, 0.023931499237992933, 0.019544420896896293, 0.006797327177732119, 0.04979696577148778, 0.025900679108287607, 0.03306621585839561, 0.03135028900578618, 0.03139077040499874, 0.05593140749260783, 0.06584606279752084, 0.01401906952794109, 0.015866406561274613, 0.03516462950834206, 0.05806479962276561, 0.01646581930773599, 0.012055690283887088, 0.051948155875184705, 0.02682228572666645, 0.01385052567015269, 0.06531949248164892, 0.020394331808867197, 0.0675876789859363, 0.1090045812140618, 0.06260541347520691, 0.04215614238221731, 0.06832729572696344, 0.029843249158667665, 0.03480163362941571, 0.04113878768735698, 0.014253084381510104, 0.01557152033118265, 0.03251521488917725, 0.02692079883334892, 0.03625430925084012, 0.06135542304920299, 0.03116208714033876, 0.03246224505294647, 0.014639275980048945, 0.006314714480790177, 0.04272903289113726, 0.06622417643666267, 0.027148252253287604, 0.03684350834893329, 0.027382837076272284, 0.036756903531828096, 0.03096786666927593, 0.05065606235127364, 0.05705228288258825, 0.08681073891265051, 0.05473255146560924, 0.05660543025338224, 0.07091770494090659, 0.013183811579697897, 0.05231911775522998, 0.0450771609986467, 0.04071496792935899, 0.08291550007249628, 0.053566197266003916, 0.02445680069337998, 0.06200427216078554, 0.04753949333514486, 0.03432191615658147, 0.03752154803701809, 0.08432455267757177, 0.032233147881925106, 0.04360338972349252, 0.04534655636442559, 0.029326364930186952, 0.021462612253214632, 0.009579286827439708, 0.01646403476063694, 0.016851435847846524, 0.03934411006048322, 0.002230040113707738, 0.019935950869694352, 0.029690717879150594, 0.05357444825183068, 0.04714452827881489, 0.020616718268554126, 0.04429944451632244, 0.01665394992700645, 0.05194397270679474, 0.03011718053104622, 0.04879534969638501, 0.015128355539802994, 0.049758994951844215, 0.1376131171626704, 0.02582812335874353, 0.041585555499685664, 0.05619022449744599, 0.03502397259165134, 0.02014754183723458, 0.03849954430812171, 0.02364953570733113, 0.05926126042114837, 0.04683399672753044, 0.05486336623185447, 0.06294255038457257, 0.044600544430847676, 0.0379673489369452, 0.021706699959135482, 0.0399081490800849, 0.025742108867104565, 0.014449991851246782, 0.019132728256019096, 0.011082687182351947, 0.055819432251155376, 0.04721305692302329, 0.03811159191120948, 0.016906680472727333, 0.028244320402986238, 0.09391526518655674, 0.0749384727595108, 0.012516828619741967, 0.0353111014701426, 0.06058626289346388, 0.06885698730392115, 0.06537127827427217, 0.00850303444479193, 0.0504672667676849, 0.022757262157808458, 0.023929545057139227, 0.013425699135820781, 0.005281999873529587, 0.01890866072582347, 0.0184325445776007, 0.04780198799978409, 0.03373243885913065, 0.03509709152526089, 0.028048429039439986, 0.04391535637634141, 0.026468029378780296, 0.029868527980787412, 0.009127539416242923, 0.03828112388561879, 0.03736853160496269, 0.03096662155751671, 0.041704726605010886, 0.0628515181264707, 0.022923094420028583, 0.06322302961988108, 0.0385485514998436, 0.026057934687872018, 0.019834667643798248, 0.02330424789605396, 0.01579403062351048, 0.03603235366089003, 0.04046891416822161, 0.024697541525321345, 0.037015832494944334, 0.020359507695372616, 0.032256587874144316, 0.019993667058380585, 0.036607971880584955, 0.039206153713166714, 0.0358300009476287, 0.03581090697220393, 0.01439279643818736, 0.07896106583731514, 0.0408634653181902, 0.013202767303612615, 0.027030967475314225, 0.026598135075931038, 0.1784015806125743, 0.15901724648262772, 0.19040440368865216, 0.15083609547998222, 0.12087150051125459, 0.26489320450595444, 0.07890453708491155, 0.07544442918151617, 0.11703536207122461, 0.09670929597424609, 0.20950212462672166, 0.1337136442639998, 0.1450365073978901, 0.11240944279623882, 0.11087281203695706, 0.10879851691424847, 0.1090593525607671, 0.10171250786100115, 0.08645212636994463, 0.12221442987876278, 0.16815144063106605, 0.1499000699924571, 0.14122327630008968, 0.1646851852004017, 0.17443596412028584, 0.0826153704630477, 0.062486194872430394, 0.10233998311949627, 0.1588441114872694, 0.2229741117251771, 0.08947333746722766, 0.11843070148357324, 0.08584114629775286, 0.22913706888045582, 0.14095882406192167, 0.2221110694642578, 0.15196449921599456, 0.10301789388592754, 0.1979173876877342, 0.12850218319467135, 0.11207445005753211, 0.10857162158936262, 0.1392829782728638, 0.09301972109824419, 0.1334239233817373, 0.1071947111881205, 0.19817794513489517, 0.11597857092108045, 0.09063379519752093, 0.1038620796586786, 0.07487374051873173, 0.13139793995235646, 0.10545575485697814, 0.18120990134775639, 0.11768964624830655, 0.10090821994734661, 0.17749439286334173, 0.10507516456501824, 0.11177181665386472, 0.10487981433314936, 0.08003962439085756, 0.14242120273411274, 0.18635612806039198, 0.1805234138986894, 0.15177138814968721, 0.15335803372519358, 0.08856409375688859, 0.18922364419060095, 0.1763654870114156, 0.15751038305461407, 0.06604757412735905, 0.09292338948164668, 0.1290116679987737, 0.06574874730514628, 0.0842942628743393, 0.11165576680962529, 0.17558099196425506, 0.15301469500575746, 0.14896872639656067, 0.12423643709293433, 0.14969080979270594, 0.09098397354994502, 0.15457685903779098, 0.0956174720610891, 0.07798827053712946, 0.10995579231530428, 0.08818293349551302, 0.10265995987824031, 0.16968127925481113, 0.11251793376037053, 0.16802717372775078, 0.132508376081075, 0.12612987549177238, 0.12739178777805396, 0.17049126007727214, 0.20229290718478815, 0.14351034643394606, 0.12085528352430888, 0.16087299904653005, 0.19041858507054193, 0.13902254296200617, 0.11460261046886444, 0.21066323375063284, 0.1252501548400947, 0.131184812102999, 0.11473278062684195, 0.12714971362480096, 0.14152781638715947, 0.16081757630620683, 0.13839044688003405, 0.12649300029235228, 0.1277444359979459, 0.07444787837032761, 0.06543780863285065, 0.11534804904035159, 0.14254666385906084, 0.07142885215580463, 0.07915508614054748, 0.1327443298484598, 0.11246709791677338, 0.15640914786074842, 0.06830734679741518, 0.16002613306045532, 0.11850289760955743, 0.22354359259562834, 0.17840049495654448, 0.08558903661157403, 0.13651725596615247, 0.13907587581447192, 0.13880486892802374, 0.12441337188439709, 0.11994213823761259, 0.15511086609746727, 0.14896149321326188, 0.13335259578057698, 0.15323033343468392, 0.0622561579304082, 0.10013287833758763, 0.11057640079941068, 0.1313010858637946, 0.08800624976200716, 0.11607598140835762, 0.0734116875433496, 0.0998947803995439, 0.0817180418276361, 0.08276114692645413, 0.129659234679171, 0.10649397450366191, 0.1399717591702938, 0.13308623007365636, 0.09546702727675438, 0.17019847221672535, 0.16235991354499543, 0.1623244397342205, 0.1740244733435767, 0.15868799415017876, 0.09294327055769307, 0.07756947872361966, 0.0726118983168687, 0.11389534627752644, 0.1314421532941716, 0.0843566202425531, 0.09792454540729523, 0.10971131614808526, 0.07967173627444676, 0.1770969477615186, 0.17377576311784132, 0.13302712967353209, 0.09012723487934896, 0.09405543695070914, 0.09841612367225544, 0.17128395182745798, 0.13855526303606375, 0.17667112632521562, 0.12305092784975256, 0.130287286692432], [0.032792803565306325, 0.05679323517584375, 0.03644901826711638, 0.057261800925646505, 0.036229064355471303, 0.054106694513133595, 0.03407301254836576, 0.07125592750630208, 0.08986818377992936, 0.045573451689311435, 0.01698004707161869, 0.022808282902198176, 0.009740814633135284, 0.03302809915372303, 0.07178732220615659, 0.044467141053506305, 0.03272852933566485, 0.0234010205604136, 0.002540284559862422, 0.01777460309676826, 0.03780337416433862, 0.057805219266031466, 0.023395358185682977, 0.06387414503842592, 0.03360834498224514, 0.06341628996389252, 0.04741400506879602, 0.041967356976653845, 0.07362418435513973, 0.02784396947494575, 0.006456560530101082, 0.012289965525269508, 0.07942278177610465, 0.02702565284978066, 0.017593676823058298, 0.038298487596746, 0.036677715102476735, 0.014775753121024795, 0.035223913112921376, 0.055815221941364665, 0.05667075960497771, 0.019348212318228822, 0.05483302214582052, 0.02481529618879514, 0.031014899324093546, 0.046464161215616126, 0.05374304724058934, 0.03196066178913627, 0.06796009971627168, 0.0037281487436432925, 0.010364025299038206, 0.029793875558035712, 0.028677651525608132, 0.0149806299845555, 0.04877299875287073, 0.05745193322322198, 0.03871694014274648, 0.03299852520493524, 0.04404206939839891, 0.05172853444569877, 0.02465204575232097, 0.044292991648295095, 0.07626855745911598, 0.029097430607570068, 0.021462997321837714, 0.04004879242607525, 0.054526846789355786, 0.006598054589371064, 0.02288408374546894, 0.032415504168186865, 0.033270950229572396, 0.05323849877874766, 0.04755116753014071, 0.031725966704211066, 0.024860054054962735, 0.03272899752482772, 0.05239199580890792, 0.02909230427550418, 0.04486087456877742, 0.005490588747696685, 0.05071319839251893, 0.05151283834129572, 0.021104266035503576, 0.011714846876982068, 0.04577939724549651, 0.028443144734150598, 0.007816620786408228, 0.027336377783545425, 0.05418918401535068, 0.01604121075277882, 0.06368525445993457, 0.05291981802188924, 0.040302160794713666, 0.04530004618157234, 0.0657333784869739, 0.08763627854308911, 0.018837165187246034, 0.05039656002606664, 0.015867380259026374, 0.019979575582380806, 0.02976862048464162, 0.03343167481943965, 0.03588895207004888, 0.009673174021632543, 0.07474846259823867, 0.02501288049721292, 0.029781383728342395, 0.016288635154653872, 0.005484026465897581, 0.05727744794317654, 0.007025077880825847, 0.048371994734874794, 0.031059706384049993, 0.02017723792232573, 0.02882117864542774, 0.016811035872836198, 0.021681154812020913, 0.016120517925758446, 0.026445944760260836, 0.062120539136230946, 0.010074109337957842, 0.059622471752975664, 0.044980554575366635, 0.08674609488142387, 0.03359944599547556, 0.06474233738013677, 0.021183140642408813, 0.03320246569014021, 0.01314884242934308, 0.057058674682463915, 0.03053489008120128, 0.059016987814434936, 0.024623547281537737, 0.046851217946303744, 0.05069928163928645, 0.08107156758861882, 0.07571211803172316, 0.0535818205348083, 0.043893188637282164, 0.036898086313158274, 0.021153946673231463, 0.020839674697656716, 0.033190842385270765, 0.027554686247770275, 0.025144969212955663, 0.07475895274962698, 0.014396901575050183, 0.10487187547343117, 0.034002115816942284, 0.07283101763044085, 0.05073106421955994, 0.05189316400459834, 0.06759964834366526, 0.009470734795156335, 0.11322306735174996, 0.006014928379694798, 0.023897429994706596, 0.04307762686429279, 0.030108312078352486, 0.023458431408341442, 0.043606443131076436, 0.009465630515478551, 0.04020415319662009, 0.03081010727744017, 0.019654796492042284, 0.024156302978683795, 0.09440364076622895, 0.037821514798062186, 0.041554553234683614, 0.019669768367228762, 0.05880911861147199, 0.015107368451676198, 0.06447793263942003, 0.06846803746053151, 0.02570165630563029, 0.04286457704646247, 0.03328307904303074, 0.03511006511481745, 0.04446997732988425, 0.04181998934862869, 0.016677506966516376, 0.09019804000854492, 0.02860771831391113, 0.023552764739309038, 0.044213128076600175, 0.03644385461562446, 0.03600451336907489, 0.11097019538283348, 0.0389020784225847, 0.007677829841018787, 0.012884167122787662, 0.024821956010003175, 0.09357372458492007, 0.018656642641872168, 0.06642324504043375, 0.030669643743229762, 0.04325735382735729, 0.04296279499041183, 0.03393212832244379, 0.012782116304151714, 0.03248239415032523, 0.018494301442322985, 0.013116785042387034, 0.045856763808322806, 0.01641507676270391, 0.032384861526744704, 0.014979205061016338, 0.012800860834041876, 0.06880903523415327, 0.01849989257087665, 0.05524938480396356, 0.04571721290371247, 0.02394901561949934, 0.043940204328724315, 0.060660277493298054, 0.04598352432783161, 0.08576154735471521, 0.08268482530755655, 0.0685517822525331, 0.011357640598102339, 0.017566437034734657, 0.029125192867858068, 0.04054469635177936, 0.04332127861146416, 0.02389293978922069, 0.015901442716962526, 0.015368631575256586, 0.04422810334446175, 0.011209733534737356, 0.037385345702724795, 0.03590609186461993, 0.02828359231352806, 0.023958428596545542, 0.03209782764315605, 0.0365146699228457, 0.036017205366598706, 0.043375239108822176, 0.040370950674904246, 0.03728693437629512, 0.023076344946665422, 0.029023582248815467, 0.03668392030522227, 0.045262438378163745, 0.044981748796999454, 0.061058116145431995, 0.016210210077198486, 0.02976904796170337, 0.023833642613941004, 0.038090136633919816, 0.026299496547185948, 0.009604755639364677, 0.014044793638666826, 0.0305694207283003, 0.012711063509673944, 0.012231593702121504, 0.030541342949228625, 0.03208298808229821, 0.08349912161273615, 0.014608847077137657, 0.035072810149618557, 0.021594614455742494, 0.05440624397514122, 0.05849598827106612, 0.046700793518019576, 0.013646500368070389, 0.042646312687013826, 0.02117357838765851, 0.041467436123639345, 0.0037862563622184098, 0.04379379004240036, 0.03640439101893987, 0.039513767563870976, 0.024270089908636043, 0.006020657335674124, 0.009533815651333757, 0.03008543187752366, 0.03839209150256855, 0.024171329136671763, 0.039531535003334284, 0.047810171132108996, 0.05536752453606043, 0.02062566644911255, 0.039861632111881456, 0.016411824883627038, 0.06694246003670351, 0.03768708683284266, 0.03224082211298602, 0.01564549082624061, 0.03566692862659693, 0.03161812034834709, 0.01663249634605433, 0.037930056652320285, 0.035636075639298985, 0.012571460018599672, 0.01736534639660801, 0.04973930386560304, 0.021318623729582344, 0.017984908240448152, 0.03887794293197138, 0.015184668857338173, 0.04358857391136033, 0.07612204139253922, 0.02954518229567579, 0.014096528541163673, 0.033620256664497514, 0.13643378258815833, 0.008358872894729887, 0.013671396666073372, 0.014159285396869694, 0.023037566670349667, 0.02760685032366642, 0.017822885952357734, 0.0558107368248914, 0.026337209523522427, 0.010688661048854036, 0.025243675702118447, 0.028403304550530653, 0.032717021381748576, 0.03213035661195006, 0.05297229592023151, 0.016778701982860054, 0.03220501582005194, 0.042742749476539235, 0.060925421837185106, 0.027223983546718955, 0.08656982505427939, 0.031639426347932646, 0.029943560383149555, 0.03015941594328199, 0.021481521327846816, 0.026817598746025136, 0.04005286024351205, 0.004155814947028245, 0.04534460557624698, 0.050916002331567664, 0.02470749054503228, 0.011098722661180156, 0.07590524266873087, 0.05144809592249138, 0.02396138700922685, 0.05953961584184851, 0.026061179781598703, 0.014395586913451552, 0.02422321162053517, 0.02069741134930934, 0.019875588394435387, 0.05095374584197998, 0.0054946815861122945, 0.07224259206226893, 0.035697157361677716, 0.023343116078259687, 0.023667710267805626, 0.09658673897917781, 0.1424355333937066, 0.0685955070491348, 0.14282974866884096, 0.1052117400935718, 0.14082839606063707, 0.11758809669741563, 0.15195057567741188, 0.15087705185370787, 0.19245705354426587, 0.16932949955974305, 0.14679613869105065, 0.08785437326878309, 0.11441751968647752, 0.21208958221333368, 0.10705934345190014, 0.22981405683926173, 0.08322934966002192, 0.10567716761891331, 0.09491024858185224, 0.1205933147243091, 0.14276186802557536, 0.09854102161313806, 0.10766232359622206, 0.11967451045555727, 0.11156064977071115, 0.11264157641146864, 0.22129111417702266, 0.09111991804093122, 0.08309382586074726, 0.05804217726524387, 0.12257284564631325, 0.15887467270450933, 0.1230334352169718, 0.16993553989699908, 0.06980365222053868, 0.10657393985560962, 0.1655153049422162, 0.26127663999795914, 0.16235022406492913, 0.16890804788896016, 0.07754261552223138, 0.16016444563865662, 0.10873787623963185, 0.0787611829915217, 0.1114169971219131, 0.10087881902498858, 0.16076395846903324, 0.17699733882078103, 0.07163216160344225, 0.16891792735883168, 0.1525045588080372, 0.07570352777838707, 0.10656850479011025, 0.11062849871814251, 0.22155392436044558, 0.15081502018230303, 0.09602031830166068, 0.11977137811481953, 0.10239769252283232, 0.15052782345030988, 0.07916713013712849, 0.12193621695041656, 0.12793076171406678, 0.13885949099702494, 0.1780995103929724, 0.15239363190318855, 0.17316357525331633, 0.1253815870732069, 0.15559780996825012, 0.11778621535216059, 0.13909680183444703, 0.1467543409339019, 0.10257879351930958, 0.22559924157602446, 0.11257499855543886, 0.13747629736151012, 0.09862858655729465, 0.1435013354888984, 0.11714850100023405, 0.21913189361138002, 0.1534792065088238, 0.09595266836030142, 0.08993727900087833, 0.10507134441286325, 0.15466702277106897, 0.10325874667614698, 0.17522956510739668, 0.1488697959908417, 0.1449965416852917, 0.09332889557949134, 0.13552635056631906, 0.24612894281744957, 0.11744736853454794, 0.11769164114126138, 0.1995249321418149, 0.09736752243978636, 0.09836690952735287, 0.0989079869219235, 0.11715642628925187, 0.12342917041054793, 0.07067942379840783, 0.14350932863141808, 0.1156046302723033, 0.17793506064585277, 0.08522125027541604, 0.10109185866479363, 0.11713133406426225, 0.16116512194275856, 0.1585054818008627, 0.13642725508127893, 0.13517216885728495, 0.11039730826658861, 0.10970337050301687, 0.06091068405658007, 0.08762819719101701, 0.2282517978123256, 0.12552357731120928, 0.07346176342772585, 0.1481266508677176, 0.13774418298687252, 0.14695862068661622, 0.0968941899814776, 0.13260084683341639, 0.16963595311556542, 0.11734421764101301, 0.09438190050423145, 0.09488854224660567, 0.10250670595892838, 0.22218581688191208, 0.14506131463817187, 0.09665675700775214, 0.08903488849422761, 0.12576778206442082, 0.10516793387276785, 0.17710298672318459, 0.11924281290599278, 0.1628962004823344, 0.08095152117311954, 0.11991810452725206, 0.11900120015655245, 0.10340007194983107, 0.13425649942031928, 0.1621723257537399, 0.13313764945736953, 0.20157887121396406, 0.1865079163440636, 0.21257288913641656, 0.1022168765110629, 0.26419729899082867, 0.12166401584233556, 0.15349042947803224, 0.1520680436598403, 0.056572107398616414, 0.21562890229480608, 0.10218393363590751, 0.14229761436581612, 0.08216166123747826, 0.15993368944951467, 0.10350400315863745, 0.10100240060793501, 0.10999108970697437, 0.0942055628235851, 0.04989064431616238, 0.1024000131125961, 0.08467070731733527, 0.12909619989139692, 0.11177364869841508, 0.17638493382505008, 0.12199701368808746, 0.16364276542195252, 0.09145787597766944, 0.21798445018274443, 0.15140590204724244, 0.07023652363568544, 0.10939477277653557], [0.04683091617854578, 0.026187801201428686, 0.04247343892763768, 0.04652568059308188, 0.028371119938258613, 0.06965014724326984, 0.04835311110530581, 0.06510616785713605, 0.06402545834758452, 0.047963160422763655, 0.0852961198293737, 0.025080079212784767, 0.018376706234578575, 0.01620040863885411, 0.009266250633767672, 0.028863661722945314, 0.06815426251185791, 0.018865870611209954, 0.023731777544266412, 0.021918560644345622, 0.06545723509043455, 0.01107490947470069, 0.03913312977445977, 0.030631964693644216, 0.06709906591900758, 0.029143340286931822, 0.02834342553147248, 0.03005330663706575, 0.04546377328889711, 0.04856332803943327, 0.017179412534460425, 0.031884156965783665, 0.09477746606405292, 0.03884070153747286, 0.03523714793846011, 0.03029289735215051, 0.030764777745519365, 0.04641405140448894, 0.03837459886978779, 0.10598211482699428, 0.023100105546680943, 0.09517701462443386, 0.03694611980712839, 0.06354707758873701, 0.022801120965076343, 0.016835664997675588, 0.04668805402304445, 0.08371730454798255, 0.04833623593939202, 0.026513304627899612, 0.02838267369328865, 0.0731488773599267, 0.06754296352820736, 0.02671151827754719, 0.03114609746262431, 0.07504172543329851, 0.10198629674102579, 0.06281081281070199, 0.025000363222456405, 0.026114870561286807, 0.03004926935370479, 0.05700505684529032, 0.05055708784077849, 0.042643764788018804, 0.05775819678923913, 0.03680496077452387, 0.039672032464295626, 0.04312800469675234, 0.04485650819593242, 0.05402399466506072, 0.059531575201877525, 0.014142112523716475, 0.01987552223727107, 0.016462219679462056, 0.03238353838345834, 0.03391498852787273, 0.03800757249285068, 0.04883030103519559, 0.023899491044825742, 0.03474545092987163, 0.04711841146594711, 0.0514015993103385, 0.030749843189758912, 0.045949533116072416, 0.02397012654026704, 0.083027594057577, 0.03425888364602413, 0.05917137488722801, 0.06950766846005406, 0.006750546853124563, 0.008669106738774903, 0.012710044010808426, 0.02617577077554805, 0.03703804433877979, 0.05840506457856723, 0.03866776670994503, 0.03357353274311338, 0.05157711935628738, 0.08423696059201445, 0.018141398771799037, 0.030683166946151426, 0.025170902821368406, 0.026695993396320512, 0.03744193891595517, 0.04729481700009533, 0.07150273104863507, 0.057307391693549495, 0.03366280081016677, 0.017034083904166306, 0.0372122921315687, 0.07004523782857827, 0.0354116603599063, 0.00957995857710817, 0.05057641930345978, 0.012944327733878578, 0.035263719369790385, 0.019567355380526612, 0.04003128282991903, 0.014066079282201827, 0.028248004848137498, 0.06447866545724017, 0.03110996208020619, 0.05687736673280597, 0.06202208370502506, 0.036396163781838756, 0.032910152804106474, 0.04610440534140382, 0.017786759051627347, 0.04425547544711402, 0.03300715956304755, 0.03325824126867311, 0.03535999670358641, 0.005931856609614832, 0.00560084984005828, 0.0271992611233145, 0.07381827251187392, 0.060404842985527854, 0.014264322617756469, 0.02097946817853621, 0.0417339341448886, 0.018426412317369665, 0.025063684110396674, 0.039376567783100266, 0.039666370089565, 0.044270410002874475, 0.008388339974252241, 0.04888140829280019, 0.041677184868603945, 0.024151880626699755, 0.015559342323935457, 0.05120857984625867, 0.04725738900846668, 0.02893166450251426, 0.019163111357816627, 0.0065668928686396354, 0.07772930086191211, 0.04493229716484036, 0.04642809707937496, 0.07948088472975151, 0.05316029083249824, 0.014673876176987375, 0.020283023228070567, 0.05048692053450005, 0.05916964462293046, 0.052510108399604044, 0.025163561072466627, 0.015493225871718355, 0.034247803169169595, 0.031741267668881586, 0.0033577224821783602, 0.03158252779394388, 0.08618037988032613, 0.05094122687088592, 0.06495425065181085, 0.03317256604454347, 0.011464429287506002, 0.02669176273047924, 0.08400662509458405, 0.03445894291092243, 0.0071091225004888, 0.055000002828559706, 0.03170725949374693, 0.035680916626006365, 0.042573170004678626, 0.05090492864006332, 0.0519057881486203, 0.01057662389108113, 0.030792886058666875, 0.033458585518279245, 0.027292239080582346, 0.07311265037528106, 0.0402674537285098, 0.04141853749752045, 0.005336686827441943, 0.02321054051364107, 0.027703438087233474, 0.07789470734340803, 0.035293520627809424, 0.048678105630512745, 0.019328059828174964, 0.01903366214329643, 0.03186007236529674, 0.10638557853443281, 0.03540039328592164, 0.05792246333190373, 0.014871913407530104, 0.009119169686787894, 0.015441482487533773, 0.11442483429397855, 0.03940668795257807, 0.04340305904458676, 0.04241230631513255, 0.01862166416166084, 0.04893598286435008, 0.021887994338093058, 0.02660691023005971, 0.01728155749983021, 0.03873929787161095, 0.02287153254396149, 0.03335853213710444, 0.016373638629115055, 0.06676738443119185, 0.06090313196182251, 0.041025282349437475, 0.05602705039616142, 0.0075480320291327575, 0.06024365699184792, 0.0573468010074326, 0.059405279478856494, 0.02469401483956192, 0.019279227359220386, 0.021907539539305226, 0.03689611177625401, 0.01836851122789085, 0.047485556586512497, 0.03501618640231235, 0.045939748641103506, 0.05314170575833746, 0.016534673648753336, 0.029439123879585947, 0.03478767616408212, 0.04003137443214655, 0.045935782603919506, 0.04372348024376801, 0.013110668049193919, 0.03795104034777198, 0.011750390237596418, 0.0658260527998209, 0.043145860345768075, 0.01251658349896648, 0.04399556600089584, 0.012486780544609895, 0.02996615899194564, 0.031846966461411545, 0.019799612828397324, 0.019234545828242387, 0.02400651298064206, 0.03364050414945398, 0.03384445820535932, 0.02573823612848563, 0.00986553615491305, 0.016286202606612017, 0.00283339260412114, 0.062182611519736905, 0.00402907605582316, 0.060536580559398444, 0.08541486345763717, 0.03134637385872858, 0.02001649806542056, 0.011587733519263566, 0.02673381833093507, 0.009169470335889076, 0.021360893068569045, 0.07114981820008584, 0.039876112049179416, 0.04614258650690317, 0.02498870768717357, 0.017828648411003605, 0.03886304908831205, 0.050688537037266154, 0.0390910945300545, 0.020765531176169003, 0.05169081129133701, 0.028319644575406398, 0.020732211714078273, 0.06121543448950563, 0.023880432692489455, 0.021366887925458804, 0.021090820864109055, 0.010466880181671252, 0.032304902960147173, 0.03972262742796114, 0.036407013556786945, 0.004112283956991243, 0.023018745805269906, 0.046120724108602316, 0.05015970719978213, 0.01843258528970182, 0.0337409001908132, 0.105110231254782, 0.030002467400793518, 0.03044813937906708, 0.028011026492874538, 0.01084120335456516, 0.036500607284584215, 0.03224473047469344, 0.06033529993146658, 0.012218768542100276, 0.03619903918089611, 0.03485719207674265, 0.012941542347627026, 0.019406125282070467, 0.06153038330376148, 0.005677397495933941, 0.012665179275375391, 0.01811427603076611, 0.043996753437178474, 0.03648164562348809, 0.02679448784328997, 0.07914722191968135, 0.0399089022539556, 0.006756532380157816, 0.02207150583022407, 0.02930245335612978, 0.05102872396154063, 0.03023108620462673, 0.07083395336355482, 0.03202921757474542, 0.05336852983704635, 0.05749144431735788, 0.03302113399175661, 0.08532569717083659, 0.03594257329989757, 0.009737309151595193, 0.04176229351599302, 0.04643801047599741, 0.036269047031445165, 0.022057952093226568, 0.02848221986953701, 0.040283752139657736, 0.0649310311834727, 0.06361683098865406, 0.012803618230723908, 0.04185138516394155, 0.051023421210369894, 0.012158555344545414, 0.050322036524968486, 0.08003040309995413, 0.05935816879251173, 0.04901221966637032, 0.02246686952587749, 0.018288964871317148, 0.11023504340222903, 0.1517780649342707, 0.1170997821858951, 0.23246471317751066, 0.15345001593232155, 0.12577160900192602, 0.12883212763283933, 0.14555023983120918, 0.1798886036766427, 0.18318776307361467, 0.11551426297851972, 0.15013943000563554, 0.06903743690678052, 0.09061563081507172, 0.11548793581979615, 0.10937209613621235, 0.12992220771099838, 0.08599288029862301, 0.1375622541776725, 0.07476814011377947, 0.19328261353075504, 0.08720064549041645, 0.12386898323893547, 0.1416176272822278, 0.1413028955991779, 0.09526605198958091, 0.2113582571702344, 0.1812429731445653, 0.11319933219679765, 0.08331295874501977, 0.09371186074401651, 0.12488393591982977, 0.23660450960908616, 0.11615667279277529, 0.10642571388078587, 0.11889175245804445, 0.11818059347569942, 0.13044761094663823, 0.09917935343193156, 0.16993118370217936, 0.13925047644547053, 0.14299603046051093, 0.09229223656335048, 0.20903021709195205, 0.08904606396598475, 0.1718680076301098, 0.17394938665841306, 0.22103987980101789, 0.17333144481692994, 0.07042985861854893, 0.17519502767494746, 0.18051270661609514, 0.13408541360071727, 0.09274678038699286, 0.1150026475744588, 0.15303491534931318, 0.1228669634354966, 0.1130724393629602, 0.1183431161833661, 0.10153563413769007, 0.15219022067529814, 0.19619669073394366, 0.12132203419293676, 0.07076534668781928, 0.16398211435547896, 0.16192238059427055, 0.09717249790472643, 0.13556042659495557, 0.10274399644029991, 0.0972024891525507, 0.12030606370951448, 0.16817725210317544, 0.11198558911148991, 0.05970707828445094, 0.1005350663991911, 0.17925170356673853, 0.15190225041338376, 0.19554379076829978, 0.11078074162027665, 0.07688487760190453, 0.13549443227904184, 0.129000580736569, 0.06044322092618261, 0.08439991077674286, 0.06671844848564693, 0.18440975035939897, 0.07541206306112663, 0.1906379825834717, 0.1308881023100444, 0.12554290198854037, 0.176720116553562, 0.18965403895292962, 0.08060563794736351, 0.049870413794581375, 0.13794216593461378, 0.13977209345570632, 0.0974136899624552, 0.18293392312313828, 0.19900887911873205, 0.15328977310231753, 0.1565935465374163, 0.1655191590211221, 0.0888985436675804, 0.11355741548218898, 0.11304792389273643, 0.17712385846035822, 0.1531581644501005, 0.10834083825881992, 0.11422499216028623, 0.13167236665529863, 0.1563267329973834, 0.13612461489226135, 0.08289208382900272, 0.19144036381372384, 0.05567778128066233, 0.16499334866447107, 0.18008418461041792, 0.13868353329598904, 0.11959505400487355, 0.18935485929250717, 0.1596185370747532, 0.12666686810553074, 0.20699641693915638, 0.1458439640700817, 0.0959698013695223, 0.08888947843973126, 0.1218449268490076, 0.08594446682504245, 0.09115434012242726, 0.06542168664080755, 0.09991820342838764, 0.1714475466204541, 0.1361082893397127, 0.08881688197808606, 0.10955828614532948, 0.09829446912876197, 0.1518738605082035, 0.19412984592573984, 0.072598700810756, 0.15429000157330716, 0.0854120882494109, 0.06604632562292473, 0.13569776208273002, 0.1527887021324464, 0.12173938751220703, 0.08893629735601799, 0.11039777645575148, 0.1345634822334562, 0.10686501780790941, 0.06842708787215607, 0.142104584723711, 0.13100607240838663, 0.12402029654809407, 0.11914172475891453, 0.075263986364007, 0.18214968591928482, 0.13440261515123503, 0.07695774547755718, 0.10658269974270038, 0.07130186432706458, 0.04815589490213564, 0.11844990402460098, 0.14948878277625355, 0.10937989250357662, 0.24473941166486057, 0.21005770909999097, 0.13285548745521478, 0.1257042983280761, 0.22503904306462832, 0.08957478523786579, 0.12180150060781411, 0.20798162264483316, 0.16378798548664364, 0.16639579912381514, 0.08009347971528769, 0.08296073800218956], [0.040273404480623345, 0.030492868407496383, 0.09179771345640932, 0.019219967503366724, 0.021531139201085483, 0.008194869284385016, 0.05145372776314616, 0.06994311152292149, 0.009531086244221245, 0.027186370654297725, 0.033473269016082795, 0.04967128751533372, 0.040148438686238866, 0.03870907931455544, 0.0015954130961160573, 0.0667402498157961, 0.06508877700460808, 0.025170429543192898, 0.05213861047689404, 0.059344218112528324, 0.02642064049307789, 0.08266353287867137, 0.04128073721325823, 0.04230495189715709, 0.029694673738309314, 0.04304234304332307, 0.05399573028885892, 0.03553322669384735, 0.01711828670730548, 0.010142905155329831, 0.06762080506554671, 0.05702371655830315, 0.046478563121386936, 0.0564006687408047, 0.05890428993318762, 0.1077693896368146, 0.025309722604496137, 0.023544627408097898, 0.04144758218899369, 0.04339516768231988, 0.024383491769965206, 0.017726866461868798, 0.031239697975771766, 0.05165809572541288, 0.03279975176389728, 0.0569722361064383, 0.05426844029820391, 0.05495865290452327, 0.03472356139017003, 0.05087301713813629, 0.07931745278515986, 0.03256641374900937, 0.014596031246972936, 0.051048374335680685, 0.06437263757522617, 0.017286444648302028, 0.02199346412505422, 0.020313737115689685, 0.0334788397885859, 0.028141766620267714, 0.06946329226983444, 0.029055978903280835, 0.03604194814605372, 0.016039424509342228, 0.002820669436394902, 0.0770787282713822, 0.039451464478458674, 0.01796360393720014, 0.058768643997609615, 0.013982596574351192, 0.0690767987232123, 0.014955437675650631, 0.009282677118400378, 0.0631740733182856, 0.013067528489045799, 0.029578871559351683, 0.05335631620671068, 0.048951120980616124, 0.03862650838813611, 0.06342909391969442, 0.002234118745296395, 0.05143606549661074, 0.02898080400856478, 0.024856310237997344, 0.03746574531708445, 0.08617998633001532, 0.030544698304895843, 0.019271982301558768, 0.03886476917458432, 0.026753394066223075, 0.004145735309326223, 0.06992532033473253, 0.04730283389134066, 0.0199120800077383, 0.017740191193297505, 0.06661857491625206, 0.03280896966212562, 0.07324337693197386, 0.08557934713150774, 0.024876857974699566, 0.04096220573410392, 0.07906406745314598, 0.02257232234946319, 0.0133235635003075, 0.030141519582165138, 0.01783947104455105, 0.023569799360952208, 0.02270370878146163, 0.050845682354910035, 0.08054638148418494, 0.026884159638679454, 0.038622837513685226, 0.021139305583866577, 0.028476448929203407, 0.030271055309900215, 0.032819459813513925, 0.042449228798172305, 0.042687621898949146, 0.027193439292854497, 0.04646928415500692, 0.01157939008304051, 0.0222275722771883, 0.04158825606905988, 0.032935387521450005, 0.06873229970889431, 0.03936607763171196, 0.014033209349560951, 0.02703520323016814, 0.01743210576075528, 0.03493870109585779, 0.021156257084969963, 0.02345597341523639, 0.03950678204585399, 0.03660597698763013, 0.04393742912049804, 0.02229362596491618, 0.013227477852654244, 0.0440241526812315, 0.032230172505868335, 0.07010669953056745, 0.02563397752653275, 0.022332636639475822, 0.04992375682507243, 0.0012092682528808446, 0.052152235460068495, 0.0490662989073566, 0.0923308791326625, 0.02872361888044647, 0.023571405792608857, 0.017105838982388377, 0.04711139541385429, 0.06837067447070565, 0.01419421553146094, 0.0788157507777214, 0.07873847920979772, 0.021915671781503727, 0.01040167042187282, 0.06282549630850554, 0.058098482101091316, 0.0175118709448725, 0.024924450420907567, 0.08121683515076127, 0.033194581113223515, 0.025538397387468388, 0.007525110268034041, 0.05109356816059776, 0.040373138950339386, 0.0149099435989878, 0.018820179759391716, 0.04197446123829909, 0.04123315494507551, 0.003682847201292004, 0.008183390168207032, 0.02972141819606934, 0.03258354675823024, 0.07506782189011574, 0.06581039221159049, 0.05874511918851307, 0.04441065301320382, 0.04695171916059085, 0.03166922421327659, 0.025157798613820757, 0.01767242081197245, 0.022470128190304552, 0.03979624169213431, 0.06921818506504808, 0.024478018483413116, 0.014804224450407284, 0.03256998284320746, 0.030333979254854575, 0.061501090947006426, 0.011714080132410994, 0.03127270870442901, 0.018864846023331796, 0.030170533739562546, 0.022059767174401453, 0.03553784412464925, 0.024924974589209472, 0.028822016636175767, 0.034457100688346794, 0.026387114077806473, 0.04614104962508593, 0.02439518123199897, 0.0572706422369395, 0.07529213878193072, 0.023618256939308982, 0.023677048605999777, 0.025512097370145575, 0.050190163244094164, 0.019004766729527285, 0.03584122730951224, 0.045357864150511365, 0.03280085777597768, 0.0033545024094304866, 0.04586099447416408, 0.021838082998458828, 0.030961647895830016, 0.026450986275449395, 0.014985975144164903, 0.039382192838404856, 0.010917872722659792, 0.031245899785842215, 0.02946374113006251, 0.04175395092793873, 0.069599067127066, 0.04391342255153826, 0.06083830472614084, 0.023223548029948558, 0.03756524569221905, 0.06849906008158411, 0.037822563134666, 0.05987817767475333, 0.019769416323729923, 0.022884823348639265, 0.044071921546544345, 0.018488961371726224, 0.051807400570916276, 0.034057077153452804, 0.027457608242652247, 0.007553644361905754, 0.032694527945880375, 0.04027580310191427, 0.0770876102947763, 0.011521359223739376, 0.0205084664880165, 0.03255400334351829, 0.0019318861013744026, 0.0034078204189427197, 0.04205392108165792, 0.02802264131605625, 0.030082446323441606, 0.026884247848231877, 0.038695739316088815, 0.023047264632103697, 0.06203173925834043, 0.06063080193208797, 0.03475214807050569, 0.06505283500467028, 0.029711355521742786, 0.03700138309172221, 0.02185614051164261, 0.026682868832722306, 0.048336073090987544, 0.013818039109797349, 0.05340672118057098, 0.03859781314219747, 0.0338901541461902, 0.05570281243750027, 0.004803406648404364, 0.02164537226781249, 0.09201736881264619, 0.18272629140743188, 0.09306460618972778, 0.0882082496370588, 0.037618259633226056, 0.019806996985737766, 0.010492605988734534, 0.020387923045616065, 0.03569067735224962, 0.027214675742600645, 0.0637109980785421, 0.029563713087035075, 0.03351869693558131, 0.04119337582960725, 0.04594273080251046, 0.0755112784515534, 0.07293911504426173, 0.046108340844511986, 0.017173132692862834, 0.05134978298363941, 0.03178725537977048, 0.03439870596464191, 0.019887613731303384, 0.03118941853088992, 0.038088039960712194, 0.009514060952434582, 0.03843159920402935, 0.017179052910900543, 0.046918467552001984, 0.06810548262936728, 0.07121948339045048, 0.07804072807942118, 0.061394683085381985, 0.061606433508651595, 0.024000611422317367, 0.018140640508915697, 0.027755951608664224, 0.03640371248392122, 0.02308417863345572, 0.019978574743228297, 0.014552571079028504, 0.01808086666278541, 0.01284732691211892, 0.03883456079555409, 0.06088686069207532, 0.0303885877531554, 0.03813472995534539, 0.0197814009484968, 0.01266723099563803, 0.04377565958670207, 0.04858899023383856, 0.05477118385689599, 0.056588497411991866, 0.021497229413528527, 0.036472359871757884, 0.010099611228464969, 0.028786960124437298, 0.02264221484905907, 0.01949336622575564, 0.04726692921082888, 0.02227590771924172, 0.02064353397249111, 0.03149065415241888, 0.0394762038652386, 0.010029446466692855, 0.020637377963534424, 0.05808527780962842, 0.03618753122697983, 0.04594032878854445, 0.023995422325762253, 0.009753502389815236, 0.03527794485645635, 0.04172662293006267, 0.016434459115511606, 0.03316290031320282, 0.03077798882233245, 0.007331150184784616, 0.0123750639946333, 0.037001505228025575, 0.011484705610200763, 0.02116810091372047, 0.07139371761253901, 0.163343002221414, 0.11024713489626135, 0.14364119512694223, 0.08234262652695179, 0.11725803012294428, 0.0788421118631959, 0.1505276741726058, 0.18763090537062713, 0.12775147919143948, 0.10915181652775832, 0.08245520905724593, 0.14249338528939656, 0.12196576036512852, 0.13135285808571748, 0.11476570314594678, 0.13663838803768158, 0.12382110580801964, 0.12053928976612431, 0.12582567467221192, 0.10038520515497242, 0.11435368311192308, 0.10112044534512929, 0.07678820671779768, 0.1218726382191692, 0.08491672375904662, 0.13128239900938102, 0.1754330170473882, 0.1125735193490982, 0.12342329429728643, 0.08600152483476059, 0.10773547645658255, 0.15399764797517232, 0.18502199250672544, 0.0931676688737103, 0.09393805717783314, 0.18171356432139874, 0.09576214251241513, 0.08197866712829896, 0.19157970776515348, 0.08641347022993223, 0.1804138304931777, 0.1319488968167986, 0.14471207266407354, 0.12998304516077042, 0.10453142052782433, 0.20089484006166458, 0.09053232707083225, 0.1483139536742653, 0.1783338085349117, 0.10711811136986528, 0.19782521549080098, 0.12265489410076823, 0.08775477789874588, 0.12431362723665577, 0.217444580580507, 0.08634412395102636, 0.10474665183573961, 0.0933191789580243, 0.13981442047016962, 0.09061417875013181, 0.18270250196967805, 0.11935008929244109, 0.11710470835013048, 0.10751877951302699, 0.10903654021344014, 0.14269363454410008, 0.3047179989516735, 0.07453504976417337, 0.11675267081175532, 0.17361223617834703, 0.14342856939349855, 0.08449557064367191, 0.13032846019736358, 0.21092176916343824, 0.10723031392054898, 0.11762623036546366, 0.08759908125336681, 0.07692477546100106, 0.1467566615236657, 0.135864953111325, 0.11908718411411558, 0.17499608120747975, 0.08591484198612825, 0.1078778738155961, 0.07827964025948729, 0.1371432723743575, 0.167002015880176, 0.1281722794686045, 0.25348000121968134, 0.1116486829040306, 0.12120200134813786, 0.10387204733810254, 0.21659460690404686, 0.10423063273940768, 0.1387884755219732, 0.2346300541290215, 0.12993288785219193, 0.22279782832733222, 0.1478919998875686, 0.10748220647552184, 0.09161365404725075, 0.14479785306113108, 0.12524750855352196, 0.07087184954434633, 0.11478945187159947, 0.13770281949213573, 0.07262458692171744, 0.1172816160001925, 0.1718508678355387, 0.24052253365516663, 0.20276942875768456, 0.14473035239747592, 0.11897234884755951, 0.15424181201628276, 0.13534621308956826, 0.08777090667613915, 0.11704003039215292, 0.14058115147054195, 0.09140385101948466, 0.1653795029435839, 0.18794660057340348, 0.1675040503697736, 0.18229734871004308, 0.13301121124199458, 0.11207022956971611, 0.20237484707364015, 0.16550357985709394, 0.1370215296213116, 0.10144939233681985, 0.09803733828344516, 0.10775317943521909, 0.19962257333099842, 0.09177982048796755, 0.11444295117897646, 0.08362245213772569, 0.06919694691896439, 0.15241622711930955, 0.14379556184368475, 0.11680698075464793, 0.1685942661549364, 0.10939855900193964, 0.048541312970753224, 0.1694832013121673, 0.1185541677155665, 0.11758673962737833, 0.09544021157281739, 0.162698393953698, 0.12457660026848316, 0.12388423670615469, 0.0873403897775071, 0.1011343892397625, 0.1327685128365244, 0.10276522101568324, 0.13760527329785482, 0.09786730419312205, 0.09262615721672773, 0.09704107924231462, 0.11214564873703889, 0.1461225569780384, 0.12919650093785354, 0.15305330364831857, 0.12281741680843489, 0.1291876799826111, 0.07118919358721801, 0.07807470911315509, 0.22208924777805805, 0.1278360110840627, 0.14007666068417685, 0.12499460498137133, 0.10046634437250239, 0.12328762800565787, 0.059174672567418644, 0.09299276290195328, 0.09416227907474552, 0.1253578790596553, 0.1102551891069327], [0.028791937178799083, 0.009649652605211096, 0.05068539542012981, 0.07408637526844229, 0.02421252130131636, 0.04645613753902061, 0.03685937589034438, 0.020365066593512893, 0.041955282445997, 0.06590554317725555, 0.04337569033460958, 0.04408588240455304, 0.03261529880442789, 0.06270003518355743, 0.04642084354002561, 0.025310492741742303, 0.03841236612892576, 0.015812532577131475, 0.018486898625269532, 0.0028375225499205825, 0.058873613364994526, 0.010774646702754711, 0.05587422056123614, 0.05734802915581635, 0.042754949536174536, 0.03315074096566864, 0.010406826439845775, 0.01974824603114809, 0.023467671358957887, 0.03305393437455807, 0.041855334237750084, 0.05570918388132538, 0.028667619385357414, 0.016735662506627183, 0.05237681019519057, 0.03393859476117151, 0.07584328563617808, 0.011882870807312429, 0.03587738983333111, 0.019245136063545942, 0.023344775096380284, 0.019047368550673127, 0.0237552786046373, 0.06583213925893817, 0.005975058934252177, 0.05939242124025311, 0.010479332147432225, 0.019642567594668696, 0.03491086080404265, 0.05071254021355084, 0.05173135715137635, 0.008770469692535698, 0.015573106406788741, 0.03843909362331033, 0.021307200592543398, 0.009284106282783406, 0.04591875137495143, 0.04594149586877652, 0.03881977551749774, 0.05049257612388049, 0.020920919088114585, 0.0693989060819149, 0.08065633129860673, 0.008390966752943183, 0.01625728853312986, 0.02655750948802701, 0.05301715726298945, 0.0028745921902425054, 0.0688798539340496, 0.03424108227980988, 0.036630740123135705, 0.03553822410425969, 0.016517069057694504, 0.03541280369141272, 0.0052818107318931395, 0.03712576534599066, 0.0271596007514745, 0.01560032244638673, 0.022305434170578207, 0.010792068089358509, 0.06214842014014721, 0.020987306954339147, 0.007691096048802137, 0.01954162024360682, 0.05697674157896212, 0.039581149483897855, 0.06468188669532537, 0.02471262026977326, 0.004037077680030572, 0.04984840890392661, 0.029664024311516966, 0.05311377725696989, 0.03388891921245626, 0.04246111333902393, 0.02210921371754791, 0.03313332636441503, 0.061309262311884334, 0.023417042468541434, 0.017647328586982827, 0.03853274841925927, 0.021603581296013932, 0.06970007384994201, 0.008725377647871417, 0.05218834709376097, 0.045764927486223836, 0.01923928709168519, 0.027075933991000056, 0.02574505710176059, 0.04211384250915476, 0.046078274957835674, 0.03380080126225948, 0.0065027318695294, 0.029338714267526354, 0.025173774720834832, 0.026573361762400185, 0.023675045231357217, 0.024613491392561367, 0.029024104720779827, 0.04996603634208441, 0.03473074707601752, 0.020338313654065132, 0.04097566447619881, 0.047307682024048905, 0.03604113729670644, 0.052359683971319876, 0.05508114204608968, 0.04950405916731272, 0.012547357606568506, 0.006449013100271779, 0.0886464204107012, 0.048290387328181944, 0.05146581247182829, 0.021617396268993616, 0.009406060229853859, 0.02290547965094447, 0.015011175934757506, 0.021477022640673176, 0.02306339510583452, 0.03810569544189742, 0.005776398723745453, 0.07778012992015906, 0.044276489676641564, 0.028894731841449226, 0.0029976867122708684, 0.03898254589044622, 0.05548225123701351, 0.02476277757835175, 0.04252489563077688, 0.012613080508474792, 0.005944029103764998, 0.05626983701118401, 0.01883661387754338, 0.04065207791115556, 0.026309282718492404, 0.06859708125037806, 0.02134751066166375, 0.10901459639093705, 0.0024863170651120265, 0.02604513242840767, 0.01579940801353327, 0.04255368247894304, 0.02501924685202539, 0.05194764697392072, 0.04834077533866678, 0.006515914108604193, 0.020572715272594775, 0.04641662644488471, 0.021781691649396504, 0.040808520945055146, 0.04644207490075912, 0.020486381869497042, 0.03126112611166068, 0.03297376206942967, 0.04090906287144337, 0.03870335587167314, 0.10248720486249242, 0.016241166541086774, 0.049060358333268335, 0.017850064672529697, 0.02145776242416884, 0.031705010150160105, 0.011799622194043227, 0.029576486508761133, 0.04628150976662125, 0.03299443703144789, 0.07462260113762957, 0.04487220271091376, 0.0438334300581898, 0.020814777551484958, 0.07228191316659961, 0.09896259542022433, 0.024391060828098228, 0.10709089533026729, 0.06907312106341124, 0.019170571850346665, 0.03835429370935474, 0.0347591675152736, 0.03959567013329693, 0.04601790230455143, 0.04160794036995087, 0.02536168651256178, 0.03529860624777419, 0.012474326882511377, 0.03681433812848159, 0.040656926043863804, 0.05424747017345258, 0.021053280914202332, 0.03266009568635907, 0.028591185808181763, 0.03217374214104243, 0.05869652929582766, 0.006297598859029157, 0.09453368200255291, 0.039117353835276196, 0.03019900506894503, 0.047479191928037574, 0.0297836398572794, 0.03329469216987491, 0.01026703804797892, 0.05290269519069365, 0.025906711284603392, 0.05707899002092225, 0.03161574547578182, 0.05912254750728607, 0.025975818379915187, 0.02998449300814952, 0.05310193682089448, 0.034410692285746336, 0.01865995558910072, 0.039851118211767504, 0.03642695230830993, 0.05432984771739159, 0.043731727836919684, 0.04583214655784624, 0.04747813680608358, 0.04882215182962162, 0.021904857629644017, 0.026915429925013865, 0.05327461380511522, 0.02915833591084395, 0.021953537428219403, 0.031091960546161448, 0.017431320356471196, 0.017240392476586357, 0.024853126212422336, 0.018344776072938527, 0.020098804363182614, 0.038207394270492454, 0.029400600053902184, 0.025284140137955546, 0.03261937340721488, 0.04213434783741832, 0.012808999861590564, 0.02022580406628549, 0.028158163418993354, 0.04043233434536627, 0.05592796392738819, 0.03972221012892468, 0.01026645620420043, 0.02802626638939338, 0.023608747271022627, 0.04999541690839188, 0.037871607645813904, 0.024618646562365547, 0.028613102489284108, 0.018292596730004464, 0.014047066730979298, 0.05514161308695163, 0.03775716932224376, 0.061481935903429985, 0.009150465418185507, 0.02040078637323209, 0.09107035105781895, 0.04756381203021322, 0.05275785171293786, 0.02872669603675604, 0.0393065667179014, 0.053341235765921216, 0.019407763944140503, 0.07104592770338058, 0.025905859723154987, 0.02607878776533263, 0.020403632827635323, 0.058738320267626216, 0.06795876300228493, 0.027681762286062752, 0.05102497844823769, 0.03079079956348453, 0.013563660572149923, 0.0757958831797753, 0.037989092591617785, 0.024147488808791553, 0.043352219808314524, 0.025641100447891012, 0.02408079899448369, 0.030081638866769414, 0.094012132845819, 0.046820236037352254, 0.01380070423640843, 0.06812125178320066, 0.05912944142307554, 0.023856305683563863, 0.07749197645378963, 0.02479367975943855, 0.021828843047842383, 0.01028774948125439, 0.023273286343153034, 0.015320978060896908, 0.03082007495686412, 0.03216441228453602, 0.09716561755963735, 0.02742047541375671, 0.03832333554912891, 0.035152758538190804, 0.010818133163931114, 0.012934708651820464, 0.06160408577748707, 0.0010823928065032565, 0.03786070698073932, 0.0099610849117328, 0.05011265418891396, 0.028896363718169074, 0.07447847351431847, 0.03554163035005331, 0.03768899351624506, 0.04639176152912634, 0.019273179915866682, 0.019715111469849944, 0.024330627106662308, 0.05089111027440854, 0.0752409433147737, 0.016677617228456905, 0.06204693165740796, 0.016460923677576438, 0.02526166705813791, 0.011630025758807148, 0.087060507653015, 0.027673268723966818, 0.04884064869422998, 0.06106819239045892, 0.011840234211246883, 0.029704543030155555, 0.011811048723757267, 0.017933381987469535, 0.00991999198283468, 0.038276764298123975, 0.02029242941976658, 0.04649813546399985, 0.04280118151967015, 0.027236855356022716, 0.0063339882679948846, 0.02836264673221324, 0.11080057519887175, 0.07675208829875503, 0.18378449391041482, 0.141106161155871, 0.13487731825028146, 0.07368552392082554, 0.08638292936874287, 0.10853428859263659, 0.08532201272568532, 0.2877934899713312, 0.1387883805270706, 0.10940270485090357, 0.09555008674838714, 0.0959075932790126, 0.14461732203406946, 0.09616190141865186, 0.1738344021141529, 0.15778816172054835, 0.11434787485216345, 0.10884559367384229, 0.08992247336677142, 0.10522475439522948, 0.20070740154811315, 0.18987587919192656, 0.09222502766975335, 0.11639139162642614, 0.05891159775533846, 0.12056084003831659, 0.10293698537030391, 0.12099624238908291, 0.17291870553578648, 0.0939154891031129, 0.14875863838408673, 0.1672834043524095, 0.12833130093557493, 0.14552393981388637, 0.16335749572941236, 0.1562143675982952, 0.06462194491177797, 0.13553700356611184, 0.11140127546553101, 0.125283131642001, 0.17888049062873634, 0.15591558148818357, 0.09838183729776315, 0.14314887725881167, 0.08275796459721667, 0.1893746182322502, 0.09779882643904005, 0.14453249158603804, 0.11155774564083133, 0.16740270437938826, 0.09587661137006112, 0.14631048403680325, 0.13438448469553674, 0.17235037817486695, 0.141449133466397, 0.14521532851670468, 0.11424732953310013, 0.2516810420368399, 0.09765608981251717, 0.12298164942434855, 0.14686486071773938, 0.1308030275894063, 0.08569095257137503, 0.10853253118693829, 0.12857680847602232, 0.10907686554959842, 0.19840340875089169, 0.13975993410817214, 0.15318736859730311, 0.17135114036500454, 0.07712032925337553, 0.138797201482313, 0.11833269388547965, 0.17214449707950863, 0.10981602767216307, 0.14923596062830516, 0.06924506862248693, 0.14828637801110744, 0.19781997720045702, 0.07813420984894037, 0.16449026923094476, 0.11500291898846626, 0.12680596778435366, 0.16223142615386418, 0.19353333222014563, 0.13988113403320312, 0.09488409105688334, 0.1998192263501031, 0.12353924236127309, 0.11516204902103969, 0.1162191658679928, 0.16148406054292405, 0.05636574454339487, 0.2014187912323645, 0.2075296097568103, 0.12674570030399732, 0.10971311426588468, 0.1130125450768641, 0.12698786945215293, 0.13452525357050554, 0.08487574702927045, 0.12497038128120558, 0.13582934359354631, 0.0817675409572465, 0.11201637424528599, 0.10233391023107938, 0.11898881010711193, 0.08573467058262654, 0.15169700714094297, 0.09406245300280196, 0.13786139312599385, 0.20196683039622648, 0.08596608495073658, 0.07028577170733895, 0.12821850127407483, 0.08829004703355686, 0.11397727259567805, 0.09774089311914784, 0.1708366751138653, 0.1482666597834655, 0.11505378197346415, 0.1530539279005357, 0.14356260720108235, 0.11517194206161158, 0.13112337754241057, 0.1167095024138689, 0.09465606257851635, 0.10900193492748908, 0.1829728303211076, 0.08093512098171882, 0.13414713314601354, 0.20435098532055104, 0.14677336705582483, 0.14210847951471806, 0.10530358659369604, 0.08586519357881375, 0.08302230148443154, 0.07328977515654904, 0.11942649233554091, 0.11953865417412349, 0.1571702877325671, 0.06723730385835681, 0.176625148792352, 0.14114016933100565, 0.21300521093819821, 0.11579293731067862, 0.09191608389041253, 0.0953132441001279, 0.13644877821207047, 0.08917053442980562, 0.08056389447301626, 0.10365063457616738, 0.16903424183172838, 0.09496819547244481, 0.15810302911060198, 0.0777673598911081, 0.08021708165428468, 0.0482556191938264, 0.14242471754550934, 0.1049290963315538, 0.13291229440697602, 0.21738436738295214, 0.1496726521956069, 0.08412942636225905, 0.11871876674039022, 0.15556389678801807, 0.09676002325224024, 0.1459609977900982, 0.10887055697717837, 0.09695738194776432, 0.17219991981983185, 0.09137312695384026, 0.15525531263223716, 0.1529889649578503], [0.018074612266251018, 0.06295420083084277, 0.015017225074448755, 0.029541538562625647, 0.07278055498110396, 0.05578589565785868, 0.05533143665109362, 0.07314908770578248, 0.030689582494752746, 0.05844947469553777, 0.03626274344112192, 0.060450121627322266, 0.0808346706575581, 0.026201200571709445, 0.059991893358528614, 0.03881486292396273, 0.006215574577384229, 0.026680950274957076, 0.036672771974865875, 0.03101406472602061, 0.014219709788449109, 0.02504802861117891, 0.03983196995354124, 0.009668368297362966, 0.027074110428137437, 0.09946764260530472, 0.030443274282983372, 0.04865670124334948, 0.023364925890096595, 0.04473827686160803, 0.04963632599849786, 0.0134411018807441, 0.01866715314931103, 0.013641857492205287, 0.05587245297751256, 0.042965088438774855, 0.027441464198221053, 0.010611869544456047, 0.015186312608420849, 0.04811834477420364, 0.036168885084667375, 0.008900835777499845, 0.06464656216225453, 0.04194183048925229, 0.0186965116632304, 0.051696819718927145, 0.021498133561440876, 0.02342926288422729, 0.10872526227363519, 0.0194881143647113, 0.021702119847759604, 0.018519498840240494, 0.043180787935853004, 0.009075345654439713, 0.023442453604989817, 0.03676200611516833, 0.013245671072841754, 0.05182916797431452, 0.026956106403044293, 0.044829451612063816, 0.03579715985272612, 0.03029992018959352, 0.05141720222309232, 0.04372894245066813, 0.005569904402364045, 0.011997166638528662, 0.04320515073569758, 0.01320614555983671, 0.030047308387500898, 0.031064194893198352, 0.047384814492293766, 0.02834302349947393, 0.01929068103033517, 0.048872740007936954, 0.03358011792546936, 0.02890515074666057, 0.03316516662016511, 0.03738801234534808, 0.020715954015031457, 0.022422690110813295, 0.044252286332526376, 0.023489805171266198, 0.05148271477914282, 0.0452415768190154, 0.05265684838273695, 0.0430556830417897, 0.05270652053877711, 0.03971942474267312, 0.020424781067829047, 0.03376225708052516, 0.03516102309471794, 0.017217171311910664, 0.05288472419072475, 0.04117092310584017, 0.05452765424602798, 0.017736742539065223, 0.05335331708192825, 0.02658831497787365, 0.06601047861788954, 0.020661718710990887, 0.07057108889733042, 0.02201469548578773, 0.02759706075968487, 0.023343199198799472, 0.06099921930581331, 0.031036483523036753, 0.03623245024521436, 0.0398474541226668, 0.025418669883427874, 0.0430877641774714, 0.05452292146427291, 0.0751584538125566, 0.03250590878139649, 0.0074592855858749574, 0.014012477560234922, 0.08392880391329527, 0.0576089597972376, 0.02533782582863101, 0.05180600278877786, 0.04907919107271092, 0.04905907929475818, 0.02058056931543563, 0.011348772993577378, 0.045863338812653504, 0.007745812264537173, 0.030810904556087086, 0.046597897075116634, 0.06897196506283113, 0.015382075050313557, 0.028090708556451967, 0.04125338207398142, 0.022494022800986255, 0.03034477135432618, 0.009931996115483344, 0.0059768863138742745, 0.022124767436512878, 0.010241454733269555, 0.04864620430661099, 0.013343387749046087, 0.045346810815057585, 0.08098084745662552, 0.04498400153326137, 0.10257585546267883, 0.0310989121374275, 0.017677392777321593, 0.0751092057409031, 0.031647463595228534, 0.014540742517315915, 0.04668749762432916, 0.0475901765083628, 0.02638162303316806, 0.06542780024132558, 0.00721523435121136, 0.009289459075911768, 0.05534106506300824, 0.027612770541704128, 0.07648661147270884, 0.027837340187813555, 0.03554717058848057, 0.0132256551379604, 0.009251180371003491, 0.011359486213353063, 0.014405898949397462, 0.02247433171474508, 0.06101271536733423, 0.02956110072721328, 0.025722680713183114, 0.060761955965842517, 0.09211361900504146, 0.045086134624268324, 0.009407380828633904, 0.02340226906484791, 0.013358997447150094, 0.015003941055121166, 0.005469457894962813, 0.03986973721267922, 0.0037752467074564523, 0.07419792642550808, 0.017640131026772515, 0.010674436410356845, 0.0809010381677321, 0.04147017740511468, 0.01857212771262441, 0.021500036852168183, 0.043827506447477, 0.0248252061927425, 0.029856833429741006, 0.00934742038537349, 0.01668122873109366, 0.028309252811595798, 0.034720056756798706, 0.008755999933263021, 0.030117407840277468, 0.009832930002760674, 0.03466805722564459, 0.03236948253054704, 0.01801332867970424, 0.03470751403697899, 0.07390872122985975, 0.053784844997738085, 0.027549595538792864, 0.057046121784618924, 0.029867567853736024, 0.017484554821359258, 0.025508211060826267, 0.08868148031511477, 0.024963608676833764, 0.018293639977595637, 0.06048937487815108, 0.05566732166334987, 0.04440964538870113, 0.03537795413285494, 0.03502005744459374, 0.02875903501574482, 0.024945717404729555, 0.022153002974976386, 0.06282481098813669, 0.038198417252195735, 0.04099721135571599, 0.03644445511911597, 0.02650606805192573, 0.028808914124965668, 0.013685220120740789, 0.04649235434564097, 0.07253054875348296, 0.08359963300504855, 0.04263134759717754, 0.04583699129787939, 0.04578564316034317, 0.03732237426031913, 0.004490500224554645, 0.05349428951740265, 0.009460965587225343, 0.02386800023461027, 0.04172853300614016, 0.017250609517629658, 0.050853349800620756, 0.01186984293495438, 0.029535170511475632, 0.034568410965480974, 0.0337248358742467, 0.01424050603860191, 0.045323068874755075, 0.016940663202798793, 0.03397265721910766, 0.04370357881167105, 0.03745004740942802, 0.00614884532322841, 0.012164234682651502, 0.10205533767917327, 0.01873888787148254, 0.02412552632657545, 0.012105016387067735, 0.07828962829496179, 0.015636510415268794, 0.02569214324466884, 0.027246643223666718, 0.06294512203229324, 0.037216790818742344, 0.008090212043108684, 0.015532172085451228, 0.057774651263441355, 0.049178498065365214, 0.01750481078800346, 0.03763732646725007, 0.004131746461748013, 0.06524746598941938, 0.025790328958204815, 0.0053650996331790725, 0.06513561627694539, 0.0245585538047765, 0.02789630657727165, 0.10656326649976627, 0.07398042881063052, 0.03398072500047939, 0.022381367328177606, 0.03197933846552457, 0.034045667587114234, 0.025824301510250995, 0.0348409513410713, 0.05679517578599708, 0.02528422834750797, 0.04888484846534474, 0.029402903680290495, 0.03137183588530336, 0.01620125680762742, 0.0804219992299165, 0.041994152324540276, 0.07857003289141826, 0.052290371619164944, 0.016728373344189355, 0.048509700024234395, 0.04044299413050924, 0.024676617201683775, 0.04096419723438365, 0.048714475107512305, 0.04261488973030022, 0.02833293198740908, 0.028782451259238378, 0.030334165851984705, 0.010788344628443676, 0.08336632552423648, 0.014757207062627588, 0.06539995316416025, 0.045381117545600445, 0.01987434158633862, 0.04220641843442406, 0.03874406458011695, 0.04292882413470319, 0.0504557214943426, 0.009607295904840742, 0.03722781362012029, 0.013588705299688237, 0.014861511465694224, 0.015346094034612179, 0.03566581243649125, 0.03106556214126093, 0.05194137052499822, 0.02843501079561455, 0.041171520216656585, 0.04866634661863957, 0.04777197639590927, 0.015134435213570083, 0.0341691304264324, 0.03221391819949661, 0.005990964219173682, 0.02334488875099591, 0.030112624168395996, 0.0541732113010117, 0.01177041041332164, 0.07158517983875104, 0.051070922054350376, 0.09522816259413958, 0.05474978286240782, 0.0010633324397661323, 0.02455784134300692, 0.012473982525989413, 0.05641301468546901, 0.05313307140022516, 0.031170182063111236, 0.01910173616904233, 0.02547061682811805, 0.028354407620749304, 0.027232322742098143, 0.03540336526930332, 0.03704064652057631, 0.06641348092151539, 0.022336368582078388, 0.0379108201845416, 0.05405630650264876, 0.014111524165075804, 0.04137130128219724, 0.05714376975915261, 0.13689228227095945, 0.1039160435487117, 0.12017531001142093, 0.14525627131972993, 0.08423459250479937, 0.1694600632680314, 0.08443338290921279, 0.22584994669471467, 0.19128667563199997, 0.12071098626724311, 0.1496141624769994, 0.14207985890763147, 0.15781009197235107, 0.18659034477812902, 0.10341510828584433, 0.12005736705447946, 0.07370972047959055, 0.10195555910468102, 0.1183325717491763, 0.09670002718589135, 0.14963322931102344, 0.13034234302384512, 0.12152206631643431, 0.104660505029772, 0.14191273573253835, 0.11816458004925932, 0.1216956762863057, 0.09606425344411816, 0.13706349022686481, 0.11332695784845523, 0.0841352210513183, 0.13275164445596083, 0.1487055905163288, 0.16601976858718054, 0.12477208620735578, 0.12948919380349772, 0.10358407707618815, 0.14228388081703866, 0.14471568247037275, 0.11753701658121177, 0.12488152033516339, 0.13901746752006666, 0.10762566913451467, 0.11729669304830687, 0.118118358243789, 0.08927736976849181, 0.12122260167130403, 0.12347923272422381, 0.12618263837482246, 0.12706527672708035, 0.11596415883728436, 0.12950330733188561, 0.13610329532197543, 0.11926004769546644, 0.16914143679397448, 0.06915086760584797, 0.1514217254838773, 0.10783560786928449, 0.1562938376196793, 0.13338201705898556, 0.17602319323590823, 0.07996204748217549, 0.15576071265552724, 0.07643840834498405, 0.08933354568268571, 0.10781061063919749, 0.12320860581738607, 0.10227884032896586, 0.17789702197270735, 0.1356909903032439, 0.06509036477655172, 0.13363994179027422, 0.19619447870978288, 0.09891646182430641, 0.20760621636041574, 0.0844261022284627, 0.14034089579113893, 0.08935477704341922, 0.09895516546177012, 0.08995045615094048, 0.14975942325379166, 0.11749519168266229, 0.13436566213411943, 0.15591680285121712, 0.09696597220110041, 0.21045827546289989, 0.07104975464088575, 0.12455814411597592, 0.05118828147117581, 0.20318387794707501, 0.12624597283346312, 0.11831338277884892, 0.12362975893276078, 0.1440937372722796, 0.1004577541191663, 0.15137069965047495, 0.0993526852024453, 0.13024048134684563, 0.0863049521243998, 0.1302134892238038, 0.18029249486114296, 0.14280465644385132, 0.12167013622820377, 0.11706571972795896, 0.17622912861406803, 0.11749611449028764, 0.05821893563760178, 0.12156142134751592, 0.11063746895108904, 0.17642378674021789, 0.16213729977607727, 0.16351511941424438, 0.11356119492224284, 0.046700562816113234, 0.255528064178569, 0.1197209358215332, 0.070717089277293, 0.10817334188946656, 0.0946808358920472, 0.15915215281503542, 0.1002022721139448, 0.1469856399510588, 0.14190827097211564, 0.14826716189937933, 0.1442815964775426, 0.09318560933960335, 0.16734185335891588, 0.09362816344946623, 0.13490333328289644, 0.09725583557571683, 0.0872298428522689, 0.14819328300654888, 0.0873306935120906, 0.21005863190761634, 0.11991844379476138, 0.13855048614953244, 0.08403402433863708, 0.0695454492898924, 0.13027872358049664, 0.15723155944475106, 0.143814710101911, 0.18605804762669972, 0.08239570832146065, 0.10569704190960952, 0.20363777716244968, 0.10624461288430861, 0.11946033766227108, 0.13990812615624496, 0.07719115473862205, 0.09040886762418918, 0.09878414749566998, 0.10185626907540218, 0.08876973057964019, 0.2246495775346245, 0.10889029556087085, 0.18410310681377137, 0.08600805912699018, 0.10338240289794547, 0.16634805739990302, 0.12438686830656868, 0.11929545365273952, 0.14363947164799484, 0.11078595955457006, 0.1814048716000148, 0.12354452136371817, 0.12541023482169422, 0.1902701080377613, 0.1785031980169671, 0.12908679539603846, 0.1352575421333313, 0.12877669132181577, 0.12685210816562176, 0.10279969737998076, 0.14996069031102316, 0.14282689882176264], [0.005764567617526544, 0.04494735385690417, 0.02346552040294877, 0.02180062447275434, 0.05504746974578925, 0.0317974367977253, 0.04431780567392707, 0.02772876271046698, 0.03568446536415389, 0.07884349607463394, 0.014350204795066799, 0.0251101349214358, 0.03672615232478295, 0.020433420514953986, 0.01181128027383238, 0.01760972587258688, 0.03928187143589769, 0.07589612315808024, 0.00552359820410077, 0.06703944304691893, 0.07092639018914529, 0.08940603357872792, 0.03019794655431594, 0.02566777535581163, 0.051085381635597775, 0.0014284581765033571, 0.020513019457991635, 0.0697009220187153, 0.064879774648164, 0.013767668062687984, 0.04105011673112001, 0.053220307254897695, 0.01433492757912193, 0.02610355768618839, 0.07559821235814265, 0.019917233481204936, 0.07270846063537256, 0.04833632414894445, 0.01482371027980532, 0.03697561911706414, 0.008488888685990657, 0.033146469587726254, 0.044878048290099413, 0.037975783127227, 0.03279576537066272, 0.028379177541605065, 0.06992164946028165, 0.02597452577070466, 0.03679196343624166, 0.03737989367384996, 0.058265578134783676, 0.04603937793789165, 0.029158759995230606, 0.07221296722335474, 0.029612486184175526, 0.0661023658301149, 0.0340959368539708, 0.037246442799057276, 0.003126035851892084, 0.04031415390116828, 0.06151118754808392, 0.039613983793450255, 0.0317218344259475, 0.06919355424387114, 0.02506016081731234, 0.02586131220284317, 0.026038196104179536, 0.0346743777793433, 0.07321645944778409, 0.1303306179387229, 0.029224547357963662, 0.022443056339398026, 0.038281700640384636, 0.010904638745289828, 0.058353170220341, 0.042421727773866484, 0.039558622121278725, 0.01682542760058173, 0.004520052969123104, 0.028822393223111118, 0.005191046071039247, 0.02525393515160041, 0.07264762318560056, 0.02579458337277174, 0.03638719354889222, 0.00370579313520076, 0.06931997210319553, 0.04113702688898359, 0.06033641951424735, 0.05019139139247792, 0.009598781138525476, 0.027656666668398038, 0.02014253255245941, 0.025152280427781597, 0.011309199134952255, 0.10751740208693913, 0.027448100270703435, 0.016073643030332666, 0.03439872292801738, 0.003560078588114785, 0.009000885765999556, 0.028317371483093927, 0.06946595212710754, 0.037378573923238685, 0.01293298602104187, 0.0566506342563246, 0.05062626448592969, 0.10463888011872768, 0.022157381222184216, 0.029728278185107877, 0.016222986891599636, 0.049183380124824386, 0.0652975147323949, 0.044671105287436924, 0.03626840242317744, 0.07139345298388175, 0.029080243315547705, 0.06434926882918392, 0.018526255352688686, 0.04857326518478138, 0.025161730724253824, 0.0341370017932994, 0.030320415339831795, 0.017674510699829886, 0.012762158892915716, 0.07085716604654278, 0.05201780749484897, 0.011523963950042213, 0.024980124219187667, 0.021637275648702468, 0.05164552586419242, 0.043207067597125254, 0.06127232286546912, 0.09036238119006157, 0.038236727339348624, 0.020207517547532916, 0.01577250410004386, 0.04848140511395676, 0.02339191292412579, 0.05860554453517709, 0.02663829586734729, 0.027088244312575886, 0.07515736815652677, 0.04430454370698758, 0.025397017830982804, 0.03086244946877871, 0.0874881339924676, 0.04854542150029114, 0.034237363907907686, 0.015132311398961713, 0.062105346737163405, 0.013075928752576666, 0.033036200861845694, 0.054507783348006864, 0.003880049833761794, 0.01867982987979693, 0.03232224292254873, 0.05126784988013761, 0.033380723624889336, 0.022312894663108245, 0.010274147398636808, 0.027038356721667305, 0.08308917789586953, 0.015874515054747462, 0.046602816454001834, 0.07439856923052243, 0.034772751786346943, 0.044385652390441725, 0.06548455291028533, 0.022811531388599957, 0.014644707652873226, 0.060729739123157093, 0.03958024703232305, 0.007005284590247486, 0.03754199568980506, 0.017230872630274723, 0.02604238605791969, 0.04786297472726021, 0.029353557221059288, 0.07646801961319787, 0.024933401994141083, 0.02580785721407405, 0.01075811674153166, 0.03910528948264463, 0.03556643080498491, 0.011784214360107268, 0.028896835300007036, 0.04849743550377233, 0.07548775364245687, 0.04047530596809728, 0.02047353720159403, 0.0366395237589521, 0.03826714606423463, 0.05360326563407268, 0.031693037399756055, 0.029403846843966415, 0.042469639131533246, 0.03760576780353274, 0.04595307846154485, 0.011444664410581546, 0.012196499022788234, 0.055639308345104964, 0.03237023570441774, 0.01248832930078996, 0.032376668216394525, 0.007564142994981791, 0.022143747757322023, 0.026547380656536137, 0.017763687164655755, 0.039528054118688614, 0.07230959061001029, 0.024184908318732466, 0.04534220016960587, 0.04748606548777648, 0.031699900781469684, 0.04642175956230078, 0.03883025209818568, 0.022974615583994558, 0.030880637599953582, 0.009481657512619026, 0.0016913019686139055, 0.04216171994007059, 0.016381302682150687, 0.039913322909602096, 0.09881504798041922, 0.05567242085401501, 0.01047602089654122, 0.03581255241962416, 0.06509010014789444, 0.027847998276618973, 0.061367853810744624, 0.03347804929528918, 0.04980792411203895, 0.04187717628000038, 0.021624144299754074, 0.017681469076446125, 0.05213771141799433, 0.042951188648917844, 0.023239457979798317, 0.0917319091303008, 0.020256404299288988, 0.0029920003767724013, 0.01608713061016585, 0.022014318898852383, 0.05857628610517297, 0.011959365452639759, 0.049482105166784356, 0.03573715700102704, 0.024044193726565157, 0.010419966270481902, 0.020586504800511257, 0.02036227272557361, 0.030446541429098164, 0.07706073352268764, 0.07014805623995406, 0.047346514583166154, 0.009116913557850888, 0.04142102772103889, 0.01757265580818057, 0.02339770082783486, 0.0851741260183709, 0.022873900631176572, 0.04164690863607185, 0.07416157730455909, 0.07748042778777224, 0.011537784860203308, 0.018008395730118667, 0.04551793056141053, 0.03839627806363361, 0.036946333545659266, 0.16370287005390438, 0.017608197472457374, 0.027496491691895893, 0.03021415675591145, 0.03108546357335789, 0.01890898642263242, 0.013935133897965508, 0.031226700637489557, 0.05769564264586993, 0.05701741296797991, 0.006076876506475466, 0.03569117607548833, 0.0524926632642746, 0.025139228806697896, 0.022410951454990675, 0.019662784545549324, 0.052780457107084136, 0.051908556571496386, 0.05374585298289146, 0.0060970803107401085, 0.02984577670161213, 0.012407946649805775, 0.021376702934503555, 0.03991886654070445, 0.012001714519491153, 0.08150787239095994, 0.021238617665533508, 0.021979506659720625, 0.029691253921815326, 0.04209407678406153, 0.058682741464248726, 0.03192612096401198, 0.03064660747934665, 0.007761627219484321, 0.028964950037854056, 0.06600106733718089, 0.035374971971447976, 0.026047673542052507, 0.03537539605583463, 0.04738295869901776, 0.029683240423245088, 0.014669971207955053, 0.009708799654617906, 0.04036968520709446, 0.022415862352188145, 0.04896731082616108, 0.07935876199709517, 0.017521295796281526, 0.06937550340912171, 0.027210784344268695, 0.029226806879575764, 0.003966965504722404, 0.04731813146333609, 0.05867900952164616, 0.03582089161500335, 0.04382300776030336, 0.06350056401320867, 0.059017510286399295, 0.04161095306543367, 0.010634395210737628, 0.03584396180563739, 0.03656781617818134, 0.036630010697990656, 0.06541816504406077, 0.003693369583093694, 0.039171918228800805, 0.09014090057462454, 0.020559773913451602, 0.038360984064638615, 0.04246887917231236, 0.042454650292971303, 0.02359193317326052, 0.009936618635297885, 0.03755635009812457, 0.03354672721720167, 0.05820530386907714, 0.02421802930933024, 0.051304314352039776, 0.06980039525244917, 0.017019722710496614, 0.022916646641013876, 0.025783735294161097, 0.107479010575584, 0.19511225606713975, 0.18719471591923917, 0.13110816478729248, 0.09744424439434494, 0.0931142953091434, 0.0938183975272945, 0.21274359497640813, 0.15510911547711917, 0.12839307476367268, 0.09826884764645781, 0.10209725757262536, 0.19765392611069338, 0.10750286108148949, 0.11520559739853654, 0.13536435711596692, 0.07938162184187345, 0.12348126832927976, 0.10702059231698513, 0.1210827963160617, 0.12711984451328004, 0.11640637367963791, 0.121468204206654, 0.10024163393037659, 0.11215070382292781, 0.09863410304699625, 0.16133196013314383, 0.12373193273586885, 0.165827960308109, 0.08926934948457138, 0.08777893374540977, 0.11124994180032186, 0.14037061562495573, 0.0551765678184373, 0.1436338669487408, 0.07065670644598347, 0.0835366445992674, 0.17689914123288222, 0.13758894774530614, 0.2220836973616055, 0.11923401909215109, 0.12069635705224105, 0.08004503231495619, 0.14638984549258435, 0.16704580853027956, 0.1167458990322692, 0.14358263755483286, 0.12787399547440664, 0.18596833172653401, 0.13041426773582185, 0.25594354474118775, 0.14449946050133022, 0.1513346830116851, 0.11291280042912279, 0.15708154892282827, 0.11535400657781533, 0.08459816513849155, 0.1492028481193951, 0.09734308839376483, 0.16740217512207373, 0.10989977246416466, 0.13240722008049488, 0.08066329306789807, 0.1578370433832918, 0.14019639497356756, 0.05600530674148883, 0.1698417934988226, 0.09858385074351515, 0.1635783045951809, 0.20228134494807037, 0.15355338395706244, 0.1924512181431055, 0.09297874436846801, 0.14309257242296422, 0.15291983581015042, 0.14547188260725566, 0.14935264151011193, 0.10875569456922156, 0.10283915419131517, 0.09532845685524599, 0.11350344480680567, 0.1814888606646231, 0.10774245179657425, 0.08247418768171753, 0.11669842872236456, 0.16413673891552857, 0.1307358526225601, 0.2068953423627785, 0.1967773131494011, 0.09592802396842412, 0.22012072269405636, 0.17367221867399557, 0.07690321161810841, 0.17831624804862908, 0.18875918697033608, 0.2520921528339386, 0.14691055326589517, 0.1267988160252571, 0.12774964714688913, 0.06853487315986838, 0.07527569787842886, 0.13530218973755836, 0.1592603927212102, 0.1580259068203824, 0.054236281130995066, 0.1570718865841627, 0.1866118407675198, 0.2236882426909038, 0.1368656972689288, 0.11149915414197104, 0.11584544235042163, 0.14740897794919355, 0.20755215069012983, 0.1374879138810294, 0.1277159782392638, 0.23704067191907338, 0.09811273709471736, 0.16562490191842827, 0.08967872323202235, 0.12222390222762312, 0.111111208530409, 0.08229584832276617, 0.16654148059231894, 0.17081239713089807, 0.15267742238938808, 0.16882701723703317, 0.08051579991089446, 0.0634928083579455, 0.09833959849285227, 0.17091435380280018, 0.06712659408471414, 0.1556819211691618, 0.07708268413054091, 0.1473018644111497, 0.12931927506412777, 0.10209543909877539, 0.0732095723173448, 0.09483774711510964, 0.1571026649326086, 0.2155681869813374, 0.1507977582514286, 0.08990643958428077, 0.16007354908755847, 0.12534945165472372, 0.11747978893773896, 0.10080077392714364, 0.21758707293442317, 0.08636857835309845, 0.13272603654435702, 0.10422309421535049, 0.2248416572277035, 0.13358806100274834, 0.14571783798081533, 0.09491588042250701, 0.1401450163019555, 0.10372950748673507, 0.10438061611992971, 0.08294951503298112, 0.1331736118133579, 0.07975926050650221, 0.17035068119210856, 0.08417334114866597, 0.21712659192936762, 0.0967029652425221, 0.1507714989462069, 0.14178408549300262, 0.06363907336656537, 0.14187000159706387, 0.11518843046256474, 0.1319010600979839, 0.11054617884968009, 0.12465118483773299, 0.16832017871950353, 0.1123710037874324, 0.11894228974623339, 0.14014840897704872], [0.10098439228854009, 0.0802628556266427, 0.06144647566335542, 0.07453875456537519, 0.00621034434464361, 0.035101763238864284, 0.02672259196905153, 0.09158010049057858, 0.022976817430130074, 0.041976449345903735, 0.08547472381698233, 0.03287970354514463, 0.01991197992382305, 0.029854278745395795, 0.012484456562171025, 0.03176617329674108, 0.022487094958445857, 0.03865221468731761, 0.023152588534035852, 0.05950460343488625, 0.06405856407114438, 0.025205357133277824, 0.04276074422523379, 0.04871014266141823, 0.0072103175168324795, 0.03847031980486853, 0.030891175248793194, 0.06186811053859336, 0.02790599945001304, 0.018106457611013736, 0.014064918987319937, 0.020968129858374596, 0.013586675631813705, 0.04590171675330826, 0.05158533302268811, 0.006122438436640161, 0.1465579186167036, 0.01184405860424574, 0.037392792624554465, 0.014030954068792718, 0.041743314891521416, 0.06362075292106185, 0.017332917511729256, 0.050450405172471485, 0.043422132663960965, 0.029142719427389756, 0.03653956876535501, 0.025712358499211923, 0.044804030297590156, 0.03973589278757572, 0.03743863445041435, 0.09002278119857822, 0.02105022411394332, 0.053112104668148925, 0.04851181026814239, 0.016994018107652664, 0.022119332371013503, 0.0714505584910512, 0.042631042256419144, 0.05125278979539871, 0.0537801223940083, 0.019905150468860353, 0.09292374231985637, 0.03714754292741418, 0.020208058679210286, 0.050796648021787405, 0.026422957690166574, 0.05938901499445949, 0.02670593054166862, 0.012769539657581066, 0.054737901714231284, 0.02949344739317894, 0.024844361236318946, 0.030171778851321766, 0.0482642535519387, 0.026117119904873625, 0.04659388693315642, 0.02958725146683199, 0.03499659031097378, 0.007507399655878544, 0.056319047763411484, 0.020053864988897527, 0.029893213084765842, 0.08574209375573055, 0.023365278728306293, 0.043188703046845536, 0.04354761414495962, 0.036885350210858245, 0.05497341104117887, 0.0033858623896126767, 0.04181464249268174, 0.025120979607371346, 0.016455293533259203, 0.013443198553951723, 0.037995922046580484, 0.04888136079534888, 0.08781881124845572, 0.0216799063075866, 0.007073824684734323, 0.04993710360888924, 0.044873284974268506, 0.02672814577817917, 0.02450121589936316, 0.0408912275784782, 0.05261592593576227, 0.030468468288225786, 0.016157398000359535, 0.0020391128699494793, 0.015271092166325875, 0.05457093799486756, 0.03363142874357956, 0.03992221171834639, 0.03976224708770003, 0.01989220910971718, 0.01589641816514943, 0.05323550304664033, 0.030106900725513697, 0.024592684116214514, 0.00969796599487641, 0.0470890512556902, 0.02962634526193142, 0.07950590231588908, 0.11289958256695952, 0.03004742373845407, 0.0542591579391488, 0.0038508965766855647, 0.034840160847774575, 0.036594336719385216, 0.03779201888080154, 0.030846283371959413, 0.02216478403923767, 0.020171528050143803, 0.05849106889218092, 0.029766676481813192, 0.02058569055848888, 0.018371696949803402, 0.029378544273121015, 0.02485175896435976, 0.035485590142863135, 0.03054218433265175, 0.012459333803105568, 0.024456166263137544, 0.01862626293274973, 0.07430924688066755, 0.03663312856640134, 0.028616922641439096, 0.019623782352677414, 0.025498971110209823, 0.036819406785070896, 0.04256131599790283, 0.023689543828368187, 0.03717872500419617, 0.014736157210011567, 0.024738050065934658, 0.036102134202207835, 0.05231828654983214, 0.029872056362884383, 0.02155542396940291, 0.06947931248162474, 0.07720702567270823, 0.03222791976960642, 0.026177575678697655, 0.03174621418916753, 0.030205987194286923, 0.0500804034194776, 0.04572815088821309, 0.020914954765300666, 0.017343355076653615, 0.015456047241709061, 0.05717522664261716, 0.03279021495421018, 0.06090087244021041, 0.011506461139236177, 0.04659626519839678, 0.04532897552209241, 0.0025209130212065895, 0.042038816892142804, 0.023313031531870365, 0.04223509671698723, 0.019909209804609418, 0.023643544243116463, 0.08304884577436106, 0.024485499331993715, 0.03452414673353944, 0.03006634468744908, 0.002060910383339173, 0.027871903065325956, 0.05362011365858572, 0.03911159646564296, 0.031643277034163475, 0.018697266533438648, 0.031219928858003447, 0.019666820132572736, 0.08144886698573828, 0.058486814477613995, 0.03694417580429997, 0.0678541057610086, 0.029457695383046354, 0.02246308669314853, 0.04010601667687297, 0.05151687562465668, 0.0734869913597192, 0.04901517129370144, 0.05271115832562957, 0.009918888515260602, 0.03199228152100529, 0.040585428808948824, 0.017439508577808738, 0.007881783048755356, 0.0026970212721997605, 0.03376367861138923, 0.035390123658414395, 0.02681620266022427, 0.0077856575371697545, 0.021775469483275498, 0.024512311643255607, 0.00763634336180985, 0.06624893617949315, 0.05734427685716322, 0.03760410539273705, 0.03000656235963106, 0.05421606757278953, 0.04392049967178276, 0.011067753474760269, 0.06694125224437032, 0.07458316468234573, 0.05811406805046967, 0.04315350743542824, 0.024793735738577585, 0.0500084617441254, 0.02778727448146258, 0.03100365599883454, 0.044875598778682094, 0.05148656885804875, 0.013695256501835371, 0.03586626525170036, 0.012750957127926605, 0.07934055011719465, 0.10985943355730601, 0.058076891116797924, 0.025675505566011583, 0.014578698069921561, 0.06603054289839097, 0.039637834299355745, 0.009597659011238387, 0.031670876446047, 0.03071795543655753, 0.01451674782271896, 0.04436003090813756, 0.03149334454376783, 0.08428219852170774, 0.06206472284559693, 0.087809834230159, 0.04983693487676127, 0.04171698094744768, 0.011048772305782353, 0.053047898292009316, 0.04026981842304979, 0.006715638346837035, 0.08402683865278959, 0.03629369142332247, 0.06522590214652674, 0.052847387801323614, 0.011786002299881406, 0.01832557692458587, 0.029924089820789437, 0.013297848719438272, 0.01964492041484586, 0.024159220679263984, 0.03440397818173681, 0.028693346040589467, 0.022149976708793213, 0.015382414317822881, 0.03021841456315347, 0.026306707678096633, 0.026821259442450743, 0.048324331042489836, 0.08664514244134937, 0.026029546479029313, 0.03472431117136564, 0.03973246957840664, 0.017715697775461843, 0.0905904368098293, 0.02880284802189895, 0.030304283169763427, 0.03032924308042441, 0.03505199608792152, 0.0945198873856238, 0.0630303935280868, 0.0748930312693119, 0.05366787234587329, 0.031710418074258735, 0.04690583322995475, 0.05987644741045577, 0.032955519655453305, 0.03248180043218391, 0.009287945094651409, 0.030765018625450984, 0.023280276950182657, 0.028216312173753977, 0.03274360977645431, 0.006330970907583833, 0.022013394394889474, 0.04059098940342665, 0.03887916768768004, 0.041984347493520806, 0.04165399593434163, 0.029654148234320537, 0.010924485894585294, 0.05642114692766752, 0.0214695570591305, 0.004537059601196753, 0.04739788307675293, 0.07686726283282042, 0.02993341289194567, 0.012342547748370894, 0.03295072241287146, 0.025540546647139957, 0.013382305125040668, 0.01504768111876079, 0.03672318034140127, 0.022557053615206053, 0.02373259178628879, 0.023062848885144507, 0.06881685195756809, 0.04755148644159947, 0.032527526907090626, 0.028256138786673546, 0.019507963210344315, 0.051271860022097826, 0.010306452450874661, 0.03567237387012158, 0.07504341498549495, 0.050622963413063965, 0.02110373677818903, 0.03597997075745037, 0.026260109285690954, 0.03727108719093459, 0.024934991462422267, 0.058242921850511005, 0.038257493903594356, 0.012360973366802292, 0.018718323171404854, 0.022860122977622917, 0.039196504945201535, 0.022337544143998196, 0.01682159218138882, 0.019803432980552316, 0.042180003066148074, 0.10830810572952032, 0.05642763711512089, 0.021077933787767376, 0.21192140052361147, 0.0928319568878838, 0.16086602370653832, 0.14197985641658306, 0.12120633040155683, 0.22400001596127236, 0.0655852271510022, 0.1284310184419155, 0.08234097768685647, 0.1243134643882513, 0.15290105396083423, 0.13857738327767166, 0.0983762868813106, 0.2616527926708971, 0.12666510391448224, 0.07810212192790848, 0.10214642422007662, 0.13702169246971607, 0.11725332108991486, 0.08957605409835066, 0.13527879385011538, 0.09455970382051808, 0.11579163452344281, 0.21866820992103644, 0.10920914595148393, 0.11177141631820373, 0.11024537749056305, 0.11779428991888251, 0.10211202927998134, 0.11107657610305718, 0.09449332273964371, 0.05876459992889847, 0.11925229882555348, 0.22714946339172976, 0.07432464284024068, 0.09952681764428105, 0.2521325120968478, 0.1904267274907657, 0.2212589109050376, 0.06998016632028989, 0.06558508465864829, 0.19159099858786377, 0.07183346937277488, 0.15721006345536026, 0.10412106968994651, 0.11299566312560014, 0.07879755925387144, 0.1281811139945473, 0.12879813302840504, 0.11968277501208441, 0.1907038411923817, 0.12764170579612255, 0.1283922062388488, 0.16626556111233576, 0.15615832060575485, 0.06524673995694943, 0.20750681098018373, 0.13437596229570253, 0.15764348448387214, 0.10922068783215114, 0.198962521606258, 0.13382518185036524, 0.19176341433610233, 0.10267684182950429, 0.07731145221207823, 0.1457198193030698, 0.08724844828248024, 0.13275308295020036, 0.06675082139138665, 0.032130516067679436, 0.18798815405794553, 0.0944828325882554, 0.1075849366773452, 0.1493553285087858, 0.2409641785281045, 0.26467430910893847, 0.2307920700737408, 0.12463222656931196, 0.11112723552754947, 0.11921400230910097, 0.12892928027680942, 0.10150294910584177, 0.1134889784402081, 0.16851470113864966, 0.1084984822997025, 0.16956225064183983, 0.11821917497685977, 0.11935823171266488, 0.09458107088825532, 0.1271771942930562, 0.09122356426502977, 0.08824269885995559, 0.06551475450396538, 0.09897700750402041, 0.13427690975368023, 0.191044967887657, 0.1687570602766105, 0.20782842300832272, 0.11156757761325155, 0.122151271839227, 0.14173717158181326, 0.1549428743975503, 0.09499318591718163, 0.15017778080488953, 0.12343511437731129, 0.09315854257770947, 0.14500578333224567, 0.0934786211167063, 0.12379572859832219, 0.11760686497603144, 0.09318617252366883, 0.13869312778115273, 0.11592457310429641, 0.1289625284927232, 0.1393370439431497, 0.11665224762899534, 0.16497931656028542, 0.1449941803834268, 0.09513183097754206, 0.11151966625558478, 0.1327606961131096, 0.11833844786243779, 0.18747087967182907, 0.13465718791953155, 0.16445730599973882, 0.09094885257737977, 0.12746829938675674, 0.13705191441944667, 0.10632465287510838, 0.15509259993476526, 0.11982684156724385, 0.08663778033639703, 0.10391329548188619, 0.12481129196073328, 0.09822373863841806, 0.13314702681132726, 0.1580328278775726, 0.2092421100075756, 0.20748406648635864, 0.09431672043034009, 0.12573965000254766, 0.04428699000605515, 0.07625869155994483, 0.13404862343200616, 0.1361239363572427, 0.10105555025594574, 0.12939252970474108, 0.05983679382396596, 0.09699104407003947, 0.17928755735712393, 0.11136394246880497, 0.10709204883979899, 0.18605521135032177, 0.15665359688656671, 0.10500756890646049, 0.16957002665315354, 0.10503827940140452, 0.09696711213993174, 0.1220422312617302, 0.23429716484887259, 0.14764999358781747, 0.11308928738747324, 0.09489175850259406, 0.10970640355455023, 0.09962250465261084, 0.059233433700033596, 0.1270340234041214, 0.0867922759747931, 0.06697754029716764, 0.10980436365519251, 0.147198794941817, 0.19510525358574732, 0.07703883719763585, 0.22635842726698943, 0.12292230475161757, 0.07472372999680893], [0.00617092485273523, 0.028576733012284552, 0.03726006778223174, 0.029280512926301787, 0.03508696439010756, 0.04693041316100529, 0.022185976384207606, 0.015029530307011945, 0.005288038411111171, 0.025458096160686443, 0.006139360251836479, 0.020660375211653963, 0.050987815085266314, 0.039109472651034594, 0.03835355410618441, 0.02827749228371041, 0.03410862885149462, 0.005655194557870605, 0.021574913191476038, 0.006654175372594702, 0.004971638804168573, 0.028401421615853906, 0.03898235929331609, 0.0030401566431724598, 0.016623498971707056, 0.035869118491453786, 0.07887447798358542, 0.027071343701598898, 0.02718338170754058, 0.022892134563465203, 0.042410090898296664, 0.026095189653070908, 0.0555780434182712, 0.04910928749346307, 0.015397939199049557, 0.0625887011576976, 0.0511411436434303, 0.014012315559999218, 0.04486087117610233, 0.039853964666170735, 0.01562123150298638, 0.043050078342535665, 0.038004586938768625, 0.012809433275833726, 0.03872265001492841, 0.02159520478120872, 0.03061122527079923, 0.011796580660822136, 0.0016198936853990225, 0.025783414686364785, 0.03279043887076633, 0.046116191494677744, 0.031157873437872956, 0.022902059834450483, 0.037216156388499906, 0.02131439815275371, 0.051091349351086786, 0.02975429661039795, 0.05287583198930536, 0.031470342206635644, 0.04241011803969741, 0.05429147995476212, 0.07177942405853953, 0.03159227155681167, 0.06017000201557364, 0.04287342853578074, 0.04450181080028415, 0.015101020756576742, 0.01676830682637436, 0.02781808845299695, 0.10302409569599799, 0.047730154890034876, 0.042907114406781535, 0.03177057020366192, 0.05966895140175309, 0.030152189545333385, 0.03105457326663392, 0.021772952118356313, 0.035962128679135015, 0.03503424221915858, 0.02850692193689091, 0.06504170703036444, 0.03287718618022544, 0.028687754912035804, 0.03905049099453858, 0.04655692034534045, 0.08417782626513924, 0.05290190130472183, 0.01480127451941371, 0.006526303327908474, 0.009657006228475698, 0.04535507197890963, 0.06744334101676941, 0.05325733491086534, 0.029745017644017935, 0.01336227307495262, 0.03469514434358903, 0.08132783669446196, 0.0309978545244251, 0.04835730445172105, 0.02648880103203867, 0.009853295383176633, 0.029434506448784044, 0.011765997391194105, 0.024928465651880418, 0.01584645084637616, 0.028780676890164614, 0.03309540643489786, 0.0045485662828598705, 0.050282603462359736, 0.01202191026615245, 0.02663514407218567, 0.00989754858892411, 0.03161820177254932, 0.014869584336078592, 0.010040856033031429, 0.016091230658016036, 0.0355403309554926, 0.05439405748620629, 0.060150120939527235, 0.05100019834935665, 0.04281556985474058, 0.03658528166956135, 0.02199818842512156, 0.03553763377879347, 0.06282530631870031, 0.053278508596122265, 0.06488769993718181, 0.028214541197355305, 0.016857020191050003, 0.03244030123044338, 0.05571882247126528, 0.03209505243492978, 0.032107126965586624, 0.05452818689601762, 0.01542189487788294, 0.01091518487581717, 0.014254726436255234, 0.06847212224134377, 0.04366591672546097, 0.0047559672966599464, 0.04899668460711837, 0.00827356577584786, 0.0426372881712658, 0.01540267706981727, 0.04419278898941619, 0.17496820698891366, 0.029579377067940574, 0.03483561805582472, 0.048777684037174494, 0.052674493685896905, 0.03479044119428311, 0.0030747169761785437, 0.013634676047201668, 0.03582550904580525, 0.0214231181224542, 0.018937072683391825, 0.037097918268825324, 0.06318208681685583, 0.046251223356063874, 0.05653702035280211, 0.017955417412200143, 0.009454911358521452, 0.0013693662580668128, 0.049951583546187193, 0.04706092258649213, 0.05120850181473153, 0.029907788016966412, 0.03927998850122094, 0.03010814244459782, 0.05608379288709589, 0.014412881074739354, 0.06554745310651404, 0.035473580073033056, 0.021291623124852777, 0.01941219817048737, 0.047465404096458635, 0.027095353663233773, 0.04486778544794236, 0.0056045236830998746, 0.04142234068629997, 0.07690184097737074, 0.00685268036821591, 0.026076117730034248, 0.023568359170375124, 0.029565918325845684, 0.032881233641611676, 0.014819764598671879, 0.058590657476867945, 0.04347773860873921, 0.018620809207537344, 0.05387028951996139, 0.023818879388272762, 0.011787930187503142, 0.00682019253560741, 0.00975079757959715, 0.03934803877824119, 0.018285646835075955, 0.0017912609910126776, 0.026724749710410833, 0.02775422134436667, 0.01967375645680087, 0.020107357297092676, 0.07534022655870233, 0.03963646026594298, 0.051212199830583165, 0.08659707502062831, 0.057585591051195345, 0.03629649377294949, 0.03563642169215849, 0.044168266733842235, 0.026213817930381213, 0.07162556624306099, 0.01672391706545438, 0.015826339068423425, 0.025014866908480014, 0.008734313105898244, 0.07169010849403483, 0.02677153130727155, 0.04958549015490072, 0.005450795637443662, 0.04601883189752698, 0.06768238211848907, 0.020279167452827096, 0.006794667320459017, 0.02801991021260619, 0.019881423795595765, 0.04514303996360727, 0.01668872993572482, 0.03220023554084556, 0.031210425975067273, 0.0334279326988118, 0.01136505528951862, 0.009154375476230468, 0.02492195171570139, 0.035421241274369616, 0.04190294025465846, 0.014170259004458785, 0.015406726227541055, 0.050990159423755746, 0.03509597533515521, 0.059212161627198966, 0.028184896002390554, 0.060001230000385215, 0.04817075142636895, 0.01871379734283047, 0.07878735408719097, 0.06915420599813972, 0.018155016969623308, 0.03317678653235946, 0.027303550259343216, 0.04428795013310654, 0.07089743031454937, 0.04063054460233875, 0.014437583142093249, 0.008112153321105455, 0.01798908462348793, 0.007404877255404634, 0.02385939471423626, 0.014041108345346791, 0.08433986721294266, 0.0347411490178534, 0.0410332008531051, 0.06342584373695509, 0.05172782876927938, 0.04108172289228865, 0.025820861337706447, 0.04751461145601102, 0.03507463540881872, 0.061453797056206634, 0.05046559417886393, 0.04423019662499428, 0.014121986326894589, 0.012636333903563874, 0.04045541810670069, 0.0538963384793273, 0.027876417019537518, 0.02180975246509271, 0.015476092862497483, 0.07029276061803102, 0.03047673963010311, 0.019271375012717078, 0.06799498998693057, 0.020851769584364126, 0.019855834543704987, 0.04177121964416333, 0.02767807275189885, 0.048995368249182186, 0.01191777634500925, 0.019833424228376577, 0.009287518465758433, 0.09734382121158497, 0.039957600712243996, 0.032618331855961254, 0.0682427299075893, 0.00605265492673165, 0.0590580731098141, 0.03593400000993695, 0.006807786795044584, 0.046999830686088116, 0.04701955569908023, 0.06415310435529266, 0.03671193023079208, 0.0622389434969851, 0.021595065681529895, 0.018753162551937357, 0.05697845148720911, 0.012598735430011792, 0.02831233336058046, 0.05385594868234225, 0.006456973588293684, 0.01516939333773085, 0.02205723454244435, 0.03154811589047313, 0.06073950324207544, 0.044166655213172944, 0.025517257628962398, 0.04067461545179997, 0.04118072793685964, 0.01101818903615432, 0.011946595423588795, 0.03624481993860432, 0.03615085980189698, 0.008222683282968189, 0.027448671936456646, 0.06404094251671008, 0.022508027763771157, 0.05559496608163629, 0.006258117026715938, 0.013441586185113659, 0.05456215775172625, 0.03235430370217987, 0.05989106305475746, 0.016523269171427404, 0.01522386952170304, 0.013655125396326184, 0.02956999632130776, 0.024809706756579022, 0.04309992691768067, 0.009890411248696702, 0.04927832752998386, 0.006560769938265106, 0.033276412436472516, 0.028152697819418142, 0.060236627369054725, 0.0586914877806391, 0.03443058014714292, 0.012827803763294858, 0.07925010139920882, 0.029509603311972957, 0.0026544529537204653, 0.07001232209482364, 0.10308876008327518, 0.12121486637209143, 0.16212961875966617, 0.07362634209649903, 0.11789134756794997, 0.17186198223914417, 0.10855548602661916, 0.1262030079960823, 0.07780843161578689, 0.09371230857712881, 0.12431038383926664, 0.12763458117842674, 0.12011555821767875, 0.10014363990298339, 0.13142379213656696, 0.09928196828280177, 0.16210067245577062, 0.14492496981152467, 0.11479027968432222, 0.10429183659808976, 0.10348434599914721, 0.13896637383316243, 0.10353813347007547, 0.10515293146350554, 0.07693308072962932, 0.07924269179680518, 0.2807673955602305, 0.1978743685675519, 0.09918036444910935, 0.15112747198769025, 0.17211503508899892, 0.17308300600520202, 0.1271083772714649, 0.11699638701975346, 0.0983672487948622, 0.12044795895261423, 0.20817353948950768, 0.1172437673168523, 0.1041128458455205, 0.10294839832931757, 0.16944327631167003, 0.21165352846894944, 0.10551372888897147, 0.07965245909456696, 0.14828050189784595, 0.19293232661272797, 0.12306071232472147, 0.1183648971574647, 0.062095392628439834, 0.16016496132527078, 0.07777865071381841, 0.08565264926957232, 0.07717480204467263, 0.09526192649666752, 0.11062205263546535, 0.13304070037390503, 0.11451134750885622, 0.06165965101016419, 0.17054647925708974, 0.09951793562088694, 0.06162516786051648, 0.13355478564543383, 0.17951572154249462, 0.11807448416948318, 0.21479038228946074, 0.1455237633947815, 0.09426193551293441, 0.1752415887479271, 0.10540430154651403, 0.10309364553540945, 0.21646445031676972, 0.16882971780640738, 0.06414762179234199, 0.17315470001527242, 0.11279910510139805, 0.09173798201871769, 0.11859881531979356, 0.1281568631529808, 0.06913722226662294, 0.1117369874513575, 0.08328147472015449, 0.14205643587878772, 0.06348198572439806, 0.13121344628078596, 0.1771528183349541, 0.1147592163511685, 0.10800213393356119, 0.14995632054550306, 0.07954387992088284, 0.09741427350257124, 0.11837962136736938, 0.12297337129712105, 0.1250199686203684, 0.15455180752490247, 0.2777263101722513, 0.12097754196396895, 0.15365008876792022, 0.11060240904667548, 0.12010361600135054, 0.18464992461459978, 0.09444866156471626, 0.09606134931423835, 0.164884443793978, 0.17311089379446848, 0.04570059558110578, 0.21714645943471364, 0.16412704943546227, 0.09462522316191878, 0.08543841540813446, 0.15108756055789335, 0.16349244277392114, 0.1730925462075642, 0.13200189040175506, 0.12151918932795525, 0.11740330447043691, 0.1986002517598016, 0.0901977007410356, 0.1613374426960945, 0.14144928274410112, 0.10419885015913419, 0.12218572784747396, 0.09391163502420698, 0.1052614902811391, 0.1681762207299471, 0.14813791454902717, 0.17707902086632593, 0.1932078796838011, 0.0852676077878901, 0.12874864068414482, 0.06253597898674862, 0.18251096510461398, 0.10415781914655652, 0.12014383955725602, 0.1140044547085251, 0.11384704815489904, 0.0997738926006215, 0.06238709483295679, 0.08538117419396128, 0.19387429606701645, 0.24889988984380448, 0.11591736706239836, 0.11003127933612891, 0.12800541413681849, 0.09777249928031649, 0.07666362768837384, 0.12093054662857737, 0.2458686296428953, 0.07028677593916655, 0.15867812825100763, 0.1255910372627633, 0.11733912862837315, 0.10842291385467563, 0.08838988667620079, 0.059276588527219634, 0.17686533661825315, 0.0842586737126112, 0.1267200516802924, 0.1006677064246365, 0.15436028423053877, 0.09602850143398557, 0.14094571476536139, 0.1224903900708471, 0.08637112964476858, 0.043993842521948476, 0.10963475704193115, 0.15210716798901558, 0.14668940513261727, 0.11134770512580872, 0.16080719472042151, 0.12109061303947653, 0.08799369686416217, 0.12466596333043915, 0.14570063033274241, 0.10238557388739926, 0.07847731108111994, 0.13375909253954887], [0.021062259628836597, 0.047045757328825336, 0.008019914118839162, 0.04749477109206574, 0.06351368009511914, 0.0453362087053912, 0.032629802490451505, 0.027104152566088096, 0.019452552344383936, 0.06695544041161026, 0.01382644531050963, 0.030993321910500526, 0.11683731126998152, 0.07949768525681325, 0.03344216157815286, 0.029419551536973034, 0.040710377639957836, 0.024209447537681887, 0.05085665087348648, 0.04192957275414041, 0.027656880406928912, 0.019648324964301925, 0.030070965510926077, 0.010773630596564283, 0.04072892539469259, 0.04179624401565109, 0.02436776163189539, 0.02849128849006125, 0.007306691541868661, 0.030913003720343113, 0.015583367552608252, 0.014032629202120006, 0.017706418809081827, 0.05445589916780591, 0.037269767440323315, 0.021331566785063063, 0.009664917098624366, 0.07271141904805388, 0.0019498808500689588, 0.022035736856716018, 0.016253997638289417, 0.018483877448098998, 0.029753329697996378, 0.040385481502328596, 0.055048714857548475, 0.019611646753868887, 0.07342770775513989, 0.035494723224214146, 0.01857293177662151, 0.017027744690754583, 0.0726785236703498, 0.050707678510142226, 0.028347961538072144, 0.02623576344922185, 0.03289549984037876, 0.045995754921542745, 0.031142521583076035, 0.009102744050323963, 0.03712339047342539, 0.01821742353162595, 0.08649050431059939, 0.023431152604254227, 0.038533260713198354, 0.0473949857322233, 0.030755495386464254, 0.027869355166330934, 0.061540527402290275, 0.0642954067194036, 0.020009310683235526, 0.02182756400933223, 0.049136350862681866, 0.08545347888554845, 0.03557047148102096, 0.06477302073368005, 0.03181853245145508, 0.05068871684904609, 0.027796270159472312, 0.022194614134995, 0.04078612928943975, 0.050677968854350705, 0.06347978727093764, 0.11316443514078856, 0.06806978490203619, 0.06177673222763198, 0.04373993132529514, 0.02582826924377254, 0.028475200424769094, 0.027137358373563205, 0.010763503461410957, 0.05397004773840308, 0.04893293284944125, 0.05952099005558661, 0.05307422545073288, 0.03909465005355222, 0.015110058843025138, 0.03514644137716719, 0.011153886710027499, 0.14702589064836502, 0.02917816609676395, 0.044443887658417225, 0.05356021258713944, 0.05751389704112496, 0.05821605186377253, 0.08388129289128951, 0.019227112477113093, 0.04577074931668384, 0.02556791535711714, 0.07824671095503227, 0.02439322365847017, 0.008806281074482416, 0.0068083113874308765, 0.07156854216009378, 0.02624534266734762, 0.05252071050927043, 0.0048289225336962515, 0.011075703360672508, 0.018664841041234986, 0.015732443392542855, 0.03184857458940574, 0.05514488362574151, 0.04899120543684278, 0.05847593077591487, 0.03119100969550865, 0.03380912010158811, 0.021342246926256588, 0.07591795841498034, 0.014492541085928679, 0.04033078479447535, 0.024190200891877924, 0.030145485619349138, 0.030091766001922742, 0.0296426199243537, 0.06494118885270186, 0.01655564546984221, 0.07537405831473214, 0.014502503676339984, 0.027986181933166723, 0.016794001251193028, 0.028708870921816145, 0.056011478017483435, 0.06858349019395453, 0.023832185459988456, 0.048116862175187895, 0.023779076524078846, 0.012200677950334336, 0.057295714105878554, 0.03655512757333262, 0.018267769133672118, 0.0192018065135926, 0.030582455386008536, 0.03692693422947611, 0.03133696597069502, 0.04719689761155418, 0.036512298442955525, 0.030243411793240478, 0.023690911076430763, 0.07820768162075963, 0.04248963895120791, 0.04578335989000542, 0.01442941018779363, 0.009634049692457276, 0.054186866818262, 0.1596847620925733, 0.03392363306401031, 0.011235407603505467, 0.01975800675739135, 0.02642808571857001, 0.06376097218266555, 0.01904797923218991, 0.0561524165262069, 0.13012920160378727, 0.02477285043070359, 0.023212282652301446, 0.018362161836453846, 0.022196208692288825, 0.010289277881383896, 0.07607691202844892, 0.015924290687377964, 0.014548242025609528, 0.03857641554038439, 0.01186818815767765, 0.014506802195683122, 0.023996750558061258, 0.08600803877093963, 0.033571076446345875, 0.005760048998386732, 0.04546239247013416, 0.04305244642975075, 0.03935741613219891, 0.03744007633732898, 0.03142616957692163, 0.043805525305547884, 0.05912608267473323, 0.023127229984051416, 0.008069438693512763, 0.048407387121447494, 0.065346566028893, 0.04823962951611195, 0.016570773408082978, 0.019856326481593505, 0.06721618784857647, 0.1054428762623242, 0.026536108493538837, 0.019633504063157097, 0.023738849575498273, 0.023981254514572874, 0.015846333799085448, 0.03231554917458977, 0.02384790711637054, 0.08449756553662674, 0.018942305884723152, 0.08626092877238989, 0.024619398039898703, 0.08289565292320081, 0.030013463060770715, 0.04814549296029976, 0.032655712350138595, 0.03886572251628552, 0.0746691757813096, 0.06614160551024334, 0.038282335070627074, 0.02236865836727832, 0.07352264837494918, 0.018387172637241225, 0.006464018054040415, 0.030882873372840028, 0.02493334940767714, 0.012564898584969342, 0.02389436980177249, 0.048868193823312006, 0.03091068991592952, 0.013698527040625257, 0.013890338712371886, 0.022850640450737307, 0.06791330115603549, 0.015410732976826174, 0.06494465616664716, 0.08243681397289038, 0.04703108061637197, 0.03817131995622601, 0.036067695157336335, 0.011991191289520689, 0.024800785717421343, 0.02944675400587065, 0.04718949140182563, 0.03653237968683243, 0.044605280605277846, 0.032673221946294816, 0.020095696672797203, 0.05247337590636952, 0.05801641329058579, 0.050910146574356725, 0.03721970173397234, 0.019004084801833545, 0.030556521777595793, 0.07309230789542198, 0.06977580514337335, 0.03761321811803749, 0.05791199353656598, 0.05511043779551983, 0.05117335030809045, 0.02937868337279984, 0.034506603210632286, 0.021047169010021856, 0.012058250905413712, 0.06848988628813199, 0.05161375006926911, 0.01331347962176161, 0.023250711483082602, 0.03336803162736552, 0.03918416239321232, 0.09983316941985063, 0.049966670772326846, 0.05255279503762722, 0.005318162821432841, 0.03321099148264953, 0.11520820297300816, 0.04275318534512605, 0.04244969020198498, 0.024855236456330334, 0.07455849314906768, 0.07829867995211057, 0.010620582782264267, 0.04854387104777353, 0.06596148838954312, 0.05519528181425162, 0.033539178515119214, 0.024243883189878294, 0.02159577644696193, 0.022684489277058413, 0.019766457911048616, 0.032665696992938004, 0.019712695885183554, 0.023964822092758756, 0.06051678769290447, 0.02079671325295099, 0.015278184553608298, 0.02039777367774929, 0.023817354380818348, 0.019827777120683874, 0.0070457125548273325, 0.042805307012583525, 0.04896451186920915, 0.055612204263785055, 0.001958286414654659, 0.02697314102468746, 0.04913927534861224, 0.002905214687676302, 0.021611352218315005, 0.013506658541570817, 0.011134508598063673, 0.028806715671505247, 0.06292825365172965, 0.032375151690627844, 0.028729939434145178, 0.022594144035662924, 0.0437114871373134, 0.05358084344438144, 0.0480682112143508, 0.0380159931124321, 0.033262376939611774, 0.030497750466955558, 0.05801145998494966, 0.016239044422815953, 0.04240080514656646, 0.03250309964641929, 0.06011535280517169, 0.0972842729783484, 0.03872800026355045, 0.05948536018175738, 0.005079776506006185, 0.01700919693601983, 0.012370563611122114, 0.07267128370170083, 0.06409245010997568, 0.036778979668659825, 0.021489753653960567, 0.04176157766154834, 0.019325991992705634, 0.035770283080637455, 0.0238831705812897, 0.04606612578832677, 0.027274551368983727, 0.053727396830384216, 0.010354833694041839, 0.023692695623529807, 0.04805062358666744, 0.009822340615625893, 0.023490758512967398, 0.057434976633105955, 0.08218908083758183, 0.04286593072382467, 0.15274055328752312, 0.06782211962022952, 0.1126483753323555, 0.09544804865228278, 0.112326417251357, 0.1692491610135351, 0.1059587596516524, 0.17842665926686355, 0.15032191521355084, 0.11288978452129023, 0.10310201187218938, 0.11677958151059491, 0.18783099177692616, 0.12042395238365446, 0.09135973945792232, 0.11685489889766489, 0.12218091024884156, 0.07539741349007402, 0.11459108894424778, 0.161294125020504, 0.2235262763819524, 0.11186965461820364, 0.17560455070010253, 0.13485629723540374, 0.150723146540778, 0.12867906370333262, 0.08141745081437485, 0.23907842114567757, 0.08856790712369339, 0.16155496745237283, 0.11381603910454682, 0.1091878738786493, 0.08076929380851132, 0.1534846212182726, 0.12063914297946862, 0.1793723606637546, 0.13315333718700068, 0.2229979011629309, 0.10015927334981305, 0.18294157699814864, 0.1109854488500527, 0.09681402785437447, 0.09547790419310331, 0.12199698654668671, 0.11684432732207434, 0.11041526908853225, 0.20022395891802652, 0.099737489196871, 0.06568820841078248, 0.1256221548787185, 0.1811656201524394, 0.1597363171832902, 0.15861592016049794, 0.2142585872539452, 0.11926196116421904, 0.12375654998634543, 0.09399076577808176, 0.03804865100287965, 0.141160959643977, 0.10520222703261034, 0.20820325932332448, 0.17141450196504593, 0.15798055353973592, 0.10617626405188016, 0.18103219302637236, 0.05784130375832319, 0.15663941550467694, 0.11885512513773781, 0.19677719101309776, 0.11935547686048917, 0.08708287216722965, 0.13696602545678616, 0.0733872399266277, 0.1665623794708933, 0.16262273729911872, 0.11466944616820131, 0.10433087950306279, 0.10923056730202266, 0.10439031238534621, 0.18696751525359495, 0.11109834350645542, 0.23633741108434542, 0.1891700399241277, 0.14659498019942216, 0.12296233831771783, 0.12852857820689678, 0.07587447110563517, 0.0946326395496726, 0.09012402540871076, 0.13961489046258585, 0.12431505216019494, 0.1900727900543383, 0.1502828180257763, 0.1511292497494391, 0.0792817889845797, 0.148236804242645, 0.16751612829310553, 0.30750702215092524, 0.0646907619333693, 0.09991148593170301, 0.1511170089777027, 0.13941700250974723, 0.1398124120065144, 0.14238940658313887, 0.1310767757573298, 0.10556206772369997, 0.10464354843965598, 0.15688002402228968, 0.13028896945927823, 0.17128518676119192, 0.0594049741380981, 0.18627626448869705, 0.12803094062422002, 0.10138197309736695, 0.08357536859278168, 0.068550323402243, 0.13647708669304848, 0.17795268898563726, 0.1559198834002018, 0.15967801745448792, 0.1381946759564536, 0.1336176994123629, 0.13748087068753584, 0.13070398861808435, 0.11227343723710094, 0.17726517016334192, 0.12111619380967957, 0.22126713474946363, 0.10472027039421455, 0.10478901956230402, 0.16625326605779783, 0.1026260806247592, 0.1388080037598099, 0.10874854281012501, 0.1349687169172934, 0.13208923142935547, 0.0823108914441296, 0.16626898092882975, 0.06061586059097733, 0.19699654781392642, 0.1681813775960888, 0.11597688815423421, 0.1766381902354104, 0.08308700658380985, 0.11435962707868644, 0.08466796603585992, 0.15471172465809754, 0.09553806310785667, 0.18498419810618671, 0.06780935637652874, 0.1156965581966298, 0.10276089196226426, 0.16611043443637236, 0.1265458445996046, 0.0867545697838068, 0.18369528012616293, 0.24921768850513867, 0.11763439992708818, 0.17143816926649638, 0.17365343682467937, 0.06318003085574933, 0.1355413326195308, 0.2620323380189282, 0.11406906481300082, 0.10240821660097156, 0.1151118917124612, 0.08487178438476153, 0.12412203608879022, 0.15762706393642084, 0.1215669989053692, 0.23756013118794986, 0.0784419390505978, 0.07948524092457124, 0.11155195773712226, 0.10874652077576943, 0.08055297005921602], [0.051620640592383485, 0.06458203348198108, 0.011105448639552509, 0.01412172254640609, 0.041952205289687426, 0.022408432393733944, 0.009386935720353254, 0.052587206941097975, 0.03844126832804509, 0.0246429940951722, 0.012293197048295821, 0.031249224607433592, 0.08283071033656597, 0.012870269029268196, 0.011557570093178322, 0.02495600060293717, 0.08355609141290188, 0.05002006808561938, 0.10696130192705564, 0.041784563035305054, 0.04561255226976105, 0.011398573223102306, 0.043493239741240225, 0.04814543528482318, 0.05627549599323954, 0.032048464220549376, 0.04813394768695746, 0.027897604275494814, 0.05039799852030618, 0.03607266203367284, 0.04826009413227439, 0.00868299210976277, 0.04148057595427547, 0.042539663945457766, 0.009164673941476005, 0.03684031244899545, 0.04037273522200329, 0.013513649148600442, 0.05565135573436107, 0.04503079330814736, 0.015913193247147968, 0.02388180842223976, 0.06556818913668394, 0.024012465429093157, 0.014457498144890581, 0.019624951129247035, 0.061314690592033524, 0.014809786741222655, 0.02978267294487783, 0.019819561757945588, 0.06783250799136502, 0.05793911458126136, 0.018908782862126827, 0.0224237927302186, 0.03774317114480904, 0.034824110101908445, 0.05195153158690248, 0.05020444979891181, 0.046932218064154894, 0.027607435560120002, 0.03843537525140813, 0.03465327873293843, 0.05685080547950097, 0.05932271533778735, 0.07365419595901455, 0.013259906737532998, 0.02907202286379678, 0.012250550274204994, 0.026749738458810107, 0.058046621669616015, 0.0078590563664745, 0.06027313255305801, 0.008400223666935094, 0.06140425042914493, 0.048467685135879686, 0.019657517417467067, 0.06162620601909501, 0.015323088304804904, 0.026301501618166055, 0.0116828887257725, 0.06592378898390702, 0.040068463156265874, 0.023668344698048065, 0.01526285644753703, 0.05701136043561356, 0.011161656784159797, 0.009808082050377769, 0.010559829301200807, 0.062365585272865634, 0.04488606518134475, 0.018675605999305844, 0.02997632683920009, 0.036046741995960474, 0.043201815736080916, 0.018677539824108993, 0.04608825620795999, 0.03410171457965459, 0.026491035108587573, 0.0766610356846026, 0.0674523316057665, 0.04102007798584444, 0.06226899581296103, 0.07388250263673918, 0.047748733178845475, 0.05691402119451335, 0.01154890944183405, 0.026013234497181008, 0.03283443847405059, 0.0404553638238992, 0.04642191901803017, 0.03826739372951644, 0.0535954760520586, 0.03707485825621656, 0.04079799347424081, 0.020683935643838983, 0.02365831595047244, 0.02623477957344481, 0.00401655920515103, 0.0605450893885323, 0.053317850056503496, 0.0462861509461488, 0.0529864569460707, 0.01583608452762876, 0.03399788515110101, 0.03754568013495632, 0.049213819205760956, 0.04462829990578549, 0.04273987588073526, 0.030004730315080712, 0.07320098206400871, 0.032266318066311736, 0.0559893068857491, 0.04474745744041034, 0.04871822740616543, 0.03728186911238091, 0.014243579802236386, 0.025897535794813718, 0.048234601571623764, 0.012496794873316373, 0.02158726592149053, 0.03204901722658958, 0.03237872417750103, 0.03612465477947678, 0.03825823011408959, 0.010875545708196504, 0.023261985342417444, 0.03746929066255689, 0.08044144604355097, 0.03301267605274916, 0.04927317744919232, 0.034187077677675655, 0.033438528023127995, 0.007060848974755832, 0.013424957836312907, 0.02568918143931244, 0.02013902791908809, 0.03223293075071914, 0.023856112301083546, 0.04368470875280244, 0.030508227047643492, 0.039291235219155035, 0.034798139174069674, 0.022473188383238654, 0.06271680856921844, 0.015524769268397774, 0.016384305199608207, 0.02671308399710272, 0.024889936737184013, 0.043769047262945344, 0.043999297943498404, 0.005528852609651429, 0.023184683240417923, 0.06701613536902837, 0.034920214409274716, 0.020404574294973696, 0.06036459228822163, 0.07684976341468946, 0.0221017142092543, 0.017822173490588154, 0.03663749833192144, 0.017524562942396318, 0.028016760113782117, 0.027618775576619164, 0.036662987499896965, 0.004359931851338063, 0.026643425592088273, 0.014934394608384796, 0.02153247082605958, 0.0158230634406209, 0.024226969008200934, 0.033149424607732465, 0.010748065941567932, 0.02633726889533656, 0.009172224339896014, 0.0515450755400317, 0.027166453955162848, 0.03782928402402571, 0.045485113215233595, 0.023233921134046147, 0.04316444881260395, 0.03392110552106585, 0.07351432275027037, 0.015829752099567225, 0.037080225468214066, 0.06221613793500832, 0.009515200891265911, 0.03558859515136906, 0.03498956747353077, 0.02952632580750755, 0.03077737135546548, 0.03680219913699797, 0.02978480693751148, 0.09957821667194366, 0.027995711957503642, 0.03562629794968026, 0.08516268591795649, 0.022538965567946434, 0.02775459793130202, 0.04978545103222132, 0.018932051524253826, 0.017725287171612893, 0.007119022326410881, 0.07630031289798872, 0.07503621572894709, 0.027401255909353495, 0.03939052864110895, 0.032156242722911496, 0.05990938350026097, 0.04786128856773887, 0.05767249781638384, 0.08144242090306111, 0.04213710608226912, 0.03827505778255207, 0.013258145939159607, 0.044024590336318524, 0.03426825760730675, 0.060115386731922626, 0.007914519818898822, 0.016485242372644798, 0.034406312342200956, 0.03920853537108217, 0.06869369106633322, 0.019458798259230595, 0.043215491609381776, 0.04921244517234819, 0.004424033902718553, 0.005055448056996933, 0.044333605361836295, 0.043192876037210226, 0.012872187587033426, 0.05154450896329113, 0.0694107533033405, 0.07901339445795331, 0.014196852488177163, 0.009584343609666186, 0.013308968212056373, 0.02391040019158806, 0.02247047085048897, 0.017100670241883824, 0.03110783826559782, 0.016663083008357456, 0.05189939974141972, 0.04237609290118728, 0.05324634603623833, 0.05633563794461744, 0.016876970816935812, 0.03395003146891083, 0.0714347418397665, 0.04194429696404508, 0.033605033731354136, 0.01778021458137248, 0.024039394787645767, 0.02371217806025275, 0.004276930055181895, 0.021631377483052865, 0.026236633670383265, 0.06140446077500071, 0.0305887487983065, 0.0050249708084655655, 0.013426330173388124, 0.005337452723844243, 0.04267909949911492, 0.018066766705097895, 0.02070720260962844, 0.048308802768588066, 0.05877450654017074, 0.04606318433902093, 0.035000315468226156, 0.02135151910728642, 0.0031086028029676527, 0.011256755163360919, 0.03637664232935224, 0.05269938574305602, 0.017082136057849442, 0.05986958063606705, 0.06070881988853216, 0.03167888655194214, 0.06142868447516646, 0.05015254865533539, 0.015178943718118327, 0.02701278612948954, 0.03793932544067502, 0.05931713777993407, 0.0311611643327134, 0.030724859530372278, 0.03281655568363411, 0.021211706966693913, 0.04250536739294018, 0.05634156494800534, 0.021479655356545533, 0.01650706066616944, 0.009129958393584405, 0.038436562687690766, 0.036170530532087596, 0.04903373261913657, 0.04640830760555608, 0.01889392124888088, 0.023589841589065533, 0.017360248902280415, 0.04045381337138159, 0.008566387563145586, 0.05924423597753048, 0.046510854602924416, 0.009306215498197292, 0.057314896290855746, 0.019549777930868522, 0.017131326454026357, 0.024783751095778177, 0.029498821390526633, 0.03308440398957048, 0.03812675716887627, 0.06371849589049816, 0.02455701692295926, 0.01793107157573104, 0.04263723049578922, 0.013775380461343696, 0.03430225221174104, 0.021040458298687423, 0.0172497342074556, 0.04550335562920996, 0.0617498147434422, 0.012376354907506278, 0.014686451127220477, 0.040944855593677075, 0.034907637762704065, 0.009592896543576248, 0.04729900695383549, 0.03154227031128747, 0.003490683751546645, 0.06818972275193248, 0.025546633106257235, 0.03511412614690406, 0.17826953769794532, 0.14923464427036898, 0.07474736337150846, 0.1440991655524288, 0.10881872368710381, 0.06557960888104779, 0.1347044003861291, 0.13338312985641615, 0.12779415904411248, 0.13615856878459454, 0.07548147719353437, 0.11329134154532637, 0.19932698990617478, 0.0707704017737082, 0.10493528457092387, 0.08235511835664511, 0.18852653088314192, 0.15137011611035892, 0.3535604423710278, 0.13525767784033502, 0.13753883114882878, 0.1520092553858246, 0.16797589005104133, 0.18182401625173433, 0.1592748455171074, 0.10832886211574078, 0.07903536542185716, 0.08063455710985831, 0.1664810502635581, 0.10715258773416281, 0.11097698073301997, 0.12089317291975021, 0.09996063222310372, 0.09888744766690902, 0.14509038307837077, 0.1428048735750573, 0.1147267823772771, 0.1475015301257372, 0.12308425748986856, 0.12184331193566322, 0.08195020258426666, 0.05931343297873225, 0.15780166456741945, 0.16746698878705502, 0.1152453324092286, 0.0806465603943382, 0.18597916114543164, 0.14860049901264055, 0.11753016337752342, 0.09950421564280987, 0.14089259904410156, 0.11352947341012103, 0.19837166688271932, 0.13535077284489358, 0.1653236730822495, 0.20391449731375488, 0.14499396325222083, 0.21781865693628788, 0.21814434017453874, 0.10463785553084952, 0.2539720748152052, 0.13731127764497483, 0.10884205172104494, 0.1159058048256806, 0.12017469932990414, 0.1253320268754448, 0.1321777259664876, 0.11021295030202184, 0.09511923736759595, 0.12931911221572331, 0.12864692828484944, 0.19571932777762413, 0.13634683511086873, 0.20190197601914406, 0.19446145956005367, 0.16573553026786872, 0.17617967698190892, 0.04544243336256061, 0.13930473210556166, 0.09321773118738617, 0.14134990450526985, 0.10553939786872693, 0.07227824907749891, 0.10107663233897515, 0.16039324764694485, 0.1131712883444769, 0.11854732808257852, 0.2035703579229968, 0.14374176758740628, 0.1258536438856806, 0.2382835309420313, 0.07812758734715836, 0.0961760828005416, 0.08477226365357637, 0.15920840336808137, 0.15597698890737124, 0.13380876130291394, 0.11036232300102711, 0.14383807884795324, 0.15688355240438664, 0.1703961973211595, 0.14765101139034542, 0.12633091184709752, 0.12791018853230135, 0.12509403750300407, 0.13100555672177247, 0.1688593290746212, 0.1289921940437385, 0.09607262656624828, 0.15025057404169015, 0.220502357929945, 0.0952152500727347, 0.11711479138050761, 0.15446928409593447, 0.14468098218951905, 0.11281701164054019, 0.10286282827811581, 0.10582169557788543, 0.1328984522925956, 0.1628561940576349, 0.12561258753495558, 0.18435379836176122, 0.07870521742318358, 0.11145876773766109, 0.09753286106778042, 0.10658470820635557, 0.2368513877902712, 0.11296507476695947, 0.1446922187294279, 0.14266704954206944, 0.09590263997337647, 0.10754035692662, 0.14228332441832336, 0.08277669216373137, 0.16190628574362823, 0.10522263736597129, 0.11183095776609012, 0.14512895100883075, 0.10269657362784658, 0.1657230316528252, 0.132310365991933, 0.09617284618850265, 0.08087913505733013, 0.3744671648102147, 0.08303511222558362, 0.11311486815767628, 0.18801795531596455, 0.2974757504250322, 0.09709112119993993, 0.08951047368879829, 0.14404732547700405, 0.14385063174579824, 0.09449566368545805, 0.11004647173519645, 0.21154037596923964, 0.12682823730366571, 0.1275872058634247, 0.045994672658188004, 0.14156638431761945, 0.1286902188190392, 0.11742994375526905, 0.1335672978311777, 0.14722973613866738, 0.11829161537545067, 0.11338761209377221, 0.07778688134359461, 0.09439603438866989, 0.11121638824364968, 0.1498164473367589, 0.17176195260669502, 0.1035179402679205, 0.12029808413769517, 0.18280327799064772, 0.08599673437752894, 0.13778376871986048, 0.17069613694080285], [0.05171886532168303, 0.03871575609913894, 0.013947259318748755, 0.05965170982692923, 0.03933423737596188, 0.057759893126785755, 0.019968942938638583, 0.012944975734821387, 0.02563698004399027, 0.016162271578130976, 0.0333388715849391, 0.053208877332508564, 0.02823346045001277, 0.06558804985667978, 0.02637518203950354, 0.030802731601787463, 0.02530042328206556, 0.04146347687180553, 0.0697802020502942, 0.04991053896290915, 0.03732569229656032, 0.035714965513242145, 0.03153570209230695, 0.009365124212178801, 0.03917140593486173, 0.015591214810098921, 0.017922091164759228, 0.0271199403796345, 0.002484877298619332, 0.01627876077379499, 0.008159632960866605, 0.06121386707361255, 0.05186183265011225, 0.0558252439035901, 0.05471705372578331, 0.007825362861954739, 0.040362750579203875, 0.0038309264429179685, 0.04720456166458981, 0.03989001183903643, 0.05588014077927385, 0.07174956851771899, 0.03544639117483582, 0.08126480079122952, 0.06533640157431364, 0.003229325421021453, 0.05171146589730467, 0.007980282584737455, 0.017655840808791772, 0.04059499615271177, 0.07799485232681036, 0.03718027884938887, 0.008558457185115134, 0.020934467736099447, 0.06647115639810051, 0.020389984095735208, 0.04605845155726586, 0.06402971276215144, 0.04276732601491468, 0.04019814816170505, 0.02617303458308535, 0.01807549436177526, 0.07100016051637274, 0.03899941087833472, 0.016839700584699, 0.06406028076474156, 0.029820270570261136, 0.02384595463185438, 0.03615744837692805, 0.025743347193513597, 0.018677578839872564, 0.03252373728901148, 0.02536501981584089, 0.027946823509410024, 0.020113995065912604, 0.01014269735398037, 0.058008610137871335, 0.019673683514286364, 0.013436793183375682, 0.01353247425452407, 0.028193499826427017, 0.0071691932056897455, 0.024916518346539566, 0.03501828646819506, 0.031445741919534545, 0.038781214372387955, 0.0356455547735095, 0.03285037726163864, 0.04678698782143848, 0.058791972031550746, 0.01842798142960029, 0.04243376498509731, 0.10116096067109279, 0.06066624860146216, 0.0521641301789454, 0.023491107958502004, 0.07662801138524498, 0.010134499802786325, 0.048664789380771775, 0.04778685327619314, 0.0468652432651392, 0.008589231292717159, 0.047506560638014755, 0.03736147823344384, 0.009848258108831942, 0.042489727160760334, 0.03189307970127889, 0.01586132263764739, 0.04620972754699843, 0.019301737758464048, 0.0547617420421115, 0.03442691605804222, 0.03030868007668427, 0.04687782669706004, 0.02224916495781924, 0.062070585388158045, 0.037953533963965516, 0.01825617127386587, 0.04843414854258299, 0.02566532075538167, 0.01956614080284323, 0.007841895367684109, 0.009739479615486093, 0.014250419435224362, 0.04327920265495777, 0.010590877367316611, 0.02657266626400607, 0.02709258354402014, 0.009914317733741232, 0.011703530609208559, 0.03123919925253306, 0.15536389180592128, 0.07513493578881025, 0.04791596152686647, 0.042780954390764236, 0.023270950486351336, 0.02691629675350019, 0.03111003671905824, 0.05428562080487609, 0.011731722042895854, 0.09155707101204566, 0.08832225030554192, 0.03700652299448848, 0.04980023291760257, 0.016527287795075347, 0.02639280698661293, 0.05102344835177064, 0.0145222507417202, 0.007933753742171186, 0.062174156973404546, 0.10841520569686379, 0.011717284514036561, 0.02479647023470274, 0.0030480573352958474, 0.04389237439525979, 0.01810441691694515, 0.028570459956037145, 0.038114268731858046, 0.043672271205910614, 0.01237741851114801, 0.0315937643338527, 0.05146843161700027, 0.032683701919657845, 0.027180435169222097, 0.051149469268109114, 0.02415957860648632, 0.023083936057186553, 0.019026925986898795, 0.10584300836282116, 0.018303901123415147, 0.04051730050040143, 0.03757704880886844, 0.030260191964251653, 0.03345761860587767, 0.01746750662901572, 0.016647571697831154, 0.04503962104873998, 0.051544783769973686, 0.11455353881631579, 0.03039476920717529, 0.017369344664205397, 0.0387990123459271, 0.03351088021216648, 0.08306065906903573, 0.03185638113479529, 0.04758765575076852, 0.008594372043652194, 0.06102366692253521, 0.05589339935353824, 0.06158528357212033, 0.016301154125747935, 0.0857888108917645, 0.02174219921497362, 0.04050133117873754, 0.02979007576193128, 0.020065240628485168, 0.029752030303435664, 0.018855914806148837, 0.021290289803541133, 0.05915363119649036, 0.021130852733871767, 0.009713411148238395, 0.03538245621270367, 0.021874516936285154, 0.03508035206635084, 0.04438555061018892, 0.050686738919466734, 0.01057392162536936, 0.038237100533608875, 0.02334249352238008, 0.049748199459697516, 0.049214246682822704, 0.007905310402358217, 0.10654449822115046, 0.023385217479829277, 0.02140744905253606, 0.03922511537426284, 0.04112426025260772, 0.036758135072886944, 0.021300218467201506, 0.13082613849214145, 0.002911433673164408, 0.026366951409727335, 0.026981604052707553, 0.03853317250364593, 0.027207542643217102, 0.014171521927762245, 0.061851656064391136, 0.012359411888090628, 0.016752154300255433, 0.04466713585757783, 0.015474136985306228, 0.05088101028065596, 0.02305137485797916, 0.040450525869216235, 0.05826335253992251, 0.06088156133357968, 0.008068212241466557, 0.024301009053098302, 0.050320693025631566, 0.012943064810575118, 0.05977232621184417, 0.004925500543322414, 0.02219540802096682, 0.011625945218838751, 0.008014688551026796, 0.03629993733816913, 0.01483951336038964, 0.01300634753092059, 0.052251108190310855, 0.0444115181453526, 0.040682147190506966, 0.03591603918799332, 0.02080407366156578, 0.10422420701278107, 0.02667024977771299, 0.05530125541346414, 0.031888869391488175, 0.02650621224061719, 0.01951354246453515, 0.034360402662839205, 0.05373791412317327, 0.028504560635026013, 0.051011275433536084, 0.04217869010088699, 0.06333173771521874, 0.028055250012714947, 0.03297024725803307, 0.07418837265244552, 0.030705816445073912, 0.015175893703209502, 0.011161098689106959, 0.043272994059537134, 0.06139078150902476, 0.01235027117322066, 0.06330270320177078, 0.006260339228902012, 0.025417529944596545, 0.0244570670183748, 0.018900022975036075, 0.005839315035180854, 0.035308333047266514, 0.048535837193152735, 0.052645628806203604, 0.028359603502654603, 0.04271586252642529, 0.011157594903904413, 0.020056180489648665, 0.049946121339287074, 0.025955462329355732, 0.07304461366896119, 0.03123290923291019, 0.038672730193606446, 0.019128087076491544, 0.042703238382403336, 0.015689702471718192, 0.03453934931063226, 0.010532111993857791, 0.03300046581508858, 0.03242494937564645, 0.022588062665558288, 0.03156613778056843, 0.036454283698861084, 0.021217253990471363, 0.03756018042830484, 0.04222641825409872, 0.08283583327595677, 0.038013957507376156, 0.02720890480226704, 0.016408959769510796, 0.05662977269717625, 0.025146689299227934, 0.008614340481082243, 0.008003061853482254, 0.01434176042675972, 0.012541382257560534, 0.012957505732109504, 0.0173997158916401, 0.0050568148809751225, 0.026664870691352656, 0.011903080972842872, 0.026152844773605466, 0.04842677625960537, 0.02278281409027321, 0.04551752344039934, 0.011035556988125401, 0.06267713462667805, 0.04059132867093597, 0.07300943162824426, 0.012518787889608314, 0.06265077354120356, 0.034605998412839005, 0.02085261944947498, 0.033723763788917234, 0.015606064548982041, 0.033801608718931675, 0.02948691649362445, 0.08778472843446902, 0.028280130088595406, 0.03567420930734702, 0.014557437871449759, 0.04624825815803238, 0.06974612602165767, 0.05005456819864256, 0.05800056949790035, 0.05519491879801665, 0.04489332889871938, 0.0941123863948243, 0.0045666534819507176, 0.029972296341189315, 0.015534085554203816, 0.04030951950699091, 0.16254941480500357, 0.1562678904405662, 0.21924569750470774, 0.14533162941890104, 0.07255498279950448, 0.1537621013287987, 0.09427788787122283, 0.24357254856399127, 0.09603735631597893, 0.15891572407313756, 0.10839693274881158, 0.19220112370593206, 0.1325794594096286, 0.10764729404555899, 0.10987621372831718, 0.16175751015543938, 0.14703078967119965, 0.18070321210793086, 0.13176589592226914, 0.18032705943499291, 0.14074979456407682, 0.10428842356694595, 0.2138864379376173, 0.10938703747732298, 0.08305105779852186, 0.1236318081085171, 0.12982398298169884, 0.10299410444817372, 0.17874510932181562, 0.13882770841675146, 0.10472449088203055, 0.15447796934417315, 0.15621314623526164, 0.10104261737849031, 0.13178011801626, 0.2071005449231182, 0.10042263993195125, 0.19574688987008163, 0.10642732879413025, 0.12931903079152107, 0.11139034426638059, 0.16118033469787665, 0.14382004338715756, 0.1917157947484936, 0.41411529587847845, 0.07700942948992763, 0.10595142468810081, 0.07582860213837453, 0.05872555702392544, 0.09300249987947089, 0.15907452840890202, 0.09888661985418626, 0.049268851788448434, 0.09421221246676785, 0.19514251872897148, 0.11307378286229712, 0.15862123987504415, 0.19523722864687443, 0.09462830371090344, 0.15124428857650074, 0.1794759186783007, 0.23554778631244386, 0.18551201692649297, 0.10287223277347428, 0.1567301492073706, 0.13074053451418877, 0.13881088074828896, 0.1345851682126522, 0.17394579042281422, 0.07645061518996954, 0.10909133870154619, 0.12256942582981926, 0.14295644472752297, 0.09647995792329311, 0.10530123886253152, 0.16265644691884518, 0.11726966021316391, 0.09230157999055726, 0.10816735042525188, 0.14357286665056432, 0.11522542419178144, 0.10588194270219121, 0.14551445389432566, 0.1209447822932686, 0.08043817550476108, 0.11994148684399468, 0.08073865795241934, 0.16973736695945263, 0.08028990203248602, 0.14530858636966773, 0.14180520150278295, 0.08401233835944108, 0.24040862119623593, 0.09068554027804307, 0.14888800787074224, 0.1428831493748086, 0.12556363801871026, 0.20457414191748413, 0.13573206881327288, 0.12616256730897085, 0.10471747482993773, 0.12757736710565432, 0.17980914722595895, 0.09068250722650971, 0.13355988822877407, 0.1577223709651402, 0.07821097251560007, 0.17813110298344068, 0.09750873236251728, 0.12334653841597693, 0.0954863994515368, 0.11634888819285802, 0.12077784910798073, 0.150744140414255, 0.1011243062093854, 0.18722655278231415, 0.12930569079305443, 0.06418990809470415, 0.1351310224937541, 0.08988474681973457, 0.10166182129510812, 0.08034532477280923, 0.11040892478610788, 0.0957930362118142, 0.13297561529491628, 0.0786128348803946, 0.11995117632406098, 0.12876569905451365, 0.12532963843217917, 0.10961363424680062, 0.09820482108209815, 0.27472658827900887, 0.13368225523403712, 0.10661720324839864, 0.1173385993710586, 0.12497761446450438, 0.10061683665428843, 0.10403626638331584, 0.08000748218702418, 0.06761784665286541, 0.13948573810713633, 0.1307405616555895, 0.0744955725967884, 0.07490777583526713, 0.140816277425204, 0.10684361002807106, 0.20228135851877077, 0.08118796348571777, 0.07930426206439734, 0.13256742219839776, 0.11624980850943498, 0.13863944209047727, 0.1302514329020466, 0.09265588383589472, 0.17037589555340155, 0.09713648805128676, 0.11835876320089612, 0.1297383111502443, 0.09286479798278638, 0.0994230153571282, 0.05660886024790151, 0.20631296932697296, 0.09673702091510807, 0.13867748076362268, 0.09783460559057337, 0.16036146506667137, 0.15151718179030077, 0.18061722815036774, 0.30963365946497234, 0.08676962647587061, 0.16911506892314979, 0.17537748574146203, 0.1492019117410694, 0.13079571298190526, 0.09629698417016438, 0.10133344427283321], [0.01808453244822366, 0.04796452767082623, 0.01500912506266364, 0.033949190085487704, 0.01797221793926188, 0.06547279389841215, 0.044346568773367574, 0.03890137274616531, 0.017682549643463323, 0.021409214939922094, 0.05401103464620454, 0.02317984358939741, 0.0075169602142913, 0.04030598773221884, 0.017357278615236282, 0.015108966401645114, 0.02606168868286269, 0.02993798961064645, 0.019435721283246363, 0.028894548636994193, 0.06247933488339186, 0.021463781029784253, 0.09024992758142096, 0.022314404403524737, 0.0595375123832907, 0.045313735625573566, 0.07659968933356659, 0.005755074488531266, 0.04547502679218139, 0.07516725441174847, 0.04865249093355877, 0.06302965392491647, 0.019866752172155038, 0.026888074785737053, 0.01470396581238934, 0.08169417096568005, 0.025346979266032577, 0.03426212365073817, 0.048189149903399606, 0.023590504857046262, 0.030884155804025273, 0.06919566448777914, 0.03323016348960144, 0.021333660065595592, 0.016934468178078532, 0.04467615358797567, 0.0816990699885147, 0.017705641886485473, 0.013890113947646958, 0.04350608101646815, 0.03683299105614424, 0.07167393221919026, 0.0604446322790214, 0.005040731056526835, 0.08974521287849971, 0.07792741951665708, 0.03810690323423062, 0.04814863457743611, 0.014991781707586986, 0.023209217370354703, 0.022855737945064902, 0.016984700125509074, 0.02494701849562781, 0.04565026524609753, 0.020465603430888483, 0.05029243204210486, 0.030994014016219547, 0.04930264622505222, 0.031001505042825426, 0.049564957685236416, 0.0425495875201055, 0.014289911869647247, 0.03665507917425462, 0.04058045853993722, 0.07714505506945507, 0.027574411260762384, 0.02391140103074057, 0.009625506088403719, 0.019019116048834155, 0.032816131599247456, 0.02358802650789065, 0.0207369173544326, 0.009654121606477668, 0.03171392949298024, 0.020063752940456783, 0.050983218010514975, 0.06413793909762587, 0.04280358353363616, 0.024130678103704537, 0.032123483052211146, 0.04679916073967304, 0.065778209295656, 0.03158948277788503, 0.04659098280327661, 0.013543328270316124, 0.03088354512250849, 0.06067971073623214, 0.0458826193852084, 0.011430739175661333, 0.04569610707195742, 0.02967201066868646, 0.06632242830736296, 0.06404311382876975, 0.044576035745974095, 0.037865344767591784, 0.01509721078244703, 0.017263267588402544, 0.033343550083892684, 0.019807996128552725, 0.05814797444535153, 0.03616931934707931, 0.02172615016544504, 0.016897688187392693, 0.03630346232759101, 0.045505035003381114, 0.06899697586361851, 0.06234107658799205, 0.012390432812805687, 0.02667271625250578, 0.06518183808241572, 0.029600035066583326, 0.06877215685588972, 0.07648864707776479, 0.00883061418841992, 0.05697172041982412, 0.03364549816719123, 0.02310837688855827, 0.006508449799314673, 0.008106199176316815, 0.07288679320897375, 0.04627432408077376, 0.02490559054006423, 0.011608851225381451, 0.04770612117967435, 0.019578654684924653, 0.011440107199762548, 0.024256291899031827, 0.03075521718710661, 0.052783676755747626, 0.02355272233087037, 0.030927863637251512, 0.04486884396257145, 0.01935928431339562, 0.012513273944413024, 0.01908786012791097, 0.03611603059938975, 0.0389321002044848, 0.02959546513323273, 0.012934503394977322, 0.0428318275537874, 0.06943285318889789, 0.03768659150227904, 0.01667399554779487, 0.0240306416859052, 0.05236404695148979, 0.02177801398959543, 0.045977325910436254, 0.009417746299212533, 0.045603459900511165, 0.030880491714924574, 0.015120482837249125, 0.02534350347039955, 0.006563113428585763, 0.07517200415687901, 0.047693673454757245, 0.010511175795857395, 0.020454165026811615, 0.022455156315118074, 0.0324268865931247, 0.05201198227171387, 0.03186328522861004, 0.054352999332227876, 0.047852053706135066, 0.022647017180653553, 0.06956975441426039, 0.0610266864033682, 0.021653289075142572, 0.007373767272968377, 0.014238042956484216, 0.0881095499332462, 0.04244093031489423, 0.01862646310058023, 0.07850965006010872, 0.02113663385223065, 0.02023927298640566, 0.01673150817597551, 0.08518954233399459, 0.02727354035180594, 0.0427368937193283, 0.04060126920895917, 0.01975984897996698, 0.03181053252358522, 0.03481448847534401, 0.05149173590221575, 0.023277608611221825, 0.01799613969134433, 0.03217804744573576, 0.023648132836180072, 0.012780059494876435, 0.018753138803211705, 0.08106688569699015, 0.06578836696488516, 0.0992362689492958, 0.03056751743757299, 0.011937421630136669, 0.05442491386617933, 0.06060864097837891, 0.05800718521433217, 0.04484749046553459, 0.06395156588405371, 0.026124850115073577, 0.059529369963066917, 0.012088623829185963, 0.05581430931176458, 0.0420645231913243, 0.0468099731951952, 0.01617856490026627, 0.03346625296398997, 0.06422841495701245, 0.019235529704019427, 0.06905727727072579, 0.06367311546845095, 0.04546590388885566, 0.012126888963393867, 0.03358089824074081, 0.034097205714455674, 0.03184007254562207, 0.026164688602355973, 0.05001613936786141, 0.029551434995872632, 0.06808964562203203, 0.02293622067996434, 0.015524194209969469, 0.019936402095481753, 0.019646336856697286, 0.027890515280887485, 0.013405017388452376, 0.010895188448817601, 0.017693552088790705, 0.010590567785714353, 0.03804910901401724, 0.029517460747488906, 0.04786381950335843, 0.034080181270837784, 0.0037720686190628578, 0.008853780222125351, 0.026125508294041668, 0.03146051023421543, 0.012506315567796784, 0.07162256033292838, 0.04144106146746448, 0.0786978756742818, 0.03214127424040011, 0.061832704581320286, 0.05153066006356052, 0.04965453787839838, 0.020501762562032257, 0.0470270501183612, 0.03049250539126141, 0.047758161422929594, 0.007127063814550638, 0.05033775818135057, 0.021883919735306075, 0.050501383508422544, 0.042767760277326615, 0.026800153610695685, 0.022919433723602976, 0.02795761391254408, 0.026361222877832394, 0.052646656786756854, 0.036980589386075735, 0.03356459304424269, 0.05887254806501525, 0.07236854851778064, 0.02772758884488472, 0.026856626383960247, 0.019869822543114424, 0.008565985531147038, 0.017176233597898057, 0.03249961876177362, 0.06791991687246732, 0.026969239448330233, 0.02506391141962792, 0.02092860858621342, 0.07842987469796624, 0.06984682061842509, 0.01879764730775995, 0.014968976145610213, 0.020038555542539273, 0.038559004331805875, 0.013706241983787289, 0.03631387444745217, 0.014112784543872943, 0.014816933411306568, 0.026787217340565155, 0.06416243421179907, 0.016154156299307942, 0.023594547229419862, 0.02165299730508455, 0.04307633086240717, 0.010701038375762957, 0.013491755368054976, 0.005941168230492622, 0.023405375058895776, 0.04459625608952982, 0.06607945170253515, 0.024866856368524686, 0.05483124438407166, 0.051265424117445946, 0.035011928595070324, 0.014934816996433904, 0.029339270666241646, 0.048839946410485675, 0.031212634606552974, 0.027487304327743392, 0.0416712307238153, 0.0492588773236743, 0.011186495406686195, 0.04503612998606903, 0.0172209168252136, 0.03776670952460595, 0.03630858187430671, 0.027297404428411807, 0.11139193203832422, 0.027615901980815188, 0.0439967907566045, 0.10046242244009461, 0.0649162187640156, 0.03553263297570603, 0.05059450565438185, 0.009547624687132026, 0.04172291134351066, 0.04478821364630546, 0.013870055604326938, 0.046161490492522717, 0.010935739397869577, 0.04243719158694148, 0.05108398385345936, 0.016012988785015683, 0.0262129952066711, 0.01918193052655884, 0.019218819082847664, 0.04688737368477242, 0.04311943479946681, 0.030814514362386296, 0.04482334140422089, 0.05619917776701706, 0.007042539131361991, 0.05854397426758494, 0.07560420382235732, 0.01222502124229712, 0.10261044717792954, 0.10879798087158374, 0.13045031151601247, 0.08611475197332245, 0.14147552847862244, 0.15393782832792827, 0.16466679690139635, 0.13191463079835686, 0.13889733968036516, 0.10156125561999423, 0.13106301506715162, 0.16497869230806828, 0.1691307295113802, 0.18784875582371438, 0.1004826088568994, 0.13686230459383555, 0.11799238143222672, 0.1155232060700655, 0.12665905138211592, 0.08292571880987712, 0.10799635960055248, 0.09293741480048213, 0.09196629548179251, 0.21913083509675094, 0.09297402176473822, 0.2623819464019367, 0.149873213576419, 0.13714183388011797, 0.10700821583824498, 0.060927742426948886, 0.21179470446492943, 0.13643066132707254, 0.1696944156927722, 0.13100065769893782, 0.10837998294404574, 0.1943156695259469, 0.21922494790383748, 0.11020616495183536, 0.11886028200387955, 0.1317631003579923, 0.10920678464961903, 0.13846562856010028, 0.16932821034320764, 0.12888037147266523, 0.06922338264329092, 0.14668940513261727, 0.08440874530268566, 0.1361822903688465, 0.060290265562278886, 0.09131238449897085, 0.07784827519208193, 0.0941318196377584, 0.1642754857561418, 0.14437313085155828, 0.1290334625435727, 0.2186704897986991, 0.1935719951455082, 0.07695117047322647, 0.11511102318763733, 0.16355655076248304, 0.10043281795723097, 0.11329945682414941, 0.06275256057935101, 0.11741097191614763, 0.0817986178611006, 0.1376544806574072, 0.2088671244148697, 0.11802177556923457, 0.1339170147797891, 0.10915448317038161, 0.15073443736348832, 0.2114413912807192, 0.16362548992037773, 0.1679861902126244, 0.200249227562121, 0.10495891116027321, 0.17114844838423388, 0.11695597347404275, 0.22859771496483258, 0.06182070808219058, 0.10219849499740771, 0.12493397109210491, 0.10112567685012307, 0.1366003765059369, 0.16646876877972058, 0.04847442977396505, 0.2769607598228114, 0.13011666227664265, 0.1063930695610387, 0.09659037592687778, 0.13221480111990655, 0.1578813652907099, 0.20594050788453647, 0.14389758636908873, 0.13267752129052365, 0.09203822019376925, 0.10538275805967194, 0.14059986546635628, 0.17984501458704472, 0.13224686868488789, 0.07974055329603807, 0.1101374700665474, 0.19391698949038982, 0.09455663005688361, 0.11726026928850583, 0.16333245778722422, 0.16425985230931214, 0.05108991424952235, 0.1586784810892173, 0.14327390412134783, 0.14853371759610517, 0.12376370174544198, 0.09697830118238926, 0.2670733103794711, 0.1589363379670041, 0.14723330523286546, 0.1676493790000677, 0.19810574900891098, 0.10683956595935992, 0.07426419215542929, 0.16536500943558557, 0.073331362567842, 0.07870223186910152, 0.14453766202288015, 0.12981228503797734, 0.12400821862476212, 0.09209814840661627, 0.09670508905713047, 0.09351541128541742, 0.2389515893799918, 0.13031476736068726, 0.21865599629070076, 0.10137016658804246, 0.1347146462649107, 0.0978235997525709, 0.12301587473068919, 0.06718981319240161, 0.13184502667614392, 0.23582926977957996, 0.13013600052467414, 0.11106377214725528, 0.188348062602537, 0.07217565458267927, 0.08654790837317705, 0.15128258509295328, 0.1393777017614671, 0.14135529207331793, 0.08018128893205098, 0.21083190398556845, 0.07621695487094776, 0.16516191033380373, 0.18034551558750017, 0.10232617493186678, 0.15333124516265734, 0.08623825213206665, 0.09574426311467375, 0.12095144550715174, 0.1420338542333671, 0.1106175132361906, 0.0962949146383575, 0.09694341091173035, 0.14397740922868252, 0.08485471244369235, 0.14816749867584023, 0.11665013059973717, 0.09906831117612974, 0.05657688767782279, 0.14903348577874048, 0.09245112232331719, 0.07869898168636219, 0.07201718951442412, 0.1601998380252293, 0.11037981563380786, 0.12669272028974124, 0.1660670760486807, 0.20196683039622648, 0.19764030112751893], [0.03120247015197362, 0.05204898278628077, 0.022254754390035356, 0.0171250805391797, 0.036958330044788976, 0.030709599277802875, 0.05423878153253879, 0.0251985412490155, 0.06394577119499445, 0.06325628462114505, 0.06425690664244549, 0.03252325552914824, 0.05445492886272924, 0.01000959168387843, 0.02890850949500288, 0.0912346447418843, 0.02022307805184807, 0.07629176335675375, 0.029857997117297988, 0.07210619973817042, 0.025469059590250254, 0.017923658580652306, 0.03404810692050627, 0.010963318453702544, 0.04370118019038013, 0.039102965500205755, 0.010329500589120601, 0.08022989239543676, 0.024080033946250166, 0.05173950296427522, 0.0227848513916667, 0.01695441541128925, 0.020506958443937556, 0.033037252591124604, 0.07581744702266795, 0.04895847969289337, 0.016285081327493702, 0.04621735428060804, 0.0944701779101576, 0.06981811858713627, 0.024184777700741376, 0.0313011291436851, 0.038735358975827694, 0.022004675219899843, 0.006489450394708131, 0.05045741443921413, 0.014772940593372499, 0.007484813769614058, 0.04812414285593799, 0.0404459762919162, 0.05473140134875264, 0.02050295508732753, 0.042354922608605454, 0.02771800962675895, 0.02534350347039955, 0.04979702005428927, 0.01156351575627923, 0.036615717357822826, 0.028814773274851695, 0.017931229335122874, 0.02666267054155469, 0.015874398007456745, 0.01109271847443389, 0.004940068266088409, 0.063463644922844, 0.06628608597176415, 0.014722888457721897, 0.03546043684972184, 0.02317845428894673, 0.05350534285285643, 0.034749186265149286, 0.009622171088787062, 0.05167532033686127, 0.01726923360755401, 0.028401228233373592, 0.011275000970012375, 0.012316747302455562, 0.05481087137013674, 0.01051072372190122, 0.04155261262453028, 0.029497766268572638, 0.00696743548282289, 0.04364304330998233, 0.017363777284377387, 0.012586466668705856, 0.016460299425359284, 0.02738208050972649, 0.043754608037748506, 0.0406601931899786, 0.032138088518487554, 0.04481788598267095, 0.05348052204187427, 0.04380803927779198, 0.045109031788472614, 0.064834292445864, 0.05458466815096991, 0.10549223968493086, 0.06196828266339643, 0.01410979644528457, 0.03021550364792347, 0.06789700953023774, 0.05973923405898469, 0.04801400983706117, 0.023293639001037394, 0.014988468760358436, 0.056811698113701174, 0.0389062989104007, 0.05200034200346895, 0.009454304069679762, 0.026986877966139997, 0.037458376426781924, 0.03248038568667003, 0.039234010968357325, 0.03298741758667997, 0.04244196168812258, 0.07318052423319646, 0.019242170865514448, 0.028196828040693487, 0.019353277582143034, 0.019906490575522184, 0.023582043525363718, 0.09822897014341184, 0.04515699403626578, 0.046568937200520716, 0.035216476369116984, 0.021506372672904814, 0.05020682806415217, 0.03388541118640985, 0.032999353017657995, 0.03303126112690993, 0.037917636068803925, 0.05377693667209574, 0.02239972509310714, 0.03846940378259335, 0.022030288220516274, 0.024405135340722542, 0.03078078438660928, 0.027698496655960168, 0.045985434403909106, 0.03037366337542023, 0.055008565940495045, 0.0138771403580904, 0.07171361294708081, 0.053186204084860425, 0.034741495070712905, 0.062103345058858395, 0.009046853120837892, 0.026861947794843997, 0.006900869925240321, 0.03360775465677891, 0.027756714960560203, 0.02495618550372975, 0.053014304023236036, 0.085888562324856, 0.007545439177192748, 0.06658489922327654, 0.06236024520226887, 0.02249756984279624, 0.02061457579423274, 0.017979680128129463, 0.04160920583776065, 0.028338222864216993, 0.03788779070600867, 0.02395425899885595, 0.016848477435165217, 0.007995257852599025, 0.0323915925941297, 0.07851241169763462, 0.023820653757346526, 0.020176276098936796, 0.0384367967822722, 0.0391848239648555, 0.03359053683068071, 0.04100114007347396, 0.03694048796647361, 0.032481355991746695, 0.043640698971492906, 0.04401339450851083, 0.023549012440655912, 0.0256723588598626, 0.04834773710795811, 0.034082685065056594, 0.020186308239187514, 0.04682664819327848, 0.017156383055927496, 0.021733315495241965, 0.02932009526661464, 0.02242737539511706, 0.026309825546507324, 0.012013626201743526, 0.040623742288776805, 0.05721642728894949, 0.0321139665985746, 0.005310709538337375, 0.0067693554197571105, 0.009563487987699253, 0.017917224372337972, 0.017738379504797713, 0.007648647746204266, 0.015034008638135024, 0.0053340278183376146, 0.044741415086069276, 0.009491208741175277, 0.030905407520809343, 0.012246191534878952, 0.0072095261753669804, 0.06988264048205954, 0.012453009856731763, 0.01515660634530442, 0.011277609088990306, 0.059761021818433485, 0.029757984448224306, 0.04823450657672115, 0.028642751076923947, 0.11191331834665366, 0.0560104941417064, 0.10662774089723825, 0.017245659604668617, 0.046190016104706695, 0.03602824852402721, 0.013201208369407271, 0.027923315663688948, 0.07351709795849663, 0.06547328244362559, 0.052668641321361065, 0.025470058733065213, 0.07984579407743045, 0.009488162118941545, 0.024897973984479904, 0.04872671248657363, 0.02139585797808, 0.012893355335108936, 0.01375606341753155, 0.011600394982711544, 0.025546999515167305, 0.04019229579716921, 0.028552692516573837, 0.02679011977410742, 0.02272791551825191, 0.05346982154463019, 0.017978811603305594, 0.011914259837275105, 0.024645301114235605, 0.06885456493390457, 0.04979350185021758, 0.018461736850440502, 0.0143655413828258, 0.027866715665108392, 0.02458338818645903, 0.01962674924704645, 0.026355721655168703, 0.013295216003565915, 0.042091671377420425, 0.04154409022469606, 0.02408450549202306, 0.06491641553917102, 0.015901227282094102, 0.016632677854171822, 0.02439825499563345, 0.07298400013574532, 0.011207899793849459, 0.02064825318354581, 0.014408767456188798, 0.059865170158445835, 0.014396491061363901, 0.012456148929361786, 0.04956331902316638, 0.036886357835360935, 0.054424259079886336, 0.07629494568599121, 0.02168499701656401, 0.03096224839932152, 0.0272547601988273, 0.05096142685839108, 0.02247508319227823, 0.05127854359203151, 0.014329003968409129, 0.05783301206039531, 0.051085120399615595, 0.03340851302657809, 0.024008903120245253, 0.048342508995639424, 0.033337344881147146, 0.06155531946569681, 0.05456924165732094, 0.03393519530072808, 0.0601811164191791, 0.06012727466544934, 0.05234303611463734, 0.019596145621367862, 0.037605571028377326, 0.09751724797700133, 0.019879941196580018, 0.04576093091496399, 0.008226371968963316, 0.021125125898314372, 0.0470362374825137, 0.05944962852767535, 0.013380573164405567, 0.054250886597271473, 0.032807171544326205, 0.03385444624083383, 0.027644234210518853, 0.047897060933922014, 0.013622777935649668, 0.027132951288617084, 0.020202437016580786, 0.05669600110767143, 0.030422741813319068, 0.06977298922304596, 0.03364735396046724, 0.037775625474750996, 0.024098393407517245, 0.04696400064442839, 0.024696569523907135, 0.022514032798686197, 0.025157079366700988, 0.006009966168286545, 0.027546720246651342, 0.051247595609830957, 0.03150834695303014, 0.07693688731108393, 0.01580686341705067, 0.0308769124427012, 0.02968547958880663, 0.08197931852191687, 0.027537202096677253, 0.04809434499059405, 0.14320872404745646, 0.030778687713401656, 0.009373561795135694, 0.04918354297322886, 0.04858407764030354, 0.03538783360272646, 0.018310443897332464, 0.02487001834171159, 0.03544124448671937, 0.03632779459335974, 0.07594561550234045, 0.039876882186425586, 0.033822226005473306, 0.011257669489298548, 0.035231804475188255, 0.007442922713900251, 0.008997454075142741, 0.004486411626982901, 0.006663744836779577, 0.0437283521252019, 0.04693773116118141, 0.043564387530620606, 0.0087976916693151, 0.04144183499738574, 0.1406805839921747, 0.15076505286352976, 0.06444016538028206, 0.09077005181461573, 0.10538564861885139, 0.15451036260596343, 0.16242102240877493, 0.13103562939379895, 0.10528672499848263, 0.17443711762981756, 0.11695377502058234, 0.10424113646149635, 0.1431332573826824, 0.14338118050779614, 0.09646866031523262, 0.13022958407444613, 0.05895490864557879, 0.14079773984849453, 0.058288587257266045, 0.1313804473195757, 0.12817731419844286, 0.16962257240499767, 0.07179924406643425, 0.13238556124269962, 0.12222592426197869, 0.11300215670572859, 0.14273617868976934, 0.13331134085144314, 0.1158354678856475, 0.0721332732854145, 0.15304331561284407, 0.11139111779630184, 0.12429100487913404, 0.13915016182831355, 0.15114560244338854, 0.21100218913384847, 0.0869539776550872, 0.14861807306962355, 0.2412751918392522, 0.20838531026882784, 0.2629779987037182, 0.11682086358112947, 0.23842637613415718, 0.08753855592970337, 0.07518199897770371, 0.20223791870687688, 0.13455121432031902, 0.08256993575819901, 0.12505871296993323, 0.12349483902965273, 0.1641051463250603, 0.08480838207261902, 0.13485283670680864, 0.141133560399924, 0.09193094380732093, 0.12126745283603668, 0.09651377610862255, 0.07545557072652237, 0.0828862212864416, 0.11597646746252264, 0.20681912930948393, 0.0805481049631323, 0.06523477059922048, 0.10490030609071255, 0.11343269396041121, 0.14079734629818372, 0.07468761157776628, 0.16815087066165038, 0.16740410216152668, 0.1374924329242536, 0.06455778942576476, 0.12007908017507621, 0.16352592169174127, 0.10592557250389031, 0.12432980351150036, 0.1580683152590479, 0.12838471521224293, 0.1445370920534645, 0.12481971936566488, 0.1613998950592109, 0.09781610194061484, 0.09419860105429377, 0.15111384700451577, 0.18862873182765075, 0.09583642174090658, 0.08721830097160169, 0.0682064350694418, 0.18616540543735027, 0.1054692305624485, 0.10994312406650611, 0.17521401308476925, 0.14895077235996723, 0.14808663087231771, 0.1772587647927659, 0.13055369311145373, 0.137200160750321, 0.1757189245628459, 0.10275971131133181, 0.07664322414036308, 0.11668910565120832, 0.12907445962939942, 0.14916246171508515, 0.13614194467663765, 0.10786883572914771, 0.09887567508433547, 0.1872022340872458, 0.10313034749456815, 0.17044700602335588, 0.11398184592170374, 0.07139255053230695, 0.20883749957595552, 0.183517829648086, 0.08746445312031678, 0.10261854210070201, 0.11692868279559271, 0.14315957097070559, 0.11805847074304308, 0.098602001555264, 0.13047119682388647, 0.11305407820535557, 0.14546255953609943, 0.2610088086553982, 0.10430397558957338, 0.13271646920059407, 0.09496311324515513, 0.10918412157999617, 0.14217303533639225, 0.16446798614093236, 0.13870876122798237, 0.12930740070130142, 0.15183455975992338, 0.14820523879357747, 0.0905856192111969, 0.19108698277601174, 0.15133032681686537, 0.14601699049983705, 0.10909403248557023, 0.12275201960333756, 0.1370922601116555, 0.09880238651697125, 0.1763727201947144, 0.11548773225929056, 0.11491426160292965, 0.09526684587555272, 0.08916864131710359, 0.1454290941889797, 0.09039133427930729, 0.21293465686695917, 0.13814534646059784, 0.1428580842912197, 0.06601212067263466, 0.10010860035462038, 0.1748086969767298, 0.1829623265990189, 0.08633426483720541, 0.23574518572006906, 0.08814394487334148, 0.08587482877607856, 0.11222098648015942, 0.11000449755894286, 0.19047893397510052, 0.1443606186658144, 0.2873874817575727, 0.10832637189222233, 0.08492058462330274, 0.07744339334645442, 0.08501089763428483, 0.18226306912090096, 0.11144388067935194, 0.11585107419107642, 0.1702924221754074, 0.10575244429388217, 0.09529394656419754, 0.08276642592889921, 0.12461301045758383, 0.10036425877894674], [0.04099507736308234, 0.05197489354759455, 0.008418181096203625, 0.04022748801591141, 0.03490147666473474, 0.016867817379534245, 0.013257657393946179, 0.01686021948366293, 0.036670675301658254, 0.03967720968648791, 0.020450419513508677, 0.08564860520086118, 0.039198974812669415, 0.0587946047474231, 0.05220421463517206, 0.03963387165484684, 0.05142518858026181, 0.020500042475759983, 0.04192585438223822, 0.018726377382076213, 0.022932692297867367, 0.011871579136433346, 0.046080524301422496, 0.05577831302902528, 0.06067761406302452, 0.04673645392592464, 0.03896008977400405, 0.06449344394994633, 0.03208738838189414, 0.045572030158447366, 0.06664573667304856, 0.0016754590240972383, 0.04998039075040391, 0.05481335480830499, 0.006360614830295422, 0.052839910345418115, 0.023082556934761148, 0.01843661578771259, 0.019789360164265548, 0.05061887184690152, 0.00554726762597316, 0.030112583456294875, 0.005825875800967748, 0.0467231207128082, 0.0177991066926292, 0.02034754173031875, 0.045934564633561034, 0.033688405329095464, 0.055674371642193625, 0.061945619593773565, 0.03316683581631098, 0.029430791469556943, 0.020240406139886806, 0.0564464562838631, 0.05456945539585181, 0.036303862663252015, 0.0007247673202073202, 0.027695280399971774, 0.012153890416292208, 0.03821013555196779, 0.027134250683177794, 0.026562591715316688, 0.033547375218144486, 0.05427474049585206, 0.022619433035807948, 0.01776384492404759, 0.017936364148876498, 0.020729575605530823, 0.04489770205691457, 0.04508159522499357, 0.045063647973750315, 0.011571787946325327, 0.03057860130710261, 0.06885776083384242, 0.053670454171619246, 0.038339766274605475, 0.037230395445866246, 0.016571884509176016, 0.04061574236090694, 0.018490561018032686, 0.07598714184548173, 0.03036585683003068, 0.062025299961013455, 0.014307346826951419, 0.057996695062943866, 0.05441612683768783, 0.04792545762445245, 0.0027267478913667476, 0.041816203123224635, 0.05434871777626021, 0.11889648863247462, 0.039205892477184534, 0.030278356346700872, 0.08067364751228265, 0.05635458942768829, 0.0630752175514187, 0.05552132806873747, 0.008617599145509303, 0.050408576881246905, 0.052658480259456804, 0.0164847148116678, 0.029130902740039995, 0.04869463135089193, 0.038797193872077126, 0.013194273741516684, 0.05778592851545129, 0.015128299560663956, 0.05645808976675783, 0.05688577038901193, 0.02432546515150794, 0.11907920454229627, 0.024346767758418406, 0.006628705288416573, 0.05468120672074812, 0.05102761455678514, 0.013898621080443263, 0.006506555414359484, 0.0263603170335825, 0.05067925467821104, 0.020450431387871504, 0.03864831989631057, 0.04504262695887259, 0.024618744949943254, 0.022415090518604432, 0.05295039280982954, 0.013386632482122098, 0.020219374946983795, 0.034274330495723655, 0.06813270545431546, 0.0322080488715853, 0.04137687884005053, 0.04957076933767114, 0.028695500389273678, 0.017923302349767516, 0.007815998230528618, 0.025582179859546677, 0.05170802911743522, 0.03701839396463973, 0.014609318658975618, 0.09508157867406096, 0.03606232115998864, 0.012125906783954372, 0.0720130300947598, 0.024914791474917104, 0.052379721110420566, 0.019171521799372773, 0.05736149807593652, 0.011871076172350772, 0.006826630560681224, 0.054054929076560905, 0.05297349353453942, 0.04421758944434779, 0.04337904569027679, 0.019692278766472424, 0.02352451393380761, 0.04393808390679104, 0.031955376001341004, 0.02387850565303649, 0.05368921905755997, 0.04404638488111751, 0.04005827156028577, 0.0287270658383412, 0.049148187906082184, 0.013377851390812014, 0.03583941562101245, 0.03146786555381758, 0.07717462562556777, 0.020035661590684737, 0.006542435073892453, 0.04830482655337878, 0.06870213882731539, 0.03596681057076369, 0.038877990429422686, 0.020121051830106547, 0.045426447077521255, 0.019289637782744, 0.09178708759801728, 0.06252486458314316, 0.010633072915620037, 0.03239950431244714, 0.026842802929292833, 0.021197116767455424, 0.013770100610729839, 0.04300852146531854, 0.04291936196386814, 0.031532957418156524, 0.016677503573841283, 0.06174585209893329, 0.022712131097380604, 0.03665685693600348, 0.04833550651424697, 0.005553764598776719, 0.05667658143543771, 0.025266508405495967, 0.008974976754481239, 0.011792785953730345, 0.03187815871621881, 0.0695765736911978, 0.01255690713878721, 0.02855187827455146, 0.05977347972137587, 0.022780008347971097, 0.05138304137757846, 0.05401070894939559, 0.028417039795645645, 0.05905431402581079, 0.021600064788279787, 0.01104722694227738, 0.027020819984110336, 0.021162587816693952, 0.05670450654413019, 0.021568940386974385, 0.08719624858349562, 0.02677756517992488, 0.015041969550241317, 0.059818439451711516, 0.02693795898397054, 0.05532431203339781, 0.06206576778952565, 0.04643208007993443, 0.044200147701693435, 0.055764185929937024, 0.041739294571535926, 0.049177877205823145, 0.016364541170852523, 0.060087112177695544, 0.014099329194453145, 0.05616263865626284, 0.02223352642197694, 0.038479459671569724, 0.05948160109775407, 0.0171663235939507, 0.03430911559345467, 0.018504206357257705, 0.025199497983391796, 0.01529528702875333, 0.02667410046394382, 0.05128973941983921, 0.02036017774870353, 0.06545069401285478, 0.04847416514530778, 0.06306771973946265, 0.03448559915913003, 0.021034310771418468, 0.054235008877835104, 0.04349995045257466, 0.04420698733468141, 0.03572494676336646, 0.03134031793368714, 0.06313855201005936, 0.07558405811765365, 0.04357135947793722, 0.0342578420947705, 0.0014423069702128746, 0.030946618345166956, 0.02552986141693379, 0.056109923270664046, 0.01759589563256928, 0.07287443708628416, 0.02790693243566368, 0.027484076197392175, 0.04255714300753815, 0.05616447748616338, 0.0247934015600809, 0.04845181080911841, 0.038522336299398115, 0.011628354866323727, 0.030413686763495207, 0.046979715515460284, 0.02868458954617381, 0.04143947030284575, 0.01933803768562419, 0.009956951785300459, 0.03072135828967605, 0.02427670223239277, 0.03451234022421496, 0.008517678926831909, 0.040227253921329975, 0.049251379511718235, 0.02398673538118601, 0.013299293999027993, 0.05935257766395807, 0.030238550089831864, 0.057204410433769226, 0.06434382019298417, 0.024212290599410023, 0.057816856141601286, 0.010392482209551548, 0.05832226973559175, 0.04770980901750071, 0.07114491239190102, 0.003920747516011553, 0.021831972790615897, 0.052118128897356134, 0.034179206671459336, 0.062057740720255036, 0.05159150769135781, 0.039526279749614854, 0.059383037100945196, 0.01081085078684347, 0.02043918127726231, 0.012228480922723455, 0.02301092229650489, 0.044525691840265474, 0.015342808228784373, 0.06814469516809497, 0.05818633881530591, 0.0396924292269562, 0.06332699475543839, 0.06810932313757283, 0.07176130038819142, 0.026562437348599945, 0.05744151771068573, 0.025091449763359766, 0.008197165277254368, 0.0444574040759887, 0.024602502517934357, 0.03364550155986633, 0.02901658316009811, 0.08585647440382413, 0.02696743454518063, 0.02491879483152713, 0.015144976255084788, 0.029547764121421745, 0.0431432886980474, 0.033163731518600664, 0.10510776138731412, 0.019785731698253324, 0.024203583298783218, 0.02560125008624579, 0.02232231612184218, 0.01032903155178896, 0.015505741450137325, 0.045988345319139104, 0.043845521552222114, 0.014477006026676722, 0.02297185225013111, 0.020746243818263923, 0.05760533642023802, 0.03208525778193559, 0.05939673672297171, 0.030366291092442613, 0.0833208772486874, 0.011776867522192853, 0.045725267114383836, 0.008662399420115565, 0.029785546540681804, 0.008467296005359717, 0.04124425917065569, 0.011358208871180457, 0.04071025889632957, 0.015229316461565239, 0.17652761616877147, 0.15643238089978695, 0.0866735934146813, 0.09076965147895472, 0.14764524384268693, 0.21434552116053446, 0.08903949574700423, 0.06368076934346131, 0.15715331078640052, 0.10796614443617207, 0.11845861641424042, 0.19663342301334652, 0.06990343758038112, 0.09546151757240295, 0.19802159709589823, 0.11485315273915019, 0.10217125860175916, 0.09778493682720832, 0.10653411663536515, 0.07375813395317111, 0.08060280845633574, 0.17072855734399386, 0.15907186855162891, 0.08396435914827244, 0.1786084659397602, 0.11726358053939683, 0.1511447610599654, 0.17234963178634644, 0.11113533045032195, 0.1396417333079236, 0.1052091820165515, 0.050413923737193854, 0.15673916015241826, 0.14940890563385828, 0.1021454335589494, 0.09924487955868244, 0.13584718906453677, 0.16031178273260593, 0.14440712545599255, 0.14338514315230505, 0.10401468218437263, 0.08718562951045376, 0.15851792613310473, 0.15576466172933578, 0.13489073967295034, 0.07543667352625302, 0.07932993782950298, 0.07904975714960269, 0.10339456903082983, 0.155477695699249, 0.06807906047574111, 0.13854409434965678, 0.13355707909379685, 0.14126120640763215, 0.19225064319159302, 0.10294176904218537, 0.11895089357026986, 0.10523094941994973, 0.14476157857903413, 0.11862027059708323, 0.15103928957666668, 0.13565919415227004, 0.1821418556251696, 0.18644982017576694, 0.1634413626577173, 0.16775533902857984, 0.19314749006714138, 0.07756352797150612, 0.1824368962219783, 0.1384320817887783, 0.16387189312704972, 0.1404314666454281, 0.12349372623222214, 0.16618828954441206, 0.20577090127127512, 0.19431699945458344, 0.11900053519223418, 0.14957700589937822, 0.13722419446068151, 0.09860771482012101, 0.1181711618389402, 0.09441377807940755, 0.22243360430002213, 0.18529214443905012, 0.09638435912451573, 0.12594657604183468, 0.13658464806420462, 0.05035343912563153, 0.15119795820542745, 0.20339259531881126, 0.1707552509116275, 0.09799357277474233, 0.10028769288744245, 0.16506513766944408, 0.11320174778146402, 0.17432525434664317, 0.13174806402197906, 0.12926704143839224, 0.11982735725385801, 0.1509249157139233, 0.07826773875526019, 0.19545947600688252, 0.16547424000288757, 0.12702575884759426, 0.0731128335797361, 0.13329179904290608, 0.12961625627108983, 0.11251355720950024, 0.1432894425732749, 0.09096597201590027, 0.22018929544304097, 0.13088578172028065, 0.12300011914755617, 0.15035259856709413, 0.17214901612273284, 0.08277009001799993, 0.07277688410665308, 0.17470690315323217, 0.2201437521725893, 0.16548487943197998, 0.18161479676408426, 0.12189268214362008, 0.13174164508070263, 0.15438741206058434, 0.177956828049251, 0.10910320627902236, 0.06910635570862464, 0.16549143408026012, 0.14732524672789232, 0.23197684649910244, 0.1616469903716019, 0.17063358958278382, 0.13263645635119506, 0.13723547171269143, 0.1366127665553774, 0.12909294292330742, 0.15889086255005427, 0.12097177441631045, 0.1254188929285322, 0.18311761612338678, 0.14605344140103885, 0.06303101099495377, 0.16686683813376085, 0.15952359645494393, 0.16489502894026892, 0.09146987247679915, 0.08342058796967779, 0.06543796469590493, 0.11018060453768287, 0.13007434883287974, 0.21086007675954274, 0.0992563468004976, 0.16390736693782465, 0.09472398393388305, 0.09763822398547616, 0.1987016113208873, 0.06417335862559931, 0.12919525243341923, 0.12879066914319992, 0.16182053248797143, 0.05964899568685463, 0.11995463685265609, 0.16744789481163025, 0.11437034793198109, 0.11483548368726458, 0.11078923687871013, 0.19058262769665035, 0.1754366268536874, 0.08807213551231793, 0.16421743029994623, 0.17696924747100898, 0.1206310684127467, 0.0610752830814038, 0.09367762865232569, 0.1429169811308384, 0.11505085070218359], [0.006898993775913758, 0.07722231985202857, 0.025464172441778437, 0.054770814055310826, 0.0383585820506726, 0.037496340461075306, 0.01803564908914268, 0.02645662150877927, 0.001746725769148075, 0.07114044763147831, 0.03870005140613232, 0.061439880302974155, 0.021847277147961513, 0.00980581489524671, 0.027972655337569968, 0.01834347328570272, 0.04973822838759848, 0.01977880046303783, 0.027824563373412405, 0.032406859632049284, 0.05358318439019578, 0.043499472085386515, 0.021931186484705125, 0.021055092602702122, 0.057628060558012555, 0.03632820849972112, 0.03935306333005428, 0.03802670378770147, 0.02536226835634027, 0.010076132220482188, 0.024765276283557926, 0.03370687844497817, 0.043710791638919284, 0.13815247107829365, 0.01871735286632819, 0.04258887469768524, 0.024746089009568095, 0.022822381163548146, 0.013434897526167333, 0.02805280898298536, 0.030886761378496885, 0.04787107304270778, 0.03203988414523857, 0.007245570803726358, 0.023707743833905885, 0.03263855559219207, 0.07545885483601264, 0.07738408938582454, 0.07197500499231474, 0.057951925322413445, 0.03269222092681697, 0.07922650195126023, 0.039425072858908346, 0.005998229632885861, 0.014159721355619175, 0.04419957094692758, 0.06403877799000059, 0.020349623136488453, 0.04531950317323208, 0.04038041963108948, 0.041333523845033984, 0.028798060957342386, 0.039973064525319, 0.022968819198597754, 0.02683066902682185, 0.09838345899645771, 0.05463903916201421, 0.041895201562770774, 0.09248487944049494, 0.02829226229472884, 0.08469658664294652, 0.0367255755700171, 0.065279289281794, 0.02473301363975874, 0.059838171250053813, 0.0331542252429894, 0.07027267598147903, 0.05996017863175698, 0.041582390133823664, 0.023822865781507323, 0.016309718934020827, 0.031414722691157033, 0.008392784378624387, 0.02542152481951884, 0.004760289564728737, 0.04292903108788388, 0.08884592327688422, 0.05094492488673755, 0.046307575689362626, 0.040659867493169646, 0.010247719307829226, 0.04103574196674994, 0.022704870772681067, 0.03174204798415303, 0.02056115473221455, 0.01425980357453227, 0.07952623122504779, 0.06447180546820164, 0.04063246485644153, 0.04489364781017814, 0.05570444431422012, 0.036505265427487235, 0.012234999099746346, 0.08535316426839147, 0.016079658243272985, 0.042596511609320126, 0.10598838449056659, 0.02191946139958288, 0.043666493480226824, 0.0753842702667628, 0.05733441774334226, 0.027248202157872062, 0.04038325930014253, 0.03172740859112569, 0.03852818527125886, 0.03661526273936033, 0.06861462138061013, 0.03206214348652533, 0.06041602524263518, 0.02372235099651984, 0.02838946073981268, 0.04271925180884344, 0.04527894374249237, 0.05095892984952245, 0.005499475011934659, 0.002675031012456332, 0.05518663727811404, 0.025568383546280007, 0.06743512395769358, 0.02309469592624477, 0.031066949745374065, 0.08654996433428355, 0.03654987571228828, 0.018372680825580443, 0.03857102797233632, 0.044953833866332255, 0.022395199264532754, 0.03136290975713304, 0.003167441118940977, 0.028216895713870014, 0.05885570004050221, 0.01951395976357162, 0.03364326239430478, 0.014290293545595236, 0.041259594062077146, 0.04465212327029024, 0.05783506802150181, 0.031689129038048644, 0.04188516942252006, 0.05304565912644778, 0.06029027234762907, 0.018551110090421777, 0.024371622496151497, 0.005400458093000842, 0.042921445066375394, 0.007799251138099602, 0.007651460273856563, 0.033924423557307036, 0.01437295098522944, 0.035470475775322745, 0.023241597061444606, 0.04035881507609572, 0.014300585225490587, 0.010086072758505387, 0.1015293916155185, 0.03500413901305624, 0.024673283898404667, 0.03188154460596187, 0.0421219543953027, 0.038709879985877445, 0.03249725067455854, 0.031983772691871436, 0.0723189204665167, 0.030906917261225835, 0.023352074436843395, 0.021312893501349857, 0.019116394221782684, 0.04218263578202043, 0.009152365316237723, 0.03449284591312919, 0.021785873121448925, 0.038499157543161085, 0.05249014589935541, 0.036488373298197985, 0.014226790301368704, 0.004584932367184332, 0.031605299429169724, 0.010981086741334625, 0.035189633523779254, 0.08438988202916724, 0.022128141451893107, 0.018002823261278014, 0.07751980317490441, 0.0287038735114038, 0.01566118873389704, 0.016532515907394033, 0.05169516070080655, 0.040291287271039825, 0.00679389718321285, 0.04206450283527374, 0.043377705583614964, 0.03267624821247799, 0.027306929363736084, 0.04254814902586596, 0.03878557735255786, 0.035170702396758964, 0.019261054495083432, 0.007791464100591838, 0.040716772832508595, 0.10968216628368412, 0.0247486216415252, 0.021670411906338165, 0.05654684553987213, 0.01656647997775248, 0.026287835922890475, 0.022673001679192697, 0.08269217384180852, 0.03842304627011929, 0.037440887186676264, 0.06236876081675291, 0.034667846879788806, 0.05307415081188083, 0.023845991951280406, 0.019366139213421514, 0.038771765772253275, 0.05902369852576937, 0.031001240414168154, 0.08331250412655727, 0.05308880038293345, 0.030550319967525344, 0.030790992945964848, 0.043608013939644606, 0.022857673466205597, 0.056990726185696464, 0.04300575304244246, 0.023118836505870734, 0.050316798234624524, 0.01655275999967541, 0.07370950334838458, 0.021952221070283225, 0.11077636506940637, 0.060619253266070566, 0.021225577918812633, 0.021255823617268885, 0.04105462898899402, 0.03143239513571773, 0.022308618196153214, 0.03188523244378822, 0.003635680959892592, 0.01451257143967918, 0.039648589079401324, 0.04087124132950391, 0.03704027671899114, 0.04360608350751655, 0.03588852120031204, 0.09519601360495601, 0.02021955475876374, 0.06110770348459482, 0.03722524197239961, 0.005551690402041588, 0.04059280787727662, 0.025168212430019463, 0.05751155609531062, 0.06300895860684769, 0.01595071793001677, 0.06044803173946483, 0.07146070258957998, 0.0709814058084573, 0.01623654062859714, 0.05190254135855606, 0.05469469599691885, 0.01905927514391286, 0.028594544556524073, 0.015631034637668302, 0.029423517574157034, 0.0031939001679087854, 0.0524147470880832, 0.017026192541899424, 0.011037869096201445, 0.04120470057906849, 0.04667631197454674, 0.02941206729571734, 0.032631787205381055, 0.04105161290083613, 0.022612428858077953, 0.07485343875097376, 0.048062229928161414, 0.0179723061488143, 0.04980020916887692, 0.05095436670152204, 0.03863304607304079, 0.04667270556092262, 0.012331858277320862, 0.02744229879629399, 0.009231791232845612, 0.017164511905450906, 0.03255215094291738, 0.03800322647605624, 0.018906031402626207, 0.05106868967413902, 0.018251733654843907, 0.03239076478140695, 0.04503015548522983, 0.06650674555982862, 0.026284222723916173, 0.04013088159263134, 0.012082775705493987, 0.03061085207653897, 0.038757116201200655, 0.017865411438313977, 0.048198686713086705, 0.039630183817020485, 0.04126519876133118, 0.016832179024017284, 0.039565431220190864, 0.09177317763013498, 0.018776968953066638, 0.0364155189932457, 0.0151360840536654, 0.02620071541917111, 0.10282445033746106, 0.031425555502729755, 0.033723631474588595, 0.02978355504040207, 0.04821215902588197, 0.035905430292976756, 0.053242827832166634, 0.01876477398244398, 0.03013484619025673, 0.01804027160895722, 0.05496156381975327, 0.04178754519671202, 0.007447449390643409, 0.024579829270286218, 0.018621854151466062, 0.045060021204075644, 0.017317199248022268, 0.03147179427157555, 0.07547473255544901, 0.0031374070385936648, 0.07916701478617531, 0.024066034072477902, 0.03051067316638572, 0.02534111333079636, 0.031963216473481486, 0.00586327792344881, 0.09450736841452972, 0.04725599122632827, 0.0027886890207550353, 0.032941619865596294, 0.05964776753847088, 0.0576933017000556, 0.12501623667776585, 0.11040019204041787, 0.10228882157909018, 0.11086249151932341, 0.08011249226651021, 0.18337598868778773, 0.17422479045178207, 0.11243116948753595, 0.15452670172921248, 0.20915950515440532, 0.17271092454237597, 0.1434448678046465, 0.10252234619110823, 0.13925635255873203, 0.10162224234747035, 0.15105820713298662, 0.23193051612802915, 0.1249535536127431, 0.1235156429133245, 0.13821714903627122, 0.13679407111236028, 0.16140965239277907, 0.12993645694639, 0.1555966293173177, 0.15638344495424203, 0.1257362166153533, 0.1699194721877575, 0.1192937573151929, 0.0731237715642367, 0.081786770639675, 0.08699612146509544, 0.10140497543449913, 0.15043546126357146, 0.19947516838354723, 0.1076174181486879, 0.14011406153440475, 0.09116056907389845, 0.1343034676143101, 0.1202405443681138, 0.12973722549421446, 0.1923327459288495, 0.13640916533768177, 0.08055305826876845, 0.16757579866264546, 0.09645226012383189, 0.14464332349598408, 0.13784820240523132, 0.1578291588063751, 0.18024088548762457, 0.18213467672467232, 0.09772512396531445, 0.11502968040960175, 0.0848250129659261, 0.09365993245903935, 0.11083026110593762, 0.09605536463537387, 0.10581373636211668, 0.13749765764389718, 0.19145432806440763, 0.11256047112068959, 0.09400708454528026, 0.14347770889954908, 0.1643044456307377, 0.15661164985171386, 0.22692446117954596, 0.15366834135992186, 0.15449124148913793, 0.16708231371428284, 0.19682311426315988, 0.09796067061168806, 0.11384212199066367, 0.10171859432011843, 0.11468729163919177, 0.13983944484165736, 0.10875521280935832, 0.0984704607565488, 0.27846721612981384, 0.22597486499164784, 0.15152733267417975, 0.1763325644923108, 0.10943796831582274, 0.127388150830354, 0.15065977137003625, 0.11864255368709564, 0.09300730390740292, 0.14114825746842793, 0.2766255906649998, 0.15088306367397308, 0.12185629909592015, 0.09371369957391705, 0.09677989754293646, 0.18393564437116894, 0.1149418508367879, 0.1175693284187998, 0.07998914138547011, 0.15645314407135757, 0.12918518297374249, 0.1706986610910722, 0.1186110425208296, 0.18282314549599374, 0.2958389882530485, 0.11790106418941702, 0.07594366132148675, 0.11519883918975081, 0.10021635850093194, 0.07283164866800819, 0.1297908704727888, 0.14245116684053624, 0.14165721301521572, 0.15775091014802456, 0.14964948701007025, 0.11805944783346993, 0.1136792396594371, 0.17353872369442666, 0.07888095120766334, 0.11488509816782815, 0.13516830120767864, 0.10891520458140544, 0.19796335164989742, 0.1169242723179715, 0.17078704706260137, 0.11868621063019548, 0.17408092745712825, 0.12695662969989435, 0.10582886769303254, 0.1378462075122765, 0.11176923822079386, 0.10399423792426075, 0.2694527155586651, 0.07665093229817492, 0.1472395206136363, 0.1897422620760543, 0.11492359824478626, 0.06699693961335079, 0.16962022467383317, 0.14130774033921106, 0.11176788793610674, 0.10442553513816424, 0.11149187346122094, 0.17978135443159513, 0.10590120631137065, 0.17345177621713706, 0.06755240873566695, 0.09755234180816583, 0.1648031688694443, 0.10485874582082033, 0.19134652242064476, 0.11740527222199099, 0.1500647368707827, 0.1575405914336443, 0.17640959178762777, 0.09569988013910395, 0.1431694504405771, 0.09851850103586912, 0.1449614478541272, 0.10998858591275555, 0.06546573713421822, 0.11155220879507916, 0.056643706413784196, 0.11184188896524054, 0.11890866155070917, 0.14775085103298935, 0.273114307650498, 0.1091432466304728, 0.21341983654669353, 0.11322608004723277, 0.09649106554154839, 0.1222952026873827, 0.09003023151308298, 0.10921546311250754, 0.13210836611688137, 0.15072587425155298, 0.14256872981786728, 0.11168041798685278, 0.10258423537015915, 0.12728685912277016], [0.020852219113813977, 0.08480557293764182, 0.05876376533082553, 0.05603143373238189, 0.029563248290547302, 0.011917611800267227, 0.020792514817523103, 0.049958789588085244, 0.01061895175371319, 0.011979883503434914, 0.02081703707309706, 0.03260475776291319, 0.004356075652010206, 0.06824209208467177, 0.07037181673305375, 0.01334996784238943, 0.03762060397171548, 0.037521276623010635, 0.05416269061554756, 0.011449995151321803, 0.024273194206346358, 0.013256469957663544, 0.014950491155364683, 0.043530301323958805, 0.01921050193985658, 0.018502818753144572, 0.05245304699721081, 0.030517563689500093, 0.0485871615819633, 0.102310100437275, 0.03333265281149319, 0.02231953582460327, 0.05003969810370888, 0.0465594580663102, 0.029380047228187323, 0.03860743137608681, 0.042395631317049265, 0.049671311264059374, 0.06250397248991899, 0.031001338801745857, 0.0199608768536044, 0.013486656177389835, 0.06596020595835787, 0.056004261797560115, 0.03034768226955618, 0.039522052476448674, 0.03677075243155871, 0.014941824566838997, 0.040897544739501815, 0.07735013549349137, 0.01960426938187863, 0.0325912006332406, 0.028827214214418615, 0.046109365432390144, 0.014097535317497594, 0.03371877994920526, 0.03369691755090441, 0.009534869925118983, 0.08646948329572167, 0.012863956109088446, 0.04358869944033878, 0.033581681948687346, 0.03161731967702508, 0.055690178115453036, 0.04131883356188025, 0.029501908724861484, 0.021264676802924702, 0.04060638536299978, 0.04384987096169165, 0.07568406739405223, 0.024687181991924132, 0.04914694957967315, 0.05242411426401564, 0.009910578157619705, 0.07505034961338554, 0.06370797181235892, 0.03942928316869906, 0.021097916644066572, 0.031726400966623, 0.03616684947961143, 0.05734479932912758, 0.040024762108389816, 0.0041360178396904045, 0.0015734108559887058, 0.02915059043360608, 0.01554527968567397, 0.017090773808636835, 0.003999315933989627, 0.09799395275435277, 0.017326973544965898, 0.013928505459002085, 0.05516308872029185, 0.02420299806232963, 0.052814295648464134, 0.0453580473549664, 0.040703008749655316, 0.06350755292390074, 0.016960150728534375, 0.023528413813827292, 0.08571689975048814, 0.08071317217711892, 0.090632960599448, 0.06304371317050286, 0.039108112188322205, 0.04577304955039706, 0.01022627336039607, 0.03658531220363719, 0.05274166186739292, 0.04669303786275642, 0.007665362608219896, 0.049447364173829556, 0.026130351337737272, 0.09234681113490037, 0.01730402040162257, 0.02628000732511282, 0.04908569483086467, 0.09816467216504471, 0.022900200648499385, 0.013982818794569798, 0.051718220713415315, 0.06761500359113727, 0.013912633676747126, 0.011548197828233242, 0.022461756764511977, 0.022626623810668076, 0.03328156251726406, 0.06801125447132758, 0.021728847342144166, 0.10877815407833882, 0.07455926667898893, 0.06487218184130532, 0.02830107816095863, 0.03421536580260311, 0.0009851238573901355, 0.029248472502721206, 0.06306841863053185, 0.07166982708232743, 0.02453265242677714, 0.026456097340477363, 0.010572206628109728, 0.024443062055589895, 0.04015639450933252, 0.030760971164064746, 0.014875441789627075, 0.0655455124963607, 0.027279301114114266, 0.03253595091934715, 0.026313968002796173, 0.012148842963922237, 0.08199785609862634, 0.03317302744835615, 0.034675870556384325, 0.031135753196265017, 0.013079678506723471, 0.06037121479000364, 0.0334273321953203, 0.011555619304999709, 0.03088296836774264, 0.03950904496014118, 0.0162127647615437, 0.029190013318189552, 0.07177987189165183, 0.044834727221833806, 0.055446197278797626, 0.009632131134692048, 0.020809532475790808, 0.04890602893595185, 0.08089620699839932, 0.01619852740051491, 0.015410707531762975, 0.04737461611096348, 0.04642267897725105, 0.022203087341040373, 0.01576430400434349, 0.06245133852852242, 0.06442605863724436, 0.027122388194714273, 0.012562488089315593, 0.02097321378200182, 0.0356344607259546, 0.014187791501171887, 0.07056579632418496, 0.03627738283414926, 0.049757665023207664, 0.006596923132227468, 0.016081330832093954, 0.02843383523369474, 0.06234288149114166, 0.04321947121726615, 0.07802004633205277, 0.049618989428771396, 0.01684323575214616, 0.019954200069020902, 0.04886265019220965, 0.033095528571201224, 0.09146631016795125, 0.01828840677626431, 0.040560170342879634, 0.023438039734693508, 0.02412176724257214, 0.09564339888415166, 0.025626676489732096, 0.011350325142432536, 0.019816376036033034, 0.03866659962971296, 0.013124309147575071, 0.04221322074798601, 0.01710914514426674, 0.06134107881890876, 0.0038921209717435496, 0.04971801143671785, 0.07631526780979973, 0.015966651628592184, 0.06132960479174342, 0.09208144287445716, 0.07812052379761424, 0.06584560817905835, 0.017100273298897913, 0.017241150739469698, 0.07294336945882865, 0.053315190199230394, 0.03642239594565971, 0.028610574946339642, 0.027552799920418432, 0.014306239118533475, 0.053032655002815385, 0.0370768972539476, 0.03026007322062339, 0.015048266355214375, 0.04884417029097676, 0.028668962884694338, 0.00811741705651262, 0.027617162359612327, 0.017488044187692658, 0.06720949749329261, 0.05354113218241504, 0.05243220918678811, 0.07431261919971023, 0.026599202072247863, 0.004079561605716923, 0.05144024866500071, 0.0683886149365987, 0.007882076515150922, 0.025569540448486805, 0.03478735385994826, 0.05911404546350241, 0.10638988044645105, 0.050027596431651285, 0.038815090233193975, 0.08237833782498326, 0.11381929607263633, 0.028260228656498448, 0.04235321609303355, 0.02815615325900061, 0.05911799453731094, 0.03417130173849208, 0.03012244257011584, 0.016883611978430833, 0.07852193154394627, 0.03985376449834023, 0.024666084641856805, 0.03422495350241661, 0.06082366872578859, 0.03666234967697944, 0.048261932962174924, 0.010103248176164925, 0.034890765989465375, 0.07018491426216704, 0.024183703919074366, 0.05450654162892273, 0.07480520848184824, 0.09690683108887502, 0.014240195608830877, 0.08296635627214398, 0.09225657276277031, 0.010570852950747524, 0.042727655465049405, 0.07106275537184306, 0.023518110259569118, 0.021981443877198865, 0.0492000924423337, 0.0531230121185737, 0.032119367737323046, 0.03279502916016749, 0.027563651391704167, 0.02423957279617233, 0.0138285564025864, 0.023302870469966104, 0.06554980083767857, 0.037918348530573506, 0.0077793344389647245, 0.0528682798945478, 0.08940984016018254, 0.07799204997718334, 0.02474885743244418, 0.029220255623970712, 0.016046433776084865, 0.03261246931340013, 0.006857235034528587, 0.03785735841042229, 0.040759483219257424, 0.020655520293595533, 0.014383407209866812, 0.002908774876102273, 0.03836239202480231, 0.03614335520459073, 0.023624736948737075, 0.013287691898377878, 0.03870213111596448, 0.01480770533505295, 0.03832746782739248, 0.05321264659453716, 0.01576712671002107, 0.023229095053726008, 0.027740326643522297, 0.0693818409261959, 0.034275114203670194, 0.05094198343743171, 0.03211978503635951, 0.014856490306556225, 0.06422123605651514, 0.036664765261645825, 0.044548782386950085, 0.0304598271447633, 0.010893202885719282, 0.0214431993663311, 0.040165313852152655, 0.004086797333522034, 0.02227776520885527, 0.01868143291877849, 0.03882619445877416, 0.05379267529185329, 0.014562791512746896, 0.04761197444583688, 0.037837806423859935, 0.05727382456617696, 0.04990185371467045, 0.0337056095844933, 0.015739291507218565, 0.04270460902314101, 0.012541605325947915, 0.05434242436396224, 0.003758947872224131, 0.006238890736962536, 0.027014256854142462, 0.020828626451215575, 0.042481421892132075, 0.038113386636333804, 0.022843225759321024, 0.060471468339008946, 0.010846475571660059, 0.02582444400260491, 0.12020983387316976, 0.11626757255622319, 0.1955641196774585, 0.1315455620310136, 0.0728723064863256, 0.13348215525703772, 0.13321452747498239, 0.13466716238430568, 0.07856027555785008, 0.12926744855940342, 0.13397331961563655, 0.1706654400165592, 0.07808325186903987, 0.1554008312523365, 0.11067661363631487, 0.1944000114287649, 0.10407565534114838, 0.14160838563527378, 0.1585098108542817, 0.181994070698108, 0.10057218226471118, 0.1094289980828762, 0.14570577362818377, 0.12206827343574592, 0.16284136128212723, 0.10037521711949791, 0.16256750454860075, 0.06459687304283891, 0.13706522727651255, 0.16757172745253357, 0.14403129847986357, 0.12784556485712528, 0.13057166071874754, 0.14757354983261653, 0.15695850338254655, 0.18126398058874266, 0.1391318549535104, 0.1422545545335327, 0.12631423345633916, 0.12375973910093307, 0.2244197984359094, 0.12499835049467427, 0.19052614644169807, 0.10978573786893062, 0.0931281034967729, 0.11424766880060945, 0.14240839199296065, 0.10282197368464299, 0.08491820296538727, 0.17719557961182936, 0.13240116754812853, 0.0831506938806602, 0.09493766818195581, 0.13881645830614225, 0.10376840789935418, 0.07163165948752846, 0.08098129528973784, 0.13938680770141737, 0.18387258132653578, 0.12267782858439855, 0.13972057907709054, 0.15548259472208364, 0.08437768196953194, 0.14470329242093222, 0.11017860964472805, 0.1396025139838457, 0.17424311089728559, 0.18283472130341188, 0.19171089572565897, 0.13626623872135366, 0.16702436682369026, 0.12777433225086757, 0.20102213323116302, 0.11527315234499318, 0.3216417208313942, 0.15457309995378765, 0.08787405756967408, 0.13629521216664994, 0.17261147845004285, 0.16643672835613998, 0.10193169502807514, 0.10920149886182376, 0.13557730854621955, 0.14603164685623987, 0.061725713179579804, 0.12540279807788984, 0.10929833937968526, 0.17903708294034004, 0.1761253806097167, 0.11933867633342743, 0.11256243208689348, 0.1543284880795649, 0.12769050603466375, 0.10185605194419622, 0.15325777339083807, 0.3100679761597088, 0.15471475092428072, 0.08725584431418351, 0.16532022612435476, 0.13732357269951276, 0.14777278128479207, 0.20428999859307492, 0.16635406922016824, 0.16463307371096952, 0.12630307834063256, 0.10746477491089276, 0.144832526200584, 0.10643661793853555, 0.11450722201594285, 0.08602293939994914, 0.11938443673508507, 0.09102767799049616, 0.14364046230912209, 0.09477700466024024, 0.13472464787108557, 0.11160862898187977, 0.17308091611734458, 0.15605996016945156, 0.19575113749929837, 0.0956725487485528, 0.16547371074557304, 0.08051239366510085, 0.07596515731087752, 0.1417797292981829, 0.13467761182359286, 0.17095961208854402, 0.16851024994892733, 0.11230466341865913, 0.12974724067108973, 0.16169317146497114, 0.13209441543689796, 0.07578770683280059, 0.09443958276616675, 0.12862872997564928, 0.1540246129568134, 0.19278409385255404, 0.13764608039387635, 0.09792901016771793, 0.09927160705306701, 0.12250738058771406, 0.15397066942283086, 0.16632631713790552, 0.19539278958524975, 0.09323244182659046, 0.23659384303859302, 0.12817911910159246, 0.1397572878215994, 0.1235857220100505, 0.09877368448568241, 0.12818190109516892, 0.11300222455923047, 0.10651778429746628, 0.08791554320071425, 0.0707622729241848, 0.13671105913817883, 0.16408134331660612, 0.16132874387715543, 0.19946181481438024, 0.1483655223356826, 0.1087401086198432, 0.117330063400524, 0.12601616659334727, 0.11856969259679317, 0.13164568665836537, 0.09828008418636662, 0.11410681850143842, 0.1278644824134452, 0.18832409674567835, 0.09271234473479645, 0.08850506121026618, 0.150744941085577, 0.1733406593224832, 0.14435578749648162, 0.10415413470140525, 0.1796606294810772, 0.07724002283066511], [0.03471469972282648, 0.01371092302724719, 0.030718125070312192, 0.07949509325304202, 0.043253917047487836, 0.018356435000896454, 0.03655040157692773, 0.025828147107469182, 0.07684444370014326, 0.03531129824529801, 0.025150801221440946, 0.039393660080220015, 0.06580670098108904, 0.052768067057643614, 0.04178635436775429, 0.07617424109152385, 0.03608347109651991, 0.004146729363128543, 0.020549100557608262, 0.0626111470961145, 0.05692870129964181, 0.02968934384573783, 0.05540852162188717, 0.047144345074359856, 0.04937770237614002, 0.017074577177741697, 0.03878178434180362, 0.020061211826811944, 0.08095949395958867, 0.023306694014796188, 0.03486815720264401, 0.02648034648570631, 0.02708082622848451, 0.06709509648914848, 0.011881283883537565, 0.09525902236678771, 0.0431950948467212, 0.011659927100741437, 0.028588424170655862, 0.05859379909400429, 0.011381691271838332, 0.008499936084263027, 0.029581511060574224, 0.024371291710329906, 0.0505076294232692, 0.011806021627437855, 0.020846733158188205, 0.056908959323274236, 0.0016993965733230912, 0.049694245747689686, 0.013657397640469884, 0.04809638059564999, 0.0518803837975221, 0.03185431160298841, 0.035809902740376334, 0.04200015735945531, 0.04752988867195589, 0.034232274895267825, 0.04386124660127929, 0.04420484994937267, 0.03434272004025323, 0.049231569681848796, 0.02457213637951229, 0.04054285412920373, 0.027557357979406203, 0.04836785227858594, 0.06368876927133117, 0.05488666373171976, 0.019578764946865182, 0.023518868522452455, 0.07290913736713783, 0.020660426101780364, 0.06345517002046108, 0.059722338537020345, 0.01582270042438592, 0.015584029124251433, 0.03778828015284879, 0.0685880770906806, 0.04930631370682802, 0.05888858863285609, 0.021766339794599583, 0.02445671078749001, 0.022242549241387417, 0.025937895057722926, 0.02224966537739549, 0.04824202813740287, 0.0699565058041896, 0.016875547589734197, 0.03086623569418277, 0.024925600537764173, 0.03671057316075478, 0.053230766872210164, 0.002160604140954092, 0.01762504719330796, 0.04344187803300364, 0.07486369820045573, 0.03835117244826896, 0.05230173368805221, 0.04596569582021662, 0.024870515368612747, 0.07057534331189734, 0.020835723927510635, 0.06531969604215451, 0.06117564519601209, 0.012578880647197366, 0.05096532843474831, 0.09763967605041605, 0.04719240910240582, 0.049004179026399336, 0.03728888177179864, 0.011540502392952996, 0.012026294450541692, 0.05824189047728266, 0.054039455085460625, 0.056654179601797035, 0.05997520139706986, 0.019060370977967978, 0.036282068118453026, 0.015435653871723583, 0.04864433154995952, 0.005059337758991335, 0.024268071266955564, 0.04269599162840417, 0.023581777200368897, 0.0002753406313006833, 0.015889324081529464, 0.033546584724847756, 0.08958119739379201, 0.030876444253538336, 0.042306376820696254, 0.002131032948714814, 0.018536784519840564, 0.03965287063536899, 0.023096621269360185, 0.020550461020320654, 0.007823919278702565, 0.08461675021265234, 0.03581956507904189, 0.019969419609489183, 0.009145936196936029, 0.059225467698914666, 0.062299604527652264, 0.008472697144108159, 0.048984084211822064, 0.045604789829147716, 0.0520200975505369, 0.03235336393117905, 0.023947400706154958, 0.05549352848902345, 0.020342479859079634, 0.025842002792549983, 0.08601659509752478, 0.009690874455762761, 0.05883075709321669, 0.039483850954898765, 0.032848531646387916, 0.06893058121204376, 0.05032625701278448, 0.008964429775785123, 0.034685770382306406, 0.04102777596563101, 0.01770955533720553, 0.03663812597681369, 0.01961088509831045, 0.026583758615223423, 0.0313407895155251, 0.02411962137557566, 0.024390573979222348, 0.04292805399745703, 0.04617276095918246, 0.018988139228895307, 0.027187039011291096, 0.041296821885875294, 0.03206826387239354, 0.03141096360715372, 0.04626407820199217, 0.03409771461571966, 0.01609251139286373, 0.002294945592958746, 0.06609916314482689, 0.05991546995937824, 0.016056942587186183, 0.042628874337034564, 0.04972518015918987, 0.05465260646971209, 0.0593644113146833, 0.020958572692636932, 0.027793091222909943, 0.04295757366344333, 0.01894255694268005, 0.04493273821260248, 0.027365495417533175, 0.04628719589007752, 0.011070329363324811, 0.02954821873988424, 0.02242134661147637, 0.047930682344096046, 0.06277382586683546, 0.05408048949071339, 0.01949973258056811, 0.030452536285987923, 0.038063721265643835, 0.034860493149608374, 0.029633354528674057, 0.004533997711925102, 0.04845742568639772, 0.04831868223845959, 0.051900115595864396, 0.02449936349876225, 0.04876663409439581, 0.044591268857142756, 0.03802515333518386, 0.022703174435134445, 0.0030418421665672213, 0.09382615996790783, 0.023853845994121263, 0.0834353461063334, 0.04158741468563676, 0.04222370750669922, 0.04088098169969661, 0.045592141936400106, 0.01421857493863042, 0.027422295583944236, 0.023742182878777385, 0.03238860364737255, 0.03224370249414018, 0.012906916705625398, 0.017722057344924127, 0.05344239855185151, 0.09069633577018976, 0.05559317135651197, 0.04236943307997925, 0.03197013074532151, 0.028760144420500313, 0.020529163502422825, 0.080132278347654, 0.07596811572355883, 0.07244820852896997, 0.05496227967419794, 0.029297907171504836, 0.017204419942572713, 0.07137722242623568, 0.06150967441499233, 0.029268574102648666, 0.08031698236508028, 0.07391751504370145, 0.04143624386883207, 0.0153941275285823, 0.0856989999966962, 0.03919718348022018, 0.06501027050295047, 0.019676801382697055, 0.01571755124522107, 0.05934098828583956, 0.003237676914847855, 0.04448645216013704, 0.023204287813444222, 0.009213790546969643, 0.062168674410453865, 0.04861988054056253, 0.03108870018539684, 0.0666559554104294, 0.03796847191240106, 0.003205696287165795, 0.027127578987606933, 0.02577640881229724, 0.022877522311838608, 0.08061305433511734, 0.019145947814519917, 0.014989852971796478, 0.06678097548761538, 0.14658780129892485, 0.03366884994985802, 0.033541651775262186, 0.019859695407961096, 0.03958503748955471, 0.04596940740676863, 0.028960403853229115, 0.05835631862282753, 0.021493129365678345, 0.009659059645075883, 0.0335356195989464, 0.025786393455096653, 0.017320418896685754, 0.059750267038387914, 0.030828210591737713, 0.014968932040834, 0.022153611960155622, 0.03517899409468685, 0.07145734384123768, 0.09122650232166052, 0.03166477641622935, 0.029937887830393653, 0.02825889703152435, 0.022363094380125403, 0.05749635012554271, 0.01471084276480334, 0.03623391927352973, 0.029675505124032497, 0.09314839847918067, 0.025686718357194747, 0.018112869766939963, 0.021250968699210455, 0.05372340365179947, 0.02682867243752948, 0.013542688751061047, 0.010835345901016678, 0.02121322858147323, 0.022816974935787063, 0.02489777890566204, 0.054927399581564326, 0.017458943517080376, 0.0948704525030085, 0.08428976418716566, 0.04270372014226658, 0.06262212579271623, 0.062160925540540896, 0.048314767091401985, 0.03736058256721922, 0.008349185111001134, 0.03637592647490757, 0.04925380527440991, 0.07069085711347205, 0.004197130944313747, 0.0230177195210542, 0.05828462461275714, 0.05312904429488948, 0.031281285387064726, 0.05924571518387113, 0.03517135039770177, 0.01603356027044356, 0.015385009714269211, 0.0499271834269166, 0.06604808302862303, 0.09235544888568775, 0.03529171911733491, 0.04514830878802708, 0.032261639567358155, 0.032394350838980505, 0.008243828978655594, 0.007626334122116012, 0.02151076788348811, 0.0502459218592516, 0.05795893458915608, 0.059853546853576384, 0.018252327372985225, 0.02679248446864741, 0.04043697213221874, 0.0270376832756613, 0.009367043618112803, 0.06750904356262513, 0.024154586285086613, 0.1342317328921386, 0.10626206480498825, 0.10346943858478751, 0.180919420506273, 0.1473242017839636, 0.13247310583080563, 0.18269197110618862, 0.14109233261219092, 0.11403003547872816, 0.1549296701060874, 0.07903821526893548, 0.1573448476514646, 0.1094654964815293, 0.09345899788396698, 0.12216913088091783, 0.2197599591953414, 0.1513584860201393, 0.18937217550618307, 0.12482981596674238, 0.1612650022975036, 0.18165723234415054, 0.19799563634608472, 0.2154652125069073, 0.10843436752579041, 0.1128544124907681, 0.10415286584092037, 0.09550443491233246, 0.13787937430398806, 0.11246567299323422, 0.10902026215834276, 0.1637922873986619, 0.22547907302422182, 0.11482093589646475, 0.1481047206159149, 0.16643599553831986, 0.1469588785299233, 0.08395019133708306, 0.08839965079511915, 0.15361457424504416, 0.1081219632178545, 0.15089085325598717, 0.11909087534461703, 0.0908508924767375, 0.0915530337286847, 0.10364382208458015, 0.11774135061672755, 0.1446394422756774, 0.2203575721276658, 0.08523722298975502, 0.14831491719399179, 0.1470365436481578, 0.1620758380740881, 0.12033027383897986, 0.3213549719325134, 0.10453040272529636, 0.10941096262208053, 0.14013092991496834, 0.08918951305427722, 0.137250847316214, 0.20060233718582562, 0.15587049962154456, 0.14403918305678026, 0.1153638589062861, 0.10455951187759638, 0.0977019587797778, 0.14229825218873365, 0.1915268363165004, 0.1148382385394403, 0.1467925017433507, 0.2344778994364398, 0.20423001609742641, 0.16009584574827126, 0.1569289599678346, 0.09021670650690794, 0.11869870924523898, 0.12741213025791304, 0.14943819120526314, 0.13393882289528847, 0.13016289765281336, 0.2034173754176923, 0.12535133798207554, 0.11574800472174372, 0.12737846135028771, 0.15396560755159172, 0.14036311102764948, 0.21017266650285038, 0.18591023555823735, 0.09446071913199765, 0.16064703331461974, 0.07867792674473353, 0.12467250440801893, 0.23150572606495448, 0.10349685818489109, 0.14336471924824373, 0.16561001486011914, 0.2567049153149128, 0.09340533933469228, 0.11544886577342238, 0.10437858730022397, 0.07517193630337715, 0.20366060308047704, 0.1405389058802809, 0.1661359609237739, 0.1455920918711594, 0.13740976021758147, 0.07961661208953176, 0.09842225762882403, 0.11870830373040267, 0.1278464062405484, 0.09806571461792503, 0.13327710197440215, 0.09756474542830672, 0.13873052863138063, 0.16179184402738297, 0.12316504386918885, 0.17292912783367292, 0.10879817086138896, 0.1868173147418669, 0.1006408432232482, 0.2692274690738746, 0.08691819850355387, 0.13330656396491186, 0.08031671095107283, 0.13526740803250245, 0.13399245430316242, 0.07734622713178396, 0.09331307214285646, 0.14125858726246016, 0.09957807417958975, 0.14254473681960786, 0.05697992390819958, 0.09990363528153726, 0.09226090181618929, 0.2030649036169052, 0.06998013239353895, 0.11249512141304356, 0.21666180901229382, 0.24612934993846075, 0.12225723186773912, 0.12157116511038371, 0.16644586143749102, 0.129416468420199, 0.09999612638992922, 0.09453112392553262, 0.09762207485203232, 0.1629177507545267, 0.14109667523631028, 0.12066420806305748, 0.1746922196554286, 0.11267514353884117, 0.11571984551846981, 0.15625657247645514, 0.15992494991847447, 0.12077522996280875, 0.10628040560654231, 0.08500525900827986, 0.1104528938553163, 0.15762520475046976, 0.15170388748603209, 0.09102408175489732, 0.12899735090988024, 0.10869816158499036, 0.16467276800956043, 0.11630809466753687, 0.15988125226327352, 0.1710249007280384, 0.086429653290127, 0.14903671560542925, 0.16603513062000275, 0.08672808656202895, 0.19565830033804688, 0.13346642681530543, 0.20039167920393602, 0.0764972712578518, 0.1670859506619828, 0.13223860412836075], [0.03500583195792777, 0.04326174394892795, 0.02099860456239964, 0.020429778478241394, 0.07572988886386156, 0.02279238143403615, 0.02227957689735506, 0.04053504079846399, 0.027778977694522058, 0.07610158356172697, 0.024371457951409475, 0.005867028101680002, 0.05584390700927802, 0.04126755667052098, 0.045034487931323905, 0.04509001923725009, 0.012739840179814823, 0.045795061226402006, 0.08017702773213387, 0.04267901468223759, 0.008177508965932896, 0.03300089329215033, 0.025026542799813405, 0.04199920401775411, 0.025441078502418737, 0.06391689274460077, 0.033352476212063005, 0.04666048175256167, 0.028023838930364166, 0.015710896513025676, 0.034078739383923154, 0.08096761602376189, 0.04229601898363658, 0.06385762271072183, 0.02770265607562448, 0.041351633944681714, 0.09391787754637854, 0.031435621569731405, 0.03213091301066535, 0.03250071120315364, 0.024739893984847834, 0.04286639552031245, 0.01585259667730757, 0.06765583782855954, 0.07628459124160664, 0.0720599711473499, 0.03007517921339188, 0.0553545882659299, 0.016093257781384245, 0.04348069362874542, 0.0604471903560417, 0.06736953676279102, 0.06292929859565836, 0.06632864368813378, 0.03806800960696169, 0.043502539063670805, 0.04291479881586773, 0.014478870301640459, 0.02192337315396539, 0.030113658934299434, 0.004321940251559551, 0.0275888861090477, 0.014836387010291219, 0.042114381944494586, 0.0213651593574988, 0.012875987383137857, 0.018556602831397737, 0.05063950948949371, 0.03388449516413467, 0.0760793818959168, 0.036164362648768086, 0.0552933436951467, 0.004019823806759502, 0.05316584803430097, 0.04313685618607061, 0.028719578204410415, 0.05119859520345926, 0.06413610026772533, 0.02403717428179724, 0.03091746848076582, 0.020919122666652714, 0.005235571114878569, 0.02531493205710181, 0.034884910232254436, 0.07396817446819373, 0.022662964449929338, 0.05713693012616464, 0.044191499772880755, 0.018381303309329917, 0.010675408411771059, 0.037441636967871866, 0.02276925526426307, 0.05144161930573838, 0.030910622062427656, 0.0483816299321396, 0.1038481696907963, 0.03456326088468943, 0.0025451956691020833, 0.07514263716127191, 0.017572238509144102, 0.03020535615671958, 0.04772349846150194, 0.02083859413063952, 0.03875791687252266, 0.030846439435013702, 0.06190891084926469, 0.0276675045689834, 0.036318077971892695, 0.06299382049058165, 0.010951247315720787, 0.02404569328895637, 0.01697318538624261, 0.04587929456361702, 0.02239931288308331, 0.008095236594921775, 0.03342351204316531, 0.0211190139941339, 0.04716128470110042, 0.03723695009414639, 0.04586681969729917, 0.10398363920726947, 0.042319733782538345, 0.0261949733165758, 0.05407952597098691, 0.036348534016204734, 0.044352014016892226, 0.017869592910366397, 0.011336988536641002, 0.033644317516258786, 0.0421686952800623, 0.022410807266299213, 0.0073998374365536225, 0.04444219810622079, 0.018416699088577713, 0.019830498046108654, 0.009041634338375713, 0.049635372656796656, 0.04304033797234297, 0.01975698725852583, 0.05489613947325519, 0.05988030827471188, 0.031209703335272412, 0.04456108422683818, 0.025214793859049678, 0.012842598371207714, 0.02106695848384074, 0.02954807285485523, 0.08001782984605857, 0.06685556005686522, 0.0237834157555231, 0.025481488655454347, 0.06117109901138714, 0.02666879940911063, 0.05108360048117382, 0.06386715612773385, 0.017748052021488547, 0.021636517385819128, 0.004522195867528873, 0.05830971005239657, 0.009761800873093307, 0.0041718279493839616, 0.021059197739564946, 0.0751280283023204, 0.050877519217985015, 0.049380216348384104, 0.03516579658857413, 0.03307641763240099, 0.017765768570825458, 0.04031251523909824, 0.025966303622616187, 0.028765979821660688, 0.050304265692830086, 0.10488229098596744, 0.08359244731920105, 0.055192163945840936, 0.027654013596475124, 0.018688306478517394, 0.02795365296437272, 0.014761553079422032, 0.029228564285274063, 0.036440353374928236, 0.007072150823660195, 0.024684518741975938, 0.003802123903629503, 0.02566185513777392, 0.03335703257471323, 0.049091340242219825, 0.02333223237656057, 0.01198436607540186, 0.012831943675077387, 0.010251022077032497, 0.05380138089614255, 0.016561306148235286, 0.022820745894153203, 0.02084674163987594, 0.03429517509149654, 0.01856056717224419, 0.04798812711877482, 0.04629879205354622, 0.026060733644823943, 0.048288745273436816, 0.035079056064465215, 0.026386732401858484, 0.03907916249175157, 0.013086386673551584, 0.0026883780083153397, 0.042081700305321386, 0.010741070245525666, 0.025334709656557867, 0.03549967992252537, 0.025045543476673107, 0.034735303438667736, 0.03356487463627543, 0.023789171428818787, 0.0165415200670915, 0.04224964790046215, 0.028778726101986, 0.028244488340403353, 0.051598136978490014, 0.013865189660074455, 0.015510023006104996, 0.052270673747573576, 0.02530460136144289, 0.05924155576420682, 0.045303201369409046, 0.049216194078326225, 0.02907033670427544, 0.05604054985035743, 0.014712311793118715, 0.008018180461866515, 0.022182980652100275, 0.06039374215262277, 0.008463887215059782, 0.02310323020044182, 0.037355615690882714, 0.028037058488864983, 0.022509912394785454, 0.045170133866901906, 0.044129729337458096, 0.08307891166103737, 0.03728235087224415, 0.09962372601564441, 0.014244127719263946, 0.026077211867751818, 0.014928269133503948, 0.05049258969458086, 0.024949822541592375, 0.05355239247104951, 0.018894433542819958, 0.026380612015990273, 0.08968705564205136, 0.15766872598656587, 0.12705861351319722, 0.034603470869894536, 0.07374815948839698, 0.010254497024496751, 0.1272982313696827, 0.03682082492325987, 0.01473914276409362, 0.025729160722611204, 0.06959363884691681, 0.010611548936659736, 0.0400606158987752, 0.061352328929517946, 0.029354076300348555, 0.044276621990970204, 0.031307140963950326, 0.04749985331935542, 0.014577001732374941, 0.012945564363950064, 0.04822000628337264, 0.07159107630806309, 0.048321447268660576, 0.05191565065511635, 0.05854803190699645, 0.06442793139389583, 0.18172732501157693, 0.09685566276311874, 0.020469949447682927, 0.06962528572018657, 0.02681835531257093, 0.032283861589218886, 0.03969621205968516, 0.04320887250027486, 0.026942055639145628, 0.024362482629450302, 0.05138817110231944, 0.034885151112186055, 0.03964310312377555, 0.0034613318109352675, 0.022035397589206696, 0.022248912203524793, 0.050743895316762586, 0.07426826336554118, 0.015656622193221535, 0.014093186756196831, 0.014544411695429256, 0.03934045954208289, 0.025864723537649428, 0.07853216385202748, 0.02839790001910712, 0.01627485580476267, 0.03555032916899238, 0.06133482272603682, 0.023210357309186032, 0.033296649743403704, 0.03624621432806764, 0.06344054080545902, 0.009560753491574099, 0.009498748961570007, 0.032413075012820106, 0.01071752847305366, 0.06383004026221377, 0.02515822439454496, 0.014986065050054873, 0.046189174721283574, 0.08731025603732892, 0.08891953754105739, 0.04543131895895515, 0.030462741452668394, 0.02766542655548879, 0.04842308842177902, 0.010765578930399247, 0.0299248124605843, 0.07093628322971718, 0.06074656679161957, 0.023249724214630466, 0.014682552943538343, 0.06873597058334521, 0.08605411808405604, 0.06913390423038177, 0.026094453442575674, 0.034200621236647875, 0.017892079560884407, 0.04910523663940174, 0.024207851284050515, 0.03923662332817912, 0.05955214838364294, 0.033072346422289095, 0.044977742047714334, 0.022216461266257932, 0.06320392885910613, 0.06414184745933328, 0.017392073890992572, 0.004677553245398615, 0.07318865986807005, 0.05220300005748868, 0.0171974734403193, 0.045705901724951606, 0.028976681908326488, 0.021512813666569333, 0.04160412700314607, 0.10709201491304807, 0.14309627722416604, 0.13073507909263882, 0.12773473294717924, 0.16291795431503228, 0.10125644411891699, 0.0987839846472655, 0.10740394424647093, 0.1429802748773779, 0.21122439578175545, 0.1164171216743333, 0.09823645438466753, 0.08807622707848038, 0.1451140639505216, 0.08782516912158046, 0.12424307316541672, 0.15014914662710258, 0.11038664169609547, 0.11374657747468778, 0.11237257120332547, 0.10517909577382462, 0.12966033390590123, 0.11544974786894661, 0.09093997733933584, 0.11484397894569806, 0.08608030275042568, 0.09525066960070815, 0.1987430290984256, 0.07785145752131939, 0.06018775249166148, 0.13304521941712924, 0.1415004985673087, 0.10678815336099692, 0.17592477851680347, 0.08069531992077827, 0.12904068215617112, 0.1524736447525876, 0.16811218059488706, 0.11729183473757335, 0.12418950961104461, 0.10285039073122398, 0.13441058115235396, 0.12487335077353887, 0.1375273096242121, 0.14570476939635618, 0.10436553907181535, 0.1463548873684236, 0.1403952735875334, 0.12198512575456075, 0.14078393844621523, 0.18297941211078847, 0.11344104672649077, 0.07729733189834015, 0.1079798915556499, 0.19744816715163843, 0.14371101638036116, 0.11432852303343159, 0.14162948807435377, 0.10329391514616353, 0.09747055798236813, 0.12066278313951832, 0.134402832282441, 0.1529986137258155, 0.1846694799938372, 0.15546515637210437, 0.1995821597852877, 0.1167717512164797, 0.14694072093282426, 0.11026747059077024, 0.19114932657352515, 0.18936591941331113, 0.14691337597157272, 0.06857204330818993, 0.11908978968858719, 0.17499730257051332, 0.19484386832586356, 0.15983422978648118, 0.17168242830250943, 0.12232963155422892, 0.11672058967607361, 0.2562402816755431, 0.08772678154387645, 0.14138636897717202, 0.1623346856130021, 0.13041893605675015, 0.18658175452479295, 0.16222039317446096, 0.21334810182452202, 0.13585940269487246, 0.11370494256594352, 0.11942924718771662, 0.11156254966876336, 0.14105314042951378, 0.11200669833592006, 0.1330300880862134, 0.27297800353595186, 0.13292407377489976, 0.0990068359034402, 0.21192753448018006, 0.1822067778557539, 0.25380721794707434, 0.25356479095561163, 0.14788239183170454, 0.18702562499259198, 0.13943904132715293, 0.1862064160938774, 0.11561706103384495, 0.15628004978810037, 0.13363230148596422, 0.10895814227738551, 0.24183875588434084, 0.1855980958789587, 0.13194053726536886, 0.21660418781851018, 0.10647553192185504, 0.13248021687780107, 0.15454574142183575, 0.20226956558014664, 0.18594733785305703, 0.12855609958725317, 0.15106776090604918, 0.1947184479130166, 0.11405767899538789, 0.12969314785940306, 0.12752347785447324, 0.18393814138003758, 0.08293523865618876, 0.12749957985111646, 0.09183679707348347, 0.11156690586358309, 0.08391502286706652, 0.09810494751270328, 0.15020930554185594, 0.07052508422306605, 0.159037996083498, 0.10845077450254134, 0.12081102947039263, 0.10426240853433098, 0.12838505447975226, 0.17558336683682033, 0.20629394320505007, 0.1699888456080641, 0.12378374566989285, 0.12908226278211388, 0.09165241196751595, 0.11248907566602741, 0.18561799052570546, 0.1408647655376366, 0.319560708212001, 0.1528166849166155, 0.07001780465777431, 0.12780994176864624, 0.13723871511008057, 0.1470242485936199, 0.2554321736097336, 0.09449575189501047, 0.10160737564521176, 0.13637644637908253, 0.15639283587890013, 0.10638029953198773, 0.11541405692696571, 0.14293101323502405, 0.14430877859038965, 0.16546172781714372, 0.11745675945920603, 0.15850141059075082, 0.17679527109222754, 0.1599575060286692, 0.11646520266575472, 0.12977408351642744, 0.18949971294828824, 0.1491596390094076, 0.21148679884416716, 0.2524926784847464, 0.11680320809994425, 0.1473027600773743], [0.0271362557541579, 0.05506842290716512, 0.021923162808109607, 0.0820319592686636, 0.019123620619731288, 0.017892462933169942, 0.03436197007873228, 0.07052100622760397, 0.021857718105560968, 0.015558470406436493, 0.011952086468227208, 0.03144068344097052, 0.040371842948453765, 0.04550736237849508, 0.09594016974525792, 0.028392349602654576, 0.0227030964036073, 0.015434077974142773, 0.016213153222841874, 0.0007558374917217796, 0.03353614207091076, 0.10840801322566611, 0.026842735075790967, 0.02478374770310308, 0.029644781058388095, 0.014324895438871213, 0.10490470299763338, 0.02626592093812568, 0.05823997700853007, 0.016498587460124066, 0.01620526016423745, 0.039117089206618924, 0.016263030635725175, 0.020944627101666162, 0.06406330024557454, 0.022031134692952037, 0.010939894576690026, 0.08432639150747231, 0.03462313481473497, 0.07929252340857472, 0.048925102555326054, 0.038619393948465586, 0.0376926881394216, 0.030113482515194585, 0.02722553230289902, 0.03888756795121091, 0.06276740692555904, 0.014613927608089787, 0.02205920229399843, 0.030866378186536685, 0.03406270560143249, 0.013347285932728221, 0.012033321528828569, 0.03419073158875108, 0.03130974653842194, 0.0854290584102273, 0.02368197646657271, 0.039574377704411745, 0.04383827140554786, 0.0330662192510707, 0.0456518869447921, 0.03920622156666858, 0.024271318057019795, 0.048342098481953144, 0.07799230782049042, 0.045949285450790606, 0.009255433937401643, 0.020104466737913232, 0.056122679729014635, 0.07900247682950326, 0.04188854852691293, 0.023675504938832352, 0.008977933470825, 0.030021717439272573, 0.08945038941289697, 0.07174340741974966, 0.05428645879562412, 0.033336707058229616, 0.002175261769610058, 0.014527655273143734, 0.06449293504868235, 0.052538589907011816, 0.029324953577348163, 0.04762735004935946, 0.02253484516404569, 0.013513806907992278, 0.03621433336021645, 0.04049690713041595, 0.027749595431877033, 0.047350575615252764, 0.03555953349652035, 0.05871265807322093, 0.03752749539645655, 0.04681877718706216, 0.023101957947281853, 0.1040520491078496, 0.0904026251020176, 0.0746989973953792, 0.0343551372310945, 0.09169833521757807, 0.0175968896863716, 0.10606826163296189, 0.061386248895100186, 0.07764649923358645, 0.03462436974846891, 0.059699139424732754, 0.15345680128250802, 0.04176923832190888, 0.015274199856711286, 0.030942167155444622, 0.022482279056150998, 0.021354869373940995, 0.05496648659131356, 0.033350586492036066, 0.019646845757961273, 0.0193852993460106, 0.03639570237802608, 0.012585731306379395, 0.011594227947560804, 0.0076520692590358, 0.02475993282028607, 0.05891913627939565, 0.03971278527751565, 0.04892442062763231, 0.028822274479482855, 0.0698651953467301, 0.055241269525140524, 0.01918319769070617, 0.02469029477132218, 0.06209484301507473, 0.020987893887130276, 0.07176650475178446, 0.028185379458591342, 0.04420466674491763, 0.00538602310864787, 0.07163049240729638, 0.0469708233140409, 0.027309930184856057, 0.03813934738614729, 0.012681270733342638, 0.013548720927376832, 0.016806864578809057, 0.022276749102664844, 0.08786416452910219, 0.032970993646553585, 0.0213297160807997, 0.039150758114244254, 0.034931227032627375, 0.03444047658038991, 0.10112852669720139, 0.02481432249104338, 0.04597927669861487, 0.03707262248333011, 0.045537309521543126, 0.06834882564310517, 0.024574594372617345, 0.005509359994903207, 0.043815533697072945, 0.032497688329645565, 0.0436807596789939, 0.0035294618158202085, 0.027093983022496104, 0.02369852763201509, 0.03772517639611449, 0.036681810061314275, 0.04966476000845432, 0.019180634524673223, 0.0503932691312262, 0.016681710490956903, 0.04113085222031389, 0.04451330179082496, 0.052010411463145695, 0.006632188717568559, 0.04457597467782242, 0.03407241543754935, 0.005262355436570942, 0.036037429102829525, 0.016949095696743046, 0.030961468084050075, 0.03281071010444846, 0.04900388386366623, 0.03538119074489389, 0.026326061193166033, 0.016505316831171513, 0.04572723147326282, 0.019600450926061188, 0.011785396707377263, 0.037850919113095315, 0.030464739738298312, 0.04218562812145267, 0.010588445667443531, 0.016909007847841297, 0.02752599778718182, 0.03348358614104135, 0.015650294854172637, 0.04510094704372542, 0.05187971204785364, 0.007401285260649664, 0.08491670340299606, 0.04119030885132296, 0.018576321059039662, 0.029856548445033174, 0.0345091578949775, 0.05968756361731461, 0.024670374679512212, 0.03791144782943385, 0.014435667977003115, 0.09316758066415787, 0.010481260035053959, 0.027122813975438476, 0.04465448117948004, 0.01857004630645471, 0.0019175442035443016, 0.05321148629965527, 0.04223805512966854, 0.1429791213678462, 0.029315006253974776, 0.03559296152421406, 0.022961631816412722, 0.01839009881950915, 0.02502944353701813, 0.033320917548345666, 0.026454416269968663, 0.00786167211897139, 0.043085847316043716, 0.032460016065410206, 0.006868212882961545, 0.030176698230206966, 0.04082126044003027, 0.06636551528104714, 0.05524753240336265, 0.004515416878608188, 0.01801667725002127, 0.02644111528726561, 0.048545730233724625, 0.021351631065564494, 0.030195378299270357, 0.038017136443938525, 0.017799049017152617, 0.058917406015098095, 0.05096719440604959, 0.06130302657506295, 0.007490884113524641, 0.031928288883396556, 0.027292559688378657, 0.1513284540602139, 0.0406079799202936, 0.06177737005054951, 0.028836391400545835, 0.06379109235214335, 0.05647370625021202, 0.05780015739479235, 0.03251129974211965, 0.010237804214869226, 0.01054633323967989, 0.023939305783382485, 0.04686204736520137, 0.011086888162286153, 0.02568657586484083, 0.06616735591420106, 0.04081267697204437, 0.07148029189556837, 0.03583357682717698, 0.006528873279291604, 0.05790890620223113, 0.06748317780771426, 0.010742955724708736, 0.06084479830626931, 0.045086606206106286, 0.013173932957995151, 0.05106857093051076, 0.05718322657048702, 0.04755206998171551, 0.032574339038027186, 0.03132953601224082, 0.0749455430944051, 0.022335730759160857, 0.1551181399928672, 0.07574808038771152, 0.10261662184659924, 0.02592280274257064, 0.014188875460864177, 0.029151224863848517, 0.05633444033030953, 0.0682520122666444, 0.050824315287172794, 0.017433189720447575, 0.061404074010040076, 0.019454957751025046, 0.05291222521503057, 0.02818600879982114, 0.03904578196150916, 0.030399807329688753, 0.06127190895910774, 0.0637891653126904, 0.050646593395088396, 0.016537998470344713, 0.011824100344840969, 0.04728714955438461, 0.09842002524861268, 0.02792348699378116, 0.01810991983594639, 0.03360075896073665, 0.05021824102316584, 0.02364371557320867, 0.05462487813617502, 0.02922279334494046, 0.0688618388293045, 0.08604231836008173, 0.028515464692775692, 0.046927749911057096, 0.02533395478634962, 0.025526154919394424, 0.04239010125664728, 0.011992388903828604, 0.031025246983127933, 0.02619794869263257, 0.0020615708947713885, 0.029588944411703517, 0.030874530784785748, 0.011261238583496638, 0.0071894941252789325, 0.03847872346107449, 0.05504095920228532, 0.04243992269039154, 0.03358822302626712, 0.0368932517511504, 0.02908320172822901, 0.03467236253033791, 0.030091026398752416, 0.027583573179851686, 0.06994070950895548, 0.017930572852492332, 0.046797528862953186, 0.02986216332231249, 0.005917448766662606, 0.021629908454737494, 0.013058516695829374, 0.028930863831192255, 0.04776528264795031, 0.02513149181114776, 0.055355891053165705, 0.02480208850465715, 0.04112149861508182, 0.04574375040829182, 0.01603974511713854, 0.018649402673223188, 0.02989520797772067, 0.052824395642216714, 0.031636875056262524, 0.05035578685679606, 0.05448574453060116, 0.1523370420826333, 0.1552825490278857, 0.16688502287226065, 0.15735190441565855, 0.11622774255062852, 0.13707250117191247, 0.07965404008116041, 0.17455146435116017, 0.08483281611864056, 0.07100667445255177, 0.08439233832593475, 0.10623012616166047, 0.12772764904158457, 0.1430989506521395, 0.09788453898259572, 0.08902238987918411, 0.0738992081688983, 0.14017511611538275, 0.09224570263177156, 0.16329435126057693, 0.1685945647103446, 0.2417262547782489, 0.23879750764795712, 0.08619714648063694, 0.08593444486281701, 0.13414158272956098, 0.09743335390729563, 0.20102171253945145, 0.11599035028900419, 0.08959941605904273, 0.06328839289822749, 0.2923058292695454, 0.10206648600952965, 0.05338613103543009, 0.1289104034325906, 0.1220763208610671, 0.09005032972033535, 0.19534667634538241, 0.2480023508625371, 0.21004751750401088, 0.12560527292745455, 0.10545834686074938, 0.11565959160881382, 0.15899086504110269, 0.17698383597390993, 0.1327097788453102, 0.14917779660650662, 0.09817614619221006, 0.12604176093425068, 0.05521234357729554, 0.17670178253735813, 0.06456935844783272, 0.07724383619746991, 0.12225484342447349, 0.10664251938994442, 0.20597477390297822, 0.12474769965878554, 0.1132535675008382, 0.13354426835264477, 0.09224129215415035, 0.1172512447727578, 0.09348843273307596, 0.11606391705572605, 0.1217949731009347, 0.1883970256894827, 0.15607648928250584, 0.17536778269069536, 0.20643502420612744, 0.13875912209706648, 0.27612681314349174, 0.10598507323967558, 0.16267111684594834, 0.12180950732103416, 0.0965444255354149, 0.1446776030851262, 0.19662196934223175, 0.16936475623931202, 0.1215371840766498, 0.07308436225035361, 0.1429426297545433, 0.16063973227781908, 0.11643909263823714, 0.15699617564678192, 0.1370544657111168, 0.18388992468161242, 0.12566290769193852, 0.18018935753830842, 0.08295573719910213, 0.140536544578416, 0.20123299477355822, 0.08552940016878502, 0.13539573257522924, 0.15046971371131285, 0.18284694850444794, 0.15705965938312666, 0.22315271571278572, 0.18230342838381017, 0.12646435254386493, 0.17032135490860256, 0.14350795799068042, 0.08375822020960705, 0.18327719398907252, 0.18100585229694843, 0.2155982189412628, 0.09843523800373077, 0.16824076298092092, 0.23286325750606401, 0.14346136977630003, 0.09323345962911844, 0.17932369613221713, 0.1502492848251547, 0.10520735675735132, 0.16443704494408198, 0.16147443891635962, 0.0700733359637005, 0.07714928234262125, 0.09524985535868577, 0.12185633980802127, 0.13707844513867581, 0.11502958541469914, 0.09322866917188678, 0.107604722758489, 0.21238040232232638, 0.23511599376797676, 0.09784810165209429, 0.12292491032608918, 0.13859726435371808, 0.12352739513984748, 0.11228146430637155, 0.23114604822226933, 0.13386164632226738, 0.3100690618157387, 0.09598471556923219, 0.17718282315347875, 0.10398724901356868, 0.11501969237412725, 0.09851039254239627, 0.1092681445713554, 0.07775485449071441, 0.11442990973591805, 0.08994968262101923, 0.10280267614871264, 0.13553228096238204, 0.20199988862233503, 0.12767453332032475, 0.11286898742296866, 0.14082040291811737, 0.13292024683739456, 0.1037446523883513, 0.1559199783951044, 0.05938564946076699, 0.17192903506968701, 0.18617029088948453, 0.13290483052177088, 0.20169620348938874, 0.11919341555663518, 0.0676470711561186, 0.16742474319679396, 0.14009427545326097, 0.16177230221884592, 0.08504240880055086, 0.08147766401192971, 0.06712366281343357, 0.17310531623661518, 0.1495226552443845, 0.1588706150650978, 0.06882605967777115, 0.14063516285802635, 0.19735790842345782, 0.11349651017891509, 0.179677796417049, 0.1270693615078926, 0.11077728109168154, 0.132151724504573, 0.10143031193209545, 0.17663098419351236], [0.007814602992896522, 0.024783294780978134, 0.0279970639385283, 0.04497244268921869, 0.058376830736441274, 0.009378559205548039, 0.04198411339893937, 0.05316957997690354, 0.02266551404526191, 0.014093829668127, 0.022687686873333793, 0.04350974510556885, 0.04875130259564944, 0.034705318976193666, 0.013003811506288392, 0.05368801126522677, 0.01931910146959126, 0.03341621779171484, 0.07314057209129844, 0.029610626998224428, 0.060719058981963565, 0.038251285308173726, 0.03547012293711305, 0.08382960887891905, 0.001194032491184771, 0.06973106932959386, 0.036887721690748415, 0.03472580394840666, 0.08381801950080053, 0.019893092901578972, 0.053850248988185606, 0.02094497485086322, 0.039674125744828155, 0.044869149303329844, 0.020849971466564705, 0.04231586613293205, 0.046872473055762906, 0.014336164209193416, 0.02638013195246458, 0.043356569217784066, 0.013944313628599048, 0.023141536894919615, 0.03581610455044678, 0.0362222891833101, 0.004881744788560484, 0.02745687372849456, 0.03939957690558263, 0.023082309269479344, 0.07841700967401266, 0.027445587994796888, 0.04137412738054991, 0.03179629007354379, 0.016058099489392977, 0.026719611503982117, 0.031592899201703925, 0.03441602557099291, 0.043100978646959574, 0.0416243439540267, 0.04693514255008527, 0.02381833825659539, 0.035774096447442255, 0.033067929159317694, 0.01438045727887324, 0.026520010250221406, 0.08009739486234528, 0.022309427349162952, 0.07960540947637387, 0.026455754680292945, 0.009428942975189005, 0.08551537484994956, 0.06057531812361308, 0.07148581517062016, 0.06758710901652064, 0.05605262777368937, 0.061145348607429435, 0.05968363489955664, 0.024372380759034837, 0.06082772636520011, 0.03787441678079111, 0.018416285182216337, 0.04434678929724863, 0.08168891910463572, 0.005906042168914739, 0.08336976569678102, 0.033217203470745256, 0.07506347926599638, 0.03286305908113718, 0.0347847754268774, 0.10350641195795365, 0.027834220623065318, 0.01754140927057181, 0.032421716156282594, 0.10224107985517808, 0.032852121096636565, 0.05279964607741151, 0.2113117232386555, 0.02601705804201109, 0.05953496787697077, 0.06078147063297885, 0.04039915059027927, 0.043035486446959634, 0.04229804441066725, 0.0625058248905199, 0.02146209147758782, 0.04220997056524668, 0.027051391379375542, 0.014730501620631133, 0.042969634623399804, 0.019180793980402604, 0.03131128681291427, 0.028078847764325992, 0.016968785086646676, 0.04249847347715071, 0.019210106693208218, 0.03417464691613402, 0.026514498849532435, 0.008504494991419571, 0.023053305290107216, 0.034940695988812616, 0.015456182948712791, 0.05095191379742963, 0.0540597025704171, 0.007614152722193727, 0.019394144049978683, 0.0521822538492935, 0.012012656744835632, 0.006548882428822773, 0.024606873979792, 0.030042908087904965, 0.05430563080257603, 0.03447703943986978, 0.034528041524546485, 0.056091792814965756, 0.038255135994404554, 0.062399376316794326, 0.029291732502835136, 0.006805227869855506, 0.03419950843921729, 0.026015471966405, 0.026632480822237473, 0.02676250339884843, 0.0425348768809012, 0.009610158474450665, 0.023328268035714115, 0.015101882496050425, 0.02332763190913413, 0.06434576758848769, 0.015592819545418024, 0.022493876915957247, 0.06297701317816973, 0.02589258927452777, 0.03207552080441799, 0.06074821563171489, 0.03307523358879345, 0.03687800846195646, 0.07010183443448373, 0.03041994964171733, 0.054173252013112815, 0.024072062856118594, 0.015009477900873338, 0.019881442455308776, 0.06655106068189655, 0.007616016997157463, 0.05326239338942936, 0.0563886213515486, 0.03778690272676093, 0.03474883681961468, 0.010429984840032245, 0.03712110720308764, 0.018268909072503448, 0.03224507652755294, 0.05189133196004799, 0.019539369203682457, 0.028624593479824916, 0.028749192865299325, 0.03848380568836417, 0.11593498183148247, 0.008823268198674279, 0.04218852885865739, 0.0542938480419772, 0.04098675513107862, 0.04253483616880008, 0.05285685336483376, 0.021246402158534954, 0.02605604666418263, 0.043090335825192075, 0.02018667125542249, 0.006375640988283391, 0.04766762449539133, 0.06412162033042737, 0.07913962232747249, 0.01801537107011037, 0.012712836182410163, 0.02493638076287295, 0.025659339469192282, 0.019173028147114173, 0.04767154982047422, 0.05314578714647463, 0.0351069268903562, 0.04283769688169871, 0.06449412248496499, 0.06866512474204813, 0.04276346175798348, 0.023526651319116354, 0.030783359427005053, 0.056991961119430404, 0.05749044008553028, 0.022627765445836952, 0.0435359263792634, 0.012446897104382515, 0.03520462575501629, 0.05661915023145931, 0.04823953112853425, 0.06517236573355538, 0.01829684096654611, 0.0330215886102191, 0.00905516347847879, 0.026889827102422714, 0.030572942325047085, 0.011019687750376761, 0.01652151855107929, 0.04329862571986658, 0.061606284230947495, 0.01645628928339907, 0.04623228205101831, 0.005331230557723237, 0.07799688793186631, 0.010593023234313088, 0.06245122317756925, 0.01336706438035305, 0.02174343754138265, 0.019442706801263348, 0.03029399997155581, 0.0041355220850424045, 0.031721047325325866, 0.08266571776143142, 0.039265288040041924, 0.008639215574865895, 0.025543807007904564, 0.11958780725087438, 0.0450999020997967, 0.09713016410491296, 0.025092545597414886, 0.00798359977280987, 0.09154917286442858, 0.061135543776409965, 0.1022512171683567, 0.07136897822575909, 0.022124618158808777, 0.08331907913088799, 0.10931530954050166, 0.10602866911462375, 0.07779475913516112, 0.028264316829985807, 0.04868741173829351, 0.04342951512496386, 0.02716902899555862, 0.04353630296619875, 0.01168959858893816, 0.016366001717480164, 0.05245469244463103, 0.11447921209037304, 0.020546228658141832, 0.029271240745271956, 0.09206017080162253, 0.02852646374542798, 0.04603712520162974, 0.09367829361664397, 0.08312313178820269, 0.10900032679949488, 0.042290851939469576, 0.11268044289733682, 0.08600763164992843, 0.044520382303744555, 0.008336700914826776, 0.055895082120384486, 0.03422380338556, 0.11302648218614714, 0.056230210566094944, 0.031216644748513187, 0.07678858669740812, 0.0027645757945720106, 0.06087534595280886, 0.008447707547540111, 0.04437866008707455, 0.03583988720285041, 0.03144240691991789, 0.024262417373912673, 0.04144497661452208, 0.04908805274005447, 0.04251018159889749, 0.028043095754193406, 0.0334834572193878, 0.07399091217666864, 0.0212703493556806, 0.028627205839646713, 0.0660795331267374, 0.06580388506076165, 0.054011808176125796, 0.06002588117761271, 0.05126898981896894, 0.08742130507848092, 0.04643612075597048, 0.04238914452227099, 0.015188692569998758, 0.022257918059559803, 0.02786308719909617, 0.06622740626335144, 0.03910478058138064, 0.03516589497615184, 0.029111886796142374, 0.0376972071826458, 0.027035966582064117, 0.008080097630486956, 0.016552113695070148, 0.011902891831206424, 0.033561702485063245, 0.04619969201407262, 0.04376284884554999, 0.035918410667883496, 0.0658694247582129, 0.02225047961941787, 0.03584605508616992, 0.017680167985547866, 0.05591025755607656, 0.02682889805042318, 0.04295821148636086, 0.06580785449062075, 0.05068587717999305, 0.02409155377452927, 0.014982679160311818, 0.04379818355664611, 0.03144268851195063, 0.0036765957733483185, 0.028924882545002868, 0.04084508041185992, 0.029404600017837117, 0.0328618953935802, 0.011765267966049058, 0.043050400646669526, 0.031179437280765603, 0.06952720348324094, 0.03974964329972863, 0.012556713756306894, 0.023971293620499115, 0.04792363915060248, 0.037181208442364416, 0.017782441872571195, 0.08340888324060611, 0.037747466271477084, 0.03580012844343271, 0.03879991140482681, 0.19438953484807694, 0.06406235708189861, 0.11728871347648756, 0.15789580451590673, 0.13408336442496094, 0.10115036195410149, 0.15599442725735052, 0.12773693140063966, 0.10323465189763478, 0.10273745536272015, 0.12837490359587328, 0.15083267566348824, 0.1512708735785314, 0.23472998876656803, 0.13228656298347882, 0.09623834517385278, 0.11169545432286603, 0.1304541113121169, 0.13482299473668846, 0.07484462458108153, 0.1898607342903103, 0.1031731969809958, 0.11804373296243803, 0.14734286149697645, 0.1049832705674427, 0.13068607529359205, 0.15351187118462153, 0.10014642189655985, 0.16282028598444803, 0.15275188482233457, 0.15005195327103138, 0.1386156797941242, 0.15787272075457232, 0.1194108317473105, 0.13828254624136857, 0.19740033043282373, 0.17006322661680834, 0.1466990267591817, 0.19892366869109018, 0.13768306055239268, 0.1154900664197547, 0.12164912878402642, 0.1441420761070081, 0.1929221214460475, 0.14678570282246384, 0.150989634384002, 0.166440840278353, 0.09787990458841835, 0.12568282948008605, 0.09396198910794087, 0.1588754462344306, 0.2099534725504262, 0.09565639961510897, 0.11064529245985405, 0.1386052846376385, 0.07496783296976771, 0.09689395927957126, 0.0815919835918716, 0.12713800211037907, 0.13974250932889326, 0.1753747851720878, 0.1913286226668528, 0.1234837653381484, 0.17136397824755736, 0.1587892315749611, 0.19449913182428905, 0.1568798611738852, 0.15888961404561996, 0.214900277821081, 0.14936081107173646, 0.2877399128462587, 0.16628233449799673, 0.19369548851890223, 0.1521764871265207, 0.21638141120118753, 0.21457455387072905, 0.14740953434790882, 0.19692574947008065, 0.1326631906309298, 0.13289117839719566, 0.1386781864400421, 0.1933823853198971, 0.08799422612147671, 0.12161583985601153, 0.07936585268804006, 0.15816732708896908, 0.14641006583614008, 0.15502022738967622, 0.21553284887756619, 0.15219081778611454, 0.11582172076616969, 0.21917050225394114, 0.16215685515531472, 0.17615272557096823, 0.211127121001482, 0.32296139001846313, 0.2834841954920973, 0.10156464150973729, 0.15356638468801975, 0.13212919714195387, 0.16548288453902515, 0.216198043897748, 0.14252630780850137, 0.08851412643811532, 0.2687318128134523, 0.12374299285667283, 0.10610469217811312, 0.12729937130851404, 0.06230898866696017, 0.11697970862899508, 0.07989413969750915, 0.10307940308536802, 0.12438975886574813, 0.07763815325285707, 0.07479099317320756, 0.06796330918690988, 0.10069087161017315, 0.14133842369275434, 0.13635902159980365, 0.09821164714438574, 0.13886319579822676, 0.19519293388085707, 0.14313407162470476, 0.12595557341618197, 0.12489500961133412, 0.1473646696124758, 0.1061630394043667, 0.1574791433023555, 0.10283008896346603, 0.09559930767863989, 0.10755796491035394, 0.12523731695754187, 0.16708331794611045, 0.15849071687885694, 0.20104571910841124, 0.09499634789036852, 0.07846937222140175, 0.12648933620325156, 0.11731962753193718, 0.11037305742502213, 0.1306855460362775, 0.1783937503184591, 0.06579956957804305, 0.09910213614680938, 0.1656863907618182, 0.12095116052244391, 0.11417016653077942, 0.12542341197175638, 0.15814075565763883, 0.11681307399911539, 0.11155978124588728, 0.1251750952963318, 0.09147071386022226, 0.14567411318421364, 0.07935225484626633, 0.14941805228590965, 0.0816713518330029, 0.11091928490038429, 0.11094078767512526, 0.1528857054987124, 0.12396971854780402, 0.1419713475874492, 0.08468022037829671, 0.175405319247927, 0.10459819515900952, 0.1418367533811501, 0.10522802493401937, 0.12500057608953544, 0.12769772564726217, 0.11760812705116612, 0.1404511034488678, 0.1191904435732535, 0.16080154930906637, 0.1061589206968035, 0.13460096450788633, 0.12920955595161232], [0.048721803285713704, 0.02283000450448266, 0.03315406917993512, 0.03701265695105706, 0.014686953243134277, 0.00723743686519031, 0.0650599053395646, 0.04565576816509877, 0.013928820129616984, 0.023656253204015747, 0.010426676133647561, 0.02110107183190329, 0.0414461708361549, 0.08291647037757294, 0.027805864644636, 0.06966681206332785, 0.017852476864520992, 0.00835801030708743, 0.027637491268771033, 0.08375062061739819, 0.04551453449364219, 0.04951705989827003, 0.016564787032880952, 0.039142853181277, 0.053345144127628634, 0.012221342734327274, 0.030943778676113913, 0.03303256730682083, 0.059838829429021904, 0.02777674361797316, 0.04029465280473232, 0.030043230392038822, 0.04049314804641264, 0.054481554576861005, 0.017762988273586546, 0.021588073378162723, 0.10920560399868659, 0.01683677440243108, 0.02595671931547778, 0.023329467346359576, 0.009333489213271864, 0.02261113455252988, 0.031160475619669472, 0.012579567663903748, 0.049357003665396144, 0.0322134703663843, 0.011745382649158793, 0.054453391980912, 0.05988703255674668, 0.04443131101184657, 0.013048232649452984, 0.036027698910662105, 0.042779230911816866, 0.027257106233654276, 0.0278779555976923, 0.044405747205019, 0.018713252818478004, 0.032288295815565755, 0.029805325836475407, 0.020060153312182853, 0.030896671382444243, 0.03686457007591214, 0.01812957360276154, 0.06434745714068413, 0.06115344353020191, 0.10143739583769015, 0.04490721172520092, 0.08923188756619181, 0.04452431441417762, 0.11964405780392033, 0.06903800687619618, 0.05917880484568221, 0.06221233813890389, 0.006451248024989451, 0.09660327487758227, 0.08031377967979227, 0.012455859703810086, 0.03017121905993138, 0.03342716256156564, 0.12376161185758454, 0.1531783983643566, 0.014862722650702511, 0.16245440633169242, 0.07189637635435377, 0.09936550951429776, 0.20778765662440232, 0.10807437755699668, 0.08826432377099991, 0.07147266516195876, 0.061986426689795086, 0.008554359681771269, 0.05596717646611588, 0.04932601497109447, 0.02645754092372954, 0.07449153531342745, 0.1919973732105323, 0.07815491195235934, 0.015966049428763132, 0.07781533910227673, 0.04625185778630631, 0.09238442911633424, 0.07951741026980536, 0.12436884641647339, 0.03887325764766761, 0.045185794455132315, 0.05450060784018465, 0.05914121400564909, 0.019515627263379947, 0.09524552630526678, 0.021947381419262717, 0.024694510170125535, 0.020045671678547348, 0.02861774366881166, 0.025781774327957203, 0.016706906192536865, 0.01950179023801216, 0.009340722396570657, 0.044755572719233375, 0.018714017866711532, 0.0447863374969789, 0.03895200163658176, 0.025369014690763185, 0.02692217456309923, 0.07819540013692208, 0.03028901613184384, 0.0612530524709395, 0.02090950952177601, 0.0991683883060302, 0.013670824152151389, 0.033809428835021596, 0.044676011095621755, 0.03866396352116551, 0.03748558907370482, 0.004103757740397538, 0.046321811354053874, 0.030700001399964094, 0.02331165410578251, 0.027983591625733033, 0.015702825338978852, 0.0014761630050738209, 0.0715114502236247, 0.012397367440696274, 0.02820424103577222, 0.0436006382639919, 0.039255937827484946, 0.06426973773964814, 0.01543520943128637, 0.08128149275268827, 0.028981597894536595, 0.012091874860094061, 0.03120339974494917, 0.048705067219478745, 0.010387902946344443, 0.06532419472932816, 0.03505718348813908, 0.0101376880692052, 0.03982782071190221, 0.038034612113343816, 0.015081857231312563, 0.07315583234386784, 0.023520715834040726, 0.059772584055151255, 0.013155062899126537, 0.04908296372741461, 0.03731076452615006, 0.039056211044745784, 0.004039089112276477, 0.027817905248541917, 0.046373091638088226, 0.04322068579494953, 0.05470222434295075, 0.04569738611046757, 0.06186500284820795, 0.02226179588719138, 0.050775077393544574, 0.05178743128531745, 0.012069878451127027, 0.006386335124261677, 0.019185933883168867, 0.033821194632244964, 0.029563373819525753, 0.0364917286538652, 0.035214182920753956, 0.023303265716614466, 0.05186526942998171, 0.03387239009940198, 0.03195024288392492, 0.05278024336855326, 0.03507604676165751, 0.05140373669564724, 0.05542062668661986, 0.06311554967292718, 0.03561904101765581, 0.03304037045953529, 0.039656745070325475, 0.0344847068855805, 0.029550807350980382, 0.06948964656995875, 0.03837772013087358, 0.05403944830011044, 0.01578299594776971, 0.02461584421273853, 0.045407610945403576, 0.017338871656517898, 0.029253252781927586, 0.0327500422884311, 0.024733408886407102, 0.025146713047953587, 0.07114480382629804, 0.019636191061830947, 0.008008475714762295, 0.05070625697927816, 0.03851310143779431, 0.03316653726090278, 0.018689638103491495, 0.015952395607850382, 0.0442364120057651, 0.03374950062217457, 0.04316768203196781, 0.009288990038580127, 0.048211541559015, 0.027119823332343782, 0.022570807520034056, 0.00975339806505612, 0.026629807394264, 0.02539390335524721, 0.04046420852786728, 0.014032733526879122, 0.03851502847724727, 0.02716799931866782, 0.025266986772684113, 0.04676562075370124, 0.04470708460680076, 0.028490229975432158, 0.054593261796981096, 0.04634835903665849, 0.012116420016224896, 0.08435793660048928, 0.04496514504509313, 0.030334220134786198, 0.09336769421185766, 0.12017864840371267, 0.02750039835726576, 0.02508459486333387, 0.019116207624652555, 0.03646216827577778, 0.11235315831644194, 0.01002552792696016, 0.09351898037961551, 0.08424395628805671, 0.08056819638503449, 0.020495579411674823, 0.03432634699025324, 0.020518390062664236, 0.09757049940526485, 0.08049360503043447, 0.042532349337956736, 0.11192422918975353, 0.0351735963486135, 0.012786887253501585, 0.06367049632327897, 0.18637457064219884, 0.12798146185066017, 0.020444300823978016, 0.10752103903463908, 0.04168799053877592, 0.051442172311778576, 0.04326197804350938, 0.058963125704654624, 0.09989986941218376, 0.11005436309746333, 0.17178156226873398, 0.04791260277852416, 0.03033792493598802, 0.07381082898271935, 0.08608212800962584, 0.116321380383202, 0.2242091947368213, 0.034605662538004775, 0.027004955835374336, 0.01826686498575977, 0.03983814801488604, 0.06782720863286938, 0.028825114148535898, 0.0411923953465053, 0.04201152960636786, 0.03691377065011433, 0.03231157295938049, 0.05460814206994005, 0.057228769840938706, 0.058018448895641735, 0.01614665679101433, 0.037145571783185005, 0.009454540708767516, 0.020125984779692123, 0.020565375220030546, 0.022469090031726018, 0.036191558332315514, 0.0748170285618731, 0.0058512373195428935, 0.03806528528886182, 0.06806225994867937, 0.037520153647554774, 0.0486287286372057, 0.01137657935864159, 0.04488753081698503, 0.011369809275493026, 0.035024766477623155, 0.019917840770046626, 0.009838398146842207, 0.07042225902634007, 0.03706694993057421, 0.053416902598525794, 0.026365872539047683, 0.019972990400024822, 0.04349012187282954, 0.03210328645738108, 0.025855020486882756, 0.02539017141264464, 0.02171141577751509, 0.0390756816071059, 0.01689006993547082, 0.04993715789169073, 0.06232084267373596, 0.05925289408436843, 0.01203876083517181, 0.018455555396420614, 0.019538848428055644, 0.10253368451126985, 0.0201720556111208, 0.0024039473667341682, 0.007874259791736091, 0.01895396481268108, 0.036034457119447846, 0.015282578067854047, 0.01290897436306945, 0.03949586781007903, 0.04493441419409854, 0.030569899095488445, 0.053012170030602386, 0.007841578152562891, 0.03820006948496614, 0.01698652877738433, 0.017226738655673604, 0.03997039109734552, 0.07122321533305304, 0.05129865876265934, 0.04915217090664165, 0.04061845989365663, 0.060325189759688716, 0.023296303947323134, 0.07728937268257141, 0.1122082978753107, 0.07609219942241907, 0.12754330464771815, 0.12750639234270367, 0.11368664247649056, 0.12227912140744072, 0.13993617679391587, 0.17121579977018492, 0.07946265249380044, 0.11583204806915351, 0.10647629188107592, 0.14718481712043285, 0.12415042599397046, 0.179582720090236, 0.15784031392208167, 0.18492900606776985, 0.12043734666492258, 0.2312900333532265, 0.10435523891023227, 0.19058219343423843, 0.11887267205332007, 0.16312847658991814, 0.11354865559509822, 0.1842156486319644, 0.2630970680287906, 0.11301512350993496, 0.12652675062417984, 0.16026514023542404, 0.10210459253617696, 0.07176999242178031, 0.13461210605289253, 0.07987716275134257, 0.12604215448456152, 0.10588764918169805, 0.11589416116476059, 0.09493234846740961, 0.2395170261817319, 0.12045466287859849, 0.16940983810595103, 0.09998654547546591, 0.12988853880337306, 0.08587437415761606, 0.14353777281939983, 0.09042937295245272, 0.1256392268197877, 0.20843233274562017, 0.08872772926198584, 0.12394415134830133, 0.1753102293504136, 0.15381478278764657, 0.10540791135281324, 0.14446319958993367, 0.08602990795459066, 0.10567066046808447, 0.0795061940859471, 0.10949976249997105, 0.08767210519207375, 0.17067314817437104, 0.14404587341206415, 0.12957235505538328, 0.11196551804563828, 0.18824693374335766, 0.13958412568484033, 0.118458127869027, 0.22592126072517463, 0.3143687753805092, 0.18969194191907132, 0.14560571685433388, 0.12750713873122418, 0.19835576202188218, 0.26131547934242655, 0.14150076998131617, 0.17073327994772367, 0.1454677571143423, 0.17282514912741526, 0.18744829802640847, 0.09123528935015202, 0.1916283315845898, 0.34696779612983975, 0.22291735905621732, 0.2787793422383921, 0.22098463347979955, 0.329026000308139, 0.17633302589612349, 0.280331803219659, 0.33197955467871254, 0.2049079540052584, 0.19172851049474307, 0.2353512282882418, 0.13643549249640533, 0.15632103330322675, 0.12155796081892081, 0.1653255729803017, 0.1669832340308598, 0.14646852841334684, 0.445366230394159, 0.18588213063776493, 0.13182002944605692, 0.12492789141833782, 0.11009878678513424, 0.2790238048349108, 0.42234519283686367, 0.19302656155611786, 0.16618834382721356, 0.16519201014723095, 0.13616684691182204, 0.18472250072019442, 0.10376484559050628, 0.15388912308428968, 0.07410531996616296, 0.08841601705976895, 0.08304204006812402, 0.1364423321293933, 0.09998109683926616, 0.12175400315650872, 0.0931099798264248, 0.1277110656457288, 0.08816104395581142, 0.18774361003722462, 0.1161986333983285, 0.09781089079167161, 0.10540174346949373, 0.18078489415347576, 0.17369068839720317, 0.18873124489826815, 0.11849947779306344, 0.15757841297558375, 0.17027647660246917, 0.09833509980567864, 0.12102201314909117, 0.09694437443145684, 0.14112761643316063, 0.11187681994800057, 0.1023756197786757, 0.10054797892059598, 0.10883544278996331, 0.09874044305511884, 0.10302280647946255, 0.04994466927434717, 0.12694609883640492, 0.13071302670453275, 0.09733118688953774, 0.12137512277279582, 0.07559662458619901, 0.14785522328955786, 0.11177409653152738, 0.09177794773131609, 0.1501817163079977, 0.08623409271240234, 0.0885280906887991, 0.10510483011603355, 0.11944965752107756, 0.17850633284875325, 0.15063819395644323, 0.10506163457674639, 0.17054003317441258, 0.09328607323446444, 0.12264791876077652, 0.09573679244411842, 0.21959928210292542, 0.08438907457249505, 0.21470696319426807, 0.09936339927038976, 0.2408110196036952, 0.0652634319184082, 0.11753286394689764, 0.11536273253815514, 0.06759437612657036, 0.09160500951111317, 0.13286820320146425, 0.10904549009033612, 0.15370956914765493, 0.17680099792778492, 0.14980223881346838, 0.18079774560672895, 0.17405336536467075], [0.03760605618091566, 0.046566565720630546, 0.07656827316220317, 0.021061311376148036, 0.05322677030095032, 0.0024229834546401563, 0.06397473785494055, 0.059195496807140965, 0.006220611003560147, 0.027349700818636587, 0.03118589354146804, 0.02693838137201965, 0.024630554851942828, 0.047536253330430815, 0.016956030324633633, 0.04297406206439648, 0.050680781382003, 0.05498889860297952, 0.05301701816331063, 0.03655082226863929, 0.02637328383778887, 0.041416607065392394, 0.02439211425371468, 0.025781055080837438, 0.02791792979197843, 0.029632167092391422, 0.07579971011728048, 0.07656059893114225, 0.0264793744842921, 0.05469036355082478, 0.004192351089191756, 0.049186786370618005, 0.03410434390285185, 0.046142108139715025, 0.10267785963203226, 0.04811463997300182, 0.06545205786824226, 0.05907627141901425, 0.08643711038998195, 0.03633476314800126, 0.020290297123470476, 0.03227227899645056, 0.06612804159522057, 0.002288906419250582, 0.0526050659827888, 0.05327902089006134, 0.028078496622453843, 0.030037082864769866, 0.05620322522840329, 0.022592715719448667, 0.056575737560966184, 0.04663956251793674, 0.05438102622117315, 0.034171959917460165, 0.09949016318257366, 0.05218395357951522, 0.03193175619734185, 0.062132773122617176, 0.11208390883569207, 0.03334827947297266, 0.044927306539778195, 0.0774100162088871, 0.03413607559299894, 0.057723075816673894, 0.13675015632595333, 0.2100980140800987, 0.10972726850637368, 0.033681185716497045, 0.42468043895704405, 0.3694500768823283, 0.18711148681385176, 0.013407156470098665, 0.10791842985366072, 0.11341229041240045, 0.04669346533981817, 0.06035082481269326, 1.535026648214885, 3.5083413209233965, 4.945018172264099, 5.224753950323377, 2.9692266838891164, 2.399546269859586, 7.236727748598371, 13.948703220912389, 18.96347870145525, 18.288490738187516, 15.12423767362322, 19.030768530709402, 22.3459312575204, 12.461803487368993, 4.221671615328107, 0.7813807342733655, 0.3854155716087137, 0.4694519436785153, 0.38775293475815226, 0.3526069378214223, 0.19927812181413174, 0.20192059502005577, 0.020516296782131706, 0.026113449030422738, 0.019575742073357105, 0.21885439993015357, 0.0741416419457112, 0.08817269440208163, 0.08259365055710077, 0.032109959849289486, 0.021981728861906698, 0.07906775868364743, 0.02134763788697975, 0.016637285106948445, 0.03681601071730256, 0.037466328857200484, 0.10002778683389936, 0.02490284077690116, 0.040997143502214124, 0.009801903989032974, 0.035664937126317194, 0.04670075959126864, 0.040469721624893804, 0.015840299926432114, 0.006286992084434522, 0.0917674982920289, 0.09720427369964973, 0.04497386082740767, 0.024654773463095938, 0.04592696164867707, 0.010080155084973999, 0.023851394786366394, 0.10884479978787047, 0.05137916015727179, 0.022587065219080875, 0.009836644981987774, 0.0766790643600481, 0.07392785591738564, 0.04576105983661754, 0.017964257027155588, 0.00949021808004805, 0.03879498184791633, 0.05951119200991733, 0.044451202265918255, 0.04666426119261554, 0.04191077733412385, 0.03291702297117029, 0.027969836024567485, 0.031652067455330064, 0.03515248033883316, 0.012240214489533432, 0.012634112549546574, 0.006558877249647464, 0.05144859464573009, 0.037573920762432475, 0.1002135629366551, 0.03453448760722365, 0.060292192601731846, 0.051320687402039766, 0.03546179731243423, 0.05491509774167623, 0.04757396969944239, 0.05876101726400001, 0.04478656141353505, 0.01816740701906383, 0.022408579975100498, 0.04830145084166101, 0.0818944541471345, 0.027679063413026075, 0.047168144690138955, 0.0980504204386047, 0.05227633951497929, 0.03154241619631648, 0.028592315568987812, 0.040036113999251804, 0.043349661731294224, 0.04447255915563021, 0.03237280056678823, 0.03287858396236386, 0.03386939775996974, 0.033758766017854214, 0.01599506358616054, 0.03404518582725099, 0.023909686033480933, 0.06870749925396272, 0.03579358058050275, 0.04536219998928053, 0.002820655865694529, 0.030643391223358254, 0.0628266701740878, 0.05014867422037891, 0.0463665777019092, 0.05819091892668179, 0.0452432324444609, 0.03561281206618462, 0.052860914396920373, 0.013022728214439536, 0.006820759960516755, 0.03677739189671619, 0.019376480087105716, 0.07585838982569319, 0.08724529309464352, 0.0063853877197418895, 0.025286799995228648, 0.05592883923756225, 0.07146767792957169, 0.04905496737254517, 0.008217771537601948, 0.05845900811254978, 0.08994059025176934, 0.023986039882791892, 0.1227066663226911, 0.04308222393904414, 0.06606392003595829, 0.04654242005199194, 0.045066514784204106, 0.03536424094012805, 0.030291896512998, 0.06412821569080863, 0.013434944175449865, 0.02856208344123193, 0.033485821913927794, 0.01761273687173213, 0.028982052512999092, 0.0666229243257216, 0.024062329271276082, 0.04276076118860926, 0.024221354130921618, 0.06867895328572818, 0.01966203815702881, 0.007876230087796492, 0.0959324480167457, 0.019532251371336833, 0.014506313650469695, 0.015553942881524563, 0.02387770328537694, 0.04324574748586331, 0.021754747023805976, 0.030026850556688647, 0.03245850632499371, 0.03814267899308886, 0.0228593799817775, 0.011950976215302944, 0.04450377855183823, 0.13797993319375174, 0.19130225479602814, 0.12135598808526993, 0.1015274849321161, 0.16991970288966382, 0.27228872052260805, 0.15993430013103144, 0.05145512893795967, 0.04054492026833551, 0.05266923503950238, 0.08395411326949086, 0.0687705622985959, 0.7374829926661083, 2.9238258515085493, 4.127157875469752, 3.5424348286220004, 1.9724192236151015, 1.3507883229425974, 5.570992239883967, 13.280111942972455, 18.548867532185145, 16.01064716066633, 15.12207852091108, 17.8570944581713, 20.24076431138175, 9.848563415663582, 3.1411774456501007, 0.516226130936827, 0.07015201209911279, 0.09134240967354604, 0.2865636045379298, 0.20798247759895666, 0.1183449210865157, 0.07368133735976048, 0.06197968205170972, 0.010059875369604145, 0.04593366218198623, 0.17259170593959944, 0.10969012549945287, 0.1171661021986178, 0.03717502020299435, 0.04682190862617322, 0.05784865229257515, 0.02269082170511995, 0.034815370570868254, 0.0401174974893885, 0.010550480784981378, 0.022708238002711108, 0.04389425393726144, 0.06949777541948216, 0.019709196340824877, 0.04128770576789975, 0.028358790956969773, 0.06401090377143451, 0.07653782729591642, 0.0399488170764276, 0.01854499988257885, 0.014155590773693152, 0.0654132320944752, 0.04390545315774424, 0.06496712924646479, 0.013424180065547782, 0.01543715682678989, 0.044229124539664814, 0.056326443795114756, 0.04878297321764486, 0.04071240985233869, 0.027599925873801112, 0.03077776829845139, 0.05810299435896533, 0.022232067571686845, 0.0042157363745250875, 0.022796481481886337, 0.013274727638677826, 0.059626203695578237, 0.031036140862852335, 0.00933886575512588, 0.052790278901479075, 0.04596512585080095, 0.031533330612416775, 0.030793588342411176, 0.06378488375672273, 0.032328085109059296, 0.025112104369327426, 0.015590592254219311, 0.026543380692601204, 0.0691287609349404, 0.09634272421577147, 0.025020544550248554, 0.04244201257824898, 0.051314567016171556, 0.05209129962271877, 0.036342980207077095, 0.01077179261483252, 0.029297133641583577, 0.04194044967048934, 0.02106794066328023, 0.018824412121570537, 0.03272924179743443, 0.06708241466964994, 0.04225704053949032, 0.01404184625217957, 0.06411005130835942, 0.020005410803215842, 0.012083141266235282, 0.03154108966035502, 0.009979792122196938, 0.03729088345010366, 0.004527186916675419, 0.02385868225246668, 0.017303633636661937, 0.03570711825575147, 0.08863188619060175, 0.11893272240247045, 0.19104897124426706, 0.09868165478110313, 0.1448225245944091, 0.06457180117389985, 0.18259426206350327, 0.09013522123651845, 0.1341424241129841, 0.13743707803743227, 0.19516728525715216, 0.11354486258434397, 0.17993474405791077, 0.1376594611044441, 0.1812620535492897, 0.1390631329268217, 0.15472567533808096, 0.09702303699616875, 0.12309587400938783, 0.11038334401590483, 0.11857928708195686, 0.25970979407429695, 0.08359958550759725, 0.06350175823484148, 0.10909519278045211, 0.14126765249030931, 0.1666358241013118, 0.16305720327155931, 0.11288182530552149, 0.12973562415157044, 0.1411875853581088, 0.21071653946169785, 0.1172267496585846, 0.19112985261848994, 0.14567696303129196, 0.18020058050751686, 0.10630711274487631, 0.13169961662164756, 0.1701329257339239, 0.18992724429283822, 0.08741859772375651, 0.12143621806587492, 0.17958478283669266, 0.09187580605170556, 0.23160359795604432, 0.12294788552182061, 0.19786227707351955, 0.06293814669230155, 0.13228036117340836, 0.11397919963513102, 0.11141042890293257, 0.11849563728485789, 0.19516191125980445, 0.13487100787460804, 0.15827458990471704, 0.0965823285015566, 0.12249883104647909, 0.13684744467692717, 0.1349743487579482, 0.12250914477876254, 0.12187957284705979, 0.15958478674292564, 0.08466835280082055, 0.15812708996236324, 0.3165916289602007, 0.34174405357667376, 0.40012469089456965, 0.16745257670325892, 0.5295046812721661, 0.4840439206787518, 0.28942039981484413, 0.14643414025860174, 0.21277495686497006, 0.14896548299917153, 0.21699558038796696, 0.5682704182607787, 3.0749496051243375, 6.333719449383872, 7.476203492709568, 8.022679311888558, 5.719250295843397, 4.4278194563729425, 12.606629133224487, 23.715351717812673, 30.668931688581193, 25.635152884892054, 24.60049663271223, 28.697411605290004, 33.553757735661094, 18.81370506967817, 6.860099341188159, 1.456779184085982, 1.0843820124864578, 1.12480728328228, 0.9889325456959861, 0.3439955956169537, 0.28710998807634625, 0.22749429488820688, 0.09933232915188585, 0.14111389645508357, 0.14579124189913273, 0.2580563399408545, 0.20107845163771085, 0.2117826265415975, 0.21387685702315398, 0.16313798965087958, 0.11711146655891623, 0.20630061998963356, 0.13217157843921865, 0.082268625497818, 0.15332751322005475, 0.14298456321869576, 0.22813704396997178, 0.08831444036747728, 0.11497231705912522, 0.13073150999844074, 0.11936318501830101, 0.19294593802520207, 0.14699876281831945, 0.1422585036073412, 0.10714078122483832, 0.13336360161857946, 0.20534062864524977, 0.11894547886082105, 0.1580853329173156, 0.12015637888440064, 0.10094756819307804, 0.08958902090255703, 0.15297098377985613, 0.16170351233865532, 0.1943140546126025, 0.14461380722267286, 0.14882312635225908, 0.1644900520997388, 0.07042999432555266, 0.09137941697346312, 0.1805040349385568, 0.1735630559601954, 0.1542705683303731, 0.10083110444247723, 0.18639500811696053, 0.09418199051703725, 0.11691024021378585, 0.06259482154356581, 0.11244059433894497, 0.2112639272319419, 0.09499115031212568, 0.08422547299414873, 0.1600658137883459, 0.2382681689092091, 0.13170893969280378, 0.1984343770891428, 0.08988862125469105, 0.1271685226155179, 0.16613332820790155, 0.10894958595080034, 0.17432236378746374, 0.1364737618714571, 0.13425063687775815, 0.15227118347372326, 0.07676424086093903, 0.11434376292995044, 0.11811860251639571, 0.15525493265262671, 0.11019340849348477, 0.0824173196618046, 0.18992154459868157, 0.11627196946314403, 0.10108750925532409, 0.12973626197448798, 0.10237367238317217, 0.15962910865034374, 0.08247664397848503, 0.09622216211365801, 0.13473979277270182, 0.10187816540045397], [0.031693766824901104, 0.10154585287507091, 0.022493775135704448, 0.0457509394868144, 0.011765925296848374, 0.056177379829542975, 0.01922696319940899, 0.03837928754676666, 0.024902610074994818, 0.02849660481193236, 0.03278392154191222, 0.09172776328133685, 0.0595161249595029, 0.036448132778917036, 0.012967169767112603, 0.016315106502068893, 0.01533339694807572, 0.004321046281672482, 0.0738371629267931, 0.0105094913326736, 0.02302252354898623, 0.023271442424239855, 0.00998637221554028, 0.040372775934104405, 0.011311320405054306, 0.009448798606172204, 0.029971224255859852, 0.016850294212677648, 0.04563564620912075, 0.05712477077863046, 0.03188956488988229, 0.024352942427088107, 0.03133932387988482, 0.06017679415111031, 0.019036769833681837, 0.04124076810798474, 0.07888559917254107, 0.020767132518813014, 0.04268349301336067, 0.011545411593812917, 0.012872943305410445, 0.02693850520466055, 0.01636163025562252, 0.026864056342414448, 0.011544928985780903, 0.03942252495991332, 0.01904815565129476, 0.017998526438272426, 0.030281046738049815, 0.011463112929569823, 0.018250230699777603, 0.012393642283443893, 0.037227474352610965, 0.02494427382147738, 0.06438219134828874, 0.05350720543148262, 0.050627624948642085, 0.06387621457023279, 0.02313135886963989, 0.07604764681309462, 0.02254028701489525, 0.026445452822372317, 0.06811760126480035, 0.0962231188480343, 0.13744580399777206, 0.12039759808353015, 0.09383734901036535, 0.2599034479686192, 5.966087656361716, 18.10860882486616, 24.92965885571071, 44.35137299128941, 43.07317195619856, 43.45631647109985, 45.73042712892805, 73.40220819200788, 85.4533861705235, 94.0888158253261, 93.7171219417027, 93.79319081987653, 87.18286228179932, 92.4138274874006, 102.48421301160539, 121.94288635253906, 116.83209718976701, 110.80531311035156, 112.9172180720738, 121.3445908682687, 113.8869434084211, 101.12459645952497, 93.68179035186768, 79.35427829197475, 77.77365343911308, 74.78237751552037, 81.38444464547294, 49.78078917094639, 32.28209148134504, 22.00954638208662, 9.478726438113622, 3.0728460380009244, 0.26464847049542833, 0.1394094843417406, 0.23656238615512848, 0.2841348834335804, 0.03164032879950745, 0.11268688898001399, 0.08180377472724233, 0.09405065327882767, 0.016202043908249055, 0.029429780452379158, 0.06301704674426999, 0.035870407707989216, 0.050422347749450376, 0.015195321857130953, 0.08724663659398045, 0.03954662562214902, 0.07694542328161852, 0.032571974343487194, 0.028629780880042484, 0.0491168056614697, 0.04065825257982526, 0.006818650140693145, 0.035507985191153627, 0.024250724519203817, 0.01263364011953984, 0.021045391248272996, 0.04480424064344593, 0.00914179374064718, 0.03502307353275163, 0.03190375644979732, 0.0678589301449912, 0.03113551570900849, 0.034535074540014775, 0.023466969075213586, 0.02154678282594042, 0.01753331265146179, 0.036198815264339955, 0.013662779271336538, 0.03184547707704561, 0.028487023897469044, 0.033781778533011675, 0.046595372924847264, 0.07315661944448948, 0.015553515404462814, 0.008327495739130037, 0.01910473359748721, 0.00403340214065143, 0.009243203343690505, 0.03776459928069796, 0.04398855334147811, 0.05612897653398769, 0.06634602775531155, 0.025673130693446313, 0.04212995771584766, 0.05382424074092081, 0.04764502588659525, 0.045689213156167946, 0.020123348671144674, 0.011611985208998834, 0.06523752545139619, 0.05396091126437698, 0.03331074970109122, 0.027788456828732575, 0.05613696289115718, 0.03031452904854502, 0.038322243107748885, 0.035857013426721096, 0.019824255523937087, 0.035780946258455515, 0.01995484298095107, 0.0239942450675049, 0.014538165780582597, 0.00645352917490527, 0.05728587534810815, 0.04080131829583219, 0.04493103508970567, 0.07144007512501307, 0.043968617982630215, 0.04034507813464318, 0.09380065383655684, 0.10576927874769483, 0.027210538375324438, 0.01747524192822831, 0.007898904183613402, 0.04460955537589533, 0.006049234686153275, 0.034072812380535264, 0.043322198026414425, 0.08020995025123868, 0.021006263526422635, 0.037537758238613605, 0.06149531661399773, 0.01472167727271361, 0.03951771663767951, 0.040065996681473086, 0.07293367319341217, 0.05069650982373527, 0.02144222566857934, 0.032270955853164196, 0.04325089756665485, 0.03163531442571964, 0.07113142311573029, 0.030842768560562814, 0.03925460111349821, 0.01783740320908172, 0.042593034117349556, 0.03503421847043293, 0.036373286973685026, 0.02565117838925549, 0.007136998415392424, 0.06952067597636155, 0.026684521065492715, 0.04754520660000188, 0.020520866715482304, 0.09618770610541105, 0.01796988208246018, 0.06437886652669736, 0.017809121869504452, 0.006229270806735647, 0.04017269631315555, 0.04558912245556712, 0.005729396178919289, 0.06975141180945293, 0.04413795318188412, 0.04519412347248622, 0.051436767780355046, 0.031024022227419273, 0.07463142887822219, 0.04646888042667082, 0.05013449623116425, 0.04574961634352803, 0.06812010505901915, 0.031132299453020096, 0.04487449615927679, 0.05017444837306227, 0.013841819217694657, 0.03677322229902659, 0.0662723049255354, 0.03957743789734585, 0.072911362961999, 0.14020828290709428, 0.1806353721767664, 0.09409099218568631, 0.10181386063673667, 3.6916169949940274, 14.828939233507429, 22.092179570879253, 45.31717259543282, 43.762554849897114, 43.68405062811715, 47.391470432281494, 76.63967268807548, 95.28719942910331, 102.60750879560197, 103.10682719094413, 104.1115506035941, 98.26075049809047, 100.97789914267403, 114.84010423932756, 137.7999540056501, 128.59058925083704, 125.8784294128418, 128.9847744532994, 137.58747809273856, 132.26800673348563, 115.13390186854771, 103.2458745411464, 82.95532117571149, 83.353682245527, 78.13773904527936, 86.16965511866978, 52.247809614454, 35.08595364434378, 22.222885608673096, 8.491811258452278, 2.58722471339362, 0.1885310634970665, 0.12413522680955273, 0.1544420477002859, 0.09983313549309969, 0.08156997191586665, 0.030783542631460086, 0.07292654857571636, 0.018646793706076484, 0.052816483923899274, 0.040896611753851175, 0.07507919413702828, 0.08094005393130438, 0.08087489421346358, 0.060352948627301624, 0.03484154166653752, 0.028771601484290192, 0.03908097757292645, 0.04079213771702988, 0.07378670027745621, 0.011183055234141648, 0.012094019030752991, 0.040195746147739034, 0.017975614007030214, 0.07288088316896132, 0.007654598498317812, 0.04880154472110527, 0.1407635145421539, 0.026343759082789932, 0.03470191273040005, 0.02381631452590227, 0.0634072654481445, 0.0017194742124827045, 0.016980011448530213, 0.0837798790474023, 0.03780828336519854, 0.028803587625069276, 0.03956514623548303, 0.01951932019021894, 0.021698540575536232, 0.03116260961230312, 0.05500866772074785, 0.05652905435168317, 0.05577233513551099, 0.036650997786117454, 0.02149349238191332, 0.04876284786899175, 0.040029026700982025, 0.047639159951359034, 0.02161756929542337, 0.06917760188558272, 0.020953363240031258, 0.06955619728458778, 0.03125059185549617, 0.05068971090284841, 0.0491581725488816, 0.026676566938736608, 0.08495836545314107, 0.013083853193425705, 0.04525988030114344, 0.019420720570321594, 0.06136874947696924, 0.05624297720247081, 0.07386681490710803, 0.06048467941582203, 0.033179822976567915, 0.04982239387131163, 0.06886211702866213, 0.0373747503784086, 0.012557652679138949, 0.020602043252438307, 0.01159488782286644, 0.045994594626660855, 0.06850095997963633, 0.049704725721052716, 0.010862179416497903, 0.034234744762735705, 0.18236118528459752, 0.204477423535926, 0.1373643662248339, 0.1575209546302046, 0.20719532269452298, 0.16525552102497645, 0.12296715591635023, 0.057366302103868554, 0.08057385536709002, 0.10400694688516003, 0.10468421304332358, 0.13473910066698278, 0.17151715074266705, 0.11161168917481389, 0.15031362351562294, 0.12886922992765903, 0.09380562071289335, 0.10789703564452273, 0.14827375725976058, 0.20721567874508245, 0.11731665554855551, 0.07750881090760231, 0.08332675336194889, 0.15602382139435836, 0.13415494986942836, 0.19283313836370194, 0.18115419362272533, 0.16753946989774704, 0.1696108201784747, 0.18736945225724153, 0.149385754019022, 0.12845685705542564, 0.09383193430091653, 0.10096238061253514, 0.10383972192981414, 0.14247286639043263, 0.16264044706310543, 0.06717062422207423, 0.19748160535735743, 0.11744401657155581, 0.15515772572585515, 0.14913515746593475, 0.10542009784174816, 0.10362037869968585, 0.11663243440645081, 0.09828019275196961, 0.1360362424914326, 0.12222052312323026, 0.16258803701826505, 0.15128771481769426, 0.10859712772071362, 0.15370308235287666, 0.12027782308203833, 0.19743366007293972, 0.14110027147190912, 0.13308553796793732, 0.1451544232134308, 0.14429265659834656, 0.07258470941867147, 0.12376733869314194, 0.11074138658919505, 0.15311828016170434, 0.14484568977994577, 0.18469017531190599, 0.2381389487002577, 0.19022509402462415, 0.12214806915393897, 0.6767019970076424, 10.145627566746303, 27.99483929361616, 37.72168329783848, 62.48570578438895, 63.87565817151751, 63.1760926927839, 68.27381924220494, 102.55412578582764, 119.37155260358537, 127.8071242741176, 127.69471631731305, 126.71118491036552, 122.8776969909668, 125.38970702035087, 140.3210244859968, 161.7469482421875, 152.43290192740304, 148.08056422642298, 150.6990623474121, 163.5571346282959, 152.96174321855818, 137.76358713422502, 131.36696434020996, 108.52628312792096, 108.74786812918526, 105.37797791617257, 112.72792829786027, 76.65962791442871, 52.545571190970286, 36.650191170828684, 14.126753415380206, 4.313814282417297, 0.5985220064009938, 0.15869568873729023, 0.36832604291183607, 0.3462712120796953, 0.07553582784852811, 0.20614889955946378, 0.2033389639109373, 0.18568532834095614, 0.14299886673688889, 0.2064981958163636, 0.11282452302319662, 0.175635532609054, 0.19077286177447864, 0.1568387962345566, 0.18118506696607384, 0.1291092141930546, 0.12628094452832425, 0.18316391935305937, 0.1557921152561903, 0.16910212247499398, 0.1342394681913512, 0.17035627232066222, 0.09949407832963125, 0.20543978975287505, 0.21582376398146152, 0.171407445200852, 0.17837380138891085, 0.1159988726888384, 0.1585041925843273, 0.11169544075216566, 0.12254795698182923, 0.10514238702931575, 0.0991213997559888, 0.1835943819688899, 0.1518556893404041, 0.07019245278622423, 0.1359977424144745, 0.08230903225817851, 0.13995159310953958, 0.13835649298770086, 0.16265875393790857, 0.1109215376366462, 0.18508282995649747, 0.11684332309024674, 0.11792861271117415, 0.12259035184979439, 0.15329974756709167, 0.14213853861604417, 0.22446365893951484, 0.18311553980622972, 0.1440841970699174, 0.14963709696062974, 0.13046165662152426, 0.10596742454384055, 0.09887712714927537, 0.0854477791913918, 0.12038925210280077, 0.11149206345102616, 0.15565387053149088, 0.16578794031270913, 0.17518457823566028, 0.20447754567222937, 0.16191328822502069, 0.19375487390373433, 0.09758003960762705, 0.16782362679285662, 0.15127856816564286, 0.16449013352394104, 0.1592629168714796, 0.18715960851737432, 0.10243567691317626, 0.19430443298603806, 0.08409480072025742, 0.13874435717506067, 0.11177410331687757, 0.10991448310336896], [0.03318183144022312, 0.021547787057768022, 0.03371864424220153, 0.07607514783740044, 0.03746073433597173, 0.02208650654314884, 0.012135302797625107, 0.027311385642471056, 0.047886231515024386, 0.009791918498064791, 0.040027927474251816, 0.10024239388959748, 0.04597367199936083, 0.008747653952533645, 0.10260681701557976, 0.023060088943956152, 0.024640902510977218, 0.02570738992653787, 0.01743893351938043, 0.03864731566448297, 0.06460276272680078, 0.015341608918138912, 0.03329117057312812, 0.04717213108337351, 0.058870546386710236, 0.017220428280000175, 0.05781722255051136, 0.010865366834748005, 0.013397651042656174, 0.03814273327589035, 0.03312279210825052, 0.035335030007575235, 0.05548981690247144, 0.02519072961461331, 0.03690426776717816, 0.015535366289051515, 0.014055799476669302, 0.04034284236175673, 0.06129427347332239, 0.025862484372087886, 0.08977752471608774, 0.05832071589039905, 0.035636767745018005, 0.06881009374878236, 0.054889438939946036, 0.013543918595782347, 0.08965097114975963, 0.027934689606939043, 0.03681138650115047, 0.0686640323006681, 0.044883530853050094, 0.08051645808986255, 0.08882732463202306, 0.057126080351216454, 0.018673779043768133, 0.07045430623527084, 0.06302693978484188, 0.07082922397447483, 0.0847958902429257, 0.0762444491099034, 0.26134652910487993, 1.093544840812683, 4.042275641645704, 11.354000074522835, 15.033509833472115, 26.336599588394165, 33.41727079663958, 52.60168831689017, 83.38390690939767, 92.72390474591936, 102.75320557185582, 106.95455196925572, 92.16052395956856, 100.29437010628837, 101.59792164393834, 88.79986790248326, 88.45793315342495, 80.36656829289028, 98.97401782444545, 96.66793850490025, 99.68351922716413, 91.23948465074811, 105.85848058973039, 87.62890189034599, 98.4272849219186, 101.2463983808245, 91.47504247937883, 98.05880110604423, 85.11715589250836, 94.60009207044328, 109.11724826267788, 112.26662349700928, 109.73173999786377, 101.71921634674072, 103.19563906533378, 105.01152297428676, 102.60850933619908, 105.86700602940151, 79.26391002110073, 69.78719942910331, 59.2908615384783, 40.72595930099487, 21.667788812092372, 7.938723359789167, 1.592861716236387, 0.07121097456131663, 0.15439407527446747, 0.0815110072227461, 0.042417911014386585, 0.05303271607096706, 0.0673686410965664, 0.04133499287334936, 0.023164459504187107, 0.020583785571424023, 0.04700470596019711, 0.06202903190361602, 0.05876775511673518, 0.019491988799667785, 0.038082872916545184, 0.0341236482241324, 0.03927154074023877, 0.04012877813407353, 0.014216340013912745, 0.006146609550341964, 0.03966618688510997, 0.010780848512825156, 0.013590727334043809, 0.04210094016577516, 0.02754566851737244, 0.015464464468615395, 0.055965011939406395, 0.04506829593862806, 0.03758193426100271, 0.06442532581942421, 0.020682834720771228, 0.06705507649374859, 0.009939943456889262, 0.04964218514838389, 0.07799272851220199, 0.01608353776724211, 0.013268460519611835, 0.016145445606006042, 0.07275196151541811, 0.06373309796409947, 0.029099235510719672, 0.0961564527824521, 0.08896140993705817, 0.00488510268873402, 0.013490401690692773, 0.02866388065740466, 0.06243601042245116, 0.01656326711443918, 0.011758731129313154, 0.01181463393316205, 0.021475192292460372, 0.01199239314467247, 0.058813162680183134, 0.06627158567841564, 0.058003168287021775, 0.015963920525142124, 0.07076427460248981, 0.0856874513306788, 0.01385334667949272, 0.039817445911467075, 0.15876781700977258, 0.034732670722795386, 0.028270332042926123, 0.046472239175013134, 0.057815431218062124, 0.08549820112862758, 0.03746793698519468, 0.11234943994453975, 0.08182202053389379, 0.03226289824981775, 0.051745399433587275, 0.044581219753516574, 0.0216103004890361, 0.024401927566421882, 0.024774482307423438, 0.031778139261794944, 0.03602003485762647, 0.016931886352332573, 0.1096177122422627, 0.03838340964700494, 0.02372980470369969, 0.02179626658159707, 0.025168953729527335, 0.07131966230060373, 0.07091470581612416, 0.004708533033928168, 0.059831779450178146, 0.04260536649131349, 0.05994558334350586, 0.026942525524646044, 0.032090289119098864, 0.03645329982308405, 0.04199513280764222, 0.025792318762147, 0.017428660499198095, 0.05240496939846447, 0.058514349428670745, 0.06153271746422563, 0.04738146252930164, 0.044141308537551334, 0.030869889605258192, 0.06302114509578262, 0.015652277872764638, 0.054724843307797394, 0.015512326632493308, 0.042468085286340544, 0.03916330422673907, 0.0049901729882029545, 0.02365614633475031, 0.030563127316002334, 0.04723853252029844, 0.05753261782228947, 0.03233580344489642, 0.003524545405525714, 0.06331970728933811, 0.028256439038419297, 0.06196976186973708, 0.013337782201623278, 0.045136780478060246, 0.03426769781591637, 0.10753602108785085, 0.012921525564576899, 0.0058314766834623045, 0.0722155524417758, 0.044302867725491524, 0.034530375685010634, 0.056937712244689465, 0.046886498374598365, 0.03834988323173352, 0.09540660373334374, 0.0122012860873448, 0.07247357895331723, 0.14337645790406636, 0.5130886392933982, 2.6027139851025174, 9.261817574501038, 12.296385986464363, 23.4828337260655, 31.981293542044504, 58.57709394182478, 93.81404931204659, 110.14366395132882, 118.86094338553292, 128.01601491655623, 109.97578852517265, 121.54489353724888, 119.72614697047642, 113.70533834184918, 108.46636881147111, 101.81788076673234, 117.55929565429688, 112.55067975180489, 112.93991783687046, 113.79827049800328, 122.30031558445522, 109.24483108520508, 121.1343661717006, 116.68885312761579, 109.75817789350236, 110.50753416333879, 105.35811301640102, 114.5056596483503, 128.47052437918526, 132.3136008126395, 125.77984837123326, 121.87276513235909, 122.14120183672223, 125.67973872593471, 121.88229806082589, 130.22031702314104, 95.12123475755963, 84.54916150229317, 69.90542997632707, 49.53611183166504, 25.6856141771589, 9.821040732519966, 2.0918585402624945, 0.09005867570106472, 0.09156925750098058, 0.09684768997664962, 0.04386596581233399, 0.017689742114660994, 0.07298178811158453, 0.007972870437827493, 0.03611115532528077, 0.053844528937978406, 0.019333335437944958, 0.045727845547454696, 0.08673141138362032, 0.04523384830515299, 0.012045390122304005, 0.021965087790574347, 0.039859762747905085, 0.012298883171752095, 0.03982801748705762, 0.03944511339068413, 0.025407304421865513, 0.06734781685684409, 0.03869466383808425, 0.034485762007534504, 0.029915994898016964, 0.01835809401901705, 0.0555172500732754, 0.041636343845831494, 0.017669704975560308, 0.06344626764101641, 0.05185903369316033, 0.059985494773302755, 0.11977650783956051, 0.032414818847818036, 0.046517114088471444, 0.014196330864381577, 0.01167876917004053, 0.016069066311631883, 0.028520563883440833, 0.043225011455693414, 0.042821768272135935, 0.03654839989862271, 0.032905552336680036, 0.05177258154643433, 0.024187559694317833, 0.02584398750747953, 0.03737686401499169, 0.018385917347456728, 0.014828214055991598, 0.014667467413736241, 0.061189175184283934, 0.10473096410610847, 0.030671177232371907, 0.06968396542859928, 0.05889347408499036, 0.036758009543908496, 0.046041912266186306, 0.040180312868739874, 0.026556471329448477, 0.09549551217683724, 0.09220466483384371, 0.012540878445309187, 0.04891510094915118, 0.022191326632829647, 0.032658141505505354, 0.10304211758609329, 0.06538174806960992, 0.07705320856933083, 0.04172804446092673, 0.031960665181811364, 0.06834230492157595, 0.059181742902312956, 0.09850130695849657, 0.0877227917579668, 0.1154938797865595, 0.12344930932990142, 0.15439452310757978, 0.11060372540461165, 0.19314781576395035, 0.15440185128578118, 0.10068167067532029, 0.14169951288827828, 0.12289966882339545, 0.21482420047479017, 0.1024739598589284, 0.0708315988470401, 0.19784620936427796, 0.10049678345343896, 0.1515064745077065, 0.1439554382647787, 0.06586574709841184, 0.12377284839749336, 0.13277889442230972, 0.2247272969356605, 0.15339316826845917, 0.24025831211890492, 0.21497311176998274, 0.14620442901338848, 0.14518788856055054, 0.10394928497927529, 0.08694504813424178, 0.263069356658629, 0.10940122564456292, 0.135296137205192, 0.12084450838821274, 0.13254269638231822, 0.09917751460203103, 0.12029896623321942, 0.1265352051705122, 0.12825540000838892, 0.11177846629704748, 0.1539734514164073, 0.15621586037533625, 0.13806100455777987, 0.10230695203478847, 0.15591254165130003, 0.1323031870914357, 0.0699131813432489, 0.15945895920906747, 0.08656962827912398, 0.19386863708496094, 0.20224929095378943, 0.1519761157355138, 0.27339801671249525, 0.14416860682623728, 0.15696431164230618, 0.11055886745452881, 0.14782394282519817, 0.16001938842236996, 0.22038464567490987, 0.21423060446977615, 0.19102264408554348, 0.3827118266906057, 2.1926736448492323, 6.812014767101832, 18.79820884977068, 23.61194167818342, 39.584783690316335, 49.15889760426113, 79.34465503692627, 113.20048223223004, 127.15614754813058, 136.4566031864711, 139.71011107308524, 123.05847522190639, 135.28655433654785, 130.70473153250558, 117.64381354195731, 114.51148223876953, 106.12562492915562, 124.94279888698033, 126.27742276872907, 126.25998279026577, 122.85065460205078, 131.94569369724817, 116.18273939405168, 128.42386027744837, 130.7323714665004, 118.81647491455078, 125.93829509190151, 112.34527015686035, 122.08613041469029, 138.48974336896623, 140.11544118608748, 139.24042674473353, 132.34313065665108, 130.74532290867396, 136.79744012015206, 139.01675033569336, 145.0864325932094, 114.1475008555821, 102.88398456573486, 86.94662352970668, 63.190197535923545, 32.9745454788208, 14.827547856739589, 4.110480027539389, 0.29005936267120497, 0.25002962350845337, 0.4134325539427144, 0.20795848460069724, 0.14163144225520746, 0.1413874274918011, 0.08979853894561529, 0.11563288447047983, 0.2374617164688451, 0.31139424070715904, 0.12794357245521887, 0.16981136798858643, 0.16602690677557672, 0.12865205800959043, 0.09346598000930888, 0.18113621244473116, 0.09411496482789516, 0.15784780494868755, 0.10472086750503097, 0.08302968394543443, 0.15000027604401112, 0.12694558314979076, 0.10192630746002708, 0.12582146775509628, 0.08075585881514208, 0.13899655507079192, 0.1347965318709612, 0.18537506141832896, 0.12370556486504418, 0.08659474764551435, 0.15062830091587134, 0.17408079175012453, 0.06808708754501172, 0.13652424487684453, 0.11250003400657858, 0.17933980455355986, 0.10322451458445617, 0.18269739938633783, 0.11146412816430841, 0.11314144637435675, 0.13524139299988747, 0.17691761095608982, 0.14235134076859268, 0.12528862777565206, 0.1106066159637911, 0.14021653389292105, 0.09394146342362676, 0.06527530628123454, 0.065175371643688, 0.11439708221171584, 0.16651739259915693, 0.20388362397040638, 0.18570576581571782, 0.12273179925978184, 0.14616716387016432, 0.13383766689470836, 0.11449726112186909, 0.0741667952388525, 0.19988309006605828, 0.1972701602748462, 0.18270810666893209, 0.13333808870187827, 0.09207913585539375, 0.07456622844828026, 0.22971024098140852, 0.10327467189303466, 0.17295084095426969, 0.12852152144270285, 0.1729074011423758, 0.12437139770814351, 0.2057018806891782], [0.04272620340010949, 0.032928978758198876, 0.028980247609849488, 0.005730651044619403, 0.015043263855789388, 0.0411610673846943, 0.02927867409640125, 0.023611288384667466, 0.028671375076685632, 0.04580925278631704, 0.013684520381502807, 0.016723593064982976, 0.046269431843289306, 0.011089117149822414, 0.03791933919170073, 0.13053795109902108, 0.04251280413674457, 0.028418183127152066, 0.03634358410324369, 0.03483933982040201, 0.054053653430725844, 0.04404465800949505, 0.04212953023878591, 0.11331190115639142, 0.04631598613091877, 0.047159313556871245, 0.022167521928037916, 0.03118442790582776, 0.012191926544931318, 0.029673812179160968, 0.05383558584643262, 0.007545998968583132, 0.04454158652307732, 0.022168185196018646, 0.03179066841091428, 0.03254216290744288, 0.015486221693988358, 0.020309911874522055, 0.06816908171666519, 0.00499024847522378, 0.028445229532995393, 0.027425454164456044, 0.0717997190409473, 0.022503473097458482, 0.01967070983456714, 0.02662175827260528, 0.07886240006025348, 0.05415361520967313, 0.050998729321041276, 0.06027586704918316, 0.06503493525087833, 0.03142225442986403, 0.019910505806495036, 0.04285270607631121, 0.024865176994353533, 0.016206160919474702, 0.04189682326146534, 0.04122665457959686, 1.1943395350660597, 5.972663692065647, 20.771971464157104, 53.65392351150513, 75.43698814937046, 92.14930261884416, 95.28972857339042, 86.80230249677385, 95.27173273903983, 93.05831459590367, 89.58812713623047, 91.8233973639352, 94.07103538513184, 64.88142381395612, 75.59053639003209, 68.57132720947266, 74.69754001072475, 62.07243388039725, 59.57797500065395, 57.63677338191441, 76.96996225629533, 66.95696885245187, 75.29949024745396, 53.36121327536446, 68.4600796018328, 75.62645162854875, 66.57973725455147, 73.5691317149571, 73.54416683741978, 84.31761278424943, 66.62094007219586, 58.400776454380576, 74.70693397521973, 79.48387609209333, 79.10818699428013, 72.77482754843575, 69.4678532736642, 94.4075574874878, 86.73221601758684, 93.57765769958496, 102.18107005528041, 101.51917770930699, 105.65577384403774, 109.00515297480992, 117.78268023899624, 93.67241723196847, 80.18290655953544, 45.69297286442348, 29.591540540967667, 6.430010625294276, 0.5014614803450448, 0.0911784620423402, 0.25856809105191914, 0.12061383362327303, 0.06721586893711771, 0.01970848727173039, 0.09801791182586125, 0.04595272223066006, 0.018322442092799714, 0.011163172461757702, 0.014331117604992219, 0.011296568205580115, 0.016915189301861182, 0.042321470832186084, 0.03483304640810404, 0.036641532222607305, 0.058761234395205975, 0.03385188477113843, 0.019734800859753574, 0.10698297433555126, 0.035434951074421406, 0.05618059608553137, 0.05557671009695955, 0.0489434501422303, 0.06221425160765648, 0.005791529630576926, 0.0299116081691214, 0.06450034465108599, 0.031547790193664174, 0.05011625720986298, 0.07846748589404992, 0.03156190711472716, 0.020034592898030366, 0.03363749823932137, 0.03901749383658171, 0.02126772003248334, 0.06215154818658318, 0.028565852703260522, 0.037686404905148914, 0.03345041934932981, 0.02530693552190704, 0.06465758157095738, 0.017273778095841408, 0.010715106951205857, 0.05067694087379745, 0.017541482213086317, 0.04626949630411608, 0.020229171296315532, 0.05082112277991005, 0.004877212174635912, 0.02933214944122093, 0.045921038037964275, 0.03469723423144647, 0.02258534004379596, 0.02690077356861106, 0.02765826801104205, 0.01943664748354682, 0.010366255134743239, 0.04928127915731498, 0.01870182459242642, 0.05728253695581641, 0.052058980999780555, 0.03420383409996118, 0.03680985640468342, 0.03695341405857887, 0.055462373553642204, 0.025743718691436306, 0.008392881069864546, 0.014909117482602596, 0.041518210899084806, 0.011782345844299665, 0.07710837346634694, 0.01014113417893116, 0.007462393276260367, 0.03774617366226656, 0.08882345019706658, 0.015427292623956288, 0.04484035906248859, 0.059194913267024925, 0.019754700595512986, 0.00890083662566862, 0.07002961795244898, 0.015201214933767915, 0.07665906114769833, 0.039309179077723196, 0.03813120835859861, 0.05020920632939253, 0.06251697322087628, 0.04008959612942167, 0.03647382211472307, 0.08556911482342652, 0.07401243530746017, 0.020238719980365465, 0.03619273219789777, 0.07473521080932446, 0.029644109308719635, 0.09612068720161915, 0.053117641513901095, 0.009093057962932756, 0.01687825664079615, 0.04994826211727091, 0.03249966286654983, 0.04780737556783216, 0.04440794226580432, 0.007123632123693824, 0.06138400972953864, 0.04343342348667128, 0.029210505075752735, 0.022803042915516665, 0.00750629958097956, 0.041236601902970245, 0.01769253089358764, 0.047121427554105005, 0.006347261261128421, 0.06343862733670644, 0.058675420071397505, 0.04372114269062877, 0.049740263992654424, 0.016265546304306815, 0.026609254568549137, 0.006852528970089874, 0.08035591670445033, 0.04744008795491286, 0.04669085976534656, 0.06193542799779347, 0.059647584334015846, 0.6669806529368673, 3.783397052969251, 20.30405718939645, 55.026894501277376, 81.19350119999477, 99.06437219892229, 108.1101416179112, 102.42228371756417, 112.09341880253383, 107.37791265760148, 102.8976308277675, 104.4566467830113, 103.82887009211949, 85.79161058153424, 91.86478083474296, 96.60191672188895, 102.55577945709229, 86.69241673605782, 92.8011895588466, 85.7556814466204, 106.80578408922467, 104.25411374228341, 110.84910065787179, 81.58480290004185, 96.09039034162248, 101.15555763244629, 90.90649918147496, 108.3479437146868, 103.09844071524483, 115.74986662183488, 91.85747132982526, 89.13566044398716, 112.05641269683838, 110.56784452710832, 112.06324972425188, 98.14392348698208, 102.77562046051025, 112.408873966762, 110.13749395098004, 114.66416195460728, 116.38787800925118, 119.65595626831055, 128.40150097438266, 127.16063608442033, 139.4535696847098, 108.27256965637207, 97.9261599949428, 57.54104804992676, 38.51322555541992, 10.186859045709882, 1.3909350144011634, 0.07595775449382407, 0.2571944376187665, 0.08149844753955092, 0.10281678967710052, 0.03197946399450302, 0.02768993184768728, 0.009920422004402747, 0.06596741200025592, 0.007095742638089827, 0.024741505505517125, 0.018075993085013967, 0.05428083034764443, 0.017214058532512615, 0.05907585072730269, 0.02039735298603773, 0.04441901595730867, 0.051530490429805856, 0.05204957311174699, 0.03332073095121554, 0.03306613104151828, 0.01745149150623807, 0.047710833605378866, 0.03873777795316918, 0.017512328956010084, 0.018143858461241637, 0.03557940778721656, 0.05735153718186276, 0.05831823923758098, 0.04412246901275856, 0.04461899719067982, 0.05078237164499504, 0.02229218407800155, 0.035398503565894704, 0.08910162919866187, 0.0527263066199209, 0.05119088026029723, 0.04875970285918031, 0.029774879970188652, 0.04792263152609978, 0.027505366929939816, 0.06175600976816245, 0.024829996649974158, 0.05156282940879464, 0.03754745450403009, 0.025365579607231275, 0.04910414759069681, 0.003555499961034262, 0.07549031850482736, 0.028623192305011407, 0.04091343942231365, 0.03196563545082297, 0.012423638620280793, 0.07667065052581684, 0.018846501829102635, 0.025446942741317407, 0.017326551156916788, 0.02171077286558492, 0.023721307748928666, 0.04658856721861022, 0.051838867632406097, 0.042043125589511225, 0.0808988736410226, 0.03952125859047685, 0.06722487309681517, 0.07726183094616447, 0.013721031502687504, 0.03589574759826064, 0.15352883456008776, 0.14050302494849476, 0.12872829820428575, 0.1577062625437975, 0.11159062066248485, 0.12067514604755811, 0.13721804693341255, 0.16550846530922822, 0.0757180212863854, 0.1831075195223093, 0.09088343501623188, 0.0674697021022439, 0.0906417408425893, 0.1109639053632106, 0.09311489241995982, 0.2817103149635451, 0.13575930520892143, 0.08751923803772245, 0.18199920042284898, 0.14060739720506327, 0.18433211238256522, 0.13737860188952514, 0.11406755846525941, 0.1951014537896429, 0.19558999900306973, 0.0795108081240739, 0.13296731002628803, 0.14256563569818223, 0.15356065785246237, 0.15807397424110345, 0.11796912125178746, 0.0996560649946332, 0.18435702818844998, 0.0609886816569737, 0.1527130183364664, 0.12873395718634129, 0.12685768572347506, 0.13790472437228474, 0.1530157806617873, 0.1006178544568164, 0.09917252736964396, 0.1257291869925601, 0.15007344926042215, 0.08189167893890824, 0.12204132202480521, 0.1392919620765107, 0.16357925454420702, 0.14427954730178627, 0.13753055302160128, 0.2496975213289261, 0.19467962213924953, 0.17357669451407023, 0.07007223673697029, 0.14528932954583848, 0.12813481076487473, 0.14112836282168115, 0.13651498965919018, 0.15373274790389196, 1.3600982576608658, 9.635237216949463, 35.47652925763811, 78.18652234758649, 103.94896275656563, 121.89433234078544, 124.38556725638253, 115.93798909868512, 124.75471115112305, 120.32130186898368, 112.12265682220459, 117.7691729409354, 114.36053957257951, 84.71668257032121, 94.12682941981724, 88.66075801849365, 96.75237301417759, 86.14822687421525, 83.73691013881138, 81.02105385916573, 103.84947844914028, 94.6448871067592, 102.71381623404366, 74.51955495561872, 93.40239633832658, 100.36948708125523, 91.53956345149449, 99.32756996154785, 99.02141843523297, 115.5765438079834, 94.53456360953194, 80.96127155848912, 103.57262052808488, 106.20124217442104, 108.03025817871094, 102.19673129490444, 97.95004790169853, 126.96671186174665, 118.137024470738, 117.7743979862758, 132.07998847961426, 130.6151692526681, 138.25361578805106, 143.51261002676827, 155.71379961286272, 127.45928355625698, 113.74065603528703, 69.0345219203404, 47.58835111345564, 13.385360649653844, 2.2447336741856168, 0.14634989335068635, 0.44825431970613344, 0.314734587179763, 0.1899726925683873, 0.15269777843994753, 0.21249491189207348, 0.1263377514800855, 0.10422813573053905, 0.1096926632204226, 0.1329221331647464, 0.09246063538427864, 0.12557351748858178, 0.2164074940873044, 0.13152801511543138, 0.07787538945142712, 0.21226741267102106, 0.09781833432082619, 0.09574110114148685, 0.1253122950771025, 0.11529775602476937, 0.09953356228236641, 0.1893120708742312, 0.19830367767385074, 0.08945970569870301, 0.11586646336529936, 0.1950675541801112, 0.1257699126643794, 0.20118122255163534, 0.1578796553824629, 0.1833579803683928, 0.11204183287918568, 0.07807014935782977, 0.17033343283193453, 0.14973076193460397, 0.11960405137922082, 0.18433929128306253, 0.10610523500612803, 0.06713125562029225, 0.15141968987882137, 0.06609031504818372, 0.15886403327541693, 0.07182107253798417, 0.17753490140395506, 0.19899513199925423, 0.11434712846364294, 0.16506194855485642, 0.1333902409034116, 0.22749282925256661, 0.12600909625845297, 0.13557154099856103, 0.10523440994854484, 0.14278691953846387, 0.11083095321165663, 0.13700041361153126, 0.09584247427327292, 0.10472397519541637, 0.12836779254887784, 0.09516571701637336, 0.14210724458098412, 0.1688215211033821, 0.16348801872559957, 0.14112164532499655, 0.1256750263273716, 0.17657610428120407, 0.13281261761273655, 0.1969047284552029, 0.17212126404047012], [0.024441888190007637, 0.0575538356123226, 0.02740735763550869, 0.04812206653878093, 0.016678339868251766, 0.03906627032639725, 0.036536596781973324, 0.04675344783546669, 0.050728628278842995, 0.027379288338124752, 0.057195107718663554, 0.03409269006390657, 0.04442386409001691, 0.04322934050911239, 0.0354368102603725, 0.05784812303526061, 0.03128553980163165, 0.06024123462183135, 0.02240752994215914, 0.041116443529192886, 0.0296339855662414, 0.025643887530480112, 0.036016811816287894, 0.03358518997473376, 0.06282781011291913, 0.03674858808517456, 0.037323141004890203, 0.04869660928047129, 0.053490245448691506, 0.03858699729400022, 0.019321744363488894, 0.055234351860625405, 0.037737871786313396, 0.010945661276179765, 0.07663360251379864, 0.052078509237617254, 0.027131161652505398, 0.03471389565882938, 0.05866579844483307, 0.04624802067077585, 0.08080155136329786, 0.03466774509953601, 0.07948152933801923, 0.03116534071575318, 0.07168236640947205, 0.01779216358305088, 0.11714508118374006, 0.025261202261650136, 0.03672809632761138, 0.040186789485492876, 0.02513864526658186, 0.05153433772336159, 0.0837828985282353, 0.02488662548629301, 0.07395357239459242, 0.12023655458220414, 2.5383840884481157, 11.727471828460693, 21.08996445792062, 49.26345409665789, 76.1092472076416, 88.99008873530796, 75.9058803830828, 70.7660824911935, 68.07070255279541, 74.8323142187936, 76.62730489458356, 65.30522918701172, 58.53389004298619, 52.219919545309885, 45.360807282584055, 27.18877877507891, 23.050226722444805, 24.64717984199524, 21.21435979434422, 20.60080259186881, 16.98718867983137, 14.786906106131417, 17.2565564428057, 23.32982223374503, 19.992687565939768, 24.59140317780631, 31.055730955941335, 23.469401121139526, 25.28622129985264, 19.54194402694702, 21.976142917360576, 11.870581269264221, 19.96512927327837, 35.9985682623727, 15.758283376693726, 18.79823316846575, 25.384154421942576, 21.360232012612478, 12.896045054708209, 32.716631821223665, 45.374818325042725, 39.46388503483364, 64.55539349147251, 56.09588180269514, 62.948455810546875, 92.96887738364083, 78.40094375610352, 112.69638347625732, 106.30768857683454, 106.58490085601807, 108.202059337071, 94.28760378701347, 62.956550461905344, 39.42378003256661, 15.315368720463344, 3.419831693172455, 0.2065006656838315, 0.008536545593025429, 0.026020484643855264, 0.004848062734319163, 0.09963823309434311, 0.04091442669076579, 0.02255542343482375, 0.03217905507023845, 0.01936499248924, 0.023786070523783565, 0.025319736085033843, 0.06883566773363523, 0.022111741260492375, 0.027279034789119447, 0.0504126446986837, 0.0037194053958436207, 0.04521598247811198, 0.013085390923411717, 0.019619132691462125, 0.024550597981682847, 0.04264624144083687, 0.03275436794917498, 0.027519361714699438, 0.023119577805378606, 0.07133123132267169, 0.03272470918350986, 0.005853278861780251, 0.050782744839255295, 0.03765427627201591, 0.0343046304769814, 0.061529752266194136, 0.01702949870377779, 0.04611455622528281, 0.024587954727134535, 0.01598380329752607, 0.057475614095372815, 0.03766589957688536, 0.07612919993698597, 0.005289327203562217, 0.03453175311109849, 0.003682941348025841, 0.005610066041949072, 0.01772189449651965, 0.02615534178247409, 0.03479453954579575, 0.047047555446624756, 0.014252241301749433, 0.021624359734622494, 0.025572342798113823, 0.05068639625928231, 0.07133480720221996, 0.041398551248546155, 0.011881952240530933, 0.08459078267748867, 0.03990049520507455, 0.00964539310163153, 0.05413924723065325, 0.03576305329001375, 0.13489577440278872, 0.012910530752768474, 0.034732986241579056, 0.04576303098084671, 0.008958741955991303, 0.03064611554145813, 0.006204996640527887, 0.04392214172652789, 0.016454087437263558, 0.014776660661612238, 0.017430967518261502, 0.013676232076250017, 0.024533668532967567, 0.013109539984725416, 0.06900405298386302, 0.06996452608811003, 0.03772499658433454, 0.04473446010212813, 0.026704154476257305, 0.060539633966982365, 0.05004535708576441, 0.06289877809051957, 0.039717772509902716, 0.04632741605330791, 0.01320407009084842, 0.025069678967286433, 0.017706649510988166, 0.05915762098240001, 0.0034026039689446664, 0.0573160769417882, 0.027814451505296996, 0.08214486071041652, 0.016373167047277093, 0.05708051672471421, 0.03286738134920597, 0.005222852400038391, 0.04465394174414022, 0.02155781750168119, 0.06302954535931349, 0.036341891158372164, 0.07348962407559156, 0.045476899548832855, 0.045135263952293565, 0.00925250181795231, 0.01080625710476722, 0.054764920978673866, 0.07486940467996256, 0.022272823777581965, 0.028018748221386756, 0.06726605338709694, 0.04147257263373051, 0.026989017047786286, 0.047937077536646805, 0.024850330648145506, 0.014342471192191755, 0.03002505922423942, 0.03422298914353762, 0.03512445684256298, 0.027685193976919566, 0.03740986456562366, 0.04507259785064629, 0.07291054871997663, 1.8048623289380754, 9.117607712745667, 19.59958107130868, 56.25558614730835, 90.21907915387834, 104.83084896632603, 88.98523194449288, 89.68802833557129, 83.8858447756086, 92.18755940028599, 86.73190334865025, 88.8996023450579, 82.73230484553746, 84.87599781581334, 89.5023307800293, 52.49192067555019, 47.80646548952375, 44.905231271471294, 39.79099232809884, 43.286665780203684, 35.55228894097464, 33.34409931727818, 38.3762001310076, 32.44730574744088, 36.218086174556184, 44.94868530545916, 52.2471147945949, 44.198491777692524, 51.16261216572353, 38.38816840308053, 44.669663020542686, 32.896711758204866, 38.59902885981968, 46.33157137462071, 39.62051827566964, 44.79896552222115, 48.88857446398054, 39.14170748846871, 33.46107224055699, 66.00985990251813, 75.02366065979004, 74.8145615713937, 96.61596597943986, 94.35746792384556, 93.79565743037632, 110.9029700415475, 101.52092865535191, 128.70023182460238, 123.61128779820034, 120.22883524213518, 123.73311751229423, 108.72195134844098, 80.36425454275948, 49.05447312763759, 21.903850385120936, 4.5621667844908576, 0.07838061984096255, 0.040175824359591515, 0.03941714756989053, 0.02123174749846969, 0.1616427427423852, 0.021641102586207644, 0.029156415656741177, 0.02536904183216393, 0.054752422363630364, 0.024838698861588324, 0.005719492536237729, 0.05132389008732779, 0.030857272246586423, 0.01705645690006869, 0.037923373082386594, 0.011745483581242817, 0.08441116088735205, 0.021175162766927054, 0.0594282682452883, 0.029908045860273496, 0.015673012206596986, 0.035999560063438754, 0.06290431493627173, 0.0112917065021715, 0.03329566586762667, 0.018058458043794547, 0.005697599179776651, 0.03502621175721288, 0.0479844732076994, 0.025019163731485605, 0.04197741625830531, 0.02172373966979129, 0.06710097260240998, 0.03634287164147411, 0.004270231642294675, 0.04760807626215475, 0.005130276474769094, 0.10113381248499666, 0.026541441778785417, 0.07807696184941701, 0.022877198311367204, 0.007851512753404677, 0.02700914578911449, 0.04022881794454796, 0.03373561440301793, 0.009752868807741573, 0.07426383253186941, 0.0026235842753002153, 0.018991492888224975, 0.03291427829701986, 0.022548188555187414, 0.034986079803534915, 0.04839888168498874, 0.04637328162789345, 0.02510801619584007, 0.027973142186445848, 0.0508405254887683, 0.04059444653934666, 0.07879534722971064, 0.03979473873706801, 0.038001876191369126, 0.0348574159932988, 0.04086090045581971, 0.049255386261003356, 0.12095885510955538, 0.1252089270523616, 0.09447595902851649, 0.15226857789925166, 0.11674456910363265, 0.10746799795223133, 0.08134515969348804, 0.10213310457766056, 0.1698574676577534, 0.2144146231668336, 0.16940267277615412, 0.10258567386439868, 0.16375700357769216, 0.11442739915634904, 0.21130814057375702, 0.1718584538570472, 0.09009433271629469, 0.1253203425024237, 0.11130409568016018, 0.08566490361200911, 0.11164455741111722, 0.10753947483109576, 0.13497898993747576, 0.21409325541130134, 0.08337545860558748, 0.16118208531822475, 0.0825316324563963, 0.11843600762741906, 0.17694640798228128, 0.06222699449530669, 0.17644347782645906, 0.09209651313722134, 0.2490807601383754, 0.13334462977945805, 0.19337581710091659, 0.12651271851999418, 0.09285141048686844, 0.10710152797400951, 0.13261147269180842, 0.20237810404172965, 0.2624537082655089, 0.10675057609166418, 0.12661717220076493, 0.16397610253521375, 0.15152792978499616, 0.11058305044259344, 0.3182654934270041, 0.15911734396857874, 0.1211524275796754, 0.1182268424225705, 0.17097349491502556, 0.12310192654175417, 0.20367980562150478, 0.1464436940316643, 0.21220907223011765, 0.2372493078666074, 3.614505018506731, 16.58923407963344, 34.321203640529085, 74.86698572976249, 109.06314958844865, 115.27996689932687, 97.31745610918317, 90.85347747802734, 87.32575198582241, 97.30566501617432, 94.92549010685512, 83.47576209477016, 78.1397818156651, 72.84512247358049, 65.28762245178223, 44.38649960926601, 39.57696349280221, 40.67761026109968, 30.538305555071148, 36.45010389600481, 27.922753470284597, 21.70941025870187, 27.719569035938807, 38.556481565747944, 31.770711013248988, 37.77521569388253, 48.63542379651751, 34.01178993497576, 38.09639964784895, 32.77523292813982, 32.28754234313965, 18.821118797574723, 34.75795350755964, 50.86247430528913, 24.5395314012255, 28.73655775615147, 40.197274344308035, 33.59864657265799, 21.92068760735648, 48.56700835909162, 63.47908278873989, 60.272371019635884, 87.61853517804826, 79.34003448486328, 86.48767416817802, 116.36164855957031, 100.93093626839774, 136.00156566074915, 130.70057650974817, 134.96750695364815, 138.28768975394112, 127.93668038504464, 92.95537008558, 62.86661992754255, 28.374815429959977, 7.51801688330514, 0.21305986014860018, 0.0946703457406589, 0.1734891634966646, 0.10464286990463734, 0.2263999536101307, 0.09932578128895589, 0.08564829307475261, 0.09418162410812718, 0.15989087388983794, 0.10091735981404781, 0.08004538515316588, 0.1336642333439418, 0.07016684487462044, 0.09898854259933744, 0.1583791792924915, 0.12289900385907718, 0.14676322974264622, 0.10913811690573182, 0.15965911346886838, 0.06938112167907612, 0.0890362523496151, 0.11310178600251675, 0.10157580341079406, 0.10713305949632611, 0.18359953883503163, 0.11792232947690146, 0.09926820080727339, 0.14091684988566808, 0.13146260433963367, 0.09715050658477203, 0.08733724137502057, 0.14864746720663138, 0.1685459001788071, 0.11182757866169725, 0.09290160172219787, 0.16206247093422071, 0.10789299157581159, 0.19086949873183454, 0.11398268730512687, 0.1688447134303195, 0.10389669851533004, 0.08286416211298533, 0.1294217881347452, 0.1545394446168627, 0.10303838564349072, 0.13217350547867163, 0.1806425375065633, 0.05807047217552151, 0.12858440806823118, 0.12677656007664545, 0.21797937474080495, 0.16224251341606888, 0.11493681610694953, 0.1215029451996088, 0.10635916995150702, 0.14145453460514545, 0.15263428113290242, 0.07371558980750186, 0.1802284275846822, 0.14956191528056348, 0.13720173495156424, 0.15559706357972963, 0.1652405389717647, 0.13405524593378815], [0.022124572357695018, 0.031742536529366455, 0.04527318976553423, 0.04574633562671287, 0.04899533771510635, 0.0311637732998601, 0.03452983285699572, 0.047459120862185955, 0.0561629609603967, 0.012336569006687828, 0.04344286530145577, 0.042700412284050665, 0.04535376240632363, 0.05319568321907094, 0.036971106859190125, 0.06727565465761082, 0.023717280643592988, 0.027295255168740238, 0.011784539208747447, 0.03467443545481988, 0.05101213717300977, 0.07151605747640133, 0.024371585176725472, 0.039257077766316276, 0.022633692449224845, 0.018809026340022683, 0.05458064783098442, 0.015555272810161114, 0.060622700223965306, 0.03281053029266851, 0.026805851608514786, 0.007239026333471494, 0.05589494641338076, 0.017791714053601027, 0.03491187521389552, 0.03337544122976916, 0.07186487197343792, 0.07151085989815847, 0.024497869025383676, 0.026176632515021732, 0.07173881373767342, 0.02025588521999972, 0.03432313073426485, 0.04222342591466648, 0.056605613457837274, 0.028500604775867293, 0.06058200169354677, 0.03485059332368629, 0.017661128292924592, 0.015654289729094932, 0.0397401200607419, 0.023840906331315637, 0.026541282323056033, 0.032864548465503116, 0.28958376390593393, 3.011160582304001, 11.891608255250112, 34.86403512954712, 56.77960886274065, 73.04589067186627, 73.27500057220459, 70.98196302141461, 64.63868849618095, 61.592229979378835, 59.70762143816267, 25.336091995239258, 36.39629357201712, 45.70551783697945, 40.81700154713222, 19.65769406727382, 22.597105162484304, 33.25004850115095, 33.93701342173985, 52.36714145115444, 67.1124347959246, 58.25598989214216, 71.11213752201625, 94.69209316798619, 78.6944773537772, 115.17254774911063, 74.80733544485909, 67.05710629054478, 55.15887900761196, 76.29349258967808, 61.116125515529085, 88.86975288391113, 91.37910175323486, 70.24887248447963, 58.84783049992153, 81.66249765668596, 96.28027071271623, 109.80092321123395, 91.7956462587629, 73.8980872290475, 95.26850877489362, 67.75572681427002, 61.944343839372905, 39.289797919137136, 33.77665594645909, 28.631467989512853, 38.277264731270925, 40.818144525800435, 32.99714796883719, 50.88904421670096, 53.291227545057026, 79.91685308728898, 74.98982293265206, 82.02940423148019, 100.18527644021171, 102.5519301550729, 100.88028390066964, 60.67364338466099, 23.943832806178502, 2.40524075286729, 0.16628728780363286, 0.0738264217174479, 0.12176067994109221, 0.022397562262735198, 0.03482851718685456, 0.04783101912055697, 0.012469345587305725, 0.027183368136840205, 0.022891266038641334, 0.025438645954376886, 0.021839730142216598, 0.039014308114669154, 0.011993330371166979, 0.007165298414682704, 0.056264764961919615, 0.04074819239654711, 0.037219447283340354, 0.024153481969343762, 0.05588709915589009, 0.022711194719054868, 0.02698506458130266, 0.02312678045460156, 0.04009354520323021, 0.04877412851367678, 0.0434762322609978, 0.0468750820229096, 0.02516381721943617, 0.1328384426555463, 0.022366319117801528, 0.04312080204752939, 0.05453901970759034, 0.014283538729484593, 0.018951215049518005, 0.01106147448133145, 0.02111727524814861, 0.017073708652917827, 0.07625305293393986, 0.03426144850839462, 0.036327149985092025, 0.025184171573658074, 0.031409263876932006, 0.022627171727695634, 0.08902035427412816, 0.09322799742221832, 0.04033028607123664, 0.011493187297933867, 0.06899694193686758, 0.026196206553972194, 0.054553788022271225, 0.07531711565596716, 0.05790849908121994, 0.024737152703372494, 0.04994698307876076, 0.1103232190279024, 0.06470997125974723, 0.020157942082732916, 0.11620699294975825, 0.02943836052768997, 0.0696991171155657, 0.04622410909671869, 0.021514430276251266, 0.048157570883631706, 0.012845295547906841, 0.008450045948848128, 0.0765434591365712, 0.023020452320841805, 0.03331344348511525, 0.015933574742770622, 0.024474103336355517, 0.035833064533237896, 0.025714531507609144, 0.013037475324901087, 0.032113006471523216, 0.04113833985424467, 0.0315184096273567, 0.04090995853766799, 0.025250438999916826, 0.030948881259454147, 0.12236319189625126, 0.049403676696653874, 0.02762068565269666, 0.029753641824104955, 0.02104511813792799, 0.01714637636073998, 0.017738213263718144, 0.034021589771977494, 0.014209691218898764, 0.051853903968419345, 0.014939293631219437, 0.02966805820220283, 0.03670935179772122, 0.07149941979774407, 0.10976880163486515, 0.003575136128347367, 0.034576115730617724, 0.07274481654167175, 0.02973023575863668, 0.04553650885022112, 0.07460705590035234, 0.08967469951936177, 0.029832592766199793, 0.010382762195409408, 0.07702596538833209, 0.032156066303806644, 0.020118191805002943, 0.03368564708424466, 0.0654689601755568, 0.026076404411079626, 0.07029088107602936, 0.005244542195993874, 0.03139230389414089, 0.0092179296105834, 0.08192940548594509, 0.06029655558190175, 0.07814143624688898, 0.04941674188843795, 0.3145865579800946, 2.5920775958469937, 12.887463160923549, 45.73904636928013, 72.68599482945034, 89.55346952165876, 82.78351306915283, 82.54377242497036, 79.35709926060268, 68.10557556152344, 72.85744162968227, 50.71766689845494, 65.30542373657227, 58.31249264308384, 50.53463397707258, 25.423729624067033, 26.92715130533491, 34.03444801058088, 22.770605155399867, 29.456332070486887, 37.253294808524, 25.151111841201782, 31.184692995888845, 39.803228105817524, 41.98322193963187, 73.92735304151262, 41.084799017224995, 32.539202622004915, 40.97086593082973, 37.89750746318272, 38.762884753090994, 53.805307388305664, 48.70235579354422, 29.25182921545846, 39.038724763052805, 50.23487131936209, 44.76620129176548, 57.920332840510774, 53.35086393356323, 45.87368508747646, 42.906449931008474, 40.92948940822056, 48.55613095419747, 33.57312931333269, 36.99755941118513, 38.242054734911235, 50.854542936597554, 67.83020455496651, 64.10663713727678, 86.99949932098389, 90.64662265777588, 105.34142344338554, 93.42195551736015, 97.52398436410087, 112.00660800933838, 117.81375258309501, 114.27106761932373, 79.99923092978341, 32.86304773603167, 3.6142433754035403, 0.15295233763754368, 0.0443321974016726, 0.10110084246844053, 0.01218064165940242, 0.05588718058009233, 0.028320871027452604, 0.06045452531959329, 0.08139915751027209, 0.07342823022710425, 0.03829450120351144, 0.03733613155782223, 0.03259179095870682, 0.021270734424303685, 0.046603905502706766, 0.0023596248231894735, 0.04767121733831508, 0.07584625083420958, 0.006624248585597212, 0.04847210579152618, 0.03335731077407088, 0.026601470075547695, 0.047059996386191676, 0.057438647507556846, 0.0026753047589279178, 0.03825606219470501, 0.048143718591226, 0.07813224209738628, 0.11195554358086415, 0.011461162141391208, 0.07114774866827897, 0.04229929630777665, 0.019998481264337897, 0.022589930333197117, 0.05439145530440977, 0.012489821229662215, 0.028456077611606036, 0.07618176604488067, 0.014092025613146169, 0.035330263299069235, 0.04032948539991464, 0.02448329409318311, 0.06765965119536434, 0.009989381518347986, 0.05695097081895385, 0.08149051546518292, 0.033457873056509664, 0.020914644335529635, 0.0450767606629857, 0.03959187712254269, 0.0782257713643568, 0.055426421375679116, 0.07218288098062788, 0.03978931045691882, 0.07312576645719153, 0.04064444439219577, 0.005086276023316064, 0.10539263752954346, 0.011149381237503673, 0.036104590498975346, 0.0488298939141844, 0.02685291479740824, 0.03816757783559816, 0.15963708822216305, 0.11707460853670325, 0.17742159962654114, 0.14006671336080345, 0.07675723837954657, 0.12701522798410483, 0.11483922920056752, 0.23968728418861115, 0.12455115520528384, 0.1289755292236805, 0.1269916963896581, 0.13727398536034993, 0.11986654943653516, 0.13046401792338916, 0.12245775253645011, 0.16286010241934232, 0.1428949423134327, 0.10909897222050599, 0.14073661741401466, 0.14906377558197292, 0.09197528607078961, 0.13628165503697737, 0.20910833004329885, 0.2218591294118336, 0.19714182216141904, 0.08555203609700714, 0.10391041170805693, 0.07389648724347353, 0.08991530803697449, 0.11898213332252842, 0.16680211946368217, 0.08946624677628279, 0.09438766805188996, 0.17151979702923978, 0.13284326025417872, 0.15585079496460302, 0.18778174370527267, 0.21034037321805954, 0.14302051200398377, 0.11506352573633194, 0.2092089160744633, 0.13792484972093785, 0.12984516684498104, 0.1298650207796267, 0.205087792926601, 0.10628185767148222, 0.20794427607740673, 0.12979513167270593, 0.0999671733006835, 0.07718052888023001, 0.13565202882247313, 0.1089712990713971, 0.10936754316623722, 0.13197791097419603, 0.7697436958551407, 5.638079268591745, 17.87660847391401, 57.9777249608721, 91.82336957114083, 105.62702219826835, 97.87171391078404, 96.25561850411552, 91.75592340741838, 82.96891185215541, 81.59626047951835, 43.30498123168945, 58.23598950249808, 60.156391688755576, 58.04526145117623, 33.06582743780953, 32.95550046648298, 51.96483727863857, 51.83592735018049, 81.30933461870465, 95.49126802171979, 84.53211757114956, 106.66601412636894, 135.35285404750277, 109.752000944955, 148.99831008911133, 111.73255716051374, 103.24117061070034, 80.24063219342912, 107.44349670410156, 81.27199499947685, 121.97916984558105, 117.61074011666435, 97.91674518585205, 86.38142231532505, 114.67343779972622, 131.29396656581332, 145.5425818307059, 127.97174099513462, 106.37508610316685, 130.10479627336775, 91.30611787523542, 84.01871517726353, 54.12750577926636, 47.16310051509312, 40.81519848959786, 54.50232287815639, 60.23199503762381, 50.75407893317086, 73.70537894112724, 78.89683668954032, 106.09014742715019, 99.64492198399135, 106.12908513205392, 124.6336179460798, 131.84830774579729, 131.19717815944125, 94.93578733716691, 42.67560298102242, 6.081317450319018, 0.22391602689666407, 0.20136133288698538, 0.28049313170569284, 0.1258612706192902, 0.07983294940952744, 0.10316356178373098, 0.10811008206967797, 0.2443508825131825, 0.10936704105032341, 0.08372166074280228, 0.23798158285873278, 0.10032908352358, 0.10553126901920352, 0.0966832877269813, 0.1766527515969106, 0.11093879278217043, 0.15346000396779605, 0.13016615462090286, 0.12486571046922888, 0.14913556458694593, 0.12369514256715775, 0.12601145756031784, 0.19594639273626463, 0.08610533390726362, 0.15034821523087366, 0.15378651501876967, 0.2492247452693326, 0.238437504108463, 0.1729622132011822, 0.07343501557729074, 0.13605612356747898, 0.19637230916747025, 0.1609578023531607, 0.09568556305021048, 0.06011022308043071, 0.16008246503770351, 0.14229080187422888, 0.08174086096031324, 0.0957114559465221, 0.10859100054949522, 0.16927288259778703, 0.12629455594079836, 0.2026737824614559, 0.1850837527641228, 0.09384450755481209, 0.14344758194472107, 0.13949276772992952, 0.13920825799661024, 0.15021466596850327, 0.1851452687489135, 0.1496907826513052, 0.1836883183568716, 0.142641455201166, 0.19541001080402307, 0.20085614999490126, 0.0421374690985041, 0.320625899625676, 0.1213479678013495, 0.13608285784721375, 0.17932503963155405, 0.16324985293405397, 0.12307597936264106], [0.0334768313249307, 0.025553888341944133, 0.024474486708641052, 0.027329695909949284, 0.017730488142530833, 0.1436321706111942, 0.06441272542412792, 0.09196622762829065, 0.02883656442697559, 0.09971249875213418, 0.028763567629669393, 0.07578577979334764, 0.005278321789644126, 0.04328524161662374, 0.10629130287894181, 0.0746540648064443, 0.03755540354177356, 0.031058254319110086, 0.031183101369866302, 0.04819980290319238, 0.03339771753443139, 0.01093564270662942, 0.053829967576478205, 0.06134023065013545, 0.051983626293284554, 0.01569895090402237, 0.0792319845142109, 0.056778656850968084, 0.07212962276701416, 0.08659710894737925, 0.034981818603617806, 0.014729697556634034, 0.04283044673502445, 0.04606807318383029, 0.016768479852804115, 0.03294074794809733, 0.07009277599198477, 0.04058652803567903, 0.04955311385648591, 0.07305760082921811, 0.08377911230283124, 0.02316899042177413, 0.02141068396823747, 0.029609324210988622, 0.029117393107818704, 0.04600546136498451, 0.0521122222500188, 0.0682816371055586, 0.02595631728347923, 0.016489269477980475, 0.07949132059833833, 0.10406536196491548, 0.1796868752155985, 2.629115402698517, 18.560490131378174, 37.212404659816194, 48.80662046160017, 45.94881248474121, 44.24416923522949, 59.58445766993931, 64.45536027635846, 46.21610621043614, 19.688681295939855, 22.457430737359182, 16.880356652396067, 19.818404163633073, 12.018772448812213, 56.91287183761597, 64.25218105316162, 78.21209866659981, 110.54767390659877, 112.92110211508614, 102.84264278411865, 76.98516491481236, 62.43650559016636, 77.11668041774205, 66.37227099282401, 73.18147781917027, 85.32232230050224, 53.094562258039204, 60.32336384909493, 78.34781782967704, 83.49428599221366, 83.24985531398228, 101.60019370487758, 65.47852420806885, 78.02676936558315, 87.91308321271623, 84.75031185150146, 62.41723823547363, 94.81147711617606, 85.16616153717041, 70.14891569955009, 49.93203755787441, 57.37248475211007, 67.32254137311662, 64.12190927777971, 100.87904712132045, 79.8455923625401, 104.25564929417202, 84.26367391858781, 57.29360185350691, 40.16357558114188, 32.061368056706016, 29.39459385190691, 40.34860610961914, 46.16493272781372, 46.137084347861155, 57.58841739382063, 71.61949498312813, 78.12565612792969, 94.16270296914237, 89.44685636247907, 58.17418875013079, 16.127246618270874, 0.947224029472896, 0.28104605632168905, 0.06164449253784759, 0.05828269078795399, 0.07451960630714893, 0.009165655272746724, 0.026611741399392486, 0.07172749577356236, 0.025756958605987684, 0.005964865641934531, 0.048959677307201285, 0.09812822126384292, 0.07018806266465358, 0.007258187314229352, 0.030863267103476182, 0.07510900218039751, 0.028373930769573365, 0.026001317725915993, 0.04207205832270639, 0.04871323678110327, 0.053431759122759104, 0.05274366693837302, 0.040393640885927846, 0.03733940548928721, 0.03225191276786583, 0.025929394710276808, 0.025108850793913007, 0.06675261950918607, 0.033008479313658814, 0.011104077150646065, 0.04540815716609359, 0.026270027771326046, 0.023698480134563785, 0.08213409914502076, 0.04689945160810437, 0.051485048939606974, 0.005917006022562938, 0.04204196868730443, 0.017888459576559917, 0.02842402531366263, 0.10658594314008951, 0.025102209632417986, 0.017282466736755202, 0.10032940922038895, 0.037802393681236675, 0.07598042434879712, 0.0955545175820589, 0.08687000216117927, 0.026056636989648854, 0.06999338418245316, 0.05642478387536747, 0.07428030057677201, 0.09565294587186404, 0.009022625179828277, 0.054679110047540495, 0.055964353760438304, 0.06401255261152983, 0.10919563631926264, 0.019438352302781174, 0.08544537717742579, 0.07184796966612339, 0.06624519066619021, 0.06319869056876216, 0.001689072238929969, 0.03090471202241523, 0.019018366267638545, 0.03865831810981035, 0.06560693348624877, 0.05112918785640171, 0.06275524079267468, 0.07483882310667209, 0.01822715881280601, 0.01683904410206846, 0.019082503093938743, 0.013662658831370729, 0.010400421069269734, 0.048210734102342806, 0.024402453431061337, 0.01554711681923696, 0.02329012588597834, 0.03579603348459516, 0.04963081629414644, 0.009497879588577365, 0.1001802875793406, 0.013074739619956484, 0.027435206409011568, 0.036686715869499106, 0.008500215131789446, 0.015685675366382514, 0.03762893298906939, 0.026180561232779707, 0.0403192632698587, 0.014673850731924176, 0.05127800076401659, 0.028947973091687475, 0.01634810196368822, 0.05472328267725451, 0.06580671455178942, 0.07749297390026705, 0.038935360565249405, 0.048602581290262084, 0.10291755891272, 0.052312298478292565, 0.039876600594392846, 0.008245551609434187, 0.037624804103480916, 0.017026854113542607, 0.062209454365074635, 0.09546329533415181, 0.04226302182567971, 0.011525299815860177, 0.13047190250030585, 0.044059056522590775, 0.08496465547276394, 1.7425579407385416, 17.634920597076416, 37.84693847383772, 56.905169759477886, 56.05689893450056, 57.00764874049595, 73.3583094733102, 86.20516041346959, 72.96292918069022, 42.28087581907, 47.36317041942051, 36.330765111105784, 19.320977415357316, 18.67023171697344, 47.064894676208496, 44.88054779597691, 47.35712548664638, 49.47679158619472, 67.4268546785627, 70.67255278996059, 68.02992357526506, 58.78330952780587, 59.083284105573384, 50.31351450511387, 63.140976497105186, 65.64901910509381, 59.08612591879708, 57.1572573525565, 57.93517071860177, 50.24703761509487, 60.60960183824812, 49.88238573074341, 51.75119754246303, 56.501406465257915, 57.346713883536204, 55.040572030203684, 51.21273299625942, 73.33599880763462, 62.59734943934849, 55.1895101411002, 41.86187859943935, 41.817194734300884, 50.63649109431675, 48.04708160672869, 58.87881251743862, 56.481117725372314, 59.281516211373464, 59.10904107775007, 43.37875025612967, 29.838215487343923, 28.163340057645524, 32.44896636690412, 64.8827439716884, 72.35349573407854, 70.1089427130563, 80.25038051605225, 82.29539516993931, 90.04319245474679, 103.36987209320068, 105.20390469687325, 72.4316073826381, 21.41217848232814, 1.2521946877241135, 0.22853222276483262, 0.07665705946939332, 0.05371471840356078, 0.05025703626285706, 0.050751077609934976, 0.05522171753857817, 0.011210766604303249, 0.08371946228934185, 0.025515668160681213, 0.04710818933589118, 0.021375076146796346, 0.027780945446076136, 0.010806553115669106, 0.03673501738480159, 0.030181763494121175, 0.014593478258965271, 0.021136165663067783, 0.026863223440679054, 0.005047142788368676, 0.07926295285246202, 0.06439312254743916, 0.00852138627254005, 0.032255722741995535, 0.025672501352216517, 0.03959152428433299, 0.012627914980319994, 0.040344453882426023, 0.06596277082072836, 0.044558882380702665, 0.024780478860650743, 0.04117012921986835, 0.04005707394597786, 0.07922378781118564, 0.07804834124233041, 0.037497700923787694, 0.06286152651799576, 0.019685289855780344, 0.013632645531158363, 0.008876727428287268, 0.06702714120703084, 0.0299654770642519, 0.033154103106686046, 0.03299887465046985, 0.03998962077977402, 0.05295908484341843, 0.021770159946754575, 0.02962769554661853, 0.023131067099581872, 0.07378290726670197, 0.011584352718533149, 0.020278690781976496, 0.057543895074299405, 0.008197496911244733, 0.028575603251478503, 0.02197977637739054, 0.06453953004841294, 0.03737780378599252, 0.05022926043186869, 0.037768490679029904, 0.034612373249339204, 0.17026529434536183, 0.1423444061407021, 0.07193401469183819, 0.1232828918312277, 0.08747598143028361, 0.19540855873908314, 0.14542773711894239, 0.13500348505164894, 0.13032836520246097, 0.22231952899268695, 0.20667856399502071, 0.2203276894454445, 0.11445646759654794, 0.1823286698865039, 0.12229714329753603, 0.21985594475907938, 0.1236834174820355, 0.09278826601803303, 0.1706529821136168, 0.15167933808905737, 0.1032055698867355, 0.09553323193852391, 0.15103673828499659, 0.12373964089368071, 0.14345343091658183, 0.19617393266941818, 0.14352355072540895, 0.1090047779892172, 0.15130854584276676, 0.09994765184819698, 0.11641357972153596, 0.10161366566483464, 0.12323816280279841, 0.21327916266662733, 0.12297007361693041, 0.11514292790421418, 0.18615572952798434, 0.14515115267464093, 0.11049072218260594, 0.1570215799978801, 0.2344776008810316, 0.15705922512071474, 0.13978452421724796, 0.06927508701171194, 0.08267459299947534, 0.10639133251139096, 0.09799137432128191, 0.15821225967790398, 0.16472215178821767, 0.07159146307302372, 0.1950062688972269, 0.2681138574012688, 0.5080356161509241, 4.6443109938076566, 24.898522240774973, 54.24673686708723, 79.46474770137242, 75.07573740822929, 70.30898829868862, 84.57297992706299, 93.42724309648786, 67.09751006535122, 33.83746658052717, 37.0821988923209, 33.25274787630354, 35.46957758494786, 23.886107172284806, 80.39753641401018, 93.7074431010655, 111.1472270148141, 161.03035272870744, 158.25764628819056, 147.6006521497454, 117.9595535823277, 98.7351734978812, 110.96716444832938, 97.81765692574638, 117.54469054085868, 126.89829989842006, 76.31112711770194, 94.15398297991071, 121.03702190944126, 122.59514154706682, 125.14274024963379, 145.58513259887695, 99.54739012037004, 121.6461843763079, 130.48486273629325, 120.74651772635323, 90.76997402736119, 144.62255695887973, 124.05370739528111, 95.81503323146275, 74.30402878352574, 86.13157899039132, 95.59157916477749, 97.83674362727574, 140.299346106393, 115.29351588657924, 148.29215076991488, 118.41051946367536, 79.54363754817417, 53.576871463230674, 47.64227955681937, 45.313660281045095, 57.3900602204459, 65.7465648651123, 65.53061485290527, 79.44551508767265, 90.88973317827497, 98.08871310097831, 112.86160469055176, 118.68404224940709, 88.1991058077131, 26.6855138029371, 1.7841736333710807, 0.2721827876354967, 0.13142166153660842, 0.11831184928970677, 0.16027412403907093, 0.18948519229888916, 0.12364121260387556, 0.1984591164759227, 0.12275116464921407, 0.10842538372214351, 0.1615406639341797, 0.22007995631013597, 0.12266223584967, 0.06366371775844268, 0.07934711833617517, 0.1650246155581304, 0.20428598166576453, 0.13352866204721586, 0.13748582399317197, 0.12469701309289251, 0.16084445986364568, 0.15929763072303363, 0.07530370101864849, 0.16429316837872776, 0.09801118075847626, 0.1826683852289404, 0.10773667067821537, 0.3281236030161381, 0.1452545749821833, 0.15678178572228976, 0.12786811936114514, 0.16998176170246942, 0.14973738443638596, 0.1848424928528922, 0.16208915093115397, 0.14687157821442398, 0.1517903192767075, 0.21678152973098413, 0.13556501349168165, 0.1933365977768387, 0.19437506848147937, 0.16413334624043532, 0.13214440989707196, 0.14034762685852392, 0.12058566084929875, 0.12787590894315923, 0.16894437665385859, 0.14162316412797996, 0.11759959108063153, 0.12220623317573752, 0.14853872518454278, 0.15118559529738768, 0.2626788733260972, 0.11760767921805382, 0.16266723562564167, 0.1860077546111175, 0.15760722357247556, 0.1556644421070814, 0.13454643743378775, 0.21323402651718684, 0.07971166806029421], [0.029953623057476113, 0.03476554235177381, 0.05867265164852142, 0.029374815723193542, 0.019561957634453262, 0.059206699420298846, 0.04783191139410649, 0.05690281179600528, 0.033406898113233705, 0.021815085750339285, 0.03793840941839984, 0.01488579623401165, 0.029997510702482293, 0.04917410115844437, 0.028619755525141954, 0.015293287046785866, 0.04618968701522265, 0.040132968087813685, 0.0453456471275006, 0.010789434525317379, 0.04186616026397262, 0.014821818863440837, 0.04440493635567171, 0.012469432948689376, 0.04827467245715005, 0.037417708430439234, 0.021909056065071906, 0.023710644571110606, 0.0865001870053155, 0.01868086464570037, 0.08113148223076548, 0.06905379638608013, 0.010004958137869835, 0.039638149818139415, 0.041670114533709626, 0.014507960794227464, 0.04712645549859319, 0.040820653151188574, 0.06564952512936932, 0.0940669991874269, 0.04821595542931131, 0.0491926115937531, 0.05771008187106677, 0.04293293266424111, 0.012964151134448392, 0.05199424875900149, 0.03679065725633076, 0.019899952890617505, 0.008244911242010338, 0.10741938091814518, 0.11628336885145732, 1.1752481652157647, 9.62049835068839, 32.76746484211513, 50.962444986615864, 68.10725007738385, 61.9747838973999, 44.53989846365792, 40.25091096333095, 39.3301739011492, 25.059025628226145, 7.614589895520892, 19.12830213138035, 24.975192138126918, 36.830055713653564, 53.28237901415144, 80.95410796574184, 51.32999774387905, 42.835123198372976, 45.25476387568882, 37.75881447110857, 28.732256821223668, 11.461898650441851, 1.70200315117836, 0.8396556015525545, 0.5693668222853115, 0.26537520864180153, 0.5706169552036694, 0.32039845468742506, 0.09918133475418602, 0.3613531185047967, 0.4560551111187254, 0.6530544002141271, 0.6239790660994393, 0.8443007437246186, 0.6083667895623616, 0.5156818915690694, 0.6337608812110764, 0.1893121658691338, 0.5108167412025588, 0.2928395377738135, 0.5319338366389275, 0.39644741107310566, 0.5254196833286966, 0.6882070196526391, 1.6624565018074853, 0.22204781642981938, 0.2136870300663369, 1.9121210191931044, 10.431820392608643, 26.630200931004115, 58.2319004876273, 111.15812873840332, 92.86004774911063, 95.43381336757115, 53.93383516584124, 35.02173491886684, 21.893789393561228, 30.235635076250347, 56.5393887928554, 54.95358058384487, 68.29870768955776, 82.77755846296037, 81.56712668282645, 76.13298920222691, 46.939858368464876, 18.178674459457397, 9.267371790749685, 2.627296277454921, 0.20783014648727008, 0.033089710133416314, 0.07512608769216708, 0.00314539869681799, 0.07872264898781266, 0.01698473235592246, 0.039292113922004185, 0.05710229769881282, 0.04331208106928638, 0.02999320879046406, 0.009317509713582695, 0.07774974512202398, 0.03079050440075142, 0.03556086003248181, 0.022159410041889975, 0.016334839996748736, 0.043513748462178876, 0.08159065366323505, 0.008555357976417457, 0.059947727514164786, 0.06401876120695046, 0.022911177648763572, 0.019636974769777486, 0.020558181052495326, 0.039852773837213, 0.03317379080025213, 0.04210922507835286, 0.022469929718811597, 0.0392143436308418, 0.026601229195616076, 0.055345862305590084, 0.0647057711279818, 0.022702180381332124, 0.06680324500692741, 0.01696119736880064, 0.029379195666738918, 0.07012713021997895, 0.047033394420785565, 0.028660515123712163, 0.028333456155710986, 0.0060926906132538405, 0.052103224875671525, 0.05355153073157583, 0.040387055703571866, 0.08028569511537041, 0.025077711125569682, 0.02766890574379691, 0.043465742109609504, 0.028577112991894995, 0.018096398329362273, 0.0264862514367061, 0.03629025803612811, 0.030726165710283176, 0.015134011129183429, 0.060374349621789794, 0.013958280423789151, 0.022566256246396472, 0.06421334469424826, 0.029503510067505494, 0.028830606889511858, 0.047168307538543425, 0.004233723489700684, 0.013491959776729345, 0.03777219208755663, 0.05990590940096548, 0.07060391642153263, 0.023663920649726475, 0.04576521247093167, 0.011259341229950743, 0.08781601568417889, 0.04392574814015201, 0.033841476043952365, 0.06240687412875039, 0.052099085812057765, 0.050446907324450355, 0.005066709617884564, 0.05077007319778204, 0.03343695042920964, 0.03699374957276242, 0.020570811981867467, 0.01046649002403553, 0.02886858449450561, 0.010267876886895724, 0.022615222726017237, 0.04852964895378266, 0.012517111908112253, 0.02151314784506602, 0.02360434697142669, 0.043011076149663756, 0.008956990487474416, 0.023949862091935108, 0.013897569351164358, 0.02518779834333275, 0.019138689186157923, 0.06300148793629237, 0.08149547555616923, 0.01104966118665678, 0.05044127209112048, 0.027768480757783567, 0.05628732964396477, 0.038956853161965094, 0.023231217171996832, 0.07483744568058423, 0.05208727930273328, 0.005800884932146541, 0.10562514433903353, 0.09484780300408602, 0.11021157966128417, 0.7608267143368721, 9.475231494222369, 34.56131253923689, 59.66507066999163, 83.90345845903668, 79.26588330950055, 62.01258209773472, 56.36969641276768, 53.25001083101545, 38.86947011947632, 21.384984970092773, 20.32285032953535, 18.431255374635967, 31.535938331059047, 36.17425693784441, 41.95747191565377, 52.19625398090908, 48.6369628225054, 48.62863540649414, 44.55403457369123, 35.560713631766184, 13.854191218103681, 3.6715749161584035, 0.8100860768130848, 0.16944190567093237, 0.11059854818241936, 0.16680981405079365, 0.30652689188718796, 0.16338816551225527, 0.449220743562494, 0.6381482343588556, 1.0552401819399424, 0.3212501789842333, 0.88930694013834, 0.06467958646161215, 0.1457820681056806, 0.13087021612695285, 0.2694165903542723, 0.5871602903519357, 0.1555871298270566, 0.04147788217025144, 0.31235632193940027, 0.3867067423249994, 0.7847364427787917, 0.958980164357594, 0.1138725746423006, 0.9364902568714959, 2.5980906103338515, 11.190986650330679, 24.603063992091588, 48.3040885244097, 72.3745070866176, 70.4081460407802, 59.73204435620989, 37.42770848955427, 32.97446557453701, 33.913917609623496, 48.493819509233745, 85.66420841217041, 78.26188945770264, 85.6210948399135, 94.46797207423619, 94.3814947945731, 92.40051473890031, 61.411250250680105, 24.964149713516235, 11.815284899302892, 3.365090093442372, 0.14645598908620222, 0.0643385344051889, 0.06888981482812337, 0.04088293248787522, 0.06950360403529235, 0.014953458049733723, 0.025335093028843403, 0.02416807895393244, 0.032590342286442, 0.04051769744338734, 0.014536382929821099, 0.033115864265710115, 0.004404227465524205, 0.0666703674942255, 0.05731579874243055, 0.03616237793383854, 0.06683428798403059, 0.027220987814611623, 0.022925087616645863, 0.03650240879505873, 0.02358330220782331, 0.029573680766459023, 0.03875024264146175, 0.028470698344920362, 0.03253867184477193, 0.034722302707710435, 0.03496623604691454, 0.047264018295598884, 0.01029672141053847, 0.02393243052730603, 0.07255517957465989, 0.02815556462987193, 0.05839970415191991, 0.04162031006334083, 0.040253068786114454, 0.024087623360433748, 0.016518100430922847, 0.058058204262384346, 0.01500414461562676, 0.03731809609702655, 0.026456523121201565, 0.032307040345455916, 0.026925153331831098, 0.011864279795970236, 0.049832850095949004, 0.09874535564865385, 0.018964231047513228, 0.052644169955913506, 0.04629542651985373, 0.018819282396829555, 0.02991233080891626, 0.02472194842994213, 0.03708897178460445, 0.031199979928455183, 0.0349514473761831, 0.017660534574783275, 0.06248494636799608, 0.20719027439398424, 0.0978017102128693, 0.1381207156394209, 0.11754488758742809, 0.19442825205624104, 0.11241666919418744, 0.133535216695496, 0.07501475366630725, 0.12353865882115704, 0.2434538049357278, 0.10489931542958532, 0.22545366867312364, 0.15300561620720796, 0.09544885610895497, 0.16881626924233778, 0.15276920103601047, 0.08639352808573417, 0.0833697724821312, 0.12621808504419668, 0.21941983673189366, 0.1814619092536824, 0.15308207353310926, 0.15254866358424934, 0.08360418597502367, 0.15779684696878704, 0.10444870710905109, 0.07401193319154636, 0.17185093568904058, 0.11332064068743161, 0.13202017013515743, 0.13945122781608785, 0.117752573585936, 0.10579106650714364, 0.08325432653405837, 0.15541570473994526, 0.12916270989392484, 0.13226968103221484, 0.1450700813106128, 0.146286206053836, 0.11525287771863596, 0.037440212044332705, 0.16357096284627914, 0.16729160105543478, 0.0657048121626888, 0.136852533689567, 0.11476129266832556, 0.17391754979533808, 0.11749713229281561, 0.21489052048751286, 0.19816660002938338, 0.2531831014369215, 1.4973448302064623, 16.556527171816143, 46.37122821807861, 75.88991342272077, 102.006913457598, 89.23067705971854, 71.10420962742397, 66.86569036756242, 61.93308080945696, 40.13709599631173, 14.699932030269078, 30.88910620553153, 38.000163623264854, 51.9083970614842, 79.93208353860038, 120.55567850385393, 82.11754213060651, 66.54185567583356, 68.27026176452637, 58.2248272214617, 47.93881825038365, 17.654757704053605, 4.659935321126666, 1.4449921080044337, 0.6310810478670257, 0.7178761533328465, 1.0529373969350542, 0.9257940479687282, 0.7193969945822443, 1.2928429522684641, 0.8903569323675973, 2.5208976439067294, 0.94634909927845, 1.4438317588397434, 0.9082888215780258, 0.5504579512136323, 0.6831396115677697, 0.6151782497763634, 1.2097775638103485, 0.48162388482264107, 0.7035420196396964, 0.6524824766176087, 1.1642858620200838, 1.2582208386489322, 2.068014059747968, 0.4753931963018009, 1.1514265920434679, 3.9081619467054094, 16.87497353553772, 39.10366610118321, 83.30383586883545, 153.01878792898995, 131.97559874398368, 126.82592746189663, 74.56897054399762, 49.47226136071341, 34.96070541654314, 48.75971664701189, 81.1797159739903, 75.17398493630546, 90.3972031729562, 103.23873179299491, 103.22983115059989, 107.26601191929409, 72.14149229867118, 32.44517959867205, 15.949172973632812, 5.19410023518971, 0.3559035594974245, 0.11152493168732949, 0.210712142554777, 0.14651004118578775, 0.149672910038914, 0.07025428089712348, 0.11237295118293592, 0.1505817398428917, 0.07880608843905584, 0.10327657179108687, 0.08361392295254128, 0.1444565635174513, 0.12023639173379966, 0.1306104864925146, 0.15092279868466513, 0.11714453835572515, 0.2374961046235902, 0.08768454273896557, 0.08761609891163451, 0.16726158266620977, 0.17314678829695496, 0.14509060020957673, 0.21040030143090657, 0.1188426808054958, 0.13168512311364922, 0.11792644139911447, 0.11773052119782992, 0.1727976141763585, 0.13105989380606584, 0.22673156724444457, 0.15542253080223287, 0.1538990568369627, 0.2058175980512585, 0.14568807743489742, 0.17366723822695868, 0.12443877623549529, 0.17433475383690425, 0.09171341905104262, 0.1614051197788545, 0.13792847309793743, 0.11518391141934053, 0.13500344433954783, 0.10816421559346573, 0.0695086998332824, 0.1912749098347766, 0.12784363781767233, 0.11081333844257252, 0.13409643300942012, 0.1172961773616927, 0.12695272133818694, 0.1349946776671069, 0.17458483470337732, 0.1380895030285631, 0.10818432058606829, 0.18866377137601376, 0.09410441360835518, 0.14996582003576414], [0.037189571386469264, 0.03534658206626773, 0.017546050450099365, 0.042972382690225325, 0.04371368898344891, 0.034400141066206355, 0.06148350331932306, 0.02281891893861549, 0.06511939928999969, 0.032262552196958234, 0.04605517423312579, 0.10853671774800334, 0.032222966463970285, 0.005814037485314267, 0.049133772429611, 0.016435012121551802, 0.06192398111202887, 0.026593498985416124, 0.013248908533049482, 0.01615896032723997, 0.019949384166726043, 0.019426444013203894, 0.02139177150093019, 0.056377364455589225, 0.030399376459951912, 0.027060381968372633, 0.017919782449358275, 0.02786721269200955, 0.020771509069683294, 0.038130265194922686, 0.053258960002235005, 0.05207700967522604, 0.05670595182371991, 0.013335172386307801, 0.028732070034103732, 0.112947738197233, 0.046274140876318724, 0.028363052156886885, 0.047307532746344805, 0.060234103218785355, 0.11268904672137328, 0.02224991813168994, 0.03738364936517818, 0.06961356063506433, 0.050702470753874095, 0.028427316208503077, 0.03338587709835597, 0.02844667311624757, 0.03281856414728931, 0.18263949320784637, 2.834357589483261, 23.081186158316477, 51.555247919900076, 62.62439182826451, 62.52604702540806, 46.88587086541312, 47.699105398995535, 34.19375630787441, 39.93604292188372, 35.47341646466936, 34.96379736491612, 49.89015729086739, 61.227519035339355, 102.73508466993059, 99.22097764696393, 55.62413733346121, 41.36023950576782, 27.673537220273698, 13.282926831926618, 2.542442270687648, 0.0865047060485397, 0.11620904212551457, 0.08297083460326705, 0.06569083434130464, 0.043530209721731286, 0.4919345772692135, 0.10668792016804218, 0.45286040540252415, 0.10571801542703595, 0.009457489791592317, 0.047516962579850636, 0.025883878581225872, 0.02808430657855102, 0.21103337460330554, 0.10926879596497331, 0.15084186302764074, 0.18987704627215862, 0.32503111181514605, 0.07295253646693059, 0.029109030163713863, 0.0882942471653223, 0.2419658862054348, 0.2330943393920149, 0.35284407223973957, 0.2893856588218893, 0.7132320425340107, 0.1795686608446496, 0.01945368549786508, 0.17654277464108808, 0.1831491951431547, 0.4943462535738945, 0.3165005152778966, 1.9392711051872797, 10.357441663742065, 29.689729009355815, 76.78296538761684, 76.7368085043771, 71.24018587384904, 48.64252485547747, 12.974200129508972, 17.38119149208069, 34.88177388054984, 59.804208346775596, 62.722833905901226, 70.0674272264753, 74.59137153625488, 72.840731212071, 61.39060020446777, 34.971047810145784, 12.715926034109932, 1.5321322892393385, 0.19111674332192966, 0.03093332584415163, 0.0274659644014069, 0.025915315108639852, 0.02858806454709598, 0.03799226474282997, 0.03887370887345501, 0.025488820226330842, 0.022585679311305285, 0.04933283764070698, 0.010100517072714865, 0.012728730865222002, 0.020063501882499883, 0.02010059230295675, 0.009718168526887894, 0.03304507609988962, 0.03606919471972755, 0.014158216704215323, 0.054226198100617955, 0.01961048476264945, 0.050653494096228054, 0.03608680609613657, 0.030749375000596046, 0.0855425094653453, 0.03203124300177608, 0.0471109882928431, 0.03567421609269721, 0.011178224912977644, 0.023578640672245195, 0.042790138362241645, 0.030735787336847613, 0.018155568279325962, 0.057882612970258505, 0.02590049590383257, 0.038720672085349045, 0.10303190563406263, 0.04416576633229852, 0.03510055883920618, 0.009625224496370979, 0.006902421225926706, 0.019442789921803132, 0.008258153701068034, 0.029446764183895927, 0.019921350492430583, 0.02015416433901659, 0.0328088780598981, 0.01593617013921695, 0.03678035030939749, 0.032012471330485175, 0.008486307708413472, 0.022346517769619823, 0.05061730103833335, 0.0354466490181429, 0.03717738829020943, 0.039639815621610196, 0.007247530921761478, 0.06899761368653604, 0.07227869012526103, 0.06114941303219114, 0.07909984660467931, 0.07135770775909935, 0.14382883720099926, 0.04038936611531036, 0.04531392561537879, 0.07037841209343501, 0.014301297687260168, 0.08103540845747505, 0.025661520959277238, 0.022399066914139048, 0.06613001613212482, 0.05084142454766801, 0.013369312875771096, 0.056114598376942534, 0.03619203330682857, 0.08361142594367266, 0.051244057049708705, 0.07058401498943567, 0.022549647405477505, 0.022017358735735928, 0.03451806705977235, 0.023150457934077297, 0.01293531000348074, 0.018122197927108834, 0.020176391449889967, 0.05077148115794573, 0.011287567438557744, 0.03616356197744608, 0.05112696565421564, 0.029236506537667344, 0.052502780221402645, 0.07166281103023461, 0.02859591180458665, 0.05263037533898439, 0.03267587501821773, 0.02270022450414087, 0.10147896967828274, 0.03667023086122104, 0.04249216649415238, 0.01916451592530523, 0.017523032845929265, 0.05005712627566286, 0.07798019597040755, 0.060152346534388404, 0.04244579201830285, 0.08117538344647203, 3.0829971390111104, 26.41579863003322, 57.96931069237845, 78.18533420562744, 79.13348538534981, 67.6860294342041, 59.93858650752476, 43.18019853319441, 47.454817158835276, 45.54659169060843, 39.19033793040684, 22.233023030417307, 36.06896046229771, 58.77620152064732, 70.91631644112724, 54.97597115380423, 50.23905413491385, 29.784742150987896, 17.26554046358381, 4.491988241672516, 0.23357419935720308, 0.2435676088290555, 0.024429342077512826, 0.04616314951064331, 0.052610640147967, 0.13688519836536475, 0.05520648103473442, 0.010102875830073441, 0.08310520489301, 0.048417361586221626, 0.032392345768000395, 0.21765588995601448, 0.18184619077614375, 0.4167191061590399, 0.3105900952858584, 0.5013078600168228, 1.2252441453082221, 0.6364604734948703, 0.07517976659749236, 0.11832930121038641, 0.14912651292979717, 0.1558154025780303, 0.12986917341394083, 0.18365626436259064, 0.0913438345970852, 0.19625257487807954, 0.08248362610382692, 0.05461764156020113, 0.2124465594866446, 0.49130245404584066, 0.6284450207437787, 0.06896661142153399, 2.80477237701416, 13.068742530686514, 35.04986470086234, 70.86291258675712, 58.58589036124093, 41.613080978393555, 38.075086048671174, 25.740065472466604, 38.14693737030029, 55.637543882642476, 79.29300212860107, 77.99284826006208, 81.58228765215192, 90.1971297945295, 87.93389306749616, 78.55042730058942, 45.278724738529746, 15.37336880820138, 1.7201678050415856, 0.2726943758981568, 0.044542943593114614, 0.025433935225009918, 0.01671108596825174, 0.004446509527042508, 0.017073018243536353, 0.009919022525926786, 0.003684928183377321, 0.040529887324997356, 0.04389938705467752, 0.045231008636099954, 0.03142324509099126, 0.03262941911816597, 0.039398073950516324, 0.01843070235502507, 0.030808811275554553, 0.060781429920877726, 0.018957384629175067, 0.027047444001904557, 0.053004570438393524, 0.03610400017350912, 0.03301920695230365, 0.015792420799178735, 0.06836232848997627, 0.03511192769344364, 0.04401624096291406, 0.02412295637519232, 0.028295990844656314, 0.012594284240289457, 0.06113942499671664, 0.05980786109077079, 0.0019607433475487468, 0.02758714397038732, 0.058039178140461445, 0.009040901520555573, 0.04980309972805636, 0.03186062537133694, 0.14838980031864984, 0.003331338284104796, 0.015216576966590114, 0.02434193150007299, 0.02036139232638691, 0.07120182790926524, 0.006341944515172924, 0.008268501360102423, 0.016311118412496786, 0.027386514736073356, 0.025967737027843083, 0.06321633247924702, 0.049601011643452306, 0.08494330197572708, 0.04836416783343468, 0.07261995252754007, 0.031456466165504286, 0.03854535559990576, 0.1686981227248907, 0.15101592083062443, 0.11723654770425387, 0.09923052854303803, 0.20735100576920168, 0.15150997574840272, 0.1832578285996403, 0.14018538913556508, 0.13530065624841622, 0.13952423818409443, 0.08736868468778473, 0.19796156031744822, 0.1205249862479312, 0.12379355728626251, 0.23688789297427448, 0.19375286544007914, 0.1334262711129018, 0.15197363229734556, 0.08281812351197004, 0.14531488317464078, 0.17041601054370403, 0.1472642600004162, 0.06811142659613065, 0.19804131532354013, 0.10613481913294111, 0.09185485967567988, 0.11396241267876965, 0.09955255447753839, 0.0929040987310665, 0.06487920467874833, 0.09288500475564174, 0.15129843567098888, 0.1604757575052125, 0.09814139162855488, 0.13501659434820923, 0.22672403550573758, 0.15584509527044638, 0.15751722268760204, 0.15766941809228488, 0.17620110511779785, 0.20086763080741676, 0.1129714869228857, 0.13003462739288807, 0.1723405122756958, 0.21509701226438793, 0.09493137137698275, 0.1339215745351144, 0.1551810944718974, 0.15975471905299596, 0.38498600465910776, 5.197627314499446, 37.09729037966047, 77.14935084751674, 95.10191876547677, 95.55996486118862, 74.29401642935616, 73.96462317875454, 55.143335887363975, 63.30334200177874, 51.46458087648664, 54.83078507014683, 72.73510469709123, 88.8805434363229, 139.46499252319336, 136.20257704598563, 84.64599159785679, 61.41155597141811, 42.74882657187325, 21.290385246276855, 6.019387287752969, 0.6773506764854703, 0.2646926838372435, 0.1875346755342824, 0.1342521839376007, 0.22225901723972388, 0.5504080653190613, 0.22680924593337945, 0.5264403085623468, 0.28087908242430004, 0.14188073602105888, 0.18290948229176657, 0.18667708869491303, 0.17467281355389527, 0.39705923252872055, 0.1743624923484666, 0.31836860360843794, 0.7792580596038273, 0.5091594872730119, 0.2464997757758413, 0.1985179047499384, 0.4072353850517954, 0.40210557888661114, 0.4707430601119995, 0.6205745030726705, 0.5222472878439086, 1.03333956854684, 0.2437369983111109, 0.10352373495697975, 0.37157671419637545, 0.6007242596575192, 0.9665525066001075, 0.524352429168565, 3.7536552889006476, 17.309399230139597, 47.03375979832241, 112.42967687334333, 112.42400714329311, 100.93192986079625, 69.25143078395298, 22.98191898209708, 29.806562968662806, 52.7795969418117, 79.76797403608049, 85.1866934640067, 91.7426176071167, 98.76620415278843, 104.51458086286272, 93.38162122453961, 57.353453636169434, 20.41305010659354, 2.3222595027514865, 0.3285610409719603, 0.1418053779218878, 0.17436482650893076, 0.1183953769505024, 0.10659481837813344, 0.0901769647108657, 0.14454822002777032, 0.0856791121352996, 0.11185116453894547, 0.15654898035739148, 0.13752781174012593, 0.08986019063740969, 0.09956566377409867, 0.12846266531518527, 0.08423027702208076, 0.13040375044303282, 0.0868405673120703, 0.09862387073891503, 0.138922404763954, 0.12002292461693287, 0.14134079856531961, 0.08972206804901361, 0.07048033483858619, 0.0921449266108019, 0.1242355549974101, 0.16219729584242615, 0.1128944664129189, 0.1211445972855602, 0.09068283970866885, 0.10521387069353036, 0.16594303984727177, 0.08907864043223006, 0.11212427488395146, 0.1685672468904938, 0.07388755772262812, 0.18613769406718866, 0.1251650122659547, 0.17894896838281835, 0.09726159633802516, 0.04313908517360687, 0.09150903073272534, 0.1307382003537246, 0.16635636266853127, 0.06128520824547325, 0.14620646461844444, 0.13023824218128408, 0.0879719905289156, 0.10796749472085919, 0.16844607410686357, 0.21802432090044022, 0.1300413313188723, 0.21970695203968457, 0.14240985762860092, 0.24835888030273573, 0.20136795538876737], [0.05508843969021525, 0.043853362024362595, 0.05053362070715853, 0.03896878520026803, 0.06210425429578338, 0.029324624487864118, 0.04617322575567024, 0.05165638242449079, 0.0754267940563815, 0.012519437586888671, 0.020831204884286438, 0.02499421908786254, 0.014893957313948443, 0.053509658335575035, 0.0320388154525842, 0.019493579964286516, 0.049199559792344055, 0.030284619224922996, 0.00798638939990529, 0.02519166768927659, 0.04457714854340468, 0.03485309033255492, 0.04600017896986433, 0.022429863922297955, 0.032041916357619424, 0.057424506837768216, 0.05393800052947231, 0.01785309093871287, 0.021068943198770285, 0.015441613105524863, 0.0628146668896079, 0.041067897741283686, 0.06740158397172179, 0.08881981324936662, 0.0732950202322432, 0.0394937745295465, 0.05887874987508569, 0.06386547336088759, 0.054878382211817164, 0.03589294185595853, 0.10338922217488289, 0.04065853077918291, 0.057756242608385425, 0.05061171669512987, 0.059127100477261205, 0.022711467829399874, 0.09038673381188086, 0.3859022169240883, 1.7541151834385735, 6.577966000352587, 27.701166731970652, 53.50959553037371, 55.90199926921299, 53.51295845849173, 46.33929777145386, 28.486611945288523, 26.24465581348964, 27.56637167930603, 30.947259153638566, 39.884713104793, 37.25953776495797, 76.63606657300676, 70.15679495675224, 35.28199011938912, 21.33912512234279, 7.0814420240265985, 0.5351535667266164, 0.04562192623104368, 0.2628897620098931, 0.048157696412610154, 0.01405938044523022, 0.06471921969205141, 0.012714243294405085, 0.06523067224770784, 0.09401910140046052, 0.29404252607907566, 0.04151195819888796, 0.1376769401665245, 0.13680979955409253, 0.05419215260605727, 0.11366486150239195, 0.04633145672934396, 0.17282369706247533, 0.09281605202704668, 0.09742692139531885, 0.2794734021382672, 0.41437495765941484, 0.13031738650585922, 0.22333349101245403, 0.12364749583814826, 0.08837945080761399, 0.17616587557962962, 0.21502607821353845, 0.22769830322691373, 0.2711694634386471, 0.6061397290655545, 0.22552693688443728, 0.14120245884571755, 0.0164140284261001, 0.21466682106256485, 0.38040244632533615, 0.188054976186582, 0.023387346383450285, 0.16494879605514662, 0.010786297997193677, 3.127907689128603, 28.52256887299674, 67.30871445792062, 73.97430896759033, 85.54756900242397, 41.17566408429827, 21.057431255068096, 18.979626314980642, 27.59381880078997, 54.1534538269043, 54.204175676618306, 64.7053564616612, 67.69013581957135, 62.310472215924946, 48.32555498395647, 22.928153821400233, 6.193707168102264, 0.18214614396648748, 0.14877774593021187, 0.004134932607744953, 0.03975950241354959, 0.0227521697524935, 0.06833980112735714, 0.07307284072573696, 0.007205095341695207, 0.026253235725952045, 0.05045909042071019, 0.02357988748034196, 0.027496293220402937, 0.026693280952583467, 0.005953613410903407, 0.0936048354155251, 0.029458587656595876, 0.06354842787342412, 0.028171075940398232, 0.03529179375618696, 0.03821217794237392, 0.0521892325819603, 0.023278304109615938, 0.028489096821951013, 0.07357488878603492, 0.07786217837461404, 0.08420824499002524, 0.04035518830642104, 0.031733688432723284, 0.033239449241331646, 0.05438094140429582, 0.01588718330354563, 0.00871686966690634, 0.03272450901567936, 0.0708994319928544, 0.014873555462275232, 0.06010777356901339, 0.11420182697474957, 0.012486390386974173, 0.016459240910730193, 0.026235498820564578, 0.0036374273393968387, 0.058929151456270895, 0.018716811734650816, 0.009794447737346803, 0.05458752817607351, 0.07043059822171926, 0.0474910798615643, 0.03447866792391453, 0.024788203981838057, 0.06599939135568482, 0.03264426885704909, 0.05825692002794572, 0.054451844921069484, 0.0553833072605942, 0.020347691008022854, 0.04559594173250454, 0.04989844746887684, 0.017374479477959018, 0.009342321194708347, 0.012487351362194334, 0.04342236336586731, 0.014739429445138999, 0.07775813860020467, 0.03387490067897098, 0.03780734698687281, 0.01553430438174733, 0.010794762721551316, 0.017528620581807833, 0.04640800905014787, 0.02359195861832372, 0.06526054135922875, 0.020101832325703332, 0.009435628241460239, 0.017937597386272888, 0.04220658128282853, 0.06381680204399995, 0.013904420010346388, 0.020600567438772747, 0.06354890284793717, 0.030084654954927306, 0.061763181883309565, 0.009640461848383504, 0.030271598137915134, 0.03748134483716317, 0.04296511218750051, 0.008534216521573918, 0.0696394806727767, 0.05172150482290557, 0.04196078197232314, 0.020464984267683964, 0.0185046609757202, 0.030888406825917106, 0.038276316465011666, 0.036006053643567223, 0.038680224612887414, 0.02748624242043921, 0.028807119399841343, 0.05479353140773518, 0.04020517099914806, 0.06309883057006768, 0.09762727921562535, 0.23483828295554432, 1.8132678036178862, 7.403203981263297, 36.60669892174857, 63.95656994410923, 74.2120554787772, 71.2744335447039, 66.4554339817592, 44.90997689110892, 50.08321646281651, 41.84455674035208, 37.574468340192524, 30.809604917253765, 25.865527357373917, 49.73667158399309, 58.73661068507603, 45.65928452355521, 26.73753670283726, 10.189591424805776, 0.9525289790970939, 0.15381272004118987, 0.1852423128272806, 0.2888447307050228, 0.01802257541567087, 0.07959174378109829, 0.04936268300350223, 0.1227051599749497, 0.20333611406385899, 0.20530341778482708, 0.1954447789383786, 0.6359939128160477, 0.3227132904742445, 0.580084852874279, 0.9495138951710292, 0.5958338677883148, 0.8746896673526082, 0.5552451514772007, 1.250473814351218, 1.7356046395642417, 1.631998747587204, 0.7500652032239097, 0.756902882031032, 0.5294466529573713, 0.5101465657353401, 0.4934647008776665, 0.7651073474969182, 0.43728485118065563, 0.5439795159867832, 1.32211506153856, 0.3429645209440163, 0.2027856864567314, 0.1649419292807579, 0.14954078570008278, 0.21510793667818817, 0.05107509843739016, 0.1058434969080346, 0.21820920812232153, 0.1066619526328785, 4.186027356556483, 28.73685826574053, 59.76504829951695, 60.35724326542446, 42.28093835285732, 27.550917148590088, 31.53341613497053, 35.29842608315604, 50.93940476008824, 74.80360426221574, 72.38023935045514, 82.40003504071916, 82.00168091910226, 79.92285633087158, 71.17430305480957, 34.83108329772949, 8.38635150023869, 0.24696278093116625, 0.18689563125371933, 0.010634734478246952, 0.07250315629478012, 0.06326552626809903, 0.02912146771060569, 0.03774201084992715, 0.028480258903333118, 0.041434191300400665, 0.04308787274307438, 0.060017446987330914, 0.05137386419145124, 0.009462667013784605, 0.024805795002196516, 0.05377812750105347, 0.014961147547832556, 0.07884785226945366, 0.039052770872201235, 0.0823667145201138, 0.05046126512544496, 0.0352134059981576, 0.014598380674475005, 0.023712417243846824, 0.06119625908987863, 0.009580610818894846, 0.03958434538383569, 0.00824542438411819, 0.05568644956552556, 0.03206558705174497, 0.012510902464522846, 0.07116872897105557, 0.0145380640003298, 0.037452188187411854, 0.032537443696388176, 0.009753821301274002, 0.04219059160511408, 0.07007209424461637, 0.010233052773401141, 0.02620354151752378, 0.0341386574187449, 0.035060688121510405, 0.014956328252862607, 0.011076305560501558, 0.02473075581448419, 0.04107046260365418, 0.08267056928681475, 0.04587509782452669, 0.020982501230069568, 0.026128900969134908, 0.036660683873508654, 0.058202087613088746, 0.044134950664426596, 0.028709549456834793, 0.0661830436438322, 0.1662023895020996, 0.1512212319565671, 0.13701679344688142, 0.14673675330621855, 0.13434697527970585, 0.12553693088037626, 0.12916239776781627, 0.11792017173554216, 0.19428251630493573, 0.0841019389086536, 0.10390192323497363, 0.14123638559664997, 0.08654940115021807, 0.12266295509678976, 0.08671664646161453, 0.15261966548860073, 0.13026224875024386, 0.1306083830339568, 0.13294012791344098, 0.05555648296805365, 0.11958088619368416, 0.09890056374881949, 0.07855618399168764, 0.07956040903393712, 0.11640732362866402, 0.20324396900832653, 0.11802588749144759, 0.09919734139527593, 0.10274955364210264, 0.10405560463134732, 0.13043254746922425, 0.12451041596276419, 0.20379492587276868, 0.21156244192804607, 0.1969159242830106, 0.1538412592240742, 0.0985911042828645, 0.14218991728765623, 0.12096208493624415, 0.15768134673791273, 0.194954388109701, 0.19396083642329487, 0.1355128205780472, 0.11577263554292065, 0.227529375148671, 0.10632495821586677, 0.23936090884464128, 0.6556230080979211, 2.704134885753904, 12.546924131257192, 54.931113583701, 76.97307504926408, 90.52791268484933, 81.60037381308419, 71.87990651811872, 45.580863680158345, 42.38382032939366, 47.454567023685996, 50.68886661529541, 61.795548166547505, 55.47262144088745, 107.03515107291085, 98.246965272086, 52.05129371370588, 35.69017594201224, 13.75388354914529, 1.241216208253588, 0.35703969853264944, 0.5301181312118257, 0.3788572320980685, 0.10635959742856876, 0.5073280398334775, 0.20089725564633096, 0.22172568871506623, 0.23104491936308996, 0.34657842559473856, 0.21258320286870003, 0.37170867568680216, 0.34387025662830895, 0.2860084543270724, 0.5062125282628196, 0.235405049685921, 0.4821427198393004, 0.4222889829959188, 0.603193855711392, 0.8190665149262973, 0.5938419603875705, 0.24862950720957347, 0.27031782056604114, 0.3579921717090266, 0.25682919578892843, 0.23930974730423518, 0.3523707262107304, 0.37467379229409353, 0.44905881796564373, 1.1636623697621482, 0.47201914020947044, 0.318540272968156, 0.39628722252590315, 0.3925293598856245, 0.6407774218491146, 0.4251402142856802, 0.15679659135639668, 0.23678456566163472, 0.6398020141891071, 5.543255031108856, 42.43921136856079, 95.91425350734166, 103.70268385750907, 118.34084292820522, 57.45681503840855, 35.81196049281529, 33.67745998927525, 44.04738235473633, 77.6109196799142, 75.42768451145717, 91.95848424094063, 92.29039968763078, 98.15183053697858, 85.42819895063127, 44.087949412209646, 9.41547611781529, 0.3093029686382839, 0.19850368265594753, 0.1324158510459321, 0.2877399671290602, 0.24617578887513705, 0.12621614443404333, 0.1350454727986029, 0.07565455112074103, 0.11520725302398205, 0.12768799545509474, 0.13857886248401233, 0.1434197620089565, 0.06713940482586622, 0.07452079374343157, 0.12933070159384183, 0.2476243797157492, 0.21091062761843204, 0.12311305451606001, 0.16911225978817257, 0.17191652288394316, 0.1035099064132997, 0.07371720472084624, 0.17567172566694872, 0.13910087304455893, 0.13421855574207647, 0.12088813818991184, 0.17349281401506492, 0.1626085423465286, 0.09532541701836245, 0.20337811538151332, 0.17013079513396534, 0.128675657457539, 0.09529031640184776, 0.2412236231778349, 0.0911022082769445, 0.21840016144726956, 0.2483834975532123, 0.1585800935115133, 0.11064679880759545, 0.04960537123094712, 0.10360176648412432, 0.14676058345607348, 0.1008535571662443, 0.08866209456963198, 0.13095651221062454, 0.17772718465753964, 0.133265526166984, 0.1635700264679534, 0.0791909195748823, 0.1309958943831069, 0.10971793186451707, 0.09577520431152411, 0.0768567794667823, 0.08705383086843149], [0.05748474717672382, 0.01683162771431463, 0.01613257379670228, 0.014485930458509495, 0.009097534597718289, 0.053030690643936396, 0.036955765182418485, 0.07367022974150521, 0.013500432982774717, 0.022825281900752867, 0.02737926798207419, 0.04848511330783367, 0.029961046230580126, 0.023835566260718873, 0.01600659528880247, 0.03199163352006248, 0.027898074160995226, 0.024236799284283603, 0.028675103626613106, 0.02912194947046893, 0.013613799221015402, 0.03328492805095656, 0.021549781950722848, 0.06045605202338525, 0.07190145858164344, 0.039320232413176975, 0.032129413448274136, 0.006443117479128497, 0.06388529336878232, 0.0265417759572821, 0.01841936742753855, 0.04712155308308346, 0.07365044366036143, 0.01980930400480117, 0.019780415376382213, 0.05484101528834019, 0.0447445125984294, 0.05625128247109907, 0.007979083274091994, 0.037209103016981056, 0.030347675484205996, 0.030662895712469305, 0.0529441367169576, 0.12210110095994813, 0.25294295432312147, 0.9186281753437859, 3.0529967716761996, 6.142329147883824, 11.485437410218374, 28.54841443470546, 42.161867073604036, 48.10420969554356, 48.915668964385986, 44.72786808013916, 19.371268476758683, 21.720332826886857, 23.17847830908639, 37.98336287907192, 24.409928389957972, 29.91852276665824, 48.44294132505144, 29.657947949000768, 10.368995649474007, 1.7591240746634347, 0.06621998309024743, 0.38225837530834333, 0.09496184438467026, 0.026808180679966296, 0.13075274814452442, 0.08315086351441485, 0.04057511507666536, 0.02885040993403111, 0.03193636005744338, 0.10053721056985003, 0.28935612897787777, 0.2581624085349696, 0.1516499032399484, 0.11559840132083211, 0.23009239190391131, 0.15447662584483624, 0.1909052710980177, 0.7871883969221796, 0.6469603415046419, 0.5873935978327478, 1.4287939029080527, 1.1610746000494276, 2.1178465400423323, 1.213100974048887, 0.12312008413885321, 0.5811630178775106, 0.13297735234456404, 0.27452574191348894, 0.28970201898898396, 0.18571639167410986, 0.2394799781697137, 0.33385497118745533, 0.11042265833488532, 0.05040253113423075, 0.06619372378502573, 0.19366910707737717, 0.029357017749654393, 0.12619800040764467, 0.05480132098974926, 0.0992467048178826, 0.11563175810234887, 0.1485587012554918, 0.19299867376685143, 0.5472161280257362, 15.623858315604073, 59.34016595567976, 95.6280711037772, 62.810624395098, 36.54859113693237, 20.649658850261144, 15.246494701930455, 25.741335255759104, 34.28509037835257, 44.88183321271624, 51.84408800942557, 59.92643410818917, 56.347535133361816, 49.340346336364746, 15.86345478466579, 0.6781960225531033, 0.05957028562469142, 0.06883479920881135, 0.03349764199395265, 0.036143626618598185, 0.07916082654680524, 0.04980515568916287, 0.005831606877369008, 0.011030480698017138, 0.012081271054090133, 0.02126625270050551, 0.02772067626938224, 0.006395187461748719, 0.07701622841081449, 0.02778271133346217, 0.06797717165734087, 0.019630577880889177, 0.034109460056892464, 0.058846879085259776, 0.005073620497049498, 0.053795586207083294, 0.019764451143730963, 0.025932870505909835, 0.042680714412459304, 0.021407201387254254, 0.015010227682068944, 0.02446329596984599, 0.027449635456183126, 0.02142649213783443, 0.030307363718748093, 0.06530893447675876, 0.009459530485660901, 0.015300560942185777, 0.031086803680019717, 0.07144519127905369, 0.06624105838792664, 0.008097385006424571, 0.04857303787555013, 0.05206154925482614, 0.019827000198087523, 0.03817218169569969, 0.031240861663328748, 0.002108095072409404, 0.053019559276955466, 0.04973475768097809, 0.028397219787750925, 0.04445181634011013, 0.024274042375119667, 0.02813086934786822, 0.02889320853033236, 0.021466062603784457, 0.02831784476126943, 0.028383204646940743, 0.017291698205683912, 0.03667853952252439, 0.03147499017151339, 0.012342155046228851, 0.008455849119595118, 0.06613030111683266, 0.04027220008096524, 0.06064684249992881, 0.02613308244118733, 0.04896460347143667, 0.03940653867487397, 0.021445837171216096, 0.006393972035896565, 0.05215078339512859, 0.025827680614643862, 0.019549862747745853, 0.030881573978279318, 0.018803062017208765, 0.05180113769269415, 0.05518290533551148, 0.013474238138379795, 0.019716650048004727, 0.014049057383090258, 0.05015880814088242, 0.045185546789850504, 0.023094170061605315, 0.000680593577271793, 0.048356931257460795, 0.06146922015718051, 0.035800430391516, 0.07570149217333112, 0.03482993871771863, 0.041822988473411114, 0.040736413028623374, 0.061511961078005176, 0.04293108365631529, 0.038174448002661975, 0.05806874191122396, 0.015404487061979515, 0.02817365267713155, 0.025244925902890306, 0.025801794503682425, 0.006417360713904989, 0.10511705053171941, 0.19478509362254823, 0.7150421568325588, 2.42995462673051, 6.5003402914319715, 15.441688707896642, 47.74924012592861, 67.99052728925432, 68.72707108088902, 67.40720517294747, 61.84793063572475, 42.00414991378784, 31.436235155378068, 25.27731023515974, 35.38411474227905, 22.39185537610735, 33.826637813023154, 45.48605898448399, 36.53176607404436, 15.451237269810267, 2.5315904872758046, 0.14216690137982368, 0.25079929935080664, 0.051419689053935666, 0.08114859488393579, 0.09919850169015781, 0.21423737624926226, 0.4984934596078736, 0.056414426038307805, 0.5305687870298113, 0.7401235795446804, 1.129496231675148, 0.9387102063213075, 1.2782789851937975, 1.274515992828778, 1.8504709558827537, 1.685636235134942, 0.8359567714588982, 3.0604717305728366, 2.923023985964911, 2.129366001912526, 6.022056698799133, 5.704709018979754, 7.7034408535276135, 6.320566509451185, 3.576350288731711, 3.380873577935355, 1.8430044651031494, 1.2216757025037492, 0.9024912012474877, 1.3089204324143273, 0.8274108128888267, 0.766027169568198, 0.8279312221067292, 0.9986795655318669, 0.2376466579735279, 0.5409657891307558, 0.3630303485052926, 0.28947082853743006, 0.08724905896399703, 0.14151085301169328, 0.052908381314149926, 0.1266962486718382, 0.29206592642835205, 0.890292118702616, 17.22492824281965, 57.985420090811594, 62.43236446380615, 36.22817495891026, 29.116106578281947, 29.362378529139928, 37.34785284314837, 43.77250814437866, 52.68930510112217, 58.30346693311419, 68.11845752171108, 76.76206520625523, 73.49892016819545, 68.93002101353237, 25.57784414291382, 0.9753577198301042, 0.05373243156022259, 0.011959823463777346, 0.0650343517107623, 0.07442592097712414, 0.02964069288490074, 0.06313614999609334, 0.013615334406495094, 0.055042821780911515, 0.021790239494293928, 0.016787636592718105, 0.03218761139682361, 0.07557301156755004, 0.014508797088637948, 0.020003672057230557, 0.03782043932005763, 0.012386654220920588, 0.023090351605787873, 0.03613918221422604, 0.04676260805821844, 0.04337715257757476, 0.015399638929271271, 0.008863268686192376, 0.023403758449213843, 0.017270931641438177, 0.015684861124360135, 0.0338437660996403, 0.02117223828099668, 0.061076110894126553, 0.05704860522278717, 0.10209465199815375, 0.015015072422102094, 0.04186996684542724, 0.045697277544864585, 0.07249546849301883, 0.027144150509099876, 0.05159604709063258, 0.008840519951523414, 0.04445505973749927, 0.027501896223319427, 0.05571276315354875, 0.027967294910922647, 0.061818672477134635, 0.02334862238993602, 0.029695426912180016, 0.0024853637234108256, 0.024976712884381413, 0.12478058146578924, 0.033396944004510126, 0.015174451816294874, 0.015720893030187914, 0.022625841799059083, 0.06871908863208123, 0.07361239820186581, 0.17042895699185984, 0.14284280368259974, 0.08083978002624852, 0.07536748331040144, 0.14218394617949212, 0.13103132748178073, 0.16093640135867254, 0.06890433547752244, 0.15828721065606388, 0.14052604085632733, 0.08556419544454132, 0.07620405592024326, 0.11280827889485018, 0.09278960951736995, 0.18005413907979215, 0.08180755416729621, 0.09160797470914465, 0.12273764823164258, 0.11919625183301312, 0.09414939369474139, 0.09450093590255294, 0.17947448018406117, 0.16650179986442837, 0.1315707221095051, 0.14870237426034041, 0.20115188269742898, 0.11273864084588629, 0.17787646236164228, 0.15894609530057224, 0.10427357043538775, 0.13704469480684825, 0.11894276472074644, 0.137097335553595, 0.12931375178907598, 0.11215510072984866, 0.1741833183914423, 0.16023981730852807, 0.14665583121989453, 0.08773132772850138, 0.13080344828111784, 0.10560806561261415, 0.19205276880945477, 0.2308380747480052, 0.2857242567198617, 1.4981193372181483, 4.18721376146589, 9.999254209654671, 29.324802671160015, 74.85107435498918, 90.88332693917411, 84.89113099234444, 80.43545968191964, 70.19049371991838, 32.39116777692522, 30.175901412963867, 34.90104818344116, 54.72847979409354, 40.016673292432515, 48.14515542984009, 71.08976432255336, 45.963129247937886, 19.02273988723755, 3.780071905681065, 0.2678755559027195, 0.7019562018769128, 0.328755183411496, 0.12871327543897287, 0.24786637244479998, 0.4018863577927862, 0.3343456062887396, 0.10449424359415259, 0.5682485965745789, 0.42091652378439903, 0.6735311214412961, 0.5231598903025899, 0.8801701675568308, 0.7098422444292477, 0.7634834232074874, 0.5668642765709332, 0.42000465414353777, 2.078537323645183, 2.8769467898777554, 2.6296514996460507, 5.2840715902192255, 5.236663596970694, 10.518315042768206, 5.934330480439322, 2.241550096443721, 1.726457118988037, 1.3709420072180885, 0.8553188496402332, 0.45776393370968954, 0.78333480656147, 0.4577228959117617, 0.41513084567018915, 0.3523661121726036, 0.4377236733479159, 0.1716892272233963, 0.39836918509432245, 0.31323860745344845, 0.29315459515367237, 0.341236482241324, 0.24273089372685977, 0.32327036772455486, 0.2829770584191595, 0.3774578757584095, 1.6143548829214913, 25.33187096459525, 92.65148367200578, 133.8138975415911, 87.48296887534005, 54.69671263013567, 32.14242226736886, 25.49919053486415, 39.1603217124939, 52.491295337677, 66.97068459647042, 79.04339504241943, 94.06964574541364, 92.60756410871232, 79.02401651654924, 29.815741539001465, 1.1481143640620368, 0.1467006823846272, 0.14748748445085116, 0.15975898025291307, 0.22861435264348984, 0.11114118620753288, 0.15583275950380734, 0.06715167952435357, 0.1828376254332917, 0.08294282467769724, 0.07275653484144382, 0.18305886856147222, 0.12076613759355885, 0.11007073614746332, 0.11994910000690392, 0.12756538417722496, 0.04991226244185652, 0.10968038173658506, 0.1006328161539776, 0.09583508502691984, 0.11696189029940537, 0.1523629892617464, 0.10965449562562363, 0.07546650192567281, 0.10994163128946509, 0.13729477567332132, 0.09917361981102399, 0.13026184162923268, 0.13862790699516023, 0.11487920848386628, 0.15974832725312027, 0.09443532835159983, 0.1555897896843297, 0.12976337623383316, 0.16950500942766666, 0.11954089333968503, 0.14558109960385732, 0.10549926252237388, 0.13403270500046865, 0.09745152507509504, 0.11748565148030009, 0.07510251538561923, 0.156792018030371, 0.10136031425957169, 0.12028843536973, 0.11117047177893774, 0.09179485682398081, 0.18795695501778806, 0.1932809307639088, 0.10471915759678398, 0.09950924358729805, 0.1180747284420899, 0.15169980270521982], [0.0332432863568621, 0.045043895819357464, 0.015988936414942145, 0.020303586231810705, 0.012385248805263212, 0.032206725728298934, 0.019054705210562264, 0.031860265747777054, 0.06437592847006661, 0.031613662373274565, 0.010040009560595666, 0.03623354947194457, 0.04807419928589037, 0.03516835466559444, 0.05277554451354912, 0.0674566470884851, 0.016391460351379852, 0.03271733350785715, 0.021850342429908257, 0.04759324348664709, 0.004581857331296695, 0.04956498143396207, 0.0065931644723085416, 0.013442458950781395, 0.03386156068050435, 0.06461997716022388, 0.009455283704612936, 0.03615533134766987, 0.06335581213768039, 0.056392329545425515, 0.004069632093887776, 0.04021600381072078, 0.01321215059475175, 0.024806763610935638, 0.011421190491611404, 0.059681090393236706, 0.046504249064517875, 0.04795381360288177, 0.07272725605538913, 0.026595068097646748, 0.11198818111526114, 0.08751674781420402, 0.39896336463945253, 2.871161763157163, 4.698579898902348, 9.578856059483119, 17.18466690608433, 27.52335885592869, 36.197224208286826, 44.30627223423549, 48.048766544886995, 36.130149773189, 49.66632454735892, 18.65078718321664, 27.674040964671544, 47.57680320739746, 73.51501219613212, 67.25143350873674, 35.11588995797293, 17.543675116130284, 6.363875934055873, 0.9599064460822514, 0.04698821755924395, 0.1239841849144016, 0.06196468642779759, 0.21325373117412838, 0.017895346706999198, 0.036047417138304026, 0.08701606360929352, 0.22794599565012114, 0.03853759315929242, 0.18177096838397638, 0.34241927734443117, 0.8570206697498048, 1.6110952006919044, 1.2164839868034636, 0.9066542578595025, 2.260863265820912, 1.445062784211976, 2.398876420089177, 4.60544798203877, 4.028521248272487, 3.524883896112442, 1.6024315570081984, 5.195549368858337, 6.97189542225429, 6.522372160639081, 8.240888357162476, 6.555310096059527, 2.9652722903660367, 2.7525382084505896, 4.369047684328897, 4.115265599318913, 1.5473363591091973, 0.4286233516676085, 1.4765215132917677, 0.9162400577749524, 0.8239136976855141, 0.4353553961430277, 0.24272519403270312, 0.04455728103805866, 0.07322715315967798, 0.04077960517523544, 0.03150398058018514, 0.06524115561374597, 0.13874818411256584, 0.13666305957095964, 0.09969489755375044, 0.18824717801596436, 0.23207930528691836, 13.66012976850782, 61.4349297114781, 78.7318308694022, 80.49080208369664, 39.32137748173305, 38.857074533190044, 37.42120844977242, 33.18643774305071, 44.90085390635899, 39.900582790374756, 55.69405705588204, 61.59529413495745, 61.58727591378348, 32.47415706089565, 4.56479754618236, 0.3128187299839088, 0.03802445444411465, 0.05977701488882303, 0.0009114930539258889, 0.05126788041421345, 0.05756659885602338, 0.036504088169229884, 0.030646746579025472, 0.06220003629901579, 0.06777558568865061, 0.017706479877233505, 0.010690285292054926, 0.004348088022587555, 0.06079373176076582, 0.03975495622892465, 0.028151303429954817, 0.02932606976745384, 0.02360910689458251, 0.034189340591962845, 0.017442115848617892, 0.05514119239524007, 0.050077774096280336, 0.04933992154630167, 0.020722286443092992, 0.015268922550603747, 0.022055127691211443, 0.032185012607702186, 0.01803293325273054, 0.05595148873648473, 0.024873339770627872, 0.004441383194976619, 0.039873011144144196, 0.049890545928584676, 0.025133887039763585, 0.03603320522233844, 0.028518860760544027, 0.04019813798367977, 0.06721331086009741, 0.012482084234112074, 0.04236742800899914, 0.023402593065319315, 0.014998349926567503, 0.02665157649399979, 0.01095205222788666, 0.006263311212283692, 0.0179431647661009, 0.04036989216027515, 0.028114331753126214, 0.046375049211617024, 0.03469593144421067, 0.06611339202416794, 0.07751812040805817, 0.05106909679515021, 0.020396842388436198, 0.05388744967058301, 0.023315045084538202, 0.06674846008952175, 0.03035186543794615, 0.021765908924862742, 0.04033926648220845, 0.015897354543475167, 0.09922088656042304, 0.044880633508520465, 0.04124071043250816, 0.024945880253134028, 0.038137070901159725, 0.030813598340111117, 0.0417279121465981, 0.006675220560282469, 0.06170853945825781, 0.026855942759928957, 0.02871462150609919, 0.05294349889404007, 0.021649536776489446, 0.017898713937029243, 0.06341628317854234, 0.015172853866325957, 0.029871377827865735, 0.008800035159635757, 0.07506554201245308, 0.05459391997594919, 0.007281917380169034, 0.03848123064796839, 0.038743199447968175, 0.02192643334689949, 0.02537579834461212, 0.05794805088745696, 0.043444768592183075, 0.0198713899590075, 0.05271096494314926, 0.021558984581913267, 0.12518215206052574, 0.10679362235324723, 0.04939895409292408, 1.7900479010173251, 4.677733566079821, 9.909843053136553, 20.16102852140154, 38.60545941761562, 60.264241627284456, 64.75688430241176, 72.15226895468575, 61.355358941214426, 68.59526375361851, 35.853889397212434, 21.03371184212821, 26.090549979891094, 42.49126032420567, 52.02444240025112, 40.585018566676546, 24.37695918764387, 10.382696628570557, 1.4135717025824954, 0.1076498996200306, 0.1006108723314745, 0.15275287548346178, 0.09995922765561513, 0.20283996925822326, 0.23276793690664427, 0.4340968222490379, 1.1980655065604617, 2.1145828408854346, 1.1135301398379462, 1.5645222940615244, 2.2424040734767914, 3.3663071138518195, 2.6480212339333127, 4.594175398349762, 5.974848900522504, 5.603525876998901, 7.013934629304068, 6.6627548677580695, 9.766742297581263, 8.123924987656729, 7.258335777691432, 10.830638306481497, 11.929679172379629, 12.004442657743182, 13.72142243385315, 12.052777801241193, 10.274686881474086, 5.104246999536242, 5.4163379328591486, 2.542389724935804, 3.209656719650541, 3.27648948771613, 2.333984587873731, 2.769783854484558, 3.052508443593979, 1.8206663323300225, 1.990202920777457, 1.0478329679795673, 0.6543357457433427, 0.47011837363243103, 0.15878517393554958, 0.09211095236241817, 0.050691773649305105, 0.045703116338700056, 0.06473013732050147, 0.24898777369941982, 0.39602264815143173, 13.491911275046212, 53.11465297426496, 56.775384357997346, 50.95237704685756, 29.252117565699987, 39.05170052392142, 54.374715736934114, 50.46358517238072, 63.092151505606516, 57.64767510550362, 69.29211248670305, 74.36284528459821, 78.02532414027623, 50.048065526144846, 8.582770126206533, 0.3247747884265014, 0.043635403005672355, 0.027551542934296385, 0.0323463580571115, 0.03946946940517851, 0.05767589049147708, 0.05027516332588025, 0.0478051974704223, 0.049626015658889494, 0.061089769804051945, 0.027272074716165662, 0.019172032396974306, 0.04490476899913379, 0.008750400323021625, 0.05542954942211509, 0.02942503409992371, 0.06423711377595152, 0.049990385571228604, 0.019182924580361162, 0.06051624486488955, 0.02346274010570986, 0.0455642812885344, 0.011267681273498704, 0.04924173413642815, 0.025897347501346042, 0.010610242756748838, 0.05529119613181267, 0.06153714151254722, 0.024207661294245293, 0.028016775380820036, 0.03970865639192717, 0.01649703022225627, 0.03732805699110031, 0.05256147010784064, 0.01105372391508094, 0.05219117997746382, 0.05245549311595304, 0.024293604539707303, 0.009545269322448542, 0.02672760634283934, 0.01983489834570459, 0.02923161430018289, 0.040115811329867156, 0.05268679891846009, 0.010020906255314392, 0.036302454703088315, 0.02143940296290176, 0.020113703295854584, 0.02639164329905595, 0.050351104965167384, 0.007127041762162532, 0.10682169334696871, 0.1808310073933431, 0.11251656990498304, 0.1452586461922952, 0.09787247462996415, 0.17079343886247703, 0.14067936262914113, 0.09431117001388754, 0.15819822757371835, 0.1905230658927134, 0.24310221523046494, 0.1371337864547968, 0.13532112086457865, 0.1655020463679518, 0.08358598766582352, 0.13103007897734642, 0.13209672245596135, 0.13323227795107023, 0.19564244976001127, 0.09187623352876731, 0.12305075143064771, 0.1418886070272752, 0.1137756866269878, 0.08073897007852793, 0.1807086132466793, 0.18696207340274537, 0.09683995467743703, 0.11148020265890018, 0.17627533684883798, 0.10807607389454331, 0.08043755803789411, 0.1208494481231485, 0.061632102488407066, 0.1486143275563206, 0.07416511925735644, 0.09144254108624798, 0.12055212764867715, 0.1754645417843546, 0.2548840801630701, 0.08247248455882072, 0.2253207436629704, 0.24167598890406744, 0.6854896768927574, 4.220664995057242, 8.643911668232509, 17.729681866509573, 36.38896322250366, 61.46484865461077, 87.87296431405204, 83.89246640886579, 80.55683081490653, 58.977845191955566, 66.98818710872105, 32.34438555581229, 40.27421522140503, 67.05307633536202, 97.1295142854963, 91.6918888092041, 53.946772711617605, 29.74522774560111, 11.177979622568403, 1.7203878675188338, 0.3140538808490549, 0.23048879206180573, 0.27014023438096046, 0.5933540665677616, 0.1761453973927668, 0.2361535280942917, 0.3261140537049089, 1.5622964820691516, 2.032230402742113, 0.5347367833767618, 1.2218283457415444, 1.8474141827651431, 5.1292678969247, 4.66123593705041, 4.937333898884909, 9.20763291631426, 7.633003490311759, 7.3667849983487805, 11.534867763519287, 11.062007239886693, 9.036829692976815, 7.271685872759138, 19.268452508108957, 20.097072090421403, 19.980314561298915, 21.222332852227346, 19.572644642421178, 13.379340035574776, 9.393800343785967, 14.4287177835192, 10.449373279299055, 9.562344534056527, 5.51373256955828, 5.5919206483023505, 3.5531680583953857, 2.9903083869389127, 2.0670450031757355, 0.990876087120601, 0.6679211567555154, 0.4662901876228196, 0.29623365136129515, 0.14971891471317836, 0.25170897053820745, 0.2811051160097122, 0.3055157390023981, 0.21699051851672785, 0.44671130393232616, 0.4147932609277112, 22.766533511025564, 88.33978598458427, 104.32021195547921, 109.92027241843087, 52.915083340236116, 51.26975686209542, 47.00307307924543, 48.810897077832905, 65.48159531184605, 64.16032586778913, 79.83724757603237, 90.0738548551287, 95.88252803257534, 55.69134031023298, 8.466822062219892, 0.35085827165416306, 0.11792250589600631, 0.17390370768095764, 0.07666727142142397, 0.17561544797250203, 0.14126932168645517, 0.16738579528672354, 0.13509664790970938, 0.11667752984379019, 0.14164455155176775, 0.13652329492781842, 0.11608200679932322, 0.20343458306576523, 0.07397915995014565, 0.0982659367312278, 0.09755720011889935, 0.09525296983442136, 0.11771500988730363, 0.06596851801233632, 0.1640697403677872, 0.1143437765006508, 0.09255558278943811, 0.0911987434540476, 0.1913446360932929, 0.05471999517508915, 0.14999838971665927, 0.13668279136930192, 0.15839831398001739, 0.10345461937998023, 0.10238526176129069, 0.11844453002725329, 0.1346506875540529, 0.2549762252186026, 0.15333003737032413, 0.1391301043331623, 0.09616084290402276, 0.21228520385921001, 0.16436548664101533, 0.1214267321463142, 0.17021437707756246, 0.07640395912208728, 0.08028284526829209, 0.19864435653601373, 0.1336635819503239, 0.093772460706532, 0.07939551145370517, 0.08704395818391017, 0.11068379253681217, 0.08732413886381046, 0.11344854453844683, 0.10499703125762087], [0.016584445888708745, 0.053785018024167845, 0.030191483508263315, 0.03143776574039033, 0.02296857492599104, 0.018078082972871404, 0.012702901581568378, 0.014675843928541456, 0.06283318411026682, 0.0533461653228317, 0.030238007261816944, 0.020209917865161384, 0.051464194165808816, 0.053157973635409556, 0.03529741202614137, 0.04414857564760106, 0.05142016063577362, 0.07143356797418424, 0.09030931296625308, 0.05598869959690741, 0.026006552623584867, 0.017368667825524296, 0.0342294759383159, 0.0074558691620560625, 0.0168558921265815, 0.02737636724486947, 0.03376619936898351, 0.01987911168751972, 0.01335614760007177, 0.023662195474441563, 0.041838157123753, 0.02686333709529468, 0.004661158991179296, 0.021484242253271595, 0.03234162188268133, 0.012451409362256527, 0.029046143538185527, 0.0563915356594537, 0.0770683806123478, 0.06728469274405922, 0.22843682074121066, 1.4596951476165225, 7.853482859475272, 15.909106186458043, 16.021792071206228, 21.50889045851571, 40.55505098615374, 44.31216083254133, 44.89570876530239, 51.03567205156599, 23.18343584878104, 20.06377284867423, 25.164728573390416, 31.143250465393066, 66.76774856022426, 62.729497228349956, 44.25075612749372, 18.27602740696498, 2.934341950075967, 0.19024171813258103, 0.12858412308352335, 0.04860984840031181, 0.07249280863574573, 0.10227243495838982, 0.01927413834658052, 0.052161986008286476, 0.18342012060540064, 0.2941030242613384, 0.3392704948782921, 0.674988831792559, 2.87656746166093, 1.6197446222816194, 0.3847382308116981, 2.641258465392249, 2.642287450177329, 2.6540405452251434, 2.902652736221041, 2.7864818956170763, 7.167255750724247, 9.352409056254796, 3.7471921614238193, 8.146873150553022, 4.667980032307761, 2.59685817360878, 9.597102897507803, 9.054023010390145, 8.983084508350917, 8.8499196767807, 7.210852222783225, 11.056477342333112, 2.8805205523967743, 2.641497092587607, 2.2687279752322604, 6.037696659564972, 5.791298772607531, 2.3103761289800917, 5.097900688648224, 1.9925488063267298, 1.8423372209072113, 3.009600494589124, 1.1811274268797465, 0.43025699257850647, 0.06846539117395878, 0.015351020198847567, 0.12143947503396443, 0.08470156708998339, 0.13350533401327475, 0.035190271346696785, 0.11140354855784348, 0.0762297452560493, 0.26618546087827, 0.28222402025546345, 16.64677906036377, 65.37300886426652, 92.76148060389927, 68.04555007389614, 38.97275856563023, 20.306558540889196, 23.020618711199077, 28.567398650305613, 46.94137307575771, 54.747076647622244, 62.56856305258614, 68.10546439034599, 50.42316402707781, 7.7337957961218695, 0.8416866468531745, 0.08710522989609412, 0.034661000461450646, 0.008388176277678992, 0.009918133645052356, 0.028301432695505873, 0.08488518545137984, 0.021419530368543098, 0.013541579346305557, 0.022991582352135862, 0.021032124192320874, 0.05115466345367687, 0.06233772462499993, 0.025336994623233165, 0.0526049133124096, 0.012816987915097602, 0.08523450884968042, 0.052493145024137836, 0.024409924101616656, 0.03944294886397464, 0.029776274359651973, 0.036712880179818184, 0.06143443166677441, 0.01958798454143107, 0.0330980018313442, 0.028927440622023175, 0.02698955817946366, 0.04187742394528218, 0.023591617654476846, 0.03333914639162166, 0.05364426611257451, 0.00874497543554753, 0.01389663721368249, 0.020545696008152196, 0.032882332868341885, 0.008341667791163283, 0.044638518643166335, 0.03758968313091567, 0.02736805349455348, 0.054049334555332146, 0.05995038737143789, 0.06734016976718392, 0.03498826129361987, 0.030672059327896153, 0.028366646696148173, 0.03607917936252696, 0.028869290170925002, 0.03970159962773323, 0.03424034946198974, 0.01867690369752901, 0.04415525243218456, 0.03721315047836729, 0.025875293416902423, 0.09094305788832051, 0.037348508036562374, 0.036027251077549796, 0.025647816248238087, 0.06995668222329446, 0.005514034677097308, 0.04691329372248479, 0.023521925322711468, 0.0006221654569214609, 0.03327943870265569, 0.06740346351372344, 0.048183385748416185, 0.02411716168613306, 0.02630187481242631, 0.06177211140415498, 0.05279434332624078, 0.035459544576172314, 0.025554680531578403, 0.03887575465653624, 0.042095074230538945, 0.008468315504225237, 0.054254801744329076, 0.06541184788303715, 0.022672536882704923, 0.055512194987386465, 0.07401958028120653, 0.011476575064339807, 0.005602173407429031, 0.028429360295246755, 0.07645170763134956, 0.043357220611401966, 0.03720101148688367, 0.0345916406118444, 0.02255697388734136, 0.07822708772229296, 0.09498126405690398, 0.04301515753780093, 0.0657806180949722, 0.7342079484036991, 6.074974179267883, 17.82422947883606, 19.856598411287578, 36.674117292676655, 63.673291887555806, 68.45452104296002, 66.02420793260846, 72.17688642229352, 48.08178091049194, 34.56615890775408, 35.617824350084575, 23.214120830808366, 35.311801365443635, 51.878686564309255, 44.76852893829346, 23.838147231510707, 4.1095563513892035, 0.2670073839170592, 0.3684484234877995, 0.13431052437850408, 0.02269116266896682, 0.08461233973503113, 0.15840220877102443, 0.501580251114709, 1.0661308318376541, 1.8300232759543826, 2.869762352534703, 4.250027648040226, 4.412747076579502, 3.845700681209564, 2.26818254164287, 1.841137136731829, 1.3478739878961017, 2.738008439540863, 0.6798997968435287, 3.4752027562686374, 5.843154481479099, 9.12201634475163, 9.38357172693525, 11.004263366971697, 7.836387685367039, 10.8992144209998, 19.938872030803136, 16.965491192681448, 15.18627119064331, 9.644718033926827, 7.828683870179312, 4.8241850904056, 2.1985453069210052, 1.0069065583603722, 2.7726247991834367, 5.42689311504364, 5.236625381878444, 5.776761404105595, 2.7437174703393663, 0.9871286196368081, 1.638043680361339, 4.517688759735652, 2.83801321046693, 1.5501287749835422, 2.367799516235079, 1.5699080164943422, 1.1957147355590547, 0.7706739402243069, 0.45376619536961826, 0.1290040412651641, 0.11047948564269713, 0.10284300148487091, 0.31475773879459923, 0.2884163579770497, 18.04960819653102, 55.60949053083147, 56.5778158051627, 51.8581337928772, 31.116878577641078, 30.4637131690979, 43.741783210209434, 44.32603291102818, 65.32826246534074, 67.18481418064663, 74.86122567313058, 83.11018957410539, 75.4664693559919, 17.998436450958252, 1.4220489391258784, 0.09287542384117842, 0.013491149775550833, 0.03941890836826392, 0.07662449657384839, 0.019960177962535193, 0.06579691650612013, 0.012367966518338238, 0.022178838195811425, 0.009044272143260708, 0.05742129736713, 0.044393808381365876, 0.04610167423795376, 0.006907564945452447, 0.026502985806603516, 0.03770796535536647, 0.10132084387753691, 0.06002934170620782, 0.008904465091680842, 0.047019847469138246, 0.06089009730411427, 0.04175171854772738, 0.03230716248175927, 0.01582230517773756, 0.012413380867136376, 0.020283747564202974, 0.032825505560530086, 0.04982628866231867, 0.06063310895115137, 0.02857395101870809, 0.01335494828942631, 0.04925891803577542, 0.08123311320585863, 0.030663221409278255, 0.032253157879625044, 0.017183895954596143, 0.012318176466838589, 0.0277414292629276, 0.0185183673830969, 0.021644203491242867, 0.07369965101991381, 0.06129219715616532, 0.06332269284342017, 0.057562507289860926, 0.033532630652189255, 0.07614436519465276, 0.05343143342595015, 0.0225070795110826, 0.0324650881146746, 0.011444734808589731, 0.1555389402700322, 0.09038493569408144, 0.07985527999699116, 0.15722699968942574, 0.1376226166529315, 0.06956731847354344, 0.0917439056294305, 0.1217969815645899, 0.15526576207152434, 0.19220018732760633, 0.15389535203576088, 0.20176272706261703, 0.15920459000127657, 0.11812171020678111, 0.0843131940013596, 0.10956636749740158, 0.17469209751912526, 0.25634276760475977, 0.2577893499817167, 0.16765126532741956, 0.11278646399400064, 0.09579676136906658, 0.13646993493395193, 0.08032840210944414, 0.0940240275646959, 0.12928339413234166, 0.08869583133075919, 0.0913687911150711, 0.14192550576158933, 0.1716281726424183, 0.13405159541538783, 0.08174280835581677, 0.08876141174031155, 0.15885031329733984, 0.09463015611150435, 0.17276720223682268, 0.10988920767392431, 0.12507108944867337, 0.11615952263985362, 0.24431912707430975, 0.3209195424403463, 2.955153976167951, 10.981889298983983, 27.048129865101405, 39.38562052590506, 64.13807078770229, 89.49654987880162, 87.73573739188058, 76.51793330056327, 73.3117982319423, 37.6724031993321, 28.546005146844045, 34.51732349395752, 43.80293778010777, 93.49265343802315, 90.09331675938198, 62.789925711495535, 29.228299140930176, 5.114432624408177, 0.9184867143630981, 0.4568065479397774, 0.18769696754004273, 0.20431217311748437, 0.4485479082380022, 0.19282176611678942, 0.3192453251353332, 0.914773227913039, 1.774251822914396, 2.8620005633149828, 6.232280961104801, 9.563472747802734, 6.178663449628012, 4.846480556896754, 8.613203236034938, 11.621886134147644, 13.117518884795052, 11.914605055536542, 14.112042341913495, 18.412517820085796, 18.75985653059823, 14.380851643426077, 18.82274467604501, 15.963008574077062, 16.440985577447073, 24.757906334740774, 25.25261286326817, 31.04578808375767, 25.416065761021205, 22.22985986300877, 24.48038833481925, 16.655304500034877, 14.428946205547877, 15.841885839189802, 19.08063054084778, 15.845674344471522, 13.223948785236903, 18.826112815311976, 12.678717562130519, 8.947400297437396, 10.122994678361074, 4.512310854026249, 2.399460503033229, 1.038931239928518, 0.7301708278911454, 0.6129285533513341, 0.3601209260523319, 0.2451036764042718, 0.2004828200276409, 0.24313521917377198, 0.30894578780446735, 0.4769660404750279, 0.616777203977108, 26.69444223812648, 94.00661168779645, 127.64339692252022, 89.67245742252895, 53.6294241632734, 32.89908109392439, 34.61911112921578, 42.368881702423096, 69.10913167681012, 75.94918155670166, 84.6908769607544, 98.10893930707658, 87.04452364785331, 19.95939874649048, 1.638023487159184, 0.31365851206438883, 0.140711050214512, 0.08686310146003962, 0.17090456932783127, 0.1110455874087555, 0.16263230464288167, 0.09568345959165267, 0.07654896884092263, 0.06592390433486019, 0.11796264802770955, 0.13856123414422783, 0.162382020215903, 0.09392205732209341, 0.09054950757750443, 0.1277534740843943, 0.17504929192364216, 0.13308101892471313, 0.1325568234814065, 0.23449687127556118, 0.24198293100510324, 0.11805624514818192, 0.2619652444762843, 0.11708076963467257, 0.1686498788850648, 0.13193426760179655, 0.11822125129401684, 0.08965865216617074, 0.09978645906916686, 0.08466181850859097, 0.08561788792056696, 0.10230746093605246, 0.1373991479298898, 0.2688250435250146, 0.11429725613977228, 0.18597568704613618, 0.13379011516060146, 0.1245813500136137, 0.11942510812410287, 0.09202726185321808, 0.20748606137931347, 0.23569169001919882, 0.15002587038491452, 0.18240701353975705, 0.19902839378586837, 0.13620017655193806, 0.15030512825718947, 0.1461624005543334, 0.1427621937223843, 0.18382034770080022], [0.014571463190285223, 0.06074666178652218, 0.062018039636313915, 0.0073442874709144235, 0.052788898082716126, 0.05627910240686365, 0.0359156490303576, 0.057530052959918976, 0.02619242711391832, 0.14354819511728628, 0.036392028110900095, 0.017802075283335786, 0.03499396098777652, 0.037734485896570344, 0.030692686792463064, 0.0035920129905986998, 0.0335121762140521, 0.055415680166333914, 0.03469506631206189, 0.03883022156410983, 0.04490352049469948, 0.029790917145354406, 0.09468999611479895, 0.057121513810540946, 0.060525004751980305, 0.016230371048940078, 0.01613328286579677, 0.030876515499715294, 0.06314157827624253, 0.02201510769581156, 0.03219577756577304, 0.018391610256263187, 0.0444821027506675, 0.030932755874735967, 0.02047740145852523, 0.02327118458093277, 0.055338289854781966, 0.04297604338665094, 0.20490484631487302, 1.0836042485066821, 7.037875081811633, 19.236440420150757, 27.021320240838186, 23.74134840284075, 30.16782065800258, 37.07231160572597, 44.40367555618286, 33.16114630017962, 30.587860107421875, 14.754661253520421, 17.821618693215505, 31.170605523245676, 45.108122144426616, 65.66024044581822, 31.28988872255598, 14.579827206475393, 2.1796034319060187, 0.05443557704399739, 0.11603418365120888, 0.019552257976361682, 0.04598080679508192, 0.14519495889544487, 0.0993653398805431, 0.0707474130072764, 0.06443887616374663, 0.20753999134259565, 1.0835977345705032, 1.3455717457192284, 1.7265545023339135, 1.6748061648436954, 2.537700342280524, 3.9728279624666487, 3.078732899257115, 2.862879727567945, 3.236562098775591, 7.988562788282122, 10.6239241872515, 8.03564030783517, 3.351210198232106, 7.409770028931754, 6.877956645829337, 11.066197872161865, 6.8703696472304205, 10.834136724472046, 11.792682409286499, 13.872451084000723, 20.236722196851456, 14.625742639814105, 9.74444031715393, 5.894737907818385, 4.88703545502254, 22.211659056799753, 46.95963988985334, 54.117444787706646, 49.87098373685564, 39.69005584716797, 25.951044048581803, 30.23427322932652, 11.39377851145608, 14.5354950938906, 5.884292594024113, 1.443968877196312, 2.480069160461426, 1.1240146458148956, 1.049118276153292, 0.10262105268027101, 0.1496428373668875, 0.0428045674094132, 0.10258815730256693, 0.05158994706081493, 0.2595112275864397, 0.051702543161809444, 0.09506565345717327, 3.1393900215625763, 26.650451455797466, 53.23049681527274, 77.26626123700822, 61.74495833260672, 36.69246401105608, 22.452507938657487, 21.380595445632935, 37.540946756090435, 58.83057117462158, 54.045114040374756, 60.558199065072195, 58.032626152038574, 27.221080950328282, 4.3233111671039035, 0.10070206743798085, 0.04198345521997128, 0.018067156862733618, 0.04177665470966271, 0.020485603250563145, 0.06638015806674957, 0.0069421299433867845, 0.027539449743926525, 0.07629184478095599, 0.009635680721008351, 0.0209758074821106, 0.0692183750548533, 0.011880632489919662, 0.011285039047444505, 0.014648375134649021, 0.05482372282338994, 0.055253713857382536, 0.06778408094708409, 0.06763198732265405, 0.050387155530708175, 0.04980946099385619, 0.02568830273646329, 0.030062697561723844, 0.052282025638435564, 0.014448522822931409, 0.06315153917031628, 0.012987727681840104, 0.015029157112751688, 0.0465624198716666, 0.07415684113012892, 0.024299667250098925, 0.04759599494614771, 0.031089612814996923, 0.028566032515040467, 0.07480842473783664, 0.03545592459184783, 0.011237028454031264, 0.022738417544003044, 0.022168887479762946, 0.04582206692014422, 0.07030408536749226, 0.025743572806407298, 0.012997781874478927, 0.04289554199203849, 0.07174070006502525, 0.03805974505043455, 0.03542728362871068, 0.029333448835781643, 0.006517142256987947, 0.09334389798875366, 0.022791270332943116, 0.018762656953185797, 0.003405416284554771, 0.006570481894803899, 0.03171379039330142, 0.047815107474369664, 0.04568092145824006, 0.004733864018427474, 0.024242336130035774, 0.027901675485606705, 0.06627157210771527, 0.050257962463157516, 0.03855623590892979, 0.04438709427735635, 0.013711777981370687, 0.018841921717726758, 0.02925697115382978, 0.06174942797848156, 0.06256791084472622, 0.03489408063303147, 0.06377168625061001, 0.07190020329185895, 0.11427094255174909, 0.055734347352491956, 0.029547597880342176, 0.028048675008384243, 0.0511867785161095, 0.01898424613422581, 0.07804334043924298, 0.05011347521628652, 0.09310168134314672, 0.012001838352132057, 0.056226970561380894, 0.01969125078591917, 0.031385840848088264, 0.007825918412501258, 0.11707820477230207, 0.3587075376084873, 4.400929059301104, 20.13845556122916, 28.640321731567383, 35.22750929423741, 53.68643760681152, 59.513620785304475, 62.766739572797505, 54.585211413247244, 54.35575062888009, 35.65795367104666, 20.178022078105382, 21.271303755896433, 26.244388307843888, 49.649787834712434, 35.207408155713765, 21.018912179129465, 3.892615786620549, 0.1259418534381049, 0.09455582260021142, 0.07050998003355094, 0.055879462244255204, 0.09511013821299587, 0.49758894528661457, 0.4396482700748103, 1.4738176869494575, 3.15670536671366, 3.261059492826462, 5.1293616976056775, 5.277837319033487, 3.640880597489221, 3.740809372493199, 3.4664590997355322, 2.196262389421463, 1.4272784356560027, 3.5695855660097937, 7.94909702028547, 9.461351599012103, 4.534866443702152, 2.599476993083954, 3.3741475045681, 7.902029054505484, 14.290806463786534, 11.721473796027047, 9.839511649949209, 11.039839012282235, 10.787182535443987, 18.00678644861494, 11.350835170064654, 2.9129901358059476, 0.886751360126904, 4.5214894243649075, 26.897991452898296, 54.46693917683193, 60.475098609924316, 54.487738609313965, 40.94496999468122, 31.06653540475028, 32.08147266932896, 15.951615265437535, 15.065732104437691, 6.326206709657397, 4.818407663277217, 3.6490149838583807, 2.9241172415869574, 3.5102375277451108, 0.988705535020147, 1.9440833841051375, 0.48301222175359726, 0.37254340946674347, 0.0453477573714086, 0.3694979543132441, 0.026730612252971957, 0.18170281632670335, 2.671984919479915, 23.968837635857717, 44.781327520098, 50.997234616960796, 42.03370060239519, 32.77745982578823, 34.46924890790667, 42.528909138270784, 55.27595615386963, 79.36565249306815, 64.80428491319928, 71.69277763366699, 81.9011196408953, 45.89764247621809, 7.451756255967276, 0.01736615046060511, 0.038524226019425054, 0.09567001102758305, 0.03435285056808165, 0.06418993523610489, 0.07040751446038485, 0.008165447157807648, 0.00963547037515257, 0.054430467675306966, 0.03288150166294404, 0.03464054263063839, 0.04373055397133742, 0.02056048298254609, 0.06153035616236074, 0.019768897244440656, 0.05729901857141938, 0.026556378030883412, 0.0288337485066482, 0.0325879368798009, 0.02786665629329426, 0.02567968194905136, 0.06408638400690896, 0.0801920640681471, 0.04356849606015852, 0.05529837163963488, 0.01594717088820679, 0.03246482687869242, 0.04015738856313484, 0.03359068950105991, 0.024176453772400106, 0.058778014566217146, 0.007951959684890295, 0.01796740203696702, 0.03111702562975032, 0.06078717711248568, 0.034051709941455295, 0.10487479995936155, 0.032785034339342795, 0.039853211492300034, 0.03991484282804387, 0.03684921143576503, 0.020635243970900774, 0.01762690977193415, 0.03312384383752942, 0.042494928131678274, 0.04661986803902047, 0.0415011423506907, 0.0284948270501835, 0.12257561406918935, 0.18164704074817045, 0.10311231881912265, 0.07635457534343004, 0.18708886445633002, 0.13504822765077862, 0.12076946241515023, 0.15622649980442865, 0.2157224587031773, 0.18112629226275853, 0.12543536775878497, 0.07447590865194798, 0.16965976969472, 0.14562565221318177, 0.1975383580263172, 0.10862811641501528, 0.08246232688959156, 0.12300898081489972, 0.15417941393596785, 0.17315946333110332, 0.09656463909362044, 0.10081192904285022, 0.15337775195283548, 0.16931599671287195, 0.2575219529015677, 0.09664363414049149, 0.10348393209278584, 0.11390153451689652, 0.18815607790436062, 0.2334984748491219, 0.2153018619865179, 0.09008104700062956, 0.10881287471524306, 0.10059221261846167, 0.16461946229849542, 0.09896350465714931, 0.11993367012057986, 0.14606528862246446, 0.32662515342235565, 2.4232724138668607, 10.909970232418605, 28.74741952759879, 46.43681573867798, 67.9200656073434, 83.70224557604108, 86.28783702850342, 79.57689162663051, 59.80185290745327, 50.605484758104595, 23.95676166670663, 25.604528699602398, 40.63479546138218, 63.58363233293806, 90.9155387878418, 48.01552288872855, 24.574927261897496, 5.388234206608363, 0.43881139212421005, 0.29502439339246067, 0.15997415727802686, 0.23528207199914114, 0.324312896068607, 0.3667320284460272, 0.23192373077784265, 1.1418050740446364, 3.0542352880750383, 4.28767819915499, 5.391941939081464, 5.867608232157571, 5.934131588254656, 9.728806001799446, 11.181693434715271, 9.359041111809866, 8.852365442684718, 12.18935593536922, 14.75587545122419, 19.561405931200298, 16.6936012336186, 16.248193911143712, 22.94033922467913, 20.527598108564103, 26.303619963782175, 21.862286261149816, 24.541454315185547, 26.026630026953562, 28.419412442616053, 41.072931494031636, 30.991731098720006, 23.228501864842006, 19.39899352618626, 12.80700215271541, 28.522301367350988, 57.789345400674, 60.60373755863735, 55.48191813060215, 45.103421688079834, 35.40024845940726, 41.37090846470424, 21.23355766705104, 27.228784765516007, 18.446004663194927, 8.486663511821202, 9.89442413193839, 4.462124015603747, 3.7064175265175954, 0.6287362479737827, 1.1131208475146974, 0.2513632976583072, 0.28701947150485857, 0.13899274170398712, 0.5044205987027713, 0.1764336662100894, 0.2536606272416455, 4.876004321234567, 40.638182708195274, 77.17361395699638, 106.70247827257428, 81.5727755682809, 48.774735178266255, 31.629516669682094, 32.11218023300171, 54.71695620673043, 82.38761860983712, 75.3410335268293, 83.77295739310128, 98.95638329642159, 52.44803932734898, 6.921526193618774, 0.23188410433275358, 0.10264512031738247, 0.17380621576947825, 0.12572222522326879, 0.10437186301818915, 0.13190123651708874, 0.13741594845695154, 0.14371077210775443, 0.12073534567441259, 0.10734504062150206, 0.09823464269616775, 0.09753837077213184, 0.14074119074004038, 0.23060476726719312, 0.06871296146086284, 0.1823682284780911, 0.1379249854279416, 0.13569742281522068, 0.1491273000304188, 0.12668539211153984, 0.12432966780449663, 0.15547609435660498, 0.10209138824471406, 0.12880816177598067, 0.16507243870624475, 0.15318905136414937, 0.11508584953844547, 0.07885251380503178, 0.14002486132085323, 0.12330913756574903, 0.12450128288141318, 0.10933411853121859, 0.09104687374617372, 0.12147296752248492, 0.11685392180723803, 0.1927366235426494, 0.14922912099531718, 0.16311596440417425, 0.0964271475427917, 0.35224446441446033, 0.16030594733144554, 0.07944461703300476, 0.06721536682120391, 0.15426610356995038, 0.15975788102618285, 0.08291163920824017, 0.18961034129772866, 0.08939376566559076], [0.02677282052380698, 0.03580851852893829, 0.01875465363264084, 0.004014822579587677, 0.0601193154496806, 0.04726385544719441, 0.032721838980380974, 0.04633706482127309, 0.05328071383493287, 0.14069434468235287, 0.017559800962252275, 0.017847279286278144, 0.012780712584831884, 0.06571642189685788, 0.0163795384911022, 0.027485039717118655, 0.022483493633834378, 0.022122803077633892, 0.02136806518371616, 0.04586982560743179, 0.014975851401686668, 0.02549115608313254, 0.035149711915957074, 0.00668778533249029, 0.05847131673778806, 0.006965020322240889, 0.020165148124630963, 0.09887882348682199, 0.058413125574588776, 0.043774994622383795, 0.02055019130265074, 0.025651682201506834, 0.03399178172860827, 0.018682477862707207, 0.038906644963260205, 0.04691521058391247, 0.062365028874150345, 0.33483341868434635, 5.155758338315146, 14.51778587273189, 27.478647197995866, 33.68251827784947, 39.03355530330113, 36.90347385406494, 36.904085295540945, 37.887891156332834, 32.10148695537022, 19.632717030388967, 28.725296463285172, 42.54189532143729, 68.82103851863316, 65.10079233986991, 47.53054210117885, 17.14534878730774, 4.068582824298313, 0.37909363369856564, 0.07577193089361701, 0.08680851331778935, 0.015209862862580588, 0.035122607834637165, 0.11757049549903188, 0.06904699746519327, 0.3292781710624695, 0.4619569001453263, 0.8097033830625671, 1.6457023322582245, 1.4133032198463167, 2.7462355409349715, 3.7626762219837735, 2.4346279416765486, 2.802255174943379, 4.48857797895159, 7.897574390683856, 27.594966990607126, 55.433888707842144, 76.85082149505615, 68.32540266854423, 47.15760101590838, 23.50523819242205, 7.157113986355918, 9.151962212153844, 9.63638366971697, 5.982996531895228, 8.11831431729453, 18.594331332615443, 13.164591193199158, 3.082586761031832, 3.342405093567712, 0.7097870388201305, 5.128291240760258, 60.52031748635428, 107.24764783041817, 109.09482642582485, 110.816041128976, 108.031904901777, 100.47421033041817, 90.11325114113944, 80.87318924495152, 67.01900236947196, 55.84147351128714, 42.520918709891184, 33.006465503147666, 23.01973455292838, 12.57329341343471, 7.503031355994088, 4.579816511699131, 2.3572953598839894, 0.3712911323777267, 0.18475363190684999, 0.04228870776881065, 0.03520667153809752, 0.20466050585465773, 0.06142294406890869, 0.06962375223104443, 0.10201917854802948, 6.46688688652856, 27.09922865458897, 71.23518317086356, 84.91749245779855, 40.1756272315979, 24.681585584368023, 18.217136212757655, 21.866481236049108, 43.4427535874503, 61.33664744240897, 57.40353972571236, 55.69958087376186, 39.69493695667812, 5.172747118132455, 0.39095646142959595, 0.004567238294319915, 0.06681596075317689, 0.015146423231012054, 0.06213268491306475, 0.049154233653098345, 0.042640209264521084, 0.027641155357871736, 0.03273118240758777, 0.043149358193789206, 0.03229507098772696, 0.03898486987288509, 0.04737923354176538, 0.018527887229408537, 0.07241765409708023, 0.0062236355734057724, 0.04616844208378877, 0.0197385786034699, 0.02974054609824504, 0.018784488817410808, 0.06985311742339816, 0.016593017482331822, 0.042473832477948496, 0.06083208256001983, 0.03814518278730767, 0.04057292680123022, 0.012925103140462722, 0.018467643497777835, 0.017032923609284416, 0.024207649419882467, 0.046796365175396204, 0.05299235341538276, 0.04602167156658002, 0.06564327582184758, 0.06564977618732623, 0.07332647711570774, 0.040885894293231625, 0.00928219875121223, 0.04259449975298984, 0.019584200012364557, 0.019879009907266924, 0.02723642109361078, 0.03593688717644129, 0.015265209267714193, 0.0444924979071532, 0.030756564079118625, 0.01955551833712629, 0.03778998327574559, 0.022327946266159415, 0.02776101856891598, 0.044675352916653664, 0.024373778541173254, 0.05026662735534566, 0.03872644641835775, 0.056403386273554394, 0.0567452627500253, 0.08539469739688293, 0.05153292637052281, 0.0635157021294747, 0.04400048198710595, 0.02229674892233951, 0.017280712723731995, 0.0524014444090426, 0.02379595168999263, 0.049444836630885086, 0.011648526016090597, 0.010667429688120527, 0.03543226407574756, 0.08274924542222704, 0.02434607226002429, 0.0251469827656235, 0.056537369798336706, 0.05426947167143226, 0.06999273957418543, 0.0431500638702086, 0.03605759177090866, 0.01118667352212859, 0.048725304526409934, 0.0811302133702806, 0.008340861182659864, 0.040895322537315745, 0.02586359716951847, 0.04654561595192977, 0.10560846594827515, 0.6290718785354069, 4.123645561082022, 15.159399032592773, 30.041884558541433, 48.15109266553606, 61.897283690316335, 64.68249688829694, 63.27029636928013, 60.37598255702427, 56.83059126990182, 36.607744625636506, 32.65649863651821, 31.124459062303814, 33.62175280707223, 39.379631178719656, 46.10993773596627, 22.335675716400146, 5.944818351949964, 0.2767725613500391, 0.13331398713801587, 0.04977785822536264, 0.04698818702516811, 0.10654258475239788, 0.40909701372895924, 0.47389482813222067, 0.7730864307710102, 2.499953384910311, 2.31391384771892, 6.281844632966178, 5.784975911889758, 6.275322011538914, 3.39267617889813, 2.2951934465340207, 2.2464081900460378, 2.022261909076146, 8.77802666596004, 32.54833255495344, 62.183007512773784, 82.57952090672084, 76.3014691216605, 54.56158406393868, 23.371596540723527, 5.72344092811857, 4.117961066109793, 9.048183917999268, 8.526787621634346, 5.423543214797974, 7.060897937842777, 1.8571310213633945, 0.6293793906058583, 1.7980532028845377, 0.22348460076110704, 7.401669297899518, 70.95026533944267, 114.87155178615025, 117.2634413582938, 116.08006586347307, 113.0309670312064, 104.96048150743756, 97.86241027287075, 85.4626967566354, 74.72435310908726, 62.35514913286482, 47.86242280687605, 34.834230831691194, 25.211022683552333, 11.772804481642586, 8.110314335141863, 5.254906092371259, 5.089776073183332, 2.1112359804766516, 0.8681695429342133, 0.6817234275596482, 0.09447718717690025, 0.3273240716329643, 0.057943952535944324, 0.08706394782555954, 0.17108010633715562, 5.906024822166987, 30.187167916979107, 57.964822156088694, 53.29506295067923, 35.797272000994, 24.005001272474015, 34.973792348589214, 40.84630904878889, 66.34067753383091, 80.65295219421387, 69.26031058175224, 75.2724825995309, 62.91193607875279, 9.977768642561776, 0.4115758107176849, 0.05917550716549158, 0.04777868710724371, 0.02271163576681699, 0.11519776710442134, 0.03002965629899076, 0.044466974812426736, 0.0037805477622896433, 0.015298281064523118, 0.047328055037983825, 0.061410581160868914, 0.07566443059061255, 0.020285633891554813, 0.01609645368132208, 0.012282265849145395, 0.003314253196419616, 0.01954776098552559, 0.04980293348697679, 0.04248077728386436, 0.047398208773561885, 0.056853736750781536, 0.02989286363923124, 0.02568892020333026, 0.063048266140478, 0.0593482486105391, 0.02234211577368634, 0.022586401951100146, 0.09039611116583858, 0.03468953285898481, 0.05095421742381794, 0.08032705861010722, 0.04584221601752298, 0.07677070729966674, 0.011899249794493829, 0.0742211594645466, 0.008617674632530128, 0.028217436845547388, 0.021456876935969506, 0.0796354210802487, 0.024596553462158357, 0.03718692849257162, 0.03716045884149415, 0.03990599473140069, 0.02512499314200665, 0.019120095630309412, 0.017351924973939146, 0.022586871836600558, 0.16672073597354548, 0.13157366695148603, 0.0917361703302179, 0.08427440215434347, 0.1703103490706001, 0.1201673982931035, 0.10721550150109188, 0.13220745937100478, 0.1498946145709072, 0.2305032584284033, 0.08856864672686372, 0.12733400373586587, 0.12085904260831219, 0.13424607712243283, 0.07952354422637395, 0.11430014669895172, 0.1533998450530427, 0.1402430103293487, 0.10314574345414128, 0.13012190056698664, 0.11240248781229768, 0.08473030304802315, 0.1741079060094697, 0.08605711720883846, 0.15678540909928934, 0.15816955268383026, 0.13344014036868299, 0.18200142601771013, 0.1241252523447786, 0.11246133715446506, 0.10160779633692332, 0.12493397109210491, 0.1565573127674205, 0.1490981908781188, 0.18460831684725626, 0.08571961389056273, 0.2757467249674456, 1.195692696741649, 7.035021977765219, 23.816844054630824, 48.989260809762136, 73.7847204208374, 90.1768410546439, 84.33838789803642, 72.52850001198905, 66.18196678161621, 54.3152391569955, 32.49350084577288, 39.69988407407488, 53.881251198904856, 95.88222231183732, 93.95263808114188, 72.63841356549943, 28.16229087965829, 8.296929921422686, 1.3309767288821084, 0.2416812814772129, 0.17857099723603043, 0.11584473667400223, 0.3447399213910103, 0.5406594712819371, 0.4165232538112572, 0.44596070849469727, 1.9455944001674652, 1.6471625396183558, 5.694545541490827, 6.701581835746765, 8.596581407955714, 9.404694250651769, 10.99247053691319, 9.840989010674612, 12.854041457176208, 14.824643509728567, 35.498089517865864, 65.07961423056466, 88.11360127585274, 79.14447048732212, 57.69671549115862, 31.952607904161724, 22.775682551520212, 26.947969845363072, 22.515720912388392, 20.556844813483103, 20.546974897384644, 38.81210926600865, 24.677692856107438, 15.646016120910645, 15.017466442925588, 8.740254521369934, 9.258596215929304, 72.78344331468854, 119.75763620649064, 122.32068770272392, 121.27144023350307, 122.82240322657994, 111.93012918744768, 103.19014304024833, 87.3948448726109, 76.2710290636335, 63.64996678488595, 48.61911984852382, 43.262937682015554, 35.54618842261178, 22.70145842007228, 18.126917328153336, 12.888985684939794, 7.5600621700286865, 0.7766043362872941, 0.4114402394209589, 0.3170496400977884, 0.12250164018145629, 0.36414501869252747, 0.2031098362058401, 0.19544936583510467, 0.2713511751166412, 11.105423927307129, 42.14919703347342, 96.6665905543736, 113.36006845746721, 54.16685342788696, 35.30924790246146, 27.056347846984863, 32.71024642671858, 65.90601907457624, 87.74523557935441, 80.98784146990094, 90.32593550000871, 71.26467827388218, 10.610060794012886, 0.4501029205109392, 0.09883607578064714, 0.15947422624698707, 0.11895481550267764, 0.15508513604956015, 0.12701331451535225, 0.16685249390346663, 0.1418013609945774, 0.12814831361174583, 0.1522707220699106, 0.09983361046761274, 0.26078453926103456, 0.11438561496990067, 0.11416578319455896, 0.09791094756552152, 0.08823673453714166, 0.09100981216345515, 0.06934384296515159, 0.14784398674964905, 0.13789014944008418, 0.11514233079339777, 0.09754794490124498, 0.09056600276380777, 0.13266779109835625, 0.09247135623757329, 0.16523942617433413, 0.15622221146311077, 0.1834263088447707, 0.12787575966545514, 0.12658114199127468, 0.32075175430093494, 0.19900541859013693, 0.144090222460883, 0.14363413836274827, 0.12091764089252267, 0.1837583567414965, 0.10300759372434445, 0.06320629016097103, 0.1792562361806631, 0.17542468463735922, 0.16611686694834912, 0.14311987667211465, 0.13535385339387826, 0.06609281884240252, 0.13739515814398015, 0.08854703538651977, 0.08958311764789478], [0.020759188570082188, 0.023616341774218848, 0.0707102632150054, 0.015560126031881996, 0.04927349975332618, 0.04335804842412472, 0.12705102749168873, 0.03564285081146019, 0.05192427144252828, 0.0029810821121957687, 0.028605720028281212, 0.05544079614004918, 0.04479337729779737, 0.07292549006108727, 0.019264180845181857, 0.052826661949179, 0.0975267474672624, 0.026910225561420833, 0.04213692966316428, 0.04259262699633837, 0.03266799722665122, 0.03299250999199493, 0.07278046677155153, 0.03527785664690392, 0.07235570384987763, 0.05786763091704675, 0.03494146273338369, 0.04416690627112985, 0.02798661110656602, 0.03177052270621061, 0.007385052158497274, 0.037524231643016846, 0.012386247948078173, 0.0508290819956788, 0.06565866499607052, 0.05080612376332283, 0.1012967558843749, 6.260316073894501, 18.302336760929652, 39.8615061214992, 46.04234218597412, 49.60448210580008, 39.99204192842756, 22.105235236031668, 17.857679843902588, 19.924237387520925, 23.852927786963328, 30.71342100415911, 52.783522674015586, 82.03980568477085, 42.80805649076189, 23.456774507250103, 2.9735428180013384, 0.23312552486147198, 0.22552815824747086, 0.02942346329135554, 0.02806335172083761, 0.015934741823002696, 0.0857604006305337, 0.06906277340437685, 0.11027308207537447, 0.2594599574804306, 1.6814235640423638, 2.8589029695306505, 1.3663010448217392, 4.7172801068850925, 3.3315593898296356, 5.150356548173087, 4.143504815442221, 4.421537416321891, 9.695641381399971, 34.33549608503069, 76.14954675946916, 101.32874148232597, 100.12188802446637, 101.24999754769462, 97.98386478424072, 101.4656765801566, 81.26691586630685, 31.313356263296946, 14.652903148106166, 12.090190376554217, 7.467388834272112, 4.296910618032728, 2.1647525259426663, 2.434845507144928, 7.625370025634766, 14.80640969957624, 16.84360068184989, 61.72089672088623, 113.90177086421421, 101.96016597747803, 101.64940084729875, 101.98207364763532, 107.26353141239711, 102.95493956974575, 103.57908930097307, 104.28224699837821, 103.21401010240827, 99.10569313594273, 88.57472542354039, 81.76121071406773, 60.18320478711809, 38.574032715388704, 34.59236403873989, 15.628015075411115, 9.899501528058734, 4.726753541401454, 0.6343472983155931, 0.12576101028493472, 0.2853557307805334, 0.36733293905854225, 0.0506764625066093, 0.06008372628795249, 0.13800446902002605, 0.035879459365137985, 0.3537112942763737, 10.997638259615217, 38.07508257457188, 77.97234412602016, 69.50354616982597, 32.369406018938335, 26.562987531934464, 21.834291969026836, 43.68717384338379, 50.36523689542498, 56.671161379132954, 66.12920216151646, 33.78158916745867, 9.359713350023542, 1.2130050020558494, 0.21183215959795884, 0.10374899501247065, 0.015225175701613938, 0.02357038459740579, 0.07206862925418786, 0.038368071362908394, 0.04038083693012595, 0.03752803483179637, 0.048498924888138256, 0.017977476585656404, 0.04719181199158941, 0.0472473907949669, 0.03219020340059485, 0.040460351056286266, 0.03400218706311924, 0.03110308512779219, 0.01896686545972313, 0.0343082945660821, 0.042672521102109125, 0.07158273711268391, 0.06401680702609674, 0.08457838584269796, 0.018283623104382838, 0.08998235408216715, 0.040208807946848016, 0.05095475007380758, 0.05003325541370681, 0.04216084123722144, 0.037785874746207676, 0.06688850293202059, 0.014550537170310105, 0.027036896175039665, 0.019997588990788375, 0.049604414496570826, 0.04196978273934551, 0.020751650046025003, 0.028679490355508666, 0.03240732103586197, 0.11317140369543008, 0.01160632198609944, 0.023404508230409453, 0.08522883629692452, 0.015207067298303758, 0.012383745002028133, 0.0635367367150528, 0.018496717026989375, 0.024429072359842912, 0.09628977134291615, 0.07477941058043923, 0.033037534183157344, 0.07877539830016238, 0.13464721345475741, 0.05913480863507305, 0.031116682969565903, 0.04312703778435077, 0.003129453335921945, 0.014895680792895811, 0.024326596608651534, 0.10392936997647796, 0.06988458787756306, 0.049296804038541656, 0.06187756931675332, 0.06798215888972793, 0.02261249501524227, 0.08742148149758577, 0.0934762123173901, 0.005191259385485734, 0.04622074356302619, 0.020699893091140047, 0.04550942851762686, 0.01306300181230264, 0.025682813388162425, 0.03791758178600243, 0.058181955479085445, 0.03656267288273998, 0.025803417898714542, 0.04112509145800557, 0.005827457211645586, 0.0637657151424459, 0.04449112048106534, 0.05168246870328273, 0.12274280509778432, 6.091678951467786, 25.713104724884033, 55.22807959147862, 64.04367256164551, 71.27984619140625, 59.747851508004324, 44.56613833563668, 42.42861883980887, 36.70057255881173, 26.318329300199235, 27.148993389947073, 34.165126255580354, 53.475479875292095, 42.610279491969514, 28.14207509585789, 4.8844559362956455, 0.24947618320584297, 0.15926704236439296, 0.050046734511852264, 0.06262788655502455, 0.22413165175489017, 0.435350130711283, 0.7392890357545444, 0.8057188083018575, 1.6632434938635146, 3.984120522226606, 6.594404569693974, 4.904432875769479, 6.890303160463061, 4.459595305579049, 2.1895308877740587, 2.1918418151991705, 6.285930173737662, 10.547737189701625, 38.14664554595947, 84.09883485521588, 108.12585844312395, 105.99652739933559, 103.71366895948137, 102.10828072684151, 106.7345164162772, 85.93743937356132, 37.16126939228603, 15.79985966001238, 5.799688722406115, 4.096841147967747, 0.6677538571613175, 0.5765132616673196, 1.8312472445624215, 6.76958646093096, 13.941502281597682, 20.626898288726807, 67.42317213330949, 119.0519632611956, 103.50965595245361, 107.2592304774693, 105.91395500728062, 112.74437468392509, 105.61866351536342, 107.51108877999442, 106.48677839551652, 105.82879788534981, 100.81922313145229, 94.73606136866978, 85.21941947937012, 65.2821820122855, 46.27934176581246, 36.28310741697039, 19.170779943466187, 12.63673220361982, 6.739853382110596, 3.0324991515704562, 1.6798307980809892, 1.5081630668469836, 1.1585918132747923, 0.5564560379300798, 0.09710834241871323, 0.08242562493043286, 0.11072270652013165, 0.08903862722218037, 10.850961787360054, 38.60135998044695, 51.57728065763201, 42.38492161887032, 23.919465473720006, 24.066190583365305, 27.087117944444927, 52.69848714556013, 74.68879917689732, 72.35162666865757, 82.19072750636509, 55.329373904636924, 18.797309058053152, 2.2698644399642944, 0.2666635023696082, 0.11400197127035686, 0.021206429660586373, 0.038518332942788086, 0.04873128920527441, 0.06711869593709707, 0.022694151615723968, 0.05531303817406297, 0.01991807316829051, 0.027386770883042897, 0.03739155429814543, 0.05925786096070494, 0.018526794788028513, 0.01564055957299258, 0.013555264549462922, 0.02431867301597127, 0.019628420139529874, 0.04761268351493137, 0.01981939890954111, 0.01159842892749501, 0.03961841801979712, 0.015321003505960107, 0.051457286679318974, 0.030193929627005543, 0.020495469149734293, 0.029063849909497157, 0.004864658428622144, 0.06300230896366493, 0.014926067287368434, 0.0481581747797983, 0.045701131623770506, 0.09571390545793942, 0.05027510904307876, 0.00955753045023552, 0.05020100284101708, 0.004461403794786227, 0.07248247454741172, 0.024180301065955843, 0.12530499404030188, 0.012942405783438256, 0.07454657128879003, 0.0705111538991332, 0.024334976516131843, 0.02547441323154739, 0.01230364733575178, 0.09630883817694016, 0.14882449699299677, 0.1951522489211389, 0.2508665828832558, 0.1101477566574301, 0.09819498910967793, 0.27329745782273157, 0.2069677556199687, 0.27910273202827995, 0.1188977099955082, 0.11468353255518846, 0.09976789435105664, 0.11704366733985287, 0.24560402812702314, 0.19139794180435793, 0.10451826373381273, 0.1561175270804337, 0.22571958654693194, 0.11129187526447432, 0.16759939811059407, 0.1820853879409177, 0.15289160875337465, 0.1672113032213279, 0.10548133562718119, 0.17599632324916975, 0.131147153409464, 0.11922770871647767, 0.12926797781671795, 0.10036328168851988, 0.09991125522979669, 0.07353294175118208, 0.1368589119187423, 0.10152142561439957, 0.15791879328233854, 0.2765219919383526, 0.09050385574144976, 0.6864149815269879, 10.63354570525033, 46.86068017142159, 86.41929694584438, 87.27557904379708, 91.5586848940168, 78.60611711229596, 43.76434748513358, 35.29503536224365, 35.61625058310372, 35.709203583853586, 44.75602912902832, 75.66160951341901, 117.59139633178711, 61.90836606706892, 38.36387055260794, 5.802768077169146, 1.0244374062333788, 0.3453071766666004, 0.11163453544889178, 0.24395556801131793, 0.3575488712106432, 0.2856533090983118, 0.4131950395447867, 0.4018753112426826, 1.7413881463663918, 4.990498908928462, 8.882113286427089, 9.815624611718313, 12.446700709206716, 9.85576001235417, 13.271675092833382, 12.408764413424901, 13.92031809261867, 15.215498788016182, 43.87751279558454, 88.60797950199672, 113.59310409000942, 108.30869334084647, 107.25190012795585, 106.1905905859811, 107.44120379856655, 88.06866032736642, 45.046234539576936, 29.649762971060618, 28.375280959265574, 23.37664440699986, 16.485368932996476, 11.759374482291085, 9.550738436835152, 15.660060167312622, 20.55331686564854, 23.774220330374582, 72.80365562438965, 119.65944426400321, 109.69424057006836, 109.91329642704555, 109.77349867139543, 115.89762701307023, 108.43741566794259, 107.73200675419399, 111.00617163521903, 107.26012679508754, 105.69656671796525, 95.12491035461426, 87.75458090645927, 68.24838883536202, 47.15042700086321, 45.0203594480242, 22.31419883455549, 20.49571282523019, 16.357501234327042, 2.8742257016045705, 0.858880127114909, 1.4312867862837655, 0.900118174297469, 0.3502278583390372, 0.19954333401152066, 0.2681872748902866, 0.2601652539202145, 1.0417217016220093, 18.07977032661438, 56.54982498713902, 107.39774976457868, 94.60021018981934, 45.51875720705305, 40.93708726337978, 33.957760742732454, 59.34630816323416, 74.00758389064244, 79.70873369489397, 97.48789542061942, 68.19301169259208, 18.456994976316178, 1.8047931726489748, 0.2757539717214448, 0.25099925005010193, 0.06869880722037383, 0.14237599873117038, 0.1695035845041275, 0.10308092978915998, 0.09994438809475728, 0.10872338951698371, 0.13766570362661565, 0.12108187350843634, 0.16045686709029333, 0.1850146371871233, 0.09014147732939039, 0.09708189312368631, 0.09873652112271104, 0.15251895732113294, 0.07598064826535326, 0.0934639647603035, 0.09940189934734787, 0.14373201025383814, 0.1126750824706895, 0.13248229319495813, 0.22722852629210266, 0.2044072901563985, 0.11197853913264615, 0.10758598162127392, 0.10317110709313836, 0.11304303165525198, 0.098679612390697, 0.14142044500580855, 0.09761567626680646, 0.11364852916449308, 0.18325630868119852, 0.13745451638741152, 0.15703356292630943, 0.12296096767698016, 0.12627071222024305, 0.13151648002011435, 0.2808222754725388, 0.07918808329850435, 0.12887544530842984, 0.20233596701707157, 0.06925338067646537, 0.08285977877676487, 0.11084781480687005], [0.00636404991382733, 0.019253799259396534, 0.03483611338638833, 0.014462073167253817, 0.03749034221151045, 0.09641916118562222, 0.05041461245023778, 0.003343806577114654, 0.026110775602449263, 0.03592293310378279, 0.03140983384634767, 0.0624243396201304, 0.06379697525075503, 0.09433909851525511, 0.05790856693472181, 0.10579456774783985, 0.03821353501241122, 0.010004389016622943, 0.020067786831142645, 0.04741341813600489, 0.09133372442530734, 0.05391249779079642, 0.015784025624660507, 0.1102262292323368, 0.0013501315926467733, 0.05909676317657743, 0.0520571964526815, 0.04759695168052401, 0.021188799624464343, 0.12876210281891481, 0.043998836539685726, 0.06295616179704666, 0.16417351551353931, 0.11811797826417855, 0.13364976697734424, 0.13549625075289182, 8.878950119018555, 35.32621887751988, 32.97240195955549, 39.50834655761719, 64.60731043134416, 35.85524082183838, 30.13031428200858, 12.095144442149572, 46.09813274656023, 31.63983474458967, 46.557141167776926, 64.12458433423723, 41.45235177448818, 17.254638739994594, 5.727760970592499, 0.366150795349053, 0.10199786576309375, 0.04244984287236418, 0.08369251766375133, 0.024696537293493748, 0.1751016748270818, 0.08246650666530643, 0.05036101157643965, 0.1477467662521771, 0.34521009187613216, 1.0780087773289, 2.6644448212214877, 4.277931613581521, 4.689157273088183, 6.622742797647204, 4.17756792477199, 7.859480891908918, 16.032690320696148, 35.25967250551496, 56.36803579330444, 96.58653341020856, 97.86667646680559, 89.97453730446952, 87.01841926574707, 89.17663397107805, 86.61892563956124, 92.85654585702079, 92.08999279567173, 83.11723504747663, 62.942528997148784, 30.944837706429617, 6.273219312940325, 6.681001271520342, 21.075166531971522, 64.67482607705253, 87.49899142129081, 127.77626037597656, 73.12145233154297, 71.85522651672363, 115.07943493979317, 96.2025203704834, 105.16750308445522, 110.91902038029262, 111.4495848246983, 106.20336137499127, 107.41828863961356, 103.25731127602714, 105.06471143450055, 102.39515100206647, 107.35633155277797, 103.12427411760602, 103.10104628971645, 82.40102168491909, 68.23906435285295, 57.3729259627206, 38.354115281786235, 24.0009400503976, 6.23023167678288, 4.633623361587524, 2.3959336408546994, 4.158334876809802, 1.259918913245201, 0.04887022942836795, 0.1132964916261179, 0.05644736212811299, 0.035317781647401195, 0.12391531361000878, 1.2038604127509254, 28.854395730154856, 57.2795386995588, 79.24877684456962, 65.18460151127407, 99.42238507952008, 133.32750974382674, 19.306082214627946, 46.65956803730556, 53.48160818644932, 52.77256536483765, 54.815089089529856, 29.772374357495988, 4.162232381956918, 1.1299317968743188, 0.10293441372258322, 0.05656416514622314, 0.04702444454388959, 0.010675717145204544, 0.1651634709643466, 0.09983360368226256, 0.044229779325957806, 0.031052520698202506, 0.06521898108933653, 0.018860472865136604, 0.0608771304999079, 0.02914000189464007, 0.051001606309520345, 0.08234787838799612, 0.016017336498147676, 0.003746056555038584, 0.10631735183830772, 0.08972060919872352, 0.03624335769563913, 0.07143416508500065, 0.04208719304629734, 0.02874730314527239, 0.020685957678194557, 0.01653411894637559, 0.06906047317066363, 0.09747415421796696, 0.23078542043055805, 0.13179664712931427, 0.03486800113958972, 0.025040239029164826, 0.04257884934278471, 0.09235299937427044, 0.057954408760581694, 0.05256411978708846, 0.006159175170718559, 0.12246647849678993, 0.048865204876554866, 0.11637426540255547, 0.05202975310385227, 0.043999131702418835, 0.039146161039492915, 0.10201131432716336, 0.15205858488168034, 0.0308453877057348, 0.02226526489747422, 0.013165981375745364, 0.04437114191906793, 0.08918679212885243, 0.07829580296363149, 0.08601654081472329, 0.009107706685816603, 0.03028415103576013, 0.05839325806924275, 0.047535072679498365, 0.03379546119166272, 0.024273643735796213, 0.05099489899086101, 0.03463414404541254, 0.13942665127771242, 0.06551848644656794, 0.03675420296245387, 0.053562115877866745, 0.11428557176675115, 0.04098765418997832, 0.040187250889305554, 0.045649067631789615, 0.06978327581392867, 0.036292408992137225, 0.023983737952741127, 0.0069770668633282185, 0.04084382172940033, 0.02198496038493301, 0.01895192581495004, 0.06407775982682194, 0.009381350528981005, 0.08951997317905937, 0.09196757791297776, 0.17114238228116715, 0.10366778115608863, 7.868159191949027, 38.753984110695974, 48.16924136025565, 59.12004702431815, 84.65484360286167, 58.108517851148335, 55.075531891414094, 22.622728381838115, 41.34965739931379, 31.518376759120397, 37.0031909261431, 47.43898221424648, 41.37861054284232, 24.12028578349522, 7.941725850105286, 0.27769341479454723, 0.09546911037926163, 0.06748849752226047, 0.14231742758836063, 0.21460119315556117, 0.31448602623173166, 0.703621326812676, 0.9563282323735101, 2.4288146878991808, 2.963838355881827, 3.4822254308632443, 2.0035868883132935, 3.5285277920109883, 5.192253317151751, 3.954895096165793, 1.5193176397255488, 8.005618010248456, 18.576375450406754, 38.725823061806814, 61.53558131626674, 102.73994840894426, 104.03116689409528, 93.63561957223075, 94.99848788125175, 94.27843911307198, 92.11417947496686, 98.29918098449707, 100.04909869602749, 92.77699593135289, 71.43388080596924, 31.5123769896371, 5.226385908467429, 6.697404231343951, 22.81702607018607, 73.06860433306012, 94.62461921146938, 138.97640909467424, 80.8667552130563, 75.35691710880825, 121.09501157488141, 102.54739298139299, 106.93454115731376, 112.20954404558454, 117.26005063738141, 110.75942025865827, 111.27467087336949, 107.73620346614292, 109.01944541931152, 106.46507222311837, 110.65292521885463, 106.75383935655866, 104.7437880379813, 91.39325523376465, 73.48593398502895, 59.69608048030308, 36.0595942905971, 19.07188102177211, 5.703654195581164, 3.8664267233439853, 2.566563376358577, 3.8875557609966824, 6.780572431428092, 0.2962733863719872, 0.4327626052711691, 0.061980150240872584, 0.0569746449057545, 0.03150693899286645, 1.5256520083972385, 27.41681170463562, 51.11464875085013, 54.22805316107613, 45.75915445600237, 87.98961067199707, 142.06416075570243, 40.25021961757115, 65.29538358960832, 65.12161609104702, 71.65474319458008, 73.72304126194545, 48.05357469831194, 9.473391958645411, 1.2310882317168372, 0.12606116703578404, 0.024428364987085973, 0.0309546284510621, 0.04219758390848126, 0.08560212555208377, 0.043522705124425035, 0.04707095811941794, 0.05266521132684179, 0.029540167921887975, 0.07979554177394935, 0.06126433650829962, 0.03362335756953273, 0.09760961016373974, 0.07939828666193144, 0.02030840383044311, 0.07775113611881222, 0.11293339396693877, 0.03665983909741044, 0.02196675698672022, 0.0836014650495989, 0.061891893190996985, 0.0769990071920412, 0.03056089493579098, 0.06481436387236629, 0.0431689916045538, 0.10733096780521528, 0.13557574791567667, 0.08098250308207103, 0.004924850846042058, 0.05584682470985821, 0.032535570939736705, 0.0757678257567542, 0.048305243852415254, 0.04327008992965732, 0.021702581251572286, 0.04070963464411242, 0.014295645490554827, 0.03847310519112008, 0.024671599435220872, 0.019106804825631634, 0.00970773774731372, 0.019084235054573843, 0.0734645522066525, 0.0956723519733974, 0.07016380503773689, 0.0882836077362299, 0.14956864634794848, 0.11650685114519936, 0.11593194199459893, 0.15664674368287834, 0.08380553445645741, 0.11700322665274143, 0.10877625418028661, 0.12244856517229762, 0.1366266222404582, 0.11754301483077662, 0.12616374795990332, 0.11749097119484629, 0.20849163670625004, 0.16545572956757887, 0.20195935294032097, 0.09772426901119095, 0.1160004333193813, 0.2276277762970754, 0.13225236481853894, 0.15614054298826627, 0.16645024477371148, 0.0888757041788527, 0.1499334539153746, 0.17851671443453856, 0.10906918453318731, 0.0924107019922563, 0.18888466166598455, 0.18649207933672837, 0.24158286675810814, 0.17228808866015502, 0.1748243032821587, 0.16765247311975273, 0.31561736123902456, 13.951184596334185, 66.02611173902238, 69.1051573072161, 75.75286020551408, 107.0548631123134, 65.448897089277, 52.499469893319265, 23.907688277108328, 59.96702548435756, 47.245332445417134, 68.75844914572579, 92.93028708866665, 62.253100940159385, 30.313736302512034, 10.760320799691335, 1.0743905029126575, 0.27393465648804394, 0.1186316292732954, 0.3290718692753996, 0.5227407185094697, 0.3769750845219408, 0.6886435619422367, 0.6035435998014042, 1.8589833676815033, 2.1915441283157895, 5.545495390892029, 8.982838715825762, 14.101744243076869, 17.39907268115452, 19.51512919153486, 15.027451004300799, 17.027833904538834, 24.912783418382915, 43.216777324676514, 65.83264609745571, 106.29049873352051, 108.89045906066895, 98.20094735281808, 96.86810915810722, 99.00977325439453, 95.80764729636056, 103.91656330653599, 105.15965856824602, 97.21432399749756, 75.98747307913644, 46.60010187966483, 14.829079934528895, 12.03304318019322, 28.62685785974775, 73.96105180467877, 92.46677276066372, 138.98446900503976, 95.5196236201695, 84.5342298235212, 124.92701257978166, 107.88272012983049, 111.84566688537598, 118.4011810847691, 122.93886893136161, 118.1573132106236, 117.82730157034737, 114.87210764203752, 113.46865490504673, 111.39883518218994, 114.51157256535122, 111.53177506583077, 108.57348224094936, 90.28589303152901, 71.37152767181396, 66.24918365478516, 48.20777606964111, 34.74021475655692, 19.296762943267822, 12.443742513656616, 7.553937332970755, 6.940678903034755, 4.895599544048309, 0.1812613614435707, 0.4176591214324747, 0.3943136898534638, 0.17767621310693876, 0.3463297017983028, 3.035599785191672, 45.01638160433088, 83.17910180773053, 106.29316684177944, 88.89917155674526, 110.72754192352295, 138.04832431248255, 26.790153673716954, 63.62859412602016, 73.59736919403076, 83.9620178767613, 89.69610214233398, 53.74785620825631, 10.233142733573914, 1.5907405614852905, 0.3002697947834219, 0.12740729908858026, 0.1328060629644564, 0.09532944751637322, 0.2457989848085812, 0.19980625276054653, 0.11681045485394341, 0.14321006754679338, 0.1330272246684347, 0.09586219250091485, 0.12495823550437178, 0.1344812980719975, 0.1215764441128288, 0.1641223132610321, 0.10980893019586802, 0.1835934727319649, 0.26138772975121227, 0.14352230222097465, 0.08180978654750756, 0.1609080657362938, 0.12421069347432681, 0.1062965208132352, 0.23127290712935583, 0.1283333365406309, 0.1593342987554414, 0.2100922872445413, 0.24219314115388052, 0.27071783053023474, 0.09322553434010063, 0.14767203240522317, 0.283840182104281, 0.12659682972090586, 0.28708607650228907, 0.13413839361497334, 0.14981354320687906, 0.2174860390701464, 0.1303479884352003, 0.1634211151727608, 0.10805917837257896, 0.1484840488327401, 0.07889539043286017, 0.17567939311265945, 0.27995315353785244], [0.01675891250904117, 0.09422154910862446, 0.056462802192462344, 0.025388520876211778, 0.0803398150684578, 0.06675293842064482, 0.051927762505199225, 0.08293176455689327, 0.28128745193992344, 0.23638406715222768, 0.06884803742702518, 0.1032120498961636, 0.025814176071435213, 0.13571511900850705, 0.10371276802782502, 0.08752772651080575, 0.0428725939377078, 0.048512054540749104, 0.14562087532665047, 0.07157859804907016, 0.2001935334077903, 0.262149453163147, 0.2887305739734854, 0.11356012962226357, 0.1120536190324596, 0.09210171750081436, 0.34304673224687576, 0.118018952863557, 0.029883917155010358, 0.07270641145961625, 0.10987182360674654, 0.06412041932344437, 0.13659743166395596, 0.08727434117879186, 0.38557955995202065, 10.890276432037354, 45.33176033837454, 75.86035578591483, 73.42277485983712, 38.1935841015407, 34.7230110168457, 17.908038650240215, 19.077941587993077, 44.928052629743306, 76.71622099195207, 57.135627610342844, 31.753924165453228, 24.81936662537711, 9.509331515857152, 1.9559773973056247, 0.10903876580830131, 0.06123981425272567, 0.03474783258778708, 0.10907545419675962, 0.11036441288888454, 0.09739161721829857, 0.47636393564088003, 0.4010851707841669, 0.9061280403818402, 1.4807633885315485, 2.2900789209774564, 3.413004219532013, 3.9053079741341725, 7.2425386139324734, 5.063167078154428, 13.884276918002538, 27.85513707569667, 46.56886625289917, 72.66008499690464, 82.14680099487305, 89.82094042641776, 97.19934368133545, 97.43212223052979, 89.90573624202183, 80.85205282483781, 82.79282365526471, 81.60698849814278, 83.80658667428153, 90.73717853001186, 94.68241432734898, 84.71987874167306, 79.15092536381313, 32.31363977704729, 55.53940405164446, 110.7591631753104, 125.66549491882324, 115.62145696367536, 126.86824199131557, 118.06023297991071, 64.5104455947876, 109.82565879821777, 87.38087899344308, 81.49483067648751, 89.41262953622001, 105.74760123661586, 94.93854577200753, 97.46078354971749, 86.35497052328927, 97.96440287998745, 96.85822881971086, 98.57933929988316, 97.90138271876744, 101.40096105848039, 95.73503862108502, 104.6440327508109, 84.21694728306362, 66.1702104296003, 39.08905751364571, 29.118611403873988, 10.06877441065652, 3.592545671122415, 4.006197120462145, 8.947647827012197, 4.067409881523677, 0.12949359071041855, 0.09208268459354128, 0.1278694492897817, 0.2079181931912899, 0.1229928181107555, 0.3438617613698755, 10.218914559909276, 34.602101939065115, 41.73722096851894, 40.629431452069966, 50.222482681274414, 26.048169442585536, 19.986585310527257, 36.62535483496529, 42.53925848007202, 56.68917110988072, 56.52800416946411, 41.460984911237446, 10.396042381014142, 3.334688250507627, 1.0034449441092355, 0.07147639031921114, 0.1243098002991506, 0.07820524568004267, 0.05803103572023766, 0.05426931900105306, 0.059336231755358834, 0.05627212706687195, 0.06553097827626125, 0.10442183712231261, 0.022790978562885096, 0.04560893567811165, 0.03178791695141366, 0.04838309556777988, 0.03381800551765731, 0.25619471126369064, 0.2074284130441291, 0.2851425622190748, 0.07354018171983105, 0.11135409014033419, 0.20920358278921672, 0.05311770597472787, 0.11886174763951983, 0.10792683690254178, 0.3808102730129446, 0.2040062216775758, 0.14333749642329557, 0.11627989475216184, 0.31873227123703274, 0.42368405099426, 0.15234841432954582, 0.1529439509447132, 0.2786875500210694, 0.15571499296597072, 0.057363492968891344, 0.055652482102492025, 0.43669281580618446, 0.25232508033514023, 0.11769546807876655, 0.1092318497332079, 0.07169623566525322, 0.2252962892608983, 0.03165635918932302, 0.09160832754735436, 0.035530994313635995, 0.016899053739117723, 0.0527946317036237, 0.0864591763487884, 0.08637082430401019, 0.10322933896843876, 0.1773034802504948, 0.16290941834449768, 0.07762228910412107, 0.06697817812008516, 0.01627772600789155, 0.0769775179880006, 0.10935283252703291, 0.09396973797785384, 0.057628691595579894, 0.010835680079513361, 0.11166236217000655, 0.12803674888397965, 0.19317282656473772, 0.1729603268738304, 0.24995018062847002, 0.07847125176340342, 0.2103139239230326, 0.04221324110403657, 0.20842838367181166, 0.08569029439240694, 0.044722198974341154, 0.07828533995364394, 0.009470762784725853, 0.07118704941655908, 0.13513357378542423, 0.15538654130484375, 0.6865511770759309, 11.304124167987279, 53.73891387666975, 99.90788350786481, 84.39614132472447, 45.15103421892439, 60.89686121259417, 30.73531825201852, 25.22352249281747, 34.031672205243794, 55.62215709686279, 44.91858918326241, 35.01574904578072, 32.502596037728445, 13.7616194997515, 2.2750291228294373, 0.15886558033525944, 0.04866552219859191, 0.059050229244998524, 0.10648015274533204, 0.5681291744112968, 0.34122304724795477, 1.6182017964976174, 2.3552434699875966, 3.193179500954492, 3.0087964577334265, 2.371239308800016, 4.017549608434949, 1.2504404847111021, 1.7790791924510683, 0.5455219617911747, 7.851103969982692, 26.2869599206107, 51.62116200583321, 75.35131686074394, 84.59237234933036, 91.17504010881696, 101.47185352870396, 100.70447363172258, 93.11044692993164, 82.00252859933036, 86.33921895708356, 87.18662125723702, 88.53034033094133, 93.12002154758999, 97.34433174133301, 88.90352807726178, 86.43027509961809, 39.77007825034005, 63.0674159186227, 122.8723885672433, 137.9750486101423, 128.07985496520996, 134.99174227033342, 121.65903854370117, 67.5270824432373, 112.1304040636335, 92.10578605106899, 87.18564850943429, 93.91886983598981, 109.70118876865932, 99.94507026672363, 100.13686834062848, 92.45339053017753, 103.79178755623954, 102.74267905099052, 103.08902590615409, 101.83985791887555, 102.6815835407802, 99.94488961356026, 106.30342933109829, 90.96223068237305, 74.59449822562081, 43.296330724443706, 26.463598762239727, 8.687193734305245, 3.7426610674176897, 4.536330342292786, 9.657284719603402, 6.731420874595642, 0.7960499014173235, 0.0987904646566936, 0.3964652972561972, 0.21530619103993687, 0.07138912393046276, 0.2503003861222948, 10.007466111864362, 36.83298090526036, 41.05031510761806, 46.88941444669451, 55.771459988185335, 26.063293933868408, 35.83534812927246, 62.62579536437988, 55.03737585885184, 75.30434703826904, 74.45517989567348, 65.10716383797782, 22.50026638167245, 5.758336084229605, 1.1371495638574873, 0.09399215677486998, 0.08930056209542922, 0.08602480537125043, 0.06849298719316721, 0.04472529648670128, 0.09929492830165795, 0.053973328455218246, 0.052471092636031766, 0.011169112187677195, 0.04585129820874759, 0.07050313361521278, 0.0322808929985123, 0.06608010309615306, 0.04805757857060858, 0.1044786237180233, 0.17357298971286841, 0.10615499876439571, 0.08129632552819592, 0.050933888514659235, 0.14040452880518778, 0.054757362098566124, 0.11284753893102918, 0.1733588847730841, 0.3263030121369021, 0.24229207155959948, 0.14170480546142372, 0.13503469766250678, 0.063929927402309, 0.25499693410737173, 0.14088043969656738, 0.09658766178680317, 0.2643601473953043, 0.09192944424492971, 0.05595299508422613, 0.11820137021797043, 0.183769254013896, 0.12969998749239103, 0.1384436847375972, 0.07850340075258698, 0.063253991172782, 0.12389729171991348, 0.09621340901191745, 0.2022740574819701, 0.15210762939282826, 0.08244138051356588, 0.2237955733601536, 0.20105639924960478, 0.15964156655328615, 0.24455921990530832, 0.41905185527035166, 0.2832395157643727, 0.21405649238399097, 0.17410900523619993, 0.1113997216203383, 0.17627551326794283, 0.34500294870563913, 0.22961152770689555, 0.1943923304123538, 0.15495195319609983, 0.20184344558843545, 0.19822609397981847, 0.3053048231772014, 0.25723772815295626, 0.3958218017859118, 0.19920642780406134, 0.27717590970652445, 0.11003693153283425, 0.36818417481013704, 0.2693401873111725, 0.16249676048755646, 0.24868137442639895, 0.1976777155484472, 0.15594972537032195, 0.1793611105531454, 0.3131841075207506, 1.7734850240605218, 20.19792171886989, 72.23527908325195, 117.64099257332938, 106.78052043914795, 63.096369062151226, 58.57583631787981, 31.533311911991664, 29.447400161198207, 61.861646379743306, 95.26323509216309, 79.0036930356707, 50.29041174479893, 42.236317021506174, 17.93059250286647, 4.562197182859693, 0.24366800487041473, 0.11411555803247861, 0.1153852463300739, 0.25965466988938196, 0.37585767305323053, 0.4011484645307064, 2.362081800188337, 2.3961405668939864, 3.351308341537203, 7.677379897662571, 6.661316590649741, 14.741814034325735, 12.804730091776166, 17.21013379096985, 14.951861551829747, 25.255845512662614, 38.475152901240754, 55.0536276953561, 80.45037746429443, 88.64439501081193, 92.66279533931187, 105.41963931492397, 107.68999099731445, 99.76684897286552, 86.91183389936174, 90.63526235307965, 91.12142780848912, 90.1816770008632, 96.26276820046562, 100.50681822640556, 90.57249927520752, 90.48244367327008, 43.53898613793509, 74.695802961077, 126.84796714782715, 137.4479443686349, 129.5670612880162, 137.89383806501115, 116.54361493246896, 78.92947932652065, 115.49962030138288, 95.34732913970947, 88.37814698900495, 97.68926811218262, 113.77936444963727, 103.46111583709717, 105.40725067683628, 97.01387541634696, 108.19475678035191, 110.65447466714042, 108.1481830051967, 107.03909070151192, 109.17535604749406, 105.79669720785958, 113.08133452279228, 94.7653341293335, 77.01719611031669, 47.26228952407837, 36.79694059916905, 18.507694244384766, 11.492929305349078, 14.344536883490425, 20.267487083162578, 9.01047170162201, 0.33701322600245476, 0.13624601837779793, 0.3361328403864588, 0.37197227297084673, 0.32299501821398735, 0.45687125303915566, 17.08565855026245, 52.078951018197195, 61.524853297642295, 51.044673442840576, 58.608381680079866, 37.92217009408133, 26.867857115609304, 56.6330018724714, 62.2909825188773, 86.5437113898141, 92.1991559437343, 83.92305932726178, 27.326914174216135, 7.154315165110996, 1.6528832955019814, 0.3756727586899485, 0.3081581172134195, 0.22497032103793962, 0.17747315471725805, 0.2421989765550409, 0.2150636012000697, 0.18771608865686826, 0.1454744203282254, 0.1502102690615824, 0.2138545060796397, 0.1806282475590706, 0.12956805314336503, 0.21242666483989783, 0.19366366522652761, 0.37717264677797047, 0.27569035227809635, 0.36272172363741056, 0.21073061227798462, 0.21305540895887784, 0.4401165678032807, 0.16918339739952767, 0.2507527247071266, 0.3196061700582504, 0.4748939030936786, 0.45730654682431904, 0.18779790640941688, 0.20964064076542854, 0.3673866790320192, 0.4908307365008763, 0.30306731324110714, 0.2650987191924027, 0.39168629369565416, 0.2915929060961519, 0.12706758374614374, 0.1778333889586585, 0.3849037390734468, 0.287422602730138, 0.17902934764112743, 0.2140723429620266, 0.1836448378328766, 0.29404790007642334], [0.11173632927238941, 0.030965444299259355, 0.04259670159912535, 0.020336210195507323, 0.05105915625712701, 0.02897787612995931, 0.09866753446736506, 0.17996730016810553, 0.3026361178074564, 0.2538031738783632, 0.18388412999255316, 0.03605137639013784, 0.048939657131476064, 0.0834264030147876, 0.02187123621946999, 0.05344080738723278, 0.04537839662017567, 0.02249235869385302, 0.20111167271222385, 0.14483904013676302, 0.17640930680291994, 0.285366560199431, 0.40540255340082304, 0.07840480282902718, 0.01925359569889094, 0.1522622810942786, 0.43122322644506184, 0.1381573701011283, 0.07417931420994656, 0.01844706692333732, 0.028871003471847092, 0.1310345980205706, 0.0348553057493908, 3.1786241105624606, 25.854993888310023, 64.22819587162563, 93.65114184788295, 80.20930276598249, 60.102299962724956, 45.029753412519185, 26.56432679721287, 31.93153054373605, 59.69110557011196, 58.17435203279768, 32.82177543640137, 32.90594938823155, 22.333987304142543, 6.68503817490169, 0.22163241729140282, 0.22037876956164837, 0.02205414042275931, 0.09414469823241234, 0.1499462646565267, 0.08594931835042578, 0.11206116434186697, 0.2717541163521153, 1.4512714339154107, 0.8156000695058278, 3.130052294049944, 3.353051687989916, 7.104292477880206, 3.243124020951135, 1.065495940191405, 9.65051543712616, 33.57623863220215, 61.63341890062605, 81.72846385410854, 96.18082114628383, 90.74333463396344, 92.6451747076852, 92.12444196428571, 95.43628692626953, 93.18406309400285, 81.01965032305036, 74.77349076952252, 86.21511023385185, 82.05066571916852, 80.36428928375244, 77.34506075722831, 88.50275598253522, 85.97840595245361, 90.67945984431675, 63.07676819392613, 61.522789682660786, 99.90224157060895, 69.45788955688477, 84.12295205252511, 71.70831380571637, 92.13931805746896, 51.09801128932408, 102.18493325369698, 87.649489402771, 81.08783994402204, 76.41860880170549, 85.39716134752545, 84.05014882768903, 88.32459722246442, 84.66891370500836, 89.29894311087472, 85.44065707070487, 89.51578249250139, 89.37496335165841, 91.26298345838273, 89.85451412200928, 89.58501434326172, 95.64683818817139, 98.874755859375, 82.51586845942906, 52.952565397535054, 24.71507590157645, 9.03711109501975, 2.2614549483571733, 6.729523147855486, 10.185766441481453, 0.6316317468881607, 0.175593761993306, 0.14942672396344797, 0.08314254467508622, 0.038984208301241906, 0.10073435891951833, 0.10145978070795536, 2.735189642224993, 24.19249667440142, 43.080140999385286, 48.19839947564261, 67.06727150508335, 32.6991605758667, 9.40285210950034, 31.91440323420933, 38.383648599897114, 47.516850675855366, 50.24221209117344, 46.41150345121111, 29.843857424599783, 12.562981418200902, 2.576358599322183, 0.11062020702021462, 0.07990410059158291, 0.01415263575368694, 0.0760600029357842, 0.024252091767266393, 0.012237271343890046, 0.044298117980360985, 0.11709514100636755, 0.06191472589437451, 0.05606936044724924, 0.0257864460415606, 0.10792829575283186, 0.08466217813215085, 0.14960861206054688, 0.20499097955014023, 0.14383465903145926, 0.053090662961559634, 0.01789749087765813, 0.15868685421134743, 0.0988363471946546, 0.10005217338246958, 0.1322869293923889, 0.25742535665631294, 0.10448311561984674, 0.07898938788899354, 0.22979652349437985, 0.2792872664119516, 0.2986505388149193, 0.3180449152631419, 0.1359177024236747, 0.2678842140095574, 0.23766082578471728, 0.021174831981105462, 0.1315007515783821, 0.2487147312079157, 0.07266832528901951, 0.08086145243474416, 0.29500534012913704, 0.08461347967386246, 0.04501660853358252, 0.0398738593129175, 0.06868032392646585, 0.02970943526764001, 0.04664069227874279, 0.06299428867974452, 0.05462159402668476, 0.10386272426694632, 0.11897958203085832, 0.3716405507709299, 0.1947051486266511, 0.14672756594206604, 0.02381467756016978, 0.0629261705492224, 0.1564616257590907, 0.0505311745884163, 0.05503959534689784, 0.03788082554404225, 0.028883322275110652, 0.1501441526093653, 0.13785726763308048, 0.15740887421582425, 0.18710172948028359, 0.311192444392613, 0.09177963728351252, 0.0365117081174893, 0.11097503333751645, 0.2976493468242032, 0.17888716741331986, 0.0665132323546069, 0.011988625578981425, 0.04123647976666689, 0.13214111221688135, 0.13974212934928282, 3.0673990845680237, 28.767643996647426, 75.12915515899658, 110.34367479596818, 92.84503269195557, 82.42292935507638, 71.30726378304618, 28.703628505979264, 23.954361064093455, 37.65548086166382, 47.05279091426304, 35.50264058794294, 38.112234592437744, 28.29610797337123, 9.031731452260699, 0.3625071437231132, 0.2523023358413151, 0.13143696928662912, 0.0973247272361602, 0.3581825414938586, 0.5878586928759302, 0.8646126623664583, 2.5297505174364363, 2.9079257675579617, 3.1517584664481024, 4.040712296962738, 2.5246366432734897, 2.539308850254331, 1.2572785977806364, 1.2226079553365707, 9.87247998373849, 37.311809062957764, 67.7300671168736, 86.97085189819336, 100.92256368909563, 98.7800658089774, 98.48475347246442, 95.1079706464495, 99.11542756216866, 96.56418800354004, 84.74155712127686, 78.42479692186627, 91.63328770228794, 85.56500898088727, 84.34118802206856, 81.33164528438023, 91.96985149383545, 88.40868432181222, 97.31009101867676, 65.49360874720982, 71.92584105900356, 110.46544892447335, 82.55478531973702, 91.50683743613106, 84.0059791292463, 99.22620964050293, 61.180834089006694, 105.97190993172782, 94.31060927254813, 83.41586862291608, 80.14125210898263, 90.57888466971261, 91.68542003631592, 93.11950043269566, 87.53152288709367, 93.93276623317173, 89.3279309953962, 91.62230260031563, 92.29027462005615, 96.27426746913365, 91.27955491202218, 93.40327875954765, 99.96220452444894, 103.90567547934396, 87.60717487335205, 57.03465291431972, 29.165577752249582, 11.90240488733564, 2.4426769954817633, 3.5372039207390378, 8.18448896067483, 1.8436658467565263, 1.1581927261182239, 0.3295443739209856, 0.1750569050865514, 0.04377540174339499, 0.03203373322529452, 0.09970084152051381, 2.67139019710677, 25.30167235646929, 36.74330745424543, 40.613926546914236, 48.571750504629954, 29.684886114937918, 15.54000745500837, 49.839866229466026, 57.32560178211757, 61.71478925432478, 66.44102341788155, 68.95928682599748, 46.54595109394619, 18.150751386369976, 3.475906261375972, 0.0871882757970265, 0.13403279999537127, 0.041468087517257245, 0.0671009047489081, 0.028026649761678915, 0.017021018712382232, 0.050082449202558825, 0.12889280223420688, 0.02892667048477701, 0.11518224222319466, 0.008507990294934382, 0.05716573393770626, 0.06672555953264236, 0.16451635211706161, 0.19494669352258953, 0.12002414597996644, 0.08623619617096015, 0.01672727072478405, 0.15744619364184992, 0.07017782357122217, 0.0951402923092246, 0.14979668839701585, 0.17865072510072164, 0.0883662329454507, 0.07817818570349898, 0.1535748392343521, 0.19846789671906404, 0.39618346095085144, 0.1260598778192486, 0.0447393455542624, 0.16362523207707064, 0.12427412292787007, 0.040998151126716814, 0.13825532341642038, 0.0968232559306281, 0.1533467293317829, 0.10354142436491591, 0.23592849874070712, 0.01511386372814221, 0.02346080119189407, 0.25183829931276186, 0.14721327487911495, 0.1589167418756655, 0.17887076043656894, 0.17634688158120426, 0.31152766783322605, 0.19405728339084558, 0.317508194063391, 0.6001969022410256, 0.40733963517206057, 0.2710317208298615, 0.1850122351731573, 0.1733211717967476, 0.32097719077553066, 0.24038489961198398, 0.1424938059811081, 0.14730566420725413, 0.12711224492107118, 0.23406871567879403, 0.2875039183667728, 0.22797788679599762, 0.35566664221031324, 0.37801601152334896, 0.20195724948176316, 0.1271789584841047, 0.17615074424871377, 0.6800983090485845, 0.29639063722320963, 0.14486178463058813, 0.12052543408104352, 0.12357424119753496, 0.28881433233618736, 0.4301598535052368, 8.01639553478786, 44.497945240565706, 96.04052312033517, 126.42534991673061, 109.29260689871651, 91.15075615474156, 73.68906457083565, 43.17203439985003, 49.81425516945975, 87.09901142120361, 79.02637890407017, 51.189001423971995, 53.60577596936907, 39.42238344464983, 12.55066921029772, 0.9889772747244153, 0.29898551798292566, 0.27187576411025866, 0.13201440258749894, 0.39929438116294996, 0.4714485194001879, 0.9999451147658485, 2.213421182973044, 4.132522319044385, 4.921988802296775, 12.37587685244424, 14.497812407357351, 23.686638287135533, 12.605103135108948, 10.638429420334951, 16.983155250549316, 41.72483580453055, 79.93065915788922, 91.0437400000436, 105.44599383217948, 102.16579791477749, 102.79470716203961, 98.61116899762834, 103.39131423405239, 106.28625338418144, 89.2357075554984, 82.6368157523019, 98.12778282165527, 89.67568138667515, 88.1869673047747, 83.3712820325579, 96.50296742575509, 91.84363051823208, 100.40692397526333, 71.45784514290946, 78.53140313284737, 116.13478987557548, 89.59146227155412, 98.91385337284633, 95.68919440678188, 104.01776381901333, 69.01988206590924, 108.5422361918858, 99.00402709415981, 87.95693329402378, 85.31148311070034, 95.44646603720528, 97.97593688964844, 98.89726802280971, 93.81889915466309, 98.64904362814767, 93.30118887765067, 96.81461497715541, 97.2305827822004, 99.93246623447963, 97.63910906655448, 98.02024555206299, 106.77344717298234, 109.3606436593192, 91.32216821398053, 59.784656115940635, 32.21004213605608, 15.314470665795461, 5.889484635421208, 17.613669531685964, 23.268002373831614, 2.5566339663096835, 1.5907741082566125, 0.4047395975462028, 0.2164363453962973, 0.1652682503419263, 0.30115845852664536, 0.33269027939864565, 5.264484184128897, 38.199952125549316, 65.19776834760393, 68.83572701045445, 88.70048781803676, 45.63227687563215, 13.567752599716187, 46.052163464682444, 55.82012169701712, 71.87773173195976, 79.65894985198975, 88.66603170122418, 58.767064639500205, 23.849038532802037, 4.371321482317788, 0.33071063991103855, 0.2253545347068991, 0.09046606812626123, 0.11330902416791234, 0.1461577322334051, 0.06750038545578718, 0.1486590023019484, 0.31776459887623787, 0.1208332854190043, 0.22083285876682826, 0.1933727501226323, 0.2506852240434715, 0.13054935048733438, 0.40946247269000324, 0.3340925398681845, 0.268777138952698, 0.18087345654410975, 0.19789990862565382, 0.27985178040606634, 0.2035166315202202, 0.22372667491436005, 0.26131865488631384, 0.3298627696931362, 0.3100070437150342, 0.17767030985227653, 0.2504090331494808, 0.4951610384242875, 0.506833686360291, 0.4181022862238543, 0.17418432262326988, 0.330682711409671, 0.21247203169124468, 0.10983001906424761, 0.21757251157292298, 0.24274774853672298, 0.2888352854975632, 0.14293744574700082, 0.3002273184912545, 0.2719738259911537, 0.13013465702533722], [0.07591229264757463, 0.03968644794076681, 0.05897506113563265, 0.04150994973523276, 0.020012874688420976, 0.041768739598670175, 0.05633890848340733, 0.1252742564039571, 0.20666188560426235, 0.1629845050296613, 0.12744877114892006, 0.08415991972599711, 0.09420137626252004, 0.06424685075346913, 0.07269764478717532, 0.019255773796300803, 0.0217809164231377, 0.022212924402473227, 0.14322354325226375, 0.1993871759623289, 0.06810259885553803, 0.10604459433151142, 0.35777246206998825, 0.1172782504665, 0.022331254124375324, 0.022200335881539753, 0.11288837316845145, 0.037450990573103936, 0.0370854298318071, 0.03141973367226975, 0.03612573704283152, 0.26342235771673067, 9.514478393963405, 39.808612959725515, 72.23666872297014, 95.64474678039551, 85.83926132747105, 74.31556279318673, 42.75234236036028, 13.349548765591212, 42.2993163381304, 44.56385932649885, 34.98708772659302, 42.96077789579119, 30.165527752467565, 13.41465859753745, 1.095347898347037, 0.05479294786761914, 0.08123420564723866, 0.08167280389794282, 0.16549080982804298, 0.03564213834969061, 0.23250045840229305, 0.7262699029275349, 1.4489494327987944, 0.9353951556341988, 2.933571134294782, 3.028213198695864, 3.35808978336198, 1.546063101717404, 0.9176837631634304, 8.975203514099121, 43.66289683750698, 88.68932901109967, 101.14303003038678, 90.97501536778041, 89.06395503452846, 91.27943679264614, 88.31822572435651, 91.02653626033238, 94.3489077431815, 93.52173859732491, 88.83883340018136, 74.56090368543352, 71.80766609736851, 82.94062573569161, 86.51207624162946, 86.30873026166643, 77.65591621398926, 78.9884695325579, 79.93215302058628, 98.74080848693848, 74.19988223484584, 36.12072801589966, 75.56575216565813, 78.51872267041887, 73.29052979605538, 65.17164312090192, 88.55504812513078, 40.34145641326904, 97.77137497493199, 91.35181617736816, 88.70471927097866, 82.51335321153913, 76.2598077229091, 71.47528512137276, 76.1613586970738, 76.672940662929, 77.48030049460274, 79.10200309753418, 77.43223285675049, 79.77322687421525, 82.22416223798479, 85.95553248269218, 84.50399821145194, 86.52996090480259, 91.11246463230678, 93.14589663914272, 85.21076897212437, 57.9037891796657, 25.449307680130005, 8.467482141086034, 1.9969887052263533, 5.416069992950984, 2.0800963257040297, 0.8464608192443848, 0.6882013742412839, 0.19615928988371575, 0.13881434127688408, 0.04076499631628394, 0.05703717190772295, 0.05317429918795824, 1.181586116552353, 13.34550404548645, 40.19862229483468, 57.371557167598176, 70.61863476889474, 58.90475014277867, 18.391603742327007, 15.806571619851248, 50.616323947906494, 46.00974471228463, 37.88026203427996, 42.88658503123692, 36.9523092678615, 21.04742932319641, 6.293668729918344, 0.7233662073101316, 0.08810577049319233, 0.062244772112795284, 0.08423735414232526, 0.04251914843916893, 0.0051200959049830476, 0.02746282278427056, 0.0379388335027865, 0.13456261370863232, 0.013199941205259944, 0.0968974537349173, 0.018967096161629473, 0.12495424571846213, 0.1454725204301732, 0.034692107899380584, 0.008314180337557835, 0.056320832310510535, 0.029818601374115263, 0.06325639318674803, 0.11259532746459756, 0.04518175717177136, 0.11063153855502605, 0.15286714078060218, 0.16258136023368153, 0.019835984001734426, 0.16750619454043253, 0.10121385926114661, 0.1664177972291197, 0.08370591194501945, 0.10706646806959595, 0.26307589773620876, 0.12872444412537984, 0.17500847125692026, 0.09657671023160219, 0.06285707532827343, 0.017647740797006657, 0.12736100942960807, 0.05274386710620352, 0.054304392476166995, 0.0191128471799727, 0.029729217956108705, 0.05797943313206945, 0.04269707728443401, 0.0464000634050795, 0.06187442769961698, 0.028006001941061447, 0.03486539217244301, 0.21617000683077744, 0.09549672675452062, 0.09468743125242846, 0.0952572717464396, 0.054737569232072146, 0.030454076560480253, 0.004959948918050421, 0.03587753911103521, 0.05498310730659536, 0.08924659142004591, 0.14044281175093992, 0.19061194040945598, 0.031326068698295524, 0.1505592939044748, 0.2001284890409027, 0.07312480972281524, 0.07293102012148925, 0.024230729788541794, 0.13415575054075035, 0.010746670703935837, 0.034234646375158, 0.034001165867916176, 0.05856521919901882, 0.5241807869502476, 12.474989431244985, 48.205101013183594, 88.29282311030796, 110.60416970934186, 97.84235777173723, 100.31980746132987, 61.80283682686942, 35.86194930757795, 59.36417198181152, 45.68669169289725, 41.34466511862618, 44.15195621762957, 34.999073369162424, 16.54439214297703, 1.8469440937042236, 0.12416391527014119, 0.004139112807544214, 0.24297098655785832, 0.191460054899965, 0.3821805880538055, 0.5723193724240575, 2.5226060322352817, 3.1507996150425504, 2.076920564685549, 4.112177559307643, 3.794285314423697, 3.5772882955414906, 0.4506079134132181, 2.419622438294547, 11.856462529727391, 47.99375418254307, 95.11725343976701, 107.02344335828508, 101.55366856711251, 97.16759736197335, 96.06161785125732, 91.56231880187988, 94.19499819619315, 98.29881967817033, 95.83717019217355, 91.02652931213379, 77.07749952588762, 76.69550841195243, 88.03684452601841, 90.03554248809814, 89.16231373378209, 81.63027885981968, 81.34992599487305, 84.80673817225865, 102.35405240740094, 78.29107189178467, 40.13146448135376, 82.95814214433942, 86.02094282422746, 80.10744217463902, 71.06186035701207, 94.0239474432809, 46.78702579225813, 99.23058005741665, 94.57762159620012, 92.37832914079938, 86.39758382524762, 76.44248976026262, 74.71911416734967, 80.15685081481934, 79.96746376582554, 82.44965212685722, 85.384293283735, 82.50439003535679, 84.33409391130719, 84.90643092564174, 90.29928915841239, 88.06902163369315, 89.28779125213623, 93.89441217694963, 96.80491529192243, 90.78412750789097, 62.4558493750436, 29.18950387409755, 11.60113707610539, 3.5191344789096286, 2.9093816322939734, 3.1054921490805487, 2.200783061129706, 1.0400717215878623, 0.5555872959750039, 0.3544937808598791, 0.09396685420402459, 0.05371726969523089, 0.13919566438666411, 1.1602614436830794, 15.401767832892281, 35.32471806662423, 42.094566822052, 47.80193526404244, 44.975720746176584, 28.320218222481863, 29.378873552594865, 75.5811493737357, 63.9602872303554, 58.97717816489083, 61.63986682891846, 55.68789747783116, 32.90920809337071, 10.170716643333435, 0.7168700758899961, 0.10487165155687503, 0.05663047158824546, 0.04385009487824781, 0.0563956000842154, 0.05969795198845012, 0.026770757777350287, 0.053928894589522054, 0.07068157475441694, 0.030816689067121063, 0.07190487839813743, 0.0281207388200398, 0.06033832619764975, 0.13343855259673937, 0.04762392005484019, 0.0231213131586888, 0.07538937285010304, 0.04508485558575817, 0.02606776326761714, 0.06753222231886216, 0.04175915868420686, 0.12880979026002543, 0.11994588375091553, 0.03317418095788785, 0.012699513147319002, 0.13599525897630624, 0.031523305257516246, 0.09641582957868065, 0.11559306803558554, 0.11192532841648374, 0.2606792577675411, 0.060512112586625984, 0.06412890101117746, 0.07626120892486402, 0.02753928180650941, 0.1145048335726772, 0.12126391088323933, 0.05567860570070999, 0.060877116929207525, 0.13346513759877, 0.2974666580557823, 0.14304894262126513, 0.1426321728421109, 0.12330863544983522, 0.19020751996764115, 0.12172246484884194, 0.2323365786245891, 0.4623846486210823, 0.2644036007778985, 0.32122013345360756, 0.2008041606417724, 0.18346955866685935, 0.24166268961770193, 0.1375141731862511, 0.15743815978722914, 0.19442963626767906, 0.2460067250898906, 0.30687544175556725, 0.3055981674364635, 0.15182713658681937, 0.2032001085047211, 0.43541613859789713, 0.11887508763798646, 0.1429718610431467, 0.1729342168463128, 0.2284153247518199, 0.10666459891945124, 0.2042974896196808, 0.12867590173014573, 0.14051127593432153, 0.978967200432505, 23.53233790397644, 68.54848848070417, 109.27262387956891, 123.03339222499302, 111.7281311580113, 104.01640892028809, 65.49364348820278, 30.83016116278512, 65.66642434256417, 69.7161818913051, 53.37173979622977, 62.32113075256348, 48.83093568256923, 23.609638350350515, 3.154620255742754, 0.25352988711425234, 0.24159863591194153, 0.48919389290469034, 0.3040352298745087, 0.2571869194507599, 0.6783790098769324, 2.178342116730554, 4.908663894448962, 4.820034410272326, 10.589593138013567, 12.172562139374868, 13.89231424672263, 10.407327124050685, 9.072575569152832, 14.2628173828125, 48.291137082236155, 100.3074118750436, 105.48443821498326, 104.00428431374687, 101.10931042262486, 97.311445917402, 97.42459733145577, 100.59640829903739, 102.99024336678642, 103.29060009547642, 96.70582008361816, 80.4925182887486, 80.61084611075265, 91.39988381522042, 92.44798483167375, 92.04034791673932, 84.34687164851597, 86.40264906202043, 86.72405188424247, 106.28322396959577, 81.37084007263184, 48.43675742830549, 94.60637324196952, 94.13355527605329, 90.55439226967948, 77.8056082044329, 100.86258683885846, 57.66891574859619, 106.62210151127407, 98.68563284192766, 95.1778347832816, 89.40673746381486, 80.25202029091972, 79.40047686440604, 85.32852704184396, 86.24576568603516, 88.47405297415597, 91.43074771336147, 86.93075384412492, 90.63343497685024, 92.84022453853062, 95.80470820835659, 94.04195717402867, 95.8521157673427, 101.10764285496303, 102.97886221749442, 94.25676073346818, 64.73872865949357, 29.56263256072998, 15.295114721570696, 7.3552006142480035, 13.01402199268341, 8.95019781589508, 4.292211898735591, 2.0799308717250824, 0.5672011013541902, 0.4083142014486449, 0.18596511547054562, 0.246428448174681, 0.3804079560296876, 2.3863659713949477, 22.493467569351196, 56.62760659626552, 76.22118268694196, 92.73403521946499, 81.80936173030308, 26.722061327525548, 24.027706248419626, 71.35972268240792, 71.36435713086809, 69.15674073355538, 82.27530097961426, 72.95687729971749, 42.70474720001221, 11.169098087719508, 1.2169953307935168, 0.23225732573441096, 0.2899602422756808, 0.1640985645353794, 0.15115477623684065, 0.1666349284350872, 0.0786160443510328, 0.12669540728841508, 0.23945052974990436, 0.09929396478193146, 0.1816307423370225, 0.086199623133455, 0.2579957874757903, 0.32046834379434586, 0.19250235254211084, 0.11260235708739076, 0.120844481246812, 0.14277860069913523, 0.2112734131515026, 0.23340087437203952, 0.1837594016854252, 0.270579137972423, 0.2944586308939116, 0.1722080215279545, 0.2154186921460288, 0.3496574546609606, 0.3892186518226351, 0.40093806439212387, 0.19522744417190552, 0.18604913167655468, 0.2726574907345431, 0.2054173166730574, 0.15755436569452286, 0.16141307220927306, 0.09637680024440799, 0.17513955065182277, 0.2098835834435054, 0.22033674110259327, 0.09900121084813561], [0.07142433311258044, 0.06943320602710758, 0.041528273573411364, 0.03667566253404532, 0.03536656152989183, 0.026132680409188782, 0.053490801847406795, 0.017190940844427263, 0.05964392024491515, 0.1182785467909915, 0.04041661947433438, 0.04957990920437234, 0.05162589245342782, 0.010299837582611611, 0.07934371209038155, 0.038702846970409155, 0.08941476632441793, 0.029119055518614392, 0.15000072387712343, 0.04321750346571207, 0.1009496512955853, 0.05863590897726161, 0.15278537731085504, 0.08233543405575411, 0.02002521893674774, 0.0699022433587483, 0.19572776875325612, 0.029637330743883337, 0.014725745090150406, 0.02073375877392079, 1.3542004312787737, 21.432293517248972, 68.9566604069301, 97.14625249590192, 86.39397076198033, 81.1472053527832, 75.68795708247593, 28.693286112376622, 9.393162846565247, 33.544936997549875, 29.501655169895717, 27.728839669908794, 32.644280229296, 21.786417143685476, 6.5211206163678845, 0.24927210701363428, 0.09477408017430987, 0.07862690769668136, 0.06963572837412357, 0.029730052554181645, 0.04772151713924749, 0.2999781332910061, 0.790783166885376, 0.6662199880395616, 0.9184178837708065, 3.3952094486781528, 1.268655838710921, 3.4198618744100844, 2.1581767073699405, 1.5944493796144212, 26.22070016179766, 87.95544637952531, 101.2822858265468, 89.52856022971017, 84.59543650490897, 94.34484999520438, 94.7962258202689, 87.25347682407924, 85.84542437962124, 78.65802710396903, 80.45083604540143, 82.05086026872907, 74.30261829921177, 66.72915826525006, 78.55361652374268, 82.88933413369315, 88.67885112762451, 85.57634149278913, 85.29148619515556, 71.63006319318498, 75.07258987426758, 83.6116132736206, 94.97985281263078, 36.232451575142996, 62.33499240875244, 67.55620929173061, 65.47719710213798, 78.34760243552071, 76.95394665854317, 26.894310644694738, 76.12332425798688, 100.313859803336, 92.20935589926583, 94.35507079533168, 86.09674767085484, 75.33569036211286, 67.8664185660226, 69.83595493861607, 71.99504511696952, 72.17723383222307, 70.41040420532227, 71.47579233986991, 75.85779884883335, 82.83761174338204, 80.70372268131801, 80.27627645220075, 81.17191314697266, 86.66501304081508, 90.49415833609444, 87.37420872279576, 56.21961532320295, 25.90095795903887, 5.631261782986777, 2.9881305609430586, 1.5658777356147766, 1.1563694753817149, 1.2497962564229965, 0.8692915141582489, 0.1670625683452402, 0.08498142885842494, 0.08346332889050245, 0.0444373703295631, 0.05192119089354362, 0.08830871353191988, 8.496554272515432, 40.005997385297505, 53.63135576248169, 45.484641551971436, 43.348904269082205, 44.632583958762034, 12.11775301183973, 15.182802302496773, 34.59868342535836, 43.73844460078648, 44.39508063452584, 44.41095379420689, 35.547654492514475, 11.807843378611974, 4.019058670316424, 0.27132427798850195, 0.042313243595084975, 0.044698161871305535, 0.03458050245951329, 0.04263388531814728, 0.0577270859586341, 0.07979274620967251, 0.07191043559994016, 0.0378436486103705, 0.043082987290940115, 0.049342428733195574, 0.030016299337148666, 0.07115916162729263, 0.05071572932813849, 0.06721262553972857, 0.07398960938943283, 0.08491170259990863, 0.07403380237519741, 0.04637175831677658, 0.1431420376258237, 0.145519814320973, 0.11286945561213152, 0.062229321870420656, 0.054394155873783996, 0.07510051370731421, 0.1594860463270119, 0.15679062024823257, 0.05299206503799983, 0.15399361747716153, 0.04373206710442901, 0.1734371062900339, 0.06062730069139174, 0.029089128731616905, 0.02317804716793554, 0.12343181669712067, 0.16717186676604406, 0.03857983874955347, 0.08062671324504272, 0.029460884497634003, 0.04644857865891286, 0.0331722505257598, 0.06881016838763442, 0.021455046587756703, 0.09563778061419725, 0.02218197811661022, 0.039989325617040904, 0.11218461021780968, 0.16635427278067383, 0.053273137991449664, 0.020447216828220656, 0.06657017501337187, 0.05049438102703009, 0.021580879210627506, 0.05792624955730779, 0.07948311032461268, 0.11016264371573925, 0.027700057286503058, 0.056831806498978815, 0.14852389240903513, 0.07427275526736464, 0.06950666422822646, 0.11681147265647139, 0.13800122562263692, 0.10180413722991943, 0.029222321763102497, 0.0026496561352230075, 0.055525216074394326, 1.6800851672887802, 24.061321633202688, 82.80066122327531, 108.4389512198312, 100.99210126059396, 96.75346388135637, 97.63990116119385, 50.7266891343253, 30.871860776628765, 30.20028611591884, 29.924258504595073, 35.67986828940255, 38.4912553514753, 29.323888983045304, 9.574298909732274, 0.5570557543209621, 0.1009161113096135, 0.11708691716194153, 0.08876820387584822, 0.23516957089304924, 0.4844002329877445, 1.3971461611134666, 2.2952878986086165, 2.4664170358862196, 2.545275832925524, 4.569493659905024, 1.137318600501333, 1.3693100490740366, 0.46182146455560413, 3.2770529431956152, 28.391103744506836, 94.88681643349784, 106.569274357387, 93.32530607495988, 88.05010168892997, 96.08328928266252, 97.5357893535069, 91.46005521501813, 90.01803302764893, 85.42683015550885, 84.1859027317592, 84.72009413582938, 77.89132118225098, 68.22309044429234, 82.88025283813477, 88.23224871499198, 91.63358647482735, 88.82695198059082, 89.38804680960519, 77.66032137189592, 77.58352988106864, 87.69679273877824, 97.50559943062919, 44.177522114345, 67.91136646270752, 77.74678475516183, 71.50680215018136, 86.4606248310634, 85.61906596592495, 33.56715038844517, 81.71201746804374, 103.29917417253766, 96.17688151768276, 99.26839910234723, 88.8202817099435, 79.84894834245954, 71.64178480420793, 75.13583237784249, 76.3904060636248, 76.16987718854631, 73.375061580113, 75.47635664258684, 81.18143912724086, 86.46583598000663, 82.52278191702706, 83.22408444540841, 84.51858942849296, 88.90400750296456, 92.06148433685303, 92.70317826952252, 61.45839377811977, 29.115130356379918, 7.6124845913478305, 1.5850008066211427, 2.627826294728688, 3.227998878274645, 2.8374588744980946, 1.5774467033999306, 0.6023406929203442, 0.15236227001462663, 0.2164543672863926, 0.0639637184462377, 0.1992175014955657, 0.13579431761588368, 9.568856733185903, 32.44479397365025, 46.02653850827898, 37.19058731624058, 30.942794936043875, 35.2234411239624, 21.56715284075056, 37.70862068448748, 55.013790198734824, 60.40927137647356, 62.26988083975655, 64.37936782836914, 49.02718755177089, 15.941123485565186, 5.308964380196162, 0.20826094837060996, 0.04175432412219899, 0.022670621717614785, 0.0383241430058011, 0.06196487641760281, 0.03132110182195902, 0.08756192467574563, 0.029887085913547447, 0.03635634056159428, 0.008492280512915125, 0.1387875120022467, 0.06554567534476519, 0.07992519624531269, 0.06018958453621183, 0.04377601581758686, 0.03369475980954511, 0.09102836331086499, 0.10638224692749125, 0.03682212771049567, 0.15956744338784898, 0.08456323415573154, 0.1054740006636296, 0.08648439749543156, 0.03728510572441986, 0.10989112114267689, 0.11631730917309012, 0.05105259143082159, 0.054797582261796506, 0.09233623277395964, 0.056326813596699915, 0.11298421623983554, 0.09932919432009969, 0.021067777814875756, 0.07806563031460557, 0.08809070023042814, 0.08729446652744498, 0.014265225069331271, 0.16074709008846963, 0.1664124368024724, 0.2054948867963893, 0.1460348359708275, 0.19230992001082214, 0.10457898583263159, 0.1566111205943993, 0.09279799621020045, 0.1250601378934724, 0.2071456132190568, 0.22657962968306883, 0.14564622539494718, 0.14368858401264462, 0.2144481156553541, 0.2999307172639029, 0.23886259272694588, 0.18701712973415852, 0.11258801285709653, 0.15692345026348317, 0.1416352013392108, 0.19225087389349937, 0.3251757483397211, 0.2542338807668005, 0.11994139184909207, 0.15770668323550904, 0.18792752016867909, 0.3144646388079439, 0.08369085525295564, 0.17029007444424288, 0.1911690855132682, 3.0504665417330603, 40.53335871015276, 102.57464381626674, 127.00249508449009, 113.69697271074567, 107.05688503810337, 105.08898844037736, 44.3389322417123, 19.722390481403895, 47.11593961715698, 42.177087102617534, 42.6815402167184, 53.079272747039795, 39.36589111600603, 13.824300936290197, 0.9541326016187668, 0.1984278495822634, 0.29161757762942997, 0.315522556326219, 0.19850635608392103, 0.4101007298699447, 1.4528280475309916, 3.2390102531228746, 6.038059702941349, 4.162086035524096, 11.232225946017675, 5.388430493218558, 11.022565790585109, 10.398079940250941, 4.2464814611843655, 28.019543613706315, 98.01078905378068, 111.33878190176827, 98.08274459838867, 92.63584327697754, 99.29697704315186, 100.9594725200108, 96.09001513889858, 96.5031133379255, 89.59379686628068, 88.55248423985073, 90.73511491503034, 82.88879912240165, 74.83516992841447, 88.18384061540876, 91.81631020137242, 95.22904300689697, 93.60090637207031, 92.84894452776227, 80.31368555341447, 82.81421715872628, 92.63682992117745, 100.81139251164028, 47.83278179168701, 77.37551471165249, 89.63810552869523, 79.59198311397007, 95.23360102517265, 96.9210683277675, 38.77968897138323, 86.14385645730155, 106.83780833653041, 97.81675365992955, 103.4081288746425, 92.46067224230084, 86.51810032980782, 77.35155732291085, 79.1798437663487, 80.86892305101667, 80.38072872161865, 78.9983081817627, 80.35855007171631, 87.88749299730573, 91.19789968218122, 88.32710552215576, 88.20330946786063, 90.30923897879464, 95.8209114074707, 99.33244064876011, 97.13610117776054, 61.78438935961042, 28.348700625555857, 10.610298769814626, 7.701208744730268, 7.155365211623056, 4.86747453893934, 7.046026187283652, 2.9308105281421115, 1.2787168302706309, 0.16668485504175934, 0.3695824183523655, 0.2925731992082936, 0.28673904655235155, 0.23041409892695291, 16.347247430256434, 58.23130989074707, 73.15812492370605, 58.87755489349365, 61.839495522635325, 61.587720598493306, 21.808446407318115, 29.127687488283428, 56.055387701307026, 74.11988067626953, 81.21001011984688, 86.04890237535749, 61.8941570009504, 22.51874511582511, 6.035247419561658, 0.5014253279992512, 0.1903854589909315, 0.10259892565331288, 0.1779139582067728, 0.1868642150823559, 0.24297736478703363, 0.19112993404269218, 0.119212984506573, 0.11057118965046746, 0.1198439813618149, 0.2208737608577524, 0.27895394286939074, 0.147948630420225, 0.14572717462267193, 0.0944217915779778, 0.1424384918063879, 0.20483564931367124, 0.16126528728221143, 0.15577371338648455, 0.2807068702365671, 0.2217077346784728, 0.22385745575385435, 0.14343892383788312, 0.13266164357108728, 0.24971907160111836, 0.2665680732045855, 0.3204042358057839, 0.17639569539044583, 0.2562148230416434, 0.07866799977741071, 0.23967854465757096, 0.23807030809777124, 0.1254379597625562, 0.152335576446993, 0.20304082919444355, 0.20088510986949715, 0.1398564896413258], [0.02747539264549102, 0.017743695826668824, 0.021116856252774596, 0.03319055400788784, 0.02668852951111538, 0.023401760163583925, 0.03172694718731301, 0.05092207521998456, 0.03981263170550976, 0.10594372331563916, 0.11814412900379725, 0.06811382861009666, 0.07033398162041392, 0.03743223925786359, 0.03835314019982304, 0.010454658069647849, 0.0402794536203146, 0.03244828758761287, 0.043882698485893865, 0.126119018931474, 0.0253805022886289, 0.0808046522683331, 0.017442144686356187, 0.03695532074198127, 0.0475818474910089, 0.0031235072487366517, 0.07481065033269779, 0.042471101374498436, 0.061292502496923716, 4.1743839127676825, 45.360359123774934, 87.95518234797886, 98.90830176217216, 81.332736151559, 76.51416737692696, 56.521764687129426, 33.47880056926182, 22.993333135332378, 39.177341324942454, 62.672007833208355, 62.08168193272182, 35.407689980098176, 24.28378905568804, 7.09353015252522, 0.3815000174301011, 0.03543938869344337, 0.06901413601424013, 0.09521641715296678, 0.04414402607030102, 0.4415384515055588, 0.23797189337866648, 1.0396550468036105, 0.7081814621176038, 4.194377354213169, 3.603578541960035, 0.6054831785815102, 2.6068062569413866, 2.2200059039252142, 14.169430988175527, 56.417506967272075, 97.66632516043526, 89.40412494114467, 84.03084673200334, 79.72026770455497, 77.1079534803118, 77.78242206573486, 82.90758010319301, 81.47850935799735, 74.65789358956474, 66.70189353397915, 70.31652709415981, 71.97717435019356, 70.39081723349435, 75.65049934387207, 85.42154257638114, 85.38555090767997, 83.85125664302281, 88.10556221008301, 86.58364268711635, 82.65474210466657, 75.3262825012207, 75.3238228389195, 91.3607793535505, 69.51394762311662, 36.80995804922921, 74.60574041094098, 72.11481121608189, 87.43280982971191, 53.486517088753835, 41.09697226115635, 94.11246749332973, 83.96742357526506, 93.81852395193917, 95.24545465196881, 90.25118677956718, 83.90929494585309, 67.0937580381121, 64.72103159768241, 67.45117337363106, 67.65834086281913, 67.4575309753418, 69.97783715384347, 70.92597443716866, 81.64400155203683, 78.79217597416469, 72.35480199541364, 73.59259578159877, 80.47115952627999, 80.87337684631348, 88.88886043003627, 82.55104718889508, 58.3096786226545, 21.422333274568828, 2.159718773194722, 2.198334038257599, 0.9391735643148422, 1.7629908557449068, 0.4306617522878306, 0.8854644777519363, 0.17005925040159905, 0.042922758031636477, 0.10862555155264479, 0.026459656256650175, 0.09170066937804222, 0.5269759169646672, 6.152876947607313, 23.55818693978446, 48.53427539552961, 63.10458183288574, 66.01056861877441, 57.334776878356934, 14.293356452669416, 14.168686662401472, 25.169140679495676, 37.102779456547324, 39.36395604269845, 42.666764872414724, 33.009578296116416, 21.57166395868574, 9.729150806154523, 1.4359627068042755, 0.017687899892085364, 0.07129870235387768, 0.05164861998387745, 0.05110837718737977, 0.035077464899846485, 0.08187999456588711, 0.02950243458950094, 0.060084194477115355, 0.1388332995453051, 0.04462399460109217, 0.018326749093830585, 0.01695246123043554, 0.04063000516699893, 0.09152813827885048, 0.013505565252022018, 0.05056600718359862, 0.015248817558001195, 0.11632737863276686, 0.1506569350936583, 0.11018048918672971, 0.018317565122353177, 0.01237751859506326, 0.10794875358364411, 0.0731294983997941, 0.12589826434850693, 0.13805497916681425, 0.02741794447813715, 0.09492964789803539, 0.15050927230290004, 0.02854129991361073, 0.11870510104511466, 0.04208799371761935, 0.07746003102511168, 0.07809704648596899, 0.15315211191773415, 0.07631218047546488, 0.011160230164283087, 0.02345779019274882, 0.0048280476476065814, 0.027238850248977542, 0.07706920163972036, 0.02430560952052474, 0.03828868615840163, 0.03129532427660056, 0.08546331085796867, 0.11992915107735566, 0.040659636791263304, 0.07637116552463599, 0.030159748425441127, 0.023826338184465255, 0.014085917949809559, 0.028897544369101524, 0.04355998044567449, 0.0808853707941515, 0.15291237192494528, 0.06972916264619146, 0.08472103425966841, 0.011318709651407386, 0.02548256074078381, 0.06866000858800751, 0.027635080773117285, 0.08788431023380586, 0.009189799245047783, 0.039055932845388136, 5.868048139980861, 53.74099138804844, 104.00721645355225, 112.88178225925991, 92.7589167186192, 89.56756046840123, 74.55389295305524, 56.75733641215733, 37.66852610451834, 21.50886787687029, 48.40648760114397, 52.735458510262625, 39.5634457724435, 32.76188543864659, 9.495910201753889, 0.4377050814884049, 0.06532325156565223, 0.043935434227543216, 0.05805477087518998, 0.17692694759794644, 2.0974190533161163, 1.3534024740968431, 2.8407130198819295, 3.039621489388602, 1.0979124350207192, 1.658477138195719, 2.20730351124491, 1.4253320715257098, 4.393091491290501, 17.681381464004517, 61.850883620125906, 105.78013965061733, 94.29143919263566, 88.09696728842599, 83.93412780761719, 84.87954834529332, 83.23017106737409, 86.90371840340751, 84.84719058445522, 78.13423020499093, 72.3292465209961, 74.36007295336042, 74.12825325557164, 74.41816684177944, 79.01982675279889, 89.26322937011719, 89.28663785117013, 86.15268066951207, 89.5924072265625, 90.24573244367326, 86.7834311894008, 77.59026963370187, 77.19585514068604, 94.89186082567487, 72.88870157514299, 43.3719653402056, 82.23373685564313, 79.06057098933628, 97.11681992667062, 59.222366196768625, 47.300667898995535, 94.85921818869454, 85.60077830723354, 96.15920530046735, 97.35707473754883, 94.03359849112374, 86.78238895961216, 72.6246839250837, 69.4686175755092, 70.34882926940918, 70.11933026994977, 71.450973374503, 74.4477870123727, 74.23524161747524, 84.27055263519287, 80.76435266222272, 75.32637977600098, 75.08931418827602, 82.49216120583671, 84.54324163709367, 90.12067876543317, 85.44594464983258, 62.61057880946568, 24.602951083864482, 3.023315587214061, 1.3020014379705702, 1.2777327916451862, 2.265939576285226, 3.421271707330431, 2.6322707533836365, 1.1120322602135795, 0.16207986857209886, 0.2454106185053076, 0.0611011352656143, 0.0834172156506351, 0.4368877453463418, 7.564548969268799, 23.28013219152178, 37.34930501665388, 48.02384683064052, 54.1121050970895, 41.53504228591919, 10.892759544508797, 24.56402553830828, 44.984965324401855, 53.37291751589094, 56.32965394428798, 64.37590762547084, 56.663441930498394, 32.83987896783011, 11.893967168671743, 1.7915424151079995, 0.049902145484728475, 0.07218634150922298, 0.04669888344194208, 0.05107487791350909, 0.026686453193958317, 0.04324802057817578, 0.0647516061684915, 0.08859578134225947, 0.12664777413010597, 0.043406536536557336, 0.0488578054521765, 0.0686870753499014, 0.07719532094363656, 0.08927779046020337, 0.040765264337616305, 0.020166481445942606, 0.05418340628966689, 0.10828498804143497, 0.12939205473022802, 0.05838183832487889, 0.05628170458866017, 0.06186459572719676, 0.10632953832724265, 0.17290407632078442, 0.09249307614352022, 0.03169834693627698, 0.02108833403326571, 0.03995205708114164, 0.10239696649036237, 0.006587495312227735, 0.09543164846088205, 0.06697327231190034, 0.0269170940321471, 0.10968048351683787, 0.06752120291015931, 0.16035054065287113, 0.12160230986773968, 0.12592115812003613, 0.07432089054158755, 0.055042781068810394, 0.10910213419369288, 0.0909525505932314, 0.11245757128511157, 0.13081477981592926, 0.34474828094244003, 0.22572858392127923, 0.15127927384206227, 0.15036284444587572, 0.09687162190675735, 0.2456640920468739, 0.09350749956709997, 0.09644741538379874, 0.20549471037728445, 0.15130242545689854, 0.24985998975379126, 0.17025043442845345, 0.1701706794223615, 0.1100101972530995, 0.284165580357824, 0.12652007383959635, 0.18006085657647677, 0.1848990148199456, 0.10244580065565449, 0.14383877095367226, 9.911153657095772, 74.06812354496547, 123.2977989741734, 123.32171467372349, 104.64208725520542, 103.04380008152553, 81.04264886038644, 49.65172290802002, 34.10501044137137, 54.4856402533395, 83.70093236650739, 86.98707594190324, 57.736841338021414, 43.3206216267177, 14.43588137626648, 0.7152756271617753, 0.1258747327540602, 0.2811727523803711, 0.17510354758373328, 0.13582532666623592, 2.7302915964807783, 3.2526232940810065, 4.906388359410422, 6.005863053458078, 8.905652914728437, 12.411535876137869, 9.140896337372915, 8.872526509421212, 7.435438411576407, 18.73763792855399, 62.79446983337402, 109.33132920946393, 94.89655780792236, 90.63682569776262, 87.03610243116105, 88.47317055293492, 88.2823382786342, 92.4390425000872, 88.75020912715367, 83.32704285212925, 75.01268250601632, 79.18037182944161, 78.97153677259172, 78.63700880323137, 82.98788738250732, 94.23541586739677, 93.14208207811627, 89.19222572871617, 93.54284722464425, 93.46617385319301, 91.64674636295864, 81.17978545597622, 77.82749502999442, 97.92217172895158, 74.46659578595842, 51.07494674410139, 91.98140634809221, 87.10166563306535, 107.03863212040493, 65.7266513279506, 52.20424440928868, 96.7036383492606, 91.57861927577427, 98.45397295270647, 100.55307933262416, 97.92387403760637, 90.98891176496232, 75.75297137669155, 73.35796206338065, 74.53416701725551, 76.43720218113491, 75.55913053240094, 79.45033713749477, 78.72482013702393, 89.62846837724958, 88.0827443259103, 79.78651877811977, 81.42680086408342, 86.7131154196603, 89.21286187853131, 94.56589998517717, 89.76409026554653, 62.9187661579677, 25.23725734438215, 4.984426183359964, 6.431206149714334, 4.829517832824162, 5.330618006842477, 5.240083413464682, 4.982446815286364, 0.848523457135473, 0.20804571706269467, 0.35192951560020447, 0.1767875086516142, 0.24864324075835093, 0.9031424862997872, 12.407051682472229, 36.736807414463584, 69.25211865561349, 81.18628202165876, 82.6205083302089, 76.04074491773332, 19.99745750427246, 21.866969347000122, 47.92821182523455, 65.05025809151786, 71.66253212520054, 85.03430557250977, 74.58534049987793, 43.49813767841884, 16.437686920166016, 2.6256363093852997, 0.18095920979976654, 0.14725124569875853, 0.20324395543762616, 0.21041917827512535, 0.10441201193524258, 0.13467284850776196, 0.21150578425398894, 0.14172685784952982, 0.3066358103283814, 0.21205625257321767, 0.12581701656537397, 0.13779599592089653, 0.10671981131391865, 0.23000814499599592, 0.1140667577939374, 0.13360288020755562, 0.20870629804474966, 0.26003752648830414, 0.2757695237440722, 0.2863841455961977, 0.12215193680354527, 0.18452598340809345, 0.27132745353238924, 0.2905983366072178, 0.29487188586166924, 0.1752705214811223, 0.1322760321199894, 0.2179362741964204, 0.16930877710027353, 0.0757148525278483, 0.20131184054272516, 0.1926552536232131, 0.15122210048139095, 0.20603022378470215, 0.18561609062765325], [0.11602857895195484, 0.049914956225880554, 0.028171194684026495, 0.010534350311250558, 0.09899032714643649, 0.02910913194396666, 0.05217484424688986, 0.05199788909937654, 0.07466730981000833, 0.11359560343303851, 0.045372065888451676, 0.05582888424396515, 0.021206999630002037, 0.024278054213417426, 0.06152583033378635, 0.038809794267373424, 0.01964308667395796, 0.02606899311233844, 0.09083097747394017, 0.08942620642483234, 0.06727423651942185, 0.06900436510997159, 0.016843008442914913, 0.016066165574427162, 0.06515309533902577, 0.10146017425826617, 0.054108692798763514, 0.04608990504805531, 4.620573341846466, 57.85264001573835, 99.65446880885533, 92.12020356314522, 86.98137841905866, 60.524993624006, 44.60377672740391, 20.00471489770072, 19.502653700964792, 42.70738056727818, 88.95425687517438, 51.23436968667166, 29.47212185178484, 27.181194816316875, 7.637556297438485, 0.11382743170750992, 0.0539978032133409, 0.05433659574815205, 0.0663704482306327, 0.18957519318376267, 0.1581217295357159, 1.9052066930702753, 1.1186407570328032, 1.4589029444115502, 2.180754227297647, 1.7399868901286806, 2.5129882054669515, 2.5011473894119263, 12.505399090903145, 37.628577436719624, 73.2439351763044, 95.34946918487549, 78.39992237091064, 87.82660593305314, 84.0502461024693, 80.39274910518101, 74.1118416104998, 77.54247297559465, 73.67544610159737, 73.99232564653668, 65.00041171482631, 65.46570478166852, 65.85290009634835, 73.36373601640973, 76.37803827013288, 84.03002684456962, 84.77317142486572, 87.59052004132951, 80.13417189461845, 88.15312957763672, 86.91190338134766, 85.91681017194475, 81.03228909628731, 76.9802942276001, 74.94666767120361, 87.67321055276054, 46.702195235661094, 47.620899949754985, 69.10932622637067, 81.9142586844308, 35.603469371795654, 78.63472979409354, 81.88349206107003, 78.4579745701381, 86.28418922424316, 93.06884806496757, 91.63476766858781, 86.05187620435441, 73.29017543792725, 64.70428643907819, 65.19204998016357, 63.88298157283238, 66.61151136670793, 65.53507559640067, 67.76355743408203, 73.41258880070278, 73.3002850668771, 71.15404210771833, 65.60888631003243, 71.6752542768206, 78.40058244977678, 85.23360770089286, 77.98028591700962, 76.65392344338554, 68.16798428126744, 25.194249732153757, 0.8477812483906746, 1.6924570862736021, 1.4296313779694694, 1.2699987952198302, 0.5917601063847542, 0.90535228486572, 0.7629274587546075, 0.14992098244173185, 0.13308483229151793, 0.04581744270399213, 0.07128090438033853, 0.3860811058964048, 4.8626203536987305, 21.698668343680247, 42.18897894450596, 39.35189396994454, 68.36944729941231, 106.87450872148786, 39.80263750893729, 11.409899200711932, 21.520240340914043, 40.26580095291138, 46.05297640391758, 48.79940128326416, 48.65195008686611, 30.91400854928153, 22.48731667654855, 5.445935521806989, 0.07851848458605153, 0.14070339633950166, 0.06129143719694444, 0.021101674031732336, 0.14839585285101617, 0.041068515208150656, 0.04033871686884335, 0.008945946481877139, 0.008413420324879033, 0.031073752058936015, 0.056354446935334375, 0.03520563677219408, 0.024759574893063734, 0.12123664734619004, 0.07743801934910671, 0.013090462972676116, 0.051382603722491434, 0.12652433503951344, 0.03686715529433318, 0.06450265167014939, 0.05180833016389182, 0.07663077302277088, 0.1000223924805011, 0.1799736376851797, 0.03559546871110797, 0.03861719549500516, 0.03978825533496482, 0.04285777812557561, 0.04131365633968796, 0.07218351201819521, 0.03941172607509153, 0.06383447788123574, 0.059933471493422985, 0.18726066952305181, 0.06052632789526667, 0.026353200897574425, 0.05672871328092047, 0.02157581564305084, 0.011349305643567016, 0.008924150240740605, 0.041702657073204, 0.07538557305399861, 0.09462221725178616, 0.03409270702728203, 0.03543799091130495, 0.055681876239499876, 0.061819683494312425, 0.005946031206154397, 0.07038816942700318, 0.04601767160264509, 0.02780489094688424, 0.03949493482442839, 0.07821796821164233, 0.12548112816044263, 0.07742267767233507, 0.08286150225571223, 0.07562041402395282, 0.03872806133170213, 0.039064635057002306, 0.10224977867411715, 0.061979654910308976, 0.050868667728666744, 7.071333697863987, 70.8881345476423, 114.40676593780518, 104.13706438882011, 98.8612277167184, 75.22120489392961, 61.352475438799175, 43.48178161893572, 33.866523947034565, 33.180893080575125, 66.07231725965227, 47.07001897266933, 34.250999041966026, 32.95972497122628, 10.819390041487557, 0.10223818251064845, 0.058440904798252244, 0.09015303278075797, 0.064441400314016, 0.7365706073386329, 1.6075789779424667, 2.6123598217964172, 1.5191908351012637, 1.650735650743757, 0.5111421123147011, 0.38910216093063354, 1.2082821811948503, 5.366263134138925, 16.785727398736135, 44.78009768894741, 80.96416200910295, 98.60032285962785, 83.33053779602051, 92.37806510925293, 88.44175774710519, 86.41059085300991, 78.32497215270996, 80.94270597185407, 78.42401872362409, 75.93530600411552, 68.10274069649833, 70.0974087033953, 69.73391369410923, 77.43247604370117, 80.16598074776786, 88.28923783983502, 88.1978759765625, 90.27650601523263, 83.72318744659424, 91.37475218091691, 88.38350405011857, 90.63317094530377, 84.85124833243233, 80.8212445122855, 79.24688693455288, 92.45213985443115, 52.07662337166922, 55.05484710420881, 76.43058749607631, 88.57139028821672, 45.683644907815115, 82.52608925955636, 87.21530342102051, 82.68427889687675, 89.92622647966657, 93.23185975211007, 93.26990808759416, 89.5656636101859, 78.97428131103516, 67.80327333722795, 66.77998433794293, 66.98790918077741, 68.90440995352608, 68.57050037384033, 70.20137459891183, 76.87441062927246, 76.12882028307233, 73.50407573154995, 68.65620640345982, 75.69034031459263, 81.00882502964565, 88.05185958317348, 81.26880577632359, 77.29039927891323, 74.66811438969204, 29.80499962397984, 2.22090374146189, 0.9152489623853138, 0.6991509752614158, 1.1707760223320551, 1.4487283932311195, 1.264482468366623, 1.3126114457845688, 0.7149884711418832, 0.31162019286836895, 0.14630521860505852, 0.010316599093909775, 0.17492726418588841, 4.7202465534210205, 24.86420508793422, 40.41770247050694, 38.65844290597098, 64.87095287867955, 84.88738591330392, 37.201131207602366, 24.920237098421367, 41.50360516139439, 60.8544077192034, 66.53349699292863, 67.99047170366559, 70.57131058829171, 52.422164235796245, 27.8684880392892, 5.390906657491412, 0.0445744785081063, 0.0583382085231798, 0.055684244326714954, 0.05663268021973116, 0.03645037533715367, 0.07353183573910169, 0.017505206034651825, 0.04271447831498725, 0.058298873848148754, 0.04184043700141566, 0.039019020540373664, 0.0027761995235258447, 0.02472759723397238, 0.048310051273022375, 0.07492775869156633, 0.06385615707508155, 0.0651536313816905, 0.08695531436907393, 0.05045025928744248, 0.08372577266501528, 0.01851637757915471, 0.034561696861471446, 0.0406673720904759, 0.23918888664671353, 0.037656193133443594, 0.0009488011356942089, 0.05402869012738977, 0.07610987525965486, 0.0789915592010532, 0.017356774802984934, 0.040722832150225124, 0.03808750052537237, 0.026803573427189673, 0.15599521435797215, 0.1603589951992035, 0.10047316364943981, 0.15017005907637732, 0.08845819479652814, 0.2082202091280903, 0.10973989604307072, 0.20292627891259535, 0.2252322898379394, 0.20880860755486147, 0.17115232960454055, 0.15408397120024475, 0.15265760916684354, 0.1565176998930318, 0.08862627470599753, 0.2293192691036633, 0.08336398457842213, 0.1443669968949897, 0.14831970765122346, 0.20970601082912513, 0.2759535424411297, 0.18188642790274961, 0.3224908395537308, 0.14456556338284696, 0.1430113110691309, 0.12610429472156934, 0.18819704784878663, 0.07893173955380917, 0.10494953380631548, 12.423186268125262, 96.882415499006, 131.85731261117118, 116.978454044887, 110.93657152993339, 87.71442031860352, 62.975595474243164, 34.640108585357666, 31.37715114865984, 60.74589075360979, 116.07365962437221, 69.48340334211076, 47.42687497820173, 45.25261688232422, 14.49263686793191, 0.39097361479486736, 0.19646393853638852, 0.20278420725039073, 0.18726456431405886, 0.5232282866324697, 1.439344959599631, 7.685371194566999, 6.324983826705387, 8.05084296635219, 7.080548746245248, 5.578292625291007, 6.463529169559479, 9.223545159612383, 17.103793348584855, 45.79595906393868, 80.66240869249616, 104.31648772103446, 84.99152551378522, 96.79321452549526, 92.61209433419364, 88.40271581922258, 83.0380186353411, 85.49868147713798, 83.79092543465751, 82.85050759996686, 72.72808701651437, 73.46149022238595, 74.04402024405343, 81.68485695975167, 84.10235759190151, 93.29050254821777, 92.68973350524902, 93.54946190970284, 87.13884544372559, 96.16383974892753, 93.07023770468575, 94.86511026109967, 87.45690618242536, 84.13411780766079, 81.80406720297677, 97.12119034358433, 56.26004689080374, 61.125936371939524, 85.42751802716936, 100.16749600001744, 52.19059814725603, 83.75635119846889, 94.47437831333706, 87.46552194867814, 94.59006581987653, 100.45292104993547, 98.52865219116211, 97.25403990064348, 84.56947108677456, 72.66883277893066, 71.83454867771694, 71.80792318071637, 74.0632598059518, 73.46515887124198, 74.95080879756382, 80.69093104771206, 80.01728234972272, 79.46411541530064, 73.19719464438302, 79.85480567387172, 86.97329071589878, 93.61938858032227, 83.4862538746425, 79.40529196602958, 75.79068619864327, 29.189215523856028, 4.344650822026389, 7.517038055828639, 5.904513154711042, 3.5896148341042653, 2.8572373560496738, 3.725732215813228, 3.404940183673586, 1.3040737382003238, 0.3369390756956169, 0.22468591987022332, 0.2329257641519819, 0.6349748617836407, 9.06617019857679, 34.784367084503174, 61.70786190032959, 52.71978684834072, 80.38666248321533, 124.13900348118374, 52.69672230311802, 18.9210912159511, 40.28972012656075, 64.42398221152169, 77.65101773398263, 84.75808688572475, 90.09420612880162, 68.139725957598, 34.94193485804966, 7.094688330377851, 0.4616734896387373, 0.1689847901995693, 0.1712841282465628, 0.13291724771261215, 0.20596736430057458, 0.07785613941294806, 0.11253926690135684, 0.14045279978641442, 0.12556589075497218, 0.17382791531937464, 0.15931306060935768, 0.12919916079512664, 0.10570134382162776, 0.24753342888184957, 0.16550870958183492, 0.14491070700543268, 0.16490340206239903, 0.18583402250494274, 0.1560850931065423, 0.15792411299688475, 0.21307523575212273, 0.15732248313724995, 0.18272348227245466, 0.3684518433042935, 0.15381809403853758, 0.1221950916307313, 0.18199816904962063, 0.13454387257141726, 0.16228777170181274, 0.12558689819914953, 0.18969834728964738, 0.1282033020896571, 0.20500019405569347, 0.25815565032618387], [0.10981880966573954, 0.006416627472000462, 0.06734426133334637, 0.057205475733748505, 0.04661042283156088, 0.04143019472914083, 0.06350450630166701, 0.03680802096745797, 0.08169384526887111, 0.04636850134868707, 0.044028200142617734, 0.031954290345311165, 0.007253447747124093, 0.04848391569352575, 0.03047143348625728, 0.07438919866191489, 0.009454045378203903, 0.054196960026664395, 0.062005412099616866, 0.045009979246450324, 0.036231401908610544, 0.15822944018457616, 0.058140890539756844, 0.10822144323693854, 0.018677373583029424, 0.11404448827462536, 0.35436928325465744, 9.057172281401497, 75.60054874420166, 97.34267112186977, 92.77880246298653, 83.3692878995623, 77.09301485334123, 46.760045937129426, 21.95261284283229, 20.029566867010935, 36.62356219972883, 65.60622514997209, 43.55414015906197, 37.266086442129954, 31.206159455435618, 6.027691253593989, 0.046861090630825074, 0.11507103033363819, 0.21914737778050558, 0.02777607017196715, 0.09298581470336233, 0.21883276823375905, 1.244917861052922, 1.6620761965002333, 0.714232365999903, 2.264850229024887, 1.1413828624146325, 0.7435153318302972, 8.653822404997689, 35.1456629889352, 63.655858857291086, 86.00924900599888, 85.33314064570835, 76.14432866232735, 80.05717890603202, 79.4596199308123, 77.65249770028251, 76.78539725712368, 74.62650857652936, 69.74496132986886, 65.78170885358537, 63.42638070242745, 63.67482743944441, 68.90594550541469, 74.3350385938372, 76.37473092760358, 81.53679779597691, 86.13000869750977, 87.81950487409318, 83.31589099339077, 79.95695114135742, 79.36449909210205, 83.83624158586774, 84.13289492470878, 87.5694739477975, 82.70178140912736, 81.84219891684396, 77.86650916508266, 86.46319566454206, 35.664207049778526, 63.39569050925118, 50.798332009996685, 55.871864931924, 89.20628888266427, 70.32609476361955, 69.72368594578334, 72.82046331678117, 88.50894682747978, 85.91294002532959, 85.21275615692139, 67.53567736489433, 63.721303939819336, 59.96615695953369, 63.08964320591518, 63.11751937866211, 65.3558885029384, 64.66753741673061, 71.33438955034528, 71.11015728541783, 68.2173581804548, 62.64338820321219, 69.98548712049211, 78.94630091530937, 84.61532919747489, 82.33980110713414, 85.93864836011613, 81.6817650113787, 85.12457656860352, 44.292150020599365, 5.367109077317374, 0.9000217137592179, 1.8955341492380415, 0.9741913995572499, 3.1187048000948767, 1.088234788605145, 0.4581689376916204, 0.6098490900227002, 0.1116882957784193, 0.07434088696858712, 0.04305344048355307, 0.15647117953215325, 2.2938774142946516, 12.642839670181274, 28.07725187710353, 29.403831481933594, 37.12375259399414, 72.37693895612443, 31.866849763052805, 10.378216777529035, 9.013536725725446, 21.456624371664866, 40.141845090048655, 41.60788719994681, 52.41176973070417, 46.8383903503418, 27.522813422339304, 8.201927202088491, 1.1050093684877669, 0.07963789773306676, 0.09754506112741572, 0.1446543564753873, 0.037866918968835046, 0.04221082212669509, 0.02004023322037288, 0.03787749393710068, 0.04620197867708547, 0.032317910476454666, 0.03257552986698491, 0.0445429503784648, 0.0034742939502133852, 0.05037689268855112, 0.011942644653442715, 0.07864005091999259, 0.03824410980035152, 0.051748116966336966, 0.08006221960697855, 0.02882366208359599, 0.023763539768489342, 0.08162724027144057, 0.08422339667699166, 0.05367053898849657, 0.11516245614205088, 0.043173904198088815, 0.07212127678628479, 0.04305414615997246, 0.022654572668086206, 0.0688445633277297, 0.030168124940246344, 0.07943796060447182, 0.12476071396044322, 0.09204091397779328, 0.04620746463271124, 0.020661023212596774, 0.04808945953845978, 0.03590379163090672, 0.1284240566726242, 0.0500084617441254, 0.06456272237535034, 0.0071646809478157335, 0.062049781504486284, 0.016256338584103754, 0.03548720505620752, 0.025377141843949045, 0.014730240384648954, 0.02857361514387386, 0.04441940611494439, 0.04729377544884171, 0.043549809205744944, 0.05881074709551675, 0.04576568066009453, 0.08399232836174113, 0.0804319940507412, 0.03130222497774022, 0.11777925358286925, 0.05241290147283247, 0.18285997637680598, 0.2694495128733771, 12.002881918634687, 89.24849918910435, 113.10922459193638, 107.63863686152867, 98.1238431930542, 92.15856456756592, 63.63159574781145, 41.26855802536011, 25.06530679975237, 26.828881195613317, 44.278653144836426, 39.85162230900356, 37.33079848970686, 36.817621912275044, 9.379343748092651, 0.11187069956213236, 0.11387382314673491, 0.19829708231346949, 0.1231352018990687, 0.36411391464727266, 1.506671918290002, 2.0130527232374464, 2.577345677784511, 2.148198877062116, 0.8778306873781341, 1.2788465661661965, 1.7828530413763863, 10.666958723749433, 41.48764862333025, 70.07279123578752, 87.60811288016183, 88.93443366459438, 78.8903887612479, 83.666337285723, 83.21123027801514, 80.5582412992205, 79.73817321232387, 79.27663217272077, 74.9153173991612, 69.47416223798479, 66.2074110848563, 66.92353412083217, 72.11733341217041, 76.481858253479, 80.4721531186785, 85.8519834790911, 88.96970966884068, 89.35092258453369, 85.65142372676304, 83.6668722970145, 81.94414288657052, 87.83016341073173, 86.87771129608154, 90.19883905138288, 85.95892320360456, 83.67878150939941, 80.37241867610386, 89.84492560795375, 43.59213638305664, 72.02699988228935, 57.789939471653526, 62.04817077091762, 93.64194938114711, 75.74419580187116, 72.55141517094204, 75.56741973331997, 90.98208168574742, 88.53726073673793, 87.23658575330461, 70.63720035552979, 66.08890955788749, 63.3912228175572, 66.35176685878209, 66.01632172720772, 68.17917782919747, 68.31057521275112, 74.82369845254081, 74.68797928946358, 70.82985305786133, 64.3037714276995, 73.87784712655204, 82.99213968004499, 85.59827695574079, 85.8161655153547, 86.60057544708252, 86.23454434531075, 91.47094999040876, 51.927841595241, 7.697500143732343, 0.420173527938979, 1.0884594108377184, 0.41188492413078037, 1.1465810920510973, 1.63722140448434, 1.307066566177777, 1.8668522025857652, 0.15318147891334125, 0.05795888030635459, 0.11763015229787145, 0.12289890886417457, 2.339718154498509, 16.554373230252946, 29.369705404554093, 27.375862496239797, 36.250475202287944, 55.461493900844026, 27.918506383895874, 20.597151313509258, 21.226689372743877, 40.83575473512922, 58.54984310695103, 59.68047482626778, 69.25594711303711, 64.1580399104527, 36.17644909449986, 10.58463386126927, 1.7072498010737556, 0.06505913180964333, 0.14290676239345754, 0.06999398129326956, 0.013213783319640373, 0.05930391313242061, 0.05189421234120216, 0.034109945209430795, 0.051077201895947964, 0.02717078979393201, 0.022833634666832428, 0.022643498976581862, 0.05242249935067125, 0.03204478316807321, 0.02439364604651928, 0.07056585060698645, 0.007772245444357395, 0.055378418415784836, 0.07862389500119857, 0.00935520148569984, 0.030272931459226778, 0.09075744463396923, 0.09602814181042568, 0.12590663747063705, 0.06875504420271941, 0.09304811100342444, 0.07096126010375363, 0.045413724545921595, 0.026559037888156514, 0.043515095354190896, 0.053056800671453984, 0.057018695399165154, 0.10931699230734791, 0.19827128441206046, 0.10302339680492878, 0.10277412339512791, 0.14809860023004667, 0.13461385667324066, 0.1837965039802449, 0.13531204206602915, 0.12445849446313721, 0.12274367362260818, 0.15504701595221246, 0.18192374732877525, 0.11442418290036065, 0.11627108736761979, 0.1553197056055069, 0.19750789180397987, 0.14108849210398539, 0.12936722034854548, 0.1722558175346681, 0.22130544483661652, 0.1426209770143032, 0.21237034643335, 0.16529051986123833, 0.28794111204998835, 0.2940457559057644, 0.11879234707781247, 0.20704675066683972, 0.44619721866079737, 16.27629590034485, 116.13542216164726, 126.47937910897392, 119.72365951538086, 108.4242696762085, 102.70240034375871, 66.94667857033866, 40.47732496261597, 31.330740656171525, 53.16958543232509, 94.7202889578683, 62.322423117501394, 60.98250470842634, 52.6593132019043, 12.563186390059334, 0.30772629752755165, 0.19306869858077594, 0.6064999497362545, 0.2370836910392557, 0.4793432472007615, 1.023179565157209, 4.961717733315059, 8.969687512942723, 5.905070313385554, 7.174057602882385, 4.07178898368563, 1.3267856623445238, 9.663210664476667, 42.16508756365095, 70.34624453953334, 91.15261132376534, 92.98141888209751, 82.97009999411446, 86.58334391457694, 88.13712787628174, 84.31284632001604, 84.92912374223981, 81.95652457645961, 80.76468617575509, 73.63839135851178, 69.37617874145508, 69.9871824809483, 76.3493491581508, 80.91419056483677, 84.22204726082938, 88.19967555999756, 93.82136576516288, 93.86911378587995, 91.11295100620815, 88.17241777692522, 86.72312082563127, 91.92825262887138, 89.21858719417027, 94.87018244607108, 88.94707243783134, 88.70697048732212, 86.01975468226841, 93.53486374446324, 47.50153684616089, 80.7488373347691, 65.17675004686627, 67.07175309317452, 99.69938196454729, 78.19521454402378, 73.87720094408307, 79.7363041469029, 95.75461169651577, 93.81252070835659, 92.50626632145473, 73.42793042319161, 69.62978104182652, 67.17177936008999, 70.34636960710797, 70.5257373537336, 72.3012591770717, 72.61606815883091, 80.74245194026402, 78.31780855996269, 75.24334880283901, 67.1527829851423, 77.4645767211914, 85.38924734933036, 90.9459649494716, 87.74913351876395, 90.80420085362026, 90.37371131352016, 96.49936825888497, 49.22470051901681, 7.601364868027823, 3.376679471560887, 8.688898648534503, 7.898481999124799, 8.795451879501343, 5.644908913544246, 1.895008908850806, 3.361427524260112, 0.3185126158807959, 0.3115949513656752, 0.26332882844976013, 0.34909041651657646, 5.167071742670877, 24.487789903368267, 43.79718467167446, 44.26844276700701, 49.868944440569194, 91.44420637403215, 45.46561738422939, 19.748977763312205, 21.87165069580078, 38.6870173726763, 66.3705825805664, 74.53607082366943, 87.64815534864152, 80.04915373665946, 43.812477656773154, 13.9295939377376, 2.1618021471159796, 0.14359966878380093, 0.270512261560985, 0.18055941696677888, 0.1272556057998112, 0.18229958787560463, 0.16032707691192627, 0.12854681722819805, 0.20383770072034427, 0.12599965105099337, 0.1154763193002769, 0.14700499176979065, 0.11834026633628777, 0.13540189367319855, 0.09996783147965159, 0.1420545766928366, 0.1436249374278954, 0.20620445800679071, 0.19873788580298424, 0.054029972558575015, 0.16074362955987453, 0.1388350094535521, 0.20277179005954946, 0.1956630636538778, 0.18072371743619442, 0.14910507122320787, 0.09758333728781768, 0.09046709271413939, 0.11954195185431413, 0.18005177777792725, 0.1374023234737771, 0.19879330854330743, 0.14073257334530354], [0.11472846514412335, 0.03742467698508075, 0.04156326901699815, 0.01451166220275419, 0.046679630010787926, 0.04285137954034975, 0.07939270231872797, 0.022473861829244664, 0.023530128811086928, 0.0294441687874496, 0.026686612649687698, 0.03765637633789863, 0.04632183849545462, 0.014470936530934913, 0.02216981876907604, 0.04308814076440675, 0.023300656749467765, 0.023157920122944882, 0.04949961815561567, 0.04799644256542836, 0.04597962275147438, 0.0016436644634398232, 0.043034977545695643, 0.047373890078493526, 0.019419063248538544, 0.02278736706024834, 10.731739384787423, 88.84831074305943, 94.83528164454869, 93.72595310211182, 81.9656823022025, 65.31665202549526, 36.57704748426165, 27.753306014197214, 21.824896267482213, 50.206404549734934, 82.40110506330217, 47.922472613198416, 47.61826310838972, 23.322026354925974, 5.133476333958762, 0.20177481855664933, 0.018895651513178433, 0.022034678342086927, 0.07228395555700574, 0.07386509821351085, 0.3853398471006325, 1.693452632852963, 3.207841068506241, 1.561057748539107, 0.5274585453527314, 1.846287054674966, 7.6848935059138705, 34.26271717888968, 62.09162480490548, 80.10348864964077, 79.32912581307548, 85.23241261073521, 80.547089440482, 78.98097937447685, 66.39515141078404, 64.27868843078613, 67.65586035592216, 70.73377336774553, 72.46464606693813, 71.04709543500627, 66.13102258954729, 64.23271914890834, 63.141379492623464, 71.92900248936245, 76.61687564849854, 81.07914774758476, 80.80836255209786, 83.72907257080078, 82.89011233193534, 77.30910382952008, 70.67160088675362, 72.24034432002476, 77.08182825360979, 82.63861533573696, 85.22745159694126, 83.99418803623745, 84.12332030705043, 82.71793597085136, 82.08471884046281, 73.30473886217389, 27.622337681906565, 37.81156519481114, 81.45020934513637, 77.48961108071464, 67.19706385476249, 61.234196254185264, 65.64707360948834, 68.84891469138009, 75.6715315410069, 68.6834363937378, 63.980103492736816, 61.76168959481375, 62.740405900137766, 62.724848883492605, 65.81943757193429, 63.686486516680034, 63.856189319065635, 68.34487846919468, 67.82954447610038, 64.47849777766636, 65.90755462646484, 70.74388994489397, 81.45802606855119, 81.73861517224992, 83.18846797943115, 78.25084182194301, 74.61530808040074, 75.61464663914272, 88.71635055541992, 76.58921486990792, 30.5376524244036, 3.0695152453013828, 1.1911389125244958, 1.7543682498591286, 0.7179345616272518, 1.0302525056259972, 0.6199359744787216, 0.11514435282775334, 0.15645731027637208, 0.012832819833420217, 0.12410382420888968, 0.18342894156064304, 1.6233329325914383, 9.760025995118276, 25.855431624821254, 38.52613878250122, 36.66038417816162, 49.774952684129985, 43.745705468314036, 34.16286809103829, 12.859706844602313, 24.390608923775808, 40.0517304284232, 46.2880026953561, 51.27455459322248, 56.13008778435843, 48.78076621464321, 22.745206015450613, 3.7576887181827, 0.16427962481975555, 0.05611801819343652, 0.035822906864008734, 0.025975019404930726, 0.10284406678485018, 0.009605267085134983, 0.06140653709215777, 0.062050962155418735, 0.035722354759595225, 0.03805004199966788, 0.045963032570268424, 0.035633178294769356, 0.03690092598221131, 0.024030338041484356, 0.03754331883309143, 0.016187988055337752, 0.04364645294845104, 0.07355498735393796, 0.08024963776447944, 0.1349578739276954, 0.03181699896231294, 0.052922145397003205, 0.07367763934390885, 0.04015767015516758, 0.005953773290717176, 0.06525156434093203, 0.11314126316990171, 0.022434917311849337, 0.06303561146238021, 0.06675121494169746, 0.07264718213783843, 0.03812374447339347, 0.05043354357725807, 0.03966637687491519, 0.024581011617556214, 0.02537605618791921, 0.012641636654734612, 0.03663865862680333, 0.03452387871220708, 0.03885355977607625, 0.013858837724131132, 0.06888043747416564, 0.03333546533914549, 0.06599416663604123, 0.045388751064560244, 0.024825275742581913, 0.036665738959397585, 0.03116388525813818, 0.05517269677615591, 0.048083912514682324, 0.013536782103723713, 0.08365171056772981, 0.07141648246241467, 0.07301957572677306, 0.01408049391050424, 0.01183992378147585, 0.04934096649023039, 12.638557842799596, 104.09989152635846, 111.94790962764195, 107.4178022657122, 93.53067398071289, 76.54878330230713, 55.1047351700919, 49.40190042768206, 23.406440019607544, 34.25973640169416, 66.5982333592006, 49.05270481109619, 49.943265846797395, 30.410587242671422, 7.86813747882843, 0.15949327951031073, 0.0253949109797499, 0.031409409761961014, 0.10229722862797123, 0.04828101675957441, 0.13968161759631975, 1.8426110233579363, 5.995067724159785, 2.117435944931848, 0.11952475777694158, 2.955628190721784, 10.630527581487383, 38.553403513772146, 68.43060534340995, 83.63270105634416, 80.54298305511475, 86.73238277435303, 84.39579391479492, 82.43387276785714, 68.98836503710065, 67.02193450927734, 70.34186022622245, 75.31989015851701, 73.4254012789045, 73.75054223196847, 69.28982652936662, 66.86999130249023, 66.96771771567208, 74.89844022478376, 80.23462200164795, 84.46286487579346, 85.0286705834525, 87.18883078438895, 84.57637064797538, 81.2130742754255, 73.8769508089338, 74.23752757481166, 79.80744675227574, 85.1364996773856, 88.235764503479, 86.36419078281948, 88.1539077758789, 86.51342419215611, 86.01029818398612, 74.89809281485421, 35.45630305153983, 44.08988101141793, 84.05618681226457, 82.818740436009, 71.39574909210205, 66.11841855730329, 67.65617302485875, 72.172682762146, 75.59736646924699, 72.04402991703579, 68.09534086499895, 66.91531440189907, 66.61579145703996, 66.94804736546108, 69.22306823730469, 67.17646244594029, 68.420565196446, 69.8407769884382, 70.39739022936139, 67.79344858442033, 67.5479965209961, 74.09775761195591, 85.24580178941999, 85.5137243270874, 85.17667416163853, 82.63822623661586, 78.56815910339355, 78.79143946511405, 91.12046200888497, 83.87167045048305, 36.41659273420061, 5.11141927753176, 0.02403035500485982, 1.600557606135096, 0.124933319698487, 1.5338487114225114, 1.39230663222926, 0.24481407765831265, 0.17653130739927292, 0.05072147651974644, 0.09711967395352465, 0.1567343154123851, 1.4296437544482095, 11.196642483983721, 28.624823774610245, 31.67675052370344, 27.542747804096766, 35.625995431627544, 33.5277749470302, 36.266938958849224, 26.16562179156712, 38.97406135286604, 55.69915703364781, 62.71141801561628, 66.00985990251813, 76.37652356284005, 63.74840191432408, 27.4307758467538, 5.1422284586088995, 0.22369684651494026, 0.03182894117864115, 0.046045366009431224, 0.0408303324532296, 0.09112634376755782, 0.043880432178931575, 0.0222294789605907, 0.04065094815034952, 0.03999054358739938, 0.09341197540717465, 0.04801191655652864, 0.02391366394502776, 0.05057772209069558, 0.048173770907201936, 0.056371491735002825, 0.02535419718229345, 0.018206095389489616, 0.034579074143299034, 0.08076966700277158, 0.06806230744613068, 0.0202708062050598, 0.033102113753557205, 0.03817726731566446, 0.059959567950240204, 0.03975994346131172, 0.06161368704800095, 0.09765375565205302, 0.032735033093818595, 0.026796380955992, 0.03405300594334092, 0.06066603147025619, 0.15763684841138975, 0.10806907141315085, 0.0886621827791844, 0.14488371488239082, 0.126203469399895, 0.11704362662775175, 0.09540287857609135, 0.1187959433134113, 0.09232163748570851, 0.10659401092146124, 0.13895162248185702, 0.1260770447552204, 0.13352630074535096, 0.12542022285716875, 0.13501854852906295, 0.1077736576220819, 0.08914382729147162, 0.145558965791549, 0.10289119782724551, 0.1293620906238045, 0.15306980561997208, 0.08850428089499474, 0.1408844023410763, 0.08023202299539532, 0.11587162023144108, 0.10870918099369321, 18.487296070371354, 129.34849875313895, 122.52370016915458, 118.38130923679897, 106.56034592219761, 89.64515100206647, 56.46565450940813, 43.676768915993826, 32.35361623764038, 73.7446015221732, 115.02099364144462, 70.20505714416504, 74.08156830923897, 39.18557146617344, 10.809775471687317, 0.5171225571206638, 0.13010527645902975, 0.18616199919155665, 0.15112805552780628, 0.15387633948453835, 1.9211862470422472, 6.493046419961112, 11.30281616960253, 6.9795849067824225, 3.674102323395865, 2.9465540604931966, 10.272078701428004, 41.415918895176475, 70.67819472721645, 86.4065192086356, 82.28969069889614, 88.16837392534528, 88.23349939073834, 86.05617019108364, 73.49451501028878, 71.18626090458461, 74.31674398694719, 78.96521391187395, 80.23920781271798, 78.47870799473354, 73.89942823137555, 72.74137197222028, 70.42539146968296, 80.9074855531965, 84.4698269707816, 86.53194114140102, 88.65421976361955, 90.72151034218925, 89.59836878095354, 86.98250402723039, 80.28744220733643, 80.16688401358468, 83.30798394339425, 89.89906597137451, 94.37205219268799, 90.30036612919399, 92.24653570992606, 90.6658135822841, 92.17105048043388, 76.22772789001465, 40.566070829119, 50.90040452139718, 87.36397402627128, 88.78876468113491, 76.92066478729248, 70.18679727826799, 71.76330184936523, 77.02397755214146, 81.31638704027448, 77.78572940826416, 70.96128518240792, 68.89578029087612, 70.71416555132184, 70.34979506901333, 73.0863847732544, 69.97159767150879, 71.1106367111206, 75.71372100285122, 74.23236506325858, 70.81961141313825, 73.16914476667131, 79.31758485521588, 89.13435418265206, 87.98394789014543, 90.34967749459403, 87.70542240142822, 81.33519581386021, 82.39632470267159, 98.93505232674735, 84.3341703414917, 33.78607075554984, 3.3804477836404527, 5.314933317048209, 6.597272438662393, 2.6406348645687103, 5.095605177538736, 3.2022935833249773, 0.5546650854604585, 0.5430468288915498, 0.22465864276247366, 0.2502110909138407, 0.41272638897810665, 3.4070986849921088, 19.42715457507542, 41.44344418389456, 57.62042774472918, 51.795704228537424, 67.74170534951347, 61.106425830296104, 48.48476948056902, 19.67216542788914, 40.037931306021555, 65.73102174486432, 76.64183357783726, 83.04720415387834, 87.3665657043457, 73.83180836268834, 34.03027214322771, 7.003699932779584, 0.7246713829892022, 0.24436296043651445, 0.1387126153068883, 0.18976734073034354, 0.24403463091169084, 0.1296141663832324, 0.12211765721440315, 0.16358723411602633, 0.10808331386319228, 0.2160238910998617, 0.11761985213628837, 0.0934685787984303, 0.1358636910361903, 0.18488898607236998, 0.13998455634074553, 0.12071572244167328, 0.18639633804559708, 0.13116020842322282, 0.23515407315322331, 0.15783538775784628, 0.10243235887693507, 0.1695110076772315, 0.10070037788578443, 0.06282453957412924, 0.09307866543531418, 0.13676473125815392, 0.13757938040154322, 0.09238533835325922, 0.14666732560311044, 0.16967289256198065, 0.13073697899069103], [0.07320536540022918, 0.02351784223823675, 0.004669150437361428, 0.030339678949011222, 0.030598180435065712, 0.022951352010880197, 0.03657097136601806, 0.07572160395128386, 0.010711392820147532, 0.0444175944264446, 0.02659217075311712, 0.01804249720381839, 0.028736799423183714, 0.04480663926473685, 0.038666776048817804, 0.030132634166095938, 0.03252041586009519, 0.012275504247684563, 0.013081141597857433, 0.06231067143380642, 0.055617011684392176, 0.05448574453060116, 0.05027888169778245, 0.016054023190268447, 0.02648168659236814, 8.101510099002294, 87.45359883989606, 101.42867742265973, 95.53642436436245, 91.76169736044747, 66.29245703560966, 47.947461809430806, 26.33897760936192, 23.287724835532053, 77.43259416307721, 59.851602009364534, 40.65926354272025, 40.50524629865374, 28.10760681969779, 7.233401732785361, 0.084196119569242, 0.006241008614389492, 0.04407161281311086, 0.05126170574554375, 0.11467164462166173, 0.19898363761603832, 1.17129833144801, 3.825688566480364, 1.6587072972740446, 0.9766899283443178, 5.364490474973406, 24.879437276295253, 58.41848046439034, 83.79387841905866, 78.71835136413574, 79.61015960148403, 77.71344035012382, 82.24686895098004, 83.4981769834246, 77.58473886762346, 72.86528614589146, 65.92032541547502, 59.61093725476946, 60.7043822152274, 60.72696386064802, 61.95845563071114, 59.989586285182405, 61.2015814099993, 61.445789745875764, 71.40041828155518, 79.92458643232072, 81.7414083480835, 79.17097091674805, 79.13953726632255, 75.59123815808977, 70.9270236151559, 59.00892448425293, 65.77799156733921, 67.7611186163766, 77.96552099500383, 74.85763345445905, 85.7213156563895, 78.82431834084647, 88.13648864201137, 75.3084534236363, 97.02845273699079, 39.118917397090364, 31.101738452911377, 91.72298894609723, 68.3776044845581, 77.25462995256696, 55.90336111613682, 65.8397193636213, 58.50096252986363, 64.9739738191877, 58.90629959106445, 65.1800434929984, 62.56331021445138, 66.3943315233503, 65.28125095367432, 67.69651426587785, 64.292619568961, 65.93211650848389, 62.87028162819998, 69.14107254573277, 62.53079959324428, 67.49425915309361, 70.34845406668526, 74.91745049612862, 81.24810709272111, 80.50476796286446, 69.091399874006, 66.06421566009521, 71.31976359231132, 74.35349300929478, 76.00483662741524, 79.18923078264508, 70.48560455867222, 28.294139896120342, 0.8073041375194276, 0.5450947561434337, 1.1487299310309547, 1.0243747638804572, 0.134000406733581, 0.02638038301042148, 0.08734197754945074, 0.11049973991300378, 0.05132751685700246, 0.031899909156241586, 0.3199133835732937, 4.848602797303881, 20.140665088381084, 33.48552642549787, 42.61136341094971, 61.18145942687988, 54.497170788901194, 30.409777777535574, 16.74066138267517, 18.767871277672903, 38.64488002232143, 42.34438582829067, 58.104032788957866, 60.23342636653355, 57.959916727883474, 40.64383159364973, 8.785852074623108, 0.3093728848866054, 0.02687958631265376, 0.011277225716704769, 0.029928384947457483, 0.012627698697282799, 0.02133161767518946, 0.03883113758638501, 0.011398703841093396, 0.02096831306282963, 0.025336964089157324, 0.01592340859185372, 0.059619669403348646, 0.035742822768432755, 0.029570501829896654, 0.07452607274587665, 0.060850328366671286, 0.01646376334662948, 0.05206344576020326, 0.037240380088665655, 0.040744087259684286, 0.05799213530761855, 0.07769615442625113, 0.06680528739733355, 0.05926118578229632, 0.02988763213423746, 0.017145458642127256, 0.03314056633306401, 0.022384510641651492, 0.07860184261309248, 0.068762779501932, 0.03548524069732853, 0.05542953585141471, 0.013867332134395838, 0.03935227283675756, 0.06127470452338457, 0.05210046323814562, 0.018904933872233545, 0.021159802430442402, 0.08170296477952174, 0.010764517871263837, 0.019023965877879943, 0.040578283835202456, 0.054684076923877, 0.032858970907649825, 0.05565013097865241, 0.02624249960561948, 0.035561446965272935, 0.05190470927794065, 0.03700557643813746, 0.04694537485816649, 0.008281150101018804, 0.02975067662607346, 0.058596011118165085, 0.029678141232579947, 0.058649662882089615, 11.745356491633824, 105.0541432244437, 116.4466667175293, 107.62057154519218, 102.89351054600307, 77.28889846801758, 68.40484142303467, 41.79319218226841, 29.735253606523784, 49.66241618565151, 44.02893488747733, 42.28091056006295, 39.94324820382254, 36.0031749180385, 9.159243055752345, 0.07221790017294032, 0.1007091242021748, 0.09043558154787336, 0.12439787414457117, 0.20960287350629056, 0.3233995607921055, 0.7873891890048981, 1.6933063949857439, 0.8763787310038293, 1.0465191070522581, 8.243825708116804, 27.786021607262747, 64.4122119631086, 88.52281543186733, 82.46252019064767, 82.67437076568604, 81.3853131702968, 82.20548548017229, 85.82587214878627, 81.05717754364014, 77.28700855800084, 67.01943315778459, 63.38305868421282, 64.14203820909772, 64.57816273825509, 65.28967217036656, 62.7805734361921, 64.29644802638462, 63.56173161097935, 74.90194906507219, 83.80924783434186, 84.47216851370675, 83.23707062857491, 83.9907625743321, 79.91931969778878, 73.36127635410854, 62.740412848336355, 68.4519988468715, 71.55461965288434, 80.61868367876325, 78.54586928231376, 88.07522637503487, 81.3913094656808, 90.58885533469063, 76.70342935834611, 100.30160318102155, 43.25678505216326, 35.04724522999355, 94.51781845092773, 72.15549291883195, 80.01627486092704, 59.41242722102574, 66.79675728934151, 60.972568784441265, 67.690719468253, 60.33842754364014, 67.55268655504499, 65.35593019212995, 69.76405497959682, 69.96041801997593, 72.12066854749406, 67.3945038659232, 68.29042543683732, 67.0535557610648, 72.31573922293526, 65.5844008581979, 70.1910982131958, 73.39452348436627, 79.06330163138253, 82.40293938773019, 81.73554406847272, 71.80309418269566, 68.52729647500175, 74.36799389975411, 78.21277959006173, 79.5410806110927, 82.02615247453961, 78.19877202170235, 34.27476535524641, 1.4616004739488875, 0.19979444625122206, 0.4495551256196839, 1.1112992252622331, 0.18289032046283993, 0.12297001933412892, 0.11312653895999704, 0.11939993447491101, 0.1516546258436782, 0.07989050274980919, 0.1796699118401323, 5.505073811326708, 26.551853043692454, 34.736910888126914, 32.34309319087437, 46.40043497085571, 46.15051521573748, 16.151254381452286, 30.877964769090923, 35.43045922688076, 51.4598456791469, 60.425599643162315, 69.86415072849819, 74.21369525364467, 70.49727058410645, 49.363848618098665, 12.029985104288373, 0.34465654300791876, 0.029082187318376133, 0.022035916668495963, 0.03258730923490865, 0.02458244332644556, 0.03081480273976922, 0.056406809482723475, 0.013898434483313134, 0.04086325836500951, 0.00749561604711094, 0.06604599992611579, 0.019987829960882664, 0.00634878669266722, 0.04218348055811865, 0.07293219398707151, 0.050425153491752486, 0.027435795038140247, 0.06831436284950801, 0.07987340366733925, 0.03971191675269178, 0.05090762581676245, 0.05583384094227638, 0.06346837431192398, 0.08149869859750782, 0.059738406246261935, 0.06378007972879068, 0.04878176881798676, 0.050278260838240385, 0.05442506992923362, 0.037285149829196076, 0.17223710353885377, 0.1401545022215162, 0.10339940020016261, 0.08675243239849806, 0.13496839122048446, 0.14769663608499936, 0.12171371174710137, 0.17027999141386577, 0.13432081096938678, 0.17857514987034456, 0.06276006517665726, 0.0973613274150661, 0.13055661081203393, 0.16907548319016183, 0.1342339584869998, 0.19059959107211658, 0.16265561910612242, 0.16935465963823454, 0.09185165020504168, 0.12785673354353222, 0.0820092215601887, 0.14444288425147533, 0.21879166258232935, 0.13428402080067567, 0.17702433094382286, 16.925948994500295, 122.54714339120048, 125.38894271850586, 121.46733774457658, 117.09539222717285, 89.26281247820172, 68.31052657536098, 40.45275265829903, 37.05339860916138, 104.48188958849225, 77.651962688991, 58.55745138440813, 62.98022297450474, 44.96485723767962, 13.049291917255946, 0.49719952046871185, 0.263055785958256, 0.24561024350779398, 0.26656421912567957, 0.6206301429441997, 1.5059219471045902, 5.01767418214253, 11.104720422199794, 6.127348397459302, 3.594671819891248, 9.474474140575953, 28.484894003186906, 67.05502183096749, 93.16961084093366, 88.85077735355922, 86.79571560450962, 84.97344630105155, 82.45047201429094, 92.12797164916992, 86.3855425970895, 82.69472898755754, 72.70928519112724, 66.0689056941441, 68.40464687347412, 68.14070565359933, 69.42215497153146, 66.37629399980817, 66.58575439453125, 67.91812011173793, 78.095431464059, 89.04525743212018, 88.0483785356794, 86.29793276105607, 88.08998434884208, 84.31114401136125, 78.63850266592843, 67.96531922476632, 71.3423660823277, 75.16640445164272, 84.44770390646798, 81.79199818202427, 92.30565098353794, 87.06900909968785, 95.17994703565324, 81.03144141605922, 103.21687276022774, 46.23829180853707, 39.89846706390381, 96.94886112213135, 78.14128262656075, 83.46737561907086, 62.93459415435791, 71.0991930280413, 63.99288122994559, 70.529586655753, 62.996099608285085, 70.6266529900687, 69.46092591966901, 71.2745030266898, 73.62829562595913, 75.90161418914795, 71.88857786996024, 74.9659697668893, 70.69935894012451, 77.83645125797817, 68.60044016156877, 74.67855753217424, 77.50594629560197, 81.58901350838798, 89.95614542279924, 86.33318097250802, 76.88172013419015, 73.31699548448834, 79.06267629350934, 80.85333824157715, 79.92806053161621, 84.25053487505231, 81.50979709625244, 32.471099853515625, 0.7292672906603131, 2.2827107906341553, 3.748764191355024, 3.5071243005139485, 0.9794286042451859, 0.4530792736581394, 0.3685253422175135, 0.23595251888036728, 0.15731839835643768, 0.25598395828689846, 1.039605432323047, 10.569208860397339, 35.84171962738037, 50.36190523420061, 60.374905586242676, 76.88570145198277, 64.72802148546491, 46.84719719205584, 29.652896608625138, 32.99570621762957, 61.65619509560721, 73.24879196711949, 85.55417673928397, 87.45830277034214, 82.14110347202846, 58.88976287841797, 16.287529400416783, 0.7449874814067567, 0.14820618874260358, 0.13637313512819155, 0.11616781433778149, 0.11688912420400552, 0.15752057465059416, 0.10417527785258633, 0.07724653676684413, 0.1743552591651678, 0.10772911858345781, 0.12799811310001782, 0.15839551841574057, 0.15933838353625365, 0.13928134978881904, 0.18431461974978447, 0.08405887907637016, 0.08178919300969158, 0.1314379870891571, 0.17656270999993595, 0.1279222664556333, 0.12242721846061093, 0.1376875795956169, 0.12527125727917465, 0.11789820077163832, 0.1680506103272949, 0.10811419399189097, 0.131667467632464, 0.13748373410531453, 0.15917516872286797, 0.15622348710894585], [0.0660000020372016, 0.03117295048598732, 0.021670678231332983, 0.02953575405159167, 0.028248739362295185, 0.020341153323118175, 0.01475839619524777, 0.027321321091481617, 0.01748597974489842, 0.020012815316606845, 0.009701008376266276, 0.03495128113510353, 0.04195823746600321, 0.052922165753053765, 0.040310978357281, 0.035619834903627634, 0.02447271064322974, 0.02415033526319478, 0.01763977818856282, 0.018172920116090348, 0.10818035115620919, 0.026811734507126466, 0.08280156725751502, 0.026927299198827574, 1.9534195916993278, 82.08291925702775, 104.65088367462158, 98.42990439278739, 90.84391675676618, 63.09978757585798, 52.738793645586284, 19.294423137392315, 23.4661545753479, 78.42786107744489, 62.464291436331614, 60.43217958722796, 52.72496673039028, 35.73203189032418, 11.707783239228384, 0.20181428215333394, 0.015534713199096066, 0.07729021406599454, 0.027002636941948106, 0.08378149396074669, 0.2646357683198792, 0.0788957771978208, 0.046587440850479264, 0.6796872796756881, 1.612333934221949, 10.56413493837629, 33.17960071563721, 72.31685788290841, 84.55192688533238, 77.95054067884172, 81.25554861341203, 81.60867691040039, 81.40909685407365, 79.86376885005406, 79.26875986371721, 80.915086882455, 72.09222957066127, 68.40816961015973, 66.03548485892159, 64.04571533203125, 60.018219811575754, 60.5603460584368, 58.3677864074707, 60.5790992464338, 58.05982834952218, 61.15775217328753, 69.46279498508999, 78.41545854296002, 76.86655916486467, 71.7925329208374, 65.75377014705113, 60.48943274361746, 57.99784346989223, 59.642780848911826, 62.6878080368042, 66.66188580649239, 67.53434331076485, 71.8823105948312, 69.56373841421944, 72.12234306335449, 68.53705174582345, 80.77253069196428, 67.01318672725132, 38.33607081004551, 86.13181522914341, 72.65585354396275, 79.30156230926514, 66.13623373849052, 63.32201875959124, 71.420227595738, 71.41104902539934, 65.91945689065116, 61.08103711264474, 62.41622379847935, 67.22293199811662, 66.86070156097412, 71.33297211783272, 67.44989490509033, 67.35305091312954, 63.963233266557964, 63.90181813921247, 59.86410181862967, 63.75168146405901, 64.3717039653233, 68.87690898350307, 65.0079505102975, 61.38003199441092, 57.8035683631897, 63.60654749189104, 70.05062648228237, 80.53367246900285, 76.32761519295829, 72.07410866873605, 81.05277933393205, 86.63542066301618, 55.346261501312256, 5.977697227682386, 0.1702045111783913, 0.521555942084108, 0.3469181816492762, 0.04638158350384661, 0.12970172454203877, 0.20079965516924858, 0.15707853622734547, 0.14473143805350575, 0.016158049393977438, 0.7124560156038829, 6.392715735094888, 20.952122620173864, 28.49894152368818, 38.74801560810634, 48.697558062417166, 94.29967975616455, 30.799797534942627, 14.651056664330618, 17.72813936642238, 25.154436554227555, 48.39319222314017, 55.90102652141026, 66.62207957676479, 64.3130750656128, 54.13166775022234, 13.127967238426208, 0.3192053458520344, 0.04004826995411089, 0.035077912732958794, 0.060433042900902886, 0.02148268331906625, 0.07142109650054149, 0.048326855192759206, 0.04276148382840412, 0.06550262908318213, 0.021144096041098237, 0.038484507972108464, 0.045245278227542124, 0.014648841627474343, 0.029933806442256485, 0.04646223756883826, 0.06445310504308768, 0.034204322645174604, 0.06276569701731205, 0.01248502398708037, 0.05245334555261901, 0.034019289538264275, 0.04146548194278564, 0.06606264439012323, 0.0429346934626145, 0.046898281135197194, 0.057445249653288295, 0.017014640483206937, 0.026135747387473072, 0.12122382303433758, 0.02754722914791533, 0.020562508409576755, 0.010711743113850909, 0.044616374652832747, 0.04410848440602422, 0.07685838759477649, 0.017956623508195792, 0.03192422106595976, 0.028085935062595775, 0.007204698398709297, 0.04224489476265652, 0.05743112933955022, 0.03889584947111351, 0.02502983369465385, 0.037494036834686995, 0.05600829229557088, 0.032080901587115865, 0.013788641580114407, 0.07624455089015619, 0.028408137416200976, 0.040624040844185014, 0.035490244893091064, 0.066752945205995, 0.03112317994236946, 2.644592732191086, 102.18949127197266, 120.72767421177456, 112.25918892451695, 100.61539077758789, 81.60610607692173, 73.18413897923061, 37.3380697795323, 31.183588232312882, 46.74499266488211, 68.05807767595563, 52.04640565599714, 44.80440248761858, 43.66967827933175, 15.445730822426931, 0.24363462094749722, 0.014602083779339279, 0.12813106525157178, 0.06747436363782201, 0.09893450407045228, 0.3768651618489197, 0.21453523955174855, 0.26373928785324097, 0.7063106053641864, 1.0241325540202004, 12.969857505389623, 37.15077066421509, 75.66516699109758, 90.0600974219186, 82.86248629433769, 86.56288841792515, 85.94643034253801, 87.18398094177246, 83.0488508769444, 81.75088569096157, 82.61749976021903, 75.79179096221924, 73.08451570783342, 70.63158621106828, 66.6691814150129, 63.04398659297398, 62.212266377040315, 62.16672093527657, 64.1307682309832, 61.34528405325753, 65.56004742213658, 74.06666442326137, 80.80297074999127, 79.35481330326625, 74.8623582295009, 67.72716276986259, 63.43089008331299, 60.16124153137207, 63.478443554469514, 65.84577124459403, 69.7440024784633, 70.25011621202741, 75.13068376268659, 70.9393149784633, 77.8164404460362, 73.19639560154506, 82.42997482844761, 72.87552779061454, 40.60018995829991, 89.16565581730434, 77.23673834119523, 83.07886014665876, 69.49538898468018, 66.745194707598, 74.24661581856864, 74.66701657431466, 70.0466799054827, 63.77071952819824, 63.370663097926546, 69.17941270555768, 70.20817688533238, 72.59541811261857, 71.28727381569999, 70.63815225873674, 68.12576007843018, 65.98729215349469, 62.2152749470302, 66.15636266980852, 66.48444965907505, 71.54221711839948, 67.35096645355225, 64.6889865057809, 60.32881818498884, 65.8311939239502, 72.58647578103202, 84.4281725202288, 79.26602227347237, 73.99192265101841, 83.56546333857945, 90.50762394496373, 63.52747004372733, 7.704268557684762, 0.7158078157476017, 0.06960884481668472, 0.6863970139196941, 0.06552469504198857, 0.13575421619628156, 0.3034111405057566, 0.2843812459281513, 0.06604751984455756, 0.0719470629202468, 0.687266407268388, 6.244373866489955, 25.955694130488805, 30.273992606571742, 30.076868738446915, 32.831798212868826, 75.53379045213971, 25.08529155594962, 22.678324392863683, 37.55049705505371, 37.20049892153059, 63.1671017238072, 67.41723837171281, 75.88608496529716, 77.56674998147147, 67.62412793295724, 18.46136018208095, 0.43759412744215553, 0.050367997094456635, 0.039651523743356974, 0.027665742074272463, 0.020916008190917115, 0.049916886658008607, 0.04232611879706383, 0.059766395815781186, 0.08047986469630684, 0.02835226005741528, 0.04459660553506442, 0.0031729607892754886, 0.005100722882031862, 0.05965616101665156, 0.029213633122188703, 0.02539118073348488, 0.018510404774653058, 0.03472996676074607, 0.04785726824775338, 0.06133393384516239, 0.05013569723814726, 0.03247822455263563, 0.06862334734094994, 0.04714173271453806, 0.04579242511785456, 0.02727700088040105, 0.06251662716801677, 0.06672321180147783, 0.13142193295061588, 0.1478188131004572, 0.0960933490257178, 0.1747261192649603, 0.1335727803941284, 0.12816256284713745, 0.12124787031539849, 0.10279414696352822, 0.08993191178888083, 0.15061353599386557, 0.14356518563415321, 0.10408948388482843, 0.2640172972210816, 0.06665012000926904, 0.1569954292582614, 0.17486046919865267, 0.12343881917851311, 0.11692599579691887, 0.18906576266246183, 0.15645743241267546, 0.14961450174450874, 0.16225814686289855, 0.09675642023129122, 0.23804183676838875, 0.06549948746604578, 3.9186550293649947, 118.03316279820034, 130.8166114262172, 124.65947914123535, 115.71179049355644, 87.42425659724644, 75.01528113228935, 30.371514047895158, 34.07633522578648, 103.19128949301583, 78.35892105102539, 77.79947294507707, 83.38364287785122, 57.23779044832502, 20.997214691979543, 0.7484010553785733, 0.10459743519978863, 0.30985510615365847, 0.10250300115772656, 0.3587757982313633, 1.0242320001125336, 1.9164228226457323, 1.0259688326290675, 3.1062236641134535, 5.891262071473258, 14.807874032429286, 37.66553143092564, 79.08901691436768, 94.38117517743791, 87.41788509913853, 91.05145944867814, 90.06856727600098, 90.19232164110456, 85.4807481765747, 82.40810189928327, 85.57773808070591, 80.0547261919294, 76.13490690503801, 73.64638873508999, 72.35980469839913, 66.33881541660854, 64.94411046164376, 64.94312381744385, 68.90256173270089, 64.41048186165946, 67.53427382877895, 77.0313217980521, 85.52683557782854, 84.60419123513358, 78.95047678266252, 72.05583490644182, 67.79286493573869, 65.3296034676688, 68.33280944824219, 70.30118547167096, 73.43865844181606, 73.84771278926304, 80.46387086595807, 76.39827837262834, 80.27161421094621, 77.95164544241769, 87.9296407699585, 75.9627513885498, 45.89205265045166, 92.34636742728097, 81.04289204733712, 88.9365598133632, 73.26858738490513, 71.38836315699986, 79.78154386792863, 78.86520154135567, 74.84971945626395, 67.6635867527553, 68.63319396972656, 73.11667197091239, 73.91690989903041, 77.54912934984479, 76.53886822291783, 74.74202932630266, 73.29103006635393, 69.8608294895717, 65.54384422302246, 68.17905276162284, 70.54014791761125, 75.54802731105259, 71.64486285618374, 68.22343785422188, 65.31925065176827, 69.27721554892403, 75.91480187007359, 89.30923339298793, 80.61486216953823, 73.25612926483154, 87.72731617518834, 96.69740581512451, 66.07547869001115, 6.455852712903704, 1.9542553297110965, 2.745843401976994, 1.292536905833653, 0.22703571378120355, 0.324705387864794, 0.5964362440364701, 0.9627937482936042, 0.44913196404065403, 0.1738017645797559, 1.3002304072890962, 13.0667553458895, 37.19545452935355, 46.15554223741804, 56.656952313014436, 61.95566940307617, 111.59107099260602, 45.204208782741, 22.102379526410783, 29.66444798878261, 41.47575330734253, 74.28040490831647, 81.93508243560791, 90.54236493791852, 87.61004447937012, 75.52961458478654, 21.817982809884207, 0.6245019723262105, 0.12453716381319932, 0.12403787060507707, 0.21448965556919575, 0.15589825170380728, 0.197318363402571, 0.11521910024540764, 0.11369387565978936, 0.15937095321714878, 0.2018666650567736, 0.1833181639334985, 0.1079505177746926, 0.11662820034793445, 0.17605979341481412, 0.19269521933581146, 0.05831755391721215, 0.1287140625395945, 0.1678167057356664, 0.15552185475826263, 0.2217726976211582, 0.16305231781942503, 0.11910413391888142, 0.07005664400224175, 0.14493426574128015, 0.1438583806157112, 0.14346415176987648, 0.1383934324341161, 0.18246800026723317, 0.22656799959284918], [0.06919878574886493, 0.08728989998676948, 0.061000963140811236, 0.027898835816553662, 0.05590583350775497, 0.0642103659255164, 0.043176187468426566, 0.04214726375149829, 0.05983515176922083, 0.03509224678522774, 0.0651487595002566, 0.013375669052558286, 0.06203057896345854, 0.07676517045391457, 0.06854908846850906, 0.07109368978334324, 0.08856531511992216, 0.03621805851746883, 0.03678902877228601, 0.036907127792281766, 0.06158637601350035, 0.06431277721588101, 0.0035098935020089683, 0.023364220213677202, 48.07449919836861, 107.39139911106655, 95.59039102281842, 91.08667291913713, 74.08752986363002, 47.46892895017351, 16.94108738218035, 40.91337306158883, 84.51660919189453, 69.36870942796979, 41.30980600629534, 42.3624198777335, 31.203300271715435, 11.139924338885717, 0.1996474348540817, 0.040977262426167727, 0.09600776540381567, 0.02428096343230988, 0.07316060244504895, 0.030561044213495085, 0.26140922574060305, 0.2252987998404673, 0.17865976318717003, 0.090499316342175, 7.084500968456268, 35.21505464826311, 74.75000585828508, 87.43660354614258, 77.95875344957624, 79.32952186039516, 74.85453455788749, 76.7293461390904, 75.76175389971051, 80.57474327087402, 77.31020859309605, 78.02820069449288, 79.45444352286202, 76.5331290108817, 68.7080191203526, 71.97984940665108, 65.78075000217983, 59.66353511810303, 55.487389836992534, 58.88760893685477, 56.855312960488455, 58.22614043099539, 58.390340260096956, 62.9586557660784, 63.54737663269043, 60.57517351422991, 57.60108395985195, 57.43156181062971, 54.745131152016775, 59.212305205208914, 59.111778667994905, 58.84225109645298, 58.34037576402937, 59.51089709145682, 55.55829272951399, 59.405916758946006, 63.65537248338972, 74.07935183388847, 73.89688519069126, 33.23554413659232, 69.8263942173549, 80.55418355124337, 73.70045961652482, 67.93806144169399, 65.97727285112653, 73.48164694649833, 73.38402475629533, 69.2923139844622, 58.354334694998606, 57.28364855902535, 63.506514276777, 65.5949204308646, 66.9730122429984, 66.0621589933123, 62.470336369105745, 62.651573181152344, 61.613283021109446, 62.330948557172505, 60.14398915427071, 57.472007274627686, 57.47838919503348, 58.2182160105024, 60.638916288103374, 65.33339023590088, 69.8082524708339, 74.8684309550694, 74.62644604274205, 73.73195580073765, 80.66225583212716, 79.00585392543248, 72.52894469669887, 81.63656003134591, 55.89771570478167, 4.719079256057739, 0.7376593574881554, 0.3031616024672985, 0.3507610240152904, 0.16237576412303106, 0.1775334629097155, 0.06706775831324713, 0.14717102928885392, 0.1187928356230259, 0.05463021820677178, 0.3011506146618298, 3.8435337117740085, 17.32994679042271, 32.141605854034424, 46.01726613725935, 47.374791281563894, 84.64350414276123, 35.71227468763079, 9.339453271457128, 17.35706213542393, 22.002306359154836, 48.1753523009164, 53.011913435799734, 67.7522040775844, 73.68857819693429, 51.023054122924805, 8.19658316884722, 0.06577849428036384, 0.05323044117540121, 0.05561741202005318, 0.04634069837629795, 0.04673472705430218, 0.022184234245547226, 0.07320888021162578, 0.015788225756425942, 0.030698861461132765, 0.02046347113459238, 0.06260549489940916, 0.05816961971244641, 0.13287432358733245, 0.09123164561710187, 0.05105985514819622, 0.05297167506068945, 0.007104731530749372, 0.05353123914184315, 0.0534120307170919, 0.0062865747853980535, 0.04813174244814685, 0.010907229052723517, 0.02530556827384446, 0.057654869476599355, 0.06519638587321554, 0.07538013798849923, 0.06248728731381042, 0.02747700416616031, 0.05683980642684868, 0.053094761313072274, 0.035581372146095545, 0.07332214127693858, 0.06646735660199608, 0.09608643475387778, 0.04124451022861259, 0.040274846367537975, 0.05927894304373434, 0.06521823470081602, 0.0061924619783115175, 0.023352269515661255, 0.03080146274130259, 0.050252948089369705, 0.010744340784315552, 0.0675568531400391, 0.07761610765010118, 0.013986673721644496, 0.021924871020019054, 0.05817546868430717, 0.0402686581281679, 0.04621569526248744, 0.059141858613916805, 0.09130879504872219, 61.34367901938302, 122.47923169817243, 105.63424832480294, 101.86400290897915, 86.91534273965019, 63.97134876251221, 36.405395712171284, 44.965336663382395, 52.98253297805786, 71.03297669546944, 41.88838945116316, 44.49706629344395, 41.358714376177105, 14.538103273936681, 0.03673080707501088, 0.09798030062977757, 0.10765611500080143, 0.021715924642714005, 0.21147416452211992, 0.12054566799529962, 0.42511866401348797, 0.32594444709164755, 0.03498389831344996, 0.8032050803303719, 9.456371477672032, 39.9611120223999, 77.86646052769252, 92.9596779687064, 80.72045394352504, 83.13921914781842, 78.05067811693463, 80.2245123726981, 80.73972824641636, 83.33333792005266, 78.76953874315534, 79.91764518192836, 83.2610697065081, 78.10920974186489, 71.28228500911167, 74.12894112723214, 70.6776180267334, 62.979000091552734, 58.104588644845144, 60.4678099496024, 59.10911055973598, 60.81622041974749, 60.63167626517159, 65.31721482958112, 66.49562236240932, 64.11883122580392, 60.38953154427664, 60.32440607888358, 59.779125349862234, 61.75724274771554, 62.160627365112305, 61.828621591840474, 61.22163391113281, 59.78372505732945, 61.02725805555071, 60.72890240805489, 67.03290571485246, 77.01302719116211, 77.92530482155937, 35.65130424499512, 71.97066388811383, 83.024566922869, 76.11058126177106, 72.00711413792202, 68.30692740849086, 76.16698673793248, 75.71989795139858, 70.94379656655448, 62.489117349897114, 59.31416579655239, 66.1421605518886, 69.55717931474958, 70.13686752319336, 68.7260844366891, 66.9320317677089, 66.72236292702812, 63.338763918195454, 63.867473193577354, 61.775884764535085, 60.75420079912458, 60.2737398147583, 59.605906758989605, 63.86902959006173, 69.15958254677909, 73.1298804964338, 81.76014763968331, 79.03825337546212, 72.87294306073869, 81.82375839778355, 80.00194767543248, 77.06638935634068, 83.04102720533098, 63.80567591530936, 6.811990882669177, 0.5901371591857502, 0.11566892825067043, 0.4289325193635055, 0.25858361593314577, 0.29194699281028336, 0.19949384166726045, 0.18203259791646684, 0.12018723865704876, 0.04528418881818652, 0.2307567862527711, 3.725149001393999, 19.059626136507305, 38.999415329524446, 45.803105286189485, 44.53900214603969, 64.8957440512521, 21.989895139421733, 13.671926941190447, 31.50436224256243, 37.12788329805647, 57.37289816992623, 64.09568677629743, 75.65281309400285, 87.15892573765346, 65.51718398502895, 13.06615172113691, 0.03609363555109926, 0.017864653175430636, 0.05268093298322388, 0.0545688107875841, 0.021786721290222237, 0.03900804523644703, 0.144017524218985, 0.10093973111361265, 0.05982342668409858, 0.02209645217018468, 0.05699822399765253, 0.06447831261903048, 0.11926493314760071, 0.06934059278241225, 0.0967677721221532, 0.07436969756547894, 0.04047458672097751, 0.02149482909590006, 0.03223569917359522, 0.0382939210560705, 0.08512664213776588, 0.012452927584360753, 0.027609240463269607, 0.09763631730207376, 0.042019027418323925, 0.04672657445605312, 0.0012315325771591493, 0.11756558290549687, 0.20345591620675155, 0.14518859423696995, 0.18154798820614815, 0.18479407259396144, 0.1918237768113613, 0.18562769357647213, 0.10485590275909219, 0.08400993634547506, 0.15199723174529417, 0.11371031656329121, 0.1771073429180043, 0.1486052894698722, 0.11487249098718166, 0.17025024443864822, 0.12279072324080126, 0.1810971423983574, 0.1427518664194005, 0.05790184943803719, 0.09757794293441943, 0.1242784248398883, 0.22565113593425068, 0.1721065669719662, 0.16833065530019148, 0.27251708826848436, 72.50208990914481, 135.00423513139998, 118.02386610848563, 117.87404905046735, 97.34073257446289, 70.61995492662702, 29.141500507082256, 58.54736260005406, 103.56687436785016, 86.58649144853864, 59.8942847933088, 63.51263563973563, 49.90273700441633, 19.266039746148245, 0.34136230977518217, 0.3049923985132149, 0.4005856333034379, 0.23839149943419866, 0.2976407972829682, 0.5083483393703188, 1.9163292390959603, 1.283432051539421, 0.5502411999872753, 1.6908717027732303, 10.056229438100543, 40.17520339148385, 82.13507243565151, 95.80128969464982, 86.4250431060791, 87.93221855163574, 80.48680686950684, 86.5710733958653, 83.44143104553223, 86.35137135641915, 80.58867440904889, 82.48011302947998, 85.75197110857282, 82.52863924843925, 75.56172221047538, 79.22209576198033, 72.9483310154506, 66.8094516481672, 61.68596117837088, 64.41258021763393, 61.9203656060355, 64.36373438153947, 64.08047716958183, 69.39051982334682, 71.63885266440255, 65.853942326137, 65.0244733265468, 63.59595148903983, 60.715485436575754, 65.01927607400077, 65.47145789010185, 66.30123261043003, 65.4981528690883, 62.975706645420615, 62.79341370718819, 63.68561799185616, 70.12875202723912, 81.49677617209298, 82.54291779654366, 40.79701852798462, 74.03186784471784, 87.89102268218994, 79.55576910291398, 75.72926412309918, 72.11967495509556, 78.61729676382882, 78.13039479936872, 75.72993115016392, 64.87578187670026, 63.15394183567592, 69.53484780447823, 73.81586224692208, 74.82519926343645, 71.6964532307216, 70.88987854548863, 71.54987403324672, 66.89797169821603, 67.0896863937378, 66.51215212685722, 64.38486385345459, 64.11324487413678, 63.75069481985909, 67.63389015197754, 73.31677314213344, 77.8798497063773, 84.18961306980678, 81.82780919756208, 75.13840321132115, 84.66634981972831, 84.97396046774728, 79.40510436466762, 87.16715935298375, 69.36256722041539, 7.90328928402492, 1.3565584761755807, 0.7992972071681703, 0.913123139313289, 0.319795942732266, 0.7579357208950179, 0.3579487183264324, 0.33138143963047434, 0.3822848381740706, 0.16429243556090764, 0.538142486342362, 7.707123398780823, 28.81847701753889, 51.76862015042986, 65.3405260358538, 56.023742130824495, 105.16721820831299, 49.9848438671657, 16.69025915009635, 29.14001532963344, 37.056542669023784, 71.19574519566127, 78.59535435267857, 90.73089041028703, 95.41276032584054, 75.50718579973493, 14.94868448802403, 0.19545503838786057, 0.09625226871243545, 0.15040755990360463, 0.1828637218901089, 0.12090705574623176, 0.10711359911199127, 0.14934240920203073, 0.14325186530394213, 0.18068337174398558, 0.07482650769608361, 0.14130623399146966, 0.17083102970251016, 0.19123752255524906, 0.18863600572305067, 0.28623421649847713, 0.15399215184152126, 0.11802429971950394, 0.17420934699475765, 0.11044389648096901, 0.1260393046374832, 0.11505979379372937, 0.1529022210410663, 0.09904692375234195, 0.16502226782696588, 0.21083848577524933, 0.10488370233880621, 0.1464479145194803, 0.1784515343606472], [0.028090498210596185, 0.050335322240633626, 0.06090236521725144, 0.04293890716508031, 0.04160625421042953, 0.04712189913594297, 0.06631935454372849, 0.038782931065985134, 0.03310700599104166, 0.009576600676934634, 0.06840111355164222, 0.06582724023610353, 0.01415840584585177, 0.05943723847823484, 0.02094177555825029, 0.04396419054163354, 0.013864357606507838, 0.09889736784888165, 0.0412372770453138, 0.07439962095980134, 0.04894811846315861, 0.2725407284285341, 0.3665867948106357, 25.66007259913853, 101.29069314684186, 98.22369575500488, 93.88196100507463, 78.24287918635777, 52.70540407725743, 23.600315604891094, 29.59782518659319, 63.52239785875593, 89.6792527607509, 46.97229603358677, 60.22368499210903, 30.874435084206716, 12.715289405414037, 0.1661214402743748, 0.2934544262077127, 0.039655133549656184, 0.09714085781680686, 0.05570007794137512, 0.20832135155797005, 0.18773090786167554, 0.19423492385872773, 0.07770764202411685, 0.31986952306968824, 2.2912119116101946, 33.075752939496724, 71.44662380218506, 85.5655300957816, 78.1719867161342, 78.73046902247837, 69.20489869798932, 68.70464924403599, 69.63003812517438, 79.5844373703003, 79.37493528638566, 79.44352095467704, 76.72921412331718, 76.89214243207658, 75.47980294908795, 77.90709359305245, 74.49506950378418, 73.79596955435616, 65.5863116128104, 56.55287177222115, 56.8389812197004, 59.332967621939524, 55.805940423692974, 57.74936894008091, 54.64355891091483, 57.44848414829799, 57.592360496520996, 58.09080341884068, 59.50147533416748, 57.961341108594624, 56.76653930119106, 60.453309059143066, 55.247166293007986, 56.1749974659511, 53.54383625302996, 57.34797845567976, 58.131721360342844, 64.02733039855957, 69.03869083949498, 78.10055228642055, 32.101184708731516, 66.69376414162772, 78.00914178575788, 73.78653390066964, 64.75065871647426, 64.89196423121861, 76.2114760535104, 74.70346682412284, 72.14566121782575, 61.520350864955354, 54.47112199238369, 57.93621294839041, 61.01122856140137, 63.40791933877127, 59.2101651600429, 59.01818643297468, 57.400642326899934, 58.9243996483939, 58.82527664729527, 56.96884652546474, 57.023994377681184, 57.746207509722026, 61.7072365624564, 71.77384921482631, 74.45030226026262, 71.91088158743722, 75.15952573503766, 71.2577439716884, 72.8569552557809, 76.66664559500558, 72.39298929486955, 72.21931212288993, 72.66151632581438, 77.73356928144182, 57.93103306634085, 0.5482325734836715, 0.52815928203719, 0.11071558190243584, 0.14140188028769834, 0.1302423541034971, 0.03913950461095997, 0.11592374529157366, 0.02438495910194303, 0.0997662115842104, 0.014151552642163421, 0.14081511034497193, 0.3074092859668391, 5.912295137132917, 18.794104201453074, 34.38148968560355, 45.577723094395225, 72.87930761064801, 66.87185341971261, 18.228251593453543, 18.318545171192714, 28.665364776338848, 37.69425875799996, 57.02927500861031, 70.52133219582694, 70.11453601292202, 50.712219510759624, 3.7459419199398587, 0.18154250564319746, 0.0501666995031493, 0.07786203588226012, 0.029918926169297526, 0.07921432224767548, 0.0050054196700719845, 0.036867613305470774, 0.05233583685808948, 0.09264816889273268, 0.015622485096433332, 0.03551238209807447, 0.02440508614693369, 0.03919204018477883, 0.023595027292945554, 0.046504303347319365, 0.021797796678064123, 0.15139975451997348, 0.06812800320663623, 0.08374019831951175, 0.06507715369973864, 0.07813811821064778, 0.046479367185384035, 0.0324528914477144, 0.009755345460559641, 0.04905111329363925, 0.04716639067711575, 0.04841147529493485, 0.06588923119540725, 0.0817698072642088, 0.05117988120764494, 0.05924887037170785, 0.06425869797489472, 0.021420587186834643, 0.04755709792620369, 0.04232864973268338, 0.005178961362357118, 0.030168725443737845, 0.05149454503719296, 0.03664926073646971, 0.06855969397085053, 0.08910347481391259, 0.02277226117439568, 0.041822995258761306, 0.046713414269366434, 0.14711965061724186, 0.014821503344657165, 0.06142170913517475, 0.09400865874652352, 0.2874578594097069, 0.4550789977822985, 31.698043278285436, 121.56345912388393, 108.35475294930595, 106.90839508601597, 86.99590015411377, 71.78447301047188, 42.6240508215768, 32.213415486471995, 50.62564843041556, 88.59968335287911, 46.30898972920009, 55.24586697987148, 40.71426548276629, 13.576678429331098, 0.08076197920101029, 0.11160647802587066, 0.08839268224047762, 0.03408530421022858, 0.05290113456015076, 0.13520639416362557, 0.05567134198333536, 0.694830769939082, 0.12475329078733921, 0.02207959396764636, 3.035059779882431, 34.802943093436106, 74.24327373504639, 90.73178672790527, 80.17520795549665, 82.2797964641026, 74.34612791878837, 70.34272875104631, 73.0659292766026, 82.58630234854562, 82.57481697627476, 79.6047261101859, 78.79476070404053, 78.0874410356794, 79.26621682303292, 81.55905287606376, 77.52965354919434, 78.4709746497018, 68.24097510746547, 59.475016593933105, 59.743154525756836, 63.86730643681118, 58.78784670148577, 60.50687272208077, 58.11305849892752, 59.72793102264404, 60.36649131774902, 61.11955792563302, 61.32518291473389, 60.17423466273716, 60.37393978663853, 63.53727395193917, 60.33090264456612, 58.4209748676845, 56.5949570110866, 60.46648979187012, 60.97682108197893, 68.49645342145647, 70.25853742871965, 82.60871723720005, 34.67331402642386, 67.76960931505475, 81.8305606842041, 75.36544254847935, 70.22966766357422, 67.5907974243164, 78.49638421194894, 77.17262036459786, 75.65919848850795, 63.301153319222585, 58.034856523786274, 59.69517026628767, 66.54030622754777, 64.48944813864571, 62.13207721710205, 61.33728667667934, 60.85639490400042, 61.09170259748186, 61.69018568311419, 58.88252285548619, 60.93451350075858, 57.36240986415318, 64.29550307137626, 74.73453222002301, 78.54780782972063, 75.77908270699638, 79.6564415522984, 71.4545864377703, 74.0548802784511, 80.38384846278599, 75.4077501296997, 74.87409373692104, 76.756242615836, 81.62262889317104, 67.22396727970668, 1.2693747601338794, 0.6390130679522241, 0.16431878986103193, 0.15478447718279703, 0.16040398207093987, 0.17541967704892159, 0.04941594121711595, 0.03439717247549977, 0.03676601964980364, 0.03429293931861009, 0.20500383100339345, 0.10765312944671937, 4.553274393081665, 22.966629471097672, 29.536173820495605, 43.67843300955636, 54.80207163946969, 35.64366122654506, 14.22865309034075, 27.733927488327026, 49.07247938428606, 45.492788314819336, 65.16222136361259, 79.49958596910749, 83.55202552250454, 66.35803413391113, 5.690866470336914, 0.14021044064845356, 0.03842837616269078, 0.03688417634527598, 0.06002726538905075, 0.036878446117043495, 0.01036522800235876, 0.028454226907342672, 0.05529336405119725, 0.04660105565562844, 0.026515531919098327, 0.005193789048852133, 0.07640598794179303, 0.08944930375686713, 0.012076813927186387, 0.07436592491077525, 0.01888293576692896, 0.12006981138672147, 0.022872402765122906, 0.03806011485201972, 0.08790932103459324, 0.04078837184767638, 0.026245726039633155, 0.06885451743645327, 0.03884019942155906, 0.059342311429125924, 0.04826917971617409, 0.05853950950716223, 0.26494105479546953, 0.14472477483962262, 0.11656411950077329, 0.0907016894114869, 0.162209224488054, 0.10394112898835114, 0.11805913570736136, 0.13756817100303514, 0.15401013301951544, 0.1675053938691105, 0.07272443334971156, 0.1510379867894309, 0.14353816636971065, 0.12674693523773126, 0.15654584552560533, 0.19579537798251423, 0.13077778608671256, 0.2269676567188331, 0.09857686861817326, 0.2695102281868458, 0.3270462793963296, 0.4557992219924927, 0.5421171816332, 40.23116070883614, 133.80118233816964, 121.80294963291713, 121.69828196934291, 102.24504211970738, 74.15124484470913, 37.73804630552019, 43.42846461704799, 84.90627806527274, 109.77281079973493, 64.40544441768101, 83.94084671565464, 49.81090266363961, 21.43813000406538, 0.3358379490673542, 0.47939134176288334, 0.27806975745729035, 0.20414487352328642, 0.18984059537095682, 0.8997087734086173, 2.038518739598138, 1.5084761700459888, 1.0387653516871589, 0.33096085648451534, 3.812709765774863, 37.73648990903582, 77.26396833147321, 95.92013168334961, 85.15944262913295, 87.87019198281425, 79.86352566310337, 77.4985603604998, 77.07714516775948, 87.24370765686035, 85.85427638462612, 81.2476554598127, 79.58058112008231, 80.27058587755475, 81.23373821803501, 84.09514536176408, 79.28861781529018, 84.4360100882394, 72.88625580923897, 63.01747226715088, 62.74599920000349, 66.22183554513114, 62.08312020983015, 64.30912848881313, 61.50155598776681, 63.48159108843122, 64.19761684962681, 63.62826756068638, 63.7463869367327, 64.3382066999163, 63.77273450578962, 67.20468602861676, 64.16856643131801, 61.7563533782959, 60.178883007594514, 64.13868222917829, 64.33002172197614, 71.86801815032959, 74.1501817703247, 85.65538419995988, 38.74111604690552, 71.53831917898995, 84.16982460021973, 80.33801814488002, 73.34907531738281, 72.21412181854248, 81.75019781930106, 80.93603570120675, 80.1339773450579, 68.34552465166364, 60.29113115583147, 64.57425785064697, 68.99242278507778, 71.71232986450195, 64.10461521148682, 65.22724955422538, 64.63039234706334, 64.94392980848039, 64.88109030042375, 61.35424722943987, 64.39340318952287, 63.34691415514265, 68.20712348393032, 78.37077467782157, 80.00794397081647, 79.11653872898647, 84.34875461033413, 74.32160772596086, 74.32103102547782, 83.79551124572754, 79.1856107711792, 81.27870695931571, 80.48705005645752, 85.6542238507952, 71.0445454461234, 2.0019757747650146, 0.8027460649609566, 0.4637820507798876, 0.406854048371315, 0.4104984328150749, 0.28795139864087105, 0.32883522340229576, 0.26452817980732235, 0.2568146751395294, 0.17314112931489944, 0.2279155972812857, 0.8002642009939466, 10.748661722455706, 33.024412700108115, 53.47311748777117, 55.20770399911063, 92.07583931514195, 92.779066494533, 28.17319781439645, 28.014094488961355, 46.585677419389995, 55.85943807874407, 78.0042085647583, 90.55424635750907, 93.1251562663487, 76.10383456093925, 6.33307717527662, 0.27222588817988125, 0.13182338140904903, 0.17993810959160328, 0.10171242643679891, 0.13146981038153172, 0.050122747397316356, 0.2086352418575968, 0.11441149429551192, 0.14687141536601953, 0.10980166308581829, 0.10221199105892863, 0.1879117510148457, 0.20923882589808532, 0.12799577893955366, 0.1127450122897114, 0.05542426024164472, 0.29605432812656673, 0.1375929918140173, 0.11751382425427437, 0.1575103152011122, 0.1391428607915129, 0.1576695537992886, 0.21810598937528475, 0.11053063361240284, 0.08000728541186877, 0.12227825288261686, 0.11290457658469677], [0.08709597467843976, 0.056298827419855764, 0.05362690579412239, 0.045729602953152995, 0.05305788632748382, 0.0041207346865641216, 0.053367050630705695, 0.027496903901919723, 0.06994703345532928, 0.030793798688266958, 0.014509764001039522, 0.028712375555187464, 0.046184479258954525, 0.04643526580184698, 0.04791106928938201, 0.055610202585480044, 0.08010420056858233, 0.04854151653125882, 0.04967516873564039, 0.01906460503648434, 0.0429803792254201, 0.19745123412992271, 2.8721881423677718, 81.11543818882534, 103.21100848061698, 93.37322780064174, 84.09391553061349, 65.3009282520839, 33.84604760578701, 26.158454724720546, 54.643617970602854, 74.13671616145542, 49.79781225749424, 52.024567467825754, 25.88709282875061, 9.700117758342198, 0.13861776968198164, 0.04731175662683589, 0.10224427575511591, 0.07283147903425352, 0.12366056442260742, 0.08795127485479627, 0.26315588344420704, 0.03975772125912564, 0.3370420773114477, 0.17194602558655397, 0.3469182630734784, 15.66449659211295, 65.13191332135881, 83.82019124712262, 78.84923458099365, 75.87166745322091, 73.18104008265904, 69.39980956486293, 59.50301088605608, 67.43795095171247, 74.16109044211251, 82.53171035221645, 72.35520499093192, 77.49004881722587, 77.4156197139195, 72.20390796661377, 74.95341437203544, 75.20363289969308, 76.81070259639195, 69.46337863377163, 58.33601924351284, 52.78873382295881, 56.650827475956504, 56.52270269393921, 58.31056104387556, 54.99980347497122, 58.44584941864014, 57.62368297576904, 60.150944301060264, 64.7596983228411, 59.37074497767857, 55.18779741014753, 60.71380397251674, 56.66607182366507, 58.05372783115932, 54.543296405247276, 68.03660079411098, 64.49225521087646, 66.94740813119071, 63.6240291595459, 83.78763198852539, 32.721832547869, 58.31027616773333, 81.61287362234933, 64.83521829332624, 63.07596220288958, 64.3283611025129, 76.28984478541783, 69.61981037684849, 75.00068296704973, 62.36074938092913, 58.274267128535676, 53.21804911749703, 57.897782461983816, 57.85269560132708, 56.617333684648784, 55.92946202414376, 58.3561829158238, 59.36582565307617, 58.112332412174766, 54.735424518585205, 56.880086762564524, 54.24634429386684, 68.63713359832764, 71.90399592263358, 76.83081068311418, 74.1292051587786, 73.55016313280377, 63.6660657610212, 71.81031336103166, 74.91588020324707, 71.55870519365583, 58.565275056021555, 68.45667498452323, 70.29791287013462, 80.77127306801933, 50.77763680049351, 1.3666587684835707, 0.5124114070619855, 0.13063342097614491, 0.016932965223012224, 0.1377448479511908, 0.08653275668621063, 0.11668282241693564, 0.0891780254564115, 0.01983753445425204, 0.08765238696443182, 0.02693069357025836, 0.039932793471962214, 1.8824365777628762, 18.964430604662212, 39.58010407856533, 41.22565637316023, 82.90242453983852, 90.65420314243862, 38.773612771715435, 10.267644882202148, 29.727638380868093, 48.01776715687343, 61.458372933524, 71.58922863006592, 69.52014541625977, 33.24690096718924, 0.9865983852318355, 0.028625668957829475, 0.01764705208396273, 0.04421671413417373, 0.07118896288531167, 0.07957655138203076, 0.04354958528918879, 0.01685416864763413, 0.08265823352017573, 0.010595711929324483, 0.02007991903727608, 0.039038497888083966, 0.058225130662322044, 0.04279053530522755, 0.0856699790539486, 0.08853339683264494, 0.05180364827226315, 0.021522657513352375, 0.011883818211832216, 0.04881268287343638, 0.014827744170491184, 0.06952056062540837, 0.11874330256666456, 0.04549483322937574, 0.02801057187441204, 0.014327579044869967, 0.03577443910762668, 0.054216600222779174, 0.03983790374227932, 0.036499596267406426, 0.03753366667245116, 0.023975417417074953, 0.07552232500165701, 0.0380076607024031, 0.01828961626493505, 0.00966829281034214, 0.04907177807763219, 0.06395238691142627, 0.029653971815215688, 0.0493926708586514, 0.024134695031014935, 0.07053111639938184, 0.03566681666831885, 0.05194952990859747, 0.029006109972085272, 0.06657556936677013, 0.07523502648941108, 0.21592285723558494, 0.15721560030111245, 4.673079141548701, 99.62821156638009, 116.29634244101388, 107.51828016553605, 94.24672058650425, 82.05154119219098, 47.03073385783604, 34.84965235846383, 38.64267744336809, 62.3873679297311, 49.93040473120553, 46.75624527250017, 35.74396889550345, 11.289308871541705, 0.10691701394638845, 0.027528537204489112, 0.07299295679799148, 0.052642639859446456, 0.1003281878573554, 0.08254454497780118, 0.054405487408595424, 0.13643873589379446, 0.8390023623194013, 0.18663957927908215, 0.30697304223264965, 17.520683526992798, 68.51609597887311, 85.88921192714146, 82.9507145200457, 79.75045067923409, 74.85223470415387, 71.1534445626395, 64.3684035709926, 69.33964511326381, 78.91139316558838, 84.67021301814488, 74.22434684208461, 78.78142016274589, 77.30504608154297, 74.15677561078752, 77.86796133858817, 78.28076771327427, 80.92855249132428, 72.38087163652692, 61.03417151314871, 53.73852825164795, 58.56649793897356, 59.68567207881382, 61.13423946925572, 57.07346207754952, 60.29675224849156, 58.04212086541312, 63.48967184339251, 65.5756252833775, 61.10090896061489, 58.389103480747764, 62.283631324768066, 59.45635373251778, 62.620403562273296, 58.43100111825125, 71.39526966639927, 68.66946356637138, 72.154999596732, 68.03499576023647, 86.33425099509103, 36.06257854189192, 59.96738679068429, 83.79175227028983, 69.52317483084542, 63.94862815311977, 68.20755427224296, 77.7223687853132, 69.85098389216832, 77.90662111554826, 66.34538841247559, 61.265317235674175, 55.692674364362446, 60.909499985831125, 59.64400373186384, 59.91856179918562, 59.547354289463584, 62.09951795850481, 62.51675033569336, 61.2420129776001, 57.31677062170846, 59.32572759900774, 57.97080455507551, 70.5872358594622, 75.18943772997174, 80.59471934182304, 76.04751941135952, 74.2918346949986, 65.5580324445452, 73.6196312223162, 78.17877510615757, 76.74017143249512, 62.41498701913016, 72.23249285561698, 74.51776926858085, 84.78184277670724, 60.33208383832659, 2.6201741567679813, 0.5143213474324771, 0.4035410061478615, 0.24167935443775995, 0.3962843455374241, 0.1584430837205478, 0.06381372828036547, 0.0795990719592997, 0.045337229900594266, 0.06778233032673597, 0.015722674184611866, 0.033555884047278335, 1.3519894927740097, 22.042129959378922, 34.84738029752459, 42.162468092782156, 81.11353438241142, 63.671137945992605, 29.689402444022043, 18.164434126445226, 45.00524016789028, 57.74729837690081, 71.36186272757394, 80.12745993477958, 82.38898740495954, 43.53748880113874, 1.194445169397763, 0.050563048770917315, 0.058330303590212546, 0.043749407066830566, 0.05491898235465799, 0.03259578752996666, 0.029076616545873027, 0.04721337244180696, 0.05106003835265126, 0.05001349986663886, 0.01712812716141343, 0.028941879847220013, 0.033209953324071, 0.05491857862632189, 0.010888864502443798, 0.02460318953464074, 0.024199883586594036, 0.008001412165218165, 0.06713847523289067, 0.07789157929697207, 0.045935762247868946, 0.006484418633460466, 0.05383437805409942, 0.039768788165279796, 0.014538479603028722, 0.02245151767108057, 0.010841516328842511, 0.17127579583653382, 0.14348571561276913, 0.09619191980787686, 0.10793348654572453, 0.19109831431082316, 0.11809911499066011, 0.15372486332697527, 0.10414920853716986, 0.17993109353951045, 0.16428769938647747, 0.1517066423382078, 0.06530588785452501, 0.19460274412163667, 0.09480442426034383, 0.209992434031197, 0.15144768623369081, 0.22843345520751818, 0.12302739625530583, 0.155392335993903, 0.1539703437260219, 0.371820009712662, 0.26940763369202614, 6.933286453996386, 113.87982150486538, 127.8613063267299, 120.17483384268624, 107.83486093793596, 86.81175899505615, 51.17538642883301, 39.42495427812849, 81.43996770041329, 99.13655008588518, 65.4661147253854, 76.70515251159668, 43.81531252179827, 15.814815657479421, 0.332257374056748, 0.23593300421323093, 0.3075724872095244, 0.26485637362514225, 0.3079037480056286, 0.36127885963235584, 0.848459891974926, 0.6341957407338279, 1.2037540184600013, 0.3771427098129477, 0.5266550513250488, 19.797130516597203, 72.0576970236642, 91.85503251211983, 88.83435181209019, 84.27015658787319, 79.00923769814628, 77.16310133252824, 66.5472057887486, 73.42258725847516, 81.9322406223842, 90.15248761858258, 78.06881291525704, 80.87194551740373, 79.42774159567696, 76.02555615561349, 78.91635417938232, 80.36664472307477, 84.96186365400041, 78.60119778769356, 65.43125561305455, 57.23422602244786, 60.49049581800188, 63.39063916887556, 64.8168055670602, 59.856903484889436, 62.9199195589338, 62.10737637111119, 65.89012854439872, 67.93560872759137, 64.24657385689872, 61.19949695042202, 66.26583153860909, 61.648850849696565, 65.14202989850725, 60.17800753457205, 74.91663060869489, 71.2102530343192, 73.72065802982875, 71.12010015760148, 90.55194650377545, 39.46663652147566, 64.12763459341866, 88.6122943333217, 73.03853252955845, 68.86486775534493, 71.16796629769462, 81.95333535330636, 73.4802781513759, 80.92634296417236, 68.94061006818498, 64.83291843959263, 58.409489495413645, 64.37467084612165, 63.63469464438302, 63.00201947348458, 62.353731700352256, 66.51017883845738, 65.8782262802124, 64.38045174734933, 58.85614054543631, 61.410367829459055, 60.964689527239116, 74.64571339743478, 78.59315177372524, 83.1156369618007, 78.31864929199219, 76.6651725769043, 64.34077753339494, 76.27189064025879, 82.25623512268066, 79.7721915926252, 64.83962345123291, 77.89792197091239, 78.50866862705776, 89.1752095903669, 61.37894112723214, 2.9642215924603597, 1.3558647419725145, 1.0327486459697997, 0.5564890418733869, 0.4033045774059636, 0.37992353630917414, 0.28473674399512156, 0.19639569148421288, 0.15094046773655073, 0.406733757683209, 0.15019494774086134, 0.16685002403599875, 3.8032567415918623, 31.987512179783412, 58.09016418457031, 48.67451088769095, 96.66157395499093, 119.54766164507184, 54.94534349441528, 19.811403853552683, 46.31987060819353, 66.9587128502982, 82.8590121950422, 91.55177838461739, 95.19209943498883, 49.41666187558855, 1.1558766961097717, 0.17971575366599218, 0.13134692768965447, 0.10152845523719277, 0.2004893882466214, 0.11760940269700118, 0.12599061296454497, 0.13256925424294813, 0.23028156746711048, 0.11904959327408246, 0.09383711152310882, 0.05863432799066816, 0.11985088884830475, 0.15554419213107654, 0.15295004418918065, 0.19877819078309195, 0.1260949173676116, 0.1447825724525111, 0.1271479765751532, 0.15151878313294478, 0.09369168789791209, 0.16071249837321894, 0.17148348183504172, 0.14287850819528103, 0.09215775092265435, 0.12614766667996133, 0.1036834078175681], [0.057017161910023005, 0.005825680722149887, 0.03423865312444312, 0.05336575462882008, 0.05199130730969565, 0.03533209195094449, 0.052913036064377854, 0.05549435969442129, 0.09229937475174665, 0.06340439524501562, 0.10771664710981504, 0.028789494452731948, 0.1132386125890272, 0.033817079317356856, 0.0635995419163789, 0.02324759870368455, 0.09123857345964227, 0.049508988724223206, 0.014807954696672303, 0.05664350963862879, 0.14986758173576423, 0.1653291420744998, 36.88195180892944, 109.95819568634033, 93.60256699153355, 94.01715905325753, 72.62665721348354, 40.062652996608186, 25.010334389550344, 50.171270983559744, 57.5850579398019, 41.95310149874006, 51.97131994792393, 34.298309326171875, 9.102396368980408, 0.031810166114675145, 0.06106420260454927, 0.016058625354032432, 0.10759554217968668, 0.054025596007704735, 0.055864402159516297, 0.08682572775121246, 0.12280808016657829, 0.22777204641274043, 0.6981482090694564, 0.14265232533216476, 1.633621911917414, 32.38236093521118, 77.68752356937954, 79.77933434077671, 75.87166745322091, 70.84682750701904, 71.38775866372245, 63.87395586286272, 58.30384908403669, 68.13194397517613, 74.25439780099052, 77.35315540858677, 76.32243878500802, 80.5915926524571, 74.83610098702567, 76.69227749960763, 71.76821422576904, 67.14231899806431, 74.89381272452218, 74.06569862365723, 63.33292743137905, 52.08560044424874, 53.338148730141775, 54.454963956560405, 55.58465766906738, 54.97624908174787, 55.530652795519146, 53.98637744358608, 58.806683267865864, 62.97615827832903, 57.10777923039028, 54.92753873552595, 59.269509724208284, 56.53422975540161, 57.20796183177403, 61.44389288766043, 77.34651293073381, 69.92579514639718, 71.4937812260219, 63.01362296513149, 77.69120611463273, 50.30234180177961, 55.680136340005056, 74.9682696206229, 60.19428021567208, 60.360703468322754, 63.884093284606934, 75.07416016714913, 68.28331742967877, 76.95095198495048, 68.4632271357945, 61.99763652256557, 53.08277811322893, 54.255599294389995, 55.68158851351057, 60.38493878500802, 56.25918184007917, 57.58469663347517, 55.83475112915039, 55.30223076684134, 53.6546357018607, 54.27167395183018, 57.27576582772391, 65.8865293775286, 71.65690408434186, 71.69962855747768, 70.4545669555664, 75.73215457371303, 70.18467112949916, 66.83712632315499, 71.63995742797852, 72.51682703835624, 64.96396841321672, 58.22669281278338, 68.90986428941999, 69.75983047485352, 77.657806124006, 61.924854142325266, 16.594780479158672, 0.21394806248801096, 0.24282377160021237, 0.08239975917552199, 0.112965312254216, 0.04384765215218067, 0.054212712217122316, 0.047708865853824785, 0.0470595315897039, 0.04859824884416802, 0.0636389037328107, 0.06105666408049209, 0.19317065525267804, 18.64821113858904, 31.64759588241577, 38.9939158303397, 115.6304965700422, 102.0463514328003, 43.240230969020296, 10.737208485603333, 31.470461981637136, 50.23776524407523, 66.29447896139962, 67.26375266483852, 67.41462584904262, 15.70912139756339, 0.19927747042051383, 0.011835464958234556, 0.040243267347770076, 0.05608757571982486, 0.043248678757143874, 0.035168704111129045, 0.021992062950240712, 0.07238663147602763, 0.12291649649185793, 0.05843776996646609, 0.11850171695862498, 0.07702758030167647, 0.0592237917174186, 0.03218007965811661, 0.03639449458569288, 0.07514168042689562, 0.014515000595045941, 0.06067514419555664, 0.060152461885341575, 0.03193324218903269, 0.011454615974798799, 0.04718155932745763, 0.04237433549548898, 0.08516126099441733, 0.05640743034226554, 0.00691402841558946, 0.03285112025748406, 0.019012227222057324, 0.01206582335622183, 0.007572314252943865, 0.024989328546715633, 0.04613918026110955, 0.02044600903588746, 0.05692842988563435, 0.03498912981844374, 0.07120093902839081, 0.07367884713624205, 0.03626310985003199, 0.09964923893234559, 0.03672669515279787, 0.08517046871462039, 0.016698923228042464, 0.07206508051604033, 0.03112093059878264, 0.07348338155341999, 0.043911115532474856, 0.14975305859531673, 0.17642974427768163, 47.709260191236226, 129.36258969988143, 100.94622925349644, 102.78408336639404, 86.29024110521588, 63.073710986546104, 38.449653012411936, 46.5660765511649, 55.37801129477364, 46.867878505161826, 45.05538879122053, 43.130348682403564, 10.904812063489642, 0.050705632727060995, 0.04853621038741299, 0.04303386814094015, 0.14676537391330513, 0.0815291308930942, 0.14787351659366063, 0.15475608727761678, 0.023814511319090213, 0.46601003408432007, 1.0319993261780058, 0.12175400315650872, 2.158159554004669, 35.11965588160923, 80.12343692779541, 85.23520578656877, 80.01765060424805, 76.99546214512416, 74.05138533455985, 68.15802751268659, 61.16554110390799, 70.8272613797869, 76.58628273010254, 79.90372794015067, 80.48431941441127, 82.38439464569092, 76.33343083517892, 78.66175828661237, 73.95713996887207, 69.10260037013462, 78.18639033181327, 76.9693716594151, 67.42196314675468, 56.767202854156494, 55.339681557246614, 57.17637879507882, 58.966748918805806, 57.22640929903303, 59.572430338178364, 56.80419506345476, 59.787470136369976, 65.119476045881, 59.896633284432546, 57.44765383856637, 62.977679933820454, 60.351504053388325, 59.57451479775565, 63.93903963906424, 80.06467601231166, 74.16930321284703, 75.22326156071254, 66.32557215009416, 80.41291972569057, 53.54970748083932, 60.22943115234375, 77.96666049957275, 64.51379462650844, 63.80813557761056, 65.0254738671439, 79.05078792572021, 71.58248192923409, 78.5359194619315, 74.06238433292934, 64.25172247205461, 56.20959602083479, 58.04508774621146, 56.93787840434483, 62.26345375605992, 58.752779143197195, 60.41748414720808, 59.783989088875906, 58.93255683353969, 55.940443652016775, 56.31521211351667, 61.32333469390869, 68.80534253801618, 73.61537197657994, 73.83640112195695, 73.19932079315186, 77.38202517373222, 71.46436255318778, 68.03894928523472, 75.95494161333356, 74.6202621459961, 68.85788481576103, 62.31497464861189, 72.14205510275704, 74.57791982378278, 81.17622797829765, 74.31878675733293, 20.940394060952322, 0.5764097443648747, 0.3732516643192087, 0.2251798662223986, 0.2840816320053169, 0.15453242856476987, 0.20167556245412144, 0.20381468481251172, 0.05421131104230881, 0.04409198243437069, 0.05641594595674958, 0.08075969932334763, 0.13163192596818718, 22.286432095936366, 30.903961454119, 40.45990235464913, 111.39875180380685, 77.2694365637643, 30.88775130680629, 23.29047805922372, 43.12453304018293, 55.97619908196585, 72.69738292694092, 76.55735737936837, 82.91974639892578, 20.499906063079834, 0.14021833879607065, 0.028824479718293463, 0.01929215684400073, 0.03975970597405519, 0.004876395812191601, 0.013658291610356952, 0.03287762383531247, 0.04869830222534282, 0.07695233076810837, 0.03902297639953239, 0.07916219718754292, 0.03565739860226001, 0.06023229153028556, 0.06830062930073057, 0.0824383542473827, 0.02074008441663214, 0.04727207589894533, 0.07717071047851018, 0.014877930316807968, 0.038612991970564635, 0.023386708560532758, 0.016493686740951877, 0.04940782254561782, 0.02730054095653551, 0.008204287350443857, 0.022887829258771877, 0.12382193362074238, 0.1443834581545421, 0.11472210048564843, 0.21499093009957246, 0.10272817300366503, 0.15174312038081034, 0.11772830917366914, 0.15617418475449085, 0.11828203446098737, 0.13841266211654457, 0.2403365879186562, 0.095161482957857, 0.12099312112799712, 0.1405414707426514, 0.14494941064289638, 0.15332878886588983, 0.22346940157668932, 0.11980444991162845, 0.22763629869690963, 0.2502879282193524, 0.2543816114110606, 0.2402711771428585, 55.583896841321675, 142.676297051566, 114.14579159872872, 117.92686925615583, 94.51893016270229, 59.52051339830671, 36.49332863943917, 69.04479830605644, 76.51662009102958, 56.74966907501221, 76.44257313864571, 56.01383747373308, 15.269798960004534, 0.2242198884487152, 0.1925623757498605, 0.12391885556280613, 0.28112940756337984, 0.26856668453131405, 0.19235384836792946, 0.43530162902815, 0.23554800344364984, 1.1189076112849372, 1.9606869731630598, 0.3855799399316311, 2.435011395386287, 41.36087874003819, 88.12011868613106, 89.48284803118024, 85.41200269971574, 81.53931304386684, 79.40899535587856, 73.12429414476667, 63.93732343401228, 74.5738273348127, 81.63324574061802, 83.79049464634487, 83.82903630392892, 84.26493849073137, 80.18813160487584, 82.39622742789132, 76.26462282453264, 69.2939259665353, 80.69785840170724, 80.23130771092006, 69.9396915435791, 59.7145140511649, 59.20500264848982, 61.68655872344971, 62.473379680088584, 60.697357586451936, 61.486214365277974, 61.63136918204171, 63.80921949659075, 68.20662321363176, 62.016855239868164, 62.275508880615234, 66.61366530827114, 61.05804552350725, 61.83904388972691, 67.52091244288853, 83.23399952479771, 76.816817011152, 79.18531199863979, 70.73431532723563, 84.07721900939941, 58.29414939880371, 63.993006297520225, 81.95093822479248, 68.49373667580741, 67.62159184047154, 68.41033049992153, 84.70219557625907, 75.02420956747872, 82.82616806030273, 76.72218949454171, 68.31735665457589, 59.862691334315706, 59.92269597734724, 60.58838203975132, 64.20270987919399, 61.98849269321987, 63.68153245108468, 62.81158324650356, 62.37447902134487, 59.17134557451521, 59.3059321812221, 64.52252156393868, 72.67635767800468, 78.35163933890206, 77.09021472930908, 76.81655297960553, 81.85046032496861, 72.25972284589494, 68.73431805201939, 80.55789388929094, 78.3410085950579, 71.70554842267717, 64.86212171827043, 75.39903708866665, 76.89645726340157, 83.88349628448486, 74.1993055343628, 19.981044122150966, 0.4417153591556208, 1.0406321372304643, 0.840861765401704, 0.24639191584927694, 0.2969716531889779, 0.2497307966862406, 0.3760142246527331, 0.21747705526649952, 0.4034651459327766, 0.17497393382447107, 0.12120106496981212, 0.4059528724423477, 33.70944949558803, 45.63325309753418, 42.430612972804475, 117.37187494550432, 120.29299490792411, 63.27399975912911, 18.44267300197056, 47.67581156321934, 68.98106248038155, 85.65623882838658, 86.47224221910749, 95.37448269980294, 22.146306037902832, 0.27256279438734055, 0.1175927785890443, 0.15749251044222287, 0.13787514024547168, 0.11458684131503105, 0.19708166324666568, 0.10938832669385842, 0.09561850343431745, 0.16991005412169866, 0.11648927708821637, 0.2655462266079017, 0.13173768243619374, 0.20060148223170213, 0.12753782208476747, 0.21369414111333235, 0.11877055253301348, 0.12326480208763055, 0.12678097055426665, 0.15117731717016014, 0.14126678396548542, 0.09495050606450864, 0.08466569972889763, 0.12440159251647336, 0.12357858382165432, 0.08788140610392604, 0.16254701279103756], [0.011819335332672511, 0.15846578750227178, 0.03372751269489527, 0.021128523662420254, 0.040246093446122747, 0.05184311865429793, 0.0720336643446769, 0.04791089626295226, 0.0632921044847795, 0.02191330030161355, 0.05111604802576559, 0.06480842669095312, 0.04821388929017952, 0.007364249122994286, 0.023357436559828262, 0.05213546207440751, 0.03758676882301058, 0.10825295440320458, 0.017372613506657735, 0.12067472535584654, 0.1609063015452453, 1.1375133671930857, 91.64702429090227, 90.97865622384208, 84.24584484100342, 81.28948361533028, 50.79145329339163, 23.79278244291033, 32.00756120681763, 62.468210220336914, 37.48479836327689, 44.47676018306187, 47.899960449763704, 9.427376644951956, 0.0927888834849, 0.015575359143050653, 0.09073605042483125, 0.06550003029406071, 0.031620264519006014, 0.0645464782470039, 0.16024069940405233, 0.03273231216839381, 0.07331889109419924, 0.13738605220402988, 0.5475619637540409, 1.0162579651389803, 9.351960028920855, 45.88252667018345, 80.00472695486886, 78.97269017355782, 79.44348621368408, 72.96499974387032, 69.83148724692208, 60.23297473362514, 57.38615533283779, 61.566452162606375, 71.6651724406651, 72.97337927137102, 79.87314891815186, 72.82887063707624, 74.82663754054478, 72.90684332166398, 75.55423205239433, 65.72545623779297, 71.99114022936139, 68.41193553379604, 62.44548961094448, 53.01858370644705, 55.41659811564854, 56.16647202627999, 59.40924494607108, 58.77597223009382, 62.19012246813093, 54.63730900628226, 56.07588488715035, 56.63555186135428, 57.251144886016846, 53.99354798453194, 55.946360043116975, 56.94298880440848, 60.30036531175886, 65.58782632010323, 71.69373648507255, 71.81544807979039, 73.94473048618862, 68.75244590214321, 78.11168330056327, 53.74458360671997, 52.627608571733745, 77.0240261895316, 61.13925606863839, 60.38145773751395, 60.73630223955427, 72.67255006517682, 66.89121804918561, 70.5123690196446, 68.7456088747297, 64.52290371486119, 55.13336869648525, 56.148913928440635, 52.020047664642334, 57.39142901556832, 58.6045949118478, 57.054316316332134, 57.70909718104771, 52.953663212912424, 52.11163534436907, 53.710276876177105, 56.52582590920584, 60.84356852940151, 62.3145021711077, 64.09937626974923, 67.92362308502197, 68.91571467263358, 71.67216232844761, 71.45063291277204, 73.22643961225236, 72.99477972303117, 65.27084950038365, 60.29832948957171, 57.33347061702183, 71.55806595938546, 70.54433768136161, 76.34048325674874, 84.8489693232945, 45.45175225394112, 1.2918974544320787, 0.7396639127816472, 0.19662857827331337, 0.12154057675174304, 0.14578647858330182, 0.05468373087101749, 0.045906893975500546, 0.08896153207336154, 0.032220927466239245, 0.10891098409358944, 0.05058303841256669, 0.6485252061060497, 24.269081456320627, 61.36109815325056, 93.1313818522862, 87.02502700260708, 70.80772999354771, 35.77334587914603, 23.4124311038426, 42.757935660226, 56.80414642606463, 67.55239473070417, 75.65998363494873, 60.18692207336426, 2.042839216334479, 0.08858935561563287, 0.010951197273763163, 0.01386709719164563, 0.05025303969159722, 0.03526560908981732, 0.046311484051070044, 0.03973581475604858, 0.05270870542153716, 0.040719188417174985, 0.09048208155270134, 0.019638389515291368, 0.03844375176621335, 0.016303067594500523, 0.032149895027812035, 0.08353336727512733, 0.041727152187377214, 0.09445012041500636, 0.08006128322865282, 0.048282838626099486, 0.0452104015275836, 0.04218868152903659, 0.13676179998687335, 0.017981759837961624, 0.027685640113694326, 0.03622701857239008, 0.03926512519163745, 0.07816344792289392, 0.06447917435850416, 0.06080280377396515, 0.042036784679761956, 0.08496270129191023, 0.04527344760884132, 0.04863011624131884, 0.06981854606419802, 0.02632355739894722, 0.02303539026927735, 0.04616081535017916, 0.01268051755947194, 0.028736548365226815, 0.028494175656565597, 0.02927063006375517, 0.04835434943171484, 0.04269907557006393, 0.04538951441645622, 0.05952183822435992, 0.10711701214313507, 2.638207337685994, 109.75370325360979, 99.68023272923061, 97.60953753335136, 92.85873453957694, 72.92745167868478, 35.34809875488281, 38.65616042273385, 45.658141544886995, 31.85436385018485, 45.301879610334126, 45.911247049059185, 12.882832186562673, 0.1940213753176587, 0.006620372454303184, 0.16850734581904753, 0.11962584592401981, 0.02823305841801422, 0.25085941755345886, 0.14383275913340704, 0.13498542244945252, 0.12731501832604408, 0.281552433435406, 0.8564394637942314, 1.0161115101405551, 9.277838383402143, 50.94447694505964, 83.80147974831718, 82.17856815883091, 82.00466169629777, 78.35974788665771, 75.03149127960205, 64.33526066371373, 60.13799285888672, 63.900317328316824, 75.61702292306083, 76.03519330705915, 81.07024710518974, 74.06883226122174, 77.5561192376273, 76.01474475860596, 79.11337729862758, 67.56756264822823, 74.61878912789481, 72.05493858882359, 65.5229023524693, 55.15909787586757, 58.01537377493722, 58.476477078029085, 61.01067965371268, 62.67865725925991, 65.80802862984794, 58.43086910247803, 58.83211367470877, 60.333925110953196, 60.0357084274292, 56.70293549128941, 58.407689911978586, 61.64547402518136, 62.358498164585654, 68.30470398494175, 74.89685603550502, 75.01471832820347, 74.53743961879185, 70.66225555964878, 81.98948683057512, 56.40512180328369, 55.95908914293562, 80.66857174464634, 63.31565420968192, 62.38528347015381, 61.1331763948713, 73.03498894827706, 69.4008309500558, 71.04993724822998, 72.65975148337228, 67.86206204550606, 57.31248705727713, 57.9140898840768, 55.32412454060146, 60.30935628073556, 62.247194971357075, 59.93586976187569, 59.51216861179897, 55.05059480667114, 53.7046731540135, 56.66990375518799, 59.39428547450474, 64.01619243621826, 64.00368567875454, 66.8327420098441, 70.77455929347447, 72.99837888990129, 75.21320751735142, 72.08613600049699, 74.15006365094865, 75.50406605856759, 69.51112665448869, 64.00756972176688, 60.56650216238839, 76.09808145250592, 73.10334532601493, 81.59403010777065, 91.27503858293805, 54.933305740356445, 2.1020799917834143, 0.17916414540793213, 0.38533773007137434, 0.404384045196431, 0.4990909504038947, 0.2126028939549412, 0.26728031784296036, 0.1827517364706312, 0.06781248442296471, 0.09023465375815119, 0.027581133846459643, 0.4278575027627604, 23.377339226858957, 49.08825526918684, 96.87415409088135, 88.31817013876778, 61.45499610900879, 35.8234041758946, 32.267635754176546, 51.173590319497244, 63.509502002171104, 72.53336375100272, 86.16155351911272, 74.21232645852226, 3.0626228494303565, 0.08701583969273738, 0.009263875761202403, 0.03046490258670279, 0.030847749007599692, 0.04315743615318622, 0.055638639988111596, 0.0348698196134397, 0.026939679070242813, 0.040270992288632054, 0.03837043605744839, 0.09659448784909078, 0.03693471024078982, 0.06497892218508891, 0.07718652712979487, 0.018821932076077377, 0.0051552240869828635, 0.10348144865461759, 0.045370135456323624, 0.07294784100460154, 0.03365195103521858, 0.04873693461662956, 0.060888604527073245, 0.07300260556595665, 0.07060028625918285, 0.06397201692951576, 0.1336643419095448, 0.27483170692409786, 0.17722044113491262, 0.15157039250646318, 0.08974443934857845, 0.21444405801594257, 0.15515623294881412, 0.1966114520494427, 0.17800953664949962, 0.14707482659390994, 0.14734269864857197, 0.14950299129954406, 0.17534020702753747, 0.13670240103134088, 0.12583936750888824, 0.3782641382089683, 0.1426021001700844, 0.18786689985011304, 0.10196566927645888, 0.21851199758904322, 0.421100596764258, 4.176784949643271, 124.91326904296875, 114.80491856166294, 108.14595263344901, 105.53788375854492, 70.65933036804199, 37.584800311497276, 46.811754431043354, 83.89260537283761, 51.535935401916504, 62.74697194780622, 72.81669739314488, 15.62187807900565, 0.2699184077126639, 0.08710027659045798, 0.3654974475502968, 0.19452602895242826, 0.20614189707807132, 0.2589768134057522, 0.4437611150954451, 0.288594405565943, 0.30452070810965126, 1.3809095237936293, 2.4603614636829922, 1.8018953395741326, 11.759092211723328, 59.38113253457205, 87.94749764033726, 86.22170407431466, 88.18502875736782, 82.27138219560895, 78.08150727408272, 66.59906019483293, 63.07011876787458, 65.9562406539917, 79.2794531413487, 80.52425071171352, 85.6309334891183, 78.7462831224714, 81.93566608428955, 80.3355793271746, 80.81283719199044, 66.22605310167584, 76.43606962476457, 76.61023317064557, 69.5304843357631, 57.690055642809185, 61.68122945513044, 62.33151830945696, 65.73524624960763, 65.01667049952916, 68.56808934892926, 62.26881776537214, 62.394531522478374, 62.29145499638149, 62.12463569641113, 59.91269057137625, 61.79333169119698, 62.85853222438267, 65.10507243020194, 71.76660224369594, 77.8037530354091, 77.72821916852678, 79.17878069196428, 76.24086693355015, 86.02819674355644, 62.07491438729422, 59.812990869794575, 82.82960047040666, 67.25936140332902, 64.11343942369733, 65.88471589769635, 78.21131352015904, 73.04916327340263, 72.96080303192139, 74.51656723022461, 72.15347794124058, 61.510498319353374, 61.70230334145682, 60.06164605276925, 62.43208653586251, 65.6362691606794, 62.01877294267927, 63.34145287105015, 57.282873834882466, 57.27453252247402, 60.09754739488874, 63.99752957480294, 68.30152865818569, 70.13653400966099, 70.52019269125802, 74.21823937552315, 75.97316673823765, 78.46732684544155, 74.62627928597587, 78.12099388667515, 78.05825165339878, 72.06413800375802, 68.32707023620605, 65.2643459865025, 78.28524930136544, 76.48588126046317, 82.79280975886753, 92.7779130935669, 52.90744726998465, 1.707961340035711, 1.8289083072117396, 0.5971103278653962, 0.220939022355846, 0.27194768882223536, 0.4416655818266528, 0.4682089218071529, 0.2000577449798584, 0.3431216153715338, 0.3438057415187359, 0.19670363781707628, 1.093752961073603, 39.087612288338796, 80.64211300441197, 95.64318343571254, 93.87328965323312, 90.71544456481934, 49.38642678941999, 39.50248575210571, 59.844236918858115, 75.8061111995152, 85.57236712319511, 96.99098110198975, 80.0837071282523, 2.96487580878394, 0.1522547086434705, 0.10372097151620047, 0.1300703997590712, 0.25275782282863346, 0.09889697429857083, 0.14142546616494656, 0.12069719843566418, 0.13933465549988405, 0.15403483169419424, 0.17264176825327532, 0.20536411952759537, 0.149569284170866, 0.15013381173568113, 0.1450065840035677, 0.14468244782515935, 0.15082990724061215, 0.18733510481459753, 0.14892752575022833, 0.15133928347911152, 0.11868952188108649, 0.12918902348194802, 0.13925498191799435, 0.14277664651828154, 0.11221549034650836, 0.13826915196010045], [0.05686736851930618, 0.05117711617744394, 0.049475333387298245, 0.10310389141419105, 0.011521813842201871, 0.16438915394246578, 0.09145813382097653, 0.06324618802006755, 0.008543074796242374, 0.02038813678414694, 0.024836028826289942, 0.027028031115021025, 0.03370377753994294, 0.07042336503842048, 0.030882011633366346, 0.06936962729586021, 0.03349173195394022, 0.10408980958163738, 0.17599347340209143, 0.2627100316541535, 0.35384868404694964, 28.998715026038035, 108.25475447518485, 99.04886381966728, 83.60422039031982, 55.50184209006173, 40.016503061567036, 38.76251302446638, 46.11354037693569, 65.44091360909599, 54.575258118765696, 43.754408087049214, 17.170060055596487, 0.05787324918700116, 0.12483995327992098, 0.09818808162318808, 0.04145449306815863, 0.05230712125610028, 0.131957934903247, 0.13118067303938524, 0.0895647429195898, 0.030739651593778814, 0.1735234023737056, 1.1534617628370012, 1.2641415723732539, 10.965912784848895, 41.5148959841047, 65.59720638820103, 77.02801445552281, 78.60714544568742, 81.29356220790318, 74.5707562310355, 73.67723873683384, 62.61093316759382, 56.55934749330793, 59.70177105494908, 66.55238219669887, 67.33244950430733, 71.52473545074463, 64.9440757206508, 68.49086706978935, 67.35835933685303, 76.25590978349958, 70.91438484191895, 72.20767389025006, 70.73296737670898, 63.42477566855294, 55.23825175421578, 56.68928575515747, 59.41505364009312, 64.10711656297956, 67.04409926278251, 65.63298266274589, 58.35867037091936, 51.993807792663574, 53.93396718161446, 58.69686004093715, 51.48696797234671, 52.91231100899832, 54.64547661372593, 60.00372586931501, 62.715517452784944, 68.9398318699428, 68.79058456420898, 72.98963805607387, 69.59153815678188, 71.34370708465576, 43.16379383632115, 44.140703610011506, 73.32499286106655, 62.74763897487095, 62.54166657584054, 54.07552630560738, 64.10656765529087, 69.18133735656738, 67.16998672485352, 68.95559038434709, 64.85959257398332, 57.519692761557444, 54.9543205669948, 52.823328903743196, 54.74137912477766, 56.019430773598806, 53.909016200474326, 52.210278919764924, 53.00558362688337, 50.13108260290963, 51.513065406254356, 53.019007546561106, 55.39308541161673, 56.92016397203718, 58.56603240966797, 59.345015798296245, 66.10751683371407, 68.29128701346261, 71.71247577667236, 69.65530177525112, 72.66556712559291, 69.2312045778547, 62.858469690595356, 52.84562914712088, 61.4215544291905, 71.12798636300224, 73.11490712847028, 67.2557622364589, 86.51675237928117, 53.80809014184134, 0.8438155097620827, 0.8635759694235665, 0.3363118922071797, 0.31619118473359514, 0.19618620058255537, 0.08673929596053702, 0.11485374984996659, 0.051610184367746115, 0.14339291916361876, 0.014511506139699901, 0.07671100978872605, 2.161788033587592, 32.55204289300101, 35.681306566510884, 34.77162061418806, 38.70473527908325, 65.81098161424909, 28.690864665167673, 28.864536625998362, 43.401974609919954, 57.52496644428798, 67.86286108834403, 78.20057160513741, 25.349335261753627, 0.424887799258743, 0.04826814155759556, 0.2988497295549938, 0.04619248936484967, 0.06248299218714237, 0.0321377628216786, 0.01429764716885984, 0.025477207099486674, 0.04320929319198642, 0.0840392829850316, 0.040417359077504704, 0.08037549243973834, 0.10668282437005214, 0.03048193042299577, 0.08568678636636053, 0.055104968803269525, 0.05659649055451155, 0.06794484624905245, 0.06959469057619572, 0.05516858146126781, 0.05311702065435903, 0.049596312788448164, 0.01805475663526782, 0.041182424274406264, 0.002000434465506779, 0.034272237215191126, 0.05837715643325022, 0.05087275250947901, 0.07768543357295649, 0.0631477190181613, 0.060848028132958074, 0.07783174607902765, 0.0190788339158254, 0.037476187971021445, 0.047845261570598395, 0.06189160142093897, 0.04603669772456799, 0.0409493610662009, 0.04550998830901725, 0.011997663665429821, 0.08183460735848971, 0.02206881883155022, 0.10362985783389636, 0.015277192196143525, 0.35339686114873203, 0.4226487422628062, 39.21877690723964, 124.86360331944057, 108.11246231624058, 95.91801943097795, 69.46375383649553, 53.934252057756694, 44.868746280670166, 48.850668566567556, 66.00307846069336, 45.205681800842285, 42.98268209184919, 23.306116717202322, 0.04293896823323198, 0.14782304715897354, 0.22182632902903215, 0.06704913931233542, 0.25229213067463463, 1.0063764325210025, 1.4824806792395455, 0.13079510230038846, 0.06252202152141503, 0.188443356060556, 2.2327523742403304, 1.1940510762589318, 13.062576004437037, 52.36131191253662, 73.24672140393938, 80.66272830963135, 80.81718676430839, 84.9201466696603, 77.5292991910662, 77.04326575142997, 64.24462836129325, 60.50480910709926, 62.85901859828404, 69.3606356212071, 70.82878998347691, 74.99875136784145, 68.14796652112688, 71.05258451189313, 71.44506740570068, 78.57630239214215, 73.44405024392265, 73.6525239944458, 74.19374697549003, 67.49912289210728, 58.7775216783796, 59.600257873535156, 64.14703396388462, 67.49000685555595, 69.44514656066895, 69.00221279689244, 60.48864759717669, 54.697014876774375, 57.20593990598406, 61.39112131936209, 53.39724663325718, 58.71584251948765, 58.35391780308315, 62.912387711661204, 64.98024109431675, 70.70857225145612, 71.11645235334123, 75.59629644666398, 72.54719066619873, 77.74086488996232, 46.54408202852522, 46.630979674203054, 75.91284247807094, 65.54236425672258, 65.83614798954555, 56.47575371606009, 67.28194304874965, 69.48432050432477, 70.68483025687081, 70.86570576259068, 70.2442102432251, 63.16842882973807, 57.56432104110718, 55.12048673629761, 56.47766447067261, 57.94318199157715, 57.65620749337332, 55.022572721753804, 55.57910605839321, 52.999292033059255, 54.561861991882324, 56.03735017776489, 58.55454008919852, 59.48998301369803, 60.80704879760742, 61.71902765546526, 69.54964051927838, 71.20839786529541, 75.17577757154191, 72.76951912471226, 75.3441115788051, 73.98290388924735, 65.72608852386475, 57.42671891621181, 63.246297291346956, 73.90686280386788, 76.3505025591169, 70.53262301853725, 88.46021911076137, 62.61651257106236, 1.2290216854640414, 0.54275429887431, 1.0672857527221953, 1.3852493252073015, 0.7061416230031422, 0.344377800822258, 0.22643903722720488, 0.1511301589863641, 0.1691001004406384, 0.031629506165960004, 0.02082769346556493, 1.7352334537676402, 33.33556692940848, 39.63404294422695, 44.25186089106968, 40.185500621795654, 56.075047629220144, 35.967683519635884, 38.37144408907209, 52.57995087759835, 64.2390489578247, 75.70315974099296, 90.00870854513985, 35.60318449565342, 0.34532419432486805, 0.06621810354824577, 0.18324855981128557, 0.06518615356513432, 0.05226198171398469, 0.016278338385745883, 0.03328403577740703, 0.029451890515961816, 0.030932691413909197, 0.06006106321832963, 0.07040778587439231, 0.054909265733190944, 0.01326725272727864, 0.05017717947651233, 0.07729067546980721, 0.04324967281094619, 0.06622302971248116, 0.016477256015475308, 0.03346514695190957, 0.006614998881039875, 0.007488440539288733, 0.007614944911827999, 0.032601724711379836, 0.05070508989904608, 0.11073205673268863, 0.15285701703812393, 0.195644186809659, 0.11773308606020041, 0.16430342782820972, 0.09583514609507152, 0.18783259311957018, 0.18683708725231035, 0.14539968648127147, 0.05973088129290512, 0.1525022517889738, 0.2313918136060238, 0.1340599956789187, 0.09598921425640583, 0.15948171727359295, 0.13241047704858439, 0.09527259985251085, 0.11607775917010647, 0.18349988918219293, 0.25477749588234083, 0.49500470395599094, 0.6989198390926633, 47.35387372970581, 138.82363210405623, 119.89304270063127, 111.15571771349225, 78.04370212554932, 56.945267813546316, 52.15359204156058, 59.979587827410015, 83.87691634041923, 77.24987043653215, 69.20547539847237, 29.835380622318812, 0.1675473680453641, 0.24723973178437778, 0.21761037382696355, 0.18319796824029513, 0.32519349881580895, 0.7835696882435254, 0.8379900966371808, 0.2697887803827013, 0.27490254598004477, 0.6539767735770771, 2.8929560908249448, 2.3501812730516707, 17.893827847072057, 62.59370163508824, 76.95133413587297, 83.72778020586286, 85.24601023537772, 85.8475227355957, 80.97231224605015, 82.34626988002232, 68.90272848946708, 62.86149910518101, 65.74675941467285, 71.92494474138532, 73.7458244051252, 77.55678626469204, 72.39793641226632, 74.69802638462612, 75.09925706045968, 83.77177619934082, 74.69664369310651, 76.17517171587262, 77.71535110473633, 71.90040370396206, 62.72223636082241, 62.046551840645925, 66.28461251940045, 69.43167400360107, 73.28759765625, 72.73511859348842, 63.0643378666469, 57.533217430114746, 58.76403522491455, 65.28834506443569, 58.0168467930385, 61.4042603628976, 61.122135707310264, 66.66794463566372, 69.91072450365338, 75.29704448154995, 75.48540319715227, 79.62281227111816, 75.35959911346436, 79.54042053222656, 51.74296392713274, 51.89132881164551, 79.51914514814104, 68.68852942330497, 70.00643593924386, 60.870423316955566, 71.6377340044294, 75.32624081202916, 73.37720162527901, 76.1311479296003, 71.85918698992047, 65.02141611916679, 61.19302122933524, 58.952810832432334, 60.62996006011963, 60.95272472926548, 60.701394489833284, 59.25860105242048, 59.25582177298409, 55.7114588192531, 57.082473891122, 59.125619479588096, 63.62469618661063, 63.221943855285645, 64.09552001953125, 64.11350195748466, 73.52548313140869, 76.21533230372837, 79.78790146963937, 74.3144302368164, 78.35070828029087, 76.76633834838867, 69.35716152191162, 61.35975020272391, 68.38299628666469, 79.99225493839809, 79.34154919215611, 73.22797516414097, 92.82169369288853, 62.17446122850691, 0.9016155110938209, 2.9506765135696957, 1.9412478676864078, 1.5079171657562256, 0.7481675850493568, 0.40485372713633944, 0.45283793232270647, 0.31143435569746153, 0.44740794226527214, 0.19111256354621478, 0.1771357599645853, 4.777739422661917, 48.581398078373496, 47.286656856536865, 44.14121777670724, 51.008716515132356, 84.1991251536778, 40.91267476763044, 42.81913191931588, 62.452500343322754, 77.04521819523403, 84.64838177817208, 99.23895263671875, 36.10715470995222, 0.5363020822405815, 0.10225303564220667, 0.338524404913187, 0.12880793107407434, 0.1394149533339909, 0.09485706500709057, 0.12146766137863908, 0.08495705588055508, 0.1335084552743605, 0.15387291966804437, 0.2661718358950955, 0.11680670934064047, 0.250881944916078, 0.1207311251865966, 0.1221131653125797, 0.07439202815294266, 0.13635440756167683, 0.13127460942736693, 0.20524726222668374, 0.1989583554012435, 0.11660841426679067, 0.20053250236170633, 0.06811735020684344, 0.11672140391809599, 0.13566716015338898], [0.08241491764783859, 0.053613260454897366, 0.060789626623903, 0.0061588863692512465, 0.027376830345019698, 0.04939976494227137, 0.0394383992866746, 0.02911724043743951, 0.03141464465962989, 0.021294891967305114, 0.07445509119757585, 0.027344124957120845, 0.07689546953354563, 0.03415380571303623, 0.02447100243132029, 0.04860678481470261, 0.04629932131086077, 0.08786698044942957, 0.024885717945705568, 0.04323506395199469, 0.2564437064741339, 57.75007765633719, 108.66327381134033, 82.39968763078961, 82.36783014025006, 45.86774090358189, 31.86298656463623, 34.030292987823486, 53.365281445639475, 49.52073546818325, 41.62484427860805, 38.92485768454415, 0.849171050957271, 0.12381719744631223, 0.08885791299066373, 0.08234283008745738, 0.2305280113858836, 0.35398262685963083, 0.6171454042196274, 0.9144717412335532, 0.19974655524960586, 0.1512976349996669, 0.2923224669482027, 2.245586782693863, 32.47770411627633, 74.76473603929792, 75.31394944872174, 77.03640093122209, 79.5617515019008, 76.3550466809954, 78.94725281851632, 76.59662164960588, 73.49439689091274, 62.57767908913748, 54.454963956560405, 55.51014518737793, 60.96512726375035, 62.004980768476216, 61.79631246839251, 60.616827964782715, 62.121627126421245, 69.02739306858608, 71.27383599962506, 73.89669064113072, 72.93555327824184, 69.01075908115932, 63.87745080675398, 61.69069290161133, 63.36116491045271, 66.00011852809361, 71.20049776349748, 71.48216383797782, 68.74632453918457, 61.747140066964285, 54.0660628591265, 54.61275407246181, 58.973412241254536, 51.93796164648873, 55.17139966147286, 54.40951926367623, 56.55647441319057, 57.122412136622835, 59.7180506842477, 63.06105831691197, 73.64126096452985, 64.68689509800502, 73.3420159476144, 37.65845816476004, 31.69118193217686, 80.57447229112897, 60.38050583430699, 68.0309727532523, 54.45605134963989, 56.5213999067034, 63.23023305620466, 66.65547956739152, 68.03756659371513, 64.68655463627407, 61.41468266078404, 55.066631249019075, 52.74295909064156, 51.5822868347168, 54.74358170373099, 54.19606018066406, 53.06686326435634, 50.91409247262137, 51.173367977142334, 49.84584168025425, 50.429907253810335, 50.98351192474365, 53.12513085774013, 54.204054083142964, 55.69672169004168, 58.75956058502197, 63.940637724740164, 68.16084153311593, 73.06293460300991, 71.15768296377999, 69.51123087746757, 65.34484086717877, 56.48580775942121, 54.35694571903774, 60.252478327069966, 67.52966717311314, 77.64553560529436, 67.04673957824707, 85.38047177450997, 34.63665533065796, 0.6142776980996132, 1.305750533938408, 1.6563209167548587, 0.20262483294521058, 0.24999879087720597, 0.25185892677732874, 0.12573297321796417, 0.09232393771942173, 0.08885434389646564, 0.06310192468975272, 0.0576653867693884, 6.532640295369284, 32.41871043613979, 27.524048464638845, 29.068021569933208, 52.2810880116054, 62.07520621163504, 32.16405895778111, 32.548447200230186, 51.73020008632115, 62.633848326546804, 73.78939655848912, 67.85398129054478, 3.430934263127191, 0.27592167843665394, 0.017780675985185162, 0.074064933561853, 0.0476740196879421, 0.05857670679688454, 0.04762409308126994, 0.0613950766356928, 0.04588129284924694, 0.06318899430334568, 0.07518712191709451, 0.04999990202486515, 0.021706716922510947, 0.058320335910788605, 0.04583915921726397, 0.11226170536662851, 0.05359682294407061, 0.05417691610221352, 0.013558535088252808, 0.06824840924569539, 0.08474445728851215, 0.09510535454111439, 0.04266625143853681, 0.07864218151995114, 0.02701525260428233, 0.00833142954590065, 0.050105010491928885, 0.039742182807198594, 0.06116470042616129, 0.07500156294554472, 0.08216775448194572, 0.05950868143034833, 0.01502733354988907, 0.028635972512087653, 0.01003639551345259, 0.00861002754286996, 0.00979939425763275, 0.06454107032290526, 0.02669968462682196, 0.03909474504845483, 0.07033525048089878, 0.066887899035854, 0.03435963931094323, 0.046876150715563975, 0.0745110431952136, 0.27518696071846144, 74.95822252546037, 118.9037720816476, 92.52326161520821, 90.6745822089059, 59.32799965994698, 39.3752121244158, 27.719080924987793, 25.04172808783395, 55.70113032204764, 44.72760057449341, 40.9744234085083, 0.5366807590637888, 0.0873329598190529, 0.1055340985102313, 0.3853436740381377, 0.07227243403238909, 0.4682701528072357, 2.478825867176056, 5.146365242344992, 0.89767637103796, 0.05860864544021232, 0.7421790521059717, 2.302517933504922, 35.78262172426496, 82.53016090393066, 84.22342995234898, 81.20388875688825, 82.53772054399762, 77.02323409489223, 81.50257791791643, 80.5422534942627, 78.5024916785104, 65.207245690482, 57.78696911675589, 57.527127334049766, 63.45179026467459, 65.12679944719586, 64.35739762442452, 64.254196030753, 66.5109292439052, 71.88149765559605, 74.24567781175885, 74.94749450683594, 76.76791558946881, 74.99233818054199, 67.24019827161516, 63.24350411551339, 66.2567571912493, 68.49682167598179, 75.1136884689331, 74.75285461970738, 72.14069325583321, 64.18312290736607, 55.71125037329537, 56.73565803255354, 60.256265095302034, 54.10385758536202, 56.97824396405901, 56.6843455859593, 60.906310762677876, 61.10088116782052, 63.93974835532052, 65.67786107744489, 75.22843102046421, 66.73994881766183, 77.17411422729492, 42.43732493264334, 33.584003244127544, 82.01126943315778, 63.44019372122628, 72.09780202593122, 58.045549801417756, 59.48711340767996, 66.98693643297467, 70.52783570970807, 69.48205539158413, 67.92211532592773, 64.22326265062604, 59.01422595977783, 55.45425387791225, 53.49377448218209, 56.57010677882603, 56.93711757659912, 55.669561181749614, 53.301816599709646, 54.750234603881836, 53.58140516281128, 53.417299134390696, 53.673910004752024, 55.72962141036987, 56.72814008167812, 57.94457163129534, 61.63437080383301, 66.96614047459194, 70.67235824040004, 73.43629605429513, 75.11254896436418, 72.2247039249965, 68.26109709058488, 58.80549512590681, 58.14727142878941, 63.39925493512835, 71.01216684068952, 82.04992921011788, 70.18530341557094, 88.21905408586774, 43.334087235586985, 0.28629989868828226, 0.9822270997932979, 2.2256183113370622, 1.1799854253019606, 0.8088929951190948, 0.7958577945828438, 0.17062943694846971, 0.12426136646951948, 0.4067905374935695, 0.02929612940975598, 0.07231853370155607, 7.5558880397251675, 34.81165960856846, 26.84959898676191, 35.914502007620676, 48.44944483893258, 51.7645172391619, 35.92542110170637, 44.477649552481516, 57.40432834625244, 71.21250425066266, 79.67163726261684, 86.04277406420026, 6.15346189907619, 0.4034007122474057, 0.039197994329567463, 0.08061603310384921, 0.06664067480180945, 0.08457706269941159, 0.09544969070702791, 0.02149365862299289, 0.019162203817229186, 0.0231699098367244, 0.07997374542589698, 0.07591164125395672, 0.05383550102955528, 0.0678308116538184, 0.0415860881496753, 0.043003144075295756, 0.04981758305802941, 0.07945995192442622, 0.087776904925704, 0.026941565397594656, 0.06785878086728708, 0.025425799590136324, 0.02023774288993861, 0.01956738930727754, 0.024897897649290304, 0.12382979105625834, 0.14449886339051382, 0.19402596221438476, 0.14665207213589124, 0.12967845079089912, 0.24842502389635357, 0.13210472916918142, 0.10937616734632424, 0.08741813631994383, 0.20047826027231558, 0.16033325158059597, 0.19406280666589737, 0.243444169738463, 0.10629779645907027, 0.1819141935557127, 0.15823330783418246, 0.17262823826500348, 0.15117002970405988, 0.11981633784515516, 0.20296042279473372, 0.5362356400915554, 86.04048115866524, 130.50674956185478, 103.69314398084367, 104.3507353918893, 64.86603355407715, 43.757941246032715, 49.21803372246878, 72.27528681073869, 67.02180249350411, 63.88721997397286, 61.15381949288504, 0.9844811388424465, 0.22303295428199427, 0.25841911190322464, 0.4741270499570029, 0.7355604044028691, 0.9554560163191387, 1.841958109821592, 6.564401813915797, 1.0462801541600908, 0.6407480548535074, 1.1107304500682014, 3.4829432666301727, 41.70133352279663, 90.73416301182338, 87.62426049368722, 86.46143082209996, 87.59707914079938, 80.49794483184814, 84.693176814488, 83.87036418914795, 82.71396160125732, 69.37940270560128, 59.67441599709647, 60.30876568385533, 67.24029554639543, 68.50254699162075, 68.25553158351353, 66.0046557017735, 68.8460589817592, 75.14276668003627, 78.3599076952253, 76.75599942888532, 79.06583772386823, 78.59275572640556, 71.28455707005092, 66.98944473266602, 68.40940638950893, 72.9589478628976, 79.54620838165283, 77.50075599125454, 73.87528324127197, 67.86292362213135, 57.4879012789045, 60.18914549691336, 64.86355999537876, 55.890312399183, 60.223997661045615, 60.562889099121094, 64.32131562914167, 63.50146293640137, 65.60894189562116, 69.78057084764752, 78.46210180010114, 71.73260470799038, 79.37410845075334, 46.04523263658796, 37.06035723005022, 86.38428497314453, 66.2316950389317, 74.689195224217, 60.302547046116416, 61.06689058031355, 70.47960131508964, 73.5764412198748, 72.50244426727295, 71.6168338230678, 67.7386759349278, 62.56794466291155, 58.99100508008684, 56.769405433109824, 60.62579114096505, 60.98570087977818, 58.853819847106934, 57.72135032926287, 58.21088913508824, 57.97732891355242, 56.300773756844656, 56.64687047685896, 59.13939775739397, 60.05614307948521, 61.31352383749825, 64.36631911141532, 70.92261150905064, 73.47993768964494, 77.89413520268032, 77.5867052078247, 75.24686459132603, 72.09565503256661, 61.90904004233224, 61.809680802481516, 66.12929943629673, 74.08261748722622, 85.84801605769566, 73.63022027696881, 91.19106960296631, 43.27373170852661, 1.369421437382698, 8.127247963632856, 5.912330746650696, 1.1829729335648673, 0.7483478039503098, 1.4349174371787479, 0.5689296828848975, 0.5472085827163288, 0.3778064527681896, 0.19027797904397759, 0.14057245265160287, 11.895504457609993, 52.49109731401716, 37.019328117370605, 42.73540265219552, 69.1759455544608, 74.51493440355573, 42.74501895904541, 48.75096191678728, 69.01278100694928, 82.63500922066825, 88.72887815747941, 93.45914227621896, 5.5261945979935785, 0.5508714775953973, 0.27215548338634626, 0.12431655850793634, 0.10760779652212348, 0.12641483305820397, 0.1492923197469541, 0.21477629590247357, 0.1427780171590192, 0.1684012365128313, 0.3139942783330168, 0.13059280386992864, 0.13403839112392493, 0.18023708569152014, 0.0894412359754954, 0.12748937468443597, 0.27655600011348724, 0.267940450991903, 0.11034117984984602, 0.1701304287250553, 0.1538846990359681, 0.22209246403404645, 0.09864162800035306, 0.13202301998223576, 0.10664878226816654], [0.055077786690422466, 0.03484794364443847, 0.06986485607922077, 0.03159241404916559, 0.028252646027665054, 0.06887464957045657, 0.01598617647375379, 0.01981426409578749, 0.07925672390099082, 0.09007487233195986, 0.17966863619429724, 0.021133909534130777, 0.117484484400068, 0.046287429984658957, 0.12467619563852038, 0.02377582973401461, 0.1662107083414282, 0.011411565472371876, 0.16795946950359003, 0.24430642489876064, 7.050698850836072, 96.52798094068254, 89.54715360913957, 87.35249560219901, 74.36221299852643, 48.49902718407767, 38.38124104908535, 113.53214059557233, 156.17332567487443, 66.38832133156913, 44.58864007677351, 7.307014857019697, 0.08869901365999665, 0.06970933585294656, 0.04375593118103487, 0.2874181243990149, 0.05405559404087918, 0.037472744405801804, 3.278030250753675, 4.754360905715397, 0.34522404255611555, 0.022561996742816906, 3.9521692310060774, 52.565199851989746, 79.41100338527134, 73.29782540457589, 72.34535939352853, 74.20740713391984, 75.54851368495396, 78.7531270980835, 75.3907687323434, 75.52270807538713, 75.83725997379848, 63.27504893711635, 54.532526697431294, 55.50516332898821, 54.48207582746233, 57.013610294886995, 57.46373891830444, 57.338233607155935, 59.27973747253418, 66.48127433231899, 69.68333775656563, 70.66083117893764, 74.08409745352608, 70.31500543866838, 68.69686031341553, 66.70773002079555, 66.6033889225551, 69.35526466369629, 69.67249161856515, 70.73539229801723, 68.8250754220145, 60.30029582977295, 51.78893320901053, 54.062682560511995, 55.25581332615444, 53.197558879852295, 51.99613543919155, 52.118541853768484, 51.402050563267295, 51.59567601340157, 55.30257817677089, 56.0818429674421, 61.70531191144671, 59.724269321986604, 68.30047948019845, 52.89482586724417, 23.044977358409337, 61.361515045166016, 67.0992818559919, 69.62427806854248, 62.256720951625276, 57.54873970576695, 59.38706629616873, 65.06136131286621, 64.77638789585659, 63.01652036394392, 61.59357098170689, 58.272248676845, 52.35770232336861, 53.37969895771572, 51.15990236827305, 51.97131994792393, 51.06020961488996, 49.490239824567524, 48.93350846426827, 53.133638926914756, 49.998507499694824, 53.59776817049299, 51.08645990916661, 53.496060439518516, 53.4741666657584, 60.071359634399414, 61.42180456433977, 70.30465957096645, 66.3494461604527, 71.83884266444615, 68.11517797197614, 67.4073371887207, 54.5163026537214, 56.35515035901751, 53.35743692943028, 59.51186983925955, 62.8238468170166, 77.77715533120292, 67.06112929752895, 84.06461497715541, 9.270784224782672, 1.7223068731171745, 1.5075314321688242, 1.0681046630655016, 0.12023063775684152, 0.3752434088715485, 0.2167210994022233, 0.31849901803902214, 0.315900201776198, 0.11562178363757473, 0.051051465062690635, 0.21873254861150468, 17.969151530947002, 34.59732157843453, 37.73182766778128, 65.54389980861119, 120.96075848170689, 58.45834922790527, 23.205437319619314, 42.37189027241298, 58.474566323416575, 59.06765760694231, 76.09720597948346, 25.748827150889806, 0.5151980146765709, 0.11475741144801889, 0.16229214146733284, 0.10637525801679917, 0.1424879298678466, 0.01455486283105399, 0.08178008706974131, 0.009449093768905317, 0.14426236679511412, 0.025444405020347664, 0.03204387053847313, 0.05411736786897693, 0.07563631209943976, 0.02521776414609381, 0.0282159237124558, 0.030059712007641792, 0.006525389426055231, 0.09684868063777685, 0.039319974569869895, 0.03587780034701739, 0.06784987848784242, 0.013284298375115862, 0.05397121821131025, 0.03486723778769374, 0.018755773215421608, 0.07718299196234771, 0.04215635272807308, 0.06816590617277793, 0.010084102462444986, 0.04838416426043425, 0.058151611393051486, 0.03208470816857048, 0.09331096189894847, 0.04254534328356385, 0.03434542060962745, 0.045910262901868136, 0.041316655464470387, 0.05385003524965473, 0.06403087305703334, 0.011720652592235377, 0.1564840038440057, 0.032172608987561295, 0.12765580575381005, 0.39891043890799793, 12.114358816828046, 113.26006998334611, 98.00803756713867, 98.70972224644252, 82.67576735360282, 62.208924293518066, 38.40841545377459, 64.91300337655204, 106.52273532322475, 48.662434918539866, 48.595520292009624, 10.05925624711173, 0.1153830885887146, 0.09011497375156198, 0.2176243652190481, 0.10089896472969226, 0.570876481277602, 0.8349321835807392, 3.610860688345773, 5.533927074500492, 0.7522127394165311, 0.10503588417278868, 4.640677954469409, 56.945934840611045, 89.46368489946637, 78.61093916211809, 77.5168480191912, 79.20415551321847, 80.19926956721714, 80.71828610556466, 77.18699618748256, 79.06797082083565, 80.20220865522111, 65.92691925593785, 58.123178550175254, 57.44226203645979, 57.768896852220806, 59.13340841020857, 60.15125002179827, 59.265111514500205, 62.37751538412911, 68.97077219826835, 73.44810799189976, 72.66743619101388, 75.92582171303886, 74.67792524610246, 73.3646879196167, 71.04064750671387, 71.19761426108224, 73.5998010635376, 73.26102079663957, 71.8762378692627, 72.90953922271729, 62.078631673540386, 55.192626408168245, 57.065284047807964, 57.937751974378315, 55.53055552073887, 55.31933375767299, 54.34299373626709, 54.926479135240825, 55.90624809265137, 58.03824029650007, 58.92981924329485, 64.42293303353446, 62.11681202479771, 72.12173162187848, 56.73624168123518, 27.616324016026088, 65.12137290409633, 69.68079471588135, 74.43507875714982, 65.59913103921073, 60.52525765555245, 63.41895307813372, 68.873427936009, 66.57052394321987, 67.2422479901995, 66.66845880235944, 61.870401109967915, 54.528847626277376, 55.054576124463765, 53.78849622181484, 53.875529357365195, 52.31702756881714, 54.43891709191458, 51.414991583142964, 55.30687911169869, 53.099801199776785, 56.36591311863491, 54.432375362941194, 56.33507701328823, 56.3887414251055, 61.65550027574812, 65.52498681204659, 72.84786701202393, 69.47263363429478, 73.15717302049909, 72.29376901899064, 68.96009976523263, 56.72855697359358, 57.42075041362217, 56.23448099408831, 62.698376246861045, 64.56513486589704, 81.62349046979631, 72.20367172786167, 89.00491619110107, 13.575263602393013, 1.3338793388434818, 1.1171427688428333, 1.775920910494668, 1.5563724913767405, 1.516195835811751, 0.48461405294282095, 0.47195622644254137, 0.7453282145517213, 0.24157667851873807, 0.015974970467920815, 0.094657141449196, 20.945296015058243, 30.496793542589458, 34.98986005783081, 54.4259170123509, 98.59309673309326, 53.64691277912685, 31.761713096073695, 52.39313118798392, 65.7858499799456, 68.64233085087368, 87.3624245779855, 36.64142949240548, 0.539739269231047, 0.09615632386079856, 0.13167841918766499, 0.04857166723481246, 0.19503961210804327, 0.027251549031851546, 0.09775347315839358, 0.07367296423763037, 0.01754833202409957, 0.017388935666531324, 0.12133458709078175, 0.02768251545993345, 0.048503169124679904, 0.039090229397905726, 0.0383701273240149, 0.07478542918605463, 0.05440696322226098, 0.01870724099821278, 0.047032098418899944, 0.05896144972315856, 0.06387291689004217, 0.03286988514342478, 0.192705899477005, 0.04312785881172333, 0.12444326813731875, 0.14753011002072267, 0.2545780065868582, 0.11680423947317259, 0.10824009616460119, 0.1285051687487534, 0.1629927424447877, 0.1080763249525002, 0.1426112332514354, 0.14930679968425206, 0.2376570531300136, 0.09651564886527401, 0.19083752616175584, 0.10381874841238771, 0.1903432541127716, 0.15023757331073284, 0.2880510075816086, 0.15785089906837257, 0.29135436032499584, 0.6027556306549481, 14.00719141960144, 127.94480977739606, 109.86033725738525, 109.61679594857353, 96.41608020237514, 67.15960611615861, 57.293316977364675, 135.46986171177454, 175.5466126033238, 86.70701490129743, 67.07243401663644, 13.073971918651036, 0.26795138897640364, 0.20948559551366738, 0.18578121890979155, 0.736893318593502, 1.1966601248298372, 0.7730805139456476, 11.723816207477025, 14.452369451522827, 2.3944215391363417, 1.0984190021242415, 5.861040881701878, 63.70976298195975, 91.6380124773298, 81.76270457676479, 80.37788690839494, 82.42978722708565, 83.3442187990461, 85.32456656864711, 79.49408299582345, 81.01858030046735, 84.89593914576939, 69.43200056893485, 60.85418537684849, 60.42111805507115, 61.04673385620117, 62.581660406930105, 63.31329877035958, 63.53612749917166, 64.44869000571114, 72.16419901166643, 77.17644882202148, 78.01607608795166, 77.02713898250035, 76.22829069410051, 76.2981687273298, 74.40742492675781, 73.50584057399205, 78.44889327457973, 74.80491052355084, 73.31955242156982, 76.07251902988979, 66.60942690713065, 56.653179441179546, 59.78835950578962, 61.22450351715088, 58.576739583696636, 57.73386403492519, 58.4507201058524, 59.30341693333217, 60.36768640790667, 62.531570843287874, 64.30539730616978, 67.98657376425606, 66.73664147513253, 74.50083650861467, 60.171809741428916, 33.11845309393746, 71.68648256574357, 72.7810183933803, 77.23204830714634, 68.77447863987514, 62.86284705570766, 66.80001599448067, 73.99925300053188, 70.72123186928886, 69.78748430524553, 69.58961350577218, 64.23075975690568, 57.13854932785034, 57.59244040080479, 57.286483424050466, 58.28735406058175, 56.295010226113455, 56.40382596424648, 52.9561367716108, 59.31918239593506, 56.97326905386788, 59.352012634277344, 55.94467510495867, 60.61377075740269, 59.61195863996233, 66.15386131831578, 69.3953766141619, 78.1530876159668, 71.33858626229423, 76.67428166525704, 75.51391860416958, 73.64680562700543, 59.26453481401716, 62.85614899226597, 58.83351026262556, 67.07752704620361, 68.96224675859723, 85.1544885635376, 72.80047334943498, 92.06575053078788, 12.1098016670772, 3.9968630841800143, 8.07305462019784, 5.778932281902858, 1.5954951920679636, 1.0576917018209184, 0.5179157916988645, 1.0207523639713014, 2.1099957270281653, 0.29611512486423763, 0.13983344659209251, 0.5999046436377934, 31.38073989323207, 52.53154277801514, 55.757893630436485, 77.38455431801933, 130.5473131452288, 67.04569734845842, 35.955833366939, 59.857667786734446, 77.10123457227434, 75.70202718462262, 100.74459947858537, 41.70714916501726, 0.8537456797701972, 0.23360926604696683, 0.32424954803926603, 0.18864729654576096, 0.27605445416910307, 0.07890613842755556, 0.19716696866921016, 0.128732382985098, 0.21348262817731925, 0.08462905883789062, 0.1931010918425662, 0.1330923368888242, 0.14285219460725784, 0.1152193716594151, 0.08886146172881126, 0.15125903992780618, 0.2092352160917861, 0.19782898814550468, 0.14846220000513963, 0.11224567836948804, 0.09238551477236406, 0.11009299209607498, 0.22634090749280794, 0.1404143947043589], [0.03146691560479147, 0.10184069669672421, 0.06582772199596677, 0.01534528997061508, 0.053056278199489625, 0.032485939495797665, 0.08012130643640246, 0.036055064227964194, 0.09775951212005955, 0.07192374167165586, 0.0405913151002356, 0.04763845766761473, 0.049555960310889144, 0.030844970406698327, 0.1287193822541407, 0.06128856699381556, 0.08996792842767068, 0.08239263455782618, 0.24737969998802456, 0.2741033402936799, 37.921454429626465, 99.7627842766898, 83.6265310559954, 82.07081549508231, 64.88229928697858, 46.486745493752615, 42.46592371804373, 146.84500776018416, 127.95692743573869, 60.78798294067383, 22.42096311705453, 0.5824121737054416, 0.10032867640256882, 0.15415421314537525, 0.2915791454059737, 0.1972536990152938, 0.43150267430714195, 0.2873466339494501, 3.54871643441064, 6.016555462564741, 0.7559326312371663, 4.768189557961055, 60.32491329738072, 80.44612516675676, 71.56586878640312, 75.10198075430733, 70.71288708278111, 70.36827727726528, 72.7077635356358, 72.6047773361206, 79.45143495287213, 75.2817862374442, 72.44002165113176, 63.02423981257847, 53.69378880092076, 52.38287912096296, 52.66639689036778, 58.182693345206125, 57.211526257651194, 57.17113290514265, 61.22134903499058, 63.133215359279085, 64.45687498365129, 68.66665649414062, 71.10497392926897, 68.02546977996826, 68.79346111842564, 66.81977667127336, 70.73729610443115, 69.20366886683873, 69.8048061643328, 66.70248413085938, 68.17748246874127, 58.97373185838972, 51.82388959612165, 54.9206600189209, 54.40220628465925, 54.238628319331575, 52.88495595114571, 50.53711795806885, 48.074262959616526, 48.53378207342965, 48.79031303950718, 50.435695103236604, 54.765298298427034, 53.395433153424946, 64.71808556147984, 59.91866602216448, 22.872906957353862, 51.51233237130301, 66.30496379307338, 69.95927156720842, 66.0636042186192, 54.35676506587437, 52.03345768792288, 64.77510247911725, 63.983070373535156, 63.294267654418945, 63.023538044520784, 60.632176535470144, 51.946139676230295, 52.13738189424787, 49.5203845841544, 48.83363158362252, 48.09260272979736, 49.62819283349173, 51.16551651273455, 54.15358931677682, 50.42698206220354, 55.51461635317121, 53.54946081978934, 56.84907347815377, 56.939702306474956, 63.73978614807129, 62.39964539664132, 67.45573834010533, 66.86383519853864, 68.93911620548793, 68.05915464673723, 66.14981746673584, 53.8356397492545, 54.53454514912197, 51.61608287266323, 57.86468819209507, 64.67627825055803, 66.8205896105085, 71.61964089529855, 76.56885664803642, 62.76321683611189, 1.688475442784173, 1.6542985567024775, 1.8724702554089683, 1.5901331369365965, 0.5765541366168431, 0.09148595375674111, 0.14112898707389832, 0.21501467882522515, 0.1420768733535494, 0.04130046561892543, 0.02335399977995881, 1.0862704025847572, 27.694585050855363, 26.831339120864868, 73.31950378417969, 103.62162617274693, 113.05886404854911, 31.36793088912964, 35.500969546181814, 61.714212553841726, 64.11319623674665, 72.69907133919853, 56.68794127873012, 1.44236601463386, 0.1742118847157274, 0.025890155030148368, 0.08493542418416057, 0.02036341096806739, 0.043852656347943206, 0.0302128268272749, 0.02654240360217435, 0.09161902804459844, 0.00365918583702296, 0.030354637253497328, 0.05850113835185766, 0.0335116232080119, 0.03653909039816686, 0.04900365655443498, 0.041218529122748544, 0.0649312279586281, 0.061450838643525324, 0.044824284567896805, 0.02577909072195845, 0.03538548926423703, 0.07280580326914787, 0.022768001670816114, 0.021531083221946443, 0.060578100117189546, 0.03460993391594716, 0.09877014253288507, 0.006416534173435399, 0.09812161233276129, 0.027167283464223146, 0.040838054181741815, 0.04604997665488294, 0.0734233854870711, 0.06586384720035962, 0.03268767474219203, 0.010981740679458847, 0.06208672773625169, 0.04302814809073295, 0.06295783099319253, 0.07406882156750985, 0.11943565255829267, 0.09220834249364478, 0.19581648042159422, 0.38104776026947157, 47.11632524217878, 113.07244082859584, 91.36372538975307, 91.34296417236328, 74.8900398526873, 61.34986291612898, 45.22079413277762, 141.87896347045898, 136.3221277509417, 55.661612442561555, 29.064913988113403, 0.32900238728949, 0.13728291488119534, 0.5114998359765325, 0.3931088016501495, 0.278586638293096, 1.0770880324499947, 2.3364627063274384, 3.6009223759174347, 0.8304790396775518, 0.40358283104641096, 5.796860371317182, 67.2586109978812, 87.70050307682583, 79.01421955653599, 80.90390723092216, 76.32539176940918, 75.29486969539097, 76.59182739257812, 78.21749741690499, 79.49849510192871, 79.05984837668282, 77.0002772467477, 67.5964115687779, 56.86540869304112, 56.159607206072124, 57.38555083956037, 59.14453942435128, 59.94022628239223, 60.072964668273926, 64.59697846003941, 66.29003211430141, 68.1617934363229, 72.13967187064034, 72.85632296970913, 70.69359193529401, 72.43706866673061, 69.20912320273263, 71.63494777679443, 73.44364030020577, 70.09710298265729, 69.13572938101632, 71.39895221165249, 61.80763108389718, 54.572298186165945, 56.417524337768555, 56.2086614881243, 56.58375998905727, 55.24502624784197, 52.53389821733747, 51.338484968457905, 53.064521721431184, 53.258477210998535, 55.35571105139596, 57.23092562811715, 57.00414684840611, 67.26555224827358, 62.44018118722098, 27.61883405276707, 58.35475853511265, 67.18962928227016, 74.37734617505754, 68.02523354121617, 56.77648217337472, 54.86644669941494, 67.77976758139474, 66.08143329620361, 66.272050176348, 66.43689618791852, 64.40518733433315, 54.62412827355521, 54.14362907409668, 52.23283624649048, 52.150392396109446, 51.8634352684021, 51.035102299281526, 53.924854619162424, 57.32530300957816, 53.49757514681135, 57.14578240258353, 57.21844318934849, 59.8575496673584, 60.28840051378523, 67.3757576261248, 65.50656018938336, 68.99525765010289, 68.17113181522915, 71.17299679347447, 71.24350016457694, 68.61567061288017, 56.68585681915283, 56.8242267199925, 55.777591773441856, 59.835655893598286, 69.01128714425224, 69.22563212258476, 73.88645594460624, 77.01920413970947, 71.3434430531093, 3.305772453546524, 0.7599195401583398, 0.8937259944421905, 1.9155560348715102, 1.3395018428564072, 0.5045012086629868, 0.1341652771724122, 0.5121156743594578, 0.3804441083754812, 0.2601930738559791, 0.02678002995838012, 0.6647978329232761, 31.89974253518241, 26.526240246636526, 60.401315689086914, 96.06300054277692, 95.11168793269566, 31.53913450241089, 45.55804579598563, 66.43410301208496, 74.92320360456193, 80.01639298030308, 77.30710274832589, 3.669622906616756, 0.18454989498215063, 0.0325815111531743, 0.07493128028831311, 0.07176655224923577, 0.03644094030771937, 0.012904905697463878, 0.013619290265653814, 0.11930375892136778, 0.11805415526032448, 0.027034796109156947, 0.06056984913136278, 0.047698592833642445, 0.04820254757734282, 0.09038797553096499, 0.0634973816839712, 0.04074243163423879, 0.03006524546071887, 0.04276483579139624, 0.05696622428617307, 0.0275926774234644, 0.009792890499479004, 0.020540800377992646, 0.053796726145914624, 0.18971925973892212, 0.25787975798760143, 0.20932520340595925, 0.1587477188025202, 0.15935717895627022, 0.12670823160026753, 0.3412972246961934, 0.1576919997377055, 0.16931058200342314, 0.14772649162581988, 0.1426067277789116, 0.24452928294028553, 0.13141322056097643, 0.1290994840008872, 0.23048374376126698, 0.17988610666777405, 0.16466389277151652, 0.17295787057706288, 0.30980809724756647, 0.467643566429615, 54.8896085194179, 125.81898062569755, 102.44621331351144, 101.08818095070976, 84.95317145756313, 61.864321436200825, 62.6831180027553, 154.09896877833773, 124.93322426932198, 86.6036604472569, 35.25519439152309, 1.1115058256047112, 0.25814140109079226, 0.6722972190805844, 0.6915727161935398, 1.1714211191449846, 1.3429412011589323, 2.0532630341393605, 10.42918268271855, 17.258779866354807, 3.989519706794194, 5.985997719424112, 72.11744458334786, 91.06857981000627, 80.01396111079625, 83.5391435623169, 78.37069824763707, 79.82951423100063, 79.57434858594621, 81.27303722926548, 82.64499378204346, 81.44939640590123, 79.7656672341483, 71.52308872767857, 61.459046908787315, 59.149132183619905, 57.60317536762783, 63.64112172807966, 63.81841891152518, 63.11740125928606, 68.39161205291748, 70.15546785082135, 71.60356971195766, 75.0688725880214, 75.58288642338344, 73.7541275024414, 74.93149975367955, 72.8617217200143, 73.72695309775216, 76.10282012394497, 73.53084019252232, 71.90794944763184, 74.22545855385917, 65.99465029580253, 55.69765622275216, 59.535702160426546, 60.11338928767613, 60.7619480405535, 56.85845354625157, 53.907181876046316, 54.37354496547154, 54.98611552374703, 54.55002226148333, 57.18594993863787, 60.00314222063337, 60.09332289014544, 70.94039194924491, 66.68529428754533, 31.795300688062394, 56.9691800389971, 71.40949957711356, 77.0819672175816, 70.84065750667027, 60.51771191188267, 56.321618352617534, 72.3178653717041, 69.70833737509591, 70.15468270438058, 70.4629464830671, 68.47189153943742, 57.54742649623326, 56.63465206963675, 56.043627875191824, 54.93236773354666, 54.64358670370919, 53.67786700384957, 56.34986277988979, 61.32063184465681, 55.91415861674717, 60.144781248910085, 59.64170387813023, 62.50831522260393, 62.04109055655343, 71.17280224391392, 68.84619794573102, 71.53950732094901, 70.08946691240583, 74.28440707070487, 75.05715097699846, 73.19199739183698, 59.892137799944194, 60.10189001900809, 57.91267245156424, 63.97208527156285, 71.53150299617222, 72.98717144557408, 77.15235246930803, 80.75400679452079, 74.28434453691754, 3.126707822084427, 3.7794483048575263, 9.203377144677297, 3.996533913271768, 1.9252329213278634, 0.2812286636659077, 0.4368756131402084, 1.2094773799180984, 0.47451408633163994, 0.3783866544919354, 0.16763707037482942, 2.170304353748049, 46.098084109170095, 42.482905115400044, 85.59339932032994, 103.55304050445557, 119.28582572937012, 42.04965366636004, 51.39619670595442, 77.68983731951032, 81.69516808646065, 90.31406102861676, 86.78124945504325, 3.2006431690284183, 0.36745814234018326, 0.11396071634122304, 0.24238853209785052, 0.09615968260914087, 0.09195630066096783, 0.083825021982193, 0.10980670460100685, 0.17363713841353143, 0.21874416513102396, 0.1270537416317633, 0.22244690358638763, 0.14138411624091013, 0.12083031343562262, 0.1329817356807845, 0.1548317303614957, 0.13989291340112686, 0.13017490772264345, 0.14824527235967772, 0.20544603227504663, 0.16090061542178902, 0.1079455034009048, 0.07820506926093783, 0.11155222236577954], [0.004275667555962822, 0.11798563679414135, 0.03749376881335463, 0.03372739055859191, 0.021297451740662967, 0.05310210306197405, 0.020982292580551336, 0.061406224966049194, 0.05202708985390408, 0.02559592528268695, 0.024112188024446368, 0.08716177221919809, 0.0331208922101983, 0.05711540699537311, 0.035336974010403664, 0.08244079697344985, 0.14109291615230696, 0.025160908000543714, 0.06402393164379255, 0.1667903536664588, 64.35680702754429, 88.99252755301339, 86.87275723048619, 88.79009873526437, 41.40095247541155, 29.268605640956334, 37.50702217647007, 38.442499841962544, 44.96721962520054, 42.58034665243966, 7.15137824841908, 0.14639257320335933, 0.15253236517310143, 0.17990374857825892, 0.2563916492675032, 0.16962812282145023, 0.22563339902886323, 1.7124385855027606, 0.4876636064478329, 1.308000990322658, 4.706655442714691, 58.89350100925991, 83.51435933794293, 76.28322315216064, 77.8673985345023, 63.75674670083182, 60.870756830487935, 59.1456024987357, 70.92313262394497, 72.8404324395316, 80.2239078794207, 73.9744131905692, 74.71122796194894, 61.92734159742083, 52.14069618497576, 53.03903225490025, 58.22912468229021, 57.51364088058472, 57.07964250019619, 62.88155855451311, 61.674628666469026, 63.935322352818076, 64.9261702128819, 70.18214198521206, 70.77022361755371, 70.08152512141636, 67.4643749509539, 67.94826139722551, 67.47949423108781, 68.60594313485282, 63.453395298549104, 66.994523865836, 64.6165862764631, 51.74627821786063, 50.226172174726216, 51.05582182747977, 52.8436940738133, 53.77110488074166, 51.22723388671875, 50.85702691759382, 48.68138613019671, 46.09970303944179, 50.47575146811349, 51.24722385406494, 53.569016524723594, 52.46243946892874, 64.9717573438372, 56.07483918326241, 37.46002803530012, 72.83973067147392, 61.67443411690848, 66.31913117000035, 56.98902756827218, 51.58278710501534, 55.920884472983225, 63.22818333762032, 65.71422100067139, 63.42824281964983, 63.07580239432198, 63.92650508880615, 56.663657324654714, 53.07321391786848, 49.930008683885845, 48.66982432774135, 48.28770119803292, 50.07803658076695, 49.63777092524937, 54.64178712027413, 55.68137659345354, 55.561523641858784, 55.08932406561715, 59.18649959564209, 60.230848584856304, 64.87630299159459, 64.82806164877755, 66.82548114231655, 63.225209508623394, 65.47115216936383, 69.27934864589146, 66.7227589743478, 52.854859828948975, 51.73672444479806, 51.90120915004185, 59.09943866729736, 62.49712862287249, 68.44057600838798, 70.0532945905413, 71.86881719316754, 76.60584190913609, 54.595769201006206, 0.8931199269635337, 0.436298668384552, 2.4872707511697496, 1.9808430458818163, 0.36217631718942095, 0.23073425889015198, 0.17615755674030098, 0.3849864660629204, 0.06359510429735694, 0.09544385530586753, 0.031239884572901895, 8.736657960074288, 28.871173892702373, 46.83536440985543, 87.42714009966168, 88.71211215427944, 45.42670052392142, 35.95968614305769, 53.94256905147007, 55.76025949205671, 63.04691873277937, 77.5718082700457, 21.87827754020691, 0.7389317463551248, 0.13050429576209613, 0.09851483694676842, 0.020277601733271564, 0.0732015927455255, 0.05188435662005629, 0.03979320524792586, 0.0543182481612478, 0.030331797764769623, 0.043496795264737945, 0.03236489902649607, 0.01943691889755428, 0.0908795537959252, 0.015370799494641168, 0.09371629157768828, 0.027908423516367162, 0.07792638135807854, 0.058734126921210966, 0.05346422702340143, 0.043262276598917584, 0.05333790755165475, 0.05025086159418736, 0.02462170336262456, 0.01866473926098219, 0.05214665111686502, 0.08316257502883673, 0.07298341659562928, 0.03690040690292205, 0.04427970593262996, 0.03004217187740973, 0.04194628507164972, 0.04210499441251159, 0.024826924582677226, 0.018431779529367174, 0.06944511431668486, 0.009999955638444849, 0.026541662302666476, 0.028834854518728595, 0.09286979878587381, 0.04112411436757871, 0.02529435887533639, 0.006131407397333533, 0.5135373409305299, 78.3454623903547, 100.5737224306379, 97.06138025011334, 100.1084988457816, 57.31753492355347, 39.976241724831716, 36.56351934160505, 50.03923783983503, 54.64139454705374, 49.97464738573347, 7.450196385383606, 0.28016982334000723, 0.11545054854026862, 0.6453153554882322, 0.5181712465626853, 0.6404581304107393, 0.7864491737314633, 2.4470042032854895, 0.922568781035287, 0.24221094591276987, 5.744281181267329, 65.37286295209611, 89.30193083626884, 79.40016419546944, 83.33115618569511, 68.22725936344692, 64.61701011657715, 62.084489004952566, 75.46733093261719, 77.80280808040074, 83.74567876543317, 77.99449498312813, 78.23529870169503, 63.8317802974156, 55.935708454677034, 56.678234645298545, 61.37918431418282, 60.071463857378276, 61.86271640232631, 64.53889151981899, 64.67811257498605, 67.35781042916435, 68.34745625087193, 72.49739292689732, 73.78039864131382, 72.07196167537144, 67.78922407967704, 70.61668232509068, 69.15604591369629, 69.90087195805141, 66.92582702636719, 69.03188160487584, 68.48932456970215, 52.46794939041138, 52.749983719417024, 53.637105396815706, 54.78774445397513, 56.08631065913609, 54.015896865299766, 53.66275119781494, 51.7215495790754, 51.18175097874233, 53.20576122828892, 54.55105059487479, 56.41769804273333, 55.340928758893696, 66.85906873430524, 59.583373750959126, 42.11543573651995, 73.8576556614467, 64.19214861733573, 67.84670652662004, 58.91952201298305, 53.765098163059776, 58.906917980739046, 67.85712882450649, 69.05532482692173, 67.93556009020124, 65.84237357548305, 66.90034798213414, 60.579912185668945, 54.94289078031267, 51.30132252829415, 51.603902680533274, 50.10023954936436, 53.70538534436907, 53.286415917532786, 57.34488303320748, 57.769289425441194, 59.04485361916678, 58.09937402180263, 62.55590343475342, 62.98601082393101, 68.71485614776611, 68.14531230926514, 69.03919110979352, 65.87474523271833, 67.88128076280866, 71.818206514631, 70.52129745483398, 55.12990501948765, 55.746755668095176, 53.901143891470774, 62.68272195543562, 63.949976103646414, 72.53082765851701, 72.47610364641461, 74.21649537767682, 78.47608852386475, 63.22799573625837, 2.3173905525888716, 0.3299449538545949, 0.7963432456765855, 1.6631580527339662, 1.507592880300113, 0.680091849395207, 0.7623692687068666, 0.2927370789859976, 0.5253375534500394, 0.11422869696148805, 0.06558093880968434, 10.037879245621816, 32.92585597719465, 44.87320702416556, 83.02966690063477, 83.81773158482143, 41.13440220696585, 47.039888109479634, 59.57376439230782, 62.32391698019845, 69.54174736567906, 86.50088964189801, 33.442204407283235, 0.6346385255455971, 0.08254687913826533, 0.11919485405087471, 0.029094614687242677, 0.09719920504306044, 0.04819202010652848, 0.028320143298645104, 0.03339817215289388, 0.024997089290991426, 0.10547683694000755, 0.047567815386823246, 0.03188934436600123, 0.03257788099082453, 0.019421848634790097, 0.060123223811388016, 0.04138794235352959, 0.08346507951085057, 0.05381637312737959, 0.01289221369994006, 0.02324090665206313, 0.051987460016139915, 0.059234688989818096, 0.01576248213781842, 0.09803830858852182, 0.19368180925292627, 0.17186268791556358, 0.1475005666060107, 0.12167481811983244, 0.11908934185547487, 0.1539114468864032, 0.1478089607719864, 0.14482924209109374, 0.19658566771873406, 0.05093503523884075, 0.22074266789214952, 0.08434537691729409, 0.1743175597595317, 0.09480658200170312, 0.12930790281721524, 0.1890276154237134, 0.1821609903126955, 0.12404700368642807, 0.8065405413508415, 91.56105422973633, 112.39531803131104, 108.89070919581822, 112.66192041124616, 61.419713156563894, 42.20456722804478, 53.32746934890747, 52.082268783024375, 60.56352138519287, 64.53736986432756, 11.01976045540401, 0.3449453275118555, 0.3689437269100121, 0.7987661585211754, 2.102555509124483, 0.9779974924666541, 0.6735465920397213, 6.569416676248823, 4.291831050600324, 7.321343779563904, 6.964129073279245, 71.23582240513393, 92.668381690979, 82.14389664786202, 85.47819818769182, 69.3168202808925, 67.7089376449585, 64.49784851074219, 79.37676961081368, 81.08371966225761, 85.67445005689348, 80.9007874897548, 83.01519380296979, 67.01646627698625, 58.70669869014195, 59.00355352674212, 64.41971601758684, 62.77723830086844, 63.61527442932129, 68.15367099217006, 68.04347256251744, 69.90704195840019, 70.91079262324742, 76.60111018589565, 77.92003808702741, 74.78295421600342, 70.57857145581926, 73.88243988582066, 71.259738104684, 75.16155460902623, 71.0832747050694, 73.94874654497418, 73.05119909558977, 56.611254010881694, 57.26222378867013, 56.49654272624424, 58.543999671936035, 59.88371658325195, 57.58121906008039, 56.65395416532244, 54.37803002766201, 55.055972712380544, 55.70389570508684, 59.68197563716343, 57.479493958609446, 58.538357734680176, 69.7125688280378, 62.641824858529226, 46.162928172520225, 75.38270882197789, 68.04215935298375, 71.96309729984829, 63.012622424534385, 57.75285693577358, 62.6474528993879, 71.15992723192487, 74.08592482975551, 70.21411759512765, 68.66353675297329, 70.96477317810059, 63.21269580296108, 57.22368213108608, 53.932178020477295, 54.309281076703755, 54.18163224628994, 56.55309064047677, 57.6702880178179, 62.11647851126534, 61.019955498831614, 62.190726961408345, 60.07768249511719, 67.24984931945801, 65.20328521728516, 71.44501182011196, 69.78519139971051, 71.0647508076259, 68.59116431644985, 69.54405416761125, 77.1761222566877, 73.38707501547677, 56.78017166682652, 58.556270190647666, 56.5334654535566, 65.9557056427002, 67.27466133662632, 75.85320608956474, 75.4669348852975, 78.8887767791748, 81.59953308105469, 63.198799405779155, 2.032406279018947, 3.2565983150686537, 8.125586475644793, 6.314987974507468, 1.8993691205978394, 0.538816787302494, 1.069959397826876, 1.9031830302306583, 0.7833130391580718, 0.3750690796545574, 0.16930043111954415, 14.607456718172346, 45.794360978262766, 62.30784579685756, 91.82173674447196, 95.6156894138881, 55.72771412985665, 52.132014410836355, 67.18304933820451, 75.25611959184918, 77.59858662741524, 100.51467663901192, 37.293639523642405, 1.1959036397082465, 0.3495624597583498, 0.1966752614825964, 0.08067590024854455, 0.1880668776908091, 0.2332660901759352, 0.15824455794479164, 0.13110914187771933, 0.10295211670121976, 0.22476924397051334, 0.12822200251477106, 0.08564359082707337, 0.17292378097772598, 0.19118376901107176, 0.21744341350027493, 0.14068099111318588, 0.1872683641101633, 0.21806016112012522, 0.12747181419815334, 0.12946012536329882, 0.14483450752283844, 0.19714497056390556, 0.17693443862455233], [0.03349632902869156, 0.018305302298228656, 0.03894307890108653, 0.02697021484241954, 0.039172701936747344, 0.05998498587203877, 0.027640995902142355, 0.04124948049762419, 0.04484820631997926, 0.06285035104623862, 0.02457155623207135, 0.06524080277553626, 0.03290900947260005, 0.07988303886460406, 0.017480912784646665, 0.1230391620525292, 0.039039824424045425, 0.10203507662351642, 0.16239403028573307, 7.481920991625104, 95.68934031895229, 78.83278819492885, 86.0330535343715, 63.83430944170271, 44.95792988368443, 33.302215576171875, 55.76962913785662, 52.90691225869315, 51.951250076293945, 23.574916464941843, 0.0250543338978397, 0.1005682060495019, 0.15072063596120902, 0.1905919914799077, 0.3815503104456833, 0.03662095904084189, 0.7341874295047351, 3.0980679988861084, 1.3701073548623492, 0.8311579003930092, 45.75005578994751, 85.87742083413261, 75.8369334084647, 75.71385996682304, 66.17723505837577, 61.69035938807896, 58.99989182608468, 55.4177827835083, 60.23712280818394, 72.73527145385742, 74.78082806723458, 74.07915728432792, 74.62270791190011, 57.61895472662789, 51.80039773668562, 54.74438074656895, 59.8689238684518, 62.782595361982075, 62.59190899985177, 63.492791584559846, 65.80269936152867, 65.15983813149589, 66.93920925685337, 66.11593805040631, 66.4730476651873, 66.96561241149902, 68.31898948124477, 66.50310557229179, 68.1786914552961, 64.81982803344727, 66.90680285862514, 63.543589864458355, 54.296882016318186, 47.46800136566162, 50.31817674636841, 51.61030197143555, 53.709446566445486, 51.16814293180193, 54.7860039302281, 51.68136814662388, 50.466541630881174, 50.94516134262085, 55.57060146331787, 52.359265668051584, 56.53540400096348, 57.224602767399375, 65.10586452484131, 61.55845478602818, 51.20657341820853, 63.66034739358084, 57.13455411366054, 53.808712005615234, 48.60271167755127, 48.03782313210623, 53.22000503540039, 61.01514039720808, 61.51046357836042, 62.000631196158274, 59.47907434191023, 60.8891487121582, 55.76959787096296, 53.715380328042166, 48.89094032560076, 48.051212310791016, 48.62539059775216, 50.059401512145996, 50.67798226220267, 54.831250599452424, 53.721220288957866, 57.10459695543562, 58.669317381722585, 60.96522453853062, 64.86404636928013, 68.20087010519845, 66.23628085000175, 65.2660413469587, 64.17481981004987, 65.09837436676025, 66.27041734967912, 66.34700734274728, 52.90293441499983, 50.11284358160836, 52.10737262453352, 60.09116894858224, 63.422260420663015, 62.84534454345703, 67.00281306675502, 68.53345257895333, 68.96430342538017, 72.76786545344761, 48.38231134414673, 1.3877540422337395, 1.1431852685553687, 1.9395351367337363, 1.7051439540726798, 0.34188128049884525, 0.18335363774427346, 0.4195300596100943, 0.37343552016786163, 0.12293369056923048, 0.04333093755745462, 0.6689357565982001, 20.99840804508754, 28.4712164742606, 56.010175773075645, 62.743893895830425, 39.60507590430123, 17.72381932394845, 31.5746363231114, 53.46819468906948, 65.67194816044399, 66.26310089656285, 51.38292217254639, 0.9978410048144204, 0.20769300098930085, 0.08884785031633717, 0.03449933949325766, 0.034710574229913096, 0.03356623509898782, 0.02988702823807086, 0.010978767847908395, 0.07783058578414576, 0.05398105696908065, 0.042579711082258394, 0.04194384573825768, 0.06361192518046924, 0.0520515272926007, 0.06424989059035267, 0.01105775695759803, 0.048427722815956385, 0.07953744062355586, 0.08566767882023539, 0.02875165594741702, 0.0602776583816324, 0.019623872258567383, 0.021642120388735617, 0.04970461376277464, 0.029789492221815244, 0.07987632136791945, 0.00245148192542339, 0.03150350560567208, 0.021514945962865437, 0.04310762489746724, 0.0029078548250254244, 0.12404452024825982, 0.03719657047518662, 0.06364298172827278, 0.016997765317293148, 0.01594516751356423, 0.032141572795808315, 0.046433179306664636, 0.15039450488984585, 0.031181737514478818, 0.14664122914629324, 0.31734303863985197, 11.445897817611694, 112.07593018668038, 87.71559456416539, 96.78340366908482, 71.50273050580705, 53.42957660130092, 33.3775965826852, 49.183383056095664, 60.967079707554404, 57.61989273343767, 26.893627984183176, 0.0780976978795869, 0.06942247160311256, 0.29092688326324734, 0.5325732337577003, 0.8277779274753162, 0.9259525537490845, 2.3557854294776917, 4.257716698305948, 0.3850656103874956, 1.1430445675339018, 51.11262682506016, 89.79441915239606, 79.21338966914585, 80.78050027574811, 68.34850542885917, 66.26400416237968, 63.66771248408726, 57.86823524747576, 64.0469034739903, 75.5951360974993, 78.52453136444092, 77.75071048736572, 76.32869911193848, 60.14936705998012, 53.604716369083945, 56.62545265470232, 62.654574802943635, 65.50483703613281, 66.44141251700265, 66.24897520882743, 68.95125470842633, 69.49320030212402, 70.79650170462472, 66.65074784415108, 69.94873809814453, 70.01189722333635, 70.69612107958112, 68.0677912575858, 69.50901440211705, 69.05323341914585, 70.32993016924176, 65.95521926879883, 56.88532223020281, 49.871046270642964, 53.4726311138698, 53.92084550857544, 55.74017572402954, 54.23051629747663, 57.23325674874442, 53.49048103604998, 54.82655709130423, 55.5389142036438, 57.80777549743652, 57.269658361162456, 59.71215861184256, 59.721073150634766, 69.11669826507568, 63.91130243028913, 55.41876942770821, 66.3801919392177, 60.57766096932547, 56.211478982652935, 51.260057176862446, 49.21898215157645, 55.857881682259695, 63.528088433401926, 65.1343799318586, 64.6155926840646, 62.82930810110909, 64.1375218800136, 58.1193014553615, 56.946174553462434, 52.26989098957607, 51.777510370527, 50.6397636958531, 52.65617609024048, 54.62850563866751, 55.656074728284565, 57.97125966208321, 59.32504667554583, 60.9850685937064, 65.11967059544155, 69.63266454424176, 69.19998632158551, 68.87551934378487, 67.38525581359863, 66.65886334010533, 65.43755068097795, 67.95819732121059, 68.50421455928257, 56.29094900403704, 52.04831641060965, 56.62374687194824, 62.46119253976004, 67.88847909654889, 65.201402255467, 69.1663292476109, 71.25820255279541, 72.45761448996407, 77.10828004564557, 57.26113639559065, 3.1298768520355225, 0.480846175125667, 1.0868919406618391, 1.8245346333299364, 1.6543389431067874, 0.8492793994290488, 0.9373745237077985, 0.8178688191941806, 0.8457243101937431, 0.09305253505174603, 0.30022943552051273, 25.529370035443986, 29.927854197365896, 52.36112431117466, 66.00560760498047, 39.339831897190635, 28.576208966118948, 40.64422069277082, 58.539108140128, 72.47509615761894, 73.8123117174421, 67.91857869284493, 1.9906615018844604, 0.21714515664747783, 0.05267151830984013, 0.02059630284618054, 0.07025008755070822, 0.024313544987567833, 0.07212556512760264, 0.029902793999229158, 0.04229046517450895, 0.06690569700939314, 0.03274936375341245, 0.056979767845145295, 0.04438517063057848, 0.021481124384860908, 0.01859719618888838, 0.01968416179131184, 0.06044719714139189, 0.10495445997055088, 0.05023295505504523, 0.0450208358067487, 0.08167270211769001, 0.07665969218526568, 0.01152584603655019, 0.07934251108339854, 0.10899560419576508, 0.1306182217917272, 0.20524391026369163, 0.1288315983755248, 0.14287132929478372, 0.09626292171222822, 0.12205341351883751, 0.24380143199648174, 0.13658474305910723, 0.17228469598506177, 0.20538030937314034, 0.13609800274882997, 0.19300878393862927, 0.1834824236908129, 0.36109619800533566, 0.1353502707289798, 0.31489412433334757, 0.4533657782844135, 12.717060327529907, 126.5471796308245, 98.68340941837856, 108.94840008871896, 82.17396845136369, 63.55994592394148, 49.139237676348, 75.61138793400356, 71.71076651981899, 73.57569776262555, 36.81562083108084, 0.3185575891818319, 0.2020250487008265, 0.4867805338331631, 1.6440932814564024, 1.850621644939695, 1.0419717282056808, 5.3579387579645426, 11.064065643719264, 6.310994931629725, 1.0682253880160195, 55.98357112067086, 93.3142306464059, 82.1253935950143, 83.98058346339634, 71.22134235927037, 67.82986409323556, 67.67535005296979, 61.51561219351632, 67.33357511247907, 79.07483564104352, 82.47278267996651, 80.82125840868268, 82.45876121520996, 61.72227246420724, 56.496646949223106, 61.233744621276855, 67.40391867501395, 67.21799182891846, 69.95233031681606, 69.88797610146659, 72.90377221788678, 72.83646501813615, 74.78713008335659, 71.29097025735038, 72.15003858293805, 71.70850140707833, 71.44733946663993, 70.19850499289376, 73.12561430249895, 70.7917491367885, 74.99376256125313, 71.41841411590576, 61.77293872833252, 53.02834939956665, 56.39502607073103, 57.57379143578665, 57.929355076381135, 56.87263829367501, 59.02637835911342, 57.8802695274353, 57.37733806882586, 56.69865192685808, 62.093827383858816, 59.89917632511684, 62.509552001953125, 63.70874159676688, 72.46618161882672, 67.7617439542498, 60.64558655875069, 70.86779022216797, 62.99304934910366, 60.148630550929475, 54.10355186462402, 51.41170161111014, 59.252396311078755, 67.95231914520264, 67.40555150168282, 66.60272189549038, 65.02107565743583, 68.03407859802246, 60.77487863813128, 60.36902741023472, 55.456418241773335, 54.348048550742014, 53.40188455581665, 55.39217867170061, 57.189795766557964, 60.66185923985073, 60.34771728515625, 63.015221050807405, 65.1545227595738, 69.43798296792167, 73.30288369315011, 72.40080601828438, 72.48950672149658, 70.10819925580705, 69.71404184613908, 68.1737721306937, 70.67388684409005, 73.4468503679548, 59.43373039790562, 56.190015997205464, 58.69054412841797, 66.79490212031773, 71.04464966910226, 67.66660921914237, 72.50525828770229, 74.0850076675415, 75.03708457946777, 78.21662194388253, 58.10317816053118, 2.3081592193671634, 5.017979468618121, 7.344020962715149, 5.401848767484937, 2.2278554141521454, 0.899223159466471, 2.4620344596249715, 3.2565533689090183, 1.1463437676429749, 0.2278652771243027, 1.3954489550420215, 33.98965644836426, 44.39402103424072, 63.88901955740792, 70.51755237579346, 49.35724435533796, 27.48122845377241, 47.48909262248448, 68.7528350012643, 82.656875201634, 85.28558717455182, 77.10840511322021, 2.276839562824794, 0.3428373634815216, 0.13314756963934216, 0.11889526726944105, 0.20945678491677555, 0.12844346277415752, 0.14340777908052715, 0.08669120139841523, 0.17517772503197193, 0.14241643941828183, 0.12935886079711573, 0.13991496578923293, 0.15511504587318214, 0.14597691622163567, 0.1382349266537598, 0.10255776571908168, 0.15094973652490548, 0.14621736189084394, 0.13257133056010517, 0.16163476317056588, 0.1264532652816602, 0.2502198304448809, 0.15413570271006652], [0.059290640987455845, 0.09658936490969998, 0.08280777585293565, 0.03970861567982605, 0.056018572101103406, 0.03819557758314269, 0.010946123528161218, 0.09334429832441465, 0.07247190297182117, 0.06272383140666143, 0.05454013589769602, 0.11639757986579623, 0.04104380635544658, 0.014523728251723307, 0.035410120085413964, 0.09244396377887044, 0.0852818638086319, 0.36116087596331325, 0.5464716936860765, 26.639417716435023, 97.14544650486538, 81.56596633366176, 76.1497552054269, 61.761307443891255, 47.22375134059361, 36.080831459590364, 60.64796979086739, 43.031097139631, 39.53706693649292, 3.8969649246760776, 0.020471776403220635, 0.1518100510750498, 0.16897773343537534, 0.6168625365410532, 0.6739050756607736, 0.1290830091706344, 2.042908264057977, 1.4333317279815674, 0.27451263261692865, 16.973134211131505, 79.81461034502301, 76.961304800851, 77.83652073996407, 73.16212708609444, 68.83171095166887, 62.14598056248256, 60.18526840209961, 54.973445483616416, 54.10666118349348, 61.81300204140799, 71.92331191471645, 74.99238681793213, 67.0013678414481, 52.893849645342144, 53.16117116383144, 56.78715460641043, 64.92535727364677, 66.24700192042759, 66.24359730311802, 66.38711929321289, 68.66861588614327, 69.28917339869908, 68.49118668692452, 63.934849875313894, 67.72960158756801, 66.24682821546281, 68.29804066249302, 64.2267575945173, 62.50945472717285, 62.84128679547991, 60.08481134687151, 51.89303806849888, 48.37847941262381, 48.20851257869175, 49.426945209503174, 48.67104026249477, 54.175851345062256, 53.33204126358032, 52.13102081843785, 48.960241658346995, 55.251237937382285, 55.56508459363665, 57.74310513905117, 52.13629797526768, 54.10330867767334, 54.90309844698225, 62.841710635593955, 58.40031787327358, 48.5733277457101, 64.86841678619385, 54.75169372558594, 52.755636078970774, 50.44522108350481, 51.091459138052805, 50.415614809308735, 56.49752937044416, 59.01984705243792, 60.74839210510254, 61.32033307211739, 60.90224606650216, 55.31187834058489, 53.41878604888916, 49.24908522197178, 47.246207918439595, 48.98337915965489, 47.524490220206125, 51.75902468817574, 53.74195718765259, 57.48643173490252, 57.0516482080732, 61.298390660967144, 64.96299566541398, 65.59216894422258, 64.73043251037598, 65.32802622658866, 64.97372368403843, 64.41408797672817, 62.014687401907786, 68.26836490631104, 61.742491722106934, 52.53071941648211, 49.61979593549456, 53.53294842583792, 56.87113748277937, 58.886226245335166, 62.98926258087158, 66.6250673021589, 66.11061573028564, 70.43540382385254, 67.43221173967633, 72.14206899915422, 44.08615330287388, 3.266764832394464, 1.584651985338756, 1.109129215989794, 2.2004145894731795, 1.5016798547336032, 0.1180453071636813, 0.34192766515272005, 0.287629420203822, 0.4116504495697362, 0.12260643312973635, 5.575013075556074, 26.84525809969221, 37.707693099975586, 48.56085572923933, 23.9186247416905, 22.514426810400828, 27.190541880471365, 52.404463699885774, 52.191911356789724, 59.38352271488735, 71.46955285753522, 14.533863135746547, 0.6190355856503759, 0.1657394114881754, 0.1956605123622077, 0.02925986171300922, 0.08866966023508992, 0.04219613862889154, 0.05752670778227704, 0.0604797736076372, 0.02481887037200587, 0.01652533870323428, 0.04728320387325116, 0.0472683269929673, 0.03422245310087289, 0.046823024816278896, 0.014093172337327684, 0.020111828842865567, 0.022589348489418626, 0.03166135659973536, 0.04494831398395555, 0.02176155273004302, 0.05464531221826162, 0.038645643075662, 0.0492043061447995, 0.12535293932471955, 0.07629599062991993, 0.02715056775403874, 0.006649714853015861, 0.008731721950295781, 0.06220366646136556, 0.07868238471980606, 0.06759537357304778, 0.061298955364951065, 0.01625747513025999, 0.0673616114737732, 0.049064921481268745, 0.09814232122153044, 0.026253447768145373, 0.15137939846941403, 0.06751678564718791, 0.2907560552869524, 0.4489798093480723, 36.554768085479736, 110.25157642364502, 87.0326908656529, 87.09860842568534, 75.91910280500139, 67.96046938214982, 39.978479044778005, 57.56961556843349, 46.04044532775879, 43.25783770424979, 4.98094470160348, 0.051005762336509566, 0.028260445787704418, 0.5359346962400845, 0.9831623924630029, 1.7176496258803775, 1.9735871723720004, 3.9431830389159064, 1.2012764428343092, 0.2450202437383788, 20.58735087939671, 85.26391574314663, 82.10980878557477, 83.37598596300397, 74.65643446786063, 73.45954472678048, 64.15615694863456, 63.40577234540667, 58.7623815536499, 58.67681448800223, 64.5633908680507, 74.9851051058088, 77.34469945090157, 70.94062818799699, 55.92980248587472, 56.5037966455732, 58.93479415348598, 70.61309705461774, 69.96264839172363, 71.01851749420166, 67.91398593357631, 72.95362554277692, 71.64866352081299, 73.09827314104352, 65.61550099509103, 69.8574526650565, 68.86748027801514, 70.41471903664726, 67.97096811022077, 66.6878581728254, 64.67974540165493, 63.86920329502651, 53.023002760750906, 50.06912899017334, 49.96220316205706, 52.47133663722447, 52.85579088756016, 56.16913666043963, 54.185290472848074, 55.32740061623709, 51.17632096154349, 57.83020428248814, 57.77990974698748, 60.230257987976074, 56.59205961227417, 57.612364360264365, 56.15722744805472, 67.72819805145264, 61.00261279514858, 51.07145527430943, 68.25469085148403, 57.48066125597273, 55.40093340192522, 53.59858805792672, 53.13562263761248, 51.79014219556536, 60.125965527125764, 62.3842134475708, 62.85055569240025, 65.99964605058942, 63.73973751068115, 58.66876152583531, 55.15311895098005, 51.11860574994768, 49.960014479500906, 50.76451512745449, 49.8601792880467, 54.51802928107125, 56.66316747665405, 60.50140448978969, 61.05849020821707, 64.80470180511475, 67.99137496948242, 67.71929046085903, 66.42810671670097, 66.80774239131382, 66.8745423725673, 67.39700521741594, 65.91699722834996, 69.68624210357666, 65.76275416782924, 55.43671662466866, 52.318045479910715, 56.67571939740862, 59.99416514805385, 62.14668927873884, 64.49877956935337, 70.61526489257812, 69.6992769241333, 73.60403946467808, 70.40393543243408, 74.03475829533168, 51.89110994338989, 5.680024674960545, 0.5539160370826721, 0.2859611197241715, 2.0423102847167423, 3.599456523145948, 0.5462690559881074, 1.186508046729224, 0.5076646474855286, 0.6772908568382263, 0.24057288095355034, 4.9359590240887234, 31.721222468784877, 38.13513238089425, 56.43948411941528, 28.64713270323617, 23.13243954522269, 36.380906786237446, 58.36238765716553, 58.096355029514854, 64.7509435926165, 82.44352381569999, 24.617212261472428, 0.6919962306107793, 0.09092471030141626, 0.15409310428159578, 0.09904494243008749, 0.12664657990847314, 0.04467457260138222, 0.04785631151337709, 0.05993082520685025, 0.026854097144678235, 0.05834080731230123, 0.06589526337172304, 0.09602086112967559, 0.026640039702345217, 0.02801148789668722, 0.02002027241646179, 0.03751032506780965, 0.02315201347560755, 0.03996037252779518, 0.010653921752236784, 0.032543933883841546, 0.04979235173336097, 0.11230198320533548, 0.13319677699889454, 0.312194287776947, 0.2480292208492756, 0.11098658878888402, 0.11712499654718808, 0.12394044654709951, 0.17543837747403554, 0.17917261352496489, 0.1207032102559294, 0.10188204662076064, 0.15876405792576925, 0.23919032514095306, 0.08813237585127354, 0.14350175618060998, 0.11395631943430219, 0.1577300112694502, 0.2662840113043785, 0.42155073689562933, 0.8591718428901264, 44.99693012237549, 123.90704481942313, 101.78459194728306, 99.32496438707624, 82.59611320495605, 66.15550109318325, 48.5708715575082, 83.32211657932827, 56.31102582386562, 60.97591086796352, 6.537963918277195, 0.16927076556852885, 0.2753298873347895, 0.7910343876906804, 2.6051855896200453, 1.8916440265519279, 2.951748490333557, 8.664553897721426, 7.785495604787554, 2.846515417098999, 23.84521528652736, 90.59763785770961, 84.70241791861397, 86.64827483040946, 78.91373470851353, 77.02144840785435, 68.01131629943848, 67.43269116537911, 63.07790075029646, 61.72972093309675, 67.95379216330392, 78.72341660090855, 82.72159767150879, 74.06831114632743, 58.91526276724679, 58.53969178880964, 62.98228658948626, 72.11152471814836, 72.68609210423061, 73.3680647441319, 72.11642319815499, 76.13048090253557, 75.60940769740513, 76.17128072466168, 67.39649105072021, 74.15978418077741, 72.93016147613525, 74.90329701559884, 71.67661612374442, 69.858140536717, 67.47177478245327, 66.3217853818621, 56.791049071720664, 51.68310867037092, 52.489898749760215, 55.54411145618984, 55.20761367252895, 59.40303325653076, 58.37283079964774, 57.78794881275722, 53.58133568082537, 61.8807052884783, 62.07186412811279, 63.90056051526751, 58.987774167742046, 60.525827407836914, 60.765693119594026, 69.93270860399518, 65.685622215271, 57.59422608784267, 69.50877121516636, 61.443587166922434, 58.72819641658238, 56.19393825531006, 56.87110274178641, 54.95111397334507, 63.41452707563128, 64.93442467280796, 66.18752534048897, 67.92564501081193, 67.38472775050572, 61.63754613058907, 58.45251274108887, 54.49325200489589, 53.158645493643625, 54.35700477872576, 52.05506658554077, 57.233649321964805, 58.02433000292097, 63.97587203979492, 62.454105377197266, 65.71755613599504, 69.57919815608433, 69.78513581412179, 70.47610637119838, 71.14214679173061, 70.9411701474871, 72.02048247201103, 67.06923784528459, 74.1199015208653, 68.29650511060441, 59.02289036342076, 55.621830531529014, 61.150942938668386, 63.1997652053833, 65.64933177403041, 68.61044556753976, 73.2729994910104, 71.90994358062744, 77.3814206804548, 73.43361404963902, 77.02436665126255, 54.04803575788225, 4.574312669890268, 3.8757846440587724, 4.856516361236572, 6.3064026066235135, 4.209185268197741, 0.4257703833281994, 2.5805865781647817, 1.2317626412425722, 1.7151350293840681, 0.334194510110787, 8.910034622464861, 46.81776114872524, 51.74412080219814, 60.55019474029541, 33.421710695539204, 32.26435620444161, 40.21524933406285, 67.4521461214338, 69.85056005205426, 73.90434060777936, 93.72698838370187, 25.995175531932286, 0.8003471993974277, 0.2457238845527172, 0.34251315944961136, 0.2079565982733454, 0.1685076036623546, 0.21333250908979348, 0.25017672990049633, 0.18925576603838376, 0.10142559611371585, 0.11884325077491147, 0.1618874224701098, 0.17518590816429683, 0.1909572333097458, 0.14539910294115543, 0.11652190105191298, 0.09454907117677586, 0.1723348397229399, 0.16640151238867215, 0.0963083157049758, 0.09215915549014296, 0.16587241792253085, 0.20070232610617364], [0.015200443100184202, 0.023636470515547053, 0.013630431810660022, 0.06828889064490795, 0.027749809170407907, 0.03568302347723927, 0.019392298434727957, 0.05250982002222112, 0.03363912333069103, 0.06856309343129396, 0.08791778915162597, 0.07170353670205389, 0.1045852554962039, 0.02558490926665919, 0.0926532850467733, 0.04014377715066075, 0.05613872368953057, 0.06229649005191667, 0.29680063522287775, 63.04464667184012, 83.77600070408413, 73.67875344412667, 62.18718338012695, 40.476800373622346, 23.607727595738, 33.85839108058384, 40.67934383664812, 53.23777157919747, 26.73740816116333, 0.03317774665941085, 0.05350162787362933, 0.07199999543705157, 0.22549751560602868, 0.05811248706387622, 0.3163601670946394, 1.5858868105070931, 1.943960270711354, 2.014397199664797, 2.178313455411366, 55.80316809245518, 83.8845385142735, 80.05747073037284, 76.92775889805385, 77.46767561776298, 72.6379827771868, 68.2191230228969, 58.60203102656773, 56.43125397818429, 55.25137690135411, 52.92363657270159, 59.450475556509836, 64.4579450062343, 56.596874713897705, 54.08948176247733, 52.16860709871565, 58.91941084180559, 68.97488553183419, 70.25853742871965, 69.59384495871407, 69.876129422869, 70.01940822601318, 69.14086409977504, 66.99396106175014, 67.57174546377999, 67.05067920684814, 64.94051824297223, 66.67428139277867, 63.210444586617605, 65.85683277675084, 56.478786604745046, 50.42490455082485, 47.28630944660732, 47.58051354544503, 47.777887548719136, 50.74392761502947, 50.70171383449009, 50.3820480619158, 48.66400868552071, 49.18539455958775, 46.716122899736675, 53.247971534729004, 60.615146500723704, 58.73679828643799, 55.7057717187064, 54.073136125292095, 55.31416777202061, 62.7094794682094, 61.68651008605957, 40.9165483883449, 62.42613887786865, 61.188372884477886, 60.99782548631941, 57.76842784881592, 55.97908953257969, 52.22644737788609, 56.28156893593924, 60.07639013017927, 61.57156603676932, 59.155427251543315, 58.24787439618792, 52.85239321844918, 49.23064122881208, 48.516140597207205, 49.71977356501988, 48.794808523995535, 47.737317017146516, 50.872465814862935, 55.658867904118125, 56.26198196411133, 63.97628198351179, 66.48677035740444, 62.408219473702566, 60.540439469473704, 63.395898955208914, 61.80655411311558, 59.014802660260884, 60.07140132359096, 63.048502922058105, 63.647444588797434, 58.89024230412075, 49.552460942949565, 50.268094130924766, 52.46544109072004, 57.01895693370274, 57.645746980394634, 60.92750971657889, 63.91076741899763, 66.92399270193917, 65.9266413279942, 71.50735800606864, 65.82435689653668, 62.381128447396414, 46.386173793247764, 5.138594116483416, 0.7444554013865334, 0.8385732024908066, 1.2166918899331773, 1.5357469809906823, 0.25177326851657456, 0.44671730218189104, 0.6304791601640838, 0.06047036911227873, 0.04108117327892354, 10.999001843588692, 28.431000300816127, 35.23966864177159, 28.988831213542394, 28.240774256842478, 22.541045359202794, 36.09660734449114, 49.305504594530376, 59.468054498944966, 62.617332458496094, 53.38281175068447, 0.6302946529218129, 0.11329401497329984, 0.016401358480964388, 0.043290730964924605, 0.04656995839572378, 0.09903705106782061, 0.05832767765969038, 0.01605302744012858, 0.04521572802747999, 0.04652049319286432, 0.03661987338481205, 0.08126908913254738, 0.016891672974452376, 0.06348177537854229, 0.05599394127992647, 0.1029686186728733, 0.006977605874583657, 0.04140936031139322, 0.09193483181297779, 0.024091947324840084, 0.053935293174747906, 0.08134406725210802, 0.08670741160001073, 0.026442134786131125, 0.0325556555762887, 0.07320549432188272, 0.029259420665247098, 0.009091107174754143, 0.023440797979544317, 0.060621539929083416, 0.033659652407680235, 0.13954224650348934, 0.08693398122808763, 0.08161637692579202, 0.07373039544160877, 0.0277637700284166, 0.08593614120036364, 0.02350375585124961, 0.04733968173552837, 0.012524358662111419, 0.5675791267837796, 79.01702662876674, 91.73143100738525, 84.12701674870083, 71.40300301143101, 46.66916002546038, 33.86113214492798, 36.76917559759957, 41.213399750845774, 55.32675095966884, 29.964693546295166, 0.047140379037175856, 0.05082974695999708, 0.32053386313574656, 1.7051404799733842, 0.6809850728937558, 2.2903292732579366, 4.337389085974012, 1.382634196962629, 0.24532987283808844, 3.607526638678142, 62.18294497898647, 86.7748223713466, 83.16456617627824, 81.07783453805106, 80.01516314915249, 76.75082996913365, 72.39658846173967, 62.11169120243618, 58.75541945866176, 56.72694499152047, 56.93465444019863, 63.25155012948172, 68.78522055489677, 58.48852525438581, 56.22631686074393, 54.471514565604075, 61.63942214420864, 72.08089011056083, 72.80509390149797, 72.45503670828683, 72.84556021009172, 73.63928072793144, 72.45057596479143, 70.59643527439663, 72.58314064570835, 70.8098978315081, 68.94181210654122, 69.59154510498047, 67.38226114000592, 68.35138893127441, 59.10414259774344, 52.038946764809744, 49.75279835292271, 50.04218735013689, 50.173261642456055, 53.71399416242327, 51.823497022901265, 53.4267452103751, 51.04063653945923, 51.89992025920323, 49.25550535746983, 56.50462348120553, 64.05361543382917, 61.318380628313335, 58.67013726915632, 56.41694416318621, 55.26367521286011, 64.99622195107597, 64.6248059953962, 44.07006474903652, 65.39351994650704, 64.07930987221854, 64.73676231929234, 60.60389041900635, 59.220497131347656, 54.845546518053325, 59.15325941358294, 63.034002031598774, 63.80794102805001, 62.18766975402832, 60.12212317330496, 55.765321254730225, 51.74404437201363, 51.46972949164254, 52.61885731560843, 51.0089180128915, 51.82766594205584, 52.20275749479021, 58.69438648223877, 60.03963415963309, 65.86635875701904, 68.28682626996721, 64.00404003688267, 63.28366470336914, 66.15795380728585, 64.23439366476876, 63.1591807774135, 64.0782606942313, 66.06864166259766, 65.88402802603585, 61.54526710510254, 52.50253404889788, 54.32538005283901, 53.884645393916536, 59.443895612444194, 60.58945206233433, 64.11080605643136, 64.90544373648507, 70.35259519304547, 69.47500991821289, 74.78097397940499, 67.39358670370919, 66.19372313363212, 51.44845758165632, 8.69471081665584, 0.4451850615441799, 0.609449134341308, 1.2847701225961958, 3.0322776777403693, 1.2785731979778834, 0.9090600173388208, 0.9095659330487251, 0.14940845780074596, 0.21544948406517506, 12.054853575570242, 33.4893479347229, 38.71015139988491, 23.562084879193986, 24.18032169342041, 31.86875009536743, 42.81251376015799, 56.70661456244332, 67.3287113734654, 69.5447142464774, 67.14834308624268, 1.7970440856048038, 0.2383463361433574, 0.07299897540360689, 0.01600658002176455, 0.02987634131152715, 0.07162532875580446, 0.04127279156818986, 0.05102349924189704, 0.029484483945582594, 0.08915644125746829, 0.045065222174993584, 0.08322771439062697, 0.05019162209438426, 0.08532768527844123, 0.04646796440439565, 0.01856388520848538, 0.06002756394445896, 0.03277513451342072, 0.07644704609577145, 0.036502870198871405, 0.018498474432687675, 0.033695607978318415, 0.14324547350406647, 0.10736624484083482, 0.13543487047510488, 0.22145959442215307, 0.11202385848654167, 0.10989779114191021, 0.12692108803561755, 0.12191026977130345, 0.12716888902442797, 0.2172242331185511, 0.18334639099027428, 0.13395912466304644, 0.2321922406554222, 0.10615962637322289, 0.26301485672593117, 0.14797822811773845, 0.16491860124681676, 0.10295606577502829, 0.8741949881826128, 91.32938044411796, 103.91927310398647, 95.36287920815604, 80.60029874529157, 56.188268525259836, 31.81874738420759, 48.263309546879356, 57.02543612888881, 75.02755165100098, 41.941338198525564, 0.2083519941994122, 0.17594787584883825, 0.37102121114730835, 2.62061037336077, 1.196767496211188, 2.799996141876493, 6.845183730125427, 8.529027547155108, 7.981426988329206, 4.07555273600987, 68.54987117222377, 85.87018081120083, 88.25703988756452, 83.70936053139823, 84.93365396772111, 79.79236221313477, 76.04388550349644, 65.82145254952567, 62.905682700020925, 59.10524041312081, 60.65126323699951, 65.96338340214321, 70.98811912536621, 61.377808570861816, 60.200234821864534, 56.83931820733206, 65.48568780081612, 77.74263668060303, 76.50164672306606, 74.36413070133754, 73.81224918365479, 75.59246104104179, 75.86566420963833, 73.63886383601597, 73.7288430077689, 74.87670625959123, 72.19401373182023, 72.90388338906425, 70.5925373349871, 73.07859584263393, 63.300486292157856, 55.869895117623464, 53.917343616485596, 53.50034400394985, 51.822656290871755, 56.60960381371634, 54.762032645089285, 54.953535420554026, 53.83986077989851, 54.735021523066926, 52.44082014901297, 59.0528370993478, 68.04621015276227, 64.5614801134382, 61.55122865949358, 59.957645416259766, 59.88179888044085, 70.14535127367292, 68.03990118844169, 48.152614321027485, 68.32414504459926, 67.10347161974225, 67.40241091591972, 63.59363079071045, 60.750900404793875, 57.674724442618235, 63.16641385214669, 65.46353694370815, 66.77254281725202, 63.80509921482631, 63.345614842006135, 60.301261629377095, 52.57057775769915, 53.832335880824495, 56.58870710645403, 54.4798697744097, 54.59252439226423, 55.53221961430141, 62.39563628605434, 63.52694198063442, 69.17681407928467, 72.28174863542829, 68.1856118610927, 67.07459490639823, 71.03845187595913, 69.68490804944719, 67.20771544320243, 67.64759199959892, 69.22834192003522, 68.73821599142892, 65.67336559295654, 55.59526409421648, 56.96489300046648, 56.58214800698416, 62.81657900129046, 63.78057902199881, 67.1789915902274, 68.02378831590924, 71.84299768720354, 73.93112591334751, 78.01057311466762, 70.25045667375836, 67.957273210798, 54.30768993922642, 6.983108511992863, 3.000605182988303, 3.6732850415366034, 4.49862550837653, 6.22250006880079, 1.5526252410241534, 1.8983457812241145, 1.8489668880190169, 0.41108427995017593, 0.3106720351747104, 19.171566826956614, 44.58300161361694, 47.85301494598389, 43.70556572505406, 41.26521246773856, 33.05310181209019, 52.51533610480172, 66.15454918997628, 77.3354583467756, 80.04507514408657, 71.8205133165632, 1.3734039493969508, 0.289454923676593, 0.10469575492399079, 0.09632981847971678, 0.21263401157089643, 0.13631494396499225, 0.13026406722409384, 0.10632088700575487, 0.1397277715482882, 0.16980820601539953, 0.12248768950147287, 0.24127847594874247, 0.09151478470968348, 0.1830425158675228, 0.08838971704244614, 0.10823795199394226, 0.1432699007647378, 0.08703201596758195, 0.15093901567161083, 0.19053811579942703, 0.1267323467348303, 0.07926067297479936], [0.04052185686305165, 0.01389113175017493, 0.006528702373283782, 0.09415263709213052, 0.08643792463200432, 0.053796312239553244, 0.09021111537835427, 0.04436790191435388, 0.04582146641665271, 0.041798313547457965, 0.09152327996811696, 0.02076710368107472, 0.04927228856831789, 0.14133608953229018, 0.1485157228474106, 0.020189933312524642, 0.0826425322198442, 0.15341713412531785, 5.855536605630602, 77.52988283974784, 77.57879815782819, 77.35915170397077, 58.34043829781668, 56.862935134342735, 35.300045013427734, 61.869421413966585, 54.73828717640468, 48.84873349325997, 6.114264939512525, 0.10835271262164627, 0.10369080384927136, 0.09416059630789927, 0.7731328425662858, 0.5051984712481499, 1.5079100004264285, 2.6897907640252794, 1.6767415638480867, 1.1437673973185676, 27.540550436292374, 85.43745395115444, 77.11706951686314, 81.95954009464809, 78.6859519141061, 76.73418208530971, 73.16128635406494, 72.74355370657784, 69.37906224387032, 58.77085140773228, 55.42283064978463, 53.87309748785836, 52.69756303514753, 53.429371629442485, 53.56573697498867, 53.869724137442454, 51.12907668522426, 58.32932812826974, 69.43894181932721, 69.43220206669399, 69.67724418640137, 68.56993756975446, 68.4766788482666, 66.69836384909493, 67.490889276777, 67.20979295458112, 66.2379275730678, 65.4590345110212, 64.85158824920654, 63.64251831599644, 54.71814087459019, 46.05339329583304, 46.87502472741263, 47.80067416599819, 48.18851913724627, 46.05840294701712, 49.12436853136335, 47.84332568304879, 48.80429628917149, 48.83940553665161, 49.022573947906494, 46.45323780604771, 54.569734300885884, 63.658471379961284, 61.559121813092915, 58.49942697797503, 55.90432344164167, 53.76853404726301, 59.797357422964915, 61.17187091282436, 41.069380964551655, 61.736815043858115, 62.05083193097796, 62.86379895891462, 56.946838106427876, 57.41789470400129, 52.28051478522164, 55.755510398319785, 60.037737301417756, 61.53831890651158, 58.47274589538574, 56.63016700744629, 51.9867970602853, 47.125691413879395, 52.073712076459614, 49.695246423993794, 49.28714745385306, 48.98755502700806, 47.297760077885215, 54.5151492527553, 57.437276703970774, 59.840575218200684, 61.809534890311106, 61.07601356506348, 61.05414758409773, 60.30673680986677, 61.167681149074006, 57.737049783979145, 57.791356904166086, 57.84302370888846, 59.12266649518694, 51.60370118277413, 50.323780468532014, 51.16220917020525, 49.77047804423741, 53.67596319743565, 56.83289459773472, 59.493074962071006, 63.77535397665841, 69.39748191833496, 68.93211242130825, 67.17141805376325, 65.76891721997941, 62.414778573172434, 62.80696964263916, 49.1752849306379, 8.605154616492134, 1.2324417190892356, 1.0839954103742326, 1.5652786706175124, 1.3124863782099314, 0.1906345627669777, 0.11578186361917428, 0.34277404259358135, 0.055090373515018394, 0.9082141827259744, 21.788725682667323, 30.468764509473527, 44.43517868859427, 35.64151075908116, 21.282827343259537, 37.588847637176514, 50.64317873546055, 62.923338072640554, 52.490506717136924, 64.77257333483014, 14.015932253428868, 0.3930237405002117, 0.14870412488068852, 0.1343668427850519, 0.029392857969339405, 0.016484701240967427, 0.019357794929029684, 0.04193773892308984, 0.06447150012744324, 0.06636828370392323, 0.012486794963479042, 0.016270543714719157, 0.08345320514802422, 0.020564209836136018, 0.017323158481823545, 0.08069704339972564, 0.04677545611879655, 0.013037366759298103, 0.1331856490245887, 0.020174664578267505, 0.051089758186468055, 0.0127563947379323, 0.04440990323200822, 0.06986220979264804, 0.057954503755484305, 0.004376683184610946, 0.033511524820434194, 0.052932343778333495, 0.008452265606527882, 0.04375496766130839, 0.06496267127139227, 0.03374432339998228, 0.061944215026284964, 0.028219324869236777, 0.01913457896028246, 0.033689443487674, 0.11902688949235848, 0.04906575268666659, 0.2046044860035181, 0.2628144174814224, 8.888863461358206, 94.84298024858747, 83.323547908238, 88.88011264801025, 71.3571310043335, 70.65160397120884, 35.950903620038716, 43.62449761799404, 45.01016991479056, 54.18294545582363, 6.5319841248648505, 0.027856398540149842, 0.1314808569316353, 0.5523945987224579, 1.6459283658436366, 1.6048629922526223, 2.422707872731345, 5.464925382818494, 0.8292745043124471, 0.7986187807151249, 34.49214322226388, 89.55026640210832, 77.90683650970459, 84.58543804713658, 82.4524175098964, 80.78985949925014, 76.11812005724225, 77.04084083012172, 71.1636723109654, 63.70340538024902, 58.346580505371094, 57.50386823926653, 54.55908271244594, 56.63052831377302, 57.71481554848807, 56.896783283778596, 54.09870202200753, 61.874180930001394, 71.38914830344063, 72.56355367388043, 69.63992541176933, 71.2170900617327, 71.86052104404995, 70.15676021575928, 68.48846994127545, 70.01919283185686, 69.45399161747524, 68.82145541054862, 67.64761284419468, 66.75059345790318, 56.679196970803396, 50.548863887786865, 49.2042623928615, 49.48527533667428, 50.119743142809185, 48.92230796813965, 52.59025853020804, 50.34985705784389, 51.10028682436262, 51.74543053763253, 50.021172523498535, 48.39675317491804, 55.84456893375942, 65.67123249598912, 64.94427027021135, 61.93201773507254, 59.03130463191441, 57.557553495679585, 61.75876440320696, 63.71519647325788, 44.07794400623867, 65.5321295601981, 64.52031203678676, 64.46369811466762, 60.100326674325125, 59.699443408421104, 55.586981841496055, 59.651862144470215, 61.0809884752546, 62.67182718004499, 61.52714620317732, 58.57134083339146, 52.08697271347046, 50.54439272199358, 54.52936526707241, 52.17468677248274, 51.29397133418492, 51.92899152210781, 49.87830366407122, 57.26880373273577, 61.750405720302034, 65.12943281446184, 66.33466039385114, 64.1192272731236, 64.42935316903251, 64.8822853905814, 63.63065774100167, 60.96390438079834, 59.519700459071565, 59.57337529318673, 60.93670218331473, 54.849500043051584, 51.97705915996006, 52.909149578639436, 52.102515833718435, 55.52289513179234, 59.31196321759905, 63.18170683724539, 67.00577994755336, 73.47912475040981, 69.29890087672642, 69.30943434579032, 67.48194694519043, 65.61539677211216, 64.63289369855607, 55.46661819730486, 13.221024462154933, 1.2769680555377687, 0.5865272443209375, 0.6216988084571702, 2.1106770847524916, 1.2183061518839426, 0.29058278458459036, 0.8364258291465896, 0.07832966864641223, 0.6161394353423799, 27.268509353910172, 33.854972566877095, 34.72468900680542, 25.690811429704937, 22.3954302242824, 45.233644826071604, 56.254175662994385, 70.53985609327043, 58.75948415483747, 76.35747855050224, 22.201679706573486, 0.6232893488236836, 0.08859230724296399, 0.13574623662446225, 0.03760622920734542, 0.0679022546059319, 0.044716940327946625, 0.041502774227410555, 0.057516394049993584, 0.13256051471190794, 0.030995170918426344, 0.09323627554944583, 0.03445499383711389, 0.012349160920296396, 0.07200813107192516, 0.06890358908900193, 0.014369950164109468, 0.025343008139835935, 0.016511866390439014, 0.029000830969640186, 0.05192675827337163, 0.010330192694839622, 0.12423102238348552, 0.19006349412458284, 0.10695104926292386, 0.11753773582833153, 0.1637349511895861, 0.1446002365222999, 0.161985416497503, 0.13525526225566864, 0.14502391378794396, 0.17055500165692397, 0.17920997366309166, 0.1677517020808799, 0.05191262099625809, 0.23866997020585196, 0.1938510358865772, 0.14278401540858404, 0.2801289755318846, 0.34584205225110054, 10.615986738886152, 109.05508272988456, 93.60240718296596, 98.57291221618652, 76.77372428349086, 76.8856041772025, 48.06933321271624, 81.57265050070626, 74.11025742122105, 72.70609596797398, 10.339860115732465, 0.24018554602350506, 0.36137746434126583, 0.807936423591205, 3.6954940898077826, 3.678947389125824, 7.355157188006809, 10.409081544194903, 9.329496502876282, 2.189095973968506, 41.407052993774414, 89.74530233655656, 80.80269282204765, 85.74063859667096, 84.82008566175188, 83.32784884316581, 80.91148771558488, 78.61204392569405, 75.74605097089494, 64.98124858311245, 61.75729833330427, 59.44313131059919, 57.723010948726106, 58.62439727783203, 61.298786708286826, 59.04000377655029, 56.93186126436506, 64.44875253949846, 75.49752085549491, 74.95475537436349, 72.1049586704799, 73.42915330614362, 75.9714435849871, 73.20294775281633, 73.01315770830426, 73.13642569950649, 72.58904661451066, 70.25353472573417, 71.17483806610107, 69.89293711526054, 59.66349342891148, 51.35008151190621, 52.13158362252371, 53.74401038033621, 52.83714539664132, 50.33395957946777, 54.57013382230486, 53.95583316258022, 53.77590261186872, 55.49700961794172, 52.73818220411028, 52.3566392489842, 58.72020598820278, 69.93076310838971, 69.02687890189034, 64.44376373291016, 62.271631785801475, 59.951899256025044, 64.48061003003801, 67.40422439575195, 47.67188235691616, 66.89699895041329, 67.2872792652675, 68.31245817456926, 64.0100849696568, 62.01781409127371, 58.08695411682129, 61.63302285330636, 64.59286512647355, 66.6973077229091, 65.71537440163749, 63.15220478602818, 56.99594797406878, 52.90562684195382, 57.5601486478533, 54.76674352373396, 53.36705323628017, 55.32209914071219, 52.358501366206575, 60.95267609187535, 64.75840595790318, 67.79068320138114, 69.29988057272774, 65.51180607931954, 67.27217388153076, 67.36317443847656, 66.923825945173, 63.84485680716378, 62.18250029427664, 63.00613975524902, 63.89958776746477, 57.885202748434885, 54.50030442646572, 57.012488160814556, 56.236742632729666, 59.165613310677664, 62.74705532618931, 66.28318813868931, 69.27683339800153, 75.46960299355644, 72.01782826014927, 73.1422621863229, 69.7440024784633, 66.76913819994245, 66.48021820613316, 54.79706546238491, 10.906054922512599, 2.669224747589656, 4.092780360153743, 4.110712792192187, 3.4551220280783514, 1.1622367948293686, 0.8793333981718335, 1.3458461995635713, 0.14943531421678408, 2.2267393597534726, 37.176072529384065, 46.14126368931362, 59.93382699148995, 50.68792513438633, 30.65628249304635, 53.36402382169451, 64.45458902631486, 81.26053742000035, 66.9513338633946, 87.18844168526786, 23.248976469039917, 0.6163039122309003, 0.23818090930581093, 0.38633281524692265, 0.12977938966027328, 0.24350930910025323, 0.16627096225108418, 0.1695204528846911, 0.24878068481172833, 0.18219795690051147, 0.08879594238741056, 0.1418747649128948, 0.19278498951877865, 0.10420964565128088, 0.08838830568960734, 0.1540402328329427, 0.22467671893537045, 0.10538550612649747, 0.16516705362924508, 0.09375017761651959, 0.13750793066407951, 0.13739024555044516], [0.020098095294088125, 0.0212345311883837, 0.0478878328576684, 0.022522141292159046, 0.03424929255353553, 0.04263805830851197, 0.10769113419311387, 0.04367269189762218, 0.09284183635775532, 0.04273494293114968, 0.044555740763566325, 0.009127587761863001, 0.08466987271926232, 0.07125359334583793, 0.12400424240955285, 0.04506201609703047, 0.09244462874318872, 0.07521646855665104, 30.687785625457764, 92.07922308785575, 73.15925053187779, 76.20890522003174, 55.68709148679461, 20.63550363268171, 38.71347263881138, 97.17485128130231, 58.39042363848005, 28.862942014421733, 0.4846698013799531, 0.03983021933319313, 0.06999995918678385, 0.28179619035550524, 0.39649325289896553, 0.4176596371190888, 2.013596636908395, 3.739846612725939, 1.353436780827386, 9.106788499014717, 78.57633713313511, 81.2094612121582, 80.5421701158796, 77.82341643742153, 76.00919314793178, 76.0273904800415, 76.02909278869629, 75.04308782305036, 71.99600396837506, 67.55623708452497, 64.16384860447475, 56.01799597058977, 53.07470778056553, 52.87572526931763, 53.73899030685425, 51.83907488414219, 50.100784982953755, 54.92333507537842, 67.86570984976632, 67.55157484327043, 67.80744225638253, 65.82495444161552, 66.34816769191197, 62.7422958101545, 63.7197197505406, 64.70560659681047, 61.611823899405344, 63.71569674355643, 60.27375371115548, 53.111147608075825, 47.31438364301409, 46.01206193651472, 47.33979320526123, 45.721359729766846, 46.17282935551235, 46.66748203550066, 47.69896990912301, 48.2625105040414, 50.16849170412336, 46.806539808000835, 49.823162760053364, 46.658748149871826, 54.99210139683315, 62.94344615936279, 63.196277209690635, 62.11065592084612, 64.81306743621826, 58.769913400922505, 62.33174760001046, 58.10781955718994, 46.28717238562447, 64.43862901415143, 58.788555417742046, 59.2340669631958, 55.015815598624094, 53.18508686338152, 53.7678496497018, 59.865109307425364, 59.5212915965489, 56.06157854625157, 53.18290165492466, 48.720813683101106, 46.76665367398943, 45.56985425949097, 49.37314878191267, 50.05108451843262, 47.07054703576224, 46.72107696533203, 44.935091154915945, 49.30980552945818, 55.96129519598824, 61.08259350912911, 59.04602091653006, 64.91107872554234, 64.39509160178048, 62.12344755445208, 58.665912764413015, 56.13100494657244, 54.10377073287964, 53.772088050842285, 49.37693902424404, 49.8247469493321, 48.226081098829, 48.75510304314749, 47.047555446624756, 50.31647791181292, 55.04069014957973, 58.56483037131173, 65.15004117148263, 66.82938602992466, 69.6623125076294, 65.80202538626534, 58.59773703983852, 64.44131101880754, 64.15641403198242, 68.12418978554862, 54.40090002332415, 17.201856749398367, 0.3984796234539577, 1.0455339827707835, 0.5200828154172216, 0.4543450671647276, 0.5694011290158544, 0.20052973393883022, 0.04514778292338763, 0.05642592042152371, 7.244078942707606, 29.608164106096538, 27.365959576198033, 52.067434379032676, 33.39708627973284, 21.996681792395457, 44.186631202697754, 40.49953140531267, 52.05808905192784, 58.9552218573434, 43.07429756437029, 0.9019504902618272, 0.07084099655704838, 0.012784936465322971, 0.05228417320176959, 0.026695184243310775, 0.04170724057725497, 0.03356401968215193, 0.03783468855544925, 0.020098641514778137, 0.046460320707410574, 0.04101384224902306, 0.017602333233558705, 0.01251177692652813, 0.01730308571963438, 0.033674247695931366, 0.035956890388791046, 0.06706498310502086, 0.007852887634986212, 0.04030718873920185, 0.04810675200341003, 0.05439097015187144, 0.038599166819559674, 0.034978168085217476, 0.06526336406490632, 0.02231693364280675, 0.05748406185635498, 0.037362112663686275, 0.039937512683016915, 0.039277264183121066, 0.06949957353728158, 0.05227831405188356, 0.04131798878578203, 0.057330068333872726, 0.06508623928363834, 0.024833888048306108, 0.1123547868004867, 0.0662001155849014, 0.08526094457400696, 0.04441631878060954, 41.288148471287315, 105.22356115068708, 78.06120463779995, 83.63564709254673, 61.236343247549875, 32.816765785217285, 36.210516112191335, 64.66575867789132, 59.688444410051616, 32.72319786889212, 0.5083057816539491, 0.0391766408325306, 0.6732472223894936, 1.4389136284589767, 2.077114245721272, 1.1734947221619743, 4.120172764573779, 0.5357024201325008, 0.3340346472603934, 13.320246475083486, 85.27249676840646, 83.51103809901646, 84.97209140232631, 78.34055696214948, 78.9583351952689, 79.08688381740025, 78.64727129255022, 76.58508763994489, 73.69750663212368, 71.86738586425781, 68.2083602632795, 59.04085840497698, 56.08250652040754, 56.51474353245327, 56.864686080387656, 53.6796909059797, 53.52159506934029, 56.77162538255964, 71.48212214878627, 69.37241976601737, 69.89509105682373, 68.14629200526646, 69.69699791499546, 66.00293949672154, 65.64699023110526, 67.21192605154855, 65.52479226248605, 65.43907233646938, 61.18708746773856, 52.873981271471294, 49.45778478894915, 47.68167584283011, 49.43932689939226, 47.6204274722508, 49.38047565732683, 48.65492044176374, 49.43338966369629, 50.09684535435268, 52.519713469914024, 50.20330565316336, 51.76221738542829, 49.2393924849374, 58.116278988974436, 64.89383329663957, 66.48055171966553, 65.00122465406145, 68.53490475245884, 63.040338788713726, 64.37746402195522, 60.034992762974326, 47.260184219905305, 67.27281311580113, 60.931810651506694, 60.95680332183838, 57.37749440329415, 56.70112548555647, 56.96821076529366, 61.22407272883824, 61.691908836364746, 59.94613919939314, 55.44125379834856, 48.81329073224749, 49.61121143613543, 47.360769816807334, 51.778476170131135, 51.63374866758074, 48.85885354450771, 48.889967577798025, 47.069070543561665, 53.17427199227469, 56.950489384787424, 62.99772548675537, 62.9703426361084, 65.77983283996582, 66.51727294921875, 64.68758991786412, 61.2340156010219, 58.29056412833077, 56.2757637160165, 54.65027434485299, 51.651108741760254, 51.613008294786724, 50.815087590898784, 51.298678738730295, 50.16629607336861, 53.42700924192156, 58.48861558096749, 61.48613098689488, 67.49432168688092, 69.17661952972412, 73.09738377162388, 67.02492223467145, 61.21329607282366, 64.94545841217041, 66.38013635362897, 70.6973717553275, 60.82321030752999, 23.172754730497086, 1.2044988870620728, 0.9308771980660302, 0.2796179572386401, 1.5112391646419252, 0.6400265278560775, 1.0558889699833733, 0.29724380001425743, 0.2727521870817457, 11.376890914780752, 42.93782799584525, 30.548105989183696, 39.294950008392334, 28.33275624683925, 39.0622478893825, 57.00454289572579, 47.17688921519688, 59.562021936689106, 66.98380974360875, 58.683491706848145, 2.226380007607596, 0.02956494123541883, 0.03541017776089055, 0.09016839481358017, 0.004406684610460485, 0.05239961914984243, 0.03963330847078136, 0.05024186082716499, 0.034782376805586476, 0.05061410174572042, 0.03719130165076681, 0.018536050005682876, 0.023379085219598243, 0.015106133517942258, 0.03775773250630923, 0.04492660764870899, 0.021896727083783065, 0.04063417476468852, 0.014272465037980249, 0.07075983698346786, 0.01281965455772089, 0.17187218740582466, 0.06886325018214327, 0.1964084343718631, 0.15958283256207192, 0.18104185536503792, 0.0920366392071758, 0.14642264587538584, 0.11913899704813957, 0.15353359787591866, 0.10811951370643717, 0.1617244112172297, 0.16884740042899335, 0.14339893098388398, 0.21472917843077863, 0.29537924006581306, 0.1395440785480397, 0.1798081701355321, 0.19165427876370295, 49.33685834067208, 116.50658798217773, 92.7756757736206, 93.9481564930507, 73.84862300327846, 31.205061640058243, 52.425749506269185, 126.54698508126395, 76.92947510310582, 47.253823144095286, 0.8785959120307649, 0.15470062382519245, 0.41244267991610933, 3.41760544691767, 4.408121747629983, 2.9273448969636644, 10.02544023309435, 14.96074308667864, 4.491086278642927, 17.823819535119192, 87.54987307957241, 84.64467144012451, 86.92120007106236, 83.21577439989362, 82.05917031424386, 82.70249707358224, 80.89668805258614, 82.07556806291852, 77.06194250924247, 75.06443268912179, 70.6831557410104, 63.17714881896973, 58.69793701171875, 58.30902549198696, 60.29209695543562, 57.90565824508667, 56.37447329929897, 59.301360266549246, 76.32603100367955, 71.74835627419608, 70.70650863647461, 72.36923340388707, 71.94210679190499, 69.17258262634277, 68.16432258061, 71.36166817801339, 68.39940098353794, 69.4533245904105, 65.3216130392892, 56.82331650597708, 52.98917545591082, 51.03609241758074, 51.69587598528181, 52.41065107073103, 52.4382632119315, 51.738961764744346, 53.40442412240164, 53.01534932000296, 56.39401510783604, 52.90153782708304, 55.233787536621094, 52.21489599772862, 60.76403944832938, 67.16474083491734, 68.66646889277867, 68.7520637512207, 70.55105658939907, 64.60833876473563, 68.78331674848283, 63.79497568947928, 52.7861247743879, 71.88871683393205, 64.81146935054234, 63.56660229819161, 61.874097551618306, 60.197775159563335, 60.711830684116904, 65.70196437835693, 64.52930995396206, 61.839099475315635, 58.2519599369594, 52.82584067753383, 51.88885872704642, 50.641226291656494, 55.34900951385498, 55.15102406910488, 51.9396014213562, 51.8605135508946, 50.4386967250279, 55.80439097540719, 61.23940740312849, 67.33867509024483, 65.66183853149414, 69.41462312425885, 72.76630905696324, 68.38405241285051, 64.51523290361676, 62.64929417201451, 59.85343633379255, 57.29502623421805, 53.553310121808735, 54.36056225640433, 52.72153432028634, 54.68258694240025, 51.756499017987935, 56.317786421094624, 60.30310985020229, 64.44296469007219, 70.94510282788957, 72.98000090462821, 73.39818518502372, 67.04416874476841, 63.023975781032014, 66.55715560913086, 68.96557494572231, 73.45623738425118, 62.022782053266255, 21.744279793330602, 1.6540021726063319, 4.189629129001072, 3.7060210449354987, 3.5511708855628967, 1.8700896288667406, 1.370805214558329, 0.4376774515424456, 0.3125819484038012, 14.709880113601685, 49.00196211678641, 39.491639614105225, 73.11098834446499, 45.384670870644705, 34.69887644904, 60.81816591535296, 58.45256832667759, 67.94954681396484, 77.66534491947719, 65.35166399819511, 1.8201466287885393, 0.08268823833870036, 0.13667093057717594, 0.10133265717221157, 0.09569171736282961, 0.10247959848493338, 0.19306557731969015, 0.08944285088883978, 0.10721252273236002, 0.1176171244255134, 0.1021208366645234, 0.16393673393343175, 0.08528377727738448, 0.1825038269162178, 0.19566623919776507, 0.09787498520953314, 0.1202540472149849, 0.10619987028517894, 0.17256750938083443, 0.14124524726399354, 0.08448892778583936], [0.03421737426625831, 0.03217054284842951, 0.10789878626487084, 0.07483646859015737, 0.019307788594492843, 0.03338083219049232, 0.04084738064557314, 0.06179523587759052, 0.15768657145755632, 0.09894860402813979, 0.0339262997066336, 0.04154096896361027, 0.05456372856029442, 0.06192776055208274, 0.09073117854339735, 0.020166739289249693, 0.03187161424596395, 1.2890887537172862, 70.87902545928955, 72.22415501730782, 80.03446524483817, 61.692131178719656, 57.58117389678955, 29.77150583267212, 69.25912938799176, 102.41754504612514, 42.228583676474436, 11.62424852166857, 0.3430838888244969, 0.3084230715675013, 0.25920876381652697, 1.165332434432847, 1.4704902597836085, 0.33722511891807827, 1.658911183476448, 1.8410250970295496, 0.4065616269196783, 60.77917957305908, 83.49958746773856, 80.62263720376151, 77.3246191569737, 77.91022723061698, 72.5420698438372, 71.48059354509626, 73.31807940346854, 75.61741202218192, 77.2502108982631, 72.57111331394741, 68.4550004686628, 65.77464253561837, 56.537592683519634, 53.07581949234009, 51.35239526203701, 51.447293758392334, 51.73032862799508, 53.641204833984375, 66.09791442326137, 69.7622206551688, 67.86094338553292, 64.68623501913888, 59.676979882376536, 56.30625588553292, 55.745383398873464, 55.81356259754726, 56.21023872920445, 51.599573952811106, 47.48458324159895, 46.4067439351763, 45.578195571899414, 45.738566943577354, 44.68684591565813, 45.739383356911794, 45.81157514027187, 47.56802415847778, 47.45066213607788, 46.15490647724697, 50.078172070639475, 49.458424023219514, 50.979673045022146, 48.96960088184902, 51.287488664899556, 57.285017354147776, 65.23374611990792, 62.426020758492605, 62.45807974679129, 59.61998380933489, 63.62351499285017, 54.5990035874503, 46.24308606556484, 61.87639740535191, 52.83606147766113, 51.448089327131, 47.95236723763602, 53.95354373114449, 50.744299343654085, 52.93427079064505, 53.68092768532889, 51.50124652045113, 50.26854576383318, 48.138301031930105, 45.38484804970877, 44.43072836739676, 45.88218968255179, 47.22847611563546, 43.67335735048567, 44.189796107155935, 44.314728191920686, 46.59310851778303, 47.60783733640398, 56.26025881086077, 62.447594915117534, 57.068956170763286, 57.57004983084542, 57.58003439222063, 57.33547864641462, 55.828897271837505, 54.797909668513704, 52.95896468843733, 49.101859842027935, 48.55613442829677, 46.42733144760132, 46.71696015766689, 45.41937712260655, 52.6118118422372, 55.498211656297954, 62.61512293134417, 64.26815496172223, 67.29863262176514, 65.14843613760812, 68.70448248726981, 67.91420132773263, 65.67665209089006, 65.71120548248291, 65.14462157658168, 67.17189053126744, 68.78100299835205, 29.430422237941197, 0.19471012907368795, 1.6087638629334313, 1.6138740458658762, 0.6346514448523521, 0.7870485644255365, 0.14983005874923297, 0.04703609838283487, 1.4862089306116104, 14.722341707774572, 24.29321255002703, 42.70355210985456, 33.18247726985386, 14.900481360299246, 17.14561803000314, 30.925879546574183, 54.28652572631836, 50.24732596533639, 67.21362141200474, 22.849250078201294, 0.8071501372115952, 0.08448701431708676, 0.18062676835272992, 0.06011993970189776, 0.06132252088614872, 0.07576540338673762, 0.021041304771123186, 0.0726440337353519, 0.06622666666018111, 0.005903994265411581, 0.14685200926448616, 0.03560435073450208, 0.07777611977819886, 0.031840096294347725, 0.025492777781827108, 0.045584637339093854, 0.04543350723439029, 0.06615268598709788, 0.05890327213065965, 0.015141427516937256, 0.016760021913796663, 0.03403777622484735, 0.03675532593790974, 0.057522046246698925, 0.09922328178903886, 0.030998037728880132, 0.08476763604474918, 0.03643634323296802, 0.1359858409102474, 0.037905290124139616, 0.06894782278686762, 0.08115573307233197, 0.015020675425018584, 0.031813311124486585, 0.08451924473047256, 0.06329588392483336, 0.10758431242512805, 2.637836043323789, 88.13034643445695, 79.26848193577358, 88.24719429016113, 69.45823001861572, 66.14566939217704, 30.21638856615339, 58.28847272055489, 95.10995088304792, 46.76107774462019, 11.578893286841256, 0.1874152533710003, 0.24506117297070368, 1.4375801171575273, 1.7244284621306827, 1.845252207347325, 2.755715489387512, 2.1612035163811276, 0.8103086362992014, 1.6902624326092857, 70.87801102229527, 85.48673057556152, 83.72329861777169, 78.87224006652832, 82.16737461090088, 73.40275709969657, 74.3952169418335, 74.85751533508301, 78.41353389195034, 77.89059162139893, 75.5822193963187, 72.12915229797363, 69.21703720092773, 58.6449431010655, 54.731557846069336, 53.25635801042829, 54.209327765873496, 53.04198523930141, 56.64730126517159, 68.24647808074951, 71.08030087607247, 71.80679062434605, 68.73317159925188, 63.451630456107004, 57.62738983971732, 57.48547635759626, 60.10558646065848, 57.360863889966694, 55.07808882849557, 50.631272997174946, 49.46709884916033, 47.589626107897075, 48.56365237917219, 48.31125906535557, 48.83553539003645, 47.50132145200457, 47.995790004730225, 49.77559539249965, 49.39514677865164, 52.16516426631382, 52.20267064230782, 52.77558783122471, 50.85808651787894, 53.06240252086094, 59.96821362631661, 64.97307750156948, 65.94879218510219, 65.59389904567173, 62.37921074458531, 65.79949624197823, 56.15427793775286, 50.293048586164204, 65.2578216280256, 55.002680029187886, 54.165911946977886, 51.17502859660557, 55.06556470053536, 53.6730067389352, 56.68690252304077, 55.77637236458914, 53.79278673444475, 52.602938992636545, 51.50044747761318, 47.35192128590175, 47.30426359176636, 47.99011680058071, 50.57751825877598, 46.512401717049734, 47.65108987263271, 47.20029074805123, 50.065352644239155, 51.035189151763916, 58.12034368515015, 63.28348405020577, 60.65814195360456, 61.07259505135672, 60.24052742549351, 60.726282937186106, 58.73950808388846, 57.09849991117205, 54.74294594355992, 51.22248479298183, 51.27395357404436, 49.19141517366682, 49.050144399915425, 50.143617153167725, 56.60404872894287, 58.5758432660784, 66.3599031993321, 65.79829420362199, 66.90994344438825, 66.68621144975934, 69.71108886173793, 70.83636351994106, 68.24673516409737, 69.80496597290039, 67.93120356968471, 70.10264764513288, 74.05799307141984, 38.26233305249895, 0.7675708095942224, 0.8882418030074665, 0.13255386506872519, 2.138828362737383, 1.2744635556425368, 0.8625936678477696, 0.06570403863276754, 0.3071565995258944, 24.39356538227626, 31.968866688864573, 41.69108492987496, 35.04955898012434, 22.98530970300947, 28.40954426356724, 35.6561610358102, 62.15397793906075, 56.59573868342808, 77.62193257468087, 34.561378547123496, 0.6552347232188497, 0.0791720427306635, 0.14607959214065755, 0.018728012651471154, 0.09135077601032597, 0.013822334236465394, 0.019773512978905013, 0.06640347252999033, 0.0745318199374846, 0.02486962648773832, 0.029049858517412628, 0.019033916593928422, 0.054389945563993285, 0.07297825294413737, 0.06659673965935196, 0.030841363993074213, 0.04155410200889621, 0.012354808027989097, 0.06272172794810363, 0.007060978744578148, 0.1472273069833006, 0.12222566641867161, 0.1446569620498589, 0.1695027702621051, 0.17957575832094463, 0.11309681234083005, 0.11290091249559607, 0.13640586765749113, 0.21140033991209098, 0.13596612268260547, 0.18025319411286286, 0.20799315774015018, 0.13291899833296025, 0.1697923554373639, 0.21363388720367635, 0.08032006969941513, 0.1839424432920558, 3.051473379135132, 100.8699310847691, 88.98439816066197, 100.20477308545793, 78.0810695375715, 80.08583327702114, 41.45086485998971, 94.31766864231655, 116.71058709280831, 61.16875811985561, 18.362237180982316, 0.5501146124941962, 0.5015283567564828, 1.748881561415536, 3.2106904813221524, 3.381462654897145, 5.143024895872388, 8.893609080995832, 7.64058484349932, 3.055271655321121, 75.37205723353794, 86.32037544250488, 89.44025557381767, 83.28356102534703, 86.65816906520298, 74.67657729557583, 76.74839809962681, 76.06025545937675, 81.89831951686314, 79.81126826150077, 79.41173989432198, 74.9132329395839, 71.80349023001534, 61.12558201381138, 58.37219851357596, 56.800012247903005, 57.12808534077236, 56.824751308986116, 59.21638379778181, 73.01832716805595, 75.6152650288173, 74.46016870226178, 71.87374346596854, 66.75349085671562, 61.651227133614675, 60.77266216278076, 63.42451163700649, 60.89224760872977, 57.80767822265625, 52.95719984599522, 52.09507778712681, 49.738113335200715, 50.18041133880615, 50.963980538504465, 52.050584997449604, 50.73455796922956, 51.837087699345176, 51.976513726370676, 52.38902827671596, 56.12008932658604, 55.73711504255022, 57.18481738226754, 51.98817975180489, 57.14624445778983, 64.07303564889091, 69.72265066419328, 67.95576545170375, 69.29084791455949, 65.84329073769706, 68.64820902688163, 58.72378431047712, 53.93561043058123, 68.22641168321881, 60.24125003814697, 58.86884880065918, 54.013899258204866, 59.52612059456961, 56.4523834500994, 60.253221784319194, 60.210511207580566, 56.63578462600708, 56.151300634656636, 53.04153708049229, 50.031240463256836, 47.891414165496826, 51.20571184158325, 52.89557974679129, 49.00768048422677, 50.30510718481881, 48.83447231565203, 52.45305592673165, 52.75654629298619, 61.47740404946463, 67.02640914916992, 63.27747385842459, 66.53561619349888, 63.06647791181292, 64.24623339516776, 61.47411755153111, 61.3521488734654, 60.01043088095528, 54.36164270128523, 55.19713578905378, 51.32192046301705, 52.755997385297505, 51.82678699493408, 59.74797657557896, 61.68782329559326, 69.2760135105678, 70.50917284829276, 70.33873353685651, 70.90187808445522, 72.42842510768345, 72.51948819841657, 69.65888704572404, 74.25204930986676, 71.57631192888532, 73.22387572697231, 76.88953685760498, 34.968226841517854, 0.7305348483579499, 4.5493499636650085, 5.550750834601266, 3.0966054030827115, 2.798079741852624, 0.8910189111317907, 0.1265469981091363, 2.153436081750052, 26.73323229381016, 37.71533611842564, 57.29526594706944, 49.36119788033621, 19.51083173070635, 29.227875300816127, 44.85239022118704, 70.29066589900425, 65.52697399684361, 86.90947151184082, 35.02896104540144, 1.2746012168271201, 0.17100021562405995, 0.2716347484716347, 0.13928919365363462, 0.22793258779815265, 0.1910830879850047, 0.04974964813196233, 0.21115124970674515, 0.19459798080580576, 0.10697731535349574, 0.14634894340166024, 0.1479098317878587, 0.15990749799779483, 0.20507832057774067, 0.13105542904564313, 0.12383469007909298, 0.124957624822855, 0.15400188203368867, 0.15035257142569336, 0.10996811451124293], [0.031527478247880936, 0.04532504680433443, 0.02754845899263663, 0.028623222839087248, 0.07234895242644207, 0.04146829107776284, 0.06881025659718684, 0.059323414228856564, 0.030881037935614586, 0.08887759050620453, 0.060468414931425025, 0.1437518099056823, 0.008092618297918566, 0.11080674986754145, 0.054522283641355376, 0.1692273664687361, 0.4429280369409493, 26.705286639077322, 84.56283555712018, 71.29711246490479, 77.83137212480817, 52.28735181263515, 33.8003944669451, 25.25968439238412, 35.87580401556832, 44.98937395640782, 34.90190976006644, 0.46943479031324387, 0.0424219211563468, 0.032059931462364535, 1.3792694232293536, 0.5474395017538751, 1.1055969255311149, 1.7051718554326465, 0.7616704319204602, 1.180750269974981, 29.39362805230277, 90.43405641828264, 75.15946320125035, 76.7377187183925, 73.01108714512416, 75.05296121324811, 77.90177822113037, 75.22411618913922, 70.26294953482491, 69.63937650408063, 68.58662019457135, 75.0883205958775, 71.16618755885533, 68.24615151541573, 62.51635428837368, 55.2602219581604, 50.24229199545724, 50.863179547446116, 51.23459202902657, 53.73483528409685, 62.82108838217599, 66.38337421417236, 66.26416397094727, 62.17573969704764, 53.42378875187465, 47.8964307648795, 47.47053050994873, 48.49172462735857, 46.220066683632986, 44.88035324641636, 46.185096400124685, 45.32339818137032, 47.71351596287319, 43.51174572535923, 46.6498509815761, 46.10885034288679, 46.97531849997384, 46.32721138000488, 46.65899133682251, 45.48047958101545, 47.38798243658883, 46.39895847865513, 48.44705465861729, 49.15832437787737, 48.6316682951791, 51.95012446812221, 57.3762333052499, 60.98964050837925, 63.755405698503765, 59.949043546404155, 63.67408398219517, 56.31728615079607, 46.219337122780935, 62.34096091134207, 50.396482944488525, 46.90355403082711, 46.968405042375835, 49.42166805267334, 50.82566622325352, 47.42419644764492, 51.48518575940813, 51.008525439671104, 54.26169286455427, 55.38498728615897, 52.194631576538086, 49.66108907972063, 48.58661617551531, 47.212488310677664, 45.097387177603586, 44.70328535352434, 43.666322299412315, 44.06679909569876, 45.56685263769967, 46.94236666815621, 51.80117246082851, 58.37152453831264, 58.17069728033883, 56.950319153921946, 54.62219320024763, 56.65399932861328, 55.65517841066633, 53.18905775887625, 48.534799984523225, 45.6345454624721, 46.86657224382673, 45.635212489536826, 47.679084164755686, 52.968900612422395, 60.85722173963274, 63.13952432359968, 65.25254794529506, 67.31124360220772, 65.9211869921003, 66.98861789703369, 65.50858211517334, 63.8549108505249, 64.3907698222569, 64.5954429081508, 65.47464711325509, 63.750938006809776, 74.63887637002128, 42.61811705998012, 0.22552518626408918, 1.4615284949541092, 0.13505658720220837, 0.7600840713296617, 0.15472654386290483, 0.03301056241616607, 0.0904214069513338, 12.08202884878431, 21.73995453970773, 30.989771706717356, 45.88002879279, 26.02550094468253, 18.3132905960083, 34.34746435710362, 43.97467640468052, 56.81614249093192, 54.00210469109671, 55.66207102366856, 4.126055717468262, 0.1887440284980195, 0.04077553396512355, 0.018544480803289583, 0.03721816485215511, 0.08110329588609082, 0.06168941155608211, 0.07148838681834084, 0.04025334020012191, 0.06563787468309913, 0.01394422711538417, 0.08686582238546439, 0.01505772682971188, 0.06107505916484764, 0.07375014759600163, 0.02317212355722274, 0.05524049260254417, 0.06758972816169262, 0.02026226175283747, 0.07729659908052001, 0.055360515269317796, 0.01106924794813884, 0.05110789542751653, 0.010297313432342239, 0.027270120535311953, 0.012439511250704527, 0.10694257436054093, 0.05147646886429616, 0.03338053024240902, 0.13781470991671085, 0.06775197267000165, 0.14169902434306486, 0.0494823324760156, 0.04981662971632821, 0.0495643130769687, 0.09270563402346202, 0.23104654784713471, 35.54871756689889, 97.95814255305699, 77.79087107522147, 85.2341844013759, 60.09056445530483, 52.6452430997576, 36.300133977617534, 41.067063740321565, 51.50852475847517, 40.655737331935335, 0.6395552988563264, 0.07858785800635815, 0.33366614846246584, 1.6321066617965698, 1.6142072337014335, 4.435838980334146, 6.8391874347414285, 0.3083626005266394, 1.6174991599151065, 36.59656497410366, 93.3140708378383, 77.41098526545933, 81.19319547925676, 76.78675215584892, 78.46942520141602, 79.83825506482805, 77.85995701381138, 72.48430252075195, 71.26714488438198, 70.38810048784528, 76.24015126909528, 74.86406748635429, 72.74554783957345, 64.14137813023159, 56.761713777269634, 54.288228034973145, 53.83194330760411, 53.90963111604963, 54.836944648197715, 65.12441621507917, 69.22078227996826, 69.48197201320103, 66.45867879050118, 57.352116107940674, 51.25516217095511, 49.49927248273577, 49.71423237664359, 48.42062371117728, 47.25185332979475, 48.42654357637678, 48.87526866367885, 48.791327476501465, 46.83045203345162, 48.24846124649048, 49.62781415666853, 48.50955023084368, 46.70915733064924, 48.465665408543174, 47.74613775525774, 51.08680384499686, 48.66882378714425, 50.78165633337838, 53.25326606205532, 50.416035175323486, 55.9317410332816, 58.79257147652762, 63.08085373469761, 66.19353553227016, 61.572462354387554, 64.21933691842216, 58.59778567722866, 49.31722967965262, 63.48484284537179, 54.048577717372346, 49.864942278180806, 49.00952870505196, 51.20465571539742, 52.724327496119905, 50.93864393234253, 53.19517912183489, 53.78843716212681, 55.39174440928868, 56.95800733566284, 53.684113434382844, 50.812558446611675, 50.30305051803589, 51.056342942374094, 47.511316435677664, 46.87839807782854, 45.17556135995047, 47.06883430480957, 46.8609059878758, 48.94077627999442, 54.38412707192557, 59.86726324898856, 61.13046659742083, 59.23118346078055, 56.434495312826975, 60.0925863810948, 59.49049718039376, 55.70724473680769, 49.57416364124843, 49.39423656463623, 48.64698907307216, 48.974398612976074, 50.259759766714915, 56.26465702056885, 63.89406394958496, 67.67500264304024, 66.44859000614711, 68.79514953068325, 65.88179765428815, 69.57720402308873, 67.94334207262311, 67.67071560450962, 67.66816561562675, 68.13866288321358, 68.40700231279645, 68.4538470676967, 76.45359298161098, 53.453408922467915, 0.8190073466726712, 0.7191127698336328, 0.329050671841417, 1.0490064535822188, 0.9169392202581678, 0.02850319677963853, 0.3309073607836451, 7.760283197675433, 31.635057858058385, 33.89195435387747, 37.86968687602452, 25.01877645083836, 27.63043233326503, 43.1119498525347, 49.88794081551688, 64.41153103964669, 60.20353521619524, 70.6737756729126, 8.9428049325943, 0.33511921763420105, 0.04163592315411993, 0.08618292438664607, 0.028523183028612818, 0.14463195124907152, 0.028727096372417042, 0.03363212763464876, 0.03106506002534713, 0.047231340049100776, 0.02469595884239035, 0.01747594421197261, 0.029691766215754405, 0.040003378077277114, 0.0501637919805944, 0.030557950093810047, 0.07567157556435891, 0.016198352677747607, 0.05219572955476386, 0.0409666806725519, 0.15475847572088242, 0.11891209493790354, 0.08179367134081465, 0.09473260132861988, 0.1057653771713376, 0.09644895565829106, 0.29975644232971327, 0.118714464828372, 0.09545038281274693, 0.18687564161206993, 0.1961046542440142, 0.20678581324006828, 0.10917345500950303, 0.1875116460557495, 0.1580491398594209, 0.30456478574446266, 0.6267479775207383, 39.56231321607317, 107.38807092394147, 88.3597412109375, 97.04173074449811, 69.99961280822754, 50.015690394810264, 38.970517771584646, 53.09169960021973, 55.943942070007324, 55.77125154222761, 1.2796731846673148, 0.27183328781809124, 0.22645822619753225, 5.451998693602426, 3.1491932783808028, 6.253515090261187, 8.13269795690264, 6.830836568559919, 3.534446571554456, 41.55011987686157, 94.00062928880963, 81.16286659240723, 82.64996869223458, 81.51639788491386, 80.44012192317417, 85.74994223458427, 79.12523092542375, 74.54891109466553, 72.28621632712228, 74.40003899165562, 76.9659184047154, 77.25656155177525, 74.95433153424943, 67.94116033826555, 61.3273229598999, 56.24226992470877, 56.05890001569475, 57.9549800327846, 57.683392320360454, 69.28511565072196, 70.99100957598004, 73.71149335588727, 69.19966670445034, 60.89095524379185, 54.046065943581716, 52.52277067729405, 54.12880856650216, 51.119526386260986, 49.04844209126064, 50.60520683016096, 50.15758303233555, 52.067708832877024, 47.53623962402344, 52.45889241354806, 51.748369625636506, 51.61177151543753, 49.19570916039603, 51.625153745923726, 50.46611431666783, 55.8921571459089, 51.95546415873936, 54.245618207114084, 56.85053954805647, 54.144869327545166, 57.86656073161534, 62.20172595977783, 66.86035415104458, 69.25276483808244, 64.39072118486676, 68.44553702218192, 60.863801683698384, 53.89301102502005, 67.4241031919207, 56.12300409589495, 52.7003562109811, 51.68877840042114, 54.45617989131382, 56.94418042046683, 51.776186738695415, 57.17035470690046, 55.974830286843435, 60.98473508017403, 60.76282351357596, 57.359071254730225, 53.58362511226109, 52.585373946598594, 52.55129998070853, 50.63560519899641, 48.536523137773784, 49.32674176352364, 48.77445030212402, 49.82634503500802, 52.68110275268555, 57.310732637132915, 62.688746043613975, 64.77570002419608, 63.670484815325054, 60.16845376150948, 62.51014954703194, 60.99795055389404, 58.33874293736049, 52.309700693402974, 50.583094188145225, 51.38794224602835, 52.19701133455549, 54.28107486452375, 59.28193310328892, 66.42327077048165, 70.16164479936872, 70.76712472098214, 70.95999281747001, 69.31362410954067, 72.79224668230329, 71.06878771100725, 71.1385476248605, 72.68823214939663, 69.11248765672956, 73.57813658033098, 71.3389892578125, 80.98184517451695, 48.17103746959141, 0.4792395127671105, 3.8991479618208746, 3.6337478373731886, 1.455350786447525, 0.9149562695196697, 0.12904304345803602, 0.7645701648933547, 20.374433755874634, 38.58076899392264, 44.50341694695609, 59.39985792977469, 38.140663146972656, 27.756516081946238, 52.815936020442415, 58.66073635646275, 75.17899458748954, 70.63309397016252, 78.65991006578717, 7.553854823112488, 0.28885162462081226, 0.12891052556889399, 0.16263461166194507, 0.16108063076223644, 0.2180910480341741, 0.1685202108430011, 0.14785120636224747, 0.15800854989460536, 0.18481224376176084, 0.1043372509468879, 0.13528171155069554, 0.08582403364458255, 0.14078426414302417, 0.1537197336022343, 0.14541711126055035, 0.19812765211931296, 0.22776075559003012, 0.13752479904464313, 0.10271081607788801], [0.03439604610736881, 0.041461112177265544, 0.05148726435644286, 0.051986415072211196, 0.06425265222787857, 0.026461137159328376, 0.005437067177678857, 0.045475274457463195, 0.042891867724912505, 0.08892470119254929, 0.04906196306858744, 0.03552241423832519, 0.053610627739025016, 0.05343442915805748, 0.040572404329265864, 0.042481313326529095, 0.7522552428500993, 60.83810724530901, 78.66251564025879, 67.82562569209507, 59.27308804648263, 59.66659232548305, 17.57247887338911, 29.09493715422494, 39.99686745234898, 32.127056326184956, 13.260676094463893, 0.1031014486881239, 0.012528313673101366, 0.5565341508814267, 0.34567798248359133, 1.7996460774115153, 1.6148390855107988, 2.6062983870506287, 2.9178731994969502, 3.84054468359266, 81.32376602717808, 78.84678881508964, 77.43943119049072, 72.50402845655168, 72.68540423257011, 71.43193531036377, 72.49688570840019, 72.32479967389787, 73.92994471958706, 72.17947810036796, 69.00200435093471, 67.83185822623116, 75.92377894265312, 70.21086583818708, 66.36694867270333, 53.52702508653913, 51.62723820550101, 51.24417012078421, 52.14331912994385, 48.370422976357595, 62.07689462389265, 65.44158063616071, 64.38671902247837, 58.724541664123535, 52.86340958731515, 48.25024345942906, 47.617589133126394, 47.035847731998985, 48.011492933545796, 47.063307012830464, 46.24305132457188, 44.028959206172395, 45.37189660753523, 43.964740480695454, 46.533531188964844, 45.35409532274519, 45.55478014264788, 46.32655130113874, 46.0230644089835, 43.74272469111851, 46.95664174216134, 47.39685876028878, 49.962818077632356, 48.90593801225935, 50.15438686098371, 48.279422419411794, 49.66302762712751, 50.244553634098594, 55.18883269173758, 53.47088711602347, 62.12311404091971, 54.99358483723232, 43.600210189819336, 63.43305792127337, 52.02060004643032, 46.72429050718035, 45.52462496076311, 48.32911246163504, 50.00410427365984, 54.05631453650338, 54.51700094767979, 57.414792333330425, 57.88731152670724, 60.74411201477051, 57.43943411963326, 59.273136683872764, 54.53878355026245, 53.737572874341694, 50.09404523032052, 46.928914955684114, 42.465829917362754, 42.12034463882446, 43.2111805507115, 45.0310492515564, 45.95167514256069, 48.142442158290315, 49.710570675986155, 53.42784649985177, 53.66465500422886, 56.04744938441685, 54.61438342503139, 52.19193914958409, 45.354658126831055, 47.28907135554722, 45.224136216299875, 47.09118318557739, 46.71716512952532, 51.71346535001482, 62.399027006966726, 65.21899509429932, 64.78868620736259, 63.64300468989781, 64.94861289433071, 64.36307430267334, 62.48961762019566, 63.0411239351545, 61.88408211299351, 64.24251610892159, 60.58291380746024, 65.52764797210693, 62.23602226802281, 76.69511931283134, 53.29322167805263, 0.27962992659636904, 1.0780526378325053, 0.8226911404303142, 0.993074323449816, 0.29290296722735676, 0.09251022950879165, 4.653543412685394, 39.717424801417756, 28.641558510916575, 56.968891688755576, 50.44589853286743, 21.985922506877355, 14.512287242071968, 38.644136565072195, 62.074712889535085, 50.625801290784565, 68.44734355381557, 33.39816672461373, 0.29954093960779055, 0.09617913620812552, 0.09502883614706141, 0.02358903413239334, 0.09461720966334854, 0.015218213932322604, 0.047374056319573095, 0.025292138369487863, 0.10947103332728148, 0.08605667616107635, 0.08376636941518102, 0.057806135288306644, 0.05794509247477565, 0.028706295881420374, 0.045723407928432734, 0.01075386826414615, 0.04376834158652595, 0.0505162671740566, 0.007991835491598716, 0.01509399283012109, 0.05955421791544982, 0.031772042624652386, 0.03504114631297333, 0.0056579193000548655, 0.029047229194215367, 0.014776981269408549, 0.03237856472177165, 0.04186466070158141, 0.0643117797694036, 0.06627925990947656, 0.0914757214486599, 0.1074386988101261, 0.005612423951138875, 0.018636868435091207, 0.02440956617439432, 1.5176298788615634, 77.17846379961286, 87.41826030186245, 76.37930979047502, 67.26984623500279, 75.80171298980713, 33.871349470955984, 28.582769802638463, 28.487138271331787, 41.140666007995605, 14.075993350573949, 0.03261450491845608, 0.16216190345585346, 1.3678419164248874, 1.7506177425384521, 2.1104914375713895, 4.155898230416434, 3.5925665157181874, 2.7602422407695224, 6.794514426163264, 86.8959572655814, 79.16803182874406, 81.03456810542515, 76.02732794625419, 75.15660749162946, 74.314284324646, 75.10174451555524, 76.63068171909877, 76.20634133475167, 73.53562750135148, 73.04454966953823, 69.03350748334611, 77.27052743094308, 72.28524357931954, 69.08814811706543, 56.006465435028076, 54.530577727726524, 52.67319917678833, 53.782378332955496, 52.53505856650216, 64.94394370487758, 66.36398874010358, 66.20281137738908, 62.25681822640555, 56.57010677882603, 49.3950251851763, 48.70811585017613, 49.06136574063982, 50.01153884615217, 48.92717865535191, 49.05001933234078, 45.521109172276084, 48.514733586992534, 46.874746799468994, 50.25963817323957, 47.32740804127285, 48.22973585128784, 49.00304256166731, 47.62357153211321, 46.28717933382307, 49.06440210342407, 49.903751441410606, 53.60057871682303, 51.86346306119646, 51.74470097678048, 51.616242681230815, 51.63068451200213, 53.94248914718628, 58.80193764822823, 57.00536625725882, 65.3730297088623, 57.74969550541469, 47.937359128679546, 65.59345436096191, 55.543840476444785, 49.6216858455113, 48.48768424987793, 51.514507157461985, 52.22322341373989, 56.891158717019216, 57.99828120640346, 60.34415980747768, 59.9563877923148, 62.86798177446638, 60.719994817461284, 60.754819188799175, 58.28752081734793, 57.341586112976074, 54.25591196332659, 48.340469292231965, 45.33104119982038, 43.487263747623985, 45.55234827314104, 46.92004905428205, 47.65912199020386, 49.130861622946604, 51.09458582741873, 55.02237817219326, 56.03155190604073, 57.06066696984427, 57.08492660522461, 54.807831696101594, 48.199424334934776, 48.20674773624965, 47.90948643003191, 48.97069869722639, 49.210223947252544, 54.50959069388253, 63.92203739711216, 67.24153232574463, 67.00093010493687, 64.32188538142613, 67.76679529462541, 67.54029096875871, 65.48558357783726, 64.04887676239014, 64.87823459080288, 66.49433694566999, 63.94653674534389, 68.80336230141776, 65.80248396737235, 77.61040551321847, 64.0079379762922, 0.9098379984498024, 1.054087106670652, 0.2523343355527946, 1.4090758923973357, 0.8533502295613289, 0.11260864032166344, 1.6752694142716271, 42.9856732913426, 37.4679594039917, 43.78232594898769, 31.556640488760813, 23.89578948702131, 28.643222604479107, 48.51770394189017, 68.23258168356759, 58.20075866154262, 74.21978187561035, 47.47959096091134, 0.2491229378751346, 0.08746649551072291, 0.03370355701606188, 0.01912741532682308, 0.04920847234981401, 0.01629325088911823, 0.04060503847098776, 0.04319303210026451, 0.07150693118040051, 0.07863796103213515, 0.036491345281579664, 0.030562072194048336, 0.05456442405868854, 0.021300751117191145, 0.03495406312867999, 0.03605768337313618, 0.04431645878191505, 0.018599433658112372, 0.032718833070248365, 0.15862470040363924, 0.1240624471434525, 0.13923507370054722, 0.18193883794759, 0.1142062238816704, 0.1406962988632066, 0.1173340803278344, 0.15433379422341073, 0.07495173811912537, 0.13211037458053657, 0.12126605505389826, 0.22948317602276802, 0.16878664440342359, 0.2555404949401106, 0.10328822902270726, 0.15007931180298328, 2.2418469148022786, 94.96216269901821, 96.75778566087995, 88.73049708775112, 77.0019656590053, 80.53897394452775, 26.90262590135847, 41.94414874485561, 55.100976194654194, 54.64119304929461, 21.302061694008962, 0.3588026139353003, 0.20045850133257254, 2.305703248296465, 4.735600335257394, 5.2158263836588175, 7.585999795368739, 11.9003985949925, 8.437705636024475, 8.086308309010096, 91.84679194859096, 82.98057092939104, 84.96146760668073, 80.39634827205113, 77.42388112204415, 77.20423466818673, 78.23941203526088, 79.2075114931379, 79.85484736306327, 75.45511599949428, 75.8584519795009, 72.75815187181745, 81.36293302263532, 74.39673859732491, 71.73844814300537, 58.2986170904977, 56.37424748284476, 55.941788128444124, 57.57224546160017, 53.8603058542524, 69.0779481615339, 70.01268931797573, 68.89507157461983, 63.89329964773995, 59.01146752493722, 52.41442741666521, 51.078483377184185, 51.35117585318429, 53.19798271996634, 52.683433873312815, 50.47956255504063, 48.17737422670637, 50.7498196874346, 49.28131444113595, 52.2130651473999, 49.84416021619524, 51.31432260785784, 52.32606022698538, 50.85942752020699, 48.785994734082905, 52.57267263957432, 55.373349053519114, 55.85628707068307, 55.01594761439732, 54.30485507420131, 54.37139449800764, 55.2571473802839, 57.13731949669974, 60.96343885149275, 60.98288685934884, 68.27094268798828, 60.80796595982143, 50.22342068808419, 67.70829146248954, 58.63568115234375, 52.02227108819144, 51.90999514716012, 53.78611993789673, 54.46459763390677, 59.954164368765696, 59.74595464978899, 63.14600004468645, 62.396907806396484, 65.9118208203997, 63.691642080034526, 63.509856360299246, 59.882354736328125, 59.89355523245675, 57.17190762928554, 52.07144348961966, 49.226079736437114, 47.51417909349714, 49.3557504926409, 48.919987269810264, 51.16164289202009, 53.666392053876606, 54.91763407843453, 59.092594691685264, 58.52875532422747, 61.990597997392925, 60.53581196921212, 58.759011677333284, 50.588221958705354, 52.051022733960835, 50.41997480392456, 51.276013714926584, 52.21361058098929, 58.20912776674543, 66.57422733306885, 71.5119160243443, 70.36230877467564, 67.40424524034772, 69.86926460266113, 71.11919689178467, 69.00235176086426, 68.53305653163365, 68.86556257520402, 70.88162408556256, 65.68064035688127, 71.38975279671806, 68.46013518742153, 84.674729347229, 61.08535194396973, 0.4795588584882872, 4.752357653209141, 4.594818540981837, 2.795949250459671, 0.7135495426399368, 0.2480658617402826, 7.70076492854527, 53.47491012300764, 43.15283652714321, 74.13892568860734, 64.88087490626744, 30.057518005371094, 27.282879965645925, 52.09951421192714, 76.16660458700997, 67.2443949835641, 87.39096777779716, 48.33991343634469, 0.3847382308116981, 0.202803246943014, 0.19749300474567072, 0.10219532623887062, 0.3083458814237799, 0.12609153826321873, 0.239347799548081, 0.11984350638730185, 0.19358715361782483, 0.11036683525890112, 0.14945106979991707, 0.12296532387179987, 0.13240627013146877, 0.15727502639804566, 0.08854803283299718, 0.13598138972052506, 0.11321515563343253, 0.09700124923671995, 0.10700039232947997], [0.06676012410649232, 0.06788065683628831, 0.035598362662962506, 0.011615281192851918, 0.10657822819692747, 0.12565171186413082, 0.04448921040498784, 0.03906187002680131, 0.0429770679745291, 0.05403949919023684, 0.07967043348721095, 0.08055554849228688, 0.1278743076005152, 0.007767145405523479, 0.10468033182301692, 0.1153983963387353, 7.725642953600202, 65.77708830152238, 67.66259316035679, 72.57714435032436, 46.16423095975603, 22.782943419047765, 19.048436062676565, 54.622960976191926, 60.552925382341655, 32.922618116651265, 2.881857429231916, 0.06355815806559154, 0.25276216545275276, 1.9593639927250999, 0.6772622498018401, 0.6537655591964722, 5.78160560131073, 5.371095606258937, 0.42446205924664226, 44.96167843682425, 87.53125885554722, 74.93383434840611, 76.85367720467704, 69.09114973885673, 70.24643366677421, 64.64203752790178, 70.76239994594029, 67.13314737592424, 70.00667912619454, 70.37706674848283, 72.75570610591343, 70.15860148838588, 68.00403458731515, 67.1567781993321, 65.65536975860596, 53.440554755074636, 51.910259178706575, 50.0174343926566, 50.82136876242501, 48.30081244877407, 57.44145604542324, 61.15240206037249, 61.54093837738037, 58.039306844983784, 53.80822910581316, 48.653027057647705, 47.03841856547764, 47.191119125911165, 46.41041258403233, 44.512883867536274, 45.27769293103899, 44.43389674595424, 43.43523563657488, 45.97575412477766, 46.79783371516636, 46.097038405282156, 48.49999645778111, 44.99771874291556, 48.247026443481445, 43.86483233315604, 43.37711048126221, 46.20431164332798, 47.66165460859026, 49.65585708618164, 51.53331593104771, 49.510844707489014, 48.41258117130825, 47.179484367370605, 51.13868604387556, 48.81457267488752, 62.44430146898542, 54.922199044908794, 43.264483656202046, 61.54593413216727, 51.580699171338765, 45.17011744635445, 52.27374376569475, 55.76770796094622, 56.57425137928554, 60.42698928288051, 58.78384453909737, 59.373684065682546, 57.93558413641793, 56.24889850616455, 58.77164350237165, 58.04056099482945, 57.589803559439524, 56.93408121381487, 53.815615040915354, 49.434473582676475, 45.53266750063215, 41.82129417146955, 40.44402224676949, 43.58995117459978, 44.22400556291853, 44.692140442984446, 44.49554811205183, 45.134886605399, 45.805540629795615, 46.89025170462472, 49.74047919682094, 47.15417902810233, 45.82934863226754, 46.072949000767295, 46.10006087166922, 47.09269094467163, 46.38646214348929, 50.62916421890259, 61.68036093030657, 62.205373764038086, 63.9383031300136, 63.41392258235386, 64.64777673993791, 56.44489329201834, 57.67415816443307, 53.390103885105674, 55.53049298695156, 51.959782464163645, 54.98796027047293, 54.904766014644075, 68.05666719164167, 60.89032295772007, 77.05730806078229, 46.41216353007725, 0.13928057625889778, 0.8785248558436121, 1.463139282805579, 0.6317584972296442, 0.24178745863693102, 0.31783266950930866, 19.51861892427717, 51.00349146979195, 31.940799440656388, 57.82045595986502, 30.545396191733225, 15.22175737789699, 22.94618092264448, 43.00180353437151, 52.530236516680034, 50.433395249503, 64.63263661520821, 9.58289817401341, 0.6546764246055058, 0.13849106005259923, 0.04504199931398034, 0.03179036646283098, 0.018566785945690105, 0.059554530041558404, 0.035319077649286816, 0.014422307622485926, 0.017816166759335568, 0.02959182479285768, 0.09214377988662038, 0.049883546839867315, 0.034826166063014946, 0.003199448463939396, 0.006500524934381247, 0.03076511701302869, 0.05544609549854483, 0.02142418851144612, 0.03267274697178176, 0.0355662340298295, 0.020675416636679853, 0.020905792846211364, 0.058239929511078765, 0.03380806158695902, 0.056063263810106685, 0.040967864716159444, 0.05236351769417524, 0.078037701813238, 0.03562405878411872, 0.05617781409195491, 0.09143654962203332, 0.03929906551327024, 0.12184184630002294, 0.24409556335636548, 14.250993285860334, 83.23552118028913, 74.93351473127092, 79.9479740687779, 57.610300745282856, 35.77893223081316, 24.614233221326554, 40.08702032906668, 48.18236650739397, 38.943197454724995, 2.9742580481937955, 0.10869694022195679, 1.0404987101043974, 2.251918111528669, 2.43215959412711, 3.2375949919223785, 4.9882246766771585, 0.8800657274467605, 1.298054101211684, 52.87532574789864, 89.74416978018624, 79.84315354483468, 79.79987321581159, 72.2467714037214, 72.28077588762555, 68.55473491123745, 74.3951335634504, 70.92623846871513, 71.3612790788923, 73.98266765049526, 75.21767520904541, 73.30362715039934, 71.48347009931291, 69.36106640951974, 67.93938159942627, 56.923023155757356, 53.90183176313128, 52.837339946201865, 52.41678285598755, 50.531302315848215, 59.27029487064907, 64.26460443224225, 63.771622794015066, 60.982421330043245, 57.46590328216553, 51.941328048706055, 48.63668836866106, 48.38580281393868, 47.901958056858604, 47.25475420270647, 48.665617193494526, 47.58358464922224, 47.58675650187901, 48.28716966084072, 49.83126088551113, 48.605588231767925, 51.727858543395996, 46.77598510469709, 51.263468742370605, 47.09237480163574, 46.65766423089163, 48.97547558375767, 51.846981934138704, 52.43420198985508, 53.87985808508736, 53.2136925969805, 51.75561312266758, 49.08431216648647, 51.77075672149658, 51.19187797818865, 64.80038002559117, 55.19593375069754, 46.47060830252511, 62.78536769321987, 52.15170213154384, 48.64547436577933, 53.71095085144043, 59.750332014901296, 59.22174085889544, 64.03561265127999, 61.207160813467844, 60.975167410714285, 59.95132950374058, 57.74420642852783, 60.591744967869346, 60.61706420353481, 60.06389726911272, 59.29660769871303, 56.95226117542812, 50.8509646143232, 47.653820514678955, 43.26406329018729, 44.20969574792044, 45.40101303373064, 45.62410231998989, 46.35810307094029, 47.411741801670615, 46.830566678728374, 48.27525350025722, 49.243359906332834, 51.883487769535606, 50.74272905077253, 48.421839645930696, 48.20919350215367, 49.49456507819039, 49.78641373770577, 49.51028537750244, 52.954622064317974, 65.76313631875175, 64.04900877816337, 67.1210297175816, 64.33602496555874, 66.37427207401821, 59.393653188432964, 58.207373346601216, 56.09248065948486, 57.053409576416016, 53.19337953839983, 56.82844427653721, 57.61819737298148, 71.06029006413051, 63.51979228428432, 77.48244748796735, 56.348594733646934, 0.5917919161064285, 0.7587907293013164, 1.5740136419023787, 1.5318710803985596, 0.2639905357999461, 0.5058386283261436, 17.45260681424822, 59.5094518661499, 34.249112606048584, 37.54867662702288, 33.10191638129098, 25.64321800640651, 37.26482534408569, 49.677024773189, 56.243336473192485, 58.02454539707729, 73.66104248591832, 19.8760655266898, 0.9163181164434978, 0.16325528121420316, 0.09570429061672517, 0.02026477063606892, 0.06134991334485156, 0.026734288216435483, 0.1368277943027871, 0.0484966450104756, 0.048840414599648545, 0.05557748023420572, 0.09394066953765494, 0.06765506429863827, 0.08936732994126421, 0.03138562710955739, 0.040829524996557405, 0.0034585430320086224, 0.08862805925309658, 0.049131445054497035, 0.15932085019137177, 0.1459488927253655, 0.12764332070946693, 0.11665454107735838, 0.35776136123708313, 0.14387889951467514, 0.1694978712392705, 0.11505492191229548, 0.1277449923966612, 0.20733079899634632, 0.14539964576917036, 0.1721525037927287, 0.24278371089271136, 0.167224005396877, 0.29670726880431175, 0.5018758209688323, 18.31329928125654, 98.2433591570173, 83.83716569628034, 92.84022453853062, 65.24894183022636, 34.33785152435303, 26.38139636175973, 76.44162818363735, 81.98278876713344, 50.35745143890381, 5.090885613645826, 0.18992541224828788, 0.9321485012769699, 4.81692465714046, 3.801160991191864, 4.9769017185483655, 15.40136136327471, 17.456091335841588, 2.8247462766511098, 56.57102394104004, 91.88106046404157, 85.0448112487793, 82.73161002567836, 76.8810670035226, 75.84734180995396, 71.38767528533936, 78.41698019845145, 76.79979392460415, 76.45943641662598, 78.77367986951555, 77.65447098868233, 77.48366342272077, 74.58176217760358, 72.35264805385044, 73.89671843392509, 59.599903515407014, 58.62407071249825, 55.28991855893816, 56.69051211220877, 54.16794082096645, 63.064546312604634, 67.64266572679792, 67.3248690196446, 64.25192396981376, 58.72071320669991, 54.17125163759504, 51.339874608176096, 50.91182041168213, 50.066158635275706, 49.11548178536551, 50.527056966509136, 50.39457218987601, 48.76544196265084, 50.62294210706438, 52.42337669645037, 50.81552880150931, 54.2930257661002, 50.306517669132774, 53.404048919677734, 49.026329449244905, 48.05155624662127, 51.11603839056832, 52.95602560043335, 55.1288662637983, 56.65817519596645, 55.885375704084126, 55.356447560446604, 52.34427145549229, 56.302041803087505, 53.95822334289551, 68.91882051740373, 59.93379919869559, 50.001474380493164, 65.90619277954102, 56.72054917471749, 49.28605311257498, 56.44356271198818, 63.02011258261544, 61.79199068886893, 66.7440413066319, 64.39764853886196, 64.64722088405064, 61.95394624982561, 59.85636847359793, 64.77742317744664, 63.29212760925293, 63.07935987200056, 63.4294170652117, 61.16723646436419, 54.71686935424805, 51.595901829855784, 45.42888920647757, 46.17031758172171, 48.16017048699515, 49.050589084625244, 48.85717208044869, 50.54243332999093, 50.101976599012104, 51.00231722423008, 51.68386254991804, 56.52036115101406, 53.54858187266758, 51.97282075881958, 50.6506723676409, 51.69672366550991, 52.587159633636475, 52.34634896687099, 55.47832243783133, 67.76818493434361, 67.72220870426723, 70.84288093021938, 68.27936390468052, 71.71711022513253, 63.586286544799805, 63.211361748831614, 58.393640654427664, 61.368692534310476, 55.90040465763637, 61.28898974827358, 61.927904401506694, 75.13646466391427, 66.03996644701276, 83.55133070264543, 55.63567134312221, 0.48174531544957844, 4.2451174429484775, 4.455655676977975, 1.941408327647618, 0.584359406360558, 0.47354904668671743, 26.03604483604431, 66.09866482870919, 48.112867150987896, 75.40623542240688, 46.40369367599487, 22.701611280441284, 36.66352823802403, 57.493588379451204, 68.70102923257011, 66.04849188668388, 83.9728570665632, 17.601042917796544, 1.1520424847091948, 0.2428398664508547, 0.20468299250517571, 0.17103802359529904, 0.25566596963575905, 0.14429360654737267, 0.14371617324650288, 0.14256545927907738, 0.1626463503177677, 0.08583337707178933, 0.18073445186018944, 0.09982829075306654, 0.20637681947222777, 0.09732579932148967, 0.11154835471617323, 0.19312889820763043, 0.16533721664122172, 0.13883267529308796], [0.036596260366163084, 0.07428816479763814, 0.03346796965758715, 0.04147144626559956, 0.042874317416655164, 0.07263749265777213, 0.09519585075655154, 0.006876807377141501, 0.03696846735796758, 0.02501520617598934, 0.02052677166648209, 0.05411475890183023, 0.10234098735132388, 0.07701821651841913, 0.20780224512730325, 0.047693449538201094, 42.55619124003819, 80.10234219687325, 72.5335999897548, 62.595501218523296, 44.40612479618618, 31.362174306597026, 52.87721218381609, 53.09819964000157, 36.10280861173357, 15.794631140572683, 0.07811601832509041, 0.1155208447682006, 0.5415041659559522, 0.8712299529995237, 0.5977645984717778, 1.4327880314418246, 2.544207330260958, 0.6226301927651677, 14.379154545920235, 86.64702415466309, 73.58004038674491, 78.59455530984062, 67.37464591435024, 69.59065573556083, 65.51147951398576, 69.96752602713448, 63.73350497654506, 66.72418335505894, 62.373902320861816, 66.16765349251884, 62.720047678266255, 67.88798577444894, 63.18197781699044, 63.36611897604806, 56.45186928340367, 52.911379950387136, 48.68495750427246, 49.464420318603516, 49.207625320979524, 49.882212025778635, 51.92451688221523, 57.60264035633632, 57.24405772345406, 56.281812122889924, 52.102095467703684, 49.750453335898264, 46.72522851399013, 47.3559581892831, 47.078193528311594, 46.6639210837228, 43.92699439185006, 45.19296659742083, 43.18115391050066, 45.905983788626536, 47.002364362989155, 50.51324047361101, 48.955388341631206, 49.9213547025408, 46.477355003356934, 46.026396070207866, 44.58568014417376, 46.001236643110005, 49.32245472499302, 51.53667885916573, 53.40873547962734, 52.34729739597866, 50.364736625126426, 46.154798780168804, 45.770674569266184, 51.03829847063337, 59.55267660958426, 53.32094499043056, 42.547863824026926, 62.573308672223774, 45.76645006452288, 51.04394735608782, 53.81608404432024, 62.328787667410715, 55.829428809029714, 56.83130693435669, 53.008567878178184, 55.399470806121826, 54.76481192452567, 55.38314948763166, 54.08431577682495, 55.834824085235596, 54.31765365600586, 55.88464961733137, 51.48261840002877, 47.25821787970406, 42.60933106286185, 41.296743392944336, 41.140509673527305, 42.29179491315569, 40.3732305254255, 44.83511699948992, 42.54842662811279, 44.339939730507986, 43.99472543171474, 45.138555254255024, 44.988300459725515, 46.09856700897217, 43.745497022356304, 46.82811049052647, 45.14880384717669, 48.88706323078701, 45.55131646565029, 48.54195315497262, 55.25655330930437, 63.14204651968819, 63.472794669015066, 61.65454142434256, 53.99428449358259, 49.58607285363333, 44.6573542867388, 46.84645026070731, 47.50551468985421, 52.894631317683626, 47.273837430136545, 52.22968176433018, 48.447426387241904, 66.84399114336286, 59.820091928754536, 77.84915256500244, 20.840345212391444, 0.7038240187934467, 0.2489385934812682, 1.2310580504792077, 0.026084882706137638, 0.06054435657071216, 1.1987854050738471, 53.552476337977815, 36.75818007332938, 33.277278491428916, 37.44103166035244, 17.65236404963902, 12.940692441804067, 21.11528021948678, 52.126073701041086, 55.05504512786865, 53.657428877694265, 46.802614075796946, 1.4718919502837318, 0.2498730719089508, 0.12021218160433428, 0.046193700549857955, 0.050406670197844505, 0.03190143586003354, 0.0923796250884022, 0.03877050708979368, 0.050641674016203196, 0.05371366667428187, 0.08289388194680214, 0.08389807306230068, 0.04888935393786856, 0.016718714398198893, 0.029497620383543626, 0.050606220561478815, 0.04469133920169302, 0.03776885030258979, 0.06110539646553142, 0.010832365435947264, 0.017031754832714796, 0.026056009344756603, 0.028934493993542025, 0.023104522809652344, 0.10267247884933438, 0.03335165857736554, 0.028135927826432244, 0.018369525637743727, 0.10087167405124221, 0.06684891719903265, 0.054616101285708804, 0.05773816643548863, 0.18665992175894125, 0.03568321346704449, 55.842060634068076, 91.89734009334019, 80.40073258536202, 71.7349670955113, 49.294717516217915, 36.71536527361189, 36.226455279758994, 38.67278746196202, 41.412517751966206, 19.93237199102129, 0.04190172567697508, 0.18145652168563434, 1.3864432211433138, 1.8517474702426364, 1.9426672543798174, 3.619389602116176, 1.8502740178789412, 0.7572426380855697, 21.575671332223074, 89.80686337607247, 76.38657065800258, 82.26284285954067, 71.73597458430699, 73.08078452519008, 66.8165249143328, 73.31877422332764, 68.74841594696045, 70.09228093283517, 66.85207884652274, 69.65056310381208, 66.21467195238385, 70.17302594866071, 66.72749069758824, 66.59188270568848, 59.22144903455462, 56.11650058201381, 51.00416891915457, 52.67062834330967, 52.23806129183088, 51.75835418701172, 54.903890541621614, 59.672595569065635, 60.03954383305141, 59.17254066467285, 55.027262755802695, 51.56450292042324, 49.72372361591884, 49.94153227124895, 48.82240676879883, 48.300826345171245, 45.49324689592634, 46.93035670689174, 45.93477364948818, 48.76306915283203, 50.35686779022217, 52.24489484514509, 52.375705105917795, 54.02516576222011, 48.841562952314106, 48.31490339551653, 46.17124169213431, 47.77315582547869, 52.1166067804609, 54.280956745147705, 55.89597865513393, 53.91700662885393, 53.648795740945, 49.838038853236604, 48.4236809185573, 54.03764125279018, 62.30571269989014, 55.23164749145508, 45.17617974962507, 65.40050288609096, 49.50042935780117, 54.830875396728516, 56.2295686176845, 65.08958489554269, 57.60529456819807, 60.29566832951137, 54.55428498131888, 55.68526063646589, 56.47118180138724, 57.992632320949006, 57.22288308824812, 58.98321614946638, 57.61034938267299, 57.7038026537214, 54.61393526622227, 51.02114336831229, 44.0019029208592, 45.141067028045654, 44.54972321646554, 45.59039660862514, 42.30980464390346, 46.047035694122314, 44.890827655792236, 47.69158049992153, 44.70196172169277, 48.21268497194563, 46.15350294113159, 48.38009139469692, 45.22130135127476, 50.38371910367693, 47.672625814165386, 50.9284474509103, 48.61363077163696, 50.95224503108433, 56.89027629579817, 66.28563390459333, 65.52079010009766, 65.09458759852818, 54.98233222961426, 52.954399721963064, 46.36023269380842, 51.15722731181553, 48.90817185810634, 55.783619335719514, 49.76784120287214, 55.66894279207502, 50.645898955208914, 70.39241531917027, 64.58424936022077, 79.85187353406633, 27.148517438343593, 0.41781059759003775, 0.2241328324058226, 1.4901507305247443, 0.28834826020257814, 0.06478658464870282, 0.7689050265720913, 53.78878109795706, 46.80191578183855, 31.407514776502335, 27.470517805644445, 17.46251494543893, 19.413826193128312, 27.569555691310338, 59.23784678322928, 62.21415628705706, 56.10307318823678, 61.19363267081124, 5.466083560671125, 0.3257650152913162, 0.014806422903867704, 0.026017008848222237, 0.04398481461352535, 0.05711910501122475, 0.061375283769198825, 0.04530721490404435, 0.14198681818587439, 0.05257523079801883, 0.05475911271891423, 0.06587824571345534, 0.0426354832681162, 0.03393769230959671, 0.036418837029486895, 0.01259036994140063, 0.03118916747293302, 0.032001560487385304, 0.19556046915905817, 0.14945906294243677, 0.13649703562259674, 0.11163859308830329, 0.14912336452731065, 0.15005742226328167, 0.23251924025160925, 0.18326394898550852, 0.11265867549393858, 0.16052131434636457, 0.15922497319323675, 0.16316675953567028, 0.1693845966032573, 0.13414497540465423, 0.3596239670046738, 0.1216664042856012, 62.49319594247, 102.51039382389614, 90.61698164258684, 82.73546627589634, 62.67796243940081, 42.95336764199393, 72.21344089508057, 73.83820070539201, 51.69766862051827, 27.533741201673234, 0.12196082063019276, 0.2873548577938761, 1.894514718226024, 3.6620775972093855, 5.265321007796696, 5.592179902962275, 9.893335001809255, 6.000778274876731, 23.2131724017007, 96.15912192208427, 78.3633678981236, 86.48841067722866, 73.71876117161342, 76.04584489549909, 69.6070465360369, 78.4290770121983, 73.26548154013497, 75.11549500056675, 68.15115574428013, 73.13991369519914, 69.07911545889718, 75.93197086879185, 68.08442524501255, 69.38759463174003, 60.19130638667515, 59.22406850542341, 54.15033408573696, 54.51475667953491, 54.51010833467756, 54.918992451259065, 58.60911818913051, 62.130534717014854, 63.06781891414097, 61.008233887808665, 57.83492905752999, 56.29876920155117, 53.63932882036482, 51.69885676247733, 51.01687022617885, 50.58147178377424, 48.0205568586077, 50.377806186676025, 48.345357349940706, 50.92884349822998, 51.968742166246685, 56.789944308144705, 53.69874286651611, 57.769952978406636, 52.10996082850865, 51.239921297345845, 49.52403238841465, 50.25426721572876, 56.23999091557094, 57.933676855904714, 58.20314884185791, 58.70937374659947, 55.686222961970735, 52.43535539082119, 50.95164053780692, 57.61753382001604, 65.60104874202183, 58.802034923008506, 49.69387068067278, 68.78100994655064, 51.690814222608296, 56.27175807952881, 58.08737448283604, 68.62365409306118, 60.38252081189837, 61.46709292275565, 54.49821996688843, 58.61799798692976, 58.095354488917756, 59.43665558951241, 58.90873146057129, 60.68266909463065, 59.74742071969168, 60.110505785260884, 56.913042068481445, 53.267454283578054, 49.351355757032124, 48.01699938092913, 47.017396790640696, 47.737181527274, 45.52566024235317, 49.91570234298706, 47.37028537477766, 50.20503922871181, 48.168160915374756, 51.0632529258728, 49.48105430603027, 50.99179417746407, 48.01138176236834, 53.01986912318638, 50.377351079668315, 54.78967605318342, 51.789297989436555, 54.016831398010254, 60.715812001909526, 68.77431188310895, 69.46495587485177, 68.20207909175328, 59.28761672973633, 55.71267475400652, 49.14401108877999, 53.88664994921003, 52.06907067980085, 58.13542822429112, 51.98740502766201, 58.494716099330354, 53.95214714322771, 75.4633287702288, 67.17038972037179, 84.41831997462681, 25.67348435946873, 1.4989443272352219, 2.9961383598191396, 2.731689270053591, 0.3496947469455855, 0.18240059459848063, 2.151626076017107, 67.30098111288888, 51.37372275761196, 49.93855149405343, 50.18972192491804, 24.48702907562256, 19.713462046214513, 33.771003586905344, 66.09950556073869, 72.63484219142369, 68.26558562687465, 68.46469320569719, 3.725837307316916, 0.4756207498056548, 0.17574850868965897, 0.15037596731313638, 0.18699985423258372, 0.12264363041945867, 0.24765401812536375, 0.15304422484976904, 0.33953354933432167, 0.1283001426075186, 0.21307782775589398, 0.19705957014645847, 0.12235209106334619, 0.10396853501775435, 0.06619345915636846, 0.08377312083861657, 0.08761559679572072, 0.13168603235057422], [0.07699600128190857, 0.07217361897762332, 0.014784640233431543, 0.03351412700223071, 0.12427115094448839, 0.0502905999975545, 0.015630707244521806, 0.03413277452013322, 0.029824670869857073, 0.05318331352568098, 0.017617790261283517, 0.071045215241611, 0.10426662223679678, 0.14376679195889405, 0.09265306113021714, 2.3731057686465125, 67.15951578957694, 62.8960941859654, 72.36931678227016, 54.65520756585257, 40.83481672831944, 23.72379204205104, 53.24542849404471, 42.035152775900706, 36.24078246525356, 5.511490038463047, 0.04674379228215132, 0.22771464235016278, 1.3585762764726366, 1.3449107983282633, 2.1622763616698126, 4.666622528008052, 1.374431739960398, 2.8630163030964986, 56.93509912490845, 82.9882903780256, 73.40343107495988, 73.19247681753976, 66.11092839922223, 64.84114510672433, 62.14350005558559, 65.2952515738351, 66.49016802651542, 64.48809323992047, 61.16369983128139, 61.89276736123221, 61.38230405535017, 61.37432752336775, 58.03745167595999, 59.10581711360386, 53.464658055986675, 50.21736880711147, 50.74787766592843, 49.377654688698904, 47.95079347065517, 49.47830976758684, 50.220988818577354, 53.38914850779942, 53.85053668703352, 54.13173375810896, 52.49964707238333, 48.4009359904698, 47.97218697411673, 45.69278873716082, 45.080499580928254, 44.492199080330984, 43.49590383257185, 44.69577087674822, 50.31305939810616, 51.10676949364798, 51.82134655543736, 51.38151863643101, 49.84776980536324, 49.371411732264924, 45.84234871183123, 42.719091756003245, 43.83094596862793, 42.6207469531468, 48.57238973890032, 50.01696538925171, 54.444322790418354, 54.249957357134136, 53.535970892224995, 49.593441418239046, 47.0811082976205, 48.1912636756897, 59.27545738220215, 51.7191732951573, 43.7511875970023, 60.26822294507708, 46.52224384035383, 55.84920685631888, 57.21295063836234, 58.290550231933594, 49.83263315473284, 54.0554529598781, 55.21956804820469, 57.977606841496055, 56.20855379104614, 56.3159625189645, 54.70202452795846, 54.67726809637887, 54.03292342594692, 52.65821886062622, 49.09967463357108, 45.694612639290945, 41.593827520098, 43.20980133329119, 41.17891584123884, 43.16789674758911, 40.164895738874165, 43.17549460274832, 43.901077611105784, 44.11971310206822, 43.75652033942086, 46.19704730170113, 45.165208544049946, 43.01713473456246, 44.77273259844099, 45.72954470770699, 44.28557007653372, 46.62121745518276, 45.37812219347273, 46.50671461650303, 46.7408515385219, 52.80825131280081, 53.274854115077424, 48.718017033168245, 44.44741446631295, 47.207336221422466, 49.37132487978254, 55.14860609599522, 57.76635381153652, 60.88834966932024, 59.52628040313721, 60.018400464739116, 55.99212782723563, 57.99488353729248, 59.99570764814104, 70.56583540780204, 49.763915470668245, 0.49329240726573126, 0.8375764616898128, 0.8884142594678062, 0.3313316623015063, 0.08400652331433126, 0.10248271296066896, 16.428011553628103, 59.77856254577637, 27.09330357824053, 63.08810070582798, 52.263564654758994, 26.76118837084089, 36.21995176587786, 41.06553513663155, 44.434994561331614, 50.676127093178884, 54.53709166390555, 37.71293898991176, 0.2084198205598763, 0.04501381975465587, 0.057241336309484074, 0.07235954435808317, 0.029534746427088976, 0.052646884095988104, 0.01664367351414902, 0.02714636592593576, 0.07736429651933056, 0.02020950395880001, 0.060671337614102025, 0.042275208314614635, 0.06966432183980942, 0.029157640412449837, 0.02711823725673769, 0.046711168318454704, 0.0043442878023987365, 0.0460203280672431, 0.04280236556327768, 0.05212024931928941, 0.012283296374204968, 0.030885380559733937, 0.03585963935724326, 0.05114665674045682, 0.040193205034094195, 0.0463502114372594, 0.03496122506580182, 0.04169607189084802, 0.07005377379911286, 0.006774717966826367, 0.10344536416232586, 0.20837325948689664, 4.173030316829681, 81.70288753509521, 70.6378812789917, 80.19523961203438, 62.36170823233468, 60.206814765930176, 35.66541951043265, 45.32594469615391, 39.93963861465454, 46.57240983418056, 6.727783492633274, 0.036870378335671763, 1.277768292597362, 2.338461399078369, 1.777630818741662, 4.60477009841374, 2.7989701969282965, 1.5100502627236503, 5.0037664941379, 61.57046127319336, 84.87385777064732, 77.1649078641619, 75.98785523005894, 68.64923736027309, 67.99435574667794, 68.2943650654384, 67.38941778455461, 68.60538727896554, 68.4097260066441, 64.54223360334123, 64.68197577340263, 63.98477963038853, 63.277904646737234, 60.29950373513358, 61.565277917044504, 56.77611739294869, 52.767006805964876, 53.265088421957834, 50.451801027570454, 50.25649758747646, 51.67910998208182, 53.01622826712472, 55.79026876177107, 56.743561608450754, 55.63215208053589, 53.42942026683262, 49.91454894202096, 49.94309561593192, 48.00136246000017, 48.057274614061626, 46.59327180044991, 45.98474856785366, 46.791490009852815, 52.39700828279768, 54.54600272859846, 53.42207949502127, 54.057040623256135, 52.17220973968506, 50.77638265064785, 48.379924637930735, 45.97886691774641, 45.48208808898926, 45.51759338378906, 51.517025879451204, 54.78770276478359, 55.928145340510774, 55.58051306860787, 55.14037595476423, 52.068858759743826, 49.737616539001465, 51.26425041471209, 64.59063475472587, 55.12567356654576, 46.94864089148385, 63.24131543295724, 48.52171652657645, 57.56712811333792, 60.855595861162456, 58.390159606933594, 52.12234599249703, 54.954132965632844, 56.462270736694336, 61.51438236236572, 59.90137195587158, 59.890956606183735, 57.74905974524361, 57.88785696029663, 54.996006284441265, 54.44361407416207, 49.13266120638166, 46.84435885293143, 42.66969353812081, 45.09233931132725, 44.04497480392456, 44.99429675510952, 43.66641957419259, 45.5473073550633, 46.94209221431187, 45.83457715170724, 46.98733193533761, 47.84403439930507, 47.17067405155727, 45.6171749659947, 46.53829417909895, 46.95619010925293, 47.346880367824006, 49.21550457818167, 48.238271713256836, 47.74374410084316, 49.63433156694685, 55.376006739480154, 55.696023396083284, 51.64910766056606, 46.829444544655935, 49.69126163210188, 51.7143234525408, 58.30872671944754, 62.843280928475515, 64.41415745871407, 63.2168299811227, 62.51598603384835, 60.54027271270752, 60.627375330243794, 64.25962257385254, 73.40468175070626, 55.98142065320696, 0.8325948204313005, 0.8425705337098667, 2.8031415045261383, 1.4356104114225932, 0.07082109512495142, 0.3027039170265198, 15.565545558929443, 67.13827514648438, 34.35331474031721, 41.492119789123535, 30.27436433519636, 27.435519729341777, 49.24102183750698, 48.86055932726179, 46.95754500797817, 60.29499435424805, 61.162629808698384, 53.81109871183123, 0.6555182965738433, 0.05218518851324916, 0.012972859283243971, 0.07097946519830398, 0.03349633581404175, 0.1745586839637586, 0.026844896209825362, 0.03499249874481133, 0.04977228406018444, 0.014963327341579964, 0.009698306110554507, 0.02307031785936228, 0.0669501953359161, 0.052427540865859816, 0.044603238214871714, 0.05248506027939064, 0.016760515548022728, 0.1752390917390585, 0.16718864015170506, 0.1651231659842389, 0.0764913951445903, 0.18020899434174809, 0.14925349397318705, 0.15541852744562284, 0.1079691503463047, 0.10174336084829909, 0.12408487951116902, 0.1464645250567368, 0.2625180333852768, 0.1605104035032647, 0.21205444767006806, 0.35259149436439785, 5.341854546751295, 95.05418464115688, 81.34914084843227, 90.81971618107387, 70.86332947867257, 58.767974853515625, 34.55020236968994, 77.42297090802873, 58.411031995500835, 58.0855644771031, 9.364222730909075, 0.13945362983005388, 0.9441555312701634, 4.949866712093353, 4.5616113628659924, 6.306903745446887, 14.419183118002755, 8.027960811342512, 6.070923379489353, 66.80931963239397, 86.24433435712541, 79.99508285522461, 79.61187580653599, 72.14580018179757, 70.6215877532959, 70.19664982386998, 70.02935109819684, 73.83708204541887, 72.5730379649571, 66.43571499415806, 70.37651784079415, 67.49004854474748, 65.96772602626255, 64.02346720014299, 65.5283705847604, 60.265339442661826, 54.95785025187901, 56.63934905188424, 54.88624906539917, 53.05093451908657, 54.64843307222639, 56.13959986822945, 57.9733441216605, 60.37691361563546, 57.764265877859934, 57.70539379119873, 52.20349747794015, 52.47756569726126, 48.79149770736694, 49.69661521911621, 48.92180074964251, 48.33338212966919, 49.55555289132254, 56.7450624193464, 55.80374131883894, 56.665887696402415, 57.05916963304792, 55.839934485299246, 54.340607030051096, 49.640810762132915, 47.934065682547434, 48.19243097305298, 48.391938073294504, 55.63090835298811, 56.670268535614014, 59.198193413870676, 58.82784053257534, 58.792328289576936, 55.260628427777974, 53.41734082358224, 52.272656372615266, 66.89537307194301, 58.771886689322336, 50.88060910361153, 66.43605545588902, 52.326636927468435, 60.26424857548305, 61.75239985329764, 59.21671731131417, 52.29898657117571, 55.67546020235334, 57.11504009791783, 65.31616565159389, 63.234575680324006, 62.79090540749686, 60.90922205788748, 59.75529302869524, 58.95512458256313, 59.6836154120309, 53.58745356968471, 50.13046073913574, 45.170419692993164, 49.273080825805664, 46.02785866601126, 48.77706282479422, 46.05543259211949, 48.36583716528756, 50.49256263460432, 49.277788230351035, 49.48079374858311, 50.90521614892142, 51.28004019601004, 46.915359020233154, 48.81840808050973, 51.37326070240566, 48.6205199105399, 53.04554271697998, 51.480728490012034, 51.41112143652779, 52.73325593130929, 58.77216461726597, 59.03737040928432, 54.39600501741682, 50.651370661599294, 53.44605425425938, 54.924978324345176, 62.4226439339774, 65.57961354936872, 66.61267866407121, 67.61272593906948, 65.16073444911412, 62.74485274723598, 63.524433680943076, 67.8980884552002, 77.83085100991386, 57.23840536390032, 0.6488052510789463, 3.8270547560283115, 5.330360489232199, 1.7622792082173484, 0.37707409635186195, 0.37201111231531414, 22.55212947300502, 74.53504943847656, 41.31447866984776, 87.47605541774205, 71.49453857966832, 35.539198534829275, 51.2643963268825, 56.53881556647164, 60.01117433820452, 65.505920955113, 71.21308095114571, 55.54431990214756, 0.519285401063306, 0.13184073833482607, 0.14215581411761896, 0.1700624937989882, 0.1151586292045457, 0.23452512547373772, 0.07248723786324263, 0.0972903390814151, 0.11634711043110915, 0.0977992539161018, 0.16347056680491992, 0.11705930078668253, 0.14656665814774378, 0.17807715944945812, 0.09968883145068373, 0.16793114745191165, 0.10788022154676062], [0.039388835696237426, 0.04684140293725899, 0.05582516587206295, 0.0406181715162737, 0.03778690272676093, 0.10875925687806946, 0.1440676408154624, 0.07087192418319838, 0.032869036974651475, 0.13994001730212144, 0.0666658484510013, 0.1010084802817021, 0.10096318806920733, 0.24945487720625742, 0.2835702065910612, 16.246616670063563, 76.23777498517717, 66.69903087615967, 60.85362952096121, 39.66071013041905, 14.698603187288557, 29.119177682059153, 49.04140704018729, 35.412380014147075, 26.550122942243302, 0.9057917584265981, 0.06913712048637015, 0.6910464444330761, 0.955627224275044, 0.6071193165012768, 0.6146418814148221, 1.9686300669397627, 0.9430009360824312, 15.753343207495552, 88.73721599578857, 69.66526549203056, 77.77843379974365, 64.73569229670933, 64.61587756020683, 62.58599608285086, 65.22339330400739, 64.01199572426933, 63.62680843898228, 61.15482003348214, 65.67413684300014, 58.668226514543804, 58.27246407100132, 55.53083692278181, 55.88642488207136, 53.814722197396414, 52.87362343924386, 49.3122512953622, 49.791346958705354, 47.4321278163365, 49.32582460130964, 47.5184383392334, 50.30132736478533, 48.62332003457205, 53.38687992095947, 49.701489380427766, 50.70296451023647, 47.43100915636335, 46.16245222091675, 47.71415172304426, 44.66928086962019, 44.84633139201573, 45.13703012466431, 49.76500981194632, 54.92379365648542, 53.77728877748762, 54.91541065488543, 50.723763942718506, 50.09701558521816, 46.33174160548619, 44.857632637023926, 43.10045058386666, 43.205201625823975, 42.62406471797398, 46.72221646990095, 47.42031587873186, 54.797364234924316, 53.10054465702602, 58.08976466315133, 50.76030799320766, 49.40843520845686, 46.408626896994456, 61.22683116367885, 51.109013761792866, 46.64609548023769, 58.98837171282087, 46.346669810158865, 55.54490007672991, 57.97860738209316, 50.6560572215489, 54.71026161738804, 57.10740402766636, 55.068854672568186, 53.22947890417916, 49.89929417201451, 51.31961018698556, 47.52415670667376, 46.90628467287336, 45.32905401502337, 44.059951645987375, 42.85971287318638, 42.017709323338096, 43.03527648108346, 39.73439230237688, 42.08163969857352, 40.73744814736502, 42.97369459697178, 41.2820132119315, 42.23383304050991, 42.236223220825195, 43.586129665374756, 43.896818365369526, 44.179960932050435, 43.347549370356965, 45.24004064287458, 43.79459299360003, 45.33903857639858, 44.546009404318674, 45.874178409576416, 44.829909324645996, 45.49672099522182, 44.85876519339425, 45.39100067956107, 43.90656321389334, 46.98962484087263, 49.72789600917271, 56.90945332390921, 60.865594318934846, 63.912143162318635, 62.82248497009277, 63.5812143598284, 61.805511883326936, 61.75013474055699, 61.76375320979527, 63.93380069732666, 64.14569990975517, 67.93412181309291, 3.9612635544368198, 0.32930129553590504, 0.5053388465728078, 0.5058005760822977, 0.08967573767794029, 0.006237351310638977, 0.8636508796896253, 50.858374868120464, 46.71148150307791, 30.383735929216655, 56.21850708552769, 25.256404842649186, 11.683961340359279, 21.359785590853008, 42.01848752158028, 49.040941510881694, 48.091695989881245, 57.353523118155344, 13.486992818968636, 1.0054177982466561, 0.0891333439254335, 0.12131435317652565, 0.041017781144806316, 0.07656063964324338, 0.023448000628767268, 0.04610900241615517, 0.03188754964087691, 0.025708185508847237, 0.06852183171680995, 0.023793441110423634, 0.024111470473664146, 0.025503552917923247, 0.022232445854959742, 0.03775211762902992, 0.05578686257026025, 0.06622388466660466, 0.05529418168589473, 0.10829273691134793, 0.010697845020331442, 0.03470774134621024, 0.038864199205168655, 0.06319974908339125, 0.13169957590954645, 0.046408273678805144, 0.07467064141694989, 0.04411008235599313, 0.08294469743434872, 0.07324190451098339, 0.2770638700042452, 0.2925855756870338, 25.8013242653438, 90.33403015136719, 72.87551389421735, 72.37338147844586, 48.94761330740792, 28.019269159861974, 23.168050800051006, 33.59837211881365, 39.556851931980674, 38.739021165030344, 1.0082934839384896, 0.13199154952807085, 0.7566897134695734, 1.748921947819846, 3.4385981261730194, 4.407386541366577, 1.5518093705177307, 1.1354003548622131, 20.69149742807661, 92.82685620444161, 73.67909390585763, 80.01548276628766, 69.11018780299595, 69.7500057220459, 65.08085100991386, 67.65918159484863, 67.56007249014718, 68.68417985098702, 65.13262898581368, 67.20882715497697, 61.531954356602256, 62.73702907562256, 59.57168688092913, 57.686480794634136, 56.039650031498496, 53.82032939365932, 52.665340764181956, 52.8624507359096, 48.764872210366384, 51.77053090504238, 49.88544641222273, 50.779776845659526, 51.84640175955636, 55.973433698926655, 52.513182163238525, 53.43408250808716, 49.55879075186593, 49.30735976355416, 48.947078296116416, 47.61492449896676, 47.83264977591378, 49.018339020865305, 52.83879211970738, 55.38091911588396, 56.37336506162371, 55.42744772774832, 53.36536134992327, 51.65812642233712, 47.54359776633126, 46.98540381022862, 45.068298544202534, 45.81818635123116, 45.03779247828892, 48.97899832044329, 50.0513277053833, 56.793091842106406, 55.06166328702654, 60.30251925332205, 53.27778625488281, 52.31979990005493, 49.13881731033325, 63.75885200500488, 53.79771648134504, 50.48419005530221, 61.397701263427734, 48.400060517447336, 57.90925741195679, 60.81956250326974, 50.930191448756624, 54.57718971797398, 59.78416279384068, 58.3450380052839, 55.74571691240583, 53.862522329602925, 52.73285640989031, 48.99885279791695, 48.82904577255249, 46.62229790006365, 45.08613804408482, 44.936129910605295, 44.40335941314697, 45.02261413846697, 41.75747496741158, 44.35609081813267, 42.58628388813564, 44.70499461037772, 42.51295607430594, 45.35680512019566, 44.38199370247977, 46.845154421670095, 45.6157922744751, 47.11191313607352, 45.130227838243755, 47.70283310753958, 45.19994953700474, 47.438290868486675, 47.324163232530864, 48.25311653954642, 46.68866014480591, 47.11133296149117, 46.372617857796804, 47.93226957321167, 45.75610072272164, 48.65113019943237, 52.941795689719065, 60.53249767848423, 64.60104315621513, 66.20317963191441, 64.09523514338902, 67.95978845868791, 64.9104255948748, 67.60110855102539, 65.26392909458706, 68.32684094565255, 63.824978010995046, 72.29875782557896, 4.963965475559235, 0.8485409361975533, 2.0382208355835507, 2.026781277997153, 0.6551483049988747, 0.01728689587408943, 0.51058500792299, 50.971609660557334, 56.7649690083095, 36.77558183670044, 41.00873361315046, 22.9683769430433, 22.424841948917933, 32.178917680467876, 51.429954528808594, 54.02828550338745, 54.06400966644287, 65.99048137664795, 25.40394115447998, 0.6800599311079297, 0.12738044267254217, 0.13006600285215036, 0.05103779936741505, 0.08950106919343982, 0.03466809115239552, 0.07664609434349196, 0.01643171613769872, 0.037408354825207164, 0.043251057022384236, 0.06938616319426469, 0.041089220704244714, 0.029265473197613443, 0.03313401507745896, 0.04047894970114742, 0.05614705949223467, 0.13968662518475736, 0.1636407705289977, 0.1890609993466309, 0.18672611963536057, 0.18658966624311038, 0.14521812408098153, 0.18812373892537185, 0.2226400010819946, 0.16227321034031256, 0.40767111309937065, 0.12359515364680972, 0.2847610084073884, 0.20135218623493398, 0.3852896083678518, 0.5557460731693676, 31.13902943474906, 101.84140736716134, 84.92195320129395, 82.04839365822929, 53.90316929136004, 23.297718082155498, 40.753356048039024, 67.63806601933071, 49.358654839651926, 44.81847953796387, 1.6449668002980096, 0.14388474848653587, 2.7442160035882677, 3.8516822116715566, 3.1590584175927297, 7.697398526327951, 10.355342439242772, 3.3913896765027727, 23.39694878033229, 97.82943412235805, 76.94091878618512, 84.16933127811977, 71.17273276192802, 72.52353899819511, 69.19371904645647, 70.47304221561977, 70.7203424998692, 71.26672799246651, 66.86938680921281, 72.36596775054932, 65.62273406982422, 66.21066978999546, 61.55046435764858, 62.004362378801616, 59.227132661002024, 58.516054017203196, 56.3841347694397, 55.20644290106637, 50.856068066188264, 55.30675057002476, 51.97401932307652, 54.925759996686665, 53.68168156487601, 58.634486062186106, 55.13999727794102, 55.664596693856375, 51.789186818259104, 51.859881264822825, 52.14002568381173, 49.81942810331072, 49.10064738137381, 50.03533295222691, 56.19249650410244, 59.669441086905344, 60.614382198878694, 58.536745752607075, 57.445458207811626, 54.55713374274117, 50.048301764896934, 50.737097535814556, 48.07184498650687, 48.11112315314156, 47.87569039208548, 52.029087271009175, 52.04717343194144, 59.19528211866106, 57.117454596928184, 63.772651127406526, 55.18571989876883, 55.18657452719552, 51.857213156563894, 67.37195001329694, 57.033409186771934, 53.783406666346956, 64.0665807723999, 51.26535865238735, 61.91802406311035, 64.62380545479911, 52.127671786717, 56.31625781740461, 61.8567340033395, 60.98431124005999, 58.44079113006592, 55.54442759922573, 54.919523988451274, 52.01719542912075, 52.50545229230608, 48.80565813609532, 49.251583099365234, 48.233512197222026, 46.980481011526926, 46.98844712121146, 44.023411069597515, 47.54027305330549, 44.97930601664952, 48.49200602940151, 46.84926080703735, 47.55942228862217, 47.181051186152864, 48.691829272678916, 47.48978049414498, 47.683628286634175, 47.309836047036306, 51.13017450060163, 46.64878443309239, 49.32182591302054, 50.162147998809814, 52.26251547677176, 49.53801563807896, 50.75502041407994, 49.18913616452898, 50.814180850982666, 48.250420638493125, 53.50018072128296, 56.01684604372297, 62.00024904523577, 66.40096705300468, 70.66668156215123, 67.33900165557861, 69.21088109697614, 68.33091259002686, 70.37368297576904, 68.5803668158395, 71.8372584751674, 69.246351650783, 75.99261474609375, 5.687499633857182, 1.7946565108639854, 3.3308600102152144, 2.43695450254849, 0.6814232436673981, 0.22208277455398015, 1.3721429599182946, 65.60002040863037, 60.991252490452354, 48.219226700919016, 74.57439708709717, 35.41077845437186, 18.148137126650127, 36.95819091796875, 55.831256185259136, 64.85834189823696, 60.8721603666033, 78.70319734300885, 26.679145778928483, 1.510799365384238, 0.21435747694756302, 0.2428113951214722, 0.20765617010848864, 0.2494641595653125, 0.13184858219964163, 0.18665057154638426, 0.18275595695844718, 0.10859036951192788, 0.22035423373537405, 0.19281854986080102, 0.1343184360968215, 0.17651142632322653, 0.1357506335313831, 0.11742771816040788, 0.25575062366468565], [0.02011850053843643, 0.0535601786603885, 0.04300296087084072, 0.024010417949674383, 0.03917353314214519, 0.041699498492692194, 0.012673504900054207, 0.03731832679893289, 0.0328101876324841, 0.09370158772383418, 0.049458437865333896, 0.09552739653736353, 0.04467203827308757, 0.02810464396939746, 0.1210917801197086, 40.747689792088096, 67.5971758706229, 60.9444911139352, 66.22251646859306, 32.305864742824006, 29.469443321228027, 60.45319093976702, 47.394267082214355, 31.952614852360316, 20.687257289886475, 0.5696083807519504, 0.12152171347822462, 2.8139014414378574, 1.0909570710999625, 3.537127273423331, 7.1139174699783325, 0.8905433937907219, 0.8357123360037804, 57.767343929835725, 79.9528933933803, 73.68545150756836, 71.45371791294643, 63.940408434186665, 60.32805388314383, 59.01407309940883, 60.33669049399239, 60.97741862705776, 63.910670144217356, 63.20742212023054, 60.55279336656843, 60.83365345001221, 56.85926995958601, 52.47717659814017, 55.693862506321494, 54.515607833862305, 50.26578038079398, 47.96341487339565, 46.65970352717808, 46.744902338300435, 48.58396543775286, 49.371345724378315, 46.911329065050396, 47.232262883867534, 47.32823140280587, 48.87746776853289, 47.57022673743111, 47.08286966596331, 46.359815801892964, 43.91086067472185, 44.20477989741734, 43.220463344029014, 49.714565890175955, 55.4091010093689, 57.08082716805594, 54.72693034580776, 50.832590103149414, 50.10937990461077, 46.53401408876692, 45.399696350097656, 44.86963217599051, 43.77030903952462, 43.99070937292916, 42.973361083439414, 44.105611733027864, 46.43446724755423, 50.46272359575544, 54.408810547419954, 54.5182238306318, 53.117425305502756, 50.71657950537545, 44.44907855987549, 56.15066487448556, 52.91839763096401, 48.51284715107509, 56.327906472342356, 47.14388179779053, 56.564256395612446, 56.51775905064174, 55.84501361846924, 56.77358130046299, 55.04929896763393, 50.82728862762451, 49.08368335451399, 46.31279386792864, 43.75532872336251, 43.999477999550955, 42.94967120034354, 43.28263929912022, 44.20451239177159, 43.55866691044399, 41.915605545043945, 43.46797554833548, 41.74125092370169, 39.56373759678432, 41.41301454816546, 40.633409295763286, 42.29051297051566, 42.2911765234811, 41.38149751935686, 43.38116822923933, 43.79613201958792, 44.062883785792756, 44.1546173776899, 43.97429077965872, 44.24672964641026, 45.36293690545218, 44.15610081808907, 43.42656775883266, 43.70805318014962, 45.8270765713283, 45.29064784731184, 45.6609069279262, 45.610362257276265, 49.93115861075265, 53.425744669778005, 59.962265968322754, 59.13547202519008, 61.981294359479634, 60.98488099234444, 63.47783211299351, 62.441946029663086, 65.08743095397949, 62.30294731685093, 66.931503704616, 62.42243548801967, 69.66782937731061, 6.961173917566027, 0.2753931539399283, 1.6495620565755027, 1.3872611543961932, 0.26283830191407886, 0.03693826576428754, 0.02528766173470233, 12.852801203727722, 73.20786707741874, 31.619889940534318, 35.325214862823486, 41.279244354793, 19.162257977894374, 20.410465376717703, 21.13580346107483, 38.143438952309744, 54.503208773476736, 48.959640639168875, 45.64117751802717, 2.569669872522354, 0.20537021277206285, 0.13681087163942202, 0.037324172378118546, 0.028107985754364302, 0.06529792863875628, 0.04663687551926289, 0.030907605974269763, 0.015928009059280157, 0.03110630138378058, 0.03344752200480018, 0.03578660524051104, 0.07772687849189554, 0.017438550147094896, 0.05890925002417394, 0.036839131798063, 0.049558633738862615, 0.04550315546137946, 0.029826882894017866, 0.0674437413524304, 0.04003114373024021, 0.030875375560883964, 0.06040620684091534, 0.05726276444537299, 0.03818986092561057, 0.04479253591437425, 0.036362807000322, 0.03851247040022697, 0.061298527887889316, 0.044893732627055476, 0.4753606809037072, 59.01720673697335, 75.10546875, 70.1645074571882, 73.98158373151506, 45.86785902295794, 35.611025537763325, 39.3488506589617, 44.820706435612266, 40.180115767887656, 23.697104011263164, 0.48223728047949926, 0.5894281715154648, 3.208903274365834, 2.5720596185752322, 8.918963057654244, 7.203756374972207, 2.1870866417884827, 1.6089820797954286, 64.49169240679059, 82.65168489728654, 76.2531305040632, 75.85477638244629, 66.27491283416748, 63.25643471309117, 60.41193948473249, 63.097939355032786, 63.11419813973563, 66.10294491904122, 65.97797461918422, 62.977422850472585, 63.084980964660645, 61.428940364292686, 57.53790051596505, 58.224924496241975, 55.98961952754429, 52.42390823364258, 50.40955598013741, 50.10103511810303, 49.91240542275565, 50.88219676698957, 50.880216530391145, 49.41029037748064, 50.22036695480347, 51.205215045383994, 51.77183716637747, 50.32347822189331, 49.69211973462786, 49.15634066717965, 46.712263175419395, 47.221639088221956, 45.97181102207729, 51.76873826980591, 56.93406384331839, 60.369485991341726, 57.87177882875715, 53.951275144304546, 53.380466733660015, 48.42239202771868, 47.690444469451904, 48.052129473005024, 46.787289823804585, 47.19623647417341, 45.43941225324358, 47.47895172664097, 49.82453155517578, 53.41603456224714, 57.358960083552766, 56.72206040791103, 56.913042068481445, 52.904390062604634, 47.213450636182515, 60.820702007838655, 55.89935547964913, 49.27673210416521, 58.747102464948384, 50.14236647742135, 59.1230833871024, 58.61331490107945, 57.796620164598735, 58.33839552743094, 57.620827266148154, 52.01668473652431, 51.45228256498064, 48.71194430759975, 47.3219120161874, 46.0110752923148, 45.969507694244385, 46.298869677952354, 46.632935592106406, 45.27944735118321, 42.40190996442522, 44.42015668324062, 44.41306604657854, 42.400634969983784, 42.27635948998587, 42.43667875017439, 45.124450411115376, 45.1362692969186, 44.02121196474348, 44.43916000638689, 46.68792363575527, 45.451359680720735, 46.45053843089512, 45.5953437260219, 45.877016748700825, 47.0412985937936, 46.36346360615322, 45.94610963548933, 46.941300119672505, 48.61330073220389, 47.390039103371755, 49.157872744968955, 47.75980486188616, 49.94643422535488, 55.625544343675884, 62.86036654881069, 62.58225795200893, 64.82481684003557, 63.05144201006208, 67.22919927324567, 65.58683967590332, 68.28244195665631, 65.03195653642926, 68.624098777771, 65.9393287386213, 70.26114995138985, 9.368083323751177, 0.891835053052221, 2.8279669838292256, 1.9040283220154899, 1.5073744463069099, 0.17700511483209475, 0.06545490771532059, 10.801294326782227, 77.51289449419293, 39.79876388822283, 39.216101850782124, 27.47208115032741, 20.917402471814835, 36.36797618865967, 33.924867970602854, 47.36859348842076, 61.807228088378906, 53.3081568309239, 64.00966112954276, 8.419003690992083, 0.4813479653426579, 0.08294032766882863, 0.043978670478931496, 0.0022575267191444126, 0.051169916920896084, 0.025554029137960503, 0.01747600019111165, 0.007245124666951597, 0.03861876630357333, 0.02902433542268617, 0.05163903567673905, 0.023782087523224096, 0.02991966577246785, 0.03865664552098938, 0.03187451159049358, 0.17881358707589762, 0.15849853360227176, 0.12542486403669628, 0.093170824061547, 0.14069404612694467, 0.08812582798834358, 0.18300499288099153, 0.14648849091359548, 0.19652035193783896, 0.26500779549990383, 0.2377205097249576, 0.10536519757338933, 0.15838547609746456, 0.1325063676174198, 0.6934687601668494, 72.50976766858781, 86.83113057272774, 80.6952041898455, 81.60392434256417, 45.08905628749302, 40.95998852593558, 85.29353591373989, 65.59133516039167, 49.40848731994629, 30.17968818119594, 1.0962051323481967, 0.40465540492108887, 6.000887709004538, 4.768372816698892, 10.743038892745972, 13.45655710356576, 5.084673489843096, 2.0046701558998654, 67.88031496320451, 84.70655904497418, 79.23351860046387, 77.1572231565203, 71.02233900342668, 66.24865559169224, 63.44936534336635, 68.21682316916329, 68.08771174294608, 70.2455165045602, 70.89454078674316, 66.28897598811558, 68.10743767874581, 62.93258612496512, 60.15102073124477, 63.23910590580532, 59.85549994877407, 55.589007241385325, 54.172745500292095, 51.8412218775068, 51.672811440059114, 53.71295540673392, 54.72342497961861, 53.385886328560964, 53.87319128853934, 54.25050279072353, 53.28576626096453, 53.60611295700073, 52.48906149183001, 52.58677748271397, 49.05251720973423, 48.97931446347918, 49.40592690876552, 54.39970145906721, 59.84369495936802, 63.42547048841204, 58.1259890965053, 57.00910438810076, 56.251302582877024, 50.984713963099885, 51.01879140308925, 49.26684134347098, 48.37400129863194, 49.95136397225516, 47.70603970118931, 50.301890168871196, 51.831615992954795, 55.511778014046804, 60.471555028642925, 59.94682012285505, 58.41422816685268, 54.820123059409006, 48.64662776674543, 65.29067271096366, 59.194788796561106, 53.946251596723286, 60.93845312935965, 52.20362949371338, 60.1984977722168, 59.920625414167134, 60.25722394670759, 62.58820561000279, 60.942503929138184, 53.716724804469514, 55.90692901611328, 50.202972139631, 49.85550662449428, 49.79620722361973, 49.26724086488996, 50.25881481170654, 49.50021743774414, 47.098857470921104, 45.12179272515433, 46.820106165749685, 45.94688088553292, 44.13285909380232, 46.2399628502982, 45.40407024111067, 48.93320621762957, 49.64460447856358, 47.38085011073521, 47.51036105837141, 49.355316230228965, 49.10343708310808, 47.54489707946777, 47.993424143110005, 48.14923402241298, 50.415611335209434, 48.93342161178589, 47.86942311695644, 50.3891977582659, 51.38038260596139, 51.147121156964985, 51.08844709396362, 50.43451738357544, 53.356328691755024, 59.65729563576834, 65.59266226632255, 65.50505937848772, 66.61370699746269, 65.16932937077114, 69.05924361092704, 67.71273136138916, 71.3737302507673, 68.95559038434709, 72.62040383475167, 67.125643321446, 72.1474608012608, 10.701934218406677, 1.3217524524245943, 7.133381545543671, 3.1610377856663296, 1.3946783563920429, 0.21230166511876242, 0.20730056347591536, 15.86091000693185, 88.71863651275635, 44.377831731523784, 53.64403622491019, 55.74579334259033, 28.522134610584803, 31.113307203565324, 34.37128625597273, 50.65101282937186, 72.02144132341657, 62.45889963422503, 74.96553203037807, 6.840665229729243, 0.6601845547556877, 0.24170603443469318, 0.155694664056812, 0.12063401325472764, 0.1454149399484907, 0.16359676074768814, 0.09340176345514399, 0.11015822645276785, 0.08900656644254923, 0.16410194363977226, 0.06825453641691379, 0.1051670110651425, 0.08729604072868824, 0.13755924148218973, 0.09245015201824051], [0.03279528021812439, 0.011237661187936152, 0.0462345449653055, 0.03675307320164783, 0.06160100522850241, 0.022256554204172323, 0.17184823511966638, 0.026044613349118402, 0.17763138908360684, 0.034306153788098266, 0.13609317157949719, 0.04195930276598249, 0.20593142908598694, 0.17473386813487324, 3.3242325144154683, 66.27867180960519, 67.49661459241594, 61.75932720729283, 42.50396163122994, 23.582352774483816, 22.05267906188965, 43.834242888859336, 35.05461379459926, 36.77337578364781, 13.86316568510873, 0.06212917688701834, 0.9761996460812432, 0.30588057371122496, 1.0160827402557646, 8.993587579045977, 7.018011919089726, 6.601086131164005, 21.92456122807094, 85.21848147256034, 72.36703082493374, 76.66890375954765, 66.23433535439628, 62.97803429194859, 56.61950152260916, 56.01657853807722, 54.093890394483296, 58.121226106371196, 57.663680280957905, 61.092202867780415, 57.44454451969692, 57.52312169756208, 53.18616036006382, 53.138408865247456, 53.68381118774414, 50.19928959437779, 49.545061111450195, 48.40773827689034, 45.244501386369976, 47.71899461746216, 46.0388993535723, 47.32511860983712, 44.79091950825283, 46.30946568080357, 45.148845536368235, 48.18209205354963, 45.1559431212289, 45.638822078704834, 44.67287308829171, 45.17436626979283, 46.1979193006243, 45.00155067443848, 51.638324056352886, 57.93365601130894, 55.908440249306814, 52.95419822420393, 52.12265171323504, 49.720913069588796, 44.617124216897146, 42.90326418195452, 43.83526774815151, 42.99443844386509, 42.97955540248326, 45.63904789515904, 46.939646448407856, 47.21177612032209, 45.31136737551008, 48.69154439653669, 52.44827209200178, 51.00655562537057, 52.22650991167341, 45.14647620064871, 56.01630061013358, 52.85029486247471, 47.472753933497835, 58.142372948782786, 46.99521466663906, 57.31765651702881, 56.11814383098057, 56.93963977268764, 51.698874132973806, 53.55473102842058, 47.17948089327131, 48.18423557281494, 46.0205317905971, 44.674957547869, 43.197193826947895, 43.675507817949565, 43.241870743887766, 44.26898125239781, 44.01617104666573, 42.03797721862793, 41.5974440574646, 42.269373076302664, 40.36616768155779, 38.61051075799124, 41.12196493148804, 39.02525568008423, 40.20167602811541, 42.01413794926235, 41.15891892569405, 41.82428537096296, 43.71362910951887, 43.7881624358041, 43.93190329415457, 44.75767585209438, 42.6743939944676, 44.73062998907906, 43.831293378557476, 44.590179102761404, 46.678171839032856, 44.961271967206685, 43.18254355021885, 45.84799064908709, 48.428756577628, 50.701105867113384, 56.154350893838064, 62.61712401253836, 61.823709215436665, 61.28466796875, 61.517599378313335, 64.03461905888149, 62.33196299416678, 61.8395163672311, 63.85180500575474, 59.43684319087437, 65.62708364214215, 11.649980306625366, 0.358181428696428, 1.7268566404070174, 2.4344016909599304, 0.206706736768995, 0.10437425824680499, 0.15739047234611853, 0.661789100084986, 49.022042410714285, 62.313223702566965, 28.900941712515696, 44.801001344408306, 31.846832002912247, 9.67430259500231, 20.160964250564575, 32.01798350470406, 43.33877379553658, 50.34617798668997, 55.998850209372385, 36.35496916089739, 0.20091226484094346, 0.06092814276260989, 0.02882235251101, 0.03998885742787804, 0.060347133582191806, 0.024593647635940994, 0.01295904939927693, 0.02945754610534225, 0.11342558291341577, 0.03893514682671853, 0.01829796563833952, 0.0821814676746726, 0.0442693922003465, 0.01480125925237579, 0.05400990827807358, 0.019023923469441276, 0.02200548946192222, 0.055446048001093526, 0.007432821871978896, 0.061575750155108314, 0.04868709282683475, 0.11549337767064571, 0.02838298412305968, 0.09877747749643666, 0.02470882556268147, 0.15383968502283096, 0.0938782918133906, 0.3051697404256889, 0.23201902423586163, 7.5312636239188055, 80.46772016797746, 74.64509500776018, 69.82553958892822, 57.83691276822771, 26.004737990243093, 25.86010949952262, 42.62554815837315, 37.60347012111119, 42.85756935392107, 13.248429025922503, 0.17919163964688778, 1.9295342905180795, 2.1182857964720045, 4.67328541619437, 6.764653674193791, 5.058740207127162, 9.810933709144592, 24.537895100457327, 89.06833934783936, 73.77463858468192, 80.23000144958496, 67.32277066367013, 67.90787151881626, 58.5563188280378, 59.78653907775879, 56.53118297031948, 61.37424414498465, 59.471903800964355, 63.411893708365305, 59.96763692583357, 59.50227437700544, 55.9166009085519, 56.2525497845241, 55.82248061043875, 53.32594421931675, 51.3101988519941, 50.52014350891113, 47.21081032071795, 51.03955609457833, 48.40972893578665, 50.52643857683454, 47.70741197041103, 49.109690461839946, 46.58403417042324, 49.9758494240897, 47.95822804314749, 49.8033013343811, 47.49103464399065, 47.33332443237305, 47.010493755340576, 47.507946559361045, 54.14946208681379, 61.4316987991333, 58.79440580095564, 56.13325268881661, 54.3228439603533, 51.3686922618321, 49.63669395446777, 45.0572578566415, 44.443870885031565, 47.16412884848458, 43.68890047073364, 47.96387345450265, 49.625194685799734, 49.07877097811018, 46.16167402267456, 50.41764715739659, 55.30215433665684, 53.21059717450823, 54.25163534709385, 49.186349936894004, 58.550662994384766, 54.84878090449742, 51.521083627428325, 60.14132104601179, 51.15171044213431, 60.782104764665874, 57.92137854439871, 57.35682003838675, 53.68490900312151, 55.476321356637136, 48.647221837724956, 51.04481588091169, 49.16585622514997, 49.12060260772705, 44.45534930910383, 47.19850853511265, 46.87393386023385, 46.1238306590489, 44.96523591450283, 45.2404088973999, 43.13760607583182, 44.8661858694894, 41.874718870435444, 41.995655741010395, 42.460205350603374, 41.90371370315552, 43.61293928963797, 45.204267842429026, 43.75454010282244, 44.58958503178188, 44.88159697396414, 46.825216565813335, 47.31664875575474, 46.41305637359619, 46.66073186056954, 47.06780249731881, 45.632415839603965, 47.17098324639456, 48.30483545575823, 47.726915563855854, 46.80837760652815, 50.292131423950195, 51.27276195798601, 53.80762113843645, 58.137036732264924, 63.87415736062186, 64.05175331660679, 64.21467467716762, 63.60100282941546, 65.45966679709298, 65.11810030255998, 62.76547500065395, 66.16250487736293, 60.53830637250628, 66.13284996577671, 15.325745855058942, 0.24651231510298593, 2.0313614436558316, 2.841841450759343, 1.4908349109547478, 0.312225907508816, 0.11268091787184988, 0.4022344191159521, 49.708639076777864, 69.25805936540876, 37.595264298575266, 37.005761759621755, 28.83122522490365, 17.779391016278947, 34.02809388296944, 39.216959953308105, 46.84029763085501, 59.50418513161795, 63.60412951878139, 52.13785089765276, 0.2737468922776835, 0.08087120298296213, 0.051736649724521806, 0.02588379376434854, 0.05806943401694298, 0.04451986322445529, 0.005633829186470913, 0.08332496881484985, 0.09060282685926982, 0.06766735935317618, 0.03163680720276066, 0.11324600862073046, 0.01987280640085893, 0.026627888836498772, 0.06160696955131633, 0.18985198118856975, 0.10574164201638528, 0.19497976531939848, 0.12333161064556666, 0.15529378556779452, 0.24056533564414295, 0.2983482650348118, 0.14275033293025835, 0.31560593470931053, 0.11822962441614696, 0.2969784385391644, 0.3317357977586133, 0.43414882517286707, 0.5188756201948438, 9.210352267537798, 93.4182243347168, 84.51021684919084, 82.33392987932477, 59.316931179591585, 34.589855739048545, 32.16940907069615, 60.093371527535574, 50.301237038203645, 52.499306610652376, 18.98681422642299, 0.2574838192335197, 2.1785051822662354, 2.6064925023487637, 5.052017390727997, 19.719126565115793, 20.203131130763463, 15.44624846322196, 28.312370232173375, 94.66320255824498, 74.61565549033028, 86.28260503496442, 70.8694577898298, 72.24637535640171, 61.835694858006065, 65.48976639338902, 59.245767729622976, 66.02429825919015, 63.39317526136126, 68.2599367414202, 63.912657329014365, 63.13853073120117, 59.83856718880789, 59.64330891200474, 58.588301386152, 56.27688932418823, 54.4027864592416, 52.45743676594326, 49.177167892456055, 54.18892438071114, 50.92428895405361, 53.13674477168492, 49.28355870928083, 53.33593920298985, 48.62151002883911, 53.98847927365984, 50.029833453042166, 50.32589619500296, 50.4912702696664, 51.697116238730295, 51.277795927865164, 49.353766781943186, 56.26541090011597, 64.19915240151542, 61.55503627232143, 57.56203160967146, 57.43466418130057, 55.09640080588204, 49.48146424974714, 47.40370621000017, 47.898831367492676, 48.81026479176113, 47.3780951499939, 50.217080456869944, 52.094952719552175, 52.937720571245464, 49.0924346106393, 53.11092873982021, 57.158713000161306, 55.7156138420105, 56.70730938230242, 51.18613529205322, 61.27819224766323, 59.48851694379534, 53.843442576272146, 64.86062785557338, 53.85907254900251, 63.68759822845459, 58.7919739314488, 61.255985804966514, 57.77890920639038, 60.42418915884835, 51.82553284508841, 55.0677672794887, 52.09381321498326, 51.52874401637486, 48.188234261104036, 50.28615597316197, 48.75920942851475, 48.08655432292393, 48.348206111363, 47.81104782649449, 45.56911775044033, 47.74329941613333, 45.39721931729998, 45.35745825086321, 46.65636839185442, 43.27956472124372, 45.50563900811331, 48.45547240121024, 46.72113602502005, 47.68863793781826, 46.81732341221401, 49.08594846725464, 49.61426516941616, 48.892917088099885, 48.13976015363421, 49.87797015053885, 48.42292703901018, 50.46246303830828, 53.06631783076695, 50.282636710575645, 48.49447611400059, 52.149259839739116, 55.15775339944022, 56.77856663295201, 61.15243680136544, 68.4054320199149, 68.11429555075509, 67.20485278538295, 66.89936133793422, 67.84098815917969, 68.24945190974644, 65.16925988878522, 68.44442531040737, 62.28746673039028, 68.93475273677281, 18.19639583996364, 0.7141274916274207, 9.733498641422816, 6.901881030627659, 2.7455450636999945, 0.44281963418637005, 0.21784889245671885, 1.1863361873797007, 60.214249338422505, 75.94639532906669, 43.56558731624058, 61.945191519601, 43.6443520954677, 13.499161720275879, 30.274458135877335, 43.304272515433176, 59.265000343322754, 66.3997997556414, 75.84282548086983, 56.54514537538801, 0.3375412890953677, 0.14053706026503018, 0.09224249316113335, 0.12916049786976405, 0.11542560559298311, 0.09479765248085771, 0.16875035635062627, 0.2051303099308695, 0.16581683233380318, 0.15134678807641777, 0.09535605965980462, 0.21166537569037505, 0.09103645823363747, 0.10919300360339028, 0.16305172070860863], [0.05594200960227421, 0.031772263148533444, 0.06699301089559283, 0.06789787805506162, 0.037895369942166975, 0.061138481833040714, 0.07121714922998633, 0.05028938202719603, 0.11884103875075068, 0.05838398249553783, 0.08770482415067297, 0.053509342816791365, 0.15299021346228464, 0.197352602279612, 24.90079951286316, 74.23524856567383, 61.61853585924421, 57.169302054813926, 26.159886053630284, 107.9369091306414, 58.95761203765869, 36.439601693834575, 40.81769289289202, 49.70157275881086, 4.642788469791412, 0.29539891758135384, 3.3710790063653673, 1.6227619860853468, 1.2204895147255488, 4.353755133492606, 1.9784122620310103, 11.406466790607997, 52.05837392807007, 73.77270698547363, 74.99280370984758, 68.51612377166748, 63.452547618321006, 59.09451239449637, 57.55352006639753, 53.107510226113455, 53.244056224823, 52.46926259994507, 53.990661008017405, 51.10413612638201, 50.147938932691304, 53.07908861977713, 50.28329331534249, 51.53907598767962, 50.120635986328125, 48.412209442683626, 47.21057408196585, 46.26511532919747, 47.44050734383719, 48.249444416591096, 48.01521716799055, 47.10523591722761, 46.05784361703055, 45.25235285077776, 47.768410205841064, 45.52594511849539, 46.23593636921474, 43.98941353389195, 43.98179830823626, 44.15091398784092, 44.76184824534825, 45.45407295227051, 55.96205254963466, 58.66874762943813, 58.77780655452183, 57.76724318095616, 55.35127462659563, 50.05055298124041, 48.047807693481445, 46.50700991494315, 44.64316259111677, 42.60655525752476, 43.14557565961565, 46.51749127251761, 53.20496218545096, 49.88150678362165, 46.72122982570103, 44.19762325286865, 49.66828393936157, 49.85783427102225, 49.49468319756644, 45.55766017096383, 55.205299922398154, 51.142500604902, 46.51723418916975, 56.09278638022286, 50.66679566247122, 57.04820537567139, 57.20707941055298, 54.51507977076939, 52.74032572337559, 51.12167337962559, 48.963868618011475, 47.634990896497456, 43.99941199166434, 44.33819225856236, 42.857315744672505, 42.17822313308716, 40.25119931357247, 43.22989552361624, 43.879124777657644, 43.72569465637207, 41.87547622408186, 40.78714166368757, 40.794194085257395, 37.24331372124808, 38.51420177732195, 39.23095709936959, 38.93067332676479, 41.775244985307964, 42.703055313655305, 42.23745652607509, 40.677165576389854, 43.66001680919102, 44.56783717019217, 45.29808589390346, 43.25045871734619, 42.93501744951521, 42.38132592609951, 44.06422826222011, 44.492122650146484, 44.88549491337368, 47.50581693649292, 43.93869168417794, 45.418876852308, 49.807126317705425, 52.59123822620937, 53.9787483215332, 57.417397907802034, 55.345549310956685, 58.41274125235421, 62.35564245496477, 63.802535329546245, 59.76973833356585, 64.33967276981899, 60.773634910583496, 61.71028682163784, 29.097407238824026, 0.38746984994837214, 1.5235080548695155, 1.4704902597836085, 1.6883069489683424, 1.1761769439492906, 0.09093264237578426, 0.1534513458609581, 14.537897433553423, 69.85410363333565, 43.77426951272147, 32.8704058783395, 40.891024180821006, 27.904462337493896, 9.997421622276306, 20.185418435505458, 37.829321316310335, 47.579540797642295, 51.71131488255092, 58.85716887882778, 5.922640136310032, 0.40017074985163553, 0.15932190870600088, 0.1802332858954157, 0.0492829279974103, 0.04783369594120553, 0.07248223706015519, 0.02600285630407078, 0.04863985661151154, 0.08084450262997832, 0.0397814394507025, 0.018001639217670475, 0.02499015805577593, 0.022072411674473966, 0.02900651709309646, 0.05264291466612901, 0.020896332371713858, 0.02994134496631367, 0.051130446538861306, 0.02643046059113528, 0.04465924449531095, 0.04041204954098378, 0.06605819320040089, 0.09243050164410047, 0.007979500573128462, 0.0725366962807519, 0.06473490063633237, 0.18862224503287248, 0.10307890096945421, 34.19402033942086, 86.84342888423375, 67.42729936327252, 64.22060149056571, 33.35432011740548, 86.19111810411725, 34.793997287750244, 36.657368659973145, 47.950796944754465, 55.29681812013899, 3.3379717086042677, 0.2511792246784483, 1.9561728153909956, 2.703533866575786, 3.018033870628902, 1.450909584760666, 1.1042834988662174, 14.920137814113072, 57.53757742473057, 76.40397589547294, 76.56650120871407, 73.01271997179303, 66.36795616149902, 61.55980968475342, 60.6690992627825, 56.39900738852364, 55.80111142567226, 56.16022906984602, 56.41837896619524, 54.841860498700825, 52.33351216997419, 54.132039478846956, 52.83673545292446, 52.810919421059744, 52.125017574855256, 51.934143611363, 48.26907655170986, 49.7764048576355, 50.591129779815674, 50.55772631508963, 49.60159512928554, 49.5495913369315, 48.72027519771031, 47.63667236055647, 50.517683846609934, 47.14931876318795, 47.63823223114014, 46.60047360828945, 47.14867952891758, 47.605061531066895, 46.85816492353167, 47.72907645361764, 56.99438810348511, 58.959800720214844, 62.1222038269043, 60.9622437613351, 57.35256079265049, 53.74036257607596, 49.84497315543038, 48.38570553915841, 45.877992970602854, 45.249622208731516, 45.86844614573887, 50.02579307556152, 56.88538476399013, 53.86705602918352, 49.52501208441598, 48.210916655404226, 50.19924095698765, 52.351900577545166, 50.26250777925764, 47.88240582602364, 59.05169759477888, 52.78385966164725, 49.51463494982038, 57.68108899252755, 53.17380993706839, 61.1365601675851, 58.54588958195278, 57.68842281614031, 55.80628783362252, 53.351867948259624, 49.69860240391323, 48.785445826394216, 48.40769311359951, 47.61664417811802, 46.48348331451416, 43.640117168426514, 44.70286846160889, 45.97662959780012, 46.251347473689485, 46.45075382505144, 44.40532922744751, 43.46259069442749, 41.405996867588584, 40.693236759730745, 40.981552260262625, 42.428917612348286, 40.65726246152605, 43.86705575670515, 44.38155944006783, 44.23437227521624, 45.228576115199495, 44.95866639273507, 45.62315041678292, 46.485331535339355, 46.70166022436959, 46.75259052004133, 46.08596297672817, 46.31573295593262, 47.876756940569194, 48.44216660090855, 48.471085003444124, 46.96804026194981, 48.9262684413365, 52.15553406306675, 54.34211826324463, 55.69762148175921, 58.520528657095774, 57.58849729810442, 61.14548165457589, 62.577595710754395, 64.85677160535539, 62.799625396728516, 67.04304313659668, 64.49989822932652, 63.64614527566092, 35.91060059411185, 0.09660977524306093, 0.3237266960952963, 1.5109091252088547, 1.371091610619, 2.33434111731393, 0.44576073065400124, 0.100441442137318, 12.49314854826246, 75.33520398821149, 51.061283111572266, 36.05757236480713, 25.79592898913792, 20.249122994286672, 11.301722696849279, 32.64416558401925, 50.47063411985125, 53.75157002040318, 56.88643741607666, 67.38030174800328, 11.641521743365697, 0.5332666422639574, 0.13477059826254845, 0.19835767549063477, 0.060002336012465615, 0.06045068481138774, 0.019896950373159986, 0.06487170686679226, 0.00814231505085315, 0.019666767546108792, 0.04800649845440473, 0.009086122486873396, 0.04166419770834701, 0.027496632487912263, 0.054819600723151646, 0.09207682883633034, 0.17255350441804954, 0.24622249922582082, 0.2590344345995358, 0.11236443556845188, 0.16389372838394983, 0.18003801708774908, 0.1625445293528693, 0.16019147847379955, 0.1538373508623668, 0.1653182990849018, 0.15088904835283756, 0.308635480169739, 0.3392694906464645, 38.456639426095144, 98.75427409580776, 77.42791107722691, 76.31285721915108, 38.23966455459595, 114.6216459274292, 76.31933988843645, 51.81935589654105, 59.17044925689697, 62.900707789829795, 6.808551958629063, 0.3165314293333462, 6.596499885831561, 6.768406135695321, 10.184725948742457, 10.46041396686009, 10.755113124847412, 16.926435368401663, 60.29777363368443, 80.3107464654105, 80.21019213540214, 75.8669913155692, 66.40537915910993, 64.78753280639648, 63.313611439296174, 61.49857521057129, 59.80513940538679, 60.47186074938093, 59.38580172402518, 58.13229806082589, 54.85914761679513, 59.31268583025251, 55.00940588542393, 56.334191117967876, 54.80785254069737, 53.9665333884103, 51.75097867420742, 52.23190171377999, 53.465919154030935, 53.707612242017476, 51.23409175872803, 52.11581121172224, 49.50494916098458, 50.01139293398176, 53.01849685396467, 49.55417367390224, 52.05479907989502, 49.10037292752947, 48.96787078039986, 50.77421133858817, 49.3422258240836, 50.25165121895926, 59.69417667388916, 62.49586405072893, 63.446176120213096, 63.75498880658831, 62.318497385297505, 55.229382378714426, 52.807250772203716, 50.42329256875174, 47.72275011880057, 48.65803670883179, 48.41582250595093, 52.90778773171561, 58.29383672986712, 54.26602159227644, 52.43756144387381, 50.78345244271414, 53.945136410849436, 55.47725241524832, 54.45286560058594, 51.71265935897827, 60.34281880514962, 57.717059816632954, 51.62563664572579, 61.04338482448033, 56.75631502696446, 63.4814521244594, 60.24954618726458, 60.41026496887207, 59.621255329677034, 56.49290534428188, 54.20154925755092, 51.96389927182879, 49.320578711373464, 50.98820195879255, 48.99857834407261, 47.377303055354524, 46.122051920209614, 48.87203080313546, 48.51257964542934, 48.597365038735525, 47.025936126708984, 45.290616580418174, 44.78447157996041, 43.16784463609968, 43.86786869594029, 44.3267867905753, 42.796216760362896, 47.92439726420811, 47.45981638772147, 45.8254611151559, 45.669640813555034, 47.53438098090035, 50.09769998277937, 49.31599637440273, 48.2747289112636, 50.21863685335432, 48.056055205208914, 49.773479666028706, 50.394200461251394, 51.34042004176548, 52.005512033190044, 49.58572544370379, 51.71767943246024, 56.446696349552695, 58.19610684258597, 59.35945415496826, 62.550671441214426, 61.3207152230399, 65.5473461151123, 70.28453063964844, 69.89238820757184, 66.53119019099644, 69.173326083592, 66.5817939213344, 65.63926383427211, 38.45957503999983, 1.031141223652022, 6.518510265009744, 7.962640796388898, 6.858256765774318, 2.625694066286087, 0.3824045588927609, 0.3009579921407359, 17.800096648080007, 84.2299473626273, 56.22809212548392, 48.617309842790874, 54.60266876220703, 37.04878500529698, 14.85497760772705, 32.47448015213013, 51.97896991457258, 64.21577944074357, 63.37789617265974, 81.3018444606236, 11.993796280452184, 0.7733248951179641, 0.41526875112737927, 0.30774668071951183, 0.2845144016402108, 0.2116137934582574, 0.1333290370447295, 0.15977812851113932, 0.12005188449152879, 0.21456631645560265, 0.18056378673229898, 0.07999681561653103, 0.08414782823196479, 0.10675890850169317, 0.1776091874177967], [0.010301883365692837, 0.018901281657495668, 0.05190588992887309, 0.006879231019411236, 0.03829349697168384, 0.017113801590832214, 0.021470009981255447, 0.01356183531294976, 0.07386591245553323, 0.0538844403677753, 0.09535947947629861, 0.040848140604794025, 0.1756183792437826, 0.2466016374528408, 60.04834720066616, 69.2049959727696, 63.300562722342356, 59.89961406162807, 53.600002016339985, 61.02125481196812, 75.1961566380092, 35.838113512311665, 48.56607035228184, 41.55356270926339, 0.17831706229065145, 0.03981386324656861, 1.7586913321699416, 1.4320083132811954, 4.584130908761706, 1.1550095826387405, 1.849140158721379, 39.1862975529262, 69.50495665413993, 74.45042732783726, 69.03272233690534, 69.27451269967216, 61.68175057002476, 58.883731842041016, 56.30030475343977, 54.9520172391619, 50.84684433255877, 51.62815884181431, 48.58034195218767, 52.437881061008994, 49.33965151650565, 50.37813622610909, 46.63109084538051, 46.82948970794678, 45.76715530667986, 46.234557151794434, 46.373434271131245, 46.51172079358782, 46.31932864870344, 47.64324883052281, 45.68247761045183, 46.788471017565044, 45.729284150259836, 44.905599525996614, 43.86080585207258, 47.40891735894339, 46.37217664718628, 45.175728116716655, 43.2293917792184, 46.186965465545654, 45.15591880253383, 48.21694769178118, 55.62674290793282, 58.594756262642996, 58.82861178261893, 59.086070333208355, 57.996224539620535, 51.45440871374947, 48.30896615982056, 44.420083727155415, 44.54325096947806, 45.45443773269653, 41.79508556638445, 48.025837489536826, 53.645526613507954, 54.11108718599592, 52.65633937290737, 49.220010484967915, 47.790053844451904, 46.86941753114973, 45.29584857395717, 45.210861682891846, 55.38169036592756, 49.49329008374895, 45.926289899008616, 59.49247741699219, 51.02199452263968, 57.53491973876953, 54.206308773585725, 52.6610815184457, 48.20383991513933, 51.660301208496094, 51.28119012287685, 49.3883444922311, 46.75224658421108, 46.035682337624685, 44.50877053397042, 42.218738079071045, 40.60962561198643, 42.637926374162944, 43.09181744711739, 43.668681212833945, 43.23760454995291, 40.88784190586635, 41.28983340944563, 39.189980098179404, 37.265811988285606, 37.273170130593435, 38.620484897068565, 42.05432285581316, 41.09470020021711, 40.14798034940447, 41.36272348676409, 43.525808879307334, 43.26323992865426, 45.00528533118111, 42.17221641540527, 43.69349323000227, 42.855300767081125, 43.538468497140066, 44.71007374354771, 45.911375590733115, 44.462822096688406, 45.10046522957938, 45.93689979825701, 48.58859988621303, 47.05893659591675, 51.53861045837402, 48.540212631225586, 52.39700828279768, 53.54019887106759, 57.508269923073904, 55.32518761498587, 60.91033376966204, 59.468582562037874, 64.66366727011544, 62.383393560137065, 62.402070317949565, 4.766336125986917, 0.9878795679126466, 0.9626393680061612, 0.514198071190289, 0.8185209184885025, 0.06432012575013296, 0.011585244992082673, 0.7242605707475117, 46.69625799996512, 64.55009201594761, 38.5045542035784, 46.380174023764475, 66.52652100154332, 59.16118730817522, 18.368000711713517, 11.189021178654261, 43.93021488189697, 48.48091670445034, 58.50395720345633, 26.913850716182164, 0.3045168268893446, 0.2067284770309925, 0.09074199439159461, 0.029966165777295828, 0.05711875895836523, 0.09291807655245066, 0.04817875135423882, 0.03969436983710953, 0.006204292660446039, 0.05540499663246529, 0.008922196059886898, 0.08686160868299858, 0.03718199893566115, 0.027294035502044216, 0.10072982630559377, 0.049749302079102824, 0.024837161979771087, 0.013563013419375887, 0.04420298058539629, 0.02167063412655677, 0.10063961507486445, 0.04736871624897633, 0.045875840820372105, 0.051447916110711436, 0.11361123687986817, 0.0539660715231938, 0.018845624822591032, 0.6313498020172119, 72.42786925179618, 74.89414623805455, 72.10345785958427, 65.28279345376151, 51.63935933794294, 77.95973314557756, 60.97906535012381, 33.68520723070417, 58.88533687591553, 42.98305034637451, 0.14936820710343973, 0.19953504231359276, 2.530679404735565, 2.464758804866246, 2.8087130912712643, 1.056504754083497, 3.3882508277893066, 42.61097778592791, 77.0048839024135, 77.35865838187081, 74.6012657710484, 74.8127828325544, 66.51479244232178, 61.907247407095774, 59.372773851667134, 58.31136703491211, 54.08221742085048, 55.724024636404856, 52.801323958805625, 56.14734363555908, 51.10816608156477, 52.242136410304475, 50.222447940281455, 50.14922782352993, 48.776500020708355, 49.13256393160139, 50.106357438223704, 48.590976170131135, 50.080975668770925, 50.29767261232649, 48.5647224017552, 48.7311178616115, 49.583168506622314, 47.43164144243513, 48.08274671009609, 49.328579562050955, 48.176863534109934, 47.90709624971662, 45.49368463243757, 47.31877490452358, 48.51277766908918, 49.75350706917899, 57.96499933515276, 60.59350981031145, 60.737059593200684, 62.91672338758196, 62.078562191554475, 53.95212977273123, 50.3260212625776, 45.848039286477224, 45.33638089043753, 45.446301392146516, 44.368211950574604, 51.152144704546245, 55.68032741546631, 57.50852353232247, 56.36642728533064, 50.629890305655344, 50.18298217228481, 48.848393031529014, 47.50689738137381, 47.444954190935405, 58.90858554840088, 51.60697031021118, 48.557051590510774, 61.568140574863975, 52.91381181989397, 59.40628501347133, 54.82537589754377, 55.652353967939106, 52.636509214128765, 55.272033895765034, 54.55745683397566, 52.72532456261771, 48.12158714021955, 47.84181792395455, 47.1997835295541, 45.0158257484436, 43.05663524355207, 43.700274671827046, 46.01155471801758, 47.66489246913365, 45.05312367847988, 43.02428790501186, 43.663991178785054, 40.91592999867031, 40.11853388377598, 40.9651267187936, 41.34898689814976, 43.99194615227835, 44.577481269836426, 42.49520690100533, 43.7797030040196, 43.810327189309255, 44.77033199582781, 46.91369145257132, 45.18519851139614, 44.91642481940133, 45.49863174983433, 47.02375439235142, 47.45805501937866, 48.28342110770089, 46.52004473549979, 48.42626564843314, 48.26979916436331, 51.6467730658395, 48.86527715410505, 53.37072188513619, 51.194824014391216, 54.59867007391793, 56.057451316288535, 58.52180017743792, 57.60856022153582, 63.44087464468819, 62.17793532780239, 67.60707705361503, 64.04258169446672, 65.96676022665841, 9.012952208518982, 0.4627146337713514, 0.4625983057277543, 2.555930026939937, 2.4432237318583896, 0.852811472756522, 0.0477302430995873, 0.48060293389218195, 47.198109013693674, 71.30930655343192, 47.15112182072231, 37.99227394376482, 41.960692405700684, 42.45230524880545, 24.174820457186016, 23.817229679652623, 50.956664085388184, 55.56468507221767, 65.68874195643834, 36.88796894890921, 0.32516022345849444, 0.12614062348646776, 0.05413772391953638, 0.04713176164243903, 0.07519011425652675, 0.09015469519155365, 0.04427917328264032, 0.01491961781201618, 0.04751070987965379, 0.02389116202747183, 0.051594394857862165, 0.022334707867620245, 0.03308795612039311, 0.021394008970154182, 0.24262080820543425, 0.1608972634587969, 0.0908177528264267, 0.06317505719406263, 0.13958937754588469, 0.16486507840454578, 0.16151910009128706, 0.14870552266282694, 0.22971357937370027, 0.15209160239568778, 0.26352215664727346, 0.37950265460780686, 0.16294451217566217, 0.7612631480608667, 83.11075237819126, 86.1431199482509, 81.2043959753854, 73.45658479418073, 69.2195246560233, 65.50362804957798, 93.85079833439418, 55.793697697775706, 63.972203390938894, 52.80976602009365, 0.47645502218178337, 0.5357876984136445, 5.820817760058811, 7.913164411272321, 13.986472759928022, 4.594419453825269, 3.6312695017882755, 45.52658435276577, 78.37784099578857, 82.85464872632707, 78.62673241751534, 78.53782326834542, 69.76522922515869, 65.66330460139683, 62.677712304251536, 62.129534176417756, 57.9133950642177, 58.78960459572928, 55.85888222285679, 58.5616272517613, 54.89279774257115, 56.27091039930071, 52.38472734178816, 53.32509306498936, 53.53110715321132, 52.478204931531636, 51.79211548396519, 51.51392003468105, 52.384828090667725, 52.700773102896555, 50.827986921582905, 52.018623283931184, 52.08128213882446, 49.72609295163836, 49.559680121285574, 53.069771085466655, 50.1359532901219, 49.94133077348982, 48.03248691558838, 51.45248406273978, 50.84173740659441, 52.09368814740862, 59.97135421207973, 64.70042324066162, 64.26452105385917, 64.07261180877686, 64.99172646658761, 55.83480324063982, 54.541614941188264, 50.41846704483032, 49.33698688234602, 49.014263902391704, 45.357701437813894, 53.872294970921104, 58.935183252607075, 61.63504477909633, 59.677132742745535, 54.62172072274344, 54.036004952022004, 52.85146563393729, 50.06544297082083, 51.44672053200858, 60.18826307569231, 54.8602419580732, 50.937500953674316, 67.19589655739921, 54.86324010576521, 64.48129095349992, 58.33614431108747, 57.20434182030814, 52.98830345698765, 56.8193803514753, 56.980717522757395, 55.25567436218262, 51.452386787959504, 51.07011774608067, 49.853088651384624, 48.15060976573399, 46.32153122765677, 46.75852428163801, 48.777538776397705, 49.508607387542725, 47.56700277328491, 46.07818794250488, 46.26098115103585, 45.116077831813264, 42.40734345572335, 44.56336253029959, 44.83070141928536, 47.297905990055625, 47.28853287015642, 45.437949657440186, 46.196578298296245, 47.7201931817191, 47.544726848602295, 49.55466004780361, 46.2508784702846, 47.68102271216256, 49.53089720862252, 48.61780316489083, 50.39576033183506, 51.38696602412632, 49.36019386563982, 51.97827162061419, 50.582659925733296, 53.61372470855713, 51.82897915158953, 58.07338081087385, 53.873232977730886, 58.18325614929199, 58.92183576311384, 64.03827381134033, 59.467040061950684, 66.34442261287144, 65.41330146789551, 70.70094312940324, 67.58607264927456, 68.37171241215297, 8.703466415405273, 4.024044871330261, 6.6952511583055765, 6.064064204692841, 4.225099682807922, 0.8318794816732407, 0.11689565171088491, 1.0546178839036395, 59.24753952026367, 76.41166755131313, 53.914949962071006, 65.3178401674543, 90.36494268689836, 70.03564616612026, 27.226698568889073, 20.797198636191233, 60.28596864427839, 62.52556759970528, 78.25619888305664, 41.3348890032087, 0.4864779072148459, 0.26608332778726307, 0.21231435372361115, 0.08626576672707285, 0.1148809048214129, 0.1195178095783506, 0.11648827285638877, 0.1226557626255921, 0.11140631019536938, 0.11496042912559849, 0.22947533215795243, 0.17246183433703013, 0.06216113588639668, 0.10887215831982237], [0.04544803806181465, 0.03731423184009535, 0.058892917686275074, 0.06481669803283044, 0.02066738108572151, 0.08758326460208211, 0.02915087541831391, 0.03953998954966664, 0.016726719415081397, 0.070004003255495, 0.032111710469637594, 0.2165749158178057, 0.1867296208760568, 8.077058519635882, 71.59167439596993, 61.76583072117397, 64.54007271357945, 37.511079924447195, 25.90798953601292, 2.7891866990498135, 29.214218616485596, 32.115355559757774, 67.76186902182442, 16.340856824602398, 0.061072127893567085, 0.2878808581403324, 0.9966934663908822, 1.9681432587759835, 1.1803258870329176, 1.2381054780312946, 20.284445898873464, 59.742056710379465, 72.26812321799142, 74.33096694946289, 72.08897086552211, 67.53258541652134, 63.18354116167341, 60.38074902125767, 58.30444662911551, 54.00288636343819, 53.389266627175466, 49.38688884462629, 52.173373562949045, 48.50834124428885, 48.86626379830496, 48.81425305775234, 49.81431770324707, 47.733485085623606, 46.84844091960362, 46.50146525246756, 46.303149768284385, 48.5823986189706, 47.414357798440115, 47.14332594190325, 47.034531048366, 48.58241946356637, 47.708315236227854, 46.945726122174946, 45.91388389042446, 47.850499698093955, 44.89481939588274, 43.583100250789094, 45.035968576158794, 44.21302046094622, 45.45744630268642, 44.57309348242623, 54.14694683892386, 58.52102197919573, 56.90853616169521, 58.477387292044504, 57.98993641989571, 51.61166034426008, 49.98280457087925, 49.02622175216675, 46.39218051092965, 45.44627707345145, 44.752482073647634, 46.39927462169102, 54.50039822714669, 54.82876314435686, 58.16924858093262, 52.64735882622855, 48.92513588496617, 45.64300489425659, 48.41404376711164, 45.48214714867728, 58.83607414790562, 47.30728953225272, 45.35430724280221, 58.25640678405762, 52.561270645686555, 54.48753363745553, 52.25106137139456, 53.8330272265843, 52.9738963672093, 54.37762008394514, 53.99113348552159, 50.858006613595144, 45.12783070972988, 42.42709023611886, 44.502815927777974, 43.352076121738975, 39.55622659410749, 39.39367001397269, 40.5423218863351, 39.954167297908235, 42.04378591264997, 41.47096947261265, 40.59971053259713, 38.57816341945103, 37.11222900663103, 37.549538203648154, 37.2740421295166, 39.46388503483364, 39.42499944141933, 41.65315818786621, 41.180180413382395, 39.61878817422049, 43.46062435422625, 43.46007892063686, 44.69408246449062, 43.60399695805141, 43.95220593043736, 46.55874272755214, 47.33285542896816, 46.60374273572649, 45.410243715558735, 46.6134215763637, 49.00747551236834, 46.74455492837088, 48.59928968974522, 50.57396425519671, 54.147457531520296, 54.15843221119472, 57.83245897293091, 59.38014589037214, 62.66000829424177, 58.46636744907924, 60.1121803011213, 59.18830612727574, 62.22993564605713, 63.94350038255964, 47.633590834481375, 1.6249643479074751, 0.3561852600957666, 0.6438313179782459, 1.8455166731561934, 0.9041143655776978, 0.1329969484359026, 0.1304787149918931, 13.516667706625801, 64.44490323747907, 55.65343441282, 30.759463242122106, 73.94641889844621, 135.80634907313754, 79.5645307813372, 25.17800658089774, 35.62548473903111, 45.92688396998814, 54.02988706316267, 43.980158533368794, 0.14909665738897665, 0.024992482038214803, 0.03440293323780809, 0.055165131110697985, 0.036348608655056784, 0.05703626945614815, 0.027809462576572384, 0.003901407995726913, 0.052939471788704395, 0.014547018966238414, 0.07305293250828981, 0.057104808278381824, 0.04404101088376982, 0.02034684962459973, 0.04750486769314323, 0.048248094240469594, 0.09288631432822772, 0.07028423821819679, 0.03144221353743758, 0.06434757249163729, 0.034631589361067326, 0.04807393804990819, 0.04150002616058503, 0.10567522022340979, 0.09259691235742398, 0.16104487196675368, 0.23673440835305623, 12.100286977631704, 87.03380257742745, 67.76368250165666, 70.70468126024518, 47.56085014343262, 42.38905579703194, 9.42535298211234, 28.690591948372976, 38.33394118717739, 76.07164355686733, 17.779814856392996, 0.18401826279503958, 0.22614707717938082, 2.008219816855022, 2.2882337399891446, 2.0107176942484717, 2.7898202879088263, 24.935957397733414, 64.00295611790249, 75.16291645595005, 79.06496919904436, 73.8110818862915, 69.883348601205, 66.17632484436035, 62.29331016540527, 61.558795247759136, 57.282109533037456, 56.009859630039756, 52.5636191368103, 57.54320893968855, 49.69166810171944, 51.818205969674246, 52.44155318396432, 51.79563127245222, 50.69496018545968, 50.1464798109872, 49.01501778193882, 49.42678540093558, 50.0038298198155, 49.30192974635533, 47.66694218771798, 48.95286267144339, 47.79414285932268, 51.437733037131174, 47.52888148171561, 49.124601296016145, 49.03842626299177, 47.29140942437308, 46.49173777444022, 46.44221796308245, 45.46630872998919, 48.1619735445295, 46.32138531548636, 55.890347140175955, 59.8296457018171, 60.32073743002755, 60.69407108851841, 58.9316257749285, 55.755433968135286, 53.56112337112427, 51.58101878847395, 49.35884938921247, 48.622791971479145, 47.882999897003174, 47.70145736421858, 57.51859494618007, 58.21297012056623, 59.19603252410889, 56.140332903180806, 53.36768552235195, 49.45554746900286, 49.921417236328125, 47.650322096688406, 60.772245270865305, 49.875969069344656, 47.48616395677839, 60.80829947335379, 55.58704437528338, 57.34140198571341, 54.092361790793284, 55.76564087186541, 57.11550562722342, 56.3270240511213, 53.63446855545044, 53.25570487976074, 46.402630601610454, 46.137709685734336, 47.70132187434605, 47.329763480595176, 43.15888840811593, 42.55878291811262, 41.81947374343872, 42.93757438659668, 45.300187723977224, 44.87413460867745, 44.52482782091413, 41.265716212136404, 40.35576622826712, 40.92747790472848, 40.20889173235212, 43.042881284441265, 42.00524772916521, 43.752580710819785, 44.08835588182722, 43.1397773878915, 45.11172478539603, 44.86503594262259, 45.30556215558733, 46.70015246527535, 46.11477715628487, 47.69282422746931, 50.830575125558035, 49.1752849306379, 48.119829245976035, 49.69405828203474, 50.514838559286936, 48.194244452885215, 51.21800320489066, 52.274653979710166, 55.871406350817, 56.15458018439156, 61.01710673740932, 61.200101443699424, 66.04649775368827, 61.18150806427002, 63.69408784593855, 62.15946006774902, 65.67242063794816, 63.98490469796317, 55.208680221012656, 3.9846937486103604, 0.371315776769604, 0.6375737051878656, 2.132796023573194, 1.7219323217868805, 0.3002284855714866, 0.15630944392510823, 11.937527162688118, 69.67628533499581, 63.89124992915562, 35.7502326965332, 62.48210661751883, 114.65924263000488, 62.276092529296875, 28.14712643623352, 43.55082586833409, 50.6832663672311, 60.107726505824495, 54.88349757875715, 0.848843725664275, 0.0835795755098973, 0.0023317156176614973, 0.07902754869844232, 0.014556745765730739, 0.05422077321314386, 0.017248546771172966, 0.11263233476451465, 0.052801841138196845, 0.06106002961418458, 0.05139032545100365, 0.017629181167909076, 0.06999070396912949, 0.05271258664184383, 0.22122772543558053, 0.17338891673300946, 0.16201913968792983, 0.24210829713514873, 0.20731971173414163, 0.21794740217072622, 0.15623298659920692, 0.0937897769202079, 0.10584312371377434, 0.20905156380363873, 0.19141239460025514, 0.3039561669741358, 0.38805230440837996, 14.624163661684308, 98.93019553593227, 76.43163667406354, 83.08897672380719, 52.78349835532052, 40.023413045065745, 7.9291852201734265, 45.045984404427664, 49.70746830531529, 83.90737724304199, 22.047355004719325, 0.23895579629710742, 0.7218435204454831, 3.5210943051746915, 6.908761918544769, 5.873895483357566, 3.560974359512329, 25.95733216830662, 68.37287276131767, 77.55728653499058, 82.55639730181012, 79.06154373713902, 74.63543701171875, 69.72983510153634, 65.86198834010533, 65.07669598715646, 60.784765924726216, 61.31876972743443, 56.347198145730154, 58.30655888148716, 53.75603423799787, 54.46981225694929, 57.138285296303884, 54.31183106558663, 53.17376477377755, 52.789970602308, 51.90128558022635, 52.07512603487287, 54.23820447921753, 52.44621195111956, 50.04011331285749, 51.986335005079, 51.609443868909565, 54.28967326028006, 50.768371377672466, 50.95881107875279, 52.70425067629133, 49.52403238841465, 47.63483803612845, 49.87852600642613, 48.53256613867623, 50.63254451751709, 48.31306559698922, 59.45859105246407, 62.48881162915911, 61.94249561854771, 63.6813656943185, 61.944309098379954, 58.43553134373256, 56.619769028254915, 54.60932166235787, 50.82889713559832, 49.80642107554844, 50.37423133850098, 49.67381817953927, 59.57079751150948, 58.29056412833077, 64.28367723737443, 58.15456356321062, 54.935320717947825, 49.74408878598894, 52.113243852342876, 51.0176762172154, 64.6191987991333, 53.11834246771676, 52.27071782520839, 64.80484771728516, 58.07304382324219, 59.942970820835654, 56.769707679748535, 57.88929871150425, 59.24116107395717, 58.54055336543492, 57.780694893428254, 55.92119714191982, 49.74060773849487, 48.018461976732524, 51.99683025905064, 48.761665616716655, 44.979271275656565, 44.32524081638881, 45.54216916220528, 44.79378564017159, 48.2781891141619, 46.5859032358442, 46.87548678261893, 43.342602252960205, 43.722964014325825, 43.571781635284424, 43.15967008045742, 46.18616642270769, 45.03884513037545, 47.81112773077828, 47.63739149911063, 45.194953782217844, 47.278621264866416, 48.11395801816668, 48.32524231501988, 49.072653089250835, 49.59701974051339, 52.27168015071324, 53.745785645076204, 52.112590721675325, 51.68269872665405, 53.237646511622835, 53.25323826926095, 50.744299343654085, 53.986200264522004, 54.87203305108206, 61.016877446855815, 58.66801112038748, 63.5561591557094, 64.22547912597656, 68.40338230133057, 63.80697522844587, 66.47989164079938, 63.46479034423828, 67.76535701751709, 66.39827810014997, 57.04479381016323, 3.610137641429901, 3.9730555159705023, 6.029703191348484, 6.102441711085183, 3.314799032041005, 0.5081613351191793, 0.2629317497568471, 17.044420991625103, 79.37788827078683, 68.28780596596854, 45.92241627829415, 81.47484765733991, 138.61508887154716, 88.42617988586426, 34.60348115648542, 49.521204471588135, 62.01080335889544, 68.80284118652344, 65.09216267721993, 1.0738147795200348, 0.15361006877252034, 0.1947367547878197, 0.1639089954218694, 0.0859824987128377, 0.19223889096507005, 0.08344935785446848, 0.19736875141305582, 0.14428346923419408, 0.11022586282342672, 0.172629785324846, 0.17563295417598315, 0.19627755853746617, 0.1613520040575947], [0.022601462035839046, 0.04919592962999429, 0.0605226977329169, 0.03461349283211997, 0.0074953183398715085, 0.043275463927005015, 0.056848756303744655, 0.06774262245744467, 0.03476286553112524, 0.06637300630765301, 0.017719136251668845, 0.07227617954569203, 0.12950231667075837, 36.99238995143345, 77.23289598737443, 62.03462873186384, 53.38517761230469, 27.661525521959575, 17.47013364519392, 44.33076116016933, 52.99134676797049, 37.01053517205374, 72.15481894356864, 3.094409338065556, 0.031590592182640514, 0.1879838928580284, 1.2669139036110468, 1.5872543028422763, 0.7979886116726058, 10.85726032938276, 39.7181647845677, 71.3532886505127, 74.90859154292515, 72.48112024579729, 69.49474280221122, 66.53571346827916, 64.72376223972866, 60.16787011282784, 56.08098486491612, 55.45527873720442, 53.288284982953755, 49.68288557870047, 51.29181044442313, 49.97163881574358, 49.55586903435843, 50.824846335819785, 48.84892109462193, 47.567912987300325, 48.023634910583496, 47.1034710747855, 46.35837752478463, 46.26449693952288, 48.018684319087434, 47.88836738041469, 47.692125933510916, 46.1169102532523, 45.566088335854666, 44.95148195539202, 46.06310340336391, 43.88790382657732, 45.3523165839059, 44.000645296914236, 43.65642459051949, 44.22452320371355, 47.116050788334434, 44.32791934694563, 51.15954106194632, 56.74849482945034, 57.05828373772757, 58.23135505403791, 58.74173845563616, 54.643437317439485, 53.33479969842093, 50.84676790237427, 55.98511709485735, 56.51860325677054, 51.28109632219587, 44.31847327096121, 50.88367325919015, 54.00594009671892, 58.25576407568795, 56.088589668273926, 56.680850642068044, 48.28122200284685, 48.863745076315745, 47.677232469831196, 61.278935704912456, 44.14894069944109, 39.55928727558681, 62.496447699410574, 50.92039448874337, 55.088087286267964, 51.27133757727486, 54.651549339294434, 51.23876789637974, 53.431480407714844, 52.90260090146746, 51.13736936024257, 43.59042712620327, 43.770965644291465, 46.60245731898716, 44.79081875937325, 39.19171019962856, 42.09634903499058, 39.121877329690115, 40.68234198434012, 38.489313329969136, 39.617266518729075, 39.356441565922324, 39.67247690473284, 37.68300615038191, 37.86582715170724, 37.897733279636924, 37.57015003476824, 40.80434192929949, 42.24337986537388, 40.35497065952846, 40.12589202608381, 40.99354485103062, 41.32134001595633, 45.56895794187273, 43.19366066796439, 44.0106645992824, 45.18743583134243, 47.20368146896362, 49.25324371882847, 49.38171591077532, 46.69814790998186, 49.55840860094343, 50.82318919045584, 55.19677448272705, 55.67943804604666, 55.06164591653006, 58.22190202985491, 59.819946016584126, 61.196898324149, 60.28334222521101, 61.92172745295933, 60.11982331957136, 58.854625838143484, 61.613950048174175, 58.23890427180699, 61.26453903743199, 36.25449126107352, 0.5264598503708839, 2.1571488082408905, 2.108703144959041, 1.038323381117412, 0.14809444759573254, 0.07109503328268017, 0.6078566940767425, 43.62903479167393, 65.40422712053571, 48.13632426943098, 61.8232992717198, 93.67626653398786, 99.65950625283378, 37.6818596976144, 23.042309250150407, 52.601069927215576, 48.4208391053336, 57.16313552856445, 6.646510847977229, 0.27996892269168583, 0.026747461973822544, 0.051764333953282664, 0.04096660942637494, 0.04904493862496955, 0.02022726461291313, 0.06136371474713087, 0.042331933842173645, 0.0399567491507956, 0.06630813835987023, 0.08584335832191364, 0.03687673281612141, 0.015410612536860364, 0.10005530821425573, 0.04677463509142399, 0.028519091462450366, 0.06702621839940548, 0.0655132345855236, 0.023489320018727864, 0.02039289501096521, 0.05508957284369639, 0.06230391322502068, 0.04619214331199016, 0.0974465242720076, 0.11349425744265318, 0.012141575005703738, 45.939769404275076, 84.30561324528286, 69.31697314126151, 61.95995644160679, 34.22215706961495, 23.27872518130711, 36.61202124186924, 50.98950822012765, 46.41491501671927, 76.33730098179409, 2.3645386397838593, 0.13629327155649662, 0.47464496216603685, 1.2567692079714365, 1.305248635155814, 0.9065235448735101, 12.903424910136632, 45.236465794699534, 74.78353091648647, 77.69029590061733, 75.24076407296317, 72.68081842150006, 70.16368756975446, 66.21092687334333, 63.75210530417306, 60.500522068568635, 58.13372938973563, 56.90696586881365, 53.16440555027553, 54.5452036857605, 52.06218501499721, 51.552975858960835, 52.20129837308611, 50.6130131312779, 52.299514634268625, 51.13692120143345, 51.08801283155169, 49.6317537852696, 48.70858832768032, 50.85890293121338, 51.02649000712803, 48.532013756888254, 48.5771735736302, 49.60588911601475, 47.07851314544678, 48.071431568690706, 46.82031461170742, 47.86656740733555, 47.09680775233677, 47.50309671674456, 45.44518968037197, 47.538817405700684, 46.04276950018746, 52.73528133119856, 60.01185526166643, 59.536119052342, 59.42640699659075, 61.100123814174104, 59.0986396244594, 55.67867374420166, 54.411395277295796, 58.24153069087437, 58.257775579180034, 55.330027035304475, 46.70753492627825, 53.82399456841605, 56.341907092503135, 59.23582485743931, 58.73283781324114, 59.18470001220703, 51.13790784563337, 51.76609795434134, 49.91649096352713, 62.269102641514365, 47.74919843673706, 41.96794979912894, 65.22142001560756, 53.204281261989046, 58.93161187853132, 54.210192816598074, 56.20447519847325, 51.45259175981794, 55.17101403645107, 55.095608711242676, 53.821618284497944, 46.41866704395839, 45.070254462105886, 47.86640412466866, 46.95022508076259, 40.15330266952515, 44.881350312914165, 39.835874216897146, 43.24773154939924, 41.16817740031651, 41.99836553846087, 42.21356514522007, 44.59774916512625, 40.042072432381765, 39.213777678353445, 39.58137559890747, 39.754229409354075, 42.08264718736921, 45.925011430467876, 41.71070664269583, 43.83377388545445, 42.838621616363525, 45.15777049745832, 46.38732719421387, 45.813652651650564, 45.459839957101, 48.944514410836355, 49.797437054770334, 51.430367946624756, 49.39002595629011, 51.031166144779746, 51.21073538916451, 55.04562684467861, 56.30030822753906, 58.08649206161499, 56.82100622994559, 61.88570104326521, 61.643424306597026, 62.760889189583914, 60.74885068620954, 63.80812862941197, 63.08412633623396, 62.59245095934187, 62.946822983878, 60.61404173714774, 63.56927735464913, 44.90152440752302, 0.9972725553171975, 1.1676262084926878, 1.5160809734037943, 1.7944933367627007, 0.347919509346996, 0.03611928756747927, 0.5041496189577239, 43.10553666523525, 72.054625919887, 52.5478640965053, 61.30856282370431, 93.016403062003, 99.6961441040039, 44.95194748469761, 29.05270947728838, 60.133622441973, 53.796128817967, 70.52714783804757, 12.379885963031224, 0.5123501760619027, 0.0496105009556881, 0.06396160141697951, 0.02957874603037323, 0.04409339717988457, 0.027847957564517856, 0.03225882025435567, 0.0650215952524117, 0.01795876767885472, 0.04142929906291621, 0.05895741922514779, 0.024384216106097614, 0.04404847816165004, 0.15504510248345987, 0.10510538651474885, 0.10869669594935008, 0.17712047935596534, 0.15472962441188948, 0.12004957747246538, 0.1367209114666496, 0.12418797612190247, 0.19013494386204652, 0.16958200958158287, 0.16920534122203076, 0.16838474811187812, 0.11323381534644536, 54.92283133098057, 96.40682520185197, 77.47365106855119, 71.38039357321603, 42.376375334603445, 24.23388361930847, 59.23023850577218, 76.25007329668317, 51.18006951468331, 86.68233489990234, 3.8533958111490523, 0.28980637767485207, 0.924940939460482, 5.134602810655322, 4.845889091491699, 3.9663974046707153, 15.730205706187657, 47.298652921404155, 78.17464787619454, 81.30977930341447, 79.98618221282959, 75.25804424285889, 72.55953066689628, 69.4692359651838, 66.52385289328438, 63.33636678968157, 62.638489723205566, 60.248969486781526, 56.594130175454275, 57.5194148336138, 57.33486720493862, 55.90941299710955, 55.8850109236581, 54.1569105557033, 54.412809235709055, 54.917356150490896, 52.82261323928833, 52.11121497835432, 50.027450220925466, 53.66543320247105, 53.342592103140696, 51.897894859313965, 51.42932571683611, 52.12630646569388, 49.82166542325701, 50.87165982382638, 49.94478750228882, 49.58064978463309, 49.434063638959614, 49.96733440671648, 48.04320798601423, 50.28265755517142, 48.40048435756138, 57.17760862622942, 63.570687838963096, 62.743004526410786, 62.729351316179546, 61.554299763270784, 60.01727485656738, 57.883469172886436, 56.82259736742292, 61.583412715366904, 61.27170957837786, 58.18636894226074, 48.96617889404297, 57.053923743111746, 60.33302184513637, 62.13248021262032, 62.108154569353374, 60.10896328517369, 54.16229540961129, 53.840493065970286, 52.06690631593977, 64.69746330806187, 50.854195526668, 45.48159129279, 66.79273428235734, 55.30478770392281, 60.97420161111014, 58.60052326747349, 59.94258172171456, 55.88191202708653, 58.190478801727295, 58.702981403895784, 55.81505993434361, 49.49312680108206, 47.02239949362618, 51.80160672324044, 51.01999691554478, 43.66704838616507, 48.54684121268136, 42.32719251087734, 46.512231486184255, 43.23072235924857, 45.45485462461199, 44.27526242392403, 46.58357558931623, 43.63827589579991, 41.650417123522075, 42.95775195530483, 42.81445230756487, 45.182860442570274, 48.91239288875035, 45.05259561538696, 44.93331936427525, 46.520419938223704, 47.816252027239116, 49.0995773587908, 48.139252935137065, 48.68691342217581, 50.68799809047154, 52.816915716443745, 54.3678891318185, 53.49491398675101, 52.4065203666687, 54.302746295928955, 57.19033772604806, 59.08915533338274, 61.18655245644705, 60.5836364201137, 65.04601274217877, 63.64522116524832, 66.53002984183175, 64.26675837380546, 67.41297912597656, 65.6271253313337, 64.58827236720494, 64.44485460008893, 64.25748252868652, 66.11260291508266, 45.18119287490845, 0.6480905637145042, 6.848932717527662, 8.737289377621241, 3.4322392216750552, 0.6472697534731456, 0.12312004342675209, 0.8784931546875409, 52.40718739373343, 75.96828215462821, 63.34687941414969, 70.504072870527, 92.30918066842216, 106.09629658290318, 51.22503825596401, 35.34506586619786, 69.86902836390904, 61.24760627746582, 82.11538124084473, 14.405643684523445, 0.7279133147427014, 0.1659051233104297, 0.14828873931297235, 0.12346439994871616, 0.07166213928056614, 0.16213366282837732, 0.18440540773527964, 0.13936999360365526, 0.08315933841679778, 0.13971983268857002, 0.15340116141097887, 0.1318656134286097, 0.1807943665023361], [0.03723198321780988, 0.045854663742440085, 0.040881812905094454, 0.04562344954216054, 0.09221117198467255, 0.0663113614012088, 0.041790849662252834, 0.07472668840949025, 0.10246908797749452, 0.014482327437560474, 0.02802589998048331, 0.06475859507918358, 0.7815956398844719, 55.62213625226702, 66.03765964508057, 58.81683458600725, 48.95095191683088, 27.984210286821636, 29.65196555001395, 45.96958065032959, 26.440351826804026, 64.86851406097412, 50.365191732134136, 0.3020703824503081, 0.04382053450016039, 0.27246109555874554, 1.0884315094777515, 0.08236960507929325, 3.5205384492874146, 16.58282262938363, 51.42410067149571, 68.28971672058105, 72.45546054840088, 73.6141004562378, 75.14083508082798, 68.07681696755546, 63.56633826664516, 60.00428867340088, 60.40926442827497, 50.60127067565918, 51.90319286073957, 49.156278133392334, 48.670296805245535, 50.05082048688616, 49.366377762385774, 47.848227637154714, 50.16519825799124, 48.78417430605207, 52.10331835065569, 47.57390233448574, 45.46379348209926, 45.70710897445679, 47.79392051696777, 48.42550482068743, 50.72881875719343, 44.76642710821969, 48.324700355529785, 45.820024149758474, 46.601842403411865, 43.45742470877511, 45.90050860813686, 44.183990887233186, 44.93797813143049, 44.137385845184326, 45.49709619794573, 43.66699627467564, 52.03207847050258, 59.18387317657471, 59.49982166290283, 53.98388304029192, 57.964426108769004, 56.0114403452192, 57.91335684912545, 55.36179072516305, 55.68956504549299, 56.561011586870464, 59.71583420889718, 51.26023783002581, 49.94245638166155, 53.72504874638149, 56.63707004274641, 51.97894559587751, 57.48036248343331, 51.39638430731637, 56.74605253764561, 46.81368950435093, 64.29387719290597, 30.36045946393694, 27.43129175049918, 64.01273223331997, 49.02452639171055, 57.872150557381765, 50.69489417757307, 55.17310197012765, 46.251573290143696, 55.285033975328716, 51.45874091557094, 51.4845152582441, 40.64755582809448, 43.8944525037493, 44.182163511003765, 44.6156234060015, 38.36084113802229, 41.112588337489534, 37.103748730250764, 40.84520081111363, 38.14403649738857, 40.8257006917681, 38.09514202390398, 42.09346900667463, 38.02928352355957, 38.71787084851946, 35.887014933994834, 37.709697655269075, 38.11203309467861, 40.57788971492222, 41.83528784343174, 39.18685340881348, 39.07266671316964, 43.38869660241263, 45.1489497593471, 43.84551634107317, 41.9616825239999, 46.46663393293108, 47.066256523132324, 51.16697563443865, 49.50499085017613, 50.084025927952354, 52.37096643447876, 58.012604917798726, 62.81653731209891, 58.512211663382395, 59.076877866472515, 61.360709054129465, 60.77000100272042, 60.90699863433838, 60.559442792619976, 60.6972325188773, 57.05815519605364, 62.08564935411726, 57.41600826808384, 60.275886808122905, 57.76131636755807, 63.106992857796804, 24.623041800090245, 0.15187102423182555, 1.633059324962752, 1.5049033846173967, 0.4792979210615158, 0.2357230654784611, 0.18153763376176357, 11.715137038912092, 68.48585047040666, 50.683975083487375, 40.131461007254465, 48.468326568603516, 37.53996358598982, 14.291395323617117, 28.044666562761577, 40.660806042807444, 50.920245102473665, 59.46737357548305, 27.58697656222752, 0.6308454062257494, 0.08292670268565416, 0.0528657184248524, 0.04850862115355475, 0.08557250071316957, 0.15969462799174444, 0.0013560026168956288, 0.07139343262783118, 0.02756877093841987, 0.05685120920783707, 0.02326985974130886, 0.03164229655106153, 0.0654544463115079, 0.020757553300687244, 0.11072011451636042, 0.025872580973165374, 0.019940459734893272, 0.03190254865746413, 0.08645180745848588, 0.04797695164701768, 0.028442169340061288, 0.14054285495408944, 0.044407877804977555, 0.021443399534161602, 0.06569287673171077, 1.6175957833017622, 67.48451777866909, 73.27558422088623, 66.14317498888288, 60.965168952941895, 43.30156619208199, 30.173816953386577, 31.916098594665527, 33.71232604980469, 71.82525893620083, 55.392592089516775, 0.08234325077916894, 0.2743821639035429, 0.5897815525531769, 3.636582919529506, 0.8442499350224222, 3.3829790992396216, 21.70364499092102, 54.766646248953684, 72.63404314858573, 73.47533798217773, 77.9653959274292, 75.45021057128906, 71.43945326123918, 67.50363227299282, 64.65084089551652, 62.46097714560372, 54.15403747558594, 54.27979292188372, 52.63026278359549, 52.890514510018484, 53.44347299848284, 52.462741715567454, 50.99834632873535, 53.33009924207415, 52.30571242741176, 53.3877067565918, 48.0373923437936, 46.5407121522086, 48.411146368299214, 49.48676572527204, 50.53979301452637, 52.329079219273154, 47.572596073150635, 50.7209221294948, 47.032762731824604, 49.14488308770316, 45.9123101234436, 48.842358521052766, 45.35573162351336, 45.8368353162493, 46.43009335654122, 47.258857113974436, 45.746647698538645, 53.30068751743862, 61.1351774760655, 59.974022320338655, 56.05784041540963, 59.397120339529856, 59.18931361607143, 59.55289200374058, 57.48864473615374, 57.87240416663033, 58.79693494524275, 62.173815046037944, 53.38873508998326, 51.66916363579886, 56.47461073739188, 57.69325181416103, 54.047479901994976, 58.415319034031455, 56.10145425796509, 56.76016780308315, 51.054380076272146, 63.28923715863909, 41.05352170126778, 36.092591285705566, 64.18023940495083, 52.39177976335798, 59.44651508331299, 52.90595688138689, 56.59603745596749, 50.42853498458862, 57.3108993938991, 54.975116525377544, 51.69824184690203, 43.432685647692, 46.31565652574812, 47.58953578131539, 46.50524854660034, 42.00093984603882, 42.892473629542756, 40.149092061179026, 42.62264381136213, 41.16372013092041, 41.499602999006, 41.69945403507778, 43.223353794642854, 40.597692080906455, 40.86083425794329, 38.46464375087193, 39.814032554626465, 39.587535176958355, 44.93519537789481, 44.751075063432964, 42.31187520708357, 41.83855349676949, 44.95283685411726, 46.57032537460327, 45.088997227805, 44.7360600062779, 48.360594749450684, 51.47939790998186, 53.85601534162249, 52.5249593598502, 53.515793323516846, 55.03185551507132, 59.195893560137065, 64.22011511666435, 62.390494619097026, 60.63124547685896, 61.63664286477225, 62.24283150264195, 62.90058272225516, 62.64008780888149, 62.60635430472237, 60.183677264622276, 65.07009519849504, 59.26297146933419, 61.93070452553885, 59.51571914127895, 63.94653674534389, 30.402277197156632, 0.6718145364097187, 0.22386592387088708, 1.130972398178918, 0.9206407644918987, 0.4269373821360724, 0.12547749121274265, 10.908037764685494, 73.38027272905622, 58.97036893027169, 46.248835699898855, 50.30309568132673, 53.14516946247646, 17.40122488566807, 35.45859595707485, 49.71177966254098, 55.768055370875764, 68.34957545144218, 35.27634123393467, 0.4380833240492003, 0.06415958436472075, 0.03827582113444805, 0.07544861574258123, 0.015554188850468822, 0.030086408967950513, 0.03572683648339339, 0.10758827506963696, 0.09063184780201741, 0.030299428251705, 0.046848059365791936, 0.01713006098621658, 0.011209910802010978, 0.08463736410651888, 0.11688003183475562, 0.25257602972643717, 0.12140463904610702, 0.13523684681526252, 0.1423891351691314, 0.15946570384715283, 0.14555808369602474, 0.17504752773259366, 0.161953688200031, 0.14446687724973473, 0.21329005993902683, 2.95035211954798, 78.57401643480573, 81.03157343183244, 76.941481590271, 65.84960665021623, 42.062427929469514, 40.92388916015625, 60.75274862561907, 40.691009862082346, 79.62955897194999, 60.09879807063511, 0.5506347502980913, 0.34812372124620844, 2.2509177880627766, 6.1965628777231485, 3.308510260922568, 7.465088980538504, 24.04062989779881, 60.46730967930385, 74.53166566576276, 74.54221997942243, 78.20679719107491, 77.82049124581474, 72.48231533595494, 70.56677341461182, 68.35221576690674, 65.57556969778878, 55.68787315913609, 59.99714592524937, 55.43317304338728, 55.085756165640696, 57.18754802431379, 55.7013908794948, 54.294272967747276, 55.891736779894146, 55.54024130957467, 57.54235431126186, 51.897884437016074, 49.99804197038923, 49.973466191973, 51.96159594399588, 52.037814208439414, 55.260430404118125, 49.223335197993684, 52.360481602805, 48.82924032211304, 51.04324211393084, 48.710120405469624, 51.456239564078196, 49.40892505645752, 49.72995267595564, 48.775377886635916, 48.0518411227635, 48.5539596421378, 57.567242758614675, 64.33910301753453, 62.562684876578196, 57.27745076588222, 61.76020268031529, 61.5219281060355, 61.88798700060163, 60.847390038626536, 60.621149744306294, 63.82726396833147, 66.07321357727051, 56.87023074286324, 55.79203707831246, 61.09717082977295, 59.64542811257498, 55.925487654549734, 61.26269081660679, 59.707746505737305, 59.53718907492501, 53.821746826171875, 66.49765123639787, 42.29975754874093, 39.53296749932425, 65.96089594704765, 54.77377510070801, 62.39576135362898, 57.34131513323103, 59.96934618268694, 52.35182067326137, 61.36762251172747, 57.0506546156747, 55.69266741616385, 46.7410043988909, 50.8558874130249, 51.518870626177105, 50.020109449114116, 44.792931011744905, 46.8220169203622, 42.26450933728899, 45.24922268731253, 43.357256003788535, 44.015882696424214, 44.01067502158028, 46.59286185673305, 43.863407952444895, 44.363323892865864, 40.65655027117048, 42.959350040980745, 42.277957575661794, 47.71362713405064, 48.02258573259626, 44.36592599323818, 45.88340214320591, 47.20247595650809, 49.133081572396414, 48.845189911978586, 45.67214216504778, 51.09721919468471, 53.13725893838065, 55.70845719746181, 55.339309828622, 55.882707595825195, 58.21815695081438, 63.4185014452253, 64.88654463631767, 65.91982514517647, 63.93475260053362, 64.99044799804688, 64.75089495522636, 65.33958802904401, 66.04510811397007, 65.32874189104352, 63.007307052612305, 68.01180962153843, 61.22549710954939, 66.26984759739467, 62.57163415636335, 67.49669797079903, 31.96076856340681, 1.4655471593141556, 5.6446292485509595, 7.69283355985369, 2.1250092642647878, 0.6230875253677368, 0.2523962179464953, 15.065306527273995, 82.25050980704171, 61.38456221989223, 54.446646962847026, 57.24229288101196, 48.42423677444458, 21.73507169314793, 40.945133277348106, 55.8288243157523, 66.30550575256348, 76.88096972874233, 42.80202892848423, 0.6406881809234619, 0.16124505336795533, 0.1233026779123715, 0.11600204823272568, 0.08358572303716626, 0.18988205386059626, 0.1370222760098321, 0.28033123325024334, 0.1728570402732917, 0.12671584476317677, 0.11887079929666859, 0.11524344608187675, 0.10009690241089889], [0.05977639063660588, 0.05890027979122741, 0.11267968293811594, 0.04978556977584958, 0.050424607271062474, 0.02992411356951509, 0.0645489345437714, 0.03854258717702968, 0.17094954262886727, 0.03695705779162901, 0.12846421237502778, 0.1753433147179229, 5.826135737555368, 62.51096943446568, 63.88166836329869, 58.83237075805664, 29.912331921713694, 14.058549898011343, 31.67252949305943, 57.674912043980186, 35.22168322971889, 84.1474861417498, 22.820967435836792, 0.08329348478998456, 0.33161322719284464, 0.4353012219071388, 0.9406300804444722, 0.9982189216784069, 6.343875544411795, 28.185122660228185, 62.85336971282959, 77.77949687412807, 73.14891161237443, 70.81253119877407, 66.7302143914359, 64.06124455588204, 61.88364437648228, 57.3648556300572, 55.52941949026925, 52.96893187931606, 48.9114340373448, 48.128069809504915, 50.13556071690151, 48.46265683855329, 49.823506695883616, 50.37135478428432, 50.491725376674104, 49.56544712611607, 49.26110907963344, 49.783846378326416, 47.88000174931118, 46.453025885990684, 47.7194948877607, 47.4647912979126, 51.16013165882656, 48.62377166748047, 47.61016845703125, 44.73530265263149, 47.54863521030971, 42.830919538225444, 45.067509923662456, 42.523430483681814, 45.402162960597444, 44.89379801068987, 47.17146267209734, 44.561778341020855, 52.23300995145525, 57.102491651262554, 59.609304428100586, 56.8747227532523, 60.87587765284947, 54.29056262969971, 55.935472215924946, 51.35822480065482, 54.859078134809224, 57.71493714196341, 60.15170860290527, 52.78597886221749, 53.712191104888916, 50.631905283246724, 60.046526772635325, 51.25505099977766, 59.71214471544538, 48.87910059520176, 60.41423239026751, 45.84986318860735, 73.2168024608067, 14.827313355037145, 14.363103338650294, 70.42655876704625, 45.85030787331717, 60.34577873774937, 46.59271594456264, 52.11581815992083, 45.53102772576468, 54.490688119615825, 46.427894251687185, 49.25480011531285, 39.917261941092356, 44.78095579147339, 44.679835183279856, 45.8067808832441, 39.36625589643206, 39.934083529881065, 38.598466055733816, 39.884289264678955, 38.258674825940815, 40.98991789136614, 38.32536016191755, 41.14048535483224, 39.87990495136806, 38.672210761478965, 34.32991668156215, 38.36876208441598, 37.99048130852835, 40.48792791366577, 39.64137329374041, 41.89122084208897, 38.06319420678275, 42.08112900597708, 42.1833370072501, 43.93235840116228, 41.30342755998884, 49.65233434949602, 48.46148954119001, 51.74569109507969, 51.603499685014995, 54.62489604949951, 53.09405156544277, 62.259215354919434, 62.50914205823626, 57.16300351279122, 58.74029323032924, 58.76089463915144, 59.329563004629954, 60.00278786250523, 59.23224653516497, 59.23615837097168, 58.67636285509382, 60.9789194379534, 62.46326310294015, 57.13490499768938, 64.03563349587577, 59.44611208779471, 59.73494870322091, 16.47677574838911, 0.39323994889855385, 0.9659238031932286, 0.5158078819513321, 0.16877666993864945, 0.06837526815278189, 0.6064436584711075, 42.299514361790244, 68.08710724966866, 47.5807671546936, 33.11474970408848, 35.85450431278774, 33.11337743486677, 22.533925192696707, 26.826114075524465, 45.626885073525564, 47.60988358088902, 50.03987012590681, 1.8905286235468728, 0.10488361412925379, 0.020715714831437384, 0.169497016285147, 0.019821560043575506, 0.03687049707930003, 0.01306345812710268, 0.0812089845005955, 0.0294339263013431, 0.08869118336588144, 0.014325502727712904, 0.025903389855687107, 0.04552994741659079, 0.08510790100055081, 0.06254018590386425, 0.03077503040965114, 0.019183258758857846, 0.055572584604046175, 0.028907067608088255, 0.059534642180161815, 0.033156623864280324, 0.12381140275725297, 0.011098543697568988, 0.14661924461168901, 0.2201662523938077, 9.552801183291844, 78.66538524627686, 68.394592830113, 67.53795637403215, 34.87590265274048, 23.284193413598196, 27.241562502724783, 45.25199154445103, 42.31376164300101, 89.64492171151298, 24.218010459627422, 0.13275830766984395, 0.20551840482013567, 0.35964329168200493, 1.5754431251968657, 0.32730325417859213, 9.835871662412371, 33.842896597726, 67.68871143886021, 78.36846092769078, 76.27735192435128, 71.57810456412179, 70.29202079772949, 67.12892287118095, 63.49288885934012, 60.19873401096889, 58.76029014587402, 55.62803874697004, 51.68082618713379, 50.46950156348092, 50.54534462520054, 51.34391498565674, 52.318729877471924, 50.694703102111816, 52.85575614656721, 50.887404441833496, 51.96900967189244, 51.679467814309255, 51.040195328848704, 47.51846613202776, 49.21935040610177, 48.43405457905361, 53.24210030691964, 49.67604855128697, 50.16439574105399, 46.94917590277535, 48.921925817217144, 45.8071734564645, 47.29837499346052, 45.08044746943882, 47.281734057835166, 46.82800279344831, 48.460266658238, 47.89000368118286, 55.06930977957589, 61.27540602002825, 60.547026361737935, 58.391841070992605, 63.34780352456229, 58.68932124546596, 59.66007491520473, 53.3208372933524, 56.89595297404698, 59.6442608152117, 61.306846618652344, 56.410913126809255, 56.03072854450771, 54.26953043256487, 60.9827617917742, 54.77173580442156, 59.270093372889924, 53.38494832175118, 59.68909059252058, 50.54733180999756, 68.88863059452602, 31.567660331726074, 26.69003360612052, 66.51812062944684, 51.772472926548545, 58.22327777317592, 50.95339495795113, 52.34963893890381, 51.52029848098755, 57.59638697760445, 51.21836798531668, 49.93575137002127, 42.92723894119263, 46.71031420571463, 47.22088520867484, 47.462595667157856, 43.666777406420024, 41.13824803488595, 41.944923468998496, 41.338939802987234, 41.22919648034232, 43.22379847935268, 42.7433305467878, 42.317909717559814, 41.56195960726057, 39.56265715190342, 38.75398063659668, 39.272545542035786, 40.2120566368103, 42.11687748772757, 43.790045397622244, 43.719472544533865, 40.77833134787423, 43.43319981438773, 44.55056047439575, 44.83412340709141, 45.29667888368879, 49.81065252849034, 51.912635462624685, 54.19329827172415, 54.38617679050991, 56.72950887680054, 57.0323600087847, 62.91793237413679, 64.48804460253034, 59.89388179779053, 61.285751887730186, 60.036354609898154, 62.87505504063198, 61.032587323869976, 61.700232778276714, 60.58450494493757, 63.7031899860927, 61.089937755039756, 64.39996923719133, 58.645915848868235, 64.12440368107387, 60.98319258008684, 63.681282315935405, 21.68479105404445, 0.4539761341043881, 0.2439608605844634, 1.44843624319349, 0.49470587713377817, 0.028078920706840496, 0.16390208793537958, 44.065805503300254, 73.18503529684884, 54.95554344994681, 38.20445455823626, 35.473392145974294, 30.636282103402273, 32.12236629213606, 35.66804245540074, 50.710419927324565, 53.019108295440674, 60.83953857421875, 3.9978636247771124, 0.17755471462649958, 0.04465340230880039, 0.13182935251721314, 0.032703175874693055, 0.04576607081773026, 0.06085656410349267, 0.04904894198157957, 0.026517993304878473, 0.0394983919603484, 0.0023490901429405703, 0.07062825547265154, 0.021597606795174733, 0.17589205955820425, 0.2040220858263118, 0.17214440208460602, 0.28821944711463793, 0.1757443289139441, 0.16714472536529812, 0.15959904954901763, 0.1263419176851, 0.3155174808842795, 0.1523873350982155, 0.4099160326378686, 0.33083440469844, 14.126939279692513, 89.5002532686506, 76.79269286564418, 76.53478963034493, 43.5498948097229, 22.77806404658726, 42.1121700831822, 77.6538039616176, 50.97677217211042, 98.53940105438232, 27.46129928316389, 0.29066879568355425, 0.9764174286808286, 2.1963392538683753, 4.915152209145682, 2.2882317858082906, 11.487441096987043, 38.87994105475289, 65.42556503840855, 80.50264181409563, 76.90434346880231, 77.5381303514753, 71.97886276245117, 70.77342673710415, 67.15580545152936, 64.63998780931745, 61.58588627406529, 59.13537475040981, 54.37430926731655, 54.15594128199986, 55.66692434038435, 54.16357387815203, 55.72935043062483, 55.28856366021292, 55.79290212903704, 55.27145024708339, 54.72745146070208, 54.75594254902431, 52.85326174327305, 50.568183353969026, 52.729969433375764, 51.20037909916469, 55.34012624195644, 51.5323987688337, 53.28231995446341, 48.81792170660836, 51.882056440625874, 47.97404909133911, 51.51245049067906, 47.04179538999285, 49.614279065813335, 49.15306806564331, 52.09624855858939, 49.73647008623396, 56.961418901171, 64.03321552276611, 62.54354953765869, 59.618427412850515, 66.10835061754499, 59.68150315965925, 63.28187206813267, 56.60526813779558, 59.06316212245396, 60.314741134643555, 66.98259380885533, 60.04430334908621, 59.020256996154785, 55.934370926448274, 64.59916714259556, 56.23040240151541, 60.46543366568429, 54.46316283089774, 62.636148180280415, 52.56660338810512, 71.77841418130058, 26.46594030516488, 23.244513988494873, 73.33027349199567, 54.36422743116106, 63.36381912231445, 52.049212728227886, 54.75063065120152, 52.42047234943935, 59.134117126464844, 54.167179993220735, 51.60635886873518, 45.1281225340707, 50.40716927392142, 50.78105878829956, 51.20465224129813, 45.933456965855186, 45.0447997365679, 45.76361172539847, 44.419559138161794, 43.60413244792393, 46.45276880264282, 45.35336576189314, 45.99157517296927, 44.99213239124843, 43.95481150490897, 40.358771324157715, 42.9886679649353, 43.99908890042986, 45.523683479854036, 48.28898661477225, 48.04310376303536, 43.53500829424177, 46.592288630349294, 47.41077600206648, 48.019705704280305, 45.95838015420096, 53.33833980560303, 55.536767210279194, 57.199325220925466, 57.03263793672834, 58.81928730010986, 61.167173930576865, 63.04434789930071, 67.83010033198765, 64.18273380824498, 62.66917296818325, 63.49137415204729, 62.67531517573765, 64.50359467097691, 64.5576308114188, 64.55264200483049, 64.77436597006661, 64.066817011152, 67.57112707410539, 62.44409302302769, 67.78300544193813, 63.533438546316965, 65.78731604984829, 22.277910130364553, 2.134512880018779, 6.1642420291900635, 3.2055650992052893, 0.8426127657294273, 0.15281496143766812, 0.7984545209578106, 52.29196194240025, 79.64547034672329, 61.55581447056362, 48.1642073903765, 48.83632401057652, 46.05021449497768, 35.60947956357683, 40.670547417231965, 61.39304597037179, 62.52663762228829, 70.62900148119245, 4.645346275397709, 0.2882211570228849, 0.09138076047280005, 0.25235588582498686, 0.09044726592089448, 0.15591205310608658, 0.11445760753537927, 0.15314813570252486, 0.10186425543257169, 0.16071350260504655, 0.1048259793647698, 0.14610804989933968, 0.11602635335709367], [0.05554044918556299, 0.03956373148996915, 0.05223731357338173, 0.03806556348821946, 0.06477722765079566, 0.019911801808380654, 0.07867530759956155, 0.014539607667497225, 0.09336613358131476, 0.06410560011863708, 0.06289249485624687, 0.09700874704867601, 28.606400626046316, 69.25263282230922, 54.1077937398638, 52.084283760615754, 39.54078074863979, 22.921320268086024, 34.303273814065115, 28.453260592051915, 46.084225927080425, 81.67269761221749, 6.551143782479422, 0.10165080867175545, 0.21148510250662053, 1.212452837399074, 0.974143630691937, 7.62270278590066, 12.303526997566223, 46.66316720417568, 67.25134318215507, 62.79943779536656, 64.36281721932548, 67.83657605307442, 66.72573975154332, 64.78796359470913, 59.01050867353167, 56.8787978717259, 53.880229813711985, 51.57857302256993, 48.916662556784495, 47.39837694168091, 49.034990378788535, 46.96594885417393, 47.46409995215279, 49.010706424713135, 50.91173703329903, 51.968648365565706, 50.54880830219814, 49.178936208997456, 46.695827211652485, 45.815865652901785, 48.221592562539236, 46.7257843698774, 47.17898062297276, 51.64836767741612, 47.60571813583374, 44.913763659340994, 44.835412297930034, 44.12929119382586, 44.69563538687569, 41.49304389953613, 45.077466692243306, 44.6608943939209, 45.72355883462088, 44.4931822504316, 48.246939590999055, 53.1565888268607, 59.83057676042829, 56.195195879255024, 57.59603261947632, 51.79408529826573, 54.23358392715454, 48.925604888371055, 52.2362825529916, 57.828665256500244, 62.65251118796212, 50.940457412174766, 56.23832334790911, 51.50166688646589, 61.994141578674316, 54.131097997937886, 53.354675020490376, 45.273468426295686, 60.87140996115548, 42.569934776851106, 72.48517799377441, 9.512014389038086, 7.689119747706822, 69.32201058523995, 44.50523042678833, 55.327094895499094, 46.97540535245623, 53.80063819885254, 48.364127908434185, 51.20807422910418, 44.18352883202689, 47.266719000680105, 38.52406474522182, 44.66976376942226, 44.45781591960362, 47.68284314019339, 39.729538985661094, 37.96794482639858, 39.46618141446795, 40.29552187238421, 40.15892028808594, 41.731888226100374, 40.22502544948033, 41.858512197222026, 41.24047340665545, 38.11410018375942, 35.415708201272146, 36.56637505122593, 38.90301602227347, 39.33860206604004, 40.998863697052, 38.69625500270298, 36.8457065309797, 40.21671540396554, 43.18813337598528, 43.54245328903198, 42.403181484767366, 48.43846321105957, 51.20502049582345, 53.794607162475586, 55.42017991202218, 53.659728731427876, 58.34766442435128, 66.40802642277309, 55.636640616825645, 58.90064375741141, 58.37651334490095, 59.66147150312151, 57.94153874261038, 57.793385778154644, 58.18643147604806, 58.27400657108852, 58.81552137647356, 60.644704137529644, 58.60319832393101, 59.76346411023821, 61.4262444632394, 61.7063958304269, 61.87715475899832, 53.738969462258474, 6.162441142967769, 0.9272621806178774, 1.031577114548002, 0.5908048919269017, 0.07011089287698269, 0.23985561515603745, 12.801473123686653, 64.54335921151298, 58.23569072995867, 52.89943947110857, 44.82493094035557, 28.323598521096365, 17.636838299887522, 19.69715288707188, 44.54376861027309, 47.569705622536794, 58.51575524466378, 21.543421268463135, 0.5198028247271265, 0.08146783882485968, 0.13668173285467283, 0.01097432429170502, 0.034630259432430775, 0.0853356309235096, 0.07549189270607062, 0.07698633894324303, 0.03495097918702023, 0.08334845969719545, 0.05720660888722964, 0.033034202576215775, 0.04425880366138049, 0.031196020676621368, 0.020777027255722454, 0.05592302419245243, 0.10813256193484579, 0.016345647363258258, 0.027111102461016605, 0.023881209615085806, 0.09327567129262856, 0.08276641235819884, 0.15169972128101758, 0.00894826791980969, 40.06312200001308, 79.00004523141044, 60.22610296521868, 60.731271743774414, 53.04758201326643, 24.658981357301982, 20.268904515675136, 34.81379270553589, 54.342476095472065, 87.00356401715959, 6.5270265851702005, 0.12849534356168338, 0.542157133775098, 2.950834150825228, 2.6673122559274947, 10.25578691278185, 16.410535097122192, 48.83151238305228, 68.79655306679862, 65.27720710209438, 67.96155330113002, 71.05090304783413, 67.6507464817592, 68.18675831386021, 62.47520705631801, 60.69430037907192, 55.02450432096209, 54.37706422805786, 52.32863106046404, 49.61542551858084, 52.659309727805, 51.396005630493164, 50.76066582543509, 52.12899889264788, 53.63836302076067, 53.901341915130615, 52.672295910971506, 51.76210968835013, 48.47459731783186, 48.199125562395366, 48.66138574055263, 47.47869464329311, 49.31607627868652, 51.94426713671003, 49.47713204792568, 47.98352296011788, 47.2202980858939, 45.15650592531477, 45.790612425122944, 45.43270376750401, 47.30675452096121, 46.90099014554705, 47.90243400846209, 47.87827859606062, 50.72949620655605, 54.98332929611206, 61.11045578547886, 58.01250416891915, 58.32324150630406, 55.04919127055577, 54.68976443154471, 51.37542506626674, 54.74845586504255, 60.513966832842144, 61.77719797406878, 54.52877467019217, 58.25477048328945, 55.27165869304112, 62.53348159790039, 56.39515461240496, 54.537070819309776, 48.8490218435015, 59.93327808380127, 47.54666192190987, 67.41060284205845, 17.23478947366987, 15.828380278178624, 64.8245667048863, 48.13843652180263, 56.73166629246303, 51.74664299828665, 55.11410481589181, 53.12297691617693, 54.08946091788155, 46.00329678399222, 49.44079991749355, 41.704217025211875, 44.9451139313834, 47.490315505436485, 48.027303559439524, 43.293627875191824, 39.78153582981655, 40.77315146582467, 43.065143312726704, 43.89479991367885, 43.378857953207834, 43.118779931749614, 43.8643285887582, 43.50820909227644, 40.69305958066668, 38.02643823623657, 39.49957793099539, 40.78830548695156, 41.4772367477417, 44.57612289701189, 42.00013385500227, 40.69355637686593, 41.8415446962629, 44.890688691820415, 45.631953784397666, 45.42002330507551, 49.37200232914516, 54.93188483374459, 55.928367682865684, 57.12000805991036, 55.75185564586094, 60.523374693734304, 66.58769989013672, 56.93104485103062, 61.0169677734375, 61.170759201049805, 64.16360541752407, 61.85109206608364, 59.91470554896763, 59.44825908115932, 60.29585593087332, 61.821221760341096, 62.615393911089214, 58.43568420410156, 61.9571076801845, 64.13293606894356, 64.1069289616176, 65.37698323386056, 58.955326080322266, 9.014023099626813, 0.3005225083657673, 1.5169930330344608, 1.725649390901838, 0.6894641550523894, 0.18336083021547112, 11.018249222210475, 70.7030553817749, 61.71264920915876, 60.78591237749372, 37.73114327022007, 29.077531916754587, 26.188800982066564, 22.649522372654506, 53.43628856113979, 52.23053986685616, 66.89570658547538, 27.891465732029506, 0.5829053329569953, 0.07791915496012994, 0.07213497640831129, 0.04407417428280626, 0.0451830396029566, 0.004031081126803266, 0.02462384244427085, 0.11016016706292119, 0.05149482662922569, 0.09078933577984571, 0.05730174628219434, 0.02040778546194945, 0.14208002175603593, 0.14468045293220452, 0.13324401660689286, 0.17970602347382478, 0.26536237075924873, 0.09871648398361035, 0.10274196083524398, 0.11312375696642057, 0.2966839814824717, 0.18618417371596607, 0.20478568199489797, 0.16951334183769567, 49.26844637734549, 90.17642416272844, 70.83890656062535, 70.6549321583339, 52.51792778287615, 33.11244985035488, 46.54072257450649, 45.5926547731672, 60.74645355769566, 97.0388194492885, 7.333490099225726, 0.29784115510327475, 0.6972739302686283, 4.0106717603547235, 5.604547696454184, 13.28306405884879, 21.415572677339824, 50.6200829233442, 72.45140280042375, 68.03259863172258, 71.84267807006836, 75.79045690808977, 72.95677307673863, 72.72741304125104, 65.91016714913505, 63.523516518729075, 57.78872701099941, 58.72540324074881, 56.22351673671177, 52.98006984165737, 56.320263453892295, 54.3396829196385, 54.38552713394165, 55.075035095214844, 57.34828765051705, 58.01212549209595, 55.39177220208304, 54.52472039631435, 49.85070889336722, 50.08785091127668, 52.22284126281738, 49.55928407396589, 51.47540964399065, 55.03646911893572, 51.89539350782122, 49.822047574179514, 50.87514781951904, 47.900665691920686, 48.73547438212803, 47.61073126111712, 51.99529470716204, 49.17889451980591, 50.54149879728045, 49.761316844395225, 51.6028013910566, 57.21576813289097, 65.19951929364885, 61.23552336011614, 62.67206341879708, 57.479740619659424, 58.653864588056294, 52.905331543513704, 58.330314772469656, 63.240405218941824, 65.36087730952671, 55.58614805766514, 60.326976912362234, 58.430625915527344, 65.2557441166469, 58.35000596727644, 58.29478168487549, 47.82720933641706, 63.053345816476, 47.578668798719136, 76.47789778028215, 10.310451865196228, 10.559919118881226, 73.72222832271031, 49.81182329995291, 60.40700626373291, 51.704599448612754, 57.7162572996957, 54.05275705882481, 54.50328867776053, 49.14641169139317, 52.472114835466655, 43.35466432571411, 49.11563464573452, 50.53820187704903, 52.2488032068525, 46.74778584071568, 42.5093742779323, 43.83375651495797, 44.57817261559622, 45.12096241542271, 46.89674479620797, 44.92553390775408, 47.09564045497349, 47.14748443875994, 41.82447297232491, 39.362601143973215, 43.506694384983604, 44.14519909449986, 44.18824665887015, 47.197198799678254, 42.89834138325283, 42.38458810533796, 45.42659977504185, 48.4658008984157, 47.64586482729231, 46.29266841070992, 53.20559099742344, 57.08203962871006, 60.07107475825718, 60.411682401384624, 58.22108561652047, 62.3980473109654, 67.06858471461705, 61.773133277893066, 63.163898604256765, 62.879606110709055, 65.18276023864746, 64.72713906424386, 63.559480394635884, 63.20483044215611, 64.41789558955601, 64.4866966520037, 65.766784123012, 62.159383637564524, 64.86755520956856, 68.81094973427909, 66.77342523847307, 67.62793554578508, 62.994487626211985, 8.321323309625898, 2.24767558489527, 5.60031841482435, 1.8883722935404097, 0.961786476629121, 0.3087148144841194, 16.349997179848806, 77.16055829184396, 70.07921831948417, 69.56083406720842, 61.27105644771031, 37.27283661706107, 26.60164557184492, 29.869294779641287, 61.61842468806675, 60.80083015986851, 77.08276626041958, 32.84707382747105, 0.7905102872422763, 0.18901339332972253, 0.3033027377511774, 0.16535507568291255, 0.1137003828106182, 0.17643700460238115, 0.15912410217736447, 0.22440006663756712, 0.22563814877399377, 0.21709444294018404, 0.1940342267709119, 0.10057165300739662], [0.09966458060911723, 0.027448015453826104, 0.04037601933149355, 0.06079284966524158, 0.02271372395833688, 0.033218563933457644, 0.036656236076461415, 0.07882059551775455, 0.04768891013892634, 0.12479803338646889, 0.08959883930427687, 1.518688393490655, 49.86959409713745, 65.2396103995187, 56.90743487221854, 38.931680815560476, 16.691396917615617, 30.384257044110978, 49.10603223528181, 39.77871138708932, 74.55217674800328, 54.11335924693516, 0.16631740118776048, 0.05728220447365727, 0.21870405014072145, 3.435058670384543, 1.2853720102991377, 6.409242459705897, 21.34298484666007, 49.637645857674734, 62.632708821977886, 66.9660154070173, 73.71143082209996, 69.52569702693394, 67.46997519901821, 60.56543908800398, 59.026635442461284, 52.48519481931414, 53.66473838261196, 50.0569383757455, 50.09942313602993, 49.68049539838518, 50.422156538282124, 45.134240422930034, 50.1271846635001, 48.845110007694785, 51.496507849012104, 50.13927452904837, 50.841046060834614, 48.98048176084246, 50.257734366825645, 46.6646853855678, 47.73575019836426, 46.57392454147339, 45.17548145566668, 46.553941522325786, 47.414427280426025, 43.87533106122698, 46.11685814176287, 42.51586389541626, 43.707184655325754, 42.898185048784526, 44.71183511189052, 42.826708929879324, 48.40304476874215, 45.61941576004028, 45.97888428824288, 47.50891235896519, 50.91003819874355, 49.408688817705425, 53.59035096849714, 46.98792948041643, 50.687737533024375, 47.18749564034598, 54.44080005373274, 50.89187560762678, 58.69760349818638, 52.49077769688198, 56.61127832957676, 52.92241716384888, 60.57777214050293, 46.796266896384104, 52.76088196890694, 51.379430702754426, 63.35388319832938, 49.7371301651001, 61.1742958341326, 10.08916129384722, 7.906923191887992, 64.90990447998047, 43.38115085874285, 56.44398307800293, 47.8090363230024, 51.509362016405376, 48.42189523151943, 50.92197520392281, 43.56106056485857, 49.055452823638916, 41.24092503956386, 43.30703442437308, 45.31825998851231, 46.94472210747855, 43.33705759048462, 39.73380517959595, 40.60368837629046, 43.1237131527492, 44.0145069531032, 45.78565488542829, 40.04123517445156, 43.29645579201834, 42.631332533700125, 40.044076987675254, 34.83770145688738, 36.70235129765102, 36.96200547899519, 38.04231834411621, 40.59301246915545, 42.286618505205425, 39.21779373713902, 39.8566632270813, 42.70386825289045, 41.6849045072283, 42.972909450531006, 47.84855420248849, 52.18874992643084, 53.12217787333897, 57.287108761923655, 55.74655417033604, 61.498957361493794, 59.7269652230399, 55.39553117752075, 59.95480360303606, 57.91599021639143, 60.09701933179583, 54.82839836393084, 54.038440295628135, 55.87319203785488, 57.94416168757847, 60.76419925689697, 57.44273451396397, 60.51332759857178, 63.73756272452218, 61.3396977015904, 61.8833247593471, 60.7646369934082, 63.86506216866629, 37.02174956457955, 0.36062328623873846, 1.1152725092002322, 0.4267135470041207, 0.12994170880743436, 0.028128155207793628, 0.3804301034126963, 43.89113473892212, 64.63624967847551, 46.73075928006853, 42.299344130924766, 39.41037348338536, 27.164539984294347, 19.770996604646953, 26.201920918055944, 50.42291041782924, 50.40826708929879, 48.386261395045686, 5.8148549028805325, 0.26497829279729296, 0.20497113918619497, 0.05870323322181191, 0.036647238702114136, 0.047616995604974885, 0.07034134372536625, 0.03811681323817798, 0.044674474213804514, 0.1547952794602939, 0.015326696414766567, 0.016431756849799837, 0.08384632798177855, 0.04036182437890342, 0.08715291055185453, 0.059021812198417525, 0.06167733363275017, 0.029478584083595445, 0.06634166477514164, 0.06724925286003522, 0.02720938147311764, 0.08752462560577051, 0.18240659284804547, 2.2740333591188704, 66.99722671508789, 70.20964990343366, 65.39949539729527, 48.65552840914045, 27.20066887991769, 29.11890149116516, 35.947179385593955, 44.00388315745762, 80.4574785232544, 58.16132416043963, 0.14686281154198305, 0.02983832299443228, 0.9309310466051102, 3.502480298280716, 5.604750062738146, 5.965236067771912, 23.336975404194423, 52.848634243011475, 65.39644513811383, 70.37047290802002, 74.95556136540004, 70.69488430023193, 69.08397919791085, 62.98029245649065, 60.902989523751394, 55.31843049185616, 56.38422162192208, 52.084363664899556, 52.13620070048741, 53.156526293073384, 53.56935698645455, 49.71081733703613, 52.13908420290266, 52.30042484828404, 52.84017481122698, 53.545684473855154, 51.403415884290425, 52.517767974308555, 52.17880705424717, 48.453662395477295, 49.13085467474801, 48.71539061410086, 46.76056705202375, 50.14886999130249, 49.48006418773106, 45.67594630377633, 47.235538959503174, 46.076669761112754, 45.94649526051113, 43.897422858646934, 47.13453994478498, 44.40993240901402, 49.061831269945415, 48.61911984852382, 46.89693239756993, 49.66517809459141, 52.37337051119123, 51.59498119354248, 53.8483236857823, 49.14737401689802, 51.41855253492083, 50.503929887499126, 57.02880253110613, 53.957354818071636, 58.40434782845633, 53.54518072945731, 57.4424809047154, 56.30096483230591, 60.5342903137207, 50.50066770826067, 56.218270846775596, 57.08718824386597, 64.3209890638079, 54.34562362943377, 58.82781273978097, 15.27125460760934, 14.165744968823024, 61.392288616725374, 47.99403558458601, 56.27782733099801, 52.302248750414165, 52.74496712003435, 51.15578556060791, 55.176892212459016, 46.71419130052839, 49.011675698416575, 45.12395361491612, 45.62138557434082, 47.62857076099941, 46.79976184027535, 44.55856132507324, 42.007144587380544, 43.770100593566895, 45.17831632069179, 47.82491295678275, 46.20526702063424, 41.72647557939802, 44.74584306989397, 43.559785570417134, 41.26346499579293, 36.85397836140224, 37.676634652274, 39.40968561172485, 40.459812028067454, 42.81091914858137, 44.13805634634835, 42.289717401777, 41.61265366418021, 43.527156829833984, 43.70772661481585, 45.079255853380474, 48.833867822374614, 53.9603772844587, 56.62399353299822, 59.40497875213623, 58.79149450574602, 62.045460973467144, 60.870979172842844, 57.46590328216553, 60.07256167275565, 60.2690497807094, 60.520776067461284, 56.48136786052159, 55.42970241819109, 57.20881993430001, 60.68742861066546, 63.75824056352888, 58.7726857321603, 61.717770031520296, 64.47182055882045, 64.16094425746373, 64.20505142211914, 63.36053957257952, 67.39117567879813, 41.267432417188374, 0.8178868953670774, 0.7450723254254886, 2.1492539175919125, 1.1650182455778122, 0.11865292170218059, 0.15248607551412924, 45.905014514923096, 68.96720777239118, 55.21582644326346, 42.44960934775216, 36.36712850843157, 33.832675797598704, 31.877817494528635, 35.60522379193987, 54.71852649961199, 56.54463120869228, 55.58539417811802, 7.530086772782462, 0.36119936246957096, 0.08276430889964104, 0.04847604129463434, 0.1265508657587426, 0.062335600810391564, 0.037898718512484005, 0.05561013812465327, 0.05731628050229379, 0.05695517095071929, 0.16624549004648412, 0.03596352306859834, 0.21752238140574523, 0.14383817384285585, 0.17984563883926186, 0.28609682672790115, 0.11750554612704686, 0.0992282283093248, 0.20199313041354927, 0.175174780189991, 0.22193842301411287, 0.4139651767909527, 0.3097759075462818, 4.119236494813647, 80.12996128627232, 80.77109241485596, 70.76083660125732, 54.89727585656302, 26.344532694135392, 43.90555919919695, 71.54631655556815, 53.98527615410941, 88.41326318468366, 66.06040109906877, 0.5532025439398629, 0.1159500317381961, 1.8753066403525216, 4.04227043049676, 10.49212293965476, 9.602439982550484, 27.46551510265895, 55.14297458103725, 68.67677307128906, 72.8260496684483, 78.09470190320695, 72.06408241816929, 71.54459340231759, 66.18325219835553, 64.59707573481968, 58.952838625226704, 60.53071199144636, 54.136423792157856, 53.89803804670061, 55.48548603057861, 57.3505597114563, 50.34390245165144, 54.94816446304321, 55.703777585710796, 56.63613551003592, 56.23521750313895, 55.06837524686541, 54.978806018829346, 57.25142976215908, 52.17013570240566, 51.670445578438894, 51.46447317940848, 47.966565881456646, 52.50781120572771, 52.13096523284912, 49.0050436428615, 50.56990303312029, 47.59970794405256, 49.11116695404053, 48.02920389175415, 50.57149417059762, 47.21183170591082, 53.56284305027553, 50.7962440763201, 51.21256276539394, 52.70833274296352, 54.486682483128135, 53.86967897415161, 57.09135716302054, 50.63390289034162, 54.31678165708269, 51.639446190425325, 60.833986963544575, 56.00389807564871, 61.61887632097517, 54.686870506831575, 60.670551436288015, 57.38711418424334, 63.216121264866416, 52.01304388046265, 58.435017177036826, 55.75971405846732, 67.92974444798061, 52.0021630014692, 68.1349664415632, 9.352784258978707, 8.84387821810586, 70.55464185987199, 47.9699843951634, 62.70307322910854, 52.49224376678467, 57.71174097061157, 52.18210050037929, 55.890913418361116, 48.257094383239746, 56.25653805051531, 46.20940467289516, 48.00865806852068, 49.26211656842913, 52.116707529340474, 47.71162952695574, 43.30240345001221, 46.64960432052612, 46.91697447640555, 50.70403453281948, 50.7186952318464, 44.83902188709804, 48.17813505445208, 47.20934077671596, 46.593250955854145, 38.83353751046317, 41.99497134344918, 41.8821256501334, 44.18508870261056, 46.54543692725045, 47.74266365596226, 45.221374307359966, 44.23059245518276, 47.26216793060303, 44.99422379902431, 47.60786165509905, 52.20817361559187, 56.145391191755024, 58.227266039167134, 62.96748692648751, 62.620882987976074, 64.32249682290214, 64.81540897914341, 61.28741945539202, 62.57469136374337, 63.266877855573384, 64.36176804133824, 60.72048813956124, 57.82354096003941, 61.57047516959054, 62.978923661368235, 67.19042137690953, 60.56744016919817, 65.13196195874895, 68.47877025604248, 68.27971826280866, 66.53595665522984, 69.45138604300362, 70.00241988045829, 46.47920669828142, 0.9963802546262741, 3.357105527605329, 3.9126700248037065, 1.1342469538961137, 0.4099503665098122, 0.5439996006233352, 54.99887241636004, 77.97095448630196, 59.53352737426758, 58.87994507380894, 52.83744069508144, 35.87903840201241, 32.54984378814697, 39.92412676130022, 67.42710481371198, 64.49766090938023, 66.66822256360734, 9.321183851787023, 0.44625980673091753, 0.2874375847833497, 0.1590663588472775, 0.25088490332875935, 0.28289462998509407, 0.21410369127988815, 0.12284180335700512, 0.18571586241679533, 0.22795074539525167, 0.16416434172008718, 0.11988514129604612], [0.013668872515804, 0.0030807381263002753, 0.007915919297374785, 0.03628669572728021, 0.010025672963820398, 0.05377085699832865, 0.12264068557747773, 0.05526843128193702, 0.049623477937919755, 0.030200229824653695, 0.2612085965062891, 9.610786506107875, 69.3361154283796, 58.01628746305193, 60.41253702981131, 39.56542600904192, 21.777610301971436, 33.698947293417795, 39.26285627910069, 42.70871809550694, 76.2210784639631, 27.9930397101811, 0.1546538591917072, 0.21763420397681849, 0.15479128967438424, 12.106106093951635, 6.533942648342677, 3.2710727155208588, 28.142132418496267, 55.59923846381051, 72.56121907915387, 69.91674164363316, 70.38433456420898, 64.42875562395368, 61.3788994380406, 60.38465390886579, 56.43348434993199, 52.929858684539795, 54.15447868619646, 52.93209947858538, 53.97649710518973, 52.7526969909668, 55.95635502679007, 52.80966179711478, 50.58550173895699, 48.57168449674334, 49.47065980093819, 48.488472870418, 50.643123149871826, 47.12734855924334, 48.2768793787275, 48.70258855819702, 47.65734672546387, 43.82061052322388, 45.03288357598441, 48.98153788702828, 44.968053409031455, 42.94057253428868, 44.74368565423148, 45.18807506561279, 43.18769563947405, 43.045333998543875, 43.03997693743025, 43.63184881210327, 47.35710116795131, 48.25618764332363, 50.78786454881941, 48.90504516874041, 49.48256206512451, 45.66012525558472, 49.00954260144915, 45.394610268729075, 50.27925293786185, 47.404814447675435, 53.413362979888916, 53.84826462609427, 52.09234367098127, 52.77285718917847, 54.02026380811419, 52.761013984680176, 50.03289066042219, 50.232679162706646, 58.246276310511995, 51.803489685058594, 59.0263158253261, 52.39773784364973, 54.703636510031565, 11.456003972462245, 7.269115039280482, 56.819651331220356, 46.742741448538645, 53.6145897592817, 47.828407900674, 52.44322769982474, 47.1431313923427, 52.0435152053833, 49.285420826503206, 48.27514927727835, 40.68588556562151, 43.51704025268555, 42.58644022260393, 48.27558353969029, 40.14166791098458, 42.405505657196045, 43.30226796013968, 47.95068229947771, 47.25973606109619, 47.54020357131958, 41.57051631382534, 41.35201283863613, 40.974683965955464, 40.003381388528005, 35.930423804691856, 37.76027359281267, 36.26107120513916, 39.25497007369995, 39.004379817417686, 41.508507115500315, 38.726768016815186, 39.1362601007734, 40.81397908074515, 43.115590708596365, 41.67899853842599, 46.57912526811872, 52.198873451777864, 55.5811106136867, 59.59442833491734, 53.72151558739798, 58.455563000270296, 56.570273535592214, 58.40780108315604, 59.39803055354527, 57.08183813095093, 55.85477236339024, 52.41719627380371, 54.06314461571829, 54.72833040782383, 58.28492913927351, 59.07879556928362, 58.73357432229178, 58.76104055132185, 63.512746810913086, 62.540422848292756, 62.38884789603097, 61.03839601789202, 64.48609910692487, 56.13732433319092, 11.495327302387782, 1.0159305312803812, 1.1919441436018263, 1.5153138488531113, 0.1919737873332841, 0.3565186379211289, 11.996994188853673, 64.80216571262905, 63.63885661533901, 43.33757870537894, 36.52830587114607, 30.374060562678746, 8.292582954679217, 17.041252613067627, 38.50684710911342, 48.29051521846226, 57.33599976130894, 23.16055543082101, 0.5009945396866117, 0.0673085025378636, 0.07052830726440464, 0.03461625446964588, 0.04434938130101987, 0.053849519563040564, 0.021744631763015474, 0.01664889314477997, 0.18795658860887798, 0.07783467056495802, 0.08984398043581418, 0.020572979901252047, 0.0034344079654796845, 0.056450717483780215, 0.04618083552590438, 0.019338845142296383, 0.037682404941213984, 0.043404623067804744, 0.07136221323162317, 0.037402685665126355, 0.12891813873180322, 0.3222366603357451, 14.785370554242816, 83.19241455623082, 64.72531168801444, 69.88639191218785, 50.77550022942679, 30.48270606994629, 33.021299907139365, 44.00876774106707, 48.73497758592878, 85.06227902003697, 28.963089874812535, 0.1772353553346225, 0.19803207367658615, 1.3385510253054755, 13.613023587635585, 9.798038721084595, 4.64416377885001, 32.47206565311977, 59.80518109457833, 73.65163462502616, 71.78534153529576, 73.38376072474888, 66.84336580548967, 64.23747866494315, 60.974583762032644, 59.2607410975865, 55.10752139772688, 56.614307744162424, 55.14927659715925, 58.63749463217599, 58.57550975254604, 57.779023851667134, 55.55279323032924, 53.341348375592915, 49.8717862537929, 50.752088274274556, 51.14245196751186, 52.89602095740182, 50.477655274527415, 50.492916992732454, 49.58462415422712, 49.52485922404698, 46.579726287296836, 46.613873209272114, 50.02921853746687, 47.442140170506065, 44.54801048551287, 45.93093129566738, 48.70215082168579, 45.07940523965018, 44.56868485042027, 45.928148542131694, 46.11872373308454, 48.68626376560756, 51.98083550589425, 52.88599470683506, 51.25430754252842, 50.50744915008545, 46.94123758588518, 49.40359231403896, 48.021727630070274, 52.21786635262625, 49.97714178902762, 55.336200509752544, 55.295588288988384, 55.196861335209434, 54.198592799050466, 54.950207233428955, 55.53562423161098, 50.987399441855295, 55.673104763031006, 59.79507841382708, 54.80081401552473, 59.34836483001709, 55.04579707554409, 53.828580379486084, 16.172416857310704, 12.6068115234375, 53.920602321624756, 48.73668336868286, 54.370633670261924, 51.975620882851736, 54.91826636450631, 52.71129962376186, 52.69408198765346, 53.05230678830828, 48.35949693407331, 43.087850025721956, 45.67916331972395, 46.89692892347063, 48.9388689994812, 43.52023294993809, 44.32451472963606, 46.32297992706299, 50.38625519616263, 50.48951932362148, 48.519305501665386, 44.197220257350374, 43.63668475832258, 42.75949553080967, 40.24380990437099, 37.39469412394932, 39.291871956416536, 39.12044252668108, 41.192596844264436, 41.44129024233137, 42.59085580280849, 41.368431431906565, 40.06270858219692, 42.42672198159354, 44.42326947620937, 43.62077338354928, 48.363690171922954, 54.784926959446494, 58.00721658979143, 60.804908752441406, 55.29233305794852, 58.49103355407715, 58.113173144204275, 60.745404379708425, 61.75624220711844, 58.9842722756522, 58.08325072697231, 54.056561197553364, 56.18295662743704, 57.65287930624825, 61.96312482016427, 61.302295548575266, 61.80062729971749, 62.15788977486746, 65.4088476725987, 63.57186903272356, 64.53828702654157, 62.43820095062256, 65.86355863298688, 61.61197675977434, 14.915069103240967, 0.5615041756204197, 0.9543626521314893, 2.6450154866491045, 0.7241565648998533, 0.3033629102366311, 11.459547553743635, 70.26722267695835, 64.49408258710588, 52.83029447283064, 26.976573841912405, 26.366766929626465, 12.647950070244924, 23.672830479485647, 46.843309674944194, 53.85231195177351, 64.01697063446045, 28.631097997937882, 0.5230716264673642, 0.06978158626173224, 0.061019297157015116, 0.04000975291377731, 0.035966932707067044, 0.026329596360613192, 0.06894825026392937, 0.06671466904559306, 0.12486036361328193, 0.08896153207336154, 0.06719711422920227, 0.10431227407285146, 0.10133740013199193, 0.10880550582494054, 0.14640406758657523, 0.09858122481299297, 0.1944306269288063, 0.18015935271978378, 0.12677870424730436, 0.24220945313572884, 0.20718149415084294, 0.49241791133369717, 18.349641833986553, 97.12073176247733, 73.91107341221401, 80.86257239750454, 53.900921549115864, 30.1408269064767, 46.98963178907122, 56.781259059906006, 55.68570532117571, 91.84985610416958, 34.62552431651524, 0.35021086782217026, 0.42458807677030563, 2.8144929068429128, 14.548041803496224, 14.01527043751308, 6.264575319630759, 34.36455692563738, 62.36111763545445, 74.84887177603585, 76.04105063847133, 77.50749574388776, 70.80232429504395, 69.1558861051287, 65.36323969704765, 63.3179749080113, 58.87877777644566, 60.44867461068289, 59.33243955884661, 62.053215163094656, 59.59112794058663, 61.436659812927246, 57.921149253845215, 57.127001421792166, 51.76941919326782, 55.990772928510395, 54.136600971221924, 55.702224663325715, 53.814166341509136, 53.61959593636649, 53.73996652875628, 52.64054959160941, 47.31032589503697, 49.98889466694423, 54.052847385406494, 49.48671361378261, 47.21102918897356, 49.91642495564052, 50.35367161887032, 47.735482692718506, 47.71053171157837, 48.8925974709647, 47.92812844685146, 52.12172065462385, 53.538868291037424, 55.472180230276926, 52.33693068368094, 54.83287647792271, 48.43173040662493, 53.961051259722026, 48.88530881064278, 56.99112245014736, 51.43545055389404, 56.9829409463065, 57.69031620025635, 56.89846822193691, 53.853010245731895, 56.97483239855085, 56.18651063101632, 54.780417578560964, 54.48880515779768, 61.58485099247524, 54.7945363180978, 64.80570929391044, 56.4251743044172, 60.91216809409005, 14.376798238073077, 8.717533043452672, 60.55455126081194, 48.900223118918284, 60.7024575642177, 51.22132791791643, 58.67692565917969, 52.768945353371755, 55.72087362834385, 54.36938994271414, 52.84304789134434, 45.5068028313773, 48.17262513296944, 50.956493854522705, 53.35947275161743, 45.12331090654646, 46.99504790987287, 47.97424364089966, 53.43648658479963, 52.13180596487862, 51.76792185647147, 46.49925919941494, 45.815636362348286, 44.31445721217564, 44.96478428159441, 40.83315263475691, 43.869088104793, 42.20623826980591, 43.99739006587437, 43.388762610299246, 44.412947927202495, 44.41676596232823, 44.50780473436628, 45.75831024987357, 46.59931673322405, 45.473079749516074, 51.50455733707973, 58.672763688223704, 61.208036286490305, 65.075820514134, 56.289917196546284, 63.11375345502581, 62.560669898986816, 64.52011053902763, 64.88601657322475, 60.783897399902344, 60.43334688459124, 55.76758984157017, 59.80501433781215, 60.01357841491699, 65.06580121176583, 63.83289200919015, 62.21569183894566, 65.36321190425328, 69.41724954332624, 68.50161593300956, 67.95409093584333, 67.51177556174142, 70.23817920684814, 64.09968199048723, 16.550683736801147, 2.1076663434505463, 5.564586000783103, 2.642072490283421, 0.9780420043638774, 0.4489159999149186, 14.787286520004272, 78.37269932883126, 71.32382828848702, 57.900850091661724, 51.497313840048655, 39.67887272153582, 15.163913624627249, 27.832115956715175, 58.26921231406075, 63.80378600529262, 73.95358943939209, 34.43390342167446, 0.6268805361219815, 0.1369576659053564, 0.20361174855913433, 0.15153371090335505, 0.14335165066378458, 0.1480769006801503, 0.1266087447958333, 0.1343348566442728, 0.3226505124143192, 0.2503497563302517, 0.19303507038525172], [0.10748390959841864, 0.07315432599612645, 0.05754639208316803, 0.033830398959772925, 0.03705673458586846, 0.02381444855460099, 0.07148468201713902, 0.0409853098514889, 0.03262922912836075, 0.0866432154018964, 0.14155916470502103, 36.75069338934762, 66.11866869245256, 54.397683007376536, 55.40405314309256, 31.650020803724015, 30.43891852242606, 47.593065466199604, 38.51134259360177, 61.776322501046316, 76.34477029527936, 7.06402245589665, 0.1268095640199525, 0.15645931874002728, 0.1454448633428131, 2.7641165128776004, 0.3855096979865006, 6.8783687608582635, 35.52447877611433, 63.48632281167166, 69.06592777797154, 67.95236083439418, 68.04541110992432, 63.74801281520298, 59.377609797886436, 60.04002325875418, 56.62181527273995, 54.52640880857195, 54.42611156191145, 56.039240087781636, 54.12696729387556, 57.978569167000906, 59.514607429504395, 60.98891789572579, 61.22831112997872, 56.330623217991416, 50.51480034419468, 48.01426873888288, 47.241267749241416, 49.180065291268484, 44.505602155412944, 47.42208072117397, 47.48218958718436, 45.73399155480521, 44.71577821459089, 43.94836705071585, 42.76122563225882, 41.43181984765189, 45.00295768465315, 47.310805320739746, 41.531015804835725, 43.22160979679653, 41.6485515322004, 44.308315004621235, 50.35427263804844, 56.83840104511806, 58.83315590449742, 58.86658368791853, 53.72708804266793, 51.72932461329869, 50.85677330834525, 51.19257974624634, 51.6094890322004, 51.8944103377206, 54.12266983304705, 52.77309342793056, 51.38178961617606, 53.56028611319405, 55.891094071524485, 43.89680446897234, 44.72779859815325, 55.591126441955566, 50.57182421003069, 53.740022114345, 53.68698304040091, 56.45155314036778, 41.80893680027553, 12.953479732785906, 7.744722706930978, 40.51254538127354, 49.157289096287315, 52.633472851344514, 50.118860721588135, 48.753595284053254, 50.24583557673863, 53.14221995217459, 51.23723234449114, 50.07367658615112, 45.579901354653494, 44.1652272769383, 44.88030808312552, 42.91278668812343, 42.8735363142831, 42.305819852011545, 47.5002236366272, 49.86300025667463, 49.176104818071636, 49.90213598523821, 42.44603797367641, 41.184245109558105, 39.32643577030727, 40.28936924253191, 35.994343757629395, 36.24745273590088, 35.646791390010286, 38.59415122440883, 37.372042996542795, 40.446606976645334, 41.64634895324707, 39.953191076006206, 38.900716168539866, 40.52298852375576, 42.643707275390625, 43.24409416743687, 50.35923017774309, 56.1474061693464, 57.499817439488, 59.54613140651158, 56.99594449996948, 54.706078801836284, 57.36878136226109, 56.48976823261806, 55.61704669679914, 51.68282726832798, 52.38690560204642, 51.75340359551566, 54.15923472813198, 56.74897425515311, 59.26032420567104, 60.71624973842076, 60.9935245513916, 61.365294865199495, 60.208537919180735, 57.82510083062308, 60.286246572222026, 60.965168952941895, 65.80801473345075, 34.59559147698538, 0.09874112159013748, 1.217321896127292, 1.2434321407760893, 0.14760648592242173, 0.01680927168178771, 0.9458934494427272, 46.53651891435896, 60.798460824149, 54.24912357330322, 57.05446917670113, 46.13391249520438, 23.64167823110308, 15.610698427472796, 28.881867170333862, 49.40237290518624, 49.09096506663731, 45.77892555509295, 3.2709335344178334, 0.07248469335692269, 0.010117396479472518, 0.0372612450404891, 0.031089728165950094, 0.0782845528530223, 0.11207843305809156, 0.03904497450483697, 0.07641953828611545, 0.011739586263761988, 0.06089609555367913, 0.05717855824955872, 0.025231568941048214, 0.07171219480889184, 0.025235557030620318, 0.018330594691048776, 0.006923505429378045, 0.05822016378598554, 0.025358114025688598, 0.06102959053324802, 0.07731880074633019, 0.07577978832913296, 45.67413977214268, 73.55058697291783, 64.17063699449811, 65.39999566759381, 38.75837884630476, 26.67739830698286, 30.673211778913224, 45.82710436412266, 66.6508103779384, 84.80732876913888, 7.243681592600686, 0.2017445151827165, 0.3044936752745083, 2.4231364897319247, 4.437121791499002, 1.0265460759401321, 9.22561138016837, 37.09058536802019, 64.41585976736886, 69.64310768672398, 71.51977443695068, 69.67533343178886, 65.4996119907924, 62.48872825077602, 62.60765361785889, 57.77240916660854, 55.39848068782261, 56.873020444597515, 56.87259660448347, 57.152716704777305, 62.20935508183071, 63.246081897190635, 63.75428703853062, 62.969884055001394, 57.54905237470354, 51.75031164714268, 49.631635665893555, 50.40122856412615, 50.61135598591396, 47.22005142484392, 48.26390014375959, 50.40501880645752, 46.951555660792756, 46.924235343933105, 47.446514061519075, 45.187460150037495, 44.411558287484304, 46.68440784726824, 49.20421722957066, 43.8383458001273, 44.64897475923811, 43.646308013371055, 46.23115600858416, 52.76765298843384, 58.57257066454206, 60.84843226841518, 60.89828559330532, 56.655201366969514, 54.434056827000205, 53.573675291878835, 53.88916867119925, 54.69184194292341, 54.79885809762137, 56.73208665847778, 54.37368392944336, 52.6816759790693, 55.605693340301514, 55.55554471697126, 45.558163915361675, 46.25094447817121, 59.87782451084682, 53.620151792253765, 55.72910724367414, 56.03770453589303, 59.1293089730399, 43.47238070624215, 15.193521635872976, 12.029864379337855, 38.9189829826355, 51.18406472887312, 53.74591071265084, 52.69198710577828, 50.7447509765625, 53.895991802215576, 55.91232776641846, 53.27235276358468, 51.35575124195644, 47.91934592383248, 46.9861854825701, 46.02626058033535, 45.466975757053916, 44.52335132871355, 44.56354318346296, 49.52559920719692, 51.74823413576399, 50.71237237112862, 53.00375625065395, 46.150570801326204, 44.82780749457223, 42.191758223942344, 41.50096484592983, 37.72324316842215, 37.99300350461687, 38.92085552215576, 39.6247010912214, 38.601870673043386, 43.212834221976145, 42.27815212522234, 42.10384266717093, 40.55995294025966, 43.3184676851545, 45.26072890417916, 45.220481463841026, 52.655495166778564, 57.795685631888254, 59.42585808890206, 59.16120120457241, 59.00899396623884, 57.07203074863979, 58.64722211020333, 57.57985373905727, 57.94881350653512, 52.72984089170183, 53.757733072553364, 53.59435313088553, 56.65044185093471, 60.138486180986675, 63.03050013950893, 62.395261083330425, 63.59718826838902, 62.10933576311384, 63.251751627240864, 59.54736818586077, 65.10466943468366, 62.904654366629465, 69.30072130475725, 39.5802777835301, 0.31281351883496555, 0.9615845446075711, 2.989598802157811, 0.8486785973821367, 0.05584854818880558, 0.43014359580618994, 49.226732867104666, 65.8786848613194, 62.78780651092529, 51.91494573865618, 41.662482670375276, 22.47348976135254, 17.91573899132865, 39.884820801871165, 53.52997807094029, 57.33644444601876, 54.93682847704206, 4.61710228238787, 0.09267504566482135, 0.0455354672989675, 0.021506605071148703, 0.13981995731592178, 0.028378770420593873, 0.0665114274514573, 0.04257578236450042, 0.033762935615543804, 0.046719286989952834, 0.029372837793614184, 0.18876200967601367, 0.16137320149157727, 0.22561714132981642, 0.07125482149422169, 0.18944893138749258, 0.09799873642623425, 0.1319943858044488, 0.1409105666513954, 0.13129321485757828, 0.2933339183884007, 0.18093912516321453, 52.278822898864746, 84.25069468361991, 70.06523854391915, 72.18206977844238, 45.42123229163033, 41.503157002585276, 65.60981042044503, 54.256843021937776, 76.70795958382743, 92.34198311397007, 9.675005231584821, 0.34765604776995523, 0.507919830935342, 4.225203037261963, 7.779939651489258, 1.9016665858881814, 9.209885001182556, 40.31191267286028, 68.92465005602155, 72.94323103768485, 74.33681733267647, 72.6605783190046, 68.67086015428815, 66.03459548950195, 66.44995880126953, 61.52285916464669, 58.87472002846854, 61.29531260899135, 60.41676153455462, 60.11854485103062, 61.03139223371233, 65.50220366886684, 65.46878978184291, 64.91531017848423, 59.77583885192871, 54.15274511064802, 52.61643934249878, 54.32070738928658, 55.45980896268572, 49.962303910936626, 51.795301233019146, 53.807864325387136, 51.218208176749094, 50.710822922842844, 48.476549761635916, 46.408550466809956, 46.40340532575335, 50.704434054238455, 51.97510324205671, 46.60855783735003, 49.59490401404244, 45.94859709058489, 47.83741971424648, 55.04961511066982, 61.92939131600516, 64.59117671421596, 63.44316060202462, 59.25246579306466, 56.50512375150408, 55.27581024169922, 55.89647197723389, 58.434252875191824, 56.975280557359966, 61.19114521571568, 56.025750160217285, 55.79017843518938, 56.797191279275076, 59.14264951433454, 47.69714948109218, 48.13018206187657, 59.8434031350272, 54.940507548195974, 56.1440988268171, 59.873245647975374, 60.190660204206196, 49.053479535239084, 14.504989896501813, 9.956928389413015, 47.79027966090611, 50.1581597328186, 56.7963297026498, 52.87468998772757, 53.93191051483154, 55.40666219166347, 59.47539874485561, 54.909647124154226, 54.23161063875471, 50.833020891462056, 49.572193826947895, 49.35518421445574, 48.81768199375698, 46.86281674248831, 46.74973828451974, 51.6525331224714, 54.717536381312776, 53.387369768960134, 55.66030618122646, 46.06639337539673, 47.34750917979649, 43.70595482417515, 46.51443406513759, 41.72275134495327, 41.71668209348406, 40.83565051215035, 42.6551787512643, 41.31666387830462, 45.23246363231114, 45.437359060559956, 45.80483538763863, 42.96094812665667, 45.377552441188264, 47.94566570009504, 48.018600940704346, 53.87339973449707, 61.34997408730643, 62.57735252380371, 62.95991339002337, 63.01611042022705, 60.50225217001778, 61.2589179447719, 61.94017492021833, 61.03250394548689, 56.44734948022025, 55.52752610615322, 56.53750235693795, 59.2372978755406, 62.649259431021555, 64.26359694344657, 66.97237300872803, 66.15634877341134, 66.71282999856132, 64.71331909724644, 63.16061210632324, 68.70675454820905, 66.71972955976213, 71.21917452130998, 44.16264254706246, 0.2930066202368055, 4.828082161290305, 5.631412037781306, 0.930377904857908, 0.14352395784642014, 1.1903965409312929, 56.037728854588096, 71.84606879098075, 68.58188152313232, 77.15096977778843, 62.122071811131065, 31.985278333936417, 27.603667872292654, 44.51036861964634, 63.168407985142295, 64.7232619694301, 64.37746402195522, 6.060712567397526, 0.217732537271721, 0.17378391910876545, 0.1533797468457903, 0.15144495852291584, 0.130760700574943, 0.11616636227284159, 0.09541333480072872, 0.20444230256336077, 0.15314037326191152, 0.12782219611108303], [0.12779809454722063, 0.14961474601711544, 0.049798611218908, 0.03270523862114974, 0.015967080801991478, 0.033856064546853304, 0.08671998485390629, 0.06281201381768499, 0.07001150106745106, 0.05446904578379222, 1.1321538090705872, 58.33711011069161, 59.21707166944231, 55.598970958164756, 44.07449769973755, 78.30382878439767, 54.35473966598511, 53.65818623134068, 47.58603388922555, 67.72966412135533, 53.61909566606794, 0.8489326951759202, 0.020271296446610774, 0.15538533351251058, 0.6376457927482468, 1.291769347020558, 2.6254211323601857, 16.93231007031032, 44.34606456756592, 65.56053379603794, 69.71201297215053, 68.15266350337437, 64.95820835658482, 62.1027558190482, 60.54800605773926, 60.08118438720703, 56.53518860680716, 57.17829997198922, 57.10523271560669, 59.36105918884277, 61.324244907924104, 65.65163162776402, 66.77774701799665, 63.979825564793174, 58.64358125414167, 62.82393019539969, 57.577539988926475, 55.64590951374599, 49.832688740321565, 46.178356647491455, 46.30207974570138, 45.707706519535606, 46.85358953475952, 46.667145047869, 44.320165157318115, 46.36723647798811, 41.622513157980784, 42.27271515982491, 44.38822971071516, 44.32936109815325, 41.553465434483115, 41.93586996623448, 41.5252731187003, 45.24608210154942, 53.33627619062151, 57.964214188711985, 55.425203459603445, 56.25803191321236, 56.72704226630074, 53.94029699053083, 53.26541151319231, 51.04514939444405, 53.450723443712505, 55.7099232673645, 56.99243218558175, 56.748560837336946, 52.17686850684029, 48.14180292401995, 52.81950739451817, 52.818517276218955, 51.28935078212193, 55.147702830178396, 51.68802799497332, 49.36109018325806, 53.61298819950649, 56.333485875810894, 36.24815102985927, 14.98665986742292, 9.967817085129873, 39.142388411930625, 52.86113405227661, 53.501181261880056, 53.17189918245588, 52.02248648234776, 49.95716224397932, 49.406545298440115, 53.847934586661204, 51.12091602597918, 50.313914026532856, 47.949011257716585, 45.736621447971885, 45.15860775538853, 45.418817792619976, 46.67348527908325, 49.9316588810512, 49.62593814304897, 52.25325700214931, 51.46050923211234, 48.198712144579204, 41.67182452338082, 40.36963483265468, 39.280021803719656, 35.36221054622105, 35.798949990953716, 35.4866110937936, 39.390098639896934, 39.837065832955496, 41.29802186148507, 41.507735865456716, 38.692304951804026, 38.427853039332796, 41.91475091661726, 42.01518712724958, 42.121272223336355, 48.546789101191926, 55.84297432218279, 55.4870354788644, 57.711185114724294, 55.39429439817156, 54.03151988983154, 56.607713903699604, 53.59089987618582, 51.812056813921245, 51.511727878025596, 52.184556688581196, 52.81769738878523, 55.25680691855294, 53.76352787017822, 58.70952660696847, 57.3028290612357, 57.53823750359671, 57.864816733769004, 58.738632610866, 57.8352313041687, 62.728184018816265, 62.92456095559256, 62.333303996494834, 53.83011940547398, 4.077663251331874, 0.28209900696362766, 1.9367139509746005, 1.946437520640237, 0.39774973690509796, 0.23185468305434498, 17.733670132500784, 66.51831517900739, 56.46310452052525, 45.91454744338989, 44.772659642355784, 31.75738784245082, 17.56040116718837, 11.459376454353333, 40.34847756794521, 52.229178019932334, 57.77306924547468, 20.5702965259552, 0.3905934180532183, 0.08323922912989344, 0.08836771893714156, 0.011537709373182483, 0.050790059446756325, 0.015056047455540724, 0.07351377313690526, 0.10398822610399552, 0.03092981442543013, 0.06836724108351128, 0.10059569350310735, 0.02571297935875399, 0.07043226063251495, 0.05095525897507157, 0.05760053239230599, 0.036739112343639135, 0.055310785437801054, 0.03056091529184154, 0.0989856995376093, 0.07180767825671605, 2.2156046543802534, 71.37931660243443, 66.72541318620954, 65.0163995197841, 50.645822525024414, 77.21159975869315, 40.90003946849278, 48.54320730481829, 55.203809533800396, 75.24867112295968, 57.47880956104824, 0.679891437292099, 0.04615002664338265, 0.8617647694689887, 3.3525605372020175, 3.3751163440091267, 3.191146718604224, 20.072421618870326, 49.23629011426653, 66.06832204546247, 71.76030022757394, 70.40281677246094, 66.63402353014264, 65.17139993395124, 63.13482734135219, 61.5280772617885, 60.34731428963797, 59.860794476100374, 58.16619832175118, 61.40651157924107, 63.44422367640904, 68.52373204912458, 71.10715566362653, 67.1374761036464, 63.80248669215611, 65.00762394496373, 61.297035762241904, 55.99411153793335, 52.61670337404524, 49.864803314208984, 48.07732711519514, 47.72122498920986, 48.634065423692974, 49.756592069353374, 46.729227202279226, 47.233662945883616, 44.476225171770366, 43.562366826193674, 45.28999124254499, 45.54309327261788, 44.13069472994123, 44.59854473386492, 42.84660857064383, 46.97231340408325, 55.6672682762146, 60.03965500422886, 57.61641863414219, 57.75820010049002, 58.34471838814871, 56.405827045440674, 55.077394008636475, 53.800968238285606, 55.62240028381348, 55.3254724911281, 58.298603194100515, 58.45368003845215, 55.99770723070417, 52.771999086652485, 53.535189219883506, 54.795443058013916, 53.62817348752703, 59.95935467311314, 56.04020936148507, 52.24722249167306, 55.828758307865684, 59.13414491925921, 38.04783868789673, 16.835188150405884, 14.151661838803973, 40.615934576307026, 56.529310430799214, 53.845172677721294, 56.282027517046245, 54.69497210638863, 52.52790192195347, 51.525304658072336, 54.673099177224294, 53.13365282331194, 52.205932821546284, 48.98996952601841, 49.02783720833914, 47.9326308795384, 47.06111833027431, 49.41763462339129, 53.67023440769741, 51.44636269978115, 54.98077930722918, 54.396995135716026, 51.16984176635742, 42.992211546216694, 41.448669229234966, 41.0068541254316, 37.08005537305559, 38.701632908412385, 37.280681133270264, 41.325675691877095, 41.74332843508039, 42.70488616398403, 43.890161991119385, 40.844804763793945, 40.57239716393607, 43.990052768162315, 45.39783770697457, 42.834890433720176, 51.50484568732125, 58.37380354745047, 57.78418983731951, 59.404082434517996, 57.17556585584368, 57.421910762786865, 57.46843242645264, 55.14828995295933, 54.613949162619456, 53.7647750718253, 53.247141224997385, 56.02084125791277, 56.081318378448486, 56.8904812676566, 59.88956001826695, 59.259358406066895, 58.937698500497, 60.089487484523225, 62.57015419006348, 61.45751135689871, 66.62547724587577, 63.43287031991141, 65.15220900944301, 57.0412780216762, 6.024946280888148, 0.5709272899797985, 0.7494402453303337, 2.4679115499768938, 0.1954980575080429, 0.2830109308872904, 16.931960923331125, 71.16892514910016, 60.789977073669434, 54.51333924702236, 40.99375677108765, 32.54110990251814, 25.399317128317698, 19.516828026090348, 49.630958216530935, 57.10488530567714, 65.19209861755371, 26.58162954875401, 0.36425719410181046, 0.06606880548809256, 0.020366364291736057, 0.030691550246306827, 0.0478374753812594, 0.05912779936833041, 0.05280605823333774, 0.06937484523015362, 0.0337702671864203, 0.08137251822543995, 0.20190131105482578, 0.323451428008931, 0.20089144738657133, 0.13706243171223573, 0.10208030098250934, 0.09147929732820817, 0.1443008804427726, 0.20013752712735108, 0.2297841470156397, 0.23712809437087604, 3.0654496806008473, 81.68333530426025, 76.88988426753453, 73.02207919529506, 57.08702148709978, 86.4364242553711, 68.00074114118303, 76.36831774030412, 62.57141181400844, 82.48573412214006, 65.62375545501709, 1.4128886078085219, 0.11017503376517977, 1.2786005565098353, 4.476323527949197, 8.161538192204066, 8.12389372076307, 22.656336818422588, 50.17166355678013, 67.5137905393328, 75.62421430860246, 74.32193429129464, 69.36720166887555, 69.25341102055141, 67.15481185913086, 66.54799788338798, 65.17395687103271, 63.11363533564976, 62.650649070739746, 64.71088027954102, 66.99914441789899, 71.29969024658203, 68.99127633231026, 67.69063608986991, 64.72687503269741, 67.94860880715507, 62.47036416190011, 58.85614749363491, 56.19089494432722, 53.55879919869559, 51.88714599609375, 49.36116313934326, 50.49972970145089, 52.18555722917829, 49.37737328665597, 50.333737237112864, 46.315156255449565, 45.99152306147984, 48.23386655535017, 48.47501768384661, 45.6167893409729, 47.51801797321865, 46.266765526362825, 49.822030203683035, 58.30877535683768, 64.7157370703561, 59.67543043409075, 59.27515860966274, 61.317352294921875, 59.95876407623291, 58.088176999773296, 56.65346431732178, 57.71422495160784, 59.67934921809605, 61.13678250994001, 60.77551787240164, 56.60970803669521, 51.93590497970581, 56.311380181993755, 56.674746649605886, 53.95021554401943, 59.529768398829866, 57.594802788325715, 52.351299558367046, 60.91394683292934, 59.67411027635847, 44.4740434374128, 17.107090268816265, 11.27093609741756, 46.583909102848594, 57.393009730747764, 57.67704861504691, 57.03813396181379, 56.148253849574495, 54.170473439352854, 53.00862693786621, 57.77982289450509, 57.203869342803955, 55.0703033719744, 54.718985080718994, 51.47694866997855, 51.310459409441265, 52.02671446119036, 52.285791942051475, 55.879594802856445, 54.17352717263358, 57.628845487322124, 58.21412352153233, 52.79082523073469, 45.09689038140433, 43.319971970149446, 44.07263558251517, 39.751828806740896, 40.020960330963135, 40.56397247314453, 45.52501405988421, 44.06487444468907, 45.305426665714805, 46.119060720716206, 44.08302313940865, 43.50499207632882, 47.414802483149934, 46.86236163548061, 46.50856283732823, 55.135790143694194, 60.74289608001709, 59.946222577776226, 63.1720210484096, 61.475847652980256, 60.73824773515974, 60.8954507282802, 58.8830509185791, 58.71634973798479, 57.09660652705601, 57.07677289417812, 58.42640835898263, 60.45278099605015, 60.310968262808665, 63.624147278921946, 62.31198692321777, 61.80876364026751, 64.18092032841274, 65.09386498587472, 63.05690329415457, 68.58224977765764, 68.44725322723389, 68.1751548222133, 61.47962747301374, 7.264352483408792, 2.1431735924312045, 9.203517845698766, 3.0672916046210696, 1.1144811745200838, 0.3142482675611973, 20.86301371029445, 77.9899161202567, 66.20569487980434, 60.51204913003104, 60.94125325339181, 43.75629104886736, 27.983260120664323, 22.21186055455889, 57.08132743835449, 65.74807957240513, 74.32055159977504, 31.843013967786515, 0.6120489005531583, 0.27471866298999104, 0.2540988251566887, 0.19491154540862354, 0.16098243317433766, 0.19089769864720957, 0.16902221819119795, 0.14850315637886524, 0.1749398306544338, 0.20516305603086948], [0.07452140442494835, 0.03353918869314449, 0.03665605287200638, 0.10400580016097852, 0.041056338897241015, 0.03170909153829728, 0.09806867303060633, 0.12808009370097093, 0.22814643489462988, 0.28084393431033405, 14.272388526371547, 65.11952468327114, 57.054986817496165, 43.54224484307425, 37.32819638933454, 56.7841807774135, 35.68494047437395, 44.167999608176096, 49.99147939682007, 80.77503899165562, 27.725966589791433, 0.09070353502673761, 0.10707754854645048, 0.41509928022112164, 2.6864695250988007, 1.9928764573165347, 4.272563695907593, 28.223021609442576, 54.298869201115195, 66.02999578203473, 70.85385908399309, 64.85365881238664, 65.92696789332798, 61.13358633858817, 59.52575928824288, 60.654105050223215, 58.462928090776714, 61.19542530604771, 64.21067251477922, 62.93016120365688, 62.284624917166575, 62.003202029636924, 61.752594402858186, 72.2041164125715, 67.05427142551967, 63.5311039515904, 59.29161194392613, 60.09391348702567, 57.243091923849924, 52.473633016858784, 46.725231988089426, 46.4695417540414, 44.98440252031599, 45.079255853380474, 45.52560813086373, 44.52852078846523, 41.99368245261056, 43.26355259759085, 42.106239795684814, 43.85302039555141, 43.64361211231777, 43.13934659957886, 40.52963447570801, 42.585978167397634, 50.47418812343052, 59.050724846976145, 59.900121280125205, 53.52624341419765, 53.84399495806013, 55.64281409127371, 57.90450137002127, 58.07489204406738, 56.16273736953735, 58.542790685381206, 52.67661074229649, 55.45625843320574, 50.55550636563982, 48.75314017704555, 52.713821819850374, 51.86776747022356, 52.54772513253348, 52.70002269744873, 48.2469083241054, 47.58451918193272, 52.8752875328064, 55.01217474256243, 33.90098006384713, 18.741416011537822, 14.869063343320574, 45.62157664980207, 54.57875306265694, 50.862071309770855, 52.444047587258474, 53.31411838531494, 57.395608357020784, 51.36837611879621, 49.02543313162667, 52.424755913870676, 52.73698363985334, 51.0573365347726, 51.64052316120693, 49.31911611557007, 47.732675620487754, 46.98894044331142, 47.710913862500874, 50.69582871028355, 51.07606887817383, 52.24514150619507, 52.47945213317871, 48.27904026848929, 40.708613123212544, 38.55579021998814, 36.30155488422939, 35.974253041403635, 35.96241331100464, 37.843085697719026, 40.16680301938738, 40.56406627382551, 40.068055221012656, 39.71209553309849, 37.898111956460134, 40.14351960590908, 41.875344208308626, 42.60373081479754, 42.165084089551655, 53.089219093322754, 55.218421595437185, 56.38207115445818, 54.870973450796946, 54.34972306660244, 53.432491370609824, 52.320651054382324, 52.496204239981516, 52.22226108823504, 52.160474232264924, 51.944680554526194, 52.39357239859444, 52.157715797424316, 54.288947173527305, 53.090403761182515, 55.62978274481637, 55.063657420022146, 56.71958337511335, 57.891494342258994, 61.73811435699463, 61.91981669834682, 60.851162910461426, 62.38856301988874, 18.78755031313215, 0.5438807755708694, 1.961867949792317, 1.3477506573711122, 0.11363233931894813, 0.018879580411261747, 1.8835033433777946, 48.39031566892351, 63.04702990395682, 56.36316163199288, 52.33385263170515, 41.886972018650596, 10.428337608064924, 12.324356828417097, 23.143403802599224, 44.04685776574271, 52.19565643583025, 45.30495418821062, 3.7940881592886786, 0.17427770261253628, 0.0922486474737525, 0.04313505128292101, 0.003981864437394376, 0.017044231395370195, 0.08439631454114403, 0.03391784516030124, 0.01564440856288586, 0.06443114764988422, 0.0539547773078084, 0.031241088972559998, 0.048830277286469936, 0.05751371383666992, 0.017166537332481573, 0.09267505923552172, 0.1373020631394216, 0.12711578687386854, 0.21302236430346966, 0.4038650473313672, 18.92764684132167, 76.17633206503731, 63.5424017224993, 52.59441007886614, 44.468377181461875, 63.14322076525007, 34.292281763894216, 52.38019016810826, 55.736722469329834, 86.83089433397565, 30.025427750178746, 0.10094734427652188, 0.10872882458248309, 1.0382715953247887, 2.385156116315297, 4.312768144266946, 4.624868197100503, 31.981182370867046, 57.27982357570103, 67.96939086914062, 70.99590110778809, 70.56810052054269, 68.96645041874477, 64.91854109082902, 63.53511306217739, 62.244228090558735, 61.762446948460166, 64.99233095986503, 65.1530566896711, 66.28908021109444, 65.72517830984933, 66.645585332598, 64.7494705745152, 69.21677316938127, 66.64252117701939, 65.82709448678153, 61.66417857578823, 62.80053561074393, 58.822247232709614, 55.844763483319966, 46.637257371629985, 47.16915239606585, 46.750346251896445, 46.57894114085606, 45.55973768234253, 46.44673776626587, 44.92447778156826, 44.95131867272513, 45.62755210059029, 47.18380267279488, 46.357432569776265, 44.624774183545796, 41.99495397295271, 45.08706215449742, 52.585075174059185, 61.18070207323347, 59.663549014500205, 56.18563168389456, 54.980570861271445, 59.088307653154644, 59.706169264657156, 60.255743980407715, 56.97875813075474, 57.82399606704712, 55.57606622150966, 56.82589776175362, 54.292153767177034, 51.79524564743042, 53.27948161533901, 54.61990376881191, 56.9371314729963, 56.85963126591274, 50.18023763384138, 50.84011500222342, 54.92369638170515, 57.508770193372456, 35.88451010840279, 20.882326228278025, 20.110829523631505, 47.22256667273385, 56.185694217681885, 52.05451420375279, 55.20384080069405, 56.159548146384104, 57.61737053734915, 51.87702941894531, 51.23766313280378, 55.06237547738211, 56.838095324380056, 52.98292555127825, 53.97548614229475, 49.88779142924717, 49.38783727373396, 51.045048645564485, 51.91906254632132, 54.29990448270525, 53.161619322640554, 53.38528183528355, 55.10186208997454, 50.9487361907959, 42.41368021283831, 40.86462450027466, 38.009265763419016, 38.24803713389805, 38.01015860693795, 39.36442852020264, 40.68027489525931, 42.24425186429705, 42.979881967817036, 43.270271505628315, 40.914839131491526, 41.49749422073364, 43.22879770823887, 45.789024761744905, 44.947448526109966, 56.50579425266811, 57.769504819597515, 57.183563232421875, 56.71052292415074, 57.62524632045201, 55.53300823484148, 55.43323557717459, 53.92250612803868, 54.80216544015067, 53.98237875529698, 54.0263261113848, 54.75894069671631, 54.50400086811611, 56.31230429240635, 57.87022590637207, 57.66828693662371, 58.35509899684361, 58.39939376286098, 62.323152678353445, 63.25754642486572, 64.23640169416154, 63.5656920841762, 66.44436550140381, 22.306027753012522, 0.06070081317531211, 0.36517772184950964, 2.001425130026681, 0.44434644654393196, 0.06171419844031334, 1.548834564430373, 52.87209830965315, 67.95902415684291, 61.880837304251536, 52.89064999989101, 40.82437358583723, 18.71666305405753, 20.2812271458762, 28.29848599433899, 50.84783445085798, 58.9735928944179, 56.05487353461129, 4.67905763217381, 0.13885695327605518, 0.06771940298910652, 0.13378554183457578, 0.04970900388434529, 0.04183073055797389, 0.03750814697039979, 0.06935552055282251, 0.0537901104294828, 0.04214851564860769, 0.17562691521431717, 0.12782233181808675, 0.17603149850453648, 0.18820620807153837, 0.12367154311920915, 0.16683847536998136, 0.304582699068955, 0.246780662132161, 0.388055507093668, 0.693150554384504, 25.105813060488018, 88.9140545981271, 70.51302215031215, 60.90440695626395, 50.56479263305664, 66.26227406093052, 48.430775029318674, 61.96855136326381, 65.04681178501674, 96.1222061429705, 33.6514424596514, 0.24265147798827716, 0.26205443111913546, 3.258123661790575, 9.883242743355886, 9.243951150349208, 8.675254123551504, 34.19376673017229, 59.80725860595703, 71.17664459773472, 78.828827721732, 71.23475238255092, 72.72732271466936, 67.52461583273751, 66.00308540889195, 66.94890894208635, 65.59023039681571, 67.24227578299386, 71.05443968091691, 68.25036212376186, 67.93649114881242, 67.32320840018136, 66.73136084420341, 69.51754678998674, 67.94407163347516, 69.12515422276088, 63.75594070979527, 62.83190672738211, 61.156077657427105, 58.290543283735005, 51.093884059361045, 51.57146501541138, 51.70048611504691, 49.30898911612374, 49.081390448978965, 48.950361319950645, 47.41225596836635, 48.172944750104634, 47.63907643726894, 48.85164826256888, 50.06143038613455, 47.60699313027518, 46.84358065468924, 47.60527345112392, 54.87163005556379, 65.01283509390694, 62.278767585754395, 56.8093957901001, 57.11303554262434, 60.974208559308735, 62.68586948939732, 61.85859612056187, 61.64366749354771, 61.47345747266497, 57.389754499707905, 58.67668942042759, 53.74994414193289, 52.27726650238037, 54.32506390980312, 57.09918083463396, 57.81121138163975, 57.99167694364275, 52.13265017100743, 54.013249601636616, 58.39435631888253, 59.700645446777344, 40.08125679833548, 19.84148781640189, 16.893674612045288, 51.81356457301548, 57.99239608219692, 56.288485867636545, 57.80557639258248, 60.26171943119594, 61.39241368430001, 53.36370073046003, 53.60123184749058, 56.826484884534565, 57.633090836661204, 55.23536825180054, 57.724622930799214, 53.970184666769846, 51.837216241019114, 52.842835971287315, 53.47568484715053, 55.05828646251133, 57.203028610774446, 56.49597992215838, 58.17396988187517, 53.37902498245239, 44.77815219334194, 44.02313314165388, 41.86969879695347, 40.090331145695274, 42.26737894330706, 42.01537125451224, 44.04368591308594, 45.006188596997944, 45.464120047433035, 46.28005395616804, 43.325023310525076, 44.687474727630615, 45.69695765631539, 48.12332418986729, 46.37931592123849, 59.73817266736712, 60.20706490107945, 58.98345933641706, 59.709289005824495, 59.433528900146484, 57.20280279432024, 57.912186077662874, 57.028653144836426, 57.54188878195626, 57.858379227774485, 56.93488720485142, 56.72009059361049, 57.08672966275896, 58.72349943433489, 59.24398899078369, 60.731452396937776, 61.22298880985805, 63.40426458631243, 64.35843290601457, 68.00463908059257, 65.66523620060512, 67.21786676134381, 68.35095814296177, 25.68919771058219, 0.6677449547818729, 6.930851110390254, 4.66473913192749, 1.1665115654468536, 0.1813137172056096, 2.2844463203634535, 60.9888345173427, 75.27751309531075, 68.59723704201835, 65.39686897822789, 56.95358828135899, 19.199670553207397, 21.18779856818063, 35.75497136797224, 60.06753812517439, 65.64346749441964, 64.39526530674526, 6.210337681429727, 0.4125488299344267, 0.14282438824219362, 0.08434143462883574, 0.15372946379440172, 0.10368472417550427, 0.24536569948707307, 0.1196194269827434, 0.16005929985216685, 0.09089628646948508], [0.03286394117666142, 0.03780021558382681, 0.08337517362087965, 0.026213561783411672, 0.07951384117560727, 0.048693264102829356, 0.11372575323496546, 0.0665267894842795, 0.059477787730949264, 0.0569721818236368, 42.380912508283345, 75.25001907348633, 59.00900786263602, 49.993018422807964, 23.484596831457957, 20.150032997131348, 42.09820072991507, 54.92787572315761, 54.625764574323384, 72.14962863922119, 7.217935476984296, 0.023265394980886152, 0.09885863028466702, 0.7879351111395019, 3.1380800689969743, 1.7197986819914408, 9.051012703350612, 39.58267838614327, 61.496171133858816, 64.73319094521659, 67.69701453617641, 66.03538758414132, 64.0197707584926, 59.9627662386213, 59.04057352883475, 62.654866627284456, 62.108224051339285, 62.78863334655762, 63.20655359540667, 61.67758859906878, 66.78268023899624, 60.83348669324602, 56.53310414722988, 48.19054453713553, 49.74515880857195, 60.54206534794399, 60.49845150538853, 60.797230992998394, 59.48583493913923, 56.94490303312029, 53.5872347014291, 45.39763273511614, 43.858210699898855, 43.71819755009243, 43.04595586231777, 43.41217803955078, 42.154345648629324, 40.935426643916536, 44.143489837646484, 44.34975406101772, 43.601839542388916, 42.10373844419207, 39.29413359505789, 39.962390490940635, 46.705394881112234, 54.70455367224557, 55.55426624843052, 56.590631757463726, 54.33510405676705, 51.923450333731516, 53.5520281791687, 47.7064322744097, 55.223087310791016, 56.15682445253645, 54.02476624080113, 54.36282042094639, 48.0193305015564, 53.20276655469622, 57.73497922079903, 56.46778760637556, 53.919469765254426, 53.01131936482021, 47.25992366245815, 46.732277461460654, 55.89096205575125, 54.82861375808716, 33.84763526916504, 25.10637412752424, 18.936752455575125, 44.26104988370623, 54.07997662680489, 50.30770928519112, 51.08411489214216, 50.42241014753069, 53.50613185337612, 53.92813069479806, 54.18299756731306, 45.3050479888916, 47.34708186558315, 51.34585700716291, 48.26284749167306, 49.915035315922324, 47.004719802311485, 49.701385157448904, 51.78346497671944, 50.67282322474888, 47.30019889559065, 51.972737380436485, 52.4091328893389, 53.0346166746957, 45.12041350773403, 38.69725554330008, 37.10446786880493, 35.78517171314785, 35.86550331115723, 35.96283367701939, 37.243987696511404, 39.84961775371006, 41.569331645965576, 40.786888054439, 38.348720005580354, 39.937050410679404, 41.01940952028547, 41.79846239089966, 41.24370779309954, 44.539561476026265, 51.049783842904226, 52.497138772692, 52.29208353587559, 52.745602880205425, 53.68481172834124, 53.667649677821565, 53.29773800713675, 53.48464454923357, 51.76155383246285, 53.670095443725586, 53.05061837605068, 52.12765441622053, 52.0671877179827, 52.71794210161482, 49.619073322841096, 57.567089898245676, 57.59025171824864, 60.95910317557198, 60.18661635262625, 64.13593074253627, 57.55556631088257, 60.86952699933733, 38.29385355540684, 0.6656549040760312, 1.1138030737638474, 1.2294684329203196, 0.4803496503404209, 0.20231175688760622, 0.027432838321796486, 24.54562497138977, 65.83143016270229, 54.72877509253365, 52.809060777936665, 49.416707038879395, 21.983669553484233, 15.817374331610543, 23.84765931538173, 38.16300160544259, 50.04681485039847, 56.999383858272004, 15.443314586366926, 0.3111327604523727, 0.05296089653191822, 0.0886596721996154, 0.16423353872128896, 0.03912248695269227, 0.09431147535464593, 0.04974801286256739, 0.05502943089231849, 0.03173449249672038, 0.030950645450502634, 0.10186914088470594, 0.09356029637690101, 0.01882630693061011, 0.08651287561016423, 0.05022807299558606, 0.10822591478271143, 0.0765249283452119, 0.15617332980036736, 0.04382415448448487, 50.66891138894217, 83.73358889988491, 66.55102034977504, 55.43067864009312, 33.837890420641216, 28.019613095692225, 43.67816897800991, 62.190101623535156, 59.222303662981304, 79.88371018001011, 8.527714337621417, 0.0891408281666892, 0.03993720394958343, 1.563123426267079, 3.9307045085089545, 1.2433689555951526, 11.79060229233333, 43.74361753463745, 63.403806005205425, 66.8649399621146, 71.32714257921491, 68.23402690887451, 65.87236894880022, 63.55641623905727, 62.76588494437081, 64.21877411433628, 64.21249294281006, 65.43378475734166, 64.86088493892125, 63.08712100982666, 68.42943804604667, 63.76270130702427, 57.64309971673148, 50.69030141830444, 49.44896405083792, 63.088753836495535, 62.672598430088584, 61.370123863220215, 60.507442474365234, 60.59051513671875, 54.272202014923096, 48.444890294756206, 46.104327065604075, 45.131471565791536, 46.36174045290266, 46.0908579826355, 42.94111796787807, 45.3802935055324, 46.86839962005615, 47.226311751774375, 45.94572401046753, 44.1013629095895, 41.82227734157017, 43.38912391662598, 48.808895996638704, 55.566977977752686, 56.86220209939139, 57.698459489004954, 56.90285948344639, 54.71616758619036, 55.04629387174334, 49.21983330590384, 56.36108412061419, 54.343726771218435, 53.010940687997, 54.90833738871983, 50.02333688735962, 56.04868616376604, 57.39841195515224, 58.23290797642299, 56.62702294758388, 58.5070561000279, 48.18037584849766, 48.6387346131461, 57.3370280947004, 57.30401720319475, 36.017936365945, 25.280994517462595, 22.474144629069738, 45.284453528267996, 55.793353761945454, 53.17568595068795, 53.326409748622346, 51.27967194148472, 55.824165548597065, 54.06167507171631, 55.763219424656455, 46.85263415745327, 46.24710559844971, 53.564319542476106, 52.26406145095825, 53.428180013384136, 50.11792618887765, 54.502941267830984, 53.261572633470806, 52.476881299700054, 51.4433992930821, 52.77804054532732, 54.67571169989449, 55.01056970868792, 48.785907881600515, 41.80529594421387, 39.41813114711216, 37.938227381025044, 38.090135846819194, 37.7392691884722, 40.12680918829781, 43.00441953114101, 43.33761692047119, 43.014129638671875, 40.125200680324006, 41.38311297552926, 42.21490267344883, 43.872152260371614, 42.931713581085205, 45.4262558392116, 52.5917523929051, 53.2277626991272, 55.81792606626238, 55.320782457079204, 56.58761623927525, 55.19495752879551, 55.194478103092735, 54.88039868218558, 54.37794664927891, 57.25472668239048, 54.61728777204241, 54.28522293908255, 54.55530636651175, 55.67643642425537, 54.45916414260864, 58.46843106406075, 60.75911317552839, 62.779447828020366, 62.5062655040196, 65.6827734538487, 60.34987122671944, 60.515432902744834, 43.25701781681606, 1.8821805800710405, 0.30778845133525984, 0.4530188569000789, 1.3120143349681581, 0.2702220385628087, 0.1728299938674484, 25.955310242516653, 72.50965649741036, 61.137873377118794, 57.584196363176616, 48.600116525377544, 22.18646662575858, 16.36573658670698, 31.265531812395366, 46.50495672225952, 56.26800952638899, 65.99775614057268, 20.222921337400162, 0.3624623604118824, 0.10589804433818374, 0.07579645993454115, 0.08423518283026558, 0.0931666646418827, 0.05824087267475469, 0.017985267864008034, 0.0406703338958323, 0.04070041674588408, 0.21259819849261216, 0.16831510327756405, 0.15103269421628543, 0.12572366371750832, 0.14881840374852928, 0.12412237535629954, 0.29210967836635454, 0.22595646312194212, 0.2884329142315047, 0.08647609901215349, 60.47509166172573, 92.34435939788818, 76.55299391065324, 65.0482986995152, 34.49598905018398, 29.132987226758683, 58.42191982269287, 71.96770395551408, 67.85575308118547, 88.39915139334542, 11.424248967851911, 0.1964407597801515, 0.37172384772981915, 5.1118379064968655, 11.29635955606188, 5.869350058691842, 16.211575167519705, 45.79789761134556, 67.95070021493095, 66.44157232557023, 74.50597817557198, 69.70541218348912, 71.0623675755092, 66.57538073403495, 66.36823408944267, 68.29603263310024, 68.89669050489152, 68.12134797232491, 68.65315614427838, 65.77990232195172, 71.15870434897286, 63.14898082188198, 60.67474120003836, 55.419339179992676, 52.58051020758492, 62.915465763636995, 64.79494653429303, 64.65799754006522, 63.040852955409456, 62.5603016444615, 56.451070240565706, 50.61923524311611, 48.95956073488508, 48.86941480636597, 47.4373528616769, 48.12766333988735, 46.40119579860142, 47.05056401661464, 49.53225210734776, 51.47043125970023, 48.36481578009469, 46.917280197143555, 43.309091091156006, 46.21991034916469, 52.98863697052002, 59.685081481933594, 61.45433603014265, 62.141436440604075, 59.36360917772566, 56.903213841574534, 56.677077770233154, 52.017803396497456, 59.47254998343331, 56.898669719696045, 54.12123155593872, 55.555357115609304, 54.37723445892334, 58.86547892434256, 61.07424872262137, 59.93111024584089, 58.10845879146031, 59.42606653485979, 50.10146243231637, 50.76228822980608, 61.73258359091622, 59.09759739467076, 39.64840487071446, 25.9818297794887, 19.477176393781388, 49.29018381663731, 59.657795906066895, 55.939800943647114, 55.044911180223735, 54.95203460965838, 60.62636089324951, 58.08146851403372, 57.100831031799316, 47.77631030763899, 48.26653003692627, 57.40218482698713, 53.39450904301235, 56.41982766560146, 52.673991271427695, 56.927473476954866, 54.98234265191214, 53.98694372177124, 53.52021932601929, 55.78898681913103, 58.328417914254324, 59.00972352709089, 49.16280596596854, 45.1776180267334, 41.89029325757708, 40.19390794209072, 41.88440465927124, 40.015068258558, 41.92603131702968, 44.438083035605295, 46.823726177215576, 46.066448960985454, 43.4835638318743, 44.81580448150635, 45.52515997205462, 46.05918114525931, 45.36037302017212, 48.89532463891165, 56.67591742106846, 57.401448317936485, 58.81922476632254, 59.48705087389265, 59.656183923993794, 57.254205567496165, 59.91528919764927, 57.53376633780343, 57.25280203138079, 57.583414690835134, 57.529760701315745, 56.40962423597063, 57.87560728618077, 59.01581709725516, 55.66988774708339, 62.93917996542794, 64.75701631818498, 65.9308727809361, 64.5154344013759, 68.17850385393415, 61.89371231624058, 61.3146424974714, 46.077871799468994, 2.6655367740562985, 3.8825634803090776, 6.794446681227003, 1.9336024607930864, 0.7033815053956849, 0.1752937545201608, 31.63278579711914, 78.33134365081787, 67.35400281633649, 64.5355772290911, 64.0203891481672, 32.55907446997506, 23.843408754893712, 38.310477120535715, 53.26989310128348, 64.09515871320451, 75.09974343436105, 26.551778350557598, 0.5736428414072309, 0.19618955254554749, 0.19956538639962673, 0.27160741708108355, 0.14680960082582065, 0.16865945979952812, 0.12537634878286294, 0.20220707250492914, 0.12912791461816855], [0.06449068231242043, 0.07700790278613567, 0.001571678789332509, 0.045914174656250646, 0.09181925015790121, 0.14121702020721777, 0.10873943008482456, 0.15310576797596046, 0.1208918294204133, 3.138509337391172, 68.73649978637695, 61.64666911533901, 47.044175148010254, 29.885772432599747, 12.96875969001225, 20.427505833762034, 56.5120267868042, 40.24189567565918, 62.817565645490376, 55.89511360440935, 1.8506064457552773, 0.11124505634818758, 0.3092110407139574, 0.5162811194147382, 0.20410910115710326, 1.607142218521663, 14.107847367014203, 55.54885707582746, 59.225624901907786, 66.36419023786272, 70.37875516074044, 64.19284343719482, 65.06738540104458, 64.48219421931675, 63.807954924447195, 64.83177198682512, 66.42632102966309, 65.19066728864397, 63.48454407283238, 62.13064588819231, 66.76158550807408, 61.03211484636579, 65.17055225372314, 61.24150575910296, 59.124917711530415, 62.36074938092913, 58.645665713718955, 59.82502514975411, 58.62021446228027, 59.59130859375, 59.135499817984446, 50.437095165252686, 45.464856556483674, 44.50784642355782, 42.61118623188564, 43.69265944617135, 39.373172828129356, 42.57675095966884, 43.488080160958425, 43.993544237954275, 44.94116040638515, 42.072805064065115, 39.290767192840576, 37.36443819318499, 41.39929185594831, 47.14181818280901, 54.466101918901714, 53.85121413639614, 56.915477412087576, 53.689526081085205, 46.9587470463344, 41.89555304391043, 44.535771233694895, 45.86466632570539, 50.63778345925467, 50.35289689472744, 53.76153373718262, 51.32148967470442, 53.553000926971436, 53.04488263811384, 53.02738012586321, 53.485273361206055, 42.00122124808175, 47.72921541758946, 55.204865659986226, 53.574352741241455, 35.71485594340733, 29.603185721806117, 22.855836970465525, 40.65964569364275, 56.370026452200754, 50.19827168328421, 48.51064804622105, 46.73952095849173, 52.097259521484375, 56.12960835865566, 54.573361260550364, 49.78767483575003, 35.64049284798758, 37.58888585226876, 57.89635113307408, 49.97582163129534, 50.0142833845956, 51.71293728692191, 52.0167681149074, 51.02688258034842, 49.782884052821565, 47.767037936619346, 52.6922789301191, 53.93450566700527, 47.621730259486604, 41.0000900541033, 35.58458764212472, 35.695720604487825, 36.5802367074149, 36.550487995147705, 37.13609259469168, 39.55242245537894, 41.34176424571446, 40.5307149205889, 39.74026700428554, 39.628077915736604, 39.52322959899902, 40.41860921042306, 40.00348561150687, 40.56231532778059, 41.3712489264352, 47.74127401624407, 51.212858063834055, 51.631671156202046, 51.04046630859375, 54.01683834620884, 53.32924113954817, 52.07322570255825, 51.53749179840088, 54.25154849461147, 50.3642954145159, 52.678931440625874, 51.21311167308262, 53.06463984080723, 54.47060782568795, 57.44167491367885, 57.256939683641704, 59.98586899893624, 59.209296635219026, 60.79073442731585, 59.17021301814488, 60.089188711983816, 59.452796254839214, 29.16014426095145, 0.5027081934469086, 0.598434285393783, 0.8945500616516385, 0.10804829467087984, 0.10806586194251265, 2.659686825105122, 55.49442488806588, 63.795100757053916, 53.84446743556431, 55.689627579280305, 49.24155337469918, 26.034564869744436, 13.542953610420227, 22.365229879106792, 47.60269914354597, 50.32367624555315, 37.60433864593506, 1.2041418147938592, 0.18952378737074987, 0.04657706605004413, 0.2036661942090307, 0.10990934659327779, 0.08589612799031393, 0.032457607266094, 0.1297927296587399, 0.04478785741542067, 0.016151564295536706, 0.08554854842701129, 0.018732341704890132, 0.05104843879650746, 0.07291736121156386, 0.05623469228989311, 0.05825473514518567, 0.13205808667199953, 0.202657158353499, 4.439649198736463, 78.98401573726109, 68.04368795667375, 54.19659171785627, 39.729747431618826, 24.95931897844587, 25.798923662730626, 58.77707004547119, 46.33483702795846, 68.52617086683, 61.27883843013218, 1.545901664665767, 0.07405779537345682, 0.5501642812575612, 1.0117560752800532, 1.2379455608980996, 1.1240202912262507, 17.08730353627886, 56.66771159853254, 60.83284051077706, 65.8535601752145, 72.06688949040004, 67.67449542454311, 67.08153615679059, 65.8150463104248, 66.01398713248116, 68.0628719329834, 67.89000770023891, 66.99881785256522, 64.9672132219587, 65.65650926317487, 68.22751644679478, 62.781386375427246, 65.09715843200684, 64.77779838017055, 61.613984789167134, 64.03570992606026, 63.37682615007673, 63.58110318865095, 61.3604519707816, 63.706650188991, 60.38124234335763, 53.491241863795686, 46.83653518131801, 47.272628443581716, 46.254762513296946, 44.96751839773995, 42.060937540871755, 45.04517841339111, 45.92360094615391, 45.38648087637765, 47.04234777178083, 44.434532506125315, 41.21416752679007, 39.470638683864046, 43.79059083121163, 49.699311120169504, 55.539501326424734, 56.89889901024954, 58.28398765836443, 57.79956272670201, 49.99348742621285, 42.45963559831892, 44.688735825674875, 46.992921761104036, 52.11931310381208, 51.67064707619803, 54.61865656716483, 54.1427709715707, 54.59489720208304, 53.58778360911778, 56.58537197113037, 56.53543526785714, 45.645485401153564, 50.49084642955235, 55.76440756661551, 55.20141587938581, 38.40699454716274, 28.356251580374582, 25.115451948983328, 42.980041776384624, 56.74077885491507, 52.99605417251587, 49.821825231824604, 47.966659682137625, 51.63161209651402, 56.23596790858677, 57.09448037828718, 52.19145277568272, 39.641654695783345, 38.55623490469796, 56.40775864464896, 53.86943578720093, 53.0662796156747, 53.19372694832938, 54.08336387361799, 51.970020634787424, 51.225239753723145, 51.82706839697701, 53.23093802588326, 56.3523849759783, 50.77725812367031, 42.29984440122332, 38.291369574410574, 37.6305958884103, 38.396151883261545, 37.737671102796284, 39.54703412737165, 42.58211496898106, 44.052739415849956, 42.13234417779105, 42.719734464372905, 42.89811904089791, 42.57626805986677, 42.463533537728445, 42.316589559827534, 43.31676885059902, 43.43757370540074, 47.52623769215175, 53.09564617701939, 52.90503971917288, 53.26537329810006, 54.8266613142831, 55.279871463775635, 54.593702111925396, 54.695851053510395, 56.048870291028706, 52.864747115543906, 54.76075765064785, 53.15921524592808, 55.23821006502424, 57.413670199257986, 60.03427015032087, 61.25142778669085, 62.268366132463726, 63.285221099853516, 62.595396995544434, 61.22806099482945, 61.44621358598982, 62.27817004067557, 35.800176348005024, 0.08685003966093063, 0.5091857058661324, 1.3789698907307215, 0.8938577930842126, 0.045315096088285954, 2.3152822085789273, 59.34315368107387, 68.71677385057721, 59.322851044791086, 56.8360629762922, 43.115590708596365, 33.58122049059187, 22.996703011648997, 28.421012265341624, 56.419171060834614, 55.91863325663975, 47.184362002781455, 1.7271875483649117, 0.23704691444124493, 0.07243002379047019, 0.13133529759943485, 0.0958948436060122, 0.08325986337981053, 0.11450176659439291, 0.0866316192384277, 0.03586525084184749, 0.14302344327526434, 0.19198746659926005, 0.11546535417437553, 0.12184665032795497, 0.1600780002772808, 0.26368549359696253, 0.19908959764455045, 0.3352043873497418, 0.392936426614012, 6.3919709750584195, 92.09963689531598, 77.13755280630929, 64.04561805725098, 43.44703367778233, 19.809143951960973, 29.96346024104527, 75.66224179949079, 52.891396931239534, 78.49329226357597, 67.69149766649518, 2.9617658385208676, 0.2762483251946313, 2.314902011837278, 3.0625855028629303, 4.561399877071381, 4.86488937480109, 18.125611066818237, 60.91802542550223, 64.38560731070382, 70.85235132489885, 75.48764746529716, 70.63758250645229, 69.8714324406215, 69.19114126477922, 68.45120675223214, 69.08728654044015, 71.98938233511788, 69.92357172284807, 67.26273127964565, 68.28985568455288, 71.8651624407087, 63.69443525586809, 66.99109840393066, 65.07009519849504, 62.76054872785296, 65.17445019313267, 63.634659903390066, 65.21045575823102, 63.42487989153181, 65.97577898842948, 64.86836814880371, 55.697875091007774, 51.89887455531529, 49.215917995997835, 46.77243457521711, 46.951117924281526, 44.56947694505964, 48.71434491021292, 49.31877217973982, 47.340199674878804, 50.21359246117728, 45.95375960213797, 44.22785833903721, 42.1471403666905, 47.80288021905081, 52.98799078805106, 60.48877266475132, 59.850128991263254, 61.6086277280535, 58.977421351841514, 55.16212729045323, 44.1642302104405, 47.99323306764875, 46.362817423684255, 53.566490854535786, 55.2179456438337, 57.526689597538535, 57.56540496008736, 58.577913829258506, 55.95024756022862, 58.092345918927876, 57.37217903137207, 46.94131401606968, 52.55772706440517, 57.88711697714669, 57.138997486659456, 40.16487489427839, 30.481851441519602, 24.42357986313956, 44.539561476026265, 59.795349393572124, 53.40196098600115, 52.94758701324463, 50.23370054789952, 55.55456849506923, 59.709073611668174, 61.20101860591343, 53.050965785980225, 42.19926575251988, 37.65214572634016, 54.58415528706142, 54.12995154517037, 53.780679498400005, 54.77825321469988, 55.393422399248394, 54.551186084747314, 53.0245487349374, 52.49812889099121, 55.14833164215088, 59.65489155905587, 52.447077001844136, 45.95582321711949, 41.927612032209126, 40.47375706263951, 41.198162351335796, 41.106046608516145, 41.550731318337576, 43.70949493135725, 45.56789834158761, 46.299335207257954, 46.00010756083897, 45.838075569697786, 45.655132974897114, 44.8119968686785, 44.89726863588606, 45.59144926071167, 47.238978317805696, 52.75431244713919, 58.59328324454171, 55.89568335669381, 57.10688291277204, 58.89844117845808, 58.173122201647075, 58.73303236280169, 56.85267264502389, 59.48852389199393, 54.86372300556728, 58.967568806239534, 56.26556723458426, 58.57668399810791, 58.87881946563721, 62.31020123617989, 62.515930448259624, 65.93035861424038, 63.36878708430699, 63.146284920828684, 61.553778648376465, 63.834170477730886, 64.58869620731899, 34.68609871183123, 0.6289064245564597, 6.167868120329721, 4.7867851087025235, 0.9086192952735084, 0.14641360778893742, 3.338939679520471, 69.5361054284232, 73.10573550633022, 65.62659726824079, 69.53357628413609, 66.88681983947754, 37.888627665383474, 25.615922008241924, 35.53861141204834, 65.0232434953962, 62.934837341308594, 60.20397990090506, 2.331862347466605, 0.2867461847407477, 0.18879615355815205, 0.2408195420035294, 0.24810193266187394, 0.237998437668596, 0.2091502770781517, 0.16565570740827493, 0.15346020752830164], [0.05413190548175147, 0.10216423576431614, 0.018158312953476394, 0.06194417431418385, 0.061413057813686986, 0.07684764638543129, 0.08896247523703746, 0.1345747323440654, 0.5242103167942592, 10.373894129480634, 73.29177352360317, 55.86768906457083, 48.036110401153564, 24.399928195135935, 14.274719646998815, 27.360870020730154, 49.60496847970145, 45.971289907182964, 68.98674610682896, 33.64826018469674, 0.12151528096624784, 0.11076385966901268, 0.22563158055501326, 0.20143314903335913, 1.0305830878870827, 1.6180829171623503, 32.96272659301758, 59.22016361781529, 60.9536349432809, 61.28616183144705, 65.83054774148124, 68.35910143171037, 64.9216399874006, 66.25469357626778, 65.41402408054897, 63.45516014099121, 63.50678525652204, 63.42078045436314, 60.44271305629185, 63.48947034563337, 62.01115076882498, 63.907119614737375, 60.11411190032959, 62.42163644518171, 62.97613048553467, 59.693495750427246, 58.21174723761422, 59.16574532645089, 59.65414115360805, 58.87364305768694, 60.49093355451311, 55.03863000869751, 44.76318229947771, 43.10658584322248, 41.71170023509434, 45.88064023426601, 39.954674516405376, 43.20482642310006, 43.40464619227818, 44.14864540100098, 44.63916737692696, 42.3811800139291, 40.32386704853603, 37.27797828401838, 36.582293374197825, 39.29340750830514, 44.286421230861116, 49.696847983769004, 52.3720885685512, 56.665425641196116, 55.508210114070344, 54.20869547980172, 46.17104019437517, 55.50156416211809, 50.83737046377999, 53.296987601688926, 52.49249390193394, 52.04954971585955, 51.399101052965435, 54.55662305014474, 53.4780124936785, 47.14211000714983, 42.03589275905064, 49.69202593394688, 51.44614383152553, 57.38137149810791, 34.71000051498413, 26.145475489752634, 24.137889044625418, 33.07096215656826, 56.54702486310686, 52.100869110652376, 48.685030460357666, 43.59003455298287, 45.377184186662944, 49.98025458199637, 53.48563814163208, 45.47646352222988, 46.17462199074881, 47.260938099452424, 40.912469795772004, 49.21038375582014, 52.57034151894705, 51.02331815447126, 50.8274484361921, 48.29727234159197, 48.90142863137381, 50.096480573926655, 53.07827568054199, 52.51038898740496, 47.751859596797395, 39.86452511378697, 36.218909536089214, 37.255007539476665, 37.57092475891113, 37.13594320842198, 37.028357301439556, 41.09154919215611, 41.89485822405134, 40.21678488595145, 38.96261419568743, 39.05467087881905, 39.33250502177647, 42.75976651055472, 40.69684982299805, 40.33025591714041, 41.082002367292134, 42.42001696995327, 48.450334208352224, 49.48999663761684, 50.51975788388933, 51.07750368118286, 54.96283211026873, 53.36465958186558, 52.41598033905029, 49.76619447980608, 52.234899861471995, 52.68048436301095, 53.29816879544939, 54.661592960357666, 55.25295066833496, 58.72649410792759, 59.31859179905483, 59.46362154824393, 60.137826102120535, 62.75651182447161, 60.25323568071638, 63.11984007699149, 61.477897371564595, 65.73878983088902, 19.275840180260793, 1.7615841712270464, 0.10362468739705426, 1.3997065722942352, 0.12439264942492757, 0.03885715940435018, 29.21453128542219, 65.02722481318882, 56.22331176485334, 52.47980996540615, 53.47171395165579, 18.118536063602992, 13.7748202085495, 30.689560890197754, 37.61682455880301, 44.38712842123849, 56.072202341897146, 8.985324433871678, 0.2411386434520994, 0.13877106431339467, 0.013719431008212268, 0.04619681163291846, 0.15594283145453247, 0.010152326614063765, 0.07981768237160784, 0.08592685205595833, 0.04403338075748511, 0.05227720464712807, 0.023317932251042554, 0.04629357751192791, 0.0511861271224916, 0.05314133934942739, 0.10863133267100368, 0.20889151096343994, 0.5833095226969037, 15.251759699412755, 84.90564577920097, 63.16348171234131, 55.726022243499756, 29.714516707829066, 17.27316263743809, 24.659118584224156, 56.579962798527305, 51.43174716404506, 77.95195811135429, 36.22719178880964, 0.22609564422496728, 0.23080246523022652, 0.391901470720768, 0.9877688309976033, 1.14296227480684, 2.4184505811759403, 35.98754494530814, 63.930521147591726, 63.68379061562674, 63.965310777936665, 67.92795181274414, 69.20519052233014, 68.37932763780866, 70.80137934003557, 69.26107488359723, 67.06222711290631, 65.68498992919922, 66.27115385872978, 64.64036996023995, 63.61101518358503, 64.77478981018066, 66.17638042994908, 63.35202802930559, 61.808520453316824, 64.84839902605329, 61.81997108459473, 62.28772381373814, 61.32326521192278, 64.59555407932827, 61.60224233354841, 61.71962520054409, 58.737909998212544, 47.38542202540806, 46.19841957092285, 44.375219208853586, 46.54400907244001, 42.09045696258545, 45.12499237060547, 46.473547390529085, 45.03923075539725, 47.29411227362496, 45.516867297036306, 42.470794405256, 41.63949108123779, 40.314024925231934, 43.21975115367344, 45.278474603380474, 52.478726046425955, 55.88458013534546, 58.866667066301616, 57.53265462602888, 58.39113930293492, 49.95619644437517, 57.55895355769566, 54.33643463679722, 55.94799634388515, 54.602905000959126, 54.42788682665144, 52.06948757171631, 57.3497120312282, 55.29585926873343, 49.76064286913191, 43.64093358176095, 51.789683614458355, 53.61134842463902, 59.42508683885847, 37.42224720546177, 24.202071292059763, 23.550179140908376, 35.53932360240391, 59.03370870862688, 54.59440040588379, 51.275721890585764, 44.752850328172954, 47.58396680014474, 51.05450514384678, 54.9340318271092, 48.05786173684256, 46.20431164332798, 46.093428816114155, 43.6888553074428, 49.37151248114449, 54.74119847161429, 52.372307436806814, 53.037607874189106, 48.77859142848423, 49.57675531932286, 51.901806695120676, 55.226259163447786, 54.172213963099885, 49.80216530391148, 41.252750873565674, 39.08262695584978, 39.33781344549996, 41.287884439740864, 38.535796778542654, 40.20220409120832, 43.05497462408883, 43.03083658218384, 41.931916441236226, 41.779156821114675, 41.509667464665, 41.609752791268484, 44.61089515686035, 42.06423793520246, 42.771752153124126, 43.28297976085118, 43.771128926958355, 50.07018511635916, 52.28586489813668, 53.41251529966082, 51.94844300406319, 54.740767683301655, 54.984413215092246, 55.11455644880022, 52.30258226394653, 55.13002661296299, 55.417727197919575, 55.350426946367534, 58.068864481789724, 57.97854137420654, 60.40817356109619, 61.73929555075509, 60.450786863054546, 61.730992453438894, 63.696443285260884, 63.50367941175188, 64.11250836508614, 64.78439222063336, 69.99453367505754, 28.506395203726633, 1.4287365802696772, 0.7536774522491864, 1.4909911368574416, 0.38807355612516403, 0.02221250710343676, 28.833408696310862, 70.79870428357805, 62.219297954014365, 58.5502530506679, 49.739252839769634, 23.799428394862584, 20.6463497706822, 36.983235699789866, 45.268906933920725, 50.793162550245015, 65.9765988758632, 10.867133719580513, 0.3062898117516722, 0.1797670102013009, 0.008902270030895514, 0.014323199101324593, 0.0721932082836117, 0.015920852211170962, 0.02572846013520445, 0.024749865056946874, 0.12245393916964531, 0.24492302324090684, 0.08514051139354706, 0.16160834101693972, 0.15053441881069116, 0.2256961092352867, 0.2602873630821705, 0.4460209352629525, 0.8922589474490711, 19.858917372567312, 95.3133316040039, 69.41104480198452, 65.49877820696149, 34.97522020339966, 22.406809636524745, 40.62428978511265, 70.21459702083042, 60.32619176592146, 84.17827360970634, 42.1638160433088, 0.2234961222857237, 0.37317409419587677, 0.6167452856898308, 2.622446651969637, 6.123727951731, 3.4764909957136427, 39.67242479324341, 68.24273994990757, 65.08291462489537, 65.77559443882534, 69.5865979875837, 72.05593218122209, 69.49139377049038, 72.83604117802211, 70.36899294172014, 69.16020093645368, 69.48411900656563, 68.90363870348249, 64.05037757328579, 66.61841092790876, 67.79497023991176, 67.9029244014195, 66.99847739083427, 66.85159247262138, 66.78213827950614, 64.52785778045654, 63.15234375, 62.33577060699463, 65.02876036507743, 63.58319459642683, 65.54449040549142, 60.77684497833252, 49.44119596481323, 47.910921233040945, 45.057699067252024, 50.10066338947841, 43.16904320035662, 48.29587575367519, 47.91997820990426, 46.0035469191415, 50.70771360397339, 47.989196164267405, 44.830955028533936, 42.73861619404384, 42.2123943737575, 43.95361988885062, 48.87681811196463, 54.02210855484009, 57.57931177956717, 60.77651841299874, 59.54381765638079, 60.264790534973145, 53.06573070798601, 61.214491162981304, 58.164530754089355, 58.10602692195347, 58.30937985011509, 56.0833020891462, 55.6865599496024, 59.26940550122942, 57.53804642813546, 51.02860573359898, 47.53421075003487, 53.56044939586094, 56.25798674992153, 61.87709222521101, 39.17434317725045, 31.780459335872106, 29.6315586907523, 36.07581486020769, 63.416146005902974, 55.9610207421439, 54.36628409794399, 47.18700926644461, 51.428592681884766, 55.84000744138445, 58.82613822392055, 48.43655593054635, 47.39800173895699, 47.614785534994944, 48.6542603628976, 50.674824305943076, 56.952625955854145, 53.730353696005686, 54.046149321964805, 51.27706289291382, 52.60448496682303, 52.602629797799246, 58.27401351928711, 56.62925679343087, 52.635470458439414, 44.695902892521445, 41.80705036435808, 41.82868010657174, 44.34539059230259, 41.444482939583914, 43.24859660012381, 45.56909343174526, 46.26904106140137, 44.56394270488194, 44.37979459762573, 44.198241642543245, 44.76206016540527, 45.823696272713796, 43.81333575929914, 44.54073224748884, 46.05892406191145, 46.818640095846995, 53.45484719957624, 54.295912742614746, 55.57548952102661, 57.29128115517752, 59.798962456839426, 58.03733703068325, 58.9880381992885, 55.68270717348371, 58.3002290725708, 58.57705225263323, 59.178648131234304, 60.649276052202495, 59.877046312604634, 62.803398268563406, 65.24921975816999, 61.717325346810476, 63.459468024117605, 66.25738252912248, 63.922905921936035, 66.1732120513916, 67.66637298039028, 70.34056786128453, 28.297082458223613, 3.639744132757187, 3.695535344736917, 2.8223693413393836, 0.3215600794979504, 0.1479769931840045, 35.276695592062815, 75.09729072025844, 68.82272693089077, 65.07068579537528, 66.38427053179059, 26.231094666889735, 24.418111630848475, 39.83874382291521, 52.25166239057268, 56.91255569458008, 77.22645500728062, 13.681210603032794, 0.4897242901580674, 0.23497398995927402, 0.12657304028315203, 0.10140967768217836, 0.24426622848425592, 0.16802988786782536, 0.22315863253814833, 0.26859287598303383], [0.05626059875690511, 0.04025040553616626, 0.06247610505670309, 0.050809967664203474, 0.05415333701031549, 0.06656779335545641, 0.0558002941709544, 0.1647626060460295, 0.3272751628288201, 24.80505507332938, 70.39056015014648, 49.79251078196934, 39.30795356205532, 22.958067553383962, 29.323128155299596, 44.39611939021519, 45.995018005371094, 48.4483504976545, 73.46663883754185, 18.07830946786063, 0.132048315767731, 0.3457523227802345, 0.12750751871083463, 0.3521797050322805, 0.5209802729742867, 8.712421774864197, 49.41389996664864, 64.2908547265189, 66.94715799604143, 64.55819361550468, 62.138511248997276, 62.04496765136719, 64.50228146144322, 65.99400411333356, 62.08730302538191, 69.20156356266567, 68.24090562547956, 60.82767799922398, 60.59627519335066, 58.42544255937849, 59.77373354775565, 56.82960115160261, 57.263092313494, 55.95883553368704, 55.75724744796753, 59.46015439714704, 61.537485122680664, 58.03922346660069, 58.590031487601145, 58.773832184927805, 57.20247622898647, 55.996199471609934, 46.5466320174081, 43.15516069957188, 42.17147295815604, 42.66955804824829, 39.59189517157418, 41.28218691689627, 44.34296219689505, 42.79310049329485, 43.97423866816929, 40.97369384765625, 38.37106541224888, 40.11266960416521, 38.01853813443865, 40.22228785923549, 40.18259627478463, 43.69470569065639, 51.12653711863926, 54.85828256607056, 52.95451784133911, 52.14474351065499, 54.70804166793823, 53.91544328417097, 54.12774201801845, 52.937414850507466, 48.26550170353481, 46.03527586800711, 45.62634311403547, 47.60583278111049, 44.71802248273577, 39.53353725160871, 46.00013187953404, 54.10216917310442, 48.237111364092144, 56.70999486105782, 25.168897492544993, 17.79970928600856, 25.691858870642527, 28.91651609965733, 56.572861739567344, 49.13456153869629, 51.57235785893032, 40.31555005482265, 42.666862147195, 48.04433706828526, 53.48672553471157, 50.00311068126133, 48.892805916922434, 41.11251885550362, 46.13094908850533, 50.49567542757307, 50.806485721043174, 48.55455718721662, 50.44816017150879, 53.846048150743755, 53.09389175687517, 50.85651275089809, 52.37003884996687, 49.2232483455113, 43.93392174584525, 37.35901859828404, 34.65848657063076, 35.680028097970144, 36.31685829162598, 35.16955436979021, 37.904535566057476, 39.24661486489432, 43.671519551958355, 39.72503655297415, 40.0459634235927, 39.1857590675354, 39.91198478426252, 41.40550701958792, 40.14921365465437, 42.152622495378765, 40.46072571618216, 39.99682923725673, 44.13751786095755, 46.513475213732036, 49.1915854045323, 49.998114926474436, 48.986773354666575, 52.08454779216221, 52.32826280593872, 51.919528075626914, 52.89917196546282, 53.786606311798096, 59.01316288539341, 56.36124045508248, 60.59391280582973, 59.433827672685894, 63.14322771344866, 61.991251128060476, 64.72963346753801, 58.04639400754656, 60.02373668125698, 58.088270800454275, 63.12498869214739, 57.963606221335276, 58.0264561516898, 6.463752814701625, 1.075796970299312, 2.006393526281629, 0.26617178161229404, 0.2824854462274483, 7.296355451856341, 66.33356952667236, 57.90468202318464, 55.20435496738979, 54.825764996664866, 60.09674835205078, 19.49947316305978, 13.437413947922842, 35.23895297731672, 43.536331926073345, 58.66471767425537, 26.370161124638148, 0.3952452370098659, 0.14446602229561123, 0.04698677906500442, 0.004984824435918459, 0.006380853409479771, 0.07060449317629848, 0.06334318460098334, 0.09267594133104597, 0.07372856339705841, 0.11891110427677631, 0.027021384864513363, 0.05538610961022122, 0.024773439059832265, 0.08828569762408733, 0.06143939854311092, 0.1278828028589487, 0.25858684575983454, 31.784961768559047, 81.38390268598283, 55.8378951890128, 47.41173832757132, 31.16411590576172, 32.91649327959333, 42.866567271096365, 53.473252977643696, 56.064726080213276, 80.89706325531006, 17.99762872287205, 0.27486289239355494, 0.21048087067902088, 1.0922373852559497, 1.462918026106698, 0.44395943731069565, 10.569666572979518, 54.11807359967913, 69.28424712589809, 69.96302359444755, 69.59699249267578, 64.35197108132499, 64.7006733758109, 63.56399672372, 66.50890731811523, 64.40715367453438, 69.3524923324585, 68.70409338814872, 65.37551716395787, 62.474797112601145, 60.154744965689524, 61.17558125087193, 60.039203371320454, 59.883820806230815, 59.85993984767369, 59.20763601575579, 60.329019682747976, 63.37180955069405, 59.9922821862357, 60.84771660396031, 59.34894847869873, 59.61350114004952, 58.382363728114534, 49.09099980763027, 46.28772824151175, 45.676366669791086, 45.123026030404226, 42.353769370487754, 42.87475572313581, 45.880463055201936, 45.64406796864101, 44.5065610068185, 44.258680547986714, 41.27320984431675, 41.80306209836687, 40.911896569388254, 42.604467323848176, 42.45186751229422, 45.03486728668213, 51.840304715292795, 56.30883019311087, 54.37354843957083, 53.68338734763009, 55.9748580796378, 56.73201370239258, 55.598123277936665, 54.93019642148699, 50.311023575919016, 50.06543254852295, 47.48743895121983, 50.91063921792166, 46.357724394117085, 43.824039459228516, 48.02161645889282, 56.271521840776714, 52.69476638521467, 58.252884047372, 26.18805057661874, 18.895547900881084, 24.388251747403825, 31.27217081614903, 57.59234312602452, 51.54473876953125, 53.46075316837856, 42.86196061543056, 44.01562908717564, 48.35896192278181, 55.23222419193813, 51.33966963631766, 49.92179938725063, 45.281201771327424, 49.12587629045759, 51.35890572411673, 54.29554101399013, 51.302434240068706, 52.342843600681846, 54.53429848807198, 55.990307399204795, 52.22531482151577, 54.961327825273784, 51.4807562828064, 46.490278652736116, 37.90891293116978, 39.197108949933735, 37.82039635522025, 38.595586027417866, 38.37416778291975, 39.92944213322231, 40.94903816495623, 45.12305382319859, 41.72649989809309, 40.63444805145264, 41.437777927943635, 42.95664719172886, 43.01637738091605, 43.269163267953054, 43.46791301454817, 41.98278767721993, 41.89647020612444, 45.46624272210257, 49.504834515707834, 51.76581655229841, 52.82121665137154, 51.60694599151611, 54.26840482439314, 54.74696895054409, 53.31944070543562, 54.964673382895334, 56.66568619864327, 62.8192332131522, 60.354297229221885, 63.139079638889854, 60.61427797589983, 64.04618780953544, 60.89051055908203, 66.64493220193046, 59.58827223096575, 65.82410676138741, 61.062096323285786, 66.11345754350934, 60.031622886657715, 66.19162477765764, 16.523346049445017, 1.0159074068069458, 0.2568842385496412, 1.7151005055223192, 0.30306728609970635, 7.01352642263685, 72.17912374223981, 63.168039730616975, 63.04636982509068, 55.64868879318237, 44.414601598467144, 23.73501511982509, 25.42160173824855, 40.68699380329677, 51.15321472712925, 66.98843724387032, 31.131323882511683, 0.3688644197370325, 0.17370691895484924, 0.06500334944576025, 0.09220499053065266, 0.018628578433500867, 0.015089531462373478, 0.039105883200785944, 0.11215654600943838, 0.3266673583005156, 0.22049526045364992, 0.09976966532745532, 0.24753416169966969, 0.14446908927389554, 0.1729600690305233, 0.1465955637395382, 0.2811955782983984, 0.4696403592824936, 40.02397237505232, 92.92676435198102, 61.36892877306257, 55.21223422459194, 32.77884251730782, 42.61403499330793, 59.020618302481516, 63.162105969020296, 61.92786271231515, 85.93142223358154, 22.530016830989293, 0.30477068041052136, 0.8747814052871296, 2.2792199722358157, 3.7593471663338796, 3.089470688785825, 10.768136654581342, 57.61308349881853, 72.78566673823765, 74.37997954232353, 70.97174222128731, 65.73753915514264, 65.955386025565, 65.75998183659145, 67.68184661865234, 66.70589569636753, 72.61285809108189, 68.67610604422433, 67.28768920898438, 65.27984046936035, 63.60521343776158, 64.73430960518974, 61.03322655814034, 60.755472319466726, 62.72958755493164, 61.51958656311035, 62.36994184766497, 67.13208430153983, 62.417849676949636, 61.277393204825266, 62.68236064910889, 60.63881206512451, 60.9493340083531, 52.559582233428955, 47.05698415211269, 47.34863131386893, 47.415010929107666, 44.31441899708339, 46.1952338218689, 49.025447028023855, 46.537192889622276, 46.019440923418315, 44.881041118076865, 42.559217180524556, 45.06230224881853, 43.652568340301514, 45.544976234436035, 44.81121519633702, 48.32024656023298, 55.70242616108486, 59.01139804295131, 57.11822584697178, 55.071981361934114, 58.62739889962332, 57.712790148598806, 58.420738628932405, 57.570612634931294, 53.76582077571324, 51.44422265461513, 49.46240186691284, 53.58637312480381, 49.633094787597656, 44.271249839237754, 50.53970268794468, 59.306085041591096, 53.15096773420061, 59.788790294102256, 31.371366773332866, 28.463227782930645, 30.81220006942749, 33.74524661472866, 62.978520665849956, 53.309876510075156, 59.33767850058419, 45.07959631511143, 47.30068874359131, 52.850544997623985, 57.826024941035676, 53.86486039842878, 52.478270939418245, 48.483237402779714, 51.1253593989781, 52.969706603458945, 56.957725933619905, 52.695343085697715, 55.2945008959089, 57.41380221503121, 56.746563230242046, 55.27207211085728, 57.79847880772182, 52.199311188289094, 48.570062092372346, 41.45516926901681, 40.85609558650425, 40.11020646776472, 41.190752097538535, 40.857186453683035, 41.708531856536865, 42.76721150534493, 48.32449885777065, 44.1585431098938, 44.431263378688264, 44.20262942995344, 45.37519700186593, 47.258572237832205, 45.57332835878645, 45.905587741306846, 42.89440522875105, 43.48544331959316, 47.653236865997314, 50.10103511810303, 54.18124314716884, 55.02647760936192, 55.71764619009835, 57.78652443204607, 59.6063722882952, 57.41994442258562, 56.179399149758474, 59.83380767277309, 65.73609392983573, 61.9856995173863, 65.3401438849313, 63.82079519544329, 66.68088912963867, 64.61677387782505, 69.12458447047642, 62.49356419699532, 67.21555995941162, 63.221096175057546, 69.03807939801897, 62.74542249952044, 66.81136935097831, 16.445765938077653, 2.527033120393753, 5.562167593411036, 1.0425723131213869, 0.4671772228819983, 9.93915055479322, 79.29801177978516, 68.39138276236397, 67.6469875063215, 69.16751044137138, 74.71870422363281, 28.898747818810598, 24.278218337467738, 48.379994119916645, 57.73634454182216, 74.21401487077985, 40.22895812988281, 0.4262651167809963, 0.25009991973638535, 0.19557066075503826, 0.19946731094803127, 0.10971283606652703, 0.17376764783901827, 0.16141552850604057, 0.2764278384191649], [0.041962325639490566, 0.05127165646159223, 0.02113806047210736, 0.03956507159663098, 0.03094854877729501, 0.0332416273387415, 0.06907840006585632, 0.02586599070179675, 0.05736737418919802, 42.152247292654856, 64.52657931191581, 54.98048400878906, 37.75822040012905, 15.50807353428432, 21.01963652883257, 39.78352301461356, 48.37288958685738, 62.39977046421596, 63.84612832750593, 3.8777805141040256, 0.18951377219387464, 0.3370641975530556, 0.48111389790262493, 0.38119815077100483, 0.8164117059537342, 28.344173874173844, 64.9530805860247, 68.51993833269391, 63.16351645333426, 63.913122858319966, 64.84296553475517, 64.25413349696568, 61.60928780691964, 61.108871596200125, 54.64371177128383, 63.55602713993618, 52.92242758614676, 60.04756900242397, 61.71302441188267, 57.94540888922555, 54.00425515856062, 55.117766516549246, 49.37039382117135, 48.65757465362549, 45.95164040156773, 48.136303424835205, 51.39943109239851, 57.67814295632498, 57.741190910339355, 60.140355246407644, 59.43124989100865, 53.017847197396414, 43.78215224402291, 44.95751646586827, 41.59061745234898, 42.99953842163086, 40.263310023716514, 41.80225263323103, 43.296775409153526, 45.40641873223441, 41.76810571125576, 43.36823068346296, 40.357569285801475, 37.125145707811626, 37.707734789167134, 39.72448764528547, 37.464516571589876, 41.8131091935294, 42.32621281487601, 47.56641565050398, 51.81966856547764, 52.938526562282014, 54.75515740258353, 55.24734347207205, 51.327010018484934, 48.05095175334385, 44.6756523677281, 43.3129369190761, 41.508694716862266, 42.43020302908761, 40.180595193590435, 48.92886706760952, 50.7841020992824, 54.775505202157156, 50.79928043910435, 57.163941519601, 14.356048311506, 11.224278943879263, 24.638268777302333, 25.72203142302377, 52.59200947625296, 50.75624329703194, 50.17835119792393, 42.87513787405831, 41.14837156023298, 46.59507833208357, 49.466331073216026, 52.83169106074742, 53.05339765548706, 53.56497614724295, 52.08095209939139, 49.55710233960833, 48.90876592908587, 49.63376876286098, 50.5986407824925, 50.667097909109934, 52.16325698580061, 49.61411925724575, 49.79304231916155, 43.355782985687256, 38.61825105122158, 34.1041384424482, 36.16626303536551, 34.484913621629985, 36.0244711467198, 35.86422484261649, 38.183297293526785, 40.323391096932546, 41.7567697252546, 41.854447501046316, 40.98490824018206, 37.7563339642116, 39.58622891562325, 42.37550333568028, 41.23603698185512, 41.90058701378958, 41.09620795931135, 41.2059234891619, 42.41541378838675, 43.9451813016619, 46.099626609257285, 48.49059901918684, 47.5706262588501, 46.97700343813215, 51.402283327920095, 52.17946365901402, 57.265687465667725, 59.23649883270264, 58.048325606754844, 60.450863293239046, 59.1960186277117, 59.50623485020229, 58.9024989264352, 58.789979798453196, 60.01922035217285, 61.3420809337071, 58.082757404872346, 62.24039963313511, 60.094094140189036, 67.24427686418805, 57.888374601091655, 47.59758179528372, 3.8722879631178717, 1.1830435012068068, 2.268802885498319, 0.04227046874750938, 0.1305198749261243, 42.01761204855782, 65.19177900041852, 54.99188600267683, 53.73400150026594, 61.459227561950684, 26.0036575453622, 10.47494786126273, 15.134097167423793, 41.187229360852925, 54.695927483694895, 42.18651580810547, 1.492431368146624, 0.10855995078704186, 0.05544326261484197, 0.02649921315189983, 0.07711707228528601, 0.044947157081748755, 0.03865234700164624, 0.09899329912981816, 0.047926770589713535, 0.03611490762393389, 0.0197067230806819, 0.05355630761810711, 0.030765103442328315, 0.09127496329269238, 0.0586593591475061, 0.027037237138886536, 0.018108174304610918, 49.44312061582293, 71.76911749158586, 61.72343976157052, 45.225112438201904, 19.323972088950022, 24.760873215539114, 42.27279159000942, 55.328713825770784, 69.45837593078613, 70.9324015208653, 3.97320533650262, 0.4012049457856587, 0.35864448813455446, 1.874829385961805, 0.4807649680546352, 0.9464806807892663, 33.064125129154746, 70.13442870548793, 71.46154853275844, 64.93090193612235, 68.66184139251709, 69.21377154758999, 66.45053550175258, 61.76894351414272, 62.92623547145298, 53.671012605939595, 68.16982555389404, 58.87737424033028, 62.588143076215474, 64.15513556344169, 59.62493092673165, 57.62790400641305, 56.555491243089946, 51.07800047738211, 50.32892908368792, 47.326299803597585, 50.53434910093035, 53.26939630508423, 60.711024693080354, 60.014856883457725, 60.968420709882466, 62.199078696114675, 54.89413527079991, 44.180370875767295, 47.835262298583984, 43.544350147247314, 45.51483494894845, 43.35248259135655, 43.77054875237601, 47.49643686839512, 47.02779129573277, 43.84192412240164, 44.14622047969273, 42.01584373201643, 40.8634398324149, 40.1436516216823, 41.1207663672311, 39.44055993216378, 43.3907185282026, 44.76606927599226, 48.52493701662336, 53.99486814226423, 55.51337609972273, 57.058141299656455, 57.02853502546038, 54.578808648245676, 50.50228663853237, 45.48379039764404, 45.749218532017295, 44.56491197858538, 44.1186500276838, 41.69865151814052, 51.74117476599557, 53.43989815030779, 56.791556290217805, 52.19037233080183, 58.90846048082624, 17.853222574506486, 12.230365071977888, 25.873655012675695, 27.020297118595668, 54.78496864863804, 53.45017801012312, 52.395142691476, 44.77266311645508, 43.16425241742815, 48.33874961308071, 51.13208872931344, 54.93035275595528, 55.208329336983816, 53.724572794778005, 54.78826904296875, 51.37486573628017, 52.10987050192696, 50.301462854657856, 51.840971742357524, 52.23289878027779, 54.42736223765782, 53.12554080145699, 53.31232575007847, 43.9635523387364, 39.18251773289272, 37.073287827628, 37.928889002118794, 37.354332038334434, 37.43743944168091, 38.08827372959682, 39.10298865182059, 41.68958759307861, 44.114050320216585, 44.90757976259504, 42.675564765930176, 41.41040202549526, 41.57629026685442, 43.90580933434622, 43.1168726512364, 43.743749550410676, 43.3174706186567, 42.51492588860648, 44.14300693784441, 46.04607336861746, 48.53655440466744, 51.257034710475374, 49.45090954644339, 50.86909941264561, 54.79329259055001, 55.192497866494314, 58.25562163761684, 62.142978940691265, 58.63629259381975, 60.71089267730713, 60.19068799700056, 62.61030782972063, 61.19662734440395, 60.7720159803118, 61.571656363351, 64.99825082506452, 60.842123304094585, 65.65997641427177, 62.651941435677664, 70.61751610892159, 61.04004968915667, 57.62432221003941, 9.769480756350926, 0.8901265561580658, 1.6398443494524275, 0.0696189007056611, 0.12954061318721088, 42.60861539840698, 70.7743786403111, 60.33937249864851, 60.518941743033274, 53.1609696660723, 27.294917719704763, 13.74041359765189, 21.069769518715994, 47.388322898319785, 60.93999562944685, 50.31243406023298, 1.3231919237545557, 0.020190092768254023, 0.07754831521638803, 0.03443872596004179, 0.05470268574676343, 0.05788800732365676, 0.011850249388122132, 0.016318419449297444, 0.1155413229550634, 0.24960510485938617, 0.11337773940925087, 0.10283232812902757, 0.08644382788666657, 0.12910164174224648, 0.174752161438976, 0.14406214468181133, 0.16466097507093633, 59.785017422267366, 81.87910079956055, 70.36743654523576, 53.88596555164882, 22.201912471226283, 28.309047256197246, 51.44341318947928, 66.12108666556222, 75.87530136108398, 77.81615556989397, 5.085948918546949, 0.36461660053048817, 0.965934225491115, 2.9365768815789903, 4.9735318422317505, 2.8696824482509067, 36.01212419782366, 73.61953394753593, 73.6201592854091, 69.00376224517822, 69.66337558201381, 71.18950571332658, 67.72967106955392, 63.30491924285889, 62.72186810629708, 56.96163429532732, 61.67653942108154, 58.602336747305735, 64.4438818522862, 65.17775058746338, 61.63154288700649, 58.98895536150251, 60.17260183606829, 54.18501949310303, 54.31495080675398, 51.154906613486155, 51.86231313432966, 55.26484945842198, 62.741809436253135, 61.7159982408796, 63.32498564038958, 62.76225103650774, 57.85339042118618, 47.90412242071969, 48.91441134044102, 46.42397199358259, 48.18558699744088, 45.252338954380576, 46.926344122205464, 50.47439309528896, 49.854103088378906, 46.7224040712629, 46.43758004052298, 44.51904344558716, 43.40790837151663, 43.20160245895386, 44.63510962894985, 42.2432860646929, 46.212527888161794, 47.255546297345845, 51.49067483629499, 57.01909589767456, 55.67151362555367, 61.638991355895996, 63.11307947976248, 55.86426707676479, 52.20409849711827, 49.92815351486206, 48.14982461929321, 47.741854190826416, 48.01309796742031, 45.749836921691895, 53.22508764266968, 55.573964391435894, 59.87856101989746, 55.29977805273873, 61.36680957249233, 22.123258863176616, 19.56081359727042, 35.81627185004098, 29.94705901827131, 57.07745729173933, 55.84662560054234, 54.36383833203997, 46.958177294049946, 44.06006629126412, 50.91926540647234, 54.390641008104595, 57.71949863433838, 56.0933769771031, 55.87911537715367, 56.31000791277204, 54.58044842311314, 53.86470058986119, 53.75160823549543, 56.30661719185965, 53.69743660518101, 58.764577184404644, 56.08142607552664, 54.92985595975603, 46.722897393362864, 44.57143633706229, 39.4480014528547, 41.59042985098702, 40.557406425476074, 39.916393416268484, 41.42859935760498, 43.274197237832205, 44.17446838106428, 45.46196263177054, 46.40657370431082, 45.11360427311489, 42.31346981866019, 44.477427210126606, 47.300317014966694, 45.83320835658482, 46.37184313365391, 45.141435282570974, 45.836838790348594, 47.74953195026943, 47.62317895889282, 50.36417382104056, 54.13603469303676, 52.43871137074062, 52.032106263296946, 58.41679900033133, 58.30842794690813, 62.00532123020717, 65.95164789472307, 61.89421258653913, 62.94723292759487, 62.88762433188302, 64.36508233206612, 64.90204606737409, 63.436400004795615, 66.16911956242153, 66.99534375326974, 63.9921864100865, 67.59975365230015, 64.78761618477958, 72.53748403276715, 62.81864261627197, 57.000651904514854, 10.371413622583662, 3.43387639096805, 4.7494276847158154, 0.2415713859455926, 0.34009084371583803, 50.60490458352225, 74.936690058027, 67.25368472508022, 68.61629595075334, 75.01088292258126, 38.19239943368094, 18.46615617615836, 27.68197580746242, 57.372859954833984, 68.66358539036342, 61.40838064466204, 2.2731641829013824, 0.22978441842964717, 0.22884348034858704, 0.18583307255591663, 0.20848875971777098, 0.12221130861767701, 0.11764212165560041, 0.11965648856546197], [0.07665695768914052, 0.04423149601955499, 0.06846861421529736, 0.10516860562243632, 0.050934499196176014, 0.039830612883503945, 0.14596376621297427, 0.10104719748986618, 0.906544606600489, 55.97043555123465, 62.867634364536826, 42.78596121924264, 35.183610575539724, 24.41859974179949, 46.34500224249703, 49.62727219717843, 46.07621118000576, 67.56101049695695, 44.81747899736677, 0.4858548492193222, 0.15353035447852953, 0.334490107106311, 0.3889351598918438, 1.1097192700420107, 6.19141035420554, 57.82473952429635, 67.33492306300572, 68.25580951145717, 63.16002150944301, 65.11021409715924, 62.26952648162842, 64.56190395355225, 64.0378360748291, 55.17476258959089, 59.118914467947825, 50.21554837908064, 54.82979495184762, 66.5137710571289, 60.927926608494346, 61.33261053902762, 58.37442193712507, 59.09736115591866, 56.27257101876395, 53.659409114292686, 43.85719626290457, 44.452549185071675, 43.68402630942208, 49.04840735026768, 52.065256118774414, 54.77876043319702, 54.208323751177105, 48.573817593710764, 43.29605974469866, 45.251025744846885, 43.98054068429129, 43.63776520320347, 41.00551312310355, 42.974538803100586, 42.183013916015625, 44.66339921951294, 43.01681164332798, 42.54458427429199, 40.43543774741036, 37.790915148598806, 36.47183438709804, 39.73152617045811, 38.40308271135603, 39.495113713400706, 38.40367330823626, 42.176694529397146, 42.10549633843558, 47.92144080570766, 49.46003947939192, 48.49327060154506, 42.18577235085623, 43.22423274176461, 39.862353801727295, 44.47711454119001, 40.94425433022635, 42.38567897251674, 40.69614110674177, 53.11614683696202, 51.98976394108364, 55.003868171146934, 49.256815092904226, 53.374835218702046, 19.6323070866721, 10.795172095298767, 20.839653866631643, 19.419495923178538, 48.528713362557546, 51.21509885787964, 51.55485534667969, 45.21485342298235, 40.01801429476057, 43.94552523749215, 50.37243522916521, 50.05612543651036, 51.8987911769322, 50.29091896329607, 49.43147890908377, 51.39826726913452, 48.885895933423726, 44.747798987797324, 46.80546283721924, 48.71477222442627, 48.98150314603533, 46.29848405293056, 39.72047506059919, 36.19383348737444, 35.04433740888323, 34.16598088400704, 35.41324159077236, 34.83573164258684, 34.86718961170742, 36.976648807525635, 38.86234821592058, 40.81781448636736, 43.448273931230815, 42.25899594170706, 39.61291694641113, 40.25661890847342, 39.125803061894004, 43.23342520850045, 40.00554575238909, 41.94841841288975, 41.89337478365217, 41.33207498277937, 40.70780365807669, 42.08069126946585, 42.046033654894146, 44.634873390197754, 46.63168491636004, 47.68204409735543, 50.12682335717337, 52.37419387272426, 52.984714712415425, 58.88667787824358, 58.46421350751604, 61.42873191833496, 58.51777022225516, 60.21285275050572, 57.877208845955984, 59.28694970267159, 56.452887194497244, 56.519047941480366, 55.3473801612854, 60.41474655696324, 60.68485082898821, 64.46432345254081, 63.77599321092878, 62.30977739606585, 23.622596740722656, 0.5619602597185543, 3.2423755696841647, 0.0984330666916711, 0.228279210627079, 12.99236272062574, 68.60297625405448, 57.03510454722813, 51.568762166159495, 55.07028947557722, 40.335943017687114, 18.708401645932877, 15.768386057444982, 36.674433435712544, 55.20705434254238, 52.520085198538645, 5.956291564873286, 0.17161891742476396, 0.021387176122516394, 0.04108926820169602, 0.09337082225829363, 0.05608613383291023, 0.06152194911347968, 0.04858718533068895, 0.07667039946785995, 0.04235430174906339, 0.10240576030420405, 0.0393850833975843, 0.07772421863462244, 0.017171700983973484, 0.10898847957806927, 0.1596872726721423, 1.7550027072429657, 64.95681871686662, 69.23695073808942, 49.382577487400596, 40.53668342317854, 28.93523802076067, 33.06371865953718, 45.716607161930625, 54.82180104936872, 73.52048737662179, 49.01458351952689, 0.2934399055583136, 0.06265453262520687, 0.8963329259838376, 2.192025508199419, 0.8762780364070619, 8.361808725765773, 62.279650006975444, 69.99927929469517, 71.21384525299072, 66.67718573978969, 66.48371315002441, 65.00881208692277, 65.138229233878, 66.17554664611816, 55.07494476863316, 60.61262430463518, 55.72008153370449, 56.503688948495046, 68.07712963649205, 62.68532752990723, 64.8098087310791, 59.97776045118059, 60.354616846357075, 58.309956550598145, 54.40691021510533, 46.556307383946006, 46.64003665106637, 45.01192086083548, 52.22192757470267, 54.837983403887065, 58.07745245524815, 55.96360547201974, 49.02661779948643, 44.313355922698975, 47.558626719883506, 46.39404262815203, 45.7512196132115, 43.93168095179966, 45.57531901768276, 44.425715242113384, 45.840604713984895, 44.25685664585659, 43.838547297886436, 43.12021126065935, 40.010069029671804, 38.59558950151716, 41.81550284794399, 39.232145241328645, 41.2179925101144, 39.62899507795061, 42.89579486846924, 43.707896845681326, 48.95550993510655, 51.211322511945454, 51.980422088078086, 43.74493769236973, 44.83145877293178, 41.620824745723176, 47.299559661320274, 42.408420426504954, 43.15435470853533, 43.765789236341206, 54.27920927320208, 53.35085351126534, 56.34307091576712, 50.838704517909456, 54.77964285441807, 22.051506553377422, 10.986396942819868, 21.729450600487844, 21.248364278248378, 49.87638248716082, 53.084605489458355, 54.58191796711513, 48.67552185058594, 42.794201782771516, 47.2214549609593, 51.741431849343435, 51.67690045492989, 51.349622930799214, 53.23450592585972, 53.358892577035085, 52.19628177370344, 50.982424531664165, 46.02259887967791, 49.594264779772075, 50.69838217326573, 50.90427466801235, 47.751508712768555, 41.80276679992676, 38.823761395045686, 37.471110412052695, 36.95854875019619, 36.63269213267735, 36.249961035592214, 37.43403829847063, 37.89883804321289, 41.7536951473781, 41.69937065669468, 45.620145320892334, 42.986277784620015, 42.476224422454834, 42.2890225819179, 41.19419492994036, 44.736685344151084, 42.30489921569824, 43.86758381979806, 43.290584564208984, 43.872461455208914, 44.341621194567, 42.97447279521397, 45.07945735113961, 46.65539564405169, 49.09383814675467, 49.94376264299665, 51.79768099103655, 53.81163024902344, 55.49922956739153, 60.854574475969585, 60.92608533586775, 63.27903720310756, 60.62085097176688, 63.416180746895925, 60.097721099853516, 60.55388423374721, 58.49366692134312, 58.14654534203665, 56.96851648603167, 62.10326303754534, 65.56447342463902, 65.7687018258231, 68.21584347316197, 65.97471591404506, 32.11866637638637, 1.3149694906813758, 1.7171344820942198, 0.22288689283388002, 0.31953440819467815, 13.516403675079346, 74.9349182673863, 60.585116386413574, 58.74873529161726, 53.95995691844395, 37.47826010840279, 19.40090080669948, 18.33587745257786, 42.3880934715271, 62.07184328351702, 62.636585916791645, 7.190317256110055, 0.33389666037900106, 0.2251469844153949, 0.07489959948829242, 0.1316370421222278, 0.05746319690453155, 0.015939746018765227, 0.026036443787493875, 0.2528354472347668, 0.09959845737154994, 0.32648051689778057, 0.20527627638408116, 0.19341800840837614, 0.1029846320993134, 0.3730526907103402, 0.2863028028181621, 2.262933611869812, 76.85521970476422, 77.09000628335136, 58.16068492616926, 49.20955344608852, 36.51001821245466, 64.35493796212333, 65.57749434879848, 60.699553217206685, 81.59177889142717, 55.45850617544991, 0.615784534386226, 0.17702304172728742, 1.1261856321777617, 5.911302413259234, 4.523540445736476, 7.764168109212603, 64.16102763584682, 72.87351281302315, 74.93810749053955, 68.85040855407715, 70.2990037373134, 67.51730632781982, 69.04134505135673, 70.08463791438511, 60.17767402103969, 63.57366166796003, 52.191157477242605, 60.84193570273263, 71.81649030957902, 65.58758313315255, 66.77623925890241, 62.240212031773154, 63.67532770974295, 61.40512888772147, 57.53430482319423, 49.250759737832205, 49.14175987243652, 46.19289575304304, 55.39405468532017, 56.48336199351719, 58.24970872061593, 59.21931593758719, 52.28599691390991, 45.96732248578753, 51.22743885857718, 48.274895668029785, 48.936402388981406, 44.76059756960188, 48.60450083868844, 45.73395333971296, 47.79120029721941, 45.7356903893607, 45.20097092219761, 45.40609564099993, 42.75182819366455, 40.59699726104736, 44.10094254357474, 43.177339349474224, 43.40007775170462, 41.304844992501394, 46.621290411267964, 45.29212086541312, 51.87816892351423, 55.14388132095337, 55.31774956839425, 44.9173697744097, 48.17361525126866, 42.885751247406006, 49.15159157344273, 45.193685735974995, 45.64718770980835, 46.56936999729702, 57.587017331804546, 56.65578154155186, 58.17630795070103, 54.390477725437705, 58.210176944732666, 24.627292360578263, 16.009233202253068, 30.209284033094132, 26.12467779432024, 53.14905003138951, 55.73370695114136, 57.079041481018066, 50.30306094033377, 44.84407670157296, 50.98783370426723, 55.17343895775931, 52.921770981379915, 54.42550706863403, 55.92076287950788, 55.402305671146934, 54.75005395071847, 54.43162843159267, 47.78305006027222, 52.1355163029262, 53.821361201150076, 55.553112847464426, 49.79195492608206, 43.23441532679966, 40.3164324760437, 39.470451082502095, 39.3325640814645, 40.014227526528494, 37.56100967952183, 40.14942557471139, 41.00587790352957, 44.93616117749895, 44.36231292997088, 47.18341704777309, 45.94759654998779, 45.773554597582134, 45.269730295453755, 43.794273376464844, 47.677187306540354, 45.26658623559134, 46.10723141261509, 46.3645475251334, 45.55826813834054, 46.174660205841064, 45.30431147984096, 48.530162061963765, 49.952826568058555, 53.10672855377197, 53.38821397508894, 56.28976781027657, 57.245165961129324, 58.07573972429548, 64.36852169036865, 63.607714789254324, 65.89323438916887, 63.334039143153596, 66.91927487509591, 61.46814210074288, 65.41590009416852, 61.70240061623709, 61.49873501913888, 59.48595305851528, 65.26192801339286, 67.97144058772496, 69.07951845441545, 68.8718090057373, 69.3483373097011, 30.65284660884312, 3.6967508452279225, 8.22534349986485, 0.3459894029157502, 0.6414226815104485, 17.476261956351145, 81.17163521902901, 65.56913566589355, 65.13697160993303, 69.44238812582833, 54.194687911442344, 30.92290571757725, 29.87193856920515, 53.1213128226144, 68.22743306841168, 74.43685749598912, 10.242935350963048, 0.4534625916608742, 0.3443088616643633, 0.32002124349985805, 0.20357027649879456, 0.1710411584270852, 0.23028306024415152, 0.10017423504697424], [0.14934574759432248, 0.04040755085381014, 0.05264767458928483, 0.04963154232661639, 0.04328993707895279, 0.03055868630430528, 0.11434867552348546, 0.140453111912523, 2.1468476695673804, 58.43524646759033, 56.953362464904785, 50.76968806130545, 28.826781851904734, 19.086574724742345, 54.276798248291016, 51.342094557625906, 52.08775438581194, 74.95342826843262, 26.10098443712507, 0.07077593861946038, 0.06631641648709774, 0.4806566195828574, 0.4182805238025529, 0.21392567083239555, 36.827689852033345, 80.0596455165318, 71.19261850629533, 69.21542521885463, 62.23734242575509, 62.27710001809256, 63.37835475376674, 66.63883863176618, 61.57559599195208, 59.947320393153596, 55.829644203186035, 45.58560929979597, 57.84353787558419, 60.39384637560163, 63.253370557512554, 60.718827520098, 61.224635532924104, 60.15334837777274, 60.74447332109724, 61.592820576259065, 53.944851534707205, 45.131256171635215, 44.435407979147776, 44.22745186941964, 44.14641850335257, 44.335718699863975, 42.20895848955427, 41.12827736990792, 43.532260281699045, 42.743823868887766, 43.741776262010845, 42.377455779484336, 41.09534985678536, 42.545880113329204, 42.91790403638567, 43.50560699190412, 41.15762308665684, 43.8708564213344, 40.16076503481184, 39.43515770775931, 37.85991423470633, 38.546062741960796, 37.841980934143066, 38.843817370278494, 38.56967619487217, 39.913110392434255, 41.578472001211985, 41.469899450029644, 41.476795537131174, 41.451934882572715, 41.04583004542759, 41.97907386507307, 41.406451974596294, 42.82746628352574, 42.31495673315865, 40.605348995753694, 40.71127775737217, 51.59331015178135, 51.39906978607178, 52.70309380122593, 48.94546283994402, 54.219017028808594, 35.623751163482666, 16.083974974496023, 24.224020651408605, 16.94837256840297, 45.34943308149065, 51.36814335414341, 52.27736030306135, 47.222309589385986, 40.64481128965105, 42.833587646484375, 48.2625105040414, 51.206726278577534, 51.41352203914097, 52.06676735196795, 51.46784652982439, 50.45456641060965, 47.064738341740195, 43.985550335475374, 42.59667491912842, 41.246629510607036, 42.012272357940674, 39.46790109361921, 36.778222152165, 33.409627778189524, 34.81087098802839, 35.7182605607169, 36.55615772519793, 34.98575367246355, 36.38221304757254, 36.78123419625418, 39.7166292326791, 40.04123517445156, 41.04852942058018, 40.812071800231934, 40.68189035143171, 38.84254584993635, 39.225534030369346, 41.09371355601719, 40.515567847660606, 40.0266752243042, 41.90231016704014, 40.66567325592041, 43.83147750582014, 42.14065769740513, 43.53408765792847, 42.6205906186785, 43.579011235918315, 44.7402150290353, 47.9980342728751, 48.42301041739327, 51.70529426847185, 54.91985402788435, 56.32780572346279, 55.42584964207241, 56.577315534864155, 53.75005531311035, 53.13220412390572, 49.04776464189802, 48.617122241428916, 48.75832005909511, 53.867330483027864, 55.30963754653931, 61.02122007097517, 62.55033792768206, 66.65254742758614, 60.91837283543178, 50.384948934827534, 7.109071101461138, 1.6194912301642554, 0.7542620780212539, 0.05564474680327943, 1.7666014220033373, 46.48264258248465, 63.99466691698347, 51.91046067646572, 53.02122054781233, 56.69614362716675, 20.879821402685984, 18.368632997785294, 36.80893666403634, 43.64422355379377, 59.384523255484446, 17.744253976004465, 0.11432203623865332, 0.14177432815943444, 0.08725584431418351, 0.04474713174360139, 0.05293808079191616, 0.046754815083529265, 0.05772606137075594, 0.03562308847904205, 0.056768516145114384, 0.023722885342847024, 0.038307440866317065, 0.029415751740868603, 0.0787150493956038, 0.17910705347146305, 0.14201938786676951, 3.2244759244578223, 71.9478737967355, 63.440506390162874, 56.945472785404746, 35.0143837247576, 21.213234186172485, 41.52372367041451, 54.04841096060616, 59.42555931636265, 81.0383687700544, 29.412068571363175, 0.011668799794279039, 0.0688216695562005, 1.263393446803093, 1.1377811985356467, 0.5513079656021935, 41.223519802093506, 83.7691011428833, 75.33231353759766, 72.46545900617326, 64.33826923370361, 65.73826871599469, 65.11913558415004, 68.67457744053432, 65.9136551448277, 64.37821442740304, 60.536562374659944, 50.34051867893764, 60.35631915501186, 62.559356689453125, 64.84071431841168, 62.30082811628069, 62.76617676871163, 64.44613306862968, 63.81489617483956, 63.93044471740723, 56.36385645185198, 47.41592461722237, 46.72445726394653, 45.50116784232003, 46.8567544392177, 46.14089890888759, 44.908045291900635, 44.17922789709908, 45.72917297908238, 44.10633087158203, 44.471378803253174, 44.53648689814976, 42.48263413565499, 43.9912930216108, 45.925654138837544, 45.60502256665911, 42.84301287787301, 44.776922362191335, 41.38623966489519, 41.96699094772339, 39.83034692491804, 39.7807993207659, 39.50144352231707, 39.118215629032676, 40.05676439830235, 42.67211845942906, 43.483945982796804, 42.96008655003139, 45.17402580806187, 43.29839781352452, 43.97755295889718, 43.59834112439837, 43.94797100339617, 45.42624889101301, 43.19025952475411, 42.0669755254473, 43.84723949432373, 54.06620529719761, 54.42202254704067, 54.61960847037179, 49.60497890199934, 56.51792928150722, 37.68373571123396, 18.83112246649606, 26.229960373469762, 20.252913236618042, 47.68233939579555, 53.34779282978603, 55.03750787462507, 49.29882737568447, 43.16692747388567, 43.76800571169172, 49.7345905985151, 53.761360032217844, 55.41041421890259, 51.884422302246094, 52.24344267163958, 52.01952654974801, 50.896218231746126, 45.87214606148856, 44.827369758060996, 43.12337269101824, 44.30725540433611, 40.7615236554827, 39.42161914280483, 36.457858085632324, 37.858673981257844, 37.92682191303798, 38.73384823117937, 38.417795521872385, 36.48714126859392, 38.517926011766704, 42.30865471703665, 41.85226924078805, 42.32460083280291, 43.10281991958618, 42.08807373046875, 41.41808325903756, 41.269850390298025, 43.29645579201834, 42.89204284123012, 43.403176648276194, 45.08818776266915, 43.9492564201355, 45.24906982694353, 44.58286959784371, 45.30561774117606, 45.014290196555, 45.95892211369106, 44.990204266139436, 51.18049682889666, 50.628775119781494, 53.90906483786446, 56.135305881500244, 59.50986180986677, 57.31403303146362, 59.24528135572161, 54.69173077174595, 55.728721618652344, 52.50039747783116, 50.762298652103965, 52.072263377053396, 56.83887004852295, 57.998298576899934, 64.99414443969727, 65.05711596352714, 69.45076765332902, 62.85569041115897, 58.437323978969026, 9.942625522613525, 0.9022935032844543, 1.6155827598912376, 0.1374473917697157, 1.6127861099583762, 49.972156456538606, 71.5838576725551, 55.691069330487935, 61.538721902029856, 46.955755846840994, 18.109301907675608, 27.10747790336609, 42.35795218603951, 49.27826765605381, 67.48710945674351, 20.924830096108572, 0.23009494319558144, 0.08652692807040044, 0.030365297038640295, 0.05714648389922721, 0.07970974102084126, 0.03220367571339011, 0.01512903577115919, 0.19588151121778147, 0.0873430021373289, 0.14014783900763306, 0.18881679459341935, 0.1268615262316806, 0.22760520822235517, 0.2505784769143377, 0.3877936468592712, 4.911508747509547, 86.07803617204938, 70.7483159473964, 65.62622901371547, 39.0744662966047, 28.794828823634557, 73.35091659000942, 68.7688158580235, 65.3343699319022, 89.9413457598005, 34.50397947856358, 0.16906070469745568, 0.15491455234587193, 2.8937783667019437, 6.387554092066629, 1.4099489769765308, 41.25181286675589, 85.9741050175258, 78.16075147901262, 74.35183933803013, 66.74648012433732, 67.84674821581159, 68.65738759722028, 71.5664176940918, 67.85264028821672, 66.64933041163853, 59.23403222220284, 49.703136103493826, 62.43230193001883, 63.81768240247454, 68.28829233986991, 64.46704714638847, 67.56830610547746, 66.09600366864885, 66.27595506395612, 68.12292521340507, 58.744385719299316, 48.95554467609951, 49.415345191955566, 46.95803485597883, 49.08504172733852, 47.28676802771432, 46.81628465652466, 44.53642783846174, 47.310513496398926, 46.454564911978586, 47.47871201378958, 47.52985770361764, 45.16925239562988, 46.851689202444895, 47.03048719678606, 47.71223749433245, 45.347258295331685, 48.19067655290876, 43.784994057246614, 43.47293308803013, 41.18923739024571, 43.27053206307547, 43.96120037351336, 43.1432341166905, 43.78988558905465, 43.492898736681255, 46.02265793936593, 44.84520925794329, 47.0454431942531, 46.80488613673619, 44.91538953781128, 46.09643043790545, 46.531568322862896, 47.65365028381348, 46.052583830697195, 44.7252972466605, 44.91286734172276, 56.562981401171, 56.23053094318935, 58.72449997493199, 51.46604347229004, 59.29391874585833, 40.331131390162874, 22.6177065713065, 31.10508053643363, 23.696567262922013, 49.955289704459055, 55.156464508601594, 58.42305237906319, 51.562751974378315, 45.94649526051113, 47.29764543260847, 53.44693667548043, 56.73424754823957, 58.97004236493792, 54.149628843579976, 55.23619508743286, 54.71103981563023, 54.180027212415425, 49.28620597294399, 47.00393465587071, 46.05576957975115, 47.41906520298549, 44.90832321984427, 41.11760146277291, 38.62690155846732, 40.73904970714024, 41.622040680476594, 41.42815467289516, 40.95037916728428, 40.14678873334612, 39.93002578190395, 45.25602149963379, 43.58016463688442, 44.343146324157715, 45.57723672049386, 45.70512178965977, 44.713877882276265, 44.64601135253906, 46.03435523169381, 45.19948748179844, 45.51204177311489, 46.77699954169137, 47.3358188356672, 48.62148571014404, 46.63431133542742, 47.60738570349557, 48.205399785723, 47.737112045288086, 48.82630123410906, 54.20908457892281, 52.14003610610962, 56.944899559020996, 59.307655334472656, 62.72461264474051, 60.67208003997803, 62.313883781433105, 59.112765312194824, 56.67704997743879, 55.24970585959298, 53.62447009767805, 54.29736144202096, 59.50513703482491, 61.42397935049874, 67.04819175175258, 70.08145563943046, 72.84404550279889, 67.15556921277727, 56.89624827248709, 9.263261062758309, 4.34064952816282, 1.4136989414691925, 0.1464489730341094, 2.5840139942509786, 59.08810615539551, 76.13350336892265, 64.76212324414934, 69.3927640914917, 70.49595042637416, 31.57062373842512, 30.206039224352153, 52.07505655288696, 56.67538240977696, 78.52439934866769, 27.697525875908987, 0.330700543309961, 0.21506271910454544, 0.16381359339824744, 0.13480799911277636, 0.18612917166735443, 0.1342846043407917, 0.13560914540929453], [0.06156208445983274, 0.062448067989732535, 0.03797632934791701, 0.039146351029298136, 0.06609586546463625, 0.11095643469265529, 0.16323079967073031, 0.19893744295196875, 6.000426956585475, 60.40227454049246, 52.775084086826865, 37.657930101667134, 13.399545397077288, 27.48824266024998, 51.738763741084504, 52.29740238189697, 52.91182810919625, 71.83240863255092, 11.628119536808558, 0.06799454893916845, 0.10875093125339065, 0.4621788625206266, 2.0241652812276567, 9.252840501921517, 79.5400870186942, 64.11195945739746, 70.4762522833688, 61.27731677464077, 62.82536847250802, 59.11171613420759, 64.08613995143345, 62.72321605682373, 62.58713558741978, 59.775859696524485, 59.45647880009243, 45.484255926949636, 61.80055781773159, 60.63043948582241, 64.57152026040214, 61.67282213483538, 63.141518456595286, 59.37812396458217, 61.6939377103533, 59.22173391069685, 57.01175512586321, 46.071639265332905, 45.04779788425991, 44.64622327259609, 43.66686078480312, 42.98045172010149, 44.495766980307444, 43.67413207462856, 43.24720001220703, 41.571423053741455, 42.69377599443708, 40.77726132529122, 41.14985500063215, 42.223761626652305, 43.05749682017735, 41.84813853672573, 41.895539147513254, 42.774573121752056, 41.52997704914638, 40.05141428538731, 37.77535465785435, 37.404199259621755, 37.24229233605521, 38.21712807246617, 37.60168790817261, 36.570269516536165, 37.27817283357893, 38.97987699508667, 42.40239633832659, 41.28286436625889, 40.957087653023855, 41.76256104878017, 42.73043816430228, 42.63006101335798, 40.55967501231602, 41.15100145339966, 40.49565431049892, 46.79682970046997, 50.71674278804234, 53.35118007659912, 52.68932594571795, 54.706679821014404, 45.3537722315107, 27.73014072009495, 38.16752140862601, 27.442792756216868, 43.79908847808838, 51.12596389225551, 49.695006711142405, 46.950628076280864, 40.96132605416434, 38.84264659881592, 41.83054569789341, 42.26504782267979, 44.68528951917376, 42.32535818644932, 43.410569531576975, 41.982627868652344, 41.33296087809971, 39.73734528677804, 40.3380309513637, 40.0099960735866, 39.79365348815918, 37.467903818402974, 34.98619835717337, 34.11869144439697, 34.88962881905692, 34.591443402426584, 35.10561357225691, 36.01474019459316, 36.236749035971506, 38.05412680762154, 39.87088966369629, 39.16490404946463, 41.12662717274257, 41.587733949933735, 40.29055391039167, 38.68625654493059, 38.6593531199864, 39.32343067441668, 42.211525848933626, 40.17087813786098, 42.797331946236746, 40.165316104888916, 40.469115665980745, 41.26617479324341, 43.154368604932515, 40.810091563633506, 41.406076771872385, 40.678471837724956, 42.110304491860525, 42.67701346533639, 43.77749000276838, 45.17501245226179, 45.821062905447825, 45.383281230926514, 47.228611605507986, 45.01492943082537, 46.11831031526838, 43.16339431490217, 47.97619955880301, 46.718714577811106, 49.95885760443551, 49.35334641592843, 56.502966335841585, 58.564434323992046, 65.23870713370187, 61.4785852432251, 62.00922611781529, 24.802826438631328, 0.29906705075076645, 1.211624264717102, 0.029164038997675692, 0.14727840067020484, 35.792443002973286, 64.52917098999023, 54.141892024448936, 44.359825474875315, 57.15069130488804, 33.47491305215018, 8.680033615657262, 23.911047731127056, 47.19711889539446, 61.64489732469831, 34.3808400290353, 0.38172431396586554, 0.09053962132228272, 0.09080419569675412, 0.04070340229996613, 0.10247114393860102, 0.12510850386960165, 0.04550757272435086, 0.0534851259019758, 0.08293289771037442, 0.04582676916782345, 0.08344806185258286, 0.008408911459680115, 0.1312777442591531, 0.21711577608117036, 0.25579196001802174, 7.91341541494642, 72.70556095668248, 60.014919417245046, 47.714540822165354, 22.59283028330122, 32.31702354976109, 43.35368810381208, 58.22312491280692, 60.226853370666504, 79.44279139382499, 11.818331684385027, 0.08652762017611947, 0.10874632400061403, 0.1925568524748087, 0.6880883574485779, 11.352637359074183, 84.54235921587262, 66.87147821698869, 74.55229486737932, 64.9212508882795, 65.39809880937848, 61.83599363054548, 66.26214204515729, 64.35369423457554, 66.69459792545864, 62.17078563145229, 62.87486743927002, 52.62552758625576, 60.940815516880576, 60.704055649893625, 66.4185459954398, 63.276765142168315, 63.09878008706229, 61.63069520677839, 62.22712857382638, 60.65737765175955, 59.89618859972273, 48.18163347244263, 46.21934754507882, 46.36315788541521, 45.99829755510603, 44.906468050820486, 46.52693040030343, 47.45382009233747, 45.90018899100167, 43.73857661655971, 45.025515011378694, 42.01836940220424, 42.147161211286274, 45.439568587711875, 44.80898829868862, 43.41376570292881, 44.34393147059849, 45.55236564363752, 43.35732201167515, 42.606301648276194, 39.34379237038748, 40.42167336600167, 38.81134843826294, 39.934093952178955, 39.74172612598964, 39.12917988640921, 41.24810600280762, 41.557394640786306, 43.20877647399902, 43.025020939963206, 43.344446999686106, 42.76438358851841, 43.812762532915386, 44.20218474524361, 42.646562985011506, 42.94961214065552, 42.84917940412249, 49.291312898908345, 53.20061261313302, 55.676696981702534, 54.36689901351929, 57.25830500466483, 47.078186580113, 32.70783192770821, 43.302247115543906, 30.386803558894567, 46.1556464603969, 53.14380761555263, 51.17107159750802, 47.974222796303884, 43.00001784733364, 41.02058376584734, 43.56206805365426, 44.649648734501426, 45.739150592258994, 44.249547140938894, 44.629359994615825, 43.69671719414847, 43.37115934916905, 41.3168306350708, 42.97155455180577, 42.305990082877024, 40.35656874520438, 39.409199237823486, 36.762800625392366, 35.875894342150005, 35.818474428994314, 38.01201377596174, 36.60355486188616, 38.50150394439697, 39.52061012813023, 39.00799982888358, 42.84444073268345, 42.45645332336426, 43.475191252572195, 42.375267096928184, 41.77146169117519, 40.581666060856406, 41.51323536464146, 41.88790307726179, 44.391988686152864, 43.47525378635952, 44.907746519361226, 42.90350389480591, 44.09809725625174, 42.953346797398154, 44.35808147702898, 42.836280073438374, 43.46402897153582, 44.772016933986116, 44.42735849108015, 44.18988643373762, 45.99105405807495, 47.5052159173148, 47.694137437003, 47.161700453077046, 48.56777613503592, 46.73645680291312, 47.35417945044381, 46.85424613952637, 50.26641614096505, 48.84743070602417, 51.49892234802246, 51.14465454646519, 59.11034039088658, 59.95026642935616, 67.19658442905971, 64.33168234143938, 66.52357496534074, 29.580937589917863, 0.5419688267367226, 0.899176476257188, 0.05311029976499932, 0.06651219419602837, 37.80364424841744, 70.24794142586845, 58.89860793522426, 53.67652947562081, 56.78797101974487, 35.07543754577637, 14.925883974347796, 32.0977349281311, 52.53535386494228, 71.88114329746791, 38.89084277834211, 0.46298148802348543, 0.01822549300933523, 0.0362857966683805, 0.055143146576093774, 0.12075743877461978, 0.0602075724995562, 0.054040730731295686, 0.12488108607275145, 0.12638846518737928, 0.17620300501585007, 0.264727343405996, 0.22260071390441485, 0.19690601767173835, 0.4941496955496924, 0.5654377245477268, 12.184805733816964, 84.76771014077323, 66.69930185590471, 57.312542642865864, 21.43549837384905, 41.68202100481306, 66.28536987304688, 67.68035970415387, 66.82883017403739, 86.97897434234619, 16.01367657525199, 0.09965242804693324, 0.3236642437321799, 2.3754193016460965, 5.111833563872746, 10.090087141309466, 86.03391511099679, 69.8824244907924, 75.75896767207554, 66.43268557957241, 68.44566208975655, 64.47447477068219, 68.39485686165946, 67.28387464795793, 67.09048543657575, 65.33985900878906, 60.885549545288086, 51.23615884780884, 63.453388350350515, 62.071711267743794, 68.51246901920864, 65.11438301631382, 65.01908847263881, 62.43414320264544, 64.98748806544712, 63.36699444907052, 62.02035713195801, 51.50179542813982, 49.96968289784023, 50.69721835000174, 46.94127580097744, 46.942199911390034, 48.270528725215364, 48.79832431248256, 46.91200998851231, 45.54788752964565, 48.521233626774375, 44.7216911315918, 45.84998825618199, 48.41578081675938, 46.48159687859671, 44.11535658155169, 46.061606066567556, 47.214152404240195, 45.43737643105643, 44.707454272678916, 41.074696336473735, 42.44064269747053, 42.6485710144043, 42.98581920351301, 44.344740935734336, 41.594661303928916, 42.65730142593384, 44.48957960946219, 46.33546583993094, 44.96924155099051, 45.470561027526855, 45.525347573416575, 46.25207356044224, 46.73346560341971, 45.42618983132498, 45.4020448412214, 43.310498101370676, 51.684484413691926, 54.3030937058585, 57.7254775592259, 57.49302557536534, 60.66333225795201, 50.72365277154105, 36.97246251787458, 45.45045294080462, 35.40872178758894, 51.46618243626186, 55.79857185908726, 53.47308969497681, 50.12318597521101, 45.95815781184605, 41.830597809382844, 45.48510013307844, 47.72243397576468, 50.1933627809797, 48.023280552455354, 47.65957014901297, 46.897470882960725, 45.79466322490147, 44.77559525626046, 45.7280056817191, 44.95643949508667, 42.1225437436785, 42.516235624040874, 40.56203392573765, 38.7945442199707, 37.589997564043315, 41.54536383492606, 39.578933307102744, 41.48347970417568, 43.12565170015608, 42.20038788659232, 45.35252850396292, 43.94045305252075, 47.06637116840908, 45.51169783728463, 45.24506766455514, 43.289267880576, 45.032532691955566, 44.38282053811209, 46.29390866415841, 46.549678802490234, 47.074841022491455, 46.23036738804409, 45.53352560315813, 45.10118089403425, 47.95452117919922, 45.18439599445888, 46.34587771551949, 46.13108457837786, 46.47398165294102, 47.21148082188198, 48.90198796136038, 50.494615827287944, 50.686417375292095, 49.58079917090279, 51.772354807172505, 49.00894505637032, 51.62829780578613, 48.40175935200283, 52.96286610194615, 51.16630860737392, 55.275514943259104, 55.302328041621614, 62.644319261823384, 62.09506416320801, 69.8422291619437, 66.72810908726284, 68.51368495396206, 27.40946224757603, 1.9210802870137351, 4.503854462078639, 0.13289986364543438, 0.49112337508371895, 43.365618160792756, 75.54268414633614, 64.39289597102574, 59.18096882956368, 69.6011961528233, 47.58850744792393, 16.483977556228638, 39.200701168605256, 59.92112568446568, 79.35029697418213, 48.930777822222026, 0.5240393802523613, 0.12707044716392243, 0.15849263034760952, 0.10352200469268219, 0.21289652319891111, 0.23801673097269876, 0.19975439911442144], [0.05049613843272839, 0.04441396765676992, 0.027792838468615497, 0.06967958209237882, 0.09924918147070066, 0.23286960859383854, 0.09580077829637698, 0.2554382804249014, 11.923232981136866, 57.67318194253104, 45.56173528943743, 40.745785985674175, 18.155578647341045, 23.776638303484233, 42.84503827776228, 48.7060626574925, 60.275337900434224, 64.25597476959229, 5.23705747297832, 0.26011745791350094, 0.1460927692907197, 0.5032949905310358, 0.7492123661296708, 59.75839192526681, 77.48906217302594, 67.46578543526786, 68.25887366703579, 61.61034393310547, 58.861726897103445, 58.24646391187395, 59.90090642656599, 63.299763679504395, 61.0530914579119, 62.83217075892857, 58.426074845450266, 49.11662823813302, 66.40940911429269, 58.42316355024065, 61.78688376290457, 60.11843367985317, 59.59884738922119, 60.07440294538225, 62.08950560433524, 57.31033311571394, 55.71867799758911, 47.46022980553763, 45.70627171652657, 42.818555218832834, 42.41441672188895, 42.8553181375776, 44.46175554820469, 43.718273980276926, 43.73907341275896, 42.60515519550869, 41.33355147497994, 41.13218225751604, 41.18903589248657, 42.3405156816755, 43.884158747536794, 42.02169064113072, 41.325957093920024, 41.335604667663574, 43.08464343207223, 39.35795627321516, 38.20908553259713, 37.11125973292759, 36.764721802302766, 36.67380114964077, 36.60215479987008, 35.15702329363142, 37.759811537606375, 37.66221366609846, 38.6219231741769, 37.99491078513009, 42.01727506092617, 44.61882305145264, 42.193665504455566, 38.982548577444895, 37.82055616378784, 38.72769907542637, 40.09406232833862, 40.89099291392735, 43.96992383684431, 47.70659555707659, 50.21764326095581, 51.87974269049508, 48.333180631910054, 31.814060824257986, 46.64095033918108, 35.92515707015991, 40.456185068402974, 52.912064347948345, 48.30706582750593, 44.59536245891026, 39.40840366908482, 38.56718873977661, 39.68986129760742, 37.90055077416556, 37.72499064036778, 38.410823004586355, 37.7630980355399, 37.084714140210835, 37.86330495561872, 37.09550469262259, 39.29029471533639, 37.277405057634624, 35.55090972355434, 35.367633615221294, 36.28933647700718, 35.09079653876168, 35.65181841169085, 35.005059242248535, 35.70148066111973, 37.54944092886788, 36.100102288382395, 38.31109551021031, 40.82034363065447, 40.42032541547503, 40.62347337177822, 38.69279132570539, 39.34150988715035, 38.032101018088206, 37.73829991476876, 40.171625069209504, 42.73171663284302, 40.45420830590384, 39.85829952784947, 40.886667660304475, 40.25943987710135, 40.70744929994856, 41.79573174885341, 42.00626911435808, 42.43271132877895, 41.67484698976789, 42.613461766924175, 43.5395941053118, 43.025149481637136, 42.03937380654471, 42.82745933532715, 43.39680167606899, 43.95262977055141, 43.389301095690044, 45.04264579500471, 47.555711950574604, 47.74774626323155, 50.904451847076416, 52.557362283979145, 51.529862676348, 50.63012307030814, 55.9753201348441, 60.53440843309675, 63.77079595838274, 63.74321160997663, 42.81971556799752, 2.7923307589122226, 1.2660886964627673, 0.30590396959866795, 0.10767497827431985, 22.387453692299978, 62.43827043260847, 59.20735808781215, 51.52782685416085, 52.40074988773891, 28.310138123376028, 14.151904157229833, 28.452989612306865, 42.159192017146516, 52.53529480525425, 47.264891624450684, 0.4400500442300524, 0.02580458837162171, 0.013521075714379549, 0.07237654166030032, 0.048957933472203355, 0.06420526334217616, 0.036380381057305, 0.08310710479106222, 0.07544280069747142, 0.02128481232960309, 0.09239105161811624, 0.041144053119101694, 0.11719169653952122, 0.10922448084290538, 0.2501626977963107, 16.91410752705165, 69.87711606706891, 52.65661382675171, 46.52991812569754, 20.76727100781032, 25.876184156962804, 43.47842911311558, 57.042594705309185, 65.10100078582764, 71.13052245548793, 5.141808092594147, 0.3632662615605763, 0.6669044941663742, 1.0402345699923379, 1.0320293988500322, 63.88762991768973, 78.4642001560756, 71.66688864571708, 70.9363272530692, 64.79184763772147, 60.9313451222011, 60.35394981929234, 61.807596342904226, 65.60880987984794, 63.69869450160435, 65.66966220310756, 60.34092889513288, 52.999076638902935, 65.77535820007324, 60.767860957554404, 63.06032180786133, 60.76234408787319, 61.274287360055105, 62.516284806387766, 63.67466068267822, 61.06443091801235, 58.00667463030134, 49.4754992212568, 48.15422977719988, 44.95824950081961, 44.32198905944824, 45.193307059151785, 46.02564566476004, 45.16865832465035, 46.296326637268066, 43.92845351355416, 45.11750568662371, 44.25602981022426, 41.97423097065517, 45.3939015524728, 46.227800028664724, 42.83071804046631, 43.986933026994976, 43.755043847220286, 44.50004012244088, 41.865807805742534, 41.390168871198384, 38.61104576928275, 38.59945617403303, 38.84038496017456, 38.56996801921299, 37.855484758104595, 39.93187747682844, 40.73801095145089, 41.369768960135325, 42.06090974807739, 44.69707713808332, 44.972736494881765, 43.32089955466134, 39.97488335200718, 39.92023229598999, 40.14126491546631, 40.40596696308681, 43.77894912447248, 46.82804100854056, 48.808746610369, 50.66651426042829, 52.93703964778355, 51.21277468545096, 35.06823921203613, 49.19458702632359, 37.48424250738961, 43.56223481042044, 54.641912187848774, 51.067147391183035, 47.7385607446943, 42.7530198097229, 41.43082625525338, 41.48135355540684, 39.85031952176775, 39.862874916621614, 40.965550558907644, 39.599559034620015, 40.60029765537807, 40.039018699101035, 38.81373167037964, 40.51124954223633, 39.22108023507254, 38.87392738887242, 36.10391337530953, 36.841040815625874, 36.506172384534565, 37.09553248541695, 37.21038620812552, 37.666719572884695, 40.30639232907976, 38.79405089787075, 39.82132816314697, 42.20500496455601, 43.32549231392996, 42.3786404473441, 41.20430455889021, 41.054921763283865, 40.6732884815761, 40.48940787996565, 42.16020992824009, 43.10074588230678, 42.11766610826765, 41.608040060315815, 43.27698693956648, 42.160762310028076, 42.89328309467861, 45.13269444874355, 43.23183059692383, 43.98869439533779, 43.02424274172102, 44.82735586166382, 46.05464397157942, 44.172224112919395, 44.25610276630947, 44.501745905194966, 45.54547997883388, 44.363591398511616, 46.56934220450265, 46.80250637871878, 49.10883583341326, 49.95570312227522, 53.005441188812256, 55.712188380105154, 53.91649941035679, 53.83319398335048, 57.15251520701817, 62.48510823931013, 65.8822909763881, 66.45412077222551, 47.15348073414394, 2.75348533477102, 3.1157073037964955, 0.08877964397626263, 0.027740598057529757, 22.58214395386832, 68.77422850472587, 64.71873869214738, 58.22542476654053, 57.12667485645839, 33.26875652585711, 20.999344314847672, 35.923093455178396, 46.16434907913208, 61.2203345979963, 53.907696042742046, 0.4897714619125639, 0.10089330574763672, 0.012591678665817847, 0.05181631652106132, 0.05694202094205788, 0.06334653656397547, 0.03542556354243841, 0.15945876921926225, 0.18260040959077223, 0.16207890505237238, 0.2018328197300434, 0.14285298170787947, 0.2680736067039626, 0.32237931553806576, 0.5143261243190084, 23.225682633263723, 85.48673057556152, 57.76738561902727, 56.79739277703421, 28.57960663522993, 35.80194813864571, 58.22660596030099, 64.52168778010777, 70.87097249712262, 80.5219647543771, 6.989826117243085, 0.48559396607535227, 1.6196079381874628, 3.58758031470435, 1.1647343465260096, 66.09368991851807, 81.68849086761475, 74.10532420022147, 74.60956192016602, 67.63291045597622, 63.15539400918143, 62.354565484183176, 63.57912295205252, 69.03703716823033, 67.11755561828613, 69.10049506596157, 59.076280321393696, 53.332736083439414, 68.82695143563407, 62.71563557216099, 65.79525784083775, 62.818385532924104, 63.58483437129429, 64.90944589887346, 67.02063519614083, 62.61936133248465, 61.25684043339321, 52.18600191388811, 51.44959708622524, 47.49375138963972, 46.892516817365376, 48.444237164088655, 48.52472162246704, 47.969223567417686, 48.33289922986712, 45.57716029030936, 48.39943865367344, 45.4471560205732, 44.2248706136431, 47.414847646440776, 47.729562827519004, 44.62248822620937, 45.643324511391775, 46.13932861600603, 46.272716658455984, 43.855028424944194, 43.23371008464268, 42.3950069291251, 41.53693567003523, 42.10506207602364, 42.89288704735892, 40.622476305280415, 43.21211855752127, 42.7288852419172, 44.42127881731306, 43.36686536243984, 47.21817193712507, 47.52809633527483, 45.56741544178554, 42.551504680088584, 42.15364735467093, 42.44257082257952, 43.754606110709055, 47.14721693311419, 47.573325634002686, 54.000642095293315, 52.888270241873606, 54.59843036106655, 53.89122186388288, 40.95729957308088, 51.86014182226998, 41.967320987156455, 47.41977391924177, 57.65978928974697, 53.270911012377056, 49.046875272478374, 43.83188050133841, 42.592280183519634, 44.948879855019705, 43.21714557920183, 42.146911076136995, 42.464947496141704, 42.46263722011021, 41.439563614981516, 42.16336441040039, 40.67637695584978, 43.97083405085972, 41.65008708408901, 41.18616281236921, 40.667889731270925, 39.732505866459434, 41.18776089804513, 40.335053648267476, 40.344527517046245, 39.736931868961875, 44.01508017948696, 41.564544337136404, 42.49239982877459, 44.88750989096505, 45.90250621523176, 44.46041801997593, 41.87328406742641, 42.91062927246094, 43.98566845485142, 42.7512514931815, 44.90467888968331, 47.2758663041251, 44.574924332754954, 44.24436725888933, 45.1477928842817, 44.67860535212925, 44.99625267301287, 46.10818331582205, 45.884621552058626, 47.83512680871146, 46.800599098205566, 47.55113656180245, 48.25539207458496, 47.53282458441598, 47.072395256587434, 47.421688147953574, 48.319503102983745, 48.69869409288679, 49.21447971888951, 49.956919057028635, 52.57527821404593, 52.43591472080776, 55.14250905173165, 57.542819840567454, 57.48586893081665, 55.23019184385027, 62.38751384190151, 65.63720716748918, 69.65368979317802, 69.78925609588623, 46.98274959836687, 4.095059369291578, 4.806741203580584, 0.9839514472654888, 0.1437726952135563, 28.843137911387853, 74.24191188812256, 70.87371008736747, 66.81541320255825, 65.57962744576591, 40.401930059705464, 23.035711935588292, 42.70873546600342, 55.84613922664097, 67.22145898001534, 64.31209536961147, 0.9985287679093224, 0.2803925728159291, 0.14712498390248843, 0.18858093582093716, 0.16556578794760363, 0.22051322806094373, 0.13752740461911472], [0.05108361405187419, 0.06498045567423105, 0.03743234443079148, 0.03968168801761099, 0.04933346189292414, 0.10075206868350506, 0.08692889900079795, 0.181650881256376, 14.661605766841344, 57.59278086253575, 48.84664208548409, 40.423976693834575, 30.69542169570923, 42.30433293751308, 46.37909705298287, 48.449931212833945, 65.66450663975307, 46.58220679419381, 0.9646876752376556, 0.1051191675609776, 0.6401475785034043, 1.2819848720516478, 18.974953651428223, 83.22842012132917, 62.58502333504813, 70.94575595855713, 59.017505509512766, 61.002744810921804, 56.35850286483765, 61.12402561732701, 57.090231554848806, 64.27564511980329, 59.4614189692906, 62.73427064078194, 55.14501735142299, 51.51904085704258, 61.202547209603445, 60.81147480010986, 60.770459583827424, 59.205968448093955, 58.048325606754844, 56.86389398574829, 54.93139498574393, 51.75620024544852, 48.96970510482788, 45.66268219266619, 45.267868178231375, 42.90806538718087, 42.957772799900596, 42.27792978286743, 41.907010623386924, 43.558038098471506, 43.149814060756135, 42.382104124341694, 42.529760292598176, 40.131829261779785, 40.00785602842058, 42.53657647541591, 43.253015654427664, 42.04643317631313, 42.89652442932129, 42.90014444078718, 42.3664949962071, 41.59105518886021, 38.49373933247158, 36.070301464625764, 37.574294635227744, 37.48645898274013, 36.41479662486485, 35.380744865962434, 36.6249692099435, 36.15072338921683, 37.3771846635001, 36.161896092551096, 38.57600252968924, 38.70241110665457, 38.711641788482666, 39.44489908218384, 36.64732851300921, 42.57150159563337, 40.27686595916748, 40.36119277136666, 41.495548725128174, 42.757449286324636, 47.679966585976736, 52.9185574395316, 45.09011588777815, 32.79449333463396, 42.35843161174229, 39.93218667166573, 41.0834059034075, 44.23391369410923, 49.36455038615635, 44.884007998875205, 39.78343963623047, 37.70434059415545, 37.96882724761963, 37.554016317640034, 37.486094202314106, 39.1889066014971, 40.58623450142996, 41.0028589112418, 38.751583508082796, 37.38799606050764, 36.57494912828718, 35.97426693780081, 36.43319892883301, 36.96631683622088, 35.6838252885001, 36.818539074489046, 34.79730115618025, 35.36011566434588, 35.07244634628296, 35.423802852630615, 36.82609871455601, 41.613536085401265, 44.334700788770405, 41.319946902138845, 39.531497955322266, 41.45445360456194, 39.96236269814627, 39.25597756249564, 36.145644256046836, 38.566556453704834, 42.49031884329659, 42.24282053538731, 42.071724619184224, 40.523071902138845, 40.5730676651001, 40.268774781908306, 41.62499019077846, 40.9972517149789, 42.05585493360247, 43.21189968926566, 42.526338304792134, 42.87818465914045, 43.734650884355815, 42.41716820853097, 44.47444643293108, 44.53267928532192, 47.672490324292866, 46.91791943141392, 46.99764653614589, 50.335647991725374, 53.23095192228045, 57.30017832347325, 56.819564478737966, 57.14374310629708, 53.694483620779856, 54.56332458768572, 58.4882264818464, 63.60989652361189, 63.44556467873709, 53.24020692280361, 5.264296148504529, 2.1798057981899808, 0.550756669470242, 0.12638541177979537, 3.5169740234102522, 55.639180183410645, 63.492937496730256, 52.72226388113839, 52.614198548453196, 43.90921395165579, 11.10601191861289, 14.376743521009173, 36.885933126722065, 54.75622047696795, 53.821969168526785, 1.3583320038659232, 0.08016036969742604, 0.03319269817854677, 0.030539968915815865, 0.03217779299510377, 0.08936063958598034, 0.061521148442157676, 0.06513218288975102, 0.09602815538112607, 0.035932137431310754, 0.01831646928829806, 0.04914438471730266, 0.10929634448673044, 0.15147300916058676, 0.22298734315804072, 21.786587374550955, 68.09540339878627, 56.895873069763184, 51.94493416377476, 25.380336386816843, 28.891308035169327, 48.36398894446236, 56.18311643600464, 72.64741148267473, 52.387930461338584, 1.122714789850371, 0.1959514817489045, 0.6070208474993706, 1.1729186730725425, 20.603448118482316, 88.6918512071882, 64.91570622580392, 73.44113894871303, 63.31434794834682, 63.97453798566546, 59.64449010576521, 62.40816388811384, 59.38861574445452, 67.7690395627703, 62.76188973018101, 62.30052934374128, 57.253972802843364, 55.823109422411235, 63.60622787475586, 63.92385087694441, 63.70967960357666, 63.757121903555735, 61.99314103807722, 58.69343457903181, 58.195460660117014, 54.839168071746826, 50.11508090155465, 48.14442586898804, 46.849691595349995, 46.01055070332119, 45.54673760277884, 42.31708288192749, 45.511009965624126, 44.73706749507359, 45.3355644771031, 44.7373697417123, 42.954392501286094, 41.841044425964355, 41.74111890792847, 44.539783818381174, 44.974442277635845, 43.54385335104806, 45.316790444510325, 46.30991036551339, 44.48108196258545, 44.54132979256766, 40.541918890816824, 40.58839539119175, 40.125819069998606, 40.59299162455967, 37.90376431601388, 39.47321646554129, 38.348858969552175, 37.653590951647075, 40.765775953020366, 38.57064894267491, 39.03666114807129, 42.46220990589687, 41.87855427605765, 41.8533844266619, 41.02842828205654, 44.81252840587071, 42.323509965624126, 42.733679498944966, 42.920797961098806, 44.3859680720738, 50.001432691301616, 54.24632692337036, 47.430161476135254, 36.10630008152553, 43.90411049979073, 41.467964376722065, 45.1529449735369, 48.270101411002024, 51.02959932599749, 47.640167304447715, 41.26573010853359, 39.68239198412214, 40.716742515563965, 40.43296766281128, 39.55304779325213, 41.383172035217285, 41.78908927100045, 43.02473953792027, 40.79562888826643, 39.0987537247794, 38.39154870169503, 38.8891578401838, 38.79191780090332, 38.30073922021048, 38.13597311292376, 39.31133038657052, 37.60540519441877, 37.917893477848594, 37.54279497691563, 37.792568819863455, 39.49500254222325, 43.26229844774519, 46.366392271859304, 43.342529296875, 41.95718356541225, 43.43292188644409, 41.497136388506206, 41.591864653996055, 39.20353603363037, 42.12313781465803, 43.604504176548545, 43.8545628956386, 42.86655684879848, 42.818308557782856, 42.12394380569458, 43.24155807495117, 43.15054014750889, 43.23304305757795, 43.65585483823504, 44.00958415440151, 43.65052556991577, 44.50370182309832, 43.62226724624634, 44.19386427743094, 45.259721415383474, 46.80561569758824, 48.101016998291016, 49.343004022325786, 50.20302077702114, 52.16575486319405, 56.72852223260062, 59.759600911821636, 59.11991500854492, 60.29281956808907, 57.85802834374564, 56.63680601119995, 61.35112748827253, 66.26692240578788, 64.4188266481672, 55.41925927570888, 6.3853953736169, 1.8727546972887856, 0.2524653199527945, 0.14447416471583502, 3.3044349253177643, 60.87483542306082, 66.89025224958147, 58.871496064322336, 57.99530042920794, 39.63035345077515, 14.66938601221357, 23.59598514011928, 42.23092869349888, 59.97762148720877, 61.75072533743722, 2.313993969133922, 0.23149546661547252, 0.06352621942226376, 0.1065784724695342, 0.06997971170182739, 0.07410902476736478, 0.0924669729013528, 0.1388075016438961, 0.1366893867296832, 0.13561591718878063, 0.27528027285422596, 0.22900782153010368, 0.3123475824083601, 0.26148492310728344, 0.31512802892497604, 28.044129814420426, 82.80721337454659, 64.01966653551374, 57.61138119016375, 40.16499996185303, 60.643780027117046, 60.646232741219656, 63.65675517490932, 78.5539083480835, 59.951940945216585, 1.9645484345299857, 0.2808807109083448, 0.8636869777526174, 3.637279910700662, 19.695160491125925, 90.41658864702497, 67.27605097634452, 76.04157870156425, 64.89502143859863, 66.17845099312919, 62.383400508335654, 66.01358413696289, 61.99740028381348, 69.97860145568848, 63.23183809007917, 65.07805783408028, 56.643344266074045, 58.89348016466413, 63.83294759477888, 66.61647238050188, 66.02181775229317, 63.803813798086985, 64.10057135990688, 61.583037512642996, 59.40736893245152, 57.90160744530814, 52.30193608147757, 50.31573098046439, 48.8723851612636, 48.08024883270264, 47.0183139528547, 45.2534749848502, 47.01291172845023, 45.758695874895366, 47.45946897779192, 47.19675064086914, 47.10430833271572, 43.833874634334016, 43.56977360589163, 46.49405499867031, 47.92121498925345, 46.59679453713553, 46.86908401761736, 47.34371198926653, 45.26858384268624, 46.47319303240095, 43.97231749125889, 42.027603558131624, 41.17569187709263, 44.11310536520821, 41.36387341363089, 41.132286480494905, 42.04755878448486, 39.66162729263306, 43.56451381955828, 40.04782901491438, 41.032624994005474, 45.99525077002389, 43.016266209738596, 44.43170458929879, 42.47971589224679, 47.36108248574393, 45.21275506700788, 44.578672885894775, 45.110891001565115, 46.290132318224224, 53.16475296020508, 58.00275584629604, 49.624235834394185, 39.296117305755615, 47.76158707482474, 45.411185196467805, 46.80642516272408, 50.46812234606062, 54.74721908569336, 50.552720138004844, 43.85700866154262, 42.032929352351594, 42.796241079057964, 41.72577728543963, 41.97385924203055, 44.78801168714251, 45.68049389975411, 45.051001003810335, 42.60393578665597, 41.403151580265586, 40.66973795209612, 41.79534959793091, 41.933750765664236, 41.26374639783587, 41.18675340924944, 42.51030881064278, 39.34165579932076, 40.32017060688564, 41.21275009427752, 42.313956192561555, 41.60112312861851, 47.06243848800659, 47.85204219818115, 46.76088319505964, 43.37944507598877, 46.352492400578086, 43.96446255275181, 45.957254546029226, 41.85265833990914, 44.349045344761436, 46.22842884063721, 47.47427211488996, 45.9567369052342, 45.455785683223176, 44.39164822442191, 44.92034707750593, 44.694985730307444, 45.864753178187776, 46.42349256787981, 46.96886362348284, 46.58661890029907, 47.71615627833775, 47.58981023515974, 46.2714729309082, 48.39053453717913, 50.085227966308594, 50.98499189104353, 52.207235608782085, 52.390025343213765, 55.573262623378206, 58.28807667323521, 62.43814536503383, 61.19448035103934, 62.33884865897042, 59.330952644348145, 60.172435079302105, 64.39071423666817, 69.38375922611782, 68.53557177952358, 59.61240332467215, 6.513128450938633, 4.136948755809239, 1.6975614066634859, 0.37600244528480936, 5.438236049243382, 69.5975066593715, 73.07296085357666, 66.35201004573277, 67.69679914202008, 56.6808888571603, 17.82771052633013, 25.304479428700038, 52.724834714617046, 67.88540799277169, 74.21770436423165, 3.762492528983525, 0.5219889559916088, 0.183773257370506, 0.22548393133495534, 0.11110846724893365, 0.24457284488848277, 0.1472146183784519], [0.013060202855350716, 0.008278212044388056, 0.08214028059904065, 0.08222327221717153, 0.08310502847390515, 0.027436834893056324, 0.06596524068819624, 0.04366759949230722, 20.09279200008937, 54.20357118334089, 43.846798283713206, 44.244659083230154, 37.82324511664254, 34.57257556915283, 51.902421610695974, 50.6731914792742, 69.09517969403947, 34.70313222067696, 0.0346064021411751, 0.08619293277817112, 0.8801081223147256, 0.5698676354118756, 62.270242146083284, 76.72599015917096, 65.54637336730957, 66.92368003300258, 57.798833165849956, 59.23301083700997, 56.2647681917463, 57.45919827052525, 59.24330111912319, 64.11908830915178, 56.14224713189261, 67.04753167288644, 50.474823883601594, 53.37392847878592, 62.719213894435335, 60.133212498256135, 61.97580528259277, 58.040001664842876, 60.44051047733852, 56.647940499441965, 54.49016353062221, 51.22482286180769, 50.54043224879673, 47.75113698414394, 45.52840825489589, 42.497791630881174, 42.676016398838584, 42.232502460479736, 42.24029833929879, 40.967047895704, 42.421813079289024, 41.833919048309326, 44.28429160799299, 40.00128650665283, 40.85527569907052, 40.78006492342268, 43.59789296558925, 41.41065216064453, 40.99564668110439, 41.98884303229195, 44.291205065590994, 45.09388875961304, 43.88251549857003, 38.181306634630474, 36.26505252293178, 35.34659446988787, 36.405215059007915, 35.7915849004473, 36.72983142307827, 37.098200593675884, 35.921856675829204, 35.08066953931536, 36.15760210582188, 35.71926804951259, 38.44197872706822, 37.46873412813459, 43.683981146131245, 46.874885763440815, 50.652322564806255, 48.51825284957886, 48.33734607696533, 48.40990958895002, 47.444276741572786, 51.14929941722325, 47.111173152923584, 33.50213609422956, 37.693379810878206, 33.54052489144461, 34.17007337297712, 44.33810888017927, 48.644425187792095, 45.23453766959054, 43.68146937234061, 44.10645246505737, 42.323878220149446, 36.250193800245015, 37.27780457905361, 38.66681548527309, 39.23836040496826, 38.05459581102644, 37.9686188016619, 36.973834787096294, 37.79561907904488, 36.031242166246685, 36.70776047025408, 35.59815747397286, 34.74932731900896, 36.933205195835654, 33.96826294490269, 36.354347297123496, 35.5119754927499, 36.615040234157014, 40.473034449986045, 44.008284841264995, 41.94766105924334, 41.44197463989258, 39.89054611751011, 41.122795241219656, 40.94157232557024, 38.93760762895857, 36.70025641577584, 38.72285270690918, 39.115627425057546, 40.58209684916905, 40.608951636723106, 40.791011810302734, 41.140589577811106, 41.058479240962434, 40.84351587295532, 41.96285676956177, 40.963459151131765, 43.552239826747346, 44.67832742418562, 46.744568824768066, 46.25907734462193, 47.1950934955052, 48.70436034883772, 50.57120929445539, 52.6260278565543, 57.26469734736851, 56.64830527986799, 58.002457073756624, 57.33464138848441, 58.72065762111119, 60.307924951825825, 65.6043838773455, 59.9835205078125, 59.321169580732075, 59.328124727521626, 61.89854826245989, 65.00558117457798, 53.89311524799892, 10.389336500849042, 0.7901801392436028, 0.3526449900652681, 0.02084724205945219, 0.6158376772488866, 43.84954629625593, 66.52313722882951, 56.16346345629011, 51.404065540858674, 44.59121438435146, 27.483137471335276, 13.360684990882874, 30.136928967067174, 48.47342307226998, 55.3214043208531, 3.005341248852866, 0.2993309465902192, 0.07806531818849699, 0.050272852914141755, 0.05774612565125738, 0.07183633957590375, 0.07163210732064076, 0.05228118086233735, 0.023171914907704507, 0.05558676937861102, 0.020802424821470464, 0.009837393066845834, 0.010168681004350739, 0.12130500296396868, 0.02068963703433318, 27.59953022003174, 64.38941492353166, 51.215609550476074, 47.90651954923357, 40.3238913672311, 38.48755196162632, 55.632499490465435, 58.658554622105186, 74.61835139138358, 40.20723806108747, 0.025497707338737588, 0.2016945614346436, 1.3868872544595172, 0.7627882233687809, 65.91254343305314, 80.39666094098772, 67.9242970602853, 68.62745475769043, 60.90433747427804, 63.06054415021624, 57.17400598526001, 60.02907289777483, 61.73815604618618, 69.06102234976632, 58.92788069588797, 63.729322160993306, 53.92798478262765, 56.6106390953064, 63.984717096601216, 60.7779358455113, 63.45593139103481, 60.1681341443743, 62.25057874407087, 57.53153249195644, 56.73329911913191, 52.93676519393921, 53.86622224535261, 49.29289708818708, 46.65748010362898, 43.63395411627633, 44.10751553944179, 43.86661802019392, 43.61454432351248, 44.67076431001936, 44.75191232136318, 43.262381826128276, 46.14860098702567, 43.05302218028477, 42.92110020773751, 42.9176539012364, 45.0735513823373, 43.07888684953962, 43.84798642567226, 43.422718456813264, 46.03519943782261, 46.7967324256897, 44.95520618983677, 41.61587068012783, 36.663559504917686, 37.50080353873116, 39.27674920218331, 38.536526339394705, 40.11725194113595, 38.69894395555769, 38.344571931021555, 39.11912931714739, 38.89511244637625, 39.202511174338206, 40.26773255211966, 40.39133753095354, 45.513188225882395, 48.800228118896484, 51.943600109645296, 52.02034991128104, 51.090191091809956, 50.463995116097585, 49.373555251530235, 53.223291533333914, 47.096081665584016, 35.73816367558071, 37.80424179349627, 35.51464360100882, 35.71694040298462, 46.03364304133824, 49.86510556084769, 47.0376056262425, 45.47405597141811, 47.941774708884104, 45.78338977268764, 39.51604516165597, 38.197266646793906, 39.82257536479405, 42.033384459359304, 40.379744461604524, 40.15763487134661, 38.1108831678118, 39.986994062151226, 38.88646193913051, 38.16741023744856, 37.04249341147286, 37.11685650689261, 37.17353991099766, 37.2741949898856, 39.3530786378043, 37.33466863632202, 40.91234820229666, 41.12907641274588, 46.06470496313912, 43.47471530096871, 42.35508605412075, 40.89444269452776, 43.69137750353132, 43.52526344571795, 41.93848596300398, 39.790432998112266, 40.98054824556623, 40.48954684393746, 41.92980418886457, 41.80966288702828, 42.82991899762835, 43.535456453050884, 43.575828960963655, 41.57316705158779, 42.991454192570274, 43.259526116507395, 45.82627058029175, 46.956853662218364, 49.24771990094866, 47.97461189542498, 50.0150476864406, 50.625036988939556, 51.725624697549, 54.506269454956055, 59.974717140197754, 60.34679317474365, 60.3127886908395, 59.04251207624163, 62.69915444510323, 61.2612247467041, 66.72969327654157, 61.778052602495464, 62.03579602922712, 61.55529335566929, 64.48671749659947, 65.39923136574882, 57.32831505366734, 11.076647094317845, 1.195699753505843, 0.6009555043918746, 0.03577987417312605, 0.5234439522027969, 46.45920630863735, 71.72148064204625, 61.44436536516462, 58.87966019766671, 44.73686947141375, 23.085949148450577, 15.97556918007987, 36.89847115107945, 54.863365173339844, 63.944188254220144, 4.558565880571093, 0.4908653146454266, 0.09334642213902303, 0.04979009560442396, 0.03247621948165553, 0.05068433012015053, 0.021723403794957057, 0.1291755342057773, 0.08835523389279842, 0.16243467453335012, 0.11891719752124377, 0.14357874276382582, 0.13117187922554358, 0.3082442097365856, 0.13459945816014493, 37.434305804116384, 78.31592559814453, 56.95142044339861, 58.479798316955566, 45.123863288334434, 53.92023059300014, 66.59847654615129, 64.10328115735734, 80.63928508758545, 45.77274860654558, 0.1307811787618058, 0.23667765568409646, 3.588113154683794, 0.5892007265772138, 66.16861234392438, 81.79775823865617, 71.35487978799003, 71.38808522905622, 63.42601939610073, 64.03591837201799, 59.93591839926583, 61.922734941755024, 64.00904968806675, 70.19694859640938, 63.594131061008994, 64.67060852050781, 55.499010699135916, 60.621851512363975, 65.14210632869175, 65.41316945212228, 65.5124522617885, 62.583459990365164, 64.47571849822998, 60.5462829044887, 60.72261428833008, 55.478120940072195, 56.438858781542095, 52.13887575694493, 50.19050012316023, 47.91938761302403, 46.89745351246425, 44.680953843253, 46.273189135960166, 45.130012444087434, 47.35068450655256, 45.983682019369944, 48.357673031943186, 45.171458448682515, 45.50980792726789, 46.283350876399446, 48.400744915008545, 44.41323280334473, 44.87299510410854, 46.659852913447786, 48.82420635223389, 48.28206273487636, 47.40549884523664, 44.537546498434885, 39.93633822032383, 39.32637323651995, 40.68203626360212, 39.91062641143799, 41.00807006018502, 43.35070037841797, 40.772908278873985, 41.64307982581002, 41.31346423285348, 40.512465476989746, 43.77904292515346, 42.65383774893624, 48.05177511487688, 52.19064678464617, 56.17049503326416, 52.73821694510323, 52.9160943031311, 53.63696295874459, 52.78955718449184, 56.26963540485927, 51.71671710695539, 39.80903679983956, 38.02924183436802, 38.189745221819194, 39.146404470716206, 49.09463024139404, 52.46743869781494, 48.64868095942906, 48.41471426827567, 51.80861050742013, 49.38294921602522, 41.151880400521414, 42.209656783512656, 42.9808303969247, 44.23314939226423, 43.48731585911342, 43.50236913136074, 40.71006529671805, 43.211632183619905, 41.13210930143084, 41.8440842628479, 40.21744496481759, 39.453334195273264, 41.13531242098127, 40.21178913116455, 41.26028619493757, 39.752384662628174, 42.58681889942714, 44.01589659282139, 47.086989947727744, 45.678739479609895, 45.902085849217, 44.76355055400303, 45.83810336249215, 45.06045402799334, 44.20910167694092, 42.69842086519514, 43.32841750553676, 42.94968857084002, 44.70686714989798, 44.9683278628758, 45.913296767643516, 45.12109790529524, 45.0961469241551, 44.71072687421526, 45.60235793249947, 44.869430678231375, 48.96967731203352, 50.28631925582886, 52.69188635689871, 50.722148486546104, 51.39855909347534, 54.03273582458496, 55.08868830544608, 55.44191040311541, 62.510983330862864, 61.9147584097726, 62.81095790863037, 63.12916455950056, 65.15841375078473, 65.4583466393607, 69.44809954507011, 65.16513960702079, 67.1692224230085, 65.26429040091378, 66.90603160858154, 69.3255124773298, 61.47111592973982, 11.73021810395377, 3.0990335813590457, 1.179239688175065, 0.13735850368227276, 1.0730350613594055, 54.988238198416575, 75.73267568860734, 67.7077772957938, 67.9431266784668, 58.85079738071987, 39.49994271142142, 23.099888971873693, 46.72566277640206, 61.54393999917166, 75.75185966491699, 8.69163363320487, 0.8670153820088932, 0.21538909444851534, 0.17281290835567883, 0.16661442310682364, 0.12827164413673536, 0.1333451997488737], [0.10510873169239078, 0.06738328388226883, 0.013360843910569591, 0.060485907564205785, 0.06038610863366297, 0.07294162562383072, 0.04779510086934481, 0.06142553607267993, 29.18082904815674, 54.570377009255544, 34.13489811761038, 41.85521527699062, 34.86532054628645, 30.357405730656215, 51.81515918459211, 53.53406013761248, 69.61617646898542, 22.48590271813529, 0.349764880325113, 0.5668561884335109, 2.48466517669814, 15.014433554240636, 86.44406032562256, 62.41215215410505, 68.15779127393449, 58.16547223499843, 58.34430149623326, 54.97677714484078, 56.70577730451311, 54.73849562236241, 62.53652490888323, 61.908706528799875, 61.2486207144601, 61.57082257952009, 45.0265086037772, 56.25056607382638, 56.50729853766305, 60.52185998644148, 64.82319096156529, 60.37653841291155, 58.76839869362967, 57.327908584049766, 59.096506527491975, 57.33231374195644, 55.5070150239127, 55.25379140036446, 47.64214406694685, 42.73078557423183, 44.153085299900596, 42.572043555123464, 40.73151091166905, 42.427347319466726, 41.62561205455235, 43.417684486934114, 43.1638320514134, 41.18174375806536, 41.96140807015555, 40.61011545998709, 41.0751827103751, 40.93003831590925, 44.44620200565883, 44.5908739226205, 45.68782424926758, 40.27079323359898, 42.17142084666661, 43.853753430502756, 41.32934086663382, 35.98910481589181, 35.787992681775776, 36.000534602573936, 35.136585167476106, 36.072233063834055, 35.58304166793823, 36.94648320334298, 37.004646573747905, 38.11646604537964, 37.83055114746094, 35.54323891230992, 37.00074168613979, 41.623020376477925, 42.10280391148159, 51.94424281801496, 52.46384300504412, 54.38304662704468, 50.73252214704241, 57.076390743255615, 45.73427990504673, 34.29025288990566, 41.57308714730399, 37.15489442007882, 32.4456798689706, 46.894451890672954, 53.38598012924194, 47.2926218850272, 50.44337633677891, 47.978006090436665, 45.442108154296875, 43.50261231831142, 37.1924181665693, 36.378537450517925, 38.481309005192344, 34.76745169503348, 35.837967600141255, 34.91357231140137, 35.51090547016689, 34.552366733551025, 36.49687916891915, 36.13334247044155, 35.414165701184956, 34.98308556420462, 36.36622176851545, 37.35438414982387, 41.060480322156636, 41.019058636256624, 40.41200494766235, 39.903994355882915, 39.538932527814595, 42.89009387152535, 39.54318829945156, 41.14649554661342, 38.216732025146484, 38.60919407435826, 36.05821507317679, 38.82359116418021, 39.82194307872227, 41.68606833049229, 41.14567913327898, 40.977463245391846, 41.39342410223824, 40.902919496808735, 42.561444078172954, 43.85076223100935, 47.53481176921299, 49.975105966840474, 50.84945338112967, 52.74674933297293, 52.62779269899641, 55.98391853060041, 55.47950710569109, 60.623783111572266, 58.3330523627145, 60.00823525020054, 57.13102790287563, 62.14507729666573, 57.414125306265696, 62.08450290134975, 58.26167699268886, 76.24155480521065, 65.84907858712333, 59.782008852277485, 61.081009319850374, 61.62820080348423, 63.67288194383894, 57.362930979047505, 9.215373209544591, 0.7611741785492215, 0.3710750054035868, 0.19330128681446823, 0.025002580335629836, 28.092845371791295, 68.2649255480085, 58.64794472285679, 54.26101541519165, 41.0002498626709, 25.660715307508195, 17.578016587666102, 41.414966991969514, 45.38648435047695, 63.4308831351144, 10.601896660668508, 0.44768866577318733, 0.20014071624193872, 0.14064477091389044, 0.08460302344922509, 0.035102380705731254, 0.0452349475318832, 0.04206741714317884, 0.07195561246148177, 0.019008340912738016, 0.03794131354827966, 0.13850440005106585, 0.020509849003117, 0.06757009814360312, 0.10591456666588783, 37.12380470548357, 67.04429381234306, 38.44516100202288, 46.65673317228045, 46.55968420846121, 29.76688528060913, 60.500452586582725, 58.24700239726475, 76.320145879473, 23.333593368530273, 0.4522735540355955, 0.39326147202934536, 2.99737948179245, 17.84132031032017, 90.23644965035575, 66.62112767355782, 71.54393332345145, 60.87269537789481, 60.3859532220023, 56.794224398476736, 58.76983002253941, 57.79516451699393, 63.73751408713204, 64.26071344103131, 60.29889229365757, 61.14771202632359, 49.345481055123464, 56.79587459564209, 58.523099490574424, 62.16465732029506, 66.06721033368791, 61.507302148001536, 59.54323400769915, 60.00398990086147, 60.99173191615513, 59.86765234810965, 57.45799275806972, 57.09347288949149, 49.382063320704866, 45.20712007795061, 46.28091900689261, 44.59990658078875, 43.828781604766846, 43.59283120291573, 43.8209753036499, 44.529236452920095, 45.8598164830889, 41.946184567042756, 43.637355259486604, 43.15554632459368, 43.47013643809727, 43.51838820321219, 45.96346970966884, 46.82264225823538, 45.794916834150044, 40.53254924501692, 43.60164499282837, 44.32285411017281, 44.17958572932652, 39.32392052241734, 37.74123205457415, 40.130509104047505, 38.40662629263741, 37.47328519821167, 37.32967288153512, 38.41931370326451, 37.9778390611921, 38.88237639835903, 39.04345996039254, 37.28717769895281, 39.90234068461827, 43.43962342398507, 45.97266912460327, 53.64443574632917, 54.4947806085859, 56.49514613832746, 53.38887405395508, 57.5127306665693, 49.87075792040144, 39.59281233378819, 42.41352735246931, 37.60012456348964, 35.2933851650783, 49.21290595190865, 54.38782351357596, 51.09195246015276, 52.90567895344326, 50.56718976157052, 47.84625782285418, 45.887956687382285, 39.02809749330793, 38.15109934125628, 39.18544292449951, 37.95323201588222, 36.40269981111799, 36.98166193280901, 36.861235754830496, 37.94998025894165, 37.415844440460205, 38.36987727028983, 37.72634901319231, 37.29317399433681, 37.76442166737148, 38.25556550707136, 42.682544231414795, 42.214305128370015, 40.05097654887608, 39.8239233153207, 41.71975667136056, 44.547996589115684, 40.71404314041138, 41.44910001754761, 40.95177228110177, 41.16269179752895, 38.60999659129551, 41.895205633980886, 42.094594614846365, 43.41217456545149, 43.45087603160313, 43.444448947906494, 41.52647168295724, 43.084549631391255, 44.5245429447719, 47.19381502696446, 49.419281346457346, 51.89518158776419, 52.96742412022182, 54.7999906539917, 56.772598130362375, 59.226583753313335, 57.920600346156526, 61.649545669555664, 59.94313062940325, 62.742129053388325, 59.45014204297747, 64.1960118157523, 60.13777051653181, 64.13246359143938, 61.85034166063581, 75.1774868283953, 67.0736152103969, 61.835243225097656, 63.21158409118652, 65.11084638323102, 65.04301806858608, 61.526062284197124, 10.48449034350259, 0.26101792816604885, 1.0548530369997025, 0.042056122927793434, 0.04881251663235681, 28.70719119480678, 75.06985228402274, 61.80936813354492, 62.787250655038015, 44.3854330607823, 28.366441113608225, 22.11692384311131, 49.37628589357649, 51.93963616234915, 71.91817024775914, 14.443963868277413, 0.6151377548064504, 0.1105142402063523, 0.11475799498813492, 0.049743412395140955, 0.05732217697160585, 0.028815994637885263, 0.18216122101460183, 0.09450548887252808, 0.07701654732227325, 0.10255138070455619, 0.2365244696182864, 0.1369955145886966, 0.16586207704884665, 0.3683561970080648, 48.161421162741526, 78.44635718209403, 48.29552139554705, 54.4466678074428, 39.68101276670183, 43.2223984173366, 68.91907065255302, 65.08447796957833, 83.24868106842041, 28.779693910053798, 0.5103594628827912, 0.804586469062737, 6.228943220206669, 19.09178761073521, 91.97147737230573, 70.61208956582206, 73.21694142477853, 65.30029596601213, 62.5012697492327, 61.02713993617466, 61.42035239083426, 61.21481078011649, 67.03942312513078, 67.88679763248989, 59.92999158586775, 62.13251495361328, 54.70536661148071, 58.4472599029541, 62.33850819723946, 62.44735867636544, 67.82106072562081, 64.90947369166783, 61.924569266183035, 62.24845954350063, 64.68761771065849, 63.09206812722342, 60.05299554552351, 61.641152245657786, 53.27516678401402, 47.5202830859593, 48.84772947856358, 45.32024022511074, 44.40647915431431, 44.926610878535676, 44.93861041750227, 47.26978315625872, 46.94386747905186, 45.863082136426655, 45.22174951008388, 45.29636968885149, 45.265655176980154, 44.78719874790737, 49.57482024601528, 48.008206435612266, 48.520865372249055, 41.98715809413365, 43.49728304999215, 47.58661406380789, 46.18357821873256, 42.81613377162388, 40.629000663757324, 41.321009976523264, 40.53630474635533, 42.25681420734951, 40.62134027481079, 41.39181212016514, 40.772352422986714, 42.02755492074149, 42.445079122270855, 39.946090017046245, 43.687083516802105, 47.18574122020176, 48.25255026136126, 57.30871071134295, 59.57082530430385, 59.49224812643868, 55.824745723179404, 58.96317754473005, 52.57620579855782, 41.63893869944981, 42.65547752380371, 38.692464760371614, 39.25692251750401, 54.810267039707725, 56.965761525290354, 54.422745159694124, 54.65874767303467, 54.86664819717407, 49.7858578818185, 50.58907658713204, 40.65105077198574, 40.975215503147666, 42.88186373029436, 41.54778528213501, 38.89705446788243, 40.621969086783274, 39.36493573869978, 40.91664566312517, 40.670102732522146, 40.84719147000994, 40.68529149464199, 39.236793586185996, 41.10167966570173, 43.06915937151228, 45.36509084701538, 43.96296869005476, 41.09645809446062, 41.59749616895403, 43.527233260018484, 46.357946736471995, 43.19658933367048, 44.119556767599924, 42.0525267464774, 43.43580886295864, 40.87499816077096, 43.90225880486624, 43.67082820619856, 46.03648485456194, 44.95510196685791, 45.797498089926584, 44.807629925864084, 44.9576450075422, 46.66185399464199, 49.28954110826765, 53.6869934626988, 54.55282933371407, 55.36940942491804, 56.903762749263215, 58.35229887281145, 60.06024946485247, 58.943604469299316, 63.69325406210763, 62.57908957345145, 65.35037163325718, 61.48887552533831, 67.42259543282645, 62.68454238346645, 66.58184255872453, 64.40765394483293, 75.12340205056327, 67.14505658830915, 65.73470429011753, 65.82338414873395, 68.19472789764404, 68.14338071005685, 67.0986773627145, 13.4282614333289, 3.38299321276801, 1.5653589005981172, 0.2509682002876486, 0.1300637229744877, 33.741400786808555, 81.67433738708496, 66.7927690233503, 70.18194743565151, 55.30559022086007, 36.75160360336304, 28.700720684868948, 55.969341209956575, 57.55343321391514, 82.12886769430978, 20.41245256151472, 0.8107205341969217, 0.3585816015090261, 0.2241345016019685, 0.12723250846777642, 0.13751810868935926, 0.1325663908251694], [0.05327679868787527, 0.028733043731855493, 0.06160308154565947, 0.027352396298998168, 0.11659370362758636, 0.05125739026282515, 0.04082195593842438, 0.26688551902770996, 36.658473423549104, 45.289810589381624, 37.76659297943115, 30.417108127049037, 27.871361119406565, 39.66492073876517, 50.866684913635254, 55.73466232844761, 69.1116121837071, 14.36496979849679, 0.3946720106261117, 1.2934138987745558, 7.177673271724156, 48.717787742614746, 75.38382748195103, 65.33273015703473, 64.88785784585136, 57.047937870025635, 56.41967827933175, 56.726635796683176, 53.90248836789812, 55.169732093811035, 60.81420544215611, 60.01459980010986, 65.32378087724958, 40.1757800919669, 48.61564922332764, 61.500791685921804, 57.60615961892264, 63.22145748138428, 56.35271154131208, 61.394887242998394, 58.31748144967215, 60.53815351213728, 58.02752270017351, 56.70853921345302, 57.356677600315635, 55.36004325321743, 48.54494782856533, 43.90301963261196, 43.960495131356375, 43.80859361376081, 42.48929745810372, 43.2312400000436, 41.563661915915354, 43.053341797419954, 41.23900038855416, 40.60098205293928, 40.01090628760201, 40.497193336486816, 41.493002210344585, 42.51361615317208, 41.652046476091655, 45.84759112766811, 45.091811248234336, 42.717597893306184, 37.65632854189192, 39.32537964412144, 40.72822093963623, 41.931478704724995, 37.446294920785085, 38.13613639559065, 37.11547034127371, 36.047038895743235, 35.426314626421245, 36.685564449855256, 34.61813838141305, 36.16689184733799, 35.84096574783325, 36.33627503258841, 36.212378229413716, 37.90929855619158, 34.460028648376465, 38.93682248251778, 39.88462972640991, 46.846766403743196, 47.53164686475481, 49.134558064596995, 31.26657404218401, 36.13949857439314, 43.71013069152832, 43.51377807344709, 30.80471338544573, 34.20043005262102, 50.455240385872976, 47.280886377607075, 46.72816412789481, 40.36495869500296, 40.20849915913173, 36.66067600250244, 34.67692708969116, 34.868832860674175, 36.96193599700928, 34.2348826953343, 35.76108578273228, 34.65008272443499, 35.707383155822754, 35.47566073281424, 35.55064221790859, 35.407655239105225, 37.08353294645037, 34.65530776977539, 36.421602385384695, 40.19570057732718, 38.41121210370745, 35.50469030652727, 38.30100672585623, 38.52153212683541, 41.58165775026594, 42.025762285505024, 37.957185540880474, 39.15022250584194, 39.24831369944981, 37.547471114567344, 36.10211031777518, 37.59752941131592, 40.450636931828086, 40.90238448551723, 42.29561642238072, 41.97067696707589, 41.71716846738543, 42.277426038469585, 44.46658802032471, 49.83568341391427, 51.093317781175884, 55.098488739558626, 55.70880460739136, 57.43135336467198, 55.436487334115164, 54.93785333633423, 55.307799748011995, 58.43639292035784, 54.20890392575945, 57.382128851754324, 54.56127486910139, 58.417952401297434, 57.35523584910801, 61.49793597630092, 56.182056835719514, 62.38675648825509, 72.53812326703752, 62.62141799926758, 63.403291838509695, 65.22931316920689, 62.6156370980399, 58.18810599190848, 11.587997164045062, 0.18967638989644392, 0.8658991647618157, 0.134244299360684, 0.07056077516504697, 16.50453553880964, 69.81476293291364, 59.396467208862305, 60.14689350128174, 47.651600565229145, 27.8727160181318, 9.010121686117989, 19.34945113318307, 38.80305923734392, 60.46619101933071, 18.9340044430324, 0.48177375963756014, 0.030427939391561916, 0.1261778072054897, 0.0560318815654942, 0.058184907106416564, 0.038123788578169684, 0.1368033941835165, 0.04335511036749397, 0.04310517877872501, 0.05273393335353051, 0.050838360962058814, 0.04780863085761666, 0.06688770904604878, 0.5390798417585236, 47.82061549595424, 58.272603034973145, 42.91213355745588, 35.158795084272114, 27.23913758141654, 41.312991755349294, 59.271587235586985, 59.83553082602364, 77.43367808205741, 16.079010486602783, 0.28928699983017786, 1.3954638285296304, 9.192197493144445, 61.19330610547747, 78.55183778490338, 70.25393077305385, 65.66116455623082, 61.281610761369976, 59.0210143498012, 59.531894547598704, 55.02538674218314, 58.14015647343227, 63.573244776044575, 62.202740396772114, 63.32244954790388, 45.06031853812081, 52.28167860848563, 62.71571895054409, 60.222608021327424, 64.08566747392926, 57.252027307237896, 61.2993495123727, 60.92301423209054, 62.30900614602225, 60.09708881378174, 58.47707462310791, 58.60298292977469, 58.593804359436035, 50.55217470441546, 45.18377760478428, 46.39955254963466, 45.32392624446324, 44.49234846660069, 44.30202341079712, 42.60096195765904, 44.919151987348286, 42.662307603018625, 42.78546094894409, 41.1921625818525, 43.48765284674508, 42.36648457390921, 41.60848127092634, 42.23510456085205, 48.27367278507778, 46.16637795312064, 42.76726361683437, 37.48797716413225, 38.786741392953054, 39.988845757075715, 44.23089122772217, 39.99767344338553, 39.51315123694283, 39.35801880700247, 39.50699513299124, 38.2268624986921, 38.52045168195452, 36.570262568337576, 39.28192213603428, 38.18092795780727, 39.587142603737966, 37.73256070273263, 39.99664510999407, 36.83296006066458, 40.15468536104475, 41.58198084150042, 48.114882128579275, 46.806908062526155, 51.10230875015259, 35.53984471729824, 39.420712402888704, 44.51052842821394, 46.07021835872105, 35.03484269550869, 38.3997927393232, 51.88903590611049, 48.68680919919695, 48.581279958997456, 42.71914039339338, 42.68598358971732, 39.54654427937099, 38.04113367625645, 38.01568589891706, 38.00837639399937, 37.49851758139474, 39.32239539282662, 38.22019917624337, 38.62755468913487, 37.789431708199636, 37.370559556143625, 37.9978220803397, 39.75878742762974, 35.969107900347026, 40.622688225337434, 43.72848435810634, 39.77790192195347, 36.99922003064837, 38.67609827859061, 39.76602397646223, 42.69462367466518, 43.593102182660786, 39.92659337180001, 42.74222578321184, 41.39806202479771, 40.46091331754412, 37.699039118630544, 38.68941797528948, 41.79991109030587, 43.47389541353498, 43.687281540461946, 44.01735571452549, 42.3890141078404, 44.91619552884783, 46.09419311795916, 52.91072334562029, 53.50297042301723, 57.05597346169608, 56.245403562273296, 59.01675510406494, 57.70982674189976, 59.35513932364327, 58.180702686309814, 59.55112716129848, 56.02310637065342, 59.32973670959473, 55.93552085331508, 60.75865459442139, 58.914130210876465, 62.98762280600411, 58.85286099570138, 64.347503389631, 70.54791600363595, 65.56199291774205, 65.11426489693778, 67.12989561898368, 65.48226928710938, 61.069510051182334, 14.846073491232735, 0.49328887888363426, 1.399755752512387, 0.06441462532218013, 0.15758164280227252, 17.15762104306902, 74.16487721034459, 63.82134410313198, 68.41381849561418, 48.87754072461809, 24.881005832127162, 18.249857016972133, 27.10952935900007, 43.747772557394846, 70.46090371268136, 23.239059652600968, 0.5036724731326103, 0.0687400892909084, 0.07344065420329571, 0.12389419760022845, 0.06877529168767588, 0.048316843408559046, 0.2547311655112675, 0.17024785599538259, 0.13120021484792233, 0.16305583263082163, 0.29855863803199356, 0.10321262665092945, 0.16709710577768938, 0.966441878250667, 59.40080288478306, 65.09816592080253, 54.51098380770002, 42.16007096426827, 37.4275278363909, 58.182880946568076, 66.20991938454765, 66.57738181522915, 82.66189874921525, 18.94150502341134, 0.43004317262342995, 2.3778390118053983, 11.699227401188441, 65.04296248299735, 79.09728527069092, 74.62293025425502, 68.34020233154297, 64.79329286302838, 59.462204115731375, 63.108160155160085, 56.829159940992085, 61.80739484514509, 67.20720822470528, 64.72680555071149, 65.54359408787319, 51.132053988320486, 55.25412491389683, 65.92715549468994, 64.25378608703613, 67.85949121202741, 59.877706391470774, 64.96877656664167, 63.028547695704866, 65.53749356951032, 62.12621293749128, 60.35038539341518, 60.96682957240513, 59.640474046979634, 53.02371147700718, 47.31142718451363, 48.364857469286235, 47.75524684361049, 47.612162590026855, 48.45705311638968, 45.00567443030221, 48.18282508850098, 44.36916732788086, 45.326104504721506, 43.29829706464495, 45.50469752720424, 44.744689668927876, 44.356017862047466, 45.67275708062308, 49.4534386907305, 45.985432965414866, 44.33605916159493, 38.08591134207589, 39.17335305895124, 39.88477216448103, 45.89642654146467, 41.362351758139475, 42.131135191236226, 44.33773715155465, 41.05027689252581, 41.487016337258474, 41.75171491077968, 38.94292300088065, 41.083013330187114, 42.84101179667881, 42.51247664860317, 41.31243937356131, 44.55453484398978, 39.776439326150076, 43.768915925707134, 44.1758371761867, 52.51357821055821, 51.70492253984724, 53.20158188683646, 38.9989914894104, 42.69302906308855, 47.301404408046174, 49.22672591890608, 39.30083165849958, 41.822874886649, 56.025534766060964, 52.77970116479056, 51.44943380355835, 44.11199712753296, 46.16633973802839, 41.49082395008632, 40.367929049900596, 39.66731786727905, 41.43153149741036, 39.30311066763741, 41.30413280214582, 39.03197111402239, 40.711183956691194, 40.719674655369346, 40.85912152699062, 40.8831900869097, 41.685797350747244, 39.01157120295933, 43.2735857963562, 45.298909255436485, 40.106186934879844, 35.665252753666465, 39.72267763955252, 40.51811783654349, 44.3822021484375, 46.35232564381191, 41.121926716395784, 43.21644728524344, 42.91660819734846, 42.6883807182312, 40.16111939293997, 42.914381299700054, 43.36375604357038, 45.486354282924104, 46.18261936732701, 46.34643357140677, 45.98612778527396, 47.223192010607036, 49.07388639450073, 55.84140402930123, 57.32774530138288, 59.35862037113735, 59.50206593104771, 63.708560943603516, 60.41781071254185, 60.27718612125942, 59.638938495091026, 62.77559157780239, 58.44404983520508, 60.45311450958252, 57.479021481105256, 63.9671242577689, 60.012619563511436, 65.09542833055768, 58.76677976335798, 69.78125177110944, 70.76536682673863, 68.56972217559814, 68.13602256774902, 71.80862494877407, 67.71772711617606, 65.8519481931414, 15.620795897075109, 2.324602348463876, 2.569571077823639, 0.25220150553754395, 0.25999415452991215, 20.045215947287424, 81.65764086587089, 68.83093970162528, 75.12764045170375, 63.24218395778111, 40.25081368855068, 16.99916042600359, 33.19214221409389, 52.950602531433105, 79.09549958365304, 32.122783184051514, 0.7218484058976173, 0.18311366704957827, 0.24560793648873055, 0.20393607472734793, 0.18985891581646033, 0.1445563488772937], [0.057698397498045645, 0.01892944086076958, 0.11840740059103284, 0.03711202161918793, 0.047885094968868155, 0.06993513195110218, 0.0699512403724449, 1.0073944521801812, 28.627707277025493, 46.69055005482265, 36.87808861051287, 28.138468980789185, 29.033330951418193, 38.88584007535662, 52.524792603084016, 57.559026513780864, 66.44052314758301, 5.113478984151568, 0.14729026146233082, 0.4347523685012545, 10.007423554147993, 70.01910250527519, 66.48066983904157, 67.1444034576416, 60.26141371045794, 62.27678734915597, 54.373739515032085, 56.07265050070626, 52.80685819898333, 55.35764959880284, 54.934789180755615, 61.790496826171875, 50.37762205941336, 51.59193440846035, 60.60541902269636, 60.089008058820454, 58.223743302481516, 60.11659240722656, 57.44290821892874, 60.68881130218506, 59.04698671613421, 58.920724051339285, 55.76361199787685, 56.38256795065743, 56.86689560753958, 55.09284332820347, 45.87247610092163, 41.7796744619097, 41.506971563611714, 43.13913467952183, 42.01754604067121, 42.22428968974522, 43.48131956372942, 43.41898380007063, 42.69410603387015, 40.569267000470845, 39.80686201368059, 41.89722408567156, 40.05908509663173, 42.21585457665579, 40.34914806910923, 42.62185866492135, 44.187378134046284, 39.33338049479893, 39.457381520952495, 37.00704370226179, 38.28693662370954, 38.586692333221436, 40.8157821382795, 38.43705940246582, 35.833739621298655, 36.97144113268171, 36.06322472436087, 35.7583794593811, 34.7019545010158, 34.826361996786936, 35.031076771872385, 35.83853735242571, 36.437749998910085, 37.39624009813581, 33.97622905458723, 35.80194466454642, 34.27842705590384, 34.294373171670095, 37.55830683026995, 37.622403962271555, 38.20875549316406, 39.17194257463728, 39.08440569468907, 38.4708936555045, 37.178723267146516, 35.28491531099592, 34.747357504708425, 35.71090589250837, 36.00873695101057, 33.962443828582764, 34.16650199890137, 35.94070713860648, 35.846465247017996, 35.00664690562657, 35.24455322538103, 35.96612364905221, 36.747632707868306, 36.101061139787944, 36.09592294692993, 34.67042704990932, 35.658297606876914, 35.01210124152047, 35.731521197727744, 40.87102031707764, 41.45993225915091, 38.03805215018136, 38.09431171417236, 36.98703636441912, 36.14891685758318, 39.82841532570975, 41.378944056374685, 39.85555498940604, 38.47510078975132, 39.76567309243338, 37.39082397733416, 37.5249137878418, 35.02389580862862, 38.23704160962786, 41.4988317489624, 41.40731702532087, 42.11190952573504, 40.89604425430298, 42.06859792981829, 40.137710911887034, 50.11664424623762, 54.72085414613996, 56.667068890162874, 56.85892602375576, 52.940447739192415, 52.987243856702534, 52.81257656642369, 53.00997836249215, 51.766504423958914, 51.75579030173165, 51.68360199247088, 52.69901520865304, 52.218067850385395, 55.38058907645089, 58.47957597460066, 60.8895378112793, 63.27415956769671, 54.527082783835276, 59.98140825544085, 65.60997022901262, 58.63452080317906, 67.54899706159318, 57.61257628032139, 57.63665178843907, 22.825860704694474, 0.69037491189582, 1.3284835198095866, 0.3681858032941818, 0.19263097564024584, 6.073743479592459, 63.177371161324636, 60.60195187159947, 60.78281348092215, 51.09814330509731, 55.995702675410676, 14.893621751240321, 21.595306941441127, 39.05135658809117, 61.09318951198033, 24.459533316748484, 0.4967370852828026, 0.03446797760469573, 0.08729316374020916, 0.056857757070767026, 0.0381898982450366, 0.03858653589018753, 0.04773981383602534, 0.018165809069094912, 0.07998879533261061, 0.0348896497993597, 0.03007157958511795, 0.03228158510423132, 0.07047625005777393, 1.0527734628745486, 40.07337406703404, 55.05530915941511, 46.091215814862935, 34.03025824683053, 32.117106505802695, 43.77079541342599, 60.034881591796875, 63.896071978977744, 73.01283809116909, 6.223272621631622, 0.1746779297079359, 0.5832489430904388, 11.976514373506818, 74.09302588871547, 69.58878667013985, 71.14833763667515, 63.41168526240757, 64.12639781406948, 56.43129219327654, 57.05108887808663, 54.768779345921104, 58.16755322047642, 58.12135117394583, 62.52829129355294, 52.966319356645855, 54.89953749520438, 61.855059487479075, 62.64632729121617, 61.340531485421316, 60.75732748849051, 60.22588062286377, 63.533438546316965, 59.191245215279714, 60.173164640154155, 57.85293184007917, 58.04843330383301, 60.169391768319265, 57.987799848829, 48.60384770802089, 42.84822402681623, 43.900382791246685, 44.407830578940256, 43.44079419544765, 44.8953092438834, 45.45773465292794, 44.39944757734026, 44.90767356327602, 41.62263127735683, 43.39043365206037, 43.01541158131191, 42.992124693734304, 44.6576634815761, 41.22153261729649, 43.266179016658235, 47.18859345572335, 41.06990555354527, 39.19056027276175, 38.75425509044102, 37.84938423974173, 39.572669506073, 42.82858146939959, 41.85739006314959, 38.74440949303763, 39.645417145320344, 38.56841162272862, 36.70387295314244, 37.69081939969744, 37.76496710096087, 37.82837636130196, 36.38443299702236, 38.70248058864048, 37.802216393607004, 36.773931639535085, 37.913290296282085, 36.43779168810163, 36.36072574343, 39.19202286856515, 39.75537586212158, 40.22230870383126, 41.02775778089251, 40.354338373456685, 41.19202709197998, 38.53550148010254, 37.842297077178955, 36.84206567491804, 36.96187693732125, 36.979136262621196, 35.32008361816406, 36.951016902923584, 37.0470757484436, 38.487836837768555, 37.25748804637364, 39.40287985120501, 38.44901030404227, 39.40802846636091, 38.211242948259624, 38.607057503291536, 37.74308722359793, 38.52271679469517, 37.19907454081944, 38.1414726121085, 44.46025473730904, 43.784525053841726, 37.73685816356114, 38.31268317358834, 37.35180984224592, 37.28654888698033, 39.29148285729544, 42.47958040237427, 41.033844402858186, 39.7401454108102, 42.872879709516255, 38.28997993469238, 39.90826402391706, 38.01148918696812, 41.56787947246006, 42.99418136051723, 42.188638482775005, 42.76126732145037, 43.34919956752232, 43.54399231501988, 43.08034944534302, 51.734639985220774, 56.67161301204136, 57.59305531638009, 58.84106295449393, 55.15449122020176, 54.20288331168038, 54.05046762738909, 54.789464133126394, 55.61104345321655, 54.95928852898734, 53.97563552856445, 53.67080415998186, 54.64828021185738, 58.11172097069876, 59.75845445905413, 62.912971360342844, 65.41421168191093, 57.81511279514858, 58.14967550550188, 65.98494366237095, 63.06471306937081, 68.38981941768101, 61.1627687726702, 61.13645594460623, 27.05199827466692, 1.0579782064471925, 2.0081134225640977, 0.18214444762894086, 0.14238133201641695, 6.10089921099799, 69.80488954271588, 65.38737079075405, 67.38446371895927, 52.63216311591012, 38.608565262385774, 15.975272144590106, 28.284601756504603, 44.11712489809309, 68.55435276031494, 31.844869136810303, 0.41508386390549795, 0.018200387213645235, 0.027748192560725977, 0.044766090012022426, 0.01882813049347273, 0.010736149170302918, 0.1391484790614673, 0.12985687835940293, 0.15609224486563886, 0.30455346778035164, 0.12957920825907163, 0.14841726741620473, 0.13197335121887072, 2.2116832648004805, 57.13729517800467, 66.59650325775146, 56.106554235730854, 39.49733713694981, 41.88355003084455, 51.7740466935294, 69.23640183040074, 68.47200271061489, 80.5855963570731, 7.799180081912449, 0.5922367636646543, 1.745742169874055, 16.324624095644268, 74.44519533429826, 73.8937793459211, 73.7595123563494, 66.82711396898542, 68.18564660208565, 59.96221038273403, 61.60887091500418, 58.37108680180141, 62.00033242361886, 61.4938017981393, 64.35289519173759, 57.90497037342617, 58.88170991625105, 63.574870654514854, 66.46611336299351, 64.41752733503068, 64.03652286529541, 63.38059902191162, 64.1327484675816, 62.291038104466026, 62.21067523956299, 59.313158307756694, 61.139624323163716, 61.410152435302734, 59.311178071158274, 51.22426005772182, 44.41210719517299, 45.84326239994594, 47.18952451433454, 45.16130018234253, 47.36962182181222, 47.98203257152012, 47.17153910228184, 47.596511772700715, 44.926214831215994, 44.91575084413801, 45.87577302115304, 43.489108494349885, 45.82848705564226, 44.18314320700509, 46.12363958358765, 48.67091519492013, 41.67551054273333, 39.281599044799805, 39.62212678364345, 37.567631312779014, 40.49406317302159, 42.23528173991612, 44.54404306411743, 42.330704825265066, 42.86608784539359, 41.198308263506206, 40.685562474387034, 41.255967889513286, 39.580402851104736, 40.46330002376011, 40.07023000717163, 40.35285145895821, 41.18051045281546, 39.16963577270508, 40.69662053244454, 38.45211614881243, 39.7032504762922, 41.65934903281075, 42.03742136274065, 42.92514753341675, 44.099358354296, 41.591583251953125, 44.32529987607683, 41.9034983089992, 39.89479146684919, 39.99341767174857, 40.308494159153526, 41.625737122126985, 37.590007986341206, 40.12918199811663, 40.44900063105992, 40.65677261352539, 40.111762864249094, 42.03084489277431, 41.228699684143066, 42.01372453144619, 41.4138240133013, 41.928407600947786, 40.24462979180472, 40.24555737631661, 39.50481339863369, 42.380009242466514, 47.02713469096592, 44.33138997214181, 37.988525390625, 38.19557128633772, 39.33137593950544, 37.820222650255474, 40.584514822278706, 43.91018322535923, 43.42357308523995, 40.932331221444265, 44.969203335898264, 41.43315390178135, 42.719460010528564, 39.978607586451936, 43.47530937194824, 46.238065992082866, 44.927399499075754, 45.574019704546245, 45.608989988054546, 44.831684589385986, 45.75184842518398, 54.05496311187744, 58.40025533948626, 60.137756620134624, 63.81964874267578, 57.76861892427717, 57.5424793788365, 59.23307337079729, 59.10123825073242, 57.78518690381731, 56.5274726322719, 54.93755108969552, 57.15461008889334, 56.78360407693045, 61.725711822509766, 60.98108727591378, 66.3783437183925, 66.96285397665841, 62.92416490827288, 65.20023495810372, 66.15143639700753, 66.37161786215646, 72.21665791102818, 65.19750431605748, 63.38308647700718, 29.5742221559797, 1.2593694627285004, 4.054719865322113, 1.4550554880074091, 0.18590631362582954, 7.832660845347813, 76.14291817801339, 69.4552422932216, 74.98401423863002, 65.55551719665527, 72.38633986881801, 22.829181943620952, 35.00649404525757, 53.38065780912127, 77.04094505310059, 43.84141342980521, 0.5081055866820472, 0.12298912688025407, 0.19803858761276516, 0.12608768418431282, 0.12151221398796354, 0.10322652983346156], [0.03975034558347293, 0.00632090526466657, 0.05105363637475031, 0.06963499555630343, 0.14973051766199724, 0.05632778050910149, 0.33569103266511646, 4.526993266173771, 41.919875213078086, 40.096560205732075, 37.54609537124634, 22.268015895571025, 21.47349807194301, 47.81454277038574, 51.09586777005877, 61.05549553462437, 57.39987107685634, 3.364882516009467, 0.03154126607945987, 0.5671764026795114, 7.155022578580039, 74.066025188991, 59.398259844098774, 69.2348106929234, 56.80944095339094, 64.39967741285051, 56.15556335449219, 59.01804746900286, 52.48359325953892, 52.18117986406599, 51.53798164640154, 55.094681126730784, 55.97612612588065, 61.70017719268799, 54.451705251421245, 60.050556727818076, 56.45103897367205, 61.76584461757115, 56.709432056971956, 59.74935926709856, 56.620376995631624, 58.921015875680105, 53.87527922221592, 56.3693733215332, 55.93378380366734, 50.13832262584141, 40.979262828826904, 44.874815532139365, 42.24077776500157, 43.5040853364127, 43.039897033146445, 43.10766976220267, 41.02181012289864, 43.08139514923096, 42.365032400403706, 42.05333273751395, 40.53793062482561, 40.967162540980745, 40.90132488523211, 41.89364228929792, 40.47125571114676, 42.74016216823033, 44.66809967585972, 41.5365708896092, 37.67107956750052, 40.486771038600374, 37.54364613124302, 36.9046550478254, 36.94063629422869, 39.167144843510215, 37.09961802618844, 38.24109240940639, 34.75412852423531, 35.95117459978376, 35.57519367762974, 36.26532350267683, 35.61639302117484, 36.31037562234061, 37.04921579360962, 36.59127739497593, 35.92775569643293, 35.19024610519409, 36.5710894039699, 37.25448989868164, 37.21134505953108, 37.4144652230399, 37.06410925728934, 38.97096940449306, 38.962763581957134, 37.66100467954363, 37.145417077200754, 37.47636672428676, 36.17106771469116, 34.064488547188894, 35.07276596341814, 35.433749198913574, 35.16156741550991, 35.99977377482823, 33.90819229398455, 35.60878126961844, 35.412164619990754, 35.949520928519114, 36.11701767785208, 35.8847393989563, 35.07920346941267, 35.05920655386788, 34.738105978284565, 35.79966565540859, 41.14515454428536, 41.262731960841585, 37.563465867723735, 36.805427823747905, 36.8588490486145, 37.431029728480745, 35.25110190255301, 37.31414018358503, 41.54782697132656, 40.60614456449236, 37.66469764709473, 40.995111669812886, 35.880782399858745, 37.17327240535191, 36.62948553902762, 39.49238307135445, 40.07721989495413, 40.98745128086635, 41.188969884599956, 41.654551301683696, 40.158513818468364, 43.779147148132324, 51.608241830553325, 54.601081098829, 54.12282964161464, 51.21467154366629, 55.001366819654194, 55.27627577100481, 55.31094380787441, 53.438574518476216, 53.824783188956125, 57.76673943655831, 55.79071692058018, 57.378116267068044, 57.94033670425415, 57.25224617549351, 57.365658146994456, 58.49142960139683, 60.15858037131173, 57.949824469430105, 46.21024887902396, 58.78549126216343, 60.09984030042376, 59.13785525730678, 60.48976625714983, 59.630065645490376, 45.366070543016704, 3.0892641970089505, 1.660935280578477, 0.25457770803144997, 0.13052345759102277, 1.4759404701845986, 53.064497402736116, 59.73847838810512, 63.641364915030344, 46.36963013240269, 72.3221663066319, 47.020679814474924, 15.453981808253697, 36.68225710732596, 53.91797590255737, 38.3130271094186, 0.5282237157225609, 0.07033014111220837, 0.09247239439615182, 0.07889988233468362, 0.07169561141303607, 0.05757919925131968, 0.10622580389359168, 0.014117976184934378, 0.04948914496760283, 0.056506839115172625, 0.14914245850273541, 0.20182391735059874, 0.33402615200195995, 5.295269046510969, 54.03136008126395, 51.3973640033177, 44.785968916756765, 29.597790445600236, 27.170697825295584, 46.761418206351145, 60.3682770047869, 66.0868945802961, 65.96648229871477, 3.36626564179148, 0.04811118283708181, 0.5867329218557903, 8.894251789365496, 77.26512173243931, 63.198514529636924, 70.26793139321464, 60.96594020298549, 66.4362986428397, 59.92389801570347, 61.32653086526053, 53.66602379935128, 54.65756300517491, 53.76951721736363, 57.78200462886265, 56.617052282605854, 62.28791836329869, 56.37576566423689, 61.6714255469186, 59.203439303806846, 63.84247357504708, 58.843494824000764, 62.66580309186663, 59.39315986633301, 60.24579416002546, 57.06321695872715, 57.87555170059204, 56.116688183375764, 53.87840243748256, 44.437207562582834, 45.40981640134539, 43.85200943265642, 43.960203307015554, 43.72151184082031, 44.990718432835166, 42.3432046345302, 44.79568944658552, 45.36461836951119, 44.63784721919468, 41.043346064431326, 42.1278452192034, 42.18000187192644, 43.52103894097464, 41.79187202453613, 43.05581188201904, 45.72036613736834, 42.32073763438633, 37.94928196498326, 39.73162691933768, 37.61708511625017, 36.61470324652535, 37.7102952003479, 39.16707188742501, 38.43153558458601, 40.67689459664481, 37.048670360020225, 38.22638654708862, 37.456755433763774, 37.85519988196236, 38.318193095070974, 38.03165980747768, 37.9470203263419, 39.63161454881941, 37.02882283074515, 38.32640586580549, 38.61051423209054, 39.10008430480957, 40.34395081656319, 39.69866466522217, 40.404622486659456, 40.60425118037632, 40.55071183613369, 39.94467258453369, 38.73696797234671, 40.16407585144043, 37.652468817574636, 36.218662875039236, 37.783504894801546, 37.29129103251866, 37.1969553402492, 38.24713386808123, 36.00784410749163, 37.64997441428048, 37.03823069163731, 38.375758920397075, 40.27343354906355, 38.932358264923096, 39.3557710647583, 38.01480695179531, 37.114938804081504, 39.14276014055525, 42.71955033711025, 42.20033230100359, 38.0952844619751, 37.09281921386719, 37.97649111066546, 37.40899004255022, 35.35012068067278, 38.043152127947124, 42.418849672589985, 41.78231130327497, 39.214531557900564, 42.32445839473179, 38.93579067502703, 39.53320026397705, 39.43569619315011, 42.6877692767552, 41.69146013259888, 42.88008846555437, 43.767005171094624, 42.6533340045384, 43.03983449935913, 44.02587420599801, 54.79770817075457, 57.520241669246126, 57.15054191861834, 55.27026210512434, 57.48307228088379, 56.67538935797555, 56.62812423706055, 55.09809616633824, 56.398152760096956, 60.15867069789341, 57.26606266839163, 59.009674889700754, 59.218308448791504, 58.311207226344514, 60.617119789123535, 60.51849705832345, 61.427175521850586, 59.70410564967564, 48.4813231740679, 59.239618573869976, 62.79249654497419, 63.43199484688895, 64.47036143711635, 62.55819634028843, 49.617940766470774, 3.8939802391188483, 1.434175934110369, 0.3258183210023812, 0.09609282655375344, 1.464436641761235, 59.958694594247, 65.65138844081334, 67.93132168906075, 51.3474029813494, 59.29464135851179, 33.922460419791086, 20.36067111151559, 44.86284031186785, 61.14828872680664, 47.265166078295024, 0.5483847824590546, 0.06186662454690252, 0.07284442548240934, 0.03357212817562478, 0.02852302018020834, 0.062034874090126584, 0.16297168071780885, 0.20580161176621914, 0.17221885094685213, 0.15089663437434606, 0.2786310144833156, 0.2579931819013187, 0.40221327596477097, 6.4829563328198025, 68.48589215959821, 57.61886092594692, 56.79868514197213, 35.043569632938926, 36.90369619641985, 63.20492771693638, 67.75947189331055, 71.66473470415387, 71.17787442888532, 4.585415022713797, 0.1444481768246208, 0.9626416478838239, 9.155059371675764, 79.96925640106201, 63.99948896680559, 74.84101336342948, 63.47100898197719, 68.44876098632812, 62.11961909702846, 64.90651375906808, 57.101970536368235, 58.590920857020784, 56.70285211290632, 59.56154945918492, 60.6793270111084, 64.53928061894008, 59.77894469669887, 65.79400716509137, 60.720759119306294, 67.32016508919853, 60.5693370274135, 65.12433978489467, 61.89053698948452, 63.25708784375872, 58.445189339774, 60.74420928955078, 59.39841270446777, 55.782427719661165, 46.80653633390154, 48.52237660544259, 46.15880789075579, 46.57547746385847, 45.65402126312256, 47.657131331307546, 46.01532758985247, 46.62442752293178, 46.579833984375, 45.93328673498971, 42.20445258276803, 44.595539637974326, 44.738755907331196, 46.35478183201381, 43.77924789701189, 45.47573743547712, 47.636342321123394, 44.66238130841936, 37.96422406605312, 40.38474716459002, 37.991162231990266, 36.91782188415527, 36.61348383767264, 38.396433285304475, 37.42382097244263, 44.837187562670024, 39.41781152997698, 40.42184707096645, 40.20057126453945, 40.74977077756609, 41.08162021636963, 41.61002377101353, 42.47665868486677, 41.89001880373274, 40.3360333442688, 42.00125598907471, 41.452810355595176, 41.7022020476205, 42.04321616036551, 41.61779533113752, 42.710576738630024, 42.999232700892854, 43.53475815909249, 42.46729598726545, 40.64110442570278, 43.609048298427034, 41.69172069004604, 38.95331403187343, 40.28848682131086, 39.29258067267281, 41.71406609671456, 41.46190554755074, 38.41662127631051, 39.43145431791033, 39.27379969188145, 40.37665251323155, 42.01511069706508, 41.68612739018032, 40.72084542683193, 39.76539863858904, 40.16765069961548, 41.13201550074986, 45.458992276872905, 41.810635634831016, 38.491668769291465, 37.18911082404, 39.70383412497384, 37.10969638824463, 36.172665800367085, 38.80625540869576, 44.250130789620535, 43.721616063799175, 41.90545770100185, 44.577540329524446, 40.78206947871617, 41.82933323723929, 41.76619495664324, 45.50725099018642, 45.528314454214915, 45.85800647735596, 46.07606526783535, 45.239245074135916, 44.556369168417795, 45.79227304458618, 55.99669974190848, 60.02706486838204, 59.842993191310335, 56.831501483917236, 59.999438830784385, 58.96789537157331, 59.50400447845459, 57.835328578948975, 58.84307793208531, 62.453674588884624, 61.27694157191685, 61.1315644127982, 61.89092608860561, 60.16091496603829, 62.42363057817732, 62.715809277125764, 65.43495900290353, 61.14258425576346, 53.405386447906494, 59.66051265171596, 65.95803328922817, 63.9231630052839, 67.554520879473, 66.06006758553642, 55.05916888373238, 3.553640318768365, 3.1351663853440965, 1.1366959767682212, 0.26551767385431696, 1.9555507344858987, 67.325014931815, 70.92550890786308, 75.66994040352958, 58.440290859767366, 85.59932613372803, 59.83746937343052, 27.926621879850114, 52.770428793770925, 67.91445841108049, 61.82728058951241, 0.7166760148746627, 0.20182175960923943, 0.15074636600911617, 0.21538738454026835, 0.20190709217318467, 0.19339336401649884], [0.07921335194259882, 0.055090600824249644, 0.10767618606665305, 0.006125273440764951, 0.02746617135458759, 0.04820059000381401, 0.24840930902532168, 5.38853645324707, 53.559681619916645, 41.18969944545201, 38.938420568193706, 26.85826686450413, 36.97833374568394, 45.78126014981951, 52.55940852846418, 58.82757650102888, 60.31861128125872, 5.017865691866193, 0.08698120726538555, 0.27816632656114443, 17.73989745548793, 75.15579455239433, 56.93966061728341, 69.04322106497628, 58.2492675100054, 64.61930302211216, 56.536050183432444, 60.31548459189278, 52.443696703229634, 55.66670894622803, 48.72806760243007, 54.98018871034895, 53.32068790708269, 55.76102031980242, 55.25381571905953, 56.68004812513079, 54.84119694573538, 57.68268013000488, 56.266779695238384, 58.425428662981304, 53.1678865977696, 50.78505400248936, 49.743310587746755, 52.32662650517055, 45.95883526120867, 42.840848514011924, 40.92243351255144, 42.29144402912685, 41.39119373049055, 43.19270181655884, 40.8303872517177, 42.43701226370675, 41.17991638183594, 43.14921998977661, 41.57010637010847, 40.65544203349522, 39.011883871895925, 40.89866372517177, 40.14209869929722, 41.34705182484218, 40.252575056893484, 42.392033100128174, 43.88685117449079, 41.77394914627075, 40.36627885273525, 39.220277718135286, 39.33992917197091, 43.05028806413923, 40.59429093769619, 39.00152063369751, 36.584388256073, 40.17070095879691, 37.77978066035679, 36.47795922415597, 35.34177589416504, 34.93647357395717, 34.34508112498692, 36.89195374080113, 35.95210565839495, 37.5715639931815, 35.39642347608294, 37.56788839612688, 34.671681199754985, 37.71289382662092, 36.929553917476106, 40.01082290921892, 36.080463205065044, 38.188133239746094, 36.5538717678615, 35.39633662360055, 36.254411356789724, 37.90880175999233, 34.83065250941685, 35.042232104710166, 34.18736743927002, 34.4610778263637, 33.14367158072335, 35.97355474744524, 35.433808258601594, 36.46876675742013, 33.79407160622733, 35.88762984957014, 37.405887671879356, 36.31456191199166, 36.78478125163487, 37.611641202654155, 38.66187531607491, 41.862635953085764, 36.374740259987966, 36.782248633248464, 39.7095559665135, 38.48454686573574, 35.21441193989345, 36.81088215964181, 33.9230614389692, 39.86179794584002, 41.012089593069895, 39.611082621983115, 37.56250006811959, 37.59594522203718, 35.61876583099365, 36.589040075029644, 34.34177725655692, 37.88739436013358, 40.275069849831716, 41.174743447984966, 40.35886859893799, 39.572415896824424, 39.604103156498496, 46.22002499444144, 53.07378019605364, 54.63447414125715, 49.46377413613455, 49.072729519435335, 56.6853461265564, 55.39677837916783, 57.417460441589355, 55.435219287872314, 55.812002726963584, 57.20926809310913, 55.598352568490164, 56.52199050358364, 57.680571351732524, 54.73109926496233, 57.75085932867867, 59.32403918675014, 60.22727721078055, 58.654448236737935, 54.728872367313926, 57.11294174194336, 62.843065534319194, 59.31966182163784, 60.61782850537981, 57.76886558532715, 64.19721385410854, 12.776847839355469, 0.7633632410849843, 0.09661414500858102, 0.03479485506457942, 0.09676137353692736, 44.24511071613857, 62.70831911904471, 61.48574883597237, 54.86925029754639, 64.44754355294364, 45.387404986790244, 18.309357915605815, 36.83245284216744, 55.29524782725743, 53.90534060341971, 1.1031202184302467, 0.09812760379697595, 0.15535748643534525, 0.07371192571840116, 0.06212079019418784, 0.12200819594519478, 0.05606272437476686, 0.08075307003621544, 0.048708772020680566, 0.06832587080342428, 0.0682718933426908, 0.101997329720429, 0.2394756626869951, 7.878288796969822, 63.904451506478445, 49.50192322049822, 49.26414196831839, 33.719913482666016, 40.91436665398734, 49.91064058031355, 60.53117752075195, 64.26283958980015, 66.20500005994523, 4.607908078602382, 0.14996216951736382, 0.4059252424963883, 21.330667427607946, 78.96631867544991, 60.578522545950754, 70.86997195652553, 61.652144295828684, 66.75387995583671, 58.81253365107945, 62.350730078560964, 55.75600372041975, 57.00428581237793, 52.380249227796284, 57.4496306010655, 56.902595451899934, 57.41822126933506, 58.10280990600586, 59.77398368290493, 55.44721187864031, 59.319592339651926, 57.9838775907244, 59.153342791966026, 56.129361697605674, 54.91630697250366, 53.292881216321675, 55.01408897127424, 49.24375247955322, 44.33245652062552, 43.41619757243565, 45.80887229101998, 44.104336738586426, 46.206371784210205, 42.71761873790196, 43.393588134220664, 43.71664810180664, 43.97700752530779, 44.1016651562282, 42.30880757740566, 41.827127184186665, 43.34457554136004, 40.96994529451643, 42.86372198377337, 41.32396296092442, 45.21931069237845, 45.142918722970144, 43.385760988507954, 40.823605809892925, 38.235023157937185, 40.086527006966726, 43.74090426308768, 40.7915746143886, 39.34545298985073, 37.56568234307425, 42.141439369746614, 40.10252870832171, 37.673219612666536, 36.239062786102295, 37.21869625364031, 36.710466793605256, 37.53179250444685, 38.19140236718314, 39.331608704158235, 38.073894432612825, 38.49016101019723, 36.42859922136579, 39.852869510650635, 39.290412834712434, 41.50749962670462, 39.545276233128135, 40.323408467429026, 38.957507269723074, 37.124569007328574, 40.6003532409668, 39.65990761348179, 38.45073693139212, 37.945825236184255, 36.5559527533395, 38.487975801740376, 36.3414305959429, 37.94926806858608, 37.8709306035723, 37.392554078783306, 36.635631220681326, 38.545426981789724, 39.31594399043492, 39.24372788837978, 37.88057817731585, 40.038813727242605, 41.50253166471209, 42.73869262422834, 36.72174024581909, 36.47754233224051, 40.63946465083531, 36.86066252844674, 35.32903984614781, 37.50593130929129, 35.65390287126814, 39.65345968518938, 41.62566416604178, 42.7061368397304, 40.2511020387922, 40.244351863861084, 38.19250018256051, 38.79982485089983, 36.652678625924246, 39.887676511492046, 42.45817647661482, 42.28095572335379, 42.49173280170986, 42.145358153751914, 42.41582720620291, 48.69374350139073, 54.64987134933472, 56.77476944242205, 50.511750085013254, 52.22328247342791, 56.602353368486675, 55.743111337934224, 57.87431492124285, 59.34923335484096, 58.41463811056954, 59.30607809339251, 58.13014759336199, 58.9393869127546, 59.69571222577776, 57.62927974973406, 61.92324216025216, 63.056889397757395, 61.58508723122733, 60.38095051901681, 57.828005177634104, 59.699943678719656, 64.26097747257778, 60.11855179922921, 63.87480354309082, 60.86576802389962, 68.78163528442383, 14.805796521050588, 0.7886627178106989, 0.41245752626231735, 0.014708109965015734, 0.19363689023469174, 49.10754346847534, 69.19130802154541, 66.10612024579729, 58.158072403499055, 66.31328773498535, 39.11677735192435, 22.881406341280254, 44.13020488194057, 58.41247722080776, 64.96003573281425, 1.2614058277436664, 0.048254961014858315, 0.052146267744579484, 0.057517289716218195, 0.030409076118043492, 0.20368117626224244, 0.19620961004069873, 0.16986817494034767, 0.2721346930733749, 0.20504598159875187, 0.12620277729417595, 0.18007521437747137, 0.4564802540200097, 9.364773375647408, 80.2786179951259, 57.76411649159023, 59.464365005493164, 36.592198031289236, 51.43369960784912, 62.18616199493408, 67.35011182512555, 68.99297864096505, 76.09482274736676, 6.543389592851911, 0.24478682769196375, 1.212679413812501, 23.65920158794948, 81.3886205128261, 62.995008741106304, 74.04547241755894, 64.14727715083531, 69.28873566218785, 61.37740557534354, 63.90989194597517, 59.064579554966514, 60.03974533081055, 54.46668209348406, 59.654683113098145, 59.530240876334055, 60.41491331372942, 61.55618967328753, 61.130438804626465, 57.5499313218253, 60.72802693503243, 59.700791358947754, 63.19752093723842, 57.509273937770296, 56.28831216267177, 55.51211152757917, 56.675465788160054, 52.12188046319144, 46.104618889944895, 45.17652368545532, 47.77133887154715, 45.779780183519634, 48.23967524937221, 45.591060161590576, 46.61417893001011, 46.28520951952253, 47.13518612725394, 45.90761661529541, 43.69706112997872, 43.69402476719448, 45.61742510114397, 42.89786890574864, 44.89035865238735, 43.83753980909075, 48.20848478589739, 48.16659757069179, 44.63311897005354, 42.029225962502615, 39.08167157854353, 40.47679342542376, 45.72269378389631, 41.05230924061367, 40.65478890282767, 38.71388258252825, 43.49368040902274, 42.179602350507466, 39.17740385872977, 38.596614360809326, 39.44097682407924, 38.2186393056597, 41.314603737422395, 40.86106007439749, 44.34501886367798, 40.60767664228167, 42.55362388065883, 39.08441959108625, 43.0986544745309, 42.36858640398298, 45.30611801147461, 41.48683568409511, 43.180952412741526, 42.03022650309971, 39.44330447060721, 43.08841977800642, 43.45301955086844, 40.76297582898821, 40.648476464407786, 38.44487265178135, 40.79601798738752, 39.822026457105366, 41.77451542445591, 40.0852381161281, 42.39736931664603, 39.26583010809762, 40.18296800340925, 42.1810371535165, 41.181722913469585, 41.51335348401751, 42.62805298396519, 43.65035881314959, 43.058813503810335, 36.88408143179757, 36.22762952532087, 41.44591079439436, 39.334061418260845, 35.49743986129761, 36.746361187526155, 36.41843400682722, 41.08833565030779, 43.81103590556553, 43.592963218688965, 42.69753149577549, 41.648402145930696, 40.6403158051627, 41.907743658338276, 38.52966846738543, 42.52802324295044, 43.758900097438264, 44.73778315952846, 44.93684210096087, 43.10417481831142, 44.79076664788382, 50.71398087910244, 59.03189522879464, 59.6332687650408, 55.868696553366526, 56.6782728603908, 59.87400994982038, 58.624126298086985, 62.416029248918804, 61.82687064579555, 60.15754508972168, 62.09466116768973, 62.108001708984375, 61.03714534214565, 61.07925837380545, 58.50658362252371, 65.54214886256626, 63.99438898903983, 64.79854570116315, 63.08684308188302, 61.02914101736886, 62.210466793605256, 67.44691412789481, 63.21643393380301, 67.83699989318848, 64.12933690207345, 73.51702717372349, 15.765446969441005, 1.7963988802262714, 1.0419045260974338, 0.08536134061536618, 0.28470919547336443, 54.2643574987139, 76.19655132293701, 73.97545542035783, 67.85479422977993, 75.95521259307861, 56.873569352286204, 29.94579792022705, 52.26336315699986, 67.86834321703229, 78.26104872567313, 2.4551811473710194, 0.24041907063552312, 0.22642849279301508, 0.13504045163946493, 0.19047343784144946, 0.3757173791527748], [0.04372743610292673, 0.07636763714253902, 0.07075787601726395, 0.05172236316970416, 0.06849099908556257, 0.08567677797483546, 0.14396869683904306, 9.74597065789359, 56.545663016183035, 42.22924722943987, 31.326307705470494, 38.80923618589129, 42.01416574205671, 30.947759423937114, 54.577485016414094, 59.3219964163644, 48.29984317507063, 0.8142413167016846, 0.1346617341041565, 0.5710746677858489, 22.980025597981044, 74.13010842459542, 61.596517017909456, 66.44386523110526, 58.83280154636928, 64.64736679622105, 57.09627996172224, 58.57879625047956, 54.94596535818917, 51.57712779726301, 49.03059911727905, 53.35708257130214, 50.61507327216012, 57.2724689074925, 52.91918625150408, 55.131124428340364, 54.36219160897391, 54.24493728365217, 52.16726262228829, 51.111157281058176, 48.87791245324271, 49.7760192326137, 48.19607182911464, 45.98601313999721, 42.4833220073155, 42.21882493155343, 40.28684704644339, 42.806687695639475, 41.999272278376985, 41.341976165771484, 42.06594371795654, 40.07612902777535, 39.15188659940447, 40.52415234701974, 39.305841309683665, 41.19971527372088, 40.05694852556501, 41.56777177538191, 39.59059585843767, 40.236924239567344, 41.15239804131644, 39.813886642456055, 42.20008563995361, 45.834670952388215, 41.053309781210764, 38.553643226623535, 40.89877837044852, 46.65620163508824, 45.84512104306902, 45.12737560272217, 41.18146930422102, 41.31038270677839, 41.67844615663801, 37.06388691493443, 35.66472816467285, 34.33784457615444, 35.04000868116106, 35.12125744138445, 34.855884892599924, 35.30371018818447, 33.219069957733154, 36.661999634334016, 36.58876214708601, 38.47260291235787, 39.06713942119053, 38.916502475738525, 38.32678801672799, 38.237604413713726, 36.56490550722395, 37.42380012784685, 38.141090461185996, 38.08525473730904, 35.023520605904714, 35.422242982046946, 36.309548786708284, 35.888029370989116, 35.15806899751936, 36.6554787499564, 34.328975200653076, 36.42032044274466, 34.7338502066476, 36.99618714196341, 36.68511629104614, 36.13855709348406, 36.304302896772114, 40.7401579448155, 39.750515597207205, 42.30772713252476, 36.971538407461985, 40.788611207689556, 42.07868324007307, 39.91258927753994, 36.89855800356184, 35.41583674294608, 33.161253997257774, 36.65630211148943, 40.020727566310335, 38.91032900129046, 38.493676798684255, 37.820712498256135, 37.48611157281058, 37.625085966927664, 35.08442851475307, 36.97570732661656, 38.335619177137104, 39.18532133102417, 39.81919159208025, 40.61569138935634, 42.717993940625874, 46.696091243198936, 50.071432318006245, 52.23562247412545, 47.27287857873099, 46.9832672391619, 54.86481039864676, 52.51401594706944, 53.420359815870015, 53.22138772691999, 55.73024327414376, 55.71118089130947, 55.644856861659456, 56.86731249945504, 58.19998741149902, 56.71031795229231, 57.19059828349522, 58.195425919124055, 56.959810393197195, 58.665252685546875, 62.02353245871407, 61.10281276702881, 60.008805002485005, 56.89957645961216, 61.86876828329903, 56.96020644051688, 66.44771453312465, 28.947732618876866, 0.36631643931780544, 0.4573265771780695, 0.05197202334446566, 0.026934355963021517, 34.8404529435294, 68.21564197540283, 58.07537146977016, 59.91273920876639, 41.840915884290425, 32.66747331619263, 17.69617244175502, 36.942870140075684, 55.093131678445, 58.47702598571777, 2.136605156319482, 0.2429544845862048, 0.06851646450481244, 0.030274444592318366, 0.06396808142640761, 0.09753671514668635, 0.02122287904577596, 0.10411758201995067, 0.1166675825204168, 0.06598084699362516, 0.03433348178597433, 0.1737970555467265, 0.19903266855648585, 11.40143368925367, 69.23584597451347, 50.06009285790579, 38.7880893434797, 35.28768764223371, 34.68231194359915, 39.38207694462368, 61.70851503099714, 64.88987977164132, 56.38947793415615, 0.8308565765619278, 0.012963139269101833, 0.3428542454327856, 24.388632161276682, 77.24757753099713, 64.48794732775006, 69.36183765956334, 60.31237874712263, 66.54745592389787, 60.20270143236433, 61.549095562526155, 56.19401815959385, 54.83129228864397, 51.4241076196943, 54.477809633527485, 53.07178258895874, 58.19673565455845, 55.06621435710362, 56.02728223800659, 56.4400121825082, 56.05468940734863, 54.30026578903198, 55.37459972926548, 50.88660192489624, 51.332103048052105, 48.8760781288147, 46.770669732775005, 44.540864263262065, 43.510376930236816, 42.523242882319856, 43.40945087160383, 44.11970615386963, 43.49213790893555, 43.00782067435128, 41.47028507505144, 40.90731770651681, 43.38108485085623, 40.529238428388325, 43.71427876608712, 41.52414403642927, 42.15362998417446, 40.87579720360892, 43.6308274269104, 41.61447409221104, 41.73498364857265, 43.76646668570382, 46.00540208816528, 40.28817415237427, 38.7815580368042, 42.52814136232649, 48.2465991292681, 47.37793186732701, 45.354418413979666, 42.29318455287388, 41.41930614198957, 43.64241702216012, 38.844418389456614, 37.77269002369472, 37.510857582092285, 38.74982213973999, 38.56214434759957, 38.14174011775425, 36.967199257441926, 37.297721590314595, 38.60378837585449, 38.321597712380544, 39.28627865655081, 39.58615248543875, 40.76070029394967, 39.98116799763271, 40.44143056869507, 37.60848324639456, 39.73636906487601, 41.39046764373779, 40.2845367704119, 38.477914810180664, 39.88606800351824, 37.82059785297939, 39.06759105409895, 37.47824968610491, 39.20215681621006, 37.70044265474592, 38.1433937890189, 36.98733513695853, 38.87108210154942, 37.85633243833269, 37.197049140930176, 38.91746827534267, 41.36579459054129, 40.96129131317139, 41.65547888619559, 37.46914407185146, 42.28132050377982, 43.16409260886056, 39.29344572339739, 37.46806362697056, 35.38996165139334, 33.69307606560843, 36.91243355614798, 41.8118029321943, 41.151255062648225, 40.18056045259748, 39.66680370058332, 40.47509459086827, 37.9368759563991, 38.485915660858154, 38.38241529464722, 40.74260718481881, 42.330145495278494, 41.13108444213867, 42.229566846575054, 43.63424941471645, 47.93836661747524, 53.88118519101824, 54.51703568867275, 49.020329679761616, 50.77478109087263, 56.01376799174717, 55.094330242701936, 56.259716851370676, 53.81637586866106, 56.83515623637608, 57.897695609501426, 58.7331018447876, 58.20858580725533, 60.93912015642439, 57.38466147014073, 60.70020634787423, 59.77562345777239, 60.03736904689244, 60.80911936078753, 63.441298484802246, 62.52453926631382, 61.17205156598772, 59.08818258558001, 65.32011917659214, 60.31764548165457, 71.27446828569684, 32.230247497558594, 0.23003971044506344, 0.6957903813038553, 0.06259799708745309, 0.04171137964086873, 37.09077991758074, 74.97047219957624, 63.09336049216134, 65.10922745295933, 48.303226947784424, 34.35514211654663, 19.611175877707346, 46.12608882359096, 58.509835379464285, 70.38212503705705, 3.4669452565056935, 0.35524087505681173, 0.06549047652099814, 0.052273068976189406, 0.06961129432810204, 0.08542195414858204, 0.1458333246409893, 0.15096220799854823, 0.28260139429143494, 0.17443576055978025, 0.18047449152384484, 0.47917687041418894, 0.2788775126848902, 14.598563023975917, 80.6819817679269, 59.315972328186035, 48.19206619262695, 48.99585117612566, 56.698533807482036, 43.875035762786865, 71.73976135253906, 68.10802132742745, 65.86207866668701, 1.373309388756752, 0.19506416150501796, 0.8727221329297338, 26.457593781607493, 80.37857478005546, 68.27149854387555, 71.89841651916504, 62.80348859514509, 69.71638338906425, 64.10740143912179, 63.16406536102295, 59.92002092088972, 57.3736937386649, 53.56440986905779, 58.379542759486604, 55.61392000743321, 60.75820296151297, 58.16612883976528, 58.45070620945522, 58.1314503805978, 57.744004930768696, 57.79768671308245, 56.81993620736258, 54.449579102652415, 54.29926872253418, 52.31417185919625, 50.27444131033761, 47.43466738292149, 44.58760479518345, 44.47667680467878, 46.58673701967512, 45.56491756439209, 45.741158621651785, 45.93966170719692, 44.57951709202358, 42.66916200092861, 44.06678172520229, 41.54505116598946, 44.85007299695696, 44.22637837273734, 44.826004437037874, 44.782692841121126, 43.55964660644531, 44.94925158364432, 43.99894993645804, 45.435830456869944, 47.96409232275826, 40.79049069540841, 38.2479224886213, 43.36671250207083, 48.60252060209002, 50.57877588272095, 46.54545777184622, 41.654301166534424, 39.86670337404524, 45.41548613139561, 41.51432275772095, 38.47379452841622, 39.133803912571494, 40.846795422690256, 41.51615360804966, 40.015978472573416, 39.885032721928184, 39.988272530691965, 42.224373068128315, 40.83127662113735, 41.472782952444895, 43.562992164066856, 43.079703262874055, 44.22396387372698, 44.87566321236746, 42.089268820626394, 42.71790361404419, 42.64322784968785, 44.16435527801514, 40.849922112056184, 40.950792585100444, 42.339553356170654, 41.99379709788731, 40.85746438162667, 41.0957042149135, 39.84993389674595, 40.758167675563264, 38.380348205566406, 42.251846245356965, 39.926075731004985, 40.59076125281197, 40.922975472041536, 41.6612354687282, 40.95096629006522, 42.360734939575195, 39.44778953279768, 43.71123545510428, 44.38846247536795, 40.57717752456665, 38.32317842755999, 35.513893195560996, 34.893214089529856, 38.26711688722883, 45.89074986321585, 43.721452781132285, 44.40819535936628, 42.88861390522548, 42.546439443315776, 39.912217548915315, 39.57944747379848, 40.12734072549002, 42.361839703151155, 44.26916537966047, 43.45784160069057, 44.62026827675955, 47.01801865441458, 51.5194125856672, 57.0928510257176, 57.596063886369976, 53.33627271652222, 54.38336624417986, 58.43423897879464, 57.66121367045811, 57.02883379799979, 55.16804368155343, 59.23593602861677, 61.10929543631417, 61.58481625148228, 60.56906604766846, 62.28900228227888, 58.81327016013009, 62.879057203020366, 63.42087772914341, 61.85464954376221, 63.00866889953613, 66.90123040335519, 65.3037839617048, 63.58843353816441, 64.36298397609166, 68.32029574257987, 63.45023386819022, 71.92297840118408, 33.53252056666783, 1.3377814037459237, 1.3994517688240324, 0.6272293574043682, 0.22374438467834676, 41.675020694732666, 82.34031527382987, 68.44543974740165, 74.70564855848039, 56.28965663909912, 45.58964620317732, 27.54962478365217, 55.85020392281668, 67.06556919642857, 82.68197904314313, 6.798061481543949, 0.560480076287474, 0.17964271615658486, 0.15160767122038774, 0.1500333206994193, 0.32570682412811686], [0.08704972573156868, 0.04539429808833769, 0.013169462260391031, 0.17274737544357777, 0.06749191055340426, 0.24687267148068973, 0.25897350215486115, 12.372894338199071, 51.079470021384104, 39.10480213165283, 38.11281476702009, 45.441448075430735, 50.49634592873709, 33.08398655482701, 58.624418122427805, 58.6889043535505, 43.184450830732075, 0.17960477247834206, 0.10414500840540443, 0.39975621923804283, 29.85054506574358, 76.98394898005894, 61.321493421282085, 63.42784677233015, 58.31026921953474, 60.9525579724993, 55.76675953183855, 55.53848688943045, 52.69221639633179, 53.260638100760325, 52.2684839793614, 52.99285452706473, 55.64105272293091, 54.011790479932515, 56.5851183618818, 55.20640468597412, 56.63522529602051, 54.38815007890974, 52.71160534449986, 51.82186419623238, 47.826205321720664, 45.213105951036724, 44.4538380759103, 43.54338782174246, 41.241619859422954, 41.450315952301025, 40.72158193588257, 40.33263220105852, 39.83258424486433, 41.61096525192261, 41.0007084437779, 41.70023570741926, 41.63165351322719, 40.40047093800136, 40.90584468841553, 40.651974882398335, 38.66124997820173, 39.504142897469656, 39.75272512435913, 41.016539914267405, 41.14679779325213, 40.05041027069092, 43.27334608350481, 45.89595406396048, 41.30844415937151, 39.17479133605957, 41.810659953526084, 42.94952528817313, 44.901229109082905, 41.969575677599224, 42.08618034635271, 39.71933903012957, 41.74311998912266, 40.59675407409668, 37.062674454280305, 34.582824162074495, 33.219764777592246, 35.144766671316965, 34.062251227242605, 36.52003404072353, 33.76978417805263, 36.24949203218733, 37.36047771998814, 36.8044307572501, 37.11173915863037, 38.30809736251831, 36.38034050805228, 37.22721127101353, 36.13641357421875, 35.56928423472813, 36.754000731876914, 36.25764226913452, 36.29917860031128, 34.788758346012656, 35.94243376595633, 35.90217937741961, 34.936303343091694, 36.03905194146292, 35.10804891586304, 36.068897928510395, 36.76984262466431, 37.27535533905029, 35.53701332637242, 39.57276330675398, 39.844781807490754, 40.296112469264436, 41.580983775002615, 44.50750943592617, 41.87491341999599, 43.23849391937256, 41.347291537693565, 40.920533180236816, 35.99214117867606, 36.79379653930664, 34.63658932277134, 37.251696722848074, 40.48064272744315, 36.11580869129726, 38.273509229932515, 37.768601008823936, 37.25991644178118, 35.68679564339774, 36.9911983353751, 36.98588643755232, 39.53866154806954, 39.026857239859446, 40.92467778069632, 38.80059610094343, 40.07880408423287, 46.73960433687483, 50.52403450012207, 50.4051126071385, 45.684767041887554, 49.109561920166016, 53.047116483960835, 51.776631423405235, 53.25928667613438, 51.78352403640747, 54.99892105375017, 53.026817321777344, 57.528902598789756, 56.168139593941824, 57.50945806503296, 54.71078968048096, 57.296926566532676, 55.418283053806846, 58.6426362991333, 57.09122167314802, 60.058866773332866, 56.052135944366455, 57.726578848702566, 53.9187263080052, 58.2745554787772, 57.70839541299002, 65.92196519034249, 44.62235968453543, 0.8458385754908834, 0.6515783422759601, 0.12512781497623238, 0.10757802919085536, 25.615260192326136, 69.29059083121163, 58.96676976340157, 62.092284883771626, 40.97402388708932, 21.483510426112584, 18.84736040660313, 29.6423214503697, 48.13852684838431, 65.4728753226144, 10.399950742721558, 0.7290996653693063, 0.12886724860540458, 0.14967444352805614, 0.04822247615084052, 0.16864655406347343, 0.02245200112728136, 0.09334398619830608, 0.023019232654145787, 0.13616182575268404, 0.06836113426834345, 0.18679557447986944, 0.2978321984410286, 15.706180572509766, 64.5215071269444, 47.623585428510395, 45.86680637087141, 44.839254651750835, 48.75431442260742, 37.602664130074636, 66.02422182900565, 63.90625803811209, 50.265898500170024, 0.0910248417141182, 0.04944915889895388, 0.5958517811128071, 31.676229408809117, 77.62833881378174, 64.22476346152169, 66.24010930742536, 60.09251689910889, 61.48560292380196, 58.08381700515747, 56.9965489932469, 56.010022912706646, 54.866151400974815, 53.25015326908657, 53.96563012259347, 56.82192686625889, 56.32786478315081, 59.800762040274485, 56.95762865883963, 56.85068546022688, 57.076904909951345, 54.35896417072841, 52.86164474487305, 49.31942183630807, 46.40437807355608, 45.473371573856895, 45.02369805744716, 43.508660725184846, 43.95862259183611, 42.88887446267264, 44.05800267628261, 43.62456015178135, 42.74738482066563, 42.16600125176566, 42.5631012235369, 44.07072482790266, 41.199138573237825, 42.44667025974819, 42.57467344829014, 40.95835222516741, 40.3913687978472, 42.46352311543056, 42.57507644380842, 43.2333904675075, 41.668135029929026, 45.21266821452549, 46.069391523088726, 40.426686491285054, 39.10299212591988, 40.76842669078282, 43.43982492174421, 45.06238910130092, 43.59036111831665, 42.080736432756694, 38.71348653520857, 41.35332257407052, 41.26011596407209, 37.900634152548655, 37.23567417689732, 35.65167597361973, 38.364148480551584, 36.9629921231951, 39.784978662218364, 36.23486607415335, 38.78806849888393, 38.26785339627947, 39.570032664707725, 39.70007514953613, 40.09607383183071, 38.6327554157802, 41.585778032030376, 37.83305944715227, 38.2666027205331, 40.23524972370693, 39.773420333862305, 39.35867541176932, 37.652632100241526, 36.8613851411002, 37.52352067402431, 36.68052353177752, 39.06299134663173, 37.68863071714129, 39.08044522149222, 38.8817024230957, 39.31124700818743, 38.24192271913801, 40.69609941755022, 40.934644971575054, 40.411431721278596, 42.692594800676616, 45.228294713156565, 43.10066597802298, 43.65716804776873, 42.3953925541469, 41.46518857138497, 38.14108351298741, 36.64770718983242, 35.603778566632954, 37.26521096910749, 42.20186785289219, 37.52008478982108, 40.54225935254778, 39.70984084265572, 39.43451847348894, 37.65781545639038, 39.21039390563965, 39.34254516874041, 42.28849451882498, 39.97999027797154, 43.18157427651541, 40.691454546792166, 42.86933612823486, 48.94500425883702, 53.40451792308262, 52.315901960645405, 47.67787517820086, 50.796539374760215, 53.84577022280012, 53.83170706885201, 55.45956230163574, 53.22625841413225, 57.25977802276611, 55.926859923771445, 60.120684896196636, 57.034003257751465, 60.08110795702253, 56.70735107149397, 58.06621026992798, 57.10658066613333, 61.72217518942696, 58.4403394971575, 63.18398584638323, 58.50335965837751, 60.88875266483852, 55.82492637634277, 61.45949159349714, 61.302010672433035, 69.3622406550816, 48.65462514332363, 1.3902245610952377, 0.8229081087878772, 0.13495259492525033, 0.08578083810529538, 26.689509017126902, 75.94595759255546, 62.02413695199149, 70.1243816103254, 46.72470045089722, 26.428539889199392, 20.962213141577585, 39.1225061416626, 54.70005818775722, 76.08894457135881, 12.800855602536883, 0.7239800372294017, 0.1669863417212452, 0.17604672483035497, 0.06336450417126928, 0.14853633674127714, 0.1621745377779007, 0.15259750453489168, 0.12008558054055486, 0.28935371339321136, 0.15357672556170396, 0.5692767671176365, 0.4278775602579117, 19.079996517726354, 76.47531305040631, 57.26592023032052, 57.57711614881243, 57.74516180583409, 65.80716010502407, 48.19397347314017, 73.11638014657157, 70.50077942439488, 55.67412267412458, 0.2786012132252966, 0.1955509696687971, 0.962927826813289, 36.42322131565639, 80.56116649082729, 66.4208597455706, 67.27229894910539, 63.32593754359654, 65.12190791538784, 61.56199836730957, 59.18257386343819, 59.08286721365792, 57.02322312763759, 56.17412894112723, 56.96758542742048, 59.85054588317871, 57.798523971012656, 61.379837444850374, 59.05657523018973, 61.79080949510847, 59.1632022857666, 56.73793704169137, 56.82831573486328, 53.40803371156965, 48.59212957109724, 49.54852826254708, 46.86155564444405, 45.41153955459595, 45.86430501937866, 45.12984916142055, 46.014559813908164, 45.02857916695731, 45.72503880092076, 43.50812571389334, 44.20539133889334, 45.21282802309309, 44.52034970692226, 45.02651555197579, 45.10538455418178, 43.20877647399902, 42.440990107400076, 44.15155322211129, 44.88046441759382, 46.45239012581961, 44.065062046051025, 48.13336433683123, 48.43053184236799, 41.54382133483887, 39.5729787009103, 42.244231019701274, 44.42216123853411, 47.55194255283901, 45.18773807798113, 44.34738819939749, 40.62008612496512, 41.74325547899519, 42.243254797799246, 39.733106885637554, 38.85517767497471, 38.10939277921404, 39.19545875276838, 37.63133239746094, 42.14600781032017, 38.31419440678188, 42.866567271096365, 42.02947609765189, 42.36046395983015, 42.693949699401855, 42.07892642702375, 41.31234557288033, 43.215696879795615, 42.48090750830514, 40.34427738189697, 41.59716265542166, 41.693277086530415, 42.08789655140468, 39.443061283656526, 39.62235607419695, 41.49035494668143, 38.763398919786724, 42.18037707465035, 39.82792547770909, 41.04894631249564, 42.9560809135437, 43.12866374424526, 40.57302597590855, 43.19362245287214, 40.803101675851, 42.262838295527864, 43.36548267092024, 46.96003246307373, 44.80808850697109, 46.96792214257376, 43.73624897003174, 42.266388825007844, 37.820962633405415, 36.8854432787214, 35.709735121045796, 37.80627761568342, 46.17351722717285, 39.918769700186594, 43.34996734346662, 42.42191730226789, 42.848380361284526, 40.126433985573904, 42.3795610836574, 40.87471328462873, 44.67270633152553, 41.66312190464565, 46.67351654597691, 43.11266204289028, 44.794407503945486, 51.340843881879536, 54.37904446465628, 55.245992047446116, 51.268071923937114, 55.093677112034385, 57.584436076028005, 55.960690702710835, 58.89829526628767, 55.412005356379915, 59.84221499306815, 58.221700532095774, 62.58344609396798, 59.32409477233887, 62.76047229766846, 58.85331957680838, 60.71180983952114, 58.18752234322684, 63.39415495736258, 60.903343881879536, 65.07311071668352, 61.217819350106375, 62.85974815913609, 60.739692960466655, 65.0385434286935, 64.66791956765312, 71.29706382751465, 52.32525771004813, 1.3544946440628596, 1.969335091965539, 0.6404511822121484, 0.12607646121510438, 30.321837902069092, 83.18571649278913, 67.17348166874477, 77.97217042105538, 55.864802088056294, 33.52246304920742, 28.62496100153242, 45.308275427137104, 61.4723596572876, 86.51233332497733, 18.726896013532365, 1.0996606669255664, 0.19805210403033666, 0.21359955333173275, 0.2079176367925746, 0.24307089405400412], [0.04179703450894781, 0.11478171657238688, 0.06526280088084084, 0.1320604072617633, 0.015735450999013016, 0.2019188715411084, 0.12567825615406036, 8.27681749207633, 49.225857394082205, 34.84056758880615, 36.609922885894775, 31.00928224836077, 25.736655644008092, 35.91584300994873, 56.136542660849436, 59.64390645708357, 37.07494844709124, 0.05892390638057675, 0.19438914129776613, 0.7166233605572155, 24.98438286781311, 79.5051862171718, 60.25749492645264, 64.56048652103969, 57.001443999154226, 59.738110133579795, 54.55563293184553, 57.136708055223735, 52.50077615465437, 50.88218634469168, 52.889246463775635, 52.52226345879691, 51.36793838228498, 54.65320648465838, 51.53682129723685, 51.34684712546212, 51.39140592302595, 50.14236647742135, 49.42791100910732, 45.130630833762034, 43.04055711201259, 42.13558898653303, 41.866245542253765, 40.379230294908794, 41.11072622026716, 41.2348175730024, 40.680486815316335, 42.386519704546245, 39.740756852286204, 39.34426832199097, 42.31824323109218, 39.74450887952532, 42.54509149278913, 40.91722583770752, 39.46495853151594, 40.704968793051584, 40.36577163423811, 41.3159099987575, 39.74284131186349, 38.436128343854634, 40.202683516911094, 39.22210509436471, 42.86199188232422, 43.24401078905378, 39.45779841286795, 38.759817123413086, 39.23654692513602, 40.518586839948384, 43.33641140801566, 42.849759578704834, 37.94585650307791, 41.88739933286394, 42.16923911230904, 40.91206680025373, 40.08220522744315, 39.60023648398263, 35.12149715423584, 35.35168055125645, 35.83445528575352, 34.76861899239676, 34.961025033678325, 35.800812108176096, 34.99916022164481, 37.73951584952218, 37.776980536324636, 38.56270367758614, 35.44016238621303, 36.472376346588135, 37.47500140326363, 36.10279471533639, 36.6615514755249, 36.86004761287144, 36.45984179633004, 37.522263050079346, 37.25403479167393, 36.75476155962263, 33.87274258477347, 35.153879233769004, 35.6221079145159, 36.85707030977522, 35.199542794908794, 35.71544654028756, 40.127531800951274, 40.348025935036794, 40.27414573941912, 42.52302401406424, 43.50924089976719, 40.28654132570539, 40.85625539507185, 39.30321141651699, 38.47294684818813, 37.965023108891074, 36.42898137228829, 34.31290749141148, 34.55143914903913, 37.6893116406032, 39.33741044998169, 35.936409677777974, 36.905294282095774, 36.97135080610003, 36.45744466781616, 36.07846907206944, 35.981600761413574, 37.70809609549386, 39.308276653289795, 39.89802237919399, 39.323316029139924, 40.3939847946167, 42.382145813533235, 46.458014692579, 48.49258967808315, 49.22083732060024, 48.09207466670445, 47.59348930631365, 50.48368978500366, 48.80946574892317, 51.36140012741089, 50.64978994641985, 52.73557315553938, 54.584971700395855, 55.421121392931255, 54.575841767447336, 56.70145899908883, 54.52258382524763, 57.36357021331787, 58.19382435934884, 60.15685721806118, 57.96553087234497, 56.786668232509065, 55.32340540204729, 52.10965510777065, 49.38221270697457, 58.57609340122768, 58.15802376610892, 65.79200608389718, 53.862060274396626, 4.605385013989039, 0.9895978357110704, 0.2567271984049252, 0.25423233370695797, 16.043996776853287, 69.40065724509103, 58.61294664655413, 60.13913236345564, 46.769776889256065, 29.435782773154124, 25.1663544518607, 39.313327993665425, 43.60706806182861, 64.68202441079276, 14.851729324885778, 0.74434830141919, 0.12793994907821926, 0.18708062704120362, 0.07732022566986935, 0.07919516720409904, 0.043865151570311615, 0.0713293110685689, 0.027695042912715247, 0.1435385463493211, 0.050659315926688056, 0.1475392702434744, 0.21095991640218667, 11.142408319881984, 64.68977860042027, 43.78197159085955, 44.612701688494, 34.87694140842983, 29.206009319850377, 43.72733790533883, 64.85110882350376, 67.04304313659668, 39.92475209917341, 0.08536383083888463, 0.15551789211375372, 0.814859923507486, 27.105242320469447, 82.10261045183454, 63.68531921931675, 67.55784211839948, 58.99884959629604, 61.21944522857666, 57.099225997924805, 58.27514260155814, 53.88307510103498, 52.36249658039638, 54.948011602674214, 55.290846143450054, 54.94169569015503, 59.10552528926304, 53.997459820338655, 54.08848817007882, 54.296367849622456, 52.86495556150164, 52.351754665374756, 48.868195397513254, 45.37047570092337, 44.561986786978586, 43.804247515542166, 42.45378174100603, 42.92776700428554, 42.69993209838867, 43.09124769483294, 43.47441305433001, 42.382437637874055, 41.48992763246809, 43.516265528542654, 41.835128034864155, 44.176910672869, 42.656578813280376, 42.88764810562134, 41.85877275466919, 40.6731390953064, 42.136759757995605, 41.342723097120015, 40.537117685590474, 41.360722405569895, 39.88826016017369, 45.723958356039866, 44.28822776249477, 39.10688311713082, 39.024036271231516, 39.63862875529698, 41.07420301437378, 44.210043157849995, 44.51157760620117, 39.804249491010395, 40.98773963110787, 42.01199095589774, 41.93322965076992, 41.073504720415386, 41.84222214562552, 37.27632113865444, 36.960931982312886, 37.56017242159162, 37.90815210342407, 36.980842045375276, 37.54008517946516, 38.07869911193848, 39.05069303512573, 40.22654710497175, 39.78791775022234, 39.03547995431082, 38.663344860076904, 38.96435819353376, 38.8963040624346, 39.69150454657418, 38.928154604775564, 40.284217153276714, 39.33934552328927, 38.74033090046474, 39.208410194941926, 36.45165681838989, 37.86975635801043, 38.40769631522042, 38.215325014931814, 37.780263560158865, 38.9428847857884, 41.18138592583792, 41.22831405912127, 40.925007820129395, 43.143915040152415, 43.42793655395508, 41.08685915810721, 40.509144238063264, 40.510995932987754, 39.385266167776926, 36.93689121518816, 36.057534149714876, 35.272467613220215, 35.74540717261178, 39.184063707079204, 42.67365401131766, 38.10617576326643, 39.291364737919395, 37.819107464381624, 38.52207408632551, 38.70999506541661, 37.03492334910801, 40.08333778381348, 41.413973399571006, 41.34970951080322, 41.91511917114258, 41.19174221583775, 44.43539408275059, 46.37310075759888, 49.62289483206612, 52.30964510781424, 51.197259357997346, 50.515967641557964, 52.512129511152, 50.84667410169329, 54.424968583243235, 52.07684571402413, 55.78996304103306, 55.754534176417756, 56.54495429992676, 55.0291040284293, 59.7836833681379, 57.58188608714512, 58.936364446367534, 60.417171478271484, 61.66154520852225, 60.65124934060233, 60.54385103498186, 57.15212958199637, 54.69803973606655, 52.0213747705732, 62.2970552444458, 62.39669936043875, 69.28233637128557, 57.84966271264212, 5.441383148942675, 1.420201478259904, 0.2455532465662275, 0.24617437752229826, 16.377084732055664, 76.53771482195172, 62.53228650774275, 68.33369881766183, 51.6717448915754, 28.921386786869594, 28.740985495703562, 43.00095585414341, 50.28912285396031, 73.11418451581682, 19.742003508976527, 0.8925157593829292, 0.10236721951514482, 0.1645128915884665, 0.06727226876786777, 0.03519758934687291, 0.09833377666239228, 0.157991762938244, 0.17866854343031133, 0.21808876815651143, 0.0932374494150281, 0.37001548654266764, 0.3598009560789381, 15.797962801797048, 79.25711468287876, 53.687889780317036, 53.132759979793, 42.420982769557405, 37.12942579814366, 51.50393199920654, 70.77226638793945, 72.38690962110246, 45.9015543120248, 0.1296605510371072, 0.22176815143653325, 1.1011881849595477, 29.849329130990164, 83.83155850001744, 65.51257732936314, 71.43538856506348, 62.60448523930141, 65.8308812550136, 60.53111498696463, 62.54817703792027, 57.559825556618826, 54.47508941377912, 58.662209374564036, 58.53776018960135, 55.18335403714861, 61.823347909109934, 56.213803155081614, 56.03794077464512, 57.178365979875835, 56.078726700374055, 55.75376640047346, 49.10654640197754, 47.99798910958426, 47.03065742765154, 45.56910732814244, 44.86123875209263, 44.37408317838396, 44.642394815172466, 44.42897742135184, 45.88394757679531, 43.58202675410679, 41.508309091840474, 46.53682116099766, 43.91131230763027, 46.505696705409456, 45.225789887564524, 44.37480231693813, 44.827901295253206, 43.418202127729145, 44.76325525556292, 45.58771112986973, 42.66264806474958, 43.72568423407418, 42.466740131378174, 47.6964442389352, 46.19478913715908, 40.59638581957136, 39.994446005140034, 39.96761901038033, 41.980647632053916, 44.47005864552089, 45.661393301827566, 41.24892589024135, 41.91567155293056, 44.2448536327907, 41.49185575757708, 41.933698654174805, 43.26755823407854, 39.77020679201399, 41.82885728563581, 39.88083600997925, 40.92012323651995, 40.70439209256853, 40.32400948660714, 40.19620432172503, 42.09582444599697, 43.19429990223476, 43.16627434321812, 40.1871577671596, 42.08730248042515, 42.496676445007324, 41.91360446384975, 41.27923045839582, 42.06120157241821, 42.66508688245501, 42.90263884408133, 43.16053165708269, 41.31510748182024, 39.62609420503889, 40.70078945159912, 40.64951869419643, 42.30996445247105, 40.584539140973774, 40.381359917776926, 43.531051295144216, 42.537511008126394, 40.065421853746685, 43.2916476385934, 43.99305438995361, 41.76658752986363, 41.006815910339355, 40.97537531171526, 40.410066400255474, 38.62347609656197, 38.79764659064156, 35.839287757873535, 35.92923566273281, 41.12132222311837, 45.1433356148856, 40.211698804582866, 40.86076477595738, 40.838742460523335, 40.913800375802175, 41.039510658809114, 40.04241636821202, 41.81055573054722, 42.97190890993391, 44.23337868281773, 43.171030385153635, 43.716658524104524, 47.467514991760254, 49.83821255820138, 52.60932438714163, 52.337021010262625, 52.6360193661281, 55.09050178527832, 55.87201084409441, 53.89514412198748, 55.74472679410662, 53.84400190625872, 57.89554861613682, 59.81224741254534, 59.20750399998256, 57.639420645577566, 62.737675258091514, 58.99229049682617, 61.069864409310476, 62.731143951416016, 64.92546149662563, 63.93000003269741, 62.092507226126536, 61.044301986694336, 58.41211591448103, 54.77325745991298, 64.6749928338187, 65.21527085985456, 71.95106301988874, 60.87164619990757, 5.8401919433048795, 2.755944128547396, 0.7904244118503162, 0.2606967096882207, 18.074524436678203, 82.50363962990897, 67.92248358045305, 74.05883380344936, 62.90771852220808, 43.61811569758824, 37.12340170996529, 56.68398775373186, 57.108821460178916, 83.8828570502145, 26.894079617091588, 0.9486941163028989, 0.3289112193243844, 0.21033992538494722, 0.18788631952234677, 0.16218837989228113], [0.0058110778003798, 0.040384168537067514, 0.0531761753372848, 0.10094898633126702, 0.06405989399978093, 0.057943545414933136, 0.04574383861784424, 2.3414623694760457, 38.14313670567104, 35.76241636276245, 32.77352019718715, 41.35995462962559, 39.60303660801479, 36.20828226634434, 57.71121638161795, 59.98312446049282, 30.480548654283794, 0.30224682869655745, 0.38474441905106815, 0.5124359428882599, 19.06850072315761, 73.68163694654191, 61.56470816476004, 63.308330808367046, 54.82680722645351, 54.77509525844029, 52.31335197176252, 54.76518365315029, 52.36100966589791, 52.64534732273647, 51.69213785443987, 50.46472120285034, 52.32557732718331, 51.890057291303364, 50.56468841007778, 46.86011389323643, 45.360918453761506, 44.671969822474885, 42.81964956011091, 43.61653845650809, 41.23255246026175, 39.84444829395839, 41.56414481571743, 40.02014739172799, 40.123355933598106, 41.571079117911204, 41.21320520128523, 42.94786466870989, 40.882387569972444, 45.225894110543386, 44.070412158966064, 43.51489325932094, 42.79972907475063, 41.0482063293457, 41.896233967372346, 40.40549101148333, 42.28872728347778, 39.11268833705357, 38.29753262656075, 39.350587708609446, 39.19556644984654, 36.84601919991629, 39.904303550720215, 43.57713174819946, 42.69977923801967, 37.168443407331196, 38.37916006360735, 36.184797355106895, 39.754837376730784, 35.94601903642927, 41.060977118355886, 40.27680689947945, 41.118285860334126, 40.027477741241455, 41.08083854402815, 42.2528954233442, 38.705749716077534, 34.80860240118844, 35.404087339128765, 34.30840853282383, 34.662891728537424, 36.53710229056222, 34.091364179338726, 37.18007469177246, 35.96642589569092, 36.985660621098106, 35.86325904301235, 35.32634741919381, 36.07508877345494, 37.452023710523335, 36.82924624851772, 36.60877643312727, 37.10176501955305, 34.98045914513724, 35.374220507485525, 36.37415313720703, 35.47854770932879, 36.21004016058785, 34.62650401251656, 34.464899335588726, 36.7077430997576, 39.86239201681954, 39.58363028935024, 40.09293672016689, 40.02166904721941, 41.05716255732945, 39.28950956889561, 41.082697187151226, 41.51919344493321, 42.751310552869526, 37.1489953994751, 34.38343170710972, 33.0465600831168, 33.236468247004915, 35.98045778274536, 38.1058144569397, 38.13289506094796, 36.67684098652431, 37.66304744992937, 36.05084998267037, 35.76287841796875, 36.362546171460835, 36.7585448537554, 38.539416790008545, 37.342843191964285, 39.59241281236921, 38.947543552943635, 39.4501553944179, 39.3629207611084, 43.68511370250157, 46.41414376667568, 49.999150208064485, 48.425080980573384, 49.02569368907383, 48.61148377827236, 48.877200262887136, 50.09731435775757, 51.08701923915318, 50.539053031376426, 49.726520265851704, 54.71418734959194, 51.94661910193307, 56.01361165727888, 58.165010179792134, 56.53213834762573, 56.2789112499782, 57.539752210889546, 55.338139057159424, 53.275594098227366, 49.68686689649309, 48.162536348615376, 54.16898305075509, 56.517852851322715, 60.13430336543492, 60.305187361580984, 59.4132262638637, 9.746223398617335, 0.5441164172121457, 0.2303796022066048, 0.17529471803988728, 7.91810371194567, 66.56051853724888, 59.83839348384312, 60.843478202819824, 51.3476357460022, 37.8939916746957, 20.413093532834733, 33.0912960597447, 41.25718035016741, 69.57598114013672, 22.396726063319615, 0.4581071638635227, 0.0736283166334033, 0.052846963716936965, 0.059082330736730776, 0.032663756382784674, 0.04572345881855913, 0.09464705841881887, 0.021442256202655177, 0.04368655436805316, 0.034353033772536685, 0.05971671348171575, 0.11856378934213094, 4.78484091588429, 53.4634108543396, 45.242152895246235, 42.11700602940151, 44.54200029373169, 36.38362005778721, 42.345164026532856, 64.2187602179391, 64.16475881849016, 34.40899412972586, 0.2806977778673172, 0.36176224797964096, 0.7750225354518209, 20.56097204344613, 79.67188739776611, 64.27761146000454, 64.11519731794084, 57.17868907111031, 56.909164973667686, 55.45615768432617, 57.66917283194405, 54.74337673187256, 55.25565004348755, 54.26208891187395, 52.32499715260097, 52.724921567099436, 54.38830293927874, 53.57422072546822, 49.84514686039516, 47.45238528932844, 47.82921389171055, 45.18289170946394, 44.74873004640852, 43.79619107927595, 42.99153757095337, 42.38396624156407, 42.19516978945051, 42.1628954069955, 42.99506030763899, 43.84743056978498, 44.310875415802, 43.434203829084126, 47.803304059164866, 46.93812131881714, 46.092553343091694, 45.88651841027396, 42.68692854472569, 41.98146751948765, 42.01947069168091, 41.06569147109985, 41.2798627444676, 39.88417114530291, 40.88582692827497, 41.8222564969744, 38.98028693880354, 41.926510742732454, 43.84697893687657, 42.70539338248116, 38.17476143155779, 37.657947472163606, 36.77503292901175, 40.384385858263286, 38.532315731048584, 41.4986754144941, 40.59569794791085, 42.097123759133474, 38.923791136060444, 41.35701206752232, 43.67139448438372, 41.55427142551967, 36.545617307935444, 37.84082753317696, 37.26600306374686, 37.333445753370015, 36.821224553244456, 36.35796730858939, 40.13197864804949, 37.536944593702046, 38.946959904261995, 38.57715940475464, 37.78598540169852, 37.88610199519566, 40.59847722734724, 39.32832220622471, 39.137785230364116, 38.59988348824637, 38.04275260652815, 36.40021930422102, 39.01487854548863, 37.282223633357454, 37.14658784866333, 37.61289187840053, 37.30802576882498, 40.47928088051932, 42.28598274503435, 38.42033856255667, 39.94986636298043, 41.59360865184239, 40.88101877485003, 39.38923011507307, 41.568817479269846, 40.98345954077584, 42.56760018212454, 38.396759850638254, 35.155512060437886, 33.56616374424526, 34.30736977713448, 35.90761981691633, 40.496769496372764, 41.23004763466971, 38.058837686266216, 39.22988012858799, 37.98750747953142, 37.7601763180324, 38.81177575247628, 39.244443552834646, 40.97413853236607, 39.762004443577354, 42.283290318080354, 42.01137604032244, 41.829552105494905, 41.19650520597185, 46.33947842461722, 48.71427890232631, 51.44978468758719, 49.424047810690745, 52.279997144426616, 51.298369543892996, 51.65279367991856, 52.73266186032976, 53.84249414716448, 52.76582908630371, 51.36817809513637, 57.267351559230256, 53.63897793633597, 58.78197547367641, 60.12490940093994, 57.89566673551287, 57.062591620853965, 60.379046712602886, 56.68577691486904, 56.11270339148385, 52.39127254486084, 50.94586658477783, 55.28495059694563, 59.98106779370989, 63.71007565089634, 63.683811460222515, 61.771681104387554, 11.3371194260461, 1.3742852849619729, 0.16099854159568036, 0.16106772502618177, 8.010150841304235, 71.6495667866298, 62.9017778124128, 66.83910655975342, 58.10119097573416, 44.6047077860151, 21.674452134541102, 45.489668573652, 46.37425763266427, 77.77050590515137, 27.39360124724252, 0.3661599148597036, 0.09561006245868546, 0.030813428706356456, 0.024738657354776348, 0.03785748393940074, 0.08204076665320567, 0.20273509488574096, 0.12530132995120116, 0.2331225121659892, 0.16701735077159746, 0.29535863974264687, 0.34060183486768175, 9.417625716754369, 71.00455856323242, 56.21062782832554, 51.57696451459612, 54.97500535420009, 57.25346905844552, 51.73680434908186, 71.12827818734306, 69.99891104016984, 40.16863734381539, 0.45277585993920055, 0.9485564551183155, 0.959434619971684, 25.20211683000837, 82.26891558510917, 67.41994816916329, 69.2043706348964, 59.34796878269741, 61.139624323163716, 57.85165684563773, 61.13979802812849, 58.71393871307373, 58.06556756155831, 55.769385950905935, 56.003300530569895, 59.26560483660017, 57.18096113204956, 56.88541603088379, 53.060140882219585, 49.96568768365042, 48.6980687550136, 46.51266574859619, 47.27267708097185, 44.51621552876064, 45.11936432974679, 44.76276193346296, 43.778254304613384, 43.1250124658857, 45.66054214750017, 45.902502741132466, 48.023436886923655, 45.430546351841514, 50.50044536590576, 49.10115459987095, 46.826700006212505, 47.45187112263271, 44.72411257880074, 45.8877204486302, 44.31865739822388, 44.97027335848127, 42.97049495152065, 41.545276982443674, 42.815664768218994, 44.29170880998884, 40.089407035282676, 43.708212988717214, 44.811711992536274, 43.30120488575527, 37.411703314099995, 38.56844983782087, 36.06272097996303, 39.950165135519846, 39.132348264966694, 42.30467687334333, 40.41563190732683, 42.51011078698294, 39.60972077505929, 43.90279034205845, 45.11705405371529, 42.85918828419277, 40.08797223227364, 40.39058017730713, 39.90613440104893, 39.256714071546284, 40.25433989933559, 37.91044153485979, 43.62933356421334, 41.234570911952424, 41.18605858939034, 39.98321076801845, 40.97580262592861, 41.55370167323521, 43.159371307918, 41.950367382594514, 41.7540043422154, 41.48882286889212, 39.520759514399934, 39.701148646218435, 41.15177617754255, 40.96630096435547, 41.04358925138201, 39.2005170413426, 39.14039427893502, 41.507676805768696, 42.328269481658936, 39.192717688424246, 40.99889496394566, 41.190185819353374, 40.74017531531197, 39.86285754612514, 42.541954381125315, 41.72913326535906, 46.04530906677246, 38.79914740153721, 34.39800555365426, 34.423755577632356, 35.40219048091343, 36.972483362470356, 41.90038204193115, 43.62833649771554, 40.95472526550293, 41.49630607877459, 40.55067362104143, 40.87645033427647, 41.054150513240266, 40.5228773525783, 43.79799066271101, 41.78092513765608, 44.30589008331299, 43.72627135685512, 43.96641847065517, 44.719023023332866, 49.023438998631065, 53.19390065329415, 54.8027595111302, 53.4976932661874, 54.57342726843697, 53.629851477486746, 54.850212233407156, 54.521155970437185, 56.554650511060444, 56.86509949820382, 54.39511912209647, 60.800010272434776, 56.018127986363, 62.596161297389436, 62.54279913221087, 61.501014028276714, 60.54664421081543, 64.36628437042236, 59.431736264910015, 60.458068575177876, 54.55475745882307, 54.14288214274815, 59.55883271353585, 64.38873400006975, 66.5112419128418, 66.41061115264893, 65.79104723249162, 11.989708134106227, 1.7365751074893134, 0.640450259404523, 0.2060109262487718, 9.333473478044782, 78.15324742453438, 70.86909648350307, 73.08680861336845, 66.1403957094465, 53.75452300480434, 27.333514962877544, 49.574264390128, 53.29206827708653, 87.1128591809954, 34.90566178730556, 0.46693658722298487, 0.15225435580526078, 0.09206875426960842, 0.16693979421896593, 0.09176973067224026], [0.05876685945051057, 0.07067325591508831, 0.055024674361837764, 0.014505046486322368, 0.038718093652278185, 0.06489365747464554, 0.045545428193041256, 1.954259672335216, 31.91412878036499, 31.810996668679373, 32.88074827194214, 20.240444694246563, 45.877614293779644, 48.69856555121285, 53.2556597164699, 61.469594274248394, 28.578305585043772, 0.14163742693407194, 0.18242990731128625, 0.6146569177508354, 9.329579012734548, 75.2235186440604, 59.46881880078997, 63.547800472804475, 53.56664024080549, 57.04853194100516, 56.318053926740376, 57.468918800354004, 52.016900130680625, 53.63531970977783, 50.34986400604248, 51.529417991638184, 49.023584910801475, 47.252562046051025, 43.92017126083374, 43.09537492479597, 43.07773692267281, 40.06857981000628, 40.84788628986904, 40.66905702863421, 42.137607438223704, 42.846038818359375, 41.53252356392996, 40.77184173039028, 41.72005196980068, 43.25079223087856, 46.421668665749685, 48.42589044570923, 51.09490197045462, 51.8572096824646, 48.97819232940674, 48.92300278799874, 46.2732377733503, 44.47005864552089, 41.16069419043404, 40.35063845770699, 39.085638999938965, 40.769187518528526, 38.58183206830706, 38.462781633649556, 38.465970856802805, 39.82995087759835, 39.50405951908657, 44.52788850239345, 43.177325453077046, 37.56472001756941, 40.38318034580776, 37.746151379176546, 38.38333593096052, 37.985040869031636, 40.43066780907767, 40.63267626081194, 40.47318731035505, 41.20743819645473, 39.325195516858784, 41.167583329336985, 39.97149610519409, 37.73491614205496, 36.479956831250874, 33.642093658447266, 35.87007869992937, 35.23891476222447, 34.85872670582363, 35.82856668744768, 37.03419031415667, 37.85234417234148, 36.07705511365618, 37.220818928309846, 35.189443588256836, 35.728985105242046, 36.961376667022705, 37.207586084093364, 37.12330443518502, 36.57427862712315, 34.76822989327567, 34.83111456462315, 36.323400020599365, 35.85903453826904, 35.503849574497764, 39.427573748997276, 38.860249859946116, 37.73621545519148, 37.06076717376709, 42.54301050731114, 39.68551172528948, 39.20790992464338, 42.1156268119812, 42.32492044993809, 38.61235203061785, 35.88495479311262, 35.81644902910505, 34.56325456074306, 33.85722378322056, 35.3061455317906, 37.65766954421997, 41.99679177148001, 36.37741879054478, 35.320778438023154, 36.25919171742031, 35.28492225919451, 36.13751138959612, 37.10926559993199, 36.96800872257778, 38.90250880377633, 38.717144761766704, 40.05715002332415, 38.624775409698486, 39.93270778656006, 39.366964612688335, 39.97015510286604, 42.405453545706614, 44.44653899329049, 45.609247071402415, 45.43190819876534, 45.50333915437971, 47.46329048701695, 48.50615603583199, 49.0029730796814, 49.897414684295654, 47.73275205067226, 50.92117616108486, 49.89706380026681, 55.017580441066194, 54.99182346888951, 55.01089974812099, 54.11285202843802, 50.755920205797466, 49.030651228768484, 46.73461900438581, 48.52512114388602, 48.041220801217214, 52.28498247691563, 57.83565861838204, 61.20429815564837, 60.93381173270089, 62.16080801827567, 16.728191103254044, 0.480392045208386, 0.29098616008247646, 0.06353900980736528, 3.9792615600994656, 63.81105382101876, 58.00482293537685, 58.724027497427805, 48.37317098890032, 29.320175170898438, 16.980210951396398, 34.492278712136404, 35.34220668247768, 64.05376134599958, 26.948942593165807, 0.2500603475740978, 0.10150311873959643, 0.04418829030224255, 0.03283703047782183, 0.09417546301015786, 0.008893955432410752, 0.03741053970796721, 0.05903948125030313, 0.05796183193368571, 0.07471682929566928, 0.03052555683201977, 0.07845974380948714, 4.577040272099631, 47.42248024259295, 41.85295711244856, 42.78135108947754, 30.032577446528844, 53.49229451588222, 51.49044207164219, 58.76070008959089, 66.24616118839809, 33.2332512310573, 0.1983772444405726, 0.24658377841114998, 1.1572753467730112, 10.856832146644592, 80.15870598384312, 63.56996522630964, 65.92018645150321, 56.16545411518642, 58.42204489026751, 56.784215518406455, 56.10101652145386, 55.01077815464565, 55.05640002659389, 54.228501319885254, 52.23587608337402, 51.71107169560024, 48.98271560668945, 45.181001799447195, 43.72053214481899, 44.625125067574636, 41.54507201058524, 42.76033973693848, 43.467096601213726, 43.83838401521955, 44.771363803318565, 43.31095668247768, 41.58694532939366, 44.713936941964285, 45.90988520213536, 48.25640303747994, 49.91721357618059, 52.41376386369978, 53.450424671173096, 52.398547308785574, 51.89428179604666, 48.89408438546317, 45.903624875204905, 42.71414116450718, 41.81906032562256, 42.06817756380354, 42.383208887917654, 40.20688022886004, 40.64346333912441, 40.59301246915545, 40.54466690335955, 41.15476042883736, 46.00748654774257, 43.87824930463518, 37.30181407928467, 40.07790429251534, 38.214845589229036, 38.72000047138759, 39.141575472695486, 41.459748131888254, 41.26844685418265, 40.59930406297956, 40.36397205080305, 40.29423645564488, 41.997128759111675, 41.52433858598982, 40.05835900987898, 40.25040027073452, 36.70909799848284, 38.5188501221793, 36.3232228415353, 36.86540814808437, 37.28144890921456, 37.758098806653706, 40.57334906714303, 38.264806611197336, 38.50416163035801, 36.84868035997663, 38.558100496019634, 39.15154961177281, 38.78192976542881, 39.748493671417236, 39.16813496180943, 38.75870541163853, 37.46885224751064, 38.96469170706612, 36.81317506517683, 37.79511880874634, 40.877562046051025, 39.66026891980852, 36.88521746226719, 36.5027608190264, 42.68813058308193, 40.3079765183585, 40.473361015319824, 41.45470026561192, 42.51070833206177, 38.93733317511422, 37.440093653542654, 35.66720519747053, 35.52159874779837, 32.62134075164795, 35.67434794562203, 37.563260895865305, 43.04675143105643, 39.197015149252756, 38.5378360748291, 38.94690779277256, 38.034963675907676, 38.52935579844883, 39.829151834760395, 39.97797877447945, 41.262561729976106, 40.89920221056257, 42.00850643430437, 40.51599863597325, 42.485785143715994, 40.074913093021934, 41.66630070550101, 45.016940934317454, 46.742970739092144, 47.80231046676636, 48.46497753688267, 46.34569706235613, 50.50020217895508, 50.008248874119346, 51.105831486838206, 51.906034673963276, 50.57039635522025, 53.31751605442592, 51.98804078783308, 56.62018244607108, 56.61951541900635, 56.61164658410208, 55.809303351810996, 52.65487330300467, 50.43249198368618, 48.50158759525844, 49.795651367732454, 50.059193066188264, 56.60201985495431, 60.965974943978445, 64.80186694008964, 65.13249697004045, 65.35868862697056, 18.057299852371216, 0.5542464022125516, 0.127292965937938, 0.09074951255960123, 4.423403441905975, 70.9377029963902, 63.14274828774588, 63.72791167667934, 56.53540052686419, 33.145915848868235, 21.84266107422965, 42.488797187805176, 40.221662521362305, 74.05711759839738, 34.511754512786865, 0.26875889993139673, 0.028444471270112053, 0.045355485885271, 0.020220504707789848, 0.04547762218862772, 0.09052297685827528, 0.12923850225550787, 0.1363172238426549, 0.14264184875147684, 0.23841885796615056, 0.17083639012915747, 0.3265065997838974, 10.503835865429469, 68.76452187129429, 48.12752785001482, 54.42685849325997, 31.62381567273821, 60.9186646597726, 61.191958154950825, 65.52230480739048, 72.18046474456787, 38.34939398084368, 0.22133690172008105, 0.27767666855028694, 1.5785898991993494, 13.567593659673419, 85.99918801443917, 65.95415619441441, 69.97890717642647, 57.7220173563276, 62.07146808079311, 62.06296348571777, 59.822079113551546, 58.074621064322336, 58.224563189915244, 57.114609309605186, 56.20149094717843, 55.15418202536446, 51.83662564413888, 48.63437461853027, 46.51349605832781, 48.05771235057286, 44.209449086870464, 45.15309088570731, 44.51026439666748, 46.917811734335764, 45.9556564603533, 45.84941850389753, 42.869311809539795, 47.29498774664742, 47.24281372342791, 52.38964319229126, 52.800038542066304, 54.3201584815979, 56.49783509118216, 54.53543104444231, 53.77327619280134, 50.445697035108296, 48.265376635960166, 45.674306528908865, 42.51571798324585, 42.24933099746704, 45.15561655589512, 41.95308065414429, 42.07376044137137, 42.29497023991176, 43.06963184901646, 42.43869372776577, 48.045869146074565, 45.846486364092144, 37.61943013327462, 40.45640046255929, 40.04415341785976, 39.22448485238211, 39.756588322775706, 42.16511188234602, 41.95988294056484, 41.88693380355835, 40.45792211805071, 40.17129850387573, 41.8004287311009, 41.300015994480674, 40.059418610164094, 43.15743623461042, 38.88630213056292, 41.881517682756694, 39.599857807159424, 40.10409205300467, 40.36087315423148, 41.15352017538888, 43.180351393563406, 41.06607014792306, 41.61811147417341, 39.862503187997, 40.38705049242292, 41.802377700805664, 42.10554150172642, 42.66417319434029, 40.35590171813965, 39.45678744997297, 38.598997592926025, 42.892876625061035, 39.754726205553325, 40.190569332667756, 44.22223377227783, 40.464022636413574, 37.24177469526018, 37.535304818834575, 44.13889013017927, 39.96360295159476, 39.823138168879915, 43.20271417072841, 44.34536279950823, 41.27535336358206, 37.54590776988438, 35.73540871483939, 36.47596856525966, 33.85538598469326, 36.40335988998413, 37.99253102711269, 44.78843552725655, 40.94370542253767, 40.050914015088765, 41.72110114778791, 38.555425439562114, 39.623707498822895, 42.12404108047485, 42.6807724407741, 44.23453555788313, 43.612171513693674, 45.07179001399449, 42.394993032727925, 45.29554285321917, 42.24256345203945, 43.90403406960623, 47.07924965449742, 48.76307610103062, 51.56767129898071, 50.680344649723594, 48.79195281437465, 53.17113488061087, 52.47090237481253, 54.82803010940552, 55.412168639046804, 52.750706332070486, 55.99146774836949, 54.948894023895264, 59.81652055467878, 58.99889823368618, 60.21149785178048, 60.43735599517822, 56.662827014923096, 52.9738164629255, 51.92986352103097, 55.26746198109218, 54.05961145673479, 59.40655599321638, 64.64862442016602, 68.46214321681431, 69.11689281463623, 68.51570687975202, 20.15821623802185, 1.6483964962618691, 1.0236064451081412, 0.08298840187489986, 5.118149042129517, 77.79014846256801, 68.67255551474435, 71.48527663094657, 62.01537527356829, 42.82508652550833, 24.675353050231934, 48.58283288138253, 48.281506878989084, 82.90427276066372, 42.80452333177839, 0.36874947590487345, 0.18458393029868603, 0.21843378964279378, 0.2172085861010211, 0.1287899770374809], [0.02731638474922095, 0.04954893408077104, 0.05142200964369944, 0.060913581401109695, 0.031012772116810083, 0.0525968319603375, 0.04135179340041109, 5.811912775039673, 30.830501624516078, 35.138290950230186, 41.19727645601545, 11.688373446464539, 18.880821193967545, 47.46407215935843, 54.7793927192688, 61.863522393362864, 31.111108098711284, 0.08064535938735519, 0.09976963818605457, 0.26072368824056213, 5.717918413025992, 65.60216045379639, 60.20651599339077, 63.8512977872576, 55.227596691676546, 55.38054043906075, 55.69180236543928, 56.25581543786185, 54.648471287318635, 55.32343666894095, 51.40507997785296, 47.90574482509068, 44.806678022657124, 41.527381896972656, 42.168572085244314, 41.82219048908779, 41.98362146105085, 41.96957915169852, 42.06664548601423, 42.99917711530413, 41.3106050491333, 40.93472487585885, 40.462983880724224, 42.02353538785662, 46.88621827534267, 48.752473149980815, 52.50370134626116, 49.878515584128245, 49.253434794289724, 53.579977308000835, 53.46569333757673, 54.36460263388497, 50.80968189239502, 50.49770082746233, 46.47524275098528, 40.63580642427717, 39.5708212852478, 39.729247161320274, 38.582780497414724, 37.55424908229283, 38.172416414533345, 38.766647202628, 39.11049618039812, 42.82399913242885, 45.38556718826294, 42.31606149673462, 35.13105092729841, 37.095362254551475, 38.23900447572981, 42.74891689845494, 43.95342533929007, 39.97127723693848, 41.59011370795113, 40.637286390577046, 41.34579420089722, 40.603268010275706, 38.47474990572248, 36.52228873116629, 39.49125051498413, 36.910404682159424, 35.28192063740322, 35.254520416259766, 36.874208041599815, 35.707421370915, 36.28383697782244, 37.198556900024414, 34.417384079524446, 34.08298465183803, 35.179538931165425, 36.115381377083914, 36.36764962332589, 37.01203945704869, 36.044037273951936, 37.145177364349365, 35.208505971091135, 34.25305918284825, 35.28080197743007, 36.13949162619454, 40.46531500135149, 37.42111117499215, 36.230822222573416, 35.816435132707866, 37.00965969903128, 38.01071446282523, 44.424363817487446, 38.89748525619507, 38.5916359765189, 37.972905840192524, 34.8274632862636, 33.41995627539498, 34.47328233718872, 34.418131010872976, 34.67213978086199, 32.28063930783953, 38.26305913925171, 40.39324481146676, 33.2912791115897, 36.619122300829204, 37.110043798174175, 36.64004332678658, 35.82789271218436, 37.81483779634748, 36.3335165977478, 38.22373580932617, 39.06313031060355, 39.684271471840994, 39.61936834880284, 38.8089165687561, 38.96523366655622, 39.13527693067278, 39.23162065233503, 39.05595282145909, 41.55980913979666, 43.798622948782786, 43.93345621653965, 46.40554189682007, 45.25618825639997, 46.56789003099714, 47.497503416878835, 49.63218457358224, 49.839094979422434, 47.968949113573345, 49.36288629259382, 47.71944972446987, 47.39283922740391, 47.23080028806414, 44.68055084773472, 45.06451872416905, 45.392268725803916, 45.717868259974885, 49.42689657211304, 57.901819365365164, 57.18137454986572, 61.04535116468157, 59.71601486206055, 60.93413829803467, 18.632344927106583, 0.2861151471734047, 0.30389515310525894, 0.06486680784395762, 1.9538280154977525, 58.015794140951975, 59.84388256072998, 56.00248064313616, 51.2255037852696, 44.85455111094883, 17.5928145136152, 37.395315987723215, 41.057589871542795, 57.37501389639718, 38.551395484379356, 0.381704392177718, 0.04545598370688302, 0.07869206062917199, 0.05304622231051326, 0.05751399203602757, 0.02029529114120773, 0.022308643641216413, 0.01861432919810925, 0.06346616907311337, 0.03150208407480802, 0.09821376417364393, 0.09975122953099863, 7.560930694852557, 48.00370747702462, 45.253909247262136, 50.66103560583932, 18.640008790152415, 29.680828366960796, 52.14764090946743, 60.42905289786202, 66.37574509211949, 34.61642565046038, 0.0844988411824618, 0.08915505704603024, 0.7893259450793266, 7.069957954542978, 70.82307161603654, 63.16575377328055, 64.77914633069719, 56.375102111271445, 57.2535593850272, 58.72843265533447, 58.65764440808977, 57.14708866391863, 57.671886103493826, 54.259594508579795, 51.446077823638916, 47.30527108056204, 44.54059675761631, 43.13140828268868, 44.09381021772112, 44.84648772648403, 43.027094977242605, 44.22983857563564, 43.35317393711635, 43.587620053972515, 42.73976959500994, 41.773994309561594, 45.16118901116507, 49.03842626299177, 50.10047231401716, 54.46518128258841, 53.78382008416312, 52.435525621686665, 55.351972920554026, 55.68480205535889, 57.25836059025356, 54.361663545881, 52.38970225197928, 49.53170319965908, 42.94803837367466, 42.77649082456316, 42.208944593157085, 40.12588855198452, 39.93984011241368, 39.96641002382551, 41.417551721845356, 41.28615433829171, 43.619453225817, 46.457743712833945, 42.65999385288784, 35.692746775490896, 38.287419523511616, 39.046802043914795, 43.5234499658857, 45.16756745747158, 40.36226626804897, 43.04060227530343, 40.91257749285017, 41.24796009063721, 40.35427931376866, 37.453187533787315, 36.98915556498936, 41.49233865737915, 40.10805947440011, 39.35637208393642, 36.6445700781686, 40.023249762398855, 38.73438324247088, 38.90248448508126, 38.07496445519583, 37.111561979566304, 37.0452310017177, 39.781799861363, 38.382491724831716, 39.1644663129534, 38.46423033305577, 37.95035546166556, 39.52061012813023, 37.14521557944161, 37.96611745016915, 36.76561464582171, 38.30734348297119, 41.47059079578945, 36.5493415423802, 36.57666533333914, 36.349056243896484, 37.778120040893555, 37.71983855111258, 45.655938965933665, 38.80095740727016, 38.820923055921284, 38.20677873066494, 35.5264173235212, 32.76396642412458, 34.048570224217, 33.893055643354145, 35.19779879706246, 32.93538543156215, 38.37122174671718, 41.49225180489676, 34.63682208742414, 37.73207432883126, 39.23323610850743, 38.60872507095337, 37.61320802143642, 39.08818204062325, 37.48085873467581, 40.89171552658081, 40.26500538417271, 40.49157224382673, 40.62150355747768, 40.62848997116089, 41.72635746002197, 42.564018385750906, 39.54815626144409, 41.84468528202602, 44.019398484911235, 45.50367266791207, 45.97704301561628, 47.663534096309114, 47.16920798165457, 49.00207676206316, 48.95241798673357, 51.03026982716152, 51.469719069344656, 51.51178346361433, 50.29789842878069, 50.14003535679409, 50.6167825290135, 50.16697699683053, 46.96669578552246, 48.10622467313494, 47.5890667779105, 48.212869099208284, 53.46607548849923, 60.1976500919887, 60.07167230333601, 64.79834420340401, 62.50660596575056, 65.02653694152832, 20.409527369907924, 0.12621607658054146, 0.7903662749699184, 0.08705681642251355, 1.730044886469841, 64.44035911560059, 66.34331090109688, 60.87150723593575, 57.52346910749163, 47.72466434751238, 19.399068219321116, 42.82911648069109, 45.73918880735125, 66.66943155016217, 45.97245373044695, 0.2314974750791277, 0.06404187210968562, 0.06682085299066134, 0.02580785212506141, 0.05027701911915626, 0.16517086699604988, 0.11641604958900384, 0.14923258152391228, 0.18770212440618447, 0.1387187356927565, 0.19713962370795862, 0.23544549037303242, 13.176922508648463, 67.49063219342912, 53.50522858755929, 65.58842386518205, 18.18494347163609, 28.562814576285227, 63.36782128470284, 65.67891720363072, 72.34204510280064, 38.88645151683262, 0.18879365654928343, 0.16367840208113194, 1.387771412730217, 9.986624121665955, 75.54903479984829, 66.44194752829415, 69.52990068708147, 60.163020270211355, 59.804388999938965, 62.23242310115269, 60.930337633405415, 60.30465929848807, 60.26104545593262, 57.95137391771589, 54.41596719196865, 49.79109682355608, 47.28059802736555, 46.43703808103289, 46.82899291174752, 46.852408340999055, 45.65070697239467, 44.859133447919575, 46.335163593292236, 46.40214075360979, 44.61728402546474, 43.73713833945138, 46.65271711349487, 50.679524762289866, 52.573714869362966, 57.02944871357509, 55.74282993589129, 56.136619091033936, 57.93233585357666, 58.133882250104634, 60.60848317827497, 55.88711622783116, 54.25667973927089, 53.430118560791016, 45.886858872004915, 44.15210907799857, 42.14531299046108, 41.15720966884068, 41.868680885859895, 42.22526938574654, 44.44710179737636, 42.08243179321289, 47.262251308986116, 50.200401306152344, 42.87543317249843, 35.04853412083217, 39.354016644614084, 39.09793036324637, 43.32503373282296, 45.29114811761038, 38.55314643042428, 44.276259490421836, 41.73920120511736, 42.18747465951102, 41.51767873764038, 39.11395638329642, 37.15888616016933, 42.00993081501552, 42.38676983969552, 40.35604763031006, 38.84079490389143, 43.18555906840733, 42.22900056838989, 42.607948371342246, 40.29670654024397, 38.64599173409598, 40.46501622881208, 41.80425371442522, 41.57987206322806, 40.154337951115195, 41.19248914718628, 40.00859601157052, 42.614490100315635, 40.26694393157959, 40.38678993497576, 39.317298889160156, 43.10891696384975, 42.91410684585571, 37.54788800648281, 36.02890757152012, 37.31782272883824, 36.73889534814017, 38.48143407276699, 45.21532242638724, 41.089079107557026, 40.68546519960676, 37.42573520115444, 34.745835849217, 33.44972235815865, 33.988242489951, 34.8454521724156, 36.6627813066755, 33.24405567986624, 39.35102197102138, 44.215907437460764, 35.11379855019705, 40.99893317903791, 41.95031179700579, 41.465803486960276, 39.46265172958374, 41.973213059561594, 39.86345509120396, 42.77433340890067, 43.60381630488804, 43.99853651864188, 43.12122917175293, 43.89884376525879, 44.34293440410069, 44.20799343926566, 43.18721621377127, 43.27316543034145, 47.164649963378906, 48.47577851159232, 47.65481063297817, 50.54673426491873, 49.78315503256661, 52.33154582977295, 52.044196128845215, 53.720643588474815, 54.91775567190987, 54.59818022591727, 54.30290610449654, 53.018781730106895, 53.25933183942522, 52.92023542949131, 49.11551652635847, 51.84997313363211, 51.13023356028965, 51.68380696432931, 56.589089257376536, 62.86199937547956, 62.597154889787944, 69.90836906433105, 66.75736100333077, 68.76395211900983, 22.72816034725734, 0.8976485782435962, 1.3724716965641295, 0.19785416179469653, 2.4602311849594116, 71.87300695691789, 71.11699431283134, 69.47719860076904, 64.57125622885567, 63.15590122767857, 28.48110202380589, 51.23601640973772, 55.7581159727914, 75.8046520778111, 57.1150609425136, 0.39381070541484015, 0.19536779235516274, 0.21399980756853307, 0.15377487135784967, 0.2121019179799727], [0.03698402277327009, 0.2088320848665067, 0.017237998944308077, 0.068039759727461, 0.03175757286537971, 0.15358893919203961, 0.09389252747808184, 6.0904877696718485, 32.274847984313965, 41.20093468257359, 42.849895068577354, 29.159737791333878, 23.930964742388042, 43.547205856868196, 57.58981050763811, 60.70679324013846, 34.68388223648071, 0.13663632529122488, 0.13964874936001642, 0.5129002779722214, 2.333880147763661, 57.93238796506609, 64.010098866054, 59.74829619271414, 56.35353142874581, 54.86205891200474, 55.650603021894185, 56.13769606181553, 54.55448995317732, 51.232854979378835, 49.18084001541138, 43.64746141433716, 43.42186035428728, 43.16849429266793, 41.76977675301688, 42.83916357585362, 43.94042525972639, 44.694652216775076, 47.893102577754426, 46.8246294430324, 48.88620512826102, 48.54525702340262, 48.55546045303345, 50.23132078988211, 51.34238985606602, 52.40646825517927, 59.38277925763811, 60.89216423034668, 53.017093317849294, 51.38200848443167, 47.64447866167341, 48.18395069667271, 50.29249620437622, 50.50101164409092, 46.03084986550467, 44.89319004331316, 42.16678639820644, 39.483176708221436, 37.42456095559256, 37.77241904394967, 37.46021563666207, 39.9784825188773, 38.53819738115583, 39.428098337990896, 44.04653467450823, 44.69652475629534, 37.91102518354143, 37.47322266442435, 37.43436138970511, 42.87673595973423, 48.94614028930664, 43.7139869417463, 40.407898562295095, 42.84676490511213, 43.37306315558297, 47.27439676012312, 39.851000445229666, 35.36831453868321, 37.46437760761806, 37.871854713984895, 39.106827531542095, 35.974749837602886, 36.23924343926566, 34.94374486378261, 36.77448402132307, 36.04009417125157, 37.566450119018555, 35.85050215039934, 35.86473553521292, 35.589166504996165, 37.85318143027169, 36.685015542166575, 36.77126005717686, 36.670188086373464, 38.03660692487444, 37.40309797014509, 39.67302233832223, 41.36758027757917, 36.73217991420201, 36.48821823937552, 35.412070819309776, 34.79479285648891, 35.81484399523054, 41.59663806642805, 41.888653482709614, 36.884901319231304, 34.18659271512713, 33.821468353271484, 33.794568402426584, 34.3981271471296, 34.613722801208496, 34.54702009473528, 34.40783725466047, 35.06993804659162, 47.1332927431379, 39.079858098711284, 34.589657715388704, 34.418214389256065, 36.12407009942191, 34.02239983422415, 35.790219579424175, 36.5017602784293, 37.81126642227173, 37.98092406136649, 38.48971632548741, 37.65886810847691, 38.28670733315604, 39.868732248033794, 38.55573116030012, 37.794583797454834, 38.616104057856965, 38.21460240227835, 38.8293651172093, 38.914786270686555, 39.78387042454311, 42.14864117758614, 41.494204248700825, 41.14459868839809, 42.105802059173584, 42.23959309714181, 44.14653662272862, 45.84413092476981, 43.56132459640503, 44.07784673145839, 42.69243151800973, 43.73271581104824, 43.5870155606951, 44.826522077832905, 45.54071004050118, 48.37853152411324, 51.6789675440107, 58.21624967030117, 58.63623700823103, 58.17962571552822, 60.16365950448172, 60.786350114004954, 20.637021814073833, 0.04822443372436932, 0.1849186380526849, 0.041138930179710896, 0.36056908486144884, 51.2024461882455, 63.978345598493306, 56.381525720868794, 54.142885616847444, 44.23493160520281, 23.974655015128, 29.50113752910069, 40.770740440913606, 54.915080615452354, 50.675897802625386, 0.22114193146782263, 0.07880505706582751, 0.06692171722118344, 0.04839199794722455, 0.03176935901865363, 0.03828574131642069, 0.16049239518386976, 0.05524842128423708, 0.19618329645267554, 0.021679142955690622, 0.07336787453719548, 0.13655788664306912, 9.238269260951451, 49.47580146789551, 50.84519760949271, 50.42932707922799, 31.674492359161377, 27.450166531971522, 50.62810809271676, 63.409295082092285, 67.36908040727887, 38.55997650963919, 0.14052532160920755, 0.028287074894511273, 1.3433868629591805, 2.389109424182347, 62.45653029850551, 66.31372547149658, 64.31979397365025, 60.20040852682931, 57.66239486421858, 57.84357261657715, 57.23334360122681, 55.84614964893886, 52.95983668736049, 51.35087360654558, 44.40401949201311, 45.54117904390608, 44.18703072411673, 44.516090461185996, 44.479945932115825, 45.54841211863926, 46.45586769921439, 49.6717198235648, 48.67060947418213, 51.616329533713206, 50.78249706540789, 49.745756353650776, 52.547266551426475, 52.974097864968435, 55.48580912181309, 59.1508275440761, 57.52196829659598, 53.41665642602103, 49.9953738621303, 49.88182987485613, 51.055905205862864, 52.13552325112479, 52.43417419706072, 49.96153960909162, 46.346430097307476, 43.00810555049351, 39.20267445700509, 41.11033017294747, 38.90173060553414, 39.517716203417095, 41.03355952671596, 39.26062590735299, 42.39973865236555, 44.28596612385341, 46.99985606329781, 37.82689292090279, 36.02733033043997, 37.181485176086426, 42.66948856626238, 50.022708075387136, 44.757516043526785, 41.0525871685573, 42.71016679491316, 42.71268899100167, 47.26236595426287, 40.58132559912545, 36.43905973434448, 38.06678989955357, 39.809088911329, 42.5874650818961, 38.75447743279593, 39.5372371673584, 37.618853432791575, 39.59415333611624, 38.951993874141145, 39.04827158791678, 39.12489284787859, 37.97181497301374, 38.35681118283953, 40.57432528904506, 38.20896393912179, 39.83338328770229, 39.68694305419922, 38.962155614580425, 38.25202887398856, 41.09991829735892, 43.684401512145996, 36.06692811420986, 35.569298131125315, 36.00958463123867, 36.78992291859218, 35.81370449066162, 41.68840987341744, 42.1869535446167, 36.84038073675973, 35.798974309648784, 33.19281618935721, 34.00488689967564, 35.012073448726106, 34.39256164005825, 33.701837744031636, 33.55276761736189, 37.20670018877302, 49.856486320495605, 41.349077224731445, 37.10128211975098, 36.287974630083355, 37.60803508758545, 35.8115679195949, 38.66599907193865, 37.9294240134103, 38.61882775170462, 40.098915645054404, 40.84807736533028, 40.290032795497346, 40.29104028429304, 39.988196100507466, 42.2917150088719, 39.51211595535278, 39.88199635914394, 40.06231253487723, 40.682800565447124, 40.84958859852382, 42.88623414720808, 43.08650554929461, 42.633271081107004, 42.02396617616926, 43.96428884778704, 44.78520808901106, 45.10695832116263, 46.46879134859358, 44.414268084934776, 47.10292216709682, 44.98027181625366, 46.97660044261387, 46.139297349112375, 47.94309834071568, 48.2368369102478, 51.18939747129168, 55.02697440556118, 61.419671467372346, 62.22553743634905, 63.03037507193429, 63.30927576337542, 66.33808585575649, 22.392902817044938, 0.3187761317406382, 0.3160607974444117, 0.04447519526417766, 0.3533352501690388, 56.53836740766253, 69.4886839730399, 61.93438012259347, 60.286656515938894, 47.50533403669085, 21.526087250028336, 30.234592846461705, 46.43586383547102, 63.60889598301479, 59.78476728711809, 0.20402242509382112, 0.07592162928943123, 0.07826571672090463, 0.036551232782325575, 0.011320231266186705, 0.13481973776859896, 0.28049055327262196, 0.1001574955880642, 0.25905449209468706, 0.10607122004564319, 0.24809883854218892, 0.17401525883802346, 15.456483159746442, 65.15626675742013, 59.55091176714216, 63.68972437722342, 40.16476719720023, 35.11641454696655, 59.26406233651297, 69.40700789860317, 72.467043195452, 44.21214846202305, 0.20189609990588256, 0.17087700723537377, 1.352922179869243, 3.728998737675803, 71.71622085571289, 68.96971607208252, 67.93764454977853, 62.74061434609549, 61.18088967459542, 59.46282250540597, 61.52710451398577, 59.150257791791645, 56.38349206107003, 55.04427889415196, 47.948274748665945, 46.4288079398019, 48.31579623903547, 46.51610858099801, 46.94303022112165, 46.96322168622698, 49.29392889567784, 52.19746644156319, 51.83866841452462, 55.328039850507466, 53.21445689882551, 53.37239292689732, 53.880434785570415, 54.846574851444785, 57.02084336962019, 60.59955474308559, 56.56943627766201, 52.581910269601, 51.71219730377197, 52.01320021493094, 55.796150411878315, 54.4541232245309, 55.45696020126343, 52.12249190466744, 48.35249662399292, 45.7343876021249, 42.813410077776226, 41.479908330099924, 40.42531769616263, 42.826385838644846, 44.84798853737967, 41.52868815830776, 44.81358800615583, 48.63855395998274, 46.82128735951015, 38.30084344318935, 37.48997477122715, 36.78584432601929, 43.42955201012747, 53.040057114192415, 47.45362206867763, 42.17588159016201, 44.46303054264614, 45.143571853637695, 48.54992273875645, 40.46374470846993, 36.68396289008004, 37.51144470487322, 40.966443402426584, 44.343729972839355, 41.46110650471279, 41.04475654874529, 38.39339344842093, 41.92648294993809, 41.12025567463466, 42.59174517222813, 41.4980639730181, 40.4307998248509, 40.93160513469151, 43.02604579925537, 40.54794297899519, 44.30242988041469, 43.82133313587734, 42.81628315789359, 40.48256390435355, 43.0566143989563, 45.89253555025373, 35.752490861075266, 36.9785977772304, 36.161903040749685, 37.26075717381069, 35.91752099990845, 43.609857763562886, 42.97481673104422, 36.66334063666207, 35.4083639553615, 33.7354531288147, 34.50325339181082, 36.01139463697161, 35.56664044516427, 33.947362763541086, 35.841191564287456, 37.4394405228751, 52.852570397513254, 44.5711201940264, 39.37292964117867, 39.608459677015034, 40.4595445224217, 39.047590664454866, 40.88389532906668, 39.256335394723074, 40.989045892442974, 41.50847584860665, 41.88737154006958, 41.015921524592805, 42.067093644823345, 44.19882181712559, 43.11544132232666, 41.059115001133506, 42.2645058631897, 43.06188808168684, 43.728063992091585, 42.89086512156895, 44.5643561226981, 46.191742352076936, 44.7618065561567, 45.59155695778983, 46.91353164400373, 46.713482584272114, 47.87078148978097, 50.11769689832415, 48.456208910260884, 48.7627078465053, 47.44802182061331, 48.86878946849278, 48.42078004564558, 50.47271510532924, 50.638672828674316, 53.968861034938264, 55.46354014532906, 65.19324507032121, 65.39256804330009, 66.9972197668893, 65.0429207938058, 69.00743784223283, 23.958750588553293, 0.5506859932626996, 1.3082394003868103, 0.12268546888870852, 0.5249321152056966, 62.55702209472656, 75.66940539223808, 69.60569163731166, 67.4765134538923, 61.21384498051235, 37.30093165806362, 41.43410233088902, 54.46731090545654, 72.07425458090646, 71.42202717917306, 0.3405571872634547, 0.21013849547931127, 0.1727383644985301, 0.1553698629140854, 0.11914669163525105], [0.030548694876155684, 0.07739802649510757, 0.027843297725277286, 0.06014181567089898, 0.058118797439549646, 0.08888135637555804, 0.07223214262298175, 6.943778233868735, 36.92219924926758, 38.64630092893328, 38.492853437151226, 23.970208168029785, 38.29810585294451, 48.43564224243164, 55.59231458391462, 63.11584486280169, 35.262656756809776, 0.0633382855781487, 0.04617601114192179, 0.20114226107086453, 0.36802835602845463, 45.321737561907085, 66.63139711107526, 56.96976368767874, 58.41239384242466, 53.92400346483503, 54.31008011954171, 52.40301152638027, 51.49798434121268, 48.06354883738926, 45.444696358272004, 42.20522035871233, 43.87543875830514, 43.73707233156477, 45.758122648511616, 46.590892042432515, 52.71911982127598, 50.69276455470494, 53.96432386125837, 54.588386740003315, 54.677532127925325, 52.164455550057546, 52.09115900312151, 54.04564210346767, 52.24431814466204, 55.80754198346819, 45.603990759168354, 41.182640075683594, 48.587571552821565, 50.23474972588675, 50.38549436841692, 50.15681178229195, 54.61796522140503, 53.67521974018642, 51.644268240247456, 45.51958751678467, 43.08822522844587, 36.72439793178013, 39.542858260018484, 37.74569627216884, 37.99805137089321, 37.43633815220424, 38.313367571149556, 37.447545596531455, 39.72549165998186, 46.61145176206316, 48.735641138894216, 37.45775597436087, 40.571504320417134, 43.42270108631679, 48.96827725001744, 45.88532332011631, 44.02568313053676, 45.191163539886475, 41.39152029582432, 40.54995100838797, 48.2479053906032, 38.68982791900635, 35.725615228925435, 37.37382173538208, 41.166812079293386, 39.67631231035505, 39.26285975319998, 37.06349434171404, 38.889738014766145, 35.74798148018973, 36.93479633331299, 35.33643620354788, 36.032100268772666, 36.10225622994559, 36.60133491243635, 37.273083278111045, 35.89258738926479, 37.091314928872244, 39.231485162462505, 36.90752465384347, 40.9636606488909, 35.40716191700527, 34.95653649738857, 35.98578010286604, 36.459692410060335, 34.85661792755127, 44.89716441290719, 41.10966314588274, 37.926120144980295, 36.787369455610005, 37.28481878553118, 35.274322782244, 33.912170137677876, 34.74428292683193, 33.91842351640974, 34.64402042116438, 39.06592696053641, 42.851236070905415, 42.43664748328072, 36.819723742348806, 35.53131927762713, 35.97213036673409, 34.83440453665597, 34.651632172720774, 36.006958212171284, 36.74557951518467, 38.75480399812971, 38.04672697612217, 39.164685181209016, 39.07182945523943, 38.62452874864851, 37.92371954236712, 40.15106187547956, 39.53866502216884, 38.44476842880249, 37.83343464987618, 38.05860144751412, 38.5665807723999, 39.45801033292498, 37.880988121032715, 39.70466096060616, 40.29512929916382, 41.290413584027974, 40.52471167700631, 40.67328153337751, 40.552021571568076, 39.8752635547093, 41.13661173411778, 42.10642392294747, 42.55512816565377, 43.61854996000017, 43.06328466960362, 44.03117915562221, 47.305326666150776, 55.13077007021223, 61.62576198577881, 57.16795410428728, 64.33337075369698, 60.35360240936279, 60.15480055127825, 25.54606134550912, 0.04692562270377364, 0.7552854173949787, 0.11879598402551242, 0.025107680321005837, 41.794807638440815, 65.64375931876046, 59.018242018563406, 53.14794874191284, 50.76339299338204, 27.124867507389613, 24.73100117274693, 44.431426661355154, 54.532422474452424, 60.83532101767403, 0.8491755021469933, 0.10098264845354216, 0.003481945492759613, 0.027928749032850777, 0.050457478900040896, 0.04879045745890055, 0.09995082060673408, 0.054565947369805405, 0.1095338249579072, 0.056279618093477826, 0.12739215418696404, 0.08478262488331113, 10.112915447780065, 49.15314449582781, 47.759749276297434, 51.70732314246041, 31.938520431518555, 40.14848409380232, 54.47440154211861, 61.093675885881694, 67.92763219560895, 39.98208515984671, 0.043551776957299025, 0.053527951639677794, 0.5831016195671899, 0.4385518931916782, 50.83010612215315, 69.82035623277936, 59.97236170087542, 61.73243073054722, 56.49501064845494, 57.47283411026001, 53.80014140265328, 54.96090398515974, 49.827588762555806, 48.333653109414236, 44.402598585401265, 45.70352370398385, 46.0811721937997, 48.36429466520037, 49.14840235028948, 54.1145612852914, 53.8722254889352, 55.547186034066335, 58.04357998711722, 55.81848887034825, 56.51430927004133, 54.91484785079956, 56.707107884543284, 55.08177137374878, 56.61118105479649, 48.980530398232595, 43.71827050617763, 47.84173801967076, 49.31162248338972, 52.20402206693377, 50.99587971823556, 56.59773281642369, 56.38736915588379, 52.21132809775216, 48.53722490583147, 45.80968870435442, 39.17019510269165, 41.540138789585654, 39.7011764390128, 39.67138951165335, 38.82843058449881, 40.40587316240583, 39.73033455439976, 41.41608565194266, 47.882169587271555, 50.19210863113403, 39.01497234616961, 41.074029309409006, 43.98325048174177, 48.70088972364153, 45.78212520054409, 45.14383241108486, 47.30098751613072, 40.89275080817086, 41.98175934382847, 48.3697246823992, 39.607789175851, 36.854127747671946, 37.9031320299421, 42.1128579548427, 42.017441817692344, 41.22164378847395, 38.79680585861206, 39.25798211778913, 38.70984220504761, 38.38120978219168, 37.030896868024556, 37.74940313611712, 40.17453636441912, 39.65036078861782, 37.70908621379307, 39.02839279174805, 38.49805416379656, 40.82294920512608, 39.19830404009138, 40.76778050831386, 35.00321102142334, 36.499919005802695, 35.49774210793631, 37.19151142665318, 34.74201781409127, 45.44258410590035, 41.70411280223301, 38.427509103502544, 37.60239315032959, 37.93230404172625, 36.353763648441856, 34.09014477048601, 35.47642503465925, 34.13344941820417, 34.94465855189732, 38.162751470293315, 46.20880017961775, 45.90642499923706, 38.75886869430542, 36.90626702989851, 37.07465314865112, 36.88935164042881, 35.76386506216866, 38.17125606536865, 40.38941635404314, 40.45262064252581, 40.225563934871126, 41.14396292822701, 40.47097430910383, 39.886641229902, 40.31168685640608, 41.82547698702131, 42.051710333142964, 41.11749376569475, 40.65212426866804, 40.003596782684326, 41.09152487346104, 40.483644349234446, 40.311117104121614, 42.458329336983816, 42.0426151411874, 43.53068651471819, 42.19877243041992, 43.81319332122803, 43.73701327187674, 41.99245956965855, 45.918803215026855, 44.56013856615339, 46.46187441689627, 45.085182666778564, 47.134043148585725, 46.53356940405709, 49.82509435926165, 57.61207601002285, 62.171612467084614, 61.93857683454241, 68.37617315564836, 62.43364988054548, 64.38610758100236, 27.102582897458756, 0.3377222408141409, 0.8184601217508316, 0.09678955988160201, 0.032183828564094644, 44.497295583997456, 73.13821833474296, 63.75743457249233, 59.3897066116333, 50.14840793609619, 26.66761871746608, 37.50503499167306, 49.12145028795515, 63.197340284075054, 67.79633903503418, 1.115868208663804, 0.12087832657354218, 0.051564223798257966, 0.006369075737893581, 0.04593489372304507, 0.11563592430736337, 0.1796428518635886, 0.10873212226267372, 0.21849632343011244, 0.17509852642459528, 0.21708304355187075, 0.2619420385786465, 17.663703509739467, 67.86950356619698, 55.806131499154226, 55.3276299067906, 33.827676568712505, 53.56981209346226, 64.19164834703717, 66.05407129015241, 75.1531125477382, 44.984305245535715, 0.14794352783688478, 0.25864775106310844, 0.6325246446899006, 1.032318834747587, 59.625973156520296, 73.52058465140206, 63.682630266462056, 65.01669829232353, 59.96935313088553, 60.17772960662842, 57.43345519474575, 56.70994969776699, 53.546483516693115, 50.29378856931414, 47.14752265385219, 47.62009743281773, 46.428297247205464, 50.520685468401226, 52.01317589623587, 58.93499565124512, 56.69127293995449, 58.292891774858745, 60.36591461726597, 57.33202886581421, 57.62370034626552, 58.61598995753697, 60.67845153808594, 56.44051592690604, 59.722170966012136, 51.56817156927926, 48.817119189671104, 49.57770722252982, 49.263881410871235, 52.8185589654105, 50.963754722050254, 61.74686908721924, 60.814254079546245, 55.16893652507237, 50.2495493888855, 47.38240998131888, 42.25286415645054, 43.67956904002598, 41.90755953107561, 41.820755686078755, 41.9339314188276, 41.16321291242327, 41.6672282900129, 43.80803428377424, 50.49953862598964, 51.432966572897776, 39.686553955078125, 41.0586598941258, 45.484801360539024, 50.60719748905727, 47.165549755096436, 45.774291106632774, 47.771154744284495, 41.662482670375276, 42.63781520298549, 50.59244646344866, 39.32003995350429, 37.46942547389439, 38.919160161699565, 45.91145549501692, 44.13045154299055, 43.58976009913853, 42.81098515646798, 42.771033014569966, 40.92709922790527, 40.85272571018764, 40.47467769895281, 40.508425099509104, 42.36339609963553, 41.22230734143938, 41.58661181586129, 40.66342551367623, 41.41945205415998, 43.34455469676426, 41.305171557835166, 42.541207449776785, 35.61867550441197, 36.70562737328665, 37.40520327431815, 36.9291022845677, 34.75293690817696, 46.73027638026646, 43.25769526617867, 40.598157610212056, 39.038877623421804, 37.60828522273472, 37.20200668062483, 34.02416467666626, 35.59256764820644, 34.115245137895855, 35.82005514417376, 39.36129140853882, 49.55921459197998, 48.59464829308646, 40.19459581375122, 39.10457978929792, 39.41180828639439, 39.18525184903826, 40.60604728971209, 40.83048105239868, 41.35031052998134, 43.277917998177664, 42.359175068991526, 43.650178159986226, 43.47842216491699, 43.06439290727888, 40.68679230553763, 43.80516815185547, 43.56246062687465, 42.83154487609863, 43.91576262882778, 42.81785692487444, 42.576726640973774, 44.456509658268516, 43.04942648751395, 45.16117858886719, 44.29567275728498, 45.39075749261038, 44.165991578783306, 45.480938162122456, 46.090312549046104, 44.25297260284424, 47.85603741237095, 46.36650691713606, 49.023063795907156, 48.161883217947825, 49.80847774233137, 49.92232745034354, 54.350664547511506, 60.54672064099993, 66.1097333090646, 64.62655694144112, 74.20070212227958, 67.26419734954834, 68.40960093906948, 28.571782963616506, 0.7997780985065869, 2.1114845957074846, 0.5167340551103864, 0.11312385874667338, 50.57906075886318, 78.47236428941999, 72.70737443651471, 66.86508587428501, 66.88886260986328, 42.29222222736904, 36.198589529309956, 60.33743395124163, 70.04836136954171, 79.54067761557442, 1.8519546134131295, 0.39735458525163786, 0.21013259222464903, 0.12268200836011342, 0.1612493959920747], [0.032399996250335655, 0.08910097780504397, 0.07619785411017281, 0.16772416712982313, 0.025821704417467117, 0.07924522951777492, 0.12362004231129374, 10.190695319856916, 38.837720326014924, 35.741537025996614, 37.70467758178711, 27.856900181089127, 28.400525501796178, 46.89633137839181, 54.60242904935564, 60.2064882005964, 35.66908121109009, 0.0677390940753477, 0.16729392164519855, 1.0636348000594547, 0.102210294721382, 30.53521360669817, 70.0020307813372, 57.330607959202354, 60.81412901197161, 48.89055470057896, 55.5579001562936, 47.82926947729928, 46.98500428880964, 40.44565854753767, 46.69242606844221, 42.76384857722691, 47.196986879621235, 45.870541027614046, 48.99347141810826, 49.405937331063406, 53.14243534633091, 49.6709520476205, 50.14338091441563, 48.314107826777864, 55.004041876111714, 56.361570494515554, 57.18981661115374, 53.70889071055821, 53.619981561388286, 50.80357095173427, 53.86186919893537, 46.7738242149353, 44.70238903590611, 44.859654562813894, 44.851966381073, 43.86305359431675, 42.51368563515799, 43.835830552237375, 48.52090358734131, 49.85280377524239, 45.37574243545532, 38.6906304359436, 38.80265276772635, 37.550715923309326, 37.75635828290667, 34.68832213538033, 36.480429308755056, 38.56084156036377, 37.799541337149485, 40.028728416987825, 49.41704750061035, 49.21724162782942, 38.53017568588257, 40.15092985970633, 43.61118139539446, 43.22861705507551, 45.16517032895769, 50.23807096481323, 48.624421324048726, 48.54595184326172, 49.38300480161394, 42.03808144160679, 37.0872745513916, 40.85918753487723, 42.239325591496055, 40.69609594345093, 39.274327754974365, 41.019360882895334, 38.39985874720982, 37.581465176173616, 37.95346825463431, 35.308066708701, 35.660340377262656, 36.81539501462664, 37.29708235604422, 36.55798510142735, 37.02542863573347, 41.228122983660015, 37.48597608293806, 41.734479904174805, 35.726695673806326, 33.67520877293178, 35.865235805511475, 33.878520011901855, 34.285840783800396, 40.144700799669536, 48.10741976329258, 38.62608167103359, 37.48440926415579, 41.713565826416016, 46.64925691059658, 41.65364803586687, 37.033040387289866, 35.054273332868306, 33.349192346845356, 35.158906255449565, 45.629160608564106, 43.51116902487618, 40.79289129802159, 36.61401537486485, 35.591876302446636, 34.58605160032, 34.427014282771516, 33.23668016706194, 34.77764122826712, 35.92877013342721, 37.67646789550781, 38.090827192579, 37.968351296016145, 37.11012370245797, 39.96422481536865, 42.89024673189436, 42.78204243523734, 42.655918734414236, 41.844362190791536, 42.21037244796753, 38.81487117494856, 39.719405038016184, 39.540270056043354, 39.604728494371685, 38.34736510685512, 40.600050994328086, 39.681099619184224, 38.46895163399832, 38.71506725038801, 40.60795109612601, 41.2803247996739, 41.908101490565706, 41.93790578842163, 42.13863229751587, 44.17451354435512, 46.617757252284456, 45.44590881892613, 49.4072505405971, 56.682410512651714, 60.551598276410786, 55.39973831176758, 63.45157487051827, 58.74738734109061, 64.69319711412702, 25.992571694510325, 0.30886805483273094, 0.3204329785491739, 0.2104443519243172, 0.1602028507207121, 34.50901344844273, 69.11879662105015, 55.69249718529837, 56.12107597078596, 48.33276373999459, 41.98156826836722, 15.84305661065238, 37.023479666028706, 56.06151948656355, 58.73354652949742, 2.4037484100886752, 0.31871975905128885, 0.020543835125863552, 0.13270249137920992, 0.08624957009617772, 0.03032754674287779, 0.07503918771232877, 0.07878314038472516, 0.058844198871936114, 0.03736889122852257, 0.1527136561593839, 0.2254645659455231, 15.83089552606855, 54.86359446389334, 45.38381624221802, 43.67545918055943, 29.450561591557094, 31.16314663205828, 53.0970219203404, 61.20962047576904, 67.75619929177421, 40.1812379019601, 0.03327743023900049, 0.23279806386147225, 1.0798940190247126, 0.07316163381827728, 35.76656791142055, 76.46757275717599, 59.14840957096645, 62.793997355869834, 51.389470849718364, 57.018550464085166, 50.23556613922119, 48.53244454520089, 43.37189238412039, 46.802627972194124, 44.30776957103184, 48.273856912340435, 48.441631589617046, 50.08301843915667, 51.07077087674822, 54.66450425556728, 52.49293858664376, 52.59134592328753, 51.6285514150347, 58.063934734889436, 57.21664360591343, 58.438532965523855, 54.59121118273054, 56.2822185925075, 53.550881726401194, 53.943145751953125, 50.44869518280029, 47.61306585584368, 46.71401759556362, 48.63830382483346, 47.05077593667166, 45.76206922531128, 47.64422505242484, 51.3250367300851, 51.843869141169954, 46.94356523241316, 41.376731055123464, 40.87177767072405, 39.723153591156006, 40.16081714630127, 36.59987926483154, 39.24850824901036, 39.18897260938372, 39.12168278012957, 41.83068118776594, 52.49950463431222, 49.372311523982454, 38.51096044267927, 39.57126944405692, 44.309968675885884, 43.680406297956196, 47.12681702205113, 50.95184203556606, 49.61390038899013, 49.21864863804409, 50.2414755821228, 42.66823789051601, 37.01322065080915, 39.76418965203421, 44.87665680476597, 43.94213799067906, 42.01465211595808, 42.53325523648943, 40.115844930921284, 40.06345898764474, 38.61170584814889, 38.25473172324044, 39.473331110818044, 40.018490246364046, 40.236635889325825, 37.85214614868164, 40.32712575367519, 41.775522913251606, 39.76193496159145, 42.832993575504844, 36.495357513427734, 34.413722378867014, 36.803951331547324, 33.83123057229178, 36.42266198566982, 39.679633549281526, 48.834597383226665, 39.32907261167254, 37.94304248264858, 43.35542515345982, 48.59545775822231, 43.04953418459211, 38.24753686359951, 36.536716665540425, 35.20717191696167, 34.80751153400966, 46.65994324002947, 47.22048568725586, 43.616666998182026, 37.12514918191092, 37.090175424303325, 37.109804085322786, 37.05700819832938, 36.41834715434483, 36.172717911856516, 37.75183500562395, 38.79004178728376, 40.11261401857649, 40.21442597252982, 41.50542558942522, 40.902266366141184, 43.49098450796944, 44.62577819824219, 45.759314264569966, 45.55990791320801, 43.261138098580496, 41.825317178453716, 41.45734405517578, 41.59182643890381, 42.157055446079795, 40.021095820835654, 42.0230142729623, 41.85907847540719, 41.65594094140189, 41.196532998766216, 43.949944291796, 43.47476046425955, 44.895878996167866, 44.07524810518537, 45.12126466206142, 46.27096223831177, 48.80763142449515, 46.984868798937114, 54.21422277178083, 59.702479771205354, 63.10198320661272, 57.9346148627145, 65.22829178401402, 61.25659029824393, 67.75020994458879, 28.050879989351543, 0.6715424167258399, 0.8212165481277874, 0.20759160071611404, 0.10987453096147094, 38.170571667807444, 75.98645169394356, 63.87224660600935, 61.65217208862305, 53.56147078105381, 33.55801003319876, 17.567708935056412, 50.105516706194194, 60.30596555982317, 73.46128177642822, 3.365709134510585, 0.37130169038261684, 0.08246822335890361, 0.12171276179807526, 0.12828636834664003, 0.17967078036495618, 0.13064494250076158, 0.1666534931531974, 0.15225232020020485, 0.1148657463490963, 0.2407658291714532, 0.3582155182957649, 22.64657286235264, 69.42898505074638, 52.77622011729649, 52.75327021735055, 38.56657382420131, 40.89361238479614, 61.7227657863072, 66.31072384970528, 73.73805631910051, 45.663210255759104, 0.09311211042638336, 0.5682234093546867, 2.1401283272675107, 0.11746324625398431, 43.18807084219796, 79.32452610560826, 63.13183266775948, 67.50573757716587, 54.03482723236084, 61.24713379996163, 53.24734272275652, 51.707104274204795, 45.47134269986834, 51.462618010384695, 47.945599692208425, 51.3761442048209, 51.502260957445415, 52.52278804779053, 53.79835224151611, 58.47466359819685, 55.23248822348458, 54.91245767048427, 55.67842360905239, 60.915183612278526, 60.445513180324006, 61.3918856212071, 56.27703176225935, 57.98480517523629, 54.68336514064244, 55.7881669316973, 51.6340126991272, 51.590749740600586, 50.94748204095023, 50.28016662597656, 47.70379890714373, 42.94069760186331, 46.84104108810425, 53.85994454792568, 55.53943879263741, 49.40244238717215, 43.40163762228829, 42.64690692084176, 41.352780614580425, 41.994669096810476, 38.59294918605259, 39.97744723728725, 42.76630823952811, 41.87369748524257, 43.287239006587434, 54.13422468730381, 50.333170958927695, 38.712756974356516, 41.025131361825125, 44.23812777655465, 44.58435303824288, 47.731477056230815, 55.113840784345356, 52.45644664764404, 50.726654393332346, 52.11908728735787, 42.383775166102815, 37.500848702022004, 43.08170781816755, 46.32849332264492, 47.15155955723354, 44.96935619626726, 44.67354358945574, 43.272362913404194, 42.35772289548601, 41.07541200092861, 40.547185625348774, 42.337771143232075, 41.72036116463797, 42.18994474411011, 40.253151757376536, 42.78636768886021, 45.52365221296038, 42.670746190207346, 43.79009403501238, 36.855670247759136, 35.52964128766741, 37.2019476209368, 35.13275671005249, 36.021886416843955, 40.32799775259835, 51.04466996874128, 38.865676403045654, 38.98208999633789, 44.53248473576137, 48.191020488739014, 43.484230858939036, 38.173514229910715, 36.804184096200125, 35.40072441101074, 36.07429667881557, 49.735156876700266, 49.583675725119456, 44.775206157139365, 39.937634059361045, 39.07132918494088, 38.4144013268607, 37.55069855281285, 38.43455457687378, 38.62393467766898, 40.09034851619175, 39.99928542545864, 43.49442734037127, 41.85726152147566, 41.70209435054234, 44.11577694756644, 45.25618825639997, 46.35203729357038, 47.80823728016445, 47.01309585571289, 46.187764508383616, 43.649851594652446, 43.99762977872576, 43.369818346840994, 44.07439347675869, 42.36038058144705, 46.213823727199006, 45.120660168784006, 42.96889339174543, 43.95451968056815, 46.9398409979684, 45.91203219549996, 46.776759828839985, 47.10413115365164, 47.34892661230904, 49.49339778082711, 52.10318980898176, 50.40717274802071, 55.985196999141145, 63.402124541146414, 67.14620998927525, 62.225120544433594, 68.81660556793213, 66.4124037878854, 70.36663750239781, 30.134184428623744, 0.8369399415595191, 1.5191315582820346, 0.67482077223914, 0.30622700655034607, 40.889686652592246, 82.08077921186174, 68.63833563668388, 69.47525310516357, 63.00841876438686, 56.01733589172363, 23.490612234388077, 56.17603274754116, 67.25305243900844, 84.33568504878453, 4.570803829601832, 0.5369532587272781, 0.2162726420376982, 0.34794746498976437, 0.19625223561057023], [0.042796313030911345, 0.07597047024007354, 0.026736118564648286, 0.2579914448516709, 0.030139738427741185, 0.06783255548881632, 0.10249318275600672, 5.294349278722491, 37.86379132952009, 39.32094669342041, 37.11053712027413, 33.16920273644583, 33.98949663979666, 47.82302304676601, 58.09748411178589, 58.23648977279663, 38.24347216742379, 0.02407679733421121, 0.14316991184438976, 0.7038248873182705, 0.30005456347550663, 13.031427230153765, 69.55544921330043, 53.88638244356428, 62.36197921207973, 49.87666736330305, 51.464632987976074, 42.303881304604666, 44.52078396933419, 41.83758074896676, 44.42286648069109, 40.775440897260395, 45.98719433375767, 43.95265061514718, 50.07287059511457, 50.732893875667024, 56.673801694597515, 55.92148201806204, 56.31095634187971, 48.003328800201416, 44.46400329044887, 44.53767851420811, 49.394907065800254, 48.4867844581604, 52.085023743765696, 50.04465396063668, 51.17292676653181, 51.3358724457877, 53.37055860246931, 49.21724510192871, 48.66306025641305, 45.60507467814854, 35.583006926945274, 38.1337879044669, 51.318022523607524, 48.00647633416312, 45.94827052525112, 37.051491328648154, 38.49193974903652, 37.13409846169608, 39.21094628742763, 36.1884104183742, 37.823901721409385, 35.33767645699637, 39.82495859691075, 36.787828036717, 43.79428379876273, 51.847437041146414, 47.56789561680385, 39.924977915627615, 45.27955157416207, 43.463261195591514, 49.127088751111714, 50.30640649795532, 52.85266419819423, 50.702137674604145, 51.60171052387783, 44.11640228543963, 40.038726874760215, 39.99092674255371, 42.89043780735561, 38.05436652047293, 42.64051110403878, 42.27540411267962, 40.307775020599365, 38.054710456303184, 39.4545327595302, 37.119364806583945, 36.93633188520159, 36.374771526881624, 38.11929048810686, 38.785462924412315, 42.48676483971732, 38.678839342934744, 41.05225018092564, 35.88004241670881, 36.974418435777935, 32.60913624082293, 36.32277815682547, 35.352628980364116, 40.76842321668352, 39.345835140773225, 41.17981563295637, 39.217387267521445, 41.36780609403338, 49.35737289701189, 48.97815758841378, 47.374954564230784, 35.87346942084176, 36.159339155469624, 32.55785158702305, 40.143019335610525, 45.522165298461914, 49.523400102342876, 40.27920750209263, 35.62077038628714, 35.58096068246024, 33.92901257106236, 35.085484640938894, 34.70175995145525, 36.13756350108555, 36.902372564588276, 37.921034063611714, 36.79164259774344, 37.54743984767369, 38.09055273873465, 41.07638127463204, 43.1793578011649, 44.349972929273335, 48.07439497538975, 47.38632181712559, 45.43525723048619, 45.627597263881135, 42.02357012884957, 41.0915526662554, 41.80855464935303, 41.866690226963584, 43.42827354158674, 43.58268683297293, 44.70782947540283, 44.20910167694092, 40.75115694318499, 41.376498290470664, 41.96841880253383, 44.084947790418354, 45.10387332098824, 43.4736452783857, 44.53374930790493, 42.302012239183696, 48.85471241814749, 55.771890776497976, 58.862755230494905, 58.79674734388079, 62.312640053885325, 59.10512229374477, 66.06602219172886, 26.718436104910715, 0.17687737382948399, 0.5697954935686929, 0.21035787942154066, 0.08441890975726501, 27.192186866487774, 74.03586305890764, 57.721801962171284, 59.424475397382466, 45.012396812438965, 32.904069900512695, 40.845593384334016, 41.64104400362287, 53.47937434060233, 50.65864889962332, 2.2983987373965125, 0.1960601694881916, 0.11049427770610366, 0.06790975241788796, 0.09555989836475678, 0.04195958775069032, 0.10914150279547487, 0.05623920115509203, 0.21355516357081278, 0.05968476126768759, 0.08279358768569571, 0.25799388757773806, 9.36759000165122, 55.17779895237514, 47.27129438945225, 46.84218059267317, 27.795255763190134, 32.17969240461077, 55.429278578077046, 60.81695692879813, 63.96346255711147, 42.23176942552839, 0.03694982800100531, 0.1200285293161869, 0.9074391328862735, 0.6311908076916422, 16.03851464816502, 74.08926691327775, 56.7173182623727, 64.5434912272862, 51.2681622505188, 54.23818710872105, 44.6195421900068, 47.00644990376064, 43.24908644812447, 46.27161884307861, 43.960408278873985, 48.80344860894339, 46.81753533227103, 52.19194957188198, 51.81020164489746, 57.69453375680106, 59.971298626491, 58.20329475402832, 49.79271227972848, 47.07182897840227, 46.8904983656747, 49.774087633405415, 51.550589152744834, 51.66136428288051, 49.753069332667756, 52.79914569854736, 53.169234548296245, 53.87163141795567, 50.30561440331595, 50.42690563201904, 46.50848640714373, 36.13812977927071, 39.70458105632237, 52.630137716020855, 49.52619675227574, 48.285887718200684, 38.80832249777657, 41.49236992427281, 39.28373214176723, 40.06445605414254, 38.225118500845774, 40.66042389188494, 38.990094321114675, 40.69825683321272, 38.47519111633301, 44.932124274117605, 53.55782992499215, 49.244596685682026, 39.040489605494905, 43.26338584082467, 45.16524675914219, 50.47961466653006, 51.765066146850586, 54.0854309626988, 51.827235153743196, 51.66038806097848, 43.99050440107073, 39.36751699447632, 39.33308867045811, 44.326234408787315, 41.498112610408235, 44.57516057150704, 42.326400416237966, 41.79728814533779, 40.33806916645595, 43.05104194368635, 39.60720552716936, 39.70773206438337, 40.3152790750776, 40.141674859183176, 41.718255860464915, 44.58315794808524, 40.86783456802368, 42.82322440828596, 35.93726430620466, 37.75065381186349, 32.83065523420061, 35.90508025033133, 34.64449984686715, 39.686227389744346, 40.28113910130092, 43.36863020488194, 39.047590664454866, 42.45863158362252, 50.666660172598704, 52.28586489813668, 47.25243003027779, 35.825130803244456, 36.8467070715768, 33.81178603853498, 40.362905502319336, 47.768625599997385, 48.98604031971523, 42.518441677093506, 37.73909548350743, 38.88668080738613, 37.47336162839617, 37.189347062792095, 35.95709446498326, 38.75402232578823, 37.81120388848441, 38.873746735709055, 39.394680976867676, 39.5639842578343, 38.64978892462594, 43.52819211142403, 45.53054135186331, 46.63818495614188, 50.39932475771223, 49.881235803876606, 48.190343039376394, 47.54760340281895, 44.61775302886963, 43.47830751964024, 44.67467614582607, 44.46748086384365, 45.10347727366856, 46.68580443518502, 45.911771638052805, 45.988983494894846, 43.7045339175633, 44.061897141592844, 45.06092650549752, 44.916157313755576, 47.554350103650776, 45.99941968917847, 47.33183751787458, 45.173077378954204, 50.983164514814106, 57.995984826769146, 62.460782596043174, 62.043668338230674, 64.79349436078752, 62.75045994349888, 71.05928952353341, 29.12074450084141, 0.6771943962999752, 0.626746837581907, 0.14920048681753023, 0.1510933416762522, 30.186156954084122, 79.88283470698765, 62.54817008972168, 65.73164708273751, 51.76391969408308, 43.84263631275722, 41.19038731711251, 45.04315301350185, 59.22510378701346, 62.740343366350444, 3.5063293831689015, 0.17490318976342678, 0.06523946606154953, 0.10501209473503487, 0.12262636848858424, 0.16312786590840134, 0.23781143341745647, 0.14468981671546186, 0.3254484651344163, 0.17767736661647046, 0.16714144125580788, 0.42525722086429596, 17.913211584091187, 69.09604821886334, 57.46278701509748, 56.91794054848807, 46.50000613076346, 49.867075375148225, 60.66153267451695, 67.94163976396833, 69.6344015938895, 45.67621728352138, 0.2235642879136971, 0.43166259144033703, 2.3698553144931793, 0.7773946938770158, 19.67931512423924, 83.7242157799857, 59.84783608572823, 69.70793437957764, 53.221217496054514, 58.15347269603184, 46.79998765672956, 49.29643372126988, 45.59694528579712, 49.2504540170942, 45.29702629361834, 51.803284713200156, 48.57316793714251, 55.21924148287092, 54.00597136361258, 60.041176659720286, 59.608144078935894, 60.74655778067452, 50.32515273775373, 48.94283989497593, 48.15067229952131, 52.320317540849956, 53.72714362825666, 54.48229469571795, 52.177393095833914, 56.74040365219116, 57.58800745010376, 56.60009172984532, 51.32464763096401, 52.746846607753206, 50.1799909727914, 38.45262336730957, 41.189320768628804, 55.5627361025129, 53.83219344275338, 51.05776384898594, 42.218797138759065, 43.10487311226981, 41.022515365055625, 43.6216002191816, 41.95028053011213, 42.41955838884626, 40.99320786339896, 43.74380166190011, 41.604041372026714, 49.81162180219378, 56.336053235190256, 51.677084582192556, 39.32303810119629, 44.85517297472273, 46.11615637370518, 52.935347761426655, 52.169572898319785, 55.37446771349226, 55.17481122698103, 54.19027233123779, 45.24477236611502, 40.51852430616106, 41.87417343684605, 45.96646090916225, 43.41192790440151, 46.680992807660786, 44.41825982502529, 43.42923934119088, 41.045017106192454, 45.082792486463276, 42.31491156986782, 42.31114217213222, 42.0041811806815, 42.828029087611604, 43.32319940839495, 46.80619587217058, 42.49407434463501, 44.81732266289847, 36.03171811785017, 38.6823273386274, 32.37616661616734, 35.892788887023926, 36.15452057974679, 40.51200342178345, 41.82466057368687, 43.60977438517979, 39.82686240332467, 42.671197823115754, 53.20346137455532, 52.4800739969526, 49.643263476235525, 37.52986437933785, 39.25881242752075, 33.51041834694998, 42.64676448277065, 50.44073602131435, 52.146824496132986, 45.82265404292515, 39.34080464499337, 40.00408663068499, 39.14052629470825, 38.86674989972796, 39.223046575273784, 40.06234727587019, 40.43150159290859, 40.936548777988975, 40.99139438356672, 42.714255809783936, 42.05009487697056, 46.08196081433977, 48.871273449489046, 47.806336947849815, 53.87432037081037, 53.76529966081892, 51.65380811691284, 50.03116055897304, 47.20226056235177, 46.56547900608608, 48.75680187770298, 46.384829316820415, 47.24530117852347, 47.69466897419521, 49.99685730252947, 49.04322746821812, 46.72100053514753, 45.93403366633824, 48.28106219427926, 47.95218311037336, 49.71526765823364, 48.07773011071341, 49.98948873792376, 47.85506119046892, 54.074199199676514, 60.711170605250764, 63.97261333465576, 65.83129119873047, 68.42795807974679, 66.5664175578526, 74.67099789210728, 30.99039704459054, 0.8255477185760225, 1.7918899336031504, 0.5001871372972215, 0.20079174345093115, 33.23830604553223, 86.93424183981759, 69.1588807787214, 73.07112652914864, 60.53665270124163, 52.01756368364607, 51.37838152476719, 58.15280566896711, 65.97126960754395, 78.75294644492013, 4.792022747652871, 0.3923155127891472, 0.29921868975673405, 0.24016684559839113, 0.2645000341747488], [0.028049402737191746, 0.06975508268390383, 0.06147430916982038, 0.09128151794097253, 0.12231946709964957, 0.0933223409312112, 0.10495256685784884, 4.530215059007917, 36.63133723395211, 36.691018785749165, 32.5354505947658, 31.550425325121196, 31.359895297459193, 46.27213648387364, 55.933026450020925, 55.59938437598092, 38.26669652121407, 0.05572231014126113, 0.06128832950655903, 1.183221223098891, 0.08900571148842573, 2.183314855609621, 60.54997934613909, 60.49599184308733, 61.06055382319859, 53.97025414875576, 52.03718539646694, 47.14957237243652, 48.51764488220215, 40.55536365509033, 44.34196513039725, 43.35796124594552, 46.37319108418056, 45.28824724469866, 47.60856342315674, 49.67689275741577, 53.08717284883772, 55.30635452270508, 55.65208993639265, 53.788697719573975, 55.23091445650373, 46.46236079079764, 46.95733308792114, 44.45955644335066, 45.98722907475063, 50.92711339678083, 53.76213823046003, 48.53811080115182, 49.55961411339896, 51.19055782045637, 50.396038259778706, 48.43371411732265, 52.20798601422991, 48.801086221422466, 50.92681115014212, 45.80759382247925, 40.7395395551409, 36.61560303824288, 39.907398973192485, 38.529692786080496, 38.408592632838655, 37.70185661315918, 37.527501991816926, 39.3151901108878, 38.61080258233206, 37.71784789221627, 38.30192388807024, 39.17831059864589, 47.569483280181885, 43.58125550406319, 41.34594011306763, 39.61807598386492, 45.13934734889439, 48.03398772648403, 52.24553060531616, 51.40428440911429, 51.7250862121582, 44.048639978681294, 40.106308528355186, 36.289440699986045, 41.240000929151265, 37.49559586388724, 38.53269440787179, 38.214185510362896, 36.9787471635001, 36.66693632943289, 39.27297633034842, 40.3989006451198, 39.083617074149, 39.848186424800325, 40.949239662715364, 43.34313726425171, 39.791968550000874, 40.933873721531455, 40.07331848144531, 35.22594942365374, 36.11583648409162, 34.22440481185913, 35.331704480307444, 39.239656244005474, 43.000632762908936, 43.264497552599224, 44.34266689845494, 40.18049097061157, 44.65274068287441, 48.51850298472813, 48.62906619480678, 38.47956500734602, 34.91555254799979, 34.04656914302281, 42.14491694314139, 46.00171954291207, 48.13151611600603, 39.763130051749094, 34.13264342716762, 34.22839307785034, 35.06676966803414, 34.441053118024556, 36.075259004320415, 37.333282470703125, 36.52702045440674, 36.489149297986714, 38.428752831050325, 37.48825856617519, 38.97426285062517, 37.91833816255842, 40.04808609826224, 43.61673648016793, 46.697171688079834, 47.72337893077305, 50.009902545383994, 50.36318022864205, 50.37208087103707, 46.56891489028931, 46.9570551599775, 44.54477609906878, 44.751745564596995, 44.074271883283345, 44.33798033850533, 48.00753246034895, 48.481608050210134, 50.0303441456386, 51.3336455481393, 47.58452960423061, 46.28014428274972, 43.92591742106846, 47.287334305899485, 48.35045732770647, 44.9947692326137, 44.96551731654576, 52.96952942439488, 60.26334530966622, 58.088878767830984, 60.690145356314524, 57.97716563088553, 66.71797166551862, 26.932725497654506, 0.20158940207745346, 0.22483511615012372, 0.2544250376522541, 0.11145789921283722, 20.02027017729623, 71.2873432976859, 57.54689495904105, 58.483536447797505, 48.336119719914024, 26.324940511158534, 13.018515740122114, 45.38963188443865, 48.970233167920796, 58.54921082087925, 2.1482310124805997, 0.11388660674648625, 0.07232825032302312, 0.013593692532075303, 0.0758930290383952, 0.02605024858244828, 0.0393206734609391, 0.08178672992757388, 0.12667435913213662, 0.10655331239104271, 0.18782747696552957, 0.1655675657093525, 8.726333805492946, 49.922893728528706, 46.2550300189427, 37.718959603990825, 24.87565224511283, 36.53209958757673, 51.47546175548008, 60.9929895401001, 62.392071860177175, 43.06755086353847, 0.05087072029709816, 0.14206330265317643, 2.234650318111692, 0.6812267399259976, 3.400875053235463, 68.79435048784528, 60.82537119729178, 62.94156319754464, 55.15689182281494, 53.26936156409127, 49.57082503182547, 50.95528139386858, 41.643326486860005, 46.66615145547049, 45.100836958204, 50.03061859948294, 48.527768407549175, 51.22193935939244, 50.98187909807478, 56.22620221546718, 55.59926973070417, 58.19870546885899, 52.48792198726109, 55.85245861325945, 49.023001262119834, 48.4680312701634, 47.00297580446516, 49.08424615859985, 53.971213000161306, 55.26044430051531, 49.8289019720895, 52.16917337690081, 51.15577513831002, 52.2031500680106, 51.62227371760777, 53.3225222315107, 50.50934253420149, 52.00465045656477, 48.27499641690935, 44.099928106580464, 38.37847914014544, 42.32062646320888, 40.50505174909319, 39.953868525368826, 38.71894781930106, 39.816520009722026, 40.50276926585606, 40.36964178085327, 38.91633571897234, 39.359477928706575, 42.62909868785313, 49.66721739087786, 44.987115791865754, 43.03835105895996, 41.956370626177105, 48.389853613717214, 48.082510471343994, 53.13177333559309, 52.54318448475429, 53.416020665849956, 43.600981439862935, 41.36818824495588, 37.46102857589722, 43.8099867275783, 40.01762866973877, 41.427643980298726, 39.73837014607021, 37.76169797352382, 38.842625754220144, 41.42758839470999, 42.80199071339199, 40.28633982794625, 41.00367532457624, 44.224387713841026, 43.68410621370588, 41.84914949962071, 41.89176280157906, 40.81257554462978, 34.09283372334072, 35.69830880846296, 33.91188178743635, 37.82264062336513, 39.65452970777239, 43.45743860517229, 43.61004883902413, 46.009435517447336, 39.75493117741176, 46.904735224587576, 49.77482066835676, 49.085211958204, 38.347024645124165, 35.27423940386091, 35.28288991110665, 43.1086425100054, 48.166993618011475, 50.487636361803325, 39.84225613730294, 36.110340459006174, 36.43790633337838, 38.35542154312134, 37.219394547598704, 37.61307947976248, 40.27351345334734, 39.83671842302595, 40.01066310065133, 40.27489961896624, 39.21059887749808, 40.043958868299214, 39.5150203023638, 42.102810859680176, 45.2713804926191, 49.48071731839861, 49.796829087393625, 52.90762792314802, 51.66170474461147, 51.83951262065342, 50.11754751205444, 48.06277411324637, 46.38395036969866, 47.89118487494332, 46.689316749572754, 45.853587423052105, 50.93992934908186, 50.494324002947124, 52.100507804325645, 51.64266668047224, 52.00628675733294, 48.34960617337908, 47.929382596697124, 50.66825131007603, 50.65611975533621, 47.46699387686593, 47.79030745370047, 56.93777070726667, 63.125370843069895, 62.41787052154541, 64.76428413391113, 60.50804001944405, 71.31734561920166, 28.875292437417166, 0.47410001712185995, 0.42467416929347174, 0.08978381473571062, 0.08438742573239974, 21.416574954986572, 77.37397221156529, 63.120576586042134, 66.2206335067749, 54.42989138194493, 36.48087746756417, 20.785596881593975, 53.7391813823155, 54.08518777574812, 69.41558197566441, 3.753207564353943, 0.26495174850736347, 0.14992200024425983, 0.027595199877396226, 0.1111548790442092, 0.06154239337359156, 0.10356910859367677, 0.14292102519954952, 0.20462400067065442, 0.2345790011542184, 0.31782827260238783, 0.37177400503839764, 15.69238839830671, 68.20681081499372, 52.602331025259836, 47.358758313315256, 42.51353972298758, 47.45176689965384, 59.378082275390625, 66.64010320390973, 68.01290743691581, 48.37350102833339, 0.14877561533025332, 0.389561474855457, 3.3953933588096072, 0.42082494869828224, 5.568671541554587, 77.80530943189348, 63.918000493730815, 66.30158002035958, 57.33523545946394, 56.37170444216047, 51.840902260371614, 56.07133034297398, 43.24918719700405, 48.57762173243931, 46.90518338339669, 51.86421346664429, 49.68236446380615, 53.60983371734619, 54.17849166052682, 59.07812854221889, 58.85841955457415, 58.598084449768066, 53.74590029035296, 58.797608920506065, 49.30236400876726, 50.63782862254551, 48.19953203201294, 49.985000201633994, 55.43486145564488, 56.210485390254426, 52.59935024806431, 54.98249898638044, 53.54576437813895, 52.92948348181588, 51.04227978842599, 54.73605680465698, 52.383198738098145, 54.48442431858608, 51.82011325018746, 46.88178532464163, 39.68174580165318, 44.986962931496755, 42.09890597207205, 41.194174085344585, 40.27794640404837, 42.45505673544747, 42.04104484830584, 42.47190611703055, 41.14383438655308, 43.48508201326643, 44.13554457255772, 51.728827817099436, 45.98849712099348, 44.70863199234009, 42.57927662985665, 50.976619311741416, 52.45433439527239, 55.2615282194955, 53.836779253823416, 55.89881352015904, 45.31098175048828, 41.76691409519741, 38.61102145058768, 45.29517112459455, 43.27399921417236, 43.626748834337505, 40.32518720626831, 40.645645073481965, 39.720211029052734, 43.82868432998657, 46.03662729263306, 42.116512707301546, 43.88552059446062, 46.7653717313494, 45.61390583855765, 43.760591983795166, 43.66853877476284, 43.014935629708425, 36.092031955718994, 36.24001121520996, 34.241462639399934, 37.552404335566926, 40.61985336031233, 46.57992083685738, 43.97949845450265, 46.95564814976284, 40.99180432728359, 47.324885845184326, 52.52698128564017, 52.586989402770996, 41.70640918186733, 36.723268849509104, 35.57177168982369, 45.97008786882673, 52.251380988529746, 51.55816963740757, 43.04393393652779, 38.26725237710135, 39.114227363041465, 38.990368774959016, 39.4397018296378, 42.62701422827584, 41.13018465042114, 42.10061870302473, 41.40319674355643, 41.61293159212385, 41.786789417266846, 43.33360086168562, 41.09517962591988, 44.13681261880057, 48.09702525820051, 50.499889510018484, 52.51156670706612, 55.334477356501985, 54.273094858442036, 54.95632512228829, 51.73582117898123, 50.68140425000872, 49.47558607373919, 50.30942896434239, 47.746373994009836, 47.72491100856236, 53.03121900558472, 53.620443616594585, 53.83030353273664, 55.37002086639404, 52.78032650266375, 51.52073621749878, 50.80132320949009, 54.4312219619751, 53.37182664871216, 49.361541816166465, 50.78493588311331, 59.95018999917166, 66.80826350620815, 64.10774190085274, 68.11908980778286, 62.37622996738979, 73.29476124899728, 32.058178833552766, 0.9107571691274643, 1.1224522782223565, 0.42754258108990534, 0.18773602401571615, 25.53333224569048, 82.62655326298305, 69.13432584490094, 72.63370268685478, 64.50662408556256, 38.69253771645682, 19.389537027903966, 65.65277113233293, 59.0675116947719, 84.81816101074219, 5.691391493592944, 0.5808290157999311, 0.28894330827253206, 0.14112726359495095, 0.22413796213056358], [0.05971946154854127, 0.06295755279383489, 0.06282120796718768, 0.03982633811288646, 0.0322210496025426, 0.06976261442261082, 0.051315276085266044, 6.779361273561205, 44.62866864885603, 30.754345893859863, 55.63002593176705, 35.3962219783238, 26.697612353733607, 51.00927584511893, 54.62008094787598, 61.12880597795759, 25.059902838298253, 0.17500111593731812, 0.03724366419815591, 0.9667037384850639, 0.4955158308148384, 0.14357514652822698, 37.93040370941162, 65.66824477059501, 57.57350655964443, 60.5843242917742, 55.167956829071045, 53.755933489118306, 50.956691878182546, 47.385699953351704, 45.26687805993216, 45.57749032974243, 47.294435364859446, 46.97044781276158, 48.138902051108225, 48.22848170144217, 51.75982025691441, 50.95687600544521, 53.462653500693186, 53.30826800210135, 51.80054712295532, 53.71920878546578, 51.44881888798305, 50.278495584215435, 48.753459794180735, 50.86686209269932, 49.69227606909615, 49.4635830606733, 51.88388729095459, 52.043365819113596, 50.58831923348563, 50.60027360916138, 47.933131149836946, 47.937077726636616, 45.57015650612967, 38.99580921445574, 37.902982643672395, 37.98620121819632, 38.81410339900425, 39.178352287837434, 38.173444747924805, 39.666324274880544, 39.438774245125906, 38.53764499936785, 38.994159017290386, 38.127711704799104, 39.319115843091694, 39.42620842797415, 41.00802142279488, 44.96948821204049, 43.29957553318569, 43.16119868414742, 41.84494931357247, 43.3195481300354, 46.892805167606895, 50.79652547836304, 49.15142134257725, 49.77251386642456, 47.951380593436106, 38.8330511365618, 41.61501605170113, 36.91717222758702, 38.18308537346976, 39.840143884931294, 34.628505093710764, 36.07772214072091, 37.72377470561436, 38.64909757886614, 39.66879783357893, 40.294792311532156, 38.22132478441511, 38.21756928307669, 37.53003461020333, 41.65632309232439, 37.082226685115266, 34.51345682144165, 36.83513137272426, 34.56443575450352, 36.94183833258492, 42.37863349914551, 39.3174204826355, 41.254647731781006, 46.75827762058803, 45.660219056265696, 48.07614592143467, 43.56010171345302, 38.90318277903965, 38.905604226248606, 38.94327735900879, 38.543797629220144, 43.695591585976736, 43.979696478162495, 37.166803632463726, 35.147657121930806, 36.75980247770037, 35.990793228149414, 36.12263877051217, 35.55281005586897, 36.496771471840994, 35.54183537619454, 38.00933524540493, 38.10872575214931, 39.27564443860735, 38.61241109030587, 37.57861294065203, 38.78535522733416, 39.35202598571777, 40.60192353384835, 44.600247042519705, 48.405118806021555, 49.48692553383963, 49.88220855167934, 51.89231545584542, 50.08060046604702, 48.52233144215175, 46.46558822904314, 45.980850628444124, 51.327583244868684, 55.88793611526489, 56.18813303538731, 57.56332050051008, 53.79046951021467, 53.00168221337454, 51.87950645174299, 54.6213698387146, 53.584514481680735, 53.26076316833496, 50.60128804615566, 47.85827125821795, 45.359785897391184, 49.2165607043675, 60.26971680777413, 59.23402527400425, 61.39155905587332, 59.850198473249165, 66.61656965528215, 27.42338296345302, 0.21109201359961713, 0.15458410579179013, 0.27207034081220627, 0.12448332884481975, 14.516942535127912, 72.14192308698381, 59.06572600773403, 60.914516585213796, 47.59475040435791, 34.777019364493235, 29.871309757232666, 36.73558105741228, 45.86075101579939, 61.78437546321324, 3.1145113451140265, 0.14787681427385124, 0.04965834106717791, 0.08887780085206032, 0.049470970407128334, 0.051678071796361885, 0.027163658390886018, 0.07997187266924552, 0.09416295760976416, 0.038507951357002766, 0.05875600967556238, 0.1085862440190145, 10.928140640258789, 60.57074751172747, 38.474791594914024, 63.15002999986921, 43.62108257838658, 30.366518293108257, 58.05346727371216, 59.729834829057964, 65.45260047912598, 29.143472058432444, 0.15694078004785947, 0.08915594592690468, 1.466466709971428, 0.5531359932252339, 0.14564341625997, 46.02065685817173, 67.46011570521763, 60.80146244594029, 61.30855587550572, 59.00574915749686, 56.94086612973894, 54.43538393293108, 49.351765700748985, 47.09329196384975, 47.069445746285574, 47.763428347451345, 47.274650369371685, 51.39625576564244, 51.33499697276524, 54.24546534674508, 54.08434009552002, 56.348681586129324, 54.904081617082866, 54.12872518811907, 54.490910461970735, 50.71928235462734, 51.559184074401855, 51.19519574301583, 52.844190870012554, 53.10281324386597, 50.74712378638131, 54.66059936795916, 53.5832325390407, 54.68171494347708, 52.01820639201573, 51.035633836473735, 50.580221108027864, 47.08968237468174, 41.2146052633013, 40.213001591818674, 38.898246083940776, 41.10208266122, 41.31816816329956, 39.301998955862864, 40.90922498703003, 40.532649993896484, 39.7798821585519, 40.364225660051616, 38.932434695107595, 41.4431141444615, 40.76939596448626, 44.539759499686106, 45.05279016494751, 47.51326193128313, 44.43534197126116, 44.76510347638811, 46.763568673815044, 47.67870896203177, 51.32777084623064, 49.69019160951887, 50.8762560571943, 47.81676271983555, 39.11837196350098, 42.35395349775042, 39.25591850280762, 40.036909920828684, 40.71476575306484, 37.815233843667166, 38.554303305489675, 40.31179802758353, 40.31514358520508, 40.413453647068565, 40.52942950384957, 39.869899545397075, 39.339241300310405, 38.836254256112234, 43.895571163722444, 39.09688465935843, 34.68884672437395, 37.106323037828716, 36.406125273023335, 36.55420528139387, 42.29976102284023, 39.409650870731895, 42.00631775174822, 45.326941762651714, 47.47522749219622, 50.03121961866106, 44.55226278305054, 42.208267143794465, 39.1722343989781, 39.42042057854788, 39.40087877001081, 44.64402069364275, 45.02863127844674, 38.17079053606306, 37.923591000693186, 39.20180245808193, 36.13562147957938, 38.54425621032715, 37.54170758383614, 39.229178360530305, 37.62315436771938, 38.97952611105782, 40.383347102573936, 40.790626185280935, 39.79090200151716, 40.42499460492815, 40.344975675855366, 42.223264830453054, 43.96526506968907, 47.25097785677229, 51.21327495574951, 52.254844665527344, 51.0720979826791, 54.33178629193987, 52.885011536734446, 50.601934228624614, 48.01663112640381, 48.561050278799875, 53.37936544418335, 58.177221638815745, 57.895861285073416, 58.802959033421104, 57.96697957175118, 55.189885343824116, 53.66755240304129, 56.85331882749285, 56.982850619724815, 54.35319021769932, 52.85301855632237, 51.52861547470093, 48.65528522218977, 50.201627663203645, 62.995363099234446, 62.508523668561665, 64.25078446524483, 62.50780800410679, 67.33791773659843, 29.61412913458688, 0.4031645549195153, 0.31928069038050516, 0.1303930567311389, 0.18074809041406426, 16.15498730114528, 78.08726733071464, 63.45654283251081, 67.40659373147147, 55.063435077667236, 36.949946880340576, 23.315083367483957, 45.923983097076416, 51.6339327948434, 72.78208146776471, 4.621071875095367, 0.18520913246486867, 0.039446755445429256, 0.06228032734777246, 0.024881185331780995, 0.16615107868398937, 0.10263379556792122, 0.15034554180290016, 0.17881206715745585, 0.09658136498183012, 0.2260530050843954, 0.2793157105999333, 19.077328409467423, 76.59935229165214, 45.13730110440935, 69.53578581128801, 50.81955180849348, 39.140324796949116, 65.43169334956578, 67.25457409449986, 71.44726998465401, 35.15691907065255, 0.36251257200326237, 0.25394200214317864, 4.826424581663949, 1.650315067597798, 0.38787588530353134, 51.64706836427961, 70.853928565979, 64.74699006761823, 64.10164833068848, 62.47362286703927, 59.9072014944894, 57.87196295601981, 51.591580050332205, 50.45060246331351, 49.475259508405415, 49.98710897990635, 50.208617550986155, 53.18476377214704, 52.19486434119088, 57.857941491263254, 55.80660745075771, 58.12850087029593, 56.77989373888288, 55.01602404458182, 56.902675356183735, 54.176424571446006, 54.96825517926897, 53.02169302531651, 56.0474076952253, 51.471167768750874, 52.923914500645225, 54.8962926864624, 54.8577892439706, 55.4291535105024, 55.11609200068882, 54.160808495112825, 51.79937982559204, 50.18496935708182, 43.50799717221941, 42.13047511237008, 41.4230512210301, 42.40806259427752, 41.9912679536002, 41.25018004008702, 43.37868424824306, 42.98408910206386, 42.701280048915315, 43.547626222882954, 39.765273571014404, 42.09965985161917, 43.1578357560294, 45.64850091934204, 48.96895817347935, 48.85527522223336, 46.63638884680611, 46.35790157318115, 48.89592565808977, 51.63607284000942, 53.325106961386545, 52.66871758869716, 55.40330273764474, 51.578753675733296, 41.521462031773154, 45.85232285090855, 39.0932160105024, 41.52380010059902, 43.72885261263166, 36.66728721346174, 39.51776484080723, 40.11496598379952, 41.544022832598, 41.718467780521934, 42.993660245622905, 41.067723819187705, 40.847823756081716, 40.224473067692344, 45.30021899087088, 38.334573473249165, 36.41757590430123, 38.215161732264924, 36.54619748251778, 38.558479172842844, 44.24223068782261, 41.30186421530587, 44.29263986860003, 47.22523478099278, 49.36531121390206, 51.84488010406494, 47.68990250996181, 45.25779676437378, 40.349029949733186, 41.64319099698748, 39.55280113220215, 47.654317310878206, 48.12510987690517, 40.679552282605854, 38.3977986063276, 41.81612123761858, 38.06195395333426, 40.40198564529419, 39.73912055151803, 41.75932318823678, 39.415000983646934, 42.710267543792725, 43.255075795309885, 43.28369195120675, 41.76091085161482, 42.62122637884957, 43.68146242414202, 45.439269815172466, 45.70988130569458, 50.84025396619524, 53.82481445584978, 53.76459094456264, 52.62823043550764, 57.32085963657924, 55.11939239501953, 53.12029143742153, 50.68420089994158, 50.72383342470442, 56.300645215170725, 61.92110211508614, 61.96790518079485, 60.569878986903596, 61.28284754071917, 57.92788553237915, 58.30403668539864, 60.56207615988595, 59.872870445251465, 56.5956448827471, 55.66447857448033, 53.98615162713187, 52.11478635243007, 52.942448820386616, 65.72921521323067, 63.97602490016392, 67.04038892473493, 68.05273451123918, 72.85645498548234, 32.0051258632115, 1.0514640531369617, 1.0954528812851225, 0.8044735608356339, 0.3201796407146113, 19.07695494379316, 85.00492858886719, 67.4732825415475, 74.09392915453229, 62.29668698992048, 52.513661588941304, 39.4586877822876, 55.25521230697632, 59.67791788918631, 87.21840231759208, 7.737624253545489, 0.26975151523947716, 0.10024499946406909, 0.3374499039990561, 0.1151362375489303], [0.0902990603021213, 0.05349489341356924, 0.030398857380662645, 0.1024514257109591, 0.062432522752455304, 0.15171467619282858, 0.15790951092328342, 5.989997710500445, 42.75054972512381, 46.28974321910313, 28.45031108175005, 11.661186013902936, 33.49790464128767, 44.153505665915354, 61.48765959058489, 57.339991501399446, 30.862539768218994, 0.5756904972451073, 0.2119928774024759, 3.3282744118145535, 0.9932350005422319, 0.47412086171763285, 11.04690706729889, 73.8983929497855, 55.4839574268886, 58.574801036289756, 54.90270239966256, 60.047485624040874, 53.80202089037214, 48.12649951662336, 47.557785987854004, 45.076275076184956, 46.470736844199045, 46.857820987701416, 47.39648355756487, 49.485327448163716, 50.23897075653076, 52.231495244162424, 51.37147848946707, 54.479136739458355, 52.99906274250576, 49.75828048161098, 50.758046354566304, 48.67354161398751, 48.02318327767508, 50.19777488708496, 47.75768218721662, 49.63737835202898, 49.244172845567974, 50.07890510559082, 51.0045336995806, 46.907778535570415, 48.03198317119053, 46.44803360530308, 43.05304997307913, 39.253180912562776, 38.375929151262554, 38.230871609279085, 40.2634003502982, 42.33980696541922, 42.26355048588344, 39.77441045216152, 37.91131353378296, 39.04781995500837, 39.134404931749614, 38.29298850468227, 39.67348091942923, 39.26814733232771, 37.003701618739534, 41.96857861110142, 42.4940048626491, 44.144716194697786, 45.05992596490042, 46.71617153712681, 45.64600651604788, 43.6136862209865, 46.7659067426409, 47.00276735850743, 47.89763280323574, 40.281208583286826, 38.7490474155971, 38.45573616027832, 37.574235575539724, 36.70335531234741, 35.56353807449341, 37.5296767779759, 38.22467381613595, 37.6803206716265, 38.03317104067121, 39.14989594050816, 39.575744083949495, 37.32874182292393, 36.70479358945574, 42.225380556924, 39.48467404501778, 34.22877870287214, 36.07810081754412, 35.20011602129255, 37.244196142469136, 41.50366769518171, 42.020891598292756, 42.03235265186855, 46.791354519980295, 47.30399261202131, 47.18597398485456, 39.74391828264509, 41.2744813646589, 39.599541664123535, 37.975709438323975, 41.236339228493826, 41.897227559770855, 35.9890388080052, 34.76488433565412, 33.801752839769634, 36.01720680509295, 35.572932038988384, 36.847547803606304, 34.756028856549946, 36.73888839994158, 36.53448281969343, 37.83459847314017, 39.73278032030378, 40.30940089906965, 40.85033900397164, 40.354140349796836, 37.48719549179077, 39.04713208334786, 38.768564905439106, 40.6596804346357, 43.792251450674875, 49.39894049508231, 50.82616301945278, 52.590494768960134, 52.46199478421892, 52.033468110220774, 51.121110575539724, 51.27817113058907, 48.103914397103445, 43.39064557211739, 44.33037553514753, 51.58067832674299, 55.498350620269775, 59.707447733197895, 57.12332929883684, 54.34743363516671, 53.42291675295149, 59.81019074576241, 58.05154262270246, 50.85782248633248, 50.75144209180559, 45.133906909397666, 58.38698428017752, 59.11875465938023, 66.37769058772496, 57.6975770677839, 63.79910291944231, 29.622303690229142, 0.08080174135310308, 0.12825599711920532, 0.2587289038513388, 0.10445328722042696, 11.994160192353384, 74.58145645686558, 58.02960368565151, 65.45026588439941, 47.94605132511684, 36.13649000440325, 18.892711298806326, 32.98187582833426, 44.58265767778669, 64.78061934879848, 3.4496131922517503, 0.2960509354514735, 0.0809450683050922, 0.0706769742869905, 0.04406141443178058, 0.03661860452432718, 0.13230033724435739, 0.024728937340634208, 0.08262343145906925, 0.061936357590769014, 0.11165455901729208, 0.2394060721354825, 10.414071219308035, 56.38179670061384, 51.640332085745676, 39.61674540383475, 15.955040727342878, 39.06143495014736, 50.43202992847988, 68.01428318023682, 62.647723879132954, 37.80125754220145, 0.599907900605883, 0.10122445119278771, 3.146524735859462, 2.698415215526308, 1.435397514275142, 12.919833081109182, 74.60981900351388, 57.98382895333426, 61.42195047651018, 58.41062205178397, 62.91671643938337, 56.14147935594831, 51.12624529429844, 50.15972307750157, 46.621196610586985, 48.71316024235317, 47.72254862104143, 49.0344831602914, 52.120626313345774, 53.36406898498535, 53.95835535866873, 54.44981186730521, 56.105199337005615, 54.55283628191267, 52.504135608673096, 53.051684924534385, 50.68423564093453, 50.35250779560634, 52.8647540637425, 53.295615332467214, 51.659033162253245, 51.678515911102295, 51.98174224581037, 52.99815252849034, 48.44191299165998, 50.45848172051566, 47.26038919176374, 44.716594627925325, 43.55184030532837, 40.586373465401785, 40.4031286239624, 42.4616436277117, 44.84493480409895, 44.47792053222656, 40.39992550441197, 39.48179401670183, 40.279707772391184, 39.959732804979595, 40.23935958317348, 39.51002107347761, 39.77835702896118, 39.120626653943745, 43.04263114929199, 45.361338819776265, 43.39820868628365, 45.64644772665841, 47.768556118011475, 47.82941886356899, 45.457887513296946, 48.98625571387154, 48.7490233693804, 50.32945019858224, 42.8304956981114, 40.61278704234532, 39.41271502631051, 39.22363369805472, 37.87541913986206, 36.262849943978445, 38.25374507904053, 38.65240492139544, 38.135028157915386, 38.353017466408865, 37.72970151901245, 39.083648341042654, 37.51950461523873, 38.33203738076346, 45.58801337650844, 40.59154987335205, 35.13714797156197, 36.15558018003191, 35.894855976104736, 36.704609462193076, 41.6292633329119, 41.49149792534964, 42.87961251395089, 46.49633400780814, 49.15587861197335, 47.36635269437517, 42.5761638368879, 43.14385250636509, 39.64957216807774, 38.54408597946167, 43.033396993364605, 43.203099795750205, 37.373714038303916, 36.403783730098176, 36.05554001671927, 38.176547118595664, 36.874287945883616, 38.32189995901925, 36.438417025974815, 38.95947013582502, 39.30780764988491, 38.826961040496826, 41.23960835593087, 41.80727618081229, 42.80307463237217, 42.347238063812256, 40.324770314352854, 39.36981337411063, 41.36985581261771, 43.908991609300884, 45.672180380140034, 50.88803325380598, 51.92393323353359, 54.499675614493235, 54.72829219273159, 55.69364711216518, 52.93687983921596, 53.838109833853586, 49.284024238586426, 45.54731777736119, 47.19603845051357, 53.28251102992466, 56.76315900257656, 61.94451754433768, 61.47618811471121, 57.42746932165963, 56.5304707799639, 61.58731065477644, 61.44262831551688, 54.097687585013254, 53.269153118133545, 46.140016487666536, 59.26882880074637, 61.54787267957415, 68.7124034336635, 61.646252223423545, 68.51684638432094, 32.277276379721506, 0.2624255083501339, 0.40917632090193884, 0.11769246895398412, 0.18954972097916262, 13.9151451587677, 79.84519631522042, 62.079805919102256, 73.30623967306954, 54.369469846997944, 42.94159391948155, 26.93732520512172, 47.87449530192784, 48.26001957484654, 78.52294717516217, 5.55396090235029, 0.2659587487578392, 0.08224875799247197, 0.12781063387436525, 0.06604359112679958, 0.13556201436689921, 0.24979327619075775, 0.1690741939736264, 0.25813108735850876, 0.2041148551340614, 0.3691630022866385, 0.42681787854858805, 18.542666264942714, 72.12515013558524, 59.04096262795584, 41.6667662348066, 18.391977208001272, 49.94833108357021, 57.85786853517805, 73.68869631631034, 68.65713051387242, 43.642681053706575, 0.998739059482302, 0.24937472864985466, 7.553217325891767, 4.635134160518646, 0.8652443513274193, 15.010665893554688, 81.78092970166887, 61.18107727595738, 64.29514871324811, 61.748606136866975, 64.8562296458653, 60.409882817949565, 53.83543477739607, 53.845474924360005, 50.44929620197841, 50.70633438655308, 48.875887053353445, 51.47192164829799, 54.06726489748274, 54.489899499075754, 57.470447404044016, 56.06730733598982, 56.924430165972026, 56.95140307290213, 52.02627672467913, 52.99585962295532, 52.80290814808437, 52.834244523729595, 53.02687290736607, 51.44590411867414, 54.09533214569092, 53.53214938299996, 54.42492341995239, 56.50895915712629, 50.739498138427734, 52.64894648960659, 51.177269390651155, 48.37728432246617, 46.0388194492885, 43.5348276410784, 42.35520069939749, 44.34983049120222, 46.764392035348074, 47.51175764628819, 43.590142250061035, 40.474003723689485, 42.63689456667219, 41.994821957179475, 42.408566338675364, 41.88173655101231, 41.68008245740618, 41.79734025682722, 46.341997146606445, 48.22826978138515, 45.958668504442485, 49.84621340887887, 50.50428771972656, 51.33093575068882, 46.77802440098354, 50.55277224949428, 51.09364087241036, 51.32709687096732, 41.35777636936733, 41.898471287318635, 39.785802023751394, 41.893076011112754, 40.53719758987427, 36.44360038212368, 39.3775988306318, 38.590027468545095, 38.25439126150948, 40.02952398572649, 38.9858454976763, 41.26434394291469, 39.33662530354091, 42.12562526975359, 46.90306765692574, 41.52646820885794, 34.40108013153076, 37.915906293051584, 36.70156267711094, 37.8401118687221, 44.64443758555821, 42.98704556056431, 42.58697870799473, 48.99830389022827, 49.07215976715088, 53.92034523827689, 44.23044654301235, 43.33735636302403, 43.318676131112234, 40.90299245289394, 45.5733630997794, 44.666275773729595, 40.275677817208425, 39.257718086242676, 39.364821093423025, 38.85528884615217, 39.667561054229736, 40.87984105518886, 37.47294821058001, 39.6198581968035, 40.80622141701834, 40.397743770054404, 43.38650444575718, 45.19969245365688, 45.32963071550642, 45.41057028089251, 42.98100062779018, 43.61188316345215, 43.11070612498692, 46.0594972882952, 47.82022639683315, 54.55016469955444, 55.73700039727347, 56.90604870659964, 57.524049282073975, 57.9995562008449, 55.64903967721121, 55.860848563058035, 51.949148246220176, 47.6703884942191, 51.37651940754482, 56.83643817901611, 58.81438882010323, 64.80885682787213, 63.91531154087612, 60.157086508614675, 60.471693992614746, 63.835303034101216, 63.15799958365304, 57.4673033441816, 55.89332791737148, 49.44027532849993, 65.39825861794608, 64.68986892700195, 72.56098978860038, 65.62110819135393, 70.9190262385777, 34.02821200234549, 0.9362839822258268, 1.0822462013789584, 0.48283325135707855, 0.25839085770504816, 15.552385670798165, 87.80407987322126, 69.98336097172329, 81.66478361402238, 61.8339022227696, 52.079833439418245, 30.259491716112407, 50.53424835205078, 56.915974208286826, 91.35008607591901, 9.297393219811575, 0.4773808696440288, 0.17257570608385972, 0.21870137671274797, 0.2078320056732212], [0.04116098256781697, 0.10895692769970212, 0.050859582144767046, 0.06054344054843698, 0.11999114203665938, 0.17169207707047462, 0.20155220478773117, 16.79239593233381, 49.83191401617867, 42.138003485543386, 43.3765025138855, 24.918654646192277, 35.393265519823345, 46.01780114855085, 59.74054895128523, 55.94593620300293, 40.485426562173025, 0.5214093242372785, 0.05511172701205526, 0.3666088879108429, 0.4104263723960945, 0.18177331611514091, 0.11019938638699905, 26.094885655811854, 71.18705299922398, 60.47766249520438, 59.648825781685964, 58.2611836705889, 56.607130255017964, 48.422697748456685, 49.30910376140049, 43.45776169640677, 49.14361156736101, 48.036773954119, 51.29460709435599, 49.69937365395682, 53.8585444859096, 52.892932483128135, 51.93163878577096, 50.36439963749477, 52.64411054338728, 51.865436349596294, 52.818399156842915, 47.292965820857454, 50.17852142878941, 41.63760811941964, 37.445864132472444, 52.95697055544172, 50.44873687199184, 50.63467761448452, 46.39950738634382, 45.95641033990042, 44.07955946241106, 42.459837096078054, 39.92228201457432, 38.258372579302105, 38.3904960496085, 43.81105327606201, 46.03163153784615, 48.75584650039673, 45.48744167600359, 41.24700471333095, 37.00848197937012, 38.042818614414756, 37.64198398590088, 38.254721300942556, 38.09341887065342, 39.02705178941999, 39.70297949654715, 39.91150883265904, 42.31757272992815, 42.906974520002095, 45.13176686423165, 44.55571951184954, 44.965482575552805, 46.12554686410086, 45.86831412996565, 48.07430117470877, 45.24784346989223, 41.219437735421316, 40.47796767098563, 40.53216014589582, 38.8073011125837, 37.0013427053179, 34.798148836408345, 37.41801227842058, 39.20166349411011, 42.73717096873692, 38.86908796855381, 36.653123310634065, 38.907403809683665, 37.42727770124163, 33.929884569985525, 37.27346542903355, 39.375239917210166, 34.60516956874302, 35.78096110480172, 35.46104172297886, 38.252233845846995, 40.68992246900286, 44.215865748269216, 44.56739943368094, 48.50692728587559, 42.63505329404558, 43.14566946029663, 43.66808366775513, 39.71273129326956, 40.39261599949428, 37.95821040017264, 41.27365452902657, 36.32580757141113, 34.76915052958897, 37.7739337512425, 35.779842444828574, 38.41989735194615, 35.638936451503206, 36.89034523282732, 35.462862151009695, 36.5284309387207, 38.606046540396555, 40.33169766834804, 41.149163654872346, 44.547416414533345, 47.10713972364153, 46.12617915017264, 44.268345492226736, 41.30692250388009, 37.067743165152415, 38.60944768360683, 40.3749988419669, 42.92894472394671, 46.79911913190569, 49.76637165887015, 49.10536868231637, 52.83196204049246, 48.795082977839876, 51.24551459721157, 48.52611126218523, 46.09965787615095, 50.365414074489046, 44.967831066676546, 42.592874254499165, 44.97941371372768, 56.519405773707796, 59.50141280038016, 62.01207487923758, 64.33509390694755, 55.811248847416465, 54.34494618007115, 52.34021370751517, 46.60576466151646, 52.86673082624163, 59.78756741115025, 65.43648065839494, 59.99956389835903, 58.41599995749337, 32.514894349234446, 0.07439332415482827, 0.3062727669520037, 0.10594055455710207, 0.5744036148701395, 17.048584699630737, 71.00567027500698, 57.34421253204346, 65.71832738603864, 47.44012171881539, 34.14811359133039, 19.48709147317069, 28.20583697727748, 46.41341767992292, 59.504532541547505, 2.901230526821954, 0.24289249362690107, 0.017426731763407588, 0.13532289862632751, 0.045030535464840274, 0.018891454774088094, 0.058074007342968664, 0.028414831164159944, 0.11713642307690211, 0.11365203040518931, 0.2560981150184359, 0.15183738246560097, 21.81742521694728, 60.664318902151926, 47.15024982179914, 36.341166564396445, 35.08811106000628, 46.4197335924421, 48.8531733921596, 67.62751170567104, 59.77563040597098, 45.8750365121024, 0.47263237301792416, 0.021706623623945882, 1.4122821603502547, 2.1846955929483687, 1.5050576563392366, 0.36437029231871876, 31.069279943193706, 72.60865443093437, 60.988897051130024, 61.771931239536826, 61.346548625401084, 59.47484983716692, 51.238649777003694, 50.58645364216396, 45.091571535382954, 51.167277881077354, 50.692882674080984, 54.46270077569144, 53.13851308822632, 55.55854286466326, 54.104271003178184, 53.71705484390259, 51.24783182144165, 54.616554737091064, 53.533174242292134, 52.847501686641145, 49.1168783732823, 50.38739817483084, 45.03249100276402, 40.98358808244978, 54.978642736162456, 51.29116773605347, 51.6130291393825, 49.95224986757551, 48.50598233086722, 47.030817236219136, 44.2383258002145, 42.57712616239275, 39.64214106968471, 41.202167987823486, 46.61807686941964, 49.932332856314524, 49.56383514404297, 48.782854148319785, 42.376872130802695, 38.681139196668354, 40.73714590072632, 39.67096219744001, 40.1401184626988, 39.84495898655483, 40.64450209481375, 42.2145413671221, 43.4433650289263, 44.088866574423655, 44.15768848146711, 45.702783720833914, 45.88551092147827, 46.94745969772339, 47.29046794346401, 47.37992252622332, 50.01306050164359, 47.936355113983154, 41.422738552093506, 43.07072271619524, 42.40503665379116, 40.85313217980521, 39.39713716506958, 36.36886208398001, 37.128935950142996, 40.60990701402937, 42.06084721429007, 38.90223087583269, 38.65685871669224, 39.14095360892159, 37.17901509148734, 35.92122091565813, 38.439592020852224, 41.00588485172817, 36.00984866278512, 37.43269729614258, 36.333030223846436, 38.38991240092686, 42.479295526232036, 44.69562496457781, 46.02042409351894, 49.94090345927647, 44.426677567618235, 44.35709135872977, 45.140306200299946, 41.26442037309919, 41.437555585588726, 39.72674928392683, 43.00552429471697, 38.65319354193551, 36.88196223122733, 37.65386887959072, 39.14845071520124, 40.685545103890554, 37.008179732731406, 40.12912293842861, 37.18798174176897, 38.657400676182334, 37.91846323013306, 41.214327335357666, 43.352659770420615, 47.227565901620046, 50.22801692145211, 50.50474630083357, 46.81055586678641, 44.882465498788015, 39.489683696201865, 40.98394591467721, 42.398963928222656, 45.34879037312099, 48.81189414433071, 50.90706784384591, 51.674520696912495, 55.764497893197195, 51.4442434992109, 54.13617713110787, 49.6463554246085, 45.517690658569336, 49.81671135766165, 48.7686311858041, 46.135521003178184, 47.17010429927281, 56.54716730117798, 61.36450277056013, 62.21348925999233, 67.65004471370152, 58.78725610460554, 58.599293436322895, 54.25312920979091, 48.77739633832659, 55.481636728559224, 62.37587560926165, 65.97426428113664, 63.34097344534737, 62.853244645254954, 35.99014009748186, 0.33496785004224094, 0.46551378071308136, 0.08077696803957224, 0.8013074621558189, 20.025258983884537, 77.44683102199009, 60.975229944501606, 73.67487634931291, 52.44039283479963, 40.03350182941982, 17.772083248410905, 33.3412366594587, 53.40062345777239, 71.56315898895264, 5.530244529247284, 0.3654357008635998, 0.1069239689303296, 0.03506978388343539, 0.06593069647039686, 0.17140471749007702, 0.18155260224427494, 0.11837726006550447, 0.32478952620710644, 0.18115791199462755, 0.37315547519496506, 0.21399138016360147, 33.442746366773335, 75.24757330758231, 56.370505877903526, 58.599439348493306, 36.44943686894008, 49.455682958875386, 59.73469161987305, 71.61156014033726, 65.94513048444475, 51.754028933388845, 0.8815700124417032, 0.16360750874238356, 1.7020653592688697, 2.6017618647643497, 0.9469125547579357, 0.25295761067952427, 33.7203859601702, 75.71168518066406, 63.69636685507638, 64.51695605686733, 64.86788177490234, 61.60844012669155, 53.20897477013724, 53.81985344205584, 47.144222259521484, 53.110244342258994, 54.6120731489999, 56.676845005580354, 54.51478099822998, 58.10839973177229, 55.39635453905378, 55.89016996111189, 54.15704951967512, 58.099245480128694, 54.62866544723511, 55.62681933811733, 49.38094118663243, 51.65868575232369, 41.81926529748099, 41.874333245413645, 57.86342709405081, 53.869724137442454, 54.67572212219238, 51.06421525137765, 51.06360033580235, 49.182973112378804, 46.34084721973964, 45.28793804986136, 41.47306782858712, 44.11364732469831, 49.61048534938267, 51.97166735785348, 51.589134284428184, 51.39342437471662, 44.38897316796439, 39.356674330575125, 43.4057822227478, 41.1707239151001, 41.57220125198364, 42.641855580466135, 44.05468838555472, 43.800936698913574, 45.633676937648225, 45.754853521074565, 47.236192090170725, 48.278606006077354, 48.603281429835725, 48.46953208105904, 50.210038457598, 48.806377274649485, 54.37458719526018, 49.16009269441877, 43.97793510981968, 42.304979119982036, 43.48117017745972, 43.08559186117989, 41.912107127053396, 37.843044008527485, 39.610724789755686, 40.15858677455357, 42.84597281047276, 41.237916469573975, 39.618357385907856, 41.21384790965489, 39.112309660230366, 36.19638000215803, 40.08681188310896, 42.60751410893032, 36.67905398777553, 38.49475029536656, 36.853113310677664, 40.05190065928868, 45.07893623624529, 46.50436265127999, 47.99005774089268, 52.46727541514805, 48.08704417092459, 49.45185450145176, 45.87940345491682, 44.199433258601594, 43.11551080431257, 41.918280601501465, 45.72999634061541, 40.987385272979736, 38.75610678536551, 39.41138097218105, 41.90190717152187, 43.671846117292134, 38.48216710771833, 41.46437215805054, 39.11619370324271, 40.77254697254726, 40.698955127171104, 46.317813941410606, 44.89050456455776, 49.172151293073384, 52.152233668736045, 52.31520366668701, 49.94078881399972, 47.14986072267805, 42.22541182381766, 44.16848945617676, 44.2666049684797, 49.294571604047505, 51.41564123971121, 54.297496931893484, 54.29104552950178, 57.02540486199515, 53.61506918498448, 56.46756526402065, 51.92964117867606, 47.49286202022007, 51.88790682383946, 50.008196762629915, 50.20071744918823, 51.39479316983904, 61.23059013911656, 63.033390590122764, 62.940548760550364, 67.29314354487828, 61.89269093104771, 60.87862913949149, 56.0191250528608, 52.794222899845664, 58.93351568494524, 65.86779703412736, 72.07024547031948, 64.73808247702462, 66.37878840310233, 37.73784480776106, 0.6874355524778366, 1.1283381623881203, 0.1577713204813855, 1.4541637301445007, 23.931258303778513, 82.96648693084717, 67.79411561148507, 79.75459875379289, 60.651068687438965, 50.32669523784092, 29.49458885192871, 41.643020766122, 59.652820995875764, 86.45935331072126, 10.430125900677272, 0.632849147277219, 0.24226004470671925, 0.15144704841077328, 0.24407672722424778], [0.021349678581048335, 0.039799016900360584, 0.10456896387040615, 0.03657462527709348, 0.044953738871429644, 0.12592887984854834, 0.17540877977652208, 24.41013162476676, 55.4034104347229, 48.42481000082833, 45.22013405391148, 17.00916756902422, 35.71790967668806, 45.81391320909773, 62.29279599870954, 52.90996251787458, 48.1002596446446, 1.546796353799956, 0.07226860030953373, 0.8361389988235065, 2.499751452888761, 2.0166236630507877, 0.1174671681863921, 0.2767819794160979, 44.56996331896101, 63.544826643807546, 58.9393104825701, 57.53832088197981, 55.231439045497346, 50.71670109885079, 50.0458698953901, 45.979961259024485, 50.13316706248692, 51.12493208476475, 51.471886907305034, 52.289669036865234, 54.16792345046997, 52.516201155526296, 55.085283688136506, 51.413310119083945, 51.099998474121094, 46.124820777348106, 48.223812511989046, 44.6040164402553, 48.00197390147618, 32.64988742555891, 44.86607122421265, 51.862455572400776, 48.01831259046282, 47.34360081808907, 43.745788846697124, 43.57675307137625, 44.32493509565081, 42.01998833247593, 40.97413853236607, 40.7971887588501, 44.01669910975865, 48.52931785583496, 47.72665500640869, 51.435408864702495, 48.9788350377764, 41.833641120365684, 37.49873297555106, 37.83833660398211, 39.98021609442574, 39.574948515210835, 37.05910308020455, 37.35599960599627, 41.97670105525425, 42.0078706741333, 43.71596370424543, 45.22078023638044, 42.92731537137713, 44.7907075881958, 42.91380112511771, 44.057231426239014, 47.10615655354091, 47.854119709559846, 45.38837773459298, 42.94399799619402, 40.52114030293056, 41.07381044115339, 38.70799745832171, 35.98430708476475, 34.98126861027309, 34.94338355745588, 38.5352200780596, 44.77419866834368, 41.90885189601353, 36.25632905960083, 43.79474932806832, 39.87025042942592, 36.17007064819336, 36.94178622109549, 40.360511847904746, 37.72561250414167, 34.57568488802229, 35.45102936880929, 39.87644822256905, 39.589550154549734, 38.638366086142405, 47.511007240840364, 43.24317700522286, 40.570218903677805, 47.41871084485735, 40.380140508924214, 41.360343728746685, 37.028305189950125, 39.38316433770316, 39.19785588128226, 39.52607488632202, 39.08063282285418, 37.507230622427805, 36.95782266344343, 36.30735663005284, 36.27080910546439, 36.12533467156546, 35.73738200323922, 36.653578417641775, 38.04710217884609, 41.72537428992135, 42.376298904418945, 47.006272724696565, 48.72060176304409, 48.40014042173113, 47.85620764323643, 47.87955011640276, 46.20416225705828, 43.99253674915859, 39.391213825770784, 40.8473755972726, 42.01489182880947, 48.020476954323904, 51.422245502471924, 50.64659030096871, 53.332736083439414, 53.59386328288487, 50.33116292953491, 46.44977412905012, 51.30744736535208, 55.503693784986226, 54.685317584446494, 45.52693176269531, 42.684472356523784, 42.41382612500872, 53.592626503535676, 52.12845345905849, 57.68611601420811, 60.48027501787458, 57.73871735164097, 51.93352174758911, 47.813816683632986, 57.71738290786743, 62.51528426579067, 62.7813446862357, 64.1951571873256, 30.935363837650844, 0.5383421927690506, 0.36510859270180973, 0.048048503164734156, 0.4864280213202749, 28.293347801480973, 70.2317590713501, 57.762257848467144, 63.256219318934846, 47.36373322350638, 37.753064836774556, 23.702667781284877, 41.13804653712681, 44.03849213463919, 63.62612056732178, 9.798127310616628, 0.41070837154984474, 0.04130237569500293, 0.12815860020262854, 0.03931496019608208, 0.035692458506673574, 0.007342013530433178, 0.008068926399573684, 0.014597769992958223, 0.06459867794598852, 0.12751693677689346, 0.19516181626490184, 32.23148775100708, 68.85399382455009, 53.182894706726074, 53.48620441981724, 26.11617146219526, 41.487968240465435, 51.33801596505301, 68.44029113224575, 58.20750188827515, 55.04162815638951, 1.9410576607499803, 0.08479905221611261, 2.0772985901151384, 6.234134827341352, 4.910738365990775, 0.11520685947367124, 0.016919810125338178, 49.17683785302298, 64.84832954406738, 60.4900997706822, 61.03036390032087, 57.90252808162144, 52.513755389622276, 50.46691683360508, 48.491669041769846, 50.96171542576381, 52.292017527988975, 52.92754146030971, 53.50457893099104, 55.79302372251238, 54.98265184674944, 56.0006810597011, 53.435322761535645, 54.118396690913606, 49.45301137651716, 49.730043002537315, 44.99990047727312, 49.460157598767964, 35.66310576030186, 46.749755655016216, 53.97297089440482, 49.59156193052019, 50.1949018069676, 44.94504444939749, 45.23716756275722, 45.13937861578805, 44.737098761967246, 41.40100111280169, 41.8142591203962, 45.128591537475586, 49.801303727286204, 50.96645409720284, 53.28244849613735, 49.936328070504324, 43.91273321424212, 40.30003125326974, 38.89613730566842, 40.51363277435303, 40.44909790584019, 38.743360315050396, 39.172032901218955, 43.78474392209734, 43.06819357190813, 44.649572304316926, 47.00593226296561, 45.98160450799124, 48.2014080456325, 47.838882310049875, 46.37774215425764, 49.18921954291207, 49.5104729788644, 47.83546379634312, 44.825792516980854, 41.9672132900783, 40.36525746754238, 40.29686287471226, 38.986029624938965, 36.392628397260395, 36.172888142721995, 39.08655268805367, 44.485441957201274, 42.46292209625244, 36.728816986083984, 42.69424499784197, 39.8279185295105, 38.058260985783164, 38.40937430518014, 41.61279610225132, 39.782442569732666, 35.78112438746861, 35.33852413722447, 40.98559263774327, 41.14329937526158, 41.28426095417568, 48.700455461229595, 45.423730169023784, 44.119918073926655, 49.98560469491141, 43.19542898450579, 44.05132893153599, 41.15708112716675, 40.551833970206125, 41.99607610702515, 41.18899072919573, 40.70974915368216, 38.985713481903076, 38.42098127092634, 38.76505259105137, 38.193896770477295, 38.66995259693691, 38.42023433957781, 39.35030630656651, 40.13563687460763, 43.1679036957877, 45.17879922049386, 48.75338683809553, 52.32829754693167, 49.91163764681135, 51.03838879721505, 50.20251703262329, 49.134558064596995, 45.6324679510934, 41.411812509809224, 42.48472554343087, 46.24161652156285, 50.435121876852854, 53.468972887311665, 52.05103315625872, 54.97070789337158, 54.063582352229524, 52.12416294642857, 47.84549699510847, 49.77670363017491, 52.539936201913015, 55.17012466703142, 48.70050062452044, 45.531607900347026, 43.83601467950003, 56.59146554129464, 57.941771507263184, 58.09258215767996, 61.8378974369594, 60.60004806518555, 55.639256613595144, 51.11577435902187, 59.77408790588379, 65.91431522369385, 65.04772894723075, 66.34125423431396, 33.3433176449367, 0.5932466951864106, 0.18178474264485495, 0.10324383926178728, 0.5123157607657569, 32.26481131144932, 76.10068702697754, 61.52555506569998, 69.26188782283238, 54.99665594100952, 43.5419773374285, 27.605292013713292, 51.26914194652012, 49.67336654663086, 75.03139400482178, 12.866212095533099, 0.5633364915847778, 0.10104845277965069, 0.12336822439517293, 0.062058968868638785, 0.1534998339733907, 0.17481362314096519, 0.18742672061281546, 0.16424058191478252, 0.12156694462256772, 0.42292534027780804, 0.3184820818049567, 42.34874929700579, 77.25804846627372, 63.238598687308176, 59.6481865474156, 23.597232341766357, 49.155162947518484, 59.44040066855294, 74.72590950557164, 64.61063861846924, 64.62154729025704, 2.048545858689717, 0.12483012809285096, 3.858367247240884, 9.969521130834307, 5.274533450603485, 0.16636413867984498, 0.5127455177051681, 53.72938094820295, 69.74385656629289, 62.130520820617676, 63.24724224635533, 60.8495648247855, 55.12654903956822, 53.229722091129844, 51.772420815059114, 53.46499504361834, 57.0300566809518, 57.492956093379426, 55.761659554072786, 57.20917429242815, 56.42837047576904, 58.95421436854771, 55.49098552976336, 56.05847964968, 52.50015081678118, 51.41752420152937, 46.51724113736834, 49.31668772016253, 35.42319141115461, 48.99133832114083, 54.41410507474627, 51.330643926348, 51.612254415239605, 46.42549017497471, 47.784728050231934, 47.47605780192784, 47.890486580984934, 42.73562846864973, 42.93476731436593, 48.35199287959507, 53.31305531093052, 53.01811122894287, 55.427854197365896, 54.282224791390554, 45.771779332842144, 44.46486834117344, 41.89613321849278, 43.86370325088501, 42.139896869659424, 42.416251046316965, 40.36480583463396, 46.24521916253226, 45.235823086329866, 47.10872391292027, 52.19913748332432, 47.497048309871126, 48.21782316480364, 49.43815265383039, 48.43425260271345, 50.490141187395366, 51.84226063319615, 48.379007475716726, 45.10056250435965, 42.55905042375837, 42.28093487875802, 42.14720637457711, 40.41092797688076, 37.707244941166465, 37.585401330675396, 40.36735234941755, 44.55685206821987, 43.23712512425014, 37.51762512751988, 43.93492923464094, 41.24723400388445, 39.25880200522286, 40.54058483668736, 44.15863691057478, 40.74286079406738, 37.92283712114607, 37.04226064682007, 42.55607312066214, 42.37714311054775, 41.45034374509539, 50.39065340587071, 47.27925355093819, 48.86229985100882, 50.18978098460606, 44.74404696055821, 45.95931468691145, 43.05389070510864, 42.78497110094343, 43.62520286015102, 41.59926101139614, 43.28298323495047, 40.13718284879412, 43.198350702013286, 42.718112060001914, 41.27322374071394, 40.10296644483294, 40.16890484946114, 40.74834292275565, 42.66766466413225, 46.29113980701992, 46.78958967753819, 51.12451171875, 54.10577876227242, 51.34685059956142, 53.275986671447754, 53.036405835832866, 51.14824676513672, 48.45925916944231, 44.72180577686855, 45.19896636690412, 47.97260734013149, 54.616589478084016, 57.722024304526194, 56.45119878223964, 56.95320265633719, 55.83913891656058, 53.910405840192524, 48.35408081327166, 49.94946016584124, 52.58111122676304, 53.335397243499756, 47.74187503542219, 46.79578399658203, 46.055543763296946, 57.32535512106759, 59.015685081481934, 59.62126227787563, 63.985682896205354, 62.675593103681294, 57.65825721195766, 54.50232982635498, 62.87241472516741, 68.12234851292202, 67.63489069257463, 69.05714525495256, 36.32168728964669, 1.8423758702618735, 1.1475213787385394, 0.2256351632199117, 1.3910323977470398, 38.257041999271934, 82.30317715236119, 68.62612070356096, 76.09012576511928, 62.38096169063023, 55.86524329866682, 35.60301079068865, 59.59904193878174, 56.416339669908794, 90.23754051753453, 19.09803056716919, 0.654113403388432, 0.22963109665683337, 0.2670637294650078, 0.1628709996917418], [0.02609028384488608, 0.09560182504355907, 0.05344263603910804, 0.04799042735248804, 0.14062115789524146, 0.030985891952046325, 0.035226864740252495, 26.593860115323746, 53.0077132497515, 36.45493636812483, 22.349870886121476, 28.259551763534546, 38.784212248665945, 42.91120249884469, 66.53487273624965, 50.65494550977434, 57.6613005229405, 4.230114110878535, 0.22406659381730215, 0.8693531794207436, 1.5007490132536208, 4.999434726578849, 0.6169396181191716, 0.2575654334255627, 12.548992088862828, 58.6170391355242, 55.170485973358154, 58.72178322928292, 52.773489475250244, 51.02795260293143, 47.393992628370015, 51.62088060379028, 51.78029659816197, 53.37107276916504, 55.07128306797573, 53.521285874503, 53.37256663186209, 51.967842374529155, 50.37961619240897, 51.96479211534773, 47.55019508089338, 46.42389208929879, 46.77019378117153, 47.49178852353777, 45.78521714891706, 43.04979821613857, 49.468505859375, 48.09267915998186, 47.10538182939802, 45.02405936377389, 42.123982020786826, 41.93641887392317, 39.76433556420462, 41.80731439590454, 43.024934087480815, 44.63793059757778, 48.27957527978079, 47.84684147153582, 50.4774364062718, 50.27838093893868, 50.677242279052734, 42.7902169908796, 36.8082001549857, 38.9861546925136, 38.486283915383474, 36.52522087097168, 38.64271913255964, 38.38477073396955, 38.81271028518677, 41.573618684496196, 44.940149443490164, 44.28388166427612, 44.34688098090035, 46.42493084498814, 44.923428603581016, 44.67533622469221, 43.7317465373448, 46.381278787340435, 47.238095896584646, 42.88272530691964, 38.82877104622977, 41.88345275606428, 37.19315814971924, 36.66443497794015, 35.443664278302876, 36.11828224999564, 37.805509839739116, 44.91801595687866, 41.32169437408447, 31.489472252982004, 41.77803816114153, 39.71467331477574, 35.176109995160786, 36.44883932386126, 35.40177011489868, 39.08840438297817, 37.800475869859966, 38.94225249971662, 42.08521454674857, 45.697871344430105, 44.37506982258388, 45.73464815957205, 40.56116887501308, 44.16410861696516, 42.55169922964913, 41.84021411623274, 40.30228246961321, 39.719808033534456, 40.83499043328421, 39.52115903581892, 40.355915614536826, 37.773162501198904, 39.56133699417114, 37.0138008253915, 36.009376185280935, 34.914781297956196, 37.70594562802996, 36.08605650493077, 36.93259028026036, 37.96314014707293, 44.97851392201015, 45.43122380120413, 44.53765766961234, 49.061720098767964, 49.962981360299246, 49.215018204280305, 50.84595148903983, 45.228371143341064, 44.544001374925884, 44.60214737483433, 40.4766058240618, 39.83465828214373, 43.6016971043178, 46.051322732652935, 49.070370606013704, 51.02483980996268, 52.28790766852242, 52.98991543906075, 49.1596097946167, 48.57992506027222, 52.178991181509836, 56.12697499138968, 62.23647390093122, 54.237610408238, 55.709138120923726, 47.67665924344744, 42.25011961800711, 60.21496500287737, 61.371145248413086, 59.717675481523784, 52.91716432571411, 50.559838567461284, 51.990754059382844, 63.83541420527867, 57.79323639188494, 64.53252696990967, 27.103566067559377, 0.19700395741633006, 0.06325503611671073, 0.044005869555154016, 0.7736653568489211, 40.15428236552647, 68.20876325879777, 61.611712728227886, 64.441575050354, 45.384601388658794, 37.86630310331072, 20.455512285232544, 23.758291585104807, 46.74764340264456, 60.97514656611851, 16.398148196084158, 0.6233788611633437, 0.09798785950988531, 0.011894699369025017, 0.07326969051999704, 0.048269776826990504, 0.010894677851216068, 0.03984688415325113, 0.07559492824865238, 0.13317017842616352, 0.10147760582289525, 0.11896640488079616, 37.41601814542498, 62.96194921221052, 45.00513594491141, 32.014186314174104, 23.045614855630056, 42.89735473905291, 48.70209871019636, 71.17116941724504, 53.57146576472691, 67.63186822618756, 3.7827908226421902, 0.11143375693687371, 1.691982003194945, 4.437463990279606, 7.999143157686506, 1.741205321890967, 0.3969180429620402, 16.35221712929862, 62.89926256452288, 55.17733689716884, 61.104911123003276, 54.201062883649556, 53.591615540640696, 49.97814580372402, 52.210341453552246, 52.73910978862217, 56.791736943381174, 55.652816023145405, 56.41913284574236, 53.05378328050886, 55.44754539217268, 53.162289823804585, 52.518917901175364, 50.435226099831716, 47.938852991376606, 46.95070798056466, 48.67546626499721, 45.58539390563965, 43.58018200738089, 52.23559815543038, 49.01524707249233, 48.16027123587472, 48.13626173564366, 45.04230185917446, 44.328370979854036, 42.411345618111746, 42.156329359327046, 45.02948243277413, 46.30164200919015, 49.09523820877075, 49.326804297310964, 51.817681380680625, 52.83394227709089, 52.32654660088675, 46.307662623269216, 38.960665225982666, 39.01833527428763, 40.04008524758475, 38.49670968736921, 39.2865218435015, 41.444510732378276, 41.15255784988403, 43.515932015010286, 46.017057691301616, 47.15755932671683, 46.16015584128243, 46.95136111123221, 46.335549218314036, 47.28568410873413, 45.62363331658499, 46.74913031714303, 47.05842937741961, 43.69594594410488, 38.578854765210835, 41.053309781210764, 37.90569938932146, 37.430286271231516, 37.045137201036724, 36.76687226976667, 38.20520496368408, 43.837425163814, 41.53973926816668, 34.15439476285662, 41.077517305101665, 39.7927884374346, 36.81397410801479, 38.195209980010986, 36.917644705091206, 40.73412343433925, 39.20960528509957, 40.802792481013704, 42.71379722867693, 44.09010682787214, 45.61887032645089, 47.4343512398856, 43.23285893031529, 46.638004302978516, 44.05612318856375, 44.75295802525112, 42.24696166174752, 42.602855341775076, 42.2606600352696, 41.186458110809326, 41.09168815612793, 39.580333369118826, 39.83102090018136, 38.87992715835571, 38.347024645124165, 38.021571023123606, 38.309198651994976, 36.74436705453055, 38.45641360964094, 41.02548919405256, 46.52315058026995, 47.70577219554356, 48.0559092930385, 50.84544774464199, 51.90707342965262, 51.62796776635306, 54.13357850483486, 48.96226705823626, 47.398442949567524, 47.72788483755929, 42.137110642024446, 41.93143701553345, 44.2473132950919, 48.38729320253645, 51.69475385120937, 52.75370100566319, 54.747736726488384, 53.25601060049874, 51.1694005557469, 51.361980301993235, 53.060748849596294, 54.07970217296055, 61.24021339416504, 55.266579559871126, 56.29857465199062, 52.72199637549264, 43.02034132821219, 60.67852102007185, 62.727662903921946, 62.0674728666033, 54.81963668550764, 52.693286418914795, 54.985563141959055, 66.98351097106934, 61.93275424412319, 67.77785682678223, 28.27854119028364, 0.37737248891166275, 0.21070501793708118, 0.07647069982652153, 0.8828457668423653, 45.02549416678292, 73.66354383741105, 66.29483331952775, 69.79548168182373, 51.46312175478254, 41.843351227896555, 22.78336031096322, 29.57761287689209, 49.38961948667254, 75.0137664249965, 21.368128640311106, 0.418345038912126, 0.12318948470056057, 0.042367828344660144, 0.03460207987310631, 0.1410831045359373, 0.14137121050485543, 0.1889908252550023, 0.14622477149324759, 0.1866917721927166, 0.1448345346642392, 0.4612070375255176, 48.530770029340474, 72.85084778921944, 51.27153212683541, 34.1716297694615, 41.88490840366909, 57.06453364236014, 54.58716038295201, 78.29792976379395, 57.91050461360386, 74.66486958095005, 5.627228353704725, 0.21169405058026314, 4.019812984125955, 7.3089247431073865, 11.25148548398699, 1.1262330753462655, 0.28049047184841974, 19.17930712018694, 69.00185149056571, 56.276093755449565, 65.4126205444336, 56.84029442923409, 57.098916803087505, 51.29063619886126, 54.35516003199986, 55.78906672341483, 58.33741583142962, 57.880846227918354, 58.30232048034668, 56.351700578417095, 56.440832069941926, 53.93075711386544, 55.21183817727225, 50.87137494768415, 50.40177747181484, 49.032700947352815, 50.18980182920183, 47.638496262686594, 46.491772515433176, 54.98233917781285, 51.632397242954795, 50.355492046901155, 50.51658603123256, 46.81873737062727, 46.30388627733503, 44.14458417892456, 45.60873637880598, 48.97919634410313, 49.02600635801043, 53.312930243355886, 50.48215423311506, 53.984647342136924, 55.54941987991333, 54.15289102281843, 49.95405639920916, 40.764764990125386, 41.83638913290841, 41.72603784288679, 42.35521459579468, 42.06869867869786, 44.87185212544033, 42.98627431052071, 46.43599585124424, 50.35649258749825, 48.24076264245169, 49.97098568507603, 49.77279874256679, 50.362179688044954, 49.21167264665876, 47.809588704790386, 49.63647856031145, 50.894144194466726, 46.10492808478219, 39.402911118098665, 43.62308018548148, 40.421336378370015, 41.657473019191194, 38.699729101998464, 38.664303711482454, 40.229798861912315, 45.31668969563076, 43.34692750658308, 35.057076930999756, 41.83371407645089, 40.683391162327354, 37.316679750170024, 40.11648416519165, 38.29869992392403, 42.39153282982962, 41.19206530707223, 41.35209969111851, 44.53856093542916, 47.69743435723441, 46.045149258204866, 50.50054611478533, 48.351763589041575, 48.519020625523154, 46.4144321169172, 47.70737375531878, 46.86347334725516, 45.483533314296174, 45.97903714861189, 44.99479007720947, 44.2341742515564, 41.76823772702898, 42.78828886577061, 42.096877098083496, 40.68853282928467, 38.57584619522095, 41.34647512435913, 40.3631660597665, 40.399081298283164, 41.857619353703086, 50.26642656326294, 51.91112075533186, 48.73977184295654, 52.887300968170166, 54.959920815059114, 53.94072083064488, 57.86188111986433, 52.519355637686594, 50.30267531531197, 50.74156870160784, 44.90867410387312, 43.9948296546936, 47.5686251776559, 49.820748261043, 54.601112365722656, 56.905322619846885, 57.56521041052682, 55.68416282108852, 52.11398383549282, 51.15146378108433, 56.58106756210327, 58.919188499450684, 62.36490440368652, 54.60621581758772, 54.12535531180245, 48.51841960634504, 48.47778306688581, 62.17709459577288, 66.66902160644531, 66.29241534641811, 59.89094965798514, 54.731189591544016, 58.60824271610805, 70.03665365491594, 65.17947374071393, 72.21788079398019, 32.20239564350673, 0.8704571830374854, 0.46485706738063265, 0.2521317521376269, 1.8237041064671107, 49.36483873639788, 80.161867414202, 72.93444851466587, 78.5973206928798, 59.96644183567592, 54.87863383974348, 30.074985776628765, 36.07508182525635, 58.319447789873394, 86.55965750558036, 31.264041423797607, 0.6906939319201878, 0.31571968431983677, 0.12752373569778033, 0.16339343094399997], [0.021647421443568807, 0.04368446787287082, 0.05455799154671175, 0.029538563186568872, 0.09379699653280632, 0.06451417319476604, 1.0007501287119729, 34.66105393001011, 54.85397815704346, 41.694743156433105, 36.565871306828086, 26.148397207260132, 37.76097188677107, 45.56003645488194, 66.65306854248047, 51.68018347876412, 60.541537284851074, 8.110399450574603, 0.41377562124814304, 1.371224386351449, 3.833556967122214, 5.926181980541774, 1.5937168874910899, 0.4205367613051619, 5.707575585160937, 56.820908955165315, 54.770891598292756, 58.71789918627058, 51.11478771482195, 53.438557147979736, 50.90299619947161, 53.77831711087908, 53.88994686944144, 56.06721006120954, 51.602478299822124, 56.848111152648926, 53.41504096984863, 52.52256917953491, 49.398707730429514, 46.62873193195888, 44.78591333116804, 47.749990531376426, 49.54784039088658, 51.310845034463064, 48.37563412530081, 47.8760621207101, 46.54062877382551, 45.845517090388704, 45.74706111635481, 43.99511800493513, 42.716586930411204, 40.92720692498343, 41.16737835747855, 43.27211972645351, 45.123283113752095, 48.5856225831168, 49.60927636282784, 51.41543974195208, 49.35363129207066, 48.63748741149902, 46.116924149649485, 39.62384646279471, 35.04026576450893, 37.74309417179653, 37.67311886378697, 35.68747656685965, 36.33452756064278, 37.391292980739046, 37.62521798270089, 38.84496034894671, 40.895498820713584, 43.48168781825474, 43.15973261424473, 45.38616473334176, 45.323016030447825, 47.29875019618443, 45.823334966387065, 45.380891050611226, 44.22939041682652, 47.68647704805647, 44.29055888312203, 40.91503020695278, 38.675719601767405, 36.899419580187114, 35.00163378034319, 35.90778309958321, 34.56122916085379, 41.945677348545615, 41.984677587236675, 32.83567530768258, 42.458704539707725, 37.6448883329119, 35.941572189331055, 35.42420584814889, 37.90833970478603, 34.26148387363979, 38.657470158168245, 42.032502038138254, 41.916349002293174, 42.09972933360508, 41.09525605610439, 40.01274061203003, 40.73725012370518, 42.402830600738525, 40.92567832129342, 43.69932276862008, 41.56067419052124, 41.36587102072579, 38.96626894814627, 40.76518188204084, 36.91235017776489, 36.64603614807129, 35.87583180836269, 35.38048430851528, 35.20906530107771, 36.571822438921245, 36.812014716012136, 37.760478564671104, 36.835954734257285, 44.40089280264718, 45.42035334450858, 46.873899119240896, 48.81498956680298, 47.331993852342876, 45.722780636378694, 49.40858806882586, 45.13567522593907, 65.89310932159424, 57.82875905718122, 47.336478914533345, 46.37280893325806, 41.55539008549282, 44.02536351340157, 42.814730235508506, 46.9801926612854, 49.76455817903791, 50.46222332545689, 52.1564234324864, 53.215763160160606, 56.26405947549002, 53.86618403026036, 54.27574559620449, 51.09224428449358, 60.53738226209368, 56.70029864992414, 44.063602924346924, 50.71037476403372, 55.4205446924482, 58.74342686789376, 58.85405608585903, 54.08360358646938, 53.831727913447786, 52.45874997547695, 62.875652585710796, 59.437294823782786, 70.02749592917306, 26.384168692997523, 0.13583308910684927, 0.17715660456035817, 0.07065265559192214, 1.1330717312438148, 49.18039533070156, 63.35452243259975, 61.21706199645996, 64.97540514809745, 44.84343746730259, 34.524660791669575, 30.13204438345773, 36.23984098434448, 49.756123065948486, 61.69120706830706, 18.488310507365636, 0.5305942999465125, 0.10857236119253294, 0.12264429538377694, 0.04402951989322901, 0.05465732907344188, 0.06360885820218495, 0.027479060127266815, 0.04943072649517229, 0.05226430569642356, 0.019216279665540372, 1.0254695394209452, 44.92385939189366, 64.92776135035923, 47.493199007851736, 41.94423907143729, 23.15124831880842, 40.00625099454607, 52.16778026308332, 70.00518526349748, 56.86451584952218, 65.83124256134033, 8.58559456893376, 0.3298162764736584, 1.4799763964755195, 7.7156392846788675, 4.221745005675724, 3.0458735653332303, 1.2583817328725542, 6.887240741934095, 60.61085251399449, 55.63705403464181, 61.353135517665315, 54.34902477264404, 55.59074081693377, 52.766193866729736, 56.46872908728463, 57.86778014046805, 56.99373149871826, 52.35720552716936, 59.51168918609619, 55.46530498777117, 54.15110533578055, 50.724232946123394, 48.93766696112496, 47.152831077575684, 49.73327044078282, 51.20510040010725, 53.708862917763845, 50.921231746673584, 51.23698568344116, 49.70483146395002, 50.139535086495535, 47.30748755591256, 46.397582735334126, 45.192285673958914, 44.07910435540335, 42.52332278660366, 45.58329554966518, 46.54700722013201, 50.782493591308594, 49.570185797555105, 55.110589027404785, 51.235839230673655, 51.4562326158796, 49.537650857652935, 42.30339840480259, 36.681576183864046, 38.99674374716622, 38.65949208395821, 37.198025362832205, 37.66714341299874, 39.70214918681553, 39.49783393314907, 41.0320656640189, 42.66774804251534, 44.86575160707746, 47.56839936120169, 46.84571375165667, 47.30588599613735, 49.29680544989449, 48.026181425367085, 47.06055900028774, 46.74795607158116, 50.06107950210571, 44.840755462646484, 44.164431708199636, 40.508174964359824, 37.90470232282366, 36.91620295388358, 36.88387645993914, 37.134793281555176, 43.183627469199045, 44.15204654421125, 34.10523625782558, 41.080279214041575, 39.93806137357439, 36.345814909253804, 39.06566292898995, 38.33375358581543, 37.59299571173531, 40.59384625298636, 43.700257301330566, 43.400185448782786, 41.66331992830549, 44.1902859551566, 43.10934427806309, 44.80848108019148, 46.535959584372385, 45.45039735521589, 44.666807310921804, 44.26971776144845, 43.358808926173616, 42.33915383475167, 41.85900204522269, 39.819941997528076, 38.32592296600342, 39.27953890391758, 37.33524186270577, 36.36615923472813, 40.629309858594624, 38.36864396503994, 37.48107760293143, 39.54408809116909, 47.26733044215611, 48.95832742963518, 51.47358226776123, 51.66351127624512, 50.95238746915545, 48.31044612612043, 51.11150816508702, 47.59192248753139, 62.07136385781424, 57.972729206085205, 49.16881268365042, 47.29383781978062, 43.99357550484793, 46.05648871830532, 45.520209380558555, 50.14764710835048, 52.464061873299734, 52.31474508558001, 55.020241601126536, 53.999182973589214, 56.67386075428554, 56.099866594587056, 56.58006354740688, 55.012463092803955, 60.64703178405762, 60.662929262433735, 46.22998523712158, 54.639442103249685, 61.93904931204659, 61.070927483694895, 61.59280667986189, 57.760451316833496, 57.38204894747053, 53.951077120644705, 66.78478554316929, 61.52119854518345, 71.27352333068848, 29.024433783122472, 0.14051882124372891, 0.3208622469433716, 0.016848989729104296, 2.378326905625207, 53.09545162745884, 70.85641602107457, 66.9082897731236, 71.31856155395508, 50.93467651094709, 37.0945006779262, 24.440985100609915, 38.87376063210623, 55.72666842596871, 73.12285586765834, 25.666685547147477, 0.5953836462327412, 0.0701002466625401, 0.09561961623174803, 0.004742776151813034, 0.24066432033266338, 0.16821420512029103, 0.13365333607154234, 0.24737915716000966, 0.10746328891920191, 0.12164992945534842, 2.1093682178429196, 59.55929824284145, 75.36730466570172, 57.10021611622402, 47.22591570445469, 36.363831588200156, 52.96057319641113, 58.34902627127511, 78.07485089983258, 63.21925490243094, 74.92871352604458, 10.026552813393728, 0.8436372450419835, 3.7367642181260243, 13.470908607755389, 13.907269375664846, 7.542075020926339, 1.1397675148078372, 8.129404510770526, 61.6949382509504, 55.20140893118722, 62.46768910544259, 56.61772973196847, 57.63100290298462, 55.30916159493582, 58.98048550742013, 59.53209604535784, 58.53867040361677, 55.337666579655235, 60.838635308401926, 57.35451323645455, 56.523797035217285, 53.26665871483939, 50.65124906812395, 50.56652968270438, 52.25484119142805, 53.53284420285906, 56.49034145900181, 54.660856451307026, 54.39788103103638, 50.99209642410278, 51.85871744155884, 50.68399592808315, 48.41987330572945, 48.29954787663051, 46.03836781638009, 43.12495340619768, 47.571487835475374, 48.128823689052034, 52.76381063461304, 51.426379680633545, 55.22882652282715, 54.385308265686035, 53.33032158442906, 50.67129462105887, 43.44723170144217, 40.081114360264365, 41.44466706684658, 40.902884755815776, 38.36403383527483, 40.090925216674805, 41.54811184746878, 42.09175280162266, 43.22317661557879, 44.404637881687705, 47.47578682218279, 49.99385220663888, 49.16495990753174, 51.11656297956194, 52.86474016734532, 49.68703712735857, 49.188590730939595, 50.165250369480674, 51.17783566883632, 48.918958936418804, 45.55589880262102, 42.23543460028512, 40.37728132520403, 39.35630260195051, 38.40629972730364, 37.75130694253104, 45.12728527614048, 45.103935854775564, 34.86394132886614, 42.09090859549386, 41.2093802179609, 38.166746684483115, 40.34807457242693, 41.09727798189436, 38.39150701250349, 43.6203738621303, 46.673752784729004, 45.84228270394461, 46.19951738630022, 46.381073815482004, 48.041651589529856, 46.137605462755474, 48.445189067295615, 46.85134179251534, 46.87808540889195, 47.36217335292271, 46.729011808122905, 44.490882396698, 46.75941365105765, 41.963926792144775, 41.47267525536673, 40.82657616479056, 39.18087795802525, 40.97444077900478, 42.8155049596514, 41.14682558604649, 38.56714357648577, 40.378459044865195, 48.71124253954206, 49.999400343213765, 54.06009088243757, 52.5008282661438, 53.37300089427403, 50.79950278145926, 50.47068970543997, 50.05174807139805, 60.11100605555943, 56.99788304737636, 53.99396487644741, 49.66213130950928, 48.74415615626744, 49.622408458164756, 48.65616416931152, 51.97616284234183, 56.316038949149, 54.281554290226524, 57.742226191929404, 57.02711411884853, 58.90577847617013, 58.336331912449424, 59.15951974051339, 57.14293016706194, 65.16225610460553, 59.216078077043804, 46.29347092764718, 52.47696120398385, 62.86614050183977, 64.12372275761196, 62.58344609396798, 60.700248037065776, 58.428756850106375, 57.60429402760097, 69.22399929591587, 65.36340645381382, 74.0395178113665, 31.782943316868373, 0.36031449852245195, 1.0789823936564582, 0.21587187211428369, 4.059503700051989, 60.493671144757954, 77.61597102028983, 71.51405606951032, 80.71081679207938, 56.90765026637486, 52.43051597050258, 40.070782388959614, 51.41637774876186, 63.06635979243687, 85.27060685838971, 36.7216533933367, 0.6003357033644403, 0.24214879210506166, 0.24218551442027092, 0.18990295273917063], [0.08559344708919525, 0.09698583292109625, 0.035455283376255205, 0.04625443961205227, 0.05719069045569215, 0.12028648118887629, 1.4237070615802492, 39.141446931021555, 53.190680163247244, 40.36406932558332, 23.46184321812221, 22.00619387626648, 39.654078074863975, 41.64698818751744, 69.22962733677456, 48.65698058264596, 63.69815254211426, 12.220487339156014, 0.17143797927669116, 1.0858590475150516, 3.130427062511444, 5.570489798273359, 4.669186847550528, 0.22974433058074542, 3.000678139073508, 50.583726474217, 52.920964990343364, 58.12907409667969, 52.212158407483784, 56.37205532618931, 52.936511584690635, 56.140082768031526, 54.70557853153774, 55.743403162275044, 57.74501936776297, 52.45762089320591, 48.605372837611604, 48.74830423082624, 45.44489785603115, 48.82667991093227, 48.33346550805228, 51.20586122785296, 48.909252302987234, 50.798787117004395, 46.77738516671317, 47.70906216757638, 47.15746552603585, 47.10022279194423, 43.93644741603306, 44.56777811050415, 41.9707464490618, 43.361126150403706, 44.00355659212385, 51.47970710481916, 47.690041473933626, 47.29724938528878, 51.26550803865705, 48.44681147166661, 50.64933483941214, 47.65938254765102, 44.22035428455898, 37.080545221056255, 35.14785167149135, 35.85607460566929, 34.63296236310686, 35.52326284136091, 36.692870480673655, 37.375079359327046, 38.63277278627668, 37.696492603846956, 39.30776596069336, 42.7215826851981, 46.594081265585764, 46.025381633213584, 44.51640313012259, 43.92972155979702, 44.74792405537197, 45.176499366760254, 44.33930049623762, 45.7050245148795, 47.09095389502389, 47.467514991760254, 42.04066269738333, 40.70112296513149, 37.308876923152376, 36.56667382376534, 36.60718182155064, 37.606530802590505, 41.83995703288487, 36.84734977994646, 42.43316296168736, 39.05552550724575, 35.15561975751604, 35.591799872262136, 36.8234931400844, 40.78549494062151, 34.212617192949565, 38.198260239192415, 41.818980421338765, 42.73778935841152, 41.49504498073033, 44.40269933428083, 43.79172338758196, 41.89103324072701, 44.34912872314453, 41.30628326960972, 42.434858322143555, 43.59438759940011, 41.0789521081107, 38.896915503910606, 37.00350359507969, 36.23954221180507, 35.72572292600359, 35.56107146399361, 34.324017660958425, 35.85742603029524, 36.19715472630092, 36.33910642351423, 42.23483010700771, 47.439551966530935, 47.20723894664219, 49.092076778411865, 50.14067459106445, 45.88704647336687, 48.4655750819615, 47.82086910520281, 47.07072074072701, 54.43460920878819, 51.22874859401158, 49.048011302948, 47.77842950820923, 48.377635206495015, 43.03313991001674, 44.083002294812886, 43.9209703036717, 45.8814149584089, 48.22866930280413, 51.38934578214373, 48.14116716384888, 51.13052191053118, 50.507282393319265, 53.62743003027779, 52.50099154881069, 54.431381770542686, 42.096095425742014, 53.33092607770647, 53.61124767575945, 54.63425874710083, 61.03140613010952, 60.182134764535085, 60.18779059818813, 61.1625394821167, 55.535686765398296, 64.06656687600272, 58.912268093654085, 64.53935010092599, 22.02083546774728, 0.31794465492878643, 0.15298604725727014, 0.14467787449913366, 1.1443152193512236, 50.360018798283164, 60.12913390568325, 58.199226583753315, 64.81253937312535, 44.76681620734078, 41.93959420067923, 34.28234931400844, 26.207680974687847, 41.321687425885884, 67.48787375858852, 24.09881932394845, 0.53219699966056, 0.10353693924844265, 0.12641947423773153, 0.03345366953206914, 0.08014198818377086, 0.07036898724202599, 0.06476574005292994, 0.055691901594400406, 0.04376111858125244, 0.06836836066629205, 2.0508593916893005, 49.29923731940133, 60.942684582301546, 48.90638269696917, 33.276851177215576, 21.434360606329783, 44.391022886548726, 46.684925488063264, 73.89334160940987, 53.07744884490967, 69.46337168557304, 14.367055995123726, 0.2529676529978003, 0.28027624477233204, 6.449962377548218, 5.300544900553567, 3.6375686952045987, 1.5997964526925768, 3.4649465637547627, 51.31547253472464, 54.43801730019705, 60.63863141196114, 54.381021227155415, 57.771519797188894, 55.04270165307181, 56.95702416556222, 55.65470593316214, 58.27390929630825, 57.918328285217285, 52.92107963562012, 50.47189521789551, 49.207257066454204, 48.656233651297434, 51.03026982716152, 50.71693386350359, 53.08497721808297, 52.281515325818745, 53.87505687986101, 48.53721795763288, 49.849506855010986, 49.34416437149048, 48.43770933151245, 45.705719334738596, 45.04576553617205, 42.8832221031189, 45.61216531481062, 47.40221234730312, 51.52009698322841, 49.755324023110525, 48.008883884974885, 52.05400698525565, 51.16470009940011, 51.47840084348406, 50.80844511304583, 46.41101360321045, 38.99961682728359, 37.501362868717735, 37.13660676138741, 37.117763246808735, 37.084780148097444, 38.29221378053938, 39.51358549935477, 39.616519587380544, 38.730044092450825, 41.31419379370553, 45.40475811277117, 46.95207677568708, 46.94911336898804, 45.27285698481968, 46.79108006613595, 47.91604552950178, 47.6813006401062, 46.30469921657017, 48.40627915518624, 47.87692369733538, 48.68517289842878, 44.09662423815046, 42.628563676561626, 37.26551668984549, 38.576117174965994, 36.73985767364502, 40.22159651347569, 42.64019843510219, 37.844895703451975, 42.246023654937744, 39.88138839176723, 37.90432364600045, 37.04995230266026, 38.89342056001936, 43.25513138089861, 36.77359812600272, 41.127846581595286, 44.06412403924124, 43.83126211166382, 44.491591112954275, 46.53287805829729, 45.45934316090175, 44.081216607775005, 45.49839551108224, 44.71180384499686, 43.18857111249651, 45.53863947732108, 42.83354595729283, 42.599356923784526, 39.308808190482004, 38.49297503062657, 37.02285780225481, 37.972363880702424, 36.304570402417866, 37.04782962799072, 38.50926160812378, 39.90260819026402, 45.42723900931222, 50.836105891636436, 50.74738434382847, 50.03521483285086, 53.46737480163574, 47.108199323926655, 50.9209121295384, 50.38653312410627, 47.46498932157244, 55.76101337160383, 50.99254805701119, 51.7647500038147, 49.9180543082101, 51.558763708387104, 45.43936708995274, 45.32025064740862, 45.84760849816458, 48.1092506136213, 49.69255747113909, 53.75835493632725, 50.35132312774658, 55.0833694594247, 53.21965415137154, 54.85347441264561, 53.865530899592805, 58.33540085383824, 47.04808350971767, 56.29009437561035, 53.55481440680367, 55.30781364440918, 62.85263320377895, 62.68333339691162, 61.96000507899693, 64.60523986816406, 58.78077343532017, 67.0859899520874, 61.99178613935198, 68.60009275163922, 23.428444964545115, 0.22172321884759835, 0.0045497456615391585, 0.04238037445715495, 1.4663507619074412, 56.604052203042166, 66.52864715031215, 65.10038934435163, 69.78614330291748, 52.05678973879133, 46.5893634387425, 24.23581174441746, 31.373096874782018, 48.68279661451067, 76.94526141030448, 31.651017870221818, 0.6049275398254395, 0.11845972921167101, 0.17600747836487635, 0.045902463141828775, 0.24765627086162567, 0.28721942220415386, 0.1452130757804428, 0.198506573215127, 0.1411281864025763, 0.19872441009751388, 3.037925260407584, 62.23305538722447, 69.16995620727539, 57.90160049710955, 33.660683563777376, 32.20543548039028, 56.93607187271118, 53.31556361062186, 81.59097984858921, 57.32500076293945, 79.1103687286377, 15.405398266656057, 0.2967464067041874, 3.04889320901462, 14.646847793034144, 14.312675050326757, 9.380418981824603, 1.9661128648689814, 4.676600141184671, 55.98852171216692, 56.6980995450701, 62.026186670575825, 55.644068241119385, 60.60211168016706, 57.714787755693706, 60.24022170475551, 59.44349956512451, 59.381938525608604, 60.380248750959126, 55.710183824811665, 52.244505746024, 51.670504638126914, 51.40913077763149, 53.276785714285715, 51.842542035239084, 55.70004292896816, 53.937211990356445, 55.064977577754426, 50.750604833875386, 52.8026510647365, 52.10975238255092, 51.99246679033552, 47.88939223970686, 46.61865356990269, 46.34003775460379, 47.80564212799072, 47.7776061466762, 55.20935419627598, 53.50496455601284, 50.901999132973806, 51.35587630953108, 54.01371513094221, 55.99274274281093, 51.988662651606965, 47.59915903636387, 42.17464133671352, 37.88159956250872, 38.71598788670131, 39.33729927880423, 38.96871818814959, 40.406217098236084, 41.94671263013567, 42.324503558022634, 41.207799502781455, 43.86509983880179, 48.1205518586295, 50.16560820170811, 50.12068462371826, 47.69466550009591, 49.85243552071707, 49.638462271009175, 49.49293919972011, 48.99868951525007, 51.41833019256592, 51.511290141514365, 52.49384880065918, 45.63181482042585, 44.117746761866975, 38.562245096479145, 40.19578048161098, 39.23458405903408, 41.65350559779576, 45.726640360695974, 39.02544675554548, 43.65324926376343, 42.94474145344326, 38.809927531651084, 38.482854979378835, 40.493496894836426, 45.19485650743757, 40.2924542427063, 42.4485045841762, 46.77181618554251, 46.3939905166626, 44.7229174886431, 49.202223096575054, 48.15684577396938, 45.3852128301348, 50.28892830439976, 48.57257039206368, 48.084577560424805, 48.10604401997158, 46.28835357938494, 44.7581969669887, 40.81587593896048, 39.414205414908274, 39.27878155027117, 40.52275923320225, 37.40909773962838, 38.04103640147618, 40.57904658998762, 41.89422593797956, 48.052386556352886, 52.92000266483852, 53.528011730739046, 51.47573273522513, 54.48131847381592, 48.92876979282924, 54.578318800245015, 53.733918121882844, 49.835732051304404, 56.65956136158535, 53.652172565460205, 54.899818897247314, 51.725944314684185, 53.317689759390696, 49.335704939705984, 47.81951420647757, 49.75905173165457, 50.68762983594622, 52.14969757625035, 55.409792355128694, 53.1772631917681, 57.905036381312776, 55.357545375823975, 56.18820946557181, 55.68388489314488, 59.290194511413574, 49.30752999441964, 60.07939175197056, 54.043647970472065, 54.532485008239746, 65.57691764831543, 62.8892571585519, 67.44574683053153, 67.00123582567487, 62.843128068106516, 70.13021114894322, 66.33208956037248, 72.87757750919887, 26.802255698612758, 0.32620017336947577, 0.9787737365279878, 0.27431599316852434, 2.745723762682506, 62.46602848597935, 73.90081092289516, 69.41242054530552, 79.01931258610317, 57.844726017543245, 60.46433585030692, 44.851577281951904, 38.7156891141619, 55.73279326302664, 90.17654923030308, 40.10074649538313, 0.6080539577773639, 0.15994492598942348, 0.2624194829591683, 0.08689763210713863], [0.12393180201096193, 0.07092260396374123, 0.0344077474437654, 0.04776869567909411, 0.05250935522573335, 0.06147312851888793, 0.2132044831024749, 42.74393504006522, 55.50223813738142, 36.96743202209473, 37.68109539576939, 23.49913419995989, 26.843283074242727, 44.98265157427107, 65.34160995483398, 48.503842285701204, 62.054681232997346, 20.786607844488962, 0.3631402440369129, 0.4666309750505856, 7.314861978803362, 0.5105718172022274, 1.48283232322761, 1.0888030209711619, 2.810310959815979, 41.66134316580636, 54.71249546323504, 54.129534653254915, 52.25924287523542, 55.64660085950579, 56.6612879889352, 56.262089661189485, 53.528115953717915, 51.61628437042236, 49.90975815909249, 52.077193123953684, 46.006440843854634, 46.357550689152305, 50.47903796604702, 52.69483586720058, 51.53482369014195, 51.32841008050101, 47.94859783990042, 46.53327063151768, 43.578420639038086, 44.45387281690325, 44.658507687704905, 45.60519279752459, 42.95952027184622, 42.077641010284424, 44.35243606567383, 46.36652428763253, 50.074732712336946, 47.78667007173811, 51.71121413367135, 56.54723678316389, 45.730635574885774, 49.195663997105186, 51.76484727859497, 47.866734164101736, 40.003364018031526, 37.319337436131065, 34.63958747046334, 36.33496182305472, 39.63414021900722, 37.43334000451224, 37.024139744894846, 36.75810364314488, 36.00558941704886, 36.08279432569231, 40.846340315682546, 41.42888423374721, 43.45194605418614, 44.28261709213257, 43.78805821282523, 46.5121203150068, 45.16671977724348, 44.97060687201363, 44.37209946768624, 46.988891805921284, 44.61135721206665, 45.49882977349417, 44.49092755998884, 44.595960003989084, 40.997751985277446, 39.93921477454049, 38.521417481558665, 37.24950804029192, 40.750020912715364, 38.334795815604075, 45.769319670540945, 36.84548071452549, 34.474098750523154, 36.984211921691895, 38.8202178137643, 40.6134922845023, 42.284054619925364, 41.05841670717512, 43.32979672295706, 45.28457164764404, 44.89033085959298, 43.93750354221889, 44.1091240474156, 44.99373047692435, 44.7276804787772, 42.73611831665039, 42.900662081582205, 40.36717864445278, 40.28897666931152, 37.87057624544416, 37.895641871861045, 35.973592962537495, 35.93083374840872, 36.51872083118984, 34.773965631212505, 37.1326254435948, 34.34689113071987, 36.609492097582134, 43.6863192149571, 49.79895176206316, 48.54360335213797, 47.60293538229806, 47.44359234401158, 48.65423951830183, 47.94394254684448, 47.53252233777727, 51.0305164882115, 40.699163573128835, 40.6433139528547, 48.916335991450715, 50.70466334479195, 47.28944655827114, 47.09421607426235, 47.58500902993338, 45.67790569577898, 46.75189222608294, 45.412008558000835, 44.9192145211356, 43.897106715611045, 49.095762797764365, 49.178644384656636, 50.234023639133994, 52.287414346422466, 47.394256659916465, 52.828036308288574, 58.22349664143154, 55.74539382117135, 55.21971048627581, 51.94720622471401, 60.89836202348982, 57.34355245317732, 60.141592025756836, 54.92101090294974, 63.10709708077567, 57.16468150275094, 74.4227318082537, 16.435326269694738, 0.29161727907402174, 0.13297979507063115, 0.04287934875381844, 1.1215503151927675, 52.48278726850237, 61.520788601466585, 60.70240197862898, 66.44655418395996, 41.28153378622872, 45.95893601008824, 54.289954662323, 31.31590277808053, 50.24412979398455, 69.00499902452741, 18.933445113045828, 0.945374397294862, 0.11965234950184822, 0.1389474698475429, 0.058510685339570045, 0.14526699217302458, 0.014356313306572182, 0.07322372655783381, 0.027642636260549937, 0.01967380056157708, 0.020878568324925642, 0.7100855399455342, 51.218944685799734, 63.10780579703194, 45.94816630227225, 38.63952643530709, 23.050073862075806, 37.37877580097744, 49.20380728585379, 69.28222520010812, 54.82464633669172, 68.09964874812535, 22.336349691663468, 0.47785801546914236, 0.7824109132800783, 5.631028149809156, 2.2356942849499837, 5.400070462908063, 1.84150430560112, 2.784885981253215, 46.18313700812203, 57.094782624925884, 57.903955936431885, 54.536977018628804, 57.646254198891775, 57.643662520817344, 57.043546608516145, 55.19980737141201, 53.995194707598, 52.708575929914204, 52.836843150002615, 48.759674957820344, 49.822262968335835, 52.74274717058454, 53.73851782935006, 53.82111801419939, 52.829286984034944, 50.120267731802805, 49.36519309452602, 45.88460070746285, 48.03493962969099, 46.85782446180071, 46.27868863514492, 45.36010551452637, 45.91019787107195, 46.6352458681379, 49.56099680491856, 51.133183070591514, 51.67862360818045, 50.11610228674752, 57.82943650654384, 49.242383684430806, 50.837745666503906, 52.908086504255024, 48.99211999348232, 42.81874629429409, 38.771031515938894, 37.37348822184971, 37.70135634286063, 41.29399190630232, 38.11782789230347, 38.47382232121059, 37.284394945417134, 38.13823127746582, 37.999274253845215, 42.123572077069966, 44.4432247025626, 45.68960298810686, 44.67216089793614, 45.68487473896572, 47.467560155051096, 46.977323055267334, 47.04400144304548, 46.70124333245413, 48.20807831627982, 46.77206632069179, 47.39652872085571, 45.97148445674351, 46.77650274549212, 42.287493978227886, 40.68777894973755, 41.37312841415405, 40.27053962435041, 42.81041193008423, 40.837849617004395, 45.30107361929757, 38.59495026724679, 34.314661911555696, 40.14067431858608, 41.030995641435894, 42.98162249156407, 41.41676657540457, 41.314020088740754, 44.67492280687605, 47.13853168487549, 46.28145749228341, 45.37834453582764, 47.55147702353341, 46.81752143587385, 47.37177228927612, 45.46603775024414, 44.711716992514475, 43.49246794836861, 42.44156333378383, 40.03241443634033, 38.90086555480957, 37.960360867636545, 37.2772730418614, 37.508106095450266, 35.907536438533235, 37.805252756391255, 36.96593468529837, 40.389676911490305, 46.41879211153303, 51.82921191624233, 49.98020594460623, 49.9478759765625, 50.16450343813215, 51.45854984010969, 50.28308834348406, 48.94022389820644, 52.48982926777431, 45.56745365687779, 42.26598235539028, 50.74988916942051, 52.518205710819785, 50.478075640542166, 50.14737612860543, 49.71717146464756, 47.08532238006592, 48.79935264587402, 47.3875481741769, 47.5748472894941, 48.05725376946585, 51.45117780140468, 51.334316049303325, 51.50551618848528, 54.99878208977835, 49.74875797544207, 55.3042631149292, 61.45443330492292, 58.6564701625279, 56.933494091033936, 53.0686628477914, 63.09730012076241, 60.273322922842844, 63.40455641065325, 56.21902820042202, 65.34502846854073, 61.61331081390381, 75.31303228650773, 18.156104973384313, 0.35744597816041535, 0.22726173379591533, 0.15749346039124898, 1.1825725436210632, 58.54983615875244, 67.10083130427769, 65.37140383039201, 72.33445072174072, 47.74039854322161, 46.15546580723354, 46.91147150312151, 37.14143575940813, 51.82723862784249, 79.74722671508789, 23.579627343586512, 0.7766974855746541, 0.13932972933564866, 0.1928668072713273, 0.017706625762262514, 0.17289031563060625, 0.22507241341684545, 0.15442406652229174, 0.17548590206674167, 0.16442124864884786, 0.14574312019561017, 1.2765734195709229, 62.73090076446533, 71.58275985717773, 51.035137040274485, 49.79181248801095, 32.95144966670445, 40.32254689080374, 57.4632351739066, 76.33088084629604, 60.312948499407085, 75.47780186789376, 25.33860550607954, 0.6028432973793575, 2.6567866035870145, 17.118019785199845, 6.632743426731654, 10.49438110419682, 3.665868708065578, 3.724945766585214, 47.760169642312185, 58.81958607264927, 60.10783767700195, 57.302766527448384, 60.60835116250174, 60.114570481436594, 60.65415368761335, 56.07351207733154, 54.397165366581504, 55.04386895043509, 53.497835704258506, 50.048287868499756, 52.605836391448975, 55.47924654824393, 56.69921473094395, 56.33283274514334, 54.92415148871285, 52.272388866969514, 52.60118804659162, 48.77940089362008, 49.85150793620518, 50.15438338688442, 49.650656359536306, 47.684107712336946, 46.821964808872764, 50.05653190612793, 51.50950445447649, 54.03727994646345, 54.81527669089181, 50.45584487915039, 53.22466032845633, 49.88303191321236, 53.11071334566389, 55.48367255074637, 51.82490055901663, 44.539311340876985, 41.44382633481707, 37.967639105660574, 41.15160594667707, 44.22893530981881, 40.99042510986328, 39.774483408246724, 40.77083771569388, 39.94310229165213, 39.991823060171946, 44.28093910217285, 45.83167627879551, 48.52948113850185, 49.48623766217913, 50.27305167061942, 51.013476031167166, 48.44616528919765, 48.323456627982004, 49.70151022502354, 51.15135955810547, 49.746972288404194, 49.28068562916347, 46.93903848103115, 48.5514235496521, 43.880622114454, 41.90006937299456, 41.86928537913731, 43.13952030454363, 46.53176634652274, 42.05000455038888, 47.041343757084434, 39.81412288120815, 36.57294804709298, 41.45931386947632, 41.755970682416645, 45.125871317727224, 43.886072976248606, 43.77664232254028, 47.97825275148664, 49.93884679249355, 48.42672075544085, 47.38885790961129, 50.54788071768624, 49.23087051936558, 51.05957385471889, 48.03778491701399, 46.55167293548584, 44.2728305544172, 46.36664935520717, 40.595256737300325, 42.9078117779323, 41.40728575842721, 39.92459576470511, 41.03215251650129, 37.83730827059065, 41.15990904399327, 38.03733648572649, 42.98883472170149, 48.45828989573887, 53.89384133475167, 52.835196426936555, 50.83472320011684, 51.673978737422395, 53.71048184803554, 52.13017313820975, 51.88413395200457, 55.02274990081787, 49.12962831769671, 43.29437133244106, 52.126233509608674, 55.14886317934309, 53.624911308288574, 52.54528284072876, 52.98937347957066, 51.328965936388286, 49.622227805001394, 50.99669613157, 50.19365807941982, 50.63032456806728, 55.68152250562395, 56.101655755724224, 54.72156286239624, 58.18374252319336, 51.448898792266846, 59.6964487348284, 62.92971651894705, 60.90701947893415, 58.014772755759104, 55.90341670172555, 64.33713667733329, 64.05763149261475, 65.73505864824567, 61.12785407475063, 68.14822360447475, 66.38399955204555, 73.86641039167131, 19.74520836557661, 0.4894798547029495, 0.8168230610234397, 0.23772680652993067, 2.245919427701405, 63.61802591596331, 76.17879867553711, 70.87803881508964, 80.51963015965053, 52.23104361125401, 64.80336775098527, 70.019088608878, 46.21463319233486, 64.38157735552106, 91.78423036847795, 31.635742255619594, 1.089102444904191, 0.2239010041313512, 0.3279330161001001, 0.1525206265172788], [0.19534880694534096, 0.050568022432604005, 0.06436332128942013, 0.09148580447903701, 0.05707875931901591, 0.11417222927723612, 1.684367103236062, 55.11813824517386, 46.576432841164724, 43.237865107400076, 31.994217191423687, 22.773341008595057, 30.60688774926322, 41.78879049846104, 67.06127520969936, 49.98785243715559, 58.69364997318813, 30.802479539598735, 0.07636909599282912, 0.13391143722193583, 2.2326377289635793, 1.7753547408751078, 3.534502157143184, 1.064200861113412, 0.8159668041127068, 34.948427949632915, 54.99226467950003, 57.57715088980538, 52.864747115543906, 54.702160017830984, 53.26295185089111, 53.764292172023225, 49.380076135907856, 47.57224518912179, 43.6510397366115, 48.580557346343994, 49.2522223336356, 52.70338909966605, 51.843400137765066, 50.93117461885725, 49.79015186854771, 48.89168030875069, 46.505106108529226, 46.49533346721104, 42.703593799046104, 43.206316811697825, 45.64947714124407, 43.28148937225342, 44.37593139920916, 44.937363215855186, 47.49216720036098, 47.69993918282645, 50.08094787597656, 49.01763725280762, 59.624430656433105, 38.19121823992048, 40.645009313310894, 50.04306977135794, 49.893023422786165, 44.29117032459804, 37.664273806980674, 35.48178904397147, 33.70285218102591, 41.261172090257915, 36.39858300345284, 35.906487260546, 33.28534187589373, 35.41996397290911, 35.381714139665874, 37.1112562588283, 40.52420793260847, 43.21785429545811, 43.35789523805891, 43.4743400982448, 42.68465648378645, 42.822491373334614, 45.36973571777344, 46.87773105076381, 44.95884357179914, 47.47703054973057, 44.57748474393572, 45.75092431477138, 45.699347836630686, 46.228383677346365, 44.98695598329817, 44.544859477451865, 41.586368628910606, 35.79794945035662, 37.34863451548985, 41.55792270387922, 46.107481547764365, 32.733158111572266, 32.67412274224417, 37.41840137754168, 36.805935042245046, 42.24911560331072, 42.073645796094624, 43.71446984154837, 47.263022559029714, 46.03049898147583, 43.012173720768516, 45.103876795087544, 44.419764110020225, 46.01749890191214, 43.707973275865825, 43.43674339566912, 41.17470175879342, 42.982039383479524, 40.25022656576974, 36.930342538016184, 33.106109619140625, 36.47865056991577, 35.44438689095633, 36.111139501844136, 35.554831981658936, 34.72529002598354, 36.01742219924927, 36.230238573891775, 39.87022263663155, 50.04656818934849, 49.305365630558555, 48.35400785718645, 45.644516127450125, 45.10262264524187, 47.86137015478951, 48.353434630802695, 47.93399967466082, 40.6790554864066, 44.38927888870239, 44.962515694754465, 50.114983626774375, 51.46852050508772, 47.09334407533918, 49.44414894921439, 52.24819871357509, 53.031896454947336, 47.14876290730068, 46.56172350474766, 44.24712916782924, 46.083336557660786, 45.1412615776062, 49.422196115766255, 48.363544259752544, 48.02656010219029, 50.905994347163606, 52.382222516196116, 57.37018837247576, 57.44026442936489, 55.849359716687886, 57.209184714726035, 58.739959716796875, 60.90677629198347, 55.78364018031529, 60.153542927333284, 67.7823314666748, 59.714493206569124, 8.967720304216657, 0.16602894238063268, 0.09230793107833181, 0.2607649160282952, 2.348147839307785, 57.72677339826311, 62.616276332310264, 59.433237075805664, 70.49684674399239, 42.16605683735439, 84.68646485464913, 52.151945318494526, 26.73478521619524, 50.188224588121685, 73.16455200740269, 22.172288826533727, 0.7712138912507466, 0.24544397528682435, 0.15622981105531963, 0.07019406091421843, 0.07461437050785337, 0.058608374026204856, 0.059063399609710486, 0.028306533582508564, 0.04885602769042764, 0.01956465990016503, 2.843738091843469, 63.43913064684187, 54.04812608446394, 47.2714854649135, 40.59403038024902, 16.846114192690166, 31.857400212969097, 49.36432804380144, 70.26225471496582, 53.98071118763515, 65.9267941883632, 33.72381837027413, 0.06273157349122421, 0.08176391079489674, 5.809627251965659, 2.623596578836441, 4.69566947221756, 2.3178437054157257, 1.0403385758399963, 38.77742733274187, 55.513494219098774, 59.4872384752546, 54.27848318644932, 57.626736709049766, 54.97045775822231, 56.30687427520752, 51.097615242004395, 48.58026899610247, 47.325511183057515, 52.37159524645124, 49.60708768027169, 54.31969295229231, 52.39077227456229, 53.26353897367205, 52.39899546759469, 50.19387347357613, 48.37826401846749, 47.182006563459126, 44.55569519315447, 46.988103185381206, 48.72160925183977, 47.39574704851423, 46.52427618844168, 47.45389652252197, 50.204302719661165, 48.308809825352256, 52.46974549974714, 47.3855436188834, 53.198889459882466, 45.18278053828648, 42.824534143720356, 51.13674749646868, 49.851108414786204, 44.61713463919503, 39.46991259711129, 37.66588578905378, 35.45344386781965, 41.94743524278913, 38.31057439531599, 38.41723271778652, 35.04931231907436, 37.063504764011924, 37.844517026628765, 37.94184391839163, 41.242040225437705, 43.18200853892735, 45.197448185511995, 45.880035740988596, 45.23016030447823, 45.38625505992344, 46.51102944782802, 46.97966807229178, 46.0158417565482, 48.44234377997262, 46.199246406555176, 47.17882081440517, 46.396321637289866, 47.354262828826904, 47.31319897515433, 46.199117864881245, 42.8617764881679, 39.622369970594136, 40.38517795290266, 42.193578651973176, 46.77047865731375, 36.25830929619925, 33.805174827575684, 40.03510686329433, 37.29961844852993, 44.25110701152256, 44.10642467226301, 44.836603913988384, 48.266672474997385, 49.041431358882356, 45.532799516405376, 46.621908800942556, 47.13987268720354, 47.21864441462925, 46.89684901918684, 44.87976612363543, 43.17488316127232, 45.06591183798653, 43.48614856175014, 38.15954835074288, 37.232787200382774, 36.86950411115374, 37.06297322681972, 37.157197747911724, 37.18564714704241, 37.69440119607108, 37.08302920205252, 39.06398146493094, 42.02165242603847, 51.96264164788382, 51.49800171170916, 50.942336899893625, 47.87851136071341, 47.916914054325645, 48.42155476978847, 51.05300085885184, 49.25192356109619, 45.596469334193635, 45.92840562547956, 46.61216047831944, 51.64218725476946, 53.11251640319824, 50.084904875074116, 51.173427036830354, 53.11833551951817, 52.95287806647164, 49.36816692352295, 49.716744150434224, 47.29402889524187, 49.15165410723005, 48.71864237104143, 51.38932146344866, 51.28380611964634, 51.79549925667899, 53.691224915640696, 55.14098392214094, 58.976059504917686, 60.062827246529714, 58.00938095365252, 58.793016161237446, 60.37818513597761, 62.89580236162458, 59.62090791974749, 63.39034734453474, 70.79470906938825, 62.74602699279785, 10.25002338205065, 0.3223830610513687, 0.12437042061771665, 0.34532324437584194, 2.617108915533338, 64.13502747671944, 67.54532146453857, 64.540878704616, 77.22301564897809, 47.46380465371268, 93.0591344833374, 62.27751691000802, 29.986743654523575, 57.6609913281032, 80.07898235321045, 29.390018463134766, 0.8039626511079925, 0.2706482671201229, 0.1468516971383776, 0.07253577347312655, 0.26957973731415613, 0.10968352335372142, 0.19825440246079648, 0.14811351442975657, 0.16192574612796307, 0.4404729886778763, 4.614007728440421, 77.43161446707589, 61.63334941864014, 57.77731112071446, 45.43699428013393, 35.0638027872358, 44.884615966251914, 52.08188315800258, 77.41349356515067, 60.4310678754534, 71.1979547228132, 38.11092485700335, 0.1959108646426882, 0.3143369113760335, 10.201796804155622, 8.62113721030099, 10.872058255331856, 4.57541960477829, 1.214630663394928, 42.30834552219936, 57.45731183460781, 62.1182086127145, 54.89584105355399, 57.88116584505354, 57.60117776053292, 56.13024411882673, 54.80297490528652, 51.77415091650826, 49.27376522336687, 53.13900988442557, 50.50945717947823, 58.50112928662981, 54.76614250455584, 54.18682255063738, 54.59160375595093, 54.388421058654785, 51.15270056043352, 50.78166675567627, 45.88476051603045, 49.338956696646555, 51.14593301500593, 48.79429088320051, 48.452401297433035, 49.36457123075213, 54.775282859802246, 51.72182750701904, 54.837743691035676, 49.349246978759766, 54.0362411907741, 48.26064143862043, 47.81584555762154, 52.97564383915493, 55.27922180720738, 49.46039036342076, 41.80455943516323, 38.19830887658255, 39.12500401905605, 45.16954769407, 40.065560817718506, 41.30094010489327, 36.50141634259905, 39.27524144308907, 39.02594007764544, 40.81674793788365, 43.72931466783796, 47.0355281148638, 47.395236355917795, 48.62774951117379, 48.30162538800921, 47.27638394492013, 49.838983808244976, 52.39434364863804, 49.727524280548096, 50.98081602369036, 47.073281151907786, 50.73692035675049, 49.315899099622456, 48.98157262802124, 49.46641097749983, 47.7926663671221, 44.70018993105207, 41.70938301086426, 43.69912127086094, 45.423806599208284, 49.355420453207834, 38.15113408224923, 36.21094342640468, 40.88564280101231, 39.92292124884469, 45.93538856506348, 45.896780899592805, 48.43964440482003, 50.39593403679984, 51.55278478349958, 48.90564271381923, 48.4091591835022, 49.936095305851524, 49.28023747035435, 49.31304339000157, 47.20396981920515, 45.91441542761666, 48.91585309164864, 45.65314926419939, 40.00262403488159, 37.93305097307478, 39.71023341587612, 38.499336106436594, 38.084358419690815, 40.99068219321114, 39.51670871462141, 39.09459522792271, 40.35382768086025, 44.54673549107143, 52.42695501872471, 54.079601424080984, 53.475344385419575, 49.21328115463257, 47.01962716238839, 50.904184341430664, 51.94403437205723, 53.351002897535054, 47.61784621647426, 44.56102098737444, 48.18207120895386, 54.02818822860718, 56.41489791870117, 52.212029865809846, 54.77763829912458, 56.263590472085134, 55.37367214475359, 53.28577668326241, 50.323995862688335, 51.099758761269705, 52.1733283996582, 52.012151036943706, 53.03965411867414, 55.21216126850673, 53.47215516226632, 56.705162388937815, 57.107542991638184, 61.84157998221261, 60.58675616128104, 60.201214517865864, 59.0931852885655, 63.26045772007534, 63.629275049482075, 62.27992098672049, 68.37503365107945, 72.42682007380894, 57.03769275120327, 12.970169305801392, 0.4909324624708721, 0.365217104021992, 0.6867890985948699, 3.5342613586357663, 70.08712536948067, 75.81706156049455, 73.33088493347168, 81.86958871568952, 56.257879052843364, 93.38551916394914, 59.98440987723214, 37.79205117906843, 66.93877846854073, 91.0414262499128, 38.95898723602295, 0.985933312347957, 0.400791907949107, 0.2925108011279787, 0.19522470289043017], [0.1731996868870088, 0.048248450471354384, 0.06842996486063514, 0.12697516727660382, 0.07532189932784863, 0.09089030857597079, 1.6314357263701302, 51.97821256092617, 48.65881838117327, 40.75116041728428, 18.506841353007726, 42.26064961297171, 56.413588183266775, 38.4830391066415, 60.732008252825054, 55.16459042685372, 55.85052006585257, 46.11873415538243, 0.20853275592838014, 0.29573557951620644, 3.0052850118705203, 0.661565509225641, 3.0836009808949063, 1.1011696202414376, 0.36185732430645395, 28.459008489336284, 51.89692211151123, 55.40444919041225, 55.09801973615374, 53.16468347821917, 52.319219725472585, 49.69853292192732, 46.97641978945051, 45.75449916294643, 47.678774969918386, 47.413603918892996, 52.55265140533447, 51.42555979319981, 51.351491996220176, 50.72798497336251, 49.76165035792759, 46.42628574371338, 47.798072065625874, 44.79621056147984, 44.84602219717843, 45.5833546093532, 46.33254064832415, 46.243999753679546, 46.050509793417795, 46.05728081294468, 46.77535629272461, 47.46134499141148, 40.78362240110125, 28.910580601011002, 24.93909103529794, 39.345175061907085, 51.05928897857666, 48.55990730013166, 45.84507935387747, 38.90505184446062, 38.3774299621582, 33.910255908966064, 36.05312204360962, 36.22651086534773, 32.31014135905674, 35.376287596566335, 35.94590439115252, 35.502953256879536, 35.452589239392964, 36.173391887119834, 38.115708691733225, 39.049313817705425, 43.57737493515015, 43.64872946058001, 43.67299951825823, 42.04482814243862, 43.317474092756, 46.50688484736851, 44.342743328639436, 44.05880866731916, 43.86703143801008, 44.24147680827549, 44.667005334581646, 44.85057326725551, 45.69876071384975, 46.87801940100533, 43.26639788491385, 37.735715184892925, 35.92414958136422, 40.18936382021223, 45.02998617717198, 33.678811413901194, 33.92975950241089, 38.13193620954241, 40.66680581229073, 45.5449275970459, 41.244948046548025, 44.36294869014195, 43.925733293805806, 44.817749977111816, 42.8958990914481, 44.157476561410085, 46.04118183680943, 45.78660331453596, 44.0824533871242, 42.412519863673616, 42.49397359575544, 42.169968673161094, 41.991247109004426, 35.54688324247088, 33.72555889402117, 34.10054969787598, 37.13631493704659, 33.58922134126936, 36.30568906239101, 36.86734322139195, 35.71405342647007, 35.045584610530305, 37.93092482430594, 45.513254233769004, 49.172338894435335, 49.85513489586966, 50.63447959082467, 42.6336532320295, 46.786740916115896, 45.838040828704834, 50.60435220173427, 37.51695810045515, 46.17713376453945, 46.43684005737305, 45.20654337746756, 50.38592515672956, 50.02113430840628, 53.69969824382237, 52.662877627781455, 55.244310583387104, 49.017970766339985, 50.87032576969692, 48.719861779894146, 49.27426896776472, 47.64170633043562, 47.46174798692976, 47.715631689344136, 48.43674005780901, 47.81028005055019, 53.80615159443447, 52.31738887514387, 57.66195365360805, 60.30262347630092, 62.23664065769741, 54.71107108252389, 59.950030190604075, 62.047059059143066, 61.09853267669678, 56.0939119883946, 37.76598501205444, 4.654063659054892, 0.32325297008667675, 0.35889359191060066, 0.22030802550060408, 3.9708798612867082, 65.44986983707973, 59.65781675066267, 63.89464065006801, 64.84730121067592, 54.73118264334542, 33.83807454790388, 31.052010195595876, 40.26798963546753, 45.832176549094065, 68.81059537615094, 13.686591114316668, 0.5463999861053058, 0.12960288913122245, 0.08812656759151391, 0.07126233287687812, 0.19460130562739714, 0.025714341517803923, 0.07608995347150735, 0.08214408039514508, 0.07616153891597476, 0.09452287293970585, 2.7419658729008267, 67.41370868682861, 53.79701471328735, 49.13650356020246, 21.920861312321254, 32.400394984654014, 52.95787729535784, 44.32967724118914, 67.14158943721226, 57.35284219469343, 61.564180101667134, 49.588032245635986, 0.2450733594596386, 0.18193985575011798, 2.4266116746834347, 3.301144519022533, 3.617394817726953, 2.47454816528729, 0.3813440358000142, 30.52172715323312, 55.870642048971995, 56.02915825162615, 57.75909641810826, 56.62069313866751, 55.96183715547834, 49.945291246686665, 49.90902165004185, 48.463223116738455, 48.075402464185444, 49.304681232997346, 54.502093587602886, 53.02037286758423, 52.141359737941194, 51.812810693468364, 52.011327675410676, 47.94540861674717, 49.83873019899641, 47.003760950905935, 47.16702972139631, 47.815505095890586, 48.21011413846697, 47.29103422164917, 47.65904903411865, 48.834298610687256, 48.10967097963606, 51.582825320107595, 42.712626457214355, 32.1071149962289, 30.696140834263392, 40.051813806806294, 51.43854250226702, 50.74449041911534, 48.05339057104928, 40.86409643718174, 40.67793335233416, 35.230740206582205, 38.26319810322353, 35.77031646456037, 34.689277512686594, 37.993778228759766, 38.44710302352905, 36.12141588756016, 36.807064124516074, 39.17959948948452, 39.32085289273943, 41.26507697786604, 44.95188842500959, 44.37759896687099, 45.87883717673165, 44.74356753485543, 47.50123459952218, 47.72932311466762, 45.75954008102417, 47.300369126456125, 48.267613955906455, 47.47840976715088, 47.02720417295183, 47.03681353160313, 47.16069991247994, 47.445947783333914, 43.80378198623657, 39.62427030290876, 39.29586022240775, 42.39092486245291, 45.394137791224885, 36.11830309459141, 36.23858336039952, 39.00702360698155, 41.82566806248256, 46.03792660576956, 44.156010491507395, 45.87357044219971, 46.99646881648472, 44.89788702556065, 44.13533960069929, 45.78339672088623, 48.448089940207346, 47.2944701058524, 45.9212281363351, 45.76779801504952, 45.530013288770405, 43.90610810688564, 42.769942147391184, 37.83541488647461, 36.84841980252947, 36.15559755052839, 38.34585387366158, 36.06769936425345, 36.27311590739659, 39.038870675223215, 35.879410130637034, 36.790635108947754, 39.675784247262136, 45.264206477573936, 51.337797096797395, 50.82533965791975, 51.58570187432425, 46.17829411370413, 46.73579324994768, 46.78596271787371, 51.20444032124111, 40.921860286167686, 49.55954115731375, 48.146103858947754, 47.19886289324079, 52.121279444013325, 52.93609816687447, 54.245284693581716, 55.78681550707136, 57.91019194466727, 51.2267301423209, 52.947875363486155, 51.826797417231965, 52.43029015404837, 50.18516738074166, 51.17393772942679, 48.919612067086355, 51.335705689021516, 52.54213530676705, 55.77098056248256, 54.87375620433262, 60.23778983524868, 61.03365734645298, 62.55796010153634, 57.208542006356375, 62.70344148363386, 64.58920342581612, 61.745965821402415, 60.07038688659668, 43.05573545183454, 4.963830419949122, 0.14914139998810633, 0.3684073585484709, 0.4934531929237502, 5.501699158123561, 68.52891540527344, 67.41747461046491, 68.60831941877092, 71.42804431915283, 57.59377792903355, 51.5413167817252, 44.44488532202584, 41.586455481392996, 53.705517360142295, 77.90963663373674, 24.38391259738377, 0.7399687107120241, 0.23736935428210668, 0.13842258229851723, 0.03495491808280349, 0.2987760135105678, 0.11394456720777921, 0.26828153697507723, 0.2265388632991484, 0.2840243365083422, 0.18989090195723943, 4.522850402763911, 78.63408361162458, 62.93042523520333, 56.08126974105835, 28.855526549475535, 53.32554817199707, 65.57349218641008, 52.39154699870518, 70.69382122584751, 65.74531418936593, 66.97031634194511, 56.14437675476074, 0.3129533513316086, 0.950022850717817, 10.148675220353262, 6.331168157713754, 10.413692542484828, 4.777491893087115, 0.8617041355797223, 33.23423440115792, 57.0681779725211, 58.54551437922886, 60.85840293339321, 59.835815702165874, 59.296600750514436, 55.8282858303615, 53.49804067611694, 49.36791678837368, 50.261670521327424, 50.734276567186626, 54.660099097660606, 54.75643587112427, 53.3952386038644, 54.17434358596802, 53.53316729409354, 49.92729888643537, 52.9947235924857, 49.53532321112496, 50.96585655212402, 51.336126055036274, 51.387851919446675, 48.627971853528706, 51.24411106109619, 50.586276463099885, 50.2143428666251, 52.771523135049, 43.75770500728062, 33.50783014297485, 38.087349619184224, 44.05872876303536, 52.845580509730745, 52.99494593484061, 49.42116778237479, 43.08796467099871, 43.4682673726763, 37.321696349552695, 39.942900793892996, 39.069929122924805, 36.41431025096348, 40.832155568259104, 40.61622640064785, 37.45014074870518, 38.604476247514995, 43.39134734017508, 43.2400016784668, 44.839529105595176, 47.432659353528706, 47.07896130425589, 48.861507756369456, 47.433524404253276, 48.49495553970337, 50.09295088904244, 48.31152309690203, 50.285895415714805, 50.34092514855521, 50.796987533569336, 48.97918939590454, 50.16368007659912, 48.21701717376709, 49.84470564978463, 46.41001306261335, 42.800555910382954, 42.244592326028005, 44.70115225655692, 48.523488317217144, 39.247719628470286, 37.67016240528652, 42.11613403047834, 44.9426577431815, 47.89629874910627, 44.6614328793117, 47.57877649579729, 48.41291468484061, 48.89742646898542, 48.12579427446638, 49.82154382978167, 52.279132093702046, 50.1254232951573, 49.03188453401838, 49.241362299237935, 49.3484514100211, 47.02294145311628, 46.19583484104702, 39.04147972379412, 37.82218551635742, 38.68166378566197, 41.971086910792756, 37.32786634990147, 37.328686237335205, 40.988635948726106, 39.378258909497944, 39.78983197893415, 40.99714401790074, 47.93119260243007, 53.75040619713919, 53.285891328539165, 54.21528237206595, 47.0272284916469, 46.973011698041645, 49.404367038181846, 53.17207983561924, 45.57996736254011, 46.41146176201956, 48.29568120411464, 48.38646984100342, 53.28251797812325, 53.6368795803615, 58.964150292532786, 57.277923243386404, 59.641828945704866, 54.6157556942531, 55.33990042550223, 53.99866533279419, 53.37669733592442, 52.314383779253276, 54.00312260219029, 52.37021950313023, 52.83843428747994, 53.42770058768136, 58.663022313799175, 57.04468263898577, 64.04280403682164, 64.9206463950021, 65.6135971886771, 57.593541690281455, 65.5949273790632, 66.40800557817731, 66.67268330710274, 57.289467675345286, 42.52625492640904, 7.527312704495021, 0.506390358720507, 1.5101076939276286, 0.7895461161221776, 6.022229100976672, 75.1074698311942, 74.26238822937012, 75.01141098567417, 76.02591051374162, 66.13912418910435, 48.17479991912842, 41.49051128114973, 54.74138259887695, 57.773201261247905, 92.60629258837018, 34.06711496625628, 0.9239906647375652, 0.40004247959171024, 0.38316443668944494, 0.2534976159887654], [0.11487581580877304, 0.037674306625766416, 0.01875278596500201, 0.08109947573393583, 0.039708995659436495, 0.030485143286309073, 2.43413679088865, 49.468491962977815, 50.49583523614066, 34.21156454086304, 44.4847297668457, 65.3206958770752, 70.30709144047329, 43.91162150246756, 50.36639724458967, 60.62372752598354, 49.87179320199149, 53.9311705316816, 1.6125382546867644, 0.2818369838808264, 3.0987875717026845, 1.5917024527277266, 2.7605800969260077, 1.0453162001711982, 0.1964218829359327, 18.77722876412528, 51.77645771844046, 46.51983281544277, 50.2566191809518, 49.12395511354719, 47.088886805943076, 48.109170709337505, 49.20526640755789, 49.175823416028706, 53.35791635513306, 43.817219802311485, 48.06597375869751, 50.171340465545654, 50.20088768005371, 51.397388322012766, 49.80514260700771, 48.33194385256086, 50.21126481464931, 49.76112229483468, 48.31458377838135, 46.33801930291312, 44.517539160592214, 46.246039049965994, 49.9903746332441, 47.12542390823364, 47.078030245644705, 47.88205146789551, 42.45121785572597, 40.15772867202759, 51.81619446618216, 52.78565229688372, 48.34291158403669, 48.185291699000764, 42.49634640557425, 38.383964742933, 36.20581912994385, 34.63947629928589, 35.733536175319124, 33.771639347076416, 34.463672978537424, 34.446222577776226, 34.071273463112966, 34.892053740365164, 35.352027961185996, 34.03367676053728, 35.51090199606759, 38.10055814470564, 42.952995913369314, 41.64741897583008, 42.21100473403931, 41.36422777175903, 43.49190861838204, 43.70616327013288, 43.86492265973772, 44.45954254695347, 46.32323006221226, 42.96559647151402, 44.636332511901855, 45.68454817363194, 46.569453375680105, 46.96470512662615, 43.10695062364851, 35.89672156742641, 35.71317447934832, 41.17040777206421, 42.064067704336985, 32.359751496996196, 34.417693274361746, 37.44679519108364, 43.589259828839985, 43.24809980392456, 45.93841450554984, 44.40627418245588, 44.43226739338466, 45.20323950903756, 42.75844982692173, 43.40023408617292, 43.24381276539394, 45.96520675931658, 43.194518770490376, 44.00600583212716, 43.36760881968907, 41.23961183003017, 38.09338065556118, 33.98764147077288, 33.96688025338309, 35.94403879983084, 35.853607995169504, 33.21525887080601, 34.546818596976145, 39.77053683144705, 39.18326119014195, 35.856932708195274, 37.25645276478359, 38.95551661082676, 43.88218893323626, 47.61333336148943, 49.26407596043178, 48.87854821341378, 46.65524278368269, 45.30623960494995, 46.6830598967416, 43.63849476405552, 37.345209053584504, 53.05330038070679, 43.94551828929356, 47.707491874694824, 46.024707657950266, 48.51724188668387, 51.528827394757954, 48.7644032069615, 47.988140038081575, 52.525400570460725, 48.80326100758144, 51.14087125233242, 51.502254009246826, 52.699435574667795, 51.32789938790457, 50.135505131312776, 49.34502247401646, 49.39128705433437, 50.7240001814706, 56.3756788117545, 55.06617266791207, 58.46551282065255, 59.54325485229492, 60.63916642325265, 55.665437425885884, 61.21940353938511, 50.37250123705183, 35.79297801426479, 1.6109739329133714, 0.277444528149707, 0.14020251535943576, 0.26578623801469803, 11.112462452479772, 66.18897751399449, 56.107863971165244, 66.86728845323834, 63.968868255615234, 57.56326491492135, 32.507046358925955, 27.198190110070364, 39.32474388395037, 49.55189119066511, 58.97193227495466, 12.302065270287649, 0.6062582827040127, 0.1702890159296138, 0.07207250368914433, 0.08642018094126667, 0.08550514932721853, 0.08981982458915029, 0.10982659246240344, 0.14113666809030942, 0.08718831650912762, 0.07039256633392402, 2.7869582814829688, 61.978695733206614, 56.93707936150687, 46.09961271286011, 43.954474517277305, 64.09995297023228, 72.95369502476284, 47.44162947790963, 56.25410270690918, 63.78284413473946, 54.37186002731323, 60.22806930541992, 1.9353453729833876, 0.21845438996595995, 1.790042906999588, 3.759979452405657, 3.397254607507161, 2.3119199318545203, 0.6092963825379099, 20.037941183362687, 53.86963728496006, 48.299266474587576, 51.88490172794887, 50.322231020246235, 51.287273270743235, 51.47822366441999, 51.54574278422764, 48.93335212979998, 54.10082122257778, 49.23305920192173, 50.420937129429404, 49.85476664134434, 52.58695813587734, 51.98401778084891, 51.87419802801949, 51.577652386256624, 52.54795789718628, 52.811958176749094, 49.94357851573399, 47.95354495729719, 48.383412633623394, 51.9861022404262, 50.237508160727366, 48.84374121257237, 48.34465905598232, 49.431096758161274, 41.3190610068185, 44.38037477220808, 56.260856355939595, 52.41389240537371, 50.78682231903076, 51.47196681158883, 45.24919836861746, 41.117170674460276, 37.93912022454398, 36.313325132642476, 37.83966370991298, 35.82838603428432, 37.48095253535679, 36.887329714638845, 36.86972992760794, 36.226986816951204, 36.79180588041033, 35.21772275652204, 38.09208134242466, 39.194284507206504, 45.57412392752511, 43.87290613991873, 45.08178847176688, 43.023888383592876, 43.76699127469744, 46.18937301635742, 46.16999101638794, 47.21105350766863, 47.3643342426845, 43.735481194087434, 47.5064492225647, 46.21123552322388, 47.86101232256208, 48.5306692804609, 44.59240252631051, 37.71878937312535, 39.15339435849871, 42.41059173856463, 44.57013354982649, 33.307489258902415, 36.21658536366054, 39.12356921604702, 44.06152193886893, 44.578457491738455, 46.621762888772146, 44.684414046151296, 46.42466333934239, 47.166227204459055, 44.361684117998394, 45.365935053144185, 44.511681829180034, 46.920170647757395, 45.3643091746739, 44.95522356033325, 45.41489553451538, 43.049158981868196, 39.43450457709176, 35.409010137830464, 36.40758786882673, 35.94246850694929, 35.64328949792044, 34.034451484680176, 35.822410583496094, 40.59063618523734, 39.322072301592144, 36.967438970293315, 38.89829124723162, 40.87656497955322, 47.12688997813633, 51.132370131356375, 51.14151048660278, 51.14447389330183, 49.62131411688668, 44.35535430908203, 46.75767660140991, 44.365957260131836, 42.88702276774815, 55.76320552825928, 45.004611355917795, 50.04870823451451, 48.58588661466326, 50.52680335726057, 54.6953820501055, 52.721249444144114, 48.16752862930298, 56.08451802389962, 50.19518320901053, 54.937412125723704, 53.33046749659947, 55.4529823575701, 51.949037075042725, 53.51104422977993, 51.426397051130024, 52.61289576121739, 52.12071316582816, 58.18810599190848, 57.581236430576865, 61.32744802747454, 60.963668142046245, 63.07419736044747, 56.75860793249947, 62.14807891845703, 55.4721976007734, 36.387792451041086, 1.7648023813962936, 0.4834199398756027, 0.41490600630640984, 0.3124414102307388, 12.268345662525721, 72.19168608529228, 61.56263065338135, 70.9222571509225, 70.53054550715855, 60.322279930114746, 37.548561981746126, 28.9361378124782, 40.94553279876709, 55.67892040525164, 69.8302435193743, 16.84863465172904, 0.993067700948034, 0.24045875136341366, 0.15652563875275, 0.09490484744310379, 0.21118288300931454, 0.19712890285466397, 0.20657507383397647, 0.21573042470429624, 0.09993922444326536, 0.18346760448600563, 4.277968091624124, 76.99922806876046, 62.74942466190883, 52.066124643598286, 56.6306151662554, 73.37929998125348, 73.95882838112968, 56.197381087711875, 62.305129051208496, 71.13637978690011, 59.103649275643484, 65.55393300737653, 2.7480123255934035, 0.6970673842089516, 10.80301400593349, 4.287141016551426, 9.787410582814898, 6.250080508845193, 1.0700580839599882, 23.746731519699097, 57.20751714706421, 48.78845092228481, 53.26808656964983, 53.75145190102713, 53.73401887076241, 53.128049101148335, 53.078449385506765, 49.994133608681814, 55.38142286028181, 48.64772210802351, 51.40409333365304, 52.1993841443743, 54.743046692439485, 54.66037702560425, 53.44333403451102, 54.01062318256923, 55.093892506190706, 55.21935265404837, 51.29284225191389, 49.85924128123692, 51.50063507897513, 52.22809757505144, 51.54703514916556, 50.11843688147408, 49.97992106846401, 51.54976231711251, 43.27784851619175, 44.87160199029105, 51.46472331455776, 55.876190185546875, 52.783112730298726, 52.69972045081002, 47.42916440963745, 43.92533029828753, 38.98835379736764, 38.26559175763811, 39.71619497026716, 38.27020536150251, 39.456568581717356, 40.360383306230815, 37.508773122514995, 39.032884802137104, 38.55814913340977, 37.537903445107595, 39.54900394167219, 42.450043610164094, 48.62208672932216, 44.7714923449925, 46.92672279902867, 47.46019853864397, 45.2901371547154, 48.67970814023699, 48.75112172535488, 50.45127296447754, 51.21523434775216, 46.958236353737966, 49.531727518354145, 49.68859004974365, 50.53942476000105, 49.24272762026106, 45.06935119628906, 39.4085738999503, 42.16292667388916, 45.32311677932739, 47.922173840659006, 36.24731377192906, 38.68364749635969, 42.322891575949534, 45.44692325592041, 48.46554034096854, 48.89887516839163, 47.133966718401226, 50.07771348953247, 51.354201793670654, 47.43055752345494, 48.06970494134085, 45.88755021776472, 51.031312056950156, 47.179328032902305, 48.62071098600115, 48.83621283939907, 47.147678988320486, 41.88755914143154, 37.59751204081944, 39.31045838764736, 38.49884973253523, 38.654496329171316, 36.854659284864155, 37.49943126950945, 43.13394437517439, 42.64635453905378, 38.91154841014317, 40.39281054905483, 43.2149395261492, 48.1535245350429, 52.954521315438406, 52.95461859021868, 53.73152099336897, 49.62359312602452, 47.01504135131836, 48.55647141592843, 46.54738242285592, 45.13138123920986, 51.197363580976216, 49.51135540008545, 51.39124958855765, 51.202678952898296, 52.17344651903425, 54.24542713165283, 52.86947536468506, 52.72067969185965, 58.37826429094587, 52.68528209413801, 56.827968324933735, 55.61057097571236, 57.99624538421631, 55.05418355124337, 56.11479827335903, 53.470824582236155, 54.556803703308105, 55.46466227940151, 63.67770399366106, 61.411319732666016, 64.15612915584019, 63.96137114933559, 62.357532364981516, 59.50144059317452, 61.53518526894705, 53.236823150089805, 40.61986378261021, 2.7770069411822726, 0.4522880475435938, 1.044287541082927, 0.5665423252752849, 15.679539442062378, 77.0946546282087, 68.4624558857509, 76.40597002846854, 76.81817885807583, 67.34198938097272, 50.699907302856445, 37.10305043629238, 54.81381409508841, 63.62300777435303, 81.24930913107735, 27.24396310533796, 0.8614202908107212, 0.3059945675943579, 0.19990569885287965, 0.24336241983941623], [0.017966801533475518, 0.11154108082077333, 0.014558643967445408, 0.07168582693806716, 0.04550192392032061, 0.061182403404797824, 1.7405660876205988, 53.31727981567383, 45.7210887500218, 33.70787920270647, 31.699787276131765, 71.07623617989677, 76.57722227913993, 45.44327197756086, 48.713128975459504, 60.96299416678292, 49.054740633283345, 64.42235633305141, 8.156145521572657, 0.26056260402713505, 1.195338772875922, 3.08075504217829, 0.9922465107270649, 1.8622329533100128, 0.20713194752378122, 7.136731011526925, 49.65100029536656, 44.97187491825649, 49.17560454777309, 45.24871894291469, 49.87806395121983, 49.378075054713655, 51.743644850594656, 48.883735043661936, 51.03118698937552, 43.94723449434553, 47.878018038613455, 52.991051469530376, 52.844044957842144, 49.59956278119768, 50.29329177311489, 49.93140527180263, 47.034666538238525, 50.37963356290545, 51.175101552690776, 48.62645019803728, 48.63460043498448, 44.18226078578404, 48.15350021634783, 47.23838424682617, 49.42762265886579, 45.01754195349557, 46.81474215643746, 56.35962152481079, 49.82183218002319, 48.22488253457205, 50.83315290723528, 46.827797821589876, 40.30956418173653, 38.43251528058733, 36.59294148853847, 34.666949476514546, 33.84357752118792, 34.05857910428728, 34.92194489070347, 34.3434066091265, 34.83016960961478, 34.17968967982701, 34.68407678604126, 33.67144979749407, 35.31495584760393, 39.16412237712315, 42.78381422587803, 43.408356530325754, 40.762843813214985, 43.423698152814595, 43.31664725712368, 44.07457760402134, 43.54756368909563, 44.9524199622018, 43.109281744275776, 44.45869834082467, 43.66501603807722, 46.273446219308035, 46.44813782828194, 46.12565108707973, 45.237831115722656, 38.28295183181763, 35.71273674283709, 41.75189903804234, 39.71942935671125, 34.32808583123343, 35.88298497881208, 39.89587885992867, 44.35480540139334, 43.753723689488, 44.12270777566092, 45.35160091945103, 41.70524883270264, 44.05052294049944, 42.215677397591726, 41.12127358572823, 44.840376785823274, 42.615306513650076, 39.92390094484602, 41.20536763327462, 41.28136355536324, 38.838991846357075, 33.55310113089425, 34.30894007001604, 34.49686104910714, 35.09974929264614, 34.64191859109061, 33.81421790804182, 32.663036891392295, 36.19794682094029, 38.16136877877371, 37.40420968191964, 36.22479466029576, 39.77768305369786, 40.346080439431326, 46.46613713673183, 47.078846658979145, 48.33627258028303, 48.13527856554304, 50.46123668125698, 43.48473807743618, 44.374110971178325, 35.10136822291783, 45.36534445626395, 53.48417901992798, 44.13185855320522, 48.56567777906145, 46.67734152930123, 46.797930989946636, 41.82216269629342, 49.7825540133885, 50.71245574951172, 52.068636417388916, 51.35637657982962, 53.81727566037859, 53.43276582445417, 54.44554567337036, 51.79196957179478, 52.5470164162772, 50.19417224611555, 50.078908579690115, 49.53174488885062, 54.24977322987148, 53.649643421173096, 57.515200751168386, 58.203729016440256, 61.11668137141636, 59.112438746861045, 50.1938977922712, 25.3500074999673, 0.10329714497285229, 0.12315182600702558, 0.5601800009608269, 0.18709733257336275, 18.67109329359872, 69.99720178331647, 56.22594165802002, 69.62813431876046, 64.12418133871896, 57.17296028137207, 44.64117193222046, 39.560242652893066, 38.69396557126726, 49.523341042654856, 66.35567869458879, 16.515023844582693, 0.5476730806486947, 0.10998387687972613, 0.08578155735241515, 0.014739107141005141, 0.09884476102888584, 0.12889285651700838, 0.02339931743751679, 0.049037420456962924, 0.06813623383641243, 0.06965375026421887, 2.9712381873811995, 64.6560867854527, 53.37487690789359, 34.95936094011579, 39.65920237132481, 81.0974006652832, 75.71340138571603, 53.77545097896031, 54.329792158944265, 66.84555448804582, 53.863543714795796, 69.42075838361467, 9.356504150799342, 0.41104392068726675, 0.5833441551242555, 3.6514950564929416, 2.270402491092682, 3.607645843710218, 0.3771267235279083, 8.872661130768911, 51.915286200387136, 45.45386798041207, 50.48920318058559, 44.97863204138619, 51.029710497174946, 49.77462264469692, 52.069261755262104, 49.897723879132954, 52.81616531099592, 47.333699635096956, 49.93756832395281, 54.14621727807181, 53.571163518088206, 53.32342897142683, 52.51077461242676, 50.667278562273296, 50.85424763815743, 51.84339666366577, 52.03281845365252, 51.52685063225882, 50.26902518953596, 45.987583432878765, 51.30083268029349, 49.90968172890799, 51.57006842749459, 46.185926709856304, 48.82841348648071, 57.03165824072701, 50.836276122501914, 50.53818450655256, 51.550523144858225, 49.45907020568848, 42.830568654196604, 39.91125522341047, 37.5534222466605, 37.594336714063374, 35.08105863843645, 34.89547572817121, 37.52227347237723, 35.758664335523335, 35.852405956813264, 35.37964705058506, 36.313606534685405, 36.027649947575156, 36.78307894298008, 42.024251052311485, 44.31546817507063, 44.95367063794817, 44.08058432170323, 45.424734183720176, 44.29448114122663, 45.50655269622803, 43.80834000451224, 46.443687507084434, 44.79943105152675, 47.001686913626536, 47.8937383379255, 46.428974696568076, 46.768210070473806, 47.73980794634138, 47.49096168790545, 39.79232290812901, 38.599966866629465, 44.88377523422241, 41.801029750279014, 34.62886987413679, 37.78896617889404, 43.80050591060093, 45.23047297341483, 46.22010142462594, 45.57822683879307, 46.49510070255825, 43.97060823440552, 45.86123044150216, 43.42947905404227, 43.754355975559776, 44.821383884974885, 44.494790758405415, 44.00120462690081, 43.13390268598284, 42.334665298461914, 41.43375839505877, 35.953130517687114, 35.02935014452253, 36.218061855861116, 36.83066715512957, 35.68783439908709, 36.08292286736624, 36.36834444318499, 37.154171807425364, 39.891046387808665, 39.047986711774556, 37.061774662562776, 40.20850263323103, 42.36416734967913, 48.74645601000105, 49.284468923296245, 51.539409501211985, 52.67026008878435, 52.257356439317974, 44.79112795421055, 45.74777330671038, 38.093693324497764, 50.37733023507254, 57.85411998203823, 45.436344623565674, 49.83451611655099, 46.26273904527937, 48.97019842692784, 43.98527935573033, 50.246106556483674, 53.427777017865864, 54.04579496383667, 53.48450558526175, 54.64117915289742, 54.52242054258074, 57.047312532152446, 55.59657730375017, 54.56233099528721, 54.27230971200125, 53.833940914699006, 54.683406829833984, 56.737686906542095, 56.07366841179984, 59.49081679752895, 61.531620843069895, 61.74330466134207, 62.22502326965332, 54.04434626443045, 24.973762546266826, 0.10301696429295198, 0.249641447194985, 0.43824139556714464, 0.24505175490464481, 19.57000606400626, 76.5548004422869, 63.287611280168804, 73.36026886531285, 70.18068286350795, 65.00921508244106, 49.13753536769322, 32.32179348809378, 37.967406341007774, 53.96758256639753, 73.48023646218437, 23.073524032320293, 0.6536750697663852, 0.1454867696655648, 0.0781693376068558, 0.05089886932234679, 0.19129342027008533, 0.2522558154804366, 0.08904992483024086, 0.2245362621865102, 0.2468818181327411, 0.13241548463702202, 3.5106466029371535, 79.7582118170602, 61.74213736397879, 48.861361844199045, 43.40824883324759, 79.76828670501709, 76.57190690721784, 59.23338603973389, 59.51931135995047, 74.172242300851, 59.50139890398298, 76.23313358851841, 10.53756763253893, 0.6126594192215374, 2.5799410470894406, 8.7414904321943, 6.337531404835837, 6.446229023592813, 0.6087933438164848, 10.310721107891627, 56.756519998822895, 45.161390508924214, 52.93278040204729, 46.36993932723999, 52.83918121882847, 51.6374694279262, 55.066245623997276, 50.82018756866455, 55.197653429848806, 49.45593656812395, 53.77563510622297, 54.843309198107036, 55.94554015568325, 55.10369641440255, 55.29103027071272, 51.565562520708355, 51.1564074243818, 54.47004849570138, 55.45017181124006, 54.322889123644146, 53.66643721716744, 48.78821120943342, 55.64291136605399, 51.261231422424316, 54.21970837456839, 45.13609906605312, 50.73339762006487, 58.15714481898716, 53.8772976739066, 54.41288219179426, 53.65644570759365, 51.35449014391218, 46.31727198192051, 41.74714994430542, 39.34606443132673, 39.23237453188215, 37.365018367767334, 37.47804124014718, 40.00610508237566, 37.816811084747314, 38.637226581573486, 36.858001368386404, 38.54572575432913, 37.47110346385411, 39.283134596688406, 45.26087829044887, 45.253933565957205, 48.13314894267491, 46.78247124808175, 47.420437472207205, 47.05755737849644, 47.434073311941965, 46.45903607777187, 47.02595697130476, 46.575533049447195, 47.88089459283011, 50.82212264197213, 50.7945556640625, 49.798611300332205, 50.24157633100237, 48.12970263617379, 42.274914264678955, 42.87838963099888, 48.37387275695801, 47.22266047341483, 39.12813765662057, 39.60637869153704, 46.04098033905029, 47.66932194573538, 48.57481813430786, 47.760385036468506, 49.84568534578596, 44.53936692646572, 50.06157282420567, 46.08910008839199, 45.65159286771502, 48.41359213420323, 46.731318610055105, 47.01161241531372, 43.79647248131888, 45.263650621686665, 43.998894350869314, 39.41021020071847, 37.891785621643066, 37.876252923692974, 39.616759300231934, 37.95076887948172, 38.744569301605225, 37.27637325014387, 40.30285569599697, 41.42573322568621, 40.36436462402344, 40.86561809267317, 42.13241365977696, 46.01473004477364, 50.903482573372976, 52.39681025913784, 51.82893398829869, 53.29625456673758, 52.998725754874094, 46.38421787534441, 46.75324017660958, 41.77736071177891, 48.66268852778843, 52.88580363137381, 48.86281749180385, 51.32963296345302, 48.64447382518223, 47.696197577885215, 44.71714006151472, 52.84782477787563, 56.398479325430735, 55.28694125584194, 54.567239897591726, 58.485773767743794, 56.928915228162495, 60.02454267229353, 56.56288760049002, 56.89632817677089, 55.3916471345084, 55.89353288922991, 55.28662511280605, 60.365720067705425, 57.322172846112935, 63.8303211757115, 62.182819911411826, 64.18014213017055, 60.15596784864153, 54.244787897382466, 29.68853391919817, 0.16072814539074898, 0.3237308758710112, 1.096443542412349, 0.4850463611739022, 23.992890562329972, 80.79773875645229, 68.61819280896867, 79.23850045885358, 78.10854966299874, 70.22683279854911, 61.11889089856829, 52.14240196772984, 55.72508771078927, 63.91098281315395, 86.67856202806745, 31.26172767366682, 0.8637011455638068, 0.21388486373637403, 0.2868247319545065, 0.12303202386413302], [0.04143981296303017, 0.057183681188949516, 0.08773546679211514, 0.060504499423716745, 0.03000186350462692, 0.0742837136079158, 1.820528888276645, 54.18882710593087, 50.24992111751011, 44.81024244853428, 30.47922502245222, 50.70398589542934, 71.81027862003872, 42.75896051951817, 51.17669269016811, 61.481524331229075, 51.97425903592791, 65.01053524017334, 15.390211241585867, 0.3740574110831533, 0.6347243466547557, 3.950021803379059, 0.46233166860682623, 0.6765650414994785, 0.7043690181204251, 3.957619224275861, 47.74783311571394, 48.654381956372944, 50.33250045776367, 47.53536415100098, 50.07271426064627, 49.2932653427124, 50.59468725749424, 47.279444626399446, 49.91439955575125, 52.733968121664866, 54.908396448407856, 51.294211047036306, 53.55143758228847, 52.370139598846436, 51.515733514513286, 48.68307801655361, 48.3026294027056, 45.257174900599885, 48.67615066255842, 47.93661914552961, 49.57654339926583, 46.700260162353516, 44.564967564174104, 45.406373568943565, 45.197500297001426, 48.29901286533901, 49.23456348691668, 45.90845734732491, 48.86384929929461, 47.02098206111363, 45.55608640398298, 40.58988925388881, 40.620520387377056, 38.374782698495046, 37.99523735046387, 35.30177858897618, 37.16471569878714, 37.486830711364746, 34.546596254621235, 34.50842979976109, 32.6584232875279, 33.881271498543875, 35.02880471093314, 34.65317814690726, 34.16907630647932, 37.46601390838623, 41.369553565979004, 43.3175505229405, 44.85152169636318, 42.79164831978934, 42.3263726234436, 44.460334641592844, 44.161464827401296, 43.68866423198155, 44.94485337393624, 44.51818881716047, 43.401880809238975, 45.22625194277082, 45.96838903427124, 44.49932098388672, 47.574055194854736, 39.188746792929514, 36.20069483348301, 38.43351582118443, 38.44386863708496, 33.41029480525425, 37.88740478243147, 44.839185169764924, 45.03099019186837, 43.06172827311924, 44.34170804704939, 43.13141175678798, 43.965897355760845, 41.484469822474885, 42.231866700308665, 45.02272183554513, 41.74549627304077, 43.0914283479963, 41.18912969316755, 39.7850272996085, 40.743625095912385, 39.61353186198643, 34.86630024228777, 33.109152930123464, 34.302165576389854, 33.97812591280256, 33.567549909864155, 31.547208309173584, 34.26488501685006, 34.45560611997332, 36.1488994870867, 36.11375202451433, 34.456033434186665, 36.46897520337786, 41.803468567984446, 40.76558835165841, 48.64026321683611, 47.62946707861764, 47.36158275604248, 48.79120240892683, 50.323575496673584, 46.64211763654436, 42.94366100856236, 32.68407951082502, 43.125436305999756, 55.80181319372994, 42.67466150011335, 48.630938734327046, 42.615476744515554, 39.86844737189156, 46.33208554131644, 49.93375376292637, 49.69660479681832, 49.87982184546334, 51.4095824105399, 49.296867983681814, 52.093184403010774, 51.676997729710166, 54.0180264881679, 54.687547956194194, 56.99317911693028, 53.420394556862966, 54.69404452187674, 52.03459024429321, 58.5547902243478, 53.833159242357524, 64.66896179744175, 49.73389230455671, 51.05035359518868, 13.269005247524806, 0.14249510876834393, 0.14989933717463697, 0.8530081393463271, 0.06309838952230555, 21.00329089164734, 70.50125190189907, 54.662193979535786, 67.93055738721574, 62.14684213910784, 55.921819005693706, 40.2208183152335, 37.49208354949951, 34.145421164376394, 45.03302948815482, 71.61923095158168, 12.556813154901777, 0.7209930175117084, 0.11358237200017486, 0.07802156625049454, 0.018328435253351927, 0.1216521007674081, 0.10698560705142361, 0.04744809127545782, 0.09640192639614854, 0.05207779677584767, 0.04120013743106808, 2.1239880962031226, 63.69110706874302, 56.64501878193447, 47.81483459472656, 34.259618282318115, 75.96420356205532, 76.86306422097343, 50.36167246954781, 55.46549606323242, 65.78587777273995, 53.67910725729806, 69.8477668762207, 16.187339850834437, 0.4043701487992491, 0.25381305334823473, 5.220926361424582, 3.092257784945624, 1.845164269208908, 0.12795947731605598, 4.943958571978977, 50.39353690828596, 46.13599000658308, 51.827158723558696, 48.54955448423113, 51.757562092372346, 47.48257868630545, 51.34487036296299, 48.60798536028181, 50.146368639809744, 54.57942008972168, 56.401421887534006, 51.9265353339059, 56.52686466489519, 54.50542524882725, 52.282783372061594, 50.747756072453086, 49.61834028788975, 48.02137327194214, 50.5636704989842, 50.33642271586827, 50.55735806056431, 48.05946329661778, 47.8306382724217, 48.67871107373919, 46.10993773596627, 49.12139817646572, 51.623145716530935, 48.441350187574116, 50.94217014312744, 49.87925556727818, 47.86740813936506, 41.56678165708269, 41.975109917776926, 40.00344392231533, 38.462927545819966, 37.12344339915684, 39.48521253040859, 39.135273456573486, 36.18337992259434, 34.74667658124651, 36.05764184679304, 36.38169888087681, 35.94996213912964, 35.199191910879954, 34.85695491518293, 39.00056178229195, 43.096236501421245, 44.99342475618635, 46.605556215558735, 44.602689334324424, 45.53633267538888, 44.56263296944754, 46.901236806597026, 44.868068831307546, 47.0343017578125, 47.474445819854736, 44.97416434969221, 48.158461230141775, 48.40299265725272, 47.32464960643223, 47.62613541739327, 41.08715098244803, 39.4667511667524, 41.08297858919416, 41.341951847076416, 35.373105321611675, 39.84533071517944, 45.13577250071934, 45.49078375952584, 45.85050589697701, 45.47443812234061, 46.38812971115112, 45.614701407296316, 43.96476479939052, 43.73471689224243, 46.574428285871235, 44.574160030909944, 45.02511896405901, 42.70940249306815, 44.29577350616455, 42.601191248212544, 39.45316743850708, 35.555662291390554, 34.82463189533779, 34.77641487121582, 35.40717233930315, 36.482513768332346, 34.19658769880022, 36.00499882016863, 35.16703912190029, 38.01226738521031, 36.309524468013215, 36.17319733755929, 38.91253852844238, 42.52270092282976, 42.81460516793387, 49.4879538672311, 49.752906050000874, 49.13008342470442, 50.61686590739659, 51.26121752602713, 45.51398032052176, 44.6426796913147, 34.99484191622053, 49.7126864024571, 58.879264150347026, 45.38302762167794, 50.41502768652779, 46.23785754612514, 40.78008924211775, 48.43800810405186, 50.608142444065635, 51.207893575940815, 53.80391427448818, 52.971148354666575, 51.450382232666016, 54.34991414206368, 55.484568868364605, 57.1569516318185, 54.26019205365862, 60.17713206154959, 58.34721973964146, 56.94660881587437, 55.12669842583792, 62.56596442631313, 55.62426240103585, 66.29192897251674, 55.37449550628662, 54.41950729915074, 13.766697764396667, 0.1570268590003252, 0.7439293467572757, 0.8192527049354145, 0.08248406715158906, 25.444487367357524, 77.27055522373745, 60.698643003191265, 73.56230163574219, 67.75307955060686, 63.6261761529105, 45.17908757073538, 30.175064155033656, 39.39002568381173, 50.04869086401803, 81.97695228031704, 16.350483553750173, 0.7006992836083684, 0.17880754811423166, 0.13012727456433432, 0.009249809730265821, 0.28855116931455477, 0.2863941607730729, 0.21572419575282506, 0.15066206481839928, 0.11876201656247888, 0.23257561294095858, 3.153953662940434, 79.37219074794224, 65.24131270817348, 61.20648683820452, 42.1789596421378, 64.90609686715263, 75.95146751403809, 56.28164536612374, 62.60829285212925, 70.89322757720947, 60.47209698813302, 76.04527514321464, 20.01005632536752, 0.7230058780738285, 0.9022404689873967, 12.311631202697754, 7.105349038328443, 5.515967283930097, 1.7937460797173637, 7.380796909332275, 55.0193452835083, 46.89386476789202, 52.13046496255057, 48.1997126851763, 53.49871465138027, 49.46251303809029, 53.36374241965157, 52.57398584910801, 51.42715093067714, 55.2808198928833, 58.376506396702354, 53.62697492327009, 60.7417357308524, 55.79476077216012, 53.71348346982683, 51.90236602510725, 51.209307534354075, 46.69379833766392, 51.81148706163679, 52.0960887500218, 54.47569738115583, 52.035201685769216, 50.89281014033726, 50.49522379466465, 47.88722092764718, 50.83072451182774, 53.82938289642334, 49.04484292439052, 54.020527839660645, 51.09341505595616, 51.61611761365618, 44.3383138520377, 44.47857713699341, 40.947037083762034, 40.66294608797346, 41.68634973253523, 41.89886038643973, 40.87633568899972, 37.5119171823774, 36.26436117717198, 37.973711831229075, 38.07863310405186, 38.749842984335764, 37.262261458805625, 36.804972716740195, 40.62864630562918, 47.10153947557722, 48.27399240221296, 49.33751147133963, 46.99455806187221, 47.623585428510395, 48.803083828517366, 48.93024281093052, 48.30448109763009, 50.150992665972026, 49.578641755240305, 47.0035525049482, 50.53627027784075, 51.61853558676583, 49.0144237109593, 50.49728046144758, 45.04253462382725, 42.67598165784563, 45.18815496989659, 46.684164660317556, 37.29484851019723, 42.75229719706944, 48.45059129170009, 49.23020349230085, 46.612716334206716, 48.25000722067696, 48.287944384983604, 49.5261481148856, 46.026875495910645, 46.13295711789812, 51.35302407400948, 46.06108495167324, 47.114980765751426, 46.416787556239534, 45.84732362202236, 45.90386806215559, 44.103520325251985, 36.865762506212505, 37.93304749897548, 36.94765050070626, 38.15864508492606, 37.797463825770784, 34.996464320591514, 37.35877888543265, 36.332668917519705, 41.02103539875576, 39.42227922167097, 38.0253404208592, 40.956299032483784, 45.252811431884766, 45.2738471031189, 53.502157483782085, 51.81245633534023, 51.879207679203574, 52.95697055544172, 53.074805055345806, 46.5767559323992, 45.83942699432373, 38.427731445857454, 47.684208461216514, 55.51241030011858, 48.14307791846139, 51.51462180273873, 45.02031775883266, 41.559649331229075, 50.23121656690325, 54.970436913626536, 55.13923297609602, 55.572241238185335, 56.282687595912385, 53.70817504610334, 58.31791223798479, 57.77752998897007, 60.388162749154226, 57.397171701703755, 63.7081093106951, 60.08236558096749, 59.28903416224888, 58.56901318686349, 64.76295007978166, 58.12827157974243, 66.81107057843889, 55.0660719190325, 58.07501711164202, 15.625831604003906, 0.16816171365124838, 1.1588028648069926, 2.2238185107707977, 0.17050606571137905, 28.52875624384199, 80.92711421421596, 66.1033548627581, 77.64254093170166, 71.87517479487828, 68.79201589311872, 58.00464923041207, 50.797946384974885, 49.36295230048043, 59.140926361083984, 93.75760909489223, 23.296955517360143, 1.23370846254485, 0.43956660159996574, 0.2212043431188379, 0.259699208928006], [0.09008510464004107, 0.032703715310032876, 0.08172288656766925, 0.05149769683235458, 0.046649981423148086, 0.030886924226901362, 1.138734295964241, 58.7164956501552, 56.568824836185996, 35.9118651662554, 23.784519297736033, 16.47294381686619, 21.757279872894287, 43.748158182416645, 55.17865705490112, 63.03981767381941, 51.652345521109446, 63.68549987248012, 20.91396485056196, 0.37052579915949274, 0.2502112537622452, 2.161461033991405, 0.3501962386071682, 3.4239441582134793, 0.027142564433493784, 5.555949824196952, 49.88358082090105, 47.076897689274375, 53.19913264683315, 47.66249534061977, 52.434931550707134, 51.65749761036464, 53.20179728099278, 58.291133880615234, 60.066294397626606, 52.46067115238735, 51.052243505205425, 51.002122674669536, 49.92107677459717, 47.295779841286794, 53.73705523354666, 46.79488073076521, 47.24199731009347, 47.70009551729475, 47.61941303525652, 47.81195804050991, 48.737895829336985, 48.90121323721749, 67.97707557678223, 48.99538564682007, 44.46378442219326, 47.23859964098249, 48.47295406886509, 49.63732624053955, 49.760014057159424, 43.640607016427175, 43.02543088368007, 39.046270506722585, 42.5318933895656, 36.97631181989397, 35.171590191977366, 36.63452993120466, 41.36637129102434, 37.007029805864605, 32.829661641802105, 33.92524664742606, 33.495559624263215, 34.29502282823835, 33.436218534197124, 35.11631032398769, 36.01230137688773, 37.95481620516096, 39.72803470066616, 41.12696763447353, 39.7617404120309, 42.864097186497276, 43.38658782414028, 42.802553517477854, 44.87446812220982, 42.498819964272634, 42.365108830588206, 42.02146829877581, 44.33940124511719, 44.85412032263619, 46.266327789851594, 46.24140460150582, 44.43304559162685, 38.37746122905186, 37.91835553305489, 39.01899882725307, 36.18523161751883, 33.64194427217756, 40.293548583984375, 46.51140117645264, 44.05362531117031, 44.48271826335362, 42.82982867104666, 42.207204069410054, 45.13478585651943, 41.321009976523264, 40.00558744158064, 42.68673052106585, 43.47681018284389, 41.14823259626116, 42.25903068270002, 42.62265770775931, 40.97675452913557, 37.23078611918858, 33.09293583461216, 33.165322167532786, 34.099371978214805, 34.031380380902974, 34.88963924135481, 34.46174485342843, 33.89763798032488, 34.40572500228882, 36.48759984970093, 38.00267539705549, 34.86904130663191, 37.30654580252511, 39.198359625680105, 39.492515087127686, 41.766688278743196, 47.24339737210955, 45.33689158303397, 47.965544496263774, 46.835677078792024, 50.79775530951363, 46.828245980399, 41.011335713522776, 30.270115511757986, 43.4836437361581, 49.4124755859375, 45.60038464409964, 41.02767440250942, 41.965323380061555, 52.535451139722554, 48.703801018851145, 55.03550679343087, 51.85612228938511, 53.324505942208425, 51.65738991328648, 49.92210163388933, 51.773991107940674, 49.879596029009136, 49.30527182987758, 52.39671993255615, 52.76459925515311, 56.79052448272705, 55.399564606802805, 55.79778323854719, 53.68325185775757, 62.47638825007847, 41.82796444211687, 55.50219644818987, 4.943723201751709, 0.09184553660452366, 0.6479637590902192, 0.7523575116481099, 0.30199685639568735, 32.544090679713655, 67.15715340205601, 59.78272451673235, 64.96432277134487, 58.46934127807617, 57.59738057000296, 38.780960491725374, 45.395200865609304, 36.735257966177805, 45.56981604439871, 68.34506607055664, 11.659599219049726, 0.7236699738672802, 0.1292464139738253, 0.10833817840154682, 0.10249983918453966, 0.09014926691140447, 0.02999523761016982, 0.040559668226965835, 0.1616395671984979, 0.07173348045242683, 0.16077813985092299, 1.7146393188408442, 70.3239825112479, 60.013231004987446, 45.77751159667969, 30.903780800955637, 34.88634579522269, 35.84042031424386, 46.24294710159302, 60.98785482134138, 66.49857534681047, 57.00933715275356, 67.20775018419538, 23.345257656914846, 0.4857265789593969, 0.2903231770864555, 2.5652304078851427, 2.4113501736095975, 1.9348668158054352, 0.24257944471069745, 6.951606682368687, 53.4673296383449, 46.94665718078613, 52.91318300792149, 49.782085009983604, 53.85513986860003, 52.534276894160676, 54.857396670750205, 58.967193603515625, 60.100840841020855, 53.86410651888166, 53.62956312724522, 51.60976348604475, 52.276457037244526, 50.55908121381487, 54.13029200690133, 48.349970953805105, 50.77730328696114, 48.916360310145784, 50.143856866019114, 49.955004828316824, 52.02625935418265, 48.63510765348162, 63.430681637355256, 52.0028578213283, 45.793819018772666, 47.25743620736258, 49.500359875815256, 51.12863547461373, 49.8524181502206, 45.59415210996355, 43.44269800186157, 42.03106723512922, 44.010807037353516, 38.01858677182879, 36.88265010288784, 38.52141400745937, 43.55365031106131, 38.918430600847515, 35.35988637379238, 36.35659156526838, 34.413062300000874, 35.1727158001491, 34.57253040586199, 35.76964248929705, 37.348467758723665, 40.38370840890067, 42.563528537750244, 42.80081646783011, 43.1380820274353, 42.867380210331504, 45.01253925051008, 45.26465811048235, 46.05209050859724, 43.841000011989046, 45.667566776275635, 45.46126433781215, 47.275227069854736, 47.34971175874983, 47.13254581178938, 49.00816338402884, 46.90618044989449, 41.77795478275844, 41.1797114099775, 40.924775055476594, 38.639762674059185, 36.11516598292759, 42.50605998720442, 47.84771694455828, 46.10028668812343, 46.06215844835554, 44.14111702782767, 43.98301771708897, 47.04629782267979, 44.64711611611502, 43.89174618039812, 45.16365909576416, 45.951619556971956, 42.70835331508091, 42.47734655652727, 44.340495586395264, 43.01419217245919, 38.91440759386335, 34.07799584524972, 35.791564055851524, 35.494281905038015, 36.029612813677105, 35.02107484000069, 34.60128205163138, 35.293520654950825, 34.64111954825265, 38.41960900170462, 39.9063914843968, 36.28951713017055, 38.96137741633824, 40.356627804892405, 42.47239596503121, 44.51897396360125, 48.23751088551113, 47.52774545124599, 49.212926796504426, 49.43400805337088, 54.15295703070504, 46.720409938267295, 42.95639705657959, 32.2524539402553, 50.58848251615252, 53.03066314969744, 46.429231779915945, 44.669819355010986, 43.795301709856304, 52.93119968686785, 51.57642602920532, 56.01173216956002, 52.48959302902222, 53.52239758627755, 53.05962324142456, 51.56221696308681, 52.988845416477744, 54.18673569815499, 52.80759470803397, 55.71110098702567, 56.36687197004046, 60.6604904447283, 58.456556592668804, 58.20163760866438, 55.51029109954834, 62.89364842006138, 46.142479624067036, 56.17546994345528, 6.3546821645327976, 0.352740934916905, 1.3335730752774646, 1.2779302724770136, 0.3604610078036785, 35.95092446463448, 73.17439065660749, 63.72149848937988, 73.73394298553467, 63.86378370012556, 61.08364268711635, 47.751501764569966, 50.81845051901681, 41.62303079877581, 52.97230175563267, 75.85469995226178, 16.05995852606637, 0.7838720434478351, 0.20532092398830823, 0.10033981794757502, 0.0867295725537198, 0.23951634764671326, 0.14323273061641625, 0.16649562519575867, 0.1444825514086655, 0.16222777563546384, 0.2851031800465924, 1.8598846793174744, 81.22995144980294, 71.3053252356393, 52.37567383902413, 33.557704312460764, 25.259458575929912, 32.263657910483225, 58.7297180720738, 65.11111736297607, 72.55757822309221, 62.39656734466553, 74.56148733411516, 29.209684916904994, 0.571651965379715, 1.5204045985426222, 7.077421622616904, 5.410291697297778, 8.998106513704572, 1.047241285443306, 10.58249989577702, 56.84940004348755, 47.68632418768746, 52.99987915584019, 50.02869394847325, 53.57527337755476, 54.101519516536165, 58.08877454485212, 60.28712204524449, 59.26663316999163, 53.93151099341256, 55.599349634987966, 54.84977797099522, 53.86800793239048, 51.72230345862252, 55.40639468601772, 49.71311024257115, 51.101954392024446, 49.957047598702566, 52.03725140435355, 51.87410075323922, 54.67173038210188, 49.12212078911917, 60.232745443071636, 55.36998265130179, 45.44014181409563, 48.907973834446494, 50.438818318503245, 53.856484345027376, 54.62570551463536, 48.75467225483486, 46.2663243157523, 44.39184972218105, 46.85897091456822, 40.173785958971294, 39.403255053928916, 40.24576234817505, 45.66995348249163, 40.16974558149065, 36.13172354016985, 38.337950297764365, 35.96423026493618, 38.045083727155415, 36.37896129063198, 38.36465917314802, 39.2690749168396, 41.77653040204729, 46.42659146445138, 44.959177085331504, 43.46795470373971, 47.12048026493618, 48.96938896179199, 48.17555379867554, 48.38098771231515, 46.48389325823103, 48.00427375520979, 48.94388907296317, 48.93859107153756, 50.650342328207834, 50.823824950626914, 51.27869571958269, 48.20230783735003, 44.9127596446446, 42.719453062329976, 45.394575527736116, 43.7361273765564, 39.3081168447222, 44.458250182015554, 51.005416120801655, 48.76721722739083, 49.610377652304514, 47.829363277980256, 47.97060625893729, 50.57062911987305, 46.02408579417637, 46.510025433131624, 47.57826232910156, 49.07048525129046, 44.47946998051235, 45.38365990774972, 47.31410918916975, 43.91477598462786, 40.79384667532784, 37.3629651750837, 37.367540563855854, 38.110271726335796, 38.841701643807546, 37.557542528424946, 36.232604435511995, 38.01991735185896, 36.450843879154746, 40.36855091367449, 43.52780301230294, 39.66332612718855, 41.28879812785557, 43.516473974500386, 43.41827508381435, 45.005622318812776, 51.12344517026629, 48.57582562310355, 51.63837964194161, 51.82493530000959, 56.54167822429112, 47.46693481717791, 43.415301254817415, 36.995454107012065, 47.02964299065726, 51.23201077325003, 47.51732662745884, 42.986791951315745, 46.29047277995518, 55.95514604023525, 55.24522079740252, 58.86276912689209, 55.48897750037057, 55.69320937565395, 55.51914657865252, 52.94582911900112, 55.33162859507969, 55.78695099694388, 56.47542020252773, 58.63117871965681, 58.142869744982036, 65.89561067308698, 61.67830426352364, 62.10233197893415, 57.7747402872358, 62.32840551648821, 50.394672938755576, 58.046595505305696, 7.675978098596845, 0.3357671642942088, 1.6636318330253874, 1.5306299584252494, 0.6396996911082948, 42.27137068339756, 77.95692607334682, 70.39845330374581, 78.12777532849992, 70.84964847564697, 70.6339555467878, 55.14788000924246, 57.03006362915039, 53.00817877905709, 58.83738735743931, 87.50466809953961, 19.879683801106044, 1.1490424914019448, 0.2707922251096794, 0.2329788798732417, 0.14371237345039845], [0.08825992686407906, 0.024840269670156494, 0.015082968332405602, 0.10113050123410565, 0.07977375401450054, 0.08375489538801567, 0.18317803288144724, 45.30114310128348, 61.77882385253906, 40.78732579095023, 34.289106437138145, 20.403829847063335, 12.518916811261859, 44.54845864432198, 49.244537625994, 64.06915160587856, 53.132266657693044, 61.9260561806815, 36.14393499919346, 0.11260782607964107, 0.27572900163275854, 2.273927616221564, 1.7927909195423126, 0.4970275525535856, 0.08143484166690282, 11.374422567231314, 61.0745335987636, 52.43797486168997, 52.31268147059849, 48.952772344861714, 57.33520071847098, 54.94085495812552, 57.07573413848877, 54.29920271464756, 54.01969405582973, 52.691500731876914, 52.843360560280935, 52.7275584084647, 50.16089037486485, 48.24319103785923, 47.35359927586147, 48.685329232897075, 49.809339318956646, 52.17607641220093, 49.777266434260774, 51.19880533218384, 44.78830698558262, 56.904089314596995, 48.45846707480294, 39.641328130449565, 48.82685708999634, 49.23866292408535, 51.143570627485005, 47.44832059315273, 46.81333862032209, 41.854009764535085, 38.17073147637503, 38.844401018960134, 41.590106759752544, 37.562291622161865, 36.91162061691284, 39.91857862472534, 39.08293267658779, 34.07313905443464, 34.96169206074306, 33.727132661002024, 34.609331539699006, 35.10485969270979, 34.01824828556606, 32.60431071690151, 35.22070353371756, 36.82156501497541, 41.80017859595162, 42.70087357929775, 41.73506007875715, 41.76377350943429, 42.93257168361119, 43.69356618608747, 40.61907516207014, 43.142997877938406, 43.72883524213518, 42.87874051502773, 43.98059974397932, 43.36997120720999, 47.06674289703369, 43.80065877096993, 45.588631766183035, 36.5338887487139, 37.411838803972515, 40.326295443943565, 37.6259058543614, 35.41140031814575, 42.77632406779698, 44.281866686684744, 45.74804776055472, 45.15712431498936, 44.1274151802063, 43.17263541902815, 42.413951192583355, 42.605290685381206, 41.409259046827046, 41.78800882611956, 44.77184670312064, 40.21495403562273, 42.70746741976057, 40.12724345070975, 41.892169271196636, 36.9500788961138, 34.18028722490583, 33.051246643066406, 35.610407148088726, 33.96073457172939, 35.17883368900844, 34.588184697287424, 33.659346035548616, 35.15898963383266, 35.61063643864223, 37.863787855420796, 38.38208872931344, 34.80263042449951, 40.398174558367046, 40.15452555247715, 39.3401688848223, 42.310707909720286, 44.23836748940604, 45.108987195151194, 46.976534434727256, 46.647280148097444, 52.66063683373587, 46.266682147979736, 40.80245896748134, 31.2210077558245, 41.965316431862966, 52.96361998149327, 37.182016713278635, 47.22369228090559, 51.115517275674, 51.767063753945486, 50.953679834093364, 51.57608209337507, 51.82818358285086, 55.52506991795131, 54.474120140075684, 49.240900244031636, 50.98077086039952, 53.30770867211478, 48.74699796949114, 49.156587328229634, 51.903380462101524, 52.56020062310355, 48.83571604319981, 62.870865276881624, 50.58077348981585, 48.64403261457171, 50.66098696844918, 1.2637479134968348, 0.17079609871975013, 0.736302558864866, 0.16978377875472817, 0.7144633393202509, 43.90869631086077, 61.332770347595215, 58.930791991097585, 64.96763706207275, 59.86045401436942, 60.94961888449532, 33.82615838732038, 18.497110400881084, 28.95041114943368, 46.68386241367885, 64.91046033586774, 7.044553603444781, 0.6516809367707798, 0.09605804484869752, 0.12361450546554156, 0.05633140388610108, 0.08701168705842324, 0.019555908494762013, 0.15867179073393345, 0.07390456859554563, 0.03755461983382702, 0.05173982526840908, 0.18369021825492382, 56.25203561782837, 70.42611408233643, 42.52707133974348, 25.613354648862565, 17.6891564982278, 17.395089626312256, 50.703628063201904, 53.30302906036377, 67.94307804107666, 60.280903407505576, 65.38734994615827, 40.811773027692524, 0.08065810906035559, 0.16901396720537118, 1.9276222331183297, 3.2433522258486067, 0.5961662413818496, 0.0900115989414709, 13.623373797961644, 64.29448168618339, 51.92779990604946, 54.45664542061942, 48.539622034345356, 57.11934103284563, 56.8504353250776, 58.219160965510774, 55.30946036747524, 56.45349516187395, 55.90180819375174, 55.93132414136614, 54.017415046691895, 53.13997220993042, 49.57434776851109, 49.71327352523804, 51.452310357775005, 52.84883574077061, 51.61219882965088, 51.679818698338096, 49.69649362564087, 47.096036502293174, 54.60673345838274, 50.56391716003418, 43.24272189821516, 49.47270604542324, 51.58966929571969, 53.66264350073678, 50.36611236844744, 46.768251759665354, 45.800586564200266, 40.0229093006679, 42.298117773873464, 41.63443974086216, 38.341518197740825, 37.609264918736045, 42.5354334967477, 40.52148423876081, 37.072554792676655, 37.16049814224243, 35.006678172520225, 35.874393531254356, 35.59384264264788, 35.68418312072754, 35.65913486480713, 36.19013704572405, 38.556464195251465, 43.22377416065761, 45.58548423222133, 44.083599839891704, 41.923915590558735, 45.994781766619, 44.213840348379954, 41.91760662623814, 45.502897943769185, 45.345208576747346, 45.14767129080636, 48.85985408510481, 46.78445495877947, 47.551296370370046, 45.84905024937221, 46.64917353221348, 39.38273007529122, 40.379292828696116, 41.719225134168354, 39.184800216129844, 37.97729015350342, 44.13024309703282, 44.66364240646362, 46.875167165483745, 46.497619424547466, 46.010067803519114, 45.73957095827375, 42.685066427503315, 44.75920098168509, 44.777651923043386, 45.168317862919395, 45.61496891294207, 42.199898038591655, 43.48375143323626, 42.97693245751517, 42.79779747554234, 37.48714338030134, 35.34138332094465, 36.30083227157593, 35.83252716064453, 35.56668560845511, 37.001686641148154, 35.02685921532767, 35.56436143602644, 35.75571829932076, 35.806725025177, 39.69882794788906, 38.53893389020647, 36.67948130198887, 41.02116046633039, 42.63529300689697, 40.892969676426475, 46.00619418280465, 45.97754676001412, 48.086550848824636, 48.72517367771694, 49.31776121684483, 55.558445589882986, 48.37003040313721, 41.46044989994594, 34.175520760672434, 48.83345093045916, 54.86715888977051, 40.473420075007844, 47.636842591421946, 51.888101373400005, 54.303500175476074, 52.2725556237357, 53.5662511416844, 54.077503068106516, 57.54784338814871, 55.37957116535732, 49.98618834359305, 51.52223355429513, 55.482571261269705, 51.08257586615426, 53.13742569514683, 54.25965356826782, 56.261627605983186, 52.48967293330601, 64.61045101710728, 52.72178792953491, 52.59430585588728, 53.14179958615984, 1.4759217969008853, 0.063322977828128, 2.2611735463142395, 0.6602233669587544, 0.9661955428974969, 48.56204734529768, 69.07657936641148, 64.01644257136753, 71.15828745705741, 64.11382852281842, 67.71057741982597, 44.24171999522618, 27.716890505381993, 37.09238147735596, 52.40026698793684, 76.67410796029228, 10.43072257723127, 0.852564160312925, 0.19839188722627504, 0.12389425188302994, 0.016737538655953746, 0.18607180831687792, 0.22212686575949192, 0.24372451326676778, 0.20371073324765476, 0.13935539153005394, 0.2598639029477324, 0.2817322994981493, 63.81058829171317, 79.15760258265904, 51.88993569782802, 46.53919744491577, 28.766269990376063, 22.702351263591222, 60.45069653647286, 58.66091700962612, 72.77354213169643, 63.68539564950125, 71.61531911577497, 44.63897977556501, 0.20950728149286338, 0.8476129717060498, 8.601105553763253, 6.381707617214747, 4.457089177199772, 0.3488456553646496, 18.39920333453587, 64.68041937691825, 52.84227316720145, 55.689884662628174, 51.55820437840053, 59.567045484270366, 57.22139269965035, 60.74876035962786, 57.45269823074341, 57.72813177108765, 56.69676201684134, 57.6583753313337, 55.68954072679792, 53.39211886269705, 51.69977045059204, 52.01536110469273, 52.71574647086007, 54.9243460382734, 55.03147336414882, 52.215896538325715, 53.885993344443186, 47.12582342965262, 57.84580646242414, 56.38023683003017, 42.91723353522164, 51.81588874544416, 54.62703956876482, 56.438834462847026, 51.752569811684744, 49.010921818869456, 47.37556600570679, 40.50359262738909, 44.49250480106899, 45.06337227140154, 40.503887925829204, 40.64501278741019, 42.913182735443115, 41.69919695172991, 38.32838610240391, 38.16784449986049, 37.97229092461722, 37.18873562131609, 39.50419500895909, 37.833917549678254, 37.02396603993007, 38.920654024396626, 40.881567682538716, 46.346454416002544, 49.068133286067415, 46.453963892800466, 44.46174512590681, 48.51716545649937, 47.873192514692036, 43.322733879089355, 48.84189993994576, 49.56287281853812, 46.72538137435913, 52.090151514325825, 48.81640005111694, 50.8919346673148, 48.198104177202495, 49.365780217306956, 41.485386984688894, 43.08316693987165, 47.01834521974836, 45.42111069815499, 41.03879846845354, 47.485059193202424, 47.760308606284006, 49.41058567592076, 51.344828673771445, 50.90821429661342, 48.76866940089634, 46.013086795806885, 48.656455993652344, 45.93988404955183, 45.3037417275565, 49.76611804962158, 44.30062334878104, 46.0494258744376, 45.063650199345176, 45.31369154793875, 41.45334536688668, 37.685695103236604, 37.00137397221157, 38.48476920809065, 37.27060277121407, 39.07559537887573, 38.038764340536936, 37.44583633967808, 37.46456173488072, 38.77647890363421, 42.10705968311855, 42.620277949741904, 38.42164134979248, 43.990302903311594, 44.02913291113717, 44.30667870385306, 47.26419333049229, 48.89438315800258, 49.021622044699534, 51.57308394568307, 50.737253870282856, 56.34828553880964, 48.45411055428641, 41.718839509146555, 35.82679837090628, 45.281212193625315, 52.74652351651873, 41.362924984523225, 49.58603811264038, 54.140050751822336, 55.02314247403826, 54.314502647944856, 56.12405674798148, 55.33973714283535, 60.15313993181501, 57.124437536512104, 52.45185041427612, 52.76581171580723, 55.72169698987688, 52.35237652914864, 55.20224271501814, 57.4542407308306, 57.03908586502075, 55.56255544934954, 61.489146505083355, 56.24752276284354, 54.74835164206368, 56.56379434040615, 2.2600366473197937, 0.20247427959527287, 3.4018102373395647, 2.0611351260117123, 1.33465210880552, 53.91575595310756, 71.6212876183646, 69.99028832571847, 76.36815793173653, 72.29378986358643, 74.00310230255127, 51.93570695604597, 29.908173424857004, 44.86501857212612, 59.80575084686279, 90.09448405674526, 14.000378710883004, 1.066004244344575, 0.2996281177869865, 0.26333118975162506, 0.13990125938185624], [0.12233675617192473, 0.05847699607589415, 0.023505494597234895, 0.06880157813429832, 0.11786250982965742, 0.0583637621519821, 0.25867901795676773, 22.68167863573347, 65.49641581944057, 44.34332350322178, 46.733719212668284, 33.83116456440517, 36.46231188092913, 40.6898147719247, 50.24047156742641, 60.58069733210972, 55.43489967073713, 56.67297485896519, 47.338167326790945, 0.642928812120642, 0.2517317421734333, 0.42087844439915245, 2.215918626104082, 1.0502548494509287, 0.03848128153809479, 19.862297671181814, 67.49414798191616, 52.98428392410278, 53.58854791096279, 56.53983347756522, 58.79254368373326, 54.01911735534668, 53.740505014147075, 52.59929813657488, 55.26698950358799, 51.28510890688215, 50.16520868028913, 46.544019494737896, 49.283715043749126, 47.70522328785488, 51.30909756251744, 49.181507042476106, 49.745985644204275, 47.08741726194109, 46.736738204956055, 44.0758421761649, 46.34967838014875, 28.630399703979492, 31.674693856920513, 50.44040945598057, 49.542403425489155, 49.50814880643572, 49.06064312798636, 48.39040946960449, 43.55763510295323, 40.72588981900896, 40.789663859776084, 40.79854713167463, 41.50230584825788, 36.53933613640921, 37.677996499197825, 37.91248777934483, 36.81161172049386, 33.801429748535156, 31.701937743595668, 33.587400913238525, 34.794723374503, 32.471527167728965, 32.6905517578125, 33.65338100705828, 33.278949533190044, 33.36341878346035, 37.866313525608604, 43.33116899217878, 42.32904420580183, 42.74566861561367, 43.962253025599885, 42.817415714263916, 43.14119482040405, 43.361272062574116, 41.998904023851665, 43.34324843542916, 44.715045179639546, 44.10623707090105, 44.84433031082153, 45.870506286621094, 46.40802240371704, 38.61775425502232, 38.571444511413574, 39.78638914653233, 34.47205598013741, 35.46467215674264, 42.26191071101597, 46.063020024980815, 43.97803585869925, 44.19282899584089, 44.243245124816895, 42.79219027927944, 40.748763288770405, 41.631097657339915, 39.95131853648594, 42.08782359531948, 43.28189584187099, 41.63808754512242, 39.98254721505301, 40.267298289707725, 41.37036303111485, 36.80081769398281, 34.194704736982075, 34.17843900408064, 34.1555620602199, 32.86096675055367, 35.00678934369768, 35.319965498788015, 35.50260584694998, 33.80821813855852, 36.155239718300955, 35.75619077682495, 39.61811072485787, 35.18117870603289, 36.58145611626761, 42.91811943054199, 38.237097195216585, 38.661614758627756, 42.7003698348999, 44.973115171704976, 45.09099136080061, 47.506404059273855, 49.13445036751883, 52.78900480270386, 48.02212715148926, 43.18829665865217, 32.24194826398577, 54.20234135219029, 39.70261819022042, 47.63097136361258, 50.48885577065604, 51.796235765729634, 51.81906754629952, 50.618530000959126, 53.18276616505214, 57.15831000464303, 49.958864552634104, 46.58523620877947, 51.888024943215505, 51.22967617852347, 50.456619603293284, 51.62436512538365, 53.65383665902274, 52.633191449301584, 54.48852375575474, 50.70991965702602, 40.12563841683524, 57.77265930175781, 32.88568844114031, 0.2538290667746748, 0.14082722898040498, 1.604965369616236, 0.8340017220803669, 1.594437437398093, 49.772972447531565, 61.98152365003313, 60.33604431152344, 60.25423622131348, 67.26542023250035, 54.32599149431501, 41.95689174107143, 37.726453236171174, 32.74302455357143, 53.906622546059744, 63.66546821594238, 4.311241277626582, 0.31650830485991066, 0.11507066392472812, 0.10989728902599641, 0.09759139828383923, 0.135124359279871, 0.07286393336419549, 0.02972330113074609, 0.09204465949109622, 0.03776875530768718, 0.08416435734501906, 0.1419052311352321, 30.4241292817252, 74.44149194444928, 47.8370167187282, 44.836002894810264, 23.395201308386667, 37.36141225269863, 48.61303322655814, 54.869806153433665, 65.28831727164132, 61.07124710083008, 62.04266084943499, 50.20009905951363, 0.7938251750809806, 0.3860696793666908, 0.3004784850137574, 2.9931354352406094, 0.6219093171613557, 0.06460247095674276, 24.092569419315883, 69.84517519814628, 55.1544634274074, 56.2772992679051, 56.90947069440569, 61.40346826825823, 56.42138058798653, 55.85591881615775, 53.87262501035418, 57.11402913502285, 53.67649820872715, 52.703277928488596, 49.55006728853498, 50.255712441035676, 49.384814807346885, 53.413592270442415, 50.22848245075771, 51.29442296709333, 49.83199739456177, 49.58149399076189, 45.69522755486624, 46.77929939542498, 31.538644654410227, 34.05000850132534, 50.8867860521589, 50.95256812231881, 51.06070293698992, 49.21996879577637, 49.615557534354075, 47.511205264500205, 42.200936794281006, 41.67154312133789, 41.94213376726423, 44.0906765801566, 38.113693714141846, 39.16271536690848, 40.251751695360454, 36.873402050563264, 36.97203867776053, 34.16504635129656, 34.127772739955354, 34.594240052359446, 35.448910168239046, 33.08215570449829, 34.678737095424104, 35.87486253465925, 35.45634821483067, 40.06824629647391, 44.45508527755737, 44.80114378247942, 44.127918924604145, 44.434282370976035, 45.034999302455354, 44.267525604793, 45.79994732992989, 43.848212242126465, 47.55268948418753, 45.13344138009207, 46.442711285182405, 46.39280237470354, 47.762108189719065, 47.710597719464985, 40.93132025854928, 40.99782494136265, 42.14493431363787, 37.90426458631243, 38.818967138017925, 43.373059681483674, 45.94144739423479, 45.87160757609776, 46.59224694115775, 45.83598416192191, 45.4493898664202, 43.228439876011436, 43.435075828007285, 42.73370034354073, 45.27814456394741, 43.849515029362266, 42.909597464970176, 41.523008005959646, 42.9965055329459, 42.15653780528477, 38.10410520008632, 34.99435901641846, 35.40402133124215, 35.73403297151838, 36.01829072407314, 36.369807038988384, 36.00237240110125, 36.67732736042568, 36.710525853293284, 37.792707783835276, 37.264603001730784, 39.201600960322786, 38.27637536185128, 38.812279496874126, 43.40407296589443, 40.5307149205889, 41.0901004927499, 43.96104056494576, 48.52416576657976, 49.85701090948922, 50.70137684685843, 52.45605060032436, 53.60018266950335, 48.74212033408028, 44.78688955307007, 36.36851814814976, 54.6363571030753, 41.63628101348877, 49.65318897792271, 53.59003829956055, 53.346656799316406, 54.841766698019846, 53.90341942650931, 54.746228967394146, 57.798120975494385, 54.117830412728445, 49.65783384868077, 50.48893567493984, 52.0467391695295, 52.314383779253276, 55.10388401576451, 54.77199983596802, 56.963805607386995, 54.556956563677105, 51.99429416656494, 41.39832605634417, 62.696972710745676, 36.98631375176566, 0.12030268460512161, 0.17820119565086706, 2.7073862084320615, 0.5301052119050707, 2.410716150488172, 53.52501705714634, 66.28347301483154, 66.32073620387486, 64.62028966631208, 71.57403986794608, 62.6521429334368, 52.07284007753645, 36.41780866895403, 36.59581804275513, 59.51309272221157, 73.77889783041817, 7.030955978802272, 0.5600143841334752, 0.18135923333466053, 0.13531286987875188, 0.03777069252516542, 0.41156397706695963, 0.15321988399539674, 0.15691557925726685, 0.18256162452910626, 0.14934631756373815, 0.25230724843485014, 0.25667340414864676, 35.62942089353289, 84.8724125453404, 57.817749636513845, 61.7112387248448, 47.782483782087056, 52.056793212890625, 56.00257791791643, 62.66337122235979, 68.79417678288051, 65.70754378182548, 67.58899784088135, 56.81445755277361, 1.1933300920895167, 1.3394322523048945, 2.5275049465043202, 9.372590099062238, 2.593744946377618, 0.15288445699427808, 28.384999752044678, 69.82942363194057, 55.268886361803325, 57.73805727277483, 58.838582447596956, 65.20067964281354, 59.25534929547991, 57.29435225895473, 56.55331993103027, 59.11509990692139, 56.134774344308035, 55.552220003945486, 52.024848869868684, 53.165232385907856, 51.63667038508824, 55.58478273664202, 52.118826729910715, 52.86367014476231, 51.33149855477469, 53.079074723379954, 50.31247227532523, 49.45563779558454, 36.71692167009626, 37.79229089191982, 50.32893255778721, 53.99478128978184, 52.73026820591518, 54.302086217062815, 53.53690889903477, 49.62649747303554, 45.23986693790981, 44.910685607365195, 44.31431824820382, 47.13624225343977, 39.735021114349365, 41.47696924209595, 41.30235753740583, 40.2723913192749, 37.63479954855782, 37.262487275259836, 37.27680056435721, 38.64615849086216, 36.26048755645752, 36.318143708365305, 36.41548797062465, 37.73919970648629, 36.69666767120361, 41.98744644437517, 47.4751614843096, 48.23225804737636, 47.06520734514509, 47.68754359654018, 47.99299682889666, 46.36626025608608, 48.656490734645296, 45.654445103236604, 47.835116386413574, 48.771775245666504, 49.08345058986119, 50.66267190660749, 49.82224212374006, 50.30386693137032, 45.85337550299508, 43.05386291231428, 47.11694015775408, 41.50542211532593, 40.13337871006557, 45.72261387961251, 49.41986152103969, 48.074193477630615, 49.87935631615775, 49.92733015332903, 48.075815882001606, 45.701960359300884, 46.29682690756661, 43.72415215628487, 46.840651988983154, 47.4599484034947, 46.02356815338135, 44.4496865272522, 45.34305810928345, 46.36568008150373, 40.85045712334769, 36.09113563810076, 37.30129296439034, 37.48342261995588, 37.16278062547956, 38.08562994003296, 38.400438921792166, 38.1963529586792, 37.1535256249564, 40.70890147345406, 39.88728046417236, 41.88417189461844, 39.629571778433665, 40.7429962839399, 47.1110828263419, 41.91643932887486, 44.09301812308175, 47.497965472085134, 51.25389412471226, 50.72460120064871, 53.20082800728934, 53.288205078669954, 59.07484899248396, 50.84124755859375, 46.959282057625906, 36.9917437689645, 50.56138801574707, 41.56597219194685, 50.52345779963902, 56.11494765962873, 56.03431034088135, 56.51554604939052, 55.18224579947335, 56.9798698425293, 60.03333909170968, 56.094651971544536, 52.31987633023943, 51.84835767745972, 54.66510874884469, 52.35335275105068, 56.20047303608486, 54.77249663216727, 57.497510637555806, 53.722265992845806, 52.44629532950265, 45.95047310420445, 62.566020011901855, 41.35556336811611, 0.37092054369194166, 0.24346069885151728, 6.689024269580841, 2.799003852265222, 2.8376223742961884, 61.11321422031948, 71.06917681012834, 72.2373149054391, 71.26108605521065, 78.83544935498918, 67.16176005772182, 56.7137816292899, 52.034496443612234, 49.88240310123989, 67.7058665411813, 85.77674838474819, 9.807781832558767, 0.8111386203340122, 0.3186381177178451, 0.3334518128207752, 0.16461996441440924], [0.07810442216162171, 0.01745792062553976, 0.061707508085029464, 0.11348863238734858, 0.13215195520647935, 0.15644401099000657, 0.5104116829378265, 10.856483868190221, 66.76608794076103, 42.07121740068708, 31.6860020501273, 28.459967340741837, 31.857094492231095, 39.38382094247, 47.02626616614205, 60.6822452545166, 58.90982232775007, 55.55070877075195, 53.00267233167376, 3.653479201453073, 0.08339361620268651, 0.9791236434664045, 3.987574211188725, 0.41450322791934013, 0.027399267801748853, 29.48927695410592, 64.29482214791435, 46.764892305646626, 55.17246968405587, 55.873598507472444, 56.25077451978411, 53.77520431791033, 53.864193371364046, 51.807161808013916, 50.69698558534895, 50.014474460056846, 50.46241787501744, 48.217475754874094, 49.35410376957485, 46.75655446733747, 47.69801453181675, 45.122518811907085, 46.642454624176025, 45.37682982853481, 46.98724160875593, 45.98245913641793, 43.20174489702497, 33.68951163973127, 45.362186500004356, 50.67684623173305, 46.75672469820295, 49.17279052734375, 49.105035168784006, 43.70021908623831, 41.90430430003575, 40.16743877955845, 38.803729738507954, 42.11287879943848, 39.909413950783865, 36.83782727377755, 38.16404036113194, 38.44041885648455, 35.612189361027305, 37.12086909157889, 39.445309025900706, 34.84302030290876, 33.199406555720735, 32.502081871032715, 33.97899096352713, 32.4676570211138, 34.76823336737496, 33.90044852665493, 35.42739854540144, 41.424006598336355, 42.224362645830425, 42.26921674183437, 41.208452633449006, 41.08867263793945, 42.442188671657014, 41.19266285215105, 43.52319288253784, 41.36936943871634, 43.362745080675396, 45.35150017057146, 44.69519417626517, 45.35365063803536, 45.94465398788452, 38.14402954918997, 37.50023378644671, 39.33568034853254, 35.64965404782976, 36.504685470036094, 43.219417640141074, 46.60969386781965, 45.94231244495937, 42.747843401772634, 44.296899114336284, 45.311575821467805, 43.04742540631975, 41.65064293997628, 41.14543942042759, 41.8280200277056, 41.83561093466622, 43.911590235573904, 42.813357966286794, 41.588838713509695, 39.93215193067278, 35.85741213389805, 34.87331444876534, 35.132013252803254, 36.13252605710711, 34.17658036095755, 33.294061865125386, 34.399231910705566, 34.98941189902169, 35.605665002550396, 34.00506060464041, 37.46584367752075, 37.19666351590838, 37.83121122632708, 37.44434247698103, 43.47643150602068, 41.63283123288836, 40.10920245306832, 39.96086883544922, 42.28773716517857, 42.11175666536604, 45.42254202706473, 46.039903368268696, 51.65744897297451, 49.29813950402396, 50.16526426587786, 34.7645925113133, 42.26344278880528, 48.77105958121163, 44.63534934180123, 52.283950669424875, 50.2208012172154, 49.58670513970511, 50.93175131934029, 50.029565947396414, 52.80198056357247, 53.22994095938546, 52.22552326747349, 51.718210969652446, 51.86417872565133, 53.06541109085083, 60.04308046613421, 57.918970993586946, 57.49207019805908, 51.874552386147634, 46.956332547324045, 45.74131843021938, 58.34704603467669, 19.499926533017838, 0.013629574312030204, 0.08472294094307081, 1.5807744562625885, 0.16792171581515244, 1.9426444556031908, 58.23241465432303, 62.10116468157087, 65.51990073067802, 60.00342014857701, 67.33462429046631, 43.07675722667149, 58.11510474341256, 34.88438292912075, 37.97789812088013, 57.42623601640974, 61.69237436567034, 3.2371285940919603, 0.41510484420827454, 0.1796848260398422, 0.2157749773136207, 0.047657493967562914, 0.060190771972494464, 0.018544014310464263, 0.11863314919173717, 0.14425821416079998, 0.11326601183308022, 0.24445795533912523, 0.38914675425205913, 16.236383710588726, 77.77719702039445, 49.39631755011422, 39.94126101902553, 30.558583872658865, 41.23513371603829, 47.358386584690635, 52.20817014149257, 66.01047134399414, 63.64271286555699, 60.465801920209614, 57.31129196711949, 3.8592179673058644, 0.18309654082570756, 0.7519914284348488, 2.894841875348772, 0.49357478639909197, 0.04663530810336981, 31.940799440656388, 65.92293098994664, 49.2666711126055, 57.735934598105295, 58.97296755654471, 57.99658237184797, 54.93222182137625, 56.06905828203474, 53.78301756722586, 53.42616156169346, 51.30514056341988, 52.33405760356358, 49.70542206083025, 52.06601347242083, 48.65784215927124, 49.756018842969624, 47.58798633302961, 50.298357009887695, 49.45593656812395, 48.36461080823626, 46.38671227863857, 41.45792770385742, 34.17292560849871, 46.48909051077706, 52.9806604385376, 49.15244620186942, 50.56015818459647, 50.80460275922503, 46.51657063620431, 43.145440169743125, 42.65580061503819, 41.71622698647635, 45.23691742760794, 41.70943859645298, 37.508634158543174, 39.491469383239746, 40.67217329570225, 36.72794151306152, 38.75927863802229, 41.32898303440639, 36.68727718080793, 35.89052724838257, 34.75176613671439, 35.38094636372158, 33.90828262056623, 36.05806916100638, 36.482322692871094, 37.781764371054514, 44.03329488209316, 43.5102344921657, 42.92855215072632, 41.558447292872835, 42.58017642157418, 44.03053992135184, 43.15861048017229, 45.787180015019004, 43.56814077922276, 46.00880670547485, 47.01751143591744, 47.233798435756135, 48.19611699240548, 47.65990366254534, 40.89353595461164, 39.656676701136995, 40.88843597684588, 39.34371594020298, 39.59839868545532, 44.29102093832833, 47.0019439969744, 45.87289299283709, 45.49255207606724, 45.03217485972813, 47.69656235831124, 43.712440967559814, 44.71239096777779, 43.91094752720424, 44.30286066872733, 44.18443904604231, 45.4071170261928, 43.02799824305943, 42.60328613008772, 42.27968767711094, 37.227558680943076, 35.80965716498238, 35.67880174091884, 36.554768085479736, 36.34415428979056, 36.50342089789254, 35.48201486042568, 37.72005047116961, 37.550875731876914, 35.24219083786011, 37.745070934295654, 39.42744173322405, 39.06512444359915, 39.33719852992466, 45.49861090523856, 43.73395953859602, 42.771828583308626, 42.64186600276402, 43.60470914840698, 45.873233454568044, 48.021077973502024, 49.34075280598232, 51.57842016220093, 51.09917163848877, 51.19518879481724, 37.87136139188494, 45.01837226322719, 48.092800753457205, 47.50512211663382, 53.99909264700753, 53.01717669623238, 51.186659881046836, 52.28330796105521, 51.27446774074009, 54.57175970077515, 54.53488213675362, 54.254442419324604, 54.9440268107823, 55.5568961415972, 56.50205264772688, 63.097286224365234, 58.470536368233816, 58.7331782749721, 53.95050042016165, 49.191887651171, 49.36573852811541, 60.036312920706614, 22.137273379734584, 0.08492193490798984, 0.6210654910121645, 3.366967409849167, 0.22509210450308664, 3.1152812923703874, 62.374937602451865, 67.91282558441162, 70.09474059513637, 66.98895141056606, 73.06709657396588, 49.5376786504473, 57.15292167663574, 40.82102108001709, 46.576377255576, 62.382580620901926, 74.36545085906982, 5.143991998263767, 0.6248124156679425, 0.06877977001879897, 0.1484475436487368, 0.054059064747499566, 0.32789949647017885, 0.15642829611897469, 0.2180235337998186, 0.3432328136903899, 0.1987358909100294, 0.46854818931647707, 0.45848003242697033, 20.15647050312587, 89.68637466430664, 57.08759123938424, 46.25252171925136, 38.2904246194022, 45.88592781339373, 52.41624437059675, 58.85867663792202, 70.9517800467355, 69.03416756221226, 66.85393401554653, 63.68568747384207, 5.460731710706439, 0.3329312407544681, 2.0916366321699957, 8.917250326701573, 1.604717297213418, 0.12976032282624925, 36.494089467184885, 68.39800439562116, 53.70742811475481, 58.62651647840227, 60.940926688058035, 60.53001022338867, 57.76473140716553, 58.22465351649693, 56.47832454953875, 55.987889426095144, 52.93255805969238, 56.04676846095494, 51.77283075877598, 52.56563064030239, 50.07513918195452, 53.193424701690674, 49.27103458132063, 52.886373383658274, 51.4139597756522, 49.789658546447754, 48.42894070489066, 42.59273181642805, 34.710535526275635, 47.970408235277446, 57.03452784674508, 51.61447089059012, 53.328115531376426, 53.61240802492414, 47.44133070537022, 44.8719459261213, 45.07344715935843, 44.66720683234078, 46.68758317402431, 44.792861529758994, 38.912653173719136, 41.168382372174946, 42.31283058438982, 39.774955885750906, 40.17853505270821, 43.20866877692086, 38.68874747412545, 38.12057590484619, 37.44581202098301, 37.72012690135411, 35.95619814736502, 38.23800046103341, 37.856763226645334, 40.56463255201067, 45.0212071282523, 45.81702252796718, 46.30516127177647, 43.719097341809956, 44.17398200716291, 47.06320973805019, 45.92187431880406, 47.45456007548741, 44.47940744672503, 46.84010655539376, 48.01519979749407, 48.618775912693565, 49.95754439490182, 50.223160130637034, 42.75973176956177, 43.44479635783604, 46.89110633305141, 44.41214541026524, 41.044607162475586, 46.835225445883616, 51.5448499407087, 50.68038633891514, 48.08270502090454, 48.46751710346767, 51.181212493351524, 46.96391303198678, 46.476298877171104, 46.53910364423479, 46.60769626072475, 45.194411822727744, 47.79821450369698, 48.699246474674766, 44.78031655720302, 46.246699128832134, 39.63034650257656, 39.768893582480295, 37.577032225472585, 40.21609354019165, 37.80078159059797, 37.93650075367519, 39.0831550189427, 39.307091985430034, 39.1554023878915, 36.467616830553325, 40.02534811837332, 40.56862429210118, 42.03400979723249, 40.36689029421125, 47.91155351911272, 44.96423537390572, 44.794338021959575, 45.90892635072981, 46.13901594706944, 48.06289223262242, 49.397147859845845, 49.783099446977886, 55.94994878768921, 51.307631492614746, 53.96539388384138, 38.536613191877095, 44.480185644967214, 48.70153243201119, 47.940034185137065, 56.696334702628, 55.705038683755056, 53.85455274581909, 56.31051860536848, 54.744172300611226, 57.068448952266145, 57.41356250217983, 56.1847562108721, 57.249161175319124, 56.88104213987078, 59.170734133039204, 64.99109418051583, 61.01427187238421, 60.81968757084438, 56.61319603238787, 51.971194880349294, 51.142841066632954, 62.57053634098598, 25.86382852281843, 0.14999762975743838, 0.613587275147438, 6.729507948671069, 0.42982701850788935, 3.893054391656603, 68.580901827131, 71.63617760794503, 75.81740202222551, 72.44182818276542, 76.04785292489188, 54.399020535605295, 74.1053797858102, 46.234147208077566, 56.0351892880031, 70.61787046704973, 85.24783761160714, 7.813154646328517, 0.7223838514515332, 0.4277552611061505, 0.40903458850724356, 0.1738618692117078], [0.031053039777491773, 0.02585541912620621, 0.05440157904688801, 0.09713304787874222, 0.07197288796305656, 0.03036787886438625, 0.16264420614710876, 4.543603369167872, 59.30090168544224, 46.7489218711853, 41.051207951136995, 20.658432688031876, 28.547526802335465, 35.050292015075684, 55.04112788609096, 58.43491990225655, 64.39356994628906, 51.386257307870046, 60.5039336340768, 7.570507049560547, 0.21885758904474123, 0.39813370630145073, 0.9483237990311214, 0.35608426694359097, 0.11058535067630665, 34.19155372892107, 54.07400465011597, 45.59214755467006, 55.94389690671648, 54.64331224986485, 55.55961636134556, 54.20581545148577, 51.638803482055664, 52.19054256166731, 51.62395518166678, 52.991676807403564, 50.1647744178772, 49.05926043646676, 45.086151940482004, 46.38778230122158, 49.12692894254412, 47.442320823669434, 50.480219159807476, 49.278851304735454, 48.79246698107038, 46.20967217854091, 46.53003971917288, 43.51129756655012, 45.93031985419137, 50.495748383658274, 48.178392137799946, 45.994375297001426, 46.3787704876491, 43.720681531088694, 42.002548354012625, 41.246052810123985, 41.62827321461269, 40.96885442733765, 41.83446795599801, 38.378340176173616, 37.2705089705331, 39.27061741692679, 40.327702454158235, 43.72246721812657, 38.14106961659023, 32.20916666303362, 32.44128165926252, 31.854860646384104, 32.86578185217721, 32.39411728722708, 33.14902516773769, 34.349649565560476, 37.17906720297677, 38.241332122257774, 41.40955434526716, 40.326872144426616, 43.60951382773263, 41.10295813424246, 42.678760937282014, 43.66713176454817, 44.083318437848774, 40.818262645176475, 41.048171588352744, 45.133486543382915, 45.45750188827515, 44.49301201956612, 43.16570111683437, 38.63135882786342, 39.43377154214041, 37.1901078905378, 33.13516698564802, 39.14705065318516, 47.36094699587141, 46.69992317472185, 46.03067963463919, 43.74668516431536, 44.466396944863455, 44.42621898651123, 41.90875809533255, 42.18845435551235, 43.248996121542795, 41.69555262156895, 42.21377011707851, 40.97740418570382, 39.25914246695382, 41.07616588047573, 37.55615288870675, 35.22550473894392, 34.806260858263286, 33.64321231842041, 34.065131255558555, 32.99904482705252, 35.92094646181379, 34.26012202671596, 34.32079717091152, 40.04771089553833, 39.235428265162874, 36.40341547557286, 39.7339962550572, 35.73530796595982, 37.256233896527974, 42.246888705662315, 43.365566049303325, 39.5873441014971, 39.489478724343435, 39.885473932538716, 38.13880797794887, 40.57970666885376, 42.86168616158621, 47.216031891959055, 50.06621422086443, 50.906508513859336, 47.97487245287214, 32.966318811689106, 47.900769914899556, 51.91301761354719, 46.88889333180019, 53.299895422799246, 50.70790467943464, 51.5342469896589, 49.19989545004708, 53.05848026275635, 50.401232038225444, 52.71838331222534, 53.6390300478254, 57.835894857134136, 54.1988707269941, 57.11430706296648, 54.13658707482474, 58.13055753707886, 53.13164826801845, 59.72237246377127, 47.50258949824742, 58.56952040536063, 9.603806172098432, 0.39709714906556265, 0.05350731060441051, 2.128516367503575, 0.10985385599945273, 2.7198556193283627, 63.30534308297293, 59.74025017874581, 65.29781545911516, 57.369670731680735, 69.16672529493059, 43.73170484815325, 55.265620708465576, 30.20456968035017, 32.26903581619263, 57.954705578940256, 49.85382168633597, 0.6421019222055162, 0.08131176898522036, 0.016631415779037134, 0.03796175780839153, 0.027573960034974983, 0.04281479971749442, 0.04618687109489526, 0.09094847259776932, 0.027154694943289672, 0.05196608955572758, 0.0711140458339027, 0.13132822726454052, 6.901539700371878, 72.10457651955741, 52.3684720311846, 45.625617027282715, 25.201891013554164, 36.73505646841866, 40.13140194756644, 60.222746985299246, 62.81646088191441, 67.44883183070591, 55.592085293361116, 64.53076907566616, 7.545462267739432, 0.24571929765599115, 0.3068310112825462, 3.693700586046491, 0.1328608478818621, 0.14743411088628428, 36.67693478720528, 56.879530906677246, 49.58252232415335, 59.2107001713344, 56.57734332765852, 57.440809862954275, 54.3199257169451, 52.792183603559224, 53.07238360813686, 53.79064668927874, 55.10283831187657, 50.438800948006765, 50.73776456287929, 47.28707374845232, 48.851387705121724, 50.57921361923218, 49.718905040196006, 50.45469495228359, 48.486659390585764, 47.840723582676475, 46.409123693193706, 46.56407894407, 44.335267066955566, 47.11918789999825, 52.270759514399934, 50.61522265842983, 50.06519978387015, 49.029358863830566, 45.929555552346365, 42.43052959442139, 43.4156243460519, 43.17469555991036, 43.92862374441964, 43.82129144668579, 40.018893241882324, 39.50101620810372, 41.120071547372, 42.06957067762102, 46.19811037608555, 40.10472433907645, 33.26088421685355, 33.52168485096523, 34.81359815597534, 32.86042479106358, 34.46099444798061, 33.46519947052002, 34.95573050635201, 38.645748547145296, 41.65456519808088, 43.776489462171284, 42.99186066218785, 43.331488609313965, 44.243116583142964, 44.075352328164236, 44.77504634857178, 47.35238334110805, 42.349398953574045, 44.13592324938093, 47.47977161407471, 47.26350198473249, 46.766056128910606, 45.085293837956016, 42.043521881103516, 41.51179361343384, 40.10565192358834, 35.68329722540719, 42.112482752118794, 48.42186743872506, 48.09186969484602, 47.01802907671247, 46.42525046212332, 45.62137515204293, 46.32822234289986, 42.44829266411917, 42.906140736171174, 44.301040240696494, 43.62776674543108, 44.77901029586792, 43.01553317478725, 41.95050982066563, 43.14744125093733, 40.04970155443464, 37.79886041368757, 35.88947459629604, 34.25536598478045, 35.865972314562114, 34.342753478458945, 35.49072790145874, 34.98088298525129, 35.572463035583496, 42.26778541292463, 39.740207944597515, 38.15486873899187, 41.9180200440543, 38.68460634776524, 39.88266338620867, 44.596877166203086, 45.94385494504656, 42.03740746634347, 41.48973308290754, 41.27169166292463, 40.86756011417934, 43.818515641348704, 45.23766783305577, 48.62888554164341, 51.49067831039429, 54.374493394579204, 48.054109709603445, 37.00091191700527, 47.71209505626133, 49.98723752158028, 51.089461530957905, 53.2941631589617, 52.14736645562308, 53.841458865574424, 51.11023664474487, 55.0746077810015, 52.660518714359824, 54.48387541089739, 54.95549133845738, 59.54132325308663, 56.950815950121196, 58.22831521715437, 57.597366673605784, 60.36933313097273, 55.344555718558176, 61.97320665631975, 50.042163031441824, 63.721825054713655, 10.2641647032329, 0.3650011398962566, 1.8546016599450792, 4.222577486719404, 0.2030123985771622, 3.473874564681734, 69.2542587007795, 64.29338387080601, 73.01194872174943, 61.36336326599121, 77.894684110369, 47.36665841511318, 60.34907218388149, 26.201163564409526, 36.38904660088675, 64.9576872416905, 60.77834578922817, 1.6475401307855333, 0.08661369234323502, 0.027638583710151057, 0.10735893701868397, 0.038109088116990666, 0.14940127890024865, 0.21500965766608715, 0.1717725648943867, 0.20024407069597924, 0.10911559632846288, 0.2215867925967489, 0.2370697132178715, 7.8596528598240445, 83.81434086390904, 58.3284387588501, 57.886529854365754, 30.165687561035156, 46.12931973593575, 48.04781811577933, 67.13481494358608, 68.94611304146903, 75.47939995356968, 61.91749600001744, 72.540680204119, 10.160884942327227, 0.3962669207581452, 1.0016857470784868, 4.754499001162393, 0.8249620614307267, 0.23794581049254962, 40.07102905000959, 61.57359491075788, 53.09295722416469, 60.45400387900216, 58.91143430982317, 60.54349667685372, 57.234542165483745, 54.95183311189924, 54.91104718617031, 56.19276053564889, 57.46548639025007, 52.927628312792095, 54.0957281930106, 50.77553844451904, 52.867526394980295, 52.300706250326975, 51.78287785393851, 50.47163118634905, 47.80284200395857, 48.621298108782085, 47.14704670224871, 47.92184032712664, 45.1437212399074, 48.28213916506086, 54.048817430223735, 51.96703290939331, 50.860709462847026, 50.17381749834333, 48.34080975396292, 46.07595409665789, 44.9501166343689, 45.27681050981794, 45.09779017312186, 45.18849890572684, 42.7939829145159, 42.17530836377825, 42.948521273476736, 44.0081285067967, 47.71607984815325, 41.85016393661499, 35.94478225708008, 35.342929295131135, 36.88639865602766, 35.16512836728777, 35.76544925144741, 37.77495166233608, 37.940277099609375, 42.16655363355364, 42.26081984383719, 47.269592080797466, 45.08407095500401, 48.110209465026855, 45.687410831451416, 46.15412827900478, 44.90044396264212, 49.854203837258474, 44.94868183135986, 44.17570168631417, 49.77788482393537, 49.21493135179792, 48.46499490737915, 47.76531130926949, 45.65438951764788, 44.96211617333548, 45.51730503354754, 40.151704583849224, 43.67113740103585, 50.3456186567034, 52.560516766139436, 50.97050142288208, 50.8932444027492, 48.37165975570679, 49.46203013828823, 46.42828682490757, 46.45687518801008, 48.01304933003017, 46.97153867994036, 46.124761717660085, 45.39341517857143, 42.74970204489571, 47.43038729258946, 42.00665821347918, 40.05293941497803, 38.47347838538033, 37.20598105021885, 37.70858941759382, 36.9511593409947, 39.26998860495431, 37.066617556980674, 37.56250354221889, 44.070763042994905, 42.825072629111155, 39.284308842250276, 45.12123686926705, 40.938181604657856, 41.295284271240234, 48.19031177248274, 47.700272696358816, 45.36906521660941, 44.345810958317344, 44.134578772953574, 41.34690591267177, 45.15064859390259, 47.16025175367083, 51.861750330243794, 52.56457104001726, 56.97261592320034, 49.09091642924717, 42.53523894718715, 47.257533482142854, 50.92163821629116, 54.36146204812186, 54.02731275558472, 55.80035754612514, 56.53303119114467, 54.91623749051775, 57.86412538800921, 55.0483991759164, 58.01307739530291, 58.06451490947178, 61.09238352094378, 59.795849663870676, 61.62229483468192, 60.3495238167899, 62.63862173897879, 57.53601408004761, 65.33232021331787, 54.946868624006, 65.19108418055943, 12.317227108137947, 0.37632271381361143, 1.279243482010705, 6.297424665519169, 0.4223305093390601, 5.00886082649231, 75.52271502358573, 69.38430118560791, 78.18532725742885, 67.73311737605503, 82.89455223083496, 55.312534945351736, 72.89101532527378, 38.96175609316145, 48.17895494188581, 73.67594637189592, 74.59167725699288, 3.018438386065619, 0.2667323329618999, 0.1639032821570124, 0.21719882876745292, 0.18165335112384387], [0.08019115483122212, 0.037427533617509265, 0.03163068342421736, 0.023489611788785884, 0.0843270971838917, 0.028166628143350993, 0.16924215853214264, 1.3205555166516985, 53.00913415636335, 50.60993160520281, 37.444158349718364, 27.77980296952384, 32.584515299115864, 33.5541398865836, 56.841968945094514, 55.9068386895316, 62.540909222194124, 50.874821254185264, 60.43311759403774, 17.839327914374216, 0.5870562845042774, 0.21048389694520406, 2.277107068470546, 0.8557831304413932, 0.14139635701264652, 28.067614725657872, 51.39593614850725, 43.49870048250471, 55.67760719571795, 54.31755985532488, 53.67029346738543, 50.703704493386404, 50.891722747257774, 51.77155923843384, 53.099116802215576, 54.84803744724819, 54.92393609455654, 48.86790009907314, 46.707729475838796, 48.26710673740932, 46.53003624507359, 44.31137221200125, 47.3757848739624, 48.983813422066824, 51.96746022360665, 50.78848641259329, 51.01336833408901, 51.86915363584246, 51.5991153717041, 48.73065233230591, 49.09876094545637, 48.10270193644932, 46.81626033782959, 46.13586841310774, 47.89524609701974, 45.58532094955444, 43.76291615622384, 43.288798877171104, 40.423549379621235, 38.20275572368077, 35.71762480054583, 40.82779557364327, 46.11374882289341, 40.90910339355469, 35.507188183920725, 36.1836439541408, 36.302638803209575, 33.777263913835796, 32.601538385663716, 32.76256288800921, 33.73734998703003, 32.434903212956016, 35.8813591003418, 37.17417219706944, 40.94251380647932, 41.37321179253714, 40.758101667676655, 39.820515223911826, 41.52276481900896, 43.781867367880686, 43.83840485981533, 43.27823066711426, 41.535115242004395, 45.64596482685634, 46.57739864076887, 45.54378114427839, 44.973935059138704, 37.40794433866228, 39.59882252556937, 33.97847332273211, 32.78348043986729, 37.77177286148071, 44.58382497514997, 45.205219745635986, 46.39919124330793, 42.61893694741385, 44.7628036226545, 43.01514407566616, 44.179471084049766, 41.55222865513393, 42.55189725330898, 41.819588388715474, 43.373959473201204, 40.05171305792672, 40.264470372881206, 41.3347361428397, 37.004511083875386, 33.974707399095806, 33.7246139390128, 31.808606488364084, 33.979373114449636, 32.36888142994472, 33.08235372815813, 32.82909536361694, 35.04448332105364, 33.353288309914724, 43.573101793016704, 41.15882512501308, 40.87170818873814, 37.072235175541465, 38.91553667613438, 42.767558915274485, 41.491390228271484, 39.63864265169416, 41.4139838218689, 42.44912992204939, 44.91489274161202, 44.67820235661098, 46.14013460704258, 43.81768185751778, 51.35884666442871, 45.67680788040161, 50.822112219674246, 25.342581612723215, 43.2097943850926, 58.1321382522583, 43.568119934626985, 54.52550554275513, 49.351519039699006, 53.50640630722046, 51.30646766935076, 53.56615386690412, 52.128978048052105, 54.50991725921631, 49.8458069392613, 50.55599621364048, 52.57057775769915, 56.06303766795567, 54.303458486284526, 56.09789678028652, 53.93288326263428, 59.39715508052281, 49.14727674211775, 54.706672872815815, 3.301699072122574, 0.37150560372642105, 2.092624362025942, 2.968522310256958, 0.04339373597343053, 3.8869764549391608, 62.01478467668806, 58.95336668831961, 64.30380616869245, 61.363759313310894, 67.12676198141915, 49.40953997203282, 30.82477978297642, 34.61652987343924, 43.342730794634136, 58.51313577379499, 44.672150475638254, 0.10770881681569985, 0.07894493705992188, 0.05327410490385123, 0.04845295753329992, 0.039186479590301, 0.07935595286211797, 0.006661562074441463, 0.0459452719161553, 0.03519884463665741, 0.09330085851252079, 0.0594904695504478, 0.10036471339740924, 2.7678318449429105, 63.42837483542306, 57.51546130861555, 41.45916100910732, 28.976440838405065, 45.200870173318044, 36.63679156984602, 63.157756396702354, 59.85158116476876, 68.28918170928955, 53.9993462562561, 68.15013435908726, 18.592601231166295, 0.49482953335557667, 0.02452318516692945, 5.5174997959818155, 0.6141744522111756, 0.09220892603376082, 32.86500712803432, 51.93755865097046, 46.90859147480556, 57.4693808555603, 55.208721910204204, 55.90247869491577, 52.26693800517491, 52.33088575090681, 53.49941641943795, 54.95650577545166, 57.476301261356895, 57.01261322838919, 52.055070059640066, 49.652806827000205, 47.756525312151226, 45.32460021972656, 44.62281479154314, 48.63159186499459, 52.32237768173218, 52.09158631733486, 51.86322334834507, 53.565149852207725, 52.28939458302089, 52.5453314781189, 50.241298403058735, 50.84818186078753, 49.98683105196272, 49.60750109808785, 48.122719696589876, 48.76271479470389, 49.34520312717983, 47.82512835093907, 44.04005547932216, 41.74096604755947, 40.82335220064436, 38.21926811763218, 43.01930257252285, 45.969420841761995, 42.66672665732247, 36.33318655831473, 36.427921772003174, 38.20281825746809, 35.18472923551287, 34.25629356929234, 35.70013965879168, 36.030856541224885, 32.54210696901594, 37.12622962679182, 39.13302224023001, 44.188920634133474, 43.95768458502633, 41.19413934435163, 42.663103171757285, 43.55684648241316, 45.108455657958984, 45.62106595720564, 44.681454113551546, 44.00312580381121, 46.94963795798165, 47.429414544786724, 47.01604189191546, 46.88847296578543, 39.402466433388845, 41.900625228881836, 37.65763132912772, 34.93431268419538, 40.604278973170686, 45.51893438611712, 47.801844937460764, 47.86893326895577, 45.39646891185215, 46.766452176230295, 45.12763268607003, 45.54464619500296, 43.658547265189036, 43.67907224382673, 43.76105751310076, 43.171919754573274, 41.66174963542393, 44.835533891405376, 42.06646135875157, 38.332951068878174, 35.71154165267944, 36.749998569488525, 34.60638550349644, 34.03878716060093, 33.67613983154297, 36.31543043681553, 36.069179330553325, 36.15556975773403, 35.82776417051043, 45.77869626453945, 43.34272732053484, 43.21527303968157, 39.104479040418354, 40.33860765184675, 44.61010306222098, 43.71266678401402, 40.81377410888672, 43.55852099827358, 44.08772359575544, 47.480292728969026, 46.40916190828596, 47.656693594796316, 48.01864957809448, 53.404684679848806, 49.423686504364014, 52.575438022613525, 29.72697135380336, 44.26639304842268, 52.19189746039254, 48.282809666224885, 54.37909310204642, 52.27421276909964, 57.07411520821707, 52.97101286479405, 55.34073073523385, 54.90961585726057, 56.5303943497794, 52.47768381663731, 53.685881750924246, 56.13752930504935, 56.72310611179897, 56.378927094595774, 60.803449630737305, 56.9714138848441, 61.14018712724958, 51.45650012152535, 56.77010720116751, 4.38297404561724, 0.3485684873802321, 6.698596715927124, 2.982696201120104, 0.11750011784689766, 4.862107055527823, 69.50941739763532, 63.6091947555542, 71.87512615748814, 65.09490721566337, 74.56052153451103, 53.35752378191267, 42.994553089141846, 34.904539653233115, 46.136108125959126, 66.82140254974365, 54.04820251464844, 0.1567976770124265, 0.019945684454536865, 0.01119585834177477, 0.05154311118115272, 0.015549405178587352, 0.15813771582075528, 0.14483395112412317, 0.09702841777886663, 0.09663946793547698, 0.3604012695806367, 0.12451958975621633, 0.30017797542469843, 3.4697647052151814, 77.75717231205532, 64.6137444632394, 52.104728834969656, 37.82906770706177, 47.62153223582676, 46.764735971178325, 68.92313534872872, 65.93308925628662, 73.9926174708775, 58.32249110085623, 72.00562027522496, 20.427048989704677, 0.5938614479133061, 0.285451594207968, 4.743118720395224, 2.1976674454552785, 0.47514566672699793, 36.65872008459908, 56.0807659966605, 51.60462876728603, 60.18401772635323, 59.28879792349679, 59.09696510859898, 54.93993432181222, 55.08087853022984, 54.74045154026577, 57.17682695388794, 58.46289334978376, 58.80361911228725, 54.24098375865391, 50.94748898914882, 49.220420428684776, 46.837469714028494, 45.44561004638672, 50.189760140010286, 52.854852880750386, 57.04031917027065, 54.973907538822715, 58.15001596723284, 55.478419712611604, 54.32034608295986, 52.5857560975211, 53.76958669934954, 52.861248697553364, 51.35045671463013, 50.88693196432931, 50.44033302579607, 51.62043244498116, 49.39955888475691, 47.88258300508772, 44.12206506729126, 42.86042158944266, 39.54395260129656, 46.78995793206351, 50.236160210200715, 46.6328626360212, 38.98173563820975, 39.05131837299892, 41.12284387860979, 38.682243960244314, 36.574584347861155, 37.60279614584786, 37.397396973201204, 35.70301968710763, 39.69919272831508, 42.33407122748238, 45.168199743543354, 45.640882219587056, 44.23477874483381, 43.84273011343819, 45.80377926145281, 46.620390619550435, 46.726729324885774, 48.96190922600882, 46.50610317502703, 50.59729978016445, 50.4692896434239, 50.558945723942344, 50.88049098423549, 43.65080002376011, 46.72496795654297, 41.462183475494385, 40.29884311131069, 43.112102712903706, 50.22509172984532, 50.3715250151498, 52.26639951978411, 48.61793170656477, 48.98078053338187, 48.26234027317592, 47.984273365565706, 46.48338951383318, 47.647449016571045, 45.83130802427019, 46.813067640577046, 45.7648971421378, 46.92280748912266, 46.84179496765137, 40.65788779939924, 37.357806137629915, 37.668804032461985, 36.35122755595616, 36.058211599077495, 34.90125315529959, 37.070494651794434, 38.27209874561855, 41.24034833908081, 38.16020495550973, 48.48681572505406, 43.6422051021031, 44.77268396105085, 40.53986917223249, 42.54738439832415, 46.534688064030235, 45.10262959344046, 43.227376801627024, 45.62107637950352, 46.19052641732352, 48.212493896484375, 48.370937143053325, 49.710681847163606, 49.11023242133004, 55.75568757738386, 50.587718214307515, 52.06866768428257, 34.72684294836861, 49.02704858779907, 50.391730376652305, 50.235507079533164, 56.86033650806972, 55.38656800133841, 57.63007531847273, 54.36332763944353, 58.44102736881801, 57.14046703066145, 59.57992049625942, 55.2550698689052, 55.55004521778652, 58.71675968170166, 61.50120162963867, 57.39896433694022, 62.29547105516706, 59.78123760223389, 64.14020388466972, 54.90198673520769, 61.527306011744905, 5.07107195683888, 0.33059811166354586, 4.623412115233285, 9.139184474945068, 0.27519477744187626, 7.036502378327506, 72.09083993094308, 69.41875730242047, 75.55306475503104, 74.00757694244385, 76.57392188480922, 63.57373114994594, 48.40265219552176, 45.547171865190776, 58.82019056592669, 73.42551939828056, 67.67401599884033, 0.7977653465100697, 0.1745749552335058, 0.057598015027386804, 0.19011700339615345, 0.1074200730238642], [0.17023683658667974, 0.023263113406885947, 0.06619795105819191, 0.011170667729207447, 0.07503467545445476, 0.018088574820597256, 0.030060091987252235, 0.8725581988692284, 54.196258204323904, 48.24074179785592, 42.09057855606079, 20.648317847933086, 20.44645357131958, 42.00270468848092, 54.65224763325283, 56.097438199179514, 61.837341581072124, 52.91249861036028, 60.40230928148542, 25.19733820642744, 0.24678549330149377, 0.3840318758572851, 6.100069335528782, 0.5653578202639307, 0.13476651348173618, 27.338394335338048, 49.657965864454, 46.75129120690482, 54.317264556884766, 52.91510418483189, 51.723964078085764, 52.18474776404244, 49.64832523890904, 50.45726925986153, 54.18936906542097, 51.440366404397146, 51.5022748538426, 53.88088641847883, 51.09581218447004, 50.63982275554112, 50.83284023829869, 48.448611055101665, 50.71930667332241, 52.25255175999233, 49.08288083757673, 49.58312681743077, 47.80208117621285, 50.42447028841291, 53.14355400630406, 49.792455196380615, 49.599118096487864, 48.20736265182495, 49.46632759911673, 50.554797649383545, 47.351518290383474, 51.061352593558176, 55.69656882967268, 47.3317437171936, 43.09738295418875, 39.43252086639404, 39.3509316444397, 41.90670837674822, 43.18806389399937, 44.785437379564556, 46.38956798825945, 41.16055522646223, 33.35692916597639, 34.00036014829363, 32.70526804242815, 32.6695681980678, 33.400539534432546, 34.80239418574742, 34.993705885750906, 36.95459522519793, 39.79526547023228, 39.82478836604527, 41.56335619517735, 40.243486813136506, 42.523638929639546, 41.222112791878835, 44.44915846415928, 42.741155760628835, 43.13260684694563, 44.29045813424246, 44.150170530591694, 46.16608265468052, 43.087447030203684, 36.27131979806082, 38.16559675761631, 32.30049378531319, 30.255937712533132, 37.83009604045323, 44.47493628093174, 45.39480134419033, 46.656750542776926, 45.19315767288208, 44.27140964780535, 41.057735783713206, 42.889395577566965, 42.72551189150129, 41.33805390766689, 38.89097826821463, 40.87278168542044, 38.442781244005474, 41.934341362544465, 37.65015854154314, 36.79823643820626, 34.872272218976704, 32.98091350282942, 33.79750749043056, 34.34228100095476, 32.48923117773873, 35.37812886919294, 33.437899998256135, 36.752958502088276, 41.43106944220406, 37.96551990509033, 43.48680516651699, 40.554328373500276, 37.70559474400112, 40.88166495731899, 41.724634306771414, 41.37733554840088, 44.423040185655864, 45.5656749180385, 49.07386902400425, 43.65362794058663, 57.58809082848685, 55.395020484924316, 43.370308194841655, 49.681714807237896, 51.2373400415693, 49.65904630933489, 39.810534136635916, 35.782785006931846, 54.68960114887783, 44.65784413473946, 46.31624364852905, 50.65403529575893, 46.64081137520926, 47.35352979387556, 50.161546979631694, 51.26983329227993, 53.396690777369905, 50.94482088088989, 49.92501987729754, 50.164736202784944, 50.686743940625874, 52.12134197780064, 56.84697164808001, 55.99569920131138, 58.916728837149485, 56.499349798474995, 51.62123496191842, 0.6205910050443241, 0.21723138487764768, 4.944627770355769, 2.589750817843846, 0.05418236134573817, 4.6128300087792535, 63.62574536459786, 59.2505897794451, 61.81304373059954, 62.67026383536202, 64.43582889011928, 42.908593450273784, 29.915819917406353, 23.138345514025005, 40.96139553615025, 60.421757289341514, 41.79380709784371, 0.352149740925857, 0.14558707071202143, 0.06154685813401427, 0.023367682438609854, 0.041721086084310494, 0.05483402977032321, 0.03512136272287794, 0.1381430123001337, 0.026541139830702117, 0.020069954750527228, 0.08959178254008293, 0.03480815435094493, 1.646420385156359, 64.32640171051025, 55.16679300580706, 45.91952930177961, 29.03472580228533, 31.765180247170584, 45.24066250664847, 62.95469529288155, 62.05019964490618, 66.10886478424072, 56.24375336510794, 65.18661648886544, 27.348443167550222, 0.3338587981249605, 0.17509771218257292, 6.1401461107390265, 0.2385307348200253, 0.3554138200623648, 30.40513985497611, 50.085349559783936, 50.74018601008824, 56.860544954027446, 53.871079036167686, 53.38734892436436, 53.60747480392456, 50.432804652622764, 52.415570395333425, 55.31853124073574, 53.05053499766758, 52.79290969031197, 53.89012752260481, 52.95005709784371, 52.39656359808785, 52.05575098310198, 51.995788029261995, 52.21169982637678, 53.519211837223594, 51.10820777075631, 52.54204845428467, 48.662528719220845, 51.032076358795166, 53.122817107609336, 51.28547021320888, 51.96409729548863, 49.74324457986014, 51.38776854106358, 51.16105924333845, 50.288202217647004, 50.908026695251465, 55.3275534766061, 50.854122570582796, 44.681231771196636, 40.94653333936419, 39.858424595424104, 43.463306358882356, 45.268681117466514, 46.394150325230186, 46.04845312663487, 43.38714368002755, 35.28675658362252, 34.38602685928345, 34.04043388366699, 35.443268230983186, 34.86828742708479, 36.43872969491141, 37.10231045314244, 39.10183525085449, 42.96063198362078, 42.81236784798758, 43.223749841962544, 42.713199683598106, 44.083436557224815, 43.57588802065168, 46.122750214168, 45.47866610118321, 44.53811625071934, 46.925941126687185, 47.220857415880474, 49.23084620067051, 45.0173647744315, 39.30461842673165, 41.395776067461284, 34.326317514692036, 32.44281373705183, 39.6871862411499, 46.71036631720406, 47.42604466847011, 48.784587723868235, 47.02810049057007, 43.558215277535574, 44.62480197634016, 43.93548856462751, 42.529854093279155, 43.52981798989432, 40.48895277295794, 43.56330483300345, 42.193679400852744, 43.473766871861045, 40.86848422459194, 37.42275789805821, 37.25521945953369, 35.707727091653005, 36.20626381465367, 35.309890610831125, 34.62011514391218, 36.630374908447266, 35.95908859797886, 39.28901972089495, 43.01796851839338, 39.25218037196568, 45.49929182870047, 42.805478709084646, 39.11953926086426, 43.30918141773769, 44.31561408724104, 44.1059695652553, 45.12729917253767, 48.71741253989083, 51.28004019601004, 46.52911908285958, 55.947551659175325, 57.02765955243792, 46.93545321055821, 50.8010904448373, 53.02676868438721, 50.1214211327689, 41.762984888894216, 37.09418453489031, 51.409175940922324, 46.65182426997593, 47.577998297555105, 51.04924883161272, 49.01739753995623, 47.84072010857718, 52.780204909188406, 52.91850185394287, 55.88755743844168, 52.80827563149588, 51.997340951647075, 52.32401398250035, 52.68442399161202, 55.021346364702495, 58.47798483712332, 57.21321814400809, 62.22041661398751, 59.92130633762905, 55.43746703011649, 0.7616254314780235, 0.1795577635722501, 3.9659019112586975, 2.5339552632399966, 0.010606362384610941, 5.438970386981964, 69.35320799691337, 63.5733767918178, 70.29325757707868, 65.748336655753, 73.87264292580741, 48.556374141148154, 44.6103948865618, 28.434799228395732, 44.69552074159895, 68.94572394234794, 50.99740137372698, 0.31117911796484676, 0.11523714927690369, 0.08353937231004238, 0.04345746398238199, 0.04194845977638449, 0.31494875997304916, 0.08131969427423817, 0.1957055806581463, 0.07794088165142707, 0.12741211668721267, 0.15090061058955534, 0.11214650369116239, 1.828579570565905, 75.97879477909633, 61.401626995631624, 57.002840587071006, 26.389548335756572, 30.36251265662057, 55.80300480978829, 66.42581381116594, 67.38847977774483, 72.13368947165353, 63.65717901502337, 71.7129829951695, 30.82048579624721, 0.3491718407188143, 0.9397390825407845, 14.64057183265686, 0.8036038417901311, 0.5297543278762272, 35.942506722041536, 53.73721156801496, 55.130971567971365, 58.56405912126814, 56.2125802721296, 55.545924936022075, 56.27786554609026, 54.60853999001639, 55.34834943498884, 58.15009934561593, 54.76283516202654, 55.99978821618216, 56.04172059467861, 54.42769227709089, 56.042814935956685, 54.79819801875523, 52.85035392216274, 53.61011859348842, 55.52895048686436, 52.37367275782994, 52.94306721006121, 52.15562786374773, 54.03531013216291, 55.39331817626953, 53.66572502681187, 52.57983275822231, 51.365305015019004, 53.496532917022705, 53.270111969539094, 52.78225115367344, 51.64793341500418, 55.13245153427124, 52.891459465026855, 46.854277406420024, 42.61991664341518, 42.43356943130493, 46.67518758773804, 46.59696476800101, 49.501179763248985, 50.621125153132844, 45.647691454206196, 36.91783578055245, 36.980070795331685, 36.575074195861816, 36.95393862043108, 37.770873069763184, 40.00890520640782, 40.214759486062185, 42.76683977672032, 44.346370288303916, 43.77249772208077, 45.59356151308332, 44.460386753082275, 45.189131191798616, 44.73384700502668, 48.48303590502058, 47.50869696480887, 48.3193815095084, 49.06629548754011, 49.234320299965994, 50.98811163221087, 48.172138759068076, 44.3533810206822, 45.740515913282124, 41.057304995400564, 36.73545946393694, 41.39864567347935, 48.89270864214216, 49.242821420942036, 51.205388750348774, 49.61913585662842, 48.54353734425136, 47.77166543688093, 47.44261612210955, 46.08799532481602, 46.48715196337019, 42.560182980128694, 46.94004249572754, 43.49145351137434, 48.500798974718364, 43.3125512940543, 39.663888931274414, 40.356318610055105, 37.15680864879063, 37.16752971921648, 38.20725468226841, 36.27099323272705, 40.33877093451363, 38.571941307612825, 40.72371155875069, 45.57079226630074, 40.68290478842599, 47.859459400177, 45.15800673621041, 42.26257078988211, 44.56154210226876, 46.08080046517508, 46.040049280439106, 47.97842298235212, 51.39746822629656, 54.325102124895366, 49.608466897692, 55.80888645989554, 60.225046839032856, 48.94336448396955, 55.690305028642925, 56.44234677723476, 54.953535420554026, 42.266896043504985, 43.879100458962576, 60.0063453401838, 44.73602179118565, 49.94026075090681, 51.20954377310616, 50.84825134277344, 48.69919088908604, 53.03596115112305, 54.76187631062099, 58.67461885724749, 55.765835421425955, 55.967892510550364, 54.83802161897932, 54.913958481379915, 57.24679183959961, 60.039974621364046, 58.935405594961985, 64.64931924002511, 61.139916147504536, 57.56406395775931, 1.2794125186545509, 0.3494593767183167, 9.655141200338091, 8.203920466559273, 0.1922157257795334, 7.749820079122271, 71.8141348702567, 69.80100549970354, 73.12956087929862, 72.67981093270438, 76.72003555297852, 55.33876092093331, 48.56564998626709, 33.711037158966064, 57.660352093832834, 75.51797635214669, 63.468584060668945, 0.5615330540708133, 0.2428665735891887, 0.17894396079438074, 0.16971892437764577, 0.18549062950270517], [0.04821536849652018, 0.02131003686892135, 0.06283359801662819, 0.030272833071649075, 0.050852901967508454, 0.064382164206888, 0.07006488141736814, 0.7005747045789446, 50.8771002633231, 52.68503890718733, 40.594277041299, 27.47947403362819, 26.867773737226212, 40.628545556749614, 51.89143303462437, 54.68106181280953, 58.706379073006765, 54.17809908730643, 56.51014729908535, 39.5771267754691, 0.2883965718959059, 0.06492182346326963, 4.849175589425223, 0.22114589411233151, 0.24524372603212083, 17.036526100976126, 57.03849526814052, 50.69766303471157, 57.385147844042095, 51.58315535954067, 50.75655249186924, 46.96999965395246, 48.24656786237444, 45.35491173607962, 49.8106038911002, 50.3782890864781, 52.73381526129586, 48.11866889681135, 50.582392420087544, 50.926401206425254, 51.73997967583792, 50.489446367536274, 49.82030010223389, 49.397755827222554, 47.47223629270281, 46.73214544568743, 49.6437463760376, 48.081232002803254, 52.917612484523225, 48.549644810812815, 48.8370292527335, 49.054747581481934, 47.49518619264875, 49.45204905101231, 57.61190230505807, 54.724526269095286, 48.51115526471819, 48.96292018890381, 43.58630337033953, 39.02325807298933, 39.57044608252389, 42.26492622920445, 43.70706653594971, 45.29185683386666, 44.708527769361226, 39.38673571177891, 34.53214052745274, 33.080536774226594, 32.35104193006243, 31.729403972625732, 33.78018563134329, 33.184367179870605, 34.439173630305696, 36.066983699798584, 37.043740613119944, 39.779465266636436, 40.48510694503784, 41.690678460257395, 43.20570189612252, 41.87280811582293, 41.853940282549175, 41.227369104112896, 41.42473268508911, 43.63941887446812, 44.868985993521555, 46.922407967703684, 41.71850946971348, 31.784541402544292, 36.248394216809956, 29.33776453563145, 30.39203555243356, 36.334819384983604, 42.83080836704799, 43.36893939971924, 46.67182118552071, 46.69981895174299, 46.15285675866263, 42.45321546282087, 45.14051117215838, 43.44608177457537, 43.198298590523855, 41.259525367191856, 39.51315818514143, 40.46851464680263, 42.77957582473755, 37.11177042552403, 35.63112667628697, 33.36940118244716, 33.31032759802682, 34.86713750021798, 34.11268125261579, 33.8448942048209, 32.66175842285156, 33.87760284968785, 31.93262141091483, 39.18831600461687, 46.842427253723145, 43.2106385912214, 40.5383996282305, 40.09451396124703, 39.76789999008179, 40.595180307115825, 47.09608513968331, 48.02925600324358, 47.12572962897164, 47.51454387392317, 52.59030369349888, 59.61584963117327, 45.64119141442435, 45.245863233293804, 46.43866048540388, 50.350253105163574, 51.05995600564139, 49.09529032026018, 35.57198708398001, 31.19067539487566, 46.79769127709525, 39.44299527576992, 41.079917907714844, 44.13238314219883, 49.0450096811567, 47.81897572108677, 54.585180146353586, 53.87687383379255, 51.75348697389875, 47.787806102207725, 47.6744601385934, 51.75266708646502, 53.65015411376953, 52.66269697461809, 56.767657961164204, 59.35964870452881, 60.54170404161726, 47.62936980383736, 0.19452119778309548, 0.15575935558548995, 9.482940520559039, 0.8078846377985818, 0.1349469902259963, 7.059074469975062, 65.59420476640973, 60.636713709150044, 62.174176352364675, 60.664728845868794, 62.583675384521484, 46.414421694619314, 24.328327008656093, 22.83753888947623, 42.483857018607004, 54.30800608226231, 37.097599574497764, 0.20088557127330983, 0.09092126334352152, 0.0295021529974682, 0.04975554460127439, 0.06762033687638384, 0.07341383171400853, 0.04622528635497604, 0.05521237071869629, 0.05081125009538872, 0.08094543471400227, 0.03727419827399509, 0.05861956985401256, 1.0193376455988203, 61.43335941859654, 58.18856457301548, 49.152241230010986, 27.636317457471574, 33.788704122815815, 49.06416933877127, 56.17364256722586, 60.742222104753765, 63.17160415649414, 57.77968045643398, 62.34189196995327, 42.68173129217965, 0.22576842749757425, 0.15744668218706334, 4.504551018987383, 0.41942743797387394, 0.2819418039705072, 18.362808670316422, 59.173819133213584, 52.854790346963064, 60.25470175061907, 52.707735197884695, 53.76120369774954, 49.70365374428885, 51.54923077992031, 48.05082321166992, 51.250194208962576, 51.652807576315745, 54.5355178969247, 49.92818130765642, 52.68319068636213, 51.13076509748186, 54.03989941733224, 51.685248715536936, 51.091611998421804, 50.4350072315761, 50.89100013460432, 49.042435373578755, 49.91500404902867, 49.499710219247, 54.85867861339024, 49.77014800480434, 50.15679093769619, 49.94271693910871, 50.302154200417654, 50.45600816181728, 56.1314183643886, 56.440950189317974, 50.79224191393171, 49.88383790424892, 46.28488990238735, 39.60969645636422, 41.57108954020909, 44.096857002803254, 46.00289726257324, 46.38858829225813, 47.76494305474417, 41.221682003566194, 35.09312071119036, 35.23239735194615, 34.82833181108747, 34.55436086654663, 36.41594655173165, 35.64211177825928, 35.63591398511614, 38.56472907747541, 38.59821244648525, 42.0366153717041, 42.62559332166399, 43.614822251456125, 44.38094799859183, 43.035634313310894, 42.54763453347342, 44.55440977641514, 43.789816107068745, 46.03148562567574, 47.088167667388916, 47.920690400259836, 44.696142605372835, 36.0110958644322, 38.557965006147114, 31.944530623299734, 32.81871822902134, 38.55849654333932, 45.46936246326992, 45.82376575469971, 47.74027694974627, 47.93276636941092, 46.91529648644583, 43.39644384384155, 46.217492376055034, 45.99364921024868, 43.86665276118687, 42.3912479536874, 43.151829038347515, 40.991258893694194, 45.29198884963989, 39.802807739802766, 37.29080465861729, 36.398242541721885, 34.89992952346802, 35.99814789635794, 35.15933009556362, 34.597634247371126, 34.911057063511436, 36.22782754898071, 33.609857491084504, 41.62976360321045, 47.91523606436593, 43.955228396824424, 42.33257041658674, 41.99898392813546, 41.556175231933594, 43.63265132904053, 47.40662097930908, 48.44813857759748, 49.54670436041695, 50.925727231161936, 53.1280734198434, 59.52780900682722, 49.44332211358206, 47.752776759011404, 48.811855929238455, 52.07262815747942, 53.697978564671104, 50.22745759146554, 37.089567456926616, 31.363581316811697, 47.55061544690813, 39.65076725823538, 42.13547086715698, 44.32008177893502, 51.266505105154856, 49.24018457957676, 55.67042623247419, 55.61895745141165, 52.9213992527553, 50.113593987056184, 49.823430265699116, 54.396053654806956, 57.00955254690987, 54.69878666741507, 59.619636399405344, 61.777892793927876, 64.73607444763184, 52.20949377332415, 0.14646808058023453, 0.1700441733534847, 9.469350712639944, 1.1866605814014162, 0.06572026919041361, 8.73339056968689, 70.78081267220634, 62.9173834664481, 68.0053825378418, 65.23847089494977, 68.90917641775948, 48.14811536243984, 37.64871679033552, 23.706206151417323, 47.085284164973665, 63.47838796888079, 46.128767354147776, 0.3415979785578591, 0.06408347309167896, 0.09848088305443525, 0.041904273575970104, 0.05918696762195655, 0.24285441424165452, 0.1347589274602277, 0.12730485387146473, 0.14691375595118317, 0.2165107535464423, 0.18672237412205764, 0.15646098793617316, 1.3563535043171473, 72.80057062421525, 66.87468133653913, 55.867914881025044, 32.56743662697928, 38.025368213653564, 51.904686723436626, 60.68435055868966, 65.9062066759382, 67.67178562709263, 63.03475243704659, 67.9452041898455, 49.06726476124355, 1.0728288952793394, 0.30286307420049396, 11.73942620413644, 0.38049087300896645, 0.42358957177826334, 23.30024548939296, 63.202718189784456, 57.76926163264683, 63.571820395333425, 55.63976035799299, 54.256971563611714, 51.37452180044991, 52.03673723765782, 50.01595095225743, 54.02737528937203, 54.60570512499128, 55.22555044719151, 51.4505489894322, 56.21516152790615, 55.16993359157017, 56.00710814339774, 52.6382532119751, 52.03620222636631, 53.556714739118306, 54.61897618430001, 50.124759742191856, 53.70594467435564, 51.35533435004098, 56.44887113571167, 51.30692277635847, 52.567444120134624, 52.037088121686665, 50.752748353140696, 51.54502017157418, 56.056072098868235, 56.272491114480154, 55.34127269472395, 50.694581508636475, 47.560641697474885, 41.646873542240684, 44.96921375819615, 46.728667872292654, 49.1999579838344, 49.60352325439453, 49.63434893744332, 44.37273175375802, 37.804349490574424, 37.99902064459664, 36.73563664300101, 35.62431744166783, 38.44489697047642, 36.55783224105835, 37.581037861960276, 39.13775396347046, 41.13644845145089, 44.01540674482073, 44.953399658203125, 47.224908215659006, 48.25174427032471, 46.463746956416536, 44.80731725692749, 44.750390665871755, 45.731219223567415, 48.2697296823774, 50.25937761579241, 51.412643092019216, 47.26137236186436, 40.04428195953369, 43.36769567217146, 36.14677333831787, 37.61340604509626, 41.169650418417795, 45.818832533700125, 47.53554480416434, 52.36335468292236, 50.49207278660366, 50.59386389596121, 45.82427992139544, 49.613243784223286, 48.07257802145821, 47.14621639251709, 45.41893243789673, 44.730084555489675, 44.106713022504536, 49.885314396449495, 41.020218985421316, 39.67733716964722, 38.53665140696934, 37.79360410145351, 36.97565174102783, 36.79960870742798, 36.95439372743879, 36.12462942940848, 37.500702789851594, 35.469164167131694, 44.59997606277466, 51.38078907557896, 47.354770047324045, 43.96801655633109, 43.68387344905308, 43.41528735842024, 45.48467281886509, 50.632728644779746, 52.36350059509277, 52.364521980285645, 52.57428462164742, 55.68345410483224, 59.68539415087019, 51.499568530491416, 48.486016682216096, 51.75534561702183, 54.38497822625296, 56.95303937367031, 51.221251487731934, 40.54240526471819, 41.48513337544033, 48.54747002465384, 41.26648746218, 42.91829660960606, 44.165407930101665, 48.75118773324149, 49.94040666307722, 59.46583802359444, 59.060646874564036, 56.72465903418404, 50.6924866267613, 52.947496686662944, 56.05769797733852, 59.22510378701346, 57.681325231279644, 61.69435460226876, 64.66394519805908, 65.56553649902344, 55.38722808020455, 0.8353115660803658, 0.20933956120695385, 24.033115421022686, 4.553491958550044, 0.23338122399789946, 12.142245411872864, 75.77121039799282, 69.23891707829067, 72.60880034310478, 71.08379581996373, 73.79847090584892, 59.078232765197754, 37.34870399747576, 31.205374308994838, 61.44747815813337, 70.35982826777867, 57.84312793186733, 0.4526279664465359, 0.22224273239927633, 0.16758421249687672, 0.19665885450584547, 0.14132369948284967], [0.007049764257057437, 0.062375349391783984, 0.055188666097819805, 0.0014769644185435027, 0.01803683822176286, 0.0556564583177013, 0.05261428048834205, 0.46909063735178536, 50.40533494949341, 57.88006108147757, 44.59375047683716, 43.01673868724278, 28.000066076006206, 39.306046281542095, 57.50613682610648, 58.360268456595286, 57.343566349574495, 59.64581721169608, 52.99275377818516, 50.473858083997456, 1.1184982103960854, 0.07419505622237921, 2.6466991220201765, 0.12148452975920268, 0.0692137610167265, 8.194892151015145, 61.426293100629536, 52.03650099890572, 56.818018504551475, 51.61027070454189, 53.524607113429475, 48.664748668670654, 51.392660072871614, 48.206028597695486, 49.108231340135845, 44.97588055474417, 46.76922450746809, 47.02935116631644, 47.86706072943551, 45.975295543670654, 48.18585450308663, 48.466370650700156, 49.97360863004412, 47.43765163421631, 47.49378613063267, 41.838702883039204, 47.01884549004691, 46.84728751863752, 51.43084042412894, 49.01258591243199, 49.151209422520225, 46.416196959359304, 47.72566141401018, 49.940615109034944, 40.039842060634065, 38.1676846912929, 45.29329163687569, 48.09612199238369, 43.10164567402431, 40.61717135565621, 39.16100263595581, 41.16583585739136, 44.12552179609026, 44.53695937565395, 45.78373718261719, 41.13478088378906, 37.008429867880686, 30.20485803059169, 34.708596978868755, 32.34177303314209, 33.0745404788426, 32.44797624860491, 35.49892330169678, 36.56398139681135, 37.8538693019322, 40.68335294723511, 40.75449902670724, 39.97265298025948, 41.480714321136475, 41.54329327174595, 42.37248434339251, 41.96188054765974, 40.26093373979841, 43.1645233971732, 45.8131628036499, 46.3689318384443, 40.06223610469273, 31.036724158695765, 33.6486770766122, 29.17358555112566, 31.95264264515468, 34.53147350038801, 41.7078891481672, 44.50467804500035, 47.13735396521432, 44.36541877474104, 43.78433745247977, 43.4793358530317, 44.664656843457905, 42.838253361838206, 42.331243310655864, 39.3902792930603, 41.920955657958984, 38.494138853890554, 41.38070889881679, 37.552859442574636, 35.42033570153372, 33.07947022574288, 33.93704816273281, 33.97925499507359, 33.5137117930821, 32.481560366494314, 34.754173687526155, 34.73542397362845, 41.459129742213655, 42.45176328931536, 43.317255224500386, 44.27695778438023, 41.896689074380056, 39.75919737134661, 40.456390040261404, 43.69712366376604, 47.76955318450928, 48.623580592019216, 49.56422771726336, 47.893925939287456, 52.62734454018729, 48.35524116243635, 42.664906229291645, 48.56716121946062, 48.82066624505179, 50.00023760114397, 46.319616998944966, 44.33473205566406, 45.68235601697649, 38.19063459123884, 49.97494615827288, 49.19816534859793, 41.10524409157889, 44.24799769265311, 45.083320549556184, 50.0617048399789, 51.9891733442034, 51.97713906424386, 50.856874057224815, 49.195674419403076, 50.42842728751046, 49.74224056516375, 53.480916840689524, 55.806068965366904, 52.50039400373186, 57.96523209980556, 60.7043057850429, 40.71860115868704, 0.18904362885015352, 0.05247782709609185, 3.9464017919131686, 0.2567572710769517, 0.09363367315381765, 10.347237365586416, 67.53189059666225, 57.38341774259295, 64.13554859161377, 58.33728381565639, 66.5631171635219, 46.70925113133022, 26.67162435395377, 25.6945287159511, 38.24609511239188, 62.07124573843819, 30.240554400852748, 0.269819477306945, 0.10089560598134995, 0.072190344865833, 0.1078701453017337, 0.03298806219494768, 0.06479905612234559, 0.006454924836621753, 0.013148005286763822, 0.026087973433147584, 0.029843985369162898, 0.010967438857603286, 0.04846907273999282, 0.40940349442618235, 60.46205684116909, 63.768655913216726, 48.91887208393642, 32.72653647831508, 28.1200875214168, 48.03717347553798, 59.24261324746268, 65.20399393354143, 60.54089805058071, 63.71719755445208, 55.771032673971995, 56.63311651774815, 1.1446021582399095, 0.10375535967094557, 2.6337863292012895, 1.3788309267589023, 0.20029737640704426, 9.887322204453604, 63.087030683244976, 52.70627955027989, 60.35104547228132, 53.655424322400776, 54.19680363791329, 50.72486523219517, 53.382697105407715, 49.39346531459263, 51.0597961970738, 46.775265966142925, 48.55308416911534, 48.41751439230782, 50.68262365886143, 48.27485745293753, 49.40331438609532, 51.047185216631206, 50.90651893615723, 48.97456536974226, 50.22437606539045, 43.29319708687918, 48.64684663500105, 49.023150648389546, 52.4451766695295, 50.91664940970284, 51.28547021320888, 47.4742408479963, 47.94565180369786, 47.6936024257115, 43.258025305611746, 39.93656056267874, 46.94628545216152, 52.782209464481895, 44.84100559779576, 41.17191205705915, 40.66756316593715, 42.650283745356965, 46.62805795669556, 46.47257464272635, 47.781900133405415, 43.82406030382429, 40.49732535226004, 34.73076868057251, 36.190748487200054, 35.14544759477888, 36.43517916543143, 35.259398051670615, 36.57108245577131, 38.63674020767212, 38.732375213078086, 40.63067517961775, 41.004609857286724, 41.60867234638759, 43.80175311224801, 42.324333327157156, 43.354667799813406, 42.46698679242815, 43.647183486393516, 46.79170192990984, 49.03252724238804, 46.00633314677647, 42.66821009772164, 34.96831021990095, 35.50287682669503, 32.17764268602644, 34.98546184812273, 36.883942467825754, 45.13496650968279, 47.18568910871233, 49.691636834825786, 47.25661284582955, 46.52230984824044, 45.19515527997698, 45.7546763420105, 44.33761208398001, 44.265465463910786, 41.51573671613421, 43.226991176605225, 40.70386055537632, 43.74701867784773, 37.902013369968955, 36.12957307270595, 35.20301342010498, 34.77172483716692, 36.552433490753174, 35.459381103515625, 34.78998817716326, 36.272049358912874, 36.880075795309885, 43.90888738632202, 43.76878390993391, 44.81687102999006, 46.275805132729666, 42.751546791621614, 42.28376626968384, 42.11789887292044, 47.60759762355259, 49.15129280090332, 50.0982141494751, 50.71193463461739, 49.26422187260219, 51.97957788194929, 50.02652611051287, 44.235834871019634, 50.6694255556379, 50.46707664217268, 52.09811762401036, 48.33203765324184, 47.12871388026646, 47.123443671635215, 40.93547528130667, 51.988766874585835, 51.1215900012425, 41.192013195582796, 45.61347157614571, 47.56588411331177, 51.311279296875, 53.797556672777446, 54.0905795778547, 51.725704601832796, 50.96834748131888, 52.90753064836775, 52.46647637231009, 56.66262204306466, 57.26592023032052, 55.19469002314976, 60.200630869184224, 64.38202204023088, 46.53126607622419, 0.24537908019764082, 0.07533173130026885, 6.8404533096722195, 0.4519815668463707, 0.07222571689635515, 12.260076437677656, 73.64434596470424, 62.424262864249094, 68.65097440992082, 62.86348628997803, 70.11342430114746, 52.34588691166469, 31.594535963875906, 22.202225140162877, 47.002680506025044, 69.0663377216884, 41.12246520178658, 0.35977234904255184, 0.04020127960081611, 0.05214421856882317, 0.08084728462355477, 0.04023379160623465, 0.16452551233981336, 0.15672237319605692, 0.2159070066575493, 0.17461991496384144, 0.19334260959710392, 0.19087152076619013, 0.12971583807042666, 0.6987166042838777, 70.82078565870012, 74.81080259595598, 59.95825685773577, 54.05043983459473, 40.392702851976665, 52.855606760297505, 67.74388708387102, 69.65802546909877, 67.13387693677629, 68.44214630126953, 62.24349158150809, 61.04205077035086, 2.1616149800164357, 0.23862453550100327, 8.156755225999014, 1.3463923931121826, 0.27856728647436413, 12.344923496246338, 65.18894413539341, 54.63701023374285, 63.157902308872764, 56.926761286599294, 57.48859262466431, 51.44826650619507, 55.757893630436485, 53.008053711482454, 52.806719235011506, 49.224262782505576, 51.782832690647666, 50.510916301182334, 52.522836685180664, 50.64495747429984, 52.69539519718715, 53.03165326799665, 53.110108852386475, 52.14450379780361, 51.817271436963765, 44.590470927102224, 51.531974928719656, 50.772856439862935, 54.92034387588501, 51.89200278690883, 51.337206499917166, 49.462113516671316, 48.68588161468506, 49.15481553758894, 46.89082145690918, 43.70136553900582, 49.23303140912737, 54.1426875931876, 48.771372250148225, 43.62243052891323, 43.58554949079241, 45.36701202392578, 48.988444396427695, 50.235156195504324, 51.40660858154297, 49.48092576435634, 43.68644775663103, 35.06637709481375, 38.33806841714041, 36.40846334184919, 37.24809408187866, 38.03139577593122, 40.37773643221174, 42.591602734157014, 42.081122057778494, 43.6063107081822, 44.619653361184255, 43.43469367708479, 46.01127331597464, 45.19262613568987, 45.96974393299648, 46.475718702588765, 45.3344840322222, 47.15113224302019, 53.18547248840332, 49.06715359006609, 45.84755638667515, 40.24100978033883, 43.24157544544765, 37.85298340661185, 38.48865325110299, 40.09679991858346, 46.7018860408238, 49.69924511228289, 50.03847353799002, 49.318271909441265, 48.83900948933193, 47.64229692731585, 49.22788626807076, 46.84754460198538, 47.096262318747385, 43.37850706917899, 48.255454608372276, 44.13241788319179, 46.37332657405308, 41.14075633457729, 40.09819303240095, 36.9398580959865, 37.39370053155081, 38.35665832247053, 37.8192811693464, 36.81660052708217, 39.23451110294887, 38.51993751525879, 45.61000789914812, 46.65933179855347, 47.72231238228934, 49.28088712692261, 45.02599791118077, 44.485004220690044, 44.67868178231375, 50.857416016714915, 50.80018023082188, 52.11514071055821, 53.27234928948538, 50.75475638253348, 55.357965741838726, 52.3119067464556, 45.64935554776873, 51.43574932643345, 53.199462686266216, 54.064527307237896, 50.55097614015852, 48.133103779384065, 49.46134921482631, 43.2363851411002, 53.703161920819966, 51.16062845502581, 42.49732610157558, 45.05305072239467, 49.4345326423645, 55.240464755467, 56.76188053403582, 55.67959438051496, 52.594389234270366, 54.24579538617815, 55.90566096987043, 54.16597448076521, 58.36337430136544, 59.040844508579795, 58.575857162475586, 62.31871277945382, 66.27248791285923, 48.57311235155378, 1.1393532284668513, 0.12986462722931588, 11.782629234450203, 4.7626891902514865, 0.1573460961558989, 14.729411499840872, 78.47494901929582, 66.30392156328473, 76.04594217027936, 67.75701917920793, 76.49144676753453, 60.369485991341726, 41.59445285797119, 32.783681937626426, 56.07622882298061, 77.28517423357282, 52.42728853225708, 0.34918465145996636, 0.15926953937326158, 0.18332380934485368, 0.18176997772284917, 0.2223345653287002], [0.06830473443759338, 0.019368658274678246, 0.08044613472052983, 0.03462258520136986, 0.07276381552219391, 0.02201255640414144, 0.0853944124121751, 0.19897712367985929, 42.870993273598806, 65.27831186567033, 40.419310978480745, 38.61927938461304, 35.596781730651855, 42.312233039310996, 57.300021989004954, 61.447353090558735, 55.347220352717805, 60.70172800336565, 49.10064738137381, 57.730358668736045, 5.845001399517059, 0.24178363169942582, 0.9799806603363582, 1.4433078212397439, 0.08349032779889447, 2.184532744543893, 59.39195087977818, 51.940581117357524, 58.13039425441197, 51.72440528869629, 50.96593645640782, 48.16553449630737, 54.92883457456316, 52.031015396118164, 53.23033005850655, 47.687005111149375, 48.17770079204014, 41.13133805138724, 42.28168875830514, 44.34079435893467, 46.100210257938926, 46.05874340874808, 47.28477389471871, 42.97667190006801, 43.17545291355678, 39.257509640284944, 42.064838954380576, 47.10006298337664, 48.80291359765189, 48.95672239576067, 48.491821902138845, 47.6743038041251, 46.53561912264143, 36.13112252099173, 40.15753064836775, 49.64047724860055, 49.563289710453574, 47.808577741895405, 41.08280488422939, 39.75899934768677, 40.438665185655864, 41.064399106161936, 44.871574197496685, 42.16236386980329, 44.436057635716026, 39.46307209559849, 33.09489175251552, 34.53423540932791, 36.016254901885986, 33.99457924706595, 33.46331303460257, 33.192597321101594, 32.99977438790457, 35.01242780685425, 35.70002153941563, 36.369140011923655, 39.360679967062815, 39.25550161089216, 39.9026255607605, 38.73278168269566, 41.14467511858259, 39.50352450779506, 41.86686740602766, 45.2424829346793, 45.77029936654227, 45.06403235026768, 38.53465032577515, 30.70980794089181, 30.45421150752476, 31.271281446729386, 33.67348561968122, 34.74387298311506, 41.9586044720241, 46.261724608285085, 44.008010387420654, 44.1606901032584, 41.774397305079866, 43.93791348593575, 42.82740027563912, 41.715424469539094, 40.30404731205532, 40.97007731028965, 39.818646158490864, 40.00875929423741, 38.021320887974326, 37.08739614486694, 34.27511971337454, 34.73964153017317, 34.328930037362234, 33.47350604193551, 32.90949991771153, 34.36376483099801, 34.93105745315552, 36.47918905530657, 39.518470082964214, 43.660259996141704, 44.596842425210134, 43.649424280439106, 39.84626872198922, 39.159661633627756, 41.068849427359446, 45.54135969706944, 47.079110690525596, 47.97728000368391, 49.030703340257915, 47.35452338627407, 46.826536723545615, 45.4031982421875, 47.59803342819214, 48.68847329275948, 49.740944726126536, 48.661337103162495, 47.775528635297505, 50.641802992139546, 49.65056603295462, 51.07243149621146, 49.29123646872384, 51.14974062783377, 45.958814416612896, 41.13698346274239, 47.27630056653704, 53.39210149220058, 50.32303006308419, 51.98531709398542, 47.99041209902082, 49.21482712881905, 49.15630940028599, 50.778369835444856, 52.07804775238037, 55.04174974986485, 52.846601894923616, 59.81898021697998, 57.95746053968157, 44.428150585719514, 0.4245994761586189, 0.18103166376905783, 4.492423806871686, 0.9679471403360367, 0.20783261635473796, 15.032356432506017, 70.61164488111223, 57.83794457571847, 60.186817850385395, 59.89365250723702, 63.44058976854597, 42.913867133004324, 38.12719406400408, 31.59832273210798, 35.19153847013201, 64.13712583269391, 19.216017927442277, 0.26490978790181025, 0.1780519179467644, 0.07084466743149928, 0.07516321034303733, 0.04511153558269143, 0.07776121914918933, 0.01814408746681043, 0.034345844694014104, 0.035793797711708715, 0.045908301935664246, 0.009713405211056982, 0.06153384383235659, 0.1998953851205962, 51.08492088317871, 70.53725746699742, 50.857398646218435, 37.10958521706717, 30.277741159711564, 49.19835294995989, 60.98250470842634, 70.77820709773472, 59.63792405809675, 65.47527245112828, 53.110272135053364, 62.38681207384382, 5.964365805898394, 0.19434686856610434, 0.06859728481088366, 3.3295787189688, 0.0719865265169314, 3.0259760958807806, 62.77244404384068, 54.44061940056937, 60.40943118504116, 53.742262908390586, 52.26598610196795, 50.49944829940796, 56.937968730926514, 52.37788684027535, 54.48650530406407, 50.36741862978254, 48.20425680705479, 43.30935164860317, 44.58563150678362, 46.349379607609336, 47.700665269579204, 47.50945084435599, 48.63541684831892, 45.811648096357075, 46.71757507324219, 41.6681524004255, 43.774398054395405, 49.45069762638637, 52.15487398420061, 51.09725046157837, 50.89007602419172, 49.301696981702534, 47.45372976575579, 39.426871980939595, 40.55705901554653, 49.39437552860805, 53.00620549065726, 48.59728166035244, 40.98159742355347, 42.30828993661063, 42.2321446282523, 41.66642229897635, 45.776198387145996, 44.33438811983381, 47.89803579875401, 41.882709298815044, 36.48632138116019, 35.896586077553884, 38.08425767081124, 36.17732456752232, 34.61773191179548, 35.1284418787275, 34.75612265723092, 36.461624009268625, 37.84939466203962, 37.94666249411446, 41.18253237860543, 39.982251916612896, 42.40141316822597, 40.663446358272004, 45.20423310143607, 41.29921347754342, 42.80498538698469, 48.49128689084734, 47.82111576625279, 47.06237595421927, 41.33829709461757, 33.53066192354475, 33.758295331682476, 34.35090371540615, 35.93839686257498, 37.60456098828997, 43.488378933497835, 48.32443979808262, 47.579353196280344, 46.37894071851458, 44.87781367983137, 45.687264919281006, 42.52767235892159, 44.57449007034302, 43.03883048466274, 41.423363889966694, 39.64770310265677, 41.26036262512207, 41.79592282431466, 38.0362560408456, 35.71216699055263, 34.72210775102888, 35.39397076198033, 34.69585745675223, 35.45032065255301, 35.665106841496055, 35.914276191166465, 37.494703020368306, 41.26634502410889, 47.40328236988613, 46.38664279665266, 45.7590537071228, 41.33292613710676, 41.23780877249581, 43.17360469273159, 45.7758857182094, 49.713228361947195, 49.97511986323765, 50.1302627154759, 49.47861548832485, 47.264405250549316, 46.38889053889683, 47.66739729472569, 48.868699141911094, 49.95463309969221, 50.53579085213797, 50.0705429485866, 53.01275416782924, 52.37906108583723, 53.008269105638774, 51.227959973471506, 53.26206595557076, 47.68576485770089, 44.25778423036848, 50.81253412791661, 54.568886620657786, 53.784692083086284, 53.88678196498326, 50.06265326908657, 52.74689177104405, 52.437419005802695, 55.55286271231515, 54.32704414640154, 57.973149572099956, 55.52040072849819, 62.90063830784389, 62.55893284933907, 52.22867774963379, 0.5714739177908216, 0.20448381533580168, 3.540548392704555, 0.38340957782098223, 0.17586018198302814, 17.588942629950388, 76.88714667728969, 63.44813551221575, 65.1489919934954, 65.67462321690151, 72.48528221675328, 52.33720513752529, 37.97111667905535, 24.339838436671666, 43.62581777572632, 72.1796795981271, 25.85952237674168, 0.5991937560694558, 0.19283503826175416, 0.06359635280179125, 0.07838312363518135, 0.041666294381554635, 0.18890219501086644, 0.13837864037070954, 0.15535280454371656, 0.1334803503538881, 0.207173528149724, 0.17214053443499974, 0.24319688443626675, 0.3293653221002647, 57.46694203785488, 81.80182293483189, 55.3851193019322, 49.542667457035606, 47.45692941120693, 55.356593472617014, 66.06446579524449, 74.25611400604248, 64.59455353873116, 69.6817466190883, 57.45588745389666, 69.43744795663017, 8.097202215875898, 0.1874767964971917, 4.5617199284689764, 3.562919855117798, 0.1855709951903139, 3.5704484454223087, 65.49782630375454, 54.65105949129377, 63.943597657339915, 54.95356668744768, 56.40740428652082, 50.692437989371165, 59.5114529473441, 54.133918966565815, 59.56562805175781, 52.67639882223946, 51.71701240539551, 45.14415897641863, 47.508693490709575, 48.91206284931728, 49.761619091033936, 49.43334102630615, 50.80532884597778, 45.94302463531494, 48.26948649542672, 43.504175662994385, 47.36985111236572, 50.22014461244856, 53.35113838740757, 52.44518709182739, 51.809697900499614, 51.24650124141148, 48.65310001373291, 41.85366930280413, 43.567091601235525, 50.118544578552246, 52.34035267148699, 51.23623180389404, 43.74654620034354, 44.12892641339983, 45.57231739589146, 44.338470186506, 50.192984104156494, 48.59910556248256, 49.539443492889404, 43.992832047598704, 39.47729158401489, 37.735569272722515, 39.99985517774309, 39.66956908362252, 36.11732339859009, 35.33221517290388, 38.1543094090053, 39.080358369009836, 39.43955591746739, 41.49946403503418, 44.50903456551688, 44.03398622785296, 43.917506626674104, 44.11919546127319, 48.56573336465018, 43.24549075535366, 47.02739177431379, 50.95207827431815, 50.8556615965707, 50.85084996904646, 43.93389047895159, 38.68128163473946, 40.12645135607038, 38.337307589394705, 41.77846547535488, 41.30248955317906, 46.683150223323274, 50.240551471710205, 50.65809651783535, 50.668452807835166, 47.90285437447684, 48.42458071027483, 45.62125703266689, 46.6487010547093, 43.75855963570731, 45.11254119873047, 43.01921224594116, 44.29722567967006, 44.277725560324534, 42.08862958635603, 38.22923878261021, 38.33343396868025, 39.4712883404323, 37.27721398217337, 37.35216072627476, 38.27509341921125, 39.779354095458984, 40.42844091142927, 43.21799325942993, 48.64155905587332, 49.28695985249111, 48.96670000893729, 43.24237796238491, 43.5113114629473, 46.005721705300466, 48.27399240221296, 51.093911852155415, 51.501548767089844, 52.96457883289882, 51.26048101697649, 50.0189699445452, 50.02807903289795, 50.52435759135655, 51.17642865862165, 51.48368494851248, 51.26680735179356, 52.8235581942967, 54.61477599825178, 54.27589498247419, 56.196404865809846, 53.79063974108015, 54.192690304347444, 49.49406828199114, 47.14135960170201, 54.809898785182405, 55.527359349387034, 55.941405977521626, 55.63847146715437, 52.42123665128435, 54.81462703432356, 54.481203828539165, 56.51083517074585, 57.06655904224941, 59.37641470772879, 59.01302392142159, 65.38385500226701, 64.15144606998989, 55.015423025403706, 0.955266460776329, 0.23163144503320965, 9.807684557778494, 1.5106499791145325, 0.2938457780650684, 20.36735875265939, 82.61847250802177, 65.22970921652657, 72.20407472337995, 69.94488879612514, 77.37800911494664, 59.16701684679304, 58.56688008989607, 41.46519551958357, 52.2440367426191, 80.91988113948277, 32.560495376586914, 0.6815541195017951, 0.27603865787386894, 0.2191773418869291, 0.1519426368176937, 0.15383854508399963], [0.06271526150937591, 0.03027464815282396, 0.020847376070118377, 0.01900534687696823, 0.05364797091377633, 0.03284857914383922, 0.051781287150723596, 0.05961419362574816, 39.709816523960654, 62.37249878474644, 33.8193039894104, 25.31902027130127, 23.997083800179617, 41.164540018354145, 57.65754154750279, 58.57493305206299, 54.94852229527065, 59.967317308698384, 48.79878289358956, 60.957595416477744, 7.305670380592346, 0.22349120969218866, 0.47441002620118006, 2.837091488497598, 0.01636564209392028, 0.326228780405862, 45.156158515385215, 58.02904435566494, 57.28718171800886, 51.72335958480835, 50.998658997671946, 49.58453035354614, 55.712146690913606, 51.900587286267964, 52.23174885341099, 50.32030289513724, 49.71246406010219, 48.597528321402415, 42.26825441632952, 40.22800970077515, 42.198115825653076, 44.62157106399536, 48.677714007241384, 45.129130022866384, 42.827869279044016, 40.79333945683071, 39.919697284698486, 42.93605967930385, 47.50351013456072, 47.5497955594744, 48.169435909816194, 48.83447578975132, 45.97674076897757, 45.80971302304949, 52.11304235458374, 46.72691692624773, 47.892991406576975, 42.329957893916536, 39.32568883895874, 38.39211845397949, 39.49526309967041, 41.44908264705113, 44.92532546179635, 42.950029032570974, 42.818006311144146, 37.41695615223476, 34.59205136980329, 32.64579493658883, 35.60191297531128, 33.93406391143799, 33.79154941013881, 33.80605377469744, 35.8012706892831, 34.95334727423531, 36.33816841670445, 36.594195638384136, 37.15181636810303, 38.58829389299665, 39.105729716164724, 37.99315289088658, 39.973650046757285, 37.4990873336792, 40.757639612470356, 43.949836594717844, 44.05882951191494, 44.818066120147705, 38.808530943734304, 32.9187444959368, 32.15910489218575, 35.80759007590157, 34.09947272709438, 38.04607384545462, 43.42765167781285, 45.80531481334141, 44.27187170301165, 43.630744048527305, 42.17332117898123, 40.534494740622385, 42.31214618682861, 39.62630959919521, 39.58426257542202, 39.603168623788015, 39.322350229535786, 39.323420252118794, 36.02056278501238, 36.34878526415144, 35.40819025039673, 32.64815385001046, 34.77064439228603, 33.04708814620972, 33.210690430232454, 34.33244235174996, 33.68606185913086, 33.950260162353516, 36.28185674122402, 37.64848402568272, 40.75064625058855, 42.13931322097778, 40.96960135868618, 37.4771032333374, 42.46279355457851, 48.59724691935948, 47.4123706136431, 46.61351537704468, 46.709306716918945, 45.37636429922921, 45.93351949964251, 41.51275246483939, 46.904672690800254, 45.354442732674734, 49.95256948471069, 48.15700905663626, 47.81591156550816, 49.07090561730521, 47.800660269601, 46.61318186351231, 47.28972101211548, 48.89296225139073, 50.359264918736045, 50.91223382949829, 50.1784519468035, 50.907425676073345, 49.250176089150564, 48.93158033915928, 49.707447460719514, 52.66819299970354, 51.97656583786011, 52.862440313611714, 52.45761741910662, 50.83532074519566, 47.76137515476772, 60.566182545253206, 55.75313064030239, 49.5628901890346, 1.0690181340490068, 0.12808439561298915, 4.300710414137159, 0.3357222452759743, 0.20470589984740528, 21.447433641978673, 67.85733032226562, 57.77149200439453, 57.69704205649239, 62.48749147142683, 50.012049538748606, 41.69621964863369, 37.53726768493652, 35.63061945778983, 44.70045396259853, 60.33912236349923, 12.232287117413112, 0.47312346952302115, 0.1851081528833934, 0.13322725679193223, 0.08012079074978828, 0.11729439959994384, 0.04357243834861687, 0.04083879039223705, 0.09577179128038031, 0.01059508343626346, 0.09058618239526238, 0.03824979931648288, 0.11335390247404575, 0.021763004794982926, 47.872289248875205, 71.90917233058384, 41.01051582608904, 33.11841835294451, 31.738613809858048, 47.64268255233765, 62.60536766052246, 66.69164494105748, 58.00699772153582, 63.985307693481445, 52.44946370806013, 63.810477120535715, 8.780824184417725, 0.24330658997808183, 0.5734698964016778, 4.372970376695905, 0.06899352890572377, 0.5329561989222253, 48.212775298527305, 60.428121839250835, 58.19195876802717, 53.60953841890608, 52.306278705596924, 52.301150935036794, 55.35618005480085, 54.09679821559361, 54.938440459115164, 52.62933867318289, 52.81750978742327, 49.18593304497855, 45.29375369208199, 42.84637233189174, 44.42415189743042, 46.01954514639718, 48.97175482341221, 47.83764900479998, 45.183968680245535, 42.30068860735212, 42.341241768428254, 45.087051732199534, 48.84101404462542, 49.14782912390572, 51.1828487941197, 50.629324027470176, 48.218486717769075, 46.1123035975865, 53.38600097383772, 50.05872753688267, 49.65863983971732, 45.170711517333984, 41.37055063247681, 39.35664653778076, 42.26624986103603, 45.03458935873849, 46.69323900767735, 47.047854219164165, 43.9132091658456, 39.859147208077566, 36.02103526251656, 34.14701230185372, 36.04241834368025, 35.326569761548726, 35.732139587402344, 35.43813698632376, 36.56312676838466, 37.2273919241769, 38.47017799104963, 37.41554914202009, 37.8291198185512, 40.41737590517317, 40.971039635794504, 38.85812718527657, 42.93572269167219, 38.95630175726754, 43.17198576245989, 45.0219783782959, 47.48037610735212, 47.89462423324585, 39.81661033630371, 34.54251071384975, 35.15174961090088, 37.54052986417498, 36.28082840783255, 40.322585105895996, 45.04571342468262, 47.73152569362095, 48.20598690850394, 44.87705980028425, 43.59665271214077, 43.26684604372297, 45.321282454899375, 43.589780943734304, 42.8371833392552, 40.72497960499355, 40.7572922025408, 40.328355584825786, 38.39616577965872, 37.65435872759138, 38.160149369921, 34.33816071919033, 34.75522286551339, 34.30615036828177, 34.56755896977016, 36.51398910794939, 33.301538126809255, 36.68521009172712, 40.259617056165425, 38.83075475692749, 44.157476561410085, 44.19370794296265, 43.53007507324219, 39.45431041717529, 43.164262839726035, 47.6962114742824, 49.11243152618408, 47.07295111247471, 48.830654280526296, 48.43577773230416, 48.41899783270699, 43.2353081703186, 48.17599153518677, 47.21670586722237, 51.37930563517979, 51.681458473205566, 50.018702438899446, 49.95228460856846, 49.702031339917866, 49.99784047263009, 49.19662632261004, 51.73110335213797, 53.316352231161936, 53.61953687667847, 53.094451086861746, 53.24358722141811, 51.545847007206504, 51.16485643386841, 51.91175651550293, 52.999087061200825, 54.33648674828665, 55.192174775259836, 55.84825495311192, 54.271979672568186, 51.16645104544503, 63.854431424822124, 59.04274136679513, 55.02585227148873, 1.327539107629231, 0.16556794568896294, 9.544692635536194, 0.17495345563760825, 0.08407635135310036, 24.742750576564244, 72.77876022883824, 62.42019121987479, 63.462511335100444, 65.02452891213554, 58.75245952606201, 47.682186535426546, 43.64070429120745, 34.07466418402535, 50.805374009268625, 67.83625643593925, 17.65350181715829, 0.7579588453684534, 0.11788027387644563, 0.046025746169367006, 0.02300632861442864, 0.02552016175884221, 0.22137306763657502, 0.12849043096814836, 0.2278363715325083, 0.09197328439248459, 0.1703681738248893, 0.1946773694029876, 0.2618541275816304, 0.19398576579988003, 55.15752758298601, 79.97270965576172, 45.781103815351216, 36.3941570009504, 34.81705141067505, 56.55591855730329, 66.81045913696289, 71.03886181967599, 63.52942248753139, 70.78235517229352, 56.16102463858468, 72.30202347891671, 9.356038621493749, 0.29190104241882053, 1.74968255843435, 6.91793658052172, 0.14868790789374284, 0.9341185327087129, 52.214371408735005, 61.227817807878765, 61.286516189575195, 55.42656530652727, 55.646580014910015, 52.92311545780727, 59.398072242736816, 55.131992953164236, 56.17064789363316, 53.295247077941895, 53.61779982703072, 52.285500117710654, 46.998066902160645, 43.38645928246634, 47.15498849323818, 48.61634404318673, 52.13181986127581, 48.44100972584316, 47.52108907699585, 46.4220403943743, 43.22010203770229, 47.542121274130686, 51.05777427128383, 49.78551394598824, 51.64078024455479, 52.15999828066145, 49.241497789110454, 48.31272166115897, 55.37389101300921, 50.63674817766462, 51.665234429495676, 46.394407408578054, 42.25484439304897, 41.62269033704485, 42.65011004039219, 46.918815749032156, 50.12893908364432, 48.925160203661235, 48.161744253976, 42.393662452697754, 38.568161487579346, 35.843335083552766, 37.320650645664756, 36.82404204777309, 38.08687366758074, 37.29409810474941, 39.66507012503487, 38.44064814703805, 39.48317323412214, 40.86198418481009, 41.114408765520366, 42.382461956569124, 44.32437229156494, 42.4254469871521, 46.08786678314209, 41.318310601370676, 45.68845306124006, 48.36291197368077, 49.01097045625959, 51.044979163578574, 43.948113441467285, 40.338103907448904, 40.8657431602478, 40.39535011563982, 40.05938039507185, 44.03528554098946, 47.296432971954346, 50.73651041303362, 50.4226324898856, 47.58567605699812, 46.659363065447124, 44.691546372004915, 46.883442470005576, 45.30364792687552, 44.58382497514997, 43.61390508924212, 43.91762127195086, 43.425171170915874, 39.2658474785941, 41.33744594029018, 39.988178730010986, 36.79821559361049, 38.208112784794395, 35.71530062811715, 36.692818369184224, 38.11805023465838, 37.472989899771555, 37.43162032536098, 43.59941462108067, 40.681685379573274, 46.17023767743792, 46.21879516329084, 45.083174637385774, 40.682876995631624, 45.19757672718593, 51.2938358443124, 51.33283608300345, 49.45845876421247, 50.94741603306362, 50.71457495008196, 50.567512852805, 47.28372819083077, 49.45098945072719, 49.19277354649135, 53.40425736563546, 52.90523426873343, 52.28494773592268, 52.34646708624703, 51.40372507912772, 51.663612025124685, 51.58117164884295, 52.736959321158274, 56.23115280696324, 54.47198009490967, 52.9275484085083, 54.268206800733296, 52.814393520355225, 53.3743314743042, 53.978345326014924, 56.41339710780552, 56.181372438158306, 56.92575032370431, 58.55219854627337, 56.261721406664165, 52.072579520089285, 66.44251033238002, 61.505440030779155, 57.962480613163535, 1.3342885226011276, 0.21993268706968852, 13.731767433030264, 0.6700277637158121, 0.23146267980337143, 28.533342054912023, 79.25514834267753, 65.22518593924386, 67.45788533346993, 72.19045625414167, 62.39817237854004, 55.177569661821636, 55.490151745932444, 47.28448207037789, 59.193023954119, 80.0757861818586, 24.432530879974365, 0.9451169882501874, 0.22545683064631053, 0.20505997299083642, 0.25841878620641573, 0.2590596489608288], [0.058003595764083524, 0.06441717661385025, 0.05401261902547308, 0.017909394078222767, 0.022121802238481383, 0.0129385050552498, 0.0772882259583899, 0.05671460653788277, 31.75801318032401, 65.28860909598214, 43.829003947121755, 34.6139486176627, 19.221381936754497, 37.374269894191194, 52.165876456669395, 55.30606964656285, 54.26091466631208, 59.675083024161204, 49.38366488048008, 59.45754187447684, 12.749350343431745, 0.4025898357587201, 0.2820952614503247, 4.534403085708618, 0.08443594777158328, 0.05440665788150259, 29.58407470158168, 63.83407320295061, 54.44722713742937, 54.293046610695974, 47.99568230765206, 50.60567235946655, 52.13406760351998, 51.354014192308696, 49.96325234004429, 49.732943875449045, 50.73551334653582, 49.87387418746948, 47.59632069723946, 41.61619029726301, 43.516154357365195, 45.112291063581196, 46.225434167044504, 45.69935131072998, 42.45878096989223, 38.66113880702427, 38.03914301736014, 41.311869621276855, 44.44567046846662, 43.00083426066807, 48.23874419076102, 49.10529572623116, 49.433969838278635, 49.41972255706787, 48.176863534109934, 47.0325334412711, 47.77575445175171, 42.5918459211077, 38.68957083565848, 39.15415866034371, 40.48515558242798, 41.60628564017159, 43.073418617248535, 42.54368795667376, 42.36165904998779, 40.089184692927766, 36.80178001948765, 33.79915073939732, 34.9344481740679, 35.825026580265586, 33.69076926367623, 36.62316962650844, 34.34457738058907, 32.956970010484966, 34.06244577680315, 34.33488811765398, 37.297172682625906, 37.665090220315115, 39.24604163851057, 38.847402640751426, 38.96390656062535, 38.49145337513515, 38.708150318690706, 45.647628920418875, 45.72044256755284, 42.83748211179461, 38.92828662054879, 34.32162053244454, 32.32695252554757, 36.347263608660015, 36.82754046576363, 38.51163789204189, 43.399077211107524, 45.65264899390084, 43.07878262656075, 47.20107242039272, 42.475460120609824, 39.16658203942435, 41.32957015718733, 41.1279855455671, 40.939678941454204, 39.7840302331107, 38.31873505456107, 38.777524607522146, 37.14575406483242, 35.94042226246425, 34.63200003760201, 34.15384585516793, 34.8459142276219, 32.137336186000276, 33.533684389931814, 33.494461808885845, 34.00020381382534, 34.5048827443804, 39.19210624694824, 42.44799736567906, 43.434492179325645, 43.632383823394775, 40.1228243964059, 38.2277067048209, 41.420817375183105, 48.50402293886457, 48.62608889171055, 44.9778607913426, 42.64179652077811, 44.963491916656494, 45.871253217969624, 43.44778060913086, 47.401649543217246, 47.16476460865566, 50.351899828229634, 49.1644526890346, 47.29381350108555, 49.08637925556728, 46.65570136478969, 46.075624057224815, 44.29414415359497, 46.810750416346956, 49.851289067949565, 51.091090883527485, 51.51466349193028, 51.24647692271641, 50.35426916394915, 54.45948028564453, 50.355717863355366, 52.93827295303345, 54.31750774383545, 57.72403928211757, 52.76895577566964, 51.384867668151855, 48.72813361031668, 58.382217815944124, 55.850002425057546, 51.813342230660574, 1.971412603344236, 0.16202033390956266, 2.5800989014761786, 0.17580010449247702, 0.11361061262765101, 25.276102985654557, 70.6801541192191, 58.14574977329799, 57.24408204214913, 66.06325680868966, 46.81155988148281, 41.74729585647583, 30.926956517355784, 24.990945441382273, 45.51049927302769, 55.3509897504534, 5.762534533228193, 0.45062224407281193, 0.11135479581675359, 0.04763359935688121, 0.04793829211433019, 0.048439040780067444, 0.07656922989657947, 0.04516995744779706, 0.02182970309097852, 0.035748098378202746, 0.05637123389169574, 0.06713697567049946, 0.04614270185785634, 0.025014546300683702, 37.100622040884836, 73.03043787819999, 45.47570964268276, 35.84670148577009, 31.567490100860596, 47.74033948353359, 54.6746312550136, 58.87877777644566, 58.8529999596732, 63.75225816454206, 53.475386074611116, 64.69209929874965, 13.680514914648873, 0.5390209992017064, 0.2551852140043463, 3.149736974920545, 0.45509704681379454, 0.037982755074543614, 33.484234060559956, 64.72640255519322, 56.919986792973106, 54.87338100160871, 49.7912357875279, 52.96464484078543, 56.48738500050136, 53.47883932931082, 53.0934852872576, 51.26420872552054, 51.63184486116682, 52.77792590005057, 50.47445910317557, 43.69186387743269, 44.12654318128313, 46.64142976488386, 48.20115443638393, 47.42037146432059, 44.79204511642456, 38.61808429445539, 40.434729031154085, 41.92571169989449, 45.71948371614729, 46.257583481924875, 49.3294689314706, 49.91135971886771, 51.72724710191999, 49.89676850182669, 49.80889116014753, 48.75684009279524, 49.61639131818499, 43.485575335366384, 41.9732790674482, 40.92006070273263, 43.932549476623535, 44.28429855619158, 47.02560608727591, 44.326116289411274, 43.77517277853829, 41.78414562770298, 37.980666978018625, 35.0599639075143, 36.38998113359724, 36.66481018066406, 35.95466954367501, 37.47975744519915, 35.200949805123464, 34.97047110966274, 36.433007853371755, 36.39680079051426, 40.04564380645752, 39.590408257075715, 40.7919602394104, 40.22314943586077, 41.06992639814104, 40.19541917528425, 40.29999998637608, 46.61676713398525, 47.43938520976475, 45.37143802642822, 39.997798510960166, 35.68376622881208, 34.756720202309744, 36.4889269556318, 37.94197940826416, 41.98624440601894, 45.72087682996477, 47.36853095463344, 45.878937925611226, 49.38102456501552, 43.74589306967599, 41.40090036392212, 43.31371511731829, 43.10026298250471, 43.849233627319336, 41.90735455921718, 42.24547127314976, 39.93137373243059, 40.07383264814104, 37.292823110307964, 35.85784639630999, 34.9799519266401, 36.327138151441304, 34.6650630405971, 35.04410464423043, 35.63800539289202, 36.42953027997698, 36.80842249734061, 39.95489338466099, 45.00324603489467, 45.082747323172434, 45.06000934328352, 41.399920667920796, 38.86227873393467, 43.136549949645996, 50.289748191833496, 49.61768020902361, 44.74416160583496, 42.42229945319039, 46.87519495827811, 47.92966399874006, 47.01905741010393, 48.36913408551897, 49.05090175356184, 51.58260645185198, 50.645961488996235, 49.45824684415545, 50.40014117104666, 48.748613425663535, 48.10489409310477, 46.452556882585796, 49.60030623844692, 52.02672140938895, 53.552639620644705, 53.24891301563808, 53.50648621150425, 52.92242063794817, 56.68032257897513, 53.45849847793579, 54.9435578073774, 56.93916382108416, 59.877928733825684, 54.35684149605887, 53.59187262398856, 51.25958469935826, 62.30792917524065, 59.37565040588379, 58.88206427437918, 2.2912394872733524, 0.12251432878630501, 7.834855607577732, 0.13034543714353017, 0.11426000456724848, 28.010095800672257, 75.30131067548479, 63.26169449942452, 64.95469951629639, 71.7159012385777, 51.62281567709786, 46.27103519439697, 45.448649883270264, 31.74426964351109, 51.47088984080723, 66.61081654684884, 9.165165526526314, 0.46845308584826334, 0.14182542184633867, 0.035496755436594994, 0.0470839283162994, 0.06692269431161028, 0.14343877456017903, 0.10048756216253553, 0.1713206877133676, 0.2582913844713143, 0.1277094100202833, 0.1427138548876558, 0.14103167158152374, 0.15080872337732995, 45.06493214198521, 84.65952668871198, 53.30536018099104, 44.073215757097515, 27.643197911126272, 52.6597717830113, 60.39245673588344, 65.91641357966832, 62.122398376464844, 72.00871222359794, 56.61648253032139, 71.68448843274797, 15.921449661254883, 0.4433415633227144, 0.4446745046547481, 9.640264238630023, 0.2660305920456137, 0.11664322311324732, 37.02818012237549, 64.78676155635289, 60.125117846897666, 57.38326488222395, 53.03267117909023, 55.76001630510603, 58.025080408368794, 55.39144216264997, 54.188771520342144, 53.38215862001692, 55.81650863374983, 53.46022163118635, 53.038504191807334, 45.94887154442923, 46.63472127914429, 47.75749111175537, 50.15607527324131, 48.98911142349243, 47.46095936638968, 41.79424483435494, 42.437446526118684, 44.44208867209298, 48.47273520060948, 46.67980466570173, 53.879371711185996, 51.81181362697056, 52.77601514543806, 51.32648195539202, 53.11872461863926, 49.236310958862305, 52.99138150896345, 46.7731328691755, 43.0110376902989, 43.3082468850272, 45.51020744868687, 47.25375713620867, 49.88284778594971, 46.893107414245605, 47.01076126098633, 44.78712926592146, 40.49065855571202, 37.60993889399937, 39.02754858561924, 40.29265921456473, 37.39828634262085, 40.312600544520784, 37.987861837659565, 36.312130042484824, 38.32219178336007, 37.84276955468314, 42.51912954875401, 41.65284204483032, 43.845168931143625, 43.945893492017476, 41.76138680321829, 41.799761704036165, 44.36985867364066, 50.02041516985212, 50.84638227735247, 47.13535288402012, 43.575881072453086, 40.62080178941999, 38.85517072677612, 40.0170693397522, 42.652899742126465, 44.22331074305943, 47.56928525652204, 49.84306934901646, 48.33035618918282, 52.42361293520246, 46.30828101294381, 42.27193348748343, 47.25237791878836, 44.457280908312114, 46.5789133480617, 45.851204190935405, 43.17045715876988, 43.011454582214355, 42.716031074523926, 39.58283124651228, 37.1778894833156, 36.89387491771153, 38.95112534931728, 36.81851128169468, 37.91900518962315, 37.661894048963276, 37.634177684783936, 38.61437048230852, 42.29167331968035, 47.96717037473406, 47.03904390335083, 47.804916041237966, 43.22098445892334, 42.14889478683472, 46.159773690359934, 53.31310394832066, 53.3578051839556, 45.38400731767927, 46.13479144232613, 48.54779658998762, 49.26325954709734, 50.56240245274135, 50.2862879889352, 50.184364863804404, 54.01129020963396, 52.1688676561628, 51.01766926901681, 52.96114642279488, 51.283225945064, 51.86025299344744, 49.56682634353638, 52.070290088653564, 54.97594336100987, 56.4553016935076, 55.688505445207866, 54.50188514164516, 54.87467336654663, 57.89470788410732, 56.38856077194214, 56.373250416346956, 59.07311194283621, 61.4418431690761, 56.887830529894146, 56.84741285869053, 54.9295780318124, 64.30118669782365, 62.015125138419016, 60.37515572139195, 2.8887702354363034, 0.1842874512076378, 8.052103195871625, 0.9929996303149632, 0.16351881064474583, 31.420966488974436, 83.6394408089774, 65.84367983681815, 68.74934700557164, 76.65585504259381, 58.7226448059082, 56.79604482650757, 45.93750776563372, 37.756243637629915, 61.871714319501606, 77.79153115408761, 14.921546561377388, 0.9481904804706573, 0.2643675298563072, 0.35866598412394524, 0.17396606504917145, 0.28246465591447695], [0.03409595042467117, 0.008429497363977134, 0.0707798944786191, 0.037521707492747476, 0.14289653008537634, 0.06008486622678382, 0.06520824666534152, 0.08179576122867209, 25.47311568260193, 62.8962470463344, 47.775810037340435, 34.97675575528826, 22.44996316092355, 32.35365445273263, 54.85847364153181, 63.4994340624128, 53.651658398764475, 59.37751252310616, 52.26898077556065, 55.36581373214722, 28.733634301594325, 0.3204430208674499, 0.340922510517495, 2.7819164948804036, 0.17733264368559631, 0.24179722954119953, 12.99408153125218, 65.62280355181012, 52.62299149377005, 55.529023442949565, 47.59502138410296, 47.696069036211284, 50.6526699747358, 53.86442961011614, 50.80404690333775, 43.73715570994786, 47.68412855693272, 52.43332651683262, 48.29574721200125, 42.41156448636736, 40.73778166089739, 45.92485509599958, 45.145517349243164, 46.68741641725813, 43.42595979145595, 38.09792477743966, 36.676997320992605, 38.30927855627877, 42.62816762924194, 46.6909704208374, 47.33671515328543, 52.04701362337385, 49.129961831229075, 49.188795702798025, 50.52353422982352, 46.80894388471331, 44.30277729034424, 40.75472136906215, 41.811184542519705, 39.891081128801616, 41.48176349912371, 44.04187590735299, 43.091786180223735, 43.16422809873308, 43.693885803222656, 44.45477608272007, 40.34481586728777, 34.2457948412214, 35.64131620952061, 33.72806371961321, 33.113054343632285, 35.41503422600882, 34.59326383045742, 35.294899872371126, 35.64895575387137, 35.39093092509678, 35.41477714266096, 37.035989897591726, 38.43176487513951, 40.71340390614101, 39.384765897478374, 38.45441600254604, 40.65605694907052, 41.8502334186009, 43.030645506722585, 45.31545639038086, 39.93924951553345, 34.612899439675466, 34.66278403145926, 38.36961323874337, 38.31412492479597, 41.3529508454459, 45.42302145276751, 47.0906412260873, 45.82501990454537, 47.58171558380127, 42.489318302699495, 37.65040520259312, 40.04890251159668, 38.53996569769723, 39.36559234346662, 38.69302756445748, 36.04089321408953, 36.18086120060512, 36.289065497262136, 34.885890688214985, 33.886826583317344, 33.89992046356201, 33.183130400521414, 34.01772717067173, 34.80669512067522, 34.95778717313494, 35.96693658828735, 34.90658589771816, 37.10452692849295, 39.00303534099034, 43.134045124053955, 42.75806767599923, 39.22721202032906, 37.908489091055735, 41.14675957815987, 44.21306562423706, 47.13841009140015, 47.600680691855295, 44.031172207423616, 44.131931509290425, 46.555143560682026, 41.89220748628889, 47.278732436043875, 46.931923525674, 46.66709988457816, 46.51441669464111, 46.13756029946463, 44.879345757620676, 41.458632946014404, 39.756379876817974, 39.71251242501395, 44.85966845921108, 47.02823250634329, 50.922201020377024, 51.59121526990618, 55.10687868935721, 51.52185835157122, 53.66325146811349, 51.99775089536394, 56.11602463041033, 54.429015908922466, 58.56715106964111, 50.95117848260062, 51.33380535670689, 46.72988033294678, 59.40905039651053, 55.714033126831055, 56.23588800430298, 3.481652638741902, 0.060240705364516804, 9.595272915703909, 0.2618796133569309, 0.22807958562459263, 29.01090737751552, 70.46115384783063, 54.21704374040876, 52.9375399180821, 62.88581780024937, 53.33461904525757, 47.05678612845284, 28.643455369131907, 26.38621493748256, 44.595960003989084, 48.2929470879691, 2.8865813357489447, 0.3598356970718929, 0.10572961159050465, 0.062436512538364956, 0.07958950461553675, 0.07566549589059182, 0.0740930927651269, 0.030950089051787342, 0.019079405581578612, 0.05157799466646143, 0.1589057631790638, 0.03192227027778115, 0.20833702571690083, 0.059336550666817596, 31.082346030644008, 73.36074829101562, 52.5948234966823, 39.77564375741141, 25.001478910446167, 41.14760725838797, 57.9731183052063, 67.60493700844901, 59.71482672010149, 64.47986657278878, 55.2089581489563, 63.44987951006208, 29.7202559198652, 0.46919703164270943, 0.19319756595151766, 2.4503119800771986, 1.8001594841480255, 0.41236130999667303, 16.067033529281616, 68.89411967141288, 55.410890170506065, 58.63799490247454, 48.82967458452497, 49.506832122802734, 53.03559637069702, 55.01954678126744, 50.90635217939104, 44.51070213317871, 50.86591713769095, 55.52842589787075, 50.98080907549177, 44.38052415847778, 42.96364055361067, 48.41026742117745, 46.62206860951015, 48.3166196005685, 46.80259323120117, 39.47108336857387, 38.1285628591265, 40.01858752114432, 43.311324937003, 48.19600234712873, 48.54936688286917, 53.83937440599714, 51.93403244018555, 50.095115252903526, 53.13607079642159, 48.09404100690569, 45.04497691563198, 42.63967037200928, 43.72408962249756, 40.50531578063965, 44.27272980553763, 44.860401494162424, 46.02977984292166, 45.39240768977574, 46.38679913112095, 44.936206340789795, 42.143878187452046, 36.720423562186106, 38.34278276988438, 36.46205827168056, 36.22256776264736, 35.961791447230745, 36.19149889264788, 36.946319920676096, 36.32300049918038, 37.304145199911936, 38.18217863355364, 38.51397596086775, 40.48695516586304, 41.145022528512136, 41.19588681629726, 39.83881330490112, 43.46930265426636, 43.9620932170323, 43.946268694741384, 45.591515268598286, 39.18912546975272, 37.33241047177996, 37.03919996534075, 40.128629616328645, 39.50346892220633, 42.771495069776265, 46.63238321031843, 48.230072838919504, 47.358782632010325, 48.13730049133301, 44.71617773600987, 40.29747084208897, 43.05562775475638, 40.55032621111189, 42.22633246013096, 40.50116423198155, 39.44336353029524, 39.2348758833749, 37.60659333637783, 36.41608551570347, 34.637833050319124, 36.26645258494786, 35.04541437966483, 36.59491130283901, 35.09818594796317, 36.59052698952811, 36.60235629762922, 36.36192083358765, 38.6687262398856, 41.62904099055699, 45.19904974528721, 45.11753000531878, 41.162215845925466, 38.45022971289498, 40.735162190028596, 47.09780829293387, 47.63385139192854, 49.380072661808555, 47.8938182422093, 45.2036702973502, 46.714580399649485, 44.502788134983604, 47.64847387586321, 50.35443244661604, 48.47103289195469, 49.79417487553188, 48.65682772227696, 47.85750000817435, 43.936697551182334, 40.36537906101772, 42.096574851444785, 47.47986888885498, 48.22164467402867, 53.23979697908674, 53.91385562079293, 56.944187368665425, 51.90664611543928, 56.058490071977886, 53.6347325869969, 57.49885858808245, 57.12148455211094, 60.029573168073384, 53.691026891980854, 54.691029003688264, 48.79771981920515, 62.067320006234304, 59.262686593191965, 60.13081536974226, 4.565435477665492, 0.035508809611201286, 8.338448882102966, 0.34240399673581123, 0.5660103538206646, 31.9738381249564, 74.91358034951347, 59.12554999760219, 59.37670653206961, 70.28184168679374, 54.90254953929356, 54.078896181924, 33.19295515332903, 27.599262714385986, 52.6756032535008, 56.14959832600185, 4.199056965964181, 0.3403589736138071, 0.13886747056884424, 0.1841080601194075, 0.062131667110536776, 0.011655547157196062, 0.16644799203744956, 0.18512546909706934, 0.15461463986762933, 0.1362410243600607, 0.3539056809885161, 0.23177700436541013, 0.3608897333698613, 0.16462878536965164, 35.59040675844465, 81.3598758152553, 60.500737462724956, 47.33116354261126, 29.947111129760742, 46.657674653189524, 65.36811038425991, 74.41563769749233, 62.82205418178013, 69.09782695770264, 61.54482936859131, 65.83130509512765, 35.08677353177752, 0.558144993015698, 0.3704106653375285, 7.683786136763437, 1.800563782453537, 0.3767870217561722, 17.745721782956803, 70.12786265781948, 56.79728160585676, 60.64177199772426, 53.107604026794434, 53.30061108725411, 53.72095625741141, 58.316334996904644, 52.778943811144146, 45.448041915893555, 53.21736124583653, 57.475255557468955, 54.13879312787737, 46.8439211164202, 45.85932316098894, 50.10189322062901, 49.14003324508667, 50.278658866882324, 49.37618167059762, 42.582024642399375, 40.6979580606733, 43.098536355154856, 45.277119704655235, 50.172636304582866, 51.18657302856445, 55.09618888582502, 54.737130301339285, 52.83682230540684, 54.819053036826, 50.33398042406355, 47.6828361919948, 45.37037147794451, 47.391446113586426, 43.19374057224819, 45.79374258858817, 46.79658651351929, 48.98084306716919, 48.45727545874459, 49.47714594432286, 47.22809396471296, 45.15532125745501, 37.68022687094552, 39.9233763558524, 37.93438155310494, 37.53283473423549, 37.13149636132376, 39.398891585213796, 38.39953218187605, 39.82540328162057, 39.738755771092, 40.88793223244803, 41.16739572797503, 41.9317045211792, 43.171072074345176, 44.49638189588274, 41.03264931270054, 47.57922118050711, 44.5859545980181, 47.50923892429897, 47.43405246734619, 42.02074221202305, 40.210983140128, 40.30153553826468, 42.55230719702584, 43.999127115522114, 44.24134826660156, 49.94983189446585, 53.33361850466047, 49.81579072134835, 53.18860960006714, 48.616882528577534, 42.758168424878804, 45.79437834875924, 43.212677887507844, 44.309360708509175, 43.15692206791469, 41.393187863486155, 39.90910823004586, 40.05344663347517, 39.31142766135079, 38.719580105372835, 37.9905994279044, 37.58074256352016, 37.053697381700786, 36.853860242026194, 38.86489125660488, 38.60511548178536, 38.187146595546174, 40.86080993924822, 45.2502440725054, 48.60657835006714, 48.561032908303396, 42.56126689910889, 41.929091998508994, 44.50465372630528, 46.996281215122764, 51.62302759715489, 51.75017615727016, 50.38606064660208, 47.822338649204795, 49.366207531520296, 46.54392916815621, 50.09725877216884, 51.743943623134065, 51.486029965536936, 50.330735615321565, 49.95451845441546, 48.196089199611116, 46.2330459186009, 43.092154434749055, 45.23142835072109, 50.51375116620745, 50.890155928475515, 56.69480609893799, 55.85880579267229, 60.153098242623464, 53.65575436183384, 57.902823380061555, 55.62151091439383, 60.964835439409526, 59.12505667550223, 63.24496323721749, 56.862181254795615, 58.97802584511893, 51.17046363013131, 65.18919427054269, 61.34168488638741, 62.93379511151995, 5.943162509373256, 0.11546656196670872, 18.08465838432312, 1.331186260495867, 0.6118795382125037, 33.90208830152239, 82.03487941196987, 62.486115728105815, 64.49909223828996, 73.3650700705392, 63.564052309308735, 60.92659950256348, 38.61922379902431, 39.57380553654262, 60.63544913700649, 67.72217396327427, 6.954822829791477, 0.5932943554861205, 0.3247341034667832, 0.34170727697866304, 0.2723845839500427, 0.12125123584909098], [0.07122092188469001, 0.13049339848969663, 0.02744132000952959, 0.04503904090129903, 0.03169652506975191, 0.07796572281845979, 0.13100581456507954, 0.26862009880798204, 20.496218306677683, 65.62173352922711, 47.12873819896153, 32.823804310389924, 55.83761726106916, 44.63127422332764, 45.207217352730886, 57.91778979982649, 44.51352310180664, 58.04780796595982, 54.007201194763184, 54.35517740249634, 41.702615465436665, 0.0977967908339841, 0.08848331416291849, 0.051739580995802364, 2.8482583292893002, 0.20869390799530915, 3.245330725397382, 59.4744815826416, 54.137083871024, 56.53660256522042, 48.05049317223685, 47.71182755061558, 50.02305895941598, 52.09698159354073, 48.14409582955496, 45.96193068368094, 55.79360389709473, 51.13936001913888, 49.40329006740025, 40.6397773197719, 41.053566864558626, 44.18772554397583, 43.64583900996617, 45.163739000047954, 38.971202169145855, 36.71849891117641, 37.096658093588694, 41.33534063611712, 45.866014276232036, 48.24350370679583, 48.517540659223286, 48.92348916190011, 49.25593614578247, 47.55699041911534, 48.023273604256765, 48.8778429712568, 42.950011662074495, 38.61124031884329, 41.96719591958182, 38.113460949489046, 41.992834772382466, 41.68854883738926, 42.73508998325893, 44.95397983278547, 44.75169345310756, 43.65407262529646, 40.380175249917166, 37.01415865761893, 35.098151206970215, 34.98807437079293, 35.68806716373989, 36.238447870527, 34.463947432381765, 35.630574294498985, 34.802564416612896, 36.13833475112915, 36.418798787253245, 37.31673533575875, 37.7371187210083, 38.22988843917847, 39.87477718080793, 42.02543919427054, 37.32476050513131, 37.031494413103374, 42.15057972499302, 51.72927597590855, 39.43649523598807, 36.078371797289165, 35.57741362707955, 37.83585262298584, 38.180160181862966, 42.72237130573818, 44.43658569880894, 46.37052297592163, 46.60831465039934, 46.05559934888567, 40.86494411740984, 39.40929651260376, 39.68839175360543, 39.23783581597464, 38.5124716758728, 38.132061277117046, 37.610758781433105, 35.86342232567923, 34.557272161756245, 34.350764751434326, 32.89544023786272, 32.37498194830758, 33.0159706388201, 33.806213583265034, 34.82335690089634, 37.2979474067688, 40.60310125350952, 39.02777440207345, 41.5971348626273, 43.26752001898629, 40.38628271647862, 41.55592509678432, 39.36367464065552, 37.21517351695469, 39.379123960222515, 40.62796885626656, 48.662511348724365, 50.10258109228951, 46.70622866494315, 47.67771189553397, 47.97210359573364, 45.449372495923726, 46.75211109433855, 47.82829325539725, 45.7192440032959, 44.465941837855745, 42.286337103162495, 40.38002586364746, 39.14658164978027, 38.68596124649048, 38.36627810341971, 42.616866384233745, 43.11221040998186, 48.26747499193464, 50.010951723371235, 51.30147191456386, 52.8722859110151, 53.53731884275164, 52.646875926426475, 51.72993605477469, 52.6989665712629, 56.142698764801025, 49.5639636857169, 48.746490750994, 46.02856043406895, 58.145801884787424, 54.072218963078086, 58.14004530225481, 4.246110166822161, 0.37955042347311974, 8.926798888615199, 0.24726310053042003, 0.6094474515744618, 35.976069995335166, 66.32814298357282, 56.01367766516549, 49.52355991091047, 59.473001616341726, 48.77613524028233, 43.13361086164202, 40.838714667728965, 30.198868683406285, 47.62509666170393, 40.39206709180559, 0.548129001898425, 0.1658984872379473, 0.06983664937849555, 0.05025486495079739, 0.04677355961341943, 0.029907591241811003, 0.08914244308003358, 0.022168673741232072, 0.1327581719628402, 0.1270196113203253, 0.04678520327433944, 0.11620213463902473, 0.15333177441997187, 0.21770802858684743, 24.10464538846697, 74.69331550598145, 52.774604661124094, 34.31232731682913, 36.4112217766898, 45.622872488839285, 53.711263520377024, 63.022210938589915, 52.3127509525844, 63.2670932497297, 59.08876623426165, 59.43316759381975, 45.66414131437029, 0.15921875781246594, 0.09266511191214834, 0.7319013093199048, 5.003733490194593, 0.33378084802201813, 3.8523244857788086, 62.925387791224885, 55.877079554966514, 57.29774645396641, 50.42425489425659, 50.1483280318124, 50.6993271282741, 55.148540088108604, 49.19487885066441, 47.36855179922921, 57.88459825515747, 52.276033197130474, 49.636909348624094, 43.337398052215576, 41.562237535204204, 46.934904302869526, 46.18666321890694, 46.80312129429409, 42.575232778276714, 38.32438394001552, 38.40641437258039, 43.63218927383423, 47.22352205004011, 51.19842665536063, 51.054842131478445, 50.902082511356895, 50.09639024734497, 49.65829242978777, 49.95361171449934, 48.95689262662615, 44.644270828792024, 41.4342725617545, 42.33106960569109, 39.896664006369456, 42.50494827542986, 45.23375252314976, 47.37682362965175, 46.7804354258946, 46.3879177910941, 46.976662976401194, 41.032986300332205, 38.820690291268484, 36.94797706604004, 37.32441309520176, 37.23297480174473, 37.18285049710955, 35.84266110828945, 36.87730346407209, 35.69642584664481, 37.269904477255686, 38.06122439248221, 39.189622265951975, 41.24140793936593, 39.843204566410606, 43.131498609270366, 45.05539921351841, 39.54124975204468, 37.76793050765991, 43.018270765032085, 51.60315922328404, 41.010244846343994, 39.59529284068516, 37.31606136049543, 39.94518327713013, 40.697096484048025, 42.56074925831386, 46.381845065525596, 47.98438106264387, 48.4640325818743, 47.38065903527396, 42.65660660607474, 41.30171135493687, 41.593650341033936, 40.244928564344136, 39.864712715148926, 40.433179582868306, 38.78759254728045, 38.39913266045706, 36.660266058785574, 35.76319803510393, 34.745835849217, 34.58039576666695, 35.01754862921578, 35.27799143110003, 36.200826849256245, 37.11021402903965, 42.39211300441197, 40.027852943965364, 43.48123965944563, 43.919111660548616, 42.78071880340576, 43.727098192487446, 42.26708711896624, 38.9933043888637, 42.164476122174946, 43.51634890692574, 50.20493153163365, 50.59048012324742, 50.83130121231079, 50.552070481436594, 49.85140371322632, 47.08751801082066, 48.13640069961548, 48.34153584071568, 48.0070287159511, 47.23470170157296, 44.455172130039756, 43.74160950524466, 41.78189441135952, 42.31105184555054, 40.80565166473389, 44.132702759334016, 45.660441398620605, 51.93949719837734, 52.30065761293684, 53.32357835769653, 55.08588818141392, 56.26878077643258, 53.36867911475045, 53.16206748144967, 54.09131956100464, 59.525814873831614, 52.21141495023455, 50.716353688921245, 49.28312792096819, 61.15004662105015, 56.53632116317749, 61.34827177865164, 5.773441467966352, 0.31499962295804707, 3.6794893486159186, 0.14106215137456143, 1.0589627879006522, 37.64898429598127, 70.49488040379116, 60.378324099949424, 53.397875445229666, 66.73054095676967, 55.667685168130056, 50.94367095402309, 39.708041259220664, 31.81805256434849, 56.02391583578927, 49.50634574890137, 1.123378342815808, 0.23127079010009766, 0.05977745593658515, 0.04148795162992818, 0.01632035497043814, 0.05133133361648236, 0.16962505584316595, 0.16740822765444005, 0.24377931175487383, 0.2434117900473731, 0.11675317292766911, 0.28760322875210215, 0.25367121238793644, 0.33057403724108425, 29.180978434426443, 83.81476470402309, 62.994265283857075, 43.05401924678257, 68.83005033220563, 59.421293122427805, 55.10399866104126, 68.28820896148682, 56.40313809258597, 67.42830685206822, 64.31405476161412, 64.48816967010498, 51.341201714106965, 1.002197959593364, 0.3211379764335496, 5.596763976982661, 8.78846286024366, 0.29985434136220385, 4.5013587559972486, 65.05681024278913, 58.34693486349923, 61.501514298575266, 53.328431674412315, 51.78144652502877, 52.64622974395752, 56.775203704833984, 51.773376192365376, 49.382448945726665, 58.019695554460796, 54.59345545087542, 51.81213671820504, 46.09628105163574, 44.44457612718855, 49.163660594395225, 47.70663377216884, 49.24196679251534, 43.74464586802891, 39.798253195626394, 40.08146524429321, 44.28101205825806, 48.9474778175354, 50.89043385641915, 53.336168493543354, 52.6776008605957, 52.79975019182478, 51.67453459330967, 53.51780135290963, 52.415862219674246, 47.22229221888951, 43.98515428815569, 44.69687564032418, 41.76748732158116, 44.57465335300991, 45.56946168627058, 50.28581551143101, 51.20067439760481, 51.296285084315706, 49.70037766865322, 43.77483926500593, 41.06474304199219, 39.595751421792166, 39.397203172956196, 38.52968583788191, 40.063855034964426, 38.56268630708967, 38.4190913609096, 37.423692430768696, 40.82937976292202, 41.07631526674543, 41.603589739118306, 43.13608094624111, 42.68827302115304, 44.037585394723074, 46.114992550441194, 42.234156131744385, 38.589026927948, 43.208588872637065, 55.69200038909912, 43.63901935304914, 41.29126821245466, 38.43789666039603, 41.270458357674734, 43.202474457877024, 44.31153202056885, 48.56549365179879, 50.15476553780692, 52.308783531188965, 49.493408203125, 45.54486853735787, 44.42126839501517, 42.94752420697893, 43.68802499771118, 43.21830245426723, 43.30914320264544, 41.31647975104195, 39.5659054347447, 39.04885523659842, 38.22826256070818, 36.098181111471995, 35.89498799187796, 36.59554706301008, 36.765698024204795, 37.728836468287874, 39.22408185686384, 44.08631658554077, 43.02755355834961, 47.11098902566092, 47.34333678654262, 44.6928630556379, 45.263331004551475, 44.34886816569737, 40.9156242779323, 44.38473129272461, 44.97688109534127, 54.019756589617046, 53.544423375810894, 51.04612214224679, 53.21099669592721, 50.67737429482596, 48.414054189409526, 51.20131710597447, 50.92140197753906, 50.5201678276062, 48.80479308537075, 47.19248792103359, 44.899280139378135, 43.60140527997698, 43.03911883490426, 43.83645936420986, 46.450559275490896, 47.223980631147114, 54.275981834956575, 55.43166528429304, 55.97252695901053, 57.38385895320347, 55.60767705099923, 57.079496588025776, 54.061483996255056, 56.56711557933262, 61.61340114048549, 55.2664475440979, 53.48187916619437, 50.68025084904262, 62.80737263815743, 59.431736264910015, 64.23233004978725, 7.358171837670462, 0.48718238941260744, 14.866423027856008, 0.42518703320196694, 1.601284344281469, 41.41580424989973, 77.70733288356236, 64.97704492296491, 59.867562021527974, 69.68392140524728, 60.91457217080252, 56.41304622377668, 58.13568183353969, 44.47867093767439, 62.579242433820454, 64.95342799595424, 2.8364922063691274, 0.4708185132060732, 0.2693383688373225, 0.2445335712816034, 0.1882422925638301, 0.14679085968860558], [0.07868504457707916, 0.03504396901865091, 0.06134287015135799, 0.03703071616057839, 0.22191765984254225, 0.03589327773079276, 0.1843757964670658, 0.2850377692707947, 14.372969780649457, 65.79103333609444, 46.486516203199116, 35.83984708786011, 64.57955237797329, 57.11282014846802, 36.874072551727295, 56.60951001303536, 44.93542814254761, 53.20789432525635, 56.93916729518345, 47.6948253086635, 51.42393044063023, 2.040802959884916, 0.21423201582261495, 0.2388409881719521, 3.776610399995531, 0.09954212539430175, 0.07683176866599492, 40.91195215497698, 60.25215176173619, 53.90888071060181, 52.64284249714443, 46.19943053381783, 47.352463245391846, 51.686575821467805, 50.2605379649571, 53.9603842326573, 51.28242342812674, 47.44374173028128, 48.58766187940325, 38.80049535206386, 38.40286731719971, 41.968429224831716, 44.65974794115339, 42.964085238320486, 37.80878244127546, 37.50540672029768, 43.36521863937378, 44.95104421888079, 47.59611225128174, 49.95731857844761, 48.45005975450788, 49.804065636226106, 49.46620600564139, 47.49551623208182, 49.18737827028547, 43.72712598528181, 40.43649387359619, 41.34358467374529, 43.93338673455374, 37.61807523454939, 40.38701922552926, 41.95052024296352, 43.98995549338204, 43.447328976222444, 42.92839581625802, 43.39893477303641, 39.6116350037711, 35.505395548684255, 35.459242139543804, 37.08310215813773, 34.93459408623831, 35.812370436532156, 33.43777840478079, 34.22892461504255, 34.248931952885215, 33.508841105869834, 36.556866441454204, 37.205056939806255, 39.85177516937256, 40.55187913349697, 40.373932293483186, 41.53670637948172, 40.52348184585571, 39.09820829119001, 41.323514802115305, 46.63195242200579, 41.30627284731184, 41.436773913247244, 38.615916456495015, 39.85119152069092, 40.94408062526158, 47.55204677581787, 47.81325387954712, 42.53224427359444, 44.378922598702566, 41.68495314461844, 41.12351437977382, 40.40206554957798, 41.25356033870152, 35.59096261433193, 38.344863755362375, 38.65153987067086, 37.13112810679844, 35.096744196755544, 34.9584333556039, 33.71104410716465, 33.14204570225307, 32.01875128064837, 32.75544793265206, 32.81256212506975, 33.530040059770855, 34.210042885371614, 45.0414958681379, 41.70975126538958, 40.71703086580549, 42.01472159794399, 44.22692033222744, 43.67592818396432, 40.004350662231445, 37.197809968675884, 42.3733354977199, 38.70867143358503, 39.73525735310146, 47.67597484588623, 47.92964315414429, 46.75765575681414, 48.993676389966694, 49.65370314461844, 48.28947646277291, 48.48513078689575, 46.308965410505024, 43.58343376432146, 41.983176776341026, 44.12342691421509, 39.97955254146031, 39.453163964407786, 36.345873968941824, 38.60940599441528, 42.02413988113403, 46.24875579561506, 48.42500455038888, 50.6752724647522, 52.05271462031773, 52.37943281446184, 51.31565318788801, 50.666951996939524, 51.89036648614066, 54.95084299360003, 47.45904861177717, 44.490750380924766, 45.83529281616211, 58.1956204686846, 58.29044600895473, 57.1875445502145, 4.423203246934073, 0.5691793837717601, 5.113968397889819, 0.18435172204460415, 0.380505339375564, 43.74864455631801, 60.777268818446565, 52.96031263896397, 54.25480719975063, 62.468064308166504, 41.78855773380825, 45.19127123696463, 29.054236343928746, 26.78253149986267, 50.100757190159385, 26.91911745071411, 0.21531928676579679, 0.045360313661928685, 0.052674157811062675, 0.025336752046964, 0.020048731871481453, 0.017357422803927745, 0.06064714105533702, 0.009925637394189835, 0.0389163378360016, 0.009059290667729718, 0.14265479519963264, 0.04699669246162687, 0.17319841124117374, 0.25659800533737454, 18.52376021657671, 76.42284720284599, 51.51453495025635, 41.4199002129691, 59.48279162815639, 63.30262633732387, 41.187667097364155, 63.06942394801548, 45.90197467803955, 59.06419045584542, 58.31880855560303, 54.2001804624285, 54.463093348911826, 2.1357781035559515, 0.3145292082003185, 0.7854010814002582, 5.716508362974439, 0.08366798862282719, 0.04442509902375085, 45.233481543404714, 58.13774197442191, 55.94115931647164, 54.37053986958095, 48.15164852142334, 50.201429639543804, 54.39749888011387, 51.93570695604597, 53.73683636529105, 54.349222796303884, 52.22937951769148, 50.23553139822823, 41.19873905181885, 41.57011679240635, 44.54830925805228, 46.33748081752232, 45.95603861127581, 40.673986775534495, 38.79976579121181, 43.73003380639212, 46.0333651133946, 49.16981669834682, 51.22728252410889, 50.630394050053184, 52.08100768498012, 51.29205015727452, 49.687134402138845, 49.73895059313093, 45.37233434404646, 41.80855117525373, 43.07045521054949, 45.11907945360456, 39.56142037255423, 42.741009848458425, 45.440041065216064, 45.48798710959298, 46.83932488305228, 44.63286883490426, 45.798081738608225, 41.59530053819929, 37.09082855497088, 35.55254602432251, 38.16323784419468, 35.04039083208357, 36.67435353142874, 36.81260878699166, 35.09115784508841, 34.11260829653059, 34.88729075023106, 39.086014202662874, 39.79618958064488, 42.228357860020225, 43.03219495500837, 39.95232949938093, 43.052230085645405, 42.14984321594238, 39.56267104830061, 42.70479236330305, 49.9367345401219, 42.34179067611694, 42.83896555219378, 40.03479766845703, 42.4482752936227, 42.93783494404384, 49.339008808135986, 49.65426247460501, 43.55853836877005, 46.62883268083845, 43.45408957345145, 42.71032312938145, 41.34710741043091, 42.80054896218436, 38.81743853432791, 39.1088980947222, 40.37870570591518, 38.44650895254952, 36.070499488285606, 35.20998246329171, 35.28370632444109, 34.99925054822649, 35.32495777947562, 34.176893029894146, 36.27142749513899, 35.75081981931414, 35.557962145124165, 46.122024127415244, 44.41595649719238, 41.0882522719247, 45.61247450964791, 45.221065112522666, 45.74846117837088, 43.22319051197597, 38.329591614859446, 43.23840011869158, 41.04263734817505, 45.01711116518293, 49.61712087903704, 48.42933675221035, 50.27622699737549, 50.21901900427682, 50.27932936804635, 51.13271754128592, 48.90177256720406, 48.2157039642334, 45.306225708552766, 44.93350001743862, 45.71802112034389, 42.10737930025373, 40.831401688711985, 38.84585319246565, 41.96005664552961, 43.433293615068706, 49.548542158944265, 50.00484773090908, 52.69095182418823, 53.004881858825684, 55.42618662970406, 55.102004528045654, 50.945491382053916, 53.38144295556204, 58.03213282993862, 51.42077248437064, 48.84566238948277, 48.51177365439278, 61.29294327327183, 61.53064809526716, 60.355721609933035, 7.101018573556628, 0.42032972670027186, 2.4175861818449835, 0.07549002673476934, 0.948466345667839, 48.355397496904644, 66.41110447474888, 58.253109863826204, 58.52351638248989, 67.34076649802071, 46.80576160975865, 51.97517272404262, 35.59071247918265, 30.699906757899694, 57.57373237609863, 36.07471704483032, 0.05974969028362206, 0.06354738971484558, 0.018905875339571918, 0.04038252987499748, 0.04544595835198249, 0.029048949280487638, 0.2131880218429225, 0.2489109363939081, 0.1419063439326627, 0.07724254698093448, 0.32881044330341475, 0.20127959655863897, 0.22632926383188792, 0.4554443210363388, 20.866131714412145, 88.17763587406704, 59.63994598388672, 49.22062887464251, 71.35031482151577, 68.43569837297711, 47.32415281023298, 64.95397690364292, 53.65234627042498, 60.70972537994385, 64.901962688991, 56.844998359680176, 59.638528551374165, 3.0593450367450714, 0.31316388717719484, 2.503158675772803, 9.247283680098397, 0.1242667268961668, 0.1789436622389725, 47.82669169562203, 60.627993719918386, 58.780419077192036, 58.171562331063406, 51.809895924159456, 53.64939676012312, 55.5035582951137, 52.913196904318674, 56.1373347554888, 55.71472794669015, 52.272639002118794, 51.97481141771589, 43.155028683798655, 42.48945031847273, 46.80615765707833, 48.456167221069336, 47.87317167009626, 41.11963381086077, 41.37319442204067, 46.1855480330331, 47.61013719013759, 50.52516705649239, 53.13812051500593, 51.61561386925833, 54.722525187901084, 52.18645354679653, 52.61225652694702, 52.13776751926967, 46.83043813705444, 42.92439712796892, 44.54358448301043, 48.11857509613037, 43.30026340484619, 43.967297417776926, 46.78263800484793, 46.64752680914742, 49.055758544376914, 48.037645953042166, 48.493760449545725, 44.26448229381016, 40.42766271318708, 38.735220500401084, 41.549640451158794, 37.648925236293245, 40.316126755305696, 38.77061809812273, 39.144344329833984, 37.213280132838655, 36.55964919498989, 41.23689161028181, 42.60350847244263, 43.48867423193795, 45.37401580810547, 44.69508647918701, 46.971312863486155, 43.041578497205464, 40.72462524686541, 45.76828786305019, 49.50244780949184, 43.64653035572597, 43.93232018607003, 43.90642424992153, 44.18204539162772, 44.626240253448486, 51.92614276068551, 52.09972960608346, 44.29377589906965, 48.53840609959194, 44.463575976235525, 44.84246471949986, 43.93945598602295, 45.50981487546648, 41.70798642294747, 44.24178600311279, 43.99750471115112, 41.79402249200003, 38.498641286577495, 37.94698558534895, 37.16950648171561, 37.47333383560181, 37.5669503893171, 38.53369147436959, 38.63787276404244, 38.02898475102016, 37.27986819403512, 49.55725867407662, 46.69913455418178, 45.31466082164219, 46.618761266980854, 48.59301199231829, 49.45016261509487, 45.20851666586739, 40.4240392276219, 46.072632857731406, 43.41932773590088, 46.014629295894075, 51.725721972329275, 51.73014450073242, 51.099981103624614, 52.13718387058803, 52.174169131687705, 52.87985944747925, 51.30747168404715, 51.62497309276036, 46.98926700864519, 47.76823650087629, 47.26781334195818, 43.727612359183176, 43.31213092803955, 41.34440108707973, 43.36997120720999, 45.047818728855674, 51.01728016989571, 52.26263012204851, 54.792646408081055, 56.053258078438894, 56.70664930343628, 56.06565713882446, 52.50575801304409, 54.377085072653635, 59.3344406400408, 51.842302322387695, 49.90243475777762, 50.61449309757778, 61.56914806365967, 64.06709493909563, 60.792311668395996, 9.934413620403834, 0.7683489535536084, 10.719600013324193, 0.3279101087578705, 1.7504837725843703, 52.97908667155674, 72.00172928401402, 62.520391191755024, 65.81019646780831, 70.49679810660226, 53.82062121800014, 59.905971663338796, 41.05431032180786, 38.002077851976665, 67.1779910496303, 47.84026500156948, 0.4476620400590556, 0.2902498138802392, 0.18422592165214674, 0.21399585849472455, 0.1931933726051024, 0.12919454675699982], [0.044264126768601794, 0.03687540288748486, 0.06545186787843704, 0.049593842920980284, 0.13995095528662205, 0.07203771519873824, 0.05585652436794979, 0.1893739668386323, 8.49518895149231, 63.00042833600725, 45.436594758714946, 35.233852999550955, 72.85978317260742, 74.92909567696708, 37.363819803510395, 47.477641991206575, 53.62997307096209, 49.23696061543056, 58.492881774902344, 47.23648738861084, 59.69704627990723, 7.5284435238156995, 1.3247325782264983, 0.25876000789659365, 3.1787105287824358, 0.4515971089048045, 0.1694465468504599, 16.42828253337315, 61.60242298671177, 53.651356152125764, 52.77960041591099, 44.488092694963726, 51.37698493685041, 50.63976716995239, 51.339151995522634, 52.29075642994472, 51.54566982814244, 47.406040804726736, 43.40534796033587, 40.964567388807026, 37.84437458855765, 40.9964804649353, 41.44790492738996, 38.287419523511616, 36.01042883736746, 39.79262515476772, 47.595542498997276, 47.6928277015686, 47.809689453669954, 47.83450494493757, 45.30313376017979, 47.40651675633022, 49.152762344905305, 45.50919301169259, 43.979970932006836, 42.05723067692348, 39.68636982781546, 37.81894418171474, 42.77685907908848, 37.76857321602957, 39.03632068634033, 43.0799047606332, 43.38939142227173, 44.183476720537456, 44.38980695179531, 40.98708650044033, 39.68290615081787, 38.15553229195731, 35.62713493619646, 35.483453137534006, 36.00801433835711, 35.81966951915196, 33.695900508335654, 34.7167889050075, 34.22364745821272, 34.54481404168265, 35.29198510306222, 39.185307434626985, 40.394446849823, 46.435877731868196, 43.891628061022075, 52.79021378925869, 43.342765535627095, 33.46730824879238, 32.364604813711985, 42.011070319584434, 42.51115301677159, 42.204442160470144, 39.87549631936209, 42.14301661082676, 43.933449268341064, 50.02209663391113, 50.089129379817415, 37.659149510519846, 37.464394978114534, 37.919592312404085, 37.317940848214285, 41.78672340938023, 36.61296272277832, 37.06110763549805, 40.64541230882917, 36.29525981630598, 35.53478642872402, 35.69139535086495, 34.263853209359304, 32.8365021433149, 33.4383898462568, 34.531984192984446, 33.883321217128206, 33.151377132960725, 35.76627261298043, 36.81067023958479, 41.559854303087505, 43.01146500451224, 43.61106675011771, 43.22695296151297, 43.36002833502633, 42.63900334494454, 40.04512963976179, 38.23049293245588, 41.04681321552822, 38.25934532710484, 36.44415971211025, 41.656771251133506, 46.656378814152305, 46.62275300707136, 48.293273653302876, 48.80483824866158, 47.51948751722063, 49.87408263342721, 48.94172470910208, 46.15785946164812, 45.46043402808053, 45.31188154220581, 42.928593839917866, 42.75385706765311, 38.603138719286235, 38.381247997283936, 39.136892386845176, 40.85174601418631, 44.561503887176514, 48.012913840157644, 48.47183888299124, 49.91600111552647, 51.951635701315745, 51.55829470498221, 52.07946865899222, 53.59943921225411, 50.115532534463064, 44.71877636228289, 47.37949868610927, 55.93913391658238, 55.7279052053179, 54.15098374230521, 4.605563495840345, 0.5366608915584428, 1.4787400513887405, 0.20085138667907032, 1.3469151364905494, 52.72590126310076, 56.05098949159895, 53.784674712589805, 51.14366095406668, 61.7236134665353, 44.93902383531843, 37.72267689023699, 22.64507552555629, 27.387495517730713, 47.901968479156494, 27.417628117970057, 0.35496699118188446, 0.047924809623509645, 0.04798812033342464, 0.12569874791162355, 0.03383095875116331, 0.029290263474519764, 0.03812593274882861, 0.006815343130646008, 0.09145745528595788, 0.015829791115330796, 0.0710811165294477, 0.10135641946856465, 0.0979906754302127, 0.15892793770347322, 10.81902699811118, 73.71443939208984, 50.32239082881382, 39.17551047461373, 62.7205479485648, 74.22533348628453, 42.19491965430123, 54.35214103971209, 54.55535500390189, 55.8727890423366, 63.669859477451865, 52.12103278296334, 63.3571696962629, 7.995148812021528, 1.568318941763469, 0.42932286698903355, 8.315804702895027, 1.7270541212388446, 0.47120560386351173, 18.512450286320277, 63.57023620605469, 56.78508056913103, 55.11060987200056, 46.8948027747018, 52.738442761557444, 52.967708996364046, 52.24153539112636, 54.10716840199062, 54.39959028788975, 50.74476487295968, 45.442097731998985, 41.18954658508301, 40.32625722885132, 41.92253637313843, 43.709321226392476, 41.11959906986782, 38.52526330947876, 41.457073075430735, 50.16136285236904, 49.8134491784232, 49.81881666183472, 49.24225514275687, 46.44579975945609, 47.94449840273176, 52.01706688744681, 48.6603296143668, 46.12950733729771, 43.33897876739502, 40.68535055433001, 41.66168015343802, 45.198195116860525, 40.62728793280465, 42.39471163068499, 46.19270815168108, 45.784654344831196, 45.13037722451346, 45.318197454724995, 43.30242082050869, 42.65447350910732, 41.494641985212056, 38.98491096496582, 37.0856590952192, 36.45374475206648, 37.454552854810444, 35.91810117449079, 37.005761759621755, 35.03259147916521, 35.051073687417166, 37.68363148825509, 41.64223561968122, 43.58913823536464, 47.9173344203404, 46.61945956093924, 51.482257093702046, 46.23940004621233, 36.166002477918354, 34.1005323273795, 44.50836059025356, 42.69049991880144, 43.70251546587263, 40.75603110449654, 44.336920738220215, 44.220708642687114, 49.35249873570034, 49.162486348833355, 36.69653912952968, 37.97466026033674, 37.53135476793562, 38.59447431564331, 42.92684984207153, 38.70998116901943, 39.69117450714111, 44.087160791669575, 38.222888129098074, 36.465052945273264, 36.10520921434675, 35.89908048084804, 35.156787054879324, 35.02836697442191, 35.112745898110525, 35.50773361751011, 36.54408523014614, 38.723516259874614, 38.14965064185006, 42.78593690054757, 45.36936398914882, 45.156829016549246, 45.19353287560599, 45.067662784031455, 45.74814503533499, 43.407963957105366, 40.006581033979145, 45.10973760059902, 40.58519574574062, 39.89041410173689, 44.29630504335676, 48.85428510393415, 48.10222251074654, 50.32576765332903, 51.78732122693743, 49.23376791817801, 51.45813642229353, 49.289450781685964, 48.75758007594517, 47.84033795765468, 47.749844619206016, 45.58928837094988, 45.476932525634766, 39.95901714052473, 40.314643314906526, 41.82088075365339, 42.5511850629534, 47.28099060058594, 49.89757101876395, 51.12386206218174, 52.61076266424996, 53.20233924048287, 53.79978357042585, 54.597749437604634, 56.45698315756661, 52.50363881247384, 46.23689522062029, 48.21596104758126, 58.63849517277309, 59.00820881979806, 56.5695926121303, 7.276891376291003, 0.5597751598273004, 0.484774078641619, 0.17230397995029176, 2.105598820107324, 60.061361176627024, 61.35934025900704, 59.48976761954171, 55.54017877578735, 69.81588159288678, 50.170423303331646, 46.64553962435041, 22.673808063779557, 29.622678892953054, 57.183399949754985, 35.54724107469831, 0.17350738894726547, 0.00865077187440225, 0.015480272638212358, 0.120327586840306, 0.019859223826123134, 0.024954758883853043, 0.13252077970121587, 0.1177193932235241, 0.12733643289123261, 0.1279254148581198, 0.24153762204306467, 0.15629733886037553, 0.21272352391055652, 0.2685311564377376, 12.457118664469037, 85.19503130231584, 58.932737486703054, 49.72837890897478, 80.31178174700055, 79.98691177368164, 50.15687779017857, 57.07961818150112, 61.857949938092915, 60.329061371939524, 65.89794526781354, 56.88212258475167, 69.73519911084855, 11.08590383189065, 1.8142250265393938, 0.4763857030442783, 13.358330420085363, 1.3100433264459883, 0.47345095766442163, 20.872869729995728, 65.08998094286237, 58.73843111310686, 57.917442389896934, 48.632773058755056, 55.45416007723127, 55.32673706327166, 52.7389360836574, 55.498718874795095, 55.44257395608084, 52.0923228263855, 46.502215657915386, 45.42605781555176, 41.62241588320051, 45.005601474217, 45.16457625797817, 43.37392473220825, 40.25645909990583, 45.66383906773159, 53.114927428109304, 52.38445288794381, 51.32818078994751, 52.4388816016061, 47.41830784933907, 49.615078108651296, 55.36181851795742, 51.09194203785488, 48.65386431557791, 45.72608797890799, 43.15282610484532, 41.69111967086792, 47.14112336294991, 42.405307633536204, 44.36261865070888, 50.20055416652134, 49.069540296282085, 48.14151457377842, 49.40793146405901, 44.864705903189524, 43.736314977918354, 42.11075265066964, 40.2811529976981, 39.34915637969971, 40.601499693734304, 38.49252339771816, 36.63473490306309, 39.25819403784615, 36.10388558251517, 38.85650825500488, 41.128815855298726, 44.54330655506679, 45.59597601209368, 50.278915950230186, 47.20352166039603, 55.02014780044556, 48.004357133592876, 36.444500173841206, 34.95947558539254, 45.40125969478062, 43.81165429524013, 46.66092988422939, 43.31802300044468, 46.86122213091169, 47.40734011786324, 50.10101774760655, 52.00311837877546, 36.05028370448521, 40.0756322315761, 37.01507929393223, 39.90151732308524, 42.1587438583374, 43.74008437565395, 43.32157352992466, 44.31775065830776, 40.70529883248465, 38.6864788872855, 39.19656351634434, 38.15805448804583, 37.832222189222065, 38.15350341796875, 37.73348133904593, 37.82407890047346, 37.752762590135845, 40.84106663295201, 39.77574450629098, 45.28296313967024, 48.19123935699463, 47.32419102532523, 47.62536416734968, 48.43130309241158, 48.539121764046804, 44.74502318246024, 43.03688498905727, 46.31046622140067, 42.30037593841553, 42.362843717847554, 45.50690705435616, 50.57520798274449, 51.152592863355366, 52.613906724112375, 52.63443170275007, 52.23545919145857, 53.0520601272583, 52.788890157427105, 50.980590207236155, 49.51814726420811, 49.36483178819929, 47.40335532597133, 47.99815934044974, 41.278535638536724, 41.92462083271572, 42.889009952545166, 45.60490097318377, 49.83534642628261, 52.72199290139334, 53.77526685169765, 53.78156886781965, 54.75497327532087, 55.56782913208008, 56.18319634028843, 59.50498417445591, 54.78596224103655, 50.63861724308559, 51.94634812218802, 61.60129043034145, 60.28359236036028, 60.53434589930943, 10.765095949172974, 0.5778015011123249, 5.01020747423172, 0.36871970178825514, 3.72326169695173, 65.15832342420305, 66.2209392275129, 65.1818013872419, 60.891643115452354, 70.99683911459786, 55.8838540485927, 51.44636617388044, 34.81905596596854, 39.54405682427542, 65.99044663565499, 48.30759736469814, 0.559090219438076, 0.13097305489437921, 0.1128751892330391, 0.2253947989749057, 0.11399412740554128, 0.1387573443353176], [0.019777840335986445, 0.05938598872827632, 0.030964901471244435, 0.05751475878059864, 0.044895323791674206, 0.06173848320863076, 0.040346380921878984, 0.03360564102019582, 3.571380155427115, 58.81469454084124, 48.09504849570138, 45.796435015542166, 76.9420999799456, 91.02456992013114, 38.74461446489607, 51.155789034707205, 50.71049288340977, 45.300847802843364, 58.45778642381941, 47.25297198976789, 59.75549452645438, 15.076911755970546, 1.0591209679841995, 0.089148353120046, 4.416800481932504, 1.7377307883330753, 0.17969010504228727, 4.076264492103031, 52.783418451036724, 53.43648658479963, 53.179594312395366, 48.565174034663606, 49.62570537839617, 51.82709271567208, 51.90015997205462, 51.67430182865688, 48.505839892796104, 48.38150535311018, 41.82743637902396, 40.06597076143537, 40.57425580705915, 38.13625798906599, 41.490914276668, 38.322935240609304, 37.61269038064139, 42.37672969273159, 47.60955701555525, 47.89734445299421, 47.644499506269185, 45.689519609723774, 44.69482592173985, 49.7528087752206, 47.56492526190621, 47.305917263031006, 47.03581993920462, 45.038508142743794, 39.898995126996724, 38.00206395557949, 41.7938939503261, 38.525395325251985, 38.52067749840872, 42.92611333302089, 41.81759078162057, 44.07688788005284, 44.42745576586042, 44.039961678641184, 43.224743434361045, 37.444752420697895, 36.94008043834141, 35.62231636047363, 33.99987377439226, 35.126527650015696, 35.32726805550711, 34.02316066196987, 35.617025307246614, 35.721241337912424, 37.30030632019043, 42.72490392412458, 45.65825619016375, 46.80906547818865, 46.682045459747314, 38.88867841448103, 35.10324076243809, 35.35665546144758, 35.771379538944785, 37.48822035108294, 39.67264713559832, 45.724865095955984, 40.806412492479595, 45.732848576136995, 41.95564453942435, 44.61428935187203, 45.819860867091585, 39.32137748173305, 35.4683130128043, 36.633939334324424, 39.39387151173183, 39.04166037695748, 42.88128355571202, 42.37439162390572, 40.375433104378835, 38.95337656566075, 34.76781300136021, 33.85723073141915, 33.76340920584542, 34.1673218863351, 34.785669871738975, 33.918232440948486, 35.470032691955566, 35.049281052180696, 32.680720056806294, 34.99956669126238, 37.07122073854719, 41.97235148293631, 43.60509129932949, 42.599082469940186, 43.49906873703003, 43.4226142338344, 42.346883705684114, 37.445488929748535, 42.61212771279471, 38.80410146713257, 37.753603322165354, 41.11258486339024, 42.68348918642317, 46.6123480796814, 46.21366391863142, 49.221955980573384, 49.962105887276785, 51.31125150408064, 49.31611449377877, 48.10942779268537, 49.96074404035296, 47.0822616985866, 45.31632144110543, 41.74009057453701, 40.996157373700825, 39.439090388161794, 38.94947862625122, 38.41167763301304, 38.320750032152446, 42.45385817119053, 45.7797280720302, 50.41015699931553, 54.367444447108674, 52.067854745047434, 54.75698477881295, 50.05849477222988, 49.126939364842, 41.387681416102815, 47.10681663240705, 55.65174947466169, 54.318094866616384, 45.34713670185634, 3.664379187992641, 0.13044971440519604, 0.528433410184724, 0.21724408705319675, 3.5384194212300435, 55.62713548115322, 50.763198443821494, 53.20395817075457, 56.21758992331368, 57.938710825783865, 48.75652394975935, 39.68769345964704, 36.98072392599923, 38.30642979485648, 47.44806350980486, 27.6178526197161, 0.3004665970802307, 0.04481599286996892, 0.025027526675590446, 0.02132897817396692, 0.04930727044120431, 0.026895379215212803, 0.02808872893053506, 0.10457996970840863, 0.0783950522808092, 0.009337471365662557, 0.058084246436400075, 0.07517881664846625, 0.09114716800728015, 0.060854915263397355, 5.269935914448329, 71.65793241773332, 53.837130137852256, 49.05800976072039, 74.469083241054, 85.01986026763916, 42.21479845046997, 52.76819494792393, 56.67144625527518, 48.10575566973005, 63.745997837611604, 50.484506198338096, 67.97080135345459, 16.461934396198817, 1.4513251738888877, 0.06985581799277238, 4.894028382641928, 3.7575432402747015, 0.2257223685405084, 4.691369840076991, 55.239867210388184, 54.13100419725691, 56.03620719909668, 49.521572726113455, 52.418169021606445, 53.865395409720286, 54.039409569331575, 53.49969434738159, 51.28325373785836, 49.66692904063633, 44.02775369371687, 42.48283215931484, 41.84303855895996, 40.67545631953648, 42.28591326304844, 39.91376004900251, 37.536326204027446, 44.253021240234375, 49.63094432013375, 48.240498610905235, 50.28273745945522, 45.74408033915928, 46.87923533575875, 51.21046788351876, 50.31756183079311, 47.69964041028704, 49.00246933528355, 45.62504727499825, 41.64670678547451, 40.959985051836284, 44.564439501081196, 40.57333517074585, 41.67086567197527, 44.80251257760184, 44.71648693084717, 44.955456324986045, 47.19243580954415, 45.17665570122855, 44.464176995413645, 39.84445871625628, 38.3273959841047, 38.34173011779785, 35.40343420846121, 34.041448320661274, 37.17783389772688, 36.2653443472726, 37.92677674974714, 36.52119091578892, 38.9488011768886, 43.618226868765696, 47.52301720210484, 49.20554780960083, 49.08438164847237, 43.783451557159424, 38.17761019298008, 36.368334020887104, 34.60324144363403, 37.090331758771626, 40.139701570783345, 46.67183855601719, 42.66946077346802, 46.88121904645647, 43.89838171005249, 46.214980602264404, 47.1485892023359, 37.79008831296648, 35.925202233450754, 37.109599113464355, 40.19744804927281, 40.29884311131069, 42.55315835135323, 44.083078724997385, 44.37041105542864, 40.85278129577637, 36.27623217446463, 34.56021472385952, 35.64376892362322, 36.19013009752546, 36.08441325596401, 35.14050742558071, 35.68203265326363, 36.961359296526226, 34.14164481844221, 37.59665741239275, 39.03968708855765, 44.47213268280029, 44.74472440992083, 46.265361990247456, 46.808315072740825, 46.2853102684021, 43.7754020690918, 39.90853500366211, 45.010364464351106, 40.20579283578055, 40.013320786612375, 43.215217454092844, 44.089071546282085, 49.82045643670218, 48.90544121606009, 50.5735890524728, 51.12995563234602, 53.60731152125767, 53.1717289515904, 50.18470879963466, 50.959554536002024, 48.04387501307896, 47.63250344140189, 44.30353116989136, 41.607713494982036, 40.48235545839582, 41.711926051548545, 40.16796336855207, 40.958571093423025, 45.44506113869803, 47.9579952784947, 52.13417182649885, 55.22001620701381, 53.841907024383545, 55.92109291894095, 52.811433587755474, 52.034187248774934, 43.09973839351109, 49.635776792253765, 59.88933767591204, 57.35561800003052, 49.56313337598528, 6.012971060616629, 0.4219751741204943, 0.5003656734313283, 0.17510767307664665, 4.442820617130824, 63.19374111720494, 56.38829326629639, 58.93871293749128, 60.95929077693394, 65.2505885532924, 50.864732469831196, 49.42668465205601, 36.25897979736328, 37.22012063435146, 57.394778047289165, 34.169785022735596, 0.20501361547836236, 0.0190340539972697, 0.017999925916748385, 0.03245039443884577, 0.08463279756584338, 0.061250446896467886, 0.0797613300383091, 0.14878891461661883, 0.16929573565721512, 0.212562426126429, 0.0998878525570035, 0.15490172803401947, 0.17079353385737964, 0.2216669682945524, 5.412326216697693, 82.05081163133893, 62.2261141368321, 60.45444161551339, 83.04772526877267, 91.6367826461792, 50.82801818847656, 62.9625050680978, 62.368489674159456, 56.72396074022566, 67.43064144679478, 55.782257488795686, 71.12816701616559, 19.95254782267979, 1.3455495983362198, 0.11328163849455969, 10.933624505996704, 6.570079360689435, 0.22215174085327558, 5.266614675521851, 55.04596035821097, 56.357429368155344, 57.54164212090628, 53.84935201917376, 53.581898484911235, 56.73450115748814, 55.58908714566912, 55.66671242032732, 52.18349014009748, 51.81881741115025, 46.745475564684185, 44.75986106055123, 43.82280962807791, 42.97420528956822, 45.39178235190255, 42.61511196408953, 40.49107197352818, 46.993925775800435, 51.084288597106934, 51.16994251523699, 51.76226602281843, 47.64636857169015, 46.58304752622332, 53.23917511531285, 51.563033376421245, 52.47740241459438, 52.263960702078684, 49.6853278705052, 43.36085169655936, 41.7390170778547, 45.90741164343697, 43.15938173021589, 42.45021731512887, 48.350269726344514, 45.577948910849436, 49.39753001076834, 51.59258753912789, 48.791765213012695, 46.70947347368513, 41.265115192958284, 40.40494557789394, 41.11673641204834, 37.65780850819179, 36.086674894605366, 39.548698220934185, 37.87587424686977, 39.6505240712847, 38.39344903400966, 41.47352293559483, 44.86276388168335, 49.39494528089251, 51.17064428329468, 52.79901020867484, 45.417633124760215, 39.058447224753245, 36.67751496178763, 35.83338526317051, 37.08453696114676, 40.60041924885341, 49.031467642102925, 45.86133466448103, 49.360437052590505, 44.67730951309204, 46.709984166281565, 47.21042469569615, 38.34251873833792, 34.81026996885027, 36.69031354359218, 42.23956877844674, 45.210243293217246, 47.222632680620464, 44.288797514779226, 46.69413185119629, 43.380035672869, 37.22149290357317, 36.82821791512625, 38.62186411448887, 38.75944192068917, 38.06989574432373, 37.59009831292288, 38.635107381003245, 38.92070266178676, 36.3458114351545, 40.17472049168178, 41.70426218850272, 47.02569988795689, 48.26247228894915, 48.97202927725655, 50.13104091371809, 49.19401727403913, 46.16877160753523, 41.44270767484392, 46.971757548195974, 41.8651442527771, 41.20678506578718, 45.52255439758301, 47.11065551212856, 52.01837314878191, 52.27597761154175, 54.390102522713796, 53.091928890773225, 53.07997451509748, 53.80207647596087, 51.709258215767996, 52.49574218477522, 50.860740729740684, 49.26760911941528, 45.83278104237148, 43.82223987579346, 42.31571061270577, 43.801006180899485, 41.811236654009136, 42.5481139591762, 47.875488894326345, 50.174512318202424, 54.36699628829956, 58.80435562133789, 56.1790725844247, 57.60466923032488, 55.18240213394165, 55.23812321254185, 46.38102170399257, 51.166072368621826, 62.59907954079764, 59.5648706981114, 59.038280623299734, 10.75295831475939, 0.4825558662414551, 1.789836849485125, 0.5083097985812596, 7.39701053074428, 66.7656363078526, 60.16685567583357, 63.46681227002825, 69.06806782313755, 66.7260663168771, 58.048148427690776, 55.448160307747976, 50.86577122552054, 51.621137687138145, 64.31509004320417, 43.89553642272949, 0.3895857664091246, 0.12738648163420813, 0.1200597554977451, 0.12724920042923518, 0.16670439685029642, 0.11922620236873627], [0.0424476240628532, 0.06543625478765794, 0.07626303418406419, 0.01781250097389732, 0.03502978424408606, 0.05481292733124324, 0.021132443898490498, 0.036491067082222016, 0.3241653282727514, 44.07437263216291, 54.2399901662554, 34.231328691755024, 55.88945777075631, 77.28032439095634, 39.212287289755686, 45.32016726902553, 56.03430339268276, 43.957587310246055, 54.54372024536133, 49.4980148587908, 58.06981985909598, 29.303680147443497, 1.2902707074369704, 0.3228056255195822, 3.1681907389845168, 5.348437096391406, 0.3284019652221884, 0.09999531893325703, 33.99425268173218, 59.56207057407924, 51.435415812901084, 49.792472566877095, 48.79351963315691, 52.54028013774327, 50.448764664786204, 54.899304730551584, 48.664971011025564, 47.74589456830706, 41.08682094301496, 40.86856760297503, 37.67721135275704, 38.67331552505493, 36.69433307647705, 39.100136416299, 37.01788289206368, 42.65329578944615, 45.16945736748831, 49.856861523219514, 47.82092121669224, 50.68143204280308, 47.638909680502756, 47.801744188581196, 48.58879790987287, 46.76078939437866, 46.6189523424421, 47.71154614857265, 43.361800125667024, 39.76241091319493, 39.577081612178254, 41.02415861402239, 37.27683530535017, 43.11153296061924, 43.01886831011091, 45.10068409783499, 43.860149247305735, 44.55066817147391, 39.276787417275564, 36.9843613079616, 34.27164561407906, 33.399132524217876, 33.1308000428336, 34.72197573525565, 32.60655498504639, 35.248610973358154, 33.674413204193115, 35.53581476211548, 38.67592804772513, 44.867578983306885, 47.79008163724627, 47.09098168781826, 45.88750158037458, 38.01257658004761, 36.20046206883022, 35.341522284916465, 34.76433890206473, 35.3424985068185, 38.108374868120464, 46.88036789212908, 45.28864329201834, 45.37770530155727, 43.73514073235648, 38.09208481652396, 41.02432189668928, 38.93669741494315, 36.04543386186872, 36.58952644893101, 41.409172194344656, 50.84722648348127, 48.415141582489014, 47.46741771697998, 44.496694564819336, 41.00230652945382, 36.80491018295288, 32.64024680001395, 34.21314525604248, 33.904777254377095, 32.729367869240896, 35.121844564165386, 34.96329014641898, 34.07635607038225, 35.01927178246634, 33.115746770586284, 38.36503437587193, 40.92844023023333, 44.02038860321045, 43.95650339126587, 43.16732004710606, 42.35512774331229, 41.554375648498535, 36.0655905859811, 42.138694831303184, 37.88497291292463, 37.524173804691856, 40.925410815647666, 46.724717821393696, 46.76870339257376, 51.275179931095664, 48.088343484061106, 48.472564969744, 51.238291944776265, 43.67030014310564, 48.725194522312705, 49.54299054827009, 50.890385219029014, 45.855515548161094, 42.398981298719136, 38.531117166791645, 39.04351207188198, 38.045090675354004, 37.85862534386771, 37.82711526325771, 39.24545104163033, 40.75877216884068, 40.7828129359654, 47.247743470328196, 50.423021589006694, 54.56105252674648, 51.92343296323504, 46.96903732844761, 43.013177735464915, 48.89189917700631, 55.24670771190098, 52.08453042166573, 29.612781184060232, 2.4776018985680173, 0.43761451063411577, 0.5015074035951069, 0.21039008269352572, 11.36759683064052, 63.87082917349679, 53.59787239347185, 55.83961139406477, 56.997104849134175, 57.930411202566965, 47.17965112413679, 32.451961040496826, 18.17654483658927, 36.46359034946987, 50.596024785723, 12.753471493721008, 0.5843788396034921, 0.16945912688970566, 0.16704088236604417, 0.06635617863919054, 0.0779038607808096, 0.03202152977298413, 0.020006755998890315, 0.0507768212285425, 0.02829719185163932, 0.07729746760534388, 0.04140636797196098, 0.02971006291253226, 0.04233222221955657, 0.07664990092494658, 0.9795503062861306, 54.751672880990164, 59.88655839647566, 41.52067341123308, 65.29628685542515, 80.22103827340263, 45.42929220199585, 52.60533612115042, 63.62446689605713, 47.19387756075178, 63.37734726497105, 52.96730252674648, 64.89053985050747, 30.717141764504568, 1.5763886230332511, 0.4377471778009619, 3.0861492327281406, 7.043767588479178, 0.3913326141025339, 0.16513567816998276, 38.7213762147086, 61.795332772391184, 53.32765695026943, 52.046561990465435, 50.41822733197893, 55.45971168790545, 52.75481619153704, 56.01788132531302, 51.439567361559185, 50.57713263375418, 43.9203553880964, 41.84564413343157, 38.87315613882882, 41.0004027230399, 38.338791029793875, 39.31933123724801, 38.0143518447876, 43.63231086730957, 46.68887901306152, 49.891720635550364, 48.55923332486834, 52.750122683388845, 48.53960118974958, 50.024274894169395, 49.060726506369456, 50.13778414045061, 48.55313975470406, 50.21102510179792, 45.55341134752546, 40.97936705180577, 42.51165328707014, 41.45834459577288, 39.9601913860866, 42.76732267652239, 44.12481655393328, 46.013548851013184, 45.001592363630024, 46.31787647519793, 42.59375320162092, 37.89648607798985, 36.24748747689383, 35.28979294640677, 35.30463777269636, 35.96561295645577, 33.285286290305, 36.373152596609934, 34.34944806780134, 36.20199762071882, 40.507379395621165, 46.48089163643973, 48.614961351667134, 51.109910079411094, 48.89347294398716, 40.26605803625924, 36.09309850420271, 35.39495393208095, 34.176840918404714, 36.656183992113384, 39.60300881522042, 48.18220322472708, 46.7283239364624, 47.70826312473842, 43.278946331569124, 38.33665793282645, 39.749872888837544, 37.830499035971506, 35.143488202776226, 35.347601958683555, 42.12227623803275, 50.631005491529194, 51.268596512930735, 49.75894750867571, 45.33834375653948, 42.50371497017996, 36.34317111968994, 35.64936569758824, 35.410021100725444, 36.11509997504098, 35.84520762307303, 36.86885445458548, 35.92882571901594, 35.32038239070347, 36.09808383669172, 35.94357327052525, 39.488370486668174, 44.38460622514997, 45.75527388708932, 44.99396324157715, 46.0840939113072, 45.136248452322825, 43.66112157276699, 37.7930725642613, 43.14060769762312, 40.05323818751744, 38.770475660051616, 42.62557247706822, 48.61540603637695, 49.05814872469221, 51.51044593538557, 50.45872490746634, 46.97921296528408, 55.75597940172468, 46.762755734579905, 49.91686616625105, 50.90129736491612, 53.94435821260725, 48.63609777178083, 44.88280596051897, 41.04408604758126, 40.278061049325125, 40.46720143726894, 40.30146953037807, 40.31592525754656, 41.3003043447222, 43.05608980996268, 43.04233237675258, 49.75988898958479, 51.88398109163557, 55.884104183741975, 54.01182174682617, 49.820383480616975, 44.78034087589809, 51.365082672664094, 58.08295542853219, 55.89467934199742, 38.59891768864223, 3.0255034012453894, 0.7909305446914264, 0.13813556198562893, 0.17946555066321576, 12.848135488373892, 69.9889612197876, 57.45459508895874, 61.26393454415457, 62.32108211517334, 63.986725125994, 51.022908210754395, 44.50784642355782, 28.192838634763444, 40.01819494792393, 62.49470370156424, 16.459566797528947, 0.4741465374827385, 0.15208469490919793, 0.1355712560138532, 0.029577463599187986, 0.06092598502125059, 0.019672840434525694, 0.17093057078974588, 0.11618576837437493, 0.2043009094361748, 0.09825130751622574, 0.10456071966992957, 0.1071119774132967, 0.14598290090050015, 0.18501554642404827, 1.0434615739754267, 63.38984707423619, 68.86548614501953, 47.47643647875105, 66.09370381491524, 80.73066779545375, 51.17022391727993, 55.637463978358674, 68.31448704855782, 54.256843021937776, 67.00095789773124, 58.554505348205566, 69.51463549477714, 35.02421889986311, 2.44998237490654, 0.6201951205730438, 8.6982969556536, 10.538938164710999, 0.48109240191323416, 0.34565417947513716, 36.65298087256295, 63.879549162728445, 55.748933928353445, 56.91073179244995, 52.46397154671805, 58.370822770254954, 53.86893204280308, 59.953177724565776, 52.90751327787127, 53.48308120455061, 45.0837721824646, 45.081958702632356, 40.1620191846575, 43.267822265625, 40.65020309175764, 43.01867028645107, 41.30171135493687, 45.28346340996878, 48.695035866328645, 51.96308980669294, 51.18253265108381, 56.05914667674473, 49.05090522766113, 51.20473909378052, 51.02122327259609, 51.73063782283238, 50.561770166669575, 51.925899573734824, 47.880137239183696, 43.68205649512154, 44.15805326189314, 45.54513604300362, 42.16631392070225, 46.164929253714426, 47.45539733341762, 50.42606142589024, 50.20983001164028, 49.99265711648123, 42.06679834638323, 40.16510418483189, 38.19541842596871, 37.89835861751011, 37.99558823449271, 38.02967609677996, 35.6648393358503, 38.159065450940815, 35.79579898289272, 37.28314426967076, 41.12271186283657, 48.54692111696516, 52.29843418938773, 53.54123762675694, 54.478744166237966, 42.253930704934255, 36.90881354468209, 35.355620179857524, 33.27035461153303, 36.62552506583077, 40.425091879708425, 48.94621671949114, 50.51321962901524, 49.677306175231934, 46.11200829914638, 38.79703514916556, 40.81174176079886, 39.102147919791086, 35.57672575541905, 36.08447926385062, 44.19319725036621, 52.96848719460623, 50.66043111256191, 51.35444845472063, 49.79782615389143, 44.392495904650005, 39.34348317555019, 37.8959059034075, 37.97264528274536, 37.70972197396414, 36.54467930112566, 39.02326154708862, 40.63387482506888, 37.000359535217285, 38.86694097518921, 38.2599150793893, 44.090134620666504, 45.558226449149, 48.07045534678868, 49.282394886016846, 48.83293676376343, 48.29354463304792, 46.32276800700596, 39.35250541142055, 46.66846520560128, 41.347138677324565, 41.48608527864729, 45.00993367603847, 50.70348909923008, 51.971486704690115, 53.216610840388704, 51.94449642726353, 51.38513169969831, 49.956165177481516, 46.23230593545096, 54.11968558175223, 54.11614547457014, 56.73771817343575, 48.702633721487864, 47.086183956691194, 42.86667844227382, 43.22722046715872, 42.2197698865618, 41.803913252694265, 41.39627981185913, 43.701233523232595, 44.49661466053554, 44.26073374067034, 52.600656509399414, 55.534297125680105, 58.72042138235909, 56.091254302433555, 51.65173060553414, 48.272383894239155, 53.07539217812674, 62.67776788984026, 58.83200250353132, 46.43681921277727, 7.576715265001569, 1.3442070760897227, 1.555955599461283, 0.41366211591022356, 16.655038731438772, 74.39637729099819, 64.33152948107038, 64.49807085309709, 66.1895055770874, 67.19331182752336, 60.60348742348807, 44.99142367499215, 28.525718144008092, 49.69989824295044, 71.81181417192731, 23.699287482670375, 0.8033521867224148, 0.29977959394454956, 0.3433718590864113, 0.22862309217453003, 0.11703403214258806, 0.23890202918222972], [0.04998635168054274, 0.02866606554016471, 0.033589169582618136, 0.10023110306688718, 0.014325014182499476, 0.1255870067647525, 0.03796068911573716, 0.1475502760814769, 0.10679624149841921, 33.50444984436035, 55.08734382901873, 37.67383105414254, 34.124010290418354, 54.78823777607509, 44.81293140138899, 35.57878589630127, 59.91285037994385, 41.391051292419434, 42.90645340510777, 52.38029439108712, 53.902300766536165, 40.69931990759713, 0.4626756044370787, 0.8154173535960061, 1.0214011520147324, 5.035351267882755, 0.2771141358784267, 0.09927343231226717, 12.915760568210057, 62.40095860617501, 49.69642414365496, 53.42239563805716, 50.449417795453755, 54.21504960741316, 50.33529710769653, 53.820562158312114, 46.321920326777864, 46.10135323660714, 43.94600813729422, 41.69903366906302, 36.68636001859392, 37.22341408048357, 35.87656136921474, 38.36265114375523, 37.69295597076416, 38.65917246682303, 41.09413044793265, 45.91710785457066, 46.95222616195679, 48.26030445098877, 48.24696738379342, 47.52213825498308, 46.27349138259888, 48.401842730385916, 48.33165897641863, 48.086050578526084, 48.20106063570295, 43.77752126966204, 39.86377123423985, 45.26543630872454, 37.76756572723389, 41.33606672286987, 43.458418301173616, 44.54052380153111, 44.577394417354036, 42.14791856493269, 39.1390289579119, 39.07033906664167, 34.95350013460432, 33.441929953438894, 34.335464818137034, 34.6193299974714, 34.29078095299857, 37.022937706538606, 34.09251063210623, 37.64784826551165, 39.5985689163208, 40.95988777705601, 46.928616183144705, 46.841398920331685, 44.36140966415405, 41.03903818130493, 34.82742159707205, 37.0516928264073, 36.78292955671038, 37.15082277570452, 35.15859358651297, 45.48448869160244, 49.07274341583252, 45.490068095070974, 39.412114007132395, 36.39271872384207, 37.7441850389753, 36.850507736206055, 37.72102321897234, 38.19667604991368, 39.45683261326381, 43.101569243839805, 45.38984033039638, 50.193515641348704, 46.88071877615792, 45.24159009116036, 37.374846594674246, 32.72092580795288, 33.17636285509382, 34.15758746010916, 33.164950438908164, 34.05723810195923, 34.11014863422939, 35.68248428617205, 37.53637831551688, 37.41952698571341, 38.017864159175325, 42.55373157773699, 42.25565733228411, 43.41899422236851, 42.22195162091936, 45.35445662907192, 40.17726353236607, 37.55629880087716, 40.551010608673096, 37.563722951071604, 44.578586033412385, 47.21382236480713, 44.63553694316319, 46.854002952575684, 47.664023944309776, 46.32337250028338, 50.85678373064314, 29.932728358677455, 40.016871316092356, 52.676982470921104, 47.87286942345755, 49.79943813596453, 46.294488838740754, 39.55895376205444, 38.576589652470176, 37.34968369347708, 37.726387228284565, 37.55802542822701, 38.73064858572823, 38.184832845415386, 40.04575845173427, 38.31863777978079, 40.377121516636436, 44.949574674878804, 48.244796071733745, 44.86932298115322, 45.78861134392874, 41.15339510781424, 49.13369648797171, 50.648455892290386, 53.31223542349679, 28.068580525262014, 1.5653848477772303, 0.5312631183436939, 0.6185770045433725, 0.05727118506495442, 31.330716337476456, 60.19622571127755, 50.749805791037424, 53.64369228907994, 55.50959627968924, 51.274384362357004, 47.88942003250122, 29.999636037009104, 21.84066867828369, 33.81178603853498, 48.96058212007795, 3.801930069923401, 0.6060608561549867, 0.06657504010945559, 0.0585267734048622, 0.019135320259790336, 0.10867762232997588, 0.027301557062725936, 0.04243437566661409, 0.05873415406261172, 0.0216965490752565, 0.06996706380907979, 0.022273205453529954, 0.052029851491429975, 0.026109773066959212, 0.1159058048256806, 0.06111897395125457, 40.70379107339041, 64.88504382542202, 40.142334938049316, 42.27417080742972, 63.37909126281738, 48.49973937443325, 42.0714293207441, 63.56597696031843, 45.23856067657471, 50.41704961231777, 55.47620671136038, 58.38390622820173, 44.53844281605312, 1.461970031261444, 0.9504495135375431, 0.9384009029184068, 8.072067975997925, 0.8864637698446001, 0.041505339089781046, 16.77066891533988, 65.72668606894356, 51.29515252794538, 54.78590318134853, 50.58051988056728, 56.50188589096069, 51.07244886670794, 55.43564312798636, 48.508952685764854, 49.69881432397025, 45.5806621823992, 43.17077677590506, 38.19609587533133, 39.4026575088501, 38.300683634621755, 39.50300339290074, 38.15815871102469, 40.720772470746724, 43.78450768334525, 47.41518463407244, 49.34828117915562, 49.82560505185808, 49.767570223127095, 50.465923241206575, 49.520106656210764, 48.726671014513286, 49.92252547400338, 49.08519458770752, 50.479489598955425, 45.2399503162929, 41.28141219275338, 46.06420121874128, 40.212914739336284, 44.620184898376465, 44.7897834777832, 46.76574345997402, 46.42719595772879, 43.54447521482195, 40.07331848144531, 40.93747288840157, 37.58266026633126, 35.05038234165737, 35.00905098233904, 35.48801462990897, 35.70193576812744, 38.927539689200266, 36.24639660971505, 39.115568365369526, 42.14236348015921, 43.28261498042515, 48.85077626364571, 48.46051679338728, 47.45234707423619, 42.32348912102835, 35.55204227992466, 35.90208557673863, 35.45985358101981, 36.502097266060964, 34.66435432434082, 47.276647976466585, 49.42447859900338, 44.768021719796316, 40.13588700975691, 37.04425130571638, 36.92058031899588, 38.81819936207363, 37.073951380593435, 37.13146162033081, 41.36113929748535, 45.65716879708426, 46.83334248406546, 50.91141741616385, 48.86918204171317, 46.637420654296875, 39.08596209117344, 34.499869619097026, 35.27987091881888, 35.79547241755894, 34.43077325820923, 35.72238779067993, 34.7692825453622, 37.18604319436209, 39.9205310685294, 39.30285358428955, 37.89254992348807, 43.32372399738857, 43.95468296323504, 45.58064481190273, 45.079068252018516, 46.29541989735195, 41.39315659659249, 38.5467506136213, 44.358116218021934, 41.25916406086513, 45.113128321511404, 48.86319269452776, 46.78265537534441, 48.50816059112549, 50.925067152295796, 44.49216086523873, 52.02332026617867, 35.82760088784354, 39.88911131450108, 54.1624413217817, 49.831292152404785, 50.966895307813374, 48.4147629056658, 41.100043364933555, 40.87209728785923, 40.279603549412315, 39.967511313302175, 41.08457667487008, 41.820762634277344, 40.88994721003941, 41.864737783159526, 40.30481161390032, 42.11521339416504, 46.192110606602256, 50.86273833683559, 48.82666948863438, 48.013497488839285, 42.81168692452567, 52.89291858673096, 55.78031894138881, 55.81656074523926, 36.40571880340576, 0.9641945702689034, 0.7201631963253021, 0.37964794252599987, 0.06566580996981689, 34.33038568496704, 67.31210517883301, 55.384077072143555, 58.54811300550188, 62.10803644997733, 56.33602891649519, 51.22351312637329, 41.84030096871512, 24.3162545136043, 38.68118435995919, 58.80544648851667, 6.4167751755033215, 0.6930469827992576, 0.170114700283323, 0.13399447633751801, 0.01901383026103888, 0.08569203144205467, 0.06726212466933898, 0.20080156863800117, 0.15771341430289404, 0.10588942694344691, 0.165228542472635, 0.07510391995310783, 0.17802667644407066, 0.08499512169510126, 0.2182595689914056, 0.1469768597079175, 44.27903182165963, 73.91055924551827, 48.03341102600098, 44.29697901862008, 62.372443199157715, 58.724541664123535, 46.90520422799246, 70.34194360460553, 48.657553809029714, 55.0134254183088, 57.60976225989205, 64.16692665645054, 48.047363008771626, 3.0136463003499165, 1.532650581427983, 3.7626401782035828, 14.661534547805786, 1.3481876339231218, 0.21170748557363236, 16.747903142656597, 66.71569265638078, 53.69234357561384, 58.84203570229666, 55.83238179343087, 57.76374128886631, 53.78777360916138, 59.27428313664028, 49.675735882350374, 51.84123577390398, 49.754062925066265, 45.45903744016375, 40.79790789740426, 42.59388174329485, 40.69000584738595, 43.21484572546822, 42.03413833890642, 43.07749373572213, 45.34667117255074, 50.69703769683838, 51.27838652474539, 50.29315628324236, 52.770949908665244, 50.35386964253017, 50.55732331957136, 51.024812017168315, 52.593152454921174, 50.84684780665806, 52.505490507398335, 47.45333024433681, 44.6516671861921, 51.29932492119925, 42.25115837369646, 45.902912684849326, 48.84759398869106, 49.3758933203561, 48.98268781389509, 46.59654440198626, 44.44477762494768, 45.56182214191982, 40.314830916268484, 36.558266503470286, 36.718450273786274, 38.59265736171177, 36.849118096487864, 41.24363831111363, 38.730891772678916, 42.00066886629377, 44.47945261001587, 45.47681788035801, 51.88410268511091, 50.72278424671718, 49.97295549937657, 44.81181274141584, 35.60879864011492, 36.141433647700715, 37.919550623212544, 36.995026792798726, 35.559101649693076, 47.567860875810894, 52.198487826756065, 45.781402587890625, 40.6040427344186, 38.04057434626988, 38.05044773646763, 37.906335149492534, 37.25385761260986, 37.365525586264475, 40.69443532398769, 44.08680990764073, 46.617430686950684, 54.56452315194266, 48.99963447025844, 50.3443158694676, 41.096041202545166, 36.45784418923514, 37.44296325956072, 37.28535379682268, 36.04664979662214, 38.36082376752581, 37.07195724759783, 40.42742300033569, 41.367451735905235, 43.49365609032767, 39.827581541878835, 47.61738068716866, 45.688772678375244, 47.902691091809956, 47.12784535544259, 49.862197739737375, 43.01945890699114, 40.775729247501914, 47.49577678952898, 43.09153257097517, 47.4159836769104, 51.457969665527344, 47.202927589416504, 50.944643701825825, 51.11564234324864, 47.71909189224243, 49.11952911104475, 34.519539969308035, 41.54955012457711, 56.61875459126064, 53.29005329949515, 54.09028427941458, 51.10344130652291, 43.5219144139971, 43.388119901929585, 42.36689451762608, 42.42401565824236, 43.23389073780605, 43.850640637534006, 42.27012695584978, 44.8778657913208, 42.18750245230538, 44.92778859819685, 47.848203318459646, 52.238957609449116, 51.89896140779768, 50.31444903782436, 46.062804630824495, 54.31345346995762, 58.514122417994905, 60.84051827022007, 45.8965550831386, 2.711578360625676, 1.7199806379420417, 1.270840938602175, 0.15999946663422243, 38.73801020213536, 72.8183649608067, 61.27789347512381, 63.376527377537315, 65.71361650739397, 61.08038398197719, 59.05365003858294, 43.17457396643502, 31.819240706307546, 46.90045166015625, 70.57299900054932, 9.648882610457283, 1.0880646663052695, 0.33401564827987124, 0.276881534074034, 0.13421014190784522, 0.22323451989463397, 0.20197546136166367], [0.11330531258136034, 0.04391110535444958, 0.009334507015799838, 0.08587178215384483, 0.08983249283794846, 0.2517635247537068, 0.0268484924454242, 0.17852910448397907, 0.20318401365407876, 15.151648317064558, 59.601730891636436, 38.932709148951936, 33.0538626398359, 24.800491843904766, 36.8176531791687, 36.931141580854145, 54.151101861681255, 53.78963920048305, 43.626467432294575, 54.398634910583496, 48.81719214575631, 49.207705225263325, 1.970539084502629, 0.3791416739778859, 0.9627624813999448, 6.231325149536133, 0.04586471963141646, 0.24349242714898928, 4.84920642205647, 56.99048668997628, 54.50517511367798, 49.83770186560494, 51.93344531740461, 51.85796703611101, 52.92841693333217, 50.14926951272147, 49.4953293800354, 50.88333279745919, 46.36786528996059, 40.74801288332258, 37.56560243879046, 36.91804770060948, 36.28569214684622, 36.88124656677246, 37.106632232666016, 38.037072454180034, 38.81213705880301, 41.47426291874477, 41.163800035204204, 44.94471788406372, 48.05311611720494, 48.833944252559114, 48.47799498694283, 46.16712488446917, 45.351236139025005, 47.85240350450788, 48.59400905881609, 46.933042185647146, 42.39184897286551, 42.29389326913016, 37.821827684129985, 39.93778691973005, 44.49970660890852, 42.46208483832223, 41.099487509046284, 41.010057244982036, 38.80632489068167, 36.54583270209176, 36.06584072113037, 34.353585720062256, 32.85378926140921, 34.23784957613264, 35.525479316711426, 33.813286849430625, 35.6315644127982, 36.601724011557444, 38.64085701533726, 41.38152183805193, 47.42462723595755, 49.60530546733311, 47.33871276038033, 39.3274050440107, 34.79432037898472, 37.83578314099993, 35.24022797175816, 37.12717110770089, 37.194415773664204, 43.87947218758719, 46.06393371309553, 43.85743250165667, 38.81730304445539, 37.43297869818551, 39.55978754588536, 37.48468024390084, 38.02569825308663, 36.6690798486982, 38.52655567441668, 40.47536557061331, 46.09280347824097, 50.03340482711792, 49.45228181566511, 46.23101009641375, 40.51986183438982, 35.9698200907026, 33.874253817967, 34.86487933567592, 34.41591106142317, 35.036555426461355, 33.71640811647688, 34.580621583121165, 34.92010709217617, 39.9011664390564, 42.14738007954189, 43.378291675022666, 41.76848438807896, 45.13509505135672, 45.23837307521275, 42.726981435503276, 38.45598976952689, 39.54175002234322, 40.053331988198416, 41.53432314736502, 48.65717165810721, 47.227385248456685, 52.918908323560444, 50.206421920231406, 51.40763691493443, 50.81275299617222, 30.63267946243286, 33.17457021985735, 50.48202221734183, 47.15818466459002, 51.526871476854595, 45.29996190752302, 40.252790451049805, 36.232031209128245, 37.204911027635845, 37.26178898130144, 38.310466698237825, 37.32439572470528, 38.30867058890206, 37.9769218989781, 38.689140047345845, 37.26170212881905, 38.8566437448774, 38.70157037462507, 41.18619755336216, 39.90889630998884, 42.99484143938337, 41.45101077216012, 53.32158769880022, 52.0224552154541, 52.37604556764875, 22.436921392168315, 0.5908897359456334, 0.12417478540113994, 0.6901496925524303, 0.8173289224505424, 45.08290018354143, 57.26144559042794, 51.64793688910348, 60.46409961155483, 50.851857457842144, 51.70736830575125, 49.197672026497976, 28.744381427764893, 30.814340114593506, 38.10347638811384, 44.574736731392996, 0.6026964624013219, 0.18740265976105416, 0.047125115391931365, 0.06887968430029494, 0.02309696562588215, 0.01670695877900081, 0.03554157606725182, 0.03609551848577602, 0.06584235799631902, 0.026679635613358448, 0.0692719928920269, 0.055751728026994636, 0.10026635974645615, 0.06804049254528113, 0.23184751772454806, 0.13713753196809972, 21.755275317600795, 68.49523748670305, 44.20130579812186, 32.72437906265259, 38.01109661374773, 50.12067767551967, 39.45651994432722, 63.27830069405692, 55.00737006323678, 49.970391614096506, 60.59123774937221, 51.74858501979283, 54.740611348833355, 3.302865718092237, 0.34546125839863506, 0.5435455249888557, 8.067665423665728, 1.3421664770160402, 0.3901904768177441, 6.020831210272653, 60.9765431540353, 56.33803694588797, 52.776671750204905, 52.99320888519287, 53.77229649680001, 54.06971066338675, 53.31831509726388, 50.321251324244905, 51.30807965142386, 47.84149135862078, 43.6234519141061, 38.27982514245169, 37.58315706253052, 37.83206238065447, 39.51885223388672, 40.0116080556597, 40.527539593832834, 40.82613148008074, 43.669282232012065, 43.4510532106672, 47.181711265019004, 49.54976851599557, 48.70746619360787, 49.89945050648281, 47.556156635284424, 47.10730300630842, 50.1253399167742, 49.27306692940848, 48.96619626453945, 43.42364256722586, 44.73097392490932, 40.467712129865376, 43.503480843135286, 45.965005261557444, 44.709465776171, 44.6511287008013, 43.23606899806431, 41.51342991420201, 38.75510971886771, 37.78520720345633, 35.848240511757986, 34.765047618321006, 35.5490163394383, 37.330013343266074, 37.664301599775044, 36.92620141165597, 38.788877964019775, 39.129072189331055, 43.716126986912315, 49.98927681786673, 49.90640565327236, 49.686859948294504, 38.582843031202046, 33.96929822649275, 36.380441256931846, 34.39387137549264, 36.88821908405849, 37.570275102342876, 44.49799735205514, 47.87979677745274, 45.505246434892925, 38.901827880314414, 37.43985741479056, 37.89927230562483, 38.36935615539551, 37.77864810398647, 36.10617848805019, 38.19760363442557, 40.74526834487915, 44.53378752299717, 52.703361306871685, 50.39208820887974, 47.80900158200945, 43.176210267203196, 37.781455176217214, 34.91298171452114, 36.28829077311924, 34.22179923738752, 35.174042906079976, 35.50201177597046, 34.915285042354036, 38.16984558105469, 42.19498566218785, 43.45790066037859, 45.209600584847585, 42.93498270852225, 47.20013788768223, 45.71719775881086, 44.06485707419259, 39.145640168871196, 42.040568896702354, 41.96747384752546, 44.82733849116734, 51.07224389484951, 48.59642703192574, 54.941838128226145, 49.66470909118652, 49.7326659475054, 51.26960052762713, 36.163615771702354, 36.46715824944632, 53.589006492069785, 49.06909908567156, 53.362554277692524, 46.62016480309622, 41.26472609383719, 38.94239493778774, 38.431445258004324, 40.10496405192784, 38.25687524250576, 39.21014724458967, 38.078928402491975, 40.736294746398926, 41.0070139339992, 40.21842813491821, 40.72441332680838, 41.59102044786726, 43.84107991627285, 43.315118653433665, 45.86651802062988, 44.05813469205584, 54.14973654065813, 53.34529842649187, 57.13874387741089, 28.347370045525686, 0.6257480340344566, 0.9917866268328258, 0.4692101680806705, 1.074454882315227, 48.967582430158345, 61.77161857060024, 58.94907964978899, 66.7081608091082, 56.805091381073, 58.80076340266636, 54.754716191973, 37.20372288567679, 28.394079310553415, 42.923403535570415, 54.952461923871724, 2.0748743202005113, 0.3447789507252829, 0.07833570082272802, 0.08051433427525417, 0.05144958869953241, 0.026113214935841303, 0.04929443595132657, 0.20888156364006655, 0.16836558628295148, 0.11600827718419687, 0.18373509656105722, 0.21635825958635124, 0.38721306515591486, 0.21011902152427606, 0.3949960246682167, 0.4240136018821171, 23.21029758453369, 80.74189608437675, 50.31846857070923, 47.249216488429475, 34.72589104516165, 51.67566367558071, 48.06740856170654, 65.86826256343296, 62.184508323669434, 53.985230990818565, 65.02851717812675, 59.42212690625872, 61.86496761866978, 5.731478256838662, 0.3996585916195597, 2.1042660687650954, 15.555005141666957, 3.706763199397496, 0.3702004280473505, 7.036963565008981, 61.86266081673758, 58.57906028202602, 53.77433579308646, 55.128939219883506, 55.89726059777396, 55.76168039866856, 55.70004987716675, 52.33559315545218, 53.82419259207589, 50.84233842577253, 45.791897841862266, 41.47120223726545, 39.54617255074637, 41.54358162198748, 41.177161421094624, 42.60319232940674, 42.8079765864781, 43.632296970912385, 44.61476877757481, 45.03591993876866, 48.23233100346157, 51.85508005959647, 51.05077396120344, 52.07690824781145, 49.55540003095354, 47.68839127676827, 52.325532163892476, 53.19325794492449, 52.21447910581316, 47.306414059230256, 47.489655426570344, 43.16347769328526, 45.25636543546404, 49.44762652260916, 47.44241809844971, 46.36627762658255, 46.52042688642229, 42.53094148635864, 40.15413645335606, 39.81636020115444, 39.09916366849627, 37.25319753374372, 37.04211820874895, 40.51664481844221, 38.77668040139334, 39.824743202754426, 41.08957937785557, 42.378828048706055, 45.91500949859619, 53.03550951821463, 53.90620912824358, 51.671974182128906, 40.314077036721365, 33.039455550057546, 37.48925910677229, 34.57009506225586, 37.27129411697388, 38.8209855897086, 48.39560324805123, 48.98712771279471, 46.82409790584019, 40.599477767944336, 38.19474445070539, 38.509907790592735, 37.34539318084717, 38.203381061553955, 35.208283628736226, 39.7294590813773, 41.47172335215977, 47.03638621738979, 55.0414058140346, 53.65346493039812, 51.381032262529644, 45.35728801999773, 41.89873531886509, 37.640326840536936, 39.31963348388672, 38.422812121255056, 38.315580572400776, 38.515699114118306, 37.97060251235962, 38.632852690560476, 44.72117001669747, 46.443673610687256, 49.3793500491551, 46.891193185533794, 50.14032718113491, 49.85782037462507, 47.421253885541645, 43.206146580832346, 43.57839632034302, 42.75012935910906, 45.722311632973806, 52.70067582811628, 52.32156821659633, 60.104613712855745, 52.708961554935996, 49.39459439686367, 49.373308590480256, 34.1854566846575, 38.919778551374165, 53.833544867379324, 51.10481357574463, 54.20530475888933, 49.74829939433506, 44.24956798553467, 42.12466641834804, 40.85246515274048, 42.671576499938965, 40.95806040082659, 42.64705283301217, 40.127069745744976, 43.47202287401472, 42.81524092810494, 41.84424407141549, 44.05500452859061, 42.776303223201204, 45.97053255353655, 45.135775974818635, 48.35817330224173, 45.28346340996878, 57.44082375935146, 58.989136014665874, 59.63199724469866, 37.15628405979702, 0.44971525988408495, 1.451217151113919, 1.1793607388223921, 1.1971853652170725, 56.16433892931257, 66.49111992972237, 62.477360997881206, 70.525118964059, 59.86346953255789, 65.09081472669328, 58.96117646353585, 42.02438654218401, 39.79505007607596, 51.35479933874947, 66.74338817596436, 4.024647627558027, 0.5590213345629829, 0.2441985106893948, 0.22938264427440508, 0.10224139876663685, 0.12155303465468542, 0.14870732756597654], [0.007942661210628492, 0.02496461121232382, 0.05093946267983743, 0.03874520451894828, 0.10039088449307851, 0.06471299074058022, 0.047748319272484095, 0.12736988466765198, 0.08453543457601752, 4.181699063096728, 60.86305822644915, 46.88751411437988, 43.626182556152344, 23.81877565383911, 24.928081614630564, 41.466831820351736, 53.402464730399, 57.05851650238037, 39.22967168263027, 54.20303269795009, 44.89398561205183, 52.16180828639439, 10.240894317626953, 0.2619345204106399, 0.6951205315334457, 3.6528851304735457, 1.735415084021432, 0.07940098044595548, 1.1261384061404636, 44.58346366882324, 58.83911745888846, 49.60312373297555, 51.92040007455008, 49.76766749790737, 54.75500801631382, 49.821509088788716, 49.223585333142964, 45.139722551618306, 44.71626458849226, 39.359290327344624, 39.82219321387154, 36.40992593765259, 38.161566802433555, 36.8849812235151, 38.23554079873221, 36.053160258701865, 37.57209553037371, 40.433005877903526, 41.35719966888428, 46.10463626044137, 45.78999750954764, 45.61632381166731, 44.503375257764546, 48.997876576014924, 49.90390430177961, 47.6380272592817, 48.43473202841622, 48.050767626081196, 43.39176423209054, 40.055722168513704, 38.90083428791591, 37.9342634337289, 44.03723103659493, 43.347351346697124, 44.76430095945086, 42.193665504455566, 40.41102525166103, 37.63096761703491, 37.13963965007237, 36.73268365859985, 35.95661503928048, 33.72298458644322, 34.5662179674421, 36.33063309533255, 36.549793175288606, 36.40419019971575, 41.04169239316668, 43.357360226767405, 47.66042825153896, 47.89377307891846, 47.73070928028652, 41.106560775211875, 33.32956715992519, 36.572423458099365, 36.6640111378261, 35.17460918426514, 35.17572437013899, 39.83911207744053, 47.97657128742763, 41.97086456843785, 36.23087780816214, 37.36846120016915, 37.12971414838518, 37.90400750296456, 39.16641180855887, 38.10986178261893, 37.30417646680559, 37.911052976335796, 42.369600840977256, 48.36544459206717, 48.886802673339844, 44.02801077706473, 39.427598067692344, 38.265164443424766, 34.543980257851736, 33.276052134377615, 35.79982198987688, 33.74633400780814, 34.313949721200125, 32.24924734660557, 34.48187378474644, 39.520922797066824, 45.94646051951817, 43.9100581577846, 42.8202714238848, 42.67768396650042, 44.56627035140991, 42.80643061229161, 36.614612919943674, 39.767246859414236, 42.02141618728638, 44.79232999256679, 49.31765699386597, 44.31819534301758, 38.95458902631487, 49.29236207689558, 46.25918851579939, 32.742228984832764, 37.76305634634835, 49.80339513506208, 48.34409277779715, 49.273740904671804, 42.72764498846871, 37.62667710440499, 37.75798068727766, 37.8585558618818, 36.39125960213797, 36.39835371289934, 37.90654012135097, 40.30295991897583, 39.20135429927281, 37.74625212805611, 37.337579931531636, 38.25930711201259, 39.17800835200718, 38.440088817051475, 39.460803508758545, 40.1136006627764, 42.07484088625227, 47.343364579336985, 53.173900263650076, 49.72866725921631, 52.46564606257847, 12.484816789627075, 0.7900787932532174, 0.8884557858109474, 1.0484822988510132, 3.539445149047034, 55.72982290812901, 53.471783433641704, 43.50642687933785, 48.65950972693307, 47.130159105573384, 51.213511194501606, 45.4429349899292, 27.349671261651174, 29.521172659737722, 39.262706892830984, 41.86736420222691, 0.29663651117256706, 0.22788324473159655, 0.06311202807618038, 0.053029621951282024, 0.04161822356815849, 0.03594627470842429, 0.013852431505386318, 0.05603591884885516, 0.011645797457146858, 0.040556808201862235, 0.029051242728850672, 0.023995668294706514, 0.07909048960677215, 0.06905944179743528, 0.16976017930677959, 0.18288136380059378, 6.063360265323094, 72.16165597098214, 51.44834641047886, 43.97587149483817, 27.798929623195104, 37.433774266924175, 44.34104101998465, 58.688661166599815, 63.04432010650635, 43.844946588788716, 60.25629983629499, 51.070423466818674, 57.03994049344744, 13.009199074336461, 0.2715437704963343, 0.4323272300618035, 8.38994198186057, 3.832348414829799, 0.05652058623465044, 1.5982539526053836, 49.46705715996878, 58.137286867414204, 51.347583634512766, 53.83272497994559, 51.9514342035566, 55.66404431206839, 52.00755132947649, 50.27138410295759, 47.002774306706016, 45.65428876876831, 42.05648374557495, 40.83886752809797, 38.43022237505232, 39.70112432752337, 38.55420255661011, 40.100485937935964, 39.681349754333496, 39.05904129573277, 42.04305982589722, 43.42783580507551, 46.86039876937866, 46.97154215403965, 48.29381908689226, 47.670061928885325, 50.1059752873012, 49.73840168544224, 49.044502462659565, 48.23319605418614, 50.867671557835166, 43.701584407261436, 42.21654939651489, 40.1860008920942, 39.076446533203125, 44.425614493233816, 44.90053081512451, 47.31164605276925, 44.452403272901265, 42.08547510419573, 38.63559028080532, 38.17947578430176, 38.21101713180542, 37.37024341310774, 36.90870932170323, 35.854841300419395, 37.090269224984304, 39.15015302385603, 40.0063864844186, 41.15370430265154, 46.987526484898154, 47.9453113419669, 49.522663593292236, 50.296133586338584, 41.65852219717843, 32.244286332811626, 35.54669911520821, 36.346662589481895, 34.534280572618755, 35.06012371608189, 42.0065644127982, 50.924087456294465, 41.88605833053589, 36.90357460294451, 38.56011547361101, 37.61559820175171, 38.55546365465437, 37.75174815314156, 36.97986582347325, 37.68709863935198, 38.99728570665632, 44.91674096243722, 50.580436502184185, 50.74020338058472, 46.732485907418386, 41.91074875422886, 40.04880176271711, 36.558110169001985, 35.50387041909354, 36.851688929966514, 36.01107849393572, 35.09545530591692, 35.70448228291103, 36.52081918716431, 41.22360665457589, 48.65013313293457, 45.292600291115896, 45.78565835952759, 45.589180673871724, 46.53692190987723, 43.80577611923218, 39.989015987941194, 41.246424538748606, 43.93086453846523, 45.88527815682547, 50.3741340637207, 48.26336513246809, 39.322631631578716, 48.34753213609968, 49.344178267887656, 36.671011447906494, 40.199042660849436, 51.66733973366873, 49.988620213099885, 50.47574799401419, 45.09575087683541, 38.27773373467581, 40.451279640197754, 38.797771658216206, 37.62065649032593, 37.78532532283238, 39.53598996571132, 41.41514417103359, 40.01038517270769, 40.33866671153477, 40.04485866001674, 39.71188708714077, 41.905176298958914, 41.45215375082833, 41.60924557277134, 41.67879704066685, 45.247801780700684, 50.15351138796125, 56.98222875595093, 52.861658641270225, 58.367306981767925, 14.266435657228742, 0.7089176454714367, 2.590901178973062, 1.1824679949453898, 4.050784145082746, 61.887146268572124, 57.60158423015049, 53.78331633976528, 59.81729875292097, 52.69112205505371, 55.316102845328196, 50.84162276131766, 31.829141889299663, 25.74859091213771, 45.53514105933053, 50.069771698543, 1.0972634298460824, 0.3133527370435851, 0.09239881405872957, 0.10391232517680951, 0.06120905626033034, 0.05764252013925995, 0.008476160217209585, 0.1254817931247609, 0.128665832270469, 0.197567969294531, 0.13324929560933793, 0.21264203185481684, 0.18132382737738745, 0.14309008898479597, 0.1983978854758399, 0.25953057940517155, 5.881480744906834, 84.50146906716483, 61.276121684483115, 56.23107985087803, 32.45240225110735, 36.99598217010498, 53.37066282544817, 63.90765462602888, 68.17926815577916, 47.57913780212402, 65.4106889452253, 55.28525979178292, 62.048413957868306, 17.505267211369105, 0.38618323898741175, 2.689784901482718, 14.15401554107666, 5.737387265477862, 0.144899185480816, 2.1873967051506042, 51.73809323992048, 61.231507301330566, 54.245051928928916, 56.54948105130877, 54.73823159081595, 57.9922536441258, 53.427082198006765, 53.35233347756522, 50.028374331338064, 49.20946659360613, 45.284974643162315, 43.63745253426688, 40.50030960355486, 41.6870619228908, 39.578908988407676, 41.44874218532017, 40.5638439314706, 41.270750182015554, 44.79084307806832, 45.71576642990112, 49.64737333570208, 49.39376756123134, 51.11683048520769, 48.499454498291016, 51.06200572422573, 51.618410519191194, 51.51708493913923, 50.551813398088726, 52.64321422576904, 46.21268769672939, 44.99111100605556, 42.635723795209614, 40.76834678649902, 46.502052375248496, 46.74855709075928, 50.89181307383946, 47.560957840510774, 44.883382661002024, 40.28068052019392, 40.60584231785366, 40.648330552237375, 39.22671869822911, 39.19523641041347, 37.612259592328755, 39.03958286557879, 40.794100284576416, 42.08683695111956, 45.40472337177822, 50.12309217453003, 51.89132186344692, 51.3064398765564, 53.35646765572684, 43.278699670519146, 32.62055213110787, 36.0674283845084, 37.25775555201939, 34.80424588067191, 34.769748074667795, 43.56859936032976, 53.37775693620954, 44.705560888562886, 38.26463290623256, 38.276441369737896, 37.740346159253804, 38.501170430864605, 38.879096848624094, 38.20315524509975, 39.26302650996617, 38.34846639633179, 45.806152071271626, 52.68578583853585, 51.472623416355674, 49.23575510297503, 43.84916067123413, 42.91094194139753, 38.7818672316415, 37.00919416972569, 39.916455950055806, 37.448181356702534, 37.38519246237618, 36.69709498541695, 36.27453681400844, 43.24630716868809, 51.40622295652117, 47.651145458221436, 48.07518359592983, 49.26480899538313, 48.47143588747297, 47.18959747041975, 41.18703828539167, 42.946815490722656, 46.502292088099885, 48.975899423871724, 52.303509848458425, 49.95864915847778, 39.03149863651821, 48.24685621261597, 49.88233361925398, 37.73317214420864, 43.6138460295541, 53.31184632437569, 53.71597439902169, 53.11595923560006, 46.811660630362375, 42.06829220908028, 42.55020884105137, 40.95652484893799, 39.0925281388419, 38.81624691826956, 41.73799221856253, 44.29625988006592, 42.46855361121041, 42.273215430123464, 41.62986782618931, 43.341031960078645, 42.9969675881522, 43.80288566861834, 42.649700096675325, 44.26449966430664, 46.85492706298828, 52.852869170052664, 58.32026767730713, 56.332002435411724, 61.017058100019185, 20.283301183155604, 0.7778414956160954, 5.317262700625828, 2.3132726592676978, 4.703918286732264, 64.48325729370117, 62.796811376299175, 53.78027302878243, 59.986473492213655, 58.6623135975429, 58.50297750745501, 56.63289417539324, 43.229152066367014, 40.61314834867205, 52.76382800510952, 62.634140150887625, 2.6446211763790677, 0.5777697999562535, 0.2363404237798282, 0.2588112237198012, 0.08148206770420074, 0.18853565039379255, 0.07432400501732316], [0.03808161423408559, 0.017042669068489755, 0.10677554618035044, 0.061327657396239896, 0.016957699520779506, 0.028219192554908137, 0.03771781089848705, 0.040520123206079006, 0.04805386019870639, 0.09741669587258782, 39.482954365866526, 51.69888455527169, 37.80030563899449, 37.92255571910313, 29.830377919333323, 40.61531966073172, 52.65506437846592, 57.745033264160156, 52.00855187007359, 56.77606528145926, 47.194746085575645, 53.913285868508474, 31.19099153791155, 0.15063975458698614, 1.0860955033983504, 3.415616742202214, 0.2905299131359373, 0.16496890783309937, 0.4015132449567318, 35.30858087539673, 58.71384143829346, 51.15396165847778, 53.55944538116455, 52.08234521320888, 54.513651915958945, 48.61937345777239, 50.16840485164097, 44.366916111537385, 45.89844846725464, 38.492554664611816, 38.982770919799805, 35.44821187428066, 37.94497060775757, 35.66881023134504, 36.77641214643206, 35.255479267665315, 36.88040236064366, 37.61296483448574, 38.012882300785606, 42.265138149261475, 44.252788475581575, 43.067776679992676, 46.84457772118704, 48.086345876966206, 47.36947590964181, 48.01964317049299, 48.85553577968052, 46.98893002101353, 43.3632036617824, 39.91048744746617, 38.28472709655762, 36.18269899913243, 43.188720498766216, 43.7864670753479, 41.83897386278425, 40.862821442740305, 40.01778500420706, 38.16048983165196, 38.23558248792376, 34.773177010672434, 36.28731802531651, 36.5105219568525, 33.228477818625315, 35.845297949654714, 38.7125381061009, 43.511651924678254, 42.824565410614014, 43.33959368297032, 47.51682983125959, 46.29845973423549, 51.857796805245535, 43.403503213609966, 35.71224342073713, 36.71898528507778, 34.080361706869944, 35.00130721500942, 36.998181274959016, 38.535042898995535, 47.476912430354524, 41.45637130737305, 37.40941040856497, 36.136159964970176, 37.030431338718955, 36.81976195744106, 37.84017787660871, 37.03987741470337, 36.563606194087434, 38.70361661911011, 47.18889570236206, 48.84454720360892, 49.10844326019287, 44.08208860669817, 39.21679319654192, 39.12559461593628, 37.141925607408794, 35.08058616093227, 33.64806563513619, 33.62224612917219, 33.619341782161165, 33.273283277239116, 34.212975025177, 35.469070366450715, 39.35618795667376, 44.142058508736746, 40.896714755467, 43.90336356844221, 43.89054066794259, 40.75803913388933, 36.554500579833984, 39.30653265544346, 42.19216121946062, 45.77680288042341, 47.604074886866975, 42.49852466583252, 34.714033944266184, 39.00396292550223, 40.635243620191304, 46.04452044623238, 48.98400797162737, 44.835850034441265, 46.15308952331543, 38.036103180476594, 36.487665857587544, 37.127984046936035, 37.28917530604771, 36.23425463267735, 35.780203751155305, 35.99572992324829, 38.781690052577424, 37.11333377020699, 38.59910529000418, 37.36318056924002, 36.82259682246617, 38.217333044324604, 38.79641328539167, 39.929935455322266, 40.414037295750205, 40.72418751035418, 46.5902111189706, 49.98732784816197, 55.59453105926514, 49.906443868364605, 51.952802998679026, 4.252830377646855, 0.08080613147467375, 3.895701221057347, 1.1548008109842027, 14.248549257005964, 56.55250699179513, 50.494025230407715, 42.43098817552839, 44.6860989843096, 54.4066982950483, 51.46792296000889, 39.73410047803606, 26.192144802638463, 26.46207536969866, 39.813209193093435, 39.385950565338135, 0.21624844547893318, 0.14274923370352813, 0.06097591841327293, 0.01016269632548626, 0.04474714870697685, 0.07115314302167722, 0.03758575102048261, 0.05440216597967914, 0.01588707643428019, 0.05845518796039479, 0.039551253230976205, 0.010245945786924233, 0.00048728674300946295, 0.053340804896184375, 0.030945617506014447, 0.03320396525253143, 0.25563356280326843, 47.80328321456909, 58.29777635846819, 41.78246416364397, 36.26839460645403, 37.64118146896362, 46.26851299830845, 58.96834005628313, 64.52042320796421, 50.1235750743321, 60.55311298370361, 52.77038015638079, 56.74264097213745, 36.28883968080793, 0.06943619158118963, 0.6284515889627593, 5.394914465291159, 5.502947228295462, 0.33328448608517647, 0.615662235234465, 40.805728094918386, 60.9090553011213, 54.44478137152535, 55.27607079914638, 54.795314516339985, 55.22000578471592, 50.31065879549299, 51.05255617414202, 48.63006673540388, 47.2156115259443, 42.086645875658306, 40.37964718682425, 37.39645201819283, 38.590267181396484, 37.52705035890852, 37.46366889136178, 36.82039424351284, 37.45946523121425, 38.962430068424766, 42.06457839693342, 43.80159330368042, 45.45348582948957, 46.846724714551655, 48.65202651705061, 50.658951146262034, 49.35694210869925, 49.63675648825509, 49.64332948412214, 48.96085657392229, 44.647581645420615, 42.86941950661795, 39.60792466572353, 39.87053530556815, 43.39420304979597, 45.34311716897147, 44.83731957844326, 42.61799199240548, 41.9449269430978, 39.77131502968924, 40.32523931775774, 38.2991862978254, 37.88342693873814, 37.90625524520874, 36.962807995932444, 38.76575435910906, 40.22852039337158, 44.489440645490376, 44.09082249232701, 45.977362632751465, 47.93519129071917, 49.67711509977068, 53.14287655694144, 44.67098317827497, 34.25350734165737, 34.69892856052944, 33.984577315194265, 34.671604769570486, 36.097065925598145, 40.59766776221139, 50.75491966520037, 41.947685377938406, 36.054577691214426, 36.062654972076416, 36.81591612952096, 37.159619195120676, 37.85614831107003, 36.57913194383894, 37.3612003326416, 39.17134502955845, 48.032327107020784, 51.11450283867972, 52.99577971867153, 48.72411755153111, 41.41944510596139, 40.377878870282856, 39.08009781156267, 37.49944864000593, 36.76570497240339, 35.92992353439331, 34.63987234660557, 33.90349531173706, 35.951254504067556, 39.14376762935093, 43.052650451660156, 45.818808215005056, 43.43105976922171, 46.02904680797032, 44.59660618645804, 41.97613477706909, 38.47170312064034, 41.419403416769846, 43.83605636869158, 47.21235629490444, 48.136268683842246, 44.781233719417024, 35.304109709603445, 43.211830207279746, 43.85674810409546, 47.52048110961914, 51.27427666527884, 47.34499045780727, 47.9124185698373, 40.52388136727469, 38.42152670451573, 39.21613311767578, 39.043911593300955, 38.503230571746826, 37.45628643035889, 38.637963090624126, 39.71221712657383, 38.02104990822928, 40.48717056001936, 38.00050408499581, 39.03713015147618, 40.192671162741526, 42.2644294330052, 40.97912386485508, 42.8406400680542, 43.17688076836722, 50.66860914230347, 53.00073031016758, 58.961780956813264, 54.207576819828574, 56.47435712814331, 4.911507444722312, 0.045408842486462424, 8.282958831105914, 1.4801304510661533, 16.424742426191056, 61.14464092254639, 56.50150721413748, 44.830670152391704, 45.085783685956685, 56.1608544077192, 52.55530561719622, 47.972628184727256, 33.48145825522286, 27.695121799196514, 47.795094762529644, 47.10762957164219, 0.6353627124003002, 0.12333379552832671, 0.008347330165893903, 0.045306621185903034, 0.057456906884908676, 0.05084694103736963, 0.044391450472176075, 0.08198656527591602, 0.1333575490862131, 0.24065308379275457, 0.1230316303138222, 0.08778936282864638, 0.1789209313158478, 0.17221458974693502, 0.07743371743708849, 0.2233263799654586, 0.2739955889327185, 53.853920459747314, 68.8914793559483, 51.851109164101736, 48.80712073189871, 43.02684831619263, 51.505502292088096, 60.00466387612479, 68.72426400865827, 61.49681036812918, 66.64145115443638, 56.714997564043315, 62.98883179255894, 40.41569791521345, 0.6534996820347649, 2.2853862813540866, 14.076378975595746, 5.642655091626303, 0.3998122662305832, 1.091368426169668, 41.78087650026594, 62.36243779318673, 56.94270045416695, 56.49656009674072, 56.62189170292446, 56.9505866595677, 53.21386282784598, 53.60157925742013, 49.87648671013968, 49.58495766775948, 44.19027553285871, 43.33612305777413, 40.080693994249614, 41.48172180993216, 39.39909308297293, 39.66360752923148, 38.45773376737322, 40.11164127077375, 40.45495523725237, 43.203033787863596, 47.05509076799665, 47.83028391429356, 50.02224949428013, 52.394885608128135, 54.293109144483296, 52.19175154822213, 51.36673981802804, 51.12675598689488, 51.04032734462193, 46.22284248897007, 43.58146742412022, 41.81460305622646, 40.86884553091866, 46.05632196153913, 48.82956688744681, 46.661002840314595, 46.85217557634626, 42.53021887370518, 41.888997418539866, 42.95384706769671, 39.83730207170759, 39.29464428765433, 41.03582811355591, 38.389950616019114, 41.260529381888254, 42.43010228020804, 46.56028175354004, 48.021790163857595, 48.963635853358674, 51.100429262433735, 51.61126429694039, 57.405978543417795, 46.27860178266253, 35.3885372706822, 36.78863055365426, 34.33650704792568, 35.8761305809021, 36.098163740975515, 40.89114924839565, 52.7674480165754, 43.84060049057007, 36.825570651463096, 35.56134244373867, 37.13304580960955, 37.02689470563616, 37.59172766549246, 36.58037567138672, 36.569762298039024, 39.76070165634155, 49.6976192338126, 54.20043407167707, 53.396649088178364, 51.48991748264858, 43.46876764297485, 43.18839045933315, 40.767558165958945, 38.88068798610142, 39.586934157780235, 39.10637589863369, 36.87181438718523, 36.60231460843767, 38.9760103225708, 40.69710690634591, 45.57461724962507, 49.00130203792027, 45.67164536884853, 49.18747901916504, 48.20304434640067, 44.239969049181255, 40.21902915409633, 43.76184613364083, 46.41810423987252, 49.815530163901194, 48.99747705459595, 46.842152799878804, 35.70024388177054, 45.88822071892874, 48.914876869746614, 50.3288700239999, 51.33763034003121, 48.313353947230745, 49.42267206736973, 43.01974378313337, 41.74069159371512, 41.45468289511544, 40.68313407897949, 40.38924264907837, 39.97713456835066, 40.89056212561471, 42.1702743938991, 40.25999573298863, 42.899032729012625, 40.535460540226524, 40.92863825389317, 43.19000244140625, 43.460374219076975, 42.80775424412319, 43.98656824656895, 45.2930588722229, 52.09946557453701, 57.25938892364502, 64.0805674961635, 55.884184088025776, 60.54607445853097, 6.186400268759046, 0.13223388152463095, 13.095406242779323, 2.136556301798139, 18.366772617612565, 67.29226807185582, 59.58490930284773, 53.19691617148263, 55.61392000743321, 63.29209286825997, 59.488461358206614, 52.091238907405305, 41.43583938053676, 39.591092654636924, 56.075544425419395, 56.98119347436087, 1.5615049302577972, 0.3285764844289848, 0.2884167108152594, 0.07938054975654397, 0.1370081217693431, 0.13841183430382184, 0.18333397379943303], [0.012700139944042479, 0.05397210030683449, 0.05848769657313824, 0.061890488623508384, 0.04920273533623133, 0.016503674776426384, 0.12168302839355809, 0.11539608931967191, 0.164519676938653, 0.23616272902914456, 17.13134295599801, 61.32687132699149, 38.20099435533796, 35.883905615125386, 27.364641155515397, 35.57283476420811, 42.95193978718349, 53.698065417153494, 55.926140785217285, 50.9469644001552, 49.89344031470162, 46.959737164633616, 50.10499211720058, 5.4802340013640265, 0.39695395103522707, 3.8890491894313266, 7.950396333421979, 0.2634662996445383, 0.28959130921534126, 24.103665692465647, 52.47891017368862, 53.54546907969883, 50.923479488917756, 54.75196123123169, 51.11365863255092, 51.76644536427089, 46.5672264780317, 45.39649323054722, 39.89179679325649, 39.21083164215088, 35.06278487614223, 38.38786268234253, 35.89696128027779, 36.26510810852051, 35.871746267591206, 38.06424338476998, 35.92359025137765, 37.22229194641113, 34.640827723911826, 37.888808318546836, 38.80478933879307, 41.86558893748692, 43.67750195094517, 44.00779151916504, 44.49597890036446, 46.80920096806118, 45.6522216796875, 47.799204621996196, 43.2170969418117, 41.90981422151838, 38.50277199063982, 38.68775735582624, 41.09869541440691, 42.94638122831072, 42.87888295309884, 42.18467453547886, 38.62719685690743, 39.5708212852478, 36.84525837217058, 35.671367168426514, 36.13561453138079, 36.82322563443865, 35.772675377982004, 40.47713041305542, 39.70176703589303, 43.951792512621196, 42.94416127886091, 43.646026611328125, 46.14979607718331, 47.92899349757603, 45.23892545700073, 46.156695638384136, 36.51561498641968, 34.10402032307216, 33.46656479154314, 34.85511711665562, 35.791018622262136, 39.045325551714214, 43.86828211375645, 40.217201777866904, 35.87636334555489, 37.168012619018555, 34.78632647650582, 37.019533089229036, 36.21157571247646, 36.662642342703684, 35.892667293548584, 38.37944841384888, 48.05497128622872, 50.37091357367379, 47.692355224064414, 46.56334243501936, 41.237753186907085, 38.040761947631836, 40.828434807913645, 39.23684917177473, 35.60830184391567, 31.95445612498692, 31.752319131578716, 33.80549097061157, 32.30399915150234, 33.449632031576975, 36.16505057471139, 41.28649827412197, 43.97533995764596, 44.4121732030596, 43.2829589162554, 37.95139421735491, 38.27801513671875, 40.988712378910606, 41.2980010168893, 47.01299163273403, 44.270805154527935, 44.34743683678763, 49.885512420109336, 50.257359164101736, 49.16496338163103, 47.88049507141113, 45.09804030827114, 43.73755523136684, 38.31674786976406, 36.89156811577933, 35.96374389103481, 36.64894049508231, 35.45976325443813, 37.0852005141122, 40.82711812428066, 43.21485267366682, 43.202672481536865, 44.0679247038705, 41.15167542866298, 37.96448114940098, 36.73452145712716, 37.50019209725516, 37.83110352924892, 39.0873030935015, 39.0051406451634, 45.92193685259138, 49.79750306265694, 50.86505903516497, 53.00719213485718, 52.49712140219552, 37.704820019858225, 0.06266856472939253, 0.04549978992768696, 1.663119837641716, 0.3555793826069151, 26.02496940749032, 58.392216273716514, 46.40512153080532, 57.153626918792725, 56.19511944907052, 59.59881959642683, 53.42231573377337, 40.333577156066895, 19.797160046441213, 15.207741124289376, 46.32057932444981, 26.0483500957489, 0.18309379954423222, 0.015115604170465043, 0.017029208630057316, 0.025177218286054473, 0.03591480764693447, 0.018893612515447394, 0.037924499450517554, 0.08013432073806014, 0.029875788305486952, 0.025848944205790758, 0.03631165903061628, 0.08800244318055254, 0.04210922507835286, 0.2016729297382491, 0.046629323424505334, 0.14562194741197995, 0.23150955300245965, 21.866720948900493, 68.7597484588623, 43.421526840754915, 37.41139759336199, 41.87815128053938, 42.281963212149485, 48.105012212480815, 61.498693329947336, 60.91365500858852, 57.99047490528652, 56.270538670676096, 50.63910709108625, 54.73529945101057, 5.478812226227351, 0.5375547121678079, 3.171614898102624, 7.698200174740382, 1.076786328639303, 0.13662195391952991, 31.09055185317993, 54.291417258126394, 56.295955181121826, 53.79976272583008, 56.680266993386404, 52.91200876235962, 52.858771664755686, 48.783291884831016, 48.68394654137747, 41.98531334740775, 41.814887932368684, 36.58014638083321, 39.413270882197786, 37.86210291726248, 37.632058484213694, 37.82167134966169, 39.03836693082537, 37.635060106004985, 39.18694026129586, 36.488753250667024, 41.138671875, 41.28187772205898, 44.8661823953901, 44.7508944102696, 46.405145849500386, 44.93873201097761, 47.7686117036002, 47.25741188866751, 49.03705399377005, 44.12439271381923, 44.261261803763254, 40.626051153455464, 39.04592309679304, 43.5175335747855, 45.169794355119976, 44.90543276923043, 45.36418410709926, 41.08858925955636, 41.59517547062465, 39.87668793542044, 37.75827945981707, 38.072609015873496, 39.03143262863159, 37.53253248759678, 40.53697177342006, 40.385296072278706, 46.61470699310303, 44.57839495795113, 44.269398144313264, 47.58182675497872, 50.3698296546936, 47.13492209570748, 47.45535911832537, 35.30569737298148, 33.87054695401873, 33.42899588176182, 33.97041688646589, 34.17094884599958, 40.20323589869908, 47.966076033455984, 42.43591792242867, 35.47209283283779, 36.995051111493794, 36.23449087142944, 36.09835481643677, 35.87588391985212, 36.04182774680001, 35.90825210298811, 38.40501083646502, 50.05090733936855, 52.55456215994698, 49.96005964279175, 47.63544947760445, 44.19429506574358, 40.26720101492745, 42.48453794206892, 40.0524252482823, 36.728723185403005, 33.17634201049805, 32.995334489004954, 34.59749528339931, 33.55590125492641, 35.44596413203648, 37.92398009981428, 43.787901878356934, 45.272989000592915, 45.89154543195452, 45.64555835723877, 40.39294951302664, 39.78777878625052, 42.23090784890311, 44.07956293651036, 49.19221421650478, 46.529226779937744, 45.506653445107595, 53.25963061196463, 50.11284358160836, 49.284263951437815, 50.12991530554635, 45.810334886823384, 46.36679874147688, 41.172016280038015, 37.719644001552034, 38.148559774671284, 38.539493220193044, 37.06773621695382, 39.00410883767264, 43.517425877707346, 46.255360058375764, 45.6782009942191, 45.40144034794399, 44.03788416726248, 40.926911626543315, 39.65136480331421, 40.164072377341135, 39.649183068956646, 41.94499295098441, 42.316127504621235, 46.631994111197336, 53.590267590114046, 53.51578637531826, 55.019049985068186, 55.891292095184326, 40.60551922661917, 0.07319768438381807, 0.09325574271913085, 1.5243589920657021, 0.14013661603842462, 29.010306358337402, 65.20853110722133, 50.22106524876186, 61.732743399483816, 55.80344254629952, 66.9246597290039, 54.14371592657906, 50.158878871372764, 19.990420716149465, 15.020775522504534, 56.68427957807268, 31.52089548110962, 0.04865745780989528, 0.03706940622734172, 0.022628326933564882, 0.039835718859519274, 0.04289707548118063, 0.03180249188361423, 0.07833635221634593, 0.14171061372118338, 0.20794503603662762, 0.11350904272070952, 0.2045306478227888, 0.17666366244001047, 0.1561025314565216, 0.3481097434248243, 0.22934996602790697, 0.37472785796437946, 0.29183074619088856, 25.03969052859715, 82.51426342555455, 48.85603257587978, 44.82571956089565, 38.21485253742763, 51.267352785382954, 54.2880300113133, 64.2229082924979, 67.20264325823102, 60.715992655072895, 63.041325432913645, 54.88391447067261, 62.53480870383126, 7.615646890231541, 0.9935162940195629, 12.396248970712934, 15.072695936475482, 0.7796690889767238, 0.5445442742535046, 34.69292879104614, 53.74029656818935, 58.790049280439106, 55.66297776358468, 58.8536947795323, 55.95904745374407, 56.700385502406526, 49.82286746161324, 51.78191205433437, 44.4889612197876, 44.719933237348286, 38.06026554107666, 41.84126329421997, 39.100164209093364, 39.60565955298287, 39.9829432623727, 41.62768956593105, 38.969135080065044, 41.47595133100237, 37.91073335920061, 43.28392471585955, 42.93672323226929, 47.26999160221645, 46.42338834490095, 47.68817935671125, 48.18113667624337, 50.037361826215474, 48.0874263218471, 50.74359062739781, 45.855602400643484, 46.435141222817556, 42.75315877369472, 41.09920610700335, 44.19191183362688, 47.699928760528564, 47.54699543544224, 48.56439931052071, 42.8165089743478, 42.614886147635325, 42.230768884931294, 39.106612137385774, 39.59062017713274, 41.711797509874614, 38.93997349057879, 43.74971110480172, 43.23909841264997, 49.66073472159249, 48.26717274529593, 48.04206848144531, 52.051234654017854, 52.37358243124825, 48.45412792478289, 50.56056465421404, 35.92591094970703, 35.16071973528181, 35.174504961286274, 33.7624260357448, 34.73417329788208, 40.8909546988351, 51.68484224591936, 45.04862471989223, 35.37389394215175, 38.56403425761631, 34.377233913966585, 37.31609957558768, 37.46724026543753, 36.24742146900722, 35.851335934230256, 39.177813802446636, 54.50387232644217, 54.97545351300921, 52.273934841156006, 51.20139353615897, 45.73001371111189, 42.59373583112444, 45.256386280059814, 44.08286680494036, 40.4078950881958, 35.191173689705984, 34.21385744639805, 37.40818057741438, 35.06300374439785, 37.07630334581648, 41.27722937720162, 46.35508060455322, 48.946452958243235, 49.70475850786482, 48.75059366226196, 42.022048473358154, 42.56334441048758, 45.06997306006295, 46.17221791403634, 50.637522901807515, 49.61172560283116, 47.77051203591483, 55.05702536446707, 53.161080837249756, 50.9991523197719, 52.77359022412981, 49.99932043892996, 48.38925954273769, 43.048505851200645, 41.49570158549717, 40.226901463099885, 41.30161755425589, 38.66894163404192, 42.48583378110613, 45.212060247148784, 46.97594731194632, 46.58999572481428, 50.67048863002232, 46.241658210754395, 42.370955739702495, 43.18408605030605, 41.47280727113996, 42.80673633302961, 42.53547518593924, 44.86999000821795, 48.497189385550364, 56.51229081835066, 54.546579429081504, 57.51469005857195, 56.60891246795654, 45.89290380477905, 0.6032387475882257, 0.2565707010882241, 6.3177885328020364, 0.6639444530010223, 34.909170627593994, 70.25525787898472, 56.146103382110596, 69.61906691959926, 62.60992567879813, 70.19619124276298, 64.04331820351737, 54.999713148389546, 29.856735910688126, 26.34974036897932, 63.75139658791678, 43.020414284297395, 0.3224436677992344, 0.11559278305087771, 0.11097532510757446, 0.17557839996048383, 0.13030598711754593, 0.23155278925384792, 0.1855706830642053], [0.020570202996688228, 0.07715195577059474, 0.03695410616429789, 0.04106276123119252, 0.05717356423182147, 0.01417454649760787, 0.01585328030133886, 0.037685132651988945, 0.17591002716549806, 0.09402849911046879, 3.553832479885646, 53.63276972089495, 39.92159761701311, 34.78451994487217, 28.185287679944718, 39.50567497525896, 38.84974765777588, 47.73783465794155, 54.38962309701102, 48.729328700474326, 53.8879770551409, 48.33731828417097, 54.37676198141915, 26.896179710115703, 0.2580736832959311, 1.2058550885745456, 5.483698112624032, 1.5482679605484009, 0.07275839402739491, 6.678509908063071, 45.29137045996529, 53.10718713487898, 51.659710611615864, 53.98850359235491, 49.08823095049177, 49.789693287440706, 43.479488713400706, 43.521146638052805, 38.808214800698416, 37.90898241315569, 38.23878560747419, 37.179289545331685, 36.36893156596592, 37.8342719078064, 39.69661494663784, 39.19996118545532, 37.164951937539236, 37.35927220753261, 35.40569584710257, 37.996324743543354, 37.08740656716483, 37.92789888381958, 37.78102786200387, 37.49077728816441, 38.78434426443917, 42.98629168101719, 44.179137570517405, 45.307733467647004, 42.665420395987375, 40.81422921589443, 40.58945846557617, 37.35922704424177, 42.575507232121055, 43.519558974674766, 42.804474694388254, 42.3553500856672, 40.614673478262766, 37.493337699345176, 37.03028890064785, 36.84642914363316, 36.27523510796683, 36.44768244879586, 39.773851122174946, 39.4544563293457, 42.93174832207816, 43.993773528507774, 43.45022637503487, 44.534458024161204, 45.343888419015066, 47.89208466666085, 46.85410022735596, 47.58113888331822, 39.15950877325875, 34.66815151487078, 35.91079861777169, 34.769841875348774, 35.28620767593384, 37.13468211037772, 40.34353739874703, 40.740675585610525, 36.31898096629551, 37.67686741692679, 34.61789519446236, 35.36010176794869, 34.362639222826274, 34.25846488135201, 34.80983918053763, 37.69498484475272, 45.990164688655305, 48.68026399612427, 45.162832260131836, 44.261320863451274, 40.85735321044922, 39.314846175057546, 39.372606549944194, 42.09644978387015, 40.60297966003418, 36.22855363573347, 33.008782727377756, 34.04072918210711, 33.92074768883841, 34.400378363473074, 35.10703795296805, 39.955230372292654, 41.02026414871216, 44.5552887235369, 42.265377862112864, 36.53410414287022, 35.83296142305647, 39.9560398374285, 42.179661410195486, 47.67181287493025, 44.99663829803467, 43.71382365907942, 46.9665915625436, 46.895945753370015, 44.66616112845284, 42.80671896253313, 39.21981913702828, 37.30734831946236, 37.92490768432617, 36.882663999285015, 34.6068023954119, 34.809081826891216, 36.611983026777, 45.3694612639291, 48.11859246662685, 49.195073400224956, 49.26074777330671, 48.00823770250593, 48.38599041530064, 48.13425023215157, 43.636243547712056, 38.11075462613787, 37.38822882516043, 38.736457279750276, 38.95345994404384, 48.145857197897776, 50.57697629928589, 57.59129742213658, 54.66984742028372, 52.9993371963501, 17.660312788827078, 0.19428357481956482, 0.1946115515061787, 1.2726434533085142, 0.21270334427910192, 40.131683349609375, 52.17792463302612, 50.41194616045271, 53.558024474552695, 50.78945568629673, 52.52420200620379, 53.01273332323347, 34.05724505015782, 39.03162022999355, 36.30303485052926, 42.46782752445766, 21.152477400643484, 0.40357083454728127, 0.11864586493798665, 0.028876567459000007, 0.05187990543033395, 0.035266538682792864, 0.056326593072818856, 0.03904943247990949, 0.015202885826251336, 0.05242678429931402, 0.08947711012193135, 0.0019615891838579303, 0.059170893127364774, 0.03469362442514726, 0.028086398162746003, 0.029569545095520358, 0.1646646120186363, 0.1932847441307136, 5.2559917484010965, 60.850954464503694, 46.3718500818525, 35.161796706063406, 32.07093225206648, 45.24974032810756, 45.814726148332866, 54.698498317173545, 58.455924306597026, 54.16209043775286, 59.01346165793282, 52.387270382472444, 58.635743686131065, 28.210214342389786, 0.36095267427819117, 0.21592610063297407, 8.52468318598611, 2.8262694520609717, 0.11605396973235266, 11.89293622970581, 49.29638160978045, 54.228157384055, 53.978133405957905, 55.102372782570974, 52.56750317982265, 50.664627824510845, 45.40630061285836, 45.09019231796265, 40.47133214133126, 40.514112200055806, 40.47290243421282, 39.251200675964355, 38.459873812539236, 38.53790208271572, 40.95118515832083, 39.94700370516096, 38.32974100112915, 38.27740022114345, 36.06253685270037, 39.52180174418858, 39.11694410869053, 40.53661046709333, 39.94718435832432, 41.66027314322335, 42.56221185411726, 44.91569178444998, 46.438511099134175, 46.528396470206125, 44.44969000135149, 41.61617292676653, 41.25290373393467, 38.13731064115252, 42.29490423202515, 43.945309843335835, 45.764921460832866, 43.7229813848223, 42.03012922831944, 40.41495793206351, 38.23770863669259, 38.32851116997855, 36.33893966674805, 37.48040362766811, 41.40438488551548, 42.67475182669503, 44.046479088919504, 43.442586830684114, 46.56488840920584, 46.67035858971732, 48.55328566687447, 50.599346024649485, 50.44797951834542, 49.678112166268484, 39.0355007989066, 35.10805933816092, 34.983287061963765, 34.460244042532786, 35.819290842328755, 38.637535776410786, 43.40896102360317, 41.68746491840908, 36.56158079419817, 36.266761779785156, 34.49646152768816, 35.669644015175955, 34.065287590026855, 34.32109246935163, 35.244282245635986, 37.98797300883702, 48.46497753688267, 49.20483909334455, 47.01337725775582, 46.099970545087544, 43.23887259619576, 40.317634514399934, 41.18777132034302, 43.374956539699006, 41.939649786267964, 36.08692850385393, 34.37471171787807, 36.1421354157584, 36.06030648095267, 35.59201526641846, 36.91597713742937, 42.907040527888704, 43.098140307835166, 45.79885646275112, 44.06203957966396, 38.86517265864781, 37.40213564464024, 42.973295075552805, 43.980801241738455, 48.79011501584734, 46.81087895802089, 46.71171426773071, 47.92735024860927, 49.202473231724326, 46.969433375767295, 45.67658206394741, 41.6753820010594, 39.35451691491263, 40.403295380728586, 39.48548003605434, 36.46796424048287, 37.58113513674055, 38.49928746904646, 46.408925669533865, 50.40097148077828, 51.594623361315044, 51.32013477597918, 50.6323812348502, 49.24798045839582, 49.890803473336355, 45.63120337894985, 40.866740226745605, 38.64283377783639, 40.774829455784385, 40.28022541318621, 49.733996527535574, 53.09655291693551, 58.89980302538191, 57.379224504743306, 55.76045404161726, 22.25029625211443, 0.21948798878916673, 0.5823853037187031, 1.6567512708050864, 0.19046415548239434, 44.47718749727522, 57.126066889081685, 53.91087484359741, 60.08070496150425, 55.23387438910348, 58.72105366843087, 56.89730787277222, 46.200865336826865, 39.3556182043893, 32.265217781066895, 51.265782492501394, 25.2608516897474, 0.28990842934165684, 0.049173727964184115, 0.07737275785101311, 0.0595839988174183, 0.015908390915553485, 0.07545665638255221, 0.06409875370029892, 0.08581956209880964, 0.19173554011753627, 0.11635160233293261, 0.1472529148949044, 0.18075602927378245, 0.07803895031767231, 0.11753432958253793, 0.09759119472333364, 0.42934856989553993, 0.3084948334310736, 5.3971452713012695, 73.11374677930559, 52.60565921238491, 44.80921758924212, 38.97216102055141, 52.839518206460134, 49.289749554225374, 57.322224957602366, 63.677801268441335, 58.42447675977434, 64.68100997379848, 56.57979951586042, 64.89886379241943, 33.79764992850167, 0.3111937471798488, 8.62329375743866, 15.983950444630214, 4.569108469145639, 0.16926925922078745, 16.38318177631923, 51.34585005896432, 54.99155943734305, 54.06828628267561, 59.01021684919085, 54.81853539603097, 53.68800095149449, 48.352055413382395, 47.21183518001011, 42.81645686285836, 43.13460445404053, 43.08621719905308, 42.825072629111155, 40.487698623112266, 42.09394148417881, 44.73855788367135, 41.61771890095302, 40.62395279748099, 39.05520241601126, 38.077257360730854, 42.296867098127095, 41.26795353208269, 42.062900406973704, 41.852550642830984, 43.65978751863752, 42.9860589163644, 48.034095423562185, 47.94202136993408, 49.27400493621826, 46.957600593566895, 43.916606834956575, 43.686708314078196, 41.277302333286826, 45.37900461469378, 46.95808001926967, 48.75280318941389, 45.511524132319856, 44.78899833134243, 41.5387213570731, 41.16411965233939, 41.071857997349326, 39.271788188389365, 40.398431641714915, 45.2530893598284, 45.5659841128758, 45.59170981815883, 47.81126322065081, 47.91827242715018, 49.290274143218994, 52.080434458596365, 53.44214589255196, 52.203900473458425, 50.744479996817454, 41.07080881936209, 35.86458614894322, 35.16783469063895, 35.98531804765974, 35.513215746198384, 38.13165480749947, 45.76548773901803, 42.914659227643696, 35.831818444388254, 36.78287049702236, 35.72280468259539, 35.446467876434326, 34.63609947477068, 34.41038376944405, 35.10818440573556, 39.10741465432303, 50.071644238063264, 53.025736876896445, 48.880990505218506, 49.20062501089913, 44.16251400538853, 43.38284969329834, 43.28318820680891, 46.207434858594624, 44.898654801504954, 38.73296233585903, 36.86811099733625, 38.39098242350987, 38.173743520464214, 38.538009779793875, 38.965852056230815, 45.425429003579275, 47.024442264011924, 49.213055338178364, 46.47428389957973, 41.1392867905753, 40.96215288979666, 46.456593785967144, 46.48716238566807, 50.88819653647286, 49.73857191630772, 47.97452156884329, 51.18677800042288, 51.075492177690776, 48.4214540209089, 47.42788246699742, 42.78209802082607, 42.693873269217356, 42.2803373336792, 41.323942116328645, 37.60348054340908, 39.774775232587544, 41.49417298180716, 49.06742456981114, 53.224382400512695, 54.80157136917114, 52.24353994641985, 52.7770539011274, 51.5386313029698, 53.58113418306623, 48.25418308803013, 42.74914271490914, 40.61885976791382, 42.404845578329905, 41.87050478799002, 51.8432993888855, 56.95726040431431, 63.96782602582659, 59.58134487697056, 57.041420459747314, 26.37178874015808, 0.41186920925974846, 1.0522062075989587, 3.827565448624747, 0.2206690197012254, 50.439005919865195, 60.75974546160017, 60.67060702187674, 65.05532332829067, 61.70056629180908, 63.62409169333321, 64.05479662758964, 44.67432526179722, 46.85097701208932, 48.22213452202933, 58.43662221091134, 35.51385498046875, 0.4510248867528779, 0.21518239911113465, 0.16970843422625745, 0.20366381933646543, 0.13292571582964488, 0.22369489233408654, 0.18033007213047572], [0.047846085990646055, 0.014212306123226881, 0.04857715658311333, 0.011590584214510662, 0.05963368793683393, 0.030088821159941808, 0.029326975611703734, 0.09546530379780702, 0.031194700926010097, 0.036010728749845705, 0.2370875451181616, 42.14519139698574, 50.368252413613455, 38.38569484438215, 43.2544504574367, 35.689571448734824, 51.4466996874128, 43.4409817968096, 57.004178115299766, 50.63412175859724, 53.914512225559776, 49.03398288999285, 49.12013360432216, 39.062049865722656, 0.32161563794527737, 2.396377674170903, 3.628418569053922, 4.48296730858939, 0.28243376900042805, 1.6161834533725465, 31.11042022705078, 53.14388404573713, 55.10679183687483, 51.99611112049648, 52.30038663319179, 47.776324204036165, 42.33564499446324, 38.84057603563581, 37.76600238255092, 39.80437108448574, 41.0322219984872, 43.356529917035786, 43.62480681283133, 44.87642056601388, 46.75130162920271, 43.78698124204363, 42.87087862832205, 37.42350482940674, 38.18760865075247, 36.449162415095735, 37.3479049546378, 36.73265586580549, 38.407692841121126, 38.09333896636963, 40.689404828207834, 44.60214390073504, 44.69537135532924, 45.46139635358538, 43.74346467426845, 42.987003871372764, 42.21841498783657, 37.65634591238839, 40.27148110525948, 43.161692006247385, 42.29507098879133, 40.814184052603586, 41.55899272646223, 36.45393582752773, 34.77949987139021, 37.09822838647025, 34.70559883117676, 36.58112260273525, 36.826640674046104, 41.86154508590698, 44.960910660879954, 41.88369246891567, 46.62657104219709, 45.45095321110317, 46.640498706272666, 46.01555340630667, 47.20141635622297, 47.59434740883963, 42.31556122643607, 34.68120718002319, 35.818217345646445, 36.3837833404541, 34.91235637664795, 35.653291429792134, 43.646849972861155, 38.203579085213796, 35.52347476141793, 36.33212695802961, 37.9620075907026, 37.27387537275042, 34.925599643162315, 36.50865983963013, 35.28648560387747, 39.17483302525112, 48.4954697063991, 50.07573325293404, 47.267003876822336, 45.281219141823904, 42.57719911847796, 40.70037603378296, 38.77204942703247, 39.62301615306309, 43.306808607918875, 39.659362179892405, 35.52635826383318, 34.69572196687971, 33.9071535382952, 33.236006191798616, 37.082622732434956, 38.37497724805559, 40.25709138597761, 41.869135992867605, 41.34908764702933, 35.71728433881487, 37.31551245280674, 40.574429512023926, 41.62451423917498, 46.064048358372276, 46.36687517166138, 46.235724449157715, 46.706037589481895, 45.68338435036795, 43.4409852709089, 40.37263992854527, 37.84796680722918, 37.56839908872332, 37.77964517048427, 35.37525578907558, 35.57992887496948, 34.72129133769444, 43.45023332323347, 49.12047059195382, 49.5209960256304, 49.99733672823225, 50.93976954051426, 50.40281275340489, 51.2648549079895, 50.81086308615548, 49.89313459396362, 50.13296903882708, 41.320117133004324, 37.65499448776245, 38.75646114349365, 45.311662673950195, 54.78305441992623, 53.617056369781494, 50.87945917674473, 46.353562423161094, 27.071694680622645, 0.6959939960922513, 0.42713331590805736, 0.9130949122565133, 1.8190107068845203, 52.27668980189732, 48.448781285967144, 51.42385401044573, 50.263987745557515, 54.080348355429514, 55.36995138440813, 52.064064502716064, 32.275963170187815, 47.33801099232265, 54.00823300225394, 46.3761579649789, 16.337466103690012, 0.6113119572401047, 0.08479895722121, 0.19537794323904173, 0.017373946827969382, 0.06049583453152861, 0.04400578473827668, 0.02541493115547512, 0.05080486847353833, 0.01828084619981902, 0.0705504139353122, 0.061675895138510635, 0.052738662742610486, 0.04620659610788737, 0.13935826851853303, 0.06929002835282258, 0.018804887276408926, 0.007696956895025713, 0.29871179695640293, 50.04670367922102, 57.953246457236155, 38.74439212254116, 40.497061320713584, 48.14447103227888, 49.264676979609895, 48.81042807442801, 62.64855071476528, 54.80855083465576, 57.48457309177944, 53.492999758039204, 52.017945834568565, 46.18002074105399, 0.575355735208307, 1.1819236470120293, 3.8432744571140836, 5.606428052697863, 0.1477856327380453, 1.796970478125981, 37.75853654316494, 53.76781838280814, 56.500600474221365, 53.50348458971296, 53.93667003086635, 49.144111837659565, 46.058138915470664, 41.648794719151084, 40.77826533998762, 41.24972840717861, 42.05201605388096, 45.018931593213765, 44.6150084904262, 49.17607355117798, 47.9224066053118, 46.1986905506679, 43.10813876560756, 39.06394672393799, 38.1992746761867, 38.42211730139596, 38.42602218900408, 38.655705315726145, 39.519140584128245, 40.525833811078755, 41.20834493637085, 46.641638210841585, 46.07714918681553, 47.09272568566458, 46.59020069667271, 43.811098439352854, 44.67851502554757, 39.03942305701119, 41.249829156058176, 46.01585912704468, 44.136579854147776, 43.64072513580322, 44.30381604603359, 37.984095914023264, 37.13656159809658, 36.99810484477452, 35.907769203186035, 37.07960374014718, 42.08719825744629, 43.29069920948574, 47.55093853814261, 44.210453101566856, 48.089010511125835, 48.42846475328718, 46.98846796580723, 49.03223194394793, 49.52330977576119, 49.39011975697109, 43.14811175210135, 34.50103344236101, 35.8851250239781, 35.69666903359549, 34.74812528065273, 36.021990639822825, 46.17815167563302, 40.57879992893764, 35.20244366782052, 36.44574737548828, 37.6306653703962, 35.89171191624233, 34.07940632956368, 35.591751234872, 35.99173470905849, 40.290341990334646, 49.7390513420105, 50.97550065176827, 49.223053795950754, 47.05461829049246, 44.58041688374111, 43.63708080564226, 42.51202154159546, 42.55734464100429, 44.99785075868879, 40.784091404506135, 36.804920605250764, 35.85948617117745, 34.579471656254356, 36.23147882734026, 39.60598611831665, 40.58844402858189, 42.74206944874355, 44.13490186418806, 42.65863200596401, 37.38432046345302, 40.62777083260672, 41.6937460899353, 43.55036728722708, 48.7089079448155, 47.272746562957764, 48.05922358376639, 49.214427607400076, 46.80098819732666, 46.844494342803955, 43.92263787133353, 39.948858874184744, 41.22526379993984, 38.11951977866036, 37.44522142410278, 36.90743432726179, 36.13193546022688, 45.36530276707241, 51.11754614966256, 51.672804491860525, 51.9719591821943, 53.41009037835257, 53.735120160239084, 53.71154144832066, 52.455546855926514, 53.6734653200422, 51.449937547956196, 43.48347697939192, 39.55961384092058, 41.51652881077358, 47.10242884499686, 55.5663491657802, 56.667214802333284, 51.86176422664097, 45.12599638530186, 32.45260374886649, 1.0915202008826392, 1.3125383811337608, 1.0254392496177127, 2.099415574754987, 55.16634137289864, 54.499213559286936, 57.243991715567454, 55.469675404684885, 59.00948034014021, 59.724415234157014, 56.370530196598594, 40.54798466818673, 53.75204944610596, 59.21598080226353, 53.35368142809187, 21.46039550645011, 0.5942479957427297, 0.045718006789684296, 0.08617695327848196, 0.0645326157765729, 0.06908688175358943, 0.01879137594785009, 0.04539787736056106, 0.16974989271589688, 0.23289094173482486, 0.17575916168945177, 0.11445289850234985, 0.11960125581494399, 0.18967309221625328, 0.2379169049007552, 0.12379400511937481, 0.10675067787191697, 0.16212436689862184, 0.3576828954475266, 63.090692383902415, 65.23557349613735, 48.87049525124686, 53.340858527592246, 48.328542709350586, 62.302016258239746, 53.16394002096993, 65.51794828687395, 61.25709751674107, 63.341320855276926, 58.48084054674421, 57.968775681086946, 49.44720615659441, 0.6052415658320699, 4.563638934067317, 11.84585349900382, 8.36479297706059, 0.2542616735611643, 4.143934300967625, 41.920021125248496, 53.740591866629465, 60.072200366428916, 56.11455161230904, 56.32111113412039, 51.26452486855643, 49.241852147238596, 43.23919916152954, 42.38288232258388, 44.82171739850725, 44.50544582094465, 48.53803784506661, 47.568607807159424, 51.051670278821675, 51.017728328704834, 48.03726380211966, 47.026811599731445, 41.77573830740792, 42.28887319564819, 39.65880284990583, 40.30875819069998, 40.03161539350237, 43.542564460209434, 42.42412682941982, 42.59187371390206, 48.74158532278878, 49.45757286889212, 49.0563838822501, 47.730156898498535, 47.18597398485456, 47.297940731048584, 41.62117910385132, 43.591695172446116, 47.17721230643136, 44.82551111493792, 45.262337412152974, 48.5167555127825, 39.9809421811785, 39.85398817062378, 40.54966613224575, 37.52685580934797, 39.344945771353586, 43.061498982565745, 46.912117685590474, 50.05343300955636, 46.19483430044991, 50.471627712249756, 50.431786741529194, 50.393147809164866, 51.140148639678955, 51.92422505787441, 51.32363319396973, 44.48318031855992, 34.959319250924246, 35.23162610190255, 36.1237713268825, 34.841331890651155, 36.78810943875994, 49.39524057933262, 40.617004598890034, 36.06073032106672, 37.82179989133562, 38.09960624149868, 36.24088668823242, 34.609665053231375, 35.77615295137678, 35.4387970651899, 41.267526217869346, 51.036568369184224, 53.488403524671284, 52.16131843839373, 50.18742901938302, 48.24028321674892, 46.0093069757734, 44.60016713823591, 43.915199824741904, 48.17808294296265, 43.523786953517366, 39.46578189304897, 38.62799937384469, 36.43765619822911, 37.98254646573748, 41.35705028261457, 43.1354695047651, 46.24562215805054, 47.43465348652431, 45.36090803146362, 38.635819571358816, 42.20074571881975, 45.94807597569057, 47.88937834330967, 51.63441569464547, 48.59083720615932, 50.3197956766401, 50.2158054624285, 49.73987817764282, 48.20951311928885, 45.16119595936367, 41.85032721928188, 42.74000235966274, 41.452991008758545, 39.156649589538574, 40.032289368765696, 38.53921181815011, 46.5226468358721, 52.24343572344099, 53.19344902038574, 51.722907951899934, 55.518569878169465, 55.22526557104928, 55.845875195094514, 55.875297342027935, 55.10329341888428, 53.25098705291748, 46.01640803473336, 41.94442319869995, 43.278261934007915, 49.77625894546509, 58.359872409275596, 58.57151453835623, 54.63170528411865, 47.88098839351109, 40.191333634512766, 1.950479418039322, 2.2548341836248125, 4.199342710631234, 2.762707982744489, 63.61890138898577, 59.11706624712263, 61.83456924983433, 60.02509157998221, 64.5568665095738, 65.84816837310791, 62.96820953914097, 46.115364279065815, 53.392900535038535, 61.15610545022147, 63.72009495326451, 28.001552990504674, 0.6223379341619355, 0.16637434384652547, 0.3365816505891936, 0.16039003139095648, 0.1726198380014726, 0.07600989312465702, 0.10746539916310992], [0.044629297352262905, 0.008038526334400688, 0.031007533826466118, 0.03348272100889257, 0.03746298707223364, 0.012929827440530062, 0.039190292957105806, 0.04215304147718208, 0.0369427542734359, 0.029000288141625266, 0.09222348739526101, 16.945525544030325, 51.54898411887032, 35.59030253546578, 30.01653058188302, 29.36319841657366, 54.548517976488384, 53.69608170645577, 54.22153227669852, 51.950117519923616, 53.25575699125017, 51.776607104710166, 47.57488897868565, 46.50146177836827, 2.8315033997808183, 0.6712555321199554, 2.7351134291716983, 3.5093207997935156, 0.2721722296306065, 0.18930086147572311, 25.12951683998108, 52.20438684735979, 53.97968980244228, 50.86975254331316, 49.40531546728951, 45.057448932102744, 43.68511370250157, 43.12238952091762, 47.06034360613142, 45.85339634759085, 50.91950511932373, 51.457927976335796, 50.78712803976876, 47.41037995474679, 50.78630815233503, 47.70262118748256, 46.21066229684012, 39.95278113228934, 36.361027990068706, 37.168509415217805, 36.55520582199097, 37.4031639780317, 37.86490304129464, 37.802706241607666, 41.380205154418945, 45.53901815414429, 47.81309754507882, 46.18890053885323, 44.09373378753662, 41.49230739048549, 41.49037231717791, 38.8533433505467, 36.860968249184744, 41.504122802189414, 42.94803489957537, 42.65714856556484, 42.16519526072911, 39.383362361363, 35.42932319641113, 33.14239311218262, 35.62012072971889, 38.7780943598066, 38.779376302446636, 42.75363819939749, 42.811336040496826, 45.377246720450266, 44.97675602776663, 47.48242930003575, 45.66025379725865, 46.43108694893973, 49.87751504353115, 48.88445765631539, 43.712430545261924, 35.130634035382954, 36.593038763318745, 37.31722865785871, 38.2417768069676, 34.10110902786255, 43.46114546912057, 39.06199428013393, 36.181455271584646, 37.3417557988848, 36.103496483394075, 36.530397278921946, 35.04572357450213, 34.46661901473999, 36.673113277980256, 42.850857394082205, 49.903657640729634, 48.211378710610525, 48.42565768105643, 45.7449870790754, 44.26605258669172, 43.13695641926357, 41.52446017946516, 38.99265820639474, 39.64410393578665, 40.13963903699602, 36.6446395601545, 33.3964262008667, 34.54143026896885, 32.891250474112375, 35.316501821790425, 37.24149676731655, 40.26021112714495, 40.84163638523647, 38.71933691842215, 35.47574758529663, 38.094346455165315, 41.70786830357143, 40.75671897615705, 46.25220210211617, 47.29594659805298, 45.17334835869925, 46.35937459128243, 46.84894813810076, 42.0193247795105, 41.09779562268938, 39.265579972948345, 36.51223121370588, 35.16136939185006, 36.266101700919016, 36.285000801086426, 36.49003866740635, 44.87767818995884, 47.84525728225708, 49.742056437901084, 51.48694712775094, 50.10968215124947, 47.627219336373464, 52.37348863056728, 51.28186757223946, 50.83516788482666, 48.677422182900564, 50.78918818065098, 39.626125471932546, 35.71394920349121, 43.83783163343157, 53.0659704208374, 53.56008461543492, 51.20591681344168, 39.01139749799456, 17.778856004987443, 0.02595780497150762, 0.8395549612385886, 1.2242479473352432, 8.20918893814087, 57.541610854012625, 45.890555313655305, 54.05955934524536, 48.339156082698274, 51.76302685056414, 52.985649245125906, 44.0552407673427, 29.253270966666086, 25.3749133178166, 40.99421535219465, 45.63985736029488, 6.3922571539878845, 0.32563473656773567, 0.0579130384804947, 0.09144963856254305, 0.032946674951485226, 0.038315562930490286, 0.06544783059507608, 0.05010881368070841, 0.04973986365699342, 0.0976236897653767, 0.022419821604021957, 0.03572170675865241, 0.020571868800159012, 0.08898823242634535, 0.044709255918860435, 0.08322964821543012, 0.02233654839385833, 0.096633937875075, 0.0687802042812109, 22.749484368732997, 60.972721644810264, 38.83616392953055, 32.36002247674124, 37.10678161893572, 57.89883163997105, 56.23845188958304, 58.53047847747803, 56.573740686689106, 57.56397363117763, 57.0766339302063, 52.37855039324079, 49.901263986315044, 4.14836334330695, 0.9412215458495277, 1.8813250831195285, 3.826381649289812, 0.6002104186585971, 0.2940006468977247, 28.653870718819753, 53.632894788469585, 55.293514251708984, 52.728263650621685, 52.92550911222185, 45.98169830867222, 45.87331335885184, 44.8940828868321, 49.360350200108115, 49.20950133459908, 52.890490191323416, 52.57288108553205, 52.21803658349173, 50.81778349195208, 51.94716106142317, 48.8109769821167, 47.38482448032924, 41.1158435685294, 38.710405009133474, 38.43613876615252, 37.80153547014509, 37.331059047154014, 39.61141960961478, 41.17470523289272, 40.83716869354248, 47.53253623417446, 48.30491883414132, 46.50971623829433, 45.918132713862825, 42.07224225997925, 44.01244681222098, 39.48456287384033, 38.88307816641671, 43.63651105335781, 45.835501262119834, 44.75622020448957, 44.84311785016741, 41.49792848314558, 37.2549797466823, 34.68811368942261, 36.019829750061035, 39.28838396072388, 40.713542870112825, 45.0374242237636, 46.43661771501814, 46.75552960804531, 48.12340062005179, 49.005120073046, 48.67322547095162, 49.90246255057198, 51.103816509246826, 49.99119799477713, 44.00095101765224, 35.00582701819283, 36.64919063023159, 35.46345622198922, 38.10854857308524, 35.419369901929585, 44.76666334697178, 39.83007247107369, 35.504443645477295, 37.242257595062256, 36.45476613725935, 36.85728570393154, 35.30763244628906, 34.53853634425572, 34.98116438729422, 43.370401995522634, 51.81928294045584, 49.72151061466762, 50.55392912455967, 47.66082777295794, 46.74710839135306, 44.886203629629954, 44.3557642527989, 41.72116715567452, 43.220911502838135, 44.09311539786202, 38.80885403496878, 36.26022352491106, 36.68723896571568, 34.73453460420881, 36.76348154885428, 38.41550261633736, 41.95616912841797, 41.844473361968994, 41.31333916527884, 36.80111994062151, 39.022181102207725, 43.15248564311436, 41.83710479736328, 47.62501328332083, 49.403439453669954, 46.46635947908674, 48.14616986683437, 48.82900755746024, 43.71519245420183, 44.008191040584016, 41.71156474522182, 39.53518050057547, 36.54463413783482, 37.62449189594814, 38.72956814084734, 38.55033935819353, 46.44911057608468, 50.42647136960711, 50.56764486857823, 52.36188166482108, 50.89628423963274, 50.468212672642295, 54.28347199303763, 52.67551987511771, 52.38720784868513, 52.67226464407784, 53.73314339773995, 41.925159318106516, 37.23042481286185, 45.80509941918509, 53.874949182782856, 56.0527925491333, 53.095420360565186, 40.18723767144339, 20.76608633995056, 0.02959734128255929, 1.2128619125911166, 1.0209736206701823, 9.068548219544546, 63.8675148827689, 51.21638774871826, 59.054025241306846, 53.14497143881661, 57.68235009057181, 59.04244259425572, 48.79961320332119, 40.31907626560756, 29.143524169921875, 42.484162739345, 54.699415479387554, 9.427291529519216, 0.3512372741741793, 0.07557357475161552, 0.03673223539122513, 0.011765712406486273, 0.10899019627166645, 0.006821120008161026, 0.08653089750025954, 0.10658422644649233, 0.14276850409805775, 0.13403829612902232, 0.07648895241852317, 0.10588155593723059, 0.17528190729873522, 0.1300213145358222, 0.1745271049439907, 0.12939676376325743, 0.2402415115918432, 0.2569348844034331, 29.369246823447092, 71.08895138331822, 45.7473703111921, 40.156311239515034, 41.91384070260184, 66.61248411451066, 63.39733028411865, 60.82872717721121, 62.09183325086321, 63.78210762568882, 61.90273107801165, 55.583202021462576, 58.17632532119751, 5.12567046710423, 2.746164756161826, 11.022559710911342, 7.93690380028316, 0.675175130367279, 0.5446311810186931, 33.94221414838518, 53.3269100189209, 59.338359424046104, 55.47767278126308, 55.430973938533235, 47.26712894439697, 47.00706829343523, 46.85184553691319, 50.980513777051655, 50.50869287763323, 56.06550080435616, 57.100914410182405, 55.74017572402954, 52.516885553087505, 54.07577296665737, 49.22081300190517, 50.33803469794137, 43.31340592248099, 40.480444703783306, 40.21161195210048, 40.3804566519601, 39.24888345173427, 41.101957593645366, 41.15991946629116, 42.946169308253694, 50.204424313136506, 52.963352475847515, 47.652121680123464, 47.824732303619385, 43.604497228349956, 45.78978211539132, 41.671237400599885, 40.553102016448975, 45.53126049041748, 46.37012692860195, 46.8831193787711, 46.50748586654663, 44.701916558401926, 40.60297271183559, 36.26589672906058, 38.64922612054007, 43.1342396736145, 43.588127272469656, 47.836599826812744, 48.41981772014073, 48.6457279750279, 51.197533811841694, 52.738046714237754, 50.69982392447335, 51.48769058500017, 54.375083991459434, 50.54595954077584, 44.89540651866368, 36.275026662009104, 38.017478534153526, 36.62939521244594, 39.42146280833653, 34.01647302082607, 47.2260650907244, 40.683314732142854, 35.57235186440604, 37.80136176518032, 35.47362838472639, 36.936036586761475, 34.84321485246931, 34.33137927736555, 36.22809158052717, 43.515494278499055, 54.588900906699045, 50.73586770466396, 53.923645632607595, 48.60928814751761, 49.230342456272666, 48.50727469580514, 47.27244084221976, 43.600165026528494, 46.207195145743235, 45.070810317993164, 42.28775453567505, 37.271043981824604, 38.48319891520909, 36.588140283312114, 38.900921140398296, 40.53585311344692, 44.86266313280378, 44.44187675203596, 43.55314656666347, 40.39309542519705, 42.17274100439889, 46.66469233376639, 43.153458390917095, 49.13387714113508, 51.22492708478655, 48.27090392793928, 50.85648495810372, 51.132217270987375, 46.56347097669329, 47.52460486548287, 43.90485395703997, 41.776728425707134, 39.56342840194702, 39.45461961201259, 39.717820848737446, 41.27245943886893, 49.24605928148542, 52.04568304334368, 52.9703597341265, 53.535592215401785, 52.57140806743077, 50.34367663519723, 55.60595737184797, 54.07897956030709, 53.966529914310996, 54.14508124760219, 55.46072612489973, 43.78198201315743, 39.705230712890625, 48.010735579899375, 56.28214911052159, 58.01631872994559, 54.93289927073887, 43.15236404963902, 26.642077139445714, 0.131216540400471, 4.514195118631635, 3.240303920848029, 10.491707784788948, 68.89942114693778, 54.536626134599956, 64.81913321358817, 57.271398884909495, 62.021732875279014, 63.49379907335554, 55.371153422764365, 40.825304644448416, 32.181335653577534, 48.72311006273542, 63.73936925615583, 13.612794297082083, 0.6162870845624379, 0.24014977365732193, 0.15644174468304428, 0.12391990050673485, 0.1791998499206134, 0.1630282841090645, 0.14021141773888043], [0.023001936796520437, 0.003117816672394318, 0.028199737259585942, 0.06995096217308726, 0.020539785968139768, 0.0986687151182975, 0.0906644378389631, 0.08412700399224247, 0.0746145537123084, 0.06779871016208615, 0.06404214352369308, 6.569632504667554, 55.27223539352417, 37.29448025567191, 37.114692143031526, 33.77134057453701, 45.83552210671561, 53.23939398356846, 52.0439008304051, 52.704101290021626, 50.73961278370449, 52.56496013913836, 46.913806097848074, 51.442690576825825, 18.285423108509608, 1.030047425201961, 0.6378528273531369, 4.895932623318263, 0.46554651324238094, 0.1860497152166707, 19.379116467067174, 56.45340830939156, 50.67829145703997, 52.61514697756086, 50.49374382836478, 48.56841189520699, 48.35627991812569, 51.034529072897776, 51.505613463265554, 51.46104424340384, 50.73908819471087, 49.18333094460623, 49.82532364981515, 52.47889627729143, 49.345918791634695, 50.96859066826956, 47.894526958465576, 41.852825096675325, 37.53099693570818, 37.60061093739101, 36.51896749223982, 36.04816450391497, 36.090524196624756, 39.02553013392857, 41.10816233498709, 45.36826964787075, 44.59902763366699, 46.28178058351789, 44.63984135219029, 40.9849534034729, 44.27560635975429, 40.916100229535786, 38.09947075162615, 40.387908594948904, 40.81044244766235, 39.4966527393886, 41.978229658944265, 36.8006648336138, 32.65571696417672, 34.789477484566824, 36.70386947904314, 37.121887002672466, 41.050454071589876, 44.51397473471505, 46.46735654558454, 46.74879680361067, 43.433790411267964, 44.78983211517334, 48.13825239453997, 49.007670061928884, 47.917813846043174, 49.599451610020225, 42.18044655663626, 35.16462114879063, 35.789337158203125, 35.4111328125, 39.1660817691258, 37.293243476322715, 43.222026688711985, 38.412768500191824, 36.277479376111714, 37.6930046081543, 36.372718334198, 38.115055561065674, 36.544835635593955, 35.96662391935076, 37.21194607870919, 43.58001525061471, 49.46932922090803, 49.51864058630807, 48.965755053928916, 47.92650604248047, 45.882794175829204, 46.522990771702354, 44.57697752543858, 40.70817191260201, 38.43035786492484, 40.85839196613857, 39.91998216084072, 35.85058205468314, 35.39159795216152, 36.37993403843471, 33.58093908854893, 36.473199708121165, 37.91523926598685, 37.646611486162456, 36.31372117996216, 34.78785160609654, 36.6478704724993, 39.46380513054984, 39.44967596871512, 44.15543379102434, 46.77226087025234, 46.53679684230259, 48.60431671142578, 46.57838528496878, 48.10301807948521, 43.425532477242605, 40.38377441678728, 37.78419624056135, 36.341937814440044, 36.01648766653878, 34.639181000845774, 37.163854122161865, 44.0450199672154, 48.18090738568987, 50.28703144618443, 49.96560083116804, 50.546932288578574, 49.13067749568394, 49.372905594961985, 42.620809486934114, 47.35555171966553, 52.80543034417288, 48.93629469190325, 48.416301931653706, 37.63898583820888, 42.00981616973877, 50.371785572596956, 53.31574773788452, 53.539785453251426, 47.92534916741507, 1.5499334654637744, 0.16930761002004147, 0.8853328419583184, 0.33893817556755884, 20.747520753315516, 51.85929414204189, 48.17971229553223, 50.81577198845999, 49.68610954284668, 51.174243450164795, 51.5741365977696, 39.13492604664394, 29.33371720995222, 24.959530898502894, 38.188897541591096, 39.60505158560616, 0.5217597740037101, 0.16074943781963416, 0.06005285294460399, 0.09186622513724224, 0.03761523675971797, 0.034887936498437605, 0.06545016475554023, 0.05600814301786678, 0.01240491444644119, 0.02401394972444645, 0.03790321719965764, 0.012327831171985184, 0.03346868211935673, 0.025929018123341457, 0.015595839026251009, 0.1351991066975253, 0.06668792798050813, 0.112446307603802, 0.3065115841371672, 8.644550033978053, 63.87671429770333, 39.175163064684185, 33.150557245527, 43.261541094098774, 52.00427177974156, 57.83948360170637, 58.29190513065883, 57.79682166235787, 57.05751248768398, 57.26062570299421, 52.09837123325893, 56.43120534079415, 17.64071192060198, 0.5088055634072849, 1.9439140217644828, 5.98606025321143, 1.0701900997332163, 0.20079717173108033, 21.408202375684464, 55.985353333609446, 53.97114699227469, 52.83914647783552, 53.14080599376133, 50.24887888772147, 51.28233310154506, 51.57898644038609, 52.34667553220476, 53.17506756101336, 51.86190666471209, 52.79130465643746, 52.60778883525303, 53.75495031901768, 51.856674671173096, 51.08176987511771, 49.85967901774815, 43.15095009122576, 38.741970675332205, 39.70825317927769, 38.42327765056065, 39.02647508893694, 38.64432069233486, 39.994789940970286, 42.662700176239014, 45.335946628025596, 46.18525620869228, 46.40895346232823, 46.744440283094136, 42.92870501109532, 45.29020316260201, 41.70826087679182, 39.36179862703596, 41.88890361785889, 43.867326736450195, 41.8486978667123, 43.791264806474956, 39.33653497695923, 36.80464962550572, 37.01657315662929, 39.432513918195454, 39.77801309313093, 41.99545076915196, 47.02575894764492, 46.89842626026699, 49.78714329855782, 47.03477076121739, 46.97068405151367, 50.436511516571045, 50.79787342888968, 51.24083151136126, 50.06660679408482, 43.47962072917393, 34.68769679750715, 36.01054000854492, 35.13084595543997, 37.86417348044259, 36.7962075642177, 45.45613309315273, 38.37552615574428, 36.206253392355784, 36.85883862631661, 36.16328225816999, 39.000068460192, 36.64518846784319, 35.03658669335501, 36.653349127088276, 45.25239453996931, 51.5436235836574, 51.898461137499126, 50.68453788757324, 49.87572935649327, 48.131783621651785, 48.391191141945974, 47.40201432364327, 42.38278504780361, 40.349509375435964, 42.42604800633022, 42.408239773341585, 37.76986905506679, 37.45637675694057, 39.32641839981079, 35.558424200330464, 37.6754013470241, 39.491160188402446, 39.73928383418492, 38.67397212982178, 36.728292397090364, 38.67302370071411, 41.95938614436558, 40.860368728637695, 46.38368286405291, 49.032631465366904, 48.93211187635149, 50.46975864682879, 49.24781717572893, 49.546113763536724, 45.8688873563494, 42.75988462993077, 40.36250598090035, 39.660904679979595, 37.82443673270089, 36.97746869495937, 39.0657046181815, 46.659852913447786, 50.091453552246094, 52.06966822487967, 51.95387996946062, 52.79800966807774, 50.01114974703108, 49.25332014901297, 45.93970339638846, 49.714034352983745, 54.42608724321638, 52.92667988368443, 50.685673918042866, 39.50523723874773, 42.85392154966082, 53.40813793454851, 57.69971363885062, 55.50860268729073, 48.43939079557146, 2.5931148316179002, 0.4405636952391693, 1.5320125413792474, 0.35277092616472927, 25.695916618619645, 57.58247668402535, 52.46019867488316, 57.25300700323922, 53.06432717187064, 55.52724470411028, 56.950326102120535, 45.64104897635323, 32.28300516945975, 21.330151523862565, 44.561385767800466, 47.20010314668928, 1.4941696120159966, 0.1839341108820268, 0.08870389232678072, 0.05930793684508119, 0.029814669263682196, 0.027270512389285222, 0.03012453585064837, 0.05430161726794072, 0.13929174494530472, 0.09055307667170252, 0.23217025612081799, 0.12974760707999977, 0.1863218213298491, 0.22417602794510977, 0.17679833807051182, 0.3001744199012007, 0.19453805259295873, 0.17395301003541264, 0.49768160602876116, 12.29429805278778, 76.82137502942766, 47.15109402792794, 45.236535276685444, 47.129241943359375, 59.77071802956717, 61.72826875959124, 61.24512577056885, 62.53872053963797, 62.1489474432809, 62.42975194113595, 56.3744455065046, 61.814044271196636, 24.295137201036724, 1.4224154566015517, 6.796465132917676, 14.834780931472778, 2.5367625526019504, 0.37486828757183893, 26.241725410733903, 57.413308892931255, 55.17789970125471, 55.996088300432476, 54.96068511690412, 50.808382579258506, 54.60151188714163, 55.54376752035958, 55.524135385240825, 56.04274892807007, 54.07792343412127, 56.197012833186555, 53.61066402707781, 55.748409339359824, 52.1687182698931, 52.60993582861764, 52.23700169154576, 45.244734151022776, 42.6297344480242, 41.253101757594514, 40.16857828412737, 40.8451486996242, 39.64117874417986, 42.99107551574707, 44.54277501787458, 49.10167571476528, 47.02596739360264, 49.37132487978254, 48.03271968024117, 44.810655866350444, 47.81383058003017, 44.07089853286743, 41.04259218488421, 45.72570582798549, 44.576956680842805, 42.37884194510323, 45.866194929395405, 40.29348952429635, 38.41334867477417, 38.559997354234966, 42.49170848301479, 42.307379722595215, 43.41061469486782, 48.100860663822715, 52.64276259286063, 50.74078355516706, 48.01483154296875, 48.44403566632952, 53.65105390548706, 53.7356412751334, 50.282185077667236, 53.39909137998308, 44.881951332092285, 35.20581007003784, 35.7860506602696, 34.572533879961284, 39.24954005650112, 37.51965052740914, 47.682554789951865, 40.62062808445522, 35.32549973896572, 37.61082478931972, 36.37923574447632, 39.593847615378245, 37.68434715270996, 34.35465921674456, 36.46949979237148, 45.95738308770316, 54.18062475749424, 53.719983509608674, 52.94220563343593, 53.97363097327096, 50.83987181527274, 51.4011264528547, 49.4505968775068, 45.12137235913958, 44.81163903645107, 44.640543120247976, 45.591751507350374, 40.90620946884155, 39.83532878330776, 41.33160597937447, 36.56391886302403, 41.51690053939819, 41.278931685856406, 41.47985621861049, 39.97052335739136, 38.61467272894723, 39.15353332247053, 44.709479672568186, 42.03964131219046, 48.576972075871055, 51.03647109440395, 50.44649955204555, 52.89406851359776, 51.617604528154644, 51.76476042611258, 47.70809636797224, 44.37391642161778, 40.98471369062151, 40.86100796290806, 38.372277872903005, 39.21431616374424, 41.75516816547939, 49.45373746326992, 52.85732991354806, 53.75427286965506, 53.454367773873464, 53.363745893750874, 51.590395382472444, 52.8909661429269, 46.20270660945347, 52.02456051962716, 55.446607385362896, 56.252907616751536, 52.23447949545724, 41.333023411887034, 46.19042566844395, 55.09315252304077, 59.00603403363909, 57.374419825417654, 52.050852503095356, 3.662680353437151, 0.5040092979158673, 7.9449037824358255, 1.5928354433604648, 27.56091386931283, 62.96825817653111, 57.43739482334682, 62.48489284515381, 59.66679382324219, 60.39514568873814, 62.38701357160296, 50.09217963899885, 40.68084117344448, 36.28690808159964, 50.79595225197928, 57.59362506866455, 2.4202877283096313, 0.4522338461663042, 0.22277656303984777, 0.2218497520578759, 0.13451265996055944, 0.1700676642358303, 0.15738659112581185, 0.17803262041083404], [0.09656871708908252, 0.05420407107365983, 0.04941451968625188, 0.054055057998214445, 0.006110818948530192, 0.02108674626132207, 0.040617923850991895, 0.08279923988240105, 0.04515053438288825, 0.10606435327125446, 0.1563894296331065, 1.8297017046383448, 43.62492840630667, 44.55545200620379, 36.50455692836216, 17.52028921672276, 43.49047381537301, 50.44128840310233, 52.096943378448486, 53.76989589418684, 55.091088908059255, 51.1438798223223, 49.825083936963765, 47.028201239449636, 42.69380726133074, 0.10433098806866578, 1.247935441987855, 1.2489955851009913, 0.7556061744689941, 0.07891269986118589, 16.201967545918055, 54.658417633601594, 50.656533173152376, 56.463924407958984, 50.68383264541626, 52.143291337149485, 51.66668312890189, 51.57953882217407, 51.382870061056956, 51.95819827488491, 52.46338789803641, 52.59446219035557, 47.090936524527415, 47.486389773232595, 44.36956684929984, 49.61838545118059, 48.5407372202192, 46.1650265284947, 36.261595794132774, 36.591398988451274, 36.07718365533011, 36.589314528873985, 39.53776523045131, 40.828125613076345, 42.095487458365305, 47.0016382762364, 47.71745211737496, 46.03138835089547, 45.436181340898784, 41.1431291443961, 42.156551701681956, 38.30480391638619, 39.6841151373727, 38.45325912748064, 38.62134299959455, 39.976703780038015, 39.19506270544869, 36.170650822775706, 34.41670315606253, 33.46462624413626, 35.260805061885286, 37.741298062460764, 41.88132313319615, 45.84157746178763, 44.99337959289551, 46.19070707048689, 44.12966987064907, 46.45964751924787, 47.52673101425171, 49.319911684308735, 49.99089227403913, 47.77507700238909, 43.12341785430908, 37.931967054094585, 37.12336002077375, 37.59389550345284, 37.543006896972656, 35.472183159419465, 44.01832151412964, 39.80902290344238, 36.20525632585798, 37.331937994275776, 34.6505378314427, 38.89586285182408, 35.934926237378804, 37.20615822928292, 37.78466524396624, 44.26793902260916, 49.328708103724885, 47.76311220441546, 47.3300518308367, 45.96781233378819, 42.57875551496233, 45.02932262420654, 46.144081183842246, 41.53590733664376, 38.75615889685494, 37.8338828086853, 38.28761407307216, 37.01011480603899, 38.47408287865775, 36.475016662052695, 35.67227390834263, 38.54531233651297, 37.39988442829677, 36.324522154671804, 36.417982373918804, 34.912995610918315, 35.91907392229353, 39.233097144535606, 40.90542779650007, 46.101127420152935, 46.50016941343035, 43.33663027627127, 42.41735928399222, 45.552546296800884, 43.746664319719585, 46.07143776757376, 42.5424233845302, 39.59677628108433, 38.03142009462629, 36.6221204485212, 34.81814922605242, 35.37640571594238, 38.96829434803554, 45.36162717001778, 48.997629914964946, 48.29437146868025, 47.868380887167795, 49.57476118632725, 48.57339027949742, 49.063905307224815, 46.89730760029384, 42.818624700818745, 54.45691640036446, 49.627560547419954, 43.1643705368042, 37.92912176677159, 48.61308881214687, 51.7316244670323, 56.59834425789969, 41.140450613839285, 0.7842940922294344, 0.052486145935420475, 1.1433951258659363, 0.10704845975020102, 27.43987798690796, 48.666061878204346, 48.30945948192051, 53.82840320042202, 49.72714907782418, 55.25971473966326, 50.69915689740862, 39.775143487112864, 30.316890784672328, 37.260281222207205, 41.797326360430034, 27.894542046955653, 0.035437230952084064, 0.07002330079142537, 0.053326399597738466, 0.0211703468646322, 0.02304724427605314, 0.04166322401059525, 0.040605615225753615, 0.023022274187366878, 0.0466726648488215, 0.08907809081886496, 0.07563146735940661, 0.03310107220230358, 0.0472852937611086, 0.0010976771258616022, 0.045207215805671046, 0.082523252548916, 0.02293913159519434, 0.11473719110446316, 0.06297550004507814, 3.4969510521207536, 54.78361027581351, 50.29041869299752, 37.70615059988839, 29.63653360094343, 50.99930170604161, 53.82699966430664, 57.079204763684956, 59.41036360604422, 59.42918627602713, 56.07486350195748, 55.87966775894165, 51.2747734614781, 44.06797334126064, 0.06201658757137401, 0.7409362473658153, 6.46704191820962, 1.9777682508741106, 0.07876320502587728, 19.066331148147583, 54.12380238941738, 51.54307815006801, 58.612925801958355, 52.6316420010158, 53.703512804848806, 54.52420622961861, 54.134662423815044, 54.1744339125497, 53.49672051838466, 53.122553076062886, 54.22827202933175, 48.719271183013916, 47.88109956468855, 44.14648798533848, 51.129385880061555, 51.62798513684954, 46.35207550866263, 39.03022016797747, 38.691728251320974, 37.860973834991455, 38.43109784807478, 40.32860571997506, 43.62714488165719, 43.43502719061715, 47.41595588411604, 48.60793324879238, 47.68141181128365, 44.84763765335083, 42.853671414511545, 46.10186045510428, 39.246465478624614, 39.5782801764352, 41.089600222451345, 40.88454845973423, 42.36710296358381, 40.159663745335166, 36.855454853602815, 36.44997188023159, 34.51421070098877, 38.26436540058681, 37.99565771647862, 44.02063526426043, 47.963168212345664, 47.95301342010498, 48.866041455950054, 47.9271730695452, 49.13596854891096, 50.17410237448556, 50.46340104511806, 51.96009165900094, 52.41766875130789, 42.90676607404436, 36.83000360216413, 36.07680150440761, 37.069879736219136, 36.473849364689414, 35.53988988058907, 45.669640813555034, 40.39527021135603, 36.18680885859898, 35.467090129852295, 35.76048476355416, 38.619748388017925, 35.11535494668143, 36.747615337371826, 37.376090322222026, 45.83977787835257, 49.24864053726196, 49.6693365914481, 50.94770438330514, 47.81988593510219, 44.76538140433175, 47.359081404549734, 47.5492570740836, 43.7810092653547, 40.52165446962629, 38.88245630264282, 41.29713944026402, 39.14017193658011, 40.29820040294102, 38.11898129326956, 38.57269866125924, 39.35713291168213, 39.40900468826294, 39.141651902879985, 39.018606254032676, 35.75080592291695, 39.21119294847761, 41.09738220487322, 41.45813962391445, 46.75777735028948, 49.011741706303184, 44.80271407536098, 45.41956124986921, 47.51975849696568, 45.8957074029105, 48.098786626543315, 44.79720415387835, 42.10283170427595, 39.19795315606253, 39.043748310634065, 36.3986941746303, 38.23237589427403, 42.918671812329976, 47.63102347510201, 50.62074647630964, 50.90486873899187, 49.92026036126273, 50.777563844408306, 49.55278403418404, 52.41381597518921, 49.528743267059326, 45.49242353439331, 57.04321656908308, 51.6069529397147, 44.91189111982073, 41.25616938727242, 50.18473311832973, 54.3595096043178, 58.298533712114605, 45.2049036026001, 1.1545036669288362, 0.19860907271504402, 0.6143621621387345, 0.1508270302521331, 33.892395564488, 53.34300899505615, 52.00019318716866, 58.83204419272286, 54.5182203565325, 61.57691614968436, 54.994668756212505, 49.95001949582781, 39.45823267527989, 31.841464519500732, 48.22135632378714, 34.43887485776629, 0.10602063526000295, 0.05272112939772861, 0.0301287868725402, 0.042971134185791016, 0.020167265153889145, 0.02310954057611525, 0.1062679612743003, 0.050921352580189705, 0.23979392275214195, 0.14558354232992443, 0.09707886685750314, 0.21711023923541817, 0.19079442561737128, 0.09196379168757371, 0.14698236941226892, 0.22649146084274563, 0.13905083787228378, 0.3122466435389859, 0.19651765136846475, 3.7191692079816545, 66.03039182935441, 57.66209609167916, 45.43473958969116, 25.373393399374827, 55.659924030303955, 58.52848434448242, 61.56425653185163, 63.29336438860212, 64.23943110874721, 60.11004025595528, 61.68373080662319, 56.067915303366526, 52.10547229221889, 0.23904815848384584, 4.581260434218815, 10.034858516284398, 4.082288146018982, 0.17557591652231558, 21.737718956811086, 53.81746326174055, 52.99100283214024, 60.58615166800362, 55.564980370657786, 55.615358284541536, 56.46695729664394, 56.33404173169817, 57.753433636256624, 56.32822608947754, 56.00376605987549, 56.34304312297276, 49.471142700740266, 48.91840655463082, 45.22877066476004, 52.46403060640608, 54.34519631522042, 50.46674312864031, 40.87037760870797, 39.79167325156075, 39.59537621906826, 40.60064506530762, 43.96476827348982, 46.0836318561009, 44.133098806653706, 50.05979061126709, 52.059589862823486, 49.88765246527535, 46.413289138248985, 45.086426394326345, 47.53682674680437, 41.51876960481916, 42.88876676559448, 41.97494316101074, 41.960282461983816, 44.44427388054984, 43.65835966382708, 39.55467019762312, 37.40223291942051, 38.4547495160784, 39.91846745354788, 41.1116954939706, 45.58230195726667, 51.39218412126814, 50.40402173995972, 50.58510569163731, 48.10168749945504, 50.41882835115705, 52.33816398893084, 52.64760896137783, 54.11221626826695, 53.17151703153338, 45.25067138671875, 37.589424337659565, 36.975165367126465, 38.4934127671378, 36.85071618216378, 34.81713131495884, 48.955120835985454, 42.32625102996826, 35.63641772951399, 34.256488118852886, 35.10846928187779, 38.30298696245466, 35.288167067936485, 38.118494919368196, 37.62355041503906, 46.85093879699707, 50.94807611192976, 50.22302116666521, 53.380011626652305, 50.346087660108296, 47.998207977839876, 49.65182365689959, 50.794621671949116, 46.89104379926409, 43.69061320168631, 41.59784010478428, 43.85629299708775, 41.0072397504534, 43.109966141836985, 40.74517454419817, 39.76552023206438, 43.05336959021432, 40.947978564671104, 40.150644983564106, 39.4183326448713, 38.79973799841744, 40.111512729099815, 42.636957100459504, 44.57352774483817, 49.863104479653494, 52.16930539267403, 46.00181334359305, 47.170135566166465, 47.97898926053728, 48.9355651310512, 50.15695422036307, 46.89227015631539, 45.128838198525564, 41.73097106388637, 41.32740926742554, 37.89393261500767, 39.330135686056956, 45.55949796949114, 49.157838003976, 53.729162079947336, 52.75084529604231, 52.82092482703072, 51.74596554892403, 52.93928391592843, 52.63457414082119, 51.1794684955052, 49.356226444244385, 58.90553528921944, 53.74153682163784, 46.802673135484966, 42.5952262197222, 52.46256453650338, 58.15713439668928, 60.17057296207973, 48.143394061497276, 1.8665093524115426, 0.5027629105108125, 4.704558389527457, 0.2002659466649805, 36.561601638793945, 57.31683315549578, 57.12112324578421, 63.15472003391811, 60.02684947422573, 64.27661786760602, 63.73973056248256, 52.48548664365496, 46.29923445837838, 47.715801920209614, 54.613897051130024, 44.93572344098772, 0.47739324612276895, 0.16858218823160442, 0.15072942977505072, 0.16432575163032326, 0.1702043754713876, 0.14219398849776813, 0.1958218137068408, 0.17877081222832203], [0.12130665858941418, 0.017782999967624034, 0.03354343292968614, 0.05358314367809466, 0.026026828946279626, 0.036296100222638676, 0.09604245211396899, 0.055829793480890136, 0.037131051133785925, 0.05824403464794159, 0.1032318766894085, 0.11946136903549943, 34.56707954406738, 50.9791693006243, 42.3698787689209, 39.48398617335728, 31.597926684788295, 52.15311261585781, 52.252100127083914, 51.19758939743042, 53.51568215233939, 48.90727206638881, 50.2578455380031, 45.036468846457346, 48.51715156010219, 2.9439358924116408, 2.0232513759817397, 4.207669258117676, 1.3450175183159965, 0.216054357322199, 15.194852215903145, 67.16069003513881, 45.518760681152344, 57.00416074480329, 53.09498609815325, 54.85531915937151, 47.708822454724995, 50.77841847283499, 46.2329660143171, 50.72788075038365, 50.448233127593994, 51.99363061359951, 49.117430755070274, 48.59594760622297, 47.94648906162807, 49.45663833618164, 50.33842727116176, 41.38198389325823, 35.76872532708304, 37.59504543031965, 36.409245014190674, 40.681935514722554, 41.71462195260184, 46.13296059199742, 44.9073782648359, 45.8359876360212, 46.24945408957345, 46.798761299678254, 45.98207351139614, 42.283008916037424, 42.40140274592808, 39.996857030051096, 36.05066238130842, 37.618269784109934, 36.63858420508248, 38.733747482299805, 35.00287055969238, 35.95926925114223, 31.906339849744523, 36.42577477863857, 35.09416988917759, 41.284205368586946, 44.140067849840435, 46.077333314078196, 45.037292207990376, 47.45518888745989, 48.74630662373134, 46.794474261147634, 45.37910188947405, 49.244596685682026, 47.1031688281468, 47.26806000300816, 39.60468333108084, 37.29393482208252, 37.7877710887364, 38.08462939943586, 38.010558128356934, 35.64085068021502, 42.42886202675955, 40.67885398864746, 37.00899267196655, 37.07775551932198, 36.31549644470215, 38.82127741404942, 36.545815331595286, 38.08292014258248, 37.503739152635845, 45.394968100956504, 50.57580205372402, 46.5145834514073, 47.39399610246931, 47.14534786769322, 44.512171677180696, 45.653409821646555, 45.8305333001273, 46.476823466164724, 39.54549857548305, 36.393604619162424, 34.67692708969116, 38.55263226372855, 36.28594923019409, 34.93468441282, 35.04830135617937, 37.219651630946565, 39.61099924360003, 36.60130017144339, 35.29339906147548, 34.15650006702968, 38.4675098827907, 39.21779373713902, 42.21106031962803, 47.07627582550049, 46.08998250961304, 47.122252055576865, 45.81849554606846, 45.05852937698364, 46.03065879004342, 44.427181312016074, 40.684568881988525, 41.08094276700701, 37.311569350106375, 36.17075504575457, 35.56109578268868, 35.687532152448384, 36.703622817993164, 39.3136545589992, 40.951751436506, 45.224417618342805, 45.95976284572056, 47.68305853434971, 50.015693868909565, 53.285300731658936, 49.22618395941598, 38.058271408081055, 49.10061958857945, 55.111996037619456, 46.21073872702462, 39.51767104012625, 42.07513965879168, 52.89556932449341, 50.72828027180263, 38.44755118233817, 0.1285031602850982, 0.6923205160668918, 0.15388487545507296, 4.592057500566755, 41.79410934448242, 42.63395547866821, 51.99273429598127, 47.04776736668178, 49.03406279427664, 50.59987408774239, 47.137739590236116, 32.17266082763672, 22.395756789616176, 28.08390130315508, 42.15019409997122, 9.498202238764081, 0.2394006981381348, 0.050491395472948036, 0.13439649476536683, 0.024734754082081572, 0.08957284462771245, 0.0476006700524262, 0.08592437540314027, 0.04579819605818816, 0.046783310161637406, 0.02978904778137803, 0.0525487373982157, 0.02334980304086847, 0.008113170275464654, 0.011676880298182368, 0.04042962359796677, 0.04954409612608807, 0.05660411050277097, 0.02708820190413722, 0.04340026008763483, 0.13516307648803505, 43.9301940373012, 55.97183908735003, 40.50705630438668, 34.91259608949934, 41.17612266540527, 53.740890639168875, 57.227948325020925, 54.10350670133318, 58.84584331512451, 52.61072792325701, 55.47489697592599, 48.80722842897688, 53.07038252694266, 2.840341725519725, 1.2492413776261466, 4.763602878366198, 2.6356955638953616, 0.21854316948779992, 17.41183999606541, 65.05109882354736, 44.438604150499614, 57.36476877757481, 55.05911329814366, 57.134658336639404, 50.2316438811166, 51.65275199072701, 49.94442967006138, 52.29035690852574, 50.304513113839285, 50.77256114142281, 50.21145241601126, 50.776549407414024, 47.67821911403111, 52.75702224458967, 53.08218404224941, 44.628314290727886, 37.40378931590489, 39.3464743750436, 39.22523525782994, 42.831906182425364, 43.60259689603533, 47.2040809903826, 47.53228957312447, 46.89540726797921, 46.37302432741438, 48.92720297404698, 47.98225143977574, 44.186245577675955, 44.14480652127947, 40.658697264535085, 38.067241532461985, 38.76262419564383, 38.82209382738386, 41.31700781413487, 36.97953230994088, 36.970492703574045, 35.91399131502424, 38.615888663700645, 38.00246695109776, 41.73012685775757, 45.4203394481114, 49.08641399656023, 47.04699264253889, 48.696835449763704, 50.44458532333374, 48.67886740820748, 47.97788102286202, 51.108798367636545, 47.465628555842805, 49.07694707598005, 39.80573640550886, 37.00668239593506, 37.961114747183665, 35.97305795124599, 37.28577763693673, 36.81422424316406, 44.86271177019392, 39.46167203358242, 36.74036489214216, 38.675650119781494, 36.51643487385341, 38.4243928364345, 34.77612999507359, 38.63941526412964, 38.150918688092915, 46.389887605394634, 51.57991402489798, 49.50768327713013, 48.14258459636143, 48.81373194285801, 47.17883818490164, 46.90946347372872, 46.79190342766898, 47.690076214926584, 40.65660238265991, 37.24302537100655, 37.10485349382673, 39.72296251569475, 38.244559560503276, 38.15456649235317, 37.643446581704275, 39.2665353502546, 42.28096961975098, 37.583368982587544, 36.93238183430263, 38.56456926890782, 41.36672912325178, 40.95508657182966, 44.554215226854595, 49.83912624631609, 46.69692850112915, 48.45849139349801, 47.07833596638271, 47.596067087990896, 46.478522300720215, 46.30909047807966, 43.05652059827532, 42.89052813393729, 39.189424242292134, 38.351311683654785, 38.01999378204346, 38.83860274723598, 38.68342515400478, 43.136299814496724, 43.168647153036936, 48.69451127733503, 49.7243663242885, 49.333064624241416, 51.80488974707467, 55.345497199467246, 50.69924027579171, 42.03983586175101, 50.78753103528704, 57.002437591552734, 48.58296489715576, 41.4873046875, 44.654863357543945, 54.42377349308559, 53.95445394515991, 40.10686091014317, 0.036738064007035325, 0.6208093304719243, 1.5470830755574363, 5.278553852013179, 45.65889889853341, 48.12302541732788, 56.081832545144216, 53.49465342930385, 53.336647919246126, 57.15260205950056, 52.741100447518484, 42.37251213618687, 25.303722075053624, 29.04100523676191, 53.23369298662458, 13.490055237497602, 0.2567163147032261, 0.03967520122283271, 0.07249835226684809, 0.040773342297013314, 0.02729735353828541, 0.03401393250429204, 0.05882428386913879, 0.03279894769990018, 0.15151392482221127, 0.10133397353014775, 0.19035025659416402, 0.1608402393758297, 0.15090776234865189, 0.08461598346808127, 0.1712035182863474, 0.09230319490390164, 0.16873556428721972, 0.09841246636850493, 0.1907853875309229, 0.38899924073900494, 51.64800289699009, 63.646006311689106, 52.268310274396626, 50.12769535609654, 42.235691683632986, 62.31157003130232, 62.914215087890625, 61.084552901131765, 63.36629268101284, 59.83322402409145, 60.705612046378, 53.57367181777954, 59.645643506731304, 3.984688537461417, 4.211412600108555, 14.795263051986694, 5.473330531801496, 0.45769396317856653, 21.32409269469125, 63.89601639338902, 45.516221114567344, 61.20008059910366, 58.11885677065168, 59.2955515725272, 52.6491653578622, 54.60517358779907, 51.083364486694336, 56.30717304774693, 52.58488757269723, 54.80011224746704, 53.38066823141915, 51.52336263656616, 50.806548254830496, 53.959814480372835, 54.23083938871111, 45.8897145816258, 39.86239896501814, 42.154998779296875, 40.69437279020037, 43.99199478966849, 46.19327790396554, 50.09879084995815, 48.39088542120797, 51.23066629682268, 49.35687610081264, 52.57612589427403, 49.81991100311279, 47.068212441035676, 45.635476521083284, 43.15976735523769, 39.613055910382954, 39.88378552028111, 40.88854019982474, 44.87706674848284, 39.847957134246826, 39.09600223813738, 37.77880443845476, 39.87996401105608, 40.334813935416086, 45.06959090914045, 47.92796516418457, 52.20721129008702, 48.87024859019688, 51.82487276622227, 54.33851214817592, 52.039884771619526, 49.42840085710798, 53.48745856966291, 50.86597619737898, 51.05609975542341, 40.69742999758039, 38.58376019341605, 37.89109427588326, 35.27691446031843, 37.850367409842356, 36.87739379065377, 48.61623634610857, 41.87245028359549, 37.68498291288103, 38.55260794503348, 37.37673650469099, 40.206338269369944, 35.4273499080113, 39.4333998135158, 38.91462646211897, 48.464998381478445, 54.75815555027553, 51.35180466515677, 50.629101685115266, 51.28913191386631, 49.82675845282418, 50.44286217008318, 49.46883589880807, 51.1244352885655, 43.84868471963065, 40.098710673195974, 39.452347551073345, 42.98332480021885, 40.14863000597273, 40.701032638549805, 38.921397481645855, 41.48931966509138, 44.92365442003523, 39.299681731632774, 39.66510834012713, 40.121101243155344, 42.98885209219796, 42.883923871176584, 46.934542996542795, 51.91727685928345, 47.55496849332537, 51.946560042245046, 49.15035131999424, 49.151897294180735, 48.38929775782994, 48.58015087672642, 44.900183405194966, 44.59911796024868, 41.650212151663645, 40.023944582257954, 41.03739840643746, 40.53465454918997, 39.721659728458945, 43.431097984313965, 44.838063035692485, 49.751842975616455, 50.67563377107893, 52.44598960876465, 53.74640056065151, 58.869342122759136, 52.558536529541016, 41.682455267224995, 53.409888880593435, 60.255014419555664, 50.72431632450649, 44.84064776556832, 46.30559206008911, 57.593114376068115, 53.418556758335654, 44.908712318965364, 0.19436263771993773, 1.4925317913293839, 2.8460312145096913, 5.042280793190002, 51.677900995527, 50.43394763129098, 63.06092630113874, 57.35446112496512, 60.35588836669922, 59.62550067901611, 60.84067113058907, 42.966767242976594, 31.934584277016775, 37.54438264029366, 61.43665286472866, 21.323962415967667, 0.2679573600845677, 0.16324088270110743, 0.13381850506578172, 0.13571377550917013, 0.22808436251112393, 0.12193591839500836, 0.2544832288154534, 0.09694659324096781], [0.038846859242767096, 0.053919876859124215, 0.03938276959317071, 0.0455277828898813, 0.06940507396523442, 0.015204879022868616, 0.07951040778841291, 0.04372202139347792, 0.12604022744510854, 0.041413051541894674, 0.18985046127012797, 0.08816180391503231, 15.451544727597918, 50.47425760541643, 43.95212255205427, 35.72613981791905, 28.290071725845337, 45.43602500643049, 49.46304110118321, 57.45695400238037, 52.293424538203645, 50.17918150765555, 48.855640002659385, 39.190341404506135, 52.11640528270176, 12.38063723700387, 1.0062545133488519, 2.618664877755301, 2.5345048223223006, 1.8674651639802116, 18.259508064814977, 42.70502165385655, 47.901360511779785, 53.58368764604841, 54.412138734545024, 52.15095867429461, 52.471524238586426, 50.58152042116438, 48.044392653873985, 50.08542946406773, 48.62300041743687, 51.236919675554546, 49.0084274155753, 50.72932250159127, 51.51691123417446, 49.89109877177647, 44.351164545331685, 38.6439802306039, 36.12150274004255, 37.99260745729719, 35.862783091408865, 40.547227314540315, 43.54969678606306, 46.635172912052695, 46.772882734026226, 48.20928382873535, 46.40066078730992, 48.483213084084646, 46.69060911451067, 44.087348393031526, 42.13323354721069, 39.23738765716553, 36.21586275100708, 38.64675603594099, 35.26360171181815, 37.93726852961949, 35.950729915073936, 35.882359640938894, 35.232814243861604, 36.14695746558053, 37.24150371551514, 43.317279543195454, 44.873880999428884, 47.300393445151194, 46.99446426119123, 45.200793743133545, 45.581815583365305, 48.18857472283499, 46.807088715689524, 46.736439432416645, 47.013905320848735, 46.14121157782418, 39.76383529390608, 36.17137343542916, 36.19715472630092, 37.295098645346506, 36.68981327329363, 38.054105963025776, 42.29435532433646, 40.92677961077009, 36.453751700265066, 38.47311360495431, 37.955396379743306, 39.44657359804426, 38.18208483287266, 38.261700766427175, 40.38515363420759, 43.83919695445469, 49.66606746401106, 49.025068351200645, 47.09998655319214, 45.39512096132551, 45.99602549416678, 46.22065033231463, 45.796650409698486, 46.86607892172677, 45.21451643535069, 38.815649373190745, 34.793371949877056, 34.55912733078003, 34.24103879928589, 34.32164485113961, 32.93707384381975, 34.9350700378418, 36.17407628468105, 37.341950348445344, 36.51289824077061, 35.766571385519846, 37.7692471912929, 41.469447817121235, 44.23002617699759, 46.610725675310405, 46.67229018892561, 46.24662617274693, 46.77996294839041, 45.465912682669504, 42.751480783735005, 43.37053748539516, 41.76983233860561, 38.097400188446045, 38.035283293042866, 36.48833635875157, 34.342385223933626, 36.231430189950125, 35.53301463808332, 35.5808356148856, 35.6755256652832, 37.73890788214547, 38.839255877903526, 42.68245390483311, 47.74898999077933, 48.89571373803275, 51.95113890511649, 54.0935012953622, 47.25477852140154, 50.85322625296456, 50.72247505187988, 44.20388010569981, 45.38753700256348, 50.27284322466169, 54.878998620169504, 29.132273299353464, 0.8124801112072808, 3.476481224809374, 1.2356306165456772, 15.885569163731166, 54.78904724121094, 47.23931877953665, 49.2526843888419, 50.319545541490825, 48.77267156328474, 55.14227281297956, 41.021650314331055, 30.422121252332413, 33.56093175070626, 28.140937328338623, 42.84476382391793, 2.4977036884852817, 0.179492339225752, 0.04987836961767503, 0.02262268491488482, 0.05434277720217194, 0.07331117615103722, 0.07090492812650544, 0.10655405877956323, 0.04153741683278765, 0.024321972392499447, 0.028870579387460436, 0.015466206607275775, 0.04808338325736778, 0.07719564664044551, 0.04902576322534254, 0.04601959524942296, 0.021076091565191746, 0.1277009690446513, 0.06729182414710522, 0.1812978937689747, 0.1051523479233895, 22.391860587256296, 60.18260724203927, 44.487637587956016, 35.77907814298357, 40.95547219685146, 49.780511243002756, 55.965801102774485, 61.250705174037385, 57.37609086717878, 54.46513611929757, 55.29769706726074, 45.41553824288504, 56.823285239083425, 13.06200885772705, 1.3373041493552071, 2.5301294113908495, 4.933834612369537, 2.2810067449297224, 22.24562532561166, 45.92555686405727, 48.870477880750386, 55.16129698072161, 55.29891995021275, 54.42292581285749, 53.79887335641043, 51.74678543635777, 50.22877427509853, 52.46624708175659, 50.516749313899446, 53.23350885936192, 51.53610910688128, 53.898444516318186, 52.39489950452532, 50.28711135046822, 46.47773020608084, 39.21023062297276, 37.10951573508126, 39.7515995161874, 37.38579000745501, 42.42838607515608, 44.958054951259065, 46.45490884780884, 49.36516877583095, 51.466984953199116, 47.19150822503226, 49.0741400037493, 49.16768707547869, 46.26233604976109, 43.76733521052769, 41.406590938568115, 38.66404662813459, 40.043726103646414, 36.85355799538748, 39.580135345458984, 38.2795124735151, 38.53160701479231, 36.15608392442976, 38.08887127467564, 39.64930813653128, 46.27504777908325, 47.597196170261924, 49.89085905892508, 49.51595163345337, 47.57506615774972, 49.32266664505005, 51.497803688049316, 48.93121903283255, 50.05684110096523, 49.47131640570504, 46.66681153433663, 40.59554508754185, 35.59258154460362, 35.77742447171892, 38.41450902393886, 37.02511249269758, 37.65984433037894, 45.10158041545323, 41.58131728853498, 36.16536324364798, 37.497430188315256, 39.206412587847026, 38.586178166525706, 37.7462660244533, 37.866744313921245, 39.01920032501221, 44.71255077634539, 53.444695881434846, 49.96405138288225, 49.418628215789795, 49.78455856868199, 46.50649227414812, 47.37301254272461, 48.34239741734096, 48.64690222058977, 46.261425835745676, 38.89121103286743, 36.09299775532314, 36.594265120370046, 37.04219463893345, 36.77241693224226, 34.67573894773211, 38.27333205086844, 39.23235716138567, 38.0870577948434, 37.05277674538748, 37.20967401776995, 40.03259856360299, 45.08722196306501, 46.862709045410156, 48.143710204533164, 49.46677923202515, 49.77758605139596, 47.90509169442313, 46.89273568562099, 45.20077289853777, 45.84546497889927, 44.618107386997764, 41.329594475882395, 39.17598990031651, 39.337354864392964, 37.21776519502912, 37.91144902365548, 36.56785501752581, 36.967591830662315, 38.05051721845354, 39.97580051422119, 41.1395195552281, 44.49146951947893, 49.21306923457554, 50.50551755087716, 53.5155987739563, 56.04020241328648, 49.03161702837263, 52.95353814533779, 53.538559096200125, 46.881187779562815, 47.72337545667376, 52.217887197222026, 56.84491845539638, 32.5958617074149, 1.2079609355756213, 3.734374906335558, 1.5340670368501117, 18.867310421807424, 55.91239030020577, 52.221642698560444, 56.21072162900652, 54.52038819449288, 57.56819118772234, 61.50860146113804, 44.18517902919224, 40.489251545497346, 30.74817589351109, 30.574894768851145, 51.05366441181728, 4.442955672740936, 0.36475640588573044, 0.07811343310666935, 0.09835637866386346, 0.01401413742652429, 0.05630576544042144, 0.07604745003793921, 0.03754833659955433, 0.05666060193574854, 0.11603288086397306, 0.1645494917673724, 0.10806898320359842, 0.11469456553459167, 0.28305549706731525, 0.16713453376931803, 0.17593392516885484, 0.07975828341607537, 0.20343653724661895, 0.18697930819221906, 0.3540871755353042, 0.30122552492788857, 24.405121973582677, 68.91345650809151, 54.49266835621425, 45.07737289156233, 39.43206228528704, 55.661775725228445, 58.03079182761056, 68.62279946463448, 62.88654736110142, 60.868304116385325, 61.54587854657854, 51.21469586236136, 61.43832043239048, 17.333002260753087, 2.7588925531932285, 10.891984820365906, 7.590259041104998, 6.8192508816719055, 27.42031707082476, 47.81265980856759, 48.776107447487966, 56.43413053240095, 56.52233443941389, 56.547577244894846, 55.23164054325649, 55.32507644380842, 52.05739770616804, 53.91337619509016, 53.43461751937866, 56.53897884913853, 53.08819423403059, 57.08667755126953, 55.606867585863384, 53.20287077767508, 47.86817591530936, 40.354310580662315, 39.181663104466026, 41.67679248537336, 38.091004371643066, 44.61518219539097, 48.78070715495518, 49.28670971734183, 51.235891342163086, 52.70399011884417, 48.965883595602854, 53.05429744720459, 51.57717990875244, 47.448529039110454, 46.41277149745396, 42.25031416756766, 41.46961109978812, 41.958653109414236, 38.73436934607369, 42.01912328175136, 39.68243019921439, 40.0434308052063, 38.77274077279227, 40.55926159449986, 40.916166237422395, 47.613868372780935, 49.963641439165386, 52.81194428035191, 52.166949953351704, 48.934859888894216, 51.995881829942974, 52.85011420931135, 51.65889072418213, 50.52433327266148, 50.93626764842442, 51.09793485913958, 41.59760039193289, 35.32750429425921, 36.12935420445034, 37.683270181928364, 35.93143824168614, 38.7074659211295, 47.939975125449045, 41.396453516823904, 36.189369269779746, 37.77621970857893, 39.75466367176601, 39.28606326239449, 39.27916717529297, 37.76285137448992, 40.51805877685547, 44.652626037597656, 56.22671290806362, 54.108259269169395, 50.70564651489258, 50.91730948856899, 49.319112641470774, 49.47282069069998, 50.326507636478965, 51.027726786477224, 50.9298996244158, 44.43403918402535, 38.85797432490757, 39.690840993608745, 38.43494367599487, 38.79150438308716, 36.52624920436314, 39.3540791784014, 40.341053417750764, 41.10712357929775, 39.66583095278059, 38.944722584315706, 42.04872955594744, 45.80472421646118, 49.67113617488316, 51.56885944093977, 50.820448126111714, 51.96247141701834, 49.65231697899954, 50.21605907167707, 47.14072036743164, 48.72979770387922, 45.99951001576015, 43.840492793491904, 41.21772847856794, 41.3266727583749, 38.6209990637643, 41.097403049468994, 38.5884120123727, 38.869056701660156, 39.34893751144409, 41.10953113010952, 42.45557090214321, 47.02166298457554, 52.376639638628276, 52.84476409639631, 55.228934219905305, 55.4615147454398, 47.436592033931184, 56.29370049067906, 55.17584650857108, 48.371263708387104, 50.7276862008231, 55.684364318847656, 58.48085444314139, 36.567448547908235, 1.9513926718916212, 5.819428988865443, 2.420678347349167, 19.85814959662301, 66.75732626233781, 57.24991158076695, 60.88843304770333, 58.95520101274763, 59.297219140189036, 63.94893387385777, 52.47800343377249, 42.044866357530864, 44.8004663331168, 39.18782615661621, 60.706147057669504, 7.8017926045826504, 0.49636275108371464, 0.16240800810711725, 0.18566760500626905, 0.15226897144956247, 0.12301462622625486, 0.1314669062516519, 0.13058053595679148, 0.10188762417861394], [0.020258594271061674, 0.08269188885710069, 0.0630375249311328, 0.032579499296844006, 0.06391601064907652, 0.008689372883444386, 0.044827578855412345, 0.026783887429961135, 0.15660065758441175, 0.04268725209736398, 0.05448062837656055, 0.08839973221932139, 2.1816883257457187, 43.67375339780535, 48.68076426642281, 30.206508227757045, 21.67508442061288, 42.933798040662495, 43.56216880253383, 50.66930396216256, 49.65332794189453, 52.40635360990252, 49.515263761792866, 46.46381991250174, 48.12509945460728, 27.458059685570852, 0.7473715277654784, 1.317679939525468, 1.2946316791432244, 13.824880242347717, 33.08945478711809, 41.488645689828054, 55.91799054827009, 53.42809663500105, 54.05174609592983, 50.74995865140642, 53.735377243586946, 51.98549427304949, 54.20146240506853, 51.578013692583355, 51.452602182115825, 50.04027312142508, 49.188278062003, 47.4434221131461, 45.38337850570679, 40.94615118844168, 36.43452603476388, 35.45111969539097, 36.43652016775948, 35.889255728040425, 36.60929754802159, 39.85994972501482, 43.29027189527239, 46.80093955993652, 48.22163772583008, 48.3811787877764, 46.93165602002825, 46.467811652592246, 48.29779693058559, 48.79132400240217, 43.62056146349226, 40.50909212657383, 38.423274176461355, 37.39815780094692, 37.91746963773455, 36.31019844327654, 37.155182770320344, 36.76004219055176, 36.17335714612688, 36.58349193845476, 39.522440978458945, 46.62591791152954, 46.58069903509957, 46.085837909153526, 45.15419912338257, 46.60489266259329, 45.704096930367605, 47.73231431416103, 46.41855934688023, 46.70593336650303, 46.25912945611136, 43.511207239968435, 38.79571499143328, 38.647541182381765, 37.198779242379324, 37.249980517796104, 36.78188385282244, 37.82912329265049, 44.4794282913208, 41.82416377748762, 35.78863539014544, 38.24587971823556, 37.03461068017142, 37.649665219443186, 38.020970003945486, 38.086071150643484, 37.96967492784773, 42.37744535718645, 46.63435649871826, 49.24270330156599, 46.47549288613455, 47.677625043051584, 46.46169376373291, 47.06591953550066, 45.03352975845337, 44.00489412035261, 44.308982031685964, 40.67074891499111, 36.38026407786778, 34.54845837184361, 35.42311150687081, 34.559335776737754, 34.6898889541626, 36.19914885929653, 36.30397285733904, 35.80278539657593, 34.742410387311665, 37.01969289779663, 38.79665994644165, 42.033009256635395, 45.14657000132969, 44.46752255303519, 44.77351427078247, 44.34873267582485, 45.93771273749215, 44.27172926494053, 42.87823329653059, 41.01603616986956, 36.79410573414394, 36.762963908059255, 33.68054151535034, 34.86090496608189, 34.31947353907994, 34.721350397382466, 34.89037227630615, 35.17910814285278, 35.5460980960301, 37.1512188230242, 38.26208291734968, 40.01989030838013, 42.71511738640921, 48.48554767881121, 49.29205288205828, 52.97536938531058, 53.27323171070644, 52.29301459448678, 52.5719222341265, 49.86565794263567, 45.677943910871235, 52.90822546822684, 48.90768895830427, 31.146120071411133, 2.9548360960824147, 0.6718396150640079, 0.3616907846714769, 26.634632144655498, 57.262505190713064, 46.860770498003276, 47.2116163117545, 48.65951667513166, 38.23545742034912, 39.787997654506135, 41.21442461013794, 25.12192940711975, 16.42614769935608, 33.44967719486782, 35.33497708184378, 0.44896005040832926, 0.017956265580973456, 0.06229007789599044, 0.06659874133765697, 0.015512613313538688, 0.02429976054866399, 0.01472390117123723, 0.03370122624827283, 0.07031135247754199, 0.024127646748508726, 0.053008611114429574, 0.025267147924751043, 0.037948237998144965, 0.03279189432838133, 0.04253157241536038, 0.035056101224784336, 0.046017980336078575, 0.1448653537247862, 0.024063116371897713, 0.034300467664641995, 0.0969829016498157, 4.76573336975915, 52.98020880562918, 48.65532691138131, 30.827736241476877, 33.73594645091465, 44.9455759865897, 49.68594626017979, 56.71015119552612, 54.35608761651175, 57.56439052309309, 53.85902043751308, 50.50647292818342, 53.458894525255474, 30.252710274287633, 0.5352657692773002, 1.0834760325295585, 2.7695350221225192, 19.208925553730555, 36.45304993220738, 42.231411593300955, 55.857666288103374, 56.24387148448399, 55.6751822744097, 54.423235007694785, 56.17583819798061, 54.23135355540684, 55.732907908303396, 53.43556594848633, 53.46106931141445, 51.623830114092144, 50.747627530779155, 50.05413825171334, 48.335206031799316, 44.595195702144075, 38.10634599413191, 36.797725745609824, 37.24404328210013, 36.864880084991455, 38.82435546602522, 41.36749342509678, 45.60929570879255, 47.748680795942036, 51.83282150541033, 50.0693895476205, 48.16033376966204, 48.293655804225374, 49.4977890423366, 50.19848707744053, 45.38433735711234, 42.78336954116821, 39.661359786987305, 37.977099078042166, 38.22545548847744, 37.51060744694301, 38.52293913705008, 37.21849128178188, 38.318794114249094, 38.62416396822248, 43.05271993364607, 48.691648619515554, 48.601148332868306, 48.20248849051339, 46.59941748210362, 48.53680453981672, 47.97549084254673, 48.968388421194895, 48.60348640169416, 49.58253622055054, 49.71000787190029, 46.01494196483067, 39.96354389190674, 38.14551646368844, 36.424569266183035, 36.421053477696006, 36.28418091365269, 37.42792388371059, 46.81865051814488, 43.07754584721157, 38.71693631580898, 38.24878406524658, 36.19750213623047, 37.94841691425869, 36.496976443699424, 38.8263704436166, 38.5396842956543, 42.67985527856009, 49.49253273010254, 49.91594900403704, 48.64575924192156, 50.74572025026594, 49.59886448723929, 48.78800971167428, 47.778631005968364, 47.55275201797485, 46.02459648677281, 41.91181182861328, 39.11790296009609, 36.39849962506975, 36.00919553211757, 37.64891133989607, 36.85366221836635, 38.04115799495152, 37.87378978729248, 36.97018003463745, 35.94718285969326, 37.55639607565743, 41.100574902125764, 43.771514551980154, 46.36369637080601, 48.07601390566145, 46.69997181211199, 46.39402525765555, 47.85442195619856, 47.740266527448384, 44.412148884364534, 42.32467378888811, 39.61582129342215, 38.753066948481965, 35.978025913238525, 37.85871567044939, 34.80830362864903, 35.8853543145316, 36.67926590783255, 37.41925948006766, 37.64051444189889, 39.45483848026821, 39.598280566079275, 42.720908709934776, 44.201938084193635, 51.95979636056082, 51.308024065835134, 54.523598262241904, 52.568635736192974, 54.606135913303916, 55.10418626240322, 53.097219944000244, 49.00084693091256, 56.69784940992083, 50.31402519771031, 35.72683811187744, 2.6955334501607076, 0.8979882800153324, 0.18638067745736667, 30.58746406010219, 63.5749957220895, 49.759423460279194, 54.12393093109131, 54.8222005707877, 45.641702107020784, 43.94969763074602, 47.89729234150478, 35.54199171066284, 17.335956982203893, 38.38979775565011, 42.96290751865932, 0.6454117074608803, 0.153473683233772, 0.039663031697273254, 0.05710268446377345, 0.06354546946074281, 0.010443872755526431, 0.04047322965094021, 0.024453499620514255, 0.029444979636796882, 0.10837688882436071, 0.12945992180279323, 0.10434923387531723, 0.1204939636268786, 0.18755192389445646, 0.14208931768579142, 0.14093936367758683, 0.10097294540277549, 0.2382367934499468, 0.1183803134730884, 0.13241752024207795, 0.3338456345455987, 6.415171444416046, 64.39605740138462, 58.20639017650059, 41.12581075940813, 31.929380076272146, 55.088507652282715, 53.27164057322911, 60.340046473911826, 59.267195974077495, 64.5704710824149, 57.358411175864084, 58.15498045512608, 56.76840141841343, 36.57476500102452, 1.3919873407908847, 8.131951894078936, 4.304742540631976, 23.810540301459177, 43.99218586512974, 44.46056393214634, 58.485224860055105, 57.885640484946116, 58.09053243909563, 55.90353829520089, 59.41406004769461, 55.46659735270909, 58.59606947217669, 54.497865608760286, 55.745296546391074, 53.79027843475342, 53.05197327477591, 50.90451785496303, 50.58976445879255, 45.6443042073931, 40.12021534783499, 38.27062920161656, 38.83478818620954, 39.58492265428816, 39.542625495365684, 43.07537800925118, 48.515470096043174, 49.808102539607454, 54.48537622179304, 52.17560740879604, 49.31659739358084, 50.47841610227312, 52.5381817817688, 53.11667142595564, 47.983915533338276, 45.4054286139352, 41.77842378616333, 39.099865436553955, 40.80261182785034, 39.075126375470845, 39.688996246882844, 40.72454881668091, 40.71792023522513, 41.32526574816023, 45.64131300789969, 50.91915423529488, 51.89518506186349, 49.90802458354405, 49.91092893055507, 52.18319136755807, 52.57755722318377, 51.87320443562099, 49.6330565725054, 51.71423660005842, 52.19779995509556, 47.61709233692714, 40.86092111042568, 38.912187644413535, 37.9996703011649, 37.697322913578574, 37.852896554129465, 39.07843024390084, 52.04408148356846, 43.612463338034495, 38.11853313446045, 37.954555647713796, 37.026675837380544, 38.01107576915196, 38.6351386478969, 38.49780750274658, 39.181534562792095, 43.613491671425955, 51.1504875591823, 54.06545489174979, 50.06135048185076, 53.096601554325645, 51.31399951662336, 50.83475794110979, 50.24478987285069, 49.56310905729021, 50.01239000047956, 45.308094773973735, 41.986067226954866, 39.18647125789097, 40.104971000126426, 39.76413754054478, 39.71256453650338, 40.16427040100098, 40.76717254093715, 39.80814743041992, 37.892393589019775, 40.256924629211426, 43.06024135862078, 46.0096891266959, 49.22574274880545, 49.64337464741298, 48.564024107796804, 47.23697028841291, 51.52906015941075, 50.01352603094918, 46.595992020198274, 44.20928233010428, 42.075935227530344, 40.720508439200266, 37.42746877670288, 40.80496031897408, 37.46648291179112, 38.24160310200283, 39.21793270111084, 38.103299209049766, 38.63988079343523, 40.12993935176304, 41.40235948562622, 44.33698327200753, 45.78799990245274, 54.23933008738926, 54.10667855398995, 54.934445244925364, 53.492391790662495, 55.541568415505544, 58.38540703909737, 56.598083700452534, 51.271167346409385, 57.93725517817906, 51.82391391481672, 37.61870404652187, 6.9702295916421075, 1.5336599158389228, 0.8229943641594478, 32.978912421635215, 70.87255668640137, 54.85120929990496, 57.00442477634975, 57.46981511797224, 49.64902005876814, 50.56560557229178, 51.760949339185444, 35.518249716077534, 24.80244255065918, 45.50236293247768, 53.07210568019322, 1.0019066780805588, 0.26453922635742594, 0.09272768641156809, 0.1912925788866622, 0.16479635637785706, 0.1157610190234014, 0.08056827780923673, 0.10677382270140306, 0.16979995502957276], [0.07576831430196762, 0.024623674506853734, 0.051411190402827094, 0.025477200314136486, 0.018659886039261307, 0.03188724090744342, 0.08177997171878815, 0.02753186202608049, 0.009521460376812943, 0.05891410833490746, 0.030353412497788668, 0.027013832769755806, 0.22902190791709082, 31.113130024501256, 52.913471358163015, 30.867452144622803, 27.951201132365636, 42.26143823351179, 53.12590210778372, 53.193570613861084, 56.17031438010079, 48.53980963570731, 50.83260399954659, 48.29584101268223, 46.17045307159424, 40.392754963466096, 0.18131025667701448, 1.3513155175106866, 1.1280225621802467, 10.365636195455279, 19.116403341293335, 47.32811328342983, 60.78725337982178, 51.26513631003243, 53.582214627947124, 48.35507093157087, 50.654243741716655, 46.59476913724627, 49.45095470973423, 47.58397374834333, 49.916914803641184, 42.872570514678955, 42.532213006700786, 39.0399545942034, 39.23221124921526, 36.18439088548933, 36.57188149860927, 35.17305973597935, 37.24205262320382, 36.97883401598249, 37.182041031973704, 37.241680894579204, 43.993596349443706, 46.27655553817749, 50.27639722824097, 48.145735604422434, 51.26997920445034, 36.526023387908936, 39.803304536002024, 52.797860281808035, 46.27289383752005, 41.84996938705444, 39.35371092387608, 37.57991572788784, 35.94485173906599, 35.98050989423479, 36.41696446282523, 36.52101721082415, 37.15267447062901, 35.5269592830113, 40.68080990655081, 46.84059987749372, 46.81753185817173, 46.55955914088658, 47.234423773629324, 45.27547992978777, 45.34967974254063, 45.84617369515555, 46.94248826163155, 46.61166715621948, 48.44310113361904, 42.533206599099294, 36.92422464915684, 37.251311097826274, 37.60464089257376, 38.07572875704084, 36.36415120533535, 37.67214959008353, 43.93383836746216, 41.18159784589495, 37.215510504586355, 37.80839681625366, 37.48975937707083, 37.046690123421804, 37.50896419797625, 38.34233113697597, 38.74504177910941, 44.34926421301705, 47.03691775458199, 49.056832041059224, 47.267490250723704, 46.715309960501536, 46.02089657102312, 46.93672473090035, 46.56711530685425, 45.556305272238596, 46.918506554194856, 43.70673649651663, 38.96591459001814, 33.0690027645656, 34.403946263449534, 34.292382512773784, 33.88916465214321, 33.29801191602434, 33.34461348397391, 34.46304416656494, 35.205313273838584, 33.53993776866368, 37.559564454214915, 39.722653320857454, 44.01715421676636, 43.90613242558071, 44.88744388307844, 42.36245461872646, 39.51213679994856, 38.71023825236729, 37.097498825618196, 38.81781721115112, 36.144855635506765, 32.69785778863089, 34.57126930781773, 34.6523026738848, 34.23644256591797, 34.03683124269758, 34.801237310682026, 37.27098492213658, 40.76333713531494, 43.94803353718349, 45.193581512996126, 46.227834769657676, 43.717457566942485, 45.365188121795654, 47.44585050855364, 49.82233592442104, 50.31746455601284, 51.7728932925633, 51.937374523707796, 51.857289586748394, 50.00511871065412, 51.96453850609915, 51.3326450075422, 12.30478114741189, 0.9582319302218301, 1.2261541421924318, 0.3497428957905088, 32.11575160707746, 48.17999717167446, 48.117317472185405, 46.90500620433262, 46.886145319257466, 44.426545551845, 47.89524957111904, 35.41390861783709, 26.673410040991648, 24.844797032220022, 46.58708790370396, 15.472288574491229, 0.17901433844651493, 0.07138913071581296, 0.018009808779295002, 0.026977824612653682, 0.03559307687516723, 0.05674593449969377, 0.07159864197352103, 0.017654736493048922, 0.05755123682320118, 0.12889335863292217, 0.06006158569029399, 0.036426280558641465, 0.021706360691626157, 0.0449219325424305, 0.07086040944393192, 0.051795991004577706, 0.03627221918265734, 0.06965228462857859, 0.051592481389109573, 0.07759108327861343, 0.05300525575876236, 0.4667678219931466, 41.07790987832205, 59.27025318145752, 35.86348485946655, 35.619832379477366, 50.187411648886545, 52.424856662750244, 58.39102118355887, 59.52609280177525, 52.83443907329014, 55.143954277038574, 53.51116929735456, 50.32068852015904, 44.393524238041465, 0.08942780776747636, 1.5939121970108576, 1.0516918237720216, 11.398932337760925, 23.510812384741648, 48.121458598545615, 63.404681478227886, 52.2344308580671, 55.46859148570469, 49.310545512608115, 53.92777286257063, 49.96044874191284, 52.2109181540353, 48.46735034670149, 51.63179274967739, 45.904858180454795, 45.42317083903721, 41.878054005759104, 40.962806020464214, 38.47828653880528, 38.75860118865967, 38.214512075696675, 38.95989397593907, 38.61095196860177, 38.10497372491019, 40.00669567925589, 46.62541764123099, 48.43373843601772, 51.190519605364116, 49.713777269635884, 51.48339312417166, 38.07866437094552, 42.12166479655674, 53.32587821143014, 48.24649838038853, 43.611021586826865, 39.62114361354283, 38.41906009401594, 37.3808776310512, 37.776560170309885, 38.49994059971401, 38.33894736426217, 38.20060178211757, 37.1343103817531, 43.38801220485142, 49.536108357565745, 49.05214548110962, 48.47818258830479, 48.719552585056846, 49.41059609821865, 47.45583159582955, 47.828008379255024, 49.479536124638145, 49.32845796857561, 49.66944776262556, 44.80802944728306, 36.16432796205793, 37.579870564596995, 38.72584738050188, 37.145965984889436, 36.984118121010916, 38.18638924189976, 46.32617957251412, 40.54960707255772, 36.2893260547093, 37.41618142809187, 36.93342406409127, 38.81973838806152, 36.39148889269148, 38.713055746895925, 39.27324383599417, 45.10825763429914, 46.966108662741526, 49.45673213686262, 50.03408922467913, 48.99601445879255, 47.651419912065776, 49.86609220504761, 47.12374939237322, 47.91988788332258, 48.822976521083284, 45.36190857206072, 40.83542816979544, 35.59526007516043, 36.40164368493216, 37.224633489336284, 34.97519588470459, 35.23707001549857, 35.543794768197195, 36.71436125891549, 36.63456467219761, 36.27162551879883, 38.96759952817644, 42.53095885685512, 45.46832023348127, 45.57224096570696, 46.818469864981516, 44.17297451836722, 43.3090945652553, 41.65604516438076, 39.070068086896626, 39.5411559513637, 37.31219468797956, 36.08103295734951, 36.802777085985454, 36.81939370291573, 35.50291851588658, 36.031533990587505, 37.8034462247576, 39.08249841417585, 43.35987547465733, 46.6721442767552, 47.69401931762695, 48.12981728145054, 46.93250370025635, 48.00678900309971, 51.11829308101109, 51.66194445746285, 52.62506900514875, 54.64516394478934, 54.11591618401663, 55.31964990070888, 52.84159919193813, 54.10740464074271, 52.41175583430699, 14.292303800582886, 1.490907324211938, 2.099417746067047, 0.5051497252924102, 38.85563973018101, 52.2994555745806, 52.815696307591026, 53.680899892534526, 50.08826780319214, 46.62099511282784, 47.07745701926095, 43.92822074890137, 27.720491409301758, 19.630252156938823, 53.727101939065115, 20.32493131501334, 0.21053182865892137, 0.007474098853500826, 0.038732777150081735, 0.02785309068193393, 0.024981564409764748, 0.07610811106860638, 0.03990045449297343, 0.010580445739573665, 0.027491390804893205, 0.22495689961527074, 0.1655588261783123, 0.2377035463494914, 0.10506905096450023, 0.15413011158151285, 0.11147227058453218, 0.2392747348972729, 0.12154523150197097, 0.21823394750910147, 0.18276777703847202, 0.22092527523636818, 0.15194355962531908, 0.8643293061426708, 50.57411016736712, 65.44011456625802, 40.64747592381069, 37.37671913419451, 55.73184830801827, 61.17669991084507, 63.02876308986119, 65.62326908111572, 59.00258772713797, 59.96485069819859, 57.63117660794939, 54.89279774257115, 49.99016618728638, 0.2295053776885782, 6.687764474323817, 2.9939353466033936, 12.45715774808611, 30.3221366746085, 49.63401542391096, 64.87962423052106, 56.389801025390625, 57.44806725638253, 51.616002968379426, 56.08373635155814, 50.635643414088655, 54.06670209339687, 52.69172307423183, 54.514287676130024, 48.05451617922102, 47.204814025333945, 43.598973410470144, 43.475500447409495, 39.871084213256836, 39.55189439228603, 39.061851842062815, 40.929784706660676, 40.76763459614345, 41.128652572631836, 40.77659429822649, 48.628715310777935, 48.49099159240723, 52.43375383104597, 51.951687812805176, 53.25508301598685, 38.62150280816214, 44.622029645102366, 56.12481410162789, 49.8969943182809, 44.85531193869454, 42.30290160860334, 40.024090494428364, 39.97052335739136, 40.871763774326865, 40.57484640393938, 40.389590059007915, 40.67487267085484, 39.244075298309326, 45.59963423865182, 52.839372294289724, 51.47852938515799, 50.298808642796104, 53.174449171338765, 50.86247430528913, 49.186120646340505, 49.01813057490757, 51.892190388270784, 51.93886491230556, 52.317381926945274, 46.2344251360212, 37.46051440920149, 38.067085197993684, 38.92682749884469, 38.1447035244533, 36.669003418513704, 38.64797197069441, 51.08433723449707, 41.47333533423287, 36.70065941129412, 37.7334292275565, 38.03934104101998, 39.66713374001639, 36.2513541494097, 38.13189104625157, 38.808068888528005, 46.506391525268555, 48.66829572405134, 52.47962931224278, 53.51247903278896, 52.377417836870464, 49.938534123556956, 52.89892530441284, 50.250386646815706, 50.521369865962434, 50.945164816720144, 47.16828734534127, 43.46298326764788, 38.667840344565256, 39.37459373474121, 39.36221204485212, 36.810496534620015, 37.986197744097026, 36.278337478637695, 38.16427312578474, 39.38123273849487, 37.96635716302054, 41.07620756966727, 43.62665850775582, 48.9532413482666, 48.454176562173025, 48.78065504346575, 45.53777095249721, 43.88160875865391, 44.464072772434776, 42.33194160461426, 43.112554345812114, 40.4164274760655, 36.202070576804026, 38.77112531661987, 38.96063395908901, 36.50976112910679, 37.956775597163606, 39.36787135260445, 40.57647228240967, 46.00801113673619, 48.3219245501927, 49.61218418393816, 49.614595208849224, 48.46297645568848, 48.916412421635215, 51.71539000102452, 52.58666283743722, 54.603700569697786, 56.24799176624843, 54.96552106312343, 57.286070006234304, 56.44280535834176, 56.94806446347918, 55.87937593460083, 18.029293400900706, 2.915982638086591, 3.160867337669645, 0.4422910825482437, 42.169138363429475, 55.81667191641671, 58.580005237034385, 57.53273800441197, 57.453611918858115, 54.22671563284737, 57.09170109885079, 46.47984593255179, 37.031477042606895, 36.19571992329189, 60.16658469608852, 27.193715470177786, 0.24995066917368344, 0.15629197843372822, 0.13879629224538803, 0.08332032084997211, 0.1888086793145963, 0.2134395276329347, 0.11794363547648702, 0.07852461175726992, 0.10317498831344502], [0.036349093807595115, 0.036176912153937986, 0.06982904978628669, 0.033870361279696226, 0.020276056369766593, 0.03415129852614232, 0.016451001799266254, 0.03983294025861791, 0.0618713539359825, 0.025957645515778234, 0.058903353554861884, 0.08689233274864298, 0.027428726399583474, 14.527276243482317, 52.66209248134068, 29.1329733303615, 25.40860686983381, 31.49075766972133, 53.66527339390346, 48.82691962378365, 52.08292538779122, 50.25747728347778, 46.51576117106846, 51.49479859215872, 47.825117928641184, 47.86389582497733, 2.642060765198299, 1.3072272432701928, 0.5944947653583118, 0.432628119630473, 9.319921885217939, 47.6341849054609, 54.57221828188215, 51.742908341544016, 51.96932928902762, 44.04680912835257, 42.245499065944124, 38.605042525700156, 40.51712424414498, 39.444322381700786, 40.13725927897862, 39.65729856491089, 38.489987305232454, 37.486990519932334, 37.1523756980896, 36.48877756936209, 35.77783441543579, 37.560662269592285, 38.515577520642964, 35.80576964787075, 39.279549326215474, 39.51848745346069, 40.487792423793245, 40.93576710564749, 46.03445945467268, 48.20010873249599, 50.07921082632882, 46.457677704947336, 39.04419994354248, 49.30070686340332, 47.566943713596885, 41.79292467662266, 40.983379636492046, 37.56310108729771, 36.29465184892927, 35.98872266496931, 34.55066442489624, 35.01028776168823, 36.42793219430106, 38.29603181566511, 42.91934578759329, 48.10843072618757, 46.520687443869456, 47.55827930995396, 44.08169255937849, 46.67046281269619, 45.34600761958531, 48.08989988054548, 47.976960386548726, 45.77218927655901, 43.67765481131417, 38.45320701599121, 36.65153564725603, 37.50401708057949, 35.464286531720845, 37.401326179504395, 38.69411148343767, 37.04950761795044, 43.22669587816511, 41.21757909229824, 37.8316524369376, 37.572505474090576, 37.17380394254412, 37.40164579663958, 37.280872208731516, 37.97478880201067, 37.45553255081177, 42.834994656699045, 45.278683049338206, 46.274655205862864, 48.669789586748394, 49.167426518031526, 48.07550321306501, 45.225824628557476, 48.02133158275059, 45.62351867130825, 45.26916401726859, 44.82676873888288, 43.83414213997977, 35.715290205819265, 34.939919880458284, 34.58717373439244, 33.04705687931606, 34.3724605015346, 34.66240882873535, 34.62728568485805, 34.45471327645438, 35.18040745598929, 39.01150172097342, 40.61829348972866, 42.91928672790527, 41.68166664668492, 40.83112028666905, 40.022964886256624, 38.791535649980815, 36.589839117867605, 37.01008006504604, 34.531178201947895, 35.97377361570086, 34.49014214106968, 34.20420292445591, 34.158987522125244, 34.837687560490195, 34.1945345061166, 37.04654768535069, 39.429213523864746, 42.603907993861604, 45.44413355418614, 47.27260412488665, 48.28734336580549, 49.23046404974801, 48.955843448638916, 49.882264137268066, 47.453545638493125, 51.654735701424734, 50.56281239645821, 48.557044642312185, 49.576831749507356, 51.599528789520264, 54.97313628877912, 21.818437916891916, 0.230548693133252, 0.08269779211176292, 1.1940271918262755, 2.0751135987894873, 37.107521602085654, 46.95288624082293, 43.52829286030361, 47.79215567452567, 50.747412136622835, 51.558068888528005, 46.402606282915386, 32.71823338099888, 30.2061573437282, 26.952470541000366, 39.18240308761597, 5.569185273987906, 0.25420511088200975, 0.08807829661028725, 0.133397569081613, 0.019456811847963502, 0.047272235354674716, 0.011150684872908252, 0.026877850959343568, 0.039061903953552246, 0.036331434933734794, 0.03419371035748294, 0.043917622683303695, 0.04440589987539819, 0.06548072597278015, 0.055390537051217895, 0.022988849552348256, 0.04783874424174428, 0.0557736345300717, 0.03367144873897944, 0.008445046842098236, 0.04427770086164985, 0.09496888079281364, 0.04638072854972311, 20.754347358431133, 62.36935125078474, 23.641369036265782, 27.263610873903545, 42.0226286479405, 57.603738171713694, 57.27267040525164, 57.73159197398594, 58.08834375653948, 50.96453292029244, 55.483610016959055, 50.744917733328684, 51.05626303809029, 3.0162384126867567, 2.2168316628251756, 2.4438870676926205, 0.38501349889806336, 13.329915761947632, 47.27771799904959, 57.683847427368164, 55.26473133904593, 52.76406076976231, 45.97890860693795, 43.28140599387032, 41.86092669623238, 42.8443260874067, 42.49544661385672, 42.759610176086426, 39.156771183013916, 40.40601560047695, 37.60127101625715, 38.72889763968331, 38.646290506635395, 38.282958780016216, 38.47648000717163, 40.5230302129473, 37.67341068812779, 40.71786117553711, 39.3157251221793, 40.079846314021516, 44.142246110098704, 47.697681018284385, 48.36369712012154, 50.61354119437081, 49.51675067629133, 42.45719678061349, 50.886376108442036, 49.14680773871285, 43.77648251397269, 43.099793979099815, 40.288076877593994, 37.85635328292847, 37.087156432015554, 35.69724920817784, 36.781341893332346, 37.906849316188264, 39.35746989931379, 44.53743532725743, 50.594662938799175, 48.49107149669102, 49.54369231632778, 47.67743049349104, 49.076220989227295, 48.86634022848946, 48.67545584269932, 50.02214527130127, 47.946843419756206, 47.57797745295933, 38.41083690098354, 36.180124691554475, 37.29757220404488, 37.09082855497088, 36.83831017357962, 37.559686047690256, 39.66612972532, 45.77851561137608, 43.366156646183555, 37.74330609185355, 37.60311228888375, 37.14329440253121, 37.7474958556039, 37.04427215031215, 38.13769974027361, 37.682113306862966, 44.369823932647705, 45.49087756020682, 48.00093861988613, 48.91425153187343, 50.17521408626011, 48.98081180027553, 48.61888708387102, 49.59883322034563, 46.983437470027376, 47.77911390577044, 47.218397753579275, 44.44664321626936, 38.01678024019514, 37.05206108093262, 36.07854897635323, 35.876349449157715, 35.06736026491438, 36.61365406853812, 36.963537556784495, 35.89508874075753, 36.53023747035435, 40.192309856414795, 42.361787591661724, 45.99402093887329, 43.27867535182408, 43.38569150652204, 42.79380226135254, 41.48531402860369, 37.693105357033865, 38.3237863949367, 37.046759605407715, 36.39671393803188, 35.44255951472691, 36.35425697054182, 36.293456758771626, 36.46360077176775, 35.701133251190186, 39.307300431387766, 41.50664152417864, 45.37226833615984, 47.030789443424766, 49.81786128452846, 48.70562144688198, 50.951442514147075, 50.83422640391758, 52.8971118245806, 51.22989157267979, 53.50627776554653, 52.45538704735892, 51.79349817548479, 51.716932501111714, 56.362008231026785, 54.752068928309846, 22.89081767627171, 0.6724091502172607, 0.2141872053699834, 1.077734540615763, 2.555086906467165, 40.383809157780235, 51.2935996055603, 50.26843111855643, 52.624502726963584, 55.377233096531455, 55.199505124773296, 50.319201605660574, 44.017261913844514, 33.45513153076172, 27.04130325998579, 48.628347056252615, 7.617391756602696, 0.40888161957263947, 0.08340086295668568, 0.06802221281187874, 0.011861104252082961, 0.04846130690670439, 0.040267884598246644, 0.07065738498100213, 0.050158363700445206, 0.015116252171407853, 0.20935991725751332, 0.10706283112189599, 0.19946701239262307, 0.12294451998812811, 0.0887363398713725, 0.11191347440970795, 0.1836120645914759, 0.1802588938070195, 0.135726179129311, 0.12296142908079283, 0.17797318074320043, 0.21039794012904167, 0.23858238490564482, 25.50383540562221, 71.03328936440604, 37.00897182737078, 34.58481134687151, 42.856190136500764, 64.72409575326103, 59.22345706394741, 62.83465126582554, 60.473604747227256, 56.01286472593035, 60.953377859933035, 56.605851786477224, 55.33359146118164, 3.862354644707271, 3.7884492618697028, 2.177814705031259, 0.6449074745178223, 16.950613362448557, 50.0581682068961, 57.86821092878069, 57.36300393513271, 56.785587787628174, 47.76398767743792, 46.51755033220564, 43.84988675798689, 45.455743994031636, 43.807798045022146, 43.12834760120937, 42.22383458273751, 42.0451477595738, 40.08110393796648, 42.19392606190273, 41.419125488826204, 40.76711000714983, 41.78022684369768, 42.94292449951172, 39.23334380558559, 42.81717252731323, 42.555065631866455, 43.45941884177071, 44.506262234279085, 49.38850082669939, 51.07381418773106, 54.42385687146868, 49.26704978942871, 41.462131364004954, 52.208152770996094, 51.34679501397269, 45.1172069140843, 47.00560917173113, 41.11110837118966, 40.23064306804112, 38.783826623644146, 38.11604567936489, 39.24836581093924, 39.66973236628941, 41.719885213034495, 46.03164196014404, 54.209567478724885, 52.260368483407156, 52.362500054495676, 49.157942226954866, 51.04709836414882, 49.448547158922466, 51.46503250939505, 52.6274140221732, 48.66730907985142, 48.075583117348806, 39.19204371316092, 37.39443704060146, 36.61775003160749, 35.89120122364589, 37.14450338908604, 38.11981507710048, 39.30578919819423, 48.39932400839669, 45.27351706368582, 37.27241277694702, 38.3686717578343, 36.33769941329956, 36.76341554096767, 37.24226106916155, 37.94054807935442, 37.380908897944856, 45.19053472791399, 47.68780762808663, 48.97947079794747, 51.41350466864449, 53.892364842551096, 51.80630717958723, 50.32346085139683, 52.69522149222237, 49.953007221221924, 49.99465472357613, 50.92939935411726, 48.57206317356655, 40.78800671441214, 38.745684487479075, 38.83934620448521, 38.70396055494036, 39.17011867250715, 38.76078987121582, 38.310689040592735, 37.390059675489155, 38.51564352852957, 43.75947332382202, 43.93232366016933, 49.47718415941511, 45.890357289995464, 45.65664420809065, 45.75246334075928, 43.30838237489973, 38.49444457462856, 40.53376865386963, 39.4997238431658, 39.5898107119969, 37.04939297267369, 37.6518052646092, 38.79863323484148, 39.53248112542288, 38.30428627559117, 41.47668089185442, 42.411515848977224, 46.65358911241804, 49.654651573726106, 53.74649783543178, 52.87057318006243, 53.08308730806623, 52.60334198815482, 55.55930716650826, 53.91867767061506, 55.90254817690168, 53.353146416800364, 52.57800885609218, 52.55650418145316, 58.71789223807198, 56.96141195297241, 28.22723048073905, 1.9080291816166468, 0.8190934934786388, 1.7682085186243057, 2.488736169678824, 49.45778826304844, 54.904672213963096, 56.6270820072719, 56.005127906799316, 62.46792534419468, 59.786004066467285, 57.42141049248831, 43.59353297097342, 41.11946357999529, 34.879414967128206, 56.01746095929827, 10.643892441477094, 0.5056144403559821, 0.2142747635287898, 0.18787478442702973, 0.14505433929818018, 0.1790250050170081, 0.14934851601719856, 0.12725819780358247, 0.1925201573010002, 0.20818962076944963], [0.025075974075921943, 0.03821391499202166, 0.016091062720598917, 0.11248979491314717, 0.06197363630469356, 0.018858564485396658, 0.028027082327753305, 0.025926237826102545, 0.09725875327629702, 0.0513728294255478, 0.007526722636872104, 0.06071817010108914, 0.008390565569113408, 4.576872646808624, 45.95099769319807, 45.687348297664094, 33.548056738717214, 25.722950322287424, 44.40358870370047, 51.65767131532942, 48.91763877868652, 46.34593677520752, 46.553528104509624, 50.85855204718453, 44.371967451913015, 53.70081690379551, 9.7582220690591, 1.5925642464842116, 0.7742099761962891, 0.053648469637015035, 5.300575298922403, 59.642600195748464, 58.324784006391255, 52.724105153764995, 53.87731157030378, 49.74670478275844, 46.94733463014875, 42.65697833469936, 38.81389495304653, 37.477447169167654, 38.9437324660165, 37.76704461233956, 36.9061211177281, 36.49190425872803, 37.380436420440674, 36.16600942611694, 38.51453529085432, 39.43062400817871, 39.86422634124756, 38.40774495261056, 37.07945782797677, 36.404485498155864, 38.416131428309846, 37.14996119907924, 41.828214577266145, 47.58465814590454, 47.77289179393223, 48.26732907976423, 41.572684151785715, 48.70586115973336, 51.5777496610369, 44.8083039011274, 39.963394505637034, 38.83937399727957, 37.100430965423584, 35.150474616459434, 35.59577424185616, 35.31179094314575, 34.34088788713728, 35.465245383126394, 45.01738214492798, 47.11165605272566, 47.03289474759783, 46.68296609606062, 47.60028811863491, 46.69363505499703, 48.17073522295271, 47.92988634109497, 47.87267139979771, 47.70431307383946, 40.5992762701852, 37.78568662915911, 37.829352583204, 36.965757506234304, 36.69725826808384, 37.88162040710449, 37.207280363355366, 40.06495632444109, 45.62795162200928, 42.31771516799927, 39.104982784816194, 36.978285108293804, 38.95003795623779, 36.051926953451975, 38.92863055637905, 37.5707927431379, 39.652365343911306, 38.94467742102486, 44.296016693115234, 45.200415066310335, 47.39837694168091, 48.93337297439575, 47.095154081072124, 46.34981734412057, 45.815789222717285, 45.531350816999165, 44.684636388506206, 44.193475178309846, 44.59210722787039, 39.89919662475586, 35.53608921595982, 33.33132158006941, 32.59089027132307, 32.336725166865754, 34.387809072222026, 33.93304600034441, 35.37188591275896, 34.61970172609602, 37.851027488708496, 38.794537271772114, 42.46176174708775, 42.6443395614624, 44.27412639345442, 37.8357310295105, 38.51426778520857, 34.3270331791469, 34.79726988928658, 34.47386598587036, 35.966147967747276, 33.176425388881135, 34.911022322518484, 33.59123979296003, 34.674151284354075, 33.33405917031424, 38.144682679857524, 38.72089678900582, 42.0919542993818, 42.612433433532715, 47.95041479383196, 47.91037579945156, 50.65340300968715, 46.664629799979075, 50.019140175410676, 49.253803048815044, 53.35845136642456, 50.39229665483747, 53.04155445098877, 46.07715266091483, 56.08797822679792, 31.99622174671718, 14.245697021484375, 2.379302259002413, 0.6738487843956266, 1.2786977227245058, 4.918181623731341, 55.96262577601841, 40.9902583530971, 45.26820863996233, 45.86285979407174, 53.17527253287179, 47.88120378766741, 41.42907183510916, 26.998735121318273, 19.31668516567775, 36.0941789490836, 31.040510926927837, 0.5331169845802444, 0.08382681331464223, 0.06444056571594306, 0.07915727780865771, 0.032658687726195366, 0.020700101740658283, 0.024711845043514456, 0.05057933021868978, 0.07584633225841181, 0.034315598995557854, 0.04538685116650803, 0.029031069882746254, 0.05305948427745274, 0.04153849909614239, 0.0411438970560474, 0.04162615903520158, 0.02338981964359326, 0.008592857214223062, 0.050532212746994834, 0.07256809888141495, 0.029374001481171166, 0.10337854881903955, 0.05757666153034993, 7.176535938467298, 57.80096973691668, 40.413609981536865, 24.900610174451554, 43.094968455178396, 46.854423318590435, 53.64724629265921, 51.75400808879307, 50.60954598018101, 52.328575474875315, 55.6432101385934, 49.43197570528303, 56.12116977146694, 10.104138135910034, 1.3791169971227646, 3.3677039188998084, 0.15976516849228314, 7.127385684422084, 57.9555914742606, 59.63057286398751, 56.373875754220144, 55.741072041647776, 52.84110934393746, 47.389035088675364, 44.21533421107701, 40.738841261182515, 38.891155447278706, 40.737347398485454, 40.04368788855416, 37.840282099587576, 38.7804775919233, 39.83870560782296, 37.41205767222813, 39.967434883117676, 41.335198198046, 41.55144350869315, 40.439335686819895, 38.874622208731516, 39.639149870191304, 40.371496949877056, 39.7459054674421, 43.59612464904785, 49.580184255327495, 49.67895289829799, 49.02127463476998, 42.86005333491734, 49.83917488370623, 51.7602128301348, 46.22910628999983, 41.935546875, 39.907037666865754, 38.593456404549734, 37.40646437236241, 36.75814880643572, 36.922084603990825, 35.26080853598458, 38.34724003928048, 46.88662821905953, 48.326458249773296, 49.82093586240496, 48.795093400137766, 49.113866329193115, 48.9657689503261, 51.081116744450156, 49.250742367335725, 49.08485065187727, 47.87700707571847, 43.30358116967337, 38.28641898291451, 36.864494459969656, 36.61618321282523, 37.04842369897025, 37.453917094639365, 37.668727602277485, 41.266428402491975, 48.109455585479736, 42.95824875150408, 38.79749720437186, 36.38634722573416, 38.94391311917986, 36.40242188317435, 37.84282514027187, 37.20949336460659, 39.85248735972813, 39.11992141178676, 45.93326241629464, 46.09035423823765, 49.51702165603638, 50.25712292534964, 48.34736885343279, 47.12458317620413, 48.955711432865684, 48.73270205089024, 47.74133655003139, 46.51507329940796, 47.15905318941389, 41.35340247835432, 37.01692404065813, 35.70802933829171, 35.6793714932033, 33.79683698926653, 35.13309022358486, 35.717673437935964, 36.321152278355186, 35.16500677381243, 39.94955021994454, 41.906704902648926, 45.303679193769185, 45.299072538103374, 46.54134096418108, 40.16834551947457, 40.990435532161165, 37.58556113924299, 37.46381480353219, 35.56052255630493, 37.85391446522304, 36.18905312674386, 37.30967596599034, 34.13775035313198, 37.19027464730399, 35.38422243935721, 40.10192768914359, 39.94272361482893, 44.229407787323, 45.70097371510097, 49.25350080217634, 49.45911536897932, 53.477949959891184, 48.94048792975289, 51.62634883608137, 49.776008810315815, 55.440989766802105, 50.7055527142116, 54.29384217943464, 45.46994611195156, 56.50496046883719, 34.68847499574934, 17.91971857207162, 2.50997941834586, 1.3327805463756834, 1.6831610479525156, 6.242423593997955, 60.8810818535941, 46.25079509190151, 50.739275796072825, 50.89472784314837, 58.02960021155221, 53.61887332371303, 47.04739563805716, 37.52946138381958, 21.601926837648662, 38.277747631073, 38.97423505783081, 0.9089396180851119, 0.21274059585162572, 0.05088502720796636, 0.0691994507131832, 0.06069435352193458, 0.044529495029045005, 0.03335963136383465, 0.20018959790468216, 0.02684011253794389, 0.05256232166928904, 0.12361720603491579, 0.16091512250048773, 0.15061629084604128, 0.1215638912149838, 0.12120508189712252, 0.19104365152972086, 0.1180655410779374, 0.1394347394151347, 0.1744357334183795, 0.1940103830503566, 0.1193754393607378, 0.1787611770310572, 0.2156231211764472, 8.197208506720406, 64.86150332859584, 57.704421043395996, 40.94716909953526, 36.268036774226594, 53.82292454583304, 59.92400918688093, 59.24616377694266, 53.08092641830444, 57.992059094565256, 61.62082181658064, 54.611993244716096, 61.921894209725515, 12.318192039217267, 3.3218069417136054, 3.659668743610382, 0.31361234454172, 10.4399219921657, 59.07602323804583, 59.71244348798479, 58.997772625514436, 58.496251651218955, 54.97430011204311, 50.32082748413086, 45.946054049900596, 43.70682682309832, 41.1691883632115, 43.684210436684744, 42.29695047651018, 40.53895548411778, 39.58869900022234, 42.53605188642229, 38.96175956726074, 43.31532709939139, 43.884527002062114, 44.92373432431902, 43.166878836495535, 41.512151445661274, 40.420186451503206, 41.63499212265015, 41.66359090805054, 46.4132787159511, 50.7810309955052, 51.062561580113, 49.90878193719046, 42.079989501408164, 53.01102059228079, 55.071741649082725, 49.344067096710205, 42.06392526626587, 43.18891157422747, 40.750066076006206, 40.27881145477295, 39.71673345565796, 40.38749517713274, 38.394487789699006, 39.38146202904837, 50.162422452654155, 49.881774289267405, 52.14291960852486, 53.02053615025112, 51.03761407307216, 51.233907631465364, 54.056099142347065, 50.92887129102434, 52.381312302180696, 49.9245091847011, 43.51326738085066, 38.96110643659319, 39.06370006288801, 37.371389865875244, 36.90739263807024, 37.113080160958425, 38.84689194815499, 41.95246573856899, 49.900662967136924, 45.83295822143555, 38.14837564740862, 36.49729953493391, 38.142014571598594, 35.10564831324986, 39.54908037185669, 37.76189947128296, 41.133134160723, 39.302780628204346, 45.805196693965364, 46.53105068206787, 50.94760363442557, 53.38917630059378, 50.77181421007429, 50.30574989318848, 51.22587203979492, 50.2221074785505, 50.58848599025181, 48.08894797733852, 49.70095784323556, 43.81482267379761, 40.04890251159668, 38.366747106824604, 37.84111588341849, 35.507563386644634, 37.28829288482666, 36.807519231523784, 38.46661009107317, 38.40150894437517, 41.8461583001273, 43.820704323904856, 47.699772426060264, 47.119576999119346, 48.69577932357788, 40.98163216454642, 42.88615771702358, 38.561060428619385, 39.68743985039847, 39.86224610464913, 40.61060183388846, 37.62745530264718, 39.75396190370832, 37.15645776476179, 39.37179708480835, 37.44922358649117, 43.36679588045393, 41.92249468394688, 45.876176016671316, 47.54821137019566, 51.929665497371126, 51.91772501809256, 55.68032741546631, 51.1440361567906, 52.98238706588745, 51.72659397125244, 57.1552597454616, 54.207844325474326, 54.36364378247942, 47.622855867658345, 57.780799116407124, 38.28610978807722, 22.672373260770524, 3.1916871581758772, 2.0164323704583302, 3.495264594044004, 6.64647958108357, 67.29455402919224, 48.93086814880371, 58.42350401197161, 54.403460434504915, 63.65325328281948, 55.68544476372855, 53.37116656984602, 37.20730120795113, 28.700533083506993, 46.75026287351336, 49.679640769958496, 1.7188004212720054, 0.2977754457720688, 0.14382395174886498, 0.21833316289952823, 0.16464152825730188, 0.2218510141330106, 0.07088105047919921, 0.23203574333872112, 0.16083458039377416, 0.21540499930935247], [0.05072265377800379, 0.011412026876184558, 0.033531690881188424, 0.06656942183950118, 0.06282570665436131, 0.05097823756347809, 0.036987059217478545, 0.02725926736768867, 0.025050810604755367, 0.028761688087667738, 0.024249861083392586, 0.041076654235699346, 0.031244637710707526, 0.2320108546742371, 30.84757682255336, 52.14615052086966, 26.848596709115164, 21.659355436052593, 36.41696446282523, 55.37211227416992, 55.397650378090994, 46.91803755078997, 45.729384899139404, 50.711792196546284, 46.58986718314034, 53.37340388979231, 22.204486778804235, 1.4855018428393771, 2.757881590298244, 0.2782777420112065, 4.758287940706525, 33.83431904656546, 51.870762143816265, 56.64403561183384, 53.16935961587088, 51.578958647591726, 49.886627605983186, 48.674323286329, 46.06337785720825, 44.61387940815517, 41.778788566589355, 38.870470660073416, 37.586523464747835, 36.30344132014683, 37.57750817707607, 37.749590737479075, 42.63870457240513, 43.00067097800118, 43.841514178684776, 44.27700294767107, 40.51599516187395, 39.03525413785662, 37.78443595341274, 36.40457582473755, 39.43070043836321, 47.58056565693447, 47.40625272478376, 50.303988524845664, 46.29897042683193, 42.64442293984549, 51.22533355440412, 45.562013217381065, 41.5814562525068, 37.88423292977469, 36.97004801886422, 35.80404996871948, 35.38405220849173, 33.55119732448033, 34.3271860395159, 35.8437693459647, 47.94643347603934, 46.298032420022146, 47.02003363200596, 47.839274883270264, 47.6418730872018, 46.70623213904244, 47.515957832336426, 47.36463301522391, 45.05956813267299, 42.911004475184846, 38.28203466960362, 35.99181113924299, 37.36066879544939, 37.295637130737305, 38.67124148777553, 36.7667749949864, 39.9270658493042, 44.36067662920271, 47.477044446127756, 42.826034954616, 39.7224657194955, 37.46439150401524, 39.57817595345633, 37.43277720042637, 37.3421414239066, 36.16249711172921, 38.800179209027974, 37.82960271835327, 40.43539605821882, 44.4724314553397, 46.99716363634382, 47.29492521286011, 46.536765575408936, 46.22939811434065, 45.54534796306065, 45.659350531441824, 45.284700189317974, 44.5836512701852, 46.24119962964739, 43.20645577566964, 38.252285957336426, 32.6433561188834, 32.448347977229524, 32.33646808351789, 33.31523650033133, 33.74702535356794, 35.371628829411094, 34.90289293016706, 38.716029575892854, 39.181107248578755, 44.39345128195626, 42.787496771131245, 44.215685095105854, 41.177428926740376, 41.08681746891567, 36.0402261870248, 35.60219437735421, 32.91349860600063, 33.71330574580601, 35.57293551308768, 36.9257150377546, 34.63042279652187, 35.79024737221854, 34.58002751214163, 36.111309732709614, 38.513923849378315, 40.132565770830425, 39.603991985321045, 42.63721765790667, 42.19992583138602, 48.42542839050293, 48.22550787244524, 50.60314321517944, 47.66436093194144, 53.384753772190635, 46.91439322062901, 51.00133058003017, 43.55126013074602, 57.879876954214915, 18.688105957848684, 13.086418747901917, 0.9355291255882808, 0.641926534473896, 0.7457886412739754, 9.999735372407095, 52.93397201810564, 41.898050921303884, 53.35436929975237, 48.15586607796805, 54.3409092766898, 48.298776626586914, 37.92327833175659, 22.426229851586477, 23.895977088383265, 40.86192512512207, 11.758384363991873, 0.22928159683942795, 0.05296877432348473, 0.0812798710539937, 0.009480905186917101, 0.0537323772774211, 0.019922695688105056, 0.060208549589983056, 0.01857788677859519, 0.02148954670077988, 0.048316022381186485, 0.006887582089153251, 0.02537402058286326, 0.0372269043831953, 0.025015002615483742, 0.045366115136338134, 0.053860932522054226, 0.015795179044029543, 0.06629696288811308, 0.04266770011080163, 0.04850248380431107, 0.04077339657981481, 0.03518655976014478, 0.01332764234393835, 0.6863812176244599, 36.5811573437282, 57.76620789936611, 22.831255980900355, 27.85235779626029, 48.09354073660714, 56.1039069720677, 60.23995072501046, 46.21556772504534, 51.98922545569283, 54.51606641496931, 51.408199719020296, 56.77467564174107, 24.619390521730693, 1.9185270411627633, 1.3553020464522498, 0.4853502905794552, 5.426463195255824, 38.078997884477886, 50.8023168018886, 58.677189690726145, 55.406957490103586, 54.24741431644985, 51.95673220498221, 50.613332748413086, 49.04424885341099, 46.0446628843035, 43.327354431152344, 41.377759388514924, 38.88282803126744, 38.65764386313302, 39.89541680472237, 40.24935456684658, 44.614268507276265, 45.177802153996055, 44.49603796005249, 45.22415358679635, 42.99448708125523, 41.16592618397304, 39.409508432660786, 39.628473963056294, 39.530441829136436, 47.25709921973092, 48.35303510938372, 49.91837739944458, 47.13436623982021, 45.11408369881766, 53.15009226117815, 47.68611226763044, 42.33090284892491, 37.92550522940499, 39.871084213256836, 37.997481618608745, 37.41307558332171, 36.00711107254028, 37.16514996119908, 38.69072076252529, 48.474774496895925, 48.70231410435268, 48.952744552067344, 49.72561352593558, 48.25749390465872, 48.358392170497346, 49.782380308423726, 48.59606572559902, 46.8918046270098, 44.441633565085276, 38.67204053061349, 35.015728201184956, 37.11839205878121, 37.89851495197841, 38.827096530369346, 37.73541988645281, 40.02376740319388, 45.33868074417114, 49.64409726006644, 44.99241726739066, 40.11709908076695, 37.34509788240705, 39.1818402835301, 36.87056371143886, 37.702068533216206, 37.53528050013951, 38.53441408702305, 38.61187955311367, 41.15038306372506, 46.18703842163086, 48.11798102515084, 48.775694029671804, 50.223469325474326, 47.521162033081055, 47.07486881528582, 48.070385864802766, 48.883946963718955, 44.64401721954346, 47.363156523023335, 45.91295630591256, 41.10327775137765, 34.92702749797276, 35.151138169424875, 34.56028767994472, 36.954557010105674, 35.420019558497835, 37.4942444392613, 36.64102302278791, 40.174129894801546, 41.66014460154942, 45.1277299608503, 44.83591604232788, 45.845280851636616, 43.93127448218209, 42.84897443226406, 36.8034336907523, 37.08156313214983, 35.35611350195748, 37.79549053737095, 39.21879775183541, 38.79737908499581, 37.00545603888375, 37.15672179630825, 35.90545892715454, 38.23950822012765, 39.904466833387104, 43.528984206063406, 40.668497698647634, 45.36787360055106, 45.624922207423616, 50.23487131936209, 50.711990220206125, 52.89513853618077, 48.159277643476216, 52.865612166268484, 49.26488195146833, 51.92232819965908, 44.08380481175014, 56.83132777895246, 21.864985636302404, 14.683402265821185, 0.8235787728003093, 0.23653329057352884, 0.5541097724011966, 11.175965513501849, 57.78581918988909, 45.14101491655622, 58.51776327405657, 51.34708683831351, 59.62367330278669, 51.00358179637364, 47.67757987976074, 29.239353724888392, 19.848739998681204, 48.778806822640554, 15.630825621741158, 0.2567271984049252, 0.09041962918958493, 0.05966461556298392, 0.017849803436547518, 0.016028254126597728, 0.04450173955410719, 0.04148286600996341, 0.03274284303188324, 0.015646459434979727, 0.00557692554346951, 0.10921157510685069, 0.16265491342970304, 0.11199553643486329, 0.16063462969447884, 0.21446735890848295, 0.15063672832080297, 0.16690631530114583, 0.22137426185820783, 0.14806143008172512, 0.18011462369135448, 0.12333181420607225, 0.13603579465832027, 0.07922509059842144, 1.1736815635647093, 46.02537815911429, 66.11296422140938, 34.85864680153983, 29.12242075375148, 49.51817853110177, 63.95302636282784, 64.73822144099644, 54.93202379771641, 57.01073374067034, 60.76020404270717, 57.48420483725411, 61.75192737579346, 28.456086771828787, 2.59585394178118, 9.088783979415894, 0.7738873735070229, 8.099966730390276, 44.52468538284302, 51.621749128614155, 60.13729109082903, 57.36140584945679, 56.32883405685425, 54.6706360408238, 53.23977266039167, 50.54242638179234, 49.16194438934326, 45.54122420719692, 43.829302719661165, 41.47280379704067, 40.4985864503043, 42.03827599116734, 43.17321559361049, 46.8844256401062, 48.61896003995623, 47.59851632799421, 48.208359718322754, 45.05749756949288, 44.50991351263863, 42.042535236903596, 40.22237818581717, 43.32451261792864, 50.982518332345144, 49.180864334106445, 52.958249023982454, 48.35642235619681, 46.789690426417756, 54.853015831538606, 50.43701178686959, 43.0565310205732, 41.13001789365496, 39.766791752406526, 40.106926918029785, 39.46858549118042, 38.238160269601, 39.96087578364781, 41.577794551849365, 52.08357504435948, 52.13576296397618, 50.6170083454677, 53.29870728084019, 50.92216280528477, 50.88749129431588, 51.99361671720232, 50.539594990866526, 46.557929788317, 45.8889468056815, 38.518217836107524, 34.9613481249128, 36.76896367754255, 37.99778733934675, 39.74862221309117, 39.453969955444336, 41.79900435038975, 46.713979380471365, 51.99605900900704, 45.73546804700579, 41.86341067722866, 36.83727141789028, 39.301366669791086, 37.67397696631295, 36.538780280521934, 37.93647643498012, 39.02033635548183, 38.59640938895089, 41.92477021898542, 47.40016262871878, 50.029114314488, 51.06538602284023, 53.36629935673305, 49.78548615319388, 48.94087355477469, 50.281076839991975, 51.89113078798567, 47.83603007452828, 50.47634553909302, 50.05111231122698, 42.36870799745832, 37.82454442977905, 37.327630111149375, 35.3538727079119, 38.67750876290457, 37.53246300561087, 40.106523922511506, 38.06090130124773, 44.53629582268851, 43.570659501211985, 48.808941159929546, 46.79930673326765, 48.01537350245884, 44.2904303414481, 44.6537446975708, 39.539797578539165, 38.799724102020264, 36.70045443943569, 39.42490911483765, 41.27679858888899, 42.27012348175049, 39.54569659914289, 39.385203633989605, 37.66654586791992, 41.04915475845337, 43.363884585244314, 45.345312799726216, 42.785325459071565, 45.982910769326345, 47.636849539620535, 52.921548639025005, 53.496404375348774, 54.42427723748343, 51.84288944516863, 56.37581082752773, 49.90846926825387, 52.461755071367534, 45.19910533087594, 56.94324936185564, 25.349097285951885, 19.617823566709244, 1.3442534336021967, 1.5873934839453017, 2.3323817253112793, 12.63176076752799, 63.73586041586739, 49.56751421519688, 62.82256140027727, 57.29495675223214, 63.28430393763951, 56.91266686575753, 50.346695627485005, 33.99296726499285, 34.27765927995954, 54.96802936281477, 23.90773865154811, 0.35696761097226826, 0.18026911254440034, 0.14574253665549414, 0.11766623679016318, 0.11353439957435642, 0.13300810355160916, 0.11266279420150177, 0.14183265502963746, 0.13264884640063557, 0.14044152253440448], [0.013266900737237717, 0.02377401465283973, 0.08600212873092719, 0.07980848143675498, 0.02358390610398991, 0.060284762643277645, 0.01865000487305224, 0.038185528479516506, 0.07028206690613713, 0.03433920183618154, 0.006403973217987056, 0.041889980235802274, 0.21496362585042203, 0.12477611670536654, 14.509054592677526, 49.84637321744646, 38.45013243811471, 40.05398164476667, 31.207159996032715, 48.69840921674456, 54.79242059162685, 47.860129901341026, 43.989549023764475, 51.22839770998274, 46.47166095461164, 50.51619345801217, 28.912197794233048, 0.26841751539281433, 4.221764981746674, 0.7816152359758104, 0.9642998789037976, 30.658929756709508, 50.55819879259382, 54.31187275477818, 54.324525424412315, 53.80922964641026, 54.740090233939036, 54.19963502883911, 50.25810956954956, 49.15629202978951, 47.45883321762085, 44.94068445478167, 40.21453019550869, 42.28693117414202, 40.18886354991368, 41.6844494002206, 43.87542833600725, 48.799498558044434, 47.45930222102574, 47.706136975969585, 42.7490245955331, 39.65285519191197, 40.82120868137905, 38.01724229540144, 37.84961353029524, 43.3293068749564, 48.68636104038784, 49.38040270124163, 52.27862140110561, 44.09908390045166, 49.59031472887312, 49.98003223964146, 41.98303433826992, 39.310479232243125, 36.95337929044451, 33.96225275312151, 37.15176773071289, 34.13696868079049, 35.83783211026873, 35.05725758416312, 43.58356578009469, 49.71290874481201, 46.38900865827288, 46.4008275440761, 49.295447077069966, 47.088039125714985, 46.25180605479649, 47.056035723005024, 41.58812652315412, 37.65178094591413, 37.27200978142874, 38.75736788340977, 39.372728143419536, 36.62024096080235, 37.43550784247262, 36.14695051738194, 40.36195012501308, 45.45727954592024, 43.28661366871425, 43.02155726296561, 41.594042914254324, 36.834721429007395, 36.28180810383388, 38.9404251234872, 37.250188963753835, 35.24457059587751, 38.193639687129426, 34.84239843913487, 39.14154420580183, 41.16232006890433, 44.49637147358486, 46.517762252262656, 47.300462927137104, 49.23996918542044, 46.07153156825474, 44.67063576834542, 45.37269565037319, 45.2921347618103, 45.77704954147339, 43.857248374394004, 40.94519928523472, 32.17903927394322, 32.247475555964876, 32.6834784916469, 33.2353252683367, 33.45006281988961, 34.766058581215994, 36.32820817402431, 37.31613779067993, 39.50849941798619, 41.9970314843314, 42.98203590938023, 44.09814241954258, 41.68304239000593, 40.785679067884175, 36.46590062550136, 35.81427076884678, 35.56649800709316, 33.810424191611155, 33.67231484821865, 35.67830841881888, 34.50115850993565, 36.23205205372402, 34.68040813718523, 36.72882393428257, 38.37245505196707, 37.70936066763741, 36.48744351523263, 39.87352303096226, 40.676019123622346, 41.212927273341585, 37.50163037436349, 45.13177728652954, 42.4555778503418, 48.55767692838396, 48.85725198473249, 49.467310769217356, 44.27793400628226, 47.208982944488525, 8.524070007460457, 1.0432538879769189, 0.342933471181563, 0.34205707535147667, 0.8250564592225211, 14.367941890444074, 53.509053570883616, 41.844449043273926, 50.662928989955354, 47.0225419316973, 54.59931625638689, 43.50488437925066, 33.374108586992534, 25.4242559501103, 32.45077289853777, 34.71945701326643, 2.556384699685233, 0.33100648117916925, 0.022819921474105546, 0.016418408369645476, 0.026483011431992054, 0.08448397448020321, 0.07403028077845063, 0.010493189528850573, 0.06328721224729504, 0.015148504637181759, 0.016154480299779346, 0.029001621462936913, 0.041700645216873715, 0.02322589067210044, 0.09729575379086391, 0.052148964921278615, 0.040576451790652106, 0.02002751238511077, 0.03665837685444525, 0.051765324614409886, 0.03125033061951399, 0.059757825918495655, 0.03342492678867919, 0.09423826142613377, 0.05825121354843889, 20.10331678390503, 59.35545894077846, 31.57353503363473, 30.354887008666992, 42.94308083398001, 53.51124225343977, 62.03177302224295, 52.146445819309776, 51.66192708696638, 56.002716881888254, 52.39995779309954, 53.46977540424892, 32.37408215659005, 0.4448581433721951, 3.032227086169379, 0.8676173239946365, 1.8613911356244768, 35.47963162830898, 49.720294679914204, 55.68053238732474, 56.06018543243408, 55.67683941977364, 56.82851723262242, 56.21906641551426, 53.38363858631679, 50.741370677948, 49.502294949122835, 46.938545158931184, 43.65578883034842, 43.997848646981375, 41.97805942807879, 43.30644382749285, 46.69190147944859, 50.592415196555, 48.905746936798096, 50.13085331235613, 45.26195526123047, 43.976729597364155, 41.70277527400425, 40.636240686689106, 38.343672139304026, 45.53870548520769, 49.959232807159424, 51.06957231249128, 52.37396110807146, 46.94201578412737, 51.70268521990095, 52.40435600280762, 43.13267632893154, 40.72966269084385, 40.32924842834473, 35.413186005183626, 38.27159152712141, 36.54259484154837, 37.64494391850063, 37.237352166857036, 47.045967783246724, 51.56210231781006, 49.337275232587544, 48.86156334195818, 49.77219077519008, 49.85407182148525, 49.912679876599995, 49.29674986430577, 44.077356883457725, 39.96284907204764, 37.324055262974326, 37.871194635118755, 38.81489201954433, 37.19900853293282, 38.15526131221226, 38.522814069475444, 41.6295690536499, 43.9343386377607, 45.998096057346885, 45.88235991341727, 41.194542339869905, 36.57651942116873, 37.45471613747733, 36.88285160064697, 37.27006775992257, 37.01101112365723, 37.712160791669575, 35.06696074349539, 38.29923146111624, 43.23281029292515, 47.045332023075645, 48.727716718401226, 48.45226928165981, 48.970993995666504, 48.698311941964285, 48.6700188773019, 48.04766525541033, 46.01279844556536, 47.16989237921578, 45.37240035193307, 41.99433558327811, 35.399046421051025, 33.439633573804585, 33.88752140317644, 34.13641977310181, 35.515564237322124, 36.47791058676583, 38.151731627328054, 39.926701068878174, 41.585072789873394, 43.42662334442139, 44.553548199789866, 46.35724496841431, 43.353792326790945, 42.60220915930611, 39.02897991452898, 37.95934990474156, 37.03025068555559, 35.89601632526943, 34.68263850893293, 37.25387845720564, 36.530199255262104, 37.281917912619456, 36.128315448760986, 38.547278676714214, 39.34060662133353, 40.98759024483817, 39.63425486428397, 41.822228704180034, 43.82042639596121, 43.15775237764631, 40.143825326647075, 46.20774752753121, 44.98329080854143, 51.79884481430054, 50.72360413415091, 51.90029198782784, 44.2086500440325, 48.78273950304304, 9.949117745671954, 2.8425788283348083, 1.2189812128032957, 0.4260063235248838, 0.5695129515869277, 15.485769816807338, 59.11535004207066, 45.80605132239205, 55.41885280609131, 50.90643903187343, 60.66370051247733, 47.36969477789742, 45.28765664781843, 26.506502151489258, 29.877920968191965, 46.677146979740684, 4.385483648095812, 0.2711969033948013, 0.04732373616259013, 0.04053077281319669, 0.023735234680186425, 0.08115124795585871, 0.07714729423501662, 0.06840899134320871, 0.04535691420148526, 0.026190328744373152, 0.04158216621726751, 0.1965192798525095, 0.1682033214185919, 0.1409428920596838, 0.14650267229548522, 0.17244291678071022, 0.24458777265889303, 0.11665705165692739, 0.16009223594197206, 0.19147777823465212, 0.12434038865779128, 0.17220207756119116, 0.16050108043210848, 0.3623957282730511, 0.21206419143293584, 24.392064571380615, 68.08589131491524, 47.6593200138637, 52.0217638696943, 44.33967569896153, 60.27355221339634, 63.409517424447195, 57.65422030857631, 56.55428225653512, 61.48875740596226, 57.16165208816528, 57.00186436516898, 36.36576318740845, 0.5501063615083694, 14.641640118190221, 3.468177693230765, 2.81456629719053, 40.283831528254915, 51.21111406598772, 57.43596002033779, 57.022726331438335, 58.82706928253174, 57.346543652670725, 58.66729545593262, 54.97628729684012, 54.143983432224815, 51.74643455232893, 49.66159282411848, 45.512364864349365, 46.926608153751914, 43.240745135716026, 46.26051214763096, 48.59677791595459, 54.588265146527974, 51.81050736563546, 51.2665467943464, 44.383689062935964, 45.44413355418614, 44.48682117462158, 42.23090784890311, 40.37721879141671, 47.880651405879426, 51.657007762363975, 52.208712100982666, 53.7656192779541, 47.45274659565517, 54.874659470149446, 57.36205898012434, 45.4891266141619, 43.3206980569022, 42.70404890605381, 37.14157819747925, 39.33411005565098, 37.12711204801287, 41.47705956867763, 38.779709815979004, 49.22330393110003, 54.149319648742676, 51.8829527582441, 52.00191286631993, 53.028550897325786, 51.12819078990391, 51.903967584882466, 50.68401329857962, 44.6889442716326, 39.18533175332205, 37.06609296798706, 38.7220675604684, 39.15651062556675, 37.54185349600655, 39.313935961042134, 39.451927185058594, 42.56466109412057, 47.60380738122122, 47.39906133924212, 46.68979270117623, 43.17670358930315, 36.40193203517369, 37.87959153311593, 38.60252380371094, 36.4667135647365, 34.89600031716483, 38.67907905578613, 33.04713330950056, 38.87685258047921, 43.34329359872, 48.43883146558489, 50.871538230351035, 51.57268442426409, 53.897930349622456, 49.925429821014404, 50.55274098260062, 49.89911699295044, 48.8204265322004, 50.90027250562395, 49.06682702473232, 45.49347618647984, 36.30789858954293, 35.90781089237758, 36.95007542201451, 35.688484055655344, 38.78548724310738, 38.80994142804827, 40.80388682229178, 42.5352771622794, 43.030120917728965, 46.188292571476524, 46.61521768569946, 48.9109650339399, 46.00564527511597, 44.14650535583496, 39.97727700642177, 41.41939994267055, 38.92362437929426, 38.19828108378819, 37.017104693821494, 40.20227704729353, 39.47640568869454, 40.2578661101205, 38.49341971533639, 41.03335802895682, 42.51100710460118, 43.375119822365896, 41.64614050728934, 44.80311707087925, 45.85980258669172, 45.864694118499756, 41.827693462371826, 49.14286463601248, 46.80678646905081, 55.09183931350708, 51.86648205348423, 51.45309550421578, 43.62816974094936, 50.47522687911987, 14.781340599060059, 5.44494366645813, 2.5708901498998915, 0.5452749207615852, 2.0102580274854387, 17.334032331194194, 65.85727051326207, 50.077432087489534, 59.438142504010884, 56.44795049939837, 61.262899262564524, 54.154232025146484, 46.09665625435965, 36.87654263632638, 40.93536063602993, 55.179310185568674, 8.962992055075508, 0.6420057330812726, 0.11797005763011319, 0.17884489468165807, 0.13227202876337937, 0.2190153891486781, 0.131173969113401, 0.16560711073023932, 0.15556422248482704, 0.12325797602534294, 0.1841837846274887], [0.01655932143330574, 0.038459256291389465, 0.01600443585110562, 0.04828342216621552, 0.015789961109736135, 0.03212324217227953, 0.029254056845924685, 0.03731696294354541, 0.06594502712999072, 0.06362997421196528, 0.054180827856596024, 0.023889553899477636, 0.03785903439191835, 0.03149669650675995, 1.5915900873286384, 45.443292822156636, 39.9442001070295, 19.374634878976003, 26.82697217805045, 42.2224623135158, 52.24159097671509, 53.42921529497419, 41.50447021211897, 48.08724914278303, 49.96605593817574, 46.91159309659685, 39.18821178163801, 0.20878352890057222, 2.3502448924950192, 0.4937880092433521, 0.10379574607525553, 16.81366089412144, 58.08721814836775, 49.7954602922712, 54.8735477583749, 56.04636199133736, 52.740697452000205, 51.34830972126552, 52.55694191796439, 51.467891693115234, 48.68883459908621, 50.902554988861084, 47.92858355385916, 46.60543462208339, 44.87667070116316, 45.52685880661011, 47.93154001235962, 47.18898255484444, 46.38539212090628, 46.91387210573469, 45.62892436981201, 41.50049931662423, 38.47166837964739, 39.495488916124614, 41.23822219031197, 39.95643588474819, 45.49049193518502, 50.24394914082119, 48.329063824244905, 50.87077392850603, 49.95837123053414, 48.97287348338536, 41.851334708077566, 40.61589288711548, 38.73927477427891, 36.7111998285566, 35.71286875861031, 34.49800750187465, 35.26848629542759, 36.54865367071969, 39.536719526563374, 45.78892401286534, 46.07068388802664, 46.06229393822806, 45.81534801210676, 47.485344069344656, 46.38859176635742, 40.53736087254116, 37.87335205078125, 38.61899103437151, 38.08894075666155, 38.429652622767854, 37.29199627467564, 34.69078527178083, 37.71468646185738, 35.15025922230312, 39.555413654872346, 39.99465792519705, 37.411932604653494, 38.9437289919172, 39.020277295793804, 40.568964753832134, 35.905163628714426, 36.50984798158918, 38.17294447762625, 37.28121614456177, 36.511143820626394, 39.294710295540945, 38.613557543073384, 38.65464571544102, 42.72241299492972, 46.38405111857823, 46.521278040749685, 46.84013087408883, 45.592550550188335, 45.35029118401663, 46.48512656348092, 46.20574644633702, 42.28035123007638, 44.83590909412929, 39.132629667009624, 31.686384201049805, 33.38721636363438, 33.05569001606533, 31.945468630109513, 33.99189376831055, 35.163158552987234, 35.94220794950213, 35.63145671572004, 36.57851355416434, 43.24564014162336, 43.48622499193464, 43.48041977201189, 40.49824251447405, 41.0575829233442, 37.85172578266689, 36.056061131613596, 33.66439390182495, 34.07221494402204, 32.79890891483852, 33.48399434770857, 33.0371869632176, 35.56044960021973, 34.095679010663716, 37.164076464516775, 37.9729961667742, 38.85297162192208, 38.50608628136771, 40.027213709695, 39.84394107546125, 39.306775842394146, 37.59870365687779, 45.932446002960205, 44.68413264410836, 49.91953427450997, 49.88668319157192, 51.42036601475307, 44.57502508163452, 42.08237968172346, 1.8530830442905426, 0.8496324004871505, 0.6952719805496079, 0.31173054980380194, 0.14617431562926086, 23.9839916569846, 52.485764571598594, 43.7221371786935, 52.10694183622088, 52.262828145708355, 50.03920309884207, 32.4442172731672, 29.92154175894601, 26.392836570739746, 39.1726200239999, 22.861855847494944, 0.0929947102974568, 0.05826872653727021, 0.051112808021051545, 0.06706590591264622, 0.050102031723197014, 0.02736329526773521, 0.024811613439981426, 0.016812949341588786, 0.014668536106390613, 0.04757739969396165, 0.010869157300995929, 0.03259894271780338, 0.011361645651049912, 0.03918235070471253, 0.033965468140585084, 0.028046110146013752, 0.04382071431194033, 0.028458879961233054, 0.03882806043007544, 0.04176965562094535, 0.040984180090682845, 0.06435408642781631, 0.025887371340234364, 0.10359764777656112, 0.06468715212707009, 3.0065539266381944, 55.80601337977818, 42.864996978214805, 24.58303928375244, 44.11652387891497, 47.17822674342564, 59.255126953125, 55.864951474326, 46.652536460331504, 54.45368201392037, 53.486669949122835, 51.970097064971924, 40.50891842160906, 0.10061465855687857, 1.9637684992381503, 1.345428656254496, 0.07451477513781615, 19.699119227273123, 59.60809544154576, 50.27238464355469, 56.09085478101458, 57.63743346078055, 55.58400106430054, 55.91656616755894, 53.652825696127756, 53.89144420623779, 51.691411767687114, 53.95620836530413, 49.1503061567034, 48.36184195109776, 46.45890058789934, 48.428315367017476, 50.54105063847133, 48.36523267201015, 46.804962566920686, 49.674179485866, 47.169621399470735, 42.66464914594378, 40.875925745282856, 42.65459510258266, 42.01958533695766, 41.927994183131624, 46.77396665300642, 50.195547989436555, 48.96206208637783, 51.1022184235709, 51.06585502624512, 48.65847097124372, 42.841116019657676, 40.188880920410156, 40.25212689808437, 38.57310165677752, 38.56794261932373, 36.95109333310808, 37.24999788829258, 38.67499698911394, 42.84252997807094, 47.57504531315395, 48.0794289452689, 47.598964486803325, 47.485351017543245, 48.60197169440133, 49.52308743340628, 43.33737025942121, 38.31426041466849, 37.668150901794434, 37.92297608511788, 39.41138792037964, 37.98746231624058, 35.25368663242885, 38.460558210100444, 35.76693269184658, 40.7456122807094, 42.038203035082134, 41.391985825129915, 40.137839453560964, 41.79227154595511, 40.89746863501412, 35.56137023653303, 36.389230728149414, 36.84068645749773, 36.99040624073574, 36.5018436568124, 37.56812116077968, 37.89807374136788, 38.74903004510062, 42.9140373638698, 47.86206497464861, 47.72807591302054, 47.95333651133946, 47.333418233054026, 47.84358624049595, 47.585356439862935, 46.610340050288606, 44.99928208759853, 45.097342014312744, 40.74590757914952, 34.52950021198818, 34.4576940536499, 35.32033722741263, 34.24882425580706, 35.85669994354248, 35.7858943258013, 36.505630425044465, 39.22888306209019, 38.81396790913173, 44.00253520693098, 45.64775398799351, 44.28476755959647, 43.314878940582275, 43.00759138379778, 38.96866955075945, 39.14962843486241, 36.154718603406636, 36.336570331028526, 35.17712095805577, 35.596653188977925, 34.76956047330584, 37.518281732286724, 36.55607087271554, 39.72635323660714, 39.53322458267212, 40.95452029364449, 40.81592457635062, 42.409716265542166, 42.47421986716134, 41.83827209472656, 39.54627677372524, 47.761576652526855, 46.05679791314261, 52.798794814518516, 51.332318442208425, 51.985911164964946, 43.58669594355992, 44.906235286167686, 2.8294775656291415, 1.605773206268038, 1.1725394534213203, 0.16565372608602047, 0.07772052740412098, 25.900332621165685, 57.85572501591274, 48.76968036379133, 56.132029805864605, 55.65894433430263, 56.74902636664254, 38.27732726505825, 43.20826578140259, 21.919716596603394, 43.121045044490266, 30.14970670427595, 0.2540214721645628, 0.030288646330258677, 0.039696653107447286, 0.059554658963211944, 0.04073598894423672, 0.015723807338093008, 0.11240238603204489, 0.011553929752803274, 0.05368389595033867, 0.05728405008890799, 0.097991231828928, 0.10467410287154572, 0.0969663793221116, 0.15644179896584579, 0.21555690972932748, 0.08327086243246283, 0.12527486708547386, 0.17783712090126105, 0.15536169335246086, 0.10944226344249078, 0.17781738910291875, 0.17809588701597281, 0.11704788782766887, 0.2978520930877754, 0.14468345205698693, 4.050268241337367, 67.10839094434465, 51.75794424329485, 27.875175680433, 37.20491450173514, 52.489169188908164, 61.20290156773159, 62.72564097813198, 52.20531095777239, 57.44263029098511, 58.785519054957796, 55.87945236478533, 48.01130880628313, 0.21484896700297082, 5.982412014688764, 4.431391264711108, 0.26628129716430393, 25.5158714226314, 60.999555587768555, 52.86314902986799, 56.78763403211321, 60.350586891174316, 55.71312986101423, 56.141722542899, 55.813281195504324, 55.66315841674805, 54.18078456606184, 56.03691938945225, 52.445961815970286, 50.687035764966694, 48.880973134722026, 50.584897245679585, 52.51279306411743, 50.4383145741054, 51.262225014822825, 51.72602769306728, 48.538360936301096, 44.667168617248535, 42.88470901761736, 44.95651592527117, 45.90477480207171, 42.36760670798165, 48.19921588897705, 53.34491280147007, 49.0432448387146, 52.5758375440325, 55.545101574489046, 51.876011507851736, 44.87089327403477, 44.60327993120466, 42.207238810403005, 41.32216337748936, 41.450176988329204, 39.012088843754356, 39.093914304460796, 40.80428286961147, 43.34257793426514, 49.437947681971956, 50.61571250643049, 50.19111851283482, 50.207200118473594, 51.13197408403669, 49.497691767556326, 41.95835086277553, 38.58784573418753, 38.24328804016113, 38.58514288493565, 38.39143753051758, 38.680795260838096, 34.31088209152222, 39.3355587550572, 36.14402185167585, 41.41231625420706, 42.60406085423061, 42.116213934762136, 41.5831481388637, 43.769284180232454, 43.527518136160715, 36.78991249629429, 36.359860692705425, 38.08162777764456, 36.77022130148751, 36.80644226074219, 39.199481759752544, 39.21434048243931, 39.9041611126491, 44.03574412209647, 48.6376576423645, 49.23782566615513, 49.59093311854771, 49.42863709586007, 50.24649565560477, 49.788605894361226, 51.488850934164866, 45.13354907717024, 49.233403137751985, 43.382981709071565, 35.035912718091694, 37.75982195990426, 37.391626494271414, 35.81635870252337, 36.70691973822457, 38.827148641858784, 38.544433389391216, 41.87734528950283, 40.187585081372944, 46.9034880229405, 48.93093415669033, 46.16171571186611, 43.78830834797451, 46.151731150490896, 42.32434722355434, 41.31911659240723, 36.99641295841762, 38.537617206573486, 37.64556925637381, 37.790588583265034, 36.469503266470774, 39.746985912323, 39.05023792811802, 41.91152000427246, 41.05177075522286, 43.1944180216108, 42.21129308428083, 45.14159509113857, 44.24107033865792, 45.08001320702689, 41.81895957674299, 50.31691564832415, 48.82206630706787, 54.59954554694039, 51.64519929885864, 54.19597332818167, 45.144155502319336, 46.93776001249041, 4.783112117222377, 2.8641143356050764, 2.429000335080283, 0.9756335850272859, 0.7989585367696626, 26.667469331196376, 64.48886448996407, 52.67808723449707, 62.407350948878694, 60.43615395682198, 57.851003714970176, 43.029908997671946, 41.06555598122733, 35.8861220904759, 51.70870235988072, 40.436942032405305, 0.7984828022973878, 0.23777674670730317, 0.11213653601173844, 0.11604962710823331, 0.12105942757001945, 0.10742263788623468, 0.16515945403703622, 0.11038756450372082, 0.09343495738825627, 0.1723780624036278, 0.136860065428274], [0.02253286723446633, 0.007343268820217678, 0.010553711459838917, 0.032051514235458205, 0.0696334552818111, 0.07196244530911956, 0.02204599291352289, 0.03273882610457284, 0.02920074774218457, 0.02036008275380092, 0.0903842503737126, 0.026033039238037806, 0.06410792749375105, 0.05539848608896136, 0.15423037191586836, 25.194696153913224, 52.128380502973286, 20.064827237810405, 18.67845664705549, 35.997303690229145, 51.247397559029714, 55.39196327754429, 46.737328801836284, 46.592059339795796, 50.64097615650722, 46.16052409580776, 44.07873610087803, 1.2910419574805667, 2.0342668763228824, 0.3307359628379345, 0.1347314603626728, 6.426841378211975, 50.19437026977539, 59.66220106397356, 56.44857931137085, 56.14932039805821, 54.26386070251465, 54.12683875220162, 52.66469805581229, 52.79615102495466, 51.257997035980225, 53.00823089054653, 49.0313321522304, 50.799336024693076, 49.70741271972656, 51.70422077178955, 47.80947058541434, 45.49083934511457, 48.927870001111714, 48.01223291669573, 43.21879230226789, 42.610050201416016, 41.533305236271445, 38.894275188446045, 38.16294601985386, 39.15059770856585, 43.510908467429026, 46.94107430321829, 47.07618202481951, 49.68766246523176, 50.827229567936485, 47.96958834784371, 42.69648926598685, 36.534941400800435, 36.58558682032994, 37.097516196114675, 34.98215797969273, 35.65396540505545, 36.80897487912859, 34.28617082323347, 37.417491163526265, 43.798331124441965, 45.15977157865252, 44.88309778485979, 46.55585922513689, 48.358124664851594, 43.155601910182405, 39.13699313572475, 38.47687258039202, 40.523620809827534, 40.11190530232021, 36.22003861836025, 36.86210775375366, 37.594103949410574, 37.29395566667829, 39.27870512008667, 36.826317582811626, 35.69052335194179, 36.17451402119228, 35.2489583832877, 35.772296701158794, 36.36801092965262, 37.447726249694824, 37.96736465181623, 36.28963872364589, 36.63978624343872, 37.50674772262573, 38.24083185195923, 38.18923452922276, 37.10572896684919, 38.21880953652518, 41.38718114580427, 43.60455976213728, 45.72205802372524, 45.77021598815918, 45.53040933609009, 45.794058731624055, 44.765892096928184, 43.85509443283081, 42.4043105670384, 35.64907039914812, 32.453194345746724, 32.7320533479963, 33.3059641293117, 33.682653767721995, 33.63590976170131, 34.739672797066824, 33.62527206965855, 35.41036851065499, 39.356889724731445, 41.80371175493513, 40.61687953131539, 42.217185156685964, 42.14479534966605, 38.13654981340681, 37.263539927346365, 33.698551246098106, 34.2590902192252, 33.46376119341169, 33.34972388403756, 34.69854988370623, 33.56312738146101, 34.11344902856009, 34.13355016708374, 38.57984140941075, 40.61025789805821, 42.93449633462088, 42.65075274876186, 44.267091342381065, 43.15147468021938, 48.041967732565745, 47.35926900591169, 47.13177456174578, 48.67622709274292, 49.87114354542324, 47.027933733803884, 48.92130395344326, 46.98565741947719, 44.13113246645246, 2.397558216537748, 0.33071834806885037, 0.23511116259864398, 0.7177403920463153, 0.32769286898630007, 24.923214401517594, 50.36126947402954, 44.34635639190674, 51.546670368739534, 46.258337361471995, 44.68316684450422, 33.47734839575631, 28.282249791281565, 22.452118839536393, 39.20804194041661, 10.543132271085467, 0.20447067889784062, 0.07607334293425083, 0.033443844344999106, 0.020247719051050286, 0.06227686003382717, 0.041166583874395916, 0.11737954217408385, 0.05077515881774681, 0.00129571308415117, 0.023845835888226117, 0.05137864786333271, 0.036467908682035546, 0.03028699749016336, 0.07046917293752943, 0.03256109403446317, 0.06609305632965905, 0.03215454638536487, 0.046282656490802765, 0.055619895458221436, 0.07143359511558499, 0.03665106903229441, 0.0727818916950907, 0.03893164558602231, 0.05469267735523837, 0.04015896954972829, 0.2385179783616747, 32.51436628614153, 56.508823667253765, 15.202898229871478, 27.622339418956212, 46.90028142929077, 53.1706519808088, 62.92140647343227, 51.58013984135219, 52.72944484438215, 54.92432519367763, 49.611732551029746, 46.78991624287197, 1.52721991283553, 3.129637573446546, 0.3311259847666536, 0.08606890336211238, 8.158779757363455, 51.7883426121303, 61.265303339277, 56.50152458463396, 56.873930658612935, 55.34798118046352, 55.0401725087847, 52.52754756382534, 54.652056557791575, 51.956061703818186, 55.44311244147164, 51.59841012954712, 51.21986879621233, 51.17763417107718, 54.27734020778111, 49.11023589542934, 47.738463469914024, 50.1334102494376, 48.95089633124215, 46.35481309890747, 43.74728965759277, 42.85651322773525, 40.509522914886475, 40.63523667199271, 40.298676354544504, 43.95593711308071, 49.384335381644114, 50.5468419619969, 51.84894480024065, 51.37643950326102, 50.353779315948486, 44.88302482877459, 37.87612785611834, 38.05123635700771, 37.60422052655901, 37.4370607648577, 37.52636248724801, 37.9972106388637, 36.44735588346209, 39.81394222804478, 46.00448840005057, 46.07580123628889, 46.59937926701137, 47.572905267987935, 48.57265029634748, 44.653661319187705, 39.33825813020979, 38.64901420048305, 39.05087716238839, 39.74502999441964, 38.62535558428083, 37.106184073856895, 37.41750158582415, 36.91743278503418, 40.994878905160085, 40.32393305642264, 37.357437883104595, 36.72820207050869, 36.55155454363142, 38.614259311131065, 38.79558644975935, 39.44192177908761, 37.52546269553048, 38.78722429275513, 36.66665145329067, 37.49008594240461, 38.64022125516619, 37.50014345986502, 36.82251344408308, 38.65556287765503, 41.99428694588797, 44.40921327045986, 47.01856408800398, 48.0259382384164, 47.115967409951345, 47.35815382003784, 46.021386419023784, 46.22654240471976, 45.38130446842739, 38.12236506598336, 34.72312913622175, 35.7532308442252, 34.506849084581646, 36.368229797908235, 34.23812402997698, 35.760995456150596, 35.76074532100132, 37.89267846516201, 39.81732600075858, 43.672395024980815, 43.879649366651265, 44.10869673320225, 44.43161078861782, 39.675937107631135, 40.069212096078054, 36.838629790714805, 36.32814564023699, 36.272987365722656, 35.53728778021676, 36.522170611790244, 37.01604856763567, 36.00423799242292, 35.80123247419085, 40.53296961103167, 42.357775006975444, 44.251228604997905, 44.80998536518642, 45.66078880855015, 44.59532771791731, 49.855457987104145, 49.546825953892295, 51.176223686763215, 50.11961112703596, 52.18827050072806, 48.47580977848598, 51.58192205429077, 47.66806779588972, 48.472870690482004, 3.385300883225032, 0.3862285922680582, 0.45726572615759714, 0.7716215550899506, 0.2769167093294007, 28.63717940875462, 56.69860328946795, 50.62313665662493, 56.154000009809224, 52.54582132611956, 47.14800902775356, 43.71742630004883, 33.73759664808001, 20.962272201265606, 48.73790625163487, 14.46826866694859, 0.1467635961515563, 0.10063717234879732, 0.02858886861109308, 0.03579881887084671, 0.06026290024497679, 0.05861327983438969, 0.07914928466613803, 0.027755680194656764, 0.06455664270158325, 0.047634277891899855, 0.05050934272419129, 0.11175135882305247, 0.19334647724671022, 0.18617795833519526, 0.15121458231338433, 0.14509836265019008, 0.2332690485886165, 0.13299270080668585, 0.1381567729903119, 0.14776752942374774, 0.08059860832457032, 0.10489624166595084, 0.20910493736820562, 0.1509548933910472, 0.13665262370237283, 0.32366055250167847, 40.333406925201416, 67.1198832648141, 29.129697254725865, 27.240801674979075, 47.05295419692993, 60.544177600315635, 66.46855912889752, 59.299609320504324, 57.80526719774519, 59.376692635672434, 55.45048795427595, 53.958862577165874, 1.803374545914786, 7.975587027413504, 1.1391623701368059, 0.26909233203956057, 11.156355091503688, 53.84618016651699, 62.63284778594971, 59.72614533560616, 59.183810642787385, 57.764595917293, 57.01294674192156, 54.0593717438834, 55.47911105837141, 56.34447792598179, 58.0352907861982, 53.41665990012032, 52.965016569410054, 53.473996434892925, 56.009088379996165, 50.82401950018746, 50.40353536605835, 53.50714976446969, 52.29533181871687, 48.61108078275408, 45.81672722952706, 46.847888537815635, 42.54070717947823, 44.240312985011506, 42.52786690848214, 46.68509224482945, 51.904832635607036, 51.63672249657767, 53.953984941755024, 54.22784471511841, 52.99250364303589, 47.43497657775879, 39.84693922315325, 41.550661836351665, 40.32398864201137, 38.649153164454866, 41.067296504974365, 41.02212626593453, 38.31791516712734, 41.191130774361746, 47.99252782549177, 47.47764893940517, 47.69930689675467, 50.21123354775565, 52.01509012494768, 44.09373031343733, 39.54701328277588, 37.96083334514073, 41.71123470578875, 40.10740634373256, 39.39682102203369, 38.968468053000315, 40.16957535062517, 39.07970176424299, 43.96387195587158, 42.4379745892116, 39.03386102403913, 39.84926339558193, 38.50414425986153, 40.52209220613752, 40.53952176230294, 41.92990493774414, 40.461476121629985, 38.51998267854963, 37.60910163606916, 38.37624182019915, 39.71028552736555, 38.89113460268293, 37.82707357406616, 39.71060861860003, 43.20559767314366, 44.71514245441982, 49.942932333265034, 50.179831164223806, 49.690521648951936, 49.56479399544852, 47.52441726412092, 47.98024688448225, 47.57625777380807, 41.08826616832188, 36.5009195463998, 36.28719295774187, 36.29796961375645, 38.38411065510341, 35.879100935799734, 38.237767696380615, 36.91965273448399, 40.64705555779593, 42.85394239425659, 46.71485137939453, 45.223663738795686, 46.30036006655012, 44.73315218516758, 41.212652819497244, 42.69006565638951, 38.67148814882551, 38.56411763599941, 38.24320466177804, 36.57872200012207, 38.49127967017037, 38.00177213123867, 37.834449086870464, 39.26894984926496, 43.317390714372905, 44.961459568568635, 48.03820875712803, 48.11220012392317, 47.9493065561567, 46.11813661030361, 51.549390588487896, 51.77131257738386, 51.28295496531895, 54.188226086752756, 54.09950801304409, 49.43200349807739, 52.58633279800415, 49.54863248552595, 50.753245149339946, 5.067053292478834, 0.8584184518882206, 2.799124142953328, 1.4102307047162737, 0.9689013234206608, 31.380715574537003, 62.01723739079067, 52.42332805906023, 62.734263692583355, 53.520886353084016, 56.73626599993025, 42.6320412499564, 40.00331538064139, 31.893155642918178, 56.24809946332659, 20.874808277402604, 0.34402634682399885, 0.2161960761461939, 0.14258196125073092, 0.1298260592988559, 0.1650993629757847, 0.12202605498688561, 0.18156204745173454, 0.17072846234909125, 0.11835569622261183, 0.08385442290455103, 0.15490627421864442], [0.09329871434186186, 0.04386662399130208, 0.013007949721733374, 0.056793065542089086, 0.07396936190447637, 0.04640097264200449, 0.002025542169576511, 0.018475736724212766, 0.06506804097443819, 0.023457566276192665, 0.01883942979787077, 0.06087592949292489, 0.03606896401782121, 0.1413996818342379, 0.19659385085105896, 6.6517389331545145, 49.50282996041434, 39.456009251730784, 30.452133996146067, 25.73906319481986, 43.085928848811555, 53.729836055210654, 49.53219304765974, 44.50813824789864, 52.020339488983154, 43.83891555241176, 44.20338678359985, 2.134980797767639, 0.43173166630523546, 0.24094298109412193, 0.14823869056999683, 1.6415982267686298, 51.33031736101423, 60.745334897722515, 51.786511761801584, 54.99860143661499, 52.65562718255179, 52.417574950626914, 52.95635911396572, 52.057074614933555, 52.721874782017295, 50.68062605176653, 52.34201676504952, 50.36846085957119, 49.628599303109304, 48.77812589917864, 46.71232918330601, 52.18863180705479, 47.71290452139718, 46.07369940621512, 42.13818761280605, 39.96223068237305, 38.715473720005576, 36.01125219890049, 37.78490148271833, 39.273014545440674, 41.673259326389854, 47.91371440887451, 49.38300132751465, 51.04202617917742, 47.222771644592285, 48.051417282649446, 42.41538252149309, 39.278357710157124, 36.29396745136806, 36.8681492124285, 35.95295681272234, 34.649471282958984, 36.895295824323384, 36.131212847573416, 39.65457487106323, 40.76877410071236, 45.40728030885969, 44.21686281476702, 47.95139796393258, 40.80544669287545, 40.183485644204275, 39.1249623298645, 38.32344593320574, 40.97459363937378, 35.67270817075457, 34.92103815078735, 38.98391042436872, 35.90735578536987, 36.3841689654759, 34.20794105529785, 33.430729457310264, 33.431469440460205, 34.49912963594709, 33.673555101667134, 33.75491155896868, 34.11343860626221, 33.47596917833601, 37.45821802956717, 36.39941331318447, 38.3447699546814, 36.436412470681326, 36.32192700249808, 38.2177950995309, 37.993038245609824, 40.17667293548584, 37.35632617133004, 40.089792660304475, 40.8549804006304, 46.31375271933419, 46.73635605403355, 44.405179841177805, 42.75385011945452, 42.03154666083199, 37.43740470068795, 32.83288560594831, 33.02538544791085, 32.04343475614275, 33.34858437946865, 31.43871913637434, 32.69591924122402, 33.57616220201765, 35.03094128199986, 35.06922933033535, 36.84545292173113, 41.48047113418579, 40.447009972163606, 41.30984769548689, 39.384105818612234, 36.774428435734336, 35.03425209862845, 32.76016575949532, 32.94934088843209, 34.008510385240825, 34.76049654824393, 33.14307056154524, 34.59421920776367, 33.45742096219744, 33.26660605839321, 36.99905674798148, 40.38641473225185, 45.13611991064889, 45.310554436274934, 48.42926379612514, 47.68041821888515, 48.12651341302054, 48.243319579533164, 49.405423164367676, 45.601673534938264, 51.73615121841431, 47.619888986860005, 51.90546144757952, 46.388970443180625, 52.131055559430806, 5.7001766221863885, 0.1140621437558106, 0.805325095142637, 0.5874808302947453, 1.5541148696626936, 37.332090854644775, 46.51493433543614, 44.29909127099173, 49.761712891714915, 49.614563941955566, 47.25454575674874, 28.839780194418772, 29.75089052745274, 33.61255686623709, 32.642372948782786, 0.4317639645721231, 0.1987844468759639, 0.039038935543171, 0.029609286891562597, 0.01211284498484539, 0.033421432333333154, 0.02656282072088548, 0.04015024358938847, 0.010396964781518494, 0.032386211811431816, 0.023853467710848366, 0.03599830138097916, 0.020577690630619015, 0.02230006526224315, 0.034707357973924706, 0.01938048005104065, 0.004976484392370496, 0.038291356193700006, 0.03270470257848501, 0.06755251730126993, 0.08420055040291377, 0.07528443062411887, 0.0289733638720853, 0.018576504263494695, 0.04168971741039838, 0.1107360872306994, 0.1465979657535042, 9.220445394515991, 62.60834843771798, 32.06272642953055, 24.15933813367571, 42.401107447487966, 47.025001593998496, 59.652084486825125, 55.08588123321533, 50.505507128579275, 54.94235576902117, 48.738837310246055, 47.57887724467686, 2.419955951826913, 1.3817908593586512, 0.1179845647088119, 0.20937291798847063, 2.2584353046757832, 51.822955063411165, 60.99236420222691, 56.068300928388325, 56.36063943590437, 55.645697593688965, 55.584480490003315, 53.16498572485787, 52.44196660178048, 53.92984689985003, 52.78680222375052, 54.14403554371425, 52.556684834616526, 50.97569520132882, 49.4915634563991, 48.876015595027376, 53.750812666756765, 49.86327818461827, 47.484545026506694, 45.563069343566895, 41.836156368255615, 41.24053246634347, 39.78711870738438, 39.17330094746181, 41.39618253707886, 44.2518435205732, 48.578705651419504, 51.61204596928188, 50.41401324953352, 48.88840423311506, 49.83314037322998, 45.07206446783883, 38.83764042173113, 37.86089045660836, 37.148505551474436, 37.289095401763916, 36.29323441641671, 38.895501545497346, 36.90115315573556, 40.648243699754985, 42.949730260031565, 46.060268538338796, 45.949938092912944, 48.2399114881243, 42.65214238848005, 39.010101658957346, 39.10664687837873, 38.84938982554844, 40.50703893389021, 36.945444447653635, 37.197382654462544, 39.1205849647522, 37.30958563940865, 38.19014474323818, 38.5629677091326, 36.924631118774414, 34.81013100487845, 37.54149913787842, 36.72038882119315, 35.752421379089355, 35.08954586301531, 36.31611483437674, 38.05510650362287, 36.618653297424316, 38.49757126399449, 37.26972034999302, 37.06181982585362, 38.41554430552891, 37.722517081669395, 38.99323838097708, 37.2436819757734, 39.641626902988975, 43.902022566114155, 47.9416183744158, 47.88855150767735, 46.32568277631487, 46.21615832192557, 43.88347782407488, 41.12247562408447, 36.537738050733296, 34.4661534854344, 34.300838470458984, 34.78919955662319, 34.1979148047311, 35.05331795556204, 35.56090470722744, 36.59966387067522, 37.16076912198748, 39.056939465659006, 42.834452697208945, 43.428506306239534, 45.58732203074864, 41.362581048692974, 37.89996017728533, 36.8357115473066, 34.70573779514858, 34.5479268346514, 36.13355786459786, 37.3630450793675, 36.56860542297363, 34.95875644683838, 37.023083618709016, 35.574915749686106, 39.305257661002024, 42.70231533050537, 47.48540660313198, 47.28357533046177, 48.76142937796456, 51.13032736097063, 50.09287098475865, 50.463779721941265, 51.1602463041033, 47.88672413144793, 52.62484318869454, 49.17892231260027, 54.821554388318745, 48.55820846557617, 55.19393614360264, 6.925058049815042, 0.02769287160065557, 1.1149305275508334, 1.0133024837289537, 1.73814138344356, 42.96488775525774, 52.02383443287441, 49.84027964728219, 52.82050446101597, 54.262339047023225, 48.9603910446167, 39.31068073000227, 27.46699333190918, 35.106881618499756, 40.62035015651158, 1.3224174167428697, 0.1453441416046449, 0.0335018319476928, 0.06541909463703632, 0.02027440244065864, 0.024799294636717865, 0.030435159004160335, 0.09349696870361056, 0.008938944000484688, 0.04046997607552579, 0.09234390021967036, 0.007924849666388971, 0.16322201942758902, 0.1478588195251567, 0.11462436430156231, 0.10992359582866941, 0.16818759297685965, 0.08816533908247948, 0.11637516106878008, 0.09022572423730578, 0.1934754667537553, 0.19916769702519688, 0.16220625250467233, 0.17014294091079915, 0.20701496808656625, 0.21350320135908468, 0.42999635370714323, 11.311020255088806, 67.91613292694092, 48.04726920809065, 39.431433473314556, 36.55275658198765, 52.86213459287371, 62.698119163513184, 61.29299191066197, 55.61702585220337, 61.48237201145717, 54.741556303841726, 54.208632946014404, 3.0801112481525967, 4.336128856454577, 0.29197532843266216, 0.2972664088010788, 3.260445011513574, 55.96196569715227, 62.470551763262065, 57.31065968104771, 58.45833533150809, 57.7725168636867, 57.1547976902553, 56.39333071027483, 54.72602013179234, 54.64968374797276, 53.39791713442121, 54.763345854622976, 53.86178234645298, 53.19564465114048, 52.19119916643415, 51.07848685128348, 54.781671728406636, 53.210506847926546, 50.8364428792681, 47.85106597627912, 44.182747159685405, 43.61716726848057, 40.805231298719136, 41.6877567427499, 43.62604011808123, 45.397139413016184, 50.79310001645769, 53.55616583142962, 53.67231886727469, 50.83519567762102, 52.41183573859078, 46.28556040355137, 41.146735259464805, 39.657576492854524, 39.489100047520225, 38.92833178383963, 38.348841599055696, 42.17969962528774, 39.21521595546177, 44.142520563943044, 44.35188020978655, 48.05939034053257, 47.137458188193186, 51.45133760997227, 41.91112395695278, 40.3052146094186, 41.21262502670288, 38.55539417266846, 42.07117918559483, 38.64634261812483, 38.633453709738596, 40.78059646061489, 39.379321983882356, 40.91526297160557, 40.142883845738, 37.75544112069266, 37.56719010216849, 38.91241693496704, 38.48749985013689, 39.55412823813302, 37.92845473970686, 37.78990765980312, 41.39594629832676, 39.26794236046927, 40.84950522014073, 38.92172057288033, 37.17651373999459, 38.96183599744524, 38.835851260593955, 41.22971759523664, 36.77420261928013, 39.10317277908325, 43.6585750579834, 50.59787648064749, 50.97459738595145, 49.19887406485421, 46.728257928575786, 46.13613591875349, 43.79964780807495, 38.21565505436489, 36.99824728284563, 36.521065848214285, 36.55732502256121, 35.75552722385952, 37.779756341661724, 38.16063574382237, 40.56859997340611, 39.143743310655864, 41.174031257629395, 45.567946978977744, 46.04764366149902, 47.16758905138288, 43.22389922823225, 39.89257499149868, 39.19749804905483, 36.85141447612217, 36.367990085056846, 38.08915615081787, 40.037990365709575, 38.16600670133318, 37.20318440028599, 38.59082998548235, 37.542336395808626, 40.07546547480992, 45.29979167665754, 49.04551689965384, 49.36677033560616, 50.79169995444161, 52.901440552302766, 51.23131595339094, 52.8286303792681, 53.16626419339861, 47.0668158531189, 54.27491181237357, 53.05168839863369, 56.73156901768276, 50.335786955697195, 57.00757231031145, 8.944515926497322, 0.2634229819689478, 2.274269380739757, 1.3091869609696525, 1.9754736082894462, 46.9326947757176, 58.3097620010376, 53.203836577279226, 58.959105900355745, 59.19121742248535, 56.50796903882708, 40.20673084259033, 40.88878686087472, 43.85363531112671, 50.28779227393014, 2.4566902092524936, 0.3033957513315337, 0.13125869099582943, 0.14435106489275182, 0.10436674686414854, 0.12140948378614017, 0.12178049316363675, 0.10683394090405532, 0.12264145910739899, 0.17392859634544167, 0.18543247905160698, 0.10857415252498218], [0.02915544535166451, 0.014781084709933825, 0.08047957971159901, 0.02432830142788589, 0.0253327096745904, 0.02171332754993013, 0.023828372093183652, 0.04581750037946871, 0.05091252483959709, 0.012556919013150036, 0.015397874738222786, 0.030217854771763086, 0.039273650984146764, 0.06991364953241178, 0.08069453960550682, 0.14723713217037065, 29.106260980878556, 46.28555345535278, 29.43528597695487, 24.958947249821254, 38.63342244284493, 51.8191682951791, 47.949535846710205, 47.2402081489563, 49.3449182510376, 44.93505988802229, 51.184241907937185, 6.425278902053833, 0.8563705789191383, 0.17151590223823274, 0.007872152092334415, 1.3474080243280955, 47.955375807625906, 61.981732095990864, 50.484825815473286, 54.10215875080654, 50.26114245823452, 53.42696755273001, 51.216637883867534, 51.24651166370937, 52.4484874861581, 53.23857757023403, 51.07687486921038, 50.07332222802298, 49.99652031489781, 49.4672725541251, 51.51598364966256, 48.79005248206002, 45.91777835573469, 41.72604826518467, 37.527467250823975, 37.74736731392996, 37.85012422289167, 37.02810369219099, 36.343841620853965, 36.98804037911551, 40.94015836715698, 43.6531936781747, 45.336700507572715, 46.36664588110787, 48.35621738433838, 47.358344895499094, 41.99539170946394, 38.723498889378135, 38.326100145067485, 35.82008988516671, 35.18554217474801, 37.86643164498465, 37.349944250924246, 36.373993328639436, 37.00724172592163, 40.664870738983154, 44.03788764136178, 46.01124899727957, 46.980963911329, 40.23628153119768, 38.927949632917134, 39.55626480919974, 38.462910175323486, 36.27609321049282, 37.63309723990304, 37.36606754575457, 39.2631585257394, 33.86139270237514, 33.60835668018886, 33.77390445981707, 33.80602945600237, 33.96358680725098, 33.650264739990234, 33.33937454223633, 33.49413524355207, 32.405498436519075, 32.58415051868984, 32.258630888802664, 33.21716615131923, 35.84464829308646, 36.56135497774397, 38.200042452131, 38.748290061950684, 36.449992724827354, 37.1822703225272, 37.56254870550973, 39.22079535893032, 39.08008738926479, 43.61964430127825, 45.28680549349104, 43.731975827898296, 40.14776495524815, 41.137980529240195, 36.82544558388846, 33.24258613586426, 33.652005263737266, 34.19180733816964, 33.24560512815203, 32.73648977279663, 33.12499829701015, 34.603130272456575, 33.943089621407644, 36.453980990818565, 36.544536863054546, 41.83618763514927, 36.73846108572823, 40.583809580121724, 37.793058667864116, 34.71691049848284, 34.547099999019075, 32.92205878666469, 32.0602250780378, 34.18041924067906, 34.34541116441999, 33.924551827566965, 34.72191320146833, 34.39144992828369, 35.30262974330357, 34.57933964048113, 39.972784996032715, 46.20014272417341, 48.284379959106445, 49.08708102362496, 48.921008655003135, 45.97371135439192, 47.599343163626536, 51.24097047533308, 47.61648089545113, 49.65979324068342, 45.032108851841514, 49.30987501144409, 45.87356349400112, 55.67071458271572, 14.383147154535566, 0.13568611842181, 0.5058618070823806, 0.7173771315387317, 2.3590321924005235, 45.88531984601702, 46.43688522066389, 46.3354241507394, 48.8361086164202, 51.822826521737234, 37.44776793888637, 32.13130167552403, 29.53493356704712, 38.422006130218506, 16.45804861613682, 0.15910559174205574, 0.022635380305083733, 0.05404440839109676, 0.030987082781004052, 0.052962796429970434, 0.03895294480025768, 0.06728037726134062, 0.08495372427361352, 0.0680658629696284, 0.04268230218440294, 0.005596019518894276, 0.013779155660553702, 0.06692745084209101, 0.020909412830535854, 0.07838934580130236, 0.029180910770914385, 0.025826905388385057, 0.019608868152967522, 0.023738593428528736, 0.020721117666523372, 0.020073033603174344, 0.01627517810889653, 0.05680010534290757, 0.056645273829677274, 0.03537814412266016, 0.014504447679168411, 0.04480345015014921, 0.7361875336085046, 37.99749551500593, 49.61869464601789, 20.41189844267709, 34.11749635423933, 46.76973172596523, 54.873363631112234, 57.97451836722237, 51.113547461373464, 56.02065018245152, 49.10159581048148, 56.1469475882394, 5.482357978820801, 1.426667537008013, 0.09393660511289324, 0.1351349444261619, 1.529916899544852, 49.923105648585725, 64.12089484078544, 53.772438934871126, 57.213172980717246, 52.08965471812657, 54.126199517931255, 53.769197600228445, 51.845800740378245, 53.74483721596854, 55.79567446027483, 51.53035599844796, 52.279396125248496, 50.53918504714966, 51.12926776068551, 53.33665139334542, 50.8292167527335, 47.98773009436471, 42.964599405016216, 40.11687673841204, 40.505895955221995, 38.81631292615618, 37.67763866697039, 38.13205085481916, 39.59663036891392, 41.60060896192278, 45.64611073902675, 47.59822450365339, 48.75169495173863, 49.90196228027344, 48.3805638722011, 43.34924473081316, 38.98507077353341, 40.15520647593907, 37.332768304007395, 36.976666178022114, 38.46617235456194, 40.41687910897391, 36.66845103672573, 39.36037424632481, 42.73756006785801, 45.11397252764021, 46.917443479810444, 47.28608015605381, 40.12878942489624, 38.916981901441304, 40.27906853812081, 38.56494447163173, 38.22944722856794, 40.1564884185791, 38.49835293633597, 39.311191422598704, 36.66991015842983, 36.64681782041277, 36.7928272656032, 36.12591484614781, 34.79621376310076, 36.01100901194981, 35.712872232709614, 35.67019987106323, 33.680114201136995, 35.39444323948452, 34.494654996054514, 36.500262941632954, 36.70314686638968, 38.066407748631065, 39.130854402269634, 37.868880884987966, 37.00200973238264, 38.064093998500276, 37.44514846801758, 38.630062988826204, 36.808564935411724, 43.06043938228062, 46.16283437183925, 46.12178441456386, 45.886035510471885, 43.2710497038705, 37.92037398474557, 35.76577581678118, 36.92183794294085, 36.697810649871826, 34.90786436625889, 35.13871826444353, 35.5396397454398, 35.91126067297799, 34.98857464109148, 38.74199846812657, 40.05493007387434, 43.02358266285488, 39.66988522665841, 42.832343918936594, 39.70199980054583, 36.106421675000874, 36.935675280434744, 35.33431700297764, 33.939539091927664, 37.10831369672503, 36.820178849356516, 35.18921429770333, 36.505081517355784, 37.24070814677647, 37.15686770847866, 37.295175075531006, 41.165953976767405, 49.567211968558176, 50.03491258621216, 49.46683134351458, 49.70531088965279, 47.91642768042428, 48.74162353788103, 52.14117213657924, 49.08047676086426, 52.49911553519112, 48.375397886548726, 51.41762147630964, 49.737085001809255, 57.893554483141216, 15.436173575265066, 0.03886362923575299, 0.5333098513739449, 0.6855552505169595, 2.970078923872539, 50.807653018406455, 50.64521108354841, 52.107042585100444, 53.947415419987266, 58.352250235421316, 42.96990088054112, 40.17240674155099, 27.691072736467632, 45.665843623025076, 21.399772473743983, 0.2940556082342352, 0.058990776006664546, 0.05163760396784969, 0.009049087197386792, 0.06361210159957409, 0.04234975556443844, 0.05668879506577339, 0.04625469745535936, 0.035151618599359474, 0.014900133678955691, 0.03103585248546941, 0.03661493704255138, 0.12645456806889602, 0.07345183646040303, 0.17973495620701993, 0.10304200902049031, 0.13556181080639362, 0.19301015457936696, 0.13108110481074878, 0.1533509769609996, 0.12831205768244608, 0.11581030780715601, 0.13320390161659035, 0.09917548578232527, 0.16195698588022164, 0.12967714800366334, 0.11891232563980988, 0.8922247492841312, 47.69287633895874, 59.70591218130929, 37.19353335244315, 34.83615895680019, 50.622952529362266, 60.60992840358189, 60.89406108856201, 59.47951207842146, 59.05474785396031, 55.9124493598938, 61.33281203678676, 7.779520153999329, 2.99696324127061, 0.25587669547115055, 0.3970544013593878, 2.200438908168248, 53.030041285923545, 66.79350553240094, 56.83069201878139, 60.13756207057408, 52.62815400532314, 57.75249562944685, 54.403932912009104, 52.80105297906058, 54.39419501168387, 56.92943981715611, 52.69084412711007, 52.53549977711269, 53.17484174455915, 53.828479630606516, 54.947625977652415, 52.88348988124302, 50.206731115068706, 45.20314570835659, 41.561400277274, 42.21009799412319, 40.952192647116526, 40.03779929024832, 40.00075149536133, 40.99024445669991, 44.533773626599995, 47.10813679013933, 48.27877623694283, 49.97757257734026, 51.277549266815186, 51.853294372558594, 45.56236410140991, 40.718879086630686, 42.15803166798183, 39.56155933652605, 40.479183605739046, 41.78444440024239, 41.66826357160296, 38.70566633769444, 41.09105587005615, 44.91111639567784, 48.43659067153931, 50.23198781694685, 49.115134375435964, 40.286874839237754, 39.813309941973, 40.9276168687003, 40.34699065344674, 39.251697472163606, 41.82825974055699, 39.37306860515049, 44.37668875285557, 38.55813871111189, 39.48941271645682, 39.82103633880615, 37.69995280674526, 38.000524929591585, 37.957529476710725, 36.419955662318635, 37.3050971031189, 37.48390204565865, 37.55572557449341, 36.074838638305664, 38.450723034994944, 39.03733164923531, 40.101618494306294, 42.061458655766074, 40.076973233904155, 38.38703237261091, 37.55593054635184, 37.2237024307251, 38.6142384665353, 38.23757662091936, 43.829028265816824, 47.04689189365932, 47.02020386287144, 45.81784936359951, 45.74173879623413, 40.37133714130947, 37.47229855401175, 39.064200333186555, 39.007381439208984, 37.517135279519216, 36.96184567042759, 37.613451208387104, 38.05426229749407, 38.28403575079781, 42.04995938709804, 41.33790799549648, 47.52588333402361, 41.1787942477635, 45.515863282339915, 41.74368279320853, 39.29868813923427, 41.21510205950056, 38.406028747558594, 33.98943410600935, 39.48176622390747, 38.81346763883318, 37.34034531457083, 38.876925536564414, 38.94421189171927, 37.67973354884556, 39.82642466681344, 43.990834440503804, 50.62579434258597, 52.49011761801583, 51.04068170275007, 52.280983788626536, 48.51255185263497, 49.749980858394075, 54.57374341147286, 50.20003652572632, 55.353907993861604, 49.96775129863194, 55.27130086081368, 50.18021331514631, 61.61752837044852, 17.730698040553502, 0.1734768548714263, 1.6830839663743973, 1.0875717784677232, 2.80145982333592, 56.79229279926845, 54.71855429240635, 57.700491837092805, 56.426414557865684, 63.68716049194336, 47.95039394923619, 44.47141007014683, 37.90329531260899, 52.98791088376726, 28.943475110190256, 0.3182568624615669, 0.2871102866317545, 0.13030457576470716, 0.09205485787242651, 0.11694798033152308, 0.15557897383613245, 0.16386274647499832, 0.160783052444458, 0.16072799611304486, 0.12320939291800771, 0.15842768097562449, 0.10262206369744879], [0.06599029898643494, 0.04851819188999278, 0.02222270718110459, 0.022093748208135366, 0.02166880717101906, 0.0126732954023672, 0.09184954674648386, 0.05741506841565881, 0.023009541477741938, 0.08355505325432334, 0.009310198498756757, 0.01767961837218276, 0.0974644986646516, 0.1374352052807808, 0.1485074447201831, 0.2308756655880383, 11.657756209373474, 50.30326591219221, 34.50484452928816, 19.051625285829815, 24.686197451182775, 43.953376701899934, 46.0248361996242, 49.52919142586844, 52.417046887534006, 43.4363751411438, 49.16073540278843, 13.016065631593976, 0.7191506049462727, 0.0814527210646442, 0.09448354505002499, 0.7971455454826355, 46.079348291669575, 63.20686626434326, 52.97158261707851, 48.78841618129185, 40.73236206599644, 44.7711866242545, 45.001352650778635, 52.175524030412944, 50.604560647692, 53.19967460632324, 51.64393125261579, 53.3756377356393, 51.91045025416783, 53.217858042035786, 47.30089718954903, 45.10518305642264, 38.73324373790196, 37.0080372946603, 38.88013560431344, 38.07223033905029, 36.31526368004935, 37.66474628448486, 36.92431150163923, 38.157588958740234, 39.200589997427805, 41.2888571875436, 44.53074421201433, 47.72999014173235, 46.69637611934117, 44.757363183157786, 40.75332825524466, 39.00750650678362, 37.04693331037249, 35.56103672300066, 35.11317668642317, 37.109126635960166, 36.22087587629046, 36.5070652280535, 37.41450343813215, 41.28903089250837, 42.50913456508091, 45.68194259916033, 44.69721610205514, 38.22621979032244, 40.753032956804546, 37.24636745452881, 36.13317918777466, 38.014390059879844, 38.35187448774065, 35.2007656778608, 33.27130651473999, 33.751941204071045, 32.824030126844136, 33.678425788879395, 34.58943884713309, 33.315173966544016, 33.752000263759065, 34.79130138669695, 34.520578724997385, 33.844887256622314, 33.49274560383388, 34.937244824000764, 34.01199490683419, 33.50926494598389, 33.46390363148281, 34.642696789332796, 36.39270830154419, 37.54687704358782, 38.39204202379499, 39.02334145137242, 37.867112568446565, 39.44617060252598, 41.00652061189924, 46.0452812739781, 42.110245432172505, 39.17040702274868, 38.16662161690848, 36.62589679445539, 32.722909518650596, 33.223082542419434, 35.36726188659668, 32.943987301417756, 32.55768483025687, 32.27111332757132, 34.88648475919451, 34.05702270780291, 35.18227999550955, 35.82871607371739, 37.86559438705444, 38.05568667820522, 37.0928886958531, 36.60457624707903, 35.02830444063459, 34.98020553588867, 33.04997859682356, 32.46075051171439, 32.832913398742676, 34.44982521874564, 33.49517747334072, 34.28806420734951, 35.57557930265154, 34.03072377613613, 33.79668065479824, 35.96099935259138, 40.66274459021432, 46.4264212335859, 48.320892742701936, 48.48837559563773, 46.440001487731934, 48.92024435315813, 49.51349891935076, 47.20419563565935, 45.597455978393555, 41.19280181612287, 46.5059676851545, 47.47586325236729, 52.9157121522086, 22.821427753993444, 0.11305003413664443, 0.31842220787491116, 0.5778889507055283, 3.734302818775177, 47.00597047805786, 44.795460156032014, 49.04743112836565, 47.703326429639546, 44.992535386766704, 32.42280292510986, 23.09462571144104, 29.663513456072124, 45.418560709272114, 4.702717551163264, 0.3288600577839783, 0.04015909168603165, 0.11039550336343901, 0.016379424836486578, 0.035651566593774726, 0.0069724511288638625, 0.037397579689111025, 0.050728367042860815, 0.01239314695288028, 0.03455114903460656, 0.004515056830963918, 0.028273514372163584, 0.05384581136916365, 0.04423533992043563, 0.032152181690824885, 0.026228745700791478, 0.04499884109411921, 0.044781784527003765, 0.006026304019282439, 0.03853997142453279, 0.014149025099218955, 0.03153423645666667, 0.05135126558265515, 0.029757713034216846, 0.1359605315540518, 0.0978350398529853, 0.05601281812414527, 0.18872140614049776, 18.683848449162074, 60.508387429373606, 27.356956447873795, 18.93441264969962, 44.83939708982195, 46.79413727351597, 50.199775968279155, 54.09222977502005, 56.437590735299246, 48.25318602153233, 54.131302969796316, 13.820974486214773, 1.3167228251695633, 0.05888984392264059, 0.06082457796271358, 0.8864138839500291, 47.61050197056362, 63.222082819257466, 54.9884466443743, 51.39000933510916, 43.28090572357178, 48.470108781542095, 47.658989974430625, 53.67664064679827, 53.64175026757376, 55.43311398369925, 53.59222003391811, 54.701336656297954, 52.52591126305716, 54.27677392959595, 50.00846774237496, 48.05555840900966, 41.712975229535786, 38.79968588692801, 40.48879991258894, 39.99348020553589, 39.04875101361956, 39.17787286213466, 39.63961887359619, 40.04783248901367, 40.88694906234741, 44.20810808454241, 46.91613374437605, 49.5746500151498, 48.4428197315761, 47.00138814108712, 43.69616133826119, 41.46819714137486, 38.65370076043265, 38.56477771486555, 37.05226257869175, 37.582295485905235, 38.63951601300921, 39.23138441358294, 39.088067395346506, 42.07594217572893, 44.23777689252581, 46.65318611689976, 46.123448508126394, 39.15174068723406, 41.23449795586722, 36.92376954214913, 37.68044226510184, 40.93604155949184, 39.453959533146445, 38.42306573050362, 35.746487617492676, 36.860488823481965, 35.43763324192592, 37.5492012160165, 35.803938797542024, 35.44962930679321, 35.25055646896362, 36.19979156766619, 36.124306338174, 35.92725542613438, 35.158159324101035, 36.289235728127615, 35.638276372637065, 36.70867763246809, 34.783766065325054, 36.36478001730782, 38.64322635105678, 38.96091536113194, 38.91868073599679, 38.53589752742222, 38.83738681248256, 39.898508753095356, 41.91759967803955, 48.850901331220356, 45.10039922169277, 40.625596046447754, 40.13255534853254, 36.70845181601388, 35.27932895932879, 35.150776863098145, 36.661502838134766, 35.08921234948294, 35.171485968998496, 34.115519591740195, 36.75844063077654, 34.56250415529524, 37.255410534994944, 36.9294879095895, 40.33905233655657, 40.44004092897688, 39.39310720988682, 38.709908212934224, 37.51072209221976, 37.35606561388288, 34.661227634974885, 34.83349084854126, 34.71953691755022, 37.261448519570486, 35.00791147777012, 36.10657453536987, 37.08712863922119, 35.80488722664969, 35.541668619428364, 37.63303470611572, 42.10607303891863, 47.678431034088135, 51.458383083343506, 50.85535587583269, 49.03430250712803, 50.47968414851597, 52.00666543415615, 49.4923312323434, 49.007482460566926, 43.26762424196516, 48.51578276497977, 51.0793901171003, 56.334517683301655, 25.673619849341257, 0.0930161995014974, 0.34436110886079924, 0.18851833418011665, 4.86670719725745, 51.23015907832554, 50.36369092123849, 51.21702003479004, 54.16707924434117, 49.370324339185444, 40.66457544054304, 29.251964705330984, 29.440729890550884, 55.48208488736834, 6.465702652931213, 0.394360997314964, 0.047786371516329904, 0.06708797865680285, 0.03621886258146592, 0.018973767857200334, 0.024431335274130106, 0.08297078710581575, 0.015044980549386569, 0.051540777020688565, 0.020085615338757634, 0.048866979245628626, 0.0267905082354056, 0.16607684695294925, 0.13106198369392327, 0.19352468768400805, 0.13919129462114402, 0.10419942691390004, 0.16064141504466534, 0.17615537185754093, 0.11903838387557439, 0.06264518241264991, 0.1102101072402937, 0.2319362158221858, 0.17580273720834935, 0.2640037808035101, 0.3329712471791676, 0.1751117171453578, 0.4596298507281712, 22.343963180269512, 66.24254117693219, 43.906934942517964, 26.2423802784511, 38.029200145176475, 54.320231437683105, 54.30796091897147, 58.973273277282715, 62.2347993850708, 53.561165060315815, 59.65872001647949, 16.16974527495248, 1.8016371705702372, 0.1807561106979847, 0.49451083902801785, 1.6228525297982352, 50.87982048307146, 66.34486034938267, 57.465712206704275, 54.02030202320644, 44.253236634390696, 51.77033635548183, 48.66139268875122, 55.59028223582676, 55.2502304485866, 57.724991185324534, 55.722027029309956, 58.43423203059605, 54.556220054626465, 57.524184771946494, 51.63637161254883, 50.05972807747977, 42.9153470993042, 39.16436556407383, 42.24000651495797, 42.902729170663015, 40.588961669376914, 41.19269411904471, 41.87268999644688, 42.3595745904105, 42.84268283843994, 47.466976506369456, 48.85008839198521, 51.890769481658936, 51.7645936693464, 49.4688150542123, 45.29795387813023, 42.62265075956072, 40.73747941425869, 40.40855169296265, 38.435742718832834, 41.12665149143764, 39.75685235432216, 40.44476570401873, 40.62237555640084, 45.88469450814383, 45.28570072991507, 48.662664209093364, 46.35535158429827, 39.52855886731829, 43.82776369367327, 37.63813468388149, 39.268025738852366, 42.65314292907715, 40.37144136428833, 40.39810160228184, 37.729128292628694, 39.06857769829886, 37.93158490317208, 39.57387849262783, 38.72694172177996, 36.82105779647827, 36.8468599319458, 39.37104320526123, 38.496497767312185, 38.45438820975167, 38.023874350956504, 40.21101093292236, 37.869120597839355, 39.17505189350673, 37.72518171582903, 38.78536217553275, 38.5416819027492, 38.89866644995553, 39.3495454788208, 40.48338726588658, 39.006697041647776, 40.25004938670567, 42.75597626822335, 50.31217350278582, 46.88604804447719, 41.46605362210955, 42.1130907194955, 40.47579288482666, 37.205810819353374, 36.9062705039978, 39.72890322549002, 36.586083616529194, 36.82319436754499, 35.711732728140696, 38.458852427346365, 36.97446707316807, 39.55949224744524, 39.32459102358137, 42.65526212964739, 43.125022888183594, 42.573450565338135, 40.854563508714946, 39.099445070539204, 40.07128265925816, 36.97140639168875, 37.226162093026296, 36.62913465499878, 37.799239090510774, 39.0390304837908, 37.16498667853219, 40.25505903788975, 37.77368014199393, 38.43456152507237, 39.80814395632063, 45.12617009026663, 50.411796774183, 53.51024171284267, 52.385258878980366, 49.92837585721697, 53.63128628049578, 54.49703182492937, 51.828305176326204, 50.845777784075054, 44.97549145562308, 51.76252310616629, 53.29069253376552, 56.914945874895366, 27.6647755418505, 0.16650205770773546, 0.8081753764833722, 1.1714537973914827, 6.207010362829481, 58.88999216897147, 54.04653147288731, 57.624019963400706, 59.569067410060335, 55.813274247305735, 41.52997357504708, 32.90805121830532, 38.56777933665684, 65.05645588466099, 9.552833318710327, 0.6127511571560587, 0.12026308530143329, 0.2354943991771766, 0.0839962570794991, 0.16989724338054657, 0.134694208790149, 0.1494676803371736, 0.1531791990356786, 0.06899508953626667, 0.1200891767761537, 0.1272655124110835, 0.15826510398515634], [0.016484913283160756, 0.031278065738401244, 0.03320815181359649, 0.08389067024524723, 0.05325126541512353, 0.0926407864317298, 0.07991753558495215, 0.02373391153690006, 0.02837204953123416, 0.023117908609232733, 0.0519199932792357, 0.04055270306499941, 0.0388674426025578, 0.02425316215625831, 0.04916034386094127, 0.02023564282405589, 0.1177540799336774, 27.595364774976456, 47.87238652365548, 24.31126570701599, 20.429616349084036, 38.800238268715994, 56.42730392728533, 49.98111963272095, 49.292862347194124, 43.70527042661394, 49.77739497593471, 14.839425802230835, 0.4895035762872015, 0.017040144918220382, 0.0840133765180196, 0.48903028454099384, 40.44488729749407, 63.65537943158831, 49.20869534356253, 51.90277944292341, 40.22146449770246, 42.73888717378889, 40.09685550417219, 40.323766299656455, 42.26761865615845, 45.00010544913155, 45.226880754743306, 48.22698089054653, 44.115019593920024, 42.666087423052105, 39.17959948948452, 37.86979457310268, 38.07480812072754, 37.37814351490566, 37.113455363682334, 36.655732359204976, 37.55519751140049, 38.40515674863543, 36.72410610743931, 37.32395798819405, 38.65686913899013, 41.25015572139195, 43.84950460706438, 43.49198504856655, 46.605462414877756, 44.19767536435808, 41.604677132197786, 38.49663325718471, 35.660666942596436, 35.30349826812744, 35.88847752979824, 37.72635248729161, 36.144185134342735, 39.63012763432094, 39.01533365249634, 38.69749525615147, 40.00774138314383, 44.111462116241455, 47.10682358060564, 41.395004817417686, 40.714838709150044, 39.42518356868199, 37.262407370976035, 37.753971576690674, 34.98295702253069, 34.54114191872733, 34.25076280321394, 34.80857113429478, 33.166409560612266, 32.86798095703125, 33.36807755061558, 34.67306041717529, 34.98250886372158, 34.880220958164756, 36.234459604535786, 33.933820724487305, 33.21345233917236, 33.56761939185006, 33.46314975193569, 33.88145215170724, 33.20959261485508, 33.57161113194057, 32.17216750553676, 33.29764713559832, 36.89032091413225, 38.3150247165135, 39.033294745853965, 39.79996245247977, 41.41567570822579, 46.55917351586478, 44.306769030434744, 40.176016330718994, 38.77009350912911, 37.11435515539986, 35.18703951154436, 33.72790738514492, 34.27195480891636, 32.48394012451172, 33.55059630530221, 32.61846072333199, 35.06303153719221, 33.295260429382324, 33.45678172792707, 35.65956217902047, 37.23652185712542, 33.97610051291329, 33.782912799290244, 35.65017516272408, 33.4427672113691, 33.87143284933907, 33.170946734292166, 31.485525676182338, 31.231648921966553, 32.04659966060093, 33.71435144969395, 33.58303049632481, 32.826764242989675, 33.74143205370222, 35.1095358303615, 33.91388981682913, 34.242021969386506, 37.6977675982884, 42.69378294263567, 45.869641235896516, 49.03960745675223, 48.41319956098284, 45.40707881110055, 41.278066635131836, 38.5132394518171, 39.27065563201904, 46.07564837591988, 48.92345094680786, 52.93374967575073, 29.599398953574045, 0.16743061931005546, 0.22411715824689182, 0.11749725442911897, 1.97536786539214, 45.41840090070452, 47.934638908931184, 47.722319330487935, 50.34505237851824, 39.06472839627947, 30.87438644681658, 25.741495064326696, 34.63422693525042, 20.5744081224714, 0.14401171595922538, 0.03878275464688029, 0.03430956342656698, 0.027847721773598875, 0.02167832532099315, 0.03608962201646396, 0.04361831749390278, 0.05163902549871376, 0.02205666118035359, 0.02090696501545608, 0.017942389539842094, 0.027053464303857515, 0.01721402969477432, 0.05136728240177035, 0.02210105094127357, 0.059073726912694316, 0.02633086691743561, 0.03265618732465165, 0.06581356097012758, 0.07969879625099045, 0.03848330017977527, 0.025228425627574325, 0.060398634390107224, 0.09080556633749179, 0.040454532618501356, 0.044175747582422834, 0.039093591538923125, 0.15827488846012525, 0.04657325268323932, 1.1951331496238708, 35.74735961641584, 51.05309465953282, 16.890593085970195, 32.41268982206072, 45.73367541176932, 58.53068692343575, 56.91219091415405, 53.2893966947283, 50.07775517872402, 53.29706403187343, 16.709225995200022, 0.9333428314753941, 0.03229945771662252, 0.27437817411763327, 0.5090985276869365, 42.576990672520225, 65.5415096282959, 52.81797531672886, 55.067815916878835, 42.86533049174717, 43.58602891649519, 42.0908773286002, 42.91458279745919, 44.05091551371983, 47.512904099055696, 46.65791436604091, 51.1751571382795, 47.21637235369001, 45.52196380070278, 41.577124050685335, 40.496171951293945, 39.422036034720286, 39.69630922589983, 38.7269104548863, 39.41068615232195, 39.41616480691092, 40.09473977770124, 38.82420607975551, 38.798060008457725, 40.77478429249355, 42.31651312964303, 44.913044520786826, 46.674242632729666, 46.943916116442, 47.160654749189106, 42.24614177431379, 40.94600527627127, 36.78178310394287, 37.453858034951345, 35.98364005770002, 39.981171471732004, 38.45258862631661, 39.94333505630493, 40.995785645076204, 40.88645921434675, 43.04660899298531, 47.30249180112566, 47.31714902605329, 42.59358297075544, 40.78802408490862, 41.29841096060616, 38.95334529876709, 39.18747527258736, 37.89825439453125, 35.787183216639924, 35.94089126586914, 36.68672479901995, 35.056277888161794, 35.621597221919465, 35.471762793404714, 37.08314732142857, 36.72587442398071, 35.98975099836077, 36.785851274217876, 37.314570971897666, 35.88395425251552, 34.777293818337576, 36.22774764469692, 35.60410165786743, 34.96790722438267, 35.019000802721294, 34.169989994594026, 36.290257113320486, 38.62843016215733, 39.52744368144444, 38.82492869240897, 39.23982300077166, 40.334511688777376, 48.32344273158482, 45.50352675574166, 41.53121035439627, 38.75682592391968, 38.488788740975515, 36.07515130724226, 35.81584453582764, 35.6048937525068, 35.488038948604036, 34.59766204016549, 34.561215264456614, 36.07278197152274, 34.3845260483878, 35.435507093157085, 37.425474643707275, 38.02562182290213, 36.66311134610857, 36.58581958498274, 37.10881049292428, 34.773837089538574, 35.57990803037371, 36.130827222551616, 34.03902339935303, 33.69881875174386, 36.07346289498465, 36.601098673684255, 36.006940841674805, 34.96931076049805, 35.4706198147365, 37.18100922448294, 35.695070947919575, 35.870262827192036, 40.591407435280935, 46.05054800851004, 49.32157577787127, 50.825138160160606, 51.19651937484741, 46.915480613708496, 44.4241657938276, 41.87281853812081, 43.45490598678589, 47.71408918925694, 52.75171034676688, 54.39304508481707, 32.99311106545584, 0.22195203442658695, 0.15225351442183765, 0.2056249212473631, 1.9983418669019426, 49.27695097242083, 53.38167224611555, 50.647212164742605, 55.57970707757132, 43.0166448865618, 46.53470196042742, 24.11363983154297, 35.22842993055071, 29.232669557843888, 0.21646940362240585, 0.034957282777343474, 0.04236679357875671, 0.08282720909586974, 0.04008143674582243, 0.036904260981827974, 0.0421885763561087, 0.05633718839713505, 0.03686065153617944, 0.08950490970164537, 0.03965286385001881, 0.044851731309401136, 0.021897846666563834, 0.13984874077141285, 0.14718054234981537, 0.1321453462753977, 0.15465043937521322, 0.13399123294012888, 0.1438018993607589, 0.17565919991050447, 0.08697575862918581, 0.10151117973561798, 0.11270765215158463, 0.23124663425343378, 0.13186161007199967, 0.11574833041855268, 0.10627048542456967, 0.28394739063722746, 0.09242613187858037, 1.3716872015169688, 45.97791154044015, 58.44375801086426, 30.564719132014684, 29.636227880205425, 51.265980516161235, 67.57913834708077, 59.687534196036204, 59.774442264011924, 54.65446410860334, 59.0499883379255, 18.589220932551793, 1.7597453956093108, 0.08294000875736986, 0.8651139097554343, 0.814279531793935, 45.69050972802298, 67.00869124276298, 54.644681044987266, 58.047283376966206, 45.037952286856516, 47.81000559670584, 45.228044578007285, 43.776857716696604, 47.27795771190098, 51.17444494792393, 48.70381144114903, 53.892646244594026, 47.38429989133562, 46.89072070802961, 43.690574986594065, 41.97630500793457, 41.66042947769165, 41.6028983933585, 41.457510811941965, 41.4982133592878, 42.25809962408883, 43.78072786331177, 39.57050166811262, 40.43002510070801, 44.55224888665335, 44.672272069113596, 48.55983434404646, 49.37602186203003, 51.55741228376116, 50.63653973170689, 45.1410288129534, 44.006502628326416, 37.97379868371146, 38.56306150981358, 39.714207785470144, 41.20050042016165, 39.51256758826119, 42.66175174713135, 43.68655545370919, 44.51243223462786, 44.1022800718035, 47.51511710030692, 49.1556840624128, 43.68218156269619, 43.5654969896589, 43.848410265786306, 39.47026000704084, 40.96440758023943, 40.94918407712664, 37.58118724822998, 39.20649249213082, 38.4264668737139, 35.88222067696707, 37.393214157649446, 37.260632106236045, 40.29223190035139, 39.20704139981951, 38.66498810904366, 39.911918776375906, 38.78092227663313, 35.99532345363072, 37.04583549499512, 40.042756829942974, 39.17357887540545, 35.984414781842915, 37.836568287440706, 37.1516878264291, 38.21658958707537, 41.632862499782014, 41.042977809906006, 40.36590365001133, 42.339219842638286, 42.57083804266793, 49.11891419546944, 48.245928628104075, 43.80794048309326, 41.568900857652935, 39.950300625392366, 38.1841276032584, 37.96377938134329, 38.47545167378017, 36.94739689145769, 36.74170242037092, 37.227902616773335, 38.50195210320609, 37.00640099389212, 37.92199291501726, 40.593415464673726, 40.68169927597046, 38.308357919965474, 38.94416672842843, 40.294868741716655, 37.50710555485317, 39.455845969063894, 38.09395040784563, 35.973488739558626, 36.930401597704204, 37.20419536318098, 38.99971062796456, 37.85869482585362, 37.84308222361973, 37.85597113200596, 39.87860216413225, 37.934770652226035, 37.26892130715506, 42.3348320552281, 47.65969174248831, 50.42142697743007, 53.72448941639492, 53.69111721856253, 49.330945423671174, 46.329698835100444, 44.839476994105745, 44.09287568501064, 48.99957193647112, 56.443163190569194, 56.58479527064732, 35.98763179779053, 0.2055550864232438, 0.4118458947965077, 0.48233422956296373, 2.2015282554285864, 57.1723175730024, 55.43224893297468, 58.33249650682722, 59.30739825112479, 49.47644765036446, 42.27882262638637, 35.586123194013325, 45.00565358570644, 37.886980942317415, 0.31290441538606373, 0.25747494399547577, 0.15162344037422112, 0.12133413925766945, 0.17798265309206077, 0.1070549940424306, 0.10134530506495919, 0.11456624099186488, 0.21079811294163975, 0.160300505480596, 0.11260053861354079, 0.1526460876422269, 0.13209670888526098], [0.014927022325407182, 0.07014588492789439, 0.01059683914562421, 0.02321239121790443, 0.03589337272569537, 0.057156085169741085, 0.01001699619726943, 0.0265715466812253, 0.032781254899288924, 0.04915563143523676, 0.0640005628977503, 0.020624763997537748, 0.040557493522231064, 0.03790145640128425, 0.06540291157684155, 0.12992560038609163, 0.12835351617208549, 10.019199013710022, 49.75875990731375, 37.73612860270909, 29.217362676348003, 26.788400990622385, 51.721500941685264, 48.541060311453684, 53.52963413511004, 41.21479981286185, 50.20663384028843, 11.925652691296168, 0.2937905453145504, 0.0994142893967884, 0.09830776841512748, 0.03889990711052503, 31.925989355359757, 65.20226383209229, 53.30763571602957, 55.64825105667114, 44.30063377107893, 40.99618864059448, 40.209742886679514, 39.652038778577534, 37.84981502805437, 38.7352865082877, 37.55618068150112, 39.08439874649048, 38.376057692936485, 38.32795878819057, 36.54252535956246, 38.12993860244751, 38.30380684988839, 37.229351316179546, 37.39979410171509, 36.290076460157124, 35.65143973486764, 36.06037596293858, 37.74168716158186, 36.161500045231406, 39.99779156276158, 39.052117415836875, 44.17434678758894, 43.105703422001426, 41.91068622044155, 43.54261309759957, 40.498853955950054, 36.99660055977957, 36.59261492320469, 35.8645201410566, 34.76919221878052, 37.11474078042166, 36.71140480041504, 40.34575734819685, 40.1448849269322, 36.72710772923061, 41.812084334237234, 44.68715858459473, 45.79555606842041, 41.60836315155029, 40.136210100991384, 38.73377527509417, 34.77350010190691, 33.13243286950247, 34.697959286826, 34.69381121226719, 34.06300163269043, 34.00055122375488, 32.71265050343105, 34.38653755187988, 36.26896088463919, 33.07445362636021, 34.339838709150044, 34.912481444222585, 34.09717982155936, 35.674601554870605, 33.57921593529837, 33.95183045523507, 32.607975891658235, 32.22137812205723, 32.029451506478445, 32.50058453423636, 33.67879751750401, 33.12728425434658, 31.545492104121617, 34.68794693265642, 36.08813749040876, 39.03225251606533, 43.632529735565186, 45.761482102530344, 44.59078359603882, 39.687231404440745, 37.66542373384748, 37.39460032326834, 37.429039069584434, 34.735875606536865, 33.157706941877095, 33.82919127600533, 32.769542353493826, 32.91546147210257, 34.04169150761196, 32.86959988730294, 33.022998741694856, 34.30011933190482, 34.48310014179775, 33.51968376977103, 34.876121520996094, 34.06274454934256, 34.57824877330235, 34.288522788456504, 34.602532727377756, 33.62378168106079, 33.16982807431902, 33.23163577488491, 33.0155085836138, 33.24103321347918, 32.98762893676758, 32.90049852643694, 35.492565699986045, 34.391922405787874, 35.73444986343384, 34.21102952957153, 34.7582939692906, 35.50114672524588, 37.800486292157856, 36.98837389264788, 36.67422498975481, 35.573077951158794, 40.084244523729595, 41.93907655988421, 47.419176374162944, 47.8400148664202, 53.67536565235683, 25.78899989809309, 0.20021846278437547, 0.19751770342034952, 0.01847288857347199, 2.6690430087702612, 47.979677132197786, 43.528331075395855, 49.31572886875698, 49.67229652404785, 31.57689448765346, 25.663230555398123, 25.76374840736389, 39.785048144204275, 5.943794795445033, 0.2109854971723897, 0.02924003152708922, 0.0972372776429568, 0.017806204168924263, 0.08752391992935113, 0.018454254305522357, 0.010258600465022027, 0.04816055643771376, 0.037820072911147556, 0.02202176582068205, 0.02562234065096293, 0.0734631476391639, 0.025306017803294317, 0.035081244339900355, 0.05056473493043866, 0.038430689967104366, 0.012952250478390073, 0.025256856244855692, 0.013332463335245848, 0.05529777452881847, 0.03750109699155603, 0.028657763664211546, 0.04813430391784225, 0.09753008585955415, 0.023986811716375605, 0.06612981935696942, 0.06317605464054005, 0.04900943088744368, 0.008501921647361346, 0.10823755165828125, 14.46490921292986, 60.29739843096052, 28.026997293744767, 28.223587887627737, 42.41496562957764, 53.240015847342356, 55.78016608101981, 55.92206219264439, 46.475923674447195, 55.38276386260986, 14.686949321201869, 0.6235640197992325, 0.12013732562107698, 0.11218469164201192, 0.13922246651990072, 34.609553882053916, 67.02262238093785, 54.45493616376604, 58.189964635031565, 44.90748943601336, 43.4500526700701, 41.94098384039742, 42.234225613730295, 39.62053564616612, 40.14370025907244, 38.43911606924874, 40.85596357073103, 40.16631664548601, 39.470603942871094, 37.79757152284895, 41.21830170495169, 39.977812017713276, 40.28171232768467, 39.53478792735508, 39.45560278211321, 37.69094794137137, 38.12722880499703, 39.18345921380179, 37.35661799567086, 40.601398944854736, 42.9223369870867, 45.46444313866751, 45.78804159164429, 44.383869716099326, 44.74976185389927, 40.97362436567034, 39.473511763981406, 37.777682304382324, 36.213132108960835, 35.284901414598735, 39.907183579036165, 38.36386013031006, 41.271257400512695, 42.681435993739534, 39.02308784212385, 43.812418597085134, 44.87487459182739, 46.6739855493818, 44.19177286965506, 41.93826362064907, 41.36089958463396, 38.2235621043614, 36.34086084365845, 35.3099079813276, 35.52086918694632, 36.64713396344866, 34.73017808369228, 34.713280064719065, 37.82144900730678, 36.73691511154175, 36.4448892729623, 36.58528109959194, 37.37619454520089, 36.700648988996235, 37.218098708561485, 36.07345594678606, 34.150507245744976, 34.03065082005092, 33.552979537418906, 34.290815693991526, 35.8180262701852, 36.09022889818464, 35.399876730782644, 34.803617068699424, 35.901258741106304, 38.929818698338096, 40.547956875392366, 46.14294515337263, 47.257887840270996, 45.63403476987566, 42.572095666612896, 39.68791580200195, 39.11932734080723, 39.78409276689802, 36.40992941175188, 35.51560245241438, 36.29529455729893, 34.652549334934776, 34.37063659940447, 35.613829135894775, 34.54494258335659, 33.7378363609314, 36.130108083997456, 36.71505260467529, 35.83168990271432, 37.41485432216099, 36.32716247013637, 36.063853536333355, 37.597713538578574, 36.48765543528965, 34.960879121507915, 34.76346342904227, 34.446900027138845, 36.7020559992109, 35.11090809958321, 36.56634031023298, 35.142897605895996, 36.886808599744526, 37.30597257614136, 38.67113379069737, 36.1107052394322, 37.36854110445295, 38.67398255211966, 39.069084916796, 39.425680364881245, 39.1531720161438, 37.264200006212505, 41.601692880902974, 43.578344208853586, 50.194140979221885, 50.169617312295095, 55.81235361099243, 28.526112454278127, 0.19976999184914998, 0.08767547751111643, 0.13442344617630753, 2.6041639872959683, 52.320480823516846, 49.67597212110247, 52.59183577128819, 53.79242195401873, 38.41648578643799, 37.152438231876914, 23.30701650891985, 48.10143736430577, 8.81675853048052, 0.34388749141778263, 0.037145310547202826, 0.06652557490659611, 0.03570206316986254, 0.026849108215953623, 0.031820021835821014, 0.03032672232283013, 0.0481088758180184, 0.03545194837663855, 0.023590901800032173, 0.03205883902098451, 0.02914001207266535, 0.05162397898467524, 0.11403454095125198, 0.17326114858899797, 0.12150464153715543, 0.06049565811242376, 0.08673261239060334, 0.09952415100165776, 0.18227275860096726, 0.08866403517978531, 0.18171546421945095, 0.1162820253521204, 0.21813470497727394, 0.10939482027398688, 0.241099478410823, 0.1809264501290662, 0.22833181066172464, 0.1594025729490178, 0.29927340682063786, 19.609928676060267, 66.84624235970634, 45.14496496745518, 40.54250601359776, 37.97694621767317, 60.732522419520784, 58.2176844733102, 63.150349617004395, 50.23823077338082, 61.46352154867989, 16.365363121032715, 0.9392292584691728, 0.38409212976694107, 0.33324963652661865, 0.3207561783492565, 36.90659359523228, 69.40578501565116, 57.780986717769075, 60.97181837899344, 49.525911876133506, 44.28109196254185, 43.79256411961147, 43.90635129383632, 42.15788228171212, 41.68966054916382, 40.87766279493059, 44.009948934827534, 43.22352055140904, 41.76033067703247, 40.92827694756644, 41.90989065170288, 41.77832303728376, 42.23835631779262, 42.33652741568429, 40.9338424546378, 40.263681752341135, 40.12253257206508, 42.25464289528983, 39.26081698281424, 43.50072935649327, 43.431528772626606, 48.857665402548655, 46.48285102844238, 44.9909998348781, 48.10075296674456, 43.24172830581665, 40.87188189370291, 39.7986283983503, 37.63752324240548, 37.00453192847115, 41.9619083404541, 40.24765225819179, 42.16060250146048, 44.07923289707729, 40.74217987060547, 44.80488886151995, 47.335047585623606, 49.64946474347796, 45.022044386182515, 43.719524656023296, 43.635486194065635, 40.17084339686802, 37.60910163606916, 37.276943002428325, 38.024065426417756, 40.62259789875576, 37.194982051849365, 35.760721002306255, 40.65511894226074, 40.53637075424194, 37.96974788393293, 38.40354129246303, 39.82430894034249, 38.87967702320644, 40.01553726196289, 37.68143585750035, 37.87339721407209, 37.39230741773333, 36.18776076180594, 36.963683468954905, 36.87379114968436, 38.85110255650112, 38.33466379983084, 35.3713196345738, 38.94681051799229, 39.281154360089985, 43.263298988342285, 46.676969800676616, 49.600181170872276, 47.81728383472988, 43.64440768105643, 41.158140727451865, 40.92172827039446, 41.91255528586251, 38.63318272999355, 36.96186998912266, 38.06369795118059, 37.07614353724888, 36.361542156764436, 37.70523691177368, 36.642482144492014, 35.619377272469656, 38.373195035117014, 39.09872593198504, 37.9332663672311, 39.341846874782014, 38.48537370136806, 39.317896434238975, 39.17303344181606, 38.10960122517177, 37.02714136668614, 37.13929918834141, 36.897258690425325, 37.7863883972168, 37.11421619142805, 37.44194882256644, 36.73285041536604, 39.515590054648264, 39.30861364092146, 39.99350105013166, 39.420173917497905, 39.65250083378383, 40.50733423233032, 41.013889176504954, 42.469707012176514, 41.00571114676339, 39.70420585359846, 43.757993357522146, 47.426722117832725, 51.31570182527815, 54.015750953129356, 55.330405712127686, 32.99831526620047, 0.26512835760201725, 0.3451710896832602, 0.4013658942920821, 3.281707150595529, 59.14754799434117, 54.505067416599815, 57.62351969310215, 58.225532463618684, 41.921358653477256, 38.42910024097988, 34.00478615079607, 56.288777691977366, 14.738725560052053, 0.36052826419472694, 0.12991071332778248, 0.23090503258364542, 0.20171205406742437, 0.15457620764417307, 0.0992808419146708, 0.1826793910669429, 0.16225617911134446, 0.15637743313397678, 0.12191442240561758, 0.16230519648109162, 0.18029510043561459, 0.10854404592620474], [0.02150863389085446, 0.009674662557829703, 0.07144238892942667, 0.05701988283544779, 0.04129933925079448, 0.018500094435044696, 0.03532753558829427, 0.010611761827021837, 0.0596663322565811, 0.0543172914268715, 0.07219197334987776, 0.08409408147313766, 0.016024842791791474, 0.041624632331409624, 0.011361594760923513, 0.045651683384286504, 0.09986777470580169, 0.608597165771893, 36.511644090924946, 46.512009143829346, 31.846387318202428, 16.741286720548356, 42.66588592529297, 51.23926816667829, 49.51590299606323, 43.970073223114014, 48.405066694532124, 14.821393489837646, 0.048127840871789625, 0.07424694379525525, 0.2838449589908123, 0.1304211345102106, 20.577303784234182, 68.56594235556466, 49.88437638963972, 54.700728688921245, 45.06804493495396, 45.767707688467844, 40.75151130131313, 39.64234951564244, 39.495207514081685, 40.99582733426775, 37.9966721534729, 38.372371673583984, 38.58183554240635, 38.666363852364675, 37.91010454722813, 38.525447436741416, 36.677084173474995, 36.85675416673933, 35.54758153642927, 36.2256875038147, 37.08421734401158, 38.82224668775286, 35.855827944619314, 38.63362741470337, 37.41598687853132, 41.108593123299734, 40.926776136670796, 41.02967548370361, 43.414213861737935, 42.39233534676688, 37.40742669786726, 38.12762137821743, 34.804485593523296, 36.58255393164498, 34.6788204738072, 36.22969314030239, 36.38780287333897, 43.99095950807844, 39.78695889881679, 36.194806235177175, 39.34529318128313, 42.67954955782209, 41.9744359425136, 40.46572494506836, 37.48369359970093, 35.629101276397705, 34.44415201459612, 35.35746840068272, 35.52606643949236, 35.28446020398821, 34.421928201402935, 34.86015803473336, 33.64055463245937, 33.356289931706016, 34.6801996912275, 33.744798455919536, 33.981971740722656, 34.41106469290597, 34.24607276916504, 34.106483459472656, 33.62462936128889, 33.23737151282174, 33.262708118983674, 32.64529466629028, 31.9625438281468, 31.965764318193706, 32.919342041015625, 33.43007632664272, 34.050383704049246, 32.256188596997944, 31.861874852861675, 34.238144874572754, 38.81280755996704, 40.24111747741699, 43.13111298424857, 40.14312355858939, 37.14388847351074, 36.10518836975098, 38.2914251599993, 37.033870697021484, 33.70027787344796, 34.04003783634731, 33.905798639569966, 33.589999539511545, 34.675610406058176, 33.39928191048758, 32.638641766139436, 33.48426185335432, 33.91108969279698, 34.12824869155884, 32.56448711667742, 34.16827726364136, 32.358222893306184, 32.42636735098702, 33.17654698235648, 34.148276873997276, 33.697679247174946, 33.130049637385774, 34.253417015075684, 33.39019019263131, 32.35755239214216, 33.25928613117763, 35.10834421430315, 33.974210602896555, 35.70905072348458, 35.33867699759347, 37.20970181056431, 34.72213901792254, 35.39924791881016, 34.11033623559134, 36.56165027618408, 38.14105919429234, 42.65346254621233, 42.05858557564871, 50.37155628204346, 46.68312243052891, 56.34822300502232, 19.78615062577384, 0.6050384938716888, 0.2865350517843451, 0.26537661999464035, 7.1057659302439005, 54.83675357273647, 43.43700395311628, 51.54257093157087, 41.525373867579866, 29.806111335754395, 24.073222160339355, 30.67100919995989, 28.45183273724147, 0.6386390594499451, 0.12023242908929076, 0.06179761075015579, 0.006934905665860112, 0.07121825524206672, 0.01913107093423605, 0.037139807628201585, 0.05507880110027535, 0.023474136101348058, 0.12572825061423437, 0.013699345523491502, 0.021549527500090853, 0.04722202715596982, 0.011424980957859328, 0.024944346763991883, 0.03590484336018562, 0.023678590576829653, 0.02073875957700823, 0.051928624244672913, 0.043642646366996427, 0.043097127960728746, 0.017242100688495805, 0.04507701850629278, 0.13904407966349805, 0.07834159050668989, 0.035554695541837385, 0.008367672645752984, 0.03309894160234502, 0.08555604623896734, 0.08475640629019056, 0.04813974237601672, 1.3687501762594496, 45.03222697121756, 48.44136755807059, 24.379375423703873, 32.1037277494158, 52.37637908118111, 54.18851096289498, 56.59666279384068, 47.4196766444615, 56.77852494376046, 16.250333956309728, 0.14542922989598342, 0.14761545615536825, 0.3646871953138283, 0.09793490663702999, 22.267117840903147, 69.51731055123466, 51.8010230745588, 57.45698874337332, 46.47014972141811, 47.236431803022114, 43.579403809138704, 43.06747790745327, 41.854301588875906, 41.57846852711269, 40.602427278246196, 40.14529487064907, 39.09571736199515, 38.76964882441929, 39.298715932028635, 38.29813364573887, 38.54117121015276, 38.7707952771868, 35.99871417454311, 38.04191882269723, 38.37132944379534, 39.94309534345354, 38.079605851854595, 40.27014010293143, 40.012153489249094, 43.045858587537495, 43.575735160282676, 43.96468142100743, 44.945972033909385, 44.515016964503694, 39.27225719179426, 39.514398438589915, 38.35132558005196, 39.37744944436209, 36.898262705121724, 39.613775048937114, 38.32727091653006, 43.6656448500497, 42.43455260140555, 37.035260336739675, 41.63186543328421, 45.059988498687744, 46.61575617109026, 42.51376553944179, 40.13188484736851, 35.98294176374163, 36.830646310533794, 36.56526681355068, 37.27923938206264, 37.599516596112935, 36.473474161965505, 36.901410239083425, 36.92119870867048, 35.67435489382063, 36.25732265199934, 35.18555954524449, 36.34057944161551, 35.79169259752546, 37.05861323220389, 35.08204528263637, 36.1404470035008, 35.691648960113525, 35.199219703674316, 34.10617773873465, 34.42459978376116, 34.407986640930176, 34.78189352580479, 34.94338008335659, 35.90501076834542, 34.421184744153706, 34.574138913835796, 36.32758978434971, 40.43625068664551, 42.49909789221627, 43.681243555886404, 41.67369358880179, 38.870477608272004, 37.432092802865164, 40.59419366291591, 39.50255523409162, 35.92953096117292, 36.38745893750872, 34.69957821709769, 34.19819968087332, 37.21174805504935, 35.41394683292934, 34.201350688934326, 36.23187834875924, 35.914380414145334, 36.748650618961875, 35.73838254383632, 37.232550961630686, 35.87192692075457, 35.61558355603899, 36.645209312438965, 34.76947362082345, 36.224217959812705, 35.950834138052805, 36.250457831791465, 35.29994773864746, 33.90349531173706, 35.53312233516148, 36.611336844308035, 36.34809044429234, 37.11899307795933, 36.4245970589774, 39.093195165906636, 34.85754203796387, 37.157843930380686, 37.549291542598176, 39.320880685533794, 40.28418936048235, 44.48594570159912, 44.760705266680034, 53.537461280822754, 49.746214934757774, 57.004925046648296, 20.9936363697052, 0.783272001360144, 0.207749658663358, 0.23210118125591958, 7.232572291578565, 59.8558543069022, 45.73488092422485, 56.73808642796108, 43.46744401114327, 38.907403809683665, 22.685185738972255, 28.563820328031266, 39.89779656273978, 0.9998484913791928, 0.11196384206414223, 0.011833789824907268, 0.006916090313877378, 0.05347978583137904, 0.032514787412115505, 0.023742493308548416, 0.0494343363014715, 0.01869726992611374, 0.0239296824604805, 0.03991448998983417, 0.014404767492253865, 0.024737473311168805, 0.07030750518398625, 0.12970138527452946, 0.14414772151836328, 0.15771540919584887, 0.19360094144940376, 0.2201000680880887, 0.09359346316861254, 0.14389806134360178, 0.1430954358407429, 0.18441155526254857, 0.24992298494492257, 0.17772164781178745, 0.12437388114631176, 0.08254616667649575, 0.12609900214842387, 0.23949211037584714, 0.15658448130956718, 0.13479951742504323, 2.024337466273989, 55.04853119168963, 57.97631447655814, 41.41293464388166, 26.84342724936349, 54.72643007550921, 60.50455897194998, 60.51771191188267, 52.32315935407366, 62.94869204929897, 20.178586619240896, 0.5082113838621548, 0.5972641110420227, 1.2173036571059908, 0.20941451218511375, 24.658934456961497, 72.92086478642055, 53.4429657799857, 58.784490721566335, 48.837102208818706, 49.98734521865845, 46.17801965985979, 44.79437971115112, 44.34729092461722, 43.6919298853193, 42.94126388004848, 41.77735723767962, 42.48311703545706, 42.11756535938808, 41.99755607332502, 40.557027748652864, 40.68253653390067, 41.42210626602173, 38.219097886766704, 39.87829644339425, 40.90285348892212, 42.538789476667134, 40.27549716404506, 43.63580928530012, 40.636991092136924, 43.93312965120588, 45.129772731236045, 45.16826227733067, 46.874104091099326, 46.32100316456386, 39.87623282841274, 41.86806944438389, 39.11752428327288, 41.534489904131206, 38.16859837940761, 40.53335871015276, 40.16274874550955, 47.078193528311594, 43.09442302158901, 39.53844962801252, 43.169922147478374, 48.08417803900582, 48.86741719927107, 43.893531867435996, 42.19067777906145, 38.79208108357021, 40.06547049113682, 39.11636046000889, 39.29916756493704, 41.406222684042795, 37.7493371282305, 39.878671646118164, 40.62042311259678, 38.18473209653582, 37.92126335416521, 38.09348487854004, 39.78307485580444, 38.28411912918091, 38.748651368277415, 37.61447606767927, 37.433843748910085, 37.65311847414289, 36.78653219767979, 36.59973335266113, 34.39563274383545, 36.77754817690168, 37.81226001467024, 37.77814783368792, 38.9272061756679, 37.31736762183053, 35.83748122623989, 38.64056519099644, 43.16995341437203, 43.03953572681972, 45.95302309308733, 44.90910489218575, 41.59131227220808, 40.01408508845738, 41.65011487688337, 43.01802062988281, 37.29794045857021, 38.9129067829677, 38.551464966365266, 37.72096415928432, 38.68367181505476, 37.460528305598665, 37.344524656023296, 39.13722937447684, 38.522060189928325, 38.56897095271519, 36.634234632764546, 40.154945918491904, 36.99894905090332, 37.522742475782124, 38.960561003003804, 37.10384253093174, 38.523345606667654, 38.166757106781006, 37.98848022733416, 37.817068168095176, 36.58504138674055, 37.0274783543178, 38.30924728938511, 37.9922114099775, 40.34561491012573, 39.386471680232454, 40.80188226699829, 38.08741215297154, 39.620678084237234, 40.38848182133266, 41.63575989859444, 43.10266358511788, 47.22028766359602, 46.21806560243879, 54.9612409727914, 53.64111450740269, 59.26468767438616, 25.2794155393328, 0.9414697268179485, 0.5294236913323402, 0.36413608917168205, 9.055066108703613, 65.55466951642717, 52.49377931867327, 60.33447401864188, 51.39242730821882, 40.861747946058, 36.40187297548567, 40.24460547310965, 48.40620967320034, 1.5496400126389094, 0.20850908862692968, 0.1413200218230486, 0.11354271841368505, 0.12099811514573437, 0.07941213556166206, 0.07727502845227718, 0.2089189509195941, 0.10310102121106215, 0.16294713132083416, 0.14692225120961666, 0.05515432544052601, 0.2016122279954808, 0.20064182792391094], [0.027227681562570587, 0.10917658984128918, 0.07352840235190732, 0.04721488557489855, 0.06315912519182477, 0.01521355239674449, 0.027606963978282044, 0.03252203416611467, 0.020802809890093546, 0.08863016949700457, 0.03532486894567098, 0.03553475000496421, 0.012540759701680924, 0.008308756298252513, 0.09599762809063707, 0.059186682637248716, 0.04206222974296127, 0.13745177510593617, 13.405122194971357, 49.371620178222656, 31.10844693865095, 19.616010086877004, 24.298972606658936, 47.18999351773943, 54.51095601490566, 43.82905605861119, 45.28067718233381, 20.922644887651714, 0.09380372081484113, 0.4885842427611351, 0.40442139176385744, 0.417301099215235, 9.440233417919703, 69.3834535053798, 51.27222694669451, 56.85807834352766, 48.62399400983538, 49.07023859024048, 44.07747152873448, 46.80355903080532, 41.67049046925136, 44.35124792371477, 39.510094029562815, 38.35261099679129, 35.86291510718209, 37.18232590811593, 37.26020131792341, 37.888988971710205, 39.10543441772461, 37.57105330058506, 36.00460624694824, 36.872286864689414, 36.67841822760445, 37.2949492590768, 36.88990749631609, 38.25796610968453, 37.57273823874337, 40.77110522133963, 39.948379448481965, 41.378085953848704, 41.78370441709246, 39.84165859222412, 37.25863102504185, 36.99217108317784, 37.06300796781267, 37.37593746185303, 37.483672755105154, 37.446586745125906, 35.93837949207851, 41.97047894341605, 40.09902681623186, 36.7901417868478, 38.79508965356009, 42.66600751876831, 38.15879794529506, 37.94357054574149, 35.01435940606253, 36.5702417237418, 34.352057116372244, 34.925002098083496, 34.65135077067784, 35.403917108263286, 34.13046169281006, 35.09683799743652, 33.06724834442139, 32.71940762656075, 32.97404868262154, 34.982161453792024, 35.504520075661794, 33.979922022138325, 35.22010946273804, 34.17434304101126, 34.04159075873238, 34.17464528764997, 35.065744808741975, 33.271362100328716, 32.8747832434518, 32.83632149015154, 33.10132925851004, 31.86698525292533, 31.726874828338623, 32.04376826967512, 33.725006512233186, 34.19369724818638, 33.82291010447911, 35.87474094118391, 39.08731004170009, 37.95788383483887, 37.313111850193565, 34.025359766823904, 39.08946745736258, 38.91735363006592, 33.6834910256522, 35.05239731924874, 32.728415966033936, 31.24001455307007, 34.16377483095442, 33.19411202839443, 33.71452862875802, 34.06677450452532, 34.23321860177176, 32.804811409541536, 33.40634822845459, 33.050541400909424, 32.8947627885001, 33.101735728127615, 33.17086335590908, 31.871786458151682, 32.42762150083269, 32.6382874080113, 32.57921382359096, 31.802380902426584, 32.64342212677002, 32.68416288920811, 33.8746394429888, 34.05688374383109, 34.860470703669954, 33.873906408037456, 35.78090899331229, 33.792105266026084, 35.83973591668265, 34.31749677658081, 40.75117778778076, 44.07711717060634, 46.45366512026106, 44.40505477360317, 50.69690915516445, 47.293396609170095, 57.67586047308785, 9.707173654011317, 0.6395495991621698, 0.33944710397294586, 0.2830064796975681, 7.11588511296681, 51.453227519989014, 41.95458146503994, 52.54056848798479, 39.05088758468628, 25.669575997761317, 22.7245420728411, 41.475002901894705, 15.148181165967669, 0.1945420830909695, 0.03043398853125317, 0.027931263005094867, 0.031922731681593826, 0.03297451524330037, 0.008577313673283373, 0.04801362646477563, 0.05482430975618107, 0.08876310129250799, 0.01692007984300809, 0.05326676994029965, 0.07269014697521925, 0.031298811946596415, 0.053339607281876464, 0.03588921330603106, 0.04727532947435975, 0.014743403964010733, 0.07324417081794568, 0.05924648871379239, 0.060410515538283756, 0.08288193294512373, 0.012549707034070576, 0.017112341044204574, 0.029978718675140823, 0.045660904675189934, 0.037231084158910174, 0.08331512327172927, 0.02003998216241598, 0.16251156612166337, 0.05366209801286459, 0.04847396158480218, 0.07966740722102778, 19.456771271569387, 57.907145159585134, 27.510898998805455, 18.55471444129944, 37.7654048374721, 51.403707708631245, 59.3826333454677, 48.78749207087925, 52.077102797372, 22.978451831000193, 0.09853530156293086, 0.504158792751176, 0.2627500652202538, 0.5165971538850239, 10.558876020567757, 70.5222076688494, 53.365135533469065, 58.96544960566929, 49.836635317121235, 51.64046062741961, 47.73685496194022, 47.78882053920201, 44.45029102052961, 44.982460498809814, 41.14180203846523, 39.99327870777675, 39.1012133870806, 40.45634140287127, 39.27347660064697, 40.41017757143293, 39.61972618103027, 38.83649049486433, 36.54283455439976, 38.324891158512656, 39.126525674547466, 39.63404641832624, 37.74286140714373, 40.69691583088466, 40.18208558218819, 42.234600816454204, 41.091177463531494, 43.22467395237514, 43.39820868628365, 40.98275777271816, 39.24867500577654, 40.5477796963283, 38.285060610089985, 39.486056736537385, 38.88358538491385, 40.301264558519634, 37.736041750226704, 43.56591040747506, 42.30644866398403, 38.78631755283901, 41.263350350516184, 43.80503613608224, 40.341122899736675, 39.36976473672049, 36.70696837561471, 37.88710600989205, 36.68769754682268, 37.59793240683419, 35.145871434892925, 36.55205481392996, 36.417099952697754, 37.553088733128135, 35.81400326320103, 36.284552642277305, 36.26760251181466, 38.00902605056763, 36.82174219403948, 36.024801186152864, 37.098502840314595, 35.18249886376517, 35.575961453574045, 35.67501149858747, 37.00499398367745, 35.67457723617554, 34.67216409955706, 34.45742654800415, 35.85631431852068, 33.824640205928254, 35.138436862400596, 34.24077476773943, 35.80478300367083, 36.04078551701137, 35.33720050539289, 38.37744385855538, 41.85843229293823, 39.87483276639666, 38.62931605747768, 36.13848761149815, 39.18765592575073, 40.05152893066406, 34.822151388440815, 36.36831317629133, 35.31068965366909, 33.40435756955828, 36.52963645117623, 36.02521112986973, 36.40806034633091, 34.95284352983747, 34.77188464573452, 35.32585062299456, 35.507556438446045, 34.82233551570347, 34.46424273082188, 35.884197439466206, 35.08856616701399, 35.316904817308696, 35.59750781740461, 34.61228452410017, 35.04369122641427, 34.61267362322126, 35.61921051570347, 34.79573086329869, 36.34836489813668, 36.36708681924002, 36.87175185339791, 37.17156662259783, 38.55819429670061, 37.538143157958984, 36.872735023498535, 37.37060819353376, 43.83960689817156, 46.87024436678205, 49.685967104775564, 47.75156429835728, 52.89477028165545, 50.154070717947825, 57.09391410010201, 11.044852137565613, 0.809001506439277, 0.24003444984555244, 0.3159031330474785, 8.211442760058812, 56.980946813310894, 47.568566117967876, 58.434906005859375, 44.063363211495535, 36.64555672236851, 20.52165045057024, 45.83536229814802, 20.469488586698258, 0.19448697247675487, 0.09263138872172151, 0.05981104342000825, 0.044849502321864874, 0.06764694223446505, 0.041641042700835636, 0.03259226593321987, 0.032882614460374625, 0.11613118701747485, 0.056850662987147055, 0.019978120124765804, 0.04994465909632189, 0.013956262630277445, 0.04519627442849534, 0.11470833979547024, 0.23090766529951776, 0.11716996984822409, 0.25693605148366516, 0.17777840048074722, 0.09649084841034242, 0.1896880335573639, 0.08703192097267934, 0.10875405251447644, 0.14910695755055972, 0.12347510723131043, 0.11816964192049843, 0.16426846970404896, 0.13300207816064358, 0.25354163934077534, 0.2111951916345528, 0.4132329560816288, 0.29715564474463463, 26.37517077582223, 64.20432186126709, 40.111821923937114, 26.955720560891287, 34.63088485172817, 56.64070395060948, 63.082271167210166, 56.06503527505057, 57.25859335490635, 28.126307896205358, 0.21957387775182724, 0.7079192219035966, 1.6927497791392463, 0.6067118155104774, 11.757253544671194, 72.89581653050014, 55.25874546595982, 62.57553904397147, 53.12255655016218, 54.81400864464896, 50.459930419921875, 51.1538713318961, 45.641788959503174, 48.481548990522114, 44.77919789722988, 42.72376094545637, 41.260237557547434, 41.21179819107056, 42.013217312949045, 41.697793415614534, 42.6607095173427, 41.55774205071585, 38.902189186641145, 41.29610415867397, 40.031771727970664, 42.165681634630474, 40.20417390550886, 43.360473019736155, 40.37079170772007, 44.613049098423545, 44.189573764801025, 44.47411986759731, 45.457661696842735, 44.54953214100429, 40.432001863207134, 42.18534851074219, 40.16787651606968, 41.41085713250296, 42.18657486779349, 41.225097043173655, 40.13499764033726, 45.49871512821743, 43.91547775268555, 41.695517880576, 42.10181031908308, 45.94544608252389, 41.8006580216544, 42.70449011666434, 38.06100899832589, 41.22657700947353, 38.32349109649658, 40.19772597721645, 38.000302587236675, 39.279841150556294, 39.12074129922049, 40.025831018175396, 38.48675986698696, 38.20208522251674, 37.737507820129395, 39.73581320898873, 40.12402296066284, 36.996569292885916, 40.49830852236067, 37.781670570373535, 37.23873833247593, 37.73498214994158, 39.22330713272095, 37.935500213078086, 37.01662179401943, 36.641641412462505, 38.425136293683735, 36.15126187460763, 36.36650317055838, 35.444418157849995, 37.89176825114659, 38.070336954934255, 37.822967188698904, 40.30409942354475, 43.50163957050869, 41.9965694291251, 42.4574955531529, 37.25872482572283, 40.57447814941406, 42.87713548115322, 37.18156508037022, 39.32674496514456, 36.57254505157471, 34.920127936771934, 39.31428337097168, 37.53079891204834, 39.038808141435894, 37.0971097264971, 37.160362652369905, 37.79127645492554, 37.76476212910244, 37.35810143607003, 37.24520363126482, 38.973672253744944, 39.26762621743338, 38.233814171382356, 37.286222321646555, 38.44978155408587, 37.25418070384434, 35.63930818012783, 37.43169328144619, 35.71614136014666, 38.811567306518555, 39.3076547895159, 40.21629156385149, 38.45134489876883, 39.9696478843689, 38.49704320090157, 38.964069843292236, 39.71484007154192, 46.200799328940256, 49.42697300229754, 50.89428315843855, 49.53449290139334, 55.854907853262766, 51.85139751434326, 59.40219252450125, 13.77415578705924, 0.8276366293430328, 0.4901294027056013, 0.4581121578812599, 10.55380470412118, 64.2269868850708, 50.32111930847168, 63.85246508462088, 48.59171267918178, 37.957710129874094, 32.44823680605207, 54.96657371520996, 27.573010683059692, 0.3170202731021813, 0.18212143172110828, 0.2584090695849487, 0.10746700050575392, 0.09217850730887481, 0.1081270861572453, 0.11042697381760393, 0.18119263941688196, 0.22326955944299698, 0.1098842950803893, 0.09953812203769173, 0.23668726373996052, 0.08168162485318524, 0.14343634540481226], [0.02344263341676976, 0.04962007847747632, 0.02522242907434702, 0.03274913305150611, 0.07694536221346684, 0.04001102177426219, 0.01789200831470745, 0.05221487442031503, 0.012729031965136528, 0.05193963008267539, 0.04443946361009564, 0.006890957376786641, 0.08553471309798104, 0.10639729683420487, 0.09048374396349702, 0.01795197045430541, 0.10113651983972106, 0.02026772904875023, 1.3120261686188834, 39.842356886182515, 39.846119335719514, 31.611131736210414, 24.785742555345806, 30.708796977996826, 47.11118704932076, 47.42091689790998, 48.52092095783779, 24.07254297392709, 0.5968654038650649, 0.34347505069204737, 0.4013998210430145, 0.1843715895499502, 3.3274686379092078, 62.312730380467, 54.23313924244472, 54.59962545122419, 53.55600602286202, 49.55724825177874, 49.44908911841256, 50.93763296944754, 50.027905327933176, 49.76474230630057, 49.110228947230745, 44.42790739876883, 39.71084485735212, 35.773620332990376, 37.01697267804827, 37.67937224251883, 36.849597522190635, 39.26758452824184, 37.172306605747764, 36.70505067280361, 36.42591374261038, 35.735467774527415, 36.77555404390608, 38.32141705921718, 37.66703224182129, 40.705517700740266, 39.29817744663784, 39.45228501728603, 37.16246100834438, 36.149761063711985, 36.218774046216694, 38.46528993334089, 36.13901914869036, 36.89929451261248, 36.01769665309361, 36.921938691820415, 37.7810035433088, 41.78631346566336, 40.64337996074131, 39.96245302472796, 39.52960457120623, 38.01620353971209, 35.70925569534302, 36.80514989580427, 35.41846316201346, 35.18177277701241, 33.56372492653983, 36.5919965335301, 34.345275674547466, 34.7583669253758, 35.35003730228969, 34.53306463786534, 33.88165364946638, 34.21385744639805, 35.02198505401611, 35.830737999507356, 35.77317564828055, 34.58388376235962, 36.24359995978219, 35.15820101329258, 34.3487879889352, 33.51303086962019, 35.04060970033918, 33.207167693546836, 32.961361271994456, 32.05543776920864, 33.26857239859444, 33.6073248726981, 33.2922796521868, 32.50945390973772, 32.881252016339985, 34.23913846697126, 33.08619260787964, 37.385453019823345, 36.04045895167759, 37.0570707321167, 35.75063221795218, 34.565957409994944, 36.56107357570103, 37.808261326381135, 34.14116539273943, 33.58716467448643, 35.26192372185843, 34.22263649531773, 32.426937103271484, 33.91577625274658, 34.04783024106707, 33.995982783181326, 35.153340748378206, 32.40710694449288, 32.429285594395225, 33.36765023640224, 31.564971378871373, 32.8613280568804, 31.9422516141619, 32.59639324460711, 31.73839841570173, 32.739244733537944, 34.063331672123496, 33.438379423958914, 33.824424811771934, 33.6534435408456, 33.188532624925884, 34.52712740216936, 34.90201398304531, 35.51829487936837, 34.24782024111067, 35.2709424836295, 36.41497032982962, 36.34490122113909, 46.71191923958914, 46.84203815460205, 49.66129405157906, 47.569326945713584, 52.17576374326433, 48.39706931795393, 48.74912759235927, 3.3305768711226325, 0.4588318392634392, 0.44604677387646263, 0.5341988950967789, 13.599531054496765, 55.1907434463501, 42.45392765317644, 49.81364025388445, 29.551015172685894, 20.67135807446071, 24.044838769095286, 33.68506826673235, 0.7272697921310152, 0.08232066913374833, 0.05963993724435568, 0.030409571448607103, 0.023965897570763315, 0.015140248562342353, 0.02017023035192064, 0.05561513892774071, 0.05505151042182531, 0.03779044467955828, 0.07595737451421362, 0.006189275408230189, 0.04325626477865236, 0.03467970767191478, 0.04151470965838858, 0.014233830950355955, 0.04671180953404733, 0.027962592663243413, 0.03676605357655457, 0.0459704252092966, 0.020390703342854977, 0.018732908281630704, 0.04601146300722446, 0.060202374921313355, 0.023700758315888897, 0.018618785476844226, 0.07789922638663224, 0.06308534129389695, 0.05161771271377802, 0.05299167148768902, 0.008110878523439169, 0.09202973850603614, 0.0846066807529756, 3.250844772372927, 50.196440832955496, 40.73032971790859, 22.20945474079677, 31.54643358503069, 38.9195944241115, 51.87131452560425, 53.541956765311106, 52.79061678477696, 29.11545171056475, 0.4194871761969158, 0.7436962021248681, 0.4179248357457774, 0.296947497342314, 3.9134794899395535, 63.08531447819301, 55.98318549564907, 57.990665980747764, 52.21901280539376, 51.47543396268572, 49.36712121963501, 52.25906917027065, 51.83610452924456, 53.6457211630685, 50.427704674857004, 47.58093043736049, 40.27986758095877, 38.00226892743792, 39.15794195447649, 40.21037517275129, 38.783388887132915, 41.45152841295515, 39.41089807237898, 40.433162212371826, 38.04153667177473, 38.241009031023296, 37.84353733062744, 39.81787143434797, 40.53733655384609, 41.98176976612636, 41.169504506247385, 42.628744329724995, 39.042521953582764, 40.24132592337472, 38.33949974605015, 41.49463503701346, 37.61670296532767, 40.170426504952566, 36.701614788600374, 38.3734312738691, 38.04129695892334, 43.66734021050589, 43.831748485565186, 40.25129311425345, 42.91414853504726, 40.23942559106009, 38.25457191467285, 39.01669202532087, 39.126543045043945, 37.797602789742605, 37.74399743761335, 37.749632426670615, 36.024408612932476, 36.5627098764692, 37.65574141911098, 36.26902689252581, 35.399911471775596, 35.76614754540579, 37.34045648574829, 37.20662028448922, 36.27813250677926, 36.936609813145225, 37.848213468279155, 37.71289382662092, 35.55936915533883, 34.80006653921944, 36.654255867004395, 34.21523666381836, 34.86951725823538, 34.864177567618235, 35.157429763248985, 34.0595622743879, 33.961099352155415, 34.38110753468105, 34.53974533081055, 36.26000118255615, 34.23093959263393, 38.34043427876064, 37.58075645991734, 38.599570819309776, 37.58228506360735, 37.7191333089556, 38.91653374263218, 40.50197369711739, 36.14454296657017, 35.73222991398403, 36.16324404307774, 35.80859409059797, 34.35621561322893, 35.82765299933297, 36.41543933323452, 37.36548042297363, 37.394430092402864, 33.29655279432024, 34.868447235652376, 35.28203528267996, 33.12915331976754, 35.306235858372276, 33.94671310697283, 34.322242396218435, 34.31985221590315, 35.736635071890696, 35.40296867915562, 36.53273187364851, 36.09204237801688, 35.45718199866158, 37.34140838895525, 36.18180962971279, 36.920688016074045, 37.52651187351772, 35.2918461390904, 37.42019401277815, 38.14337641852242, 39.03276668276106, 48.415200642177034, 50.21410315377371, 53.20081411089216, 49.55650132043021, 53.514910902295796, 51.312595980507986, 49.41141945975167, 4.494779680456434, 0.956289257322039, 0.3881596215069294, 0.5228510211621011, 15.160505533218384, 60.2227817262922, 47.41633456093924, 53.44053738457816, 38.92813376017979, 28.583634853363037, 22.630169902529033, 44.06681646619524, 1.7424883501870292, 0.04737237694540194, 0.04321149503812194, 0.023262377196390713, 0.0389801438764802, 0.01808602692160223, 0.02273179334588349, 0.053476959733026366, 0.028293308934995105, 0.04733494895377329, 0.03044493669377906, 0.0566835160633283, 0.04504857771098614, 0.05225853814876505, 0.02847537345119885, 0.07944545841642789, 0.0999642556001033, 0.1890183330646583, 0.14318709235106195, 0.18436517060867377, 0.11771411422107901, 0.10128612324063267, 0.11501477978059224, 0.17731319687196187, 0.11804532073438168, 0.14613819042486803, 0.11525169706770352, 0.22112654229359968, 0.17362727251436028, 0.2013233620673418, 0.07627091197563068, 0.15271498608802045, 0.22416412644088268, 3.8084044882229398, 60.343485832214355, 47.76488746915545, 41.87270041874477, 36.00923374720982, 41.107109682900564, 57.03399978365217, 58.88073022024972, 58.66809449877058, 36.20424536296299, 1.52387934923172, 1.405459355030741, 1.5077497575964247, 0.43362882307597567, 5.051001216684069, 65.00228078024728, 58.26796858651297, 61.43038558959961, 57.10304403305054, 54.09859085083008, 51.719326155526296, 55.385261740003315, 54.65976905822754, 56.362359115055625, 53.633151871817454, 49.75947209766933, 43.79567343848092, 40.03973436355591, 41.38063941683088, 41.20467281341553, 40.03573220116751, 44.32692575454712, 41.639449392046245, 41.084496770586284, 39.99319532939366, 40.93867492675781, 39.50545263290405, 43.06169353212629, 43.27198771068028, 45.394377504076274, 44.009177684783936, 44.65304640361241, 40.94393471309117, 41.30329207011631, 39.441758496420725, 44.86512279510498, 39.11517231804984, 42.557646887642996, 38.17008876800537, 39.68790190560477, 41.01803725106375, 45.357770919799805, 46.806591919490266, 43.541004589625764, 45.02199922289167, 42.55630241121565, 40.77636153357369, 40.98169469833374, 40.14197015762329, 40.91322020121983, 39.72810418265206, 40.32226548876081, 37.89862959725516, 39.04400886808123, 39.610023021698, 38.85601840700422, 38.36883851460048, 38.18585770470755, 40.139357634953086, 39.815790448869976, 39.073059286390034, 39.52753748212542, 40.88574702399117, 39.19527809960501, 37.42869165965489, 37.43296480178833, 40.050243513924734, 35.72822080339704, 37.60933092662266, 37.082594939640586, 37.51442895616804, 36.620084626334055, 37.117016315460205, 37.084248610905235, 37.02806200299944, 38.21659653527396, 36.95431382315499, 41.35417720249721, 39.29376186643328, 40.63156107493809, 38.83185952050345, 39.33142457689558, 41.38504804883684, 42.806461879185264, 37.873313835689, 36.939132009233745, 38.740918023245676, 38.624629497528076, 34.98170287268502, 37.28654193878174, 38.35386167253767, 38.94797434125628, 38.721723624638145, 35.32803235735212, 35.642889976501465, 37.99521997996739, 35.022551332201274, 37.74962200437273, 35.88384655543736, 35.9262409891401, 37.423338072640554, 38.985428605760845, 38.512277126312256, 38.71516799926758, 38.40657418114798, 36.81517267227173, 38.458355631147114, 37.65269463402884, 39.362694944654194, 39.76659720284598, 36.7748453276498, 39.13812221799578, 40.88197067805699, 39.80549669265747, 49.93413591384888, 51.837765148707796, 55.4866498538426, 51.158919198172434, 56.793949944632395, 52.71210561479841, 52.6646146774292, 5.420746999127524, 0.5593397574765342, 0.9454305257116045, 0.640801197716168, 17.162390981401714, 66.75727762494768, 51.001111711774556, 59.062446457999094, 40.5895870072501, 32.153817313058035, 31.437836715153285, 52.875450815473286, 3.1387659864766255, 0.34102480645690647, 0.18073388189077377, 0.10878723966223852, 0.1305049200143133, 0.11626156073595796, 0.12977351354701178, 0.15487546872879776, 0.18191548277224812, 0.12113800192517893, 0.14096015399055822, 0.1144048310816288, 0.10330950788089208, 0.1571304305855717, 0.10743268698986087], [0.023646003932559063, 0.03727668849751353, 0.05718811880797148, 0.000401365841493576, 0.035634928915117464, 0.01777115274619843, 0.05781841677214418, 0.02133499508324478, 0.022691578271665742, 0.024463674253118888, 0.03342539158516696, 0.009734022497598614, 0.04750767004277025, 0.0051261938143787635, 0.024609678025756563, 0.11247449394847665, 0.02260131445447249, 0.08928350372506039, 0.04040592236976538, 16.32040306500026, 43.452877112797324, 29.412367343902588, 16.555106265204294, 29.57756076540266, 44.8449695450919, 48.94093261446272, 46.37294094903128, 42.457248892102925, 1.523345097899437, 0.4571473353675434, 0.1859344999705042, 0.04122381830321891, 0.2349903562239238, 40.21456841060093, 63.34410013471331, 50.740227699279785, 53.7384101322719, 48.703259059361045, 51.79853909356253, 50.16336393356323, 52.28079966136387, 50.08925444739205, 54.37141186850411, 50.912202562604634, 51.14039530072893, 43.27372476032802, 39.323625223977224, 36.0313846043178, 39.05173179081508, 36.76012904303414, 39.73793935775757, 37.32772738592965, 37.688304151807515, 36.479466983250205, 36.92524256025042, 36.43734005519322, 36.86265318734305, 36.830194677625386, 37.49998017719814, 36.84282997676304, 38.69938516616821, 37.27178743907383, 39.91124480111258, 37.82854659216744, 37.65500143596104, 38.27070910590035, 37.63986131123134, 36.13196325302124, 36.84007501602173, 37.92399747031075, 39.34287173407418, 38.81789016723633, 36.27119473048619, 37.346411091940745, 35.72161306653704, 36.59852089200701, 35.46647868837629, 35.96768004553658, 35.68864039012364, 34.58579799107143, 35.79737274987357, 34.03295414788382, 34.877271447862896, 34.68532746178763, 35.03859124864851, 37.43323578153338, 37.750327246529714, 39.54239273071289, 37.93868248803275, 38.61927591051374, 39.20893478393555, 37.78275796345302, 36.4393515586853, 35.45013305119106, 33.30163540158953, 33.75493240356445, 32.962723118918284, 33.68393571036202, 33.27515581675938, 32.67637395858765, 31.936574935913086, 31.89154018674578, 32.65813146318708, 34.66806466238839, 33.4128725869315, 34.24750757217407, 34.60738604409354, 35.800871167864116, 34.02717324665615, 35.92815521785191, 36.31905392238072, 36.351269245147705, 34.7188629422869, 34.78712551934378, 35.54936374936785, 33.44563681738717, 32.74453578676496, 33.99109819957188, 34.22708681651524, 33.28933014188494, 34.78054557527815, 33.506089619227815, 32.82916137150356, 32.868936334337505, 32.640166895730154, 33.07834461757115, 33.39659990583147, 31.45500918797084, 31.209435531071254, 31.555438450404576, 32.91863332475935, 33.73730482373919, 33.599431719098774, 34.21009152276175, 33.58276299067906, 35.68425955091204, 35.17902476446969, 35.43696274076189, 35.205539090292795, 35.66214343479702, 35.90669918060303, 40.501452582223074, 45.936535017830984, 48.38781084333147, 50.8558144569397, 47.710785320826936, 49.23249639783587, 43.406657695770264, 34.72142335346767, 1.1783009214060647, 0.5207086961184229, 0.40363773810012, 0.24134448383535656, 24.762608528137207, 51.423489230019705, 45.95311689376831, 40.01423447472708, 25.057041917528423, 23.037506307874406, 40.511041096278596, 20.686220271246775, 0.03967104519584349, 0.026312358178464428, 0.03652525167646153, 0.020305138380665864, 0.01698869839310646, 0.06424802461905138, 0.05736425971346242, 0.02993429159479482, 0.03408731945923396, 0.015256257694480675, 0.04574011006791677, 0.043979002961090634, 0.07281982858798333, 0.06001199156578098, 0.1092500276863575, 0.05987040166343961, 0.012172377951044058, 0.012726664726090218, 0.0401761839831514, 0.05263816492099847, 0.05599831783079675, 0.011772319641230362, 0.04391718842089176, 0.05627204564266971, 0.01766140479594469, 0.03800949613962855, 0.09086790334965501, 0.05782659311911889, 0.036486520897597075, 0.024609038506501486, 0.02906485753399985, 0.04995684897793191, 0.03895037315253701, 0.05692170560359955, 23.200617006846837, 51.253230571746826, 28.35487757410322, 20.68831515312195, 38.97794886997768, 47.65928527287075, 54.86134672164917, 50.46366855076381, 48.38755028588431, 1.3279558909790856, 0.6169746305261339, 0.2592369094491005, 0.23097513882177217, 0.36158653455121176, 43.798028877803254, 62.0767000743321, 53.65337460381644, 57.30723074504307, 52.133119174412315, 53.539236545562744, 51.63414124080113, 54.94439159120832, 53.41482210159302, 55.87421689714704, 52.702461515154155, 52.974646772657124, 44.59536245891026, 40.43467344556536, 39.31802150181362, 40.38156488963536, 38.55014828273228, 41.447793756212505, 39.90413679395403, 40.26653746196202, 37.82756689616612, 39.60254328591483, 38.73913928440639, 39.09635312216622, 38.88649320602417, 39.25865609305245, 38.288757051740376, 39.937112944466726, 39.483124596732004, 41.12505340576172, 39.84721367699759, 38.542453152792795, 38.43405430657523, 39.5538329396929, 38.90892546517508, 37.61149876458304, 40.97007383619036, 43.16263001305716, 41.23617247172764, 38.676678453172954, 38.61554472787039, 39.32139137813023, 38.29232842581612, 36.00170189993722, 36.84032167707171, 37.14849165507725, 36.71324954714094, 38.31584112984793, 35.846816131046836, 36.012985774448936, 37.35547501700265, 37.25155775887625, 38.06527171816145, 40.38006060464041, 40.61012240818569, 40.23226547241211, 39.187100069863455, 39.59008516584124, 38.745691435677664, 37.29263898304531, 37.35602739879063, 35.240731716156006, 35.52208512169974, 34.89575713021414, 35.03600304467337, 34.15505831582205, 35.15160717282976, 33.45855699266706, 35.22717578070504, 34.63890307290213, 37.19637516566685, 36.29730258669172, 37.435480049678254, 36.32318115234375, 38.888511657714844, 37.00048112869263, 37.39147015980312, 38.1717563356672, 37.00623076302664, 36.02780975614275, 37.33854920523507, 37.05570193699428, 36.57874979291643, 34.49723277773176, 35.57271317073277, 35.046255111694336, 34.38779864992414, 36.94338778087071, 36.29717404501778, 33.93461629322597, 35.612206731523784, 34.35946042197091, 35.31416375296456, 35.791480677468435, 33.70677791322981, 34.086622033800396, 33.37060669490269, 35.52775137765067, 37.02078723907471, 35.66417578288487, 35.663612978799, 35.50054570606777, 38.46825681413923, 37.09500789642334, 37.933089188167024, 36.73281914847237, 37.18962846483503, 38.384531021118164, 41.90840373720442, 47.89992570877075, 50.47588348388672, 51.45905705860683, 50.595340388161794, 50.947016511644634, 45.33592925752912, 37.7469608443124, 1.1495632805994578, 0.8871257486087936, 1.2504088921206338, 0.3199429948415075, 27.48411021913801, 54.700068610055105, 50.85105146680559, 44.79337569645473, 35.20713022777012, 20.528272083827428, 41.40462459836687, 25.956811053412302, 0.04819697680483971, 0.03881031334666269, 0.04470934412841286, 0.0189114562901003, 0.018009235417204242, 0.038982990330883434, 0.06626080375696931, 0.07785259067480053, 0.09798030741512775, 0.02253892146317022, 0.05012721215773906, 0.09186470521880047, 0.057268464139529636, 0.03133691508056862, 0.03465838810162885, 0.159603283607534, 0.08941608268235411, 0.18013592969094003, 0.16403824277222157, 0.12070975133350917, 0.06557475057031427, 0.09515150849308286, 0.06240981897073133, 0.08644204333956752, 0.08947947142379624, 0.11394850271088736, 0.11914095122899328, 0.1298502151455198, 0.12480291883860316, 0.1598722684596266, 0.20047740531819208, 0.21924478826778276, 0.17843132758779184, 0.18600257060357503, 28.49376858983721, 60.23295388902937, 40.2119802066258, 26.055623122623988, 43.01461253847395, 55.08997024808611, 60.55786555153983, 56.7845664024353, 56.30939299719674, 2.1239752854619707, 2.2393952863556996, 1.149901571018355, 0.30379622269954, 0.7044405628527913, 43.62761041096279, 65.95676176888603, 56.62050553730556, 58.453735624040874, 52.71591670172555, 55.41520152773176, 53.340285301208496, 57.43965993608747, 55.24554736273629, 59.16035352434431, 55.607941082545686, 56.38030283791678, 47.37212664740426, 43.35278136389596, 40.57426970345633, 43.337144442967, 40.08460235595703, 43.005381856645855, 41.28641836983817, 42.006449767521445, 40.80743040357317, 40.13753373282296, 40.92783921105521, 40.84285926818848, 39.83994238717215, 41.77916724341256, 39.60106679371425, 43.510915415627615, 40.29349299839565, 43.61132035936628, 42.1228529385158, 40.68376636505127, 40.6688346862793, 41.70300803865705, 40.42394195284162, 40.45325640269688, 42.59766156332833, 44.96120943341936, 41.65694843019758, 41.43260151999337, 41.3233654158456, 40.69982017789568, 39.9812513760158, 38.67988157272339, 40.63154370444161, 41.01404203687395, 37.52364921569824, 41.49508319582258, 37.08081272670201, 38.875879832676475, 40.4048239844186, 39.10281147275652, 41.806150572640554, 42.565894399370464, 42.60034009388515, 42.359918526240754, 43.313558782849995, 42.506744384765625, 40.214321749550955, 40.383451325552805, 40.736388547079905, 38.136838163648335, 37.83278499330793, 38.18703542436872, 38.26914923531668, 35.65204075404576, 36.79694407326834, 34.884448937007356, 37.44807365962437, 36.29461363383702, 38.711992672511506, 38.78916284016201, 39.62781388419015, 39.255522455487935, 40.36140816552298, 38.52936969484602, 39.809634344918386, 40.75040306363787, 39.121936389378135, 39.52739156995501, 40.08791317258562, 39.94705581665039, 38.08933680398123, 36.58514560971941, 37.21530900682722, 37.74687051773071, 35.70140423093523, 39.5335441998073, 39.42111192430769, 35.74928079332624, 37.30917222159249, 37.32406221117292, 36.86790949957711, 37.79586574009487, 35.16117484228951, 36.49993290219988, 35.92277731214251, 38.05644403185163, 39.35986007962908, 36.86608559744698, 38.21692657470703, 37.23801571982247, 40.322574683598106, 39.42628138405936, 39.61503267288208, 38.78224243436541, 39.44236993789673, 41.20952960423061, 44.575560092926025, 52.29927144731794, 51.97909150804792, 56.20803962435041, 51.945375374385286, 53.111901487622944, 46.09493310110909, 37.12637901306152, 1.6063393758875983, 0.9901744276285172, 0.9437701233795711, 0.3883418488715376, 30.515689168657573, 61.69295801435198, 52.95362499782017, 50.16376345498221, 35.58977447237287, 31.145887306758336, 52.77061292103359, 33.66008601869856, 0.12508681789040565, 0.18957315757870674, 0.14684740879705974, 0.11035279636936528, 0.06911695442561593, 0.09357594339443104, 0.19145925422864302, 0.15259750453489168, 0.19378478372735636, 0.13729848047452314, 0.2568322627672127, 0.15605792456439563, 0.17956422322562762, 0.18695053830742836, 0.13676566763647965], [0.022555180858554583, 0.046853348546262295, 0.03357797375481043, 0.02950137946754694, 0.015655331280348555, 0.019347903584795337, 0.06442064392779555, 0.08139682334980794, 0.01565350771748594, 0.07927943446806499, 0.020781556476971934, 0.042023125769836564, 0.1037234210276178, 0.04576449661648699, 0.06704206219209091, 0.07609602635992424, 0.044369798419731, 0.022172005348173634, 0.08482492475637368, 1.6540787113564355, 38.31574385506766, 37.94024930681501, 26.529056004115514, 31.61345590863909, 33.76893302372524, 58.73882021222796, 43.133704662323, 49.89975275312151, 7.985990217753819, 0.4399849320096629, 0.15220571841512406, 0.061298039342675886, 0.04260121046432427, 18.028501306261333, 64.45506150381905, 50.6166261945452, 59.6500278200422, 52.145136083875386, 56.22609799248831, 50.63101938792637, 54.73224571772984, 52.003163542066304, 53.707893644060405, 51.2918312890189, 55.4200096811567, 47.809074538094656, 46.34565189906529, 37.17041669573103, 38.01686014447893, 37.93702186856951, 37.33220549992153, 38.262284415108816, 38.65991939817156, 37.42410237448556, 38.98723513739449, 37.39043835231236, 38.047647612435476, 37.11762080873762, 38.74785579953875, 37.261326926095144, 38.23406778063093, 37.76543263026646, 38.76919024331229, 39.98511110033308, 38.016415459769114, 37.653754234313965, 39.10134540285383, 38.194358825683594, 36.929863112313406, 37.27312844140189, 36.6359612601144, 34.60785504749843, 35.77846670150757, 35.7217242377145, 36.138355595724924, 34.306233746664866, 36.16674593516758, 37.350837094443186, 34.93876300539289, 35.200862952641074, 35.296845367976594, 35.179750851222444, 36.72948748724801, 34.838288579668315, 39.416640758514404, 43.31779718399048, 43.346434184483115, 44.55588974271502, 44.50184317997524, 42.96578754697527, 42.21638263974871, 42.070334979466026, 40.22337525231497, 39.91872106279646, 38.86792761938912, 37.89162233897618, 34.85886566979544, 32.810891083308626, 32.6272154535566, 31.72866746357509, 31.743289947509766, 32.29165915080479, 33.01664808818272, 33.266491413116455, 34.16235045024327, 34.416338375636506, 35.041426113673616, 33.93886511666434, 32.396503993443076, 33.94200917652675, 34.81780529022217, 35.63350990840367, 34.216004439762656, 33.02591003690447, 35.157791069575715, 33.86498144694737, 34.028309277125764, 33.739232948848176, 35.22830138887678, 34.614639963422505, 34.066625118255615, 34.898640632629395, 32.73527036394392, 33.24322884423392, 34.01791477203369, 31.946253776550293, 32.319465841565815, 33.256569385528564, 33.42371872493199, 34.89139018739973, 38.19256271634783, 39.724883692605154, 40.4313383102417, 42.13575921739851, 41.94440235410418, 43.26965659005301, 43.70585754939488, 44.39756114142281, 44.60590982437134, 41.7595385823931, 42.82097666604178, 46.36943210874285, 46.47961664199829, 48.570003032684326, 46.611024447849815, 48.6284373828343, 51.398416655404226, 43.87228080204555, 29.169423580169678, 0.078590436439429, 0.10502774853791509, 0.30066711774894167, 0.0843669611162373, 38.637018135615754, 54.34865999221802, 46.76479503086635, 32.82375914709908, 23.015303339276993, 27.38595822879246, 35.80392837524414, 1.9658258174146925, 0.3303239292332104, 0.11175287874149424, 0.06809551494994334, 0.07215968865369048, 0.08328166470995971, 0.044540192133613994, 0.010171070295785154, 0.05153500268767987, 0.009288558320674514, 0.04502838111615606, 0.06883595950369324, 0.033026772617761574, 0.02508515804739935, 0.07057110246803079, 0.030429822326238667, 0.03119765255334122, 0.014498086413368583, 0.013479575664470238, 0.00617252619537924, 0.037479855452797244, 0.027301794549982463, 0.08624598743127924, 0.023418033129668663, 0.013373490955148424, 0.046371344410415204, 0.04939644690603018, 0.04648323144231524, 0.07447508762457541, 0.1290089674293995, 0.03312939764665706, 0.11612616585833685, 0.005327373510226607, 0.11015716793813876, 0.11830068060329982, 3.3571044419492995, 47.94955669130598, 38.3762765611921, 21.68413966042655, 35.1434326171875, 41.620883805411204, 61.60104029519217, 49.11192083358765, 55.68416282108852, 8.283927236284528, 0.8329979245151792, 0.2258902923869235, 0.02080601596805666, 0.0649143595780645, 21.88969169344221, 66.88225487300328, 51.838967187064036, 61.80575507027762, 54.325942856924875, 58.825401714869905, 51.67810596738543, 55.755590302603586, 54.068668433598106, 56.2673077583313, 52.33967522212437, 56.717106342315674, 50.80829572677612, 48.20160606929234, 38.682334286826, 40.228384903499055, 40.65014403206961, 40.848963260650635, 39.19825887680054, 40.8450722694397, 38.64383084433419, 39.67467948368618, 38.55787467956543, 42.02056155885969, 38.819491727011545, 40.48509652273995, 39.46463891438076, 41.38089997427804, 37.55166435241699, 41.445007528577534, 41.51506274087088, 40.18324245725359, 39.1580114364624, 40.411119052342, 39.3735237121582, 39.41747454234532, 39.21618522916521, 39.712991850716726, 37.34327050617763, 38.155803271702354, 39.1444867679051, 38.22458348955427, 37.3276926449367, 37.053138051714214, 38.026413917541504, 37.68779345921108, 38.3919551713126, 37.925449643816265, 38.09155675343105, 37.6209066254752, 37.20125280107771, 40.51947968346732, 43.237788677215576, 44.58425576346261, 45.8336044039045, 45.02245780399868, 44.144605023520334, 44.724758761269705, 44.258569376809255, 40.51554352896554, 40.71662439618792, 40.951539516448975, 38.99532284055437, 37.68736267089844, 35.46315050125122, 35.12301186152867, 34.054927825927734, 34.92102425439017, 33.16819177355085, 34.2601706641061, 34.171643665858674, 34.75912427902222, 37.01494380405971, 36.52940021242414, 35.799335615975515, 35.731684480394634, 37.000932761601035, 36.41304915291922, 38.03080170495169, 35.76689795085362, 35.73249741962978, 37.1962570462908, 34.360120500837056, 36.20557246889387, 35.20148481641497, 36.28557750156948, 36.38047252382551, 37.697117941720144, 35.90788732256208, 35.25393329347883, 34.72531434467861, 34.75169665472848, 34.5835919380188, 35.28353609357561, 34.689353942871094, 36.618076596941265, 36.28899254117693, 39.581754275730674, 41.59396995816912, 41.54142420632498, 42.37403379167829, 43.65586873463222, 44.799021107809885, 46.25829914637974, 44.84497996738979, 46.19329874856131, 43.23071888514927, 44.50743647984096, 47.34845413480486, 48.1021078654698, 50.929447991507395, 51.018433570861816, 49.96759843826294, 50.608357838221956, 45.885761056627544, 32.47017921720232, 0.08973468201501028, 0.39781856749738964, 1.3151620860610689, 0.07483895202832562, 43.1689806665693, 60.44583279745919, 50.442129135131836, 39.02259104592459, 30.321771894182476, 20.976931163242885, 44.4306241444179, 3.368087806871959, 0.21571316277342184, 0.06695394084921905, 0.06456035428813525, 0.047482710132109265, 0.015715295116284063, 0.06507947428950242, 0.021397703593330722, 0.013716093464089292, 0.04873768439782517, 0.04420967433335526, 0.02989861083083919, 0.04285058904705303, 0.024049321754968593, 0.076997290498444, 0.03876021371356078, 0.1632729366953884, 0.14238510467112064, 0.10759390691029173, 0.10199396418673651, 0.16400313537035668, 0.13510605240506784, 0.13740677466349943, 0.17722384738070623, 0.1109272101894021, 0.2609545258539063, 0.1760395730712584, 0.13578279609126703, 0.24919011284198078, 0.19691147309328827, 0.10241842176765203, 0.2013161831668445, 0.13001743331551552, 0.2343909383884498, 0.19995198851185186, 3.8607109614780972, 60.535457611083984, 48.66374117987496, 34.575313159397666, 44.738686425345286, 45.608930928366526, 67.72518948146275, 54.0058080809457, 61.545100348336355, 11.475802864347186, 0.9310208303587777, 1.120632175888334, 0.19547398308558123, 0.11836333652692181, 23.352985790797643, 67.86837795802525, 54.24945708683559, 65.48260974884033, 57.08876201084682, 63.520987374441965, 55.24926117488316, 57.93459054401943, 55.91475963592529, 57.87440177372524, 56.67827980858939, 60.095601899283274, 52.49097919464111, 50.37695155824934, 42.15784754071917, 41.56744521004813, 42.79035595485142, 42.13035351889474, 41.37261772155762, 42.69641283580235, 40.88268286841256, 41.88591936656407, 41.06877647127424, 44.30709906986782, 41.53055027553013, 42.10471814019339, 42.22498798370361, 43.348904269082205, 41.27883441107613, 42.774965694972444, 44.53265496662685, 42.132299014500205, 41.480551038469585, 42.93961020878383, 40.8636725970677, 41.14181246076311, 40.05167136873518, 41.01879807880947, 39.125129086630686, 39.51834501538958, 41.57061358860561, 39.92212915420532, 37.25992338997977, 38.88984571184431, 40.287166663578574, 40.070542676108225, 41.750318322862896, 40.290220396859304, 41.44024453844343, 41.107623849596294, 38.40226282392229, 42.76426894324166, 46.50846208844866, 46.48992082050869, 47.68730388368879, 48.92525747844151, 47.35033362252371, 47.917285782950266, 47.218894549778526, 43.36132764816284, 43.35386528287615, 45.67584555489676, 42.17513813291277, 40.0413498197283, 37.50229740142822, 37.27090154375349, 37.69191721507481, 37.15055527005877, 35.32429075241089, 35.94697788783482, 35.75423833302089, 37.778703689575195, 40.7204841205052, 39.83753831045968, 37.24396685191563, 36.06167875017439, 37.777459962027415, 38.97403703417097, 39.47816358293806, 37.88613673618862, 38.470556667872835, 39.723976952689036, 35.59145941053118, 37.67092323303223, 37.314372948237825, 39.47645432608468, 39.45540475845337, 39.32663379396711, 39.04513447625296, 37.004733426230295, 35.9987211227417, 37.64785868780953, 36.218440532684326, 36.74537801742554, 36.639411040714805, 37.901137896946494, 38.37661354882376, 42.05059862136841, 44.37265532357352, 44.19855778557913, 46.56504126957485, 46.01972927365984, 47.247663566044395, 49.21846451078142, 48.24681452342442, 48.15007128034319, 45.18849195752825, 47.30817890167236, 52.580822876521516, 51.46175643375942, 52.57817908695766, 53.15647070748465, 51.76670592171805, 51.74428061076573, 46.62603603090559, 32.509620666503906, 0.12663824749844416, 0.4061630011669227, 0.7721741540091378, 0.10180010673190866, 47.035309246608186, 62.418078967503135, 57.479139600481304, 41.95114210673741, 36.823673793247764, 35.070994172777446, 52.7980409349714, 7.534882766859872, 0.581213609448501, 0.2902755167867456, 0.16828858612903527, 0.18184085749089718, 0.17683360832078115, 0.1856086810252496, 0.1353355600897755, 0.14739466086030006, 0.17240848791386398, 0.16759166281138146, 0.1593932770192623, 0.12184082849749497, 0.095526358378785, 0.2021062693425587, 0.09510787190603358], [0.03364268224686384, 0.013436285978449243, 0.027241077540176253, 0.02703671805959727, 0.029577395745686123, 0.016091379935720136, 0.019880877574905753, 0.012893497827462852, 0.035380471497774124, 0.07932398707738944, 0.0753968231646078, 0.062093146677528105, 0.024046865458201085, 0.06215100535856826, 0.05019285024276801, 0.08055959256099803, 0.007711499596812895, 0.051734010223299265, 0.0946999095114214, 0.04919638085578169, 17.98436461176191, 43.467044489724294, 45.85940653937203, 43.01177767344883, 26.384820086615427, 49.018714223589214, 43.81308215005057, 52.6958190373012, 20.17515073503767, 0.19308115648371832, 0.05576247941436512, 0.2170916609466076, 0.07492458993302924, 5.834530029978071, 56.829295430864605, 50.49571016856602, 57.99300404957363, 53.126273836408345, 55.78527995518276, 49.28514984675816, 51.412316526685444, 51.472668579646516, 53.933644090379985, 50.99312475749424, 51.43976191111973, 49.499776227133616, 50.789886474609375, 43.316199098314556, 40.404716287340435, 39.03094972882952, 39.06303998402187, 38.970389229910715, 38.11411755425589, 38.22615378243582, 38.37875011989048, 36.34064197540283, 37.64333541052682, 38.07741369519915, 38.44174248831612, 37.28800800868443, 39.779774461473735, 38.107773848942344, 38.56930794034685, 39.14272539956229, 38.58109555925642, 37.86617456163679, 38.49588285173689, 39.71728236334664, 38.51163094384329, 39.592930453164236, 38.56924888065883, 36.84799248831612, 35.78561292375837, 36.28715821674892, 37.09971877506801, 36.964934144701274, 36.1677325793675, 36.866808210100444, 36.92659051077706, 35.85815906524658, 35.750816345214844, 36.78180742263794, 35.77422482626778, 35.783479826790945, 40.81088365827288, 49.30058526992798, 48.499291215624126, 50.50009100777762, 49.72971991130284, 52.199457100459504, 44.94193860462734, 45.430942399161204, 48.1044841493879, 49.37671668188912, 46.91942024230957, 42.57806764330183, 36.37761334010533, 36.41280596596854, 34.18583536148071, 33.49489607129778, 33.24152653557913, 33.179538181849885, 33.753886699676514, 33.56765065874372, 33.503449303763254, 33.4054936000279, 33.090604713984895, 35.10872983932495, 34.09335483823504, 33.18848746163504, 34.60020160675049, 34.44024017878941, 34.75809594563076, 34.901683943612234, 37.40169095993042, 34.21867254802159, 33.09293583461216, 33.77768080575125, 33.64823586600167, 35.21756642205374, 35.714397362300325, 34.5675242287772, 35.124005453927175, 33.57956681932722, 34.15560374941145, 33.88050719669887, 34.105177198137554, 32.05804681777954, 39.34505346843174, 45.12812948226929, 46.35275295802525, 45.54766518729073, 46.19454942430769, 47.36303492954799, 45.870551449911936, 47.3536513873509, 48.750096866062705, 45.59579883302961, 46.06606681006295, 47.46765742983137, 45.76949337550572, 47.37296390533447, 45.47580344336373, 48.77589552743094, 47.92152418409075, 52.42560706819807, 44.68618931089129, 45.99973930631365, 26.957728590284074, 0.5761889219284058, 1.441108607820102, 2.2810625476496558, 1.8414465487003326, 49.58512442452567, 41.86618995666504, 44.860144410814556, 27.55576699120658, 26.529370410101755, 35.88941901070731, 18.266970430101665, 0.36636306824428694, 0.05959028883704117, 0.02080088115430304, 0.014477925441626991, 0.021002692735887, 0.034409141833228726, 0.03951034774737699, 0.06676374069814171, 0.05305146060085722, 0.03367613063060811, 0.0354606064834765, 0.01057704458279269, 0.03670121955552271, 0.022616026790014336, 0.032856314443051815, 0.025496570792581354, 0.07857719822121517, 0.012283119106931346, 0.0611656503751874, 0.00951325858477503, 0.14012105044509682, 0.02821741988217192, 0.033850005229136775, 0.023664916399866343, 0.03605314397386142, 0.062137651789401255, 0.026558014996615902, 0.026895263864259635, 0.01356713127877031, 0.03434649269495692, 0.011801810469478369, 0.04524225535403405, 0.021805177442729473, 0.05215176727090563, 0.09278895812375204, 0.03297994352344956, 26.84622389929635, 49.71848120008196, 43.37736756461007, 48.35401133128575, 32.90965277808053, 55.246606963021414, 49.513648305620464, 57.87096241542271, 20.847769362585886, 0.17047854433102266, 0.2085959818214178, 0.31260401436260765, 0.10083427320101432, 7.039020231791905, 60.28746945517403, 51.499287128448486, 60.98641654423305, 55.73627431052071, 57.0037716456822, 49.83507892063686, 53.680298873356406, 51.544888155800955, 54.04157740729195, 53.0653520311628, 53.09322820390974, 52.37782083238874, 52.68444831030709, 46.13148062569754, 41.68586335863386, 39.6725081716265, 42.00040830884661, 39.90884419849941, 39.8798736844744, 39.93884652001517, 40.966064725603374, 38.30043002537319, 40.148880141122, 38.89685297012329, 39.03487546103341, 38.09705972671509, 41.765006814684185, 38.707337379455566, 42.79658848898751, 41.51809215545654, 40.65792601449149, 39.68975707462856, 40.93801484789167, 39.745398248944966, 41.1191474369594, 40.947440079280305, 40.0786303792681, 37.777161189488, 38.54781368800572, 38.84592962265015, 38.761168548039024, 38.865815367017476, 37.727259227207725, 39.15173026493618, 39.3321749823434, 37.02475118637085, 38.181831223624094, 38.237854548863, 38.16584341866629, 37.495446477617534, 42.898654052189414, 49.5878654888698, 49.8739401953561, 52.44125093732561, 51.86131954193115, 51.411826678684776, 46.909501688820974, 44.37155750819615, 47.838486262730186, 51.41194132396153, 46.31391600200108, 43.24985769816807, 37.89376585824149, 38.82314995356968, 36.505349023001536, 35.76378863198416, 33.851369925907676, 35.72477797099522, 36.284236499241416, 36.096259934561594, 36.54859461103167, 35.74214846747262, 36.75775623321533, 35.26969528198242, 36.738540990012034, 35.153497082846506, 36.155180658612935, 36.03952094486782, 37.633878912244526, 36.69963107790266, 38.30794450214931, 36.132018838609966, 35.72287763868059, 34.574385574885774, 36.16548483712332, 37.52454553331648, 36.82447631018502, 35.9918007169451, 36.29104920795986, 35.342276164463584, 35.74035235813686, 34.388347557612825, 36.52385207584926, 34.97553634643555, 40.27489614486694, 46.97149004255022, 48.19017628261021, 48.28465788705008, 48.02845696040562, 48.993950843811035, 48.428398745400564, 49.61982025418963, 49.48675877707345, 48.41479764665876, 49.34017957959856, 49.36079488481794, 48.13141189302717, 49.74875450134277, 48.81924186434065, 51.02087933676583, 50.59436764035906, 53.97170632226126, 46.473179136003765, 49.102975027901785, 28.663184779030935, 0.7133263317602021, 1.91015858735357, 1.3213374061243874, 2.592199840715953, 52.095769132886616, 49.43912540163313, 48.142532484872, 35.79251248495919, 25.980610370635986, 37.45215572629656, 26.50141085897173, 0.6495880090764591, 0.08668206831706421, 0.03450090012380055, 0.010585845181984561, 0.05923888912158353, 0.03253821722630944, 0.09658987381096397, 0.06365959905087948, 0.047400488651224544, 0.015302654222718306, 0.029882074932434728, 0.00619072959359203, 0.026599722847874676, 0.06081104797444173, 0.06005321256816387, 0.04627615612532411, 0.13084293901920319, 0.08624236405427967, 0.205599666173969, 0.07014488069606678, 0.21202571849737847, 0.10521032874073301, 0.14148238168231078, 0.10321492688464266, 0.08947745617479086, 0.16440324032945292, 0.16571106229509625, 0.11513045643057142, 0.10344885861767189, 0.11553795742137091, 0.1838193434689726, 0.19912097310381277, 0.08819646348378488, 0.1387257653155497, 0.146182797316994, 0.1770006093595709, 33.001907484872, 60.354693276541575, 50.025383131844656, 54.75618226187569, 38.65760564804077, 59.921910830906455, 54.05223594393049, 63.53221566336495, 26.008896487099783, 0.2347740392599787, 0.4796139555318015, 0.8628069992576326, 0.1706847104110888, 8.496132169451032, 61.21861144474575, 52.118250029427664, 62.629964283534456, 57.855745860508506, 58.974148750305176, 51.258511202675955, 54.0616021156311, 54.447546754564556, 55.937699113573345, 54.17190129416329, 55.081809588841026, 54.56677436828613, 55.77858189174107, 48.95948083060128, 44.92113222394671, 42.71548216683524, 42.59816530772618, 43.807488850184846, 41.6107359613691, 41.00579799924578, 42.31864970070975, 39.60276215417044, 41.92343963895525, 41.35558073861258, 41.260505063193186, 39.680748735155376, 44.234997613089426, 40.318760122571675, 43.78640801565987, 44.546370710645405, 44.20938655308315, 38.98605046953474, 42.506296225956504, 42.892122745513916, 43.38707767214094, 45.27149861199515, 42.88712351662772, 39.05684913907732, 40.505965437207905, 41.236724853515625, 40.309772627694265, 41.26352752958025, 39.66463238852364, 42.22628729684012, 42.56833321707589, 39.64335353033883, 39.83644049508231, 39.62798758915493, 39.728270939418245, 38.7163075038365, 44.07517514910017, 51.711915901729036, 52.13680171966553, 54.242925780160085, 53.352236202784944, 53.637275627681184, 49.10802984237671, 47.53981099809919, 52.450856821877615, 55.15462671007429, 49.63033982685634, 46.95975800922939, 40.625151361737935, 42.11139188494001, 38.033445494515554, 37.855460439409526, 36.028438568115234, 38.020240443093435, 37.855064392089844, 37.68418387004307, 38.76306888035366, 37.351865427834646, 38.35925347464425, 37.9304176058088, 38.773810795375276, 38.12700298854283, 38.98110335213797, 37.150954791477744, 38.8418162890843, 38.420418466840474, 40.496171951293945, 38.38406549181257, 38.55867372240339, 36.56192473002842, 37.96197632380894, 38.97421768733433, 38.79350893838065, 37.71692030770438, 39.07945510319301, 37.39050088609968, 39.02501596723284, 37.579245226723806, 38.198347091674805, 37.43064062935965, 43.87781504222325, 50.34305477142334, 50.38470227377755, 49.39616468974522, 51.628554889133994, 50.862707069941926, 50.125419821058, 52.0720340864999, 51.68917792184012, 49.79760728563581, 52.198633738926475, 52.93336057662964, 49.895767961229595, 52.119410378592356, 50.79799502236502, 51.970010212489534, 53.72528498513358, 52.217619691576274, 49.20536715643746, 46.74312359946114, 30.735512801579066, 0.6510185780269759, 2.6296024279935017, 6.323837373937879, 2.527465428624834, 57.59703663417271, 51.85302339281355, 53.91950103214809, 38.30281673158918, 36.78679970332554, 47.485781805855886, 37.40069389343262, 0.689383327960968, 0.1428145630551236, 0.10619283387703554, 0.14927287293331964, 0.16582406551710197, 0.12253053220255034, 0.2188591496752841, 0.10445971973240376, 0.11621518965278353, 0.08113964500703982, 0.1358133844499077, 0.07562342671943562, 0.12764642839985235, 0.21319216090653623, 0.12862402094261988, 0.12262520140835217], [0.042660066591841836, 0.0493018523390804, 0.047591045033186674, 0.03432303913203733, 0.013311230278174793, 0.05513775222269552, 0.06898279448172875, 0.06641233419733387, 0.046621262428483794, 0.03759347274899483, 0.02909915747919253, 0.00756692498855825, 0.055243681717131815, 0.018695880625663058, 0.04573657490046961, 0.08297799993306398, 0.06614445535732166, 0.04942137628261532, 0.023914028657600284, 0.11360846167164189, 1.9544116641793932, 41.12126316343035, 37.000873701913015, 31.56740324837821, 27.71586217199053, 37.24027735846383, 51.1904535974775, 44.72084692546299, 39.87463126863752, 0.14326886939150946, 0.0273511494909014, 0.09255552850663662, 0.048595792547400506, 0.5567140983683723, 35.83174548830305, 59.28212765284947, 51.303334031786235, 55.927443572453086, 51.45049340384347, 55.08810813086373, 53.19020768574306, 52.31619725908552, 51.30740220206124, 53.29483018602644, 53.75054168701172, 50.933537006378174, 49.907336711883545, 49.18631519590105, 43.07932806015015, 40.448965890066965, 39.77756493432181, 40.03042030334473, 38.59841047014509, 40.93385635103498, 38.538218225751606, 38.99156733921596, 38.01330614089966, 38.085748059409006, 39.043327944619314, 39.78251552581787, 39.32157550539289, 39.368388993399485, 39.48048775536673, 39.49937990733555, 37.826955454690115, 38.488420486450195, 37.59872797557286, 36.93600879396711, 38.279939787728445, 36.92303303309849, 36.45899411610195, 37.62418964930943, 37.16158553532192, 35.44315011160714, 36.70310517719814, 36.01186711447579, 36.74499934060233, 37.62179946899414, 38.288024016789024, 37.12122344970703, 37.08363369532994, 36.03541803359985, 37.39644854409354, 37.49595717021397, 40.54586894171578, 48.461336680821006, 50.31928498404366, 51.97537074770246, 52.256140504564556, 53.74662637710571, 46.56866822923933, 47.96400547027588, 51.47641365868704, 50.70555966241019, 50.44107648304531, 44.960292271205354, 37.957915101732524, 36.890682220458984, 35.186209201812744, 35.05367578778948, 35.23802886690412, 33.514201641082764, 36.2874048777989, 33.09864377975464, 34.80083084106445, 35.6223406791687, 35.062350613730295, 35.755603654044016, 34.88208654948643, 33.871262618473594, 35.76031800678798, 33.63871683393206, 34.670652866363525, 34.49394975389753, 36.578666414533345, 34.81070075716291, 35.45738697052002, 33.23504039219448, 35.176398345402305, 35.09071316037859, 35.66711139678955, 34.04052421024868, 33.79260901042393, 35.3039881161281, 33.06084210532052, 33.633123534066335, 33.29418693270002, 35.69285447256905, 44.19699444089617, 45.92188821520124, 46.24262401035854, 46.486359868730815, 47.5996732030596, 47.39603539875576, 46.92910950524466, 47.59986080442156, 48.73524161747524, 48.87018953050886, 50.474215916224885, 48.774116788591655, 50.23356853212629, 48.55754838671003, 49.54287590299334, 47.377681732177734, 50.4472325869969, 47.354280199323384, 43.93736457824707, 52.78642354692732, 14.891283682414464, 0.6126894376107624, 1.4402989255530494, 0.5673856628792626, 12.071081961904254, 53.337109974452424, 47.23135961805071, 38.02436072485787, 23.09043594769069, 27.229406629289898, 41.37177351542881, 7.949492199080331, 0.4377655253878662, 0.07562907891614096, 0.08799561711826495, 0.03809362091124058, 0.039265416961695464, 0.026675454141306024, 0.022792428931487457, 0.04825113407735314, 0.054939779452979565, 0.029502451552876403, 0.03590939293748566, 0.012731408534039344, 0.03275428991764784, 0.02169878824081804, 0.019779043039306998, 0.06729174950825316, 0.058297157154551575, 0.08769417793623038, 0.05122566535802824, 0.0317115885471659, 0.03233276360801288, 0.05170577298849821, 0.1144191345998219, 0.010376191431922572, 0.047041737008839846, 0.04370733789567437, 0.007557028555311263, 0.043235372685428174, 0.03336522588506341, 0.009655158068718655, 0.030239388080579892, 0.006158265085624797, 0.0630328498248543, 0.0624630975403956, 0.057876214385032654, 0.18518570943602494, 4.032903390271323, 50.03514882496425, 41.65392943790981, 37.236341203962056, 36.75665494373867, 45.22306271961757, 55.72480978284563, 52.03701169150216, 42.036122049604145, 0.07546707868043866, 0.031460676475295, 0.25680243436779293, 0.17137501122696058, 1.1409830152988434, 39.81528670447213, 60.210233279636924, 53.172809396471294, 56.77440118789673, 54.48113087245396, 55.96565866470337, 54.54851450238909, 54.05201360157558, 53.39894894191197, 55.050709451947895, 54.691237449645996, 54.504657472882954, 51.99763625008719, 52.02623503548758, 47.06398098809378, 40.29389251981463, 40.80179194041661, 41.79824352264404, 39.30274588721139, 42.03828641346523, 40.53927162715367, 41.310695375714985, 39.77938536235264, 40.06867013658796, 39.86126293454851, 41.14444235392979, 40.63365943091256, 41.040198530469624, 41.318463461739675, 40.863651752471924, 39.638507161821636, 39.877761432102744, 39.412774085998535, 39.87823738370623, 40.51427895682198, 39.883962699345176, 39.53704956599644, 40.08658259255545, 39.45415408270699, 37.58712795802525, 39.42288024084908, 38.69702972684588, 40.32048327582223, 39.2159628868103, 40.17157990591866, 38.72058064596993, 38.97021205084664, 38.03619350705828, 37.75698014668056, 39.6761976650783, 43.63315159933907, 50.27180446897234, 51.46644994190761, 53.69410841805594, 52.989602770124165, 54.119383335113525, 47.5957544190543, 50.00589343479702, 53.867931502205984, 52.711157185690745, 52.31506470271519, 45.917087009974885, 39.509263719831196, 37.7489584514073, 37.7286627633231, 36.19127655029297, 36.3395927974156, 35.28199706758772, 36.82793651308332, 34.87933158874512, 37.16507005691528, 35.58000530515398, 36.78006342479161, 36.8141200201852, 35.39899778366089, 36.49134145464216, 37.69125018801008, 36.65771606990269, 38.50077090944563, 37.02289949144636, 38.526381969451904, 36.76939793995449, 36.68152059827532, 35.59051098142351, 36.92427328654698, 37.832649503435405, 37.92957339968, 35.22083554949079, 35.81701530729021, 37.08663879122053, 34.55410378319876, 35.094155992780415, 36.40990856715611, 37.004570143563406, 45.20068257195609, 48.25881406239101, 47.787823472704204, 48.344596522195, 49.342257090977256, 50.328248160226, 49.024477754320415, 49.788724013737266, 51.444747243608745, 50.271154812404085, 52.61850643157959, 50.742364270346506, 52.280598163604736, 49.95626245226179, 51.58782107489449, 48.869807379586355, 51.33177648271833, 49.48865563528878, 47.12452411651611, 53.51011664526803, 14.978502682277135, 0.644091224031789, 1.5404023826122284, 1.371980002948216, 12.615787727492195, 59.67944649287632, 50.85729094914028, 43.174296038491384, 30.80700629098075, 26.34630274772644, 46.095200606754844, 11.509694440024239, 0.6099541815263885, 0.023129991621577313, 0.07150396598236901, 0.07441842995051827, 0.007697877158144755, 0.044632761273533106, 0.06128725742122956, 0.08420531371874468, 0.042724469743136845, 0.023757565267650143, 0.032256828754075935, 0.03967896369951112, 0.05594130053317972, 0.04026673448139003, 0.02910812431946397, 0.03927606996148825, 0.15808651356824807, 0.22375117002853326, 0.12351455725729465, 0.08432626937116895, 0.12466349346297127, 0.1568596408303295, 0.18045831524900027, 0.17538960437689508, 0.17149976667548927, 0.11602431775203773, 0.14818016013928823, 0.11194227822124958, 0.10372559233967747, 0.1131089920444148, 0.09460438535149608, 0.12828378991356917, 0.17801689196910175, 0.13737872402582849, 0.16750827085758957, 0.2233957126736641, 5.35220171724047, 64.82946518489292, 46.31375619343349, 43.3025667326791, 44.65940400532314, 48.97296033586775, 61.03945909227644, 55.61831474304199, 49.95392090933663, 0.34801998681255747, 0.15026733385665075, 0.18735426664352417, 0.23151593123163494, 2.0240753889083862, 40.9196194921221, 62.447442054748535, 54.78852265221732, 58.05072273526873, 55.72075203486851, 58.57284164428711, 57.25223227909633, 55.13523428780692, 55.76928520202637, 57.06632627759661, 56.67652191434588, 57.67635726928711, 55.46642712184361, 55.33641937800816, 49.01409019742693, 44.41500806808472, 42.00603634970528, 43.6417430468968, 41.78834581375122, 43.94681760243007, 43.413734436035156, 43.506774289267405, 40.37201459067208, 41.659088475363596, 42.28524971008301, 44.71706363133022, 44.5568277495248, 43.25719152178083, 41.41007546016148, 42.53993592943464, 42.149732044764924, 42.918713501521516, 41.925423349652974, 41.003109046391074, 41.956843103681294, 41.94581978661673, 41.465424810137065, 43.304272515433176, 42.72725936344692, 38.94748101915632, 41.82322577067784, 40.20965256009783, 40.68746280670166, 41.22948483058384, 42.71967887878418, 40.3747695514134, 41.1737950188773, 40.2785439491272, 39.91030332020351, 42.172963346753804, 44.683983257838655, 51.66372319630214, 53.811644145420615, 55.844787802015034, 54.7830822127206, 56.29557303019932, 48.986446789332796, 51.141760621752056, 56.71490723746163, 54.260247639247346, 53.67967006138393, 48.54669877461025, 41.21475117547171, 39.84716851370675, 39.6965663092477, 38.55119398662022, 40.21642010552542, 37.53594405310494, 42.116436277117046, 37.12704256602696, 39.4346261705671, 38.34155641283308, 38.579504421779085, 39.95833969116211, 39.03452805110386, 38.026910713740754, 40.950664043426514, 38.669646876198904, 40.07919665745327, 39.16125624520438, 41.39425093787057, 38.069086279187886, 39.57923207964216, 35.89368520464216, 39.01770646231515, 40.02125562940325, 39.95393105915615, 37.12119913101196, 38.60272182737078, 39.25978170122419, 36.60869652884347, 37.12895679473877, 37.587141854422434, 38.50100367409842, 47.57903010504586, 50.34103979383196, 49.50398336138044, 51.47235591070992, 49.46682786941528, 52.42968913487026, 54.244503021240234, 52.19112968444824, 54.37591430119106, 51.53495223181588, 54.413684708731516, 53.87591845648629, 54.300790378025596, 50.873167582920615, 54.76760510035923, 51.97616284234183, 52.8011919430324, 51.207455839429585, 48.18087611879621, 49.28518458775112, 17.711824996130808, 0.8806569214378084, 4.642573944159916, 3.080696633883885, 14.153646418026515, 64.03570297786167, 54.98588970729283, 47.051241465977256, 35.69659955160958, 36.553753648485454, 53.700195040021626, 17.390019178390503, 0.8678683819515365, 0.1913529277912208, 0.41072655628834454, 0.16447000817528792, 0.09899323806166649, 0.23790306278637477, 0.15434953623584338, 0.2109690359128373, 0.17557214386761189, 0.12605090758630208, 0.11997838557830878, 0.09191613817321402, 0.1942277585289308, 0.11732327805033751, 0.10997254534491471, 0.1541796853499753], [0.035141237013574154, 0.05216586722859314, 0.032187797993953736, 0.0953795098300491, 0.05364191498873489, 0.11597334620143686, 0.10502911917865276, 0.0515235388385398, 0.04400526226631232, 0.0741446071437427, 0.06137432703482253, 0.021761072666517327, 0.015112991810643246, 0.028364200577405945, 0.06446447050465004, 0.03356869139575532, 0.07102743083877222, 0.10136105386274201, 0.013786496561286705, 0.008009867559719299, 0.060693878547421524, 19.38175678253174, 47.990200178963796, 30.4727076121739, 36.701892716544016, 27.112706422805786, 47.811183316367014, 47.5542563029698, 47.97052982875279, 3.7350414991378784, 0.5358342187745231, 0.2192424133952175, 0.03237725514918566, 0.17530177480408124, 24.50641281264169, 55.49849305834089, 52.201155935014995, 56.70868512562343, 52.26327977861677, 54.556570938655305, 53.66332442419869, 53.94513988494873, 54.38428340639387, 54.9367207799639, 54.212774072374614, 55.36876324244908, 48.69547012874058, 51.523588453020366, 49.42153603690011, 42.60138579777309, 39.217849322727744, 41.14573471886771, 38.50335911342076, 39.52938917704991, 38.39728791373116, 38.842170647212434, 37.666358266557964, 40.16057048525129, 38.78837421962193, 38.89743314470564, 38.14531149183001, 40.35282366616385, 39.20331369127546, 40.123526164463584, 37.81122473308018, 36.67996072769165, 39.105618544987266, 41.23871203831264, 39.598958015441895, 37.402201652526855, 36.60083811623709, 39.00548110689436, 37.727690015520366, 37.19570466450283, 37.08380045209612, 36.457934515816824, 36.15017448152815, 37.80753523962838, 37.68632738930838, 38.49621636526925, 36.66523054667881, 37.60792391640799, 37.266805580684114, 37.983262130192344, 41.00069802148001, 42.91192511149815, 47.75026845932007, 49.389122690473286, 50.32466288975307, 60.75248459407261, 49.16814913068499, 49.14843709128243, 52.95666830880301, 48.59712879998343, 45.991787093026296, 40.485006196158274, 38.598406996045796, 39.82121351787022, 37.00806508745466, 37.38432741165161, 36.370144026620046, 37.12443004335676, 35.77312353679112, 34.68602228164673, 34.9188494682312, 34.63669007165091, 35.157586097717285, 35.07578495570591, 33.4573757989066, 34.371164662497385, 33.56232833862305, 35.6337114061628, 34.955692291259766, 34.3786826133728, 36.52814258847918, 36.00518989562988, 36.054789611271445, 34.02050992420742, 34.56955310276577, 35.98369216918945, 34.88110685348511, 35.729231766292024, 35.032935414995464, 35.925045898982454, 35.44416107450213, 33.6629764693124, 34.4669177872794, 37.54477868761335, 44.15721947806222, 47.07553931644985, 46.59226778575352, 46.58434336526053, 46.49788693019322, 46.397478512355256, 48.74660539627075, 50.0368789264134, 47.86544527326311, 48.37266377040318, 47.207412651606965, 47.0347638130188, 48.6335894720895, 49.26658426012312, 45.967697688511436, 46.239726611546104, 48.669935498918804, 49.932822704315186, 55.78011744362967, 47.67617286954607, 3.748517530305045, 0.4444217367896012, 1.0692577383347919, 0.6330376171639988, 25.603849513190134, 47.28808471134731, 37.95505244391305, 26.831947088241577, 26.756303787231445, 33.39463356563023, 24.286710773195537, 0.2160887454769441, 0.013556390069425106, 0.16556300595402718, 0.026491323485970497, 0.05275253878374185, 0.020405257919004986, 0.03145194712228008, 0.053784420913351436, 0.03326442611536809, 0.06587844248861074, 0.038525274356028864, 0.04145237943157554, 0.07007889316550323, 0.05051697285047599, 0.02463771678906466, 0.03090259838583214, 0.04860626234273825, 0.04095511165048395, 0.08824579297964062, 0.026360395065109645, 0.03689643408038786, 0.045919803104230335, 0.03076165309175849, 0.04465652017721108, 0.006806965343587632, 0.009024797340056725, 0.03857650714261191, 0.022764999153358594, 0.06085988213973386, 0.036963436020804305, 0.03532521839120558, 0.016443076510248438, 0.027501024305820465, 0.05053252487310341, 0.03448070013629539, 0.06710925072963748, 0.043115797851766856, 0.10158560145646334, 28.8752281665802, 53.170297622680664, 32.289126532418386, 44.030296734401155, 36.60849503108433, 52.62414836883545, 52.12447908946446, 52.70990650994437, 4.121540691171374, 0.7281383712376867, 0.5317620315722057, 0.2036890336977584, 0.36329454290015356, 27.024683168956212, 58.63669558933803, 53.089768001011436, 60.21650055476597, 53.84603772844587, 55.6799487386431, 54.986358710697715, 56.31025109972273, 55.95568799972534, 57.85774346760341, 54.68343114852905, 55.54063388279506, 51.548233713422505, 52.58026702063424, 50.38721752166748, 45.9125463621957, 41.88931703567505, 42.67583227157593, 39.506387165614534, 40.4885949407305, 41.30901738575527, 40.155161312648225, 39.12020281382969, 41.95712797982352, 40.112707819257466, 40.57418632507324, 40.11438928331648, 41.23895869936262, 40.024048805236816, 40.97800867898123, 39.685299805232454, 39.55679982049124, 41.014524936676025, 42.79995836530413, 41.26315232685634, 39.75179753984724, 38.07227202824184, 41.03674527576992, 38.54865789413452, 38.523818084171836, 38.838911942073274, 39.197914940970286, 39.11525222233364, 40.18857172557286, 40.686121804373606, 41.215175015585764, 39.64851256779262, 39.74335200445992, 39.739377634865896, 40.393877097538535, 40.90657772336687, 44.61510229110718, 47.7023606300354, 50.94707209723336, 51.7020320892334, 53.04814829145159, 51.3724616595677, 51.35065821238926, 53.87172174453735, 50.0009115764073, 47.364104952131, 41.79630497523716, 39.96220983777727, 39.46200554711478, 39.006061281476704, 37.70541756493704, 37.85718706675938, 38.49342318943569, 37.556486402239116, 36.98008469172886, 38.9708617074149, 36.693450655256, 37.04292072568621, 38.493034090314595, 36.814276354653494, 35.90783521107265, 35.96762098584856, 37.291839940207346, 37.51336588178362, 37.04647820336478, 37.80342885426113, 37.98108039583479, 37.00501135417393, 36.09689222063337, 36.83459288733346, 37.04375450951712, 35.753963879176546, 38.66802794592721, 37.09154074532645, 38.554963384355815, 37.026324953351704, 36.90113925933838, 36.520388398851665, 40.44907358714512, 45.243017945970806, 49.13573578425816, 47.88621343885149, 47.71580539430891, 48.93412685394287, 49.85489170891898, 49.94448872974941, 50.49496323721749, 49.083638191223145, 49.55188076836722, 48.76680380957467, 49.00631863730294, 47.45449754170009, 50.61071327754429, 47.38177422114781, 48.27467679977417, 48.561880588531494, 52.24798331941877, 54.55228042602539, 47.806458541325156, 4.108194938727787, 0.73402132413217, 2.0184152126312256, 0.6603481088365827, 29.3377297946385, 53.56329468318394, 43.07626390457153, 33.77791357040405, 28.933436700275966, 34.50469514301845, 28.97945809364319, 0.6999034434556961, 0.07169074631695237, 0.04483503595526729, 0.006604320436183895, 0.026007789253656353, 0.02017416076601616, 0.06378538587263652, 0.023712162793214833, 0.04233906524521964, 0.013720532779448798, 0.03958336490073374, 0.03958191962114402, 0.06655566114932299, 0.029174590217215673, 0.053405007879648886, 0.02208935808656471, 0.02224423879358385, 0.1546475895281349, 0.17954861692019872, 0.10081506387463637, 0.18339840748480388, 0.1107354833345328, 0.1790601938430752, 0.18844398031277315, 0.14995770475694112, 0.10533878220511333, 0.12403818273118564, 0.08943439634250742, 0.167583167552948, 0.1520987677254847, 0.11933577220354762, 0.15574225650302, 0.12311419445489134, 0.13050356294427598, 0.14886990455644472, 0.2124943554933582, 0.11213739096586194, 0.19791544707758085, 33.681889465876985, 62.975039618355886, 38.739594391414094, 51.71977778843471, 40.00841188430786, 56.265126023973735, 58.05186223983765, 59.13516630445208, 6.300814952169146, 1.4317683832986015, 0.9561553959335599, 0.15261023385184153, 0.9510963474001203, 30.677491869245255, 58.78907653263637, 55.08562067576817, 59.61737823486328, 57.53735160827637, 56.286338874271934, 56.11127553667341, 57.51416546957833, 57.29088510785784, 59.313457080296104, 57.681557995932444, 56.53683532987322, 54.35256487982613, 55.96382086617606, 52.97391373770577, 47.65295893805367, 44.7714923449925, 45.14691741125924, 40.76989276068551, 41.64230857576643, 43.28356688363211, 42.649717467171804, 41.25465815407889, 43.65717847006661, 42.35299464634487, 42.712720257895334, 41.77423054831368, 44.54325096947806, 42.872799805232454, 42.62971012932913, 40.93900844029018, 40.747422286442344, 43.21061427252633, 45.95524999073574, 43.123275416237966, 41.886346680777415, 39.61634240831648, 42.15953595297677, 40.83145727430071, 41.163577692849294, 42.194290842328755, 41.30160713195801, 40.775798729487825, 41.94240127290998, 42.59548677716936, 42.52322898592268, 40.86152212960379, 40.61240489142281, 40.6697553225926, 40.544329915727886, 43.34672253472464, 46.18005895614624, 49.322645800454275, 53.01448426927839, 51.4357145854405, 54.58841453279768, 53.10121863228934, 51.727848121098106, 56.21663802010672, 52.351761613573345, 49.389942577907014, 42.56206594194685, 42.05777958461216, 42.77157497406006, 39.39463581357683, 41.16529737200056, 39.96913024357387, 40.62785073689052, 40.48201847076416, 40.15255226407732, 40.02886390686035, 39.01119947433472, 39.267407349177766, 40.582385199410574, 38.04868289402553, 38.70074353899275, 37.21066761016846, 41.053139550345286, 39.28929417473929, 38.853055000305176, 39.23314578192574, 40.72045980181013, 39.28422546386719, 37.438714436122346, 38.78019618988037, 39.62687240328108, 39.17308555330549, 39.89273132596697, 39.22317164284842, 40.797049794878276, 40.145461627415244, 37.963411126817974, 38.26643248966762, 41.646849223545615, 47.73776517595564, 52.76492582048689, 51.68050309589931, 50.45155784061977, 52.464860916137695, 52.524955885750906, 51.74718148367745, 52.15304660797119, 50.028641836983816, 50.29261779785156, 50.17266409737723, 50.103227274758474, 49.60413122177124, 52.467827796936035, 48.33480303628104, 49.66110297611782, 50.14965861184256, 52.62766763142177, 54.75827366965157, 48.85945456368582, 5.993883924824851, 1.2397486184324538, 5.542921951838902, 2.564940103462764, 31.61923680986677, 57.2580965587071, 47.13295922960554, 38.199014118739534, 37.395135334559846, 43.65149484361921, 40.12764297212873, 1.5804679755653654, 0.20100265927612782, 0.19887999817728996, 0.1072782456342663, 0.10453909475888525, 0.10532990696706943, 0.09602630976587534, 0.15854578678097042, 0.14656315690704755, 0.10612944513559341, 0.1326353299830641, 0.09212577835257564, 0.15966661806617463, 0.08683277773005621, 0.11562213647578444, 0.1616759231047971, 0.1079753657270755], [0.012100197092097784, 0.039914333926779885, 0.09774389224393026, 0.028798993942993026, 0.010239041693109487, 0.028645651814128672, 0.02689026645384729, 0.03049896504463894, 0.05106007567207728, 0.027502535742574503, 0.020420664056603397, 0.0299296809493431, 0.053167032077908516, 0.006512121946018721, 0.04434358661196061, 0.02227185686518039, 0.11141449332769428, 0.09155317622103862, 0.03790545975789428, 0.04832078569701739, 0.06010144962263959, 1.347377517393657, 37.21083436693464, 42.414475781576975, 27.524102313177927, 30.37890693119594, 39.955942562648225, 43.25678505216326, 55.801431042807444, 13.587838973317828, 0.72162291514022, 0.7746790881667818, 0.28994409314223696, 0.15078859802867683, 6.597508243152073, 53.61336687632969, 54.36018010548183, 59.69929749625069, 51.71164492198399, 55.6029349054609, 54.434598786490305, 55.054489271981375, 52.87480115890503, 55.35016986301967, 51.074727875845774, 55.34440285818917, 52.492737088884624, 50.74136372974941, 50.828105040958945, 51.72766399383545, 43.25258834021432, 41.241029262542725, 40.454163142613, 38.465720721653526, 39.79688092640468, 40.92275660378592, 43.45770263671875, 42.29011344909668, 42.320053236825125, 38.076777935028076, 39.5436885697501, 39.64928729193551, 40.08847597667149, 41.345082010541645, 41.93616873877389, 37.94527285439627, 38.68828889301845, 37.285176617758616, 39.439020906175884, 38.53561612537929, 36.77079800197056, 38.356946672712056, 36.30081490107945, 37.880473954336985, 37.037112031664165, 36.756644521440776, 37.49226072856358, 38.556095940726145, 38.98450449534825, 40.39438084193638, 36.99071543557303, 36.39112411226545, 38.08818687711443, 38.487666606903076, 42.66465262004307, 47.373075076511924, 46.85689687728882, 50.49455329350063, 53.61301599230085, 81.710280418396, 51.08912454332624, 48.1597501209804, 53.49011625562395, 45.60303538186209, 43.358277388981406, 42.93060881750924, 42.383663994925364, 42.420649256025044, 41.860304832458496, 37.46048314230782, 38.98467820031302, 36.27314370019095, 36.384335722242085, 35.33660643441336, 36.1677325793675, 34.81039156232561, 35.7692950793675, 35.459679876055034, 35.39463431494576, 33.77815328325544, 37.13275745936802, 34.35429791041783, 33.95883076531546, 35.306468623025076, 35.98546743392944, 33.78015783854893, 35.017218589782715, 35.278693199157715, 36.569095270974294, 36.36737516948155, 34.67891080038888, 34.52895825249808, 34.12401376451765, 35.013358865465435, 35.51099927084786, 35.289789472307476, 35.76738779885428, 37.76525892530169, 45.71515498842512, 47.84557689939226, 47.14100871767317, 42.872285638536724, 46.38274138314383, 49.129791600363596, 46.77757971627371, 46.282878398895264, 46.543943064553396, 49.187183720724924, 49.31003482001168, 48.243614877973286, 48.2342209134783, 48.326423508780344, 50.79563610894339, 48.873486450740266, 50.494848591940745, 51.284493991306846, 51.55042587007795, 27.896609136036464, 0.16072494270546095, 0.01318707872581269, 0.7485989704728127, 0.1330025124230555, 33.25026389530727, 49.52843059812273, 34.48684869493757, 29.558237825121196, 29.648060662405832, 28.417234182357788, 8.73120709827968, 0.2772347794047424, 0.07960852395210948, 0.033467918767460754, 0.06268646448318448, 0.0330413712986878, 0.02692958077282778, 0.05934256248708282, 0.06536580928202186, 0.020692303676956465, 0.08348360351685967, 0.0734121421618121, 0.008078611638796116, 0.052915455041719336, 0.026744934430878078, 0.03875130454876593, 0.004357845780240106, 0.06566190839345966, 0.03715919676635947, 0.02188098167867533, 0.06257849599101714, 0.03986477033634271, 0.007211371790617704, 0.038737866162721596, 0.04176034951316459, 0.005865098093636334, 0.0718285364231893, 0.04542656921382461, 0.0041163399000652134, 0.03251076030677982, 0.09125907878790583, 0.030817730618374686, 0.08679288665630988, 0.04978735771562372, 0.0741709071610655, 0.06385722237506083, 0.07079771959355899, 0.07527838487710271, 0.11877716146409512, 3.2421712492193495, 49.2961870602199, 43.08187804903303, 34.384359291621614, 36.239114897591726, 47.371209485190256, 49.84933315004621, 59.88333443232945, 15.231424059186663, 0.8237299504024642, 1.3434523280177797, 1.6944163697106498, 0.027798226036663567, 7.841037767274039, 54.96237005506243, 53.65293339320591, 61.16228239876883, 53.83211701256888, 56.5588333266122, 54.66230167661394, 56.6594432422093, 55.026696477617534, 56.5122526032584, 53.616371972220286, 55.59352357046944, 53.993818964277, 52.41583790097918, 51.63645151683262, 53.678551401410786, 44.09188904081072, 42.12395075389317, 41.75179828916277, 38.628075804029194, 40.335182189941406, 43.029624121529714, 42.96747248513358, 42.09121431623186, 42.45906237193516, 40.6453080858503, 39.88208321162632, 40.50411721638271, 40.99600451333182, 42.15635020392281, 42.21650423322405, 40.41362387793404, 40.492826393672395, 38.09995017732893, 41.53589344024658, 38.46955612727574, 40.39271674837385, 40.390875475747244, 39.411797864096506, 40.14235578264509, 38.13861690248762, 40.09000110626221, 39.00204522269112, 41.42226260049002, 40.56201308114188, 40.58701269967215, 39.36955281666347, 40.042902742113384, 39.102300780160085, 40.75263690948486, 43.49838433946882, 45.437727315085276, 50.253231934138704, 52.501408440726145, 54.40235914502825, 64.78379467555455, 48.253627232142854, 51.766018050057546, 53.23270981652396, 49.68646042687552, 44.7815602847508, 41.570564951215474, 43.36301953451974, 43.59882402420044, 43.10798243113926, 40.14178603036063, 39.20644038064139, 37.859771796635215, 38.4459114074707, 37.16362830570766, 37.44383178438459, 37.04326466151646, 36.133279936654226, 38.26645680836269, 37.280066217694966, 36.14132595062256, 38.8051541192191, 36.014941692352295, 38.034550258091514, 37.20660291399275, 37.25047036579677, 38.169355733054026, 36.36339037758963, 37.1761211667742, 39.38822610037667, 38.033438546316965, 36.836854525974815, 36.39921528952462, 34.636113371167866, 35.52318641117641, 37.668348925454275, 38.68135459082467, 37.63636289324079, 40.385431562151226, 49.282916000911165, 50.675897802625386, 50.20653656550816, 45.884725775037495, 47.515666007995605, 49.810110569000244, 47.813028063092915, 48.16796636581421, 47.03669193812779, 50.954683848789756, 50.44582905088152, 51.668757166181294, 49.09829889025007, 51.441773414611816, 51.90852907725743, 50.49469920567104, 51.96654653549194, 52.01271731512887, 51.08438239778791, 29.824496269226074, 0.5239752722637994, 0.4734276703425816, 1.8071261388914925, 0.6412838803870338, 35.853041716984336, 56.15198850631714, 38.294732502528596, 35.53989682878767, 35.39209474836077, 34.700432845524375, 11.84021156174796, 0.6305624842643738, 0.03437761709626232, 0.04814166941546968, 0.033921037667563984, 0.0197368975329612, 0.0237934580737991, 0.03964216674544981, 0.03531390721244471, 0.033567466640046666, 0.029044131681855236, 0.01132672993532781, 0.029474970884621143, 0.05737439024129084, 0.06247907704008477, 0.031451431435665915, 0.02151686112795557, 0.01830671025839235, 0.1659594061119216, 0.14934812246688775, 0.14020577232752526, 0.14067558997443744, 0.06747755275240966, 0.0814779761380383, 0.09273278899490833, 0.14919344362403664, 0.15509044219340595, 0.1040115337818861, 0.18303164573652403, 0.11326491939170019, 0.1588091126510075, 0.1326901556125709, 0.12327436943139349, 0.18905084846275194, 0.15773429961076804, 0.16931126053844178, 0.22534204966255597, 0.1430816344384636, 0.19003487351749623, 3.6844590476581027, 60.24449484688895, 51.37304530824934, 39.12324612481253, 41.982884952000205, 52.0033198765346, 53.03995636531285, 67.16847896575928, 19.49333964075361, 1.2885550452130181, 4.07548542533602, 1.7851159828049796, 0.23444997093507222, 8.676062720162527, 58.10293844767979, 54.901423931121826, 62.30742195674351, 55.54508420399257, 60.17845916748047, 57.117791584559846, 57.82888412475586, 56.15084205354963, 59.70223658425467, 54.9224283354623, 58.73080893925258, 56.35352100644793, 55.340702942439485, 55.4665070261274, 55.93082734516689, 47.37029927117484, 45.067551612854004, 43.559375626700266, 41.03065865380423, 43.01587363651821, 46.232378891536165, 47.43075207301548, 45.967854022979736, 44.540579387119834, 43.115823473249165, 43.812832014901296, 42.55420405524117, 43.85116522652762, 44.679456506456646, 45.12554475239345, 42.32103640692574, 43.32448482513428, 39.440591199057444, 43.45509358814785, 40.824557713099885, 43.41325153623308, 42.458346707480295, 42.12501035417829, 43.04691471372332, 40.38143982206072, 41.68582514354161, 42.24565887451172, 42.54833630153111, 44.18130888257708, 43.75158364432198, 41.850365434374126, 39.55705342973982, 40.25865820475987, 41.46011291231428, 45.734846183231895, 49.570623534066335, 53.02950974873134, 54.325400897434776, 57.594382422310964, 65.76004437037876, 47.53648281097412, 52.41153001785278, 55.52616078513009, 50.34416995729719, 47.444697107587544, 45.82942853655134, 46.14844117845808, 46.627182483673096, 46.18571478979928, 42.28028522218977, 42.77279438291277, 41.43598876680647, 40.33644328798567, 38.53344133922032, 40.04306602478027, 38.753212860652376, 39.10303381511143, 39.916310037885395, 39.589758600507466, 37.70395149503435, 41.81942858014788, 37.63874612535749, 39.47793429238455, 40.69686024529593, 38.53000545501709, 39.628661564418245, 38.66705519812447, 38.62662363052368, 41.275853633880615, 41.22639635631016, 38.986467361450195, 37.475081307547434, 37.25012295586722, 37.552859442574636, 40.490151337214876, 39.22885179519653, 38.958907331739155, 42.98623956952776, 52.17944628851754, 53.63235282897949, 52.502839769635884, 49.395320483616416, 52.689881801605225, 49.149461950574604, 49.32618243353707, 50.801076548440115, 48.72924184799194, 53.98781224659511, 51.23354632513863, 52.88675900868007, 50.15488713128226, 51.71561581747872, 53.4948445047651, 51.801526818956646, 55.118350165230886, 51.89199583871024, 52.36763824735369, 33.47511454990932, 0.650640498314585, 0.2760678620210716, 3.188198511089597, 1.0438437248979295, 42.275338104793, 61.4575252532959, 42.13181611469814, 41.43577337265015, 43.692642075674875, 45.93209859303066, 21.43338785852705, 0.680359463606562, 0.16020369210413524, 0.18037117778190545, 0.1560249613331897, 0.13374314696661063, 0.11590404063463211, 0.15357886973236287, 0.13915449088173254, 0.09800151163446051, 0.0896229747948902, 0.15662291353302343, 0.12145584129861423, 0.14527794372822556, 0.11461022363177367, 0.17660453489848546, 0.08221492623644215, 0.1637138216091054], [0.05512810006205525, 0.04219589774895992, 0.05018108444554465, 0.03727052400686911, 0.030186119688940898, 0.0685210581868887, 0.03541372310636299, 0.06368372097079243, 0.003125874275740768, 0.01069445743425084, 0.03586754768288561, 0.046856510519449196, 0.07568838287677083, 0.04160035095576729, 0.07210789607571703, 0.05567074487251895, 0.06503661801772458, 0.07781257746475083, 0.02358695611889873, 0.04923376474263413, 0.03123686509206891, 0.0786993820220232, 8.690252678734915, 38.009043421064106, 23.20814711706979, 28.529960019247874, 25.258834975106375, 47.28574316842215, 49.78002486910139, 37.54830837249756, 0.17077108791896276, 0.992780653493745, 1.0312407783099582, 0.08032503657575164, 0.06397164373525552, 26.422378574098857, 57.68597705023629, 54.402494634900776, 59.21205507005964, 52.233784675598145, 53.5508747782026, 53.61394705091204, 53.1847950390407, 51.710390772138325, 52.899811199733186, 52.91172041211809, 53.32945653370449, 53.3792473248073, 51.67120293208531, 50.85601942879813, 48.884197098868235, 41.60783856255667, 39.36202096939087, 42.72102682931082, 48.27985668182373, 47.77956553867885, 49.48350007193429, 51.390603406088694, 49.593441418239046, 46.93518223081316, 43.44172525405884, 40.501136439187185, 39.20382785797119, 39.33592006138393, 39.666376386369976, 38.06639385223389, 38.94952378954206, 37.24333803994315, 38.44667223521641, 40.7552216393607, 38.22505944115775, 38.714316844940186, 38.5639682497297, 37.29782928739275, 37.61050169808524, 38.98898260934012, 36.452059813908164, 38.14942829949515, 37.62537431716919, 37.130144936697825, 38.6834842136928, 38.92626469475882, 38.921227250780376, 38.79145574569702, 45.3565480368478, 52.30938802446638, 50.87628384998867, 52.46611854008266, 49.99297325951712, 87.21851348876953, 74.49117851257324, 48.719125270843506, 54.0204826763698, 46.65270669119698, 47.79441383906773, 47.34494529451643, 48.80427197047642, 46.850702558244976, 50.569531304495676, 47.55816466467721, 41.586952277592246, 37.29288911819458, 37.67049591881888, 35.64231327601841, 36.66005761282784, 35.74153355189732, 35.65727622168404, 35.44520330429077, 35.24539395741054, 34.22584308896746, 36.29856021063668, 35.41054916381836, 35.77293940952846, 35.61864423751831, 36.65277590070452, 34.6169467653547, 34.12076200757708, 34.79206568854195, 34.30983291353498, 34.630256039755686, 36.8809860093253, 36.61916399002075, 33.780915192195344, 35.05062552860805, 33.76075151988438, 34.93813419342041, 33.155761446271626, 38.053272179194856, 44.210025787353516, 47.63909033366612, 46.5906697000776, 43.448110648563926, 50.79836675098964, 46.11497170584542, 48.09016043799264, 47.58669049399239, 48.927064010075156, 46.633408069610596, 48.23564529418945, 50.831982135772705, 49.44416979381016, 49.21506684167044, 49.41310439790998, 49.813834803445, 49.44399956294468, 49.06267895017351, 46.31419392994472, 3.9813855375562395, 0.6044799781271389, 0.4744987242988178, 1.86440252832004, 1.6529977236475264, 49.77934047154018, 45.67444896697998, 28.608914136886597, 33.11757067271641, 21.570769378117152, 17.548921006066458, 0.4013603303049292, 0.0945191817092044, 0.023955015565401742, 0.02144941983611456, 0.06970738845744304, 0.05681952501514128, 0.0665303042956761, 0.07296538113483361, 0.02305099318203117, 0.06170359972332205, 0.043993710207619836, 0.08160775953105517, 0.020475795026868582, 0.011111061820494277, 0.0669400580227375, 0.05886514524796179, 0.02047422421830041, 0.007676004581818623, 0.011732785646537585, 0.08743837701955012, 0.037979671132883856, 0.1050688541893448, 0.033547375218144486, 0.031030563304999044, 0.04427186885316457, 0.037590287027082274, 0.006029578798916191, 0.022027385786974003, 0.020709758990311196, 0.0283805905907814, 0.048714437788086276, 0.0289599085226655, 0.02910733043349215, 0.05490840060104217, 0.06827272794076375, 0.09444532317242452, 0.05891451545591865, 0.0431873154427324, 0.04406728715236698, 0.12371613644063473, 16.143901450293406, 50.772686208997456, 23.76684829166957, 38.547570501055034, 36.82751267296927, 53.392771993364605, 56.37069347926548, 41.95192377907889, 0.0992875254846045, 1.4109245474849428, 3.754240240369524, 0.8138040144528661, 0.05055334911282573, 31.12651572908674, 57.76518651417324, 53.94048111779349, 60.63139833722796, 55.01835169110979, 57.227597440992085, 54.45010369164603, 57.23458732877459, 55.203243255615234, 55.788903440747944, 55.7551977293832, 55.932081495012554, 55.861671924591064, 53.86184140614101, 53.61658041817801, 49.95017235619681, 42.18586267743792, 42.83253499439785, 43.95531177520752, 46.225194454193115, 48.89437273570469, 50.93884890420096, 51.91159323283604, 49.811184065682546, 47.589316913059776, 43.61272389548165, 41.632348333086284, 40.40733575820923, 42.79656764439174, 40.52164057322911, 39.73607724053519, 40.52949898583548, 40.88582692827497, 40.34028216770717, 40.85671050207955, 40.22350031988961, 41.28241968154907, 40.933574948992046, 37.945158209119526, 38.68997035707746, 40.5689925466265, 39.53164039339338, 41.13864060810634, 39.83581863130842, 38.888914653233115, 40.23151159286499, 39.844566413334434, 43.174785886492046, 41.65613201686314, 48.966019085475374, 51.40120983123779, 51.98407336643764, 55.23957538604736, 56.72570473807198, 81.49455274854387, 57.196931566510884, 53.504961081913535, 55.84490244729178, 49.578547954559326, 48.40376738139561, 47.15851470402309, 47.93649755205427, 45.461205278124126, 50.999788079942974, 50.09231512887137, 42.19645868028913, 37.89459269387381, 38.5741925239563, 37.328755719321116, 38.45576395307268, 38.74168232509068, 38.30327878679548, 37.66151884623936, 37.525445325034006, 36.798389298575266, 38.86891426358904, 37.9479409626552, 38.173142501286094, 38.600248268672395, 38.84115621021816, 37.039102690560476, 37.513070583343506, 36.16054466792515, 37.355784211839946, 37.55563872201102, 37.67757960728237, 38.3961067199707, 36.389849117824006, 36.8829801423209, 34.72169780731201, 37.601222378867014, 36.63871969495501, 39.55400317055838, 47.837294646671836, 49.94896684374128, 49.246740204947336, 46.76352003642491, 51.84192711966378, 47.43762731552124, 51.5267915725708, 49.907902990068706, 51.46412229537964, 49.14142983300345, 49.31543704441616, 53.91367496762957, 52.628261702401296, 51.108496120997835, 51.572086879185264, 52.33653463636126, 51.22244657788958, 50.81235000065395, 47.15334871837071, 5.400972860200064, 0.7691724236522401, 1.3269232149635042, 1.8665547328335899, 2.1059017181396484, 54.246062891823904, 51.94394751957485, 34.28233194351196, 41.697855949401855, 26.526327099118912, 26.97959109715053, 1.339335737483842, 0.023878313966893723, 0.05521722902942981, 0.036143365382616005, 0.015055053401738405, 0.03633026446082762, 0.04498847307903426, 0.0668470783691321, 0.04552925870354686, 0.08295848526592765, 0.01975463274201112, 0.03015868312546185, 0.029961300681212118, 0.07735502773097583, 0.054780523891427686, 0.02761732690435435, 0.03296331263014248, 0.027154068994734968, 0.18702240873660358, 0.16341572760471276, 0.13695333685193742, 0.17133174783417157, 0.08475269470363855, 0.09919106494635344, 0.12972263699131353, 0.12465482178543295, 0.09732721067432847, 0.08914326410740614, 0.09857203744884048, 0.13078626777444566, 0.10607249569147825, 0.08401810590709959, 0.1669755665851491, 0.227156967989036, 0.1587275391710656, 0.2623796122414725, 0.16030334175697394, 0.21188919725162642, 0.1473339455468314, 0.15880357580525534, 22.99390983581543, 59.536174637930735, 31.62945760999407, 41.839842387608115, 35.40491417476109, 59.495777811322895, 59.8047433580671, 49.33729607718331, 0.31889495679310387, 6.358808525971003, 4.288757341248648, 1.0638637649161475, 0.28315752159271923, 31.944297858646937, 59.82248905726841, 57.05691146850586, 62.040618079049246, 58.461719104221885, 57.46221031461443, 57.59863471984863, 59.350984300885884, 55.82956082480294, 57.949963433401926, 57.24926192419869, 56.934487683432444, 57.73907518386841, 58.38361440386091, 55.15428624834333, 54.09087487629482, 44.37241561072213, 44.59228440693447, 47.31032242093767, 49.05976070676531, 50.48086534227644, 53.0941036769322, 56.47903673989432, 54.543751512254985, 51.81234169006348, 47.72689471926008, 43.825821672167095, 41.701611450740266, 43.91492884499686, 42.16493122918265, 40.62136459350586, 42.59541729518345, 41.24649402073452, 43.30617979594639, 45.64826120649065, 40.48932450158255, 43.152249404362266, 44.349792276109966, 41.46084247316633, 42.06017323902675, 42.21246385574341, 40.5278765814645, 44.36208363941738, 41.47642033440726, 40.97093888691494, 42.28044850485665, 42.56137459618704, 44.92311246054513, 41.161778109414236, 48.955558572496685, 53.5703193119594, 54.141395228249685, 56.67844309125628, 56.86102785382952, 83.88299601418632, 57.11220175879342, 53.350968156542095, 56.65020213808332, 50.979930128370015, 50.56024156297956, 50.22276060921805, 50.590073653629844, 49.88826390675136, 53.54014675957816, 52.73484359468733, 44.31150075367519, 40.82267822538103, 41.4667067527771, 38.57436275482178, 41.24130719048636, 40.95088638578142, 40.498847007751465, 40.08139228820801, 39.66536889757429, 39.43497358049665, 40.84142099108015, 40.5050448008946, 39.676479067121235, 40.551087038857595, 41.55877733230591, 38.57796539579119, 39.36070775985718, 38.784128870282856, 37.192828110286165, 39.067990575517925, 39.12433699199131, 39.595570768628804, 37.273170130593435, 38.72846337727138, 36.867530822753906, 39.14303459439959, 36.66678694316319, 41.773428031376426, 49.47164297103882, 51.01804794584002, 51.29724046162197, 50.161411489759175, 53.209402084350586, 50.31450809751238, 53.049058505467, 53.67743274143764, 53.37796885626656, 50.58263908113752, 51.108874797821045, 56.16192443030221, 54.23919807161604, 52.977450370788574, 51.096003259931294, 54.07138865334647, 53.93889345441546, 52.281112330300466, 47.73483651024954, 6.177913044180189, 0.8702286524432046, 1.6260681343930108, 6.805004468985966, 2.18761014512607, 60.67046805790493, 55.48370034354073, 38.459880760737825, 45.80012450899397, 34.30446890422276, 40.75848729269845, 3.783975056239537, 0.32061238320810453, 0.15642932749220304, 0.05958265531808138, 0.1570871536220823, 0.15406622072415693, 0.16713502231453145, 0.26217491179704666, 0.14250874732221874, 0.18786372430622578, 0.10836733505129814, 0.13429352029093675, 0.08575230570776121, 0.09884358037795339, 0.19839731550642423, 0.08996895301554884, 0.054363211284258535, 0.08382750542036124], [0.028134150064683387, 0.02573633792677096, 0.020673733869833604, 0.06393762877477066, 0.047872314761791906, 0.07598159142902919, 0.09648886708808796, 0.026164612267166376, 0.04950409648673875, 0.07071556935885123, 0.025983540108427405, 0.0493844877263265, 0.029439490288496017, 0.06659251238618578, 0.07340859342366457, 0.01936487035293664, 0.01608913907382105, 0.04935491377753871, 0.15109725003795965, 0.07259458888854299, 0.0539327384904027, 0.030657287620540177, 0.589957808809621, 22.833925826208933, 33.69134596415928, 22.303905078342982, 19.353413343429565, 33.16848012379238, 40.7669015611921, 51.372954981667654, 6.701189262526376, 2.31518406527383, 3.706014096736908, 0.15530107303389482, 0.09972874288048063, 5.300996533461979, 48.47127260480608, 53.4953065599714, 59.39250673566546, 54.70729126249041, 54.756484508514404, 54.424530846732004, 54.94482932771955, 53.405275276729036, 53.59277588980538, 52.968601839882986, 54.568747656685964, 53.741714000701904, 53.29234273093087, 51.20656647000994, 52.09871864318848, 42.45814173562186, 43.831918716430664, 48.822976521083284, 50.96828842163086, 52.95362152372088, 53.98147896357945, 52.042910712105886, 53.454444204057964, 51.1292017527989, 49.123048373631065, 43.40642493111746, 39.12145001547677, 42.06623901639666, 40.87832982199532, 40.07746308190482, 38.18896007537842, 36.7335695539202, 39.14346538271223, 39.4906564440046, 40.5832849911281, 37.08607598713466, 38.74230071476528, 37.54860714503697, 38.27787964684622, 40.396715436662944, 40.613641670772004, 38.869074072156636, 41.19021708624703, 38.40869338171822, 38.544902392796104, 37.69526277269636, 40.68149083001273, 42.4871643611363, 47.49159744807652, 52.12327010290963, 53.40746395928519, 53.092015743255615, 50.17641265051705, 50.146069867270334, 82.44018868037632, 68.14064311981201, 48.73421328408377, 52.19779995509556, 47.74225371224539, 51.92326968056815, 50.536780970437185, 51.568873337336946, 50.29031447001866, 51.58724784851074, 46.60069247654506, 38.46760368347168, 36.88803495679583, 39.185342175619944, 35.699743611471995, 37.20629371915545, 35.69999722072056, 36.009546416146414, 34.98175498417446, 37.16239152635847, 34.39709881373814, 36.30773878097534, 36.55780792236328, 35.020915031433105, 36.338870184762136, 36.0244711467198, 34.9890992300851, 34.44028534208025, 35.61376312800816, 36.095103059496196, 35.642320224217, 36.297858442579, 35.75565576553345, 35.788444314684185, 33.870150906699045, 35.598108836582725, 35.32659755434309, 39.623182909829275, 47.262181827000205, 47.98285245895386, 44.59612676075527, 47.97047076906477, 43.847611222948345, 47.84464584078108, 47.33922692707607, 48.18883875438145, 46.75498417445591, 50.994712420872276, 45.99791540418352, 48.72541339056832, 47.000509193965364, 49.414528778621126, 47.34344448362078, 51.647825717926025, 47.508915833064485, 55.779248918805806, 20.742830719266617, 0.09720707604927675, 0.6100420110992023, 0.8687810929758208, 1.2808321224791663, 11.098025832857404, 55.576608180999756, 33.38128955023629, 34.02707944597517, 30.54062625340053, 29.130663054330007, 13.231874942779541, 0.17953276634216309, 0.049794105746384175, 0.009147081224779998, 0.05706238626901593, 0.019226608664861748, 0.05609368932034288, 0.04666610002251608, 0.03741043792771442, 0.01708405970462731, 0.02575228689238429, 0.07944716832467488, 0.0278977857836123, 0.06337755918502808, 0.049544245403792174, 0.020648578880354762, 0.03275383869186044, 0.03101280943623611, 0.02466597268357873, 0.013521167316607066, 0.02892720652744174, 0.0746891518522586, 0.03781265652339373, 0.03107256122997829, 0.06621049717068672, 0.03173506246613605, 0.00974509194825909, 0.008561349440632122, 0.01435388924021806, 0.08768490236252546, 0.02644273528962263, 0.002798472223470786, 0.14766581702445233, 0.06797086128166743, 0.00695396529044956, 0.04582232137077621, 0.09972480059202228, 0.0377899289929441, 0.07600363024643489, 0.10264528316578694, 0.044738042767026594, 1.2284531274012156, 38.294913155691965, 37.23674419948033, 24.740096364702495, 26.2891503402165, 42.07368401118687, 47.028892585209434, 53.69113111495972, 7.257087707519531, 2.0443356846060072, 3.755168693406241, 1.5540876196963447, 0.21409569813736848, 6.00438916683197, 51.9518962587629, 55.78444617135184, 61.42653628758022, 56.2824444089617, 58.2416592325483, 55.45984370367867, 57.52714123044695, 54.78256457192557, 58.23292187282017, 55.383750506809776, 54.92321695600237, 54.53077227728707, 56.964406626565115, 53.49037333897182, 53.0094051361084, 43.930920124053955, 44.677920954568044, 49.022101470402305, 51.50335529872349, 53.729485171181814, 56.0271189553397, 53.53649548121861, 54.48044647489275, 51.734108448028564, 50.30454090663365, 44.67328998020717, 42.31068011692592, 43.61439841134207, 40.67667920248849, 41.75173575537545, 40.104411670139854, 39.35935286113194, 39.423707076481406, 41.45957442692348, 43.36179665156773, 40.20107848303658, 40.656862940107075, 39.670038087027415, 39.33403362546648, 40.84537104197911, 42.832677432468955, 41.20348814555577, 41.719346727643696, 40.51808656964983, 42.46194240025112, 39.76638180868966, 43.396693978990825, 45.02346529279436, 49.749834946223665, 54.72993196759905, 52.4152820450919, 55.15372691835676, 51.93113851547241, 61.370999336242676, 71.77770546504429, 58.23178931644985, 51.3375643321446, 51.68653065817696, 50.82742411749703, 52.914860997881206, 50.74594954081944, 50.847202164786204, 50.01327589579991, 51.95118406840733, 46.67081022262573, 40.15429278782436, 37.718375955309185, 40.54300280979702, 37.041847229003906, 38.753358772822786, 38.26297576086861, 37.5225305557251, 37.437786851610454, 39.33743476867676, 35.82540873118809, 39.1794570514134, 38.61706290926252, 37.765265873500276, 37.559616565704346, 37.606985909598215, 37.32117870875767, 36.4143762588501, 37.79334701810564, 37.72510528564453, 37.16081428527832, 37.11939607347761, 38.6530476297651, 36.502965790884836, 36.532641547066824, 36.66035985946655, 37.959450653621126, 42.78894894463675, 49.30651208332607, 50.70254414422171, 48.006886277879985, 51.43539844240461, 45.878038133893696, 47.80413784299578, 48.17844772338867, 49.522910254342214, 49.17075817925589, 52.266687870025635, 48.200240748269216, 50.62641968045916, 49.411666120801655, 51.25012125287737, 49.584103039332796, 52.81328528267996, 48.48963321958269, 56.51013340268816, 21.873090709958756, 0.18619011768272944, 1.2881253425564085, 1.012672803231648, 1.4383671092135566, 12.066643800054278, 65.09360790252686, 36.91006422042847, 42.19309227807181, 40.527883529663086, 32.855185849326, 22.054525545665197, 0.2396720578627927, 0.06383895621235881, 0.044183815363794565, 0.028394795721396804, 0.04982854139858058, 0.07991837696837527, 0.06713964909847293, 0.0156358556289758, 0.07414266653358936, 0.04627630540302821, 0.02695406401263816, 0.043250083324632475, 0.03083847343389477, 0.02410410836871181, 0.05030697304755449, 0.044486764286245616, 0.031392632983624935, 0.02423392908115472, 0.10665219529931035, 0.11794700101017952, 0.14114087500742503, 0.09638215388570513, 0.17779701948165894, 0.15351628166224274, 0.16738738305866718, 0.13091900279479368, 0.08016813892338957, 0.11624759648527418, 0.14721277276320116, 0.15415638445743493, 0.09882217259811503, 0.22202600831432, 0.2009943268660988, 0.11045387773109333, 0.11008217624787774, 0.25475485995411873, 0.21773157375199453, 0.1986161701913391, 0.1632024504776512, 0.2138445180441652, 2.3367482338632857, 50.87338992527553, 47.45901387078421, 35.655469690050396, 32.219425678253174, 45.49745055607387, 50.0228922026498, 61.89456694466727, 8.764071209090096, 5.064538478851318, 11.99256123815264, 1.5020512576614107, 0.23171620762773923, 6.903729251452854, 53.19842740467617, 57.158959661211284, 64.57417447226388, 59.09501961299351, 62.61267021724156, 56.42793621335711, 59.786775316510884, 57.10535430908203, 60.44966125488281, 57.381117888859336, 57.33002083642142, 56.104890142168315, 59.00272669110979, 57.93808201381138, 58.03248371396746, 47.25404896054949, 47.63344144821167, 53.3706419808524, 55.19023275375366, 56.8944000516619, 58.23210545948574, 55.009496212005615, 57.39520883560181, 55.91004180908203, 53.889206886291504, 47.34614733287266, 43.46901430402483, 45.75733402797154, 43.223475388118196, 44.46257543563843, 42.097339153289795, 40.41362040383475, 41.40687928880964, 44.71677875518799, 45.80692332131522, 42.68506990160261, 44.23333351952689, 42.653045654296875, 43.670671871730256, 43.396846839359824, 43.58941616330828, 44.08843926021031, 45.132527691977366, 41.73826667240688, 45.55295276641846, 41.68950768879482, 43.230524335588726, 47.47627319608416, 50.35539129802159, 57.9731183052063, 54.55956561224801, 55.91741732188633, 53.54546907969883, 68.55543667929513, 70.98341519492013, 57.13076039722988, 54.70727389199393, 52.38850368772234, 53.38686602456229, 55.49590138026646, 54.153929778507774, 54.74391174316406, 55.05955450875418, 54.65029518944876, 51.181591170174734, 41.692015988486155, 40.713542870112825, 42.997801371983115, 39.00392123631069, 40.6105705669948, 39.427229813167024, 39.847748688289094, 39.220381941114155, 40.918334075382774, 39.181534562792095, 40.87741960797991, 41.36510671888079, 39.44525344031197, 41.54338707242693, 40.02446917125157, 39.23509822572981, 37.81275333677019, 39.05354527064732, 39.77806173052107, 39.30455936704363, 38.78564705167498, 39.67415836879185, 38.58146728788103, 38.01549482345581, 38.02115413120815, 40.61943646839687, 46.01305900301252, 51.85599027361189, 52.94053111757551, 49.06233501434326, 52.26123353413173, 48.58448307854788, 50.59787648064749, 50.34224878038679, 52.49931355885097, 51.31910296848842, 54.24382209777832, 49.872331687382285, 52.422695772988455, 51.97577026912144, 53.78818702697754, 51.805626256125315, 54.12537963049752, 50.48588194165911, 58.42995194026402, 23.096927302224294, 0.30952707518424305, 1.340077349117824, 3.9101643306868414, 4.211973667144775, 12.750741720199585, 69.41115597316197, 40.43506949288504, 45.79966940198626, 43.16787242889404, 43.161365440913606, 34.44974531446184, 0.41783958460603443, 0.21768943672733648, 0.23406301598463738, 0.16072382990803036, 0.1284174206001418, 0.07568178073103939, 0.1105636375557099, 0.12753512151539326, 0.13268727862409183, 0.09513157991958515, 0.16916243066745146, 0.17224439100495406, 0.15960185868399485, 0.1393277073012931, 0.20283152828259127, 0.12912140068198952, 0.11356507614254951, 0.10589179503066198], [0.029855781700462103, 0.07786991367382662, 0.03689652568261538, 0.02047451938103352, 0.037064734513738325, 0.03016817243769765, 0.10033998758132968, 0.02303817735186645, 0.06378251566950764, 0.08284685268465962, 0.09970025119504758, 0.03585478104650974, 0.02016270030955119, 0.03400247883317726, 0.024874805406268154, 0.031418576770062955, 0.011529014795087278, 0.09451033361256123, 0.07321421349687235, 0.09998446915830884, 0.03113604157364794, 0.03262139544157045, 0.07609487963574273, 5.355227657726832, 25.34393651144845, 25.309584617614746, 27.448587553841726, 29.6248710496085, 35.86111204964774, 56.004783970969065, 30.88544797897339, 0.6854398995637894, 3.1875078167234148, 2.095971005303519, 0.18407023857746804, 0.17944737949541636, 19.3634170123509, 53.68820244925362, 57.9715792792184, 57.07426806858608, 54.34154503686087, 54.739454473767964, 55.57092802865164, 53.58157191957746, 54.227952412196565, 53.864947250911165, 51.08538293838501, 54.26457984106881, 52.157938139779226, 51.955047266823904, 50.428211893354145, 46.847805159432546, 48.519347190856934, 53.46203858511788, 53.10219138009207, 54.78036546707153, 52.99205895832607, 55.22914613996233, 53.482254368918284, 52.923931871141704, 48.819874150412424, 45.23984261921474, 39.55278376170567, 39.340318271092, 39.98996441704886, 40.3478661264692, 39.523959159851074, 39.789713859558105, 39.78938382012503, 38.948752539498464, 39.24375915527344, 39.97958728245327, 37.854241030556814, 36.77211121150425, 37.659361430576865, 39.70798567363194, 41.84261819294521, 39.484608037131174, 39.942831311907085, 39.145810399736675, 39.75852687018258, 40.6662186895098, 42.35109083993094, 41.97680875233242, 49.59652641841343, 53.13074847630092, 53.47704321997506, 52.711515017918174, 52.76044075829642, 30.984352111816406, 44.147630964006694, 84.21685695648193, 53.0573650768825, 51.865867137908936, 52.13286209106445, 51.923217569078716, 51.81632648195539, 51.724975040980745, 52.984103270939414, 51.38936315264021, 46.803871699741904, 40.06753063201904, 36.45105232511248, 37.15159055164882, 37.04518583842686, 34.8592825617109, 35.8818941116333, 36.301155362810405, 37.192390373774934, 35.791737760816304, 34.74763543265206, 36.33133486339024, 35.94873578207833, 36.448057651519775, 34.50564357212612, 36.104535239083425, 35.33521679469517, 35.38211713518415, 36.02347755432129, 37.82090357371739, 35.52689674922398, 36.33502088274275, 35.13232939583914, 36.29103183746338, 35.4523286819458, 37.209514209202354, 34.35736206599644, 41.265632833753315, 45.87780884334019, 48.850463594709126, 48.26696082523891, 49.77711704799107, 47.61049154826573, 45.60486970629011, 47.65035336358206, 50.848334721156526, 47.666118826184956, 48.15774556568691, 47.319351605006624, 51.5426994732448, 46.872620650700156, 49.15105308805193, 45.85847895486014, 51.804295676095144, 47.678688117435996, 43.30437673841204, 2.4826002589293887, 0.13249639315264566, 1.255277299455234, 0.5885873309203556, 0.1590181014367512, 21.80460752759661, 56.36404405321394, 27.241060495376587, 26.797881807599747, 25.350620678492955, 30.81218617303031, 6.286864706448146, 0.20532742435378687, 0.047059881035238504, 0.0033462331879750957, 0.12881983257830143, 0.04538916497092162, 0.012045900719905538, 0.07107436510601214, 0.05417922990662711, 0.030272761825472116, 0.04209082320864711, 0.060280515014060905, 0.03840424745742764, 0.02848848614043423, 0.09794418899608509, 0.0245884229162974, 0.0083739898067766, 0.05851370482040303, 0.0056704297894611955, 0.024346542145524706, 0.009336244065447577, 0.07118742261081934, 0.06126466899045876, 0.05630825227126479, 0.060216047401939116, 0.0483847952980016, 0.042230587851788313, 0.04367406593103494, 0.030108176371348754, 0.062206400957490714, 0.012381853585663651, 0.019791210868528912, 0.019510743507583226, 0.023874156243566955, 0.0388904347616647, 0.011164348871846284, 0.08630753734282084, 0.06981678865849972, 0.028079412644729018, 0.041277537920645306, 0.04142353830060788, 0.1272357925772667, 11.038252217429024, 42.96912268229893, 26.23570305960519, 26.405379806246074, 34.16195787702288, 41.30917372022356, 59.10323238372803, 31.957204137529644, 0.33789358447705, 4.452920692307608, 4.283065029553004, 0.23773391757692608, 0.03881340407367263, 23.611496993473597, 55.229243414742605, 57.86078330448696, 59.33956841060093, 55.89028113228934, 55.67290326527187, 55.63802330834525, 56.51465320587158, 57.79688419614519, 55.80016647066389, 53.96666887828282, 55.49780171258109, 55.390799454280305, 53.35925040926252, 52.84432635988508, 48.11166511263166, 47.8716847555978, 54.358689716884065, 54.99257387433733, 53.449010712759836, 56.2620062828064, 56.6535233770098, 55.3285505431039, 53.80703748975481, 51.56409297670637, 46.79517950330462, 41.980220317840576, 41.412139075142996, 40.93093810762678, 40.65203741618565, 40.09052569525582, 40.50168187277657, 41.97004120690482, 41.230412415095735, 41.475656032562256, 41.61951501028878, 39.51899119785854, 39.4987337248666, 39.21469831466675, 39.959586892809185, 42.803418568202424, 40.681841714041575, 42.08495398930141, 41.606872762952534, 43.45115048544747, 41.39157588141305, 42.52559832164219, 44.54835442134312, 52.176767757960725, 55.3980255808149, 55.88030004501343, 52.798245906829834, 54.60794244493757, 34.81252465929304, 58.746046338762554, 76.35877091544015, 49.50507075445992, 57.7444600377764, 50.87146527426583, 54.78073024749756, 52.07033525194441, 52.2030736378261, 52.34875304358346, 49.65817083631243, 49.22889028276716, 40.72961752755301, 39.109064851488384, 39.54357392447335, 37.699417795453755, 36.3253698348999, 39.010324001312256, 37.959690366472515, 36.35985027040754, 39.0998341696603, 36.87921074458531, 37.60669755935669, 38.063614572797505, 38.32969583783831, 35.59827559334891, 37.81337867464338, 36.21164519446236, 38.02006673812866, 36.98066486631121, 39.916310037885395, 37.99301045281546, 38.607992036002024, 36.01918356759207, 37.84773404257638, 36.087494782039094, 37.680713244846885, 36.375202315194265, 42.70169694083077, 48.19216346740723, 49.806751114981516, 51.009522506168906, 52.187478406088694, 51.00964757374355, 49.72117362703596, 49.83398110525948, 51.27609709330967, 49.810315540858674, 51.105254786355154, 49.00232342311314, 52.54280580793108, 48.8236539704459, 52.15302228927612, 48.90356520244053, 54.339071478162495, 49.17492709841047, 44.817593642643516, 2.747200906276703, 0.7813699319958687, 3.045039781502315, 1.37343630194664, 0.4720127891216959, 24.925528151648386, 61.2296382359096, 32.955587318965364, 38.52673980167934, 28.319202048437937, 35.20957251957485, 10.097635490553719, 0.17516747915319034, 0.05340610371370401, 0.03129062542159643, 0.04947077363197293, 0.05435309432713049, 0.03175844478287867, 0.038111178004848104, 0.038424474586333544, 0.010242609939138805, 0.019439517686675702, 0.02112544989878578, 0.03293061402759381, 0.046296630919511826, 0.07961139415523835, 0.018563384788909128, 0.01366627203034503, 0.0333809950388968, 0.10935451529387917, 0.10892061929085425, 0.14016235965703214, 0.12204665531005178, 0.16224306981478417, 0.159597353211471, 0.15030583393360886, 0.18089032492467336, 0.10054168211562292, 0.15582401997276715, 0.168525883395757, 0.14885627957327024, 0.12962541649384157, 0.06887960287609271, 0.17977007717958518, 0.10048816605870213, 0.197134724685124, 0.15201305518192904, 0.2625514987323965, 0.20013573579490185, 0.31831809346164974, 0.09986808004656009, 0.0972487245287214, 0.190160103940538, 18.188009364264353, 54.790923254830496, 35.8519994871957, 41.57819059916905, 42.28481544767107, 47.20643990380423, 65.3207653590611, 38.55946929114205, 1.2224771337849754, 13.012162481035505, 5.497670939990452, 0.4060771257749626, 0.3057181052863598, 25.233986479895457, 57.02755185535976, 61.18347440447126, 60.69579424176897, 59.49599320547921, 58.67962850843157, 61.76604611533028, 58.01381390435355, 60.57418687002999, 58.37076023646763, 54.44793585368565, 58.2986935206822, 57.49369260243007, 56.619341714041575, 54.84186397280012, 51.321298599243164, 51.86587756020682, 56.98741211209978, 57.44353008270264, 56.842312880924766, 55.984529972076416, 59.796370778764995, 59.08387470245361, 56.66688476290022, 53.919598306928364, 49.65180281230381, 44.76455109460013, 42.46654210771833, 43.9344220161438, 43.94050516401018, 41.65306091308594, 44.34678370612008, 44.62294680731637, 43.56928028379168, 42.73150471278599, 44.26415572847639, 42.48905427115304, 42.23074804033552, 42.946891920907156, 43.02576092311314, 45.68776518957955, 42.48798772266933, 43.72481223515102, 43.0370135307312, 45.07710191181728, 43.97816440037319, 45.712792600904194, 46.16614171436855, 51.72213670185634, 59.364936283656526, 56.341934885297505, 54.126286370413645, 54.349789074489046, 45.330853598458425, 65.85290009634835, 72.62047331673759, 51.57951102937971, 58.304453577314106, 52.92876434326172, 57.06968573161534, 54.61241013663155, 55.57012551171439, 56.11606631960188, 52.19158479145595, 49.60712242126465, 44.645601408822195, 40.64895241601126, 41.62437180110386, 41.61731243133545, 38.605025155203684, 40.13889210564749, 40.21616302217756, 40.64868491036551, 40.90368032455444, 38.68307426997593, 40.92074857439314, 40.90634148461478, 39.53244638442993, 36.86610296794346, 40.24990694863455, 39.5969569342477, 40.239592347826274, 39.27480023247855, 40.910044874463765, 40.321185043879915, 40.609799316951204, 37.96713883536202, 39.20967476708548, 40.10615219388689, 39.88268423080444, 37.510555335453574, 44.52526208332607, 49.028636251177105, 51.683393546513145, 53.12072917393276, 51.43982444490705, 51.753077030181885, 52.79923949922834, 50.30395725795201, 56.50575603757586, 51.361250741141184, 55.117380891527446, 52.09559890202114, 53.613540581294465, 48.430389404296875, 54.9061348097665, 48.52118846348354, 56.62568541935512, 48.94218329020909, 48.00116443634033, 3.4261128646986823, 0.7618367001414299, 4.316773346492222, 3.054284793989999, 2.117485667978014, 26.726871218000138, 68.3048151561192, 37.27898924691336, 39.89467682157244, 36.478476864951, 45.851735728127615, 16.845815420150757, 0.4283056615718773, 0.07238988165876695, 0.0688909547669547, 0.20406312362423965, 0.28225387579628397, 0.12730370036193303, 0.11969886986272675, 0.11638615333608218, 0.09240450696753603, 0.11470079448606287, 0.12628707848489285, 0.24156796612909862, 0.13047457592827932, 0.1925714002656085, 0.1337009420884507, 0.06567562158618655, 0.10270180513284036, 0.19032235523419722], [0.04559237942365663, 0.06473638662802321, 0.0229378203262708, 0.06106962409934827, 0.052374540495553186, 0.06004068681171962, 0.018919568176248243, 0.062155239417084625, 0.045511626971087286, 0.03352983508791242, 0.022065414282094156, 0.023196545728881444, 0.03991560957261494, 0.0377108626998961, 0.052085677960089276, 0.02342065397117819, 0.009493256220594049, 0.030144885115857636, 0.03945008026702063, 0.021036512617553984, 0.01753942116296717, 0.03903993298964841, 0.047263774022992165, 0.3101733390774046, 7.765083534376962, 28.318880694253103, 27.527376651763916, 30.225160666874476, 27.46567143712725, 46.67372499193464, 47.2610319001334, 0.45553942450455254, 3.059859420572008, 1.3011833961520876, 0.41171553464872496, 0.0768999003672174, 2.529817828110286, 37.73699712753296, 54.43080507005964, 54.34243440628052, 55.505295344761436, 57.8168637411935, 55.08269895826067, 55.60500199454171, 52.910118852342876, 52.29311534336635, 49.519575119018555, 52.4139757837568, 54.137844698769705, 55.234447615487234, 49.86674880981445, 51.34969936098371, 53.97480869293213, 51.32815647125244, 52.63197204044887, 52.31181294577462, 54.08609104156494, 54.4009347643171, 55.28301899773734, 51.086039543151855, 48.42949308667864, 44.61078745978219, 40.01540524618966, 40.718010561806814, 40.32216126578194, 37.63001571382795, 40.15670381273542, 40.216037954602925, 39.56808369500296, 39.284916809626985, 37.79186357770647, 39.31982455934797, 37.107591084071565, 37.884357997349326, 38.64914274215698, 38.388192721775596, 41.966945784432546, 43.68364415849958, 47.462911810193745, 49.398287364414756, 45.274910177503315, 42.08659029006958, 40.80958434513637, 40.96526568276541, 48.554310526166645, 53.756326062338694, 51.24809237888881, 52.440583910260884, 51.42502130780901, 36.91433041436331, 17.352127177374705, 53.37294183458601, 67.18912206377301, 48.056871618543354, 54.80600779397147, 50.36797101157052, 50.97467729023525, 50.96893113000052, 52.14046342032296, 49.041841302599224, 44.984836782727925, 34.82020589283535, 37.733564717429026, 36.611687728336875, 36.11956071853638, 36.48927436556135, 36.89384365081787, 34.79082196099417, 35.445797375270296, 35.07573979241507, 37.3710355077471, 35.97040721348354, 35.345520973205566, 35.19876112256731, 34.24607276916504, 35.49669292994908, 36.788918903895784, 36.28652593067714, 37.011754580906455, 34.68198537826538, 35.223632199423655, 35.87652662822178, 35.18621962411063, 34.49303259168352, 34.77684218542916, 34.40856681551252, 36.58741072246006, 38.144074712480815, 45.11277743748256, 49.21581377301897, 52.17689282553536, 49.45317118508475, 50.983762059892925, 47.84565680367606, 48.665915966033936, 46.83251217433384, 50.237806933266775, 49.24070569447109, 49.88797903060913, 45.85577957970755, 51.6008836882455, 45.820232595716206, 53.42659929820469, 49.288328647613525, 50.993239402770996, 16.019763197217667, 0.06185168320579188, 0.7840359775083405, 0.35358747520617073, 0.39096452242561747, 0.3031474346561091, 40.30915771211897, 47.31318507875715, 21.398377622876847, 22.43632558413914, 29.818385328565324, 35.679489612579346, 1.4842578981603896, 0.09036320221743413, 0.09760726921792541, 0.0509938506542572, 0.02149656444921025, 0.06755776237696409, 0.03250937270266669, 0.03865368710830808, 0.05974743076200996, 0.05657886221472706, 0.05972576513886452, 0.014783844651122178, 0.024637760893840874, 0.06318988318422011, 0.028860676168863262, 0.03805582651070186, 0.04698522182713662, 0.03487981782693948, 0.07037444944892611, 0.02106239872851542, 0.04023285522790892, 0.03830536115648491, 0.030072281868862252, 0.02794292362939034, 0.028074939402618578, 0.03506297478452325, 0.07162488770804235, 0.0502028993463942, 0.010679849423468113, 0.034850749386740584, 0.05587574387235301, 0.0480091718823782, 0.05533346886347447, 0.05888904325131859, 0.030412272017981325, 0.04616990771942905, 0.05640231758090002, 0.04491753563550966, 0.02530027400436146, 0.050736183766275644, 0.050762134338063855, 0.05116338602134159, 0.3575480298272201, 24.15599431310381, 36.28480625152588, 34.70647777829851, 38.3360082762582, 32.99412202835083, 49.85265786307198, 49.34071806498936, 0.6894852167793682, 1.3330754105533873, 3.223652562924794, 1.0926268100738525, 0.09358217234590224, 3.3024907324995314, 42.5814653124128, 53.114489691598074, 55.23410715375628, 58.76734256744385, 60.103369985307964, 56.35860013961792, 57.40975488935198, 54.91777651650565, 54.08140448161534, 51.25031232833862, 54.649739333561485, 56.558610984257285, 57.14661966051374, 51.63348463603428, 52.19853299004691, 53.862161023276194, 53.53146498543875, 55.062361580984934, 53.537718364170615, 55.369763783046174, 56.969645568302695, 55.58724934714181, 53.90160942077637, 50.454621996198384, 46.61709369931902, 42.78064584732056, 41.779243673597065, 41.626980849674766, 40.54952369417463, 42.51032618113926, 41.038253034864155, 40.111290386744905, 41.08775894982474, 40.801972593579976, 41.16960525512695, 40.39754574639456, 40.00276299885341, 40.71654101780483, 39.68076957975115, 42.36923606055123, 45.003402369362966, 47.402729988098145, 47.21045248849051, 48.3841734613691, 44.06865079062325, 41.392270701272146, 42.693821157727925, 51.49430874415806, 54.9111270904541, 55.03212649481637, 52.57821382795061, 52.48882525307791, 35.87875005177089, 22.717566081455775, 62.162274088178364, 60.19789327893938, 51.31466654368809, 54.90901483808245, 52.51826477050781, 53.35944495882307, 51.61964382444109, 52.16285399028233, 49.64306197847639, 48.052035672324045, 38.87289210728237, 38.871801240103586, 37.71702453068325, 38.884196826389854, 37.54549087796892, 38.84981019156319, 38.16801473072597, 38.01758623123169, 37.424307346343994, 39.21047728402274, 36.91038383756365, 38.628315516880576, 36.812785966055735, 35.54931511197771, 38.16125413349697, 37.894099371773855, 37.80977603367397, 39.10344723292759, 37.02744361332485, 37.489196572984966, 37.027429716927664, 36.98385756356375, 36.77947282791138, 37.24253552300589, 38.21459545407976, 37.62809106281826, 40.50460359028408, 48.89499807357788, 50.66124405179705, 52.67651694161551, 50.39213684626988, 53.23648616245815, 51.36996030807495, 50.44180256979806, 48.22905492782593, 50.09812729699271, 49.420754364558626, 51.003717286246165, 48.75430052621024, 53.264549936567036, 49.181086676461355, 55.212341921670095, 51.241300514766145, 54.293268953050884, 18.17650314739772, 0.10048212709703616, 2.5626452437468936, 3.672382644244603, 1.156710262809481, 0.5485386199184826, 43.77421392713274, 51.81247023173741, 27.531191212790354, 29.139103378568375, 30.333827018737793, 43.79390859603882, 2.0581332870892117, 0.3317293923880373, 0.0924535718347345, 0.11235284619033337, 0.05003438178183777, 0.0407294716153826, 0.03150182623150093, 0.04852112316127334, 0.010673461016267538, 0.05641419194372637, 0.06964558748794453, 0.03248097601213625, 0.029224180949053595, 0.052292990764336925, 0.02696630817704967, 0.022915359120815992, 0.011438556747244937, 0.02595288898529751, 0.13905646971293859, 0.08702430780977011, 0.13029660976358823, 0.13866074809006282, 0.11946603735642773, 0.19526234801326478, 0.20863362694425241, 0.21088136918842793, 0.17293364687689713, 0.11528485028871469, 0.1380307147545474, 0.1621519018496786, 0.14683978206345014, 0.13027847930788994, 0.1333636287599802, 0.14756968218301023, 0.10974640319389956, 0.17716451627867563, 0.10537240361528737, 0.10868636864636626, 0.1301383211144379, 0.18792245829743998, 0.18960050253995828, 0.30228156968951225, 0.7999855130910873, 38.99528462546212, 44.58201844351632, 38.71214553288051, 44.40007291521345, 37.742017201014924, 55.2070369720459, 57.134821619306294, 0.9164310246706009, 6.715524699006762, 6.778489708900452, 2.15128778559821, 0.10270593741110393, 4.128628722258976, 45.22502905981881, 53.7138934135437, 57.257085595812114, 59.64216940743582, 62.7149338041033, 59.53411102294922, 59.09659685407366, 56.3409343447004, 55.82013211931501, 54.41365691593715, 56.177377223968506, 58.400380407060894, 61.186170305524556, 53.09553153174264, 54.17509399141584, 59.5033791405814, 55.599724837711875, 56.249218123299734, 56.35044642857143, 57.21672003609793, 58.863700185503276, 57.58400181361607, 56.29312726429531, 55.03111553192139, 49.79827778679984, 45.19515527997698, 45.041954449244905, 43.592438629695344, 41.686759676252095, 45.08197259902954, 43.59012140546526, 42.44931752341134, 43.51477861404419, 43.396558489118306, 45.1988274029323, 41.001163550785606, 42.07743951252529, 42.50300277982439, 41.19819361822945, 45.432985169546946, 48.20495857511248, 51.13602140971592, 52.66882528577532, 51.42693206242153, 46.91220453807286, 43.78575488499233, 45.08389030184065, 51.97119140625, 55.095685141427175, 55.42442526136126, 57.17406504494803, 52.880060945238384, 41.34086792809622, 31.86367791039603, 62.76815005711147, 58.8465450831822, 55.017702034541536, 55.618068081992014, 54.58996745518276, 54.399096965789795, 53.550735814230784, 55.71202162333897, 54.66900321415493, 49.329472405569895, 40.652318818228586, 41.58600384848458, 40.751275062561035, 39.842030320848735, 39.78540597643171, 40.88011203493391, 38.59195906775338, 38.72985996518816, 38.84961216790335, 40.93592344011579, 40.95115041732788, 40.43878330503191, 39.130975995744976, 39.114546980176655, 40.4049733706883, 39.77524423599243, 38.98971217019217, 41.18178197315761, 38.481336797986714, 39.78846318381173, 39.22017696925572, 38.07622555324009, 37.95167909349714, 39.400760650634766, 38.95284155436924, 40.408582959856304, 41.47127171925136, 49.73004995073591, 54.063446862357004, 55.38691193716866, 52.86130428314209, 55.16538252149309, 52.136739185878206, 54.51795285088675, 50.09289182935442, 53.538833550044465, 51.092265129089355, 53.296428271702354, 51.79807356425694, 57.366085461207796, 50.66210215432303, 59.205016544886995, 53.0892607825143, 56.83538205283028, 18.517395666667394, 0.08770137719277825, 3.736061147281102, 4.711879619530269, 3.2632523008755276, 0.5925676716225488, 50.915659291403635, 56.38238729749407, 30.907386916024343, 35.932310240609304, 40.54731069292341, 52.310242652893066, 3.882936945983342, 0.7366728761366436, 0.3437651922660214, 0.27446448377200533, 0.1688248866370746, 0.08921474098627057, 0.11194824254406349, 0.08302010303097111, 0.1307458406580346, 0.12636429577001504, 0.31085830660802977, 0.08876962879938738, 0.12483384646475315, 0.12019345403781959, 0.14048379526606627, 0.17397456030760491, 0.10984321657036032, 0.1234616179551397, 0.3341891903962408], [0.07096275288079466, 0.04613751106496368, 0.028133435906576257, 0.039716724173298905, 0.03912646656057664, 0.023764496502865638, 0.013203187995324177, 0.037355374810951095, 0.03331082094726818, 0.07621152659079858, 0.023993551265448332, 0.05291051191410848, 0.0095191355462053, 0.013822782917746475, 0.021602142801774398, 0.03335869498550892, 0.02630119288473257, 0.010922070309918906, 0.049717200587370565, 0.02843502606265247, 0.02658007586640971, 0.021197067573666573, 0.11202693225017615, 0.10552576610020228, 1.9785903096199036, 24.10715195110866, 27.38579147202628, 32.55463457107544, 30.06443841116769, 34.79421615600586, 65.13389355795724, 5.9686480675424844, 2.673552606787, 2.4445990409169878, 0.5196015983819962, 0.17213123850524426, 0.021178903191217353, 7.449823788234165, 49.26570183890206, 56.56471497671944, 53.79029927934919, 56.74100814546858, 54.09837545667376, 54.03256211962019, 53.54627159663609, 52.579561778477256, 53.081416266305105, 55.54248557771955, 51.631883076259065, 53.94264895575387, 56.29243244443621, 52.39273861476353, 52.84452090944563, 53.885545185634065, 54.85825824737549, 55.013206550053184, 52.71612862178257, 55.39811243329729, 52.44899123055594, 50.34493773324149, 48.05318559919085, 46.85123756953648, 39.28926290784563, 39.561990124838694, 40.48795223236084, 41.29798364639282, 41.08296121869768, 41.93219436917986, 39.839945861271445, 40.24025590079171, 38.82111413138253, 38.57647500719343, 37.983039787837434, 37.37957484381539, 39.42635434014456, 39.21263122558594, 47.05091837474278, 54.12320137023926, 52.75632395063128, 53.579233850751606, 51.24915197917393, 50.76260437284197, 45.73317166737148, 40.356464522225515, 40.436584200177876, 48.48734031404768, 53.49466732570103, 53.02517754690987, 54.55485820770264, 51.11970009122576, 35.428715229034424, 27.11392409460885, 56.763037409101216, 51.93970911843436, 51.29250873838152, 52.936376094818115, 50.721703801836284, 51.99936287743704, 50.368912492479595, 44.95972946711949, 39.59867313929966, 38.98620332990374, 37.099017007010325, 37.348519870213096, 37.48639644895281, 36.110375199999126, 35.89784370149885, 36.026656355176655, 36.40631634848458, 35.09550741740635, 36.22240795407976, 35.41531215395246, 35.01571430478777, 37.42772238595145, 36.480762822287424, 36.52237210954939, 36.47575317110334, 38.08262831824166, 36.06126185825893, 36.15759515762329, 34.90815619059971, 35.14836583818708, 35.822024958474294, 36.606879574911936, 35.76686668395996, 34.25773184640067, 35.975951875959126, 34.98147010803223, 39.52522373199463, 43.04639707292829, 45.36316967010498, 45.99156475067139, 48.60656097957066, 47.05660547528948, 46.273744991847444, 48.536172253744944, 51.6981862613133, 47.25444848196847, 52.44317211423601, 51.43312985556466, 48.01682915006365, 49.62958942140852, 52.63996941702706, 47.598391260419575, 43.13147776467459, 2.2108787936823706, 0.17033625553761209, 2.168061605521611, 1.7761876561811991, 0.8759237325617245, 1.841410287788936, 49.12773840767996, 32.3499892779759, 23.82092959540231, 27.433492592402867, 34.9741918700082, 17.941334417888097, 0.05415934543790562, 0.08318415244242974, 0.03392553974741271, 0.02488120399149401, 0.006652415422390082, 0.07359657476523093, 0.06862182063715798, 0.08298129082790442, 0.07144612765737943, 0.012503206181073827, 0.022237645129540136, 0.040407106413372924, 0.014174371774840568, 0.049936883085008175, 0.032469006654407294, 0.04504852342818465, 0.01409817229224635, 0.06976775771805219, 0.01778768694826535, 0.017042730136641433, 0.06423408750976835, 0.006989695672278425, 0.09767467488667794, 0.06861454674175807, 0.045502154622226954, 0.030644351350409643, 0.026674293846424137, 0.02656692755408585, 0.030091141749705588, 0.07491249165364675, 0.02180506887712649, 0.031417698067213805, 0.0343543331670974, 0.028667734736310582, 0.04967307884778295, 0.05822487281901496, 0.013247902604884334, 0.03718540857412985, 0.006210891837586782, 0.012455910593936486, 0.025072820584422777, 0.14590991767389433, 0.19231985376349517, 7.428996562957764, 38.57259791237967, 28.584765672683716, 38.85139785494123, 33.4649076461792, 40.63889489855085, 66.62100955418178, 6.365981672491346, 1.8318708453859602, 3.8986559425081526, 2.34970315013613, 0.6907406694122723, 0.4155924123312746, 8.94842689377921, 54.06641026905605, 54.67028863089425, 55.6718749318804, 56.19532789502825, 54.11514493397304, 55.8789381980896, 56.041331495557515, 54.167360646384104, 55.39184168406895, 56.9734844480242, 53.91300099236624, 55.36692544392177, 57.526192801339285, 54.21957288469587, 54.856059142521445, 55.670454025268555, 57.25541455405099, 55.02267347063337, 55.58783646992275, 57.37327337265015, 54.38583632877895, 53.05492973327637, 50.783052921295166, 49.12280866077968, 41.02975191388811, 41.42999594552176, 41.79090275083269, 43.2629029410226, 42.59105035236904, 43.48191016060965, 43.140433992658345, 40.601096698216026, 41.236269746507915, 39.34910079411098, 39.08908878053938, 40.03406810760498, 40.619422571999685, 40.44587046759469, 47.10214049475533, 54.07171174458095, 55.482606002262656, 54.22257798058646, 51.49045249394008, 51.83734130859375, 46.279894147600444, 42.42904267992292, 44.01901633398873, 51.489827156066895, 55.98810829435076, 55.846253871917725, 55.412582056862966, 50.55354697363717, 32.276116030556814, 31.486873626708984, 60.324816022600444, 52.71828603744507, 52.75750167029244, 53.10261174610683, 52.78478724615914, 53.24752337591988, 51.17904118129185, 46.391562121255056, 40.767266341618125, 40.23326253890991, 39.34987551825387, 38.37848261424473, 38.97394323348999, 39.440205574035645, 38.45618084498814, 37.93208517347063, 38.135181018284385, 37.633670466286794, 38.97785159519741, 37.80722257069179, 36.145970821380615, 37.50899199077061, 39.32042210442679, 39.057908739362446, 40.04225308554513, 38.49365595408848, 37.70826285226004, 36.54698610305786, 36.6885278565543, 37.80803550992693, 37.906130177634104, 38.4601343699864, 37.65129804611206, 35.17023876735142, 37.98564188820975, 36.719530718667166, 40.82961252757481, 45.699448585510254, 48.363846506391255, 49.13204629080636, 50.537826674325125, 49.44156421933855, 47.31607205527169, 49.897303513118196, 52.80022266932896, 49.65848003114973, 52.38016932351248, 52.99906274250576, 49.67923430034092, 52.58295597348894, 55.40150315420968, 50.3786677633013, 44.79220839909145, 2.156889553580965, 0.10743692783372742, 6.103546474661146, 7.536775282451084, 2.0260043825422014, 2.3111688750130788, 54.5536526952471, 35.445130348205566, 29.456707273210796, 30.84496429988316, 37.62933131626674, 26.977524008069718, 0.05295446401994143, 0.04966518409284098, 0.04275668997849737, 0.03314309387600847, 0.02664838059406195, 0.08534536111567702, 0.13804915733635426, 0.013408399885520339, 0.06175731934074845, 0.03552306902461818, 0.004184220543330801, 0.026646036255572523, 0.03089306496882013, 0.01755388074421457, 0.06831003379608903, 0.06496814026364259, 0.059537057764828205, 0.014417919197252818, 0.035069403903824944, 0.15861216107649462, 0.09473697109413998, 0.07134936177836997, 0.13281192550701754, 0.20838932719613823, 0.14303548048649514, 0.0914169806720955, 0.16752253366368158, 0.09507150242903403, 0.20722743097160543, 0.1644978281110525, 0.149362249565976, 0.13070464001170226, 0.06329171093446867, 0.10963624303362199, 0.10472819568323237, 0.16846797721726553, 0.11580865218171052, 0.20942045615187713, 0.11177887341805867, 0.08613387309014797, 0.10189916605928115, 0.24173352867364883, 0.21306607552937099, 15.03645065852574, 51.56159162521362, 37.269327776772634, 50.2221804346357, 41.05463688714163, 43.63317591803414, 76.29529912131173, 7.872681600706918, 6.998662488801139, 5.1235790593283514, 1.9283472342150552, 0.5766738301941327, 0.3103596919349262, 10.76413709776742, 56.36039277485439, 57.029792649405344, 54.31206383023943, 58.39951188223702, 55.381916182381765, 57.39386435917446, 57.86594581604004, 57.310201099940706, 55.43083150046212, 58.49755791255406, 54.690209116254536, 58.2138386453901, 60.8995293208531, 58.35831601279122, 56.549727712358745, 58.512322834559846, 60.14363479614258, 58.314820289611816, 56.984584195273264, 56.879923479897634, 55.144836698259624, 55.579960686819895, 51.67601803370884, 52.96869911466326, 41.82728699275425, 43.54239075524466, 43.49442039217268, 46.00205653054373, 44.47363696779524, 45.80188935143607, 45.179313387189595, 42.749104499816895, 42.653250626155305, 42.64025054659162, 40.00186668123518, 41.56107718603951, 42.96464804240635, 43.76886034011841, 51.85188388824463, 58.162977831704275, 55.637568201337544, 57.92920569011143, 53.66692359106881, 54.328753403254915, 49.08063309533255, 45.04504292351859, 44.78720569610596, 52.23290572847639, 57.4467054094587, 57.435699462890625, 56.64927107947213, 56.14910500390189, 38.7404351234436, 38.73402541024344, 61.369574955531526, 51.887861660548616, 55.88441685267857, 55.12800816127232, 55.42153133664812, 56.87135635103498, 53.06955916540963, 47.138545581272666, 43.03950098582676, 41.42157472882952, 42.44876166752407, 41.07635695593697, 42.47484867913382, 40.11970465523856, 41.64659908839634, 40.779366629464285, 39.85590239933559, 39.631458214351106, 40.388047558920725, 39.101546900612966, 38.53047445842198, 40.197413308279856, 41.131265095302034, 41.83497864859444, 41.36127131325858, 41.16932037898472, 39.700856821877615, 38.15144675118582, 38.37302827835083, 40.253064904894146, 39.81925412586757, 40.31621013368879, 40.23837641307286, 36.383140632084434, 40.4298791885376, 37.85580090114048, 42.52868332181658, 46.24709517615182, 49.49368960516793, 50.09850249971662, 53.53571380887713, 50.55372762680054, 49.41503252301897, 52.40804549625942, 56.48691252299717, 49.68231235231672, 55.05318301064627, 53.871756485530305, 52.80899824414934, 54.69594832829067, 56.697272709437776, 51.03943797520229, 47.66195338112967, 2.61590752857072, 0.21264986214893206, 3.168743120772498, 6.965412752968924, 5.101766492639269, 2.1508574315479825, 60.539675167628694, 38.759987354278564, 36.64495570319039, 38.98312527792794, 47.09337534223284, 35.82352924346924, 0.1907647464956556, 0.11663645133376122, 0.0973042490492974, 0.12636307440698147, 0.08724420065326349, 0.13646084256470203, 0.13913545118910925, 0.10808807717902319, 0.10634957546634333, 0.09642043004610709, 0.10249962205333368, 0.14584165705101831, 0.0948363629036716, 0.1366433956261192, 0.1366691528154271, 0.137881409909044, 0.06939408848328249, 0.15043827039854868, 0.10997209072645221], [0.06466656537460429, 0.05697947607508727, 0.020742611959576607, 0.0633752385952643, 0.03330323153308459, 0.01830905968589442, 0.024988790807713355, 0.07796274404972792, 0.0699908057493823, 0.00902390421833843, 0.04280558181926608, 0.03265669622591563, 0.06776731434677329, 0.04452564434281417, 0.044544344767928123, 0.06205020898154803, 0.021366767485492995, 0.046608407582555494, 0.019046581450051496, 0.011913229312215532, 0.07157768881214516, 0.027226319403520653, 0.04523146325456245, 0.08029770518520049, 0.4908565751143864, 17.33172379221235, 33.71646022796631, 28.397305011749268, 34.34490394592285, 26.610325608934673, 54.03595978873116, 30.02920409611293, 0.21210113087935106, 2.881382997546877, 1.2973623211894716, 0.5563791734831673, 0.27852787716048105, 0.07228700217923947, 7.426549060004098, 53.52386365618025, 58.404285294669016, 58.2811666897365, 57.7391585622515, 52.62307139805385, 52.45430312837873, 55.473601136888774, 51.404590129852295, 53.9086548941476, 51.960494654519216, 54.90003776550293, 54.96290159225464, 55.950181552342, 55.27173859732491, 56.18315812519619, 55.554078647068565, 55.125492913382395, 52.718049798692974, 53.53407750810896, 51.619233880724224, 50.278471265520366, 47.983852999550955, 45.23114347457886, 41.0425956589835, 40.4080479485648, 41.03227758407593, 40.85147850854056, 41.624187673841206, 40.25561836787632, 41.414352076394216, 38.913990701947895, 40.2132864679609, 39.18745790209089, 39.133515562329976, 40.662477084568565, 38.28302131380354, 40.84282800129482, 50.414214747292654, 52.72473743983677, 54.178620202200754, 55.89735092435564, 53.888883795057026, 51.34044088636126, 52.22125012534005, 48.298116547720774, 40.87976115090506, 41.84187820979527, 49.359929834093364, 49.923098700387136, 51.89021362577166, 51.81796278272356, 52.61070360456194, 36.29112911224365, 32.7014604296003, 53.54843596049717, 49.328426701681956, 53.99971798488072, 50.40674543380737, 48.097192014966694, 43.399813720158164, 41.27546106066023, 38.78408718109131, 37.008308274405344, 37.231460094451904, 36.6863044330052, 37.449466773441856, 37.993785176958355, 37.61338867459978, 36.36444650377546, 37.296356269291465, 35.431828022003174, 36.91702284131731, 35.979422501155305, 36.05376475197928, 35.90609816142491, 36.12184320177351, 36.857907567705425, 36.048598766326904, 36.588070801326204, 35.61169951302664, 37.971259117126465, 35.446613788604736, 36.651733670915874, 35.52141809463501, 35.934926237378804, 35.38054684230259, 36.62124497549874, 34.0050710269383, 36.4473419870649, 36.03175285884312, 40.480590615953716, 42.09672771181379, 44.475005762917654, 44.399906158447266, 47.573857171194895, 45.00101566314697, 46.93809005192348, 47.852671010153635, 50.33880247388567, 46.98321165357317, 53.08939279828753, 50.122421673366, 49.306706632886616, 53.07507950919015, 51.666054316929404, 25.496675286974224, 0.03689899215740817, 0.2514942277755056, 5.245017068726676, 1.5285255227770125, 2.0006467146532874, 8.026577251298086, 50.995706013270784, 22.479454789842876, 32.435306208474294, 22.314480236598424, 33.14740971156529, 6.763480731419154, 0.2643589803150722, 0.09556187290166106, 0.03811281666691814, 0.10448739717581443, 0.01319337637895452, 0.040964987727680376, 0.05484316285167422, 0.0414487323058503, 0.06279085709580354, 0.016754313737952282, 0.05722158415509122, 0.06602227155651365, 0.01793298843715872, 0.052651060479027886, 0.020419178064912558, 0.035254813597670624, 0.021591822284140756, 0.037557713953512054, 0.03278110222890973, 0.0736313768263374, 0.019899796827563217, 0.11777531807976109, 0.040259077213704586, 0.044128667430153916, 0.06368285244596855, 0.05400755376155887, 0.01607865740412048, 0.04759154375642538, 0.006018487295867609, 0.0051538542944139665, 0.04636710017387356, 0.005692809994798154, 0.04486238770186901, 0.03498958443690624, 0.038986885121890476, 0.023458470424105014, 0.04909665656409093, 0.03675715798246009, 0.03305260105324643, 0.06005809123494795, 0.09762107062020473, 0.021534949175215194, 0.10947323856609208, 1.0982450800282615, 29.747541495731898, 41.25952884129116, 33.6788079398019, 42.60341467176165, 31.31455135345459, 63.36525045122419, 28.090462139674596, 0.1736463936311858, 1.5488626829215457, 2.926072725227901, 1.9905064702033997, 0.8957181732569421, 0.4270924138171332, 9.399592535836355, 57.66364901406424, 56.27379042761666, 58.980082511901855, 57.000801290784565, 53.71965347017561, 52.91775492259434, 55.82989086423601, 54.51999909537179, 55.712772028786794, 52.510284764426096, 57.01167869567871, 56.89821113858904, 57.281678744724815, 56.66667284284319, 54.99343892506191, 57.60389103208269, 57.37258550098964, 56.00962339128767, 53.762301513126914, 53.309317180088584, 53.5902224268232, 50.05907147271292, 48.35971927642822, 42.7153570992606, 42.85780906677246, 42.36699874060494, 42.893442903246196, 43.654420035226, 43.15602575029646, 43.85019595282418, 42.575156348092214, 41.82836743763515, 41.47056300299508, 40.73114265714373, 41.86303547450474, 41.182699135371614, 41.75071437018258, 52.01645197187151, 55.50209222521101, 55.3124863079616, 56.38234908240182, 57.42245619637625, 51.925163064684185, 53.1051686831883, 48.60897200448172, 42.28339106695992, 45.2962064061846, 51.38427012307303, 50.98764262880598, 54.319793701171875, 53.35070065089634, 52.90393148149763, 35.626794474465505, 37.900238105228965, 55.48429094042097, 51.73420224870954, 54.78731019156319, 52.221684387751985, 50.89908783776419, 45.82431466238839, 44.42496483666556, 40.03854274749756, 39.38012102672032, 38.09042419706072, 39.02370275769915, 38.76647349766323, 38.87237099238804, 39.20732627596174, 38.11270012174334, 39.162420068468364, 38.2758264541626, 38.280162130083355, 37.938432352883474, 37.04412623814174, 37.79252018247332, 37.72679369790213, 39.24818515777588, 37.7463424546378, 37.65850680215018, 36.53749486378261, 38.98333372388567, 36.67260258538382, 38.28360843658447, 38.345179898398264, 39.50691522870745, 37.36448335647583, 38.44427858080183, 36.67441259111677, 37.95950276511056, 38.047501700265066, 40.79883895601545, 43.479186466761995, 47.235813413347515, 46.273644242967876, 49.13348456791469, 47.998277459825786, 49.3648977960859, 50.24582168034145, 51.6081098147801, 49.22352974755423, 52.32353455679757, 52.18017932346889, 51.30568252290998, 53.32299818311419, 54.252024446214946, 27.325027738298687, 0.00552012537705845, 0.8273069698895726, 8.348196336201259, 5.4983132140977045, 0.8311407470277378, 8.793621029172625, 58.32302611214774, 28.16674988610404, 36.95142337254116, 21.94471968923296, 41.71110269001552, 10.12954248700823, 0.29290684844766346, 0.09724241415304796, 0.06314011264060225, 0.04132657225376793, 0.020654068228655627, 0.03341150197333523, 0.0669549722224474, 0.032317231941436014, 0.03127534142030137, 0.02194729320971029, 0.026502919649439197, 0.01796519510181887, 0.019357438698144894, 0.06160179911447423, 0.08393296333295958, 0.04108783310013158, 0.02294197804959757, 0.0742684058578951, 0.021676284626924565, 0.15552853154284613, 0.1840260930891548, 0.14899295009672642, 0.1572216392627784, 0.09189865232578345, 0.11244119144976139, 0.21142661278801306, 0.16704342008701392, 0.15272205642291478, 0.09807393167700086, 0.1110983027943543, 0.12112998164125852, 0.18419042069997105, 0.12782119187925542, 0.1953044714672225, 0.10831797841404166, 0.10842496303043195, 0.12922863635633672, 0.2538834852831704, 0.10268694521593195, 0.12399886841220514, 0.16451789917690413, 0.1752085169511182, 0.27100357519728796, 1.518943196960858, 42.775472913469585, 50.007390771593364, 39.74210480281285, 48.42548050199236, 35.76148183005196, 65.4606603894915, 36.49888025011335, 0.4799513231430735, 13.514656203133718, 5.9086399504116605, 1.796742381794112, 0.49750323274305885, 0.23605239923511231, 8.998152545520238, 59.27845205579485, 59.10981232779366, 60.39119911193848, 58.92827674320766, 56.67901284354073, 54.50033916745867, 57.99713127953665, 55.48892191478184, 56.67177629470825, 53.3722574370248, 59.34041609082903, 60.62457520621163, 59.44078976767403, 59.27346324920654, 59.47049331665039, 58.347594942365376, 59.97823987688337, 57.33849763870239, 57.19560446058001, 55.60250759124756, 55.565039430345806, 50.70493432453701, 49.79350437436785, 45.58633886064802, 45.2821432522365, 44.34516824994768, 45.67247915267944, 46.122378485543386, 44.054177692958284, 44.20272670473371, 43.268607412065776, 44.64138732637678, 44.384213651929585, 43.57863255909511, 45.27573701313564, 42.57968657357352, 43.92375305720738, 54.32626594815935, 58.74890204838344, 57.61363935470581, 59.00977216448103, 61.41418239048549, 54.63234799248831, 55.024639810834614, 51.002661160060335, 44.84209646497454, 46.83014978681292, 53.943520954677034, 52.34367043631417, 54.70947994504656, 55.4536007472447, 54.10969407217843, 42.20848601205008, 45.327063356127056, 55.16511154174805, 52.729319776807515, 56.31559426443917, 53.68247365951538, 52.30199861526489, 47.79627595629011, 46.04065029961722, 42.97266626358032, 42.02256958825247, 40.78316381999424, 40.033668586185996, 40.51286152430943, 41.92714997700283, 41.08859273365566, 39.94787917818342, 42.15271977015904, 38.50710766656058, 41.84581783839634, 39.4432384627206, 39.98295021057129, 39.173988819122314, 40.460162912096294, 41.40695571899414, 39.5861941746303, 40.43360342298235, 38.81567369188581, 43.44725949423653, 39.3618437903268, 40.042159284864155, 40.03319958278111, 40.64072574887957, 39.820223399571006, 40.43727554593767, 38.07423489434378, 39.204637323107036, 39.99943481172834, 43.441482067108154, 47.18545981815883, 49.295429706573486, 47.97544567925589, 52.46341916493007, 49.925568784986226, 50.8885543687003, 52.620337281908306, 53.96762425558907, 50.785297189440044, 52.77838795525687, 52.48846742085048, 53.46292100633894, 56.23409536906651, 56.3900476864406, 29.26389823641096, 0.11538502919886794, 1.119602648275239, 10.619887283870153, 7.874425598553248, 2.926526095185961, 9.518196548734393, 64.28503213609967, 32.081392765045166, 47.08175448008946, 31.419899940490723, 50.75033385413033, 15.443087032863072, 0.5167173360075269, 0.2175418689314808, 0.12110209385199205, 0.22818559993590626, 0.12935939005443028, 0.18178601829069002, 0.23184379935264587, 0.1694660343761955, 0.0879961463755795, 0.10429203337324516, 0.12969518346445902, 0.12742328537361963, 0.11067418448094811, 0.16827842167445592, 0.14763853991670267, 0.14651852287352085, 0.15291811233120306, 0.17656975319342955, 0.14603965356945992], [0.025566644800294722, 0.01137128593732736, 0.039514921073402674, 0.0077610114489548975, 0.051704303960182836, 0.06918548646249942, 0.03289324710411685, 0.07133813880916152, 0.03420745408428567, 0.011217151618828731, 0.03624048749251025, 0.029305082679327046, 0.014873199231390442, 0.02430763155488031, 0.05651585006022027, 0.026661250707028166, 0.07435037288814783, 0.04722166074705975, 0.029837481611009155, 0.04311073937320283, 0.008194363775796123, 0.19255877951426165, 0.014007040798398, 0.07416585207517658, 0.07631054520606995, 6.610670302595411, 34.829165594918386, 35.057889870234895, 37.25715800694057, 32.113719258989605, 37.77916921888079, 60.69484233856201, 0.9825079590082169, 0.602786083306585, 3.099478700331279, 1.9054405433791024, 1.7452055300985063, 0.827548582639013, 0.16651883109339646, 6.697203167847224, 55.454521383558, 60.03586823599679, 54.36060047149658, 53.53986188343593, 54.518498284476145, 52.34090157917568, 55.27311781474522, 54.0091084752764, 56.867979526519775, 53.97163684027535, 56.55977133342198, 56.35210704803467, 59.439163889203755, 56.02782072339739, 56.13959639413016, 52.136412620544434, 50.96921253204346, 51.26029688971383, 50.3875857761928, 48.89881958280291, 49.06255388259888, 43.1936537197658, 41.12120757784162, 40.4479410307748, 41.457740102495464, 41.75571359906878, 42.28120238440377, 40.8203957421439, 43.8329644203186, 41.16035720280239, 39.64526081085205, 39.2038209097726, 38.64649895259312, 38.6728013583592, 38.732555866241455, 45.75814001900809, 53.53171512058803, 51.46470594406128, 54.75812428338187, 49.47184099469866, 55.45371191842215, 64.91824231828961, 50.11601543426514, 53.14866093226841, 47.52449369430542, 42.081910678318565, 40.18854740687779, 44.94791405541556, 50.245790413447786, 52.68699482509068, 52.37289455958775, 49.152616432734895, 40.976049286978586, 49.68282304491316, 51.0252879687718, 48.540108408246724, 48.747140407562256, 43.75974430356707, 39.82586881092617, 37.59832150595528, 37.375051566532676, 40.89745473861694, 42.10579858507429, 40.52661895751953, 39.111430713108604, 37.385015283312114, 38.16940437044416, 36.04969310760498, 37.2273884500776, 37.77627182006836, 38.80736712047032, 37.21706690107073, 37.31468561717442, 36.81161519459316, 36.64016144616263, 37.90995863505772, 35.80902835300991, 36.60934271131243, 36.80552509852818, 34.7633626801627, 35.28071859904698, 35.56429542813982, 37.01637165887015, 36.69801909582955, 35.62677015577044, 35.18273857661656, 35.86937345777239, 35.21802500316075, 37.59775175367083, 40.62942450387137, 42.21203654153006, 44.6184652192252, 44.32270124980381, 45.78513029643467, 44.39041491917202, 45.19814995356968, 47.72824614388602, 51.10244424002511, 50.48831033706665, 49.02518647057669, 49.726655755724224, 54.88922984259469, 48.39624943052019, 50.41132429667881, 11.329980151993887, 0.29976073067103115, 0.8565162739583424, 13.264047707830157, 19.14839458465576, 1.7267162650823593, 19.86588294165475, 40.404341084616526, 20.280457632882253, 33.81851536887032, 24.606871604919434, 28.699824367250713, 0.1859157316918884, 0.032660129613109996, 0.026857761233778935, 0.10624713703457798, 0.06972842304302113, 0.004970736352593771, 0.019968194853780524, 0.01958897350622075, 0.04575778929782765, 0.025373336958831975, 0.0020139269223104096, 0.010698746623737472, 0.030913163176072494, 0.0365921857633761, 0.013411952864511736, 0.0708117720537952, 0.05049560917541385, 0.09551449758665902, 0.044032885426921506, 0.028673291938113313, 0.03252711978607944, 0.022800318597416793, 0.06668648948626858, 0.036593977095825334, 0.003922132575618369, 0.014402604661881924, 0.030103477516344616, 0.054497215165091414, 0.012770587994184877, 0.059464020255420885, 0.03995601633297546, 0.01697293432828571, 0.03154718969017267, 0.03947426664776035, 0.06076552506004061, 0.03587688432474222, 0.0654642850692783, 0.05326056134487901, 0.03796227349500571, 0.07585329402770315, 0.0334038379202996, 0.1294408142566681, 0.012961110449396074, 0.12992580394659722, 0.12824744757797035, 12.945176635469709, 48.278661591666086, 36.5074508530753, 43.57989713123867, 37.0570707321167, 44.55101558140346, 61.52009378160749, 0.8847366539495332, 0.5344571726662772, 2.533474317618779, 2.075891145638057, 3.480213927371161, 2.2680283784866333, 0.6920259233031953, 9.304589816502162, 59.72695132664272, 59.97505760192871, 56.73635285241263, 53.74997888292585, 55.401725496564595, 53.41839000156948, 56.41685036250523, 55.83033554894583, 57.70218372344971, 55.52194670268467, 59.644754137311665, 56.86350836072649, 61.282458441598074, 59.45831312452044, 57.66391651970999, 53.580484526497976, 52.96033000946045, 53.362443106515066, 51.283267634255544, 50.17283432824271, 51.341913904462544, 47.07197489057268, 41.43899733679635, 42.370861939021516, 43.478005273001536, 43.00729955945696, 42.73503787176949, 42.75050803593227, 44.33873769215175, 44.15601396560669, 42.22892413820539, 41.513461181095664, 40.312294823782786, 41.54206691469465, 39.92431436266218, 44.24238354819161, 54.73799187796456, 52.54621737343924, 56.81258153915405, 52.70364270891462, 53.012490136282786, 61.291129793439595, 54.83041334152222, 53.33060993467058, 48.86289044788906, 44.80365555627005, 46.159311635153635, 47.14067867824009, 50.69069399152483, 54.41245487758091, 53.110605648585725, 47.81847892488752, 40.09473282950265, 49.99822957175118, 52.68043572562081, 51.2101343699864, 50.254708426339285, 46.50017636162894, 43.52947057996477, 40.186803409031455, 39.92041294915335, 42.068080289023264, 42.68816532407488, 42.59840154647827, 40.93473877225603, 39.586350509098594, 38.62286465508597, 38.61044127600533, 39.81766993658883, 38.17122132437569, 39.31498861312866, 38.572594438280376, 38.82968126024519, 38.4552880014692, 38.35853433609009, 40.87990011487688, 39.61222907475063, 38.921922070639475, 39.32142264502389, 36.65421417781285, 36.99380390984671, 38.508629322052, 38.31854050500052, 38.70167807170323, 37.10535723822457, 37.64961658205305, 38.47810241154262, 37.48776524407523, 39.72269153594971, 43.148872579847065, 43.80081857953753, 45.78222247532436, 46.094328607831685, 48.21776410511562, 48.411427770342144, 47.40689890725272, 49.3207802091326, 52.55315167563302, 51.77481099537441, 50.15733289718628, 51.41652366093227, 55.974514143807546, 50.32366234915597, 50.84599665233067, 12.661668419837952, 0.5255143525344985, 1.662966217313494, 5.628320957933154, 2.6945737302303314, 1.041162914463452, 18.552035910742624, 48.840023926326204, 24.319547959736415, 42.81602954864502, 24.912321363176616, 41.19336462020874, 1.1983164016689574, 0.05015929668609585, 0.08110470045357943, 0.11628712793546063, 0.02292748793427433, 0.023505197738164237, 0.04289911787158676, 0.05221068107389978, 0.044185813649424484, 0.04080419528431126, 0.019650704925879836, 0.013270061862255846, 0.0186502508419965, 0.060971385799348354, 0.018323716042297225, 0.06650912721774407, 0.05217419285327196, 0.0213440484367311, 0.014026985487102397, 0.03635378248457398, 0.1389143844800336, 0.07549384688692433, 0.19591752785657132, 0.09671308219965015, 0.1280600769179208, 0.098598181403109, 0.09715081871088062, 0.1294752431235143, 0.15407770153667244, 0.07923596751477037, 0.10745142812707595, 0.15063742042652198, 0.07186594405876738, 0.08848336844572, 0.13731498244617665, 0.15626565127500466, 0.19638612414044992, 0.24697724729776382, 0.06696662266871758, 0.23035642345036778, 0.07746035672192063, 0.35043587003435406, 0.14154022000730038, 0.21371992544404098, 0.36919923605663435, 16.03512566430228, 60.8894613810948, 42.93572269167219, 53.16667761121477, 43.102701800210134, 46.592639514378135, 68.41379765101841, 1.5728611094611031, 3.2230658744062697, 8.516768319266182, 6.128691571099417, 4.412142149039677, 1.9397672499929155, 0.34212669304439, 9.156162398202078, 60.11353519984654, 60.71823692321777, 56.480964865003315, 54.47042369842529, 55.976383209228516, 54.21220432009016, 56.348535673958914, 57.347881180899485, 61.73847566332136, 56.626963887895855, 60.89498519897461, 58.56589344569615, 64.85843917301723, 61.06178365434919, 61.71442794799805, 55.93741423743111, 54.955814429691856, 56.19802727018084, 55.34695284707205, 52.82434334073748, 54.23926755360195, 48.21043028150286, 44.24638223648071, 44.25848599842617, 45.919626576559885, 44.96945694514683, 45.699851581028526, 45.329095704214915, 46.51952362060547, 46.59834745952061, 43.96990646634783, 43.68207386561802, 41.97484936032976, 43.0591470173427, 41.95612049102783, 49.915476526532856, 57.739262785230366, 55.64045865195138, 57.690819944654194, 53.533903803144185, 53.38129356929234, 64.70572471618652, 56.44216612407139, 56.46594633374895, 52.02464042391096, 46.34224728175572, 46.07142734527588, 47.70196458271572, 52.36459493637085, 56.120926584516255, 54.88708979742867, 51.47626774651663, 46.359645571027485, 52.532911573137554, 54.119984354291645, 52.21843263081142, 52.28724411555699, 47.93860633032662, 44.856138774326865, 41.06948518753052, 41.6758405821664, 45.53004802976336, 45.694529260907856, 44.99241379329136, 43.28848968233381, 42.80606235776629, 42.0635917527335, 40.71960169928414, 42.022913524082725, 41.02827194758824, 42.85429675238473, 41.05573122841971, 40.8061067717416, 40.41536440168108, 40.763486521584646, 42.37266847065517, 41.54535688672747, 40.96999740600586, 40.91027763911656, 39.888868127550396, 38.76889494487217, 41.35755402701241, 41.841728823525564, 40.51912532533918, 38.09477724347796, 39.262091977255686, 39.724619661058696, 39.69216462544033, 41.785382407052175, 47.144204889025005, 46.3976765360151, 49.292650427137104, 46.86955649512154, 50.777664593287874, 49.448793819972444, 50.53249740600586, 52.23296478816441, 54.867645263671875, 54.73968029022217, 52.08006272997175, 49.875764097486226, 57.05683503832136, 51.89299290520804, 55.027332237788606, 12.786528417042323, 0.31117092126182144, 2.908816222633634, 24.639328377587454, 32.14184904098511, 2.168152800628117, 23.396366868700298, 53.3959264755249, 28.609721864972794, 51.0747834614345, 34.06939050129482, 51.01969466890608, 3.591382933514459, 0.32756419160536354, 0.21788188282932552, 0.2202010340988636, 0.13436088524758816, 0.15467678010463715, 0.29844624549150467, 0.16944517620972224, 0.11515161315245287, 0.12636329153818743, 0.0779175671881863, 0.14867831340857915, 0.07717594876885414, 0.12857428432575294, 0.10366871074906417, 0.21334868536463805, 0.16804550774395466, 0.08286755478807858, 0.13698403377618107, 0.10272403394005128], [0.04365138250536152, 0.03160502462248717, 0.018729483376124074, 0.049821664446166584, 0.02455975141908441, 0.037969618636582575, 0.050032665088240585, 0.009616509562225213, 0.04302262481568115, 0.0833328737478171, 0.08816695399582386, 0.031184441476528133, 0.010111163287157459, 0.03456175114427294, 0.08247228099831513, 0.051598601774977784, 0.02438179712875613, 0.11088513423289571, 0.028135315448577915, 0.02389956059466515, 0.034155234029250484, 0.06219218564885003, 0.05396664488528456, 0.04506069973909429, 0.11341516740087952, 0.6984420961567334, 19.462017161505564, 44.94694478171212, 38.534605162484304, 36.34483868735177, 28.936811787741526, 49.91076912198748, 14.475846546036856, 1.4768946532692229, 1.9570200613566806, 3.1220284274646213, 2.1362692543438504, 1.6729871481657028, 0.2555922535913331, 0.18290439327912672, 15.318379027502877, 69.80427810123989, 55.496714319501606, 60.3246214730399, 57.79446622303554, 59.59344169071743, 58.00345761435372, 60.22689505985805, 57.41164479936872, 60.296349252973286, 57.468088490622385, 57.61704397201538, 56.94979803902762, 51.985438687460764, 50.24168402808053, 48.56075150626046, 48.66327565056937, 51.2357245853969, 49.90781961168562, 50.337211336408345, 47.274428027016775, 41.7749913760594, 39.96356473650251, 41.3616360936846, 41.63549934114729, 41.73756490434919, 40.94563702174595, 40.0793981552124, 41.368938650403706, 39.77441045216152, 40.95274155480521, 40.33420944213867, 38.69865560531616, 38.08952440534319, 38.69344098227364, 42.55013588496617, 51.67542396272932, 50.95452056612287, 53.04367017745972, 48.060849462236675, 60.255375725882395, 49.01771368299212, 51.11124413354056, 55.245637689317974, 53.44541154588972, 49.877855505262104, 45.80126748766218, 44.70174980163574, 48.382495471409385, 50.696117060525076, 53.21554776600429, 52.590769222804475, 50.32002149309431, 50.602312905447825, 47.352178369249614, 46.036127022334504, 41.9695930480957, 38.34036479677473, 38.57029805864607, 40.57171624047415, 44.888632025037495, 49.782953534807476, 51.04684475490025, 49.3630495752607, 42.558716910226, 36.425444739205496, 37.04191323689052, 37.93854004996163, 37.293201787131174, 37.93482623781477, 37.926332065037315, 37.09828397205898, 35.954304763248985, 36.80075168609619, 36.68711737224034, 37.374999455043245, 37.3040965625218, 38.09189026696341, 40.89913967677525, 38.92131757736206, 37.33619376591274, 37.154609543936594, 36.042793546404155, 34.82528502600533, 36.303694929395405, 35.68046236038208, 36.3055431502206, 35.78303861618042, 41.80317326954433, 43.88159486225673, 45.29789481844221, 47.00959396362305, 46.009716919490266, 47.32580648149763, 47.849978583199636, 46.4380281993321, 46.58250209263393, 49.660811151777, 48.188713686806814, 47.62530510766165, 52.970463957105366, 52.10366923468453, 49.66699504852295, 38.50129549843924, 1.853614798613957, 0.30786143456186565, 1.0150068551301956, 2.8979144990444183, 0.860460679445948, 0.1996061256421464, 30.727452891213552, 29.012686116354807, 27.096159287861415, 44.47994245801653, 27.39076464516776, 26.471118450164795, 0.2741968695606504, 0.03274508898279496, 0.027543288555794528, 0.028782091635678495, 0.13116486317345075, 0.027572343425293053, 0.05545172733919961, 0.039945702600691996, 0.04954283405095339, 0.048326142730989625, 0.012532321270555258, 0.0545388398958104, 0.041001075612647195, 0.07866480387747288, 0.03976566351151892, 0.007770629682844239, 0.02670745724546058, 0.05998360166060073, 0.0313782412558794, 0.0100431672929387, 0.05041504671264972, 0.031178551792566265, 0.018417330126145055, 0.03451501365218844, 0.02909016689019544, 0.014059835063692714, 0.07355421382401671, 0.02972892957872578, 0.013380060870466488, 0.08223256814692702, 0.011794067536746817, 0.024906033284163902, 0.005424697908373284, 0.0433802466972598, 0.07221667202455656, 0.04155297903344035, 0.06637407839298248, 0.034171905634658675, 0.023749448292489563, 0.05496132293982165, 0.01705035856658859, 0.026668497461027334, 0.069490929001144, 0.039449914025941064, 0.06829824085746493, 1.3425185552665164, 35.43525348390852, 51.35352087020874, 41.05941724777222, 45.65311104910714, 33.05835117612566, 61.298418453761506, 13.741130999156407, 1.4370438030787875, 1.718407739486013, 3.419603922537395, 6.019395538738795, 5.134187655789511, 1.0025683854307448, 0.42884452694228714, 18.10026577540806, 69.51902675628662, 54.14485195704869, 61.01336860656738, 57.85641636167254, 61.3982640675136, 58.1501271384103, 62.49807357788086, 59.71549374716622, 61.94371155330113, 58.55064909798758, 60.696440424237935, 56.91861799785069, 54.90926497323172, 51.46801676068987, 52.98916155951363, 50.53859792436872, 51.540034839085166, 53.27183164869036, 52.533213819776265, 50.15294163567679, 44.53094570977347, 43.52723673411778, 43.29100840432303, 42.92980630057198, 42.9970509665353, 42.70858607973371, 40.41225160871233, 44.54808691569737, 42.0618269102914, 43.78835698536464, 41.27464812142508, 42.505413804735454, 41.26568494524275, 41.46120377949306, 45.154032366616384, 55.513626234872, 54.28014380591256, 56.138845988682334, 47.722208159310476, 58.997439111982075, 55.405849252428325, 53.52509696143014, 55.306642872946604, 52.82458652768816, 49.93320138113839, 46.11720902579171, 46.65167488370623, 50.013737951006206, 54.719586099897114, 53.73566211972918, 53.91991444996425, 51.72551005227225, 50.85841308321272, 50.48229667118618, 48.46786103929792, 45.17738873617989, 41.21592194693429, 39.91899899074009, 41.135701520102366, 47.02614804676601, 50.24859748567854, 52.0482816696167, 51.10996913909912, 44.15758425848824, 37.65532105309622, 39.1112048966544, 40.15601594107491, 38.63052156993321, 39.897605487278526, 39.54769768033709, 40.188012395586284, 38.91963611330305, 38.655920709882466, 39.75381251743862, 38.18341193880354, 39.39621652875628, 39.378060885838096, 42.099197796412874, 40.77878992898123, 38.8358929497855, 38.44758939743042, 37.10237298692976, 38.11070598874773, 37.98290082386562, 37.67683267593384, 37.073197501046316, 37.748176779065815, 42.640733446393696, 45.636345045907156, 46.97998768942696, 47.91660138538906, 47.806562764304026, 48.37037781306675, 49.79533175059727, 48.772417954036165, 50.063549586704795, 50.37204613004412, 51.904558181762695, 48.5270596912929, 51.98603275844029, 52.28668131147112, 50.887574672698975, 40.38493129185268, 2.878057850258691, 0.6720093573842729, 2.2541371924536566, 2.6237600786345343, 1.1473463709865297, 0.13870707846113614, 33.280776909419465, 35.33245141165597, 33.30038472584316, 49.305383001055034, 31.6676344871521, 35.67924295152937, 0.8326208218932152, 0.020106083347595165, 0.04567717933761222, 0.07657155048634325, 0.017484069668820927, 0.06673794958208289, 0.05611354325498853, 0.04711199591734579, 0.0654702629627926, 0.03478520290393915, 0.00322770096577837, 0.08724015658455235, 0.03332681401765772, 0.010621061149452413, 0.059563887039465566, 0.03213523867140923, 0.12395219877362251, 0.033419247450573106, 0.08311494865587779, 0.04594441356935671, 0.12546786958617823, 0.11390157522899763, 0.1502101333545787, 0.1767646555921861, 0.14665209927729198, 0.12133489921689034, 0.13407371565699577, 0.08304008588727031, 0.15605227915304049, 0.18194693965571268, 0.15967990378183977, 0.16902646582041467, 0.14190391477729591, 0.1475477519312075, 0.24903024999158724, 0.1047030288193907, 0.10527913897697415, 0.16372868152601378, 0.13907314810369695, 0.11802013351448945, 0.13097157568803855, 0.12794275821319648, 0.14234469112540993, 0.18281390384903975, 0.1442901731601783, 1.2467741157327379, 46.25221252441406, 57.09944486618042, 47.48580265045166, 52.373113427843364, 38.88573237827846, 61.59855284009661, 18.459631817681448, 2.4446331305163245, 8.28261489527566, 6.966075871671949, 6.798358517033713, 4.811026505061558, 1.8162522720439094, 0.2889217037175383, 20.09567550250462, 71.11752932412284, 53.504540715898784, 60.95657403128487, 59.634866850716726, 62.34943771362305, 60.703763825552805, 64.503066607884, 62.196848324366975, 64.75190939222063, 59.73933301653181, 62.764140946524485, 59.85495798928397, 56.54809488568987, 54.02850784574236, 55.41764381953648, 52.54109307697841, 55.72850275039673, 55.1744499206543, 54.745506354740684, 52.26977981839861, 46.72713926860264, 44.30160651888166, 45.95915835244315, 47.463210582733154, 45.33205911091396, 44.47828878675188, 41.65529475893293, 46.56163317816598, 43.50466898509434, 45.96994195665632, 44.628494943891255, 43.72858510698591, 43.10647814614432, 42.90273264476231, 47.78877190181187, 56.43402630942208, 55.49424076080322, 57.84710577556065, 49.200663225991384, 58.99797412327358, 53.31723812648228, 54.93289232254028, 58.132193837847026, 56.315986837659565, 52.33447102137974, 49.37345102855137, 49.44537878036499, 52.02976124627249, 56.10862479891096, 55.257498264312744, 55.79120676858084, 55.03047629765102, 53.5015286718096, 51.3617753301348, 51.67029619216919, 45.42401851926531, 41.9272472517831, 42.759686606270925, 45.90667166028704, 49.82716492244175, 54.47323077065604, 54.566871643066406, 52.433861528124126, 45.471519878932405, 39.80761936732701, 41.18049308231899, 43.018322876521516, 40.814097200121196, 42.92881270817348, 41.20406484603882, 42.69574580873762, 39.39048426491873, 41.7148060798645, 42.465899399348665, 40.563076155526296, 40.85654027121407, 41.74551016943795, 44.489266940525596, 43.320889132363455, 40.70004946844918, 41.58374220984322, 38.667753492082866, 40.05856050763811, 38.92389535903931, 40.24741949353899, 40.042242663247244, 41.6801415170942, 45.29556369781494, 48.34162964139666, 49.473303590502056, 50.89168105806623, 48.67874581473214, 50.31577614375523, 50.677085944584434, 50.241631916591096, 51.80268716812134, 54.600598199026926, 51.73679045268467, 49.82077257973807, 52.83171885354178, 54.04576717104231, 52.326397214617046, 43.118283135550364, 2.52364695923669, 0.7765977137855121, 3.895501026085445, 12.543941617012024, 3.990613179547446, 0.38530092633196283, 36.44237749917166, 39.935629504067556, 37.8872241292681, 53.6873756136213, 39.32469177246094, 48.41789654323033, 1.0614336324589593, 0.20526281424931117, 0.13844087560261997, 0.1824445365262883, 0.18475070063556942, 0.10031646277223315, 0.1824546738394669, 0.0759395629699741, 0.21068933020745004, 0.15345779194363526, 0.11176606946225677, 0.255716724055154, 0.13476081378757954, 0.10322673339396715, 0.1462051346898079, 0.07324899520192828, 0.235695408391101, 0.12859997366155895, 0.13540265363241943, 0.10414753934102398], [0.04116398847794958, 0.07607135482664619, 0.01682111042152558, 0.06915234002683844, 0.015243709885648318, 0.006139854310146932, 0.0012926188584450366, 0.01319589459204248, 0.08353796774255377, 0.02824590987126742, 0.05684215076533811, 0.06734297211681094, 0.04804437767182078, 0.08171687474740402, 0.06067848258784839, 0.08089252933859825, 0.06213575867669923, 0.016288986296526024, 0.04764816750373159, 0.10123879542308194, 0.031191325214292322, 0.07756407079952103, 0.04860560755644526, 0.04920733919633286, 0.15058939371790203, 0.0481124924096678, 3.0387527474335263, 40.07397856031145, 31.178960732051305, 32.755253383091514, 35.207672187260215, 34.78097636359078, 45.05292565482003, 0.40250458461897715, 0.8179708708609853, 1.4484056276934487, 3.181214702980859, 4.023780839783805, 0.5349256875259536, 0.14879362364964827, 0.9584202915430069, 48.34535387584141, 63.6444707598005, 56.52145201819283, 62.91467366899763, 59.980136735098704, 61.29576424189976, 59.73371887207031, 59.069623947143555, 56.1796875, 55.32734503064837, 51.19969817570278, 49.36483178819929, 48.47769621440342, 48.97600017275129, 48.44161421912057, 48.996976784297395, 49.75386490140642, 48.69988570894514, 46.839769567762104, 43.58849205289568, 42.13219479152134, 41.922866412571494, 40.756771087646484, 39.910313742501394, 40.63792909894671, 41.07963303157261, 41.29012175968715, 43.54952655519758, 40.464554173605784, 38.85999625069754, 38.998591967991416, 40.04556737627302, 38.14598199299404, 38.33559833254133, 43.42072432381766, 47.85066645486014, 53.365340505327495, 51.43049648829869, 54.58626753943307, 45.07438169206892, 42.5322790145874, 51.71424354825701, 51.50361933026995, 54.074706418173655, 50.18493114198957, 48.68224423272269, 48.28745801108224, 51.28413963317871, 53.18951286588396, 53.01044389179775, 51.49064356940133, 50.481865882873535, 49.71330826623099, 46.19426454816546, 41.092282227107454, 40.01858057294573, 42.172876494271414, 47.18301405225481, 51.62493487766811, 50.94797188895089, 53.39602722440447, 51.58398219517299, 51.574883529118125, 47.97222171510969, 36.79845878056118, 36.77604736600603, 36.36800398145403, 37.216153212956016, 37.846670968191965, 36.65716368811471, 38.643545968191965, 39.555069719042095, 37.99177367346627, 37.4191517829895, 36.75611645834786, 41.814874035971506, 44.20417887823922, 44.50303827013288, 41.02070883342198, 40.92252383913313, 38.881653785705566, 39.46841178621565, 35.73408160890852, 37.23013646262032, 37.68959651674543, 37.26006235395159, 37.46446793419974, 41.35661254610334, 45.46918181010655, 47.686723709106445, 50.71330690383911, 49.261498178754536, 48.714838232312886, 45.92028318132673, 48.16676780155727, 46.56413452965872, 48.018514088221956, 50.82007987158639, 46.8009604045323, 52.11479677472796, 47.66356188910348, 46.14293820517403, 13.631478871617999, 0.08849467283913068, 0.5518849917820522, 0.17452432295041426, 2.2121357662337164, 0.6979697272181511, 0.6126422115734645, 30.086624009268625, 24.09041374070304, 36.715302739824565, 42.340522629874094, 37.44953972952706, 14.868910482951573, 0.21660933111395153, 0.02390017806153212, 0.0336423531573798, 0.05235924292355776, 0.014760274040911878, 0.032836949053619585, 0.027253582940569947, 0.08017535175063781, 0.03967669399987374, 0.010202908007028912, 0.030100305365132432, 0.026559439920155064, 0.01386661797628871, 0.05077050067484379, 0.03745533658989838, 0.06661926702197109, 0.019563438537131463, 0.03498906196494188, 0.02726457520787205, 0.015480362544102328, 0.049115204318825684, 0.06541885036442961, 0.023570893498669778, 0.06856223847717047, 0.0607241615653038, 0.038670911719756465, 0.03233860240184835, 0.004964798323011824, 0.04665374729250159, 0.033242550146366866, 0.009409492768879448, 0.012136818475223013, 0.04686560628137418, 0.04909598481442247, 0.04811308612780912, 0.06091760511377028, 0.011801560259690242, 0.02533078602781253, 0.03066778794995376, 0.030281277439956154, 0.010642538479130183, 0.043388443400285075, 0.06622497710798468, 0.07238685539258377, 0.08929005837334053, 0.01604229980148375, 7.667152149336679, 50.74946532930647, 32.64907448632376, 43.58050857271467, 39.01746327536446, 39.67585372924805, 43.8116786139352, 0.4244709887674877, 0.8629043826035091, 3.8017559306962148, 7.371451582227435, 7.66616724218641, 2.9553450516292026, 1.3582246324845721, 1.0393036199467522, 54.347138336726594, 60.30593081883022, 58.050976344517295, 62.98665700639997, 61.87345136914934, 62.80338437216622, 61.597948346819194, 59.88956696646554, 58.98428617204939, 55.87797587258475, 55.14239093235561, 52.07008164269583, 51.15979814529419, 51.21984447751726, 49.94741044725691, 51.11145952769688, 53.47070646286011, 50.67145790372576, 50.023468903132844, 46.6772894178118, 44.735049043382915, 42.63079057421003, 42.51392534800938, 42.21528482437134, 43.301312582833425, 42.79926354544503, 42.888579164232524, 43.65739386422293, 43.31417717252459, 41.23876067570278, 40.27459389822823, 41.34139946528843, 40.940700326647075, 40.87997654506138, 45.201307909829275, 49.513349533081055, 54.48654351915632, 52.70130811418806, 56.207535879952566, 49.204967635018484, 41.635436807359966, 52.62535735539028, 53.652401856013704, 56.163310595921104, 53.123435497283936, 51.1385748726981, 50.148762294224326, 53.053342069898335, 54.189855439322336, 53.00478458404541, 53.55993175506592, 52.362736293247764, 50.60580090114048, 47.61278097970145, 43.230173451559885, 41.92772320338658, 42.26917852674212, 47.598533698490684, 50.60835436412266, 51.564645358494346, 55.31037752968924, 53.26894119807652, 55.15018333707537, 48.5992306300572, 38.482347760881694, 40.860135963984895, 37.69111122403826, 38.723592690059114, 38.561279296875, 39.34467131750924, 40.01267113004412, 39.69873414720808, 37.65012380055019, 40.08605105536324, 38.56754657200405, 43.46860783440726, 46.03224992752075, 45.604786327907014, 43.01827423913138, 41.52298021316528, 40.05152545656477, 40.52059139524187, 37.76924024309431, 39.10296433312552, 38.603215149470735, 38.52063233511788, 38.39681543622698, 43.29573665346418, 47.72501523154122, 49.61590494428362, 50.55524928229195, 50.558365549360005, 50.107455253601074, 48.709074701581685, 49.270183426993235, 50.68690374919346, 49.01112331662859, 51.56906788689749, 48.114677156720845, 53.72714710235596, 48.62525510787964, 49.09472056797573, 15.139768634523664, 0.2540710052209241, 1.909697400672095, 2.4368856719561984, 2.1522653102874756, 0.6455755872385842, 0.43511937452214106, 36.87723398208618, 29.27030794961112, 45.867966720036094, 41.60283933367048, 43.018930843898225, 21.792027814047678, 0.16539417287068708, 0.0860474548701729, 0.03692170950983252, 0.03204665931739977, 0.022978579924841012, 0.06972665206662246, 0.054337857823286734, 0.04261243004085762, 0.027511612844786475, 0.02792936310704265, 0.03706006280013493, 0.049441505023943524, 0.013458868472038634, 0.0537710334174335, 0.05198185870956097, 0.08076741426650967, 0.054356045954461606, 0.027789332138906633, 0.030136525564427887, 0.02234517766295799, 0.14109250903129578, 0.2161072287708521, 0.06645019645137445, 0.2075458403144564, 0.2702594394130366, 0.1119413689843246, 0.08929191755929164, 0.17254153506032058, 0.30215500933783396, 0.08008458412119321, 0.1805030849895307, 0.2151431255042553, 0.11152961357895817, 0.12800516986421176, 0.10938825884035655, 0.15981756496642316, 0.16666380688548088, 0.17585828208497592, 0.1075570760294795, 0.2724678266261305, 0.16499963189874375, 0.09483665467372962, 0.1502581193510975, 0.17600806190499238, 0.1683651791619403, 0.12925471924245358, 10.499712109565735, 62.28397178649902, 39.912544114249094, 48.253106117248535, 46.574348381587434, 46.10885729108538, 53.706299032483784, 0.5904170413102422, 5.073136006082807, 6.2826410702296664, 10.564495376178197, 8.646347880363464, 4.627215385437012, 1.3722439259290695, 1.3487763851881027, 54.72765643256051, 60.96163926805769, 58.03758716583252, 64.92504460471017, 64.41511631011963, 65.58757618495396, 64.22622953142438, 62.341468129839214, 59.932527678353445, 59.08550752912249, 57.58380726405552, 51.8057930128915, 52.302627427237375, 51.953914710453574, 52.6174225125994, 54.220465728214805, 54.54516894476754, 51.572020871298655, 51.18228599003383, 48.35887507029942, 46.13032375063215, 45.90904099600655, 45.77394022260393, 44.39974634987967, 44.89625072479248, 44.81321975163051, 45.28946317945208, 47.54913548060826, 46.33564649309431, 42.55184514181954, 42.54366711207798, 42.36668954576765, 42.49424457550049, 41.57014805930001, 48.04232209069388, 52.39155742100307, 57.87582615443638, 55.96547106334141, 57.23758895056588, 51.11673321042742, 46.17015777315412, 53.144700459071565, 55.45822824750628, 57.89676455089024, 54.20744480405535, 52.33876153400966, 51.22431564331055, 55.37285573141915, 56.61508594240461, 55.59999581745693, 55.91157041277204, 54.0529203414917, 50.83860724312918, 51.05184050968715, 43.140409673963276, 43.56316934313093, 46.398618016924175, 49.78318977355957, 53.755624294281006, 53.67711312430245, 56.86747925622122, 53.86251885550362, 57.99539075578962, 52.90581096921648, 40.591476917266846, 42.88668578011649, 39.942018372671946, 40.6855068887983, 40.36723075594221, 40.277460030147004, 42.82460709980556, 42.390181405203684, 40.70455537523542, 40.105280194963726, 41.40703909737723, 46.19462932859148, 48.78491081510271, 47.39849853515625, 44.20014892305647, 45.702297346932546, 44.19490303312029, 43.83890513011387, 39.69059085845947, 42.2648880141122, 40.915961265563965, 41.716154030391145, 40.60226746967861, 45.31281607491629, 49.345849309648784, 52.58036776951381, 54.862896169934956, 53.25035129274641, 52.52513653891427, 50.46471425465175, 51.86559615816389, 53.08523430143084, 52.025613171713694, 53.59589910507202, 48.860469000680105, 53.32246664592198, 51.202241216387065, 50.08286905288696, 15.481937885284424, 0.28999813167112215, 2.2477157541683743, 5.002555770533426, 9.368064216205052, 1.7607665636709757, 1.0657710454293658, 40.42323671068464, 35.93743453707014, 48.80114180701119, 45.22993796212332, 52.49990068163191, 26.952338525227137, 0.3906610815652779, 0.24789411095636232, 0.11097618684704814, 0.16177128441631794, 0.12172622393284525, 0.234905512205192, 0.14006545128566877, 0.1087745510573898, 0.12948269343801908, 0.14341206742184504, 0.1395422736448901, 0.132221803601299, 0.10833951511553355, 0.15008982909577234, 0.1296580811696393, 0.1489808043198926, 0.12847496036972317, 0.15126221547169344, 0.1172150517148631, 0.08763953551117863], [0.022806537370862703, 0.06708703549312693, 0.018173736054450274, 0.011462565860711038, 0.031790804117918015, 0.041818316759807725, 0.06430665004466261, 0.06476086817149605, 0.02154672684680138, 0.032526403931634765, 0.025542565288820436, 0.05017406160810164, 0.0728585525814976, 0.04841237774650965, 0.03188068286648818, 0.034351313686264415, 0.034618286682026725, 0.009762395439403397, 0.029593500774353743, 0.03259470865928701, 0.05761349919651236, 0.04651960770466498, 0.016616705139832835, 0.02977102928395782, 0.0037749413666980608, 0.12258087950093405, 0.21002095964338097, 26.927092245646886, 43.81126867021833, 20.04348237173898, 45.739237444741384, 25.683319534574235, 56.3267183303833, 3.6273381241730283, 1.201291642018727, 2.017917113644736, 8.55035504273006, 5.773741977555411, 2.169710499899728, 1.401263837303434, 0.23442122819168226, 16.32069836344038, 64.76996776035854, 59.72274766649519, 64.73611613682338, 61.56893266950335, 56.95470346723284, 54.9108178956168, 52.36823231833321, 51.60148818152291, 49.54161827904837, 49.95292384283883, 47.91103935241699, 45.883412565503804, 44.88715205873762, 49.334429945264546, 47.91907841818673, 49.04357835224697, 47.80583667755127, 46.93882308687483, 44.837396008627756, 40.91734743118286, 42.01627452032906, 42.26003817149571, 42.99946893964495, 40.1225152015686, 41.30435167040144, 41.122812611716135, 41.35489286695208, 40.71538414273943, 40.70996107373919, 40.6243314743042, 38.0475503376552, 39.62317248753139, 39.35543755122593, 41.85586493355887, 45.95875883102417, 49.48207221712385, 54.26267950875418, 53.16266850062779, 45.069104535239084, 52.84274911880493, 53.21113565989903, 54.25831604003906, 53.906667709350586, 51.607442787715364, 54.100637095315115, 53.87940992627825, 51.537821837833945, 52.842502457754954, 52.94255999156407, 54.569845472063335, 54.419239793504985, 48.456080368586946, 46.33670956747872, 44.848165716443745, 47.296672684805735, 48.84767736707415, 52.21286712374006, 51.67990207672119, 52.13983808244978, 51.538245677948, 54.585048130580354, 51.01394503457205, 45.01209109170096, 37.55417265210833, 38.857512269701274, 37.547412054879324, 38.58228717531477, 38.47087975910732, 37.219592571258545, 37.63272203717913, 36.82460137775966, 36.10247162410191, 36.27296652112688, 37.81685624803816, 44.79930598395211, 48.94719988959176, 48.19452238082886, 50.465916293007986, 47.484701360974995, 41.215508529118125, 38.78454923629761, 38.692919867379324, 37.32642807279314, 37.776483740125386, 36.761713232312886, 35.62330647877285, 41.44028970173427, 49.02117041179112, 48.38854735238211, 49.346519810812815, 47.57766825812203, 50.37747267314366, 48.24722794124058, 48.562148094177246, 47.62549270902361, 46.76418706348964, 46.957454681396484, 51.41368532180786, 47.293945516858784, 49.891498293195454, 26.95125981739589, 0.9614169193165643, 0.3652604216975825, 1.193555474281311, 1.1815302052668162, 0.22845785532678875, 0.5728829364691461, 4.4421761717115125, 25.587203366415842, 31.10059894834246, 31.87456921168736, 37.104950768607004, 34.520088876996724, 1.9602220952510834, 0.15694775538785116, 0.02236198497536991, 0.0506769646225231, 0.026748152383204018, 0.023185751933072294, 0.03658009087666869, 0.0023627028276678175, 0.05670990429020353, 0.06411030236631632, 0.01960506835686309, 0.07492459671837942, 0.008631447197071143, 0.047418167881135426, 0.03407854260876775, 0.05371582780831626, 0.027382414688223174, 0.05450944575880255, 0.031582605825471025, 0.030966502813888446, 0.0449898064003459, 0.008976071740367582, 0.03667858701997569, 0.019332120860261575, 0.04380952187680772, 0.014962840492704084, 0.06030385661870241, 0.06478416227868625, 0.02473570912012032, 0.016099089789869528, 0.08068533867065396, 0.07335748616605997, 0.04778899744685207, 0.06966690027288028, 0.061576333695224354, 0.025767089133816104, 0.05589006435392158, 0.08880140459431068, 0.03451084066182375, 0.05624757766989725, 0.01795554124484105, 0.04576552798971534, 0.01962811479877148, 0.060044948011636734, 0.018950953813535825, 0.034584149585238526, 0.1529387126543692, 0.7170655482581684, 36.46636268070766, 44.93323598589216, 23.600996528353008, 58.6855970110212, 29.48650462286813, 63.593457085745676, 1.7037653880459922, 0.8560871684125492, 2.1729396751948764, 6.37059440783092, 5.3733837349074225, 3.66624173947743, 2.620177196604865, 0.3052737462733473, 19.535826138087682, 66.8420386995588, 57.951360021318706, 65.88989230564663, 62.96491609300886, 60.8478764125279, 56.668475900377544, 57.01050445011684, 51.82839897700718, 53.312739167894634, 51.50800711768014, 51.45634726115635, 48.595228467668804, 48.07680947440011, 50.075993810381206, 50.56661306108747, 50.94614103862217, 50.29604325975691, 49.27086435045515, 45.40425089427403, 43.682643617902485, 44.513912200927734, 44.10259621483939, 43.749916076660156, 43.20403780255999, 43.1941922051566, 42.22621086665562, 42.3482003893171, 42.662126949855256, 42.736420563289094, 41.73879126140049, 40.41333205359322, 43.31260687964303, 41.66831220899309, 44.57833589826311, 48.059657846178325, 51.16466883250645, 54.413691656930105, 54.43749965940203, 45.18862049920218, 53.06203079223633, 55.570483343941824, 56.04866879326956, 55.24410213742937, 53.74273885999407, 53.24080099378313, 54.315763745989116, 52.9467636517116, 55.070327690669465, 53.37044743129185, 54.678518772125244, 55.34854745864868, 50.83081136431013, 47.52802685328892, 45.483158111572266, 48.108896255493164, 51.017318384987966, 53.65431955882481, 54.55188437870571, 53.14018760408674, 51.93479674203055, 54.62264135905674, 52.81772518157959, 47.05130052566528, 40.72891228539603, 40.05566658292498, 38.85032435825893, 40.29626880373274, 41.057940755571636, 39.440282004220144, 38.05679144178118, 40.64282757895333, 38.66542584555489, 39.84738390786307, 38.9531055859157, 45.775253432137625, 50.24583905083792, 50.19270270211356, 52.654963629586355, 48.2118581363133, 42.97536563873291, 40.978964056287495, 40.17428275517055, 38.65824835641043, 38.960748604365754, 38.07329341343471, 37.89042377471924, 43.87535885402134, 49.89036921092442, 49.41346917833601, 51.997632775987896, 48.985255173274446, 52.51378665651594, 51.524866921561106, 50.78287921633039, 49.8119136265346, 50.434461797986714, 48.788471766880576, 53.95512097222464, 48.686222076416016, 51.77895906993321, 28.768660170691355, 1.5349156941686357, 1.0341602159397942, 2.233248736177172, 3.102604304041181, 0.37323342529790743, 0.5943223631807736, 5.465237617492676, 30.40137393133981, 35.29206500734602, 37.51229933329991, 37.07955857685634, 45.54619564328875, 3.0896773976939063, 0.17240717155592783, 0.025002836482599378, 0.08489085800413575, 0.040920594574085305, 0.061384823971561024, 0.024283674179709384, 0.025005302957392166, 0.023763831538547362, 0.09032469535512583, 0.037118186109832356, 0.09455540869385004, 0.017136286545012678, 0.03431229453001704, 0.04613762302324176, 0.07856742731694664, 0.05264270432027323, 0.044921213295310736, 0.05362618315432753, 0.024015822481097918, 0.011100854957476258, 0.13470792876822607, 0.0913521195096629, 0.07986306957900524, 0.11863327132804052, 0.08018787072173186, 0.09899454763425247, 0.1498065000133855, 0.12115788300122533, 0.08182155234473092, 0.16266695064093384, 0.13282240208770546, 0.16552922848079885, 0.186362533430968, 0.11469524406961032, 0.13132940791547298, 0.19675585787211144, 0.11426076452646937, 0.09157545252570085, 0.1048317469124283, 0.12562026855136665, 0.1829148291477135, 0.14815118669399194, 0.16780945898166724, 0.16374244221619197, 0.11165823667709317, 0.28393143149358885, 0.672449699469975, 41.63385261808123, 57.28134175709316, 29.40750013078962, 63.25312737056187, 33.536276068006245, 65.7395680291312, 4.880036447729383, 2.510545479399817, 6.472318206514631, 19.35962850706918, 12.96702698298863, 5.122689689908709, 6.148209060941424, 0.2513999928321157, 19.9852842603411, 66.0152656010219, 61.34828567504883, 69.31902980804443, 65.92512662070138, 62.47746522086007, 60.17016996656145, 58.02643183299473, 54.74830647877285, 55.3319343158177, 54.11412354878017, 54.254991327013286, 52.31526272637503, 49.58982835497175, 52.74183348246983, 51.73328856059483, 54.57913521357945, 53.28520345687866, 52.35735491343907, 48.298450061253135, 44.15752867289952, 47.31023556845528, 48.331586020333425, 46.59767001015799, 45.43605974742344, 45.547891003744944, 43.97591665812901, 45.46828201838902, 44.51935958862305, 44.89389181137085, 43.76867968695504, 42.56342084067208, 45.57953657422747, 42.94589138031006, 45.98006200790405, 50.71275799615042, 52.393190247671946, 57.70180852072579, 54.99162197113037, 49.16080141067505, 55.305777822222026, 56.66746146338326, 57.70733233860561, 58.16021939686367, 54.13927602767944, 57.486806937626426, 57.10989843096052, 56.1776898929051, 57.28777926308768, 55.9605621610369, 57.490083013262065, 57.94341475622994, 52.33438069479806, 51.54061501366751, 48.187661034720286, 53.162039688655305, 54.012725012642996, 57.077471188136506, 57.389924730573384, 56.351693630218506, 52.61477524893624, 57.81313950674874, 53.615548610687256, 49.94905022212437, 42.094980239868164, 42.4309847014291, 40.76584196090698, 43.152763571058, 42.5736277444022, 42.421326705387656, 40.35229907717024, 42.46726819447109, 40.507782391139436, 40.67999349321638, 40.189412457602366, 47.85099996839251, 52.68617146355765, 53.0215471131461, 56.70793124607631, 52.23359707423619, 45.06597089767456, 42.804686614445274, 42.90959051677159, 40.81966618129185, 41.44683837890625, 40.428583349500386, 39.47578035082136, 46.32887894766671, 53.27121325901577, 51.98107521874564, 53.10008955001831, 51.04452058247158, 53.56349965504238, 54.47110114778791, 52.31046846934727, 52.857364654541016, 52.212568351200645, 50.15398039136614, 50.81393766403198, 50.51795482635498, 53.21149001802717, 29.85915388379778, 1.4819729179143906, 2.0768367520400455, 3.7488467012132918, 7.493952666010175, 3.0664797510419572, 1.2364051235573632, 5.922745227813721, 37.91821656908308, 39.988939557756694, 43.07479088647025, 42.59847102846418, 56.74695232936314, 3.8749300156320845, 0.26650529514466015, 0.09163224590676171, 0.12299344236297266, 0.1024071987984436, 0.13222259070192063, 0.07745537627488375, 0.09384727597768817, 0.14897044987550803, 0.240909108625991, 0.07626276277005672, 0.21106355584093503, 0.05000202923214861, 0.1487169899046421, 0.1462541792009558, 0.08561304996588401, 0.11968730762600899, 0.23273352161049843, 0.249424153140613, 0.1987101472914219, 0.11259961580591542], [0.04213829351855176, 0.02488980781553047, 0.03619815030002168, 0.04439860901662281, 0.01988197680163596, 0.07845236813383442, 0.018341586958350878, 0.04693721208189215, 0.016546763446448103, 0.021037391320403134, 0.02104741837164121, 0.044252954689519744, 0.004830529389437288, 0.08198740665933915, 0.028774967017982687, 0.07132899894246034, 0.03671562824664371, 0.05643196616853986, 0.014245762988658888, 0.03946216497570276, 0.04002530832907983, 0.031238897304449762, 0.014163699267166001, 0.0764569052095924, 0.05545045508603964, 0.07487985411924974, 0.04597075090610555, 3.587713416133608, 55.93016379220145, 21.914510658809117, 41.36343567711966, 32.132559299468994, 32.16888100760323, 24.095880235944474, 1.5008394484009062, 1.045564706836428, 1.6726616684879576, 11.201679927962166, 4.951544267790658, 0.7755372449755669, 0.6211085915565491, 2.524862676858902, 46.609457629067556, 65.91976955958775, 59.34996291569301, 62.6535256249564, 56.04743896211897, 54.598461627960205, 53.158249446323936, 54.70282357079642, 53.03587082454136, 51.51728296279907, 47.008947781154085, 49.00136457170759, 47.464051314762656, 46.23978567123413, 47.6349526814052, 46.76446499143328, 44.8460499899728, 45.09884629930769, 42.90720381055559, 41.99515547071184, 41.89817598887852, 43.49502488545009, 42.47326796395438, 43.93522105898176, 43.416656153542654, 43.96287488937378, 42.48424959182739, 42.76825720923287, 40.112860679626465, 40.14816100256783, 38.94637278148106, 39.079628808157786, 39.25448717389788, 43.12782301221575, 44.951238768441335, 48.075746400015696, 51.818077428000315, 53.31192970275879, 47.494237763541086, 49.99642651421683, 52.373877729688374, 49.88795818601336, 51.83488164629255, 52.91062607084002, 54.51626443862915, 52.63714497429984, 53.67633145196097, 53.50205326080322, 50.0657764843532, 53.70388453347342, 53.246557576315745, 50.132065773010254, 49.74641295841762, 49.61305965696062, 51.19797502245222, 53.684071745191304, 52.0369804246085, 53.91805580684117, 50.419575282505576, 52.322669506073, 51.80964926310948, 48.99577127184187, 43.54680633544922, 38.62825993129185, 35.84142780303955, 38.446248395102366, 37.326292582920615, 38.24664054598127, 38.188546657562256, 37.76030485970633, 38.80339275087629, 37.49226767676217, 37.02449062892369, 38.51558099474226, 47.42023944854736, 52.38080160958426, 49.45663833618164, 49.33472524370466, 47.657687187194824, 48.28278187343052, 41.63015965053013, 39.38333109446934, 37.966388429914204, 38.834023884364534, 37.066079071589876, 35.44919157028198, 37.187477997371126, 46.99092762810843, 48.404166902814595, 50.95002508163452, 50.68075111934117, 49.4465981892177, 49.45960521697998, 51.51337112699236, 48.59491579873221, 48.65115104402815, 46.77368177686419, 50.73856013161795, 47.25271143232073, 39.413211822509766, 2.914796450308391, 0.13618317246437073, 0.7634071015885898, 0.6760770933968681, 2.0758490221840993, 0.21583388772393974, 0.25774649370993885, 5.540575197764805, 28.38344509260995, 41.32268449238369, 23.891083819525583, 36.874965395246235, 20.287781034197124, 0.299259184726647, 0.031517001667193005, 0.054665359535387585, 0.056194624797041924, 0.04563429592443364, 0.13767273324940885, 0.037829090641545396, 0.01736680355056056, 0.048533214655305655, 0.049390879526202164, 0.03328944709418075, 0.06073284002819231, 0.040955596803022284, 0.04028885133032288, 0.04100600516955767, 0.014283423378531421, 0.012553424557803996, 0.11549797813807215, 0.023418679434273924, 0.02050477186483996, 0.026041125679122548, 0.021811881368713718, 0.028407250231664096, 0.02489952104432242, 0.02712100567961378, 0.027865428144910505, 0.14357800994600567, 0.04379646686304893, 0.01962149908233966, 0.02010825296331729, 0.02549063361116818, 0.038621130998113325, 0.07745590553219829, 0.045728256061140976, 0.008894398176510419, 0.01238754649447011, 0.042040058611226935, 0.039054548633950095, 0.10716125941170113, 0.013729830405541828, 0.03736915585717984, 0.051333026561353884, 0.04641068247812135, 0.04016084909172995, 0.05600720663954105, 0.01602635083587042, 0.100330393096166, 0.0492329742493374, 8.166299445288521, 67.54188210623605, 20.221653291157313, 48.53069707325527, 34.576761858803884, 39.478663853236604, 23.675621918269567, 1.3951748268944877, 1.223434790968895, 4.042008570262364, 2.856747942311423, 4.430461508887155, 3.4580346260751997, 1.937420061656407, 2.584118217229843, 49.140217372349326, 66.64390386853898, 61.96721730913435, 65.35797991071428, 58.344933782305034, 55.172243867601665, 54.9145073890686, 57.19406196049282, 52.67170878819057, 52.849516664232524, 49.99664190837315, 51.64178425925118, 48.901835100991384, 48.727570806230815, 49.4919490814209, 49.709462438310894, 47.46408258165632, 47.14776931490217, 44.10513230732509, 42.765849658421104, 43.59300838197981, 43.80880553381783, 44.90096855163574, 44.554291657039094, 45.08284112385341, 44.618246350969585, 45.16026142665318, 43.424264430999756, 43.03814261300223, 42.97679001944405, 40.8055613381522, 40.658106667654856, 39.568406786237446, 44.9169841493879, 46.29647254943848, 50.894057341984336, 54.17315196990967, 54.954278877803254, 49.12028299059187, 52.37148754937308, 52.97692925589425, 52.763970443180625, 52.595615591321675, 53.56453146253313, 57.51848030090332, 54.51133469172886, 54.23921544211251, 55.11048827852522, 51.495434352329795, 54.71662269319807, 54.482763699122835, 52.453594412122456, 50.72845050266811, 51.14522082465035, 52.10348163332258, 55.61109903880528, 53.90924896512713, 54.45606524603707, 53.292426109313965, 55.31628697259085, 53.963160037994385, 53.50092070443289, 46.40169259480068, 40.532417229243684, 39.05518157141549, 39.9885504586356, 39.07056835719517, 39.45326123918806, 38.90536798749651, 39.544848918914795, 40.07821001325335, 39.92424488067627, 38.48540496826172, 40.92598056793213, 48.76141200746809, 54.36862564086914, 51.63306427001953, 50.847031933920725, 50.249434743608745, 50.2380952835083, 42.82398523603167, 41.557804584503174, 41.659088475363596, 40.1747031211853, 38.86592306409563, 38.034852504730225, 39.261959961482454, 48.861431326184956, 50.17884104592459, 52.49787528174264, 50.81106458391462, 51.03056859970093, 51.59261533192226, 52.285062381199424, 49.674384457724436, 51.436902727399556, 49.325022084372385, 51.781891209738596, 49.180770533425466, 43.48288985661098, 3.6286324432918002, 0.135541631174939, 1.6448136142321994, 2.6079210085528235, 2.4606439513819556, 0.36024854491863934, 0.33195412318621365, 8.37938940525055, 31.652925150735037, 47.27741575241089, 25.06041353089469, 40.37539141518729, 29.5131961277553, 0.3645955388035093, 0.008320690032892993, 0.019854609787996327, 0.03861820990485804, 0.13163865703557218, 0.07283409139407532, 0.03607058232384069, 0.05138474789315036, 0.025611338205635548, 0.029725604757134403, 0.05740104988217354, 0.04557151786450829, 0.0399805419812245, 0.06782541730042015, 0.05144913747374501, 0.01545363335338022, 0.010225812804752162, 0.04204057090516601, 0.03968485677614808, 0.02095957862080208, 0.057651537869657786, 0.09732433368584939, 0.09564087473388229, 0.15044512360223702, 0.14334460747029099, 0.11439183035067149, 0.21882545362625802, 0.09980513235288006, 0.1586341591817992, 0.07207282938595329, 0.11183031315782241, 0.16574479905622347, 0.14345510011272772, 0.10972117526190621, 0.12239456735551357, 0.08348658907094172, 0.14323030146104948, 0.11401111792240824, 0.14237982566867555, 0.07467482797801495, 0.116233727229493, 0.12151351677519934, 0.18195357572819504, 0.12464685578431402, 0.25654366825308117, 0.11200228785829884, 0.31526208030326025, 0.17909205784755095, 9.831766145569937, 76.14332117353166, 32.6425119127546, 55.388961655753, 41.96529558726719, 40.977306910923545, 27.965740237917217, 1.894574646438871, 5.024876858506884, 8.188326971871511, 23.278853722981044, 8.180630973407201, 4.757148001875196, 1.6735024005174637, 3.585311076470784, 51.11937699999128, 66.68682983943394, 63.51230212620327, 67.06771618979317, 59.812671252659385, 59.85802909306118, 57.40976531164986, 59.37470545087542, 57.60889026096889, 54.33940846579415, 51.18131671633039, 53.167528765542166, 52.90128421783447, 50.94174977711269, 52.266326563698904, 52.164497239249094, 51.27648271833147, 49.915483474731445, 48.01171875, 45.454524585178916, 47.79857233592442, 47.51663180759975, 46.70822279793875, 46.78221069063459, 48.56789772851126, 49.46768944604056, 47.663294383457725, 45.688112599509104, 45.0388069152832, 44.3784362248012, 42.5092214175633, 42.135884284973145, 43.061283588409424, 48.45608731678554, 49.84108911241804, 53.716280119759695, 57.02976485661098, 57.623443262917654, 54.84337868009295, 53.70527417319161, 55.88302026476179, 52.906550952366416, 53.10878522055489, 55.31782252447945, 59.976766858782085, 55.739595549447195, 55.07583066395351, 56.20026806422642, 51.7851151738848, 57.685674803597585, 56.905426842825754, 55.98122262954712, 53.23708023343767, 53.59285579408918, 53.560793331691194, 58.8014234815325, 55.44443954740252, 54.69785213470459, 53.24495601654053, 55.90350702830723, 56.79770197187151, 56.04872785295759, 49.419604437691824, 42.987375599997385, 40.61629588263375, 41.90886926651001, 42.43795721871512, 42.37936305999756, 41.05831595829555, 41.24669899259295, 42.8836042540414, 41.18667697906494, 40.364757197243826, 43.32640600204468, 51.32204205649239, 56.83472892216274, 53.92850589752197, 52.64350605010986, 53.00907857077462, 52.77903413772583, 45.57881048747471, 43.951733452933176, 45.15544285093035, 42.7665479523795, 41.59870515550886, 39.16541474206107, 39.63467870439802, 50.56673812866211, 51.52611412320818, 54.11351558140346, 54.929720469883506, 53.412768908909385, 55.65656457628523, 54.35677201407296, 52.003618649074006, 52.96184819085257, 52.784679549080984, 53.13304138183594, 51.967019012996126, 44.83001702172415, 4.1256362199783325, 0.24179560105715478, 2.4253073675291876, 4.507486632892063, 6.599586188793182, 1.499263618673597, 0.5592713611466544, 10.462541852678571, 42.16061987195696, 51.41640901565552, 35.27757453918457, 48.89009959357125, 35.92223882675171, 0.30832123703190256, 0.09305174795112439, 0.16443762848419802, 0.22876273468136787, 0.20755637117794581, 0.20772677846252918, 0.08446558618119784, 0.15911974598254475, 0.12205677905253001, 0.12990016889359268, 0.06111868218119655, 0.18041369478617394, 0.21908662175493582, 0.1735024492123297, 0.13286896316068514, 0.08278535027056932, 0.14066615833767823, 0.26556362424577984, 0.15855861109282288, 0.07905764851186957, 0.10252520960888692], [0.007363137173732477, 0.0355477609139468, 0.006840503633221877, 0.03781225618773273, 0.028706696217081377, 0.034986490317221196, 0.09593976262424674, 0.06853796049420323, 0.022809380432590842, 0.047162791048841815, 0.013399224395730665, 0.013554301877905215, 0.03278634391192879, 0.15658084436186723, 0.07419146677213055, 0.045002084491508346, 0.04431786674207874, 0.046291501194770844, 0.07098972464778594, 0.03171674541330763, 0.040007048951728005, 0.06768919461007629, 0.019741983152925968, 0.0505018075928092, 0.008343088473858578, 0.06607506836631469, 0.07893444690853357, 0.41181696206331253, 27.626119238989695, 47.34100219181606, 27.756674153464182, 54.04122999736241, 30.729221207754954, 33.18216460091727, 0.2505970959152494, 1.2527015805244446, 2.1656844530786787, 0.884483696094581, 2.6230665615626743, 2.849588257925851, 0.6616372710892132, 0.07643625060362474, 22.41113489014762, 65.48866162981305, 63.28634670802525, 62.82704298836844, 61.74169267926897, 60.406658853803364, 60.49076679774693, 60.15124307359968, 57.272461959293906, 53.89331674575806, 53.580484526497976, 47.888898917606895, 46.68239286967686, 47.49422039304461, 47.25587633677891, 44.072708538600374, 44.36888939993722, 42.32009145191738, 40.20989922114781, 42.15783017022269, 42.637061323438374, 44.714221818106516, 49.49946355819702, 49.60778944832938, 49.91564328329903, 47.32826614379883, 43.45038965770176, 45.94701984950474, 43.01511280877249, 39.647560664585654, 39.72320222854614, 38.749801295144216, 40.34831428527832, 40.18470157895769, 43.92110231944493, 47.05342320033482, 50.872003759656636, 53.32271678107125, 52.346043246132986, 52.889976024627686, 53.108684471675325, 53.90490286690848, 53.21426234926496, 53.244507857731406, 51.60117203848702, 54.34304584775652, 50.64560713086809, 44.920041356767925, 46.29686164855957, 54.3314562525068, 54.04101112910679, 51.72714982713972, 50.517006397247314, 52.175454548427034, 52.0774050440107, 53.400328159332275, 51.02461746760777, 51.12963948931013, 52.620524883270264, 52.9921110698155, 50.52685546875, 47.35828930991036, 44.081414631434846, 38.316119057791575, 37.20244094303676, 37.56660645348685, 37.56401824951172, 36.77691241673061, 38.42383698054722, 36.38074002947126, 38.09627110617501, 36.779076780591694, 38.28334093093872, 39.77368783950806, 47.87389080865042, 53.13084922518049, 52.72937536239624, 52.5945177759443, 50.437866415296284, 46.97339732306344, 46.714646407536094, 42.41784565789359, 39.5352395602635, 40.56276001249041, 39.55696310315813, 37.05055332183838, 38.093849658966064, 40.23489536557879, 48.00420079912458, 50.982289041791645, 51.0282096862793, 50.291110038757324, 50.220373903002056, 48.235697405678884, 50.16224527359009, 47.947434016636436, 46.70225082124983, 44.69992242540632, 47.16485840933663, 5.633222043514252, 0.21166595923049109, 0.39306613536817686, 0.8317884494151387, 1.971700736454555, 1.4004934557846613, 0.1716408205351659, 0.06355121665235076, 9.916588016918727, 41.34213597433907, 38.69757168633597, 27.47391721180507, 46.02343266350882, 4.023773023060389, 0.16722650240574563, 0.02466922965166824, 0.01590176671743393, 0.007188856302361403, 0.012919448399251061, 0.04390216565557888, 0.06347731061811958, 0.0469326183998159, 0.05507352888318045, 0.05116486183500715, 0.026170130453205535, 0.0167613840728466, 0.02232241620575743, 0.027617102987798195, 0.0036013665958307683, 0.012702632712067237, 0.03918391812060561, 0.048290373757481575, 0.10598841841731753, 0.06371190731546708, 0.05831179315490382, 0.010239755851216614, 0.020552929191450988, 0.029381692675607543, 0.010799943336418696, 0.05254845580618296, 0.03768750413187912, 0.03645574254915118, 0.07888582308909722, 0.012910983674893422, 0.04987963169280972, 0.013444358000664838, 0.02144033425221486, 0.03342829232237168, 0.05433740320482424, 0.05145989903914077, 0.03105461737141013, 0.008918621876676167, 0.042153570734496625, 0.023961480307791914, 0.013227320941431182, 0.0627187288233212, 0.053127836502556286, 0.04373884227659021, 0.029350249362843375, 0.028502558956721, 0.04740535035463316, 0.004428510961588472, 0.7216300261872155, 39.663128103528706, 46.12484162194388, 31.349803039005824, 61.07154587336949, 31.73905849456787, 40.342179025922505, 0.1388083973101207, 1.352001434990338, 2.6023778659956793, 2.023440497262137, 2.3733456986291066, 4.2097150683403015, 3.0932924151420593, 0.3585794301969664, 28.507406166621617, 66.40650476728166, 62.486706324986045, 66.353976385934, 60.76597104753767, 64.15392657688686, 62.133341789245605, 61.57558209555489, 58.19394595282418, 54.23106173106602, 53.824720655168804, 50.856207030160085, 48.18083095550537, 49.32683209010533, 48.79938391276768, 46.91493170601981, 47.67059694017683, 45.93233830588204, 42.24374464579991, 43.17981290817261, 45.863228048597065, 46.83297075544085, 51.39173943655831, 51.268540927342, 49.26674754279, 48.730016572134836, 44.01238775253296, 46.36061484473092, 44.930647781917024, 41.57388619014195, 42.24952207292829, 41.161194460732595, 42.48534393310547, 42.88157538005284, 47.41553899220058, 50.94155870165144, 51.114429882594514, 54.62679638181414, 53.986836024693076, 53.822459016527446, 54.778242792402, 53.47115114756993, 55.9605621610369, 54.525436060769216, 53.220001561301096, 52.73473937170846, 51.37987886156355, 47.38575553894043, 47.636481285095215, 55.05607346126011, 56.01377493994576, 53.547074113573345, 52.820473194122314, 52.96220602308001, 55.30161585126604, 55.68116119929722, 54.33134160723005, 52.739172322409495, 53.44155182157244, 53.988670349121094, 51.504362787519185, 48.68882417678833, 45.900605882917134, 39.579819202423096, 38.37649890354702, 39.13138593946184, 39.228080545152935, 38.91987930025373, 39.0208922113691, 38.52040651866368, 41.445632866450715, 38.60460826328823, 40.533303124564036, 40.82729877744402, 49.14639432089669, 53.05278273991176, 53.92910691670009, 54.992379324776785, 53.622493335178916, 50.330933638981406, 46.011155196598594, 42.216514655521934, 41.012457847595215, 42.448862416403635, 41.38212980542864, 39.55044569287981, 40.066682951790945, 43.205458709171836, 49.081115995134624, 53.40715823854719, 55.027290548597065, 52.433072907584055, 52.03243282863072, 51.6091833114624, 51.2136675289699, 49.8752429825919, 49.290333202907014, 47.015114307403564, 49.35116468157087, 7.487622857093811, 0.37018805156861034, 2.897045974220548, 4.421607766832624, 2.4285808375903537, 0.9202619791030884, 0.1240276111555951, 0.1185748494629349, 13.741376791681562, 45.274152823856895, 46.698630809783936, 25.964195251464844, 52.876024041857036, 6.681731266634805, 0.14175782618778093, 0.09545760242534534, 0.06924150631363903, 0.02056194013649864, 0.04437976949183004, 0.060540210721748214, 0.038515510237110515, 0.05696367299450295, 0.00535170959275482, 0.029911109445882694, 0.016424343854721104, 0.034389905365450044, 0.030608606125627245, 0.02467261384507375, 0.035300947193588526, 0.061607464881879945, 0.03836606629192829, 0.004828513292263129, 0.01604980100611491, 0.03302601944389088, 0.027835245210943476, 0.16341179210160459, 0.13674680436296122, 0.11744778922625951, 0.12757744852985653, 0.12380074975746018, 0.13709543565554277, 0.22018635060106004, 0.19177967203514917, 0.16034526165042604, 0.21834255382418633, 0.0788465291261673, 0.13335613773337432, 0.08415900370372192, 0.1681881629462753, 0.1736750685210739, 0.12990832488451684, 0.10599530554775681, 0.13022756204009056, 0.12134848348796368, 0.06781036060835634, 0.11146249968026366, 0.15666452130036695, 0.14148278880332196, 0.1377449022339923, 0.14854237570294312, 0.2443093561700412, 0.12424823003155844, 0.8420859511409486, 43.61639254433768, 61.15184620448521, 39.90778807231358, 65.62893881116594, 39.80390208108084, 42.886050019945415, 0.46754992859704153, 4.3832754237311224, 7.699201583862305, 4.867196176733289, 7.629237566675458, 6.660903172833579, 4.184081860951014, 0.4643382323639733, 28.207652194159373, 67.8810236794608, 64.24464225769043, 69.55121776035854, 66.82791301182338, 65.07723099844796, 64.18626349312919, 65.26739624568394, 60.669738497052876, 57.24697249276297, 57.447094508579795, 52.09590114865984, 51.458400453839985, 51.841023853846956, 52.324854714529856, 49.39474030903408, 50.35723951884678, 48.48379325866699, 43.879263741629465, 45.921023164476665, 48.27706003189087, 50.26442200796944, 54.33300917489188, 55.86600760051182, 53.55353593826294, 50.860038961683, 46.78810971123831, 49.25273650033133, 46.381296157836914, 43.51956592287336, 45.907672200884136, 43.125623907361714, 44.9265900339399, 45.60714871542794, 47.71131338391985, 51.84353215353829, 53.84479400089809, 55.68449286052159, 58.08176728657314, 56.33046340942383, 56.2453236579895, 55.986346926007954, 56.80164507457188, 56.25133037567139, 54.598975794655935, 55.601097106933594, 52.8949613571167, 48.455666950770784, 46.889522143772666, 57.29958772659302, 58.11217955180577, 56.59874030521938, 54.44954088756016, 56.4027316229684, 57.66947160448347, 56.99940470286778, 54.6772437776838, 55.60121175221035, 54.845195634024485, 56.61503383091518, 54.66050904137747, 50.9406658581325, 46.76402725492205, 42.20941012246268, 40.07330805914742, 40.47768974304199, 41.40136936732701, 39.531883580344065, 42.3775634765625, 41.59840638296944, 44.83727094105312, 42.291291168757844, 42.699556895664756, 42.5478811945234, 51.55774232319423, 56.57180561338152, 55.31311511993408, 58.382363728114534, 55.6779511315482, 51.82252427509853, 51.21985489981515, 46.13903679166521, 43.00253309522356, 46.128663131168906, 45.240665980747764, 42.06721176419939, 41.95347670146397, 44.30537939071655, 51.48379611968994, 55.683704239981516, 55.1643020766122, 53.61463492257254, 54.05241312299456, 53.154726709638325, 53.345624991825645, 53.605386870247976, 51.66082927158901, 48.79394694737026, 51.52641984394619, 7.524011441639491, 0.31032961926289965, 1.7656499530587877, 5.721799416201455, 8.277299523353577, 5.293601478849139, 0.618046335875988, 0.11972320212849549, 18.76600568635123, 51.82391044071743, 50.118346554892405, 37.872747557503835, 61.41295255933489, 8.386792710849218, 0.27589456417730873, 0.21335718062307152, 0.13371588342956134, 0.07936918429498162, 0.10090740570532424, 0.10689415410161018, 0.14605857112577983, 0.17332654579409532, 0.1336425609354462, 0.14131407785628522, 0.10709953308105469, 0.14006961749068328, 0.09573704350207533, 0.2359573771911008, 0.1291565080838544, 0.12067135982215405, 0.11829635154988084, 0.07678271736949682, 0.15984708123973437, 0.17923813286636556, 0.1596993641661746], [0.017684595426544547, 0.008032087037073714, 0.06163783610931464, 0.028108372519324933, 0.05029417587710278, 0.048045924731663296, 0.018552618134500723, 0.039692887238093784, 0.0320723011557545, 0.012934278630252396, 0.028909605329058, 0.010794569339071, 0.018771001237577627, 0.06499864719808102, 0.010408276808448136, 0.015368663805669971, 0.04244524919028793, 0.006374879756809345, 0.03426410836566772, 0.10944357301507678, 0.04498847647170935, 0.07338260553245034, 0.0434560051320919, 0.04625165083312562, 0.08305675070732832, 0.021534971227603297, 0.07673439889081887, 0.05839678645133972, 4.016917756625584, 52.31245565414429, 23.89645651408604, 36.58129630770002, 50.88774837766375, 27.25175551005772, 4.868258382592883, 1.6769429530416216, 0.26693372215543476, 1.6430191333804811, 0.32158610810126576, 2.9727991436209, 2.048931266580309, 0.19617098782743725, 4.193913127694811, 48.148170948028564, 62.39047377450125, 63.95848069872175, 62.42226178305489, 60.90604673113142, 61.7322222845895, 59.44354820251465, 58.905153138296946, 53.9085749898638, 51.11907475335257, 49.958152362278526, 47.71553788866316, 46.518026283809114, 46.807793957846506, 45.496807847704204, 42.63060644694737, 42.43974985395159, 42.1306905065264, 44.81957040514265, 45.72805431910923, 50.26588460377285, 50.52369056429182, 50.88208212171282, 52.06819520677839, 54.849534784044536, 50.24925409044538, 47.187485218048096, 45.915759904044016, 40.67399372373308, 39.47698586327689, 40.36389214651925, 39.25428220203945, 40.83904470716204, 41.98010567256382, 45.91470725195748, 47.34794691630772, 50.89065619877407, 51.653252261025564, 52.137579917907715, 51.48863901410784, 54.18364722388131, 53.42602259772164, 54.354041372026714, 55.44290052141462, 53.968510150909424, 52.88165903091431, 55.792822224753245, 50.2952025277274, 50.50043146950858, 54.4497458594186, 55.198167596544536, 53.3300575528826, 53.95613540921892, 52.75394766671317, 51.79966122763497, 52.1103047643389, 53.993926661355154, 55.52645260947091, 51.98473344530378, 50.144270283835276, 47.127167906079976, 44.078138555799214, 39.53211634499686, 37.209500312805176, 38.17895119530814, 37.01084089279175, 38.135934897831504, 37.11504650115967, 36.09586041314261, 36.96467358725411, 37.368964944567, 37.382708481379915, 38.05994939804077, 44.547235761369976, 51.71442767551967, 49.751148155757356, 52.07068613597325, 50.68621935163225, 51.36311980656215, 50.47073834283011, 45.6597570010594, 39.59445905685425, 40.84857068743025, 38.52333171027047, 38.42433377674648, 36.59465421949114, 38.298915318080354, 44.24299846376692, 47.428445271083284, 51.190835748400005, 51.11434303011213, 51.62752308164324, 51.28528956004551, 48.5334381375994, 49.03074502944946, 45.1250444820949, 49.153012480054585, 16.9934663772583, 0.17734329668538912, 0.16597449673073633, 1.4544833472796848, 1.5938846213476998, 1.2321162394114902, 0.5105883191738809, 0.1139839765216623, 0.984730948294912, 24.93570031438555, 48.69664090020316, 22.020885842187063, 37.581044810158865, 29.922583988734655, 0.0747035164386034, 0.01550151756964624, 0.016149615203695636, 0.13784991231347832, 0.013337513332122138, 0.022628932526069026, 0.05848184760127749, 0.03174072823354176, 0.024061820370012095, 0.009202884792882417, 0.030479148429419314, 0.04302580035956843, 0.021670893666201403, 0.011744356364943087, 0.04951215748276029, 0.07306746672838926, 0.07346717135182448, 0.03478905698284507, 0.043611864625875435, 0.004699756607546338, 0.0418454378045031, 0.03726998117885419, 0.011723980806501848, 0.018047140079683492, 0.01740258270209389, 0.016737206173794608, 0.0709771446085402, 0.019267770295430506, 0.043444755021482706, 0.07328205342803683, 0.041336054780653546, 0.05072233825922012, 0.06644660021577563, 0.020360225246154835, 0.023141994906057204, 0.07950067759624549, 0.03515754560274737, 0.043016646922166855, 0.03804987236591322, 0.05561523392264332, 0.04871078048433576, 0.03744882604639445, 0.048949624810900004, 0.035199574061802456, 0.034567586545433314, 0.0734597346080201, 0.07558467558452062, 0.01603041695696967, 0.034429660732192655, 0.05770436182085957, 7.641196284975324, 64.83918571472168, 23.379199607031687, 47.56645039149693, 49.40821981430054, 35.57277570452009, 5.687631215367999, 1.4362069794109888, 1.9585100156920296, 1.8149669638701846, 1.836507030895778, 4.927014086927686, 4.566857252802167, 0.8573676996997425, 5.50933175427573, 52.499984060014995, 63.956340653555735, 63.15530368259975, 65.36697087969098, 61.19015857151577, 61.32238279070173, 60.75723716190883, 61.304247992379324, 54.76760162625994, 53.35012742451259, 51.451632908412385, 51.46087053843907, 47.94848319462368, 49.4539771761213, 46.76135914666312, 44.09169449125017, 44.21546275275094, 44.191331659044536, 46.92311668395996, 46.16818101065499, 50.94163860593523, 55.004159995487754, 54.165568011147634, 56.231931005205425, 55.4247796194894, 53.27822399139404, 48.966456821986604, 47.731511797223774, 42.61178725106375, 41.12092617579869, 40.30204970496041, 42.08264371326992, 41.4105236189706, 43.30713169915335, 48.48526280266898, 50.75063610076904, 52.34713758741106, 53.04482705252511, 52.70614058630807, 54.23520285742623, 56.79470729827881, 53.45715052740914, 55.68720613207136, 55.36012315750122, 55.555127825055806, 54.18773276465279, 54.36898694719587, 50.50863034384591, 50.846191201891216, 54.70549167905535, 55.23744576317923, 54.00854219709124, 55.66322442463466, 54.22850479398455, 53.34261294773647, 53.50374167306082, 55.62413385936192, 57.311795711517334, 53.68882431302752, 52.53751475470406, 50.47569588252476, 45.60038117000035, 41.254956926618306, 40.73364748273577, 39.34524801799229, 39.327106271471294, 39.24817820957729, 38.77277898788452, 38.81192166464669, 38.61074004854475, 39.748260906764436, 39.171595164707725, 40.03510686329433, 46.58364507130214, 53.21681581224714, 52.04187890461513, 54.38315779822213, 52.113250800541465, 51.86936208180019, 51.468096664973665, 48.17442124230521, 42.323364053453716, 42.91670199802944, 40.207349232264924, 41.25151409421648, 38.785094669886995, 41.08044944490705, 45.78738151277815, 48.63676132474627, 52.9795035634722, 50.794944763183594, 51.80223553521292, 52.450617109026226, 51.014146532331196, 52.46465941837856, 47.81512989316668, 51.30256278174264, 20.580583333969116, 0.4701303701315607, 0.38720953677381786, 4.020438321999141, 5.060897188527243, 4.181302581514631, 0.8614045487982886, 0.36767071379082544, 1.1651768599237715, 27.488663026264735, 55.0089681489127, 26.92767068317958, 38.08672775541033, 39.91181802749634, 0.05096511469621744, 0.02563990792259574, 0.022407881084031293, 0.03654278841401849, 0.025383431863571917, 0.024825725272031765, 0.015553277917206287, 0.0475544821737068, 0.012248512972811503, 0.0372840845292168, 0.018102533982268403, 0.017433696925374012, 0.010889891634828277, 0.03427665447816253, 0.07766281800078494, 0.056390986046088595, 0.03675926483369299, 0.05338331850777779, 0.014826673781499267, 0.0347008338597204, 0.023508023836516907, 0.008257130809527422, 0.09744277875870466, 0.12285371843193259, 0.14558499439486436, 0.11571863772613661, 0.16512687078544072, 0.13607186557991163, 0.07377469020762614, 0.145073799682515, 0.1020394531743867, 0.12056453126881804, 0.1692711048360382, 0.09103460583303656, 0.07827050039278609, 0.12329672037490777, 0.12628490717283317, 0.19784259955797875, 0.17110560568315641, 0.10264195834419557, 0.1971859676497323, 0.1077644634725792, 0.18022462778857776, 0.11168669443577528, 0.12350929182554994, 0.09743707906454802, 0.16443097884101526, 0.08263478334993124, 0.11996501843844141, 0.23905038407870702, 8.894073741776602, 73.26764937809536, 34.40909835270473, 50.50628880092076, 57.24563149043492, 41.198916230882915, 6.671569526195526, 3.358343609741756, 4.554584128516061, 4.69303263085229, 5.260026914732797, 8.64076326574598, 5.338856399059296, 0.6605879845363753, 6.072052027497973, 52.040704659053254, 63.920536586216514, 65.25887775421143, 65.38889244624546, 64.383786882673, 63.95918246677944, 63.332058906555176, 63.29088388170515, 57.78740685326712, 55.893838609967915, 54.63353613444737, 53.64161477770124, 52.41133199419294, 51.97232048852103, 50.12976591927664, 48.15568889890398, 47.19443689073835, 47.73190437044416, 49.48803377151489, 50.455563477107454, 54.40391206741333, 55.62552349908011, 55.522808279309956, 57.81649201256888, 60.42327894483294, 56.47637210573469, 53.82132298605782, 50.938133239746094, 44.76717403956822, 44.23469189235142, 44.03836359296526, 45.0903034891401, 44.12329142434256, 44.89020926611764, 48.91501930781773, 51.36432531901768, 55.129119873046875, 54.586885929107666, 55.68506261280605, 57.653525488717214, 58.53559235164097, 56.085063457489014, 56.86508560180664, 58.06547028677804, 57.3018285206386, 54.8108993257795, 57.690896374838694, 52.08385992050171, 51.551131112234934, 57.007565362112864, 58.60590812138149, 55.97139440264021, 55.88440295628139, 54.562143393925254, 53.6720791544233, 55.958012172154014, 59.064649036952424, 59.71206133706229, 56.010853222438264, 53.43391922542027, 52.1183750970023, 48.49644245420183, 43.34900154386248, 42.47462633677891, 41.47905370167324, 40.62450865336827, 42.94664525985718, 40.36806801387242, 41.32694026402065, 39.83002035958426, 41.08172443934849, 41.12843370437622, 42.55893577848162, 49.3223991394043, 56.302882535117014, 53.58088404791695, 56.15702247619629, 52.97081136703491, 54.79673542295183, 53.77799054554531, 52.42460652760097, 43.34690318788801, 44.61095421654837, 41.64699166161673, 44.17711911882673, 41.47015305927822, 43.71466439110892, 47.53810174124581, 52.018640654427664, 56.63410316194807, 53.82882009233747, 52.761639322553364, 54.9919068472726, 53.108264105660574, 56.75575222287859, 50.97864123753139, 55.142436095646445, 21.157987322126115, 0.4554420954414776, 0.46843234981809345, 2.021489139114107, 6.291435752596174, 6.731121233531407, 3.2081079227583746, 0.6144623139074871, 1.7428457481520516, 36.355538913181846, 60.61618178231375, 32.165386063711985, 48.00620535441807, 43.7439614704677, 0.2718993771289076, 0.12812665477395058, 0.13539551544402326, 0.20420795013861998, 0.12080066145530768, 0.09688669895487172, 0.1236725744924375, 0.10649916529655457, 0.1152384520641395, 0.12639451771974564, 0.059526689749743254, 0.17145350415791782, 0.14893969866846288, 0.11718256345817021, 0.20485016996307032, 0.10843498499265738, 0.20245256647467613, 0.1475142187305859, 0.1471934752272708, 0.1736017053148576, 0.0947164793365768, 0.20055770315229893], [0.04487892699294856, 0.007733061743367995, 0.035794092874441824, 0.07439958024770021, 0.03593233759914126, 0.06121151255709784, 0.0672385659334915, 0.03542214372594442, 0.05411480300660644, 0.10829293368650333, 0.08013428002595901, 0.03950948261522821, 0.04809696752844112, 0.010838041381378258, 0.06568469359938588, 0.057688409462571144, 0.02866138025586094, 0.020888403690020953, 0.027406799540455853, 0.048776991931455474, 0.039932460989803076, 0.06449431247477021, 0.027336328589756573, 0.12973440278853687, 0.09518612056438412, 0.08156142237463168, 0.07074516027101449, 0.06725196021475963, 0.12698822229036263, 23.654325689588273, 51.888841356549946, 20.704327276774816, 54.87174470084054, 41.273762226104736, 7.704628126961844, 0.18892466809068406, 1.0351382834570748, 1.085804439016751, 1.2964654607432229, 2.000697306224278, 2.2495895964758734, 0.9463543104273933, 0.1016726710700563, 13.778372475079127, 60.739950043814524, 60.4972494670323, 63.180817467825754, 57.14885350636074, 62.103610447474885, 60.796786308288574, 58.47382286616734, 53.62980284009661, 55.69747904368809, 48.92980160032, 50.687977245875764, 45.52388150351388, 46.736943176814485, 43.54777908325195, 43.20197418757847, 44.06783437728882, 43.66820526123047, 43.729196548461914, 52.18622773034232, 55.25892959322248, 56.84289305550711, 53.93953963688442, 53.28164250510079, 51.89866958345686, 52.69454056876046, 53.62632179260254, 54.2739633832659, 45.94852066040039, 41.61093398502895, 40.103661264692036, 39.73556307383946, 39.90274715423584, 42.10011843272618, 44.06590277808053, 47.33301523753575, 48.09090389524187, 49.807056835719514, 52.203737190791536, 54.74590587615967, 53.93620102746146, 55.379772663116455, 54.31414481571743, 52.84218978881836, 54.32114165169852, 53.82562739508492, 50.157027176448274, 40.08481775011335, 52.89258854729788, 52.501637731279644, 51.83931112289429, 52.568104199000764, 52.77941976274763, 51.93729114532471, 51.967265674046104, 50.58017247063773, 52.905984674181255, 51.96456977299282, 48.900876249585835, 49.019582748413086, 46.79347372055054, 45.0040659223284, 40.11848177228655, 36.80909647260393, 38.51196445737566, 37.84678908756801, 37.773291042872835, 36.67665685926165, 37.5953164100647, 36.77251420702253, 36.625247137887136, 38.083250182015554, 37.22025612422398, 41.68113163539341, 50.79429163251604, 52.505334172930034, 52.086892809186665, 51.47163677215576, 51.82402161189488, 48.63411406108311, 49.843725953783306, 44.440431526729036, 39.17387069974627, 39.50305550439017, 39.67455094201224, 38.604101044791086, 36.88758332388741, 39.8475923538208, 45.52602154867989, 47.868453843253, 49.951791286468506, 51.22605616705758, 51.267019271850586, 49.81264666148594, 47.16605697359358, 44.041806425367085, 37.76258386884417, 0.8689071376408849, 0.2731084722493376, 0.046453216445765326, 7.586100544248309, 6.491144350596836, 2.4190103454249243, 0.4714652385030474, 0.20015788317791053, 5.663829292569842, 42.372567721775596, 35.66258117130825, 24.000484943389893, 47.001832825796946, 5.89637507711138, 0.5359295393739427, 0.05650392819994262, 0.050155744555273225, 0.036804641863065105, 0.03518042580357619, 0.025146061654335687, 0.03865797884230103, 0.04114780881042991, 0.02805114826852722, 0.07967520358839206, 0.02314241390143122, 0.0462724479314472, 0.04981045165498342, 0.005481669828960938, 0.04300952908982124, 0.04277229967660137, 0.03344520820038659, 0.044072878280920644, 0.034295690778110705, 0.05572215747088194, 0.05397880084014364, 0.02013382694817015, 0.10403686349413224, 0.0743920620796936, 0.05625992700723665, 0.042104203919214864, 0.06683616752603225, 0.09211247906621013, 0.008369089935773184, 0.005392860197129526, 0.052336135413497686, 0.08319189452699252, 0.003238687719983448, 0.001679384137137926, 0.04703358780326588, 0.006323314488067159, 0.018842615519783328, 0.014241425453552177, 0.037960716257137914, 0.04679447206269417, 0.05816349932657821, 0.024034227743478756, 0.027660242547946315, 0.027240370167419314, 0.043369753153196404, 0.02173361913966281, 0.0662203969966088, 0.011293386724511427, 0.020928622156913792, 0.06253050320914813, 0.19840051819171223, 34.40025329589844, 50.06929227284023, 24.548824616840907, 67.52387932368687, 40.76296888078962, 12.583488157817296, 0.1816802482519831, 0.9645997370992387, 1.4624498912266322, 1.7045694249016898, 3.6024008222988675, 4.196291582924979, 2.7007139836038863, 0.21838090462344034, 16.30593170438494, 63.68891143798828, 61.34732682364327, 64.35654299599784, 59.05165590558733, 64.39210387638637, 63.1095358984811, 60.62568691798619, 55.5572053364345, 57.682947635650635, 51.971556186676025, 52.50589002881731, 50.13739504132952, 49.450037547520225, 46.32051331656319, 45.87435211454119, 44.60534354618618, 44.71190111977713, 45.73737185341971, 52.90252794538225, 56.900583948407856, 56.50212212971279, 56.06722048350743, 54.69619846343994, 54.00336578914097, 56.53515386581421, 56.10155848094395, 56.31199509756905, 46.58884579794747, 42.30004937308175, 40.281809602464946, 41.61947679519653, 42.525292600904194, 44.98724433353969, 45.65967014857701, 49.78391238621303, 50.34094599315098, 51.8927184513637, 54.30098145348685, 56.40420116697039, 55.845875195094514, 57.702746527535574, 55.969667775290354, 55.29247897011893, 55.09014047895159, 55.04487296513149, 54.31425598689488, 42.84846373966762, 49.51147699356079, 52.4328818321228, 53.37498460497175, 55.70506647654942, 52.40472078323364, 54.97263601848057, 52.983366761888774, 54.14306627001081, 54.728083746773855, 54.872995376586914, 51.64905554907662, 50.583233152117046, 47.62970331736973, 44.97418172018868, 42.335464341299875, 38.19379949569702, 40.012487002781455, 38.950107438223704, 40.51745775767735, 39.90447378158569, 40.18376357214791, 39.43805858067104, 38.303890228271484, 39.379888262067524, 38.953779561179026, 44.90701001031058, 52.62473201751709, 54.09259455544608, 52.905609471457346, 54.156135831560405, 54.08392320360456, 51.858251912253245, 50.87590864726475, 45.59747682298933, 40.95926243918282, 41.65112583977835, 40.608156067984446, 40.832728794642854, 39.73305477414812, 41.5657776423863, 47.56326116834368, 48.85075889314924, 51.80891275405884, 52.96654864719936, 53.73148625237601, 52.322822366442, 49.847293853759766, 47.8923556464059, 41.08439254760742, 1.7624042757919856, 0.5656089325036321, 1.331267033304487, 7.935557586806161, 1.686517896396773, 0.7752810844353267, 0.47096789947577883, 0.0692906186782888, 7.091411820479801, 49.49681282043457, 45.14269985471453, 23.782693658556255, 51.733646392822266, 10.333237613950457, 0.7685714587569237, 0.12629295459815434, 0.016803331107699444, 0.013373715719873351, 0.013167217157648077, 0.04311409472887005, 0.022965986314894896, 0.024230519442686012, 0.00976177373169256, 0.054268416549478254, 0.031728616383458884, 0.026814365526661277, 0.07410645311964409, 0.007684138520354671, 0.01235782411614699, 0.044885725913835425, 0.03439723015097635, 0.03830367499696357, 0.0034583288693933612, 0.013106104053024734, 0.07972477057150432, 0.004324813847363527, 0.2311909943819046, 0.17684932319181307, 0.15227677460227693, 0.2142159752547741, 0.22691397102815763, 0.1727555450052023, 0.15302323097629206, 0.1810473379279886, 0.11685888868357454, 0.24209706059523992, 0.18525958832885536, 0.11411333243761744, 0.13167257021580422, 0.11029697329338108, 0.1831790642546756, 0.1309512196374791, 0.12321370840072632, 0.15463125040488584, 0.248610969632864, 0.12544094531663827, 0.17759633596454347, 0.21752966887184552, 0.12643582693168096, 0.16978183814457484, 0.12594809596027645, 0.16639779401676996, 0.1462663249777896, 0.15210578377757752, 0.23176750487514905, 41.67189400536673, 65.28056308201381, 33.31663308824812, 67.18760735648019, 52.67387662615095, 14.704307658331734, 0.46047937657151905, 2.9198388883045743, 3.7372145482472012, 5.698533807482038, 8.374968613897051, 7.483492153031485, 3.4938756057194302, 0.2688841303544385, 16.369207211903163, 65.50667830875942, 62.072121211460654, 65.20944826943534, 59.47800431932722, 66.42959363119942, 65.45644978114537, 64.10986804962158, 57.31504052025931, 62.799403054373606, 53.610222816467285, 53.33706481116158, 51.487735748291016, 53.54690735680716, 48.32525621141706, 47.8118121283395, 48.8819910458156, 47.312452043805806, 48.75667681012835, 55.226189681461875, 60.0238686970302, 61.04157134464809, 58.47232205527169, 58.715050424848286, 55.8503463608878, 57.63241686139788, 59.62076200757708, 61.30152429853167, 51.24982248033796, 48.45007365090506, 43.59867811203003, 43.99756029673985, 44.308502605983186, 47.944706848689485, 47.12358610970633, 51.8512133870806, 53.11995097569057, 54.07978555134365, 54.26657049996512, 58.85508441925049, 57.17137956619263, 60.692452158246724, 58.565712792532786, 57.888631684439524, 58.74846431187221, 58.056062425885884, 54.431194169180735, 40.46170193808419, 53.03374120167324, 54.0201005254473, 54.330855233328684, 55.66319663184029, 53.6437965120588, 55.46582610266549, 55.00239862714495, 55.19056279318673, 58.4886086327689, 56.35622385569981, 53.46290363584246, 52.603668553488596, 51.3613931792123, 47.035548959459575, 44.83472442626953, 39.103037289210725, 43.01638780321394, 40.474021094185964, 41.58797366278512, 42.80363048825945, 41.49947098323277, 41.270889145987375, 39.85430083956037, 42.39528833116804, 41.00823334285191, 46.55993434361049, 53.61732040132795, 56.57508863721575, 55.81692899976458, 54.8680864742824, 54.93759625298636, 53.31232227597918, 54.72841378620693, 50.39943592888968, 44.275582041059224, 43.33082505634853, 43.976111207689556, 41.93824972425188, 40.82877179554531, 44.199280398232595, 49.241619382585796, 52.05270767211914, 52.84402411324637, 54.82029676437378, 56.79139300755092, 55.216045311519075, 53.41259520394461, 48.74142551422119, 42.70156145095825, 1.7805675183023726, 0.6743358096906117, 0.3668444481279169, 15.60500090462821, 17.096746138163976, 4.649346266474042, 1.7748275463070189, 0.37805732073528425, 9.636853541646685, 56.15823146275112, 45.68286670957293, 34.080851554870605, 61.35018253326416, 13.394564407212393, 1.0314198029892785, 0.3099716513284615, 0.07105156632938556, 0.09398052668465035, 0.14304211655897753, 0.07684908487967082, 0.18071102883134568, 0.09064083160566432, 0.17204271682671138, 0.14605744475764887, 0.11212393561644213, 0.07243642916104623, 0.191008435562253, 0.08041761589369603, 0.1486064429794039, 0.09831777680665255, 0.10572168630148683, 0.14059537356453283, 0.11114319467118808, 0.10050846782646009, 0.2222364220236029, 0.15981390087732247], [0.023779790682185973, 0.04158922976681164, 0.05245182563417724, 0.009025475875075375, 0.01910939174039023, 0.15640446596911975, 0.11103010323962995, 0.01810494956693479, 0.00654898675358189, 0.04450989893770643, 0.049035252537578344, 0.02783629185120974, 0.019569155194663575, 0.01111296087037772, 0.01323503758093076, 0.05672755637871368, 0.048629054334014654, 0.02491288139883961, 0.061508405554507456, 0.05223054179389562, 0.023282025874193226, 0.03282557002135685, 0.05098910090912666, 0.06387238763272762, 0.06230856118989842, 0.04096576804295182, 0.07431391520159585, 0.04370522086641618, 0.1385371054389647, 2.7417943392481123, 47.36536257607596, 29.572849886757986, 30.20533398219517, 58.92250973837716, 19.882367542811803, 0.18795757927000523, 0.3615575475352151, 0.1734936282570873, 2.351253684077944, 3.045845989670072, 3.3215661432061876, 1.2097877689770289, 0.2456006897347314, 0.5623261258006096, 26.809214319501603, 66.98471300942558, 60.72342722756522, 63.81761292048863, 61.679791178022114, 61.46088818141392, 56.43792772293091, 55.35807343891689, 50.32850524357387, 53.59242500577654, 49.75324303763253, 48.848823819841655, 47.01867525918143, 45.53746523175921, 42.037431785038535, 43.77404022216797, 43.36062935420445, 51.97669785363333, 57.10308919634138, 57.73904044287545, 54.606076853615896, 53.337909017290386, 55.16216550554548, 57.65567248208182, 55.97349623271397, 54.19974620001656, 55.55035441262381, 54.306571279253276, 44.238572461264475, 40.05706664494106, 38.20624371937343, 40.108392987932476, 41.52600615365164, 41.8932705606733, 44.094234057835166, 47.63021053586687, 46.9602860723223, 45.760915824345176, 48.131870474134175, 52.41115828922817, 50.96014860698155, 50.94836098807198, 49.875298568180625, 53.534629889896934, 54.66076612472534, 52.28149448122297, 37.84670570918492, 52.90724924632481, 56.79782356534685, 54.01826620101929, 55.50635494504656, 52.78780276434762, 52.80129616601126, 52.63018635341099, 50.50412791115897, 53.48989738736834, 49.85134465353829, 47.88329519544329, 49.099709374564036, 49.783981868198936, 45.215603828430176, 40.272502490452354, 37.246218068259104, 39.25853797367641, 37.32429844992501, 38.36289433070591, 37.95442015784127, 38.44838844026838, 37.67585645403181, 40.51317071914673, 38.95257404872349, 38.362262044634136, 41.84253828866141, 47.504611424037385, 52.130256516592844, 49.843913555145264, 52.01894290106637, 52.04550239018032, 54.21710974829537, 49.82980523790632, 48.56659146717617, 41.52447754996163, 42.15049982070923, 39.589456353868755, 38.88512441090175, 40.43431213923863, 44.672647271837505, 44.65356057030814, 50.49000569752285, 47.03731380190168, 52.16159289223807, 49.975432532174246, 53.61291176932198, 45.15829856055123, 46.98251683371407, 12.572592513901846, 0.2925239918487412, 0.28513189564858166, 3.342839790242059, 12.784318021365575, 1.7154575777905328, 1.4201042034796305, 0.1327363502766405, 0.17374270489173277, 19.70530833516802, 46.16415452957153, 18.7657607623509, 36.59009272711617, 38.07375199454171, 0.28863129072955673, 0.015307563423578228, 0.017138084662812095, 0.10705578114305224, 0.051077374922377725, 0.027853530033358505, 0.015551888616755605, 0.05658990876483066, 0.04761428485757538, 0.03323277924209833, 0.020196216546797326, 0.04786643186318023, 0.007203771350240069, 0.08322342604930912, 0.045660422915326696, 0.04665614591379251, 0.025053723216322914, 0.0074421975295990705, 0.05588615259953907, 0.035084297747484276, 0.030124847976756946, 0.049284481842603, 0.06744947497333799, 0.04394599223243339, 0.0425038033697222, 0.09276468692613499, 0.03401775944179722, 0.017032256948628595, 0.21105816827288695, 0.1380811706185341, 0.0827587516978383, 0.04522252355569175, 0.029516015467899184, 0.022572434307741265, 0.01201425978381719, 0.0278661847114563, 0.03272965231112071, 0.05753901640751532, 0.03205285094944494, 0.042353877664676735, 0.08612436002918653, 0.05767975135573319, 0.04915846431893962, 0.024258034037692205, 0.09268813460533108, 0.04035494403381433, 0.01815442494781954, 0.022124348441138864, 0.014838012101660882, 0.13530768587120942, 0.03315779772986259, 0.1993112750351429, 5.969500958919525, 65.07293006352016, 27.2350937298366, 42.015670027051655, 60.867644037519185, 21.65798142978123, 0.5492406593901771, 0.7121952953083175, 0.49913470234189716, 1.6961853376456668, 2.1611765921115875, 4.880889339106424, 3.076986078705106, 0.9673399329185486, 1.1592216023377009, 33.55351802280971, 64.67180361066545, 61.89630399431501, 63.99773107256208, 63.009801455906455, 63.58330576760428, 58.27764047895159, 57.78929328918457, 54.24090732846941, 57.62782062802996, 50.77317258289882, 50.16099459784371, 48.51688058035714, 47.39438172749111, 44.872630323682515, 44.67081989560808, 46.54547166824341, 52.21728965214321, 57.53742803846087, 58.93220247541155, 56.53750583103725, 55.024038791656494, 58.31803035736084, 57.709840638296946, 57.654616355895996, 57.41052961349487, 56.7545918737139, 56.91344158990042, 45.549058301108225, 41.156949111393516, 40.109671456473215, 41.277406556265696, 43.70181022371565, 45.36341633115496, 47.99839557920183, 50.24529014314924, 48.88716050556728, 49.06240449632917, 50.55235883167812, 55.33233036313738, 54.577922752925325, 54.588230405535015, 52.41671337400164, 57.01184892654419, 56.243715150015696, 53.36907516207014, 37.09498010362898, 52.79945141928536, 57.37231452124459, 53.709780079977854, 55.613951274326865, 54.21239192145211, 53.836984225681846, 54.43271235057286, 52.64042452403477, 53.44471672603062, 51.403183119637625, 50.36533417020525, 51.23291751316616, 52.29113858086722, 48.20348903111049, 42.78006567273821, 39.44475664411272, 41.074352400643484, 38.62311826433454, 41.25328588485718, 40.71060725620815, 40.27466685431344, 39.3288711139134, 41.005356788635254, 40.6597638130188, 40.82781294413975, 42.88153716496059, 49.82094281060355, 54.56066690172468, 51.62326036180769, 52.92746850422451, 53.61677496773856, 56.42983307157244, 51.39700617109026, 50.216514178684776, 43.20935664858137, 44.243922574179514, 40.631477696555, 41.12970175061907, 42.010900088718955, 46.361862046378, 46.05583211353847, 52.33217811584473, 48.20469454356602, 53.28373738697597, 51.227178301130024, 55.57149083273751, 48.044701848711284, 49.484372070857454, 15.464702878679548, 0.2393963826554162, 0.7978967108896801, 8.313645550182887, 7.877552287919181, 1.2624724847929818, 0.6939347780176571, 0.1719767903642995, 0.12834525161555835, 23.881748914718628, 54.082481452396934, 25.10694214275905, 36.673516273498535, 45.85481030600411, 0.7164608378495488, 0.07588699007672922, 0.03796999861619302, 0.05229053107489433, 0.02672927044997258, 0.04272773688925164, 0.019663568253495863, 0.05671268628378, 0.015669872285798192, 0.05464875917615635, 0.008797241291696472, 0.07749960997274943, 0.011948464787565172, 0.025609210998352085, 0.029592489757175957, 0.10548976981746298, 0.04036492867661374, 0.0668793630653194, 0.041486234936330996, 0.028893232279058014, 0.05052276075418506, 0.04196097196212836, 0.033315339990492375, 0.11750158348253795, 0.15043828396924905, 0.1722878443875483, 0.09813274030706712, 0.14229851003204072, 0.26971264875360895, 0.24262895062565804, 0.10953976213932037, 0.1324324073003871, 0.08640797409628119, 0.1768433249422482, 0.16036012156733445, 0.10748067977172987, 0.057170768667544634, 0.1843433624931744, 0.14496175998023578, 0.11231041739561728, 0.21038815565407276, 0.19182721019855567, 0.21274535916745663, 0.037385196425020695, 0.15148605060364517, 0.1132616081408092, 0.327477719102587, 0.16138013611946786, 0.10467945651284286, 0.1981295384466648, 0.11170128293867622, 0.42913901114038056, 6.744886917727334, 74.61998421805245, 39.50463621956961, 44.993994508470806, 65.92881611415318, 32.14972134998867, 0.7441836073994637, 2.4731454976967404, 1.9987928484167372, 5.955510326794215, 8.24579117979322, 13.329280870301382, 2.800909612859998, 0.6332076851810727, 1.2574829182454517, 31.948543207986013, 69.85875197819301, 59.44986411503383, 67.7481324332101, 66.04330853053501, 67.91482666560582, 60.07944733755929, 62.583195958818706, 55.56998307364327, 60.286948340279714, 54.90957069396973, 53.26370920453753, 51.26861388342721, 50.7862525667463, 46.57415383202689, 48.30202143532889, 49.91431965146746, 55.16028254372733, 61.04813044411795, 61.92477771214077, 59.68952832903181, 56.60816206250872, 58.87775639125279, 61.14569704873221, 62.162128176007954, 60.81878430502755, 59.184686115809846, 59.716390064784456, 48.38734531402588, 43.581978116716655, 42.22275761195591, 44.29529060636248, 46.604500089372905, 48.339569500514436, 50.451047148023335, 54.32591159003121, 50.923205035073416, 51.273852825164795, 52.05576835359846, 57.46459354673113, 55.31558173043387, 56.7629714012146, 54.5005441393171, 58.720400537763325, 58.81959996904646, 57.14296490805489, 37.80546120234898, 52.95558786392212, 58.44213908059256, 55.78572811399187, 59.42018835885184, 55.933401652744834, 55.55160508837019, 56.502236774989534, 54.340089389256065, 55.20993089675903, 54.568619115012034, 51.452609130314414, 53.08146142959595, 55.56164870943342, 49.98304428373064, 44.414810044424875, 41.61811147417341, 44.250644956316265, 41.45111499513899, 43.27618442262922, 42.97819702965872, 41.968592507498606, 41.02521126610892, 43.63798407145909, 40.81460094451904, 42.960103920527864, 47.214736052921836, 53.1629637990679, 56.595262731824604, 52.40133353642055, 55.08411291667393, 55.31647457395281, 59.6178993497576, 52.687873772212434, 53.82348040172032, 44.79114185060774, 46.278789384024485, 42.87136500222342, 43.50008317402431, 44.761299337659565, 49.58385290418352, 48.10916723523821, 55.89817428588867, 49.91755403791155, 55.82894590922764, 54.05424744742257, 57.34404577527727, 49.608456475394114, 53.31682470866612, 15.99923300743103, 0.3040981707828385, 0.7153558571423803, 8.753527317728315, 26.374246665409633, 8.913166522979736, 2.9605079974446977, 0.9875525683164597, 0.359899669353451, 30.421690464019775, 56.09868540082659, 31.03925677708217, 48.34698322841099, 52.77626180648804, 0.8767304292746952, 0.19730745255947113, 0.10178051064057009, 0.19955181569925376, 0.15821497381797858, 0.14272039596523556, 0.13407989032566547, 0.15011133865586349, 0.1811321276639189, 0.15791179080094608, 0.1281963810324669, 0.21923790792269365, 0.08688680947359119, 0.1925327509109463, 0.13592424350125448, 0.18831923843494483, 0.10447788411485297, 0.17332213531647409, 0.16387091603662285, 0.09721979179552623, 0.17330583690532617, 0.1577234294797693, 0.20306199948702539], [0.048937149944582155, 0.019185830406578522, 0.040258663307343207, 0.040828944849116464, 0.03702083669070687, 0.03527902711981109, 0.02089878188313118, 0.03516619692423514, 0.05063865453537021, 0.028853755111673048, 0.03026333697406309, 0.07952357136777469, 0.04891785580132689, 0.0031744940663754407, 0.018459032888391187, 0.01854229422419199, 0.01230455148366413, 0.012665903611507798, 0.05866910291037389, 0.07741908822208643, 0.05750827877117055, 0.031057972727077346, 0.030222862360200713, 0.0470967831622277, 0.04177918564528227, 0.09983086240078722, 0.07441340200603008, 0.03705452595438276, 0.023823228797742298, 0.11979813953595501, 15.580254895346505, 54.34614127022879, 26.652914592197963, 56.09863676343645, 47.33262613841465, 5.5160228695188245, 0.2544721008411476, 0.3733772747218609, 0.34325588388102396, 1.5576468344245638, 1.3896142052752631, 3.7322756818362643, 0.8668496566159385, 0.22507512755692005, 3.1222618435110365, 40.87398372377668, 61.26246152605329, 61.82855210985456, 67.21921471187046, 61.08968761989048, 58.8978853225708, 56.461850370679585, 57.574239594595774, 53.71001284463065, 51.350762435368125, 52.887874194553916, 48.78440359660557, 45.0630978175572, 43.927772590092246, 44.40572527476719, 48.724089758736746, 58.412901060921804, 58.59477710723877, 58.29870046888079, 58.32999515533447, 59.32924338749477, 56.241981574467246, 52.997756481170654, 56.99584722518921, 58.19567258017403, 56.705238819122314, 55.715370655059814, 51.7556027003697, 41.26204061508179, 40.91607938494001, 39.9361332484654, 41.86130884715489, 42.29740558351789, 42.658534731183735, 42.21551411492484, 43.52281073161534, 42.76529727663313, 42.81740876606533, 43.917138372148784, 45.82794509615217, 43.6807085445949, 48.573046343667166, 54.19744634628296, 55.22648845400129, 53.172937938145225, 53.98285123280117, 56.21752391542707, 54.91338872909546, 55.50254038402012, 55.66886636189052, 53.689981188092915, 52.986924239567344, 53.499228818076, 51.550634316035676, 54.13338395527431, 50.53088194983346, 50.21993964059012, 48.64038481031145, 46.93625225339617, 42.61532041004726, 39.232530866350444, 38.75357416697911, 37.69370985031128, 38.91580070768084, 39.87001419067383, 37.289574827466694, 40.04205853598458, 39.161530699048726, 40.043121610369, 40.049406255994526, 38.88059071132115, 38.45623295647757, 43.826533862522666, 49.841238498687744, 52.59355545043945, 53.35122871398926, 51.25441871370588, 51.681944847106934, 52.300775732312886, 49.35848460878645, 45.85991028376988, 41.571113858904155, 39.87931782858712, 43.561088357652935, 46.51012965611049, 46.21456023624965, 50.225585051945274, 48.85557052067348, 51.53322907856533, 53.149758747645784, 50.58233683449881, 51.952973229544504, 45.708040033067974, 32.72542476654053, 1.1414846969502312, 0.276076682976314, 0.6830988994666508, 8.72159947667803, 3.6666790417262485, 0.3263029307126999, 0.3408864938787052, 0.30694704077073504, 2.1525000291211263, 36.357032775878906, 38.39682585852486, 26.47688545499529, 44.93524748938424, 11.238437635557991, 0.3678667832698141, 0.1178975086659193, 0.07986783289483615, 0.06960450219256537, 0.045212314996336184, 0.042479627167007754, 0.09048983720796448, 0.05698873129274164, 0.06488335731306247, 0.03208049785877977, 0.021184455304007446, 0.05217940400221518, 0.034295490610280206, 0.0560548737246011, 0.03524599942777838, 0.06173333991318941, 0.032326144498905966, 0.015082941191004855, 0.06551415739314896, 0.03910772542336157, 0.07412305687155042, 0.02206956861274583, 0.032445644693715234, 0.046538274203027995, 0.04168806178495288, 0.031123407251600708, 0.03777864156290889, 0.02805143325323505, 0.029362697087760483, 0.005975258677998292, 0.017093550713200654, 0.025632359220513275, 0.02707883981721742, 0.022098099313942448, 0.007858624648568886, 0.014841109614021011, 0.048857099775757105, 0.024200119377513016, 0.07918131830436842, 0.03851172401170645, 0.020068446706448282, 0.09049859030970506, 0.04761531623080373, 0.03151258101154651, 0.025847763554858308, 0.03549257226820503, 0.048362400249711106, 0.01757206717905189, 0.10117951860385281, 0.03270755921091352, 0.08265461014317614, 0.021828765016315237, 0.16851474185075077, 25.809076717921666, 55.657641547066824, 29.174120562417166, 67.55062294006348, 48.02487863813128, 7.645383443151202, 0.22653312289289065, 0.1976247083927904, 1.476137516754014, 1.6281788668462207, 2.9134235296930586, 4.551645040512085, 4.267494985035487, 1.058763352887971, 3.2678665561335425, 50.17735413142613, 58.250511237553184, 64.19245433807373, 68.62043012891496, 64.72556182316372, 59.68949358803885, 59.90217099870954, 57.987171036856516, 55.40806572777884, 52.440233026232036, 55.03552763802664, 51.3068984576634, 47.12950944900513, 46.3103654725211, 47.08665296009609, 50.9640291758946, 60.08788939884731, 61.49098777770996, 60.770827838352744, 59.9493909563337, 60.715700830732075, 58.03760801042829, 56.17096056256975, 59.07364000592913, 61.20556272779192, 59.86073889051165, 59.27724306924002, 53.352958815438406, 43.83091817583357, 42.9064290864127, 42.54671042306082, 44.233924116407124, 44.57263490131923, 43.68437371935163, 45.12725748334612, 47.65126357759748, 46.15499332972935, 46.99516602924892, 46.50496367045811, 46.78683819089617, 47.02771486554827, 49.984426975250244, 54.146884305136545, 57.79355948311942, 56.64958722250802, 50.47842305047171, 56.833436557224815, 57.32442058835711, 57.864465849740164, 57.98551389149257, 53.929082598005024, 56.42814813341413, 55.168008940560476, 52.98661504473005, 55.727359771728516, 51.42714398247855, 50.72249589647566, 51.16332088197981, 49.409564290727886, 45.87473773956299, 39.513575077056885, 38.89523751395089, 39.3297153200422, 40.46768781117031, 41.026211806706016, 38.707816805158345, 42.43275996616909, 41.61755214418684, 42.956014905657085, 40.4158090863909, 41.383814743586946, 40.89753116880144, 45.86078575679234, 52.765481676374165, 56.326506410326274, 54.53189441135952, 52.571175302777974, 53.23316492353167, 54.06577798298427, 51.108134814671104, 48.47237042018345, 43.09499972207205, 41.76610115596226, 43.043020248413086, 48.37279578617641, 48.56099469321114, 51.897672516959055, 49.58445044926235, 52.02093703406197, 53.238136359623496, 53.32315799168178, 53.540101596287315, 48.08016545431954, 37.15089920588902, 1.4354967432362693, 0.28908441641501015, 2.6224312356540134, 7.091982441289084, 1.6849105826445987, 0.3174957904432501, 0.3614766390195915, 0.33378326360668453, 3.3711569564683095, 43.96108225413731, 50.093374729156494, 25.134568180356705, 49.502638884953086, 18.129380464553833, 0.4758682793804577, 0.042754176006253274, 0.06960631388106517, 0.033494897319802215, 0.050676638925714154, 0.0612137924347605, 0.03661226022190281, 0.029330446318324124, 0.005659190280961671, 0.030369246112448827, 0.0281725992515151, 0.05458862061745354, 0.03511646030736821, 0.02885519021323749, 0.029046537088496343, 0.08277587792170898, 0.04649047480363931, 0.030011284963360856, 0.04418026662564703, 0.019105008404169763, 0.015741303363548856, 0.0513298578028168, 0.07458361251545803, 0.12398936892194407, 0.06865829189441033, 0.07782791235617229, 0.18195106514862605, 0.12412085543785777, 0.0940578186086246, 0.09657915295766932, 0.1027024361704077, 0.10800389133925949, 0.07904550952038594, 0.16970747070653097, 0.13105184638074466, 0.16970934346318245, 0.12744004518858024, 0.108864613010415, 0.11677274187760693, 0.08942716315920864, 0.12965162151626178, 0.14492248637335642, 0.10811253836644547, 0.12366215219455105, 0.11886925223682608, 0.06790090432124478, 0.11350886630160467, 0.07761890321437802, 0.26335122010537554, 0.1792396256434066, 0.17086767059351715, 0.1347753887197801, 0.24879593827894755, 29.755945341927664, 70.66559069497245, 38.59464454650879, 67.00841331481934, 59.62503514971052, 11.119159647396632, 0.5969018276248659, 2.5959006249904633, 2.6929298298699513, 6.477566267762866, 6.811571385179247, 14.332788348197937, 4.204747974872589, 0.6520507654973439, 4.340771121638162, 48.252814292907715, 65.43809958866665, 64.96679633004325, 73.81161689758301, 65.54182229723249, 62.88489368983677, 61.62708909170968, 61.1743722643171, 59.71237400599888, 55.392574719020296, 58.379827635628835, 54.21878773825509, 49.122398717062815, 49.58043091637747, 49.652594906943186, 54.49833113806588, 62.03337805611746, 64.87507316044399, 63.114934648786274, 60.765950202941895, 64.90023258754185, 61.00158446175711, 56.94146367481777, 61.624636377607075, 62.42500632149832, 61.681187765938894, 60.29778058188302, 58.219230447496685, 48.02107449940273, 46.92865787233625, 44.390446186065674, 44.93660238810948, 46.46558128084455, 47.208020618983674, 45.71542944226946, 48.40911749431065, 46.69044235774449, 47.8464732170105, 48.3522047996521, 47.52302415030343, 49.44082771028791, 52.93069594247, 57.47748940331595, 60.57718849182129, 57.840501512799946, 56.735036168779644, 59.99272687094552, 59.17456953866141, 60.62948758261544, 61.37385504586356, 58.00803647722517, 57.77388913290841, 56.55577264513288, 55.84871006011963, 60.91852569580078, 54.49042408806937, 54.00768756866455, 53.91543633597237, 51.56202936172485, 45.60938950947353, 40.761488914489746, 41.63864687510899, 41.544599533081055, 43.37653725487845, 43.34414822714669, 40.923138754708425, 45.359236989702495, 44.929285934993196, 48.6034586088998, 44.952892439705984, 43.70602430616106, 43.41256366457258, 48.98314292090279, 55.323502676827566, 59.10826982770647, 58.21663529532296, 52.89452709470476, 55.09654324395316, 57.42686135428292, 52.66471890040806, 49.33449942725045, 46.018113817487446, 43.76701211929321, 45.987736293247764, 51.634954180036274, 49.964318888528005, 53.39648233141218, 51.745058809007915, 56.354761259896414, 56.75566189629691, 54.826115880693706, 58.043937819344656, 51.00303636278425, 38.781023025512695, 1.453239294035094, 0.36420538116778645, 2.4465443193912506, 20.580692768096924, 13.725382038525172, 1.8498582116195132, 1.1765475869178772, 1.1440074358667647, 4.510042267186301, 52.74522420338222, 49.10798467908587, 36.02879292624337, 58.148014886038645, 20.61655763217381, 0.6749543622136116, 0.2677221255643027, 0.1591968954141651, 0.1637082847633532, 0.15504681239170687, 0.15454232160534176, 0.13545239024928638, 0.20099607748644693, 0.11400131987673895, 0.1029520013502666, 0.11256526157792125, 0.17338199567581924, 0.16425284982791968, 0.15412680033062184, 0.12564533363495553, 0.2529177399618285, 0.06812400663537638, 0.17153015147362435, 0.284282776926245, 0.09881016252828495, 0.19578207869614872, 0.14567319037658827, 0.11587046672190938], [0.020966820285788605, 0.08081949861454112, 0.037287992890924215, 0.038797207442777495, 0.015980408926095282, 0.027964143115761023, 0.01858298766559788, 0.03959550049954227, 0.02162336907349527, 0.06412091465400797, 0.018279348333765353, 0.0426750418597034, 0.07617791196597473, 0.02232982580816107, 0.021059894934296608, 0.0288143695465156, 0.023737080295437148, 0.04490442633894937, 0.0702973882268582, 0.06662858330777713, 0.01353860566658633, 0.006593861667040203, 0.037816164549440145, 0.02780909786399986, 0.05427690841523664, 0.052657469242279015, 0.09013395916138377, 0.054948569874146154, 0.03573035468746509, 0.10508798209152051, 2.1553381511143277, 45.82574599129813, 38.72533321380615, 31.95913573673793, 56.30414015906197, 26.04088773046221, 0.24265394785574504, 0.26860937795468737, 0.4977608589189393, 0.3023524358868599, 2.583672881126404, 2.9383389013154164, 5.544298129422324, 2.496313180242266, 0.3679289370775223, 4.175775723797934, 50.04823228291103, 57.44000734601702, 67.35642078944615, 63.70909595489502, 66.6269780567714, 60.6274448122297, 56.00020163399832, 55.5492114339556, 57.53391224997384, 54.191585540771484, 51.30293451036726, 46.99129935673305, 44.064631257738384, 46.11526700428554, 57.23433371952602, 59.088523047310964, 60.08396366664341, 59.075592449733186, 55.83970519474575, 58.94725227355957, 57.60944611685616, 60.124561991010395, 59.80287429264614, 57.51698991230556, 57.72443185533796, 55.35142748696463, 52.81134673527309, 42.754086358206614, 41.732909611293245, 40.6627584866115, 41.965854917253765, 42.224223681858604, 41.2905455998012, 41.423867634364534, 41.977639062064036, 40.34863042831421, 40.8143230165754, 41.13839394705636, 44.72633600234985, 47.738456521715435, 53.95128556660244, 53.86956432887486, 57.404700074877056, 52.52313545772007, 43.98581436702183, 61.56670924595424, 55.5953301021031, 55.93936668123518, 53.04113061087472, 53.62193053109305, 52.02316393171038, 53.82999781199864, 53.10029452187674, 53.97717455455235, 51.47590296609061, 50.188217639923096, 48.73456416811262, 47.47387259347098, 37.68995782307216, 38.276156493595664, 39.63096489225115, 37.96433523723057, 37.848161356789724, 39.712936265128, 40.027324880872456, 39.0577836717878, 42.86551809310913, 42.346362590789795, 43.25970329557146, 41.62332609721592, 41.36104202270508, 42.168460914066856, 46.40068858010428, 50.70781435285296, 50.58383069719587, 54.78922094617571, 52.92305987221854, 54.469885213034495, 51.37531042098999, 50.28246995380947, 43.25840745653425, 40.21792786461966, 41.144567421504426, 52.32946831839425, 50.57921014513288, 53.12590558188302, 51.72092424120222, 54.72349098750523, 48.77268198558262, 55.67128433500017, 46.95276812144688, 51.511033058166504, 13.9348589352199, 0.22213261973645004, 0.2596437861876828, 1.0450326268162047, 7.235680741923196, 1.1332922279834747, 0.3939483937408243, 0.21785821552787507, 0.03303982084617019, 14.025395699909755, 46.308208056858604, 14.023118427821569, 33.408179078783306, 33.59168447766985, 0.14470311600182736, 0.020327720026086484, 0.03454402441691075, 0.03783289383032492, 0.025112316411520754, 0.046744491173220534, 0.07388171553611755, 0.027695268525608947, 0.04695111865709935, 0.01887837770794119, 0.07919636821108204, 0.016563039805207933, 0.02668475516007415, 0.022357525303959846, 0.054877673142722676, 0.02493622130714357, 0.09566032833286695, 0.047173566184937954, 0.03906529662864549, 0.05899370049259492, 0.058192974887788296, 0.010333620993021344, 0.0567802581936121, 0.03794712520071438, 0.027321025928748504, 0.01936151838994452, 0.0185819478106818, 0.024642374931967685, 0.027301156727064933, 0.07866674448762621, 0.018526350347591296, 0.029194627356316363, 0.03841453065563526, 0.01454167889564165, 0.030521658648337637, 0.01063495415395924, 0.02116869972087443, 0.06321920268237591, 0.00689432630315423, 0.012982103474704283, 0.03885453347382801, 0.0977274649111288, 0.034042376692273786, 0.022741628710978797, 0.04609131979356919, 0.011637319162088846, 0.03224367874541453, 0.018927339098549316, 0.009770890697836876, 0.06711648391293627, 0.013307639131588596, 0.03930248532976423, 0.06450936916683402, 0.16537551315767424, 3.9384699889591763, 59.9617656980242, 35.86215427943638, 42.780079569135395, 65.27996553693498, 26.911165237426758, 0.5281883776187897, 0.13326893241277762, 0.3356800675392151, 0.6200906804629734, 1.7439011143786567, 5.588310624871935, 6.568941593170166, 3.6443705473627364, 0.34243254948939594, 5.700537059988294, 57.4194997378758, 60.059165545872276, 68.40054743630546, 64.67417989458356, 68.57431493486676, 60.59550394330706, 59.17430550711495, 58.39878926958357, 60.663804735456196, 54.41868393761771, 53.56854057312012, 48.96087047031948, 45.61306510652815, 47.04798970903669, 59.35488224029541, 63.567971093314036, 61.02108110700335, 59.037613596235005, 56.72875499725342, 62.297875131879536, 59.967206137520925, 62.043300083705354, 61.72329384940011, 59.967428479875835, 59.14097499847412, 57.89251920155117, 56.37810720716204, 43.46867731639317, 43.965546471732004, 42.69500582558768, 43.083792277744834, 44.15699366160801, 44.22428696496146, 42.29796143940517, 44.04636096954346, 42.0737361226763, 43.13822446550642, 42.7023709160941, 45.98266758237566, 47.815192426954, 55.77130365371704, 56.11859893798828, 57.244901929582866, 52.224720750536235, 47.54105819974627, 61.68457153865269, 56.305300508226665, 57.68779053006853, 53.78507770810808, 56.42972537449428, 53.464282853262766, 55.750778675079346, 55.66842862537929, 55.345952306474956, 54.558731828417095, 53.31551149913243, 51.92654575620379, 48.436323165893555, 41.97054842540196, 40.031455584934776, 40.81006377083914, 41.22457592827933, 40.23841462816511, 42.44376591273716, 40.736628259931294, 40.64925118855068, 42.74757242202759, 43.17106860024588, 43.83269691467285, 44.99744776317051, 43.61852216720581, 43.36252621241978, 48.39488410949707, 52.00275012425014, 52.262307030814036, 57.03172424861363, 52.54530021122524, 56.62526157924107, 52.7441646030971, 51.69034174510411, 44.34732913970947, 41.147628102983745, 42.916792324611116, 52.55466290882656, 51.68471370424543, 52.01156391416277, 53.7979006086077, 56.45140027999878, 51.57826382773263, 58.75572517939976, 48.1712007522583, 55.063664368220735, 15.991902657917567, 0.41364805666463716, 1.2919102651732308, 2.9552605875900815, 2.6834375049386705, 0.723249933549336, 0.5126799983637673, 0.1891136672347784, 0.1533643033887659, 16.71357904161726, 54.383626801627024, 20.74863072804042, 32.26647193091256, 44.118132386888774, 0.7577800378203392, 0.1067496125719377, 0.01971284855556275, 0.0894428916009409, 0.03521228302270174, 0.04164167373840298, 0.03913464969290154, 0.021052431049091474, 0.005719390331900546, 0.05205635167658329, 0.050042259573404274, 0.04367791322459068, 0.05247567274740764, 0.043844256084412336, 0.08164456327046667, 0.03433362088565316, 0.0319660697132349, 0.010841734308217253, 0.05837130067603929, 0.004862874305607485, 0.03625949325838259, 0.0333630715363792, 0.02005330180483205, 0.025188378490773693, 0.13145923880594118, 0.16716470143624715, 0.12430887749152524, 0.054882290573524575, 0.11536945003483977, 0.1651870161294937, 0.1395097446760961, 0.05741610657423735, 0.0737029147733535, 0.1438994455550398, 0.15151438622602395, 0.10998049777533327, 0.1094145385016288, 0.15882131271064281, 0.14099824694650515, 0.05507326086184808, 0.12023966227258955, 0.18131900977875504, 0.2055931386670896, 0.13877148500510625, 0.06127718796155282, 0.1127633870180164, 0.13102266937494278, 0.1015269828162023, 0.11891873101038591, 0.1281667019107512, 0.25403251871466637, 0.10229450091719627, 0.20503120310604572, 0.25709822135312216, 4.843962703432355, 68.56383010319301, 49.287307262420654, 43.17845106124878, 67.40163271767753, 39.36351135798863, 1.05453602543899, 1.285970315337181, 1.4719071494681495, 2.723405280283519, 8.909880025046212, 9.985201478004456, 11.624423095158168, 3.910620306219373, 0.4475123823753425, 5.249219860349383, 58.521695954459055, 62.458135332380024, 70.0687334878104, 68.59387411390031, 70.79789134434291, 66.32944924490792, 61.169994899204795, 60.39898109436035, 63.14197703770229, 59.39919785090855, 55.58148234231131, 52.01194259098598, 48.0664392880031, 50.46270275115967, 61.22650459834507, 65.06696156093052, 63.45790467943464, 63.90997532435826, 58.2400472504752, 63.960620743887766, 63.50907121385847, 66.98964623042515, 64.9114886692592, 63.74158573150635, 60.69313308170864, 60.52917643955776, 58.29382283346993, 45.38297551018851, 46.22688634055001, 45.59754630497524, 46.70971666063581, 47.89269610813686, 47.314602511269705, 45.75702830723354, 47.01818888528006, 44.44543422971453, 46.41810423987252, 45.83458062580654, 48.828833852495464, 53.45493752615792, 58.64690249306815, 58.059046677180696, 60.19838660103934, 56.80667904445103, 47.038661752428325, 64.2061631338937, 60.81355925968715, 59.609089033944265, 56.383627550942556, 57.53957155772618, 54.388556548527305, 58.277234009334016, 56.90271357127598, 57.41398286819458, 57.619055475507466, 54.90446029390608, 54.08857502256121, 51.141322885240825, 42.209382329668315, 42.41970430101667, 44.91449669429234, 43.02856799534389, 42.97845411300659, 43.972251483372276, 43.92859942572457, 42.00922209875924, 46.871634006500244, 46.798702239990234, 47.50643532616751, 48.136362484523225, 46.586278438568115, 45.82496779305594, 51.6583765574864, 54.021764619009836, 54.05633538109915, 59.90138585226876, 53.51688071659633, 57.9057867867606, 55.92876373018537, 54.441637311662944, 46.821360315595356, 43.22368383407593, 46.17895071847098, 55.16368021283831, 53.80518926892962, 55.74759292602539, 56.02716064453125, 59.17636217389788, 51.161097458430696, 60.80593013763428, 50.54119655064174, 57.81366409574236, 17.093582970755442, 0.25671197207910673, 0.676127413553851, 5.669393931116376, 14.94835444859096, 6.556585090500968, 1.0074390726430076, 0.4899242679987635, 0.18414941004344396, 25.28473785945347, 60.82353687286377, 23.844897406441824, 44.574865273066926, 52.112375327519004, 1.6429284811019897, 0.30492717772722244, 0.16241970605083875, 0.21828179779861653, 0.08225352130830288, 0.11674367343740803, 0.12904803747577326, 0.07972734221922499, 0.13544359643544468, 0.13860903015094145, 0.16499119092311176, 0.09553556609898806, 0.16531696915626526, 0.128345930150577, 0.1934734040072986, 0.16076241140919073, 0.19020084318305763, 0.13510913295405252, 0.14765401051512786, 0.1560347050960575, 0.16854094687317098, 0.05687298678926059, 0.10116666036524943, 0.12356805295816489], [0.04139126378244587, 0.06659353018871375, 0.030155975770737444, 0.020683813507535627, 0.038287929591855833, 0.029360159366790737, 0.039277389712099514, 0.011395145773089357, 0.07021061038332325, 0.07177609245159797, 0.03511284032304372, 0.009170779908475066, 0.07188354525715113, 0.03514227856482778, 0.029303986845271926, 0.01863949266927583, 0.02531008392439357, 0.020072377120543803, 0.04301323049834796, 0.02831578710382538, 0.057034186353640895, 0.03378059109672904, 0.0247692304463791, 0.060481151033725054, 0.05645429336332849, 0.014508174532758338, 0.004906495625618845, 0.023494195292836854, 0.04815523333049246, 0.08080244702952248, 0.06407630776188203, 17.98993706703186, 51.6391613142831, 32.16382966722761, 37.64253984178816, 57.47252491542271, 8.32374736240932, 0.12535711910043443, 0.5431174508162907, 0.45076150660003933, 1.1107685565948486, 2.9161278988633836, 4.559906882899148, 3.5998942596571784, 0.23846043859209332, 0.06865833260651145, 9.583047560283116, 58.6364871433803, 58.639363697596956, 71.09400272369385, 62.558995383126394, 66.36471830095563, 61.7545815876552, 59.62402766091483, 55.605908734457834, 53.78756168910435, 51.83147702898298, 47.9949631690979, 46.5074337550572, 53.53395244053432, 62.21587249210903, 59.57096426827567, 58.93757343292236, 58.67994812556675, 61.84672859736851, 63.69843741825649, 60.563834054129465, 55.47296190261841, 57.279173919132774, 55.88068567003523, 59.73856176648821, 59.324546405247276, 55.93393666403634, 46.0516597202846, 40.97905090876988, 42.04658951078142, 42.20054769515991, 42.46539912905012, 43.480232170649934, 40.59348842075893, 43.58125550406319, 46.59929241452898, 47.255254473005024, 50.417664527893066, 53.54125499725342, 54.577999183109824, 55.9140613419669, 55.9603328704834, 57.57773106438773, 50.602816649845664, 54.76266840526036, 58.279283727918354, 54.755438804626465, 52.613246645246235, 51.96894366400582, 53.378107820238384, 52.49343538284302, 51.80043942587716, 52.02358429772513, 52.2440402167184, 54.02365105492728, 50.98538793836321, 45.868182114192415, 40.42050954273769, 38.94617475782122, 38.598629338400706, 38.895133290972026, 39.34953853062221, 40.084320953914094, 41.96501765932356, 39.888687474387034, 40.250063283102854, 42.09806176594326, 42.948597703661235, 44.305132729666575, 44.38951512745449, 41.87977021081107, 41.985494000571116, 43.719250202178955, 48.75261558805193, 53.27204009464809, 52.66870716639927, 54.54194498062134, 51.72873749051775, 51.78758525848389, 49.787112031664165, 45.720314025878906, 38.72708068575178, 46.58224848338536, 50.70039020265852, 52.606093474796836, 56.03340012686593, 53.16076469421387, 54.25237880434309, 54.03572702407837, 50.28607259477888, 51.418371881757466, 25.99276798112052, 0.057051977541829856, 0.141175439581275, 0.8172246451888765, 2.294682536806379, 2.4148173247064864, 0.3545921141547816, 0.038043904650424204, 0.09150901037667479, 1.776142275759152, 36.92851516178676, 32.34763036455427, 20.37224507331848, 40.856310980660574, 11.092728699956622, 0.0569211288488337, 0.0324871778222067, 0.056142041725771766, 0.02357515469858689, 0.05503378708713821, 0.04993745983977403, 0.01183360322777714, 0.0074068458551274875, 0.0652238597561206, 0.03611533510099564, 0.028626768184559684, 0.06728136113711766, 0.04236533472846661, 0.012889654774750983, 0.0638250530298267, 0.03401018699098911, 0.008663216206644262, 0.010457395958448095, 0.012411994959360786, 0.030791797009961944, 0.048872424489153285, 0.03611965058371425, 0.0334636270334678, 0.01634370505676738, 0.027168871236166785, 0.05376109627208539, 0.04105186735146812, 0.023867004484470402, 0.10783115667956215, 0.06024441695106881, 0.066328433342278, 0.02755509676145656, 0.030465024723006145, 0.018096121826342175, 0.04969797429761716, 0.025320797992338027, 0.030127931918416704, 0.003325639438116923, 0.03176658720310245, 0.03236159795363035, 0.010958682363187628, 0.0509801408542054, 0.01836500150550689, 0.02139347292748945, 0.048123705200850964, 0.027592524753085206, 0.018805713392794132, 0.07509651713605438, 0.011294700537941285, 0.006850350024511239, 0.031127298649932657, 0.03446783171966672, 0.04598878636690123, 0.01994562677906028, 0.11056888263140406, 30.432668617793492, 54.97608927318028, 30.61958905628749, 55.7335193497794, 59.55929824284145, 8.430842552866254, 0.18952135821538313, 0.37671699694224764, 0.41529301553964615, 1.0534065089055469, 2.9108733236789703, 9.678830214909144, 7.485930102212088, 1.425398079412324, 0.13991508792553628, 14.38819328376225, 63.88159193311419, 62.497691426958355, 72.63217408316476, 64.24962411608014, 68.14378370557512, 62.128908838544575, 60.894748960222515, 56.78851645333426, 56.10220118931362, 54.63439771107265, 49.69302647454398, 48.53539058140346, 54.73941625867571, 61.46223613194057, 61.811515126909526, 61.292526381356375, 62.57707459586007, 61.84255967821394, 63.404973302568706, 60.9599369594029, 59.26026862008231, 58.11900268282209, 57.73537526811872, 60.87425872257778, 61.08392061505999, 58.198754106249126, 47.41091496603829, 42.45155484335763, 44.439344133649556, 45.382235527038574, 44.42632668358939, 45.13574818202427, 43.10260452542986, 45.03521817071097, 46.82075234821865, 47.969101973942344, 50.00174536023821, 54.14673144476754, 56.042908736637656, 58.0548916544233, 56.404916831425254, 60.10140364510672, 52.35230009896414, 52.471659728458945, 59.232065882001606, 55.73630557741438, 56.229565143585205, 54.54219511577061, 53.63951989582607, 54.892846379961284, 53.65124845504761, 53.83830438341413, 53.57031236376081, 54.351418427058626, 52.19583361489432, 48.96571683883667, 43.47404479980469, 40.875168391636436, 39.44193567548479, 40.49707521711077, 42.17467607770647, 41.36347736631121, 42.54639775412423, 41.398788111550466, 42.316624300820486, 45.167428493499756, 45.199911321912495, 46.98913846697126, 45.802584171295166, 45.521359307425364, 43.313326018197195, 45.059227670942036, 52.32127291815621, 54.77102361406599, 55.03503431592669, 54.98955488204956, 53.78635965074812, 54.80133860451834, 52.3214362008231, 48.01690558024815, 40.25744227000645, 49.057829107557026, 53.545993668692454, 55.69189964021955, 56.30134350912911, 55.15474830354963, 55.4661283493042, 56.842920848301475, 51.185228552137104, 54.09163222994123, 30.454499857766287, 0.13988382103187696, 0.7179519864065307, 3.3888928847653523, 3.0219370211873735, 1.0512916509594237, 0.07759627407150609, 0.0547958282487733, 0.12622857519558497, 2.909145393541881, 45.58549812861851, 42.17148338045393, 17.727583510535105, 45.334136622292654, 17.542565141405376, 0.24531619357211248, 0.05590846961630242, 0.04964931315875479, 0.004541151167359203, 0.05423304112628102, 0.03386659880301782, 0.08176923050944294, 0.0030257290802962545, 0.05713144077786377, 0.0854847322085074, 0.054407882637211254, 0.047304428448634486, 0.08883652556687593, 0.03389269865251013, 0.03645777815420713, 0.05827156959899834, 0.07527816774589674, 0.02913129629035081, 0.034432938056332726, 0.025424613850191236, 0.05923153380198138, 0.04193365074960249, 0.06557322386652231, 0.022823646631357924, 0.12144759031278746, 0.13931227741496904, 0.1190965071852718, 0.06963664439639874, 0.14325908491654055, 0.14681391630853924, 0.175848497610007, 0.08178455183016402, 0.20658488545034612, 0.11875060360346522, 0.08324548522276537, 0.07317731476255826, 0.12725400445716722, 0.09981491682784897, 0.09806799449558769, 0.11303673485027892, 0.08419645205140114, 0.11766063209090914, 0.08210560067423753, 0.09613638171660048, 0.10486039466091565, 0.14790006088359015, 0.12049184659762041, 0.2251520598573344, 0.14085537461297853, 0.16994543293757097, 0.1528175805828401, 0.18118939601949283, 0.14934173066701206, 0.13246287352272443, 0.1514281579958541, 34.08584383555821, 68.79915169307164, 40.49591834204537, 45.85767991202218, 71.3658926827567, 14.448502779006958, 0.44593256286212374, 2.048269884926932, 1.0916032535689217, 5.154584961278098, 8.348700080599103, 13.566383804593768, 9.46002275603158, 0.7302424811891147, 0.24652368734989846, 13.346510665757314, 65.77678952898297, 65.32911014556885, 76.59002086094448, 66.3269270488194, 71.77729552132743, 65.12850870404924, 64.52758680071149, 60.039245060511995, 58.28026342391968, 58.08291721343994, 52.27809681211199, 51.1162086214338, 58.48020131247384, 67.80549676077706, 63.04201330457415, 62.083898408072336, 64.44283267429897, 65.33038166591099, 67.8307465144566, 64.01602567945207, 60.21062237875802, 58.76681450435093, 59.13106686728341, 61.12484550476074, 66.25847339630127, 62.49076407296317, 51.254609789167134, 44.09484549931118, 47.064189434051514, 46.334371498652864, 47.33571113858904, 47.966875076293945, 44.837660040174214, 48.66666637148176, 49.73060233252389, 52.42798335211617, 54.122718470437185, 58.595339911324636, 57.960357938494, 59.329014096941265, 60.731348173958914, 63.0971611567906, 55.28694820404053, 59.45024626595633, 60.98157364981515, 59.56857408796038, 59.421300070626394, 57.79455654961722, 57.63597781317574, 58.08885097503662, 55.66268593924386, 56.77464090074812, 56.69863108226231, 59.17724459511893, 55.34269707543509, 49.399729115622385, 45.28909492492676, 42.12399591718401, 40.75326919555664, 41.91200985227312, 44.54296261923653, 44.31776455470494, 45.556767327444895, 43.01402541569301, 46.2925363949367, 48.61976603099278, 49.278542109898154, 50.99326719556536, 49.33025755201067, 47.44569417408535, 45.954888684409006, 47.222823756081716, 55.08934838431222, 57.72892039162772, 56.76002883911133, 57.422115734645296, 54.506568227495464, 55.730128628867014, 53.65420838764736, 50.73564536230904, 42.80746589388166, 51.38185214996338, 54.8215856552124, 57.76902191979544, 59.344126428876606, 57.53609051023211, 57.78439828327724, 58.11502136502947, 51.466397830418174, 57.13444294248308, 29.556556361062185, 0.17207817706678594, 0.4505259192415646, 2.3460388439042226, 10.900371296065194, 10.252455251557485, 0.8568070669259343, 0.36083604767918587, 0.40778670832514763, 4.96888176032475, 54.206635338919504, 43.81116097314017, 31.03809642791748, 56.4188688141959, 20.235210963657924, 0.4458954062845026, 0.1606509688177279, 0.10444590475942407, 0.10187964460679463, 0.1078833970906479, 0.12275917136243411, 0.1090598546766809, 0.11181421152182988, 0.16708646634859697, 0.17774847708642483, 0.15781192401690142, 0.1457407453230449, 0.200635680396642, 0.09506814368069172, 0.20912926963397435, 0.1788666078022548, 0.19370287097990513, 0.07717302428292376, 0.10754409565457276, 0.07792459002562932, 0.11569612393421785, 0.16235455311834812, 0.13683202836130345, 0.08094945842666285], [0.03046412905678153, 0.05138132807665637, 0.02231455368122884, 0.11137953520353351, 0.05141047115570732, 0.016981103889910237, 0.03511479789657252, 0.005418845543837441, 0.028188339567610195, 0.0864819615547146, 0.1309256660086768, 0.01146357602972005, 0.04572893459615963, 0.05983143339731863, 0.024583047222612158, 0.03552223442654524, 0.06879748656813588, 0.04986601349498544, 0.04414266900026372, 0.031620807347020934, 0.06334534912769284, 0.022792976848515015, 0.06062521758888449, 0.038688065085027895, 0.1219024123357875, 0.02753513935022056, 0.024304435654942478, 0.017210659072069184, 0.01112645014654845, 0.028489904278623204, 0.06061973502593381, 1.1685087382793427, 41.06869656699044, 46.22748041152954, 20.847230877195084, 51.34580489567348, 39.97550868988037, 1.5856312470776694, 0.23566726275852748, 0.5279240746583257, 0.3072242358965533, 6.086932463305337, 9.062961867877416, 5.636135510035923, 2.3196456772940497, 0.30470233836344307, 0.13926362645413193, 23.5093480518886, 56.781592573438374, 58.733331135341096, 70.57125500270298, 64.63262966700962, 63.00329794202532, 59.70241723741804, 58.26936517442976, 53.28761795588902, 56.0295021874564, 51.808593136923655, 52.47517899104527, 57.53180347170149, 62.08479472569057, 62.08335644858224, 61.94922842298235, 57.17083065850394, 58.19234439304897, 57.820723465510774, 59.31420748574393, 62.06730610983712, 57.93882894515991, 56.33373253686087, 57.81120095934187, 58.77335275922503, 56.66693687438965, 43.893351214272634, 41.47314773287092, 42.19264759336199, 42.570313453674316, 43.809528146471294, 43.646242005484446, 47.344615255083355, 53.81967626299177, 55.56125961031233, 54.99553033283779, 56.114030497414724, 55.77130017961775, 56.07003102983747, 55.774753434317454, 56.13179704121181, 54.565669604710166, 48.06108570098877, 50.17672879355294, 55.625853538513184, 56.991435119083945, 52.4666222844805, 49.87099763325283, 50.81674821036202, 50.391310010637554, 52.245120661599294, 52.751408100128174, 51.893805844443186, 48.208189487457275, 43.4964006287711, 39.5323942729405, 39.955539567129954, 41.39103739602225, 40.4359484400068, 39.58222327913557, 39.15213673455374, 38.96900653839111, 42.48987068448748, 40.40094688960484, 40.091147559029714, 42.59723424911499, 43.39935861315046, 48.0579902785165, 47.468519006456646, 46.174823488507954, 43.55589805330549, 43.4183862549918, 43.71605403082711, 51.854454721723286, 54.88252483095442, 57.13801431655884, 53.71812834058489, 54.16227109091622, 52.62832771028791, 50.28563485826765, 41.026211806706016, 44.19961391176496, 55.234902722494944, 54.878029346466064, 52.72489030020577, 54.52400473185948, 49.98368351800101, 53.881970337459016, 50.4928092956543, 39.37233904429844, 1.0196763702801295, 0.08873139335108654, 0.27014620548912455, 4.0201920952115735, 2.2641030805451527, 0.9450788817235402, 0.4263209466423307, 0.032855283069823465, 0.09236138606710093, 20.867898293903895, 45.154213019779746, 20.238365445818218, 38.09568050929478, 31.337237221854075, 0.2937166392803192, 0.017817193043551276, 0.014524060733882444, 0.03437850597713675, 0.04085279196234686, 0.05355462824393596, 0.031156099068799188, 0.02208057275441076, 0.0073520482151902145, 0.10643465018698148, 0.015262759756296873, 0.05563937619860683, 0.05213006432833416, 0.028070623919899975, 0.08546252375734703, 0.032592293074620624, 0.026379648496263793, 0.024414005489753823, 0.004408218099602631, 0.02199844966110374, 0.03626489100445594, 0.03600574491013374, 0.038481851507510455, 0.0578923567331263, 0.07780660635658673, 0.045316989200987985, 0.03157885013414281, 0.08432049503816025, 0.0763459104512419, 0.004158813647726285, 0.024850595276802778, 0.019291788738753115, 0.026948442350008657, 0.04309208644554019, 0.040848717359559875, 0.06964346367333617, 0.02469850504504783, 0.034099509340843985, 0.02685503861201661, 0.02873496737863336, 0.02909782755055598, 0.013850929398488785, 0.02959991293027997, 0.06591327847646815, 0.04878396727144718, 0.08019657632602112, 0.06029434355774096, 0.04501120400215898, 0.03250581717916897, 0.03503431346533554, 0.05255872543369021, 0.08591194464159863, 0.04419729106926492, 0.031054044009319375, 0.023446879349648952, 0.0114778210242678, 3.1310721593243733, 57.055167470659526, 42.15235498973301, 25.083505868911743, 67.76935223170689, 37.494178431374685, 1.7657187836510795, 0.24612525158694812, 0.3978117550058024, 0.32042904304606573, 1.2996299309389931, 3.92048761674336, 14.026321547372, 5.652112892695835, 0.6017720805747169, 0.04987603884988597, 28.548166036605835, 60.51393904004778, 59.42985330309187, 71.00517695290702, 65.34990610395158, 65.0559834071568, 61.39321272713797, 60.728339603969026, 56.559573309762136, 58.46192755017962, 54.04738957541329, 53.99995769773211, 58.209892068590435, 65.08959879193986, 64.14942414419991, 62.22054862976074, 60.614451680864605, 59.5087639944894, 61.39868095942906, 62.46587562561035, 61.80601215362549, 58.904388836451936, 57.024366106305806, 59.6565591267177, 59.85741070338658, 56.84240320750645, 46.739406313214985, 43.12584624971662, 43.82567923409598, 44.723626204899375, 45.382200786045615, 45.752477237156455, 48.47956527982439, 53.31834636415754, 55.54720687866211, 55.508314337049214, 58.43861634390694, 57.55335330963135, 57.95718955993652, 58.9774352482387, 57.70769017083304, 55.02609198434012, 49.17105695179531, 53.72901964187622, 56.28940302985055, 58.62436253683907, 55.56790556226458, 52.86312123707363, 55.516280446733745, 52.30561515263149, 54.80190140860421, 54.98256846836635, 54.80678251811436, 50.1822178704398, 47.6595527785165, 42.971380846840994, 42.803178855351035, 42.28827217647007, 42.26871299743652, 42.37452711377825, 41.16770839691162, 41.90295287540981, 44.25565808159964, 42.113726479666575, 41.398881912231445, 44.04214688709804, 44.57929127556937, 48.194168022700715, 49.90330328260149, 47.68439606257847, 45.34111956187657, 45.76290300914219, 46.739694663456504, 52.513189111437114, 55.91645152228219, 58.28487007958548, 53.97781726292202, 55.029586928231375, 55.24897282464163, 53.00069556917463, 43.17155497414725, 46.348584038870676, 56.67801925114223, 55.70745318276541, 53.797521931784495, 56.86166361400059, 53.16997800554548, 54.72552680969238, 50.83661311013358, 44.16717972074236, 1.718901930110795, 0.5530860530478614, 2.256418590034757, 4.119916549750736, 0.6386749946645328, 0.5601511225104332, 0.30601459794810837, 0.05230325699916907, 0.07931483363998787, 26.739049673080444, 51.994999408721924, 26.2508362361363, 34.104037693568635, 45.23552431379046, 0.8061248436570168, 0.13872302403407438, 0.03250770350652082, 0.04874516185373068, 0.09478182225887265, 0.07298471938286509, 0.021529154486155937, 0.020961984027443186, 0.057596427255443165, 0.029629907570779324, 0.04661822937695043, 0.02480909607506224, 0.040000216104090214, 0.03178894153929182, 0.030203320551663637, 0.07299617983933006, 0.013331451469899287, 0.07266219811780111, 0.03489738849124738, 0.024887441424652934, 0.015922667292345847, 0.044876949063369205, 0.04565195140561887, 0.034588203831974945, 0.052478946678872616, 0.1496311937059675, 0.136970313798104, 0.14698331936129502, 0.23357816200171197, 0.17510229907929897, 0.09680496262652533, 0.10813613102904387, 0.11084700735019785, 0.13816947516586098, 0.12178702067051615, 0.19706746829407557, 0.0965033063132848, 0.11264271635029997, 0.16085347080869333, 0.0883474646668349, 0.17275250516831875, 0.1704725053693567, 0.0971422488135951, 0.1319633089005947, 0.11641674169472285, 0.26141704246401787, 0.08942829631268978, 0.20484467382941926, 0.1913340373763016, 0.18397164743925842, 0.18502846573080334, 0.2922857989157949, 0.10334271538470473, 0.10266468248197011, 0.10149412136524916, 0.1705519753907408, 3.4801466166973114, 65.43370832715715, 57.292062827519004, 30.203864438193186, 63.73164285932268, 54.88846901484898, 2.6691811042172566, 0.4509334202323641, 1.5543175616434641, 1.6783718935080936, 11.853041410446167, 19.417449678693497, 12.949939625603811, 6.795553181852613, 0.7815937399864197, 0.23003173087324413, 27.987816401890345, 70.81774929591587, 62.383977208818706, 72.79349735804966, 69.9124893460955, 67.3520781653268, 65.03140068054199, 62.27049228123256, 57.5141932623727, 62.34288556235177, 57.0149165562221, 56.73390013831002, 61.49450356619698, 67.93495559692383, 66.22822788783482, 65.24516201019287, 62.91167899540493, 61.48407432011196, 62.320991788591655, 64.74656622750419, 65.40908391135079, 61.745514188494, 60.27329513004848, 61.242096355983186, 63.88486453465053, 59.89767551422119, 48.0413111277989, 45.60652337755476, 46.271577153887065, 48.20012610299246, 48.713250568934846, 49.54207338605608, 54.10043559755598, 58.99428462982178, 60.14799131665911, 58.02387489591326, 62.713710921151296, 60.846333912440706, 61.436819621494834, 59.86513710021973, 58.92560168675014, 57.284193992614746, 50.083959920065745, 54.62027897153582, 58.728022711617605, 62.310486112322124, 56.97519023077828, 53.915637833731516, 55.60165991101946, 53.53071457999093, 55.713484219142366, 56.9452817099435, 56.90490920203072, 51.961585521698, 49.348378453935894, 44.41156523568289, 44.67263684953962, 46.46446262087141, 43.703856468200684, 44.76691000802176, 43.282628876822336, 44.5611321585519, 46.804326806749614, 44.62310314178467, 44.43726314817156, 45.616330759865896, 46.08974974496024, 51.689799785614014, 53.26489387239729, 51.43946313858032, 48.580470493861604, 47.803807803562705, 47.58461993081229, 55.189513615199495, 58.77673653193882, 62.484100750514436, 53.9650673185076, 56.707813126700266, 58.272147927965435, 54.311705998011995, 46.18861566271101, 49.47679158619472, 58.5342652457101, 57.67457158224923, 55.616542952401296, 60.135519300188335, 53.036874839237754, 55.810536657060894, 54.7793927192688, 44.47194855553763, 1.6444639244249888, 0.4851372848664011, 2.0406003764697482, 9.112211568014962, 8.143603154591151, 2.9229612350463867, 0.7103886008262634, 0.33537730521389414, 0.17173660253839834, 36.28820044653756, 58.3289737701416, 31.754493917737687, 49.788682324545725, 51.105101925986155, 1.3339981096131461, 0.3542937215949808, 0.08366870786994696, 0.23312248502458843, 0.27104757140789715, 0.17795503671680177, 0.20481698960065842, 0.13981321267783642, 0.15866752953401633, 0.1410256733319589, 0.17060156272990362, 0.12527061945625714, 0.08980280014553241, 0.10608034634164401, 0.1376144199499062, 0.19397866832358496, 0.1037019861063787, 0.12136999304805483, 0.17666753008961678, 0.18879433508430207, 0.07172643047358308, 0.101287663515125, 0.096673598246915, 0.20874532737902232, 0.10854821891656943], [0.025268693288256015, 0.032632645552179644, 0.01930572584803615, 0.03561448465500559, 0.056738290802708695, 0.053586214049054046, 0.009476322531034904, 0.019997422749708806, 0.008959693601354957, 0.09132322070321866, 0.046290011810404916, 0.034122481143900325, 0.028193871324349726, 0.013413086866161652, 0.0412710646965674, 0.05964014759021146, 0.014600385745455111, 0.022158534731715918, 0.026775665281872665, 0.031636990407215695, 0.07000117376446724, 0.026451708915244256, 0.022735869645008018, 0.015930847031995654, 0.0331680300379438, 0.053596690629741976, 0.029766995393271958, 0.025657012094078318, 0.06344746186264924, 0.035873847880533764, 0.03452652160610471, 0.04521423864311405, 12.209047130176, 58.86296367645264, 30.580088547297887, 26.891150951385498, 60.762073108128135, 17.846204893929617, 0.010609936567821672, 0.3298427664807865, 0.37979198193975855, 0.18135832409773553, 6.3745978730065485, 16.286902325493948, 6.223750310284751, 0.6591181148375783, 0.16765693788017544, 0.7205277596201215, 49.63142374583653, 66.8102159500122, 70.5786965233939, 68.9446747643607, 65.63418470110211, 62.530938557216096, 59.70985875810896, 57.61250332423619, 54.57068967819214, 55.335953848702566, 58.638154711042134, 60.17445700509207, 62.70893750871931, 61.398250171116416, 60.80134432656424, 60.348141125270296, 60.57137284960066, 63.281163351876394, 60.67577648162842, 57.64628893988473, 58.07711199351719, 55.59176220212664, 58.33895138331822, 58.385400090898784, 57.82107087544033, 45.423302854810444, 41.49571895599365, 43.18137277875628, 42.36382341384888, 43.30469635554722, 48.207915033612935, 54.9919867515564, 58.311575480869834, 57.03215503692627, 58.26782962254116, 57.87847341809954, 57.69323444366455, 58.70533684321812, 56.87206506729126, 54.8506430217198, 51.86679819652012, 48.62261479241507, 50.55175086430141, 55.56374706540789, 55.21203967503139, 54.995380946568076, 50.02136012486049, 49.0004369871957, 47.45104776109968, 46.121416160038535, 45.48214714867728, 44.579416343144004, 41.74406494413103, 40.86529847553798, 38.92664337158203, 40.15907314845494, 39.25002990450178, 39.6544463293893, 39.32937833241054, 39.65030172892979, 40.97329085213797, 42.35973787307739, 41.315725871494834, 42.05578197751726, 41.44081081662859, 43.768985407693044, 44.853474140167236, 46.689282008579795, 46.57772173200335, 47.329541138240266, 46.26061289651053, 47.074128832135884, 49.29644066946847, 52.75416306086949, 55.29046746662685, 55.945852824619834, 53.27306842803955, 53.068655899592805, 50.30939074925014, 46.237492765699116, 46.859731742313926, 51.72697959627424, 51.479158197130474, 57.20049599238804, 48.508011204855784, 57.77496610369001, 49.37130056108747, 49.04761872972761, 6.309533638613565, 0.29695379414728706, 0.2140671589544841, 3.0766721069812775, 5.8272248676845, 1.010983522449221, 0.04759857337921858, 0.05174545032371368, 0.2523229361644813, 10.455124650682722, 42.18200642721993, 25.10718706675938, 21.745191744395665, 48.49776956013271, 9.244962113244192, 0.25805178018552916, 0.021412156389227936, 0.05440216597967914, 0.025906668876164725, 0.04098379332572222, 0.04554131627082825, 0.028110235097951124, 0.030008625106087754, 0.0069941608567855185, 0.10800888535699674, 0.033585424069315195, 0.014881373882027609, 0.027509494119190743, 0.06223238206335476, 0.0496779235878161, 0.025145569716447165, 0.02589387000937547, 0.0415172100599323, 0.07877623289823532, 0.05854978931269475, 0.03724248015454837, 0.007380656099745205, 0.054816889975752146, 0.03187589580193162, 0.006918965606018901, 0.028827234570469176, 0.018182706287396804, 0.02550290322064289, 0.03335623868874141, 0.03124593710526824, 0.027529125833617787, 0.02552596153691411, 0.033900403417646885, 0.0698527917265892, 0.037454169509666305, 0.029188995515661578, 0.008617862925997801, 0.03189007718382137, 0.007709371541360659, 0.045315357324268134, 0.019142565317451954, 0.02605135629086622, 0.009763778802672667, 0.035599723125674894, 0.011913717857428958, 0.06980743844594274, 0.034779805157865794, 0.01803422755827861, 0.028402471648795263, 0.028007874697712914, 0.024926589502553855, 0.017607283146519746, 0.030440882447042635, 0.021932862466201186, 0.04476565574961049, 0.022075990946697335, 0.20871756172605924, 22.104899985449656, 64.58514567783901, 20.832950592041016, 42.45394502367292, 71.30031558445522, 18.177640914916992, 0.050954241172543595, 0.09506432352853672, 0.22834234152521404, 0.25753967623625484, 0.897339003426688, 7.5037522315979, 11.858124886240278, 3.9040325454303195, 0.5137009492942265, 1.4169799025569643, 58.33253124782017, 67.91781439099992, 72.89498274666923, 71.059449332101, 68.55780601501465, 62.60362366267613, 62.266135760716026, 59.53672354561942, 58.25792843954903, 56.59627716881888, 60.21174798692976, 62.5672151020595, 64.93610613686698, 61.509615898132324, 63.80348028455462, 63.026386805943076, 62.128255707877024, 63.43799809047154, 60.73359244210379, 58.459217752729145, 58.40693950653076, 56.91969844273159, 60.161304065159385, 61.40143939426967, 59.55073111397879, 47.31210810797555, 42.70864166532244, 46.44388553074428, 44.68551533562796, 44.96211617333548, 48.10243443080357, 57.46791825975691, 59.73256547110421, 60.32672677721296, 58.72796712602888, 59.54962635040283, 57.27720757893154, 59.799483571733745, 57.02233028411865, 56.50063174111502, 53.186427865709575, 51.37487963267735, 53.27705669403076, 58.08693674632481, 58.10183368410383, 56.97149726322719, 52.308853013174875, 50.94170808792114, 49.721830231802805, 48.7519450868879, 48.36231790270124, 48.18701832635062, 44.19970771244594, 42.28773716517857, 40.398928437914165, 41.429787499564036, 41.9924248286656, 41.259191853659495, 41.83796289988926, 41.81752477373396, 42.52826295580183, 43.85078307560512, 41.98788070678711, 43.30514451435634, 44.85387713568551, 46.371033668518066, 47.833018030439106, 48.109702246529714, 48.66577352796282, 48.87937157494681, 48.490508692605154, 48.6295108795166, 51.817382608141216, 55.69971636363438, 56.503654207502095, 55.99474034990583, 55.61370461327689, 54.90058667319161, 52.67164625440325, 48.62827410016741, 47.6366480418614, 54.58713606425694, 53.84692709786551, 58.0007895060948, 50.363277503422324, 57.02209057126726, 51.889088017599924, 52.523250102996826, 9.266820277486529, 0.4057616612740925, 1.5178107491561343, 4.14654769216265, 0.27831812841551645, 0.5498880903635706, 0.13384705781936646, 0.046419520396739244, 0.11777451740843908, 16.133433989116124, 50.54576499121529, 40.10064574650356, 19.20328187942505, 55.795549392700195, 13.438474416732788, 0.3171694965234825, 0.05921298265457153, 0.012996610553402985, 0.036569397164774795, 0.07930979212479931, 0.023973826252456223, 0.02327673669372286, 0.039187578817031214, 0.0038316054020210034, 0.019351925601118376, 0.07407431091581072, 0.030934340254004513, 0.01695747560422335, 0.009273048706485756, 0.02904628263786435, 0.031715731003454754, 0.04257711229313697, 0.029219692439905236, 0.020634288932862024, 0.0828552936602916, 0.03015151440298983, 0.04083849522950394, 0.014952402927779725, 0.06218902367566313, 0.03099502164072224, 0.09300857955323798, 0.09840678024504866, 0.0959779302190457, 0.114113753129329, 0.11672372450785977, 0.13199400582483836, 0.09733576021556344, 0.10437524212258202, 0.1441614550671407, 0.23378628226263182, 0.17213180847465992, 0.08758551733834402, 0.1279592059020485, 0.06863285361656121, 0.18361875494675978, 0.26451634615659714, 0.16304085057760986, 0.10485982469149999, 0.09804694633930922, 0.07383932745350258, 0.18473486362823419, 0.08348842111549207, 0.11928252077528409, 0.0977996474664126, 0.0913556275357093, 0.1561254659401519, 0.18446275751505578, 0.12770119974655764, 0.11450623135481562, 0.08973314174051795, 0.18659352032201632, 0.17137958455298627, 25.294110979352677, 75.72105135236467, 42.286027908325195, 37.6383500780378, 75.9488410949707, 28.824311767305645, 0.29041752059544834, 0.6464441120624542, 0.9883892834186554, 1.0591789420161928, 13.561479244913373, 25.54111075401306, 19.93300254004342, 4.3583939245768955, 0.4879161300403731, 1.5628433270113808, 56.05526958193098, 72.42307499476841, 72.13296685900006, 73.40006119864327, 72.23029027666364, 67.105820110866, 63.878743171691895, 60.78678090231759, 61.98221846989223, 60.96621118273054, 63.45075498308454, 65.06662804739815, 65.88438238416398, 64.86703409467424, 64.77674920218331, 65.61380563463483, 64.12668269021171, 67.48380211421421, 64.49144921983991, 59.90303257533482, 59.7205103465489, 56.55054759979248, 60.56770420074463, 64.09703472682408, 62.83153847285679, 51.1663225037711, 46.29921013968331, 47.77378463745117, 46.53711993353707, 47.10407209396362, 52.410956791469026, 59.01800577981131, 63.32479803902762, 62.038610049656455, 61.92311709267752, 62.59290954044887, 60.90091896057129, 63.55705547332764, 59.88476576123919, 56.891176087515696, 53.45834214346749, 52.29041944231306, 55.407555035182405, 62.153227533612935, 60.785203661237446, 59.93270138331822, 55.81758213043213, 53.90774468013218, 53.88669163840157, 50.442959444863455, 51.77002021244594, 50.94774259839739, 46.34991809300014, 44.28623015539986, 42.64721958977835, 42.46717439379011, 42.28716046469552, 43.4515187399728, 43.59848008837019, 44.383456298283164, 45.83056109292166, 46.42358636856079, 44.69905737468174, 47.161474636622835, 48.08459840502058, 49.75890581948416, 50.49744027001517, 51.75108984538487, 52.03452771050589, 52.974115235464915, 52.159737723214285, 52.14923552104405, 53.229510171072825, 57.1518030166626, 58.42966706412179, 57.795015130724224, 55.512191431862966, 56.11666733877999, 54.009910992213655, 52.98548248835972, 49.313109397888184, 56.69652230398995, 55.518132141658235, 61.23841381072998, 51.195133209228516, 58.317870548793245, 53.88409301212856, 55.28770555768694, 8.493044563702174, 0.3687717861362866, 0.5788342856935093, 6.184744426182338, 15.13569004195077, 3.847584077290126, 0.6243041115147727, 0.19317365437746048, 0.3328705797238009, 18.104222774505615, 57.246986389160156, 38.53158964429583, 33.011763504573274, 63.60970892224993, 17.5740578515189, 0.4003118579941136, 0.2152113454150302, 0.10790332566414561, 0.10917303431779146, 0.17251132668129035, 0.09729207613106285, 0.11472173407673836, 0.10491224152169057, 0.14536054858139583, 0.1615893148950168, 0.09758153238466807, 0.13012620247900486, 0.10732470492699317, 0.13172629661858082, 0.15801606806261198, 0.1789398488721677, 0.11877739216600146, 0.20538533053227834, 0.1820975337177515, 0.26062885618635584, 0.1755521542259625, 0.09487890026399068, 0.142472879961133, 0.09178490271525723, 0.1542527907128845], [0.02440732191982014, 0.03217873615877969, 0.018858135311997364, 0.05392857228538819, 0.021327178359829953, 0.031167264362531047, 0.030009069546524967, 0.04482485453731247, 0.02839560996341918, 0.03917687492711203, 0.05631329717912844, 0.019242284520130073, 0.030448811128735542, 0.06734461417155606, 0.039202808535524776, 0.05199405537652118, 0.02498778318321066, 0.06881801903780017, 0.04087108526644962, 0.04409671860880085, 0.011711571249179542, 0.03705043438822031, 0.013302064966410398, 0.032019297392772775, 0.03285552055707999, 0.033526208318237743, 0.016399300823520337, 0.0030655317324479775, 0.02170848789890962, 0.05196157729785357, 0.07406213121222598, 0.06765909479664904, 0.8276239271674837, 34.59904473168509, 47.81329904283796, 18.368395021983556, 44.73572301864624, 54.25167008808681, 6.849009581974574, 0.0408880147151649, 0.049465189288769446, 0.12288224404411656, 0.3037965212549482, 10.090113197054182, 11.771116937909808, 2.3616384182657515, 0.5457460411957332, 0.2025144352976765, 7.699552467891148, 60.79431969778878, 66.71666540418352, 75.65780884878976, 64.33237021309989, 67.86416734967912, 61.27149418422154, 58.7976645060948, 59.350588253566194, 59.679661887032644, 59.84452179500035, 64.54032284872872, 64.14077363695417, 64.35559109279087, 60.504614557538716, 60.02408409118652, 57.44819232395717, 61.060456548418315, 61.43162931714739, 62.845441818237305, 61.211739676339285, 58.645769936697825, 57.24720525741577, 57.65917437417166, 56.00289058685303, 41.36344609941755, 41.99763945170811, 44.46835286276681, 45.865232603890554, 45.56710972104754, 54.022250992911204, 55.71827152797154, 59.160186767578125, 56.09504801886422, 59.1914119720459, 57.13691650118147, 59.242363112313406, 51.99466242109026, 55.936146191188264, 52.60940081732613, 56.032284940992085, 39.22200434548514, 34.053955078125, 66.02280439649309, 54.82429892676217, 59.2037033353533, 53.222315311431885, 51.82710313796997, 42.92483139038086, 42.63453565325056, 41.195581095559255, 41.939667156764436, 41.4673216683524, 43.650296279362266, 41.793202604566304, 40.4423303604126, 40.774099894932334, 39.2028238432748, 39.52715880530221, 40.41294642857143, 41.53048079354422, 42.13879558018276, 40.45907899311611, 40.53059332711356, 43.488371985299246, 43.16668776103428, 45.55383518763951, 47.00818347930908, 49.451392446245464, 48.20420816966465, 45.310109751565115, 46.02511065346854, 46.798455578940256, 55.59965188162667, 56.83308914729527, 56.55579348972866, 56.657518591199604, 54.541555881500244, 53.694705963134766, 49.916126183101106, 48.5742483820234, 53.055766991206575, 55.130742277417866, 52.41680717468262, 60.04637391226632, 46.01654699870518, 53.112742219652446, 21.41653847694397, 0.16252969657736166, 0.14005079492926598, 1.7350637657301766, 1.5601120335715157, 3.625976494380406, 0.31720402038523127, 0.19556226049150738, 0.29843359759875704, 4.744904841695513, 35.030100549970356, 32.33040230614798, 15.770475728171212, 41.91401440756661, 26.120432444981166, 0.029367860739252398, 0.11338255022253309, 0.04393695753866008, 0.08634951830442462, 0.05167760021452393, 0.03690195057008948, 0.09427822035338197, 0.03395367520196097, 0.0548371442460588, 0.08916815277189016, 0.06745041135166373, 0.06864182384950773, 0.018420449690893292, 0.029044172393956354, 0.07566041366330215, 0.055218857513474565, 0.04386033057900412, 0.1229279094508716, 0.024753831094130874, 0.04331589104341609, 0.034221089245485406, 0.012151947261632552, 0.026218659277739267, 0.07136420133922781, 0.060611151557947905, 0.08057870010712317, 0.03603526118344494, 0.08677092926310641, 0.02850448599617396, 0.06926264946482011, 0.04087108865912471, 0.0568204681788172, 0.03836016303726605, 0.05637422623112798, 0.008909007883630693, 0.05774220371884959, 0.04570455483293959, 0.020937821395429115, 0.02254362201451191, 0.024530767795762846, 0.016900694097525308, 0.08163251927388565, 0.03166925135467734, 0.02200708571555359, 0.014378319893564497, 0.009794229757972062, 0.028489819461745874, 0.0064772079266341666, 0.03063597483560443, 0.046412931821708164, 0.016599180276638696, 0.01553395832888782, 0.017571755052943314, 0.020595776981541088, 0.06860925416861262, 0.010902883035929074, 0.057279259631676335, 0.018456909073782817, 2.391126573085785, 52.962529114314485, 42.026780196598594, 17.943125316074916, 65.96543312072754, 51.56856066840035, 8.91580249582018, 0.043119031071130715, 0.06978675669857434, 0.11574085296264716, 0.44196218305400436, 1.3716627742562975, 7.258314064570835, 7.324280261993408, 2.9314000393663133, 0.4164153667432921, 11.299363783427648, 66.94794314248222, 68.38963876451764, 77.03842980521065, 66.79679897853306, 71.20445823669434, 63.20184966496059, 61.18908160073416, 59.67882810320173, 60.8209799357823, 61.46143708910261, 65.83324364253453, 65.29773208073208, 64.87542057037354, 60.52939878191267, 61.34879289354597, 59.94530541556222, 63.56663703918457, 62.70216996329171, 61.95224394117083, 62.50409071786063, 57.326022148132324, 60.1150290625436, 61.3642178944179, 58.12773656845093, 43.1347781590053, 43.568568093436106, 46.90819542748587, 47.21449286597115, 46.80917664936611, 54.83558627537319, 59.373322759355815, 60.40274701799665, 57.52235392161778, 59.198415756225586, 59.73312132699149, 61.27026435307094, 54.958791732788086, 59.05134323665074, 52.43564721516201, 54.5310571534293, 43.9022136415754, 39.13218150820051, 64.4087587084089, 55.90736675262451, 57.81903157915388, 53.69609212875366, 52.786361013139995, 43.7866199357169, 43.63454123905727, 43.38089724949428, 44.19955137797764, 42.02426494870867, 45.15316036769322, 44.016080720084055, 42.766273498535156, 41.57258687700544, 42.04297992161342, 42.134237561907085, 43.81948144095284, 42.7605551310948, 43.67628601619175, 42.26178216934204, 42.66026135853359, 44.7766409601484, 44.26343311582293, 48.9240345954895, 49.267661230904714, 50.527862957545686, 48.976458753858296, 48.03276831763131, 48.81806761877877, 49.66714096069336, 56.22982570103237, 57.18936150414603, 58.46444974626814, 56.13570192881993, 55.911921296800884, 54.76260239737374, 51.66201393944876, 49.69470793860299, 54.81711796351841, 57.423995222364155, 53.868035725184846, 61.398514202662874, 48.8069782938276, 55.710225514003206, 25.719107968466624, 0.10204153627689395, 0.932701968720981, 2.943599339042391, 3.2576414133821214, 1.4595208998237337, 0.2517588292913777, 0.0723326743713447, 0.09305533740137305, 10.673922555787222, 35.14317553383963, 44.79951095581055, 17.321372713361466, 42.05382605961391, 35.4405688558306, 0.28824810843382564, 0.11588847504130431, 0.08948485899184432, 0.07233817729034595, 0.06295326445251703, 0.04896108526736498, 0.03309387633843081, 0.021117097132706215, 0.07251860653715474, 0.02901791308873466, 0.03065614089635866, 0.0553225614130497, 0.02663983783817717, 0.02419864017117236, 0.08257187636835234, 0.050495955228273354, 0.013977640724208738, 0.03647201042622328, 0.04097359494439193, 0.08480441942811012, 0.045915202636803897, 0.04781266474830253, 0.02430173847824335, 0.030908515211194754, 0.044002276712230275, 0.0620453574561647, 0.12563744905803884, 0.19201971058334621, 0.13005336853010313, 0.15724983917815344, 0.06923763187868254, 0.17056941374072007, 0.11046877157475267, 0.22459669251527103, 0.07988892176321574, 0.10529414138623647, 0.14200752707464354, 0.1708278405879225, 0.11445015722087451, 0.18672227912715503, 0.09689334859805447, 0.16224369406700134, 0.1222151762672833, 0.20228427621935094, 0.13308386877179146, 0.1049169437693698, 0.11179981300873415, 0.0922498484807355, 0.13392394940767968, 0.13523802746619495, 0.131478699190276, 0.12334471994212695, 0.10960468436990466, 0.12690576671489648, 0.0741753244240369, 0.10277805211288588, 0.11739845973040376, 0.24439705003585133, 2.373543070895331, 59.111257553100586, 59.92851856776646, 28.52124697821481, 56.12470293045044, 71.69056810651506, 13.537476692880903, 0.09339828257049833, 0.18423875953469956, 0.320599409618548, 1.0014827294009072, 18.812457868031093, 29.321429320744105, 8.576245767729622, 1.8228229880332947, 0.2512874917260238, 10.619817801884242, 70.12244306291852, 72.05775260925293, 80.75925963265556, 69.95371995653424, 72.1972654887608, 67.28905800410679, 64.6979010445731, 64.41900730133057, 63.423837661743164, 66.15689073290143, 69.02935940878731, 67.51135866982597, 68.31006104605538, 64.30211080823625, 62.42368616376604, 60.42117364065987, 64.79537037440709, 64.14303874969482, 64.9131770815168, 65.44369288853237, 59.927399907793315, 62.34217684609549, 65.95994404384068, 59.44537557874407, 44.389400482177734, 46.30518906457083, 48.9792936188834, 51.65481560570853, 51.34123298100063, 60.51451574053083, 62.971822602408274, 63.75406469617571, 60.02753039768764, 62.741580145699636, 62.44684450966971, 62.8565867287772, 55.69005141939436, 58.72575759887695, 53.8103517804827, 56.296563148498535, 43.73509904316494, 38.80429254259382, 68.46934155055455, 60.24224363054548, 62.37868962969099, 56.54156705311367, 55.266006333487375, 45.898299080984934, 45.800086293901714, 45.75735487256731, 46.64153746196202, 45.278467655181885, 47.72928837367466, 46.687027318137034, 46.4979043006897, 46.48611668178013, 44.28182847159249, 45.98620768955776, 47.25798511505127, 46.13611160005842, 46.25699635914394, 45.009113788604736, 44.40277229036604, 46.39274678911482, 45.57570811680385, 51.466922419411794, 51.01347255706787, 54.27337278638567, 54.30906220844814, 51.35118974958147, 51.01120744432722, 50.795691694532124, 59.82591451917376, 60.55288369315011, 61.024235589163645, 58.48734406062535, 57.35968964440482, 59.59794412340437, 53.69591842378889, 52.93573686054775, 57.549705505371094, 58.79284940447126, 54.62135246821812, 61.466363361903596, 49.52442496163504, 59.8939790725708, 24.242660931178502, 0.2358853439135211, 0.4696622895342963, 6.841471655028207, 9.46978063242776, 6.5462235893521985, 0.5073867195418903, 0.32637167988078936, 0.2796450172151838, 9.760665229388646, 49.97280611310686, 44.3780505997794, 27.70987629890442, 53.55267783573696, 41.821183000292095, 0.35629263147711754, 0.26266600830214365, 0.20702627247997693, 0.15796638572854654, 0.1833935763154711, 0.1327904566590275, 0.18597172440162726, 0.12718365394643374, 0.29315413374985966, 0.1421780972076314, 0.10276411500360284, 0.23777001563991818, 0.09323807366724525, 0.18609643913805485, 0.2019140946545771, 0.1668307672121695, 0.1410039466406618, 0.20373615116945334, 0.09212633475129094, 0.09822466823139361, 0.13537076248654298, 0.10415496929947819, 0.12722736517233507, 0.1335111694144351, 0.11636674723454885, 0.20778240476335796], [0.01766608329489827, 0.07327354459890298, 0.030832471791654825, 0.0480585217342845, 0.024164445398907577, 0.03705088222133262, 0.07698808956359114, 0.030263744095074277, 0.0065310216907944, 0.04791655185233269, 0.04912106686138681, 0.03423720445217831, 0.034726099111139774, 0.1083985340914556, 0.023301328499136225, 0.02712275629996189, 0.026429327437654138, 0.05842025697763477, 0.052444690838456154, 0.04478732476543103, 0.033401452869709046, 0.023940781597048044, 0.02737922896631062, 0.07826306364898171, 0.023474967306745902, 0.05299302177237613, 0.04687938732760293, 0.06833955006940023, 0.026430307920756083, 0.08578131986515862, 0.09203767736575433, 0.089250669415508, 0.1996311635843345, 11.125857710838318, 58.16162640707833, 43.650588103703086, 18.67544286591666, 51.895674909864155, 44.200214930943076, 5.186452005590711, 0.13171237307999814, 0.05566246674529143, 0.0981669859694583, 0.18220495938190392, 6.7922488791602, 6.2466181346348355, 3.1856619843414853, 0.20325513769473347, 0.12291661862816129, 16.26761065210615, 74.22147028786796, 68.21429402487618, 72.70744391850063, 65.93498611450195, 65.05084868839809, 60.12711892809187, 62.512407711574006, 58.362325123378206, 66.2219467163086, 65.27840219225202, 65.28375230516706, 61.777600969587056, 61.81634412493025, 58.929624693734304, 67.15640994480678, 65.30361025674003, 61.459804262433735, 59.28315598624093, 59.78900568825858, 63.4379494530814, 59.507471629551475, 60.52856499808175, 54.52630805969238, 42.34951707295009, 47.12362779889788, 43.05166033336094, 46.73403535570417, 50.316655090876985, 55.063435077667236, 56.84241362980434, 59.90253925323486, 57.70424733843122, 58.76042216164725, 54.003258092062815, 58.71389702388218, 53.61455501828875, 56.528528758457725, 49.45030852726528, 57.517524923597065, 34.37315879549299, 38.63842861992972, 66.8029898234776, 58.521473612104145, 59.10354505266462, 50.854793071746826, 50.67139536993844, 48.64953211375645, 51.51286390849522, 46.5329475402832, 50.272579193115234, 44.90254579271589, 43.7516496522086, 42.087743691035676, 41.2787093435015, 41.72236224583217, 41.09020471572876, 39.39952039718628, 41.2873980658395, 41.71598379952567, 41.00212935038975, 43.621423040117534, 43.62457404817854, 44.66683857781546, 45.36731079646519, 42.521484988076345, 44.768431663513184, 43.8068391936166, 46.42779350280762, 48.75250094277518, 48.31030716214861, 49.77987200873238, 50.45665087018694, 54.43344191142491, 55.104182788303916, 54.760927881513325, 55.85651288713728, 55.20237473079136, 52.30119957242693, 54.413830620901926, 52.350563049316406, 55.572824886866975, 60.42268139975411, 48.108218806130544, 57.042459215436665, 33.77428313664028, 0.03965965598555548, 0.08977717866322824, 1.250916219183377, 5.828542419842311, 1.9011380885328566, 0.16565022484532424, 0.06750156610671963, 0.3680335943187986, 8.182366286005292, 41.59884064538138, 54.65867124285017, 20.007923228400095, 34.42140013831002, 40.23397472926548, 4.434335129601615, 0.4894139010991369, 0.05476634929488812, 0.09431585190551621, 0.0437624417245388, 0.006468789427474673, 0.050964341166296175, 0.05347447629485812, 0.048643381600933414, 0.04737124718459589, 0.05306697191138353, 0.11686183352555547, 0.025047809783635393, 0.0452910759486258, 0.06465911506009953, 0.03283134096169046, 0.054628355628145595, 0.02514180723976876, 0.0160461911998157, 0.05099983872579677, 0.058139221343610964, 0.029228336976042817, 0.04023118603176304, 0.0250048822656806, 0.02845186730181532, 0.07975295691617898, 0.05809251099292721, 0.0363690834492445, 0.05147751380822488, 0.007010817619240177, 0.046621109758104594, 0.07660443229334694, 0.038653948344290257, 0.03811920846679381, 0.029671067505010536, 0.04292337889117854, 0.03863034211099148, 0.038667905809623856, 0.034837738477758, 0.020463031783167804, 0.006729622529486993, 0.08940146703805242, 0.019841261307841966, 0.05664781155064702, 0.06286509561219386, 0.028645047917962074, 0.012650591620643224, 0.06421692057379655, 0.02604978548229805, 0.011955640295387378, 0.10087980290076562, 0.054605360076363595, 0.04415868581937892, 0.024855099052989056, 0.05388291705665844, 0.07600394237254347, 0.11035630439541169, 0.08850298489310912, 0.1359995880297252, 0.08262033733938422, 16.483673572540283, 69.64190564836774, 30.32925510406494, 25.55297827720642, 73.6691232408796, 37.047266823904856, 6.9669435279709955, 0.03858935181051493, 0.06715254804917745, 0.01766011049039662, 0.23555812718612806, 1.6817651114293506, 3.4151221173150197, 6.704895257949829, 1.144599661231041, 0.17250439205339976, 22.221407379422867, 76.36369718824113, 70.56148583548409, 77.22896330697196, 68.40732887813023, 66.91968481881278, 63.329279627118794, 64.63162217821393, 62.50320829663958, 67.89184202466691, 66.71933351244245, 67.67655903952462, 62.15995338984898, 63.401214327131, 59.165606362479075, 67.00532136644635, 66.28617586408342, 62.13325841086251, 62.57000132969448, 60.78866386413574, 63.34569822038923, 62.222153663635254, 61.03008597237723, 56.236006123679026, 46.006388732365195, 49.365908758980886, 45.582235949380056, 47.923115321568076, 51.082926750183105, 56.893746920994346, 58.341814041137695, 62.24989782060896, 60.838857650756836, 59.38554464067732, 56.61689247403826, 59.42289815630232, 53.716922828129356, 57.492827551705496, 49.25034284591675, 59.09692341940743, 35.9203245980399, 36.739159379686626, 68.23417976924351, 58.15374367577689, 62.13578755514962, 53.507490226200645, 50.86432947431292, 50.135282788957866, 51.62049150466919, 45.59158822468349, 50.17173303876604, 45.116446086338584, 44.400111130305696, 43.4284576688494, 42.54819733755929, 43.37044021061489, 43.475430965423584, 42.07890905652727, 42.89703859601702, 43.1342396736145, 44.37121704646519, 43.98650918688093, 45.0682499068124, 45.81985739299229, 45.808149678366526, 44.95974683761597, 47.363302435193745, 47.39717837742397, 49.80876956667219, 50.767839840480256, 51.205517292022705, 51.50769444874355, 54.56509290422712, 56.57275056838989, 57.67188262939453, 55.29406663349697, 57.596029145377024, 56.08391005652291, 54.14949682780674, 55.22289276123047, 56.18028504507882, 56.713736465999055, 61.306144850594656, 50.58845124925886, 57.922184535435264, 38.25079904283796, 0.2125581649265119, 0.30563730533633915, 1.3039064386061259, 5.213033642087664, 1.9140795426709312, 0.18987904116511345, 0.029172747994640043, 0.27981904787676676, 15.704466104507446, 36.902900627681184, 66.6064669745309, 22.648438453674316, 29.29139573233468, 52.13831295285906, 6.727525540760585, 0.6111099166529519, 0.06767916586250067, 0.06621410697698593, 0.05002842763704913, 0.0762440962716937, 0.07194504767124142, 0.06926872235323701, 0.016943272169945494, 0.03553545228870852, 0.0541540325087096, 0.0674044406041503, 0.054849364661744664, 0.023473710320623856, 0.04544514071728502, 0.037508309818804264, 0.040481616343770704, 0.043363110295363834, 0.02509988395364157, 0.04305381028513823, 0.04326936389718737, 0.035154166498354504, 0.038229952167187414, 0.0035834184964187443, 0.03960335793505822, 0.010049061217744435, 0.0303288461374385, 0.1380829755216837, 0.1350189692207745, 0.11318334591175828, 0.23921081689851625, 0.11997172236442566, 0.07393318241728203, 0.16995840652712754, 0.1075175174378923, 0.10548381906534944, 0.13698088537369454, 0.1837500650435686, 0.11023148787873131, 0.12117286505443708, 0.1636719831398555, 0.209339493353452, 0.13852619459586485, 0.17912351473101548, 0.17190186652754033, 0.1325403486511537, 0.2166934830269643, 0.14650310655789717, 0.07500465706522975, 0.10751590252454792, 0.13851147038596018, 0.06801204835729939, 0.17843614518642426, 0.13140488815094742, 0.19606797264090606, 0.13092517746346338, 0.15100323222577572, 0.2431013195642403, 0.2983131712036473, 0.4089108237198421, 18.581280878611974, 80.86779049464634, 54.5426641191755, 30.943458489009313, 62.11832673209054, 62.14181164332798, 9.257568751062665, 0.22123113168137415, 0.25080833743725506, 0.2276492722864662, 0.9530401059559414, 14.348578129495893, 16.000259603772843, 9.81348977770124, 0.4731243923306465, 0.3244321553834847, 19.01594976016453, 83.24721499851772, 70.84638977050781, 80.5818373816354, 70.70587635040283, 68.61913081577846, 66.48556137084961, 69.85825170789445, 63.565851892743794, 72.12089088984898, 67.423248563494, 70.41911724635533, 64.34092344556535, 64.65070193154472, 60.876294544764924, 71.089430809021, 69.90765339987618, 66.97102505820138, 62.58934511457171, 61.22578893389021, 64.56029891967773, 65.84035164969308, 64.81772272927421, 59.3974677494594, 48.30721173967634, 53.694070202963694, 48.07810878753662, 51.06311396190098, 55.477537291390554, 59.418256759643555, 61.141715730939595, 63.84450939723423, 63.022871017456055, 60.89411667415074, 57.151031766619, 61.67758165087019, 56.75708975110735, 58.35959448133196, 50.426870891026084, 61.394518988473074, 38.395860058920725, 42.52939551217215, 68.66080611092704, 64.48106166294643, 64.34532860347203, 55.641622475215364, 54.07875026975359, 55.59704630715506, 56.44611964906965, 49.977739334106445, 55.35755927222115, 48.634193965366904, 47.40317119870867, 45.710562229156494, 43.05448825018746, 44.78835909707205, 45.257345131465364, 44.496350628989084, 45.08758674349104, 46.769693510872976, 45.31947592326573, 47.1439026423863, 49.15731341498238, 51.76681014469692, 51.23664174761091, 48.027056898389546, 48.9176526750837, 48.65171037401472, 52.21255792890276, 53.4554899079459, 54.15786245891026, 53.702842303684776, 55.21968616758074, 59.60995755876814, 59.0720488684518, 56.37812805175781, 57.794997760227744, 59.10464286804199, 55.84694174357823, 57.72268785749163, 57.573760168892996, 60.89894567217146, 61.19593252454485, 54.12748493467058, 62.12890189034598, 36.660154887608115, 0.21292594447731972, 0.32228654623031616, 2.324742615222931, 15.383101497377668, 8.797211510794503, 0.6446662960307938, 0.0882254233583808, 0.5430312497275216, 14.920453957148961, 55.058470589774, 68.62582887922014, 32.86643498284476, 45.36004645483834, 61.066098485674175, 8.706495829990931, 0.9924997942788261, 0.2696065530180931, 0.12488959490188531, 0.1198695349906172, 0.1782107087118285, 0.2715504744223186, 0.12853772485894815, 0.11110479637448277, 0.14940807782113552, 0.10872241921190705, 0.196968442893454, 0.1453873235732317, 0.13021217286586761, 0.14550024537103518, 0.10958800597914628, 0.09535890272153275, 0.14558358304202557, 0.14319330773183278, 0.14726508781313896, 0.12540437227913312, 0.07841840745615107, 0.12862502517444746, 0.13349869794079236, 0.07507651392370462, 0.10060725573982511, 0.13174188935330935], [0.031564091997487206, 0.06090153740452869, 0.026853963134012053, 0.014593412101800953, 0.03351520587291036, 0.03105989976653031, 0.04078023960547788, 0.055313574216727696, 0.03821851885212319, 0.06280737263815743, 0.058321041587207995, 0.026232828785266196, 0.052848534525505135, 0.08602287833179746, 0.03263650302376066, 0.020739600960431353, 0.03854130135316934, 0.04573399307472365, 0.051046338730624745, 0.057855715842119286, 0.028263914797987257, 0.045992575984980376, 0.088736285588571, 0.011838616753396178, 0.04584264349458473, 0.05209496710449457, 0.07061594684741326, 0.07547799630888871, 0.03297081722744873, 0.02195321682042309, 0.02990691949214254, 0.022195991561082856, 0.05919836701026984, 0.20530348563832895, 31.90014205660139, 53.1341461454119, 40.883419377463206, 28.456290006637573, 58.26200008392334, 41.055307388305664, 8.127784711974007, 0.1558743537004505, 0.08068364233310733, 0.04474211736981358, 0.1744770019182137, 4.635736916746412, 8.515032138143267, 3.7394158244132996, 0.173424702669893, 0.04737215302884579, 32.42910494123186, 80.22533920833042, 66.43024676186698, 74.64404582977295, 65.71711145128522, 65.93177604675293, 65.44792434147426, 64.85801533290318, 65.4509607042585, 69.43028436388288, 66.78889887673515, 65.38927459716797, 60.68756062643868, 62.22389766148159, 63.5472446169172, 60.62693064553397, 60.855345726013184, 69.2134519304548, 66.29405512128557, 61.01503617422921, 56.21410540172032, 59.58153247833252, 49.52721118927002, 42.23999956675938, 45.214658873421804, 44.650145530700684, 48.06003999710083, 53.85507386071341, 54.63740280696324, 57.451176575251985, 59.490142822265625, 58.86851528712681, 62.819441659109934, 55.632207666124614, 59.95934772491455, 53.21161508560181, 56.5114083971296, 54.759305477142334, 55.16295412608555, 45.04935775484358, 39.19417681012835, 69.31594480787004, 55.87721504483904, 59.56969274793352, 51.842517716544016, 54.772322927202495, 52.469620432172505, 55.05872072492327, 51.0057635307312, 54.293578147888184, 49.87725101198469, 45.10927207129342, 41.23404632295881, 43.7523444720677, 42.982529231480186, 43.60026230130877, 43.12098945890154, 43.69934013911656, 42.749326842171804, 43.83868278775896, 47.03809200014387, 51.40920720781599, 53.3985389981951, 51.38042082105364, 50.7320670400347, 46.698999064309255, 45.67054407937186, 45.99836356299264, 44.597558089665, 47.867505414145334, 49.49605546678816, 56.78961079461234, 55.111669472285676, 58.65222481318882, 56.2741482598441, 59.00701372964041, 58.96968105861119, 56.132759366716655, 52.07881552832467, 60.146865708487375, 56.743613719940186, 47.80664266858782, 55.78208725793021, 37.266541549137656, 0.3148589219365801, 0.027293976130230085, 0.06903998141310044, 0.9210359432867595, 1.5463246362549918, 0.05677676034559097, 0.06981966564697878, 0.4314733887357371, 11.66251311983381, 34.41383702414376, 43.482549394880024, 13.540897812162127, 26.567835637501307, 39.940482820783345, 17.053797585623606, 0.18124177892293247, 0.027114530759198324, 0.031127390252160173, 0.023474037713770355, 0.09747411350586585, 0.012454667178514813, 0.05549975065514445, 0.04479415761306882, 0.027316376267533218, 0.07981280370482377, 0.030355675412075858, 0.06201347309563841, 0.01934893835069878, 0.062340275916670046, 0.06812266313603946, 0.034326520016683, 0.054643958540899415, 0.015904453716107776, 0.03885678281741483, 0.047611099135662825, 0.018244380031579306, 0.0173958007445825, 0.03668829346341746, 0.02946472500583955, 0.0947399295068213, 0.009839158954231866, 0.057695445870714526, 0.005900857737287879, 0.02035735504302595, 0.038907323498278856, 0.038226813942726166, 0.0617150737504874, 0.0304101753447737, 0.022654862741806676, 0.024942803096824458, 0.016713671186672788, 0.05495124330211963, 0.010285026859492064, 0.01971822594558554, 0.03800696859668408, 0.02520345723522561, 0.03918768059728401, 0.01957881753332913, 0.029887418395706584, 0.06317649568830218, 0.028756147849240472, 0.09508911719811813, 0.027939393550955822, 0.032568062589104683, 0.022070320090278983, 0.031745623863701306, 0.08772541090313878, 0.027103757319439734, 0.016412167543811456, 0.05542549856805375, 0.01753926001090024, 0.051182232331484556, 0.07884921612484114, 0.032040026637592485, 0.09385763720742293, 0.8269683537738663, 46.03631114959717, 59.91529614584786, 26.75612313406808, 39.25649172919137, 77.03332982744489, 34.40285192217146, 9.338983399527413, 0.28342508152127266, 0.11499071892883096, 0.11622824466654233, 0.5332376009651593, 2.198164458785738, 4.130745317254748, 7.312545623098101, 0.7866676077246666, 0.07859775783228022, 41.32288251604353, 79.49402741023472, 68.6048800604684, 76.10266726357597, 69.08328437805176, 69.67194965907505, 66.75684683663505, 68.40859345027378, 65.8155048915318, 70.41825566973004, 69.58427728925432, 66.1761372429984, 60.870756830487935, 62.25120408194405, 65.50549711499895, 62.24500628880092, 64.1479024887085, 68.27523667471749, 67.04570429665702, 63.55513777051653, 58.298054286411826, 63.21257768358503, 52.64833157403128, 45.21697957175118, 49.130031313214985, 46.19105448041643, 50.9719431740897, 55.59620557512556, 58.151871136256624, 60.12049729483468, 63.06812463487898, 60.10999856676374, 62.44357885633196, 57.96019812992641, 60.536631856645855, 56.338571957179475, 57.2895302091326, 54.627967153276714, 54.92425571169172, 43.95748656136649, 41.36748995099749, 68.14750794001988, 57.465840748378206, 59.6567953654698, 52.812823227473665, 54.73589699608939, 53.3863205909729, 55.738164220537456, 54.40828595842634, 55.28375898088728, 50.94810390472412, 46.4758437701634, 42.20554344994681, 45.30561079297747, 44.11331033706665, 45.95750815527779, 43.466005734034944, 44.458378723689485, 44.94268553597586, 44.74660389763968, 48.77699681690761, 52.355569226401194, 53.7590844971793, 51.234758785792756, 51.007507528577534, 47.929135935647146, 46.62834630693708, 48.83047015326363, 47.02142327172415, 50.4430775642395, 52.70690836225237, 58.660236086164204, 56.62756143297468, 59.777263232639854, 57.51075042997088, 57.79790210723877, 58.46495001656668, 57.316357203892295, 53.184729031154085, 59.22183118547712, 59.622749192374094, 49.409880433763774, 57.96382508959089, 43.19600568498884, 0.6062809186322349, 0.2740536986717156, 0.7944765144160816, 0.9825897089072636, 0.6535438682351793, 0.17694803646632604, 0.11389678477176599, 0.27905773158584324, 18.351292031151907, 29.89197369984218, 50.67740903581892, 24.864378792898997, 22.925339800970896, 48.673479080200195, 23.98937824794224, 0.10405183876199381, 0.035882003871457915, 0.052506525734705586, 0.08050830209893839, 0.0649472006729671, 0.0360622397357864, 0.0455119696312717, 0.014613968320190907, 0.024399756254362207, 0.009900553650887949, 0.02166541788860091, 0.028517690287636857, 0.04171444661915302, 0.03624504724783557, 0.049015985535723824, 0.021633409695433717, 0.025533981820834533, 0.011079769481771758, 0.010479104838200977, 0.03819810512608715, 0.036891745403409004, 0.04131566480334316, 0.04240600272480931, 0.06055318431130477, 0.042763719601290565, 0.05109247571921774, 0.04430638932223831, 0.08259578115705933, 0.22883951770407812, 0.13327414356172085, 0.12631667618240627, 0.1695513805108411, 0.20710697743509496, 0.1508318478507655, 0.08520639714385782, 0.19780361093580723, 0.1456733803663935, 0.09265886260462658, 0.11419120111635753, 0.08323449974081346, 0.15627022460103035, 0.1874773393252066, 0.18667708869491303, 0.10886559010084186, 0.11461660186094896, 0.1424823115978922, 0.17185401623802526, 0.0904990720695683, 0.09873798675835133, 0.12975747297917092, 0.08653767606509583, 0.13845026652727807, 0.09077837743929454, 0.13115777926785605, 0.17179292094494614, 0.09953692781605891, 0.10981744581035205, 0.16610710961478098, 0.11601267409111772, 0.11322012250976903, 0.5640225176300321, 49.235282625470845, 72.83952222551618, 51.08172123772757, 42.68732459204537, 70.21795994894845, 57.04532882145473, 12.954336098262242, 0.5285771510430745, 0.2853158600628376, 0.7123713344335556, 2.2551598804337636, 13.327024442808968, 21.35780188015529, 6.183442941733769, 0.36792060466749327, 0.1998636568231242, 36.37727287837437, 85.28428786141532, 69.96115452902657, 79.99959223611015, 70.62112917218889, 72.29283796037946, 69.964510508946, 70.92098563058036, 68.33436584472656, 72.5701961517334, 71.05250808170864, 67.37823118482316, 62.83221244812012, 63.25451701028006, 66.63608019692558, 62.99161107199532, 64.12780135018485, 72.81559262956891, 70.47657190050397, 66.86236912863595, 60.859181131635395, 66.57675647735596, 54.67022262300764, 46.6476206098284, 50.00788409369332, 49.18765619822911, 52.963369846343994, 58.9743641444615, 60.97217968532017, 64.0435266494751, 63.76941326686314, 63.28465829576765, 65.36253792898995, 59.52300085340227, 63.968395778111045, 58.1892420223781, 58.52505193437849, 57.95862088884626, 56.31152262006487, 46.086199215480256, 43.3419109072004, 69.84084647042411, 62.17195292881557, 62.45024217878069, 54.064784390585764, 58.003290857587544, 54.5722564969744, 58.841875893729075, 56.52375187192644, 56.756586006709504, 55.03385312216622, 50.01424169540405, 45.12151479721069, 48.800280230385916, 48.908428941454204, 49.87824807848249, 47.79982648577009, 48.834819725581575, 48.216815676007954, 48.82412992204939, 53.06084959847586, 56.48679092952183, 57.53392962047032, 54.764023303985596, 54.81514467511858, 51.99058730261666, 50.750139304569785, 51.069728646959575, 48.71291010720389, 52.9410001209804, 54.91014044625418, 64.78578880855015, 57.9253876549857, 61.623879023960654, 59.026121275765554, 58.81015736716134, 60.12780679975237, 60.568850653512136, 55.577438490731375, 63.523009300231934, 59.208782468523296, 53.13700532913208, 60.09023094177246, 39.53694534301758, 0.5207963085600308, 0.43382947945169037, 0.5815668819206101, 5.184450924396515, 5.945614789213453, 0.21374775895050593, 0.2813106035547597, 0.605678813798087, 19.553352969033376, 45.703600134168354, 54.16488708768572, 24.745239768709453, 37.22375454221453, 56.49453469685146, 30.65489285332816, 0.3346449216561658, 0.1064547687502844, 0.1077406197520239, 0.17819863078849657, 0.2397344559431076, 0.11219618602522782, 0.12446580907063824, 0.1049428027389305, 0.09005847892590932, 0.13853259996644088, 0.1701349341975791, 0.16111808589526586, 0.06782496268195765, 0.17114711845559732, 0.224127824817385, 0.15531251313430922, 0.128877087363175, 0.2095321701573474, 0.08177309815904923, 0.11614809611013957, 0.1505522642816816, 0.15340150067848818, 0.1109806244660701, 0.15778334412191594, 0.0920689714008144, 0.11329095478036574, 0.13994862112615788], [0.04785854389358844, 0.012308432703970798, 0.060221251765532155, 0.05009833710002048, 0.03630550132532205, 0.007318432742197598, 0.03874265322727816, 0.016373445246634737, 0.011770977838230985, 0.00823908856338156, 0.013269032185365046, 0.031679697401289425, 0.11118995930467333, 0.03160439019224473, 0.029008030226188045, 0.029802062083035707, 0.02624223497696221, 0.038155425273414166, 0.01687657048127481, 0.04082956910133362, 0.02215321162449462, 0.04142654760341559, 0.04273334498118077, 0.025828449055552483, 0.08048184601856129, 0.05783620796033314, 0.04172572726383805, 0.09770760419113295, 0.04236737372619765, 0.023076409407492195, 0.03821240185893007, 0.0070899504935368896, 0.051323713668222935, 0.02208677286814366, 2.5294074501310075, 49.402643884931294, 49.24790055411202, 40.39461360658918, 26.577137538364955, 65.28743485042027, 51.91527925218855, 13.584999765668597, 0.6324757358857563, 0.05314401277740087, 0.11710283559347902, 0.1351136112851756, 1.667561907853399, 3.473315234695162, 2.152944930962154, 0.24804279154964856, 0.2431288409445967, 45.727300439562114, 84.64531762259347, 68.1813873563494, 73.87048203604562, 70.36105115073067, 66.77509280613491, 68.41520813533238, 70.59353787558419, 69.0452777317592, 63.94386863708496, 63.98600946153913, 64.41678387778146, 65.80349145616803, 66.82072857448033, 63.087357248578755, 65.01914405822754, 61.58635875156948, 61.10764871324812, 62.82486820220947, 62.676107270377024, 61.57990387507847, 48.86409943444388, 44.21930510657174, 47.3235239982605, 49.116687297821045, 57.02536317280361, 53.157613686152864, 56.11803960800171, 56.22189433234078, 62.85652419498989, 60.589549337114605, 61.97211578914097, 55.43464606148856, 59.886794635227744, 53.72822059903826, 60.35460989815848, 54.48561593464443, 65.53114291599819, 32.748284339904785, 30.140371799468994, 71.36956827981132, 55.29756852558681, 63.20908273969378, 54.05606440135411, 59.6873049054827, 53.64477620806013, 60.134928703308105, 56.59627022062029, 57.702284472329275, 52.88677985327584, 46.40836981364659, 40.80444962637765, 44.5253141948155, 43.10332366398403, 42.63046053477696, 41.99182380948748, 43.97462429319109, 43.32960564749581, 44.73747743879046, 50.8331424849374, 54.899909223829, 56.90796640941075, 58.96092632838658, 58.11190857206072, 57.137006827763145, 54.49271004540579, 50.95093876974923, 47.7491636957441, 48.694059644426616, 51.41900416782924, 52.06202520642962, 55.746568066733225, 57.67360578264509, 60.2597530909947, 56.21721124649048, 57.743334429604666, 58.470320974077495, 62.04607241494315, 53.37362275804792, 47.92481763022286, 60.27683176313128, 30.73657587596348, 0.387025029531547, 0.05343324850712504, 0.20172386057674885, 1.2518279531172343, 0.5220094206077712, 0.19881731511226722, 0.055296400495405705, 0.8287824849997247, 14.946660825184413, 36.63943535940987, 57.49242455618722, 56.92160224914551, 32.20174946103777, 33.635360854012625, 35.840778146471294, 0.16768820477383478, 0.05240320520741599, 0.039580270781048706, 0.1225663452808346, 0.049507285601326396, 0.022734492218920162, 0.022028357788388218, 0.058434974402189255, 0.03015318020646061, 0.02030711291757013, 0.04165117662133915, 0.02248716281194772, 0.041084247042558024, 0.037811129819601774, 0.038466513223413906, 0.009251478078242923, 0.012107748338686568, 0.011493849717745823, 0.047756437943982225, 0.05855166885469641, 0.02297393704897591, 0.07183367293328047, 0.016784454263480644, 0.03947326580860785, 0.05801422840782574, 0.02244214031712285, 0.02848353622747319, 0.018231338588520885, 0.04789713557277407, 0.07401459983416966, 0.028378171613439918, 0.06494053745908396, 0.09794576319732837, 0.02416005527733692, 0.04036713730809944, 0.002031219599302858, 0.04185827907973102, 0.017814967448690107, 0.027402860644672598, 0.06102130562067032, 0.0361518029655729, 0.06432247348129749, 0.025030820963105986, 0.03335394863305347, 0.041964758187532425, 0.02095131915328758, 0.015537230564015252, 0.053243676000939946, 0.07594595476984978, 0.055875048373958895, 0.0500702627136239, 0.0313564026063042, 0.08470671038542475, 0.04854654108307191, 0.08455004343496901, 0.06825782052640404, 0.04932347046477454, 0.029173144937625954, 0.0501902480609715, 0.07522905538124697, 0.010812666716187127, 0.07981145342013665, 7.002063632011414, 61.04858207702637, 54.71163388660976, 32.58681515284947, 41.61107642310006, 84.26923942565918, 46.6223361151559, 14.106332659721375, 1.3085427326815469, 0.07997227300490652, 0.10479119765971388, 0.3272541825260435, 0.9633701230798448, 3.2582152911594937, 4.844623650823321, 0.569820680788585, 1.094788134098053, 56.44518511635916, 84.9253647668021, 69.8397694996425, 75.79262474605015, 71.51816245487758, 70.3763232912336, 71.05976894923619, 72.61744390215192, 72.74224744524274, 66.66099643707275, 63.583208492824006, 64.58298478807721, 67.00473076956612, 65.91309928894043, 64.61341789790562, 64.34544672284807, 65.04112121037075, 64.22339466639927, 63.29839488438198, 64.96786635262626, 63.16772706168038, 50.173688956669395, 46.06974935531616, 47.3943087714059, 50.67479998724801, 58.95558316367013, 55.97279099055699, 57.32437195096697, 58.683053970336914, 62.94914368220738, 63.41381141117641, 63.37123285021101, 57.2333470753261, 61.61813981192452, 55.04795101710728, 59.86343479156494, 55.48106697627476, 64.78148092542375, 37.96053804670061, 32.759894779750276, 73.41877269744873, 56.377804960523335, 64.72987665448869, 56.12537343161446, 61.46429279872349, 56.375849042619976, 61.563117027282715, 57.81325762612479, 59.933590752737864, 54.86295870372227, 48.36205039705549, 43.765083994184224, 45.17605815614973, 44.89758825302124, 45.31992060797555, 42.983439445495605, 45.495769092014854, 44.38610356194632, 47.34587287902832, 53.09537172317505, 56.58490296772548, 57.662023135593955, 59.42914458683559, 59.732794761657715, 59.13010801587786, 54.18970605305263, 53.5016051019941, 49.38241767883301, 50.47714805603027, 52.663794789995464, 55.02658183234078, 56.85972854069301, 59.50689492906843, 60.59783158983503, 57.61590794154576, 57.91707760947091, 58.478339195251465, 63.21119499206543, 56.32791689464024, 49.20807695388794, 62.876708711896626, 36.61934116908482, 1.174083690558161, 0.16258114310247557, 0.660019155059542, 0.5733400519405092, 0.15111668328089373, 0.09060022807014839, 0.0913298771317516, 1.0379156087126051, 21.538109370640345, 32.76253162111555, 59.35249205998012, 48.168115752083914, 23.045778138296946, 37.76399435315813, 44.038985456739155, 0.6872290607009615, 0.10972397761153323, 0.06006905636084931, 0.03302454702290041, 0.014448935032955237, 0.05187100644356438, 0.008755675932791616, 0.05120038653590849, 0.058326469867357185, 0.004984076351060399, 0.026810287531199198, 0.013827843092648047, 0.056390813019658835, 0.016999197026182498, 0.031549696877066574, 0.04032790780599628, 0.04720669565722346, 0.04447100531043751, 0.026223185106313655, 0.03772362594359687, 0.051622699946165085, 0.017215157759242823, 0.028207998423437988, 0.02703266720553594, 0.019544729630329778, 0.003935035343082356, 0.05710822130952563, 0.024456885510257313, 0.19179177709988185, 0.09946731012314558, 0.11095984772379909, 0.17166892545563833, 0.15914916726095335, 0.12965462064104422, 0.17443356210631983, 0.08418936136045627, 0.15022857593638556, 0.06968753452279738, 0.10149799580020563, 0.13389033478285584, 0.11423412524163723, 0.13794713281095028, 0.12184540182352066, 0.149649405585868, 0.0730442540454013, 0.08417047773088727, 0.10861198085227183, 0.14986055211297103, 0.19071714047874722, 0.16298602494810308, 0.17307079237486633, 0.10896920239818947, 0.08968958657767091, 0.12000984246177332, 0.18904300459793635, 0.20351470448076725, 0.11974745297006198, 0.08724595127361161, 0.13551398765827927, 0.12245005794933864, 0.10124758245157343, 0.193333842924663, 5.052221059799194, 71.81288419451032, 64.46134267534528, 52.87822662081037, 40.87182283401489, 74.53369453975132, 69.23209394727434, 22.86069549833025, 1.3065230867692401, 0.20090382386531147, 0.21711036137172154, 0.6243004745670727, 10.401137147630964, 11.130992429597036, 5.221042309488569, 0.4182534095432077, 0.7019739523530006, 50.710051672799246, 87.53898525238037, 73.02480288914272, 81.29859270368303, 74.56618431636265, 74.06839452471051, 75.16867651258195, 74.76830046517509, 72.79419217790876, 68.53129168919155, 64.95965358189174, 65.40133666992188, 68.93077836717877, 70.99877071380615, 67.0286534173148, 68.44958782196045, 65.26290770939418, 65.87053462437221, 65.28123010907854, 68.34464223044259, 66.2993357522147, 53.78361163820539, 49.820744786943706, 51.52950484412057, 55.32050800323486, 63.21320302145821, 57.72769750867571, 60.02973992483956, 64.09547138214111, 69.24098764147077, 65.98342895507812, 64.19087709699357, 58.51260771070208, 64.8619966506958, 56.05598872048514, 60.81273937225342, 57.71775116239275, 67.10946791512626, 39.388222626277376, 34.51894242422921, 74.33164092472622, 60.00682476588658, 69.69605990818569, 59.995895249503, 65.5596444266183, 58.824296951293945, 64.93857274736676, 60.111457688467844, 62.818593978881836, 56.532475335257395, 51.120613779340474, 45.032977376665386, 46.782408714294434, 46.76725121906826, 46.25369596481323, 46.177248409816194, 47.15142059326172, 47.8377115385873, 50.52645247323172, 56.68290730885097, 60.84902286529541, 63.59490231105259, 63.815424237932476, 63.734526361737935, 61.42294406890869, 60.11704404013497, 55.60415778841291, 52.48977368218558, 55.38889912196568, 56.36334923335484, 55.974545410701204, 60.09462915148054, 62.70264938899449, 62.31316811697823, 56.411274433135986, 60.08769484928676, 59.36909825461251, 62.96656976427351, 57.48856830596924, 54.09152453286307, 62.62737260546003, 32.82450955254691, 1.09110070339271, 0.37439108746392386, 0.5317101914967809, 3.119186831372125, 3.83676529782159, 0.4033118241599628, 0.19031646555023535, 1.345942388687815, 23.87793435369219, 46.71028988701956, 67.93544891902378, 63.64534623282296, 41.404978956495015, 46.6540025302342, 53.51179116112845, 0.7262304936136518, 0.2636122932391507, 0.14389651428375924, 0.17468643853706972, 0.13371017016470432, 0.09256022396896567, 0.1338087748736143, 0.12146858418626444, 0.1282132901251316, 0.11679761697139059, 0.11993523075112275, 0.1806846745312214, 0.15292283493493283, 0.11871955384101186, 0.2266707026532718, 0.12683308204369886, 0.14646922051906586, 0.07257217687687703, 0.20392250402697495, 0.11076522352440016, 0.13016382046043873, 0.16624402441084385, 0.1215998400002718, 0.10832265352032014, 0.09468536850597177, 0.13923675646739347, 0.12073649918394429, 0.12504675718290464], [0.04033148029286947, 0.03434647573158145, 0.06452956236898899, 0.07652198350323097, 0.0076981757135529605, 0.026102757014866387, 0.007096950006338635, 0.013870123457828802, 0.007731877699760454, 0.011630622869623559, 0.02878867681803448, 0.08572010922112636, 0.058924327072288306, 0.018889787274279764, 0.03544092218258551, 0.07700248129133667, 0.06348330886768443, 0.07934719297502722, 0.01818515919148922, 0.021859526401385665, 0.04115683671885303, 0.035892219216163666, 0.046778597735932896, 0.037252956735236306, 0.05994766644601311, 0.04460062924772501, 0.013792452402412891, 0.04396605651293482, 0.045236728686307154, 0.1236563032226903, 0.008438618570965315, 0.03872545575723052, 0.04661135242453643, 0.020754530427179167, 0.028236517250271778, 6.8767706751823425, 50.21538857051304, 37.00601189477103, 35.51801347732544, 23.16968536376953, 49.26570878710066, 61.77056244441441, 22.09970968110221, 2.7169245651790073, 0.005250794048021946, 0.0219692522992513, 0.07438195190791573, 2.91217155115945, 2.6136152744293213, 0.22085183060594968, 0.017792267059641223, 1.4748269127947944, 46.02869244984218, 81.94974313463483, 72.85535717010498, 70.47735009874616, 72.1298679624285, 72.36216013772147, 67.87167835235596, 64.64128712245396, 66.29681355612618, 65.22662421635219, 64.58096286228725, 66.2864329474313, 64.58770956311906, 61.62809658050537, 67.20492226736886, 64.68709659576416, 66.6609547478812, 62.990089416503906, 58.54686232975551, 54.55852338245937, 46.50852114813668, 45.474830695560996, 49.96627480643136, 58.23446784700666, 59.575292995997835, 56.76416301727295, 55.710301944187705, 54.81200408935547, 64.77118369511196, 61.22696317945208, 62.75362832205636, 59.45731953212193, 60.12660476139614, 55.02916308811733, 61.89592184339251, 53.56967660358974, 54.18376881735665, 37.638773918151855, 35.553810596466064, 72.36965029580253, 57.27700955527169, 63.50212301526751, 57.784641470227925, 60.81339945111956, 56.60476786749703, 62.20742348262242, 55.94017267227173, 59.593962805611746, 48.590531485421316, 44.456450598580496, 43.07270990099226, 46.182789598192485, 45.63024800164359, 45.705865246909006, 44.37256499699184, 45.55848700659615, 45.96735722678048, 48.04313155582973, 52.26269612993513, 57.83979279654366, 59.851893833705354, 59.79804529462542, 58.806648526872905, 60.78322342463902, 58.459009306771414, 57.77063390186855, 57.348155634743826, 52.67186859675816, 50.97825908660889, 56.52946676526751, 58.1432831627982, 60.65008899143764, 60.34508391789028, 59.500433104378835, 57.659535680498394, 54.014903272901265, 50.051734175000874, 54.21344109943935, 57.56296961648123, 23.59436273574829, 0.28939974520887646, 0.03559460697163429, 0.07740434365613119, 0.16721145249903202, 0.9898028075695038, 0.22191878621067318, 0.1593162632946457, 0.6441766651613372, 18.961708647864207, 45.31194755009243, 49.72806971413748, 31.22344309943063, 68.57565593719482, 38.95688888004848, 45.70970065253121, 3.896506343569074, 0.3470924294420651, 0.011197448658224727, 0.06001604241984231, 0.025668677807386433, 0.049898121772067885, 0.01126797728440059, 0.04438282968476415, 0.035928978850798945, 0.03325205981465323, 0.020742476252572875, 0.09955068850623709, 0.035391117712216716, 0.020751504160995995, 0.05600630079529115, 0.04651150260386722, 0.01292947375415159, 0.006734462604591889, 0.02730123475859208, 0.02121651099462594, 0.037603247045938454, 0.056116613625947914, 0.031222548003175428, 0.0174756236041763, 0.07917247020772525, 0.014660273246201021, 0.03757179355514901, 0.04985256153824074, 0.027638329259519066, 0.05912815220654011, 0.026247985561245253, 0.02013083121606282, 0.06867669376411609, 0.0645513908405389, 0.010501924819046897, 0.021248639627758945, 0.02218223426357976, 0.015465519590569394, 0.03476653640557613, 0.04322163913665073, 0.0858766201085278, 0.012698744706410383, 0.0881562874253307, 0.054780259262770414, 0.08346670120954514, 0.004842258291319013, 0.08827240512307201, 0.019851393532007933, 0.024656771748725857, 0.022662786334486942, 0.037659897934645414, 0.058826394113046784, 0.038062801850693564, 0.08145331139011042, 0.0808942596028958, 0.025873490210090364, 0.039120173148278675, 0.011708203170980726, 0.07868011162749358, 0.06091574592781918, 0.027900265829105462, 0.03591617150232196, 0.06147858394043786, 0.044019565784505436, 15.902673891612462, 59.783634730747764, 42.81069333212716, 30.86132035936628, 40.47100210189819, 75.48727921077183, 60.96684346880232, 20.487260341644287, 4.831613148961749, 0.08915920289499418, 0.09795547303344522, 0.07347703725099564, 0.6402711261595998, 2.5219481246812, 1.439833721944264, 0.10234627992446933, 3.0239986819880347, 56.15376377105713, 84.11067458561489, 73.53912939344133, 73.8701902117048, 73.312194279262, 74.73522703988212, 69.20592008318219, 67.49840027945382, 67.79617922646659, 66.21303912571499, 64.58413818904332, 65.76834746769497, 67.11709703717912, 63.5553879056658, 70.23595578329903, 66.36230032784599, 66.51240226200649, 65.10119533538818, 62.83670098440987, 57.86653641292027, 48.593866620744976, 48.79203271865845, 51.1153678894043, 58.65648405892508, 62.444329261779785, 57.62673323495047, 56.808200699942454, 57.0916941506522, 65.93150506700788, 60.896611077444895, 62.79770769391741, 57.8616726739066, 61.23483548845564, 55.76501553399222, 62.40735789707729, 55.79122413907732, 60.15751034872872, 36.166499274117605, 35.46168443134853, 73.17447403499058, 58.798262051173616, 64.52810096740723, 58.76450770241873, 61.59931714194161, 57.263526575905935, 62.370803424290244, 59.02386311122349, 61.63593414851597, 52.20106908253261, 47.23148468562535, 45.21730613708496, 47.71422120503017, 47.32968010221209, 47.11004754475185, 46.24409702845982, 48.81119932447161, 47.04614496231079, 48.28196546009609, 54.94721603393555, 60.20159666878836, 60.42917101723807, 60.137450899396626, 60.51014532361712, 62.3500144141061, 60.896465165274485, 59.51120976039341, 57.55619512285505, 56.62210362298148, 52.06804929460798, 57.034510476248606, 60.40978554316929, 60.60471030644008, 61.11393683297293, 59.551738602774485, 58.385393142700195, 57.19964483806065, 53.25042772293091, 55.82932806015015, 61.29495825086321, 28.50724114690508, 0.7515855016452926, 0.1914696086730276, 0.15985188526766642, 0.4347160261656557, 0.6478432512709072, 0.20010874367186002, 0.21967586156513008, 1.3022452763148715, 23.578321082251414, 35.77587849753243, 56.18093122754778, 40.245133536202566, 75.52407687050956, 41.444535051073345, 51.63011128561837, 8.675144689423696, 0.7122762309653419, 0.06345270693834339, 0.06422944633024079, 0.017525070147322755, 0.056908338463732173, 0.014221807309825505, 0.033171555027365685, 0.05255768388243658, 0.05993639597935336, 0.0397092467173934, 0.04348733987925308, 0.019056823936157992, 0.014737904437684586, 0.047181050426193645, 0.02049210191970425, 0.013449311306300973, 0.03261826739513448, 0.036899005728108544, 0.013286125330653573, 0.04452329661164965, 0.0604497009356107, 0.013250750755625111, 0.03562515461817384, 0.03822661377489567, 0.06889611163309642, 0.003304287213333217, 0.046089691309524436, 0.05882518632071359, 0.15846916660666466, 0.1691303766731705, 0.12617927284112998, 0.1725870104772704, 0.14754992324326718, 0.13722884921090944, 0.13436494288699968, 0.15386127600712435, 0.11009622870811395, 0.10626414112214531, 0.10190260623182569, 0.15895444128130162, 0.07014294687126364, 0.16822882076459272, 0.15450230160994188, 0.16214367800525256, 0.17714892354394707, 0.13560583415840352, 0.09882169762360198, 0.08563953997301203, 0.18990422838500567, 0.12225976958870888, 0.15068714347268852, 0.11349762297634568, 0.22245496458240918, 0.14213403314352036, 0.10826725792139769, 0.16662513038941792, 0.1272180149597781, 0.2669659118567194, 0.12451596637921673, 0.10353432010327067, 0.13014582571174416, 0.08096667964543615, 0.10517060051539115, 11.963222469602313, 75.57254750388009, 55.47262838908604, 47.967844349997385, 36.443041052137104, 58.11780759266445, 76.29273523603166, 34.55633415494646, 5.272264429501124, 0.15032305515238217, 0.23786758897559984, 0.5803451389074326, 10.760116696357727, 12.934333971568517, 0.5519954030002866, 0.08141222609473125, 2.3984501915318623, 52.03457982199532, 85.22702775682721, 75.48750155312675, 74.84678036825997, 75.32223864964077, 76.95594773973737, 70.19329384395054, 67.75163432529995, 68.50723702566964, 66.29107434409005, 65.79702963147844, 66.30749988555908, 67.98744923727853, 65.22958414895194, 71.37290341513497, 71.73030485425676, 70.70409066336495, 69.2050724029541, 64.5853054864066, 60.19239725385393, 51.548299721309114, 51.729623385838096, 54.28241239275251, 61.677671977451865, 64.17691121782575, 62.08462102072579, 59.65554468972342, 60.04349735804966, 69.34696156638009, 64.85916873386928, 65.7750802721296, 61.88934884752546, 62.48434393746512, 59.08298533303397, 61.8544272014073, 56.46956981931414, 60.39276245662144, 40.265738419124055, 39.70976093837193, 73.46492263248989, 60.36518505641392, 65.22060012817383, 62.80880396706717, 65.47547394888741, 58.12166036878313, 66.03392846243722, 60.45480292184012, 64.3885394505092, 54.47678477423531, 49.27164602279663, 47.87057999202183, 51.68513754435948, 51.286724363054546, 50.983324323381694, 50.448747294289724, 53.63232503618513, 52.07280881064278, 52.382246834891184, 59.45570755004883, 62.22407136644636, 61.53262138366699, 60.93248462677002, 62.972642489842, 65.03889083862305, 61.55921213967459, 62.29845183236258, 63.20492076873779, 57.73558718817574, 55.332316466740195, 60.617640904017854, 63.04855155944824, 62.53333568572998, 62.10424273354666, 60.46820599692208, 61.00842843736921, 56.34835502079555, 56.03440761566162, 59.175973074776785, 59.54662472861153, 26.036595480782644, 0.8198336394769805, 0.3321474513837269, 0.15664322887148174, 0.8299707898071834, 5.20566724879401, 0.6127997945461954, 0.30555962664740427, 1.1087061358349664, 29.891553333827428, 53.13639736175537, 59.13921710423061, 40.229757172720774, 72.8975396837507, 47.84520864486694, 64.62333992549351, 9.426978860582624, 0.6892769879528454, 0.15920142802808965, 0.18648335337638855, 0.08492674572127205, 0.09855760500899383, 0.10904912703803607, 0.1931476393448455, 0.12768874184361526, 0.10453959008944885, 0.10759489078606878, 0.22236790853951657, 0.09208115110439913, 0.05020799853705934, 0.13261772878468037, 0.207015687333686, 0.11013333778828382, 0.14763683000845568, 0.14019653068057128, 0.07215030451438256, 0.1204582726848977, 0.13886414574725287, 0.17206227220594883, 0.10982822773179837, 0.14675531802432878, 0.1457069135670151, 0.1569454755101885, 0.11925580006624971, 0.169616180605122], [0.02824762317218951, 0.014737887474309121, 0.0051768252493015355, 0.050780729590249915, 0.05012383644602128, 0.00825475508879338, 0.02922501215445144, 0.04772582922929099, 0.009353528048710098, 0.0556537984604282, 0.007049988597697977, 0.04111314245632716, 0.07266668323427439, 0.039901611395180225, 0.004647314756376935, 0.035179408001048226, 0.08611481982682433, 0.08316596770392996, 0.02607768684226487, 0.034447377281529565, 0.050156192388385534, 0.009051503630221953, 0.06126473005861044, 0.054414654416697364, 0.013831994030624628, 0.03818645128714187, 0.06485572058175292, 0.04881841988701906, 0.07589916978031397, 0.05170325223090393, 0.11457844105150018, 0.051077208681298156, 0.01689215303797807, 0.03272606964622225, 0.07316267197685582, 0.10322065372020006, 10.217098474502563, 42.56301784515381, 37.89170919145857, 40.66161550794329, 30.06070375442505, 43.29566717147827, 65.28562831878662, 35.736548219408306, 7.885383776256016, 0.12112224634204592, 0.05021045144115176, 0.1048499723630292, 1.7317253734384264, 6.35754873071398, 0.40418127179145813, 0.11183285766414233, 0.3829785723771368, 31.083079065595353, 79.04301289149693, 75.45105130331856, 67.04982457842145, 69.16436290740967, 72.83472102028983, 66.26576205662319, 63.66560023171561, 65.63396235874721, 65.64079243796212, 66.41027069091797, 68.19211537497384, 68.84056295667375, 66.07387365613664, 61.469510895865305, 63.05829988207136, 61.316615785871235, 61.64256272997175, 48.85495213099888, 48.331089224134175, 47.19828619275774, 59.21682153429304, 61.923909187316895, 63.75505134037563, 60.36190550667899, 56.27967207772391, 55.414030756269185, 64.34145845685686, 62.75988170078823, 67.61451857430595, 59.725360189165386, 61.087144579206196, 55.95389189038958, 57.232089451381135, 43.36013603210449, 66.84535299028668, 36.60100834710257, 31.57123170580183, 68.63484764099121, 51.40876947130476, 65.43632084982735, 59.896285874503, 63.1574159349714, 58.41438797542027, 63.52496869223458, 59.61252839224679, 61.924868038722444, 48.49126952035086, 44.951607022966655, 43.86440849304199, 45.89467559541975, 43.99849482945034, 45.736871583121165, 47.30426011766706, 45.70934282030378, 44.377439158303396, 46.10091897419521, 51.06590713773455, 61.04235649108887, 61.17736693790981, 63.87711729322161, 59.6200532913208, 59.73731803894043, 58.24424048832485, 60.960478918892996, 59.95528302873884, 62.19925240107945, 57.030675070626394, 55.71533243996756, 55.55990818568638, 59.78510080065046, 62.61496312277657, 58.57785129547119, 44.56191383089338, 51.85915517807007, 64.1634247643607, 42.84024402073452, 8.78223901135581, 0.1665161033826215, 0.13225226982363633, 0.052361258172563145, 0.3324505394058568, 0.8532649512801851, 0.0453908307743924, 0.15223604893045767, 1.8052179898534502, 26.23171479361398, 50.590101446424214, 57.13964366912842, 25.72663460459028, 24.32215874535697, 28.178568771907262, 42.15026705605643, 10.876638855252947, 0.053320034939263544, 0.02576494835583227, 0.04645391872950962, 0.031957489637924094, 0.065346566028893, 0.00829839167584266, 0.03308019367977977, 0.08484491439802305, 0.0067588958024446455, 0.06196155838136162, 0.03382657541494284, 0.035014625771769455, 0.04128309512244804, 0.07159666065126657, 0.02869725100962179, 0.009507374837994576, 0.04805386698405657, 0.03808313415252736, 0.06936043993170772, 0.06521381743784462, 0.028918236294495206, 0.044807338155806065, 0.022850204491987824, 0.007303327704513711, 0.008112473080732992, 0.029282867442816496, 0.05824400072119065, 0.07966377027332783, 0.04543286941147276, 0.0216947407794318, 0.03717533911445311, 0.051266061940363476, 0.04102436971983739, 0.048682614495711665, 0.021963396542040364, 0.02848733263090253, 0.014473274084074157, 0.011580172942818275, 0.04770267761445471, 0.02059711708820292, 0.0508908320750509, 0.026244501283924495, 0.0374892158433795, 0.010991486138664186, 0.033593858259596994, 0.025117186596617103, 0.020512695457520227, 0.044077818015856404, 0.03079145434977753, 0.03531221766024828, 0.04747828608378768, 0.02843761637008616, 0.023395872175959603, 0.023146988923794458, 0.0561830930944, 0.07349524913089615, 0.079991611252938, 0.04122776059167726, 0.034592604131570885, 0.017317647081134573, 0.014581715854417001, 0.05625750802989517, 0.0448564708765064, 0.034935362703566036, 0.12419040527726923, 20.28290687288557, 54.07772193636213, 44.97588055474417, 25.63401164327349, 31.311018194471085, 66.54337733132499, 66.89109992980957, 31.07030827658517, 9.0578818661826, 0.32211058852928026, 0.07962490378745965, 0.0803027670564396, 0.6140877625771931, 3.1342976433890204, 1.2099372638123376, 0.30205681174993515, 1.584024150456701, 41.331230776650564, 80.83414036887032, 72.47377599988664, 67.16627638680595, 69.02382169451032, 72.07885428837368, 67.49195929936, 65.85483169555664, 64.40381159101213, 66.91720431191581, 67.449526650565, 69.99773679460797, 68.44602339608329, 66.31518459320068, 63.65096732548305, 66.85676888057164, 63.256615366254536, 63.92024476187569, 53.46172939028059, 49.16518572398594, 49.774445465632844, 57.46424961090088, 65.32447569710868, 64.89194338662284, 61.26320498330252, 57.8628260748727, 58.130745138440815, 65.20388276236397, 66.32571806226457, 68.85263892582485, 61.49466337476458, 59.87293297903878, 56.67959649222237, 57.20991080147879, 46.19459111349923, 62.80756023951939, 38.61089638301304, 35.53035000392369, 70.22733306884766, 53.77974843978882, 66.39485263824463, 61.047192437308176, 64.41092654636928, 61.72489888327462, 66.97387381962368, 59.74150085449219, 62.129610606602256, 49.22076089041573, 46.86578362328665, 46.25682265417916, 47.95401396070208, 47.40842056274414, 47.245950835091726, 47.20118359157017, 46.68606499263218, 46.06173808234078, 51.30859381811959, 53.205465929848806, 61.85468428475516, 64.1074639729091, 63.44534233638218, 61.33869021279471, 63.12371717180525, 59.94513865879604, 62.49789292471749, 62.95377813066755, 62.3992007119315, 57.442154339381624, 58.779731205531526, 56.529136725834434, 60.819235937935964, 62.49353640420096, 58.93475941249302, 48.60861417225429, 53.312141622815815, 64.83864375523159, 51.475989818573, 13.25804533277239, 0.3939529263547489, 0.2805454060435295, 0.15144064304019722, 0.42773379225816044, 0.49100943548338755, 0.12711075214403017, 0.11694073357752391, 2.324923268386296, 24.139556612287247, 45.8960930279323, 68.01262950897217, 32.54677963256836, 24.151074988501414, 35.42804820196969, 47.904490675245015, 17.589173657553538, 0.07158482700054135, 0.00513216873930235, 0.04667606091658984, 0.020507701439782977, 0.054792513605207205, 0.018364560457744768, 0.024944065171959143, 0.044694419750677686, 0.010116116592793592, 0.057936637928443294, 0.03137608690719519, 0.03428690714229431, 0.07663700197424207, 0.09376638103276491, 0.07322190808398382, 0.02402704714664391, 0.03708307870796748, 0.03655298679534878, 0.014829596571092094, 0.02568342237334166, 0.05041801191068121, 0.034704029759658236, 0.023247025341593792, 0.0010740079160314053, 0.03842902755630868, 0.037612770284925184, 0.07869957201182842, 0.018667918197544556, 0.004778197800208415, 0.0822808255574533, 0.1384075323918036, 0.07084163437996592, 0.2161983017410551, 0.2112174475831645, 0.1949140831295933, 0.09635603707283735, 0.11083017289638519, 0.12401416259152548, 0.17682488236044133, 0.0903526781392949, 0.16444438669298375, 0.11852387791233403, 0.09833912351833922, 0.06990328151732683, 0.09009260923734733, 0.16477081631975515, 0.144269640690514, 0.126924779266119, 0.07231087982654572, 0.06378398130514792, 0.1286031084933451, 0.13653283513018064, 0.14729549975267478, 0.15046618532921585, 0.15882758237421513, 0.151621689753873, 0.11857551442725317, 0.11090322397649288, 0.1222720510725464, 0.19372305061135972, 0.11800945337329592, 0.10113928826259715, 0.1494826352489846, 0.18420537561178207, 0.1835214394543852, 16.11444977351597, 69.18064948490688, 58.58864879608154, 50.70888784953526, 41.47737223761422, 55.192258153642925, 76.50236238752092, 49.39673444202968, 14.053006104060582, 0.2887418105133942, 0.14780266396701336, 0.26595209911465645, 10.156689098903112, 17.712980134146555, 1.018503753202302, 0.29029576427170206, 1.0540162133319038, 37.04901082175118, 81.20273535592216, 75.39073399135044, 66.6030832018171, 68.07295376913888, 73.03569766453334, 67.12547656467983, 66.72906099046979, 64.9779759815761, 67.38845893314907, 68.6102579661778, 72.00386932918003, 72.47802829742432, 71.26609570639474, 65.44060094015938, 68.88017463684082, 65.75767503465924, 66.94539315359933, 53.04248898369925, 53.23999500274658, 53.8707594190325, 64.85663264138358, 68.8937931060791, 70.18951402391706, 66.05156299046108, 60.13402543749128, 59.622346196855815, 69.41140610831124, 71.05748994009835, 71.11078262329102, 62.58882399967739, 63.04448686327253, 58.07240111487252, 58.1607266153608, 48.490053585597444, 71.02204717908586, 41.32119410378592, 37.988230092184885, 68.09880801609584, 55.52633796419416, 70.23895045689174, 64.97003419058663, 67.65246963500977, 65.29552950177873, 68.77367264883858, 63.905479839869905, 66.53809670039585, 52.45173576899937, 49.83242123467581, 47.12862007958548, 49.86231585911342, 48.65317644391741, 50.418487889426096, 51.67898838860648, 49.66806159700666, 49.32722813742501, 53.19944531576974, 53.86679547173636, 67.4838090624128, 68.94414670126778, 67.94054889678955, 66.25211579459054, 66.04788044520787, 63.54797417776925, 65.03173419407436, 65.28796986171177, 65.90841620309013, 60.690402439662385, 58.099231583731516, 59.80529226575579, 63.152218682425364, 64.5873691013881, 57.59797464098249, 52.141807896750315, 59.13757038116455, 67.04352256229946, 47.49309478487287, 11.220609426498413, 0.6297551361577851, 0.28410798630544115, 0.18598304236573832, 1.6778303682804108, 2.960620254278183, 0.35942857606070383, 0.4168184165443693, 2.868592015334538, 36.724144322531565, 60.815678460257395, 66.07595811571393, 38.22512544904436, 34.458124841962544, 40.16257504054478, 60.091801234654014, 18.996083123343332, 0.1784223166427442, 0.05617172084748745, 0.16129385360649653, 0.10879173834941216, 0.16541029486273015, 0.08069353537367922, 0.14495359041861125, 0.18656010925769806, 0.1257807556539774, 0.19278470453407082, 0.17292082256504468, 0.10404107719659805, 0.2008590812661818, 0.15978298682187284, 0.13334642111190728, 0.10361647033797843, 0.12006100400217942, 0.14562976413539477, 0.2154892190758671, 0.1511881330183574, 0.1331344060599804, 0.1472760122269392, 0.12105482710259301, 0.10925158831690039, 0.13289214191692217, 0.10104363518101828, 0.21400339023343154, 0.15113558726651327, 0.12380429171025753], [0.03261718173910465, 0.07659206938530717, 0.018638466385060122, 0.03773216191413147, 0.041947771063340564, 0.02120850937041853, 0.02818069078161248, 0.07955622925822224, 0.036025714195732556, 0.028779092510896068, 0.04320988351745265, 0.04083170648664236, 0.00531253098077806, 0.030293847301176617, 0.02468148060142994, 0.014570112905598112, 0.04001928633078933, 0.06423528173140117, 0.020512005048138753, 0.008999213177178587, 0.010647885335077132, 0.00825657186630581, 0.014401654712855816, 0.043662507086992264, 0.04585630240451012, 0.03770235387076225, 0.008223148927624737, 0.02798776970511036, 0.056594651724611006, 0.050698226517332454, 0.01686378857786102, 0.03907519306189247, 0.04056645018447723, 0.06583340133407287, 0.03038996857191835, 0.028112599792491113, 0.013775063246222479, 5.949124498026712, 33.25336626597813, 46.87714740208217, 49.19587591716221, 31.753389154161724, 38.91986540385655, 64.20264039720807, 58.78230898720877, 15.179837158748082, 0.3749213490102972, 0.19090942373233183, 0.017569346253627112, 1.0161903287683214, 2.0357042849063873, 0.2933666780591011, 0.08642150408455304, 0.07942842718745981, 12.296648280961172, 58.03257056644985, 82.13535036359514, 71.8637866973877, 62.37641756875174, 62.97688783918108, 69.67388125828334, 67.40497480119977, 68.6333954674857, 67.34104442596436, 66.12173284803117, 65.14879744393485, 63.444279261997764, 67.7488272530692, 66.06481320517403, 62.68315969194685, 53.09394039426531, 44.90529033115932, 47.34334373474121, 51.75419569015503, 66.28045749664307, 64.15851238795689, 67.21535846165249, 62.875145367213655, 61.037638664245605, 56.52283123561314, 62.730789593287874, 63.67855167388916, 67.93230833326066, 62.41707147870745, 65.22689519609723, 60.19888687133789, 52.1056946345738, 46.26868322917393, 70.73901230948312, 32.19939749581473, 22.73216598374503, 67.98650428227016, 57.88975034441267, 64.78137670244489, 60.41177272796631, 61.93868105752127, 63.02897153581892, 63.172250338963096, 59.61947659083775, 56.26419496536255, 43.107881682259695, 44.41937153679984, 49.00569329942976, 56.33790145601545, 57.664614813668386, 60.26524911608015, 59.18843814304897, 53.16809504372733, 50.30277953829084, 49.25871889931815, 51.95573513848441, 59.14214924403599, 61.18124403272356, 62.092805998665945, 59.84838499341692, 60.782473019191194, 61.69456304822649, 63.06353882380894, 63.40476485661098, 60.12798745291573, 63.49512617928641, 62.77292346954346, 63.73849378313337, 66.01540456499372, 61.00432900020054, 60.41161291939871, 66.23796926225934, 48.9923597063337, 17.71518792424883, 1.0229291043111255, 0.0638257112087948, 0.11369818435715777, 0.10133151723338024, 0.26022789627313614, 0.2570786252617836, 0.11372766670371805, 0.13156916147896222, 2.577674848692758, 33.084629263196675, 52.3355063029698, 35.02294043132237, 17.617638690131052, 30.052379812513077, 40.062138829912456, 38.79424892153059, 7.576920236860003, 0.11734250773276601, 0.010506610951519437, 0.012307517529864396, 0.07681789941021375, 0.037794576957821846, 0.013815386037874435, 0.03477609357131379, 0.08198860088097197, 0.02996810299477407, 0.04102711778666292, 0.024396046364147748, 0.011176708387210965, 0.018624381694410528, 0.0374506580909448, 0.06652165975953851, 0.05559676080676062, 0.007710913512190538, 0.04621599381789565, 0.02144104671398444, 0.04402109927364758, 0.028906107481036867, 0.038574156018772295, 0.020156681703935777, 0.03975186210923961, 0.010556934501177498, 0.005686533545875656, 0.04516739258542657, 0.05649532776858125, 0.011757290090567299, 0.0037183956509189947, 0.03429131083456533, 0.026277472996818166, 0.008728598992872452, 0.07387750861900193, 0.05936512377645288, 0.024139590661174486, 0.02058037423661777, 0.08549745474010706, 0.08856888421412025, 0.04508036029125963, 0.025829527926232134, 0.048569774122110436, 0.036584399574037106, 0.007146269748253482, 0.025713852972590497, 0.027372572537777678, 0.0015944920908493388, 0.022518465328695517, 0.012348572291167719, 0.032967828280691586, 0.08366294710763864, 0.03914394222998193, 0.04380479248772774, 0.04500280713130321, 0.06220254009323461, 0.016705905353384357, 0.02189117666733052, 0.07331237037267004, 0.07422105768429381, 0.06794416092868362, 0.027486062608659267, 0.08535758831671306, 0.03412124960284148, 0.013768958975560963, 0.06358564551919699, 0.04016934095748833, 0.015991204418241978, 14.291072232382637, 49.399402550288606, 54.58833115441458, 37.84440238135201, 25.677347557885305, 55.35971321378435, 71.8219724382673, 54.523626055036274, 13.614100558417183, 1.0017211394650596, 0.12072036362120084, 0.03725112129801086, 0.999734280364854, 0.8700046273214477, 0.9278521261044911, 0.22495594966624463, 0.12398235286985125, 21.48908461843218, 65.1012578691755, 80.31640229906354, 69.39528628758022, 62.96718120574951, 64.59927136557442, 70.8338760648455, 67.79160036359514, 68.79608753749302, 67.95479270390102, 68.33535943712506, 70.6071424484253, 70.01202923910958, 68.56812408992222, 67.19205420357841, 62.00302137647356, 55.4995630809239, 48.011885506766184, 50.35259812218802, 52.61624131883894, 68.43320396968296, 67.53639302934918, 69.25630841936383, 65.34848172324044, 63.52129309517996, 57.59142943790981, 66.07601370130266, 64.48216642652238, 68.5705976486206, 61.89537293570382, 65.22763865334647, 59.962703704833984, 57.14924260548183, 47.015044825417654, 69.6291001183646, 34.20478309903826, 24.89887833595276, 65.78270244598389, 54.070763315473286, 65.13121850149972, 61.095607485089985, 65.62673623221261, 62.34548418862479, 66.87616130283901, 61.71966688973563, 59.08578545706612, 46.37442438943045, 47.50473996571132, 48.24124206815447, 54.51670217514038, 57.035854952675955, 59.13694504329136, 58.26813186917986, 53.929923330034526, 50.34102242333548, 51.02374199458531, 55.195895535605295, 62.250682967049734, 61.24328449794224, 63.915728432791575, 59.95606122698103, 62.256978034973145, 63.80457809993199, 65.82377324785504, 62.72969872610909, 61.89858300345284, 63.16460037231445, 61.85009847368513, 65.59287766047886, 66.0527789252145, 60.27964578356062, 57.04604796000889, 64.78702558789934, 55.63065821783883, 25.66220395905631, 2.3941605474267686, 0.08274589345923491, 0.4103280119597912, 0.1900882606527635, 0.08349334049437727, 0.1358695535787514, 0.10709227275635515, 0.13776550255715847, 2.6103329019887105, 28.608601467950002, 59.42508683885847, 56.81820610591343, 25.949722153799875, 31.077492713928223, 41.97602360589163, 47.6470946584429, 14.381843498774938, 0.06913205182978086, 0.04106360261461564, 0.09038469820682492, 0.03077863682327526, 0.061161884505833895, 0.06382436770945787, 0.060189767740666866, 0.12328969075211457, 0.030914031700896363, 0.08369038027844258, 0.021327459951862693, 0.03691193860556398, 0.018194271916789666, 0.04914328209789736, 0.05433258221351674, 0.012749438057653606, 0.03876193719250815, 0.03741117753088474, 0.018695907767063806, 0.018591259007475207, 0.030438999512365887, 0.007039984871101166, 0.061230911873281, 0.04918090686468141, 0.031247667369565794, 0.030482110234775713, 0.07285648304969072, 0.048598133493214846, 0.027659426609586393, 0.02440315401846809, 0.15056132950953074, 0.15361670484500273, 0.12125806191137858, 0.19656745583883353, 0.15217802061566285, 0.1828029387231384, 0.13984643375234945, 0.2807472294994763, 0.20153629992689404, 0.10468609258532524, 0.099305045258786, 0.13489771501294204, 0.12111961362617356, 0.14213579733456883, 0.13302582688629627, 0.13179611787199974, 0.24153376796415874, 0.22052746372563498, 0.06612551065960101, 0.0716777252299445, 0.17138118589563028, 0.09946116938122682, 0.0857443261359419, 0.10895705662135567, 0.13027558874871048, 0.12338157796433993, 0.1344005795461791, 0.14250935800373554, 0.16805876631821903, 0.16483462575290883, 0.18051611286188873, 0.14823430723377637, 0.15521074645221233, 0.16029369298900875, 0.16882342100143433, 0.15127156568425043, 0.08143627337579216, 12.033927338463918, 63.90022700173514, 69.98892647879464, 61.91778782435826, 44.90524864196777, 54.73781817299979, 73.16628210885185, 71.54156398773193, 24.848106111798966, 1.1028470673731394, 0.5275661881480898, 0.2846824883350304, 6.204874660287585, 6.171925434044429, 1.2711410139288222, 0.21201537762369427, 0.1819735246577433, 17.57747115407671, 60.77974932534354, 81.04956926618303, 73.68742479596818, 66.44017573765346, 65.76866708483014, 70.29117311750139, 68.87062781197685, 71.29254749843052, 71.99515628814697, 69.48418848855155, 71.31701210566929, 69.2075390134539, 72.81226444244385, 70.36977808816093, 66.70419338771275, 58.18105704443795, 51.813547202519004, 52.163503646850586, 57.26311663218907, 70.87316812787736, 70.20154135567802, 70.87129211425781, 72.42211614336286, 67.88026632581438, 61.71138463701521, 67.21448298863002, 68.68447167532784, 71.18501022883824, 66.81453772953579, 66.60672405787876, 60.83393137795584, 57.5118065561567, 51.78266245978219, 69.1081519808088, 36.81717722756522, 28.3384051322937, 65.38297952924455, 58.03692013876778, 65.67974403926304, 63.07760892595564, 65.74938583374023, 66.51554979596818, 68.34489236559186, 65.19023650033134, 61.741977555411204, 49.39353827067784, 50.49650573730469, 55.616438729422434, 61.51356247493199, 63.68691035679409, 66.47620214734758, 65.58471352713448, 58.990338053022114, 54.66949653625488, 54.66222872052874, 57.662898608616416, 64.00322014944894, 61.56856441497803, 65.10078539167131, 60.19739300864083, 63.59798036302839, 66.43542316981724, 69.97987992422921, 68.08787849971226, 64.57174260275704, 67.87409632546562, 65.17694459642682, 67.52611664363316, 67.83354663848877, 59.75203432355608, 64.42318316868374, 71.06611265454973, 52.4746161869594, 21.15075077329363, 1.9790132812091281, 0.11381241572754723, 0.4520961849817208, 0.3570233594094004, 0.6606459585683686, 1.085249777351107, 0.7068568531955991, 0.2856393041355269, 4.430454126426151, 44.90829542704991, 59.86903503962925, 44.84410796846662, 29.05464107649667, 41.304733821323936, 53.10903535570417, 59.52187524523054, 15.275567701884679, 0.20694338264209883, 0.2120662270379918, 0.1531332486442157, 0.1255528357412134, 0.16919775520052227, 0.2992350288799831, 0.2455630446118968, 0.18358823444162095, 0.08584339224866458, 0.13980858506900923, 0.09043130677725587, 0.15072176232933998, 0.08091666482921157, 0.21086661783712252, 0.1695335078984499, 0.157807323549475, 0.08604757022112608, 0.11528650591416018, 0.08793129199849707, 0.12232458325369017, 0.08220482285001449, 0.15256376777376446, 0.18453100456723145, 0.11631454075021402, 0.14601993534181798, 0.0911583366936871, 0.17579979236636842, 0.12651875748166017, 0.08085361535527877, 0.11216956031109605], [0.06327605034623827, 0.05515346370105233, 0.03644818027636834, 0.0663018754816481, 0.012031955977103539, 0.0008793930994995337, 0.024394713042836105, 0.01585011663181441, 0.03583582956343889, 0.027484924366165484, 0.02274156255381448, 0.011431633145548403, 0.030224626551249197, 0.014475492893585136, 0.03083990514278412, 0.07089994767946856, 0.03615642718172499, 0.006503842122453664, 0.04888818685763648, 0.03666365924956543, 0.08048978487827949, 0.11078998326723065, 0.04890224610322288, 0.07029188530785696, 0.06226811371743679, 0.08536554074713162, 0.04815324183021273, 0.06150693313351699, 0.041215967653053145, 0.018298705241509845, 0.08125231574688639, 0.0457844217973096, 0.052832083443978, 0.020402486103453805, 0.01556705217808485, 0.060432852911097665, 0.05994455197027751, 0.03936234908178449, 2.6682995515210286, 29.472048895699636, 54.66997596195766, 46.54636103766305, 32.976855754852295, 39.49216767719814, 44.95677995681763, 71.66381754193986, 29.001631532396587, 2.9242377494062697, 0.3744642606803349, 0.19486775275851997, 1.2346660111631667, 1.0537583700248172, 0.10851885870631252, 0.025947698192404847, 0.30969000501292093, 1.032531514763832, 23.937536001205444, 61.76316956111363, 78.65878445761544, 71.37269496917725, 64.56487083435059, 67.77343082427979, 66.96295819963727, 67.52959074292863, 70.77786663600376, 67.40245955330985, 65.76305988856724, 62.97754096984863, 57.85126774651663, 60.03021240234375, 53.02168607711792, 49.3274678502764, 50.19953972952706, 57.95296505519322, 69.07572473798479, 63.623014722551616, 67.60672964368547, 64.10915238516671, 59.53292982918875, 56.916901792798726, 59.245920589991975, 61.69292327335903, 64.0568185533796, 63.71949740818569, 69.08523682185582, 58.435128348214285, 58.43376650129046, 60.7401237487793, 75.02786431993756, 32.0440913609096, 22.925553458077566, 76.55111789703369, 59.34104837690081, 65.84849493844169, 63.22024849482945, 67.17078576769147, 62.120230538504465, 66.6784920011248, 59.424989564078196, 52.05563981192452, 46.63410636356899, 53.06899983542306, 58.91404683249337, 64.72084399632045, 61.434762954711914, 63.19586031777518, 58.96791621616909, 58.93601703643799, 56.01971564974104, 54.14471646717617, 53.293530872889924, 63.356822286333355, 64.8213357925415, 70.77150903429303, 64.97334153311593, 61.62902763911656, 57.80315841947283, 60.36184992109026, 61.37684277125767, 64.0180059160505, 65.07082475934709, 62.94189671107701, 64.40098367418561, 59.59380299704415, 62.548260416303364, 60.16384015764509, 25.495019878659928, 3.740352962698255, 0.14653780683875084, 0.048175321359719546, 0.19362558584128106, 0.2087761735809701, 0.33807928594095366, 0.2270607381526913, 0.09543718530663423, 0.08721590574298586, 6.937565241541181, 46.78292982918875, 53.06263875961304, 23.276493072509766, 17.465339388166154, 28.611288683755056, 43.76703296388899, 24.460005794252666, 1.54873403268201, 0.0160714428805347, 0.04610732304198401, 0.018861422814162712, 0.01864941624392356, 0.021345853339880705, 0.06420627435935394, 0.05779377238026687, 0.057504499331116676, 0.00870362127066723, 0.029411185200193098, 0.059484525583684444, 0.045459559586431296, 0.013358843080433351, 0.040410322669361315, 0.05196404377264636, 0.015447645281840647, 0.022142697724380662, 0.019023026106879115, 0.00034311490890104324, 0.038896168382572274, 0.0349229319420244, 0.027947490170065845, 0.038144989404827356, 0.00968125113286078, 0.028669183408575397, 0.060897662969572205, 0.04535099059077246, 0.03845694927232606, 0.050019535435629744, 0.05229272613567965, 0.05690474562080843, 0.03036390943452716, 0.05270750441455415, 0.020402336825749705, 0.021691044459917715, 0.030347651735480343, 0.007466712151654065, 0.03367401020867484, 0.05605548779879298, 0.04439146065020135, 0.02511108317412436, 0.029205609445593188, 0.018920345098844597, 0.052493989800236056, 0.041555252125752826, 0.03193089445786817, 0.01068851855650012, 0.038682921789586544, 0.01872650291105466, 0.01713670723672424, 0.020339004063446606, 0.06457131941403661, 0.05951189768633672, 0.04998672826747809, 0.015890949172899127, 0.01222825191715466, 0.03018032499988164, 0.04854267682614071, 0.08256063304309334, 0.013735547063073941, 0.020473262394911478, 0.1469039579055139, 0.022936483612284064, 0.04938290673973305, 0.004178427126524704, 0.04703932820952364, 0.09581882732787303, 0.024374083881931644, 0.055718703727637015, 7.833851592881339, 44.64946460723877, 64.62443774087089, 42.683735847473145, 32.01809467588152, 50.64842809949602, 68.23325565883091, 76.14805289677211, 24.334771462849208, 3.2574268877506256, 0.25212005419390543, 0.06997434448982988, 0.2654523716441223, 0.2628124090177672, 0.276489042277847, 0.2938814418656485, 0.6777126342058182, 3.077837884426117, 32.331607818603516, 70.94148976462228, 78.27025508880615, 70.83315345219204, 64.4727029800415, 68.74232237679618, 69.3679451261248, 71.52851527077812, 72.1615378516061, 70.04624216897147, 66.5995465687343, 65.51151425497872, 63.67026942116873, 64.81922354016984, 55.3343175479344, 51.640123639787944, 51.662653173719136, 58.65505967821394, 71.3403650011335, 65.05882522038051, 69.79760783059257, 65.61600126538957, 61.62897205352783, 57.51616655077253, 60.62584672655378, 62.577415057591026, 67.94933141980852, 65.18871484483991, 69.18486704145158, 58.58051940373012, 56.93747540882656, 57.760611125401084, 73.60642269679478, 33.357808113098145, 24.714888300214493, 75.36940302167619, 60.1174817766462, 66.44515759604317, 62.92833382742745, 67.81312588282994, 66.46129131317139, 68.52706023624965, 61.97721576690674, 53.18232842854091, 47.34531354904175, 52.127505029950825, 59.397856848580496, 66.22820009504045, 64.98677240099225, 64.61616243634904, 61.86730916159493, 59.529914311000276, 57.035125391823904, 56.455176625932964, 55.35969236918858, 63.21633665902274, 64.60687964303153, 67.71315520150321, 64.86451884678432, 62.65857696533203, 59.8434795652117, 62.1082101549421, 65.4927749633789, 64.2968440737043, 65.74261134011405, 64.94113663264683, 64.42446858542306, 59.16566889626639, 62.97820799691336, 61.70428357805525, 35.281653131757466, 6.072017286505018, 0.15313989828739846, 0.19397952327770845, 1.0599307588168552, 0.36578441358038355, 0.058291898508157046, 0.11257404182106256, 0.11024468538484403, 0.09614703471639327, 5.243125855922699, 44.45182657241821, 69.78193964276994, 41.10026570728847, 13.131503002984182, 24.958601576941355, 49.61172212873186, 35.047203540802, 3.827499006475721, 0.039876427567963085, 0.041445231065154076, 0.02206070694540228, 0.00858016945754311, 0.043270524192069254, 0.10608793914850269, 0.00825439376889595, 0.05614655737632087, 0.02346605814195105, 0.02967234654352069, 0.04330563837928431, 0.03333898015054209, 0.054425884171255996, 0.0262809962899025, 0.013956179509737661, 0.033022735334400616, 0.013082366353566093, 0.03118656189846141, 0.021908053529581854, 0.043422546570322344, 0.06977689079940319, 0.0849481602864606, 0.06696182542613574, 0.05494663604934301, 0.01841744886977332, 0.027963805544589247, 0.04529434988009078, 0.01455310542535569, 0.05786047237260001, 0.06218716448971203, 0.08313028354729925, 0.09631819517484733, 0.10640095413795539, 0.1609198586749179, 0.12624074811381952, 0.0685375737292426, 0.06939222251198121, 0.12336181902459689, 0.218825562191861, 0.16888189714934143, 0.08631627008851085, 0.09788335833166327, 0.08792892391128199, 0.16341578188751424, 0.10184881876089744, 0.09972660549517189, 0.09055727001811777, 0.15007936608578476, 0.13549322448670864, 0.1625588328710624, 0.13276518801493303, 0.14080491874899181, 0.22560908033379487, 0.20075887521462782, 0.1790913657418319, 0.1985730832176549, 0.18009823028530392, 0.26997988298535347, 0.147427624091506, 0.11394960193761758, 0.11046266475958483, 0.19427503884903022, 0.1587594710290432, 0.1097086291494114, 0.0980588953409876, 0.13076622384999478, 0.13727325254252978, 0.09003206355763332, 0.14640775881707668, 5.668145860944476, 48.607311385018484, 79.23268481663295, 58.7013555254255, 47.59874561854771, 55.614576612200054, 55.530833448682515, 84.83455181121826, 42.733926159994944, 5.823748162814549, 0.6921974569559097, 0.3098355100623199, 2.9275898209639957, 3.225232626710619, 0.3044443864907537, 0.25738600162523134, 0.3704747733260904, 1.9100502388817924, 28.067694629941666, 67.01217923845563, 81.47360392979213, 71.93752098083496, 65.14333615984235, 67.42050402505058, 68.7728944505964, 71.94139112745012, 75.31501947130475, 75.41945784432548, 71.67736652919224, 65.89766039167131, 63.07462814876011, 65.83388287680489, 56.51813425336565, 54.95154128755842, 56.37198237010411, 63.3268894468035, 75.78502341679165, 69.23793043409074, 73.76876735687256, 68.50452028002057, 62.986024720328196, 59.47164671761649, 64.25537027631486, 67.84890910557338, 70.54159314291817, 69.78699793134416, 73.26012447902134, 61.49400329589844, 59.073917933872764, 59.910362924848286, 74.95203862871442, 36.30944456372942, 29.388934544154576, 75.00331633431571, 64.05427551269531, 69.14809022630963, 68.0090720312936, 70.51177147456578, 70.50578907557896, 71.49134935651506, 63.43786607469831, 55.718021392822266, 50.546949659075054, 56.867687702178955, 62.03086975642613, 66.90397494179862, 65.66377707890102, 66.58276666913713, 62.21409375326974, 61.882011549813406, 61.282124928065706, 61.298494883946006, 58.56303078787667, 68.10565199170793, 72.00112479073661, 76.13447611672538, 70.88821792602539, 65.31732600075858, 60.84774439675467, 62.62090383257185, 66.08492824009487, 69.29602432250977, 67.22758729117257, 65.48691763196672, 66.72089685712541, 59.746857915605815, 66.30529730660575, 62.446712493896484, 29.763039452689036, 4.803486406803131, 0.2260859411742006, 0.2578430085309914, 0.7300834325807435, 0.8522822154419762, 1.049505095396723, 1.1329770620380128, 0.4043681403355939, 0.19446494723004953, 11.5279404095241, 59.47958156040737, 60.86323193141392, 33.86847291673933, 27.011344364711217, 38.717711039951865, 59.08766147068569, 41.830212184361045, 3.6986338070460727, 0.14853396186871187, 0.16562156352613652, 0.10675787034311465, 0.14370389176266535, 0.19360627473465034, 0.22096145472356252, 0.12441455253532954, 0.17456664996487753, 0.19351098127663136, 0.13976389675268105, 0.14674698561429977, 0.1574241683951446, 0.0851987229127969, 0.19032975126590046, 0.12269355702613081, 0.08879383892885276, 0.12061612707163606, 0.11966986927602973, 0.0493875004218093, 0.07643136515149049, 0.09687588989202466, 0.15333641559949943, 0.15298140607774258, 0.09454239439219236, 0.10208759523395981, 0.14866380632988044, 0.11387030833533832, 0.1875132881104946, 0.24121132812329701, 0.20468133687973022, 0.14851047098636627], [0.06478256772139243, 0.03657398406150086, 0.016713409950690608, 0.03696252339120422, 0.08096011142645564, 0.034308267424681356, 0.01283842877351812, 0.07124018549386944, 0.10549969678478581, 0.03708798112347722, 0.0355706512928009, 0.0679021053282278, 0.02016717185532408, 0.0346019848782037, 0.0659319789015821, 0.0522445569347058, 0.02783498227862375, 0.04088764491357973, 0.10678529672856842, 0.0157135207472103, 0.03455293018903051, 0.03890375440408077, 0.03995998915550964, 0.06624146550893784, 0.022270810224914124, 0.06472080746399504, 0.03408643736370972, 0.09896820690482855, 0.04690158220806292, 0.047049682653908215, 0.10622284548091036, 0.04014473049236195, 0.0849539346194693, 0.07135397581649677, 0.060692155068474155, 0.07436721412731068, 0.06885564380458423, 0.037536262068897486, 0.04227965611166187, 0.9180614628962108, 20.71585954938616, 57.695346696036204, 58.08751344680786, 45.49923971721104, 33.361650466918945, 34.22488076346261, 71.86701760973249, 51.375984396253315, 12.343498247010366, 0.08873808370637042, 0.08352367779506104, 0.2393406613596848, 0.4237940279500825, 0.2614553118390696, 0.2533114802624498, 0.08062671324504272, 0.2002892746989216, 2.551229787724359, 23.536230632237025, 60.45915249415806, 79.42259298052106, 70.71363748822893, 66.37830897739956, 67.14484814235142, 67.4543070111956, 65.68125179835728, 70.11297961643764, 70.62914044516427, 69.74655941554478, 58.75037506648472, 55.4621296610151, 52.89733416693551, 50.42348364421299, 59.483222416469026, 67.60121972220284, 64.83944974626813, 65.88797460283551, 66.26435852050781, 64.85201903751918, 63.742725236075266, 59.20885195050921, 62.373541014535085, 66.7232106072562, 64.98768261500767, 68.52407251085553, 61.75462327684675, 64.06907517569405, 63.266620772225515, 59.57413959503174, 32.073405810764854, 38.503897598811555, 68.90768255506242, 61.69469506399972, 66.1257905960083, 66.16554818834577, 66.02714702061245, 63.53477260044643, 64.81337315695626, 51.50481789452689, 46.52563108716692, 49.41956969669887, 64.59770802089146, 63.80024937220982, 67.74911907741001, 68.99052592686245, 73.65409428732735, 68.77841826847622, 63.2932254246303, 59.728653635297505, 59.26058823721749, 57.93071344920567, 59.6860750743321, 61.12961196899414, 64.42073045458112, 62.016486985342844, 66.25495065961564, 64.95710359300885, 62.946774346487864, 65.9967347553798, 66.73786435808454, 65.58002349308559, 64.26060226985386, 65.1849558694022, 65.03112970079694, 38.085084506443565, 6.187468120029994, 0.07471136708876916, 0.1375386140176228, 0.284585104989154, 0.5950294509530067, 0.6054633653589657, 0.11315000948629209, 0.10724519419350795, 0.1230378592652934, 0.17413845365600927, 17.370826516832622, 56.42193296977452, 40.962559359414236, 16.86342215538025, 27.668044669287546, 49.10151938029698, 44.105236530303955, 20.591556276593888, 1.459946911249842, 0.051113065864358626, 0.06619019540292875, 0.03504962460803134, 0.05684082083670156, 0.05029725642608745, 0.054070341999509504, 0.05086439635072436, 0.0662299846964223, 0.03277726511337927, 0.04266817508531468, 0.019636167313105295, 0.03689764187272106, 0.02234424976631999, 0.019107580051890442, 0.0032962512382904863, 0.03218215597527368, 0.01733867997037513, 0.018944146410961236, 0.0832210240353431, 0.01990030742516475, 0.00648761580565146, 0.018837489187717438, 0.0749236060572522, 0.027226668849055256, 0.0374921776487359, 0.03477450579937015, 0.009202319912479391, 0.004686201598295676, 0.04988642043567129, 0.04013426748237439, 0.07729170005768538, 0.06276342392499958, 0.044706911580371, 0.035029577290905375, 0.013506578813706125, 0.04744474949049098, 0.02431075111962855, 0.044258776519979746, 0.03910465844507728, 0.08626566494682006, 0.07921251055917569, 0.10008541481303317, 0.004109437926672399, 0.043675304257443974, 0.01987512699062271, 0.0657459788822702, 0.032558749695973735, 0.026249558066150973, 0.03027549632159727, 0.0923719440719911, 0.0746820272345628, 0.07303716335445642, 0.055732098008905134, 0.006269177571604294, 0.032774659538907666, 0.10155170863228184, 0.0633512388116547, 0.08287016714790038, 0.034120106271335056, 0.029692414216697216, 0.0035654199309647083, 0.03944943565875292, 0.0821820240733879, 0.010999142558180859, 0.021115541591175964, 0.0901320796193821, 0.03248484026906746, 0.039406158695263524, 0.06676814439041273, 0.06902628179107394, 0.047446866519749165, 3.3994589235101427, 35.22002955845424, 67.95231914520264, 58.66721207754952, 40.97529888153076, 32.09818656103951, 59.04643086024693, 84.7226232801165, 47.38273654665266, 9.116487315722875, 0.05062022891693881, 0.0773905897513032, 0.148688423580357, 0.15797436530036585, 0.4880283868738583, 0.3978322467633656, 0.37054211114134106, 0.03265991587457912, 5.3261616059712, 33.817455768585205, 67.32721056256975, 79.42303071703229, 69.08247143881661, 67.69112246377128, 68.45452104296002, 69.4182848249163, 68.97433662414551, 75.46317590985979, 73.23683411734444, 68.83047417231968, 59.23758275168282, 57.511948994227815, 54.3529817717416, 53.16368988582066, 63.22380597250802, 69.25969219207764, 68.15946578979492, 68.46235861097063, 69.05121149335588, 67.35647637503487, 65.82430131094796, 62.88037736075265, 63.426248686654226, 65.76579053061349, 65.56841305324009, 69.7934319632394, 60.8169777733939, 67.04300144740513, 63.08499486105782, 61.84201077052525, 32.1440029825483, 35.32229661941528, 66.05944224766323, 61.96343748910086, 67.26612894875663, 66.93458870479039, 68.4307165145874, 64.70244516645158, 66.80132920401437, 56.85766839981079, 50.40005431856428, 50.05835233415876, 61.66552652631487, 64.0697352545602, 67.55265181405204, 65.09268379211426, 72.53954764774868, 64.672609601702, 64.3991562979562, 61.70787579672677, 60.58037771497454, 59.53424998692104, 60.859994070870535, 65.24539130074638, 68.00105381011963, 61.71833283560616, 66.09172357831682, 65.46916498456682, 62.09703050340925, 66.02515983581543, 67.66641466958183, 66.05201462336949, 62.987532479422434, 65.65607152666364, 65.69993550436837, 45.51144770213536, 12.345560124942235, 0.4249371423252991, 0.09718207203383956, 1.2650818590606963, 1.602065908057349, 0.3890187011233398, 0.1512295100837946, 0.07450884474175316, 0.08107519096561841, 0.163086773827672, 14.612145015171595, 63.45779350825718, 61.220237323216026, 25.20018870489938, 14.880805798939296, 38.78100218091692, 51.40510082244873, 31.075498580932617, 3.376319468021393, 0.1332647797784635, 0.09404143198792424, 0.10204133271638836, 0.06691564433276653, 0.04431710678285786, 0.018815185741654465, 0.05618159692468388, 0.09984249249100685, 0.024263643825958883, 0.07837352915001766, 0.043286127104823074, 0.010698644843484675, 0.008298853927824115, 0.03446183007742677, 0.003443507968248533, 0.024593708704092672, 0.041816423647105694, 0.009000942593307366, 0.05810916902763503, 0.014058299878213023, 0.020917565428784916, 0.028991806453892162, 0.03147244905786855, 0.04190303524956107, 0.0023717689036857337, 0.06939809183989253, 0.008429566913816546, 0.007048301590007863, 0.031122762643332993, 0.03173399716615677, 0.012257096440797406, 0.022518707904964685, 0.2906726226210594, 0.1556717702852828, 0.1316686618540968, 0.13397919572889805, 0.12301199351038251, 0.1426967286637851, 0.22595469893089362, 0.19353831266718252, 0.16533139481076173, 0.18186214991978236, 0.1582653211163623, 0.10469370574823447, 0.11540841151561056, 0.1402452087828091, 0.21127037331461906, 0.09534992570323603, 0.1886768535311733, 0.09793964959681034, 0.19759359077683517, 0.14618324515010628, 0.12440969422459602, 0.18896143111799443, 0.10864815355411597, 0.25214288011193275, 0.1295548624226025, 0.12247548944183759, 0.12534186563321523, 0.14977127047521727, 0.11316857420440231, 0.10031334151114736, 0.21587157355887548, 0.08594439897154059, 0.2341948960508619, 0.19807309790381364, 0.09117140527814627, 0.1904168887329953, 0.14780974787260803, 0.12120501404362065, 0.14375669535781654, 2.0268759472029547, 33.42344774518694, 81.42193712506975, 73.96021107264927, 58.37999439239502, 47.544108458927695, 46.74024357114519, 81.50689969744, 68.79300253731864, 20.37521890231541, 0.22221407108008862, 0.40331817524773733, 1.508909021105085, 1.3249325560671943, 1.9091890965189253, 0.5936036588890212, 0.3396299013069698, 0.29987247181790216, 3.763753627027784, 27.19361298424857, 63.75776808602469, 81.76279490334647, 69.80994088309151, 67.43639455522809, 70.98807048797607, 68.4527839933123, 68.67739840916225, 74.20880372183663, 78.27541065216064, 73.25035531180245, 64.75908688136509, 63.17270197187151, 59.11129229409354, 56.251045499529155, 65.66254029955182, 70.84234591892788, 69.34762859344482, 68.92187772478376, 74.20738628932408, 72.81545366559709, 70.74607167925153, 64.40351976667131, 66.63486426217216, 69.87083489554269, 69.18665967668805, 68.95132419041225, 63.72741835457938, 66.16138621738979, 66.6564245223999, 57.76370307377407, 41.479668617248535, 48.90370069231306, 64.08228370121547, 67.79160036359514, 67.73006016867501, 69.65613555908203, 69.98435456412179, 66.99206420353481, 69.09832027980259, 60.73027120317732, 51.27434267316546, 56.98507056917463, 70.2284517288208, 72.63222272055489, 74.98875985826764, 73.57879665919712, 78.21874809265137, 72.78358922685895, 69.35420158931187, 68.03046553475517, 64.3735521861485, 64.88054139273507, 63.23781354086739, 64.52563435690743, 65.12611157553536, 61.26387895856585, 66.58833912440709, 67.77582795279366, 63.894029208592, 70.00577586037772, 70.27668612343925, 71.20136628832135, 65.14082091195243, 66.38349928174699, 67.15246336800712, 42.85149662835257, 8.815176946776253, 0.18986587758575166, 0.26924375391432215, 0.6854653581976891, 1.7165616899728775, 3.732650016035352, 3.9292097772870744, 0.5736783966422081, 0.38399428501725197, 0.5261141232081822, 27.081470796040126, 67.32350717272077, 49.72719424111502, 26.019777366093226, 37.779294286455425, 58.462038721357075, 61.04377392360142, 34.72010666983468, 2.5762928085667745, 0.1750021744519472, 0.11350858810224704, 0.25804078791822704, 0.17755056199218544, 0.13890738199864114, 0.11253169445054871, 0.15246843360364437, 0.2114248350262642, 0.08368643120463405, 0.12830654797809465, 0.1404697224497795, 0.1050066596695355, 0.07924752975148813, 0.1321154228810753, 0.11771389708987304, 0.11030622172568526, 0.142280108162335, 0.07594301671321903, 0.11258254386484623, 0.07119373977184296, 0.10076791926154069, 0.10920143779367208, 0.09183765202760696, 0.15704710648528167, 0.11031013008739267, 0.09411769932402031, 0.05372812964820436, 0.1126347639198814, 0.102143927211208, 0.12447735773665564, 0.15237638354301453, 0.07712790170418364], [0.04096415652228253, 0.03399072660665427, 0.04171625830765281, 0.06164612102189234, 0.08534850273281336, 0.006593708148492234, 0.02375500719062984, 0.056513573575232706, 0.033273101185581515, 0.062317714627299986, 0.03210355447871344, 0.058404331760747094, 0.054175928833761385, 0.017232155061459968, 0.021567629118050848, 0.025917779887095094, 0.08988149663699524, 0.013517230117161359, 0.16011481758739265, 0.0757793133546199, 0.05045048998934882, 0.05014935275539756, 0.04809313719826085, 0.13248852214642934, 0.054603789267795425, 0.07314707924212728, 0.03325463824772409, 0.04539270692371896, 0.02826040337926575, 0.03147762628006084, 0.04823193492900048, 0.04768403825749244, 0.05070557505158441, 0.012671605002001991, 0.07706126278000218, 0.021765464484425526, 0.031083597602056603, 0.038430801925382445, 0.10247488266655377, 0.029305408376135995, 0.03810266239036407, 7.5094471488680155, 47.43202359335763, 59.71063000815255, 53.23364782333374, 36.37400027683803, 25.81587553024292, 51.286595821380615, 63.900164467947825, 32.556618281773154, 1.4762972167560031, 0.4165841591145311, 0.11833158108804907, 0.7492522639887673, 1.1835997913564955, 0.06143519841134548, 0.07082721551081964, 0.06636379180209977, 0.2406334334186145, 2.0731049180030823, 24.012948274612427, 68.85582814897809, 72.05621705736432, 69.64512266431535, 76.7248784473964, 75.82613590785435, 73.13621030535016, 64.0365992954799, 61.7631904057094, 65.95651858193534, 66.00510733468192, 63.73901489802769, 56.46196501595633, 63.607492446899414, 69.85809884752545, 67.05644621167863, 69.14595018114362, 67.44234221322196, 63.075420243399485, 60.796313830784385, 61.77102797372, 65.18513652256557, 64.42271763937813, 68.11355904170445, 68.36288125174386, 63.931070055280415, 65.29252093178886, 67.37391635349819, 60.82275172642299, 37.03161253247942, 37.79944406236921, 57.699755328042166, 70.22076007298061, 68.2884521484375, 68.51014832087925, 63.67259011949812, 65.36448342459542, 54.91445875167847, 47.419315338134766, 55.03295333044869, 61.578236307416645, 65.23619883401054, 65.91117463793073, 64.23047488076347, 67.03530979156494, 68.4669930594308, 66.60897527422223, 64.85320023127964, 64.49295697893415, 62.87999520983015, 64.73398998805455, 67.92897319793701, 69.67702879224504, 72.28903034755162, 71.82500880105155, 67.22168827056885, 63.50315134865897, 66.6306050164359, 66.31229414258684, 71.4246049608503, 73.88705348968506, 64.50312219347272, 46.61825057438442, 12.692591377667018, 0.5212370306253433, 0.06504171381571464, 0.7068869801504272, 1.033567230616297, 2.037003598042897, 1.2930674659354346, 1.299343317747116, 0.2333004783306803, 0.014023224706761539, 1.7025295857872282, 32.4002560206822, 56.22700820650373, 22.913314206259592, 17.740279606410436, 34.11129856109619, 50.781284604753765, 38.31911373138428, 11.128676073891775, 0.7025568953582219, 0.143125820638878, 0.1377149788396699, 0.07648364627467734, 0.04836684126140816, 0.06072271628571408, 0.029306914723877395, 0.024039360860894834, 0.03992258830528174, 0.006812892771059913, 0.04572340453575764, 0.04082303820177913, 0.022925940874431814, 0.02705452960383679, 0.07540531163769108, 0.04444601147302559, 0.03842317858444793, 0.06066136993467808, 0.09426737736378397, 0.009842414225983833, 0.10739881452172995, 0.04211362537794879, 0.07509256127689566, 0.030324228706636598, 0.0194276959103133, 0.017296205374545286, 0.029532351198473146, 0.01961837273224124, 0.047765961182968955, 0.0178346517495811, 0.01581551643487598, 0.01809753487551851, 0.06281086709350348, 0.06693572218396834, 0.01747179327399603, 0.053450127065713914, 0.014142512859377478, 0.025394507251413803, 0.025958357977547815, 0.09205725310104233, 0.10700795120958771, 0.042935382175658426, 0.01976607453876308, 0.09531159526003258, 0.03491730010136962, 0.03669822382341538, 0.08584063739648887, 0.02876855486205646, 0.040342733796153746, 0.05051759710269315, 0.025143166006143605, 0.04900420277512499, 0.06014293525367975, 0.048845127025353055, 0.05422845083687987, 0.04523244373766439, 0.047983753960579634, 0.04253085656091571, 0.03636994518871818, 0.045971046068838665, 0.029205636586993933, 0.07305610805217709, 0.045597678782152276, 0.023320603982678483, 0.07761364456798349, 0.019719525340146253, 0.006990838579700461, 0.017839433725125024, 0.0545721729286015, 0.03287638211622834, 0.0611683102324605, 0.06597237887659244, 0.007400711898558906, 0.10935984857912574, 0.4190457213137831, 19.164123569216045, 63.34895692552839, 64.37915938241142, 45.7944895199367, 24.263288395745413, 40.246418952941895, 77.63594014304024, 75.98000376565116, 26.844521590641566, 0.6820397334439414, 0.21617325022816658, 0.14216711851102964, 0.6640183861766542, 0.5302460757749421, 0.3041379057935306, 0.15374399801450117, 0.2414805165358952, 0.12211722295199122, 5.099402802331107, 34.01351656232561, 75.46522562844413, 74.00577735900879, 73.97097383226667, 75.50810991014752, 72.86262498583112, 69.85035855429513, 65.67840303693498, 68.41893236977714, 71.49048777988979, 67.12397575378418, 64.15790094648088, 56.90176166806902, 63.30357129233224, 71.2940205165318, 67.55174854823521, 68.99987820216587, 68.6505436216082, 64.7403267451695, 62.46357577187674, 60.81587995801653, 66.41515527452741, 67.59819725581578, 72.72185448237828, 70.45496995108468, 65.17625672476632, 64.86264978136334, 65.28980418613979, 60.12696606772286, 40.200317655290874, 43.52371399743216, 61.509574208940776, 70.9284063066755, 70.56189577920097, 67.5304731641497, 66.49396869114467, 68.88890157427106, 60.941364424569265, 49.695468766348704, 53.39181661605835, 59.80485452924456, 67.23379898071289, 69.38674695151192, 69.00335230146135, 71.87113789149693, 70.61921841757638, 70.3663387298584, 67.2041927065168, 65.63795062473842, 65.36893027169364, 65.44267845153809, 66.27840777805874, 69.2174471446446, 70.37685135432652, 70.35262993403843, 68.69550541469029, 65.04595715659005, 65.42179216657365, 67.85416889190674, 66.93499170030866, 72.16701998029436, 68.03639234815324, 55.261142594473704, 20.048441648483276, 2.342383005789348, 0.11282824818044901, 1.317465522459575, 1.5586155652999878, 2.240080552441733, 0.5523054663624082, 0.49533501480306896, 0.358637485653162, 0.03706309924434338, 1.717653642807688, 29.34260048185076, 70.75576441628593, 41.45285899298531, 17.18344054903303, 18.858072791780742, 48.204708439963206, 52.25120728356497, 18.566691398620605, 1.5660781477178847, 0.08132056279906205, 0.03170091858399766, 0.05625792872160673, 0.03175459409664784, 0.02092967558253024, 0.02066825469955802, 0.016353068840024725, 0.008918011195159383, 0.013934142388669508, 0.039634163424904854, 0.034059787900852304, 0.04650491402883615, 0.02745053281874529, 0.041763986460864544, 0.02604250140887286, 0.02166405912222607, 0.06354852965367691, 0.02983009915000626, 0.036232175438531806, 0.04665717389434576, 0.07179205838058676, 0.05825850101453917, 0.0646749452820846, 0.0303763401960688, 0.03743092289992741, 0.009579905142475451, 0.04400516048605953, 0.01762970533621098, 0.09279378250773464, 0.03365899422871215, 0.04975596529298595, 0.01247550074809364, 0.07989477073507649, 0.08839785946266991, 0.17509286744253977, 0.07932754260088716, 0.23396812964762959, 0.15085768646427564, 0.15307413467339107, 0.17679721170238086, 0.13834845913308008, 0.13742001966706344, 0.21120857234512055, 0.11569016639675413, 0.10146460509193794, 0.17870369154427732, 0.13240561873785087, 0.09405542338000876, 0.14156742926154817, 0.14832050832254545, 0.13459405702139648, 0.22242645254092558, 0.2544211564319474, 0.16458539984055928, 0.24294218953166688, 0.1252516611878361, 0.18962802392031464, 0.19424945807882718, 0.17910626637084143, 0.11172415635415486, 0.1513373971517597, 0.09824282582849264, 0.10830728470214776, 0.16392137190060957, 0.1829331088811159, 0.14521565421351365, 0.0706438414220299, 0.18075216162417615, 0.1691192758402654, 0.22608245350420475, 0.11359984427690506, 0.2783744196806635, 0.31624275339501245, 0.2150485920054572, 15.740553310939244, 71.91009644099644, 77.67266137259347, 65.39802932739258, 49.116360732487266, 43.542755535670686, 64.5379535130092, 80.49904264722551, 49.05225665228707, 3.42660944376673, 0.8279990756085941, 1.7042451394455773, 5.673203715256282, 1.4678896793297358, 0.3007754933621202, 0.13172598449247225, 0.147339970937797, 0.24050755160195486, 3.576847084930965, 27.333372524806432, 73.18349974496024, 74.36300509316581, 73.81541061401367, 74.81549263000488, 76.59521116529191, 74.23491505214146, 67.97465065547398, 66.59567642211914, 72.71065398624965, 70.24306379045758, 68.46873010907854, 63.07086222512381, 68.57426629747663, 76.75473485674176, 72.16827065604073, 74.67061574118478, 71.55240317753383, 66.77507890973772, 66.5789521081107, 68.27090099879673, 73.49368122645787, 74.52336951664516, 76.82125691005162, 75.2940776007516, 67.95461205073765, 64.91139139447893, 66.69979517800468, 63.88145991734096, 45.6422301701137, 48.94721031188965, 60.186748368399485, 76.77325180598667, 76.26000227246965, 73.25407259804862, 69.35961423601422, 72.8704833984375, 62.80437796456473, 51.3908257484436, 57.5068872315543, 62.446490151541575, 67.95334053039551, 70.69077791486467, 67.62458651406425, 72.24611827305385, 71.62011337280273, 72.57028647831508, 68.2344924381801, 68.81810637882778, 71.62473392486572, 68.7513758795602, 73.33244827815464, 80.12017822265625, 80.58192076001848, 79.89169366019112, 73.60094056810651, 68.17480046408517, 63.662452697753906, 65.48607689993722, 68.14540263584682, 74.7409245627267, 69.13718850272042, 53.93062857219151, 15.80992933682033, 1.2067585715225764, 0.15834883520645754, 1.0980061271360941, 2.0390856691769192, 5.717590110642569, 7.225353981767382, 6.673049058232989, 1.0841376313141413, 0.23207227566412517, 3.8582499963896613, 43.307795252118794, 63.98740604945591, 32.45268017905099, 26.485874686922344, 43.00696952002389, 62.554958479745046, 59.503476415361675, 20.107600348336355, 1.268976324370929, 0.21591183782688209, 0.19195429980754852, 0.19565691612660885, 0.12241554765829019, 0.2468335878636156, 0.12307205743023328, 0.17543278634548187, 0.13268381809549673, 0.10794746436710868, 0.21546492752219948, 0.15387540310621262, 0.08292235327618462, 0.09867921884038619, 0.09811695758253336, 0.09146840684115887, 0.17314494268170424, 0.15124093661350863, 0.1995316089263984, 0.17454395975385392, 0.18370530887373857, 0.10448405199817248, 0.16011009498366288, 0.13178623840212822, 0.09011291779045548, 0.1263434783156429, 0.13716193208737032, 0.062067409844270775, 0.1286442277154752, 0.1767887571560485, 0.1365137275840555, 0.08440172925059285, 0.09148475953510829, 0.2901822046509811], [0.012919769855216146, 0.022366385274965848, 0.03250929806381464, 0.05580496588455779, 0.030804885950471674, 0.0054673514678142965, 0.11080648523888417, 0.04839662894872682, 0.06375606637448072, 0.04168626705982855, 0.09516944895897593, 0.17298393989247934, 0.07807808143219777, 0.058008108021957536, 0.015677794182140912, 0.04504555823015315, 0.038726307318678925, 0.05365152643727405, 0.09450960079474108, 0.0471444739960134, 0.06204889262361186, 0.023400051951674477, 0.04531077042754207, 0.04482276125677994, 0.07582875820142881, 0.03395171084308198, 0.07053467870822974, 0.07905222701707057, 0.06718466311161007, 0.018353315436148217, 0.06370892854673521, 0.010451587698688465, 0.023899226416168467, 0.02297169957975192, 0.0863709125135626, 0.02392370965597885, 0.032676947103547196, 0.0158282847675894, 0.021267882880887816, 0.031168200740856782, 0.18470274178045137, 0.031153581703880003, 3.9879181470189775, 35.439314705984934, 65.10976246425084, 61.40415613991873, 42.00682149614607, 26.60128252846854, 35.830995082855225, 56.90229320526123, 59.08660534449986, 11.204784904207502, 0.5867085488779205, 0.6452451135431017, 0.6834366470575333, 0.433708591652768, 0.228476420044899, 0.2635732096220766, 0.3372260960085051, 0.14218622605715478, 0.060776768385299614, 3.475813980613436, 43.35363251822335, 75.92482117244175, 72.2175681250436, 73.26639175415039, 74.74910954066685, 76.85350349971226, 79.70070157732282, 69.4076818738665, 65.24876812526158, 65.7304936817714, 60.54672758919852, 63.987767355782644, 65.9464020047869, 71.64308411734444, 67.76324476514543, 67.09550203595842, 66.87741892678397, 68.54068565368652, 63.588259833199636, 66.09691388266427, 68.77287360600063, 71.494781766619, 64.88222980499268, 70.0816432407924, 61.73020730699812, 66.02131053379604, 40.245748451777864, 39.006179400852744, 38.17642205102103, 42.41613292694092, 71.92113018035889, 58.56489290509905, 67.32649489811489, 63.92117582048689, 63.255010332380024, 56.886003153664724, 57.94341475622994, 59.77804143088204, 64.49177578517369, 65.77702576773507, 69.55007825578961, 69.02093124389648, 74.43297345297677, 69.68415764399937, 75.85979993002755, 72.42433956691197, 68.12964412144252, 66.22059181758335, 67.86577933175224, 65.29185390472412, 66.45862320491246, 60.7827023097447, 69.01731123243059, 73.66880362374442, 76.02722372327531, 57.601862158094136, 61.585573605128694, 67.02456787654332, 54.4678042275565, 27.489145926066808, 2.323644582714353, 0.09942957000540835, 0.1458180168909686, 0.3813083991408348, 0.7563685764159475, 0.8779548321451459, 2.5764402406556264, 1.143784767815045, 0.15262163324015482, 0.0991623697004148, 9.687703064509801, 51.82766594205584, 48.490717138562886, 16.072374956948416, 22.334709916796, 41.96762670789446, 45.39662872041975, 27.89917302131653, 3.859115481376648, 0.092325803690723, 0.06155375883515392, 0.008765349297651222, 0.0859191913955978, 0.033485764238451204, 0.024302389871861254, 0.01459868940790849, 0.07294501151357378, 0.02711167073409472, 0.029801057851208106, 0.04076495899685791, 0.06574401113071612, 0.046461559033819606, 0.041191177376146824, 0.04615481710061431, 0.02705310976931027, 0.048475559534771104, 0.023920527326741388, 0.09282456085618053, 0.056215187800782065, 0.037337732900466235, 0.019126484037509987, 0.06232002843171358, 0.02398590587212571, 0.04464854060539177, 0.011337533060993468, 0.037697481989328346, 0.07878585452479975, 0.03744656313210726, 0.003682223373159234, 0.023310283465044837, 0.0719885824780379, 0.022948787148509706, 0.008394372998736799, 0.03311753346185599, 0.033506459556519985, 0.05234889865719846, 0.02769395725668541, 0.06071040087512561, 0.07284502937857594, 0.025946117205811397, 0.07786014276955809, 0.10164562466421298, 0.025362858681806495, 0.0390771913475224, 0.03807167708873749, 0.04973058469061341, 0.0868212901321905, 0.046451116379882605, 0.03120275174400636, 0.06580459073718105, 0.06290316821209022, 0.03969932992809585, 0.06000254635832139, 0.03656695104603257, 0.07465791210000004, 0.021237418354888047, 0.041282457299530506, 0.02301617755022432, 0.028546969073691537, 0.06972706597298384, 0.05532465469358223, 0.02795316950817193, 0.04123238141515425, 0.045857863035053015, 0.03765238655198898, 0.007539638550952077, 0.06808365415781736, 0.04028889543509909, 0.0398365602429424, 0.04498700065804379, 0.06554234373782362, 0.011181676111716245, 0.020718320405908992, 0.023157774237915874, 0.13571735817406858, 0.1033889100487743, 9.941222855022975, 48.189297335488455, 72.8226797921317, 57.90943806512015, 32.41895709718977, 28.322194984980992, 56.11967590876988, 87.4000004359654, 62.09367452348982, 8.12322929927281, 0.10841998936874525, 0.2904473489948681, 0.9171403923204967, 0.14986399907086576, 0.3085167908242771, 0.2950318029948643, 0.6580043403165681, 0.44536224060824936, 0.02655278179528458, 9.303232312202454, 54.055668354034424, 77.85093130384172, 70.92252813066754, 73.3319341114589, 79.67210974012102, 80.16842651367188, 76.0757360458374, 68.6921911239624, 64.80557032993862, 70.16298580169678, 63.947259357997346, 68.10836178915841, 69.05825696672711, 73.91303280421666, 68.47681086403983, 70.40428284236363, 70.27282292502267, 69.46136365618024, 67.58047240121024, 68.68790408543178, 68.10226127079555, 69.41844463348389, 65.09839521135602, 69.86511652810233, 63.98550919124058, 66.14531503404889, 46.647040435246055, 41.129354340689524, 42.081604957580566, 46.21904877253941, 72.12754031590053, 61.50704506465367, 71.99828992571149, 64.89577184404645, 63.652085985456196, 56.96399668284825, 57.62543044771467, 63.12926878247942, 66.20636190686906, 67.04231357574463, 71.31776251111711, 65.50487872532436, 69.27818829672677, 71.99874155861991, 76.38019221169608, 71.87438270023891, 71.54598999023438, 66.40923540932792, 71.02768216814313, 71.39053099496024, 70.45408752986363, 64.96894332340786, 68.84400926317487, 70.82752541133335, 72.76555170331682, 61.17066887446812, 60.41118907928467, 69.32492882864815, 61.10364655085972, 36.983440671648296, 4.815497236592429, 0.20478695764073304, 0.7024830707481929, 1.815399706363678, 1.2359109329325813, 1.7095179536512919, 0.8195736791406358, 0.7153148736272539, 0.16975272899227484, 0.2712442379977022, 8.785990170070104, 48.66224384307861, 66.078827721732, 25.88096799169268, 11.747720616204397, 31.310927867889404, 54.033364636557444, 38.123476777757915, 7.018741045679365, 0.2523455720927034, 0.09174272497849804, 0.06892420976821866, 0.01683993298294289, 0.010733980402749563, 0.09033692255616188, 0.04781853407621384, 0.05293744636167373, 0.020790053431742957, 0.03616974003879087, 0.013437418283761611, 0.07079918522919927, 0.05730023993445294, 0.08515993785113096, 0.032212791831365654, 0.018520852517602698, 0.034042356336223226, 0.046110939633633406, 0.08928156990025725, 0.036011814405875545, 0.016574897204658816, 0.0862551001565797, 0.010763825765544814, 0.027325799422604696, 0.02844830329662987, 0.028188249661720226, 0.055898244093571386, 0.028711887009974037, 0.04702232412195631, 0.07431056323860373, 0.07593714059995753, 0.06948672886937857, 0.032755857333540916, 0.040891013839947324, 0.06781452002802066, 0.10351935162075929, 0.16381283343902656, 0.1114737226494721, 0.16768059161092552, 0.16658129702721322, 0.06595701005842004, 0.2250932173005172, 0.27867123803922106, 0.12320186117930071, 0.09810219266052757, 0.13442383972661837, 0.2588899609233652, 0.24037987845284597, 0.141832492181233, 0.12969421994473251, 0.10722012910991907, 0.18408446067145892, 0.20332442969083786, 0.163934304778065, 0.1434335634112358, 0.09690802531050784, 0.08775585676942553, 0.09256264633898224, 0.2061312033661774, 0.25692628057939665, 0.1616859654230731, 0.148771964811853, 0.1828619305576597, 0.1721520966717175, 0.13090214798493044, 0.13608481202806744, 0.07587462038333927, 0.2143348003072398, 0.226139952561685, 0.21059057622083596, 0.1740232248391424, 0.13478083057062967, 0.08564567392958061, 0.0509518764780036, 0.08379734453878232, 0.34578160835163935, 0.1354716063610145, 7.708891715322222, 51.42623029436384, 85.5270231791905, 75.69564179011753, 55.584615979875835, 39.58244909558977, 47.22763885770525, 71.77782358442033, 81.38813413892473, 20.859303372246877, 1.185852853315217, 0.8820379844733647, 4.2056955354554315, 2.478143206664494, 0.6540296993085316, 0.6047957954662186, 0.47773169939007076, 0.2566440642944404, 0.1684873697480985, 6.612366965838841, 50.54397235597883, 79.62944085257394, 72.03324631282261, 70.34919752393449, 76.64520345415387, 84.39895534515381, 84.00562477111816, 73.87166322980607, 71.48453317369733, 75.65919848850795, 70.06076390402657, 69.77603367396763, 70.41804722377232, 76.32749012538365, 69.47989450182233, 74.37104415893555, 77.53172411237443, 74.55216979980469, 68.41197722298759, 68.94841289520264, 69.56202220916748, 71.65874535696847, 65.21982887813023, 72.61158657073975, 64.93530014583042, 68.75632299695695, 46.90296343394688, 46.12153080531529, 50.10801458358765, 48.196328912462505, 72.37736279623849, 60.14289828709194, 71.87263175419399, 68.89862210409981, 65.76876435961042, 61.36564922332764, 66.42979512895856, 69.53649452754429, 73.2975891658238, 74.11068820953369, 77.10022013528007, 75.21290179661342, 80.65179879324776, 76.51905196053642, 81.4644114630563, 79.10569953918457, 76.42945493970598, 69.12960106985909, 78.28950159890312, 71.86935915265764, 67.10450690133231, 59.073772021702354, 64.68686035701207, 68.10194860185895, 74.27195589882987, 63.86473560333252, 65.26728507450649, 67.79622786385673, 56.03289985656738, 33.545673506600515, 2.8490508581910814, 0.17846994980105332, 0.4823611538325037, 1.8552476252828325, 2.1632875416960036, 5.19908252784184, 10.103049005780901, 4.302388404096876, 0.7877025093351091, 0.4456328675150871, 14.669297422681536, 62.096905435834614, 55.976518699101035, 27.357635634286062, 33.04326663698469, 53.3862441607884, 61.720153263636995, 46.499137605939595, 7.876320719718933, 0.23739503004721232, 0.23670297861099243, 0.0741509785875678, 0.10977648265127625, 0.10615695294524942, 0.21065631269344262, 0.1321464997849294, 0.13449393239404472, 0.1137781972065568, 0.06998138768332345, 0.10635469840573412, 0.15464674814471177, 0.1699897548449891, 0.25566127417343004, 0.13623535180730478, 0.09002056917441742, 0.11164783473525729, 0.0938840661463993, 0.24068961611815862, 0.15820528433791228, 0.1327794643917254, 0.13077633402177266, 0.20195156335830688, 0.09713506991309778, 0.14998760100986275, 0.19272417921040738, 0.1668104925858123, 0.24035393127373286, 0.1608851719647646, 0.12765143598828996, 0.1273603851773909, 0.21256450244358607, 0.22739677583532675, 0.15020930554185594, 0.1093559062906674], [0.08329011247094188, 0.09019875925566469, 0.09479448372232062, 0.02599641022139362, 0.013242319109849632, 0.049290958459356, 0.10283599221812827, 0.06217482193772282, 0.03920911891119821, 0.02753401467842715, 0.08764559482889515, 0.017614609628383602, 0.06624756553875548, 0.0703900150422539, 0.04359984437802008, 0.04074576663385544, 0.056488898649279556, 0.12078008827354227, 0.05113490451393383, 0.06917388351368052, 0.07720984159303562, 0.03989922973726477, 0.04828781907313636, 0.08296600343393427, 0.08127286857260124, 0.031134938954242637, 0.005530958188631172, 0.05555774165051324, 0.06351539678871632, 0.05430197010615042, 0.05644604916285191, 0.07956259391669716, 0.017265978335802044, 0.04300887430352824, 0.03901347690927131, 0.04288748438869204, 0.05102281731420329, 0.038020485014255555, 0.03934710239991546, 0.10557500060115542, 0.005268096690997481, 0.0766290088317224, 0.06850163172930479, 1.4457193889788218, 16.39709206989833, 50.795135838644846, 59.30149923052107, 50.94286496298653, 27.04837826320103, 18.637302466801234, 33.867388997759136, 66.8361188343593, 42.74629742758614, 5.252274027892521, 0.6777980753353664, 0.37903240269848276, 0.3531431161931583, 1.7639200687408447, 0.6305038588387626, 0.1358228703694684, 0.2751729286142758, 0.13984190113842487, 0.15277263442320482, 21.010741097586497, 70.95010553087506, 94.98864228384835, 71.26693643842424, 68.94382708413261, 64.22724396841866, 75.49504034859794, 78.44235501970563, 74.31086581093925, 73.43462153843471, 69.4699238368443, 66.89758259909493, 68.25022315979004, 70.80610411507743, 64.59799289703369, 67.58884498051235, 68.84238338470459, 71.63720594133649, 67.87180341993059, 70.4591805594308, 72.44866521017892, 67.56125368390764, 66.53142642974854, 68.43922805786133, 72.14104066576276, 49.095908709934776, 63.554859842572895, 46.40667792728969, 47.86923204149519, 60.181335721697124, 70.8327921458653, 66.36246708461216, 69.02820600782121, 69.61186163766044, 70.04110050201416, 67.74285875047956, 72.92923736572266, 70.45198917388916, 70.11101327623639, 67.69375583103725, 68.78808321271623, 61.475958824157715, 63.34476021357945, 66.24329158238002, 68.14478424617222, 72.04295294625419, 69.8637477329799, 70.5683992930821, 82.31172343662807, 79.19378185272217, 73.99726581573486, 63.8795839037214, 60.37021555219378, 63.414930071149556, 78.1676162992205, 68.17872619628906, 39.37594515936715, 6.264368176460266, 0.284839148500136, 0.30703288902129444, 0.22905206201331957, 1.523712158203125, 1.4316395159278597, 2.2069621809891293, 0.1776782079998936, 0.22391665114888124, 0.1512230775718178, 3.215366401842662, 31.32839216504778, 60.83119378771101, 43.73993498938424, 22.93596707071577, 35.18423938751221, 49.92296321051461, 44.671316691807334, 18.726145608084543, 0.41440437893782345, 0.23554501788956778, 0.0250165547643389, 0.044474601546036344, 0.08951580018869468, 0.053791708379451714, 0.0865876433838691, 0.010765642543057246, 0.02751973830163479, 0.05987093770610435, 0.03662463670064296, 0.024884861295244524, 0.008779896240282272, 0.047544911437268765, 0.06305652391165495, 0.06632882689258882, 0.024438493818576847, 0.11209049741072313, 0.07070295539285455, 0.13267840338604792, 0.051444995017456155, 0.06553563302648918, 0.06480525793241602, 0.0477928956305342, 0.05975638063890593, 0.08950571037296738, 0.022948822771598185, 0.07021311417754207, 0.0289343548938632, 0.0345503755046853, 0.03160167944484523, 0.1427345909178257, 0.15718178211578301, 0.11187580214547259, 0.04122151806950569, 0.020720622335959758, 0.06072280449526651, 0.02722130502973284, 0.08269421623221465, 0.03824802155473402, 0.0549425207344549, 0.03351363506434219, 0.042560257483273745, 0.08790642369006361, 0.05278180739177125, 0.0950307021183627, 0.019022347571860467, 0.08644254545548133, 0.04870226147717663, 0.044929593202791045, 0.011867506229983909, 0.02425168125358011, 0.08128246984311513, 0.03121129789256624, 0.1260278916784695, 0.04864355462736317, 0.026526381694046513, 0.09208048614008085, 0.06121592303471906, 0.0013567722240363114, 0.03238462403948818, 0.05223571562341281, 0.008360470844698804, 0.013346994162670203, 0.07633046020886727, 0.052179661845522265, 0.03995154478720256, 0.031105246261826584, 0.04698107597817268, 0.011469729494170418, 0.06453495672238724, 0.03875396440603903, 0.043598904607019255, 0.0342944388810013, 0.035986508442355056, 0.04934560427708285, 0.06936316764248268, 0.048741433303803205, 0.03454896075917142, 0.0746457323964153, 3.658565717084067, 29.197261537824357, 62.459969656808035, 69.29848398481096, 41.25382784434727, 19.016246795654297, 26.12583293233599, 63.70802593231201, 91.00127955845424, 41.55718272072928, 3.075138509273529, 0.5773243552872113, 0.49777567812374657, 0.4082253947854042, 0.31101434252091814, 0.7634448281356266, 0.627989262342453, 0.789316499871867, 0.41537851095199585, 0.5230506733059883, 31.86431019646781, 82.21209321703229, 90.76001725878034, 65.00559507097516, 69.69139071873256, 70.43425042288644, 79.32143415723527, 79.1026840209961, 74.5721389225551, 71.86976909637451, 68.43772724696568, 69.35798140934536, 72.52260099138532, 68.11610208238874, 67.72589819771903, 66.81063284192766, 68.15922260284424, 67.6266153880528, 69.50376851218087, 74.27809810638428, 79.18498543330601, 68.13708564213344, 69.55067580086845, 62.76895604814802, 73.27174186706543, 48.75457150595528, 58.74867275782994, 54.41082899911063, 48.43417617252895, 67.55420821053642, 71.1748241697039, 67.41224956512451, 69.14894485473633, 73.28385952540806, 71.55851759229387, 69.23155893598283, 72.04974133627755, 71.50441196986607, 71.82400131225586, 72.46725164140973, 73.62680871146065, 72.44794259752545, 69.82285063607353, 74.18875816890171, 70.18436540876115, 72.64975997379848, 71.11506966182164, 69.1254460471017, 74.12670380728585, 77.7299770627703, 70.12525708334786, 70.33892113821847, 66.93267100197929, 65.57464558737618, 74.31921059744698, 72.68903119223458, 50.95986025674002, 9.930702413831439, 1.6030731797218323, 0.7676218897104263, 1.9931995485510146, 2.121836108820779, 2.1530817236219133, 1.150109799844878, 1.079650832074029, 0.2719664978129523, 0.36250741513712065, 1.7920109842504774, 27.824321814945765, 65.26112897055489, 58.18019894191197, 25.831913709640503, 23.037563630512782, 47.55783462524414, 54.25926446914673, 24.68220223699297, 1.3712835546050752, 0.28872764270220486, 0.025813431379252245, 0.020292658425335373, 0.04974868121956076, 0.05942944211087056, 0.0996651980759842, 0.02027032783787165, 0.022728015602167164, 0.069869958662561, 0.0186415147036314, 0.037941863161644766, 0.016325114893593957, 0.07676458012844835, 0.021599057163777094, 0.031005996944648877, 0.023222810123115778, 0.0664671462561403, 0.043310357590339014, 0.06500069637383733, 0.01371201716496476, 0.06488925378237452, 0.045010016565876346, 0.05369379577626075, 0.046921836478369575, 0.02623570238107017, 0.02411330591088959, 0.06041538741971765, 0.03813997163836445, 0.05559051149923887, 0.14123181227062429, 0.013551911738302027, 0.03861638464565788, 0.09150338532137019, 0.02482867520302534, 0.040545374886798005, 0.031585547274776866, 0.165267001837492, 0.1765769999474287, 0.1442574949136802, 0.12489780517561094, 0.07321120758673974, 0.1146609644804682, 0.2718430044395583, 0.1297313358102526, 0.22361999563872814, 0.14025568536349706, 0.21217211921300205, 0.1617420395570142, 0.13599483828459466, 0.13799545807497843, 0.09202938566782645, 0.1384798370833908, 0.16047693815614494, 0.3091394416987896, 0.18868179326610907, 0.1481927808906351, 0.15040914767554828, 0.12133610700922352, 0.10626373400113412, 0.15402139670082501, 0.16188416550202028, 0.09854556101241282, 0.23851922686610902, 0.2981293967791966, 0.19645091066403048, 0.1198248059621879, 0.2833298152046544, 0.17425984357084545, 0.0981888755091599, 0.17015800438821316, 0.16702908942742006, 0.12179901716964585, 0.18054549342819623, 0.13090977471854004, 0.24135770169751986, 0.19195488334766456, 0.1884122791567019, 0.16784301932368959, 0.11594334138291222, 2.5692469009331296, 26.86294300215585, 74.24697017669678, 80.4280320576259, 64.99415833609444, 42.48698718207223, 31.034080369131907, 45.26055867331368, 81.2887054170881, 61.31536511012486, 10.37509616783687, 0.7173340852771486, 2.596368977001735, 4.413572175162179, 5.772341047014509, 2.649394154548645, 0.2579236184912068, 0.6544891489403588, 0.21700328854577883, 0.2256383794759001, 25.007829563958303, 81.35225364140102, 94.5847087587629, 67.11979293823242, 72.123030935015, 65.02555029732841, 81.79497895921979, 80.29974746704102, 76.58718599591936, 77.1317024230957, 75.58467905861991, 75.82396112169538, 78.23160920824323, 74.67668846675328, 66.8613338470459, 66.23881694248745, 73.16237722124372, 78.22832271030971, 76.27240480695451, 85.24347414289201, 86.57237270900181, 74.47819927760533, 71.48051016671317, 64.93953159877232, 74.2716223852975, 60.42801761627197, 72.88057913099016, 61.9104574748448, 58.61268261500767, 70.70084585462297, 81.9776679447719, 75.85620076315743, 75.77551133292062, 80.30113015856061, 76.86508614676339, 71.15161023821149, 74.58365903581891, 72.83920955657959, 70.49551963806152, 70.38662052154541, 71.23936598641532, 66.71467821938651, 68.83610221317836, 72.14780821119035, 68.33313601357597, 76.88814721788678, 77.62242589678083, 67.0740737915039, 83.82214369092668, 93.39495481763566, 91.14289774213518, 80.34206199645996, 72.26488535744804, 70.54377487727574, 80.7023538861956, 74.29447501046317, 47.06401572908674, 8.549025331224714, 0.6725786754063198, 0.308288613068206, 1.0937044322490692, 2.952898851462773, 4.6323301281247815, 9.40260544845036, 7.938475830214364, 1.7326328733137675, 0.44903363074575153, 5.679399337087359, 40.220238140651155, 72.15581948416573, 54.453935623168945, 34.48792913981846, 44.886099406651084, 60.60483537401472, 61.645696367536274, 29.482502460479736, 1.3700474266495024, 0.6737600862979889, 0.12312191618340355, 0.12815504467913083, 0.2058289431567703, 0.19916575641504355, 0.18446448099400314, 0.16400377319327422, 0.11159462401909487, 0.11354160561625447, 0.1614553313702345, 0.08904937521687575, 0.06803431787661143, 0.12982600501605443, 0.21431574704391615, 0.08490428621215479, 0.10602028920714344, 0.1492212364184005, 0.21142028884163924, 0.12067353113421372, 0.11727344643856798, 0.3193402928965432, 0.2211950064769813, 0.1267081637467657, 0.12234056953872953, 0.21916473470628262, 0.13921273632773332, 0.15955822888229573, 0.15489395202270576, 0.11494550135518823, 0.22011404590947287, 0.20383372450513498, 0.22633653772728785, 0.17148633168212005, 0.1263972997133221, 0.09888481495103665, 0.16921246583972657], [0.13708550190286978, 0.04847061301448515, 0.06796297670475074, 0.1196302699723414, 0.003933197361350591, 0.15560802870563098, 0.41430281581623213, 0.13583369978836604, 0.15346714215619223, 0.05744490360042878, 0.06088646035641432, 0.04369535157456994, 0.09609342366456985, 0.31906822749546593, 0.09819899246628795, 0.08545467989253146, 0.0971775326345648, 0.03212024983284729, 0.27560149133205414, 0.01966237912087568, 0.13716297703129904, 0.03097353582935674, 0.09788221160748176, 0.04021438550470131, 0.20130410524351255, 0.25149330496788025, 0.0908766428806952, 0.4993607902101108, 0.41871836887938635, 0.061534895561635494, 0.14598230378968374, 0.11192345565983228, 0.03369359612198813, 0.06842347128050667, 0.11195512967450277, 0.06761828770062753, 0.025928271734820943, 0.047021696477064064, 0.044074014827076874, 0.07513557361172778, 0.026665715467450873, 0.02537623091068651, 0.024029846103595834, 0.08733152132481337, 0.08347783596920115, 3.1184205753462653, 29.933350222451345, 48.70138651984078, 60.99169717516218, 47.39005299976894, 23.98405245372227, 21.894041265760148, 47.01226554598127, 57.37734154292515, 34.158515044621055, 2.94470323409353, 0.46664139734847204, 0.4890183966074671, 1.4182074538299014, 0.6644731674875531, 0.6237484727587018, 0.14182121492922306, 0.41415584513119286, 0.2600691190787724, 2.7305957973003387, 27.611574922289165, 73.99819687434605, 93.96381773267473, 85.51928983415876, 73.66700404030937, 67.08041749681745, 68.70540659768241, 66.6748719896589, 73.53649602617536, 74.50199685777936, 75.73569120679582, 75.51284858158657, 67.75813089098249, 73.48478058406285, 75.86639377049038, 65.46791430882045, 72.16203117370605, 82.38723645891461, 76.05040291377476, 66.71195452553886, 70.52696023668561, 65.27852725982666, 27.793049710137502, 9.72024495261056, 27.96836839403425, 26.5940876688276, 48.596180370875764, 70.56714166913713, 56.03287901197161, 62.80423205239432, 76.56390953063965, 68.07963793618339, 72.09899711608887, 69.32289995465959, 67.31507900782994, 68.78500516074044, 68.90424319675991, 72.88486616952079, 74.78148814610073, 78.86112989698137, 74.60656029837472, 68.81779370989118, 74.0368219103132, 69.5390236718314, 77.17799827030727, 69.93867015838623, 62.57242625100272, 78.3446147101266, 91.94141946520124, 82.62187017713273, 85.77982643672398, 77.75751972198486, 38.8780129296439, 5.415229260921478, 0.16684885695576668, 0.23872395445193562, 2.693736255168915, 4.16481841461999, 2.3699067745889937, 0.9117345852511269, 1.9297433878694261, 0.23906829740319932, 0.5260835077081407, 0.7289363284196172, 19.304626567023142, 54.985417229788645, 52.09412240982056, 34.559766565050396, 27.249679735728673, 42.88349308286394, 49.71584783281599, 33.6200088092259, 6.757494858333042, 0.03056178381666541, 0.07735747045704297, 0.052390625168170245, 0.12372973428240844, 0.05182449286803603, 0.12210739776492119, 0.03233450744301081, 0.1387357669217246, 0.044532660394907, 0.05656723551718252, 0.05336916765996388, 0.03262377031413572, 0.03592834442055651, 0.05152607655950955, 0.0858327935316733, 0.07202843283968312, 0.08042144283120121, 0.050650746029402526, 0.040176462182509046, 0.03867815847375563, 0.08110699390194245, 0.04265264681141291, 0.07155331583427531, 0.020180528817166175, 0.03789041663653084, 0.05693590734153986, 0.09122534202677862, 0.03599854904626097, 0.02303385847647275, 0.03562052022399647, 0.039517485935773165, 0.1122464993968606, 0.08058389768536602, 0.010902988208856965, 0.07821630580084664, 0.018941630742379596, 0.06369198552731957, 0.017000881489366293, 0.08684642985463142, 0.03503864251875451, 0.04965333687141538, 0.04741116200706788, 0.03352741950324603, 0.0882176880591682, 0.21722031118614332, 0.10139367782643863, 0.15603387728333473, 0.032855635908033164, 0.05837512082819428, 0.013634432622763728, 0.1271030575569187, 0.07777933603418724, 0.03576271741517952, 0.10648746056748287, 0.05429511350978698, 0.005695214553270489, 0.16380132548511028, 0.04320730169170669, 0.017894500234563435, 0.0438456301178251, 0.10173261963895389, 0.050397336948662996, 0.1532935050449201, 0.1534214224666357, 0.0599265368655324, 0.19477026084704058, 0.22177463823131152, 0.11980575269886426, 0.03545916798923697, 0.05083057816539492, 0.03648879738258464, 0.06830075822238411, 0.07536728653524603, 0.04099994585184114, 0.01788067677989602, 0.0854697705113462, 0.0508154773685549, 0.00905883774560477, 0.020862069745947207, 0.07301976571657828, 0.19381763839295932, 0.05486382424299206, 0.04398897403318967, 7.518001249858311, 41.43966783796038, 62.4194894518171, 56.27027811322893, 29.445680482046946, 16.044481413705007, 37.58182648250035, 81.49878420148576, 81.58381625584194, 30.862362589154923, 1.0193024703434534, 0.3613941291613238, 0.46082331240177155, 1.0255988410540988, 0.8984021320939064, 0.7128344210130828, 1.1936456922973906, 0.15541395411959716, 0.28171370763863834, 6.880293846130371, 42.409372329711914, 87.37985066005162, 95.80975260053361, 80.14678287506104, 71.2865650994437, 70.64056328364781, 74.78107125418526, 71.97074031829834, 79.09749371664864, 78.15228162493024, 76.26624870300293, 75.40704836164201, 72.9842393057687, 80.83879566192627, 77.23686340876988, 69.48571709224156, 71.99047320229667, 74.15460082462856, 67.6948744910104, 64.00719451904297, 68.55088560921806, 70.8453961781093, 46.27167790276663, 21.149689435958862, 52.0812543460301, 42.04838214601789, 55.8029214314052, 63.986593110220774, 61.247849464416504, 75.41165501730782, 74.033292225429, 69.13925906590053, 71.66700676509312, 74.84846878051758, 76.50167451586042, 75.75603553227016, 71.75489452907017, 73.14985656738281, 71.69140883854458, 70.80385984693254, 74.82659585135323, 67.75378826686314, 73.69151728493827, 72.7163793018886, 71.5890201841082, 75.27868734087262, 69.55412905556815, 71.46060357775006, 89.80462605612618, 88.08463423592704, 80.41221795763288, 80.48436110360282, 49.86185032980782, 10.850002935954503, 1.0207305422851016, 0.5490724369883537, 4.344203097479684, 4.695623006139483, 3.2163198249680653, 2.643555713551385, 1.386221421616418, 1.0041818874222892, 0.1590739312980856, 0.4307324013539723, 16.27336549758911, 59.47536400386265, 63.10067694527762, 44.926259994506836, 28.801071780068533, 40.65927049091884, 57.80947780609131, 39.28957210268293, 8.165022713797432, 0.11989352798887662, 0.1446236188390425, 0.04934414542679276, 0.07567677992795195, 0.003517145981147353, 0.03515849215909839, 0.05231128746111478, 0.11391916285668101, 0.04756499946649585, 0.04741989814543298, 0.036349697703761716, 0.058437328918703964, 0.04275084439931171, 0.10920227239174501, 0.07529927018497672, 0.051161238458007574, 0.041620876640081406, 0.0922528068934168, 0.01313877381783511, 0.02472324782450284, 0.07175940049013921, 0.019188089928190624, 0.0745701232392873, 0.038299325587494035, 0.03211529652721115, 0.09507263558251516, 0.0677346700270261, 0.0341035194828042, 0.0400278833694756, 0.03998253008882914, 0.05675607181287237, 0.07799527980387211, 0.07800515927374363, 0.02437841802436326, 0.03274225609909211, 0.028778461473328725, 0.07031227528516736, 0.011958721692540815, 0.17046810846243585, 0.14534270311040537, 0.1995621837143387, 0.12488238885998726, 0.13329758016126497, 0.14039859840912478, 0.30806656926870346, 0.1854794608162982, 0.18271149934402534, 0.14163035659917764, 0.18700331476117882, 0.20481123562370027, 0.17974623345902987, 0.314827845032726, 0.23144552643809999, 0.23162463254162244, 0.3162766530045441, 0.09275436640850135, 0.27392067866665976, 0.12456387095153332, 0.13717295149607317, 0.14003167381244047, 0.2979304503117289, 0.12100340771887984, 0.25487121513911654, 0.30361567810177803, 0.2519594042428902, 0.47411081939935684, 0.43917619969163624, 0.19951024864401135, 0.16538560975875172, 0.1726500599512032, 0.21429866153214658, 0.2578757953430925, 0.14286724451397145, 0.24408929369279317, 0.16168990092618124, 0.22251266720039503, 0.15386242951665605, 0.1414454829479967, 0.09702714213303157, 0.14587965501206263, 0.2296406232884952, 0.20628266595304012, 0.17364666504519327, 6.8927463207926065, 48.93714584623064, 73.52398232051304, 75.52368082318986, 60.398202896118164, 37.09463964189802, 33.988006251198904, 58.46396337236677, 74.51482323237828, 49.27316073008946, 6.155457769121442, 0.8087558224797249, 1.8953934482165744, 8.952374339103699, 5.809399698461805, 1.14359684075628, 0.2910580576530525, 0.6922019081456321, 0.3474366638277258, 4.285499504634312, 32.76246908732823, 82.38689599718366, 98.43690817696708, 94.27782767159599, 76.86423151833671, 74.40960666111538, 81.77657318115234, 76.95000008174351, 83.40637738364083, 81.7747666495187, 76.08194773537772, 75.68801961626325, 85.59173175266811, 90.52821840558732, 79.66434165409633, 56.72304010391235, 66.88983535766602, 70.84731388092041, 67.45136097499302, 57.86892659323556, 65.32124478476388, 65.96405737740653, 38.70252227783203, 13.550412501607623, 43.69507047108242, 43.85288143157959, 65.40750667027065, 76.29972512381417, 54.20706960133144, 76.49018219539097, 78.8879360471453, 70.36284378596714, 77.43512330736432, 86.51409121922084, 84.9558812550136, 87.98954119001115, 81.92513956342424, 87.40857451302665, 82.26357936859131, 84.34611429486955, 78.21056311471122, 72.21369797842843, 81.21488080705915, 75.40054484776088, 67.2852920804705, 83.05172048296247, 55.77206795556204, 56.20255749566214, 96.83607796260289, 107.03021090371269, 101.55642700195312, 78.74792289733887, 40.14009066990444, 5.759018310478755, 0.4777081406542233, 0.4684821271470615, 4.99926449571337, 11.463503684316363, 6.270422663007464, 10.695869309561592, 12.086999416351318, 3.6615165301731656, 0.5773852063076836, 1.6898291472877776, 26.108921016965592, 64.99797984531948, 62.431843348911826, 45.734272956848145, 38.96915939876011, 58.107986313956125, 67.32100582122803, 46.109600748334614, 9.89672485419682, 0.2002724606011595, 0.2217223503227745, 0.1284130508346217, 0.26935791064585957, 0.10940081173820154, 0.2355662967477526, 0.10775978836630072, 0.28160174936056137, 0.1814251597970724, 0.14401224521653994, 0.1498739735356399, 0.12036402417080742, 0.19568295830062457, 0.16480576087321552, 0.1099965994113258, 0.19061561806925706, 0.19826512331409113, 0.13733391357319696, 0.09357006728116955, 0.07277288753539324, 0.2299525322658675, 0.17106232871966703, 0.25909509563020294, 0.058869698217936924, 0.08864276310695068, 0.2179592086800507, 0.17189533902066095, 0.13601006461041315, 0.2244618676070656, 0.10039030095296246, 0.15032784560961382, 0.1431983153202704, 0.13765681481787137, 0.14477611279913358, 0.1641006272818361, 0.18970425054430962, 0.21140031277069024, 0.05403750090460692], [0.033330847908343585, 0.036383929795452526, 0.08434817248157092, 0.09907312877476215, 0.45243292834077564, 0.08234177157282829, 0.028845588942723613, 0.029629931319504976, 0.03631980823619025, 0.029107734161828245, 0.08091898541897535, 0.14498179033398628, 0.0625803212502173, 0.16603337999965462, 0.08912244665303401, 0.10142564361116715, 0.03920642851984926, 0.16327372379601002, 0.012879759189672768, 0.3177940472960472, 0.02129628466043089, 0.47916536246027264, 0.029467669847820486, 0.10965568984725646, 0.08638122624584607, 0.08912080459828887, 0.040792711079120636, 0.0765970769737448, 0.09639930046562638, 0.03815232776105404, 0.03667886182665825, 0.07003491731094462, 0.06732214109173842, 0.04725896320970995, 0.049747453071177006, 0.05752816663256713, 0.05014177691191435, 0.01503069738724402, 0.044749377694513114, 0.02847473562828132, 0.046123791086886606, 0.07813167212797062, 0.034902491074587615, 0.024670166029993976, 0.1353318010057722, 0.13679265975952148, 0.12488970346748829, 7.500113981110709, 42.095178263528005, 63.9818822315761, 62.45835072653634, 40.832200731549946, 23.715026889528545, 22.526772022247314, 50.08581508908953, 67.52598462785993, 22.02148859841483, 1.191450061542647, 1.6425645692007882, 1.2426748956952776, 3.8228015899658203, 4.145172817366464, 0.2853583906378065, 0.15824424581868307, 0.08255920811955418, 0.28890650453312056, 2.0288887534822737, 19.198367765971593, 47.75857155663626, 79.8010196685791, 88.4705719266619, 92.4676204408918, 83.88380895342145, 80.53804983411516, 72.06416579655239, 71.71900013514927, 72.64666107722691, 82.55645288739885, 71.22413553510393, 67.3435388292585, 57.11758313860212, 69.34002726418632, 54.52894837515694, 60.590209415980745, 48.28095102310181, 28.50837196622576, 12.286579472678048, 3.380331401314054, 0.18095855840614863, 1.4620496098484312, 2.218865313700267, 5.838189993585859, 50.28235183443342, 63.868814195905415, 36.564936774117605, 53.740435532161165, 78.99135998317173, 67.97840963091168, 79.27673639569963, 90.92828178405762, 84.06843648638043, 80.19352340698242, 73.15927832467216, 67.74533230917794, 61.14239665440151, 60.80814661298479, 69.05201748439244, 74.03210408346993, 81.94721399034772, 66.5898607798985, 68.8063222340175, 50.74676595415388, 65.35570784977504, 71.54351643153599, 61.99672630855015, 40.01113557815552, 6.592642332826342, 0.13146356785936014, 0.4867263595972742, 1.3676518180540629, 0.7891141878707069, 2.2460316845348904, 2.881856777838298, 6.120782784053257, 0.04907415973554764, 1.2745590933731623, 0.10072404518723488, 10.164619599069868, 46.57912526811872, 55.154251507350374, 36.62691123144967, 26.529512848172867, 35.6132698059082, 48.53750283377511, 41.73540054048811, 16.135348217827932, 0.3270698109907763, 0.32976801906313213, 0.044701188137488704, 0.05947482931826796, 0.05247970324541841, 0.035716027420546324, 0.10941803295697484, 0.04489511005314333, 0.0515358881758792, 0.084444524454219, 0.0333813953745578, 0.013675384755645479, 0.03333190981564777, 0.030719780695757697, 0.02447527550560023, 0.08562259695359639, 0.07929244198437248, 0.09022725772644792, 0.09626580548605748, 0.10288061946630478, 0.06752101970570427, 0.09734815026500396, 0.10892190850738968, 0.024027937723855888, 0.08194232479270015, 0.09363074188253709, 0.07442130015364715, 0.05915851664862462, 0.03684949642047286, 0.15606177864330156, 0.054386423967246494, 0.031065670706863915, 0.09197607317141124, 0.082417625002563, 0.04323207839791264, 0.12623982530619415, 0.006014482242920036, 0.07911117135414056, 0.031180675607174635, 0.19498944122876438, 0.016334427786724906, 0.0900590828220759, 0.11895667468862874, 0.06110963730939797, 0.18813426978886127, 0.08224772661924362, 0.13702937348612718, 0.10825164483061858, 0.047747196297028234, 0.07631817872502974, 0.05189051432535052, 0.0656681644863316, 0.06024157388934067, 0.15441121506903852, 0.17474407330155373, 0.08606908656656742, 0.03548073522480471, 0.09759051618831498, 0.032936924403267245, 0.21686551879559243, 0.04967633581587246, 0.2592065382216658, 0.014951568329706788, 0.023765074953969036, 0.04945590014436415, 0.11914654235754694, 0.01711102807894349, 0.13397523308438913, 0.08040612829583031, 0.045279744413814375, 0.21710584232849733, 0.03262179916990655, 0.04191850245531116, 0.07180782753442015, 0.03065291785502008, 0.08081261826945202, 0.05273242022043892, 0.08499599700527531, 0.05654412122177226, 0.08083978002624852, 0.04585454160613673, 0.07978613727859088, 0.03251424119142549, 0.12252996223313467, 0.14396208790796144, 0.25353135274989264, 0.505775226014001, 13.575976661273412, 56.89083562578474, 71.494323185512, 51.65835918698992, 21.789316279547556, 19.20353201457432, 38.23507874352591, 82.9829889025007, 73.85057544708252, 18.543093579156057, 0.7239923051425389, 0.8433420551674706, 1.0852529257535934, 1.556604061807905, 2.064641360725675, 0.7065598719886371, 0.5183294809290341, 0.1729022714176348, 0.22926873181547436, 4.9822079709597995, 29.944581985473633, 62.22168813432966, 88.77065072740827, 88.44716344560895, 90.03659861428397, 78.86044202532086, 80.77162047794887, 72.74194172450474, 71.50802503313336, 73.19740309034074, 76.83588286808559, 78.47336483001709, 76.72259943825858, 62.56090613773891, 80.85648577553886, 76.17048863002232, 77.39987509591239, 58.02713360105242, 43.0131846836635, 27.220347915376934, 7.145758458546229, 0.1057572483218142, 5.2627249870981485, 6.5113436324255805, 20.571500301361084, 73.7346100125994, 65.47099930899483, 47.88702637808663, 73.73900127410889, 80.19061211177281, 77.17639323643276, 76.86759444645473, 80.91712270464215, 81.50565596989223, 80.77216243743896, 76.33203424726213, 76.3186033793858, 72.80250222342355, 65.967684337071, 72.95597403390067, 66.57739571162632, 80.19859559195382, 71.60960074833461, 69.22097682952881, 46.173374789101736, 62.468467303684776, 93.98339775630406, 79.30753081185478, 61.39082949502127, 14.529308591570173, 1.5012171481336867, 1.4618930582489287, 2.647138161318643, 3.299200543335506, 4.019781282969883, 2.647685331957681, 3.013649123055594, 1.84016894868442, 0.23763137736490794, 0.16682698098676546, 7.016205387456076, 45.49106168746948, 67.24949496132987, 49.09892075402396, 29.982665061950684, 34.7187865121024, 52.34745373044695, 53.639714445386616, 21.345210007258824, 0.9049952668803078, 0.15839606124375546, 0.10219726684902396, 0.09718821277575833, 0.02688587293960154, 0.03916988940909505, 0.15708165748843125, 0.08663376340908663, 0.0282352772275252, 0.07928352603422743, 0.013226893464369434, 0.015606468277318137, 0.05975641456565686, 0.027801900303789547, 0.01175784648928259, 0.06011696771851607, 0.022364403952711394, 0.0843912051724536, 0.050323234139276404, 0.10984933695622853, 0.08635923492589168, 0.04392628079014165, 0.07235932722687721, 0.007789903470048947, 0.09577131630586726, 0.004543453521494354, 0.08541622731302466, 0.13545595934348448, 0.09598072578332253, 0.0878156628459692, 0.03633657144382596, 0.016163628648168275, 0.053055379140589914, 0.07497638929635286, 0.06681193025516612, 0.10274964863700525, 0.08566429971584252, 0.0645681167287486, 0.03819876330505524, 0.032515906994896274, 0.09286143244909388, 0.18094023796064512, 0.35109966727239744, 0.16291004259671482, 0.4720900335482189, 0.1231665230755295, 0.17811887578240462, 0.2439314393060548, 0.15010924876800605, 0.11495414589132581, 0.24939459615520068, 0.370951702019998, 0.13214343280664512, 0.23906126778040612, 0.1854469861303057, 0.2081767421747957, 0.17635385692119598, 0.2612256684473583, 0.12088731037718908, 0.4435189595179898, 0.09762588143348694, 0.6564314961433411, 0.1117571195853608, 0.15278928567256245, 0.11786610606525626, 0.15068144377853188, 0.16594221203454904, 0.12928967736661434, 0.20350000741226332, 0.10943952216101543, 0.18139229156076908, 0.08263628291232245, 0.22030356074018137, 0.14724570885300636, 0.2580456462289606, 0.11546550345207963, 0.12011836735265595, 0.19668307820601122, 0.12241835679326739, 0.16279532946646214, 0.24300230773431913, 0.11514816619455814, 0.14603977570576326, 0.279807485640049, 0.22295591341597693, 0.3885386511683464, 0.3130302429199219, 15.675373997007098, 65.8420331137521, 83.12501008169991, 76.4019261768886, 58.989274978637695, 36.31930753162929, 35.708498341696604, 65.43558434077671, 86.73607921600342, 30.983570439474924, 2.4481528273650577, 2.7716533541679382, 6.664875371115548, 12.982371211051941, 10.96102385861533, 2.924510031938553, 0.37691469490528107, 0.1908717378973961, 0.22334217626069272, 2.885404918875013, 19.712699481419154, 49.87429107938494, 80.6543835231236, 88.0022633416312, 96.4805247443063, 86.63213416508266, 82.62218979426792, 76.09309264591762, 70.11641897474016, 68.94804464067731, 75.6883739743914, 89.11382920401437, 91.34008761814663, 95.24027129581997, 103.21839441571916, 81.02370807102749, 78.74239907945905, 61.35742255619594, 35.754787240709575, 21.178137098039898, 6.148679801395961, 0.1651721562125853, 3.4596856917653764, 3.953874145235334, 15.919667448316302, 78.83387211390904, 88.94461972372872, 51.69300290516445, 76.12563800811768, 87.488082749503, 76.69033200400216, 67.87499959128243, 81.96753747122628, 79.69244711739677, 81.98301110948834, 68.15094729832241, 71.28177779061454, 61.06413214547293, 62.44234207698277, 74.10605376107353, 59.50264957972935, 92.19883632659912, 72.04148687635148, 65.48203999655587, 66.27884551456997, 55.46570798328945, 84.56291893550328, 63.78178106035505, 43.86574602127075, 6.833988010883331, 0.7665427476167679, 0.8575455844402313, 3.2178447374275754, 3.639370015689305, 8.613558462687902, 15.636255638939993, 14.205838680267334, 6.179857236998422, 2.4283018239906857, 0.349542890808412, 15.40538958140782, 60.326163973127095, 67.2177347455706, 51.4467830657959, 38.81605931690761, 45.05252265930176, 63.31978143964495, 58.209600244249614, 29.590383665902273, 1.8433297276496887, 0.41707031588469234, 0.22042941541544028, 0.24944535057459558, 0.16020681336522102, 0.2055112530610391, 0.18128376666988644, 0.21948686242103577, 0.11068544816225767, 0.1495075781962701, 0.1390168568385499, 0.14687954421554292, 0.126833706295916, 0.1268832664936781, 0.08860135211476258, 0.18243316427937575, 0.08259505512458937, 0.1580701201621975, 0.17399388498493604, 0.1919304018041917, 0.14511704950460366, 0.27350014980350223, 0.3013941544507231, 0.09604175322289978, 0.2282512549843107, 0.15317932117198194, 0.20394001023045608, 0.3246909486395972, 0.15547738357314042, 0.2707001343369484, 0.18333495088985988, 0.16265993458884104, 0.1849216100360666, 0.23162740096449852, 0.17047011692609104, 0.17402078211307526, 0.13713626989296504, 0.23328489916665213, 0.1286567941840206, 0.3589666837028095], [0.06953825003334455, 0.12156846454100949, 0.02894842092479978, 0.04565098788589239, 0.022718916447567086, 0.059101017591144354, 0.2561444453895092, 0.22351657333118574, 0.14410900431019918, 0.03264292875038726, 0.032611298840492964, 0.024730893217825463, 0.04993520710351212, 0.6047785335353443, 0.021947147324681282, 0.17980443819292954, 0.03159329953736492, 0.18162179924547672, 0.06436611685369696, 0.0807139321363398, 0.10446681042334863, 0.047525081251348765, 0.01811117003671825, 0.0786333130672574, 0.2848941369780472, 0.05649197919826422, 0.10780054117952075, 0.1175121550581285, 0.10144958232662507, 0.11872821194784981, 0.02004114076096032, 0.0801529600950224, 0.06367604673973151, 0.11910184047051839, 0.041811860499105284, 0.04143324474404965, 0.09938850506607975, 0.08247639292052814, 0.047066425505493364, 0.016751872708222697, 0.06180124769785574, 0.0730795446517212, 0.048148196922349076, 0.07668141209121261, 0.07693947252950498, 0.03267912859363215, 0.04824561419497643, 0.0914307413622737, 2.651766747236252, 22.222496509552002, 51.73565789631435, 69.21355615343366, 62.59037344796317, 42.24096189226423, 22.555692161832535, 37.361905574798584, 62.488651820591514, 58.50511755262102, 20.215116773332866, 1.0907693611724036, 0.9612415858677456, 1.7589997670480182, 0.612702954028334, 0.23936734135661805, 1.8370064326695033, 0.24602428557617323, 0.2009394469537905, 0.14866243568914278, 0.11870990507304668, 6.678660597120013, 23.913017545427593, 50.96039179393223, 66.56459018162319, 70.43635572705949, 73.81764793395996, 79.43020820617676, 51.916536876133506, 50.675460066114155, 71.56310340336391, 78.79348918369838, 86.98016248430524, 79.96886730194092, 58.48762198856899, 28.825772626059397, 10.87167957850865, 1.3033161674227034, 0.17224163615277835, 0.13045166858604976, 0.07459060142615012, 0.16782174046550477, 0.03184246098888772, 0.14200414797025068, 1.850435346364975, 36.25257008416312, 66.61558301108224, 50.66623285838536, 52.81307683672224, 74.0146154676165, 49.624235834394185, 48.42611973626273, 45.8525174004691, 53.315320423671174, 55.716843673161094, 72.28598703656877, 91.13911097390312, 97.69348566872733, 80.8054095676967, 62.399763516017366, 64.51733125959123, 50.298193727220806, 40.545386041913716, 45.71459913253784, 41.94837324959891, 27.576106105531963, 5.869941958359309, 0.5198718724506242, 0.5928861488189016, 0.21633650575365337, 0.31262437041316715, 23.622864246368408, 20.86544210570199, 8.894893629210335, 1.4988374986818858, 0.8228088798267501, 0.47405192255973816, 7.783464125224522, 41.29434279033116, 61.792657715933665, 43.53396953855242, 26.287286485944474, 33.28830528259277, 44.2234080178397, 46.2650180544172, 24.518290758132935, 3.5846110454627444, 0.11807685904204845, 0.11585209199360438, 0.16835756599903107, 0.08759395152862583, 0.06623697360711438, 0.13702399948877947, 0.02382005155751748, 0.08291376980819873, 0.11039827857166529, 0.08059059482600008, 0.0546250375919044, 0.03973880709548082, 0.021147744863161018, 0.07723323748047863, 0.013274414664400476, 0.05961077380925417, 0.05573390291205474, 0.05323206965944596, 0.13409556448459625, 0.03610708072249379, 0.07685704409543957, 0.028544828295707703, 0.04718062634180699, 0.0822221797757915, 0.03668351657688618, 0.10916927523378815, 0.18878533770995481, 0.08625937492719718, 0.06291897807802473, 0.05546498252078891, 0.021604264920045222, 0.08418543264269829, 0.045577122563762326, 0.1312497207628829, 0.0412953121454588, 0.08164561499974557, 0.049067075829952955, 0.09822396255497422, 0.026440238280754005, 0.04806299667273249, 0.04239175688209278, 0.11846215836703777, 0.0344645781442523, 0.2689887604543141, 0.026413926389068365, 0.1527281225259815, 0.0158795158578349, 0.13321926364941256, 0.21650676376053266, 0.15370120959622519, 0.0869468462520412, 0.0625686775892973, 0.0767040615901351, 0.056482018304190466, 0.18942644473697456, 0.032911893246429305, 0.1548679234193904, 0.038380661580179415, 0.18689857609570026, 0.053408098606658835, 0.16607213791991982, 0.0797106706138168, 0.1533863422061716, 0.061546233881797106, 0.24722366407513618, 0.15336191494550022, 0.04848131690440433, 0.07917677890509367, 0.05820514102067266, 0.022889204988522188, 0.09134220611304045, 0.10120811885488884, 0.05717533520822014, 0.020011132549760596, 0.10470809069062982, 0.03800189994009478, 0.02983399054833821, 0.04992923599534801, 0.05629704287275672, 0.010008041231360818, 0.10826972778886557, 0.02672826961082007, 0.07161951371069465, 0.0246731176573251, 0.062098405323922634, 0.05612588580697775, 0.1336200607142278, 0.023618672542007904, 0.07833152104701314, 3.77221132176263, 29.643276827675955, 65.78207015991211, 72.5545904976981, 44.72819464547293, 21.98996809550694, 22.5712856565203, 60.46529470171247, 83.96951498304094, 65.1189271381923, 13.764268500464302, 0.7774802978549684, 0.18299902177282742, 2.1040039913994923, 0.79502515069076, 0.151442271524242, 1.6854706725903918, 0.6065584123134613, 0.6151737443038395, 0.47873907962015694, 0.28235163912177086, 13.58034794671195, 38.76129361561367, 65.1619712284633, 81.80169786725725, 82.54002734592983, 82.89175905500139, 80.4979726246425, 68.52938093457902, 77.64620263235909, 80.45292745317731, 85.31331743512834, 102.38203280312675, 102.76317623683384, 80.31821577889579, 44.15047625132969, 15.570054939814977, 1.3287784925528934, 0.37365105003118515, 0.16686723168407167, 0.3067595751157829, 0.12498697824776173, 0.06045639129089458, 0.24422318222267286, 10.131198763847351, 62.255588395254954, 65.37862995692662, 53.41107702255249, 65.69934490748814, 74.08852345602853, 73.89679486410958, 68.72329820905412, 70.91651099068778, 69.67554187774658, 70.32979120526994, 71.00731699807304, 75.4870707648141, 82.99782330649239, 77.9371862411499, 65.1432249886649, 79.6991799218314, 63.255156244550435, 56.76855775288173, 57.754677363804404, 60.212818009512766, 42.384032249450684, 11.185386402266365, 2.565566744123186, 1.1507087562765395, 0.12747026713831083, 1.6953938943999154, 31.938940797533306, 22.142937898635864, 3.191340182508741, 3.4082308071000234, 0.6517701776964324, 0.6471866465040615, 3.3857017074312483, 41.68357392719814, 71.72863033839634, 57.905592237200054, 31.016157490866526, 32.72864873068673, 44.29422753197806, 55.7985405921936, 31.747740268707275, 5.626284267221179, 0.14460760541260242, 0.08449612025703702, 0.1052020506135055, 0.0932736424729228, 0.13240506233913557, 0.05117725527712277, 0.014286388576562916, 0.03283288123618279, 0.05221013824588486, 0.04517610158239092, 0.04617651665051069, 0.055917324498295784, 0.021419818745926023, 0.08201239710407597, 0.036355583995048485, 0.029323742392339876, 0.19707706277923925, 0.0555578637868166, 0.10143376567534038, 0.04074679461440869, 0.011311176216362842, 0.020772092609799335, 0.026835164321320396, 0.0885574101869549, 0.08451524815921273, 0.08567522412964276, 0.20340746880642005, 0.14350487744169577, 0.05004143515335662, 0.08891934076590197, 0.02159817167557776, 0.09417979884892702, 0.02368988479221506, 0.050021014641970396, 0.09647718950041703, 0.027942674267770987, 0.11017962744725601, 0.0512720737606287, 0.05952874571084976, 0.029688488891614333, 0.036643418549959145, 0.24358525073954038, 0.23642274364829063, 0.36313831699745996, 0.11596862359770707, 0.14031960336225374, 0.09392485288637024, 0.26862821408680504, 0.28198004620415823, 0.2696202051426683, 0.13670560371662888, 0.10339161061814853, 0.15404011069663934, 0.12009984334664685, 0.5555110286389078, 0.06083633018923657, 0.3081035901393209, 0.18271276141916, 0.21517116257122584, 0.14781960020107882, 0.28524363679545267, 0.2640487269631454, 0.213700641478811, 0.14058725828570978, 0.24062672949263028, 0.4079895902957235, 0.12045152804681233, 0.2685008394931044, 0.13177949376404285, 0.30738578151379314, 0.27106350341013496, 0.27141096762248446, 0.18976858923477785, 0.12727646396628448, 0.13614611088165215, 0.18615426389234407, 0.10966242091464144, 0.21126597640769823, 0.09411101575408663, 0.12776781831468853, 0.1451701516551631, 0.18283564411103725, 0.20183575100132398, 0.15933522156306676, 0.11127020285597869, 0.13093918242624827, 0.22942905606968061, 0.08858936918633324, 0.2080276408897979, 3.848427849156516, 34.81990712029593, 77.28868307386125, 84.49435411180768, 75.59392711094448, 57.794646876198904, 36.95364679609026, 53.1711175101144, 77.6543459211077, 73.6463817868914, 28.748793533870153, 1.9649032269205366, 1.1151527613401413, 4.223893301827567, 2.599248136792864, 0.23983202927878924, 4.625613825661795, 0.6238580154521125, 0.7567189718995775, 0.5690748350960868, 0.14236938980008873, 8.053086365972247, 26.70736415045602, 49.13229642595564, 66.07472133636475, 70.82604544503349, 83.26962988717216, 80.42522498539516, 61.976680755615234, 67.16798564365932, 72.63157653808594, 90.70036002567836, 109.0941663469587, 109.45641762869698, 103.9351566859654, 50.951862880161826, 14.339859877313886, 1.251943466918809, 0.4121179059147835, 0.28228310708488735, 0.4822290294936725, 0.2138735729136637, 0.31006138079932755, 0.22626088107270853, 5.810257800987788, 64.76242896488735, 85.0383494240897, 63.846809250967844, 66.27188341958183, 91.63012627192906, 86.89638110569545, 57.5506261416844, 70.95713015965053, 78.45616803850446, 96.33338969094413, 103.26266138894218, 126.80848748343331, 110.94925199236188, 87.47719492231096, 68.99418762751988, 70.25920445578438, 74.50409521375383, 52.84117187772478, 60.59758145468575, 49.83156313214983, 31.770189898354666, 6.314563700131007, 1.5999760201999118, 1.0708040382180894, 0.19548125698098115, 0.7892927240048135, 32.26976190294538, 34.028389181409565, 16.77233474595206, 8.388217091560364, 4.8941890597343445, 0.8227194217698914, 9.5679760490145, 51.787241322653635, 67.92425537109375, 53.5324307850429, 34.10505560466221, 44.9348966053554, 55.02806179864066, 66.18784495762416, 38.379986899239675, 7.399079356874738, 0.222370106992977, 0.18199151940643787, 0.3413104696997574, 0.28059447769607815, 0.3165542823927743, 0.2658690735697746, 0.11159216093697719, 0.17071424025510037, 0.08890914238457169, 0.15006134419568948, 0.27663671863930567, 0.19249435939959117, 0.10971899037914616, 0.21078743280044623, 0.14265489019453526, 0.16116064361163548, 0.3706198169716767, 0.17299721203744411, 0.24913946698818887, 0.16919405039932045, 0.265330181057964, 0.14008054190448352, 0.18378296042127268, 0.1916164979338646, 0.17585866206458636, 0.2779312277478831, 0.23921271679656847, 0.3350061737000942, 0.20151420682668686, 0.26348562432186945, 0.17562312898891314, 0.10954056959599257, 0.07020259009940283, 0.28106861082570894, 0.12548837491444179, 0.14280745200812817, 0.20206863779042447, 0.14990799528147492, 0.2861299935196127, 0.135677894577384, 0.0947282722752009], [0.05210485335971628, 0.19660956572209085, 0.006769857959755297, 0.04435492153944714, 0.37375893709915026, 0.14028129327510083, 0.1551406266433852, 0.04356590744906238, 0.04738810538713421, 0.02698346832767129, 0.06891836758170809, 0.40896586648055483, 0.13250685616263322, 0.5829514733382634, 0.34362948526229176, 0.132970838408385, 0.2589387340205056, 0.07558409204440457, 0.038260577845254114, 0.053560765593179634, 0.05435953701713255, 0.08565684261598758, 0.13082988400544437, 0.05029588917802487, 0.04702163880158748, 0.0827566957367318, 0.048745056680802784, 0.03563277795910835, 0.07357809825667314, 0.09662754607519933, 0.07390509785286017, 0.07201600886349167, 0.059660761484078, 0.0795790416055492, 0.039261532348713706, 0.1438441720924207, 0.03937324635418398, 0.0061351457012018985, 0.019186863476144414, 0.07929419260472059, 0.06190847658685275, 0.028893137284155403, 0.023210357309186032, 0.002840886599317725, 0.057707625574299266, 0.01883520931005478, 0.029076121215309416, 0.029666124377399683, 0.07438880511160408, 0.19258037049855503, 5.635995243276868, 27.41356689589364, 53.43460014888218, 64.97202137538365, 54.2847261428833, 26.15331826891218, 20.481436014175415, 31.811232907431467, 57.46618468420846, 57.5530823298863, 16.924373490469797, 1.1830861674887794, 1.383856754217829, 0.780094557574817, 0.4735746681690216, 0.5600051560572216, 0.6771524899772235, 0.19011034018227033, 0.37051876953669954, 1.0212107279470988, 0.28132884257606094, 0.05717421562543937, 2.8658476940223148, 9.427178621292114, 16.929337978363037, 17.694817543029785, 3.550038980586188, 9.80107855796814, 19.502073526382446, 9.382239409855433, 8.49704498904092, 2.6630456277302335, 0.7590347847768238, 0.0932974386960268, 0.3174331752317292, 0.11513682108904634, 0.29987716728023117, 0.4413216459964003, 0.1904837108616318, 0.10798312816768885, 0.18434820723320755, 0.14005612821451255, 0.09810325796050684, 0.8926289933068412, 15.773393971579415, 72.08004937853131, 69.53790501185826, 73.41477748325893, 90.95685277666364, 59.670976638793945, 66.48629093170166, 63.5678390775408, 67.33305399758476, 53.23081990650722, 47.656606742313926, 37.340279306684224, 43.44025918415615, 38.85298204421997, 24.377923250198364, 15.10987401008606, 22.82661979539054, 9.874752913202558, 0.7563184733901704, 0.04110844360132303, 0.3362113876002175, 0.11834238336554595, 0.04162262726042952, 0.11463500373065472, 4.769432851246425, 5.823233127593994, 1.4976323119231632, 0.865716883114406, 0.4955681051526751, 7.494120291301182, 32.91841793060303, 53.063639300210134, 37.340022223336355, 21.63153484889439, 25.80399411065238, 43.640836306980674, 50.99030031476702, 37.83633899688721, 8.5444621018001, 0.035016814047204595, 0.1018914036186678, 0.04791819390707782, 0.043956183828413486, 0.07478335286889758, 0.12063264261398997, 0.04365149785631469, 0.039723645230489116, 0.12758989286209854, 0.03734180071790304, 0.09862534994525568, 0.0474033215349274, 0.11903676896223, 0.09027626152549471, 0.039528783543833663, 0.04938543089000242, 0.06298593591366496, 0.056113794312945435, 0.15334569795855454, 0.013511264946178665, 0.06322728403444801, 0.021277214433731775, 0.033974689431488514, 0.19213882062051976, 0.02993345699672188, 0.06105129686849458, 0.026679913812716092, 0.055028918598379405, 0.08875158655324153, 0.04839709713788969, 0.09728452403630529, 0.08221562512751136, 0.06990928655224186, 0.04068591984521065, 0.021982644884181873, 0.09517571183719806, 0.06031879795981305, 0.09050475140767437, 0.05817219814551728, 0.06911614696894373, 0.18321091468845094, 0.05891908199659415, 0.05984022721116032, 0.06243926060519048, 0.09872557635286025, 0.045754108245351484, 0.050040244324398894, 0.1778394007789237, 0.22662233667714254, 0.141434979225908, 0.09945044852793217, 0.04262701854375856, 0.024441179120913148, 0.025616664705531936, 0.3029771223664284, 0.10804720222949982, 0.7440028456704957, 0.11605284336422171, 0.1482395048120192, 0.1320149182741131, 0.046415595071656365, 0.1042995515412518, 0.04336246907977121, 0.046009953266807964, 0.06805301830172539, 0.09178895356931857, 0.03280967873122011, 0.09756017210228102, 0.0940903407920684, 0.07787013759038278, 0.03719349331887705, 0.14084010757505894, 0.053436474941138706, 0.10706151476395981, 0.04884556128776499, 0.12543151367987904, 0.09365816826799087, 0.06971331885350601, 0.09368875662663154, 0.08814049113009657, 0.07170656296823706, 0.03384520798655493, 0.04347890908164637, 0.056395454199186394, 0.13356306377266133, 0.01815971073561481, 0.02022069300125752, 0.07181109807321004, 0.05230295844376087, 0.11034467430519206, 0.0552905311674944, 0.24208454840949603, 0.10268222939755235, 9.268745797021047, 38.0681517464774, 68.15307344709123, 67.11224719456264, 44.16793360028948, 22.23029933656965, 30.612415041242325, 50.196003096444265, 81.20319393702916, 57.840077672685894, 8.612485834530421, 2.0419446357658932, 0.42820825108460014, 0.649999526994569, 0.3369972397174154, 0.6028530140008245, 0.6856373261128152, 0.5025619555796895, 0.5275376896773065, 0.7829143319811139, 0.42324085906147957, 1.2835424627576555, 8.652384996414185, 18.749847650527954, 29.856885296957834, 33.58713340759277, 13.021914277757917, 22.554365055901663, 33.68498488834926, 24.765849862779888, 25.767804418291362, 12.225134815488543, 6.244681758540017, 0.5771329541291509, 0.06444954273423978, 0.13879030756652355, 1.4944438487291336, 1.5926466477768761, 1.3582087819065367, 0.5998416213052613, 0.5633681384580476, 0.253184974193573, 0.09079939845417227, 3.7332523380007063, 44.621300084250315, 90.6370688847133, 84.98675904955182, 78.46963364737374, 88.7049207687378, 62.771693638392854, 68.47338540213448, 79.17212431771415, 91.11312471117292, 75.78694111960274, 58.564510754176546, 61.344568388802664, 63.993291173662456, 48.89191654750279, 35.541890961783274, 25.2256121635437, 32.47865949358259, 19.020681483404978, 3.1164277451378957, 0.9061029074447495, 0.5986068504197257, 0.2968934859548296, 0.6539443124617849, 0.6296576985291072, 3.0268339812755585, 8.16834829534803, 3.324308076075145, 1.2786902316978999, 0.6464646309614182, 3.7088876111166815, 33.18261275972639, 67.64771706717355, 56.415200165339876, 29.08490742955889, 25.060125180653163, 44.06965480531965, 58.49597372327532, 45.94584212984358, 12.093325751168386, 0.0835762642590063, 0.17299520357378892, 0.029042167322976247, 0.03670215254117336, 0.0736457414126822, 0.06587797429944788, 0.04814964559461389, 0.04638516277606998, 0.03637858633218067, 0.030750145137842213, 0.08348190039396286, 0.04237553650247199, 0.03646909611831818, 0.08081929505403553, 0.01606570077793939, 0.049539817962795496, 0.05334087614236133, 0.06791494321078062, 0.06211827961461885, 0.05193453089201024, 0.021283877647614906, 0.1162449230573007, 0.06453651735293013, 0.11243791412562132, 0.03283063189259597, 0.03008981860641922, 0.09441662792648588, 0.04252760298550129, 0.021890204665916305, 0.03752943939928498, 0.07682142100696053, 0.021701985837093422, 0.09552731511316129, 0.07160122040659189, 0.11644625796803407, 0.12619825825095177, 0.06751099774347884, 0.0657703790015408, 0.08932152882750545, 0.06768578836428267, 0.08206460358841078, 0.04476754886231252, 0.019490955730101893, 0.15848657781524317, 0.32266107041920933, 0.2618897370994091, 0.08306892362556287, 0.4246696638209479, 0.36988740627254757, 0.21268473884889058, 0.11836196588618414, 0.1253756566771439, 0.1460946827594723, 0.10686557420662471, 0.6319150488291467, 0.23137932856168064, 0.8739840994988168, 0.6064760110207966, 0.2793324025613921, 0.3478606939315796, 0.15095207068536962, 0.19777174693133148, 0.1381616448717458, 0.11126992465662104, 0.08481667377054691, 0.23537318568144525, 0.21475121724818433, 0.24033623508044652, 0.2167213979576315, 0.16747616258050713, 0.09059712037976299, 0.13674136251211166, 0.08742770366370678, 0.2530216643852847, 0.17123672579016003, 0.227926888103996, 0.2430102601647377, 0.1940324625798634, 0.23243640469653265, 0.2539741104202611, 0.12640192732214928, 0.1389222147741488, 0.2103869342910392, 0.12250847981444427, 0.19996698413576397, 0.08680698661399738, 0.14183137938380241, 0.10818801181656973, 0.0834101860278419, 0.2810868227056095, 0.15567927488258906, 0.47203851916960304, 0.49494097594703945, 11.215896810804095, 47.069358893803184, 79.27025372641427, 82.03467096601213, 68.6842006955828, 41.96017476490566, 38.933000973292756, 47.67934472220284, 75.94130229949951, 75.48801571982247, 22.78370772089277, 2.268686286040715, 2.0499374525887624, 1.5335210604327065, 1.5542502509696143, 7.191957030977521, 3.7023159180368697, 0.3788536765745708, 0.3315190193908555, 1.5150786957570483, 0.5557621951614107, 0.43512048731957165, 4.520893616335733, 12.335766639028277, 20.843482324055262, 26.506423984255107, 11.603513360023499, 26.846941300800868, 29.165695871625626, 14.192270585468837, 14.540733167103358, 4.266364165714808, 1.8978865487234933, 0.22919026602591785, 0.17625095030026777, 0.1057176354474255, 0.9515096566506794, 0.6480351952569825, 0.4333651986505304, 0.34583605400153566, 0.5288051930921418, 0.4252805624689375, 0.2172982477183853, 1.3569157655750002, 36.755192347935264, 100.0969648361206, 115.8328628540039, 64.41322640010289, 126.03046989440918, 113.88599150521415, 101.2238723209926, 103.59331921168736, 101.84029565538678, 61.19413988930838, 31.16407769066947, 42.436108997889924, 59.43145138876778, 52.45052678244454, 34.10473598752703, 23.058896337236675, 31.654568399701798, 16.25454456465585, 0.9506072593586785, 0.40472947380372454, 0.3948540480009147, 0.3340982938451426, 0.8831936653171266, 1.0120996854134967, 14.875954219273158, 14.4377487046378, 1.6653886416128703, 2.440300928694861, 1.447750217148236, 11.585807612964086, 40.989897046770366, 65.52731445857457, 49.29497807366507, 34.977127483912874, 33.260033062526155, 54.50059625080654, 66.63466276441301, 52.67626333236694, 15.024412904466901, 0.3357782651271139, 0.7311394502009664, 0.1675288033272539, 0.18129209907991545, 0.195212543542896, 0.2080365161278418, 0.1326680082295622, 0.24554222715752466, 0.20390815979668073, 0.07286887309913125, 0.10611682438424655, 0.1464341538293021, 0.20275007693895272, 0.21767864802053996, 0.07636621221899986, 0.0819959629859243, 0.1645604976053749, 0.19493392349353858, 0.25608891408358303, 0.11170866539967911, 0.14643567374774388, 0.1499736774712801, 0.13111847851957592, 0.3404879495501518, 0.1136016763214554, 0.12073139660060406, 0.21634633094072342, 0.08988619888467447, 0.20677336890782627, 0.0970476610319955, 0.21319651710135595, 0.16067861233438763, 0.25402280209319933, 0.1365207436361483, 0.1439331416040659, 0.231622542653765, 0.17717093521995203, 0.29983306250401903, 0.14358609808342798, 0.2573495778654303, 0.20052824116178922, 0.19230023053075584, 0.2886652174804892], [0.003934670630509832, 0.038315749527620416, 0.034861487203410695, 0.017253440704994967, 0.049871479094560654, 0.026786562554272156, 0.05543363420292735, 0.022912860415609818, 0.024207456037402153, 0.0559183694422245, 0.08543661050498486, 0.039528658014855216, 0.025113598842706, 0.030930981505662203, 0.0159925988077053, 0.0043596405053644306, 0.0789087779287781, 0.051135477876024585, 0.04104126863447683, 0.043154650766934664, 0.02373697003349662, 0.03834047534369996, 0.03588167817464896, 0.08634912475411381, 0.037551973547254286, 0.06438352127692529, 0.027088310469740202, 0.056391993670591285, 0.02756537656698908, 0.03953526355326176, 0.04292053243677531, 0.05649569757016642, 0.044275013862976005, 0.057682479066508155, 0.04622793264154877, 0.06011110517595496, 0.05514849343204072, 0.046013993942844014, 0.06233360591743674, 0.01618039864115417, 0.0047985292538734415, 0.030857241712510586, 0.02238637491661523, 0.09042508461113487, 0.08301960091505732, 0.04776186961680651, 0.047835745116961856, 0.05342142164175, 0.0638730525970459, 0.1592579907072442, 0.23554005101323128, 0.03304779023996421, 10.181505458695547, 35.73668718338013, 52.076345443725586, 61.80651242392403, 40.24236467906407, 29.064941780907766, 23.00198016847883, 35.64619384493147, 57.09289271490914, 53.926483971732004, 17.300922427858623, 1.5944463397775377, 1.7665648353951318, 0.7913718638675553, 1.2232839933463504, 1.9982274387563979, 1.8209888807364871, 2.182808939899717, 0.28003194502421785, 0.07420213334262371, 0.5486291093485696, 1.170249153460775, 0.6789781291569982, 0.066421616556389, 2.0566911016191756, 3.311437623841422, 0.7177239443574632, 0.15372541972569057, 0.1138664542564324, 0.07713979642306056, 0.2793930635920593, 0.013676036149263382, 0.5259539889437812, 1.309837486062731, 1.0015603538070406, 5.624845990112849, 4.696159320218222, 0.588986200945718, 0.3949852766735213, 0.057665990665555, 0.09275386429258756, 0.15088233085615294, 0.08530685425336872, 1.0240168230874198, 13.870579413005284, 16.26113840511867, 20.02353409358433, 20.27710165296282, 12.914238912718636, 7.135259296212878, 3.2147291217531477, 0.9831298227821077, 0.561608181468078, 3.5219684754099165, 14.284137061664037, 2.2787335983344486, 6.085765600204468, 1.076792842575482, 0.19091262641761983, 0.06244414605732475, 0.08460008539259434, 0.08453039306082896, 0.36337908836347715, 0.773255033152444, 0.13856787021671021, 1.1738979348114558, 2.2177818289824893, 0.53012046537229, 0.07064954790153674, 7.718224883079529, 42.78532893317086, 55.090341976710725, 38.118574823652, 20.344650302614482, 25.91816864694868, 41.92331109728132, 55.89803532191685, 32.485395772116526, 12.687210866383143, 0.8723638121570859, 0.18223196507564612, 0.03420958129156913, 0.07507892272302083, 0.07725382423294441, 0.042472855387521644, 0.045893893244543245, 0.10379045350211007, 0.048929540174348016, 0.0042937666294164956, 0.03202206581564886, 0.015063874356980835, 0.06493899039924145, 0.03115717115412865, 0.01713843919735934, 0.04628112639433571, 0.042166367904948335, 0.04664939109768186, 0.042591609193810394, 0.04250635466139231, 0.025701137226341025, 0.029328638022499423, 0.03935934317165187, 0.038005238332386525, 0.02813295753938811, 0.024291511259174774, 0.030598234717867205, 0.03319674224725791, 0.034217699963067255, 0.06707638927868434, 0.026404625370300243, 0.04528711669679199, 0.07721119866307292, 0.04838783174221005, 0.052209201867559125, 0.017040701316935674, 0.007442080482308353, 0.019016707249517952, 0.024345453096819774, 0.05614203494042158, 0.04148908478340932, 0.025137016782537103, 0.060951966127114635, 0.009369839182389634, 0.025177435417260443, 0.05432258739269205, 0.04600818229040929, 0.05814254616520234, 0.03460476687178016, 0.1725058848304408, 0.0523280438834003, 0.03904830271910344, 0.02056205039843917, 0.0643680981759514, 0.021000365360773036, 0.08525673087154116, 0.1570467943591731, 0.05760809127241373, 0.08140841951327664, 0.11507793782012803, 0.12749025677996023, 0.04341056024921792, 0.08786868357232638, 0.05327098364276545, 0.019486996478268077, 0.015091862230162536, 0.04937306119661246, 0.07377028651535511, 0.08257252776197024, 0.05172167445666023, 0.0614376479227628, 0.03836067193853004, 0.13434403043772492, 0.022976389953068325, 0.0035385664835173103, 0.017441152328891412, 0.009164181155418711, 0.04608283471316099, 0.06019421214503901, 0.08636666488434587, 0.05474882273535643, 0.09859036467969418, 0.04795441071369818, 0.07134109043649264, 0.06304074797247138, 0.03987671594534602, 0.029803127383014986, 0.0446550511488957, 0.026544218683349233, 0.058907696178981235, 0.06525444811476128, 0.01603913782829685, 0.01753510398391102, 0.0980883709021977, 0.015218792383426001, 0.2568414637020656, 0.28486406430602074, 13.935135994638715, 46.723248277391704, 67.21870054517473, 61.361890247889924, 32.85851403645107, 23.531019483293804, 30.3022335597447, 62.54802417755127, 89.57946968078613, 60.7668673651559, 7.126754701137543, 2.0358714759349823, 0.7372324775372232, 0.5760508264814104, 1.4209540550197874, 1.1261402517557144, 0.8039402323109763, 0.5554993578365871, 0.9260765356676919, 0.2601408538009439, 0.8233083901660783, 1.1036026839699065, 0.7145189791917801, 0.134328532697899, 3.147094705275127, 7.74568590096065, 3.7368493335587636, 0.39280416656817707, 0.26872462034225464, 0.25535324641636437, 1.4993046564715249, 1.6492035729544503, 1.1964176978383745, 2.8211551436356137, 2.44421233023916, 7.334438528333392, 4.855911867959159, 2.8921750698770796, 1.5333672229732787, 0.4656396082469395, 0.3001612020390374, 0.10162624570408038, 0.10105124155857734, 11.905132923807416, 35.81485789162772, 37.36927761350359, 45.279204164232524, 34.06213310786656, 24.94862743786403, 15.87861054284232, 12.482605525425502, 6.2971771359443665, 5.65548711163657, 9.047566396849495, 28.889425073351177, 8.18659860747201, 12.868729080472674, 3.676393057618822, 2.3224154029573714, 0.1404783127031156, 0.16133231297135353, 0.5347738042473793, 0.7995698153972626, 1.0244523882865906, 0.9361106029578617, 0.4356939308345318, 1.6041356027126312, 1.0936255050557, 0.22123457863926888, 1.588599430663245, 37.79879093170166, 66.3837285723005, 53.274416378566194, 29.181992871420725, 19.524363347462245, 34.1115209034511, 59.25524507250105, 42.2355249268668, 18.088311399732316, 1.6156810117619378, 0.19572191978139536, 0.01772071554192475, 0.067151258832642, 0.049742136749305894, 0.059081862547567914, 0.05463028945294874, 0.01960628293454647, 0.0493176181002387, 0.022228856404711093, 0.08120651463312761, 0.023305660945230296, 0.17635509185492992, 0.09443798820887293, 0.08038516834910427, 0.05663344696430223, 0.04672282215739999, 0.045192661229521036, 0.06342974531331233, 0.0531892303510436, 0.01309287007565477, 0.030814076707299267, 0.06059068015643528, 0.004504735465161502, 0.019198098319715688, 0.00478446958420266, 0.055754228428538354, 0.03516562695481947, 0.03531188517808914, 0.03761512819411499, 0.08780082328511135, 0.046377424084182294, 0.01878736919856497, 0.028256900442231978, 0.07220784428396396, 0.029969653447291682, 0.03509887267968484, 0.04253188793414405, 0.03190736625609653, 0.03279412331591759, 0.04668738227337599, 0.03288726921060255, 0.09004201088100672, 0.02411664430318134, 0.07938363030552864, 0.11840892050947462, 0.28438737988471985, 0.1098838404619268, 0.1608193133558546, 0.2305725504245077, 0.13483017363718577, 0.21368560514279775, 0.09445282098438058, 0.17158613061266287, 0.09370821022561618, 0.1643194141132491, 0.16223536165697233, 0.1435627836201872, 0.12372346461883613, 0.19090100989810058, 0.1250255868903228, 0.1581485452396529, 0.16881491217230046, 0.16366226651838847, 0.14415095134505204, 0.16288716239588602, 0.09845186889703784, 0.19920125736721925, 0.31860486950193134, 0.13399032370320388, 0.1887996412281479, 0.11597072705626488, 0.19111884678048746, 0.20987312043351786, 0.18372357503644057, 0.13086694558816298, 0.11132120833333049, 0.14729357271322183, 0.14882259709494455, 0.1975924644087042, 0.2808226283107485, 0.24627404074583734, 0.18024422387991632, 0.10155811400285789, 0.15265083738735744, 0.08628837551389422, 0.13803034834563732, 0.15936464284147533, 0.1941208349806922, 0.1672582985567195, 0.15033913643232413, 0.1274590848812035, 0.20792890047388418, 0.1460487459387098, 0.36234198829957415, 0.42259695647018297, 0.39654395303555895, 17.31369842801775, 60.21955081394741, 79.72320679255894, 77.67027119227818, 54.90307412828718, 45.61633423396519, 36.15792519705636, 51.48120444161551, 73.67849636077881, 69.08311067308698, 23.400740759713308, 2.255052617618016, 2.606507484401975, 3.0432391124112264, 9.83152643271855, 10.478286470685687, 9.601950134549822, 7.23637729883194, 1.7910464874335696, 0.164991272347314, 0.6818513178399631, 1.4386866177831377, 0.8214078950030463, 0.1294716333172151, 3.3940482309886386, 8.942929131644112, 4.021200452532087, 0.3915959671139717, 0.4622772772397314, 0.4330284281500748, 1.0431892914431435, 1.1265386875186647, 1.1471862367221286, 4.209492291722979, 3.9046700426510403, 11.310889107840401, 10.807742255074636, 2.3780177107879092, 1.0905295397554124, 0.3830106806542192, 0.19818236918321677, 0.18363966739603452, 0.244776649666684, 5.938943650041308, 27.550342185156687, 28.457028252737864, 24.309210777282715, 21.002821888242448, 13.198012028421674, 7.56670377935682, 4.862450991358076, 2.12936252781323, 1.3473733919007438, 5.818538750920977, 30.585396971021378, 4.965920090675354, 11.629592554909841, 3.3627613612583707, 1.0168689723525728, 0.09386562356459242, 0.11139020855937685, 0.3606416609670435, 3.377895623445511, 2.0533913586820876, 4.010005167552403, 7.271245096411024, 7.603933095932007, 1.3520443184035165, 0.08819583923156772, 11.183248094149999, 55.96637780325753, 68.24009963444301, 53.93265049798148, 32.32007728304182, 36.7786077771868, 54.87385695321219, 72.20499883379254, 52.363837582724436, 22.515194586345128, 2.0373486195291792, 0.3828978809927191, 0.1856492031365633, 0.28947888953345163, 0.18594174672450337, 0.16686620031084332, 0.1930235352899347, 0.13188453098492964, 0.13917781891567366, 0.10503797406064612, 0.14210600964725018, 0.16962812282145023, 0.2332179413310119, 0.169060243293643, 0.14396708192569868, 0.11689508174146925, 0.10606417006679944, 0.17065269712890896, 0.2395403135035719, 0.09871778677084617, 0.09387253783643246, 0.15778539329767227, 0.17689344153872558, 0.10098999698779412, 0.07682301556425435, 0.07698074102933918, 0.14713917885507855, 0.11564307606645993, 0.16129489855042525, 0.11846195480653218, 0.09954694977828435, 0.09516319286610399, 0.12979135901800223, 0.12186596143458571, 0.16053958050906658, 0.16087298547582968, 0.12442965672484466, 0.16488738863595895, 0.1513171496668032, 0.1384384057351521, 0.18192781853888715, 0.14061768379594597, 0.14472400130970137, 0.13433784219835485, 0.19337241085512297], [0.04807733411767653, 0.05268621198566897, 0.05483949197722333, 0.07621323649904557, 0.011094144246141826, 0.02941121912694403, 0.027351951858560954, 0.0331898720801941, 0.01843855300519083, 0.04813065000676683, 0.0807995293289423, 0.04037189044590507, 0.047491612511553934, 0.050300784808184416, 0.05035021608429296, 0.030786836918975626, 0.017535960634372065, 0.07033378484525851, 0.046707036040191136, 0.03683016495779157, 0.06394078396260738, 0.025382112112960646, 0.03563234369669642, 0.048903718524213345, 0.030610112473368645, 0.0359365818356829, 0.009861456463113427, 0.0781096468812653, 0.09063476550259761, 0.04553945029952696, 0.043236407451331615, 0.018755333863997033, 0.03464956036103623, 0.008851734439044126, 0.03245530703238078, 0.02736134617589414, 0.03983469766431621, 0.11000569856592587, 0.046696484820651155, 0.015942190441169908, 0.031728300864675214, 0.03985557279416493, 0.03423267523092883, 0.06804273171084267, 0.0885142892865198, 0.01846446456121547, 0.027062122410695468, 0.05206385627388954, 0.05615787873310702, 0.05355185982105987, 0.3449358008801937, 0.08322185863341604, 0.34481713867613245, 0.2973737801824297, 12.996185098375593, 47.387888635907856, 62.247709138052805, 54.19948564256941, 40.73921993800572, 23.998520340238297, 21.918346064431326, 21.52327844074794, 51.426292828151155, 58.83394105093819, 30.010888644627162, 7.595669950757708, 0.9304625860282353, 0.44915788407836643, 1.6514144028936113, 1.0585150633539473, 0.7910425843937057, 0.4102685722921576, 1.2485881383929933, 1.7147945676531111, 2.0738040804862976, 0.6026151467646871, 0.37334758202944485, 1.8796492644718714, 2.433274345738547, 0.3571237825921604, 0.33576732714261326, 0.27770123151796205, 0.5786700259361948, 1.2684460899659564, 2.2627138750893727, 2.327420060123716, 0.39694925557289806, 4.61591066632952, 3.7669914875711714, 3.624352570090975, 2.9167899319103787, 0.5773877033165523, 0.21750564873218536, 0.009907295744466995, 0.14686165803245135, 0.11589363190744605, 0.4925205601113183, 0.11663452429430825, 0.18116262102765696, 0.22204077323632582, 0.5153235707964215, 0.09799687045493297, 0.15086760664624826, 0.05669146849374686, 0.15171570756605693, 0.5040035982217107, 0.7696685684578759, 0.4603617457406861, 0.3672819675079414, 0.6381625650184495, 0.39625484283481327, 0.32699294654386385, 0.6666834545986993, 0.6780954908047403, 0.2572815886565617, 1.4579348649297441, 1.147477843931743, 0.9364340198891503, 0.7491484752723149, 14.638126066752843, 48.678582532065256, 56.238764558519634, 34.8118645804269, 20.318332263401576, 31.624538285391672, 46.04331840787615, 61.115972655160085, 46.58276959827968, 22.28269570214408, 0.6848864321197782, 0.20492175540753774, 0.06463450459497315, 0.023713172114055072, 0.03790930026609983, 0.06920158809849195, 0.07188372846160616, 0.029425464969660555, 0.06805688595133168, 0.04176163533702493, 0.08067747444978782, 0.06740801648369857, 0.02805004734545946, 0.025891230508152927, 0.01867562805169395, 0.04186320524396641, 0.030926682986319065, 0.03942298975640109, 0.11723647985075202, 0.008156393804321331, 0.034495848430586715, 0.02768764179199934, 0.09752287303230592, 0.09292901453695127, 0.08395914799932923, 0.026771729778764502, 0.018818157725036144, 0.03861502757562058, 0.005274840480914074, 0.021406339647780572, 0.013955500974719013, 0.01260760727538062, 0.06426966988614627, 0.0277398465799966, 0.07504277716257743, 0.08553516093109335, 0.03257955697232059, 0.05928179967616286, 0.04932878339397056, 0.008187255273307008, 0.014709059914041842, 0.02264412322879902, 0.03172136623678463, 0.04245526097448809, 0.030948396106915813, 0.04507666906075818, 0.019252504953848462, 0.012335435853206685, 0.035640937342707596, 0.03569213280986462, 0.032062621853713474, 0.03704079579828041, 0.019210513814219406, 0.08086807493652616, 0.018114851089194417, 0.05938225678567376, 0.06452165743602173, 0.03483729064464569, 0.03432973627267139, 0.08067958469369582, 0.07414999471179076, 0.039732778311840126, 0.019773736895461167, 0.05728276765772274, 0.05364613547655089, 0.05457404229257788, 0.014800629911145993, 0.03750645063285317, 0.028863359774862016, 0.04882818400593741, 0.03392108855769038, 0.037223209760018756, 0.05633470835164189, 0.052314303549272675, 0.009132609769169773, 0.059081414714455605, 0.02986710305724825, 0.05205399037471839, 0.05140205732147608, 0.05727534448461873, 0.03940756665542722, 0.027824056168485965, 0.04556632028626544, 0.030881886104387895, 0.050852769653179815, 0.03619891704459276, 0.05665029838149037, 0.030527120855237757, 0.022908103885129094, 0.03530971725870456, 0.055532734242400954, 0.04132124236119645, 0.011932861026642578, 0.03532151698267885, 0.0454916373294379, 0.03743690757879189, 0.06301105528005532, 0.25044678683791843, 0.04680143043931041, 0.4155300956751619, 1.019392688359533, 17.996560437338694, 62.416397503444124, 72.94453729901994, 57.42387362888881, 35.740140438079834, 18.394881555012294, 26.07259062358311, 46.460352761404856, 86.90996483394078, 66.65544482639858, 17.15133466039385, 1.3773822273526872, 1.082597411104611, 0.5285290021981511, 0.27625492055501255, 0.7683363056608609, 1.3762472825390952, 0.8838307282754353, 1.5851047039031982, 0.8916977718472481, 0.8772510013410023, 1.0343040653637476, 2.0334569769246236, 4.345411215509687, 5.051641753741673, 0.7873308349932943, 0.4522395187190601, 0.836339573775019, 1.2334633214133126, 0.6862710778202329, 1.8925366529396601, 4.7861732329641065, 3.7442656670297896, 4.457360591207232, 3.313870361873082, 3.452872548784528, 4.827729540211814, 2.835413715669087, 1.2559766790696552, 0.3979000188410282, 0.08112490722643477, 0.31217089188950403, 0.8660452940634319, 0.8061006335275513, 0.29552026678408894, 0.35991443427545683, 0.4348099354122366, 0.2122101578861475, 0.2903935818799904, 0.1343009298933404, 0.27138181775808334, 1.5416556639330727, 1.785206200821059, 0.9478169062307903, 1.4391489986862456, 0.8843028800828117, 1.6425476329667228, 2.275390212024961, 0.9752223385231835, 1.7309985267264503, 1.5687223715441567, 1.0774241515568324, 0.9673263622181756, 0.3628647045365402, 0.7545518938984189, 5.971690944262913, 48.58598041534424, 72.58385631016323, 56.55809334346226, 30.680375371660503, 28.222462279456003, 36.39071764264788, 63.677620615277974, 59.98384707314627, 30.522345542907715, 2.005480923822948, 0.13771795082305158, 0.050917552784085274, 0.05759385560772248, 0.05211210689906563, 0.04322660940566233, 0.05937528144568205, 0.047078438967998536, 0.032261391902076345, 0.0063228954926931435, 0.01975510093117399, 0.019833690553371395, 0.028785806614905596, 0.012075159149909658, 0.05406103589172874, 0.05095201897035752, 0.060430647672287056, 0.09536505703415189, 0.028025647226188864, 0.02460196308259453, 0.021706014638766646, 0.11027631868741342, 0.0740355665662459, 0.0410967083381755, 0.04478744350905929, 0.02250330855271646, 0.029416864538299184, 0.03432911541312933, 0.010278335656039417, 0.03210443996691278, 0.01848578073882631, 0.043016012491924424, 0.024280118656211665, 0.06549510412982532, 0.031019547288971286, 0.04907967283257416, 0.016787427943199873, 0.020148157607764006, 0.01611912523263267, 0.008890711186852838, 0.03986412912075009, 0.02878744527697563, 0.04158199319083776, 0.031037199377481426, 0.019398149102926254, 0.039405266421714, 0.00992601822196905, 0.1258897419486727, 0.16654939231063637, 0.12797179951199464, 0.11962242610752583, 0.08200346758323056, 0.12694335755492958, 0.12463156160499368, 0.13411018012889794, 0.17336073038833483, 0.10955895789499794, 0.15070029348134995, 0.14724470462117875, 0.1613453272730112, 0.1892175916582346, 0.22542726009019784, 0.09533104207366705, 0.11394996834652764, 0.08713712782732078, 0.15804600502763475, 0.09130538880292859, 0.1378441583365202, 0.0841015860704439, 0.21002577724201338, 0.1551463127668415, 0.14497033666287149, 0.13554969217096055, 0.21040568899895462, 0.18067354655691556, 0.16805816920740263, 0.1267238107642957, 0.12929609630789074, 0.09434779733419418, 0.12030803146106855, 0.09164667834660836, 0.11115981199379478, 0.13986571771757944, 0.1395913724388395, 0.2644697715129171, 0.10706753336957522, 0.13494133124394075, 0.13831963496548788, 0.12548236309417657, 0.145089555265648, 0.15142336753862246, 0.16604309662112168, 0.08908410263913018, 0.13559161206441267, 0.18236123956739902, 0.18329138894166264, 0.1914471491639103, 0.4146072609083993, 0.1852691149605172, 0.7468606723206384, 1.0608227338109697, 22.033165046146937, 72.90834413255963, 87.13213348388672, 71.94504587990897, 56.11908878598894, 41.05463688714163, 32.52119289125715, 34.24016332626343, 69.74486405508858, 74.48515442439488, 38.88160514831543, 11.100689598492213, 1.1942320551191057, 1.005778778876577, 3.40252394761358, 4.17296040058136, 4.675868843282972, 4.35048166343144, 5.632460347243717, 5.913992668901171, 4.5097465344837735, 2.0821534267493655, 3.1867604511124745, 6.803603104182652, 7.11740459714617, 1.7613028777497155, 0.34953995953713146, 0.7777611027870859, 1.9498799187796456, 2.8583477650369917, 3.776606491633824, 6.402004608086177, 5.045154307569776, 9.729845626013619, 10.632692813873291, 8.522756797926766, 10.447062134742737, 3.9995854752404347, 0.5589545667171478, 0.25832189140575273, 0.25135284821902004, 0.3315686881542206, 0.8236130795308522, 0.7968872679131371, 0.2768548269357, 0.17815952003002167, 0.42657922421182903, 0.11733239756098815, 0.2356794492474624, 0.13515479836080754, 0.1963629996670144, 1.2117828790630614, 1.4574915915727615, 0.6980199930923325, 1.5155136095626014, 0.9708552871431623, 2.39767763870103, 5.098000134740557, 3.4648362611021315, 4.832389175891876, 5.696563124656677, 5.190398148127964, 4.756833595888955, 1.6613801824195045, 1.3466417683022363, 21.453780821391515, 59.104531696864534, 69.78506633213588, 46.297834396362305, 33.214741230010986, 44.7766444342477, 56.15833568572998, 80.63326099940709, 67.57309341430664, 36.64897871017456, 2.5543395408562253, 0.28752367730651585, 0.13323188440075942, 0.2628989358033453, 0.16711972813521112, 0.23117891645857266, 0.12709796854427882, 0.09526186542851584, 0.13941032572516374, 0.08669356948563031, 0.16762495173939637, 0.11444752450500216, 0.1416881542120661, 0.240506683077131, 0.1389715714114053, 0.13367236219346523, 0.1388742694897311, 0.14170412692640508, 0.2052233370819262, 0.11508122192961828, 0.10424256138503551, 0.11225934406476361, 0.21533475736422197, 0.18241066405815737, 0.21797219584030764, 0.07660557223217827, 0.0858059778277363, 0.0908363786126886, 0.04375046897413475, 0.18447754957846232, 0.13963337375649384, 0.10020462663045951, 0.09710707355822835, 0.12958823277481965, 0.17840117349156312, 0.20096449846667902, 0.086968233675829, 0.12974095743681702, 0.09105492117149488, 0.09640279492097241, 0.07445597329310008, 0.1595935941274677, 0.16272442255701336, 0.09928699622728995, 0.09177311656198331, 0.13447643976126397, 0.09064017342669622], [0.04856344339038644, 0.015450071044532316, 0.04128919854494078, 0.032842323050967286, 0.03813074356211083, 0.09208778717688151, 0.08188257299895797, 0.009986937095943307, 0.10078941525093146, 0.03440712319154825, 0.016801563523975865, 0.04824308665203197, 0.07330443829830204, 0.027851916816351668, 0.0500871310941875, 0.021693680568465164, 0.05381563013153417, 0.04066082762022104, 0.03701247713927712, 0.027189347726692046, 0.060097493763480864, 0.0213697258981743, 0.05155800502481205, 0.04042496884773884, 0.033543741663119624, 0.029167390960667814, 0.04017971915059856, 0.039080217613705566, 0.014590553773034896, 0.03200983182926263, 0.036281297981206856, 0.054096815043262074, 0.01777383974487228, 0.029749845420675616, 0.03345582727342844, 0.0018574128542760654, 0.07138598231332642, 0.016264562428529774, 0.02427416281508548, 0.039434239867010286, 0.018844393281532184, 0.03297298175415822, 0.061705078929662704, 0.051079264642404656, 0.022429382162434713, 0.09625935261803013, 0.07815166855497019, 0.04544626030006579, 0.049137243136231384, 0.07155475432851485, 0.06882596468286854, 0.06692091654986143, 0.28979215558086124, 0.05392388021573424, 0.44859860837459564, 1.2083355954715183, 29.337761061532156, 57.49309853145054, 56.13227646691458, 51.308986391339985, 49.394438062395366, 35.84475251606533, 10.247084294046674, 13.35029309136527, 38.596697739192415, 50.689856733594624, 52.313900879451204, 33.422721658434185, 16.232418026242936, 4.346962835107531, 0.5006531008652279, 0.8777778159294809, 2.1892599080290114, 4.822430235998971, 1.4603836706706455, 2.6066935658454895, 1.5465266768421446, 1.0913234800100327, 1.2168689604316438, 0.5580635688134602, 1.8262000296797072, 2.37446066737175, 1.7561937804733003, 2.5477411406380788, 2.105850040912628, 5.254064057554517, 4.45272787979671, 4.13065151657377, 2.070979420627866, 1.712617610182081, 2.832368233374187, 1.1808532987322127, 3.008486828633717, 0.7249689070241792, 0.1245330518909863, 0.5697488103594098, 0.4152928798326424, 0.1647113902228219, 0.08387387650353567, 0.3016660570033959, 0.718520707317761, 0.3301788584462234, 0.4477158614567348, 0.32024494292480604, 0.7297769518835204, 0.6558053983109338, 0.32556628595505444, 1.8971487368856157, 0.846809477678367, 1.6782343408891132, 0.4323852855179991, 1.5410850431237901, 2.6256612794739858, 1.4078167485339301, 0.05273761779868177, 1.5753180576222283, 11.544274755886622, 31.522333758217947, 53.88536105837141, 45.37542976651873, 24.364148446491786, 21.795687777655466, 22.170520509992325, 44.88589096069336, 55.3334698677063, 51.609586306980674, 19.38196870258876, 2.54917442372867, 0.04719538787113769, 0.15651281444089754, 0.026735105851132954, 0.03633352821426732, 0.04956208069675735, 0.025506614807194898, 0.037676644178905656, 0.05882344927106585, 0.005801987551551844, 0.03136527784434812, 0.05267103994265199, 0.006334726598912052, 0.01734066807797977, 0.017655920536656464, 0.02702522706905646, 0.04399616650438734, 0.007824631740472146, 0.01687263837084174, 0.05047161617715444, 0.012310294434428215, 0.0381545058584639, 0.024562821790043796, 0.03360586154407688, 0.040146827165569575, 0.04054132064006158, 0.04575511247717908, 0.07009694898234946, 0.04209683842158743, 0.054880343178021054, 0.03572511300444603, 0.018138080735557845, 0.027206999815202186, 0.03601253026032022, 0.031240169557609727, 0.03682535753718444, 0.021764221069003855, 0.060576865183455605, 0.026092833440218653, 0.03904595498793891, 0.013663096486457756, 0.05477249342948198, 0.01907292048313788, 0.015398975661290544, 0.047874838912061284, 0.07062163297086954, 0.05074609037754791, 0.05115496540176017, 0.01970386814459094, 0.03487858289320554, 0.05080178453187857, 0.01431297357859356, 0.019135364364566546, 0.01098101379882012, 0.03564988721960357, 0.07111358443009001, 0.027466488569708805, 0.043496103159018924, 0.07770882946039949, 0.006370306006699268, 0.05574363649689725, 0.04923443988497768, 0.0232221706038607, 0.03655810973473957, 0.02345087592090879, 0.03275808971375227, 0.012532401846588721, 0.037217611846114905, 0.014650997672496098, 0.02416768709995917, 0.014047780040917652, 0.04994349880144, 0.03960261833188789, 0.03356427413278392, 0.04271320606182728, 0.04714584802942617, 0.04911307371886713, 0.03695695261870112, 0.14244995904820307, 0.024971399955185394, 0.05024279381281563, 0.020693051761814525, 0.03876058690782104, 0.03591321308964065, 0.024421174212225845, 0.07320231199264526, 0.021438427568812455, 0.11826522036322526, 0.006833338727509337, 0.03587312184806381, 0.04823111390162792, 0.030802524648606777, 0.05282022604452712, 0.044131934576268704, 0.02942417575312512, 0.07233994826674461, 0.03877518219607217, 0.07513095957360097, 0.0805166820064187, 0.029994148561464887, 0.0846852958202362, 0.2282588817179203, 0.0797353217910443, 0.4461152787719454, 2.833810635975429, 38.13514975139073, 68.89166695731026, 63.251973969595774, 46.91805839538574, 35.083462715148926, 16.406687532152446, 18.791948522840226, 42.075831004551475, 79.44632802690778, 82.49118150983537, 48.211250168936594, 17.80493606839861, 2.9276792790208543, 1.6530221509081977, 0.9827626539128167, 1.6438575855323245, 2.52380524788584, 1.1419102741139275, 0.6768656596541405, 0.7950943612626621, 1.4354127134595598, 1.4761129809277398, 1.5440355305160796, 0.48936830354588373, 0.9210681872708457, 0.4290550085050719, 3.036935576370784, 0.6618468027029718, 1.4629418019737517, 3.0605865929807936, 2.4211473507540564, 3.516986834151404, 4.732463223593576, 2.1126464647906165, 2.879905636821474, 2.6816876445497786, 1.4982972762414386, 1.6485088616609573, 0.22189410110669477, 0.7729159284915242, 0.3688084270272936, 0.7167408285396439, 0.45391229752983364, 0.3623758336263043, 0.5288982338138989, 1.1479042896202631, 0.9002225601247379, 1.7142579278775623, 1.6003005227872302, 2.5324585778372626, 1.9180196055344172, 1.94052677495139, 1.255244946905545, 0.3351758617375578, 1.6494342748607909, 1.5058560477835792, 0.6156280913523265, 1.3478818046195167, 0.09969080598758799, 1.2881068864039011, 3.8384975705827986, 13.130024773733956, 48.95903614589146, 73.87584604535783, 48.046393735068186, 29.65078088215419, 18.622813735689434, 35.757163524627686, 60.847688811165945, 65.07040786743164, 30.077876227242605, 4.776100082056863, 0.09099837884839092, 0.07791005580552987, 0.015603684587404132, 0.05824480139251266, 0.08074143316064562, 0.004209709287221942, 0.01817459609758641, 0.01667792087287775, 0.05507109633513859, 0.0545330146726753, 0.08901579451880284, 0.03274178112457905, 0.04234185402414628, 0.011878897984778243, 0.09299648127385549, 0.02026409549372537, 0.03517666332689779, 0.0376542321672397, 0.017295927175187638, 0.05492975070540394, 0.059796420990356376, 0.015039112917812807, 0.05151673313230276, 0.015429621695407798, 0.05825866386294365, 0.04772963241807052, 0.055630578992090056, 0.024179893944944655, 0.026345357032758848, 0.07924496488911764, 0.017868978836174523, 0.06019220368138381, 0.020402073893429976, 0.029520765213029723, 0.035691148934087584, 0.01293575783659305, 0.10278721233563763, 0.009036379084656281, 0.03610729446102466, 0.03570064503167357, 0.0472999060127352, 0.04365462590275066, 0.02865150078598942, 0.02766493461760027, 0.06354774933840547, 0.04382985417864152, 0.032306724826672246, 0.02327545595887516, 0.0789980392104813, 0.1288429434810366, 0.13291518496615545, 0.1498669439128467, 0.10559339568551097, 0.15182782869253839, 0.09675450676253863, 0.1047032323798963, 0.1910664095942463, 0.1896523968981845, 0.07615450929318156, 0.13405409242425645, 0.22303365995841368, 0.11381269392690488, 0.18187059089541435, 0.10466876958629914, 0.14263396417456015, 0.13228398455040796, 0.12223482664142336, 0.12407250303242888, 0.11874544673732348, 0.10949239360966853, 0.1264189721218177, 0.09693794191948005, 0.08771538215556315, 0.08955828326621226, 0.13096039343093122, 0.11898210618112769, 0.107709841403578, 0.21232512885970728, 0.09583448791610343, 0.10432108824274369, 0.11206623978380646, 0.16832704549389227, 0.11305133692388024, 0.11374794133007526, 0.2946714466171605, 0.14580861239561013, 0.19116899051836558, 0.07666898811502115, 0.1321262658706733, 0.14355639182031155, 0.21034896347139562, 0.1597350686788559, 0.14045450969466142, 0.23447461532694952, 0.15502185587372097, 0.19710919819772243, 0.11411568016878196, 0.22409198459769997, 0.23620539531111717, 0.25359928767595974, 0.3570457510650158, 0.15081143751740456, 0.8400080054998398, 3.247596706662859, 43.62951421737671, 82.82487569536481, 74.47943605695451, 64.6006749016898, 66.18498229980469, 50.02778720855713, 19.339610746928624, 24.140821184430802, 55.281639780317036, 65.40786102839878, 68.28385938916887, 43.49158900124686, 20.664027724947246, 5.97557715858732, 0.7524457754833358, 1.4681665216173445, 3.9715065019471303, 7.060607850551605, 3.3964816204139163, 6.436718676771436, 5.1596788593700955, 6.276265663760049, 7.245977972234998, 4.210255725043161, 9.62110458101545, 10.289569054331098, 14.52419298035758, 12.386989627565656, 12.286103521074567, 17.1114467893328, 17.996353728430613, 17.8153965813773, 13.596160309655325, 12.900281718799047, 12.865134256226675, 8.89507862499782, 8.39101721559252, 2.6638776745115007, 0.17024135562990392, 0.7573425727231162, 0.7123474500008992, 0.8357785610216004, 0.7592843770980835, 0.8566306478210858, 1.6037949238504683, 2.3803219071456363, 1.8170337272541863, 4.827613157885415, 4.03156499351774, 7.709763714245387, 4.711441448756626, 5.953031556946891, 5.748072726385934, 5.0009767924036295, 4.336872747966221, 6.441989753927503, 5.1462753500257215, 2.5194565440927232, 0.19266946214650357, 2.296867093869618, 16.576063769204275, 40.96339314324515, 68.92269761221749, 56.78293704986572, 37.30043486186436, 33.833440099443706, 35.55511685780117, 58.61769226619175, 71.53208664485386, 73.3288769040789, 34.233180386679514, 6.481624450002398, 0.2260149528405496, 0.3366309936557497, 0.05927394902599709, 0.10467955150774547, 0.1984390861221722, 0.10843028274497815, 0.12899859941431455, 0.20917773060500622, 0.22736519681555883, 0.12850515517805303, 0.1843351386487484, 0.12742438460034983, 0.09893746926848378, 0.1009415088753615, 0.07875101853694234, 0.10162078349718026, 0.09241895976343326, 0.0956947368436626, 0.14316987113228866, 0.2474305901144232, 0.13791699228542192, 0.09898265291537557, 0.27769504327859196, 0.13574482527162346, 0.16190937986331327, 0.11234634582485471, 0.16114309669605323, 0.16141248866915703, 0.10127740406564303, 0.1734632570296526, 0.0960785366062607, 0.1132860489721809, 0.1443674854402031, 0.11990803506757532, 0.0920092263924224, 0.09853755429919277, 0.17456443794071674, 0.13402176701596805, 0.09714743282113757, 0.12861655705741473, 0.15952226652630738, 0.10688568598457746, 0.1930428192551647, 0.1141727449638503, 0.1711076684296131, 0.15603044389614038, 0.10572316550782748, 0.07911169382610492], [0.05738988119576659, 0.02311946584710053, 0.011022450236071433, 0.03338101878762245, 0.047616262787154744, 0.09391380633626666, 0.08618571995092289, 0.07076048159173556, 0.03150090342387557, 0.035646606502788405, 0.05058138617979629, 0.020001122461897985, 0.040448578473712714, 0.04216595060591187, 0.02480958970928831, 0.04253369622996875, 0.012715350154654255, 0.09334039674805743, 0.06470421728278909, 0.0427537620998919, 0.0583885151094624, 0.027670188174982156, 0.030932050198316574, 0.03180131123268178, 0.061606528503554206, 0.02906676082472716, 0.04177214584446379, 0.033151989470102956, 0.09985589355762516, 0.03064239038420575, 0.03413644200190902, 0.03533350330378328, 0.039770766094859154, 0.02215142877373312, 0.06287057138979435, 0.03120069917557495, 0.07068543561867305, 0.04032159743032285, 0.06519210431724787, 0.05206162728635328, 0.012777453920404826, 0.015126693129007305, 0.026951756993574754, 0.04730338350470577, 0.050269205788416524, 0.01094212186788874, 0.01759703387506306, 0.04868137616930263, 0.07161057740449905, 0.025229229691571424, 0.06505205468939883, 0.06857232829289776, 0.09779727259384734, 0.04268064995163253, 0.057013999936836104, 0.17385901936462947, 0.34497938996979166, 5.952609019620078, 39.90274020603725, 58.565386227199006, 50.97913455963135, 46.26054688862392, 50.70269700459072, 33.28602627345494, 17.761468138013566, 8.762455752917699, 22.601484264646256, 45.38715137754168, 37.42065954208374, 52.942035402570454, 54.717459951128276, 45.9392100742885, 35.758886677878245, 24.922424043927872, 11.73876873084477, 5.245778330734797, 1.6214732038123267, 0.1782428984131132, 0.10908708428697926, 1.0614655507462365, 1.2170364771570479, 0.8293969663126128, 3.4325002133846283, 2.3406683206558228, 1.5864883725132262, 2.544653752020427, 1.2697105535439082, 0.736365906894207, 1.6464792277131761, 0.4435682211603437, 1.1120021875415529, 1.6027227299554008, 1.4240596826587404, 1.7765971656356538, 1.2169867541108812, 3.163932144641876, 1.8641654210431235, 0.56209254690579, 0.28023889820490566, 0.28539549293262617, 2.932767314570291, 2.395115924733026, 2.8138482442923953, 1.0818444000823157, 1.7087646169321877, 3.5403584028993333, 2.425800689629146, 1.1371995040348597, 2.315543851682118, 0.8696348528776849, 0.2519059899662222, 2.24984125154359, 10.353332672800336, 25.410866771425518, 38.09757041931152, 56.120179653167725, 45.26063857759748, 86.91682270595005, 47.26017032350813, 12.023201056889125, 35.873983587537495, 52.80123015812465, 58.926435470581055, 58.57463427952358, 34.46990203857422, 5.682778332914625, 0.17092590246881756, 0.14214326121977397, 0.023158250908766474, 0.04786366004762905, 0.12221740186214447, 0.059716557418661456, 0.049072256444820335, 0.07967683207243681, 0.057414267744336805, 0.04853389997567449, 0.051773107411073785, 0.13767364248633385, 0.029276787769049406, 0.04793104196765593, 0.020730780005188923, 0.023489779726203, 0.11292150603341204, 0.051317128485866954, 0.02827107673510909, 0.016321304919464246, 0.019808264149885093, 0.04363891781706895, 0.021097302569874694, 0.043485857280237336, 0.0350480877262141, 0.04765446770137974, 0.05357896390237978, 0.017684364724638205, 0.013991731352039745, 0.058766601607203484, 0.07584174536168575, 0.03755860283438649, 0.032103778395269594, 0.02948152892557638, 0.015180687553116252, 0.03809160566223519, 0.00851421500556171, 0.025481454728703414, 0.0869012079866869, 0.0391149416432849, 0.12323114675070558, 0.014473730398874198, 0.04979662989665355, 0.027708494869459952, 0.03408273595518299, 0.04975838427032743, 0.058900870116693635, 0.0487437437155417, 0.06789018346795014, 0.0542613156805081, 0.043193659745156765, 0.10226687775658709, 0.058197839983872006, 0.023758406651073267, 0.04938451486772724, 0.03045609520216073, 0.010200426265198206, 0.0988188274204731, 0.04101553519389459, 0.011215487511695495, 0.031013508327305317, 0.017618020963189856, 0.04658441797697118, 0.01504865990552519, 0.02821726042644254, 0.04634497993226562, 0.012382196245848067, 0.11525107281548636, 0.018592132621311715, 0.030968209329460348, 0.04123036616614886, 0.031262408542845926, 0.02460251608863473, 0.03167398413643241, 0.07841601222753525, 0.034958188621593375, 0.032477562980992455, 0.059684062376618385, 0.014496849783297096, 0.04998085554689169, 0.007599769476135927, 0.06058745711509671, 0.05472677034725036, 0.03592814425272601, 0.030649060383439064, 0.024313584003331404, 0.035098007547536066, 0.018114810377093296, 0.03448438458144665, 0.04311984870582819, 0.010214710275509527, 0.008394809805655053, 0.02295740623958409, 0.03666538612118789, 0.028165886843843118, 0.0493692749712084, 0.014352966432592698, 0.023688028998939053, 0.09893381875008345, 0.06391624135098287, 0.0965038084291986, 0.01191724878403225, 0.013712724537721701, 0.09641377361757414, 0.04417928953522018, 0.23751958193523542, 0.08697244059294462, 10.144167576517377, 52.82576772144863, 71.96275683811733, 59.85101836068289, 48.36220325742449, 24.53777003288269, 7.822625909532819, 16.678247451782227, 20.387689181736537, 51.76216874803816, 83.65121105739048, 77.25747176579067, 72.1637682233538, 53.288719245365684, 38.01933022907802, 20.74090780530657, 3.6053394760404314, 1.8933843331677573, 1.830301203898021, 1.8651475054877145, 0.5241386634962899, 0.1326188144407102, 0.32536690522517475, 0.7120728875909532, 0.8534601522343499, 0.17634981285248483, 1.1353587742362703, 0.8498106109244483, 1.410829552582332, 0.43635642528533936, 1.5336167067289352, 1.6393940193312508, 0.6008269627179418, 1.0771043172904422, 0.7717153557709285, 0.423017322484936, 1.2284991592168808, 0.6683959141373634, 1.1374837287834711, 0.4695446587034634, 0.9948095274823052, 0.2563887451376234, 1.0105543626206261, 0.036669240200093815, 0.4637216883046286, 0.8466195964387485, 1.513705340879304, 1.9021518741335188, 2.313694328069687, 1.4607381373643875, 1.513458462698119, 1.2518711622272218, 0.8257353742207799, 0.8170241245201656, 1.3478782219546181, 1.8928434593336922, 9.897994637489319, 23.235519545418875, 52.05452810014997, 62.37308243342808, 98.78971685682023, 61.65739713396345, 15.251874344689504, 20.521907533918107, 41.55756139755249, 58.74491378239223, 69.56372451782227, 46.66508838108608, 8.935042926243373, 0.1203976252249309, 0.13580699265003204, 0.0965328293719462, 0.0675369720639927, 0.12861108806516441, 0.046620458364486694, 0.07573881838470697, 0.05029772800792541, 0.0758938297097172, 0.0752707649288433, 0.024786884231226783, 0.01303117343091539, 0.022841088374012282, 0.059564538433083465, 0.053677432904286046, 0.041070418498877964, 0.014924145336928112, 0.043494552706501315, 0.05282460938074759, 0.03452550719625183, 0.016617868827389817, 0.025761214716892158, 0.07250287809542247, 0.04114955943077803, 0.06852286987538848, 0.03267008711450866, 0.03155361541679927, 0.04796902296532478, 0.017623749495084797, 0.040779516965683014, 0.021904246948127235, 0.03545630117878318, 0.04701652604022196, 0.0191311455730881, 0.048943002309117994, 0.03568876388349703, 0.028105995950422118, 0.03677238430827856, 0.005699571596258985, 0.02524702766511057, 0.02179601552364017, 0.017218119564599225, 0.044449485572321076, 0.03433100174048117, 0.04461556380348546, 0.04269995088023799, 0.017696997350347892, 0.026437568245455623, 0.06274846222783838, 0.07917411904782057, 0.1460175197571516, 0.1229495954300676, 0.16316154838672706, 0.10429083236626216, 0.15482371007757528, 0.18706289013581617, 0.208888566121459, 0.1853938296969448, 0.13978966751268931, 0.12713279096143587, 0.1012808849502887, 0.1307117917707988, 0.1354248145861285, 0.0707030368170568, 0.104850874814604, 0.10037009418010712, 0.09336443045841795, 0.22826783838016645, 0.20085425009684904, 0.2582838663033077, 0.16611941824001925, 0.17027212040764944, 0.1559045213673796, 0.14669304208031722, 0.16832510488373892, 0.14016447668629034, 0.15573389695159026, 0.11873539084834711, 0.18641208005802973, 0.16740662631179604, 0.12781845059778008, 0.13559994447444165, 0.11280729501907315, 0.1274773646146059, 0.13925389626196452, 0.12390073867780821, 0.23953008119549068, 0.06584967260382005, 0.2058143817952701, 0.08905737514474563, 0.11376060957887343, 0.1029542540865285, 0.1274749490299395, 0.11125321233911173, 0.10223293064960412, 0.1790624601500375, 0.1633490818951811, 0.10055732234780278, 0.2078501089875187, 0.1805969128119094, 0.21822026824312551, 0.16640453865485533, 0.31298993793981417, 0.10040413628199271, 0.23250819370150566, 0.24553359619208745, 0.40399003348180224, 11.012118305478777, 64.2631036213466, 85.91833182743618, 71.7277409689767, 62.762570653642925, 74.82142639160156, 49.382740770067485, 28.114593233380997, 15.73304751941136, 36.10058866228376, 59.828415870666504, 53.836539540972026, 68.94611998966762, 67.80737972259521, 61.141680989946636, 45.85208313805716, 31.202716623033794, 15.082114219665527, 6.225890355450766, 1.8234576625483376, 0.2772217515323843, 0.11062759626656771, 1.3338399295295988, 1.8370372653007507, 1.6688531871352876, 6.366605707577296, 6.281944079058511, 4.0500706519399365, 5.2843347532408576, 3.647979702268328, 3.9334373218672614, 7.91834603037153, 6.690123822007861, 7.381666302680969, 9.94752139704568, 9.902325102261134, 7.881032466888428, 7.331474253109523, 10.026363474982125, 7.887050475393023, 4.337731719017029, 7.0869011368070325, 5.625257670879364, 6.847996013505118, 10.39305465562003, 9.147352950913564, 7.878270557948521, 6.2389742476599555, 8.695898958614894, 5.999677419662476, 4.4493584377425055, 4.188759301389966, 1.8505035255636488, 0.5587213678019387, 2.6969150560242787, 13.277465547834124, 35.27891901561192, 51.51179041181292, 71.06311103275844, 61.01010990142822, 94.17580032348633, 60.906394141060964, 20.755697046007427, 53.6133599281311, 64.47080612182617, 78.51398399897984, 75.60751778738839, 54.178036553519114, 10.1980664900371, 0.23233888564365252, 0.6063504006181444, 0.15558988467923232, 0.20121341225292, 0.2040155040366309, 0.16155441105365753, 0.1503891037510974, 0.08533820935658046, 0.16332834586501122, 0.10872615793985979, 0.12013032313968454, 0.25229088217020035, 0.15122295543551445, 0.17787271684833936, 0.10063003416040114, 0.15468788093754224, 0.161126133320587, 0.17585851278688225, 0.14169470886034624, 0.23172950691410474, 0.16065565070935658, 0.2404685222676822, 0.18501534286354268, 0.11092345789074898, 0.18377313523420266, 0.16767285631171294, 0.06485956787530865, 0.10008587621684585, 0.11348045604037386, 0.21462936592953546, 0.11723386070558003, 0.08206813197050776, 0.0948020222463778, 0.07433287347001688, 0.13591825882239, 0.11103413373764072, 0.11127679821635995, 0.06968874231513057, 0.1606707956109728, 0.15465244783886842, 0.2055979155536209, 0.08826285813535963, 0.1761619129351207, 0.1534499752202204, 0.08770224571760211, 0.086930574982294, 0.1585967040487698, 0.10069864762148686, 0.3130219376512936, 0.1512083262205124], [0.03631704320598926, 0.03163145016878843, 0.13355568131165846, 0.011615225213712879, 0.028277539781161716, 0.04192754054175956, 0.018282947962039282, 0.03941714417721544, 0.019851222201915722, 0.020764828892424703, 0.028562921431979964, 0.017158528922923973, 0.016883143789267967, 0.07267251185008458, 0.0167710226627865, 0.018447974463924766, 0.06530206770237003, 0.025958127275641476, 0.03581522924027272, 0.019818493065291216, 0.06361518214855875, 0.0352947860956192, 0.029861393185066323, 0.014236921677365899, 0.046414845290460756, 0.08467735017516784, 0.05083940590598753, 0.009938089359950806, 0.07753542983638388, 0.07001372666231223, 0.02408670903449612, 0.04063508400161352, 0.023797235817515423, 0.08452343807688781, 0.023245132228891765, 0.028759279288351536, 0.006015205306799284, 0.07397643902472087, 0.03521703616050737, 0.03696945123374462, 0.04770858086911695, 0.02305381079869611, 0.024341380190370337, 0.04459176418770637, 0.11993460649890558, 0.0352165204738932, 0.048931070270815065, 0.03417504046644483, 0.08045788016170263, 0.02437214836079095, 0.06938382224845034, 0.02912803253691111, 0.17839684443814413, 0.05747062007763556, 0.08401851302811078, 0.09820088557898998, 0.07545739598572254, 0.4056401220815522, 0.29892583404268536, 12.504231793539864, 47.46554517745972, 62.045745849609375, 55.340077604566304, 54.526214259011404, 55.35892111914498, 62.432017053876606, 34.741670404161724, 16.302813700267247, 7.801677959305899, 13.78872355393001, 14.549401913370405, 23.138663394110544, 20.98881605693272, 35.21729891640799, 52.76393570218767, 56.30421658924648, 53.137172085898264, 54.97099624361311, 45.25257519313267, 43.72838013512747, 34.109241894313264, 26.546225002833776, 20.364702803747996, 14.400901538985115, 9.273084078516279, 6.3562741705349515, 2.802085812602724, 1.505094785775457, 0.4339724874922207, 0.27198525252086775, 0.18244570360652038, 0.4364824428090027, 0.5883383899927139, 0.3033163627343518, 0.5755701522741998, 0.781995378434658, 0.2840752809175423, 0.5203311049512455, 0.15186438815934317, 0.15124739626688616, 0.46321332986865726, 0.37499321943947245, 0.18029796385339328, 0.8117154293826648, 2.952054428202765, 5.451281292097909, 9.443288019725255, 13.11582612991333, 26.853179046085902, 41.163303239004954, 45.924135957445415, 52.996641295296804, 45.87062093189785, 46.975540842328755, 39.23311104093279, 26.901467289243424, 24.547087567193167, 25.792913470949443, 31.811066150665283, 63.442952156066895, 56.537422452654155, 48.759515149252756, 34.74233395712716, 11.881320578711373, 0.22311009014291422, 0.2736740176166807, 0.03063788151900683, 0.09867412982774632, 0.03888424652229462, 0.022858345215874057, 0.04360594440783773, 0.013953708794101008, 0.12122520724577562, 0.06008530727454594, 0.0557895495689341, 0.014480581906225, 0.06053153904420989, 0.011081632060397948, 0.022433348199618713, 0.06705421475427491, 0.012754043614092683, 0.0603444262274674, 0.010042994266508945, 0.03281275928020477, 0.03631934343970247, 0.01659093777249966, 0.022770573318536793, 0.027879699432690228, 0.01533046567679516, 0.028399866074323654, 0.04444354160555771, 0.0816685426980257, 0.08617026292319808, 0.024436956936759607, 0.09320837418947901, 0.0350774038316948, 0.009602676777701293, 0.05868293145405395, 0.02242545174833919, 0.06904163703854595, 0.03403641236945987, 0.0465948029554316, 0.03772238761718784, 0.004170525586232543, 0.03394381269546492, 0.009101471797163998, 0.03621887954484139, 0.05270881737981524, 0.027778497630996362, 0.02559643588028848, 0.04311236785724759, 0.09663544422281639, 0.039892457957778654, 0.01675752320859049, 0.021807355540139333, 0.0175025309103408, 0.01840092145305659, 0.07732194914881672, 0.01532909503605749, 0.03672399797609874, 0.014044955638902528, 0.04300249268167785, 0.02836877729610673, 0.03552636670480881, 0.027159804311980094, 0.05443607915991119, 0.007861228526702948, 0.03064996962036405, 0.04984184747029628, 0.07607879835580077, 0.0498514758822109, 0.058206389525106976, 0.07607841159084014, 0.017202891542443206, 0.02899066312238574, 0.05035063338332942, 0.05373603458117161, 0.1155056320130825, 0.07015043111251933, 0.049838926377041, 0.05028809620333569, 0.05953281692096165, 0.006439327436964959, 0.04025807976722717, 0.042909265362790654, 0.03446503954806498, 0.049064304014401774, 0.054448367429098914, 0.05244153565061944, 0.06330697118703808, 0.04293676299442138, 0.05520510360864656, 0.054778898800058026, 0.055698690337261984, 0.022743347100913525, 0.036443420353212526, 0.06200505926140717, 0.03750029971290912, 0.03344553050452045, 0.06603834605110542, 0.09547548182308674, 0.023741840218592967, 0.045230520090886524, 0.019651698979682157, 0.05767312885395118, 0.03660676069557667, 0.046075506534959586, 0.03238469867834023, 0.06312122222568307, 0.0911981463432312, 0.08558288229895489, 0.05689588734613998, 0.027002065276194896, 0.5053894381437982, 0.5420165956020355, 19.66567059925624, 61.30604062761579, 72.15930053165981, 61.245688574654714, 51.20256083352225, 35.631029401506694, 21.610811846596853, 18.87303400039673, 19.21491663796561, 11.060112118721008, 28.661701338631765, 42.1479046685355, 57.95368766784668, 59.392221859523225, 74.80930178506034, 79.25381428854806, 61.54925537109375, 57.657683985573904, 43.27997466496059, 27.73051244871957, 14.491563371249608, 10.998136792864118, 7.7404434851237705, 1.2809620755059379, 3.07805957538741, 1.6486076563596725, 3.753125488758087, 1.3050290069409778, 1.5624525994062424, 0.8040137312241963, 0.30963903346232, 0.3463692468191896, 0.4069549600992884, 0.29355873061077936, 0.3193354888686112, 0.23127610981464386, 0.10582655388861895, 0.2748025027768952, 0.46887312616620747, 0.4168177108679499, 0.42512835349355427, 0.35398498816149576, 0.4024918553020273, 0.38573923281260897, 1.3978405467101505, 3.0324394404888153, 2.913994801895959, 2.814425596169063, 5.095143122332437, 6.655218243598938, 16.404323407581874, 29.820987428937638, 50.421239376068115, 62.67181328364781, 71.64313275473458, 61.3476116997855, 45.65342024394444, 29.184994493212017, 41.99085800988333, 36.788918903895784, 40.48701422555106, 59.27064228057861, 62.60559695107596, 48.73239285605294, 16.1837181023189, 0.746726213821343, 0.1823554720197405, 0.03291393902951053, 0.04206870635971427, 0.04858539399823972, 0.07294221594929695, 0.009860718556280648, 0.034499777148344686, 0.030864512215235403, 0.06183074361511639, 0.017299358866044452, 0.052377604081162384, 0.05540291352995804, 0.01708212079081152, 0.03059734244431768, 0.03147718183962362, 0.02017861365207604, 0.05712054350546428, 0.04585019898201738, 0.09143583716026374, 0.019895902036556175, 0.022193626866542866, 0.018341673471565758, 0.03060964767688087, 0.0436737843390022, 0.02363590563514403, 0.05186403788892286, 0.026674183584483604, 0.04618713911622763, 0.021570031132016863, 0.02705870259420148, 0.02965112536081246, 0.02951486874371767, 0.05058081281770553, 0.07850225402840547, 0.051389731732862334, 0.02200425961720092, 0.03982241618047867, 0.03447267985237496, 0.04177237993904522, 0.003958798487604196, 0.04954885604924389, 0.03836166938500745, 0.012034403792183315, 0.048759353413645706, 0.023799229014132704, 0.011954233183392456, 0.02281884938877608, 0.030439762864261866, 0.02746754029898771, 0.04336495930328965, 0.08925066263015781, 0.15987571541752132, 0.23257317021489143, 0.243031484740121, 0.2007219357682126, 0.14076599798032216, 0.13372754066118173, 0.09429069861237492, 0.10386273783764668, 0.11095003610742943, 0.11242733576468059, 0.10459339791642767, 0.09525647786046777, 0.1561019750578063, 0.15621343121996947, 0.08642947008567196, 0.1328882606966155, 0.16592086532286235, 0.0843043119779655, 0.16391168242054327, 0.11821181965725762, 0.09849775822034904, 0.1825654786080122, 0.2305505930313042, 0.15213680639863014, 0.10774895894740309, 0.1908765419253281, 0.09700703035507884, 0.1835310882223504, 0.19118296833974974, 0.1345217116177082, 0.12993781401642732, 0.2710507740931851, 0.10810723900794983, 0.19078333835516656, 0.16155299970081874, 0.15401991749448435, 0.11858159410102026, 0.13113749107079847, 0.12169817329517432, 0.06393164409590618, 0.22537360154092312, 0.09692305486117091, 0.0858655192756227, 0.11930485814809799, 0.1741819070386035, 0.1924248095601797, 0.17976486603064196, 0.15588040623281682, 0.16321842319199018, 0.22812683880329132, 0.1996693243937833, 0.08688221579151494, 0.21197290133152688, 0.13265587602342876, 0.2735627650150231, 0.12895125124071324, 0.41683339859758106, 0.5242667709078107, 0.8326794473188264, 23.312840836388723, 76.82340390341622, 90.24355070931571, 74.1504944392613, 75.08281067439488, 74.77470670427594, 85.69539192744664, 49.710046086992534, 29.12460422515869, 14.762990406581334, 25.293035745620728, 22.221271889550344, 30.95146976198469, 28.466519492013113, 47.646632603236604, 66.24627235957554, 71.41380746023995, 67.05199936458042, 68.93991524832589, 57.581820079258506, 58.945695877075195, 46.67978034700666, 38.79811906814575, 29.319334438868932, 22.368208919252666, 13.262255941118513, 9.682525788034711, 3.6518029485430037, 2.3057948776653836, 0.7244082742503711, 0.4438984234418188, 0.28464530461600845, 0.7515971724476133, 0.8494025128228324, 0.4324745535850525, 1.027608498930931, 0.9047066452247756, 0.5570039142455373, 0.658131796334471, 0.38348017260432243, 0.2671245533440794, 0.4188072569668293, 0.44104111247829025, 0.47247099024908884, 1.7539876188550676, 4.538464307785034, 7.586903929710388, 13.363968883241926, 20.54139028276716, 35.95657682418823, 54.377085072653635, 64.33742850167411, 73.60367121015275, 66.5921745300293, 67.91228362492153, 55.7159160886492, 42.27770396641323, 34.92912585394723, 40.74757514681135, 45.56536224910191, 82.19217273167202, 73.22859355381557, 70.12342275891984, 56.539729254586355, 19.226127556392125, 0.5979930205004556, 0.5152645111083984, 0.09574758793626513, 0.16691748398755277, 0.10158868879079819, 0.1346404416752713, 0.10741318589342491, 0.2143187461686986, 0.1791328378021717, 0.13049566479665892, 0.10676333255001477, 0.11280600580253772, 0.16431345657578536, 0.1868419184216431, 0.07748052278267485, 0.17220172472298145, 0.08982823842338153, 0.1284715269825288, 0.07798687275499105, 0.14866183857832635, 0.13937201563801083, 0.11890472604760102, 0.16413175846849168, 0.20964536336915834, 0.08561658513333116, 0.17636787545468124, 0.1140301169029304, 0.14266424040709222, 0.15037124470940658, 0.08909641804971866, 0.12931752444377967, 0.08472152280488185, 0.09297736015702997, 0.13104287614779814, 0.16897896836910928, 0.14555319824389049, 0.13966967537999153, 0.15496766806713172, 0.18257022835314274, 0.11908008663782052, 0.15898682097239153, 0.15849942926849636, 0.15237692637102945, 0.12814958925758088, 0.09388599318585225, 0.08280165546706744, 0.08722849256758179, 0.12906409161431448, 0.13933590400431836, 0.09779836503522736, 0.13947693072259426, 0.10735819741551365], [0.015299295474375998, 0.04404526869101184, 0.12419999976243291, 0.1022471934556961, 0.029832073686910526, 0.04088772294510688, 0.03338917138587151, 0.02341910860767322, 0.05563920995752726, 0.05635043340069907, 0.04262856899627617, 0.07460021626736436, 0.035321896962289295, 0.018047891557216644, 0.062163978948124816, 0.028333907381498387, 0.031591552309691906, 0.015588987518900206, 0.02355300053022802, 0.059560195808964114, 0.013638824440671929, 0.073352648211377, 0.03739832607763154, 0.026731372212192843, 0.01296673804920699, 0.019714814610779285, 0.0159791434582855, 0.05359310796484351, 0.057053924937333376, 0.08736618767891612, 0.011467983962834945, 0.06599161534437112, 0.025277475227734873, 0.05453227846218007, 0.04717130327065076, 0.08797682848359857, 0.04464556183665991, 0.005468044845786477, 0.060082362432565005, 0.0628951411428196, 0.03167535138449498, 0.03130754469228642, 0.039801751396485736, 0.019259782241923467, 0.0513399476185441, 0.05044798280245491, 0.02118223479815892, 0.07338913982467991, 0.028915440730218376, 0.015703089967636124, 0.06850974700812783, 0.055753767024725676, 0.031105307329978262, 0.04003837012818881, 0.07439189244593893, 0.04241241827341063, 0.15750939239348682, 0.07170093791293246, 0.10858205067259924, 0.5839548909238407, 1.0364436762673515, 23.711646590914043, 54.694280760628835, 68.6303938456944, 53.98721817561558, 50.255069732666016, 56.33713368007115, 55.22306299209595, 64.08721692221505, 47.05154023851667, 32.84943274089268, 40.994715622493196, 37.13019009998867, 15.759374243872506, 23.925847394125803, 26.849871703556605, 11.803599766322545, 14.849695239748273, 29.84996141706194, 40.43042114802769, 36.458500794001985, 37.63816942487444, 37.217928477696006, 44.84778356552124, 47.97567844390869, 43.19663797106062, 46.63782017571585, 41.50143732343401, 35.822883061000276, 37.99852384839739, 30.66352251597813, 29.14097591808864, 29.725748470851354, 26.147733654294694, 29.1677143233163, 33.73275375366211, 30.208749021802628, 33.282639026641846, 36.65087556838989, 39.765040806361604, 25.876682690211705, 40.03631237574986, 49.613695417131694, 54.120790345328196, 46.89611945833479, 46.1195193018232, 46.811438288007466, 47.010938440050396, 55.19085461752755, 52.19233867100307, 55.020120007651194, 41.93848596300398, 27.270282881600515, 28.520896094185964, 30.71216685431344, 40.359268120356965, 51.91868734359741, 55.66467659814017, 61.04605293273926, 56.69406958988735, 34.21954107284546, 8.86546105997903, 0.41241046307342394, 0.3112438773470265, 0.032285995581852536, 0.009702632619467164, 0.023201877317790474, 0.038836304630552015, 0.05716991371342114, 0.037559457788509984, 0.026898044161498547, 0.04664074316886919, 0.02849227575851338, 0.06542276551148721, 0.07404067593493632, 0.06669956485607795, 0.05965434254280158, 0.07537817023694515, 0.03358319168910384, 0.013869008115891899, 0.016973137888791304, 0.012667325142371868, 0.04681600537151098, 0.04301623980115567, 0.035245663552944145, 0.007788451405109039, 0.007245825254358351, 0.054779024329036474, 0.03176563725407634, 0.04336263532085078, 0.022552147807021226, 0.027802994441507117, 0.01859262795187533, 0.019456830507676517, 0.09789905963199479, 0.016233388833435516, 0.03488757348220263, 0.029977473563381603, 0.01603888168132731, 0.03671263590721147, 0.024102802188800912, 0.013834443542041948, 0.04382401877748115, 0.025155612034723163, 0.03763352667114564, 0.03193538296701653, 0.04550199855917266, 0.025863736269197295, 0.047407335069562705, 0.023525094081248556, 0.05252681393176317, 0.020942209820662226, 0.042907433318240304, 0.09576475487223693, 0.05441320235175746, 0.05981721130332776, 0.10785992656435285, 0.025276593132210628, 0.057084045106811185, 0.0727090509608388, 0.016107249173468778, 0.09112498669752053, 0.030069930745022636, 0.0413614794878023, 0.0339831304071205, 0.016877109916614633, 0.03350230013685567, 0.08644181942301137, 0.020810183869408708, 0.01855564270434635, 0.0347906481474638, 0.035545134983424626, 0.02473617561294564, 0.08324750725712095, 0.014671592906649624, 0.012954409067918147, 0.03918108862957784, 0.02863777062988707, 0.03312674457473414, 0.026961692442585315, 0.00865105346643499, 0.03717191590528403, 0.09095765317657165, 0.04674711371106761, 0.05294053030333348, 0.1044665729360921, 0.09296183527580329, 0.010099267720111778, 0.015173683375386255, 0.004726199117223067, 0.007431501273198852, 0.01656055127802704, 0.04872155222775681, 0.03930061935846295, 0.04971962635006223, 0.07133017280804259, 0.026191290567762086, 0.039114520951573334, 0.017458310783175484, 0.0367580061512334, 0.07554030617965118, 0.06516887127820935, 0.03262796366055097, 0.06563790182449988, 0.07556742722434656, 0.012825327110476792, 0.0869710428108062, 0.004478906181507877, 0.020946250496698276, 0.02717405015469662, 0.0872759764481868, 0.099022801832429, 0.079294789715537, 0.17866259946354798, 0.08416945314300911, 0.7271715945431164, 2.199081403868539, 33.29409660611834, 67.66537938799176, 76.72316919054303, 62.109106472560335, 59.72251837594168, 53.89146505083357, 32.77275936944144, 24.931053706577845, 21.15718306813921, 10.838370782988411, 23.94531798362732, 14.662670578275408, 18.521300554275513, 34.94031940187727, 46.66890641621181, 38.57805572237287, 46.80796071461269, 57.71431180409023, 77.30357306344169, 67.95981625148228, 64.81329672677177, 68.41201891217912, 56.2039749281747, 51.382859638759065, 58.37372711726597, 47.89485699789864, 38.06333664485386, 30.76630026953561, 19.127362387520925, 17.67234012058803, 12.937082852636065, 9.68318326132638, 13.16944624696459, 7.6340778555188855, 10.357116835457937, 11.89851302759988, 18.252207245145524, 21.43403925214495, 24.198407854352677, 21.59364458492824, 30.096483503069194, 37.360251903533936, 44.961768763405935, 55.4077912739345, 59.13496480669294, 61.52435997554234, 57.59589712960379, 71.6596486227853, 69.98966993604387, 69.44231864384243, 56.526086466653005, 35.15236800057547, 27.806821039744786, 27.948020594460623, 33.301023960113525, 41.582988330296104, 45.17229223251343, 62.63269492558071, 68.43393353053501, 46.915359020233154, 14.760965006692068, 1.2473231319870268, 0.35751320741006304, 0.03951667508642588, 0.03386336558365396, 0.030969023571482727, 0.07235251473528997, 0.034294924033539634, 0.01592628049132015, 0.032603047854666195, 0.06389471143484116, 0.031165944611919776, 0.02128917700611055, 0.015980091710974063, 0.10331638822598116, 0.08480984092290912, 0.05118562839925289, 0.06792455126664468, 0.07270580756344966, 0.0363654193601438, 0.018603007841323103, 0.04032435228249856, 0.05799101572483778, 0.02852340355249388, 0.04146096629223653, 0.03478653622525079, 0.039419576725257297, 0.04816425784624048, 0.04746429469170315, 0.06311829095440251, 0.05738337404493775, 0.06399894798440592, 0.021784935046785643, 0.07228455945317235, 0.03047399495595268, 0.033752353861927986, 0.02312729274854064, 0.0061021561767639855, 0.06640845297702722, 0.04194029360743506, 0.04568056522735527, 0.014372399675526788, 0.05393357987382582, 0.02325158000790647, 0.03964945760422519, 0.05119903964389648, 0.04303414973297289, 0.07441617721425635, 0.031170721498451064, 0.04644336411729455, 0.03751566853108151, 0.03959437073873622, 0.05829851422458887, 0.041896029375493526, 0.06361740774341992, 0.21097730046936444, 0.07163223624229431, 0.18624043783971242, 0.2574777124183518, 0.07612102359001126, 0.11223779379257134, 0.13943687001509325, 0.1300854089536837, 0.131384423534785, 0.1192602241145713, 0.12614538680229867, 0.14592356979846954, 0.13463265209325723, 0.1378059568149703, 0.06544021064681665, 0.12595619766839913, 0.11225779021957091, 0.15672178965594086, 0.15388129279017448, 0.137119130098394, 0.1119172131376607, 0.18193654449922697, 0.15579972841909953, 0.11815301781254155, 0.0669251506083778, 0.10580189592604126, 0.18041977445994103, 0.11557381121175629, 0.2035604105996234, 0.3106119441134589, 0.1665486187807151, 0.13498462177813053, 0.1493156070687941, 0.1760107081915651, 0.222163764493806, 0.16556250383811338, 0.1263108950640474, 0.14460276067256927, 0.17211981197553022, 0.10938095780355589, 0.10138693997370345, 0.1113814486722861, 0.1820486384843077, 0.16128115143094743, 0.19125886926693575, 0.15432144488607133, 0.08110020176640578, 0.19462597716067517, 0.16898580800209725, 0.11133796814829111, 0.18350785518331186, 0.16132669470139913, 0.22592531836458615, 0.13329911365040711, 0.20752408648175852, 0.18444816901215486, 0.2972652960036482, 0.35960515801395687, 0.23512782741870197, 0.7655360730631011, 2.1977859990937367, 35.787989207676475, 84.27154622759137, 94.65010520390102, 75.40195533207485, 69.40973854064941, 72.99181284223283, 70.6044395991734, 83.49911499023438, 67.32458414350236, 46.181549344744, 59.214639799935476, 51.239097935812815, 24.20111244065421, 33.59820188794817, 34.83861167090279, 19.296245302472794, 28.035731179373606, 43.48372711454119, 59.388303075517925, 50.67067970548357, 53.00195666721889, 56.025802271706716, 63.23239394596645, 67.72910131726945, 64.98395838056291, 68.9539714540754, 62.70755481719971, 52.316982405526296, 54.553534575871055, 44.194555623190745, 43.111192498888286, 41.60311378751482, 39.43117291586739, 42.44318226405552, 46.9793449810573, 43.438428333827424, 47.04323366710118, 52.192032950265066, 56.008240699768066, 42.07503890991211, 57.23406273978097, 68.31081145150321, 69.6765285219465, 60.66090733664376, 63.56495557512556, 65.49893801552909, 62.890709332057405, 74.99490901402065, 68.33706869397844, 73.02584511893136, 58.366417612348286, 43.61223404748099, 44.628321238926475, 45.920953682490754, 59.21678679330008, 72.71623338971818, 71.12221935817173, 79.81801496233258, 74.43454374585832, 56.614283425467356, 20.911960295268468, 1.515762333359037, 0.5441229311483247, 0.11921800566571099, 0.22725460917821952, 0.11369576877249138, 0.22723100973027094, 0.16460750651146683, 0.12154087530715124, 0.11545873167259352, 0.1393964836107833, 0.14139044018728392, 0.14956196956336498, 0.17692312066044125, 0.1273031982460192, 0.24571579641529492, 0.1711481769702264, 0.10044374237103121, 0.21703836880624294, 0.07685884899858918, 0.10044128607426371, 0.1685194915958813, 0.2044755643499749, 0.11798201341714178, 0.11072543423090662, 0.10110048963023083, 0.13456059167427675, 0.16617892576115473, 0.11383282606090818, 0.1152237414249352, 0.16995285611067498, 0.12539139868957655, 0.1256599628499576, 0.1279142733131136, 0.09406589317534651, 0.11861596868506499, 0.11194028332829475, 0.09609376971742936, 0.10439728093998772, 0.1725185734352895, 0.11514157083417688, 0.11922055695738111, 0.18085388759417192, 0.17518037131854466, 0.10860909707844257, 0.18211029017610209, 0.18665553842272076, 0.19490447507372924, 0.136193771181362, 0.11199376545846462, 0.09878076160592691, 0.1413476381983076, 0.10526630787977151, 0.1521016854260649, 0.23213266528078488], [0.04897406224959663, 0.08132869843393564, 0.03163897851482034, 0.03187024699790137, 0.026899380875485282, 0.030592480740909065, 0.06575879640877247, 0.006831055881255972, 0.053920233090009005, 0.03632549096697143, 0.039795274779732735, 0.05099091259762645, 0.029859344009310007, 0.03696022994284119, 0.07532100366162402, 0.020740254050386802, 0.034561120106705596, 0.013096313640874411, 0.00454610532116411, 0.060950168009315214, 0.010402723847489272, 0.07755032368004322, 0.03231919290763991, 0.010436357980194901, 0.07574635690876416, 0.030836749954947403, 0.056553457863628864, 0.04305738277201142, 0.0377779324938144, 0.06900858559778758, 0.03276452561840415, 0.02858867183593767, 0.026313755960602845, 0.012443333947365838, 0.04431163779060755, 0.04671416405056204, 0.03767264421497073, 0.08219915029725858, 0.029916008468717337, 0.02377779918190624, 0.019828803404899578, 0.02174370895539011, 0.03290313335933855, 0.055985775110977035, 0.020090680602671843, 0.010364570671559444, 0.038972591781722646, 0.010127920557611754, 0.07811544157032456, 0.04537684277498296, 0.04788584814273885, 0.03333539070029344, 0.040155471701707156, 0.03605803281867078, 0.12275925278663635, 0.05590023559385112, 0.022615429679197923, 0.0516861463630838, 0.02934249710025532, 0.13013663834759168, 0.019697130291855762, 0.6044113646660532, 1.274454110435077, 16.566101789474487, 45.43192556926182, 42.47282675334385, 51.15683126449585, 66.32291793823242, 56.20572240012032, 54.49917881829398, 69.329347882952, 77.89878354753766, 76.41239711216518, 82.85504477364677, 64.14115578787667, 55.09026902062552, 72.96098368508476, 55.41871731621878, 35.999085903167725, 18.53129553794861, 36.09961938858032, 43.135236740112305, 25.456268038068497, 40.162408283778596, 79.97416182926723, 33.038305623190745, 56.92216157913208, 36.47093459538051, 17.328685692378453, 33.76952709470476, 29.064981733049663, 34.32337842668806, 29.06233968053545, 32.62396717071533, 51.33386441639492, 35.90817219870431, 39.50863143375942, 22.609834262302943, 22.282273599079677, 32.04575545447213, 84.04209586552211, 67.90737124851772, 39.14408029828753, 24.33349299430847, 15.719529799052648, 14.905028956277029, 15.384011711393084, 30.2913943699428, 27.886275427682058, 27.043127162115915, 31.82248898914882, 42.597460065569194, 44.959573132651194, 52.45287874766758, 55.904274804251536, 51.69012982504708, 54.08458675657, 47.193033354622976, 36.412847655160085, 14.526021225111824, 0.43431666759508, 0.2644139416515827, 0.0746583327917116, 0.07583124842494726, 0.017248165095224977, 0.04144302582634347, 0.04221285433907594, 0.03393884581912841, 0.018695461630289043, 0.05269978947139212, 0.04286122169079525, 0.01581266149878502, 0.05380605939509613, 0.030483494446213757, 0.030641138487096344, 0.06335880447711263, 0.009293563364605819, 0.04306988477973001, 0.05513848504051566, 0.048829510541898866, 0.046346750908664296, 0.03170935616695455, 0.03153534246874707, 0.014838615997827478, 0.022918923126001443, 0.022129266123686517, 0.03403949291844453, 0.01683694064351065, 0.027290627559913055, 0.021459974448329637, 0.01041230561012136, 0.046451452254716835, 0.030709809623658657, 0.03557895656142916, 0.014460331028593438, 0.016339289490133524, 0.038373445360256095, 0.04780516354367137, 0.023592170660517046, 0.030125662218779325, 0.03307418864486473, 0.025457532976620963, 0.029418499807694128, 0.024131458418975984, 0.03684988997078367, 0.03621325448953679, 0.06488159990736417, 0.024381101630362015, 0.09295372678233044, 0.042039736307093074, 0.04446355499593275, 0.11151336266526155, 0.05114390188828111, 0.062268887247358046, 0.05952894927135535, 0.042725012571151764, 0.0164863958821765, 0.050048695478056154, 0.024595768057874272, 0.037380294009510956, 0.051622289432478805, 0.012661298903237497, 0.1093343695891755, 0.033684856590947936, 0.04616240651479789, 0.04499141113566501, 0.0145804860096957, 0.07192147536469357, 0.03138377131628139, 0.023211451446903602, 0.06069940182247332, 0.10272746054189545, 0.0431748677178153, 0.040432419162243605, 0.05429994807179485, 0.04423536027648619, 0.05921454328511443, 0.03649630197989089, 0.05070824508688279, 0.024676220258697867, 0.07488336214529616, 0.05216126336849161, 0.034507709222712686, 0.06867224935974393, 0.02675228805414268, 0.030311730091593096, 0.02964988024905324, 0.016542507335543633, 0.016706804412284067, 0.012918046376268779, 0.0936615609430841, 0.03447304965396013, 0.023310220700555613, 0.06615911849907466, 0.045737406105867455, 0.016841541110937084, 0.020049910826076354, 0.1059843132804547, 0.01569843861008329, 0.010759854639348174, 0.04799837639023151, 0.04171525068315012, 0.06277719818587814, 0.021722742223313878, 0.02731990804230528, 0.09842009988746472, 0.029577399138361216, 0.017442200665495226, 0.03589117427223495, 0.028933564400566474, 0.07061172635959727, 0.10851754913372652, 0.04484600108116865, 0.04986209834792784, 0.042471081018447876, 0.1440492118043559, 0.04212346752839429, 0.41818797162600924, 3.365450314113072, 28.767088140760148, 58.63065760476248, 56.52152150017874, 62.63866342817034, 70.32082108088902, 63.19695118495396, 57.92802449635097, 49.69792148045131, 49.028792585645405, 45.525681086948936, 30.089472770690918, 31.765989712306432, 31.594028745378765, 13.73814674786159, 13.815448931285314, 23.076211248125347, 18.32581298691886, 29.381274155208043, 35.57211562565395, 27.864859342575073, 49.31061846869332, 77.08357225145612, 43.065862451280864, 65.38553646632603, 54.16256638935634, 41.598701681409565, 65.0363130569458, 57.58131286076137, 61.607613291059224, 61.9587196622576, 62.01445811135428, 79.3108937399728, 71.8217361995152, 69.1687124797276, 58.04962491989136, 57.60440519877842, 57.41289547511509, 74.2231309073312, 78.81343051365444, 61.278067180088584, 52.23963505881173, 34.184199060712544, 28.50299232346671, 27.60171890258789, 37.45010600771223, 36.61522436141968, 31.482468468802317, 44.22703150340489, 42.3395915712629, 39.84425374439785, 51.351304394858225, 56.160322870527, 61.02982194083077, 63.97482286180769, 67.86448001861572, 51.81706646510533, 22.9731034551348, 1.6579944555248534, 0.1430865198905979, 0.13699985721281596, 0.08842656149395875, 0.07288850311722074, 0.027758736994915774, 0.04234899899789265, 0.040759873376893144, 0.020593244349583983, 0.06854680180549622, 0.035257900932005475, 0.04320895053180201, 0.026881966274231672, 0.050470252321766954, 0.011712533072568476, 0.05211116034271462, 0.037761403380760124, 0.04097619034083826, 0.07305594520377261, 0.014323899688731347, 0.03429652876885874, 0.058641092984804084, 0.04016932399411287, 0.05426724607657109, 0.03178827318229845, 0.07952206502003328, 0.028989370513175215, 0.027865372165771465, 0.03797004272096923, 0.06539548161838736, 0.022240327039201344, 0.0033156181120180656, 0.036381870441670926, 0.02499494681667004, 0.04214124853855797, 0.011099563196434506, 0.056371637620031834, 0.02413515982750271, 0.07365321208323751, 0.05387182640177863, 0.04735554927693946, 0.0770592475309968, 0.04339572408103517, 0.011796499236619898, 0.07902162508772952, 0.04265896736511162, 0.02220739094939615, 0.05152104522234627, 0.1106338252180389, 0.06833205225744418, 0.040007048951728005, 0.06313419581523963, 0.018174635113349984, 0.06901964571859155, 0.04729521055040615, 0.04689870182690876, 0.13247742131352425, 0.18770738983792917, 0.10729352624288627, 0.09383071293788296, 0.12477038986980915, 0.16132714253451141, 0.21301082920815262, 0.06519109330007009, 0.1224056953298194, 0.17245647391038282, 0.12637114897370338, 0.19034011928098543, 0.10200634066547666, 0.191531043233616, 0.16865456077669347, 0.10417079952146326, 0.10490737642560687, 0.11256479338875838, 0.08294866007885762, 0.11518631343330656, 0.12914375162550382, 0.20606317344520772, 0.20803638042083808, 0.08248661844325916, 0.11601871305278369, 0.16747526691428252, 0.15813658945262432, 0.1601378470659256, 0.1567052469721862, 0.17978320004684584, 0.11324838349329573, 0.06155074613967112, 0.1206546135778938, 0.20019965379365853, 0.2688383699527809, 0.11156384567064898, 0.11860965830939156, 0.15235931160194532, 0.131734344043902, 0.16140198494706834, 0.18169580027461052, 0.11533707034374986, 0.1083754367594208, 0.11799050867557526, 0.16965734053935322, 0.10822264424392156, 0.15781356607164654, 0.1625621034098523, 0.11022300619099822, 0.12483010095145021, 0.16330778625394615, 0.10972952802798577, 0.14343188064438955, 0.08457705591406141, 0.199733934498259, 0.222287474998406, 0.12879692523607186, 0.20412903651595116, 0.2800819937671934, 0.19955921173095703, 0.11864477928195681, 0.472513167985848, 3.003623741013663, 28.792560236794607, 68.47300325121198, 76.88486766815186, 80.833619253976, 88.83516475132534, 75.27993106842041, 70.69462026868547, 81.18543434143066, 92.90693419320243, 91.50993633270264, 98.42910534994942, 81.91388348170689, 72.72712816510881, 97.24591050829206, 73.42148249489921, 54.78452396392822, 34.241240297045024, 48.84495367322649, 53.99870702198574, 33.85494129998343, 52.9037230355399, 91.46063191550118, 42.95595237186977, 69.48705809456962, 52.44933516638619, 30.430323600769043, 52.97731140681675, 45.50383595057896, 49.6416688646589, 46.28260394505092, 50.13198586872646, 72.91185297284807, 53.41094848087856, 56.86720132827759, 35.737225668770925, 34.69459635870797, 42.8601610319955, 94.38193253108433, 86.27626132965088, 49.28791175569807, 40.63872119358608, 24.88048471723284, 25.1151271206992, 27.183268853596278, 46.50258738654, 43.320597308022634, 40.82668038776943, 51.67883552823748, 66.07052462441581, 72.57951368604387, 78.97061266217912, 78.3101863861084, 77.01686259678432, 79.64355959211076, 76.47083146231515, 57.21514974321638, 29.05371175493513, 2.2540459973471503, 0.6249475255608559, 0.23961875215172768, 0.2065009642392397, 0.20962265958743437, 0.18530241745923245, 0.09597271907010249, 0.09941340051591396, 0.08786655297236783, 0.11691850477031299, 0.0778627483440297, 0.12086874565907887, 0.14378850507949079, 0.14008963427373342, 0.12071617027478558, 0.13860544748604298, 0.1547375361302069, 0.19829234613903932, 0.13427574267344816, 0.1388590703053134, 0.09006214301501002, 0.14310341541256222, 0.07776507322809526, 0.14768519598458493, 0.1333658950669425, 0.1369220699582781, 0.16920102573931217, 0.12920297416193144, 0.22437076749546186, 0.15137246384152345, 0.10638316973511662, 0.1148754358291626, 0.07328026888093778, 0.17367367073893547, 0.21075927359717234, 0.13109584259135382, 0.13419834896922112, 0.07727840077131987, 0.17144350255174295, 0.139726672321558, 0.13893957169992582, 0.1941249469029052, 0.1332326443599803, 0.07248964666255883, 0.1918632404080459, 0.19528585246631078, 0.17778714001178741, 0.12507989683321544, 0.2014646873410259, 0.19836515294654028, 0.08439425858003752, 0.1441908220627478, 0.13754256309143134, 0.23115199218903268, 0.16194422942187103, 0.08024336131555693], [0.07370784093758889, 0.01938865809435291, 0.030599266091095548, 0.00686976545590109, 0.046000955892460685, 0.022046092997438142, 0.06446610577404499, 0.04771420592442155, 0.02804342145100236, 0.061143665840583186, 0.08630392753652164, 0.03614169618647013, 0.06754476843135697, 0.05714600892471416, 0.014913651792864715, 0.07903537899255753, 0.07280668536467211, 0.020726571391735758, 0.022679400264418552, 0.06362242211720773, 0.12836769755397523, 0.054487559611776044, 0.05241622290174876, 0.10909076194678034, 0.04441069372530494, 0.024830815981009176, 0.04267638875171542, 0.026001468699957644, 0.020033710802506124, 0.05853657823588167, 0.05005652577217136, 0.015151727678520339, 0.0599025370819228, 0.04363990169284599, 0.08228831658405916, 0.07537251804023981, 0.023874995930652534, 0.01150562908566956, 0.03485309372523001, 0.023475138636838113, 0.04466887969257576, 0.03826023857774479, 0.04709585017657705, 0.04645420710689255, 0.007535903215674418, 0.10796888571764741, 0.041012617493314404, 0.039575632994196246, 0.03031819313764572, 0.02273021235929004, 0.05453504688505616, 0.05457692945908223, 0.042318984001342735, 0.07920476847461291, 0.07732754706272058, 0.047208517523748536, 0.07006659811096531, 0.032667121916477165, 0.07108610376183476, 0.1710243443293231, 0.042707187456211874, 0.021412809479183385, 0.029781957090433155, 0.55122160166502, 0.24017767501728876, 1.248456882578986, 6.515389655317579, 33.22934981754848, 57.92068372453962, 71.05350862230573, 69.1704842703683, 70.7310288293021, 69.85254028865269, 70.35661820002964, 63.921662194388254, 69.34413364955357, 65.3368226460048, 61.76699801853725, 59.20475946153913, 67.2101195199149, 60.43336772918701, 47.079899311065674, 55.10847330093384, 37.77121353149414, 37.96025317055838, 53.15755810056414, 58.25133807318551, 79.92094557625907, 56.16281379972185, 33.60493121828352, 47.712671756744385, 39.95339952196394, 27.775409970964702, 32.293250288282124, 27.375671420778545, 28.147586754390172, 33.93009649004255, 36.050804819379536, 39.21182176045009, 32.29830857685634, 72.37942641122001, 49.55940219334194, 30.178055354527064, 50.14770269393921, 64.87526076180595, 66.76048074449811, 70.44775772094727, 60.255813462393625, 48.144894872392925, 41.92740706035069, 28.77404155050005, 25.454751593726023, 28.864962203162058, 33.748262132917134, 30.36703245980399, 21.718500239508494, 12.510538152285985, 1.4861830919981003, 0.10533857864460774, 0.4004652069083282, 0.03480037833963122, 0.1319545829402549, 0.09753719690654959, 0.0683353499376348, 0.041950688763920746, 0.05971222836524248, 0.0990752118772694, 0.02736946315105472, 0.026927960770470754, 0.030050046276301146, 0.0615407173920955, 0.03599723608099988, 0.03890143720699208, 0.004714409147189664, 0.018584541510790586, 0.05262131350381034, 0.03894164379952209, 0.035373160282948186, 0.026100217597559094, 0.02744567790068686, 0.08310776975538049, 0.041899992020002434, 0.02167424902186862, 0.029103612061589956, 0.023428677647773708, 0.00463334796118683, 0.08845140944634165, 0.011667710745574107, 0.037350309547036886, 0.035164344523634226, 0.037653706302600246, 0.0548758037787463, 0.045790647356105704, 0.05506201075123889, 0.08138598714556013, 0.04575722611376217, 0.020831634057685733, 0.0787653016990849, 0.0261398236865976, 0.034951935921396525, 0.04753705060907772, 0.02888700332758682, 0.06210510924990688, 0.0437940173516316, 0.031157903971948793, 0.06832786569637911, 0.00717709050513804, 0.042900213705641885, 0.04836766907413091, 0.0257185721836452, 0.02480966774081545, 0.10677906099174704, 0.037314184342644045, 0.06841424320425306, 0.04770631116947957, 0.047032342691506655, 0.05955047918749707, 0.02052368433214724, 0.05441441692944084, 0.05789822606103761, 0.028129461387704526, 0.016192227202866758, 0.02831315099527793, 0.11328142136335373, 0.032382808958313296, 0.04057683177026255, 0.04650391658235874, 0.07477664894291333, 0.04265011926846845, 0.02036612680447953, 0.067564235601042, 0.05386993668175169, 0.04749546319778476, 0.021677487330245118, 0.052800209261476994, 0.07379997242242098, 0.05017441783898643, 0.08638846621449504, 0.07685654876487595, 0.13921863958239555, 0.06464601254888944, 0.0226067071115332, 0.0783364607819489, 0.029001906447644745, 0.030404570645519664, 0.013996599840798547, 0.006611614263549979, 0.09537658534411873, 0.11049302920166935, 0.040975165752960105, 0.06375459395349026, 0.02595861073184226, 0.06274154795599834, 0.03510392776557377, 0.03038434690928885, 0.019878733404246823, 0.028115715964564254, 0.045725806549723656, 0.05227740142228348, 0.026747875880183916, 0.04470626697210329, 0.03747885122096964, 0.04984145052731037, 0.07941800488957337, 0.03242614020460418, 0.0188255096519632, 0.05476354355258601, 0.05676190721403275, 0.04348375042900443, 0.037481918199253936, 0.11329441530896084, 0.03423773031681776, 0.005283513854789946, 0.044125573310468874, 0.025504189044503228, 0.11009443059031453, 0.055350751150399446, 0.0905464066724692, 0.08508252379085336, 0.6438065650207656, 0.5508760373507227, 4.284022143908909, 15.370683329445974, 49.86637360709054, 69.4663177217756, 78.10384573255266, 79.37417793273926, 81.58304500579834, 78.10764639718192, 76.72693511417934, 67.60633359636579, 60.61944743565151, 59.499849455697195, 59.83405780792236, 52.46167516708374, 40.383871691567556, 48.54476717540196, 42.36667912346976, 30.33923966544015, 36.197411809648784, 56.33938489641462, 34.33643061774117, 59.18035738808768, 62.949338231767925, 26.384142637252808, 28.948826960154943, 33.70823008673531, 30.887442111968994, 23.663516419274465, 27.095400197165354, 39.4126420702253, 28.397937297821045, 32.485833508627756, 17.73908277920314, 16.534629923956736, 23.72808255468096, 85.29263959612165, 54.54453318459647, 27.258276394435338, 26.489254985536846, 21.933288165501185, 29.728350571223668, 36.12059252602713, 49.79010323115757, 47.003253732408794, 50.411539690835134, 44.227670737675254, 44.361138684409006, 47.327852725982666, 52.91496869495937, 51.459790093558176, 38.49868644986834, 22.286694390433176, 5.518024384975433, 0.3478285585130964, 0.4442743589835507, 0.06253589756254639, 0.09961934267942395, 0.033023444403495104, 0.03776012434224997, 0.06908711245549576, 0.02605855554741408, 0.01586097149577524, 0.017381600702979734, 0.0597418396334563, 0.06729804631322622, 0.060878874334905825, 0.052045267807053666, 0.09214930994702236, 0.01480399035582585, 0.03239409638834851, 0.08774645227406706, 0.08454629792166607, 0.029650853946805, 0.044304123015276024, 0.00808358021147017, 0.030105570796877146, 0.028265207407197783, 0.01982420463381069, 0.024627343684967076, 0.045643340796232224, 0.017597700535718883, 0.04170211763786418, 0.0629611083173326, 0.011956003311622356, 0.06380677329642431, 0.07142674869724683, 0.06180293046470199, 0.05924477202019521, 0.047059392490025075, 0.05493405261742217, 0.01135157619137317, 0.06333437721644129, 0.05172567781327026, 0.060209723455565314, 0.013499153096095791, 0.05774338436978204, 0.044804386528474946, 0.10061223618686199, 0.017479386080854704, 0.03885000425257853, 0.046313278776194365, 0.01905226248449513, 0.04315297478543861, 0.018259351906765784, 0.04154051434514778, 0.04437197990981596, 0.090819510232125, 0.020732215106753365, 0.06494359765201807, 0.03437694534659386, 0.05446522902431233, 0.2347730893109526, 0.1307904204087598, 0.09102693838732583, 0.10276213368134839, 0.12701826782098838, 0.09498861937650613, 0.14619410171040467, 0.19361966901591846, 0.10744345534060683, 0.18380598989980562, 0.20384050985532148, 0.18857495114207268, 0.09258217457681894, 0.12207847860242639, 0.1360592855406659, 0.21195193459945066, 0.22721627194966587, 0.09049514335181032, 0.09948172899229185, 0.14086157642304897, 0.21314393063741072, 0.15618251716451986, 0.13479708826967648, 0.2951113001576492, 0.13351349000419888, 0.18722626779760632, 0.27947836901460377, 0.08782309958977358, 0.17466871520238264, 0.16882100541676792, 0.16228652319737844, 0.20374143017189844, 0.12773805776877062, 0.12140493760151522, 0.147178818870868, 0.08687758139733757, 0.24253002021993908, 0.09547713744853224, 0.10946636500635318, 0.20492736010679177, 0.0989441324823669, 0.1548780064497675, 0.22358863375016622, 0.1362802165427378, 0.12985058155442986, 0.17631334838058266, 0.15989508080695355, 0.10002202607159104, 0.19895551912486553, 0.06827844799097095, 0.12653813644179276, 0.21710995425071034, 0.10955720048929964, 0.13196130043693952, 0.21655578113027982, 0.19310219106929644, 0.11508073338440486, 0.144503490999341, 0.15481302993638174, 0.2973438703588077, 0.11319642806691782, 0.13728440765823635, 0.16053200805825846, 0.5991597750357219, 0.3537428325840405, 2.4669459675039564, 16.0446811744145, 53.3290570122855, 78.10722255706787, 91.99429525647844, 90.68743637629917, 95.84777314322335, 91.00528866904122, 88.04313959394182, 82.01921817234584, 85.38276468004499, 80.01408617837089, 83.05417319706508, 78.58352157047817, 81.73219503675188, 83.35385595049176, 66.90124429975236, 71.23177160535539, 53.33002281188965, 57.58154909951346, 72.18270901271275, 79.53280530657086, 104.13476453508649, 73.28363718305314, 47.277301107134136, 63.405049732753206, 55.670582566942485, 40.89553008760725, 43.33466741016933, 41.14724942616054, 40.097682339804514, 48.36185237339565, 51.25706250326974, 56.3196450642177, 50.37378665379116, 91.47741876329694, 63.38473320007324, 44.04314047949654, 64.48632839747837, 80.49192769186837, 79.65149443490165, 81.83755057198661, 79.53502178192139, 70.15109048570905, 74.11020183563232, 64.22725786481584, 57.42852892194475, 56.67446872166225, 64.17789786202567, 57.60723311560494, 44.20900787625994, 22.268670763288224, 5.42547698531832, 0.386569081140416, 0.6207590645977429, 0.15926753090960638, 0.47361364322049276, 0.13458048632102354, 0.18412439924265656, 0.12044186570814677, 0.12286095161523138, 0.3071952760219574, 0.16865678637155465, 0.14790672409747327, 0.2156846643026386, 0.17545202959861073, 0.13078679703176022, 0.17559028789401054, 0.13415298211787427, 0.12059704666691166, 0.19319981868777955, 0.1450873161000865, 0.17224650803421224, 0.1275629007390567, 0.10802111934338297, 0.1516055270497288, 0.18281226179429463, 0.08673831208475999, 0.09589917265943118, 0.11951006070843764, 0.13853019795247487, 0.309355622955731, 0.18077654817274638, 0.21312113186078413, 0.28922009627733913, 0.2515842558017799, 0.16521909726517542, 0.192095421520727, 0.18438859363751753, 0.1902082392147609, 0.12028920889965125, 0.13542499100523336, 0.11481404198067528, 0.13077192354415143, 0.11016999224999122, 0.21570868444229874, 0.11799734830856323, 0.18782592990568706, 0.08894536258386714, 0.11569898735199656, 0.12488637864589691, 0.08315479901752301, 0.16863359404461725, 0.15093489017869743, 0.08596246835908719, 0.11388580607516424, 0.2611375403191362, 0.0911463876920087, 0.21429501101374626, 0.09599120914936066, 0.15061217892382825], [0.062447023045803816, 0.07908996713480779, 0.05986672400363854, 0.03999418732044952, 0.04208788515201636, 0.07283147903425352, 0.030237749418509857, 0.010765608616306313, 0.017162489871095334, 0.02364539325104228, 0.03690421687705176, 0.05290867986955813, 0.05023909918963909, 0.014516956472237195, 0.039544461095439534, 0.02409368776716292, 0.022910907931093658, 0.060750576933579784, 0.04140325688890048, 0.018139853408294063, 0.030933682075036422, 0.06893296286995922, 0.07439939704324518, 0.06557490663336855, 0.08523227646946907, 0.07367974958781685, 0.019257960375398397, 0.01959288526060326, 0.02965470463303583, 0.01728925378327923, 0.06449264327862433, 0.06894192631755557, 0.03756889621061938, 0.015454590087756515, 0.011201125469857028, 0.02048877709811287, 0.023470202294577445, 0.06048016715794802, 0.008812321732485933, 0.013845682626457086, 0.005580262239423713, 0.10795414115169219, 0.05512987103845392, 0.039751458380903514, 0.01549954472907952, 0.026049958508727804, 0.03997457765841058, 0.06858253345957824, 0.07131975729550634, 0.014021380787848361, 0.05986063754452126, 0.10237759431557995, 0.023212177479373555, 0.0378531379226063, 0.09354066635881152, 0.01050514870855425, 0.011843811787132705, 0.1380462260650737, 0.03301507128136499, 0.04128408917625036, 0.01918619851182614, 0.10516843598868165, 0.03551418021587389, 0.2145034841128758, 0.003009958654209705, 0.02454158873297274, 0.13950399069913796, 0.21444473655096122, 0.32008955840553555, 2.886514242206301, 6.226107052394322, 10.11691153049469, 23.421689578465053, 33.40246071134295, 43.99971423830305, 51.599219594682964, 53.71659278869629, 41.12371587753296, 51.34329659598214, 60.675859860011506, 67.30553913116455, 71.0626038142613, 66.09023666381836, 66.74113695962089, 61.19857978820801, 59.28596305847168, 50.84691381454468, 57.56221921103341, 65.33903217315674, 71.44335814884731, 65.95826257978166, 71.32865033830915, 74.51506641932896, 73.37747955322266, 81.51047107151577, 80.42106996263776, 82.76521151406425, 88.52776949746269, 79.15239838191441, 75.39557688576835, 64.17837728772844, 69.35527856009347, 76.50457191467285, 73.2945805958339, 67.70031493050712, 70.00327450888497, 65.3589665549142, 63.7517648424421, 40.001675605773926, 18.622039011546544, 18.38090177944728, 11.997355495180402, 8.524288007191249, 4.506296753883362, 0.7486814260482788, 0.008884857974148222, 0.23046037501522473, 0.10145223539854799, 0.047808389977685044, 0.12756649697465555, 0.028168896146650826, 0.052518759721091816, 0.05285806115716696, 0.04805320880508848, 0.027874825854918787, 0.06830792355218104, 0.05459975537710956, 0.08611906067069088, 0.03615063249266573, 0.022040003145645772, 0.04858617092083607, 0.12602772883006505, 0.022584368042381744, 0.009012316536557461, 0.026620106039834873, 0.03369829497699227, 0.04861071353246059, 0.07337071759892361, 0.015020607571516718, 0.026249907511685575, 0.04903284713093724, 0.04217086659212198, 0.0026114972341539605, 0.024369485110842755, 0.12869754699724062, 0.02006068765851004, 0.03162657150200435, 0.04778070914159928, 0.053066215344837735, 0.04109545983374119, 0.01872687440897737, 0.10110180598816701, 0.05435637504394565, 0.0375899206181722, 0.1031680197588035, 0.037987844087183475, 0.03272641909175685, 0.029174369693334614, 0.09258367413921015, 0.010212840911533152, 0.03788088661219392, 0.025976033814783608, 0.034254076225417, 0.05607939937285014, 0.036638505956424136, 0.06418132462671824, 0.04761163857100265, 0.055711294125233374, 0.07089108601212502, 0.04035760389108743, 0.07863665145954915, 0.016026408511347005, 0.055922169238328934, 0.014135738535385047, 0.028666845855436156, 0.022090701585901634, 0.05656740175826209, 0.0411348623622741, 0.043984841754926104, 0.03647328946473343, 0.0559816292620131, 0.04074531540806804, 0.06309494934976101, 0.04742573354659336, 0.045348211989871094, 0.013392712155889188, 0.04459813563153148, 0.060159776492842605, 0.08283766532050711, 0.030805673051093305, 0.18331086289669785, 0.01867090035895152, 0.030244348171566213, 0.041013811714947224, 0.07755466630416256, 0.04431522045550602, 0.08448662755212613, 0.07342943801943745, 0.1095693191247327, 0.08412329919104065, 0.04518446113382067, 0.0831943168970091, 0.03581346844189933, 0.015352068535451378, 0.025897681679842726, 0.033203751514000554, 0.047761618558849604, 0.049144038664443154, 0.03294576571456023, 0.05294583983985441, 0.04330593693469252, 0.0024358100989567383, 0.012854203864532922, 0.027324925808768188, 0.015282433879162585, 0.04215299737240587, 0.04284084867686033, 0.10689028645200388, 0.034709369830254994, 0.015281022526323795, 0.014906934296180094, 0.06096191345048802, 0.030522683236215795, 0.014733195404655166, 0.032383161796522994, 0.015896309599546448, 0.04966054630598851, 0.07222297561487981, 0.057569747258509905, 0.01220821138537888, 0.009305427549406886, 0.04906024976766535, 0.03072386547656996, 0.1260287602032934, 0.0713875022317682, 0.038043205759355, 0.01661167380266956, 0.05115214269608259, 0.02919546534706439, 0.2297156692615577, 0.11163931233542305, 0.051417643270854435, 0.18595761087323937, 0.0995084157745753, 1.074587332350867, 8.028724244662694, 14.351314851215907, 22.177032709121704, 39.38520015989031, 52.677583490099224, 64.28797122410366, 76.26454639434814, 76.37397357395717, 62.81987244742257, 67.74622167859758, 74.05314322880336, 68.56213474273682, 63.617261614118306, 59.97623879568917, 56.225121770586284, 45.997616631644114, 54.05867692402431, 51.567845003945486, 71.86964402879987, 63.84193161555699, 56.79072598048619, 59.61408478873116, 55.69958782196045, 52.37028898511614, 49.92446402141026, 51.19920832770211, 50.718111583164756, 62.79148210797991, 58.744837352207725, 58.71935830797468, 62.422901017325266, 73.95274175916398, 70.10178606850761, 66.15593188149589, 77.00393199920654, 81.14778900146484, 84.80297224862235, 84.21884414127895, 77.40541975838798, 62.997669901166645, 38.2136470249721, 27.98048778942653, 19.06179050036839, 15.330277817589895, 10.491012964929853, 2.7934355224881853, 0.11039969670985426, 0.09099814136113439, 0.10856997953461749, 0.007569117504837257, 0.18263145935322556, 0.020157735129552226, 0.12857536998178276, 0.06712522344397646, 0.06923336389341525, 0.023868117281900983, 0.05737639870494604, 0.014188036621947373, 0.07099298161587544, 0.03505167717646275, 0.10004720650613308, 0.029138271630342518, 0.05264090280979872, 0.004203088905861867, 0.06292505096644163, 0.028867207068417753, 0.005176726861723832, 0.05357134734679546, 0.06546475325844117, 0.04728570766746998, 0.02722753907021667, 0.048986146958278756, 0.04203978041186929, 0.03375210280397108, 0.04863317982692804, 0.08842861066971507, 0.0026195548375004102, 0.028138479118102362, 0.03683600714430213, 0.041657242724405866, 0.009895621549471148, 0.10204910872770206, 0.04547814126791699, 0.08856118962700878, 0.03209673520177603, 0.02331106547665383, 0.07987927299525056, 0.02116063024316515, 0.05014621113826122, 0.043960445028330596, 0.09577679208346776, 0.06518768705427647, 0.029074207746556828, 0.04110924766532012, 0.012592789766910886, 0.05569252584661756, 0.03992581134662032, 0.005368079674164099, 0.044502981273191314, 0.013009641818436129, 0.0492462260382516, 0.03187716466241649, 0.0869487054379923, 0.05161102914384433, 0.07961467147937842, 0.1158177445509604, 0.0935183764834489, 0.13347276433237962, 0.10428698507270642, 0.09079901847456183, 0.12345723461891923, 0.0896473681288106, 0.19255001284182072, 0.12396969140640327, 0.04799914313480258, 0.16612023248204164, 0.11901516440723624, 0.12784386851957866, 0.09128952465419259, 0.23017099340047154, 0.08264715982867138, 0.3380527416510241, 0.10412227069692952, 0.09446382682238307, 0.17021724049534115, 0.16367870063654014, 0.10062544726367507, 0.1243061904928514, 0.19669271340327604, 0.19949996205312864, 0.13587264769843646, 0.1452536793159587, 0.22257745372397558, 0.12743917666375637, 0.131862750010831, 0.09220851212739944, 0.16221326855676516, 0.13228926355285303, 0.12809027172625065, 0.10801298370850937, 0.12518150066690786, 0.12881992757320404, 0.09559244768960135, 0.08913125403757606, 0.09642766322940588, 0.0964185165773545, 0.1698925479182175, 0.15037546519722256, 0.2511238290795258, 0.12023088202944823, 0.08990130985953979, 0.06637247705033847, 0.16056365493152822, 0.10418440414858715, 0.09378113916942052, 0.20124321351093905, 0.09690805245190859, 0.19742819108068943, 0.13175665427531513, 0.20316261265959057, 0.0928124218646969, 0.21663141064345837, 0.11780792847275734, 0.10332440850990159, 0.18814412211733206, 0.14137601453278745, 0.1712499572230237, 0.11368927519236292, 0.26214239639895304, 0.15913467375295504, 0.20900929107197694, 0.2336545650448118, 0.12566499757979596, 0.35717879821147236, 0.29822224751114845, 0.3589648652289595, 4.271347326891763, 10.455934984343392, 17.888470785958425, 36.99619409016201, 53.748804637363975, 69.7691341127668, 83.16154370989118, 89.76294381277901, 77.99296637943813, 85.36129474639893, 84.69699832371303, 87.88730539594377, 90.55025114331926, 85.16268048967633, 83.24610328674316, 74.25222996303013, 71.26715183258057, 65.20169407980782, 77.02734742845807, 85.11056900024414, 91.4779190335955, 90.34136050088065, 90.24756676810128, 97.95754500797817, 97.92056669507707, 103.59941973005022, 98.60586752210344, 103.00276402064732, 106.45547676086426, 95.84319428035191, 87.02511732918876, 78.48431519099644, 83.36192975725446, 92.90173694065639, 97.04371792929513, 93.3628055027553, 92.331435748509, 92.11548573630196, 82.81675325121198, 71.92305483136857, 45.30514178957258, 29.86844709941319, 16.508866003581456, 14.274823001452855, 9.984299080712454, 2.2174200883933475, 0.08776176002408777, 0.3979070213224207, 0.24532886860626085, 0.24690334126353264, 0.5968689322471619, 0.0788154522223132, 0.32927863246628214, 0.15876720632825578, 0.12048940387155328, 0.1550914735666343, 0.18949845087315353, 0.09085583899702344, 0.20108516913439545, 0.1580653975584677, 0.19147528122578347, 0.11045368774128811, 0.1587439054357154, 0.08329758992684738, 0.14286514105541365, 0.11015171251658883, 0.08849614526012115, 0.1566510863069977, 0.1461240497550794, 0.10312960789139781, 0.06561263318040542, 0.14311993095491612, 0.17070661352149077, 0.10291796603373118, 0.1566145946936948, 0.24453948810696602, 0.05159541266039014, 0.14093092270195484, 0.12586143346769468, 0.14793485615934643, 0.08847790623881988, 0.15246755150812014, 0.20621507029448236, 0.19706944961633, 0.12730618380010128, 0.13396386083747658, 0.09667598669018064, 0.08943341925208058, 0.08661785854824952, 0.22951775416731834, 0.1758719477802515, 0.16920629117105687, 0.11065479873546533, 0.11255884263664484, 0.17749383646462644, 0.14097345327692373, 0.10300400427409581, 0.12054650937872273, 0.148859617965562, 0.11048852372914553, 0.13669140876403876, 0.1867829265871218, 0.09805707008178745, 0.1033320352435112, 0.21155067613082273, 0.16118028041507515, 0.3244444504380226], [0.05805933741586549, 0.10061051270791463, 0.11757000695381846, 0.011296908321258212, 0.024972136165680628, 0.023882310538153564, 0.041914285360170264, 0.03280751420451062, 0.07014349648462874, 0.052547862088041644, 0.08136601107461111, 0.0944528141990304, 0.045944030197071176, 0.05543761720348682, 0.07762858590909413, 0.05063687338094626, 0.027392063456188356, 0.12262898763375622, 0.03417511171262179, 0.06254966503807477, 0.07859825316284384, 0.0881798325904778, 0.0023580230564610766, 0.03425823564508131, 0.05057198168443782, 0.02027004454950137, 0.059862103180161545, 0.0056211783251326, 0.07396183695111956, 0.0436215235718659, 0.0412892901471683, 0.002501053361421717, 0.019581937098077366, 0.052670788884695084, 0.007303460018842348, 0.023511026353974427, 0.036710600302155526, 0.035564761608839035, 0.07152426775012698, 0.06196206049727542, 0.03248851453619344, 0.061186651034014564, 0.030665979654129063, 0.027572072011285594, 0.04553750968937363, 0.028751292931182042, 0.0006644693587856766, 0.043878661202532906, 0.08021652525556938, 0.029414469309683357, 0.018278908982340778, 0.03664266537608845, 0.03724876678149615, 0.06811598635145596, 0.025734466866457036, 0.044013034884950945, 0.032508873979427984, 0.025598719150626233, 0.04756108431943825, 0.111651390258755, 0.028916777444205115, 0.06899363068597657, 0.06473963002541236, 0.16321892530790397, 0.07540463310267244, 0.09587509145161935, 0.06036633612321956, 0.277464504220656, 0.1019870974123478, 0.14382416888007096, 0.37853332662156647, 0.3472170356128897, 0.5346854318465505, 0.5509476363658905, 0.8588894637567657, 1.0358885803392954, 3.3972682867731367, 7.483963762010847, 11.837126561573573, 26.615531546728953, 36.95616551807949, 41.593674659729004, 50.73716006960188, 48.801701136997764, 50.073207582746235, 55.89065980911255, 65.62274101802281, 68.10681928907121, 56.146092959812705, 47.51593351364136, 54.38923747198922, 59.322281292506624, 53.9369410106114, 56.74855736323765, 55.67374052320208, 57.300904410226, 49.37685217176165, 50.811735085078645, 38.625598771231516, 24.253604343959264, 12.697202375956945, 18.819545030593872, 31.356528895241873, 25.36131395612444, 18.03928664752415, 16.215249027524674, 8.79194564478738, 4.566432109900883, 1.1247450751917702, 0.3493670145315783, 0.015198287055162447, 0.13564453779586724, 0.5468682295509747, 0.4286497602505343, 0.11936748693031923, 0.028735313431492875, 0.16904469127101557, 0.058167380546884875, 0.01793915292780314, 0.16167162119277886, 0.051847379854215045, 0.006565868280761476, 0.03271432081237435, 0.0403219740172582, 0.029779473652264903, 0.0203302458726934, 0.055531217716634274, 0.06485321000218391, 0.06283538256372724, 0.019325398274564316, 0.026903696358203888, 0.035311556088605096, 0.051026240523372374, 0.035312451754829714, 0.017852972195084606, 0.023285774780171256, 0.035983529673623185, 0.03520644083619118, 0.060827054615531645, 0.023731012496032884, 0.09450719878077507, 0.03493193270904677, 0.031668226766799173, 0.015831684228032827, 0.043089518190494606, 0.04514114345823016, 0.04118351671578629, 0.031795682784702094, 0.05177745342786823, 0.032662711438855956, 0.060389786293464046, 0.028713569776820283, 0.010160354531503149, 0.06439303433788673, 0.0631152850442699, 0.05349595192819834, 0.03134061309642025, 0.02265765660974596, 0.041481563222727606, 0.023063563043251634, 0.03226334608293005, 0.03482682424198304, 0.02666200218456132, 0.03850646875798702, 0.06334017190550055, 0.020510123809799552, 0.055740145434226306, 0.043896615239126344, 0.03291438686262284, 0.018566304185826863, 0.04404445105631437, 0.027325092049847757, 0.007504385264058198, 0.03117290638121111, 0.004557382573174047, 0.024632534477859735, 0.004146981269254216, 0.07433184888213873, 0.04917993316692965, 0.04612124997324177, 0.019803550027843033, 0.06517273892781564, 0.010040311508678963, 0.046873585853193483, 0.022502304320888858, 0.011403481575793453, 0.12526201563222067, 0.015573764585756829, 0.03735111021835889, 0.030134076053010564, 0.02212909988260695, 0.06949242856353521, 0.04112953586237771, 0.0477521326392889, 0.03799308916287763, 0.07239955078278269, 0.14629265213651316, 0.06306561628090483, 0.013952339849700885, 0.03699809219688177, 0.012007013877986797, 0.05510941660031676, 0.028863787251923765, 0.02655772492289543, 0.02205580792256764, 0.03245644697121211, 0.08343716458018337, 0.030509719824684516, 0.009959827077441981, 0.0435405438100653, 0.058646181997443945, 0.04664229701406189, 0.04695478953155024, 0.017712934441598396, 0.06631790926413876, 0.039190533837037425, 0.00945083421122815, 0.01222853859820004, 0.09605458432010242, 0.03057462169921824, 0.021098734278764044, 0.012885650569972183, 0.08294490099485431, 0.014140641799063554, 0.05614010790096862, 0.14513698486345156, 0.02541063602880708, 0.03010505171758788, 0.03499946390677776, 0.011561894905753434, 0.06376437164310898, 0.028698278990175043, 0.05420351128226944, 0.044442221854946444, 0.04216359948207225, 0.0660891140412007, 0.03697737991543753, 0.05706066279006856, 0.08361215876149279, 0.28253025668007986, 0.10262800087886197, 0.05522545287385583, 0.053698396243687184, 0.13564723836524145, 0.1995713167956897, 0.21955228676753386, 0.39582714864185875, 0.27923949754663874, 0.10769290516951255, 1.0252091991049903, 3.1399176503930772, 5.462186924048832, 12.389123593057905, 15.834468637193952, 28.64579517500741, 47.08084774017334, 59.46706090654646, 67.73822430201939, 70.96977588108608, 72.9553347996303, 75.62816088540214, 79.64133616856166, 83.9590093067714, 77.40459292275565, 72.13165364946637, 72.52510929107666, 73.75983197348458, 81.60320172991071, 78.0411799294608, 77.27441842215401, 80.39231831686837, 81.06671742030552, 76.00076498304094, 75.80528436388288, 67.19872447422573, 60.530732836042134, 50.555037362234934, 55.869311468941824, 60.068865231105256, 46.28727660860334, 34.1696321623666, 29.427128791809082, 19.72164007595607, 13.670377492904663, 5.491244724818638, 1.9588053141321455, 1.014296293258667, 0.31299495909895214, 0.3141825310885906, 0.11522760907454149, 0.12275488302111626, 0.1454940028488636, 0.08552932552993298, 0.026092567115223834, 0.04544197195874793, 0.12738892436027527, 0.054887416905590465, 0.07236105749117476, 0.0340326804268573, 0.0422114667349628, 0.04724404901000006, 0.010513291128778031, 0.09400301333516836, 0.034314160501318317, 0.04318742061566029, 0.07503849560660975, 0.06124239268579653, 0.02701846886027072, 0.03904573446405785, 0.03939854892502938, 0.022906600930062786, 0.026362357727651085, 0.021021645915295397, 0.034433494455048015, 0.02528211979993752, 0.04993516978408609, 0.05254330233271633, 0.03761941653543285, 0.08130071564976658, 0.0358120808377862, 0.011755756601425154, 0.020621507029448236, 0.021057358909664408, 0.019969222834333777, 0.021656591844345843, 0.043436487072280476, 0.03287112007715872, 0.03450782796634095, 0.04463725656803165, 0.10922282521745988, 0.027245259012228677, 0.008992756068307375, 0.08192616208855595, 0.03474234663216131, 0.02429527203951563, 0.05187404628044792, 0.00912655214779079, 0.036061428886439116, 0.06957243462758404, 0.010397278603964617, 0.015492830625069993, 0.018744380612458502, 0.015077115967869759, 0.040283216096993, 0.07447273989341088, 0.039854293755654774, 0.052932679653167725, 0.030798589145498614, 0.047809007444552014, 0.013188538424271559, 0.04447179580373423, 0.1037636852956244, 0.1299719578985657, 0.17453192254262312, 0.19592108338006906, 0.2188429326883384, 0.12243903854063579, 0.12757553506110395, 0.0793214493564197, 0.17251302301883698, 0.13810376583465508, 0.08165572517152343, 0.18064067832061223, 0.18897292550121034, 0.230759147554636, 0.16490891176675046, 0.10207774969083921, 0.2133124108825411, 0.15221263947231428, 0.27386845861162457, 0.16276263764926366, 0.10471711520637784, 0.21524512288825853, 0.155545264216406, 0.16786019983036177, 0.11070239796702351, 0.07696531792836529, 0.11913842707872391, 0.13374090780104908, 0.10879610132958208, 0.10535752334232841, 0.0958802415324109, 0.23497070584978375, 0.22570548658924444, 0.12469017345990453, 0.22099310159683228, 0.08324382281196968, 0.0931716315182192, 0.12137512277279582, 0.0772504722699523, 0.14726736769080162, 0.08595439379236527, 0.08389625458845071, 0.19315340689250401, 0.2123005251799311, 0.1371233370155096, 0.13403560913034848, 0.16442291784499372, 0.11900026377822671, 0.11404043063521385, 0.20701703083302292, 0.3192677710737501, 0.10591745722506728, 0.16394337000591414, 0.09707877186260053, 0.11165401618927717, 0.24470103372420582, 0.11934016911046845, 0.1484251655638218, 0.1916907975184066, 0.1282377988100052, 0.26292455728564945, 0.1554839653628213, 0.1526869490210499, 0.108579967570092, 0.3749592384057385, 0.18204937130212784, 0.31404269859194756, 0.1478371335459607, 0.42315148242882317, 0.2561615716133799, 0.22884277467216763, 0.4672903482403074, 0.5421939375145095, 0.7510162921888488, 0.6494010591081211, 1.4756437603916441, 2.5707576998642514, 6.856828910963876, 10.94868472644261, 26.700917959213257, 42.072016443525044, 54.67814704350063, 62.29423427581787, 71.70843887329102, 75.28507968357631, 82.14301422664097, 92.22582312992641, 99.32895960126604, 94.17016533442906, 86.1516523361206, 78.55148342677525, 84.64151000976562, 90.84477138519287, 81.79634775434221, 80.74329962049211, 80.99813870021275, 83.18367372240338, 75.33670479910714, 77.49052129473004, 74.07492583138603, 64.97846930367606, 57.41989231109619, 63.186494146074565, 59.210220745631624, 42.77395820617676, 30.909745829445974, 24.292465618678502, 14.563383425985064, 9.115618790899005, 3.116207791226251, 0.6864202469587326, 0.35633638341512, 0.17745777911373548, 0.6963333721671785, 0.6205832426037107, 0.16959438606032304, 0.18120398452239378, 0.3758836473737444, 0.20575963758996554, 0.1845294710780893, 0.46889516498361317, 0.16260384688419954, 0.2553834547953946, 0.11816079382385526, 0.13019884643810137, 0.1378942477915968, 0.19249335516776356, 0.19619304021554335, 0.12538940379662172, 0.1299706008285284, 0.1356789395213127, 0.2142127589987857, 0.0994228185819728, 0.195521385541984, 0.0669118445366621, 0.09543408440159899, 0.10192678243454013, 0.17222468634801252, 0.090867102678333, 0.10200043062546424, 0.08503776762102332, 0.18462971784174442, 0.07283825081373964, 0.17994117656988756, 0.14276949475918496, 0.1839213001408747, 0.1337405956749405, 0.08938877164785351, 0.199423274025321, 0.13254439271986485, 0.12032038079840796, 0.14517994970083237, 0.22555578819343022, 0.14185071763183388, 0.22910916752048902, 0.08567976352891751, 0.19786238563912256, 0.16008294001221657, 0.11685799301734992, 0.0997017982548901, 0.12918177672794887, 0.1012813870662025, 0.1170435044914484, 0.12666509034378187, 0.08909173615808998, 0.20207855797239713, 0.09778249410114118, 0.25375836342573166, 0.3196338271456105, 0.1704621644956725, 0.17760381342044898, 0.13280561513134412, 0.10591636478368725, 0.15167891739734582, 0.09378449791776282, 0.1006798589868205, 0.14989940502813884], [0.011700040394706386, 0.061294578814080784, 0.047680601477622986, 0.02827301055991224, 0.010374369565397501, 0.03400091141728418, 0.10774636015828166, 0.013022039501395608, 0.024782813021114895, 0.0194234533701092, 0.039255900508058925, 0.022920071546520506, 0.08376335671969823, 0.05007886653766036, 0.05524126613246543, 0.02126032908979271, 0.04082509416288563, 0.01228680185574506, 0.046443391258695295, 0.058484459961099286, 0.05247121137966003, 0.022415887797251344, 0.06582572031766176, 0.04232858866453171, 0.026477725644196783, 0.027728764406804527, 0.017818828312946216, 0.023457644307719808, 0.019901082651423554, 0.0428993010760418, 0.038405339898807664, 0.03772819587694747, 0.06644100230187178, 0.02534788171760738, 0.008185245961483036, 0.07933265875492777, 0.03199380822479725, 0.09487655253282615, 0.01822590861203415, 0.017246865700664263, 0.024497085317437137, 0.04135911479326231, 0.022739219911662594, 0.03232644305431417, 0.021531897463968823, 0.024424337881750295, 0.01708512839728168, 0.010886676227008658, 0.027510142120133554, 0.008354858511925807, 0.049556835621063194, 0.02905548018004213, 0.07733262250466005, 0.0203444543959839, 0.03598440498379724, 0.0526271048001945, 0.0544315567240119, 0.0387535301436271, 0.02761240752546915, 0.02764343353919685, 0.06381026096642017, 0.07361670689923422, 0.046293170390916724, 0.07719794687415872, 0.03999929329646485, 0.08140040601470641, 0.01896435996916677, 0.20398235081561975, 0.15775784477591515, 0.05519806041515299, 0.03406906347455723, 0.1886796219540494, 0.30186815187335014, 0.23523215896316937, 0.06131564732640982, 0.10415684205612966, 0.10490549009825502, 0.2486747790660177, 0.19150646669524057, 0.4149622161473547, 0.03738102004198091, 0.13254469127527305, 0.6784578827875001, 0.48530290169375284, 0.8839774546878678, 1.4292540039334978, 3.0811222110475813, 4.6354720166751315, 5.569710297243936, 4.533174557345254, 5.176849160875593, 4.417043668883188, 3.8316162484032765, 3.8481546980994086, 3.8216234360422408, 2.266661754676274, 2.4769583216735294, 3.4718435193811144, 2.585777533905847, 2.15613654255867, 1.693867136325155, 1.121300831437111, 0.5899230135338647, 0.1566090171358415, 0.3810842925948756, 0.5737219857318061, 0.40175393489854677, 0.3587926801826273, 0.127477405326707, 0.09022071664886815, 0.02545317678180124, 0.0779424694233707, 0.23329442579831394, 0.11960914039186069, 0.13962926183428082, 0.008805506696392382, 0.015360243186088545, 0.058922698588243554, 0.027282815925510864, 0.07715506346098014, 0.09185723454824515, 0.014594842114352753, 0.0388377193760659, 0.046153409140450616, 0.018981397983485034, 0.08177530339785985, 0.05115057188751442, 0.03711145843512245, 0.004969317790320409, 0.03167516139468976, 0.009086404078906136, 0.010464643560616034, 0.01693235114882035, 0.023706980482009903, 0.033161624667367766, 0.03143823053687811, 0.10227090825459786, 0.011436199686223907, 0.06476689356246165, 0.018834491759272556, 0.052611902223101685, 0.013590916475680257, 0.030248677224985192, 0.029776172579399178, 0.07004526496997901, 0.04614875439022269, 0.023468682376135672, 0.005048373057174363, 0.03246769368914621, 0.04321742543418493, 0.05145866410540683, 0.05450282325702054, 0.09413978563887732, 0.026281450908364992, 0.05270559433847666, 0.08130770456045866, 0.028109274970899736, 0.03656816562371595, 0.020638037838840058, 0.013192513791312064, 0.049988702804382355, 0.0548072751345379, 0.019236800260841846, 0.035892141184636524, 0.047030564929757795, 0.028547898666667085, 0.047224642908466716, 0.020841255684250166, 0.013490122643166354, 0.09464434427874428, 0.05792483141911881, 0.05837239311741931, 0.012493878869073731, 0.04404541118336575, 0.057195881248584816, 0.028454924102074335, 0.03730137020881687, 0.08210928511938878, 0.032972021627106836, 0.021198616329846636, 0.0035630047703827067, 0.027099947345310023, 0.0847425302490592, 0.021974161500111222, 0.009032653927403902, 0.0470813702392791, 0.024417194604341472, 0.04638607879834516, 0.043796527931200604, 0.03164668667263218, 0.014280777091958692, 0.05504359531083277, 0.040262500422873666, 0.04891360817211015, 0.04678668248068009, 0.032085033865379434, 0.05836986218179975, 0.04178094305098057, 0.049722567799368074, 0.006135795822566641, 0.019917148664327602, 0.0037678854506728904, 0.03590429374682052, 0.03711331422839846, 0.033124261136565886, 0.07161068597010203, 0.03614113639507975, 0.012730325422515827, 0.016650748938055973, 0.015461729972490242, 0.02874627855739423, 0.03503659673567329, 0.024121141294017434, 0.05727133434265852, 0.0071662161332954255, 0.01601470717495041, 0.014491552121138998, 0.00655938487865829, 0.029101790195064883, 0.0621219165623188, 0.036444265129310746, 0.023735726618074944, 0.023545426383082355, 0.0621326102742127, 0.06475781476391212, 0.059554075423095904, 0.029361211096069643, 0.013891602483844119, 0.05599549851779427, 0.017223527488697852, 0.08317351979868752, 0.06723999085703067, 0.03964929136314562, 0.021799372575644935, 0.042462134534226995, 0.03930263800014343, 0.02847674409193652, 0.10788321388619286, 0.0791375052982143, 0.15962768372680458, 0.024603447377947823, 0.035815853492489884, 0.13819891001496995, 0.17746958562305995, 0.12434616977615015, 0.04604935579534088, 0.16013885129775318, 0.06488214273537908, 0.21766506374946662, 0.1828989242868764, 0.06421755839671407, 0.08093339071742126, 0.3067959988755839, 0.2557807777609144, 0.3989255838096142, 0.6301848930971963, 0.12865722844643251, 0.567133193569524, 2.1991174476487294, 2.3463719231741766, 3.6022659838199615, 5.292260042258671, 9.511382971491132, 14.632504974092756, 14.63924993787493, 11.801449298858643, 12.90266581944057, 14.28753559929984, 12.358146786689758, 11.859824589320592, 10.616239479609899, 9.973374775477819, 8.934805818966456, 9.51283253942217, 7.514478513172694, 3.765081601483481, 0.43892470747232437, 1.4211123436689377, 1.362126263124602, 0.29718696592109545, 0.39088475384882515, 0.23164973833731242, 0.1967214968587671, 0.5105628605399812, 0.15483014258955205, 0.05744987726211548, 0.12594072706997395, 0.047481437878949304, 0.09288056035126958, 0.03399379697761365, 0.1277447345533541, 0.05386099359020591, 0.07821364594357354, 0.01290672501948263, 0.0191673420236579, 0.14427213769938263, 0.05193185407136168, 0.03948374238929578, 0.028645458431648355, 0.0675580066495708, 0.024923198523798158, 0.022852640432704772, 0.03497325888435755, 0.01741618224020515, 0.026707628575552787, 0.03561410128272005, 0.03564590082636901, 0.04019002949020692, 0.055346649406211715, 0.028337372999106134, 0.04060383407132966, 0.09606341206069503, 0.025207827000745704, 0.013981791662185319, 0.032753740304282734, 0.031132815139634267, 0.007935642614029348, 0.03447877988219261, 0.0784135695014681, 0.02535267387117658, 0.06627458480319806, 0.021650997323117087, 0.03302580231268491, 0.03543073058660541, 0.10047806945762464, 0.016426606769008294, 0.0268385010172746, 0.016983739998457686, 0.0164495989281152, 0.06020631042442151, 0.06983107860599246, 0.050602427550724575, 0.05400728574022651, 0.06779085951192038, 0.02319451860551323, 0.04075354603784425, 0.0364148675996278, 0.04233853938058019, 0.01418540220973747, 0.09028650061892611, 0.018283584088619267, 0.04671670516420688, 0.04950711936024683, 0.025142397565234984, 0.010634069513928677, 0.03239572147971817, 0.016476246694635068, 0.07158021296241454, 0.04683676854308162, 0.0076465222352583495, 0.03255006444773503, 0.05328145683077829, 0.11425068149609224, 0.1364761638854231, 0.14577782047646387, 0.07696714997291565, 0.10258253903261252, 0.16153009235858917, 0.16723400700305188, 0.10227683186531067, 0.07969561392175299, 0.15019566698798112, 0.17205763102642127, 0.13091054824846132, 0.16680182090827397, 0.18441507007394517, 0.1546187653605427, 0.17104962654411793, 0.22836839726993016, 0.13266000151634216, 0.11474644632211753, 0.07536525771554027, 0.13241419542048657, 0.09968978139970984, 0.15679184161126614, 0.2057243673396962, 0.088903659821621, 0.09570775793067046, 0.08059406892529555, 0.08367653137871198, 0.11174198146909475, 0.26989034350429264, 0.0956125051847526, 0.11748077959886619, 0.19678659550845623, 0.1222208488200392, 0.10479377609278474, 0.27873692022902624, 0.054267541239304204, 0.1554768000330244, 0.07088859578860657, 0.14215141721069813, 0.14813897306365625, 0.15984602272510529, 0.08721633322004761, 0.15211003140679427, 0.10680085553654603, 0.11539899344955172, 0.06334681476333312, 0.1358466190951211, 0.17512154233242783, 0.09142450562545232, 0.17670977567987783, 0.10761299410036632, 0.16056369564362935, 0.0774558037519455, 0.182507436722517, 0.12182512719716344, 0.0948075455214296, 0.18314152769744396, 0.10334308179361479, 0.1473011723054307, 0.14232877269387245, 0.14839417008416994, 0.13877966813743114, 0.21668899112514087, 0.14145743873502525, 0.16923617385327816, 0.2634468121188027, 0.5316751790898187, 0.21779712023479597, 0.1698460682694401, 0.2390176515494074, 0.29345152207783287, 0.41717975001249996, 0.26732765244586126, 0.17187982771013463, 0.1666733335171427, 0.31257890856691767, 0.357828997607742, 0.4462316339569432, 0.5038206651806831, 0.15559276166771138, 0.15099054362092698, 0.7428696379065514, 1.0336424665791648, 1.587819169674601, 2.271130532026291, 5.093723952770233, 7.323324016162327, 7.940480385507856, 6.419793733528682, 7.273250954491751, 9.002189448901586, 7.297165785517011, 6.805960280554635, 5.941632168633597, 5.476691288607461, 5.117715213979993, 5.963365265301295, 4.94261018718992, 4.000005841255188, 1.7612713937248503, 1.4269259231431144, 0.6939701704042298, 0.17018017891262258, 0.5554381811193058, 0.7060949397938592, 0.9651567872081483, 0.6908545004470008, 0.2912263071962765, 0.158885868532317, 0.1683569010347128, 0.16348225117794105, 0.37759227997490336, 0.27952651785952704, 0.20811876814280236, 0.07170785897012268, 0.22845329557146343, 0.07019117714038917, 0.1634971789483513, 0.48645429419619696, 0.15364072498466286, 0.11851539622460093, 0.1293747927993536, 0.11036394469972167, 0.11488382252199308, 0.1919517892279795, 0.1117154982473169, 0.11065944670034306, 0.09366213769784995, 0.09645118803850242, 0.08617233924035515, 0.11687250009604863, 0.15507528372108936, 0.10321028570511512, 0.12119581310876779, 0.22506212682596274, 0.1447979344853333, 0.10938907986772911, 0.15073059685528278, 0.1307181835706745, 0.11319751372294766, 0.08798716257193259, 0.10222121234983206, 0.11844177517507758, 0.10947220719286374, 0.1276509610137769, 0.14775083746228898, 0.059687068286750994, 0.12156765029898711, 0.11000786309263536, 0.1664818645055805, 0.06886284984648228, 0.19152324008090155, 0.12554011999496392, 0.2649003969771521, 0.125501117802092, 0.15121161033000263, 0.09153735956975392, 0.15654568267720087, 0.1534792065088238, 0.10313595219382218, 0.15801898576319218, 0.17924577317067555, 0.18551683452512535, 0.0979357548058033, 0.12394735403358936, 0.11928280575999192, 0.10363156774214335, 0.06801362255854265, 0.12940585613250732, 0.11626848179314818, 0.15719852836004325, 0.1197912727615663, 0.10304923541843891, 0.17379987825240406, 0.18536083932433808], [0.08496074032570634, 0.0031874882240247515, 0.02197190367483667, 0.033526564549122534, 0.0815411273922239, 0.04968416610998767, 0.02706651253226612, 0.026989778703344718, 0.012087531387805939, 0.03424178795622928, 0.01849810972011515, 0.028827526340527192, 0.02819091291166842, 0.07747599016875029, 0.041220008329089196, 0.049355487139629464, 0.051846029569527934, 0.06871148903987237, 0.015291614457964897, 0.09783227143010922, 0.03804771801722901, 0.030975727497466972, 0.05804628918745688, 0.0075640318848724875, 0.0536518996315343, 0.010764427965373864, 0.027942348570962037, 0.038674765798662386, 0.021502672960715632, 0.0747966385845627, 0.019770690273227434, 0.05165116788287248, 0.0384752018643277, 0.033601624092885425, 0.04263868934607931, 0.05207069590687752, 0.037994351238012314, 0.01307196356356144, 0.022425948775240352, 0.0461625015097005, 0.044690117838659456, 0.03879990801215172, 0.016072262211569717, 0.04377973758216415, 0.04969296331650444, 0.019396868368078555, 0.0776175529296909, 0.06540867912450007, 0.06632039270230702, 0.03836398318942104, 0.03533141341592584, 0.04237962806863444, 0.007785849223312522, 0.06294365639665297, 0.017658671996157085, 0.012051895576795297, 0.010449217915135835, 0.026184552715026906, 0.0581530091751899, 0.054777657080973895, 0.04167024345536317, 0.011595149907017393, 0.04205565134595547, 0.04139204749039241, 0.0508711002767086, 0.016347141836636832, 0.006161484310203897, 0.031203528666602712, 0.02535465688976858, 0.01729856667641018, 0.15194693872971193, 0.1759734701897417, 0.21807777588920935, 0.1748184407395976, 0.10965221574796097, 0.014150622201019099, 0.024195069380636727, 0.019828509938504015, 0.05290736011894686, 0.05518927677933659, 0.15252532197960786, 0.07930206361093692, 0.05705492916916098, 0.015948241277198707, 0.0689831744613392, 0.07077159599534102, 0.01752625249459275, 0.12960123350577696, 0.3811361055288996, 0.46617369673081804, 0.2549207753368786, 0.15518702486796038, 0.27526070390428814, 0.32098639171038357, 0.30541767712150303, 0.17416763066181115, 0.31849014280097826, 0.33367456229669706, 0.16957597061991692, 0.10163947713694402, 0.10374034369098288, 0.027285526672910367, 0.056377048936805556, 0.06591066611664635, 0.1751239307756935, 0.1650218064231532, 0.037619396179382286, 0.11107866599091462, 0.018657719816214273, 0.017815802046763043, 0.011423354170152118, 0.09742365764187914, 0.16751251848680632, 0.02180309603655977, 0.03443705676389592, 0.06978558283299208, 0.04439843599019306, 0.023440957435273697, 0.029311040216790776, 0.013064481866812068, 0.043853792894099436, 0.01710323680059186, 0.08923699014953204, 0.048544274776109626, 0.018550709754760777, 0.022751518358875598, 0.01269701189760651, 0.03677569555916956, 0.02940182141693575, 0.05569733326722469, 0.03505137522837945, 0.0057443913787470335, 0.01211240393708327, 0.05361016972788742, 0.03229150189352887, 0.0321726564850126, 0.024075726945219294, 0.0181996764482132, 0.03793333736913545, 0.010289370331780186, 0.03117782236742122, 0.04001526940347893, 0.013552708168780165, 0.029624387688402618, 0.016221556879047836, 0.02163060904214425, 0.033038243252251825, 0.01016500758539353, 0.003180939512926021, 0.07612309990716831, 0.030565797351300716, 0.01860292811345841, 0.04202413000166416, 0.0002583666537248064, 0.051860787706183534, 0.012260465367164994, 0.0468606767244637, 0.06197539371039186, 0.01617315867250519, 0.03365376272371837, 0.010227335267700255, 0.06724248786589929, 0.033725429592388015, 0.033144875030432425, 0.03094143433762448, 0.0586899339354464, 0.06568926692541156, 0.017832168311412846, 0.013458888828089195, 0.017332535835781267, 0.031104482909930602, 0.14747961344463484, 0.03644879095788513, 0.021613391216046045, 0.03398938649999244, 0.01954931822339339, 0.023639126980145062, 0.01745159667916596, 0.02335373854397663, 0.04122135182842612, 0.055640041162925105, 0.02895044974450554, 0.06416530441492796, 0.024537012014271956, 0.021863246469625404, 0.021981036756187677, 0.044857865265969715, 0.015723427358482565, 0.024793013098782728, 0.021399625543771044, 0.04464212505679045, 0.033345256599464586, 0.01204857075520392, 0.07791697686272007, 0.029397068279130117, 0.02211414327445839, 0.08078535473240273, 0.020179156480090957, 0.053841065016708205, 0.06161052507481404, 0.024883103889546225, 0.029586291339780604, 0.07661263578172241, 0.036616931935506206, 0.023217022219406705, 0.10264187013464314, 0.03772582778973239, 0.04398565599694848, 0.014347393963752049, 0.027547678677365184, 0.018025540613702366, 0.04394785141838448, 0.025415149983018637, 0.0401519840317113, 0.03578429822144764, 0.01061849034990051, 0.034014665322112184, 0.02898552661229457, 0.03379219065287283, 0.06974508786307913, 0.032033780722745826, 0.04338050114789179, 0.03907564089500478, 0.016879359260201454, 0.008365955103987029, 0.08590325939335994, 0.04230582720733114, 0.045293138695082495, 0.030583741209868873, 0.034466006460466554, 0.014130334003961511, 0.024093010928481817, 0.019740704114415815, 0.018232524328465973, 0.001856340344862214, 0.05472696033705558, 0.03485990282414215, 0.02991442408944879, 0.02398941050549703, 0.13874492714447634, 0.04123960442042776, 0.06656239221670798, 0.041504477350307364, 0.020839686572019542, 0.09172869965966259, 0.06161306958113398, 0.13835565160427774, 0.06291048960494143, 0.15591615145759924, 0.1485368117157902, 0.0652105672551053, 0.03462699567899108, 0.05054260790348053, 0.0624213269246476, 0.0879285710730723, 0.0426783565032695, 0.15094353471483501, 0.03580426750704646, 0.081775527314416, 0.03779052271108542, 0.07383338348673922, 0.1097490969779236, 0.10892901955438511, 0.13265868515840598, 0.2111953544829573, 0.14019427794430936, 0.048688171697514396, 0.1821022427507809, 0.1661151841815029, 0.08804430200585298, 0.19055099439408096, 0.24719155579805374, 0.2699314627264227, 0.2574970913784844, 0.15322551583605154, 0.15725866013339587, 0.10559363995811769, 0.0483974940808756, 0.05457730943869267, 0.05695132365716355, 0.15263508180422442, 0.024879114103636572, 0.10452047575797353, 0.14986612967082433, 0.015527116999562298, 0.014614911483866828, 0.11186431454760687, 0.020301940784390484, 0.009621693569767688, 0.038248547419373474, 0.09302700856434447, 0.059315611076142104, 0.0854728374896305, 0.050841522935245714, 0.05127486253955534, 0.0648210813690509, 0.0037958974966646303, 0.050416132368679555, 0.017209178169390986, 0.08186402863689832, 0.029988082458398173, 0.0714829381821411, 0.048524590475218635, 0.07536968854921204, 0.05832339610372271, 0.05007291578554681, 0.02880723135811942, 0.01306563537634377, 0.0500799488010151, 0.0346701572915273, 0.02513954771815666, 0.017455067385786345, 0.046337750141641924, 0.05672567683671202, 0.035477976979953904, 0.027360791473516395, 0.0441034734249115, 0.007474998760569308, 0.03971684970227735, 0.010522258817218244, 0.06675265343593699, 0.010355251841247082, 0.041134848791573725, 0.03652464099494474, 0.0822834854147264, 0.04409843869507313, 0.027986416027748158, 0.04962610386844192, 0.022739021440169642, 0.023620099161884615, 0.06854432515267815, 0.03742808323087437, 0.06801935617945024, 0.047010962053069046, 0.03495699779263564, 0.01958871735925121, 0.0780082873201796, 0.027768219521801387, 0.016437147810523, 0.014674142501982195, 0.030029201680528264, 0.038907401529806, 0.04312022868543863, 0.017011071389008845, 0.018502538857449378, 0.04182769411376544, 0.0695184843082513, 0.060494138193981986, 0.019028725801035762, 0.02825236104295722, 0.012712582579946943, 0.044652662705630064, 0.14210401475429535, 0.0657825315637248, 0.11840528356177465, 0.07741313746997289, 0.1918729841709137, 0.14387235843709537, 0.18245474169296877, 0.13450405613652297, 0.09751397743821144, 0.1250113919377327, 0.10617991457028048, 0.1055746070508446, 0.11732743068465165, 0.1488526833376714, 0.11141884273716382, 0.16497637171830448, 0.19765674881637096, 0.21445215972406523, 0.08252342218267066, 0.1697538417897054, 0.15983431121068342, 0.11315821976001773, 0.2358618394604751, 0.12182420438953809, 0.11037058077220406, 0.1409629631255354, 0.2630167566239834, 0.14574663500700677, 0.1647739375808409, 0.1560876172568117, 0.12747040284531458, 0.10555863433650561, 0.1667334788611957, 0.20148870748068604, 0.15072534499423845, 0.13567853240030153, 0.14287137000688485, 0.11224428058734962, 0.17439742333122663, 0.10976646068905081, 0.08362677440579448, 0.09066677878477744, 0.0507741579785943, 0.14755636932594435, 0.12466565120433058, 0.147298308887652, 0.17943846354527132, 0.16288900801113673, 0.09304269629397563, 0.2174519087587084, 0.1447193194180727, 0.16625136615974562, 0.10278026413704668, 0.13490699737199716, 0.16399853490293026, 0.09207815876496689, 0.1525364499539137, 0.10483718876327787, 0.09858227654227189, 0.1399804444185325, 0.13632996673030512, 0.11840522927897316, 0.1031237385634865, 0.18580967666847364, 0.1207529604434967, 0.11110512885664191, 0.06799579744360276, 0.21104898090873445, 0.1363819967955351, 0.10539980285934039, 0.297445433480399, 0.3082512393593788, 0.6688229569367, 0.32038428687623566, 0.2446120913539614, 0.17533777787217072, 0.09604703222534486, 0.10921078800622906, 0.20259747441325868, 0.16504117181258543, 0.2342948578298092, 0.18530845642089844, 0.1162614385996546, 0.16500128752418927, 0.18073514396590845, 0.21436169743537903, 0.1449911134051425, 0.28248259638037, 0.4320522333894457, 0.5610560168113027, 0.3021338390452521, 0.3510787955352238, 0.45363018981048037, 0.5491720459290913, 0.49474854341575075, 0.35357363309179035, 0.6441755795053073, 0.3462091396961893, 0.3079168844435896, 0.15373232721218041, 0.10157344889427934, 0.2141924708017281, 0.1210158249097211, 0.1405365038663149, 0.30926551350525444, 0.5602396577596664, 0.31129778016890797, 0.3045550419815949, 0.07648343592882156, 0.09697508492640086, 0.17518334330192634, 0.18054115080407687, 0.36988556065729683, 0.2643604730921132, 0.1949138795690877, 0.1656331664749554, 0.12067737164241926, 0.12343455797859601, 0.06253458120461021, 0.2400266874049391, 0.09131533612630197, 0.13699242046901158, 0.15213992765971593, 0.15461546768035206, 0.08494702713297946, 0.17180806584656239, 0.1362082782600607, 0.12843134413872445, 0.17424199809985502, 0.10706406605562993, 0.11459380308432238, 0.09632646651672465, 0.21270082012883254, 0.1296460303877081, 0.10535033087113074, 0.15779719980699675, 0.16709296671407564, 0.2112457967762436, 0.12181846398328032, 0.14915115732167447, 0.15244947533522332, 0.0643488277814218, 0.1155607561979975, 0.14313753215329988, 0.11269095340477568, 0.16641399743301527, 0.14104000399155275, 0.18795117389942917, 0.10406737042857067, 0.12135383034391062, 0.14055078024310724, 0.13157995018575872, 0.09182397276163101, 0.11575356870889664, 0.19384343629436834, 0.15449668333998748, 0.15854315406509809, 0.20282666997185775, 0.12499358717884336, 0.08576519787311554, 0.15549054715250218, 0.15971400695187704, 0.07235407536583287, 0.08171194858316864, 0.21352008331034864, 0.1468199688409056, 0.09401224141142198, 0.08011677382247788, 0.09012261405587196, 0.11173741492841925, 0.17685374724013464, 0.21610640095812933, 0.14418733439275197, 0.17314900032111577, 0.05252734658175281, 0.07174956173236881], [0.07624348559017692, 0.0732418977256332, 0.02454581091712628, 0.04473334391202245, 0.05740343154008899, 0.06040466656642301, 0.003506674913556448, 0.06166243300374065, 0.02751065102139754, 0.03840893952708159, 0.0285320277325809, 0.02535375952720642, 0.024986633066354052, 0.07598663972956793, 0.021611240260036926, 0.08757316800100462, 0.03558494463296873, 0.03128686633759311, 0.031067597746316875, 0.03830714909625905, 0.07021800641502653, 0.03430018267993416, 0.02903003172416772, 0.01810910220124892, 0.027669119482327784, 0.03965722343751362, 0.05421978933736682, 0.051119854607220204, 0.062059084219591956, 0.011345923994667828, 0.03696650978443878, 0.05718537074114595, 0.021122925748516406, 0.0026409562560729682, 0.05960054150117295, 0.04615937685593963, 0.017250614606642296, 0.014738391286560466, 0.015452702064067125, 0.004134051360389484, 0.012882817686269326, 0.048307506766702445, 0.019736268191731403, 0.03071273410958903, 0.03409252721550209, 0.06771155912429094, 0.03840776226882424, 0.03542299528739282, 0.03983535923595939, 0.06628875939973763, 0.005683611604451601, 0.0339840328586953, 0.03305458576817598, 0.024682756247264997, 0.03224730212241411, 0.0272126910276711, 0.05742801486381462, 0.07231417072138616, 0.010796396294608712, 0.0520447996178908, 0.06580284690218312, 0.07517826024975095, 0.03164096662242498, 0.027525901095941663, 0.05929639496441398, 0.05897126133952822, 0.024072503903880715, 0.05626184047598924, 0.07048477245760815, 0.05020407660465155, 0.0857112475537828, 0.0493506525776216, 0.13972755441708223, 0.10183178753192935, 0.07349505914109093, 0.023099538969940374, 0.03360816856314029, 0.044760773690151315, 0.045639021920838525, 0.17770498299172946, 0.1244607607700995, 0.041710860561579466, 0.08634302472429616, 0.03927570015990308, 0.09318767208606005, 0.11219736667616026, 0.012774040889261025, 0.009636925832767571, 0.02568817720748484, 0.2733603444482599, 0.10829402612788336, 0.11143683070050818, 0.02577772856290851, 0.11252222888703857, 0.09947423796568598, 0.04745988082140684, 0.12118872920317308, 0.06158925300197942, 0.081375503779522, 0.03300774649583867, 0.004835531888862273, 0.03654317857165422, 0.05607078197811331, 0.027619050383301716, 0.1434187034943274, 0.09420181731028215, 0.07207201514393091, 0.0734213295259646, 0.05517065777842488, 0.035943251834916215, 0.030155171706740345, 0.11983300266521317, 0.10190503538719245, 0.1329740546643734, 0.05897589573370559, 0.08858085357184921, 0.06399997935763427, 0.05552061899964299, 0.0510030346257346, 0.042485910401280434, 0.06068980733730963, 0.04114958317950368, 0.004904651706705668, 0.011449070647358894, 0.01725071299422, 0.05116673119898353, 0.017604742032874907, 0.050779755892498155, 0.05310831844274487, 0.01681771096108215, 0.01418170504205461, 0.028937292950493947, 0.06643835601529904, 0.06885578629693814, 0.02953540121338197, 0.07597095199993678, 0.029002065903374126, 0.016847359548721994, 0.05065977733050074, 0.02006345777772367, 0.007914105912537446, 0.019752441073900888, 0.028954850044101477, 0.03790307131462863, 0.03642612788826227, 0.019398615595751574, 0.12102153817457811, 0.07998384202697448, 0.07740118846829448, 0.004468225192145577, 0.03669850202277303, 0.05925813916006258, 0.05770898942968675, 0.00857065724475043, 0.05059621895530394, 0.09871161888752665, 0.07315026835671493, 0.02224316161924175, 0.06088941198374544, 0.037161195051989386, 0.033387325770620785, 0.0980625662154385, 0.011831437004730105, 0.05880527810326644, 0.06031873010631118, 0.07244854779647929, 0.013660927718904401, 0.032682331278920174, 0.05531121970021299, 0.007950446551798709, 0.036201902598674805, 0.056694752603237114, 0.032536765161369524, 0.0389353164604732, 0.04202047609058874, 0.017349997934486185, 0.0728103087416717, 0.0256227325049362, 0.034564835085932694, 0.04193133015983871, 0.0009388710937595793, 0.052534287994993586, 0.04868307589952435, 0.031847767132733545, 0.03355677292815276, 0.025917990232950876, 0.07424367325646536, 0.006774141212060515, 0.037965055488582165, 0.03493037547117897, 0.026589940069243312, 0.02474349022044667, 0.024324659391173294, 0.03867877933329769, 0.019883834291249514, 0.08498421763735158, 0.030693178730351583, 0.026592036742450934, 0.03184187066342149, 0.01028592252571668, 0.030651716848037074, 0.03012438996561936, 0.023751494075570787, 0.011949084798938461, 0.014231048956779497, 0.05349862535617181, 0.038407657095896344, 0.04781324489574347, 0.005252794029989413, 0.03852142706247313, 0.02399104238221688, 0.05623684663857732, 0.030300934599446397, 0.008105442609771021, 0.1015518307685852, 0.007692682124408228, 0.015120828890108635, 0.043049498195094724, 0.03421196294948459, 0.010213948619951094, 0.021978817946676697, 0.08143482809620244, 0.011143729888967105, 0.02488679681638522, 0.06858693036649909, 0.03263925787593637, 0.0719481146495257, 0.026789300443072404, 0.10327743353056056, 0.016131326988605515, 0.02472893225162157, 0.0433990217612258, 0.04366376916212695, 0.027800312531845908, 0.017900259300534214, 0.052332539177898846, 0.09180928247847728, 0.1625952837722642, 0.027060029130162935, 0.0467804535292089, 0.021496452490932176, 0.10229211925928082, 0.0143186766654253, 0.13607608606772764, 0.047506564030689855, 0.04856312447892768, 0.10256519567753587, 0.1291580144315958, 0.02946830427806292, 0.11031854392162391, 0.0253619528375566, 0.00941347237676382, 0.058079571330121586, 0.0528424243176622, 0.029280886120562042, 0.12501131051353045, 0.036552186124026775, 0.05297975641276155, 0.04612860529284392, 0.039316324051469564, 0.0853184572021876, 0.06790459555174623, 0.05657576809504202, 0.02629440414187099, 0.1433325024055583, 0.09827594512275287, 0.08907701873353549, 0.05177510230402861, 0.1301834708345788, 0.06443983289812293, 0.09381798362093312, 0.04947453950132642, 0.07477898310337748, 0.06889916504068033, 0.09445066324302129, 0.04081415617838502, 0.040353023779711554, 0.0779656617503081, 0.031719228851475885, 0.058757027478090355, 0.1587235222437552, 0.06340031724955354, 0.04690763134775417, 0.1495263057627848, 0.040547447811279974, 0.0424881359961416, 0.027337066496589353, 0.04061975928821734, 0.06034381554595061, 0.04180152980344636, 0.0774927024862596, 0.11838441182460104, 0.027134705301640288, 0.05730023314910276, 0.033612792779292376, 0.11136042087205819, 0.022246011466320072, 0.017126152624509165, 0.023285866382398775, 0.015870951049562012, 0.03586807354752507, 0.03549470965351377, 0.015189701890838998, 0.029600733957652534, 0.03495484344395144, 0.03727037472916501, 0.04201781623331564, 0.06902114528098277, 0.008052532993523138, 0.030156216650669063, 0.0202518055282001, 0.03587596830246704, 0.032987339555152824, 0.02111438468896917, 0.06862146779894829, 0.01308655969998134, 0.00870608604912247, 0.03570086555555463, 0.02461945401903774, 0.09026510640978813, 0.06663593862737928, 0.03115101344883442, 0.06016821746847459, 0.0282471753390772, 0.01048984011036477, 0.023456779175571034, 0.007386363427420812, 0.07457923596458775, 0.08459176655326571, 0.05635224848187395, 0.015799798171168992, 0.045874270011803935, 0.026685328522164906, 0.031635772436857224, 0.0639839523604938, 0.0069036192643190065, 0.027459791429074745, 0.038919347138809304, 0.014652680439342345, 0.09707076514938048, 0.08219794929027557, 0.089692355000547, 0.014385736281318324, 0.02276534350988056, 0.027817457415429608, 0.015692357239978652, 0.011340878238635404, 0.04267994088253804, 0.015705564924116646, 0.05420656808252845, 0.034114566032907793, 0.010382249053301556, 0.16674641173865112, 0.10847156481551272, 0.16803337553782122, 0.11221355652170521, 0.12647081219724246, 0.08303583147270338, 0.10375503397413663, 0.29102708931480137, 0.09791766506220613, 0.2365532395030771, 0.15808461367019586, 0.0709381831277694, 0.15713793518287794, 0.1407666765153408, 0.17891843430697918, 0.19696034118533134, 0.17340563583586896, 0.1149054542183876, 0.12293857602136475, 0.11149833311459847, 0.12974430939980916, 0.26634950350437847, 0.06429804622062615, 0.08689822921795504, 0.1877921795738595, 0.20486424277935708, 0.13945593684911728, 0.0990448406498347, 0.14317706360348634, 0.12473446822592191, 0.10863529531551258, 0.09992578266454594, 0.06468842098755495, 0.13039197107510908, 0.1938945571226733, 0.21385855014835084, 0.12631788397473948, 0.04093618052346366, 0.16568952559360436, 0.08891292860997574, 0.06136399294648852, 0.11577837594917842, 0.11540881863662175, 0.107816778522517, 0.08352544877145972, 0.1666025894560984, 0.14517240439142498, 0.15346737285809858, 0.16805799278829778, 0.12506437195198877, 0.13610400099839481, 0.08101670124701091, 0.18004947075886385, 0.06171980992491756, 0.0685367730579206, 0.09550366816776139, 0.14057207267199243, 0.25634417895759853, 0.11884886904486588, 0.1972575123820986, 0.11916100872414452, 0.2874835894576141, 0.19642267003655434, 0.14084043327186788, 0.20999166050127574, 0.14764578667070183, 0.20444999715047224, 0.30482832874570576, 0.16221975535154343, 0.08967661977346454, 0.14706923546535627, 0.19073863646813802, 0.329548390848296, 0.26755949429103304, 0.134623220456498, 0.10200996404247624, 0.11196497521762337, 0.1865468371127333, 0.2726147973111698, 0.38369019276329447, 0.21539134718477726, 0.12039341830781528, 0.18035482508795603, 0.0942460238667471, 0.17999103532305785, 0.1817690006324223, 0.09853997666920934, 0.09140614446784769, 0.22457597005580152, 0.2757457478770188, 0.20124146289059094, 0.2709024463381086, 0.36114866233297754, 0.31276081023471697, 0.18993909151426383, 0.22790919191070966, 0.24671240150928497, 0.19654583771313938, 0.17805015375571592, 0.2615088075399399, 0.19982713806842053, 0.18325584727738584, 0.11517371982336044, 0.23545892536640167, 0.35464954535876003, 0.45280902673091206, 0.2051385473459959, 0.23458239382931165, 0.11648032042597022, 0.08858955917613846, 0.1047093595511147, 0.1303545973662819, 0.27391231911523, 0.2446191752595561, 0.16562004360769475, 0.21267306804656982, 0.10382739294852529, 0.1895608218120677, 0.1951425051582711, 0.3576175118131297, 0.12873891049197742, 0.1652172380792243, 0.11751902183251721, 0.11328009822006736, 0.125790092295834, 0.10543642339429685, 0.11778302623757295, 0.10599647941333906, 0.11551787278481893, 0.11027304814862353, 0.17778171173163823, 0.23191048577427864, 0.123994023672172, 0.17803281040063926, 0.1352835978780474, 0.13340533152222633, 0.1659568412495511, 0.08327369870884077, 0.1408265640160867, 0.12970589074705327, 0.13732054643332958, 0.11643872622932706, 0.12580051459372044, 0.16970703644411905, 0.16258400652025426, 0.15885860499526772, 0.35413478155221256, 0.18307855964771338, 0.13863938780767576, 0.0991534333942192, 0.1550849053476538, 0.22449134316827568, 0.17517232389322349, 0.13247279370469706, 0.1218018534460238, 0.22384104877710342, 0.18996020752404416, 0.1611137839832476, 0.1628232036850282, 0.06598224477576357, 0.10314448137900659, 0.15930892154574394, 0.08053258008190564, 0.15861168610198156, 0.1867790182254144, 0.15215889949883732, 0.13328432158700057, 0.11376659425773791, 0.10330827294715814, 0.05290069690506373, 0.07539427865828786, 0.09701775799372367, 0.16241925821772643, 0.19372790892209324, 0.1541017759591341, 0.11690899170935154], [0.025374146111841713, 0.01769773695351822, 0.048500533016132455, 0.017033149222178117, 0.059102666431239674, 0.02846569414915783, 0.07141429757965462, 0.05797125678509474, 0.008065070624330213, 0.04569488570892385, 0.04599518155945199, 0.02580331272578665, 0.024289592701409544, 0.041622291385595284, 0.03572705700727446, 0.036797683486448865, 0.017375821280958395, 0.029245174822530577, 0.039903758958514245, 0.03165156194674117, 0.0459908592913832, 0.04767295438796282, 0.03315280371212533, 0.03258839828361358, 0.005386321664056075, 0.017981708947835223, 0.02020131404112492, 0.12471605278551579, 0.02408565391254212, 0.10225056577473879, 0.012524542714735227, 0.07742780061172587, 0.012463893558430885, 0.058337434993258545, 0.07042185869067907, 0.027544832222961953, 0.04036210597093616, 0.017345512818012918, 0.027180823630520275, 0.03227541382823672, 0.046599973392273696, 0.03548602779795017, 0.06882114029888596, 0.05574711398886783, 0.09962557841624532, 0.030454110487231185, 0.032297500143093724, 0.03835915541276336, 0.023407098537843143, 0.021665906433814337, 0.07998931780457497, 0.036382094358227084, 0.005030380428901741, 0.011070175844776844, 0.04649673428918634, 0.058140388423843045, 0.024283192419846143, 0.06011703557201794, 0.03222361785758819, 0.06557998207530805, 0.018047345336526632, 0.11685029843023845, 0.023738813952409794, 0.033693290781229734, 0.02637072915344366, 0.03026645484247378, 0.042689993378839323, 0.08367014636418649, 0.032297086236732345, 0.03132371078910572, 0.05193319417802351, 0.03821191331371665, 0.03996236742075, 0.06686456421656267, 0.124899189387049, 0.03344513356153454, 0.042650200692670684, 0.03270982212520071, 0.08266821477030005, 0.14059883409312793, 0.07707103368427072, 0.03328970493748784, 0.09110072907060385, 0.0180754010632102, 0.05369215372151562, 0.07886626092450959, 0.024916893237137368, 0.0274892839536603, 0.08517049585602113, 0.08461045340767928, 0.024616298831201026, 0.06436271739325353, 0.04164869996852108, 0.13271532926176274, 0.14024097472429276, 0.08259498048573732, 0.05262188008055091, 0.06703852702464376, 0.054191457107663155, 0.047044871840626, 0.029020050474043404, 0.032237677103174586, 0.09058628417551517, 0.056740645319223404, 0.15945456230214664, 0.08334503309535128, 0.11246364417352847, 0.048706712666898966, 0.037127366688634665, 0.044433655350336006, 0.05203557154163718, 0.06741146344159331, 0.11127565827752862, 0.11329085978546313, 0.024038324398653846, 0.004222761756474418, 0.01629933056288532, 0.05577039113268256, 0.049943566654941866, 0.04831994431359427, 0.02725670250531818, 0.053560392398919375, 0.03147589601576328, 0.025839887459629347, 0.024126014871788875, 0.012439062569423445, 0.02021919852787895, 0.023046502976545265, 0.03628096889172282, 0.017541879156072224, 0.028899786927338158, 0.030321294042680944, 0.02553814124049885, 0.029905854192163264, 0.09901890704142195, 0.0466057443326073, 0.012324914319573768, 0.06765980725841862, 0.005865708775153118, 0.050056725940001864, 0.013771032748211707, 0.05995126946696213, 0.06047913578471967, 0.03950133001697915, 0.031102423556149006, 0.03283344442024827, 0.03166412841528654, 0.060416595212050846, 0.04512633103877306, 0.06191745360514947, 0.0576989742528115, 0.042715981270053556, 0.027431566068636518, 0.04942714722294893, 0.029014717188796828, 0.02712525161249297, 0.02299467138280826, 0.010722574229086084, 0.023293803545779417, 0.04249759816697665, 0.006055438616645655, 0.021021516993641853, 0.05906407814472914, 0.03196969648290958, 0.12325714821262018, 0.08144936910165207, 0.04131989546918443, 0.04022786121017166, 0.03477961177538548, 0.03759776109031268, 0.09937980624714068, 0.011506063348081495, 0.01826405754712011, 0.0561688811784344, 0.052468938287347555, 0.01745848380960524, 0.0070751987181470865, 0.011004296879816269, 0.0909578228103263, 0.01134134897230459, 0.08480986127895968, 0.03681348995970828, 0.06670050801975386, 0.04815849029858198, 0.009341493381985595, 0.01765457364464445, 0.009834011417946644, 0.04676561396835106, 0.031229984746979814, 0.03030346553506596, 0.01215832888348294, 0.04925485021833863, 0.0264996813410627, 0.013099371289302195, 0.042085998824664524, 0.03551414628912296, 0.022177642277841057, 0.00896925331159894, 0.03942859445565513, 0.03887820416795356, 0.019411942023517828, 0.031300325079688, 0.025887893812198724, 0.026370008209986345, 0.021888443867542913, 0.03504331083968282, 0.023731964141396538, 0.040646866762212346, 0.027286181459203362, 0.007172462896310857, 0.0870268726721406, 0.05167239924360599, 0.05405413858326418, 0.021436780425054685, 0.04166735628885882, 0.01033636142632791, 0.04870046675205231, 0.009523506159894168, 0.09140509273856878, 0.04031150082924536, 0.08119483704545669, 0.028705244152141467, 0.07316546075578247, 0.052812914829701185, 0.052736722132457156, 0.026503418372677903, 0.06106933232929025, 0.016292412898370197, 0.04730534107823457, 0.031889001705816815, 0.05209664987134082, 0.020287491381168365, 0.032406113243528774, 0.05729421454348734, 0.019595802961183444, 0.03056764296655144, 0.011279004326622401, 0.11369959570999656, 0.056740665675273964, 0.028154765654887472, 0.007126682138602648, 0.09489235561341047, 0.07497037747608763, 0.07300833918686424, 0.054956220356481414, 0.037162053398787975, 0.05025436622755868, 0.06753884482064418, 0.11256497659321342, 0.07227078519229378, 0.09364135417022876, 0.0259965951221862, 0.029254307903881584, 0.04705612873658538, 0.07747895536678177, 0.07166936567851476, 0.008786383883229323, 0.02746985919241394, 0.09513583433415208, 0.014377738049786006, 0.015475622976997068, 0.06973413630787816, 0.02554653980769217, 0.02617114995207105, 0.06969218927302531, 0.04978552567107337, 0.06672503027532782, 0.05732235339071069, 0.046118854744625945, 0.07639835442283324, 0.07139386689024312, 0.061258677526244094, 0.03743882104754448, 0.11578554127897535, 0.04269965911017997, 0.036167782465262074, 0.019429612771740983, 0.07849593008203165, 0.02316122967749834, 0.0784290400998933, 0.2272773129599435, 0.03476919287017413, 0.07787912139402968, 0.022931403081331934, 0.02235779502162976, 0.04111044867230313, 0.02195666547465537, 0.03233655661876712, 0.030764078854450157, 0.060693186441702504, 0.010269234805101795, 0.007339513128889459, 0.010006306726219398, 0.024469865885164057, 0.04693681174623115, 0.06323789632213966, 0.02785480228651847, 0.03842839312606624, 0.01804748104353036, 0.027010071989414946, 0.041170811147562096, 0.003976988315116614, 0.04842959896528295, 0.003518719122179651, 0.015686895033078532, 0.07313651445188693, 0.011273801659366913, 0.01641547540202737, 0.016089580121583173, 0.02420732711574861, 0.06155039330146142, 0.02346891307804201, 0.033212952448853424, 0.021071277359234433, 0.015088863105380108, 0.03804131264665297, 0.00862985518428364, 0.06151335207479341, 0.012512871912414474, 0.03201033055250134, 0.035699457595390935, 0.005841800169686654, 0.05742297334862607, 0.016810158866324594, 0.025027623366830603, 0.05856680018561227, 0.08160686386483056, 0.026644585886970162, 0.028568617733461515, 0.022148037794977427, 0.02821636136754283, 0.023162403543080603, 0.035601086981062374, 0.025268406607210636, 0.020175042861540402, 0.07274381230984416, 0.0223656304047576, 0.010376914919886206, 0.05665673428614225, 0.11337064871830599, 0.0035432839982344633, 0.03054018265434674, 0.02168748893642, 0.06870965020997183, 0.04234643413552216, 0.050072345816131146, 0.027840863480897884, 0.02732487322230424, 0.04455597825082285, 0.047007257251867225, 0.052295908464917114, 0.037678231950849295, 0.08110858845923628, 0.08590538999331848, 0.19199554116598197, 0.08360500700239624, 0.13750822921948774, 0.0812722375350339, 0.187491615701999, 0.18494482950440475, 0.10210297083748238, 0.1644974752728428, 0.08748704155108758, 0.08441156800836325, 0.26982061724577633, 0.12347023534987654, 0.13640878535807133, 0.12551429495215416, 0.09467251705271856, 0.11766487972012588, 0.08657483942806721, 0.19346116323556217, 0.11324808493788753, 0.138363156201584, 0.07432078876133476, 0.1828011745320899, 0.09787201322615147, 0.12344384033765111, 0.09595803557229893, 0.22843071392604283, 0.09823206426309687, 0.14736382822905267, 0.08438777857060943, 0.13666732077087673, 0.10634255262890033, 0.0983941594937018, 0.1492421217262745, 0.0826393159638558, 0.14736684092453547, 0.08548678138426372, 0.06931031654988017, 0.13795432528214796, 0.17422708390014513, 0.07323087831693036, 0.1756186777991908, 0.13881449055458817, 0.1917579589145524, 0.0949841614014336, 0.16322029594864162, 0.1654510883880513, 0.13245188125542232, 0.11832745559513569, 0.2953772044607571, 0.133319849680577, 0.13230173502649578, 0.05202209922884192, 0.2037328127771616, 0.1459877456405333, 0.15044137808893407, 0.17166872189513274, 0.11119498724916152, 0.14226804380970343, 0.09637270867824554, 0.3127988081957613, 0.14659526518413, 0.14676344687385218, 0.07323985533522707, 0.16627240074532373, 0.14594841775085243, 0.2413422582404954, 0.258789130619594, 0.08227560762315989, 0.11073515763772385, 0.13191247305699758, 0.3092979203377451, 0.2303378858736583, 0.16161599489195005, 0.09856790517057691, 0.10223581442343337, 0.13669607708496706, 0.16034478667591298, 0.2391483373939991, 0.18653117652450288, 0.0672353021800518, 0.21142482145556382, 0.11828591568129403, 0.11546671124441282, 0.11205503717064857, 0.16325601403202328, 0.09147584358496325, 0.19616854510137013, 0.14449152164161205, 0.18807527795433998, 0.1878626657915967, 0.24672936488475117, 0.1985061660941158, 0.21978591994515487, 0.14837608034057276, 0.24046309398753302, 0.15249396009104593, 0.18730778699474676, 0.08466448515121426, 0.1667153619761978, 0.16714073557938847, 0.12132036499679089, 0.19892957194575242, 0.4018904561442988, 0.2413466280060155, 0.21948477253317833, 0.29705315881541794, 0.14148766068475588, 0.23824805713125638, 0.13360255451074668, 0.0938127181891884, 0.11100172011979989, 0.33246020174452234, 0.05487500989277448, 0.06324242215071406, 0.1201771827680724, 0.15215292839067324, 0.148915542821799, 0.2219831384718418, 0.11828773415514401, 0.184286039854799, 0.1172951731298651, 0.10530714211719376, 0.09939837096525089, 0.10069032199680805, 0.08049696377877678, 0.09673010664326803, 0.09620280350957598, 0.1277175388698067, 0.08192767522164754, 0.09736957840089287, 0.0856934292241931, 0.12274446072322981, 0.18477413723511354, 0.15060951906655515, 0.16434358353061335, 0.12196162130151476, 0.09095313413334744, 0.07624406234494277, 0.12527679412492684, 0.1844792730574097, 0.11466570065489837, 0.08744360173919372, 0.17108444896127495, 0.12830444451953682, 0.1540608602975096, 0.16861592499273165, 0.11432388185390405, 0.1037476108010326, 0.14480119145342282, 0.04941649761583124, 0.10853173730096646, 0.09267423820814916, 0.10655435054962124, 0.13074662775865623, 0.10799691599926778, 0.09169715456664562, 0.14509421001587594, 0.22204264599297727, 0.10064792712884289, 0.07508610840886831, 0.2062042544462851, 0.21866322947399958, 0.14226264267095498, 0.1750781432326351, 0.1774083681936775, 0.1242840973926442, 0.21134943621499197, 0.09119992410498005, 0.2115044543253524, 0.15388167276978493, 0.096023168148739, 0.24107133277824946, 0.12676444144121238, 0.09082116585757051], [0.02097760051089738, 0.06121438954557691, 0.034817016018288474, 0.038713679781981876, 0.045431875357670445, 0.011943890613370707, 0.03998676075467041, 0.010262117820924945, 0.020395468355023434, 0.01059800452951874, 0.04235852902222957, 0.017619126975270252, 0.014177197873193239, 0.0344856127298304, 0.025215041524331485, 0.02947812607245786, 0.09515855168657643, 0.06698777260524885, 0.015758952059383904, 0.04647440370172262, 0.041525807098618576, 0.06696485169231892, 0.01211945221958948, 0.019506319459261637, 0.0212082498307739, 0.0766250394018633, 0.04038806672074965, 0.052906959783285856, 0.019557587868933166, 0.06109688085104738, 0.01346071154278304, 0.06412058895719902, 0.03813074016943574, 0.023577748398695673, 0.012074041263466435, 0.06252504100224801, 0.009554750152996607, 0.08769930766097137, 0.05737439024129084, 0.02304210267694933, 0.010703397133121533, 0.012102485451448177, 0.02922226069495082, 0.014360411658084818, 0.03524778736755252, 0.026273332236866866, 0.04486963106319308, 0.02947563584893942, 0.04262176329003913, 0.04856385729674782, 0.023296975696991597, 0.0255831484682858, 0.03832084532561047, 0.015439670799033982, 0.018083585891872644, 0.025697540990742188, 0.08939678514642374, 0.01608114253862628, 0.04274958232417703, 0.04067844917465534, 0.06326444061206919, 0.05902249751878636, 0.02818128789242889, 0.06156589104128735, 0.02501054633674877, 0.01832308670106743, 0.03472882342923965, 0.11112716088869742, 0.03592549118080309, 0.054993566923907826, 0.05133737257814833, 0.09348849380122763, 0.06904120277613401, 0.01844262082262763, 0.04065971482279045, 0.03296007941077862, 0.01033205951430968, 0.0773034862109593, 0.03398256043770483, 0.05685668498543756, 0.04889504684667502, 0.015519123857042618, 0.059319974056312015, 0.06443966326436826, 0.028202315692656806, 0.04470595145331962, 0.01635443778442485, 0.07360039491738592, 0.03876118062596236, 0.10944479437811033, 0.011990918179175683, 0.11949277163616248, 0.1102729124416198, 0.10470587866646902, 0.0776848771742412, 0.07712105528584548, 0.07649870296674115, 0.032762551081499884, 0.004767257271201483, 0.03315298352390528, 0.022656233382544348, 0.022539701778441668, 0.057643137606126924, 0.06061339072350945, 0.11067899529423032, 0.04500222359118717, 0.12265593904469695, 0.03381831764376589, 0.009059403474176568, 0.06728508629437004, 0.02932260584618364, 0.08727328944951296, 0.0773816534451076, 0.11031590442040137, 0.07317466169063534, 0.06721833201923541, 0.06243941666824477, 0.0645020952714341, 0.05950678153229611, 0.043731951753475835, 0.0268067472747394, 0.10046678542026452, 0.03304756632340806, 0.031164801280413355, 0.03410677645089371, 0.044176280232412476, 0.033726756128349474, 0.005480707157403231, 0.01326832311627056, 0.042834887746721506, 0.06609030826283352, 0.055514349336070676, 0.02008718784366335, 0.07009796678487744, 0.024792085202144723, 0.03981481658826981, 0.027661212853022983, 0.001831959097346823, 0.029930498584040573, 0.012812369636126926, 0.05646597434367452, 0.052607501923505745, 0.012153511284850538, 0.10916588934404509, 0.08981982458915029, 0.03550551871636084, 0.02774461328850261, 0.07515668283615794, 0.027480440946029763, 0.060357141973716874, 0.0789640988888485, 0.029072993168873445, 0.08430239172386271, 0.02817318109529359, 0.04728662029707006, 0.030891938600689173, 0.0377453017447676, 0.05541129004476326, 0.057361755919243605, 0.0300916879703956, 0.011885039574865783, 0.06370486412197351, 0.07404829588319574, 0.07004896977118083, 0.017303313028865626, 0.01538434305361339, 0.027805876518998827, 0.08170901731188808, 0.00974122853949666, 0.041435144642101865, 0.02530163446707385, 0.021029961361948932, 0.0338967800406473, 0.0298226488355015, 0.06065463886729308, 0.04031670519283839, 0.07617610027747494, 0.07340840343385935, 0.08787010171051536, 0.03466218111238309, 0.05878458957054785, 0.027769340800919702, 0.04338718132515039, 0.026783894215311323, 0.05498964499150004, 0.021063112886622548, 0.01828300903019096, 0.009520253432648522, 0.034626103405441554, 0.0733049607702664, 0.04352720720427377, 0.04434877401217818, 0.023847971577197313, 0.052866251074842045, 0.0658654553283538, 0.005881491923771266, 0.030256039329937527, 0.0228520738559642, 0.01819892497068005, 0.010129149554164281, 0.04943799360522202, 0.03824927345184343, 0.033958323166838715, 0.02025999714221273, 0.05064875452912279, 0.031068652868270874, 0.01423735254710274, 0.04182320221194199, 0.05833233240991831, 0.024296566345063702, 0.026613673527858088, 0.014653450576588511, 0.018050999247602055, 0.07052452103900057, 0.09088112799716846, 0.03931750809507711, 0.037595749233982394, 0.037856985216162035, 0.030000967838402306, 0.044411094060965946, 0.013291300856508315, 0.04569292474271996, 0.0408849036321044, 0.03463621696989451, 0.03338624689994114, 0.06873303252671446, 0.04679981552596603, 0.033440030978194306, 0.01737992981049631, 0.007955580517383558, 0.015311670256778598, 0.01917191026067095, 0.0764340657208647, 0.01840106564174805, 0.029313876493168727, 0.02902521751821041, 0.005808554922363588, 0.042559660372457335, 0.031103858657713448, 0.04771808035937803, 0.0316359352852617, 0.015466182858550122, 0.012923062446394136, 0.06205964061830725, 0.05190695183617728, 0.04599538851263268, 0.05050327322844948, 0.03506952943280339, 0.02141546594378139, 0.09672422374465636, 0.04534436469631536, 0.03997701699180262, 0.05415506727461304, 0.08592504036745854, 0.010159545378493411, 0.046050492341497114, 0.06821126623877458, 0.0028673602791968733, 0.06898432118552071, 0.10189618729054928, 0.03258294625473874, 0.015284367703965731, 0.06514543467866522, 0.051268603054008315, 0.12343953842563288, 0.049471367350114245, 0.08182124021862235, 0.05327935337222048, 0.049111109359988143, 0.09148989604519946, 0.041933233450566015, 0.025936780563954796, 0.06988898478448391, 0.05974097789398261, 0.02484402196880962, 0.043998928141913245, 0.032321947759815624, 0.03914056991093925, 0.06092244306845324, 0.01072271417693368, 0.07161734239863497, 0.032322307383375506, 0.017799488368577192, 0.021257686195895076, 0.020706059278122017, 0.05031882705433028, 0.05608776231695499, 0.03568326435717089, 0.03965707076713443, 0.10065944865345955, 0.06446181743272714, 0.03852423619745033, 0.0731781968580825, 0.020637096371501684, 0.05054195990253772, 0.07156406382897071, 0.034262578269200664, 0.05257849794413362, 0.020752734005717293, 0.06629072715129171, 0.0250997431576252, 0.04029855098841446, 0.010184825048781931, 0.028899983702493564, 0.051703852734395435, 0.012330495270102151, 0.06036301130162818, 0.05245088925585151, 0.057863437570631504, 0.03059386495234711, 0.05079983374369996, 0.060194463202995915, 0.03498200520074793, 0.0039943168272397345, 0.03461575574640717, 0.06996005454233714, 0.057389535142907074, 0.015276493305074317, 0.03581156515117202, 0.0384060727166278, 0.03030655286940081, 0.009037066101362663, 0.0484432273411325, 0.029658372114811624, 0.021596840050603663, 0.0343124641637717, 0.07022266116525445, 0.02497413954032319, 0.06824797498328344, 0.04268904003713812, 0.024510991892644336, 0.05989360756107739, 0.09233229727085147, 0.021456832831193293, 0.027014969315912043, 0.03867179381528071, 0.010836728416117174, 0.051993071500744135, 0.12211011190499578, 0.028894178835409026, 0.01620314992032945, 0.015194390567817857, 0.0391808579276715, 0.03755357149722321, 0.04378308275980609, 0.05405671023098486, 0.016387222900188396, 0.04805822657155139, 0.03766730414437396, 0.05612852530820029, 0.041899618825742176, 0.016763155049245273, 0.11333579237439803, 0.18428597200129712, 0.12517205545944826, 0.1447580773383379, 0.19891625908868654, 0.16319357523960726, 0.11256847104855947, 0.16693215391465596, 0.126059674258743, 0.13035782719297068, 0.08525704978299992, 0.14516473694571427, 0.10888762891824756, 0.12948323626603397, 0.14650952549917357, 0.1151627954095602, 0.18462718012077467, 0.12087810944233622, 0.20946476448859486, 0.0835700420928853, 0.1326547089431967, 0.18797303629773005, 0.2477119378745556, 0.13681768413100923, 0.10353216236191136, 0.1569572277367115, 0.15129975202892507, 0.07445566116699151, 0.16477414114134653, 0.09263873725597348, 0.09611227336738791, 0.18279624836785452, 0.14127441069909505, 0.1184744398508753, 0.06438346020877361, 0.2060985794024808, 0.14923319220542908, 0.17276435238974436, 0.19848158955574036, 0.0709884354312505, 0.1260011845401355, 0.10790891679269926, 0.12035456539264747, 0.07946103758045606, 0.08630050093467746, 0.1474427418517215, 0.24423987418413162, 0.14385821776730673, 0.14343122925077165, 0.15326415162001336, 0.16366333860371793, 0.08921463242066757, 0.1705678395394768, 0.09507448798311607, 0.1551061842058386, 0.13213488326541015, 0.1503060646355152, 0.08561277176652636, 0.07250700358833585, 0.07442450962428536, 0.23131513914891652, 0.08604856766760349, 0.12836705973105772, 0.14450328743883542, 0.16780510278684752, 0.10547521524131298, 0.11823208071291447, 0.23869464173913002, 0.14180174097418785, 0.10084434266069106, 0.15882646957678453, 0.22930784257394926, 0.10383728598909718, 0.1956618558615446, 0.08195722542170968, 0.12540577006127152, 0.11155802384018898, 0.15748999986265386, 0.14342744302536758, 0.16796539989965303, 0.3567485527268478, 0.15017881217811788, 0.2196367915187563, 0.1426460828099932, 0.17168141049998148, 0.16219505667686462, 0.1592257060110569, 0.1215716265141964, 0.23146588248865946, 0.16119294187852315, 0.19840222809995922, 0.16499442074980053, 0.1954046775187765, 0.30686371667044504, 0.14120514584439142, 0.16261656263044902, 0.2748228045446532, 0.23030925169587135, 0.1607282403856516, 0.15568539526845726, 0.2372202394264085, 0.15667431934603623, 0.15018662890153273, 0.17727461537080152, 0.27398402669600075, 0.2425408496388367, 0.2250581370400531, 0.16546802462211677, 0.06294316106608935, 0.13398067493523869, 0.12892119213938713, 0.1808103799287762, 0.1526362353137561, 0.18487850949168205, 0.24199652884687695, 0.19829611879374298, 0.15656044759920665, 0.15145003396485532, 0.13190195576420852, 0.1939859286482845, 0.10447449143975973, 0.2445733877164977, 0.09793148003518581, 0.14787571504712105, 0.15045093186199665, 0.1735761109739542, 0.1516405123152903, 0.14176341731633457, 0.12396924357329096, 0.11972662194498948, 0.14873051989291394, 0.21597305525626453, 0.141629678064159, 0.13888850515442236, 0.15093661365764482, 0.15278210677206516, 0.1037001676325287, 0.1104186549782753, 0.11975771241954394, 0.16899882230375493, 0.1725356453763587, 0.185975062793919, 0.11521215204681669, 0.16402844472655229, 0.2072470813457455, 0.16039953088121756, 0.09718505080257143, 0.1117283022031188, 0.15029938785093172, 0.14415266125329904, 0.20870958215423993, 0.191327319879617, 0.20028007376406873, 0.23190144768783025, 0.12135320609169346, 0.18549366933958872, 0.1381621876997607, 0.11786515611623015, 0.09087124852729694, 0.10604899123843227, 0.11447854712605476, 0.20588222172643456, 0.1426859942397901, 0.140074774356825, 0.07640273775905371, 0.09841537049838475, 0.1502705772540399, 0.212165021736707, 0.10895312111824751, 0.12134183384478092, 0.07930131043706622, 0.12457665455128465, 0.13596494203167303, 0.19099135005048343, 0.13331851975194045, 0.09938533630754266], [0.008065518457442522, 0.0629484129271337, 0.06339299585670233, 0.06988254548715693, 0.03731739381328225, 0.05994679792118924, 0.044476012898875136, 0.02730450190470687, 0.047872318154467006, 0.01232611108571291, 0.024953466274642518, 0.11484458962721483, 0.05125248106196523, 0.048544274776109626, 0.049490332403885465, 0.06123038940131664, 0.03947340490828667, 0.041437600938869376, 0.019334502518177032, 0.024850079590188603, 0.03567377843761018, 0.04418270595903907, 0.019684682566938654, 0.016251695708238652, 0.01038072065317205, 0.03876365727878042, 0.07062368214662586, 0.026216930709779263, 0.022392970276996493, 0.07248036430350371, 0.03158008506787675, 0.016543202833937745, 0.05987428966909647, 0.009811584139242768, 0.02546435734257102, 0.023585663509688208, 0.028488611669412682, 0.02004664028728647, 0.02983907616830298, 0.028299526012103473, 0.04715498450345226, 0.07025876601359674, 0.004448609592925225, 0.03366915529061641, 0.012891915992700627, 0.003563550142903945, 0.0064625553869908405, 0.07225127052515745, 0.010588113185284393, 0.05974483197288854, 0.06289031675883702, 0.04405984362321241, 0.09089583185102258, 0.036750186035143476, 0.01457306622926678, 0.016099196659134965, 0.029005495897893394, 0.04997645863997085, 0.027904104640973464, 0.07428074162453413, 0.057939297785716395, 0.05537314959136503, 0.01469189128173249, 0.11973438438560281, 0.03463324837918792, 0.02430490045143025, 0.034937774895557334, 0.03195436159148812, 0.07601690239139966, 0.04610889045787709, 0.05422837619802781, 0.023520218807139566, 0.0809273449704051, 0.0302721681073308, 0.10258568064974886, 0.004735720235787864, 0.030526659451425076, 0.09824513963290624, 0.015094355846356069, 0.08439797695193972, 0.0541417815589479, 0.05280948822785701, 0.02158775446670396, 0.02018875435792974, 0.07269843188779694, 0.037346489394881895, 0.03559268671753151, 0.07137691708547728, 0.0443414865460779, 0.06016732858760016, 0.05813962167927197, 0.047236697083073, 0.06116036458739212, 0.03330346902034112, 0.03238683945632406, 0.04143440503893154, 0.04224447067826986, 0.02552461634123964, 0.03595184887360249, 0.037272328910018714, 0.01886893080414406, 0.02306309824676386, 0.059837350222681246, 0.0703825850837997, 0.0879143625497818, 0.03959413664415479, 0.06558663850384099, 0.045730003288814, 0.03896497183346322, 0.05303099598469479, 0.012451479760264712, 0.08928844345999615, 0.058754645820174894, 0.03711291389273746, 0.056165668315121105, 0.04894905823415943, 0.08203212890241827, 0.030093903387231485, 0.028577791526913643, 0.03300569732008236, 0.006092640995380602, 0.014987043836819274, 0.03227118655507054, 0.021513186860829592, 0.04520960085626159, 0.027533476939424872, 0.019764771751527275, 0.020218718464353254, 0.10013342116560255, 0.016205789421551993, 0.04869726067408919, 0.016683001403829882, 0.022303451151986207, 0.0334964104528938, 0.0335593140417976, 0.03552848712674209, 0.033698505322848044, 0.06719153667134897, 0.008178108621255627, 0.02290519466623664, 0.011850365587244076, 0.028326519831482853, 0.010274297524509686, 0.06849593882049833, 0.04079248716256448, 0.02065699441092355, 0.03239458154088684, 0.02530898300132581, 0.041608998884579966, 0.07644101391945567, 0.04745613191542881, 0.0266979577551995, 0.038669415550040345, 0.04792876887534346, 0.05876162794551679, 0.023692249486755048, 0.025729924074507186, 0.03227670983012233, 0.047574953575219424, 0.022088706692946807, 0.050399820386831246, 0.03339935958917652, 0.031481904443353415, 0.025421777573813285, 0.012162781769542821, 0.01182096975389868, 0.060314753891101906, 0.04308211198076606, 0.01029223035688379, 0.04065943323075771, 0.04645628681672471, 0.03346737254677074, 0.014642169931903481, 0.05348102755046316, 0.036537872427808385, 0.08242312792156424, 0.01884303960416998, 0.04953319885368858, 0.02705543544808669, 0.09753109009138175, 0.022808756180373684, 0.04606779498447265, 0.07709894182958774, 0.008391354366072586, 0.08555432276001998, 0.0766161030956677, 0.04652853722551039, 0.02106739953160286, 0.05758875980973244, 0.03075750045744436, 0.03852270610098328, 0.05205297935754061, 0.05414596812001296, 0.04579519014805555, 0.014756374160892196, 0.029190600250980685, 0.0585687950785671, 0.018130084200363075, 0.01309994889223682, 0.04850223953170436, 0.05191315703892282, 0.025647587242669294, 0.029140320806098834, 0.02481512994771557, 0.01482208858111075, 0.02807762979396752, 0.027711013930716684, 0.04001890974385398, 0.02242518203066928, 0.02040203657400395, 0.003072161867748946, 0.03779981864084091, 0.046299077038254054, 0.03115681153056877, 0.05718625962202038, 0.02425051247701049, 0.031209340319037437, 0.021861728247521178, 0.023319669300690293, 0.036858972162008286, 0.033338966579841714, 0.016487571444096308, 0.04907181539705821, 0.019511929247528315, 0.016017051513439844, 0.04443046623574836, 0.05198066109525306, 0.06709701674325125, 0.06853171118668147, 0.031786946646336994, 0.017810957306729894, 0.0163491672636675, 0.026633228907095532, 0.030510774946638515, 0.02742892996008907, 0.043150857756180425, 0.0497163829526731, 0.03803155192040971, 0.035721303030316315, 0.018761493265628815, 0.01654888047570629, 0.06541229571614947, 0.0768923686285104, 0.06613144784101418, 0.054377351954047165, 0.08394050185701676, 0.06495480026517596, 0.04968093289062381, 0.021226780622133186, 0.10087641701102257, 0.05701945535838604, 0.032188656340752325, 0.02415809770380812, 0.009410336696808892, 0.023534588482496992, 0.11762271555406706, 0.017092190250488262, 0.04557612511728491, 0.08213736289846045, 0.04463845757501466, 0.0420715528141175, 0.045436190840389044, 0.0914881182834506, 0.050157033771808655, 0.0391166481588568, 0.016220360961077467, 0.04444395890459418, 0.028886324792568172, 0.02031707720431898, 0.05848723516932555, 0.047314097572650225, 0.0666318131344659, 0.08110575896820851, 0.017750021469380175, 0.01784464657040579, 0.023100675516096607, 0.02154278116566794, 0.010842652874998748, 0.07006264903715678, 0.011693206698899823, 0.06218303221144846, 0.06611921385462795, 0.025645904475823045, 0.028994557913392782, 0.04904942034876772, 0.08824270564530577, 0.00894479890952685, 0.0565104658848473, 0.06551332279507603, 0.047472213195370774, 0.025028271367773414, 0.037921055885297913, 0.030338518654129336, 0.018858900360230888, 0.024563963425212672, 0.04621034162119031, 0.03294387260185821, 0.06399915833026171, 0.020670953572594693, 0.0246012743695506, 0.027345129188948443, 0.0659605452258672, 0.006288266458016421, 0.009634508551763636, 0.023237259526337897, 0.022713371120127182, 0.05382782340581928, 0.05464405014312693, 0.017422745370173028, 0.02134900343870478, 0.023324468239609684, 0.04413467925041914, 0.04619151566709791, 0.013192645257471927, 0.017758228350430727, 0.03546006365546158, 0.001101948503803994, 0.03796108266604798, 0.0026173648657277226, 0.021384132892957756, 0.05680072620244963, 0.014039608782955577, 0.03510409400665334, 0.06386787537485361, 0.07225808301674468, 0.055207556512738974, 0.04204344789364508, 0.011819257301145365, 0.00866862921975553, 0.03409775532782078, 0.03925014992377587, 0.06996207657669272, 0.03251034979309354, 0.05167338651205812, 0.052230660537523885, 0.008689883481045919, 0.014008394475760204, 0.03230201579364283, 0.0327026500100536, 0.022175501499857222, 0.012717684315118407, 0.02195877062955073, 0.02548081860212343, 0.024245930669297065, 0.03919320387233581, 0.02316803708007293, 0.034552234690636396, 0.05307392350264958, 0.047988184794251404, 0.09838678381804909, 0.019659510614084344, 0.06868881239954915, 0.06538003137601273, 0.16869779702808174, 0.15966585810695375, 0.1392595281026193, 0.10457954223134688, 0.10794490629008838, 0.11442241870931216, 0.10319066925772599, 0.18441298018608773, 0.16490326635539532, 0.13672220068318502, 0.13955291307398252, 0.17515869891004904, 0.16779748962393828, 0.15022371762565204, 0.13075268029102258, 0.13399991818836757, 0.08681645217750754, 0.09436560209308352, 0.15467216606651032, 0.14022331924310752, 0.08214248583785125, 0.09494828725499765, 0.09375134469675166, 0.10736568844211952, 0.13482737807290895, 0.09862066126827683, 0.12667332775890827, 0.10445114304976803, 0.17378945595451764, 0.08974367938935757, 0.16772103229803698, 0.10116944235882588, 0.07326207735708781, 0.097464295104146, 0.06585926708898374, 0.1505205359842096, 0.057346807792782784, 0.09396823163011245, 0.08826870710722037, 0.17303910478949547, 0.22039870492049626, 0.09850168015275683, 0.09695877294455256, 0.14125653808670385, 0.05631492905584829, 0.17423855114196027, 0.21066531006778988, 0.11935350910893508, 0.1523659476744277, 0.21471145509609155, 0.137716729460018, 0.15311481963310922, 0.11895751607205186, 0.16890133039227553, 0.08933813936476197, 0.12322046660951205, 0.16017944126256875, 0.15429015085101128, 0.1318031203533922, 0.12943917220192297, 0.1473623083106109, 0.13400533289781638, 0.16653066474412168, 0.10586008708924055, 0.12732377142778464, 0.12726528170917714, 0.16316135839692184, 0.1252617035061121, 0.1564328015914985, 0.2258734782891614, 0.1508308029068368, 0.13765437209180423, 0.18910751970750944, 0.25180475254143986, 0.06813614562686, 0.16350675986281463, 0.14127027163548128, 0.13405862503818103, 0.19824494368263654, 0.12251944494034563, 0.15896117234868662, 0.18920615155782017, 0.12340787798166275, 0.17779745374407085, 0.12556571433586733, 0.20280456330095017, 0.11733869436596121, 0.33335812070540016, 0.08573809039912053, 0.15699523926845618, 0.1767571238534791, 0.09781222072030817, 0.17658713726060732, 0.1617726550570556, 0.11449299992195197, 0.20433712963547024, 0.13399974176926271, 0.0972054000677807, 0.1031655091792345, 0.18866750331861631, 0.0976453282471214, 0.1716149683509554, 0.2578170613518783, 0.19364708183067186, 0.22346115059086255, 0.21264956359352383, 0.12573229468294553, 0.07753886322357825, 0.13219034671783447, 0.1777285145861762, 0.16540796070226602, 0.29757215668048176, 0.08531582448631525, 0.15750195564968245, 0.20118500877703938, 0.18512118075575146, 0.10186840128153563, 0.19052032461123808, 0.16316266118415765, 0.09939820133149624, 0.15353639344019548, 0.12034005831394877, 0.09561116168541567, 0.07974515376346451, 0.12603736402732985, 0.1191407340977873, 0.04911850539169141, 0.276236708675112, 0.10008791860725198, 0.21786744360412869, 0.14492438627140863, 0.11301516422203609, 0.08424312168998377, 0.0735583868143814, 0.14265444236142294, 0.1204802029367004, 0.09791923926344939, 0.13207731635442801, 0.12521434176181043, 0.07627923081495933, 0.1314972231962851, 0.0831266873117004, 0.08791962798152651, 0.07205558102577925, 0.13491709397307464, 0.13326662539371423, 0.11428082202162061, 0.1489521430007049, 0.15473346492009504, 0.07587840660874333, 0.12084278490926538, 0.09175049420446157, 0.15612864148403915, 0.14086890460125037, 0.17234722977238043, 0.08806883104677711, 0.12482056074908801, 0.16729583511395113, 0.07507790492049285, 0.12790310462670668, 0.12310626916587353, 0.1131167680557285, 0.10296972468495369, 0.0699869855972273, 0.08164709420608622, 0.16241111579750264, 0.10300853688802038, 0.16769086463110788, 0.0923761102770056, 0.17643677390047482, 0.0892772747735892, 0.08981146503772054, 0.2052077850592988, 0.18338551531944955, 0.117466218237366], [0.014843068883887358, 0.05896649802369731, 0.06026300881057978, 0.020875789724024277, 0.03489504415275795, 0.01567361271008849, 0.040400276958410225, 0.05861007036375148, 0.03872888914442488, 0.03020467422902584, 0.02787488861940801, 0.025213435092674832, 0.03808503744325467, 0.10043558638010706, 0.047380417585372925, 0.059057842407907755, 0.024669799621083906, 0.04532232927158475, 0.062373653054237366, 0.07709886719073568, 0.026768259072144116, 0.03100859234109521, 0.013631045884851898, 0.019633510848507285, 0.02249692184185343, 0.028195828897878528, 0.028276209852525165, 0.017443725672949637, 0.026846416128267134, 0.026173026101397615, 0.013819523405150642, 0.007904477500622826, 0.07124315069190093, 0.054139617032238414, 0.042586730527026315, 0.04065443921302046, 0.0777348852051156, 0.07709063656095948, 0.01667307104383196, 0.06359950120427779, 0.014489341793315751, 0.0802948349820716, 0.05789355095475912, 0.014606711388166462, 0.058769892502043924, 0.03726693794929555, 0.015664186162341918, 0.0552236581487315, 0.03964712344376104, 0.05041853438264557, 0.05516377404066069, 0.05573322776971119, 0.03232289092349155, 0.016361876224566783, 0.08015329257718154, 0.011754659919201263, 0.03498878376558423, 0.023607261279331784, 0.03736485394516161, 0.0936954469819154, 0.022173659277281592, 0.03539622708090714, 0.03049187096101897, 0.06926076992281846, 0.04501088509070022, 0.07234201779855148, 0.06575090504650559, 0.05147167840706451, 0.024646758268188153, 0.011883628222026994, 0.011278368200042417, 0.03080277909923877, 0.059485855512320995, 0.04678752725677831, 0.050063758955470154, 0.050418381712266376, 0.028039446932130625, 0.025992076078962003, 0.03992305649444461, 0.0784645817641701, 0.02953933671649013, 0.04668038657733372, 0.036741090273218494, 0.06937989353069238, 0.02042105930325176, 0.04590439696663192, 0.0904632250645331, 0.05384441019435014, 0.05046211668689336, 0.03703824450661029, 0.05152317921497992, 0.04676642481769834, 0.042809351081294675, 0.046302934509835074, 0.04710452524679048, 0.09284870991749422, 0.053469254967889616, 0.050110398059976954, 0.07668487261980772, 0.06959897213216339, 0.06199759537620204, 0.010913565721628922, 0.03558387594031436, 0.021693217468314936, 0.016340924759528468, 0.02368434964280043, 0.02607828564941883, 0.03459223772266081, 0.002701917114401502, 0.04297935124486685, 0.03823215401332293, 0.04450985822560532, 0.05684416940701859, 0.03864801794822727, 0.04938135289454034, 0.02922298333474568, 0.04527546964319689, 0.021427342002945285, 0.01459052154262151, 0.08159085722374064, 0.057171928962426524, 0.02498877384433789, 0.03667375924331801, 0.03543842178104179, 0.02930343383923173, 0.02502158610150218, 0.036217671752508195, 0.05340415631820049, 0.018602939987821237, 0.026397298888436387, 0.030153122530984025, 0.06409999541938305, 0.09729799295642547, 0.06041628987129245, 0.010477348280671452, 0.05566989331107054, 0.03256817454738276, 0.009981805674864777, 0.04744994706873383, 0.06273958020444427, 0.10194671779338803, 0.027201529126614332, 0.04560767699565206, 0.09798586461693048, 0.04710053885355592, 0.08880448514329535, 0.02543516337339367, 0.02291073151198881, 0.025083417605076517, 0.03456217862133469, 0.05852213901068483, 0.007794637099972793, 0.093172533969794, 0.034508177411875555, 0.05635049446885075, 0.05702852737158537, 0.05914285606039422, 0.019502119327496206, 0.0558710280539734, 0.03670213897047298, 0.028218196804768274, 0.004099975755837346, 0.03804859672007816, 0.007798171419251178, 0.023631479890484895, 0.039028302899428775, 0.051835420674511364, 0.03528159198218158, 0.020721743615078073, 0.014195107805010463, 0.0376309889501759, 0.05501080171338149, 0.026001334689291458, 0.02294227321233068, 0.03976232172655208, 0.013939662271046212, 0.016290316225162575, 0.02597980816582484, 0.058252740252230845, 0.003907392250507006, 0.018144559048648392, 0.044948276664529524, 0.05508466703551156, 0.01753059002969946, 0.05936136469244957, 0.04356598887326462, 0.046447913694594584, 0.014119916795087712, 0.011889914848974772, 0.044183574483862946, 0.037810196833951135, 0.08213397022336721, 0.029599353138889586, 0.030406100741986717, 0.036612535028585365, 0.0750224075413176, 0.04226314735465816, 0.02914689920310463, 0.011946793046912976, 0.037136774576668224, 0.04995278116049511, 0.03880393851016249, 0.027601125184446573, 0.014379785529204776, 0.019797008950263262, 0.05257807046707187, 0.012951520205076252, 0.030044760488505875, 0.03590594258691583, 0.05630200635641813, 0.045604501451764784, 0.0671441884977477, 0.0054625156335532665, 0.04006018163636327, 0.034870091027447155, 0.041252371056803634, 0.030110371432134082, 0.05721323138901165, 0.07379632868937083, 0.031098460911640098, 0.03569814123745475, 0.03093355315338288, 0.05565508767696364, 0.03463091082604868, 0.02274205788437809, 0.02203063088070069, 0.030349609309009144, 0.02301891374268702, 0.027860018524474332, 0.010118224292195268, 0.07608797893460308, 0.015445077026795064, 0.02638857123175902, 0.017142142302223613, 0.018676537288618938, 0.030305032950959036, 0.032822506435747655, 0.027032850409990976, 0.021218168316408992, 0.04769016542871084, 0.036778301133641174, 0.06755458004772663, 0.0367849134573979, 0.08807289547153882, 0.033482642977365425, 0.0752751754064645, 0.06317235662468842, 0.04535264621621796, 0.06716013407068593, 0.05089125955211265, 0.048355533475322385, 0.04383882101891296, 0.04823023859145386, 0.0707932480477861, 0.008160469255277088, 0.11088890688759939, 0.009978727670386434, 0.029137959504233937, 0.1019438204488584, 0.05319819040596485, 0.0338888988564057, 0.06635841780475207, 0.03827804672930922, 0.05838075266884906, 0.038149644155055285, 0.015695230835782628, 0.009586386000072318, 0.056918835400470665, 0.03131401113101414, 0.06409717949905566, 0.013437647289330406, 0.08419588208198547, 0.07680610647158963, 0.061079252511262894, 0.062248721186603816, 0.07817831462515251, 0.07529639319649764, 0.03204039643917765, 0.06996548960783652, 0.05443246935361198, 0.008146175066940486, 0.05225348984822631, 0.016661401937848756, 0.024988298869824836, 0.054623432856585295, 0.0394059653127832, 0.07213258796504565, 0.024806059630853788, 0.01759461489772158, 0.03079066046380571, 0.02181036993195968, 0.02175991915698562, 0.0494521614164114, 0.014748776265020882, 0.017676626032750522, 0.15804873273840972, 0.059102761426142285, 0.028190151256109987, 0.035783100607139726, 0.03325236515541162, 0.08369916730693408, 0.05439507868140936, 0.0748762646690011, 0.027535363266776716, 0.05746033348675285, 0.095708395753588, 0.03329810520101871, 0.06915554271212646, 0.008900097022498292, 0.058183244695620875, 0.009468589776328631, 0.06701378085251365, 0.0771525257400104, 0.035429132636636496, 0.05956236712102379, 0.05844697768666914, 0.02118523731561644, 0.014506741127531444, 0.046002228145620654, 0.030759057695312158, 0.03436516597867012, 0.003987298654724977, 0.05165127644847546, 0.06429398179586444, 0.03520289209804364, 0.030064634779202085, 0.050720974403832636, 0.04932170966640115, 0.06221657898277044, 0.051054888271859715, 0.07028606347739697, 0.11254527193627187, 0.044534543329583745, 0.013145612602654313, 0.041296597969319136, 0.05806207869734083, 0.04849560345922198, 0.011376198530862374, 0.04820630666134613, 0.015002327838114329, 0.035168066288211515, 0.05338851947869573, 0.06108842630471502, 0.053603492943303924, 0.017736250601176704, 0.019008619112095664, 0.037425213027745485, 0.0108065183407494, 0.028768344516200677, 0.048655992174254994, 0.025482925453356335, 0.024414156463795474, 0.09958639980426856, 0.14873107629162924, 0.17981373412268503, 0.06807930474834782, 0.12720695483897412, 0.14699386379548482, 0.13533452871654714, 0.1171313069228615, 0.15450638639075415, 0.2149003321038825, 0.14430169468479498, 0.07950926784958158, 0.0787525452407343, 0.1442950043295111, 0.07756733455296073, 0.10454009899071284, 0.08837700129619666, 0.13193562467183384, 0.11877152962344033, 0.23673864241157258, 0.130731374291437, 0.07226439339241811, 0.07492472564003297, 0.1000073290030871, 0.1140700283327273, 0.06977257531668458, 0.12008091221962656, 0.0779605863083686, 0.12932327842073782, 0.20952674187719822, 0.07454817263143403, 0.10539587414158241, 0.15276834608188697, 0.12631655404610292, 0.10854808999491589, 0.13266082932906492, 0.14413138239511422, 0.14584665106875555, 0.060277875512838364, 0.19176862548504556, 0.1601001476602895, 0.18511572533420154, 0.1655063618506704, 0.06844112676169191, 0.11252633402390139, 0.11532823581780706, 0.10501066302614552, 0.10107247970466103, 0.1281436588615179, 0.13720860172595295, 0.15523239171930722, 0.1461535117455891, 0.13396745707307542, 0.20352497750094958, 0.19834160778139318, 0.15998448458101067, 0.14706061807061943, 0.10843062879783766, 0.11430037740085806, 0.15682245711130754, 0.114591387499656, 0.12431796986077513, 0.13516363288675035, 0.19568035272615297, 0.1370594868702548, 0.17887674511543342, 0.150142211999212, 0.2207797294748681, 0.13235563784837723, 0.12298363074660301, 0.16743528763098375, 0.14005125633307866, 0.20631750194089754, 0.12858919852546283, 0.12327936344913074, 0.1559161650282996, 0.1411013299865382, 0.16936502765331948, 0.1653141735919884, 0.33560629721198765, 0.12771494686603546, 0.1293004932148116, 0.19129180535674095, 0.1472840325108596, 0.05882840257670198, 0.20743882177131517, 0.21669523364731244, 0.18255178577133588, 0.14639393027339662, 0.1610484274902514, 0.11732287092932633, 0.17168644522981985, 0.19901866359370096, 0.18147885905844824, 0.15601236772324356, 0.25839074913944515, 0.1492329886449235, 0.12887934009943688, 0.15860190162701265, 0.1427911671676806, 0.16695217069770607, 0.15578991680272988, 0.0829003212441291, 0.13317624452923024, 0.2849224997418267, 0.09546277964753763, 0.10885157156735659, 0.16758335754275322, 0.1367558017373085, 0.14080113252358778, 0.15191618752266678, 0.12927390821278095, 0.1167743703616517, 0.12747926451265812, 0.1829936070633786, 0.075624240961458, 0.13939406802611692, 0.14258726739457675, 0.14788845793477126, 0.30157982877322603, 0.07884423567780427, 0.1911908257752657, 0.15147765034011432, 0.18032585164265974, 0.12447161733039788, 0.17230423779359885, 0.15661676600575447, 0.16671154860939297, 0.12061840694929872, 0.13414652246449674, 0.255753147814955, 0.0760649291000196, 0.17121516194726738, 0.13396643927054747, 0.1462023119841303, 0.21625139032091412, 0.1473450463797365, 0.13602826291961329, 0.1366350089332887, 0.25097726551549776, 0.1813864018768072, 0.15032196949635232, 0.14767697214015893, 0.13600479917866842, 0.09846375683056456, 0.1783305379961218, 0.10030817785965544, 0.14697924815118313, 0.127004100009799, 0.13327611131327494, 0.22315578269107, 0.13809050726039068, 0.16075295263103076, 0.14259555909250463, 0.11729786012853895, 0.17007286181407316, 0.1904801553381341, 0.11850540818912642, 0.14669038222304412, 0.1272893018488373, 0.16084155573376588, 0.10483509209007025, 0.10218049346336297, 0.06213786892060723, 0.14796710014343262, 0.2320048292832715, 0.2118039596825838, 0.11597435043326446, 0.09566033511821713, 0.16772407213492052, 0.13552208936640195, 0.12339286878705025, 0.1095471785270742, 0.12329646253160068, 0.11012890016926186, 0.06766172072717122], [0.015806632715144327, 0.012743774834754211, 0.014946625202095934, 0.027771456133840338, 0.0662161290113415, 0.019634683017752, 0.04969681061006018, 0.02900616086221167, 0.026791822897004228, 0.06066867097147873, 0.05539040134421416, 0.06559816002845764, 0.03583129355683923, 0.08063799728240285, 0.04080402904323169, 0.0413696626201272, 0.05031638093558805, 0.0327178627651717, 0.05507589697039553, 0.036398243491670916, 0.04360171374199646, 0.0326334699722273, 0.014971993930105652, 0.08408836820828063, 0.011537587236879128, 0.02222429495304823, 0.0012207952905945213, 0.02332765905053488, 0.044420593551227024, 0.07728408689477614, 0.04139085326875959, 0.02677967881650797, 0.017789844689624648, 0.032970898651650975, 0.09216127251940114, 0.012180153114188994, 0.03355894424021244, 0.06956556785319533, 0.012704161960365517, 0.021755164322842444, 0.04325173555740288, 0.05066610127687454, 0.02686389858302261, 0.04363092467454927, 0.03277242715869631, 0.0611197135544249, 0.012958290288224816, 0.04434673501444714, 0.014376109565741249, 0.010191458576757993, 0.01763240760192275, 0.05995194800198078, 0.06310598232916423, 0.026367874217352698, 0.006135658419225365, 0.06705547004405941, 0.02567097804109965, 0.06403196549841336, 0.040620057843625546, 0.012972101868529404, 0.015159179689362645, 0.11755091297839369, 0.030789462849497795, 0.007544038002379239, 0.018792297059137906, 0.0783403284315552, 0.06679175062371151, 0.11374147489134755, 0.055684376641043594, 0.0032192230948047446, 0.031854467666042705, 0.030223076098731587, 0.059721137530037334, 0.026805144235757843, 0.033434080226080756, 0.055346574767359664, 0.0056920178051638815, 0.020928966513435756, 0.02665238903968462, 0.0898412527250392, 0.047111025612269125, 0.02711841367584254, 0.031859892553516796, 0.07300591003149748, 0.04764997919223138, 0.03537691258160131, 0.03907533894692149, 0.024738502988059605, 0.043710717000067234, 0.021269258610638123, 0.0651814920295562, 0.04457214095496705, 0.06206041414822851, 0.028057173659492816, 0.04309463095186012, 0.06809034451310124, 0.08078013679810933, 0.004347375984902361, 0.07509167918137141, 0.08455384323107344, 0.045924179655100615, 0.055270602593996694, 0.05240516956629498, 0.020556844338508587, 0.11259959544986486, 0.025643473624118736, 0.06082729888813836, 0.04091888466583831, 0.06012425518461636, 0.05489030746476991, 0.04259025551644819, 0.005583860595444483, 0.015701122216082046, 0.04970094967367394, 0.0279514290658491, 0.058150708941476684, 0.0157905310791518, 0.015980351250618696, 0.053959523660263846, 0.051193021038281064, 0.05288867326453328, 0.08446002219404493, 0.06567899390522923, 0.04744871213499989, 0.04625316057354212, 0.0568729325064591, 0.024083592862422978, 0.05158588942140341, 0.014328713894688656, 0.03170877601951361, 0.012224707419850996, 0.02607327975731875, 0.013854914095385798, 0.018854193023539016, 0.041867086464273076, 0.02560829327973936, 0.043460130625005276, 0.052018791370626004, 0.04801421339756676, 0.05780601993735347, 0.03058007712076817, 0.04413911008409091, 0.005196392078817422, 0.03300930034103138, 0.03486949052395565, 0.029702995970313038, 0.059560799705130715, 0.05374878764684711, 0.05312453203701547, 0.0300075971255345, 0.01015200515809868, 0.049853318104786534, 0.023135755776560733, 0.0847272632111396, 0.04954384167545608, 0.012928277836181223, 0.062189342587121894, 0.03923721704632044, 0.0682329386472702, 0.06421493925154209, 0.021314627158322504, 0.04158806607925466, 0.010548394289799035, 0.11101088034255163, 0.04217352984207017, 0.048678967369986434, 0.044440729077905416, 0.01684879295394889, 0.025453631400263736, 0.09962225359465395, 0.04686641373804637, 0.045462100700076134, 0.05852055802409138, 0.017392947504829084, 0.06564850054149117, 0.026177565500672375, 0.037243972931589396, 0.04258468813662018, 0.037438983895948956, 0.0256301879084536, 0.0437325726130179, 0.03904044528358749, 0.009709842054040303, 0.04758267191105655, 0.06256649270653725, 0.01959980122878083, 0.06506142525800637, 0.036107918713241816, 0.00520159983508555, 0.08970160343285118, 0.026468377127977352, 0.02822036133147776, 0.020168238851640905, 0.042039905940847735, 0.05118830521990146, 0.019095027154045444, 0.024462822691670487, 0.02943419771535056, 0.022829509173919047, 0.013553004179682051, 0.09737856898988996, 0.015849373635968993, 0.02259016442777855, 0.0186598894319364, 0.016050962997334342, 0.0059651446894609505, 0.07383562943765096, 0.04803057966221656, 0.012485947642874504, 0.06995672972074576, 0.04057482669928244, 0.039685538703841824, 0.022057974145614674, 0.06228135193565062, 0.07327716119055237, 0.009784452068353338, 0.028060815696205412, 0.014432916517502494, 0.02999833851520504, 0.02129460358992219, 0.02902530233508774, 0.05900566985032388, 0.0190934682198401, 0.043297153298876116, 0.03530529660305806, 0.017717711328129684, 0.013998609152622521, 0.05373846712921347, 0.06353143057120697, 0.021005997201427817, 0.033217162758644135, 0.00841300726668643, 0.0035057966347916848, 0.019528203909950595, 0.034934446681290865, 0.04924946943564074, 0.03746459859290293, 0.0752258798373597, 0.08076708178435053, 0.06716511451772281, 0.02573303346123014, 0.083620389391269, 0.06425478961318731, 0.049609724033091745, 0.09055734465696982, 0.036320055901472054, 0.00648154758216281, 0.017572182530005063, 0.05178682738915086, 0.04957642153437648, 0.05164666919569884, 0.03668434438960893, 0.035675467989806614, 0.06999593547412328, 0.06280862114259175, 0.04310407615931971, 0.011868902315784777, 0.03016066105504121, 0.0331742080992886, 0.039491762673216205, 0.051418898560638936, 0.06149647690887962, 0.05137528232964022, 0.05626376412276711, 0.11460688523948193, 0.014566175706152405, 0.05275712568046791, 0.0353129097659673, 0.03900354315659829, 0.0468041004746088, 0.07280256665710892, 0.010000130361212152, 0.03482165719781603, 0.03592659719288349, 0.01946139195933938, 0.05321922838421805, 0.019187952524849346, 0.03704281783263598, 0.032485155787851126, 0.024225610241826092, 0.05533109059823411, 0.047212517487683466, 0.011438935030517834, 0.05146182268591864, 0.029791731387376785, 0.07491340089057173, 0.023841746018401215, 0.0071084083423816734, 0.07689299966607775, 0.06420801140900169, 0.08201396451996905, 0.040145056189170907, 0.03498539109049099, 0.029278714808502367, 0.020776686291875582, 0.03905403294733592, 0.013442689652687736, 0.033090982386576276, 0.046183936430939605, 0.044757129957101176, 0.028816171056990112, 0.05242539330252579, 0.026536496954837015, 0.006557042660590793, 0.015293622921620096, 0.013432605774141848, 0.021494040298940878, 0.05053532383005534, 0.009438509470783174, 0.011935107825723077, 0.03989656309464148, 0.013751729275099933, 0.03084010531061462, 0.020857833991093293, 0.034402570221573114, 0.034484866341309886, 0.0160530172621033, 0.008934334203201746, 0.04888098420841353, 0.06780394166707993, 0.1213934025061982, 0.05176705148603235, 0.019526677206158638, 0.05038872294660125, 0.029429515823721886, 0.029953090407486473, 0.0488387284401272, 0.07084381926272597, 0.018785048608801196, 0.009453149711979287, 0.011572029674425721, 0.048605614341795444, 0.02747952492375459, 0.05039653627734099, 0.057417185444916995, 0.024380779326228157, 0.05924943355577333, 0.07667295075953007, 0.04567587315770132, 0.032879791754697046, 0.03517127915152481, 0.027432193713528768, 0.027595425490289927, 0.03882633355845298, 0.05343717383220792, 0.03470297124502914, 0.0392646977145757, 0.020290403992735913, 0.022860038160745586, 0.04457798992682781, 0.033943877156291685, 0.05340557445638946, 0.12041237657623631, 0.18514186250311987, 0.13462084558393272, 0.11541869810649327, 0.1798675555203642, 0.16634463758340903, 0.14701512908296926, 0.13145005144178867, 0.22640175851328032, 0.0842676575162581, 0.1736662747072322, 0.2671661339700222, 0.17519255780747958, 0.2434023448399135, 0.1332810917603118, 0.09802804235368967, 0.099941321116473, 0.14339814388326236, 0.14164885346378597, 0.14779414156717913, 0.10457336756267718, 0.10774834148053612, 0.11080666165798903, 0.21614264829882554, 0.17327917047909328, 0.0674940547240632, 0.1712660656443664, 0.05528507913861956, 0.19565672613680363, 0.18995648915214197, 0.13210866467228957, 0.11804712563753128, 0.08441609383693763, 0.14408824113862856, 0.20562641402440412, 0.09497297235897609, 0.14774908684194088, 0.1579017484826701, 0.08568990084209613, 0.1795360775930541, 0.20992547619555676, 0.1260114847017186, 0.1745189218116658, 0.14331500977277756, 0.1284454305257116, 0.09311732157532658, 0.10489446390420198, 0.1596451085060835, 0.13126557134091854, 0.10010958423039742, 0.1664431472974164, 0.13184324891439506, 0.13789453277630465, 0.09630970670176403, 0.1382415084434407, 0.11850154053952013, 0.09435254029397454, 0.16490450128912926, 0.07569744810461998, 0.10637440984802586, 0.07197612457509552, 0.16870874858328275, 0.18532611190208367, 0.14028377671326908, 0.13001039012202195, 0.20447462797164917, 0.35930847536240307, 0.14254624316734926, 0.40694497206381386, 0.12090989202260971, 0.1469956822693348, 0.07675717052604471, 0.15114644382681164, 0.2878572722630841, 0.1428119439099516, 0.18776307042155946, 0.06641105855149881, 0.19777291401156358, 0.1185986524713891, 0.17449190254722322, 0.1411475246506078, 0.11872316364731107, 0.09301235899329185, 0.23607796643461498, 0.19809477031230927, 0.11997926767383303, 0.11242575477808714, 0.09699495243174688, 0.20477820453899248, 0.08641387735094343, 0.10071902402809688, 0.18703158253005572, 0.19171929598918983, 0.13659232908061572, 0.14295119286647864, 0.15811619268996374, 0.20010651807699883, 0.11924858045365129, 0.1257881245442799, 0.165330349866833, 0.10501997931195156, 0.0759639630892447, 0.2194958869367838, 0.09276525011020047, 0.25408918995942387, 0.2117678073367902, 0.14872479305735656, 0.19425825189266885, 0.17084998797093118, 0.2109245104449136, 0.131297571052398, 0.12686482391187123, 0.18519766522305353, 0.08607835535492216, 0.2078862613333123, 0.13703602312930993, 0.16016348211893014, 0.1332393754273653, 0.10922485403716564, 0.22877915522881917, 0.10080502155636038, 0.1739919986575842, 0.16611800688718045, 0.10013743130756275, 0.13980083619909628, 0.16806419459836824, 0.13098803694759095, 0.21914056528891834, 0.09292300950203623, 0.1166025245828288, 0.09943062173468725, 0.14653885178267956, 0.12299756785588604, 0.14934083500078746, 0.15060923408184732, 0.12049495428800583, 0.1010112894166793, 0.13774563505181245, 0.1504587757268122, 0.10760490596294403, 0.10426277494324104, 0.11801686297569956, 0.08808386738279037, 0.14818131364881992, 0.19044489865856512, 0.09285987181855099, 0.07633555600685732, 0.17317832660462174, 0.10471454355865717, 0.13360201168273175, 0.1389789538724082, 0.12811794238431112, 0.09367870073765516, 0.12535099871456623, 0.10656572279653378, 0.08663180244288274, 0.13344132101961545, 0.19690300497625554, 0.1614520608314446, 0.12734077551535197, 0.14031265516366276, 0.11797560804656573, 0.1482604444026947, 0.18421513294535025, 0.13672659759010586, 0.2333577195448535, 0.17313965010855878, 0.12951519526541233, 0.08965303389621632, 0.18022968965981687, 0.11842084915510245, 0.12836213356682233, 0.11307233079735722, 0.12737144529819489, 0.1205951739102602, 0.10074826888740063], [0.11397160004292216, 0.03344313527590462, 0.06076014427734273, 0.03786823532677122, 0.036469737333910804, 0.03332051721268466, 0.04777727236172982, 0.04198089375027588, 0.012548295681231787, 0.02033355542724686, 0.006991916602211339, 0.06886018998920918, 0.02510344795882702, 0.029975183507693664, 0.03956343971991113, 0.06088565968509231, 0.038845997503293414, 0.032259539501475434, 0.08475082873233727, 0.04232892793204103, 0.03379874190847788, 0.06029366502272231, 0.03693848968084369, 0.010203562793321908, 0.02726105530746281, 0.07128798150058303, 0.007156330726242491, 0.11476843085672174, 0.02515187330677041, 0.04730347849960838, 0.08389888730432306, 0.03421864651941827, 0.052092917928738255, 0.06941859038280589, 0.03523588925600052, 0.03642142564058304, 0.07206068360911948, 0.04717320316870298, 0.017347541637718678, 0.04392807551526597, 0.04351510553221617, 0.020082507648372223, 0.03798826477889504, 0.02480402063312275, 0.025245314364188483, 0.06474773173353501, 0.07216776322041239, 0.041335264287356815, 0.1525121855416468, 0.0030657989056115703, 0.04111385491809674, 0.03438998678965228, 0.06256556989891188, 0.026312275057924644, 0.05287658177050097, 0.023619005024167042, 0.0282868357109172, 0.04015537331412945, 0.01403776231953608, 0.06656811905226537, 0.03874747761126075, 0.009077154798433185, 0.06811817123421601, 0.06536042849932398, 0.028358075102525096, 0.029894658364355564, 0.041492484243852754, 0.09765119078968253, 0.053720977889107804, 0.007169518902498696, 0.02538228005037776, 0.024168307959501232, 0.08079279147620712, 0.05727324102606092, 0.03701169343133058, 0.009265512726934893, 0.04148132912814617, 0.0599638834329588, 0.03769466946167605, 0.03336911728339536, 0.03944454342126846, 0.026299915542559962, 0.040862973380301676, 0.051253600644745996, 0.030787362783615078, 0.06518316122570209, 0.04641743729423199, 0.023203789090205516, 0.06531018976654325, 0.03599058983049222, 0.04890782366107617, 0.02169002326471465, 0.05628361805741276, 0.08658977398382765, 0.032082116164799244, 0.010415325090954346, 0.05916883038090808, 0.017729007239852632, 0.05470384943432041, 0.03065693478233048, 0.050438714014100175, 0.0465925909312708, 0.02352794392832688, 0.033159843512943814, 0.017978894723845378, 0.05585832248574921, 0.01723295573278197, 0.04473199023466025, 0.04623710982767599, 0.027170764348868812, 0.04619456907468183, 0.010148200272981609, 0.03632388623165233, 0.0455088585482112, 0.03191237384453416, 0.04865255878706064, 0.05226632773077913, 0.0391337167072509, 0.06125010084360838, 0.046546637147132836, 0.0851176515487688, 0.03951220693332808, 0.028459349846733466, 0.03862895450687834, 0.00533658207859844, 0.01858033120099987, 0.048802440387329886, 0.023146050849131176, 0.06781939190945455, 0.05247631735567536, 0.02938046452722379, 0.023711850667106252, 0.04604923026636243, 0.03885705762409738, 0.0261520746363593, 0.04287058886672769, 0.008300247469118662, 0.042619727684983184, 0.03207984646516187, 0.08974772345806871, 0.050138611546052356, 0.060828126700861115, 0.017211943199591975, 0.0080854224340458, 0.05325738240831664, 0.058281231937663894, 0.0399157825990447, 0.011205761560371943, 0.047169243916869164, 0.05802783303494964, 0.03909851431048342, 0.024454846512526274, 0.032958115051899634, 0.015918321275551404, 0.019465921180588857, 0.00020866342025068922, 0.07140942569822073, 0.006819360482040793, 0.026418996741995215, 0.07141866055982453, 0.02186310228093394, 0.030913929920643568, 0.015194064871008908, 0.02932614440630589, 0.0074542288036484805, 0.03856909754020827, 0.03574881762532251, 0.003668199750661318, 0.023181163340008686, 0.03198458014854363, 0.05207091982343367, 0.03215308414239969, 0.026434343507779495, 0.015803389317755188, 0.03041010070592165, 0.038585155071424584, 0.005469475282422666, 0.03303340869024396, 0.026674017343404036, 0.033669755794107914, 0.06543980352580547, 0.08878269738384656, 0.033942774536886385, 0.08481132012924977, 0.025920716247388294, 0.035541674454829524, 0.041449010505207946, 0.05746957513370684, 0.02679018593127174, 0.025517474760168364, 0.04589594242029956, 0.02977258652182562, 0.03444197614278112, 0.0178900999349675, 0.03936929728037544, 0.029512164781668355, 0.03536363025861127, 0.010424145198028003, 0.021518637193366885, 0.024742533486070376, 0.040368643655840836, 0.07111121634287493, 0.04971233888396195, 0.03591925883665681, 0.025524236361629198, 0.0556271422122206, 0.03205922239327005, 0.02521589138944234, 0.04666883112596614, 0.06390484874801976, 0.020921597623133233, 0.016873106560004607, 0.07667856902948447, 0.05947880553347724, 0.014251859625801444, 0.011912288693045931, 0.03401445158358131, 0.03357125286545072, 0.01812201981166644, 0.030951313807496002, 0.04025931130828602, 0.024933990623269762, 0.04946513839864305, 0.018837972643918226, 0.050225521703915935, 0.0650502090741481, 0.07248195207544736, 0.007327753268847508, 0.03529966476240328, 0.017095119825431278, 0.025881583436525295, 0.001012145242254649, 0.021051501456115927, 0.06267378944903612, 0.04258596378245524, 0.025157835933246782, 0.03341416183060833, 0.045748649431126456, 0.014489657312099422, 0.08592286227004868, 0.0062976989429444075, 0.024101036301414882, 0.03623244345986417, 0.029561168580715145, 0.02292601890595896, 0.04478772849376712, 0.07403230959815638, 0.026099489868751595, 0.04832748283765145, 0.05767841464174645, 0.04374269635549613, 0.01491429131211979, 0.02008659073284694, 0.03248050443029829, 0.03193155602951135, 0.004715689457952976, 0.040531865254576714, 0.08613495874617781, 0.03669741975941828, 0.04719980513410909, 0.007744579875309552, 0.051482992978500466, 0.08818425663879939, 0.04833206294902733, 0.09925598039158753, 0.022208831139973233, 0.03679830773866602, 0.00857544006846313, 0.1018167986933674, 0.01595304360879319, 0.04876278340816498, 0.01881144192468907, 0.022611975935953002, 0.06278418709657022, 0.0435067086613604, 0.02842402701000018, 0.018283504360754575, 0.035293710617614646, 0.037090939536158524, 0.021992444626188705, 0.027059879852458835, 0.027948950716693486, 0.01600702276586422, 0.032583672287208695, 0.057464682896222384, 0.016216457688382695, 0.022425957256928086, 0.027969936108482734, 0.08847364503890276, 0.05581593779580934, 0.007487069898551064, 0.014903226102303182, 0.03975671024194785, 0.03207960558523025, 0.015370314342102833, 0.020003136014565825, 0.013176498668534415, 0.029168334124343734, 0.029145426782114164, 0.07497082530919995, 0.01005267272038119, 0.014521694343004907, 0.03483880377773728, 0.07795914781412908, 0.03483894966276629, 0.01484806799063725, 0.03565185836383274, 0.05416124194328274, 0.04134364758751222, 0.0316786049599094, 0.05070868952732001, 0.023569946942318763, 0.11403010333223002, 0.03607161369706903, 0.06482772422688347, 0.09278561294611011, 0.01735109037586621, 0.02935199998319149, 0.038154132664203644, 0.008127235458232462, 0.020712817486907755, 0.07316917234233447, 0.028205847467428873, 0.02063465873444719, 0.01632632777493979, 0.06245252596480506, 0.04256967215665749, 0.029272224621048996, 0.05777514659400497, 0.042762538950358114, 0.01451907180515783, 0.010679002951032348, 0.048300850338169506, 0.011490252633978213, 0.03541477483564189, 0.12835468325231755, 0.06159824359097651, 0.028612193252359117, 0.03649622734103884, 0.03744772342698915, 0.04161749753568854, 0.03089983674830624, 0.027067470962979963, 0.04587327256532652, 0.05533476825803518, 0.03198655807812299, 0.02813045204883175, 0.037986286849315674, 0.00757758053285735, 0.027678703789466193, 0.019385601294093897, 0.03641798546803849, 0.14641666119652136, 0.16127000988594123, 0.15110923296638898, 0.11930587595062596, 0.1078632649566446, 0.1726652184235198, 0.08423612599394151, 0.15188553131052426, 0.1404014482562031, 0.14453291227774961, 0.1459809738610472, 0.16235444455274514, 0.19960794411599636, 0.0777684184057372, 0.14089008846453258, 0.07978300244680472, 0.15801680088043213, 0.12556232166077408, 0.24185987189412117, 0.11066344327160291, 0.12588603714747088, 0.21458542400172778, 0.1321700042379754, 0.1280063098030431, 0.08450358414224216, 0.17704206784921034, 0.2203857856137412, 0.1855798297162567, 0.202884386160544, 0.09373592838112797, 0.16304975295705454, 0.11809158325195312, 0.11789611088378088, 0.14863386936485767, 0.1015978693696005, 0.07208731610860143, 0.1466171954359327, 0.1689142904111317, 0.15295746736228466, 0.15087744540401868, 0.07937197985925845, 0.09292415622621775, 0.17540635062115534, 0.15670607478490897, 0.14835535788110324, 0.15155459621122905, 0.14615083831761563, 0.12018338457814284, 0.25764332924570355, 0.1557158072079931, 0.1627555401729686, 0.12281797320715018, 0.10011902943785701, 0.127581031194755, 0.13234908320009708, 0.16456532877470764, 0.1848139265286071, 0.32260372063943316, 0.10645269243312733, 0.13204062118061952, 0.11766002140939236, 0.1574213999722685, 0.07173393507088933, 0.1989254600235394, 0.05182838087369289, 0.11270915849932603, 0.12430228213114397, 0.16140176781586238, 0.09587662494076149, 0.07310231628694705, 0.09060303720512561, 0.1410607128803219, 0.20359310241682188, 0.1180498262069055, 0.11844721702592713, 0.046966582470174344, 0.11589885662708964, 0.14001556539109775, 0.16386905685067177, 0.15155327985329287, 0.17171771212347917, 0.15890880301594734, 0.11939119494387082, 0.17987264453300408, 0.06802136464310543, 0.12097002379596233, 0.18578102891998632, 0.1508948566125972, 0.2014654880123479, 0.10394339529531342, 0.11130786154951368, 0.1458423220153366, 0.2265338557107108, 0.17806953271584852, 0.14939103302146706, 0.13517125962035997, 0.09164441882499627, 0.1629986185580492, 0.16998811279024395, 0.1364918923271554, 0.2340934414948736, 0.104085684088724, 0.13705283722707204, 0.21559728256293706, 0.08871908472584826, 0.16653972997197083, 0.11516753158399037, 0.160844907696758, 0.14638463434364113, 0.10569271285619054, 0.12579329498112202, 0.06588638813367911, 0.22426199833197252, 0.13397447312516825, 0.10408265103719064, 0.19932627065905503, 0.10554621036031417, 0.1595009605267218, 0.09059379555817161, 0.20354465501649038, 0.14312858906175407, 0.15504462750894682, 0.08650467890713896, 0.20340042561292648, 0.07747397491974489, 0.13371785118111543, 0.14913834658052239, 0.12937292004270212, 0.09441953205636569, 0.10122818313539028, 0.11207005315061126, 0.13129207491874695, 0.11897566009845052, 0.12912118355078356, 0.10238066129386425, 0.08738967856126172, 0.1544648464769125, 0.15406468723501476, 0.07765748471553836, 0.20667171079133237, 0.1391850249575717, 0.09270511833684784, 0.06330651656857558, 0.07457160244562797, 0.1331868161048208, 0.14737347699701786, 0.12193445275936808, 0.14190908521413803, 0.12311826566500322, 0.17262081509189947, 0.12199351244739123, 0.06710695049592427, 0.10723332661603178, 0.1577445047774485, 0.09333550451057297, 0.10259507835975715, 0.1636308232056243, 0.06712497238601957, 0.1019472334800022, 0.3375739130590643, 0.1965627468058041, 0.12038952351680823, 0.11226625833660364, 0.11667489712791783, 0.16480394239936555, 0.10770270321518183, 0.14111590491873877, 0.17160465461867197, 0.12555597057299955, 0.1510131795491491, 0.1515029596963099, 0.09060925258589642, 0.07880294003656932, 0.11250979134014674, 0.06739349583429949, 0.08597249710666281], [0.06878927629441023, 0.04015117996771421, 0.029819368118686334, 0.011668290893015052, 0.03364594939297863, 0.04611167245145355, 0.010439879576941686, 0.03679497613172446, 0.02917441719078592, 0.023902276431077292, 0.041572758329233954, 0.03011130102510963, 0.009815221086942723, 0.06756260033164706, 0.012517533447992588, 0.0028994089724229915, 0.048644168701555045, 0.033107199373521974, 0.0550827399960586, 0.04788787356976952, 0.030633447292659963, 0.013640753176462437, 0.01101978020077305, 0.03446789618049349, 0.01841702139271157, 0.0028456450381781906, 0.021350457199982235, 0.04464261360200388, 0.06273951235094241, 0.029294334684631655, 0.06594823660062892, 0.025498699696202363, 0.004444896734120058, 0.05846283505005496, 0.025171455827408602, 0.055535204109868834, 0.03702948461951954, 0.0067866224396441665, 0.03931730453457151, 0.03597794533041971, 0.11117941487048354, 0.027170269018305198, 0.007430888047175748, 0.058010421826371124, 0.018892548911805664, 0.005555680187951241, 0.0634501420759729, 0.05794309079647064, 0.0947398752240198, 0.02841520944743284, 0.014292112019445215, 0.05100073439202138, 0.048190920879798274, 0.036989776750228236, 0.04790077591314912, 0.037058447886790545, 0.009287104559397059, 0.02672608642439757, 0.07059295808098145, 0.07856775979910578, 0.028397099347785115, 0.01641392834218485, 0.04135503001245005, 0.039793663259063444, 0.021782865514978766, 0.03689677674057228, 0.014012469078547187, 0.02398974129131862, 0.020638059891228164, 0.030716974953455583, 0.031106029969773123, 0.055652421034340344, 0.05745362277541842, 0.024445735483563373, 0.027988407528027892, 0.009809736827654498, 0.026771421045331017, 0.014422015852427908, 0.027213927657742585, 0.03270194433363421, 0.0172230016240584, 0.022835342878741876, 0.020421865063586404, 0.04316268462155547, 0.06107687085334744, 0.043376284052750895, 0.02540539943480066, 0.029450563980000358, 0.01825918396934867, 0.04597073733540518, 0.028088447338502322, 0.05270243236528976, 0.053241955914667675, 0.1143844478896686, 0.057053456748170514, 0.03311338422021695, 0.0760337436305625, 0.01591574284248054, 0.056755277926900556, 0.024328362496037568, 0.06268440173672778, 0.02973457838275603, 0.015477589032213603, 0.009849385325131672, 0.04168218227901629, 0.04734864518312471, 0.02833901675018881, 0.03290763543918729, 0.012745257433769959, 0.025053772410111766, 0.04061961001051324, 0.02248483374049621, 0.08032130463314907, 0.02572827014539923, 0.011164031656725066, 0.03450237593746611, 0.013644264595183943, 0.030022365440215384, 0.06431481960628714, 0.08902559256447212, 0.05301054154655763, 0.08015798803951059, 0.053958980832248926, 0.008916144375689328, 0.08798554765858821, 0.03594240027346781, 0.024099353534568633, 0.02717574479590569, 0.04396391573495098, 0.019451604091695378, 0.04825429265786495, 0.025391199393197894, 0.04110322227435453, 0.023647530636351024, 0.013577852980233729, 0.04329953834946666, 0.08259569973285709, 0.06246839689889124, 0.022036467978198613, 0.02144890245316284, 0.051778121784861596, 0.08624171944601194, 0.026299326913431287, 0.03630570149315255, 0.0629110052915556, 0.030370793172291348, 0.03970040540610041, 0.0072525300285113704, 0.030170126618551354, 0.07520922858800207, 0.03150755645973342, 0.04429820279723831, 0.024730621803818003, 0.05616484050239835, 0.021117884233327847, 0.0708080604672432, 0.0195084212214819, 0.0067197710491849905, 0.014899368630722165, 0.024271397784884487, 0.01609333072389875, 0.06119904786880527, 0.07428260081048522, 0.022652330109849572, 0.05070070656282561, 0.05032717642773475, 0.03920887803126659, 0.013112295685069901, 0.015809085619236742, 0.03488069313711353, 0.02723717426748148, 0.01147341393932168, 0.029566539185387746, 0.050941162410059145, 0.05516158915790064, 0.05233970790037087, 0.1014641233320747, 0.04189966293051839, 0.04938947156603847, 0.027074593884338225, 0.09153026209345885, 0.05949219302939517, 0.03470871165128691, 0.02316735515237919, 0.061125840725643296, 0.03210358162011419, 0.02776347995469613, 0.02834748656355909, 0.03586478604535971, 0.049092368222773075, 0.061514763427632194, 0.0848324429243803, 0.048279802181891034, 0.036417079623788595, 0.03765532460861972, 0.00939183559135667, 0.021676533988543918, 0.02155918305340622, 0.04465030479644026, 0.04826831119135022, 0.049582128013883314, 0.03772384986015303, 0.02430401157055582, 0.0631848688104323, 0.05791968133832727, 0.026163652140114988, 0.10850496230913059, 0.02858541826052325, 0.03377445374748536, 0.04696307105145284, 0.0578887944242784, 0.04917068812730057, 0.04172994775165405, 0.0267016218443002, 0.02732714801095426, 0.039220840603645356, 0.06087791760052953, 0.03230488260409661, 0.016233309105570828, 0.009090326859482696, 0.013504119972432298, 0.019540132555578436, 0.022104316391050816, 0.0402760880866221, 0.029166349409414188, 0.01859665336087346, 0.033658868699733696, 0.07586911746433803, 0.05147094898191946, 0.01668884528667799, 0.026905781157048683, 0.11763070869658675, 0.0501224725906338, 0.036654007088925154, 0.04750627565330692, 0.06885282788425684, 0.026204603424827968, 0.014435230321916086, 0.04214326039488826, 0.12815019993909768, 0.009734939368042563, 0.036867562415344377, 0.04148391434656722, 0.05935260480535882, 0.04268738101901753, 0.02247683041995125, 0.010829488447468196, 0.037698082492819855, 0.06089624483138323, 0.02528894246955003, 0.0410322475114039, 0.023460477191422666, 0.018612247791939547, 0.10055285080202989, 0.05462258808048708, 0.06065314609025206, 0.027895524565662657, 0.007919518077479941, 0.057811753558261056, 0.007139285926574043, 0.06191010507089751, 0.0194780499940472, 0.06888792850077152, 0.02124303492850491, 0.08660987219108002, 0.03171639257509794, 0.044417248373585086, 0.024634212155693343, 0.020027982270611182, 0.041052447498909066, 0.05310119382504906, 0.03896661728088345, 0.10573305176304919, 0.042371312621980906, 0.05907478542732341, 0.013917365610333425, 0.021492057280348878, 0.022438382929457084, 0.04574905994481274, 0.01415630238729396, 0.023366810521110892, 0.030337816370385032, 0.04922155111229845, 0.07473899703472853, 0.05561521017391767, 0.021707902662456036, 0.020088244661954895, 0.047629840272877894, 0.07424469784434352, 0.023301057085128765, 0.06893563629793269, 0.025084978235619407, 0.03373494265334947, 0.02716088996800993, 0.013002937892451882, 0.014458510858405913, 0.03179057341601167, 0.037455183919519186, 0.05842245543109519, 0.0284687713054674, 0.03797436498903802, 0.09401099969233785, 0.033205247683716674, 0.017652923108211586, 0.018662944535857866, 0.019768339149387817, 0.011116644467360206, 0.028423984601561512, 0.021758490840771368, 0.023788543783926537, 0.028558493990983282, 0.060263022381280146, 0.06284088548272848, 0.029462638510657207, 0.02758783777244389, 0.029960561078041792, 0.028871658258140087, 0.07703399924295289, 0.020834736659058502, 0.02676606740403388, 0.0189551335892507, 0.03379819229511278, 0.011901828227564692, 0.02366954061601843, 0.022704709620614136, 0.02596716027307723, 0.053025598238621435, 0.05933938694319554, 0.038686250003853014, 0.020733539946377277, 0.06296545772680215, 0.054944827753518305, 0.0345732692762145, 0.025954453008515493, 0.04626862099394202, 0.11030446431998696, 0.04818195064685174, 0.04542598228103348, 0.025451850245839784, 0.024529514202315892, 0.01787103818995612, 0.025767969533002803, 0.013704846746155193, 0.08562753668853215, 0.05015135104102748, 0.01187033741734922, 0.025844404806516, 0.07133437293980803, 0.09347729797341994, 0.006864695527058626, 0.04697132882262979, 0.06567258853465319, 0.09655317185180527, 0.19434545721326554, 0.17650271393358707, 0.0825035207505737, 0.16821115171270712, 0.15490269155374595, 0.1167378651776484, 0.08913893505398716, 0.20743988028594426, 0.07180771896881716, 0.11282889278871672, 0.08871107801262822, 0.13406201771327428, 0.19888375726129326, 0.15206918359867164, 0.1937667889786618, 0.11333643698266574, 0.10856510086783341, 0.16067585748221191, 0.10019440789307867, 0.06252267291503293, 0.09824539069086313, 0.16383115388453007, 0.10899106479649033, 0.12114794924855232, 0.08607289314802204, 0.14065049774944782, 0.09609195802892957, 0.2532198780349323, 0.08357990120670625, 0.23750758543610573, 0.11457062432808535, 0.08803145055259977, 0.13532010306205067, 0.15379461672689232, 0.20940408988722733, 0.2039395488266434, 0.21649281308054924, 0.10546942733760391, 0.21354005938129766, 0.18823657929897308, 0.09202933817037515, 0.07758585177361965, 0.12105151585170201, 0.14541709768984998, 0.08272432283099208, 0.09168093079434973, 0.06901537773332425, 0.13075338596744196, 0.1761577467301062, 0.13082357362977096, 0.13788761171911443, 0.11211201375616447, 0.1424815652093717, 0.21285486114876612, 0.19952456573290483, 0.15030583393360886, 0.17423484634075845, 0.1451083913977657, 0.12089841121009418, 0.1275681254587003, 0.05310610981125917, 0.21864998447043554, 0.26774359441229273, 0.0909652052713292, 0.0662965082696506, 0.20556029757218702, 0.16874481950487408, 0.06571738541658435, 0.09493602612721068, 0.06068579719534942, 0.12209240214100905, 0.21651092996554716, 0.1364683878741094, 0.20760741058204854, 0.09054109374327318, 0.16494119646293776, 0.13530907008264745, 0.1763279368834836, 0.1073848774124469, 0.1619730128773621, 0.07922222718064274, 0.17850431081439766, 0.06896275734262806, 0.17919998562761716, 0.13531996735504695, 0.09918645769357681, 0.12030592800251075, 0.15445057010012014, 0.10510895560894694, 0.12248634600213595, 0.12791200700615132, 0.11029191820749215, 0.28381008229085375, 0.07584154858653035, 0.1459028066268989, 0.22662704571017198, 0.13771729942943367, 0.1420051386313779, 0.14600815597389424, 0.1472870044942413, 0.07698570112032549, 0.08991833430315767, 0.09894318253334079, 0.18974534262503895, 0.27389296729649815, 0.12989666765289648, 0.15895853963281426, 0.11017274710216693, 0.10894718393683434, 0.1614782251417637, 0.07242678717843123, 0.19632908648678235, 0.14381328517837183, 0.09538861576999937, 0.1225571579166821, 0.07486480421253613, 0.09148754831403494, 0.08683229597019297, 0.16394662697400364, 0.22468167224100657, 0.19247291769300187, 0.11239587888121605, 0.0935742063447833, 0.1292352724288191, 0.22737644692616804, 0.14502989846680844, 0.15495331026613712, 0.12609457810010227, 0.14701915958098002, 0.15283136841441902, 0.08787627637918506, 0.1602091882377863, 0.0685353617050818, 0.13662875284041676, 0.1418176865471261, 0.1667873002588749, 0.22385402236665997, 0.09613982188914504, 0.1348119753279856, 0.15389627484338625, 0.2029275545584304, 0.09123201881136213, 0.1549630133169038, 0.17194488564772265, 0.09409555872636181, 0.13653702847659588, 0.182148383132049, 0.06598764591451202, 0.1409737654030323, 0.08363698635782514, 0.15726841746696404, 0.11236090718635491, 0.08660530565040452, 0.13944790299449647, 0.16558186922754559, 0.07260262274316379, 0.0810009931613292, 0.0851460618099996, 0.2556427094553198, 0.13806631070162567, 0.18850097725433962, 0.15215427189001016, 0.14755703429026262, 0.11889039538800716, 0.0764041898239936, 0.10808015867535557, 0.14520600544554846, 0.11667704129857676, 0.1813364481287343, 0.15413674765399524, 0.10210278084767715, 0.17100538606090204, 0.10385576249765498, 0.12347275950014591, 0.16322200585688862], [0.0455732684848564, 0.02848186363865222, 0.014596535059224282, 0.06548066490462848, 0.011648772833203631, 0.011261040960172457, 0.028877273135419403, 0.023766230159838284, 0.03401547617145947, 0.02260130427644721, 0.043773149007133076, 0.03849251129265342, 0.03732850482421262, 0.007735149934887886, 0.059620714347277365, 0.033129533353660784, 0.051579277097646675, 0.04563051987705486, 0.04966016971905317, 0.01835893200976508, 0.003177277332205059, 0.030129920026021342, 0.05112459756700056, 0.03636212846530335, 0.015809402834357958, 0.0649505662066596, 0.024287485850176642, 0.023905945609190633, 0.026970779722822563, 0.03164693433791399, 0.025261198868975043, 0.048658071884087155, 0.01030996980677758, 0.0370610331052116, 0.031790145938949924, 0.05584033112972975, 0.029111398250928948, 0.08029979507305793, 0.01739895423608167, 0.008717957867442496, 0.03931887873581477, 0.03018192294985056, 0.019990900331842046, 0.08122763064290796, 0.03764789465016552, 0.03338838428524988, 0.01334157181970243, 0.07768494502774306, 0.04516485147178173, 0.05984201854360955, 0.028588481846132448, 0.06122322407151971, 0.06693125063819544, 0.030107650506709303, 0.05227823941303151, 0.12504404304283007, 0.010613185054223453, 0.004482934135012329, 0.06866380159876176, 0.021363900675039207, 0.004372947849333286, 0.06070293020457029, 0.01752115330392761, 0.08490795708660569, 0.07410048879683018, 0.011647024757361837, 0.02878530789166689, 0.022946853323706558, 0.04135144395487649, 0.025771455506661108, 0.05251661894310798, 0.04383023415825196, 0.02840692792753024, 0.03310311459270971, 0.002443625550118408, 0.030537220848990337, 0.05279098118522337, 0.08928358514926263, 0.03310468879395297, 0.06658293825707265, 0.011187488612319742, 0.07794785699141876, 0.03139984241819807, 0.047484097736222405, 0.025206882140732238, 0.04014309183029192, 0.010775872306632144, 0.01775544635685427, 0.06799386361879961, 0.033526215103587935, 0.019928620995155404, 0.006550949416123331, 0.07315825471388442, 0.042024981563112566, 0.03045565415439861, 0.05012537332783852, 0.11296426052493708, 0.0658598370583994, 0.05415326576413853, 0.05289604554751089, 0.06629004183092288, 0.026029234352920736, 0.013947272041280354, 0.05134435470349022, 0.06654050946235657, 0.028911067572023188, 0.07019301597028971, 0.04334347349192415, 0.06579182749348027, 0.05456969966845853, 0.030526052162583386, 0.04320846198658858, 0.05345695312800152, 0.033157919866165945, 0.03931311797350645, 0.013948262702407581, 0.002677716950919213, 0.029216666173722063, 0.03424242577914681, 0.05090622464194894, 0.06267378266368594, 0.060923379446778975, 0.012495883940053838, 0.035657496989837716, 0.0515687224854316, 0.037766533105501106, 0.015356850510995303, 0.04591824247368744, 0.032933986346636496, 0.0614825805116977, 0.03566419073779668, 0.06182256048279149, 0.023301789902948906, 0.029553457030228207, 0.010829976992681623, 0.051741083950868676, 0.05765396023967436, 0.04679277233247246, 0.03295403027108737, 0.03337303243045296, 0.027762280644050667, 0.05774611208055701, 0.056574397454304357, 0.050633986214441914, 0.010555840363459927, 0.0526155086367258, 0.029936364519276788, 0.09293954540044069, 0.043552204434360774, 0.06261829885521106, 0.03689103972698961, 0.03669076333088534, 0.01042061427142471, 0.03539576228441937, 0.059175439311989715, 0.05011506638090525, 0.027559128955804875, 0.005961257531972868, 0.09837413592530148, 0.021268052514642477, 0.04958094397027578, 0.06255936130349125, 0.004121170645313603, 0.010917601308652332, 0.027227717185659066, 0.047239716563905985, 0.04416687234437891, 0.021122584784669534, 0.015049682797065802, 0.05124686618468591, 0.06018627328532083, 0.05196865102542298, 0.06055565417877265, 0.057081127406230996, 0.0611170536971518, 0.016111030309860195, 0.04296705958300403, 0.03796488246215241, 0.039816360255437236, 0.032366401981562376, 0.021856566292366812, 0.07804093842527696, 0.04391497639673097, 0.08046846530799355, 0.027291353592383008, 0.03760076021509511, 0.04653454565310052, 0.02359162613616458, 0.03469876093523843, 0.02356690540909767, 0.057128305946077616, 0.03382511995732784, 0.02670619517032589, 0.027627253871677176, 0.06492246807153736, 0.019796271043430482, 0.04626466852745839, 0.021858476368444305, 0.037886053656360934, 0.013040760282560118, 0.07259044982492924, 0.04210146603041461, 0.04913852556741663, 0.06525294176701989, 0.035697282890656164, 0.05937948836279767, 0.05588357077379312, 0.09935731959662267, 0.040157212144029994, 0.03862926324031182, 0.04312424222007394, 0.04737960334335055, 0.036961468269250224, 0.017060928445841585, 0.07815730718097516, 0.04930897356410112, 0.026712434299822365, 0.05523839592933655, 0.0179870422330818, 0.04118288567821894, 0.036191144425954135, 0.042801771845136366, 0.05103618784674576, 0.019917082507163286, 0.036360360881579776, 0.023368718900850842, 0.02581439829165382, 0.08880353519426924, 0.019042591664141843, 0.03192505905670779, 0.031529381538608243, 0.014973615628800221, 0.04597248795575329, 0.006764937732701323, 0.0375036211418254, 0.022578510588833263, 0.05043678018929703, 0.015337291739082761, 0.022246328681441288, 0.024228919796379547, 0.09271993075630494, 0.016520315847758735, 0.05859508831053972, 0.052386665916336436, 0.020447096388254846, 0.03134030097031167, 0.03980162586750729, 0.03786723788029381, 0.05997127267931189, 0.015012692460524184, 0.05960823608828442, 0.023993234050327113, 0.017288176608937125, 0.023807345989293287, 0.056354667459215434, 0.015934802891154374, 0.07091722318104335, 0.038655719320688925, 0.020358846123729433, 0.043395208394421, 0.030611004746918167, 0.011880851317463177, 0.047240259391920905, 0.08388855321598904, 0.118193458499653, 0.02287279631543372, 0.02113426915769066, 0.0524198666347989, 0.02212686919873314, 0.028699703913714205, 0.02783819005292441, 0.018325107039085457, 0.08662131229149443, 0.0216962471271732, 0.04169956634619406, 0.10888743892844234, 0.007701480179093778, 0.026588764507323503, 0.06001559458673, 0.0964853862034423, 0.051232399818088324, 0.05807521513530186, 0.048168413873229704, 0.02007348652529929, 0.01688976968372507, 0.015615099242755344, 0.019932626048102975, 0.021343659975432923, 0.052313740365207195, 0.024637881333806684, 0.03579572135848658, 0.045825476558612924, 0.06637561188212462, 0.05548627494967409, 0.00601374518425603, 0.023559790969427143, 0.012919948818827314, 0.01688580703921616, 0.013491573859937489, 0.04018094390630722, 0.05579084896349481, 0.04990493426365512, 0.061120805995804925, 0.04017077945172787, 0.01256845410846706, 0.012425006716512144, 0.023682451441085765, 0.02293876857895936, 0.01934668731077441, 0.03349812714649098, 0.022370860213413835, 0.06250484101474285, 0.03795282489487103, 0.0276448873004743, 0.05803697968700102, 0.021573257566030537, 0.023322626017034054, 0.09818676526525191, 0.02390577088642333, 0.03498183556699327, 0.03087401170549648, 0.0119744179038597, 0.029044959494577985, 0.011609734169074466, 0.016079195143122758, 0.07776003849825688, 0.015300309884228876, 0.016204898844340017, 0.030631825593965392, 0.035700600926897356, 0.026403444719367793, 0.022926773776167204, 0.009622439110119427, 0.039274787530303, 0.00939688049922032, 0.056969291264457364, 0.03933184554002114, 0.07671770692936011, 0.030703085341623852, 0.007532435901729124, 0.02678180263111634, 0.05579601600766182, 0.029070815071463585, 0.03521269353638802, 0.07316831738821097, 0.06537781935185194, 0.035544537872608216, 0.0609319018466132, 0.02166616258078388, 0.042235609010926316, 0.01026135277269142, 0.017516391684434245, 0.13848854947303021, 0.15903469840330736, 0.112437574858112, 0.24537582322955132, 0.09027123358100653, 0.12063528890056269, 0.14231677619474276, 0.19760725647211075, 0.10701501475913183, 0.10513878400836672, 0.1586959194391966, 0.1659402171415942, 0.1090109594432371, 0.10834291457597699, 0.18523942226810114, 0.10478242420192276, 0.08730922466410057, 0.12216966013823237, 0.11370878985949925, 0.1245051912431206, 0.10562452687216656, 0.083519783004054, 0.14812686799892358, 0.09377157861100775, 0.21690855148647512, 0.19634990394115448, 0.1574680967522519, 0.11394293872373444, 0.15070266835391521, 0.14945776015520096, 0.11729756157313075, 0.1356764289417437, 0.07578482305897133, 0.14341330235557898, 0.1736201343259641, 0.17338118143379688, 0.11598770400243145, 0.12550198632691587, 0.1423330067523888, 0.11348906664976052, 0.1590359333370413, 0.0984812630340457, 0.14274571889213153, 0.12622656673192978, 0.08546207592423473, 0.11391932570508548, 0.2071909529290029, 0.0931395503825375, 0.165291089830654, 0.0997643998957106, 0.24062743516904966, 0.1808053044868367, 0.20825268381408282, 0.16317039648337023, 0.13400198093482427, 0.22252247881676468, 0.07811754502888237, 0.08002776359873158, 0.17065598123839923, 0.0973285473883152, 0.11414639066372599, 0.11066714807280473, 0.15021556163472788, 0.18472669406660966, 0.2610680583332266, 0.1042094285200749, 0.12214873411825725, 0.20224390338574136, 0.12317397339003426, 0.11404902088854994, 0.13141031643109663, 0.1728452066225665, 0.19077214252735886, 0.1075482415035367, 0.17028038496417658, 0.09299633199615137, 0.09180506199066128, 0.11552568950823375, 0.10989074116306645, 0.250967087490218, 0.20329061150550842, 0.10376920857067619, 0.05277312553620764, 0.14930665040654795, 0.15324488122548374, 0.17154080447341713, 0.14687509302582058, 0.13389490810888155, 0.17593396588095597, 0.12162924770798002, 0.09574258713317768, 0.10570390189864806, 0.13271049809242996, 0.10909547097980976, 0.15723759840641702, 0.0923431266897491, 0.15514741199357168, 0.17200201829629286, 0.11105711571872234, 0.19009796370353016, 0.12095363038991179, 0.18479190128190176, 0.10681475871907813, 0.12778062905584062, 0.268902342234339, 0.21218758981142724, 0.15443789506597178, 0.09972942820084946, 0.14171429138098443, 0.1608039920351335, 0.09155023137905768, 0.12138387587453638, 0.16946439232145036, 0.162892183555024, 0.12033121021730558, 0.08204785055880036, 0.16806644733463014, 0.09510195508067097, 0.08805647492408752, 0.14930802104728563, 0.19282426312565804, 0.13853915461472102, 0.0767432673435126, 0.10960437224379607, 0.1843439731746912, 0.15331558457442693, 0.12713520654610225, 0.16649980497147354, 0.09077746141701937, 0.16654583678713866, 0.2270717304199934, 0.12733968985932215, 0.11712425015866756, 0.12985747547021934, 0.08927480490612132, 0.12119404891771929, 0.13177240985844815, 0.11757515024925981, 0.15798907593957015, 0.07253948505967855, 0.14844461237745626, 0.16088150787566388, 0.11063590153519597, 0.12099822371133737, 0.08863485138863325, 0.10182170450155224, 0.1804151197097131, 0.1451691881354366, 0.220280151282038, 0.14623543806374073, 0.09897601684289319, 0.08987821252750498, 0.13244103826582432, 0.11761039335812841, 0.15815379710069724, 0.14925732091069221, 0.08714747548635517, 0.18314696954829351, 0.22214298775153501, 0.12959957788033144, 0.13232553803494998, 0.23018529691866466, 0.08372989815792867, 0.10750304428594452, 0.06065883221370833, 0.11180265607046229, 0.10232353543064424, 0.16674490539090975, 0.17063677869737148, 0.1965973928038563, 0.12287946205054011, 0.14646202804786818, 0.10214206123990671, 0.15557450907570974, 0.1313930545002222, 0.20396792516112328], [0.014460444683209062, 0.029555038016821657, 0.023303844167717865, 0.0187037414538541, 0.029136928131005595, 0.0015645362540713645, 0.020640237988638024, 0.025401233229786158, 0.06395967437752656, 0.03113953602899398, 0.04498190486005374, 0.0952157454032983, 0.04205742910770433, 0.03095836378633976, 0.08151967890028443, 0.013991012953088751, 0.00860466287537877, 0.05576253030449152, 0.01778792613185942, 0.024317144615841762, 0.03607199367667947, 0.06888378943715777, 0.029674928369266645, 0.028183547414040992, 0.006953798625285604, 0.011433296404512865, 0.07431004755198956, 0.021737230642299567, 0.07340513968041965, 0.018596621130460074, 0.028514986325587546, 0.023193819714444022, 0.035954552835651805, 0.020425028733110855, 0.025154158273445706, 0.043344460760376284, 0.013703840817990047, 0.06104795847620283, 0.028560624590941837, 0.03650299572784986, 0.06772285673235144, 0.011814118246547878, 0.020145095718492354, 0.022592698756073202, 0.04421623237431049, 0.057642180871750624, 0.02129967903186168, 0.05596009595319629, 0.022522880895329372, 0.018644635964717184, 0.032412162383220026, 0.07768615960542645, 0.02021158197229462, 0.05608191673776933, 0.046307908171521764, 0.07508048335356371, 0.01533379898007427, 0.03214518599478262, 0.06422777034874473, 0.03894143345366631, 0.023400576119976382, 0.029886919672467878, 0.04954433700601969, 0.012988853201802288, 0.057085334323346615, 0.01617657848899918, 0.015792451333254576, 0.020828460210136006, 0.018557941241722022, 0.06251829636416265, 0.03926756791770458, 0.05836395214178732, 0.021016137907281518, 0.04912702100617545, 0.03042871631415827, 0.03103186609223485, 0.04149524927405374, 0.025695028714835644, 0.06074929450239454, 0.018133641420198337, 0.024044103820675185, 0.03140124020033649, 0.03388250366385494, 0.04028871901599424, 0.036734997028751035, 0.018673339692343558, 0.022772232336657386, 0.03034718015364238, 0.030916342112634863, 0.051151562548641644, 0.0066586477665363675, 0.03892237679766757, 0.05874405388853379, 0.05589086502524359, 0.03547458769753575, 0.018675112365079776, 0.08890561400247471, 0.0810222245220627, 0.03319755648928029, 0.06522202092622008, 0.03091288497671485, 0.04111717973968812, 0.0632224189383643, 0.07933159345494849, 0.023428021165143167, 0.029680930011506592, 0.05014331040105649, 0.039574652511094294, 0.022462820368153707, 0.06808039718972785, 0.020852582130048956, 0.0034610858419910073, 0.05402577242680958, 0.02956173855013081, 0.010195483985756124, 0.01107686450372317, 0.07769121469131537, 0.06510449866099016, 0.048624606536967416, 0.037660366123808284, 0.0033477454728979084, 0.03206644539854356, 0.0349821714418275, 0.007508938234033329, 0.04669073084369302, 0.03784803533926606, 0.03818757426259773, 0.02043551718816161, 0.09476399714393274, 0.02813965128734708, 0.05885619537106582, 0.03643583433170404, 0.013874359212682714, 0.04311300568016512, 0.08036928384431771, 0.03670185398576515, 0.043175766776715, 0.0244865103491715, 0.024280423996970057, 0.03237175562285951, 0.03457332355901599, 0.05652710695617965, 0.07801077754369803, 0.034301644922899346, 0.024233284472887005, 0.02686295033033405, 0.038816908707043955, 0.04793526245547192, 0.03762166587901967, 0.032240051975739856, 0.03404928417876363, 0.052240723211850436, 0.04074377513357571, 0.05716093669512442, 0.02711754006200603, 0.027517273523179547, 0.056239486139799864, 0.02472129025097404, 0.03455525756414447, 0.05996059932346855, 0.019815229311851517, 0.014952289273164101, 0.015816915913351944, 0.074417656420597, 0.02575511299073696, 0.0206831247944917, 0.04151356293420706, 0.01813803663078163, 0.019020069390535355, 0.009377561759070625, 0.06850933988711663, 0.07998220675757953, 0.0477449028486652, 0.04825313914833324, 0.03329828501279865, 0.05545312851401312, 0.02798524046582835, 0.08554237375834159, 0.03670337051153183, 0.05670985000740204, 0.016661530859502297, 0.014837041796584214, 0.009241741100725318, 0.02280378251868699, 0.017502882052212954, 0.022392020327970386, 0.025818091218492815, 0.07878454495221376, 0.01807068694116814, 0.02963804659832801, 0.04262652321319495, 0.029073512248162712, 0.03391216582219515, 0.043385132149394066, 0.00738841769218977, 0.05054305573659284, 0.012282616991017545, 0.12208571178572518, 0.036125910069261274, 0.01249270245898515, 0.007506863613213811, 0.024890449031123092, 0.02093719375053687, 0.03118676206629191, 0.03436762566811272, 0.05441767729020544, 0.05261344589026911, 0.0316687153120126, 0.024005456162350516, 0.016462759114801884, 0.025346397422254086, 0.04809892849464502, 0.05943244123565299, 0.04676737815939954, 0.04533200518095067, 0.031951314969254394, 0.06330235714891128, 0.02599401499277779, 0.07154178073895828, 0.02855111492265548, 0.056037655898502896, 0.028489934812699045, 0.03841174187670861, 0.005634605260898492, 0.04246294877624937, 0.029039643172706877, 0.010982615989632905, 0.05358944048306771, 0.0047959635433341774, 0.07085743067520005, 0.012690585322811134, 0.048942557868680785, 0.03635239148778575, 0.04597348200955561, 0.025411111003320132, 0.00591123805082004, 0.02250271992358778, 0.035956605404083214, 0.041563930588641336, 0.07442907616496086, 0.06548648673508849, 0.03551203265253987, 0.07243167941591569, 0.01153607664829386, 0.029060528480580876, 0.0280686527756708, 0.03182944329455495, 0.06976551176714045, 0.043727402176175795, 0.00845369222640459, 0.002728626797241824, 0.07087858739708151, 0.06269275450280734, 0.01772448480395334, 0.021856729140771285, 0.0045407826380272, 0.01688063490603651, 0.02341219942484583, 0.043253886513412, 0.02458111848682165, 0.03992556028866342, 0.026880047716466442, 0.033436774010104794, 0.028202872091372098, 0.027248583833820055, 0.05208843620494008, 0.012554271878408534, 0.04574793018400669, 0.02988481960658516, 0.022902609447815588, 0.04012960594679628, 0.02046054495232446, 0.04087104794702359, 0.05258817385349955, 0.05647512778107609, 0.08577180680419717, 0.03180340790588941, 0.0636639009628977, 0.05628125675554786, 0.04107344137238605, 0.024265633629901067, 0.049153952061065605, 0.03224046588210123, 0.06424228421279363, 0.00549584103282541, 0.017808619753590653, 0.01240044629334339, 0.05880329678101199, 0.06196890691561358, 0.017235847988298962, 0.03281926643103361, 0.03594805247017315, 0.03971193710874234, 0.02892428882686155, 0.07053093998027699, 0.017569892474317124, 0.057453405644212446, 0.04275167899738465, 0.038392410414027314, 0.05155990831553936, 0.02959295455366373, 0.054972013259040456, 0.04315160753737603, 0.013433064633448209, 0.017213956752259816, 0.014987964948107089, 0.016951434946219836, 0.06498403833912951, 0.0729485670370715, 0.09971233590372972, 0.004011002427432686, 0.016270796469013606, 0.02955979454730238, 0.0782941405528358, 0.01855356808352683, 0.03331028829727854, 0.019633761906464185, 0.029255661581243788, 0.044829281978309155, 0.039653355787907324, 0.09492282862109797, 0.017774148478305767, 0.015947985130229166, 0.018330151946949105, 0.04682607143851263, 0.03968852425792387, 0.05146197196362274, 0.03977778214695198, 0.03594318058873926, 0.01583640174274998, 0.02251868076356394, 0.028304743946396878, 0.03906331530639103, 0.032571994699537754, 0.02779586473479867, 0.03485430830291339, 0.038433197153998275, 0.019585633417591453, 0.023426811676472425, 0.05497561967266457, 0.04575826087966561, 0.033811050533716164, 0.06507449384246554, 0.05613982291626079, 0.01405473078401493, 0.03334028972312808, 0.04566308616527489, 0.02540351650012391, 0.025536543290529932, 0.015726329792024832, 0.05938438060028212, 0.04002946096339396, 0.10904887598007917, 0.2673753670283726, 0.11934757871287209, 0.0898642007793699, 0.10802785719611815, 0.07460688626659767, 0.11961353729878153, 0.12477667310408183, 0.1874068666781698, 0.08585861857448306, 0.08133631838219506, 0.15552574954926968, 0.056273273791053464, 0.0990840531885624, 0.18406201473304204, 0.07507281590785299, 0.08296155902956213, 0.11437991527574402, 0.09080956290875163, 0.10203004867902823, 0.106951381745083, 0.21341776022953646, 0.15656422025391034, 0.1275337373039552, 0.1246555003204516, 0.18559962936810084, 0.10738171543926, 0.08400197034435612, 0.23785426254783357, 0.14015340299478599, 0.1303136817046574, 0.1578777554844107, 0.16528540370719774, 0.06255808565765619, 0.12613436739359582, 0.11003070936671325, 0.0874652945037399, 0.11421739256807736, 0.11868626491299697, 0.12844198356781686, 0.11273315828293562, 0.11455039041382925, 0.13153052569500037, 0.07399423699826002, 0.12008274426417691, 0.16868254356086254, 0.09299863901521478, 0.17866587000233786, 0.10696078624044146, 0.11071824175970894, 0.09343602947358574, 0.20211005556796277, 0.11737061265323843, 0.11510543205908366, 0.12241948316139833, 0.1631172536207097, 0.11320763746542589, 0.10519520419516734, 0.17759579313652857, 0.09637819124119622, 0.08497497599039759, 0.10233005615217344, 0.1767922176846436, 0.1234328073582479, 0.1372000386140176, 0.08657332629497562, 0.11053346310343061, 0.07565593533217907, 0.0901299761608243, 0.2338565784905638, 0.1240181252360344, 0.25998546928167343, 0.1565958671271801, 0.13104204833507538, 0.06619597652128764, 0.07536210931305375, 0.11677355611962931, 0.10787013851638351, 0.12294214511556284, 0.1180416430745806, 0.08862525690346956, 0.07775294102196183, 0.12448609726769583, 0.13713640559996876, 0.16751745822174208, 0.0737362511988197, 0.07760396187326737, 0.1019446754029819, 0.10864771929170404, 0.12190906197897025, 0.1096619391547782, 0.1237129337553467, 0.1228658099259649, 0.17690983494477613, 0.16924970384155, 0.11484509174312864, 0.15344536118209362, 0.183412711002997, 0.10177610694829907, 0.14621437633676188, 0.1179093558873449, 0.14644061348267964, 0.18618871990059102, 0.15209688139813288, 0.18502777362508432, 0.2495683011199747, 0.13513175531157426, 0.10525232327303716, 0.06490186774837119, 0.1022234515153936, 0.08970532859010355, 0.12754741656993115, 0.1730235256254673, 0.1044093927900706, 0.1747836997466428, 0.13350488618016243, 0.1880683433264494, 0.14311744751674788, 0.14457895766411508, 0.22633181512355804, 0.13213493754821165, 0.21520093668784412, 0.12947850009160383, 0.21913523200367177, 0.12571451706545694, 0.15129178602780613, 0.11044321116060019, 0.09701645520648786, 0.1628466131431716, 0.11414364938225065, 0.13890751770564488, 0.10239740753812449, 0.13621965050697327, 0.11152624804526567, 0.150490314034479, 0.10109134976352964, 0.09369322817240443, 0.11784832844776766, 0.04954650153272918, 0.0799452673111643, 0.09471082035452127, 0.11113146958606583, 0.11638892175895826, 0.08091334679297038, 0.15184571487562998, 0.10385761489825589, 0.08439533066536699, 0.1840783538562911, 0.12296647738133158, 0.18269403385264532, 0.1699764555586236, 0.18822986180228846, 0.13769325214837277, 0.14159735265587056, 0.06936375118259873, 0.09650909421699387, 0.1584704015403986, 0.08794434022690568, 0.09239958758865084, 0.1274949386715889, 0.10190430256937232, 0.10208587854036263, 0.07114733476191759, 0.12675642115729197, 0.1739341060497931, 0.12143894577664988, 0.19543762717928204, 0.11572080903819629, 0.08603221497365407, 0.11639359007988657, 0.0896214684471488, 0.19263454473444394, 0.10418616833963565, 0.12034970708191395, 0.2551228159240314, 0.2686708803687777], [0.09066285685236965, 0.024624451429450085, 0.03695386867704136, 0.07812225406191178, 0.0399906826870782, 0.0376009637756007, 0.02485922454590244, 0.03774805320426822, 0.03371373164866652, 0.022212881994034563, 0.02268824666472418, 0.014586389264357942, 0.010495134379847773, 0.03863103760938559, 0.04855745531884687, 0.10301994984703404, 0.0094627942391006, 0.01484365581667849, 0.03580334809209619, 0.023090792653549994, 0.019638839044741223, 0.03944939833932689, 0.04441626449780805, 0.015401650785601564, 0.013451609843676644, 0.058773583732545376, 0.08442222100815602, 0.021743196661451032, 0.012603714180711125, 0.09375409954892737, 0.030287662454481636, 0.031776999322963614, 0.025998605282178948, 0.06067130368735109, 0.03485066456986325, 0.06308229467166321, 0.022838839030425464, 0.02980637756575431, 0.04881977695705635, 0.03883296623826027, 0.024696006339841654, 0.0367814529288028, 0.0573820916137525, 0.020815815710063492, 0.05089541218642678, 0.048786158939557414, 0.030674077969576632, 0.019975882655541812, 0.03154759681118386, 0.03224744800744312, 0.003564765568756099, 0.0008008411678019911, 0.0501738817963217, 0.029159876185336282, 0.011545953573659062, 0.040799072344920466, 0.051184736125703366, 0.015106387968574251, 0.011198134826762336, 0.023536021887723888, 0.03174350004909294, 0.032339705021253655, 0.05784065915005548, 0.03184180959526982, 0.04574921600786703, 0.05094830399113042, 0.05331768381542393, 0.02602104952425829, 0.03144951457423823, 0.009028591198979743, 0.03149559049467955, 0.052700926017548354, 0.038364502268710306, 0.019459207076579332, 0.043059693183749914, 0.0719433513336948, 0.0162154755089432, 0.06466511330966439, 0.01819607342726418, 0.03172868423696075, 0.0034425720140071852, 0.07664734284792628, 0.02637647295237652, 0.04625701804512313, 0.061685286063168726, 0.022319510379540067, 0.023844940222001502, 0.011511098077919866, 0.0387079461610743, 0.05041783209890127, 0.049407568094985824, 0.018925376436007873, 0.0320146155011441, 0.01807068694116814, 0.017043417153347815, 0.01923117520553725, 0.09916536882519722, 0.03731062203379614, 0.0481027520394751, 0.06175748897450311, 0.05842014841203179, 0.01948283196959112, 0.0565818036640329, 0.009975090722686477, 0.07972078078559466, 0.0254547034855932, 0.08987618370779923, 0.00614486529125965, 0.040616726236683984, 0.03903443346332226, 0.0036424709750073297, 0.04033505277974265, 0.031480238639882634, 0.011180603178218007, 0.045855583157390356, 0.050976198565747054, 0.051045548237328014, 0.02474722725206188, 0.1001484100041645, 0.019665057637861798, 0.034820520651659796, 0.04462221683934331, 0.08366448059678078, 0.036983622437609096, 0.08401805840964828, 0.021456736139953136, 0.028863977241728987, 0.08109429172639336, 0.01995525010196226, 0.011439221711563212, 0.028361554290833216, 0.02719150546805135, 0.04556726684261646, 0.008775891187334699, 0.02605157851108483, 0.05145949870347977, 0.01417837682778814, 0.03983693004452756, 0.025395932174952965, 0.07109385941709791, 0.04371606385601418, 0.04090028602097716, 0.006802238499013973, 0.05640199527676616, 0.032279596996626685, 0.0940470706139292, 0.07992276030459575, 0.04851880257150956, 0.036876312124409845, 0.07582291601491825, 0.04089295105742557, 0.04010430337595088, 0.046915420929768255, 0.0678121858675565, 0.07156007404306106, 0.027740779565647244, 0.046448215642677884, 0.04313404026574322, 0.06702505810452358, 0.03579728538170457, 0.04884880807782922, 0.04234634592596974, 0.029386109938578944, 0.026910500368103385, 0.053596666881016324, 0.025982003226610165, 0.04011711072442787, 0.02869954445798482, 0.025418003222772052, 0.05448574453060116, 0.018246162882340804, 0.04634791798889637, 0.02248668614109712, 0.04515532484011991, 0.057128285590027056, 0.06335921838347401, 0.06623852745230709, 0.0369483759360654, 0.018417830545721308, 0.034443071976836236, 0.01674115185492805, 0.036724964888500314, 0.017898003171597208, 0.008857220394669898, 0.03617927345580288, 0.0096643725742719, 0.08014877353395734, 0.019340636474745612, 0.008357185038870998, 0.06758854751076017, 0.05185608206582921, 0.023239737875493507, 0.030936060340276787, 0.008403573085420897, 0.03467150418353932, 0.04353654384613037, 0.029348373213516812, 0.07133250696850674, 0.026283242240814225, 0.03848874542329993, 0.04059166115309511, 0.03652811170156513, 0.012500648952222295, 0.03442947074238743, 0.0342148670793644, 0.06287861202976533, 0.02155455544457904, 0.05586900941229292, 0.044032960065773556, 0.020148503660623516, 0.025723842704402547, 0.05344273442668574, 0.00895179545373789, 0.07207670382090978, 0.042394355671214204, 0.05304304676662598, 0.07522699942014047, 0.019265198647709827, 0.011100018663065774, 0.08745715208351612, 0.04105173164446439, 0.041942346175866466, 0.031914891209453344, 0.03329675830900669, 0.06759734810995204, 0.019426462672916905, 0.08050830888428859, 0.016800764548991407, 0.028894511317568164, 0.04449455047558461, 0.044620299977915626, 0.05037929470251713, 0.022526862199551294, 0.12132195276873452, 0.03449580093313541, 0.01565431008514549, 0.03905167164547103, 0.042546059138008525, 0.0703888072499207, 0.112971934755998, 0.04992897475936583, 0.03653159597888589, 0.03500681244102972, 0.025878881170813526, 0.016708032560667822, 0.024993084238043854, 0.060351136938801835, 0.03026493153135691, 0.027976587448003035, 0.007913437555544078, 0.038680038015757284, 0.02921275781201465, 0.0412083612754941, 0.010137824624377702, 0.05734806986791747, 0.018575019968141402, 0.005705809453502297, 0.06296988856047392, 0.006622220614060227, 0.035263081546872854, 0.025274406553113034, 0.0774110204407147, 0.07764882660870041, 0.06822956632822752, 0.037266513864908896, 0.05046333126457674, 0.042165448489998064, 0.012375841765398425, 0.06238005163946322, 0.007006870665853577, 0.03653249164511051, 0.04890780330502561, 0.058465169210519106, 0.040770933497697115, 0.02170899510383606, 0.06475165366594281, 0.07644969916769437, 0.05207569331728986, 0.027893008897081017, 0.050331349418099434, 0.03336074755394033, 0.013890041005132454, 0.03300310192363603, 0.035127656135175905, 0.0787621872233493, 0.05664389979626451, 0.016020956482472162, 0.013452175572248442, 0.044631597585976124, 0.062107063430760584, 0.043097782747021744, 0.027051876531913877, 0.028480537102690766, 0.03427310574001499, 0.04357841284945607, 0.07260708071823631, 0.016427985891433697, 0.055608930332320075, 0.042054552119225264, 0.016769624880648086, 0.03775326096053634, 0.018292459326663187, 0.017188031625534807, 0.041481990699789355, 0.01729043952322432, 0.024790768844208548, 0.048214642464050224, 0.06420634221285582, 0.05494831203083907, 0.02305556650805686, 0.039990038078810485, 0.008911206337091113, 0.048446915178958855, 0.022861198455627476, 0.014386964429702078, 0.09206875426960842, 0.0602880467527679, 0.036186883226037025, 0.0828987199014851, 0.03449715461049761, 0.04766388237476349, 0.04818948238555874, 0.07529032709343092, 0.046588509543133635, 0.01848837443893509, 0.023783269870494093, 0.03224411640050156, 0.042579449846276214, 0.009224647107268018, 0.04811260097527078, 0.022108482596065317, 0.017057608713262847, 0.043312528902398686, 0.015800849900447896, 0.02241674275137484, 0.03531829733401537, 0.03205780086240598, 0.03854278055950999, 0.04064017640692847, 0.03884338514347162, 0.019287742973704423, 0.04926748114771076, 0.016036729028980647, 0.04562413825520447, 0.029194637534341643, 0.01698836760728487, 0.04119633763496365, 0.05576744629070163, 0.03360907780006528, 0.04277315123804978, 0.03820002538018993, 0.03538338919835431, 0.16915412539882319, 0.08133066618548972, 0.09725377961461033, 0.16661538662655012, 0.11344776422317539, 0.1854013478649514, 0.18953382968902588, 0.18967953829893044, 0.08615538943558931, 0.17767736661647046, 0.1444875318557024, 0.09485593185360942, 0.049288380026285133, 0.10878628292786223, 0.09388634602406196, 0.1492896056068795, 0.08717576361128263, 0.07698741781392268, 0.1746048243450267, 0.15225705637463502, 0.1499816570430994, 0.13970577344298363, 0.061722870117851665, 0.15503759788615362, 0.09442692808806896, 0.14793975518218108, 0.16127839657877172, 0.1009840869477817, 0.12511784051145824, 0.20634999019759043, 0.1482548261327403, 0.27175322068589075, 0.0656656064093113, 0.10858825926801988, 0.06766128646475927, 0.16456672655684607, 0.07441217385764633, 0.15149652718433312, 0.13408653996884823, 0.1409040798566171, 0.1511342166257756, 0.07507902450327363, 0.11620957138282911, 0.14412550628185272, 0.15306280313857965, 0.14569716980414732, 0.155762449705175, 0.10788842503513608, 0.11557529041809694, 0.27306075766682625, 0.18140827784580843, 0.07522532343864441, 0.10195458201425416, 0.13320979130055222, 0.08241419161536864, 0.1686074568756989, 0.13337259899292672, 0.19870515327368463, 0.10685338093233959, 0.1448156171079193, 0.2561258263885975, 0.06620087554412228, 0.19477513272847446, 0.14885644242167473, 0.09836997650563717, 0.16675312923533575, 0.12123283397938524, 0.15021668800285884, 0.20180810748466424, 0.06621024611272983, 0.18586594079221996, 0.13329573454601423, 0.12565230897494725, 0.07386156983141388, 0.10681492156748261, 0.1889034706567015, 0.07049471978098154, 0.09908410747136388, 0.09136735940618174, 0.07578743541879313, 0.10762385744601488, 0.1428422201424837, 0.12156177418572561, 0.14234565464513643, 0.13158309858824524, 0.15870621960077966, 0.1375087449061019, 0.11783521915120737, 0.151276898969497, 0.1420378575899771, 0.144088512552636, 0.10733191775424139, 0.18751612438687257, 0.12209731473454408, 0.1504628469369241, 0.08837970186557088, 0.15074598602950573, 0.11597397045365401, 0.10195741829063211, 0.14036472594099386, 0.13484240083822183, 0.10555372852832079, 0.1372550135212285, 0.1616918822484357, 0.14441040956548282, 0.12641688223396028, 0.13637498074344226, 0.11720294665013041, 0.14088839212698595, 0.16269147289650782, 0.12587987604950154, 0.0881865161604115, 0.14527588098176888, 0.15523974703890936, 0.17390807744647774, 0.14536485049341405, 0.11934785012687955, 0.19922962013099874, 0.12902921491435596, 0.19092779846063682, 0.08962938016546623, 0.12532733141311578, 0.30746403017214363, 0.1347388292529753, 0.1310492136648723, 0.13650440451289925, 0.10091624023126704, 0.17051010978009018, 0.054423414303788116, 0.13267798269433634, 0.1914678444819791, 0.17878210305103234, 0.1685922034084797, 0.15530678629875183, 0.05775035970977374, 0.11058239226362535, 0.20057112457496779, 0.10065297542938165, 0.2083614801189729, 0.20254142742071832, 0.13975711140249455, 0.15854240767657757, 0.2220212857105902, 0.18272420151957444, 0.09008831411067929, 0.1650466543755361, 0.1384835283138922, 0.12877164302127703, 0.10905068088322878, 0.12883632097925457, 0.16510101860123022, 0.1605258605309895, 0.10006784754140036, 0.10514681786298752, 0.1296351873981101, 0.09062720662248985, 0.14671605798814977, 0.09299444566879954, 0.16574967093765736, 0.11156658016677413, 0.1318481343665293, 0.1383516075355666, 0.16208263699497494, 0.10774992246712957, 0.137410506606102, 0.12221384633864675, 0.11772429224635873, 0.21436313592961856, 0.10435066558420658, 0.09648902993649244, 0.10522945664290871, 0.19950650313070842, 0.0921484889196498, 0.16358143942696707, 0.12911059840449265, 0.09952561663729803], [0.034683293729488335, 0.028968498776001588, 0.046968400944024324, 0.039417571654277186, 0.05454961163923144, 0.07069526080574308, 0.062356160421456606, 0.045722610649785826, 0.03239543649501034, 0.0023004400302722517, 0.09850649096603904, 0.056965511824403486, 0.013701892574317753, 0.033815657786492787, 0.11249107734433242, 0.023625505389645696, 0.030800495828901018, 0.04941868928394147, 0.05713475202875478, 0.07945231162011623, 0.06173456806157317, 0.10104675644210406, 0.029960428763713156, 0.06528819166123867, 0.009086860393706177, 0.044321578328630755, 0.09118657732116324, 0.02462766259642584, 0.03912736901215144, 0.00843656515436513, 0.06626218796840735, 0.04575924136276756, 0.004089184928618903, 0.02629993759494807, 0.03989978274330497, 0.022227899670334797, 0.03329800342076591, 0.035309642619852505, 0.024328367585050206, 0.0612687673419714, 0.030903555120208433, 0.03780007648414799, 0.018674752741519893, 0.018955683202615807, 0.009278303960205188, 0.021037060534581542, 0.054393663935895474, 0.023176898747416477, 0.007432740447776658, 0.08157845360359975, 0.023110619446794902, 0.016397378873080015, 0.11374618392437696, 0.013983570272102952, 0.10257745001997266, 0.0523285968894405, 0.010882780587832843, 0.09984761543039765, 0.0113457119524745, 0.03259087832910674, 0.07381995527872018, 0.014304663220952665, 0.029502553333129202, 0.06301795598119497, 0.08485828153789043, 0.04134994439248528, 0.02295975905976125, 0.008196595307838703, 0.0360892997123301, 0.04900680495692151, 0.012737004751605647, 0.05197538209280797, 0.02240378612519375, 0.05614497638972742, 0.07082545810512134, 0.013560855678016586, 0.022525031851338487, 0.03773647739685007, 0.01709344723661031, 0.06116064278674977, 0.04476321302354336, 0.028394142631441355, 0.06847921971763883, 0.05357017348121319, 0.04359312688133546, 0.04074328998103738, 0.04516336548009089, 0.014203553021486317, 0.03504399616005165, 0.036077873182616065, 0.028501758285398995, 0.018211723837469305, 0.03906608033659203, 0.04508490986855967, 0.0843306662780898, 0.027871446750525917, 0.047545043751597404, 0.015785024767475467, 0.006604319163930735, 0.008867249990414296, 0.0423397369948881, 0.023659893544390798, 0.03171597866873656, 0.05704984015652111, 0.03790345468691417, 0.076295156031847, 0.03069687674620322, 0.007084673611513738, 0.08347092848271132, 0.02183521618800504, 0.009767545520194938, 0.02668991032987833, 0.0200420567832355, 0.030933403875678778, 0.03641937307215162, 0.01227561875046896, 0.04540537517251713, 0.03714031992214067, 0.10843755664037806, 0.021690628857218792, 0.005848856933880597, 0.029704193584620953, 0.01273774605111352, 0.023833330487832427, 0.04149899139468159, 0.026365075260400772, 0.015029152023739048, 0.057401884480246475, 0.020458653535959975, 0.03858007284413491, 0.012123593827709556, 0.025834075807194625, 0.017115996651617543, 0.04700034637270229, 0.02202074632181653, 0.05377726576157978, 0.016104440038491572, 0.058353163434990814, 0.041165946051478386, 0.033380822012467046, 0.028718540045831884, 0.05458531954458781, 0.0557789033544915, 0.02654769447898226, 0.025373601587489247, 0.02644235870268728, 0.0102570949654494, 0.031288728916219304, 0.05912808435303824, 0.07359113969973155, 0.07204293991838183, 0.0073178627727819336, 0.018788461639944996, 0.047602549594427855, 0.05668510044259684, 0.014057386400444167, 0.05716483827148165, 0.03936609120241233, 0.05683361140212842, 0.024501936842820475, 0.028573136776685715, 0.031622510469917736, 0.014338372840679117, 0.01358263156310256, 0.022554342867806554, 0.05066538542242987, 0.059325660179768286, 0.005656530847772956, 0.02112698508426547, 0.03809153441605823, 0.06692412602049963, 0.05803189067436116, 0.006573106553072908, 0.02018271539626377, 0.009041715762577951, 0.01831231665398393, 0.029133050303374017, 0.01641328034124204, 0.024065391160547733, 0.036792428232729435, 0.0511568076243358, 0.04993373807519674, 0.04159534676000476, 0.04900407385347145, 0.030598275429968323, 0.02176146791316569, 0.0172778238608901, 0.07275690803570406, 0.03501424239948392, 0.01935689926280507, 0.032228320105267425, 0.08095893756087337, 0.02501312137714454, 0.025092138476403694, 0.017873767597068633, 0.07857455193464245, 0.009579222366612936, 0.034259741992822716, 0.03536413237452507, 0.10296084266155958, 0.043781247322580645, 0.03457675016086016, 0.051728809252381325, 0.005140218285045454, 0.02850515435316733, 0.06149847858718463, 0.04383642239762204, 0.028195903536730578, 0.0338615878219051, 0.01588003832979926, 0.026118588933189, 0.028707462961652448, 0.02581278677098453, 0.03115577337199024, 0.05868715872722013, 0.029304346468831812, 0.08342311211994716, 0.018142738878460865, 0.024412611100290502, 0.018474201538733075, 0.01899351492258055, 0.0321861593318837, 0.03126068506389856, 0.01159498790678169, 0.02449712942221335, 0.025011998401688676, 0.06203156962458577, 0.042526079674384425, 0.024688832528356994, 0.05101917697382825, 0.03548779198899865, 0.006672366472360278, 0.027171176558892642, 0.09819085004606418, 0.0527424218266138, 0.060239748630140505, 0.046771015107099495, 0.023581707650529485, 0.03895256482064724, 0.06933638586529664, 0.06553206393229109, 0.023896824402202452, 0.017274044420836226, 0.008855110150761902, 0.02494010592012533, 0.010936723273646618, 0.12961237505078316, 0.050302552391908, 0.04222156672871538, 0.04709959908255509, 0.02330544720669942, 0.02470982979450907, 0.05042386766789215, 0.04037146296884332, 0.021171001650925194, 0.03401961523507323, 0.03338754968717694, 0.016547845709802847, 0.018704898356060897, 0.028410985566941754, 0.029744128763143505, 0.01003731832107795, 0.027227286315922226, 0.06572180946490594, 0.055254436497177394, 0.04688370281032153, 0.0381643955063607, 0.06743314263543912, 0.012121748212458832, 0.04011829476803541, 0.05635666574484535, 0.013091099099256098, 0.03319284745625087, 0.03513887571170926, 0.06882038712501526, 0.054847359590764554, 0.09264240813042436, 0.02878476506365197, 0.0302379801204162, 0.1530964041927031, 0.06366027758589812, 0.016006875184497664, 0.011042157437519302, 0.023063681786879897, 0.023984094183625917, 0.022974834411538074, 0.028254367810274874, 0.06111269071698189, 0.05384596064686775, 0.058644126036337445, 0.01621686650573143, 0.03260511738647308, 0.025154098901631575, 0.0482451799325645, 0.04931163681404931, 0.036913784220814705, 0.04928114005763616, 0.0679100849000471, 0.06061455101839133, 0.030871579157454625, 0.021578901281048144, 0.042705335055610964, 0.04145733952256186, 0.02106356411240995, 0.024817331793851087, 0.08032321810190167, 0.05715742866907801, 0.04131669617657151, 0.021338628638269644, 0.047231764133487425, 0.011513477191329002, 0.03668452759406396, 0.049209347659988065, 0.06471955895956073, 0.022617505996354988, 0.01506120092900736, 0.007486343017912337, 0.07017450553498097, 0.017076219232486825, 0.0539294238468366, 0.009591521661994713, 0.0318975919591529, 0.01552945964171418, 0.052531383865113766, 0.05783525122595685, 0.02637495642660984, 0.05582275028739657, 0.003871336595953575, 0.038204228904630454, 0.047376224238957675, 0.07522877039653914, 0.03640202971707497, 0.07643370609730482, 0.028044337473277534, 0.009607112700385707, 0.04391980078071356, 0.06044838457767453, 0.0565383774228394, 0.04493392564888511, 0.017589139120121087, 0.02774134274971272, 0.05664856472451772, 0.017453228555885807, 0.01240632071026734, 0.011478532637868608, 0.04965388309210539, 0.013288111741920667, 0.026221804287550703, 0.023791458091831634, 0.057511827509318075, 0.01633658043907157, 0.04405458497681788, 0.07325776865971939, 0.11258358880877495, 0.16818174400499888, 0.07110334533665862, 0.1665373415287052, 0.13409738295844623, 0.15108038165739604, 0.12820043867187841, 0.06043482744800193, 0.10664471784340483, 0.10840339240218912, 0.22045799531042576, 0.21785430716616766, 0.18730533069797925, 0.15192743763327599, 0.16857692279985972, 0.10588370010788951, 0.10846812464296818, 0.11860159731337003, 0.16501514320927008, 0.2180754824408463, 0.14661525482577936, 0.10031051202011959, 0.13060777235244, 0.12973216362297535, 0.17838547219123158, 0.19678356924227305, 0.08421982758279357, 0.1753265956150634, 0.178347609937191, 0.14710759983531066, 0.18338240762906416, 0.1768102395747389, 0.08740856219083071, 0.1999628179307495, 0.12005641710545335, 0.10699410909520728, 0.10770948856536831, 0.14905416752610887, 0.1313292043549674, 0.1722679225994008, 0.07814703416079283, 0.10601389062191759, 0.1411666457674333, 0.11076227868241922, 0.09986609872430563, 0.13180409744381905, 0.1370679142751864, 0.07157566677778959, 0.15766004073832715, 0.14504424269710267, 0.12044874605323587, 0.19863666194890225, 0.07660444586404733, 0.17025898396968842, 0.12330030303980623, 0.09051772499723093, 0.1904880806271519, 0.08632317757500069, 0.10509730516267674, 0.13453468520726475, 0.06676497563187565, 0.09649915367897068, 0.20220681466162205, 0.18736111984721251, 0.13122659628944738, 0.1643853812877621, 0.10931021374251161, 0.09354283767087118, 0.108691416946905, 0.22903496293084963, 0.10513983573764563, 0.06475823545562369, 0.11721104835825306, 0.06772752505327974, 0.07431626971811056, 0.10014975350350142, 0.11936641484498978, 0.07793687829481703, 0.17358114570379257, 0.15161292308143207, 0.1161266001207488, 0.1830422580242157, 0.13017881608435086, 0.09879186922418219, 0.07800513891769306, 0.1218693812510797, 0.10918213347239153, 0.17840786384684698, 0.12723330913909844, 0.15624669300658361, 0.10160666318344218, 0.1371024924197367, 0.06436164530792407, 0.2133156678506306, 0.10372601981673922, 0.16914963349699974, 0.10400658047624997, 0.11434632779232093, 0.11293266114911862, 0.10905098622398716, 0.1156527791172266, 0.06709114062998976, 0.2788590836737837, 0.12289615401199885, 0.12299346950437341, 0.09558967926672526, 0.11200270176466022, 0.13283232226967812, 0.17051418099020207, 0.11391494236886501, 0.15595853275486402, 0.09757249429821968, 0.11668873924229826, 0.21951088256069592, 0.11224015509443623, 0.17200002340333803, 0.1834930224078042, 0.19708154111036233, 0.11703036805348736, 0.12247414594250065, 0.23723983551774705, 0.09424152517957346, 0.08678230829536915, 0.18822713409151348, 0.07115910734449114, 0.13448484002479485, 0.15114826230066164, 0.08631665685347148, 0.2041159136486905, 0.12860689471874917, 0.07543461756514651, 0.1368344168045691, 0.14153705803411348, 0.07794428789722067, 0.16392595879733562, 0.1185891122690269, 0.15966443318341458, 0.09138190041163138, 0.07881250059498207, 0.07845683289425713, 0.22061496760163987, 0.15308652472283157, 0.11589956230350903, 0.09897095497165408, 0.057699618861079216, 0.12647795038563864, 0.11166939179279975, 0.12383540932621274, 0.13108964078128338, 0.21520982549658843, 0.054223938579005856, 0.1351662248905216, 0.0643625816862498, 0.18062032227005276, 0.1438495460897684, 0.13385735798094953, 0.16300015204719134, 0.11036397862647261, 0.11069042860929455, 0.1727944929152727, 0.1614745474819626, 0.1423912386276892, 0.1313471176794597, 0.03622515260108879, 0.10601265568818365, 0.10040927279208388, 0.09886045554386717, 0.13422673887440137, 0.16715627403131553, 0.12868628331593104, 0.06561272138995783, 0.12018806646977152, 0.12919221259653568, 0.15223550610244274, 0.16487537856612886], [0.04067129741555878, 0.09053981131208794, 0.013730044992241477, 0.05356532874118004, 0.059461496105151515, 0.03644250772361245, 0.035088820183383565, 0.020320692099630833, 0.09001941566488572, 0.06455873258944068, 0.009428070209521269, 0.040247304631131034, 0.003882858120570225, 0.05251139083078929, 0.02584153799606221, 0.0773264749773911, 0.031539742768343, 0.07640486157366208, 0.0085096264124981, 0.056516718585044146, 0.03550074522250465, 0.012797926170086222, 0.02979015718613352, 0.0654486787638494, 0.10003725918275969, 0.014504926046356559, 0.02556482802278229, 0.037249061944229264, 0.0076947940646537715, 0.046819676245961867, 0.04123010493016668, 0.018655297446197698, 0.06801242155155965, 0.014967449441818255, 0.027032779163814018, 0.01945655230831887, 0.04013673734984227, 0.031219182469482933, 0.05838281541530575, 0.019884446669103842, 0.013066216371953487, 0.05860638591860022, 0.02300999439986689, 0.025640357452045594, 0.06628599776221172, 0.0515749480442277, 0.01705993269570172, 0.016239068171541606, 0.015505132464958089, 0.028597967765693153, 0.04017098979758365, 0.0049127801321446896, 0.025705430656671524, 0.0859822408695306, 0.014361875597387552, 0.027630782253774147, 0.09280143638274499, 0.027951361212347235, 0.044872199318238666, 0.01745008354607437, 0.03182092768007091, 0.029392535665205548, 0.01183609090678926, 0.08560122310050897, 0.044970111921429634, 0.04117281961121729, 0.01508463074320129, 0.07968733579452549, 0.02521994902885386, 0.04022387142426201, 0.04538888677156397, 0.05319623961778624, 0.03617370268329978, 0.015524677666170257, 0.03550729987078479, 0.0293429076139416, 0.009303396185194808, 0.04717489272089941, 0.013787058897183409, 0.06579471805265971, 0.039809344203344414, 0.05520399420389107, 0.07451898205493178, 0.05156697865043368, 0.012631383990602834, 0.043263382610997984, 0.045772781529064686, 0.009359466078292047, 0.03842320233317358, 0.02379455730052931, 0.03801442230386393, 0.06231833887951715, 0.014704481499003512, 0.05973787020359721, 0.02821959289056914, 0.042232796483274014, 0.05630069339115705, 0.04774426163307258, 0.03226934093981981, 0.050481275123144896, 0.009455073358757156, 0.03334666116695319, 0.0800561670746122, 0.03163787250273994, 0.051297298299946954, 0.05695055691259248, 0.014093938233729984, 0.06158349223967109, 0.07143062991755349, 0.030019556305238178, 0.024783910551507558, 0.03057332230465753, 0.035322446575654406, 0.0489847186420645, 0.019533284440902726, 0.027821976458653808, 0.0745744387220059, 0.054804520282362185, 0.01583500735328666, 0.06601275171020202, 0.030823654229087488, 0.017235746208046163, 0.06281739460038287, 0.012048059309433614, 0.0806436494791082, 0.04758724184440715, 0.025809122681883827, 0.03018773120961019, 0.021029016501935463, 0.033860590375427685, 0.019600393250584602, 0.019450705032795668, 0.03915595229981201, 0.022658411479954208, 0.028098204672070484, 0.03716799058020115, 0.0785756308053221, 0.02978884082819734, 0.011857938038052192, 0.030425014905631542, 0.024648946543623294, 0.015354399303240436, 0.015353836119174957, 0.02010135735119028, 0.019524816323869994, 0.07528148578213793, 0.02172983800327139, 0.03144529747909733, 0.03355691881318178, 0.04293719047148313, 0.04543589907033103, 0.013528901767650885, 0.03530703365270581, 0.050638325445886166, 0.058824785985052586, 0.034231080673635006, 0.026574386350278343, 0.047226132292832644, 0.007251820959416884, 0.02880704476098929, 0.03115223141919289, 0.12570142133959702, 0.016491123574918935, 0.05301036173477769, 0.027069538798449293, 0.057892227811472755, 0.049087387775736194, 0.026479094588596905, 0.03687886002340487, 0.016728246118873358, 0.03447433887049556, 0.03098269605210849, 0.06714473132576261, 0.02057974998440061, 0.07288125636322157, 0.04062015623120325, 0.005293839885520616, 0.03145748736070735, 0.015491502392770988, 0.03552985776747976, 0.07652220063443695, 0.0353757149672934, 0.015494091003867132, 0.030050643387117555, 0.06601585261523724, 0.07479778530874423, 0.020799764964197363, 0.10373273731342383, 0.03393771945099745, 0.03408527706882783, 0.03305212268605828, 0.011544176660078977, 0.07640413554119212, 0.004834180331922003, 0.06529524164008242, 0.03552152196477566, 0.02932055327775223, 0.03622512545968805, 0.07946063724479505, 0.0546856307690697, 0.06237990236175912, 0.030464794021099806, 0.0463763689622283, 0.03199721447059086, 0.026908999109374623, 0.04219608095341495, 0.007999856623687913, 0.015635122811155658, 0.02782796792286847, 0.014118333263987941, 0.017007310608667985, 0.02710341296291777, 0.03598915133625269, 0.05646230007654854, 0.04396307095885277, 0.007813680185271161, 0.019194926168503504, 0.012967620992900004, 0.028653461752193313, 0.039028957685721774, 0.10020101003881011, 0.07651562563010625, 0.006091301312803158, 0.042896342663360496, 0.08191386703401804, 0.02750550433328109, 0.040840147462274344, 0.01753395556339196, 0.041588137325431616, 0.06414177282048122, 0.008987492332900209, 0.03656706978966083, 0.06991307956299611, 0.03577248153409787, 0.07392881265176193, 0.030550381035677025, 0.054835933061050515, 0.012417625103678023, 0.016320205692734038, 0.07535522896796465, 0.044889108410903385, 0.02164842058638377, 0.05514743152473654, 0.06896445368017469, 0.047825265143598826, 0.03400871796267373, 0.06179560228650059, 0.04664492972993425, 0.05076250074697392, 0.032843914215586016, 0.05776691596422877, 0.05634126978527222, 0.031425253554646454, 0.027156074065715075, 0.021109948766284754, 0.036507660656103065, 0.062379244182791026, 0.027834239282778332, 0.07368560534502779, 0.06970696098038129, 0.03232657536864281, 0.012990381601931793, 0.01900293298863939, 0.02880867663770914, 0.048041524432067356, 0.05690585502556392, 0.015208203844459993, 0.04221144637891224, 0.053297646676323245, 0.04281731368973851, 0.05976856712784086, 0.036477075690137487, 0.025778902428490773, 0.023761504163433398, 0.027643750754318068, 0.011599394991727812, 0.052393491978624036, 0.03039865042748196, 0.0635658594380532, 0.008455749883848642, 0.02136314580483096, 0.06572459824383259, 0.04836078533636672, 0.043631114664354494, 0.021322893411187187, 0.03022519652066486, 0.06975910639656441, 0.031028636265546083, 0.08449913295251982, 0.05188742359834058, 0.007980946700886955, 0.016983322699421217, 0.012148742880006986, 0.022432786711890782, 0.03784216261867966, 0.04156449716538191, 0.058181317656167915, 0.012201118998096457, 0.03051574182297502, 0.0024122799888053642, 0.028523064284984554, 0.07433060037770442, 0.018246013604636704, 0.011905811228124159, 0.07091505186898367, 0.02109198964067868, 0.032945796248636076, 0.060888658809874735, 0.045284351666591, 0.005421398107760719, 0.06699276662298612, 0.02397096962002771, 0.038092100992798805, 0.06243171529578311, 0.05772084343646254, 0.022023770891662155, 0.020859991732452596, 0.02765323837021632, 0.05779427449618067, 0.03217763353937438, 0.006567157497296908, 0.030657006028507437, 0.05085846256198628, 0.04520107845642737, 0.03655838454142213, 0.07282723819038697, 0.03738279780372977, 0.01625729871115514, 0.0029982999382939723, 0.05451121334252613, 0.020756381131442528, 0.03187999415344425, 0.022380373274375285, 0.026969705941155553, 0.01908941736577877, 0.044164361764809916, 0.07532204860555274, 0.037671796046197414, 0.024172781201611673, 0.05679320464176791, 0.022223594365641475, 0.019871016764747243, 0.07444581562387091, 0.03105432560135211, 0.05333288639251675, 0.0450319298543036, 0.03330643761104771, 0.018268040547679578, 0.036228301003575325, 0.023649377947939292, 0.05603940312617591, 0.04013768390619329, 0.08369272122425692, 0.18126031649964197, 0.10564286088837044, 0.12317011931112834, 0.1709946244955063, 0.1272034128861768, 0.09006296404238258, 0.12441755166011197, 0.24883114067571505, 0.10330752655863762, 0.09639071021229029, 0.12363738566637039, 0.12117842904159001, 0.09408876659082514, 0.17702734363930567, 0.14923841692507267, 0.13780692033469677, 0.16692578925618104, 0.1234008212174688, 0.1043631574138999, 0.19921679581914628, 0.13142048088567598, 0.12367246592683451, 0.15979202490832123, 0.2220591479646308, 0.09776868591351168, 0.10119588486850262, 0.18498278675334795, 0.07007654543433871, 0.19150044130427496, 0.09209434861051184, 0.09143293981573411, 0.18595809941845282, 0.06889907683112792, 0.11025191178279263, 0.10130233344222818, 0.12903450748750142, 0.2034805334572281, 0.13864435468401226, 0.08942530397325754, 0.07182704364614827, 0.13647458968417986, 0.12653128323810442, 0.2857709942119462, 0.1770745153938021, 0.159939633416278, 0.060405976139009, 0.15181364731064864, 0.22307046369782516, 0.1559484497244869, 0.09617072915924446, 0.08518046353544508, 0.10861659489039864, 0.1446868854441813, 0.08555570697145802, 0.16195713515792573, 0.17760531976819038, 0.12959641590714455, 0.17995808566255228, 0.09493223311645643, 0.16693896640624317, 0.10282224509865046, 0.05975514570517199, 0.17801121941634587, 0.16381534401859554, 0.12083605384188038, 0.16315853569124425, 0.2304324193724564, 0.08787355545376029, 0.11115664323525769, 0.12456263601779938, 0.22509074743304933, 0.13474437966942787, 0.11266736074217729, 0.16758480960769312, 0.11607394580330167, 0.15328966453671455, 0.15301134304276534, 0.07699239147560936, 0.14962759747036866, 0.10309826635888644, 0.1333992111363581, 0.12476958919848714, 0.13502267402197632, 0.07345648442528077, 0.09981094739798989, 0.11042672954499722, 0.11595216233815465, 0.1681522684437888, 0.1535846372800214, 0.10981509807918753, 0.24640776642731257, 0.11009889535073723, 0.10332436779780046, 0.15117562083261354, 0.13141398052019732, 0.13827903142997197, 0.16982070463044302, 0.12124340555497579, 0.10937305965593883, 0.14195010944136552, 0.11830066703259945, 0.18817229489130632, 0.12004401348531246, 0.12896913742380484, 0.19512296334973403, 0.1629511211067438, 0.220357870683074, 0.11526126441146646, 0.18159297507788452, 0.11628471235079424, 0.09974884108773299, 0.14911356648164137, 0.14921529245163712, 0.09527391621044703, 0.10174875520169735, 0.16971473103123053, 0.08044133069259779, 0.08051049376704864, 0.18563096411526203, 0.13501428732914583, 0.13719385037464754, 0.09037369236882244, 0.09718032141349145, 0.11680523013429982, 0.19872359585549149, 0.10943163758409874, 0.20223282969423703, 0.16930033612464154, 0.0987288604623505, 0.1253005564212799, 0.11842960225684301, 0.10986246660883937, 0.1191266341400998, 0.17650081403553486, 0.10084905169372048, 0.08327791241130658, 0.1716973153608186, 0.09898822368787867, 0.11695918973003115, 0.08718667445438248, 0.05801327167344945, 0.17087555517043385, 0.13908656952636583, 0.11761880719235965, 0.11261331542794194, 0.08569218750510897, 0.2899015082844666, 0.09358802810311317, 0.17711270334465162, 0.10600545643163578, 0.08938873093575239, 0.10029586244906698, 0.08704769012651273, 0.14704669453203678, 0.09827654223356928, 0.09247286937066487, 0.0749077961913177, 0.17515271423118456, 0.09009788823979241, 0.14416187575885228, 0.14012903001691612, 0.17731834016740322, 0.11577372119895049, 0.09387339279055595, 0.08352937748921768, 0.15908516783799442, 0.2631842733493873, 0.16673627442547254, 0.08383599389344454, 0.13114718055086477, 0.0900846364508782, 0.1642434046204601, 0.14451319405010768, 0.16833212093583175, 0.13925564688231262], [0.018811448710039258, 0.05338110987629209, 0.048008116760424206, 0.07057716857109751, 0.012676540496093886, 0.08518707246652671, 0.04427493583144886, 0.01756078653436686, 0.03622732052047338, 0.012029616727626749, 0.02694680368793862, 0.05793262778648308, 0.07962984352239541, 0.05661193401153598, 0.018655258430434123, 0.057078148637499125, 0.006502826440347624, 0.037065131456724236, 0.016480468878788606, 0.07328798382409982, 0.03551176802388259, 0.030254909569131475, 0.05646599469972508, 0.040164167127971134, 0.027402102381789258, 0.07559355082256453, 0.03822540598256247, 0.004909130037828747, 0.03955425574843373, 0.050127198587038686, 0.019540027382650545, 0.03704219697309392, 0.04121823735269053, 0.039807620724397044, 0.04901304069374289, 0.015027001067729933, 0.024377413792535663, 0.012838296459189482, 0.05043291932504092, 0.012117262247816792, 0.024890035124761716, 0.052381312275039296, 0.026704598916694522, 0.04803393501788378, 0.039385524445346425, 0.016680036205798388, 0.06869597772934607, 0.03313587765608515, 0.05443871866113373, 0.01835066406056285, 0.023163031187972853, 0.026772603392601013, 0.042126297019422054, 0.022147019992449453, 0.01886592150133635, 0.07550228107720613, 0.04372597046728645, 0.05078543862327933, 0.0500775400016989, 0.038094119634479284, 0.01284101144743285, 0.011165800936786192, 0.07591154625905411, 0.03751413504193936, 0.04488855540486319, 0.03571676363104156, 0.016229719655322175, 0.058154583376433165, 0.03495186467521957, 0.03674782473327858, 0.058535994695765634, 0.03729133467589106, 0.06539466737636498, 0.03095894054110561, 0.04984642079632197, 0.0498044364420431, 0.005512960895430297, 0.04177491766001497, 0.025846988328599503, 0.06107518808650119, 0.02150264412297734, 0.04234034428372979, 0.04977825516834855, 0.0519892750973148, 0.054834402964583466, 0.09758953231253795, 0.06582772878131696, 0.04226687929726072, 0.06585077861590044, 0.05927086847701243, 0.0671223464554974, 0.061889464035630226, 0.08017387254429714, 0.026340098386364322, 0.04958326116736446, 0.011190966952459087, 0.01927932574679809, 0.0217652524422322, 0.012906395081829811, 0.034086430578359535, 0.052988916635513306, 0.025034615670197775, 0.01648216012732259, 0.018261080474725792, 0.023512754921934435, 0.025966305318953734, 0.022361398042578782, 0.02744283483895872, 0.01456759384434138, 0.022843889027301754, 0.031151702161878347, 0.06108067064945187, 0.02924148359202913, 0.05274188578394907, 0.06708470133266278, 0.06559688438262258, 0.03416338662749954, 0.023429619115112082, 0.039318027174366374, 0.03926758148840495, 0.02009027178532311, 0.05694528469549758, 0.02533353409463806, 0.008258950131546174, 0.027268783821325217, 0.0337471766397357, 0.03471278625407389, 0.02394194358826748, 0.025375935747953396, 0.01567686628550291, 0.027218419559566037, 0.018861794312085425, 0.03910513002691524, 0.007117900199123791, 0.02046356612949499, 0.06788647188139812, 0.02649652784956353, 0.01906110379578812, 0.03720218874514103, 0.024774092149787715, 0.05263469421437808, 0.05723339744976588, 0.03945635671594313, 0.06214580099497523, 0.06774719578347035, 0.015107212388621909, 0.0742350694324289, 0.025043903118265525, 0.03250372389863644, 0.019506171877895082, 0.05937551214758839, 0.04715397348627448, 0.06052652467042208, 0.0159569044730493, 0.03387340111657977, 0.01960527361370623, 0.031039394438266754, 0.057464255419160636, 0.004821327606415642, 0.014023178057479007, 0.05782318687332528, 0.058774255482213836, 0.03399757641766753, 0.005056187236082873, 0.016781192206378494, 0.09837997811181204, 0.03443939431703516, 0.026364814024418592, 0.03141116377498422, 0.022889914057616676, 0.017607629199379256, 0.095072119895901, 0.057995494055960856, 0.058011602477303574, 0.04163188926343407, 0.027292507101914713, 0.02013072943581002, 0.05099966569936701, 0.030264327635190318, 0.04474590698789273, 0.03597493263493691, 0.012312879652849265, 0.04005980844210301, 0.00355407885425458, 0.09782152343541384, 0.06700300571641751, 0.0458603295098458, 0.01532927484783743, 0.02869226038455963, 0.062236276854361804, 0.018771888422114507, 0.035583075268992355, 0.04629422551287072, 0.0836601515433618, 0.058813088041331084, 0.026750620554334352, 0.016778476369966353, 0.06629711216581718, 0.02274623935643051, 0.01568091713956424, 0.0513485853693315, 0.027164833952805827, 0.054193794660802395, 0.055649713679615936, 0.01980853047487991, 0.05402881904904332, 0.0061447652073444, 0.03648426476866007, 0.02237950644588896, 0.052184506585555415, 0.02899845948975001, 0.015483729774132371, 0.018457674122016345, 0.058488178333001475, 0.04704576072150043, 0.09141752350011043, 0.027888245581250106, 0.01632204621897212, 0.03969509926225458, 0.05721939927233117, 0.09277581490044083, 0.10482667825583901, 0.02844266127794981, 0.009953847487590142, 0.027026509500241706, 0.026225151161530187, 0.02696837092350636, 0.038849349466285536, 0.05771434985633407, 0.022940288497401134, 0.05552300405023353, 0.07360175198742322, 0.03721642780250736, 0.06476318876125983, 0.016221636606912528, 0.033678098382162194, 0.05099387101030775, 0.01623231335543096, 0.04889839880966714, 0.028034943155944347, 0.10140566754021815, 0.04855073782216225, 0.06133683118969202, 0.026799507306090424, 0.05169676882880075, 0.01804032249908362, 0.014715360111689993, 0.047385805153420994, 0.061764864650155814, 0.05554467645872917, 0.039036251937172244, 0.056791172429387055, 0.011282774436819767, 0.03991322452202439, 0.03283248768587198, 0.030630940105766058, 0.06323113132800375, 0.03952082772074001, 0.04609753178166492, 0.07421808570091214, 0.020421637754355158, 0.021715432704825486, 0.014894781733996101, 0.06164937798998185, 0.09069698037845747, 0.01977484460387911, 0.01252640868603651, 0.01630766806192696, 0.028403779525043707, 0.02441037193472896, 0.039219924581370184, 0.01244381909990417, 0.017963720984490852, 0.04718448381338801, 0.04753290136743869, 0.022990713827311993, 0.01273264261960451, 0.02529600601909416, 0.04387021004887564, 0.06616114053343024, 0.033821398192750554, 0.006519962842243591, 0.11220108504806246, 0.018551664792799523, 0.01470185217580625, 0.018363322131335735, 0.027124374605981365, 0.04649624235129782, 0.03403273470965879, 0.054979385542018075, 0.04885241109877825, 0.02359449803563101, 0.038574960082769394, 0.03478968123506222, 0.061599078189049444, 0.029070092431668724, 0.05912796900208507, 0.06857620951320444, 0.025402882069881474, 0.059197342422391684, 0.007936203253588505, 0.052551868837326765, 0.018308689884309257, 0.05152922496199608, 0.028109336039051414, 0.02848952090633767, 0.026214236925755228, 0.010147458973473735, 0.0320045256854168, 0.048352144192904234, 0.09518399674977575, 0.06561466200011117, 0.08243604044296912, 0.016446094294743877, 0.023383008848343576, 0.04498976229556969, 0.03298996887835009, 0.018687147879973054, 0.059310861331011565, 0.023912697032626187, 0.02535032614001206, 0.008664079642455493, 0.0361309719405004, 0.012603556421319289, 0.02906184483851705, 0.029945663841707364, 0.019683444240529622, 0.056810049273605855, 0.02720517455600202, 0.025059511120031987, 0.059622064631964476, 0.04720878215240581, 0.045654119325003455, 0.06054916059864419, 0.08169913105666637, 0.015086796966248324, 0.051736907567828894, 0.042940844382558546, 0.011112366304067629, 0.12274357862770557, 0.012186994443514516, 0.09835367130913905, 0.017141012541417564, 0.046567614057234356, 0.03382842442286866, 0.03282988550407546, 0.02597514323757163, 0.04294672388849514, 0.05776616957570825, 0.018280812273068086, 0.02057727672425764, 0.027008457076070563, 0.07463902847043105, 0.1162096799484321, 0.10589118434914521, 0.14470625083361352, 0.10486899848495211, 0.13014297586466583, 0.12638505894158567, 0.08624378219246864, 0.16785517867122376, 0.1413766930678061, 0.076925901829132, 0.0976772058222975, 0.0939185560813972, 0.16729909208204063, 0.09685354573386055, 0.10457418859004974, 0.1470021554934127, 0.18156725860067777, 0.13750821564878735, 0.12124404337789331, 0.11196910749588694, 0.15311688237956592, 0.15793426388076373, 0.110988006927073, 0.0983765854367188, 0.1319964892630066, 0.11358894700450556, 0.1513767928949424, 0.1747714046921049, 0.15858839878014155, 0.08842826461685555, 0.11365110759756394, 0.1260340256350381, 0.17930525355041027, 0.12682823730366571, 0.09028491284698248, 0.0943430679451142, 0.1524600333401135, 0.11829821073583194, 0.163477664281215, 0.08202020025679044, 0.11750589896525655, 0.13241517251091345, 0.17397861794701644, 0.13577952555247716, 0.19231027284903185, 0.19157943635114602, 0.16505251691809722, 0.11996329495949404, 0.07981230837426015, 0.12181218074900763, 0.121562588427748, 0.16750381966786726, 0.0689785061404109, 0.13621833414903708, 0.18940954921501024, 0.12007118202745914, 0.1431030218622514, 0.16847910519157136, 0.11949787421950273, 0.127629532877888, 0.06758944317698479, 0.24914690373199327, 0.11048310223434653, 0.15365319645830564, 0.1329480396317584, 0.11956967679517609, 0.13862348294683866, 0.15543249169630663, 0.05616167852921145, 0.11958262324333191, 0.13058095664850303, 0.17400403586881502, 0.1589519849845341, 0.11057733717773642, 0.1804962453565427, 0.11123299199555602, 0.21958226444465773, 0.15128375217318535, 0.17511981885348046, 0.1545277873852423, 0.1415195246892316, 0.11779416778257915, 0.2289949565061501, 0.11175059886383158, 0.17201139565025056, 0.11927914167089121, 0.12118464442236082, 0.17710826572562965, 0.16188808743442806, 0.17242395851228917, 0.09098478100661721, 0.16536448017827102, 0.12444854713976383, 0.1587659985359226, 0.08653421553650073, 0.13455238140055112, 0.21004903742245265, 0.12487356790474483, 0.1406624535364764, 0.09642173283334289, 0.08491447102278471, 0.12741648645273276, 0.08950386475771666, 0.118279401745115, 0.1803211018975292, 0.16696414005543503, 0.13175604359379836, 0.15059179573186807, 0.10245805499809128, 0.14940087177923747, 0.15208605197923525, 0.18350752948650292, 0.1449805689709527, 0.20450651911752565, 0.11876074091664382, 0.1327143521713359, 0.10752232146582433, 0.20957296368266853, 0.10658813480819974, 0.13461297457771643, 0.14243762328156404, 0.12978161525513443, 0.1450776673321213, 0.14269610441156796, 0.13352385801928385, 0.15273004956543446, 0.12793285160192422, 0.08746904680239302, 0.06395579315721989, 0.08174240802015577, 0.05648524813087923, 0.11110110514398132, 0.11183853700224843, 0.15378450655511447, 0.18818210650767597, 0.10726191329636744, 0.1481018436274358, 0.1507524321121829, 0.11924043803342751, 0.09599998260715178, 0.14932868922395365, 0.13476751771356377, 0.2116795570722648, 0.11593156201498848, 0.1308811405407531, 0.19043211505881377, 0.11720301450363227, 0.08103622269949742, 0.10348787438124418, 0.07876745944044419, 0.14740405178495816, 0.18087265587278775, 0.06422038110239164, 0.13613627212388174, 0.08965322388602154, 0.13548344001173973, 0.14305165676133974, 0.10583950033677475, 0.138623605083142, 0.098682122970266, 0.19572543459279196, 0.14320853405765124, 0.22594344882028444, 0.09831781751875367, 0.24496053265673773, 0.1337690127215215, 0.22771081541265759, 0.1852325147816113, 0.12385839809264455, 0.15781847866518156, 0.21163366096360342, 0.20313937962055206, 0.18944960992251123, 0.09871727108423199, 0.20812594704329967], [0.0595885178606425, 0.04117049562877842, 0.024895875614934733, 0.025143086278278912, 0.05130161038999047, 0.010160982176395399, 0.03324938299400466, 0.04571126215159893, 0.03009482958753194, 0.057191497912364345, 0.04734708794525691, 0.05401213387293475, 0.03252723174435752, 0.07982017259512629, 0.029675114966396774, 0.03561744985303708, 0.05088249287967171, 0.06709006854466029, 0.035697489843836853, 0.011108306120149791, 0.030743006949446032, 0.04134703686993037, 0.013050530338659883, 0.028616722473608594, 0.013978845972035612, 0.058149365442139764, 0.010821437629471933, 0.03814849064552358, 0.1264679352087634, 0.04175881263134735, 0.03406876152647393, 0.03333667652415378, 0.018313163126419698, 0.03596662058095847, 0.013593244698962994, 0.006434072183245527, 0.05751005653291941, 0.07746560179761477, 0.022612206637859344, 0.011292858315365655, 0.06476147885301284, 0.007156006725771087, 0.05462853204725044, 0.018298852822876403, 0.07650779533599104, 0.02613313672398882, 0.023923455205346857, 0.05429872331608619, 0.020958504839135066, 0.0430862069396036, 0.02865657622792891, 0.08517145259039742, 0.030103976239583323, 0.0489915480970272, 0.048521075663822036, 0.01180152378843299, 0.06810922135732003, 0.04185968364721962, 0.02074319210701755, 0.07550243714026042, 0.016227480489760637, 0.029630508074270825, 0.04498816773827587, 0.04549353722749012, 0.049623705247151, 0.0076612226964373675, 0.054001368914863894, 0.029473467929554836, 0.03367466838764293, 0.12440592156989233, 0.01970508781128696, 0.010976618588236826, 0.051248491276055574, 0.07333062296467167, 0.04888063815555402, 0.03769900869312031, 0.029399293873991286, 0.06022281918142523, 0.10709451192191669, 0.055009817837604454, 0.0400069980616016, 0.027305346680805087, 0.010692063053803784, 0.10154990372913224, 0.05347975868997829, 0.042672728055289814, 0.014644493914342352, 0.039389229246548245, 0.07209122447030884, 0.04242381087637373, 0.03717332047277263, 0.039218706611011706, 0.031318363933158774, 0.06319780168788773, 0.05498718190938234, 0.055128934660128186, 0.025634067432422723, 0.07796158375484602, 0.030720859566437345, 0.01173629960976541, 0.00348008015758491, 0.02322973626931863, 0.027074015433234826, 0.0695481566446168, 0.013472389130453979, 0.05868469564510243, 0.016779701125675013, 0.07961504467363868, 0.01357769946168576, 0.06080209131219557, 0.09573202234293733, 0.03534585603379777, 0.0398721019072192, 0.011047441528977027, 0.026726937985845974, 0.035972700254725556, 0.024183076274182116, 0.05681026301213673, 0.018874248822352717, 0.023641932722447172, 0.013770526391454041, 0.05194262242210763, 0.06379451895398752, 0.033892600264932425, 0.04644647520035505, 0.016468798076467853, 0.040992186803902896, 0.007947163290477224, 0.024109821633568833, 0.10695684395198311, 0.04826737820569958, 0.008413874095172753, 0.02842994892437543, 0.028604834540081874, 0.01198186567385814, 0.01225445354689977, 0.030948881259454147, 0.034289220946707895, 0.038797193872077126, 0.02069626123245273, 0.06312673871538468, 0.07118159399500915, 0.05705322604626417, 0.053974841588309834, 0.03515635138111455, 0.06808980168508631, 0.035268133240086694, 0.08379988904510226, 0.02898176752829126, 0.020041977055370808, 0.01260407465243978, 0.03429884257327233, 0.03237565041386655, 0.047668421774038246, 0.0213425675340529, 0.04137667527954493, 0.06590222514101438, 0.03961744771472045, 0.0421838537523789, 0.0191384991963527, 0.05155794734933546, 0.011717365090070027, 0.03759871103933879, 0.028652175928332975, 0.02903441506038819, 0.12474243422704083, 0.015711715844060694, 0.0474569902622274, 0.031322519960147996, 0.0780174204015306, 0.02853949161778603, 0.00485302833840251, 0.031610052566975355, 0.028061930189973543, 0.0358392392019076, 0.03975355505411114, 0.02213503367134503, 0.06925656979105302, 0.025529308410893594, 0.030511969168271338, 0.02996263060984867, 0.030362026499850408, 0.05469966965860554, 0.03183462390942233, 0.023251505369054418, 0.011553745700179465, 0.03890051439936672, 0.03240664250084332, 0.03811237561915602, 0.042605695580797534, 0.05899633999381747, 0.016500326206109354, 0.013500878271380705, 0.019250009641317383, 0.02689663111232221, 0.006148247788327613, 0.030969705499176468, 0.022504579109538878, 0.04938713740557432, 0.06870075461587735, 0.016484190643365895, 0.00422467098438314, 0.03905557322182825, 0.06427269615232944, 0.05253251701859491, 0.05393090644585235, 0.02826511750130781, 0.02331970153110368, 0.0353953924828342, 0.0015296162975053968, 0.06593581940978765, 0.023993437610832707, 0.018189016663070236, 0.060413908213377, 0.0544283438606986, 0.018863802775740623, 0.02986629560057606, 0.04772727111620562, 0.023335832004834498, 0.020294405653008392, 0.011218544311954506, 0.03888933553493448, 0.04572936546589647, 0.027252685578007783, 0.04376305240605559, 0.03229257058618324, 0.016960096445732882, 0.06718139257282019, 0.04422084301976221, 0.016008445993065834, 0.05019672807039959, 0.07528633730752127, 0.07636181531207901, 0.0648128507392747, 0.052020891436508725, 0.05066996553380575, 0.03198834601789713, 0.04950790646086846, 0.024838111928797195, 0.01860600526976798, 0.04762976563402584, 0.013724364805966616, 0.06244819012603589, 0.014780329839725579, 0.025178063062152693, 0.15236448203878744, 0.03365802053096039, 0.05001705878281167, 0.032632238431168456, 0.06909817257629973, 0.03919598586591227, 0.008435915457084775, 0.046250500716269016, 0.02626175812578627, 0.04158060897939971, 0.03090779935675008, 0.006039257252788437, 0.08511991107038089, 0.021062013659892336, 0.03229437888200794, 0.06250013198171343, 0.03592767267088805, 0.018414312341649617, 0.02289404803221779, 0.052846695695604594, 0.019531216605433395, 0.03220488350572331, 0.02993753499218396, 0.03608451943312373, 0.040655657183378935, 0.07561683135905437, 0.03475076385906764, 0.044515724160841534, 0.04583839586536799, 0.009272961345102106, 0.05415224117626037, 0.009258104820868798, 0.0262549151001232, 0.0037815880412901087, 0.12517284256006989, 0.045898364790316136, 0.018752967473119497, 0.0360020468942821, 0.03997658612206578, 0.03432799583034856, 0.015120783088994878, 0.06477969751826354, 0.0200494358515633, 0.059194743633270264, 0.050591557419725826, 0.06789220550230571, 0.02608397346921265, 0.026353672479412386, 0.02943653187581471, 0.03909956603976233, 0.032338300453765054, 0.02490094257518649, 0.03017636914072292, 0.06633744428732566, 0.037924346780138354, 0.04984868031793407, 0.01910181250423193, 0.020005137692870836, 0.023904262842344384, 0.027758022836808647, 0.027484973559954336, 0.004330489792794521, 0.006427547220872449, 0.03954067826271057, 0.013459132252527135, 0.02282831834496132, 0.023681859419281994, 0.042324076406657696, 0.053000343165227344, 0.01600979288507785, 0.0152503459581307, 0.03274223913571664, 0.029085946402379444, 0.06910776027611323, 0.0642794950732163, 0.010050358915967601, 0.01167908129614911, 0.035579387431166, 0.03277657640033534, 0.006827309095699872, 0.008989817163507854, 0.03280976354809744, 0.0600143392969455, 0.08257989665227276, 0.028602388421339647, 0.01519879765276398, 0.01773762802726456, 0.023313833899529915, 0.015493453180949603, 0.03606747802613037, 0.05941241766725268, 0.06100219128919499, 0.02137728817095714, 0.059225440557513914, 0.02043801758970533, 0.02924569050914475, 0.04595671540924481, 0.04558440324451242, 0.038622851084385595, 0.07645485603383609, 0.027110147422977855, 0.11425536338772092, 0.039943103811570575, 0.040587301565600295, 0.029551509634724686, 0.08906211810452597, 0.03344158482338701, 0.1296497080475092, 0.15316740609705448, 0.062204141435878615, 0.13218399563005992, 0.16043405474296638, 0.10062695361141648, 0.1357619243540934, 0.1143645668136222, 0.08293695534978594, 0.10229467733630113, 0.1331533643284014, 0.18344984043921742, 0.09234480267124516, 0.14031809701451234, 0.10398853144475392, 0.1338061150163412, 0.0999757499833192, 0.0760329904566918, 0.19048529863357544, 0.07775163823472601, 0.13658479734190873, 0.08602618279733829, 0.08428947920245783, 0.17009898541229113, 0.13024076633155346, 0.18499588247920784, 0.10919870329754693, 0.14097236762089388, 0.17730239459446498, 0.10826106289667742, 0.12450407844569002, 0.0961140850558877, 0.1283777127308505, 0.11158880897398506, 0.15413282572158746, 0.09186085792524473, 0.10331641536738191, 0.21306155648614677, 0.12722488173416682, 0.15434961766004562, 0.19167529977858067, 0.06025639309414795, 0.0945802770022835, 0.15177157813949244, 0.195975732590471, 0.16583573631942272, 0.08942126668989658, 0.10391436756721564, 0.12626608461141586, 0.11015866750052997, 0.13115773855575494, 0.14578816135014805, 0.11889799498021603, 0.09188253711909056, 0.1267558376171759, 0.12548954199467385, 0.24893074961645262, 0.13027504592069558, 0.25314708479813164, 0.1644842302692788, 0.11864923047167913, 0.08159568839307342, 0.1189527798976217, 0.1471901639763798, 0.12658302831862653, 0.1286670264921018, 0.12115663449679102, 0.13083859639508383, 0.16813085387860024, 0.24691281361239298, 0.16527595849973814, 0.0947609640923994, 0.1639819379363741, 0.17166334789778503, 0.17599086782761983, 0.10608599853834935, 0.11346071745668139, 0.1598509217479399, 0.18844088619308813, 0.13994985605989183, 0.10593568946101836, 0.1067380639059203, 0.2723568454384804, 0.27624452539852684, 0.1241512130945921, 0.09128025586583785, 0.19577242992818356, 0.14733718894422054, 0.12327833207590239, 0.12405112917934145, 0.0935021662818534, 0.17738038540950843, 0.10955899860709906, 0.11103697679936886, 0.1725330940846886, 0.18586147603179726, 0.18021799171609537, 0.16207419601934298, 0.1272440707044942, 0.14829703101090022, 0.093127452103155, 0.212811231347067, 0.11014895766441311, 0.213327325082251, 0.13387550200734818, 0.10158037673681974, 0.10463141623352255, 0.24208587833813258, 0.07762165806655373, 0.10812990207757268, 0.164748506088342, 0.10026161678667579, 0.17774486728012562, 0.12032173786844526, 0.1548193267413548, 0.14628411616597856, 0.10858654935977288, 0.13363525989864553, 0.13626432525260107, 0.22078567344163144, 0.10714151404265847, 0.08511868970734732, 0.12010284247142927, 0.14260684991521494, 0.19231648822980268, 0.19956854837281363, 0.09267067589930125, 0.06708867754787207, 0.18422832366611275, 0.1529346550149577, 0.15683719489191258, 0.09348875842988491, 0.11470274866691657, 0.12593422670449528, 0.11557637607412678, 0.09003627047474895, 0.08388758969626256, 0.2194503436663321, 0.14797114421214375, 0.07563726883381605, 0.14425487576850823, 0.12893951258489064, 0.11265794267611844, 0.1692896695541484, 0.08404625832502331, 0.15804950626833097, 0.20686103563223565, 0.22773393988609314, 0.12113615630992822, 0.13811015763453074, 0.11842884229762213, 0.1797131888036217, 0.11579676424818379, 0.0839976209348866, 0.08127677014895848, 0.11731352071676936, 0.09001613834074565, 0.108760295036648, 0.13276323383407934, 0.12982884129243238, 0.09912277039672647, 0.16048372350633144, 0.1435210265751396, 0.09217741486749478, 0.11866878585091659, 0.16296716167458467, 0.13116900223706449, 0.16146010825676577, 0.1753012319760663, 0.1280305063618081, 0.1595465987920761, 0.12506695038505963, 0.10018260816910438, 0.07516396351690803, 0.25959495880774086, 0.09851573261299304], [0.019132931816524694, 0.01076114215954606, 0.04469935270026326, 0.024179883766919374, 0.014518383092113903, 0.024312584860516444, 0.0035583279677666724, 0.03562932421586343, 0.03454946626776031, 0.027173300373501012, 0.015436651318200996, 0.014449147075148565, 0.04259418423420616, 0.04226817869182144, 0.0198077077511698, 0.01628007204271853, 0.011578322238554912, 0.06420464587530919, 0.048577886008258374, 0.01590821788912373, 0.025994086238954748, 0.04631095818643059, 0.02169481372194631, 0.063003984945161, 0.024156538769602776, 0.047802252628441365, 0.010144720236504716, 0.0533494765737227, 0.040330930679504357, 0.02309469083723213, 0.013529493789454656, 0.015786185062357357, 0.03002962576491492, 0.013005937865403081, 0.05815370806625911, 0.012370812124572694, 0.03196087892034224, 0.07787982028509889, 0.015359764818900397, 0.046327120890574794, 0.032182742908064804, 0.02480095365483846, 0.021923827772427882, 0.03262928680383733, 0.04970201158097812, 0.00430920669376584, 0.007813958384628807, 0.012533107523008116, 0.03332522963838918, 0.014587522417839085, 0.015661687457135746, 0.04157968277909926, 0.088881573506764, 0.0741919417466436, 0.025113856686013084, 0.018664684978180697, 0.04718419543600508, 0.041180459915527275, 0.019989088643342257, 0.012185544923080929, 0.035804104658641984, 0.008081117977521248, 0.006779822246504149, 0.03764978437019246, 0.05834683270326682, 0.04942553570227964, 0.01270243339240551, 0.013881496552910124, 0.09024228727711098, 0.04829342716506549, 0.021584063236202513, 0.010911716713703104, 0.03139470251543181, 0.030736635505620922, 0.023094013998551027, 0.018377077732501284, 0.02612306217529944, 0.09920374676585197, 0.021436196884938648, 0.03678864540000047, 0.019839924593855227, 0.046641577766942124, 0.0828486168757081, 0.026182907267606685, 0.05866540489452226, 0.029741299272115742, 0.08494256915790693, 0.042325613288474936, 0.03398927793438945, 0.05121652888400214, 0.03712644048833421, 0.045886880585125515, 0.02315564703063241, 0.05930280712034021, 0.05947765202394553, 0.07353610372436897, 0.008319258324003645, 0.03448539559862443, 0.024340050261733786, 0.059552453724401336, 0.04445927343996508, 0.046850729401090314, 0.05318850092589855, 0.04935084596010191, 0.0026461998474717674, 0.04790779875059213, 0.026464926777407527, 0.03672112438029476, 0.011072808560649199, 0.06571169250777789, 0.036372085966702015, 0.02512212802789041, 0.015207376031737243, 0.02940344650830541, 0.07111044281295367, 0.0228106815234891, 0.038834302952247005, 0.03627221918265734, 0.019235986018819467, 0.012256002303079834, 0.018140107858926058, 0.02710133834209825, 0.02537567281563367, 0.037739870071943314, 0.07204123001013484, 0.040022685791232755, 0.12956829741597176, 0.03324354759284428, 0.025748063011893203, 0.029948167635926178, 0.011269425108496631, 0.012243317090906203, 0.009446416948256748, 0.03855149294914944, 0.011440608467507576, 0.03529592264177544, 0.023101857863366604, 0.011801156531354147, 0.019114687706210783, 0.029371199131544148, 0.015504455626276987, 0.023081254147525345, 0.021933744561725428, 0.010496682287859065, 0.049519777431019714, 0.05445107478382332, 0.04729683903445091, 0.02364843139158828, 0.05951770594609635, 0.014485214604064822, 0.047379874757358005, 0.0541231591653611, 0.07112818650369133, 0.1109874030309064, 0.033968684396573474, 0.062460118771663735, 0.023516022068049227, 0.024849757286054746, 0.04547774771760617, 0.02204856795391866, 0.016781979307000126, 0.014800723209711058, 0.017237278000850762, 0.028456148857782994, 0.02953087877748268, 0.033241562877914736, 0.04177385236003569, 0.011167871316761842, 0.04061105368392808, 0.0334640782592552, 0.060954490277384005, 0.027486695342564156, 0.015244335834203022, 0.08253602936331715, 0.027888881707830087, 0.0048319814543771955, 0.020317742168637257, 0.019782820783023323, 0.02122715551273099, 0.006038408235846353, 0.026319917058572173, 0.038638755945222716, 0.03686235805175134, 0.024006723326497843, 0.046680702096117396, 0.020668965464990054, 0.025226953206583858, 0.060255972402436395, 0.001244628833124547, 0.0532027840880411, 0.01897518090637667, 0.040573025188807926, 0.004942898181200559, 0.06306506666753973, 0.03238136028604848, 0.020097114810986177, 0.041482435140226565, 0.012599194289318152, 0.00994074497638004, 0.03863212665809052, 0.02340115457107978, 0.07570005367909159, 0.026065678468772342, 0.02731075630124126, 0.02548435716224568, 0.0387312911583909, 0.02150288161023387, 0.012208925543486007, 0.017200196062081625, 0.007947863877883979, 0.039300388656556606, 0.039841727287109406, 0.02125703989128981, 0.011220363633973258, 0.0066162232126641485, 0.022874065175918595, 0.008542496345138975, 0.011320976806538445, 0.026802881321470653, 0.036919134469436746, 0.033303448664290566, 0.009335562137753835, 0.05849471941058125, 0.06899823793875319, 0.024154420044007044, 0.029143174045852253, 0.05040464477081384, 0.017904605317328657, 0.03813931345939636, 0.057606150662260394, 0.02549377522830452, 0.03535661420651844, 0.006960891436652413, 0.015485354865502034, 0.022094029800168107, 0.034750400842832666, 0.031714584279273234, 0.017335606206740652, 0.030192793080849305, 0.037782509212515185, 0.03641891845368913, 0.03541254245543054, 0.018938925083992735, 0.008716729719058743, 0.13483324061547006, 0.045794725351567776, 0.03115981744070138, 0.08541460561433009, 0.011982384753147406, 0.08285693571503673, 0.018006047998954142, 0.019081130756863525, 0.0855748959417854, 0.033953793945589235, 0.0757283146626183, 0.07931168523750134, 0.008126211718523076, 0.038243729820741076, 0.043907091819814274, 0.009171442328287023, 0.042986509789313586, 0.016477245837450027, 0.0514642993387367, 0.06326108864907708, 0.03783165550391589, 0.010651634241055166, 0.03946880444086023, 0.05559299833008221, 0.05155121288927538, 0.053796929706420214, 0.04992690522755895, 0.07476775334881884, 0.012017919632074024, 0.03681007353588939, 0.013811579456419816, 0.01768165228090116, 0.0403044508504016, 0.054544003547302315, 0.06461685589913811, 0.04185590081449066, 0.05362115181716425, 0.011643701632108008, 0.016642581072768996, 0.04507129506341048, 0.07698219987962927, 0.029233588837087154, 0.05078577110543847, 0.037708820309489965, 0.036341273691505194, 0.03718078096530267, 0.04604960006794759, 0.02143172873184085, 0.030115311167069843, 0.04373670828395656, 0.026934457743274312, 0.021945764809580784, 0.020293699976589, 0.029046096040734222, 0.024893563506858687, 0.03413910525185721, 0.04506407545081206, 0.05434367286839655, 0.0709655484450715, 0.020690020406618714, 0.025833819660225084, 0.0431953492973532, 0.028738339697676044, 0.01653670416479664, 0.0047031454658801, 0.02547210281980889, 0.02775305596047214, 0.03912831896117755, 0.01933623956782477, 0.02887924767232367, 0.033317026150013716, 0.01604370097629726, 0.02420566979396556, 0.00792223391389208, 0.005538939032703638, 0.019171045128522173, 0.027789296515818154, 0.0253086623935295, 0.13361026266855852, 0.04076669943918075, 0.033695163537881205, 0.04014857778591769, 0.017961344415588037, 0.02358705281013889, 0.01910196347827358, 0.01931108797102102, 0.06608674595398562, 0.04335212481341191, 0.021014590847439, 0.05494762331779514, 0.03169755305030516, 0.026324610824563673, 0.04420486352007304, 0.02075604864928339, 0.042861092769141705, 0.05935818236321211, 0.01615893657851432, 0.054680901379989724, 0.017779239187283174, 0.03032152135191219, 0.018949744324865084, 0.02241607948339411, 0.03705843770876527, 0.030401954893022776, 0.040854780069951496, 0.04711994156241417, 0.00516711498910029, 0.045450019384069104, 0.12345172491456781, 0.06732809862920217, 0.12939903007021972, 0.13252672366797924, 0.14070032936121735, 0.0939275873824954, 0.13827209680208138, 0.08569087793252297, 0.09809135645627975, 0.11912770622542926, 0.12822509663445608, 0.10373926482030324, 0.10176338441669941, 0.16724281438759395, 0.08911683516842978, 0.12882714718580246, 0.033759498835674355, 0.2453374724302973, 0.14209853219134466, 0.14302770447518143, 0.08489013875701598, 0.18778823050005095, 0.06766012616987739, 0.17033576699239866, 0.09666544225599084, 0.2100707505430494, 0.10114817028599125, 0.2214781998523644, 0.17197345197200775, 0.15034148416348866, 0.0858947912763272, 0.14945203331964357, 0.18590047822466918, 0.10284692341727869, 0.12937642128339835, 0.14996926699365887, 0.1451572459191084, 0.1915630700864962, 0.1505679384406124, 0.11471636007939066, 0.11679798338030066, 0.11013614013791084, 0.11147771922073194, 0.20071475686771528, 0.13182704549814972, 0.11528637020715646, 0.13668081004704746, 0.1499314047396183, 0.16430657623069628, 0.19853992999664374, 0.1314517884914364, 0.10951017122715712, 0.22055395373276301, 0.10501050696309124, 0.094779033479946, 0.14306373468467168, 0.10883663022624594, 0.11717334895261697, 0.06810015612947089, 0.10266035342855112, 0.11490378502224173, 0.18595415034464427, 0.12003789309944425, 0.1792988074677331, 0.10291962844452687, 0.24569932158504212, 0.15564503600554808, 0.15454945979373796, 0.16596685642642633, 0.17446693245853695, 0.21334660904748098, 0.14670449575143202, 0.08556205805923257, 0.14377387586448873, 0.059893417571272166, 0.11608178966811725, 0.1498516904456275, 0.23892868203776224, 0.11885615651096616, 0.1572301345212119, 0.11805377528071404, 0.07560997137001582, 0.16239084117114544, 0.13081222852425917, 0.21187283098697662, 0.10691056786371128, 0.21161817679447786, 0.23032206243702344, 0.1608426413897957, 0.1424484391297613, 0.09945387512977634, 0.18693577338542255, 0.18722451717725822, 0.14456717829619134, 0.09652685826378209, 0.12955659947225026, 0.08163959639413015, 0.1343554841088397, 0.1136318032762834, 0.11374994979373046, 0.10387047992220946, 0.09938453563622066, 0.14652016492826597, 0.17344163890395844, 0.08272411927048649, 0.14985687445316995, 0.10028006615383284, 0.15271950513124466, 0.19753820874861308, 0.15834084206393786, 0.13500765125666345, 0.08567901035504681, 0.14218771883419581, 0.12033787343118872, 0.13407986318426474, 0.14612930161612375, 0.17035510524043015, 0.11255004882280316, 0.23621283205492155, 0.15386716569108622, 0.11039692828697817, 0.1178557923329728, 0.11347100404756409, 0.1628714475248541, 0.1264406173889126, 0.09468291220920426, 0.1817986254713365, 0.13919335736760072, 0.1220643650740385, 0.15290656366518565, 0.0649964487446206, 0.05963928585073777, 0.1364865047591073, 0.10332093441060611, 0.11841291029538427, 0.1766080361391817, 0.08553999210042612, 0.1077383059476103, 0.19445092869656427, 0.09649759304842778, 0.10456048218267304, 0.09266585151531867, 0.06926663925072976, 0.08321432010935885, 0.13678892781691893, 0.09751226752996445, 0.25381571320550783, 0.1345348209142685, 0.0855379972074713, 0.09056472033262253, 0.18553367576428823, 0.11007028152900082, 0.16059687600604125, 0.1528688778302499, 0.18850582199437277, 0.10897946184767143, 0.0777077234483191, 0.10373252696756806, 0.08155372100217001, 0.1498595071690423, 0.10743549612483808, 0.12330133441303458, 0.0711826253682375, 0.0653178436415536, 0.09557699744722672, 0.1766952821718795, 0.24754995799490384, 0.14773410478872911, 0.15110004560223647, 0.09404918764318738, 0.12521389392869814, 0.16563209438962595, 0.10870277562311717, 0.1711442278964179, 0.1764415914991072, 0.127450806753976], [0.03530685044825077, 0.033761887278939993, 0.058451998845807145, 0.06275123065071446, 0.02874734385737351, 0.04995768018332975, 0.07103887093918664, 0.0349202211946249, 0.017393659966598665, 0.05325145201225366, 0.008323489838013691, 0.07646819603230272, 0.02052405583006995, 0.03363088930823973, 0.022124077027131404, 0.04170231780569468, 0.021894910306270634, 0.016303142233352576, 0.03283153434417077, 0.013899712673654514, 0.03621064891506519, 0.03742150483386857, 0.03679866396955081, 0.013089113536157777, 0.0804284792393446, 0.0342553315152015, 0.019178989077253, 0.050827779208442996, 0.06598767305591277, 0.03326714025544269, 0.06431652272918395, 0.06942156236618757, 0.020393334362389784, 0.04466464902673449, 0.04895367905763643, 0.037392846907355955, 0.016362050947334086, 0.025130470615944693, 0.03671434581545847, 0.02955480052956513, 0.057577563981924734, 0.038289371478770456, 0.022290043300017715, 0.014802699442952871, 0.015890443664310232, 0.007706658249454839, 0.018453036335163882, 0.02883588589195694, 0.01300350107651736, 0.04721021046862006, 0.028841823073370115, 0.06562990189663001, 0.0565687520429492, 0.10940013998853308, 0.048339387734553645, 0.025038557958656123, 0.05865192240370171, 0.02854064173464264, 0.03128850160698805, 0.021822303666600158, 0.0450183252271797, 0.010073133095699762, 0.05177192336746624, 0.027967094743092145, 0.039504746440798044, 0.05716612748801708, 0.09630573048655476, 0.007916558816629862, 0.016135835853804435, 0.03859229665249586, 0.007058288353229207, 0.015277602709829807, 0.03902116810370769, 0.012942550820298493, 0.029641232320240567, 0.058327012695372105, 0.015572643306638514, 0.052037335732685666, 0.03948550658034427, 0.02597464621067047, 0.09526944466467414, 0.02656803695884134, 0.07266016929809536, 0.031248749632920538, 0.04303117774959121, 0.04941395989486149, 0.04552676848002842, 0.06537910178303719, 0.017102100254435624, 0.060625482217541764, 0.011944793913114284, 0.03755445698542254, 0.013861065863498619, 0.07109575931515012, 0.02315322296427829, 0.03962448412286384, 0.0146183889758374, 0.01744302169286779, 0.0200625129177102, 0.04430648431714092, 0.09491351233529192, 0.03589904188577618, 0.04603604972362518, 0.016885647583486776, 0.12000309782368795, 0.03691562305071524, 0.1121313316481454, 0.07026804837265185, 0.028324083890765905, 0.06090714888913291, 0.04440836974286607, 0.026035083324781487, 0.020741271852914776, 0.021696876468402997, 0.042089757908667834, 0.022607134588594948, 0.025016603958127753, 0.017939982436863438, 0.027983345656788776, 0.009820240549743176, 0.04686018478657518, 0.021790561798427786, 0.030643774595643793, 0.03118095380653228, 0.0397306816386325, 0.07970182251717363, 0.04921543411910534, 0.09134028585893766, 0.00813028377680374, 0.03378388199156948, 0.00892943433219833, 0.023965005297213793, 0.03703318602804627, 0.022153476253151894, 0.03153475892863103, 0.026990559018616165, 0.011744644742326012, 0.03688171665583338, 0.05724552287054913, 0.06198080163449049, 0.04427307664549776, 0.004267690952734223, 0.06266469029443604, 0.032603105530142784, 0.030739716054605584, 0.04672762279265693, 0.07557968156678335, 0.017356474551239183, 0.01512952770904771, 0.04311550947438393, 0.02885123435407877, 0.020419094944372773, 0.029253042436071804, 0.034561120106705596, 0.01471348396236343, 0.013178459634738309, 0.04717583927725043, 0.020478621125221252, 0.017867916928870336, 0.014457097809229578, 0.05495544343388506, 0.04665782189528857, 0.044698874333075116, 0.062185563147068024, 0.008069205447100103, 0.020465279430417076, 0.025850155390799046, 0.05102968069591692, 0.03908873322818961, 0.02402776469742613, 0.039240426516958644, 0.03345283832667129, 0.028692755715123246, 0.04133420577272773, 0.00401545234490186, 0.038064990126128705, 0.046157554989414554, 0.023357852162527185, 0.01859576956901167, 0.052983827622873444, 0.019176985702610443, 0.05241512367501855, 0.019022768263572028, 0.0375965974027557, 0.025967063581837074, 0.047625914947795014, 0.061467774877590795, 0.061236156948975155, 0.06426763428109032, 0.049447812006941864, 0.06188428681343794, 0.011475229868665338, 0.03847144278032439, 0.0327705272606441, 0.04723789469738092, 0.02490004012361169, 0.03792002111939447, 0.07343444560787507, 0.022097078118739382, 0.06017112838370459, 0.05777476661439453, 0.024414349846275787, 0.028129530937543938, 0.030295513104647398, 0.06850439336683069, 0.04154777466984732, 0.04202046591256346, 0.012108792434446514, 0.020400708341704946, 0.02688682628130274, 0.016505868140874163, 0.024585425487852523, 0.05857442691922188, 0.005949362813095961, 0.043735673518053124, 0.045135922131261656, 0.021862718908648406, 0.08976860876594271, 0.027224580657535365, 0.035380620775478225, 0.03274454954745514, 0.008949996487769698, 0.045193109062633345, 0.01786797460434692, 0.0007467555125393638, 0.048968844315303225, 0.018140967902062193, 0.033101384328412156, 0.029763334696846347, 0.01739268796518445, 0.029702697414904833, 0.028248398398448313, 0.028531403480363742, 0.04184281526665602, 0.008661263722128101, 0.01991644298790821, 0.020506403741559813, 0.02796944586693176, 0.0356947044575853, 0.03992741947461452, 0.021075467312974588, 0.02625229086593858, 0.09879102784075908, 0.03319331903808883, 0.033946794856871874, 0.023366445808538368, 0.048082436701016765, 0.012561203113624027, 0.035065807668226104, 0.012984232378325291, 0.05653752925406609, 0.050415253665830405, 0.017863972944074442, 0.030220979425523962, 0.03813122532197407, 0.017327752163899795, 0.10139922145754099, 0.07004278831716094, 0.0330256055375295, 0.029032382848007337, 0.034869439633829255, 0.04792306239583662, 0.05086499685421586, 0.04013062374932425, 0.03437374605398093, 0.019683245769036666, 0.03554698399135044, 0.06726766830044133, 0.044687407091259956, 0.045078334864228964, 0.04556073594306197, 0.018658325408718417, 0.024736647194783603, 0.07285070871668202, 0.02821276513194399, 0.008969772390888205, 0.016252447185771804, 0.053162200908575735, 0.009799515545767332, 0.013340939933966314, 0.06895523238927126, 0.043690194708428214, 0.021637116192973087, 0.04674833168142608, 0.02914778808397906, 0.03785334487578698, 0.07912542737488236, 0.03829467762261629, 0.07891755817191941, 0.06119117007723876, 0.03808387375569769, 0.024977413471788168, 0.015270145609974861, 0.008757524092548659, 0.05850274647985186, 0.03784512442403606, 0.03181501424738339, 0.06180932904992785, 0.025268664450517724, 0.02143883129714855, 0.08618969616613217, 0.0786532416407551, 0.07421616544680935, 0.05904872968260731, 0.025720129421512996, 0.07319549950105803, 0.011119606272716607, 0.015563501743599772, 0.027698096320299164, 0.031278832482972314, 0.04835293468620096, 0.06328825719122376, 0.015944166674411724, 0.09391937710876976, 0.014034054125659168, 0.009934180150074618, 0.03792413304160748, 0.007838088786229491, 0.06447201581405741, 0.033270980763648234, 0.056837529941861115, 0.060273851800177775, 0.06163933567170586, 0.01105668826494366, 0.03608267721054809, 0.031760853582194874, 0.0377129661584539, 0.03826029286054628, 0.0740889808429139, 0.04272028996742197, 0.03145300563690918, 0.05812660737761429, 0.0939813544973731, 0.012786436027714183, 0.02250110331390585, 0.02532596673284258, 0.07037714323295013, 0.03031366052372115, 0.034357837800468714, 0.026699269024123038, 0.033113696346325536, 0.03316941424938185, 0.026971709315798113, 0.06058004751269307, 0.08429787268063851, 0.043269238368208916, 0.04554685650925551, 0.04766665419031467, 0.03893410527546491, 0.0371861888894013, 0.037534932140260935, 0.03884997711117778, 0.1222746702177184, 0.1368638380829777, 0.1188416765736682, 0.13578910646694048, 0.06551126004861933, 0.20416497173053877, 0.060319598631135056, 0.2799623001899038, 0.060372571860040934, 0.16914354025253228, 0.09450721913682562, 0.1722925669912781, 0.12824628049773829, 0.16996994162244455, 0.15946218903575624, 0.09915728747312512, 0.10432740540376731, 0.15390272092606339, 0.10854725539684296, 0.08180256014955894, 0.15296413057616778, 0.17340073681303433, 0.09490702554051365, 0.24368599961910928, 0.1672514317823308, 0.12521926792604582, 0.16334768411304268, 0.16952940954693727, 0.20527054954852375, 0.10337795849357333, 0.1286555321088859, 0.08758162933268718, 0.11421121789940766, 0.11084163335285016, 0.2572992577084473, 0.15924083734197275, 0.09034838979797703, 0.07199948653578758, 0.0861223651362317, 0.1191769407263824, 0.17117568477988243, 0.18255981962595666, 0.17186381428369454, 0.15571417872394833, 0.12998145738882677, 0.0780657660216093, 0.15971586613782815, 0.10170001603130784, 0.09103982376732997, 0.3295422297503267, 0.12194235090698514, 0.18716220052114554, 0.099811788781413, 0.20092466846108437, 0.12021577783993312, 0.18920199892350606, 0.13021978602877685, 0.14972726069390774, 0.10079563741705247, 0.18302095202463015, 0.06485873327723571, 0.1019695233553648, 0.15866328190479959, 0.1450183226593903, 0.1409362017043999, 0.14568454905280045, 0.20549460181168147, 0.1588724199682474, 0.07942734153142997, 0.09916853758373431, 0.13969486259988376, 0.19584402894335134, 0.09030868871403591, 0.1076725423336029, 0.12745890846209867, 0.13234225713780948, 0.09939496471945729, 0.07608706969767809, 0.16816197149455547, 0.10469565992908818, 0.18858419278902666, 0.27013917586633135, 0.15918776233281406, 0.134050401193755, 0.10062601723309074, 0.13290834533316748, 0.16141974899385655, 0.13956820725330285, 0.20447740996522562, 0.09284799067037446, 0.08872019073792867, 0.15086126912917408, 0.16328251760985169, 0.12195440168891634, 0.1105390881587352, 0.11819778755307198, 0.1306235957890749, 0.17661057386015142, 0.10644152374672038, 0.1462915257683822, 0.20894012121217592, 0.16303040113832268, 0.11307132656552962, 0.13868601673415729, 0.16895794735423156, 0.13164465528513702, 0.294992203691176, 0.242119805089065, 0.11028521428150789, 0.14362526312470436, 0.24822982294218882, 0.10415845018412385, 0.10748815722763538, 0.1178109140268394, 0.1660846501056637, 0.06948898839099066, 0.13058931619993278, 0.06980525356318269, 0.12270909547805786, 0.10872011897819382, 0.08915440565241234, 0.17879746508385452, 0.08904726497296776, 0.08866781461983919, 0.15921894780227117, 0.16356664736356052, 0.13747853652707168, 0.20720980263182096, 0.11512763372489385, 0.08651890778648001, 0.11432242978896413, 0.10356270322310072, 0.10062290275735514, 0.11039461448256459, 0.0887039058974811, 0.06276835687458515, 0.12511663271912507, 0.156369399279356, 0.09997138700314931, 0.11055841283606631, 0.1856643616088799, 0.11263678595423698, 0.24617701023817062, 0.14702572779996054, 0.2496943457850388, 0.13659770307796343, 0.11385728046298027, 0.08573030081710645, 0.11903987665261541, 0.10797438185129847, 0.1148323624261788, 0.11364457330533437, 0.1235167421400547, 0.13872387898819788, 0.12872570620051452, 0.16997769049235753, 0.1117263955197164, 0.07514636231852428, 0.08705346445952143, 0.08820694006447281, 0.23434680647083692, 0.13303980470768043, 0.13429073829736027, 0.16993973324341433, 0.13929534118090356, 0.07598290778696537, 0.047019080724567175, 0.10363409189241272, 0.17013190793139593, 0.12942995769636972, 0.11031295957842044, 0.17054424009152822, 0.1427211287830557, 0.14482852284397396, 0.08910990732588939, 0.13383271358907223], [0.04046262754127383, 0.030554408141012703, 0.032654348494751115, 0.031196424404957464, 0.09304008393415383, 0.008225546700746884, 0.021365471483607377, 0.03361510997638106, 0.013073376612737775, 0.034513598906674554, 0.05485309321167214, 0.03235506366140076, 0.027052629705784575, 0.030455854322229112, 0.05860870650836399, 0.03227645877216544, 0.022753438612978374, 0.040438067966273854, 0.025733026675879955, 0.03125430344204817, 0.07421551405319146, 0.03373581457084843, 0.021942292406622852, 0.03267818542995623, 0.04325867357796856, 0.044579102724258385, 0.048302438110113144, 0.034094233731073995, 0.026731143206624047, 0.017326773377135396, 0.01760493541535522, 0.030927575259868587, 0.021357675116243105, 0.030524240474083593, 0.03016410462026085, 0.01749661408497819, 0.031386064764644415, 0.03148301045543381, 0.020352593423532586, 0.015450372992615615, 0.031478348919855695, 0.03181213725890432, 0.04870030051097274, 0.03540327027440071, 0.05929564857589347, 0.030324832602803196, 0.03831785977152841, 0.09544120223394462, 0.008119249949231744, 0.02528038444662733, 0.0030210321336718543, 0.01855837380779641, 0.020882768456691077, 0.0036325155940305975, 0.042296741623431444, 0.004484879410093916, 0.03534654813951679, 0.0549678741954267, 0.06458609790674277, 0.029181762332362787, 0.012025552302865046, 0.01202906372158655, 0.009260022530465253, 0.04253381836627211, 0.05782403504209859, 0.02985772570329053, 0.04246875025065882, 0.028892241617930785, 0.059299848707658906, 0.03818837832659483, 0.022095305446003164, 0.049375843190188916, 0.03086029172741941, 0.005819075607827732, 0.04261614502008472, 0.050093560213489194, 0.01757566680732582, 0.10283310165894882, 0.015982229096282805, 0.028275527924831425, 0.056644524048481665, 0.01612934736268861, 0.04626934702641197, 0.041989151521452835, 0.024216283777994767, 0.015200024104810186, 0.012283392217276352, 0.054812774660864046, 0.016393633359777074, 0.008772275443854076, 0.01564824398207877, 0.08684027554201228, 0.015661131058420454, 0.04052546666935086, 0.008792634038919849, 0.009592047526634164, 0.018917987189654793, 0.03681281142468963, 0.030431935962821757, 0.02746866666711867, 0.024947461239727478, 0.029471544282776967, 0.06839242151805333, 0.10002448236835854, 0.1006616810336709, 0.021992276688771586, 0.05929598105805261, 0.061841715526367934, 0.0794458044692874, 0.03609746588127954, 0.04529894016949194, 0.009863531083932944, 0.0694041308015585, 0.015690236818045378, 0.015745959810114334, 0.02625017722935549, 0.03976107322211776, 0.05635639772351299, 0.0321866614477975, 0.07227556886417524, 0.03272657176213605, 0.009968250241529728, 0.09787178930959531, 0.07375210856220552, 0.06357340474746057, 0.017851937429181168, 0.0034321827947029044, 0.03212958647470389, 0.016776859760284424, 0.05202210262151701, 0.02616274120685245, 0.013928557197297258, 0.08545980961727244, 0.015350039715745618, 0.025545109795140367, 0.05003967435498323, 0.037679354926305156, 0.0489251296967268, 0.06202563922852278, 0.0458947685547173, 0.07516618232641901, 0.02162189325982971, 0.00932060637777405, 0.11086553814155714, 0.010505816217378845, 0.04251518579466002, 0.0304631383956543, 0.0525759500451386, 0.04515731634039964, 0.0391510363136019, 0.031105633026787212, 0.02739502356520721, 0.012558688293211162, 0.00987176171370915, 0.003554600053965779, 0.021690496542890157, 0.04351697828886764, 0.0810621427372098, 0.022789976027395045, 0.012435327234145786, 0.0418410171488566, 0.05868228684578623, 0.027988556805731993, 0.06058694821383272, 0.06263567613703863, 0.07017094322613307, 0.0285578324193401, 0.017518834410501376, 0.05179438287658351, 0.015191891862611686, 0.04040550507072892, 0.050918265245854855, 0.03700658066996506, 0.06198633848024266, 0.07012220405574356, 0.021250709159565822, 0.07186309421168906, 0.02688437676988542, 0.03385497210547328, 0.041651047699685605, 0.021452527526499968, 0.018249864290867533, 0.0493645557601537, 0.0653454057340111, 0.011615700188225933, 0.028803180504058088, 0.10955770260521344, 0.03503379099337118, 0.047092678025364876, 0.04097131167405418, 0.02702715410850942, 0.02630282306511487, 0.015554467049826468, 0.04785949723528964, 0.005524483692300106, 0.003175546007696539, 0.024501314286940863, 0.06782130537820713, 0.057031716486173015, 0.048658702921654494, 0.0228750405700079, 0.04330448826242771, 0.03291125881618687, 0.04596003005281091, 0.064504056237638, 0.021886218272681748, 0.03221451531031302, 0.06436302273401193, 0.017626351676881313, 0.02908890481506075, 0.036579086644841094, 0.016088901586564522, 0.04600077268800565, 0.05010197065504534, 0.018558350059070756, 0.02877039708463209, 0.024974868965468237, 0.01587565499357879, 0.023939765490857617, 0.014390257020880069, 0.033469791524112225, 0.006061412693400468, 0.0199423782926585, 0.022516736760735512, 0.06386934779584408, 0.048280436612133465, 0.024766502735604132, 0.03547164285555482, 0.031489442967410596, 0.01981825557803469, 0.028348673999841725, 0.02153346996887454, 0.04904012781168733, 0.027635531998904686, 0.012284397297272725, 0.0029652828483709265, 0.052889782669288773, 0.022263502402763282, 0.05974939851356404, 0.06600861264658825, 0.09642410092055798, 0.043658564798533916, 0.02951079753360578, 0.0158385747511472, 0.03766414895653725, 0.03626795459006514, 0.07264386410159723, 0.0720337593395795, 0.03386203565501741, 0.008792497483747346, 0.02172916116459029, 0.02204502260844622, 0.059989016370049546, 0.044186943410230536, 0.04255299037322402, 0.04041378998330661, 0.0392558122985065, 0.018855175202978507, 0.0305723316435303, 0.021721578535756896, 0.050723179642643244, 0.022459834814071655, 0.033632714567439895, 0.08957313639777047, 0.055683145099984746, 0.03478885002966438, 0.05930624729288476, 0.016513442288019826, 0.02350060235975044, 0.06939482130110264, 0.04328776237421802, 0.018483599248741354, 0.029547848938299075, 0.02832133412760283, 0.0070483104957799825, 0.05313535467056291, 0.007890050149788814, 0.017389719374477863, 0.10517839688275542, 0.02635427637557898, 0.009416545292229524, 0.011367797419162733, 0.0355019258734371, 0.021935915873785104, 0.05357041096846972, 0.036647652608475516, 0.03144758414211018, 0.01789717366253691, 0.03966043290815183, 0.026739613019994328, 0.023661791746105467, 0.014027751383504697, 0.025370424347264425, 0.04733492859772273, 0.04593532459278192, 0.059391193091869354, 0.05405183156420078, 0.04948308904256139, 0.03380073340875762, 0.032249850021409135, 0.0144026911750968, 0.004515768020480339, 0.04069820132904819, 0.04797338255281959, 0.02245770251777555, 0.0325956687863384, 0.029516107070126703, 0.05217022342341287, 0.02346323543627347, 0.008918357248018895, 0.03129307832568884, 0.023157826824379817, 0.06809919260974441, 0.02210562426729926, 0.029851944584931647, 0.05251330769221697, 0.034485334530472755, 0.02444607644741024, 0.01243975806781756, 0.05080616108274885, 0.037276033711220534, 0.04137428344360419, 0.03343315741845539, 0.05853718891739845, 0.026348932912307124, 0.02673650363327137, 0.0493677177333406, 0.027499446711902107, 0.01929792608799679, 0.051717131664710383, 0.017860205378383398, 0.07306146169347422, 0.023554639192298055, 0.03280519700742193, 0.04272496507370046, 0.03140207140573433, 0.015192053014678615, 0.005046622860910637, 0.030275306331792047, 0.023781146055885723, 0.0347357241303793, 0.04783510390136923, 0.02397034197513546, 0.020500405491994958, 0.04776370166135686, 0.03821849510339754, 0.03243795010660376, 0.04205445712432265, 0.023328637837299278, 0.04409482888877392, 0.03976802820605891, 0.03922508144751191, 0.16434879467955657, 0.18371714252446378, 0.12047434039413929, 0.22402318114680903, 0.17961914385003702, 0.10616180447063275, 0.1171551506434168, 0.2324902532356126, 0.12950801636491502, 0.06889258325099945, 0.19134455466909067, 0.10698984110993998, 0.1793195977807045, 0.13096871227025986, 0.12337549829057284, 0.1987527185784919, 0.09079000074416399, 0.13704428768583707, 0.11074074198092733, 0.10601249283977918, 0.24429399413721903, 0.11839313778494086, 0.12179702227669102, 0.1714983553226505, 0.31538212671875954, 0.12958446012011596, 0.1712209837777274, 0.15154076766754898, 0.15178966788308962, 0.13216781935521535, 0.11153584253042936, 0.11521212490541594, 0.10297279166323797, 0.1215066092887095, 0.13987103743212564, 0.07338300586811133, 0.16546441481581756, 0.07589530213070766, 0.10109445066856486, 0.0962739818330322, 0.12126159029347555, 0.11769846720354897, 0.16590282986206667, 0.10314742622098752, 0.20458894755159104, 0.11487227385597569, 0.16344077911760124, 0.16440732511026518, 0.10629895675395216, 0.15167222704206193, 0.04791176478777613, 0.08859085517802409, 0.08835004309990577, 0.15625311194786004, 0.1282005472374814, 0.19269321087215627, 0.15088276511856488, 0.07615989686122962, 0.14212404510804585, 0.17573306523263454, 0.13538357322769506, 0.06707605001117502, 0.10390091900314603, 0.16669253605817044, 0.14508931099304131, 0.11383464453475815, 0.05226770515686699, 0.07439418589430195, 0.1416288638221366, 0.1343223037464278, 0.13702199102512427, 0.23599958206926072, 0.0983464177697897, 0.14375427977315017, 0.14531647094658443, 0.11008891410061292, 0.10132903379521199, 0.20220218705279486, 0.17668100579508714, 0.1772297913474696, 0.1646933276206255, 0.14773946521537645, 0.14236968835549696, 0.0914775263518095, 0.19625233060547284, 0.08017149767173187, 0.1223531360072749, 0.13772696176809923, 0.159572355981384, 0.13012720671083244, 0.13393206468650273, 0.1408929383116109, 0.14622156880795956, 0.17273142987063952, 0.0942581764289311, 0.11252167248832327, 0.16637319033699377, 0.08093139582446643, 0.08374802182827677, 0.13426590391567775, 0.13688252493739128, 0.09565059135534934, 0.2949875625116484, 0.3637813782053334, 0.14093408467514174, 0.14173601807228156, 0.11172314533697707, 0.16872791041220936, 0.23754297782267841, 0.10680603275873832, 0.13449888569968088, 0.1557359325566462, 0.10327465832233429, 0.20934076899928705, 0.07425998523831367, 0.10503971111029387, 0.14235052652657032, 0.11032976689083235, 0.15252636692353658, 0.2123740648052522, 0.13566686159798078, 0.12312505101518971, 0.2691745976252215, 0.17985673967216695, 0.14176955127290317, 0.1031899092985051, 0.06049910507031849, 0.12331879990441458, 0.07844689914158412, 0.29830513734902653, 0.089989661904318, 0.09629418182053737, 0.21273952376629623, 0.12404027261904307, 0.07943319050329072, 0.15598309572253907, 0.16202448654387677, 0.17013295287532465, 0.18594220812831605, 0.19233009964227676, 0.21219904348254204, 0.0643121258222631, 0.09577508217522077, 0.18943142518401146, 0.07738002496106283, 0.11877831497362681, 0.1469070655958993, 0.14534909491028103, 0.1020330817305616, 0.11085849494806357, 0.14056705151285442, 0.09321129867540938, 0.09158219716378621, 0.08849244724426951, 0.05929201162819352, 0.22822400501796178, 0.14524932312113897, 0.13233985512384347, 0.0964685178228787, 0.11022861089025225, 0.13879728290651525, 0.1206922179886273, 0.12282990185277802, 0.177855821326375, 0.2789399107652051, 0.10427120234817266, 0.06577366311103106, 0.12235257960855961, 0.09236015791871718, 0.10207491341446127, 0.08174001957689013, 0.1418739506708724, 0.1541546338370868, 0.08639413198190075, 0.09664572402834892, 0.06790074147284031], [0.030310579974736487, 0.06760266782449824, 0.04848292163972344, 0.053022307343780994, 0.10583894393805947, 0.032471276354044676, 0.014008966141513415, 0.029853783414832184, 0.02919988600271089, 0.05362913817433374, 0.039360422042331526, 0.1342660803347826, 0.05456785066053271, 0.019392373073580008, 0.06199819927236863, 0.03392252365925482, 0.0798471715035183, 0.03697459792186107, 0.02872396832598107, 0.03453042318246194, 0.01616119610012642, 0.03993918527183788, 0.03256890397252781, 0.029938057464148318, 0.05946334172040224, 0.04130409238860011, 0.04616057447024754, 0.02664078269819064, 0.08644245046057872, 0.04934875946491957, 0.05725002834307296, 0.04555875462080751, 0.05501864557819707, 0.0436439627249326, 0.02204613370953926, 0.07541569322347641, 0.06248216437441962, 0.02677861860554133, 0.044294002665472884, 0.06638678735388176, 0.020330836198159626, 0.02290494360827974, 0.0517515130341053, 0.05295375495084694, 0.07703408066715513, 0.08827311758484159, 0.026436631867129887, 0.045411444668258936, 0.06842053322387592, 0.03656844721574869, 0.022295882093853185, 0.07184281279998166, 0.012633394998764353, 0.009750532950939876, 0.05038241935627801, 0.021819784605343426, 0.036984012595244815, 0.04638990234317524, 0.042079023484672816, 0.021692684818325297, 0.03395096106188638, 0.06040172850979226, 0.013244783040136099, 0.008810381970501371, 0.016531672827633362, 0.032033987675926516, 0.04288004085953746, 0.03246750369934099, 0.024158844092328633, 0.0010209361935267225, 0.017283260622727017, 0.019347191123025756, 0.04007827137996044, 0.04937604675069451, 0.03670984712828483, 0.04835395248872893, 0.017139044789863483, 0.03043690962450845, 0.041011806643967114, 0.005326812022498676, 0.059965837613812516, 0.014860887213477066, 0.017995177867955396, 0.019509226981816546, 0.03294793702661991, 0.02468577742443553, 0.04193768464028835, 0.05120663584343024, 0.051221909666700025, 0.045247490251702924, 0.03788286454177328, 0.04431021625974348, 0.052385162961270125, 0.013414186941060637, 0.058375331174050055, 0.05413240420499018, 0.007577762040974838, 0.052960292635751624, 0.0522919492130833, 0.04424832708069256, 0.035178634471126964, 0.05201463195096169, 0.008983542410922902, 0.07403783965855837, 0.03791853512770363, 0.031423401154045544, 0.027368333390248672, 0.05379068718424865, 0.04158587780381952, 0.04665507382846304, 0.020755785716963664, 0.018863434670493007, 0.053555564622261694, 0.032880069954054694, 0.011929848331159778, 0.011070448106953075, 0.010429150241959308, 0.06475071728761707, 0.04619191600275891, 0.037275531595306735, 0.034027686409120045, 0.13240557802574976, 0.023009704326146414, 0.07082469136055027, 0.050797916882272275, 0.04869091297898974, 0.034934728273323605, 0.05461875775030681, 0.016952452748747807, 0.013334604961398457, 0.03877422206902078, 0.023444628309724585, 0.0357824593915471, 0.03811316271977765, 0.014478659955784678, 0.034696613371904404, 0.1440548707864114, 0.0627032650102462, 0.07263571489602327, 0.026276411089513983, 0.07939209163721118, 0.04082055815628596, 0.08169214893132448, 0.07010485391531672, 0.029691416770219803, 0.014930187691269177, 0.036727231195462604, 0.02716833519350205, 0.06859782763889857, 0.011943078067685877, 0.06782332062721252, 0.04145221997584615, 0.05582990204649312, 0.04473514202982187, 0.008449809309760374, 0.04302971889930112, 0.049685662279703786, 0.048956752821270905, 0.03742759468566094, 0.04170523211359978, 0.006824529222545347, 0.03563462357435908, 0.05445364982421909, 0.023502453064013804, 0.05967606244874852, 0.026824039739689658, 0.03906557143532804, 0.04653925468612995, 0.06473560631275177, 0.05601829390174576, 0.02771031334330993, 0.03733908657782844, 0.023349417972245386, 0.042283048786755116, 0.05389952759391495, 0.04606469068676233, 0.03904391938288297, 0.07617250404187612, 0.00927229892529015, 0.019934707454272678, 0.05380115019423621, 0.05507782740252359, 0.029558783530124595, 0.06499718156244073, 0.008843876155359405, 0.03750328187431608, 0.018993959363017763, 0.03594167424099786, 0.06512760956372533, 0.004938474132878972, 0.031726319542420764, 0.030764472404760972, 0.04028731105583055, 0.07813776537243809, 0.04293726511033518, 0.06042352983994143, 0.017003962038350955, 0.06095317391944783, 0.03532614798418113, 0.03791550546884537, 0.01871780409211559, 0.022958340921572278, 0.019202591917876686, 0.0336742782300072, 0.055489090870001485, 0.041093247809580395, 0.026564856325941424, 0.04516473612082856, 0.08025325435612883, 0.022907270983393704, 0.016572166101208756, 0.034929245710372925, 0.04167160391807556, 0.05932642013898917, 0.004515281595688845, 0.05353060471160071, 0.05575560246195112, 0.021734601319102303, 0.04160840855911374, 0.033084753435105085, 0.032132497389933894, 0.023136446185942208, 0.043120459387344975, 0.018299655190535953, 0.07916537273143019, 0.017730130215308497, 0.055078159884682724, 0.05434904347306915, 0.012301444641447492, 0.02373947382771543, 0.026155216253495643, 0.016137786641983048, 0.05772579674209867, 0.04242110012897423, 0.037926426489970515, 0.03084124524944595, 0.01895286049693823, 0.04162531765177846, 0.062189919341887744, 0.04232486689995442, 0.041627458429762294, 0.02337041693473501, 0.06971603299358062, 0.04064301946865661, 0.038408145641109774, 0.024660101659329872, 0.05742593854665756, 0.01051116646600089, 0.03602778372753944, 0.02668058216970946, 0.06081941431122167, 0.03195697734398501, 0.024800985885251845, 0.025786111863063912, 0.03733587371451514, 0.0015511708105415373, 0.04228571203670331, 0.02540215094839888, 0.019858950715778128, 0.05351537838578224, 0.00888653310747551, 0.027951152562829, 0.04495446829657469, 0.04557406576350331, 0.08414171463144676, 0.008435957017354667, 0.0025984666052473976, 0.006585130193603358, 0.017286230909771154, 0.019507520466244647, 0.026377007298703705, 0.02562621678225696, 0.07489318733236619, 0.008349236001127532, 0.056205087807029486, 0.06455892936459609, 0.07412258868238755, 0.04310067669887628, 0.051304314352039776, 0.08634499247585024, 0.03452409923608814, 0.04052069317549467, 0.0208343108783343, 0.05126411793753505, 0.054953041419919045, 0.02309467557019421, 0.012869162169019026, 0.0227506888498153, 0.025643678880961876, 0.016214447528389946, 0.033038412886006494, 0.03817856331755008, 0.017775183244209205, 0.03127038132931505, 0.02490838271166597, 0.03653366890336786, 0.04930889553257397, 0.011721375232030238, 0.02412901908558394, 0.05205165960692933, 0.06343841699085065, 0.04469444689207843, 0.01728631742298603, 0.02237960313712912, 0.020773722790181637, 0.03288767633161374, 0.04571948938870004, 0.05536372134728091, 0.04505091526412538, 0.06536083562033516, 0.03591064822727016, 0.011791171888554735, 0.056438483497393985, 0.011508928462197738, 0.03845598914527467, 0.02732747031508812, 0.02725474662812693, 0.013088658917695284, 0.0420498634422464, 0.01620649509797139, 0.03497178985604218, 0.03282216716823833, 0.03353910387626716, 0.03726205928251147, 0.00833035830873996, 0.027924828796780536, 0.05646214062081916, 0.006091823784767517, 0.0432544870169035, 0.04002924722486308, 0.02416008411507521, 0.038444250489452055, 0.05057274842900889, 0.051192311969186576, 0.05310782650485635, 0.04120306530967355, 0.0668630917955722, 0.03476589179730841, 0.024657655540587645, 0.03346281957679561, 0.057302587665617466, 0.02882001156519566, 0.04013680859601923, 0.027145826490595937, 0.02002791441710932, 0.0631449098831841, 0.028027438558638096, 0.03533497911744884, 0.0335599179379642, 0.027021065953054597, 0.03207462513819337, 0.03199974201353533, 0.12857021311564104, 0.2021943839000804, 0.15787296502717904, 0.12703274775828632, 0.18927218658583506, 0.11300458586109535, 0.10463835764676332, 0.1370493359863758, 0.06663635931909084, 0.13336991199425288, 0.13786431082657405, 0.17316770074622972, 0.18221254540341242, 0.07501640929175274, 0.12115952505597047, 0.16221212861793383, 0.19805120836411202, 0.17625964911920683, 0.09251043306929724, 0.12242240086197853, 0.08713911593492542, 0.1672627226050411, 0.16652210163218634, 0.0717879261023232, 0.1250003453876291, 0.24493265843817166, 0.09751229467136519, 0.16380611594234193, 0.2078097090125084, 0.10736000231866326, 0.09183375045124974, 0.10569513522620712, 0.23525788901107653, 0.10134801920503378, 0.10362357459962368, 0.14525215939751693, 0.10305798852017947, 0.170163093400853, 0.10786162968724966, 0.15229570572929724, 0.14803215808102063, 0.151056293664234, 0.15436199413878576, 0.09339843184820243, 0.09386690599577767, 0.16043732528175625, 0.09227034702364888, 0.1467804509614195, 0.10501429997384548, 0.16337426911507333, 0.19029967859387398, 0.11905103176832199, 0.07453379447438888, 0.1832678709179163, 0.13559970020183496, 0.10456362379980938, 0.11398682636874062, 0.09588545946670429, 0.11855111430798258, 0.09922921897045203, 0.10823354830167123, 0.1283596229872533, 0.11307662592402526, 0.1788655085755246, 0.12567029015294143, 0.15296323490994318, 0.12215892571423735, 0.09650843603802578, 0.13385213326130593, 0.06068051140755415, 0.1459576729685068, 0.09083129638539893, 0.12551512276487692, 0.15363487601280212, 0.1308668777346611, 0.10595406418932335, 0.0953263941087893, 0.09921507151531321, 0.11817395740321704, 0.09406716203583138, 0.08921389960284744, 0.1094427587730544, 0.11216977065695183, 0.10804420989006758, 0.2509058564901352, 0.137910627626947, 0.1178171836904117, 0.1387859649424042, 0.2039642475013222, 0.17084293120673724, 0.12629463736500057, 0.07688740853752409, 0.08442889100738935, 0.11738060068871294, 0.19369539352399961, 0.11998978496662208, 0.13989835525197641, 0.1362982520035335, 0.13491876316922052, 0.13561097745384487, 0.23721877379076822, 0.13933783104377134, 0.11368373834661075, 0.17321487250072615, 0.1044295724215252, 0.10327836312353611, 0.08500620217195579, 0.14419368548052652, 0.11150816508701869, 0.18228907058281557, 0.07219504032816206, 0.20651646197906562, 0.13169912807643414, 0.13121744963739598, 0.10045325543199267, 0.0896075109818152, 0.11103603363569294, 0.1490012010825532, 0.1764193626918963, 0.17472985120756285, 0.11193542501756124, 0.2598825490900448, 0.07993261263306652, 0.17408415728381701, 0.1379775990332876, 0.12601400885198796, 0.1254368062530245, 0.14102312204028877, 0.11972067797822611, 0.10392196037407432, 0.09696481869156871, 0.1096209759957024, 0.08594694347786051, 0.16935996578208037, 0.07386826697204794, 0.1310240535863808, 0.26248497515916824, 0.08054468514663832, 0.1356344683361905, 0.10862513764628343, 0.17957951740494796, 0.06160212481128318, 0.12820904249591486, 0.0764166002294847, 0.10471652488091163, 0.08536378334143332, 0.1007581687133227, 0.13713973042156014, 0.13055560658020632, 0.07742667424359492, 0.1629972072052104, 0.1105536495202354, 0.1390114285584007, 0.09960220288485289, 0.1741180026105472, 0.06850488191204411, 0.10111776513180562, 0.12095584241407258, 0.18652500185583318, 0.17045278714171477, 0.1287255569228104, 0.09789219285760607, 0.15087147429585457, 0.12089486925729684, 0.1256194950214454, 0.12035632958369595, 0.07849106498594795, 0.08927141901637826, 0.12495234582040991, 0.17303507429148468, 0.06140186198587928, 0.12764695765716688, 0.17773823120764323, 0.13689429073461465, 0.11942941003612109, 0.17699693169976982], [0.018782646594835178, 0.06385682882475001, 0.06837222831589834, 0.048377772460558584, 0.0053273832641675, 0.025864307934950505, 0.02336318205509867, 0.04248900791364057, 0.018474018334278038, 0.09060539172164031, 0.03167679327140961, 0.039118870361042876, 0.027671628365559236, 0.03821765371997442, 0.0287152186169156, 0.07860915722059351, 0.037157751486769745, 0.013505154738335736, 0.0435475734328585, 0.05954211963606732, 0.08131664086665426, 0.017321918459076966, 0.0047891968528607064, 0.07679155868078981, 0.055168849482600174, 0.043460334185510874, 0.018835609645715783, 0.021175824338570237, 0.07886839152446815, 0.03461138937356217, 0.03757836855947971, 0.026618850750050375, 0.0710466198090996, 0.028619443399033377, 0.026410939138648764, 0.01612739827084754, 0.011269494658336043, 0.021130355706970607, 0.12346712765949112, 0.010118717078252562, 0.015906815017972673, 0.017177709411563616, 0.008414645928756466, 0.014363687285887343, 0.05852676661951201, 0.026574425366041914, 0.026424925441720655, 0.0929785000958613, 0.028325992270505855, 0.03370474445234452, 0.06236460818243878, 0.07001445948013238, 0.03328407309683306, 0.01394615161033081, 0.043129809599901946, 0.02708680581833635, 0.01352165755815804, 0.06770628012184586, 0.07732732314616442, 0.05528170003422669, 0.022082187667755142, 0.08705260950539793, 0.024837777750300508, 0.06158274585115058, 0.027052616135084202, 0.08296121297670261, 0.019507761346176267, 0.023366140467779975, 0.02530920522154442, 0.05915517147098269, 0.04270818490268929, 0.03857005088190947, 0.011947040712194783, 0.0715571359864303, 0.020320741293419684, 0.027158644017098204, 0.02684487246109971, 0.02091195564051824, 0.013184559664555957, 0.09338592644780874, 0.06498660998685019, 0.05745647940784693, 0.05026282077389104, 0.014552883205137082, 0.03130169911310077, 0.033056183718144894, 0.01778585320737745, 0.022452674573287368, 0.02007061123315777, 0.07290641644171306, 0.04797662255753364, 0.030601196523223604, 0.05353022473199027, 0.016182670037129095, 0.022083280109135166, 0.030560073908418417, 0.007339045787895364, 0.06946623711181538, 0.07445439230650663, 0.07319011193300996, 0.03608628023149712, 0.039352618889617066, 0.036989379807242324, 0.02629696561156639, 0.009636178596078284, 0.02288219572177955, 0.03812417534313031, 0.008836631097697785, 0.04416151870308178, 0.022591277225209132, 0.012559431289056582, 0.029751097317785025, 0.06922233091401202, 0.09640299169612782, 0.04105432364823563, 0.0803726968754615, 0.017037337479580725, 0.02471928857266903, 0.024828003453356878, 0.05644066498747893, 0.021908820274152925, 0.008509158223335232, 0.05435167279626642, 0.02778570367289441, 0.04071287464882646, 0.013405097116317068, 0.03642070639346327, 0.0034450556642176317, 0.041170634728457244, 0.07722686603665352, 0.01631706577193524, 0.012295634685350316, 0.009436480651077415, 0.047055558767169714, 0.038380909245461226, 0.030558116334889616, 0.03690149934430208, 0.04720701796135732, 0.04270726888041411, 0.007069197075907141, 0.03177778981626034, 0.02578603383153677, 0.012367158213497272, 0.030260134288775067, 0.0183958460111171, 0.023243079660460353, 0.0326917561303292, 0.03315481896113072, 0.042977570090442896, 0.053584901083792956, 0.03567096930263298, 0.023688675303544317, 0.052550749254545996, 0.052801668111767085, 0.02939887996762991, 0.02601696813612112, 0.03561698505654931, 0.023906515578606298, 0.08078858455909149, 0.04533166930611644, 0.07872687626097884, 0.07171919050493411, 0.05238915613985487, 0.04493185950975333, 0.03566848925713982, 0.03470183130619781, 0.088794320688716, 0.06833762302994728, 0.005933033019703413, 0.07116566877812147, 0.027411757935104624, 0.08133128365235669, 0.02250531192735902, 0.10674259651984487, 0.01635216808478747, 0.029324444676084176, 0.008141445677860506, 0.013541376633968736, 0.029103211725928953, 0.05749409060393061, 0.0025450217945035547, 0.04274350943576012, 0.018823263701051474, 0.06034399875040565, 0.036981481659625254, 0.006067441477041159, 0.017509312867852192, 0.04782078341980066, 0.022239081927442124, 0.06833334147397961, 0.008208985357279224, 0.03162281241800104, 0.024142747545348744, 0.030453221606356756, 0.03530961208577667, 0.030959415515618663, 0.09030511961983782, 0.023434803122654557, 0.04805251330669437, 0.018561498461557285, 0.11319121013262443, 0.014509007434493728, 0.03540683597592371, 0.013042340420984795, 0.09262401983141899, 0.027571912555556213, 0.033447532182825465, 0.02883649318079863, 0.053891670158399005, 0.060922802692013125, 0.0066089946942936096, 0.06299751172108309, 0.02780033628057156, 0.037773844320327044, 0.08197879604995251, 0.026401836591373597, 0.020770092627831867, 0.017285336939884082, 0.013814859325066209, 0.03476831077464989, 0.04437428353620427, 0.02315818814427725, 0.04600115945296628, 0.048799709283879826, 0.03860228468797036, 0.046373743031706126, 0.02252061289202954, 0.053827148263475726, 0.0419528702540057, 0.037072537666452784, 0.05379169141607625, 0.047438466256218295, 0.03497898232723985, 0.008727595609213625, 0.03780492122418114, 0.07418482391429798, 0.05156603209408266, 0.022571145091205835, 0.007960813718714883, 0.028938063087740114, 0.100878106563219, 0.016666652102555548, 0.040061915293335915, 0.05811286025813647, 0.04962445502834661, 0.048126290419272015, 0.08027763411934886, 0.025444364308246543, 0.03485779597290924, 0.03708364189203296, 0.0507890212881778, 0.020717911588560258, 0.038367287654961856, 0.00903318912189986, 0.031020046012209992, 0.04625174243535314, 0.026366679995719875, 0.02857274661904999, 0.05327670708564775, 0.009158886037766933, 0.01965776508274887, 0.05006061055298362, 0.007251909168969307, 0.01810631511865982, 0.05182976169245584, 0.0732218266597816, 0.08172646923256771, 0.021173785340839198, 0.03239939574684415, 0.04562202122594629, 0.023910388317225233, 0.007834568885820252, 0.012822056571686906, 0.032242369172828536, 0.010571199851775808, 0.03910579838390861, 0.06909901395972286, 0.006100868656566101, 0.013151949271559715, 0.0178142685576209, 0.02981407554554088, 0.0035048863376557294, 0.0022053866040161146, 0.03360092180914112, 0.058456375396677425, 0.011659329141756254, 0.014596874326733606, 0.09648295704807554, 0.033756211333509, 0.01132922015884625, 0.05453812064869063, 0.08113195041992835, 0.03530662313901952, 0.04399325219648225, 0.020033987305526222, 0.050095056383205314, 0.016306075200970684, 0.03465096153584974, 0.03163470035152776, 0.06948647781142167, 0.03097839414009026, 0.017824134456792047, 0.023989817626508217, 0.01893957987028573, 0.02130761619524232, 0.05934194502021585, 0.04813425302771585, 0.04583448411098548, 0.019183209565068995, 0.04659596325031348, 0.028147846294034804, 0.009901108353265693, 0.03205555151881916, 0.0473586908940758, 0.017484134129647697, 0.07564066150890929, 0.02917196089401841, 0.020519036367269497, 0.06406395842454263, 0.02125962680604841, 0.047946865404290814, 0.044249178642140966, 0.019257414154708385, 0.031227616659764732, 0.0017593985768533976, 0.05467064532318285, 0.057450135105422566, 0.04162812678675566, 0.03129502572119236, 0.008553628560288675, 0.0038607531460002065, 0.04085173684039286, 0.038156751809375625, 0.012703564849549105, 0.04269539112491267, 0.023990407951974442, 0.040909856757415194, 0.026688420945512395, 0.037881653356764994, 0.03248649250183787, 0.029221795898463045, 0.016369341806109463, 0.04676917288452387, 0.022144171841708676, 0.03542746344049062, 0.14751549437642097, 0.01759151738536145, 0.031472401560417244, 0.03720767130809171, 0.10292737731443984, 0.03241786207737667, 0.027375171326899102, 0.10539440172059195, 0.16507298153425964, 0.11266314025436129, 0.15833647229841777, 0.09358768883560385, 0.10102803566093956, 0.11677369182663304, 0.15202792866953782, 0.07644846423396043, 0.14165368463311875, 0.12192115347300257, 0.09832858586949961, 0.18383961809532984, 0.10371192664440189, 0.17476946408195154, 0.1799829336149352, 0.08947892859578133, 0.08344644693923847, 0.24667842047555105, 0.0961021360542093, 0.14764905720949173, 0.06537637407226221, 0.07668627718729631, 0.1333946649517332, 0.17964583741767065, 0.06953115934239966, 0.11057294705616576, 0.11630585550197534, 0.23845997718828066, 0.10265770035662822, 0.1543097198009491, 0.2990061997302941, 0.15500661597720214, 0.12492124177515507, 0.09980352422488586, 0.10847606350268636, 0.11035836714186839, 0.12408707796462945, 0.4070636342678751, 0.15424326408122266, 0.06550834234803915, 0.0759245537753616, 0.0715249055730445, 0.09083302664969649, 0.11273875619683947, 0.13371633126267365, 0.19869979284703732, 0.16270678064652852, 0.12695880101195403, 0.08545823541602918, 0.1700614895671606, 0.1604534201323986, 0.11777651230139391, 0.07747409027069807, 0.20772088877856731, 0.11709089337715081, 0.15064208874745028, 0.12243821072791304, 0.19399367751819746, 0.1233774796128273, 0.15298854426613875, 0.14247079007327557, 0.07470907364040613, 0.09820460395089217, 0.19406408231173242, 0.21933975602899278, 0.16518188640475273, 0.10334191471338272, 0.12028348206409387, 0.10468372449811016, 0.12960514186748437, 0.11126248112746648, 0.12558678963354655, 0.20154197247964994, 0.1764755861035415, 0.11222021295023815, 0.17227683854954584, 0.08047645166516304, 0.1054654104102935, 0.1766759982066495, 0.12834934996707098, 0.153988067060709, 0.12336386820035321, 0.08214608885880027, 0.15285153447517327, 0.1511516414050545, 0.09129762636231524, 0.16176394266741617, 0.060966446064412594, 0.32498958547200474, 0.1478397391204323, 0.08180092488016401, 0.1420945016933339, 0.11638882676405565, 0.10110769567212888, 0.13571838954729692, 0.10725937557539769, 0.12218747846782207, 0.2421044973390443, 0.15283609101814882, 0.11467564797827176, 0.16428514809480735, 0.13179953768849373, 0.10421875159123115, 0.0806970094729747, 0.055063995466168435, 0.1605179352419717, 0.10902598220854998, 0.13860012777149677, 0.15299467822270735, 0.08161953211362873, 0.12947631520884378, 0.18436639197170734, 0.17537919564970902, 0.13184793080602372, 0.2097543089517525, 0.10638966331524508, 0.11420065989451748, 0.1738391111471823, 0.10083661414682865, 0.0466339578186827, 0.07095952983945608, 0.22738686922405446, 0.15048708420779022, 0.18170265347829886, 0.0940412962809205, 0.11401801183819771, 0.08845861548823969, 0.14657724329403468, 0.1666663988892521, 0.13823207680668148, 0.1117062633857131, 0.06624184548854828, 0.13485503516026906, 0.07866713125258684, 0.14168324161853108, 0.10257215744682721, 0.09133949197296586, 0.14468421201620782, 0.1769784755472626, 0.12496468158704893, 0.04021683501611863, 0.1755998416670731, 0.07691096048802137, 0.22124508236135754, 0.08907507133803197, 0.19428149850240775, 0.13853682045425686, 0.10928970162889787, 0.1468243386064257, 0.13181741030088492, 0.10184822165008102, 0.1406272104276078, 0.13672657044870512, 0.1460729017853737, 0.07989829911717347, 0.12054459590997015, 0.08174046062465225, 0.14111731627157756, 0.0879026646060603, 0.18841317482292652, 0.13428733205156668, 0.24420668025101933, 0.11724570792700563, 0.10809934086033277, 0.09859098893191133, 0.15671330796820776, 0.11126696624393974, 0.0460069202152746, 0.1789987457117864, 0.07053557437445436, 0.14272567496768065, 0.1224980710872582, 0.15548967862767832, 0.09506656947944846, 0.07265143655240536], [0.039324873592704535, 0.07841520477086306, 0.018632873560168912, 0.01170047465711832, 0.024205045541748405, 0.02171624864318541, 0.027712174225598574, 0.040412700934601684, 0.035083337620432885, 0.014572969538026621, 0.05548708579902138, 0.01913106075621077, 0.06697839525129114, 0.05086701210322125, 0.05460445762478879, 0.031242802273482084, 0.003052517430790301, 0.06724860146641731, 0.03957979241386056, 0.017656305605279546, 0.05836684948631695, 0.0592994008745466, 0.01688695715607277, 0.09588662654693637, 0.08145318246845688, 0.06458630146724836, 0.016692884266376495, 0.042348635981657674, 0.05076497739979199, 0.05698813418192523, 0.03518613567575812, 0.043395812290587595, 0.012089616186650736, 0.09479322843253613, 0.024020031094551086, 0.05067557023305978, 0.011959672489735697, 0.01008739335728543, 0.04741632226588471, 0.03571339470467397, 0.024074261309579015, 0.040131617803126574, 0.01194702968600073, 0.01601008974414851, 0.04610604739614895, 0.05552148752446685, 0.024712282698601484, 0.07294572397534337, 0.024626607474471842, 0.044889651238918304, 0.029079313722572157, 0.041449047824633975, 0.03781766411183136, 0.03624507099656122, 0.06867731801633324, 0.011451079959182866, 0.03307188841115151, 0.022499193237828355, 0.07800346972154719, 0.04031803512147494, 0.01272829745097884, 0.017597391802285398, 0.06267843741391387, 0.021616085000070076, 0.052378391181784015, 0.015343999057742102, 0.010131589735725095, 0.05508509111989822, 0.0220200576087726, 0.004915336936911834, 0.04717526252248457, 0.04948311618396214, 0.010607593077501016, 0.03136424647111978, 0.010441156919114292, 0.030665725203497068, 0.020229983842000365, 0.020851062211607183, 0.03495937266520091, 0.0054148421872274154, 0.02787335343392832, 0.06367247086018324, 0.07449172530323267, 0.04317745632891144, 0.07084094227424689, 0.0343610099516809, 0.02649067378869014, 0.008373384214272457, 0.05743738543242216, 0.022980842839128206, 0.011726719543470867, 0.03651550112824355, 0.009894398490100034, 0.04900207896051662, 0.05115437168361885, 0.046447116415947676, 0.057599304243922234, 0.025004746558676873, 0.026596869608121257, 0.0800133990123868, 0.039642624756587405, 0.0911955882662109, 0.045602991711348295, 0.02262589438552303, 0.01758955472282001, 0.024609744182920883, 0.03525869481797729, 0.037473287233816724, 0.04663429030084184, 0.053251587719257386, 0.11420288548937865, 0.019137925834261944, 0.015254245838150382, 0.02009338795739625, 0.051124142948538065, 0.07415972490395818, 0.0508526271608259, 0.009208773628675511, 0.051826565792518, 0.013193060012002076, 0.010059134070096272, 0.0436150978452393, 0.04719065848205771, 0.030582346820405552, 0.031053524930030107, 0.024683553525911908, 0.04507116274908185, 0.03810252668336034, 0.048311384594334025, 0.04299025869529162, 0.009572396304325333, 0.040358614908265214, 0.01783605122805706, 0.02886304086340325, 0.07930846219616276, 0.04464779082419617, 0.04150306599746857, 0.04883202451414295, 0.009093531241108264, 0.017122055969334075, 0.014870461342590196, 0.013333651619697255, 0.043428660170840364, 0.0831108774457659, 0.009155238063872924, 0.0450119978881308, 0.06210007452006851, 0.0460860916812505, 0.06036563044680016, 0.016523594868236353, 0.005811412827045257, 0.033922367596200535, 0.05200795855905328, 0.030203541075544696, 0.02462466856065605, 0.03476364245372159, 0.0427732394476022, 0.04535074292549065, 0.040415394718625715, 0.03154180890747479, 0.028591399546712637, 0.04427048124905143, 0.043756124563515186, 0.04047879363809313, 0.03468347693394337, 0.040881229364978414, 0.0319448349598263, 0.06015666201710701, 0.04201892224539604, 0.02320615208840796, 0.05565741165940251, 0.027294208528473973, 0.04432653502694198, 0.021488026782338108, 0.04933734989858099, 0.030525862172778164, 0.007739654559242938, 0.06611954633678709, 0.10183334137712206, 0.00935845251660794, 0.032332315774900575, 0.043810539679335694, 0.01940724825752633, 0.021499699280996407, 0.023990341794810126, 0.03315263068569558, 0.031254364510199854, 0.054034145548939705, 0.043863394164613316, 0.03457666873665793, 0.058884761695350916, 0.024969406758568118, 0.02481928767104234, 0.009174789202266505, 0.018409978199218, 0.026351915073714087, 0.01775759392018829, 0.05631463050044008, 0.007546894634807748, 0.043495546760303636, 0.015487493947148323, 0.04898832166301353, 0.0237265121125217, 0.024161408954699124, 0.046459628601691554, 0.04767016221636108, 0.048347937275788615, 0.018161495282713856, 0.03768931921305401, 0.03608894008877022, 0.01974830201028713, 0.030189179881875004, 0.002407812895918531, 0.0129065765899473, 0.0305459739507309, 0.04846387855442507, 0.0173262678685465, 0.02604265238291451, 0.054445395445717235, 0.03468675086540835, 0.05200243528400149, 0.006944292773758727, 0.0818559540701764, 0.06395831052213907, 0.04429248274703111, 0.03864874058802213, 0.024040051270276308, 0.008732429323052722, 0.108906892527427, 0.06053276040724345, 0.005901679612829217, 0.05219929186361177, 0.023747538216412067, 0.024708391300269535, 0.05747726293546813, 0.05837592828486647, 0.042260935330497365, 0.04517564357125333, 0.040110087886984856, 0.05423549742304853, 0.03116557141765952, 0.03196707733773759, 0.05754487895007644, 0.06365284762744393, 0.030014331585594585, 0.011197755695320666, 0.03771231137216091, 0.04324821735333119, 0.06753138093543903, 0.04005072285820331, 0.024029098018737774, 0.027811079186254313, 0.005332014265669776, 0.016892083488138657, 0.04529417346098593, 0.014661879677857672, 0.029660132913185016, 0.025368697475641966, 0.019600886884810667, 0.0224859685903149, 0.03084292123094201, 0.03427298699638673, 0.06609393163983311, 0.040278792048671415, 0.02715056436136365, 0.06427500995674304, 0.015615854112963592, 0.04007298559216516, 0.030825357351984297, 0.07141132559627295, 0.052927777237657986, 0.022581611493868486, 0.03364940652889865, 0.053041374177805016, 0.031101806089282036, 0.06992411254239933, 0.041846784696515114, 0.012758197096575583, 0.02110524651860552, 0.09156102008585419, 0.007278069238444524, 0.02104670930254672, 0.0023260125308297575, 0.04154877211632473, 0.015825212700292468, 0.028881144177700793, 0.040030556797449074, 0.04283916251733899, 0.04328034598646419, 0.0071546623782653895, 0.03995388912569199, 0.08921510060983044, 0.04040837866653289, 0.07252666753317628, 0.07639547064900398, 0.03496701975486108, 0.0616958440680589, 0.04585526424593159, 0.020131238337074007, 0.022979161768619503, 0.03588681807741523, 0.03446150438061782, 0.03646230398278151, 0.024277589416929653, 0.041360634711704085, 0.034637913307441134, 0.04293642033423696, 0.030653386044182947, 0.020335401042497585, 0.06629297988755362, 0.023545501021934406, 0.04505128845838564, 0.05500927161691444, 0.04731611282165561, 0.02214957806946976, 0.01414650773429977, 0.041212354454078844, 0.005510756928872849, 0.08528327516147069, 0.030932040020291294, 0.03938201641930001, 0.05099898377167327, 0.039559728133359125, 0.019951947332758988, 0.0554571047292224, 0.0539337902196816, 0.010562429786659777, 0.03559993686420577, 0.03142160642892122, 0.10617096469338451, 0.0017607263850680152, 0.07231550065002271, 0.046722004522702525, 0.04846626699769071, 0.03692918357306293, 0.010902536134900791, 0.03538120770826936, 0.03276625249002661, 0.03754049612741385, 0.014559607487171888, 0.08001126841242824, 0.015851544948028665, 0.008744502157372023, 0.02201731293462217, 0.1025807409148131, 0.06102964481604951, 0.07348002959042788, 0.0770827859107937, 0.07246115497712578, 0.030966499421213354, 0.006889652469128902, 0.06672743907464401, 0.10986591356673411, 0.2009222393057176, 0.1444013850497348, 0.07364131057901041, 0.1434097196906805, 0.1215888884450708, 0.09979574142822198, 0.10888547796223845, 0.10394679475575686, 0.11226655010666166, 0.1917750851384231, 0.13432929265711988, 0.16671488700168474, 0.14178150705993176, 0.13480101020208426, 0.0696010213079197, 0.12247014258589063, 0.09421863140804426, 0.19579117106539862, 0.10852180354829345, 0.1588947166289602, 0.10920329697962318, 0.14743196671562536, 0.15476281834500177, 0.11390475077288491, 0.3053149197782789, 0.11949659857366766, 0.1280054005661181, 0.1229695307889155, 0.11248771181063992, 0.13359605414526804, 0.09691675127084766, 0.171530938574246, 0.14043841484401906, 0.11968677836869444, 0.1892884171434811, 0.11392545966165406, 0.05897402297705412, 0.15799032444400446, 0.16719515408788407, 0.11295412999710866, 0.09977865591645241, 0.12361101779554572, 0.09780141844281129, 0.17716003794755253, 0.11037782074085303, 0.08587744792125054, 0.1552420404872724, 0.07930048262434346, 0.17477041403097765, 0.08719603145228964, 0.08357674601886954, 0.20356577102627071, 0.19797750589038643, 0.1176664267799684, 0.0869389141776732, 0.0790561285934278, 0.08160838378327233, 0.11253138232444014, 0.1409196997327464, 0.09288595470466784, 0.07740992799933467, 0.12459753985915865, 0.11169038566627673, 0.17267584428191185, 0.1397838999650308, 0.15350435301661491, 0.11857991133417402, 0.12022727222314902, 0.10100001216466938, 0.11643280940396444, 0.1391574628651142, 0.11596737509327275, 0.20222122674541815, 0.06804817356169224, 0.17425349248307093, 0.12886514514684677, 0.06418770964124373, 0.14540347270667553, 0.0816492655181459, 0.1646716280707291, 0.18033803813159466, 0.14119857762541088, 0.15895444128130162, 0.12810016476682254, 0.25751470614756855, 0.1508699000946113, 0.1280205047556332, 0.14132234241281236, 0.17058218376977102, 0.14791265449353627, 0.1542570519128016, 0.1696543414145708, 0.13766571719731602, 0.1556356179394892, 0.15590028730886324, 0.113649071992508, 0.08724529987999372, 0.1370901973651988, 0.2554941645690373, 0.19733250407235964, 0.1689553689211607, 0.1124963088493262, 0.2647041917911598, 0.11696255526372365, 0.1139312136386122, 0.09493193456104823, 0.06808045147252934, 0.16612621716090611, 0.14418152613299234, 0.1845698846238, 0.20841838206563676, 0.17858912769172872, 0.1732637948755707, 0.17346131641949925, 0.19173157747302735, 0.17351580278149673, 0.16413513757288456, 0.19352197354393347, 0.08662723590220724, 0.24089757353067398, 0.08992337581834622, 0.14094070717692375, 0.08380687795579433, 0.0771460932280336, 0.08365196162568671, 0.11175071421478476, 0.07903083959328276, 0.1445585201893534, 0.09535242271210466, 0.12618414472256387, 0.12499696628323623, 0.1250765584409237, 0.09925095923244953, 0.1487323519374643, 0.13028326976512158, 0.20036410354077816, 0.1284726397799594, 0.11227849232298986, 0.10424098718379225, 0.12850533159715788, 0.10330061907214777, 0.13815992139279842, 0.14680387399026326, 0.08977375884673425, 0.17380821066243307, 0.1598414493990796, 0.07676421371953827, 0.12372999212571553, 0.12509330468518393, 0.1402960174850055, 0.18715993421418325, 0.13582243610705647, 0.2035788396107299, 0.06577096932700702, 0.1550721488893032, 0.11712042322116238, 0.16700985974499158, 0.10233378130942583, 0.0932788129097649, 0.08245845923998527, 0.08524572503353868, 0.14923540422958986, 0.11869419020201478, 0.12663900745766504, 0.20327655225992203, 0.1704158748367003, 0.19541362061032228, 0.13051523374659674, 0.10970723815262318, 0.11304672288575343, 0.22983810412032263, 0.12642258192811692, 0.12398057510810238, 0.09903325127171618, 0.17203996197453567], [0.05556463556630271, 0.011621461798703032, 0.09387695509940386, 0.049894925872130055, 0.040390217676758766, 0.049669567429061444, 0.031615911716861386, 0.060153120064309666, 0.07472884615084954, 0.042031637991645505, 0.01023396201032613, 0.020392365753650665, 0.025634908815845847, 0.07991837018302508, 0.06540734241051332, 0.042405208838837485, 0.038724288676998446, 0.029557921790650914, 0.020543724863923023, 0.06722982640245131, 0.018683090240561535, 0.03902679315901228, 0.07915343051510197, 0.014435043724785959, 0.008820414110752088, 0.05217226242114391, 0.016370127210393548, 0.052733051258006265, 0.0379824599118105, 0.02853650606370398, 0.036249834312392135, 0.014718042021351201, 0.05402261045362268, 0.019377458873870115, 0.1120741989995752, 0.04506730527750083, 0.04067914467304945, 0.024699906219861338, 0.01803990180737206, 0.07878205472869532, 0.035957616421261, 0.025148823291861584, 0.03512526090656008, 0.012185628043620713, 0.034403913720910034, 0.0170439769447382, 0.034853348175862005, 0.14347635182951177, 0.038296010943927934, 0.02922985689448459, 0.03435063515124576, 0.04851051087358168, 0.054251544776239564, 0.009117164615807789, 0.02356100215443543, 0.023545344958880117, 0.02386776783636638, 0.015298226781721627, 0.03852721835885729, 0.014107684505039027, 0.037873480402465375, 0.020602446980774403, 0.024414100484656434, 0.04037815671680229, 0.03326486377045512, 0.025251763839540736, 0.012095119105651975, 0.011928797450049647, 0.013177518167399933, 0.011484602981779193, 0.040380996385855336, 0.022833836531000476, 0.03230515741077917, 0.014450551642637168, 0.029765645108584846, 0.037843288986810615, 0.05569100932085088, 0.040528706674064906, 0.034830546006560326, 0.034512625208922794, 0.04027670216081398, 0.04395900314141597, 0.01561190334281751, 0.05414130997710994, 0.01952335238456726, 0.04041727426062737, 0.028982839613620724, 0.09119213452296597, 0.06574820447713137, 0.07293543059911047, 0.023370016599074006, 0.012213646450878253, 0.02614994064372565, 0.018954999578584517, 0.012285058020747133, 0.04463142795222146, 0.03339847410097718, 0.009391731266597552, 0.048129988435123644, 0.09514977144343512, 0.03243202988856605, 0.05146402792472925, 0.015280835929193666, 0.045515365699040036, 0.08162865162427936, 0.016705067362636328, 0.04342556605115533, 0.009888931194187274, 0.05706489684858492, 0.030041479771690707, 0.021578643437741057, 0.008951941338766898, 0.05062991161165493, 0.026511872919010263, 0.04965493482138429, 0.06592097306357962, 0.10764500738254615, 0.01057474858992334, 0.014005668461322784, 0.03448560594448021, 0.057637241136814864, 0.04303206323779055, 0.002366334686355133, 0.05485937644594482, 0.030704720611018792, 0.029738826011972766, 0.02584665415010282, 0.0141035191481933, 0.07200612939362015, 0.016542023879342845, 0.0318540673303817, 0.011290715841044272, 0.015259816610653485, 0.013360553836849118, 0.01990536251105368, 0.01994505341696952, 0.01616346919243889, 0.030384363872664313, 0.029404043619121824, 0.03251310125259416, 0.06649656074919871, 0.025659509102946947, 0.03230896059955869, 0.02955669703494225, 0.010348644606502993, 0.007717363835711564, 0.04813875510756459, 0.04914701743317502, 0.034754516157720766, 0.0669723427189248, 0.01979056965293629, 0.05722728384924786, 0.06551448308995791, 0.04830555258584874, 0.010791702528617211, 0.04229511653206178, 0.021135656761803796, 0.030683248370353664, 0.018306491430848837, 0.03935685294813343, 0.041792033705860376, 0.04965201372812901, 0.007441707288048097, 0.032483449272279225, 0.038952887124781094, 0.02924064899395619, 0.035152880674494166, 0.03667448527578797, 0.02000420301088265, 0.03563034880374159, 0.028790105134248734, 0.038760128896683455, 0.028241428147469248, 0.05256464904440301, 0.05023116032992091, 0.004809434583876282, 0.021851523080840707, 0.07164643119488444, 0.034836666392428536, 0.024411325276430165, 0.08819235156157187, 0.0878814807427781, 0.009114213836645442, 0.01356841201361801, 0.03800270061141678, 0.08345334764037814, 0.018124752611454045, 0.03503116506284901, 0.0548894084058702, 0.0198446828206735, 0.029776199720799923, 0.013634994110491658, 0.022924217395484447, 0.019485091491203223, 0.010215061417381679, 0.07691083156636783, 0.04407741428752031, 0.020253318661291684, 0.09969955908932857, 0.059880172567708154, 0.06739837450108357, 0.06194269510784319, 0.026389141201174686, 0.04294898680278233, 0.01594266202300787, 0.024448393644498925, 0.031338550349963565, 0.056546048261225224, 0.014453289531437414, 0.007239580187680466, 0.07851741928607225, 0.06958069918411118, 0.04989029826330287, 0.030509037896990776, 0.020397502263741832, 0.0858707914927176, 0.05557915621570178, 0.01853104750625789, 0.010438229040508824, 0.018866900288100754, 0.08082403801381588, 0.005060104079478021, 0.024487594308863794, 0.020171422877215912, 0.03253689408302307, 0.04789156140759587, 0.019421658644984876, 0.04347180821267622, 0.038101020335618935, 0.03190749857042517, 0.052681452062513144, 0.07042970255549465, 0.03821752479832087, 0.015073397595967566, 0.019386340897264223, 0.06049566489777394, 0.024168533572394933, 0.04561977866770966, 0.014004755831722702, 0.0067702616880913925, 0.02596594230271876, 0.027260229191077606, 0.03125696669199637, 0.007026479055639356, 0.012123849974679095, 0.03326214284503034, 0.05192627651350839, 0.021206417786223546, 0.02440360015524285, 0.07794280190552984, 0.0414590765722096, 0.0525058166656111, 0.027483499442626323, 0.024947434098326733, 0.017630925002907003, 0.002222239293457408, 0.04040702159649559, 0.038452050249491415, 0.01046292092983744, 0.016349689735631858, 0.028506603025432144, 0.05974948672311647, 0.045917726787073274, 0.02073965863590794, 0.0370212709531188, 0.05655424835692559, 0.03173666041610496, 0.022631785765822445, 0.012740420327255768, 0.02374183343324278, 0.03524516822238054, 0.0018112203106284142, 0.0330352950175958, 0.05955968012234994, 0.04796176603330033, 0.023746106507522718, 0.02662278794949608, 0.04096273499141846, 0.017454351531341672, 0.01495978538878262, 0.03539412022967424, 0.05791395450276988, 0.0228210987323629, 0.017405476653948426, 0.0686103126832417, 0.026103784995419637, 0.056017934278185876, 0.028778766814087118, 0.045250764183167896, 0.014806578966921993, 0.028331191545086246, 0.04696406849793025, 0.005913364834019116, 0.0034543577431967215, 0.04170991061255336, 0.008030805454057242, 0.049519852069871764, 0.06736521449472223, 0.031881707454366345, 0.05528963210859469, 0.026120161438094716, 0.01933450421451458, 0.03235737068046417, 0.03526510018855333, 0.09470757695713214, 0.04404767070497785, 0.021155917817460637, 0.0452403724193573, 0.03350226960277983, 0.0654460189065763, 0.02599100738630763, 0.014696498534509113, 0.011881401778997054, 0.06421808086867843, 0.025919386318751743, 0.04865261646253722, 0.01214509575428175, 0.039080007267849784, 0.0813659635771598, 0.022835675360901014, 0.012752632261253893, 0.04015082034415432, 0.024185359544519867, 0.060443756968847344, 0.04038676393351384, 0.012875930555830044, 0.037269343355936665, 0.08407862444541284, 0.06238423141517809, 0.030472424147384505, 0.04535356563116823, 0.061799232448850355, 0.023550849574218904, 0.07146975424672876, 0.06016223278961011, 0.019500825021948134, 0.0287356018088758, 0.02432660848301436, 0.07010192264403615, 0.011272268170224769, 0.05718602892011404, 0.03289780007409198, 0.023802862569157566, 0.034290846038077555, 0.029368959965982606, 0.06965904962271452, 0.03193114212314997, 0.0702297179294484, 0.010167783641788577, 0.027735904291538254, 0.008107168633224708, 0.0536555162231837, 0.13954576131488594, 0.11034126805939845, 0.22254143708518573, 0.1413842248065131, 0.10320023660148893, 0.17852898234767572, 0.11432165625904288, 0.1556828711181879, 0.17849759331771306, 0.3106969781219959, 0.1360540608210223, 0.10285632791263716, 0.10170005674340896, 0.1716556940227747, 0.14348692340510233, 0.05831095855683088, 0.06655557293977056, 0.11558527845357146, 0.11422112451067992, 0.08450983344976391, 0.1711454764008522, 0.13653423291231903, 0.28529555829507963, 0.19289241518293107, 0.22260407943810734, 0.17560115802500928, 0.1184320721243109, 0.0905872273391911, 0.0941628897562623, 0.10160174380455698, 0.12238677777349949, 0.12598358334175178, 0.12443222158721515, 0.06402007756488663, 0.14929174977753842, 0.11048600636422634, 0.10803534143737384, 0.1352001652121544, 0.12087919509836606, 0.17270264641514846, 0.08691700428192105, 0.1086954338742154, 0.07789692615291902, 0.07769305352121592, 0.1200201426233564, 0.08020503765770368, 0.07658843243760721, 0.24619573780468532, 0.1947763676622084, 0.08415894263557025, 0.11201934622866766, 0.1284412100378956, 0.11613456612186772, 0.1866894516029528, 0.11321735408689294, 0.23309089243412018, 0.09873395626034055, 0.11041522837643113, 0.10418719971286398, 0.07056914828717709, 0.10647245137287037, 0.15923251850264414, 0.1577708726482732, 0.08729396441153117, 0.1807516866496631, 0.08675454264240605, 0.12867207479264053, 0.17631334838058266, 0.14801748815391744, 0.0730133264192513, 0.11983131989836693, 0.07708822097629309, 0.107765365924154, 0.1486297845840454, 0.1144432904464858, 0.10201895463147334, 0.13296254671045712, 0.0970299376973084, 0.1247846662466015, 0.08375015921358551, 0.13865439700228827, 0.13056879730096885, 0.09802346902766398, 0.10849293866860014, 0.08634989828403507, 0.10597676797104733, 0.1304904536477157, 0.14656118915549346, 0.15875416488519736, 0.17128235048481397, 0.10271008326006786, 0.07227563671767712, 0.16352924651333264, 0.12585980498364993, 0.08839462285063096, 0.15312509265329155, 0.10890312665807349, 0.12482520192861557, 0.1572947446256876, 0.2330910281411239, 0.11120743836675372, 0.11128850294543163, 0.09801569980170045, 0.06591764824198824, 0.13514998076217516, 0.1555761375597545, 0.11866798517959458, 0.09038217405655555, 0.18584990022437914, 0.10167339710252625, 0.16072856608246053, 0.11158206433589969, 0.13500284722873143, 0.14132326522043773, 0.24178566730448178, 0.1786911522171327, 0.28161249735525673, 0.07765686046332121, 0.10118973734123365, 0.12464268957929951, 0.13138534634241036, 0.1301756269697632, 0.08374603372067213, 0.17572021377938135, 0.09013478018875633, 0.08875354751944542, 0.08224824909120798, 0.05296751224835004, 0.16483438148030213, 0.09710159778062787, 0.08769747561642102, 0.1161579212972096, 0.1221171822398901, 0.09978585517300026, 0.06662840010332209, 0.10263938669647489, 0.06795284617692232, 0.10742837829249245, 0.14508568761604174, 0.16075375330235275, 0.1356315099235092, 0.11699664486306054, 0.19543689436146192, 0.09993613710893051, 0.0918806032942874, 0.09442405109958989, 0.1547489355185202, 0.13025239642177308, 0.18708634030606064, 0.17113746968763216, 0.13603392190166883, 0.24107651678579195, 0.12634049276156084, 0.11086057805057083, 0.09084107407501765, 0.1312623279435294, 0.07755004548068557, 0.18130887246557645, 0.08351804595440626, 0.17230171364332947, 0.07942408456334046, 0.11361969821155071, 0.14883835267807755, 0.09006374435765402, 0.22231952899268695, 0.10305041606937136, 0.09228005007441555, 0.08118148347628967, 0.09003753933523383, 0.14519839228263923, 0.19166622098003114, 0.15091921601976666, 0.11098202903355871, 0.14036232392702783, 0.11668278170483452, 0.15579942986369133], [0.040841100803975544, 0.0170048441338752, 0.03122479734676225, 0.0028533654944372495, 0.09590549660580498, 0.0374028145867799, 0.03326722167964492, 0.06804388522037438, 0.061507679522037506, 0.03141688721786652, 0.002136240917025134, 0.04816958434613688, 0.007290747665267969, 0.03641139689300742, 0.013500226877762802, 0.019112117754827653, 0.043661682666944604, 0.017343200709936873, 0.0613364919221827, 0.0665509792576943, 0.04980766287605677, 0.04240071015166385, 0.06994449573435954, 0.07601812375443322, 0.04542991439146655, 0.05597957669358168, 0.03866257252437728, 0.05874874256551266, 0.02217295190452465, 0.0845419145854456, 0.013263393559360077, 0.07927315801914249, 0.02933841571211815, 0.008864592677647514, 0.012640298244410327, 0.018437818491033146, 0.06294902360865048, 0.009739270965967859, 0.05340850572767002, 0.06024767391915832, 0.014500191568263938, 0.02183792693540454, 0.01096367638092488, 0.048225722940904756, 0.03878440687965069, 0.03995981612907989, 0.04147888979475413, 0.028343467939911143, 0.03169730877769845, 0.0737042718433908, 0.0711569224617311, 0.07333745581230947, 0.038313184665249925, 0.08284199437392609, 0.06980245799890586, 0.07022538209067923, 0.08745137775050742, 0.09000057274741785, 0.06238200582031693, 0.005052660126239061, 0.017987144013334597, 0.03510512877255678, 0.015209097814347063, 0.011800193011627665, 0.0336161956324109, 0.022542163164221814, 0.006559107527469418, 0.04619496262499264, 0.046375948270516734, 0.0745641521311232, 0.017002381051757505, 0.04801783677456634, 0.044357778171875646, 0.03905371403587716, 0.03544049470552376, 0.030738657539976493, 0.04082740118194904, 0.06434187279748065, 0.03323119147015469, 0.017320924405274645, 0.02835618538249816, 0.05019947274455002, 0.04678219736420682, 0.041249826550483704, 0.034062505433601994, 0.004748836317698338, 0.02727601021927382, 0.021729877019034963, 0.03206143441743084, 0.0177001813759229, 0.012377240395705615, 0.06362099719366857, 0.06463925434010369, 0.023674648288371306, 0.049830122385174036, 0.08071440711085286, 0.021946316119283438, 0.05830612060214792, 0.02377013343253306, 0.044567116403153965, 0.058476602525583336, 0.03273433759542448, 0.05394144070201686, 0.034819485885756354, 0.07160309316324336, 0.04554187945489373, 0.0454223080139075, 0.03709304299471634, 0.0023418618366122246, 0.029774757833885293, 0.002463448738646028, 0.0121167821842911, 0.007834394163052951, 0.04636380588635802, 0.02414518518240324, 0.0161956707680864, 0.0032222067405070576, 0.04014554812705942, 0.04242780405495848, 0.02148655945036028, 0.013614361556912107, 0.02847825383235301, 0.048622394512806616, 0.1597442967551095, 0.023573421041614244, 0.08129574198807989, 0.009097956985767399, 0.02927435182833246, 0.03309904338259782, 0.04698981550921287, 0.05285789830876248, 0.03552276368385979, 0.0886542507048164, 0.06180330365896225, 0.0595571424013802, 0.09702801744320563, 0.05326456809416413, 0.02236601716971823, 0.01715320411936513, 0.04882830274956567, 0.017591442746509398, 0.008541573537513614, 0.04694032995030284, 0.06738016940653324, 0.07646934275648423, 0.03747595726911511, 0.07903553505561181, 0.04299386510891574, 0.03851241611742547, 0.018263635159071003, 0.09076658450067043, 0.05276351748034358, 0.03785580795790468, 0.09359300855015006, 0.029774421959051063, 0.07373009010085038, 0.04433273344433733, 0.024114995463086025, 0.023094220951731716, 0.032970169226505926, 0.009616774190882487, 0.01778317129771624, 0.04899391279156719, 0.027632010402157903, 0.022838645647945147, 0.03173065198851483, 0.025575959389763217, 0.048616318231714625, 0.023717782759506787, 0.009074941077934844, 0.010502286138944328, 0.019907844252884388, 0.0405595834100885, 0.04229899775236845, 0.02608333564629512, 0.04565119823174817, 0.0378987219051591, 0.022016732787181224, 0.032057420882795534, 0.06585679722151586, 0.028646784967609813, 0.036516959978533645, 0.022753978048318198, 0.07227803873164312, 0.03099240588822535, 0.030821296319897686, 0.016718914566029395, 0.07696803885379008, 0.03870156114654882, 0.016600581451452205, 0.012856665250313069, 0.04103086669264095, 0.0320321386680007, 0.024023686701964055, 0.050774029056940756, 0.014329529833048582, 0.010643850596222495, 0.036453035194426775, 0.04764468322641083, 0.05982135036694152, 0.020555054702396904, 0.025582147629133294, 0.04959241460476603, 0.04048943306718554, 0.12581223967884267, 0.05597609580893602, 0.026091445836105516, 0.017386688019282052, 0.03670439849208508, 0.027358730423397253, 0.031154704679335867, 0.011069395529505397, 0.02090699046051928, 0.01074646714343024, 0.03925592425678458, 0.0330141077616385, 0.01831801125912794, 0.07143337798437902, 0.010870596643404236, 0.029299128534538404, 0.0054853351903147995, 0.09184760613633053, 0.03946198516392282, 0.020172170962073972, 0.08925134795052664, 0.06483351891594273, 0.08265672717243433, 0.04887986462563276, 0.06101755332201719, 0.01971399358340672, 0.03668941304619823, 0.038035714732749124, 0.053671292162367275, 0.04255406924390367, 0.039241736089544635, 0.02602821824673031, 0.0374938807716327, 0.030514998827129602, 0.03398276739088552, 0.01933809196842568, 0.049230952214981825, 0.026749477222827927, 0.02383002093327897, 0.01892150709006403, 0.05216616239132626, 0.04188331362924405, 0.009949874665055956, 0.028542453423142433, 0.07963740918785334, 0.016537330113351345, 0.020173472052972232, 0.061357417942157814, 0.0303349224185305, 0.038990922405251434, 0.037001956453812976, 0.042661033504243405, 0.02767381664099438, 0.04117856001747506, 0.06865521813077585, 0.039841801925961456, 0.07863340127680983, 0.008694505152691687, 0.028950873828892196, 0.035071680388812504, 0.0034938894054253717, 0.05423602328768798, 0.012688972953973072, 0.03344363739181842, 0.021887851845739142, 0.010075842146761715, 0.08148946373590402, 0.04239507152565888, 0.010305499957342232, 0.012595021298953464, 0.011323995439202657, 0.03724826466558235, 0.039572579586612325, 0.020257228719336644, 0.10735152741628033, 0.04909209341609052, 0.11728105960147721, 0.015190456761047244, 0.052363555013601265, 0.01291054008262498, 0.03267698103029813, 0.011464071360283663, 0.04023844635646258, 0.08579284817512546, 0.00929357947981251, 0.04985410859808326, 0.035402096408818445, 0.052554969742361984, 0.040700013017547984, 0.017918818929631795, 0.033353772213948626, 0.03508598390700562, 0.030542442175958837, 0.039746708635772975, 0.006067251487235937, 0.07893921022436448, 0.021966836714584912, 0.034551729182047505, 0.01745310302690736, 0.03370059860338058, 0.011532461752982011, 0.018742792840514864, 0.04112201430169599, 0.022399138160316006, 0.05744843876787594, 0.02725735559527363, 0.0188432550390384, 0.03321929335860269, 0.053017350645469766, 0.029382133723369667, 0.01313848968129605, 0.04213016466902835, 0.027003992315647856, 0.025215930405205915, 0.08128968267036335, 0.0781165747238057, 0.01520276368994798, 0.024216431359361325, 0.01730086182111076, 0.04567223960267646, 0.007772576230178986, 0.009281766185137843, 0.06714726226138217, 0.01341690871465419, 0.03895066152991993, 0.06663198955357075, 0.0568341236960675, 0.016289096558466554, 0.028094230153198754, 0.05690742922680719, 0.06227370484599045, 0.03065368459959115, 0.016373813351882354, 0.06483868256743465, 0.05506333050185016, 0.024459535189505135, 0.0501526470429131, 0.023904770047270825, 0.0214806765517486, 0.10431105270981789, 0.048605950216629674, 0.018144608242437243, 0.013252183312683232, 0.036517950639660866, 0.041071996092796326, 0.01462160692816334, 0.025448946115959967, 0.031617217896772284, 0.08081277433250632, 0.08503115868994168, 0.07955508931939091, 0.1404434224324567, 0.168802196426051, 0.23352176217096193, 0.26154205575585365, 0.15938009986920015, 0.10705150637243475, 0.07729689763592822, 0.06964734489364283, 0.15070646815001965, 0.13865564550672257, 0.0855530606848853, 0.07938179826097828, 0.1170884370803833, 0.10522887310279266, 0.059285551974815984, 0.10938101887170758, 0.14156794494816236, 0.1536411185349737, 0.10754904217485871, 0.1355926570083414, 0.1431940948324544, 0.11716398516935961, 0.1431923849242074, 0.12152297555335931, 0.08990645994033132, 0.1832974957568305, 0.17515778967312404, 0.08868226063038621, 0.11889452088092055, 0.08221835283828632, 0.1172567680478096, 0.08694203543875899, 0.06141592123146568, 0.0866376446293933, 0.03371155694393175, 0.12560193453516277, 0.14521177299320698, 0.07246929061199937, 0.1628301925957203, 0.10514115209558181, 0.14620662746684893, 0.10020505410752126, 0.1718449510101761, 0.11605669744312763, 0.07647155478064503, 0.1277284768543073, 0.13628693403942244, 0.23793929655637058, 0.1212783365377358, 0.1527615607317005, 0.20142639082457336, 0.06818736823541777, 0.16400033980607986, 0.1625429687223264, 0.23332468846014567, 0.12905037163623742, 0.08722365461289883, 0.11582465203745024, 0.11228917246418339, 0.11553042568266392, 0.08357151451387576, 0.11848925905568258, 0.07323221503091709, 0.1939722765237093, 0.13472962831812246, 0.14162095210381917, 0.15541565045714378, 0.08457264543644019, 0.14611524237053736, 0.23025920295289584, 0.14205203897186688, 0.08096097316592932, 0.15928838907607965, 0.15322715789079666, 0.13303405073072228, 0.10415274370461702, 0.10857673095805304, 0.12421734311750957, 0.15279844589531422, 0.21701114598129476, 0.1016684505822403, 0.15458258587334836, 0.20666715103600705, 0.1241483496768134, 0.11042237335017749, 0.13223263302019664, 0.1569983469588416, 0.06859651806631259, 0.19717013064239705, 0.1305436643638781, 0.12015249766409397, 0.1583831962198019, 0.22227519351456845, 0.08659117176596608, 0.0813919243269733, 0.1111239582034094, 0.12311636576695101, 0.2089233613972153, 0.12986947196934903, 0.23873266684157507, 0.10608168984098093, 0.20133843911545618, 0.09970013584409441, 0.20243362177695545, 0.07222520120974098, 0.05769265030643769, 0.13349231971161707, 0.13713808836681501, 0.2205483354628086, 0.11853447662932531, 0.21060262700276716, 0.14573079799967154, 0.14701662186001027, 0.12273949384689331, 0.18148557655513287, 0.1286745582308088, 0.13230637620602334, 0.11916868974055563, 0.19837169402412005, 0.13567280556474412, 0.2619066190506731, 0.12181123079998152, 0.1290316983525242, 0.09125148598104715, 0.10157653622861419, 0.0837356046374355, 0.09055678147290434, 0.10020305921456643, 0.0894240215420723, 0.17773920829807008, 0.15501257351466588, 0.13964284610535416, 0.14216988693390573, 0.1522817686200142, 0.1061662488750049, 0.09986442274280957, 0.0718830499265875, 0.11714618041047029, 0.12044562479215008, 0.18174945882388524, 0.19618800548570497, 0.17663881448762758, 0.0925548838983689, 0.10737541184893676, 0.16259014047682285, 0.0976950309372374, 0.06147671118378639, 0.20031755603849888, 0.2598760894366673, 0.11831977457872458, 0.187644218227693, 0.21365779877773353, 0.10852510122848408, 0.0987028047176344, 0.15930755090500626, 0.11793235822447709, 0.08683411444404296, 0.07516445884747164, 0.13751253113150597, 0.14819158666900226, 0.08468261560691254, 0.1688685028680733, 0.1371689209980624, 0.10171134078076907, 0.17592670555625642, 0.12456669365721089, 0.14852739364973136, 0.12164485401340894, 0.11976539343595505, 0.17985568115753786, 0.16992327198386192, 0.20847707534474985, 0.1558823332722698], [0.040563077865434546, 0.05260158170546804, 0.006544248882814178, 0.023533090616443327, 0.06403759055371795, 0.0761185469371932, 0.048351642076990435, 0.06828649541629211, 0.033397222203867774, 0.009620054059528878, 0.042305481154471636, 0.01960321086724954, 0.08539519272744656, 0.026619687044460858, 0.0557867370412818, 0.004013652530764895, 0.020105742383748293, 0.07330681995621749, 0.04879401298239827, 0.047222522486533434, 0.0032494215078518857, 0.06135878858289548, 0.019116060043286, 0.018886328442022204, 0.05398872780746647, 0.027382579232965196, 0.04772651115698474, 0.03829911524163825, 0.055149752114500315, 0.06967054400593042, 0.021879412566444705, 0.01880886858063085, 0.04388728538261993, 0.021165758271568587, 0.016817256342619658, 0.06983682579760041, 0.04339991742745042, 0.04827427890683923, 0.03328920282157404, 0.034703894052654505, 0.0374210875348321, 0.010098748640822513, 0.02019099861250392, 0.04936145146244338, 0.05702229163476399, 0.012621080436344658, 0.012996885360085537, 0.04385956044175795, 0.06211599973695619, 0.054562486841210296, 0.02904714098466294, 0.0435097688542945, 0.011043320276907511, 0.03540236782282591, 0.00864359551841127, 0.029528208742184297, 0.024425382825679014, 0.05684358586690255, 0.04588368807786277, 0.020152754682515348, 0.053009530529379845, 0.04647142832566585, 0.020693017835063592, 0.016812730514045273, 0.044826103041746786, 0.021103753741564493, 0.012313322396948934, 0.05276470152395112, 0.02231974108144641, 0.06140669994056225, 0.03546543426013418, 0.014266076630779674, 0.015273063310555049, 0.031475824769586325, 0.04125147878325411, 0.08255991379597358, 0.06569557051573481, 0.026572401635348797, 0.032474492610033066, 0.01962784508110157, 0.02019396550687296, 0.030882062523492744, 0.052689652158213515, 0.007192272726180298, 0.03242479670526726, 0.028176543236310993, 0.02054901234805584, 0.04888981194900615, 0.06125446382377829, 0.044397832094026465, 0.021579674810969403, 0.012500538690281766, 0.023499971322183098, 0.06707961232002292, 0.08890494903815643, 0.06266659697783844, 0.05406167032197118, 0.03512736775779298, 0.037995192621435435, 0.026276248241109506, 0.046026214358529875, 0.04180244243304644, 0.0374747562621321, 0.051346597261726856, 0.012701827799901366, 0.0132295575624864, 0.02723385114222765, 0.013596307436403419, 0.038950759917497635, 0.02693637290836445, 0.03629344375804067, 0.035929280798882246, 0.04090470667662365, 0.030288785429937497, 0.05416878046733992, 0.058190430381468365, 0.07072508920516286, 0.03575731288375599, 0.01815933414867946, 0.04482827435380646, 0.060493310381259234, 0.03510141379332968, 0.04360336936744196, 0.0666517959907651, 0.04125717169206057, 0.07442785480192729, 0.05272105475887656, 0.042701070463018756, 0.06583233603409358, 0.03754425860409226, 0.012946999465514506, 0.023681874686319913, 0.013453993197929646, 0.07103501686028071, 0.009340011631138623, 0.009646551700175872, 0.0017051322086315069, 0.048476943746209145, 0.029011439864656756, 0.07281515348170485, 0.022488404531031847, 0.03603341217551913, 0.022288396156259944, 0.04075829578297479, 0.0013656678181307922, 0.015078861499205232, 0.029131988396069834, 0.03871172220845308, 0.027035301617745842, 0.060835610942116806, 0.009130446938797832, 0.03678680317742484, 0.03665761350254927, 0.02775188209488988, 0.02873056029368724, 0.02286108480101185, 0.028748863775815283, 0.03927601228601166, 0.030773032124021223, 0.02238625447664942, 0.060749382711946964, 0.06178817232804639, 0.06684280359851462, 0.025782732758671045, 0.020603198458307555, 0.026370528985613158, 0.04120677350355046, 0.03069324997652854, 0.045522117122475586, 0.05900737975857087, 0.1073524027264544, 0.03621198223637683, 0.012062613037414849, 0.026147582734535848, 0.02090653244938169, 0.0072840878440599355, 0.027394996423806463, 0.017603919309164797, 0.018090763096032397, 0.05497282071571265, 0.06598192586430482, 0.019823193616632904, 0.050482791648911576, 0.03131130038361464, 0.04513360832684806, 0.02767106857416885, 0.012033965288927513, 0.0333983621426991, 0.012852867998714958, 0.03083139970632536, 0.0072256303558658275, 0.05452594094510589, 0.009808106647272195, 0.07379869677658592, 0.01788159110583365, 0.03730990957202656, 0.04124497502510037, 0.0224854155842747, 0.02031560817600361, 0.0383378494131778, 0.04620330182037183, 0.03375243189345513, 0.030581535971058265, 0.001507252737480615, 0.036982893012464046, 0.031606066173740795, 0.035459385120442936, 0.006598709799748446, 0.015534385805949569, 0.026140782117311443, 0.005772178235929459, 0.026644755520724824, 0.050453550182282925, 0.02403517090715468, 0.0317716830010925, 0.03224333608523011, 0.04581030112292085, 0.027357704139181545, 0.05714286730757781, 0.031777409836649895, 0.0421956025862268, 0.04422605077603033, 0.034803099265055995, 0.05907908733934164, 0.04858750084947262, 0.012659730639175644, 0.0355190453119576, 0.04326758613543851, 0.030791630768882375, 0.010673800283776862, 0.049225568039608855, 0.07175802984940154, 0.029503991827368736, 0.08173077792993613, 0.05478277323501451, 0.030706074288380996, 0.019713951174968054, 0.04530853804733072, 0.025270559259557297, 0.011455096038324493, 0.07934543556932892, 0.010774483854350234, 0.036807749553450515, 0.0074194275907107764, 0.038856039821569405, 0.04655016213655472, 0.033915422790284665, 0.046445277586047135, 0.048789080032812696, 0.03976399092269795, 0.016106964188760946, 0.07397690042853355, 0.03536136055897389, 0.026600012921595147, 0.03235957931194987, 0.012694564930695509, 0.012328441853501966, 0.017668505664914846, 0.03171114410672869, 0.044789641962519715, 0.06445891330284731, 0.010292902106552251, 0.011419983547446983, 0.03836869900780065, 0.03168805016736899, 0.028493704074727635, 0.05791033112577029, 0.010794124050465013, 0.02472439794135945, 0.016987702642966594, 0.05810507067612239, 0.0478677516137915, 0.02835302340931126, 0.03397782765594976, 0.011648264780108417, 0.01797084560218666, 0.027028792770579457, 0.01810302252748183, 0.024539156184930886, 0.0687483742034861, 0.024937729351222515, 0.04651426084871803, 0.024403101432004144, 0.03532774593415005, 0.0103617310025064, 0.05446647074339645, 0.020975607314280102, 0.016765702948240296, 0.027016643601070558, 0.07570780933435474, 0.05469238558518035, 0.07612436876765319, 0.02411027455569378, 0.03790796355211309, 0.05355979189542787, 0.02836691471748054, 0.018690457434526513, 0.02552141365595162, 0.03424129601834076, 0.04294807417318225, 0.006208253608617399, 0.03597492245691163, 0.008521718754699188, 0.11077601223119668, 0.032486024312675, 0.02042409235478512, 0.06649412480848176, 0.03248628215598209, 0.03609199010367904, 0.13931226384426865, 0.011749690498358436, 0.007049394455472273, 0.051816618469144614, 0.07295593592737402, 0.006818912648928485, 0.028496611597282544, 0.03506664226629904, 0.015162928595340677, 0.011596340735975121, 0.02133624698035419, 0.006764413988483804, 0.041646277598504505, 0.03453932556190661, 0.03079943052892174, 0.04342508768396718, 0.07030730162348066, 0.01379224205655711, 0.01998552294181926, 0.020827328752992407, 0.012856077469353164, 0.030451837394918715, 0.014168645787451948, 0.04087238805368543, 0.035369401198944876, 0.05645708214225514, 0.0018217761950966502, 0.01212649795758937, 0.033420194006924114, 0.07395117716597659, 0.030416482327772037, 0.006356486368791333, 0.0605319868773222, 0.012152045649210257, 0.033372476031737666, 0.007604909378902188, 0.02317913112762783, 0.06678639698241438, 0.04771812446415424, 0.04096126935577818, 0.04117403758157577, 0.060492563992738724, 0.05552182339930108, 0.1293653611625944, 0.09671647487474339, 0.10671137033828668, 0.12862692507249968, 0.20347503732357705, 0.11423028473343168, 0.14248213517878736, 0.11633919871279172, 0.13970756477543286, 0.15932196298880236, 0.123997334923063, 0.12165979535451957, 0.12627341278961726, 0.09672372162874256, 0.24256858815039906, 0.10695491691253015, 0.0928861718358738, 0.15475709150944436, 0.16491961904934474, 0.11594206573707716, 0.11556352462087359, 0.11262979704354491, 0.07906171293663126, 0.06008730895285096, 0.1574447551476104, 0.1354678472770112, 0.13295912689396314, 0.10312889542962823, 0.15679484073604855, 0.1492155502949442, 0.1323993762156793, 0.08368895535490342, 0.15934571171445505, 0.11794728599488735, 0.17648987605103425, 0.24111769029072352, 0.17661855343197072, 0.09991823056978838, 0.16654086991080216, 0.15265227588159697, 0.12168464330690247, 0.16541501746645995, 0.14612593608243124, 0.14454439309026512, 0.16873162878411158, 0.15303362613277777, 0.10236647991197449, 0.12109893187880516, 0.11533580826861517, 0.13922751482043946, 0.11800901911088399, 0.10903955969427313, 0.09017389094723122, 0.08435968722083739, 0.15587230452469417, 0.13424049956457956, 0.0956775631223406, 0.20664520721350396, 0.21313827165535518, 0.1747446839830705, 0.14976657501288823, 0.0865819233336619, 0.09606199392250606, 0.14430438168346882, 0.14143774764878408, 0.14453198947012424, 0.17586479602115496, 0.1742398946412972, 0.19658494847161428, 0.1755463323955025, 0.1230341408933912, 0.19846442261976854, 0.10870488586702517, 0.11864640776600156, 0.11127894917236907, 0.15120534066643032, 0.2806802988052368, 0.09067490763430085, 0.14234118988471373, 0.12224131343620163, 0.07763656548091344, 0.07394148768591029, 0.13584405423275062, 0.1496192379189389, 0.09439742538545813, 0.09490978717803955, 0.1083641459367105, 0.15382930343704565, 0.09262310380914382, 0.11713357322982379, 0.1771938018500805, 0.07868575703884874, 0.17398130494569028, 0.1031316231404032, 0.1446853248136384, 0.22489309018211706, 0.11125622503459454, 0.13785250431724957, 0.09507904773844139, 0.18869336907352718, 0.15331463462540082, 0.09261811657675675, 0.10457634633140904, 0.15926622812237057, 0.12909387930163316, 0.08178514894098043, 0.09644265885331801, 0.1950693048004593, 0.20521001065415995, 0.11469809391668864, 0.1184248389410121, 0.08258497887956244, 0.17118580852236065, 0.1667571733040469, 0.10273400840482541, 0.11994204324270998, 0.14836966139929636, 0.1726164724677801, 0.11299195832439832, 0.14052745220916613, 0.1337774536971535, 0.11232318063931805, 0.13143983270440782, 0.11386329228324549, 0.07971243480486528, 0.1620819584599563, 0.08807256298937968, 0.17178127728402615, 0.07955949979701213, 0.08868333271571568, 0.0843131940013596, 0.15088969974645547, 0.3079413388456617, 0.2563123420945236, 0.08447427142943655, 0.07391606297876153, 0.17203993483313493, 0.1402654969798667, 0.0734578822074192, 0.1752718106976577, 0.12691145283835276, 0.16877243588013308, 0.10500502440014056, 0.1138413484607424, 0.08095994179270097, 0.1197769692433732, 0.1068964000525219, 0.20318598140563282, 0.06764429594789233, 0.12529430032840796, 0.0747551733095731, 0.12995085545948573, 0.12819453541721615, 0.07551959050553185, 0.10287171030150992, 0.11003566267234938, 0.11317421961575747, 0.08606054381068264, 0.20858973929924624, 0.11943524543728147, 0.14577815974397318, 0.08661951417369501, 0.21087043120392732, 0.07610853176031794, 0.06364746684474604, 0.10524093067007405, 0.1451025152845042, 0.16645879431494645, 0.1487383366163288, 0.11405078507959843, 0.16790097978498253, 0.21519877894648484, 0.10730595021907773, 0.1253915751086814, 0.09252574081931796, 0.12265880246247564], [0.02117523062042892, 0.017259427080196992, 0.05628693609365395, 0.01316019262386752, 0.04828123049810529, 0.0346254791532244, 0.05161104949989489, 0.033073472790420055, 0.043116076051124504, 0.06980912799813918, 0.02524116512254945, 0.020544425451329777, 0.014050165939676975, 0.021991940813937357, 0.02531448083131441, 0.01938044951696481, 0.03376663702407053, 0.023213632936988558, 0.09045145926730973, 0.004362807991648359, 0.04031632182055286, 0.06381108877914292, 0.025139756367674897, 0.03996268293953367, 0.020885586073356013, 0.04543659117605005, 0.04949657492605703, 0.017659956123679876, 0.04376468089010034, 0.05590714308034096, 0.03711357546438064, 0.01991807316829051, 0.054444272470261366, 0.045723971112498214, 0.03248477580824068, 0.034876957801835876, 0.007431328246769096, 0.05779825071138995, 0.011434393934905529, 0.0221470725789134, 0.05030167708173394, 0.017855593036594133, 0.036435281325663836, 0.0137338354584894, 0.025786178020228232, 0.1067124559943165, 0.06283258021410022, 0.021182663971558213, 0.03320086095482111, 0.05793333346290248, 0.05739732472492116, 0.037705074796187024, 0.05760640850556748, 0.02060605339439852, 0.037401620365147076, 0.01895157297674034, 0.05368853373719113, 0.04335660992988518, 0.03693430990512882, 0.048267062686915906, 0.039873438621205945, 0.01132602765158351, 0.0148070522450975, 0.03322540356644562, 0.008686524732703609, 0.006178764900791326, 0.07609129697084427, 0.03550761538956847, 0.04898106133831399, 0.08307839597442321, 0.041322748708937845, 0.040831523282187324, 0.03134079630087529, 0.023219571814739277, 0.004220638365950435, 0.04003193083086184, 0.03913482950468149, 0.02907218231952616, 0.010506328511317926, 0.03620256417031799, 0.07169262585895401, 0.060749511633600504, 0.030576145010335103, 0.052864486883793554, 0.012961660910929953, 0.014548659324645996, 0.019638414960354567, 0.03434340875329716, 0.03481031209230423, 0.09537878379757915, 0.05591080377676657, 0.07780367508530617, 0.00945336090600384, 0.027388708100521138, 0.051044971482562165, 0.051069480167435746, 0.015646981906944087, 0.019121327171368257, 0.009626263503118284, 0.036960850802383254, 0.0271516686771065, 0.0377888772636652, 0.03964063664898276, 0.024314503418281674, 0.021250968699210455, 0.026317998500806943, 0.04097216323550258, 0.03409700893930026, 0.04411895080868687, 0.04123315155240042, 0.042574238697333, 0.030363074836454222, 0.03731727846232908, 0.03071835237954344, 0.03847092370103512, 0.01714161134857152, 0.02295308736419039, 0.006734627573418298, 0.02262060690139021, 0.0532793940843216, 0.06493719228144203, 0.049396477440106015, 0.060035577443029196, 0.07990111503750086, 0.029345289271857058, 0.04845006697412048, 0.03785905474796891, 0.041711773191179545, 0.025703490046518188, 0.055761844984122684, 0.02700849269915904, 0.03455341194889375, 0.01413387680492763, 0.05061373533681035, 0.074260724841484, 0.04733587854674884, 0.05534724990970322, 0.04142615405310478, 0.04869821401579039, 0.007568939389394862, 0.03955745504104665, 0.038798201496579816, 0.02848099511382835, 0.008622807749946202, 0.05419148085638881, 0.01205562412672277, 0.08816048755709614, 0.028117911025349582, 0.029544982127845287, 0.03813886223360896, 0.04647594736889005, 0.003529360459651798, 0.0682853011946593, 0.022017772642097304, 0.014694875139476997, 0.05346708704850503, 0.08506596075104815, 0.020246484117316346, 0.0020656242933390395, 0.020121214678511024, 0.07205864800406353, 0.052831530437937806, 0.028916472103446722, 0.07675705517509154, 0.016568883688056042, 0.019458657463214228, 0.07204663793423347, 0.021940226267491068, 0.044006110435085635, 0.0321424820327333, 0.024745150934904814, 0.06722707833562579, 0.05001022593517389, 0.02676876966974565, 0.05813401019466775, 0.010745409476969923, 0.04500741438407983, 0.040847054948764186, 0.013647731909129237, 0.030158639020685638, 0.021350440236606767, 0.0241061965602317, 0.06693661785019295, 0.03214285183431847, 0.0465627218197499, 0.03346750486109938, 0.041214844677597284, 0.02092336690319436, 0.04508040439603584, 0.01625572790258697, 0.05844576310898576, 0.04454819545415895, 0.03256046299689582, 0.02874060600463833, 0.08033450213926178, 0.016514923190698028, 0.05047375356246318, 0.01696099720097014, 0.005156227894726076, 0.0341025118583015, 0.06655907418046679, 0.01938037487811276, 0.039780330045947006, 0.031466416881552765, 0.06538144272885152, 0.07094715336071593, 0.01466378805759762, 0.026341112796217203, 0.0376664797243263, 0.02059909501778228, 0.05550541642255016, 0.03843844222969242, 0.046030906428183825, 0.04141274620113628, 0.05627053929492831, 0.025126216201377765, 0.02088874126119273, 0.0036261759565344876, 0.016532449750229716, 0.010744081244670918, 0.021440605666222315, 0.07553559036127158, 0.07520014300410237, 0.018037272484174798, 0.03463010336937649, 0.04691186201359544, 0.017512471448364, 0.08136372441159827, 0.04570387629792094, 0.01728305366954633, 0.018069687798353176, 0.021482676533716064, 0.05821402304406677, 0.0825322906353644, 0.04343540820160082, 0.019435926540089504, 0.025358409188421707, 0.052733780683151314, 0.005864499710566763, 0.06559903533863169, 0.028618072758295705, 0.02932105878634112, 0.06671297270804644, 0.019053921502615725, 0.05931429471820593, 0.03357701362775905, 0.01922815402836672, 0.05583330150693655, 0.06815444571631295, 0.03853891969525388, 0.015507402164595467, 0.03014998769919787, 0.04339146627379315, 0.021395153997998153, 0.022881883595670973, 0.023526359549058334, 0.027809493110648224, 0.015621019460793053, 0.03598700038024357, 0.006909788843976068, 0.04256417941568153, 0.041176911177379746, 0.04908669227734208, 0.03292042582428881, 0.05547067203692027, 0.016677875071763992, 0.07398965688688414, 0.024344494666105936, 0.031885151019585986, 0.011194904151904796, 0.059458334131964614, 0.017262112382533293, 0.05950838966029031, 0.007370369508862495, 0.026315689785405993, 0.0328410575831575, 0.030177546398980275, 0.06324913964739867, 0.013142211445873337, 0.018613192651953017, 0.02362306944892875, 0.020384961240259663, 0.025167308282107115, 0.053543123682694774, 0.027144839222143804, 0.04832671609308038, 0.0098547423591039, 0.027703317647267665, 0.07414018309542111, 0.06657748283552271, 0.03172627204496946, 0.02684481139294803, 0.062114405179662366, 0.03436905737700207, 0.06914504577538796, 0.0698102204395192, 0.010468534958947982, 0.008388505367163037, 0.07424474534179483, 0.04621678770386747, 0.044536093782101355, 0.025921469421258996, 0.10853370505252055, 0.032042530431811295, 0.03377000595043812, 0.02817859750107995, 0.07574892855648484, 0.08114339052034275, 0.05530778631301863, 0.006826246764311301, 0.036386531977249045, 0.044769567503992996, 0.015422924554773738, 0.02165622204276068, 0.014815113241119044, 0.05823209921696356, 0.01409829273221216, 0.008334820524656346, 0.001690229565221151, 0.08320437278598547, 0.05487749672361782, 0.017213278217241168, 0.06832232885062695, 0.0032080103036215796, 0.05364695650392345, 0.040012059932840724, 0.07898302323051862, 0.053148134877639155, 0.04904745598988874, 0.07695925182529859, 0.013583830873748022, 0.05767558515071869, 0.0907042474885072, 0.030647292799715484, 0.004115917087931718, 0.013544593738125903, 0.07457316307617085, 0.061754544132522175, 0.0403874899659838, 0.06472434941679239, 0.012711811594532003, 0.04421072945530925, 0.08858180352087532, 0.015970290272629688, 0.02711705830214279, 0.018965277687779496, 0.017264134416888868, 0.02902695456785815, 0.00782675894775561, 0.027438168214367967, 0.0738035279459187, 0.03853109618648887, 0.12299338808017117, 0.1235313984964575, 0.11588696869356291, 0.12219647584216935, 0.13690562226942607, 0.1393573728523084, 0.18561640275376184, 0.08442142033683402, 0.15151406052921498, 0.11954937502741814, 0.09633097877459866, 0.09258850530854293, 0.116258032353861, 0.12056940315025193, 0.11010219303092786, 0.0880506123815264, 0.08341406724814858, 0.1454222681266921, 0.24940409564546176, 0.10324941681964056, 0.1554448138922453, 0.12847196124494076, 0.05540287621053202, 0.10825018598032848, 0.21194121374615602, 0.24107089851583752, 0.23265274880187853, 0.06533737866474049, 0.13251984332289013, 0.14252500502126558, 0.11022301976169858, 0.08547707833349705, 0.1255081067127841, 0.17571204421775682, 0.121945037905659, 0.16602333768137864, 0.09451650828123093, 0.12280612598572459, 0.06844180529671055, 0.06878152063914708, 0.12970852346292563, 0.1799565250320094, 0.1033150175852435, 0.08282479351120335, 0.09969969479633228, 0.1447333243808576, 0.169944415135043, 0.0960249255544373, 0.13127504368977888, 0.16380135262651102, 0.1002844087779522, 0.23042452122483933, 0.22428016949977192, 0.08276473637670279, 0.13307156014655316, 0.16702923870512418, 0.12244266191763536, 0.1394892664892333, 0.21271265377955778, 0.12241067577685628, 0.12694518959947995, 0.18733184784650803, 0.12504257740718977, 0.168600182980299, 0.1286678814462253, 0.10028281422065836, 0.26627540748034206, 0.12280121339218956, 0.1878181674650737, 0.14094891745064939, 0.07763037045619317, 0.15388844454927103, 0.15439612445022377, 0.16647259571722575, 0.14320244081318378, 0.20135547034442425, 0.11491359663861138, 0.11009825074246951, 0.10759330301412515, 0.18449441795902594, 0.20220908096858434, 0.10923878436109849, 0.10025827839438405, 0.12909971470279352, 0.17344874995095388, 0.07302832204316344, 0.09879403375089169, 0.07664840136255537, 0.11557739387665476, 0.14097414538264275, 0.15187098351972445, 0.13896239761795315, 0.11711837404540607, 0.13904239689665182, 0.1596434393099376, 0.22726277873984405, 0.1422507275960275, 0.08945836219936609, 0.0780157172786338, 0.12131397319691521, 0.14248451005135263, 0.250089063176087, 0.10505603666284255, 0.11838418112269469, 0.12344165545489107, 0.12228115701249667, 0.1503122935869864, 0.15117093894098485, 0.10803091738905225, 0.09814884872840983, 0.13786128456039087, 0.1507787864123072, 0.09181484646563019, 0.1305642104042428, 0.11161894271416323, 0.10028873104602098, 0.18893814379615442, 0.1475167971636568, 0.15622736832925252, 0.24564699296440395, 0.17166642844676971, 0.1668762019170182, 0.10700018876897437, 0.214168124965259, 0.11598926463297435, 0.13933555116610868, 0.1876252463885716, 0.11598830111324787, 0.13337961504501955, 0.1270985385136945, 0.2073274063212531, 0.1698007421301944, 0.1446254373128925, 0.11679216154984065, 0.1667217402053731, 0.12567726549293312, 0.1027112706963505, 0.08475014341196843, 0.14750189653464726, 0.16639794329447405, 0.18606670573353767, 0.131544666364789, 0.1661353638129575, 0.11631705132978302, 0.13386607037058898, 0.099174311916743, 0.21635388982083115, 0.10106111424309866, 0.14407317766121455, 0.09571183592613254, 0.14927804337016173, 0.14255889106009687, 0.12500286953789846, 0.15387080263878616, 0.052891713101416826, 0.20794773660600185, 0.2008388066398246, 0.11429801609899316, 0.15632696369928972, 0.07503121492585965, 0.23136597499251366, 0.14140113389917783, 0.14107796124049596, 0.18437813062752995, 0.11592663585075311, 0.07137192985309021, 0.21377688167350634, 0.15514932546232427, 0.12227047687130314, 0.12999607303312846, 0.1316268098141466, 0.09706708070422922, 0.11084911759410586, 0.08227717503905296, 0.12429829234523432, 0.12769666713263306], [0.051020968306277475, 0.025959643801408153, 0.037815472443721125, 0.012050831973153566, 0.04014322753729565, 0.04571827141834157, 0.02205095300450921, 0.022779562211196338, 0.02090343663335911, 0.04306344887507813, 0.03795343557638781, 0.0215852744212108, 0.01895202080985265, 0.035468022871230326, 0.05605201369949749, 0.05660080603723015, 0.07025761250406504, 0.020858627877065113, 0.039154001511633396, 0.05253666626023395, 0.03777915385684796, 0.05095879074984363, 0.02782774230997477, 0.027579907394413437, 0.03180095500179699, 0.02036536345258355, 0.018600181742970432, 0.027353509096428752, 0.046524079250437875, 0.02067033271305263, 0.025876938864322643, 0.06068159706358399, 0.05020331325275557, 0.055147957389375994, 0.012383861201150077, 0.05978010222315788, 0.02163238510755556, 0.030427562804626565, 0.022843748231285384, 0.01584966031701437, 0.03082966265667762, 0.01820194105883794, 0.025414371364084736, 0.014043604506046643, 0.03131870998601828, 0.032170943184090514, 0.015772400623453513, 0.03247724406953369, 0.012252565523210381, 0.09285799227654934, 0.0016143347872587452, 0.011078422589759742, 0.041684971057942936, 0.022542412525841167, 0.024165836395695806, 0.001290234231938874, 0.027668235690465996, 0.017033683568505303, 0.028295062948018312, 0.08217544906905719, 0.07431141819272723, 0.015351069392636418, 0.04578169408653464, 0.0447773469079818, 0.013631801603228917, 0.005391502703007842, 0.06677570327052049, 0.016975928364055495, 0.014120493549853563, 0.0027522991877049208, 0.0022656121000181884, 0.0213988197834364, 0.0259670500111367, 0.027632804288129722, 0.013105084554159215, 0.03054609608703426, 0.013821828727876502, 0.060336677357554436, 0.05443830814744745, 0.017931994383356402, 0.05771711149385997, 0.06015637703239918, 0.08631059753575496, 0.07682181455727134, 0.017083318405119435, 0.020203833102381656, 0.030129950560097183, 0.018330504785158803, 0.018959047039970756, 0.033712184588823996, 0.05785461661538907, 0.0344110586946564, 0.051803695769714456, 0.014887170267424412, 0.013507998648232647, 0.08436185174754687, 0.010634988928878946, 0.058055734394916465, 0.10122126207820006, 0.08000495803675481, 0.044858184177428484, 0.042491152084299495, 0.045460251692150316, 0.012449111673049629, 0.0709197066192116, 0.07960518555981771, 0.0422101130576006, 0.00989310079187687, 0.0324760328845254, 0.044230077881366014, 0.077268690935203, 0.042887681163847446, 0.03307855162503464, 0.04609268704163177, 0.010901759212304438, 0.044895585027656386, 0.018770897760987282, 0.029618389438837767, 0.08168202518884625, 0.06636918615549803, 0.08550498647881405, 0.061006778185921054, 0.03599259150879724, 0.0339080267585814, 0.009692264604382217, 0.01733304134437016, 0.06313070814524378, 0.006291730379286621, 0.047978427460683246, 0.09779482986778021, 0.018188480620405505, 0.050390449818223715, 0.029048484483999864, 0.046461857589227815, 0.055526691888059886, 0.03793950864513006, 0.02425010365966175, 0.07164479592548949, 0.029067798983305693, 0.027838191749261956, 0.037344511465302536, 0.028740975806223493, 0.02395029635434704, 0.06402895958828074, 0.019431102156106914, 0.05749898962676525, 0.052896048940185986, 0.09187592140265874, 0.050256815738976, 0.023149260319769382, 0.015530161925458481, 0.018570336380175183, 0.040564472254897864, 0.0042859337907949725, 0.09156972569014345, 0.05468476563692093, 0.02752647954704506, 0.01922270199949188, 0.018005771495934044, 0.0251359141631318, 0.023008579654353004, 0.024967440703351582, 0.047099035898489613, 0.05966902604060514, 0.029919828620872328, 0.03554535889998078, 0.04560597726543035, 0.0052441376194890055, 0.022215387484590923, 0.036848770388002904, 0.07658102962055377, 0.02906915944601808, 0.05178342453603234, 0.03115039598196745, 0.03598515476499285, 0.027194448613694737, 0.0305430630355009, 0.03129815376762833, 0.04662400031728404, 0.018779240349041562, 0.024986887516986047, 0.035172334273478816, 0.010346338435608362, 0.01838313365754272, 0.07720779920262949, 0.017570481103445803, 0.02325674026672329, 0.01961436089394348, 0.05546006314190371, 0.05878714086221797, 0.022986542533284852, 0.015876696544832418, 0.020618049893528223, 0.0411460072999554, 0.018826646198119436, 0.05023626291326114, 0.048889577854424715, 0.04886381048709154, 0.06485580879130534, 0.021864028481234397, 0.011306283130709614, 0.01293412087086056, 0.09467406411256109, 0.028422502002545764, 0.021715605731255243, 0.0634086225181818, 0.013368940529679614, 0.09307411925068923, 0.025192403899771825, 0.03532366454601288, 0.04195448177467499, 0.008679625727901501, 0.05632016056084207, 0.024717724549451044, 0.01665196012306426, 0.021074130598987852, 0.00887291066880737, 0.02335433565479304, 0.050142933814121146, 0.02892140844570739, 0.06381608279688017, 0.04824132246098348, 0.025073558491255556, 0.02452609608215945, 0.03625279951042362, 0.05658062979845064, 0.007624460517295769, 0.0026485441859611975, 0.018983560813856975, 0.005988568566473467, 0.024219226923638155, 0.019940089933308106, 0.021663031141672815, 0.027939644608912722, 0.023597860176648413, 0.057710020802915096, 0.0180479882484568, 0.06337908588882003, 0.0073518455028533936, 0.03356807392888835, 0.038628164013581615, 0.07201412932149001, 0.07172493769654206, 0.09708668358091797, 0.02763729788629072, 0.014913139498925634, 0.014198560700086611, 0.00283153320612785, 0.05188277902613793, 0.08699698998991932, 0.037701074832252095, 0.054241237829306295, 0.024298727479098097, 0.05924401884632451, 0.02158597331228001, 0.036546462681144476, 0.0448105849458703, 0.02509035392930465, 0.029086458696318523, 0.1438026593199798, 0.013329024859038847, 0.005661003241714622, 0.03453933573993189, 0.03362846354554806, 0.02339249137522919, 0.027611196340460862, 0.04666172686432089, 0.03724573712263789, 0.02555073145776987, 0.02737698471173644, 0.03015625736277018, 0.03721616995920028, 0.05953857768326998, 0.07874640449881554, 0.08971370849758387, 0.0370556116104126, 0.04788060985239489, 0.0618994656418051, 0.07061346340924501, 0.04430654199261751, 0.04689912251862032, 0.12331269308924675, 0.03849361391205873, 0.007885222373131131, 0.020745251460799148, 0.04487646730350597, 0.06505715048738889, 0.092065354809165, 0.06395519604640347, 0.08168278514806714, 0.01045870892370918, 0.029418235179036856, 0.01211984661806907, 0.01829705131240189, 0.04895712601553116, 0.05381929422063487, 0.02526332437992096, 0.038029858975538185, 0.05045449334595885, 0.01605160760560206, 0.044689853210002184, 0.04932870875511851, 0.09646473159747464, 0.03205904936684029, 0.029631481772022586, 0.009467417607083917, 0.011245510989933141, 0.007805731995696468, 0.0332722530168082, 0.027074502282110707, 0.05199495104274579, 0.005806481149712843, 0.04259214862915022, 0.03260330569797328, 0.035216442442366054, 0.012358550148616945, 0.018360221226300513, 0.07767043794904437, 0.013037521126014846, 0.02108872927991407, 0.0674862176445978, 0.04713366832584143, 0.039483515080064535, 0.0423484731332532, 0.05979811054255281, 0.010700715223460324, 0.03351409646815487, 0.0227868344102587, 0.028959131600069146, 0.018176747053595524, 0.02695049831111516, 0.036605088106755695, 0.05164310010150075, 0.031583538811121664, 0.03542245924472809, 0.045329833868891, 0.014932794962078333, 0.0503217786816614, 0.11740749781685215, 0.038048790102558475, 0.054823906027844975, 0.037083255127072334, 0.013936200894282331, 0.010011952985743327, 0.02164511103183031, 0.04519827949947544, 0.004693719342217914, 0.030193994087832313, 0.017255050529326712, 0.007614293518210096, 0.022899172667946135, 0.03201322789703097, 0.14200781205935137, 0.06768055007393871, 0.13766431941517762, 0.087233812282128, 0.14256388507783413, 0.17441813221999578, 0.0949560021981597, 0.05641180689313582, 0.21092920590724262, 0.11862932225423199, 0.09600076292242322, 0.11150652981762375, 0.1119728869359408, 0.1453221977821418, 0.15729923652751104, 0.07105933555534907, 0.11666344345680305, 0.21408872279737676, 0.11571687353508812, 0.11123867811901228, 0.09463855637503521, 0.13918193083788666, 0.14034217143697397, 0.1409672921789544, 0.11105752962508372, 0.12302574062986033, 0.28450083093983786, 0.12715930810996465, 0.1280848163047007, 0.09653590992093086, 0.09467970952391624, 0.13932902365922928, 0.19911297996129307, 0.09692509725157704, 0.18214604897158487, 0.16400944574603013, 0.1479623368276017, 0.05215577402019075, 0.13154292931514128, 0.1631788510297026, 0.13399989104696683, 0.2543195661689554, 0.12891200477523462, 0.10793136273111616, 0.11768250805991036, 0.11433403273778302, 0.07338925517563309, 0.08493948860892228, 0.08869072196206876, 0.16455677923347267, 0.12966232879885606, 0.0898932149367673, 0.15170888150376932, 0.08792721400303499, 0.07021875958889723, 0.12893924117088318, 0.09400653493191514, 0.07146169325070721, 0.1545427965798548, 0.20592579724533217, 0.13743527313428267, 0.19806986807712487, 0.08964679815939494, 0.15442418865859509, 0.157276057771274, 0.13098925831062452, 0.18254491899694714, 0.14139429426618985, 0.12363072245248727, 0.05763873391385589, 0.20162175462714263, 0.08448846638202667, 0.16314286153231347, 0.1515341858778681, 0.13793759260858807, 0.12782467954925128, 0.09173334083919014, 0.15823661908507347, 0.14218523539602757, 0.15450011672718184, 0.16046038190168993, 0.11755279930574553, 0.11492587812244892, 0.2384398111275264, 0.1868004599320037, 0.12816849324320043, 0.12452698578791958, 0.11048197586621557, 0.139405277424625, 0.16918723790773324, 0.135140915534326, 0.1871969686555011, 0.16228626535407134, 0.10105599130370788, 0.1277283818594047, 0.1597370771425111, 0.1923598059053932, 0.2820602219019617, 0.2510652036539146, 0.1927488236022847, 0.14488866818802698, 0.20956805108913354, 0.15019820470895084, 0.10113578702190093, 0.17575906669454916, 0.1295927789594446, 0.14844586088189057, 0.11065392342529126, 0.11011526161538703, 0.14116862708968775, 0.19442332589200564, 0.1674832193447011, 0.10875509067305497, 0.14894790894218854, 0.06607635079749993, 0.09200623405299016, 0.08957679370152098, 0.09321256753589426, 0.1479618889944894, 0.1213199035929782, 0.17005302145012788, 0.20666816883853503, 0.15420678603862012, 0.10280926472374372, 0.09475667575108153, 0.11252057326159307, 0.2294554646526064, 0.08788038151604788, 0.12140877810972077, 0.1996641539569412, 0.15549050644040108, 0.13226356064634665, 0.11186496594122478, 0.14117284757750376, 0.14815077957298073, 0.10881158549870763, 0.150892848148942, 0.12270195728966168, 0.2142462514873062, 0.14285166534994329, 0.15694094289626392, 0.23396158857004984, 0.10859195049852133, 0.15082921513489314, 0.15005195327103138, 0.1499352723892246, 0.15143919097525732, 0.15335963506783756, 0.11873342309679304, 0.09791492378073079, 0.12273380772343703, 0.18016735943300383, 0.1502065642603806, 0.05153135895462973, 0.15675448147313936, 0.10994488147220441, 0.14209360602710927, 0.092172583698162, 0.11351271359516041, 0.11656764788287026, 0.1311549429914781, 0.10079529814954315, 0.13196932072085993, 0.09126329927572183, 0.0640718022893582, 0.13303231368107454, 0.09233877049492938, 0.048185950610786676, 0.0938966665416956, 0.09478903508612088, 0.15087690257600375, 0.09551919983433825, 0.09754449794335024, 0.1403431078152997, 0.10860009970409529, 0.19748616511268274]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.08030261099338531, 0.013420912071264215, 0.02613088229138936, 0.023361310994784747, 0.026311357339311923, 0.02805983690944101, 0.022298623375328522, 0.03187450480514339, 0.026546456152573228, 0.08537921322775738, 0.06816494943840162, 0.026522184954956174, 0.05067707997347627, 0.006755065896348762, 0.013169175579345651, 0.03913911445332425, 0.053033869580498764, 0.03036623341696603, 0.05898464883544615, 0.06458790959524256, 0.053122672851064374, 0.05478793349383133, 0.02616614236363343, 0.11374066743467535, 0.07746346441230603, 0.04466021140771253, 0.05007581652275153, 0.05424793836261545, 0.027213235552023565, 0.025389138343078748, 0.01484587462618947, 0.04883775134970035, 0.053186112482632907, 0.025140324640753012, 0.019752059397952895, 0.028138404479250312, 0.0347993842858289, 0.0389234183489212, 0.02777346968650818, 0.027916676198531474, 0.06799967187855925, 0.012957810224699122, 0.022956186572888067, 0.006551155097050858, 0.01840181372660611, 0.036014470870473554, 0.024455623435122625, 0.019519920693710446, 0.03213920470859323, 0.047667929836149724, 0.074368862967406, 0.004333097063603678, 0.12834852215434822, 0.03541871712410024, 0.009067227831110358, 0.04874892093773399, 0.057885510314788134, 0.003798020463104227, 0.03740200373743262, 0.05856086978954928, 0.04793269080775125, 0.04373691523713725, 0.020370747627956525, 0.0975647047162056, 0.01991894338945193, 0.051420099567621946, 0.01386787835508585, 0.006410150855247463, 0.03853917075321078, 0.05042546222518597, 0.06266350964350359, 0.018230943341872523, 0.04012463228510959, 0.011566366451526327, 0.04707097169011831, 0.01569454381907625, 0.015301242869879519, 0.014094843229811107, 0.03730972297489643, 0.03342946618795395, 0.05484374299911516, 0.04183757019096187, 0.015127303810524089, 0.049949137427444966, 0.046819041815719435, 0.04320711848725166, 0.014237600212384547, 0.03270742689658489, 0.048618184203015904, 0.0156468003988266, 0.008657334156201353, 0.050348489212670496, 0.006479402139250721, 0.018506326779190983, 0.06365225051662751, 0.043275752304387946, 0.05312215377177511, 0.0373008511295276, 0.032991475226091485, 0.018692401437354938, 0.045474938582628965, 0.004807019847378666, 0.05812197298343692, 0.04026019340381026, 0.04880553789969001, 0.04214941131483231, 0.01598927059343883, 0.02909665707764881, 0.05251105156327997, 0.04455132350059492, 0.012706175513033355, 0.08218570173318897, 0.054234072499509366, 0.0512714732571372, 0.060489910920815806, 0.08926898307566132, 0.03064187809026667, 0.05076796295387404, 0.032898498965161185, 0.04240263379844172, 0.04258952269862805, 0.04203896616984691, 0.03210579364427498, 0.032987061355795176, 0.013530267319375915, 0.03937275780897055, 0.009644255707306522, 0.0472011554187962, 0.025564710975491574, 0.05043636967561074, 0.045020544036690674, 0.0353119564242661, 0.028156236379540393, 0.019507851252066236, 0.030304008363080875, 0.06311458615320069, 0.06725527146565062, 0.021495307463088205, 0.05118446131902082, 0.057262771230723174, 0.03563582118866699, 0.06015741519097771, 0.02047569494295333, 0.06383181123861245, 0.03377243510580488, 0.04718302496309791, 0.025029155159635202, 0.05584360845386982, 0.011976881834146167, 0.053351373079099824, 0.019179996701755693, 0.02571677745852087, 0.06085568879331861, 0.06211228815040418, 0.054466816796255965, 0.11412466397242886, 0.00850090554117092, 0.012847798493956881, 0.029736332395779233, 0.010758065851405263, 0.027796946998153414, 0.017014133278280497, 0.04632045767669167, 0.03479092973949654, 0.030844346154481173, 0.03946283333269613, 0.023355110881051848, 0.07008041986929518, 0.01914963565234627, 0.0483287686615118, 0.03788488657612886, 0.0304184602573514, 0.06041865795850754, 0.034420527650841644, 0.04482531933380025, 0.04213861921536071, 0.07039610828672137, 0.03561870175014649, 0.03777408520025866, 0.03981219744309783, 0.020333962548258047, 0.04037585309041398, 0.08988233123506818, 0.01944796714399542, 0.055751996048327, 0.06647248632673707, 0.02874624802331839, 0.05092944411028709, 0.06031138835740941, 0.02026913531257638, 0.042648053129336665, 0.015623297642118164, 0.0447600781917572, 0.03317414703113692, 0.048828214540013244, 0.025079130960096205, 0.03261892218142748, 0.03592455480247736, 0.02359046584128269, 0.08520366264773266, 0.06252901043210711, 0.022439373590584313, 0.026220297939809303, 0.06143414668206658, 0.07389772217720747, 0.05849581863731146, 0.012881182416874384, 0.03662733727001718, 0.04315462362553392, 0.016328605956264904, 0.01668141023921115, 0.062003878610474725, 0.0336228249195431, 0.02523427120675998, 0.032357703162623305, 0.028068098073293055, 0.040295836848339865, 0.02723204793541559, 0.01611827197484672, 0.03217691429225462, 0.03240511918972645, 0.006627839732183409, 0.031493744879428826, 0.017114269779995084, 0.006532733719463327, 0.10364150149481637, 0.08237219708306448, 0.04001691145822406, 0.03733667777851224, 0.04274307856602328, 0.0227904255568449, 0.05207804783380457, 0.010475983577115195, 0.020820909811715995, 0.0438832311358835, 0.0170941054155784, 0.03445434583617108, 0.02350051245386047, 0.0728276724527989, 0.07352512502776724, 0.05196404716532145, 0.037884123224232874, 0.023446210992655585, 0.011377911831784462, 0.032860446721315384, 0.05669743960191097, 0.05829291631068502, 0.048579982681466, 0.03878670711336391, 0.024081131476642828, 0.01303863137893911, 0.04094330174848437, 0.026623512285628488, 0.0516223403226052, 0.049253666174731085, 0.07719174506408827, 0.07669374785785164, 0.032175991484629254, 0.020087968158934797, 0.01925215041930122, 0.026844417842637216, 0.021929507110533968, 0.032590477993445735, 0.03722762702299016, 0.029872222603963952, 0.07868154333638293, 0.07122768687882594, 0.06938281123127256, 0.0040021314302326316, 0.0366611113505704, 0.06026935989835432, 0.061518529296985695, 0.07315899431705475, 0.03348353864359004, 0.06463259791157075, 0.11167238413223199, 0.03273504327184387, 0.02036111582336681, 0.012725987887409116, 0.009265678968014461, 0.04415781390187996, 0.06984614208340645, 0.03196090945441808, 0.022920175023110848, 0.014787198310451848, 0.05794695166072675, 0.05067090191213148, 0.10503618951354708, 0.08120726102164813, 0.05134007654019764, 0.027686440785016333, 0.08794817394976105, 0.011045336374081671, 0.026503511671242968, 0.02063260616601578, 0.015299746700163399, 0.037104004727942605, 0.023748673066230755, 0.059694315040750165, 0.03738419558586819, 0.01535832293198577, 0.035417119174131324, 0.03695491701364517, 0.060407502842800956, 0.03868662998346346, 0.08720741048455238, 0.037910857503967624, 0.03697052671174918, 0.01247200374824128, 0.01641387745205845, 0.021827721768724065, 0.021719846575121795, 0.043486915794866424, 0.0209918972437403, 0.03384490603847163, 0.022763467360553995, 0.04208481478105698, 0.06704856934291975, 0.03739944566041231, 0.03474749332027776, 0.004009559692349285, 0.06024364342114755, 0.012999136400009905, 0.01431919913738966, 0.046199071154530556, 0.10742145044995205, 0.04656577862000891, 0.015488908692662205, 0.04323301138356328, 0.04081827149327312, 0.03840869864714997, 0.009464218314470989, 0.055952516717037985, 0.00991021768589105, 0.022251261631026864, 0.014097328364316906, 0.023660782425265228, 0.053714073795293055, 0.027124617182250534, 0.056254603900015354, 0.026607366544859748, 0.06035400035658053, 0.04586258563878281, 0.01322886545676738, 0.03467801472704325, 0.025741464258836846, 0.031179627270570824, 0.003770834533497691, 0.05192227315689836, 0.02531929673360927, 0.05351975154397743, 0.022460338626323, 0.19813992003245012, 0.16365769319236279, 0.10278739554009267, 0.19006840671811784, 0.08397524284997157, 0.1579735510583435, 0.12756104155310563, 0.1134401239188654, 0.07644659826265914, 0.16227839434785502, 0.13366417906114034, 0.14019141452653067, 0.10297743284276553, 0.17612554345812115, 0.09002350044569798, 0.11624098755419254, 0.16148125140794686, 0.134394499872412, 0.11168267750846488, 0.11611678850437913, 0.16979927649455412, 0.16643685049244336, 0.052714320298816474, 0.20566054433584213, 0.14508297347596713, 0.12556229451937334, 0.1223398367209094, 0.11694704395319734, 0.09522943145462445, 0.18984436802566051, 0.09471153281629086, 0.11505030787416867, 0.17387795049164975, 0.1792401820421219, 0.1776568612882069, 0.19107011439544813, 0.13627828950328486, 0.096532021915274, 0.08722381067595311, 0.13592999747821263, 0.25503134940351757, 0.10896022537989275, 0.10829323224191155, 0.11065884280417647, 0.09300118352153472, 0.08831393825156347, 0.19568556387509617, 0.09810340045286076, 0.057165930712861676, 0.1880749115454299, 0.18947546210672173, 0.10744516524885382, 0.20401342771947384, 0.1669049718018089, 0.11518623200910431, 0.08861796265201909, 0.18241814151406288, 0.07366653172565357, 0.17868147630776676, 0.15602573486311094, 0.2560307229203837, 0.08122488936143261, 0.12866098753043584, 0.1245967120464359, 0.14839422436697142, 0.12599384279123374, 0.069123943336308, 0.10836789823536362, 0.10987966747156211, 0.16389858669468335, 0.2215286014335496, 0.12713599364672387, 0.0983607212879828, 0.07294195810598986, 0.11486516280898026, 0.08885127691818134, 0.10310688375362329, 0.1610866425825017, 0.1340064728366477, 0.12627250355269226, 0.1235125759350402, 0.1253177776400532, 0.10513831581920385, 0.11741311608680657, 0.15172790762569222, 0.11704290738063199, 0.059629752433725765, 0.10138046674962554, 0.18131046023752007, 0.22979836910963058, 0.2759941459766456, 0.1207617949694395, 0.09569078776985407, 0.09648170175829104, 0.16677854715713433, 0.17259466435228074, 0.1358573670898165, 0.17850960338754313, 0.1414305687482868, 0.16827783813433989, 0.14276447360004696, 0.06809773375945431, 0.12231056472020489, 0.1134505190753511, 0.11751296930015087, 0.15639198092477663, 0.12423285442803587, 0.1399014222302607, 0.1158611707921539, 0.12894561940005847, 0.14203659551484243, 0.21326819754072598, 0.13798506291849272, 0.11044950796557323, 0.17474013779844555, 0.22686347445206984, 0.11803378563906465, 0.14461131021380424, 0.18935325794986316, 0.1292178612202406, 0.11124876793473959, 0.07210192496755294, 0.1056278720498085, 0.11034639778413943, 0.08314861756350313, 0.10604118130036763, 0.177718065146889, 0.12969123439065047, 0.10628078558615275, 0.20358204229601792, 0.10656482713030917, 0.11371082546455519, 0.11937801779380866, 0.057931664266756604, 0.1416350792029074, 0.1872464609997613, 0.20497826380389078, 0.1839100636009659, 0.1384435761719942, 0.1252096870115825, 0.16071870018328938, 0.13677306366818293, 0.1342226540935891, 0.1320622664477144, 0.1797441571418728, 0.0851899901671069, 0.1588624862155744, 0.1069210512297494, 0.10234241227486304, 0.15896674990653992, 0.15398969554475375, 0.14406865861799034, 0.11941054676260267, 0.1585685448454959, 0.1591571739741734, 0.23943622623171124, 0.16836276357727392, 0.11057576976184334, 0.08521686015384537, 0.10643027363611118, 0.1333788957978998, 0.17770984130246298, 0.16706946226102964, 0.12698130123317242, 0.11805703224880354, 0.17341061628290586, 0.09840313651199852, 0.10249919457627193, 0.10367503469543797, 0.12284815444477967, 0.1244581009128264, 0.07564808468201331, 0.12854058827672685, 0.10415882337838411, 0.11975194487188544, 0.16825218951063498], [0.007643110900452095, 0.014404221271563853, 0.04276885611138173, 0.05075231593634401, 0.014096193514498217, 0.03886357156027641, 0.05553981136264546, 0.02200571846749101, 0.04156083307628121, 0.010843360247755689, 0.0184989629779011, 0.028449034418112466, 0.002275400815830965, 0.09459436338927064, 0.028473473553146635, 0.059653548656829765, 0.031880621798336506, 0.05587756234620299, 0.030656951745705943, 0.03867940358551485, 0.024055423481123786, 0.04772395647263952, 0.006895216032197433, 0.02132783823513559, 0.018194846975217973, 0.006807769407584731, 0.02125299582257867, 0.025151803756930997, 0.017096768665526594, 0.03332077505599175, 0.03312626960022109, 0.04573323990085295, 0.03474098616944892, 0.025141920894384384, 0.047239421401172876, 0.007523710789558078, 0.054839356270219596, 0.018012599254559194, 0.03447531256824732, 0.024033539030434828, 0.02449360443279147, 0.05473579825567348, 0.06361426612628357, 0.014837265713140368, 0.018341217156765715, 0.05405615043959447, 0.011524855375422962, 0.015746024270941104, 0.022218076179602315, 0.03444679034873843, 0.04782970615529588, 0.11543799564242363, 0.011790018379023033, 0.030815382887210165, 0.012628166886445667, 0.032171316378350766, 0.05138641369662114, 0.009286321699619293, 0.021715020494801656, 0.03142119252255984, 0.0341865518130362, 0.05091823810445411, 0.03542032864476953, 0.021144357277080417, 0.09659178049436637, 0.023428199280585562, 0.007816234021447599, 0.03580443374812603, 0.060986035370400975, 0.05341746238991618, 0.04349902085959911, 0.03863624197297862, 0.06946933801685061, 0.025551706851859177, 0.04611793193700058, 0.05183463018121464, 0.02656786223607404, 0.008703837553704423, 0.009377073213857199, 0.008063735606681024, 0.030817540628569465, 0.026450317918456027, 0.03757080967937197, 0.0256936190583344, 0.049468280015779395, 0.040849409465278895, 0.026724844705313444, 0.022312473971396685, 0.05349615548870393, 0.02895053456138287, 0.010789847583509982, 0.031595592985727956, 0.03633776566545878, 0.03792750536065016, 0.01951418028745268, 0.021525449684954116, 0.023962599890572683, 0.0724311705146517, 0.02481572705853198, 0.017558432017852153, 0.049980319504226954, 0.032326551619917154, 0.017148661327415278, 0.005087077966891229, 0.008654410518439752, 0.1250886092228549, 0.06386599583285195, 0.09059323915945632, 0.03251914021426013, 0.014488149268020476, 0.016355235063071762, 0.04332755845306175, 0.028630181215703487, 0.06206584921372788, 0.03774714396734323, 0.07446373573371343, 0.039195622849677286, 0.03391504959602441, 0.07041410303541593, 0.016589334733518105, 0.027257226673620086, 0.06626901403069496, 0.045190900431147644, 0.02453852175468845, 0.036854629537888935, 0.017186710178585987, 0.03756425503109183, 0.10975915286689997, 0.008874005654693713, 0.0073145108097898105, 0.022154460128928934, 0.0334593081580741, 0.02963549530665789, 0.02347019381288971, 0.05064951448834368, 0.038695827525641234, 0.013525184243917465, 0.05764220801315137, 0.029511391251747097, 0.00959591772074678, 0.044329188098864894, 0.0084322632423469, 0.06437631523502724, 0.03928247533206429, 0.011974650302103587, 0.07751742151698895, 0.09121935056256396, 0.06160088987754924, 0.01709164402979825, 0.04533001707334604, 0.03701688422422324, 0.012219460647819298, 0.04056933056563139, 0.02007830242759415, 0.027893176834498132, 0.11312793674213545, 0.04032383659588439, 0.01626769726031593, 0.026122407389006445, 0.03281744795718363, 0.03596606757491827, 0.021482405119708607, 0.042643914065722904, 0.023615471553057432, 0.06899317606751408, 0.010290483977379543, 0.007879067212343216, 0.029159567451902797, 0.03643099976969617, 0.017916359240189195, 0.0897180579070534, 0.048423010390251875, 0.036990037986210415, 0.05989689167056765, 0.029763195597167526, 0.03152546299887555, 0.03954624903521367, 0.0765148453148348, 0.03480181344119566, 0.05513406777754426, 0.009963071322999895, 0.023306965428803648, 0.017180160619318485, 0.024737067886495163, 0.024781813878299933, 0.02707593229466251, 0.03806691377290657, 0.01050478229964418, 0.05238719856632607, 0.11229392220931393, 0.07769500091671944, 0.04119295853057078, 0.036566102877259254, 0.02711110415735415, 0.06898286233523063, 0.05236104104135718, 0.046370726943548234, 0.02546268475375005, 0.013164092503887202, 0.011252746717738253, 0.014762380892144782, 0.03902416044313993, 0.029958729033491442, 0.02909411596400397, 0.04080078225316746, 0.014724725591284888, 0.04283861290397389, 0.03971501426505191, 0.008488830162345298, 0.02336758914004479, 0.06575429093624864, 0.024202297474922876, 0.023105030014578785, 0.034884197770484855, 0.01646175657931183, 0.02152112402421023, 0.02068117230997554, 0.04561521891238434, 0.045039933174848557, 0.03962901673678841, 0.024060278399182216, 0.04695092527461903, 0.07303913789136068, 0.0939070549128311, 0.052788891297365935, 0.016358251151229655, 0.05936473022614207, 0.04106397920155099, 0.042856570333242416, 0.029245436058512757, 0.04836251560066428, 0.04708405045260276, 0.06215214529739959, 0.018593345502657548, 0.07176653867853539, 0.042942693390484364, 0.051587171852588654, 0.012881102689009691, 0.019871942965047698, 0.0377229575866035, 0.08572020421602897, 0.024711773797337497, 0.018429156991520097, 0.04057860613933631, 0.030872108414769173, 0.037686744172658236, 0.03682871289285166, 0.035193284042179585, 0.048376693589878936, 0.05776416789740324, 0.05065662553533912, 0.04799694807401725, 0.02806671386185501, 0.036940162269664664, 0.05109368690422603, 0.008034954695696277, 0.07974402739533357, 0.12335439585149288, 0.0923857997570719, 0.013097188951048468, 0.031961289434028525, 0.04479577931176339, 0.05363023740106395, 0.042969166434236934, 0.03313163002686841, 0.02321991277858615, 0.027711032590429698, 0.029264920191573243, 0.059849957403327735, 0.01580317218654922, 0.03395544617835965, 0.07208461553922721, 0.020841481297143867, 0.013392916564563555, 0.032264614943414927, 0.04844335965546114, 0.042604691348969936, 0.040564869197883775, 0.011186996674431222, 0.016088687848033648, 0.09667804943663733, 0.034412524330296686, 0.0666447663679719, 0.10712746158242226, 0.014840697403997183, 0.02970925884853516, 0.020763979027313844, 0.05509201217708843, 0.06831156728523118, 0.060498229760144434, 0.05214275971853307, 0.06124076420175178, 0.012782506461787437, 0.022893048889402832, 0.011193328254323984, 0.016385791191299046, 0.03058698121458292, 0.030976009089499712, 0.009260356708961939, 0.052911034386072836, 0.020020603202283382, 0.058097545722765584, 0.009186823020822235, 0.038191940635442734, 0.036766518373042345, 0.04792697415021913, 0.04385069198906422, 0.009137978677504828, 0.02204091238257076, 0.038350487127900124, 0.019918168163193122, 0.048076431666101725, 0.026147160346486738, 0.011788433151585715, 0.03018193312787584, 0.053814235742070844, 0.09735002302165542, 0.0411713098708008, 0.027099855743082504, 0.06228846976799624, 0.022243568740252937, 0.04030697160799589, 0.04915890197402664, 0.013675940306191998, 0.04065283787037645, 0.05818101231540952, 0.046392694514776976, 0.037058152724057436, 0.02341048782026129, 0.08316448171223913, 0.01540690434298345, 0.07344852520951203, 0.010835580843766885, 0.0898460771090218, 0.04112800915858575, 0.04198779105874045, 0.0428968922767256, 0.046991617019687376, 0.02282340405508876, 0.06948517502418586, 0.04479608125984669, 0.02349844970740378, 0.03912163878391896, 0.019322511108059968, 0.08816556978438582, 0.038106007568006, 0.11838822519140584, 0.0594592433688896, 0.025494390998833945, 0.017554711949612414, 0.024780804557459693, 0.05442770603778107, 0.12894703075289726, 0.23415279973830494, 0.08476492869002478, 0.13773810331310543, 0.15741390894566262, 0.10192520144794669, 0.22637448140553065, 0.09406464467091219, 0.1662219041692359, 0.14433221518993378, 0.13322184208248342, 0.11986728225435529, 0.13288788071700505, 0.3130745919687407, 0.18714170876358235, 0.1716766200427498, 0.11923069427055971, 0.1423750352114439, 0.2970238189612116, 0.1491457833243268, 0.13156092406383582, 0.09669499245605298, 0.11861351238829748, 0.10194920801690646, 0.09118547809443303, 0.09994848644626991, 0.1496640212301697, 0.13088874013296195, 0.08676053410662071, 0.11766435046281133, 0.13553445227444172, 0.14398422172026976, 0.17005944039140428, 0.08871326968073845, 0.12487468070217542, 0.09285898293767657, 0.22512506773429258, 0.18285547090428217, 0.20391239385519708, 0.0787590727476137, 0.10466788070542471, 0.1482194880289691, 0.1871649418026209, 0.15966294040637358, 0.11322327091225556, 0.26599718098129543, 0.10608618852815457, 0.13982564343937806, 0.1102557930030993, 0.16186019964516163, 0.14115767553448677, 0.16383219882845879, 0.07666629433099713, 0.10910961843494858, 0.11067206066633974, 0.15575920630778584, 0.13207834772765636, 0.1362698349569525, 0.12560616859367915, 0.1021208841619747, 0.12521477602422237, 0.10162881056645087, 0.15029089259249823, 0.13551792316138744, 0.19282532164028712, 0.11251530104449817, 0.11688258312642574, 0.12149915897420474, 0.09766164022896971, 0.11123943807823317, 0.22059465226318153, 0.2141613531857729, 0.17719145411891596, 0.09442808159760066, 0.16090571800512926, 0.15011853112706117, 0.0649977990293077, 0.08580262586474419, 0.10621572086321455, 0.09551197343638965, 0.09964349174073764, 0.2507133425346443, 0.1742260932390179, 0.0692589921610696, 0.12790482810565404, 0.13517446230564797, 0.20569470178868088, 0.1509929999176945, 0.15272964244442327, 0.19780509014214787, 0.15842062421143055, 0.17020801241908753, 0.17383487708866596, 0.15544959077877657, 0.11895617257271494, 0.16595199650951795, 0.11788768347884927, 0.1364361031779221, 0.1309319899550506, 0.09432972794664757, 0.16937538209770406, 0.1769221435700144, 0.1213641305054937, 0.11052969723407711, 0.13909528191600526, 0.18553100233631475, 0.13240112683602742, 0.2770867773464748, 0.091677483836455, 0.09655349076326404, 0.07239320648035832, 0.1421514850642, 0.17619973447706017, 0.11723842046090535, 0.1913487073034048, 0.15419915930501052, 0.08417777876768794, 0.19495824218860694, 0.1122822989044445, 0.12421331261949879, 0.06582888907619885, 0.14076261887592928, 0.1008855365216732, 0.14703783286469324, 0.10786384171141045, 0.18443763814866543, 0.1275424361228943, 0.25031129696539467, 0.11126233863511256, 0.12006677154983793, 0.1394914106598922, 0.18208921487842286, 0.11085533297487668, 0.13841662476105349, 0.21842887704925879, 0.09197540820709296, 0.12139899363475186, 0.0792427257235561, 0.06775114485727889, 0.08969971032014915, 0.16125628990786417, 0.17323575780860015, 0.12257446055965764, 0.11963986445750509, 0.06626391144735472, 0.15742335415312222, 0.12691409912492546, 0.16336890868842602, 0.17149778535323484, 0.1405097967279809, 0.09047359986496822, 0.08118672176663365, 0.11019534231828791, 0.1641354632696935, 0.1338753527296441, 0.24614150928599493, 0.14858082149709972, 0.1934835006083761, 0.14007664711347648, 0.15319025915648254, 0.12025754845568112, 0.1374517615352358, 0.11898160406521388, 0.08552145452371665, 0.15944893046149186, 0.10264047235250473, 0.10688559777502503, 0.12204248910503727, 0.18137246476752417, 0.08751541110021727, 0.19281527932201112, 0.13167540649218218, 0.1449945332216365, 0.09324488615883247, 0.09342264876301799, 0.11806930016194071], [0.013314335424053882, 0.04185644703518067, 0.06984813697636127, 0.036879399458744695, 0.012987562288929309, 0.056090462886329205, 0.06788881961256266, 0.03718619906742658, 0.0524582717168544, 0.05310958391055465, 0.030428522931677953, 0.033906669688544104, 0.021547843036907058, 0.019798888492264917, 0.07479275057890586, 0.02968429893787418, 0.06610225726451192, 0.04464588074811867, 0.055839018164468665, 0.0404744408359485, 0.036214774407978566, 0.04856629663013986, 0.011091290158219635, 0.03549834999388882, 0.042242319722260745, 0.029408304819038937, 0.050732126126864126, 0.043585042136588266, 0.05370927994538631, 0.011886128623570715, 0.018606665145073618, 0.057175409847072194, 0.04724335351160594, 0.014038643566891551, 0.02401276059182627, 0.017614636769784347, 0.027481004130095243, 0.03822258666955999, 0.04430012644401618, 0.05417876511013933, 0.02375379091660891, 0.039648402482271194, 0.030638176681739942, 0.03354768395157797, 0.06625042217118399, 0.03156957456043788, 0.027083937311545014, 0.027067508282405988, 0.01603460351803473, 0.08633032254874706, 0.05209066179980125, 0.020094561822978512, 0.0351792214039181, 0.03797099266999534, 0.006825717082912368, 0.05671867774799466, 0.019918839912861586, 0.006639690346284104, 0.021916784578934312, 0.054137303227824826, 0.06469806297016995, 0.006403890945616045, 0.0158828050563378, 0.021903897502592633, 0.022219745375748192, 0.03507706795686057, 0.05923059742365565, 0.00844549891605441, 0.009655552467198243, 0.04821899526619485, 0.04977679292538336, 0.044562325945922306, 0.015052929587130035, 0.017319745450679744, 0.03831885043265564, 0.015552029412771975, 0.025253592491415993, 0.02096712732288454, 0.04778317900906716, 0.0360433662842427, 0.019111909105309417, 0.06524669245949813, 0.011722898543147104, 0.06163914568190064, 0.010396170895546675, 0.030944657378963063, 0.019630418425159793, 0.04144402327282088, 0.04499450186267495, 0.0352140098943242, 0.06253525295427867, 0.022630102998976196, 0.01430676837584802, 0.01055441883259586, 0.029718765124146427, 0.007104191247240773, 0.025319235665457587, 0.023527614838842834, 0.023319421635408486, 0.011677708959073892, 0.010992762632668018, 0.03291880073291915, 0.11848422432584421, 0.09686187814388957, 0.03366551834291645, 0.03761780162208846, 0.035313615442386696, 0.08124458723302398, 0.024898179241323044, 0.03481423402471202, 0.043113911524415016, 0.03971470892429352, 0.0054059351428544945, 0.050648598466068506, 0.019193250187007443, 0.0575641289885555, 0.013184094868068184, 0.05322308246312397, 0.020432423068476573, 0.04595838121271559, 0.030609135382941792, 0.011264152891401733, 0.024899142761049525, 0.04124405221747501, 0.02680164129872407, 0.06768936424383096, 0.013187052432580717, 0.025292535312473774, 0.06744229607284069, 0.011017611433219696, 0.040033013094216585, 0.013406536458725376, 0.03771368201289858, 0.034931467912558994, 0.03144970117136836, 0.0391125328439687, 0.03015276969277433, 0.03153521015441843, 0.02793106622993946, 0.029013875805373703, 0.03470828417422516, 0.07110066512333495, 0.09470544635717358, 0.028587559038507085, 0.017186113067769578, 0.01009179450505014, 0.012759855266527405, 0.023597704113594124, 0.024876676466582075, 0.04017795156687498, 0.05978497410459178, 0.024071007734164596, 0.04028085479512811, 0.019860309482152973, 0.006117326947527805, 0.0824402677161353, 0.03765314990388496, 0.011057694193108805, 0.02384275194656636, 0.04021621754925166, 0.019151516890685474, 0.04253701765888503, 0.07428042949842555, 0.060907969916505475, 0.1045306334272027, 0.05068930038916213, 0.047349958148385794, 0.006119031342677772, 0.017914810484009128, 0.0114087045990995, 0.030608667193778923, 0.040878369339874814, 0.03628197651622551, 0.015704721844355975, 0.027674147426815968, 0.010859628972996558, 0.06589585369718926, 0.02531887434556016, 0.13150905684701034, 0.04668654767530305, 0.01444076038231807, 0.10695637576282024, 0.062338817066379955, 0.05225077231547662, 0.0319773673212954, 0.0964294613472053, 0.014226347557269037, 0.02542402352472501, 0.05428232991003564, 0.029385105706751347, 0.07471437299890177, 0.027466205281338522, 0.037719317246228456, 0.016483474788921218, 0.03635023035375135, 0.030573264629180943, 0.01773793845703559, 0.032101685114737065, 0.014085987499648971, 0.047868681206767044, 0.030321460283760513, 0.017889490949788263, 0.06579965778759547, 0.10621304743524108, 0.05678862113771694, 0.061594688067478795, 0.0068074335327505, 0.01468970809530999, 0.008315071762938584, 0.04125282906794122, 0.02487329057683902, 0.03230059765545385, 0.030961356125772, 0.0148608956951648, 0.0594437320583633, 0.01374518480484507, 0.007898508936965039, 0.025072652647005658, 0.02577349789706724, 0.027924370785642947, 0.01970027869434229, 0.06674280110746622, 0.04706002352759242, 0.06762242676424128, 0.023917616411511387, 0.03272548610610621, 0.02039856756372111, 0.020137012670082704, 0.09038477284567696, 0.00875737820751965, 0.0437971827174936, 0.02447298714624984, 0.028253553568252494, 0.042830640117504766, 0.025921474510271634, 0.0476948507130146, 0.024745290034583638, 0.01447994917232011, 0.024838030504594957, 0.02215474172096167, 0.023236519923167567, 0.03548277422253575, 0.061442214463438304, 0.02009812243548887, 0.020869375871760503, 0.013009041314944625, 0.02908303209447435, 0.05531992530450225, 0.029079490141677003, 0.009125877853616007, 0.03613738748910172, 0.004360713862947055, 0.011270319926552474, 0.020370934225086654, 0.029327216491635357, 0.04176635794075472, 0.019941211212426424, 0.04397478247327464, 0.021336876321583986, 0.011903857895439225, 0.03306704706379345, 0.06837831477501563, 0.059643730255109925, 0.0532172436692885, 0.031150457050119127, 0.01710541150532663, 0.02854991391567247, 0.05624643773106592, 0.05473002731533987, 0.014204232404673738, 0.02249798035648252, 0.025979267034147466, 0.06132296871926103, 0.02982113230973482, 0.025991207554138133, 0.0878768599193011, 0.02332286859330322, 0.03427694285554545, 0.0059152630357337845, 0.001767171937639692, 0.07261226472577878, 0.04405254597908684, 0.019266767759940455, 0.018246478401124477, 0.026411100290715694, 0.06293747494263308, 0.014064170902461877, 0.03270106902346015, 0.02923732077968972, 0.03756903191762311, 0.030524019950202534, 0.0318566288000771, 0.05897495935537985, 0.04206361395439931, 0.051724018795149665, 0.016316933457606604, 0.07714626964713846, 0.007396633054928056, 0.06277699462537255, 0.009367717912287583, 0.10341626858072621, 0.0399314940774015, 0.028718814852514436, 0.0392245352268219, 0.04819201671385339, 0.022672245112646903, 0.035170705789434056, 0.03320974297821522, 0.02818917416568313, 0.029198481435222284, 0.03753768699243665, 0.0388097094504961, 0.006208605174573937, 0.04727834556251764, 0.028817667226706232, 0.002850995498842427, 0.029888378522757972, 0.019120711400838833, 0.049798841920814345, 0.022382817696779966, 0.023332651371934583, 0.057408004866114686, 0.009092405721146082, 0.012593337683938444, 0.03457600037966456, 0.026815083077443496, 0.08959778078964778, 0.03222765174827405, 0.10330028658998863, 0.06512914983821766, 0.006295792683626392, 0.057033609598875046, 0.04772635170125535, 0.0824754022594009, 0.03524651511439255, 0.021014312648081353, 0.012666325999556907, 0.07143264516655888, 0.07084271325064556, 0.043978443169700246, 0.06912584323436022, 0.0249059823940375, 0.032352858422590156, 0.021561881926442896, 0.008924002659374049, 0.01670451944560877, 0.03557262922238026, 0.052940666010337215, 0.03313583694398403, 0.055682412282164605, 0.030151826529098407, 0.022494370550183312, 0.1545641432915415, 0.09493730177304574, 0.1620663928666285, 0.1031259505876473, 0.15066473824637278, 0.29419364939842907, 0.14453469003949845, 0.12368352604763848, 0.14389233450804437, 0.2084235253610781, 0.10896267489131008, 0.06917540343212229, 0.19347504606204374, 0.12972300340022358, 0.32436704316309517, 0.11487901849406106, 0.14150841028562613, 0.10216467681207828, 0.09989138093910047, 0.11054843158594199, 0.09089049856577601, 0.13285725164626325, 0.05447975306638649, 0.10027415611382041, 0.09963347656386239, 0.12408143255327429, 0.14546831351305756, 0.18129661812313966, 0.16596380301884242, 0.156275015058262, 0.12462466768920422, 0.09864295792898961, 0.0763177919600691, 0.10638223335679088, 0.08399527998907225, 0.14872824001525128, 0.10414084898574011, 0.11828881981117384, 0.12440874427556992, 0.08134254733366625, 0.07230283918657474, 0.14197437385363237, 0.08793385686086756, 0.14558465512735502, 0.14609396351235254, 0.14888720719942025, 0.13206867181829043, 0.0736518075157489, 0.059874988560165675, 0.13039691081004484, 0.19219885739896977, 0.07958696010921683, 0.12118961129869733, 0.13925711251795292, 0.14694057165512017, 0.1107691658128585, 0.11695686914026737, 0.10289660575134413, 0.1336775597717081, 0.10032353310712747, 0.1267952062189579, 0.08194947655179671, 0.15080953761935234, 0.11068441000367914, 0.12098921276628971, 0.11324627324938774, 0.14676177767770632, 0.1012075895975743, 0.11975799740425178, 0.1639860634292875, 0.06927491737795727, 0.15045032118047985, 0.09990754364324467, 0.08392741291650704, 0.12491828336247376, 0.16341074715767587, 0.08820590190589428, 0.07108904181846551, 0.166170240512916, 0.18408059302185262, 0.07877415658107825, 0.18483916803130082, 0.07160423988742487, 0.12335093532289777, 0.1359959239406245, 0.11253040523401328, 0.10908118103231702, 0.12112622255725519, 0.09173362582389798, 0.1807693557015487, 0.24070717660444124, 0.20977655132966383, 0.17406567398990902, 0.07891784994197742, 0.14326876082590648, 0.056437974596129994, 0.14571918148015225, 0.07907035747276885, 0.09381854001964841, 0.1292972226760217, 0.13236019760370255, 0.14515702878790243, 0.21927309674876078, 0.11207552892821175, 0.14138962594526155, 0.15221851558557578, 0.1453875678458384, 0.13111334879483494, 0.12060267850756645, 0.09407250889177833, 0.19148788840642997, 0.0900422687243138, 0.05727250820824078, 0.1706866645919425, 0.08865268328892333, 0.1593768700425114, 0.12844904033201082, 0.12817868483918055, 0.12634651815252645, 0.14152066462806293, 0.11152362211474351, 0.2504735754004547, 0.19728398881852627, 0.09779333030538899, 0.2784966102668217, 0.15960591632340634, 0.09633918904832431, 0.1400192973337003, 0.15769434746887, 0.13995946411575588, 0.19698619336954185, 0.13895069967423165, 0.13777961608554634, 0.11280363092997245, 0.11136813581522022, 0.1373240476740258, 0.09023107109325272, 0.22100174613296986, 0.13208182182695183, 0.09917990983064685, 0.0896827605153833, 0.12278408716831889, 0.15817594448370592, 0.22148544660636357, 0.17917041507150444, 0.13453118396656855, 0.09587605497134583, 0.1098758608901075, 0.07415986061096191, 0.16042688941316946, 0.19155260707650865, 0.11638139002025127, 0.112671316601336, 0.15435995853372983, 0.07550293247082404, 0.1512110267898866, 0.15243982656725816, 0.14911717628794058, 0.1012825405757342, 0.1540006742413555, 0.07321261893957853, 0.14384510847074644, 0.19563350666846546, 0.11367071725960289, 0.1746850407549313, 0.13494184693055494, 0.10497436818799802, 0.1841305603406259, 0.09806960262358189, 0.05271595556821142, 0.15171221989606107, 0.14860204607248306, 0.07803792572979416, 0.13731020555964538, 0.09370331798813172, 0.12992452830076218], [0.019163498122777258, 0.014793361104758722, 0.04420389321499637, 0.051766484909291775, 0.09234210210187094, 0.0088024236029014, 0.005593044142837503, 0.03155206496428166, 0.05084185541740485, 0.05470489098557404, 0.06029495423925774, 0.049020993124161444, 0.03608171029814652, 0.07790162840059825, 0.07285193686506578, 0.01893367152661085, 0.04545444343239069, 0.04467517649754882, 0.00789501193711268, 0.010852863130691861, 0.04142073255830577, 0.03560276974790862, 0.0206666567495891, 0.019517130218446255, 0.029233317423079695, 0.027063347166404128, 0.05140720061691744, 0.03434632984655244, 0.0479877878512655, 0.030658878785158907, 0.046992913021573, 0.028423362045681903, 0.06916580216160842, 0.06171646474727562, 0.03611333342269063, 0.04676372424832412, 0.027920688036829233, 0.02004355125661407, 0.034093182001795085, 0.038458472583442926, 0.00048258375318255275, 0.015406395441719463, 0.014080552434149598, 0.04841156689716237, 0.0332261669183416, 0.07315331497894866, 0.06851898865508181, 0.021926908321412544, 0.05942051937537534, 0.025199153626869832, 0.03575490069176469, 0.04155848195244159, 0.0067291017538601795, 0.04780307026313884, 0.07940023405743496, 0.023333589446597865, 0.027271194316978966, 0.02272287061038826, 0.04985405770795686, 0.028174663694309335, 0.024183186536122645, 0.02411264942825905, 0.025467568509546772, 0.019464706602905477, 0.023614214566935385, 0.023542378064511076, 0.0596442934391754, 0.03685055493510195, 0.029823212019566978, 0.02091888348305864, 0.024438777106947134, 0.023379877409232513, 0.035936670045235326, 0.033106531016528606, 0.05349694598200066, 0.021662513758721094, 0.012980951661510127, 0.030618075081812482, 0.005772914446424693, 0.032624788116663694, 0.0522664939718587, 0.03903167521847146, 0.016180873615667224, 0.00859154764163707, 0.020033946593425105, 0.046471099236181805, 0.045191962338451824, 0.03864134794899395, 0.05897867772728205, 0.03862440153690321, 0.10384323674121074, 0.03978908993303776, 0.02123841580136546, 0.021995945866884928, 0.06835661522511925, 0.05880018909062658, 0.05378993401037795, 0.04789378021710685, 0.021703442991045967, 0.028795414670769657, 0.006901926319447479, 0.03339940369395273, 0.05826479781951223, 0.06153960459466491, 0.0432568992088948, 0.04294396564364433, 0.019351153767534664, 0.030906611920467446, 0.0409103520879788, 0.03287835665313261, 0.04909857342551861, 0.012779208781596805, 0.06349083382104125, 0.030966404426310743, 0.04662799010319369, 0.05521718153197851, 0.04567627349336233, 0.04500106329630528, 0.018062139096270715, 0.044562702532857656, 0.03408455103635788, 0.05901364942214318, 0.027410161681473255, 0.015791396211300577, 0.027277408001412238, 0.024891667001481568, 0.011968566387492632, 0.029002469631710222, 0.04651138046756387, 0.016015909878270965, 0.032255729527345726, 0.040116951268698485, 0.01924562800143446, 0.05186935081811888, 0.024877852028501884, 0.05682458010103021, 0.018518330063670874, 0.049936245262090645, 0.035646928806922266, 0.044557481205889156, 0.014733105498765196, 0.028633444969143187, 0.06721414545817034, 0.043793291319161654, 0.03760569316468068, 0.00965087820908853, 0.07742993121168443, 0.03759779501706362, 0.02453269313887826, 0.03162910243762391, 0.027015756416533674, 0.015309241101411837, 0.10068276311670031, 0.022762800699898174, 0.05094643462715404, 0.07737807078020913, 0.037937123594539504, 0.06238485566739525, 0.07015955740852015, 0.026526502134012322, 0.015297960456726807, 0.03610434622636863, 0.07210649150822844, 0.04414179029741457, 0.020859099458903074, 0.018705987404765825, 0.008127184568106063, 0.06960140128753015, 0.047272323564227135, 0.015289872319304516, 0.04694286427859749, 0.04064537398517132, 0.03956786376823272, 0.028422848055405275, 0.01563981657714716, 0.019626818796885864, 0.014684288296848536, 0.024055740696245005, 0.01890042331069708, 0.06104688639087336, 0.04778481088578701, 0.05231163351397429, 0.04871311125212482, 0.038836403018129725, 0.07207424073879208, 0.03356029452489955, 0.03810115943529776, 0.015485862070428473, 0.04507166147232056, 0.01971006825832384, 0.059132623752313, 0.06903078726359776, 0.021288174470620494, 0.03984407501827393, 0.03929141842361007, 0.051744296814181974, 0.038825268258473704, 0.016972364358870045, 0.05863561720720359, 0.02885658460270081, 0.08144642425967114, 0.04768795340455004, 0.017535919922270944, 0.03058496257290244, 0.012819473049603403, 0.04492823274007865, 0.009481559973210096, 0.0237237250299326, 0.05450275879619377, 0.07176481519958802, 0.03845350909978151, 0.026590359064617326, 0.024148923910355995, 0.016052562643640807, 0.023547383956611156, 0.016665396812771047, 0.0225692299261157, 0.014604691050148435, 0.03213804102103625, 0.060217770880886486, 0.028566985856741667, 0.03102301460291658, 0.02067006808439536, 0.06712333711662463, 0.016933180657880645, 0.04013297148048878, 0.03429708177489894, 0.021857621414320808, 0.0029206888908187723, 0.0290516294938113, 0.07159201947173902, 0.013007205029550408, 0.0342091436364821, 0.023686246148177555, 0.01676453586800822, 0.03166264920894589, 0.03223886793213231, 0.037761573014514785, 0.03842689695635012, 0.012924048866677498, 0.018153278223638023, 0.028359155669542294, 0.03605949166896088, 0.040880761175815544, 0.0422267303802073, 0.024611043577481593, 0.07766633281218153, 0.02445680578239262, 0.08734367388699736, 0.017419583396986127, 0.00952912527801735, 0.023442122819168226, 0.04242657929924982, 0.06566034776291677, 0.06707149704119988, 0.0179757955151477, 0.045322285166808536, 0.04513980335156832, 0.01805441058240831, 0.01583410320537431, 0.08564832700150353, 0.03562572119491441, 0.014307519853381174, 0.017815023427829146, 0.02072577750576394, 0.02901561964037163, 0.03202617773786187, 0.01610242648582373, 0.018130747468343804, 0.004678096921582307, 0.010969613562338054, 0.006775788355818284, 0.053094462757664065, 0.022411618115646497, 0.04086060868576169, 0.048012941144406796, 0.050575055448072295, 0.042923334786402326, 0.034992458032710214, 0.05039101639496429, 0.053415935686124225, 0.05549396614411047, 0.011663127241523137, 0.00424574882656868, 0.03936441522091627, 0.06401119554149252, 0.054106619874281545, 0.05558824519227658, 0.08791744988411665, 0.023200247137408172, 0.03698435186275414, 0.049824249664587636, 0.026788146933540702, 0.05948954674282244, 0.05115518931831632, 0.057917150402707715, 0.043788321050150056, 0.034964902725602896, 0.028699754803840603, 0.003504679596517235, 0.019298680958205035, 0.0585000119837267, 0.007721240815174366, 0.0155428539229823, 0.010857189639604517, 0.0371110309580607, 0.008239885842028474, 0.030809374459620033, 0.04534898551979235, 0.13698169961571693, 0.013090521496321474, 0.015522475820034742, 0.06748431096119539, 0.03923002118244767, 0.04336941049301198, 0.03120114022333707, 0.021813250313113843, 0.03717473861096161, 0.06194115483335086, 0.07713398816330092, 0.02085846333232309, 0.00874105011046465, 0.03424339269154838, 0.022193918636600887, 0.03324031776615551, 0.02273227001673409, 0.028443757112004926, 0.0476357129934643, 0.03587180209745254, 0.04200845584273338, 0.048627500488821945, 0.027799681494278566, 0.0273827539557325, 0.03172976989299059, 0.039512977070574246, 0.027352552362052456, 0.01576241258797901, 0.002025181909890047, 0.06620199512690306, 0.08314038693372693, 0.03450685426858919, 0.04344477877020836, 0.025101154510463988, 0.0383936215990356, 0.01956290249446673, 0.08328121009149722, 0.019574320542493036, 0.04022289772651025, 0.02995788086471813, 0.010542256092386586, 0.06879462315035717, 0.054285315464117696, 0.11662277206778526, 0.08491147868335247, 0.08920577753867422, 0.12878994989608014, 0.15708798143480504, 0.15120093018880912, 0.10522252201501812, 0.15082817019096442, 0.1430084476513522, 0.14131084802959645, 0.09958680013992957, 0.06427938650761332, 0.06691687248115029, 0.17372614863727773, 0.18764530388372286, 0.17279993476612227, 0.14165208329047474, 0.20335359312593937, 0.11170012264379434, 0.08819237191762243, 0.1626577904181821, 0.08344753259526831, 0.09872565777706248, 0.19044408441654273, 0.1462387086025306, 0.10385963014726128, 0.17201024214071886, 0.1326037509632962, 0.23719977481024607, 0.12352818224046912, 0.15613651249025548, 0.07473912595638207, 0.12045374007097312, 0.13515519191111836, 0.22609274009508745, 0.18060933000275067, 0.14905165694653988, 0.08891951718500682, 0.060350729817790646, 0.09463221885796104, 0.0830326627141663, 0.08430995060397045, 0.10643868068499224, 0.11746662535837718, 0.11801368743181229, 0.21101478274379457, 0.103654332592019, 0.08936303481459618, 0.08370830038828508, 0.08783882124615566, 0.10528033998395715, 0.09134587020214115, 0.061368586628564765, 0.10257854924670287, 0.16733508157942975, 0.10086695823286261, 0.11479262741548674, 0.09475497262818472, 0.0916330533634339, 0.0930521007893341, 0.11057009042373725, 0.1000012086172189, 0.12185529486409255, 0.09340708995504038, 0.07244913812194552, 0.10947110796613352, 0.11484131908842496, 0.13001288713089057, 0.09689340288085596, 0.08615139286432948, 0.17861497987593922, 0.16363641433417797, 0.21874436869152955, 0.17941022291779518, 0.1676028043563877, 0.09827329205082995, 0.13019499235919543, 0.08382686081209353, 0.13203853129276208, 0.11340213274317128, 0.14746940827795438, 0.10551277215459517, 0.13306584688169615, 0.05495247145050338, 0.1287750085549695, 0.10547560879162379, 0.14447594247758389, 0.11645681597292423, 0.1174206342548132, 0.1049686074256897, 0.25797868839332033, 0.11826626530715398, 0.09856756590306759, 0.09357924107462168, 0.19877965641873224, 0.18579028413764068, 0.16247286248419965, 0.36222476458975245, 0.14555693018649304, 0.09051169960626534, 0.12353533399956566, 0.1008861404178398, 0.1329341432345765, 0.12179019621440343, 0.09075936488807201, 0.2594698912331036, 0.074869784659573, 0.07397392844515187, 0.11692063537027154, 0.15632263464587076, 0.17440518577183994, 0.2774054988154343, 0.1492321744029011, 0.13962175723697456, 0.12216865590640477, 0.1651346060846533, 0.1012756602306451, 0.11902161048991339, 0.0951191084459424, 0.11283314041793346, 0.17849603268717015, 0.1922079361975193, 0.11106373822050435, 0.09772325120866299, 0.13863296886639936, 0.12004562839865685, 0.1332009567746094, 0.12863372399338655, 0.09055596044553177, 0.1384338324091264, 0.10436839570424386, 0.13391777473900998, 0.13855014688202313, 0.1884377242199012, 0.12300450248377663, 0.14426375100655214, 0.08799487072974443, 0.1591122413852385, 0.11128475064677851, 0.14076795216117585, 0.13977412906076225, 0.10184458470238106, 0.15964611273791107, 0.11812742347163813, 0.10116992411868912, 0.07087524221943957, 0.10778171861810343, 0.10287299273269516, 0.1555001280669655, 0.08341963802065168, 0.07619333506694861, 0.13312464872641222, 0.18426381104758807, 0.1254913333271231, 0.12933907471597195, 0.17864398046263627, 0.14059879338102682, 0.17815681946064743, 0.12121828618858542, 0.12150484509766102, 0.12922080606222153, 0.09173103382012673, 0.19468362549585955, 0.22781178142343247, 0.12681932135352067, 0.13266658330602304, 0.12088807033640997, 0.11724990127342087, 0.11787382779376847, 0.14500339488898004, 0.13936018198728561, 0.11179912768836532, 0.097658776811191, 0.12917963255728993, 0.11984030370201383, 0.10697558508919817], [0.06524313693600041, 0.06900070102087089, 0.032389936968684196, 0.020037222221227627, 0.010045360657386482, 0.032294657081365585, 0.04861052354265537, 0.04271398976977382, 0.02911173751843827, 0.035659047442355325, 0.034844910592905114, 0.02700178198782461, 0.0397987590570535, 0.019119264424911568, 0.025060956399621706, 0.03401138121262193, 0.04416769337175148, 0.08781750846121993, 0.0593763603163617, 0.02277475139791412, 0.027197714063471982, 0.0215428778569081, 0.036489045047866445, 0.04506513735811625, 0.0167813889815339, 0.06282162187354905, 0.014830770436674356, 0.007910434189917786, 0.0130770907437961, 0.05238652003130742, 0.07593781913497619, 0.014685943922294038, 0.01952382905541786, 0.07272206526249647, 0.019113722490146756, 0.026425358007795045, 0.017226745441023792, 0.04111422132700682, 0.03756279278812664, 0.06355323868670634, 0.03856961661949754, 0.03142906352877617, 0.015800598842490996, 0.026570437276469808, 0.05630574508437088, 0.028006960371775285, 0.039824081983949454, 0.05534082418307662, 0.058858441321977546, 0.01854897609778813, 0.01591607871731477, 0.015601905129317726, 0.050457227842084, 0.04512924195400306, 0.02796057571790048, 0.013700622017495334, 0.022239804567236985, 0.07047181243875197, 0.07399795537016221, 0.0437804670073092, 0.016717170731031468, 0.026385168378640498, 0.020130882106189216, 0.04867349159238594, 0.020540330492492233, 0.018385822352554117, 0.018411783102367605, 0.04791119142568537, 0.04081221556823168, 0.022406191531834856, 0.024565327280600156, 0.06121164147875138, 0.031133442784526517, 0.0454321467716779, 0.0492990907015545, 0.06359652243554592, 0.025364531270627464, 0.03128234390169382, 0.08620817946004015, 0.014851255408887352, 0.025358974068824734, 0.07922384887933731, 0.05375299795663782, 0.0019884600187651813, 0.0433251225123448, 0.0343969519516187, 0.03554537247068115, 0.07031854494873967, 0.06672631270651307, 0.04225459781342319, 0.005118465300516358, 0.029061566639159406, 0.010178258526138961, 0.025729952912245477, 0.03495752704995019, 0.08300731943121978, 0.03902774310803839, 0.012063015917582172, 0.06682043908429997, 0.07048387679138354, 0.06971527303435973, 0.03961530354406152, 0.0150443376374564, 0.026697328413969705, 0.03157719111602221, 0.07962666119315795, 0.03112088649400643, 0.04711260320618749, 0.0701102346980146, 0.03835059230082801, 0.05029076963130917, 0.030083141821835722, 0.03667536397863712, 0.02100310324957328, 0.031654109845736196, 0.06460774317383766, 0.04926082132650273, 0.028628305066376925, 0.03839199650766594, 0.013389972570751394, 0.03978700004518032, 0.040250371609415324, 0.04081771170188274, 0.05954364633985928, 0.06364486805562462, 0.025381594730008925, 0.042645973419504504, 0.09062175798629012, 0.010923658081862544, 0.04652356695649879, 0.029080589368407215, 0.05203635185690863, 0.016091820983482257, 0.031713987168456824, 0.03690270374396017, 0.038024155888706446, 0.029484310919152837, 0.018137117215831364, 0.011257624536353563, 0.0538930272284363, 0.029403697566262314, 0.06866338769240038, 0.037316257267126014, 0.03832595469430089, 0.02022793636258159, 0.03099628710853202, 0.08772594016045332, 0.037467584146984985, 0.026042901744533862, 0.05411027717803206, 0.029454652153487717, 0.007750729947084827, 0.036913638335785696, 0.020808394233297025, 0.026777381975469843, 0.04238033374505384, 0.05830900437597718, 0.08111795902784381, 0.0394977914568569, 0.038605735038540194, 0.01873258258482175, 0.056039226707071066, 0.02826898345457656, 0.04063667855890734, 0.040322550772024054, 0.04238197240712387, 0.06316135078668594, 0.0024756135992772344, 0.09145410332296576, 0.011318401766142674, 0.04675741387265069, 0.016779741837776134, 0.03543117502704263, 0.05838109872170857, 0.0444237182049879, 0.017936895102528588, 0.04597198583983949, 0.020176033522667627, 0.1020244914772255, 0.0577668006132756, 0.015173306788450905, 0.09126536202217851, 0.05744093417056969, 0.036652622877487114, 0.0353144670038351, 0.04044315358623862, 0.04040602415001818, 0.03273605428902166, 0.06926720243479524, 0.04045435619939651, 0.0121257057679551, 0.022729043582720414, 0.04711310871477638, 0.010133777162991464, 0.01229595868582172, 0.1160923069609063, 0.023871925559693148, 0.030446544821773256, 0.05516391314033951, 0.04527439755786743, 0.038535174181950946, 0.047537298274359534, 0.029789641499519348, 0.038494092279246876, 0.004525024510387863, 0.023984874498897364, 0.03778516906978829, 0.0494210845125573, 0.06502417368548256, 0.0418474937656096, 0.06603868531861476, 0.04714470809059484, 0.017780479210029756, 0.04300668263541801, 0.027509660360270312, 0.02177241268301649, 0.02811174314203007, 0.023125040012278726, 0.052048840293926854, 0.009274748436707472, 0.03286466720913138, 0.08323800776685987, 0.04259766511885183, 0.053068851453385184, 0.03239416763452547, 0.030153977485107522, 0.019838235041658794, 0.0585565950189318, 0.011930986573653561, 0.0382614361920527, 0.006210402868288968, 0.018278137148757066, 0.025568936552320207, 0.03999667075861778, 0.009278366724694414, 0.02999014520485486, 0.06233525475753205, 0.04251722139971597, 0.020724656226645623, 0.07041284096028123, 0.02788942283950746, 0.01287471767448421, 0.04005318933299609, 0.032916778698563576, 0.01923948895585324, 0.019588201672637036, 0.012928970790069019, 0.02376255758904985, 0.04381165586944137, 0.021487297357193062, 0.06443262007087469, 0.06572828947433404, 0.0352884587565703, 0.0553479114813464, 0.03740490786731243, 0.001835630607924291, 0.0569746924032058, 0.03161254618316889, 0.011271806766412087, 0.05203642988843577, 0.10715766996145248, 0.05791205460471766, 0.05965230693774564, 0.06147059079791818, 0.025982936212260808, 0.049394438442374976, 0.03936809627339244, 0.04917103757283517, 0.021961569586502652, 0.04358247388154268, 0.07618625794670411, 0.031313278313194, 0.016856155058901225, 0.02270895385715578, 0.03520056472292968, 0.010998273185188217, 0.027101022823314582, 0.0197903626997556, 0.05528212411861334, 0.03412467281201056, 0.010739702149294317, 0.012390429420130593, 0.027860032095174705, 0.02936950957934771, 0.01639675292452531, 0.10482891742140055, 0.028841802717319558, 0.010773426187889916, 0.023136793935139264, 0.017775086552969048, 0.0164286627301148, 0.043605394794472625, 0.01084558669078563, 0.03207735624164343, 0.02615376758123083, 0.041371219857994995, 0.041659522602068524, 0.05296576162800193, 0.011232319421001842, 0.08205005579761096, 0.017440789312656437, 0.010963285375120384, 0.0195379917775946, 0.06323907697307211, 0.016309186284031187, 0.03310346403824432, 0.01749170827679336, 0.012380827301447945, 0.028645794306482588, 0.05045364856986063, 0.05171136750972696, 0.02945211103984288, 0.08227633365562984, 0.03472180737714682, 0.05528377295870866, 0.0210038716904819, 0.02123032257493053, 0.0505609453123595, 0.01631517774824585, 0.024562273873016238, 0.03983941687537091, 0.03949409344100526, 0.06307896985007183, 0.017771834673892175, 0.03764295491522976, 0.019567843925740038, 0.04519721419949617, 0.034595766104757786, 0.02372600321125771, 0.062361398711800575, 0.038501199933567216, 0.0330899645840483, 0.04855997268376606, 0.016038859628939202, 0.015907161070832183, 0.04516901428412114, 0.02310450923895197, 0.031183583129729544, 0.020823169333328093, 0.03332169786361711, 0.007303898522098149, 0.00950994563754648, 0.041193087452224324, 0.05286526041371482, 0.046716240367719104, 0.017839055441852127, 0.047195041818278174, 0.0254001577517816, 0.02189827923263822, 0.0867199237857546, 0.032324085145124366, 0.043102295004895756, 0.15785585237400873, 0.22944762078779085, 0.18784254044294357, 0.11030393506267241, 0.09225840480732066, 0.2265316979693515, 0.154365386813879, 0.1884430439344474, 0.06738804719809975, 0.1150585181478943, 0.14045699313282967, 0.11791965604892798, 0.1930789580302579, 0.22211957829339163, 0.07846802872206483, 0.11316954450947897, 0.13437087328306266, 0.13649037240871362, 0.08991814431335245, 0.16555654630064964, 0.07473430835774966, 0.11435163393616676, 0.2036036332803113, 0.11785401457122394, 0.08367349154182843, 0.19728560373187065, 0.0900772607752255, 0.07687660626002721, 0.12749117958758557, 0.14391545898147992, 0.24587894337517874, 0.16412308679095336, 0.13097670541277953, 0.12373107778174536, 0.14924384520522185, 0.1251767644924777, 0.12178467293935162, 0.15390189311334065, 0.10443403718194791, 0.08450216600405318, 0.20535634351628168, 0.1448653130126851, 0.09985642960028988, 0.09696931059339217, 0.13511226778583868, 0.15750366555792944, 0.13362842026565755, 0.1748185357345002, 0.08204271404870919, 0.11496274971536227, 0.09637757377432925, 0.15598582343331405, 0.1330307801919324, 0.21177698113024235, 0.1371414674712079, 0.04679072315671614, 0.144975194973605, 0.11064740270376205, 0.13015155254730157, 0.1121355996334127, 0.11291733982839755, 0.14784106904906885, 0.11884547636977263, 0.1080456008868558, 0.1072755382795419, 0.09998868964612484, 0.12767880809094223, 0.12427986333412783, 0.10579491380069937, 0.16500485661838735, 0.22408015094697475, 0.11040637349443776, 0.17129170069737093, 0.14403551896767958, 0.15263938371624264, 0.12213324994913169, 0.1309336455804961, 0.09829885925033263, 0.20164960170430796, 0.09730488687221493, 0.1414103212633303, 0.17874931623893126, 0.13774887844920158, 0.11958364104585988, 0.186490464423384, 0.15058601461350918, 0.11637315260512487, 0.15947413125208446, 0.19565414770373277, 0.16138974417533192, 0.0848389161484582, 0.14126305202288286, 0.13279540996466363, 0.11982020549476147, 0.16116402271602834, 0.08242300578526088, 0.11419390168573175, 0.08938299731484481, 0.09918649840567793, 0.14498768001794815, 0.11424401828220912, 0.1367466686559575, 0.18834457493254117, 0.17939013828124317, 0.21205154354018824, 0.12885711129222596, 0.10935893934220076, 0.10075522387134177, 0.10052710039807217, 0.12672250797705992, 0.19073323532938957, 0.07809999811330012, 0.15261644923261233, 0.09637242369353771, 0.08065347466617823, 0.15022174987409795, 0.15393408281462534, 0.1008212249726057, 0.10024682472326926, 0.11549131492418901, 0.08224706844027553, 0.12964577254440102, 0.09922916468765054, 0.1574104619877679, 0.1732743393097605, 0.07653953720416341, 0.08982616210622446, 0.19484907947480679, 0.15710696684462683, 0.12197715975344181, 0.11482350075883524, 0.14212701709142753, 0.16980279130595072, 0.13920048198529653, 0.12228870232190404, 0.12915202975273132, 0.14577881113759109, 0.09620277636817523, 0.18273573661489145, 0.12422984173255307, 0.14091338935707295, 0.16324328471507343, 0.11085510905832052, 0.08937999819006238, 0.12208666173475129, 0.11316012644342013, 0.1821915651006358, 0.06847695341067654, 0.10999158503753798, 0.10024643117295844, 0.08742261465106692, 0.12892704111124786, 0.0462334389532251, 0.20508355886808463, 0.12751909451825277, 0.15861848502286843, 0.15494541211852006, 0.12296410250876631, 0.1423945091664791, 0.09039305775825467, 0.15434277802705765, 0.11235360614955425, 0.07722439616918564, 0.2672954084617751, 0.13964250683784485, 0.1301383753972394, 0.2194564776229007, 0.09756449437034981, 0.1365587415971926, 0.09534630232623645, 0.23867168011409895, 0.11345640875931297, 0.094928541885955, 0.10689768926905734, 0.12639879249036312, 0.22611524031630584], [0.01293916832323053, 0.03519144521227904, 0.03304109988468034, 0.039830409322998354, 0.06366097647696733, 0.07243639523429529, 0.096983349482928, 0.04963895192902003, 0.07524980498211724, 0.05897244877581086, 0.03355529032913702, 0.03350190319386976, 0.02388275328225323, 0.04027480226276176, 0.04886432956638081, 0.012635791075548955, 0.0517065804451704, 0.0282657502352127, 0.03471699656386461, 0.04537179447444422, 0.08033288044056722, 0.040585072578064034, 0.05164848766954882, 0.02792312906655882, 0.028019321583477513, 0.02106472271095429, 0.044316041482878585, 0.012675154588318296, 0.0483761575472142, 0.024714896754760827, 0.04822744641985212, 0.03585013647430709, 0.07375135538833481, 0.06201113214982407, 0.030664921139499972, 0.0278163581886994, 0.0211289290870939, 0.029915543672229563, 0.027874576493299434, 0.019942761664944034, 0.050451938661613634, 0.01845143159984478, 0.031622944732329676, 0.024869331325005208, 0.0422683958230274, 0.006634628475044987, 0.058273510209151676, 0.08690713159739971, 0.05033084390951054, 0.004458908906339535, 0.061587427742779255, 0.05212908723790731, 0.045225488753723245, 0.04707651532122067, 0.01706461458733039, 0.08640205048556839, 0.03615164690251861, 0.017754336952098777, 0.0284780095597463, 0.009945603287113565, 0.036188097803720405, 0.024112634161221128, 0.03682828202311482, 0.06886284984648228, 0.01911138154433242, 0.017850677050384026, 0.05981796447719846, 0.025534623036427156, 0.03280507487111858, 0.037618944953594885, 0.024376894713246396, 0.08701999911240169, 0.0565597682393023, 0.013215756160207093, 0.022804362666127936, 0.034470362655286274, 0.019229733318622624, 0.012314193466279124, 0.04197480729115861, 0.015772843367553184, 0.04809293703043035, 0.07289563452026673, 0.04847109816702349, 0.04217650521812694, 0.08176471825156893, 0.04631753319076129, 0.01610947137565485, 0.05745988565364054, 0.015419774455949664, 0.022024885385430286, 0.026401095291865722, 0.0036557236120903064, 0.02173447239744876, 0.07118827077959265, 0.026322315679863095, 0.04247775101768119, 0.023143367243132422, 0.024071900007714118, 0.0197292165165501, 0.030113499478570054, 0.05427872010373643, 0.05042503474812422, 0.0030497142329945093, 0.027776168559544852, 0.026011321028428416, 0.025086043535598686, 0.029812810077731098, 0.04994035039895347, 0.04396653148744788, 0.032914926297962666, 0.06406474552516427, 0.020132871910131404, 0.004861595691181719, 0.022628927437056388, 0.020853771262669137, 0.06530525681695767, 0.06766275888574974, 0.009014764351637235, 0.022556890766801577, 0.0305605353122311, 0.03638679999858141, 0.019709822289379578, 0.07242995593696833, 0.02838081111466246, 0.07848689878093344, 0.010824341759351748, 0.018749729164742997, 0.031298530354563675, 0.020766303009752716, 0.09544494774724756, 0.03744384559935757, 0.05812333005347422, 0.08225474945668663, 0.07786517071404628, 0.03014127870223352, 0.0326278991997242, 0.0293183073268405, 0.02480583910697273, 0.05956364276685885, 0.005792908753002328, 0.026926732622087002, 0.054857951522405655, 0.041551448936973295, 0.035936069541743824, 0.05139942799827882, 0.03145689024989094, 0.02846637268417648, 0.013535783809077526, 0.05102565359058125, 0.07922479204301323, 0.036157380523426194, 0.02557027665898204, 0.053383963116045506, 0.06142493217651333, 0.046514779928007295, 0.025070123407723646, 0.030829856039157937, 0.018541632652548806, 0.021369644473972063, 0.04101220697962812, 0.01306288137233683, 0.05911403189280203, 0.019817088497802615, 0.022640216563429152, 0.006957071284497423, 0.028811747008668523, 0.04645726051447647, 0.03228484546499593, 0.03245076424043093, 0.05147818216521825, 0.017980151709967425, 0.08235938634191241, 0.031661441416612694, 0.009212145947718194, 0.03145453573337623, 0.029770557702119862, 0.04644053462626679, 0.053860298091811795, 0.05863900988229683, 0.004653593325721366, 0.04608959970729692, 0.02689826298904206, 0.03131272191447871, 0.07994317063795668, 0.03016525473711746, 0.02179979666003159, 0.027911753426971178, 0.0704447388915079, 0.037000694378678284, 0.024003644473850727, 0.015408042585477233, 0.021784281956830194, 0.03597866118486438, 0.028810708850089992, 0.04845164456803884, 0.020425905739622455, 0.02984470800895776, 0.024445323273539543, 0.025719025105770146, 0.028727517064128603, 0.004717522774756486, 0.02344047567541046, 0.014149542482170676, 0.016800861240231564, 0.124067522585392, 0.048235897573509386, 0.06263677536376885, 0.03355329543618219, 0.05266463117940085, 0.035051368443029265, 0.032344624400138855, 0.011963186452963522, 0.014141159182015275, 0.05113002245447465, 0.029235539625265768, 0.023363171877073388, 0.010850829221973462, 0.034335873621915064, 0.0096326569993315, 0.03873798151367477, 0.04455422763047474, 0.01327608894955899, 0.0144401938055775, 0.06870396408651556, 0.027169188451288, 0.05505027548809137, 0.0215936577213662, 0.09170415704803807, 0.06825293507426977, 0.041808081059051413, 0.028228586872241328, 0.07125364762863942, 0.040491777405674965, 0.02613711802821074, 0.04790119321218558, 0.04236329573073557, 0.019519995332562497, 0.018619945771726112, 0.036111491200114997, 0.07839222278978143, 0.06550366724176065, 0.005245292825358254, 0.01971492317638227, 0.022737092704379132, 0.027309282183913246, 0.06588977402342217, 0.08736245573631354, 0.014850519198392118, 0.044962664999599965, 0.04456654982641339, 0.04983991025281804, 0.028251896246469448, 0.04002093856355973, 0.03742227836378983, 0.024608733165743094, 0.0145968522743455, 0.015898095842983042, 0.029033957049250603, 0.03142150464866843, 0.037399767964546166, 0.05039345912103142, 0.02362132052491818, 0.028428264461191635, 0.05211464462003537, 0.02936582513419645, 0.04392831639519759, 0.01177076664420643, 0.02358489337244204, 0.036414328164287975, 0.04001019396153944, 0.03636534472129174, 0.0219965124436255, 0.012585839023813605, 0.04131920336346541, 0.06986677633332354, 0.020928379580644623, 0.018918994814157486, 0.07803957456988947, 0.01908733426327152, 0.013589594180562665, 0.017811262647488287, 0.0492034036932247, 0.025535491561251025, 0.01915602745222194, 0.037725451202797036, 0.02661875745148531, 0.042154717458678145, 0.012312168039248457, 0.04237655430499997, 0.042522656465215344, 0.052054319464202435, 0.048905045060174804, 0.06367199588567019, 0.01615623092012746, 0.026285170976604735, 0.004938118750162954, 0.0612552102122988, 0.013463623306181813, 0.03303397187430944, 0.018560940366504446, 0.06473802868276834, 0.022030257686440433, 0.04005777622972216, 0.05999675166926213, 0.03644294537869947, 0.014939722804618734, 0.048236548967127285, 0.015644308478970612, 0.032405818080795665, 0.031780948396772146, 0.06646439818931477, 0.008801420219242573, 0.004023600278222668, 0.010982478586291628, 0.029938729213816778, 0.028670150320976973, 0.026207712811550925, 0.022786323812657168, 0.03842671714457018, 0.07121208057339702, 0.08727851416915655, 0.031601184114281616, 0.010433004320865231, 0.04375705076381564, 0.04811225152973618, 0.007438946498690971, 0.06771535213504519, 0.03483194039602365, 0.02627199891555522, 0.023514286714739034, 0.040984166519982476, 0.012271786723951144, 0.020086061475532394, 0.04249366944921868, 0.011130282173066266, 0.05468268931976386, 0.02171985336047198, 0.05006260883861354, 0.0305343777872622, 0.026645491731220057, 0.00803397421259433, 0.03518572516207184, 0.01589770907802241, 0.03300293568255646, 0.07212692219763994, 0.03216201027057, 0.04117274157969015, 0.028950673661061695, 0.06846220884472132, 0.0486440906700279, 0.048770525492727757, 0.021330540500847355, 0.12699128926864692, 0.14510152462337697, 0.1254134103655815, 0.1704162819577115, 0.16116546121026787, 0.13681043737701007, 0.17615128707672867, 0.1678240881966693, 0.16976475263280527, 0.1234750258071082, 0.07268875597843102, 0.11412940014685903, 0.08743519469031266, 0.11534874114607062, 0.19834585541060992, 0.12244240407432828, 0.19852730924529688, 0.16349143854209355, 0.23273406443851336, 0.16132111714354583, 0.15026744242225373, 0.10908748462264027, 0.12480981275439262, 0.07770933836166348, 0.1296324732580355, 0.08304644376039505, 0.13832427614501544, 0.09567211448614087, 0.21016695323799336, 0.12134006965373244, 0.1486279796808958, 0.12502865386860712, 0.20610271846609457, 0.13712463980274542, 0.1183168568781444, 0.08406151857759271, 0.11312332270400864, 0.1647619003696101, 0.0991221054324082, 0.12823360546358994, 0.1352319342217275, 0.12989733261721476, 0.11267052950071436, 0.12623460058655056, 0.06752918248197862, 0.20973246012415203, 0.17135943206293242, 0.3222370131739548, 0.10782820505223104, 0.11736838705837727, 0.11324996447988919, 0.17638519166835717, 0.1046892274171114, 0.1142416705510446, 0.1269558561699731, 0.2693633660674095, 0.07309529344950404, 0.0819585689210466, 0.10323586647531816, 0.07468385249376297, 0.1739050511802946, 0.09721703015800033, 0.1478254220315388, 0.18222332053950854, 0.11614284424909524, 0.15192377354417527, 0.15460220910608768, 0.0680693234982235, 0.09927643143704959, 0.12312487459608487, 0.1736944474812065, 0.233514596841165, 0.16400404460728168, 0.12676672131887504, 0.10512574935065848, 0.15266082542283194, 0.13999828988952295, 0.10844168891864163, 0.13553677286420548, 0.1413111872971058, 0.0900376004033855, 0.17130364291369915, 0.14558609362159455, 0.14239049223916872, 0.20140254710401806, 0.1262473299035004, 0.1359767485409975, 0.1363001519015857, 0.08633553369769029, 0.09830413825277771, 0.10165724118373223, 0.10381476541182824, 0.102723877876997, 0.14181388675102166, 0.1910422673182828, 0.09334094636142254, 0.10284714733383485, 0.15867553624723638, 0.17107037614498818, 0.08674887008965015, 0.11863978526421956, 0.18227077727871283, 0.13442179055086204, 0.10027995758822986, 0.08313769314970289, 0.12373118634734835, 0.12639374418982438, 0.07667186510350023, 0.14860717579722404, 0.12990907127303736, 0.1808774056179183, 0.11508724732058388, 0.13284965205405438, 0.21414280203836306, 0.1354449942175831, 0.14425532360162052, 0.18618188026760304, 0.03705620872122901, 0.13160196186176368, 0.09574545055095639, 0.11194945712174688, 0.07294070281620536, 0.20531461361263478, 0.09028863800423485, 0.13091890779989107, 0.06287987410490002, 0.09221539247248854, 0.17885913034634932, 0.07897163062755551, 0.20186414090650423, 0.10433585316474948, 0.1507529749401978, 0.19187325558492116, 0.1484068315476179, 0.12293537333607674, 0.17784070356615952, 0.09652497193643025, 0.10464802677077906, 0.18062931964440004, 0.07684761924403054, 0.15226722082921437, 0.10992333120001213, 0.0967507069664342, 0.10297204527471747, 0.1615433237914528, 0.08312279930604355, 0.06638471782207489, 0.1069862652303917, 0.17774066036301, 0.1922080854752234, 0.1561083397162812, 0.11986779794096947, 0.11456645812307086, 0.09451589081436396, 0.136527827541743, 0.1695092027740819, 0.10035033524036407, 0.10572358619953905, 0.0937843079279576, 0.1354404887450593, 0.0971917954406568, 0.09313906183732407, 0.0673627174858536, 0.16373416408896446, 0.1259843704423734, 0.10328526382467576, 0.06788987812719174, 0.12233659332352025, 0.19112090952694416, 0.14431758597493172, 0.14503747091761657, 0.16656598927719252, 0.20884250716439315, 0.1089122529540743, 0.1071478244183319, 0.08415388754968132], [0.04910698386707476, 0.061508799104818275, 0.028790379940931286, 0.019002592024792517, 0.019988601794466376, 0.020865620180432285, 0.09072294112827096, 0.08693304484976189, 0.028371499917869056, 0.06372433807700872, 0.0509070456693215, 0.06554315119449582, 0.04070293750347836, 0.042057435893054516, 0.008824089226046843, 0.08391993546060153, 0.03346726058849266, 0.0264559785968491, 0.032820413155215125, 0.055833033485604186, 0.04791190728013005, 0.03322415166933622, 0.023351110917116915, 0.031253652048430274, 0.06488292305065052, 0.03496151005050965, 0.05965894301022802, 0.0762807982308524, 0.05154198481302176, 0.019092947444213287, 0.05030949380514877, 0.01958971650206617, 0.018769589884738837, 0.022346375277265906, 0.034001162475241084, 0.008729563360767705, 0.04185637239632862, 0.01001178759283253, 0.013635980530775018, 0.040910504758358, 0.05150277227429407, 0.031027499719389846, 0.030594614733542715, 0.015218780509063175, 0.012663525346267437, 0.04247837187722325, 0.05041100264393857, 0.015421847380431635, 0.0383103348181716, 0.027248655079997013, 0.033098222355225256, 0.02624939861042159, 0.05664640019780823, 0.07125629391521215, 0.05365843053108879, 0.052784477427069626, 0.03547088968168412, 0.04786184496645417, 0.0177279690812741, 0.027149305678904057, 0.04196781838046653, 0.06584855980638947, 0.04031508688681892, 0.016122723164569055, 0.0162246374280325, 0.10234615100281579, 0.02937559603846499, 0.04233807119141732, 0.056163405400833914, 0.08856882314596858, 0.06956279264496905, 0.07799084218485014, 0.02798465353303722, 0.018050675247130648, 0.00802331612378891, 0.04196595919451543, 0.024820380112422363, 0.026078372162633708, 0.050556667149066925, 0.022874146600120833, 0.057874307701630254, 0.056318196201963086, 0.06502432974853686, 0.0423712651245296, 0.05673117636303816, 0.013909693923778832, 0.015858854466517056, 0.002975493316106232, 0.016640391100996306, 0.056766402508531294, 0.03573122660496405, 0.10487070160784892, 0.004246766629096652, 0.06138571285243545, 0.033504440914839506, 0.026499077444896102, 0.02432110726035067, 0.01120969875981765, 0.06553907998438392, 0.06463789048471622, 0.0259921524141516, 0.04045156063511968, 0.03962046041020325, 0.044041166946824105, 0.007639391680381128, 0.015877994243055582, 0.013407220930925437, 0.02474892867862114, 0.034494908659585884, 0.0352290224816118, 0.03830622289595859, 0.022865235738988434, 0.0015798641481004389, 0.007827775053946035, 0.08392425094332014, 0.02506144155216004, 0.031915437430143356, 0.08173453022858926, 0.029071340936103036, 0.018809121334925294, 0.07386747308607612, 0.013343381811864674, 0.020221381714301448, 0.04108776863930481, 0.01918067184409925, 0.01997734829118209, 0.026338642928749323, 0.03964184783399105, 0.04734245355107954, 0.05517238465004733, 0.06807517247008425, 0.08572170377842017, 0.012225052624541734, 0.01855814819490271, 0.07346717813717467, 0.038785777520388365, 0.01805690080592675, 0.030337711197457144, 0.04793900118342467, 0.04090152774006128, 0.01704620253959937, 0.01272747218276241, 0.006046076105641467, 0.026206678045647483, 0.04915313103369304, 0.022027962541739856, 0.040570819949997325, 0.014890398397775633, 0.04841731069609523, 0.03413888133530106, 0.05017515404948166, 0.0033645436674955165, 0.08003471858267273, 0.02604076775190021, 0.030161848491323844, 0.04177452071702906, 0.08708497562578746, 0.04786125124831285, 0.03700805648363062, 0.00444419402629137, 0.041267264900462966, 0.051443183328956366, 0.09928096405097417, 0.05861667250948293, 0.03804974005158458, 0.06232421499277864, 0.02019289172520595, 0.0032025124736329807, 0.031833490755941184, 0.04429780585425241, 0.030160654269691025, 0.0594081903940865, 0.023545387367318784, 0.02173014504036733, 0.046893290510135036, 0.0027623597416095436, 0.023564086096095185, 0.039531643568937264, 0.02837462117895484, 0.010692931578627654, 0.024482612165489366, 0.031104703433811665, 0.02639799777950559, 0.05353095754981041, 0.04654953109898737, 0.02557519603786724, 0.03565268956923059, 0.06363175875906434, 0.04031247452699712, 0.023496344552508423, 0.0516517616010138, 0.08146665138857705, 0.12544139314975056, 0.08115673051880938, 0.0398574930482677, 0.05404322434748922, 0.03746856802276202, 0.018794999324849675, 0.04202029967148389, 0.012642580666579306, 0.034328117966651917, 0.014863779468994056, 0.024261275738743798, 0.05193912796676159, 0.0654749787811722, 0.03356764305915151, 0.03294832379158054, 0.017829963072602237, 0.02792179404890963, 0.021991996793076396, 0.0435179044891681, 0.008540519263728388, 0.01171819375096155, 0.030944263828652244, 0.012415575927921703, 0.023091735817225914, 0.011448105431294866, 0.017771934757807424, 0.027724185991766195, 0.02131683748614575, 0.01631120322937412, 0.0412426510426615, 0.03256758422191654, 0.009165603534451552, 0.026699408123801862, 0.0136805704595255, 0.03640876417713506, 0.0048473464557901025, 0.07180112360843591, 0.05088346657742347, 0.04380510461383632, 0.02730096334458462, 0.06688578200659581, 0.04451851972511836, 0.058624645295952044, 0.026959790848195553, 0.04141807948638286, 0.07800539676100016, 0.10312485814626728, 0.03372445250196116, 0.03236389818734356, 0.0380375807040504, 0.027762908288942914, 0.053780783965651474, 0.04742411184789879, 0.05346129235944577, 0.03663479097719703, 0.03966032773522394, 0.018790651611717682, 0.020827807120180557, 0.022951952514371703, 0.04239693071160998, 0.016459910964061106, 0.036734467771436484, 0.0485125125518867, 0.05652262523238148, 0.016881293085004603, 0.02807858313566872, 0.04894815917525973, 0.016228182773504938, 0.04143926674234016, 0.03679717458518488, 0.027118179581261108, 0.028148497687652707, 0.03262098153520908, 0.03890871449506708, 0.013629637924688203, 0.0392362806679947, 0.010956125134336097, 0.048811078138117275, 0.004691442009061575, 0.029296472069940398, 0.03120636833565576, 0.026458400966865674, 0.043572523165494204, 0.02267934598161706, 0.015523513978613275, 0.08588921371847391, 0.009041268777634417, 0.05511092634073325, 0.03279944981581398, 0.02110247639939189, 0.010301102202252617, 0.0600857279662575, 0.014084115591166275, 0.05050889828375407, 0.04442780637847526, 0.050300862839711566, 0.04113330173173121, 0.035250827204436064, 0.029737506261361495, 0.03276673764256494, 0.05201444196115647, 0.031233428312199454, 0.0255994638428092, 0.02685095552754189, 0.030349578774933304, 0.022544817932482277, 0.024836308721985136, 0.042969916215432544, 0.02145902789197862, 0.024270837993494103, 0.003637339129844414, 0.01277816723034318, 0.022983964100213986, 0.04084408296538251, 0.021876350677173053, 0.019202266221067736, 0.019770686880552342, 0.0589500842615962, 0.03930972529841321, 0.03971201174759439, 0.02172527146259589, 0.021228012163192034, 0.06264467351138592, 0.029601965498711382, 0.01846318382636777, 0.02504001171993358, 0.040032022433089356, 0.02215253308947597, 0.04416208527982235, 0.052823852814201794, 0.04879091886271324, 0.032141063894544325, 0.06166829554630177, 0.018404848474477018, 0.02073332790418395, 0.06312504237783806, 0.05016051126377923, 0.03621073033926742, 0.03999172763100692, 0.038550600675599914, 0.019015280629641244, 0.07307247431682688, 0.04848091317606824, 0.057414810572351725, 0.08950216842017003, 0.015881218980731707, 0.09983280301094055, 0.03062247877408351, 0.04278648105849113, 0.06195173319429159, 0.009834983419360859, 0.06076953520200082, 0.048820156936666796, 0.038940378331712315, 0.04068373156977551, 0.03382277561883841, 0.06527905179453747, 0.006321413741846169, 0.06180685918245997, 0.07520962213831288, 0.14195336640945502, 0.21345590746828488, 0.07786410541406699, 0.10901390428521804, 0.17874493290271076, 0.12552996911108494, 0.17949955883835042, 0.12856124288269452, 0.1448823306709528, 0.19178409608347075, 0.0723780547933919, 0.12207026832870074, 0.15424738957413606, 0.20180444339556353, 0.180502732151321, 0.2550268710723945, 0.27079388073512484, 0.22102214289563044, 0.13987035889710697, 0.1561812958014863, 0.11370753456971475, 0.14579475671052933, 0.13697096519172192, 0.11412147485784122, 0.1136621270062668, 0.12071338828120913, 0.08290669947330441, 0.13743547669478826, 0.16600641501801355, 0.1367093220885311, 0.09764485327260834, 0.08618897691901241, 0.11399350315332413, 0.07289247254707984, 0.16554144211113453, 0.08824833070061036, 0.07455001824668475, 0.14404189719685487, 0.051060163881629705, 0.15447119756468705, 0.18501446076801845, 0.1479789609355586, 0.12426119005041462, 0.10383173557264463, 0.07611133410994496, 0.16730316329215253, 0.0830975238765989, 0.08539723511785269, 0.16103694667773588, 0.09393228963017464, 0.15049848359610352, 0.13011640443333558, 0.21808158925601415, 0.23520089206951006, 0.1974773034453392, 0.1549459956586361, 0.10113556310534477, 0.11579931553985391, 0.13429210893809795, 0.16680838912725449, 0.12002804077097348, 0.21603309203471455, 0.17150461141552242, 0.0778340327420405, 0.06896456224577767, 0.16204424548361981, 0.059111460245081356, 0.13707020772354944, 0.13823058402964047, 0.14026267427418912, 0.13674950493233545, 0.14873377686100347, 0.16133912546294077, 0.12303323165646621, 0.11856845766305923, 0.10114221953387771, 0.10275557224771806, 0.19024821849805967, 0.1082041948767645, 0.1247849240899086, 0.11153152026236057, 0.1500825687710728, 0.1491440734160798, 0.15990046837500163, 0.20391647863600934, 0.131188924025212, 0.1329046812440668, 0.1542617745165314, 0.12030808574387006, 0.15712459518441133, 0.103654841493283, 0.14191228789942606, 0.0935658739347543, 0.19338112324476242, 0.09414042346179485, 0.06288904789835215, 0.10059113374778203, 0.08343865735722439, 0.0860272209559168, 0.1634960254388196, 0.17013049657855714, 0.1900900655559131, 0.12098934847329344, 0.19414950987058027, 0.12248177267611027, 0.09130033371703965, 0.13097217279885495, 0.2133103617067848, 0.08551801435117211, 0.13488590850361756, 0.17869625480047294, 0.12539228078510078, 0.09252695539700133, 0.1327235395354884, 0.14681939887148993, 0.11319852474012546, 0.16499591352684156, 0.128018604857581, 0.12213117363197462, 0.07099095279616968, 0.16632650712771074, 0.10703486869377749, 0.10578635747411422, 0.09900986895497356, 0.10680979184274163, 0.18072443668331417, 0.09583395865878888, 0.11477516192410674, 0.10501309218151228, 0.09039992453264338, 0.11683362003948007, 0.0958379620153989, 0.14900645294359752, 0.11758441903761455, 0.12743613682687283, 0.11384756384151322, 0.0970161295096789, 0.12287620508245059, 0.12664481571742467, 0.11998434311577252, 0.0848990614925112, 0.07783416166369404, 0.2328854048890727, 0.10673718181039606, 0.09853946776794535, 0.11520851509911673, 0.19433171009378775, 0.13976562023162842, 0.16241266285734518, 0.11761768082422869, 0.08156337655548539, 0.15349934542817728, 0.0896321621590427, 0.1281617893172162, 0.10413576675845043, 0.09936565879200186, 0.14180590717920236, 0.12227670582277433, 0.10488944953041417, 0.11534125011946474, 0.2033314457429307, 0.1297566451664482, 0.1358401865831443, 0.10700951862548079, 0.12095842084714345, 0.15945810425494397, 0.10627178821180548, 0.10440230888447591, 0.15398432154740604, 0.17764894956988947, 0.08284782298973628, 0.12411366296666008, 0.16077324082808836, 0.07812416074531418, 0.12655861462865556, 0.10621482519698994], [0.07098609448543616, 0.03221220489857452, 0.033175931578235965, 0.005062925088818052, 0.033989433997443745, 0.021529335994273424, 0.03233173902013472, 0.049798930130366764, 0.03399227705917188, 0.06392308098397084, 0.03038775994043265, 0.011604542528013033, 0.007362367884655083, 0.026257283187338283, 0.04313047795689531, 0.03211812601823892, 0.045608077331313064, 0.03399174440918224, 0.006194153226845498, 0.03017715284866946, 0.04957464377262762, 0.029637398597385203, 0.0101518075347745, 0.022219848852338533, 0.022799037862569094, 0.03072965338027903, 0.020145055006391237, 0.07507420690464121, 0.03925867910896029, 0.03508354118093848, 0.04292012192308903, 0.03763680738796081, 0.04887930144156728, 0.06072088424116373, 0.02710933148461793, 0.038926230876573494, 0.027330635680950115, 0.07945078491632428, 0.11145800099309001, 0.038754775255386315, 0.021650033803390603, 0.039431037181722264, 0.024817555710407238, 0.04146090183140976, 0.011480316336798881, 0.07586489019117185, 0.08069956076464482, 0.019069176666172485, 0.026699828815513423, 0.027444790716149976, 0.10037280153483152, 0.029847978547747647, 0.05358301814911621, 0.05163693900353142, 0.07031752714621169, 0.03064256001796041, 0.09531253163835832, 0.014112207789107092, 0.05357123199584229, 0.09977379082036869, 0.05794830194541386, 0.08235303525413785, 0.04648249183914491, 0.043336922236319096, 0.038223411089607646, 0.012106116461966718, 0.02678617918198662, 0.009213545426194156, 0.03208689644400563, 0.004385599134755986, 0.030551836493292024, 0.007542501968730773, 0.05747485413615193, 0.03132067773757236, 0.03620922738420112, 0.05951309869331973, 0.05354266567155719, 0.027925249488492097, 0.07078453565814666, 0.011253336195035704, 0.011257504096387752, 0.02366309962235391, 0.06285507364996842, 0.020077340604205216, 0.06356531661003828, 0.014736776373216083, 0.030977895416851555, 0.05688002998275416, 0.0249243825674057, 0.024995255550103526, 0.04504418419674039, 0.012738552659616938, 0.012894586876167782, 0.018697605800947974, 0.019492889554905038, 0.018834483277584826, 0.01911525258661381, 0.04534914158284664, 0.04633101907425693, 0.1270246867622648, 0.04326930282903569, 0.041360929874437194, 0.016723769484087825, 0.011278667603619397, 0.01487798459960946, 0.039255296611892324, 0.00637483098710488, 0.042538144027015994, 0.0288319911009499, 0.024821173998394182, 0.029845128700669323, 0.04067145347861307, 0.02177925401234201, 0.03854126064106822, 0.058944845971252234, 0.012818709697707422, 0.022594546067661474, 0.0162799108906516, 0.04283926769026688, 0.10768652015498706, 0.03792278614959546, 0.05664573862616505, 0.032920554745942354, 0.022586770056347762, 0.03315466968342662, 0.05294209771922656, 0.03702841592686517, 0.09438166980232511, 0.026568812185100148, 0.02319048810750246, 0.040003344150526185, 0.04547811412651624, 0.08214193622448615, 0.022730288694479635, 0.036897149934832535, 0.02509479663733925, 0.04824922739395073, 0.058539210951754024, 0.04541707990158882, 0.055833138658532074, 0.010879996897918838, 0.0608208528054612, 0.04407085285388997, 0.021301251536767398, 0.06146692670881748, 0.06386594833540064, 0.04430691857955285, 0.018035830597260168, 0.031160960772207806, 0.03321908301274691, 0.01918668536070202, 0.015233713368486081, 0.02480953373014927, 0.030212277213909795, 0.01731442234345845, 0.05489178667111056, 0.014738177548029592, 0.060820133558341434, 0.08717086458844797, 0.02334418477091406, 0.04068638464169843, 0.04313747026026249, 0.0449025535822979, 0.03450179918270026, 0.04401505013395633, 0.02945025185389178, 0.05893026425370148, 0.027887950418516994, 0.007422584474885038, 0.056072654734764776, 0.04979922868577497, 0.00665905573571633, 0.006124143679958901, 0.015155003306322863, 0.009684106917120516, 0.07673671269523245, 0.02160641417971679, 0.051394033644880564, 0.0428088862848069, 0.020779391950262443, 0.06319913161652428, 0.015204643231949635, 0.008065089284043227, 0.06109631088163171, 0.030578815045633485, 0.0625194227322936, 0.01908864892487015, 0.012604419857130518, 0.042229132394173315, 0.05568396273468222, 0.024555593695757643, 0.05154689401388168, 0.08186198624649219, 0.041949362227959294, 0.02641579575304474, 0.07439263204910926, 0.020831739230613624, 0.041011721827089787, 0.043932923647974215, 0.026610406381743293, 0.02082328298794372, 0.05810665844806603, 0.0346154368349484, 0.042593146075627634, 0.032543411411877186, 0.061100090321685584, 0.04265470616519451, 0.009812445878716452, 0.019387183977024894, 0.03680496755987406, 0.02625456904726369, 0.03362311329692602, 0.030502822516219955, 0.06353550178131886, 0.018716335063800216, 0.016734120535797307, 0.01775186199561826, 0.038431979183639796, 0.019101934640535286, 0.009278409981301852, 0.03180183370464614, 0.12280464677938394, 0.01269586686976254, 0.009696119531456913, 0.02668173737557871, 0.018348653900570104, 0.04995051146085773, 0.022784111788496375, 0.06240327789315155, 0.03986096714756318, 0.015378941914864948, 0.015350865832130824, 0.061709435124482424, 0.004213488303191427, 0.02387770328537694, 0.03508125451792564, 0.007730006639446531, 0.005453247269282916, 0.016041258250230124, 0.007229225743295891, 0.019006273077268685, 0.023976599764344946, 0.014541246329567261, 0.0505920222162136, 0.023849065714914883, 0.007349556295334229, 0.026745236378961375, 0.03974924974941781, 0.0881282774997609, 0.02413838795785393, 0.029954257487718548, 0.023572686527456557, 0.039954873001469035, 0.05383209478376167, 0.052795571474624534, 0.021367720827194195, 0.013717157067731023, 0.03488245393548693, 0.04623793764039874, 0.027302932792476246, 0.04615727000470672, 0.04333466610738209, 0.031863281835934947, 0.033658604071076424, 0.038222512030707936, 0.028251353418454528, 0.049349672094519646, 0.04797305007066045, 0.043339731371296306, 0.05537503252604178, 0.03176375771207469, 0.04005312147949423, 0.04148465055706246, 0.06019467354885169, 0.09732707496732473, 0.03285922875095691, 0.11809630585568291, 0.018586404089416777, 0.08790544659963676, 0.027632470109633038, 0.06735030029501234, 0.04979170712509325, 0.02640338534755366, 0.028041546998013343, 0.05513337227915015, 0.0190939448906907, 0.04331790629242148, 0.030160678018416678, 0.018475677352398634, 0.016431595697732906, 0.037919373118451664, 0.05786033666559628, 0.09346154239028692, 0.07460781585957323, 0.030709117517939637, 0.04608144371637276, 0.0075142910271616915, 0.06565062435609953, 0.05854609129684312, 0.04149934084021619, 0.05422099034434982, 0.028786865129534687, 0.06531050867800202, 0.03653181650276695, 0.019750315562954972, 0.012410194297055048, 0.023383912996255925, 0.052455489723277945, 0.056001079468322654, 0.020357127733794705, 0.039732754563114474, 0.04905071295797825, 0.06554874232304947, 0.043153008712189536, 0.002684941016403692, 0.019856753958655254, 0.020694256161472628, 0.0379171441309154, 0.05002515709825924, 0.0009689251060730644, 0.05043159957442965, 0.05062071067680206, 0.05270815580817206, 0.02178365091926285, 0.05748153770608561, 0.038600812266979895, 0.026169667353055308, 0.012996734386043889, 0.03345968135233436, 0.020102281855153184, 0.048617454777870855, 0.0427762046456337, 0.004028520929361028, 0.03847138510484781, 0.1531476064452103, 0.02769567395028259, 0.03646335910473551, 0.04075107956305146, 0.026489442247631292, 0.05390361237472721, 0.03933560462402446, 0.07772944335426603, 0.007611091681090849, 0.0214415691859488, 0.04836598630728466, 0.016247897608471767, 0.06773424254996435, 0.02507256274111569, 0.030737280113888637, 0.039956328459084034, 0.04276172810101083, 0.019919041777029634, 0.11459121108055115, 0.07941110418843371, 0.11764421154345785, 0.10926908773503133, 0.12254714273980685, 0.11931401837084975, 0.11594494272555624, 0.11295539207224335, 0.1936917430055993, 0.11748265235551766, 0.13848116701202734, 0.10368694298501525, 0.11656949349812099, 0.08240064805639641, 0.14452072578881467, 0.1387973643307175, 0.22193268260785512, 0.1356174371072224, 0.09455153425889355, 0.1174468392772334, 0.0597829045727849, 0.17027661230947289, 0.2072922582072871, 0.09399481663214308, 0.08575391383575541, 0.09973298372434718, 0.10168517647044999, 0.16256578106965336, 0.1504410659628255, 0.1725455384169306, 0.09238969454807894, 0.09963405331862824, 0.2440823454942022, 0.10542874237788574, 0.0847591000742146, 0.10791530859257494, 0.08758779721600668, 0.2228072328226907, 0.16018621304205485, 0.1663055539663349, 0.1041012971795031, 0.11611843055912427, 0.09682673002992358, 0.13789259216615132, 0.10856501265828099, 0.18676780882690633, 0.14016039190547808, 0.13314568331199034, 0.05805432304207768, 0.07369279781622545, 0.22665821760892868, 0.1379048465085881, 0.14245707009519848, 0.11696475371718407, 0.1284276121961219, 0.08807983009942941, 0.13582075334021024, 0.06409828551113605, 0.11060371183391128, 0.2122684983270509, 0.09710760960089308, 0.17017568701079913, 0.07756645245743649, 0.16200760459261282, 0.09005611083869423, 0.07789710935737405, 0.15045028046837874, 0.11957743923578944, 0.11888038021113191, 0.15766658181590693, 0.12121642700263432, 0.1474296868379627, 0.16101616993546486, 0.07916147794042315, 0.1598780902900866, 0.19819830118545465, 0.16993315145373344, 0.06289588074598994, 0.18508553052587168, 0.12877365148493222, 0.09336196737630026, 0.13811673942421163, 0.20585844585938112, 0.1495226552443845, 0.21227380447089672, 0.08454538868474108, 0.13098672058965477, 0.18054956463830812, 0.17509161893810543, 0.09749168756284884, 0.1880919292036976, 0.20462986321321555, 0.12656484358012676, 0.1278011208134038, 0.07885068176048142, 0.1320647770272834, 0.14733025431632996, 0.15102193265088967, 0.14888795358794077, 0.19024547721658433, 0.2894805994416986, 0.12670682024742874, 0.09965112525969744, 0.17505391953246935, 0.11594111578805105, 0.18791063821741513, 0.1449090785213879, 0.247607416340283, 0.08728234789201192, 0.05053121869319251, 0.07525832738195147, 0.10677801604781832, 0.09988310959722314, 0.09623676418725934, 0.14367110495056423, 0.09557225448744637, 0.15181766423795903, 0.15742092499775545, 0.10709446442446538, 0.1533637469900506, 0.06879262147205216, 0.1766328705208642, 0.24006226978131703, 0.14647231463875088, 0.09753515451614346, 0.1461445957954441, 0.13093374057539872, 0.2121515731726374, 0.09089912953121321, 0.15165496511118753, 0.0859196460140603, 0.11662359988050801, 0.20077787419514997, 0.12686284258961678, 0.12000871609364237, 0.12660843266972474, 0.1637719992016043, 0.16187638949070657, 0.0852277913529958, 0.0953342311882547, 0.11783007585576602, 0.20470475990857395, 0.20094160469514982, 0.056909278234733005, 0.2435607420546668, 0.12758435601634638, 0.19030893381152833, 0.07508348926369633, 0.0945107475189226, 0.08985873178711959, 0.07934186647513083, 0.14930040788437637, 0.1547309271991253, 0.08622441001768623, 0.10424936709127255, 0.12419485646699156, 0.04150032132331814, 0.09593481610396079, 0.36389086661594255, 0.07631412108561822, 0.151496377906629, 0.08619473089597054, 0.08640367896961314, 0.11168666050902434, 0.16525963294718946, 0.16058893714632305, 0.0841597161654915, 0.13451788468020304, 0.10249531335596528, 0.10892103319721562, 0.1559537694390331, 0.08512506115117244, 0.1045874132375632, 0.1631157472729683, 0.13592688978782722, 0.16521778090723924], [0.10940176168722765, 0.017300853339423026, 0.03140841570815869, 0.033555490496967516, 0.011087440320157578, 0.01122944921787296, 0.03496363386511803, 0.01752278348430991, 0.04580799749653254, 0.010298328690363892, 0.017826436386842812, 0.034706211249743185, 0.010971599125436373, 0.0260737581245069, 0.05061745031603745, 0.021812251170298884, 0.04909219180366822, 0.04044583040688719, 0.028763116403881992, 0.011208970182841378, 0.05223513886864696, 0.01916973216326109, 0.04222943773493171, 0.016608508436807563, 0.02703562901089234, 0.0182827376161835, 0.06069227720477751, 0.08140317443758249, 0.07567862554320268, 0.024730501363852193, 0.025974976996492063, 0.0769784679370267, 0.05641456174531153, 0.01624837258298482, 0.06089894540075745, 0.024617272528952787, 0.06081319893045085, 0.014455158895413791, 0.04620887937822512, 0.0331935870594212, 0.023749102239630053, 0.037161941440509896, 0.03148159570991993, 0.0024572015515462097, 0.030735373430486237, 0.027439984991880398, 0.04837559436314872, 0.03555260904665504, 0.0495862535067967, 0.017171237883823257, 0.01965787704102695, 0.08244008451168026, 0.004967042577586004, 0.006233509954264653, 0.03834950325212308, 0.05570538408522095, 0.05063951627484389, 0.0843482810471739, 0.05592249493513789, 0.054269919504544566, 0.02317032204674823, 0.0056643094035929865, 0.029487686630870615, 0.02411865785584918, 0.04385621526411601, 0.04324023438883679, 0.011887533191059316, 0.02659081368307982, 0.014620497523407851, 0.00821718290847327, 0.027327924933550612, 0.043342625323150835, 0.049335059842893055, 0.024800636439717243, 0.03384355914645961, 0.014077806063661618, 0.017369895973908048, 0.06144255373094763, 0.030589121992566755, 0.04448651322828872, 0.028642286280436174, 0.02492370912139969, 0.050880196038633585, 0.06653147816125836, 0.09835791893835578, 0.04576684434765151, 0.09353981140468802, 0.04805703913526876, 0.07154049152242285, 0.06833220832049847, 0.04394721359546695, 0.008266016225596624, 0.02997362966250096, 0.012159680864507598, 0.03613388964108058, 0.10991420490401131, 0.05697925215853112, 0.0584373085626534, 0.0643027891804065, 0.0853237294192825, 0.07128380851021834, 0.055218206119856665, 0.0847028698772192, 0.07876583774174963, 0.02252127616001027, 0.020116729562037756, 0.025794082953195487, 0.09784685993301016, 0.03678143596542733, 0.037783119894031963, 0.021342021313362887, 0.03537404237847243, 0.008461571714308645, 0.07304461366896119, 0.032264204429728646, 0.01209353472638343, 0.025559469292472516, 0.022383214639765874, 0.04807437909767032, 0.02415932754852942, 0.03760522497551782, 0.01876466372050345, 0.02100981056823262, 0.03764002025127411, 0.017649133490132432, 0.05135241909218686, 0.028882684452193122, 0.023891738782237684, 0.0059697074133769745, 0.06391290295869112, 0.07961856627038547, 0.030302427376487424, 0.08214394468814135, 0.03619734623602458, 0.016761172030653273, 0.016561051697603295, 0.03886991586270077, 0.03979403306064861, 0.004989807851546044, 0.02823752487477447, 0.009852731350942381, 0.048015109063791375, 0.023370503447949886, 0.0109334569757006, 0.029036511733595814, 0.02169301560414689, 0.05380820356575506, 0.05816149764827319, 0.035355029827249904, 0.010544268796885652, 0.010492386313022246, 0.028277353184031587, 0.042653756216168404, 0.006272663121178214, 0.012352230443087007, 0.008641088331517364, 0.04313406740714397, 0.021010014128738215, 0.039294268270688396, 0.017083720437117984, 0.010932172848177808, 0.026978107901023965, 0.010908808342979422, 0.008126506033087415, 0.025418980313198905, 0.08486446299191032, 0.017356175995830978, 0.04701367958581873, 0.03353892745716231, 0.02548931386055691, 0.0627746061821069, 0.013284092270103949, 0.01790435765204685, 0.048991252934294086, 0.0387497133841472, 0.03627627342939377, 0.06403502569134746, 0.058943068209503374, 0.02334257325024477, 0.04078609536268881, 0.01938579128389912, 0.03505546340186681, 0.019731116414602314, 0.01763789525388607, 0.0222035249961274, 0.043269706557371786, 0.043436310653175624, 0.038538912909903696, 0.018567771517804692, 0.04281272000766226, 0.008922118876528527, 0.04238452709146908, 0.026245105180091093, 0.01366346883254924, 0.039714905699448924, 0.020998416268931966, 0.01461977997262563, 0.024955591785588434, 0.04889546414571149, 0.07053123175033502, 0.058669170763875754, 0.01050343455946339, 0.007293678936548531, 0.025615646903003966, 0.05259028409740754, 0.04829279612749815, 0.022420644327732067, 0.045853394881955216, 0.018194497529683367, 0.06195200460829905, 0.032411731513483186, 0.06309943446623427, 0.052467326766678264, 0.016094993134694438, 0.07904118046696697, 0.003327342348971537, 0.0396467434641506, 0.06245720785643373, 0.039041527546942234, 0.044480328381593735, 0.0577921506815723, 0.08307547148849283, 0.05127942568755575, 0.04788792785257101, 0.08267859635608536, 0.026379466988146305, 0.04260698140465787, 0.02112424380279013, 0.025958135757329207, 0.0349620901979506, 0.026377215948221937, 0.04460614573742662, 0.07459682359227113, 0.03242726318006005, 0.0400944544401552, 0.0361106362459915, 0.047613324730523994, 0.0331399183321212, 0.07210774001266275, 0.010799481932606016, 0.034149235779685636, 0.035921382651265175, 0.02297369616904429, 0.021892213129571507, 0.027111362000661235, 0.024120936037174294, 0.023203325990055288, 0.020499156987560645, 0.12631115290735448, 0.01757031655870378, 0.020798842156572, 0.012100868841766246, 0.023010662756860256, 0.08024712039956025, 0.05992945456611259, 0.02870749688840338, 0.028659500713859285, 0.01520120645208018, 0.05467451297278915, 0.01048487747487213, 0.07407127786427736, 0.019365537013592463, 0.008312908932566643, 0.0172996370654021, 0.058904310289238176, 0.08649996308875935, 0.05286738422832318, 0.019433751835354736, 0.019013238239235113, 0.047806893807968924, 0.029629765078425407, 0.04773908780355539, 0.028901876815195595, 0.03834808511393411, 0.00470921241711559, 0.05274245236068964, 0.020075690067772354, 0.05537362117320299, 0.022867208579555154, 0.03601279488897749, 0.11763932609132358, 0.02016002688157771, 0.0500744289186384, 0.08020990275378738, 0.0017504358714047286, 0.03262824185990861, 0.06574028597346374, 0.01447958785242268, 0.019331016544518725, 0.10454766465617077, 0.02380847235742424, 0.05394997667255146, 0.039743889322770495, 0.025013009418866465, 0.036654739906745296, 0.0726808849722147, 0.057741165560271056, 0.07617289759218693, 0.04510777989136321, 0.03298011654987931, 0.05154529945658786, 0.05975141376256943, 0.020896956623931016, 0.044679675184722455, 0.052132914175412486, 0.023681732193965997, 0.008444926402132426, 0.026004766380148273, 0.08523842399673802, 0.04070134973153472, 0.06990787519940309, 0.06373127270489931, 0.0391172486623483, 0.03574117732101253, 0.023660164958398257, 0.0230717376938888, 0.00876087011835937, 0.009975631006195076, 0.029647827680621828, 0.016880994529596398, 0.004212269484664181, 0.022588669954399978, 0.01189170278874891, 0.06256031125251736, 0.10222260334662028, 0.020868704122092043, 0.01772646782254534, 0.03383793748383011, 0.08578949621213333, 0.03372304793447256, 0.02298084962447839, 0.02260466302478952, 0.01751030013630433, 0.04117850234199848, 0.01881731634161302, 0.014643024886026978, 0.020769700773858597, 0.012084602661031698, 0.04385739252237337, 0.02236444636115006, 0.02762901975906321, 0.05749970208853483, 0.029231383598276546, 0.08095262718519994, 0.04781345524159925, 0.07102824508079461, 0.01408379413520119, 0.04808184976822563, 0.0186422169873757, 0.034872486256062984, 0.014331071803878461, 0.050114007866276164, 0.15472882374056748, 0.1594217347779444, 0.15082499464707716, 0.15351848011570318, 0.10271777784717934, 0.11003643620227065, 0.12719769962131977, 0.07627979399902479, 0.11344378122261592, 0.09949361692581858, 0.07136416741247688, 0.19989851995238236, 0.15979233703442983, 0.10561397565262658, 0.1863581093826464, 0.18338510819843837, 0.1594125609844923, 0.1514874076736825, 0.10884560724454266, 0.09946833471102373, 0.07205427823854343, 0.07132276320563895, 0.11365465633571148, 0.20688599215022155, 0.13494993506797723, 0.04178334167227149, 0.09931062960198947, 0.1391162079359804, 0.2195517575102193, 0.1136051979182022, 0.10731949377804995, 0.19177622507725442, 0.14298612384923867, 0.09825518195118223, 0.10047970472701959, 0.1488793904760054, 0.12305027645613466, 0.07932363423917975, 0.17181676466550144, 0.08778561052999326, 0.10102141994450774, 0.1374168712645769, 0.1229627997215305, 0.11994409241846629, 0.08210800947355372, 0.19822735605495317, 0.07071925380400249, 0.13035953710121767, 0.15604663374168531, 0.0662699504090207, 0.1655614860355854, 0.18970665255827562, 0.18764109696660722, 0.1283139032976968, 0.14882548765412398, 0.15605400263198785, 0.11338875203260354, 0.1655878403357097, 0.2186757688011442, 0.14074594048517092, 0.10695716964879207, 0.12072082502501351, 0.09676664575402226, 0.08960955337222133, 0.11645224264689855, 0.12959656518484863, 0.05668840830081275, 0.10600289156926529, 0.09737720513450247, 0.1466602281268154, 0.17305477894842625, 0.11344144027680159, 0.21707807667553425, 0.18445773635591778, 0.10024457198700734, 0.13877812107758863, 0.1399235696132694, 0.1313846813780921, 0.21718384671424115, 0.17269940301775932, 0.17632052728107997, 0.11432981224996702, 0.10241878139121191, 0.200300022693617, 0.14072562514671258, 0.0978098933451942, 0.28200504343424526, 0.05791341167475496, 0.16060580552688666, 0.1615226963268859, 0.15313699415751866, 0.14258947941873754, 0.06724852004221507, 0.19523892498442105, 0.20579247868486814, 0.21368909281279358, 0.1421932963920491, 0.12330828261162553, 0.11235504464379378, 0.15797774440475873, 0.17493250247623238, 0.31595025051917347, 0.12658551175679478, 0.12983388959297112, 0.20858029409178666, 0.06480578040438038, 0.16088544337877206, 0.129251787971173, 0.20313376135059766, 0.09321983464594398, 0.1677315631615264, 0.15390189311334065, 0.10190237552991935, 0.15836498433990137, 0.10216125021023409, 0.13238177501729556, 0.1419293326990945, 0.16957023021365913, 0.0859750619690333, 0.2128140947648457, 0.27402786005820545, 0.13697506354323455, 0.11984843255153724, 0.11892456641154629, 0.1565335097589663, 0.10602169377463204, 0.15623808918254717, 0.1576942117618663, 0.13440682206835064, 0.10913618308092866, 0.1862194575369358, 0.1226852246161018, 0.21230728338871682, 0.14239840395748615, 0.14114569260605744, 0.1576548567307847, 0.16318734628813608, 0.1742731292865106, 0.16053096311432974, 0.15351256329034055, 0.058416843946490965, 0.208749208599329, 0.07393895675029073, 0.05451129137405327, 0.14704476749258383, 0.07561338440115963, 0.15545204707554408, 0.1819242223032883, 0.19945794716477394, 0.09018002490379981, 0.13340858849031584, 0.12592016745890888, 0.18690887625728334, 0.10459162015467882, 0.08407325044806514, 0.07610380237123796, 0.0699142941406795, 0.09914613914276872, 0.18162046931684017, 0.10124053247272968, 0.06824125748659883, 0.14117440820804664, 0.11084253580442496, 0.05945629852690867, 0.09716912558568375, 0.14050995957638535, 0.10354929537113224, 0.17179473941879614, 0.16950134533856595, 0.14754448139241763, 0.14583903790584632, 0.12272319543574538, 0.06958693492093257, 0.10514260416052171, 0.1003319469413587, 0.12123864223914486], [0.021688751011554683, 0.03636998250814421, 0.036741426148052723, 0.060706261811511855, 0.06450909096747637, 0.08909973608595984, 0.054671432423804484, 0.011918498136635338, 0.021681723085099032, 0.041078900186611075, 0.011323747773920851, 0.019075152863349234, 0.029022608551063707, 0.01133019385659801, 0.0548381518705615, 0.04354024186198201, 0.033558747465057034, 0.0694635636838419, 0.10800404740231377, 0.05173426128125616, 0.04705309568505202, 0.03125915496743151, 0.03579058824107051, 0.005143521902417498, 0.03698138666472264, 0.012575558370112308, 0.023428730234237652, 0.03847413656434842, 0.010657210102570909, 0.04452841276569026, 0.018964102125859687, 0.03438718444002526, 0.018554440001025796, 0.019434213239167417, 0.06304038834891149, 0.03518990154511162, 0.033317345061472485, 0.04945137431578977, 0.05460707337728568, 0.017333209281787276, 0.044629131111183336, 0.028407933855695382, 0.03573253617755004, 0.09247376503688948, 0.06294500668134008, 0.06513784187180655, 0.028463095360036408, 0.018124145322612355, 0.02173846387969596, 0.041430225263216665, 0.00950111195977245, 0.039457920739161115, 0.05842608559344496, 0.04354965653536575, 0.018922825144337754, 0.03959793983293431, 0.055959305459899564, 0.030330898705869913, 0.012033704052945333, 0.020774503105453083, 0.025218982116452286, 0.03281383475820933, 0.07893057247357708, 0.03564417056207146, 0.06579082326165267, 0.0488751250585275, 0.054027743571038754, 0.06281317411256687, 0.02253961017621415, 0.008876665511966815, 0.060850138376866064, 0.006813690897875598, 0.03268816668008055, 0.04375807195901871, 0.04877591645345092, 0.01182651677767613, 0.059117349929043224, 0.01828933976191495, 0.01048887743880706, 0.04106932266482285, 0.0386614054441452, 0.08241383877715894, 0.06877065050814833, 0.05652050820312329, 0.02367977631677474, 0.030223378046814884, 0.07194259137447391, 0.006749422181331153, 0.027335544881810035, 0.04304423276335001, 0.007514604849607817, 0.10202807414212398, 0.0377144758988704, 0.04826169886759349, 0.0380197623744607, 0.0038710986846126616, 0.04649426781439355, 0.0555954139147486, 0.027318321966699192, 0.03499372350051999, 0.015562668841864382, 0.014317046485042997, 0.061213575303554535, 0.057294072051133425, 0.0430047250618892, 0.018924908246845007, 0.033948297811938186, 0.05826940507228885, 0.04074565128290227, 0.02372963846262012, 0.02027191560981529, 0.055964618389095576, 0.0148457338301731, 0.09411609798137631, 0.03275973855384758, 0.012546880935717906, 0.023564559374270693, 0.03211159851135952, 0.016783948754891753, 0.03254643767806036, 0.042798945746783695, 0.1478688075606312, 0.009592952522715288, 0.054961482395551035, 0.07120132579335145, 0.048673206607678106, 0.022101831256545017, 0.04547939655770149, 0.055044226348400116, 0.0041992746908882895, 0.022790043880896907, 0.01247633619433535, 0.013088874352563704, 0.033224568968372684, 0.011333128520553666, 0.023054896454725946, 0.041377825396401544, 0.04069478490522929, 0.009944440447725356, 0.017376945952751806, 0.04585063663710441, 0.04152182409805911, 0.0592344854293125, 0.016102682632793273, 0.03231037873774767, 0.057730220790420256, 0.04493984586692282, 0.02633249031246773, 0.0201473060463156, 0.04112925427034497, 0.029292590849633728, 0.021049915380509834, 0.03499686511765633, 0.048003529863698144, 0.004253740696835199, 0.09632390165435416, 0.02725458547606, 0.04564545104014022, 0.07752740955246346, 0.02229825357374336, 0.04684624428461705, 0.033229138901723285, 0.039223198512835164, 0.05786461143621376, 0.009609317939196314, 0.0582649131704654, 0.06627016075487648, 0.0391476232824581, 0.003340903507445806, 0.025228856497311165, 0.011020831081883183, 0.057129391602107456, 0.04203549546322652, 0.06886796600052289, 0.03810637736959117, 0.007760025028671537, 0.043429915460624864, 0.03452948680413621, 0.026513116334431937, 0.006838705515422459, 0.061978474259376526, 0.03016233703653727, 0.08123024300272975, 0.06917592590408665, 0.029715765999364, 0.0020240184343752582, 0.006987858114631048, 0.0161879388615489, 0.0640311376856906, 0.02431246272421309, 0.0315539546843086, 0.04529627691954374, 0.010649119420642299, 0.06388544264648642, 0.031769141887447665, 0.015551798710865634, 0.03405678877606988, 0.06666397569434983, 0.03453796170651913, 0.04938672689188804, 0.06898622108357293, 0.02450542281647878, 0.03210485726594925, 0.005206824978813529, 0.03761366255847471, 0.08595355919429234, 0.030827776329325776, 0.03596972827134388, 0.05632386875471898, 0.035069814417511225, 0.07474314966904265, 0.02622226399502584, 0.039656765426376035, 0.054332924873701165, 0.05463098495134285, 0.02132480518360223, 0.056658016717327495, 0.016388824242832403, 0.03317139896431139, 0.06670823653361627, 0.03727432380297354, 0.023948007994996648, 0.06541558661098991, 0.014023785346320696, 0.03159612902839269, 0.028937299735844135, 0.05019472978476967, 0.018713982243623053, 0.01550446919697736, 0.012540181250577527, 0.05533547393445458, 0.021642093247334872, 0.047196914574929645, 0.04097263481734054, 0.01925614190154842, 0.02322297975687044, 0.010311098719414855, 0.0361306699924171, 0.06389152232025351, 0.01780772578370358, 0.07677327894738742, 0.0358684569198106, 0.01503288057366652, 0.08218001560973269, 0.029447724310947315, 0.010406700910867324, 0.03231049408870084, 0.012560096253374857, 0.036008710108165226, 0.049596852223787985, 0.021089153364300728, 0.008742243483928698, 0.0048685248059752795, 0.032841780222952366, 0.026222582906484604, 0.06344142968633346, 0.01855285562175725, 0.053103422812585316, 0.05175427806430629, 0.07108755582677466, 0.018301994440012744, 0.02544942617948566, 0.082914434772517, 0.02150449652357825, 0.03391855422939573, 0.044733201419668536, 0.03373222851327487, 0.015606648089098079, 0.012639881793542631, 0.028208400455436537, 0.09706811886280775, 0.04567189694249204, 0.036489194325570545, 0.022730314139542834, 0.0232790267494108, 0.057201791288597245, 0.042339431654129706, 0.02293286193162203, 0.08392585907131433, 0.011716750167709376, 0.04715879447758198, 0.05036941523264561, 0.07038602525634424, 0.08085683839661734, 0.05908864111240421, 0.038330511056951115, 0.01478148334925728, 0.03636655251362494, 0.030838799130703722, 0.05579940189740487, 0.02744148625060916, 0.026027263208691562, 0.04617746999221189, 0.0345187964849174, 0.04200328201321619, 0.04389790106298668, 0.009389074801999544, 0.045448954084089825, 0.04389789427763649, 0.06361116522124835, 0.07622501586696931, 0.02409342992385583, 0.06869738908218485, 0.042686122336557934, 0.00913803804931896, 0.02195658065777804, 0.03012729748817427, 0.030951055964188914, 0.034451251716486046, 0.006038328083897275, 0.029890183425907577, 0.06766869606716291, 0.013901167283100741, 0.028743143725608076, 0.027395903964393904, 0.05299495898985437, 0.024548389350197146, 0.025370402294876318, 0.06171975564211607, 0.0089193835322346, 0.01121012114786676, 0.054828564170747995, 0.025116036479760493, 0.03405238508379885, 0.04500570108315774, 0.09193203624870096, 0.09696672537497111, 0.04096211752455149, 0.025813677348196507, 0.05485498971704926, 0.01158696083751108, 0.04159574709566576, 0.03183803694056613, 0.0997802165469953, 0.09540496846394879, 0.0398884715645441, 0.0026692602841649204, 0.037389986882252355, 0.060909238776990345, 0.030195751493530612, 0.035129359258072715, 0.02850399405828544, 0.027778636730675186, 0.016352895813594972, 0.09173288622072764, 0.022984712185072045, 0.05369967528219734, 0.014329948828422596, 0.03422161511012486, 0.04629463263388191, 0.025347752795953835, 0.02831360391740288, 0.18235524131783418, 0.1605461894401482, 0.07409111822822265, 0.08593386810805116, 0.16080412774213723, 0.15087884318615707, 0.1719699643020119, 0.12398181004183632, 0.07640606258064508, 0.10807192804557936, 0.1759192416710513, 0.1466914000255721, 0.20284328050911427, 0.1992584578692913, 0.10783282587570803, 0.15152408927679062, 0.08584453218749591, 0.15748041894819054, 0.22261717516396726, 0.13470422396702425, 0.1202153842896223, 0.08203801180102996, 0.16509637742170266, 0.12662669883242675, 0.09168101900390216, 0.07962041188563619, 0.10073965149266378, 0.08110763172485999, 0.143681065844638, 0.1495248129857438, 0.12025387079588004, 0.21173392129795893, 0.11450962402990886, 0.10225464377020087, 0.13520159013569355, 0.08667555438088519, 0.12679958955517837, 0.12860203640801565, 0.14811639141823563, 0.0886071671598724, 0.10393861840878214, 0.13983113957302912, 0.12462747682418142, 0.20346263370343617, 0.1561185855950628, 0.09140417671629361, 0.11402913981250354, 0.09289732695158039, 0.1603849966611181, 0.10024925387863602, 0.0938109132860388, 0.10828678615923439, 0.15467806932117256, 0.12342349785779204, 0.11318088282964059, 0.09289138298481703, 0.14344184153846332, 0.15155323914119176, 0.08288999394114528, 0.1191077030130795, 0.13758277307663644, 0.11014935121472393, 0.17849424135472092, 0.1270128802529403, 0.20584074966609478, 0.10467398752059255, 0.12010973638721875, 0.16565869296235697, 0.1174892612865993, 0.07487627823970147, 0.15760422444769315, 0.07857471478304692, 0.06641706358641386, 0.15557696537247725, 0.08888144458511046, 0.09184518376631395, 0.11064810159483127, 0.10510030428745917, 0.12874181462185724, 0.2180118765681982, 0.12448505232376711, 0.16452184825071267, 0.18027764851493494, 0.2232981664793832, 0.07402561245752232, 0.10905522028250353, 0.16805620145584854, 0.07818321364798717, 0.1214947077844824, 0.19335409040961946, 0.279221095676933, 0.13444363937846251, 0.15863618121615478, 0.10185238106974534, 0.16262155664818628, 0.12829308584332466, 0.23381331509777478, 0.09544863897774901, 0.08362023332821471, 0.1396762571696724, 0.09318283413137708, 0.08685265202075243, 0.2037712178592171, 0.13908229475574835, 0.10249914029347044, 0.14162909452404293, 0.1356424479080098, 0.19840802278901848, 0.13275463001004287, 0.15261468504156384, 0.10687926704330103, 0.12567162008157798, 0.15312358630555017, 0.1573432870209217, 0.07514379067080361, 0.08396255424512283, 0.10116626681493861, 0.07877184277666466, 0.09021992276289634, 0.1293304573212351, 0.09689827476228986, 0.22499197987573488, 0.1275580967111247, 0.2461196875997952, 0.1186945837523256, 0.08694070551012244, 0.1674249738987003, 0.1524804572441748, 0.1110870051862938, 0.10005395792956863, 0.12092688253947667, 0.07350585463323764, 0.1257956020001854, 0.08074127031224114, 0.08183774897562605, 0.09380501681672675, 0.15292027007256234, 0.11610411347023078, 0.1018246832702841, 0.09314601003591504, 0.08076070355517523, 0.10467092732765845, 0.15110035772834504, 0.08031423429825477, 0.1788905058056116, 0.18767727645380156, 0.30796389334968155, 0.16556852922907897, 0.10810335100229297, 0.18583646523100988, 0.1593081480158227, 0.16113034023770265, 0.055101976463837285, 0.1273916656417506, 0.08391089737415314, 0.22682213809873375, 0.13223735562392644, 0.23420382557170732, 0.14821183415395872, 0.18378844298422337, 0.08712909397269998, 0.11168679621602808, 0.13221220911613532, 0.1455410388963563, 0.06564985761152846, 0.1379907897540501, 0.15374053748590605, 0.09442208334803581, 0.1662037330014365, 0.09826038631477527, 0.2283269523509911, 0.14436196216515132, 0.09474923222192697, 0.11216805396335465, 0.16737943062824862, 0.10997101864112274], [0.06314887931304318, 0.0428729976660439, 0.00979700157352324, 0.018355459606807147, 0.01830223871261946, 0.0862780414255602, 0.10663142534238951, 0.011188235849009028, 0.04518337547779083, 0.006902816896659455, 0.028838230230446373, 0.03545595173324857, 0.061075025238096714, 0.06175002508929797, 0.023598514962941408, 0.02046488248743117, 0.02514061301813594, 0.020651869775195206, 0.0452063846002732, 0.0647021002535309, 0.017802043052922403, 0.07558057723300797, 0.054945536822612794, 0.054696846952927966, 0.04091088813064354, 0.052720684957291396, 0.011956144955807498, 0.015580538061580487, 0.027623815395470177, 0.051200881866472106, 0.05919834665421929, 0.07827575903918062, 0.059800614336771626, 0.04578919868384089, 0.055659755997891934, 0.020753303975132958, 0.06881685874291829, 0.023284085227974823, 0.00820243834251804, 0.00865984897661422, 0.048507491392748694, 0.011764472383739693, 0.04006994914795671, 0.038533752651086876, 0.011523168367732848, 0.03544906799548438, 0.018234644750399247, 0.013964997072304999, 0.02877341995814017, 0.046932163781353405, 0.029447860017951046, 0.046313037896262746, 0.07766800200832741, 0.033544542334441624, 0.03517988297556128, 0.03558216603206737, 0.04205445373164756, 0.04548821072759373, 0.010347215442119964, 0.04480678854244096, 0.02135115609105144, 0.05366453056090644, 0.014855577676956142, 0.03341936619420137, 0.018848187988623977, 0.06066846062562295, 0.05963176768273115, 0.031682431897414584, 0.03884851826088769, 0.05126064044556447, 0.027337924843387942, 0.044046985384609015, 0.02936370131958808, 0.007822379852379007, 0.02774877440450447, 0.06605952991438763, 0.054897839203476906, 0.05472241075975554, 0.039644565366740735, 0.008237770509107836, 0.03202647290059498, 0.02138166981084006, 0.07006083056330681, 0.048146568438304324, 0.012187703512609005, 0.06925165041216783, 0.026601515876661454, 0.03295861716781344, 0.03879457472690514, 0.02907385490834713, 0.0113650145774175, 0.024604853641773974, 0.039668680501303503, 0.023870566793318306, 0.026158050833536044, 0.028197184271578277, 0.0601368352238621, 0.05588791000523737, 0.029208058957010508, 0.01294959062111697, 0.024551432579755783, 0.022089008641030108, 0.043504096301538606, 0.09478357287922076, 0.021419806871563196, 0.039956793255571804, 0.05872816259839705, 0.018688979924523404, 0.06244676520249673, 0.042626407862241776, 0.02751700041283454, 0.02537147607654333, 0.030007553020758287, 0.0660455385223031, 0.0643618760098304, 0.038223200743751864, 0.04091384993599994, 0.0028455538600350595, 0.015185130261150854, 0.03626875186871205, 0.016401363569977026, 0.07090521989656345, 0.03403377626091242, 0.05518268481163042, 0.02585745133858706, 0.02781861262129886, 0.0443115156543042, 0.05312730385256665, 0.033702661349837265, 0.033048098973397694, 0.048082497769168446, 0.06546165913875614, 0.027002414721729498, 0.012704665772616863, 0.011214135530670839, 0.031389620288142135, 0.06553297316921608, 0.02279000316879579, 0.03833125066012144, 0.03732186196638005, 0.01529418780202312, 0.038653927988239696, 0.01895278925076127, 0.07855581079742738, 0.06564976261662585, 0.012812080410575228, 0.07776205374726228, 0.04076514559398804, 0.04655641483675156, 0.05146635529984321, 0.010960623821509736, 0.019008571614644358, 0.06276398710906506, 0.04116325566012945, 0.04430148351405348, 0.0035713346359053893, 0.07200587833566324, 0.04278206040284463, 0.017551566939800978, 0.04414852815014975, 0.027674496872350574, 0.04686714655586651, 0.05368169749687825, 0.028828513608979325, 0.09135499649814197, 0.04506665388388293, 0.03776634990104607, 0.01852761411906353, 0.056138842433158836, 0.04044755049315946, 0.03938609780743718, 0.07601762842386961, 0.006767862642716084, 0.040697095316967795, 0.07411378808319569, 0.020879053477463976, 0.03232250076585582, 0.013303092098794878, 0.03397853333236916, 0.059025985188782215, 0.019209458692265407, 0.08986246372972216, 0.023875623575544784, 0.08761934909437384, 0.004919120193725186, 0.02210009759957237, 0.02271546609699726, 0.036596837120928934, 0.01987464862343456, 0.0491837261776839, 0.022144036134704947, 0.03337961761280894, 0.03318957691746099, 0.01687553062635873, 0.03816241079143115, 0.015871410757037144, 0.04859812670786466, 0.04066791831116591, 0.008591344929300249, 0.015029209699215633, 0.08168678171932697, 0.007097271038219333, 0.01887664065829345, 0.05839743784495762, 0.03633187598149691, 0.027644083236477206, 0.01821471787323909, 0.08219402735786778, 0.05581841105595231, 0.025609777575092654, 0.023558583177093948, 0.04527341028941529, 0.03371510568207928, 0.019709467754832337, 0.04842144975970898, 0.024160564178600907, 0.017127511390884007, 0.01168595570405679, 0.09229832302246775, 0.05498448134000812, 0.004440644864059452, 0.03379349344010864, 0.024757581696446453, 0.008887960575520992, 0.01711169643593686, 0.039763980744672675, 0.01778310344421438, 0.04126826573961547, 0.05813647327678544, 0.0525740433617362, 0.0029077664034308066, 0.025638277742213438, 0.05483848096004554, 0.028958429316324846, 0.030975425549383675, 0.01631705050489732, 0.04966080075662051, 0.0204959424279098, 0.04968834927837763, 0.0784469059269343, 0.02563891895780606, 0.07128841576299497, 0.029122695858989443, 0.025818011490628123, 0.022104290945987617, 0.053461730014532804, 0.02386799853827272, 0.07704957162163087, 0.054028852975794246, 0.026715696356924515, 0.042514049248503785, 0.06126276909240654, 0.027527047820123177, 0.10004731507173606, 0.01717570603692106, 0.03862210808854018, 0.03564519854262471, 0.03413346323317715, 0.02796765792715762, 0.04485671175643802, 0.028991148274924074, 0.04280025531936969, 0.009963145113683172, 0.009787265444174409, 0.07474078836717776, 0.04518631353442158, 0.02682056394405663, 0.013780098824229623, 0.05413696735299059, 0.04229640235592212, 0.04820590293301003, 0.03407880723742502, 0.0367733172939292, 0.005322597471864096, 0.042999717473451576, 0.02061145453314696, 0.013997434438871486, 0.008475635200738907, 0.03314208625150578, 0.06217577188674893, 0.022833444677027206, 0.031903390040887256, 0.07686783280223608, 0.01901017126095082, 0.04974280510629926, 0.03589117766491004, 0.07197460465665374, 0.030760581006429026, 0.01169883260237319, 0.020042083924636245, 0.05258530365037067, 0.07689872650163514, 0.020350978510188203, 0.04579180765098759, 0.06094198487699032, 0.062147985877735276, 0.015374633217496532, 0.05948468843208892, 0.013687974124747728, 0.014230572285928896, 0.03476330318621226, 0.0674498210261975, 0.032362809138638635, 0.013329752587846347, 0.028775330034217665, 0.038602668060255904, 0.09099691999810082, 0.08237215637096337, 0.05528690439781972, 0.028920638308461224, 0.07868484101657357, 0.0073861310291769245, 0.10083524350609098, 0.020181724735136543, 0.026324863578858118, 0.054688402584620883, 0.0560526108103139, 0.07745302854371922, 0.019109184787209545, 0.08655235956289939, 0.02418575988018087, 0.078258598888559, 0.03871011747313397, 0.016981631450887238, 0.04946810020399945, 0.03949398148272719, 0.044611095650387664, 0.026834512927702496, 0.03578764000641448, 0.06333226697253329, 0.03669472258271916, 0.03790090339524405, 0.013611695762457592, 0.06210538066391434, 0.040530094278178046, 0.08711384729083095, 0.08363434685660259, 0.050536443412836106, 0.059348838936005316, 0.023973843215831687, 0.04431273023198758, 0.03544961760884949, 0.027980465275634612, 0.01193341488085155, 0.07852801121771336, 0.09013366739132575, 0.006927789953936423, 0.03633507527410984, 0.034874657568122656, 0.015340290863865187, 0.07333151184554611, 0.06914104241877794, 0.17361448891460896, 0.12426308994846684, 0.11769869790545531, 0.14242477182831081, 0.08466676502887692, 0.15740383948598588, 0.16343863494694233, 0.22977991295712336, 0.06467140332928725, 0.2288058895085539, 0.14359035928334507, 0.06734726045812879, 0.15279712953737803, 0.12282117589243821, 0.09642024684165205, 0.10238266975751945, 0.0971118708008102, 0.09949397654937846, 0.16125524496393545, 0.13373566951070512, 0.13064313759761198, 0.08986910658755473, 0.2040679140814713, 0.08529715798795223, 0.12732488422521523, 0.11137025962982859, 0.096908249227064, 0.20770967938005924, 0.13257219908492907, 0.10824724113834755, 0.11326747068337031, 0.11661435823355402, 0.22993565031460353, 0.12218317655580384, 0.09501602540590934, 0.07166580336966685, 0.1324992294290236, 0.14082072861492634, 0.14308122731745243, 0.14105276044990334, 0.10152931697666645, 0.05843770211296422, 0.21342977029936655, 0.15081715078226157, 0.09442523175052234, 0.11734051283981119, 0.19305216946772166, 0.09321750727083002, 0.11518886472497668, 0.11079052609524556, 0.12704920901783875, 0.1033862501915012, 0.13384993480784552, 0.08710540631519896, 0.117243210918137, 0.11092387858246054, 0.1247442119887897, 0.12323364375957421, 0.09515584433185202, 0.07027722216610398, 0.09345182576881987, 0.08925161257918392, 0.17371496638017042, 0.2184454333037138, 0.15585569398743765, 0.21186069878084318, 0.11729422318083899, 0.19109040259250573, 0.11329679018152611, 0.2246199526957103, 0.11305204260029963, 0.1059262238975082, 0.11305646664862122, 0.11909832565912179, 0.13908408608819756, 0.1482688310955252, 0.11286096035369805, 0.19359543174505234, 0.1593785120972565, 0.15138893867177622, 0.11384015423910958, 0.10149353782513312, 0.2754582390189171, 0.20289875753223896, 0.1591869480907917, 0.16766809299588203, 0.1756316649594477, 0.18905223267418997, 0.2071615859333958, 0.15842765383422375, 0.10474853816309146, 0.12051571745957647, 0.09864772803017072, 0.16145333647727966, 0.16679298638233117, 0.12365292411829744, 0.1732899049030883, 0.13243176947746957, 0.17932779448372976, 0.12219832145742007, 0.07156436238437891, 0.09460043627768755, 0.12677043969077723, 0.17433524238211767, 0.05571221693285874, 0.11046790983527899, 0.17020737459617002, 0.07765486557036638, 0.2086599405322756, 0.11494092802916255, 0.11683975399604865, 0.06904494828943696, 0.14259534196129867, 0.09150837255375725, 0.1333141771278211, 0.19193968416324683, 0.20100122078188828, 0.12597128828721388, 0.20763111859560013, 0.17552381860358374, 0.07369544410279819, 0.1261169154729162, 0.09657541422971658, 0.10102452763489314, 0.1940104237624577, 0.15473440129842075, 0.13484835837568554, 0.12229787611535617, 0.060333644306021075, 0.14022821826594217, 0.17272840360445635, 0.1872861145862511, 0.08508454582520894, 0.12694837871406758, 0.21521526734743798, 0.08416616903351885, 0.17112803805087293, 0.08300169437591519, 0.11306628505034105, 0.11054806517703192, 0.11444626242986747, 0.12745479653988565, 0.14405100313680513, 0.2872577730034079, 0.10664350326572146, 0.14851138022329124, 0.20664412155747414, 0.09813919996044465, 0.10441714844533376, 0.11141223380608217, 0.09989738597401551, 0.13951168528624944, 0.18089465397809232, 0.21268458957118647, 0.12798006406852178, 0.11204817718161003, 0.16902253031730652, 0.09397691009300095, 0.2051963856709855, 0.30792016855307985, 0.1268629782966205, 0.12058369309774467, 0.14590679641280854, 0.08649095892906189, 0.14266293761985643, 0.20110726223460265, 0.16427691067968095, 0.12986142454402788, 0.11944977965738092, 0.2236551573233945, 0.06464149350566523, 0.1496123168617487, 0.16039970730032238, 0.10783276480755635, 0.2401061574263232, 0.113363116979599], [0.0839020289214594, 0.021172231495646492, 0.08318785045828138, 0.04528059936793787, 0.020213760069704483, 0.03926076560414263, 0.021553697097780447, 0.030905790893094878, 0.05011264401088868, 0.02090080052481166, 0.03999052323134882, 0.01906458637677133, 0.017577809281647205, 0.04100994406534093, 0.08347415830940008, 0.03826272880126323, 0.014467045132602965, 0.031912363666508875, 0.05551448843574949, 0.04138333170807787, 0.03232705034315586, 0.028533968342734233, 0.07534854539803096, 0.02343265725565808, 0.03996623167768121, 0.049718998705169985, 0.03379031450354627, 0.03265448080907975, 0.034829847115491114, 0.01048305900102215, 0.03904749865510634, 0.052507197484374046, 0.03425742818840912, 0.025013752414711883, 0.017880756507760713, 0.016360312201348797, 0.07306641499911036, 0.038458095996507576, 0.02190839618976627, 0.027282860030287077, 0.03357395004214985, 0.0083772662827479, 0.06025562634957688, 0.04848391908620085, 0.03951425271640931, 0.020534244033374956, 0.02717953102130975, 0.02662890324635165, 0.054390600350286276, 0.02384626166895032, 0.041623397397675684, 0.01127468714756625, 0.025197133288851807, 0.004381252269792769, 0.013910632846610886, 0.017272945194106017, 0.0517897179483303, 0.022365844143288474, 0.031097483821213245, 0.02923102058204157, 0.1031373499759606, 0.03812499976317797, 0.06181606011731284, 0.03650710086471268, 0.026660975900345614, 0.03395065572112799, 0.044457376934587955, 0.038282396138778756, 0.08463905365871531, 0.06116938910314015, 0.025015810072155933, 0.06449939470205988, 0.060473218959357054, 0.02250109992123076, 0.003406289898391281, 0.04407242366245814, 0.03494247714323657, 0.05542299138115985, 0.03853787135865007, 0.029854210891893933, 0.024119997962511013, 0.08391496858426503, 0.0253136581076043, 0.05641782549875123, 0.04629063266994698, 0.060787285678088665, 0.030011081402855258, 0.05327518716720598, 0.07209959759243897, 0.05506498273462057, 0.046852751435445886, 0.039095515185700994, 0.07376361651612179, 0.04778022738173604, 0.07941119239798614, 0.033938774572951455, 0.04087193004254784, 0.03810265560501388, 0.0969210531828659, 0.03478758116917951, 0.037080825971705575, 0.029367850561227118, 0.027724155457690358, 0.014809052227064967, 0.08284487814775535, 0.030235384723969867, 0.04005299934319087, 0.024502876613821303, 0.05338879428537829, 0.031663222571036646, 0.02611628021778805, 0.04991732770577073, 0.022076379407995513, 0.034613306234989843, 0.044896945490368774, 0.013185384084603615, 0.09845287991421563, 0.01014197216967919, 0.05856283075575318, 0.08679741248488426, 0.02001224025817854, 0.06483262324971811, 0.08371644280850887, 0.06730360351502895, 0.03480447669114385, 0.031415604786681275, 0.035577935366226096, 0.06620163550334317, 0.009972178959287703, 0.04079305373930505, 0.06818982453218528, 0.010916033044590481, 0.04003015306911298, 0.041790215232010396, 0.020635839385379637, 0.02101864679051297, 0.032747151729251654, 0.04165975669664996, 0.02802266676111945, 0.016887990225638663, 0.0583204376910414, 0.037581849444125376, 0.05754211052720036, 0.07736897162560906, 0.019172614240752797, 0.04674674730215754, 0.06791331472673587, 0.034414763495858224, 0.03352502088195511, 0.02558115018265588, 0.024613092753237913, 0.025172941819099442, 0.010504700027273169, 0.040480998876903734, 0.06162009241857699, 0.05417046323418617, 0.03002619237772056, 0.03657020122877189, 0.0106865075483386, 0.03758041434256094, 0.01965581768724535, 0.05790710808443172, 0.017922503374783055, 0.02172965819149145, 0.04011344324265208, 0.03553562531513827, 0.027502946256260787, 0.048029348121157715, 0.07384238764643669, 0.031499787233769894, 0.022551275889522264, 0.015330769321216004, 0.02066332853532263, 0.06962920086724417, 0.02789348896060671, 0.025478428462520242, 0.04182169586420059, 0.02938448145453419, 0.010222869659108775, 0.03695821130116071, 0.011493892126184489, 0.01385709473730198, 0.025382581998461058, 0.045005283784121275, 0.04472623286502702, 0.04577305633574724, 0.02161067198695881, 0.06110235662864787, 0.032625965374921045, 0.054551331725503714, 0.02346144580016179, 0.042109231863703044, 0.06518039280282599, 0.03189059965578573, 0.05679208166631205, 0.06260198687336274, 0.035547883050250154, 0.02130462894482272, 0.06467723194509745, 0.04217346877391849, 0.035627169867179224, 0.05676670784928969, 0.030094592100275413, 0.03246446046978235, 0.03498704671593649, 0.033980487513222864, 0.03976112411224416, 0.006748994704269404, 0.017951103625819087, 0.01726278752487685, 0.007884127387244786, 0.06750193251562969, 0.033765310488109074, 0.009682144254579075, 0.0620992738487465, 0.023644292327974523, 0.015929610401924168, 0.031365691750709496, 0.03386888546603067, 0.031124146854771034, 0.03883171434115086, 0.018438084816027964, 0.037843926809728146, 0.043032999616116285, 0.04576868996290224, 0.0303778465438102, 0.033683916819947105, 0.015328854156125869, 0.011273486140583242, 0.03062794776633382, 0.047297727915325334, 0.06977404095232487, 0.03073677121262465, 0.0369217671853091, 0.015257613068180425, 0.05742042205695595, 0.04674487454550607, 0.0573740577591317, 0.057762865110167434, 0.006374050671833434, 0.021788543156747307, 0.009805222025274165, 0.05993823480925389, 0.045060587780816216, 0.023789944958740046, 0.04594454249101026, 0.019221173599362373, 0.07620803213545255, 0.013638862608266729, 0.03132534945117576, 0.06860297771969012, 0.018857119205806936, 0.09268464693533522, 0.02359800266900233, 0.04479761814166393, 0.08101048586624009, 0.04134214123977082, 0.08046208707881825, 0.06836442516318389, 0.03379138998155083, 0.04861709515431097, 0.035063697424318106, 0.041683118657342026, 0.010341688774393072, 0.008513096270949712, 0.024521600787660906, 0.03985718770750931, 0.03086108561339123, 0.015081022633239627, 0.040977086007062874, 0.05581072325419102, 0.010771790918494974, 0.15314170319054807, 0.01814809930510819, 0.06397612885172878, 0.05393616848492196, 0.0609594639390707, 0.02054464427887329, 0.024815028167462776, 0.015055458826412047, 0.03708612533020122, 0.02788520065535392, 0.025886523171461055, 0.03863002319953271, 0.03874756242813809, 0.022600985364988446, 0.07341803184577397, 0.03724352509847709, 0.025588922801294496, 0.065364940757198, 0.015235028030084712, 0.02930114378354379, 0.07941651211253234, 0.034165367949754, 0.03875772688271744, 0.05731267748134477, 0.02539585583976337, 0.055634263437241316, 0.014387190042595779, 0.02952252601140312, 0.018355535941996744, 0.05204469444496291, 0.06501031800040177, 0.057967300925936015, 0.01599344188746597, 0.05209953025249498, 0.04419076356238552, 0.05938920498426471, 0.04857784529615726, 0.027732163867247955, 0.015608190059927958, 0.022641593989517008, 0.021221082624314085, 0.012357253298562552, 0.033218309482825656, 0.04403292613902262, 0.03289242268406919, 0.06630486782108035, 0.02765961829572916, 0.014138922560960054, 0.028638506840382303, 0.0722775026889784, 0.032408342231065035, 0.00834509778568255, 0.0385319816746882, 0.02610815645727728, 0.0198054736746209, 0.03462104153420244, 0.06690123224897043, 0.030097099287169318, 0.07305295964969055, 0.025433355077568973, 0.0803112555295229, 0.05256540900362389, 0.020723767345771194, 0.04247772726895554, 0.005388398829381913, 0.06801394147000142, 0.03938261692279151, 0.09244872709470135, 0.03938545998451965, 0.009142669050821235, 0.002092023758450523, 0.03397486924326845, 0.010512151189946702, 0.01522927066045148, 0.06117673763739211, 0.013681289706645268, 0.020002538903749416, 0.03631187616182225, 0.012064766537930285, 0.011343374399335256, 0.15555994771420956, 0.1376470981964043, 0.22602186032703944, 0.17904052989823477, 0.09745013407830681, 0.1386430247553757, 0.14255399203726224, 0.12886240386537143, 0.10802061722746917, 0.09613515356821672, 0.06508211379072495, 0.14223088723208221, 0.08493675411279712, 0.11970925144851208, 0.21140944585204124, 0.17008936378572667, 0.099567204048591, 0.07209494284221105, 0.13610147684812546, 0.1846160657171692, 0.10364344889031989, 0.06200526960726295, 0.13336288237145968, 0.11111067248774426, 0.09573722670653037, 0.1875962322311742, 0.12805908625679358, 0.16501408469464096, 0.17809592772807392, 0.12567227147519588, 0.17253648675978184, 0.1505046175526721, 0.12128095568290778, 0.15653424257678644, 0.04705858503335288, 0.14433688351086207, 0.16623259788112982, 0.11541812813707761, 0.1327285606946264, 0.07951546287430183, 0.05716399010270834, 0.09029764216393232, 0.11493678896554879, 0.08322743619126932, 0.07093020355595009, 0.16040909822498048, 0.09152272356940166, 0.16769443372530596, 0.19375191549105303, 0.12118133317146983, 0.08784913497843913, 0.09183025599590369, 0.08212723915598222, 0.10538214059280497, 0.13917723537555762, 0.15824392012187413, 0.15592651947268418, 0.09129561789866004, 0.11407000119132654, 0.10001585818827152, 0.20345831822071755, 0.16166710214955465, 0.12494754179247788, 0.14527292256908758, 0.08136533253959247, 0.11072082019277982, 0.09511285235307046, 0.13559865525790624, 0.13972329321716512, 0.20236898453107902, 0.16125995399696486, 0.15215086564421654, 0.1381305136850902, 0.08352556412241288, 0.1669750508985349, 0.08177786826023034, 0.16213561700923101, 0.16346298078341143, 0.12958859918372972, 0.1840684065329177, 0.13279481285384723, 0.20102092543882982, 0.0983270388096571, 0.16824130580893584, 0.13933703037244932, 0.11825055043612208, 0.08122209379715578, 0.11456021560089928, 0.12183683871158532, 0.14046565123966762, 0.18410428746470384, 0.14367745603833879, 0.21854350875530923, 0.10254182693149362, 0.15403521167380468, 0.10655260671462331, 0.1964288175638233, 0.08260123657860927, 0.11667689202087266, 0.12709634006023407, 0.12578604822712286, 0.17508635350636073, 0.12186307087540627, 0.12303952846143927, 0.15897285672170774, 0.1037698599642941, 0.1308324352971145, 0.12931392820818083, 0.12225301137992314, 0.15614655480853148, 0.07352141344121524, 0.14547322610659258, 0.08908330196780817, 0.28679631490792545, 0.12719398124941758, 0.13743525956358227, 0.1348030593778406, 0.12353765458932944, 0.17852032424083777, 0.21355813555419445, 0.0932250457948872, 0.25644015095063616, 0.23985927924513817, 0.13326921739748546, 0.2182812142585005, 0.16828076940562042, 0.14998960947351797, 0.13921109427298817, 0.12371441296168736, 0.11522672697901726, 0.08848157711327076, 0.10035862693829195, 0.10245344095996448, 0.11515690572559834, 0.12707054215882504, 0.08364128148449318, 0.08526834060571023, 0.10983938963285514, 0.10153734404593706, 0.08794342420463051, 0.09582266105072838, 0.1988920761006219, 0.1159911509603262, 0.1640839624617781, 0.10808340207274471, 0.15447883786899702, 0.16223437099584512, 0.1173921629254307, 0.10857588278927974, 0.24458877689072064, 0.07632132034216609, 0.10520101924027715, 0.1422093098184892, 0.1186983021242278, 0.14426741509565286, 0.13611724600195885, 0.16339439446372644, 0.1065163661592773, 0.0641463597172073, 0.18545884692243167, 0.09525763136999947, 0.18400975396590574, 0.10101892972098929, 0.2261193250971181, 0.14342656092984335, 0.11090879474899598, 0.11383017977433545, 0.17215380657996449, 0.10009085666388273, 0.06813416430460555, 0.18968742287584714, 0.15862888017935411, 0.11125531579766955, 0.17283565284950392, 0.1300818941422871, 0.051494073455355], [0.04391870155398335, 0.08202090593320982, 0.04906754741179092, 0.057744666800967286, 0.014631771382742693, 0.014658422541937657, 0.038245595792042356, 0.017033776867070367, 0.13653238729706832, 0.02902597069208111, 0.023965570177616816, 0.03628269237067018, 0.035572466373975785, 0.05298923893964716, 0.04473730994920645, 0.05439617112278938, 0.054177581066531796, 0.026718990644440055, 0.05350263210545693, 0.003930009094931717, 0.03345945404310312, 0.013179313740693033, 0.049596702946083884, 0.06530604391757931, 0.029098068430487598, 0.06889102940580674, 0.0698202627577952, 0.05050969895507608, 0.0335330106317997, 0.05407248956284352, 0.10367527896804468, 0.017591378285682628, 0.0238959965894797, 0.07490761977221284, 0.008207264422838177, 0.008564648817160299, 0.03209101175889373, 0.05037981717448149, 0.021171904102499996, 0.00465693765519453, 0.025938431100387658, 0.049179539616618834, 0.024752555448295813, 0.017465445578896573, 0.01248001046146133, 0.0882548378514392, 0.035493763097162755, 0.011171777133962937, 0.05940642620303801, 0.028899322130850384, 0.008911086745294077, 0.00925098274767931, 0.06912756671330758, 0.027916128281503916, 0.017090115629668747, 0.08709135385496275, 0.08147387778652565, 0.03255944519436785, 0.036441808832543235, 0.05892858827220542, 0.038933080687586746, 0.06847504672727414, 0.061469586566090584, 0.05550702455054436, 0.010980773767057275, 0.043060069770685265, 0.03637873221720968, 0.03471397029768143, 0.06915763938533408, 0.07215665560215712, 0.03864974821252482, 0.06634568170245204, 0.035725906890417845, 0.04333500198221632, 0.0179188664270831, 0.046066692365067344, 0.024517410833920752, 0.030971870025885955, 0.032892605888524225, 0.028528533277234862, 0.0243950404359826, 0.05658506402479751, 0.0335588119258838, 0.013569873408414423, 0.056310674641281366, 0.012298463328209306, 0.06417164871735231, 0.03138720809615084, 0.02548947331628629, 0.012715378992392548, 0.028779598019484962, 0.005800959995082978, 0.022053796066237346, 0.02946001597281013, 0.04398672129692776, 0.07656960309083972, 0.019861798866518905, 0.06678811367601156, 0.04584917439413922, 0.035356675274670124, 0.060207314656249115, 0.04510511664141502, 0.024687757050352435, 0.012718067687403942, 0.01192283143089818, 0.045457764861306975, 0.03976179586191263, 0.03291203573878322, 0.03517636137881449, 0.02289232624960797, 0.0643656961619854, 0.03545042167284659, 0.026536184828728437, 0.005609555020263153, 0.012392815318889916, 0.016018686782834784, 0.06512625249368803, 0.03273105348593422, 0.0652084027283958, 0.02434382970178766, 0.030402558789189373, 0.02371121114785118, 0.025555515129651343, 0.022544862037258487, 0.027584977747340287, 0.03563612313675029, 0.024190948976735984, 0.03322241122701338, 0.03734790414039578, 0.014146019189086343, 0.026132870398994004, 0.05210237331422312, 0.031244220411671058, 0.05668204364233783, 0.07482795297567334, 0.04843583470210433, 0.04238020482340029, 0.017075805326125452, 0.012562457555239754, 0.049662483523466756, 0.09117291841123785, 0.0695062910339662, 0.034735025239310095, 0.03279763812731419, 0.01973933686635324, 0.06946363153734378, 0.021771198105333105, 0.06862777138927154, 0.016261831325079714, 0.06561053650719778, 0.01980102927024875, 0.023568399882476245, 0.018301064847037196, 0.046433983370661736, 0.056689551632319174, 0.09240483266434499, 0.031611508024590354, 0.07119455401386533, 0.05400630186444946, 0.03645704533638699, 0.03153102020067828, 0.04634905453505261, 0.01658387591929308, 0.0642361231148243, 0.05520795006304979, 0.01931061638918306, 0.05739457665809563, 0.03697406866454652, 0.005127111957075873, 0.06252162118575402, 0.023957315799114958, 0.06051534241331475, 0.05462596718487995, 0.05143667957080262, 0.04268891790083476, 0.020117452201832618, 0.029557368784610714, 0.025051277097580687, 0.04608509762744818, 0.04096869931423238, 0.053441933755363734, 0.038733296229371, 0.037842223686831336, 0.016010905682508434, 0.015943282882549932, 0.04628170654177666, 0.025607560461919223, 0.025158473756164312, 0.08901967573910952, 0.024514235290033475, 0.009050045628100634, 0.009673901750440044, 0.034912784450820515, 0.03632180652182017, 0.04651414889043995, 0.028838871446038996, 0.022414876780073558, 0.02600625406817666, 0.05005434088941131, 0.06715444116187946, 0.005671124863770923, 0.01328018560473408, 0.031129374967089722, 0.04653063389871802, 0.009025939823394375, 0.04572712630033493, 0.01658532289522035, 0.02791657781095377, 0.013411390528615032, 0.06631335629416363, 0.01668275543488562, 0.07899039890617132, 0.06728256214410067, 0.04288615106738039, 0.050851975767208, 0.06490207130887679, 0.011764396048550094, 0.07194212318531104, 0.02282443203564201, 0.03593455980132733, 0.027280371503106186, 0.024649116177377955, 0.017813668054129397, 0.05201441142708063, 0.01571656228043139, 0.027022367043952857, 0.032310897817036936, 0.03214814440746393, 0.019767640258318613, 0.0237994071295751, 0.0439962377505643, 0.06109899788030556, 0.066257445008627, 0.06339725027126925, 0.033107406326702664, 0.10187430453619786, 0.007924758064161454, 0.1231239517884595, 0.05602437696818795, 0.025007788091897964, 0.047289032489061356, 0.047470625423427136, 0.009377802639002246, 0.044639471984867535, 0.039530147399221144, 0.08117745297827891, 0.022836457372510006, 0.07846082268016678, 0.0115086087025702, 0.04175493819639087, 0.03353181301749178, 0.034231155312487056, 0.012933113246357866, 0.027184910107670084, 0.009647779848559626, 0.04067462562982525, 0.04819502940933619, 0.04271844435217125, 0.021001830996413316, 0.02280604373663664, 0.043470267938183885, 0.03182676986658147, 0.045066755664135726, 0.035584015039993186, 0.034520465681063275, 0.03090416919440031, 0.04541245229276163, 0.01503042597323656, 0.03471660301355379, 0.03247725764023406, 0.027958711442936744, 0.038421824907085726, 0.03270945232361555, 0.052522732543626, 0.07163956442049571, 0.04590717896020838, 0.03459752011778099, 0.028991348442754576, 0.041518767297800095, 0.06573519017547369, 0.03093702725267836, 0.010588632264573659, 0.011882949687008346, 0.00938943781823452, 0.012872223210121905, 0.026997798987265145, 0.02484305844908314, 0.04849078246791448, 0.0069896502952490535, 0.05245517420449427, 0.02601901052652725, 0.01753003871999681, 0.057790868250387054, 0.017102454788982868, 0.031398621055164506, 0.03876255465937512, 0.041253215832901854, 0.045473852926599126, 0.020664463385141323, 0.035593982719417126, 0.03114070650190115, 0.04238803851019059, 0.03655992142323937, 0.04052822830687676, 0.05495468347466417, 0.026012128485100608, 0.026182364439591765, 0.006608560007797288, 0.03277537878602743, 0.038587940457676134, 0.030689531604626348, 0.031627769116312265, 0.024268049214567457, 0.02937315670507295, 0.030380692998213426, 0.027724221614854674, 0.09124623412000281, 0.03163913797054972, 0.035778510317738564, 0.07854574812310082, 0.05494360978315983, 0.030645650744970356, 0.048605146152632575, 0.024870757944881916, 0.03809163619631103, 0.021405158996848122, 0.01951152891186731, 0.07236860958593232, 0.01697028973805053, 0.048170961772224734, 0.04414628559191312, 0.025141664747414843, 0.046516242170972485, 0.10079966791506324, 0.02092730070996497, 0.034605136673365317, 0.0063184807742280615, 0.06854100033108677, 0.022168373489486318, 0.07252631469496659, 0.028692569117993116, 0.025269159781081334, 0.013331336118946118, 0.013001340790651739, 0.03335694097248571, 0.024293351785412858, 0.025772264659670845, 0.07633129480694022, 0.026849533996677825, 0.04004242776760033, 0.04564879621778216, 0.04318051312917045, 0.0861945001940642, 0.10788563625620944, 0.11042684489595038, 0.22058182795132908, 0.22188576869666576, 0.10206818234707628, 0.10418900461601359, 0.10073052519666297, 0.16852847539952823, 0.11829069256782532, 0.17197981663048267, 0.10572957087840353, 0.12815959086375578, 0.1043112969824246, 0.08227079002452747, 0.14676795234637602, 0.07816500855343682, 0.1570643141333546, 0.2336712298648698, 0.10433062844510589, 0.07368515072656528, 0.1155093503849847, 0.19701348404799188, 0.11901475728622504, 0.09196987814669098, 0.09780732169747353, 0.14459931371467455, 0.09785702438758952, 0.13312839423971518, 0.18976772070995399, 0.17923897424978869, 0.16845691709646157, 0.1414237833981003, 0.15633347763546876, 0.1280582041612693, 0.08256956256393876, 0.18564491479524545, 0.107485341307308, 0.0743065055991922, 0.09708264629755702, 0.0960776341546859, 0.11978984783802714, 0.10565308641110148, 0.08121433135654245, 0.08036925670291696, 0.15965246382568563, 0.11950738728046417, 0.09517849383077451, 0.16594048855560167, 0.072927227110735, 0.11865476731743131, 0.15005987856004918, 0.16598400979169778, 0.10159155220857688, 0.1523755964423929, 0.17250641408775533, 0.22755427738385542, 0.19344456626900605, 0.13793192005583219, 0.17176469388817037, 0.07179709989577532, 0.1497559898665973, 0.11137258700494256, 0.11224035865494184, 0.09473166495029416, 0.10086620505899191, 0.11316607041018349, 0.09307842794805765, 0.20587767554180963, 0.17156197476599896, 0.1208665200642177, 0.2348344831594399, 0.11661965080669948, 0.14995674123721464, 0.09333068012659039, 0.0668257927255971, 0.11275601812771388, 0.14174672535487584, 0.11449374631047249, 0.12859146483242512, 0.16479703491287573, 0.15231678102697643, 0.093364213327212, 0.1295601414250476, 0.08275304521833148, 0.12460357882082462, 0.14908662864140101, 0.09818382042327098, 0.09928570022540432, 0.11830116914851324, 0.09999898302235774, 0.06408598367124796, 0.11928569631917135, 0.09154666907020978, 0.14470781146415643, 0.169693900006158, 0.12675310990640096, 0.18228957269872936, 0.12808071795318807, 0.18317598370569094, 0.18113822090838635, 0.14062664045819215, 0.12175922787615232, 0.12593083402940206, 0.10131445886301142, 0.09480840726090328, 0.08536455687135458, 0.0830228239563959, 0.11207954585552216, 0.0627588438136237, 0.1798844374716282, 0.08257635469947543, 0.21084715745278768, 0.09488481708935328, 0.10229108110070229, 0.20312256552278996, 0.13489067181944847, 0.06609124464115926, 0.15092245941715582, 0.10509553418627807, 0.11832837840276104, 0.10232602565416268, 0.1459966344492776, 0.06857350894383021, 0.13810056314936706, 0.1649950042899166, 0.15644493379763194, 0.1121933293927993, 0.14093667667891296, 0.13384294589715345, 0.078443547178592, 0.10670807265809604, 0.15292896889150143, 0.16273576766252518, 0.10014515982142516, 0.144946886492627, 0.1441187887851681, 0.07619872942034688, 0.09203798270651273, 0.1346117803560836, 0.2153524671282087, 0.1606778795165675, 0.10463440857295479, 0.17733026881303104, 0.12817801987486227, 0.14865745524210588, 0.1431831025651523, 0.23658171083245957, 0.11660720647445746, 0.12313516118696757, 0.09193880124283688, 0.10358633659780025, 0.058380929087953906, 0.09536524702395711, 0.12736128084361553, 0.15625289481665405, 0.05325155718518155, 0.2902986141187804, 0.1286555321088859, 0.15596377104520798, 0.13914554779018673, 0.09563550752188478, 0.09418614993670157, 0.09445434090282236, 0.1276231546487127, 0.0785848181694746, 0.10283304059079715, 0.15469267139477388, 0.06411405466496944, 0.205013384776456, 0.11581425688096456, 0.14289946135665688, 0.21889371424913406, 0.1509534413261073, 0.07174896462155239, 0.1318039617368153], [0.06332464702427387, 0.07206968098346676, 0.03745042399636336, 0.08389598317444324, 0.008020420475596828, 0.01041470592774983, 0.01749713146792991, 0.04357994633859821, 0.0341200825226094, 0.02598836618874754, 0.020223578471424322, 0.04259592806920409, 0.032410998695663044, 0.023817517229222825, 0.014750185921522123, 0.050978770213467736, 0.05152740988082119, 0.04105411330237985, 0.023634786052363257, 0.04584156123122998, 0.0412397367347564, 0.044210753204034905, 0.019093558125730072, 0.015969342019941126, 0.06592442002147436, 0.026675751000376682, 0.03873581359429019, 0.03697896768738117, 0.050964134213115485, 0.02714244060085288, 0.02761966615383114, 0.0524305094565664, 0.054410708735563924, 0.03399107265951378, 0.04280749189534357, 0.019075614267161915, 0.11758063281221048, 0.030381493669535433, 0.048621797401990206, 0.09224825392344169, 0.011960963402608675, 0.1003793358270611, 0.01637213906672384, 0.03394958363579852, 0.022878786083310843, 0.044819796058748446, 0.025973850628361106, 0.014590957501370991, 0.04818837298080325, 0.07109629535781485, 0.053817638595189364, 0.004191900711573128, 0.0019271821573576225, 0.020216608220445256, 0.02627097093500197, 0.05744186376354524, 0.060215918480285575, 0.068739492180092, 0.02466909564100206, 0.004955095696329538, 0.11459909565746784, 0.0333816464325147, 0.053718508021639924, 0.036756588013044426, 0.03234985251245754, 0.01799683179706335, 0.04111031975064959, 0.03002098122877734, 0.06782190248902355, 0.050380960505987914, 0.08481890615075827, 0.04421015948589359, 0.012594816042110324, 0.04695705244583743, 0.04643413604104093, 0.0616687840915152, 0.01742579199240676, 0.0843518433560218, 0.046969313573624404, 0.021350786289466277, 0.016984633968344758, 0.04466748530311244, 0.05803892708250454, 0.043909578650657616, 0.04908216644876769, 0.082041105920715, 0.03131902889747705, 0.06136344333312341, 0.010577154844733221, 0.012836846938755895, 0.03439722675830126, 0.0963609835931233, 0.08339928875544242, 0.04385209655655282, 0.05328575195744634, 0.05640301647196923, 0.07839271133499486, 0.053770127573183606, 0.022801098912688236, 0.04801062394731811, 0.08605427414711032, 0.015361766497205411, 0.05580780555361083, 0.05252937540145857, 0.047327342576214244, 0.025995865697041154, 0.038750754935400825, 0.06024126176323209, 0.006676741326893014, 0.01581258516359542, 0.06204106232949665, 0.042177448381802866, 0.03268192755058408, 0.015006792598537036, 0.030830252982143844, 0.026458823354914784, 0.04799541458487511, 0.018061932143090025, 0.01049263313013528, 0.05644031214926924, 0.02893619372376374, 0.019715784915855954, 0.01443315061208393, 0.038252367571528466, 0.02154550209109272, 0.028005184306363975, 0.08485810511878558, 0.04531639548284667, 0.022620625561103225, 0.06092442439070769, 0.058743633196822236, 0.03365979829270925, 0.019444793296445693, 0.01725179865024984, 0.03706150807972465, 0.032049604159380705, 0.049570416499461444, 0.049619603502963266, 0.018424415728077292, 0.008598885997863752, 0.046632916267429075, 0.058783612480121, 0.0444673446140119, 0.011210773389653435, 0.018203223490023186, 0.03838504830907498, 0.04204773623496294, 0.008993951138108969, 0.02868372102134994, 0.025792023599413887, 0.03392715805343219, 0.006221405313616353, 0.0106548174184614, 0.09415059470172439, 0.02371951811281698, 0.013388906422603344, 0.019223049748688936, 0.02965624151485307, 0.06894597717161689, 0.0099993407160842, 0.0551240559933441, 0.02620678491491292, 0.05303127757672753, 0.03931188303977251, 0.04336244533104556, 0.03603498637676239, 0.03550310991704464, 0.04607164227802839, 0.05519825379763331, 0.05877697640763862, 0.06973341706075839, 0.014602546879489506, 0.018715602245980074, 0.029503153836620704, 0.013084917645236211, 0.029564588397209133, 0.019964208460545967, 0.018247555575466583, 0.08195785645927701, 0.038020339129226546, 0.023808720022706047, 0.013869920745491982, 0.06290554987000567, 0.026944598449128013, 0.006104976337935243, 0.06638283149472304, 0.020878541183524897, 0.050723518910152574, 0.09053119391735111, 0.07322536861257893, 0.003994235403037497, 0.045420421686555655, 0.001354106535602893, 0.012681751645037105, 0.022665395301633647, 0.02123152358191354, 0.05691331212541886, 0.06115738581866026, 0.015386265004053712, 0.021974124180685197, 0.01902019152683871, 0.05428593632365976, 0.07398006240172045, 0.02295722982047924, 0.025254152282806377, 0.05309828290981906, 0.1086204828960555, 0.0339607387515051, 0.02424535052185612, 0.020741086952122192, 0.05916735117456742, 0.03622973271246467, 0.04721966585410493, 0.018457036299098815, 0.06765798199921846, 0.06500300339290074, 0.05232888865949852, 0.05096062957974417, 0.0352702366986445, 0.03978709504008293, 0.019021450209298303, 0.0043363938956255356, 0.023642278775306683, 0.039479491367403946, 0.058700973700199804, 0.04981148302821176, 0.09118593271289553, 0.01824796269647777, 0.03522470699889319, 0.004377284112186837, 0.07570894927318607, 0.054359750755663426, 0.06378368274973971, 0.022559825430757234, 0.03812814138031431, 0.025264993576066833, 0.046942243419055424, 0.08682283040668283, 0.03891393242936049, 0.04962249406214271, 0.05018291988277009, 0.07826043093310935, 0.054223093802907636, 0.02909230427550418, 0.0766392954226051, 0.02662807373729135, 0.031044513984982456, 0.03499299068269985, 0.054331557625638585, 0.0017406735548450211, 0.0982377775279539, 0.024557902411158596, 0.025240992096119692, 0.018159909207107763, 0.043518983359847746, 0.011794232081488838, 0.01238314958754927, 0.10544373121644769, 0.04456008678036077, 0.061306887439319065, 0.02242254761845938, 0.024231737413044487, 0.0370132404911731, 0.01956779133927609, 0.016055110542635833, 0.02187516663356551, 0.03144805572394814, 0.12185300141572952, 0.028442293172702193, 0.019412211741187742, 0.011652196890541484, 0.024915268145767704, 0.039790134876966476, 0.03901936998590827, 0.027731470065191388, 0.035803918061511855, 0.09275337574737412, 0.03441741656778114, 0.054651079765920124, 0.07732285838574171, 0.020944394703422273, 0.06253188742058617, 0.041924965501363785, 0.09104876685887575, 0.042913248363350115, 0.05159272566171629, 0.051375814979629855, 0.020908744473542486, 0.048293888568878174, 0.03280372119375637, 0.015352372179872223, 0.019155511765607765, 0.04307931980916432, 0.026993727777153254, 0.018217033373990228, 0.04826169886759349, 0.01630017364264599, 0.038144144628729136, 0.03244432494310396, 0.006214728104948465, 0.05608523477401052, 0.07869161958140986, 0.03660919324361852, 0.008450523467867501, 0.04933546357122915, 0.014217743733232575, 0.06677022749291998, 0.03829124423542193, 0.039260446692683866, 0.01709755915882332, 0.023667908739298582, 0.026744418744263903, 0.0423674483650497, 0.043973394869161506, 0.0592671161783593, 0.025637687416747212, 0.03309388990913119, 0.05856711231172085, 0.021336521787036742, 0.03968011720904282, 0.03689904644020966, 0.10283444515828576, 0.03184699360281229, 0.010340410584051694, 0.026717960967549255, 0.04057027372930731, 0.04204405518248677, 0.13459310707237038, 0.012687580260847296, 0.009423860747899328, 0.037890128259147914, 0.01710875329029347, 0.057485357858240604, 0.034838773243661435, 0.03971287009439298, 0.08992275835147925, 0.03572444464745266, 0.02608312530043934, 0.048752578241484504, 0.04794569832405873, 0.0059908162137227395, 0.006383092575041311, 0.06204936759812491, 0.012405627756379545, 0.06108027031379087, 0.04659476563600557, 0.020699884609452317, 0.025450413447937796, 0.05116588981556041, 0.0038286923663690686, 0.02261981471175594, 0.06678570487669536, 0.13421578731920036, 0.18327297350125654, 0.12981786259583064, 0.15689857516969952, 0.07431044110230037, 0.09717464207538537, 0.10701652110687324, 0.07761228749794619, 0.1019770008112703, 0.12121219294411795, 0.15003553272358008, 0.158107833138534, 0.16545863369745867, 0.18380094159926685, 0.07385819072702102, 0.09390894124018294, 0.1111269166160907, 0.08463781193963119, 0.0805975158831903, 0.08408400522811071, 0.08340313604899816, 0.18697333708405495, 0.08165039867162704, 0.13045259139367513, 0.16208343766629696, 0.11475176603666373, 0.208966285522495, 0.15690823750836508, 0.08722615162176744, 0.09761752188205719, 0.19661899735885008, 0.1541850050645215, 0.1353802484061037, 0.09828822660659041, 0.1995595238570656, 0.16404011552887304, 0.24546009727886745, 0.08283203347985234, 0.15979772460247788, 0.20292059278913907, 0.11502613845680441, 0.29296805230634554, 0.13219410580183777, 0.11502319361482348, 0.10101629700511694, 0.06836976523378066, 0.12420951282339436, 0.1441141611763409, 0.1448212760899748, 0.15709539103720868, 0.21982808411121368, 0.12744168724332536, 0.13105412625840732, 0.13262074148016317, 0.19149290956556797, 0.10848368345094578, 0.172999681904912, 0.11178689370197908, 0.13035699938024792, 0.24506258432354244, 0.19666923609163078, 0.1707425487360784, 0.1193467237587486, 0.09263704091842685, 0.18105712240295752, 0.16902061684855393, 0.16589315395270074, 0.06414018504853759, 0.2037072591483593, 0.09937640000134706, 0.160036528216941, 0.13678785573158944, 0.1535038644714015, 0.1551579428570611, 0.24507015677435057, 0.21052289913807595, 0.08835958330226795, 0.20679653409336293, 0.08622782983418022, 0.10442682435469967, 0.1065071312976735, 0.1723981470401798, 0.10081097909382411, 0.17124428467026778, 0.1844718363136053, 0.1951477705900158, 0.1334256332899843, 0.16516089253127575, 0.08831487462988921, 0.07387271816177027, 0.1163977427142007, 0.20992905886045524, 0.16630498399691923, 0.08898538936461721, 0.08207812679133245, 0.14705529835607323, 0.16899313618029865, 0.1482035017439297, 0.10652435930179698, 0.32259712527905193, 0.14942075285528386, 0.0754013897052833, 0.13889434055558272, 0.09999296441674232, 0.1632684583642653, 0.15560642736298697, 0.11465640472514288, 0.220961400440761, 0.10808703223509447, 0.09179995940732104, 0.14117328183991568, 0.15051980316638947, 0.205752485830869, 0.10607725222195898, 0.07389224639960698, 0.14482928280319485, 0.13921127069209302, 0.12830182537436485, 0.08150743134319782, 0.26236989562000546, 0.11127069140119211, 0.1900427309530122, 0.08034083965633597, 0.1700424091624362, 0.13608671192611965, 0.18416849044816835, 0.14102536120585032, 0.12077638347234045, 0.12238626208688531, 0.18663180326776846, 0.1537400217992919, 0.08242669023041214, 0.11605592391320638, 0.09542001837066241, 0.09556553699076176, 0.14659553659813745, 0.09806975190128599, 0.12194407438593251, 0.116876734154565, 0.09065749642572232, 0.23419104197195598, 0.14569558203220367, 0.22708887021456445, 0.13941777603966848, 0.1054916697155152, 0.1522193569689989, 0.138631136821849, 0.14304883405566216, 0.1330480556935072, 0.07409104358937059, 0.1943463257380894, 0.20138428094131605, 0.1297584907816989, 0.13211102597415447, 0.13624577410519123, 0.06271904773477997, 0.08463797478803567, 0.08534383441188506, 0.19674559842262948, 0.1435585767030716, 0.14004033191927842, 0.21968324402613298, 0.20226866991392203, 0.19733574746974877, 0.1512694622256926, 0.0853987821776952, 0.1364291278379304, 0.07811264600604773, 0.11477400841457502, 0.10272411536425352, 0.146915859409741, 0.1817851226244654, 0.08295253451381411, 0.061063164445970736, 0.09134061155574662, 0.12944322984133447], [0.03508177020453981, 0.012205671968071588, 0.020535175322688053, 0.013195045575100397, 0.0501040469722024, 0.06218894225146089, 0.043749091548046896, 0.04850860758285437, 0.0749781738434519, 0.028071863942646554, 0.03052780617560659, 0.02685633291756468, 0.08214931190013885, 0.009846481195251857, 0.029300638274954896, 0.022153120022267103, 0.05294753617740103, 0.04784111911430955, 0.027642958564683795, 0.020435710570641925, 0.027670200049344982, 0.037233998466815264, 0.010381357627920806, 0.04089967194678528, 0.01463267213797995, 0.037210952024906874, 0.053407179191708565, 0.04428750229999423, 0.04244042480630534, 0.008529804347615157, 0.028440320332135473, 0.03385205779756818, 0.030385822722954408, 0.006528826205924685, 0.08981818253440516, 0.06047614344528743, 0.09398423148585217, 0.014229063393681176, 0.021155378382120813, 0.02402233302460185, 0.010590510110237768, 0.06212977399783475, 0.0243228002052222, 0.04779040201434067, 0.034057077153452804, 0.03425133155126657, 0.018821309520197765, 0.012472974053317947, 0.03331647314397352, 0.04159368095653398, 0.05396510461079223, 0.07685426210186311, 0.032039802721036334, 0.015833769026877623, 0.0052544780690888205, 0.09420102342431035, 0.031829341514302154, 0.008866596052290072, 0.019248126706640636, 0.03829577345667141, 0.008170886464150888, 0.04657837901530521, 0.03504832521347063, 0.07143341191112995, 0.003785233894762184, 0.014881075326619404, 0.04111830610781908, 0.018606400516416346, 0.08370925712266139, 0.057051170085157664, 0.04919864037739379, 0.05286303821152874, 0.07395184213029486, 0.05637662145974381, 0.008670848877435284, 0.029359233166490282, 0.05102918536535331, 0.0441393170372716, 0.03695725117410932, 0.029799327586910555, 0.06007045414298773, 0.02129090896674565, 0.03447125832151089, 0.03459371014365128, 0.030752584471234252, 0.05844811762550047, 0.010987270739860833, 0.07291595664407526, 0.05636478102366839, 0.03631027481917824, 0.015763238704364215, 0.03189307970127889, 0.06447848903813533, 0.05099686674241509, 0.019673043995031288, 0.007693441235460341, 0.05587008149762239, 0.06965575872787408, 0.02798382911298956, 0.043787343959723196, 0.04504351583974702, 0.02929147465952805, 0.012095257357162024, 0.0511987784079143, 0.038455907721072435, 0.0027856652990781833, 0.041494876079793484, 0.043287087231874466, 0.007559578998812607, 0.022911125062299625, 0.022927552395101105, 0.03986304346472025, 0.0566910952994866, 0.02051312632725707, 0.00866589811630547, 0.03999892010220459, 0.047460728990180154, 0.0589299521275929, 0.07191150089991943, 0.05043062248400279, 0.0223024757578969, 0.009148854745684989, 0.0720474725323064, 0.048013819847255945, 0.06350369205964462, 0.034742770716547966, 0.01922052729475711, 0.04010661378768938, 0.03186914777117116, 0.035647295215832334, 0.022997957188636065, 0.035202922632119486, 0.04059290965752942, 0.04689721244254282, 0.004908515539552484, 0.03404601024729865, 0.11043886853648083, 0.04494945053011179, 0.01262008723071111, 0.060819611086377075, 0.015907629259995053, 0.015232207020744681, 0.06702587234654597, 0.022551565963242735, 0.010100529795246465, 0.0317791638496731, 0.025756368280521462, 0.04945857696501272, 0.006068713730201125, 0.024785630637779832, 0.0113645506290985, 0.028454086111326302, 0.038435996110950194, 0.037532350314514976, 0.0404914109967649, 0.0363988032830613, 0.02758450955817742, 0.030839691404253244, 0.03483221859538129, 0.043003398525927744, 0.0663488165342382, 0.07096092762159449, 0.0624235864462597, 0.01844386593438685, 0.024997301333184754, 0.030081855997975384, 0.045318163066570244, 0.033333769001598866, 0.023106461723468134, 0.02703745596643005, 0.04134889266320637, 0.012455064121500721, 0.057215803036732335, 0.04090900858864188, 0.009382009556117867, 0.06988516463232891, 0.018896720205832804, 0.11606471772704806, 0.056474232114851475, 0.03968775412067771, 0.050055453686841896, 0.01846268679946661, 0.05015381412314517, 0.05295971588098577, 0.02632242763814117, 0.0208465109379696, 0.01223907115802701, 0.012522112711199691, 0.019092957622238567, 0.01692480414307543, 0.026557333068922162, 0.03098525752180389, 0.05607707539041128, 0.030422049707600048, 0.030251686527792896, 0.03378599902082767, 0.0061295931643274215, 0.01555029405946178, 0.027079954310985546, 0.0059137253057477725, 0.01040688411532236, 0.019736229175967828, 0.02984505406181727, 0.05364975546087537, 0.04755098093301058, 0.044345897023699114, 0.048475878446229866, 0.06547316709267241, 0.034156618240688524, 0.0319943849795631, 0.0418039725295135, 0.01025241901100214, 0.058727687623883994, 0.018747350899502635, 0.05564811233697193, 0.012502923740872314, 0.02360056753137282, 0.015707195104498948, 0.022826387912833264, 0.0696992256811687, 0.012275796017742582, 0.013192097340444369, 0.02342048773009862, 0.012195160612463951, 0.022144972513030683, 0.04767544800415635, 0.023049871902912855, 0.027815968031063676, 0.035364946616547446, 0.015469412685238888, 0.020319173877526606, 0.039242859065000496, 0.03745164875207203, 0.040222924867911, 0.014440936801422919, 0.05036338305632983, 0.05463864900437849, 0.050226420762815645, 0.037072853185236454, 0.017762343665318828, 0.021516377671754787, 0.03904400080708521, 0.020753556729427407, 0.0410564440701689, 0.00937182389731918, 0.08595043793320656, 0.11323038195925099, 0.06545619014650583, 0.02511712722480297, 0.05675607859822256, 0.02821104334933417, 0.051659215308193646, 0.008327797687213336, 0.02516100978079651, 0.018364289043737308, 0.003673246778946902, 0.02674867146249328, 0.015810651338792274, 0.012458930074769472, 0.07418011488126856, 0.05893054923840931, 0.04304526413657835, 0.018132618528657725, 0.028829609443034445, 0.08306667088930096, 0.056269436675523005, 0.06866767603371825, 0.021159753236653547, 0.11270026290523154, 0.04141879194815244, 0.02689167780668608, 0.03896018476890666, 0.02600375027395785, 0.084811910454716, 0.01582626103689628, 0.037812568313841305, 0.030214085509734492, 0.018074675030740242, 0.05815910920500755, 0.08049061269100223, 0.009921499178744853, 0.04297931053276573, 0.02760168836851205, 0.03165687148326209, 0.023241893920515264, 0.053120559214481285, 0.004195041904625083, 0.03759405968178596, 0.04834224097430706, 0.10811470289315496, 0.04794655327818223, 0.0523315586947969, 0.04349690043766584, 0.03511820753504123, 0.03868160543165036, 0.03211619558611086, 0.024569946407739605, 0.015136920348075884, 0.05516837790076222, 0.03005720142807279, 0.0564430398600442, 0.04777379147708416, 0.032845875181789906, 0.06305819310780082, 0.017597132262640765, 0.020442205847107937, 0.04890327747645123, 0.055794194141136746, 0.07777736149728298, 0.021763547622997845, 0.03705390848751579, 0.025227942171373537, 0.05106154130771756, 0.0315228268903281, 0.05133868893608451, 0.014997342302064811, 0.017553353183237568, 0.10326598664479596, 0.034051581019801755, 0.033419301733374596, 0.0566922522016934, 0.0416836818414075, 0.07399417593010835, 0.033832848471190245, 0.04112387348764709, 0.0889626516561423, 0.0566322595280196, 0.030205854879958288, 0.01936504168302885, 0.025748514237680604, 0.03062319802120328, 0.06423759553581476, 0.014906932599842548, 0.0068474039102771455, 0.021377213532105088, 0.05676931681643639, 0.007779079988332731, 0.07616115215101413, 0.04058040086446064, 0.03477269071819527, 0.04901197200108852, 0.011939801591714578, 0.03716913051903248, 0.03063555753656796, 0.02670263795049063, 0.025998004778687443, 0.036081204789557626, 0.031932254920580556, 0.011582607187197676, 0.06409724056720734, 0.028092767910233567, 0.035911079097007, 0.15887992456555367, 0.19935917960745947, 0.14812882217977727, 0.10119406639465264, 0.15213874700878346, 0.09615671741110937, 0.09142390172928572, 0.2031633590481111, 0.1320868701274906, 0.11266236672444002, 0.09345099795609713, 0.14914894529751369, 0.11708638790462698, 0.13708793105823652, 0.13765407353639603, 0.10370457132479974, 0.11486229939120156, 0.16764575562306813, 0.12898554440055574, 0.11925183742174081, 0.1369420460292271, 0.11967793027205126, 0.07990197677697454, 0.15268005510526045, 0.08270437390144382, 0.07895895559340715, 0.10332680373851742, 0.16423543861934117, 0.10608103166201285, 0.11226435165320124, 0.0879996001188244, 0.18147661989288671, 0.10271871422550508, 0.1662308472607817, 0.19287762311952455, 0.15927719324827194, 0.12749540007540158, 0.05026025251884546, 0.13371631769197329, 0.14100701361894608, 0.10954610644174473, 0.14223094151488372, 0.0831105246075562, 0.22578255459666252, 0.1591883594436305, 0.09936110582202673, 0.10991077151681695, 0.14142286059047493, 0.11918854367520128, 0.1200821471533605, 0.16249677405825683, 0.15889739005693368, 0.18256745993026666, 0.10266182584954159, 0.1297050765050309, 0.1320604072617633, 0.09575853949146611, 0.11208265354590756, 0.10190118130828653, 0.13044541249317781, 0.0983586653268763, 0.11777729940201555, 0.22869376838207245, 0.15977104460554464, 0.12015821092895099, 0.0726102969742247, 0.10265790391713381, 0.10359624320907251, 0.1709797102957964, 0.17779095337859221, 0.15121737787766115, 0.2105131418045078, 0.15614153364939348, 0.13033162217055047, 0.100401781765478, 0.18160204030573368, 0.07860159155513559, 0.13712013433022158, 0.10303236025252513, 0.07756833199943815, 0.17096563747950963, 0.09701696410775185, 0.10488756998841252, 0.14691870925681932, 0.14783112172569546, 0.12033847054200512, 0.09118722871478115, 0.16604400585804666, 0.14633928106299468, 0.10906841100326606, 0.0874903460166284, 0.11526214650699071, 0.19610337859817914, 0.13207464292645454, 0.0691810284874269, 0.22201561315783433, 0.17624905040221556, 0.19216897471674851, 0.2460689874632018, 0.12362705836338655, 0.22687982714601926, 0.15412264769630774, 0.1653962763292449, 0.20063886951122964, 0.08273213955440692, 0.157378774402397, 0.23215752680386814, 0.1424254367926291, 0.1108167650444167, 0.16165285291416304, 0.06556587533227035, 0.11547013106090681, 0.1357582059821912, 0.1352824986513172, 0.14811668997364386, 0.13981803027646883, 0.1216700683747019, 0.1938961177532162, 0.15172055230609008, 0.1931593915713685, 0.10250063985586166, 0.13525636148239883, 0.1972777462963547, 0.1373148060270718, 0.10816862607108695, 0.12115193903446198, 0.08590008384947266, 0.16161670056836946, 0.0823504025382655, 0.08149255107023887, 0.17272336887461798, 0.13309962435492448, 0.14846446631210192, 0.15667801057653769, 0.13798419439366885, 0.10186310870839016, 0.19990127480455808, 0.14084663508193834, 0.11516238828854901, 0.14818701334297657, 0.18310674599238805, 0.19386276097169944, 0.10252168122678995, 0.15093943636332238, 0.09953996765294246, 0.1435771414211818, 0.13533290023250238, 0.23067405926329748, 0.07972099113145045, 0.17498525178858212, 0.19138124984289917, 0.06566964369267225, 0.08383058596934591, 0.12011534108647279, 0.14134428623531545, 0.0823915692578469, 0.14035726205578872, 0.12406322067337376, 0.11869617152426924, 0.1575416906603745, 0.13168151330735, 0.10601558695946421, 0.12890341452189855, 0.13329497458679335, 0.10426512945975576, 0.09289672984076397, 0.10404718401176588, 0.057514724853847704, 0.08910599217883178, 0.09205472895077296, 0.10895801335573196, 0.08398714435419866, 0.1171859832746642, 0.17249234127146856, 0.08512568540338959, 0.1740531482334648], [0.00500250154540741, 0.022988493321463466, 0.03592676004128797, 0.024105689355305264, 0.004698265950927245, 0.03380664684144514, 0.04122171823733619, 0.09663693021450724, 0.012663800152949989, 0.059444383451981206, 0.07838914224079677, 0.030468844875161136, 0.006164586911576667, 0.022869673358010392, 0.014476181606629064, 0.024216041201725602, 0.08467536885291338, 0.0738668352631586, 0.05071856899719153, 0.023579975689894388, 0.057576227267938, 0.02817070953148816, 0.042290421069732735, 0.045188769831189086, 0.031308766055319986, 0.022263300538595234, 0.007982426755396383, 0.089184301905334, 0.013183758145065179, 0.05731252141829048, 0.03719333725582276, 0.04593878512137702, 0.028840065667671815, 0.05587607296183705, 0.07176740720335927, 0.05973941047808953, 0.017297023009242754, 0.027152298018336296, 0.020687681157141924, 0.0106416894621881, 0.02172467265544193, 0.022398305258580616, 0.007988102700827377, 0.05025110586679407, 0.058987858306084356, 0.027183980514694537, 0.022982771574918712, 0.02819368303088205, 0.04144138716427343, 0.05837250168302229, 0.01550679317941623, 0.04112788702228239, 0.034267592642988474, 0.048327934063438854, 0.0758572838136128, 0.03236890916845628, 0.013319794238278908, 0.027299472263881137, 0.03165643382817507, 0.0256547881955547, 0.0226170225401542, 0.033809615432151725, 0.0379495781048068, 0.0277440636751375, 0.02549500676936337, 0.02901093096339277, 0.02577754026944084, 0.05102142971009016, 0.05356747291183897, 0.05103856950466122, 0.01578407651478691, 0.046113874297589064, 0.01529320901525872, 0.043638653188411675, 0.026179860645372952, 0.03917877821783934, 0.04339806502684951, 0.03434040962851473, 0.03829190580706511, 0.022211234850276793, 0.030181291912283217, 0.03292343173442142, 0.002690399406544332, 0.04988523978473885, 0.039595100163881264, 0.01641642874372857, 0.096092446574143, 0.005903750416889254, 0.05748828912952116, 0.02479513012804091, 0.014457845894087638, 0.03707899392715522, 0.035470438455896716, 0.03732629958540201, 0.0074180620389857465, 0.02133121225051582, 0.04457671767366784, 0.004753910911469055, 0.06588068843952247, 0.015616471579830562, 0.015149106837010809, 0.07311262323388032, 0.033388747301484854, 0.0688759930697935, 0.02241742128639349, 0.01288190675300679, 0.01970033297714378, 0.0023705878286688986, 0.030843491200357676, 0.05713010406387704, 0.09138732869178057, 0.0407252545202417, 0.05180431662925652, 0.02323095084700201, 0.07661246614796774, 0.08999118860810995, 0.016999985823141675, 0.11536836437880993, 0.025535778242296407, 0.035722018884760995, 0.029155818545924764, 0.04426102925624166, 0.012230153511544424, 0.05706016067415476, 0.023397755110636353, 0.025981521466746926, 0.015662330369065915, 0.010514537088706024, 0.006541376559263361, 0.025300333376175592, 0.020882563199847937, 0.011616361759869116, 0.01991184930583196, 0.009890901490247675, 0.02642086610597159, 0.00859030507438417, 0.07183122342186314, 0.044009068847766945, 0.06275911522763115, 0.035496704546468597, 0.05565301475248166, 0.03504941426217556, 0.004118334368935653, 0.0323340596098985, 0.09267657915396349, 0.04668950269530926, 0.0373144557566515, 0.08001943797405277, 0.022331637496660863, 0.01612518115767411, 0.05926620015608413, 0.018142236762547066, 0.0645039544573852, 0.03813846868329814, 0.0290640297212771, 0.06028561759740114, 0.019547306367063096, 0.06313407367893628, 0.027450980651857596, 0.12025806414229528, 0.03561223531141877, 0.05797608795442751, 0.020466811223221675, 0.04142421683562653, 0.042108359946204085, 0.02920250854055796, 0.017660213966986964, 0.003107790681367208, 0.011753680284268089, 0.0049415445038383556, 0.029813841450959444, 0.011734563408286443, 0.023118824631507908, 0.04070400958880782, 0.024782551785132716, 0.05793914172266211, 0.027950599556788802, 0.06977259567273514, 0.02734077808314136, 0.012720065973033863, 0.027565910913316265, 0.00455848264807303, 0.05312776864905443, 0.05900137472365584, 0.0228811168510999, 0.033487341832369566, 0.07003898173570633, 0.052336060774645636, 0.06598752377820866, 0.01534174123246755, 0.021322615211829543, 0.059693229384720325, 0.029200740956834385, 0.025059304166851298, 0.01500988332554698, 0.026089109979303818, 0.08735826917524848, 0.020300186771367277, 0.04631611844524741, 0.06658410533730473, 0.05056315055117011, 0.02140001061239413, 0.014846585391621505, 0.029397414331989627, 0.03039738835234727, 0.02249679122386234, 0.029154268093407154, 0.017856071403782283, 0.05069401281486664, 0.014105888083577156, 0.028240832732990384, 0.02475038243989859, 0.016106348418231522, 0.03401724375518305, 0.03156919458082744, 0.033508668188005686, 0.029068440198898315, 0.00672934517829812, 0.006078393032242144, 0.05627452229548778, 0.02005076238752476, 0.03509366831609181, 0.04794756090268493, 0.02974300578768764, 0.02886952765818153, 0.0761016717712794, 0.01908716802219195, 0.0836235038670046, 0.01798339171468147, 0.03580924116873315, 0.03920797557969179, 0.003295283477720139, 0.05282654320555074, 0.02278310416399368, 0.010334574334722544, 0.006675421152197356, 0.024504406710288355, 0.023079099798841134, 0.0533034922555089, 0.010029644938185811, 0.06675348124865975, 0.019623555043446164, 0.01715874775046749, 0.030177468367453133, 0.04377703701278993, 0.012397804247614528, 0.03490093383671982, 0.047451395740998645, 0.05059027838121567, 0.005028621750950281, 0.008329957973078957, 0.03175314881705812, 0.009515083843975194, 0.05713864003441163, 0.019551569263317754, 0.01946014684758016, 0.02246575163943427, 0.030346426979771683, 0.05705726332962513, 0.04407225063602839, 0.0466873245978994, 0.047822666354477406, 0.03377452160098723, 0.025751450597973805, 0.02974901082260268, 0.024857684271410108, 0.028650493161486726, 0.061197541521063874, 0.014170668669976294, 0.04876761118482266, 0.04396629060751625, 0.06317233626863786, 0.021363630957369293, 0.04075426189228892, 0.033095732131706815, 0.03633613718141403, 0.046244400686451366, 0.06618212083620684, 0.055107140115329196, 0.0700886437137212, 0.022724634801436747, 0.04512715885149581, 0.05990911887160369, 0.022598778429840292, 0.021808363164642026, 0.04514586266928485, 0.01896252453194133, 0.03592803568712302, 0.09255519602447748, 0.04402633756399155, 0.037955966512007375, 0.04549913514139397, 0.08526798776750054, 0.10539048657353435, 0.02668220047572894, 0.030729334468820264, 0.05630607756653002, 0.03675077296793461, 0.03930296030427728, 0.02725394256412983, 0.059312618736709864, 0.042718393462044854, 0.024734436866960356, 0.02305087952741555, 0.023552992048540285, 0.04036857240966388, 0.03140796448237129, 0.02619778923690319, 0.01639691916560488, 0.05911300730492387, 0.011807181922319745, 0.005889312463945576, 0.040337719422365935, 0.04182161104732326, 0.03728450182825327, 0.02823364026179271, 0.042930086209837875, 0.045542374785457335, 0.020371857032712017, 0.03047884308866092, 0.05817247634487493, 0.04206430945279343, 0.022051226114854217, 0.054221668879368475, 0.049577731106962473, 0.048720052665365596, 0.03595114658985819, 0.006898935252268399, 0.035874166791992526, 0.05533082257690174, 0.04828497261873313, 0.04274321088035192, 0.03137640242597886, 0.03698631622163313, 0.01716512089063014, 0.04896269000268408, 0.021785701791356717, 0.030816960481128523, 0.039847491442092826, 0.02803408311280821, 0.025438722289566482, 0.015384249755048325, 0.019979163372356976, 0.02391860876897616, 0.023272402551291243, 0.038937290997377465, 0.08925770582365138, 0.00791624584235251, 0.01550974989575999, 0.03614598452778799, 0.022826247116816894, 0.004189899033268115, 0.12547960824200086, 0.08834793964134795, 0.13067090325057507, 0.064284468734903, 0.11246421414294414, 0.17710743791290692, 0.11873476659612996, 0.20873065745191915, 0.08521536737680435, 0.14053735882043839, 0.1495474489139659, 0.1742681624101741, 0.12992486756827148, 0.0829169385667358, 0.13838305084833077, 0.11364352157605545, 0.21136696955987386, 0.14784197828599385, 0.11744493937918118, 0.07923496328294277, 0.1602676236735923, 0.07437608258000442, 0.12856413344187395, 0.14054248854517937, 0.15356810816696712, 0.09389845787414483, 0.17865079295422348, 0.14492498338222504, 0.08160214804645095, 0.1384253507213933, 0.16918186391038553, 0.08802727756223508, 0.0856351430660912, 0.10525425709784031, 0.17121683114341327, 0.11515086676393237, 0.06291550397872925, 0.08058254061532871, 0.09361894894391298, 0.12926643075687544, 0.17638680658170156, 0.1311109196394682, 0.11630238140267984, 0.15155272345457757, 0.11807303210454327, 0.12186183594167233, 0.1767573274139847, 0.09793850965797901, 0.07962894107082061, 0.18139317365629332, 0.09675061197153159, 0.24599405005574226, 0.08840820033635412, 0.17926782555878162, 0.20932846037404879, 0.11391956997769219, 0.1612015049904585, 0.12052802608481475, 0.15089526373360837, 0.06704954643334661, 0.11479336023330688, 0.13900673309607164, 0.08382206356951169, 0.18442657802786144, 0.13517533083047184, 0.13697441214961664, 0.0958034245829497, 0.07734168094715901, 0.1360968356685979, 0.1520301406936986, 0.15386730139808996, 0.14779396514807427, 0.10791085061750241, 0.062435630442840714, 0.10168765312326805, 0.11247272297207798, 0.0884725186707718, 0.18957228905388288, 0.0922959888620036, 0.11765886789986066, 0.1482106942151274, 0.11478607276720659, 0.14515420608222485, 0.19380842388740607, 0.12470290277685438, 0.18291843895401272, 0.1616345053272588, 0.12414978817105293, 0.15926062342311653, 0.12639637690569672, 0.08096594682761601, 0.1419027205556631, 0.06422262705330338, 0.16966559152518, 0.1005072600341269, 0.2060116726372923, 0.1544180547020265, 0.09918881899544171, 0.271357173366206, 0.17925074004701205, 0.1063419080206326, 0.19137776217290334, 0.14646177020456108, 0.16192012785800866, 0.09900305646338634, 0.1503458810704095, 0.1116495378581541, 0.09087137744895049, 0.10690326682691063, 0.18979284007634434, 0.13496653203453335, 0.1466355294521366, 0.1604280700641019, 0.13666364311107568, 0.18097427327718052, 0.22169466609401361, 0.1816977680261646, 0.2894196941384247, 0.11826155627412455, 0.21938219160905906, 0.10343182060335364, 0.08070776425302029, 0.08324026050312178, 0.10215922139052834, 0.13648421131074429, 0.13208761651601109, 0.07719711227608578, 0.11123502760061196, 0.08067077052380357, 0.14212374655263765, 0.1102562476215618, 0.10415933906499829, 0.1313887933003051, 0.09348813417766776, 0.10156021067606551, 0.09579843735056263, 0.20576278599245207, 0.10602414328604937, 0.12012926462505545, 0.15640739724040031, 0.13217007209147724, 0.15315899226282323, 0.08908963269953217, 0.07008481677621603, 0.23502151455198014, 0.1448958878006254, 0.10593247999038015, 0.2082345262169838, 0.16753092035651207, 0.18543760877634796, 0.09089765711022274, 0.12595173290797643, 0.12458129573081221, 0.19238844008318015, 0.09047448196049247, 0.24055922882897512, 0.0951243806630373, 0.1408489556717021, 0.11761962143438202, 0.15058141414608273, 0.08909421281090804, 0.12210560643247195, 0.09891099961740629, 0.1348859356450183, 0.197827508939164, 0.1205687653273344, 0.1661944913544825, 0.12812657334974834, 0.12211940783475127, 0.18118262424000672, 0.18064213038555213, 0.09314780136836426, 0.11623542356703963, 0.12990942411124706, 0.14978524829660142, 0.13463897603963101], [0.037516788113862276, 0.03397787515340107, 0.022960491877581393, 0.011162729717658033, 0.04569555067324212, 0.02221854606510273, 0.05675890130390014, 0.004876701152949993, 0.0222600791935942, 0.02506747712115092, 0.0202523076441139, 0.07338435615279845, 0.04615717500980411, 0.035402805477912934, 0.06298428028821945, 0.042268365288951566, 0.032759144835706265, 0.03259047460077064, 0.018619694713769213, 0.015860376081296375, 0.022837251258481826, 0.03291282283940485, 0.08417782626513924, 0.06791416289550917, 0.01618177945991712, 0.016795273504352996, 0.007510508194432727, 0.032153691431241374, 0.022785928566008806, 0.021189925992595296, 0.030082829695727144, 0.04455096048435994, 0.0076416342386177605, 0.09570152219384909, 0.05097775919628995, 0.043617163984371085, 0.09468191476272685, 0.09855312667787075, 0.007848183690969433, 0.1264209398733718, 0.021834330699805702, 0.01281967745827777, 0.04878461527238999, 0.043876520424549065, 0.022392320579716136, 0.02240914315916598, 0.014359904453158379, 0.055568879802844355, 0.023652975879875675, 0.04825878795236349, 0.02275883635905172, 0.031911562995186875, 0.05793374736926385, 0.0459988897533289, 0.03614341288006731, 0.010771055556168514, 0.014717122606400932, 0.007227616767132921, 0.0868538258863347, 0.01743024487846664, 0.023721010889858007, 0.07498502026179008, 0.03168649971485138, 0.04429174653653588, 0.039644738393170495, 0.04916271873350654, 0.048113455929394276, 0.05840604166899409, 0.03882926143705845, 0.047270189571593485, 0.04283071814903191, 0.06920704352004187, 0.03448579254161034, 0.027745639572718313, 0.06830827639039073, 0.03799785247870854, 0.020209817781246135, 0.04602013129208769, 0.030117811568613564, 0.06902689925794091, 0.06363193517816917, 0.027762952393719127, 0.06877563095518521, 0.0159606194522764, 0.028233109308140616, 0.03372901225728648, 0.04719477379694581, 0.03654323285445571, 0.01285773648747376, 0.04672918003052473, 0.04755662973704083, 0.013422236062719353, 0.012680073119034725, 0.03307669243908354, 0.06847937578069312, 0.044787267089954445, 0.044436946245176454, 0.021983930708042214, 0.043390200805983374, 0.04233348768736635, 0.003088978510017374, 0.04833640557314668, 0.06402171961963177, 0.013633408034885568, 0.023525429956082786, 0.02639992142628346, 0.05779280886054039, 0.06192486320755311, 0.04861467956964459, 0.008908392113101269, 0.0024415064004382914, 0.010396990226581693, 0.029412688155259405, 0.042217424272426536, 0.018277156665655117, 0.03226533419053469, 0.030779420531221797, 0.05178000471953835, 0.006982510834599712, 0.014004392815487725, 0.006114800676836499, 0.01735020149499178, 0.04189146962016821, 0.016589480618547117, 0.006442595855332911, 0.03598919204835381, 0.022116102544324737, 0.060031065185155184, 0.10259556011962039, 0.017351653559931686, 0.040409427003136704, 0.05084833203415785, 0.04312298014493925, 0.03623151047421353, 0.048661325459501574, 0.03277100223515715, 0.016858881073338643, 0.04275619464793375, 0.022638990111382942, 0.027929858437606266, 0.028658214889998947, 0.03893465828150511, 0.03590533869074924, 0.037491997836955955, 0.04115150004093136, 0.02741727781748133, 0.08335931625749383, 0.050912667331951, 0.06304676657808678, 0.00650052451029686, 0.027669791231996248, 0.018560027736904364, 0.043863319525761266, 0.06779816054872104, 0.057968596927821636, 0.07955665673528399, 0.042420289279626947, 0.04786195353205715, 0.043307867366820574, 0.054052065658782206, 0.03920586872845888, 0.06982227800680058, 0.06438753820423569, 0.03949292975344828, 0.049140954722783396, 0.05589825087892158, 0.04668010159262589, 0.043751371425709555, 0.03321700669558985, 0.006829525784788919, 0.021715005227763737, 0.016969338092686873, 0.08027916082314082, 0.031027611677667925, 0.02091895812191069, 0.011316760559566319, 0.10267229564487934, 0.019809020716430883, 0.0562223022404526, 0.022561129914330583, 0.03896776061238987, 0.039834524637886455, 0.037959423647927384, 0.03697667084634304, 0.05569950457928436, 0.08785370830446482, 0.043044802732765675, 0.030683791198368584, 0.03040576825982758, 0.02100545776608799, 0.022523491576846157, 0.10214270584817443, 0.04076722191114511, 0.026222074005220617, 0.005700048691193972, 0.017616324625643234, 0.06090642964201314, 0.05728684565318482, 0.09036027094615356, 0.06031268435929503, 0.052947478501924446, 0.0038374649759914193, 0.036871246860495636, 0.010409563480477248, 0.032855710546885214, 0.018763391467343484, 0.01930806170483785, 0.046611291356384754, 0.008629188523627818, 0.027243937565279857, 0.024431370897218585, 0.05302373905267034, 0.05727107649935143, 0.09261006236608539, 0.02677193164293255, 0.04357636706637485, 0.06669925272996936, 0.0371884959084647, 0.044907537422009876, 0.06503382245344774, 0.03917380455615265, 0.0241444269195199, 0.015781920469765152, 0.04804615543356963, 0.004685115518181452, 0.08988604282162019, 0.08451568920697484, 0.060339052230119705, 0.027033169321449738, 0.07949731884790318, 0.0829367246478796, 0.03269372388188328, 0.037672372800963264, 0.06807237012045723, 0.011932866115655218, 0.012774692282878926, 0.04169647901185921, 0.038739474290715795, 0.06377444110278573, 0.03642889970381345, 0.04127435219873275, 0.02581107516639999, 0.02710883615405432, 0.03002881830824273, 0.01663480675779283, 0.02455025871417352, 0.04831791888656361, 0.021688598341175487, 0.038216880190053155, 0.027494842851800576, 0.21594509961349623, 0.03699920838698745, 0.06246942827211959, 0.0023234983465434717, 0.04878461866506508, 0.04218669002875686, 0.020258127778236355, 0.08174064382910728, 0.04240725122924362, 0.0401738735714129, 0.03036356677434274, 0.025480399606749415, 0.013196756331516164, 0.03006230740408812, 0.03651664785242506, 0.010931505339353212, 0.049514878408185074, 0.029309225135615895, 0.01984321548869567, 0.009635303285904229, 0.00971864689407604, 0.05645378106938941, 0.02078276257296758, 0.08132337871938944, 0.043077162067805014, 0.043085491085158925, 0.00811045613539006, 0.012309016244086837, 0.046826539627675495, 0.03470704245514103, 0.006771784151039485, 0.03607211581298283, 0.08631857710757426, 0.02966211423543947, 0.04150220765066998, 0.025073438051289747, 0.028794010103281056, 0.04518938051270587, 0.06470832241965191, 0.0297531668495919, 0.01576944729978485, 0.056601440467472584, 0.015041903393076999, 0.039325450347470384, 0.022286718478426337, 0.03772944098870669, 0.03046094672754407, 0.032259237553392134, 0.048038586375436614, 0.0629209933270301, 0.025074089444907646, 0.039398823731711934, 0.008799595808211182, 0.023117781383916736, 0.07066032303763287, 0.02496688430463629, 0.03634040516668132, 0.032775100586669784, 0.02327018034910517, 0.053941057329731326, 0.02083617345696049, 0.037749861500092914, 0.01265358565641301, 0.07123986658241067, 0.018224972233708416, 0.014678941440901585, 0.042227279993572404, 0.11121779959648848, 0.01675468523587499, 0.044385557395539114, 0.03208173279251371, 0.017852800864992396, 0.11097727250307798, 0.04174455661060555, 0.07651511672884226, 0.008654083973462028, 0.0195389960094222, 0.016573540134621517, 0.07655783050826617, 0.04722615943423339, 0.0041662694753280705, 0.03158664989418217, 0.05569979634934238, 0.0490531997888216, 0.07375725864299706, 0.019016132191089646, 0.06778849821005549, 0.025243246528719152, 0.1010992479111467, 0.01426921146256583, 0.041154645050742795, 0.03636955163840737, 0.030199832881667783, 0.04775831748598388, 0.04074953589588404, 0.01769976068421134, 0.03274539771622845, 0.014602959089513336, 0.020322532625868917, 0.03612240882856505, 0.011650215568287032, 0.05094242109251874, 0.13633207018886292, 0.1376161841409547, 0.12813489218907698, 0.09707369642066103, 0.24136302141206606, 0.13926176726818085, 0.2405073344707489, 0.14596643964094774, 0.14558367803692818, 0.2000962450568165, 0.10892095855836358, 0.10969768437956061, 0.2167110570839473, 0.0890790679092918, 0.0914653262921742, 0.17007721800889286, 0.1563626274998699, 0.11669465606766087, 0.09745135544134037, 0.08899874293378421, 0.1091360202325242, 0.2110768144151994, 0.15664750364209923, 0.202823331579566, 0.15266754291951656, 0.06729341191904885, 0.16843633034399577, 0.16285079291888646, 0.049810081853398254, 0.18963083305529185, 0.17827770725956985, 0.18881752741123947, 0.08996737881430558, 0.22725355066359043, 0.16354379430413246, 0.13443879463842937, 0.14780387175934656, 0.2053562756627798, 0.07303862899009671, 0.19809543527662754, 0.12327394873968192, 0.13235778201903614, 0.11748551577329636, 0.18219677624957903, 0.1208199318498373, 0.10983058903366327, 0.12950480010892662, 0.1540965512394905, 0.12329712749591895, 0.15991010357226643, 0.1427265027804034, 0.15864831342228822, 0.196200232686741, 0.11175217985042504, 0.1668480427137443, 0.1653469196919884, 0.24166605515139444, 0.1015180465100067, 0.16188678464719228, 0.10224238264241389, 0.15390164884073393, 0.20052047872117587, 0.11475988131548677, 0.1267014733914818, 0.08443949650973082, 0.2195265024368252, 0.11992221644946507, 0.10176418508802142, 0.09044209548405238, 0.14310574957302638, 0.09172190073877573, 0.16537218833608286, 0.12423689849674702, 0.16944119999451296, 0.3871161432138511, 0.08357937873474189, 0.18253076475645813, 0.13878852980477469, 0.14940114319324493, 0.11837788431772164, 0.09658878815493413, 0.11976580055696623, 0.11290217457073075, 0.12739846456263745, 0.09460032771208457, 0.10535902290471963, 0.1314717781330858, 0.15666450772966656, 0.12078130963657584, 0.17160029842385224, 0.1437674704939127, 0.053686895075121095, 0.10728064086288214, 0.14623683584587915, 0.13569610645728453, 0.11233226622321776, 0.16321729682385921, 0.2599905718650137, 0.1843354914869581, 0.11980177648365498, 0.09336909877934627, 0.13581928770456994, 0.13717189298144408, 0.1746553344918149, 0.08330324212355272, 0.14890396701438086, 0.2567455731332302, 0.10415760880070073, 0.15969688072800636, 0.1422598742480789, 0.10954858309456281, 0.09110721586538212, 0.12168906735522406, 0.12712867903922284, 0.09351752152932541, 0.14202864308442387, 0.08203122645084347, 0.15507163320268902, 0.12904077715107373, 0.12850178964436054, 0.11830742524138518, 0.15018833880977972, 0.18549520282873086, 0.08331113348581962, 0.08531829435378313, 0.09871164602892739, 0.17997859099081584, 0.19273367870066846, 0.16820535702364786, 0.07945136845644031, 0.11218112254781382, 0.10495032090693712, 0.11190749651619367, 0.13020774881754602, 0.12303475157490798, 0.18501800272081578, 0.12443516642919608, 0.21430851386061736, 0.18956869281828403, 0.17556765196578844, 0.16291705864880765, 0.15193392442805426, 0.1616677806845733, 0.2146554488156523, 0.10764740939651217, 0.13554990930216654, 0.1922893603997571, 0.17932316687490257, 0.16965212939041002, 0.08466612720595938, 0.1079736626041787, 0.08491393498011998, 0.12060195926044669, 0.14334486531359808, 0.18781154496329172, 0.12949459494224616, 0.1406045202165842, 0.12716875331742422, 0.18000768657241548, 0.09495610397841249, 0.12282603420317173, 0.15204915324492113, 0.24605142697691917, 0.095860815074827, 0.11967345194092818, 0.19322994564260754, 0.12053876050880977, 0.11592772150678293, 0.11720754711755685, 0.12370939180254936, 0.08667977486870118, 0.08153428775923592, 0.17397260612675122, 0.12437694812459604, 0.16365902312099934, 0.08158103203667061], [0.07282061568860497, 0.013765338991236473, 0.0060609283890309075, 0.021609504906726733, 0.0323276847733983, 0.029054309707134962, 0.035770337363438945, 0.03305058580424104, 0.03846206881904176, 0.06792758431817804, 0.04878243378230503, 0.025810844464493648, 0.02521362168980496, 0.01502923684061638, 0.062214523021663935, 0.0522469182365707, 0.02494015681025173, 0.023319738850529705, 0.00818511110264808, 0.045548023589487584, 0.01404943481819438, 0.02583173825405538, 0.008256844128482044, 0.10092843350555215, 0.005198339050236557, 0.09546478132584266, 0.06299501471221447, 0.08309073174106223, 0.00961839928225215, 0.028576017157839875, 0.0369247798807919, 0.024289646984211037, 0.05938585302127259, 0.005017701577993908, 0.028386144399909035, 0.004538334822947425, 0.06169454806617328, 0.03718581908781614, 0.03425237988787038, 0.07822499104908534, 0.028757308144122362, 0.029412593160356795, 0.014757468298609768, 0.020304587070963213, 0.07878322859427758, 0.0360541074935879, 0.07483160349407367, 0.0065798439817237, 0.05594227762360658, 0.024457424945597137, 0.029651081256036247, 0.008805300591380467, 0.012442783485831959, 0.039352283014782836, 0.036044048211936436, 0.05002152693590947, 0.02090795398024576, 0.010983593928228532, 0.01099834612770272, 0.02591734392834561, 0.06243868385042463, 0.037701895859624655, 0.0176708618777671, 0.02244428448778178, 0.012528652092441916, 0.016066240213279213, 0.03020109495680247, 0.007643741089850664, 0.009760532012608434, 0.09974244250250713, 0.021619012878675545, 0.012198493067574288, 0.0323646852879652, 0.03208225526447807, 0.057225641794502735, 0.07608991954475641, 0.05102696316316724, 0.020267786724226813, 0.03305932194260614, 0.019743384327739477, 0.02160180183792753, 0.04432295575471861, 0.02211872168949672, 0.02121268575345831, 0.009124718406902892, 0.04452396157596793, 0.07332049922219344, 0.039714610536715815, 0.1472652099494423, 0.051642343534954956, 0.026079834405598894, 0.08971550661538329, 0.027365381762917553, 0.018773771356791258, 0.029462533337729316, 0.016366162869547094, 0.03655758387010012, 0.05812121980956622, 0.023605088270934563, 0.10037561745515891, 0.04407709876873663, 0.09040643168347222, 0.04050669499805995, 0.020884118741378188, 0.03722866518156869, 0.03200979111716151, 0.04305858038631933, 0.03290889751432197, 0.052916513556348424, 0.02386025815004749, 0.036467348890645165, 0.04886556450011475, 0.028777494560927153, 0.02376101222554488, 0.045312853530049324, 0.04232452084709491, 0.043767228789095364, 0.009745175068798875, 0.027830402167247872, 0.007512702407049281, 0.06265688714172159, 0.05716363047914846, 0.017387541277068, 0.019847877024273788, 0.03801694306145821, 0.07460624165832996, 0.0067605751766158, 0.06437926007700817, 0.04706582160932677, 0.003492454091818737, 0.023397914566365734, 0.022669117066210935, 0.08339357549058539, 0.033471436971532445, 0.02945755628336753, 0.016376539366319776, 0.00859488857843514, 0.001514699447268088, 0.022714887645893862, 0.044497037306427956, 0.04342442950499909, 0.019835034052708318, 0.0801904152280518, 0.034510735488895855, 0.05134130808125649, 0.028127975396013687, 0.038757170484002144, 0.04370479338935443, 0.025315486759479557, 0.04109082883223891, 0.007097181980498135, 0.08566688493426357, 0.06662761978805065, 0.05356701829337648, 0.007651026011444628, 0.002661829477541947, 0.07281424424477986, 0.07671571203640529, 0.01694254613747554, 0.05084575360108699, 0.03830238917310323, 0.02423507410899869, 0.09989247338048049, 0.04685199486890009, 0.011501110890614135, 0.030510975114469017, 0.029331749105559926, 0.0026652866134619607, 0.01943234896420368, 0.03876635106280446, 0.08352245643202748, 0.09402720989393336, 0.03698963425787432, 0.04463874255972249, 0.07307059477482523, 0.016717884889138595, 0.02070516870091004, 0.04618879813434822, 0.0005704565826038431, 0.061783782206475735, 0.03348306366907699, 0.012158925994299352, 0.07002182158508471, 0.007967726294217365, 0.08465802549783673, 0.038065047801605294, 0.025897413658510362, 0.11962851935199328, 0.030810582251953225, 0.016126102268961922, 0.015427915179835898, 0.046656844804861715, 0.013072725219119872, 0.017426321249721304, 0.05042101103546364, 0.027840441092848778, 0.02784600847267679, 0.02902924801622118, 0.018252559771229113, 0.03355245066008397, 0.04543608566746116, 0.015014841720195753, 0.006697493472269603, 0.02917204231822065, 0.009231803955377212, 0.02356024389155209, 0.04535484806235347, 0.05648127870102014, 0.03260205380086388, 0.03484185718532119, 0.018712684545399885, 0.02300168404222599, 0.0641671432448285, 0.031782872043550014, 0.040425481141677926, 0.04078812078971948, 0.01577822584658861, 0.054862803047789, 0.040208770627421994, 0.04427413176745176, 0.055557955389044116, 0.01325092463022364, 0.03430608932727149, 0.0046262852598114735, 0.035643017052539756, 0.08825448501322951, 0.01855946794551398, 0.053682179256741486, 0.015846471202426722, 0.020426323038658926, 0.033352048735001256, 0.04785860496174012, 0.030368248665971414, 0.05205060787765043, 0.06399224405842167, 0.08054786747587578, 0.046597483168755255, 0.018075718278331415, 0.020371572048004185, 0.06514217771057572, 0.06747791916131973, 0.025782371438773613, 0.016882366866671612, 0.022115583465035473, 0.02087257686071098, 0.08567928855440446, 0.015846910553851297, 0.03805154495473419, 0.037592458339141946, 0.02484934507603092, 0.024189279780590107, 0.05774810018816164, 0.05340182215773633, 0.024546050100720355, 0.028598123828747442, 0.05224023127396192, 0.04413442819246224, 0.01861976256727108, 0.017961327452212572, 0.035617144512278695, 0.03028566756152681, 0.007021738640365324, 0.06410344237727778, 0.022308798007933155, 0.03035330053951059, 0.062299808088157854, 0.03480868700093456, 0.01907182464908276, 0.01629848069777446, 0.03895387778590832, 0.03703565589551415, 0.07376358937472105, 0.08231292026383535, 0.015985557310549275, 0.051132444824491224, 0.04686086671426892, 0.055620814873171706, 0.04351959404136453, 0.06770909604217325, 0.0651987607457808, 0.04297963622957468, 0.026399446451770406, 0.007907838793471456, 0.02131042702655707, 0.00745226359660072, 0.045992542058229446, 0.03397417374487434, 0.006653787759465298, 0.030905929992773702, 0.0006939345829388392, 0.012971717648075094, 0.015453378902748227, 0.04171453482870545, 0.030337053018489053, 0.028789596232984747, 0.023309457348659635, 0.07307040478502001, 0.041373336887253184, 0.015141459747350641, 0.06892568218920912, 0.026960291267771806, 0.08195757825991937, 0.03579761786386371, 0.02749752645779933, 0.023030638827809265, 0.02688030555977353, 0.076432912211333, 0.02778256035942052, 0.05009440498958741, 0.031461236266685386, 0.08204548247158527, 0.04811350342684558, 0.022556400525250604, 0.042323492866541655, 0.04449715605005622, 0.03522191482729145, 0.03974748216569424, 0.08947855540152107, 0.03317822841927409, 0.038438432051667144, 0.010111130208575299, 0.008825883951171168, 0.026312230953148434, 0.016561295970210006, 0.07528102437832526, 0.02865604018526418, 0.03318180090614727, 0.06910598929971457, 0.04673510364123753, 0.10110465583524533, 0.0943833797105721, 0.020841598344434584, 0.023977378383278847, 0.1136693534042154, 0.027054868871346116, 0.007804978821825768, 0.05329950925494943, 0.03515322333467858, 0.02464934518294675, 0.04935629798897675, 0.010245735441068453, 0.04611463086413486, 0.006748381478246301, 0.02715875088636364, 0.028157330517257963, 0.012047752272337675, 0.03142519587916987, 0.02284352431472923, 0.01644414011389017, 0.012892832863144577, 0.04973677292998348, 0.013254937316690172, 0.16528674720653466, 0.13887424234833035, 0.07474113442003727, 0.1158702631614038, 0.1580031080437558, 0.07991198516849961, 0.08742731011339597, 0.09255079911755663, 0.22873263486794063, 0.13164483170424188, 0.132793930758323, 0.22168748719351633, 0.12379696353205613, 0.10207120182790927, 0.18537861694182667, 0.15133897135300295, 0.11891426624996321, 0.11926686018705368, 0.1471277116132634, 0.16400202257292612, 0.10949761154396193, 0.1194371860474348, 0.10561595697488103, 0.2034368629434279, 0.09256092286003487, 0.20295804792216846, 0.20782007702759334, 0.17145843032215322, 0.16603793975497994, 0.09331863613000937, 0.12594865235899175, 0.1699295552181346, 0.14207315498164722, 0.1048134807497263, 0.08394800645432302, 0.052135509571858814, 0.1408840495028666, 0.11098682627614055, 0.1251382101327181, 0.13534349894949368, 0.13562019195939812, 0.09807598763810736, 0.09614004580570118, 0.10735935771039554, 0.1342248118349484, 0.15298105323953287, 0.1479416550802333, 0.11970800294407777, 0.20431487368685858, 0.13384320374046052, 0.11821658297308854, 0.10488142246114356, 0.12280437536537647, 0.07891845383814403, 0.11991292051970959, 0.1411608239369733, 0.14553561061620712, 0.12773889915219375, 0.13878903192068848, 0.16520340953554424, 0.1448010964585202, 0.07469515010182347, 0.12458554336002894, 0.14354861580899783, 0.14151066302188806, 0.11573188272970063, 0.09682417873825346, 0.07939376761870724, 0.13187884486147336, 0.29327317593353136, 0.14857242123356887, 0.1000952400001032, 0.0927732161113194, 0.07216939848980733, 0.23780763362135204, 0.11863294563123158, 0.0736107968592218, 0.17584741195397718, 0.09454183799347707, 0.08029052628470318, 0.11121520080736705, 0.09178670761840683, 0.11628621869853564, 0.1213270824934755, 0.09893149137496948, 0.18438430529619965, 0.20326227588312967, 0.0810830280450838, 0.22370760808033602, 0.13575888451720985, 0.13442632316478662, 0.12381566395717007, 0.10402648190834693, 0.2216168652687754, 0.15971528259771212, 0.10326935217848845, 0.1451368491564478, 0.11776292803032057, 0.17509239246802671, 0.31059109951768604, 0.15283670169966562, 0.12424474236156259, 0.14311846531927586, 0.15016186237335205, 0.13050638564995357, 0.10705688715513263, 0.10889649058559112, 0.07212971776191678, 0.14060427594397748, 0.13727376822914394, 0.11069640650280885, 0.11502208081739289, 0.14450567588210106, 0.05898889646466289, 0.13597701995500497, 0.13788966089487076, 0.12909025592463358, 0.09693369429026331, 0.16780172368245466, 0.11488796158560685, 0.14683238603174686, 0.2038777342864445, 0.20140512553708895, 0.1392202680664403, 0.1643557564488479, 0.29269207854356083, 0.11433308278875691, 0.15656111256352492, 0.06924287016902651, 0.06023267829524619, 0.17651533468493394, 0.16374507493206433, 0.1655317119189671, 0.12793548431779656, 0.20060102082788944, 0.162204203328916, 0.08468285309416906, 0.1424861792474985, 0.14298676167215618, 0.15563523795987877, 0.06885962001979351, 0.13890398932354792, 0.11603062812771116, 0.16172116781984056, 0.11848089950425283, 0.08907676089022841, 0.13747399034244673, 0.19018181706113474, 0.21030081462647232, 0.1544769379709448, 0.07465213098164115, 0.13317087053188256, 0.15608395316771098, 0.21008422624851975, 0.17495254640068325, 0.1557124009621995, 0.14276880265346595, 0.1723928273256336, 0.1316961289516517, 0.13960421032139234, 0.08255280274897814, 0.19588544672088964, 0.21590493034039224, 0.09632983883576733, 0.1287598093705518, 0.09941774992538349, 0.11186558340809175, 0.11374609571482454, 0.09668146925313131, 0.10656137338706426, 0.13308310881257057, 0.18319107432450565, 0.1499721304114376, 0.11978958999472004, 0.12362435779401235, 0.05971007062388318], [0.026537222987306968, 0.030904715415090322, 0.04135313011439783, 0.027533164813316295, 0.056195880086826425, 0.031795167098087926, 0.011175957757846584, 0.010757333033585122, 0.029407592357269356, 0.00878887071407267, 0.022202028826411282, 0.07866578775324992, 0.007681249657512775, 0.0676919019648007, 0.02867504595113652, 0.011300426525329905, 0.025512077014095018, 0.017869530145877173, 0.026956040245879973, 0.04413703376693385, 0.050640612108899016, 0.016518739950177923, 0.03908686725688832, 0.05178593172292624, 0.044946936557867696, 0.018036375121612633, 0.016021697781980038, 0.03165975525709135, 0.011408656253479421, 0.04435568828401821, 0.022089105332270265, 0.0712201687108193, 0.017624911486304233, 0.056037146997238906, 0.037120374385267496, 0.07660304129655872, 0.01995169966747718, 0.030715136123555045, 0.05992961062916687, 0.03387126373127103, 0.03021471654730184, 0.03963629063218832, 0.0450692323169538, 0.030899823177605867, 0.028459124233839766, 0.018303237855434418, 0.022761094184326272, 0.02804856135376862, 0.010544919342334782, 0.027170718547755053, 0.013645420649221965, 0.054044340537594895, 0.03809331896315728, 0.020024345322911228, 0.050473098776170185, 0.04328331118449569, 0.023143219661765864, 0.0586232135870627, 0.03730008777763162, 0.01701490511186421, 0.05424505798146129, 0.03595960113619055, 0.04186926795435803, 0.06499889825603791, 0.018990510708785484, 0.01566181128977665, 0.02901858144572803, 0.07136588410607406, 0.09400063167725291, 0.017518554514806186, 0.025499922755573477, 0.0332584482218538, 0.03231942021687116, 0.026830677508509586, 0.03411720892680543, 0.07986606191843748, 0.0345221586259348, 0.06581966778529541, 0.022362571908161044, 0.06332570553890296, 0.06639737928552286, 0.058690463192760944, 0.0374475436152092, 0.02599556714163295, 0.03440518597407, 0.039765490485089164, 0.04617986522082772, 0.08109089226594993, 0.014176856909346367, 0.016981283701690178, 0.030790392442473342, 0.029084643615143638, 0.0418990522490016, 0.09263243366565023, 0.01778727473824152, 0.031245092329170023, 0.02261891226018114, 0.06451985253287212, 0.024441109571073736, 0.027528998608301793, 0.01982934962558959, 0.04972947867853301, 0.011786631641111203, 0.02824575380821313, 0.04099741152354649, 0.0202717849918242, 0.03898966372279184, 0.05056329982887421, 0.05055594450927206, 0.008455986522936394, 0.004033844036582325, 0.028423845501882688, 0.031000636518001556, 0.04719583570425, 0.032368943095207214, 0.011754498767134334, 0.01604885614610144, 0.058326374872454574, 0.01764056189650936, 0.06725587536181722, 0.006241427609763507, 0.07600248352225338, 0.07001609474952732, 0.020638144708105495, 0.0760619096191866, 0.026524072978645563, 0.030088054415370737, 0.04258279163124306, 0.023598813518349613, 0.027597791881167462, 0.09692238989685263, 0.03543262030663235, 0.010954493257616247, 0.08044226707092353, 0.0489699571127338, 0.017298493733895675, 0.03844368391271148, 0.078944977772023, 0.015141468229038375, 0.04721906874328852, 0.06020156746464116, 0.047292588012559075, 0.03208086426768984, 0.0019290190788784198, 0.03416334930807352, 0.03769162962479251, 0.09293044624584061, 0.06022095999547413, 0.06797513605228492, 0.00629734610473471, 0.05993885227612086, 0.015225838969594665, 0.04813770337828568, 0.03953698363953403, 0.025403864249320965, 0.01735153142362833, 0.10770796186157636, 0.05347823537886143, 0.019387375663167665, 0.08814714077327933, 0.05893985873886517, 0.024293356874425496, 0.026293428747781684, 0.0527359960999872, 0.07764544071895735, 0.03886937642736094, 0.03596086321132524, 0.020595420750656297, 0.04314525305692639, 0.048437320693795166, 0.028482257188963037, 0.024857149925082922, 0.017768097642276968, 0.04087924465004887, 0.040691239559756856, 0.03998447069898248, 0.11439048685133457, 0.032435035798698664, 0.05618238063263042, 0.03330227819138339, 0.05746615531721285, 0.012465667079335876, 0.011260526121727057, 0.0418279655277729, 0.023558018296690922, 0.04799125516521079, 0.024290520598047545, 0.10083686520478555, 0.02781201047556741, 0.02420598192007414, 0.019127936102449894, 0.02260971811067845, 0.021977703452908566, 0.019598539153646146, 0.050090472879154344, 0.021888805187440345, 0.022925029941169277, 0.02014595576162849, 0.03502584195562771, 0.016595310930694853, 0.023910924359889965, 0.02401038402292345, 0.01770370127633214, 0.032238701691052744, 0.0393028483459992, 0.037616044216390164, 0.021990261439766203, 0.03619812655129603, 0.02522811689414084, 0.08233687933534384, 0.036336225390966446, 0.01885022359367992, 0.1307235439973218, 0.023287764584113444, 0.06698110260601554, 0.026082465425133705, 0.025959182397595475, 0.00963400728401861, 0.06243389339319297, 0.015059864215020622, 0.03988549618848732, 0.13531723964427197, 0.028994310248110975, 0.023070662215884243, 0.030502510390111377, 0.02161333354056946, 0.011391958354839256, 0.01435373317716377, 0.047998498526534865, 0.01302099201296057, 0.03900180610695055, 0.02310604781710676, 0.05596212138022695, 0.036107501414205344, 0.021503047851313437, 0.04209021252713033, 0.04159541122083153, 0.01642032353473561, 0.027999484612207328, 0.03586305578106216, 0.05092828720808029, 0.05123284086585045, 0.07352718777422394, 0.015548400946759751, 0.0596349567973188, 0.011079379324136036, 0.021581622206472924, 0.12321701965161733, 0.006165567394678614, 0.03991094803703683, 0.026644236441435556, 0.056470303397093496, 0.08421597350388765, 0.012294007049474334, 0.053338857500680854, 0.08922485115804843, 0.04810592419068728, 0.02171662692645831, 0.017596781120768616, 0.04962071969306894, 0.019516628102532456, 0.034393141977488995, 0.052115082275122404, 0.0410106599197856, 0.040087994786777666, 0.03705175753150668, 0.04064034264800804, 0.023423439357429743, 0.034630632626691034, 0.027351268234529665, 0.06372232961335353, 0.024272983860490576, 0.019432659393974712, 0.04138663617361869, 0.0615098915461983, 0.05236867456031697, 0.013792691586006964, 0.023812623295400823, 0.011740374212552394, 0.025835354845704775, 0.023716513899021914, 0.04250812563779099, 0.011451733897307088, 0.050251692799585204, 0.06606423894741706, 0.039236952417663166, 0.028557096208844866, 0.02399466745555401, 0.03371721931866237, 0.050976198565747054, 0.010593545706277447, 0.010884560045919247, 0.02668116401348795, 0.04864784975403121, 0.03736363936747823, 0.06642616274101393, 0.03150856408423611, 0.0751125712745956, 0.05682622215577534, 0.05276484062362995, 0.033494541088917425, 0.02319142278949065, 0.011156186943740716, 0.022113512236891047, 0.026222350508240715, 0.03730410470494202, 0.040543773544154, 0.04717177824516382, 0.02877489577180573, 0.046965578238346746, 0.03419010733653392, 0.045195894448884895, 0.02321731229312718, 0.012284640721710665, 0.038890170133007426, 0.047397458992366276, 0.03290625801309943, 0.020717462059110403, 0.10927681624889374, 0.019457563325496655, 0.02429941449580448, 0.02297655789048544, 0.07512918181185212, 0.03469241324013897, 0.07290657929011754, 0.0354807895076062, 0.056320584645228725, 0.07011996489018202, 0.035124911461025476, 0.000768899502872955, 0.032954512030950615, 0.022858255309984088, 0.05095394940248557, 0.024697784101590514, 0.004413592521034713, 0.06360282602586917, 0.03198107551517231, 0.017398837188790952, 0.04605684003659657, 0.043735673518053124, 0.05242827029100486, 0.018531743004652004, 0.03793706591906292, 0.03365318936162761, 0.05371241816984756, 0.018352713236319165, 0.05025207277919565, 0.018746204175321118, 0.013892045227943786, 0.049474244338593314, 0.009813925085057105, 0.023499710086200918, 0.20759504767400877, 0.1099260114133358, 0.13999242734696182, 0.07870592309960298, 0.2101598150495972, 0.1621371369276728, 0.14806869040642465, 0.10752844863704272, 0.055435812300337214, 0.11848085879215173, 0.06929557876927511, 0.18119741630341324, 0.08720340712794236, 0.12597892859152385, 0.1190190999103444, 0.058647152302520614, 0.12183031120470592, 0.10531282145529985, 0.1236882350806679, 0.12358448707631656, 0.14539372894380773, 0.10630599994744573, 0.13624979103250162, 0.13687629598592008, 0.09352695995143481, 0.07340445436005082, 0.13496647775173187, 0.07235644345304795, 0.08840784071279423, 0.11602868751755782, 0.14220580857779297, 0.12419801844017846, 0.097054337816579, 0.19085438097161905, 0.1667397078126669, 0.19632451316075666, 0.14478877426258155, 0.10522584005125932, 0.16809737496078014, 0.15556737088731357, 0.11686576902866364, 0.10552463294672114, 0.13537699143801415, 0.10530906915664673, 0.22070635269795144, 0.20003482406692846, 0.08435906296862022, 0.14336044447762625, 0.10004183929413557, 0.08944222663662263, 0.15652580160115445, 0.1705176822308983, 0.16841857986790792, 0.07105847381587539, 0.11808905910168375, 0.11616670154035091, 0.12031994653599602, 0.16772565990686417, 0.10049687166299139, 0.08629212781254735, 0.11792764919144766, 0.144127881154418, 0.10425254263515983, 0.14749599327998503, 0.11070625204592943, 0.11892642559749739, 0.17521713434585504, 0.20756118877657823, 0.18464022156383308, 0.04418974915253265, 0.10562353621103934, 0.1414449265492814, 0.14086604118347168, 0.1233755254319736, 0.10323364088045699, 0.12241476055766855, 0.21874100315783704, 0.10872680254812751, 0.13003985211253166, 0.21283455938100815, 0.2587459215096065, 0.0753782516611474, 0.11803337851805346, 0.14827189807380947, 0.09164718046252217, 0.11386203020811081, 0.21407151514930384, 0.12221463343926839, 0.06114073456930263, 0.1349492972450597, 0.22325406170317105, 0.1315266987574952, 0.1542694148208414, 0.12976026854344777, 0.19982644596270152, 0.14827719064695494, 0.08901465457997151, 0.17282308638095856, 0.08252449426800013, 0.1499295455536672, 0.08890754782727786, 0.10079949149595839, 0.09810111378984791, 0.197195562134896, 0.19436090067029, 0.09910650591232947, 0.12921191725347722, 0.13552073229636463, 0.21694515166538103, 0.15476778522133827, 0.09650585760495492, 0.12793929768460138, 0.13544982538691588, 0.10187544447502919, 0.18213610164821148, 0.09032641204872302, 0.05518274927245719, 0.18841998731451376, 0.09450397573943649, 0.1401916995112385, 0.0642673967938338, 0.2364471980503627, 0.16743519263608114, 0.19027763977646828, 0.07344098668545485, 0.1804662269673177, 0.24836330435105733, 0.1571055826331888, 0.0896094651626689, 0.19630563631653786, 0.16775756462344102, 0.15474711704467023, 0.13942659699491092, 0.25821563282183235, 0.0801939300394484, 0.0692846407847745, 0.09788392830107893, 0.11020446861428873, 0.12412040760474545, 0.13709679272558006, 0.1444807057934148, 0.11855141286339078, 0.2786479778587818, 0.09665089446519103, 0.10904647396611315, 0.10871904010751418, 0.154296216954078, 0.11070783981787306, 0.18748350042317594, 0.1562268255012376, 0.14435225911438465, 0.1051458746993116, 0.27308203652501106, 0.10674528351851872, 0.08155813826514141, 0.09042422965701137, 0.15420114062726498, 0.14406119473278522, 0.13788700103759766, 0.19944889550762518, 0.10782734331275735, 0.13133573186184677, 0.1266339998692274, 0.13856728667659418, 0.18067826916064533, 0.09763540806514875, 0.07630717967237745, 0.09397914925856249, 0.13095691933163575, 0.11591994549546923, 0.14016808649258955, 0.14214365477008478, 0.12968500543917927, 0.11313952612025396, 0.08379807057125227, 0.08922941769872393], [0.08223354523735386, 0.0439008526903178, 0.005491440309145088, 0.03826465584071619, 0.008535291999578476, 0.04346119931765965, 0.025219487625041177, 0.059194336512259076, 0.03264173113607934, 0.015833523057933365, 0.05133216142920511, 0.012204023976145046, 0.015134609936337386, 0.03278441008712564, 0.051551453769207, 0.07270704928253378, 0.05804129516971963, 0.042575409170240164, 0.029689757752099206, 0.058819859820817194, 0.039735448347138505, 0.012951490519169186, 0.028087592384378825, 0.10904990735330752, 0.014917159818911126, 0.03280849808028766, 0.04581046397132533, 0.03947284850957138, 0.032759317862136025, 0.05584735735984785, 0.032786947808095386, 0.011222292369763767, 0.0835684814623424, 0.04559596548123019, 0.02406706544570625, 0.0885198600590229, 0.029792925609009605, 0.05263239058798977, 0.024609896853300076, 0.011833432745853705, 0.0024910774123522317, 0.034537992240594964, 0.06754557588802916, 0.06383909870471273, 0.04533252086756485, 0.0351832349385534, 0.012130815136645521, 0.006087147406235869, 0.040684128512761424, 0.008950346781473075, 0.04543198731594852, 0.016809702551524554, 0.019773049878754785, 0.091190316049116, 0.04350067648504462, 0.06092659570276737, 0.042180461077285666, 0.038694205826946666, 0.021946446737274528, 0.02498333029715078, 0.032755551992782524, 0.07229202333837748, 0.08716007588165146, 0.0036325363741655436, 0.007051751516493303, 0.043744579290172884, 0.02213958155230752, 0.018250049191660116, 0.07518896753234522, 0.025236883566581776, 0.06409994792193174, 0.025258791765996387, 0.024173778648089086, 0.08965616872800247, 0.026787865341507962, 0.050214817813996754, 0.03983911153461252, 0.051902615997408114, 0.03783906510631953, 0.05949052383324929, 0.049139828354652436, 0.026512488689539686, 0.02244790956111891, 0.03696282194661243, 0.013581685854920318, 0.06458555507872786, 0.025952059476237212, 0.035852609734450064, 0.03467752957450492, 0.02849375157217894, 0.02760467222625656, 0.02284368546679616, 0.03591761678191168, 0.06167143716343811, 0.028210381777690988, 0.014615868218243122, 0.03082678566819855, 0.0800204761326313, 0.019649039122409055, 0.04318399401381612, 0.05543205660900899, 0.04560408076005323, 0.016229288785585334, 0.0076452559192797965, 0.03185082393299256, 0.06607251028929438, 0.056803803358759196, 0.021117005530478697, 0.0022096461075956798, 0.036273030032004626, 0.061588472686707973, 0.00204689333414925, 0.017136624116184454, 0.0226091413559126, 0.04242928326129913, 0.032897786503391604, 0.04041785780074341, 0.03305615996941924, 0.07006588564919573, 0.019817646592855453, 0.03146653562518103, 0.08048727429871048, 0.03708617961300271, 0.022330025975991572, 0.043720355590007136, 0.06642187439969607, 0.012888968606213374, 0.04502514111144202, 0.057544736457722526, 0.026809632744906203, 0.009577735526753324, 0.02500382035837642, 0.06867980145450149, 0.030686691935573305, 0.030441747579191412, 0.009779328280793769, 0.06798362452536821, 0.00594940988646288, 0.04416844993829727, 0.02618611673824489, 0.01868210975745959, 0.06471483635583095, 0.027700357538248812, 0.028547240487698997, 0.008876171877740749, 0.07747292319046599, 0.029360417210097824, 0.020076399136866842, 0.009095171599515846, 0.05850368285817759, 0.01314171526714095, 0.03605517279356718, 0.03737351883734975, 0.0250235589420689, 0.04718220054305025, 0.06730863824486732, 0.03333144841183509, 0.029567580736641372, 0.052836724623505554, 0.040076391837958775, 0.024581854697316885, 0.06056162528693676, 0.052200357163591046, 0.03419606826667275, 0.03270881110802293, 0.07874415176255362, 0.02341806875275714, 0.06299943876053606, 0.06081870863480227, 0.043478783552667925, 0.08654009164976222, 0.03614794210131679, 0.01444205638420369, 0.0035074766450894196, 0.05342008832043835, 0.017967062769457698, 0.025493714160152843, 0.025250057323968837, 0.02800806808019323, 0.010748870853733803, 0.02386560839866953, 0.024280028750321696, 0.012195121596700378, 0.014135749561579099, 0.016868183788444315, 0.024730482704139183, 0.038129230429019244, 0.04221250828621643, 0.047453858823116334, 0.02838095530335392, 0.037396229404423914, 0.01836965116672218, 0.021610658416258435, 0.012204639746674469, 0.024262432640950595, 0.0080370640914355, 0.026535825205168555, 0.024997040097202574, 0.008391004072369208, 0.014882942994258233, 0.05688559736258217, 0.06744281854480505, 0.013534260497960662, 0.05617813978876386, 0.022716468632487313, 0.03617381464157786, 0.05435986949929169, 0.0545708192512393, 0.024374304405812706, 0.01058100807547037, 0.04677794973499008, 0.03982944580327187, 0.06982725845383746, 0.0620006759251867, 0.025636286241933703, 0.009979653022518116, 0.06278567308826105, 0.04285722851221051, 0.04125191304566605, 0.030079240245478492, 0.024086710730833665, 0.009405122155190578, 0.03170735448864954, 0.03849032980256847, 0.03257621179467865, 0.005929702260930623, 0.03000989057389753, 0.03206893901473709, 0.02860623232222029, 0.012953484563955238, 0.051942205123071156, 0.06972624494561128, 0.02107197625030364, 0.03045787296390959, 0.06800189747342042, 0.01881757248858256, 0.0025313469814136624, 0.014242080239845174, 0.09850355290940829, 0.0472493483684957, 0.015732806408777833, 0.03834992394383464, 0.01288993891129004, 0.020427186474470154, 0.028810722420790365, 0.08152776703770671, 0.03442542328100119, 0.0364768687369568, 0.0420247101491051, 0.03842047122972352, 0.037515922981713495, 0.013018712983466685, 0.036680351211024184, 0.059707281844956536, 0.013864115878407444, 0.09126162329422575, 0.03816851760659899, 0.03941864713228174, 0.03172129838328276, 0.015093495803219932, 0.029409655103726045, 0.04223700000771454, 0.02210648261409785, 0.0227719236032239, 0.07864799656506095, 0.049963932883526595, 0.015366304200142622, 0.06453008484095335, 0.008801823947578669, 0.05502713744395545, 0.01724193953642888, 0.027050149660291414, 0.017694349367437617, 0.008681841144737388, 0.024082196776622107, 0.03359283706439393, 0.04458039194079382, 0.007841708770553981, 0.0060635653457471305, 0.030199354514479637, 0.018893894107480134, 0.036737147984760146, 0.04114823968016675, 0.03799861243792942, 0.022425509423815777, 0.061468555192862234, 0.05481428440128054, 0.01879200359274234, 0.03813796317470925, 0.045600389529551776, 0.039085187882717164, 0.05210976595325129, 0.025535466116187826, 0.024612273422202895, 0.026853064075112343, 0.06223196815699339, 0.016495030240288804, 0.09308790708226816, 0.026695189332323413, 0.03154327793579016, 0.037615297827869654, 0.05544205821518387, 0.019367260492539833, 0.0260559364022421, 0.016563411303130642, 0.017457647515194755, 0.010638576682790049, 0.05443172635776656, 0.03593826460252915, 0.028852330188133886, 0.04178892940815006, 0.017764038306527903, 0.04988966044038534, 0.08096093923917838, 0.03686348781255739, 0.02378096285143069, 0.0269612734472113, 0.028501117069806372, 0.07479530865592615, 0.029758557810315063, 0.048375190634812625, 0.020787098411736742, 0.01899942835526807, 0.035943289154342244, 0.026097445782007914, 0.04269188649154135, 0.01111539765926344, 0.03580783660124455, 0.021257806635860885, 0.06967210463647332, 0.02275384234131447, 0.04823380768565195, 0.06772570657942976, 0.054107814095914364, 0.02624721372766154, 0.03212991895686303, 0.09211811090686492, 0.02352786250412464, 0.011348208961343127, 0.04967504320666194, 0.027034010704872862, 0.04187175817787647, 0.010208672162012329, 0.039664470191512785, 0.007575854509403663, 0.030093316454440355, 0.10463191156408616, 0.03522752970457077, 0.030606777473751987, 0.02961055575204747, 0.010793331012661968, 0.036312836288873634, 0.09539928234049252, 0.0922239487990737, 0.09010132162698678, 0.06867896007107836, 0.06833492246057306, 0.13599574752151966, 0.08974694314279727, 0.10300075409135648, 0.09400057060910122, 0.14373020535068853, 0.13854709347443922, 0.25073166298014776, 0.12006473594478198, 0.10109814189906631, 0.10271359128611428, 0.14920162675636156, 0.1647391151636839, 0.1201028289007289, 0.09606827037142855, 0.22058580416653836, 0.1322235677923475, 0.10496472620538302, 0.11926325038075447, 0.1124639291582363, 0.11231967939862184, 0.12617714224117144, 0.1309353012059416, 0.1794126249317612, 0.13599460758268833, 0.17073744615273817, 0.1079259751630681, 0.11306766247642891, 0.21328636870852538, 0.08240704664162227, 0.16751931740769319, 0.18186145781406335, 0.17587654824767793, 0.14457806199789047, 0.12996119633316994, 0.09715465921908617, 0.07553310013775315, 0.12615176503147396, 0.1453921276011637, 0.10161441883870534, 0.10474653648478643, 0.11199510895780154, 0.15080351222838673, 0.16305275208183698, 0.09908127119498593, 0.10548413119145802, 0.06408679791327034, 0.09705507063439914, 0.14631380885839462, 0.16952670897756303, 0.1283780112862587, 0.25293839456779615, 0.15747337575469697, 0.10369997764272348, 0.16142371163836547, 0.14679955850754464, 0.19146389540817055, 0.19758069861148084, 0.2046855573675462, 0.07071995948042188, 0.10545361068631921, 0.1236303560435772, 0.11603323370218277, 0.11933186384184019, 0.19228115012603147, 0.12279129321021692, 0.1286647737558399, 0.10971847469253199, 0.16191400747214044, 0.17197391337582044, 0.1043311237756695, 0.11860827409795352, 0.15152651843215736, 0.15167038142681122, 0.11187928303011827, 0.24782582319208554, 0.14967334430132592, 0.10988154022821359, 0.12663321276860579, 0.09766050707548857, 0.13360558077692986, 0.18982070072421006, 0.15062222124210425, 0.1112557907721826, 0.168668443603175, 0.122266432802592, 0.1047659832984209, 0.16792152582534722, 0.08274946933878319, 0.144438433061753, 0.07476974145642348, 0.10727956877755267, 0.14025913232139178, 0.14975129440426826, 0.11982985426272665, 0.12436788289674691, 0.10207882856151887, 0.10731590432780129, 0.16692542284727097, 0.13397467668567384, 0.1226916571280786, 0.15679630637168884, 0.1166216456996543, 0.20471188452626976, 0.1440570963812726, 0.23541574339781488, 0.14891400933265686, 0.12336134405008384, 0.07507164204227072, 0.13564010017684527, 0.219269758356469, 0.11495428159832954, 0.08651330987257616, 0.0738295769052846, 0.19542782913361276, 0.1750638261437416, 0.11246192747993128, 0.18864615660692963, 0.10720474672104631, 0.12460062040814332, 0.18711710508380616, 0.19905477522739343, 0.09185070704136576, 0.11669870013637201, 0.1366511852081333, 0.07147276015686137, 0.0672763671193804, 0.17235721780785493, 0.18817173849259103, 0.10771010603223528, 0.0855789128690958, 0.11464451679161616, 0.13229380973747798, 0.11755655838974885, 0.1280534951282399, 0.11234049685299397, 0.12488054324473653, 0.1366882739322526, 0.23870020572628292, 0.1971882746687957, 0.11057285884661333, 0.1430446949920484, 0.09535113349556923, 0.19792983201997622, 0.07404091342219285, 0.14290927297302655, 0.0937269242214305, 0.1757055845643793, 0.13622558090303624, 0.11597297979252678, 0.1035062355388488, 0.15552288613149098, 0.10760715191385575, 0.13479524265442575, 0.16019259127123014, 0.22053084283002786, 0.1711357326379844, 0.1748419316219432, 0.09768843557685614, 0.10941075906157494, 0.10552072458501373, 0.11798269195216042, 0.0911516056263021, 0.18748861657721655, 0.13512456284037658, 0.14001703102673801, 0.18127251655927726, 0.09959143453410693, 0.09281588239329201, 0.0861069013231567, 0.12159062549471855, 0.11705985718539783], [0.026283360984442488, 0.06698761654219457, 0.050512626833681545, 0.03455128474161029, 0.024944472292970334, 0.057051400787064006, 0.017046560466821705, 0.006181519328882652, 0.02257877861016563, 0.07545743669782366, 0.018590354859562855, 0.02263648801350168, 0.054084920324385166, 0.03742067362847073, 0.03030661733022758, 0.008230402466974087, 0.03966659400612116, 0.029586986838174716, 0.08799075880753142, 0.006812374964023807, 0.03704346583357879, 0.07891392800956964, 0.03384518423782928, 0.06419297507298843, 0.020555090325485383, 0.010798145218619278, 0.02259876825181501, 0.11781240680388042, 0.033721429628453085, 0.022022564795666506, 0.04906824630286012, 0.01093121272112642, 0.05717852432280779, 0.02823489046256457, 0.03191053840730872, 0.028188970605177537, 0.024329273429300104, 0.04354559211060405, 0.019686027762613127, 0.02592625648581556, 0.018587791693529913, 0.0334953553309398, 0.020988657239026258, 0.04079253805269088, 0.029741071962884495, 0.05644761997142008, 0.028248747843982916, 0.04630123477961336, 0.05427230455513511, 0.036080719637019296, 0.011005776086156922, 0.05169909620391471, 0.04730065240125571, 0.052024219650775194, 0.011739057854616215, 0.03443191346845456, 0.02385669244852449, 0.01869397224592311, 0.024966997959251915, 0.06990218907594681, 0.09278779104351997, 0.0007622704277829533, 0.06567368097603321, 0.027594314389196888, 0.025092104549652765, 0.06252288326088871, 0.061497854334967475, 0.04827212795083012, 0.0323416388460568, 0.061737947165966034, 0.05241564614698291, 0.05423613524596606, 0.0567045506489064, 0.017058970872312784, 0.02440307768327849, 0.030727034235107045, 0.006839853935941521, 0.02988024628055947, 0.0859074934518763, 0.009616188954428902, 0.02824492090647774, 0.023557236285081933, 0.054796218406409025, 0.008639184192621281, 0.04934654404808368, 0.06165154930204153, 0.05219076946377754, 0.010843255922996571, 0.028921092926923717, 0.032400148920714855, 0.05897320873503174, 0.02528730550381754, 0.006211714137212506, 0.03126646957493254, 0.04309409151652029, 0.027242945207815086, 0.03578674094751477, 0.03704664816281625, 0.029580998766635145, 0.07063132923628603, 0.019451405620202422, 0.01547305641828903, 0.026935005660301874, 0.020406794800822223, 0.03280102401705725, 0.014232740205313479, 0.07455704786947795, 0.04558831499889493, 0.013183198353674794, 0.032828514863337786, 0.045420180806624036, 0.01638077851384878, 0.04716775792517832, 0.03961417039058038, 0.020771865300568085, 0.002036552036380661, 0.021049425138958862, 0.1167390186871801, 0.02413564837271614, 0.08429880227361407, 0.03539206087589264, 0.011773539307926382, 0.01632335239888302, 0.013634932194171208, 0.03487347691719021, 0.060534734944147725, 0.029061335937253067, 0.051530615958784304, 0.021000947204551527, 0.036939653368400674, 0.0414068124123982, 0.038418581509696584, 0.05069064388849905, 0.02627430423828108, 0.054624912062925954, 0.037566507767353735, 0.02293550143284457, 0.05514620676902788, 0.008834762581890183, 0.03882621481482472, 0.039099409976708036, 0.017038889628435885, 0.06556267264698233, 0.02467575715854764, 0.02885897983131664, 0.02610126763050045, 0.13106406001108034, 0.027667981239834, 0.013999408975775753, 0.05266109601195369, 0.04478978106219854, 0.02206232864409685, 0.008477139003973986, 0.015381108137911983, 0.04875098029151559, 0.015058619103261402, 0.034985764284751246, 0.021377342453758632, 0.037632176386458535, 0.047345171083829234, 0.04430071337680731, 0.04098763383392777, 0.03927672814045634, 0.04995572939515114, 0.03576307025338922, 0.03778554904939873, 0.016833644659657563, 0.0067045417547758135, 0.022521057332466756, 0.03943394131160208, 0.05003604758530855, 0.02514936272720141, 0.029803514147975614, 0.03357321722432971, 0.08268528671136924, 0.04585481980549438, 0.03951601690745779, 0.039613620777215273, 0.0470499947800168, 0.03449864399486354, 0.012718357761124415, 0.05667654750868678, 0.054050925719950876, 0.038299322194818936, 0.05354180053940841, 0.06575364632798092, 0.04021009037803326, 0.03299721223967416, 0.03419483333293881, 0.032942613919398615, 0.01936238182575575, 0.03737412612619145, 0.048158649754311354, 0.033492342635457, 0.054509822345737896, 0.01881531296697046, 0.05000843121004956, 0.08419558352657727, 0.012938181054778397, 0.08994114665048462, 0.05367955671889441, 0.01842230378783175, 0.024338740689147795, 0.06688526631998164, 0.05783998740038701, 0.0024581258434669246, 0.033455203021211286, 0.039717209325837236, 0.052342038668159924, 0.016635924644236053, 0.01532493731273072, 0.06359937906797443, 0.017608356928186755, 0.04823641326012356, 0.06836004861231361, 0.054775394166686704, 0.02789841342850455, 0.026217315778402344, 0.019750719291291068, 0.018894567553486143, 0.037199695128947496, 0.03534855999584709, 0.029865491536578963, 0.030573882096047913, 0.020958155393600464, 0.05850270576775074, 0.03854506043717265, 0.06074317411652633, 0.03164274099149874, 0.03691231858517442, 0.06633582937398128, 0.06541336101612874, 0.038150943549616, 0.04009129585964339, 0.016944232296996882, 0.01805394239324544, 0.04443843223686729, 0.04764704452827573, 0.038910071565104384, 0.025981728419927613, 0.06961223749177796, 0.08850889493312154, 0.01977243071555027, 0.05098498559423855, 0.028869252851498977, 0.0357643391138741, 0.07009840783263956, 0.040350838896951506, 0.02606987181518759, 0.05065952966521893, 0.040253536975277324, 0.039509143347718885, 0.026807529286348393, 0.02671770821325481, 0.02384181217556553, 0.02373398108673947, 0.058161918339984756, 0.01669444828959448, 0.04421579811189856, 0.04436805458473308, 0.0361334282372679, 0.04819986397134406, 0.004079321149869689, 0.045689532067626715, 0.03179644952927317, 0.00460843597206154, 0.02273371020731117, 0.03722960834524461, 0.008769602864049375, 0.05434561347854989, 0.0024081309592085226, 0.04267580521159938, 0.01057189959101379, 0.057818708542202196, 0.043480578277792246, 0.0443933469775532, 0.021871270146220922, 0.07099578396550246, 0.04193065841017025, 0.03184228456978287, 0.04498292266258171, 0.04507664531203253, 0.05181860318407416, 0.08003038952925376, 0.040595077576914, 0.050412614164607863, 0.08108502972338881, 0.059476104964103015, 0.0036020883874568555, 0.03022992590974484, 0.009914679053638662, 0.044142750424465964, 0.07370425827269043, 0.0654280377285821, 0.04898145149594971, 0.0795292371351804, 0.03520146717450448, 0.045445775147527456, 0.008499995456077158, 0.04595551100958671, 0.012420729401388338, 0.0735239986596363, 0.05444967360900981, 0.05775342668805804, 0.046720040163823535, 0.09406927906508956, 0.03556591511837073, 0.023684224113821983, 0.015803821883829575, 0.03270641927208219, 0.0387723052075931, 0.04786235726039324, 0.03639964805915952, 0.05852933826723269, 0.03492093365639448, 0.03691504968862448, 0.0329683236112552, 0.031082847820860997, 0.04016771586611867, 0.028058503588129367, 0.021948244855073944, 0.021733125505436744, 0.0571447332788791, 0.004007937569570328, 0.03088116685726813, 0.04371610117544021, 0.029631101792412143, 0.043633194374186654, 0.025523257574864795, 0.03652208631059953, 0.025168987656278268, 0.026005714632836834, 0.04779539263940283, 0.03656773136130401, 0.052350126805582216, 0.048346349503844976, 0.0954874511808157, 0.02796224830672145, 0.021972417665113295, 0.021332026492538195, 0.06149389169045857, 0.030063199677637646, 0.06574167018490178, 0.013302321113379938, 0.029860429665339843, 0.03616584864045892, 0.10461063270590135, 0.01823730969668499, 0.024050683914018527, 0.04876977571153215, 0.007877941692381032, 0.04217703786811658, 0.11048251869423048, 0.13345255755952426, 0.11887364914374692, 0.2252176877643381, 0.13061898175094808, 0.12729230097361974, 0.15572232114417212, 0.18657491489180497, 0.1481144915201834, 0.1922053713351488, 0.07463839064751353, 0.0801065686557974, 0.11270852067640849, 0.08520988481385366, 0.09970833933246986, 0.07557362903441701, 0.1462255585938692, 0.1062745430639812, 0.13716018146702222, 0.12593771437449114, 0.157012189073222, 0.14182433619030885, 0.18114967457950115, 0.14999780617654324, 0.18017095566860267, 0.09423730469175748, 0.16308952867984772, 0.23497252432363375, 0.13895722718111106, 0.06538332905620337, 0.14139354787766933, 0.12042871569948536, 0.12432057543524674, 0.191189672265734, 0.12922972201236657, 0.11691317148506641, 0.14971558989158698, 0.10912469548306294, 0.17216171829828195, 0.1326336200748171, 0.05960798503032752, 0.08270206688238041, 0.15428495327276842, 0.10850429734481232, 0.16893411720437662, 0.15767468352402958, 0.07296877380992685, 0.21216228045523167, 0.16774776657777174, 0.0847081420943141, 0.07272866740822792, 0.15505082931901726, 0.09041384807122604, 0.11707562633923121, 0.12162379228643008, 0.19467507595462458, 0.1247491788651262, 0.17425228469073772, 0.11726431335721697, 0.11637890658208302, 0.13391116580792836, 0.1477945079760892, 0.09052738055054631, 0.13654723364327634, 0.16854167969099113, 0.21957144859646047, 0.1721135423119579, 0.15951493834810598, 0.11381618838225092, 0.12526479762579712, 0.1822379090424095, 0.11216626263090543, 0.12484296597540379, 0.1089888663430299, 0.14196627214550972, 0.12310156013284411, 0.1090252154639789, 0.19911462201603822, 0.15263661529336656, 0.10363896377384663, 0.12464156321116857, 0.1362449327217681, 0.11528282825435911, 0.09039849282375403, 0.10591525877160685, 0.11054696595030171, 0.10322325929467167, 0.13398826095674718, 0.13697106018662453, 0.055765475146472454, 0.09928483170058046, 0.13296680791037424, 0.1476420411573989, 0.17162103445402213, 0.08562567750258104, 0.09504035088632788, 0.10669180817369904, 0.22006311507097312, 0.08167297353169747, 0.15133316309324332, 0.12034184964639799, 0.14962261702333177, 0.12727060142372335, 0.10248383932879992, 0.09859809997890677, 0.10314200472618852, 0.16315320240599768, 0.15712127036281995, 0.10277018110666956, 0.17566594454858983, 0.27978645105447086, 0.08605603155280862, 0.08927158865013293, 0.11501574330031872, 0.10387059527316264, 0.15633233769663743, 0.1958950547767537, 0.24108650482126645, 0.14339663753552095, 0.20471822204334394, 0.09667133193995271, 0.11913313450557844, 0.10545619590474026, 0.09463245634521757, 0.08071657163756234, 0.16649819005812916, 0.19795868332896913, 0.09984590552215065, 0.12896855388368877, 0.15656757221690246, 0.11254712433687278, 0.1110905674951417, 0.1222959083638021, 0.08176154949303184, 0.13319060233022484, 0.1555764496858631, 0.1263718410794224, 0.1370334175548383, 0.1283011468393462, 0.11640298100454466, 0.1420756248491151, 0.14887358221624578, 0.13736332128090517, 0.0958906774009977, 0.08580635780734674, 0.1426899161721979, 0.2154562829860619, 0.0843662079423666, 0.12819574320954935, 0.22813199566943304, 0.13509223743208817, 0.0930033480482442, 0.13813629480344908, 0.09924142581543752, 0.11927152850798198, 0.24891671751226696, 0.09375399776867457, 0.10549719299056701, 0.20991202763148717, 0.11702263275427477, 0.15528562957687037, 0.12119280041328498, 0.08739579216177974, 0.10898829637361424, 0.17539820820093155, 0.19848460225122316, 0.17774033466620104, 0.18382866654012883, 0.1637548729777336, 0.2126184188361679, 0.1395075326519353, 0.06632616703531571, 0.08536418367709432, 0.10394624514239174, 0.22670929772513254, 0.1422524375042745], [0.06362075292106185, 0.028483800856130462, 0.03873527755162545, 0.035653473277177126, 0.0781787760289652, 0.02319473064770656, 0.06970204160149608, 0.06866420193442277, 0.028699150907674005, 0.015018456615507603, 0.03676610107400587, 0.009658683906309307, 0.03365586618227618, 0.04908571857959032, 0.05404038807111127, 0.05273747530632785, 0.02332444449088403, 0.05704233555921486, 0.02973941633743899, 0.07671546097844839, 0.045599527790078094, 0.06533095293811389, 0.03187462694144674, 0.05937194983874049, 0.04300737474113703, 0.059684415214828083, 0.04755972046405077, 0.04532165752191629, 0.012984714138188531, 0.05498214039419379, 0.0460027574029352, 0.017222993142370666, 0.003866375656798482, 0.013719332620634564, 0.011961306062793093, 0.024272444425150752, 0.025035265367478132, 0.026127026516145894, 0.056745866646191905, 0.04692673210852912, 0.05460659840277263, 0.03901210626853364, 0.07481962056564433, 0.030387189971016984, 0.03749166535479682, 0.037311843396829705, 0.014228480701733912, 0.0794848609449608, 0.04747899854555726, 0.06597182247787714, 0.02501006966589817, 0.06202213120247636, 0.02008438210136124, 0.05424994004092046, 0.034518833804343424, 0.03400538296305707, 0.022357007921008126, 0.05105901715744819, 0.002443828898581809, 0.057201309528734, 0.07514300357018198, 0.046206874307245016, 0.03681627534595983, 0.024560363796938742, 0.08119067084044218, 0.0320875139108726, 0.04555011687002011, 0.024794461771047542, 0.12045226086463247, 0.06320548948964902, 0.029816206145499433, 0.005244037959658141, 0.008227972463438553, 0.04669654928147793, 0.06071951360042606, 0.05613838102934616, 0.02400464192032814, 0.014680946511881692, 0.0012871824146714061, 0.010463579956974303, 0.01910446896882994, 0.04356166999787092, 0.026601361509944712, 0.026113521972937242, 0.02153902208166463, 0.06785658241382667, 0.061451028633330546, 0.02239352328303669, 0.024907101976818273, 0.06453970646751778, 0.03823492243619902, 0.05874520061271531, 0.0343210951292089, 0.03630940629435437, 0.03854361515758293, 0.017072455059470873, 0.032865929284266064, 0.03136987831177456, 0.07781622798315116, 0.012707861672554697, 0.061041668456579955, 0.0036802420509047806, 0.04011612684865083, 0.0043927508938525405, 0.035568015184253454, 0.019775078698460544, 0.024642206994550567, 0.01880947926214763, 0.06076609502945628, 0.04699992568099073, 0.10002718972308294, 0.02991846137280975, 0.07755157218447753, 0.01176869117521814, 0.03541870355339987, 0.06076118243592126, 0.07698351623756544, 0.01834754110313952, 0.05480367211358888, 0.07218167997364487, 0.05180645401456526, 0.025776824414996163, 0.0490527926678104, 0.04095295051644955, 0.024977523733728697, 0.07478110691798584, 0.02680500004706638, 0.007674297218077949, 0.03647642768919468, 0.040192458645573685, 0.04767387719558818, 0.012421942282734173, 0.029497552530041764, 0.012421180627175739, 0.11651985187615667, 0.020104882340612154, 0.08150761454765286, 0.01427230388591332, 0.021538835484534502, 0.052647053729742765, 0.04624255167852555, 0.026835432342652763, 0.016194069425442388, 0.07580361169363771, 0.026443758181163242, 0.03269033459946513, 0.02065345415446375, 0.06111085867243154, 0.13861976457493647, 0.028425804771749035, 0.010169851477257907, 0.06418256634580237, 0.01182898155613137, 0.02361325783255909, 0.014667779539844819, 0.0815518211041178, 0.05072526953050068, 0.020449549292347262, 0.023815776786899993, 0.03278209628271205, 0.014219862458828305, 0.015188378747552633, 0.015347166119941642, 0.014614711316036326, 0.06692666374146938, 0.04429854206474764, 0.04379274509847164, 0.07008153945207596, 0.09556926214801413, 0.037693739868700504, 0.027526140279535736, 0.025005357240193656, 0.06288733799010515, 0.020195091875003915, 0.02467758920309799, 0.09951655819479908, 0.007304683078213462, 0.025869736215099692, 0.05003117909654975, 0.033332028559276035, 0.040264142477618795, 0.08064844672169004, 0.08875387321625437, 0.07166689581104688, 0.026141423332904066, 0.016274389311937348, 0.02525559247338346, 0.061491123267582486, 0.02173980398635779, 0.043385149112769535, 0.049880089703947306, 0.03978277616468923, 0.013591140392236412, 0.06019460569534983, 0.012785659953286605, 0.032436891591974666, 0.015558657003566623, 0.015692564193159342, 0.014654848358726926, 0.020725051473293985, 0.06742109863885812, 0.027061269152909517, 0.0458854319128607, 0.038913589769176075, 0.015841290587559342, 0.02739276913260775, 0.03469917144892471, 0.02370313827746681, 0.02479694690555334, 0.06648384500294924, 0.03787907153101904, 0.032288913282432725, 0.00832627946510911, 0.0621457127854228, 0.04331200643043433, 0.022856133191713264, 0.021934959139408808, 0.043471689469047954, 0.009649181871541908, 0.0374870072118938, 0.03190161906448858, 0.027870240654530268, 0.05653612468657749, 0.0638601943584425, 0.0157528537259038, 0.034775452355721166, 0.07436167728155851, 0.04086953142125692, 0.0662675416097045, 0.03477093331249697, 0.03370756037267191, 0.05638827869136419, 0.054631863654192, 0.09331016801297665, 0.029026425310543606, 0.014712715521454811, 0.04216323646583727, 0.01942324641692851, 0.006918712427640068, 0.05887423761721168, 0.024844712378191094, 0.035078733760331354, 0.039809171176914654, 0.012864835660106369, 0.04795707735632147, 0.0353074882711683, 0.08774645227406706, 0.038301004961665185, 0.012339396801378046, 0.057431387182857306, 0.03732094594410487, 0.01772313621560378, 0.04705150452043329, 0.026039234262758067, 0.08423040594373431, 0.024164379241743257, 0.05062326196847217, 0.056590967279459746, 0.004766051599290222, 0.01802835483769221, 0.055088113993406296, 0.03286252643114754, 0.03766132625085967, 0.023273364374680177, 0.015908017721293227, 0.049446088527994494, 0.0031402081159675227, 0.049078302191836495, 0.016865985334983895, 0.04968024078490479, 0.026920898917264173, 0.014653498074039817, 0.009467688172922602, 0.09355407421078, 0.04160403200824346, 0.04234007626239743, 0.05053141207567283, 0.06658415283475604, 0.026463442482054234, 0.02320338027285678, 0.024418643276606287, 0.01389290951192379, 0.030038283871752874, 0.021477616358814493, 0.022108477507052676, 0.026970352245760814, 0.05920854503554957, 0.05566092647079911, 0.051058874665094275, 0.050434374782655916, 0.06286861042359046, 0.019063027442565987, 0.05831452765102897, 0.008236945240891405, 0.01393057923165283, 0.058606935531965325, 0.037154290958174636, 0.07090774404683284, 0.038179743968482525, 0.09336077315466744, 0.025017913530713747, 0.07271649448999337, 0.035358938188957315, 0.017048886145598123, 0.032587275308157714, 0.022980452681492482, 0.0856042697227427, 0.020760262351749197, 0.004559405879782779, 0.030027383206678287, 0.026893582793750932, 0.027387530842263783, 0.028431708026411276, 0.015152904936777694, 0.015062361223889249, 0.048415957018733025, 0.04987409145438245, 0.052540177678955455, 0.020523747096636465, 0.04227928291740162, 0.016256226625825678, 0.034111400667045794, 0.017363882457305278, 0.025135193219674484, 0.0032052164356822944, 0.04758416808077267, 0.01617137751808124, 0.036051271217209954, 0.04029519563274724, 0.04499616427347064, 0.06841620417045695, 0.04217216259400759, 0.06248200831136533, 0.03779632418549486, 0.02989542850160173, 0.02689960988105408, 0.03477922161774976, 0.01735958393796214, 0.029114567009466033, 0.06731896554785115, 0.03563945474369185, 0.05435688055253454, 0.04354784145419087, 0.05525012440713389, 0.05047152118225183, 0.012305068866615849, 0.04231234792886036, 0.05166178695591433, 0.028335347572075467, 0.04173126410959022, 0.060559650750032494, 0.07417291562472071, 0.10983869074178593, 0.09856256509998015, 0.2142086877886738, 0.15812261163124017, 0.23875001019665174, 0.14618050386863096, 0.14383816027215549, 0.14098790607282094, 0.16771673038601875, 0.09282830636948347, 0.0710416054353118, 0.1381347341729062, 0.12297915241547994, 0.2082162464835814, 0.18231237147535595, 0.07852037091340337, 0.07980791146733932, 0.12993020085351809, 0.0743948712146708, 0.09731786724712167, 0.09612421558371612, 0.09724283484475953, 0.1317625575299774, 0.09761697226869208, 0.11091768355774027, 0.16281654047114508, 0.1583681870251894, 0.0953590791406376, 0.1273398527077266, 0.13244219177535602, 0.14227732616875852, 0.07302195738468852, 0.09977545323116438, 0.185034273990563, 0.1882891250508172, 0.14915163229618753, 0.10600172448903322, 0.11285946757665702, 0.1788577325642109, 0.11744400300085545, 0.07636907563677856, 0.1210084967315197, 0.1025788885142122, 0.07617064485592501, 0.0976911632876311, 0.11682380842311041, 0.06684236933610269, 0.2221509808940547, 0.12835560605994292, 0.19697653103087628, 0.18798089373324597, 0.09503990305321557, 0.21577148964362486, 0.17936877799885614, 0.09901123959571123, 0.14688383255686077, 0.07168969458767346, 0.10807876767856733, 0.17103620512144907, 0.09089217454727207, 0.11833691437329565, 0.09011582870568548, 0.14303629472851753, 0.13342570114348615, 0.20985132588871888, 0.11336397871907268, 0.17383647843130998, 0.07184964564761945, 0.25709396015320507, 0.18088086614651339, 0.20343638796891483, 0.13508823407547815, 0.06893906289977686, 0.12389256911618368, 0.16087237479431288, 0.16806191472070559, 0.13916544243693352, 0.11815812039588179, 0.1574863629149539, 0.07702603324183396, 0.11680907064250537, 0.143156748265028, 0.06903090261455093, 0.13925427624157496, 0.13590307320867265, 0.11256169926907335, 0.10268496389367751, 0.11461833891059671, 0.16736782767942973, 0.17240848791386398, 0.13985430475856575, 0.12962528078683785, 0.1015476645635707, 0.1181652450135776, 0.10630378792328493, 0.15753079338797502, 0.11029195213424307, 0.13862317082073006, 0.2091473186654704, 0.07995181517409426, 0.14349685715777533, 0.10941303215388741, 0.1232107092759439, 0.07226528905864273, 0.1709461770951748, 0.1543237790465355, 0.07738232519477606, 0.0829973721078464, 0.1493077767746789, 0.10663131677678653, 0.20712848699518613, 0.14154935308865138, 0.160872524072017, 0.10327181526060615, 0.12768083012529782, 0.21225209135029996, 0.1515377956841673, 0.11930819654038974, 0.10946399013378791, 0.14337075820990972, 0.10413263192666428, 0.10509582595633608, 0.13482831445123467, 0.19016285879271372, 0.06637405125158173, 0.14437695778906345, 0.1522149329206773, 0.08859746410910573, 0.07249163477016346, 0.07713218326015131, 0.30674185178109575, 0.14999491561736378, 0.11292611328618866, 0.09502831367509705, 0.16312133840152196, 0.0922577330576522, 0.16906815501196043, 0.10723390337079763, 0.13871880354625837, 0.09177195626710143, 0.09636743646115065, 0.1285411175340414, 0.07310355122068099, 0.15050465826477322, 0.05904028192162514, 0.12942824778812273, 0.09757277249757733, 0.08338857468749795, 0.21283671712236746, 0.08982695599219628, 0.08248895938907351, 0.16552435659936496, 0.1600691114685365, 0.13323923972036156, 0.07663285612527813, 0.21658064265336308, 0.10583780399922814, 0.15168160439601966, 0.09497228703860726, 0.1347185546266181, 0.11030043382197618, 0.0667949193822486, 0.09111921236451183, 0.11878032343728201, 0.10511681304446288, 0.18319458913590225, 0.14192132598587445, 0.1344529760203191, 0.24441773178321974, 0.058313747335757525, 0.15007548486547811, 0.1762644802885396, 0.1879189841981445, 0.10882736822324139, 0.12210606783628464, 0.16995113263172762], [0.04363389665793095, 0.023682283503668647, 0.031125707485313927, 0.04783964669331908, 0.03608616488054395, 0.04559100539024387, 0.039543046349925656, 0.02099068945140711, 0.013964299877573336, 0.04736379687009113, 0.041342504256005795, 0.026008625548066835, 0.06080560612359217, 0.08469012020421879, 0.09675501566380262, 0.06643159780651331, 0.03475085206862007, 0.07312318802412067, 0.019744020454319458, 0.08538044137614113, 0.024186455378574983, 0.03381703181990555, 0.07623259510312762, 0.047982502063470225, 0.06266681410904441, 0.018738021042996218, 0.04097620051886354, 0.034461650265646834, 0.04646664804645947, 0.028528455245707716, 0.028995436616241932, 0.03529454521568758, 0.019882005639374256, 0.030787328856864145, 0.048688941834760566, 0.03151300170325807, 0.02463613580247121, 0.05999994756919997, 0.06352085899561644, 0.08054001004035984, 0.026116256469062397, 0.038901430421641896, 0.017939851818872348, 0.054726549823369296, 0.07710762029247624, 0.0669706260253276, 0.026876278454437852, 0.06282422066267047, 0.017159792694396207, 0.018321958636598926, 0.06036677038563149, 0.015245587731312429, 0.03508183805804167, 0.02946603118575045, 0.015507062897086143, 0.04864995999793921, 0.013363889684634549, 0.03913653941292848, 0.06880790208067213, 0.010321398880997939, 0.029339531902223825, 0.05058396461286715, 0.024260152763287936, 0.02306190911414368, 0.047443629907710214, 0.06591302063316107, 0.02878019173762628, 0.05659952699872, 0.03955863229930401, 0.06426351557352714, 0.024567505378010016, 0.048743153390075476, 0.07163243301744972, 0.06856027751096658, 0.01209176714265985, 0.03298679333446281, 0.018673892698383758, 0.08732290393007652, 0.02493590918103499, 0.018735922673451047, 0.04767510195129684, 0.03715520019509962, 0.044271217459546666, 0.031532845459878445, 0.025054686736049395, 0.014983293234503694, 0.07756449827658278, 0.07511436260704484, 0.05411366306777511, 0.04156167445970433, 0.04543297119172556, 0.0317244400004191, 0.043959101528993676, 0.0934212374101792, 0.01853384985588491, 0.12008860680673804, 0.06241964415780135, 0.005450933040784938, 0.012395666014137012, 0.03765702433884144, 0.013285207612040852, 0.056670756212302616, 0.04519988762746964, 0.027780422974111776, 0.05256766852523599, 0.021103477238544395, 0.04706674102427704, 0.03217680572665163, 0.041044420429638455, 0.05468822277284094, 0.035760688595473766, 0.03975430822798184, 0.03611286523352776, 0.015884815216330544, 0.044118713321430345, 0.0850778351138745, 0.020912907285881892, 0.02827103771934552, 0.046710516924836805, 0.027809123309063058, 0.04202459819082703, 0.005631599774850267, 0.02660256251692772, 0.035892029226358445, 0.019235967359106456, 0.038250426961375136, 0.06393413431942463, 0.04375451982819608, 0.05708859807678631, 0.03943966475448438, 0.04343285012458052, 0.030586591056947197, 0.06362192678664412, 0.05438780817868454, 0.04731485074652093, 0.07373190857470036, 0.022912039388237253, 0.026478080178744028, 0.06313834844955377, 0.004444770781057221, 0.032139211493943415, 0.041034744520272524, 0.039175171804215224, 0.022527191289035336, 0.046830671905939064, 0.04983179158131991, 0.06750585444803749, 0.01014170075567173, 0.08073583524674177, 0.0018309580461521233, 0.0395570784541113, 0.07780826876738242, 0.015784639698852385, 0.07041434730802264, 0.029362303537449667, 0.008135901198589375, 0.02110799458543105, 0.03309576945113284, 0.039713107581649504, 0.010741358622908592, 0.01801245506586773, 0.054019143139677386, 0.013030430435069969, 0.004297083817488913, 0.03231315394597394, 0.041287281683513095, 0.07084668946585485, 0.08558530466897146, 0.08938070386648178, 0.037789169033723216, 0.03230734229353922, 0.007054335038576807, 0.021326228410803845, 0.025291290200714554, 0.05805329166884933, 0.04839996394834348, 0.036958757521850724, 0.04259096458554268, 0.018769902010847415, 0.051283476541617086, 0.018782061358381594, 0.05146694223263434, 0.021210606043626155, 0.043100181368312666, 0.04501099704897829, 0.01827160455286503, 0.06370422629905598, 0.0490492778564138, 0.06288985535502434, 0.05847829207777977, 0.021364599566108415, 0.03182309899213059, 0.053508966229856014, 0.011660134053922125, 0.04789597188521709, 0.007555165976685072, 0.03996408411434718, 0.03810417213078056, 0.03935622191056609, 0.030008197629026005, 0.02598850698476391, 0.017729317669623663, 0.0036811589213487294, 0.021024797710457017, 0.0174624702028398, 0.016267804129581367, 0.015113315811114652, 0.03360963419878057, 0.02908303209447435, 0.017320132215640376, 0.057533248859856806, 0.03422458030815635, 0.014511495961674621, 0.03478717744084341, 0.08434822676437241, 0.007141794809805495, 0.02500215794758073, 0.03520475806934493, 0.010738061790886735, 0.055923794329698594, 0.07206644437142781, 0.03293933320258345, 0.036657772958278656, 0.04942226516348975, 0.0500383308556463, 0.028199223269309317, 0.05437606952286192, 0.0186116930895618, 0.05367938369246466, 0.01841804089157709, 0.035882224395338974, 0.05664614913985133, 0.016370739588247876, 0.015428536039377962, 0.03739050256886652, 0.02425419183314911, 0.04266449064016342, 0.019595000593523895, 0.011416638369805046, 0.06613241814609085, 0.043626195285469294, 0.04671474080532789, 0.04615553295505898, 0.012904269570883895, 0.12500748357602529, 0.02593684841745666, 0.0663900375366211, 0.03225424353565488, 0.05920448061078787, 0.04270867005522762, 0.045721972826868296, 0.08419673025075879, 0.0317001959442028, 0.016102129626753073, 0.016230885039216707, 0.0324961141284023, 0.051444418262690306, 0.058157969266176224, 0.023748744312407713, 0.03473350532086832, 0.018052439438179135, 0.09690179635903665, 0.07943284445043121, 0.03013749247682946, 0.01784825468036745, 0.017129630116479735, 0.029078988025763204, 0.036499355387474806, 0.04161643562838435, 0.07142338994890451, 0.05395687058834093, 0.042514761710273366, 0.05544061293559415, 0.007186638341019196, 0.01219917499526803, 0.02583789935202471, 0.03276650354798351, 0.013374798831396868, 0.00445015453234581, 0.04461672409836735, 0.063695785323424, 0.03177678219175764, 0.041188096827162166, 0.021242400498262475, 0.013915145952653672, 0.040727737958409956, 0.03307823949892606, 0.04120726204876389, 0.0656305125781468, 0.022597294134487, 0.02988449051710112, 0.049334686648632796, 0.024603971546249728, 0.043950847150491815, 0.10781116703791277, 0.016197080424587642, 0.052415381518325636, 0.04713393973984888, 0.05137740953692368, 0.025468350521155765, 0.0225315780179309, 0.03138265173350062, 0.03289573732763529, 0.04072649963200092, 0.03296345851517149, 0.05700796776052032, 0.06274650804698467, 0.03574416966044477, 0.03220642038754054, 0.006130861176643521, 0.03430561774543353, 0.013418680539221635, 0.014101443679205008, 0.009864855075388082, 0.020823574758001735, 0.02478377484450383, 0.03141606958316905, 0.041148148077939234, 0.0223455491608807, 0.05133222249735679, 0.06775679026863404, 0.019574220458577787, 0.021639957558363676, 0.02815091666499419, 0.03593675486211266, 0.05482303411034601, 0.0035329015642803696, 0.025937420083209872, 0.04928693135402032, 0.023872268219877566, 0.044882821783955605, 0.042321922057973485, 0.03573603741824627, 0.04541575336562736, 0.010112732399388083, 0.06496413012168237, 0.02448524657769927, 0.026506526063063314, 0.031596054389540634, 0.038562407184924395, 0.03871781545292054, 0.050851975767208, 0.036387485318950245, 0.024276773478569727, 0.020756869676655958, 0.050471266731619835, 0.02347193595155009, 0.029093081198100532, 0.026311257255396674, 0.05393860103296382, 0.07034012914768287, 0.10827801270144326, 0.1261335395808731, 0.11305137085063116, 0.1067737073504499, 0.17431371925132616, 0.12069746984967164, 0.09464051734123911, 0.11795678548514843, 0.12091916081096445, 0.22436163441411086, 0.13353871793619224, 0.16565943935087749, 0.14019735849329404, 0.18773282133042812, 0.18390169047883578, 0.11077886886362519, 0.1195357364735433, 0.2747066393494606, 0.2439656646123954, 0.15617889378752026, 0.13596201076039247, 0.08402684543813978, 0.1434313649577754, 0.15728802712900297, 0.11918815012489047, 0.14618080242403916, 0.07812753984970705, 0.15745061769017152, 0.1256378154669489, 0.10846176676984344, 0.0852959705516696, 0.08094823706362929, 0.09680094569921494, 0.22860485315322876, 0.07750002387911081, 0.13134010162736687, 0.12284687879894461, 0.085815972648561, 0.15911050433559076, 0.1603182288152831, 0.14007714922939027, 0.13567896666271345, 0.1318513099104166, 0.11883780892406191, 0.15554449068648474, 0.21746614442339965, 0.1437665612569877, 0.08141016334827457, 0.1799834900136505, 0.10980690816151244, 0.19121789932250977, 0.16641528664955071, 0.12780853041580745, 0.19125730863639287, 0.1288872111056532, 0.14290205336042813, 0.12817314799342835, 0.0723845280174698, 0.1445330208433526, 0.21342218427785806, 0.13303327720080102, 0.13497356165732655, 0.14810523630252906, 0.08453145836080823, 0.10675721216414656, 0.08853738661855459, 0.15916362005685056, 0.158050306939653, 0.21737733776015894, 0.19625072926282883, 0.15079842321574688, 0.18278555465596064, 0.10436130501329899, 0.15212756475167616, 0.10053081198462419, 0.1269035004079342, 0.11820812842675618, 0.13925765534596785, 0.13947181456855365, 0.06133970817817109, 0.15348433623356478, 0.24670903597559246, 0.12357957448278155, 0.08556691636996609, 0.12260937797171728, 0.10932711604982615, 0.11891250205891472, 0.28436335974505966, 0.1818739699998072, 0.11309967575860874, 0.07643032699291195, 0.08820060254739863, 0.09712842705526523, 0.08154448614056621, 0.14483844302594662, 0.10989250535411493, 0.26508650556206703, 0.15209253877401352, 0.13644561623888357, 0.07946424705109426, 0.1460881552525929, 0.09192471485584974, 0.1558953204325267, 0.14217827362673624, 0.12385577894747257, 0.1377610649381365, 0.09215954904045377, 0.13478501034634455, 0.13822438221957, 0.14487483964434691, 0.23987290422831262, 0.10202058990086828, 0.0729291337941374, 0.16269071293728693, 0.12286426286612238, 0.08111805402274642, 0.2544307644878115, 0.08772830146231822, 0.11919220776430198, 0.17889178145144666, 0.13293531031480857, 0.16113906619804247, 0.12060008650379521, 0.09346541003989321, 0.13342966378799506, 0.09397698473185301, 0.1253888609686068, 0.17838914985103266, 0.10832065862736531, 0.1379335213984762, 0.13380539576922143, 0.1711143994969981, 0.1707494290811675, 0.10171121185911552, 0.13350844170366014, 0.15287734594728264, 0.16400044837168284, 0.13334435836545058, 0.08843946044466325, 0.16539312792675837, 0.09974426097635712, 0.10494785782481943, 0.15084984259946005, 0.11098557777170624, 0.10823780950158834, 0.13563307055405208, 0.1273609415761062, 0.12430515911962305, 0.09002909157425165, 0.1274169071444443, 0.13365237255181583, 0.07976660904075418, 0.17644720976906164, 0.1578451179500137, 0.25560251304081505, 0.14152822350817068, 0.09436632812555347, 0.07533608749508858, 0.244544617831707, 0.13097730252359593, 0.13200951713536466, 0.11110364965030126, 0.1267085980091776, 0.10373695101588964, 0.10441929940134287, 0.09509065068726029, 0.10774239751377276, 0.12793875485658646, 0.14753632540149347, 0.27980941267950193, 0.14756430818566255, 0.14080836570688657, 0.15391451386468752, 0.09464206440108162, 0.10246357827314309, 0.14205700584820338, 0.14054514840245247], [0.018232548077191626, 0.02487670530432037, 0.04309412544327123, 0.010552833605158542, 0.010246950866920608, 0.14027175307273865, 0.011751332553103566, 0.07000935011144195, 0.04548027526055064, 0.08527672729854073, 0.01402556904525097, 0.06308790615626744, 0.036229345947504044, 0.06036750320345163, 0.05079643767593162, 0.01155013419754271, 0.03164901744042124, 0.0900110968255571, 0.052809766427214654, 0.038410167675465345, 0.021563523981188024, 0.05496874611292567, 0.02422090120879667, 0.03497813076579145, 0.02175795310176909, 0.028144833598552004, 0.011417119281499513, 0.026259434143347398, 0.08050953703267233, 0.015558012395298906, 0.0470469311944076, 0.0267106344856854, 0.05949912765728576, 0.021773559407198002, 0.029482458518551927, 0.019115971833733574, 0.03323880463306393, 0.015461076882534792, 0.030390443546431403, 0.041822242084890604, 0.019489205109753778, 0.015072815752189075, 0.050973246938415935, 0.05453278736344405, 0.010411207231559923, 0.019677432420264398, 0.029441050919038907, 0.04856240183913282, 0.06674067729285785, 0.07852365502289363, 0.025617981063468114, 0.05076116742566228, 0.019059035960318785, 0.028783150150307586, 0.01060346928092518, 0.012193868851422198, 0.04895784865532603, 0.009443022576825959, 0.03470213325428111, 0.009763949284596103, 0.025253848638385534, 0.060886453571064134, 0.031082783360034227, 0.022237816459632347, 0.024117750315261737, 0.0380577637281801, 0.07347994138087545, 0.02506020152941346, 0.07429919777704136, 0.07347485236823559, 0.032748203458530564, 0.050369975024036, 0.022516256697209816, 0.035055069851555994, 0.034140947474432845, 0.08400970564356872, 0.011976226199684399, 0.036832197170172415, 0.12327956700963633, 0.026025339561913694, 0.020790796427588378, 0.05501301713021738, 0.0571067285324846, 0.04754380542518837, 0.0544112753123045, 0.039014833979308605, 0.07664802816829511, 0.023499243593375598, 0.019232026766985655, 0.046447241944926124, 0.09101028035261802, 0.025658404787204096, 0.06761551249240126, 0.03309579659253359, 0.050687397098434825, 0.016656572464853525, 0.060977804740624766, 0.012654881658298629, 0.045548220364643, 0.007614052638278476, 0.012305860208081347, 0.04710177717996495, 0.05097404421706285, 0.11061531478273016, 0.04764723791075604, 0.013107427196311099, 0.017674692207947373, 0.030553899239748716, 0.018679977461163486, 0.024189625833449618, 0.06454280737255301, 0.07513372799647705, 0.04122428988505687, 0.029883842516158308, 0.039097930770367384, 0.049958731912608655, 0.06185824463942221, 0.047242708903338225, 0.08423722522067172, 0.01161094959492662, 0.028660701720842292, 0.02704086390856121, 0.06875093228050641, 0.01908110870447542, 0.02429969948051231, 0.07324269161160503, 0.02302668466498809, 0.009071786738266903, 0.05589864442923239, 0.014656760131141968, 0.011904713697731495, 0.013230214893285717, 0.06303428831909384, 0.04061023604923061, 0.042942231986671686, 0.046365346160850356, 0.08042186352291278, 0.04182177728840283, 0.03631909238174558, 0.014700052361669285, 0.03949661759127464, 0.036469479490603716, 0.021892080815242868, 0.06568714311080319, 0.05770783592015505, 0.018271887841235315, 0.048825805740697045, 0.06917451455124787, 0.021138389561591402, 0.037240179920835156, 0.01433214558554547, 0.04026776585461838, 0.014961503778717347, 0.015420736279338598, 0.04121148253657988, 0.07771492270486695, 0.0208963374607265, 0.015153710697112339, 0.008023693558893033, 0.06987791109297957, 0.028808442543127706, 0.048880465129124265, 0.026048592957002775, 0.034544933653835735, 0.037490535593990765, 0.016647797310724854, 0.020123538660949895, 0.052676868558462174, 0.014856651458623154, 0.0229029046105487, 0.02717161930299231, 0.0625462791483317, 0.02008701820990869, 0.061842509412339756, 0.04678204130115254, 0.04725967227880444, 0.0426576238657747, 0.01623524971572416, 0.061390415100114684, 0.0286619536179517, 0.09482466495995011, 0.08633423769580466, 0.040778509341180325, 0.04011206581656422, 0.05664337393162506, 0.021071733674034476, 0.00286375916662759, 0.049137887744499106, 0.023536347584532838, 0.008606292207592299, 0.04355794484061854, 0.05762298511607306, 0.016213271966470138, 0.04173765590946589, 0.026922298395740132, 0.02599463245964476, 0.02358858460294349, 0.027720406551712325, 0.06715934018471412, 0.02608179028279015, 0.008031186281836458, 0.05409536637099726, 0.013826849887014499, 0.028194334424499954, 0.03676677621634943, 0.012940878231477524, 0.0011493046289875305, 0.05274982125099216, 0.06625496157045875, 0.12049139876450811, 0.027428068220615387, 0.06080209809754576, 0.020724303388435925, 0.06962314154952765, 0.04772689452927027, 0.020966998401231, 0.05965464109820979, 0.022101810900494456, 0.090506447745221, 0.04239356857059257, 0.018076529127678702, 0.04538521928978818, 0.04290993371978402, 0.032449760008603334, 0.06859130013201918, 0.056774717955184836, 0.03628106388662543, 0.03148736325757844, 0.024689775692032914, 0.0740570489849363, 0.0395206343382597, 0.010950286340500628, 0.05103803685467158, 0.023835398323301758, 0.036158282975000997, 0.030093974633408443, 0.052611824191574535, 0.02689496361251388, 0.059083830299121995, 0.04233910595732076, 0.05368787895089813, 0.04314287818436112, 0.07898435315915517, 0.030094561566199576, 0.030946509779563973, 0.02353151811153761, 0.05477479027052011, 0.06738856288471393, 0.04068869166076183, 0.059417031705379486, 0.01951242457809193, 0.08128736886594977, 0.04313251695462635, 0.030746148566582372, 0.05604974739253521, 0.07479587862534182, 0.010127906986911381, 0.01299842054556523, 0.06398056647075073, 0.04928038349109037, 0.03505102239016976, 0.06498874737215893, 0.021509147881131088, 0.05950199786041464, 0.014877906568082315, 0.013624713456790363, 0.04988268170771854, 0.07537410581218344, 0.036606190726161, 0.01318783444418971, 0.04275576377819691, 0.029902756679803133, 0.03165110732827868, 0.01195622468367219, 0.037739144039473364, 0.0651696448081306, 0.018303824788225547, 0.043999097775667906, 0.045930954827261825, 0.0868265148518341, 0.05722965193646295, 0.04040938289836049, 0.019741099361064177, 0.007933174442899014, 0.09678776176380259, 0.029494645007486855, 0.03774044004135898, 0.0495341420173645, 0.037917575000652244, 0.03270097742123263, 0.03988713824323245, 0.01608070488353925, 0.10224221979400941, 0.019950598744409423, 0.07370429219944136, 0.005814705842307636, 0.03352149249985814, 0.028400888965864266, 0.057057874011141915, 0.09408650028386287, 0.03203195207087057, 0.05670431316164987, 0.008511929190717638, 0.01836955956449466, 0.07624591474554368, 0.018226273324606673, 0.006327050671513591, 0.01744003953146083, 0.027545488705592494, 0.045192956392254145, 0.03922456576089774, 0.027453258833182708, 0.13451253782425607, 0.06882202917976038, 0.05359308760879295, 0.025234328882236565, 0.00587391056719103, 0.03887359691517694, 0.010629608994349837, 0.013622265641710587, 0.0352118012628385, 0.053000662076686106, 0.04845011107889669, 0.07874037232249975, 0.04449066246992775, 0.022632789997650043, 0.02499387303500303, 0.0793393694662622, 0.023391071540702666, 0.07468965396817241, 0.018584171709205424, 0.02760920314384358, 0.03887984961537378, 0.012962207131619965, 0.030828858592680523, 0.07165244980049984, 0.12145859615078994, 0.019475726011608328, 0.008833520862806057, 0.02550323061378939, 0.0029181925180767265, 0.003526044119748154, 0.012760721246844955, 0.07824309436338288, 0.014566796565694469, 0.016747099214366505, 0.04240400783185448, 0.07024738019598381, 0.05173756913947208, 0.06153410167566367, 0.07157929694013936, 0.015378204008032168, 0.1535312637154545, 0.08211174141615629, 0.1748157808823245, 0.13415651049997124, 0.12062266814921584, 0.2151698869253908, 0.12611783828054154, 0.15039074580584252, 0.1620796107287918, 0.1503656128687518, 0.1384180225431919, 0.18246319623930113, 0.15889976492949895, 0.20446947110550745, 0.13060543819197587, 0.1012808849502887, 0.16977526992559433, 0.14123207011393138, 0.08830120893461363, 0.1371800625430686, 0.11541265914482729, 0.12245445485625948, 0.11136429530701467, 0.09992303459772042, 0.06128666031041315, 0.11953668642256941, 0.11070444035742964, 0.1129776548062052, 0.12516879849135876, 0.09060642988021884, 0.08809166375015463, 0.14629797185105936, 0.22300752278949532, 0.18385789782873221, 0.11786130203732423, 0.08937683621687548, 0.14371713676622935, 0.143651848126735, 0.08709168633712189, 0.0611907493855272, 0.11948792689612933, 0.08357852378061839, 0.2492966428399086, 0.15039683905030998, 0.19312269639755997, 0.11288804068629231, 0.15337106159755162, 0.13766655858073915, 0.1509038404162441, 0.20938515876020702, 0.1771799868771008, 0.1324429110224758, 0.13429954568190233, 0.15590598700301989, 0.09151697637779371, 0.0792675804612892, 0.101086450740695, 0.11472265688436371, 0.1865292630557503, 0.16339934776936257, 0.1401986884219306, 0.11032201802091939, 0.1945084413247449, 0.1907103686992611, 0.12370184649314199, 0.17366761820656912, 0.17381674663296767, 0.11768769206745283, 0.22280234737055643, 0.1713792181440762, 0.09380030778369733, 0.14974217489361763, 0.07576297423137085, 0.14502524371658052, 0.11889669219298021, 0.19603332664285386, 0.13435716687568597, 0.12279844496931348, 0.44540707820228165, 0.13355587130146368, 0.09021623831774507, 0.15657701742436203, 0.22546711723719323, 0.14823471435478755, 0.15447484808308737, 0.2022769208997488, 0.17469325102865696, 0.11370862022574459, 0.08227576368621417, 0.16604818563376153, 0.08785127914909806, 0.10364729618387562, 0.14045365474053792, 0.12483626204941954, 0.12945106013544969, 0.1379631869494915, 0.26726023320640835, 0.07955126916723591, 0.1786627351705517, 0.15508894941636495, 0.1928271401141371, 0.09483001860124723, 0.10087731946259737, 0.2355861642530986, 0.19182726448135717, 0.09331831043320042, 0.09652010005499635, 0.08681489833231483, 0.2850889579526016, 0.1585281312997852, 0.30323176298822674, 0.16623482347599097, 0.09597982333174773, 0.12407139023499829, 0.15452993155590125, 0.1196503003260919, 0.2263384647667408, 0.08993176251117672, 0.16637180612555572, 0.1547540109604597, 0.1847209400896515, 0.1304760958467211, 0.2130790219775268, 0.131264933518001, 0.12358042943690505, 0.20465316410575593, 0.12653516445841106, 0.1303023365991456, 0.2462274118193558, 0.13604871396507534, 0.09691073266523224, 0.08294897899031639, 0.1899296191654035, 0.12029732417847429, 0.0923651655071548, 0.11318447227988924, 0.3126272202602455, 0.17214992535965784, 0.11192314353372369, 0.12656432789351257, 0.09821444949401276, 0.11164373638374464, 0.08565580445740904, 0.2643178068101406, 0.12640016313110078, 0.1314619936581169, 0.09188779576548509, 0.20856457922075475, 0.09266350378415414, 0.13019105685608728, 0.0832593816199473, 0.21640800977391855, 0.07568988922451224, 0.13158057443797588, 0.11060715200645582, 0.11504375322588853, 0.12012085079082421, 0.1845001990773848, 0.11044048344982521, 0.21320775364126476, 0.17079308602426732, 0.19932313582726888, 0.11347274788256202, 0.11366058673177447, 0.1006285956661616, 0.1764262430369854, 0.13593714923730918, 0.17217940092086792, 0.12234816913093839, 0.10728581129972424, 0.18676523039383547, 0.0958682925307325, 0.16154723215316022, 0.17998783263776982, 0.15238037332892418, 0.15118347826812947], [0.031151834476206983, 0.02966202941856214, 0.02699123076828463, 0.051209468727133105, 0.038811164908111095, 0.044030113611370325, 0.05267788975366524, 0.0880920844418662, 0.06386721719588552, 0.058017790716673644, 0.0223418341816536, 0.013215144630521536, 0.039408927118139606, 0.058317492849060466, 0.011564587841608694, 0.017739081788542013, 0.05383081574525152, 0.015412349586508103, 0.020652256540155838, 0.015404264841760908, 0.07149032742849418, 0.029723867707486664, 0.02878054796851107, 0.05295668622212751, 0.036191616007792096, 0.06253997555800847, 0.056168976173337014, 0.03250165775950466, 0.06457867473363876, 0.030281959367649894, 0.049138481462640424, 0.05485204826774342, 0.0397731545381248, 0.07071664822953087, 0.024114973410697918, 0.029192897092018808, 0.015884326671117117, 0.026829015097713897, 0.023855301451736262, 0.033053829201630185, 0.02079001611231693, 0.02771276285472725, 0.05440881562286189, 0.0509753707530243, 0.02548066762808178, 0.015950806139569198, 0.025359815452247858, 0.015826724137046506, 0.011343089414627423, 0.05345431701945407, 0.03636848973110318, 0.007019312029504883, 0.007831606232295079, 0.04909514343099935, 0.025380415775414025, 0.03103757257174168, 0.02861422885741506, 0.02573961016189839, 0.07515322230756283, 0.038242264185100794, 0.0683207885761346, 0.0053037206276452965, 0.04976599064788648, 0.022576593727405583, 0.055292085012687106, 0.02983857744506427, 0.018792688913111175, 0.07538526771324021, 0.03826257613088403, 0.04451842473021575, 0.023440368806145022, 0.02264703075135393, 0.03198990325576492, 0.05427131050133279, 0.02107273451318698, 0.049492259443338425, 0.07101862345423017, 0.04389252706563898, 0.04545889801478811, 0.032135157247206995, 0.05980640224048069, 0.02479230402968824, 0.03395765141717025, 0.038342293817549944, 0.03960079985803791, 0.06417596420007092, 0.02763680085938956, 0.027365727815777063, 0.014559514188606824, 0.0055150372125873605, 0.045721918544066806, 0.03900225394006286, 0.010805979753578348, 0.017900311886998158, 0.028627962406192507, 0.09477532867874418, 0.057385423220694065, 0.031915732592876465, 0.018204787513241172, 0.012789514880361301, 0.06447570025920868, 0.009421822598337062, 0.04328148592529552, 0.029702724556305578, 0.08509808259883098, 0.011945185767087554, 0.040284722444734404, 0.0721564656123519, 0.09204448985734157, 0.13288200460374355, 0.026358958267207657, 0.010032426083593496, 0.050339115251387866, 0.0043122575568434384, 0.0361036575133247, 0.04063100600615144, 0.009765735528032695, 0.027272700664720366, 0.016150069822158133, 0.027328576327168515, 0.0333764284982213, 0.03480754706210323, 0.07797368881957871, 0.03751631992469941, 0.04011170958567943, 0.011843762593343854, 0.06659929773637227, 0.01844836462156049, 0.009615772503561206, 0.051495488200868876, 0.034513191785663366, 0.017229686890329634, 0.04801223207531231, 0.02202237650219883, 0.033690057561865876, 0.03090806059273226, 0.018033085923109735, 0.021708184254488776, 0.015889212123251388, 0.027772626606747508, 0.020213139210162417, 0.017124863407973732, 0.05431035001363073, 0.07929283553468329, 0.046612017388854704, 0.036444936878979206, 0.05817915312945843, 0.041792406900120635, 0.02936950957934771, 0.026664158229583075, 0.027551665070599744, 0.06847340467252902, 0.025138424742700796, 0.01209998080906059, 0.023413576850933687, 0.03849465546331235, 0.027609627228230238, 0.03561636758968234, 0.024990548213411654, 0.017027724334704022, 0.05595621812556471, 0.08657192172748701, 0.023628066859341094, 0.03848186847088592, 0.042181580660066435, 0.017888910802347318, 0.02364113544380026, 0.028455044542040144, 0.010225489652449531, 0.10183230321854353, 0.05918968176203115, 0.035201419677053175, 0.013365964305454066, 0.014937142675210322, 0.046964940415429215, 0.07021919385130916, 0.04356389220005699, 0.06783206015825272, 0.020453428816316382, 0.04222048446536064, 0.03058461652004293, 0.024629250368369476, 0.046367809242968044, 0.02662198049282389, 0.052083228448671956, 0.029327270774436847, 0.031788710837385485, 0.046336830726691654, 0.031832859718373845, 0.023846824853015796, 0.017142583349985734, 0.05496694120977606, 0.027135098851951103, 0.018691074901393483, 0.016571097408554385, 0.06319609177964074, 0.05084840328033481, 0.036858961983983, 0.046603824078504524, 0.06118661032191344, 0.02896175753059132, 0.037469246557780674, 0.04460385228906359, 0.05868076014199427, 0.039971032312938144, 0.02524107860933457, 0.08561685654733862, 0.062386965911303244, 0.06442573294043541, 0.05018272650028978, 0.0169926440742399, 0.03354012507147022, 0.003231697961122596, 0.016572440907891308, 0.06511059869080782, 0.014161569515376218, 0.04409331236300724, 0.02936925852139081, 0.0485764203726181, 0.05759293958544731, 0.05436879562746201, 0.03625128637733204, 0.03872775599094374, 0.0613948255777359, 0.013932291684406144, 0.01963107830046543, 0.09443194924720696, 0.017157585759248053, 0.05526550340333155, 0.0925033763051033, 0.0230268814401435, 0.017967356235853264, 0.007416867817352925, 0.029602566002202884, 0.050447691032396894, 0.015671266675261513, 0.007897553050757518, 0.010657386521675756, 0.04582478106021881, 0.07482990037117686, 0.029638480860739946, 0.02234797492357237, 0.03085373368646417, 0.09167886126254286, 0.025990713919912065, 0.042976576036640575, 0.021432665110166584, 0.02769189790290381, 0.029517172370105982, 0.00835379066744021, 0.053413201189999066, 0.04581420948462827, 0.07750554715416261, 0.022889037051105073, 0.07335448025592736, 0.05847088247537613, 0.03731462539040616, 0.012062959938443132, 0.024017756305901066, 0.04633336341274636, 0.009392141780283834, 0.059477360253887515, 0.03697552412216153, 0.04302146791347435, 0.052813196421733925, 0.0023977667608830544, 0.06148967120264258, 0.051246713514306715, 0.0838965056464076, 0.033112441056541035, 0.01661470515786537, 0.016633811007652963, 0.06548382687781538, 0.07345273212662765, 0.02665379360717322, 0.01716957038401493, 0.032196048979780505, 0.03645701819498624, 0.050857166560100656, 0.05004980827548674, 0.07364718669227191, 0.025257419428921173, 0.03927672474778124, 0.034973282633083205, 0.06055266183934041, 0.05051998554595879, 0.04657435530264463, 0.02305717802872615, 0.03971468856824296, 0.011373955124456967, 0.033790233079344034, 0.051653305268181224, 0.06260931505156414, 0.055796158500015736, 0.026916949843455638, 0.05606005773214357, 0.01492583828179964, 0.036479375923850706, 0.06966939728174891, 0.0350640536552029, 0.01737134125349777, 0.030062799341976643, 0.01166921794148428, 0.026872621150687337, 0.017394160386174917, 0.052374109625816345, 0.04598886779110346, 0.030197322302098786, 0.032233314123004675, 0.011374848246175264, 0.05434761176417981, 0.017977741214313676, 0.042447128732289584, 0.005062193119166685, 0.028104258900774375, 0.05133358635274427, 0.022079948502193605, 0.06760751256453139, 0.014513762268636907, 0.030328096356242895, 0.015169998930234994, 0.017254947052736367, 0.02698662521184555, 0.020259993749537637, 0.03324128807123218, 0.0395297165294843, 0.026624672580510378, 0.04816448515547173, 0.05439389803047691, 0.04007043090781995, 0.031008317534412657, 0.08005114591547421, 0.05472433101385832, 0.023831798695027828, 0.02404852956533432, 0.1036614164976137, 0.05223167834005185, 0.02349531148294253, 0.0642040351937924, 0.010338418235603188, 0.025185286067426205, 0.03205287469817059, 0.031717566440680196, 0.0391583136016769, 0.032281805628112385, 0.06434187958283083, 0.05638321003477488, 0.022067950306726352, 0.016618527006357908, 0.04877264591466103, 0.03756034327670932, 0.0806893352419138, 0.21161797323397227, 0.08049490103232008, 0.10790361743420362, 0.20208195064749035, 0.1517956932740552, 0.11673515103757381, 0.11393778185759272, 0.23941630444356374, 0.1718838717788458, 0.0984662538394332, 0.11631732274379049, 0.0954490935962115, 0.17313840160412447, 0.12773808491017136, 0.075251433466162, 0.15204117367310183, 0.08781512680330447, 0.08406500624758856, 0.1599463237715619, 0.17470078276736395, 0.1656031480857304, 0.15216469418789658, 0.12259905066873346, 0.13651300833693572, 0.11689257116190024, 0.11551650214408125, 0.14677545694368227, 0.1879981963762215, 0.08811244727777583, 0.16361822959567818, 0.1647979984326022, 0.1392472737601825, 0.10600749203669173, 0.1270216197839805, 0.0905231668480805, 0.176618417724967, 0.1021081819864256, 0.0963163020621453, 0.08110147062689066, 0.07770336725349937, 0.16859779453703336, 0.08943268643426043, 0.10692229973418371, 0.10272332826363188, 0.10705576078700167, 0.10743612716240541, 0.09003678616136312, 0.18168931347983225, 0.11060633097908326, 0.09372538394693818, 0.15745390179966176, 0.11732596504901137, 0.16986418515443802, 0.13570652875517095, 0.151810566761664, 0.20148816465267114, 0.12575950393719332, 0.11667957901954651, 0.11652979919953005, 0.26754448509642054, 0.15983967163733073, 0.06775365543684789, 0.13927943632006645, 0.18112553230353765, 0.17445975355803967, 0.13784949162176677, 0.19058534183672496, 0.2376301831432751, 0.15061183965631894, 0.1413952170738152, 0.1460062832172428, 0.07322530754442726, 0.2667173237672874, 0.17212928432439054, 0.15316615759262017, 0.17125246780259268, 0.18068851503942693, 0.07943520575229611, 0.12745362945965358, 0.1407208346894809, 0.14122905741844857, 0.08633188317928996, 0.196842221809285, 0.12849233086620057, 0.11933499867362635, 0.13642967066594533, 0.19672509309436592, 0.14378789439797401, 0.14404775973941597, 0.141552759334445, 0.17299202802990163, 0.21166779127504143, 0.12152723675327641, 0.12680196442774364, 0.0983916489141328, 0.1507938498897212, 0.15798447547214373, 0.2220560402742454, 0.09351440705358982, 0.1304651985743216, 0.19932861839021954, 0.17879656941762992, 0.16768816406173365, 0.1811017021536827, 0.2744276528911931, 0.144071047061256, 0.11338388693651982, 0.18666935339570045, 0.12577985998775276, 0.19547235460153647, 0.10303301164614302, 0.12415187805891037, 0.16253431061548845, 0.05762305975492511, 0.1148640907236508, 0.1559905053249427, 0.25576015029634747, 0.1572051372911249, 0.08363252838275262, 0.12090709645833288, 0.11122113798878022, 0.19678702977086815, 0.15331738947757653, 0.16125236797545636, 0.12261386987354074, 0.07350485718676023, 0.11785366173301424, 0.1696384772658348, 0.06899793938334499, 0.15245478147906916, 0.17697559855878353, 0.13953793102077075, 0.15897280243890627, 0.1035404744158898, 0.12471572708870683, 0.13519625685044698, 0.09833068254270724, 0.07769401025559221, 0.08710404924516167, 0.1385206984622138, 0.05609085304396493, 0.11392335620309625, 0.18448866398206779, 0.11331289181751864, 0.07555251980998687, 0.13371914039765084, 0.16905052667217596, 0.09566564804741315, 0.0856375993628587, 0.0851186014977949, 0.09755967677171741, 0.17274516341941698, 0.23875769121306284, 0.12246216301407133, 0.11663501283952168, 0.12869100591966084, 0.12335719141576972, 0.12977227861327784, 0.08163853787950107, 0.2017568645200559, 0.11246569334928479, 0.12973049442682946, 0.09290372553680624, 0.15064165448503836, 0.18028121760913304, 0.09870443998702935, 0.1925641263702086, 0.14133089195404733, 0.1479099674948624, 0.24243752232619695, 0.10901061339037758, 0.10007025634071656, 0.07433058002165385, 0.08187087505523648, 0.17112168696309837, 0.17847666729773792], [0.047973765925105126, 0.09780194770012583, 0.022246929184932793, 0.025510401032598953, 0.014322902242253934, 0.05432760176647987, 0.02619030329930995, 0.005504285825216877, 0.014574111173195499, 0.06224542350641318, 0.015489907835477164, 0.038842289309416494, 0.06333107953625065, 0.024641443642654588, 0.015224629480923926, 0.03180029343015381, 0.05172629188746214, 0.0368185518309474, 0.01636064298717039, 0.02893929123612387, 0.027487653773277998, 0.015923963294231465, 0.027221856339435493, 0.0741709139464157, 0.026584481255018284, 0.0167946441631232, 0.03258012694173625, 0.049269360689712424, 0.043173320657972775, 0.026658850389399698, 0.07306422333100013, 0.04282027888777001, 0.06398110929876566, 0.03092166521985616, 0.011339421084682857, 0.08413701916911773, 0.034111332813543935, 0.03607028716110757, 0.058759402350655625, 0.055532493362469335, 0.023523195879533887, 0.03629688053791012, 0.053539011760481765, 0.024116656177544167, 0.08008261636963912, 0.0371453207252281, 0.014252896088042429, 0.0519410787549402, 0.012121699866838753, 0.01447850389273039, 0.06177787895181349, 0.05725326495511191, 0.003218661607076813, 0.023795035667717457, 0.0546649965191526, 0.06134739597993238, 0.038051863866192956, 0.0270607008798314, 0.037561177874782255, 0.014992524703432406, 0.028048644474308406, 0.018254561449534128, 0.06642730946519546, 0.04030508188796895, 0.019559099305687205, 0.05626692270327892, 0.03967830891321812, 0.02292040572501719, 0.07015333524239914, 0.04390631489721792, 0.03890279766970447, 0.03616662895573037, 0.045577302375542264, 0.0703688243936215, 0.047267180268785784, 0.04434068926743098, 0.016879729061786617, 0.029273011721670628, 0.010936002330189305, 0.022700730012729764, 0.01675793032960168, 0.0528380070546908, 0.061752915648477416, 0.040912153598453314, 0.11031169071793556, 0.04469350712107761, 0.10270472961877074, 0.026179975996326123, 0.023130934785253236, 0.038813726377806494, 0.008699712908959814, 0.06107590054827077, 0.04713107632207019, 0.030133054857807498, 0.028400909321914827, 0.03637340571731329, 0.02152045227454177, 0.0306021532575999, 0.02247767010703683, 0.01710983894632331, 0.06545798826430525, 0.021909042494371533, 0.10164984515202896, 0.027566943982882158, 0.0434476218319365, 0.040299260057508945, 0.03209058088915689, 0.0686465125264866, 0.03056950893785272, 0.048685688259346147, 0.012467707773404462, 0.0509630214156849, 0.04829825833439827, 0.03689276659861207, 0.013288060851794268, 0.014174981608188577, 0.04380488408995526, 0.08629770537040063, 0.014858544571325183, 0.03844661179131695, 0.04288456668811185, 0.037060110297586234, 0.055105681265039105, 0.040356653942061324, 0.05294396369052785, 0.02733009115659765, 0.012855988411631967, 0.023719647034470524, 0.02342402798655842, 0.04945812573922532, 0.01994373875537089, 0.060384195164910386, 0.0458381889121873, 0.012343013393027442, 0.005002175000429685, 0.04056533399437155, 0.008192820108628698, 0.05572786395038877, 0.01077391388493457, 0.03554940636136702, 0.019460494596777216, 0.016327359148168137, 0.044074639079294035, 0.016881293085004603, 0.05356409041477101, 0.04236434067466429, 0.02889626533059137, 0.030044906373534883, 0.033356554207525084, 0.06574464216828346, 0.01874127970742328, 0.06953951210847922, 0.060644060506352356, 0.022706889414361546, 0.08864578258778368, 0.03716595158247011, 0.0948979670980147, 0.04728803164990885, 0.046037871590150256, 0.04208040091076067, 0.02178346601847027, 0.041410527391625304, 0.042736011623804054, 0.06804392593247549, 0.012145420602921928, 0.03633402354483094, 0.04864848079159856, 0.02787067661327975, 0.05221126800669091, 0.03715422310467277, 0.012872914467672152, 0.022579955868422985, 0.02075870002486876, 0.05125265408839498, 0.002998196249661435, 0.017760689736210873, 0.04931492431621466, 0.05283317927803312, 0.04553862248680421, 0.04305702654112663, 0.0443804921316249, 0.06303499399551324, 0.020545796092067446, 0.02756387191558523, 0.08029687058712755, 0.06939848539020334, 0.036734939353274446, 0.04459251396890197, 0.09152045726243939, 0.03217741980084351, 0.039188121645046134, 0.02291619371888893, 0.04302177664690784, 0.024995387864432166, 0.027198942211855735, 0.007744158335429217, 0.011680727591738105, 0.024467803138707365, 0.029700743234051124, 0.02051016961091331, 0.053198773946080885, 0.029834289103746414, 0.04405822531719293, 0.013115014914157135, 0.019890551787934134, 0.021913741349375675, 0.017574481067380736, 0.021144448879307935, 0.010712346161848732, 0.06659899918096406, 0.005612432856910995, 0.04593263080875788, 0.07351798005402088, 0.023035001807979176, 0.043733427567141395, 0.12487576635820524, 0.012751915558640445, 0.04088749224320054, 0.04497232733826552, 0.0056940886092239195, 0.0513420069723257, 0.06301355907427413, 0.03710240338529859, 0.02511420613154769, 0.05507848558149167, 0.06622394573475633, 0.045580895218466005, 0.016742069573540772, 0.03349546389654279, 0.07678150957716362, 0.05453126744500228, 0.03317520893844111, 0.005725353806545692, 0.03202019305899739, 0.030243221803435257, 0.01308038757581796, 0.05262567648398025, 0.03642816349331822, 0.01373262088080602, 0.03939702222123742, 0.042493588025016446, 0.05067006052870836, 0.026671606847750287, 0.03389621346390673, 0.08847583670701299, 0.07295372390321322, 0.040953517093190124, 0.026263352683080093, 0.014536371055458273, 0.002398088004805946, 0.08160569678459849, 0.02098813815973699, 0.0924580976633089, 0.05110549680622561, 0.031041772703507116, 0.051398301630147865, 0.052659515025360246, 0.009025046701676078, 0.030823650836412395, 0.032806177490523884, 0.10684834620250122, 0.030030477326363325, 0.0749878633235182, 0.03820138584290232, 0.064691406541637, 0.019455352997673408, 0.013881482134040977, 0.015381681500002742, 0.04735064007607954, 0.02238206791558436, 0.03826021822169423, 0.05160121752747467, 0.02743220898056669, 0.04338417202234268, 0.012029963628655034, 0.04096396313980222, 0.03480004925014717, 0.009097846723826868, 0.06404989239360605, 0.03534944548404642, 0.017648436295400773, 0.006697406110885952, 0.06557131718311991, 0.05983988794365099, 0.03717082007122891, 0.04380529799631663, 0.06398257493440594, 0.003335151438867407, 0.050351912421839576, 0.014765776959913117, 0.011452803438130234, 0.020124030598838414, 0.025961452097232853, 0.05875222345015832, 0.0073362858467070115, 0.0825188352859446, 0.04224070480891636, 0.008914765253263925, 0.017761722805776765, 0.030557054427585432, 0.019079977247331823, 0.015922745323872993, 0.044454140322549004, 0.01973172539978155, 0.06309641498540129, 0.08398895604269845, 0.036141512982015095, 0.04695084724309189, 0.014952087408996053, 0.041200140823743174, 0.024346796596156697, 0.04555542640654104, 0.031946527904697826, 0.017587754908683043, 0.013160112047834056, 0.005909533231585685, 0.039913916627743413, 0.04021813780335443, 0.010963575448840857, 0.021888162275510173, 0.012459635751188865, 0.026415899229635085, 0.03182948400665607, 0.02551679961782481, 0.02598775550723076, 0.0524444160317736, 0.03864521220592516, 0.05051924594278846, 0.012945136886888316, 0.008579431550710328, 0.06971314921975136, 0.012634657922067812, 0.037135244480201175, 0.006319385346224797, 0.036673128205750666, 0.01783943542146257, 0.011629880721946912, 0.04661525060821857, 0.042559528058128696, 0.043085470729108365, 0.029121118265071085, 0.03862841846421361, 0.02949600886287434, 0.02010704347464655, 0.04839438639049019, 0.03654709032603672, 0.033609953110239336, 0.03714187376733337, 0.027067611758996333, 0.019796664593741298, 0.034782763570547104, 0.058428446895309856, 0.16477055847644806, 0.16192825670753205, 0.09288146958819457, 0.1051701255408781, 0.13780260485197815, 0.12631518340536527, 0.1118403554760984, 0.127972830885223, 0.13552860330258096, 0.1472843446369682, 0.09640888138008968, 0.1064075223569359, 0.1891157706933362, 0.08421999043119804, 0.12645215248422964, 0.10214630208377327, 0.12269563334328787, 0.1160842731062855, 0.12174366228282452, 0.09186058651123728, 0.13234095435057366, 0.08625142928212881, 0.11928775906562805, 0.09170339708881718, 0.19525090791285038, 0.14729441409664495, 0.08996190303670508, 0.10921924255256142, 0.10143124831042119, 0.17920620100838797, 0.17052729028676236, 0.15609328980956758, 0.17945231923035213, 0.16351358592510223, 0.08498976126845394, 0.17900972440838814, 0.16345349486385072, 0.13045112575803483, 0.11624395953757422, 0.16576929417039665, 0.2097973552133356, 0.11447097467524664, 0.15063180215656757, 0.14437254731144222, 0.10327476010258708, 0.16244088991412095, 0.12414419704249927, 0.11416408685701233, 0.16694740738187516, 0.20415438658424787, 0.18415502831339836, 0.11352049639182431, 0.09647009880947215, 0.1265726060207401, 0.11898921722812311, 0.12328814369227205, 0.10987170147044317, 0.10832725398774658, 0.08707046176173858, 0.10475455676870686, 0.09166688511946372, 0.16944742894598416, 0.1029579656730805, 0.10278198083064385, 0.1602661173258509, 0.16699103718357428, 0.12545094692281314, 0.0940265856417162, 0.22908886575273105, 0.18829422763415746, 0.08228203334978648, 0.1370591747441462, 0.09825141608182873, 0.1360730869429452, 0.21704220931444848, 0.14033891446888447, 0.1532320026308298, 0.12874005043080874, 0.0838923394413931, 0.17905530839094094, 0.14628079134438718, 0.11200485272066933, 0.15927305418465817, 0.14508872745292528, 0.1875919167484556, 0.168843967041799, 0.2582001079406057, 0.23456643468567304, 0.12222006171941757, 0.17511572050196783, 0.09595122986606189, 0.1824924275279045, 0.09534337784030608, 0.09605153769786869, 0.16347698574619635, 0.15500125555055483, 0.17026525363326073, 0.15220594911703042, 0.15330159318234238, 0.13227293800030435, 0.12328671876873289, 0.10827059631368943, 0.19033880292304925, 0.16083353544984544, 0.1621422123696123, 0.0998163621074387, 0.18582650433693612, 0.1594644689134189, 0.128702364595873, 0.07643384180430855, 0.14686427717762335, 0.18018795975617, 0.12400041547204767, 0.1470783549760069, 0.09594753185021025, 0.1465414980692523, 0.14898630045354366, 0.15409646981528827, 0.16940093572650636, 0.15188668482005596, 0.09908978002411978, 0.10027383720236165, 0.2334416407559599, 0.15196838043630123, 0.14375737389283522, 0.0993485189974308, 0.11080489746694054, 0.09809478984347411, 0.11178213038614818, 0.2411214086626257, 0.08156855377767767, 0.15324241135801586, 0.09561659675091505, 0.08986684706594263, 0.15059278639299528, 0.08279031036155564, 0.0980233536767108, 0.12044954672455788, 0.06002873781004122, 0.22239384214792932, 0.12683536192136152, 0.1620982704418046, 0.0894162862428597, 0.13321374037436076, 0.06786021936152663, 0.07980403024703264, 0.09361309318670205, 0.1622847725770303, 0.07322179951838084, 0.12009392652128424, 0.1771262740450246, 0.23180639850241797, 0.24738140989627155, 0.18240751565567084, 0.23832036182284355, 0.12427272514573165, 0.1826891212591103, 0.07123918804739203, 0.07019608973392419, 0.14466600013630732, 0.07909396370606762, 0.22577719417001518, 0.14601684122213296, 0.14340065446283135, 0.13762457083378518, 0.08785509930125304, 0.09338509863508598, 0.08622222513492618, 0.24609968438744545, 0.12465737307710306, 0.10733676249427454, 0.13930889831057616, 0.0841023867417659, 0.08639955347669975, 0.22343635692128114, 0.09356433366026197], [0.05911513790488243, 0.0433145814708301, 0.01603587407485715, 0.056170102541467974, 0.02094841841608286, 0.04286577805344548, 0.013844828520502363, 0.03036495777113097, 0.033653162220226865, 0.02157638730880405, 0.039134561483349116, 0.050563605169632604, 0.03536707382383091, 0.007926423867632235, 0.0296538666422878, 0.06740351101117474, 0.02515631601480501, 0.02652918404367353, 0.05906776937523058, 0.016974673074270998, 0.015088249031188232, 0.04705099222649421, 0.02283867448568344, 0.13360879703291825, 0.045033161395362446, 0.01581861394723611, 0.009956076475126403, 0.06780719184981925, 0.008570922721576477, 0.0486910826127444, 0.04739194589533976, 0.056133906090898175, 0.036754674544291835, 0.04426783496247871, 0.026268153318337033, 0.017176564383719648, 0.046885673954550705, 0.05009806907868811, 0.086364486786936, 0.027182234983359064, 0.03225339875955667, 0.035710477004093785, 0.038973792788705656, 0.026111301467088715, 0.010429425896810634, 0.055268699303269386, 0.023635420482605696, 0.04787501193849104, 0.04386800141738994, 0.007243893974061523, 0.04849027356665049, 0.030484223871358802, 0.02245645740601633, 0.040881405784083266, 0.03021024160885385, 0.02631419022301478, 0.040216604314212284, 0.004897606816874551, 0.042509017911340506, 0.018054227377953272, 0.024542883038520813, 0.021294601893584644, 0.009097148680926433, 0.02366451945688043, 0.06743232160806656, 0.04978639758857233, 0.08228016059313502, 0.024886372731998563, 0.044701751321554184, 0.0365245629634176, 0.04609254115660276, 0.05625840708879488, 0.035376620811543295, 0.028456452502203838, 0.022339281193645935, 0.022723822255751917, 0.07031799533537456, 0.06339776595788342, 0.012382922278318022, 0.04405937543404954, 0.02987126586958766, 0.12574206558721407, 0.03883798061204808, 0.006713439045207841, 0.04061336748834167, 0.03239900219653334, 0.0937537874228188, 0.056755651121160815, 0.03648924521569695, 0.05038271451901112, 0.028069789321827035, 0.027313450085265294, 0.060045585834554265, 0.03388865797647408, 0.039676500617393425, 0.036805184691080024, 0.09598953995321478, 0.03507880839918341, 0.04175793732117329, 0.05004631721281579, 0.013934731017798185, 0.053866130100297074, 0.08340822506163802, 0.08248260830129896, 0.0447506397696478, 0.006730918107288224, 0.031227898251797472, 0.00789881682222975, 0.046407829238367934, 0.024625509944079176, 0.01988584445124226, 0.026936357641326528, 0.05869882274419069, 0.005061322898005268, 0.027988809560026442, 0.006003354268614203, 0.025165142059060078, 0.007684970573921288, 0.02336377407690244, 0.04961441271007061, 0.044601667406303544, 0.053236303717962334, 0.031681288565908156, 0.01697045428279255, 0.03751515284446733, 0.052560733897345405, 0.014663023009364094, 0.02232865703159145, 0.025132105885339633, 0.05521976335772446, 0.01739205014226692, 0.048794528669012446, 0.06355463646884475, 0.04197108891925641, 0.07567471718149525, 0.03173935759280409, 0.058971790596842766, 0.07953228375741414, 0.035038235397743325, 0.030614869003849368, 0.06460545651082482, 0.03323621602196779, 0.02302748363997255, 0.027276851602696946, 0.024003213604113886, 0.056521712602781396, 0.01623369417419391, 0.09990347243313279, 0.03900932088228209, 0.03907653995390449, 0.04037518473342061, 0.03685968801645296, 0.025677301987473453, 0.02131405718890684, 0.03386627649888396, 0.051203663860048564, 0.07329343924564974, 0.05235459835135511, 0.04747282726956265, 0.041233344934880733, 0.07338697529797043, 0.013538102702503758, 0.023540601999099766, 0.056245830442224226, 0.013074673462792166, 0.055808056611567736, 0.012520032153198761, 0.06533853895962238, 0.05911262732531343, 0.08420196175575256, 0.02847353122862322, 0.012131700624844857, 0.10278168906058584, 0.016141121641599705, 0.007890612485685518, 0.029658395863537277, 0.009783257846720517, 0.01715184365665274, 0.03002609059746776, 0.007594160536038024, 0.015419165470770426, 0.0535224792547524, 0.04857586058122771, 0.037838926006640704, 0.06362105826182024, 0.0336189063798104, 0.05353686080447265, 0.038446289487183094, 0.025206563229273473, 0.012221307959407568, 0.02399923569256706, 0.030291248512055193, 0.02169452195188829, 0.05945876160902636, 0.04466234540034618, 0.07785360169197832, 0.06151748435305698, 0.03140502642574055, 0.03375311382114887, 0.032029275250222, 0.0428481429283108, 0.014301041540290629, 0.02632312144019774, 0.08710372354835272, 0.04155301974554147, 0.020785900797428827, 0.06462235203278915, 0.047911751217075756, 0.032173189135002236, 0.05707717154707227, 0.023102538094722798, 0.008974734178212072, 0.07532586197235755, 0.0320055808073708, 0.016015590966812203, 0.044600507111421654, 0.033439260840948136, 0.05533268176285284, 0.011178069698092128, 0.044847656706614156, 0.0644260857786451, 0.023153263676379408, 0.06248676484184606, 0.05230800335162452, 0.05416110623627901, 0.013639073802291282, 0.020848605914839675, 0.027793732438502566, 0.04669275287804859, 0.022318512933062654, 0.01946595001832715, 0.03709063419540014, 0.07340556037213121, 0.0545769430297826, 0.06458459155900137, 0.014961897329028164, 0.021374161820858717, 0.07362121237175805, 0.04523017064535192, 0.035013265309057066, 0.06090208023254361, 0.052631919006151814, 0.003916088949024145, 0.02622791619173118, 0.09809377204094614, 0.05543711848024811, 0.05366092753995742, 0.026680724662063376, 0.04137097219271319, 0.02592057884404702, 0.008512254039357816, 0.08841300436428615, 0.04079708084464073, 0.029799768634672676, 0.07933912519365549, 0.017863479309848378, 0.07234260133866753, 0.06529477345091955, 0.11346905665206057, 0.036132217052259614, 0.06522039244217531, 0.047957155387848616, 0.07040408107319049, 0.06236903901611056, 0.03328062613893833, 0.03971136374665158, 0.043152225004243, 0.05284775421023369, 0.048124621223126135, 0.05980267029787813, 0.009454956311466438, 0.059671170211264064, 0.12056630903056689, 0.06773892444159303, 0.05648043053224683, 0.07060670520045928, 0.007747989513778261, 0.018465058279356787, 0.030661915229367356, 0.05654738497521196, 0.03895689048139112, 0.020318592033748115, 0.03802664950489998, 0.04670833543475185, 0.09107763852391924, 0.028714021002607684, 0.02250568681795682, 0.02787891063573105, 0.01946791776988123, 0.014601754689855235, 0.054291971892650635, 0.033877170378608365, 0.016321908815630844, 0.021407058894900338, 0.05288840524320092, 0.03315515822864004, 0.031848140326993804, 0.020748727256432176, 0.005939595301502517, 0.020394759285928946, 0.05597239779308438, 0.018152469070628285, 0.056703512490327866, 0.07079735996999911, 0.026054538620103682, 0.07800819911062717, 0.07228170282074384, 0.040932323051882644, 0.023815203424809233, 0.0338924645579287, 0.052171716200453896, 0.021706403100064824, 0.01753653908547546, 0.03253604591424976, 0.033981987075614076, 0.024411618742825728, 0.039315068761685064, 0.02479811568212296, 0.06598331686109304, 0.04787861495944006, 0.02981981255912355, 0.01736289688519069, 0.008744311319398028, 0.05369720541472946, 0.03529890819585749, 0.03909599694556423, 0.04272868005292756, 0.03218488029337355, 0.021733264605115567, 0.01537620063338961, 0.006424864887126854, 0.033213010124330006, 0.07339871395379305, 0.009005766129121184, 0.042400062150721035, 0.03447599449594106, 0.084162281027862, 0.07456238794007472, 0.004145150072872639, 0.07054686519716467, 0.026542310303609287, 0.0637745496683887, 0.01649986649863422, 0.03518923997346844, 0.037349254425082884, 0.051535803359001875, 0.052257968179349384, 0.03317775683743613, 0.03599562795300569, 0.03653975536248513, 0.05750615495656218, 0.09588702688259737, 0.11883132212928363, 0.1375215963593551, 0.0808872774775539, 0.09832019917666912, 0.21038626932672091, 0.14378690373684677, 0.1297817373914378, 0.0796085646642106, 0.12795964016446046, 0.1112470580264926, 0.1038311045350773, 0.1130474421328732, 0.09325304214975663, 0.05767504232270377, 0.1370854340493679, 0.09594964887946844, 0.2387105194585664, 0.17136905368949684, 0.1527660119214228, 0.1309448956911053, 0.14217203110456467, 0.17192946933209896, 0.09588358671005283, 0.2540241320218359, 0.10993871358888489, 0.052494960105312724, 0.10781304657991443, 0.202434259599873, 0.1491264993590968, 0.11696962559861795, 0.12866576441696712, 0.2658910852457796, 0.11040363221296243, 0.15917814070624964, 0.1653805478875126, 0.11735473493380205, 0.19473082439175673, 0.10331828812403338, 0.1255684827587434, 0.10229430414204087, 0.16787803173065186, 0.16089946191225732, 0.11532306538096496, 0.18762954830058984, 0.1697797482567174, 0.12714744731783867, 0.09125170311225311, 0.10591582195567233, 0.21112418973020144, 0.13310486264526844, 0.07459204670573984, 0.09091604540922812, 0.1294334860784667, 0.09968591375010354, 0.09596160466649703, 0.1173710740570511, 0.09867577866784163, 0.12429152056574821, 0.13721924115504536, 0.1620727168130023, 0.10865209584257432, 0.13829807112259523, 0.1273513063788414, 0.11331916148109095, 0.29282431144799503, 0.13085455553872244, 0.1685686989554337, 0.10686838334160191, 0.18306040205061436, 0.16663914892290319, 0.10420931316912174, 0.11920864188245364, 0.14484434628060885, 0.12056649902037211, 0.1280273851007223, 0.19982078698064598, 0.15585017071238585, 0.15100145446402685, 0.1537647611860718, 0.12219069472381047, 0.09733333106019668, 0.18130800394075258, 0.1846005001238414, 0.09187691206378595, 0.10630990152380296, 0.12811989656516484, 0.15363863509680542, 0.14117457105645112, 0.08732807436691863, 0.17228951358369418, 0.1057320407458714, 0.12628311584038393, 0.14461497430290493, 0.18420362499143395, 0.15905970920409473, 0.118191748591406, 0.23908922342317446, 0.2959846018680504, 0.15960526492978844, 0.2738963056887899, 0.0845975883837257, 0.14034289068409375, 0.12470157284821783, 0.17856753670743533, 0.1455774897975581, 0.1368897852620908, 0.11885836853512696, 0.1352688872388431, 0.252490045768874, 0.07543906875486885, 0.10757579681064401, 0.05583234137988516, 0.06872723105230502, 0.09806428969438587, 0.17295782986496175, 0.08381698134222201, 0.1209386076245989, 0.07229011665497508, 0.07958852073975972, 0.12873376719653606, 0.10973601482276406, 0.1990701915430171, 0.1708005770508732, 0.12454620189964771, 0.11294504441320896, 0.11459593368428093, 0.09942475240677595, 0.18354482177112783, 0.09888151048549584, 0.1472569861050163, 0.14784262967961176, 0.16882219963840076, 0.15995745174586773, 0.15811765832560404, 0.10642572745148625, 0.1467632840254477, 0.10591843431549412, 0.14795015033866676, 0.12767291840698036, 0.08953665156981774, 0.1312805533941303, 0.10164439651582922, 0.10906241275370121, 0.07010378182998725, 0.059581807149308066, 0.08088902809790202, 0.09520465135574341, 0.19290044903755188, 0.0888147581634777, 0.10891375251646553, 0.11447980920118944, 0.13452559283801488, 0.08522447331675462, 0.09970508236438036, 0.09299623700124876, 0.1607741229236126, 0.17562709163342202, 0.08270537813327142, 0.16452376171946526, 0.08853216868426118, 0.17178073445601122, 0.18192549794912338, 0.12360215612820216, 0.19380804390779563, 0.09276275310133185, 0.16574815101921558, 0.15330691289688858, 0.15506328722195967, 0.18621888756752014, 0.1437381984932082, 0.09568646550178528, 0.11952159580375467, 0.12405072205833026, 0.09991639852523804, 0.10362112508820635, 0.14351212419569492], [0.026771488898832883, 0.05098060904336827, 0.0940851771405765, 0.06194546353071928, 0.01900013572802501, 0.04213117229353104, 0.10387138915913445, 0.06940290265317474, 0.06468660251370498, 0.00985094001849315, 0.04074384637975267, 0.04809925079877887, 0.021897434456540004, 0.045499029968466075, 0.036183293775788376, 0.0650255103994693, 0.04653639466102634, 0.03197801532223821, 0.061233816003160815, 0.021951427184311405, 0.05157843232154846, 0.035515279442604096, 0.03454194809975369, 0.02874458221984761, 0.028289448070738996, 0.0876758439200265, 0.054708273482642004, 0.03883442848122545, 0.06277534578527723, 0.02378710189701191, 0.03247657231986523, 0.014818807864295585, 0.04353385345478143, 0.05481355497613549, 0.017895767398710762, 0.024169832966955643, 0.029537457174488475, 0.012014230946078897, 0.06488924021167414, 0.01655415947815137, 0.011023418844810553, 0.0036899803006755455, 0.08568361082247325, 0.025202269798942974, 0.02567140382182385, 0.03522739399756704, 0.011558201130745667, 0.0330991044507495, 0.020115794880049567, 0.05937094560691288, 0.03741483483463526, 0.02565385860257915, 0.0317233373810138, 0.016379302700183222, 0.019720687331365686, 0.017596915131434798, 0.04918286783088531, 0.04329042901684131, 0.0069888127285854095, 0.021483475508700525, 0.005978917678086353, 0.046423092883612425, 0.020094926535551037, 0.05463729193434119, 0.041549694923950095, 0.035376037271427255, 0.05415453123194831, 0.020803549493263875, 0.11002042956118073, 0.050165885261126926, 0.0124186395135309, 0.0037474882639279322, 0.019755056826397777, 0.02832768521537738, 0.03451240807771683, 0.20789067181093351, 0.13594864362052508, 0.1342428337250437, 0.13196098831083092, 0.059854652865656784, 0.033140423840710094, 0.10155290963926486, 0.02874106740845101, 0.060295273150716505, 0.1247344139431204, 0.01991108595393598, 0.25777230518204824, 0.057254750946802754, 0.025290676126522676, 0.10242563459490027, 0.08723417869103806, 0.056200880889913866, 0.016966086213610003, 0.017530498427471945, 0.1076087329004492, 0.08091542989547763, 0.11871036647685937, 0.08392974707697119, 0.16195717587002686, 0.12118564865418843, 0.06782783288508654, 0.03868442813732794, 0.05000423447095922, 0.0440884133401726, 0.0828443013929895, 0.058328824383871894, 0.033158798569015095, 0.05186824819871357, 0.028238391703260795, 0.0818974736279675, 0.013602521969005466, 0.04708612337708473, 0.04921739847798433, 0.043162769438432794, 0.010227951038229679, 0.027645487803965807, 0.0496807870055948, 0.013720675271802714, 0.03404062607192567, 0.04764842873971377, 0.03544131912557142, 0.07603088021278381, 0.0026818963025497006, 0.037265075370669365, 0.022005542048386166, 0.07667455888752427, 0.04185362772217818, 0.03790415697065847, 0.050903954942311556, 0.04558800965813654, 0.02608441621331232, 0.020533640137208358, 0.027306016734136, 0.02442180016078055, 0.03434359195775219, 0.054839078070861955, 0.020306117167430263, 0.040407839231193066, 0.028401601427633847, 0.05509797989257744, 0.036886035531227074, 0.033100020473024676, 0.006268488858560366, 0.013778868979508323, 0.009385769488289952, 0.018058982212096453, 0.006414000269225133, 0.04734709133793201, 0.013116341450118592, 0.018649029478962933, 0.09704151350472655, 0.03512951532112701, 0.032210257503071, 0.032357248544160805, 0.02638567558356694, 0.05282905717779483, 0.029129318360771452, 0.04613141782049622, 0.05794899405113288, 0.012093540663564844, 0.0335472157624151, 0.02784105177436556, 0.007492352293671242, 0.0298838967989598, 0.07699897326529026, 0.003665297317119049, 0.07277204615197011, 0.02108762157149613, 0.034705858411533494, 0.011927649029530585, 0.02204500055605812, 0.04975803821746792, 0.059609566016920974, 0.017279011297172735, 0.0311821989182915, 0.009443327069415577, 0.04326800682715007, 0.038377411397440095, 0.053664449136704206, 0.02234516409225762, 0.040211786715579886, 0.0338948224671185, 0.04689270018466881, 0.04722552839666605, 0.022211826872080564, 0.026102818083018064, 0.039579168161643405, 0.014531388912083847, 0.014601242395916154, 0.03302521198721869, 0.03398313379979559, 0.013523836503736675, 0.07218339666724205, 0.006182164785319141, 0.009729260029936475, 0.016640682871054326, 0.0490683582611382, 0.07116081725273814, 0.05450867562155638, 0.020349892854158367, 0.061285710361387045, 0.01759427223753716, 0.03135779360309243, 0.03655787903283324, 0.05340832930856517, 0.026906191670734967, 0.05522433668375015, 0.04034776852599212, 0.07792728380965334, 0.031605784581708055, 0.02834382077812084, 0.04087630320074303, 0.006324501500265407, 0.06812042397047792, 0.017171857047027776, 0.03171568350600345, 0.056750280516488213, 0.09799390525690146, 0.06143460808587926, 0.01206841875266816, 0.0910352843680552, 0.0620281362373914, 0.018488985120451877, 0.05111819898177471, 0.026006652707500116, 0.03581356004412685, 0.013197479819479798, 0.033193071372807026, 0.028100554099572555, 0.07724935268717152, 0.016121954723660434, 0.014362991787493229, 0.0951452116881098, 0.017334381451031992, 0.049565385162298164, 0.03649550470124398, 0.04033150404159512, 0.02124008839018643, 0.03698077259053077, 0.0251558681816927, 0.03821872241262879, 0.03676390601322055, 0.04374167176761797, 0.09685720982296125, 0.07105337801788535, 0.11202628764190845, 0.09075572794037205, 0.03556862586577024, 0.032752878564809046, 0.027057584707758257, 0.00963446868783129, 0.06617612937199217, 0.04293204378336668, 0.08113042371613638, 0.012209331816328424, 0.043912381000284634, 0.06902372371405363, 0.07975444290786982, 0.0047110805088388065, 0.04790877923369408, 0.09968631408576455, 0.053477427922189236, 0.1607346050441265, 0.07651443819382361, 0.04964069237134286, 0.08760171396923916, 0.04257244397220867, 0.05152948959065335, 0.021848673233762383, 0.007192647616778101, 0.05661556417388575, 0.09429770787911755, 0.19926801164235386, 0.10893560812941619, 0.07043423516941921, 0.06782067434063979, 0.030804278661629984, 0.0383059175552002, 0.11268169818712132, 0.030380944056170325, 0.0704393648941602, 0.0871240117454103, 0.009736622983057584, 0.014149666314811578, 0.04782926510753376, 0.02289732705269541, 0.03501533144818885, 0.00447704445105046, 0.05693913038287844, 0.09144942143133708, 0.0435598718800715, 0.04345450556970068, 0.044016583623098474, 0.025650145319689597, 0.01205462498390781, 0.04469847399741411, 0.051598140371165106, 0.031145401964230195, 0.03418805476810251, 0.028206069687647477, 0.050601959361561706, 0.06725868449679442, 0.03365226655400225, 0.03146953474996345, 0.031213418314499513, 0.023988163697400262, 0.01750814409128257, 0.05778286832251719, 0.02137515417832349, 0.008038866450078785, 0.05817027110606432, 0.060588929536087174, 0.012816427275538445, 0.04175760144633906, 0.04954053381724017, 0.02591023118501263, 0.06800362773771797, 0.014537684020719357, 0.020286487149340764, 0.026764092867129614, 0.014517875887187464, 0.0409922851914806, 0.016715223335527947, 0.004346333161395575, 0.020841109799221158, 0.02545261020506067, 0.0708934540993401, 0.017202886453430568, 0.02875137435538428, 0.026620575925335288, 0.02698843350767025, 0.00847231037914753, 0.04695578697802765, 0.013776786725169845, 0.018375883510868465, 0.06459538705114808, 0.03984276205301285, 0.023334605552788292, 0.01452697504178754, 0.10555631374674183, 0.09681102194424186, 0.024555079705481018, 0.021190249993066703, 0.009721551023955857, 0.05415205118645515, 0.008094822688560401, 0.024491387319618037, 0.011237054747263235, 0.025688506296968887, 0.027760825186435665, 0.04891102634636419, 0.019982844424833144, 0.1830094712121146, 0.10657784143196684, 0.17098752701921122, 0.2500456640762942, 0.146766351003732, 0.1379372804824795, 0.12034122539418084, 0.14767760996307644, 0.18984485657087394, 0.08943780258830104, 0.15644050974931034, 0.08921483598117318, 0.11153458045529467, 0.0641345124957817, 0.11569412904126303, 0.15360263202871594, 0.2634809288595404, 0.12216975513313498, 0.13868151126163347, 0.10528446547687054, 0.22643176333180495, 0.11600240107093539, 0.12570197773831232, 0.12696086375841073, 0.22894140652247838, 0.11674766322331769, 0.16079553748880113, 0.11909023752169949, 0.19771107232996396, 0.07714318231280361, 0.1689521526651723, 0.12825804629496165, 0.12922630219587258, 0.13628179074398108, 0.1739929893187114, 0.221160211201225, 0.15988916398159095, 0.1784614274012191, 0.1333861696932997, 0.15856273658573627, 0.13756529401455606, 0.16071506323558943, 0.18107426219752856, 0.1096305094127144, 0.2937979820583548, 0.13586989284626075, 0.10497472102620772, 0.10941128831888948, 0.15503511444798537, 0.17327509926898138, 0.21169675114963735, 0.06807270938796656, 0.11105933452823333, 0.10990062063293797, 0.11031340062618256, 0.08934290268059288, 0.18594762283776486, 0.13717965542205743, 0.13406329335910933, 0.12252184695431165, 0.1630550455302, 0.17906438718949044, 0.07048010413667985, 0.1598373239061662, 0.15018593679581368, 0.11294103427124874, 0.14232455220605644, 0.19785124409411634, 0.14511700879250253, 0.19308889178293093, 0.14126203422035488, 0.10296422855130263, 0.1444912909397057, 0.08060447086713143, 0.11047198104539088, 0.34593322021620615, 0.2580842413008213, 0.21361631314669335, 0.09218460733869246, 0.1510408502072096, 0.24727498846394674, 0.20588645578495093, 0.09842146374285221, 0.17771623310233864, 0.25026789786560194, 0.10654572636953422, 0.24647868690746172, 0.13260548801294395, 0.17180949077010155, 0.1830498440457242, 0.18514704651066236, 0.13341827797038214, 0.10594011350933995, 0.07801106252840587, 0.10482977916087423, 0.22671754871095928, 0.27681916313511984, 0.3634675693299089, 0.4423510107610907, 0.2779342947261674, 0.2008717427296298, 0.17170627202306474, 0.17786077463201114, 0.19859464706054755, 0.16016055084764957, 0.17544052164469445, 0.09395751756216798, 0.06469600700906344, 0.14621267999921525, 0.1563154828867742, 0.16857773704188211, 0.09309338285986866, 0.13586682586797647, 0.1989103015512228, 0.074340445920825, 0.11131780887288706, 0.12074454660926547, 0.08180694348577942, 0.07923315837979317, 0.08380280674568244, 0.14771039677517755, 0.1286585448043687, 0.13685091877622263, 0.15245419793895312, 0.1858312405113663, 0.22473124600946903, 0.11786529182323388, 0.09599203017673322, 0.13063646081302846, 0.20435589791408607, 0.05493440545563187, 0.11585370690694877, 0.061725339985319545, 0.09359419598643269, 0.2414912102477891, 0.10644791554659605, 0.17461729581866944, 0.13083764644605772, 0.10364017156617981, 0.15100522711873055, 0.13425426025475773, 0.1223826522805861, 0.12957240933818476, 0.11907514690288476, 0.0498412842862308, 0.07918214611709118, 0.08183979815138237, 0.08322523095245872, 0.08613273993666683, 0.05313987371378711, 0.1469467191823891, 0.0654871788408075, 0.14381717996937887, 0.0869692854051079, 0.08283125316458088, 0.11244222282298974, 0.12351961912853376, 0.1013590046869857, 0.1714048667677811, 0.09301209436463458, 0.16126296669244766, 0.10523511562496424, 0.08148185735834496, 0.13186203076371125, 0.2054420696305377, 0.11455119108515126, 0.17056830094328948, 0.19612988217600755, 0.09765152327184166, 0.08986738310860735, 0.11383881752512284, 0.16653880716434546, 0.14455362116651876, 0.1342730556747743, 0.13225411543888704, 0.09126760118774005], [0.04453051961692316, 0.05665232041584594, 0.03733703061672194, 0.03264468276341047, 0.010698718634167952, 0.046003181487321854, 0.03882582465718899, 0.07292815670371056, 0.08629929992769446, 0.051545455519642146, 0.01334066258277744, 0.06192915154887097, 0.0804687435073512, 0.01729294501378068, 0.036076957160340886, 0.11333101548786674, 0.07995141483843327, 0.1166577437626464, 0.15613170846232347, 0.10033237441842045, 0.09920535489384617, 0.0739303936383554, 0.1004227145708033, 0.05774738094104188, 0.02755187711279307, 0.07613075378217868, 0.025716042944363186, 0.10478802890117679, 0.029489654382424693, 0.03555786769304957, 0.027207854769325683, 0.036042965948581696, 0.07128089759498835, 0.025605012562924197, 0.03380253491923213, 0.03929647011682391, 0.055558739096990654, 0.008398570585995913, 0.07319710084370204, 0.11830039561859199, 0.1034279258123466, 0.06993979348668031, 0.05821270668613059, 0.08874755605523076, 0.09829124608742339, 0.06718323818807091, 0.08407420718244143, 0.09516813938638993, 0.11680826997118336, 0.03069651372996824, 0.07144010905176401, 0.0434791465689029, 0.11373230109789542, 0.03736191249585577, 0.022187318187206984, 0.07928944964494024, 0.049758747286562405, 0.01980885277901377, 0.08499611914157867, 0.11944235648427691, 0.0783964025654963, 0.056042945078973255, 0.0460276596381196, 0.1788372000945466, 0.15476941370538302, 0.04571496695280075, 0.06299200880208186, 0.1529828988547836, 0.014536544081888028, 0.15593512329672063, 0.27205367599214825, 2.2620635671275, 1.7004652108464922, 1.9931409231254031, 2.9781169039862494, 11.091095873287745, 15.568583658763341, 16.171188763209752, 13.838364090238299, 12.86353530202593, 9.90498799937112, 9.255965454237801, 14.928619827542986, 18.720687798091344, 32.26990781511579, 33.0027516910008, 30.19340739931379, 27.490662370409282, 24.475173711776733, 7.864454065050397, 6.45094815322331, 2.357133597135544, 2.603945553302765, 2.539476041282926, 2.8652942265783037, 0.13603773526847363, 0.048049045992749076, 0.025661035806738904, 0.18184081677879604, 0.0798577159377081, 0.03434861990224038, 0.010694369224698415, 0.19314770719834737, 0.24570523841040476, 0.10386053259883608, 0.02055687826525952, 0.09795585301305566, 0.05357005134490984, 0.007790609146468341, 0.04364663276023098, 0.08225775536681924, 0.05340773219774876, 0.09137638392192976, 0.048583504278212786, 0.04856229666620493, 0.059075450391641686, 0.050535917548196654, 0.06618327434573855, 0.13718772998877934, 0.08625146320887975, 0.0567140908512686, 0.09439394450081245, 0.07020919224513428, 0.10954236771379199, 0.07354498574776308, 0.07577333546110562, 0.012257472179563982, 0.07871297986379691, 0.04844694232035961, 0.025054199887173514, 0.05970029293426445, 0.02923718507268599, 0.1141997506575925, 0.03967238190983023, 0.049512337294540236, 0.06960332832698311, 0.05981436824159963, 0.015874303012554134, 0.025349991961515377, 0.09459759321595941, 0.03746354007827384, 0.07541407152478184, 0.057405121092285426, 0.07117953124855246, 0.012255156678812844, 0.06296600055481706, 0.10878086821841342, 0.04537546195622001, 0.10996764632208006, 0.058292495618973456, 0.10774670621114117, 0.06161521375179291, 0.06406550548438515, 0.09928419387766294, 0.04566537622096283, 0.006681135265223149, 0.0333606084542615, 0.05513350459347878, 0.021505460043304732, 0.09547874557652644, 0.0320519688539207, 0.042918381480766196, 0.02407602719696505, 0.029350025446287224, 0.053700794864978106, 0.02941897478220718, 0.04758470073076231, 0.05726164486259222, 0.0551814363071961, 0.13451346063188144, 0.09496088086494378, 0.02823948414464082, 0.025454364218083874, 0.044674514925905635, 0.04602140015257256, 0.019767891316275512, 0.03323403113920774, 0.03739806144897427, 0.018354360380076935, 0.01750945027119347, 0.07744269445538521, 0.0785641907049077, 0.04724760114082268, 0.06461729694690023, 0.05144478467160037, 0.04411538510716387, 0.028091587259301116, 0.045911382484648905, 0.09770594178033726, 0.09948820221636977, 0.13072004275662558, 0.0805754227829831, 0.11429501697421074, 0.12348599093300955, 0.08112228808126279, 0.044512860743062835, 0.12010478308158261, 0.06614073698541947, 0.12383482578609671, 0.10814360848494939, 0.04909565233226333, 0.10682672807680708, 0.08760398706155163, 0.08662108837493829, 0.043259209620633295, 0.040823204442858696, 0.10974868985691241, 0.036575995917831144, 0.14010348995881422, 0.06772461413804974, 0.06611420626619033, 0.03446105654750552, 0.064840514611985, 0.0610372783350093, 0.14160337804683618, 0.08961198931293828, 0.17092986511332647, 0.07273068944258348, 0.1178061371403081, 0.08931223968310015, 0.1805620225412505, 0.0908180106697338, 0.03416725427710584, 0.04996722038569195, 0.1323697649474655, 0.042604070489427874, 0.07009327810789857, 0.028324602970055172, 0.08074445942682879, 0.04403621024851288, 0.024450205332998718, 0.059898696573717256, 0.08043561064239059, 0.024716817008863603, 0.042589370028248856, 0.14153188759727137, 0.04606185780305948, 0.04772226692044309, 0.08756317318017993, 0.24672078820211546, 0.1893862618931702, 0.18502119183540344, 0.0993205565693123, 0.11291984362261635, 0.08086960164031812, 0.19752109609544277, 0.1692274614636387, 1.594679321561541, 1.2504112805638994, 1.181618251970836, 1.8823432113443102, 8.950358492987496, 13.27803703716823, 13.85133637700762, 11.647335648536682, 10.852062208311898, 9.369632772036962, 8.019881793430873, 14.667225122451782, 20.403499807630265, 33.94141510554722, 33.74955102375576, 31.26685197012765, 28.868431091308594, 25.797527074813843, 7.536504302706037, 5.311609038284846, 1.5230627187660761, 2.0756455702441077, 2.1896524812494005, 2.705590750489916, 0.12338852616293089, 0.05722991656512022, 0.09590071293392352, 0.06535606551915407, 0.08424460089632443, 0.03700326941907406, 0.03377853513562253, 0.22681605842496666, 0.2903940704252039, 0.04582069967208164, 0.10346723334597689, 0.07166980672627687, 0.05814170478177922, 0.022273424281073467, 0.04118061937125666, 0.10531424637883902, 0.04815890420494335, 0.07920290250331163, 0.08902983340833868, 0.005228433774651161, 0.05147525089393769, 0.07168138253369502, 0.12257161071257931, 0.06330132577568293, 0.08629385807684489, 0.08520822240305798, 0.01800054168727781, 0.0628760200259941, 0.03956651348354561, 0.09888824833823101, 0.10940619252089943, 0.0327555112806814, 0.03209893026256135, 0.01786048527407859, 0.028580010336424624, 0.07091247343591281, 0.14828225251819405, 0.06246442746903215, 0.08409511284636599, 0.017509182249861102, 0.04307167950485434, 0.04182810802012682, 0.10518079211137124, 0.041377486128892214, 0.04325763202671494, 0.0826385695753353, 0.09457662648388318, 0.061742364428937435, 0.08849359396845102, 0.08175534768296139, 0.05017723036663873, 0.1509869745267289, 0.09375173824706248, 0.0661491033221994, 0.12276450464768068, 0.017772686235340576, 0.07722574645387274, 0.1079413846933416, 0.096061518947993, 0.09334636785622154, 0.06313349692417042, 0.04737133539414831, 0.044825485574879816, 0.04175955562719277, 0.04215871063726289, 0.050770904403179884, 0.07199217871363674, 0.004794334635205034, 0.03901486112070935, 0.03154728129240019, 0.016078592943293706, 0.06703213522476809, 0.029235081614128182, 0.05787512194365263, 0.04713495754237686, 0.0914683932704585, 0.02279722278139421, 0.057461860190544806, 0.03449894255027175, 0.03968823588054095, 0.06499688979238272, 0.1412647890725306, 0.1433470230549574, 0.09404262620955706, 0.13655970511691912, 0.15025347817156995, 0.2831120868878705, 0.20711963889854296, 0.1378240194171667, 0.13812043065471308, 0.19935246211077484, 0.14731786426688942, 0.2438087330332824, 0.15116652846336365, 0.15761088766157627, 0.20863431904997143, 0.25765945123774664, 0.1776307105485882, 0.22477381729653903, 0.2538691003407751, 0.2858662876699652, 0.18194148423416273, 0.19143051148525306, 0.19523591228893825, 0.27956647000142504, 0.1809847362871681, 0.18834563344717026, 0.20130935710455689, 0.16255922642137322, 0.19504479611558573, 0.17178534849413804, 0.23253221384116582, 0.21386853818382534, 0.4935953052980559, 0.19770867031599793, 0.15332205779850483, 0.18653707977916512, 0.13846143521368504, 0.17759997291224344, 0.3780393802693912, 0.23250694519707135, 0.26492930256894653, 0.15471062543136732, 0.28954112476536203, 0.29540640860795975, 0.41561426115887506, 0.1736847580011402, 0.15498400719038077, 0.14162749318139894, 0.36256424923028263, 0.14054377776171478, 0.18745747181986058, 0.2000090397362198, 0.182050104119948, 0.11199455255908625, 0.11325572524219751, 0.24610551978860581, 0.2072832336915391, 0.16973238651241573, 0.18662079742976598, 0.35206215562564985, 0.2511175594159535, 0.11711568704673223, 0.14279061076896532, 0.516793929040432, 0.29028759471007753, 0.25283780853663174, 0.1522007379680872, 0.3494689033499786, 0.11499374519501414, 0.42648498926843914, 1.033006380711283, 3.5300574813570296, 3.2120128103664944, 3.1446925827435086, 5.239570115293775, 16.86101634161813, 23.27755093574524, 24.58734369277954, 20.47931855065482, 19.397477081843785, 17.091995307377406, 14.520777940750122, 21.980822529111588, 31.21250663484846, 46.56397124699184, 47.18893391745431, 45.90816552298409, 41.81812926701137, 37.27413593019758, 13.800881164414541, 9.442117248262678, 4.052966747965131, 4.565704720360892, 4.130370983055659, 5.132583490439823, 0.5333878014768872, 0.2446695225579398, 0.1798753451023783, 0.3254291947398867, 0.23684593236872128, 0.21223544010094234, 0.13909142783709935, 0.22546485093023094, 0.4169044547847339, 0.20480972927595886, 0.32764146317328724, 0.22252030750470503, 0.1522469733442579, 0.1405789665877819, 0.1924164771501507, 0.26973626177225796, 0.23211895887340817, 0.14906578404562815, 0.18219875757183346, 0.18958961883825914, 0.1746816209384373, 0.16869808201278957, 0.20582635115299905, 0.17900859804025718, 0.1726206929555961, 0.18729441985487938, 0.22384043809558662, 0.22873271629214287, 0.20772718558354036, 0.3238127886184624, 0.16409323125013284, 0.11753297251250062, 0.28339726158550804, 0.193228507148368, 0.1265900850828205, 0.17433304392865726, 0.18016885221004486, 0.1750621162354946, 0.21634976432791778, 0.1902857550552913, 0.21578915869551046, 0.13539542044912065, 0.1979727697159563, 0.1443938940231289, 0.15155114925333432, 0.1910438822316272, 0.25934210951839176, 0.21087894003306115, 0.2556814130927835, 0.28430790986333576, 0.19759132446987288, 0.31386706658772057, 0.16850772579865797, 0.22590212603764875, 0.3221110499330929, 0.2696709324206625, 0.2061547078192234, 0.16881728704486573, 0.18225515740258352, 0.16340890154242516, 0.205106968326228, 0.1347335638212306, 0.10723336054278271, 0.12064102930682045, 0.21249921380409173, 0.16080452129244804, 0.13068367327962602, 0.13257472323519842, 0.219241449875491, 0.2316484355500766, 0.1526153500058821, 0.14450654440692492, 0.15270893355565412, 0.17917958886495658, 0.30904051129307064, 0.2049915630902563, 0.16093980760446616, 0.1284592319279909, 0.13283821195363998, 0.15556518600455352, 0.1498988622001239], [0.02285611962101289, 0.02536212247131126, 0.028201440382482748, 0.042643517122737, 0.03755323901506407, 0.046590511221438646, 0.03597852887053575, 0.07125708780118398, 0.018138813553377986, 0.04243552239079561, 0.03193393090207662, 0.062278488517871926, 0.06070558327649321, 0.07952842289315802, 0.02273031074686774, 0.013688533916138113, 0.033878663155649386, 0.011193949113866048, 0.036829713732004166, 0.046657462271728685, 0.020727394115445868, 0.032224516916487894, 0.05946528911590576, 0.09952896181493998, 0.06822518299200706, 0.04382804249014173, 0.012810829361634595, 0.0758154657004135, 0.011092425008038325, 0.03422501117789319, 0.028756120707839727, 0.04230108764022589, 0.06315772062433617, 0.02951953367197088, 0.0355812941145684, 0.04923581391839044, 0.02403614460490644, 0.01613296565067555, 0.004195558863492417, 0.060181754242096624, 0.08780581051749842, 0.04606597651062267, 0.02728600673643606, 0.07957277872732707, 0.028897344201271023, 0.013384790259546466, 0.052165721343564134, 0.03821860706167562, 0.01719879319093057, 0.005992707206002835, 0.04245193615289671, 0.0028015720682950424, 0.035865301731973886, 0.027460800749914985, 0.07301944001976933, 0.029314745017992597, 0.019184368163613335, 0.022016771802944795, 0.06892877630889416, 0.012568143678696027, 0.1050739296312843, 0.06721493934414216, 0.08538891627852406, 0.15245027600654534, 0.05405710038862058, 0.49582198581525255, 2.1870312733309607, 11.494612506457738, 29.83775690623692, 43.07778903416225, 54.89788382393973, 71.68230669839042, 68.19138581412179, 77.76414135524205, 82.33546543121338, 85.9885503223964, 102.73660632542202, 95.71739714486259, 100.29600293295724, 103.42329679216657, 100.33779634748186, 102.36757360185895, 114.55428314208984, 113.5692161832537, 128.5410485948835, 115.85379082815987, 123.96939795357841, 116.88461167471749, 110.90054512023926, 95.61186790466309, 89.78220421927315, 83.88199547358921, 79.04658426557268, 77.4388336454119, 65.39868940625871, 48.952668121882844, 29.505275181361608, 17.821627378463745, 7.441614491598947, 5.095202616282871, 3.673561232430594, 1.6272783151694705, 0.20303618801491602, 0.04098283998402102, 0.06287635250815324, 0.06022136711648532, 0.07704213487782649, 0.10333150598619666, 0.08288259790944201, 0.024024244797016894, 0.03538242567862783, 0.0021225658918930484, 0.02355161971146507, 0.032341740626309595, 0.046244421042501926, 0.05012836905994585, 0.044738158117979765, 0.025612437432365756, 0.005530218161376459, 0.07656897205327239, 0.024453925401238457, 0.06693156954965421, 0.014623489862840091, 0.02844154169516904, 0.05586857854255608, 0.05709240465824093, 0.029642915087086812, 0.03690631355025938, 0.009495592925564518, 0.05601413787475654, 0.006854958549541022, 0.04288246662222913, 0.03597631684637495, 0.022204424055027108, 0.11927108067486968, 0.052454604235078604, 0.06656335573643446, 0.025838177551382353, 0.017634312588987604, 0.04121346725150943, 0.04975303741438048, 0.01501753889689488, 0.06070153920778206, 0.004097946936131588, 0.045531457157007287, 0.028638981814895357, 0.015383150528318115, 0.024326620357377187, 0.02875862450205854, 0.013551948209559279, 0.028999409438776116, 0.027225564533312405, 0.1110461913049221, 0.09543406404554844, 0.006581477554781097, 0.014419732582090157, 0.03091076455478157, 0.0378167888016573, 0.07489956556154148, 0.030250804432268654, 0.0510527848133019, 0.055631586616592746, 0.046545049375189204, 0.05094822256692818, 0.008706051274202764, 0.031662995261805396, 0.07504542344915015, 0.059505254828504155, 0.050758236154381714, 0.05396952187376363, 0.04818410838821104, 0.0440616044215858, 0.02273496040808303, 0.013259009374970836, 0.02865269161494715, 0.01334992204127567, 0.030674712399819067, 0.012157860694320073, 0.008730849184628044, 0.0366615184715816, 0.04564758503277387, 0.01566031003104789, 0.009014360623301139, 0.024214283796027303, 0.03696289997813957, 0.030538326861070733, 0.022302979570148245, 0.08748623409441539, 0.015557249043402928, 0.057451139337250164, 0.02176873163054032, 0.03248846364606704, 0.0338867920051728, 0.03296797755839569, 0.0317270523602409, 0.022235662110948136, 0.029566674892391478, 0.017288548106859838, 0.024578009100098695, 0.007973514197926437, 0.02139717772869127, 0.0745022493813719, 0.01867772642123912, 0.0830194109252521, 0.0412450089518513, 0.03217648681519287, 0.02969311989311661, 0.04056929324620536, 0.04517925337755254, 0.015863337886652777, 0.01783775265461632, 0.059140942591641626, 0.07014724199793168, 0.028887142427265644, 0.09049822390079498, 0.036736493198467154, 0.07175908836403064, 0.046397145704499314, 0.019148868907775198, 0.05209915027288454, 0.04042031070483582, 0.03408621683982866, 0.03936732952882137, 0.05010933954534786, 0.024746604696182267, 0.03458681622786181, 0.011361150320486298, 0.01071576597834272, 0.04291182683248605, 0.03379715752920934, 0.1315943215574537, 0.05381174212587731, 0.04198032717353531, 0.019162046057837348, 0.05967254763735192, 0.03417199045153601, 0.042245057611060996, 0.014881935369755541, 0.06363200303167105, 0.24807783109801157, 0.1691165752708912, 0.21571937815419265, 1.5584965773991175, 10.118953432355609, 28.765347617013113, 43.68542289733887, 57.74590178898403, 74.36917509351457, 71.37682914733887, 81.966370173863, 92.76785210200718, 101.60833699362618, 117.51873207092285, 113.16674872807094, 113.61653341565813, 117.41489819117955, 113.57480253492082, 118.17365537370954, 129.64902223859514, 132.28743389674594, 148.48699215480258, 138.7783715384347, 143.47875840323312, 136.03026172092981, 129.7256747654506, 109.39098644256592, 101.51908043452671, 95.50466414860317, 88.73461736951555, 87.15046283176967, 74.62475763048444, 56.23206302097866, 33.162799971444265, 22.84565612248012, 9.188894493239266, 7.046222039631434, 4.72218336377825, 2.625080236366817, 0.17192501814237662, 0.0668681672375117, 0.020293666049838066, 0.04410990593688829, 0.041387552195893865, 0.034915532517646036, 0.2256892831729991, 0.06272949717406716, 0.040535027227763615, 0.02730379283561238, 0.005403061971134905, 0.061134288486625464, 0.07773692759552173, 0.0068247349034728745, 0.054193234869412014, 0.04965124698355794, 0.08515151044619934, 0.06200442822383983, 0.06971048257712807, 0.037494600018752475, 0.0055976666626520455, 0.006020366413784879, 0.016307630742500936, 0.03609792389241712, 0.021600639846708094, 0.024635833854387914, 0.01290789888506489, 0.05317170379151191, 0.024573605407827666, 0.049748162140271494, 0.04554487857967615, 0.0692695840927107, 0.08862392018948283, 0.04336185500557933, 0.07632569689303637, 0.04128916461818984, 0.06828036145972353, 0.06184703524091414, 0.02603493913609002, 0.038201070324118645, 0.06296790045286928, 0.020659321786037514, 0.09908547811210155, 0.05661159813670175, 0.018544224656320045, 0.032959767284670045, 0.061142953378813605, 0.0603153577872685, 0.0177061049866357, 0.0223544854670763, 0.09774574464453117, 0.04788444018257516, 0.02543395558106048, 0.061261466305170736, 0.05139330082706042, 0.06518041994422674, 0.08620774519762822, 0.015324279133762633, 0.07525478542915412, 0.03359641294394221, 0.01330093520560435, 0.05785583797842264, 0.005715839049246694, 0.02575545904359647, 0.05598879459181002, 0.08121798187494278, 0.032562420570424626, 0.050490645691752434, 0.056520369103444476, 0.05893479008227587, 0.004536881485754358, 0.025151832594669292, 0.04192959311019097, 0.053167439198919704, 0.22089183703064919, 0.15206541094396794, 0.12869496856416973, 0.11674910171755723, 0.11300625505724124, 0.0783339502023799, 0.10894007967518908, 0.12612626568547317, 0.12424308673611709, 0.13766775280237198, 0.20104816183447838, 0.21083252823778562, 0.14238807665450232, 0.18491652102342673, 0.054626632149198225, 0.11870128767830984, 0.173929736284273, 0.08324860648385116, 0.13940071766929968, 0.12059691095990793, 0.127318071733628, 0.11200701046202864, 0.12247052256550107, 0.19310984494430677, 0.20883079564997128, 0.22023464872368745, 0.09827955492905208, 0.2247885007943426, 0.10712829618049519, 0.09392152806477887, 0.1477169514234577, 0.09934060727911335, 0.12948371124054703, 0.16506857105663844, 0.15373732122991765, 0.12988217414489814, 0.14445984762694153, 0.11737232256148543, 0.1500867349760873, 0.11886537101651941, 0.3244368779872145, 0.21443717767085346, 0.09128634232495512, 0.1534951656524624, 0.17229500971734524, 0.12672123233122484, 0.4088629191475255, 0.11441367917827197, 0.10648336900132042, 0.10932815420840468, 0.10254892440778868, 0.11864419574184076, 0.20030485386294977, 0.12250105664134026, 0.25239771072353634, 0.12898369878530502, 0.1006464139957513, 0.07695423745151077, 0.1072103717763509, 0.11182918678969145, 0.0987401105729597, 0.10944743387933288, 0.18950774680290902, 0.28894775946225437, 0.38957165288073675, 0.9662561225039619, 5.584119558334351, 20.959989718028478, 44.86890261513846, 63.893758228846956, 80.71260942731584, 98.14015061514718, 96.82136167798723, 105.23833996909005, 115.36729880741665, 123.48452486310686, 141.54656164986747, 132.64797592163086, 138.0260900769915, 138.33987072535922, 137.79766110011508, 141.33075060163225, 155.2619582584926, 153.3196588243757, 167.10998480660575, 156.40296363830566, 164.46462494986397, 155.60072462899345, 150.51611627851213, 130.90411703927177, 123.9018336704799, 114.28451933179582, 109.8124919618879, 109.14078875950405, 93.90655067988804, 72.82986422947475, 44.88421991893223, 31.750262464795792, 13.095900433404104, 8.60643916470664, 7.279641994408198, 3.7124029653412953, 0.5088260823062488, 0.2677314893475601, 0.2611395487827914, 0.21711420187992708, 0.11633864231407642, 0.1760249709976571, 0.30273553675838877, 0.1956631179366793, 0.16189236220504555, 0.14217330675039971, 0.10789526466812406, 0.1300090059105839, 0.12773543862359865, 0.1604288164526224, 0.2787133886345795, 0.12392953570399966, 0.11328112280794553, 0.16774564954851354, 0.13950078801384994, 0.23108270019292831, 0.09546564306531634, 0.13990925252437592, 0.16194208525121212, 0.14662852697074413, 0.18188530153461865, 0.14613124222627707, 0.05852814404559987, 0.16028401707964285, 0.1390115778361048, 0.15960496637438024, 0.1688320655375719, 0.1303935588470527, 0.22802978115422384, 0.13522594954286302, 0.14130556902715138, 0.1768997112022979, 0.15918151981064252, 0.12289296489741121, 0.12508296381149972, 0.17875754008335726, 0.14288662347410405, 0.1440116073936224, 0.190257799412523, 0.12264430895447731, 0.11731814832559653, 0.15109476659979137, 0.16980505761291298, 0.20310697278806142, 0.09512813296169043, 0.13238328136503696, 0.165684382298163, 0.1782872746033328, 0.20153510570526123, 0.15042754954525403, 0.11761625590068953, 0.16894175750868662, 0.19189144032342093, 0.12939050767038549, 0.218367211786764, 0.15325275223170007, 0.0876813671950783, 0.12981252931058407, 0.09362858414117779, 0.16902437593255723, 0.1152055159743343, 0.19533128717115947, 0.08438783285341092, 0.11914798085178648, 0.18533253084336007, 0.17833232932857104, 0.11935793315725667, 0.11998993424432618, 0.20310191091682228, 0.11111248417624406], [0.0682819899437683, 0.10316854901611805, 0.027051732343222414, 0.03277292588193502, 0.11714820244482585, 0.0537755015705313, 0.051444618430520804, 0.018162319702761512, 0.026716189991150583, 0.05439478351867624, 0.010633141617290676, 0.022900538219671165, 0.041247655238424025, 0.04534449701064399, 0.07468535205615418, 0.049810773959117274, 0.051538011990487576, 0.033057649353785176, 0.008621591475925275, 0.019227638341752545, 0.1187362050903695, 0.053852159064263105, 0.03116349849317755, 0.059133342999432764, 0.07295970179672752, 0.028448980135310973, 0.03399638898138489, 0.04359231942466327, 0.11921363590019089, 0.06980428325810603, 0.02867627070684518, 0.11995710672012397, 0.1147535437984126, 0.056288917415908406, 0.09587934586618628, 0.07151734669293676, 0.022544071543961763, 0.05465635198301502, 0.02599206250826163, 0.05916908822421517, 0.03645335410588554, 0.09036428787346397, 0.09462571849248239, 0.04323523019307426, 0.02011396622817431, 0.07289216042097126, 0.0578406455793551, 0.07508607448211738, 0.12425243694867406, 0.05523405669789229, 0.1288912280329636, 0.07238496906523194, 0.03600264061242342, 0.040351507253944874, 0.016365689591371586, 0.024783393168555837, 0.02765745546535722, 0.16734516460980686, 0.04179077163072569, 0.05310023709067276, 0.05263463993157659, 0.5931524059602192, 4.696686514786311, 12.744748030390058, 25.568874018532888, 42.90468856266567, 66.78618213108608, 84.8412846156529, 95.17527784620012, 94.3212400163923, 96.07597282954625, 86.55318178449357, 103.32686969212124, 88.56002303532192, 89.5411434173584, 81.89226068769182, 90.54038470132011, 86.34137289864677, 81.7546307700021, 81.2860859462193, 88.80338369097028, 100.18169116973877, 82.44116142817906, 85.0138361794608, 93.7124388558524, 98.67525918143136, 105.62301308768136, 96.50030626569475, 99.10813890184674, 97.47734110695976, 101.28575992584229, 95.33164010729108, 97.7394688470023, 106.72201660701207, 95.36312239510673, 95.45395619528634, 100.29210499354771, 112.15857900891984, 90.56698935372489, 86.1683349609375, 94.66352912357875, 79.99291501726422, 54.77775641850063, 21.277857644217356, 8.747447643961225, 2.3587586070810045, 0.55050371161529, 0.17559237778186798, 0.41060108159269604, 0.12080963168825422, 0.13955534222934926, 0.08571402954735927, 0.03398683520832232, 0.0632103681564331, 0.05131195126367467, 0.032966501744730134, 0.08408581013126032, 0.07820326435778822, 0.002922573309790875, 0.038705035245844295, 0.09873308773551669, 0.06575142751846995, 0.09969102311879396, 0.08340981961893183, 0.11984400850321565, 0.08807505321289812, 0.05460762977600098, 0.04577117679374559, 0.03144447645172477, 0.06343511931066002, 0.01639306339036141, 0.12734700446682318, 0.03514200375814523, 0.048925119518701515, 0.06787633456821952, 0.022303583466314843, 0.03496335566576038, 0.08570634174559798, 0.09493563936225005, 0.06030409410595894, 0.01431966563021498, 0.0639858590438962, 0.052610534975039105, 0.06017904010202203, 0.08865687663533858, 0.056221287830599716, 0.06452467691685472, 0.15084471287471907, 0.031090260815939734, 0.046736124836440594, 0.03918027438755546, 0.0489134792504566, 0.01949240100969161, 0.07416484784334898, 0.03613146387838891, 0.022565779575545872, 0.12459543640060083, 0.07327296105878693, 0.04931805914800082, 0.037715476738022904, 0.05946254783443042, 0.0311334020724254, 0.10903613987777915, 0.06024909884269748, 0.051845205149480274, 0.010809081506782343, 0.09588851287428822, 0.047559706893350394, 0.05740957228200776, 0.07976864464581013, 0.07771558088383504, 0.029343664180487394, 0.095042101506676, 0.037418872117996216, 0.05237810619707618, 0.06627584687833275, 0.05035198027534144, 0.07827043932463441, 0.02020074237537171, 0.025361888376729827, 0.03392910544893571, 0.02962538513488003, 0.0335376280626016, 0.05261104726897819, 0.03932128753513098, 0.021628863510808775, 0.030711797731263295, 0.07505404084388699, 0.05861468440187829, 0.07789755719048636, 0.12292353968535151, 0.08880926881517683, 0.09584528340825013, 0.025500811636447906, 0.059665769072515626, 0.06536773632147483, 0.04383481087695275, 0.08623841498047113, 0.045107240456023386, 0.04028344340622425, 0.07858472317457199, 0.0748513081510152, 0.06961480235414845, 0.10655348881014756, 0.01773243214535926, 0.09891357126512698, 0.018226207167442356, 0.1155621132680348, 0.08701824170670339, 0.04677418725831168, 0.01759377181796091, 0.11301021770175014, 0.04839252041918891, 0.047863839859408994, 0.07612575297909123, 0.0239304865244776, 0.08054161816835403, 0.11926591023802757, 0.12077569136662142, 0.09451067288007055, 0.06717373869780983, 0.10530872310378722, 0.09432792982884816, 0.06558687599109751, 0.0681075860879251, 0.04982786625623703, 0.11471878923475742, 0.02047361184044608, 0.04307695850729942, 0.08195166821990695, 0.05387768215898957, 0.025198870338499546, 0.013498846058999854, 0.10429617243685893, 0.12654399898435387, 0.018330923780532818, 0.07274517616523163, 0.4083272564624037, 5.179816475936344, 13.49619744505201, 28.28016185760498, 48.11622313090733, 75.78373800005231, 95.59458078656877, 104.94020666394914, 109.90895380292619, 113.75932584490094, 104.64125347137451, 118.1402484348842, 112.38068512507847, 103.26698316846574, 99.98687757764543, 110.20325170244489, 100.15132059369768, 100.767792565482, 101.22852761404855, 107.8230698449271, 117.64446667262486, 108.57289859226772, 102.28516101837158, 109.81641074589321, 115.29681628090995, 122.0856579371861, 109.34794930049351, 112.34334550585065, 115.19653987884521, 114.21047237941197, 115.49617399488176, 120.46482385907854, 121.75568798610142, 110.69972828456334, 111.8222792489188, 117.92397880554199, 131.75785609654017, 113.4101093837193, 101.37040982927594, 113.78268568856376, 93.11492156982422, 63.65760980333601, 27.203472478049143, 10.45548335143498, 3.0063359269074033, 0.9973974057606289, 0.11231502464839391, 0.4396288368318762, 0.11791011584656579, 0.12179775509451117, 0.05800412502139807, 0.012369927484542131, 0.016549830424732397, 0.15386717926178659, 0.05656276397140963, 0.0716230013806905, 0.08857393930000917, 0.05682975393054741, 0.17270278212215218, 0.09702133387327194, 0.02520617307163775, 0.1162559153246028, 0.017634845238977244, 0.04701532503323896, 0.03395062518705215, 0.09634824749082327, 0.10235652580325093, 0.0644486809947661, 0.059866961490895064, 0.014897836837917566, 0.06287510400371892, 0.03327556087502411, 0.08589299994387797, 0.015207072387316396, 0.0790864998208625, 0.01937063450792006, 0.03236296180901783, 0.0730736753238099, 0.008921761797474963, 0.03161092109179922, 0.023553750311423625, 0.007267042196222714, 0.02344382424572749, 0.10444710576640708, 0.06009298829095704, 0.04820752123902951, 0.05853528223399605, 0.10055122231798512, 0.058346561289259365, 0.029696617741137743, 0.06405568029731512, 0.0419568905739912, 0.11346284127128975, 0.05183902369546039, 0.025446131891970123, 0.11248188998017992, 0.11089681860591684, 0.022466068854555488, 0.028248734273282543, 0.08766127577317612, 0.023646847012319734, 0.05724312085658312, 0.07621058342712266, 0.07539387153727667, 0.0934011120615261, 0.040813175695283074, 0.014969367999583483, 0.06768456021589891, 0.09186527518821613, 0.04315015886511121, 0.05170487732227359, 0.10369432544601814, 0.056536172184028795, 0.0555550478664892, 0.031038346101662943, 0.20920119434595108, 0.2508394686239106, 0.20941752488059656, 0.13773860542901925, 0.2200929434703929, 0.1658872506980385, 0.19541176142437117, 0.10077068089906659, 0.16431539718593868, 0.11674367343740803, 0.20929357010338986, 0.22216821568352835, 0.22985039917486055, 0.14844501949846745, 0.29457438896809307, 0.16429168917238712, 0.16785132459231786, 0.16068311780691147, 0.13860957297895635, 0.11479060538113117, 0.1509213059076241, 0.14124118962458201, 0.19566542495574268, 0.18521403148770332, 0.17290708901626722, 0.13906598277390003, 0.17141121785555566, 0.183808405484472, 0.18965037486382894, 0.14088870425309452, 0.19001356751791068, 0.15896763200206415, 0.21326450631022453, 0.2960304708353111, 0.2589449765426772, 0.18383634755653994, 0.1970590544598443, 0.15484982010509285, 0.17874799988099507, 0.08265600792531456, 0.1702339867396014, 0.22293106546359404, 0.31987003875630243, 0.2263534739613533, 0.13723000272044114, 0.18855990123535904, 0.2796494412635054, 0.19533078505524568, 0.16861307514565332, 0.18963921974812234, 0.2114311046898365, 0.16843429473893984, 0.15311183407902718, 0.25392699294856613, 0.14103909475462778, 0.12446313564266477, 0.10509398712643556, 0.2597058857125895, 0.17845059798232146, 0.1311712956854275, 0.11231966582792145, 1.3860497793981006, 9.647875990186419, 24.59132501057216, 43.548543385096956, 65.15527316502163, 96.40423352377755, 115.69092505318778, 122.28892053876604, 124.89610699244908, 128.19691821507044, 113.1861411503383, 132.10864285060336, 117.63147354125977, 116.6999841417585, 106.58841664450509, 114.1156086240496, 111.17154570988247, 106.39732033865792, 109.25091075897217, 115.76654924665178, 125.55671392168317, 107.89421245029995, 109.06886795588902, 118.13428688049316, 126.2482681274414, 130.83357892717635, 120.47808102199009, 127.09580939156669, 125.03009605407715, 129.29237120492118, 124.52599034990583, 127.69812093462262, 133.8757781982422, 127.00263404846191, 126.73714338030133, 132.97720936366488, 150.05293546404158, 129.6107793535505, 119.83366339547294, 131.89814022609164, 113.35999202728271, 78.75968619755336, 36.27807692119053, 14.940555095672607, 4.807792552879878, 1.503137239388057, 0.22591212764382362, 0.6554791586739677, 0.1985223830810615, 0.21411532137010778, 0.18796242401003838, 0.1798070573381015, 0.15868042169937066, 0.20748280441122396, 0.18399653610374245, 0.16465668672961847, 0.25439504640442984, 0.3177209555038384, 0.21235467227441923, 0.2540906013122627, 0.21421715590570653, 0.24457336057509693, 0.17168694734573364, 0.20791778607027872, 0.22667305038443633, 0.17452068600271428, 0.21226163155266217, 0.15695323795080185, 0.12481135981423513, 0.16589717088001116, 0.20079732100878442, 0.07372021063097886, 0.16193865186401776, 0.1427416205406189, 0.128047021904162, 0.11398302657263619, 0.15007863326796464, 0.20728564927620546, 0.10002538481993334, 0.060197095918868265, 0.10439800697245769, 0.11228645153875862, 0.14247989601322583, 0.19772004256291048, 0.19305408293647425, 0.18749941885471344, 0.2815834017736571, 0.20203506387770176, 0.106879884510168, 0.15008172738764966, 0.15581950092954294, 0.10200258836682354, 0.2473563855247838, 0.11871850889708314, 0.13670065041099275, 0.15233824987496647, 0.1211395218436207, 0.11041367453123842, 0.27641546194042477, 0.16338357861552918, 0.10618123092821666, 0.21698441170156002, 0.1569427206580128, 0.13231089524924755, 0.21425269756998333, 0.20929423506770814, 0.26340970982398304, 0.23499374889901706, 0.19377380503075464, 0.15628598018416337, 0.1078167242397155, 0.18931597923593863, 0.11051782287125077, 0.1566796933433839, 0.2179922397647585], [0.07847281239394631, 0.07605188087161098, 0.05900825506874493, 0.029287763072976043, 0.04031810297497681, 0.05719759115683181, 0.024454273150435517, 0.053504236840776036, 0.017478690582460592, 0.04580355987751058, 0.040208879193024974, 0.08275032429290669, 0.05726613676441567, 0.06891236933214323, 0.04946351330727339, 0.10204662528953382, 0.0583384120836854, 0.038033994646476846, 0.06486906058021955, 0.055277544007237465, 0.05306309747642704, 0.01239080515889717, 0.02793874215733792, 0.04106336173468402, 0.053846639181886397, 0.06196136160620621, 0.06231860350817442, 0.05596422144610967, 0.06743673208568778, 0.07561852769660098, 0.08832486266536371, 0.0757821835577488, 0.04706305997180087, 0.07871282380074263, 0.07969152235559054, 0.06841752731374331, 0.04533819342032075, 0.10885816692773785, 0.0789141044286745, 0.06640679735158171, 0.06653507439685719, 0.030385432565318685, 0.09395281531448875, 0.07357663940638304, 0.025893791977848326, 0.02000088327830391, 0.04534261068329215, 0.05303264821746519, 0.05492558789306453, 0.03306703010041799, 0.024466817566592778, 0.031779995055070946, 0.06886991339602641, 0.06551183680338518, 0.043566127972943444, 0.048610655856984, 0.023949125881439874, 0.09677047947687761, 0.14479205837207182, 0.19127128645777702, 13.763142892292567, 45.54240540095738, 64.9619951248169, 77.21108559199742, 85.58640248434884, 88.25274590083531, 77.67965820857457, 79.69936752319336, 72.97406714303153, 87.94591345105852, 80.44583334241594, 70.8740713936942, 57.444061619894846, 49.14516796384539, 59.03302083696638, 31.527801990509033, 39.54097529820034, 40.81170701980591, 57.010309900556294, 45.62207692010062, 38.24113757269723, 50.13683918544224, 52.940989698682515, 50.68127918243408, 61.896693093436106, 52.979972566877095, 52.0821749823434, 55.848525932856965, 69.07821914127895, 52.411804471697124, 64.04871695382255, 59.62197099413191, 48.26288570676531, 78.99232578277588, 75.01543399265834, 89.72197723388672, 78.20116915021623, 82.81848335266113, 100.74821254185268, 93.20725618089948, 92.4650079182216, 89.96230152675084, 98.85888617379325, 98.84572628566197, 90.44595868246896, 78.10179601396833, 59.116572925022666, 32.57464190891811, 12.657921603747777, 2.6374604063374654, 0.05045901578185814, 0.17295309369053158, 0.06858142744749784, 0.09112656768411398, 0.02562005738062518, 0.06399849336594343, 0.11352509007390056, 0.03760913672990032, 0.04951547212632639, 0.0684323940160019, 0.028883284955684627, 0.041751138400286436, 0.07917954732796975, 0.12866680936089583, 0.02478891983628273, 0.10130753102047102, 0.05266244290396571, 0.06352598193500723, 0.024459184047632983, 0.07544550126684563, 0.07017221887196813, 0.0613036576126303, 0.05288021193285074, 0.026879579527303576, 0.04250734192984445, 0.04862244540293302, 0.0351535626021879, 0.07229872726436172, 0.05900915752031973, 0.012586179987660475, 0.03983870780627642, 0.02736450475640595, 0.04659689962863922, 0.020493766026837484, 0.11925300450197288, 0.009661482015092458, 0.05845322020884071, 0.01432760788260826, 0.09492916613817215, 0.13059033400246076, 0.03189721876489265, 0.05231884294854743, 0.14010391065052577, 0.05230285666350808, 0.07184670080563851, 0.016657883733777062, 0.03945023972275002, 0.08087933183248554, 0.02068872779740819, 0.03528556480471577, 0.04563339347285884, 0.043186942248472145, 0.0440494518594018, 0.04228949826210737, 0.021856834313699176, 0.034214558345930915, 0.01731425610237888, 0.061358035409024785, 0.056866978361670456, 0.10096334413226161, 0.04507170896977186, 0.10320081335625478, 0.036493258750332255, 0.02657163658711527, 0.007789492956362665, 0.09509918665779488, 0.03275306176926408, 0.06998301616736821, 0.043109962450606484, 0.016854999853031974, 0.01725579352517213, 0.10869914546076741, 0.010234780493192375, 0.03896482934110931, 0.0311643771960267, 0.07992440914469105, 0.0113246519218332, 0.011423369437190039, 0.04619054536202124, 0.06512658497584717, 0.022527364315465093, 0.03130844375118613, 0.10623752897871391, 0.03764095323692475, 0.03212427354550787, 0.0603882053068706, 0.06421698842729841, 0.0693190289395196, 0.04508534752364669, 0.05390032487256186, 0.045499050324516635, 0.07678448834589549, 0.03630979645199009, 0.07981266121246985, 0.02829052015606846, 0.04623850421713931, 0.02893856181097882, 0.07351597837571587, 0.06294417208326714, 0.06842362055821077, 0.052813308380012, 0.042612060239272456, 0.06354827181036983, 0.05235471709498337, 0.046918358986399004, 0.033562448873583756, 0.022749701581363167, 0.02882214216515422, 0.05923008173704147, 0.03180087357759476, 0.04869904861386333, 0.03621939183878047, 0.040755540930799077, 0.05608907188954098, 0.025500153457479816, 0.04154306902949299, 0.06802061146923474, 0.03194803425243922, 0.04812895366922021, 0.06821845870997224, 0.0667594794982246, 0.03390709716560585, 0.0554060958591955, 0.053113434596785476, 0.060751906862216334, 0.32354267739823883, 16.73889306613377, 51.60213088989258, 75.15584318978446, 89.21711417606899, 100.68836075919015, 97.8772724696568, 89.35973984854562, 96.31405285426548, 97.6952713557652, 105.72452626909528, 102.35587978363037, 92.73537622179303, 83.2024199622018, 76.01284095219204, 89.34054197583879, 67.05231898171562, 74.37620667048863, 80.84194319588798, 92.11597905840192, 77.5593432017735, 75.47867039271763, 91.15974712371826, 78.82922376905168, 86.76790196555001, 105.19966629573277, 98.70931925092424, 100.9919900894165, 94.44115202767509, 99.22394452776227, 78.61378792354039, 102.84855570111955, 98.85043716430664, 76.86610753195626, 104.5988416671753, 98.01783452715192, 114.60055119650704, 109.1004753112793, 114.3630895614624, 115.49379771096366, 113.93025153023856, 107.41982419150216, 112.00094522748674, 116.88662665230888, 114.05987017495292, 111.0747573035104, 94.17688424246651, 73.6340695789882, 39.0865353175572, 15.684662001473562, 3.429737001657486, 0.04064386085207973, 0.12899888439902238, 0.1400633342564106, 0.02929778503520148, 0.03808990253933838, 0.03685104687299047, 0.10747613358710494, 0.07510779438806431, 0.058682083285280635, 0.10348599483924252, 0.03551403772351997, 0.043287755588867834, 0.031324647167431455, 0.15282558729606016, 0.08928220093782459, 0.056951086169907024, 0.05742061883211136, 0.0641651822786246, 0.05929049849510193, 0.011451440430911524, 0.047383633841361315, 0.017833438868235265, 0.03058494900220207, 0.022208778553509285, 0.05708808917552233, 0.031558100533272536, 0.03234326054475137, 0.03569156962579914, 0.025009073915758302, 0.00525674013520724, 0.03632221703550645, 0.02244108010615621, 0.05170357792771288, 0.04758377453046186, 0.056472603630806716, 0.020338934513607194, 0.024387552802051817, 0.01939640866060342, 0.014881490929318326, 0.049384955915489366, 0.06551672904086964, 0.02119363927548485, 0.10521543810942344, 0.059980616106518676, 0.047101407378379784, 0.04428134798737509, 0.016046269231342843, 0.04660801063956959, 0.0434678998509688, 0.0862372750416398, 0.05588992186156767, 0.06899850935276065, 0.040522121491708925, 0.04260192292609385, 0.04203162102827004, 0.10877292935869523, 0.0060004399607091075, 0.06047910185796874, 0.10017091701073305, 0.014717205726940717, 0.018184141388961246, 0.13714108749159745, 0.06689678105924811, 0.030562363964106356, 0.02613473976297038, 0.07135216412799698, 0.21343826555780002, 0.24736064672470093, 0.22844349752579415, 0.10764158078070198, 0.13416400152657712, 0.2827735793377672, 0.15725439893347876, 0.15513513050973415, 0.09224230995667831, 0.18234777743262903, 0.14841946586966515, 0.20821503869124822, 0.1409397300864969, 0.17470840950097355, 0.1634342380400215, 0.22713752117540154, 0.22781954386404582, 0.1259310104485069, 0.1419454546911376, 0.14072642581803457, 0.1758921816945076, 0.19574812480381557, 0.18236829633159296, 0.1482330315879413, 0.2323452638728278, 0.2631483924176012, 0.11045791501445429, 0.20215179904231004, 0.2055185948099409, 0.1558544590537037, 0.1604955435863563, 0.2790593329284872, 0.12140687821166855, 0.14217717440000602, 0.19696017833692686, 0.17677663852061543, 0.1542119157633611, 0.1938466118382556, 0.15128669701516628, 0.18007353161062511, 0.18820909863071783, 0.13793187934373105, 0.25089649270687786, 0.140324488814388, 0.19427586666175298, 0.18871494648712023, 0.11347478348761797, 0.18246529969785893, 0.1513731423765421, 0.0902363025982465, 0.19532777235976287, 0.18017404978828772, 0.2116923542427165, 0.1845839438693864, 0.12298838049173355, 0.17422575397150858, 0.22939811487283024, 0.19198697805404663, 0.24839693254658154, 0.6740585874233926, 24.220843587602886, 72.13293906620571, 93.52169690813336, 105.09137167249406, 113.85177162715367, 110.56018761226109, 101.43591744559151, 99.48045117514474, 96.60375104631696, 109.0881769997733, 104.3372141974313, 92.43405369349888, 79.89039434705461, 68.37725012642997, 86.38001877920968, 54.59870828901018, 64.15286350250244, 62.516298702784944, 85.3356489453997, 72.37641784123012, 62.56228188105992, 75.80285249437604, 78.07338482992989, 75.53025381905692, 87.33889102935791, 78.85938589913505, 78.39294637952531, 86.84836210523332, 99.48195893423897, 74.09909166608537, 88.59452778952462, 85.03884969438825, 71.40813773018974, 109.03434930528913, 106.28717749459403, 116.58943830217633, 103.16037000928605, 104.04118619646344, 125.35767582484654, 118.06687545776367, 114.26218087332589, 114.9255462374006, 126.44597217014858, 129.2729718344552, 124.99414607456752, 108.04454367501395, 86.89169801984514, 50.61329453332083, 20.036634922027588, 5.253974165235247, 0.26970247072832926, 0.40905461886099403, 0.34136092556374414, 0.21424516583127634, 0.19838852169258253, 0.2406122088432312, 0.21854903203036102, 0.2599126489034721, 0.1579167033944811, 0.1663539470838649, 0.19639394086386475, 0.346690438155617, 0.2618099956640175, 0.22989518248609134, 0.2786912683929716, 0.15029811220509665, 0.15354043750890664, 0.17694532232625143, 0.11931365196193967, 0.25795521108167513, 0.15254605800977775, 0.12424658797681332, 0.1386764222489936, 0.11898989576314177, 0.11872012381042753, 0.27499849083168165, 0.112393693998456, 0.17148581599550589, 0.18072957997875555, 0.12402178932513509, 0.1250560666833605, 0.1386380578790392, 0.13704557690237248, 0.16815528113927158, 0.23349945193954877, 0.12805813630776747, 0.1894339629049812, 0.10133822794471468, 0.290116088198764, 0.25622277547206196, 0.21628227723496302, 0.20056292787194252, 0.21088396119219915, 0.23974666957344326, 0.20198114748511994, 0.2300467672092574, 0.1426270566880703, 0.21606271687362874, 0.15771863902253763, 0.18923729631517613, 0.1288800457758563, 0.22476096584328584, 0.18505034169980458, 0.15709007132266248, 0.24679881972926004, 0.20514149218797684, 0.12202491504805428, 0.18643312821430819, 0.16593177616596222, 0.21360200962850026, 0.11726416407951287, 0.2625839869890894, 0.23412663542798587, 0.18631314965231077, 0.18613362285707677, 0.18319800895239624], [0.041022941403623135, 0.01761613124316292, 0.042846802821648974, 0.0373846400263054, 0.02666052128188312, 0.09296824064637933, 0.04733138664492539, 0.02259839166487966, 0.026925792851086174, 0.028591952552752833, 0.014054977601127965, 0.008474746319864477, 0.0561530713124999, 0.043829606513359716, 0.03453483705275825, 0.05370224692991801, 0.026414433593994806, 0.03180599990966065, 0.04562389737527285, 0.03572610366557326, 0.11191225304667439, 0.04694771580398083, 0.016302726630653654, 0.034318123145827224, 0.01748106375868831, 0.052317954067673, 0.05164942404787455, 0.014106658220823323, 0.014748257185731615, 0.036639550900352855, 0.06813541959439005, 0.09692433050700597, 0.044399664138576815, 0.03205032001382538, 0.07274759174989802, 0.05804062342005117, 0.03930984064936638, 0.042104614432901144, 0.03818088051463876, 0.03305906070662396, 0.01261825518616076, 0.08316264288233859, 0.0366591062795903, 0.10824373989765133, 0.025181489663996866, 0.02565025388529258, 0.00862535395260368, 0.03993050680894937, 0.0367749763120498, 0.017477667690919976, 0.027236726434369172, 0.05070670820506556, 0.043042614457330534, 0.14217117615044117, 0.058280173423034806, 0.06837326647447688, 0.05620342878890889, 0.22366518607097013, 6.000975430011749, 42.523576395852224, 76.92582035064697, 78.95419406890869, 76.52272755759103, 82.53003583635602, 61.520851135253906, 57.288435867854524, 66.3340072631836, 54.08466666085379, 40.64232383455549, 29.460560049329484, 24.099015610558645, 14.074867742402212, 23.123575380870275, 16.634253195353917, 23.473856653485978, 16.046159403664724, 15.10107237952096, 16.057589190346853, 14.711094311305455, 23.498244830540248, 27.593606880732946, 9.195583871432714, 15.471267189298358, 14.121271286691938, 13.792376569339208, 19.404524292264664, 23.09506344795227, 15.893333775656563, 22.4350905418396, 36.30171121869768, 18.109812600272043, 20.605426618031093, 26.29010398047311, 24.778097799846105, 33.21199321746826, 33.50560671942574, 30.158614294869558, 35.83603252683367, 52.03281845365252, 38.13603912081037, 68.2796140398298, 60.98096915653774, 68.89537034715924, 68.1938385282244, 72.68967042650495, 97.99443299429757, 86.20055375780377, 101.24743366241455, 97.82345172337124, 72.18891375405448, 44.766416685921804, 8.49068912437984, 0.17286183073052339, 0.13160641305148602, 0.07058102943535362, 0.16038256750575133, 0.10134039247142416, 0.02099734587994005, 0.08533460633563143, 0.10418455342629127, 0.05991910012172801, 0.02578128069373114, 0.053541797146733315, 0.071711509488523, 0.09250093357903616, 0.023547003977000713, 0.01985932730271348, 0.012691063689999282, 0.06041780300438404, 0.05694314731018884, 0.06302690585809094, 0.031914294098636935, 0.045584620375718386, 0.04209191904270223, 0.03237307198079569, 0.060956044122576714, 0.03151651990732976, 0.05935840627976826, 0.022118423134088516, 0.07986753433942795, 0.03851517775495138, 0.03950509927900774, 0.007256075373983809, 0.03931381347190056, 0.04529247373076422, 0.011624772201425262, 0.03142350971964853, 0.0696453025032367, 0.019499710528180003, 0.08755860663950443, 0.03212625486776233, 0.07704675570130348, 0.03292577268023576, 0.0170061503137861, 0.021271334927795187, 0.06519929678844553, 0.10415653671537127, 0.08817278939698424, 0.03566625348425337, 0.051434990018606186, 0.02066861093044281, 0.01959505826900048, 0.0453097017348877, 0.09685102158359118, 0.021648359518232088, 0.06444222812673875, 0.02571268249968333, 0.021161488589963744, 0.10235997276114565, 0.017056229590837444, 0.03603857243433595, 0.04109473380127123, 0.039589559925454, 0.08720555129860129, 0.10152461472898722, 0.06023859512060881, 0.011312406061084142, 0.04593808623030782, 0.005473457434813359, 0.05359010884006109, 0.045340429193207195, 0.027094106855137006, 0.01270247919351927, 0.044461672061256, 0.051705033385327885, 0.04203278810850211, 0.031161598595125333, 0.025394195125305226, 0.09377443524343626, 0.015166414568998983, 0.0519274741278163, 0.02968134731054306, 0.037958958851439614, 0.032936171229396544, 0.0400250708418233, 0.08971988316625357, 0.0307152107624071, 0.06354947960270302, 0.039988599584570954, 0.006524370351274098, 0.038036335592291186, 0.03990767749824694, 0.05533904981400285, 0.054734634568116496, 0.024699690784992914, 0.015271439915522933, 0.087803612064038, 0.013005165183650596, 0.02678628944392715, 0.058473868029458184, 0.06080809634711061, 0.014884853070335729, 0.03204999431701643, 0.06515893074018614, 0.0039019381012102322, 0.10121123333062444, 0.05328499539090054, 0.06256980395742825, 0.07541337941906281, 0.021921546198427677, 0.08590559355382409, 0.05640783407060163, 0.045716378305639536, 0.09707328251429967, 0.04631242382207087, 0.041063877421298196, 0.04486760902883751, 0.066535067611507, 0.0349574218770223, 0.03900191806522863, 0.03527569890554462, 0.0318230888141053, 0.07580476520316941, 0.21445361178900513, 6.13713493517467, 48.879232610974995, 87.38403347560337, 90.30120686122349, 87.53353091648647, 92.83817481994629, 72.27591909681047, 73.39671911512102, 87.49279362814767, 71.80465752737862, 56.35259689603533, 54.08495501109532, 46.304171153477256, 40.04475791113717, 42.1444479397365, 33.95360571997506, 38.55174289430891, 19.10513162612915, 24.213351692472184, 19.25592143195016, 29.463318484170095, 35.93479422160557, 36.580705710819785, 21.848191840308054, 30.501535688127788, 29.317910058157786, 26.240504264831543, 33.468360900878906, 28.005416188921245, 28.642838716506958, 41.13774429048811, 50.183558872767854, 31.86563730239868, 33.48447724751064, 35.19982072285244, 42.614740235464915, 50.42500182560512, 57.26540258952549, 52.33823694501604, 53.9533873966762, 89.53334753853935, 69.84335477011544, 103.54329218183244, 86.50603825705392, 95.94889027731759, 92.31842177254813, 87.2528167452131, 108.51755619049072, 99.56514971596854, 116.22752053397042, 112.1492406300136, 85.54996613093785, 53.45838383265904, 13.202955671719142, 0.29599567555955475, 0.18774856334286077, 0.13375484491033213, 0.05870699230581522, 0.07149091096861021, 0.021076702246708528, 0.08229763286986522, 0.21826335521680967, 0.040796205534466674, 0.021744831930845976, 0.04654459136405161, 0.043423197963940244, 0.053707563251789124, 0.08227604188557182, 0.023385066505787627, 0.029270955760564123, 0.0410266224560993, 0.062125885992177894, 0.1137625298329762, 0.11456955224275589, 0.03746957564726472, 0.033054090437612364, 0.03166867459991148, 0.06159196035670383, 0.008800672134384513, 0.03830114406134401, 0.12230072596243449, 0.028908896259963512, 0.04379353898444346, 0.030073564300047498, 0.008113384862164301, 0.019348404004371593, 0.024921468259500604, 0.07317132329834358, 0.07855239776628357, 0.11628471235079424, 0.06262733694165945, 0.08661984665585415, 0.04312552125858409, 0.020305932266637683, 0.05517190967553428, 0.04285703512973019, 0.010766570439695247, 0.013017224447269524, 0.16191013982253416, 0.06320215109735727, 0.04353392809363348, 0.06489099761737244, 0.04148878622800112, 0.09856576099991798, 0.023919344979471395, 0.039599032274314334, 0.11288612043218953, 0.01090841309633106, 0.1182205727589982, 0.015080093040264078, 0.022519707047779645, 0.017514557943546345, 0.030360041784920862, 0.0430973043798336, 0.02293853448437793, 0.07432881583060537, 0.06153055972286633, 0.029241225748722042, 0.13201132203851426, 0.10394512555961098, 0.11122065622891698, 0.09935035104198114, 0.13658312814576284, 0.12006515663649354, 0.11103485298476048, 0.16401690963123525, 0.15663480146655015, 0.12263415807059833, 0.12598253839782306, 0.08396414880241666, 0.15173282021922724, 0.13040810663785252, 0.17755639739334583, 0.1374330339687211, 0.12248863945049898, 0.17070399437631878, 0.15704213960894517, 0.18272393010556698, 0.285568573645183, 0.1211278238998992, 0.14111396430858544, 0.09855623436825615, 0.13414691601480755, 0.08977434238685028, 0.1954752451607159, 0.17968049698642322, 0.1483490610761302, 0.12065214371042592, 0.15004713567239897, 0.22449717856943607, 0.13747286397431577, 0.13684820463614805, 0.22574001045099326, 0.1220296240810837, 0.09971338084765843, 0.2651081643998623, 0.10873816122433969, 0.19991894385644368, 0.1282910638089691, 0.2019436787813902, 0.17215338588825294, 0.22902234217950276, 0.274047890411956, 0.11541284913463251, 0.26922985751714024, 0.11856106163135596, 0.19271495113415377, 0.07149706528122936, 0.15870220267346927, 0.1121678300467985, 0.13655319118074008, 0.18814551989947045, 0.14285230317286082, 0.14838131863091672, 0.23353112595421927, 0.3795751492891993, 9.743653433663503, 65.70321505410331, 104.28212887900216, 101.87753799983433, 98.16427476065499, 104.71470287867955, 83.2369247164045, 77.93082169124058, 87.10876669202531, 73.69892406463623, 57.09955603735787, 47.772603443690706, 36.54285192489624, 27.707411425454275, 37.993118149893625, 27.488946165357316, 36.714625290461946, 27.045493023736135, 29.03181971822466, 26.594589676175797, 27.367964131491526, 36.98794657843453, 41.46808597019741, 19.411601032529557, 33.41144125802176, 23.841431992394583, 21.29549217224121, 27.586787223815918, 32.513264996664866, 26.669451304844447, 36.09219871248518, 50.8927823475429, 25.87926742008754, 28.333100182669504, 37.83765915461949, 39.01009471075875, 46.05652345929827, 47.32776934759957, 41.28809288569859, 49.16034630366734, 72.45923342023576, 54.64303084782192, 90.37146009717668, 81.47226987566266, 90.97621740613664, 90.5469160079956, 91.78637041364397, 120.23362949916294, 111.80766023908342, 128.87308910914828, 127.8424767085484, 103.46424947466168, 68.45175565992082, 18.217990841184342, 0.5417374191539628, 0.27083489139165196, 0.20022091908114298, 0.24363027832337789, 0.23688604735902377, 0.12749941700271197, 0.20430419354566506, 0.25437482606087414, 0.15369428853903497, 0.11958384460636548, 0.07669134584388562, 0.18984732643834182, 0.15043190574007376, 0.13174640839653357, 0.14747373733137334, 0.1551998627505132, 0.1202665458300284, 0.12796597768153462, 0.17176629523081438, 0.14989441101040157, 0.14306350398276532, 0.09841084466981036, 0.07936347781547479, 0.16192909809095518, 0.08539785937006984, 0.1648842945162739, 0.3006721389080797, 0.10360794115279402, 0.13742434872048243, 0.14303233208400862, 0.07440926294241633, 0.10807897802442312, 0.13288146177572863, 0.1343732617263283, 0.16081351866679533, 0.24549624962466104, 0.08750523986028773, 0.25503837902631077, 0.1055117543520672, 0.16142512299120426, 0.12351474724709988, 0.12073530496231147, 0.12488853638725621, 0.16581006055431707, 0.29850256389805246, 0.26476599276065826, 0.1864220816642046, 0.21159811929932662, 0.1398998073169163, 0.11827367490955762, 0.14481162732200964, 0.13685205871505396, 0.21772353989737375, 0.1190915403089353, 0.2006129901856184, 0.12823474540242127, 0.12895848442401203, 0.08536493006561484, 0.0989886647356408, 0.1471910189305033, 0.11263297937278237, 0.1909894501524312, 0.1921561775462968, 0.1281122291194541], [0.051167453838778396, 0.044526068427200825, 0.019784111695896302, 0.05628851029489722, 0.07110319605895452, 0.09227723415408816, 0.08457301184535027, 0.01596731150389782, 0.06005764340183564, 0.026639654633722136, 0.08934214950672217, 0.05916462346379246, 0.08774905784853868, 0.12906490585633687, 0.15111407770642213, 0.12109768337437085, 0.01573202948618148, 0.15870106273463794, 0.07139146487627711, 0.06919281464070082, 0.1437951682933739, 0.07764976298702614, 0.025177859501647096, 0.12611547697867664, 0.04917196038046053, 0.03348876675590873, 0.06083669659814664, 0.03132803305717451, 0.03273773705586791, 0.016988616968904222, 0.024184216213013445, 0.015045660780742764, 0.016363898258922354, 0.05712559859135321, 0.1108240932226181, 0.05527553893625736, 0.04273847131324666, 0.0388152293328728, 0.02068901787112866, 0.15014658176473208, 0.06589670865131275, 0.05978317598679236, 0.0755991894485695, 0.028199859395889298, 0.0578755901328155, 0.05541737650388053, 0.11534453422895499, 0.12412928284278937, 0.018907167948782444, 0.12628502930913652, 0.10579756008727209, 0.05188338631497962, 0.08409338936741863, 0.08672435461942639, 0.12955851294100285, 0.14525636631463254, 0.8240105382033757, 15.82592408997672, 45.843359674726216, 46.73775264195034, 64.32318469456264, 78.11622047424316, 65.37091745649064, 44.15388434273856, 47.28373166493007, 30.533705847603933, 21.82924062865121, 25.123193979263306, 55.326785700661794, 40.71069758278983, 54.52417843682425, 41.20468323571341, 59.661930084228516, 79.82578304835728, 86.43509714944022, 111.78659330095563, 108.22453675951276, 115.70400851113456, 106.35644408634731, 113.6871201651437, 127.30044773646763, 117.10612024579729, 82.45008291516984, 115.1837135042463, 110.30715506417411, 119.29294068472726, 134.22215979439872, 100.44981520516532, 77.52889619554792, 77.5831685747419, 98.01548603602818, 107.23131261553083, 85.03040763310024, 74.18762561253139, 83.5787969316755, 79.06216212681362, 86.77507250649589, 77.34294155665806, 48.62388631275722, 47.428070068359375, 28.22429312978472, 38.85632412774222, 29.125441483088903, 29.732380526406423, 45.0076060295105, 49.79543249947684, 65.45266996111188, 75.81798567090715, 83.99577222551618, 94.45363794054303, 97.40378747667584, 83.70295429229736, 45.940874167851035, 4.752421924046107, 0.18573376217058726, 0.07479241809674672, 0.032975366804748774, 0.05589255118476493, 0.045815400313586, 0.054667021946183274, 0.05149646868397083, 0.045671160731996806, 0.012910248312566961, 0.0362513067333826, 0.03285975122292127, 0.044623855501413345, 0.041712170134165456, 0.06660136726817914, 0.09330117742397956, 0.07784610388002225, 0.032585443263607364, 0.07456544813300882, 0.04668334499001503, 0.09807528196168797, 0.026269300042518547, 0.08309679105877876, 0.05713452811219862, 0.0824566339807851, 0.09027417163763728, 0.06644888009343829, 0.13731198332139424, 0.06387384648301772, 0.038850879562752585, 0.027969389887792722, 0.06959874821560723, 0.05093120490866048, 0.10029021703771182, 0.014477189231131758, 0.11599427222141198, 0.0505788213174258, 0.09857695682772569, 0.05900433992168733, 0.03666654980874487, 0.025284077373466322, 0.10362757117088352, 0.01998168752262635, 0.04275233378367765, 0.09024404468280928, 0.07309597876987287, 0.021749281424230764, 0.05728699493088892, 0.09475612613771643, 0.06626774517021009, 0.033433500078639815, 0.03769039469105857, 0.0676026406830975, 0.03577268848727856, 0.05246626825204917, 0.03939748023237501, 0.06301002390682697, 0.08698557024555546, 0.05102561287848013, 0.06333067920058966, 0.03342245013586112, 0.021853182098961303, 0.068451426923275, 0.028280311596712897, 0.1041871929275138, 0.02524488010177655, 0.060193838950778754, 0.08517931002591338, 0.11280712538531848, 0.0964112358966044, 0.023260346680347408, 0.07796698489359447, 0.01638294304055827, 0.04433578685192125, 0.05281770867960794, 0.0567739342472383, 0.049805705302527974, 0.09746033245963709, 0.0700502386316657, 0.02598202188632318, 0.021992858532550077, 0.04410400946757623, 0.10226630778717143, 0.03118748470608677, 0.07749743187533957, 0.013501995309655155, 0.03726267335670335, 0.038082577753812075, 0.02853395137935877, 0.07693547595824514, 0.021211776516533325, 0.08739119847970349, 0.06833965863500323, 0.0399664386308619, 0.06426054359014545, 0.08419931546917983, 0.0757101909922702, 0.10886488442442246, 0.020144708953531723, 0.09472278971225023, 0.08767824593399252, 0.016800147082124437, 0.023864609255854572, 0.028058756342423812, 0.04362723005137273, 0.07934802757310015, 0.06889831008655684, 0.03655561611854604, 0.016032708708995154, 0.14080139036689485, 0.14429135381111077, 0.013411437177897563, 0.05011418089270592, 0.09057020968092339, 0.02781463640608958, 0.0062615330264504465, 0.052830125870449204, 0.08854509477636643, 0.17741766412343296, 1.4265128310237611, 18.9500686781747, 61.93496377127511, 58.020088127681184, 73.83688749585832, 87.34641592843192, 76.81492710113525, 67.35849830082485, 73.80102089473179, 46.951684202466694, 42.406533990587505, 46.00977597917829, 64.48639093126569, 37.59486130305699, 36.897654737745015, 18.913272755486624, 40.26387282780239, 32.60557876314436, 53.2779495375497, 56.71509483882359, 54.0312454359872, 52.62394687107631, 51.22829696110317, 58.21830286298479, 75.72600541796002, 55.60735048566546, 39.05721391950335, 56.69673422404698, 46.422776903424946, 58.644790240696494, 70.75413158961705, 54.4061598096575, 54.23980603899275, 58.618338448660715, 58.63200555528913, 55.21898439952305, 53.95347077505929, 51.637868949345176, 62.58655193873814, 56.26273584365845, 53.74292646135603, 50.95616034099034, 45.005698748997276, 38.024475370134624, 36.24647651399885, 52.68858596256801, 42.90404238019671, 46.40888745444161, 66.54990863800049, 86.07300567626953, 83.63003989628383, 94.78313541412354, 95.4910387311663, 107.36268915448869, 108.35684435708183, 101.09019592830113, 59.96102224077497, 9.180493252617971, 0.1349517942539283, 0.051180094946175814, 0.06557340028562716, 0.059330342071396966, 0.08098051497446639, 0.12227358456168856, 0.0367349631020001, 0.0458789044059813, 0.07158005689936024, 0.025234211834945848, 0.04780186586348074, 0.08953830040991306, 0.0935214434617332, 0.05412569010098066, 0.09534693336380379, 0.006883673727445836, 0.11332484760454722, 0.015416203665414026, 0.06542592069932393, 0.018600329324336987, 0.0582855474203825, 0.015088608654748117, 0.08402843999543361, 0.05943592890564885, 0.08614317580525364, 0.010110269317270389, 0.1368595226002591, 0.06960760988295078, 0.08427350648811885, 0.0427190211069371, 0.022611182049981186, 0.0443907346177314, 0.06143036045666252, 0.041347033477255275, 0.06265069890235152, 0.0942932702600956, 0.06947457630719457, 0.03689839504659176, 0.05015262668686254, 0.05592311240200486, 0.04657496598416141, 0.0460000466555357, 0.02459327274534319, 0.043251145231936655, 0.03943776824910726, 0.025251156550699046, 0.06681101423289094, 0.028307546296023896, 0.08054135353969676, 0.04311319566997034, 0.03862312249839306, 0.080275456021939, 0.026741858970906054, 0.0324682534805366, 0.030132464532341276, 0.011072553261848432, 0.10620022312338863, 0.030705653596669436, 0.06432313844561577, 0.10738495205129896, 0.035562441019075255, 0.031688233371824026, 0.18984069036585943, 0.1575576633747135, 0.13665095450622694, 0.1411545949855021, 0.14647832645901612, 0.14121980220079422, 0.2409111170896462, 0.16074156681341784, 0.23970842733979225, 0.15286705935639994, 0.1596975049802235, 0.223188420225467, 0.24462891902242387, 0.17000434334789002, 0.16158942346061977, 0.2734714613429138, 0.15576713159680367, 0.30640923391495434, 0.16216620536787169, 0.23622404145342962, 0.22233280113765172, 0.2743098592119557, 0.14056323814604962, 0.2231483188058649, 0.10617805538432938, 0.2094104409750019, 0.25771845664296833, 0.16675197572580405, 0.1971090624907187, 0.17164867797068187, 0.11436801377151694, 0.104124944124903, 0.13948187045753002, 0.17803085621978554, 0.36037819939000265, 0.2042225929243224, 0.20714589820376464, 0.1311456470617226, 0.11378147453069687, 0.32135543333632605, 0.16503062737839563, 0.1763856259307691, 0.2249860359089715, 0.14788049193365232, 0.11625801878316061, 0.1161830270928996, 0.34013280432139126, 0.2564244903624058, 0.09723815295313086, 0.23856059036084584, 0.17748998238572053, 0.19416177778371743, 0.10386108899755137, 0.22792930368866238, 0.2679928610367434, 0.30700786464980667, 2.2477665628705705, 26.023696150098527, 76.62702001844133, 72.0729066303798, 85.15629509517125, 101.34796019962856, 91.0565733228411, 66.0130421774728, 71.8016003199986, 50.53170531136649, 32.86926984786987, 38.88281066077096, 77.30995845794678, 59.36105918884277, 73.11211395263672, 58.43844263894217, 88.05777944837297, 114.25081362043107, 120.27479062761579, 150.93366132463728, 150.99185943603516, 166.6862141745431, 142.6569949558803, 152.4938098362514, 171.74261283874512, 165.32905033656527, 114.25226579393659, 154.26515579223633, 154.6893711090088, 161.39010265895297, 186.28969492231096, 139.1559088570731, 108.84979820251465, 110.0954920904977, 137.2560212271554, 146.1946702684675, 115.63488783155168, 103.4717048917498, 114.59572219848633, 108.33880683353969, 115.85500676291329, 106.17701380593437, 61.38846015930176, 62.46527113233294, 39.92726387296404, 52.97829805101667, 43.999700341905864, 44.96942220415388, 62.595098223005024, 70.14549023764474, 89.10271903446743, 101.46181338174003, 107.08524758475167, 118.4749709538051, 124.45211710248674, 115.29708726065499, 73.96438694000244, 11.838677746909005, 0.1759302339383534, 0.16955752803811006, 0.15551517797367914, 0.12049753272107669, 0.29091040843299454, 0.27389522003276007, 0.1158524312611137, 0.14990548470190593, 0.1901699426983084, 0.13606141614062445, 0.1296356488019228, 0.2201358133128711, 0.32761551599417416, 0.15534781052597932, 0.1863259468227625, 0.15996492920177324, 0.22946675547531672, 0.18544580547937325, 0.1442806872406176, 0.16286977832870825, 0.1558845860085317, 0.30775466029133114, 0.2828327204499926, 0.09716566505708865, 0.158208948427013, 0.15324342916054384, 0.20351539658648626, 0.16938732431403228, 0.17556436785629817, 0.12044478340872697, 0.17825275074158395, 0.13471752325338976, 0.20628270666514123, 0.11128189401435, 0.25576289157782284, 0.2645969289754118, 0.21804588474333286, 0.14452907176954405, 0.15445264641727718, 0.18522209248372487, 0.15520683809050492, 0.17446596893881047, 0.1355865773345743, 0.24217028809445246, 0.14846730258847984, 0.09487412337745939, 0.1756986906485898, 0.20680334658495017, 0.20276148989796638, 0.13203040244323866, 0.18551934510469437, 0.15234453310923918, 0.14335306201662334, 0.14067401577319416, 0.13165498258812086, 0.3254393999065672, 0.21297333336302213, 0.16642114919211182, 0.18885595963469573, 0.2223471046558448, 0.12451614279832159, 0.14823467364268644], [0.06181233496006046, 0.0382616397525583, 0.10409299191087484, 0.1299251118408782, 0.1532000843435526, 0.0928141860557454, 0.05203197869871344, 0.09465093285377536, 0.09771856253168412, 0.07499360372977597, 0.06180276083094733, 0.12557969215725148, 0.11099314343716417, 0.07245302612760238, 0.10701927595904895, 0.047390463296324015, 0.11189164593815804, 0.11426114450607981, 0.12655314563640527, 0.1873995792120695, 0.11784534289368562, 0.0992179417184421, 0.08805843589029141, 0.07090667874685355, 0.16009930627686636, 0.15914019702800683, 0.18080187109964235, 0.009531293197401931, 0.10169759366129126, 0.17118746414780617, 0.1332764641514846, 0.07109244806425911, 0.09518993393118892, 0.10041409039071628, 0.11786088134561266, 0.08177714901311056, 0.2277294886963708, 0.2015997836632388, 0.1560623079006161, 0.13533062035483973, 0.13888322615197726, 0.04619698465934821, 0.09941407226558242, 0.10780432061957461, 0.11044369970581361, 0.12675591904137815, 0.08820185783718314, 0.12211342315588679, 0.039257674877132685, 0.1308639600340809, 0.20104827040008136, 0.1339381579309702, 0.12691468266504152, 0.39431485693369595, 0.311387943902186, 11.873227664402553, 46.09145900181362, 70.75778634207589, 60.366157804216655, 34.555611542293, 42.02451160975865, 23.20844415255955, 23.48373872893197, 17.52272629737854, 8.26340138912201, 21.32446094921657, 45.91602046149117, 42.183767795562744, 41.50484194074358, 75.52969101497105, 90.2326420375279, 107.9559610911778, 66.2236351285662, 62.58461339133126, 37.411331585475374, 24.704189811434063, 27.764572518212454, 20.86415147781372, 38.862799848829, 33.87383345195225, 23.017469440187725, 38.71470594406128, 46.28957298823765, 57.090419156210764, 51.513836656297954, 60.00376755850655, 33.76762676239014, 47.45112419128418, 56.93909086499895, 55.94632530212402, 59.34125682285854, 60.466538429260254, 37.298756871904644, 32.618575368608745, 28.612987518310547, 31.645987374441965, 37.792044230869834, 39.59871482849121, 86.62216350010463, 88.39211981637138, 106.45772797720772, 86.124450138637, 76.5531815120152, 58.34743513379778, 28.983607905251638, 20.213768822806223, 27.823939664023264, 35.12774011066982, 50.40487289428711, 68.69403239658901, 59.5471111025129, 78.63185323987688, 84.95755577087402, 73.8848648071289, 20.27409134592329, 1.5304018620933806, 0.06591204354273421, 0.10707032214850187, 0.12473332828709058, 0.18051726637142046, 0.12760701908596925, 0.09077780068452869, 0.09739312356603996, 0.15956478353057588, 0.1582426309053387, 0.21348474520657743, 0.20998001684035572, 0.10735030605324677, 0.223979008517095, 0.1569707848663841, 0.12269027291664056, 0.07233338683311429, 0.10211091648255076, 0.11963358122323241, 0.03168201459837811, 0.10162974015942641, 0.07236535261784281, 0.08450097178242036, 0.0637514116242528, 0.07063309342733451, 0.12632643351597445, 0.06913186183997563, 0.10086913633027247, 0.11516907864383288, 0.015476723900064826, 0.09807499019162995, 0.16930024112973893, 0.14605990105441638, 0.1355456073901483, 0.2422766009611743, 0.22790121233889035, 0.1752746876861368, 0.17837629839777946, 0.2370905035308429, 0.15836570358702115, 0.18675966640668257, 0.13653951191476413, 0.2714252439992768, 0.1014420370172177, 0.15277537570468017, 0.10590568464249372, 0.048338247795722315, 0.0746759543461459, 0.07851319201290607, 0.06367226729967765, 0.026298298932878033, 0.044716662128588984, 0.02696915972046554, 0.1570054715765374, 0.055172761236982684, 0.07800433146102087, 0.07760356153760638, 0.0730292923482401, 0.03452941216528416, 0.020407083178205148, 0.021822639541434388, 0.07904662910316672, 0.0723114905080625, 0.04536573515672769, 0.09653491247445345, 0.04974364309704729, 0.05519003334588238, 0.031412968678133826, 0.05183442662070904, 0.017202701552637985, 0.051675808882074695, 0.06697523327810423, 0.09856512996235064, 0.04984032755185451, 0.019029677446399416, 0.034645621465252976, 0.10595050866582564, 0.1076013572247965, 0.06614753590630633, 0.011508251623516636, 0.09941406548023224, 0.09077056071587972, 0.088864108015384, 0.02335967233271471, 0.08074478512363774, 0.09352519576038633, 0.025646218298269168, 0.053154832018273215, 0.0591696717643312, 0.09249752054789237, 0.07256587328655378, 0.13124087266623974, 0.05810423607804945, 0.022333347404907857, 0.049061036868286986, 0.12111875867205006, 0.028078445732327442, 0.030304103357983486, 0.10083757088120494, 0.18068253036056245, 0.12439784700317041, 0.07349841788943325, 0.11131747639072792, 0.08000037114002875, 0.15851437060960702, 0.1391139416290181, 0.15730150283447333, 0.18992948345839977, 0.1146301861320223, 0.031248674994068484, 0.22272325732878276, 0.08080332233969655, 0.06280077049242598, 0.13080770948103496, 0.4161898217030934, 0.5922364922506469, 16.254617520741053, 58.6231118610927, 88.08224405561174, 69.21987206595284, 47.22402926853725, 62.266135760716026, 51.46006802150181, 47.36243391036987, 30.57357461111886, 24.225142785481044, 37.89837598800659, 29.244471073150635, 27.080923625401088, 37.634632791791645, 59.338387216840474, 72.59985106331962, 75.13808359418596, 59.01558780670166, 52.96012156350272, 37.702683448791504, 26.90087148121425, 26.425708498273575, 22.76463838985988, 35.21061127526419, 32.27372237614223, 25.51959044592721, 35.806016308920725, 38.4717378616333, 41.51385028021676, 45.359098025730674, 42.853327478681294, 34.392405305589946, 40.846725940704346, 43.2728180204119, 40.8215526172093, 45.461292130606516, 46.95496722630092, 28.27130811555045, 25.759753193174088, 25.40451785496303, 24.12430010523115, 28.279397555759974, 32.73215062277657, 53.145954608917236, 63.27803666251046, 69.36763940538678, 56.97549942561558, 44.810732296534944, 35.89047861099243, 32.302932603018625, 23.23532325880868, 50.56817640577044, 63.11323234013149, 70.01678875514439, 87.68239607129777, 69.87541375841413, 89.43788623809814, 95.11278574807304, 88.29984773908342, 28.082548141479492, 2.7003917608942305, 0.0502009892703167, 0.11670192996306078, 0.11157421368573393, 0.1799103439386402, 0.09248009576861348, 0.10388626264674322, 0.28079651828323093, 0.06684971787035465, 0.011531566086757396, 0.10303491832954542, 0.24298466582383427, 0.08230555137353283, 0.01763374261957194, 0.1692036720258849, 0.0618847075051495, 0.0706417854609234, 0.14899514855018683, 0.09479468728282622, 0.0326820666502629, 0.09421167642410312, 0.03584891511127353, 0.08827712094145161, 0.06114631212715592, 0.08969038724899292, 0.05909721100968974, 0.03672550093116505, 0.09292497046824012, 0.1240916648613555, 0.19167865174157278, 0.08592371043882199, 0.19374031254223414, 0.08386002760380507, 0.14599655302507536, 0.0607309401301401, 0.21936593391001225, 0.12923072624419416, 0.0856839365192822, 0.15931770178888524, 0.11813260747918061, 0.1324510398719992, 0.10781164201242582, 0.13947519367294653, 0.08661516476422548, 0.09894926899245807, 0.06996907227273498, 0.05351042168747101, 0.0917028881875532, 0.12486028218907969, 0.09428940939583949, 0.04203630291989871, 0.07211595707173858, 0.05223609560302325, 0.07566683260457856, 0.04337836715525814, 0.11459104823214666, 0.026729258575609753, 0.10301782603242568, 0.07102446564074073, 0.03166575011398111, 0.09344607857721192, 0.2386594664837633, 0.2490900153560298, 0.23707264448915208, 0.2878485055906432, 0.23748885786959104, 0.19004464442176477, 0.18732023132698877, 0.18645433921899113, 0.2526214101484844, 0.22443324699997902, 0.3626139722764492, 0.21581651722746237, 0.22987835481762886, 0.20766568316945008, 0.18214157064046177, 0.38232438319495743, 0.3540236646575587, 0.370059781308685, 0.37743765541485375, 0.46218917625291006, 0.483531653881073, 0.3564768401639802, 0.3267407757895333, 0.373620190258537, 0.41031080431171824, 0.40955079080803053, 0.4138582668134144, 0.2546055551086153, 0.30776831241590635, 0.387059960514307, 0.2912249501262392, 0.19606014234679087, 0.26118240505456924, 0.2489641878221716, 0.2881411441734859, 0.37766257620283533, 0.37240137851663996, 0.4972435438207218, 0.34819447887795313, 0.48379340554986683, 0.3042420744895935, 0.3545636428253991, 0.4349166011171681, 0.40520173417670385, 0.3649343177676201, 0.28991529611604555, 0.46772960466997965, 0.3378051577934197, 0.23658591774957521, 0.4030038778270994, 0.4016613284392016, 0.2625275328755379, 0.2664814107120037, 0.6346239234719957, 0.9008290618658066, 20.434295960835048, 70.89556217193604, 97.30260780879429, 80.17859172821045, 53.76315266745431, 63.20763751438686, 41.905759947640554, 38.45990855353219, 27.65784297670637, 12.575997999736241, 33.53494201387678, 65.74466800689697, 59.21743992396763, 57.53456538064139, 103.40988676888603, 127.08572060721261, 157.59844289507186, 101.3615300314767, 96.88996819087437, 59.13226890563965, 38.53528608594622, 44.58902570179531, 32.01953295298985, 56.895841802869526, 51.00573921203613, 39.98216853822981, 61.42403493608747, 69.25621809278215, 91.52093533107212, 81.1589686529977, 94.92653233664376, 53.36903347287859, 73.34326662336076, 86.94616494859967, 81.56561197553361, 86.17999403817313, 83.42066287994385, 53.91114929744175, 46.21510566983904, 41.29093817302159, 47.70170055116926, 53.05793482916695, 58.97633048466274, 121.43484796796525, 130.31431225367953, 145.4971545083182, 115.10467774527413, 104.23888329097203, 80.86092567443848, 40.77920682089669, 30.41496113368443, 39.96480846405029, 50.6193915775844, 69.19265597207206, 87.55450752803257, 77.83735452379499, 94.0271783556257, 104.30723966870988, 102.02946731022426, 33.88791397639683, 2.589598608868463, 0.20957195945084095, 0.26731280609965324, 0.35832660804901806, 0.4335420791591917, 0.28703743911215235, 0.32642313997660366, 0.49323698452540804, 0.27769428331937107, 0.37481430332575527, 0.7741466824497495, 0.7976750199283872, 0.33350492854203495, 0.5401177832058498, 0.45214780792593956, 0.40963191645486013, 0.3805793268339974, 0.3824595202292715, 0.2671788361455713, 0.2932057838354792, 0.30201289696352823, 0.18842324428260326, 0.2597514289830412, 0.3390476911195687, 0.3372441721814019, 0.36420787817665506, 0.3291050089257104, 0.30557417443820406, 0.35980964132717674, 0.4398421139589378, 0.2959065431995051, 0.4273658905710493, 0.48998647608927315, 0.4558817318507603, 0.5397668991770063, 0.5643085879938943, 0.36587848567536896, 0.3631608715014798, 0.43621379722441944, 0.28235755594713347, 0.2534450430955206, 0.27183524199894493, 0.4091437783624445, 0.2268368215965373, 0.32531685648219927, 0.19880199379154614, 0.2374956432197775, 0.2307464453790869, 0.2636991728629385, 0.2188956005764859, 0.12964893451758794, 0.2725869502340044, 0.22909388691186905, 0.1822781190276146, 0.25290142797998016, 0.2785026899405888, 0.2127894503729684, 0.20403865565146717, 0.17269292979368142, 0.1552938534212964, 0.2583246055458273], [0.010737898942482258, 0.050173237188053985, 0.05333372438326478, 0.023137296051053063, 0.09358070671026196, 0.06342528055288962, 0.09771599766931363, 0.03977225208655, 0.0841213653662375, 0.08876451264534678, 0.08516354765743017, 0.06391004632626261, 0.02734479840312685, 0.06259098103536026, 0.12127665377088956, 0.03099936426484159, 0.05404643042545233, 0.08862983022949525, 0.031453470433396954, 0.06840439766113247, 0.044209046688463004, 0.05602273491344281, 0.134954657671707, 0.10597786041242735, 0.04269402726952519, 0.2118796706199646, 0.14955515707177774, 0.06474159777696643, 0.023309126562838043, 0.026381405901962092, 0.12061040023607866, 0.21646343251424177, 0.13316741000328744, 0.12582680104034288, 0.040299972519278526, 0.0500025381334126, 0.06320736903165068, 0.04789172764867544, 0.09307440423539706, 0.15298312955668994, 0.1365005640046937, 0.09621325294886317, 0.11167467758059502, 0.043745274788567, 0.12550198632691587, 0.06275423656084708, 0.058617615673158846, 0.102305079278137, 0.22446640022099018, 0.04864773779575314, 0.29441485181450844, 0.3435836705778326, 0.30470944941043854, 9.10606414931161, 36.65585742677961, 65.14011219569615, 76.66253920963833, 54.2651287487575, 62.01686913626534, 34.53751495906285, 21.114213671003068, 16.839275428227015, 17.760856696537562, 44.725189549582346, 74.06825556073869, 66.4662731715611, 73.92503929138184, 102.36869921003068, 82.0405352456229, 43.81116444723946, 18.574238879340037, 7.824745978627886, 2.711328659738813, 0.46042498520442415, 0.19019468208508833, 0.09591484003301178, 0.5506080431597573, 0.3194183515650885, 1.352702551654407, 1.0499148219823837, 0.3589252659252712, 0.47957194064344677, 0.9894122970955712, 0.2264037262648344, 0.38397460750171114, 0.11431398881333214, 0.19141721219888755, 0.10402319779885666, 0.32468039063470705, 0.23078593611717224, 0.12622002565435, 0.19872763992420264, 0.24467837065458298, 0.17530827516955988, 0.1854135072124856, 0.20719800969319685, 0.6283936692135674, 0.3647999135511262, 0.16814382746815681, 2.0261044800281525, 10.306254284722463, 33.64581094469343, 40.818273067474365, 55.90852015359061, 98.22730187007359, 90.67271314348493, 48.13863107136318, 33.802781173161094, 26.677743979862758, 30.521838324410574, 51.31056363242013, 65.06078461238316, 66.13465649741036, 73.660979952131, 77.1491562979562, 58.124147823878694, 20.472474575042725, 2.881275951862335, 0.22293270751833916, 0.12383634570453848, 0.17532446501510485, 0.07626430982989924, 0.08940867307995047, 0.21791335328349046, 0.27963817758219583, 0.14149916863867215, 0.0903556365519762, 0.052886753010430505, 0.11692721715995244, 0.06541435846260615, 0.09946549843464579, 0.13161095923611096, 0.1474805362522602, 0.1144931356289557, 0.09701662484024252, 0.058436168623822074, 0.14132923632860184, 0.02078083553351462, 0.10893294827214309, 0.1096376476011106, 0.06908007604735238, 0.10170516611209937, 0.07272246559815747, 0.03680321354685085, 0.14884855784475803, 0.06424410947199378, 0.04976179390879614, 0.05424154317006469, 0.10828956136746065, 0.10446579262082066, 0.1868892123124429, 0.13037165573665074, 0.04210793246914234, 0.07212896458804607, 0.11300017538347415, 0.039200338668056896, 0.10439013596624136, 0.08369973727634974, 0.05061490580971752, 0.06665267130093915, 0.07380597745733601, 0.0325109740453107, 0.07849627613489117, 0.08497979358902999, 0.056665419534380944, 0.06484009392027344, 0.05520248785614967, 0.12469843801643167, 0.13743827225906508, 0.15435196539121016, 0.07394420182598488, 0.04295567037271602, 0.07262914667704276, 0.10605720151215792, 0.09646348309304033, 0.07431351486593485, 0.03381328969927771, 0.05109272338449955, 0.02576446489963148, 0.07447932846844196, 0.0795633742319686, 0.06708172256393091, 0.07641462569258042, 0.08140162737773997, 0.027727765263989568, 0.0017942353068584843, 0.06153227641646351, 0.055532622284122875, 0.11274539905467204, 0.07214217566485916, 0.06589126001511302, 0.04521509698991265, 0.02672399314386504, 0.06656290790332214, 0.057125741083707125, 0.12328929720180375, 0.05951051347489868, 0.047040441006954224, 0.14379812670605524, 0.08801781199872494, 0.045740775032235045, 0.13444496930709907, 0.0647751988310899, 0.09603160233902079, 0.0432653808966279, 0.0798736275838954, 0.028752144492630447, 0.07878286218536751, 0.0648573829925486, 0.08318898361176252, 0.013620729608062123, 0.0581359915169222, 0.06826565082051925, 0.07928039798779146, 0.10434383952191897, 0.07070290789540325, 0.0870124673736947, 0.051909503127847395, 0.04285446008933442, 0.03743922138320548, 0.1357637835400445, 0.0417236441613308, 0.05298026870670063, 0.07494506133454186, 0.21179847711963312, 0.03281743099380817, 0.0969700434112123, 0.4118880182504654, 0.5578145193202155, 14.495643700872149, 49.003897190093994, 82.32101317814418, 88.84444754464286, 70.72563007899693, 83.41126891544887, 46.28410823004586, 34.77836384092058, 23.43527330671038, 18.332316500799998, 29.643422739846365, 26.35723226411002, 39.37845345905849, 61.69514669690813, 67.58162580217633, 57.03890173775809, 42.01058394568307, 23.777685744421824, 11.794214487075806, 5.100386840956552, 0.7079692163637706, 0.13903536727385862, 0.35531958511897493, 0.44641201570630074, 0.5169580259493419, 0.7103300839662552, 0.7423162790281432, 0.3455780478460448, 0.49013081405844006, 0.6620531316314424, 0.15853083186915942, 0.2990456633269787, 0.2562294251152447, 0.5649825089744159, 0.206757749031697, 0.12172935876463141, 0.21002613008022308, 0.036494042458278794, 0.09217923334134476, 0.21742290817201138, 0.1917125784925052, 0.28501738607883453, 0.29631192716104643, 0.4230821361499173, 0.12897508139056818, 0.5420916144336972, 2.5928857581956044, 11.441603830882482, 28.861269235610962, 43.870515959603445, 59.34268120356968, 70.65120792388916, 54.7108278955732, 37.44838980266026, 31.044884817940847, 40.963407039642334, 57.71604190553938, 78.45754378182548, 82.85963753291539, 75.35534681592668, 87.30153751373291, 92.93014812469482, 75.36802727835519, 30.848910876682826, 6.21150758436748, 0.2925622340823923, 0.1665107158145734, 0.0644751845725945, 0.03346566263852375, 0.11533533329410212, 0.1186914217791387, 0.15305171587637492, 0.03995886618005378, 0.010110939370601304, 0.2479751551789897, 0.15339262544044427, 0.03044356605304139, 0.04989995042394314, 0.07898045836814813, 0.19189704502267496, 0.05478762136772275, 0.024890030035749078, 0.08052925526031426, 0.09345069261533873, 0.08294376784137317, 0.09302586184016295, 0.15556150834475244, 0.07738909018891198, 0.0904334984453661, 0.04885987498398338, 0.05959537784968104, 0.027603535680100322, 0.06610461178102664, 0.035811096962009153, 0.13436378937746796, 0.0948664830731494, 0.1007578701579145, 0.09910960003201451, 0.13592896610498428, 0.04927688225039414, 0.11838070702339921, 0.06036177636789424, 0.07598144893667527, 0.05395895369084818, 0.06265660894236394, 0.028158809723598615, 0.03416917792388371, 0.04759212051119123, 0.06161798896001918, 0.05145789396816066, 0.07023131248674222, 0.09647593421063252, 0.06074983054505927, 0.0805164852312633, 0.0678913030507309, 0.06823779695800372, 0.05524767828839166, 0.1288570977215256, 0.06290631661457674, 0.11620182251291615, 0.08258057518729142, 0.04639410586761577, 0.06515314283647708, 0.16536377450185163, 0.14884615583079203, 0.0797355185661997, 0.15228142935250485, 0.23592214765293257, 0.2215175006006445, 0.22646860778331757, 0.21272819223148481, 0.2892202048429421, 0.2546131547008242, 0.24424014559813909, 0.14504858532122203, 0.19015871972909995, 0.24761870716299328, 0.2775951086410454, 0.1733381487429142, 0.20257029230041163, 0.2531759361071246, 0.16798969145332063, 0.3163161166012287, 0.1996258438697883, 0.2756295012576239, 0.3412977675242083, 0.31574443727731705, 0.20852135654006684, 0.3913136422634125, 0.2384465964777129, 0.3062635117343494, 0.25607398631317274, 0.20407783426344395, 0.33411677713905064, 0.540149484361921, 0.2348731325141021, 0.28175026710544315, 0.3736088451530252, 0.28120510493006023, 0.16231591733438627, 0.2768619379826954, 0.17076787166297436, 0.19476997586233274, 0.2500999468777861, 0.1744546645453998, 0.21395172657711164, 0.2111015130898782, 0.18229734871004308, 0.33019755887133734, 0.23195174070341246, 0.2797587939671108, 0.29622371760862215, 0.3014260455965996, 0.35402390893016544, 0.5869773030281067, 1.1287307356085097, 17.659647498811992, 62.06670161655971, 94.20647662026542, 98.39196028028215, 76.69015829903739, 85.28495488848004, 51.13249519893101, 34.94327933447701, 28.76383638381958, 28.444931438991002, 62.49070848737444, 98.0924859728132, 88.44305011204311, 106.11346558162144, 136.34668268476213, 111.41858196258545, 66.48636041368756, 31.159762859344482, 13.847685967172895, 5.179502504212516, 0.7834866355572427, 0.4874013662338257, 0.4951764004571097, 1.0474247613123484, 0.5714541588510785, 1.8171538008110864, 1.434156066605023, 0.674738425229277, 0.8840253864015851, 1.2330821475812366, 0.5407829103725297, 0.6572739109396935, 0.40122044352548464, 0.4927920826843807, 0.32692083184208187, 1.018444693514279, 1.116443714925221, 1.007923492363521, 0.546058004455907, 0.4638690118278776, 0.38273429977042334, 0.36579909707818714, 0.460051953792572, 0.8812347618596894, 0.5121748968958855, 0.7854106351733208, 3.1506235216345106, 16.6961373261043, 50.0419476372855, 62.7447624206543, 85.61744703565324, 140.8537150791713, 128.53368350437708, 67.65586730412075, 48.99027524675642, 42.20014469964163, 47.6099009513855, 69.87415613446916, 85.67750031607491, 86.1515759059361, 93.22641236441476, 101.99216938018799, 84.14677047729492, 32.90996197291783, 5.45655540909086, 0.3293968875493322, 0.4605900049209595, 0.2380337757723672, 0.14946609256522997, 0.2996410642351423, 0.37120479558195385, 0.5510078359927449, 0.2574588220034327, 0.14525776409677096, 0.39596958671297344, 0.19883231073617935, 0.22423079929181508, 0.23664581882102148, 0.22948352886097773, 0.3967416509985924, 0.23458755069545337, 0.24378596139805658, 0.2401470866586481, 0.23776789861066, 0.24466713411467417, 0.4410091127668108, 0.2826426492205688, 0.21060895094914095, 0.3233721208359514, 0.1796403005719185, 0.23768373312694685, 0.2850204530571188, 0.2375522330403328, 0.25587256997823715, 0.2723554883684431, 0.2266632251973663, 0.36113023332187105, 0.3378451370767185, 0.2504550378237452, 0.16804857472223894, 0.2290496735700539, 0.23639503227812902, 0.20158071682921477, 0.22321781436247484, 0.15418450294860772, 0.20029728141214165, 0.19239059782453946, 0.20252853525536402, 0.1801338398030826, 0.35306066061769215, 0.2212090114397662, 0.218567623889872, 0.18784327326076372, 0.20028964110783168, 0.18716449396950857, 0.2858873222555433, 0.1874383371323347, 0.1727007193756955, 0.1965421193412372, 0.24322706567389624, 0.21859012411109038, 0.1756738969790084, 0.18931812340659754], [0.04383188299834728, 0.023803810821846128, 0.1017750823604209, 0.044766351248004606, 0.09610987813877207, 0.07501177489757538, 0.10309965057032448, 0.025790396811706678, 0.0338172591291368, 0.012859186856076121, 0.00390856950876436, 0.03823821333103946, 0.022086776260818754, 0.06373612423028265, 0.02218960993923247, 0.015431501237409455, 0.0025293548450073494, 0.04203965149021574, 0.0200070392872606, 0.03575411359114306, 0.06372100647006716, 0.007423706602172128, 0.0482805214290108, 0.06536984656538282, 0.019097692100331187, 0.007736864083978746, 0.0007058371473768992, 0.08992435969412327, 0.020323694617088352, 0.02965849425111498, 0.059955937787890434, 0.045787207183561156, 0.07680015571947608, 0.021455287467688322, 0.05450753229004996, 0.02407352001007114, 0.006294941546262375, 0.035583726662610254, 0.0444715108190264, 0.022093683747308593, 0.07033972202667169, 0.0355723103109215, 0.0539825395680964, 0.09840969116027866, 0.10923231792237077, 0.022823103803343008, 0.018347797250109057, 0.029693985025265386, 0.22447424408580574, 0.26609993832451956, 0.19582357789788926, 2.71109459229878, 37.4710305077689, 71.50048623766217, 74.20185552324567, 59.36598546164376, 59.02105603899275, 41.92990493774414, 27.464083773749216, 38.22468771253313, 35.143470832279746, 68.39218875340053, 76.8130441393171, 69.16014535086495, 100.47148663657052, 85.24589211600167, 25.60192138808114, 8.71859003816332, 3.6367965766361783, 1.4884032585791178, 0.15269145449357374, 0.15917237315859112, 0.11011749399559838, 0.08173094077834062, 0.05117620015516877, 0.08864323129611355, 0.08630563065941844, 0.009486079016434295, 0.35950823607189314, 0.22657322431249277, 0.05473387460889561, 0.04058892326429486, 0.3351000558052744, 0.07201763056218624, 0.11141477152705193, 0.06591028613703591, 0.08420914065624986, 0.09440896726612534, 0.07198659437043325, 0.05606774214122977, 0.09431672721569027, 0.1871848635907684, 0.09620814358017274, 0.30365628163729397, 0.4409898966550827, 0.31424221502883093, 0.42537699586578775, 0.1395878033446414, 0.2182819742177214, 0.011509558651596308, 0.26962509059480255, 0.8102166269506726, 0.18659068404563836, 1.8221891820430756, 12.620838199343, 30.610188143593923, 85.45219802856445, 89.49532699584961, 52.39168248857771, 31.30495936529977, 18.949401651109966, 30.03101757594517, 59.437447684151785, 73.10923739842006, 59.73508071899414, 72.26608044760567, 82.4680301121303, 56.05667659214565, 18.504334790366038, 3.799850821495056, 0.10011101593928677, 0.1640264362628971, 0.07320823560335807, 0.1658595936106784, 0.10854863282293081, 0.04636356161375131, 0.042472254884030135, 0.0533215141456042, 0.09496637021324464, 0.08635151319737945, 0.08505908040595905, 0.04694835362689836, 0.04838851706257888, 0.019779762286426764, 0.04468464206105896, 0.03962285563881908, 0.0996668062039784, 0.036507267105792246, 0.02758115929152284, 0.06311949874673571, 0.021620166388207247, 0.05103895966229694, 0.06448768997298819, 0.01501772549402501, 0.011928107888836945, 0.05412862476493631, 0.03213396641824927, 0.05164992277111326, 0.06593521551362105, 0.04577596725097724, 0.024642330827191472, 0.06747717277279922, 0.0467521382628807, 0.031016836541571786, 0.060147020034492016, 0.02070673950947821, 0.009527881862595677, 0.012873233379130917, 0.03623948326068265, 0.060724500832813125, 0.05796025773244245, 0.05116069223731756, 0.02157250778483493, 0.05649394016446812, 0.07225857156195811, 0.03160718236384647, 0.035666453652083874, 0.041416081200752936, 0.052740345509456735, 0.05360814769353185, 0.04332284942003233, 0.03787364325086985, 0.06079209649137088, 0.06114581001124211, 0.02930517428155456, 0.04378138981493456, 0.055600044916250875, 0.10770283892218556, 0.10455035165484462, 0.01629170891828835, 0.049458716064691544, 0.04337051650509238, 0.05927925516984292, 0.10692177047686917, 0.031227694691291878, 0.055384589691779444, 0.013178046576545706, 0.07722662854939699, 0.011333223515456277, 0.033065968193113804, 0.025913310037659745, 0.03632941968472941, 0.02762885351798364, 0.00358618819154799, 0.01206441200338304, 0.05580738825457437, 0.019091225661603466, 0.08349394439054386, 0.043637906799891164, 0.041797977672623735, 0.026876577009846057, 0.050331522444529195, 0.029763636644929647, 0.06963886320590973, 0.0567646926002843, 0.047875327457274706, 0.07425553404859134, 0.0806043351601277, 0.03299320209771395, 0.0355422885290214, 0.04342154912384493, 0.044206919481179545, 0.01679234901842262, 0.06783400076840605, 0.08625538514128753, 0.030423427133687904, 0.10803845591310944, 0.04636224525581513, 0.028641980939677784, 0.03099421418405005, 0.19661241556916917, 0.03534229711762496, 0.03606605988794139, 0.05006203886919788, 0.18686416079955442, 0.34208147547074724, 0.9244978832347053, 6.253037401608058, 53.439825194222585, 86.85075923374721, 85.71877261570522, 71.92183889661516, 82.26671995435441, 64.00246974400112, 40.49621711458479, 39.70150647844587, 24.331108025142125, 38.24106114251273, 41.965504033224924, 48.69394152505057, 80.47493934631348, 66.39235128675188, 26.729136330740793, 14.172525542122976, 6.397536482129778, 2.370859980583191, 0.13426298621509755, 0.020314520823636224, 0.10524598575596299, 0.02730455618750836, 0.0233040782622993, 0.06445564954940762, 0.08265198421265398, 0.11337658589971916, 0.3039236787174429, 0.25566488397972925, 0.19956165445702417, 0.22067192383110523, 0.3092871180602482, 0.3635068157953875, 0.8173035180994442, 0.9597798585891724, 0.6943066152078765, 0.5903517391000475, 0.42677836066910196, 0.23906324910266058, 0.2862148646797453, 0.4255969769188336, 0.11843910174710409, 0.08899435281221356, 0.19522823127252714, 0.1869365062032427, 0.11637768521904945, 0.06449955755046435, 0.3450486548244953, 0.09043202602437564, 0.4422041486416544, 0.434929221868515, 0.09751390279935938, 2.4771398433617184, 16.492647171020508, 41.716925280434744, 68.06523432050432, 68.06091948917934, 41.509594508579795, 28.279956885746547, 36.626362323760986, 52.32521602085659, 83.05985682351249, 94.06496265956334, 77.87065723964146, 87.05616882869175, 97.39009257725307, 78.82834829602922, 32.11714819499424, 8.874094196728297, 0.2546882006738867, 0.2325803084032876, 0.05610319559595414, 0.037648579970534356, 0.1711598749139479, 0.06451171689799853, 0.0053570857105244485, 0.04302145095009889, 0.07651016342320613, 0.025861909313659583, 0.08151739902262177, 0.042964287767452855, 0.026403563462996056, 0.06847792371575322, 0.010525928843500358, 0.006023575460338699, 0.09332577431840555, 0.009507037266822798, 0.05383121947358761, 0.12704733626118728, 0.005985691577994398, 0.02065715386665293, 0.039039261239979944, 0.03464416940031307, 0.05049969056355102, 0.1020820787442582, 0.04288049887067505, 0.051842965983918736, 0.05057224292042, 0.04084165720269084, 0.04909636479403291, 0.06088081494505916, 0.01958076492883265, 0.04512934034158077, 0.03970266153503742, 0.03945424647203513, 0.0438088806612151, 0.04489695566839405, 0.02655727878612067, 0.025810082808935216, 0.03943727631121874, 0.02240043076952653, 0.015472603496164083, 0.04609720269218087, 0.03860630500795586, 0.025969910036240305, 0.0032942417144243208, 0.0763560002669692, 0.06802889638181243, 0.09480510279536247, 0.0322965569794178, 0.049354669504931996, 0.04349946190736123, 0.01141182501201651, 0.06738543483827795, 0.06603239529899188, 0.12847707739898137, 0.20978571155241557, 0.22377968207001686, 0.2221542921449457, 0.2457802572420665, 0.2035123160375016, 0.1809158649827753, 0.21634486530508312, 0.17192490957677364, 0.11090212474976267, 0.09816817340574094, 0.16901643707283906, 0.16810578879501137, 0.25812492626053946, 0.15326877922884055, 0.19426901345806463, 0.0794088514521718, 0.0984563540135111, 0.13772857668144362, 0.11086026592446224, 0.2247389813086816, 0.11991290694900922, 0.1352436864482505, 0.25590636102216585, 0.16293353347906045, 0.1333850704665695, 0.08966109489223786, 0.14926232849912985, 0.11556697157876832, 0.09771457953112465, 0.18587694663022244, 0.19926983011620386, 0.18196621005024227, 0.1291995272040367, 0.16470745471971376, 0.12025453576019832, 0.1394494364836386, 0.1851747307394232, 0.15355650521814823, 0.07801089289465121, 0.19994536601006985, 0.21370650402137212, 0.11658721683280808, 0.12036334563578878, 0.27121313395244734, 0.09604950209281274, 0.20750142341213568, 0.1753454724592822, 0.30228740509067265, 0.35300146522266523, 1.2186335857425417, 8.511712636266436, 65.05510793413434, 98.31965732574463, 99.36155360085624, 80.63611670902797, 79.71383367265973, 60.56279877253941, 39.608285972050254, 55.4519852910723, 53.33862468174526, 96.17121178763253, 103.64775834764752, 97.73527908325195, 141.78910936628068, 119.86355454581124, 37.53721557344709, 14.744242429733276, 6.597075717789786, 2.9629396498203278, 0.45907106356961386, 0.20541614959282534, 0.1458825320005417, 0.16896167929683412, 0.18963885333921227, 0.23307031925235475, 0.4292161470013005, 0.40067457567368236, 0.7479862804923738, 0.5816797901477132, 0.30303612777165, 0.6855201838271958, 0.8933030771357673, 0.34256942357335773, 0.6491885419402803, 0.6471102706023625, 0.31894804537296295, 0.5098922508103507, 0.28315814584493637, 0.1669260470994881, 0.3889646625944546, 0.43947483652404373, 0.37098090616720064, 0.5261867535965783, 0.9044220947793552, 0.7081449297921998, 0.6320662807141031, 0.49849541378872736, 0.42939310893416405, 0.21015160477587155, 0.420310483447143, 1.0215923360415866, 0.3667197876742908, 3.3841535619327, 22.399859700884136, 48.3126973424639, 127.0146405356271, 130.85786982945032, 74.63508265359062, 45.24820130211966, 27.819579669407435, 45.673570019858225, 81.04446234021867, 96.39303302764893, 82.60961355481828, 92.91373647962297, 112.9771671295166, 90.35552092960903, 37.81273249217442, 7.759094187191554, 0.28452181124261444, 0.3643252104520798, 0.19734971172043256, 0.257169494671481, 0.3457344908799444, 0.10275857815785067, 0.17296878142016275, 0.17778259382716247, 0.20926442023898872, 0.14808701085192816, 0.19221092175160134, 0.15512472178254808, 0.16163736874503748, 0.22265591951353209, 0.15739218225436552, 0.11880552422787462, 0.22645283862948418, 0.1229145558817046, 0.13537629933229514, 0.2601380853780678, 0.16534924028175219, 0.27947481349110603, 0.13391192576714925, 0.10071360253329788, 0.1164006604147809, 0.14249455236962863, 0.11190802577350821, 0.10185983138425009, 0.1535675653389522, 0.1554481251431363, 0.19895416205482824, 0.10811542892562491, 0.13794622357402528, 0.12816322781145573, 0.15503845284027712, 0.12935791084808962, 0.13428604283503123, 0.14266494608351163, 0.09118199042443718, 0.1292023499097143, 0.1825417298823595, 0.14952793424682959, 0.1157107124371188, 0.16563248793993676, 0.11855179284300123, 0.13935379018740995, 0.08869038269455944, 0.20108225143381528, 0.20876568342958177, 0.18144155320312294, 0.2035914875034775, 0.12078425447855677, 0.15910631098917552, 0.15195004642009735, 0.12934941558965615, 0.14666565640696458], [0.02808353304862976, 0.048278061739568195, 0.04107286461762019, 0.11726329555468899, 0.01094946700946561, 0.02302797218518598, 0.025257259973191788, 0.06503412779420614, 0.03216933844877141, 0.009808311055946563, 0.04098149648468409, 0.039584718578095944, 0.005053872583500508, 0.05044973681547812, 0.00944426768858518, 0.018150106072425842, 0.01589432149194181, 0.014169095316901803, 0.01531133268560682, 0.04701001549671803, 0.004176493301721556, 0.029001448436507156, 0.014409059226246817, 0.010989033234571772, 0.04514764043103371, 0.082056861503848, 0.029370350962770835, 0.03128990956715175, 0.030876800484423126, 0.011176552324156677, 0.029396810435823033, 0.02304889650882355, 0.009123212059161492, 0.03908358993274825, 0.004943365522194654, 0.010178804746828973, 0.06237246561795473, 0.079734873957932, 0.10037505427109343, 0.04556645599326917, 0.07898312501077141, 0.036109072222773514, 0.05393517782379474, 0.023932832559304576, 0.04356747825763055, 0.03378481836989522, 0.12266143517834799, 0.14144897061799253, 0.10534950305840798, 6.393263339996338, 44.383140155247276, 77.14523751395089, 79.49808515821184, 72.70370578765869, 56.65279034205845, 39.309725352696006, 12.905082924025399, 27.133837631770543, 47.24260180337088, 30.845732075827463, 31.000266960689, 33.48933056422642, 34.78754588535854, 17.20119145938328, 4.169896245002747, 0.2594019834484373, 0.0482126950685467, 0.18504883535206318, 0.029943621451301233, 0.046940845636917014, 0.03458724031224847, 0.04679274858374681, 0.0075643423146435195, 0.09028544888964721, 0.06624155371849026, 0.04685309070295521, 0.032780325306313376, 0.07395792858941214, 0.1287540282521929, 0.22116692869790963, 0.06326793506741524, 0.25504999554583, 0.1688996340547289, 0.04212920454197696, 0.26693421070064816, 0.8009626578007425, 1.2664409918444497, 0.2688986781452383, 0.0386862058990768, 0.09270571544766426, 0.10622607530759913, 0.13544827832707337, 0.0660619590697544, 0.07480036374181509, 0.16562859314892972, 0.0916669461876154, 0.19934893372867787, 0.15666807682386466, 0.09423292814088718, 0.08350419026932546, 0.14690189515905722, 0.5638742712991578, 0.24452716591102736, 0.006368040123821369, 0.15899028150098665, 0.06897847899901015, 3.1353077377591814, 18.717788662229264, 62.89105674198696, 105.94704232897077, 66.98859010423932, 38.67751571110317, 17.70019371168954, 32.5502815246582, 38.382714067186626, 49.28208221708025, 71.6796316419329, 66.56128283909389, 76.09919316428048, 52.96226160866873, 19.18983016695295, 1.7226960808038712, 0.07544037832745484, 0.05442028286467705, 0.09502160296376262, 0.06886214417006288, 0.010901660824726735, 0.024496975055496608, 0.07649578526616096, 0.05272118028785501, 0.03147577727213502, 0.09981067598398242, 0.04812589008361101, 0.04127835216266768, 0.0436296083166131, 0.04738525554005589, 0.01277926136806075, 0.01901584890271936, 0.07118374495101826, 0.001426582769324471, 0.04028781656441944, 0.05469346784853509, 0.07123667068247284, 0.06017116231045552, 0.06378313313637461, 0.026364610463913, 0.04749958190534796, 0.046332047054810185, 0.02595284827319639, 0.02842249352085803, 0.01500420568377844, 0.0749141201376915, 0.05082441706742559, 0.030003603946949755, 0.06044128031602927, 0.018426829616406133, 0.04711961925828031, 0.050449451830770285, 0.03773326114086168, 0.02436684052060757, 0.07761215179094247, 0.06286679194974047, 0.036995588402662954, 0.02517272299155593, 0.035985120838241916, 0.0743231772046004, 0.09584913070180587, 0.013832910901068576, 0.02939425575147782, 0.09228332739855562, 0.07137838950646774, 0.013028488976747861, 0.053572348185947964, 0.035707328601607254, 0.018483358368809735, 0.04112728651879089, 0.0281021639239043, 0.03393907652103475, 0.050563289650848935, 0.06769939299140658, 0.024888827332428524, 0.011396594445354171, 0.05272352123366935, 0.035567170408155234, 0.03577081573062709, 0.12005105667880603, 0.011988882574119737, 0.020887530076184442, 0.013630816879283105, 0.05048932933381625, 0.006376674906018057, 0.05333944782614708, 0.02059170407509165, 0.06126852985471487, 0.01668389537371695, 0.016840983015884246, 0.015237521646278245, 0.07141407366309847, 0.030975435727408955, 0.021983255565698658, 0.01994724338874221, 0.07519464008510113, 0.071108271500894, 0.06390190390603882, 0.025916402461007237, 0.008362620104370373, 0.04153714541878019, 0.014255661118243421, 0.021568209265491793, 0.0400496711289244, 0.020206016288804154, 0.04057668588523354, 0.058767409063875675, 0.0513931142299303, 0.06089849756764514, 0.037714577679123194, 0.03584173281810113, 0.035701120006186624, 0.05467903880136354, 0.025606630868943672, 0.07377513125538826, 0.03149150910654238, 0.16163085480885847, 0.11432765450860773, 0.04858372819476894, 10.828774452209473, 61.07117067064558, 93.03032030378068, 88.94212532043457, 80.15340450831822, 76.90032046181815, 66.25708375658307, 30.01218100956508, 33.785983903067454, 39.1509416443961, 29.95805106844221, 30.073842797960552, 41.6673846244812, 44.58101442881993, 26.981104067393712, 6.732237722192492, 0.5231558733752796, 0.14197921859366552, 0.2873739110571997, 0.14412338925259455, 0.1644466665706464, 0.11795655478324209, 0.10349703460399594, 0.04289438508983169, 0.09946925073329892, 0.25517378747463226, 0.010889691466997777, 0.2253599494163479, 0.16684178662087235, 0.39807497231023653, 0.8957572568740163, 0.3289721246276583, 0.8100066067917007, 0.5236108718173844, 0.49479186109134127, 1.1337020631347383, 0.6753965499145644, 3.218996835606439, 2.172495859009879, 1.379320666193962, 1.0729116222688129, 0.7025881622518811, 0.335972678980657, 0.6122452414461544, 0.5692883293543543, 0.6422120077269418, 0.3434050530195236, 0.7763962160263742, 0.3021448855953557, 0.06780036578753165, 0.06631752928452832, 0.12365159418966089, 0.3700243889221123, 0.29339772782155443, 0.08555341352309499, 0.4271865673363209, 0.14768352678843907, 3.9764601332800726, 21.47376036643982, 52.90761750085013, 67.97166987827846, 34.330020904541016, 32.161588873182026, 37.851850850241526, 54.13265092032296, 63.709144592285156, 68.73426246643066, 80.8705836704799, 78.40981660570417, 93.81229141780308, 70.53170585632324, 31.36117376599993, 4.978333481720515, 0.0900486469534891, 0.04547665188355105, 0.031000622947301184, 0.04783478159723537, 0.033188202884048223, 0.04679785116708704, 0.08625985668706042, 0.03209430943908436, 0.08155335459325995, 0.032155190993632586, 0.03985918938581433, 0.01019044586324266, 0.013646483404694923, 0.01445770000905863, 0.029905504746628658, 0.07178332563489676, 0.02344714567464377, 0.0465968080264117, 0.023145202680357864, 0.03968929439517004, 0.14101996006710188, 0.08776112220117024, 0.06915976319994245, 0.07989242300391197, 0.0614798188741718, 0.03853005802791033, 0.0465146781477545, 0.040023398253002336, 0.025135707209951112, 0.07422087447983877, 0.017321507945390682, 0.03691617605675544, 0.0620093611734254, 0.10186281693833214, 0.017621009909947003, 0.03278962802141905, 0.033124427377645455, 0.029817885519670587, 0.0254598230323089, 0.0131586837316198, 0.04119386098214558, 0.00586661122672792, 0.00625088087482644, 0.06312000764799969, 0.05983274296990462, 0.03138034810711231, 0.014399646249200617, 0.047088732344231436, 0.0551552312847759, 0.026812450361571143, 0.03716928997476186, 0.036623459442385604, 0.03738219730023827, 0.0043741357097003076, 0.15673215767102583, 0.11940171223665987, 0.15963277273944446, 0.24790380043642862, 0.11574154506836619, 0.11329006589949131, 0.20239599022482122, 0.15766909239547594, 0.11612440166728837, 0.21493822149932384, 0.13458716310560703, 0.11839695115174566, 0.07498129510453769, 0.1378860103764704, 0.14338694805545465, 0.12874136678874493, 0.12002538091370038, 0.13933375983365945, 0.09532422279672963, 0.11425376204507691, 0.07531621998974256, 0.1510282973093646, 0.08521297893353871, 0.13745425854410442, 0.10850659757852554, 0.15276542838130677, 0.1825288784291063, 0.23286263325384685, 0.09522381318467003, 0.11956517132265226, 0.08617807286126272, 0.11297475746167557, 0.06658022411699806, 0.08977983173515115, 0.056701269932091236, 0.09085321306650128, 0.172587105472173, 0.15269438576485428, 0.20531172305345535, 0.11507290309028965, 0.18895940908363887, 0.04875713121145964, 0.17940117126064642, 0.09755517129919358, 0.27738478992666515, 0.27979228645563126, 0.32009257110101835, 0.22523110918700695, 0.3052762161408152, 10.731704643794469, 70.76754856109619, 107.55308369227818, 97.12914603097099, 93.1610506602696, 75.7632199696132, 57.98289442062378, 21.40488808495658, 37.77036585126604, 69.71815517970494, 48.317126819065635, 49.23804800851004, 54.79402562550136, 53.33705786296299, 29.12971636227199, 6.476713810648237, 0.3107367945568902, 0.4310200459190777, 0.3811425651822771, 0.3121368022901671, 0.18354526960424014, 0.15126476676336356, 0.23906924735222543, 0.24740114169461386, 0.20261569986385958, 0.26349485239812304, 0.13492235940481934, 0.21269947662949562, 0.10748028622141906, 0.22762815627668584, 0.3549743465014866, 0.10256654596222298, 0.5625312062246459, 0.2730428986251354, 0.30123317880289896, 0.2878361019705023, 1.1538213321140833, 2.729459115437099, 0.988091162272862, 0.5902951221380914, 0.5353672238332885, 0.3235177073095526, 0.27040966706616537, 0.37111588035311016, 0.44216050526925493, 0.3531744916524206, 0.2849292850920132, 0.5733610593846866, 0.35571232118776863, 0.38815587599362644, 0.3957413546741009, 0.28884451357381685, 1.0890552188668932, 0.688758478632995, 0.19379393037940773, 0.45009757365499226, 0.2842213287949562, 5.390325614384242, 30.26697145189558, 88.74201025281633, 144.5736277444022, 92.9354634966169, 57.11247968673706, 30.95395721708025, 43.472603048597065, 52.84436457497733, 68.82795197623116, 90.38519668579102, 87.23263222830636, 107.09999861036027, 79.8465929031372, 30.899959291730607, 3.7143649629184177, 0.22295978106558323, 0.15408429689705372, 0.20700058314417089, 0.18004582024046353, 0.09715657268783875, 0.20080521915640148, 0.23330625944903918, 0.10848027041980199, 0.1328844473298107, 0.17787062696048192, 0.16675658976393087, 0.12959006481937, 0.14765337269221032, 0.11829701651419912, 0.13086406859968389, 0.1444680036178657, 0.16055338191134588, 0.18456740118563175, 0.10910748104963984, 0.11836059524544648, 0.2382451801427773, 0.1891384066215583, 0.25320704015237944, 0.1401428585605962, 0.1338495412575347, 0.09458550850727729, 0.12321343698671886, 0.07876777835190296, 0.11252001686287777, 0.15607742566083158, 0.1525062280041831, 0.18955733414207185, 0.09332910592534713, 0.12014905070619923, 0.15179159492254257, 0.17172547456409248, 0.06501458598566906, 0.16168226062187127, 0.19346405379474163, 0.12584452437502996, 0.07571813663733856, 0.08545092080852815, 0.10326722836388008, 0.12390870467892715, 0.16383042106670992, 0.09769161112074341, 0.0956401147746614, 0.14280931119407925, 0.14541776265416825, 0.10869250260293484, 0.1971958606903042, 0.15738397198063986, 0.15321932759668144, 0.07249658129044942], [0.014538567812581147, 0.03850565790863974, 0.02653186934600983, 0.1130091795431716, 0.04487098813323038, 0.0371378398766475, 0.017545253171452453, 0.03423776424356869, 0.02779802756517061, 0.022933893304850374, 0.013989399736081915, 0.041184615942516496, 0.00020469734330877794, 0.04166203657431262, 0.038082486151584556, 0.031458834252719364, 0.03534925210156611, 0.028286275919526815, 0.04144678491034678, 0.03980328827830298, 0.04480805401025074, 0.034677292087248394, 0.02902460005134344, 0.0202886024822614, 0.05334626031773431, 0.0237239251977631, 0.03549477072166545, 0.07642958060439144, 0.04748183482193521, 0.051927053436104736, 0.06480778886803559, 0.019309892053050653, 0.04549698757805994, 0.02207210972639067, 0.040752093972904344, 0.02198328440343695, 0.04022917078275766, 0.04776782036892005, 0.054538687225431204, 0.017979323897244673, 0.03468673390203288, 0.02976469515955874, 0.03459360836339848, 0.04625766943874104, 0.08072373696735927, 0.08775941229292325, 0.22881145349570683, 0.050762765375631194, 22.338029418672832, 73.34544140951974, 76.00830377851213, 66.84463732583183, 65.13831956045968, 54.68171841757638, 28.851223877498082, 18.97215700149536, 38.51961442402431, 58.6355630329677, 43.00801174981253, 26.978616612298147, 26.85418827193124, 11.50095534324646, 2.076728403568268, 0.14047759345599584, 0.06740568232323442, 0.13602689227887563, 0.06130690101001944, 0.03765451715194753, 0.029086970990257602, 0.03417599041547094, 0.07879209704697132, 0.06439303433788673, 0.055553558482123275, 0.1656607828502144, 0.010271618159354796, 0.25602467038801735, 0.13533960415848664, 0.33699067149843487, 0.38376597155417713, 0.3035131107483591, 0.22360035883528845, 0.2034952440964324, 0.2132799904793501, 1.502811108316694, 1.3702112521444048, 2.595113741500037, 3.4255624370915547, 1.8309664939131056, 1.0547001766307014, 0.7049743799226624, 0.43510360536830767, 0.868338579578059, 0.1494064357663904, 0.1874334788216012, 0.17893621192446776, 0.07097303268632718, 0.20900797471404076, 0.054801643293883116, 0.06404035219124385, 0.05480674248454826, 0.06341930265937533, 0.2500895788627011, 0.12935694732836314, 0.03697563947311469, 0.22582778574100562, 0.08573064008461577, 0.10886055537100349, 0.06519423491720643, 1.9866513056414468, 20.597639424460276, 75.92095102582658, 78.42738859994071, 59.64777660369873, 31.289336340767996, 23.1324325970241, 40.853979860033306, 50.01263318743025, 69.07999788011823, 63.148035866873606, 66.77434934888566, 73.28355380467006, 50.37581900187901, 15.582493952342443, 0.10843481535890273, 0.2834071139139788, 0.06146292335220745, 0.025805326278454492, 0.040437114624572654, 0.025616188034681336, 0.05013594490342906, 0.05635795496138079, 0.036853319965302944, 0.04359066379921777, 0.04265507596677967, 0.04161205229216388, 0.002218757348600775, 0.020344937852184688, 0.03368865638705237, 0.06248623558453151, 0.01022849216990705, 0.10399966620440994, 0.05975140697721924, 0.03279008263988154, 0.004659134412317404, 0.050446143972554376, 0.000591806421912874, 0.04996692183028374, 0.02892621586631451, 0.02172368877966489, 0.020738742613632764, 0.021424497244879603, 0.025158858824787394, 0.07251287291624717, 0.022730078348623853, 0.05081410672781723, 0.04665470402687788, 0.04146940726786852, 0.0609541442245245, 0.055874183241810114, 0.03444102619375501, 0.0962420024776033, 0.07194649295083114, 0.013375507052322584, 0.032671501860022545, 0.03881906644840326, 0.027602042903059294, 0.035905593141381226, 0.010110667956593846, 0.0344531312584877, 0.059054022255752764, 0.016101471447784985, 0.03504466112436993, 0.06068682178322758, 0.08509146688239914, 0.087614952187453, 0.07326498148696763, 0.04370853890265737, 0.05809387484831469, 0.03958992972703917, 0.05663686338812113, 0.050291560124605894, 0.1040793601423502, 0.04486343603847282, 0.05473179829173854, 0.00663303306958239, 0.04667129760075893, 0.014997125170858843, 0.028307430945070725, 0.031032320710697343, 0.01095733801568193, 0.04128811288891094, 0.04014901204832962, 0.03576818640742983, 0.06202599885208266, 0.033025880344212055, 0.07799351561282362, 0.03761863282748631, 0.1020352869693722, 0.040028443160865984, 0.0537432711571455, 0.06126608034329755, 0.01746280607767403, 0.056067416444420815, 0.03009530795472009, 0.038724549912980626, 0.07340200484863349, 0.030307913332113197, 0.03956130572727748, 0.032161945809743235, 0.019818725463535105, 0.049834556611520905, 0.028666995133140256, 0.04660312518743532, 0.0377680428459176, 0.02015515330380627, 0.06334034832460539, 0.09239913975553853, 0.05117043600018535, 0.0314308548612254, 0.03956529212051204, 0.27386902858104023, 0.12171270751527377, 0.3176158368587494, 0.5372183759297643, 33.58015046800886, 92.2403518131801, 85.0886196408953, 77.40484305790493, 91.96332713535854, 78.04296561649868, 42.964394433157786, 31.067945889064244, 21.179316554750713, 42.90602261679513, 42.1405291557312, 34.17591680799212, 36.408181939806255, 15.712913376944405, 2.8800621884209767, 0.01861775410361588, 0.043061806820333004, 0.17329138410942896, 0.06239047393734966, 0.21635726892522403, 0.10508536294634853, 0.16621776510562214, 0.348215540604932, 0.22260482582662786, 0.3087345462824617, 0.6009368311081613, 0.9067470814500536, 1.2708236766713006, 1.4371529115097863, 1.965374618768692, 4.573058954307011, 2.681135914155415, 1.9084810316562653, 1.429132519023759, 1.9491640371935708, 2.8196897251265387, 8.10471408707755, 7.651830502918788, 8.218256337302071, 8.328202026230947, 4.97857232604708, 3.332820487873895, 3.9977780750819614, 2.7366494153227126, 1.4383613552365984, 1.871169205222811, 1.4319799776588167, 1.3462325845445906, 0.7898547138486589, 0.6949475865278925, 0.6391912241067205, 0.7356242409774235, 0.6749230410371507, 0.3859096536678927, 0.17790905918393815, 0.10158695852650063, 0.19562609706606182, 0.2054040716694934, 0.2351066299847194, 0.07987322724823441, 2.251898786851338, 24.011216436113628, 62.427813393729075, 63.17919853755406, 41.035136767796104, 28.833417381559098, 27.626322473798478, 57.71649701254708, 73.74885381971086, 81.10445308685303, 73.0723077229091, 79.5370784487043, 89.21173627035958, 69.0097654887608, 28.623593943459646, 1.5284831821918488, 0.19992803622569355, 0.024114688425990086, 0.02124308072961867, 0.075984095223248, 0.038061003732894144, 0.01697013876400888, 0.02244393843492227, 0.1326454130134412, 0.03411408427304455, 0.024376613121213656, 0.07479465047695807, 0.0044043203400048825, 0.017447262536734343, 0.05686381978115865, 0.01504777102465076, 0.03638212828497801, 0.03496291461799826, 0.033876773435622454, 0.07842947436230523, 0.09257530101708003, 0.02237920619414321, 0.06466406158038548, 0.06417327720139708, 0.00898469252777951, 0.006076244196654963, 0.07922130437301737, 0.02104350152824606, 0.003749750754130738, 0.054354811020727666, 0.06120278659675803, 0.02690313147780086, 0.032687494930412085, 0.038008251027869325, 0.08322816222373929, 0.05881158847893987, 0.03653293608554772, 0.05175990990496107, 0.07639592526746647, 0.03348442752446447, 0.05264113011902996, 0.04186410091019102, 0.04481557896360755, 0.004283357054061655, 0.020004075785566653, 0.015248919338253992, 0.027898165763222744, 0.0647302187447037, 0.05551485484465957, 0.008294016821309924, 0.017832003766670823, 0.014173039301697696, 0.03708416097132223, 0.14898445483829292, 0.14240140308226856, 0.13077363345239842, 0.1660027237875121, 0.1680558214762381, 0.1598375817494733, 0.22348728775978088, 0.10861008095421962, 0.07865934845592294, 0.13322157066847595, 0.09278101926403386, 0.14490891567298345, 0.061808698012360504, 0.11836679705551692, 0.14650309298719677, 0.0861761254657592, 0.08754109365067311, 0.1356466141130243, 0.1132065789507968, 0.1379722793187414, 0.14711321810526506, 0.1955089004976409, 0.1750447457390172, 0.16015559754201344, 0.10689447979841914, 0.12033241800963879, 0.15309896905507359, 0.16228826024702617, 0.10864009934344462, 0.16351775213011674, 0.14450061401086195, 0.1188410794628518, 0.11239931905376059, 0.1505735024277653, 0.1603090957339321, 0.10277425231678144, 0.11967528398547854, 0.16227059119514056, 0.1651022806763649, 0.2041576706937381, 0.146288716633405, 0.12176171131432056, 0.15557780675590038, 0.15457631620977605, 0.4046150456581797, 0.2175035724150283, 0.47122031450271606, 0.5419977051871163, 35.03117752075195, 107.57995932442802, 95.04562446049282, 83.66783114842006, 86.42207622528076, 75.19115393502372, 41.3646377154759, 27.030608245304652, 56.417583397456575, 81.00159195491246, 62.4662230355399, 45.02840198789324, 45.58429956436157, 18.295678649629863, 3.467758195740836, 0.5252602004579136, 0.4114345397268023, 0.3174409648137433, 0.2117060199379921, 0.4137512482702732, 0.284120715622391, 0.32400459689753397, 0.3644415656370776, 0.21500230234648499, 0.2704394683241844, 0.4466377507363047, 0.9286175136055265, 1.0240388619048255, 1.5244984988655363, 1.1824523614985603, 1.7023329734802246, 1.2260877000434058, 1.1405419132539203, 0.6696887676204953, 1.8798509793622153, 3.8669925672667365, 6.720741927623749, 7.9360813072749545, 9.461674690246582, 9.64931513581957, 5.1572244082178385, 2.153820186853409, 3.0409333961350575, 3.120412971292223, 0.9672525376081467, 1.3493657878467014, 1.131566360592842, 0.9839600239481244, 0.4225919895938465, 0.3982276426894324, 0.44895766196506365, 0.40902669035962647, 0.3190699645451137, 0.49253505361931665, 0.28627150878310204, 0.24198434235794203, 0.6201211331146104, 0.271430889410632, 0.279276328427451, 0.23873885508094514, 3.7761066555976868, 33.03972652980259, 113.05011626652309, 112.79298428126744, 80.80576392582485, 46.534330231802805, 31.9232656615121, 54.82101590292794, 67.58307797568185, 91.82309859139579, 77.82564680916923, 91.61261681147984, 101.33058275495256, 77.48574093409947, 27.874013594218663, 1.11932906295572, 0.627745261149747, 0.14380324286009583, 0.08419339185846703, 0.16287215320127352, 0.17414890309529646, 0.16434133079435143, 0.15560162333505495, 0.20352478751114436, 0.08539716726435082, 0.1785205549427441, 0.16626571039003984, 0.11871675827673503, 0.05957048239984682, 0.15110413038304873, 0.11214427131095103, 0.11239851838243858, 0.13612966319280012, 0.1901556256094149, 0.22755902712898596, 0.21298311783799104, 0.1519478072545358, 0.16852631765816892, 0.13003286320183957, 0.16679453344217368, 0.16826038621366024, 0.1422535910138062, 0.14032155754310743, 0.13279053808322974, 0.13751179831368582, 0.14660720740045818, 0.10665818676352501, 0.14405025674828462, 0.12783708316939218, 0.20243544025080545, 0.13369057407336576, 0.09352231198655707, 0.16955622525087424, 0.24252858172569955, 0.0825519681509052, 0.11725849152675696, 0.12050780574125902, 0.15188312929655823, 0.09731570950576238, 0.07044083052980048, 0.10975778901151248, 0.16443553859634058, 0.12201844182397638, 0.09832636027463845, 0.13372641429305077, 0.20985071520720208, 0.18483295265052999, 0.1649592997772353], [0.02102494189914848, 0.10434274029518877, 0.019126273691654205, 0.0525172126612493, 0.06555662011461598, 0.018218029124130095, 0.05406253545411995, 0.023248865867831876, 0.0357001259523843, 0.0445003790913948, 0.01474283738727016, 0.05955200589128903, 0.006105182442947158, 0.03289464149358017, 0.028342638430850844, 0.07026769553444215, 0.07607987044113022, 0.01576908428354987, 0.016053212340921164, 0.06315724564982311, 0.03237149777955242, 0.01635284661980612, 0.052154593369258304, 0.02158221253193915, 0.07810691917049033, 0.05495273947183575, 0.02477068081498146, 0.04904764597969396, 0.029505046949322735, 0.03394585169319596, 0.05227761176813926, 0.03587569688845958, 0.03418880454929812, 0.07146174074815852, 0.02885141077318362, 0.0400410876609385, 0.06008701039744275, 0.016571870938475643, 0.027250906119921377, 0.06435313647879021, 0.04626404766791633, 0.050353649471487315, 0.03243638269071068, 0.10493539992187705, 0.2021599414625338, 0.6523053518363408, 11.283989156995501, 42.73561109815325, 71.33121422358921, 70.89082350049699, 65.45954867771694, 44.7005547114781, 20.80248100417001, 21.320120062146867, 39.59414986201695, 62.82356194087437, 70.20370919363839, 49.66282960346767, 28.178249154772075, 8.865678191184998, 1.3460739701986313, 0.4363726558429854, 0.07756602498037474, 0.044395301158406904, 0.04132341028058103, 0.024973398240815316, 0.046670208552054, 0.06843667557196957, 0.20419592649808951, 0.18760261046034948, 0.2901732479887349, 0.5163007155060768, 0.11987949588469096, 0.3550968085016523, 1.4823938267571586, 1.2028389189924513, 1.1651227942534854, 2.1313203998974393, 5.546713062695094, 5.895297237804957, 1.3709769653422492, 1.8550956334386552, 1.4875450474875314, 3.6906142830848694, 10.71748341832842, 1.590216298188482, 4.833645931312016, 6.835903108119965, 4.1493478161948065, 6.099369304520743, 5.736239944185529, 1.6755061958517348, 1.231408717376845, 3.0401925444602966, 3.0006959438323975, 0.4987768158316612, 2.7099212152617316, 1.6543200526918684, 0.3377298946891512, 0.1747590960668666, 0.16782361322215625, 0.27123484707304407, 0.12502371413367136, 0.1343674806079694, 0.046378231540854485, 0.13877520337700844, 0.08999344134437186, 0.09277986575450216, 0.030825242001031126, 0.13901972025632858, 1.3684286049434116, 22.110802480152675, 77.8539398738316, 83.77525724683488, 62.22372395651681, 27.52299060140337, 19.894625902175903, 41.36054522650582, 42.79384395054409, 50.37489489146641, 64.13505526951381, 73.456376348223, 75.0744103022984, 50.116828373500276, 16.210529463631765, 0.2065877624388252, 0.06207125713782651, 0.003072579378827608, 0.048669613764754364, 0.03353306491460119, 0.02857246502701725, 0.07966624014079571, 0.026183144754863212, 0.047602715835507424, 0.03289368815187897, 0.01737817410113556, 0.02654793535891388, 0.05577976170129009, 0.0056517972178491095, 0.04001391911879182, 0.014567466619025384, 0.02713753139999296, 0.05128402954765728, 0.0408675806330783, 0.022353533821712648, 0.017203809261055927, 0.009949825471267104, 0.07998652902564832, 0.029583743440785577, 0.03653288858809641, 0.013084022827180368, 0.04503385350108147, 0.018753093002097945, 0.04393156657793692, 0.05673211952671409, 0.011085630327995335, 0.014440527984074183, 0.05807272491178342, 0.039246356913021634, 0.011793358467652329, 0.02028793582160558, 0.0498860642047865, 0.016616725495883396, 0.0955778591867004, 0.0697299972442644, 0.02267403814143368, 0.024624066360827004, 0.02328282654551523, 0.07434469355004174, 0.019454155383365493, 0.041303837937968116, 0.0431729576417378, 0.01836884201371244, 0.040015069235648425, 0.04913034922044192, 0.07114636445684092, 0.026087140531412194, 0.0844110387510487, 0.01739935966075531, 0.0011540211895148136, 0.008839810882428927, 0.017003675357305577, 0.044890736894948144, 0.008748721797019243, 0.04953058649386678, 0.028755564309124435, 0.034630507097712586, 0.006106581497338733, 0.02412570104934275, 0.05314713403848665, 0.01283924640821559, 0.05686782992311886, 0.0178122346489025, 0.08294081621404205, 0.08781370187976531, 0.04199473586465631, 0.028832774808896438, 0.022358987546925033, 0.015143234116424407, 0.04657053854316473, 0.08914124207305056, 0.07290841812001807, 0.08516822276370865, 0.027056770465735878, 0.0346353179109948, 0.01538249065301248, 0.012987432519106992, 0.04128259639920933, 0.024015432323462198, 0.024734475882723927, 0.009959816899416702, 0.029725642076560428, 0.0441340957103031, 0.04091874895883458, 0.012822774122469127, 0.03611492797998445, 0.022023574116506746, 0.007272344947393451, 0.01306437499754663, 0.058278857065098624, 0.1742660589516163, 1.5730015933513641, 20.804883343832834, 62.14486885070801, 86.34711905888149, 79.49008778163365, 84.69654669080461, 60.58697155543736, 40.53359842300415, 30.468021052224294, 33.0417970929827, 31.572909695761545, 51.59469631740025, 53.506899629320415, 34.008913380759104, 13.055203097207205, 1.9973254757268089, 0.2446127970303808, 0.0484238008835486, 0.07254786496715886, 0.05846817512065172, 0.08608337651406016, 0.3734800049236843, 0.7025552125913757, 1.648284130862781, 1.2164031054292406, 1.1612698010035922, 1.9623402101652963, 1.6399557377610887, 2.8237335767064775, 4.043925404548645, 3.7500035762786865, 5.986778523240771, 7.678055609975543, 10.354649356433324, 7.707779135022845, 6.022075806345258, 6.7855595009667535, 4.518856491361346, 8.026989800589424, 10.263902408736092, 10.397267869540624, 12.92571038859231, 14.316097906657628, 8.385258027485438, 7.809677941458566, 6.531588511807578, 5.839616111346653, 5.346687887396131, 7.479991129466465, 6.4068852833339145, 2.6262631671769276, 7.39034720829555, 5.044743061065674, 2.8095440523965016, 1.7906254700251987, 1.1893436717135566, 1.4056365340948105, 1.1111504903861453, 0.3989500382116863, 0.3975849343197686, 0.20477904592241558, 0.11469069788498537, 0.15208116652710096, 0.16335532441735268, 0.16644351370632648, 1.7031010751213347, 22.287809576307023, 65.48686899457658, 56.66110038757324, 36.56566980906895, 35.436184542519705, 33.17029012952532, 65.47124249594552, 70.73637199401855, 65.60034697396415, 71.03706223624093, 84.637070110866, 88.3709556034633, 73.66079235076904, 29.17750780923026, 0.3764889006103788, 0.17348511942795344, 0.048122022434004715, 0.049985266024512906, 0.011319037892722657, 0.01882603551660265, 0.03601410446156349, 0.05326777756480234, 0.012610508012585342, 0.03131738345005682, 0.01583205911863063, 0.05239387535090957, 0.06694714871368238, 0.012420022028631397, 0.0646700259031994, 0.07146308424749545, 0.061560150635029585, 0.009331543514105891, 0.07513748029513018, 0.02513249943565045, 0.049361210582511764, 0.04545414148430739, 0.03354452197839107, 0.016233999514952302, 0.010205144628084131, 0.013768034471598054, 0.07286738032209021, 0.023747243053678955, 0.03793786659038492, 0.009263634881270784, 0.024765157539929663, 0.019640857686421702, 0.023076037909569483, 0.03148433020604508, 0.029342056052493196, 0.015932361861424785, 0.014502778483022536, 0.053853767192257304, 0.041070160655570884, 0.07683349893029247, 0.05017588008195162, 0.04037102870643139, 0.01105815644509026, 0.017419452778995037, 0.0215745552642537, 0.0495769168649401, 0.03323398703443153, 0.06815808266401291, 0.01934019542698349, 0.047588442851390154, 0.045767577165471654, 0.07722542754241399, 0.15549133425312384, 0.1395057277487857, 0.16100363060832024, 0.16588285379111767, 0.06295044853218965, 0.2072656053517546, 0.1186809316277504, 0.14835644353713306, 0.10138657356479339, 0.08218509105167218, 0.10748115474624292, 0.11430098808237485, 0.10355403833091259, 0.06787455680647067, 0.16352837798850878, 0.27170927875808304, 0.16711514123848506, 0.11493935382791928, 0.13801136293581553, 0.15585106637861046, 0.170814432735954, 0.18437708568360123, 0.1592445692845753, 0.22248857920723303, 0.16181371999638422, 0.09175774774381093, 0.15000099529113087, 0.07363582123070955, 0.10790900500225169, 0.14284030667373113, 0.11556838293160711, 0.14377497509121895, 0.11091030109673738, 0.06160945298948458, 0.155017635385905, 0.15625335622046674, 0.09727054621492114, 0.13240982565496648, 0.13857624333884033, 0.10890912490763835, 0.11044493463954755, 0.15548651665449142, 0.2409311474433967, 0.3860943780413696, 1.434088321668761, 20.948024920054845, 70.65330627986363, 98.48654610770089, 86.41134820665631, 83.38114152635846, 62.437658991132466, 28.575196266174316, 31.107095514025005, 56.23491178240095, 86.39832033429826, 96.07121331351144, 71.04027925218854, 44.63785069329398, 15.769989354269844, 2.9721177858965735, 0.7485623838646072, 0.21126438863575459, 0.16316260690135614, 0.14657192357948848, 0.23356858108724865, 0.532043596463544, 0.5963991688830512, 1.2427415549755096, 0.9013842663594654, 1.4263307665075575, 1.610496461391449, 1.192960860473769, 1.271007695368358, 7.144941176686968, 6.516625566141946, 5.36635867186955, 8.757650205067225, 11.326836960656301, 9.549934182848249, 7.153245142527989, 6.037604161671229, 5.924164831638336, 10.241604770932879, 20.989542143685476, 11.86874086516244, 18.87758333342416, 19.11014301436288, 14.779544489724294, 15.727080753871373, 13.705651760101318, 7.116442705903735, 7.3826607636043, 9.634714365005493, 7.287292395319257, 3.5332642921379636, 8.05835223197937, 6.11651485306876, 2.407837859221867, 1.5471213992152895, 0.8592372536659241, 0.8307019791432789, 0.7737010749323028, 0.2888769475477082, 0.32847910108310835, 0.346959545144013, 0.37367344168680056, 0.26375958962099894, 0.3090894472386156, 0.3274854544017996, 2.3196491513933455, 32.517506871904644, 116.064133644104, 119.32078906467983, 88.69989027295793, 43.58085250854492, 29.79144021442958, 58.340202059064595, 63.26476560320173, 71.93171923501151, 79.70197309766496, 96.31684603009904, 100.62931496756417, 78.4329332624163, 25.64667820930481, 0.27980734993304524, 0.3024062844259398, 0.118392961365836, 0.17909983385886463, 0.13250330063913549, 0.12023088202944823, 0.21328874358109065, 0.10873394073652369, 0.14908710361591407, 0.1619392761162349, 0.07905550434121064, 0.1919537162674325, 0.13431938604584762, 0.10063823086342641, 0.133930219071252, 0.1306319281991039, 0.08842344023287296, 0.08556637354195118, 0.12273466267756053, 0.1625484512852771, 0.12425696956259863, 0.11147205345332623, 0.1757336352020502, 0.13376762851008347, 0.08731128062520709, 0.0567370830103755, 0.13165096566081047, 0.06548126880079508, 0.1335998810827732, 0.14728726233754838, 0.07384928834757634, 0.18485970050096512, 0.11795253785593168, 0.12439376222235815, 0.0975468321038144, 0.07284062568630491, 0.19004977414650576, 0.11858153981821877, 0.2015051958816392, 0.13959271593817643, 0.1556269055498498, 0.19277565287692205, 0.06794405236308064, 0.18763068823942117, 0.10861725985471692, 0.14388557629925863, 0.11867061789546694, 0.1522197640900101, 0.09707757085561752, 0.12017672136425972, 0.17854939268103667], [0.024843207726787244, 0.029525396214532, 0.03882633355845298, 0.02196353055270655, 0.05953295262796538, 0.028923243882932832, 0.050952090216534476, 0.043286113534122705, 0.04951695811801723, 0.018808101836059774, 0.04179004899093083, 0.018833241558500698, 0.0461540673194187, 0.04120473789849451, 0.15386563220194407, 0.03889393260968583, 0.018445095779108148, 0.020119245230619396, 0.049728158927921734, 0.014546822191083005, 0.0478981737313526, 0.05486953750784908, 0.025810077719922577, 0.021166256994807293, 0.04293801489153078, 0.017831333713339906, 0.021502796793356538, 0.02730444592556783, 0.03497606462665966, 0.03131134109571576, 0.0017968097111276749, 0.013443983958235808, 0.03283359030527728, 0.013836052518204918, 0.062466028811676164, 0.06582069237317358, 0.07892300002276897, 0.012088771410552519, 0.049904652671622377, 0.019923740632033775, 0.023594068862231712, 0.06443313575748887, 0.11287664129797902, 1.218872647200312, 16.672483921051025, 47.077651568821494, 68.16676139831543, 75.68341296059745, 68.76646041870117, 48.95456150599888, 28.13542914390564, 28.276316029684885, 46.32442167827061, 45.68397494724819, 47.24717719214303, 51.88785471235003, 21.07373172896249, 8.537300246102468, 0.46953635343483513, 0.21426637683595928, 0.067467340800379, 0.20665524953177997, 0.19965905137360096, 0.021891069798065082, 0.0238559613270419, 0.21578895513500485, 0.22939618783337729, 0.22014411858149938, 0.3614569886454514, 0.3824667941246714, 1.3125720364706857, 1.325455516576767, 0.7691129839846066, 1.7323834981237138, 3.506952766861234, 3.144643945353372, 5.640423851353781, 8.717401896204267, 19.282335008893693, 7.025760463305882, 5.3949474692344666, 8.127258385930743, 2.0936277253287177, 4.768940831933703, 11.837729317801339, 18.077347142355784, 9.25456886632102, 10.474663853645325, 4.589257376534598, 6.09352673803057, 6.422713713986533, 2.1229215477194106, 2.7040632324559346, 4.301681424890246, 1.4834882766008377, 3.7796346034322466, 4.745402940682002, 3.1049894903387343, 2.0221140427248816, 1.871964339699064, 3.880589323384421, 0.7324745899864605, 0.36219819315842217, 0.09149557538330555, 0.10984103168760027, 0.06688637911741223, 0.04824650986120105, 0.045459182999495945, 0.06780548194157225, 0.20420524956924574, 0.18335198211882794, 0.05908612374748502, 4.347551694938114, 31.06919309071132, 57.85803876604353, 66.09207793644497, 45.17370966502598, 18.52211175646101, 16.923937491008214, 38.77314029421125, 54.324459416525706, 64.57194410051618, 63.68332508632115, 67.63135405949184, 71.82315363202775, 40.88378068378994, 2.0025776624679565, 0.31034769543579643, 0.021191196549417715, 0.07359565874295575, 0.09129007426755768, 0.007471292263029942, 0.06003796588629484, 0.04885552557451384, 0.016176810887243067, 0.04999960346945694, 0.054342051169701984, 0.0014942969594682965, 0.0291930022649467, 0.062151799244540076, 0.04131427041387983, 0.020221770175599625, 0.08687799530369894, 0.05118627300752061, 0.03520352313561099, 0.052158033541802845, 0.039225366432219744, 0.027575354424438307, 0.014208145855393792, 0.03471939179248043, 0.048469890374690294, 0.03905504057183862, 0.060233635029622486, 0.027033998830510036, 0.024627983204222152, 0.03179836639070085, 0.0314191569175039, 0.010414637226079191, 0.03975904440241201, 0.030551975592970848, 0.03820555204791682, 0.019938008527138402, 0.014557229221931525, 0.04281643498688936, 0.019356018863618374, 0.011981412751733192, 0.0636509545147419, 0.009986317932738789, 0.035565826908818314, 0.0355446973283376, 0.04564567156402128, 0.0740405877253839, 0.02945960545912385, 0.025937856041959355, 0.0894481163205845, 0.026234218085716878, 0.043029501768095155, 0.029187404351042848, 0.04115702670865825, 0.02982492871316416, 0.04621522368064948, 0.026913721713104417, 0.05061141813972166, 0.0672295753444944, 0.03421741497835942, 0.053115677155022106, 0.040282978609736474, 0.01913155778311193, 0.0338396507847522, 0.019746407201247554, 0.09703723873410906, 0.03000974129619343, 0.018524525088391135, 0.023017802641593983, 0.06889645090060574, 0.02173229769271399, 0.0807234248412507, 0.04460377086486135, 0.03315802503909383, 0.027282790480447665, 0.050115561711468866, 0.038088881344135316, 0.023297499865293503, 0.02911765773647598, 0.07476258291197674, 0.10163325497082301, 0.02816942031495273, 0.012364472062992198, 0.036728126861687214, 0.082548758680267, 0.04578023862891963, 0.039160549374563355, 0.018568346576232995, 0.06287055103374378, 0.02723202757936503, 0.018928031204268336, 0.09832956974527665, 0.05571912781202367, 0.09739843649523598, 2.8569055795669556, 29.686842032841273, 66.33459091186523, 82.9398614338466, 85.84516034807477, 81.3834718976702, 78.87884780338833, 52.838385650089805, 37.619280747004915, 18.46013903617859, 30.590625490461075, 40.62688493728638, 49.753694670540945, 29.53177908488682, 10.168658239500862, 0.9331171235867909, 0.20931802450546197, 0.02205541097958173, 0.2234383789556367, 0.04055676409708602, 0.29163494812590735, 0.34407734551600044, 1.0233083239623477, 1.3977951662881034, 3.654338606766292, 2.817623938832964, 3.3760428428649902, 5.249330597264426, 4.680153276239123, 4.942538968154362, 4.427838129656656, 8.26693628515516, 2.917150152581079, 5.953483189855303, 5.967468610831669, 11.445700662476675, 12.00767878123692, 12.002280899456569, 8.834637113979884, 8.734251277787344, 9.301342402185712, 12.595203689166478, 17.41253134182521, 16.9485410622188, 12.18427072252546, 8.698100669043404, 9.007589936256409, 3.265024960041046, 3.867184945515224, 3.7254456026213507, 6.1318230373518805, 4.814744225570133, 3.516019297497613, 4.065658935478755, 6.203302196093968, 3.466802818434579, 3.7165718844958713, 5.284052048410688, 3.1325486515249525, 2.193752569811685, 1.592427670955658, 1.0056058338710239, 0.7453487334506852, 0.34773625060915947, 0.13328007395778382, 0.058175122631447654, 0.15253042456294807, 0.08524715674242803, 0.1283031553030014, 4.751972896712167, 35.5599284853254, 54.52208702904837, 47.72291687556675, 37.900008814675466, 29.89270326069423, 28.79212597438267, 60.89365809304373, 78.01447105407715, 74.77571419307164, 71.20891203199113, 75.78102125440324, 84.88698986598423, 64.69624042510986, 6.047664284706116, 0.49638744975839344, 0.035259417457772155, 0.07275205651032073, 0.05298238912863391, 0.06741300371608563, 0.08509233540722302, 0.04651409121496337, 0.04219782818108797, 0.09293137583881617, 0.08483803405293397, 0.06187606296901192, 0.0049206558032892644, 0.11636439950338431, 0.021313907911202738, 0.008566414704546332, 0.11271972328956638, 0.020143133055950915, 0.0168066915523793, 0.018303634798420326, 0.13030205161443778, 0.039785731184695444, 0.02221021195873618, 0.021816829585337212, 0.042689976415463855, 0.053505336067506244, 0.0858651732227632, 0.044775484329355617, 0.04678382584825158, 0.07267692911305598, 0.08213103216673646, 0.007524645471546266, 0.033252480506364784, 0.04351823018597705, 0.012485366647264786, 0.028850844196443046, 0.0404950241957392, 0.03512261461998735, 0.04237335840506213, 0.02673284293684576, 0.05819530226290226, 0.04648331625919257, 0.04258982803938644, 0.04109198573444571, 0.00868916932293879, 0.03761600011161395, 0.006309612321534327, 0.03866821115038224, 0.05524865198614342, 0.03016665591193097, 0.1819142342678138, 0.16137316077947617, 0.09238968097737857, 0.12112928953553949, 0.1610525936952659, 0.1223980143134083, 0.13328869135252067, 0.14771974698773452, 0.11942596307822637, 0.06685568897851876, 0.16931919939815998, 0.17869438204382146, 0.12157896826309816, 0.14931894546108587, 0.28432237622993334, 0.13430703670850822, 0.14415525325707026, 0.15621440831039632, 0.13638954210494245, 0.09952294999467474, 0.19509884821517126, 0.13983662213597978, 0.1821178083441087, 0.10522641680602517, 0.17846558003553323, 0.11753361033541815, 0.1638911228094782, 0.1846166221158845, 0.16098136108900818, 0.14039486646652222, 0.13428965264133044, 0.15875032437699182, 0.11776045816285269, 0.13886756556374685, 0.11651565852974143, 0.1613773134137903, 0.23402129965169088, 0.12935415176408632, 0.17350761964917183, 0.14040057973137923, 0.15645412116178445, 0.1433968139546258, 0.23275792172976903, 2.8475878281252722, 31.74144172668457, 74.53946154458183, 98.28488159179688, 96.02461174556187, 86.59612165178571, 68.12275150844029, 39.36623852593558, 36.99815695626395, 62.44087600708008, 65.28439848763603, 68.61489936283657, 73.76814201899937, 33.9156060218811, 14.247375879968915, 1.2665283871548516, 0.5752609031541007, 0.1382716761103698, 0.3489978371986321, 0.5181940996221134, 0.37124903606516974, 0.5958906475986753, 0.6829794230205672, 1.4365883703742708, 2.7129818967410495, 1.6788002933774675, 3.0133460078920637, 6.771044714110238, 6.413149952888489, 6.033991098403931, 7.082620612212589, 11.391994561467852, 11.712039010865347, 16.882034642355784, 20.940819638116018, 36.48696756362915, 23.56466439792088, 21.259743690490723, 19.32282563618251, 12.055734259741646, 14.544866476740156, 28.066131285258702, 37.95041799545288, 22.811835765838623, 26.57594244820731, 15.048064572470528, 18.915986027036393, 14.656401566096715, 11.805931755474635, 11.793123619897024, 14.72577064377921, 10.033786756651741, 13.457902448517935, 16.46127084323338, 13.245039173534938, 9.145956362996783, 7.781718390328543, 9.653220023427691, 3.083301774093083, 1.3914708942174911, 1.150571420788765, 0.580525737787996, 0.3935963697731495, 0.24109318160584994, 0.22963972762227058, 0.3126666567155293, 0.4277569981557982, 0.30169414835316793, 0.3092698561293738, 6.711647604193006, 49.83821255820138, 84.94878019605363, 89.4641226359776, 62.839139802115305, 28.076022045952932, 23.25961763518197, 53.32480124064854, 74.29281439099992, 85.01881803785051, 77.278886113848, 85.97798906053815, 97.47075421469552, 65.37562138693673, 4.187681027821132, 0.7039581515959331, 0.14929416536220483, 0.1974522519324507, 0.21304107829928398, 0.0907295975568039, 0.11076869762369565, 0.1258254846824067, 0.06819885583328349, 0.2139085717499256, 0.16900729042078766, 0.11039202926414353, 0.10125928718064513, 0.25651115285498755, 0.13310702038662775, 0.0716036224205579, 0.2048615693513836, 0.1349264441856316, 0.10563376851912055, 0.10375400938625846, 0.2698003969022206, 0.13618018691028866, 0.14905542960124357, 0.10911643771188599, 0.18454659730196, 0.17142469356102602, 0.2652374931744167, 0.16499983545924934, 0.08779477075274501, 0.17477956068302902, 0.14868287316390447, 0.06963804896388735, 0.08509587736002036, 0.13659999652632646, 0.08534269447305373, 0.10293024073221854, 0.1297016702592373, 0.14121963935238974, 0.14538057893514633, 0.11079404090664216, 0.14892937136547907, 0.13814199449760572, 0.14404305070638657, 0.25408943423203056, 0.2257152982056141, 0.2574128173291683, 0.11125610968364136, 0.17344465159944125, 0.24324207486850874, 0.17912590317428112], [0.0237349971929299, 0.018407158886215517, 0.11471648221569401, 0.03568266385367938, 0.04463680873491934, 0.024218529728906493, 0.06435155549219676, 0.053045167188559256, 0.015215435331421239, 0.03173592081293464, 0.068345290475658, 0.03844392139996801, 0.014312196655997207, 0.03158793232536741, 0.03889311497498836, 0.048981431139899154, 0.01967488452126937, 0.04682905699259468, 0.027301134674676826, 0.03726019670388528, 0.024225523728611212, 0.04848971038258501, 0.011364789812692573, 0.008198261111309486, 0.03089210144909365, 0.04216676824060934, 0.010561513764384602, 0.013966107325229262, 0.008491396721053337, 0.03898721421137452, 0.04698207003197499, 0.04094954087798085, 0.04612027627549001, 0.021336269032742296, 0.04266890451045973, 0.10318202472158841, 0.03757848730310798, 0.0755181112991912, 0.028751527025763477, 0.08824826963245869, 0.2959032048072134, 0.7384570432560784, 11.804027949060712, 53.74650130953108, 70.33341121673584, 67.84820733751569, 72.66425391605922, 60.84150491441999, 39.44496161597115, 15.2947655745915, 48.34652812140328, 44.03903409412929, 60.46585055759975, 44.13685083389282, 22.442825623920985, 6.774130582809448, 0.4134001742516245, 0.09231448572661195, 0.08662270328828267, 0.19036331160792283, 0.053092145560575385, 0.14403855880456312, 0.09240117536059447, 0.07720796883638416, 0.12923448532819748, 0.10956736494387899, 0.7352648345487458, 2.2235258179051534, 3.4327924719878604, 3.2134914738791327, 1.3795292207172938, 3.276722686631339, 4.88852801493236, 11.577457615307399, 5.353480185781207, 3.0532927215099335, 10.374909434999738, 7.783927048955645, 9.321736233575002, 7.745791860989161, 8.346617358071462, 9.913282411439077, 6.796083850519998, 10.552176220076424, 5.232701820986612, 8.045526725905281, 13.5054863180433, 12.742158089365278, 9.118038501058306, 4.961030295916966, 2.439500148807253, 10.980652519634791, 17.023593766348704, 21.79361026627677, 19.417428834097727, 9.031902551651001, 9.282669986997332, 8.256508776119777, 5.15306374004909, 4.946607572691781, 3.3180001974105835, 3.717136859893799, 3.0101871831076483, 2.036133336169379, 1.3495077916554041, 0.539845663521971, 0.24255930579134397, 0.09970327067588057, 0.033069259087954245, 0.0758183291181922, 0.0717177859374455, 0.14745008360062326, 0.18074760186885083, 0.04160555192668523, 7.418067046574183, 53.18967614855085, 58.788340023585725, 58.58419500078474, 65.33794825417655, 20.93245574406215, 16.102703843797954, 50.60257693699428, 46.919131892068044, 64.84874643598283, 68.73681245531354, 69.2257502419608, 53.560699531010215, 4.373318655150277, 0.2699139565229416, 0.0668567203517471, 0.012763840811593192, 0.04379811570314424, 0.02702400740236044, 0.056447908348803005, 0.010518261397789632, 0.009594330796971917, 0.040463940506534915, 0.01808443745332105, 0.015303241155509437, 0.004760199234754379, 0.01882713643967041, 0.03174659077610288, 0.029489810445478985, 0.04124248819425702, 0.048975724660392315, 0.07951061813426868, 0.05671408745859351, 0.010107947879337838, 0.054588152428290675, 0.019099330762401223, 0.026699837297201157, 0.009227290001165653, 0.03859109903818794, 0.0031720933246625854, 0.022201138249199306, 0.11554281573210444, 0.04279490846342274, 0.025795943835484128, 0.013753595246401216, 0.03237735692943845, 0.05306879717058369, 0.014820115740544029, 0.021127470236803805, 0.02415184161093618, 0.03153043326788715, 0.033823050425520966, 0.026033761877832667, 0.0552563397879047, 0.015370794405628527, 0.06559194464768682, 0.0821165522294385, 0.07445863993572337, 0.0631214122154883, 0.017485173984563777, 0.0450930285400578, 0.06938483326562814, 0.009132564816224788, 0.03687611534925444, 0.02934819000906178, 0.07694735710642167, 0.020690892324117676, 0.009996929372261678, 0.07918547772403274, 0.021806149444143687, 0.041435952098774056, 0.023461878366236175, 0.06366749719849654, 0.08308972750923463, 0.03863575682044029, 0.07042559063328163, 0.013387023487926593, 0.029613405599125793, 0.02749160454342408, 0.009637585708073207, 0.1127845233838473, 0.01120998798536935, 0.016605013981461525, 0.06230423213647945, 0.02417683714468564, 0.013357391015493443, 0.02384436346723565, 0.05687591466786606, 0.01981053384952247, 0.03457269252144864, 0.056285473850688765, 0.05040454977591123, 0.017360520316287875, 0.025583184091374278, 0.0559959836703326, 0.014826821362865823, 0.04903859432254519, 0.05566505535638758, 0.04562058612438185, 0.03903117310255766, 0.05887657177767583, 0.19345657633883612, 0.2316264510154724, 1.2247271559068134, 21.271407978875295, 70.86886024475098, 80.94162205287388, 79.37066909245083, 84.02776868002755, 80.9489107131958, 57.78107009615217, 22.10977762086051, 37.0061855997358, 33.0218140738351, 47.50896447045462, 46.76932873044695, 29.594556059156144, 10.70077473776681, 0.9887954273394176, 0.09060315934142896, 0.07060891043926988, 0.17822327518037387, 0.04310680047741958, 0.24865651290331567, 0.46310584992170334, 1.1094462275505066, 1.500085785984993, 3.274581555809293, 5.077098650591714, 7.8647589172635755, 5.738777339458466, 5.486725790160043, 5.982903599739075, 3.67848185982023, 4.786117213112967, 0.7842887725148882, 5.458805322647095, 4.5670240095683505, 5.879755420344217, 3.2710496996130263, 6.482621082237788, 9.448228188923427, 17.489416633333477, 13.693213616098676, 12.243278299059186, 12.749256542750768, 11.794032096862793, 9.414030023983546, 13.410500969205584, 7.6116951022829324, 3.526385575532913, 2.2762554798807417, 3.564849065882819, 12.881117718560354, 17.400479691369192, 15.990533862795148, 14.865174089159284, 10.757399950708662, 6.974045889718192, 6.070494328226362, 3.9839859008789062, 3.033788476671491, 6.161081467356, 5.82375511101314, 3.7614850401878357, 2.349403726203101, 4.279024217809949, 2.61724505679948, 0.9775954740388053, 0.80182781709092, 0.11674933241946356, 0.2503488063812256, 0.03722980851307511, 0.045027095292295725, 0.18277406027274473, 0.04465265931295497, 8.560257094247, 40.04941667829241, 45.0913075038365, 41.14824301855904, 45.59384638922555, 34.50266626902989, 31.024405002593994, 73.95893955230713, 62.46413162776402, 77.15479128701347, 78.24128110068185, 75.01983220236642, 75.77071707589286, 13.083454472678048, 0.20945469502891811, 0.054798372755093236, 0.03219994716346264, 0.07464717767600502, 0.02043987507931888, 0.014147310101959323, 0.008255845833835858, 0.03354201479149716, 0.009904959039496524, 0.03829841635056904, 0.024011819124487892, 0.04458622734195419, 0.07877414301037788, 0.03735284726800663, 0.056532508094928095, 0.05301272303664258, 0.005891711509320885, 0.026466472140912498, 0.09411892747240407, 0.013285680890216358, 0.010815891453863254, 0.009627145598642528, 0.016739979685683335, 0.0553228599684579, 0.03148963634989091, 0.02230567335417228, 0.012463655223005583, 0.09481667860278062, 0.04714391759729811, 0.019249008802164878, 0.007328679469147963, 0.0548922175408474, 0.018970639810764363, 0.058523998196635924, 0.023698263003357818, 0.04341021080368331, 0.03545259637758136, 0.06830394733697176, 0.059446229067231925, 0.01743560191243887, 0.0379028881101736, 0.009213519981130958, 0.06734647335750715, 0.07156816896583353, 0.04312721759613071, 0.044999258393155675, 0.04505735456145235, 0.07658120603965861, 0.21836296415754727, 0.12765462510287762, 0.1696471218019724, 0.17863548520420278, 0.18928005759205135, 0.10157903323748282, 0.12366705121738569, 0.10391984334481613, 0.10551331498261009, 0.13833670690655708, 0.1640609058418444, 0.18855114813361848, 0.08563474951578037, 0.13737382500299386, 0.15393739406551632, 0.1357107221015862, 0.10525944789073297, 0.1587369708078248, 0.17538389111203806, 0.11654190426426274, 0.12757625430822372, 0.12421070704502718, 0.14148772853825772, 0.09640018256115061, 0.10467605705239943, 0.12051468608634812, 0.14674972689577512, 0.1303275373897382, 0.14786405781550066, 0.13049559694315704, 0.14291810749896935, 0.10305342876485415, 0.14107439214629786, 0.11914758730147566, 0.14408016657190664, 0.18025565040963037, 0.13246215427560465, 0.15398881344922952, 0.12469326757958957, 0.42505645592297825, 0.29466911245669636, 1.48273808828422, 25.178855998175486, 84.14028780800956, 98.56110027858189, 89.16990116664341, 93.5989191872733, 81.78800296783447, 55.968441418239046, 18.561511516571045, 58.70836625780378, 62.910296303885325, 85.01594843183244, 65.507143838065, 37.72706467764718, 13.944039242608206, 1.3231367724282401, 0.3504076429775783, 0.14175592628972872, 0.5426342796002115, 0.32767536278281895, 0.3147597201168537, 0.22584162785538606, 0.6054452891860689, 0.6878174319863319, 1.61835834809712, 3.7588208402906145, 7.617515955652509, 7.712344101497105, 10.555659873144966, 8.434080413409642, 11.224652409553528, 14.8393372126988, 23.18522674696786, 15.326871463230678, 11.534712297575814, 24.659123795373098, 20.90211817196437, 24.214904614857264, 22.017225878579275, 19.354212386267527, 27.520958253315516, 21.175786869866506, 23.44785475730896, 21.933599097388132, 21.679168224334717, 25.677430936268397, 28.563862017222814, 22.61162689753941, 15.358669894082205, 10.828409671783447, 21.094138588224137, 25.940347296851023, 32.05104303359985, 31.659981046404155, 19.473660605294363, 18.143122264317103, 18.897194623947144, 14.748456512178693, 15.090931483677455, 15.70517829486302, 14.661588396344866, 9.6366685458592, 5.88523885181972, 4.534275846821921, 1.794391393661499, 0.47562015269483837, 0.3521682513611657, 0.14351994091910975, 0.21630586311221123, 0.071380072273314, 0.25557200610637665, 0.45376394263335634, 0.30335832333990503, 13.097879801477704, 80.63459505353654, 78.14066423688615, 77.32010977608817, 86.48895958491734, 27.781072752816335, 22.941080944878713, 65.67606149400983, 64.03163828168596, 82.14386885506767, 82.85166794913155, 86.44480378287179, 81.98133659362793, 9.196822387831551, 0.3869889314685549, 0.1736069300345012, 0.1764185077377728, 0.2612805483596665, 0.13474292760448797, 0.12104269489645958, 0.14729309773870877, 0.14570809421794756, 0.09782511288566248, 0.10727597932730402, 0.2025099026837519, 0.1146666370332241, 0.1326672618410417, 0.13098438642919064, 0.1607779905732189, 0.19543241603033884, 0.070411049627832, 0.1719221140124968, 0.19610112586191722, 0.09284800424107484, 0.12914315451468739, 0.10453482677361794, 0.11243263512317624, 0.19201437729809964, 0.13354197490428174, 0.16763112640806607, 0.06623815425804683, 0.19900916410343988, 0.22944496093051775, 0.1395233968006713, 0.08360859645264489, 0.15600239325846943, 0.1055526225162404, 0.08030689254935298, 0.14977403889809335, 0.08120544933314834, 0.14576697748686585, 0.1237899474799633, 0.10852126072027854, 0.14769111280994757, 0.12861956975289754, 0.1400816547019141, 0.15340122926448072, 0.15377654055399553, 0.18250207629586968, 0.09912030052925859, 0.1374775730073452, 0.1936699484608003], [0.04926657530346087, 0.01175195086813931, 0.06951175324086632, 0.046423689994428835, 0.057202218765658994, 0.05211819335818291, 0.05792624955730779, 0.09402190375008754, 0.015277064970827528, 0.0771901233653937, 0.04740516375750303, 0.008656255285521703, 0.06728752223508698, 0.04674436564424208, 0.012359254128698791, 0.03273870057559439, 0.03145986223327262, 0.004952253058685788, 0.04146863713062235, 0.08856129140726157, 0.12264413253537246, 0.030698942885335003, 0.011421645110073899, 0.03767405217513442, 0.08392860713813986, 0.055236258544027805, 0.06255076426480498, 0.08384795646582331, 0.05205980541982821, 0.03893357262547527, 0.022122611391491125, 0.035488300890262635, 0.01135242181564016, 0.0033265077508985996, 0.05276778546561088, 0.016984671287770783, 0.1557219683059624, 0.03611503654558744, 0.10521915648132563, 3.150411601577486, 11.797645160130092, 32.128831590924946, 73.44949763161796, 67.82339532034737, 64.04877948760986, 52.639802660260884, 39.53961345127651, 21.09542747906276, 24.49302363395691, 60.30208846500942, 82.86926773616246, 48.26892021724156, 16.785150698253087, 7.3939394269670755, 0.6999818821038518, 0.080390216649643, 0.1380118921931301, 0.0521655890292355, 0.10659397699471031, 0.03944718970784119, 0.01458792614617518, 0.3569995292595455, 0.31047094453658375, 0.8832275920680591, 0.8179257618529456, 4.305588483810425, 2.5855716935225894, 8.468090976987567, 7.098250584942954, 4.446029382092612, 6.205505643572126, 3.5385666361876895, 7.829323972974505, 8.657632623400007, 26.296763828822545, 20.48034167289734, 17.625335557120188, 8.272411465644836, 9.973214966910225, 10.222453798566546, 16.381854670388357, 4.7955698030335565, 8.798446553094045, 6.187793816838946, 9.413059881755284, 6.6259945545877725, 16.209148509161814, 4.2569189582552225, 4.388750604220799, 6.502664029598236, 19.2591940334865, 45.87453971590315, 48.01884412765503, 51.05343859536307, 52.071773529052734, 46.08217968259539, 36.468808446611675, 37.07708501815796, 25.5765517779759, 15.749196869986397, 8.316932916641235, 8.634597608021327, 3.753031688077109, 2.511408575943538, 3.7053210139274597, 3.8249585713659013, 1.0308282290186201, 0.292116680847747, 0.2619536822395665, 0.056544609766985686, 0.181786927527615, 0.14211223859872135, 0.1945184293602194, 0.1606724105243172, 0.21416598079460009, 1.1933779695204325, 26.576651164463588, 60.976557050432476, 69.4484886441912, 51.77050658634731, 34.285350935799734, 14.082275390625, 26.733619655881608, 41.052357878003804, 58.805182456970215, 72.75205830165318, 70.47561304909843, 62.0109840120588, 8.910022463117327, 0.35687910286443575, 0.028121027197422724, 0.066406553078975, 0.11464311900947775, 0.017901543428057005, 0.04455336249832596, 0.06483098119497299, 0.03282322568286743, 0.03850359855485814, 0.12342013232409954, 0.0355229604590152, 0.03004286059045366, 0.06743347511759826, 0.0179781568170126, 0.019823729659297636, 0.08926557004451752, 0.04579922743141651, 0.014444224303588271, 0.05774220371884959, 0.04366233066788741, 0.025022917726476277, 0.02383324397461755, 0.03919989762029477, 0.014764981377603752, 0.024939607196886624, 0.11235395220241376, 0.031620695388742855, 0.0203064496495894, 0.04400111302467329, 0.05123744133327689, 0.04919378545933536, 0.0221472218566175, 0.009205054408604545, 0.03767383165125336, 0.03158731825117554, 0.06607546870197568, 0.012306743151774364, 0.02206506483655955, 0.036041469778865576, 0.041006612458399365, 0.04071895771526864, 0.018922548641317656, 0.05139759595372847, 0.017424884451819316, 0.029431344475597143, 0.03718659940308758, 0.041047114213662486, 0.033610546828380654, 0.08244220832628862, 0.03832853312737175, 0.04655136314353772, 0.06889002517397914, 0.07834868798298494, 0.02910206839442253, 0.04260192631876894, 0.02976869173081858, 0.059036739968827794, 0.048740703878658156, 0.03456597163208893, 0.04062773886003664, 0.010816144208157701, 0.026710707428199903, 0.03773273188354714, 0.06447672484708683, 0.04999075198013868, 0.09407816108848367, 0.11949349088328225, 0.08180869410612754, 0.024553157755040696, 0.135324554251773, 0.050160755536385944, 0.04129928496799298, 0.022119176307959214, 0.021851378892149245, 0.12582711316645145, 0.06482078959899289, 0.031966975557484796, 0.07777680509856769, 0.10825480680380549, 0.0499739209190011, 0.027910469299448386, 0.10143352818808385, 0.04222179064527154, 0.160854040778109, 0.06472852240715708, 0.11237177731735365, 5.848095084939684, 19.662010635648453, 51.8276937348502, 94.51304503849575, 82.89747742244175, 87.40149429866246, 72.87832791464669, 62.870455333164756, 39.63145126615252, 20.655278205871582, 32.06085041591099, 60.57411043984549, 47.38509546007429, 24.776360750198364, 10.597766825131007, 1.0780725053378513, 0.20640294307044574, 0.12188308765845639, 0.056030039342918565, 0.11075191745268446, 0.2232593542763165, 0.5282407062394279, 1.7332545199564524, 1.5708230073962892, 4.6330926929201395, 9.056592975343976, 8.852020638329641, 7.954012870788574, 8.552753908293587, 5.972694090434483, 4.895517468452454, 4.12990415096283, 3.4900397658348083, 6.8117824367114475, 11.456668393952505, 24.62124569075448, 23.96517072405134, 23.212017263684952, 13.747656226158142, 7.539948872157505, 6.502980606896537, 10.570278014455523, 12.77531315599169, 11.028911232948303, 8.211001549448286, 4.120029023715428, 1.0454686262777872, 3.917850775378091, 2.0320703770433153, 0.7030720934271812, 4.633133947849274, 21.809981959206716, 46.442523683820454, 52.93030684334891, 58.77872371673584, 57.339109080178396, 51.60117898668562, 43.876157896859304, 39.486605644226074, 29.03427938052586, 18.065000193459646, 10.256700600896563, 6.735628008842468, 6.151119921888624, 3.7789002656936646, 5.633265469755445, 4.929933633123126, 6.329997820513589, 1.9101677068642207, 0.9301020396607262, 0.8591414988040924, 0.8882776839392525, 0.49299466609954834, 0.08466964201735598, 0.2693109560225691, 0.18327389630888188, 1.5508684324366706, 23.86449827466692, 45.08391114643642, 56.1469441141401, 30.761686665671213, 29.12122392654419, 26.91795710154942, 42.95283610480172, 56.97793476922171, 81.46304961613247, 83.81709235055106, 77.52289990016392, 77.63261195591518, 20.23378484589713, 0.3256488772375243, 0.3924025824027402, 0.05640956772757428, 0.05683153847764645, 0.027581605428297604, 0.06089456206453698, 0.05142911390534469, 0.024130091170913408, 0.015081897943413683, 0.06662574703139917, 0.03393811300130827, 0.03176142015893545, 0.00586969601655645, 0.06790410700653281, 0.062477794608899524, 0.023129962783839022, 0.012895244206967098, 0.03885906269507749, 0.038727199592228444, 0.03203005895816854, 0.04086864593305758, 0.1051572198048234, 0.05118303300280656, 0.042175327959869585, 0.024306992035625235, 0.003598236428972866, 0.08489942790142127, 0.061997968570462296, 0.09392490038382155, 0.06262107406343732, 0.033949400431343486, 0.03399138817829745, 0.0015000442570973454, 0.07321410493126937, 0.042706512313868315, 0.03217704321390816, 0.03787760589537876, 0.05878237754638706, 0.07199768841798816, 0.03199094480701855, 0.04527090649519648, 0.019336919799180965, 0.032195373837436946, 0.05439166904294065, 0.029997439456305335, 0.0531713577386524, 0.030647689742701392, 0.1001940889816199, 0.13762499152549676, 0.18979955757302897, 0.11968224575476986, 0.20082256251147815, 0.14179429065968308, 0.17386132638369287, 0.19227891096046992, 0.11904001235961914, 0.15978183331234114, 0.12173272429832391, 0.14305084251931735, 0.21909979890499795, 0.06999138250414814, 0.13365576522690908, 0.05282673319535596, 0.10498546223555293, 0.14000598447663443, 0.20047739174749168, 0.17325099770511898, 0.1634876930287906, 0.2584188404892172, 0.23335834379707063, 0.11503627576998302, 0.12843449254121098, 0.15270138824624674, 0.13142205508691923, 0.2654314456241471, 0.22717481346002646, 0.15789038980645792, 0.11956603984747614, 0.1309978078518595, 0.17061087223035948, 0.10951956215181521, 0.21812034717627934, 0.10725543328693934, 0.34530617243477274, 0.17199241024042877, 0.16122015113277094, 6.929890087672642, 23.225442920412334, 63.821246828351704, 113.53184877123151, 91.32316875457764, 89.44813483101981, 75.47744056156704, 58.74311419895717, 33.77935184751238, 35.33420235770089, 84.82750633784703, 113.04136848449707, 71.05721201215471, 30.575131007603236, 13.816632730620247, 1.9498794845172336, 0.4945549709456307, 0.21186574708138192, 0.33423261663743425, 0.23645015646304401, 0.1833481823227235, 0.34708879249436514, 1.2571868598461151, 0.8293728104659489, 3.6472418904304504, 5.938488977296012, 12.395353521619525, 10.287837215832301, 19.93863926615034, 16.662084204810007, 15.16087031364441, 14.740537302834646, 12.26400477545602, 14.576636246272496, 15.637520211083547, 35.4185917036874, 27.419214044298442, 26.686078344072612, 16.178458315985544, 22.729402337755474, 27.11523383004325, 31.977041244506836, 15.716241564069476, 23.158757584435598, 19.465411356517247, 23.766417503356934, 19.573169231414795, 35.67681803022112, 15.781679698399135, 13.509850655283246, 13.74902241570609, 25.526811361312866, 56.62927416392735, 57.39557361602783, 61.404225621904644, 57.833914620535715, 55.172896998269216, 44.2625298500061, 46.819591999053955, 34.36348690305437, 23.974694967269897, 15.80089841570173, 19.97403860092163, 20.627299547195435, 13.385834864207677, 14.541158744267054, 10.484392200197492, 5.810441928250449, 0.9912073207753045, 0.6590037952576364, 0.5360423390354428, 0.41636629509074347, 0.3572995774447918, 0.44472743038620266, 0.4231140544371945, 0.4848059969288962, 2.103925172771726, 42.758519308907644, 90.76598576136998, 95.68991007123674, 67.01029627663749, 49.9515654700143, 21.51058234487261, 34.49009002958025, 55.45518841062273, 74.61506489345005, 89.81627123696464, 83.78028079441616, 90.55627523149762, 14.51116076537541, 0.24153925052710942, 0.4807915123445647, 0.15187257129166806, 0.2518228015729359, 0.06813309900462627, 0.15596966072916985, 0.24277708839092935, 0.2553570733538696, 0.13532740409885133, 0.22694523792181695, 0.2186130043119192, 0.17592788620718888, 0.17678551375865936, 0.17158067519111292, 0.1749282277056149, 0.23446381304945263, 0.1601423525384494, 0.14115072733589581, 0.15987551185701573, 0.11993367012057986, 0.0936640715226531, 0.20256033140633786, 0.16895376757851668, 0.09760274338935103, 0.22267353428261621, 0.22688715532422066, 0.18693984459553445, 0.11920971396778311, 0.2597866313798087, 0.12539245720420564, 0.10950810169535023, 0.10506204848310777, 0.07374541142157146, 0.14620860878910336, 0.09435528836080007, 0.1764358782342502, 0.12998683138617448, 0.11414419221026556, 0.1421761701681784, 0.21035230186368736, 0.15235909447073936, 0.08925085940531322, 0.13758976198732853, 0.19469206647149154, 0.12171531308974538, 0.17026213237217494, 0.09511902702174016], [0.07445133889892272, 0.0608783857896924, 0.02706864652489977, 0.015521656488999724, 0.022520217645381178, 0.020315323191295778, 0.05752896051853895, 0.024376248408641134, 0.02422720310278237, 0.059238407361720286, 0.02057619615724044, 0.0679039034460272, 0.019279307087085078, 0.11338003964296409, 0.03571721824950405, 0.051288114328469546, 0.002563517598900944, 0.04735396829034601, 0.03632403211668134, 0.0397290769033134, 0.07193072379699775, 0.08652771517102208, 0.04299697958465133, 0.054317525521452935, 0.05479480026822005, 0.03460311803168484, 0.026043699023180773, 0.05246092818145241, 0.014781987161508628, 0.06604842229613236, 0.04088231162833316, 0.05977677061621632, 0.049535868888986964, 0.0487324461074812, 0.074282811156341, 0.04548682312348059, 0.06414676683821849, 0.09771609266421624, 7.110256203583308, 36.497077192579, 60.07577174050467, 72.20023931775773, 66.28206253051758, 51.889233929770334, 23.129309381757462, 22.33628715787615, 27.695114850997925, 41.88250780105591, 52.18964276994978, 39.21766172136579, 23.237117631094797, 8.161897761481148, 1.9363352741513933, 0.05420631702457156, 0.06795856622712952, 0.05104758044970887, 0.06065173473741327, 0.0639240105769464, 0.0766279571024435, 0.08053002200488533, 0.20532844215631485, 1.092696183494159, 2.8372128648417334, 3.7490012986319403, 9.64325543812343, 8.311914580208914, 9.768623522349767, 6.2007578526224405, 2.1691372735159735, 2.4138730210917334, 4.898546014513288, 10.405706456729344, 27.956551245280675, 40.281086989811485, 52.82946416309902, 52.486580984933035, 51.67117861339024, 36.48507417951311, 23.60577515193394, 9.94430090699877, 18.402988365718297, 18.669260706220353, 10.874730706214905, 9.947854910578046, 2.644787064620427, 4.943121748311179, 9.344144174030848, 12.682028378759112, 8.040749839373998, 20.337130614689418, 64.49641023363385, 77.24763311658586, 91.22795064108712, 93.11380290985107, 98.81158978598458, 94.74176583971295, 91.84919602530343, 86.47586917877197, 76.88772337777274, 59.72193472726004, 50.83519915172032, 36.069016047886436, 17.954963309424265, 7.603420666285923, 5.695592548166003, 4.443864149706704, 5.410098016262054, 2.5759184743676866, 1.0188869897808348, 0.7816844465477126, 0.205795749223658, 0.03354096645489335, 0.11381956748664379, 0.06095700764230319, 0.0784871226974896, 0.05295667604410222, 0.20659625769725867, 7.088303804397583, 34.39163752964565, 77.05597400665283, 74.87307235172817, 47.106688090733115, 38.625084604535786, 79.46096788133893, 42.02143703188215, 45.863054343632285, 59.00459575653076, 71.02199159349713, 79.49746676853725, 24.72078905786787, 0.18997657378869398, 0.42079460461224827, 0.060476828765656264, 0.015823331461953263, 0.02504988949346755, 0.053442720855985365, 0.01601306681654283, 0.017572905169799924, 0.0281833659059235, 0.0264460380588259, 0.06949440310043947, 0.03989898207198296, 0.04942377829658134, 0.04490592929401568, 0.039478683910731754, 0.05750184625919376, 0.048267100006341934, 0.0936485602121268, 0.06994551353688751, 0.0208958862349391, 0.011613979253784885, 0.045613183307328393, 0.00511827743113307, 0.053791413216718605, 0.03938692222748484, 0.024795472788225328, 0.04010045947507024, 0.06588350435984985, 0.016292256835315908, 0.030417537449726036, 0.03049895486661366, 0.07731470918016774, 0.028509676789066622, 0.026608167216181755, 0.05637708625623158, 0.0701589806537543, 0.07213485427200794, 0.01581756052161966, 0.04332089523917862, 0.009822545872469033, 0.03264105938641088, 0.026359365388218845, 0.04208434659189411, 0.046824263142687936, 0.02937302439074431, 0.05339052454967584, 0.05240828404203057, 0.03279436080317412, 0.03493316425010562, 0.04614574508741498, 0.061460161714681556, 0.05917490326932498, 0.11194366243268762, 0.034672728939247985, 0.013697973186416286, 0.03639684231685741, 0.025907240541917936, 0.01357776137800621, 0.03532228372724993, 0.08350519450115305, 0.10171001085213252, 0.0678114869764873, 0.05539212482316153, 0.04156330294374909, 0.11620784790388175, 0.03485831165952342, 0.026913923577272465, 0.025969938873978596, 0.11210495699197054, 0.08220311294176749, 0.041490726838154454, 0.04928987280332616, 0.011187876225449145, 0.08478724570678813, 0.05002476354794843, 0.03045996285176703, 0.10431568031864506, 0.03756121519420828, 0.038843154441565275, 0.0612103794036167, 0.11478052235075406, 0.023080378837351288, 0.09839925529169184, 0.11582489631005696, 11.700732554708209, 47.16954844338553, 75.27208655221122, 84.41303934369768, 81.88549314226422, 65.9886748450143, 43.41014221736363, 41.31807088851929, 27.255715983254568, 30.817122868129186, 45.359476702553884, 42.99940293175833, 28.543793882642472, 13.351982372147695, 2.3502707311085294, 0.04185581599761333, 0.12301590187208992, 0.06427247223577329, 0.18136911280453205, 0.35244349230613026, 0.7251689391476768, 0.9313089634690965, 2.0363257144178664, 3.7650911552565436, 5.017942122050694, 8.160914591380529, 11.136755960328237, 10.651736957686287, 7.197572043963841, 5.645382259573255, 1.137684466583388, 1.2257418100322997, 2.6027847698756625, 11.347702401024954, 28.466542073658534, 45.044629505702424, 58.62389005933489, 58.435058866228374, 52.79241289411272, 41.022105421338765, 26.321912833622523, 11.779193350246974, 6.745545693806239, 4.847273954323359, 3.2959038402353014, 0.9514073878526688, 0.8760691561869213, 2.566099149840219, 5.082450934818812, 9.613333020891462, 8.878369075911385, 25.129240649087087, 67.66306563786098, 84.40612588609967, 95.96905394962856, 96.74955899374825, 102.9827948978969, 100.6455112184797, 96.58549118041992, 92.02102497645787, 82.54402256011963, 67.01357582637242, 53.96346575873238, 37.42324774605887, 20.580736194338115, 9.894113200051443, 6.383211033684867, 4.964881334986005, 6.48229364837919, 6.206685968807765, 4.172320297786167, 2.1234368000711714, 1.2585136400801795, 0.7482136168650219, 0.3619774521461555, 0.2245173446301903, 0.12014256391142096, 0.050634098172719987, 0.16981210080640657, 7.882775596209934, 32.80597870690482, 61.849500928606304, 53.394967624119346, 36.474467754364014, 33.83311006001064, 75.66537543705532, 55.523423194885254, 61.33853040422712, 71.99995749337333, 81.02051884787423, 97.99895627158028, 44.82336759567261, 2.1818978573594774, 0.4265158218996865, 0.005482931480011237, 0.018319498947156326, 0.0841688085347414, 0.053082469651209455, 0.07148428846682821, 0.053648133762180805, 0.014121241634711623, 0.0069133108648072395, 0.10057475391243186, 0.06546110952539103, 0.05971176017607961, 0.02519690428328301, 0.03911792041201677, 0.05055093692083444, 0.03919232516948666, 0.05015017378277012, 0.09476138478411095, 0.057186130700366836, 0.03428206579493625, 0.0929066568080868, 0.031146172101476362, 0.07868020662239619, 0.02926498804507511, 0.0027539155853446573, 0.06645270024559327, 0.02635693284017699, 0.022291391888367276, 0.023876336037314365, 0.031740426285458465, 0.09579135344496795, 0.04541882373658674, 0.009371136032444025, 0.019246544023709636, 0.08007455537361757, 0.04050615217004504, 0.043329343000160794, 0.03614581489403333, 0.06358090934476682, 0.07027317131204264, 0.02424097397098584, 0.07241810871554272, 0.049174871295690536, 0.02775710172552083, 0.05755984064723764, 0.19029197043606214, 0.16902235389820167, 0.22828102910092898, 0.2143632173538208, 0.07188042399606534, 0.09211523391838584, 0.17573937560830796, 0.13857698972736085, 0.14620669532035077, 0.14050177644406045, 0.14756580096270355, 0.1546437625906297, 0.13562309608927794, 0.21194502711296082, 0.13596381566354207, 0.15560954862407275, 0.13501679790871485, 0.08603182142334324, 0.2015747864331518, 0.11905951345605509, 0.21016119926103524, 0.187479062804154, 0.21598155051469803, 0.20375444447355612, 0.16341139855129377, 0.15986447887761251, 0.11315811797976494, 0.15211060137620994, 0.1867264181907688, 0.10653883923909493, 0.20441468618810177, 0.12579584627279214, 0.11294360591896943, 0.14807296517704213, 0.2567592795406069, 0.11824879981577396, 0.15212896253381455, 0.39414630883506363, 15.148552894592285, 60.10521820613316, 98.5825424194336, 99.63330459594727, 88.5109965460641, 71.79029560089111, 34.16048485892159, 34.8157034601484, 39.932780742645264, 57.822328499385286, 73.6596736907959, 60.39932155609131, 39.15399537767683, 17.327785900660924, 4.45758901323591, 0.3236962705850601, 0.19608553312718868, 0.16849197021552495, 0.3648762623114245, 0.4509600188050951, 0.5749175644346646, 0.8272823797804969, 1.4417100612606322, 2.773263599191393, 7.4420895746776035, 14.645815985543386, 23.193370035716466, 19.017738921301707, 21.757387569972447, 16.29991282735552, 8.835490005356924, 6.778808457510812, 12.548171332904271, 16.97730139323643, 35.70347132001604, 46.07564490182059, 62.40152835845947, 58.121250425066265, 59.64803368704659, 42.824238845280235, 34.49454035077776, 21.987906217575073, 37.13220855167934, 31.066768169403076, 23.39247066634042, 22.026866504124232, 14.53928620474679, 11.355489594595772, 16.132139887128556, 18.90228417941502, 11.343590804508754, 30.366775376456125, 70.75806427001953, 89.83790097917829, 98.27091571262905, 100.64278057643345, 108.53355094364711, 103.85458537510463, 99.31013693128313, 94.4119348526001, 81.96516118730817, 69.3720932006836, 59.218086106436594, 45.88934632710048, 26.701595408575876, 18.154882090432302, 18.54763422693525, 14.966258219310216, 16.57334702355521, 9.200902717454092, 3.637096651962825, 2.5169773399829865, 1.1016289613076617, 0.35674988265548435, 0.43483390126909527, 0.24563681493912423, 0.3647427266197545, 0.22083953555141175, 0.4609088620969227, 11.158917239734105, 52.44243213108608, 112.90992941175188, 93.57531615665981, 61.81780324663435, 52.28818907056536, 89.09783445085797, 48.240807805742534, 59.16333430153983, 75.62490218026298, 88.74304553440639, 110.35469463893345, 40.51368835994175, 1.0017035518373762, 0.5541476075138364, 0.09833914387438979, 0.11899342414523874, 0.25267341307231356, 0.2635262007159846, 0.1278148272207805, 0.1495095866599253, 0.21579014935663768, 0.1266016201781375, 0.1462918378944908, 0.13340090747390473, 0.12942900774734362, 0.09871337629322495, 0.15411208969141754, 0.15447868859129293, 0.1092127218310322, 0.17605718784034252, 0.29970479224409374, 0.12171839363873005, 0.14483195623116835, 0.15577284486166068, 0.12994894199073315, 0.15564399106161936, 0.10763187094458512, 0.09462704842111894, 0.1324599286807435, 0.20291844861848013, 0.15457129505063805, 0.12011528680367128, 0.21206562992717537, 0.19331177696585655, 0.09536142687180213, 0.09728780814579555, 0.09164262749254704, 0.11408545821905136, 0.15847308853907244, 0.13114563349102223, 0.1480005926319531, 0.14898860747260706, 0.14478088968566485, 0.11969280375966004, 0.22625941543706826, 0.15292170856680187, 0.08046457730233669, 0.15341266936489514], [0.0886074114324791, 0.03286896233579942, 0.03725314672504153, 0.038884460260825496, 0.2416919751891068, 0.021708414956395115, 0.12147242469446999, 0.055011409002223184, 0.06753805093467236, 0.03561795196895089, 0.10321458083178316, 0.01728616644894438, 0.039583785592445304, 0.05951961941484894, 0.10378429240414075, 0.12335487082600594, 0.06631381091262613, 0.0641710583918861, 0.04164903923603041, 0.05940899785075869, 0.016117676560367857, 0.1524535058332341, 0.16215737084192888, 0.08589892355459076, 0.07538687584123441, 0.04225606684173856, 0.15365424140223435, 0.12997062796992914, 0.0491235808336309, 0.02812381597634937, 0.04166195515011038, 0.06905668015990939, 0.04598876601085067, 0.2069212081176894, 0.06019897546086993, 0.07527366227337293, 0.3933820612728596, 12.219359993934631, 79.87186350141252, 23.456786666597637, 36.40863357271467, 67.31545421055385, 35.19987978254046, 35.10970606122698, 53.740967069353374, 46.24845354897635, 41.16636392048427, 54.84355933325631, 24.15376741545541, 18.484099899019512, 4.082383683749607, 0.35550439091665403, 0.08052216456936938, 0.0894677938361253, 0.15339595026203565, 0.16640624856310232, 0.10466644899653536, 0.3560659464980875, 0.15133582295051642, 0.627681587423597, 1.5892646121127265, 3.9378051332065036, 4.640086489064353, 9.01296784196581, 15.165638514927455, 7.826641968318394, 2.4325159064361026, 2.3058934552328925, 5.2906376378876825, 11.7327698298863, 25.255428620747157, 53.88165766852242, 66.30355330875942, 78.02173886980329, 82.43709673200334, 88.60651343209403, 76.60436889103481, 72.3396132332938, 50.890465123312815, 35.43347474506923, 17.69527265003749, 9.770678452083043, 5.816821677344186, 7.461755582264491, 19.146971940994263, 53.43243925912039, 76.91398756844657, 96.30676419394356, 91.89447743552071, 53.60333367756435, 88.3571286882673, 103.22808715275356, 111.47781535557338, 105.68604714529855, 99.57308455875942, 97.22120966230119, 96.54601846422467, 99.15394142695835, 102.46782221112932, 95.52409826006208, 88.68030330113002, 73.99702262878418, 56.50656202861241, 41.60287407466343, 25.87063775743757, 11.340850608689443, 11.070737651416234, 6.213732310703822, 3.1612099707126617, 2.2695287551198686, 3.492988190480641, 1.7172151463372367, 0.3076317368873528, 0.7212985211185047, 0.11062819337738411, 0.19785960364554608, 0.025354395653786402, 0.12307793354349476, 0.789142903472696, 14.38828100476946, 47.70782191412789, 68.0202169418335, 83.83737414223808, 154.42824390956332, 48.922526836395264, 9.806392192840576, 49.347110407693044, 69.81603445325578, 61.256819588797434, 79.64032173156738, 45.4491605758667, 6.983936216150012, 0.46694190693753107, 0.08386381382920913, 0.012430165278991418, 0.09718811099550553, 0.0950773378301944, 0.060319069373820505, 0.06483957144830908, 0.05405561778960483, 0.08611918280699424, 0.05726156343838998, 0.025511335714587142, 0.06787909620574542, 0.04515826628942575, 0.02783213073520788, 0.05586228852293321, 0.04042441923437374, 0.09678561080779348, 0.1281448530831507, 0.11937527651233332, 0.11902390393827643, 0.20315881286348614, 0.0666633921542338, 0.11501579758312021, 0.03936826251447201, 0.07807497374181237, 0.036147633367883306, 0.06762136146426201, 0.007974185947594898, 0.01640411842215274, 0.04999207512342504, 0.14829777739942074, 0.10258384181984834, 0.10156016996396439, 0.07838398537465505, 0.013915045020569648, 0.08265418945146458, 0.03003162405054484, 0.06843925400504045, 0.0772428387509925, 0.08161779506398098, 0.179442344765578, 0.1807578613183328, 0.03330566068845136, 0.009448465275844293, 0.025837025738188198, 0.018976889118286114, 0.09627133554645947, 0.03458298250500645, 0.14704203978180885, 0.06484598360423531, 0.07557488432420151, 0.09200416452118329, 0.07158447416233164, 0.014177085066746389, 0.03161362844652363, 0.03362425323575735, 0.02540148259140551, 0.03226951735892466, 0.11798608462725367, 0.07741821969726256, 0.07081081531941891, 0.06702549915228571, 0.004656738335532802, 0.04929337743669748, 0.030728459158646207, 0.06944107024797372, 0.0912899182045034, 0.12270555352526051, 0.08304515454385962, 0.015151122086016195, 0.08612728451511689, 0.12160302911485944, 0.08994375901030642, 0.09599372651427984, 0.020336432415725927, 0.033764903367097886, 0.031559057267648835, 0.15498988330364227, 0.0721404996833631, 0.1208959413426263, 0.4625510254076549, 18.452695778438024, 102.92590304783413, 30.637095042637416, 42.998308590480256, 85.05461515699113, 58.932007925851, 60.044657707214355, 49.79263237544468, 37.92414338248116, 41.72823347364153, 47.23091493334089, 31.649860995156423, 21.98445643697466, 5.582212277821132, 0.14203458705118724, 0.1158710638327258, 0.13600908751998628, 0.05097123168941055, 0.6501025014689991, 0.7422793667231287, 1.5292975327798297, 1.6257219186850955, 2.354480036667415, 3.8943658641406467, 5.963417376790728, 6.399780316012246, 5.682138664381845, 4.3607189655303955, 1.7337545731237956, 1.3438883274793625, 1.2319196271044868, 5.900142303534916, 12.655582666397095, 28.4008138520377, 55.86802952630179, 72.4731992994036, 83.41766820635114, 86.56127643585205, 93.86445154462541, 82.8750833783831, 76.9746800831386, 56.53149216515677, 38.858926228114534, 18.60959131377084, 9.93468633719853, 3.8382391844476973, 7.15228933095932, 20.256194523402623, 54.9580899647304, 81.39820207868303, 100.8895458493914, 96.06373705182756, 56.59930658340454, 92.47875840323312, 108.57311398642403, 113.38073240007672, 107.17204448154995, 101.44428307669503, 102.19334752219063, 102.42143603733608, 105.55870056152344, 106.36534472874233, 102.43545055389404, 93.89571149008614, 80.22032955714634, 60.482866695949006, 46.16536351612636, 27.35439256259373, 11.321408680507115, 6.9636635439736505, 4.7586153745651245, 1.8534727948052543, 2.800785413810185, 3.764187455177307, 2.130767583847046, 0.7751809869493756, 0.9822157004049846, 0.1192889397165605, 0.15894946083426476, 0.00876851805618831, 0.12616108810263021, 1.494146704673767, 15.026766606739589, 41.84894452776228, 49.66788094384329, 65.99903460911342, 142.9307539803641, 53.75410958698818, 24.531594821384974, 68.94993455069405, 76.59133407047817, 63.60492161342076, 91.41382884979248, 70.30638967241559, 17.128435134887695, 0.3439831919968128, 0.1434768403747252, 0.08077394855873925, 0.09683967647807938, 0.051714193608079634, 0.030971798779708997, 0.07618832069316081, 0.04785433019112263, 0.14355062427265303, 0.08195443664278303, 0.028009515056120496, 0.054403448410864384, 0.0688451129410948, 0.09703332358705145, 0.03906243321086679, 0.08263030501880816, 0.07760484396879162, 0.10509370214172772, 0.09289293683000974, 0.05684673087671399, 0.07428649560149227, 0.13457721578223364, 0.057385626781199656, 0.027041366024475013, 0.03367005095684102, 0.03497918249507036, 0.028602439311466048, 0.03654489865792649, 0.04127127504242318, 0.05764337509338345, 0.08431910404137202, 0.06211350951343775, 0.08047990540840796, 0.05026837458301868, 0.08239163032599858, 0.07015410877232041, 0.041818594959165366, 0.0241809507632362, 0.022091872058808804, 0.06125411098556859, 0.13346289843320847, 0.14293458232922213, 0.020985520710902553, 0.016609251432652985, 0.15183648679937634, 0.08669584257794277, 0.2455922487590994, 0.10476164745965175, 0.3147320087466921, 0.0782775707276804, 0.25754171184131075, 0.21858693499650272, 0.1441573974277292, 0.17160705663263798, 0.11185783453817878, 0.09669464640319347, 0.20634495546775206, 0.2408469548182828, 0.21397495961615018, 0.2968315764197281, 0.18192937916943006, 0.16278412006795406, 0.10397652137492384, 0.159406182755317, 0.11513492119099412, 0.18432491991136754, 0.17791288612144335, 0.19774936884641647, 0.2904072068631649, 0.09623378541852746, 0.29166754494820324, 0.26944090904934065, 0.1728482600301504, 0.16318669489451818, 0.17327410860785417, 0.1334933646555458, 0.09603228087403945, 0.4078780934214592, 0.11873541798974786, 0.15231631962316378, 0.668104958321367, 24.722305502210343, 122.70643779209682, 42.38662392752511, 55.50330468586513, 95.39928082057408, 59.54801436832973, 52.63111393792288, 63.39918545314244, 61.91928168705532, 62.734333174569265, 78.65872887202671, 40.93544054031372, 33.12601620810372, 8.225829005241394, 1.114432754261153, 0.21063256396778993, 0.32234422170690125, 0.3325589693018368, 0.6680794454046658, 0.7656996271439961, 1.4248264815126146, 1.1597935259342194, 2.89003415618624, 6.512061468192509, 11.01670411654881, 12.985609071595327, 21.071338074547903, 28.87774167742048, 22.888337169374736, 14.724153450557164, 12.186085939407349, 13.14500161579677, 18.89336790357317, 31.810148988451274, 62.54340362548828, 75.53717422485352, 89.40115806034633, 91.57785497392926, 100.08480548858643, 82.54025663648332, 80.00286483764648, 60.18797819955008, 46.55360800879342, 30.531485898154124, 28.68539122172764, 17.52704633985247, 15.178285973412649, 23.310494082314626, 57.04009335381644, 79.12155532836914, 98.62498201642717, 101.48763983590263, 69.64422634669712, 94.09142139979771, 112.92183862413678, 116.95277350289481, 112.94633797236851, 106.79718916756767, 107.44774900163922, 108.08033384595598, 112.92437471662248, 113.68855149405343, 107.07021168300084, 98.0993994304112, 80.99674906049455, 63.82990428379604, 52.97702305657523, 34.17421102523804, 22.572965383529663, 22.407961300441197, 15.625623158046178, 8.065427235194615, 7.418560368674142, 7.253760823181697, 4.18989793743406, 0.9704463205167225, 1.7485422939062119, 0.17710956851286547, 0.43983348299350056, 0.11285278400672333, 0.30164238970194546, 2.012995400599071, 24.434696980885096, 69.40010833740234, 93.84767859322685, 100.5196932383946, 154.98530878339494, 57.654272420065745, 15.529138735362462, 62.37024062020438, 82.83344977242606, 73.48257105691093, 101.6678135735648, 73.74276024954659, 12.155679753848485, 0.3671766317316464, 0.2185042622898306, 0.17508475216371672, 0.39352018386125565, 0.17105223211858953, 0.15759077588362352, 0.27745486902339117, 0.18376305220382555, 0.1582554687878915, 0.16449524967798165, 0.16368079052439757, 0.09096823832286255, 0.1534622838454587, 0.20895992086402007, 0.10625004794980798, 0.1603055673518351, 0.19903231571827615, 0.21858405800802366, 0.1515047645994595, 0.35493930695312365, 0.24459835780518396, 0.13909176710460866, 0.2037788445928267, 0.09236333346260445, 0.17361337611717836, 0.1222858117627246, 0.1665167954883405, 0.06772451914314713, 0.07305226754397154, 0.2089893285717283, 0.2705762881253447, 0.22606462160391466, 0.21613922848233155, 0.20709369171942982, 0.27741160563060213, 0.1412918083369732, 0.11634675759289946, 0.10992041349943195, 0.17131122893520764, 0.18901313548641546, 0.18356744412864956, 0.34736731754881994, 0.19667136669158936, 0.1384797149470874], [0.1426376961171627, 0.27732469886541367, 0.15326768000211033, 0.48535067055906567, 0.18113870945359978, 0.16111985008631433, 0.12691008219761507, 0.12312011128025395, 0.12669276100184235, 0.09608412094946418, 0.046440829788999896, 0.10535126724945647, 0.08635479052151952, 0.019849061067881327, 0.11534156224557332, 0.015804982178711464, 0.11316507974905626, 0.0911542654835752, 0.0720373827165791, 0.28059472196868485, 0.24349519557186536, 0.6399087341768401, 0.7382319324782917, 0.27778070153934614, 0.19408977164753846, 0.07733965212745325, 0.24372516466038568, 0.05197184353268572, 0.0615008534597499, 0.019946400308981538, 0.04786813837875213, 0.03608124889433384, 0.09906310681253672, 0.01939925511500665, 0.011709415204157787, 2.1303063971655707, 23.730946949550084, 65.23026507241386, 79.11646924700055, 69.68714536939348, 36.73313181740897, 38.66023901530674, 16.103105102266582, 17.610949311937603, 46.770016602107454, 58.71086066109793, 34.87745557512556, 25.88526545252119, 8.680637240409851, 1.0008807331323624, 0.22859937059027807, 0.04596765339374542, 0.13438384687261923, 0.10802056294466768, 0.1387441400438547, 0.1984059600425618, 0.6646987125277519, 1.1529846170118876, 1.6066381484270096, 2.067248237984521, 4.880975757326398, 7.1243506244250705, 3.8981752140181403, 2.517667382955551, 4.731168253081186, 8.665235689708165, 16.244580847876414, 34.816113403865266, 60.009103775024414, 78.37173352922711, 83.88245405469621, 84.72815404619489, 87.8327133996146, 85.07668958391461, 87.06750134059361, 97.94897093091691, 94.83520521436418, 86.01317473820278, 81.5461848122733, 78.77176911490304, 53.03796918051583, 28.981888226100377, 25.636014461517334, 60.80249077933175, 116.55253641945976, 114.70793560573033, 126.05091149466378, 112.22619192940849, 133.88294873918807, 50.147021770477295, 91.3430267061506, 101.13552597590855, 91.9352981022426, 88.8311903817313, 86.55449499402727, 84.72654206412179, 86.9473044531686, 85.92710045405796, 87.42658424377441, 88.69626331329346, 92.29404054369245, 91.80393545968192, 86.91819150107247, 75.15061814444405, 54.13544062205723, 38.116212436131065, 25.98756899152483, 14.201570749282837, 7.929777554103306, 2.719038120337895, 3.54332007254873, 2.257354642663683, 2.2153966426849365, 1.6039483270474841, 0.25378903320857454, 0.22782168803470476, 0.03443253772067172, 0.2519835058067526, 0.13514903081314905, 0.5852456273777145, 8.183178356715612, 36.406698499407085, 42.54092257363455, 25.683628729411534, 39.00131218773978, 24.672653675079346, 13.401431832994733, 42.73588555199759, 67.00486973353794, 68.36311054229736, 67.52460888453892, 59.79819120679583, 17.170869520732335, 0.5373175506080899, 0.13768323697149754, 0.027547420834058096, 0.023234698056642498, 0.04038335768772023, 0.04315960067989571, 0.014206393538708133, 0.17165652183549746, 0.04275666283709662, 0.05197637614661029, 0.037975437074367485, 0.02374102428023304, 0.0685563487932086, 0.04411919508129358, 0.16790354464735302, 0.012704590285596038, 0.2944798283278942, 0.19050093208040508, 0.298178495573146, 0.4168641226632254, 0.29279855425868717, 0.1839546976344926, 0.10033413860946894, 0.021571381416703974, 0.057012914280806265, 0.08093366213142872, 0.05555382311078055, 0.021908659122085998, 0.11738511973193713, 0.16017387727541582, 0.12495041878095695, 0.09728821526680674, 0.1519360143159117, 0.029947441603456224, 0.09461593401751348, 0.03856133509959493, 0.07777133610631738, 0.2830866282539708, 0.22661164296524866, 0.4369247119341578, 0.36021980217524935, 0.2291382359606879, 0.22878181508609227, 0.1734037630792175, 0.30264659438814434, 0.11025993885206324, 0.38648486137390137, 0.23573210356490953, 0.16762607810752733, 0.16361684538424015, 0.06870155528719936, 0.14520563903663838, 0.10466980774487768, 0.10333175704415355, 0.05994740181735583, 0.11229896372450249, 0.05265222416658487, 0.04839910560154489, 0.033857950874205144, 0.09327628875949553, 0.0676747825262802, 0.019295719152848636, 0.17151907778212003, 0.23596220836043358, 0.4287432080933026, 0.49032471222536905, 0.27393517217465807, 0.1522266308643988, 0.09393207249896866, 0.16882766863065107, 0.07829965025718723, 0.08182168126638446, 0.016386856491278325, 0.08112219987171036, 0.058686317343797, 0.05791768644537244, 0.06239582079329661, 0.01299324247520417, 2.0052672667162756, 33.765618732997346, 87.34999425070626, 90.34622423989433, 82.74674320220947, 43.494100775037495, 57.949893951416016, 26.990763800484793, 24.992894411087036, 54.48615442003523, 49.36458512714931, 37.89496789659773, 31.29985591343471, 12.290226408413478, 1.4140067249536514, 0.1338075670812811, 0.04220269666984677, 0.1219246004308973, 0.05410049270306315, 0.43060828372836113, 0.9979976649795259, 1.7006293620382036, 3.8864740133285522, 4.684620099408286, 5.139411398342677, 6.131178157670157, 4.914360114506312, 1.5465683660336902, 1.5102334128958839, 2.478552064725331, 8.204650895936147, 19.18582626751491, 39.37663997922625, 65.50656713758195, 82.65417235238212, 90.76007284436906, 88.61382988521031, 93.35047939845494, 88.03198773520333, 93.43569210597447, 101.76893765585763, 96.68922778538295, 90.91920743669782, 88.15137168339321, 82.72114603860038, 58.40387535095215, 30.152051721300396, 30.497283390590123, 67.1905950818743, 124.91809109279087, 126.61628641401018, 138.73352786472864, 123.28598703656877, 142.1837114606585, 58.83018207550049, 89.98571000780377, 109.08935124533517, 98.35006959097726, 94.22267287118095, 89.49729333605084, 85.44996765681675, 87.84092617034912, 88.04167352403913, 91.67701966421944, 92.5291884286063, 98.02635301862443, 94.93800381251744, 91.63829735347203, 77.44136278969901, 58.47273894718715, 43.023975236075266, 27.416985409600393, 9.585122466087341, 3.01626946244921, 1.260039963892528, 4.640114716121128, 3.1157476902008057, 3.9885013614382063, 4.139533919947488, 0.7581903072340148, 0.7388504850012916, 0.08544792846909591, 0.19825757800468377, 0.14642966192747864, 0.06560585461556911, 7.901929174150739, 32.59683098111834, 44.76652785709926, 34.65794808523995, 35.53589814049857, 22.17864121709551, 25.8152745110648, 69.43594714573452, 88.71479415893555, 76.54884583609444, 75.73910972050258, 78.46565927777971, 35.114152908325195, 2.508055635860988, 0.17909379489719868, 0.10046289062925748, 0.01746800365591688, 0.02731793520173856, 0.08193422308457748, 0.015097546657281262, 0.1171503873275859, 0.05906168291611331, 0.07331486738153867, 0.039370654350412745, 0.06228661058204515, 0.05672069978235023, 0.02272667719184288, 0.15178250255329268, 0.105690473690629, 0.2832991454218115, 0.16121637847806725, 0.04394019075802394, 0.1958271741334881, 0.1677295004150697, 0.05993244690554483, 0.06268263754567929, 0.05187508783170155, 0.04905047547072172, 0.028313956755612577, 0.016136064859373227, 0.028414700546168854, 0.10295322949865035, 0.20788725199443953, 0.1379750206002167, 0.1396140762205635, 0.07065024000725575, 0.09963220770337752, 0.026692481977599006, 0.08357185378138508, 0.07792767057461397, 0.25885774408067974, 0.1049716676186238, 0.20155844730990274, 0.3158827769969191, 0.1127658975975854, 0.13452358437435968, 0.18256701209715434, 0.5079339444637299, 0.2921897997813565, 0.6217525484306472, 0.2676087016505854, 0.3660695068538189, 0.19355853301073822, 0.20024949897612843, 0.2537678900573935, 0.21339900552162103, 0.12945927040917532, 0.17784558901829378, 0.24078613093921117, 0.11947208988879408, 0.15678406559995242, 0.08641390449234418, 0.27631221605198725, 0.13552229292690754, 0.19778860174119473, 0.3310549828623022, 0.4134899580052921, 1.0732341706752777, 0.9100508955972535, 0.3757154249719211, 0.28795506272997173, 0.17954067806048052, 0.3858830822365624, 0.13180484383233956, 0.21858602575957775, 0.11907484834747654, 0.13459016223038944, 0.18176457658410072, 0.17222360069198267, 0.1874174925365618, 0.13525670074990817, 3.389116312776293, 45.761079107012065, 110.51766463688442, 106.24539797646659, 93.55910600934709, 57.528926917484824, 59.50788852146694, 26.9239273411887, 30.102309567587717, 67.04847662789481, 80.65232685634068, 53.38382271357945, 42.09391369138445, 17.638542345591954, 1.9438276035445077, 0.3829506167343685, 0.21616964042186737, 0.6622326991387776, 0.32543052466852324, 0.709900652723653, 1.347164403115, 2.4128379566328864, 4.939889967441559, 7.454629336084638, 9.56109298978533, 15.580352170126778, 16.975451435361588, 15.503539834703718, 13.53518899849483, 16.799226011548722, 19.640089069093975, 24.991527353014263, 43.853030817849294, 67.55267265864781, 85.35412420545305, 91.3445622580392, 90.32924284253801, 96.05323832375663, 91.10316099439348, 95.20992851257324, 108.16288539341518, 100.16949013301304, 94.12058298928397, 93.47592912401471, 86.68396077837262, 60.80365807669503, 36.55238832746233, 35.55820185797555, 73.1757733481271, 125.43770517621721, 124.00035912649972, 134.98097256251742, 122.41849054609025, 135.36041368756975, 67.27564798082624, 93.51781286512102, 114.18691103799003, 103.16297558375767, 97.81628118242536, 94.34270300183977, 89.86122608184814, 91.77963760920933, 93.02120426722935, 96.37263311658586, 97.00334194728306, 102.11219256264823, 99.9210364477975, 95.5600482395717, 82.0111721583775, 66.49665764399937, 47.290513106754844, 33.90237317766462, 24.67787872041975, 17.43779672895159, 7.145394112382617, 8.535795092582703, 7.58822843006679, 5.895232966967991, 5.574667402676173, 0.9689088144472667, 0.7766873346907752, 0.0821371932647058, 0.6489967608026096, 0.27749851239579065, 1.560083046555519, 13.617857796805245, 53.15483093261719, 59.22220638820103, 37.971335547310964, 50.961965560913086, 32.96154539925711, 20.435689074652537, 56.90987021582467, 89.18228285653251, 78.59529876708984, 86.60826710292271, 94.99511800493512, 30.278731278010778, 1.5432540753058024, 0.40752688369580675, 0.16629462955253466, 0.16800186437155518, 0.1961314156651497, 0.11805511878005095, 0.143439683797104, 0.21812770249588148, 0.11948275645928723, 0.2895601780286857, 0.1304290055164269, 0.14028677583805152, 0.1683449045355831, 0.13132929934987, 0.35995346360972946, 0.19823244506759302, 0.4091972740633147, 0.4960487793598856, 0.5915330414261136, 0.593555075781686, 0.47031379171780174, 0.2582843005657196, 0.21921742973583086, 0.1637543844325202, 0.16351255455187388, 0.16376315110496112, 0.11480098696691649, 0.09345052298158407, 0.2229931242763996, 0.29340967003788265, 0.35406711804015295, 0.2516878545284271, 0.3172545033906187, 0.2204368928713458, 0.22370766236313752, 0.15281946691019194, 0.2957144635064261, 0.42956453402127537, 0.37096312854971203, 0.5496536429439272, 0.4052454046905041, 0.22543118202260562, 0.2987749007131372], [0.12778624732579502, 0.18875177736793244, 0.16443505005112716, 0.23858385054128511, 0.029811391939542124, 0.033298990689218044, 0.0027044266337595347, 0.012070646043866873, 0.09443345559494835, 0.08102565790925707, 0.03370493444214974, 0.13302597616400036, 0.025137461222974316, 0.05486811597698501, 0.03529866731592587, 0.01470691743972046, 0.06338513163583619, 0.030319037913743938, 0.04453174097995673, 0.1950898372701236, 0.25255955489618437, 0.4396022382591452, 0.49510062166622704, 0.2816364903535162, 0.17961716252778256, 0.07171623887760298, 0.2249190102198294, 0.03445630340969988, 0.06188322151345866, 0.09785676654428244, 0.04168833659163543, 0.0515122955132808, 0.09420853480696678, 0.3832866544170039, 7.186346794877734, 41.29004185540335, 75.19734477996826, 78.89581530434745, 72.86441762106759, 57.314953667776926, 50.8384439604623, 35.93522500991821, 60.55644811902727, 70.75944696153913, 52.34461191722325, 28.925857952662877, 23.461525338036672, 4.738534646374839, 0.03421839885413647, 0.04940489466701235, 0.1901060789823532, 0.039453042072377036, 0.10083991182701928, 0.2657476158014366, 0.11119466833770275, 2.2324824801513126, 1.7802052348852158, 1.3308285368340356, 4.511810149465289, 3.2408536970615387, 4.311012855597904, 5.228787379605429, 6.3800734877586365, 17.281992060797556, 51.747382981436594, 57.808136803763254, 79.76434707641602, 104.53814220428467, 92.80410085405622, 91.59856060573033, 90.78564916338239, 88.76883029937744, 84.77358831678117, 81.76098142351422, 87.15262372153146, 94.38353061676025, 89.99341556004116, 87.71030698503766, 86.07305431365967, 91.58387906210763, 86.96120085035051, 70.35599981035504, 52.83960853304182, 86.17565836225236, 96.39818859100342, 76.60664790017265, 75.25927407400948, 71.76744992392403, 83.5858701978411, 41.9952666418893, 67.66364233834403, 83.3950309753418, 87.98937443324498, 90.86460154397147, 86.68237658909389, 80.33567660195487, 78.15097536359514, 74.54858452933175, 77.93197509220668, 79.96200942993164, 83.30040345873151, 92.06386756896973, 93.48189762660435, 87.87704290662492, 79.19909722464425, 78.49519606998989, 64.27466542380196, 44.46349259785244, 11.631116815975734, 2.7525182323796407, 2.4922015837260654, 1.7405831324202674, 1.5653859334332603, 0.8794802874326706, 1.1327411489827293, 0.33345563975828035, 0.035929843982947726, 0.0987685208341905, 0.10894876492342778, 0.13313522030200275, 0.10830914388809885, 3.805682097162519, 23.364135912486486, 42.648654392787385, 55.35380029678345, 64.79506465366909, 44.428828035082134, 11.028772268976484, 18.46213490622384, 52.03765092577253, 57.59165872846331, 61.57283755711147, 71.65973200116838, 38.73570687430245, 2.816454687288829, 0.2729869873395988, 0.049584340038044114, 0.10902016716344015, 0.09457604972911732, 0.05577129019158227, 0.045273925976029465, 0.037849517938281806, 0.06054987984576395, 0.053381645918956826, 0.0774876813271216, 0.07662449657384839, 0.0672217518357294, 0.09024576137640647, 0.059438921245081086, 0.12615427561104298, 0.2252550343317645, 0.1335524921970708, 0.18454913502292974, 0.15787595058126108, 0.07342592999339104, 0.01944313258198755, 0.052695019370211024, 0.015274077720407928, 0.021199008183819906, 0.17966126730399473, 0.060376710923654694, 0.04994416715843337, 0.08955668870891843, 0.04703755044777479, 0.06941755222422735, 0.04357954600293722, 0.009995915810577571, 0.08365725419883217, 0.0898465249421341, 0.1692637630871364, 0.15079021294202122, 0.15994996071926185, 0.10242872192923512, 0.15203016783509934, 0.13883163034915924, 0.13730677217245102, 0.17021266716931546, 0.1653355745864766, 0.11249246155577046, 0.1833437175623008, 0.048721772751637867, 0.03083110793626734, 0.06578427539872271, 0.05767728148826531, 0.10710483243955032, 0.04397322862808194, 0.020096197092373456, 0.24481771460601262, 0.06700052227824926, 0.059701514297298024, 0.04266317428222724, 0.029220174199768474, 0.05476077512970992, 0.10070406233093568, 0.04197391501760908, 0.21638370464955056, 0.2258963720606906, 0.29987407316054615, 0.4838202755366053, 0.21447930112481117, 0.13050578853913716, 0.17023319963897976, 0.14330952720982687, 0.04860349731253726, 0.07779004331678152, 0.07291093548493725, 0.10635933958526168, 0.09853696397372655, 0.12608762990151132, 0.2964171272303377, 9.823232020650591, 57.70593575068882, 96.66654886518205, 93.59677914210728, 91.88102572304862, 81.80908380235944, 72.1019639968872, 35.79243605477469, 36.288850103105815, 44.26082754135132, 36.57351085117885, 30.725844383239746, 25.8032454422542, 6.27488557781492, 0.07745471809591566, 0.03485040333388107, 0.03576851210423878, 0.04414093195061598, 0.12369595680918012, 0.27479927295020645, 0.6294471898249218, 4.041303762367793, 3.137529641389847, 2.914615362882614, 3.735813183443887, 2.4066798985004425, 3.3953108489513397, 0.7575649150780269, 7.124157811914172, 21.057146378925868, 54.42129646028791, 68.2524048941476, 90.60531561715263, 109.53222247532436, 99.27123396737235, 96.3765310559954, 94.10558182852608, 89.64516489846366, 89.43607275826591, 85.97821835109166, 90.8467377253941, 100.23778397696358, 92.51339517320905, 89.91401154654366, 92.5600870677403, 93.7235837663923, 90.28970064435686, 78.89956038338798, 58.995945249285015, 97.33223492758614, 111.58752046312604, 89.6471312386649, 85.34066554478237, 85.03085926600865, 94.22607054029191, 52.71836594172886, 69.73344816480363, 89.20369720458984, 91.01812894003731, 94.6468812397548, 90.48110961914062, 83.14083112989152, 80.96018069131034, 76.63549682072231, 81.27495493207658, 83.02622059413365, 86.94918046678815, 91.5244094303676, 94.64441462925502, 90.2068920135498, 85.6680577141898, 82.38644436427525, 69.06061240604946, 47.970741748809814, 14.998772314616613, 2.3647981115749905, 1.9076518075806754, 2.6551027510847365, 1.358045716370855, 1.9436710519450051, 1.6842265107801981, 1.7140021473169327, 0.23664077052048274, 0.13937334556664738, 0.14534317808491842, 0.07867057142513138, 0.1430786760257823, 3.7013679231916154, 23.401744774409703, 43.423996925354004, 39.242755140577046, 34.4895133290972, 26.66545261655535, 17.603533846991404, 40.214842864445274, 79.30449444907052, 71.07898766653878, 70.0662043435233, 90.06471797398159, 63.27226965767996, 11.006314822605678, 0.2487777535404478, 0.05268014927527734, 0.05937863340867417, 0.053085275393511565, 0.06002956562276397, 0.044904239741819243, 0.08918664963649851, 0.0417531129371907, 0.012701955025217362, 0.08170367045594112, 0.08117132580706052, 0.07136218609022242, 0.08491059658782822, 0.0799634452643139, 0.1564354614487716, 0.15595777279564313, 0.13552500706698212, 0.129351301917008, 0.13170268359993184, 0.019227629860064814, 0.025248369468109946, 0.0317982408617224, 0.05575642009664859, 0.12082559083189283, 0.07457247775580202, 0.01450236457666116, 0.05414116069940584, 0.009396586184655982, 0.012715189002587326, 0.06104557003293719, 0.01685422462677317, 0.015198706050536461, 0.08348221930542163, 0.04859291555892144, 0.14671696722507477, 0.23175054149968283, 0.1083666565162795, 0.0232670777477324, 0.24022528103419713, 0.14790261217526027, 0.14210816738860949, 0.3547199772936957, 0.3088766043739659, 0.2679416723549366, 0.45042992010712624, 0.10753414833119937, 0.15502695845706121, 0.11876281723380089, 0.23199883103370667, 0.23450588222060884, 0.16117044165730476, 0.26513207597391947, 0.5676648936101368, 0.2082069098417248, 0.2249041638736214, 0.19004049178745064, 0.13633779702442034, 0.3201979340187141, 0.19992115588060447, 0.2383929379284382, 0.4301722028425762, 0.39919488078781534, 0.6543057273541177, 0.7808134789977754, 0.4858828048620905, 0.273416418582201, 0.25218500356589046, 0.3090056617345129, 0.1257313583046198, 0.15424627677670547, 0.12052943743765354, 0.17983124032616615, 0.20916300639510155, 0.395289884614093, 1.0140995723860604, 13.685555832726614, 73.7486731665475, 116.10969298226493, 105.89409010750907, 101.44896616254533, 83.12473215375627, 71.61143507276262, 54.166460854666575, 79.36574281964982, 90.06903975350517, 68.01504748208183, 43.428937094552175, 38.23379332678658, 8.185317533356802, 0.1698315611907414, 0.07726305230919804, 0.3997349946626595, 0.1606444413108485, 0.1779793282704694, 0.4987463631800243, 2.0251278238637105, 6.0329176017216275, 7.31927147933415, 7.211355532918658, 11.652212415422712, 14.041045648711068, 13.794218710490636, 16.435399225779943, 14.896095309938703, 27.090216841016495, 57.13002041407994, 74.17515359606061, 96.6372344153268, 111.90384415217808, 104.9768375669207, 101.59553146362305, 100.29302215576172, 93.91458279745919, 94.80230549403599, 89.40085233960832, 97.47688252585274, 107.38201209477016, 95.84979506901333, 93.60433878217424, 98.43080071040562, 96.90645626613072, 92.64520944867814, 85.26950209481376, 68.96844455174038, 102.48234394618443, 117.99216842651367, 96.0826917375837, 92.42292962755475, 91.91764272962297, 102.66802065713065, 56.580504758017405, 75.72634587969098, 91.27642822265625, 93.38768700190953, 98.4161330631801, 94.4108578818185, 87.62154374803815, 85.3218915121896, 82.4950863974435, 88.05637591225761, 87.0457534790039, 91.39757701328823, 97.27127143314907, 97.28502886635917, 94.90671607426235, 89.25571836744035, 84.1983539036342, 76.7979040145874, 52.786805697849815, 17.58148373876299, 7.788282700947352, 7.7894187314169745, 8.754001532282148, 6.979053369590214, 6.622238618986947, 3.489552306277411, 2.227031401225499, 0.26475605900798527, 0.2114708125591278, 0.2656851091555187, 0.16316099198801176, 0.35162849032453125, 7.0679442797388345, 35.873090744018555, 66.1426955631801, 80.12812001364571, 88.69400514875139, 58.83847822461809, 17.96814751625061, 28.606800147465297, 72.3864996773856, 73.82017707824707, 77.22509316035679, 103.5169654573713, 68.96752044132778, 8.114150609288897, 0.3613094479909965, 0.15324144783828939, 0.20659696337367806, 0.3190523769174303, 0.20701439811715058, 0.11931963664080415, 0.2147651814988681, 0.12329779246023723, 0.14659888856112957, 0.24878947862557002, 0.2416113923702921, 0.1897490881383419, 0.24205184302159719, 0.14421588714633668, 0.23917219468525477, 0.4298795371183327, 0.34702278460775104, 0.3429052712661879, 0.2518008713211332, 0.13136990288538591, 0.15256186787571224, 0.16115358684744152, 0.18817066640726157, 0.2270924121673618, 0.265559118773256, 0.1670128045869725, 0.18271752473499092, 0.17172342538833618, 0.18145972437092237, 0.21938095667532512, 0.18770293864820684, 0.12729490654809134, 0.2685559908194201, 0.12039754380072866, 0.3203307640339647, 0.2565838103847844, 0.2935275179999215, 0.20567844408963407, 0.3795091142611844, 0.24739565913166317, 0.30907802070890156], [0.03080473667276757, 0.1639677836958851, 0.1267564482986927, 0.05228566597881062, 0.04955209944663303, 0.03505680011585355, 0.06715630713318076, 0.015397506632975169, 0.11033781431615353, 0.06400679863457169, 0.03393450998035925, 0.04474060423672199, 0.04278337676078081, 0.014716182835400105, 0.017193229203777652, 0.033546140284410546, 0.025586809164711406, 0.05657798351187791, 0.06076215274099793, 0.18690226732620172, 0.19709482682602747, 0.2649316367294107, 0.1520071519272668, 0.03285058421481933, 0.07521022603447948, 0.09632339953844037, 0.291353491800172, 0.060018966905772686, 0.062123124354652, 0.04237530240789056, 0.09995421328182731, 0.17835603734212263, 2.9386507017271857, 21.771459409168788, 70.57657037462506, 81.67689432416643, 79.63273429870605, 72.17612212044853, 39.19623000281197, 26.78763668877738, 25.239122935703822, 34.1171350479126, 59.68223966870989, 68.00319385528564, 42.22127764565604, 11.791101694107056, 0.7412888684443065, 0.0346869781746396, 0.04172863817906805, 0.04441290914214083, 0.08569313745413508, 0.056565206697476764, 0.14158137994153158, 0.39848339610866135, 0.2370966374874115, 2.445839728627886, 4.19121071270534, 5.068255765097482, 3.8833403757640292, 2.6637321966035024, 3.655154151575906, 23.271723134177073, 66.25930718013218, 94.78774206978935, 98.16806847708565, 90.25475815364292, 87.61373397282192, 85.19047328404018, 78.5589041028704, 77.93269075666154, 77.63701016562325, 79.65719890594482, 81.33696065630231, 84.87439973013741, 86.95750440870012, 91.49396242414201, 83.92271886553083, 82.308242389134, 83.82944624764579, 89.6001753125872, 85.20061070578438, 81.85540744236538, 44.184411253247944, 51.607289927346365, 71.45221710205078, 73.90828023638043, 69.48927456992013, 64.82703331538609, 82.48775604793003, 33.35675893511091, 59.21937847137451, 92.74064295632499, 89.8764773777553, 92.88361603873116, 91.29683508191789, 87.44014712742397, 78.71863624027797, 70.15978268214634, 67.9020767211914, 72.36495331355503, 81.58150945390973, 84.73112787519182, 90.18104471479143, 87.89398261478969, 93.01474244253976, 91.99746363503593, 89.05430398668561, 79.27405439104352, 55.64143139975411, 15.436719008854457, 2.5107198357582092, 2.2440985654081618, 0.8510116179074559, 0.2730710985405104, 1.249251582792827, 0.9236702876431602, 0.6784730819719178, 0.21843416962240422, 0.17424974696976797, 0.09476508958531277, 0.08973653441561119, 0.07916723191738129, 1.2964970533336913, 14.353396705218724, 44.10999952043806, 70.10272407531738, 107.98653316497803, 78.21175820486886, 30.627426624298096, 12.435039026396614, 33.43951545442854, 66.23389066968645, 54.63931703567505, 67.69611821855817, 50.849467277526855, 10.987639801842825, 0.5577486742820058, 0.022893824115661637, 0.04676673694380692, 0.02500090605047132, 0.27115936683756964, 0.047982749728752036, 0.10343631929052727, 0.02921487144859774, 0.022729158933673586, 0.042897591167794805, 0.02899995565946613, 0.11062446822013174, 0.07429643613951546, 0.039583001884498765, 0.14171433209308557, 0.20015560330024787, 0.06011559707777841, 0.07173876624022212, 0.07130000514111348, 0.0762719569195594, 0.035026975109108856, 0.021153034043631384, 0.06777684776378529, 0.03269377816468477, 0.058346690210912905, 0.12941722837941988, 0.06900065352341958, 0.07549638460789408, 0.0850337574790631, 0.04129896944920931, 0.06719046458601952, 0.0680825820724879, 0.06978073130760874, 0.020974418181659918, 0.12874740575041088, 0.0544651917048863, 0.07631653667028461, 0.07189167410667453, 0.10704280076814549, 0.12038469234747545, 0.08512206202639, 0.2217764567051615, 0.09186140753860984, 0.06766161216156823, 0.02681440963143749, 0.02634217300718384, 0.014330990379676223, 0.09263649809041194, 0.052038099084581645, 0.09731932609741177, 0.06032950524240732, 0.1050105205337916, 0.042729168598140986, 0.02285844529978931, 0.08003218764705317, 0.003505049186060205, 0.017587754908683043, 0.04278288482289229, 0.10524790601006576, 0.1241848955729178, 0.18758186085947923, 0.37678767314979006, 0.07299351998205696, 0.11605206983430044, 0.05605613919241088, 0.11544605663844518, 0.3011561786489827, 0.05686327016779354, 0.05839936488441058, 0.030842079847518886, 0.07077899881239448, 0.11963358122323241, 3.9942822626658847, 27.759474277496338, 94.47635854993547, 102.31802599770683, 99.54604911804199, 89.56493404933384, 57.71018804822649, 46.535118852342876, 44.411172662462505, 40.345566272735596, 59.936043466840474, 63.86256776537214, 39.69659062794277, 16.168423380170548, 1.3158463750566756, 0.13655450753867626, 0.09577757918408938, 0.09789446594991855, 0.12413262123508112, 0.3511783501931599, 0.3138307242521218, 0.5141695727195058, 0.45188385780368534, 3.883328650678907, 3.507922909089497, 3.2179103110517775, 3.923901787825993, 0.9390050704990114, 2.529580069439752, 29.52470929282052, 72.47233077457973, 101.46342536381313, 99.75937271118164, 95.90498461042131, 94.30610683986119, 90.1534812109811, 83.59487506321499, 83.19812597547258, 82.59426498413086, 84.5784273147583, 83.61739417484829, 86.8788230078561, 91.36513587406704, 95.58198370252336, 83.62054170880998, 85.96674687521798, 88.28091389792306, 94.71240970066616, 89.73695755004883, 85.92747565678188, 47.8553842817034, 58.378326824733186, 81.5609358378819, 82.209855897086, 77.38055910382951, 71.4768762588501, 90.78182765415737, 38.14973054613386, 60.9010648727417, 93.32839107513428, 89.68334524972099, 95.1538565499442, 91.5546966280256, 90.32396915980748, 81.88322802952358, 72.41400759560722, 69.1773212977818, 73.97074454171317, 83.73574978964669, 87.86426516941616, 93.11076654706682, 89.89864907945905, 91.75968933105469, 95.88729449680874, 91.26630469730922, 84.66844817570278, 58.607429776872905, 20.378686053412302, 2.2009493836334775, 1.4272743101630891, 0.3550154114408152, 2.4786936342716217, 5.29002011673791, 2.832448137657983, 1.6391520266022002, 0.26058087018983705, 0.37100655479090555, 0.11112936612750803, 0.10389863234013319, 0.09950990176626615, 1.357919563140188, 15.861698627471924, 35.60684272221157, 59.78216866084507, 90.64592088971818, 57.549764565059114, 27.170921904700144, 19.836815152849468, 48.730030468532014, 88.40906647273472, 62.709361348833355, 78.78688144683838, 71.51624475206647, 25.879639148712158, 1.1161939054727554, 0.06639356591871806, 0.0065618326937380645, 0.017226680980197022, 0.1787649089736598, 0.031594975518860986, 0.1863839751375573, 0.03226911363058856, 0.07327792114977326, 0.05249370142285313, 0.05733699617641313, 0.08416230138391256, 0.045538656413555145, 0.05888314678200653, 0.08265344984829426, 0.09156801578189645, 0.0262481874254133, 0.05397862781371389, 0.048991324180471044, 0.0632933054917625, 0.057556142631386004, 0.029099245688744953, 0.0162546592099326, 0.032096053274082284, 0.043705288719918044, 0.1325390458639179, 0.06942543680114405, 0.16245732403227262, 0.10700064338743687, 0.03106205750788961, 0.022359889998499836, 0.021958395738952925, 0.03826342769233244, 0.018524078951616372, 0.12768217362463474, 0.016205270342262726, 0.013292651989364197, 0.09340436224426542, 0.03940582960577948, 0.06597302348486014, 0.1638340037316084, 0.331365561911038, 0.28483304168496815, 0.15853206680289336, 0.18732599887464726, 0.1038485768118075, 0.1159430021154029, 0.19330467948956148, 0.2701913687799658, 0.20040276646614075, 0.18592782318592072, 0.2066108054880585, 0.21668269432016782, 0.178960381341832, 0.21344895926969393, 0.11716272309422493, 0.1317589884357793, 0.22041679466409342, 0.29878521444542067, 0.2767880862312657, 0.3216063013034207, 0.5803992588605199, 0.22449689358472824, 0.3037501366010734, 0.18623153546026774, 0.21469778940081596, 0.4492178665740149, 0.15901405736804008, 0.15345768337803228, 0.14062824180083616, 0.26882591204983847, 0.2903532768998827, 7.045426036630358, 38.585132462637766, 114.50668103354317, 117.45233508518764, 110.34149306161063, 96.278304372515, 55.58146844591413, 38.4057925088065, 41.76236302512032, 52.36653000967843, 76.24306256430489, 85.94087178366524, 61.20051833561489, 21.520686762673513, 1.5356978007725306, 0.2899623050221375, 0.22275243433458464, 0.1915096150977271, 0.15340515119688852, 0.6344415875417846, 1.4736706891230174, 2.673293352127075, 2.9211540520191193, 6.60139445747648, 9.982827799660818, 14.22622730050768, 16.823457854134695, 11.517208916800362, 12.12256463936397, 31.331956590924943, 77.21167618887765, 103.7907383782523, 103.71219594138009, 95.10048048836845, 98.76186847686768, 95.21943364824567, 87.36104883466447, 86.7099609375, 85.4190342766898, 87.5912218093872, 88.13955279758999, 90.7650477545602, 94.47272464207241, 101.00804042816162, 86.69029753548759, 85.06343242100307, 89.06374658857072, 98.70923587254116, 91.3978966304234, 85.68436513628278, 53.348379952566965, 65.49525547027588, 96.6425358908517, 91.17340728214809, 87.19796766553605, 77.9856012889317, 97.55289581843785, 43.016530241285054, 65.4226815359933, 93.90737751552037, 92.244124685015, 95.47953251429966, 95.7333015714373, 93.43715122767857, 84.35662691933769, 75.70198549543107, 72.27076353345598, 76.81091799054826, 88.29421275002616, 93.98393276759556, 99.07067421504429, 90.91995089394706, 95.95491436549595, 100.35463878086635, 98.72696767534528, 87.03394848959786, 64.98548698425293, 22.030750547136577, 7.094287940434047, 9.479156357901436, 4.639638764517648, 3.850084125995636, 7.645226240158081, 3.7485205701419284, 2.9911567185606276, 1.1438875794410706, 0.49883332422801424, 0.29054581799677437, 0.35369305525507244, 0.14718590277646268, 3.1039785274437497, 25.737129858561925, 66.63373170580182, 89.88899108341762, 126.6112698146275, 93.26790005820138, 41.402825014931814, 15.699147258486066, 43.78661298751831, 89.28717286246163, 67.02160099574498, 91.52238055637905, 83.62098639351981, 22.65442258971078, 0.5311413077371461, 0.20053977625710623, 0.1079829992460353, 0.09148995711335114, 0.30033981959734646, 0.14779727639896528, 0.32247732313615934, 0.13107114391667501, 0.2022692805954388, 0.1494746013943638, 0.19056391370083603, 0.3166833940361227, 0.1418878742094551, 0.1415015977940389, 0.27196568357092993, 0.4138605738324778, 0.2382172787828105, 0.2310000274862562, 0.13592621125280857, 0.20662167561905725, 0.2168337226446186, 0.12738678018961633, 0.18180754142148153, 0.11453839391469955, 0.12728585489094257, 0.48772668306316647, 0.21339291227715357, 0.31100519586886677, 0.22021841816604137, 0.1420975008181163, 0.09795939496585301, 0.1437480915337801, 0.16067106702498027, 0.10878354843173708, 0.4204330268715109, 0.21984510176948138, 0.1708959655037948, 0.27760482526251246, 0.23405224084854126, 0.24980869250638144], [0.054527796738381894, 0.02394710893609694, 0.16719281992741994, 0.02821190169613276, 0.03459878219291568, 0.005011836490926466, 0.02236319107136556, 0.05941120308956929, 0.07703542416649205, 0.07105900985854012, 0.020184013094486933, 0.04648985733677234, 0.04027688875794411, 0.0041328164266555435, 0.03586189548618027, 0.06355663814714976, 0.049158253973083835, 0.09407973528972693, 0.03443054622039199, 0.09725007481340851, 0.17866611427494458, 0.1864497387515647, 0.1301494762301445, 0.05409645541970219, 0.022509797043832283, 0.057001202766384394, 0.16579426425908292, 0.018767325274114097, 0.025174587266519666, 0.05809971024947507, 0.045013497450522015, 8.300199917384557, 46.36487061636788, 78.70509420122418, 78.92354556492397, 65.21645205361503, 51.28239563533238, 33.28564759663173, 21.814390591212682, 31.21540403366089, 34.64536142349243, 33.35914216722761, 27.978945289339336, 23.02305579185486, 5.667529208319528, 0.15939376556447574, 0.04352510374571596, 0.1265309846826962, 0.03038849275825279, 0.5021861014621598, 0.059769496720816405, 0.30166423852954594, 0.31840000620910097, 0.07479191598083292, 0.5884987956711224, 2.1431088873318265, 1.9477483417306627, 2.614069078649793, 1.374504478914397, 3.159779293196542, 43.92317288262503, 92.64659214019775, 91.4989651271275, 85.51253618512834, 84.62020683288574, 94.28012752532959, 89.38730335235596, 84.69822120666504, 74.50488036019462, 72.44175175258091, 78.41795294625419, 84.18951579502651, 85.9176995413644, 86.45885304042271, 87.31082030705043, 84.32305322374616, 82.94323131016323, 83.06640202658517, 91.67719336918422, 89.20897783551897, 82.04095908573696, 88.57904720306396, 64.07053429739815, 36.75677306311471, 69.55640111650739, 65.04140608651298, 66.13050842285156, 67.58163275037492, 76.21176787785122, 27.939879042761667, 75.83551597595215, 88.65885421207973, 84.71651581355503, 91.35376167297363, 89.12945570264543, 85.49810477665493, 82.78673703329903, 71.35430308750698, 65.35060787200928, 66.16727134159633, 72.82209614345005, 80.1021476473127, 87.95796162741524, 89.59171240670341, 89.81143529074532, 84.49323545183454, 79.53509126390729, 86.41468334197998, 85.93439606257847, 59.476635524204795, 14.575312614440918, 1.921048368726458, 1.5750984294073922, 1.8378228460039412, 0.9052215718797275, 1.1275242460625512, 0.41277698054909706, 0.7208189868501255, 0.1796150454985244, 0.12265391701034137, 0.10428701221410717, 0.10705293129597392, 0.06511535522128854, 0.6133693296994481, 13.506434747150966, 31.023373195103236, 35.2877710206168, 57.28098739896502, 94.22882897513253, 64.55607441493443, 24.577854190553936, 18.106883934565953, 42.48767157963344, 47.159014974321636, 59.69347490583147, 64.2950028010777, 28.69757662500654, 3.9671569296291898, 0.03485203521060092, 0.10037734771945647, 0.07954328959541661, 0.04238258987399084, 0.07587976367878062, 0.012801809934899211, 0.015404044317879846, 0.06483868935278483, 0.03868933055283768, 0.07451586079384599, 0.04996968346780964, 0.034245628464434824, 0.029288058235709156, 0.05274390442562955, 0.024042611043634157, 0.049011215434542725, 0.06815024558454752, 0.060017745542739115, 0.04661419887893966, 0.011128193981546377, 0.02876352352489318, 0.056431223172694445, 0.02140199363098613, 0.03155941689120872, 0.13255368864962033, 0.05890255966889007, 0.08378760077591453, 0.0647429684177041, 0.028868567531130145, 0.01994898552740259, 0.03848919325641223, 0.015195014820035015, 0.007178754612271274, 0.03545364810686026, 0.05697535736752408, 0.12520315950470312, 0.003653972567657807, 0.05715329639081444, 0.0489966167536165, 0.058359317747609954, 0.14881917727845057, 0.04918975156864949, 0.029900537870292152, 0.024396261799016168, 0.026421809269647514, 0.02667891975891377, 0.06513571805719819, 0.062025333887764385, 0.05657205990116511, 0.0977134056655424, 0.06692278252116271, 0.05367401648046715, 0.000850441176485869, 0.04287244466000369, 0.0829619254384722, 0.11899898813239165, 0.07200864675853934, 0.08927420100995473, 0.16679504912878784, 0.16738561886761869, 0.17145796891834053, 0.02403168493349637, 0.01677927534495081, 0.06336417168911014, 0.07082071514534098, 0.01933921833655664, 0.023588632100394795, 0.06020642577537468, 0.1155239117464849, 9.174281563077654, 56.833450453622, 103.71066733769008, 94.9948400769915, 82.5771793637957, 66.77903243473598, 60.54261425563267, 42.17853580202375, 39.561663559504915, 34.875065394810264, 37.30769920349121, 37.10800450188773, 30.393484251839773, 9.34210661479405, 0.2681581793086869, 0.16367842922253267, 0.06521756295114756, 0.060518850439361165, 0.9892739845173699, 0.7610767409205437, 0.2232786789536476, 0.1466528863779136, 0.19816259667277336, 0.37273109225290163, 2.209529757499695, 2.2076541781425476, 1.7114376106432505, 1.1548305579594202, 4.933714321681431, 49.84683527265276, 96.33928176334926, 96.52743898119245, 85.30479894365583, 88.72957992553711, 97.80107852390834, 93.85945578983852, 87.91085978916713, 78.10035773686, 76.36588587079729, 81.36844989231655, 89.23065621512276, 92.83526352473667, 90.7071762084961, 90.03313146318708, 86.3957633972168, 86.62616566249302, 87.19707134791783, 93.66811629704067, 90.75780078342983, 86.8623627253941, 92.89915221078056, 67.68026937757219, 45.802070004599436, 77.89240510123116, 75.3521089553833, 74.5872859954834, 76.63120283399309, 85.05560874938965, 35.62764910289219, 78.68099784851074, 90.62273475102016, 87.90294579097203, 93.57567051478794, 91.44508879525321, 87.37664059230259, 87.51254735674176, 74.45084421975272, 67.89476026807512, 68.57881736755371, 75.8269488470895, 83.45923927852085, 89.2442329951695, 87.97855608803886, 91.58827032361711, 88.34337820325578, 81.93237263815743, 89.12136799948556, 91.0193726675851, 63.779356139046804, 19.94041279384068, 2.665905679975237, 0.9495229061160768, 0.6695857931460653, 1.9773930481501987, 2.422675520181656, 0.6139457587684903, 1.7249188529593604, 0.6245009409529823, 0.5292265361973217, 0.19522611424326897, 0.21800230922443525, 0.0786825136414596, 0.4361647255718708, 14.893838882446289, 33.34370674405779, 40.672743047986714, 56.72660105569022, 80.19523961203438, 54.158963748386924, 38.788902282714844, 34.88263545717512, 62.175156048366, 64.18836184910366, 68.68061542510986, 82.43512344360352, 48.97455494744437, 8.415696348462786, 0.27615441594805035, 0.041701283039791245, 0.06008194174085345, 0.06243497226387262, 0.04814363377434867, 0.025482872866892388, 0.024104808956118565, 0.02192694733717612, 0.032310049648263624, 0.06611408412988697, 0.044472342024424245, 0.038714633123683076, 0.030932165549269745, 0.03078506254990186, 0.01677278515749744, 0.09026809196387019, 0.0205085937133325, 0.04474214111853923, 0.03698628908023238, 0.04015152941324881, 0.0995544475902404, 0.036640782441411696, 0.04272753672142114, 0.1148997816656317, 0.0952346765303186, 0.02738065049717469, 0.11208582230444465, 0.03577921260148287, 0.03274499059521726, 0.018188378840152706, 0.03875304159841367, 0.024320279447627918, 0.005634779983665794, 0.005121508954159383, 0.08189722257001059, 0.124722064605781, 0.06461515956159149, 0.10707428479301077, 0.17509588013802255, 0.24206158678446496, 0.29105938758168903, 0.10043244476297072, 0.1650758720934391, 0.08957526021237884, 0.15950140835983412, 0.15287499821611814, 0.29833841270634104, 0.15144897545022623, 0.1560013483145407, 0.1712142527103424, 0.2023238619523389, 0.23286890291741916, 0.10473017700548683, 0.23275290057063103, 0.12898443160312517, 0.23174750166279928, 0.19090109132230282, 0.18678452792976583, 0.32083041008029667, 0.33708884194493294, 0.37062109261751175, 0.21736373991838523, 0.10995913749294621, 0.2100474089384079, 0.29043014134679523, 0.131177171798689, 0.1411783979939563, 0.17536319579396928, 0.5794106061969484, 15.335551500320435, 78.63874585287911, 120.50360870361328, 109.75788606916154, 91.5633818762643, 74.88905320848737, 52.138180937085835, 33.15972539356777, 44.77889565059117, 49.55218996320452, 49.069387435913086, 46.19144705363682, 39.55281850269863, 12.383889862469264, 0.5489155054092407, 0.42180144201431957, 0.37900992961866514, 0.13211122953466006, 1.2658810104642595, 1.9703480090413774, 1.5483478648321969, 1.1738266072102954, 1.0830052920750208, 2.6246010277952467, 7.959990927151271, 6.476353807108743, 9.084397060530526, 8.433865019253322, 6.613359255450113, 51.93818746294294, 102.81539194924491, 102.53873552594865, 91.73397404806954, 93.98200811658586, 107.0549464906965, 97.34807682037354, 91.1737755366734, 82.65447112492153, 81.1151533126831, 86.68877587999616, 92.01507731846401, 94.07491942814418, 95.79307692391532, 96.19380732945034, 90.52215262821743, 90.1570942742484, 93.2278367451259, 97.72222341809953, 94.35691206795829, 87.23918437957764, 94.1597569329398, 71.00694874354771, 51.44107164655413, 89.09379059927804, 83.27723816462925, 82.09115287235805, 84.8177719116211, 95.28756073543003, 39.75887080601284, 81.82262584141323, 96.03950868334088, 91.02777303968156, 97.2525668825422, 93.61388560703823, 92.83041368212018, 90.91432980128697, 78.42208017621721, 71.5932377406529, 73.68336009979248, 79.55260072435651, 86.90424646650041, 94.67864145551408, 89.07202189309257, 94.51970836094448, 93.68489619663784, 87.38998808179582, 94.851804460798, 93.13091632298061, 66.42958668300084, 20.462074858801707, 4.648889422416687, 5.028383527483259, 6.768649756908417, 5.106213773999896, 6.344479603426797, 3.194441250392369, 3.50320052249091, 1.814204290509224, 0.5099057129451207, 0.28066461107560564, 0.4197839674140726, 0.29863536677190233, 1.4083306980984551, 24.2470417703901, 46.336594922201975, 51.777138641902376, 73.03584357670375, 112.28561987195695, 84.52121584756034, 32.964102336338584, 26.012686729431152, 66.21397713252476, 67.75801971980503, 79.57078416006905, 97.35098811558315, 49.499988147190635, 6.406322044985635, 0.3525761051901749, 0.2119719378118004, 0.20814668307346956, 0.277856996016843, 0.14600358264786856, 0.11793215466397149, 0.13168208327676567, 0.17540537353072846, 0.2185662125370332, 0.17319033667445183, 0.12733519795749867, 0.12031073203044278, 0.2256973713104214, 0.1333975147988115, 0.16928607331854956, 0.1806081493518182, 0.11879791106496539, 0.1515732423535415, 0.2503149067716939, 0.14572232988263878, 0.21618045627006463, 0.15974611522895948, 0.18325420522264071, 0.1645820750189679, 0.21656500920653343, 0.23224652345691407, 0.2267883199134043, 0.11234345526567527, 0.13295223297817366, 0.10672106660370316, 0.19383248473916734, 0.2622707752244813, 0.11724382159965378, 0.13220169182334626, 0.18835478009922163, 0.18173964720751556, 0.2520265520683357, 0.19375689593808992], [0.10697620934141533, 0.05756813234516552, 0.03407418980662312, 0.037381752859801054, 0.09779071116021701, 0.043796042778662274, 0.0280680997696306, 0.02167068332034562, 0.008125446670289551, 0.009290587988549044, 0.04740680241957307, 0.04119242588058114, 0.020482049423402975, 0.011761452054737933, 0.03842799957575543, 0.05953102558851242, 0.02201190501052354, 0.07651528636259691, 0.08139254179384027, 0.11423423380724021, 0.07855088463319199, 0.14873411612851278, 0.15124078733580454, 0.0988502028797354, 0.14140823137547287, 0.14095992328865187, 0.07305410637387208, 0.1429156104901007, 0.03202496316017849, 0.3309896806521075, 14.914785964148384, 56.08982992172241, 94.48391819000244, 91.31747817993164, 83.11712387629917, 45.46462379183088, 33.16164657047817, 16.929746185030254, 26.685937643051147, 56.895994663238525, 57.331038747514995, 39.907836709703716, 28.50591925212315, 8.799757157053266, 0.9156830076660428, 0.06773185410669871, 0.00837693125608244, 0.018332491196425896, 0.07674836992685284, 0.9133783770459039, 0.3940954458500658, 0.23495325392910413, 0.07085114744092737, 0.08575423953256436, 0.2737851073699338, 1.3929870128631592, 0.33524105538214954, 1.598827070423535, 6.059559166431427, 60.2323910849435, 93.97175257546562, 86.81642818450928, 80.40579782213483, 76.55384159088135, 81.50009741101945, 81.56461838313511, 79.20801871163505, 70.20502935137067, 68.67642566135952, 77.93974317823137, 85.00612367902482, 87.66263539450509, 85.90865993499756, 85.18094730377197, 82.86199297223772, 80.5848251070295, 82.28537586757115, 87.87241540636334, 85.2532572065081, 85.7735869543893, 85.65512711661202, 84.4737527029855, 86.89113521575928, 45.502595697130474, 41.28097793034145, 70.63869421822685, 73.60795130048479, 77.22694138118199, 56.43222325188773, 38.95451259613037, 83.88851983206612, 78.3570658820016, 78.26011766706193, 87.42626462663922, 87.07629081181118, 87.10165173666817, 76.27034814017159, 64.47725405011857, 61.21062101636614, 67.23751626695905, 68.82381779806954, 77.05921881539481, 80.45242718287876, 86.14764322553361, 87.00788579668317, 80.97689805712018, 70.38300745827812, 75.33744825635637, 79.25254276820591, 87.2862514768328, 58.26185417175293, 27.858764035361155, 3.605660830225263, 3.0994172521999905, 2.4456816571099416, 5.284426382609776, 1.129649092044149, 0.26435203211648123, 0.14779643501554215, 0.10199649512235608, 0.1162667176020997, 0.04740697544600282, 0.14715539584202425, 0.044049085450491736, 0.3723425902426243, 9.189311385154724, 30.542227813175746, 49.156125273023335, 36.903331415993826, 45.707122870853965, 42.33817413875035, 26.782911913735525, 14.415363345827375, 23.140355280467443, 57.5451648575919, 59.500370570591514, 67.3861312866211, 40.81809936250959, 18.670589549200876, 1.7043433913162775, 0.19453470062996658, 0.10605462307908706, 0.10992557036557368, 0.060897120141557286, 0.04349256459889667, 0.030098079770271267, 0.07256961879985672, 0.03980560886806675, 0.02163267009226339, 0.07971085381827184, 0.035438408210341416, 0.07827000506222248, 0.008731857657299509, 0.021458222131643976, 0.038384647973413975, 0.03958784323185682, 0.019610764658344642, 0.02311332001616912, 0.10444687506450073, 0.05067567201331258, 0.04902512879510011, 0.007702934788540006, 0.05475880398548075, 0.004130292700470558, 0.043116917434547625, 0.0404406022945685, 0.036784832033195665, 0.030997097957879305, 0.07215217048568384, 0.05563582067510911, 0.030414022638329437, 0.06210265973848956, 0.052935057918408086, 0.027855353596221124, 0.013918457203544676, 0.07515058280634028, 0.060884791160268445, 0.05097398654158626, 0.055479811903621466, 0.03049365890079311, 0.08985979030174868, 0.0546480806411377, 0.03711315477266908, 0.032729102697755606, 0.008751089884234326, 0.07337675656058959, 0.012006196243289326, 0.045054613279977014, 0.02586246231969978, 0.03755209568355765, 0.06269464761550937, 0.017373247936900173, 0.04831309110990592, 0.05659860758376973, 0.05329807415338499, 0.06348531054598944, 0.08596956583538226, 0.08495224506727286, 0.14103380218148232, 0.10846302205962793, 0.1440779816891466, 0.038014968524553945, 0.1569508495075362, 0.10921136476099491, 0.08372734008090836, 0.6946538080062185, 16.691768646240234, 69.55071749005998, 114.41718823569161, 100.44834218706403, 103.28383949824742, 67.09999057224819, 57.70469202314104, 27.46916811806815, 32.187509128025596, 49.77322605678013, 47.9133426802499, 44.79087781906128, 31.611277648380824, 11.718813504491534, 0.7333218359521457, 0.030259815377316306, 0.04270296696839588, 0.060551440476306846, 0.5627965405583382, 1.379742443561554, 0.30383761333567755, 0.292505644261837, 0.021090069386575903, 0.11091628577560186, 0.3196706851678235, 0.6426879050476211, 0.7076279946735927, 0.8819372898765973, 7.663190807615008, 66.96331950596401, 96.7160895211356, 88.25150912148612, 83.24075317382812, 80.22181647164481, 85.2332741873605, 85.42792102268764, 83.08886555262974, 74.95602689470563, 71.17335809980119, 81.51516110556466, 91.04304518018449, 91.54874897003174, 90.24815041678292, 89.71619633265904, 84.71441745758057, 82.11456830160958, 84.76055349622453, 91.28701032911027, 89.85776587894985, 87.79641601017543, 90.24418994358608, 85.82533713749477, 90.56893484933036, 48.912132331303184, 48.369102818625315, 78.3556137084961, 80.423647744315, 88.08185495649064, 61.32730211530413, 46.802200657980784, 88.23117174421037, 81.2921586717878, 80.69500269208635, 89.68373434884208, 90.30298560006278, 88.9092047555106, 80.21404143742153, 68.14812632969448, 63.084466797964915, 68.171388898577, 73.58428573608398, 79.96064758300781, 85.33597551073346, 87.08207171303886, 87.38741030011857, 84.13863413674491, 72.57228061131069, 77.80407265254429, 83.12573964255196, 90.22781303950718, 62.36727373940604, 33.014810289655415, 6.6374638591493875, 0.5442932162966047, 0.7110884689858982, 6.203560582229069, 1.7727110598768507, 0.12434642761945724, 0.10273970809898206, 0.3418952583202294, 0.34166379645466805, 0.14772304466792516, 0.13661446289292403, 0.09111276628183466, 0.23630880404795918, 10.808153067316328, 27.676043782915386, 38.814687047685894, 32.64719499860491, 43.87379550933838, 35.84121240888323, 24.09666190828596, 29.22953244618007, 44.09667982373919, 74.08690452575684, 71.15174920218331, 81.54118905748639, 65.50448962620327, 33.8897066116333, 3.363611647060939, 0.2654735419367041, 0.025633936814431633, 0.14399411476084165, 0.10407045776290552, 0.044080661077584536, 0.07872840975012098, 0.04833925202754991, 0.040790763683617115, 0.028849069827369282, 0.06241120996751955, 0.010045342845842242, 0.06534303764679603, 0.030801727369959866, 0.048369317914226224, 0.04425863742030092, 0.0345593627010073, 0.04294337531817811, 0.057589187286794186, 0.11155683640390635, 0.06024730072489806, 0.010492434658642327, 0.009312784565346581, 0.08698171616664954, 0.03730757201888731, 0.03148419449904135, 0.008654600508244974, 0.015036454756877251, 0.02757950875508998, 0.0722162038353937, 0.00929624103342316, 0.041488165368459055, 0.06538475397974253, 0.025262067393798913, 0.030674050828175883, 0.042687621898949146, 0.06697194916861397, 0.1437097271638257, 0.1489532965102366, 0.127033317727702, 0.12938233810876096, 0.23288152366876602, 0.24268613755702972, 0.08707844811890807, 0.16862634729061807, 0.1712113350097622, 0.15664724579879216, 0.16181826618100914, 0.1843173610312598, 0.1658534596541098, 0.13616178504058293, 0.08447556743132216, 0.11760770635945456, 0.11777348603521075, 0.19687152095139027, 0.18591277327920708, 0.15548834869904177, 0.2427270667893546, 0.2633450318660055, 0.26468285865017344, 0.18616436049342155, 0.30337876081466675, 0.17799565382301807, 0.21841609344950744, 0.15768579792763504, 0.1648465951106378, 1.7143956976277488, 31.006134714399064, 91.6687513078962, 131.03453472682406, 116.21777221134731, 112.76591409955705, 71.38228348323277, 52.9283891405378, 27.026149238858903, 36.28815180914742, 73.4093439919608, 76.73191697256905, 59.601911544799805, 44.71416623251778, 15.726795877729144, 1.732055087174688, 0.18815695999988488, 0.09185471039797578, 0.15297487857086317, 0.5575321944696563, 3.811994969844818, 2.4308533327920094, 1.114546856709889, 0.2714656304035868, 0.3143325416105134, 0.9353121029479163, 5.128279081412724, 3.5885137617588043, 4.85035982302257, 8.115312695503235, 71.22467749459403, 102.67665726797921, 94.09363787514823, 89.36334596361432, 83.35899761744908, 88.94165284293038, 87.42268630436489, 88.31994887760708, 79.7297033582415, 74.77970245906285, 86.69449424743652, 93.8244299207415, 95.25714152199882, 95.30879443032401, 92.30264936174665, 87.61394936697823, 86.20108876909528, 91.21242836543492, 96.93203953334263, 94.19433116912842, 93.23110239846366, 91.31114837101528, 87.97022519792829, 90.52951077052525, 52.57205772399902, 57.20421327863421, 89.64317771366665, 89.21750327519008, 97.70498493739537, 68.86023330688477, 51.91625199999128, 90.15100765228271, 85.33193860735211, 83.06607546125139, 94.19829164232526, 92.97378976004464, 93.04152774810791, 82.96545859745571, 72.97603348323277, 65.94142709459577, 72.5954806464059, 75.34452847072056, 86.44394915444511, 87.63648932320731, 89.76277705601284, 93.1786504473005, 88.50224876403809, 75.2185367856707, 83.45212432316372, 86.93395696367536, 93.44065311976841, 61.38914803096226, 30.63645233426775, 5.768318040030343, 11.336573992456708, 8.9116370507649, 15.283504281725202, 5.282732759203229, 1.5802839568683078, 1.5547114376510893, 1.26793572306633, 0.7437754007322448, 0.3550316962812628, 0.3851826441075121, 0.13464988688273088, 0.6817935066563743, 17.77406348500933, 47.590251445770264, 66.81822027478898, 52.840230396815706, 61.293693678719656, 56.35967363630022, 39.345741340092246, 20.077832528523036, 37.92038093294416, 81.66670826503209, 76.75335911342076, 100.38491208212716, 73.9040140424456, 34.761361598968506, 2.7735958099365234, 0.3408983546708311, 0.1584804438586746, 0.33047377690672874, 0.20719377563468047, 0.15902613529137202, 0.16899123628224644, 0.15020668639668397, 0.18553174872483524, 0.15905821642705373, 0.19169528942023004, 0.09133484400808811, 0.2332610690167972, 0.06931131399635758, 0.15180288574525289, 0.13411237858235836, 0.10834269744477101, 0.140777818060347, 0.095181058693145, 0.2033882119825908, 0.2860657769654478, 0.1082214160955378, 0.11517188777881009, 0.19957605297011988, 0.18958283348807267, 0.20172178425959178, 0.1177998131939343, 0.044235241532857926, 0.059496813852872164, 0.136403533497027, 0.1619948481342622, 0.1098027623125485, 0.23161358599151882, 0.13644401489623956, 0.09600986886237349, 0.07424786660288062, 0.2350189904017108], [0.11020870267280511, 0.12798807078174182, 0.0038110703878503826, 0.04995662166870066, 0.04781255279002445, 0.05132606139938746, 0.020952582924759815, 0.08772857287632567, 0.05679599342069455, 0.02379452167744083, 0.048052842396178415, 0.10620493215641805, 0.014531448283897979, 0.013131678886046367, 0.04621672663571579, 0.015428074635565281, 0.03219397944797363, 0.035576133855751584, 0.03651406602667911, 0.14072820357978344, 0.0509550893413169, 0.04744780968342509, 0.06504310481250286, 0.12519972611750874, 0.06595411271389041, 0.021769089557762657, 0.008947526620301818, 0.13568529060908727, 0.07917918091905968, 16.006653683526174, 66.58243315560478, 94.41180978502545, 81.08482442583356, 81.1073226928711, 36.56088250023978, 28.80222691808428, 15.72394711630685, 51.82415015356881, 74.13133130754743, 63.293607575552805, 49.61680473600115, 24.697392736162456, 9.376515831266131, 0.14118069144231932, 0.08140510147703545, 0.0250081714641835, 0.055377631315163205, 0.2199051792600325, 0.27179746116910664, 0.641723245382309, 0.09848009595381362, 0.47669772058725357, 0.048578693464930565, 0.02983344772032329, 0.09189658279397658, 0.7706783371312278, 2.965195425919124, 18.61640749658857, 69.1253696169172, 87.84997272491455, 79.20594120025635, 77.45450183323452, 70.39541694096157, 65.63118307931083, 66.28657191140312, 68.1255794252668, 67.06836932046073, 63.82141358511788, 77.69037927900041, 84.93644714355469, 87.4050726209368, 87.26330157688686, 84.27386692592076, 82.48645673479352, 85.89440223148891, 81.23721926552909, 81.11890533992222, 80.15291813441685, 74.92191818782261, 74.6175731931414, 78.93623992374965, 85.71510396684918, 84.34824739183698, 86.27106407710484, 36.81764623097011, 43.24455969674246, 65.99192660195487, 72.07357365744454, 34.36124610900879, 69.9904898234776, 82.09416839054653, 70.58332402365548, 67.58853925977434, 76.28839261191231, 83.82670170920235, 79.16220229012626, 67.19731398991176, 62.20580455235073, 68.94133268083844, 72.6248367854527, 76.84253229413713, 74.82958357674735, 80.78637845175606, 85.42066710335868, 82.43434524536133, 77.13471794128418, 64.67627130235944, 68.61152948651994, 78.04520988464355, 79.91964626312256, 81.1104632786342, 82.03633853367397, 65.5229857308524, 23.908515112740652, 1.9720251304762704, 2.121875409569059, 0.993688804762704, 0.5290743815047401, 0.280406903475523, 0.5352619694811958, 0.20130086184612342, 0.15790539900107042, 0.3084882380706923, 0.08116185345820018, 0.292224893612521, 0.5525769889354706, 5.734353942530496, 24.332299641200475, 51.96681751523699, 45.00625460488455, 56.20572934831892, 58.340903827122276, 27.775708743504115, 19.631572314671107, 19.9201066834586, 48.609375, 56.71838828495571, 54.579715388161794, 58.65697043282645, 31.786987168448313, 2.4947061921869005, 0.1012514161744288, 0.08346844504454307, 0.01674985745921731, 0.021297763866771544, 0.025825409218668938, 0.01905396391105439, 0.033966404518910816, 0.022460601558642726, 0.014887562121397682, 0.032847652943538766, 0.05249590666166373, 0.06563832930156163, 0.06059781834483147, 0.014721142926386424, 0.029744641057082584, 0.04772877746394702, 0.06031932043177741, 0.03973356541246176, 0.018426778726279736, 0.01052661840471306, 0.03550183427120958, 0.07148460059293679, 0.050749486445316246, 0.0534577164798975, 0.005030420716918472, 0.004304793671638305, 0.03145907173997589, 0.017921154786433493, 0.024306031908573847, 0.0520698986282306, 0.042974499719483514, 0.06238752231001854, 0.07732569466211967, 0.02617880213074386, 0.03857286340956177, 0.1073314156383276, 0.057483675091394355, 0.027964674069413116, 0.0118642967593457, 0.07240856851318053, 0.01731244950289173, 0.0265664016894464, 0.10430344633225884, 0.03697049957034843, 0.05213417285787208, 0.06163521017879248, 0.05832910258322954, 0.02094825726401593, 0.022132896286036288, 0.01419019521147545, 0.006196720209637923, 0.045559290663472245, 0.023016898493681635, 0.027761351051075116, 0.10764253751507827, 0.10911789656217609, 0.09768597249473844, 0.0051658028720079786, 0.07355293139283146, 0.028542015768055404, 0.0453349534156067, 0.023832545083548342, 0.11011051187025649, 0.4971116366130965, 18.66094544955662, 80.13021142142159, 110.36602715083531, 93.91180351802281, 97.7698255266462, 56.95887238638741, 47.76421001979283, 28.10946719987052, 42.30633749280657, 41.97463049207415, 44.93501819883074, 45.67773199081421, 29.699230670928955, 12.852657897131783, 0.2220872121730021, 0.04320412275514432, 0.10763468007956233, 0.12878449447453022, 0.5542894484741347, 0.6994740122130939, 0.6465649455785751, 0.3273683392575809, 0.3047765700944832, 0.07685392961970397, 0.06824245849358183, 0.08909208899629967, 0.24665844440460205, 3.20638889500073, 20.485116822378977, 73.86276258741105, 90.7703492300851, 81.19012437547956, 78.75969314575195, 75.26835536956787, 68.72920417785645, 69.30786405290876, 70.9602360044207, 69.75451510293144, 66.15825257982526, 80.18189907073975, 88.41796016693115, 90.21855803898403, 89.30291748046875, 85.7262419291905, 85.33569063459123, 88.5657205581665, 84.9573403767177, 85.67101764678955, 83.57409994942802, 78.53935187203544, 80.62670189993722, 82.20215729304722, 90.96104254041398, 86.81428813934326, 91.79438863481793, 43.30677386692592, 50.562892300742014, 74.83107049124581, 79.11664295196533, 44.43494244984218, 73.68759155273438, 84.81576388222831, 74.25728130340576, 71.9690032686506, 77.58083398001534, 85.6758952822004, 80.93634837014335, 70.11276422228131, 65.72978496551514, 73.67998327527727, 77.60382556915283, 78.65257971627372, 78.57346057891846, 83.43182168688092, 84.61516938890729, 84.32193456377301, 79.83180018833706, 65.03636169433594, 72.94420378548759, 80.5706090927124, 83.93347467694963, 86.4358058656965, 85.59907599857875, 70.28306456974575, 31.22795942851475, 4.133116390023913, 0.2010218889585563, 1.0680882696594511, 0.543857216835022, 0.6328540870121547, 0.2892480247787067, 0.4256320707499981, 0.5865248015948704, 0.43949345552495545, 0.034620963502675295, 0.2256461012044123, 0.37990057468414307, 6.92313209601811, 26.046517508370535, 40.48652785164969, 32.3368432862418, 32.94348355701992, 38.958622455596924, 22.824559654508317, 24.549901587622507, 40.503425870622905, 67.85915769849504, 68.55094119480678, 68.55704866136823, 72.99958092825753, 49.032881600516184, 6.485333051000323, 0.2394532710313797, 0.06047604845038482, 0.08378133111234222, 0.028471437948090688, 0.03241909361843552, 0.015829550235399177, 0.046135444925831895, 0.025501262862235308, 0.04568019542577011, 0.0816241597224559, 0.03787596384063363, 0.015596622734197547, 0.04783322775204267, 0.03141896014234849, 0.04323261104790228, 0.012840521205881876, 0.0729323025526745, 0.005905398832900184, 0.023763120773115327, 0.04254832544497081, 0.06799828088177101, 0.05188438036878194, 0.04898960070152368, 0.02081873171430613, 0.09237307044012205, 0.010017576344710375, 0.04104817612096667, 0.034178938650126965, 0.04767239120389734, 0.008967051465463425, 0.059913135798914094, 0.053150757415486236, 0.07005082217178174, 0.013670133742769914, 0.024862690163510184, 0.33393530973366325, 0.219182905874082, 0.14009717958314077, 0.14507951294737204, 0.13998090582234518, 0.14362586023552076, 0.07270227918135268, 0.2559054382145405, 0.1921522013310875, 0.202253932133317, 0.1729665829667023, 0.20150663437587873, 0.10154324051524911, 0.08757763276142733, 0.1391733270138502, 0.09093187563121319, 0.11652233531432492, 0.11710857599973679, 0.08653766249439546, 0.23612136553440774, 0.13839508805956158, 0.4747485880340849, 0.28390757420233315, 0.2014834556196417, 0.23149761078613146, 0.2183478463973318, 0.12688024022749492, 0.20330709990646156, 1.8680040836334229, 31.878046785082134, 98.4560991014753, 124.54958643232072, 104.98776708330426, 108.8320802961077, 57.738102436065674, 39.54532487051827, 20.263201781681605, 70.50862394060407, 98.37813336508614, 83.09465340205601, 70.07712691170829, 41.00437361853463, 17.133985008512223, 0.36717969870993067, 0.19849049193518503, 0.1613873014492648, 0.24540991282888822, 1.0542063117027283, 2.147657568965639, 2.7821514308452606, 1.4064002931118011, 0.7481515173401151, 0.3383088479084628, 0.17680312852774346, 0.2613388480884688, 3.126327625342778, 4.807573250361851, 22.449640069689067, 79.79893520900181, 94.65507316589355, 85.68972914559501, 84.33562251499721, 77.81762858799526, 73.51089886256626, 73.89912945883614, 76.54944338117326, 72.10338837759835, 68.6482298714774, 84.2662239074707, 93.09451471056256, 94.01323332105363, 94.58577878134591, 91.62446349007743, 91.61390222821916, 94.03276470729283, 90.2692312513079, 91.82434231894356, 89.87570612771171, 84.87084920065743, 84.11611502511161, 84.38092476981026, 93.91207449776786, 89.59807000841413, 95.11238275255475, 47.953016894204275, 57.66318695885794, 85.14002936226981, 90.59754058292934, 50.934085914066856, 77.20819514138358, 88.84009102412632, 76.77969278608049, 73.62337630135673, 83.47130135127476, 91.78616196768624, 86.79941204616001, 73.47262818472726, 69.53739779336112, 77.42581272125244, 80.65964330945695, 81.97609765189034, 81.82318864549909, 86.68969304221017, 87.45068059648786, 89.69370501382011, 83.45157541547502, 71.19520323617118, 74.90329701559884, 85.71658393314907, 88.25150217328752, 88.27781500135148, 87.04057012285504, 68.48398835318429, 27.587509836469376, 3.4545201403754096, 8.333079661641802, 3.9655961905206953, 1.727106015597071, 1.8478616901806422, 2.018259095294135, 1.6936048418283463, 1.251637529049601, 0.8690260712589536, 0.3896067195705005, 0.7438425485576902, 1.1732837791953767, 11.16365156854902, 41.93297256742205, 71.42719663892473, 62.83597142355782, 76.60703005109514, 77.88608224051339, 38.33956922803606, 27.72666835784912, 33.727869170052664, 70.4253706250872, 73.9166041782924, 79.72955049787248, 91.89434541974748, 51.7821934563773, 5.610201793057578, 0.25511117226311136, 0.21094032031084808, 0.2260654629873378, 0.10145682229527406, 0.09683795299913202, 0.19973383950335638, 0.09362810238131455, 0.0830806554960353, 0.13093110785952636, 0.1603277147348438, 0.11267943188015904, 0.10854313668927976, 0.1533653890447957, 0.10128114279359579, 0.10715280486536877, 0.08286463708749839, 0.1869022130434002, 0.08609915923859392, 0.1285741621894496, 0.18673393635877542, 0.1596521788409778, 0.21550236908452852, 0.1481531680162464, 0.20741910354367324, 0.17115547800702707, 0.07459145638027362, 0.1833109986037016, 0.149834862777165, 0.15677550248801708, 0.1566039959767035, 0.12827043634440216, 0.13347380927630834, 0.13816458971372672, 0.07004949224314519, 0.13633216518376554], [0.022813767161486403, 0.012485408207534679, 0.011329351625006114, 0.04472245003229805, 0.010671120070453202, 0.023610560655859963, 0.05063440690615347, 0.016053331084549427, 0.03898232875924025, 0.05520201627431171, 0.029864606048379625, 0.02753678649397833, 0.07354694671396698, 0.029781580503497804, 0.014405746279018266, 0.026458426411928873, 0.07101768029055425, 0.04571861407852598, 0.012757122466739799, 0.036478629535330195, 0.07414391503802367, 0.027546693105250597, 0.13656796967344625, 0.06401086984468357, 0.09538860898464918, 0.054144163216863356, 0.08704295395208256, 3.060142776795796, 31.396894454956055, 66.92701516832624, 88.50012956346784, 85.62697996412004, 64.66647434234619, 47.208552156175884, 23.750658988952637, 21.212989262172155, 56.469267572675435, 48.64981004170009, 59.13159493037632, 47.041493143354145, 27.49472185543605, 10.739533526556832, 0.2860853187739849, 0.0985437628946134, 0.1906039879790374, 0.11853662079998425, 0.12216885946691036, 0.4312137540962015, 1.1558116653135844, 2.9023270394120897, 0.34575362556747025, 0.06955170538276434, 0.07691020731415067, 0.15391143331570284, 2.7047836737973348, 18.095214435032435, 51.61351203918457, 77.10734898703438, 76.72963101523263, 81.87655081067766, 78.70173127310616, 73.67430659702846, 65.03570856366838, 62.58969947269985, 61.6136234828404, 59.99710423605782, 59.31105995178223, 65.00121770586286, 80.36952822549003, 85.6803560256958, 86.65514659881592, 81.7350160053798, 72.6324520111084, 75.37680285317558, 83.20697798047746, 83.08448818751744, 76.47664710453579, 73.21161910465786, 70.39908558981759, 68.65520586286272, 73.49261815207345, 76.36177948543003, 81.1578916822161, 80.41171073913574, 85.67404011317662, 30.709974697657994, 57.690382208142964, 48.77151468821934, 54.735348088400706, 85.31217098236084, 68.78727722167969, 67.81411252702985, 60.6528821672712, 66.57500553131104, 68.34004947117397, 65.23134204319545, 59.265549251011436, 71.27967943464006, 73.83495589665004, 80.81672818320138, 80.79529299054826, 81.54873480115617, 77.74754905700684, 79.48767675672258, 81.56879425048828, 77.49213327680314, 61.22009835924421, 62.36711393083845, 72.95708574567522, 80.78368255070278, 80.88884353637695, 81.86435672215053, 84.55922944205147, 88.98892143794468, 65.53260203770229, 25.46800180843898, 2.0341303007943288, 0.32285770986761364, 0.33574037573167254, 0.11524697446397372, 0.4188339098223618, 0.30551620040621075, 0.02645775635859796, 0.08447273115494422, 0.016765233062739884, 0.07262853599552598, 0.19642702623137406, 1.489477515220642, 8.098128931862966, 36.13077858516148, 44.92423459461757, 39.94202879496983, 74.98684215545654, 44.26874501364571, 13.673848986625671, 18.042135408946447, 31.708201544625418, 47.5212801524571, 58.48150757380894, 65.29183306012834, 40.321383067539756, 8.320371406418936, 0.6247237718531063, 0.25133602055055754, 0.022423763892480304, 0.06938318442553282, 0.08196591066994838, 0.12293994666210242, 0.03698069116632853, 0.03405742659898741, 0.03483993693121842, 0.08906649465539626, 0.034909883713615794, 0.03566958848387003, 0.019757216264094626, 0.03628166778279202, 0.04504324781841465, 0.0396802766647722, 0.019088469113090208, 0.06078880559653044, 0.020614324736275842, 0.05058784922584891, 0.025331038782106977, 0.01849555842844503, 0.009859118909974183, 0.03941248942698751, 0.03051329909690789, 0.0387864628407572, 0.06351401257727828, 0.02057701548827546, 0.05918136292270251, 0.04088896466419101, 0.03548170892255647, 0.08136232662945986, 0.040651894706700525, 0.0026554115964764996, 0.027077409804665616, 0.03374959561707718, 0.04792415822989174, 0.03349901942004051, 0.036836224275508096, 0.03671175720436232, 0.0351300208297159, 0.08668650593608618, 0.03247349516355565, 0.02176173932717315, 0.07382479323340313, 0.026295040268450975, 0.09305175473647458, 0.017010750781212534, 0.030919334452067102, 0.013161481840402951, 0.042418246889220815, 0.05633934613849435, 0.06143601265336786, 0.0243286729258086, 0.06537037582269736, 0.07435655434216772, 0.08311244486165897, 0.03725900248225246, 0.18572578259876796, 0.06388863854642425, 0.10881745482661895, 3.9450560126985823, 38.567431926727295, 80.45683928898403, 104.35799625941685, 99.35071441105434, 78.11972236633301, 68.30833094460624, 37.153091362544465, 24.529411349977764, 22.985243695122854, 47.91013956069946, 53.24800974982125, 43.50266790390015, 34.49936587469918, 12.543100016457693, 0.5046361557074955, 0.045326678681054285, 0.26080562812941416, 0.06773416791111231, 0.11565773242286273, 0.6497608455164092, 2.359195909329823, 4.490352375166757, 0.20622070213513716, 0.03857467170538647, 0.11353352426418237, 0.3858758897653648, 3.3969955699784413, 20.367746114730835, 56.62173884255545, 82.15846007210868, 76.2967096056257, 84.72476332528251, 82.31273787362235, 75.34691170283726, 67.53566346849713, 67.09279918670654, 64.44608443123954, 61.70842470441546, 61.61080946241106, 68.33436584472656, 83.08454377310616, 90.61523764474052, 90.78033379146031, 83.19475609915597, 74.61114610944475, 78.83430290222168, 86.56494508470807, 86.79604911804199, 79.97754560198102, 76.66296999795097, 76.32404381888253, 74.98589025224958, 75.87295286996024, 78.68957192557198, 84.11824117388043, 84.20086220332554, 89.62825298309326, 38.4411484173366, 64.10683168683732, 57.60265077863421, 62.05067212241036, 87.99523871285575, 73.29465007781982, 71.01300062452043, 62.479820660182405, 70.22239289964948, 70.50745664324079, 66.60174219948905, 61.069801875523154, 75.27873597826276, 76.2478220803397, 83.45518153054374, 84.01574829646519, 82.96572262900216, 81.06629358019147, 81.77473190852574, 82.42909935542515, 79.44652952466691, 64.59233011518205, 63.441590309143066, 75.87284864698137, 82.98180770874023, 81.39394283294678, 84.48476559775216, 84.25566264561245, 93.07296139853341, 73.40807941981724, 34.91044214793614, 4.790795087814331, 0.5689953107919011, 0.5196252656834466, 0.7171569062130791, 0.3002884680671351, 0.32564931149993626, 0.6076361973370824, 0.04694584983267954, 0.09479416481086186, 0.15961160244686262, 0.06258914220545973, 1.7649891142334257, 11.356143593788147, 37.316387925829204, 39.99497406823294, 40.33747162137713, 49.19716828210013, 32.40361547470093, 15.104775769369942, 34.169416768210276, 55.300125462668284, 62.34852749960763, 74.38210569109235, 84.06029319763184, 60.41872787475586, 17.865444455827983, 1.5891888333218438, 0.3186186301921095, 0.014519239742574947, 0.10491845690246139, 0.05269929074815341, 0.07692914522652115, 0.042925353428082805, 0.03892127078558717, 0.037403174210339785, 0.034420941557203016, 0.08256009021507842, 0.042546113420810015, 0.024238054574068104, 0.02935930441266724, 0.0289490655330675, 0.042925767334444184, 0.043653865943529775, 0.013943440862931311, 0.0881765688370381, 0.10182750597596169, 0.03495890786871314, 0.04194160996537123, 0.03803091749016728, 0.031209231753434454, 0.031095977473471845, 0.07827677684170858, 0.039888868507530005, 0.059364648801939826, 0.020507111114316752, 0.01827512614961181, 0.03391747875139117, 0.026750562878857766, 0.010939950555829065, 0.00775409463260855, 0.04654886952734419, 0.17638388888112136, 0.09271274507045746, 0.11509920310761247, 0.07783022616058588, 0.10156846166189228, 0.12306989968887397, 0.1630861767168556, 0.08712192185755287, 0.15142997646970408, 0.15583140243377003, 0.15975266987723963, 0.1803538887096303, 0.12479554994830064, 0.14497021452656814, 0.10201117183480944, 0.21509747366820062, 0.14729507906096323, 0.12722618452140264, 0.07889355160295963, 0.258864339441061, 0.21899317391216755, 0.24955842165010317, 0.13165665178426675, 0.26874193655593054, 0.19899096579423972, 0.18593318361256803, 7.050143429211207, 57.88847534997122, 101.57778576442173, 120.01237106323242, 111.99491419110979, 92.99339062826974, 67.78096267155239, 40.13568203789847, 35.579063824244905, 80.06130613599504, 65.71393612452916, 76.96432726723808, 67.57134941646031, 43.88394682747977, 17.84623442377363, 0.6813175550528935, 0.40625851175614763, 0.5448105313948223, 0.3736645393073559, 0.7088152681078229, 1.9149597925799233, 3.6964711802346364, 7.530943138258798, 0.5846214837261609, 0.18202571757137775, 0.17827864363789558, 0.8583080406699861, 5.374155853475843, 22.123842511858257, 62.25725596291678, 84.83884579794747, 75.63583169664655, 87.49154295240129, 86.54100159236363, 80.40142045702252, 70.3727866581508, 70.12771674564907, 66.6174590247018, 64.06562886919293, 64.81816046578544, 73.07963807242257, 86.7391642161778, 93.38719367980957, 96.14074393681118, 88.60271971566337, 79.14316422598702, 82.59324359893799, 88.11902781895229, 92.2608698436192, 85.41906206948417, 82.68441091264997, 79.55523409162248, 77.32560580117362, 78.77158151354108, 81.12098285130092, 86.11303424835205, 89.52917861938477, 92.46967015947614, 43.81110886165074, 72.18022155761719, 64.22741072518485, 66.37466812133789, 92.55035264151437, 79.02061189923967, 75.81216308048793, 66.18579523903983, 73.3376385825021, 74.33371148790631, 70.28464875902448, 63.702849524361746, 77.68489715031215, 80.82573999677385, 86.9609020778111, 86.28609997885567, 86.8729795728411, 83.6928516115461, 84.07208429064069, 86.9438442502703, 83.54991327013288, 68.1859245300293, 68.00724465506417, 82.09229237692696, 87.18625300271171, 84.2299473626273, 89.4629761832101, 90.81790270124162, 99.39983817509243, 78.46877207074846, 32.849675927843364, 4.036156449999128, 1.4078309706279208, 2.184800684452057, 2.6093710107462744, 1.716746142932347, 1.2313741935150964, 1.152527664388929, 0.22404908761382103, 0.21862331804420265, 0.416182493524892, 0.524528793990612, 4.173632638795035, 17.73534291131156, 56.77228546142578, 64.09542274475098, 57.715798718588694, 94.24442073277065, 64.9549982888358, 21.147408689771378, 28.80058888026646, 48.81056356430054, 70.27014092036656, 84.06209972926548, 100.01658807482038, 70.24464797973633, 16.307418618883403, 1.680379597204072, 0.4455933224942003, 0.10559241859508411, 0.19594905259353773, 0.2347886956163815, 0.21513621801776545, 0.13369601592421532, 0.1230838910809585, 0.1458903487239565, 0.18505515929843697, 0.15292090789547988, 0.13807982711919717, 0.11294342949986458, 0.11319832117961985, 0.10277822174664054, 0.10416379704007081, 0.08948854343699557, 0.1152217872440815, 0.2045585491827556, 0.218777277639934, 0.10395858090903078, 0.15436630962150438, 0.08393037811453853, 0.07542902643659286, 0.106244117553745, 0.13966500705906323, 0.16742137766310147, 0.13615031779876777, 0.14386288608823503, 0.12147580379886286, 0.13920763374439307, 0.13669292868248054, 0.13515903241932392, 0.07173479681036302], [0.025953489488789012, 0.061084287241101265, 0.0544490290007421, 0.033546228493962965, 0.06036986450531653, 0.08528051352394478, 0.06092836667916604, 0.034798200242221355, 0.08058870849864823, 0.017520651188013808, 0.05959100129881075, 0.008626502373122742, 0.029150563292205334, 0.03878451205257859, 0.012773330971997763, 0.03823546526421394, 0.03485103437144842, 0.05690685925739152, 0.058925996268434186, 0.03183872904628515, 0.05370608065277338, 0.04573745360331876, 0.03981191245839, 0.04328794897134815, 0.006300854130781123, 0.04595889011397958, 2.7101526771272932, 38.467367444719585, 80.59241948808942, 104.91117709023612, 83.58026300157819, 73.36198507036481, 51.10066897528512, 19.63684252330235, 28.0446127142225, 78.47434452601841, 108.99116625104631, 50.31138835634504, 41.0049329485212, 25.79768862043108, 10.57367047241756, 0.13693072806511605, 0.09125629679432937, 0.03156815642224891, 0.020457303251272867, 0.04693748349589961, 0.31559065410069054, 0.36703381368092125, 1.6896401345729828, 2.2678212353161404, 0.45287495319332394, 0.2553443983197212, 0.9603448339870998, 12.939363598823547, 43.98695387159075, 80.35989802224296, 78.64636107853481, 79.12144415719169, 77.5689595086234, 77.22645500728062, 79.9687283379691, 75.27266325269426, 72.51553467341832, 62.55418028150286, 56.717356477464946, 61.12976482936314, 60.61677932739258, 60.70106097630092, 70.17144175938198, 78.93718487875802, 75.67958450317383, 73.56394141060966, 65.05023029872349, 67.73529216221401, 78.96644374302456, 80.35905729021344, 71.63334969111851, 73.11035605839321, 72.22612135750907, 71.45970031193325, 65.30342265537807, 69.6623125076294, 71.18567725590297, 73.53156975337437, 77.1405335835048, 76.05609348842076, 23.418915510177612, 33.74833161490304, 81.23849773406982, 72.15356131962368, 67.82516711098808, 60.674101965767996, 62.40723282950265, 62.189955711364746, 59.25501578194754, 55.09001888547625, 61.712788173130576, 72.26605265481132, 80.84597315107072, 80.71258163452148, 80.5068941116333, 79.23923696790422, 78.47997951507568, 74.62750216892788, 79.00850118909563, 74.89037336621965, 61.79867485591343, 58.51016194479806, 65.14638641902378, 76.6357261112758, 76.5175997870309, 73.25892938886369, 71.23926871163505, 70.67401191166469, 79.19851357596261, 86.64380019051688, 47.3946909223284, 9.803133487701416, 0.5680855310388974, 0.5216989229832376, 0.2805192417332104, 0.3928074778190681, 0.2185420295489686, 0.03242939038734351, 0.06768368490572486, 0.028309195136119212, 0.012779574342338102, 0.16266942050840172, 1.4013262625251497, 4.5386158653668, 19.543700184140885, 30.70119217463902, 42.97258635929653, 51.40790442058018, 51.44613340922764, 26.434741156441824, 10.623127749988011, 28.76512180055891, 43.66153151648385, 53.21893501281738, 62.94618374960763, 63.55658299582345, 18.880274023328507, 2.9102571053164343, 0.11099273631615297, 0.07627083055142846, 0.04444514634087682, 0.07254390910800014, 0.09411471376993827, 0.039332507111664326, 0.02830581772806389, 0.11679757625928947, 0.07130653264799289, 0.03913350636139512, 0.053722982960087914, 0.05094751349783369, 0.02019442691068564, 0.059125899470278194, 0.025778293443311538, 0.05403603526896664, 0.057257478657577715, 0.06666603165545634, 0.02501284996313708, 0.06285590824804135, 0.035652479223374806, 0.03673333122528025, 0.037200699360775094, 0.03693750241239156, 0.07070275861769915, 0.043332973162510564, 0.07383367525679724, 0.031415024639240334, 0.012962002722945596, 0.05796027130314282, 0.04743783861132605, 0.006463420519139618, 0.06855420462254967, 0.03090125827917031, 0.02640535479544529, 0.026036589672522883, 0.021778349864429662, 0.030399742868861983, 0.04410212653289948, 0.023510035692847202, 0.032181178884846826, 0.03932233587173479, 0.010917468146154923, 0.009308581889074827, 0.01718746335245669, 0.033714542498013804, 0.05368239978062255, 0.050161824229040315, 0.004169108296212341, 0.03210057231730648, 0.02334038327847208, 0.03949524016518678, 0.039704490186912675, 0.024287954039339508, 0.05394372397235461, 0.16353700895394596, 0.02880600660241076, 0.07868258149496146, 4.030709496566227, 46.85077551433018, 96.6103379385812, 118.59243719918388, 96.03118474142892, 86.94826330457414, 66.97281074523926, 41.526822566986084, 41.781206539699006, 63.0917763028826, 93.3887917654855, 40.80197606767927, 39.696389130183626, 32.23411069597517, 12.855960897036962, 0.013807315711996384, 0.07049431944532053, 0.05109524753476892, 0.09624990062522036, 0.04249035819832768, 0.7223395024027143, 0.35757145285606384, 2.7116801951612746, 1.7406304670231683, 0.3373796349125249, 0.4498395403581006, 1.3854458289487022, 15.215599536895752, 46.98675523485456, 87.18111828395298, 81.05087552751813, 81.61280414036342, 78.98382813589913, 79.18401963370187, 81.56122766222272, 78.48498221806118, 76.16173389979771, 65.91731684548515, 59.70653057098389, 64.15188380650112, 63.33225345611572, 63.18757806505476, 71.71056502205985, 81.06839193616594, 77.97599193028041, 75.22362981523786, 67.94975525992257, 72.46056052616665, 81.7675335747855, 82.50664125170026, 76.26298999786377, 75.4849168232509, 75.95703996930803, 75.48013646262032, 69.58192879813058, 73.03605897086007, 73.17213944026402, 77.10966273716518, 80.18668637956891, 79.02755314963204, 29.533113139016287, 39.85533612115042, 82.62584454672677, 75.66778646196637, 70.79443808964321, 63.126843861171174, 65.531740461077, 64.30297238486153, 62.441577775137766, 59.36386626107352, 65.35055923461914, 75.50503880637032, 83.69284466334751, 83.02135685511998, 82.47553416660854, 81.67156505584717, 81.18165452139718, 76.47584806169782, 82.04546151842389, 77.36389037540981, 64.15255778176444, 62.36736406598772, 67.56388705117362, 78.85602297101701, 79.62770380292619, 76.07331807272774, 75.43586948939732, 74.14304597037179, 82.1640464237758, 89.95568684169224, 56.07667350769043, 13.167570233345032, 0.8466743677854538, 0.4647405222058296, 0.3918332915220942, 0.3857573632683073, 0.2188916786440781, 0.12625558088932717, 0.07393421379051038, 0.10750735976866313, 0.04994500854185649, 0.09098887257277966, 0.6208058563726289, 5.634670742920466, 21.884298154285975, 33.52488797051566, 37.57157441547939, 42.13429314749581, 39.99497059413365, 22.459859132766724, 22.3404369694846, 47.99731860842024, 53.170144762311665, 63.93348108019148, 76.66581875937325, 86.54106412615094, 34.96731662750244, 4.354125993592398, 0.1286689806729555, 0.07970937461193119, 0.07772854090269123, 0.042176060777689726, 0.02925581085894789, 0.019922210535566722, 0.0442472041052367, 0.05290380459544914, 0.05587639526597091, 0.041237646846898963, 0.04679653820182596, 0.05025589293135064, 0.09622525623334305, 0.001886216241733304, 0.02560352996390845, 0.017931694131610647, 0.02445473285791065, 0.03480851397450481, 0.05838918685913086, 0.07109636321131672, 0.030668296851217747, 0.026058404573372433, 0.046308057449225865, 0.07840419214751039, 0.030404591001570225, 0.01824750468534018, 0.05287907199401941, 0.020598226492958407, 0.030450687278062105, 0.08088311127253942, 0.03069998782926372, 0.07065673358738422, 0.1751978096685239, 0.12042073612766606, 0.15837383243654454, 0.2052050166364227, 0.1375068450080497, 0.12945746550602572, 0.1385613019977297, 0.0759211407442178, 0.2208698932081461, 0.05507392243349126, 0.12328376035605158, 0.09158900287002325, 0.057177506520279815, 0.08125764224678278, 0.18183891688074383, 0.12825168163648673, 0.16667380849165575, 0.16360814656530107, 0.20231907149510725, 0.13186023943126202, 0.15513844176062516, 0.14492762966879777, 0.13373496383428574, 0.19828553364745208, 0.08710819509412561, 0.27024842000433374, 5.584447860717773, 61.63446807861328, 111.823821749006, 129.51708984375, 108.42620127541679, 98.48011902400425, 74.86258057185582, 33.416367530822754, 40.96921920776367, 102.17974989754813, 128.9647775377546, 67.97763838086809, 61.34795910971505, 41.45613854272025, 17.660238095692225, 0.2576105152922017, 0.13485580869019032, 0.19612154976597854, 0.19974731520882674, 0.1969540443803583, 2.284179683242525, 2.073329431670053, 3.860096045902797, 4.067244861807142, 1.5412711245673043, 0.6984147376247815, 1.8683747266020094, 18.529259715761455, 52.434615407671245, 93.90728024074009, 85.84400694710868, 86.678756577628, 81.75783388955253, 81.02350657326835, 83.9803055354527, 82.22552408490861, 80.10971423557827, 70.16682815551758, 63.40391717638288, 67.17544106074742, 64.89577879224504, 68.36673750196184, 76.82991436549595, 86.52900205339704, 83.67108985355922, 80.93388870784214, 73.34610148838588, 77.54516887664795, 87.40216132572719, 88.80008329663957, 81.87519591195243, 81.80928530011857, 80.70839881896973, 78.83965996333531, 71.94867283957345, 77.57508087158203, 77.32869774954659, 79.60591425214494, 86.26905604771206, 82.16718700953892, 35.56927381243025, 47.72621379579817, 86.38395145961216, 80.17057350703648, 74.35721029554094, 67.98988805498395, 69.10987513405937, 69.49424253191266, 64.34371662139893, 62.68527889251709, 68.17243807656425, 78.7242990221296, 87.6074528012957, 86.97273486001151, 85.75188078199113, 83.09866251264299, 85.99222591945103, 79.6798986707415, 85.58265740530831, 81.35339314596993, 66.91661371503557, 65.63970851898193, 71.24577917371477, 84.81257465907505, 84.66651657649449, 81.20658465794155, 79.83633041381836, 76.65009498596191, 86.13894408089774, 98.85001332419259, 62.28887721470424, 13.48509248665401, 1.564865904194968, 1.2063653469085693, 1.1390249260834284, 1.1363313049077988, 1.1154240667819977, 0.32956182584166527, 0.36744310600417, 0.3031032755970955, 0.1350217376436506, 0.44181480524795397, 2.008947206395013, 9.812839252608162, 31.469482285635813, 48.143859590802876, 60.29568917410714, 65.23536505017961, 69.56671919141496, 37.99590785162789, 16.107282706669398, 45.60267407553536, 63.11619922092983, 72.93494878496442, 91.00925609043666, 99.90845326014927, 38.64407403128487, 5.837444365024567, 0.3649100533553532, 0.2073550091258117, 0.1298440269061497, 0.14009077421256474, 0.16258781988705906, 0.11186715082398482, 0.11618582265717642, 0.1506370540176119, 0.1501641422510147, 0.17296519875526428, 0.151616668594735, 0.1687339222324746, 0.18952610796051367, 0.10259124463690178, 0.13085763608770712, 0.11793317246649947, 0.12442261353135109, 0.08350891965840544, 0.1004405871831945, 0.15561904811433383, 0.10929627663322858, 0.1943906612162079, 0.12233113790197031, 0.20567252726427146, 0.14931087089436396, 0.1058538377817188, 0.17621420084365777, 0.07437008433043957, 0.0979378582643611, 0.14229796720402582, 0.1490665032927479, 0.1673452460340091], [0.03268660944221275, 0.019197170423077684, 0.06170249371124165, 0.011028567229264548, 0.010616382650498832, 0.020040769263037612, 0.05218424195689814, 0.01911693365712251, 0.08812445056225572, 0.047885800645287545, 0.060924879009170194, 0.050909885338374546, 0.039406979722636085, 0.04369465607617583, 0.02405093327563788, 0.0755808147202645, 0.05300348138968859, 0.12419572499181543, 0.0037564177847733454, 0.02269880466961435, 0.03534742005701576, 0.0360702735904072, 0.007896252808028033, 0.06173114824507918, 0.06567580479064158, 3.547293790749141, 54.804044927869526, 88.95517403738839, 93.68462521689278, 82.76168877737862, 62.99835777282715, 47.83027001789638, 31.14649874823434, 31.203199522835867, 45.4183418410165, 69.2659525190081, 52.183851446424214, 55.92084278379168, 36.900757108415874, 14.47087858404432, 0.6282376061592783, 0.008765044805061604, 0.12747281842998096, 0.08346385136246681, 0.20375729432063444, 0.033302583532141786, 0.03954372827761939, 0.07652308951531138, 2.48362164412226, 0.8329334908298084, 0.3290887783680643, 1.3943885947976793, 17.808170454842703, 54.36924403054373, 75.212297303336, 71.24694647107805, 73.3729076385498, 78.93131365094865, 75.62445749555314, 76.3036230632237, 79.32044056483677, 78.16155052185059, 73.28784084320068, 72.94035448346818, 64.65437058040074, 58.489289556230815, 57.46395778656006, 57.01295716421944, 56.15391315732683, 61.749078614371165, 62.412694113595144, 60.15600953783308, 56.513868059430806, 60.06654453277588, 64.049439566476, 75.21417331695557, 70.15646839141846, 75.47969872610909, 74.071715763637, 75.60875456673759, 66.44403198787144, 64.70746871403286, 56.4335503578186, 69.38682338169643, 66.41134071350098, 90.33739307948521, 46.244625091552734, 34.64640017918178, 86.19657244001115, 65.3832574571882, 76.04296834128243, 63.76589747837612, 62.48492758614676, 59.226868629455566, 64.26444462367466, 58.56284318651472, 62.03551810128348, 70.54566478729248, 82.07794434683663, 73.30954006740025, 79.06499004364014, 75.05683830806187, 78.08691297258649, 75.35163647787911, 78.85776002066476, 70.00270475660051, 60.01570456368582, 56.80798877988543, 58.405605452401296, 59.21617535182408, 60.35999475206648, 59.31290817260742, 60.86196041107178, 67.57800579071045, 75.3069178717477, 76.31609507969448, 69.70414761134556, 55.90282957894461, 23.08509452002389, 1.0438737975699561, 0.11950148402580194, 0.09698666751916919, 0.4574783518910408, 0.10879771624292646, 0.10535424601818834, 0.030245070811361074, 0.13901666684874467, 0.02724351517723075, 0.15417914252196038, 1.31930864070143, 8.949001857212611, 23.262266635894775, 35.61931126458304, 34.383546352386475, 46.56794214248657, 78.27317333221436, 39.761104651859824, 14.937980788094656, 33.860280990600586, 41.787122930799214, 40.67597048623221, 54.58271353585379, 63.278418813432964, 30.14642368044172, 7.09605929681233, 0.38503656908869743, 0.07897304198039429, 0.0120671431068331, 0.06264169474265405, 0.055909992927419286, 0.054687808866479566, 0.05723951105028391, 0.01664496273068445, 0.07492423030946936, 0.012596156996940928, 0.017075282854161093, 0.05966293279613767, 0.014584837115502782, 0.02962932063798819, 0.027675032915015305, 0.07999601494520903, 0.009647689094500882, 0.04427184849711401, 0.04457352177373, 0.021666074371231452, 0.0950987795367837, 0.030627879912831953, 0.09999207553586789, 0.018196266809744493, 0.038920863664575985, 0.021449521616367356, 0.049190504742520194, 0.039296137634664774, 0.05116265320352145, 0.026825507071667483, 0.037076256038354974, 0.06193573333855186, 0.07736143310155187, 0.030753934755921364, 0.011195241723076572, 0.023980915247063552, 0.018412497260474732, 0.056941437401941845, 0.02686790024329509, 0.04514038689168436, 0.022180585423484445, 0.010204181956526424, 0.029922054215733494, 0.024118481436744332, 0.015064362902194262, 0.03285087937755244, 0.02657101403123566, 0.051762220316699574, 0.03692832522626434, 0.03368374040084226, 0.04599784480940018, 0.037349705650870285, 0.017633776546322873, 0.0798466761729547, 0.07478215864726476, 0.05640995449253491, 4.556552640029362, 65.45121083940778, 103.83112130846295, 107.68243830544608, 93.8487833568028, 78.25286374773297, 70.52164486476353, 47.69140679495675, 31.128384794507706, 41.1355173928397, 69.87549713679722, 61.886479241507395, 51.22154678617205, 45.74236066000802, 19.114463056836808, 0.7679331472941807, 0.08281008965734925, 0.13074533854212078, 0.034910538499908786, 0.1744662539235183, 0.08202961153749909, 0.05226916739983218, 0.3225659398095948, 2.1626932535852705, 2.382148197719029, 0.1488102206162044, 2.128294676542282, 19.300127608435496, 59.616593088422505, 81.87864221845354, 75.93245029449463, 76.50794873918805, 82.19420855385917, 77.99226461138043, 77.00061076028007, 81.52014296395438, 83.51291411263603, 78.47717244284493, 78.40197903769356, 66.0016679763794, 61.04754679543631, 59.322427204677034, 59.990135192871094, 59.072743688310894, 65.01554489135742, 65.19230706351144, 63.93688569750105, 58.60235064370291, 60.43234634399414, 68.16317612784249, 77.69118527003697, 73.75939423697335, 79.20663602011544, 76.2904840196882, 80.06031254359654, 70.08044815063477, 67.68927424294608, 59.03044305528913, 70.80299132210868, 69.31512492043632, 91.49592876434326, 50.863916056496755, 37.51636055537632, 90.81435217176164, 71.51869746616909, 79.73858315604073, 66.51606396266392, 64.062502179827, 60.85444940839495, 66.2281653540475, 58.98161806379046, 63.613391467503135, 73.92453207288469, 84.4677425112043, 74.49331160954067, 81.1771798815046, 77.3507443836757, 80.14669949667794, 81.02375670841762, 81.42230537959507, 73.23226915087018, 61.60067898886544, 60.13303879329136, 60.907234873090474, 62.13505104609898, 62.773701667785645, 61.07889011928013, 64.97115285055978, 70.67724977220807, 77.79788875579834, 75.39324229104179, 68.6267807824271, 62.86798177446638, 28.183145897729055, 2.0282488678182875, 0.22613053449562617, 0.2816072047821113, 0.6498278847762516, 0.12581214468394006, 0.13390690460801125, 0.023059770032497387, 0.2732909438865525, 0.05036595131137541, 0.2486606112548283, 1.2154344831194197, 10.838981355939593, 27.492557491574967, 38.64246552331107, 33.13477093832833, 40.54135261263166, 60.088674545288086, 26.807190656661987, 23.582260710852488, 58.98351492200579, 58.703641482761924, 53.37071146283831, 63.773575237819124, 83.09480626242501, 49.75567838123867, 10.938370125634329, 0.6651348748377391, 0.1102667377729501, 0.05916779900767973, 0.15536641595619066, 0.02777314738237432, 0.03890643801007952, 0.022580943136875118, 0.018212327733635902, 0.04653579755020993, 0.027644824535985078, 0.0729943477947797, 0.09490247257053852, 0.030622390564531088, 0.06243154566202845, 0.011141750263050199, 0.036721154914370606, 0.04138694829972727, 0.04894473257341555, 0.03593903134710022, 0.02748730602408094, 0.05345693616462605, 0.029535343537905386, 0.06866722820060593, 0.013452323153614998, 0.009930885014390307, 0.009840704317736839, 0.03777629043906927, 0.024188745434262922, 0.026779147862855877, 0.0495764147490263, 0.08259118068963289, 0.12925512636346476, 0.2651028446853161, 0.14755833707749844, 0.061789244413375854, 0.18775720787899836, 0.10967905180794851, 0.11334398229207311, 0.0850925457530788, 0.11182866431772709, 0.11932658483939511, 0.23974311404994555, 0.15739086589642934, 0.14741093213004725, 0.10153161042502948, 0.0847941939053791, 0.1666443600718464, 0.1817700591470514, 0.18350020130830152, 0.11409965317164149, 0.17642762724842342, 0.09530388710222074, 0.12328912078269891, 0.11071418412029743, 0.13900044986179896, 0.17479931962277206, 5.781682465757642, 85.96082006181989, 120.23656163896833, 119.09487533569336, 108.54940673283168, 89.61497497558594, 73.61405876704625, 46.36624983378819, 46.49575730732509, 61.394734382629395, 87.02333164215088, 64.63307435171944, 81.63205759865897, 60.00216947283064, 26.949359485081263, 1.2669472332511629, 0.22246416551726206, 0.2883083080606801, 0.2475294390959399, 0.6184318523321832, 0.2951234323637826, 0.20626817244504178, 2.2068913962159837, 5.020228947911944, 5.315913447311946, 0.8579838094966752, 2.3835853891713277, 21.976665769304546, 69.28942353384835, 86.14678859710693, 79.51097406659807, 82.6554925101144, 88.21596213749477, 79.12237521580288, 79.93891361781529, 83.81818321772984, 85.09188529423305, 80.23823506491524, 82.34041949680874, 72.03895773206438, 62.537414278302876, 62.404460498264854, 63.44508525303432, 61.691186223711284, 67.94648960658482, 68.9997809273856, 65.9127310344151, 62.57453850337437, 64.1933228628976, 72.92317158835274, 82.06960650852749, 78.13309070042202, 82.57064805712018, 80.64872074127197, 84.45019136156354, 72.44880417415074, 70.5710951941354, 61.79772990090506, 74.25903919764927, 74.41893809182304, 94.43786552974156, 55.71980707986014, 41.75148562022618, 91.21502699170793, 75.43580695561, 83.20285769871303, 72.05574457986015, 66.69523021153041, 64.22816807883126, 69.9677483694894, 63.16839408874512, 66.79834842681885, 78.02431665148053, 88.98418971470424, 78.82325526646206, 87.40302290235246, 83.15952178410122, 87.25338649749756, 83.75624697549003, 84.23830604553223, 78.09583445957729, 65.66383961268834, 63.507584299360005, 63.00324930463518, 65.39192880902971, 65.68141855512346, 65.53805637359619, 68.93535028185163, 76.48278931209019, 83.37823023114885, 76.4497297831944, 69.6048231124878, 66.94751930236816, 29.771901879991802, 2.311475464275905, 0.40156850484865053, 0.6283548027276993, 1.0472380284752165, 0.3449211173823902, 0.39297960858259884, 0.23640208904232296, 0.5578280357377869, 0.19057611376047134, 0.4031498985631125, 2.3046592814581732, 17.71335186277117, 38.6463634627206, 53.30692005157471, 50.519358362470356, 61.684661865234375, 92.65236609322685, 51.87497622626168, 21.24067783355713, 49.62071657180786, 61.9956910269601, 65.51596110207694, 79.22390924181256, 100.50114849635533, 60.0503830228533, 12.511684605053492, 0.8465006085378783, 0.20275000908545085, 0.17772604471870831, 0.23916654927389963, 0.0979263638811452, 0.1511751322874001, 0.16236813738942146, 0.08090662929628577, 0.15301347364272389, 0.14893595315515995, 0.1100088469684124, 0.19245025462337903, 0.09926359355449677, 0.11507746284561497, 0.23353940408144677, 0.16684751345642976, 0.16948326916566916, 0.1304162083459752, 0.17340934063707078, 0.1664421566362892, 0.14743122032710484, 0.12741739568965776, 0.17957297632736818, 0.1631704100540706, 0.1483272122485297, 0.1361248455941677, 0.11013106469597135, 0.13601222235177243, 0.11649758235684463, 0.1186274630682809, 0.13945847457008703], [0.011770323051937988, 0.003155161331440987, 0.045352551221315346, 0.06340508735073463, 0.08746747938649994, 0.06229173352143594, 0.031391489652118514, 0.012040521633545203, 0.01092945785993444, 0.042032740611050806, 0.027170452222760235, 0.01523695167686258, 0.06392808857240848, 0.0466479661741427, 0.03946977135326181, 0.057413480643715174, 0.05298267750601683, 0.03163624741137028, 0.018030135992116163, 0.02213292512377458, 0.03465170792437025, 0.03246702193947775, 0.04261777011145439, 0.08256985433399677, 0.295918838254043, 32.83941343852452, 90.17588915143693, 88.47759655543736, 88.92435182843889, 75.65156936645508, 44.961365767887656, 21.000931978225708, 21.774245636803762, 54.15589959280831, 70.22909791128976, 51.67241191864014, 41.40401315689087, 32.93389851706368, 11.223268849509102, 0.6606343963316509, 0.030515996273607016, 0.03317112076495375, 0.023139589499416094, 0.01932126938897584, 0.03276379280058401, 0.1799203726862158, 0.027588828433571116, 0.1263727503163474, 0.20512896643153258, 0.6469240805932454, 4.075372082846505, 21.29363352911813, 49.242321150643484, 70.28490584237235, 71.60434096200126, 72.24786227090019, 71.32862949371338, 73.32069192613874, 79.82996586390904, 72.76084082467216, 73.23301955631801, 75.24524566105434, 77.69322109222412, 74.50205939156669, 69.88892105647496, 59.61564118521554, 57.49294567108154, 56.991143294743125, 55.69659314836775, 56.13675110680716, 54.700429916381836, 56.95264332635062, 56.152183055877686, 54.88303899765015, 56.0747731753758, 65.53371374947685, 71.59343229021344, 78.60055160522461, 74.43268857683454, 76.54876245771135, 70.26417241777692, 67.7299976348877, 58.77290807451521, 60.080732754298616, 61.04731750488281, 78.05579893929618, 63.900199208940776, 30.001265389578684, 81.93763937268938, 71.39258766174316, 79.50404671260289, 70.36228793007987, 64.23355988093785, 62.26359966823033, 60.58900042942592, 55.61488580703735, 60.45594937460763, 66.66154534476144, 75.56302152361188, 76.69055434635708, 77.4497423171997, 66.99246719905308, 69.3096705845424, 70.23925617762974, 70.55876214163644, 59.255182538713726, 57.462884289877756, 56.4582268851144, 57.702937602996826, 55.92991018295288, 56.554184981754844, 61.90839385986328, 69.02969987051827, 68.3081224986485, 74.18076079232353, 73.88222449166435, 70.88469518933977, 77.69583361489433, 81.17243426186698, 54.67430121558053, 5.119708912713187, 0.40510429654802593, 0.13995005962039742, 0.09005408201898847, 0.07893144099840096, 0.06829335540533066, 0.07910488133451768, 0.0703101921826601, 0.37874872077788624, 0.07087999874992029, 0.8612660733716828, 7.833783847945077, 20.69843520436968, 34.56266048976353, 38.60959012167794, 37.70263828550066, 73.59463855198452, 31.546708038875035, 8.290137188775198, 15.310062033789498, 35.049291474478586, 54.66882603509085, 55.84378726141793, 55.940304688044954, 40.57108742850167, 19.497456448418752, 0.5304709151387215, 0.026588627103982226, 0.03455643821507692, 0.0524058107818876, 0.045438867661037614, 0.02983279971938048, 0.07249531921531473, 0.029828681011817286, 0.043216387275606394, 0.017961590384532298, 0.038342799326138835, 0.042192783273224316, 0.06980113485561949, 0.03102876857987472, 0.012231675974492515, 0.042075108337615214, 0.03333202516660094, 0.0988455345588071, 0.03263413493654557, 0.05419829334797604, 0.028860479393707852, 0.025836084270849824, 0.04194356414622494, 0.04887078243440815, 0.018004926719835827, 0.09073388589812176, 0.03870908609990563, 0.060983769063438685, 0.035353832212941985, 0.04200328540589128, 0.04480974016977208, 0.03577205744971122, 0.02868847076648048, 0.06357184411691767, 0.022383918619847724, 0.05246252952409642, 0.057572047492223125, 0.028220702295324633, 0.01036037562880665, 0.05350759219644325, 0.015437906607985497, 0.0036917822352344437, 0.012316413972127651, 0.05908715512071337, 0.04071517488253968, 0.02310646341980568, 0.018064532628548995, 0.07656463621450321, 0.006135405240846532, 0.048694587246115716, 0.039084220970315595, 0.012588464954335774, 0.06804520836366074, 0.09460727591067553, 0.42687655825700077, 44.09593289239066, 105.46592821393693, 102.07014901297433, 100.46161324637276, 85.76435279846191, 63.676258768354145, 41.40698003768921, 37.9537809235709, 58.0635039465768, 48.13001877920968, 44.51527752195086, 43.23532901491438, 43.31745672225952, 13.195236223084585, 0.6767715332763535, 0.03704520288322653, 0.05865629895457199, 0.08522671926766634, 0.15676408952900342, 0.05388787714764476, 0.19838018928255352, 0.1917073537728616, 0.33749558297651155, 0.23714758189661161, 1.433347035731588, 5.797548242977687, 22.47953122002738, 54.81460966382708, 76.47978769029889, 77.55098451886857, 77.34907681601388, 74.72763265882219, 76.30037130628313, 81.66945975167411, 75.79001917157854, 74.95676340375627, 76.58881882258824, 81.03832013266427, 77.98401015145438, 74.88788591112409, 63.881633622305735, 61.68142400469099, 58.37130914415632, 57.728173460279194, 58.332183837890625, 55.973725523267476, 59.36103139604841, 57.24806335994175, 57.87218529837472, 58.74850600106375, 67.93874931335449, 74.07201453617641, 80.79662704467773, 78.5582857131958, 78.88341276986259, 75.43309715815953, 70.98579842703683, 62.14559146336147, 63.606054169791086, 63.5712228502546, 79.47343989780971, 66.35596357073102, 32.19149391991751, 82.03437914167131, 76.18096651349748, 82.17332226889474, 74.10663740975517, 67.33661842346191, 65.03676468985421, 62.907294682094026, 60.23038305555071, 62.28586169651577, 69.29605906350272, 76.35635294233049, 78.36739090510777, 79.21689850943429, 68.74866608210972, 71.11373560769218, 73.54902362823486, 73.70197432381767, 59.694093295506065, 60.362468310764854, 60.0084228515625, 60.62578419276646, 58.09731388092041, 60.189208030700684, 65.76022502354213, 72.3617501940046, 72.56360231127057, 78.84425272260393, 74.99811908176967, 73.54865537370954, 80.65379987444196, 85.70090879712785, 60.96350833347866, 6.2449279853275845, 0.5469434655138424, 0.21184746734797955, 0.12184840094830308, 0.20523043455822126, 0.11569472615207944, 0.0955037156652127, 0.13446205481886864, 0.028785911787833487, 0.22241698019206524, 0.4430688465280192, 7.420054231371198, 24.954924242837087, 37.94746501105172, 37.100757530757356, 37.376354353768484, 50.638704095567974, 28.467718056270055, 17.258891037532262, 31.47019100189209, 53.78163834980556, 68.71773270198277, 69.48056152888707, 71.89982005528041, 59.19777652195522, 28.60483033316476, 0.8582674914172718, 0.06291966339839355, 0.0950244731668915, 0.03119363562603082, 0.02856111652883036, 0.040845423072044335, 0.05973727987813098, 0.050093356652983596, 0.0791502549712147, 0.00796012585383973, 0.015061136468180587, 0.02165647310071758, 0.07159322726407222, 0.055452612827398946, 0.02533025337782289, 0.05496741279161402, 0.01313700114509889, 0.03357305437592523, 0.02854895718129618, 0.01089761421150927, 0.021682630625686476, 0.08175299316644669, 0.034853215861533365, 0.13660291422690662, 0.011982645989129586, 0.01828800474426576, 0.0114942127339808, 0.04946394417701023, 0.012082003023741501, 0.07481177670082875, 0.13617356440850667, 0.07213786696749074, 0.09706986269780568, 0.17338245707963193, 0.1324176016662802, 0.10178922303020954, 0.11826653672116143, 0.10295514975275312, 0.10919227078557014, 0.1473073876862015, 0.072400799287217, 0.2403086322758879, 0.1391032072050231, 0.12831093131431512, 0.1542301954967635, 0.09673598954187972, 0.09142278214650494, 0.18035291161920342, 0.12371733066226755, 0.10510818207902567, 0.09893737427358117, 0.1165889131703547, 0.09115383122116327, 0.21296082117727824, 0.6429765809859548, 60.778915541512625, 117.41617665972028, 111.3298534665789, 113.86671025412423, 100.5398291179112, 66.68554442269462, 36.00300816127232, 33.34750393458775, 75.87739276885986, 90.48791190556118, 71.75265720912388, 65.88580676487514, 51.18690306799752, 18.429926531655447, 1.6092882347958428, 0.19379393037940773, 0.137403666973114, 0.14331198350659438, 0.29366832758699146, 0.22373966207461699, 0.45895831819091526, 0.4146684376256806, 0.6649011330945152, 2.579356747014182, 2.5792232113225118, 7.107526430061885, 24.70994118281773, 64.85650757380894, 81.23159122467041, 82.43305982862199, 82.38406808035714, 78.28748662131173, 80.21726540156773, 86.43465246473039, 78.70574038369315, 74.86542933327812, 76.98519965580532, 84.85240173339844, 80.88552924564907, 79.02685138157436, 67.34472697121757, 65.30963434491838, 61.14343888419015, 61.122712407793315, 61.276955468314036, 60.191111837114605, 63.157082421439036, 62.28339508601597, 60.498826708112446, 62.69120570591518, 71.99841499328613, 79.10156536102295, 85.44301945822579, 82.78867558070591, 83.3246248790196, 80.2446482522147, 74.83125809260777, 66.20169271741594, 65.26625674111503, 67.95577934810093, 83.61342675345284, 71.83891214643205, 37.0698241506304, 84.39511299133301, 79.7628949029105, 86.11753668103898, 78.99296501704625, 69.83769198826381, 68.91440841129848, 66.86074325016567, 62.96495083400181, 66.79985618591309, 73.7948717389788, 80.20378589630127, 82.40244606563023, 84.21140262058803, 72.73041466304234, 75.8052009854998, 76.51540415627616, 78.8880124773298, 65.10323115757534, 62.94199398585728, 63.323790550231934, 64.52823298318046, 60.885778835841585, 65.58636025020054, 70.48119940076555, 77.37222821371896, 74.45356096540178, 81.2531167439052, 77.53401006971086, 76.26514393942696, 83.66785199301583, 90.8641916002546, 65.38736384255546, 7.5575825316565375, 0.7931229727608817, 0.9162189960479736, 0.2591231055557728, 0.3446741577770029, 0.21670379675924778, 0.251568432365145, 0.5053036713174411, 0.5654983041541917, 0.25509616306849886, 1.457281734262194, 13.936425754002162, 35.36989525386265, 51.52846261433193, 55.676825523376465, 53.44630438940865, 92.01060962677002, 43.85268688201904, 13.938388620104108, 25.17629384994507, 54.55101237978254, 78.6026360648019, 81.18899181910923, 89.03643321990967, 69.46733215876988, 32.88503531047276, 1.4604291596582957, 0.14265803859702178, 0.24326913484505244, 0.1292560627417905, 0.18597624344485147, 0.14750862760203226, 0.16653248321797165, 0.11590657835560185, 0.15340114784027847, 0.07547446114144155, 0.11219432005392653, 0.09354870021343231, 0.13240370526909828, 0.16728040522762708, 0.1341840047389269, 0.13341981145952428, 0.07796146840389286, 0.11384227126836777, 0.08373956728194441, 0.15559470227786473, 0.08771584355937583, 0.16172829243753636, 0.08977161467607532, 0.20367486588656902, 0.16771263203450612, 0.17760618829301425, 0.11324133351445198, 0.1359378413430282, 0.1374051190380539, 0.18614590434091433], [0.04860471867557083, 0.04169394468356456, 0.04999922009717141, 0.021106917411088943, 0.07106708442526204, 0.024762404384091496, 0.08276523170726639, 0.05087189416268042, 0.003752830879031015, 0.017844895932025144, 0.052347748540341854, 0.039777073077857494, 0.06416863602186952, 0.016822850863848413, 0.014887892907219273, 0.0063716215164666724, 0.03124172001012734, 0.029170288305197443, 0.02308359000432704, 0.03938108343364937, 0.01902095657507224, 0.0455413400195539, 0.06441470674638237, 0.1185083801725081, 19.713891097477504, 97.92127541133335, 96.59109837668282, 103.97032151903424, 76.09548282623291, 59.500210762023926, 29.08503770828247, 26.88537178720747, 42.43721376146589, 43.901265212467735, 65.71932792663574, 49.713603564671104, 35.321045943668906, 12.71465972491673, 0.17946637847593852, 0.09789012332579919, 0.07651960184531552, 0.14723808211939676, 0.08265008431460176, 0.15114682380642208, 0.1261360365897417, 0.05697347104017224, 0.06625830674810068, 0.10854046326130629, 0.07220844139478036, 1.8846474077020372, 19.782200574874878, 43.29674414225987, 68.20158576965332, 68.84485694340297, 69.96297495705741, 62.357018198285786, 63.023753438677105, 74.59287234715053, 76.45241873604911, 75.60075719015938, 77.32989978790283, 72.42718138013566, 70.88427134922573, 76.39551298958915, 72.95798901149205, 62.90573828560965, 58.40596675872803, 60.39095592498779, 57.58233424595424, 60.395896094185964, 57.50811358860561, 57.71815068381173, 55.69312947137015, 53.5671683038984, 55.71348074504307, 58.01375484466553, 60.006539889744346, 67.98060526166643, 73.74134976523263, 75.14629636492047, 73.98093060084751, 65.43142931801933, 57.0352852003915, 65.16265910012382, 67.31397424425397, 71.68336977277482, 70.80613190787179, 20.501978363309586, 64.76379776000977, 77.67842837742397, 76.26551219395229, 69.14739540645054, 58.61297443934849, 60.04702704293387, 58.74225262233189, 55.51513399396624, 56.720861843654085, 60.18324647630964, 70.87853908538818, 73.96216351645333, 73.49920504433769, 61.74279744284493, 52.433138915470664, 57.11424800327846, 54.25591196332659, 54.77800307955061, 58.77133778163365, 54.728632654462544, 54.75960424968174, 54.77080821990967, 62.23755781991141, 70.63522011893136, 72.11358833312988, 74.29830346788678, 74.74967234475272, 67.19881480080741, 75.82961000714982, 72.04172311510358, 68.45887756347656, 77.30487237657819, 74.73977810995919, 8.873517496245247, 0.5924382071409906, 0.048635340960962434, 0.268257951097829, 0.0507883156117584, 0.17111217390213693, 0.053353561354534965, 0.06387833838484117, 0.218194307493312, 0.09051224921963044, 0.1463502190474953, 1.4100058653524943, 9.484539474759783, 25.17391582897731, 36.31573615755354, 28.765107904161724, 53.49390302385603, 63.725778579711914, 15.838331835610525, 19.33028105327061, 32.27194363730294, 52.34800958633423, 51.78278752735683, 66.83297824859619, 58.36260305132185, 14.608762979507446, 0.38447018233793123, 0.06707828239138637, 0.0657910607489092, 0.0425243324467114, 0.03205167029851249, 0.03142762842721172, 0.04018169368750282, 0.050832939467259815, 0.034244756546935866, 0.01590670645236969, 0.024666401856978024, 0.009977126327742423, 0.010063648872476603, 0.043772996336753876, 0.037414417535598786, 0.03604867921343871, 0.0033507414170474347, 0.03650728067649262, 0.05874207935162953, 0.03334208105557731, 0.04839146190455981, 0.06077522811080728, 0.026297679769673517, 0.07779205178043672, 0.04969889031989234, 0.04340177322072642, 0.04270950126062546, 0.047840416830565245, 0.05033368018588849, 0.0188063817497875, 0.04202801461464592, 0.03545301367661782, 0.015118925599381328, 0.04140458342486194, 0.059129583915429454, 0.013248112950740116, 0.026991676905059388, 0.03540387077789221, 0.0257602155740772, 0.021943720722837106, 0.014681563978748662, 0.01600951638205775, 0.002330993613993217, 0.014334523850785834, 0.017295867803373506, 0.06749598854886633, 0.045397002050387006, 0.04818072249846799, 0.06205832426037107, 0.03340059791558555, 0.05086600447871855, 0.09838325543595211, 0.1308772186083453, 27.582486288888113, 116.3767192023141, 107.88505472455705, 118.73072024754116, 87.87300600324357, 78.1901354108538, 43.30043363571167, 35.49754408427647, 40.50606618608747, 34.86202710015433, 55.25470161437988, 48.44767304829189, 43.536460467747276, 14.616604021617345, 0.3692058042756149, 0.09177237695881299, 0.07548531770173993, 0.09769024726535593, 0.04937633852075253, 0.3436038909213883, 0.3176204780382769, 0.05685836096693363, 0.07772203375186239, 0.05574297831792917, 0.7363342600209373, 2.0757602155208588, 21.746539694922312, 47.79170751571655, 74.37109279632568, 75.93351336887905, 77.3114036832537, 66.61265781947544, 67.13154234204973, 78.64066355569022, 78.47738783700126, 78.67875358036586, 78.97413539886475, 73.58231244768415, 71.46461268833706, 79.30593967437744, 76.53071103777204, 66.45631640298026, 59.526217869349885, 61.613435881478445, 60.18541431427002, 62.77192987714495, 60.76183686937605, 60.37286976405552, 58.551406451633994, 56.2122015953064, 59.330619130815776, 60.39499977656773, 62.06126117706299, 71.25592354365757, 76.54233537401471, 79.56922776358468, 75.97221483503068, 67.72976834433419, 59.682149342128206, 66.92133849007743, 71.54603167942592, 77.71380165645054, 74.73055090223039, 23.21335652896336, 68.76210389818463, 79.08713395254952, 78.64365128108433, 72.01903029850551, 62.095147541591096, 61.4661340713501, 60.64998476845877, 57.84985726220267, 57.53384624208723, 63.019612312316895, 74.16393225533622, 76.12075342450822, 77.07235091073173, 65.07311766488212, 56.6350759097508, 60.438815116882324, 56.65734141213553, 56.79004505702427, 61.661774499075754, 56.97334895815168, 58.14855684552874, 58.046963759831016, 64.29168851034981, 73.94854504721505, 75.01947784423828, 77.864091191973, 74.63202544621059, 66.16481862749372, 79.00466578347343, 76.84428324018205, 71.81117493765694, 80.58535317012242, 81.94157900129045, 10.761166742869786, 0.46021447650023867, 0.08813638599323374, 0.19301122666469642, 0.3437295284654413, 0.31165479815432, 0.14106318274778978, 0.07348345619227205, 0.1649956963956356, 0.061433128879538605, 0.13272629438766412, 0.6813895883304733, 10.150426166398184, 29.87108394077846, 39.01744590486799, 28.896666833332606, 44.701048033578054, 38.19282327379499, 13.301759924207415, 31.632983820778982, 48.971542903355186, 66.33828040531704, 66.97871671404157, 78.06374073028564, 72.06810542515346, 21.814486128943308, 0.8615783080458641, 0.06392286385276488, 0.05124331744653838, 0.0661522245832852, 0.03135197177263243, 0.05877295269497803, 0.03075690334662795, 0.07528164863054242, 0.044491235832018514, 0.09665725912366595, 0.008161445497535169, 0.022503317034404193, 0.03179859709260719, 0.015575803583487868, 0.02795187011361122, 0.0255789059280817, 0.01705907434890313, 0.02340319356881082, 0.024851044806252633, 0.03778429375961423, 0.045916454533913305, 0.043158335212085924, 0.054240657681865354, 0.09165068170321838, 0.034361356004540405, 0.04879688997087734, 0.04967884639544146, 0.009006616842400814, 0.004592106178668993, 0.2055009257580553, 0.13664678830121244, 0.07346597034484148, 0.07315638874258314, 0.1700575812054532, 0.15643020958772727, 0.11230992206505366, 0.1192504803517035, 0.12700749268489225, 0.11849791716252055, 0.14501665346324444, 0.21613124891051225, 0.15606701693364552, 0.14197981570448193, 0.06278890291494982, 0.09160655657095568, 0.15366543723004206, 0.17048697173595428, 0.08487829153559037, 0.2103940181966339, 0.05060615949332714, 0.17762643577797071, 0.1428491004875728, 0.30547206848859787, 36.87224517549787, 133.56437383379256, 120.44877352033342, 131.18101664951868, 99.38893645150321, 82.9497765132359, 43.3343825340271, 37.670141560690745, 59.97035367148263, 59.70923342023577, 85.92106246948242, 74.19607462201799, 53.623976775578086, 21.984689201627457, 0.7537364033716065, 0.23976319868649754, 0.19552960938641004, 0.39221530673759325, 0.13335357287100383, 0.8849431457264083, 0.7302680483886174, 0.328015824513776, 0.2312907933124474, 0.520457746727126, 1.4519139251538684, 3.0693198272160123, 24.802492925098964, 56.355789593287874, 80.73223808833531, 79.20359270913261, 80.098541532244, 69.63992541176933, 70.01122324807304, 82.15519441877092, 82.94084112984794, 81.40738064902169, 81.8001206261771, 73.17126396724156, 72.63910838535854, 82.14608533041817, 80.07096413203648, 68.5079596383231, 63.67617538997105, 66.6989266531808, 62.487727710178916, 66.75310175759452, 62.934760911124094, 63.6370917728969, 60.825537954057964, 60.000272614615305, 61.93418557303292, 65.41481617518834, 66.85208579472133, 75.37314115251813, 80.51277923583984, 82.7338126046317, 80.40872996194022, 70.8758292879377, 62.395108222961426, 70.84891196659633, 73.74479607173375, 80.2284242085048, 77.732971736363, 27.91757706233433, 70.08307456970215, 81.95571163722447, 82.3186160496303, 74.93262536185128, 64.57440376281738, 66.10901764460972, 65.54799924577985, 60.39513179234096, 61.451501165117534, 65.9626191002982, 76.92169312068394, 79.38252271924699, 79.84470299312046, 68.12921333312988, 59.392513683864046, 62.95758574349539, 58.894723892211914, 58.63889816829136, 63.46793787819998, 60.85401862008231, 61.093974658421104, 62.0215174811227, 68.33059992109025, 77.738662311009, 78.95547948564801, 81.84470026833671, 76.69805840083531, 67.24884183066231, 83.56610257284981, 82.75598430633545, 75.2432723726545, 84.61781665257045, 85.07794720785958, 10.62230178288051, 1.17564095556736, 0.3902691054557051, 0.4907437754528863, 0.29070505659495083, 0.3301245485033308, 0.23770517483353615, 0.26481590579663006, 0.3836406325655324, 0.1534633966428893, 0.42661686933466364, 2.428961902856827, 16.871942383902415, 41.26460450036185, 54.9143580027989, 42.12963785443987, 70.62423501695905, 80.12891210828508, 25.6143673488072, 29.31265722002302, 48.31487212862287, 74.89434078761509, 78.50596577780587, 90.15176500592912, 84.82522732870919, 28.599032061440603, 1.5088232542787279, 0.08588111201035124, 0.11818402686289378, 0.09517476867352213, 0.09529203309544496, 0.19390998700899736, 0.13195859986756528, 0.10027464465903384, 0.1376500158969845, 0.14119073376059532, 0.09669636309679065, 0.18046343140304089, 0.13611579393701895, 0.22565353794821671, 0.1384400613605976, 0.11686301417648792, 0.08339123454477106, 0.17745914975447313, 0.14768134190567903, 0.1420758826924222, 0.13210728046085152, 0.11684101607118334, 0.11104372822280441, 0.13252259817506584, 0.09763458025242601, 0.18120122967021807, 0.2915993928909302, 0.08468995057046413, 0.11955088137515954], [0.029501952829637697, 0.016903620279793228, 0.07454735838941165, 0.007716340096002179, 0.08711528578507048, 0.03221300556989653, 0.023238258669152856, 0.05095486881743584, 0.030342277738132646, 0.0879431731466736, 0.011815940113072949, 0.02678364994270461, 0.01891733579603689, 0.060304854065179825, 0.06674149832023041, 0.03192993772349187, 0.04558614707951035, 0.0067292425498765495, 0.009370276837476661, 0.053901006800255606, 0.026856069985244955, 0.019065008764820437, 0.1077818339690566, 7.692057967185974, 81.57487392425537, 97.38079588753837, 87.12728364127022, 68.98794119698661, 61.818796839032856, 26.1187926701137, 21.516260760171072, 43.72386728014265, 60.96237577710833, 74.8130885532924, 45.87901782989502, 29.864444937024796, 12.604256323405675, 0.19990264544529573, 0.09772142594946281, 0.07193779413189207, 0.07902553344943694, 0.048818226504538736, 0.17456351513309137, 0.12354800903371402, 0.16804311930068902, 0.04208562223772917, 0.19588102267256804, 0.22389810000147137, 0.5996942434992109, 13.664571404457092, 44.48169340406145, 64.19132178170341, 72.35971437181745, 70.42145878928048, 67.58252211979458, 57.26581253324236, 63.25346783229283, 67.34405994415283, 75.66572284698486, 70.52732154301235, 73.68716771262032, 75.91762978690011, 72.23868370056152, 72.0505542755127, 73.55576338086809, 63.616129057747976, 59.090128081185476, 57.789345400674, 63.129289627075195, 63.52004936763218, 66.99054949624198, 61.80418477739607, 61.07508945465088, 53.118547439575195, 54.71683113915579, 53.12414421354021, 52.06230313437325, 54.101390974862234, 70.63403197697231, 73.06275394984654, 73.60938957759312, 64.11794880458287, 63.34946414402553, 68.68538883754185, 73.38196114131382, 69.13618101392473, 80.06849752153668, 24.496414354869298, 63.813777514866416, 74.42031383514404, 68.16408634185791, 59.74852548326765, 54.73014041355678, 59.0048736844744, 56.02566678183419, 56.14600958142962, 54.68665163857596, 55.95120293753487, 60.68161991664341, 71.18066760471889, 71.62245491572789, 62.21360043116978, 53.0975604057312, 55.910740103040425, 52.77011612483433, 58.00542742865426, 54.24696615764073, 55.2193283353533, 53.283052989414756, 55.66626426151821, 62.186412130083355, 71.18814386640275, 72.14011655535016, 71.11412470681327, 64.38087558746338, 70.77212047576904, 75.85786833081926, 69.25969914027623, 69.2897639955793, 69.80154051099504, 73.2409474509103, 80.16835008348737, 9.635188579559326, 0.5027311007891382, 0.0885563041748745, 0.24847623971956118, 0.05656342215037771, 0.10321919486990996, 0.11900717126471655, 0.25961873467479435, 0.034836754601980956, 0.044901040449206314, 0.012463475411225642, 0.10651460196822882, 2.735361175877707, 17.502163103648595, 38.26095730917794, 39.19957208633423, 64.970673424857, 91.22519915444511, 30.50293575014387, 12.7969229221344, 23.85437822341919, 53.32302597590855, 65.42430741446358, 66.64699581691197, 54.23503262656075, 14.06294115952083, 0.07310362585953303, 0.011486401947747384, 0.020153178766902004, 0.026651659614539573, 0.028127293468319943, 0.04712905089503952, 0.04337662332026022, 0.05659069586545229, 0.014118461337472712, 0.016358658272240843, 0.1180448050477675, 0.03058334087420787, 0.08108335374189274, 0.022010551333161335, 0.053894380905798504, 0.12963753512927464, 0.049204445244478326, 0.02115695258336408, 0.026159938857225434, 0.015086174410368716, 0.082130869318332, 0.05434428694258843, 0.030059304886630604, 0.03806817924071636, 0.06161203142255545, 0.002271286349111636, 0.01003187901473471, 0.05342065828985401, 0.05867614610386746, 0.045216121577790806, 0.07851957702743155, 0.04756582388654351, 0.01096281040060733, 0.03073831827246717, 0.05632119193407042, 0.022075268306902478, 0.032702911246035776, 0.0856305697400655, 0.04036293039098382, 0.016694634886724607, 0.033079627103039196, 0.06756224749343735, 0.06729644497058221, 0.06571509196822133, 0.04537576051162822, 0.0357483222947589, 0.05017176815973861, 0.07448379322886467, 0.035507981798478534, 0.04574631527066231, 0.12260931011821542, 11.22985487324851, 100.06997108459473, 108.46478462219238, 99.2190807887486, 78.70608084542411, 72.3541419165475, 42.05681031090872, 35.340879576546804, 38.6560457774571, 45.72311067581177, 50.064991337912424, 44.150059359414236, 39.87688248498099, 15.18126848765782, 0.25518849811383654, 0.01923744486910956, 0.036090649997017214, 0.054746291799736876, 0.08423269939209733, 0.11705000485692706, 0.10437252798250743, 0.22351433416562422, 0.04336901355002608, 0.4740245097449848, 0.510698350412505, 1.1902445490871156, 15.914986099515643, 48.49466371536255, 69.80551488058907, 78.76853820255825, 76.27644171033586, 70.77780410221645, 61.65980121067592, 65.39180374145508, 71.8494039263044, 80.28726155417306, 74.52174363817487, 76.46211842128209, 79.04652173178536, 74.24259975978306, 74.29220989772251, 75.23017501831055, 67.4795150756836, 61.92721652984619, 60.84092126573835, 65.11262512207031, 66.19767665863037, 69.62759235927037, 64.96941580091203, 65.03535420554024, 55.22223963056292, 56.23244169780186, 56.95851455415998, 56.58815819876534, 56.903085299900596, 73.39973463330949, 75.82822731563023, 76.300934110369, 68.29443454742432, 64.68435205732072, 72.44690036773682, 75.5269603729248, 71.01546723502022, 80.55906118665422, 27.712898765291484, 65.25896113259452, 79.0584795815604, 70.90071773529053, 62.91928727286202, 57.6728310585022, 62.21105739048549, 58.694768633161274, 57.487123080662315, 58.646506445748464, 58.829570634024485, 62.653991154261995, 73.97731058938163, 73.03973456791469, 64.10289900643485, 56.24515342712402, 57.97886446544102, 56.693569319588796, 58.69446986062186, 55.826256956372944, 58.511996269226074, 56.93121855599539, 58.473065512520925, 65.90916660853794, 74.58235277448381, 73.63366658346993, 72.78527069091797, 64.11202199118478, 72.49305030277797, 78.35220214298793, 73.92949308667863, 71.71648488725934, 73.80516896929059, 77.87985665457589, 86.06391743251255, 12.734600186347961, 0.5323382435100419, 0.093919458532972, 0.5619295899357114, 0.207858197124941, 0.48287054364170345, 0.22036905294018133, 0.19068238591509207, 0.03465954161116055, 0.030452699134392396, 0.04507969532694135, 0.06817014701664448, 1.4694475957325526, 20.553113630839757, 38.36409636906215, 38.05734729766846, 62.52173914228167, 58.758775438581196, 23.738171339035034, 20.467048031943186, 36.21255193437849, 63.07324545724051, 74.84672478267125, 75.32503877367292, 70.93190819876534, 22.62137348311288, 0.062034460183765204, 0.044890926884753365, 0.035318175197712014, 0.028117885580286384, 0.04239303592060294, 0.061210528681320805, 0.02566396877435701, 0.03360032130564962, 0.009562148729206195, 0.025873871886038353, 0.08279748926205294, 0.04957273030387504, 0.06474906166217156, 0.028013934015429447, 0.010997278283217123, 0.08955102972686291, 0.054391984561724324, 0.04503080348617264, 0.0340719404630363, 0.008634396279895944, 0.09180476343525307, 0.004604509798809886, 0.024099112654637014, 0.06314789543726615, 0.048122324382088015, 0.0294820717535913, 0.050676360726356506, 0.02898500414033021, 0.10528987340096917, 0.11217116165374007, 0.2521046650196825, 0.12608210662645952, 0.1823728425162179, 0.08901513633983475, 0.10571897216141224, 0.1600129830517939, 0.13873587548732758, 0.15136486424931458, 0.13497761929673807, 0.1505250143153327, 0.08598030704472746, 0.12046902067959309, 0.15409623911338194, 0.11164423171430826, 0.10793293014700923, 0.12903899938932487, 0.15068479574152402, 0.13378387263842992, 0.09152811113744974, 0.16659310353653772, 0.3919566763298852, 14.808304820741926, 120.71386119297573, 117.36231422424316, 111.96188940320695, 94.08013752528599, 85.5865067073277, 40.637223856789724, 36.84226369857788, 58.72916916438511, 84.31821727752686, 103.5998922075544, 68.89367498670305, 48.67351382119315, 23.438827310289653, 0.6368862677897725, 0.1523229285542454, 0.34355308221919195, 0.1763042967234339, 0.24241035378405026, 0.3792029321193695, 0.41206978421126095, 0.5149362630077771, 0.15974352322518826, 0.664333986384528, 1.030213204877717, 2.176175364426204, 17.534720625196183, 55.22897243499756, 76.58660929543632, 83.709534236363, 82.06952313014439, 73.66093131474086, 65.05328055790493, 67.8789461680821, 75.13492911202567, 83.21134839739118, 76.31367710658482, 79.10196835654122, 83.32317965371269, 75.60209819248745, 75.7445501599993, 81.48245593479702, 70.76486655644008, 66.06049837384904, 64.07397365570068, 69.79907390049526, 69.55826323372978, 73.57943589346749, 69.33395453861782, 68.06507451193673, 58.34881782531738, 60.241680826459614, 59.97686413356236, 59.43115956442696, 59.68765231541225, 78.30256421225411, 80.55335671561105, 80.99151011875698, 73.40207617623466, 67.9442036492484, 76.7566247667585, 79.00320666176933, 74.63780634743827, 85.81610298156738, 33.27436024802071, 66.97333186013358, 81.19557176317487, 77.32903821127755, 65.40549864087785, 59.89381231580462, 64.94758456093925, 61.85713699885777, 62.32066522325788, 63.211542401994976, 61.60093607221331, 67.88737433297294, 78.53656564440045, 77.68509864807129, 67.48886735098702, 58.550739424569265, 61.76129354749407, 58.838144711085725, 62.80897767203194, 59.03977448599679, 61.918704986572266, 58.81980841500418, 61.47292940957205, 70.25131825038365, 77.4458235331944, 78.155852999006, 75.04818780081612, 64.2952390398298, 75.6477131162371, 83.6294492994036, 76.033004624503, 76.45510074070522, 75.88721752166748, 80.24683693477085, 87.53629629952567, 12.740463597433907, 0.9782114752701351, 0.2245306439165558, 0.5418117865920067, 0.14279783038156374, 0.3590085357427597, 0.29357732247029034, 0.397670782570328, 0.14729681611061096, 0.13788689247199468, 0.22724806810063974, 0.23199611689363206, 4.739083988325937, 30.52752889905657, 58.83728313446045, 55.03666019439697, 84.23550592150006, 117.20397867475236, 41.940198693956646, 21.77073505946568, 37.17071199417114, 74.02809497288295, 84.7951694216047, 87.40412766592843, 79.18501322610038, 26.887593473706925, 0.11446337508303778, 0.1837399820131915, 0.14616759813257627, 0.1306543198547193, 0.15914516390434333, 0.14520220564944403, 0.08698275432522808, 0.1754326234970774, 0.06602898905319826, 0.07843666683350291, 0.16596815921366215, 0.19473296856241568, 0.19271203343357357, 0.07642369092042957, 0.11770665033587388, 0.21230674056070192, 0.1269912485565458, 0.1480591366333621, 0.056036057948533974, 0.060401287462030134, 0.17448943267975534, 0.07792666634278637, 0.11693867083106722, 0.11636422308427946, 0.1715943408863885, 0.09899984699274812, 0.09376521395253283, 0.08805505678589855], [0.03188788890838623, 0.05959792235600097, 0.06910227092781238, 0.05132417167936053, 0.0779239454173616, 0.01466996272626732, 0.011309295826192414, 0.029820854110377173, 0.013463457913271018, 0.03506453202239104, 0.020973466536296264, 0.0390665451330798, 0.06895749869623355, 0.04648374712892941, 0.015983983109306012, 0.02445056156388351, 0.038428294738488536, 0.08052534689860684, 0.017697253497317433, 0.04133819895131247, 0.011103759087356073, 0.07349776649581534, 0.1936212567878621, 57.30272136415754, 102.91755826132638, 89.65520504542759, 84.20417649405343, 54.96345397404262, 43.04130056926182, 28.83661355291094, 44.54486295155117, 72.51351969582694, 56.837845189230784, 45.03496108736311, 33.71322236742292, 11.899424978664943, 0.18650716995554312, 0.08435448285724435, 0.07343889679759741, 0.08464360662869044, 0.07194547514830317, 0.0782788803002664, 0.04072481007980449, 0.16108616760798863, 0.2033186350017786, 0.03917996904679707, 0.06571611655609948, 0.22413414876375878, 7.4683780840465, 31.429318223680767, 59.04389476776123, 72.22367559160504, 71.14147976466587, 71.88074030194963, 61.14798995426723, 55.89284154347011, 60.556336947849815, 66.02190113067627, 66.30566556113106, 69.33105019160679, 72.66979857853481, 74.16311236790249, 72.03517096383231, 71.54149450574602, 71.48146901811872, 66.4902514048985, 61.306513105119976, 58.52629566192627, 66.09742804936, 67.79025936126709, 69.50546387263707, 67.39116178240094, 67.39494855063302, 58.398983819144114, 53.41656262534005, 52.436414991106304, 52.961493832724436, 49.969873973301475, 62.139866147722515, 72.42738287789481, 73.5077930177961, 65.55373845781598, 60.475112506321494, 65.1934882572719, 72.95313916887555, 70.51176452636719, 65.83650234767369, 31.96851233073643, 61.94631017957415, 72.57751260484967, 62.45221546718052, 58.754828861781526, 51.88373095648629, 57.91840124130249, 54.96767847878592, 59.530386788504465, 55.20126649311611, 53.848417486463276, 55.934502942221506, 57.85598904745919, 58.2066924231393, 54.68568583897182, 54.006506374904085, 54.44662264415196, 53.803601605551584, 55.36998265130179, 54.61247614451817, 54.65035424913679, 53.98383787700108, 53.60525138037545, 57.07611976351057, 68.3302664075579, 68.64583969116211, 74.47885935647147, 68.7410717010498, 68.62594699859619, 72.18504360743931, 68.47493485042027, 58.013476916721885, 65.7504141671317, 73.9644911629813, 72.24914073944092, 74.32558209555489, 10.116608415331159, 0.09104188651378665, 0.4099022448062897, 0.8030380521501813, 0.010325967966179763, 0.2214439202632223, 0.04674657427572778, 0.07637782195316893, 0.08715926163962909, 0.07418289687484503, 0.06128278587545667, 0.07118932250887156, 0.5901564295802797, 17.20745004926409, 51.36782373700823, 26.972161735807145, 67.9601914542062, 105.80488218579973, 36.2293769972665, 21.389063562665665, 37.72048473358154, 49.706189836774556, 64.64739458901542, 71.04289872305733, 58.198847906930105, 6.361564789499555, 0.09507044391440493, 0.04813295363315514, 0.028533401765993664, 0.07292611431330442, 0.03765012703037687, 0.02233446529135108, 0.1184461856526988, 0.058426574138658385, 0.04478218486266477, 0.07104472669639758, 0.05944573373666831, 0.019984722270497253, 0.06290219112166337, 0.08064554937716041, 0.022828793319474374, 0.03133401773603899, 0.037640383267509084, 0.07054095515715224, 0.08592322189360857, 0.02185378429879035, 0.03588992576780064, 0.05838046768414123, 0.04235706677926438, 0.01061426816574697, 0.0031742453408826676, 0.039396204586539946, 0.01093730257291879, 0.011462695630533355, 0.0044919866403298715, 0.04150055541789957, 0.034065535092460256, 0.02159691977846835, 0.030874673277139664, 0.0035007105907425284, 0.025018602243757675, 0.04861880845523306, 0.04054274556360074, 0.03492527628051383, 0.03175831586122513, 0.007668441460867013, 0.0024459240874940796, 0.021721968693392615, 0.03127378418243357, 0.024006457001503025, 0.06903655481125627, 0.02304678626491555, 0.07093293805207525, 0.019222657894715667, 0.07332425830619675, 0.475943352494921, 72.85910224914551, 114.16673346928188, 101.87561334882463, 94.05582577841622, 72.7668788092477, 64.56544058663505, 38.94100877216884, 37.82677827562605, 43.96261085782732, 50.08244868687221, 44.7962383542742, 42.121143681662424, 13.29556039401463, 0.24939907448632376, 0.057096950842865875, 0.01650059422744172, 0.01307172522813614, 0.12692178014133657, 0.03353203014869775, 0.062171198560723236, 0.21515536627599172, 0.32552348396607805, 0.212898192395057, 0.23327157273888588, 0.5029537145580564, 7.582543066569737, 38.123949255262104, 66.9854564666748, 75.57773780822754, 77.83117757524762, 76.55621787479946, 65.18385805402482, 60.72567844390869, 64.51990904126848, 67.80098737989152, 69.45600659506661, 74.2753883089338, 75.6277162006923, 76.68852547236851, 72.88033594403947, 73.42796516418457, 75.82722677503313, 69.90318570818219, 64.0751895904541, 61.309222902570454, 69.02309213365827, 71.64478642599923, 72.69670895167759, 70.94360201699394, 71.505857195173, 61.48005131312779, 55.73902579716274, 55.53669425419399, 56.02244976588658, 52.81398357663836, 65.50933252062116, 76.99930449894497, 78.30380099160331, 67.81903185163225, 62.13281372615269, 66.53881236485073, 75.91068158830915, 72.54949051993233, 70.0294622693743, 36.80227334158761, 63.744052342006135, 75.27021748679024, 66.21240683964321, 62.39531666891915, 53.52869265420096, 61.18578815460205, 58.91936220441546, 62.35988780430385, 59.04852226802281, 57.367492471422466, 60.12238025665283, 60.69509942190987, 61.779442242213655, 57.333567891802105, 57.84012631007603, 56.83296407972063, 56.31527464730399, 58.076806272779194, 57.88391385759626, 57.95297547749111, 56.23938989639282, 55.44243499210903, 59.358307702200754, 70.98593739100865, 71.21940381186349, 76.97788320268903, 70.58319200788225, 72.02813938685826, 75.50363527025495, 72.18996293204171, 61.491675649370464, 70.27722113473075, 78.81181853158134, 77.59114510672433, 83.34025137765067, 14.266504270689827, 0.0370675097219646, 0.16085041740110942, 1.374552139214107, 0.8734753068004335, 0.6060814836195537, 0.19627170956560544, 0.23581618762442044, 0.17259068813707146, 0.07498978357762098, 0.0695904768737299, 0.03047096190441932, 0.04762728898120778, 17.765049934387207, 41.98129728862217, 23.47189031328474, 69.3824599129813, 89.38339846474784, 33.975443908146445, 31.98728288922991, 53.96209348951067, 58.48450919560024, 73.29480988638741, 79.9576529094151, 73.4270132609776, 10.531410660062518, 0.1032426178987537, 0.03762454626017383, 0.012906643595280392, 0.08559907214449984, 0.007293543229544801, 0.07080974323408944, 0.07116777902202946, 0.07558753221694912, 0.03767732271392431, 0.06399617277617965, 0.12106581936989512, 0.048346831263708215, 0.0214103175593274, 0.09804988439593997, 0.040762753758047304, 0.0503614390535014, 0.02697435560237084, 0.03704309942466872, 0.010696238588674791, 0.039909899700433016, 0.022024374787828753, 0.051159107858049016, 0.03960731379421694, 0.008727857693364578, 0.07267300718064819, 0.04379048218418445, 0.04139784896480186, 0.20159649955374853, 0.06462334269391638, 0.15440303193671362, 0.164937966636249, 0.16479303155626568, 0.13894429430365562, 0.1327427692179169, 0.1056187321831073, 0.17339917618249143, 0.08152304443397693, 0.18072496594062873, 0.10768040655446903, 0.1476729145007474, 0.11440544176314558, 0.11064741627446242, 0.08561388456395694, 0.09391128897134747, 0.26013626690421787, 0.13558447387601646, 0.1589807548693248, 0.12672162588153565, 0.12953194150967257, 0.7247056354369436, 84.93944876534599, 128.97097533089774, 113.76978983197893, 109.10563782283238, 79.84562710353306, 64.13240105765206, 40.6003532409668, 61.65795298985073, 100.55125195639474, 78.83175986153739, 66.29778630392892, 53.397600991385325, 19.755231142044067, 0.5338363945484161, 0.25123559736779755, 0.27223411202430725, 0.21585086467010633, 0.2589670696428844, 0.2438736009810652, 0.2451638217483248, 0.5726063655955451, 0.7287457415035793, 0.22323684048439774, 0.546469196677208, 0.911754235625267, 9.01824586732047, 44.97294841493879, 71.71254525865827, 80.23567812783378, 81.16235242571149, 80.36003003801618, 67.76556546347481, 63.02274594988142, 67.39358670370919, 71.36619840349469, 72.57399681636265, 78.33068357195172, 79.86602006639752, 81.05585738590786, 75.11755861554826, 74.39633560180664, 79.23997347695487, 72.59307656969342, 68.61929062434605, 65.41455909184047, 73.74669987814767, 73.92708900996617, 75.80178247179303, 74.45928628104073, 74.46151665278843, 64.51173795972551, 57.885407720293315, 57.510913712637766, 58.86190755026681, 55.89862591879708, 68.61556638990129, 80.37733105250767, 80.90905584607805, 70.12499305180141, 64.43678774152482, 71.7169851575579, 78.7173855645316, 75.25389616830009, 75.86953435625348, 42.96527338027954, 68.19658306666783, 79.69405215127128, 70.13772215162004, 65.05625438690186, 57.16670690264021, 63.5804500579834, 61.57315022604806, 66.52295657566616, 62.56809057508196, 59.33832468305315, 62.93046692439488, 63.9977171761649, 65.19796289716447, 60.6700998033796, 60.798766544886995, 61.670709882463726, 59.311838150024414, 60.46122305733817, 60.18560191563198, 60.32720620291573, 59.791791915893555, 58.60294124058315, 62.486553464617046, 75.99298994881767, 75.88049166543144, 82.49225153241838, 72.51134490966797, 71.22024454389299, 78.17138917105538, 75.21919686453683, 64.57573086874825, 74.11508641924176, 83.441299029759, 78.90022046225411, 84.8299173627581, 12.406482798712593, 0.22619210476321833, 1.4529893760170256, 2.4857017610754286, 0.7227667623332569, 0.4548641193125929, 0.2597379397068705, 0.3227728658488819, 0.46484577655792236, 0.3223724216222763, 0.22005133570304938, 0.16620643357081072, 1.060981999550547, 29.999173981802805, 73.62113898141044, 32.930504322052, 74.46490737370083, 124.71448108128139, 50.09407997131348, 32.20583152770996, 53.62168039594378, 66.68652411869594, 85.91849163600376, 88.06018352508545, 85.93292999267578, 12.395753043038503, 0.23936329728790692, 0.10553930287382432, 0.1139944666730506, 0.1838382745959929, 0.1712578825120415, 0.18482985853084496, 0.14513938687741756, 0.1925375142267772, 0.11523199241076197, 0.1864971819200686, 0.18157964865011827, 0.10407710740608828, 0.18958807177841663, 0.19855749048292637, 0.12089877761900425, 0.21666265039571694, 0.08294032766882863, 0.15353118229125226, 0.20803264847823552, 0.11632486805319786, 0.07138213501977068, 0.1473716585231679, 0.15907836891710758, 0.05611301399767399, 0.1347016998167549, 0.16180183206285748, 0.0955428739211389], [0.05959221587649413, 0.05191702129585402, 0.07732958945312671, 0.030164922254958322, 0.04376085734527026, 0.0529812899019037, 0.05121189448982477, 0.042378159040319066, 0.10598569070654255, 0.03188267097409282, 0.0632178998951401, 0.03566296937476311, 0.009827414361227835, 0.02598992342661534, 0.033911477109151225, 0.025519888648497205, 0.0937264288908669, 0.19430948128657682, 0.05378332847197141, 0.07111493471477713, 0.21789930760860443, 0.37872011374150005, 20.603250094822474, 101.70261015210832, 88.98689951215471, 82.49321038382394, 62.36957359313965, 33.49923522131783, 18.826835427965435, 37.310874530247276, 56.300137996673584, 61.35303824288504, 53.20579596928188, 42.97461175918579, 9.959333334650312, 0.11085565188633544, 0.05626354020621095, 0.019419650181329677, 0.04401689574920705, 0.09561253232615334, 0.0637723376442279, 0.1263510100543499, 0.08281689536358629, 0.139257478926863, 0.1754793609891619, 0.24974868286933216, 0.3710875175893307, 4.777055893625532, 28.42801778657096, 54.57208626610892, 65.66909939902169, 74.99260916028703, 71.49119649614606, 70.7208080291748, 56.33492415291922, 59.43819808959961, 55.28315101351057, 57.71746628625052, 61.55933025905064, 62.8698091506958, 69.51115444728306, 73.44203526633126, 72.97045407976422, 69.2931547164917, 73.16640717642647, 68.98755209786552, 65.63408047812325, 61.36785180228097, 65.0681288582938, 70.44530500684465, 70.50933265686035, 69.91555350167411, 70.42023590632847, 66.58914511544364, 57.27371610913958, 53.44987576348441, 52.98516981942313, 48.496359075818745, 61.903620447431294, 68.6394681930542, 70.0858052117484, 69.73946530478341, 60.98681953975132, 60.535165786743164, 65.87358488355363, 66.75476237705776, 67.88883345467704, 35.9888789994376, 57.89502402714321, 72.82868998391288, 61.76187719617571, 66.07939052581787, 54.07135043825422, 55.594256605420796, 54.38944591794695, 57.2522531236921, 55.53212928771973, 56.09732355390276, 54.65500954219273, 55.515391077314106, 53.44654062816075, 53.23410293034145, 53.82131603785923, 56.16004841668265, 53.93896641050066, 55.82278285707746, 56.597312450408936, 59.28355898175921, 57.66031040464129, 56.603253160204204, 53.74628938947405, 58.25105667114258, 65.25160993848527, 69.26345116751534, 69.00248377663749, 73.62180600847516, 71.3987785066877, 71.11925942557198, 61.76330157688686, 55.54928091594151, 65.43318721226284, 73.51900741032192, 73.5536858694894, 71.43548583984375, 22.108250754220144, 1.3303164328847612, 1.4448142775467463, 0.7415061082158769, 0.35368477712784496, 0.17207831277378968, 0.1592494954488107, 0.05081805580162576, 0.09896246649857078, 0.1580208856612444, 0.03480436134019068, 0.010145035755288388, 0.21778703720441886, 24.14295949254717, 57.834154333387104, 65.52726582118443, 103.08357851845878, 79.68244865962437, 20.558696508407593, 12.315779277256556, 41.869504247392925, 61.78771754673549, 66.30149664197648, 69.99552726745605, 44.13135133470808, 1.0026229939290454, 0.03875295338886125, 0.07462656378213849, 0.02087217822138752, 0.0513589262430157, 0.01757359897185649, 0.004852362525915461, 0.036063505203596184, 0.11576328533036367, 0.01349078760748463, 0.0669635489050831, 0.06887141295841762, 0.01869916812782841, 0.05810279079845973, 0.011101230696242834, 0.017488734597074132, 0.029782191185014587, 0.06434889563492366, 0.04389572635825191, 0.05599364611719336, 0.04753657224188958, 0.03504360600241593, 0.09239375897284065, 0.056474924220570495, 0.027585768240637014, 0.042597322458667417, 0.05914553627371788, 0.05449357482471636, 0.04300116614571639, 0.07626091036945581, 0.03726465128628271, 0.04997015844232269, 0.018748804660780088, 0.06198489998600312, 0.02874303176733, 0.019091736259205, 0.06474750103162867, 0.04018204313303743, 0.005101438312392149, 0.06062984519771167, 0.040052541332053285, 0.05530892964452505, 0.056926245002874305, 0.04605138461504664, 0.061018998601606915, 0.057820900210312436, 0.049726272600569894, 0.22578054613300733, 0.486557485801833, 29.02268804822649, 118.68067932128906, 98.86074134281704, 94.5395176751273, 74.78284999302456, 47.69100379943848, 36.93804114205496, 39.116621017456055, 38.50149004799979, 65.80773680550712, 46.92444726399013, 46.19902059010097, 11.408649393490382, 0.16742445821208612, 0.026672029235799397, 0.18925527749317034, 0.05879980232566595, 0.11109197206263031, 0.05324762507474848, 0.29751790102039066, 0.264139677797045, 0.31751082677926334, 0.0959867647449885, 0.43386479041406084, 0.40171333136303083, 5.0748291952269415, 31.076568603515625, 66.09840774536133, 71.45446831839425, 80.49800736563546, 76.21337985992432, 74.23754147120884, 58.514560154506135, 62.29102420806885, 56.98548398699079, 60.45289216722761, 63.93478039332798, 67.20398426055908, 71.39657592773438, 77.29147624969482, 74.67070606776646, 69.83465562547956, 74.27694470541817, 73.4048832484654, 68.14791093553815, 63.6995004926409, 68.52036912100655, 71.88550676618303, 73.69021102360317, 74.19296877724784, 72.26949201311383, 72.3369242804391, 60.08019079480852, 55.0605411529541, 55.77911342893328, 51.7038768359593, 65.88266617911202, 71.43563870021275, 73.78963279724121, 72.27108315059117, 64.71855803898403, 63.85379219055176, 69.20687893458775, 69.8404643195016, 72.4328511101859, 40.04653317587716, 60.3659702028547, 75.35839012690953, 65.2239213671003, 69.47572558266776, 57.13540179388863, 59.51466996329171, 56.88811540603638, 61.09669140407017, 59.02863652365548, 59.109027181352886, 56.356081417628694, 58.89349406106131, 56.15829399653843, 56.68768072128296, 56.33011252539498, 56.94975982393537, 55.66087245941162, 58.98833697182791, 59.41105147770473, 63.802688189915244, 60.17270605904715, 58.16848080498831, 56.34702444076538, 60.8054507119315, 69.24494811466762, 71.88004548209054, 70.05101558140346, 75.66075488499233, 73.91920280456543, 74.50176756722587, 65.82393305642265, 58.1587290082659, 67.50954518999372, 78.29578971862793, 76.55017294202531, 78.64561067308698, 28.71409944125584, 2.0681065576417104, 1.1359774896076746, 1.6098510388817107, 1.0609941588980811, 0.833667014326368, 0.4657311290502548, 0.022577350293951373, 0.21520994763289178, 0.09491674894733088, 0.0909822704270482, 0.08266468638820307, 0.14930369199386664, 23.543854543140956, 50.5423777444022, 66.209335735866, 107.57434517996651, 72.48281560625348, 31.31388780048915, 19.829771416527883, 48.81632709503174, 69.62204074859619, 73.9653318950108, 80.80731337411063, 56.64393138885498, 1.9777172250407082, 0.026191919908991883, 0.03145658830180764, 0.05457831706319537, 0.06543398169534546, 0.056618875424776755, 0.0563225048993315, 0.0161792027231838, 0.04592630686238408, 0.006956221843470952, 0.033306698847029886, 0.009869360547911907, 0.035256686354322095, 0.03906632800187383, 0.015176377159410288, 0.08790603013975279, 0.03843615895935467, 0.10395382437855005, 0.05995649418660572, 0.06384319027087518, 0.019833605736494064, 0.01580587275592344, 0.03212197670446975, 0.08428572011845452, 0.032837217074951956, 0.10304410569369793, 0.036251774922545464, 0.1391854863613844, 0.18187880116914, 0.19426046391682966, 0.09167375867920262, 0.12613694582666668, 0.13332758497978958, 0.2533464655280113, 0.1345563576157604, 0.1650537789932319, 0.0884111248222845, 0.11312772639627967, 0.08734224217810801, 0.15173959199871334, 0.15862657316029072, 0.1915709546634129, 0.15108477856431687, 0.16389129922858306, 0.3776794310126986, 0.14267424201326712, 0.2136872743389436, 0.4437258855572769, 0.6347571877496583, 33.5577529498509, 132.4594018118722, 109.63910661424909, 107.3601461138044, 83.63533442361015, 53.10767003468105, 31.27569702693394, 52.91471855981009, 77.86277798243931, 82.68974018096924, 77.85236958095005, 64.5702348436628, 15.883851221629552, 0.32078983368618147, 0.20366831123828888, 0.24582020938396454, 0.1438050749046462, 0.2475604617169925, 0.2957726818110262, 0.42527263717991964, 0.2943391001650265, 0.2801113336213997, 0.4291199578770569, 1.0163211503199168, 1.1999327263661792, 7.697143180029733, 38.3357720375061, 69.62415994916643, 73.0957578931536, 84.13459028516496, 78.74913883209229, 78.05859211512974, 62.63775321415493, 66.82856614249093, 60.95851257869175, 62.62010478973389, 66.90942232949394, 71.48647172110421, 74.33209950583321, 81.98064872196743, 76.53870841435024, 69.96310002463204, 78.38317026410783, 76.94590064457485, 72.66346182141984, 68.95756367274693, 72.00061062404087, 76.45612212589809, 76.29122747693742, 76.4472770690918, 75.93843964168003, 75.0485838481358, 63.65466376713344, 58.77578462873186, 58.877575738089426, 55.320337772369385, 68.32846682412284, 75.97605718885148, 77.68321568625313, 77.43984113420758, 68.64735439845494, 68.05409635816301, 74.29845632825578, 73.99295793260846, 75.40023912702287, 44.8731028011867, 64.94324888501848, 78.55231026240757, 68.2225067956107, 73.1422621863229, 59.50727707999093, 62.01906476702009, 60.4431368964059, 64.87523991721017, 62.24522168295724, 62.409352030072895, 60.454851559230256, 61.469733238220215, 60.11021396092006, 58.67893368857247, 58.86039979117257, 60.98324121747698, 59.810315813337056, 61.95538452693394, 61.61956419263567, 65.78504398890904, 63.32633359091622, 61.6172365461077, 59.239180837358745, 64.81422083718437, 72.35300936017717, 76.83998230525425, 73.43558733803886, 80.24113941192627, 78.87966074262346, 78.3117983681815, 68.91959176744733, 62.087900570460725, 70.68128667558942, 80.33458573477608, 80.31168447222028, 80.93721689496721, 27.75044683047703, 2.133866263287408, 3.483306961400168, 3.9514136144093106, 1.7256585104124886, 0.45950744301080704, 0.4024162936423506, 0.18771718788359845, 0.44860487803816795, 0.49712330741541727, 0.32414255663752556, 0.19958000204392842, 0.6326009120259966, 40.4732255254473, 78.00260353088379, 69.56839370727539, 104.49680737086705, 91.11937808990479, 29.511507715497697, 18.645273787634714, 57.49768434252058, 80.9156218937465, 84.36186586107526, 91.04877049582345, 64.72590228489467, 2.1036565814699446, 0.10261022326137338, 0.13493552298418113, 0.14131011521177633, 0.14493467286229134, 0.16725961491465569, 0.12366748547979764, 0.10881083911018712, 0.20711647692535604, 0.08755939374012606, 0.15023584983178548, 0.08106867024408919, 0.11132698945168938, 0.16265926962452276, 0.15417269643928322, 0.21535037724035128, 0.08997832358415637, 0.23824113607406616, 0.14250452683440276, 0.14488188283784048, 0.09965586143412761, 0.0928158959639924, 0.18823267093726567, 0.14240050741604396, 0.12643235283238546, 0.1820577308535576, 0.14064631797373295], [0.01616628511276628, 0.015084330491455538, 0.05882084369659424, 0.025850216458950723, 0.03479158791846462, 0.05358419201469847, 0.0382568696513772, 0.01939673605374992, 0.02217964395614607, 0.06771820198212351, 0.04187770553731492, 0.01777995504172785, 0.01934878059130694, 0.01604482395175312, 0.05275468973975096, 0.07583291083574295, 0.054221648523317914, 0.008790813868732324, 0.017661438722695624, 0.05991425538169486, 0.03835776102330003, 0.7722104692033359, 71.20842565808977, 93.49365397862026, 85.22093418666294, 62.141505922589985, 46.434265749795095, 48.305283614567344, 33.332631315503804, 50.03350210189819, 51.933070114680696, 25.35322277886527, 48.38245725631714, 11.53557300567627, 0.12427948335451738, 0.07579652778804302, 0.06290344641144786, 0.02429655616703842, 0.08431759769363062, 0.08088163885154895, 0.11744744995875017, 0.03718951710366777, 0.09464693628251553, 0.10126394871622324, 0.2669580137091023, 0.8643708867686135, 17.388638223920548, 61.35413605826241, 77.23908683231899, 66.70390156337193, 68.90306895119804, 75.40366458892822, 74.80485493796212, 66.93153149741036, 53.43707718167986, 54.70702723094395, 55.783396993364605, 58.88675430842808, 58.56655352456229, 61.31703962598528, 67.5030208315168, 71.44295515332902, 73.55025345938546, 67.46764060429165, 71.83379132407052, 71.51496628352574, 66.76314190455845, 64.8467106137957, 68.0970014844622, 71.0182465144566, 71.60903099605015, 69.41029439653668, 69.09390817369733, 69.81813975742885, 61.3244811466762, 52.772127628326416, 52.01259224755423, 47.66871050425938, 59.34800352369036, 66.72462109157017, 69.9593618937901, 67.13862950461251, 59.47972052437918, 54.09539467947823, 62.969481059483115, 57.655839238848, 77.42704255240304, 37.62108380453927, 40.28119816098894, 78.46881375994, 62.264523778642925, 73.30495425633022, 60.505795751299175, 56.8992464201791, 52.118774618421284, 56.91375078473772, 54.99278232029506, 56.11859893798828, 50.86098739079067, 53.758719716753276, 52.414198126111714, 55.10348449434553, 51.46501166479928, 53.157075200762065, 53.40009192058018, 58.13557761056082, 57.39781788417271, 62.45117323739188, 58.95666013445173, 57.911063943590435, 54.19997896466936, 56.305557591574534, 57.593757084437776, 66.32632950374058, 68.52747017996651, 70.50072383880615, 69.17906529562813, 72.079528263637, 62.5446959904262, 56.794669083186555, 56.696928773607524, 66.42006070273263, 71.58149528503418, 72.05095032283238, 72.6025469643729, 34.301995345524375, 1.7660436119352068, 1.5291479293789183, 0.8515751819525446, 0.34090410864778925, 0.40300716193658964, 0.19158479677779333, 0.03575523317392383, 0.06359051740063087, 0.014181008695491722, 0.13606935500034265, 0.013751589327252336, 0.600621936576707, 17.260362318583898, 37.79625483921596, 67.11307403019497, 70.92115238734654, 47.450776781354634, 26.276759965079172, 30.717381477355957, 54.05273968832833, 62.80312728881836, 69.24624742780412, 69.46855504172188, 21.02224210330418, 0.21251807707761014, 0.10937770083546638, 0.07452888866620404, 0.059131646661886146, 0.03369518728660686, 0.015443631747205342, 0.05223354431135314, 0.03704338440937655, 0.025312053372285197, 0.033378552312829664, 0.06920252447681767, 0.051162812659250836, 0.05248453441475119, 0.020649991929531097, 0.03597806407404797, 0.02077299845404923, 0.023928569663049917, 0.05217834888026118, 0.03816461603024176, 0.04006324182929737, 0.10235451055424553, 0.05427102890930005, 0.02099790227865534, 0.014463715221998947, 0.04669102939910122, 0.025874764159587876, 0.03275386583326118, 0.05557555319475276, 0.0333359131722578, 0.058838533104530404, 0.00946477216867996, 0.05844581739178725, 0.010524559899100235, 0.00569293722011415, 0.020598397823050618, 0.06763481002833162, 0.023892234112801294, 0.03371917010684099, 0.026018170839441673, 0.01918903987721673, 0.02802401195679392, 0.028878226477120603, 0.03771926974877715, 0.03167695951248918, 0.06184014132512467, 0.06896252664072172, 0.013846812387263136, 1.4101506918668747, 86.89045429229736, 105.07807976858956, 98.31032589503697, 72.71642099108014, 61.01198591504778, 64.02714279719761, 39.11873326982771, 47.10918596812657, 51.54994991847447, 28.83690537725176, 51.5777461869376, 13.704438430922371, 0.11937037748949868, 0.06126151380262204, 0.08644648774393968, 0.2122262663074902, 0.09151479149503366, 0.31349208099501474, 1.3670716434717178, 0.8987786918878555, 0.45821963782821384, 0.17437675515455858, 0.6826702281832695, 0.6972071081399918, 18.612669365746633, 64.6723108291626, 81.80318478175572, 71.76767921447754, 72.21807534354073, 80.09281621660504, 78.7263765335083, 71.08757563999721, 57.31988341467721, 57.25228786468506, 59.312414850507466, 62.722687993730815, 59.76504135131836, 65.95271791730607, 71.28420966012138, 74.80224936349052, 75.7798261642456, 67.82001849583217, 73.45810644967216, 75.41900621141706, 70.15986606052944, 67.42519405909947, 69.83412061418805, 73.63816901615688, 73.39945670536586, 70.97900308881486, 72.12389945983887, 72.43559564862932, 64.97737843649728, 55.45063386644636, 54.734170368739534, 50.172507762908936, 62.194687434605186, 70.95403126307896, 73.26270920889718, 68.80348736899239, 62.38747910090855, 55.31740910666329, 65.01662881033761, 60.33468246459961, 80.87884507860456, 40.37257044655936, 41.36869893755232, 80.60994979313442, 64.22536795479911, 76.75069795336042, 63.39013195037842, 59.28806141444615, 53.911708627428325, 61.161941937037874, 56.8084716796875, 58.480687686375205, 53.37757975714547, 54.29085445404053, 56.535390104566304, 58.09526068823678, 54.61170836857387, 55.01683350971767, 55.9553336415972, 62.79506043025425, 60.95505237579346, 64.80265208653041, 63.550246238708496, 60.238310950142996, 57.25645678383963, 59.24502427237374, 60.69701712472098, 69.14091273716518, 71.26614434378487, 72.0045919418335, 72.02941785539899, 75.23664379119873, 65.40467180524553, 59.54993207114083, 61.56368677956717, 69.88730212620327, 75.15077795301164, 74.42630318232945, 75.20099258422852, 40.718208585466655, 2.812536120414734, 0.9198487784181322, 1.5769197259630476, 0.9964873003108161, 0.9887898904936654, 0.643733663218362, 0.0570629494530814, 0.22233736089297704, 0.13243740131812437, 0.145578032625573, 0.08145998138934374, 0.5181046958480562, 20.600858177457535, 38.916363511766704, 78.58723190852574, 72.9777774810791, 36.37707832881382, 35.148685455322266, 46.22137294496809, 60.820326805114746, 69.73992388589042, 75.72793006896973, 82.52134363991874, 29.097452402114868, 0.365633100271225, 0.06720938214233943, 0.06763327653918948, 0.03735669116888728, 0.03618825725944979, 0.0718098156420248, 0.0626918181244816, 0.03925220927755747, 0.013093585930099445, 0.017394796512754898, 0.11532364892108099, 0.039539521360503774, 0.041071337913828235, 0.02147210665446307, 0.05631659485931907, 0.027813223356913244, 0.0424380872531661, 0.043232756932931285, 0.0172139160401587, 0.062212019227445126, 0.002443252779942538, 0.009061410241494221, 0.019036120136401484, 0.008878104854375124, 0.04619986504050238, 0.05858903577817338, 0.08007440609591347, 0.14038827110614094, 0.19918862304517201, 0.10269703503165926, 0.17786758712359838, 0.1469196184937443, 0.14827552145080908, 0.08349701136882816, 0.09304345625319652, 0.15650688404483454, 0.12219521376703467, 0.12144326125936848, 0.14893922369394982, 0.09131917663450752, 0.16960134782961436, 0.15644095758242266, 0.15290684864989348, 0.13649331725069455, 0.12487886047789029, 0.1297372526356152, 0.12842150538095407, 1.6068039281027657, 102.24891921452114, 118.38821574619838, 108.49503707885742, 85.19588593074253, 67.91607734135219, 66.33180468423026, 46.45310926437378, 69.0442007609776, 73.0003660746983, 37.93209906986782, 74.52901840209961, 17.430973597935267, 0.5618977802140372, 0.18168122534240994, 0.20433737390807696, 0.33326996543577736, 0.6093282465423856, 0.29653934495789663, 1.177457366670881, 0.6060499995946884, 0.41604059828179224, 0.336093295365572, 2.47613930276462, 2.962584423167365, 24.529303652899607, 71.96973977770124, 85.14448315756661, 71.16134466443742, 72.22259862082345, 82.62878363473075, 82.6878502709525, 73.67615481785366, 59.17232527051653, 59.17702225276402, 62.46855068206787, 65.64024353027344, 63.31623091016497, 68.4990450995309, 74.09886237553188, 79.37661675044468, 79.41930648258754, 69.55002267020089, 74.41013472420829, 77.73218658992222, 73.13652992248535, 69.85658414023263, 74.414199420384, 77.42597252982003, 75.57832840510777, 71.3440614427839, 74.63089983803886, 76.40209988185337, 68.12671198163713, 59.71113722664969, 56.68115288870675, 53.155352047511506, 64.56687886374337, 73.93320342472622, 77.37424319131034, 72.88257326398576, 64.45144149235317, 59.290118081229075, 69.33502456120083, 64.78225217546735, 82.81234809330532, 44.605211530412944, 47.320383412497385, 83.62596825190953, 68.26309817177909, 79.54599993569511, 66.49535833086286, 61.863300051007954, 57.72419561658587, 62.35884557451521, 60.3922552381243, 63.551017488752095, 56.384638513837544, 56.91344506399972, 59.304556437901084, 61.055808203560964, 57.09882647650582, 57.94060073580061, 57.69760833467756, 64.7105815070016, 63.354987961905344, 67.4769789831979, 64.35650825500488, 64.63114275251115, 59.93056828635079, 61.210933685302734, 61.556050709315706, 73.74184308733258, 75.04134382520402, 74.88244547162736, 73.24141992841447, 78.23369366782052, 67.96768161228725, 63.848574093409944, 66.03478309086391, 71.7654696873256, 76.96764155796596, 77.57480294363839, 77.41072123391288, 38.801912784576416, 3.0679358329091753, 5.147370994091034, 4.894355382238116, 1.1585218970264708, 0.7399759303246225, 0.8715653121471405, 0.12583877039807184, 0.4883717798760959, 0.27166737243533134, 0.42320793654237476, 0.12101121087159429, 1.347197298492704, 29.096455335617065, 52.7274854523795, 75.66556998661586, 81.43160901750836, 60.78482845851353, 36.61176415852138, 45.488146918160574, 68.91052436828613, 81.82602351052421, 84.18707697732108, 93.26294599260602, 31.17405182974679, 0.3964851104787418, 0.27074263777051655, 0.15303334114806993, 0.1339322818177087, 0.10969385065670524, 0.11450845694967679, 0.11720998984362398, 0.1022188306919166, 0.08061084231095654, 0.0754668072664312, 0.26065143783177647, 0.1457129389579807, 0.08373223231839282, 0.10870431589760951, 0.2129224839487246, 0.14780122547277383, 0.10100088068949324, 0.16619996034673282, 0.13895873352885246, 0.10995207394340209, 0.22055164671369962, 0.116988583867039, 0.13621062599122524, 0.07845726715666906, 0.1232372128537723, 0.24461456122142927], [0.03764948581478425, 0.023404818660180484, 0.027774770777406435, 0.009942217397370508, 0.0322342572866806, 0.00694737077823707, 0.05574593333793538, 0.018833894648456147, 0.0029332854693555938, 0.02638472563454083, 0.053473326178001504, 0.05779063754848071, 0.023824652024943913, 0.04270346908430968, 0.019919647369533777, 0.04801397930298533, 0.023088338053120033, 0.0295240900346211, 0.06296348997524806, 0.21173898316919804, 0.5628100026931081, 12.570484604154315, 92.8757576261248, 78.75767816816057, 80.94404697418213, 59.27947344098772, 36.99869196755545, 14.600746495383126, 45.87695074081421, 26.3452570438385, 32.34418405805315, 55.1457017489842, 21.082510777882167, 0.1357821718390499, 0.06595063861459494, 0.0550817832616823, 0.04498717029179845, 0.25825612779174534, 0.08628909476101398, 0.505544795521668, 0.15938879868813924, 1.0514743668692452, 1.9470157410417284, 0.07054674306086131, 0.11293730232864618, 29.22418580736433, 85.10580253601074, 77.44596944536481, 74.74512822287423, 76.06700216020856, 76.25876549312046, 75.68601853506905, 72.41359765189034, 62.41220773969378, 56.44348280770438, 55.31280245099749, 58.902742113385884, 59.433897154671804, 63.128087588718955, 63.457856042044504, 69.74537822178432, 70.15534973144531, 72.61091259547642, 66.85150909423828, 67.7953940800258, 69.41085025242397, 69.51196738651821, 68.16515636444092, 70.52994796207973, 66.53917367117745, 68.65142604282924, 66.65169974735805, 65.6294251850673, 67.26390552520752, 63.58773177010672, 51.24473639896938, 51.66731888907296, 47.70847504479544, 56.614015919821604, 65.09820066179547, 67.58560711996896, 65.75433989933559, 60.2061060496739, 51.96190166473389, 56.49041441508702, 55.340025493076865, 75.7478575025286, 49.828822067805696, 29.259371485028947, 60.68115438733782, 63.73019763401577, 71.16514532906669, 64.32072503226144, 57.59716864994594, 49.29591260637556, 55.66868570872715, 51.69815846851894, 52.18296555110386, 50.90986796787807, 54.07914979117257, 51.874451637268066, 53.01967109952654, 50.9298266683306, 52.82850183759417, 55.257119587489534, 60.9321928024292, 61.23569706508091, 65.82812976837158, 62.08857454572405, 63.48737893785749, 60.33617632729666, 57.89131716319493, 61.25572872161865, 64.07901109967912, 67.46542412894112, 69.52466174534389, 67.26580238342285, 71.18355805533272, 67.46165125710624, 58.01091650554112, 53.2468250819615, 60.850544520786826, 66.88850130353654, 74.03421633584159, 70.07690456935337, 70.2446618761335, 27.619384697505406, 0.8739413246512413, 1.177818347300802, 3.063387151275362, 0.2476078506026949, 0.07763950353754417, 0.17779311111995152, 0.13793639838695526, 0.11307599488645792, 0.10125721086348806, 0.11739721122596945, 0.003059478775997247, 5.68839247737612, 24.355126210621425, 25.363900423049927, 50.93103565488543, 58.57793467385428, 24.62596525464739, 14.398057120186941, 46.118682043892996, 61.465814454214915, 65.41296100616455, 66.9106730052403, 65.05612237112862, 9.99270292690822, 0.07688525079616479, 0.018400029179507067, 0.02053079877181777, 0.04253594218088048, 0.03185283239664776, 0.04150257066690496, 0.008217199023679962, 0.10558887664228678, 0.03635657126350062, 0.01566183164582721, 0.03211916417681745, 0.029284363612532616, 0.011553648160770535, 0.01850475088161017, 0.0437040062887328, 0.0812830398125308, 0.04669528381366815, 0.018181673217830912, 0.06754487699695996, 0.05468787671998143, 0.05094696727714368, 0.03595451551622578, 0.01019178088089185, 0.027307411123599325, 0.08791886123695544, 0.04701400528262768, 0.07518334247704063, 0.008804639019737286, 0.028324044875002334, 0.019863259413146546, 0.02053362487017044, 0.02269054520209985, 0.0842733368543642, 0.025261483853682876, 0.03546063701755234, 0.02751741771187101, 0.0706641228337373, 0.041336947054203065, 0.034199145422982316, 0.03402234294584819, 0.06279346267027514, 0.01950825158772724, 0.0464064382415797, 0.06596977330212082, 0.3723773312355791, 0.641765640250274, 18.080767393112183, 112.29894651685441, 88.93608733585903, 89.72991902487618, 73.52542754581997, 53.52887330736433, 21.526247058595928, 27.3036915574755, 16.322147062846593, 33.99310622896467, 46.53923218590872, 26.964989457811626, 0.017445162470851625, 0.07205299580735819, 0.2888648696243763, 0.09096808904515845, 0.2597600870898792, 0.4971412207399096, 1.9321730860642023, 1.166662688766207, 1.27011995443276, 3.500127464532852, 0.35348281796489445, 0.8438848288995879, 32.46074703761509, 91.16522230420793, 83.5183059147426, 80.4545533316476, 77.99694769723075, 78.07246766771588, 78.32843930380685, 77.19283267429897, 66.98426137651715, 58.4411107472011, 56.1138984816415, 60.8411922454834, 62.65709005083357, 66.49532358986991, 66.86820561545235, 71.37691947392055, 71.04273196629116, 75.26052474975586, 68.17445305415562, 70.81823566981724, 72.59301403590611, 72.15544428144182, 69.08841909681047, 72.7006972176688, 69.25582899366105, 71.56700134277344, 67.06030246189663, 67.22299453190395, 70.67449828556606, 65.57682037353516, 53.29009846278599, 54.82721369607108, 48.90762642451695, 60.29853098733084, 67.59744685036796, 71.86928967067173, 67.59812777382987, 63.3849208014352, 56.91860062735421, 58.726410729544504, 58.15517153058733, 77.85239042554582, 52.32886382511684, 33.167413575308665, 65.53445025852749, 66.91807283673967, 73.19577026367188, 66.99170984540666, 59.736421721322195, 51.63662869589669, 57.89493022646223, 54.89078623907906, 55.09660577774048, 54.60913406099592, 55.41612563814436, 53.38896438053676, 55.97144998822893, 53.281003270830425, 54.99471739360264, 58.13211393356323, 64.75786399841309, 64.77947984422956, 68.14943259102958, 67.23870440891811, 65.45909009660993, 64.38348811013358, 61.45386355263846, 65.33193806239537, 68.48050035749162, 69.16777447291783, 69.41365037645612, 69.2434334073748, 73.218275478908, 72.5712661743164, 58.745566913059776, 53.631265435900005, 65.78493281773159, 70.48221383775983, 76.56752259390694, 74.06250245230538, 73.0134425844465, 34.643530573163716, 1.8843162826129367, 0.663726127573422, 1.1266183746712548, 1.4960357461656844, 0.7172824623329299, 0.5306224184376853, 0.24250133175935062, 0.052219376500163756, 0.22968779504299164, 0.0781598516872951, 0.09796644494469677, 5.4313859939575195, 28.651039327893937, 26.33853987285069, 53.462281772068565, 40.37636068889073, 26.912301267896378, 20.97057703563145, 53.43084464754377, 66.84704835074288, 73.63130419594901, 75.81536620003837, 78.34423950740269, 13.679184334618704, 0.13272914423474244, 0.07352912838437728, 0.02402798013229455, 0.1300557976854699, 0.03008339287979262, 0.07240519619413785, 0.022490865916811993, 0.007205019854674382, 0.03381248563528061, 0.01740042326439704, 0.04987197781779936, 0.04081006461222257, 0.042097530527306457, 0.010877490559193705, 0.006944842387123832, 0.06832680718175002, 0.0736242454232914, 0.008812884916551411, 0.041921993517982106, 0.015650225304333226, 0.08108593217496361, 0.02677448293460267, 0.023873504849949052, 0.03387842906106796, 0.018986044252025228, 0.11983054636844567, 0.13803139328956604, 0.1242906248995236, 0.20337770826050214, 0.12562815312828335, 0.09405868034809828, 0.199219442105719, 0.24625029202018464, 0.09775454524372305, 0.13127764926425048, 0.15166146547666617, 0.16677176180694783, 0.09195055346935987, 0.12678103840776853, 0.16591766263757432, 0.23949715867638588, 0.13979888201824256, 0.13872419111430645, 0.2471508708383356, 0.6326965583222253, 0.8223144177879605, 22.473086765834264, 133.4698783329555, 100.59528269086564, 105.13166427612305, 80.9365359715053, 54.36423437935965, 24.32889676094055, 66.67421191079276, 40.49101986203875, 47.38919489724295, 84.80833625793457, 35.50298452377319, 0.4702950098684856, 0.2246308499681098, 0.3936770340161664, 0.2984366374356406, 0.7519669468913759, 0.523232520690986, 2.616862471614565, 2.1170479314667836, 3.669362783432007, 5.674257670130048, 1.980765095778874, 1.891047784260341, 38.43295649119786, 95.5636682510376, 84.35975360870361, 81.11165836879185, 80.18263557979039, 78.46158068520683, 80.93824522835868, 80.62269973754883, 70.53786890847343, 61.09182071685791, 59.48742607661656, 64.24234935215541, 64.90569387163434, 70.27589402879987, 70.95949254717145, 74.45128195626395, 74.47739328656877, 77.86483464922223, 69.32952853611538, 72.5047093800136, 75.45631803785051, 74.82512978145054, 72.94321019308907, 77.43649210248674, 71.83759198869977, 73.88378783634731, 69.53401402064732, 70.67893123626709, 74.81874438694545, 69.42571244921002, 57.13962629863194, 58.128292424338206, 52.59282241548811, 63.4682366507394, 71.1297859464373, 75.46804659707206, 71.02699429648263, 66.93504728589738, 60.44593702043806, 61.46315329415457, 61.18781008039202, 81.03019768851144, 57.565269470214844, 38.1881297656468, 69.05108642578125, 70.06877517700195, 77.8740062713623, 71.86487756456647, 64.45762538909912, 54.868013518197195, 63.17735726492745, 59.15852614811489, 59.2654241834368, 57.01988451821463, 58.00690392085484, 56.28495270865304, 57.839341163635254, 56.43146937234061, 58.34553132738386, 61.7853273664202, 68.06397669655937, 68.26983792441231, 72.69191469464982, 68.33350426810128, 68.71222278050014, 67.35409314291817, 63.586105891636436, 67.63027708871024, 72.297041620527, 73.47123854500907, 72.29928588867188, 71.26437950134277, 77.53738689422607, 74.68408829825265, 62.87198393685477, 57.89961331231253, 66.66337272099086, 73.26118060520717, 81.53244822365897, 77.03123841966901, 75.53439494541713, 32.036476135253906, 2.3907559301171983, 5.6273647121020725, 6.572578106607709, 1.5724379207406725, 0.5087792362485613, 0.6954008479203496, 0.7615038922854832, 0.31557073231254307, 0.5600530334881374, 0.17746114464742796, 0.24687592844877923, 9.951943925448827, 41.52875416619437, 36.59929214205061, 64.88165310450962, 76.74804374149868, 33.772754532950266, 21.2345130443573, 61.079063824244905, 76.79158810206822, 84.16041673932756, 85.75927366529191, 87.75754778725761, 14.38481993334634, 0.23972197089876446, 0.11597053706645966, 0.10668162336306912, 0.19536036918205874, 0.13650873356631824, 0.1614938314471926, 0.09965589536087853, 0.20766801732991422, 0.08546054922044277, 0.11996899465365068, 0.11029668152332306, 0.08384286745318345, 0.09388207125344447, 0.0782575878713812, 0.15211153775453568, 0.19905782863497734, 0.16148110213024275, 0.07457534117358071, 0.14593739834214958, 0.0629103064004864, 0.18728094414940902, 0.1303136409925563, 0.1233529302158526, 0.14259785254086765, 0.1625067756644317], [0.030204616553549255, 0.033892020117491484, 0.03391914116218686, 0.042549278786672015, 0.02439138652490718, 0.03568528978420155, 0.021766214265621135, 0.010183207590931227, 0.007296115725434252, 0.018971035057412725, 0.04149395327216812, 0.03720251104927488, 0.033027546147682836, 0.027398126166579977, 0.03900723438709974, 0.04716455184721521, 0.03186036413535476, 0.07116320569600378, 0.07059540759239878, 0.13926229652549538, 0.11340059925402914, 44.88755505425589, 94.23164299556187, 81.11165142059326, 82.03699166434151, 45.27955852236067, 29.05905144555228, 105.51810918535504, 143.963200705392, 102.06028951917375, 52.52164854322161, 40.6082637650626, 3.1371129666055952, 0.1379970187055213, 0.031975599737571817, 0.09063515226755824, 0.06094851238386972, 0.2911233055804457, 0.25121450849941795, 1.5562443839652198, 1.6325953155755997, 1.709718474320003, 0.849758716566222, 0.620313891342708, 47.54965659550258, 84.8496641431536, 74.94670241219657, 72.69175488608224, 73.98387663705009, 75.88108921051025, 79.28011322021484, 74.60478155953544, 73.57542678288051, 59.18459578922817, 54.18033293315342, 55.09937116077968, 62.81797558920724, 65.01461383274624, 67.01959991455078, 67.48433017730713, 72.12780434744698, 70.77713012695312, 73.03214018685478, 66.45798397064209, 66.20263072422573, 65.69493974958147, 71.98506750379289, 69.84352152688163, 69.12079075404576, 69.21507086072648, 70.0682679585048, 62.435866355895996, 66.13926315307617, 67.79112788609096, 60.623060498918804, 49.21029690333775, 52.00342409951346, 48.546747412000386, 54.818868909563335, 65.37477370670864, 66.3519058227539, 60.172504561288015, 55.32796689442226, 52.85885851723807, 56.81055613926479, 58.06065171105521, 70.8860639844622, 51.803086689540315, 32.82276208060128, 59.39341694968087, 62.70998668670654, 67.61918776375907, 63.36987100328718, 55.403542450496126, 49.46808549336025, 51.61766011374337, 51.333072321755544, 52.209309646061485, 50.199227060590474, 53.76637315750122, 52.82173776626587, 52.44962699072701, 50.53440816061837, 52.10825157165527, 57.36233343396868, 62.77302769252232, 64.97393907819475, 66.1183282307216, 65.33462006705147, 62.78863334655762, 62.316051619393484, 65.70659187861851, 64.48949677603585, 68.05628504071916, 68.32363087790353, 61.238622256687705, 60.37559345790318, 67.69165747506278, 68.52674756731305, 61.45715699877058, 52.79444524220058, 58.84466906956264, 65.37168175833565, 68.39662170410156, 71.09998512268066, 70.20397322518485, 68.29833943503243, 19.503325939178467, 1.1302330664225986, 0.8003046959638596, 2.0954207948275974, 0.5147686377167702, 0.08471331931650639, 0.16647798328527383, 0.08259184565395117, 0.07580606120505504, 0.02290772390551865, 0.043620811110096316, 0.10873814765363932, 10.573620097977773, 48.89149965558733, 34.099990367889404, 40.23356131144932, 47.87472806658064, 37.17778526033674, 36.35124840055193, 48.66004473822457, 60.652013642447336, 63.48846285683768, 71.42244407108852, 52.18079423904419, 1.800436217870031, 0.029617174861154387, 0.05222028912976384, 0.027170477667823434, 0.031044222214924436, 0.018411672840427076, 0.006149771523528865, 0.04922276908265693, 0.03408097176413451, 0.04127717829708542, 0.040890216561300416, 0.03208476584404707, 0.040138881520501206, 0.018701644780646478, 0.03939496626013091, 0.017609484992655258, 0.023160032063190426, 0.12873367220163345, 0.08128846809267998, 0.016164531099743078, 0.0036453738326339847, 0.025980809004977345, 0.036466375192893405, 0.06257532044712986, 0.11371174827218056, 0.04836084979719349, 0.015329432607229267, 0.04119720955246261, 0.035386144050530026, 0.018112503358029892, 0.004944661524080272, 0.010318883212416299, 0.033967357860612016, 0.044403477505381615, 0.04579360576878701, 0.006629117074356015, 0.023406967919852053, 0.020226533491430537, 0.08795200088726622, 0.021570083718480806, 0.06019408322338547, 0.057787224517336915, 0.047011074011347125, 0.024262676913557307, 0.019121172804651514, 0.087631617007511, 58.69346237182617, 107.60390976497105, 91.17768042428153, 92.49726145608085, 60.96186855861119, 37.51057618004935, 74.8050286429269, 112.61072608402797, 77.78117833818708, 51.11650044577462, 47.40769795009068, 3.152878212077277, 0.1076087329004492, 0.16079879445689066, 0.20286708351756844, 0.07001662400684186, 1.081689368401255, 1.640956061226981, 2.8347688359873633, 2.024363956281117, 1.1587828887360436, 0.4170283281377384, 1.8892521091869898, 53.458793776375906, 89.66120828901018, 77.92069121769497, 76.1778120313372, 79.57861477988106, 80.20666939871651, 82.89915193830217, 77.51927294049943, 77.29468631744385, 63.124933106558665, 56.33430576324463, 58.01049613952637, 67.47822965894426, 67.02882017408098, 70.11909403119768, 70.72522708347866, 73.93579510280064, 72.16957691737584, 73.67064489637102, 68.04653671809605, 66.00947080339704, 67.12942314147949, 74.90174061911446, 71.93185819898332, 71.22822802407401, 71.50473158700126, 72.46017837524414, 66.87709930964878, 69.9621272768293, 68.98698929377964, 65.10382175445557, 51.745531286512104, 53.13463946751186, 50.87763180051531, 58.117237840379985, 66.59175068991524, 68.65330900464738, 62.925353050231934, 59.13969652993338, 54.256808280944824, 59.01510838099888, 60.913932936532156, 72.94753892081124, 55.161713872637065, 35.78959424155099, 64.46528925214494, 64.92854649680001, 69.87061950138637, 65.36728354862758, 57.08623286655971, 51.98323610850743, 55.18995482581002, 53.905844347817556, 53.98304925646101, 53.47869689123971, 55.21297768184117, 54.714604241507395, 55.45016833714077, 53.268242904118125, 54.853714125497, 59.1502925327846, 65.80538831438336, 68.16341236659459, 67.45509215763637, 67.2903573172433, 65.93199144090924, 64.58552088056291, 68.75318935939244, 68.66903277805874, 72.48772798265729, 69.44050516401018, 62.890709332057405, 61.15532725197928, 70.9666769845145, 70.68307931082589, 64.0458265032087, 54.25161797659737, 61.305123465401785, 68.63787010737828, 70.14391994476318, 74.3743862424578, 73.32869625091553, 70.47162478310722, 23.127869367599487, 0.29545238614082336, 0.5231081587927682, 2.2513948253222873, 1.9756538271903992, 0.8288581009422029, 0.29252635315060616, 0.4702022948435375, 0.4654660118477685, 0.13174092583358288, 0.010650100751913019, 0.06086843168096883, 12.227810740470886, 45.78235101699829, 30.57579803466797, 34.55334642955235, 38.053522314344136, 34.98635469164167, 43.07835878644671, 58.905966077532085, 66.84016268593925, 70.60562774113247, 80.09298992156982, 67.57464981079102, 3.296495957033975, 0.051144424360245466, 0.06579743897808449, 0.05378891620784998, 0.03250042282577072, 0.09127223558191742, 0.03697205680821623, 0.05963188303368432, 0.033919541497847865, 0.021180640240865092, 0.037968536373227835, 0.04309456649103335, 0.03336872034040945, 0.01561329433960574, 0.010715335956774652, 0.02104852268738406, 0.017143657131652747, 0.04528959334961005, 0.08812632331890718, 0.024277233186044862, 0.03222117173884596, 0.05175433913245797, 0.05770227193300213, 0.016022708799157823, 0.029149664233305624, 0.20905374868639878, 0.11702213063836098, 0.10269398162407534, 0.1372197161295584, 0.08983246569654771, 0.1430933323821851, 0.09054296649992466, 0.10123251897415944, 0.16436251465763363, 0.0858901229553989, 0.14160791066076073, 0.11073464873645987, 0.1955753562173673, 0.1518882725919996, 0.12468439234154564, 0.16447120239692076, 0.1394033096730709, 0.1273091829248837, 0.09632571334285395, 0.21984603814780712, 0.17580398571278366, 72.4188574382237, 119.88737297058105, 104.5044503893171, 102.40027182442802, 66.21217060089111, 40.90807506016323, 119.37758363996232, 154.35460690089633, 110.47504438672746, 73.13707188197544, 62.32632800510952, 5.250555217266083, 0.28902087839586393, 0.32278450950980186, 0.4203179201909474, 0.42985608694808825, 1.4019601770809718, 2.0344004120145525, 5.180263766220637, 6.573396256991795, 6.710033885070255, 5.220982815538134, 2.843736571925027, 59.65107004983084, 91.20585536956787, 80.03325625828334, 79.47322450365338, 83.15283066885812, 81.20702239445278, 85.05797113691057, 80.09486593518938, 80.38382761819022, 66.20785576956612, 58.179802894592285, 59.8832996913365, 71.1121027810233, 70.6232761655535, 71.23793465750558, 75.06537069593156, 78.00627217973981, 75.8752110345023, 76.45180034637451, 69.62661961146763, 68.78804847172329, 68.87877804892403, 77.34281648908342, 75.61605712345668, 73.71707275935582, 74.57597432817731, 75.26351942334855, 70.06357792445591, 73.01772962297711, 73.4473158972604, 67.56472083500454, 54.95212493624006, 56.23249380929129, 53.940272671835764, 59.769932883126394, 71.17411545344761, 71.48678439004081, 66.51756477355957, 60.73744174412319, 57.86818313598633, 62.74520015716553, 64.79171562194824, 77.84102317265102, 59.897300311497276, 42.098350116184776, 65.06271621159145, 69.73599120548793, 73.04947594233921, 69.18926525115967, 59.34137494223458, 55.980343682425364, 57.87122644696917, 57.605530806950156, 58.00173098700387, 54.91636603219168, 57.09749242237636, 57.43590096064976, 58.45825890132359, 56.91528633662632, 58.1013195174081, 64.56146621704102, 68.152329989842, 70.26074695587158, 69.64186395917619, 71.669403893607, 66.68254280090332, 67.7123144694737, 73.26060390472412, 72.30647727421352, 75.07886409759521, 72.4177109854562, 63.65754726954869, 62.74765287126814, 74.25721876961845, 73.43553870064872, 66.71456010001046, 58.892931256975444, 63.41686167035784, 71.75027397700718, 74.00624288831438, 76.70449938092912, 75.64016042436872, 74.36367906842912, 21.995656933103287, 2.6021031950201308, 6.773842666830335, 7.459495680672782, 2.592187898499625, 0.5317984010492052, 0.6650083416274616, 1.1488004986728941, 0.5604626515081951, 0.2760145291686058, 0.12287969275244645, 0.16474720330110618, 19.140136650630406, 70.56780174800328, 45.28740998676845, 57.08546161651611, 63.92346177782331, 50.5524456841605, 49.3158608845302, 66.29210267748151, 76.93801443917411, 80.44437422071184, 88.88110624040876, 75.45461572919572, 3.5614707214491705, 0.15017419813999108, 0.15502436645328999, 0.11511233954557351, 0.09692177921533585, 0.2545549363962242, 0.06413006130605936, 0.18897454041455472, 0.1938867811113596, 0.14939737053854124, 0.1415753952626671, 0.12533182331493922, 0.14354875151600155, 0.1171095259487629, 0.13722127676010132, 0.11343782368515219, 0.11105247453919478, 0.18937072344124317, 0.17887662297913007, 0.1046620181628636, 0.08190523606858083, 0.16049160808324814, 0.0951147929632238, 0.11769455884184156, 0.1605784741363355], [0.039547589141875505, 0.026197178555386405, 0.029597748403570483, 0.06438179101262774, 0.009637515310065022, 0.03075876592525414, 0.03515170341623681, 0.01359045337553003, 0.03507487628875034, 0.040359815915248225, 0.05269714318481939, 0.08298535525266613, 0.05529129791206547, 0.035502709581383636, 0.023321491167215363, 0.07123700994998217, 0.023706608984087194, 0.0757448777024235, 0.05294641659462026, 0.09685962540762764, 3.4504658664975847, 77.30370507921491, 81.83537578582764, 77.10921805245536, 61.6695773260934, 47.048180784497944, 33.0899133682251, 86.6932852608817, 114.62630816868374, 66.77663530622209, 41.36570078986031, 12.173930934497289, 0.14281830856842653, 0.11007027474365064, 0.12736322145376885, 0.013384948018938303, 0.32952494067805155, 0.018666834237852266, 1.9225255123206546, 2.0228850756372725, 1.3187498535428728, 0.9515150849308286, 2.643650599888393, 45.696182932172505, 83.09909330095563, 70.89649323054722, 75.54672104971749, 65.8586323601859, 68.32889761243547, 73.89158371516636, 74.6473879132952, 74.8339262008667, 71.5844760622297, 57.26636144093105, 52.81842694963728, 60.48196343013218, 66.70358889443534, 68.7838100705828, 69.57794053213937, 69.14009979793003, 68.55989047459194, 71.2630593436105, 67.41299302237374, 68.5187223979405, 66.67388534545898, 68.54085935865129, 66.89845807211739, 68.36758518218994, 70.3180626460484, 64.69772733960832, 64.69997160775321, 66.67114080701555, 68.22615459987095, 69.29134818485805, 56.644733905792236, 46.88386978421892, 51.20202929633004, 48.236684049878804, 53.74840859004429, 62.69955049242292, 62.2499395098005, 55.993566104343955, 58.290696144104004, 57.855332442692344, 62.537713050842285, 58.31756482805525, 72.02205276489258, 51.76535102299282, 33.63775798252651, 70.68109212602887, 56.71495240075247, 61.41938659123012, 54.90842424120222, 52.966037954602925, 48.80917045048305, 49.9754672731672, 49.63024950027466, 50.77013622011457, 49.608234133039204, 52.97459118706839, 50.62274060930525, 51.22076163973127, 49.354194096156526, 54.8132895060948, 58.425164631434846, 63.86315836225237, 63.32351262228829, 66.79774393354143, 64.9446941103254, 66.00230721064976, 63.77577086857387, 65.42254257202148, 66.98019668034145, 66.16774381910051, 61.676956312997, 65.00358009338379, 64.71051202501569, 65.23049436296735, 68.30210535866874, 65.02049895695278, 50.18872833251953, 58.0420583316258, 63.17087459564209, 68.9832511629377, 67.6816520690918, 69.37574795314244, 68.92717225211007, 64.48472336360386, 10.742590733936854, 1.265089892915317, 1.5724578968116214, 1.6537049199853624, 0.33849164524248665, 0.1172948202916554, 0.15605508828801767, 0.1500929639275585, 0.3210822551378182, 0.11087035574018955, 0.12759822527212755, 0.27981532950486454, 21.700452293668473, 36.62036950247628, 41.00293186732701, 37.032831941332134, 49.438368047986714, 35.265839031764436, 28.599085909979685, 48.68248394557408, 60.9632443019322, 67.37700830187116, 75.48327010018485, 24.740617479596818, 0.1347188124699252, 0.048683866392821074, 0.06954310155872788, 0.053111297211476734, 0.08478989199336086, 0.024994709329413514, 0.01945034201656069, 0.004950529579738421, 0.07877998519688845, 0.041600279709590335, 0.012631613844340401, 0.07852001807519368, 0.039955914552722654, 0.015403101154203926, 0.0690256914656077, 0.07540824969432183, 0.055329346763236184, 0.02742111323667424, 0.028853134252130985, 0.052820063196122646, 0.030587330660117523, 0.06589756360543625, 0.010840993008709379, 0.05151392399732556, 0.00861592570851956, 0.031009277661464045, 0.07454967219382524, 0.027750384228836213, 0.03313029331288167, 0.023780888212578635, 0.08815198551331248, 0.04781919225518193, 0.020750213248123015, 0.04657363605552486, 0.061824358600590906, 0.04210958130923765, 0.07071753032505512, 0.052282235984291346, 0.09977047278412751, 0.018660457705014517, 0.012295042663546545, 0.06937086901494435, 0.14729965238698892, 0.1537152552711112, 5.9478924955640515, 95.54595034463065, 90.95353153773716, 86.75942516326904, 69.88947691236223, 61.142966406685964, 37.048698152814595, 102.86477974482945, 138.8589984348842, 78.18566077096122, 50.1653094291687, 13.585726720946175, 0.14169968930738314, 0.07628218922764063, 0.2292581738105842, 0.23057797870465688, 1.0594375452825, 0.7789234061326299, 2.0392726191452573, 1.4572329883064543, 0.7583219430276326, 0.5648320370486805, 3.96061954327992, 51.50579064232962, 86.62267766680036, 75.77403136662075, 79.619553565979, 70.68379497528076, 70.72002983093262, 77.90701716286796, 78.07110582079206, 78.1909761428833, 75.49990408761161, 60.10447474888393, 55.87678773062569, 62.13410609109061, 68.85949679783413, 71.92962087903703, 73.17118058885846, 72.16938931601388, 72.00253527505058, 72.75754043034145, 68.13621016911098, 69.1943860735212, 69.13880743299211, 69.40966211046491, 69.04001099722726, 70.80342905861991, 70.94775703975132, 67.64262403760637, 68.72359698159354, 67.93494170052665, 69.67327676500592, 71.11377034868512, 59.20730250222342, 49.27236863545009, 53.87736368179321, 51.146134512765066, 57.471767561776296, 64.77846540723527, 63.77080290658133, 59.806994574410574, 61.058775084359304, 62.23926707676479, 66.20707757132394, 61.305707114083425, 73.20765168326241, 54.10580308096749, 37.90932982308524, 72.41322939736503, 59.3712591443743, 64.94898809705461, 56.27231740951538, 54.98568820953369, 51.31136614935738, 54.22644465310233, 53.08442483629499, 54.143101011003765, 52.56571749278477, 55.889763491494314, 53.060140882219585, 53.14700378690447, 51.827217783246724, 57.28368330001831, 61.63749054500035, 66.65387453351701, 66.29877989632743, 68.33171163286481, 67.26180022103446, 68.67170088631767, 67.15142808641706, 68.09781442369733, 70.65031160627092, 69.26495197841099, 63.733532769339426, 67.15620844704765, 66.95327935900006, 66.91473770141602, 71.7729390008109, 67.22653811318534, 53.44756548745291, 60.63227381025042, 66.2916510445731, 71.09605244227818, 71.4642722266061, 72.6537412915911, 71.21407454354423, 67.31207738603864, 14.660026788711548, 0.582789982003825, 1.3382156661578586, 1.2904221564531326, 2.039219639131001, 1.0338618776627948, 0.30187938841325895, 0.47823034120457514, 0.2640387389276709, 0.25619636688913616, 0.06253598577209882, 0.07972579515938248, 23.837692124503, 33.8383663722447, 41.54770885195051, 30.970257690974645, 53.10899019241333, 45.0206686428615, 33.62545272282192, 57.59148849759783, 66.55944851466587, 74.98885018484933, 87.7869039263044, 35.735690116882324, 0.10092882027051278, 0.050369327023093186, 0.04890796954610518, 0.037451438406216245, 0.07611780054867268, 0.005910324997135571, 0.020708349333809953, 0.11194729938038758, 0.024751008388453295, 0.012635252488377904, 0.03876400672431503, 0.050589759301926406, 0.023615013541919843, 0.04076086403802037, 0.01171750164524253, 0.035784820693411996, 0.036345389006393294, 0.048596555899296484, 0.04625076873760138, 0.04347186249547771, 0.0851671981758305, 0.02549446394134845, 0.004973193073445665, 0.042347519791552, 0.17335338863943303, 0.10325208346226386, 0.22850890830159187, 0.19810220705611364, 0.10964567467038121, 0.12071891155626092, 0.13881791037108215, 0.18106276781431266, 0.12360488383897714, 0.12049950047263078, 0.10261386020907334, 0.15023610767509255, 0.2021691288266863, 0.14558701642921992, 0.1859560909547976, 0.1670678880597864, 0.19870744672204765, 0.15975547901221684, 0.30599880165287424, 0.32837509523544994, 7.846145561763218, 109.33615820748466, 102.38465227399553, 100.13502706800188, 82.56302588326591, 63.68583338601248, 45.60762814113072, 98.68719618661063, 117.76596287318638, 78.00664738246373, 62.7681222643171, 19.33679846354893, 0.25779116845556665, 0.2670011685362884, 0.39554650655814577, 0.5092343975390706, 2.057456271989005, 0.3590347543358803, 6.09066538299833, 5.805087906973703, 4.1181447591100415, 2.8852959190096175, 6.620819449424744, 58.34206417628697, 86.55473123277936, 77.21908991677421, 82.010790007455, 74.2278973715646, 73.60483850751604, 82.5230598449707, 79.04952335357666, 80.94303948538644, 78.15361567905971, 62.48815849849156, 58.351881980895996, 66.59826810019356, 71.81091785430908, 74.2751520701817, 75.46065371377128, 75.025071144104, 72.98485769544328, 75.53378350394112, 70.37302984510148, 70.76064205169678, 71.58840874263218, 73.88108498709542, 72.3404539653233, 72.92857728685651, 75.20152759552002, 72.25495638166154, 71.36768531799316, 72.74983487810407, 73.1829160962786, 77.06788321903774, 62.187801769801546, 51.77239997046334, 55.994028159550254, 54.59305592945644, 60.3983279636928, 69.8353921345302, 68.35443919045585, 62.79538699558803, 64.91733210427421, 67.11992495400565, 70.6862268447876, 65.22531795501709, 77.16698537554059, 58.21380737849644, 41.575856004442485, 75.85236535753522, 64.01929133278983, 68.68689659663609, 62.10641751970564, 57.88481364931379, 54.93763099397932, 58.357371057782856, 56.65812308447701, 57.43711689540318, 54.84647062846592, 57.859758445194785, 55.74849966594151, 55.445106574467246, 54.182907240731375, 60.87490490504673, 64.24411419459751, 69.36422783987862, 68.88428797040666, 70.6579337801252, 69.80977412632534, 71.77173001425606, 70.61425045558384, 71.50391864776611, 73.64969607761928, 70.3647267477853, 64.30267361232212, 70.17530495779855, 67.92579092298234, 68.94084630693708, 75.02581460135323, 71.14953967503139, 56.21807629721505, 64.41335146767753, 68.95526381901333, 74.92053549630302, 73.44641957964215, 75.72196851457868, 73.40009593963623, 71.82114560263497, 13.637400473867144, 2.7973078404154097, 7.651194742747715, 6.340767962591989, 2.5839842472757613, 0.6400473724518503, 0.4857674539089203, 1.1513953251498086, 1.1919299215078354, 0.34839190542697906, 0.34163934205259594, 0.5729574667555946, 35.451515742710654, 54.582480771201, 57.54786770684378, 53.08235427311489, 62.10857840946743, 46.0491236277989, 42.39084843226841, 65.90898595537458, 79.02391229357038, 84.77040604182652, 98.80738612583706, 39.14860010147095, 0.23795674847705023, 0.17045581340789795, 0.1906007310109479, 0.1961578649601766, 0.1127311091071793, 0.2767113303499562, 0.15718251493360313, 0.20902725867927074, 0.17482618960951055, 0.14268200445388043, 0.1733196654490062, 0.2317339852452278, 0.10755370371043682, 0.09401416845087494, 0.17647201700934342, 0.11659926761473928, 0.11796039529144764, 0.08484087032931191, 0.14021983157311166, 0.16169412141399725, 0.10986668709665537, 0.13704886101186275, 0.07720399940652506, 0.16398725765092032], [0.0338977333823485, 0.02706778308908854, 0.014380842347496321, 0.037324325048497746, 0.08019655596997056, 0.051247911128614626, 0.0745598366484046, 0.03912225964346102, 0.06949712402586426, 0.0336179530381092, 0.046868255960622, 0.0316668086286102, 0.018154669220426252, 0.015485643242884959, 0.14202329622847693, 0.03526573122612067, 0.09425422056977238, 0.11051531229168177, 0.34018746710249353, 0.6727724650076458, 23.9091317653656, 91.55458545684814, 76.04664393833706, 76.55698912484306, 64.17609827859062, 31.843013967786515, 68.32000391823905, 90.59393446786063, 41.278726713997976, 44.385954175676616, 32.552143641880576, 1.4432431161403656, 0.16862912928419455, 0.14266409112938813, 0.6209378178630556, 0.12432912497648171, 0.24271512457302638, 1.322209622178759, 1.4308380846466338, 1.9226286496434892, 0.14452324993908405, 2.3243667611054013, 37.29630068370274, 83.87878540584019, 75.74871213095528, 80.38254914964948, 69.17654309953961, 63.5397127696446, 63.402701241629465, 74.97901153564453, 76.08574840000698, 74.81251185280937, 68.31483445848737, 58.33257988521031, 48.865065234048025, 62.30193287985665, 69.42280115400041, 73.18349974496024, 66.92792538234166, 69.24037619999477, 68.11149542672294, 69.77039868491036, 66.55361897604806, 65.99644293103898, 66.58720656803676, 63.68671580723354, 61.699489321027485, 66.62269796643938, 63.334518568856375, 60.98728506905692, 58.97824818747384, 62.912422452654155, 62.96891825539725, 59.926010268075125, 47.97197505405971, 48.94950669152396, 48.6000713620867, 49.23795420782906, 48.501657077244346, 55.674869605473106, 60.73814351218087, 58.93744836534773, 64.21529306684221, 63.15059280395508, 68.48946353367397, 61.509212902614046, 71.00298827035087, 47.31248678479876, 38.61114304406302, 68.37565204075405, 53.67903430121285, 55.75729261125837, 46.927862303597585, 50.29759618214199, 47.772971698216026, 50.54480961390904, 48.30538783754621, 50.86213731765747, 48.919302872249055, 48.79127883911133, 50.02533796855381, 50.2552364894322, 49.10508380617414, 52.801942348480225, 56.93155901772635, 63.68741062709263, 65.07667514256069, 63.51991735185896, 61.98194749014718, 63.23064299992153, 63.801138741629465, 66.38351317814418, 62.52781881604876, 62.05411842891148, 67.0430292401995, 67.9806261062622, 64.83457211085728, 67.28460420880998, 67.25388622283936, 66.93933432442802, 51.28653328759329, 53.09357908793858, 64.2539667401995, 62.48196765354702, 68.38681779588971, 67.29669407435826, 71.21205956595284, 67.28043528965541, 65.85061413901192, 10.073699814932686, 2.300306235040937, 0.47610918645347866, 1.3711939879826136, 0.6489343355808939, 0.15957645433289663, 0.38689909343208584, 0.08121008372732572, 0.13897448911198548, 0.054288151740495644, 0.04029218972261463, 6.064428116594042, 27.86198452540806, 30.875352246420725, 48.20696313040597, 32.61122417449951, 51.677108900887625, 30.030256748199463, 36.18746893746512, 50.13688782283238, 63.41399901253836, 65.5881598336356, 63.755919865199495, 1.078468769788742, 0.0980390210502914, 0.04182156354987195, 0.0724975923076272, 0.060302960952477794, 0.05566816304677299, 0.042674950257475884, 0.04445689517472472, 0.04370609278391514, 0.04954732256010175, 0.09482364715742213, 0.046779808920941184, 0.06874933772321258, 0.08411791162299258, 0.03337757522240281, 0.041777777685118575, 0.044340180366167, 0.09594660225723471, 0.05985433395419802, 0.07529941267733063, 0.10280696449003049, 0.014926101214119365, 0.017404508045209304, 0.07320527719067675, 0.0680397122300097, 0.02323731889815203, 0.03089850681966969, 0.07605028631431715, 0.021721081508855735, 0.04700242268985935, 0.08181589336267539, 0.08367286728961126, 0.042499199509620667, 0.05889371157224689, 0.12734103335865907, 0.025908441548900943, 0.013307925812633974, 0.027652125572785735, 0.11948922968336514, 0.012973110341200871, 0.08793929871171713, 0.11450705916753837, 0.24295985858355248, 0.5954202328409467, 30.574140889304026, 106.93402699061802, 84.96519878932408, 88.36081123352051, 72.4168563570295, 41.26307937077114, 56.81451661246163, 89.33209296635219, 42.830982072012766, 46.23078080586025, 36.17607389177595, 1.8097066347088133, 0.10805211482303483, 0.09226385344352041, 0.7168909747685704, 0.19959507909204277, 0.6631051866071564, 2.1800615787506104, 0.9023235759564808, 1.9184981627123696, 0.39650630791272434, 3.309882095881871, 42.67094421386719, 86.96784332820347, 80.20512689862932, 84.7502771105085, 71.65108844212124, 66.44627625601632, 68.35030501229423, 79.3629982812064, 77.31703172411237, 76.77626732417515, 72.46760599953788, 59.939329964774, 52.25054373059954, 65.34916264670235, 74.20404420580182, 75.28497546059745, 70.01837989262172, 72.35436425890241, 70.28283527919224, 70.61595276423863, 69.67135211399624, 68.1777673448835, 69.02008356366838, 67.64818259647915, 64.36936242239815, 68.62215328216553, 66.09068134852818, 63.31378514426095, 62.93012646266392, 65.89510345458984, 65.49246924264091, 62.345755168369834, 49.69176190240042, 51.205155985695974, 50.68624367032732, 51.8417638369969, 51.33040768759591, 57.94873707635062, 63.0923182623727, 61.439265387398855, 66.17656108311245, 66.84079497201103, 71.55819797515869, 64.2065452848162, 72.29637459346226, 48.79424919400896, 41.78852299281529, 71.44376114436558, 57.074539048331125, 57.705772468021934, 48.590093748910085, 52.17508976800101, 51.31494099753243, 52.53800460270473, 51.989058698926655, 53.20611211231777, 51.52443960734776, 50.858805656433105, 53.85233974456787, 51.79251153128487, 50.82926191602434, 55.490856988089426, 59.5983818599156, 67.63344546726772, 66.29263768877301, 65.012953213283, 63.641510827200754, 66.48699964795793, 66.483872958592, 66.56622300829206, 66.40604618617466, 63.202349935259136, 69.8094128199986, 69.2700172151838, 67.9290635245187, 69.78516360691616, 70.43955189841134, 69.7014239174979, 55.824749197278706, 54.56492962156023, 67.85059056963239, 66.57501942770821, 70.53236593518938, 69.58629921504429, 76.26855550493512, 68.33736051831926, 71.08314963749477, 13.81865291936057, 1.1455300684486116, 1.2227534332445689, 3.2294527888298035, 1.6312192465577806, 0.39739836433104103, 1.3677950160843986, 0.5105954845036779, 0.3331644396696772, 0.1031672665849328, 0.047006714423852305, 5.068569302558899, 33.22552830832345, 30.731614862169536, 41.36318554197039, 32.76903166089739, 48.15693957465035, 39.23716184071132, 46.99215398515974, 53.15903459276472, 70.08379718235561, 73.46089267730713, 81.80285821642194, 2.491930386849812, 0.1367921576436077, 0.05470870774505394, 0.05100952142051288, 0.016403482295572758, 0.04979001418022173, 0.0169421407128019, 0.014920455802764212, 0.08590247907808848, 0.036858710926026106, 0.07230315809803349, 0.016625154597152556, 0.06285480902131114, 0.043083509762904475, 0.016420357461486543, 0.026121101209095547, 0.04856042730222855, 0.025511103316343257, 0.02538236995626773, 0.061088982703430314, 0.015454664726608565, 0.018113833286666443, 0.04740282281168869, 0.048338247795722315, 0.12508630220379147, 0.06769309618643352, 0.12071298116019794, 0.16974404374403612, 0.15410336373107775, 0.1048165409426604, 0.14825990157467978, 0.1373870971479586, 0.20144899961139473, 0.1309241596609354, 0.2598904200962612, 0.17612415924668312, 0.1444322991051844, 0.16042090473430498, 0.2641335709818772, 0.26493147388100624, 0.24768751061388425, 0.2154297929789339, 0.3937405991767134, 0.8596534941877637, 34.96710818154471, 115.957457951137, 97.45045852661133, 97.70499883379254, 83.41934272221157, 44.28760589872088, 81.99268995012555, 101.37723990849086, 54.42333228247506, 63.80691269465855, 49.37714747020176, 2.83793243765831, 0.32213960268667763, 0.432045258049454, 1.5381752678326197, 1.3566794182573045, 0.4835130348801613, 3.8870976141520908, 5.136248230934143, 5.653684054102216, 3.2836430924279347, 3.559931044067655, 49.75187076841082, 89.57345948900495, 82.80699103219169, 86.49767957414899, 73.1695477621896, 68.31602260044643, 71.14426599230084, 81.82899039132255, 80.92632906777519, 78.44117382594517, 75.89848055158342, 63.12678827558245, 54.661290713718955, 66.60095010484967, 76.00082751682827, 79.85295050484794, 72.23334748404366, 74.63142095293317, 71.5159181867327, 72.3614444732666, 72.0204963684082, 71.55576610565186, 71.18414865221295, 68.91230310712541, 66.65684141431535, 72.70717988695417, 69.08896105630058, 65.34361798422677, 65.1244648524693, 69.28817980630058, 67.27362605503627, 66.46546023232597, 53.00000769751412, 53.4436605998448, 51.99207074301583, 55.875821931021555, 52.280469621930806, 60.72068963732038, 66.76511519295829, 64.76401315416608, 69.52162538255963, 69.91997255597795, 75.34424359457833, 67.94902569907052, 73.64020483834403, 53.152333055223735, 45.5437776701791, 75.18384443010602, 61.500416483197895, 61.91859381539481, 51.63600335802351, 55.29226010186331, 53.235075678144185, 55.13111400604248, 54.27970954350063, 57.0993823323931, 53.79941184180123, 53.80262885774885, 55.72331244604928, 55.33685711451939, 54.07991409301758, 57.67031233651297, 63.739980697631836, 70.9938166482108, 69.43200751713344, 67.05676582881382, 67.62501035417829, 67.8986234664917, 70.62014947618756, 70.16799545288086, 66.58544172559465, 65.63100937434605, 71.53337900979179, 73.31362560817173, 71.37180559975761, 72.73545210702079, 73.26400852203369, 75.00984069279262, 57.05156830378941, 57.78126464571272, 71.50127833230155, 68.51053047180176, 74.29230717250279, 73.93179294041225, 79.42282227107457, 72.01986408233643, 73.37671525137765, 12.895303334508624, 4.844664905752454, 6.638364519391741, 5.582823719297137, 2.716464247022356, 0.2923107418630804, 2.8974856649126326, 1.484181467975889, 0.8903373362762588, 0.2222108141119991, 0.14387438047145093, 8.775846668652125, 45.27232892172677, 44.711122921534944, 64.05950055803571, 41.93358053479876, 63.84837259565081, 41.230137961251394, 51.954001562935964, 65.04275403703961, 82.17317635672433, 80.06571129390171, 89.15059907095772, 3.0620889237948825, 0.35640773815768106, 0.23352249498878205, 0.13240833287792547, 0.15571759854044231, 0.06534664745309524, 0.1154433289276702, 0.14290267761264527, 0.1830299493989774, 0.1456215674323695, 0.2632432516132082, 0.11169649248144456, 0.12424362956413201, 0.20686582608946733, 0.12223550517644201, 0.14959842046456678, 0.09417319670319557, 0.2146850736545665, 0.11941818706691265, 0.27354954715285984, 0.08438389056495257, 0.08117714085217033, 0.15233298444322177, 0.1471590870725257], [0.020148137251713445, 0.06739096489867993, 0.035792790087206025, 0.07336219519908939, 0.012654262495094111, 0.03219565203679459, 0.05027179439951267, 0.045885364059358835, 0.025395311315410903, 0.021993494659130062, 0.05074852292558976, 0.016901979921385646, 0.026890741428360343, 0.02394898169274841, 0.055512469794069014, 0.04527159181556531, 0.05828066196824823, 0.029379524756222963, 0.06404397556824343, 0.11091204493173532, 59.10176631382534, 91.90214129856655, 70.5947607585362, 69.41683265141079, 44.582178252083914, 36.84748526981899, 45.74259689876011, 66.17917360578264, 67.31798335484096, 46.74634408950806, 10.096469061715261, 0.08288487778710467, 0.07784632779657841, 0.06725377190325942, 0.26316817849874496, 0.10198475646653346, 0.7722232256616864, 2.6572571269103458, 1.0527844280004501, 0.7229485011526516, 0.4757007083722523, 23.730015890938894, 75.25177696772984, 75.95112705230713, 75.88825280325753, 70.74004064287458, 74.76485415867397, 65.01897730146135, 58.979790687561035, 71.94190529414585, 77.33149787357875, 73.09616783687046, 69.99105957576207, 55.1505446434021, 49.307912145342144, 62.06959901537214, 70.05709525517055, 66.9656263078962, 70.36648464202881, 70.56459862845284, 67.89899172101701, 66.6327520098005, 65.96780940464565, 65.92140238625663, 64.32161440168107, 61.643097741263254, 59.77010658809117, 59.05824279785156, 57.84539304460798, 52.98151159286499, 51.77426903588431, 50.481831141880576, 49.259868826184956, 47.28488506589617, 48.730461256844656, 47.50271803992135, 50.480219159807476, 51.2497113091605, 48.28960847854614, 49.70798594611031, 56.85862725121634, 60.72600500924246, 65.96835831233433, 64.87520517621721, 69.02541978018624, 61.66926465715681, 66.69512598855155, 48.61855009623936, 41.80583790370396, 69.56439849308559, 53.271974086761475, 55.77589641298567, 50.471627712249756, 50.20329523086548, 44.165776184626985, 48.56553186689104, 47.27068989617484, 48.64055156707764, 45.78315700803484, 50.81472628457205, 47.99923978533064, 49.94420037950788, 46.86960513251168, 51.49659470149449, 55.086124420166016, 63.27534770965576, 56.85414913722447, 63.95549297332764, 61.399466105869834, 65.30722332000732, 60.06433500562395, 65.38345200674874, 58.10182326180594, 64.1201513835362, 64.6969074521746, 64.30427864619664, 62.814452852521626, 64.69057069505963, 65.03506238119942, 61.17684582301548, 52.09065873282296, 51.46278476715088, 55.987118176051546, 66.2020262309483, 61.55529335566929, 66.74537536076137, 64.56933852604458, 72.02322701045445, 69.23251778738839, 72.59224278586251, 7.610787493841989, 0.6527431426303727, 2.900835130895887, 1.7950436558042253, 0.34840010213000433, 0.15033064117389067, 0.46370920326028553, 0.8980330633265632, 0.10156640570078578, 0.09410961118659802, 0.05869012392525162, 17.884597165243967, 29.99753073283604, 37.50900936126709, 62.06505489349365, 104.52895668574742, 46.69985716683524, 21.452179261616298, 41.38113621303013, 56.14224713189261, 64.59802068982805, 75.18027305603027, 16.732221058436803, 0.5875104687043599, 0.12977974249848298, 0.057246404966073375, 0.07299451742853437, 0.07321138400584459, 0.03000840458220669, 0.030546815334154025, 0.0899021987404142, 0.06696333855922733, 0.04439018839704139, 0.05174416110717824, 0.028024093380996158, 0.08196543569543532, 0.020786391038979803, 0.004229867714457214, 0.028645112378788844, 0.03271751331963709, 0.05774265833731208, 0.06176871872906174, 0.0032307919048305067, 0.0649015624076128, 0.05397490265646151, 0.03151743592960494, 0.08859608668301787, 0.05646622879430652, 0.031920407699154954, 0.024790624655517082, 0.004903020678154592, 0.05836747373853411, 0.035176727787724564, 0.0649250600753086, 0.03708670208496707, 0.04126884588705642, 0.05011371948889323, 0.0620753283479384, 0.02883790453363742, 0.031510847354573865, 0.041083049428250105, 0.04565727451284017, 0.009334351800914322, 0.02926339688045638, 0.043737298609422784, 0.28937550793801037, 74.02992929731096, 101.61098425728935, 79.81004537854875, 77.74946675981793, 56.60018900462559, 36.89435086931501, 44.64139427457537, 74.35741874149868, 53.97747332709176, 55.75165067400251, 11.305896827152797, 0.03806962112763098, 0.14921724663249084, 0.24142232537269592, 0.7272161064403397, 0.6349472318376813, 1.1452823217426027, 2.5364268677575246, 2.190618715115956, 0.450307946652174, 0.8790240947689328, 27.374035120010376, 80.15016664777482, 80.5142800467355, 79.64856229509626, 74.67206791469029, 77.93802002498082, 69.47678865705217, 61.54216820853097, 73.8878594807216, 80.07151998792375, 76.02819647107805, 74.02171652657645, 57.04462705339704, 51.689681666237966, 64.3913882119315, 73.76630074637276, 69.6123480115618, 71.15210356031145, 70.18613025120327, 71.36107758113316, 68.47073119027274, 68.54591764722551, 68.97815813337053, 66.84844493865967, 65.04045418330601, 61.69003282274519, 62.10264464787075, 60.716736112322124, 54.82462896619524, 53.12201459067208, 53.52417285101754, 53.07087237494332, 50.04260771615164, 50.79406929016113, 50.87742682865688, 52.25180830274309, 53.434412547520225, 49.75072431564331, 51.19282988139561, 58.217465605054585, 64.83645507267543, 67.2786009652274, 66.69732856750488, 70.42879608699253, 63.771400451660156, 67.2439364024571, 50.952849524361746, 44.42380101340157, 72.279205594744, 57.390953063964844, 59.50045394897461, 51.78812026977539, 52.73430163519723, 46.110663822719026, 52.1363639831543, 48.826905727386475, 51.61212239946638, 48.0418496131897, 53.48903581074306, 51.45362704140799, 50.79974249431065, 49.37134919847761, 52.923476764133994, 57.615341663360596, 66.508316721235, 61.09941509791783, 67.78074727739606, 63.269358362470356, 68.45061615535191, 63.18130384172712, 66.39466503688267, 59.126745087759836, 66.57761805398124, 66.18380110604423, 67.89364160810197, 65.35674313136509, 67.92731257847377, 66.68035411834717, 66.06869724818638, 54.120317867824006, 54.91206509726388, 58.11123807089669, 69.75278500148228, 65.12574332101005, 70.10392611367362, 67.08466284615653, 76.2374484198434, 69.8569940839495, 80.9113209588187, 10.676869460514613, 0.6301042288541794, 0.9080041625670024, 1.8666177008833205, 0.6500779113599232, 0.6463391834071704, 1.1684544554778507, 1.5828189636979784, 0.5402209205286843, 0.05020478228107095, 0.15924821980297565, 18.50358612196786, 36.14407743726458, 32.452284131731304, 56.30102389199393, 94.96622739519391, 48.3479768208095, 34.070543902260916, 52.47144433430263, 63.10718045915876, 71.28596755436489, 85.34377138955253, 26.31542147908892, 0.5495470315217972, 0.1282193155160972, 0.01761342558477606, 0.09238736717296497, 0.030427111578839164, 0.03532085880371077, 0.05298250447958708, 0.04282466222399047, 0.04468660302726286, 0.025867646327242255, 0.07083735960934844, 0.0028988303092774004, 0.1067423793886389, 0.04187724074082715, 0.020898539306862012, 0.0370888428629509, 0.0006636564950375551, 0.0419874619692564, 0.05784459465316363, 0.0382121881203992, 0.02637440342056964, 0.030452811092670475, 0.040316243789025714, 0.16739180710698875, 0.1773485756878342, 0.09541544504463673, 0.15415174327790737, 0.07697588950395584, 0.20389585117144243, 0.14733899384737015, 0.1244250698281186, 0.09231538139283657, 0.17811508955700056, 0.16301476769149303, 0.12493030700300421, 0.08072072427187647, 0.06533772471760001, 0.15576516384524958, 0.2202620751091412, 0.05830887545432363, 0.1676679030060768, 0.18556425055222853, 0.35125179482357843, 83.07988848005022, 115.36451952798026, 93.39596230643136, 90.29815660204206, 61.35636643001011, 53.21514824458531, 54.298921312604634, 79.90282467433384, 98.32152639116559, 68.93059771401542, 16.608529227120535, 0.22102704191846506, 0.3307621271482536, 0.3126720849956785, 1.4362303210156304, 0.8173695259860584, 2.5453440121241977, 8.027717624391828, 3.97414117200034, 2.899838064398084, 1.186288635645594, 33.14994580405099, 84.63196318490165, 83.18855135781425, 82.14406340462821, 77.2781982421875, 82.78596578325543, 72.59222194126674, 65.4631131035941, 76.39966106414795, 82.50297260284424, 78.9358855656215, 74.12567547389439, 58.79007012503487, 53.761891569410054, 68.20156492505754, 74.83261299133301, 72.90285505567277, 72.81648894718715, 71.35988249097551, 74.31438159942627, 71.06427833012172, 71.4923985345023, 72.1985786982945, 70.94214984348842, 66.88416562761579, 64.67497893742153, 64.73939568655831, 63.064588001796174, 59.19466372898647, 56.02463844844273, 56.36055258342198, 56.18407528741019, 54.01249919618879, 54.887221813201904, 52.30757107053484, 54.6993008341108, 57.99929216929844, 51.90307821546282, 54.90978956222534, 61.11543764386858, 68.98022869655064, 70.9232576915196, 70.20802402496338, 73.4420839037214, 67.70107228415353, 69.15909617287772, 54.685157775878906, 48.652262755802695, 76.88555553981236, 60.31106553758894, 62.560968671526226, 55.832155976976665, 55.99554981504168, 48.82337604250227, 55.272402150290354, 53.024340288979666, 54.56238310677664, 51.696060112544465, 57.00295870644705, 53.51084968021938, 54.31143501826695, 52.74198634283883, 56.1972838129316, 61.36118847983224, 69.62366662706647, 62.98992265973772, 71.20668860844204, 66.30442183358329, 69.87133516584123, 65.48491655077252, 70.82093157087053, 61.13806792667934, 69.10082163129533, 70.26951558249337, 71.18933200836182, 69.09868853432792, 70.11018644060407, 70.69411305018834, 68.20393426077706, 58.70842184339251, 57.06140347889492, 61.68908091953823, 73.8154661996024, 68.16013976505825, 72.14061682564872, 70.60862936292375, 78.7064699445452, 74.38567706516811, 82.0006456375122, 9.910961713109698, 2.675070136785507, 8.044059787477766, 6.273587133203234, 1.2422137090138026, 0.5389999917575291, 1.9935374047074998, 3.268046340772084, 1.3908324199063438, 0.25058648362755775, 0.21405794444893086, 26.764596462249756, 47.979145595005576, 51.102947984422954, 70.25238132476807, 116.66846711294991, 55.46025364739554, 35.56520216805594, 56.72978333064488, 73.94506399972099, 79.16772610800606, 96.89559623173305, 25.880361761365617, 0.750637452517237, 0.2818257473409176, 0.13681942118065699, 0.23651722286428722, 0.1255599060761077, 0.11714111853923116, 0.11152192577719688, 0.22293437671448502, 0.21034082105117186, 0.06639797639633928, 0.1467527938740594, 0.1577621874000345, 0.1323818971535989, 0.1311019222651209, 0.10915497850094523, 0.08002202997782401, 0.1180857749921935, 0.19400153495371342, 0.13346606040639536, 0.10979901679924556, 0.15004062173621996, 0.08934371013726507, 0.11906074838978903], [0.01568686280266515, 0.04051150920401726, 0.020681308016979268, 0.028241312796516076, 0.04800009986917887, 0.028692535191242183, 0.04740571676354323, 0.04013292059036238, 0.019423650145264607, 0.07908128188656909, 0.03096927123676453, 0.024682934362707392, 0.047649334583963664, 0.06382217604134764, 0.04523367527872324, 0.10697561901594911, 0.03650215095175164, 0.15483561158180237, 0.39745359708155903, 5.023407314504896, 79.36137935093471, 73.69522067478725, 75.80092784336635, 55.331270762852256, 41.48618950162615, 25.871902329581125, 21.33663419314793, 38.81392274584089, 45.062868527003694, 24.1741430078234, 0.7665633207985333, 0.057744456455111504, 0.027714817119496207, 0.3566429183951446, 0.3783592688185828, 0.27368718119604246, 1.380838087626866, 1.4713405455861772, 0.31925346755555695, 1.2763140563453947, 12.739271981375557, 77.20501286642892, 74.5444781439645, 77.66430268968854, 76.3026294708252, 75.7486218043736, 71.89389324188232, 66.45134149278913, 54.60367277690342, 67.37686238970075, 72.49352972848075, 69.54511029379708, 70.28650392804826, 51.38113995960781, 50.546581404549734, 59.658525466918945, 69.04465934208461, 67.24298449925014, 65.24312618800572, 66.48746517726353, 68.37864671434674, 63.81390953063965, 67.20713179452079, 63.296032496861045, 62.95090157645089, 60.99795750209263, 55.72777318954468, 51.22017799104963, 49.411415985652376, 47.50609139033726, 48.35716233934675, 46.50463015692574, 46.969145025525776, 48.16272047587803, 49.161218302590505, 46.86230257579258, 50.59108114242554, 50.04026617322649, 51.43441874640328, 46.992577825273784, 49.05256584712437, 50.16261352811541, 56.220244135175435, 57.51968581335885, 63.2332763671875, 58.957195145743235, 68.09447928837368, 52.05851984024048, 37.88403838021414, 67.01188046591622, 59.19082832336426, 63.77294989994594, 59.280668531145366, 60.83238887786865, 47.564484051295686, 48.30686085564749, 46.66102368491036, 47.28637892859322, 47.55708769389561, 50.12214374542236, 48.55168063299996, 48.40924603598458, 47.57976313999721, 47.602900641305105, 50.931143351963584, 61.4864228112357, 63.8784305027553, 56.58225917816162, 62.91017818450928, 59.94877256665911, 63.39251518249512, 63.876804624285015, 64.96527467455182, 65.169892174857, 65.11172185625348, 58.981291498456685, 57.809078284672324, 59.17479188101632, 58.11566407339913, 54.6787098475865, 50.13260773250035, 49.99525226865496, 51.05548831394741, 53.56933266775948, 57.91634804861886, 57.687245096479145, 62.09729453495571, 65.70717552730015, 66.55855219704765, 70.27613721575055, 69.50292083195278, 3.2294501832553317, 1.942996425288064, 1.339710614510945, 1.0840977877378464, 0.6781876630016735, 0.45081939920783043, 0.6092652784926551, 0.43934732622333933, 0.22013890743255615, 0.04759483804394092, 1.4477844153131758, 25.225191797528947, 32.93562167031424, 90.18878500802177, 103.30338478088379, 101.61086613791329, 31.781956672668457, 40.01077774592808, 53.98327507291521, 57.13706241335188, 64.85324192047119, 50.40355968475342, 0.580254920891353, 0.04559742772419538, 0.03057155811360904, 0.020368181069248488, 0.10732300180409636, 0.034695493789123635, 0.022484100922676067, 0.05139522447383829, 0.034695378438170464, 0.048631449562630484, 0.05227711643757565, 0.02525653563705938, 0.073688814815666, 0.06124119846416371, 0.014038186403922737, 0.04611954345766987, 0.05010432517156005, 0.017888517252036502, 0.013509482095417167, 0.08434220815875701, 0.05242213633443628, 0.04259052693045565, 0.030130530707538128, 0.0029077871835657527, 0.021997438643925955, 0.09291158297232219, 0.05186638901276248, 0.03784622025809117, 0.04062111296557954, 0.0236709621468825, 0.02291333708646042, 0.06555545303438391, 0.035088932141661644, 0.02977466962433287, 0.023533899769453064, 0.031212719423430305, 0.018798576900735497, 0.05936798719423158, 0.06135248499257224, 0.050016539703522406, 0.20490044940795216, 0.23498574218579701, 7.702229261398315, 96.95946407318115, 83.03656646183559, 82.49963746752057, 64.58784852709088, 52.14030361175537, 35.74052606310163, 31.965934549059185, 37.897983414786204, 52.2538788659232, 28.20902098928179, 0.7426228140081678, 0.03127175197005272, 0.12460862712136336, 0.9827095653329576, 0.4750423122729574, 0.8541970955474036, 2.7687744115080153, 4.079272627830505, 0.5534457308905465, 1.025437404002462, 15.11184208733695, 82.4727201461792, 80.38081210000175, 81.45457976205009, 81.27584430149624, 80.74773257119315, 75.54867349352155, 68.9073907307216, 59.66212463378906, 70.59169660295758, 77.98901285443986, 74.38016714368547, 72.73056752341134, 54.25768027986799, 54.204679421016145, 64.65615626743862, 72.72842053004673, 69.02816431862968, 66.48638125828334, 69.0399762562343, 70.62678500584194, 66.26789515359062, 67.08116790226528, 66.34921686989921, 65.05431583949498, 60.12376989637102, 58.33109991891043, 52.84132473809378, 53.155480589185444, 49.910518986838206, 52.01945011956351, 48.40071712221418, 49.42889417920794, 49.722292287009104, 51.61372743334089, 49.1434691292899, 53.81193249566214, 51.340378352573936, 53.645186151777, 49.21180813653128, 52.09309755052839, 52.937557288578574, 58.58909348079136, 58.12763581957136, 66.23710768563407, 62.149280956813264, 71.35840947287423, 55.19815370014736, 41.16686071668352, 69.4909977231707, 62.96515233176095, 66.87976741790771, 62.89156396048409, 62.76649638584682, 50.75464868545532, 50.67224652426583, 49.06523936135428, 50.46692030770438, 50.50457606996809, 51.80268021992275, 51.25043739591326, 49.76437405177525, 49.755324023110525, 49.40567677361624, 52.956168038504465, 63.33278846740723, 65.04308755057198, 61.92699418749128, 62.79125281742641, 60.70973232814244, 64.59808322361538, 66.09107044764927, 65.9034343447004, 67.88460200173515, 66.34319278172084, 62.94101428985596, 60.16878727504185, 61.17759622846331, 60.368318693978445, 56.9883258002145, 50.49078736986433, 52.71735150473458, 52.08158091136387, 55.25181811196463, 58.91158022199358, 60.75453431265694, 65.47313240596226, 67.27971962520054, 69.73512962886265, 71.11308247702462, 75.32407297406877, 5.626046291419438, 0.6848935974495751, 0.2512368730136326, 2.081050617354257, 1.890814585345132, 0.5792896098324231, 2.1254389669213976, 0.7833330152290208, 0.4725794472864696, 0.0425443153030106, 0.6783806383609772, 30.01928554262434, 30.25513866969517, 67.85339764186314, 102.41682243347168, 86.01886531284877, 34.85812221254621, 45.915690422058105, 60.062125478472026, 63.06804125649588, 72.95220116206578, 64.38702474321637, 0.8066984500203813, 0.02943016721733979, 0.04510483844205737, 0.03313587087073496, 0.03210557990574411, 0.030314546011920487, 0.021902313123324087, 0.0269496518386794, 0.0883819003190313, 0.01613518106751144, 0.030608395779771463, 0.06933848253850426, 0.020096821344590614, 0.03785772481933236, 0.03941899997049144, 0.03436733050537961, 0.02316122967749834, 0.039492716014917405, 0.04427823690431459, 0.03151458268985152, 0.0434519848121064, 0.029951824939676693, 0.05488630071548479, 0.09438583600733962, 0.1581245522413935, 0.16304588530744824, 0.13479073718190193, 0.07718807418963738, 0.19884518933083328, 0.07365767684366022, 0.15744440230940068, 0.13632174288587912, 0.2697277936552252, 0.10636667454881327, 0.11681911296078137, 0.14987315929361752, 0.1569055640803916, 0.11994231465671744, 0.3139694168099335, 0.2383801814700876, 0.3106013318257672, 0.5009672897202628, 9.777842044830322, 113.97471305302211, 94.78788103376115, 98.15344946725028, 75.49986239842006, 58.215242181505474, 40.8229353087289, 37.19348471505301, 58.77776486533028, 62.37974575587681, 39.44425637381417, 1.4982970591102327, 0.1250947838915246, 0.2601634625877653, 1.6159173590796334, 1.4533880289111818, 0.7036797351070813, 4.822422419275556, 6.842141287667411, 2.3900215923786163, 3.0643731440816606, 18.826439380645752, 86.88448578970772, 81.10202121734619, 83.66535064152309, 84.38871370043073, 84.04299218314034, 78.89964376177106, 73.19740309034074, 61.39014162336077, 74.01239204406738, 79.73747839246477, 76.44902801513672, 75.5437263761248, 56.53790535245623, 56.43452310562134, 66.78597368512834, 75.1411269051688, 71.22730391366142, 67.01948874337333, 70.97036647796631, 74.50283064161027, 68.73849391937256, 71.29370089939663, 68.81817586081368, 69.64258657182965, 65.27786023276192, 61.41585690634591, 56.53805473872593, 54.30828401020595, 52.794361863817485, 53.36123411996024, 51.601265839168, 52.085037640162874, 54.70056888035366, 53.980405466897146, 51.761189052036826, 55.428778307778494, 55.1599976675851, 57.50575467518398, 52.89067431858608, 55.49906628472464, 55.03646911893572, 61.807707514081685, 61.84021813528878, 68.99628598349435, 65.37323120662144, 75.18328162602016, 58.200494629996165, 45.426304476601736, 72.42233153751918, 65.42093753814697, 69.11075060708183, 65.5368265424456, 66.03288623264858, 52.97953135626656, 53.147170543670654, 52.09583166667393, 52.37594829286848, 52.81861455099923, 55.474716322762625, 53.03275108337402, 52.48424639020647, 52.99877091816494, 52.27598108564104, 55.94337231772286, 67.25793007441929, 69.62674467904228, 64.8407073702131, 66.35794380732945, 63.545271328517366, 67.72022151947021, 68.39350891113281, 67.35605948311942, 69.45306750706264, 70.7495596749442, 64.53160980769566, 62.11490821838379, 64.16829545157296, 65.57461779458183, 61.57786805289132, 54.88311890193394, 55.4214722769601, 56.316344669886995, 58.647889137268066, 63.608597210475374, 62.710931641714915, 69.32453972952706, 71.98534543173653, 71.3055545261928, 75.01111221313477, 78.13937187194824, 5.35952034166881, 5.572211214474269, 5.861551574298313, 4.018286117485591, 3.818316093512944, 0.8680900186300278, 2.5734866048608507, 1.7440153253929955, 1.1891854916300093, 0.18533931619354657, 2.7229812230382646, 39.709604603903635, 50.82513121196202, 96.07107434953961, 105.16903863634381, 106.7952367237636, 40.05336672919137, 53.145617621285574, 70.74344526018415, 71.87496634892055, 81.66179588862828, 68.53228528159005, 0.9737956779343742, 0.219782432275159, 0.13100033200212888, 0.11600742223007338, 0.14901257332946571, 0.1464917885937861, 0.1004002211349351, 0.10797153878957033, 0.2071996788893427, 0.12341196276247501, 0.14691321312316827, 0.19070343407137053, 0.18859338015317917, 0.10149432492575475, 0.09794241801968642, 0.13107149675488472, 0.11093607185674564, 0.10313528722950391, 0.07773153324212347, 0.17551657184958458, 0.11243372077920608, 0.09545209950634412, 0.1846107052905219], [0.016441588822220052, 0.060359645767935684, 0.03448955841096384, 0.032885457522102764, 0.05337861626009856, 0.04623518957357321, 0.008908035034047706, 0.056404709416840754, 0.06620918759810072, 0.026899304540295686, 0.03019021125510335, 0.024496111619685377, 0.04244685053293194, 0.05806870798447302, 0.0711625407316855, 0.02158084019486393, 0.06807082306061472, 0.20680205736841473, 0.4787072698984827, 23.155040298189434, 87.91101959773472, 67.67129230499268, 72.39828382219586, 55.99930879047939, 33.10302809306553, 21.977812222072057, 34.71584047589983, 50.061124665396555, 40.58963564464024, 9.645083682877676, 0.08307777850755624, 0.08637940777199608, 0.04474549986688154, 0.34092484467795914, 0.5027426087430545, 0.30350651538797785, 1.2277127099888665, 0.46615632623434067, 1.2244555247681481, 5.133072904178074, 78.78237901415143, 74.54760483333042, 79.76679284232003, 72.8978523526873, 78.23011534554618, 71.66457489558628, 72.99496732439313, 65.65998336247036, 54.62501416887556, 60.49836812700544, 74.10295486450195, 74.12468188149589, 66.81657355172294, 49.47276510511126, 50.874744824000764, 58.80509907858712, 69.27952929905483, 64.20603111812046, 66.36587865012032, 66.27989469255719, 64.784670148577, 60.6943142754691, 58.79699053083147, 56.53552559443882, 58.312999861580984, 55.56416743142264, 53.402471678597585, 49.27992132731846, 48.28149993079049, 44.565481730869834, 47.91603510720389, 47.32668890271868, 46.052274635859895, 45.637005124773296, 47.342916420527864, 48.64418200084141, 48.38719245365688, 46.548685210091726, 48.967804772513254, 46.29243564605713, 45.570153032030376, 43.7485021182469, 46.89010926655361, 47.336975710732595, 51.16722924368722, 54.996614251817974, 62.446385928562705, 59.49804292406355, 35.469834668295725, 61.48406737191336, 61.07695852007185, 61.5924106325422, 61.4018007005964, 61.9386602129255, 54.11336966923305, 46.24025467463902, 48.23477676936558, 47.15244892665318, 48.69752679552351, 45.192021642412456, 49.97359125954764, 49.044502462659565, 47.64496156147548, 47.431620597839355, 47.64006655556815, 52.85704851150513, 62.39974267142159, 59.123785155160085, 57.761486598423545, 60.82371057782854, 59.33785915374756, 61.34265068599156, 64.11423151833671, 65.43894726889474, 63.75582259041922, 60.97245761326381, 56.4151028905596, 52.331087248665945, 51.53091532843453, 49.5404440334865, 49.41267013549805, 49.040194579533164, 49.90980332238333, 50.0291177885873, 51.30664137431553, 50.583851541791645, 54.46114090510777, 53.96100262233189, 66.62144729069301, 63.753349031720845, 72.74108014787946, 47.04498808724539, 0.16745854781142303, 0.37833815280880245, 0.8680874673383576, 1.8573907102857317, 0.3878383758877005, 0.025045060020472323, 0.18144983133035048, 0.2646867127290794, 0.15266143610434874, 0.04588031915149518, 6.2547866106033325, 28.47896718978882, 63.87803445543562, 95.3715991973877, 62.52892357962472, 35.88560792378017, 32.082223074776785, 46.308878558022634, 53.87128748212542, 58.5196601322719, 62.69797325134277, 5.837503858975001, 0.4226358229560511, 0.04709662031382322, 0.06670434852795941, 0.05661223256694419, 0.03267233306542039, 0.028025964441310083, 0.06687105101134096, 0.046604909734534364, 0.03176251599299056, 0.06521110329777002, 0.04166067950427532, 0.03902628765042339, 0.03036372283739703, 0.05011859815567732, 0.07388648563729865, 0.0077362949627318555, 0.062186947358506064, 0.026405839947983623, 0.0377224588633648, 0.047647617890366485, 0.050554363522678614, 0.0399494175799191, 0.03731132771021553, 0.04257505972470556, 0.0338473792986146, 0.05264054997158902, 0.056850517102118046, 0.01765706217182534, 0.010887264856137335, 0.05317654174619487, 0.023659622130383338, 0.06074934878519603, 0.009268105578874903, 0.060087186816547594, 0.07148620872093098, 0.08187896997800895, 0.0320910762197205, 0.04901266749948263, 0.06857161583112818, 0.13619924017361232, 0.4505207080926214, 30.486850670405797, 103.99686363765171, 75.12119947160993, 84.7017161505563, 62.538734436035156, 45.30562816347395, 29.054291929517472, 36.89953075136457, 61.42653628758022, 46.91973638534546, 12.384569917406354, 0.16376430461449282, 0.06411098090133496, 0.5371696299740246, 0.35222722962498665, 1.5232154705694743, 2.4858494102954865, 2.397183665207454, 1.5537395583731788, 0.5415358671120235, 6.1529503379549295, 86.35767337254116, 78.63278429848808, 82.95293794359479, 78.16605990273612, 79.9774135862078, 76.03376197814941, 76.99671976906913, 71.32473155430385, 56.79293550763811, 62.82074097224644, 75.78480107443673, 75.26469366891044, 69.20281423841203, 54.22757026127407, 53.72593464170183, 60.85313619886126, 70.59333637782505, 66.67061969212124, 67.98603875296456, 69.15671294076103, 66.49966621398926, 63.846336773463655, 61.81032698495047, 59.316417012895855, 60.69214643750872, 57.408337456839426, 56.50861174719674, 51.28886440822056, 50.42333773204258, 47.020971638815745, 50.94601249694824, 49.54138898849487, 50.09007780892508, 47.95194687162127, 50.73845590863909, 48.930357456207275, 50.84802900041853, 49.342805998665945, 50.834031854357036, 47.82290145329067, 47.672632762363975, 47.11672476359776, 49.302047865731375, 50.02441038404192, 52.66693537575858, 56.85947840554373, 64.17764772687639, 63.305398668561665, 37.54575490951538, 63.12074334280831, 64.0974029813494, 65.22401864188058, 64.28494875771659, 62.35793536049979, 56.96237775257656, 48.22927032198225, 51.93749959128243, 50.0615485055106, 52.3973001071385, 49.5770297731672, 51.5330171585083, 50.49787105832781, 51.18142441340855, 48.778105054582866, 48.975444316864014, 54.97312934058053, 65.26385266440255, 63.34439195905413, 62.87606947762625, 62.9444397517613, 63.58718286241804, 62.95486899784633, 66.51789828709194, 66.74793229784284, 66.28873974936349, 64.02165372031075, 60.979635102408274, 54.87636872700283, 53.55160781315395, 49.60411385127476, 52.09879854747227, 51.16375514439174, 52.45398351124355, 52.51967525482178, 52.86603600638253, 51.18747976848057, 56.423124585832866, 57.641074316842214, 69.15477439335415, 67.9773257119315, 75.99428231375558, 52.60416882378714, 0.9159938309873853, 0.7059908796633992, 1.1655561881405967, 1.5300904959440231, 1.697119761790548, 0.6831238695553371, 0.7255184661064829, 0.9340640327760151, 0.29546259130750385, 0.05759886319616011, 6.260392504079001, 31.085424082619802, 54.04672949654715, 96.39775085449219, 59.742723737444194, 25.971235513687134, 41.39005422592163, 52.72116953986031, 61.121982846941265, 63.06651265280587, 74.75664138793945, 11.811654465539114, 0.4068933219781944, 0.09331508739186184, 0.11389892894242491, 0.03801578955192651, 0.08321613179785864, 0.024066166386806538, 0.053052033962947984, 0.045725769230297635, 0.025152509433350394, 0.02484375055480216, 0.07700475438364915, 0.05469255182625992, 0.02356828622786062, 0.08555175789764949, 0.01128723580456738, 0.03482481238565274, 0.014886720737974559, 0.05878414852278573, 0.01953280946638967, 0.03222729891006436, 0.035459734565977535, 0.03304217875535999, 0.1913768665066787, 0.21684965464685643, 0.08526380120643548, 0.1475850170744317, 0.13108156621456146, 0.10929402389696666, 0.10133332213652985, 0.13756070711783, 0.12751012428530625, 0.16767669681991848, 0.09505141779248204, 0.19659811205097608, 0.09677871689200401, 0.13499408055629047, 0.163551963865757, 0.15245027600654534, 0.1750569457986525, 0.31063721275755335, 0.7417060860565731, 36.55365637370518, 113.54608563014439, 86.90478842599052, 93.49519647870744, 73.47517817361015, 46.90028837748936, 30.942266872950963, 49.74549579620361, 68.74782535008022, 62.02338654654366, 17.002085617610387, 0.1989852932414838, 0.2517439286623682, 0.9958305869783673, 1.5527013455118452, 1.3931466042995453, 3.6313904438699995, 6.007686955588205, 7.3659633738654, 8.312377503940038, 8.008798548153468, 90.66941274915422, 79.67989172254289, 85.44115039280483, 78.6096259525844, 83.24232346670968, 77.56105940682548, 80.24666322980607, 72.97180203029087, 59.13665321895054, 66.57777091435024, 78.64349842071533, 78.91791752406529, 73.62694072723389, 57.2157438141959, 55.91835185459682, 65.44818837302071, 75.35115705217633, 69.79656560080392, 70.375399180821, 71.31008475167411, 69.40909930637905, 66.26906939915249, 65.10573250906808, 62.128471102033345, 63.39984553200858, 61.02795287540981, 60.02572386605399, 53.341046128954204, 53.90463883536202, 50.097936221531455, 53.28075660978045, 51.66172906330654, 52.32905837467739, 52.67523152487618, 53.5368081501552, 52.97019992555891, 51.93140254701887, 52.17009401321411, 54.66155127116612, 50.298732212611604, 51.59131949288504, 49.80283580507551, 51.04471165793282, 53.75052431651524, 54.80164779935564, 60.34548691340855, 67.92631203787667, 67.54928193773542, 41.57802036830357, 65.78209100450788, 67.39546271732875, 67.42759813581193, 68.20935385567802, 66.6355868748256, 60.999340193612234, 51.49877643585205, 54.26054293768746, 53.141803060259136, 54.99498837334769, 51.376859869275776, 54.141919817243306, 53.54954767227173, 52.02688469205584, 51.125543526240754, 51.707361357552664, 60.226075172424316, 68.81904438563755, 65.0558305467878, 68.12985951559884, 66.28869806017194, 66.13179383959088, 65.2855657849993, 70.28674711499895, 69.0440479006086, 70.41244002750942, 67.2130377633231, 64.3661801474435, 57.78271334511893, 56.59169830594744, 53.67562968390328, 55.23063652856009, 54.8647027015686, 54.7903812953404, 55.871576581682476, 56.52373797552926, 54.20420346941267, 60.27510166168213, 60.85313619886126, 72.10518796103341, 72.81189618791852, 75.92883028302873, 55.77976655960083, 0.8239442589027541, 4.484390386513301, 6.539794768605914, 6.33247355052403, 3.7053970098495483, 1.135581550853593, 2.2904843049389974, 1.633435070514679, 0.5175931890095983, 0.2024877688714436, 11.388168709618704, 44.984399046216694, 79.93835081372941, 96.66298443930489, 70.68557371412004, 45.37249067851475, 48.103177888052805, 59.2480536869594, 71.7295058114188, 70.9148017338344, 87.04835905347551, 11.715920448303223, 0.620040414588792, 0.17279907981199877, 0.22628567474228994, 0.16570291987487248, 0.13657233943896635, 0.17609701784593718, 0.13057383203080722, 0.14580223416643484, 0.09209900336073977, 0.19090018208537782, 0.14949592096464975, 0.13251651850129875, 0.15266474735523972, 0.13186766260436603, 0.17129512051386492, 0.16946154247437203, 0.11046206764876842, 0.07851484763835158, 0.16462185074176106, 0.08620216763977494, 0.0931884456159813, 0.08730355211134468], [0.033571466603981595, 0.06354541517794132, 0.020541020901873708, 0.046034573909959624, 0.03370740430961762, 0.08362908142485789, 0.01904376213704901, 0.04962469590827823, 0.010648260225674935, 0.04201787051611713, 0.03143178106152585, 0.023893343517556787, 0.0878821796338473, 0.05599275045096874, 0.05494055976825101, 0.019518896105832288, 0.032845766616186926, 0.06524749313082014, 0.07140918142561402, 56.388831751687185, 85.58470712389264, 67.72899709429059, 68.44108322688511, 57.01408624649048, 31.593101160866873, 32.93767486299787, 51.13735546384539, 29.344768319811138, 29.59432676860264, 0.5197500075612749, 0.04090557520144752, 0.07574577336864811, 0.10543764475733042, 0.797783151268959, 0.5228442358119147, 1.3422185885054725, 2.3476566885198866, 3.5056975313595364, 1.1681692536388124, 69.59360177176339, 82.19033145904541, 73.39391899108887, 76.16379751477922, 73.74225303104946, 77.01224204472133, 74.73836762564522, 71.4632647378104, 65.12299183436802, 55.94417136056082, 53.07100786481585, 60.74292387281145, 63.44400133405413, 55.78796195983887, 52.159953117370605, 50.63311774390084, 55.19021538325718, 66.70804963793073, 67.92262254442487, 66.30265699114118, 65.00562981196812, 59.85326262882778, 54.06363793781826, 54.608998571123394, 52.28994696480887, 50.51322657721383, 50.904611655644004, 50.004722663334434, 46.889007977076936, 43.66374799183437, 46.07753481183733, 45.15129130227225, 43.99125133241926, 46.0627247265407, 47.8534700529916, 46.89330891200474, 46.46979883738926, 45.6090212549482, 44.02082633972168, 46.85801901136126, 46.01826320375715, 44.73662975856236, 46.89556360244751, 47.52444505691528, 45.91004153660366, 45.68510750361851, 49.53435046332223, 59.8503235408238, 59.66136033194405, 37.749847820826936, 56.400185108184814, 54.609377247946604, 58.71710014343262, 60.53942503247942, 60.09524059295654, 54.07149635042463, 47.142610277448384, 46.82308694294521, 47.45193713051932, 46.87453835351126, 47.57027537482125, 47.91736568723406, 47.92576953342983, 47.05278049196516, 47.537549359457834, 47.10584388460432, 45.07580259868077, 51.58717836652483, 59.20726081303188, 56.604361397879465, 56.64581782477242, 59.057763372148784, 58.452561378479004, 59.40479115077427, 61.798626218523296, 63.57073647635323, 60.08513791220528, 59.24439893450056, 52.247649805886404, 48.19685002735683, 48.81257506779262, 47.94954974310738, 50.17304277420044, 48.2346899168832, 49.387132031576975, 55.61908251898629, 57.91675451823643, 59.14127377101353, 63.63856479099819, 61.29857131413051, 67.87723691122872, 65.46034772055489, 54.78906461170742, 30.264160905565532, 0.59341149777174, 1.7321837374142237, 1.2764736477817809, 1.0744796352727073, 1.9624696203640528, 0.30954430997371674, 0.41989000886678696, 0.30131927132606506, 0.03419193598840918, 0.08510819955595902, 14.259512645857674, 25.955760138375418, 47.471871512276785, 55.29045704432896, 33.808614185878206, 19.44012859889439, 36.09138577325003, 54.36456094469343, 58.19112845829555, 57.97977467945644, 42.20787109647478, 0.1344421330307211, 0.0034746374585665762, 0.11378315051219293, 0.08912487580840077, 0.03313147396381412, 0.03498262606029, 0.017009675303207974, 0.026066239956500273, 0.042107647484434504, 0.056543286623699326, 0.04654987375917179, 0.015440250946474927, 0.051199121068098714, 0.08564418793788978, 0.0717382709096585, 0.022735579571287547, 0.017228382406756282, 0.023180900407688956, 0.010615596398045974, 0.06325268160019602, 0.043853348453662226, 0.037454189865716865, 0.03296929391633187, 0.005859401368070394, 0.016553811728954315, 0.03120590014649289, 0.04903028905391693, 0.017728644223617654, 0.022159111486481767, 0.02174305247275957, 0.03127730577918036, 0.030465832179678336, 0.02464147417673043, 0.010802650691143103, 0.007136973818497998, 0.0392991367594472, 0.05294932411717517, 0.020775324132825648, 0.03060062655380794, 0.03398456550868494, 0.12510876171290874, 71.18378734588623, 92.28356266021729, 76.2678050994873, 74.51847103663853, 69.95174666813442, 42.04580436434065, 28.156515189579554, 34.553919655936106, 29.56791319165911, 33.39156246185303, 0.4513395370117256, 0.1669664199330977, 0.09443214602236237, 0.5210568660071918, 1.5603809505701065, 1.7894629495484489, 3.4013086642537798, 2.2375579220908026, 0.8113585742456573, 1.710473439523152, 75.71115711757115, 82.64635562896729, 77.9757695879255, 78.30883843558175, 77.97410896846226, 80.36548437391008, 79.65469060625348, 73.27224908556256, 68.47278090885708, 58.11204406193325, 55.64917516708374, 63.886136054992676, 65.27074527740479, 58.89584950038365, 54.84709249223982, 52.36682183401925, 58.135879857199534, 69.49633393968854, 70.62048993791852, 67.1417075565883, 67.47072560446603, 63.5679155077253, 57.67097936357771, 57.06398126057216, 55.03540257045201, 54.094797134399414, 52.861373765128, 50.99512583868844, 49.350052969796316, 47.015809127262656, 49.11731610979353, 45.82116712842669, 47.14567790712629, 46.80409056799752, 49.902003969464985, 49.619681290217805, 48.56703962598528, 47.25884321757725, 47.07691853387015, 48.96574463163103, 48.295646463121685, 47.06551306588309, 49.066146101270405, 49.58313723972866, 46.72329691478184, 48.86167451313564, 51.17453874860491, 62.90181255340576, 60.7693270274571, 40.69697836467198, 55.748145307813374, 56.55517857415335, 61.89829117911202, 61.27208478110177, 62.25153064727783, 55.71850776672363, 51.03076662336077, 50.5201678276062, 50.23413481031145, 50.14725800922939, 48.90287733078003, 49.620212827410015, 51.684001513889854, 48.999592781066895, 49.227709089006694, 49.27498115812029, 48.89114529745919, 52.98768854141235, 62.47705527714321, 61.19792665754046, 59.445465905325754, 59.74833788190569, 61.11823776790074, 62.73365919930594, 64.06587900434221, 65.5972341809954, 63.53422369275774, 62.13651016780308, 55.62436662401472, 49.7467360496521, 53.097786222185405, 50.24005120141165, 51.23683977127075, 50.21605907167707, 51.80062007904053, 58.030378409794395, 61.26041875566755, 62.315683364868164, 68.39245278494698, 64.19344098227364, 70.62854984828404, 68.9677288872855, 61.611198561532156, 36.46978119441441, 1.3417685840811049, 0.6570350666131292, 0.5979134419134685, 0.9808513564722878, 2.1739955842494965, 1.5813548479761397, 1.1904635259083338, 0.4763067758509091, 0.04059180025277393, 0.0678839748725295, 15.262868131910052, 29.623015880584717, 49.7908501625061, 63.228683607918875, 28.588967595781597, 25.159776244844707, 44.59361498696463, 60.40634618486677, 64.80260344914028, 65.95840154375348, 60.39445086887905, 0.6167193385107177, 0.024140157237915055, 0.03301858270008649, 0.09545470508081572, 0.03306393258805786, 0.01174759043247572, 0.052812260043408187, 0.03533885694508042, 0.04756417504644819, 0.012236228096298873, 0.12486120499670506, 0.004679538384412548, 0.05234405391716531, 0.05902616839323725, 0.027484703842284422, 0.02499018350083913, 0.02291408347498093, 0.05074941859181438, 0.0266054072749934, 0.040478664716439586, 0.02011969984908189, 0.051369955829743824, 0.10617226748062031, 0.1507055317716939, 0.08532541897147894, 0.10289210027882031, 0.10127145331352949, 0.19585913313286646, 0.10982440757964339, 0.13263645635119506, 0.1284429742289441, 0.15539794069315704, 0.12580557646495955, 0.0966545721249921, 0.16745199316314288, 0.10876919063074247, 0.22089983017316886, 0.13752002215811185, 0.11479649506509304, 0.10635276458093099, 0.22303488132144722, 77.3555108479091, 105.15194606781006, 87.9523891721453, 86.55560670580182, 75.62023299080985, 45.55779218673706, 45.364673955099924, 66.1444673538208, 43.61640644073486, 47.496412549700054, 0.9161722042730877, 0.3888051797236715, 0.1489428470709494, 2.0174122835908617, 3.1209505881581987, 0.9700033728565488, 6.333213099411555, 8.49080376965659, 10.497161252158028, 1.8340823267187392, 79.56057030814034, 87.04925537109375, 80.01723371233258, 81.43663256508964, 81.10841356004987, 84.10900701795305, 82.27994237627301, 74.87133530208042, 71.77059050968715, 62.1350371497018, 58.076788902282715, 66.56871741158622, 68.79146698543003, 63.262986864362446, 58.598098346165244, 54.284437792641775, 58.82485975537981, 73.45388889312744, 74.84838540213448, 68.46524211338588, 70.31711074284145, 67.50476482936314, 59.929331507001606, 59.754139627729145, 58.593658447265625, 57.387517179761616, 55.77265507834298, 54.03241620744978, 52.672910826546804, 48.53007868358067, 51.44301019396101, 48.17963239124843, 48.32584680829729, 50.31839214052473, 53.25337723323277, 51.214348452431814, 50.90816913332258, 49.70903859819685, 50.046589033944265, 53.059463432856965, 51.34018727711269, 50.10648250579834, 51.28443145751953, 51.50593308040074, 50.545740672520225, 51.65938752038138, 56.099203041621614, 66.10386208125523, 66.06808580671037, 43.60632460457938, 57.66073424475533, 59.864407539367676, 62.965631757463726, 63.75295993259975, 64.52661405290876, 59.20030566624233, 52.19246373857771, 51.4136575290135, 52.95371879850115, 53.78043283735003, 52.3007618359157, 53.49116195951189, 53.66446392876761, 51.15384006500244, 52.36598457608904, 52.30436100278582, 51.46202046530587, 57.84963839394705, 65.37006977626255, 63.83203738076346, 64.40844603947231, 62.70659596579415, 63.10693727220808, 66.35963221958706, 65.93998881748745, 68.23423535483224, 65.11085333142961, 65.52797453744071, 57.63990701947893, 51.45980051585606, 57.047166619982036, 54.66306250435965, 55.4725832257952, 53.32818501336234, 54.405607427869526, 60.540550640651155, 65.01107025146484, 65.89775766645158, 72.15436036246163, 66.19123567853654, 75.83058275495256, 71.37698200770787, 66.10770443507603, 38.39352893829346, 0.9350613164050239, 3.4435878012861525, 5.206979155540466, 4.9563988872936795, 5.252337430204664, 1.8634686470031738, 1.4091149760144097, 1.820950665644237, 0.16377989734922135, 0.3483055686312062, 22.217879431588308, 42.76738521030971, 56.11575365066528, 66.82072162628174, 44.39443792615618, 30.50531898226057, 50.493639605385916, 70.07611247471401, 73.65840911865234, 77.33024719783238, 63.00281156812395, 0.488387793302536, 0.11020811913268906, 0.22584557692919457, 0.19418887847236224, 0.1516073862356799, 0.14278336401496614, 0.12513389464999947, 0.15413362639290945, 0.1424730835216386, 0.18609144512031758, 0.1880877629986831, 0.10261768714657851, 0.17432980053126812, 0.1713614405265876, 0.1431343158973115, 0.08795415184327535, 0.12440080541585173, 0.07550093757786921, 0.07869976878698383, 0.17569403589836188, 0.11486656059111867, 0.19432894167091164], [0.03864234200279627, 0.053325317334383726, 0.024391584996400133, 0.03752146661281586, 0.04384283794622336, 0.05852515170616763, 0.016881900373846292, 0.0358610269613564, 0.030985440726258924, 0.04271111956664494, 0.07497982268354722, 0.042104560150099654, 0.05212072768647756, 0.022466095995956233, 0.005451153140581612, 0.028227830305695534, 0.06201778179300683, 0.23461678198405675, 4.5661298632621765, 87.30242688315255, 71.17795085906982, 77.62097372327531, 47.98765366418021, 38.06842620032174, 28.417406150272914, 61.531773703438894, 43.113301277160645, 59.82129396711077, 13.2119231905256, 0.17884093203714915, 0.16189937825713838, 0.10945451778492757, 0.39250618112938745, 0.21032102139932768, 2.768429607152939, 3.76855092389243, 0.23527854361704417, 1.0429672747850418, 49.02192081723894, 85.92849704197475, 72.78580570220947, 74.09360953739711, 70.63920838492257, 75.21340901511056, 76.04182883671352, 73.80050672803605, 70.42046519688198, 66.90093163081578, 52.81826366697039, 53.11092873982021, 52.733804838997976, 52.711636611393516, 51.38033744267055, 52.139740807669504, 49.75218343734741, 54.4516600881304, 62.87896687643868, 65.22411591666085, 66.16912651062012, 65.84837681906563, 58.743357385907856, 51.26865209851946, 50.1401743207659, 47.843794686453684, 47.812211649758474, 46.76397514343262, 45.76178087506975, 44.6332231930324, 46.59456416538784, 46.38347094399588, 46.62833588463919, 45.097908292497905, 46.284052644457134, 45.44974422454834, 45.264526094709126, 47.043473379952566, 46.55968768256051, 45.929093497140066, 45.527789865221294, 45.54593161174229, 46.6808260508946, 52.26664618083409, 52.589139870234895, 48.843491077423096, 50.09700516292027, 48.42174237115042, 58.04761341639927, 58.048645223890034, 39.85157367161342, 59.28375353131975, 57.01544809341431, 59.82560185023716, 58.41633347102574, 58.76573058537075, 50.678023951394216, 44.17392642157418, 45.75787946156093, 46.42649071557181, 45.55200433731079, 47.31543976919991, 45.64380046299526, 47.867772919791086, 48.4638032913208, 47.501095635550364, 46.231857776641846, 47.1975496837071, 44.317069734845845, 54.29965782165527, 56.427102429526194, 55.96842752184187, 54.45714569091797, 59.290486335754395, 59.86365018572126, 62.18081883021763, 63.268010411943706, 62.5347809110369, 59.5250575201852, 56.16075018474034, 46.65938738414219, 48.19344541004726, 48.23281042916434, 47.179922103881836, 50.25495161328997, 57.60082687650408, 61.83875206538609, 64.2773265838623, 64.45745168413434, 66.51571655273438, 65.83083956582206, 65.2782632282802, 65.06095831734794, 60.336162430899485, 59.990281105041504, 45.03779942648751, 5.570134137357984, 0.5575219893029758, 1.2187059989997318, 0.9821958328996385, 0.5161778735263007, 0.2197060292320592, 1.0575382986239024, 0.19954866729676723, 0.17033787045095647, 3.720448979309627, 21.070163828986033, 33.89150619506836, 47.46222046443394, 50.20308331080845, 37.68619884763445, 36.81881005423409, 42.40985870361328, 46.495851108006065, 50.91709756851196, 69.33511488778251, 11.469611150877816, 0.6429025392447199, 0.2091206115271364, 0.10940301697701216, 0.04388319720913257, 0.01161520485766232, 0.026701513278697218, 0.046002882931913645, 0.03138538622962577, 0.023743770650721023, 0.04212689073756337, 0.12434317065136773, 0.029377424690340246, 0.024888309949476804, 0.03369906511423843, 0.08571943747145788, 0.04810758660148297, 0.07106903182076556, 0.015621370602665203, 0.04520505806431174, 0.03471058101526328, 0.040663212670811584, 0.034991131496748755, 0.05531554875363197, 0.07622500229626894, 0.06569339920367513, 0.028822895339024917, 0.0476254705073578, 0.03347113163077405, 0.05465759030942406, 0.03188576509377786, 0.00857466399403555, 0.07457787889455046, 0.022725318425468037, 0.08127812721899577, 0.022115788721878613, 0.10018482019326516, 0.11457758609737669, 0.09652738752109663, 0.6137689054012299, 7.709094950131007, 100.0932058606829, 79.1225072315761, 85.01232147216797, 55.51580449513027, 46.994061265672954, 34.51404741832188, 44.185293674468994, 42.89587824685233, 58.34194605691092, 14.672811474118914, 0.04752810412485685, 0.11734480118112904, 0.432379097278629, 0.8975739936743463, 0.8146073999149459, 3.3374306176389967, 2.121460037572043, 0.37829125246831347, 0.5271391453487533, 53.302441937582834, 92.66640145438058, 77.21792956760952, 77.62019552503313, 73.4234071459089, 79.03654411860875, 77.50907298496791, 77.57811723436627, 73.27758530208042, 71.32270268031529, 55.57414157049996, 54.671528884342735, 55.554106439862935, 53.94984034129551, 52.68235342843192, 54.1506849697658, 52.34140532357352, 57.30569519315447, 65.68012619018555, 68.04929515293666, 68.42469242640904, 66.98679052080426, 62.14785657610212, 54.90370641435896, 52.55369363512312, 50.45734569004604, 49.8208281653268, 50.0469468661717, 49.34269135338919, 47.97908306121826, 47.84838397162301, 48.1772005217416, 47.61548382895333, 47.76021133150373, 47.95155777250017, 47.81270497185843, 47.31696489879063, 49.24373163495745, 50.02487938744681, 49.94389465876988, 48.152801922389436, 46.67396470478603, 49.1833552633013, 55.57138313565935, 55.895982129233225, 53.108333587646484, 52.56726346697126, 51.77214288711548, 61.14564841134207, 60.29190240587507, 41.46834305354527, 59.89084543500628, 59.226326669965474, 62.54633576529366, 62.173148018973215, 62.938832555498394, 52.71606261389596, 45.465304715292795, 48.5297486441476, 48.83497953414917, 49.54837540217808, 50.451922621045796, 47.99730123792376, 50.82620818274361, 50.51857321602957, 49.46541738510132, 47.69430766786848, 48.61428737640381, 46.29341534205845, 55.922649315425325, 58.54750851222447, 58.99708475385393, 58.6241124016898, 60.97673075539725, 62.16784654344831, 63.88118198939732, 65.70340960366386, 63.40224960872105, 63.7988805770874, 57.97140210015433, 50.87518950871059, 50.200314453669954, 51.28626578194754, 49.89996814727783, 52.02812147140503, 60.649824959891184, 65.1050168446132, 67.57974978855678, 68.5141018458775, 70.00913184029716, 68.03537791115897, 67.62127222333635, 67.35312734331403, 63.037663732256206, 65.84624372209821, 52.293810163225444, 9.12403392791748, 0.5582034555929047, 0.500394226184913, 0.5080818650977952, 1.3889969012566974, 1.2373911163636615, 1.332655695932252, 0.2544259604598795, 0.11999562036778245, 3.1855733948094502, 35.962677342551096, 35.58281932558332, 55.74618591581072, 49.71359314237322, 30.426241534096853, 46.93843398775373, 47.34124190466744, 53.012351172310964, 56.388772691999165, 78.43609469277519, 18.297214201518468, 0.47628685406276156, 0.17630587092467717, 0.13133050714220318, 0.02804870214978499, 0.049150511888521056, 0.00972745003777423, 0.056418836515929015, 0.029276662240070955, 0.03142534515687397, 0.05080583199326481, 0.04972224888790931, 0.011893268508304442, 0.011294661522177714, 0.05461456101121647, 0.016745029682559625, 0.06234567027006831, 0.09096593808914934, 0.05545235159141677, 0.009384341172075697, 0.02758519827122135, 0.06699542648025922, 0.1443718144936221, 0.16874643441821846, 0.13542725731219563, 0.17174854475472653, 0.1293362791516951, 0.07911463866808585, 0.08436354129974331, 0.09894703661224671, 0.07337496522814035, 0.11938013482306685, 0.20630161065076077, 0.1422217541507312, 0.17157463622944696, 0.137786116451025, 0.1492859008056777, 0.3149759827979973, 0.24628847997103417, 0.6534297657864434, 9.281846625464302, 116.1316909790039, 88.02846499851772, 97.22693497794015, 64.14680467333112, 56.40490640912737, 36.50836801528931, 84.02641378130231, 62.83077417101179, 87.09858758108956, 22.452594791139873, 0.2927508939589773, 0.45144983966435703, 0.34598139620253016, 2.7398492779050554, 1.034194522670337, 6.818203440734318, 7.853206668581281, 4.673392244747706, 2.801619414772306, 58.8355530330113, 94.09188692910331, 80.95740141187395, 78.03211947849819, 76.41375201089042, 80.65840653010777, 79.63194915226528, 81.81145313807896, 77.3925586427961, 72.34527601514543, 59.44314520699637, 58.76363222939627, 58.05278982434954, 56.26028660365513, 54.87629577091762, 57.18507099151611, 55.6017815044948, 59.402831758771626, 69.85412447793144, 70.99676268441337, 69.787442616054, 72.3763553074428, 65.29570320674351, 58.525976044791086, 55.57827227456229, 51.7282406943185, 51.51547990526472, 51.913295541490825, 51.36833095550537, 49.47046177727835, 51.616079398563926, 51.97568689073835, 51.254585470472065, 51.11560412815639, 51.02564580099923, 50.482946327754426, 49.98196383884975, 52.54923636572701, 52.26729236330305, 53.09781748907906, 50.868081501552034, 49.66102654593331, 52.006978103092735, 59.598541668483186, 57.68403155463082, 54.93583835874285, 56.292498452322825, 53.67321171079363, 63.46171229226248, 65.70375006539481, 46.04587881905692, 61.59086813245501, 62.86461884634835, 65.8505585534232, 63.725848061697825, 66.07261603219169, 56.432025228227886, 48.63004241670881, 51.32502630778721, 49.66277749197823, 50.22086722510201, 53.14197676522391, 50.83799580165318, 53.94341673169817, 53.87033210481916, 52.840942587171284, 50.33551597595215, 51.09666681289673, 49.082592487335205, 60.0240285055978, 60.641549655369346, 61.54577432359968, 61.44063418252127, 64.23385865347726, 64.79829556601388, 66.08537292480469, 68.35160432543073, 65.20161070142473, 66.28099250793457, 60.86921433040074, 54.56314046042306, 54.91507714135306, 53.66842440196446, 53.34224121911185, 55.6431302343096, 63.40124906812395, 68.09104687826974, 70.9336383002145, 70.20419556753976, 73.98059013911656, 71.50478717258999, 71.08897917611259, 71.45148059300014, 64.30042239597866, 65.50833892822266, 53.03036437715803, 8.030795676367623, 2.0514280583177293, 4.80976106439318, 4.012691080570221, 2.784159025975636, 2.4044265108449117, 1.907453566789627, 0.7880578988364765, 0.3140214468751635, 6.814057971749987, 40.22206899097988, 49.65546451296125, 60.707536697387695, 62.45096479143415, 52.15478365761893, 51.86460951396397, 57.59480973652431, 63.9017208644322, 64.81977244785854, 90.0507868358067, 19.348077126911708, 0.9345183798245021, 0.3825557364949158, 0.20850428459899767, 0.20003144496253558, 0.1151080240628549, 0.12377105706504413, 0.08545603017721858, 0.16828151579414094, 0.15405499775494846, 0.1377943538661514, 0.2309037297964096, 0.06377710096005883, 0.13436440005898476, 0.13287538210196154, 0.138786358492715, 0.149740478556071, 0.29653752648404663, 0.13165118279201643, 0.14903776054935797, 0.1617916947496789, 0.19030712890837873], [0.05870339607021638, 0.03028828670669879, 0.018688642353351628, 0.07356841556195702, 0.07243522815406322, 0.06244387464331729, 0.0387108061861779, 0.015572348143905401, 0.028667850087263753, 0.00328980982054158, 0.06047040982437985, 0.019342571995886307, 0.06107914394565991, 0.05929584535104888, 0.036444709569747956, 0.056808274904532094, 0.13600515201687813, 0.24937985837459564, 26.555495636803762, 85.07678685869489, 65.95307227543422, 73.09971836635044, 50.03306783948626, 42.38961165291922, 34.605944292885916, 68.72889845711845, 47.39246055058071, 30.496699741908483, 0.7785843557545117, 0.059482788534036705, 0.1644852887839079, 0.0857916200267417, 0.5008531329887254, 0.9854915589094162, 4.942264948572431, 1.3263345722641264, 2.6130320600100925, 18.35530982698713, 88.58843421936035, 67.68598774501255, 78.04183306012834, 63.47804055895124, 74.12270164489746, 73.9363648550851, 76.20574378967285, 70.13440091269356, 71.93538788386753, 67.90536321912492, 62.37626470838274, 51.511898108891074, 53.52441256386893, 55.33316414696829, 51.771521023341585, 50.31520986557007, 48.77214697429112, 51.712336267743794, 63.2584844316755, 64.26529230390275, 65.76788193838937, 62.28131757463728, 60.89557579585484, 52.107952799115864, 48.9533942086356, 46.79032966068813, 47.30501052311489, 45.7509833744594, 46.62784603663853, 44.573923792157856, 43.697811535426546, 44.69766426086426, 44.69717788696289, 42.919998918260845, 45.79642459324428, 46.52635717391968, 49.127217292785645, 50.25939498628889, 52.76924760001046, 45.07676839828491, 46.307686941964285, 44.46607037952968, 47.83315004621233, 54.91080052512032, 59.025753021240234, 54.918794427599224, 56.98194735390799, 52.03205067770821, 57.5195746421814, 54.34710012163435, 40.27961049761091, 62.160988671439036, 56.01669665745327, 59.63502665928432, 59.82444150107247, 56.72217852728707, 44.64112329483032, 44.906554903302876, 44.65936926433018, 44.881940909794395, 47.32339545658657, 48.06495932170323, 44.76867832456316, 46.27169527326311, 48.10039166041783, 44.339776447841096, 44.81804180145264, 44.638347489493235, 45.03654180254255, 46.02011489868164, 47.507432392665315, 51.253821168627056, 54.02652413504464, 54.171786648886545, 56.519329343523296, 60.33079842158726, 60.850065095084055, 61.994113785879954, 62.456634521484375, 61.85996491568429, 50.002641677856445, 45.74232244491577, 48.40521955490112, 46.09159449168614, 54.30075216293335, 63.42902796609061, 64.93880203792027, 62.921309198652, 68.17343861716134, 64.62920420510429, 62.59203406742641, 61.56374931335449, 69.91512271336147, 70.00135680607387, 65.40294170379639, 72.3227152143206, 69.2377428327288, 27.02479260308402, 0.17400870418974332, 1.6477934143372943, 2.4694772831031253, 2.1761729759829382, 0.31638397010309355, 0.19214625736432417, 0.08683169207402638, 0.08396344312599727, 8.294580561774117, 22.41243420328413, 36.71577174322945, 45.07218953541347, 26.834662096840994, 25.523827110018047, 35.45871755055019, 41.31000402995518, 54.02492952346802, 55.0538569859096, 41.64815201078142, 0.6532416215964726, 0.043396260123699903, 0.06881246862134763, 0.03941016544454864, 0.04323286210585918, 0.041994518733450344, 0.021245031517797282, 0.043823618441820145, 0.035307922533580234, 0.04528434488124081, 0.03639039623418024, 0.023905889630051594, 0.03451154973091824, 0.03125336706372244, 0.01165586437231728, 0.04619821620040706, 0.05401529584612165, 0.006722625137107181, 0.03542365346636091, 0.04659978000979338, 0.01219510124064982, 0.010054006889861609, 0.05970565336091178, 0.02836922343288149, 0.017119323169546466, 0.03873688567961965, 0.04679233467738543, 0.035586539190262556, 0.035154800928596935, 0.02814600576779672, 0.025019394433391944, 0.07686433834689003, 0.023556712116780024, 0.05003052431025675, 0.05867268557527235, 0.03331209659310324, 0.08546951266803912, 0.1634738916265113, 0.16249194288892405, 34.6625269481114, 98.7578454698835, 72.32872540610177, 83.39336340767997, 58.684665952410015, 52.87727471760341, 26.59601058278765, 59.80637618473598, 46.61824362618582, 32.200147901262554, 1.1993897897856576, 0.0983722699540002, 0.4262581957238061, 1.0444394243615014, 0.9082031090344701, 3.0038690992764066, 2.43682205251285, 0.6825262159109116, 1.312362287725721, 21.425776106970652, 93.95047719138009, 72.27794797079903, 83.24761799403599, 66.72804655347551, 77.94930389949253, 75.10041740962437, 79.44379193442208, 72.67381463732038, 76.5857685634068, 70.05256502968925, 65.822585105896, 53.399358885628835, 56.52581896100725, 57.96640287126814, 54.83017710277012, 52.708395276750835, 52.010709285736084, 53.58712700435093, 65.9930591583252, 66.26750605446952, 69.75735691615513, 65.07419463566372, 64.35014370509556, 54.7656318119594, 51.08403498785836, 48.30361604690552, 49.46367686135428, 47.4459582056318, 49.39665453774588, 46.926729747227256, 46.87656722749983, 46.535726819719585, 46.89705746514456, 44.54632207325527, 49.14709261485508, 48.89411565235683, 50.964915071214946, 53.225299562726704, 54.521816049303325, 47.08726787567139, 49.24711888177054, 47.11535596847534, 50.73758043561663, 57.41952405657087, 62.259465490068706, 57.61974682126726, 60.775837489536826, 55.62642329079764, 60.56445939200265, 56.82141269956316, 43.26687731061663, 63.73857021331787, 59.75577245439802, 61.954488209315706, 61.83351312364851, 58.921933037894114, 47.42479746682303, 47.16909333637783, 48.29004968915667, 48.20074101856777, 49.472876276288716, 49.49237986973354, 47.19874824796404, 48.24718625204903, 50.47386155809675, 47.24601684297834, 47.11105850764683, 48.914887292044504, 48.07770579201834, 46.94674750736782, 50.642768791743684, 54.80891561508179, 56.06675148010254, 56.66203839438302, 59.71452794756208, 64.1681912285941, 63.514212880815776, 64.35149165562221, 65.14004271371024, 64.36783381870815, 51.57912540435791, 48.03189631870815, 50.48765025820051, 49.98245716094971, 58.93890053885323, 67.01821027483258, 67.07572051456997, 64.51591382707868, 68.77403395516532, 67.67091710226876, 64.1342214856829, 63.29457337515694, 69.41952855246407, 70.43932955605644, 68.32756355830601, 74.17953096117292, 75.41813768659318, 34.20427935464041, 1.3834417079176222, 1.2809903025627136, 0.45262253816638676, 1.868784236056464, 1.4161757571356637, 0.5040157032864434, 0.17884399901543344, 0.08998136342103992, 11.77181349481855, 32.5532032421657, 38.333937713078086, 50.8585798399789, 25.01737117767334, 34.00037751879011, 43.49085249219622, 50.27729007175991, 61.995322772434776, 60.550361497061594, 57.54179150717599, 1.8400002377373832, 0.16047890590769903, 0.04604167477892978, 0.02612971860383238, 0.023719540165205086, 0.00918190024926194, 0.08137409242668323, 0.04710860324225255, 0.010848777501710823, 0.03876153685684715, 0.014758043357038071, 0.034482189520661316, 0.04246357302846653, 0.00593910930079541, 0.027952606324106455, 0.08589322386043412, 0.032930454571864436, 0.039952155468719344, 0.02926104575661676, 0.0661290797537991, 0.010929553703005825, 0.2013043902282204, 0.2708457479519503, 0.10077570884355477, 0.13181241628314766, 0.19266555378479616, 0.26771553020392147, 0.13579206487962178, 0.11940549846206393, 0.16335185031805718, 0.1532410950000797, 0.13919463301343576, 0.12785521362509045, 0.14180320660982812, 0.1863653561366456, 0.08735516827021327, 0.16182016607906136, 0.35583035913961275, 0.3072751803057534, 42.0011100769043, 109.78310108184814, 83.41571576254708, 92.96952356610979, 70.44556903839111, 59.78287737710135, 47.31784732001168, 96.98183032444545, 61.3889604296003, 48.66461317879813, 2.2177192951951707, 0.25528930127620697, 0.7229708113840648, 1.6955892039196832, 1.1500995946781976, 4.822999554021018, 11.407586319105965, 8.358851398740496, 6.603846737316676, 23.102114132472447, 96.74379198891776, 75.50115476335797, 86.61805711473737, 68.57840742383684, 82.76666368756975, 77.64757142748151, 80.51225117274693, 75.34631415775844, 79.19157232557023, 74.13592406681606, 69.17494501386369, 55.97372899736677, 58.086502483912874, 59.857563563755576, 56.67903021403721, 55.46696560723441, 54.52952854973929, 56.5974131992885, 68.80077757154191, 69.84924684252057, 71.00586482456752, 68.43323871067592, 68.88012599945068, 56.45803233555385, 54.82215888159615, 51.28058910369873, 51.97722591672625, 50.48069511141096, 51.678971018110005, 49.646143504551475, 49.60576057434082, 49.79391084398542, 48.518346650259836, 46.40957185200283, 51.75282342093331, 51.706075940813335, 53.891996588025776, 55.554981912885395, 57.856381620679585, 50.717614786965505, 51.61694097518921, 48.90900216783796, 54.11600303649902, 60.53342178889683, 63.668379511152, 60.569566317967, 64.1854088647025, 59.64915929521833, 63.88247435433524, 59.85146304539272, 46.576279980795725, 65.19514887673515, 62.425291197640554, 64.00544357299805, 65.43395151410783, 60.61047036307198, 50.31093324933733, 50.25697701317923, 48.58389595576695, 50.593634605407715, 52.913700648716514, 52.104016644614084, 49.88869816916329, 52.206061363220215, 53.95258140563965, 50.05383253097534, 50.29124205453055, 50.61832850319998, 50.514108998434885, 49.91620608738491, 53.44394895008632, 56.08254473549979, 60.55117443629673, 59.57242338997977, 63.36409705025809, 67.93542807442802, 67.10871056147984, 67.268449647086, 68.15462289537702, 68.05036517551967, 53.80588756288801, 51.25893504279, 53.52881077357701, 52.45314277921404, 61.225914001464844, 70.33399486541748, 70.721280506679, 66.99840790884835, 72.29039219447544, 69.99192810058594, 65.37195273808071, 63.02884646824428, 69.00056607382638, 73.59247071402413, 71.52516623905727, 78.32761941637311, 75.6758394241333, 30.61536455154419, 0.8210978316409248, 4.963119966643197, 8.182500907352992, 5.40132200717926, 1.803322434425354, 0.9782380738428661, 0.2594118086355073, 0.24266708429370606, 13.494921582085745, 35.97015707833426, 49.95213522229876, 58.123696190970286, 36.08922488348824, 37.43941967827933, 49.7597257069179, 57.124145712171284, 70.3568822315761, 71.79666709899902, 61.89198916299002, 1.3833200058766773, 0.22338383831083775, 0.1823340845959527, 0.11778834595211915, 0.13067956135741302, 0.1043214885784047, 0.10233634617179632, 0.22427142996873173, 0.10153305570461921, 0.07273474708199501, 0.16817052103579044, 0.08210627242390599, 0.1236779484897852, 0.12462470840130534, 0.07878440924521003, 0.18680503325802938, 0.11927289914871965, 0.09402493680162088, 0.10971900394984654, 0.15465619335217135, 0.07178466234888349], [0.00821075209283403, 0.07000938403819289, 0.04105518538770931, 0.10415313725492784, 0.02469727859300162, 0.051880604321403165, 0.015393713622220924, 0.029151462351105044, 0.04045426459716899, 0.02886705779071365, 0.039835888493273935, 0.01972340147144028, 0.044102421695632596, 0.007145852449217013, 0.02031949787799801, 0.022033397607239227, 0.0231512586053993, 0.7040740453771183, 66.89609568459647, 75.7704530443464, 75.036299433027, 53.739296027592246, 45.21433578218733, 22.393872090748378, 66.4569069998605, 97.25710405622209, 55.432380948747905, 18.491263491766794, 0.02130727862407054, 0.1291120776108333, 0.3094230964779854, 0.6360517239996365, 0.4521492192787783, 0.7171965326581682, 1.3295993570770537, 1.0015757701226642, 1.8819814707551683, 76.09742137363979, 72.77469553266252, 78.29098851340157, 62.14736325400216, 66.3160878590175, 66.71511595589774, 76.17991038731166, 70.9354726246425, 70.47077015468052, 71.30070468357631, 67.33040673392159, 62.074052810668945, 57.664673873356406, 50.72454214096069, 53.278929233551025, 49.193992955344065, 49.925318649836946, 49.11404698235648, 51.768991879054475, 61.87013707842146, 64.97317477634975, 64.78263432638985, 64.85511793409074, 61.15848173413958, 53.77528074809483, 50.06791305541992, 45.56590073449271, 45.967517035348074, 45.43704291752407, 43.89780500956944, 42.94159044538225, 45.933783531188965, 44.336448260716026, 44.37572642735073, 45.58378887176514, 44.33779273714338, 48.060797350747244, 55.80849041257586, 54.149979727608816, 54.1461477960859, 46.65449932643345, 45.07565668651036, 43.75991106033325, 47.36150632585798, 55.387943744659424, 62.27664838518415, 57.44968966075352, 63.4002902167184, 57.042174339294434, 63.32636138371059, 50.05833843776158, 41.18904284068516, 63.18819645472935, 51.961255482264924, 58.317537035260884, 54.9055928502764, 54.000666413988384, 44.6387539591108, 43.60175963810512, 42.70930869238717, 46.16178519385201, 44.14529636928013, 45.45768254143851, 44.12062679018293, 44.89082070759365, 45.47944777352469, 43.992713928222656, 40.446461064474924, 42.461150305611746, 43.584055628095356, 46.387007577078684, 44.819824014391216, 46.0394413130624, 48.29716464451381, 53.299329144614084, 52.7475449017116, 57.22584649494716, 58.77622931344168, 60.38866301945278, 60.73924132755825, 60.35472106933594, 51.77260146822248, 45.51150328772408, 48.173073291778564, 47.50627899169922, 57.3923670223781, 64.6806139264788, 65.50132819584438, 62.03867258344378, 63.06075259617397, 61.60206862858364, 66.53128746577671, 64.81017698560441, 63.80548136574881, 64.80485466548375, 63.47116184234619, 61.04315553392683, 64.56014605930874, 74.28241293770927, 47.830520153045654, 1.8302178255149295, 0.8046346721904618, 1.6246987964425768, 0.5637610916580472, 0.24781265961272375, 0.17700725900275366, 0.12406657263636589, 6.342175841331482, 12.755304949624197, 32.04563733509609, 32.640663691929404, 25.235221522194998, 23.6182975428445, 21.701696021216257, 42.34096384048462, 50.86577122552054, 53.180504526410786, 67.84439972468785, 20.67992867742266, 0.447068240493536, 0.12911561956363066, 0.11517089711768286, 0.04683360317721963, 0.024153398848803978, 0.030430860484817197, 0.0331479012966156, 0.0280500524344721, 0.04308526038325258, 0.03236577772934522, 0.028596413920500448, 0.024572931961821656, 0.04875578771212271, 0.07773855607956648, 0.07227777410298586, 0.03845552095611181, 0.07110483132834945, 0.010757701987001513, 0.04162979259022644, 0.014261769629748804, 0.027356328409431235, 0.01929002963671727, 0.037866094548787387, 0.006337236330312277, 0.035423232774649344, 0.011526100487182183, 0.03379635685788734, 0.05239402462861367, 0.05608453927561641, 0.048102117609232664, 0.09393971958862883, 0.014383973786607385, 0.04973249137401581, 0.02909452308501516, 0.04938131218243923, 0.061829630817685804, 0.07366135450346128, 1.5556397821222032, 82.29398468562535, 82.74622903551374, 84.22624397277832, 62.31472451346261, 58.047290325164795, 32.27085624422346, 54.951252937316895, 80.29234068734306, 56.37880202702114, 20.5145354952131, 0.018113607673772743, 0.07722342586410896, 0.610147374016898, 1.6494343834263938, 1.1400910403047289, 3.9703374675342014, 3.24947532585689, 0.7135505197303635, 2.4325628067765916, 83.06039878300258, 75.48597294943673, 84.03530052730015, 66.93387304033551, 69.52833039419991, 69.51414912087577, 79.21313953399658, 71.91396658761161, 72.2236408506121, 73.25556646074567, 69.11887305123466, 65.4733339037214, 60.58001640864781, 52.251790932246614, 55.345497199467246, 51.97982106889997, 53.2804856300354, 51.46479974474226, 53.80741964067732, 65.09442778996059, 67.17641380855015, 66.55856609344482, 67.3160239628383, 65.15584291730607, 56.480937072208945, 52.426048278808594, 48.35856587546212, 48.58455950873238, 47.62147317613874, 47.11442838396345, 47.35355411257063, 46.47412061691284, 46.22724764687674, 46.6190322467259, 47.29155533654349, 46.74019840785435, 52.019825322287424, 58.04820053918021, 57.031953539167134, 57.14489303316389, 49.84324652808053, 46.86535283497402, 46.90975529806954, 49.09626654216221, 61.21555423736572, 65.33512033735002, 60.96890013558524, 65.09929152897426, 58.82884802137102, 65.89228248596191, 52.769553320748464, 42.7609407561166, 66.16536753518241, 55.29420212336949, 60.55298096793038, 57.20050988878523, 57.58447081702096, 45.66049351011004, 45.79905448641096, 45.73360592978341, 47.2340589932033, 46.694986479622976, 48.399542876652305, 44.78293602807181, 48.06263862337385, 46.48225348336356, 47.539564337049214, 43.34994649887085, 45.06034285681588, 45.38556024006435, 48.112877573285786, 47.46803958075387, 47.41935702732631, 50.08851446424212, 55.52825914110456, 54.941587993076865, 60.61241585867745, 62.22254971095494, 62.604881286621094, 63.22306946345738, 63.125370843069895, 54.768643856048584, 48.06266294206892, 50.99857561928885, 48.376356737954275, 61.569161960056846, 68.19474179404122, 67.18887192862374, 64.92500986371721, 65.37578814370292, 65.18460151127407, 66.85866573878697, 67.65019757407052, 64.46722085135323, 67.09757259913853, 65.97584847041539, 65.32134900774274, 66.73978900909424, 76.49426078796387, 56.232229777744834, 4.75710631268365, 0.5156528502702713, 0.4740274410162653, 0.9337890361036573, 1.3820343720061439, 0.25058653791035923, 0.0391250823491386, 1.3547913538558143, 20.38797058377947, 36.62808895111084, 35.902064732142854, 27.7913977759225, 30.172812938690186, 36.79261881964547, 47.08569758278983, 58.00813027790615, 59.14873613630022, 78.75402341570172, 32.48729263033186, 0.274755846709013, 0.09733423351177148, 0.1619241719267198, 0.02687867877206632, 0.06427702520574842, 0.022070881578006914, 0.0670510595664382, 0.05366211836891515, 0.051797690734799416, 0.040747788668211014, 0.03222784173807927, 0.0866600905678102, 0.04394429589488676, 0.02773696619884244, 0.03933761987302985, 0.056217450715069256, 0.04529452629919563, 0.01051350062646504, 0.009778978835259165, 0.019597385644114444, 0.11266673648996012, 0.201572465843388, 0.12871756378029073, 0.17892527393996716, 0.15053091756999493, 0.15650100793157304, 0.12991094402968884, 0.12526550330221653, 0.16740893333085946, 0.16823485972625868, 0.16456162397350582, 0.1328274639589446, 0.1945926882326603, 0.07996506017765828, 0.15252738472606453, 0.1517782820654767, 0.1444636338523456, 1.7851105545248305, 94.59937640598842, 92.0033209664481, 97.72984559195382, 70.13779858180455, 64.07331357683454, 31.39237812587193, 92.09411307743618, 116.3489750453404, 75.60078498295375, 30.31012323924473, 0.09303977180804525, 0.2614534119410174, 0.6921905630401203, 3.8652785335268294, 0.8914815091661045, 6.581993349960872, 9.337030955723353, 5.834528727190835, 2.2288980782032013, 87.77924006325858, 76.17720753805978, 88.50562558855329, 67.36815629686627, 72.57622718811035, 72.97934777396065, 83.25582381657192, 74.96541391100202, 73.67647443498883, 75.93208898816789, 74.2526329585484, 68.6171783719744, 63.87248979296003, 56.70938689368111, 59.27057974679129, 54.14305932181222, 55.95929758889334, 53.51812097004482, 57.64917939049857, 67.3835882459368, 70.4940744127546, 68.38494873046875, 71.44886807032994, 67.61203111921037, 59.7868378502982, 55.70418405532837, 51.803336824689595, 50.43142543520246, 50.050799642290386, 48.28038821901594, 49.06300204140799, 50.89529064723423, 49.36202124186924, 48.766800335475374, 48.37412984030587, 48.478366715567454, 54.54164968218122, 61.164644786289756, 60.183378492082866, 60.76414367130825, 52.97261095046997, 50.17780229023525, 49.597214290073936, 51.3240396635873, 64.38195950644356, 69.6254940032959, 63.50038596561977, 67.73768929072789, 61.539104052952354, 68.45450714656285, 55.5044059753418, 49.142996651785715, 67.20938995906285, 59.821342604500906, 65.04878507341657, 59.9781356539045, 60.630606242588584, 47.540797642299104, 47.777345589229036, 47.684354373386924, 50.13176352637154, 48.21842418398176, 51.11929709570748, 47.53632647650582, 49.639518397195, 50.47844736916678, 49.17262029647827, 46.00663539341518, 48.35559899466378, 47.27311481748308, 51.87785972867693, 50.305183615003315, 50.85610628128052, 53.50634377343314, 58.842535972595215, 58.80914987836565, 63.18210288456508, 67.16449069976807, 64.95242050715855, 66.58849893297467, 65.6128328868321, 55.661167757851736, 50.57108770098005, 54.7150593485151, 51.50074277605329, 64.31356838771275, 71.15400041852678, 71.06114469255719, 66.64738491603306, 66.20134530748639, 66.68226487295968, 68.76690510341099, 68.55786854880196, 69.58650071280343, 70.40636730194092, 68.80283423832485, 68.37047563280377, 71.26235062735421, 80.2595660345895, 53.76295116969517, 2.7333157999174933, 3.6494379554476057, 6.659190007618495, 1.9535757090364183, 1.4486320955412728, 0.4288949285234724, 0.26517732068896294, 10.334345851625715, 23.22961183956691, 47.857781410217285, 44.02537046160017, 32.64876181738717, 30.363068512507848, 36.07514435904366, 55.499681200299946, 67.00063133239746, 68.05061531066895, 89.61440522330147, 33.94094957624163, 0.6373093479446003, 0.2783433427768094, 0.35066505202225273, 0.24752401081579073, 0.13344376374568256, 0.13153541114713463, 0.19432081282138824, 0.11880916117557458, 0.08889977860131434, 0.06216408072837761, 0.12307209814233439, 0.185616009203451, 0.0995954650321177, 0.13189365049558027, 0.1105110307357141, 0.13032233981149538, 0.09968291462532111, 0.1198666715728385, 0.16950049038444245, 0.06313997014824833], [0.020869291054883173, 0.050690813522253714, 0.030503942099000727, 0.04938475235498377, 0.06420836424721138, 0.03595811514449971, 0.0688163973391056, 0.01954316899978689, 0.043138169151331694, 0.04816497370068516, 0.06294099653937987, 0.040915152723235745, 0.05029959737190178, 0.03517758274184806, 0.08087701802807194, 0.07450469210743904, 0.36618778907826965, 26.60086042540414, 88.49751704079765, 65.85490117754254, 73.67106873648507, 57.94746903010777, 36.519856861659456, 20.195488112313406, 42.93272801807949, 53.207324572971885, 36.41215978349958, 1.3197015396186282, 0.10187003655093056, 0.03747360275260039, 0.2916419506072998, 1.2480815712894713, 0.9806919821671077, 1.8270134031772614, 1.6924460125820977, 0.44873417967132156, 41.064030851636616, 84.99796649387905, 73.143721308027, 73.02961104256767, 61.3208680834089, 60.76613780430385, 63.43854699816023, 67.05560547964913, 70.39348534175328, 71.19493920462472, 66.67395482744489, 67.64329801286969, 59.395223481314524, 53.17342778614589, 53.237646511622835, 48.19327517918178, 51.14456769398281, 47.9709849357605, 48.54655981063843, 48.923419679914204, 59.99372741154262, 63.41035120827811, 65.95098086765834, 63.28614521026611, 64.1092427117484, 56.201609066554475, 51.014368874686106, 45.16836997440883, 45.77091775621687, 45.53441497257778, 43.35822875159127, 43.509946141924175, 44.223376750946045, 45.29837424414498, 45.466298307691304, 43.78412553242275, 50.200050422123496, 53.9618364061628, 58.314611843654085, 57.37490272521973, 55.80254970278059, 46.62791204452515, 43.825745241982595, 42.68011583600725, 45.23701122828892, 55.68908561979021, 60.30173410688128, 56.22588954653059, 58.57862254551479, 56.340656416756765, 61.74945381709507, 42.745863165174214, 38.30022505351475, 61.57691614968436, 49.7176057270595, 54.311664308820454, 48.47621972220284, 48.829702377319336, 43.19264623097011, 47.72753395353045, 46.95204550879342, 48.51009913853237, 48.09463855198452, 49.03846100398472, 45.42754125595093, 44.3845089503697, 41.89869710377285, 44.16781548091343, 40.37548521586827, 40.389572688511436, 41.81342533656529, 43.26023135866438, 42.33118772506714, 44.49068089893886, 43.91204881668091, 46.76210607801165, 46.86336217607771, 50.95038638796125, 57.073125089917866, 60.25953074863979, 57.41040454592024, 62.82078960963658, 51.920181206294465, 45.13366024834769, 45.97080700738089, 44.99232694080898, 55.5685065814427, 61.85291249411446, 62.27421651567732, 65.86305141448975, 63.22885036468506, 64.66775281088692, 64.97334153311593, 64.9569924218314, 64.31267207009452, 62.02993174961635, 60.125076157706125, 61.888306617736816, 65.01565606253487, 63.82208061218262, 68.59290136609758, 58.519535064697266, 3.9201497605868747, 1.2847393985305513, 1.4239129019635064, 0.4070637971162796, 0.7917874529957771, 0.07153519216392722, 0.9798469075134822, 21.570161410740443, 29.333560875483922, 33.50419623511178, 27.650821822030203, 17.088385718209402, 13.633189865521022, 28.296161821910314, 46.84284067153931, 55.91843523297991, 56.91455677577427, 54.675114154815674, 3.322965119566236, 0.201247651129961, 0.14495717308350972, 0.05556256264182074, 0.06577973599944796, 0.04068725655919739, 0.048413809455399, 0.026685002825355957, 0.048055536180202446, 0.06154652565185513, 0.02847400281046118, 0.04625200706401041, 0.024207359346161996, 0.032154369966260025, 0.030748659146151373, 0.02695696135716779, 0.035729967922504456, 0.027181205306468264, 0.0531599617430142, 0.06997706541525466, 0.013936700465689813, 0.016790204847763692, 0.052331212641937394, 0.05164509838713067, 0.013464322197251022, 0.048251853324472904, 0.028299337718635798, 0.009400611593654113, 0.04103734330939395, 0.04483574163168669, 0.02017704114717032, 0.009167426249145396, 0.025946700745927434, 0.03580819622480443, 0.06664771799530302, 0.09605498465576343, 0.2752250129623072, 33.13940191268921, 101.97982937949044, 72.81534249441964, 84.22256142752511, 64.85037231445312, 48.8902976172311, 28.855064494269236, 38.34601715632847, 57.9940949167524, 39.97424064363752, 1.6513942096914564, 0.10254140623978206, 0.18897220625409059, 0.8571102363722665, 1.0581387749740054, 3.9075787322861806, 3.9194245423589433, 1.5955715136868613, 0.442509082279035, 45.601235798427034, 89.10585962023053, 76.01992116655622, 77.32345185961042, 63.01563099452427, 63.08026313781738, 66.44733238220215, 71.42163808005196, 72.69912692478725, 74.01425416128976, 69.96239130837577, 70.1283073425293, 63.780009269714355, 57.31542614528111, 54.610992704119, 51.61928251811436, 52.49706581660679, 49.93772118432181, 51.923405170440674, 50.956191607883994, 63.0317508152553, 67.2177347455706, 66.46891348702567, 65.61524391174316, 64.15568447113037, 59.48557090759277, 53.96448366982596, 47.68409729003906, 49.806671210697715, 46.86927509307861, 45.35492563247681, 46.39849642344883, 46.91451481410435, 47.12063659940447, 48.82682234900338, 46.47382879257202, 52.51732676369803, 57.849047797066824, 61.04767186301095, 59.331605775015696, 59.30058901650565, 50.359994479588096, 47.76362637111119, 44.53994362694876, 46.8053377696446, 57.493880203792024, 63.01527663639614, 59.898585728236604, 61.778122084481375, 59.89729336329869, 62.93898541586739, 44.23110662187849, 39.754135608673096, 63.88451712472098, 52.27335466657366, 55.02259704044887, 51.21918092455183, 52.41976015908377, 45.45688349860055, 50.27888815743582, 48.86306415285383, 52.97877400262015, 50.320375851222444, 52.41042525427682, 48.31175238745553, 48.05040979385376, 45.31567873273577, 46.914184774671284, 43.11488894053868, 42.80008690697806, 45.639996324266704, 45.8142397744315, 44.94846296310425, 46.7079622404916, 45.20799207687378, 48.59460660389492, 48.821124826158794, 53.735797609601704, 59.24856785365513, 63.01105213165283, 58.579129764011924, 65.32141848972866, 53.57873705455235, 47.896858079092844, 48.693628856113975, 48.7295058795384, 57.315193380628315, 65.59624058859688, 64.09714589800153, 67.86229828425816, 66.64723900386265, 67.10572283608573, 67.57813780648368, 68.61926283155168, 65.50412831987653, 64.44800908224923, 60.48723016466413, 64.67033059256417, 67.2494671685355, 66.620835849217, 70.54599135262626, 66.73753084455217, 6.869071636881147, 0.2502474332494395, 0.6172305196523666, 1.3798069315297263, 1.3429805019072123, 0.1810835852686848, 0.36685022924627575, 16.82088007245745, 39.31423820768084, 33.25150762285505, 29.45934064047677, 20.342183692114695, 22.678968838282994, 38.573487281799316, 54.47885186331612, 62.19452067783901, 60.395826612200054, 68.68841130392892, 6.460054636001587, 0.28792764991521835, 0.12784061155148915, 0.014801951358094811, 0.10083750302770308, 0.03621827904134989, 0.029326524385916333, 0.03339723238189306, 0.08953824612711157, 0.020015778818300793, 0.03525292727031878, 0.02164977935275861, 0.032210230361670256, 0.02989910276872771, 0.028567996873919452, 0.00828797446696886, 0.07354231231978961, 0.03641443672989096, 0.00799418831177588, 0.06366068470690932, 0.1457985836480345, 0.21204899224851811, 0.12017528287002019, 0.16834771367056028, 0.1523567195981741, 0.13234792969056539, 0.20303420669266156, 0.10351401155016252, 0.11641467894826617, 0.12970860488712788, 0.11641686383102622, 0.13042223373694078, 0.11958032979496888, 0.16772937827876636, 0.22136808718953813, 0.2680285248373236, 0.3948094275380884, 40.42519957678658, 112.77257742200578, 83.91575677054269, 92.69817556653703, 76.73662785121373, 52.23628602709089, 31.453070640563965, 57.09451511928013, 64.31546524592808, 55.512267862047466, 2.3142319449356625, 0.3095712342432567, 0.27300913472260746, 2.1552916850362505, 2.2916390086923326, 7.817478162901742, 9.189601472445897, 8.47913600717272, 2.4056322404316495, 49.86688082558768, 90.90645749228341, 79.45439488547188, 80.85935538155692, 66.04519149235317, 66.15939208439418, 69.9664421081543, 74.19839532034737, 77.62289142608643, 77.97485937391008, 71.80451161520821, 73.32855033874512, 66.73919146401542, 59.35777963910784, 58.69409465789795, 53.0121739932469, 55.93599680491856, 52.172258377075195, 55.07148109163557, 54.05463307244437, 66.87782192230225, 68.1853061403547, 69.58181067875454, 66.90170982905796, 68.11061300550188, 62.03695637839181, 56.69543491091047, 49.74259144919259, 51.750537463596885, 50.01080928530012, 47.59685223443167, 49.466793128422324, 49.862770966121126, 49.66353137152535, 50.822609015873496, 49.75375720432827, 55.46622562408447, 59.03068624223982, 63.604157311575754, 62.696326528276714, 62.42203944069998, 51.720326696123394, 48.41114984239851, 46.40766109739031, 50.455101421901155, 60.52438218252999, 65.20300728934151, 62.07704748426165, 63.56021690368652, 64.18065629686627, 65.99288545336042, 46.48725618634905, 44.67485332489014, 66.38608401162284, 54.191338879721506, 58.68520096370152, 55.30466611044747, 54.93287147794451, 49.40834835597447, 52.119580609457834, 51.66518579210554, 54.51629570552281, 53.265216963631765, 54.608022349221365, 50.54644591467721, 49.84779412405831, 47.84542751312256, 48.81497567040579, 46.03717620032174, 44.7078537940979, 48.072015217372346, 47.5744686126709, 46.39626605170113, 48.373810223170686, 48.59981427873884, 51.35554279599871, 52.186116559164866, 56.43483577455793, 63.331475257873535, 65.96771907806396, 62.029229981558665, 69.12231935773576, 57.7735139301845, 50.64681959152222, 52.06531170436314, 50.62444291796003, 60.372348649161204, 67.995696749006, 66.9412659236363, 71.61302621023995, 69.36996705191476, 69.59768036433628, 70.80278287615094, 70.97903088160923, 68.34091104779924, 68.28247669764927, 63.93496104649135, 68.59706333705357, 69.5620083127703, 69.7830513545445, 74.98910726819719, 69.11735139574323, 5.297470322677067, 3.739065374646868, 7.736903377941676, 1.5080223658255167, 2.399842002562114, 0.14113015415413038, 2.2730267388480048, 29.89596196583339, 46.54542997905186, 46.700506823403494, 36.5474168913705, 26.117911985942296, 20.975767339978898, 41.29946708679199, 62.377612658909385, 70.16236046382359, 69.0892459324428, 77.33151871817452, 5.928609507424491, 0.4330825209617615, 0.37103594892791336, 0.14726117945143155, 0.2017915648009096, 0.12516115818704876, 0.11698844816003527, 0.0989726445238505, 0.14696364184575422, 0.13469057184244904, 0.07802236692181655, 0.12004304996558599, 0.08897241577506065, 0.09599376722638096, 0.06604817802352564, 0.1286503073892423, 0.1821680606475898, 0.19282939285039902, 0.13721443712711334, 0.14552057428019388], [0.07795333955436945, 0.038797790982893536, 0.07999073594276394, 0.02652469214185008, 0.028490983149302856, 0.021830982129488672, 0.035080518307430406, 0.04780159784214837, 0.05362986759947879, 0.04071721048759563, 0.059046653365450244, 0.06081488848264728, 0.02671919420494565, 0.012286439687678856, 0.02432462546442236, 0.10389301407017879, 0.07874421961605549, 50.506306171417236, 77.63017313820976, 69.5097439629691, 64.83459295545305, 38.87714440482003, 17.03907608985901, 33.84319537026541, 37.964519364493235, 29.15643392290388, 23.334093638828822, 0.48219276858227594, 0.05980636831372976, 0.08993967422949416, 1.085797056555748, 0.27011895552277565, 2.3383791063513075, 3.3516926637717654, 1.2933204237903868, 10.802123767989022, 80.53580556597028, 71.57799339294434, 73.66421781267438, 64.57075595855713, 58.60499790736607, 53.36525017874581, 56.434735025678364, 58.3027651650565, 65.3884825025286, 63.53810773577009, 66.33395167759487, 61.76667145320347, 58.704364095415386, 51.73680434908186, 50.6835720879691, 47.404925618852886, 48.080804688589915, 47.068598066057476, 46.99209492547171, 48.19155550003052, 55.20715161732265, 59.52799660818917, 62.68239539010184, 64.43632916041783, 63.26990032196045, 57.20819807052612, 51.63907446180071, 46.56198058809553, 44.13468994413103, 43.894466400146484, 45.42999049595424, 45.398289339882986, 45.34815461294991, 44.56342853818621, 48.19650609152657, 50.780898979731965, 57.99129131862095, 58.96197550637381, 62.73354107992989, 58.794496127537315, 53.65208223887852, 46.500832966395784, 47.70135314123971, 44.72916391917637, 44.11127798897879, 53.84072930472237, 58.33638749803816, 56.425764901297434, 59.551078523908345, 54.34487322398594, 58.893216133117676, 40.96363285609654, 39.989891460963655, 60.199970790318076, 48.99971784864153, 48.01574175698416, 45.083226748875205, 48.337578841618125, 47.21943998336792, 53.02033117839268, 52.573336192539756, 52.482516288757324, 49.96318285805838, 50.562874930245535, 48.332030705043245, 47.89947407586234, 42.979235785348074, 42.16257578986031, 40.87943458557129, 39.67537430354527, 39.12944391795567, 40.34325252260481, 41.96833542415074, 43.608252729688374, 42.234441007886616, 44.65445341382708, 43.51150253840855, 45.53189625058855, 49.448116370609824, 59.6584073475429, 58.447468348911826, 57.7951853615897, 49.112959589277, 45.70455551147461, 45.045119353703086, 46.590221541268484, 53.49850273132324, 60.29058919634138, 60.459326199122835, 60.46336310250418, 62.09967081887381, 63.79292597089495, 62.04279286520821, 61.29308918544224, 57.191633565085276, 55.7285235949925, 51.97076061793736, 51.88148321424212, 53.043711866651265, 62.797256061008994, 63.195283617292134, 69.86771515437535, 53.515508447374614, 1.9966521518571037, 0.5828108265995979, 1.9124323853424616, 0.3845758166696344, 0.4535070764166968, 0.08491559739091567, 5.052407358373914, 33.46541486467634, 27.803249665669032, 43.32970987047468, 41.34809752873012, 25.682230404445104, 25.74297676767622, 40.24163859231131, 48.67611592156546, 53.60322598048619, 55.62783030101231, 28.347809519086564, 0.2734194312776838, 0.019466294374849116, 0.03484469685437424, 0.055811364469783645, 0.07195153446601969, 0.05688808758610061, 0.012026262220128306, 0.03449880684326802, 0.0496883662417531, 0.009188595693558455, 0.05128923051857522, 0.05363775896174567, 0.012084876619545477, 0.039692398692880354, 0.04947652421625597, 0.009402021250155355, 0.04304211912676692, 0.022367733863315413, 0.04668789117463997, 0.048620223200746944, 0.04205482353323272, 0.09697779906647545, 0.05006401001342705, 0.04049411495881421, 0.040965754472251446, 0.06972875552518026, 0.03203683752300484, 0.02676685111198042, 0.054264698177576065, 0.04301723724763308, 0.013540755774426674, 0.06724744117153542, 0.015279385560591306, 0.08347914554178715, 0.0671035171087299, 0.4297395960560867, 62.35360663277762, 86.30363028390067, 77.32111726488385, 71.73525891985211, 52.03976665224348, 25.931806223733084, 30.863387448447092, 35.649758270808626, 36.87501403263637, 26.671410696847097, 0.4237368953015123, 0.0778574761269348, 0.2090218032577208, 0.6629799019013132, 1.5715002396277018, 6.307366669178009, 8.275324497904096, 1.2553413531609943, 13.350796835763113, 84.58354118892125, 75.01947089603969, 77.2620575768607, 67.62968649183, 60.79466710771833, 56.17770031520298, 58.59442274911063, 62.26257133483887, 66.36733082362584, 66.0693712234497, 68.51759678976876, 64.8559934071132, 60.569475991385325, 54.653599057878765, 52.71680607114519, 50.066808291843955, 50.85203811100551, 49.48675877707345, 49.28401034218924, 50.8932409286499, 57.48560837336949, 64.7060443333217, 64.80569539751325, 66.80442810058594, 65.73970699310303, 60.79001876286098, 53.5574859891619, 48.36998176574707, 47.312295709337505, 47.05990239552089, 47.47164569582258, 47.93901974814278, 47.20655802318028, 46.67649384907314, 49.08222770690918, 55.582892826625276, 61.68548175266811, 62.12522629329136, 64.55624811989921, 59.713277271815706, 55.54157188960484, 48.76740482875279, 49.1888165473938, 46.835159437997, 46.26110969270979, 56.36928646905081, 62.85706615447998, 58.42667933872768, 60.715846742902485, 56.458643777029856, 60.77332918984549, 42.96093075616019, 43.314448152269634, 62.70903478349958, 50.78843777520316, 50.213932922908235, 46.95358453478132, 49.695159571511404, 50.174588748386924, 54.711731161390034, 55.34844323566982, 55.89350509643555, 53.73840318407331, 54.411103452954976, 49.961265155247276, 50.26747574125017, 45.68620531899588, 45.55583279473441, 43.50048616954258, 42.677208014896934, 41.651539257594514, 43.07163987840925, 44.600837639399934, 45.831808294568745, 45.36303070613316, 47.272951534816194, 45.15243080684117, 47.24585356031145, 51.6401549066816, 61.93707602364676, 62.051901953560964, 60.687803813389365, 52.511862005506245, 47.577852385384695, 47.657968589237754, 49.008906841278076, 56.21457093102591, 62.77133233206612, 62.87861251831055, 63.526921136038645, 63.872878892081125, 66.34800788334438, 63.66100747244698, 63.41546508244106, 59.78250217437744, 56.55684961591448, 54.01007774897984, 53.54791137150356, 54.41930232729231, 65.27867317199707, 66.05095849718366, 70.42098631177629, 61.664303643362864, 3.68060279744012, 0.8261278931583677, 1.5271935313940048, 0.8667492877159799, 0.4650018396122115, 0.04564391415832298, 1.2307236684220177, 38.94144303458077, 33.98091908863613, 38.561949798039024, 32.19210883549282, 27.700431959969656, 37.68536853790283, 46.51548671722412, 53.53132602146694, 59.94162287030901, 62.843718664986746, 44.1399427822658, 0.6552705498678344, 0.06913674729210989, 0.02410927541287882, 0.061759931700570245, 0.025256148872098753, 0.03729809627735189, 0.03420049570766943, 0.022246274398639798, 0.02689461755965437, 0.013570227094792893, 0.04104532627388835, 0.03682504201840077, 0.0198267338730927, 0.037666520436427424, 0.043494722340255976, 0.014370274164580872, 0.04217857814260891, 0.02310465682031853, 0.03743988634752376, 0.3081092084092753, 0.09924925610955272, 0.19458156025835446, 0.19964564352163247, 0.11313820297696761, 0.2484693458037717, 0.13536080159246922, 0.13220686226018838, 0.11721282612000193, 0.17333373826529297, 0.15099770895072392, 0.2096604404172727, 0.13435080221721105, 0.18136771502239363, 0.11984928750566073, 0.214828597381711, 0.5814938172698021, 72.94993604932512, 92.29677118573869, 89.5409071786063, 81.8752862385341, 57.19165093558175, 26.27786820275443, 48.1646659714835, 52.7532320022583, 47.439399106161936, 34.70035988943917, 1.1630602649280002, 0.13445440094385827, 0.43706155887671877, 2.0669989713600705, 2.523298680782318, 6.715785256453922, 7.891601545470102, 6.4260614429201395, 13.570818492344447, 90.20706571851457, 76.66464451381138, 81.97188009534563, 71.2610513142177, 64.28408718109131, 59.541052273341585, 63.00436101640974, 64.59235095977783, 70.75092847006661, 69.20535727909633, 73.05103233882359, 67.93547671181815, 63.61252989087786, 57.872157505580354, 57.38763877323696, 53.29627193723406, 53.643004417419434, 50.724802698407856, 50.81817953927176, 53.53827769415719, 61.796215193612234, 66.88380432128906, 67.83573532104492, 69.44942665100098, 67.70531068529401, 62.583341870989116, 57.13962977273123, 51.203005518232075, 48.93345635277884, 49.18246936798096, 49.42939097540719, 51.03337914603097, 49.81364720208304, 50.221179894038606, 51.594255106789724, 56.576037066323416, 64.67005961281913, 63.97393349238804, 67.25144740513393, 64.12105464935303, 59.066212381635395, 51.696626390729634, 52.014541217258994, 48.95583650044033, 49.005835737500874, 60.096185547964915, 66.5339138848441, 61.210315295628135, 64.41162136622837, 59.56446075439453, 61.32261902945382, 45.00899566922869, 46.73217671258109, 63.79815101623535, 53.45507649012974, 52.29958759035383, 51.18488114220755, 53.51999698366438, 52.27923631668091, 57.43690150124686, 58.72189440046038, 58.26211125510079, 55.86470481327602, 58.10217414583479, 54.5609587260655, 53.18300240380423, 48.90333938598633, 48.343436173030305, 46.61867788859776, 44.407948698316304, 44.21192959376744, 45.08290713174002, 46.90500620433262, 49.237186431884766, 46.45852191107613, 48.8216598374503, 48.023572376796174, 49.47221967152187, 55.013345514025005, 65.66399942125592, 65.82044506072998, 63.35702378409249, 54.80564648764474, 50.82363734926496, 49.18517221723284, 51.58574703761509, 59.565878186907085, 65.84936346326555, 65.44401250566754, 66.53811754499162, 66.78620992388043, 69.78560134342739, 66.80759647914341, 67.12483733040946, 63.93014594486782, 61.22517054421561, 57.17693812506539, 57.89530890328543, 57.80247054781233, 69.4183543069022, 69.79698944091797, 76.63120283399309, 62.9894015448434, 3.1493387562888007, 3.314627932650702, 7.452040263584681, 1.4954587199858256, 1.781078319464411, 0.12999743010316575, 9.108412640435354, 48.652787344796316, 42.31061410903931, 56.309757777622764, 56.43683338165283, 36.55941990443638, 37.34047038214547, 55.45896128245762, 64.21451486860002, 69.52840682438442, 72.54676682608468, 47.245283808027, 0.8826968148350716, 0.14724329326833996, 0.12295138676251684, 0.12686118696417126, 0.234902200954301, 0.13327174154775484, 0.09979253195758377, 0.10758426492767674, 0.09441647864878178, 0.12155665803168501, 0.14552970736154489, 0.165575043165258, 0.07540197324539934, 0.14627798220941, 0.0981254189142159, 0.13083095609077386, 0.11067833032991205, 0.14087392576038837, 0.1713712385722569], [0.06638163048774004, 0.046465019562414715, 0.05473205952772072, 0.022953246819919775, 0.027002329904852167, 0.06905980820634536, 0.050613467315477986, 0.029049125699592487, 0.08140428723501307, 0.03472423992518868, 0.039339967604194365, 0.0611606767135007, 0.016381906578317285, 0.046837582785104, 0.0840405382748161, 0.1949234197714499, 8.896318878446307, 81.50196647644043, 70.00706127711705, 68.91835498809814, 49.08432953698294, 26.65708872250148, 19.803771257400513, 54.175542150224956, 44.12527513504028, 38.82879189082554, 5.444946706295013, 0.42826348383511814, 0.2087194887655122, 0.4162528711770262, 0.5624382740684918, 0.36733730882406235, 4.783995841230665, 6.016442554337638, 0.41330743208527565, 44.35957186562674, 81.25381851196289, 73.30321025848389, 71.44093322753906, 61.03157983507429, 57.10016747883388, 54.94559015546526, 50.76710333142962, 49.94108411243984, 51.69639015197754, 54.38837936946324, 54.259775161743164, 55.36483751024519, 52.56153815133231, 48.59583296094622, 49.15577786309378, 47.97639758246285, 47.50886719567435, 48.08846160343715, 48.286669390542166, 46.847898960113525, 51.11795956747872, 59.727006912231445, 63.22079045431954, 62.65210124424526, 64.03149236951555, 60.953155517578125, 53.76111684526716, 46.039583751133506, 45.877520493098665, 44.68391030175345, 45.15131562096732, 44.90257011141096, 48.602423327309744, 50.63550445011684, 55.25624064036778, 56.59356737136841, 59.29280008588518, 60.32728263310024, 59.18447766985212, 54.11768797465733, 48.476327419281006, 45.13507073266165, 45.077035903930664, 44.31983164378575, 42.9939729145595, 45.72868660518101, 56.76047004972185, 53.827208110264365, 58.13661636625017, 54.72835125241961, 64.40588215419224, 47.89582279750279, 41.71739428383963, 60.34388187953404, 47.75552824565342, 47.934187276022776, 46.79215356281826, 51.51164102554321, 50.98588126046317, 51.51351009096418, 51.371530600956504, 52.13622849328177, 50.211730343954905, 48.820971965789795, 45.497836181095664, 43.799658230372835, 41.71605328151158, 39.055240631103516, 41.74727848597935, 41.152095794677734, 40.04094682421003, 39.76442241668701, 42.0416875566755, 40.99952725001744, 43.59810835974557, 43.317237854003906, 45.34082773753575, 42.416900702885215, 47.44016688210623, 51.0302038192749, 56.40309987749372, 55.34252337047032, 48.028512545994346, 44.338539668491904, 46.62569209507534, 44.9186760357448, 53.4612569127764, 53.83261380876814, 56.252452509743826, 58.93246650695801, 58.8747547694615, 58.02679661342076, 56.13650097165789, 51.22452756336757, 51.56797007152012, 48.556898730141775, 51.34838267735073, 49.37068564551217, 53.46063852310181, 50.520779269082205, 60.33325113568987, 61.49970776694161, 70.73904705047607, 28.227438926696777, 0.13258102004017147, 0.7367848615561212, 0.5363951772451401, 0.3226683443146092, 0.09191315261913197, 0.08622470178774425, 31.270708220345632, 44.37178679874965, 33.06375340053013, 60.140313557216096, 24.756553173065186, 18.058298655918666, 28.230221680232457, 41.06737640925816, 54.7763216154916, 50.78836134501866, 60.78769111633301, 13.085350462368556, 0.5250936608229364, 0.03130133609686579, 0.08749790489673615, 0.043886311684868166, 0.04451676571209516, 0.05795227816062314, 0.07070774585008621, 0.07798635706837688, 0.08098590254251446, 0.016768177904720818, 0.01442081993445754, 0.019019821725253547, 0.01835356479776757, 0.040755293265517266, 0.01807968601185296, 0.048853995478046794, 0.08312032265322548, 0.03487880002441151, 0.024457075500062535, 0.036439756264111826, 0.05516870699024626, 0.04372658793415342, 0.04247166455856391, 0.050768824693347724, 0.07774395043296473, 0.0170555222180805, 0.05521671673549073, 0.043169897448803694, 0.10219911924962487, 0.028405241768008897, 0.05637658753299287, 0.06904854452503578, 0.1611374919967992, 0.39261808512466295, 12.478723219462804, 94.79411356789726, 78.44468961443219, 77.64379855564663, 57.11689179284232, 40.64192083903721, 28.19572561127799, 40.46196249553135, 36.62138393947056, 46.58446148463658, 7.32710383619581, 0.4199083021708897, 0.4048979676195553, 1.2910089535372598, 2.159550062247685, 1.9342297528471266, 2.6390973584992543, 0.9140569120645523, 0.4315721020102501, 46.20247384480068, 85.22401918683732, 75.85263633728027, 75.0190817969186, 63.386192321777344, 61.17108576638358, 59.25908047812325, 53.951667717524934, 51.73643609455654, 54.464882510049, 55.560821873801096, 56.631490639277864, 55.96299403054373, 55.891160079411094, 51.2050587109157, 50.8829402242388, 50.132322856358115, 50.58383764539446, 50.12501335144043, 50.0676976612636, 48.53761053085327, 53.142213003976, 61.234620094299316, 65.11902441297258, 65.56712763650077, 65.7571747643607, 62.96390860421317, 55.724031584603445, 47.22719069889614, 48.25141075679234, 47.25535869598389, 47.132500648498535, 48.019636222294395, 51.2189724785941, 53.53762108939034, 58.188394342150005, 59.48475796835763, 61.63725430624825, 63.34591361454555, 61.78096389770508, 56.88404376166207, 51.96105398450579, 46.57916348321097, 47.18959747041975, 46.02992922919137, 44.97092648914882, 49.09377213886806, 58.52703217097691, 56.28997278213501, 59.75882271357945, 55.953853675297324, 65.00476128714425, 49.13813638687134, 44.34942749568394, 62.75950649806431, 50.22543913977486, 49.239990030016216, 48.64912217003958, 53.64163909639631, 53.69556406566075, 53.75026028496878, 52.03297478812081, 52.932877676827566, 51.321135316576274, 50.15642268317086, 48.0723626273019, 46.01835353033883, 45.648306369781494, 42.303950786590576, 43.967537130628315, 42.54460164478847, 41.65809835706438, 43.17444542476109, 42.79856177738735, 43.48219156265259, 45.27766861234392, 46.14637756347656, 46.748932293483186, 46.076972007751465, 50.62080206189837, 55.674629892621724, 58.82552678244454, 57.04455409731184, 49.931853430611746, 46.354799202510286, 47.65157972063337, 47.767201219286235, 55.62334523882185, 56.47132771355765, 58.56181485312325, 61.285022326878135, 61.49919360024588, 60.24507849557059, 58.540442194257466, 54.78665011269705, 54.62755026136126, 50.54241943359375, 53.08070755004883, 52.23314891542707, 57.96414818082537, 54.03632109505789, 63.9190913609096, 63.353042466299875, 74.05636024475098, 33.13109881537301, 0.3201637901365757, 1.1706197964293616, 1.0073213875293732, 0.89659826031753, 0.0439311255301748, 0.38321529967444284, 26.92432165145874, 55.001092365809846, 32.69990750721523, 49.248393876211985, 21.482608897345408, 27.049965926579066, 37.02879851205008, 48.099147932870046, 60.93563910893032, 57.458791800907676, 70.80739648001534, 25.240903411592754, 0.35021325626543587, 0.0381067607418767, 0.06227502120392663, 0.10630880908242293, 0.03596629149147442, 0.03649636644071766, 0.05241983610072306, 0.08446847674037729, 0.027659200996692692, 0.08323000105363981, 0.044764179935944934, 0.019008658127859235, 0.007542979487750147, 0.006641167856287211, 0.06610695272684097, 0.021431560794423734, 0.008214871648565998, 0.039144685225827355, 0.18709562266511576, 0.09919938378568206, 0.13045626905347618, 0.07385024508195263, 0.20905233733356, 0.1633252381746258, 0.20447063818573952, 0.11644391023686954, 0.14467149626995834, 0.11008493110005345, 0.1851268804499081, 0.1156849552478109, 0.211306647796716, 0.13877082004078797, 0.2656154100384031, 0.5462272582309586, 15.051126990999494, 107.6589742388044, 89.33072417122978, 87.74356801169259, 65.6888461794172, 41.3262801851545, 28.474212884902954, 77.06267207009452, 61.58753994532994, 58.531249727521626, 9.339660848890032, 0.745757482945919, 0.6440324900405747, 1.7821247833115714, 4.583146001611437, 3.754041348184858, 14.911966732570104, 15.163988317762103, 0.8350919378655297, 52.46397154671805, 85.05521965026855, 78.81618894849504, 75.9388565335955, 66.89646393912179, 63.43756035396031, 61.910179546901155, 55.07098429543631, 54.88355663844517, 55.717204979487825, 60.561228479657856, 58.46599224635533, 61.156841959272114, 58.312152181352886, 54.44107450757708, 55.213224342891145, 53.26562690734863, 53.01728091921125, 54.08613967895508, 51.65884556089129, 51.6978041103908, 56.344575200762065, 64.58094896589006, 68.47531005314418, 68.6252521787371, 67.69613211495536, 66.76451764787946, 59.33926963806152, 51.09053502764021, 51.21507453918457, 50.34235300336565, 50.26895570755005, 51.00178916113717, 53.80065209524972, 55.32185247966221, 59.99548530578613, 62.58815697261265, 64.26616777692522, 64.93540436880929, 63.569068908691406, 59.3103859765189, 54.61293819972447, 49.978399412972585, 49.59576906476702, 49.77259029660906, 46.81001738139561, 50.70273174558367, 61.32674625941685, 58.52186965942383, 62.043070793151855, 59.220219203404014, 67.40758732386998, 51.260689462934224, 46.15170683179583, 66.44278826032365, 53.46335874285017, 51.66249336515154, 51.58639669418335, 55.934947626931326, 56.87401056289673, 56.7811096736363, 55.59403773716518, 56.42611231122698, 55.51609284537179, 53.09947463444301, 50.945251669202534, 49.87817164829799, 47.21842902047293, 43.75401551382882, 47.23845025471279, 45.63098798479353, 44.81262220655169, 46.28394147327968, 45.76062747410366, 45.80337626593453, 46.724808147975374, 47.42000668389456, 49.23540421894619, 46.98947198050362, 54.52303198405674, 57.43338223866054, 63.58857945033482, 60.65286827087402, 52.93141508102417, 50.366855825696675, 50.74172156197684, 50.31989295142037, 60.49540819440569, 60.16835648672921, 62.17904009137835, 65.36168330056327, 64.08429173060826, 63.96201038360596, 62.532071113586426, 57.656485421316965, 57.14028985159737, 54.66683537619454, 56.11162642070225, 54.31306784493582, 59.45674977983747, 56.78069625582014, 66.94135625021798, 68.80269527435303, 76.18100820268903, 34.10379103251866, 0.7348628704036985, 6.8708542840821405, 2.688344887324742, 0.8578706298555646, 0.323989316288914, 1.0746137137923921, 38.9716294833592, 60.26037842886788, 47.03173787253243, 79.29818548474992, 37.37843533924648, 25.224955558776855, 41.29841096060616, 53.932032108306885, 70.72685991014752, 64.80823843819755, 84.077531678336, 25.189636128289358, 0.5967729059713227, 0.20695421206099646, 0.1704886680735009, 0.22330496540027006, 0.21272452814238413, 0.16975481888013227, 0.15153186528810433, 0.17169722036591598, 0.16551842620330198, 0.23226248260055268, 0.1908212820334094, 0.08127394065793071, 0.0669346365279385, 0.11852030881813594, 0.1330322865396738, 0.09672257490456104, 0.15932627847152098, 0.1952696219086647], [0.03969748431284513, 0.031986992340534925, 0.021298593375831842, 0.034331673490149636, 0.04412268275128944, 0.05704458151012659, 0.03826539544388652, 0.0454828536936215, 0.04960898103724633, 0.07469938416033983, 0.008569245891911643, 0.020914483183462704, 0.07301409994917256, 0.03908527609226959, 0.02509571605228952, 0.033063501718321016, 39.809255668095176, 74.94058104923793, 66.28434153965541, 64.57443155561174, 56.452769075121196, 22.46627926826477, 24.24887956891741, 45.66251196180071, 37.32049778529576, 26.22474922452654, 1.2881523753915514, 0.10727251201335873, 0.3538629061409405, 0.8900641852191516, 0.1414417510053941, 1.3819711868252074, 7.6046400751386365, 6.900818390505655, 6.18059287752424, 81.33714130946568, 73.13511943817139, 75.41786670684814, 62.44991561344692, 58.057486806597026, 51.18554469517299, 56.101523739951, 51.09635066986084, 52.14414596557617, 46.79346677235195, 47.75917952401297, 47.590320927756174, 47.69113234111241, 47.55330787386213, 47.84686926433018, 46.26992348262242, 46.45802511487688, 45.42005804606846, 47.025807585035054, 46.182806968688965, 47.6802201952253, 45.66440534591675, 57.25999689102173, 61.73581450326102, 63.12371717180525, 61.63722651345389, 61.43551336015974, 47.97170754841396, 43.730964865003315, 45.306913580213276, 45.44612421308245, 42.585439682006836, 48.70812627247402, 55.44064583097185, 57.91233893803188, 59.30386856624058, 62.273493903023855, 61.24521609715053, 60.0551494870867, 55.361061164310996, 46.40429469517299, 44.49298422677176, 44.065367766789024, 42.5115282194955, 42.39645562853132, 43.09609406335013, 44.80927317483084, 54.19289527620588, 53.341560295649934, 53.70780331747872, 52.29065220696585, 58.68875844138009, 51.505425861903596, 45.241409437997, 58.70332186562674, 45.49018621444702, 47.28007343837193, 49.882851260049, 51.56238371985299, 47.781976563589915, 51.11405120577131, 47.993775027138845, 48.69656447001866, 45.17443922587803, 46.319391182490754, 43.96214880262102, 45.15569993427822, 40.13163818631853, 42.239499296460835, 40.448885985783164, 42.191636630467, 39.65190328870501, 40.03657293319702, 38.46416432516915, 41.55756139755249, 42.02382026399885, 44.4924943787711, 42.424404757363455, 43.67293698447091, 45.06011356626238, 49.98906142371041, 51.51199538367135, 51.37844058445522, 45.86048698425293, 44.43278156008039, 44.08632353373936, 45.972318240574424, 50.66917194638933, 57.82549340384347, 56.37241315841675, 56.46420233590262, 53.96617208208357, 52.20059313092913, 48.75182696751186, 47.647723470415386, 47.137809072222026, 49.05422994068691, 50.95298848833357, 56.573817116873606, 58.35937908717564, 60.469790186200825, 58.336331912449424, 61.38137994493757, 67.50784288133893, 53.96579340526036, 2.2926156648567746, 0.9731118232011795, 0.4355742915400437, 0.24687237292528152, 0.16739247207130703, 0.04077217860945633, 3.9500183292797635, 61.24470887865339, 34.138441698891775, 38.81750454221453, 35.83044270106724, 20.898442574909755, 21.383140223366873, 46.73146799632481, 61.71379566192627, 63.70847756522042, 52.81637723105294, 60.03239413670131, 5.505084233624594, 0.28802522325089996, 0.17527444341353007, 0.08093282753335578, 0.08688940147736243, 0.0476062442176044, 0.09290561186415808, 0.018004394069846188, 0.01913645850228412, 0.027565895646278347, 0.043642490303942134, 0.05858670161770923, 0.03670934161969593, 0.06337004780237164, 0.03200885813151087, 0.04511526073994381, 0.013748519804461725, 0.05537585694608944, 0.059844834463936944, 0.008500599352243756, 0.039778236765414476, 0.011397424802583243, 0.046201652980276516, 0.05939822271466255, 0.01015836387939219, 0.0554483177007309, 0.04333135485649109, 0.0429817837929087, 0.06749946943351201, 0.03607439908332058, 0.1224524871047054, 0.018419270736298392, 0.051260236717228375, 0.04050294609208192, 51.153353691101074, 85.60494027818952, 70.9225628716605, 71.41385609763009, 66.1642975125994, 35.09681715284075, 26.879154886518204, 46.28155824116298, 43.226546491895405, 36.17692157200405, 1.6394849973065513, 0.1354614690478359, 0.8023203249488557, 1.5683517285755701, 1.8832443058490753, 1.9371814344610487, 4.095054592405047, 1.3147385716438293, 8.414471728461129, 84.00741045815604, 76.0472970690046, 77.53967979976109, 65.74204158782959, 61.22699792044503, 55.10308149882725, 57.9989412852696, 54.029136657714844, 55.47984061922346, 49.437374455588206, 49.38316461018154, 50.533004624503, 49.58109099524361, 50.52896424702236, 50.43583059310913, 49.43093000139509, 49.79300062997, 47.858698572431294, 49.50936474118914, 48.91123948778425, 50.187849385397776, 48.76366669791085, 60.88545227050781, 62.33144187927246, 65.25247151511056, 63.805939946855815, 63.40145056588309, 52.41401399884905, 46.847600187574116, 46.86455379213606, 46.66147184371948, 46.552002974918906, 50.66334588187081, 59.76215784890311, 60.88557733808245, 60.8466465813773, 63.712917464120046, 63.28561019897461, 61.52080249786377, 57.01964480536324, 49.52203478131975, 45.68106712613787, 46.036179133823936, 45.91351216179984, 44.59968423843384, 46.452709742954795, 47.35506534576416, 56.18922390256609, 55.04035663604736, 56.07173681259155, 56.578291756766184, 60.91886615753174, 54.57502882821219, 47.82722323281424, 60.70563983917236, 49.37892968314034, 48.47432286398751, 51.65704597745623, 52.45079428809029, 51.09620475769043, 54.942491258893696, 50.45331226076399, 52.80601051875523, 47.846497535705566, 48.733205795288086, 46.661353724343435, 46.93768358230591, 43.2649005481175, 44.431777545383994, 43.410347189222065, 45.65017543520246, 43.02814762932913, 42.77781098229544, 42.217629841395784, 43.692110538482666, 45.014241559164866, 45.51309095110212, 44.46525049209595, 46.3788469178336, 45.94915642057146, 52.528110367911204, 54.49647944314139, 52.82124791826521, 46.846561431884766, 46.07582208088466, 46.24178327832903, 49.001444475991384, 51.828273909432546, 60.301414489746094, 58.25236293247768, 58.62163189479283, 57.00931978225708, 53.66237946919033, 51.24317305428641, 50.79329456601824, 49.65784427097866, 51.642757007053916, 55.779099532536094, 60.1825863974435, 61.91620363507952, 63.83086313520159, 61.39708982195173, 63.85353510720389, 69.28450420924595, 58.13725560052054, 3.154548602444785, 1.2679992339440753, 2.2344225474766324, 1.9686906465462275, 0.38731894376022474, 0.0428848957775959, 2.651312291622162, 62.441035815647666, 38.61750411987305, 35.51075260979788, 26.103138378688268, 20.875909566879272, 35.57102475847517, 59.58388096945626, 67.64768927437919, 69.17262431553432, 57.25607115881783, 73.29342719486782, 10.445025444030762, 0.4801273079855101, 0.15619851702025958, 0.03401181208235877, 0.017947580332734754, 0.01696281737115766, 0.10221465770155191, 0.045311431999185255, 0.04837405408865639, 0.03425810672342777, 0.02443124706457768, 0.030004832095333507, 0.03454707443181958, 0.04893969105822699, 0.018044827971607447, 0.050718602923942466, 0.02407413917327566, 0.02598416605698211, 0.2262629031070641, 0.0941725317388773, 0.055594694667628834, 0.09359846397169999, 0.16440489595489843, 0.1115399883793933, 0.10670305828430823, 0.1343789749911853, 0.23736289462872914, 0.20915932873530046, 0.1244761770857232, 0.10380524556551661, 0.25633573798196657, 0.08967381742383752, 0.15866645744868688, 0.11251014417835645, 61.02115058898926, 95.62748745509556, 84.1311092376709, 80.13004466465541, 73.72427804129464, 33.72414493560791, 34.89378384181431, 65.26447800227574, 55.83416748046875, 45.34640366690499, 2.682286275284631, 0.3570866531559399, 1.5609675305230277, 2.5595259368419647, 4.008919511522565, 4.910000119890485, 18.089994600840978, 12.07591790812356, 8.277263045310974, 88.58997671944755, 77.64682797023228, 82.48856203896659, 68.2932880946568, 64.75676618303571, 58.525315965924946, 63.19393566676548, 57.00260782241821, 59.4667204448155, 52.39870016915457, 52.0412848336356, 53.16868216650826, 53.21396357672555, 53.013542788369314, 55.24651663643973, 51.80389615467617, 52.22289684840611, 50.80348757335118, 53.30874742780413, 51.85637937273298, 52.56849677222115, 49.288175787244526, 62.286674635750906, 65.62183080400739, 67.51477718353271, 66.3750433240618, 67.97811780657086, 53.85860354559762, 49.66753005981445, 49.1968868800572, 50.9052335194179, 48.68928970609392, 53.13545935494559, 60.22371973310198, 64.55912467411586, 63.656081199645996, 66.78675883156913, 66.24028996058873, 64.51795659746442, 59.30397973741804, 50.462827818734304, 47.88315275737217, 48.416899476732524, 46.51489612034389, 47.274883134024485, 48.915394510541645, 49.9198955808367, 60.01651750292097, 59.34921251024519, 57.39526094709124, 59.751103264944895, 62.90883023398263, 57.16651930127825, 50.807361194065635, 64.12758595602853, 52.75298534120832, 51.637542384011404, 55.19821623393467, 56.43054526192801, 54.18345962251936, 58.523606709071565, 52.18357004438128, 55.26142052241734, 50.056243555886404, 50.22194766998291, 48.27427380425589, 50.4180223601205, 44.650395665849956, 47.52882242202759, 46.16609655107771, 48.71429279872349, 45.76484503064837, 45.31494222368513, 44.82261371612549, 46.12403563090733, 47.06586742401123, 47.61517463411604, 47.2232997076852, 48.798675196511404, 48.151394912174766, 56.39554371152605, 57.74101025717599, 55.60887908935547, 50.65688405718122, 49.49482216153826, 47.76064211981637, 49.99631186894008, 55.13022116252354, 64.22632680620465, 61.377662658691406, 61.4379243850708, 59.99235166822161, 57.0599547794887, 53.2592693056379, 52.23195729936872, 53.387300286974224, 55.06445298876081, 57.07104410443987, 62.381343841552734, 65.08498518807548, 68.8253116607666, 64.55980559757778, 66.0549259185791, 72.47731263296944, 60.02051966530936, 3.216564314705985, 2.7327100038528442, 4.886101790836879, 2.2962487041950226, 0.49115024507045746, 0.1112544811995966, 5.177200044904437, 72.7199159349714, 48.32996014186314, 54.74668754850115, 48.90979426247733, 27.265101262501307, 33.24549395697457, 65.30329063960484, 76.04649107796806, 78.41452053615025, 67.08577455793107, 81.45468398502895, 9.326805812971932, 0.5435329313789095, 0.35288082169634954, 0.14877860088433537, 0.14325045395110333, 0.11617943085730076, 0.1919864352260317, 0.10247801749833993, 0.11666253421987806, 0.17195430371378148, 0.17828960876379693, 0.13817924607012952, 0.10455241440130131, 0.13448272299553665, 0.11537164848830019, 0.15852232304002556, 0.10163847290511642, 0.13246857321688107], [0.03982582242627229, 0.02809025563432702, 0.027349963750956312, 0.024285143208024756, 0.07212606724351645, 0.03875088385705437, 0.03429804529462542, 0.04083341978756445, 0.0029219689895398915, 0.051945652080965896, 0.04022179849978004, 0.02156304900667497, 0.09281748373593603, 0.05769584620637553, 0.15780256023364408, 2.7061739649091447, 73.4715164729527, 67.76677445002964, 64.9359324319022, 42.66136959620884, 25.813702481133596, 23.855083465576172, 54.85476677758353, 39.169795581272666, 32.90436519895281, 17.603808300835745, 0.4321168570646218, 0.03053723441969071, 0.4855909262384687, 0.49052398438964573, 0.6137444781405585, 1.1353595341954912, 0.8277075226817812, 0.6865253384624208, 44.54589128494263, 84.14569350651333, 71.69957297188895, 71.29336043766567, 59.96623338971819, 55.58497033800398, 51.586598191942485, 51.342077187129426, 49.98906142371041, 49.56408527919224, 48.86857060023716, 48.92744268689837, 45.58580037525722, 45.03339774268014, 46.3945255279541, 47.34331941604614, 45.38825961521694, 44.3250149999346, 45.87808329718453, 45.80456093379429, 45.578265053885325, 46.73772137505667, 48.41819184167044, 55.019605840955464, 62.43612343924386, 60.24774660382952, 62.43856225694929, 56.20102889197213, 46.76746661322457, 44.74530805860247, 45.01048953192574, 42.46203620093209, 47.98713949748448, 60.06027725764683, 57.22332777295794, 60.31684643881661, 59.51321084158761, 55.83844757080078, 57.87761531557356, 56.861823422568186, 52.45209012712751, 45.1283518246242, 42.51616266795567, 42.02830185209002, 42.17752136502947, 44.30321502685547, 43.4683472769601, 40.37416853223528, 48.58058513913836, 53.47047369820731, 51.853714738573345, 51.8900260244097, 57.37460742677961, 52.32238810403006, 45.27461487906319, 59.768279211861746, 45.59166465486799, 47.01867525918143, 50.088913985661094, 49.954174518585205, 51.86753817967006, 49.79482453210013, 45.97235645566668, 42.418325083596365, 40.63653251102993, 40.8879565511431, 40.66240412848336, 41.6114307812282, 41.2434333392552, 41.64953122820173, 40.711399350847515, 41.27553401674543, 41.27095167977469, 42.10180337088448, 40.47711999075753, 39.99878168106079, 40.84430449349539, 43.02315534864153, 42.20729092189244, 45.28003099986485, 43.06472642081124, 45.612481457846506, 47.17248058319092, 46.85712964194161, 45.17687456948416, 47.46519429343087, 45.28488779067993, 45.46132339750017, 47.5611697605678, 55.78702047892979, 55.21538175855364, 58.09319359915597, 55.06970930099487, 50.747568471091135, 46.72861923490252, 50.194811480385916, 50.423587867191856, 53.25280053274972, 55.69926125662667, 59.73251683371407, 59.8426388331822, 62.209591320582796, 61.40906851632254, 67.01886340550014, 62.18509892054966, 64.41447012765067, 9.256426640919276, 0.3509404829570225, 0.4819762887699263, 0.7909804848687989, 0.30558978074363297, 0.07834927830845118, 0.07578767290604965, 24.746156930923462, 59.50460202353341, 28.924921682902745, 54.75148180552891, 43.68135472706386, 12.512959599494934, 25.65273356437683, 51.58968319211687, 50.89545045580183, 52.728485992976594, 54.64485822405134, 42.49965374810355, 0.8362731859087944, 0.09649679237710578, 0.06551311244922024, 0.022848832154912607, 0.028306518315470645, 0.043857663936380825, 0.05474525364115834, 0.0828289325748171, 0.019370086590892503, 0.03415833493428571, 0.015640004870614836, 0.02834034837516291, 0.042455009916531186, 0.061008895215179236, 0.08129346211041723, 0.01884664092878146, 0.022722818023924316, 0.11468047914760453, 0.02904734793784363, 0.012401636274132346, 0.027713017305359244, 0.05567841571090477, 0.04535165894776583, 0.02884874413056033, 0.015334577599008168, 0.05981170838432653, 0.08205555193126202, 0.017568501477528895, 0.026886005253930177, 0.05193565386746611, 0.026117245433852077, 0.165501544252038, 3.6676570006779263, 85.60758059365409, 74.27930014474052, 73.81736305781773, 51.34074660709926, 37.944032600947786, 24.316251039505005, 35.97223458971296, 35.19751044682094, 42.984929834093364, 23.189195905412944, 0.19404033358607972, 0.12511473282107285, 1.0617007038422992, 1.4234774453299386, 2.8859351532799855, 3.0178981636251723, 0.5937336119157928, 0.48360835547958103, 49.41918407167707, 85.45686721801758, 71.83886350904191, 73.86417307172502, 63.193011556352886, 57.649571963718955, 55.080670084272114, 53.45092841557094, 53.51038415091378, 52.55875539779663, 53.62697492327009, 52.16184302738735, 49.28797081538609, 49.41363593510219, 49.84929493495396, 50.89122595105852, 49.142051696777344, 47.60310213906424, 48.72711917332241, 49.54591573987688, 47.54966354370117, 48.80682890755789, 50.61354814256941, 56.160698073250906, 66.47128282274518, 63.08177089691162, 65.41670608520508, 59.30840573992048, 49.84823880876814, 46.30416073117937, 47.760169642312185, 43.980578899383545, 49.328940868377686, 59.294703892299104, 60.048583439418245, 63.96924345833914, 61.386931555611746, 58.06924663271223, 60.66162300109863, 58.53135395050049, 54.962290150778635, 47.33011436462402, 44.11446373803275, 43.758507524217876, 43.503077847617014, 47.46602112906319, 45.32451684134347, 41.67114707401821, 51.18878950391497, 54.190977573394775, 56.14074979509626, 53.279829025268555, 60.47864219120571, 54.64749506541661, 47.4752448626927, 59.8940555027553, 47.77593510491507, 49.68798555646624, 51.69750533785139, 53.23851503644671, 54.02997391564505, 52.02724599838257, 47.180623871939524, 44.73968696594238, 43.38753277914864, 42.90670354025704, 43.475208623068674, 43.055394990103586, 42.573947361537385, 43.75732980455671, 42.71540226255144, 43.792748246874126, 44.09807988575527, 43.31184605189732, 42.44087546212332, 42.86740452902657, 43.64221205030169, 45.344941071101594, 44.110353878566194, 45.84398848669869, 45.35206297465733, 46.89693587166922, 48.53706162316458, 49.39288166591099, 46.80486876623971, 50.03842142650059, 47.21025446483067, 48.5970002583095, 49.5812542779105, 58.92019598824637, 57.38834401539394, 61.39508179255894, 57.35545124326433, 52.826809951237266, 48.46103096008301, 52.59908969061715, 52.29871906552996, 56.387125968933105, 57.460883208683555, 63.02795015062605, 63.40476485661098, 67.0665419442313, 64.79085404532296, 69.52976867130825, 65.36983353751046, 66.85752623421806, 11.974052105631147, 0.7531468378646033, 1.792085894516536, 2.5255852895123616, 1.150884849684579, 0.1414343821150916, 0.1809247945036207, 23.943549667085918, 67.86288888113839, 32.69677734375, 40.36240870612008, 31.418895925794327, 18.613136632101877, 33.92963790893555, 58.11716488429478, 55.56010273524693, 61.854253496442524, 58.819169180733816, 56.16476624352591, 1.3394657990762164, 0.11168064190340893, 0.03895839343645743, 0.008668254329157727, 0.008045248071929174, 0.018082620675808618, 0.044941399712115526, 0.021810161282441447, 0.012883185791516942, 0.06643093284219503, 0.06682345177978277, 0.03281548020562955, 0.0781884655090315, 0.0640513715999467, 0.04279508827520268, 0.011452375112899711, 0.03221847116947174, 0.16167251685900347, 0.1465976129152945, 0.08602106664329767, 0.08028127785239901, 0.1620866267808846, 0.11254730075597763, 0.09855449731860842, 0.08092076996607439, 0.1379803538854633, 0.11638162072215762, 0.122877711430192, 0.15323694236576557, 0.2221348046192101, 0.22261302252965315, 0.2929729920412813, 5.088138035365513, 94.84959493364606, 82.5365185056414, 84.13519477844238, 60.846702166966026, 38.92192554473877, 31.74451630456107, 75.52131148747036, 55.11877400534493, 50.85733263833182, 29.916754450116837, 0.5912204810551235, 0.16828546486794949, 2.22027536375182, 2.9118512826306477, 5.23956664119448, 6.372312784194946, 5.092713858400073, 1.0585178860596247, 51.264771529606406, 89.45703547341483, 77.58702482495988, 77.75055067879813, 66.86311953408378, 60.88714068276541, 58.663175174168174, 57.127376624516074, 57.36044004985264, 55.47845792770386, 56.74011182785034, 56.736401489802766, 52.13309832981655, 50.95784527914864, 53.68607977458409, 53.80895519256592, 50.205779211861746, 49.093713079180034, 50.46117067337036, 51.08933646338326, 49.85735831941877, 52.97848565237862, 54.63476596559797, 59.62142903464181, 69.69551100049699, 64.683990750994, 69.63631234850202, 62.2363349369594, 51.30079793930054, 49.01746007374355, 49.85992220469883, 46.081825324467246, 51.465883663722444, 63.27636909484863, 61.56356866019112, 65.79771750313895, 64.36751420157296, 61.5712742124285, 64.24298858642578, 62.52861091068813, 58.7064277103969, 49.57229457582746, 45.10178886141096, 45.97370788029262, 45.65074866158621, 49.83714253561837, 48.11344732557024, 45.041072028023855, 54.40511063167027, 59.25140271868025, 57.50559139251709, 56.63153232846941, 63.71950435638428, 57.864441531045095, 50.49129111426217, 64.52824687957764, 51.41179888589041, 52.10002490452358, 54.4764860016959, 55.34327030181885, 56.819717339106965, 55.833354541233604, 51.22482633590698, 48.083907059260774, 46.63159111567906, 45.57472842080252, 46.24642814908709, 46.71466030393328, 44.47288308824812, 47.42232043402535, 46.24100508008684, 46.333798272269114, 46.74168879645211, 46.227251120976035, 45.586710589272634, 44.63682583400181, 47.900005613054546, 47.635810783931184, 46.09145552771432, 50.21106679098946, 47.126146520887104, 49.746329580034526, 52.76369251523699, 51.134204455784385, 50.039932659694124, 52.40919542312622, 48.763885566166465, 49.78076137815203, 53.36580603463309, 61.96445887429373, 60.747342927115305, 63.08145127977644, 60.17668737683977, 54.98503507886614, 51.1732429095677, 56.223037311008994, 56.45189707619803, 57.85586397988455, 60.37328665597098, 64.99186543055943, 66.74561159951347, 68.14686870574951, 67.1483291898455, 73.84758077348981, 66.90571199144635, 71.10279914311, 12.614610876355853, 1.4316484183073044, 3.7715877209390913, 4.72117109809603, 0.975466176867485, 0.274256092097078, 0.23341767489910126, 30.61852945600237, 74.56497532980782, 42.89898756572178, 76.77540574754987, 59.93359770093645, 20.588469539369854, 36.93251385007586, 65.42890017373222, 65.3648099899292, 69.22953701019287, 69.03704411642892, 61.63213348388672, 1.1643343908446175, 0.24156815611890384, 0.17036588037652628, 0.0653562012261578, 0.12056126073002815, 0.09846687130630016, 0.11216383347553865, 0.15694506838917732, 0.11008373009307043, 0.12806314389620507, 0.1916553508490324, 0.09341116795050246, 0.11789889287735734, 0.18918998885367597, 0.27378141613943235, 0.07084544096142054, 0.14665972601090158], [0.07074062087173973, 0.05574938029583011, 0.0663589063499655, 0.04002937614651663, 0.055538196449301074, 0.05101467828665461, 0.09783814754337072, 0.0335965656143214, 0.0738928367250732, 0.04112388027299728, 0.012911243214538055, 0.09479410374271018, 0.04582506265225155, 0.08403394291443483, 0.14277452948902333, 22.881885766983032, 78.94187491280692, 62.761987004961284, 67.49480806078229, 41.80579621451241, 20.168157373155864, 27.623176676886423, 54.9735358101981, 39.601375988551546, 45.63668550763811, 11.965299112456185, 0.043041844320084365, 0.32308805893574444, 0.8102371458496366, 0.7136158219405583, 1.9468459444386619, 1.3943891376256943, 2.276096974100385, 10.507290857178823, 82.14039475577218, 68.40540422712053, 74.52136843545097, 62.022455487932476, 57.03286722728184, 53.31951713562012, 52.95507369722639, 47.75815119062151, 48.442642552512034, 45.95159176417759, 47.75581659589495, 47.50332600729806, 49.81678778784615, 44.376066889081685, 45.947846685137065, 47.5059871673584, 46.78439589909145, 46.24492733819144, 46.7731328691755, 45.734616892678396, 46.38519409724644, 47.18872199739729, 49.33433961868286, 54.21862098148891, 60.860278947012766, 60.43843991415841, 60.745182037353516, 53.000261306762695, 45.554220812661306, 44.411902223314556, 44.69271714346749, 42.71088245936802, 53.54978391102382, 59.11095183236258, 60.456428800310405, 56.42814465931484, 49.86141259329659, 53.19498804637364, 57.601921217782156, 54.325102124895366, 49.71404824938093, 45.668140002659385, 44.13644436427525, 41.37776633671352, 50.00468444824219, 50.644328662327354, 46.62470545087542, 41.31049735205514, 43.168046133858816, 45.55564866747175, 47.03739023208618, 48.36950581414359, 56.49495158876692, 51.504029273986816, 47.033457551683696, 57.18880912235805, 45.54643188204084, 46.78642129898071, 52.31196233204433, 52.86737353461129, 47.57858542033604, 44.61160734721592, 41.04779291152954, 42.17128883089338, 40.59889759336199, 42.55325910023281, 41.4605575970241, 41.55535534449986, 41.41039160319737, 41.67936331885201, 41.24936710085188, 41.664504596165244, 41.35010208402361, 42.499188218797954, 40.801395893096924, 40.62302868706839, 40.787204197474885, 40.747717584882466, 41.09072930472237, 44.00806597300938, 43.092696394239155, 42.83055823189871, 42.98302950177874, 44.35548979895455, 44.679713589804514, 44.536063058035715, 47.43270799091884, 44.878623144967214, 47.44947052001953, 56.659877504621235, 58.43166814531599, 56.07449524743216, 53.242784704480854, 50.26914330891201, 50.90643903187343, 49.2643712588719, 50.72231871741158, 55.804297174726216, 58.787672996520996, 61.390627997262136, 60.999256815229145, 62.20388684953962, 60.01792103903634, 62.73128291538784, 63.34305790492466, 62.23751613071987, 16.626818622861588, 0.5370541161724499, 1.2057772470372063, 1.1826091302292687, 0.4614181433405195, 0.15034706172134193, 0.039477886632084846, 1.8391178165163313, 61.77750369480678, 41.13025413240705, 29.284068856920513, 46.74211611066546, 29.66280821391514, 16.800662551607402, 33.33197471073696, 45.16643837520054, 55.419269698006765, 48.74682426452637, 60.80281734466553, 25.37332739148821, 0.3142879211476871, 0.028290547297469208, 0.019970512050869207, 0.0928194582728403, 0.01664081179270787, 0.07465339984212603, 0.026663215065907155, 0.009457791739675616, 0.0701939252072147, 0.03596517190869365, 0.08215834320123706, 0.028584139222013097, 0.10101221900965486, 0.005752056704035827, 0.019571696308308413, 0.04482422010707004, 0.06432128604501486, 0.019444119850439683, 0.016569245007953474, 0.053361401826675446, 0.033384767693600485, 0.04105193181229489, 0.11737157617296491, 0.06272389926016331, 0.05050002643838525, 0.07616257707455329, 0.030502493426735913, 0.07973414114011185, 0.07117887985493455, 0.1280204640435321, 0.3085415709231581, 32.21058756964547, 89.99902970450265, 69.6437886101859, 75.37116091591972, 50.28224761145455, 26.766208444322857, 32.63754047666277, 52.65536315100533, 36.58904702322823, 50.34542063304356, 10.22733577660152, 0.09143804918442454, 0.284436722951276, 1.630768699305398, 1.93034570983478, 4.590711721352168, 2.4988143146038055, 0.9562189068113054, 11.79417540345873, 87.1638103212629, 71.26906258719308, 77.99643353053501, 63.414276940482004, 59.60225200653076, 56.83783476693289, 56.8213849067688, 51.39587708881923, 53.486440658569336, 50.09668207168579, 50.77753952571324, 48.099686418260845, 52.331618785858154, 47.65944160733904, 50.08362640653338, 50.03283160073416, 48.32191065379551, 48.25046232768467, 49.15227944510323, 47.785370758601594, 48.52051101412092, 47.822717326028005, 50.38097109113421, 56.83939463751656, 64.26115117754254, 62.575573784964426, 63.435816356113975, 54.06999553952898, 45.926442759377615, 46.813717297145296, 46.82230874470302, 45.29732159205845, 55.95243624278477, 60.77926989964077, 60.807215554373606, 58.18882165636335, 54.0373146874564, 55.18132168906075, 59.47976916176932, 56.16477319172451, 51.5841281073434, 47.14072036743164, 46.3079822404044, 43.36232124056135, 52.06399154663086, 53.91090611049107, 50.17759037017822, 45.09582035882132, 45.38382319041661, 48.757944856371196, 49.29923731940133, 51.199291706085205, 58.29487895965576, 54.101700169699534, 50.5324661391122, 59.57258319854736, 48.69081483568464, 51.18877560751778, 53.57165684018816, 55.22137457983834, 51.197207246507915, 48.036402225494385, 42.96797622953142, 44.57931212016514, 43.75689901624407, 44.802863461630686, 43.704586029052734, 44.47568321228027, 43.61149059023176, 44.41231911523001, 42.908259936741416, 42.20443868637085, 44.75725201198033, 45.0323485646929, 43.76322882516043, 42.63803059714181, 43.37970910753523, 43.17311831883022, 43.270990644182476, 45.51317432948521, 43.203752926417756, 45.7771954536438, 43.93347358703613, 46.07283435549055, 46.57520995821272, 46.9646634374346, 47.34592499051775, 46.15784209115164, 48.9733807018825, 59.81884820120675, 60.03233855111258, 59.30376434326172, 56.42745678765433, 52.38225378308977, 52.54218047005789, 51.41797236033848, 53.35800320761544, 58.39406449454171, 59.78682395390102, 63.11671338762556, 63.59894616263253, 63.90153326307024, 62.25433077130999, 65.65324360983712, 63.27884265354702, 65.60682964324951, 19.75832482746669, 0.2595185829060418, 0.6417845306651933, 2.6740782814366475, 2.3005700494561876, 0.41755934964333263, 0.04479217629081436, 1.1410372981003352, 62.50390311649868, 49.56503370829991, 32.551559993198936, 41.19157198497227, 28.95651340484619, 27.270791837147303, 47.49527651923043, 54.882455348968506, 61.774126870291575, 55.72015101569039, 68.94350746699742, 39.300550256456646, 0.271433983530317, 0.06762782790298973, 0.06154197946723018, 0.1101894797757268, 0.021908740546288233, 0.024299299144851308, 0.026703698161457266, 0.04684864629858306, 0.08086932344096047, 0.0375421280041337, 0.03559741610661149, 0.017776682806600417, 0.0809384933007615, 0.007642261883510011, 0.07843812568379299, 0.03502698867980923, 0.17665112311286585, 0.14872297458350658, 0.13069556121315273, 0.16796203436596052, 0.14058823537613663, 0.15865038973944529, 0.18532185070216656, 0.20650048926472664, 0.1507830069001232, 0.11540011981768267, 0.12278559351606028, 0.23016670505915368, 0.1678622897182192, 0.18128843499081476, 0.43284948489495684, 36.33824832098824, 103.40215342385429, 78.54743957519531, 85.41517802647182, 56.8819488797869, 32.26149354662214, 44.70742300578526, 76.31158569880894, 56.918736117226736, 64.87830407278878, 15.695174625941686, 0.2342316455074719, 0.9906258434057236, 4.068109912531717, 3.3239161542483737, 5.619587072304316, 6.6069417255265375, 5.132012869630541, 11.922738790512085, 91.09509413582938, 74.68931334359306, 81.30288669041225, 66.73750305175781, 63.10436643872942, 58.61947100503104, 59.72549220493862, 54.44322497504098, 54.740750312805176, 53.261204378945486, 55.75506223951067, 52.856249468667166, 55.544973032815115, 50.880911350250244, 52.222448689596995, 54.266070229666575, 50.557215622493196, 51.340927260262625, 51.025114263807026, 51.04975952420916, 51.98910386221749, 52.040715081351145, 53.96216644559588, 59.011363301958355, 67.99405002593994, 65.68911021096366, 66.15172127314976, 56.47362061909267, 48.73453637531826, 50.03038930892944, 49.77853100640433, 49.466650690351216, 58.38608796255929, 63.41356127602713, 65.18254484449113, 60.954774447849815, 55.25672006607056, 57.46664326531546, 62.70116247449602, 59.23080130985805, 54.65507902417864, 51.126505851745605, 48.198559284210205, 46.584923539842876, 54.93192999703543, 56.20578145980835, 52.35572208677019, 47.464402198791504, 48.86939743586949, 51.757708004542756, 52.93106072289603, 55.31687756947109, 63.448191097804475, 57.920378003801616, 54.07317434038435, 64.15788010188511, 51.65047298158918, 51.91748183114188, 58.772810799734934, 59.900628498622346, 54.37317671094622, 50.40975052969796, 46.595616817474365, 47.237536566598074, 46.85424266542707, 45.70828669411795, 46.05609267098563, 46.91942719050816, 47.07924618039812, 46.666832378932405, 43.97606604439871, 45.55774702344622, 46.13864074434553, 47.72275011880057, 45.58770765577044, 45.91626712254116, 45.01651014600481, 46.04779999596732, 46.38065692356655, 48.70194237572806, 45.96746144975935, 47.69930689675467, 46.345974990299766, 48.91643674033028, 50.46368244716099, 49.28346490859985, 51.75694022859846, 48.17802735737392, 53.199170861925396, 62.43146814618792, 63.83713041033064, 62.0704744883946, 57.36301783152989, 55.002318722861155, 56.29422507967268, 54.90191725322178, 55.89867803028652, 62.10110214778355, 63.29725537981306, 68.108215876988, 65.72991003308977, 67.72920554024833, 64.9443119594029, 67.76002080099923, 66.23875440870012, 67.39239161355155, 22.31177912439619, 1.6254535445145197, 4.495801065649305, 5.367179862090519, 3.8960017306464056, 0.22862936183810234, 0.17486652173101902, 2.321199033941541, 75.19357885633195, 54.446646962847026, 43.991838455200195, 62.190407344273154, 44.1930513381958, 27.922086443219865, 49.78479133333479, 60.23367650168282, 70.29165949140275, 62.471607889447895, 80.57228360857282, 39.218280111040386, 0.5863052819456372, 0.2609759404190949, 0.2154687408890043, 0.1973802593669721, 0.1074574738740921, 0.1557872976575579, 0.1838795430958271, 0.1131158656041537, 0.1471287701278925, 0.09887433158499853, 0.13530565026615346, 0.06635746785572597, 0.18263061796980246, 0.07090207149407693, 0.19188549635665758, 0.18684195913374424], [0.022667208686470985, 0.015615791348474366, 0.03862615554992642, 0.021456926129758358, 0.03614820672997406, 0.047255994619003365, 0.0098421165187444, 0.0914252655846732, 0.04233539776344385, 0.09086350644273417, 0.021704874699935317, 0.03654531595696296, 0.03816472120316965, 0.04413005164159196, 0.14884899210716995, 55.12039640971592, 76.3375997543335, 65.63977800096784, 57.830061844417024, 34.93595245906285, 18.42367662702288, 27.550797292164393, 42.448254449026926, 32.73723670414516, 50.553776264190674, 3.9108118159430365, 0.014853959370936667, 0.04892149614170194, 1.2379482750381743, 0.7998925809349332, 2.3542553058692386, 2.0184638500213623, 0.1293817681393453, 46.94832474844796, 78.08574567522321, 69.23465088435582, 65.94848646436418, 57.064540590558735, 55.937563623700825, 52.71162618909563, 54.64224917548043, 50.32499292918614, 49.435814585004536, 47.27185371943882, 47.20319856916155, 46.85543775558472, 47.67594705309187, 47.213276931217735, 46.680159023829866, 47.0182375226702, 45.78621074131557, 47.17315803255354, 45.94863877977644, 46.43812200001308, 44.786121777125764, 44.161377974918906, 49.13271679197039, 53.786974566323416, 56.52094827379499, 57.84313488006592, 53.34464182172503, 46.87560837609427, 45.472120898110525, 44.8543461390904, 43.47223479407174, 46.24244335719517, 59.158720697675435, 59.40671580178397, 58.034974643162315, 56.90012189320156, 59.79220185961042, 55.890194279806956, 57.246899536677766, 54.473074436187744, 49.32294804709298, 46.83129971367972, 42.30503470557076, 49.91842951093401, 57.957894802093506, 58.15955931799752, 52.42583635875157, 44.040621757507324, 44.56440128598894, 43.25327621187483, 45.829793316977366, 47.09337534223284, 57.08932828903198, 51.40753616605486, 45.02405936377389, 57.25877053397042, 44.308912549700054, 48.28566884994507, 47.64905057634626, 47.54845108304705, 42.62208795547485, 40.32978343963623, 38.87469516481672, 40.42600209372384, 44.96787970406668, 48.61584724698748, 44.98186642783028, 42.92119748251778, 42.080666950770784, 42.528909138270784, 40.68830353873116, 42.12353386197771, 40.26096153259277, 42.11981310163225, 42.62763956614903, 41.71937799453735, 38.65749447686331, 40.644324915749685, 42.06818451200213, 43.10398721694946, 45.035798345293315, 43.964875970567974, 43.11872782026018, 44.440688610076904, 42.46117809840611, 44.2959645816258, 44.674224512917654, 46.27589545931135, 47.15345641544887, 56.633335386003765, 57.664878845214844, 56.04905441829136, 54.39599459511893, 52.43594946180071, 51.99145235334124, 52.222664083753315, 55.10721220288958, 58.85716193062918, 57.76690966742379, 57.823162283216206, 60.1111867087228, 60.876732281276155, 54.65787220001221, 56.595151560647146, 55.60422727039882, 64.66211782182965, 29.21801928111485, 0.1895862804459674, 0.857577231313501, 1.6945377460547855, 1.905109635421208, 0.1918355833206858, 0.04462607431092432, 0.06396900423403297, 17.95346597262791, 71.72184194837297, 28.79691502026149, 42.50826256615775, 42.02808993203299, 14.88053481919425, 13.136477044650487, 26.318713188171387, 45.29796082632882, 47.882666383470806, 53.89730153764997, 61.08303124564034, 4.822860590049198, 0.22228534439844744, 0.1291940582117864, 0.09795305744877883, 0.016578892079581107, 0.04366433573886752, 0.029065332508512905, 0.03988322988152504, 0.03968993900343776, 0.057989020831882954, 0.020877346961892078, 0.038946736204837046, 0.10236568602600268, 0.03893452596717647, 0.06803002953529358, 0.030765751443271126, 0.04394703717636211, 0.1114868251606822, 0.07692400871642999, 0.08130916341074876, 0.0711534076503345, 0.05449788352208478, 0.04370442019509418, 0.023546371243095825, 0.039151080418378115, 0.056095104065856764, 0.006382791475126786, 0.016145343825753247, 0.0032353796497253434, 0.00872091543195503, 0.31717237351196154, 66.40643528529576, 85.83818435668945, 71.11632033756801, 72.04128537859235, 44.73410756247384, 27.87659137589591, 28.33167232785906, 34.432287965502056, 40.705927644457134, 53.79471485955374, 3.6155251009123663, 0.0821259431540966, 0.6093554422259331, 1.6460563646895545, 2.847368525607245, 5.2420467138290405, 2.274978748389653, 0.44237964493887766, 51.18104921068464, 80.54834706442696, 72.36664172581264, 68.96983419145856, 59.05806214468819, 58.392973627362935, 56.795964922223774, 56.889178480420796, 54.14787442343575, 53.02299928665161, 51.219802788325715, 51.7356926373073, 50.20729391915457, 50.26813582011631, 49.44839429855347, 49.752503054482595, 50.70946455001831, 48.963903359004426, 50.330082484654014, 48.23845584051949, 47.07432338169643, 47.990429469517295, 47.84644889831543, 50.64338023321969, 57.19279391424996, 59.28105763026646, 58.650571141924175, 53.31639392035348, 48.897898946489605, 46.88487727301461, 47.07151978356497, 44.755775519779746, 46.95306689398629, 61.11186626979283, 61.55983052934919, 60.619760104588096, 59.41094030652727, 62.64557688576834, 59.89058835165841, 61.03765950884138, 56.002400738852366, 51.94732434409005, 48.45292936052595, 44.56939704077584, 52.84360722133091, 61.32659339904785, 60.53637477329799, 54.9776109286717, 47.702148709978374, 46.40320035389492, 44.51386703763689, 46.8307785987854, 49.88494266782488, 59.607880047389436, 52.90921211242676, 47.85617637634277, 59.880416188921245, 47.04466152191162, 50.21717425755092, 51.06441674913679, 48.71339995520455, 45.96555764334542, 43.64568962369646, 39.83380017961775, 44.222261565072195, 46.31659800665719, 51.470181124550955, 46.298418045043945, 43.98289959771292, 43.10615158081055, 45.28926862989153, 42.941145760672434, 44.86453914642334, 42.48276615142822, 44.43156909942627, 45.816028935568674, 43.843880040305, 40.79361738477434, 42.389771461486816, 44.59155832018171, 45.31100606918335, 46.700628416878835, 45.46247679846627, 44.66647727148873, 47.20936509541103, 43.875199045453755, 45.6436892918178, 46.68324749810355, 47.868217604500906, 48.98201731273106, 58.219369411468506, 59.570790563310894, 58.33540085383824, 56.77336243220738, 56.00372437068394, 53.46296616962978, 54.606014319828574, 57.25769356318882, 61.12469959259033, 58.73642308371407, 60.32152257646833, 62.75708852495466, 61.7369053704398, 55.77789054598127, 57.50556707382202, 55.02527904510498, 63.624883787972585, 33.93263258252825, 0.574704070176397, 0.763629606791905, 2.5328895832811082, 2.0913743376731873, 0.8585279945816312, 0.10128889166350875, 0.038368766861302514, 17.19263301576887, 79.79535688672746, 36.549285956791465, 39.107890605926514, 38.23151084354946, 22.216571433203562, 25.062937464032853, 37.21423898424421, 50.50089005061558, 54.80859252384731, 59.34961550576346, 69.74525315420968, 8.551103711128235, 0.11024614423513412, 0.0956328883767128, 0.06007721235177346, 0.007018555887043476, 0.0320081931671926, 0.05002998826759202, 0.08525983856192657, 0.028105892473831773, 0.013787309106971537, 0.03535331652632781, 0.01865161469738398, 0.02834519311519606, 0.03756529997502055, 0.007905651366205087, 0.07123639926846538, 0.13012762740254402, 0.22350327404482023, 0.14297363880489553, 0.13915674361799443, 0.13306770606764726, 0.1831023490854672, 0.11910901937101569, 0.14490892924368382, 0.14439921373767511, 0.1272938208920615, 0.12516873063785688, 0.06868026964366436, 0.12118800995605332, 0.11702038001801286, 0.49410523793527056, 77.09107630593437, 92.91444519587925, 81.14220264979771, 74.96149512699672, 51.57174641745431, 27.58570330483573, 40.99998583112444, 55.9643280846732, 50.560036591121126, 65.02135358537946, 5.3948745131492615, 0.12485151551663876, 0.28841657510825564, 3.251819040094103, 4.37040388584137, 7.150824998106275, 9.824275987488882, 1.513157844543457, 55.07745654242379, 79.11395399911063, 76.19116646902901, 71.01385525294712, 64.05211462293352, 63.094499996730256, 58.62020056588309, 60.389003481183735, 57.48246431350708, 55.327567373003276, 54.41513340813773, 54.57758229119437, 51.60160630089896, 52.46085180555071, 53.226449489593506, 52.228201798030305, 54.607355322156636, 51.441436426980154, 52.86250284739903, 52.503611019679475, 51.17134952545166, 50.40942396436419, 51.094356536865234, 53.332343510219026, 59.18759046282087, 60.099298340933665, 62.19079644339425, 57.29212188720703, 50.319118227277485, 49.64557375226702, 48.53245496749878, 47.58860124860491, 50.566564423697336, 64.32508155277797, 62.872574533735005, 63.569993019104004, 61.517675808497835, 65.22192028590611, 62.64958599635533, 61.10797527858189, 59.34040914263044, 54.59368126732962, 51.82472685405186, 46.49074765614101, 55.94483143942696, 62.843649183000835, 62.74409539358956, 57.800934995923726, 49.97128793171474, 48.90961708341326, 47.02443878991263, 50.46647562299456, 52.5769944190979, 61.78367369515555, 56.35388926097325, 50.30146632875715, 62.812222480773926, 50.113639150347026, 52.554325921194895, 53.572157110486714, 52.55188362939017, 47.840226786477224, 45.80866731916155, 42.74056168964931, 46.766810008457725, 49.47112880434309, 54.2345358303615, 48.40892989294869, 47.654386792864116, 46.868941579546245, 47.81700938088553, 45.40191282544817, 47.092350482940674, 44.99554395675659, 48.14785827909197, 49.745301246643066, 46.14460577283587, 42.32171385628836, 45.477092334202354, 49.18897983006069, 47.263244901384624, 50.69366782052176, 46.76702887671334, 47.82013954435076, 49.24820280075073, 46.66261829648699, 48.42850644247872, 48.69664437430245, 51.123820372990195, 52.34955208642142, 60.12896714891706, 63.57185513632638, 62.57831137520926, 59.007771083286826, 60.31834030151367, 57.5124249458313, 58.39182717459542, 59.375921385628835, 65.70863464900425, 62.83982072557722, 64.21249989100865, 66.99216147831508, 64.05187838418144, 55.76459864207676, 59.41559559958321, 59.47039604187012, 64.25497422899518, 39.77927071707589, 0.931807279586792, 4.488736918994358, 6.189676344394684, 6.433560286249433, 1.4899447815758842, 0.19806171208620071, 0.2000938430428505, 24.03190122331892, 87.08569867270333, 42.00820766176496, 57.632594040461946, 55.71140670776367, 23.192718642098562, 20.858750990458898, 40.56311089651925, 58.3263612474714, 64.86066954476493, 65.68705354418073, 80.54861109597343, 9.745801295552935, 0.3279333146555083, 0.2334196019385542, 0.14657272425081047, 0.1359775085002184, 0.19002833243991646, 0.13150326215795108, 0.1344402874154704, 0.10624464681105954, 0.10878845423992191, 0.1351420283317566, 0.1510586549660989, 0.2686937605696065, 0.15781030910355703, 0.11979987658560276, 0.1004312980387892], [0.01916494849137962, 0.002184156939620152, 0.027101389232224653, 0.052506613944258006, 0.06352737971714564, 0.01070153370632657, 0.1214497751955475, 0.004724696586241147, 0.054538093507289886, 0.0397333448885807, 0.03640975823093738, 0.009043079617965435, 0.07955410544361387, 0.12892212851771287, 3.9044446604592458, 66.36715017046247, 63.49329880305699, 59.967421531677246, 24.9255142552512, 62.08769907270159, 23.977594103131974, 52.914364201681956, 49.806302956172395, 44.44013275418963, 40.40498379298619, 0.41184380490865025, 0.5627143563968795, 0.3729132381933076, 0.8865296148828098, 1.0633683800697327, 5.606715968676975, 4.109487303665706, 5.203905880451202, 67.41587652478898, 73.13698850359235, 68.1491824558803, 57.83477619716099, 58.862164633614675, 61.61502007075718, 63.35155555180141, 62.433378900800435, 60.51778834206717, 61.458463260105674, 57.32509803771973, 54.838257857731406, 52.40368550164359, 50.72320808683123, 46.04992267063686, 46.680544648851665, 47.14796386446272, 45.60161794934954, 49.78624350684029, 46.98748826980591, 46.05187511444092, 45.7201646396092, 45.97694574083601, 46.90799740382603, 51.63797664642334, 54.28845385142735, 50.91573919568743, 46.60387475149972, 45.40129096167428, 43.54417296818325, 43.042367117745535, 43.89559895651681, 45.411477020808626, 55.92488316127232, 57.677767753601074, 59.71476418631417, 60.20996229989188, 57.93583427156721, 55.50520501817976, 56.12969173703875, 54.50651959010533, 49.867829254695344, 42.467521803719656, 43.96111352103097, 54.84249973297119, 55.65403195789882, 56.54211943490164, 55.730496883392334, 49.67567334856306, 47.90031828199114, 45.882339068821494, 49.80677195957729, 49.00452947616577, 58.877985681806294, 50.501348631722585, 43.45941884177071, 58.14218534742083, 45.02364247185843, 45.94166626249041, 45.031143052237375, 45.11108555112566, 38.91688462666103, 39.934830461229595, 39.68073831285749, 42.813555989946636, 45.99099152428763, 50.33597108295986, 49.978100640433176, 46.89029686791556, 40.307396343776155, 42.16379519871303, 40.43286343983242, 41.00812564577375, 41.06428793498448, 43.73530401502337, 44.82974604197911, 44.47459234510149, 41.77444594247, 37.7465752192906, 38.591288566589355, 40.20437887736729, 43.8999137878418, 42.5365104675293, 43.99444055557251, 44.198714120047434, 43.2416101864406, 44.49412720543997, 45.11565399169922, 45.78423397881644, 47.4053008215768, 56.44885376521519, 57.957731519426616, 56.04445818492344, 54.03143651144845, 50.749180453164236, 52.48996128354754, 52.892578125, 55.23713309424264, 56.65461424418858, 54.67911284310477, 56.60691138676235, 61.86867100851876, 62.075442450387136, 57.82583039147513, 56.91925375802176, 57.472101075308665, 55.02441052028111, 43.75952890941075, 2.1543297937938144, 0.24911788957459585, 2.0472311292375838, 2.267668809209551, 1.66832349555833, 0.11800999620131084, 0.02092106666948114, 2.170425078698567, 53.00991235460554, 56.4715952192034, 33.23057964869908, 41.043714318956646, 30.349005358559744, 11.835297448294503, 24.710391078676494, 35.60110698427473, 45.16594852719988, 49.162788595472065, 54.56827865328108, 24.140859399523052, 0.3334615294422422, 0.028159147294770395, 0.03472496256498354, 0.008929786322239255, 0.03896975889801979, 0.07422117982059717, 0.04413028573617339, 0.048347167138542445, 0.02914972190878221, 0.028216050937771797, 0.070170977152884, 0.06179907638579607, 0.021328387848500694, 0.03751909174025059, 0.008249476934517068, 0.034870840808642764, 0.03393558206568871, 0.03698611944647772, 0.06379888193415743, 0.046789257521075864, 0.03060382923909596, 0.05702045280486345, 0.02825968582848353, 0.01143151440192014, 0.044500229813690693, 0.05737931640552623, 0.02968749144513692, 0.09283598060054438, 0.2387522357915129, 6.92418474810464, 80.7771303994315, 72.31489849090576, 68.12785148620605, 32.86735561915806, 63.94540418897356, 21.22646529333932, 31.98101908820016, 47.175204277038574, 53.39045129503523, 43.56706033434187, 0.5715407942022596, 1.65917760346617, 4.915203017847879, 1.2092524319887161, 4.237288125923701, 10.984069296291896, 3.0542876166956763, 6.809782224042075, 75.68456636156354, 73.39070892333984, 72.28761986323765, 60.64769186292376, 60.98592322213309, 64.93579346793038, 68.22825295584542, 64.60173797607422, 64.71118600027901, 64.7373320715768, 61.09949152810233, 59.0465281350272, 54.791770935058594, 53.790087359292166, 50.12233134678432, 48.79962362561907, 50.50651114327567, 49.23372275488717, 52.68196432931082, 49.84036997386387, 49.99949761799404, 47.5374242918832, 48.4624970299857, 48.2751909664699, 55.33862543106079, 55.822088037218364, 53.73965733391898, 48.42864540645054, 49.17646612439837, 46.33376700537545, 44.93738406045096, 45.12146268572126, 47.669700622558594, 59.28593526567732, 60.371862275259836, 62.03562927246094, 61.033539227076936, 58.85570280892508, 57.652695178985596, 58.06725944791521, 56.23288638251168, 51.94479867390224, 45.51250382832119, 44.91017838886806, 55.94097866330828, 58.079008851732524, 59.66857951028006, 57.84403814588274, 52.24137558255877, 50.61305482046944, 49.98761967250279, 53.2113892691476, 51.801096030644004, 61.323063714163645, 52.183149678366526, 46.797416823250906, 62.427007402692524, 48.00269651412964, 48.49862766265869, 48.14900473185948, 47.419537680489675, 41.102360589163645, 42.46477379117693, 41.90131657464163, 45.02870423453194, 49.28560495376587, 53.436052322387695, 51.64206566129412, 48.626220907483784, 40.763493469783235, 43.173243386404856, 42.448021684374126, 43.98451852798462, 43.41643728528704, 46.489215578351704, 46.56518718174526, 46.52538442611694, 43.52840403148106, 42.179602350507466, 42.01480150222778, 42.701811586107524, 44.71447195325579, 44.85423844201224, 45.525399684906006, 45.18170009340559, 45.51984460013253, 46.011346272059846, 46.04053912843977, 48.02456944329398, 49.72564479282924, 59.99016298566546, 61.69214507511684, 57.94733354023525, 56.62949650628226, 54.22524956294468, 55.41783489499773, 55.700741222926546, 58.57390471867153, 59.639779227120535, 56.92043842588152, 58.95219244275774, 62.96033028193882, 63.2067550931658, 59.7257353918893, 58.57484967367989, 61.076388767787385, 55.395833424159456, 46.025986126491, 5.820629724434443, 0.3424958703773362, 1.6593874607767378, 3.3918977635247365, 2.5549653129918233, 0.7494717836380005, 0.026941288894574558, 1.5648469052144458, 54.80235998971121, 64.21557099478585, 36.855593817574636, 36.26069252831595, 18.157777752195084, 7.1711554271834235, 29.814817428588867, 44.33255379540579, 52.505309854234966, 54.86210754939488, 62.21216215406145, 37.143631390162874, 0.4998036293046815, 0.06737349262194973, 0.027274320667077388, 0.0069083185434075335, 0.08352295176259109, 0.028579124848225286, 0.021167843070413386, 0.010043275010372912, 0.012430306075007787, 0.03411538027493017, 0.016441520968718187, 0.022510606196842024, 0.040354896536363025, 0.07621794553207499, 0.019300940479817133, 0.1584306936711073, 0.1240014061331749, 0.13727986147361143, 0.15455734437065466, 0.18272981978952885, 0.09489506296813488, 0.2102966077093567, 0.10862528692398753, 0.18080392027539866, 0.10061028200600829, 0.14141475888235228, 0.10481214403573956, 0.29823646960513933, 0.34214083371417864, 8.00341282572065, 92.46438258034843, 81.37302875518799, 78.85331317356655, 36.40851197923933, 71.55940001351493, 32.55844913210188, 70.68828351157052, 72.15247740064348, 60.345757893153596, 51.39237172263009, 0.5172797058309827, 1.1518478265830447, 2.9511976284640173, 3.6136160833495, 6.6945116094180515, 17.29807366643633, 8.9498564856393, 7.089762057576861, 81.86638559613908, 76.13298920222691, 76.6869968686785, 62.73118564060756, 66.61775084904262, 65.8882177897862, 72.73640401022774, 67.04896300179618, 67.58215386526925, 67.49451623644147, 63.507146562848774, 60.7043822152274, 58.611827986580984, 56.56731012889317, 51.31772027696882, 51.48225014550345, 53.65405205317906, 51.182473591395784, 56.33958639417376, 52.11032213483538, 51.934508391789024, 49.94899811063494, 51.27421065739223, 50.86310659136091, 58.62177085876465, 60.56829479762486, 56.98543882369995, 51.3469409261431, 51.07735429491316, 47.40007925033569, 47.24523169653756, 48.92538602011544, 51.76333257130214, 62.68297903878348, 63.46189989362444, 63.05128220149449, 65.20644664764404, 62.749244008745464, 59.68934072766985, 59.72546441214425, 59.81253923688616, 54.178585461207796, 48.06561245237078, 47.80439840044294, 60.670481954302105, 59.72194167545864, 61.32447419847761, 60.470158440726145, 54.97357749938965, 53.238608837127686, 53.93895598820278, 53.77510356903076, 54.22319984436035, 65.2130126953125, 55.19332470212664, 49.44684485026768, 64.80743939535958, 51.01458774294172, 50.71602017538888, 51.442141669137136, 51.047810554504395, 44.59377479553223, 45.0634000641959, 43.802343709128245, 49.46659857886178, 52.24723291397095, 55.161345618111746, 55.75294998713902, 52.568034717014854, 42.986844062805176, 46.4543981552124, 45.09624072483608, 45.579456669943674, 45.654514585222515, 49.719103063855854, 49.843340328761506, 50.17110422679356, 48.025365012032644, 44.164532457079204, 43.683432238442556, 46.2298150062561, 48.92033120564052, 46.61313322612217, 46.9077125276838, 49.086129120418, 48.0848902293614, 49.175826890128, 50.78044387272426, 50.51930625098092, 52.621539320264546, 64.04987730298723, 64.3952305657523, 60.873035839625764, 59.418263707842144, 57.26898091179984, 58.18787670135498, 58.35348701477051, 61.4121743610927, 60.21830013820103, 59.818598066057476, 60.76251779283796, 66.1217953818185, 64.34377915518624, 62.927583421979634, 60.712046078273225, 65.21761240277971, 57.45913226263863, 50.78017636707851, 7.755620956420898, 1.9253649371010917, 7.24608393226351, 6.547368739332471, 5.217247724533081, 0.7111535540648869, 0.1691266040184668, 2.880668201616832, 63.61123752593994, 68.72486850193569, 48.07422821862357, 52.20817361559187, 39.88753407342093, 17.64029676573617, 35.59209517070225, 47.127018519810264, 60.52049813951765, 62.954528536115376, 72.38144138881138, 42.454125676836284, 0.7990076084222112, 0.14104240600551876, 0.1747000635202442, 0.1532410814293793, 0.19532907514699868, 0.18240735280726636, 0.16160901955195836, 0.1269567518361977, 0.10535531131816761, 0.1642144854579653, 0.1293894084436553, 0.09550182255251066, 0.1428756990603038, 0.22827120391385897, 0.06661025607692343], [0.02609692670271865, 0.050077268587691445, 0.08703056390264205, 0.035117315261491706, 0.032616761047393084, 0.0275359230581671, 0.022382692167801515, 0.031094742539737905, 0.07443233991840056, 0.05240720856402602, 0.016927930493173853, 0.041064566134342124, 0.290227720780032, 0.12702123980437005, 15.615779297692434, 79.37676961081368, 64.08888448987688, 74.3452593939645, 61.975548199244905, 88.64279692513603, 57.77132872172764, 57.34586272920881, 28.59255460330418, 66.16789667946952, 15.733410562787737, 0.11744390800595284, 0.645166349198137, 5.019536733627319, 0.44479104982955114, 2.256647663457053, 8.937371441296168, 2.3061566182545254, 40.855574471609934, 74.27588163103376, 66.99624701908657, 65.7021380833217, 57.82324913569859, 65.46466255187988, 63.099051066807334, 68.02348954336983, 67.76538481031145, 68.22891998291016, 63.461997168404714, 64.30466774531773, 62.47808361053467, 62.565693446568076, 55.92187806538173, 53.517429624285015, 47.277016230991904, 47.21626465661185, 46.97821937288557, 47.081959451947895, 48.20298528671265, 46.83295338494437, 46.39807953153338, 45.74841948917934, 43.66385568891253, 47.88286788122994, 49.81432465144566, 47.80337701525007, 47.68758528573172, 44.31687865938459, 44.425485951559885, 44.79722499847412, 43.33980907712664, 45.392293044498985, 48.77004167011806, 55.7631117275783, 55.762027808598106, 56.05752427237374, 59.621026039123535, 56.871332032339915, 58.09454154968262, 54.22852911267962, 49.83187232698713, 46.741032191685264, 47.16197143282209, 51.832679067339214, 56.94864463806152, 55.76118360246931, 55.21179996218, 54.35468408039638, 56.09587485449654, 54.97146872111729, 54.33713640485491, 50.50781740461077, 58.318746021815706, 45.77613237925938, 43.41358157566616, 58.81025464194161, 45.28093773978097, 44.96270677021572, 41.243155411311555, 40.12088584899902, 39.22757680075509, 41.83122314725603, 41.51526771272932, 40.9293087550572, 45.8042482648577, 51.031072344098774, 50.81439277103969, 47.34589719772339, 41.609804902757915, 39.59935753686087, 40.00282205854143, 38.970285006931846, 40.874741077423096, 43.4303753716605, 43.331377438136506, 43.619769368852886, 41.35212400981358, 40.56666490009853, 40.29350689479283, 39.54107257298061, 43.37269837515694, 42.69116694586617, 42.68094267163958, 43.98051636559622, 42.983376911708284, 43.18284927095686, 43.489504541669575, 43.50242819104876, 47.04026331220354, 58.14329705919538, 55.660736969539094, 58.35145814078194, 53.99174492699759, 54.551401478903635, 57.04918507167271, 55.631172384534565, 58.478860310145784, 60.81610230037144, 57.19191149302891, 59.316569873264854, 60.093107495989116, 58.42099571228027, 58.556013107299805, 61.50726740700858, 58.798880440848215, 57.67170197623116, 58.100850514003206, 18.4085590839386, 0.7246485842125756, 1.0064970489059175, 1.0275315259184157, 1.0073909780808856, 0.7227574799742017, 0.13523528618471964, 0.11682473123073578, 19.51456986154829, 66.9922240121024, 44.38326174872262, 33.687291690281455, 59.590995924813406, 46.58425998687744, 14.083140441349574, 21.164697544915335, 30.053821563720703, 48.539156505039756, 51.208327838352744, 54.98313127245222, 3.408768641097205, 0.12567702122032642, 0.0199719963462225, 0.04706797256533589, 0.04899757688066789, 0.009019700693897903, 0.03140927066228219, 0.028615233089242662, 0.014985047247526901, 0.03399027877354196, 0.03617508350206273, 0.018816368088924458, 0.030926591384091547, 0.043235413397529295, 0.060861666686832905, 0.014901331293263605, 0.005547982632249061, 0.027585306836824332, 0.04158745539773788, 0.04259392978357417, 0.02414268478085952, 0.01268601878213563, 0.012029150234801429, 0.03417162064995084, 0.04054248093494347, 0.031599555630236864, 0.05855547543615103, 0.2915150917002133, 0.20882319605776242, 21.471896512167795, 91.16308920724052, 68.44491168430874, 83.14466653551374, 60.413252694266184, 101.73435647147042, 49.35829700742449, 48.596336705344065, 35.67626217433384, 73.04345185416085, 17.097053595951625, 0.30904303544334, 5.073336201054709, 6.829124271869659, 3.0051425737994055, 2.7987658764634813, 6.978352904319763, 2.836239899907793, 44.862166336604524, 79.68105207170758, 69.6300242287772, 67.87807764325822, 59.11223030090332, 68.43398216792515, 66.52691010066441, 71.00829669407436, 69.59233719961983, 71.65312426430839, 64.4652406147548, 67.87852927616665, 67.01312419346401, 65.48634093148368, 60.102563994271414, 54.54755565098354, 50.09783199855259, 50.16060202462332, 48.596256801060264, 49.79606825964791, 51.63414124080113, 48.37332732336861, 48.4387446131025, 46.78664711543492, 45.64902203423636, 50.229076521737234, 51.92144577843802, 50.18100888388497, 47.40186146327427, 46.00740316935948, 46.28740167617798, 45.758636815207346, 44.59148188999721, 46.79505443572998, 49.729667799813406, 57.339056968688965, 56.50182335717337, 58.833711760384695, 61.70705590929304, 58.91445677621024, 57.45803097316197, 54.588386740003315, 52.13709701810564, 48.92913457325527, 49.32303837367466, 53.7841466494969, 60.629536220005576, 56.91062756947109, 58.17629405430385, 57.057328360421316, 58.16166809626988, 58.80926104954311, 57.71505526133946, 54.00685378483364, 60.87898349761963, 48.898663248334614, 45.59563902446202, 60.964835439409526, 47.266976084027974, 47.79998629433768, 44.98542390550886, 42.33461666107178, 40.98258406775338, 44.732631070273264, 43.31174182891846, 44.04026739937918, 46.82204818725586, 55.109842096056255, 53.6869170325143, 50.886494227818076, 43.119526863098145, 43.010940415518625, 40.95460367202759, 42.18540409633091, 42.58685711451939, 45.76254170281546, 47.39719922201974, 47.540415491376606, 43.63539239338466, 41.91418463843209, 42.90449053900582, 42.40093721662249, 42.58957038606916, 44.12262787137713, 44.513005461011616, 45.68003184454781, 44.32055425643921, 45.96045766557966, 46.280425684792654, 46.23152078901018, 49.608585017068044, 60.10711506434849, 57.520609923771445, 60.220877919878276, 56.04215138299124, 59.19566426958357, 59.145505223955425, 58.99769619532994, 60.90431662968227, 64.1372161592756, 58.6194293158395, 62.4473169871739, 63.33060673304966, 61.52322047097342, 61.332923207964214, 65.09953471592495, 61.34901523590088, 62.075393812997, 60.493205615452354, 24.983726263046265, 0.7803886075104985, 0.8264615152563367, 1.898797414132527, 2.757874859230859, 1.669652772801263, 0.20483849916074956, 0.15204335855586187, 17.99274935041155, 72.87037917545864, 50.0911408833095, 31.939871856144496, 43.70424904142107, 33.369324752262656, 16.337276765278407, 37.42915718896048, 38.83419758932931, 55.536475385938374, 57.57707098552159, 70.62337344033378, 6.401257242475237, 0.17424122456993374, 0.12226485860134874, 0.0241285627707839, 0.062152769549616745, 0.027078254580763832, 0.03579028629298721, 0.019530037650838494, 0.017122505498783927, 0.030924006165670495, 0.046029132059110064, 0.021144803413855176, 0.054447970486113, 0.014709821569600275, 0.01192988480241703, 0.14154305628367833, 0.11403048331184046, 0.10317848955414125, 0.09148669335991144, 0.09486371465027332, 0.11205690992730004, 0.15247004851698875, 0.1772776280662843, 0.17688882750059876, 0.13513951775218758, 0.18073443828948907, 0.201675291040114, 0.3759866218481745, 0.23573036651526177, 27.594385078975133, 102.86910847255162, 78.52098778315953, 90.5383905683245, 78.43690068381173, 96.23308549608502, 75.1817182813372, 79.82674884796143, 41.9984906060355, 84.40143585205078, 21.1368248462677, 0.292588968362127, 4.254389379705701, 14.807127101080757, 6.712905662400382, 9.345509495053973, 17.69890308380127, 5.152405832495008, 44.94139664513724, 81.1234564099993, 72.54035363878522, 71.19206959860665, 63.68526363372803, 72.71047333308628, 68.40403543199811, 75.18827738080705, 71.00022288731166, 74.9690408706665, 66.30396325247628, 70.19834518432617, 67.63860103062221, 68.3537096296038, 61.87013013022286, 58.173653738839285, 52.380266598292756, 52.1531925201416, 50.793798310416086, 52.82334974833897, 53.77006612505232, 51.960536343710764, 50.32742132459368, 51.15039028440203, 47.276436056409565, 53.53836802073887, 55.12461049216134, 52.95434761047363, 51.66786084856306, 48.61264412743704, 47.420788356236045, 50.44640575136457, 47.40134382247925, 48.87597737993513, 53.17169073649815, 61.17537975311279, 58.427943910871235, 61.16396386282784, 64.47553089686802, 63.21803896767752, 61.58865860530308, 58.5983693259103, 55.57775463376726, 51.31147732053484, 52.390445709228516, 56.95293515069144, 63.82350499289376, 57.595164094652446, 59.80513940538679, 59.28654670715332, 60.72565759931292, 61.130112239292686, 60.32319014413016, 57.399409021650044, 63.219553674970356, 51.10650198800223, 49.32782915660313, 64.41668660300118, 49.74576677594866, 49.242383684430806, 47.31133338383266, 46.08193302154541, 43.76214490618025, 46.71846791676113, 46.79886899675642, 47.05295072283064, 50.48365156991141, 56.86816712788173, 56.75789226804461, 53.593772956303184, 45.0444974899292, 44.862228870391846, 42.160571234566824, 44.15063258579799, 44.52199642998831, 48.899236474718364, 48.44836786815098, 49.98673030308315, 47.4921498298645, 45.154633385794504, 44.730814116341726, 44.76771947315761, 46.55980927603585, 46.78587933949062, 47.14633451189314, 48.4933956691197, 47.522784437452046, 47.692674841199604, 48.567849091121126, 48.56747736249651, 51.7172451700483, 64.02697604043144, 59.484132630484446, 63.55360916682652, 58.12341478892735, 61.80050918034145, 62.15419333321707, 61.266269138881135, 61.79151126316616, 65.10714994158063, 61.76851967402867, 66.4962546484811, 64.7763739994594, 64.51045254298619, 63.30535697937012, 67.90352194649833, 63.87744385855538, 64.222838810512, 63.34211294991629, 31.718012401035853, 1.2730929149048669, 6.361347224031176, 4.949759449277606, 4.93206890140261, 2.2392415574618747, 0.36477005801030565, 0.19522523214774473, 24.26519046510969, 79.5995010648455, 55.71877874646868, 50.116536549159456, 75.90712411063058, 61.18952628544399, 22.30017736979893, 34.75657429013933, 43.311106068747385, 65.03368663787842, 65.319306237357, 79.02711541312081, 7.636030299322946, 0.46296601742506027, 0.32307855944548336, 0.13444039598107338, 0.10539516167981283, 0.08140138310513326, 0.11723882758191653, 0.06283248521919761, 0.15140709626887525, 0.1479845249227115, 0.10023372221205916, 0.167922828612583, 0.11726744818900313, 0.14654225802847318, 0.12233493769807474], [0.09301045909523964, 0.04607878385909966, 0.043066729591893296, 0.018440822704828212, 0.012636507778162403, 0.0066845949456494835, 0.03865315785099353, 0.03276321943849325, 0.015125899243035486, 0.06333975799913917, 0.010665136239757496, 0.02294204759943698, 0.040777610282280614, 0.07624126678066594, 40.56721033368792, 67.95093645368303, 59.12989956992013, 57.469485078539165, 45.31617552893502, 7.562008534158979, 26.20629828316825, 42.851826667785645, 41.644664015088765, 64.64297553471157, 3.0232903999941687, 0.1310348558638777, 5.700342510427747, 7.46265971660614, 2.2220347779137746, 3.8366871305874417, 7.866144214357648, 6.406304674489157, 73.74608148847307, 72.92019775935582, 69.91638728550502, 59.58934225354876, 59.58537483215332, 62.62464196341378, 65.66641044616699, 66.82813535417829, 69.1670310156686, 65.68544156210763, 66.60568877628872, 65.08592319488525, 65.68455219268799, 64.19358689444405, 61.91967078617641, 62.92035729544503, 56.780519076756065, 47.99083593913487, 46.482586996895925, 46.912975788116455, 52.47553334917341, 47.10760872704642, 45.8528265953064, 43.640864099775044, 43.82346623284476, 44.30373266765049, 45.81575100762503, 46.348719528743196, 45.54974617276873, 44.36724962506975, 43.0927346093314, 42.76280982153756, 44.21584142957415, 43.081197125571116, 45.380595752171104, 47.25760643822806, 51.67574010576521, 53.428951263427734, 56.71373994009835, 55.91079568862915, 57.20166328975132, 53.17370918818882, 51.78170708247593, 48.606032916477744, 50.257300104413716, 53.59661824362618, 59.276673316955566, 50.49396617071969, 51.95745481763567, 54.24486085346767, 54.206558908735005, 53.46637773513794, 53.83987120219639, 52.85731601715088, 55.27294063568115, 43.04521935326712, 45.37904282978603, 57.74493251528059, 44.74169846943447, 45.10161515644619, 37.498336928231375, 40.3117459160941, 41.60057769502912, 46.33447919573103, 43.90441622052874, 43.810438360486714, 43.80211789267403, 52.379606519426616, 53.62649202346802, 52.035312856946675, 43.80853107997349, 41.971781730651855, 39.65283782141549, 40.962938036237446, 40.394554546901155, 42.229087420872276, 44.12742560250418, 44.0328745160784, 42.814532211848665, 40.43567746026175, 40.587822164808, 39.325032234191895, 39.34803424562727, 42.9406281198774, 42.14312778200422, 42.55955069405692, 42.39336715425764, 44.19750165939331, 42.498271056583945, 42.101094654628206, 49.371491636548726, 59.54861886160714, 53.963590826307026, 59.8629275730678, 59.51565660749163, 58.69364997318813, 58.13986117499215, 57.03091130937849, 58.42365687234061, 59.13968958173479, 57.23401757649013, 61.73946230752127, 59.418180329459055, 63.99627195085798, 62.960545676095144, 61.9710944039481, 58.0989362852914, 64.98108182634626, 50.767436844961985, 46.96717173712594, 6.908290309565408, 1.3175148112433297, 2.7599028646945953, 0.9905740576131004, 1.4433691608054298, 0.23456000217369624, 0.07696413049208266, 1.0708909992660796, 51.67189427784511, 60.15605122702462, 51.166002886635916, 41.42230428968157, 64.19179425920758, 69.29275172097343, 18.46914390155247, 14.766214370727539, 45.4357852935791, 43.97415181568691, 58.72030326298305, 13.489007796560015, 0.45050572603940964, 0.08276726052697216, 0.07916521666837589, 0.059970587358943055, 0.03967102144711784, 0.020737305815730776, 0.04647515009024313, 0.015919255957539593, 0.032643142488918135, 0.042122144385107925, 0.01350536847686661, 0.03262393994789038, 0.029156938128705536, 0.08627665721412216, 0.06211342130388532, 0.05298766813107899, 0.040923057656202994, 0.05299124740330236, 0.050669775544000525, 0.047245741954871585, 0.06576527641820056, 0.020218723553365896, 0.04319946800491639, 0.025356534735432694, 0.10098124388605356, 0.021403435517900755, 0.048290746951741834, 0.09040331720773663, 53.21210840770176, 78.05061558314732, 64.94041401999337, 61.9305099759783, 54.08995076588222, 15.588535411017281, 23.158215624945505, 47.28164373125349, 47.43938173566546, 73.45843301500592, 2.373366108962468, 0.1866596503449338, 4.876014309270041, 4.295790655272348, 4.652714840003422, 3.4701998361519406, 6.886654053415571, 8.872159123420715, 76.02010876791817, 76.57368564605713, 72.17726857321603, 62.388146127973286, 62.87884875706264, 65.77660192762102, 68.09057440076555, 68.92551163264683, 72.13022232055664, 67.13534995487758, 68.63502829415458, 66.42998273032052, 67.36687782832554, 66.58084201812744, 65.0553719656808, 63.781044551304404, 59.53023392813546, 50.55209827423096, 49.96235949652535, 47.65777403967721, 53.66893856866019, 48.57122938973563, 47.63516807556152, 47.803081716809956, 46.1293614251273, 47.453649861471995, 47.5211238179888, 49.07728753771101, 46.302406311035156, 45.727317810058594, 44.878143719264436, 43.894963196345735, 46.930221217019216, 43.992422103881836, 47.06925467082432, 49.390397684914724, 53.009419032505576, 57.24374852861677, 57.67490856988089, 59.39124911172049, 58.50481183188302, 57.02765955243792, 54.77363613673619, 49.59776667186192, 51.64220462526594, 57.16229827063424, 58.363096373421804, 51.37244776317051, 52.57205772399902, 54.85931437356131, 56.11445433752877, 55.89221273149763, 56.71279845918928, 55.4164765221732, 56.571809087480815, 43.99085528509957, 46.57594299316406, 59.34243106842041, 47.557400362832205, 47.12989159992763, 40.06135368347168, 43.73233018602644, 43.737600394657676, 48.62398011343819, 46.848704951150076, 45.32310288293021, 46.85593107768467, 54.50351449421474, 56.170550618852886, 55.02062375204903, 47.514387539454866, 44.72058636801583, 43.25538846424648, 42.54754420689174, 43.02959285463606, 44.43394538334438, 47.24942493438721, 46.90628467287336, 45.35994570595877, 42.85555785042899, 40.63314526421683, 41.772073132651194, 41.817632470812114, 46.25308452333723, 44.01395109721592, 44.62371458326067, 44.4874221937997, 44.57974985667637, 46.27325514384678, 43.5984696660723, 50.97137689590454, 60.57258183615548, 59.06868594033377, 61.62323978969029, 60.572109358651296, 62.012387548174175, 60.15919876098633, 59.44348566872733, 59.54923030308315, 60.08132335117885, 60.72929150717599, 62.67022909436907, 62.365154538835796, 65.28325203486851, 64.91603973933628, 62.96148368290493, 61.7964722769601, 66.11703586578369, 57.00037745067051, 53.65468781335013, 11.906856945582799, 0.7152896864073617, 0.6467955389193126, 1.449633070400783, 2.4345562883785794, 0.6845091123666082, 0.0992744229733944, 0.8649805369121688, 52.847202914101736, 65.44890403747559, 51.20964799608503, 43.77383872440883, 66.29872431073869, 63.85008880070278, 23.460741928645543, 22.68386037009103, 52.51631580080305, 51.32375478744507, 67.2876753125872, 20.98161424909319, 0.5574049013001579, 0.1618510258517095, 0.04392932401970029, 0.033394117906157456, 0.10520038820270981, 0.03748965349846652, 0.021612510816859345, 0.020605110230722597, 0.043722313163535934, 0.02369413411776934, 0.004505288047117314, 0.08360406383872032, 0.024597698490002325, 0.03560671882171716, 0.22517787132944378, 0.16503100735800608, 0.20077506506017276, 0.10320168188107864, 0.17499215927507195, 0.12436784218464579, 0.14497362077236176, 0.10205773290778909, 0.08886076283774205, 0.11120572845850672, 0.13528156227299146, 0.10643192926155669, 0.1614666629050459, 0.1391746840838875, 60.2203984941755, 87.41871193477085, 77.75605365208217, 72.05329881395612, 59.22252600533621, 14.873039449964251, 39.02185106277466, 59.34737123761858, 57.81490087509155, 79.43220928737095, 4.41243223633085, 0.4661119229027203, 12.850722823824201, 17.411100012915476, 8.402849997792925, 13.90115235533033, 25.022292239325388, 10.111663903508868, 78.36195046561105, 80.31924411228725, 76.00819260733468, 66.04394081660679, 65.67305292401994, 68.76186071123395, 72.76566287449428, 71.48482499803815, 73.66218199048723, 70.76449830191476, 73.66299492972237, 69.89077622549874, 69.40423556736538, 70.19298812321254, 67.329176902771, 67.16577611650739, 63.58322238922119, 52.08559349605015, 52.46648332050869, 51.10070024217878, 57.213440486363, 51.20049374444144, 51.89399344580514, 49.67349508830479, 49.225437028067454, 49.26138700757708, 52.13193103245327, 52.43755449567522, 48.23981768744332, 48.48405729021345, 46.34457492828369, 46.649778025490896, 49.09493943623134, 45.95964820044381, 49.986716406685964, 53.436368465423584, 55.07343006134033, 59.24941553388323, 60.109880447387695, 60.49583203451974, 61.175490924290244, 57.74920218331473, 56.7601261138916, 52.31740624564034, 54.56851141793387, 59.57111712864467, 61.778198514665874, 51.521375451769146, 55.15472398485456, 57.66724470683506, 57.52435152871268, 56.9320592880249, 59.358127049037385, 58.76400743212019, 56.91375425883702, 46.50275066920689, 50.44934136526925, 62.46889114379883, 50.635146617889404, 50.88334321975708, 42.20600203105381, 46.166360582624165, 46.33894688742501, 50.49350758961269, 49.75545951298305, 49.32872894832066, 50.32809182575771, 58.70013264247349, 58.360483850751606, 57.49154560906546, 50.49769735336304, 46.847520283290315, 45.0323555128915, 45.33845840181623, 45.949632372174946, 47.55519430977957, 50.07307209287371, 50.34194653374808, 47.44207068852016, 45.58748531341553, 43.455409731183735, 45.302178382873535, 44.56787191118513, 49.741104534694124, 46.644657203129356, 46.36571134839739, 46.47499261583601, 47.16290943963187, 48.857957226889475, 45.580356461661204, 53.47139433452061, 62.774882861546104, 60.337329728262766, 63.711604254586355, 63.01003769465855, 64.01992361886161, 62.73762662070138, 61.71061338697161, 61.60781478881836, 61.8553443636213, 62.89646244049072, 64.6010640008109, 64.42316232408795, 67.98840808868408, 68.76727335793632, 66.72317586626325, 63.989448819841655, 69.90704890659877, 59.87168230329241, 55.11552919660296, 13.812153748103551, 3.1487481594085693, 10.021616118294851, 4.868291820798602, 5.234048902988434, 0.826543428003788, 0.12053220586052962, 1.457320275051253, 61.22917965480259, 73.58359786442348, 66.89841638292584, 50.69579744338989, 73.73081629616874, 76.15354892185756, 25.078808886664255, 23.686197076525005, 63.240141187395366, 57.651586941310335, 78.69279588971818, 25.486968653542654, 0.7751200273633003, 0.19431096049291746, 0.20145058738333838, 0.13662544158952578, 0.24549605963485582, 0.18709703401795455, 0.18784469818430288, 0.08751089205699307, 0.14648068776088102, 0.12857371435633727, 0.05716180521994829, 0.1839565025376422, 0.24571055812495096, 0.19516609103551932], [0.06774081755429506, 0.03930147770526154, 0.050601732052330456, 0.06779571103730372, 0.028424937943262712, 0.012937126780993171, 0.036762084146695476, 0.01252839933814747, 0.07344810451780047, 0.08724935751940523, 0.034456764813512564, 0.06838297631059374, 0.14771757567567484, 2.2704958575112477, 64.815415927342, 62.970683097839355, 62.8792587007795, 57.922101157052175, 32.223466055733816, 30.1465939113072, 55.27640778677804, 32.78105551855904, 56.56323848451887, 44.86502552032471, 0.32381634414196014, 0.10450465232133865, 5.314050027302333, 2.005599477461406, 2.1096283410276686, 12.068344371659414, 1.6225299813917704, 21.909544433866227, 77.58838667188371, 63.07138334001814, 66.94489288330078, 56.05267442975725, 62.09070764269148, 62.26959596361433, 63.56073107038225, 62.766558919634136, 69.45257418496269, 64.47594778878349, 64.7138888495309, 62.27589103153774, 62.01786272866385, 60.827844755990164, 63.68580559321812, 61.131974356515066, 60.92417458125523, 55.033832277570454, 47.89653498785836, 44.771356855119976, 47.616637229919434, 47.548124517713276, 45.643032687050955, 44.442394392830984, 44.215761525290354, 44.85483946119036, 43.31212397984096, 43.83628913334438, 43.528108733040945, 43.554768971034456, 43.20705679484776, 42.10456875392369, 41.232479504176546, 41.94228662763323, 44.15537125723702, 45.540456431252615, 52.577598912375315, 52.15961612973894, 56.92744221006121, 55.920231342315674, 57.53050415856497, 55.57228640147618, 58.26847927910941, 53.40177338463919, 53.91882010868618, 53.31436504636492, 55.71695484433855, 50.75963749204363, 53.54538917541504, 54.111837591443745, 56.279574802943635, 54.288356576647075, 55.33390760421753, 53.615934235709055, 57.47197253363473, 39.619135584150044, 43.44039119992937, 57.02224343163626, 44.744095597948345, 44.017921992710654, 42.061048712049214, 44.46993705204555, 44.589571135384695, 48.73682928085327, 45.53696148736136, 43.79045534133911, 44.44573647635323, 51.79084396362305, 53.832561697278706, 50.23945713043213, 47.005647386823384, 41.40725449153355, 40.19652393886021, 41.035432066236226, 40.149536745888845, 43.409447397504536, 45.62919882365635, 44.74187217439924, 45.92521292822701, 41.15866184234619, 40.37196247918265, 41.00225441796439, 40.62984486988613, 41.30834688459124, 41.97062485558646, 43.46514763150896, 41.57744714191982, 43.12785080501011, 43.82122891289847, 42.51369605745588, 50.616796425410676, 57.59351389748709, 55.414947918483186, 59.65965107509068, 57.93839120864868, 57.567885466984336, 59.58203969682966, 59.27747930799212, 59.2543557030814, 55.7426666532244, 60.982963289533345, 59.90923036847796, 60.683739117213655, 58.228475025721956, 56.94319030216762, 56.54063946860177, 56.51268686567034, 61.924201011657715, 60.66763319287981, 55.54664060047695, 47.91866152627127, 0.904079733150346, 1.2093350504125868, 2.9133655556610654, 1.513958950127874, 0.18177996575832367, 0.02853677747771144, 0.07180641618158136, 15.57867591721671, 71.18330792018345, 41.97332770483834, 59.6479503086635, 66.42828042166573, 98.89613546643938, 79.29800483158657, 23.594253301620483, 35.69368478230068, 45.19722931725638, 56.26850632258824, 27.20047606740679, 0.130378251097032, 0.009762500612331288, 0.04575118036674602, 0.0746275137311646, 0.048917299402611594, 0.04910295336906399, 0.04394752232890044, 0.07579424791038036, 0.059254441144210954, 0.04267990695578711, 0.042966235162956376, 0.056065136566758156, 0.08741758670657873, 0.016666792898571918, 0.0435287474787661, 0.02481209350350712, 0.04748318849929741, 0.12438038151179041, 0.08187901069011007, 0.02524809635776494, 0.04708311068160193, 0.07960894464382104, 0.0694110586440989, 0.06292202470025846, 0.013311369377853615, 0.0537638511242611, 0.19101097328322275, 3.8762128267969405, 78.75785187312535, 70.04151739392961, 71.0901186806815, 61.57873657771519, 39.46928031103951, 18.146846498761857, 41.62397575378418, 38.00250864028931, 63.40251364026751, 47.069122655051096, 0.295153830732618, 0.16275062757943357, 4.858344605990818, 2.629655190876552, 4.415177643299103, 18.881760937826975, 2.8762324282101224, 24.18886797768729, 82.92127500261579, 67.89303711482457, 70.51344599042619, 57.145754609789165, 63.625467436654226, 64.0112383706229, 66.93823650905064, 66.36705289568219, 73.1737653187343, 67.04619067055839, 67.4327745437622, 65.65364660535539, 64.68626281193325, 62.59391008104597, 67.06645856584821, 64.52737835475376, 64.26247828347343, 56.74497904096331, 49.86387572969709, 47.43456663404192, 49.383102076394216, 49.520638193402974, 48.738548960004536, 45.28114965983799, 46.494454520089285, 47.47207995823452, 46.60024431773594, 45.8445269720895, 46.26474360057286, 45.44555793489729, 45.543398993355886, 44.11780234745571, 43.23703479766846, 43.32999127251761, 45.38919414792742, 47.927239077431814, 54.9054399899074, 55.07436806815011, 59.379110608782085, 57.43342740195138, 61.73338263375418, 57.9849510874067, 59.57171467372349, 56.65789379392351, 56.62450075149536, 55.27794681276594, 56.80992385319301, 52.18592548370361, 54.00617633547102, 55.696891920907156, 58.26924358095442, 55.85632528577532, 58.43797016143799, 55.05283212661743, 58.65588651384626, 42.15768425805228, 44.44062955038888, 59.58450630732945, 47.63620335715157, 47.00275693620954, 45.23211622238159, 47.30525023596627, 47.92724255153111, 50.72921827861241, 48.957052435193745, 45.99740818568638, 46.07831995827811, 54.65296677180699, 55.71342863355364, 53.57580491474697, 48.09379434585571, 43.93122584479195, 42.65922607694353, 42.5569485936846, 43.136563846043174, 44.765833037240164, 48.535341944013325, 48.34388780593872, 48.05025693348476, 42.88282952989851, 42.368169512067524, 43.6148396219526, 41.87130730492728, 42.871361528124126, 44.102293968200684, 45.67004033497402, 44.957533836364746, 44.84494522639683, 46.1880076953343, 44.339904989515034, 53.22617850984846, 59.73023782457624, 57.01965870176043, 62.24713243756975, 58.367077691214426, 58.53150681086949, 60.77223832266671, 61.11928694588797, 59.647463934762136, 58.40800952911377, 62.37297126225063, 61.42402798788888, 61.93908405303955, 60.55880355834961, 58.90866892678397, 58.92410782405308, 59.58644485473633, 62.6085638318743, 63.183603695460725, 54.85181031908308, 54.6939229284014, 5.077716171741486, 1.0006978000913347, 0.5657103870596204, 1.5453895607164927, 1.2856857648917606, 0.11050296973969255, 0.028896438357021128, 14.602989026478358, 75.16091537475586, 48.18740742547171, 66.92944008963448, 71.85364927564348, 94.37609604426792, 73.50474275861467, 30.224517958504812, 40.97528151103428, 51.919392585754395, 63.43378748212542, 39.338212966918945, 0.18016664018588407, 0.018812322323875766, 0.014475348704893674, 0.058889945702893395, 0.09913402729268585, 0.06296387674020869, 0.020596501317673495, 0.03679971909150481, 0.07055015609200511, 0.050803565686302524, 0.04177832729848368, 0.01831083744764328, 0.06131206466151135, 0.05390076592032399, 0.21441912863935741, 0.1839361329163824, 0.08581003546714783, 0.15671518072485924, 0.17196339608303138, 0.1197533697954246, 0.14937010700149195, 0.17761211868907723, 0.2502911037632397, 0.16852059082261153, 0.18065426259168557, 0.19530110593352998, 0.2979435867496899, 4.402809849807194, 85.41017532348633, 80.16334738050188, 81.0200046811785, 72.96466623033795, 45.339584009987966, 43.70972074781145, 74.83357184273856, 46.96116154534476, 70.78357110704694, 52.79931245531355, 0.6281742581299373, 0.29300276615789955, 12.583340508597237, 8.94886028766632, 4.663984818117959, 26.564993824277604, 5.188549493040357, 25.079024280820573, 84.60098811558315, 69.19487244742257, 73.72966289520264, 61.06252016339983, 67.46203340802873, 67.16437258039201, 69.9961039679391, 69.37450422559465, 75.40412317003522, 70.68920067378453, 71.79190063476562, 69.25113201141357, 68.1109812600272, 65.94495677947998, 70.42125729152134, 67.18653733389718, 67.08082049233573, 59.588174956185476, 52.53874805995396, 50.74128035136631, 52.239120892116, 52.51413059234619, 52.038251944950645, 48.33948612213135, 49.20023243767874, 49.41940988813128, 48.55105529512678, 47.397227014814106, 49.35669544764927, 46.68816334860665, 48.34274482727051, 47.416939054216655, 44.85646881375994, 44.0846003804888, 48.15413250241961, 48.08399738584246, 57.90885441643851, 57.0450439453125, 61.53025899614607, 58.689606121608186, 63.054575647626606, 59.85538877759661, 61.887945311410085, 57.74280636651175, 58.32501329694475, 58.16501365389143, 60.47732203347342, 53.59462063653128, 57.87330743244716, 58.95494392939976, 60.961618423461914, 58.59180327824184, 59.58921718597412, 59.719614028930664, 62.37525027138846, 44.823784487588064, 48.062485763004844, 62.52462264469692, 50.47973278590611, 49.10156454358782, 47.74219465255737, 50.94659614562988, 50.87716627120972, 53.45223120280674, 52.74527284077236, 48.84890372412545, 48.51051950454712, 56.605559962136404, 60.154522623334614, 55.42940017155239, 51.02449934823172, 45.658829416547505, 44.90367834908621, 45.9508934702192, 45.94869089126587, 48.02487516403198, 52.72409473146711, 50.37989412035261, 50.650915554591585, 46.249933515276226, 44.36085728236607, 46.63026053564889, 45.17650284085955, 44.89924887248448, 46.476448263440815, 48.18573638371059, 45.76060662950788, 46.74241835730416, 47.53124039513724, 46.090958731515066, 55.96993180683681, 61.52460316249302, 58.98567581176758, 64.04975918361119, 62.26897062574114, 60.64141763959612, 65.60604449680874, 62.08624689919608, 62.64372171674456, 61.75814601353237, 63.900643893650596, 65.2980100086757, 64.36847305297852, 63.858454431806294, 62.75861018044608, 60.46644115447998, 61.789148875645225, 66.57554749080113, 65.2418268748692, 56.19211435317993, 56.64901747022356, 5.462813998971667, 5.533309987613133, 10.109118257250104, 4.250717256750379, 1.8077542994703566, 0.28531529009342194, 0.13451818323561124, 19.155829157148087, 83.14681352887834, 55.65297930581229, 70.88650172097343, 71.41211904798234, 107.38103239876884, 91.69835758209229, 33.91260092599051, 50.40209708895002, 59.78062616075788, 71.19077028547014, 45.67946556636265, 0.3024234377912113, 0.059477360253887515, 0.10986481434000389, 0.1563946000699486, 0.19594416714140347, 0.12027723954192229, 0.2175125019358737, 0.20848551632038184, 0.17512938619724341, 0.15960366358714445, 0.10353866272739001, 0.17514710953193052, 0.24624798500112124, 0.11363879218697548], [0.04540114450667586, 0.06428480800241232, 0.01911819912493229, 0.03273187451330679, 0.03693836075919015, 0.04253919914896999, 0.06770121146525655, 0.030895110751901354, 0.07455644397331135, 0.05783283564129046, 0.09864424036017486, 0.15044823129262241, 0.27120716284428326, 15.330124957220894, 76.10139574323381, 56.48831605911255, 68.43574006216866, 48.57961239133562, 20.95523020199367, 21.227307762418473, 35.58319105420794, 36.11267852783203, 77.12189156668526, 20.133494547435216, 0.2801034354737827, 0.3141652691577162, 2.8789550364017487, 1.110051046524729, 5.034914834158761, 7.5092630216053555, 4.56865770476205, 38.89376449584961, 78.74492822374616, 63.50192151750837, 65.97999654497418, 56.01127706255232, 60.0758273260934, 56.96474708829607, 60.17010743277413, 59.90382466997419, 66.01060335976737, 61.228470938546316, 61.875938824244905, 61.15411826542446, 62.654053688049316, 61.44276033129011, 57.60034397670201, 62.06216444287981, 62.76876844678606, 58.359142848423545, 49.972986766270225, 44.33581597464425, 46.43054151535034, 45.827177320207866, 45.06847224916731, 43.5814847946167, 45.12764310836792, 42.26251867839268, 44.56803866795131, 42.45369141442435, 45.55999476569039, 41.062133993421284, 42.97699499130249, 41.09234128679548, 44.42307492664882, 43.62693990979876, 51.30316380092076, 54.44362449645996, 57.44054930550711, 55.758779525756836, 56.47721283776419, 55.926356179373606, 53.67326034818377, 53.65491362980434, 63.71309116908482, 55.89284154347011, 57.7071829523359, 53.84557567323957, 55.454941749572754, 54.1307749067034, 54.38075719560896, 54.53678594316755, 57.85338347298758, 54.92802510942732, 59.275290625435964, 51.824601786477224, 57.01494434901646, 34.513220582689556, 38.81375598907471, 59.31543036869594, 46.43319572721209, 47.558737891060964, 43.13126584461757, 46.99823365892683, 45.83140877314976, 46.799886907849995, 44.74228211811611, 44.18817022868565, 44.96381153379168, 51.095402240753174, 54.30177354812622, 55.23835597719465, 47.5164337839399, 45.1111341885158, 43.98943785258702, 44.64090442657471, 43.923794746398926, 47.773058550698416, 47.11659622192383, 47.46786934988839, 46.84489386422293, 43.10651636123657, 39.18637745720999, 40.81860658100673, 39.52636323656355, 42.00186048235212, 42.52515363693237, 41.82492807933262, 43.251455783843994, 42.070918628147666, 41.92761550630842, 40.98789249147688, 49.15705633163452, 58.77627795083182, 56.86615909848894, 56.182855878557476, 54.40843881879534, 58.30114623478481, 56.84363651275635, 58.40254129682268, 51.13508687700544, 54.6817045211792, 61.39278193882534, 57.977693693978445, 57.679758412497385, 55.50873817716326, 52.49699633462088, 54.73935372488839, 59.607150486537385, 60.333848680768696, 58.228808539254324, 60.47628675188337, 65.04342106410435, 48.34647600991385, 1.2270849836724145, 0.6698172007288251, 1.1265472642013004, 0.9549206793308258, 0.23393553282533372, 0.06780086790344544, 1.1521219547305788, 51.17534473964146, 56.32546418053763, 38.51738057817732, 62.63917759486607, 82.19335392543248, 40.39604146139962, 17.668230261121476, 24.667063849312918, 44.52943795067923, 51.98913860321045, 50.285999638693674, 1.7471964061260223, 0.07909956161997148, 0.06086516114217894, 0.03617542955492224, 0.03068196933184351, 0.051762691898537536, 0.028962218934403997, 0.054233159869909286, 0.005927612797157573, 0.011235621342036341, 0.06380216604364769, 0.02449174863951547, 0.056822697166353464, 0.08210163124437843, 0.08612963224628142, 0.03910062116171632, 0.028022449629913484, 0.0478438536104347, 0.020397853405613984, 0.030258831501539265, 0.06486237022493567, 0.025580787166420902, 0.006051105322382812, 0.12262659919049058, 0.044274637276040654, 0.19714353206966603, 0.338422706084592, 22.05754974910191, 85.45522049495152, 63.19640227726528, 74.71101951599121, 59.82052966526577, 37.41291577475411, 22.976711307253154, 39.99187864576067, 41.47536768232073, 84.73692267281669, 19.70550635882786, 0.256731921008655, 0.10427813019071307, 3.9976664696420943, 1.8502753206661768, 6.139202892780304, 13.83553877898625, 5.9181142534528455, 43.058351448604036, 78.46342195783342, 67.32315281459263, 69.42724105290004, 60.013606207711355, 62.560239110674175, 59.15141119275774, 60.78215340205601, 63.807447705950054, 68.96748570033482, 63.994097164699006, 65.36317716326032, 64.55854102543422, 66.2766637802124, 66.26053006308419, 61.940577915736604, 64.6797592980521, 64.28016144888741, 61.81000736781529, 52.92638805934361, 46.970805644989014, 48.004760129111155, 48.27479491915022, 48.22829410008022, 46.61582217897688, 48.232035705021445, 45.68626437868391, 46.95170852116176, 45.44711085728237, 47.62029545647757, 43.17736714226859, 44.08659103938511, 42.867699827466694, 45.48829977852957, 45.107771260397776, 52.562368461063926, 55.6682653427124, 58.778626441955566, 56.78000143596104, 58.082045214516775, 56.20840787887573, 56.98536239351545, 56.352541310446604, 62.94864341190883, 57.06789657047817, 57.884240422930034, 57.4251903125218, 58.127990177699495, 55.21460356031145, 56.44575834274292, 55.286395822252544, 60.342902183532715, 56.1390266418457, 60.57202598026821, 54.604680265699116, 59.025968415396555, 35.27494464601789, 40.36572994504656, 61.83401339394705, 47.89428377151489, 50.34732443945748, 46.70883771351406, 50.04003688267299, 48.38822773524693, 50.33702026094709, 47.45471640995571, 44.43160384041922, 47.36219072341919, 52.82005977630615, 55.682252066476, 58.12607594898769, 50.59477063587734, 46.93750292914254, 46.11041716166905, 47.29100642885481, 46.79382807867867, 51.636239596775596, 49.416397844042095, 50.44052757535662, 49.539436544690815, 45.019685472760884, 40.786947114127024, 41.58558348246983, 42.127584661756245, 43.99393333707537, 45.48187616893223, 43.57562051500593, 45.04988234383719, 43.747404302869526, 44.45354972566877, 43.62425095694405, 50.39676087243216, 60.78043024880545, 59.30125604357038, 57.545248235974995, 57.01462820598057, 60.613020351954866, 60.240840094430105, 61.51720333099365, 54.02652760914394, 56.871384143829346, 62.82913439614432, 60.382965496608186, 57.938915797642295, 58.44653729030064, 55.685347488948274, 58.76660605839321, 61.09320340837751, 63.32278306143624, 60.14399610246931, 63.28176784515381, 65.23469802311489, 57.28928354808262, 4.1648470759391785, 1.0796996865953719, 0.31178868668419973, 1.661797508597374, 0.8532929612057549, 0.047931656041847806, 1.0104641446045466, 51.84404284613473, 63.43045234680176, 42.78652054922921, 65.76085036141532, 83.66650404248918, 46.02681991032192, 24.188378129686626, 34.45776353563581, 52.74646793093, 57.81999737875802, 61.195731026785715, 3.0599929562636783, 0.1868202867252486, 0.13797732761928014, 0.036197095178067684, 0.11087562117193427, 0.09264445052083049, 0.03466766028265868, 0.030751349537500312, 0.02965700825942414, 0.01976611864353929, 0.05628075124695897, 0.026852003864145706, 0.07233439785029207, 0.09297720409397568, 0.1484814296875681, 0.10756132365869624, 0.09734036746834006, 0.1606890617736748, 0.07300209666469268, 0.14944847779614584, 0.1514602391315358, 0.17157987451979093, 0.14966225703912123, 0.15252130505229744, 0.26019464805722237, 0.3553390997861113, 0.5138483813830784, 25.92205442701067, 97.654999596732, 69.99228245871407, 86.95173045567104, 62.729907172066824, 33.76021303449358, 35.168109144483296, 52.54421281814575, 47.69020823069981, 94.08607823508126, 23.378622906548635, 0.3729866013995239, 0.35307702688234194, 7.145698530333383, 7.915524193218776, 9.915972232818604, 15.30123782157898, 7.451600790023804, 46.02121271405901, 83.22444575173515, 69.58868939535958, 71.1275416782924, 62.01640360695975, 66.3475979396275, 63.10977908543178, 62.49533598763602, 65.5904735837664, 70.94879926953996, 67.32334736415318, 67.06681987217495, 66.78404208592006, 65.55473899841309, 67.13229274749756, 64.89233943394252, 66.89965316227504, 66.95445360456193, 65.03356157030377, 54.34176390511649, 49.60547569819859, 49.54746866226196, 49.93475430352347, 50.45577539716448, 49.57746056147984, 50.03266484396798, 48.198757307870046, 50.354738167354036, 47.0974052974156, 50.67234032494681, 45.68252624784197, 45.97512183870588, 43.84663847514561, 47.976943016052246, 48.41597536631993, 56.29823071616036, 56.93241712025234, 60.32676151820591, 59.48583493913923, 60.41186305454799, 59.080275535583496, 58.696894781930105, 57.35633366448538, 64.05655452183315, 59.09706238337925, 61.80245467594692, 58.912414005824495, 60.06254237038748, 57.899599415915354, 58.0328380720956, 57.46286344528198, 62.446524892534526, 57.88314955575125, 63.71534238542829, 56.76237038203648, 58.56471920013428, 38.52328307288033, 44.249633993421284, 63.96367795126778, 50.50027860913958, 54.512418610709055, 50.42976481573922, 52.651559012276785, 50.800433840070454, 52.203917843954905, 50.48952974591936, 47.524472849709646, 50.9175248827253, 56.837595054081504, 58.699416978018625, 59.2665011542184, 53.37399796077183, 48.301736559186665, 49.51684447697231, 48.55017287390572, 50.59743874413626, 53.64139938354492, 53.15595306668963, 53.51627969741821, 51.31452063151768, 48.04755755833217, 42.69353975568499, 43.72745949881417, 44.2699852670942, 46.483271394457134, 48.422680377960205, 46.13365888595581, 47.087215764181956, 45.91922358104161, 47.633729798453196, 44.18985169274466, 54.09963655471802, 65.25857203347343, 62.294074467250276, 61.48717321668352, 58.85923249380929, 62.45875372205462, 61.06156826019287, 63.10236535753523, 56.174691745213096, 60.49763856615339, 64.30039460318429, 62.90680830819266, 62.49679510934012, 61.915752002171104, 57.72738831383841, 61.70583997453962, 64.84753050122941, 66.326169695173, 63.10012108939034, 64.99837589263916, 66.90405137198312, 57.21131086349487, 5.01086060489927, 3.8532937594822476, 7.444330368723188, 3.5431956563677107, 1.5940536579915454, 0.16788666269608907, 1.7073518527405602, 61.93460941314697, 66.98442813328334, 51.964302267347065, 70.41745662689209, 87.34986223493303, 46.96360036305019, 29.68701226370675, 38.598389625549316, 60.52534103393555, 67.12508746555874, 71.66904953547886, 3.8379938261849538, 0.2979291746658938, 0.33168186779533115, 0.1307418780135257, 0.2610895543226174, 0.13400906484041894, 0.16147517173417977, 0.13976012409797736, 0.10119946753340107, 0.10976203664072923, 0.11196966389460222, 0.20236333911972387, 0.14224141809557164, 0.14462384954094887], [0.056552222929894924, 0.052979434108627696, 0.007977699910822724, 0.01966723912794675, 0.03648694158930864, 0.04507787685309138, 0.06195259493376527, 0.018649107510490075, 0.07872225543750183, 0.04682881611266306, 0.06151341314294508, 0.08758374636194535, 0.09250951704702207, 37.674553666796, 69.13699395315987, 57.426204749516074, 66.09503786904472, 33.256534644535606, 13.034626007080078, 21.912888254438126, 27.380309343338013, 48.32126447132656, 67.24928651537213, 4.03516720022474, 0.12720247650785105, 0.2686178189303194, 1.6928338089159556, 1.5089663437434604, 9.119422929627554, 2.7762159321989333, 9.684342741966248, 54.30796439307076, 69.82822854178292, 63.873108182634624, 63.34042453765869, 59.06596919468471, 56.54451656341553, 55.6993168422154, 59.05099582672119, 58.02057450158255, 61.88964762006487, 62.262175287519185, 60.63360786437988, 63.446648597717285, 63.316279547555105, 64.06117507389614, 60.779276847839355, 58.8381655556815, 62.8987067086356, 59.60920715332031, 50.75792476109096, 44.79698528562273, 45.325065749032156, 44.34270511354719, 45.704697949545725, 44.19486134392874, 43.64284781047276, 44.68777697426932, 44.33694158281599, 42.70443453107561, 43.2448410987854, 42.26525626863752, 43.023012910570415, 40.8961832182748, 41.81823696408953, 50.93099396569388, 57.861405168260845, 55.902207715170725, 58.122598375592915, 55.60974414008004, 56.07050698144095, 53.054971422467915, 54.339877469199045, 52.3991379056658, 50.06763860157558, 53.315115451812744, 51.121548312050955, 53.768607003348215, 53.49149547304426, 53.45743540355137, 56.41518974304199, 54.00441149302891, 55.428993701934814, 53.06753723961966, 56.09864371163504, 52.04902165276663, 63.05897385733468, 29.458538123539515, 35.93621512821743, 57.72853824070522, 45.10581881659371, 51.61308819907052, 44.72009652001517, 48.17310108457293, 43.77698278427124, 47.224348885672434, 41.515761034829275, 44.66039759772164, 44.634651047842844, 51.0155222756522, 50.38279151916504, 52.949720110212056, 50.54438924789429, 47.61603621074131, 47.92962230954851, 50.616091183253694, 49.75021014894758, 53.76219034194946, 49.638358048030305, 50.48329373768398, 48.43475982121059, 43.96087033408028, 39.67567307608468, 41.53091505595616, 41.076787744249614, 41.5581693649292, 40.73222657612392, 40.96589796883719, 41.497237137385774, 43.04888105392456, 42.86756086349487, 42.418300764901296, 46.20389822551182, 58.26393863133022, 53.710485322134836, 55.65202045440674, 55.43279089246477, 58.423121861049104, 57.3823025567191, 59.38802514757429, 52.07295472281319, 57.649898529052734, 56.85651499884469, 54.716164112091064, 51.22364861624581, 49.49283150264195, 51.46604694638933, 56.82544960294451, 56.53948606763567, 60.605266162327354, 58.80878857203892, 64.34284114837646, 58.81692491258894, 69.21063096182687, 42.700474057878765, 0.06413086197738137, 0.2890162372163364, 1.8349855925355638, 0.3057841674557754, 0.2614805262003626, 0.0810188182762691, 16.958084412983485, 64.12602261134556, 47.40548494883946, 57.037425245557515, 45.278544085366384, 19.723986830030167, 17.593224457332067, 21.82912598337446, 48.364284242902485, 45.71771887370518, 53.942701067243306, 8.128186838967459, 0.3859985146139349, 0.16739068073885782, 0.046154019821967394, 0.03490618569776416, 0.07277147618255445, 0.025751089278076376, 0.04056390567815729, 0.10169699655047484, 0.04033443870555077, 0.06504889271621193, 0.03696063027850219, 0.036600596204932244, 0.05687039139281426, 0.05052749014326504, 0.04053768708503672, 0.021578565406213914, 0.013802508291389261, 0.0322075467556715, 0.02481858877997313, 0.07154800969042949, 0.05453523008951119, 0.016345825478700653, 0.0310003142138677, 0.02673308551311493, 0.027982994514916624, 0.2147512851016862, 49.66509124210903, 78.57932485852922, 64.01511546543666, 72.99406405857631, 45.17858035223824, 20.893728222165787, 27.96112663405282, 33.487044606889995, 55.35816029139927, 72.65265042441231, 3.6658222419875006, 0.1562621093222073, 0.45275387540459633, 2.512511168207441, 3.6823359387261525, 12.588282414845057, 1.7639986702374049, 10.093715838023595, 58.51403209141323, 71.54759502410889, 68.05033043452671, 65.87414073944092, 62.70121806008475, 59.16514778137207, 58.580039978027344, 61.14821924482073, 62.05554975782122, 62.88005774361746, 64.86827782222203, 63.748742376055034, 65.77495520455497, 67.65617997305733, 67.42290115356445, 62.415431703839985, 62.52549811771938, 63.83678994859968, 63.316140583583284, 54.316277912684846, 48.019945417131694, 47.285402706691194, 45.87651300430298, 47.010698727199006, 46.639126437050955, 46.47068125861031, 46.57533849988665, 46.55342040743147, 46.05195501872471, 45.45917640413557, 44.450926780700684, 44.12067890167236, 44.333662033081055, 43.29135928835188, 53.183547837393625, 59.57400063105992, 58.280913080487935, 58.54657745361328, 59.08900942121233, 57.116332462855745, 56.67879744938442, 56.432581084115164, 51.93363291876656, 51.410430090767996, 52.439948150089805, 52.68355546678816, 56.411795548030305, 58.60125977652413, 55.076622758592876, 56.768755776541575, 55.593509674072266, 57.14831502096993, 54.60420083999634, 59.06476715632847, 54.10954121180943, 63.151558603559224, 32.40566519328526, 37.81562294278826, 60.961472511291504, 48.27706003189087, 55.316408566066194, 47.89551360266549, 50.98957770211356, 45.47356612341744, 48.429986408778596, 45.244904381888254, 47.418714318956646, 47.717337472098215, 53.2020126751491, 52.224668639046804, 54.91686977658953, 51.43915046964373, 49.630204336983816, 49.80731739316668, 52.33282082421439, 53.79015336717878, 55.955406597682405, 52.337774889809744, 54.79883030482701, 49.904831886291504, 45.766703673771445, 42.68613297598702, 43.180580684116904, 43.596239294324604, 44.20581865310669, 42.76507493427822, 41.8415446962629, 43.0943465914045, 44.35789040156773, 44.7609658241272, 44.008722577776226, 48.58780084337507, 59.6751594543457, 56.64129454748971, 56.381181785038535, 58.5749261038644, 59.90003790174212, 59.365123885018484, 62.126831327165874, 54.202174595424104, 59.53655678885323, 59.031360217503135, 56.746125493730815, 52.59935024806431, 52.64080320085798, 54.059587138039724, 59.818778719220845, 58.819134439740864, 62.15852206093924, 60.70594555991036, 63.72989886147635, 61.285487856183735, 68.4420142854963, 52.4922194480896, 0.7261673627155167, 0.7286759338208607, 1.166168932403837, 1.4440025325332368, 0.7087025770119258, 0.23043214795844896, 17.154219899858745, 69.19598415919712, 52.53204999651228, 55.08127110345023, 52.7506924356733, 25.646872758865356, 23.410344907215663, 29.286667483193533, 54.97442865371704, 52.39946447099958, 63.73781285967146, 12.79480459008898, 0.4342814380569117, 0.08900284128529684, 0.023555904660107832, 0.033772384215678485, 0.0486778783212815, 0.020191091911068985, 0.02820630038955382, 0.006941461586393416, 0.054317355887698274, 0.024434680451772044, 0.05207170353138021, 0.0715449902095965, 0.03559587922479425, 0.1949784489614623, 0.11108135298958846, 0.15748909062572888, 0.06079071906528302, 0.20602229849568435, 0.10080730143402304, 0.14421062171459198, 0.1493706362588065, 0.17112906942410128, 0.10832013615540095, 0.1467146330646106, 0.19149122679872171, 0.40082849455731256, 58.48473848615374, 88.82553454807827, 72.96358231135777, 82.08721324375698, 46.64269781112671, 22.669727734157018, 33.854809284210205, 43.3967912537711, 62.932454109191895, 79.80470221383231, 4.832725729261126, 0.20784371718764305, 0.4710852046098028, 6.626536514077868, 4.385151871613093, 18.5182363986969, 7.5538053171975275, 12.540845326014928, 60.47729424067906, 74.10842309679303, 71.31658826555524, 70.20690536499023, 65.91036864689418, 60.60739231109619, 61.24142932891846, 65.72336483001709, 63.57177175794329, 66.2758230481829, 66.60426439557756, 66.62440722329276, 70.05966608864921, 70.63893740517753, 70.06794139317104, 65.53071907588414, 66.76766518184117, 66.2727449962071, 66.32289709363664, 56.94327368055071, 49.78523601804461, 50.104453631809776, 48.750690937042236, 49.26737982886178, 49.561576979500906, 47.96047578539167, 49.49193171092442, 48.734268869672505, 47.82825156620571, 47.233576093401226, 47.455869810921804, 47.098843574523926, 44.90064893450056, 45.084411416734966, 54.89499684742519, 63.31024851117815, 59.859828676496235, 61.1903600692749, 60.20243740081787, 60.61035919189453, 58.437178066798616, 59.34334128243582, 53.16530534199306, 54.563894339970176, 52.83299037388393, 53.62523092542376, 57.95437206540789, 58.93552371433803, 58.163585799080984, 59.375038964407786, 58.76642540522984, 59.61477266039167, 57.120716776166645, 58.58857236589704, 57.606962135859895, 65.60574572426933, 35.765247753688264, 42.46744189943586, 63.0225305557251, 50.4987986428397, 58.660784993852886, 51.101131030491416, 53.01155907767159, 49.803638322012766, 50.29254136766706, 46.12155859810965, 50.132194314684185, 50.35763904026577, 56.07406793321882, 55.21288735525948, 57.52745042528425, 54.08103970118931, 54.042522362300325, 52.71021917888096, 56.639356000082834, 54.888079915727886, 59.68045398167202, 54.88090590068272, 56.0162102835519, 52.29473079953875, 48.1902631350926, 45.608208315713064, 46.4388758795602, 46.487259660448345, 46.923283440726145, 45.18355873652867, 45.097995144980295, 46.06169639314924, 46.86308077403477, 47.35384941101074, 47.15179579598563, 49.60747330529349, 62.57392011369978, 59.76900182451521, 60.279076031276155, 61.18783787318638, 61.78673785073416, 61.41500922611782, 62.63847582680838, 57.22026014328003, 62.69508280072893, 62.04006222316197, 59.36085074288504, 55.0081239427839, 55.709898948669434, 56.898954595838276, 62.549657004220144, 61.18766416822161, 65.88324287959507, 63.64249052320208, 65.88332625797817, 65.39244992392403, 73.54227692740304, 53.6458740234375, 1.1236962229013443, 3.7067110879080634, 7.147613627570016, 1.436193083013807, 0.8672768622636795, 0.38261666893959045, 22.44201442173549, 76.83810629163469, 64.48155498504639, 64.87885298047746, 54.09337622778756, 27.041730574199132, 26.63184244292123, 33.329931940351216, 63.12410627092634, 59.22938387734549, 76.4893970489502, 16.154877867017472, 0.7526733832699912, 0.24009147392851965, 0.06651823994304452, 0.19239762744733266, 0.1899492966809443, 0.15121330666754926, 0.0951950636559299, 0.3264772327882903, 0.1306216823203223, 0.14303504622408322, 0.10506301200283424, 0.14098179925765308, 0.1300208938441106], [0.01043648605367967, 0.03409012859421117, 0.05717640729354961, 0.023791817715391517, 0.0448949743461396, 0.0316351312212646, 0.016758820906813656, 0.03556828320558582, 0.06522860271590096, 0.024019891994872263, 0.12998911126383714, 0.017319920173447047, 1.734353203858648, 63.7890419278826, 56.86715963908604, 58.01693364552089, 41.54055220740182, 23.03429971422468, 32.957956654684885, 31.87833513532366, 31.198297568729945, 68.8918684550694, 44.25814553669521, 0.039623300079256296, 0.18611230328679085, 0.6939209901860782, 1.677434538091932, 5.015240575586047, 5.157448053359985, 1.3738999856369836, 18.76486791883196, 65.38588387625558, 68.4078152520316, 66.54661519186837, 59.49497182028634, 59.25641931806292, 60.398897715977256, 59.94048336574009, 59.9865151814052, 61.50992161887032, 62.07029383523123, 63.10543646131243, 62.49587099892752, 61.7195348739624, 60.55444703783308, 60.65543910435268, 60.10548223767962, 58.587877546037944, 58.77259540557861, 60.34684181213379, 53.50887291772025, 45.57525300979614, 43.988381726401194, 46.53039755140032, 45.65513644899641, 45.994083472660606, 43.50989055633545, 44.223838806152344, 46.85466997964041, 45.94493538992745, 41.54744829450335, 42.588740076337544, 42.15906694957188, 42.378716877528596, 47.28430489131382, 54.61763170787266, 57.82960673740932, 53.75966814586094, 55.03611476080758, 56.8721102305821, 54.07243435723441, 54.11988360541207, 51.02731336866106, 54.00030510766165, 52.5973665373666, 44.76179265975952, 55.479534898485454, 51.13987071173531, 56.460203647613525, 52.12033796310425, 55.531166962214876, 51.84915672029768, 56.54579503195626, 51.59551967893328, 57.454091344560894, 49.15021235602242, 58.697193554469514, 26.154859031949723, 30.300743171146937, 57.53803947993687, 46.62497990471976, 50.9574179649353, 46.127495833805625, 47.99110344478062, 42.73767123903547, 47.316832883017405, 44.091652802058626, 44.74650662285941, 46.98208604540144, 51.274891580854145, 49.91016462871006, 52.638284478868755, 50.27756799970354, 49.70289639064244, 48.3735705103193, 50.61258929116385, 53.1569709777832, 53.363214356558665, 51.62708534513201, 50.82629156112671, 49.7387421471732, 45.59289101191929, 39.069929122924805, 39.8303781918117, 40.13775954927717, 40.17025627408709, 40.99355179922921, 39.48262432643345, 40.7508408001491, 41.929977893829346, 43.485491956983296, 42.89118126460484, 46.39199985776629, 55.26786150251116, 54.62627526691982, 55.38514362062727, 56.953456265585764, 55.77430180140904, 59.50084999629429, 54.98648030417306, 51.811712878090994, 54.131712913513184, 52.127939292362754, 48.39891753877912, 51.07366827556065, 50.04953507014683, 54.68117298398699, 60.38807242257254, 59.88145841870989, 59.16955293927874, 61.20008059910366, 58.12012134279524, 61.031642368861604, 57.65761797768729, 70.56459862845284, 27.060879809515818, 0.7994446935398238, 0.8724514245986938, 1.0714301360504968, 0.13445322029292583, 0.09425690078309604, 1.2139312837805067, 48.153573172433035, 55.80203206198556, 35.193445750645225, 37.49265677588326, 33.81947769437517, 22.23021595818656, 21.9118321282523, 35.10428646632603, 46.18660068511963, 56.67031717300415, 19.495528323309763, 0.41351186111569405, 0.03614468852590237, 0.04987703290368829, 0.050601172260940075, 0.04218623541029436, 0.04725738900846668, 0.010973024048975535, 0.13214693404734135, 0.06291720710162606, 0.024445647274010947, 0.028373671229928732, 0.03739019722810813, 0.10783935338258743, 0.013982839998789132, 0.04687747725152543, 0.03381562725241695, 0.050649321105863364, 0.04633179260417819, 0.025517159241384695, 0.03531621423150812, 0.0033672762552409297, 0.07018318399786949, 0.037917276445244036, 0.14164054819515773, 0.0803246565961412, 4.157295252595629, 76.58260713304792, 63.29052952357701, 66.07964760916573, 53.330662046160015, 36.8145820753915, 34.81987237930298, 33.17955902644566, 38.21076004845755, 75.2406667981829, 46.68204198564802, 0.03276327032861965, 0.07944791471319539, 1.583308377436229, 2.8793964641434804, 7.3353791407176425, 7.551337838172913, 0.9746904756341661, 21.75226501056126, 68.55827154432023, 70.80340126582554, 68.21453026362828, 63.821719305855886, 61.437875747680664, 61.47821004050118, 61.97975185939244, 64.15247440338135, 62.5685213633946, 65.66336713518415, 64.01485838208879, 62.90732247488839, 66.18217522757394, 63.34121663229806, 63.49010263170515, 62.72870513371059, 62.62042440686907, 62.884518487112864, 62.56360898699079, 57.84939520699637, 48.73932368414742, 47.61014066423689, 48.70196669442313, 48.189794131687705, 46.874274321964805, 46.223103046417236, 46.00378315789359, 48.04595252445766, 47.73728575025286, 44.0318010193961, 43.48299060549055, 43.87780809402466, 43.296038900102886, 48.31411130087716, 58.67192990439278, 59.298831122262136, 56.134534631456646, 57.06301546096802, 57.76771913255964, 56.22247798102242, 57.14569207600185, 54.68105139051165, 54.62796367917742, 51.22446502958025, 46.716491154261995, 54.46153347832816, 51.859916005815776, 58.32094860076904, 55.588027545383994, 56.70750045776367, 54.162361417497905, 59.41908359527588, 53.5212094443185, 57.492594787052695, 53.23916121891567, 58.3455035345895, 32.32937049865723, 34.91276632036482, 56.9720253263201, 49.88951458249773, 52.159077644348145, 50.04029049192156, 50.61650807516915, 46.24100508008684, 48.64003045218331, 47.597779818943565, 46.988419328417095, 49.728698526109966, 54.16567570822579, 50.559668336595806, 54.14844764981951, 54.85976600646973, 51.713767596653526, 51.01796109335763, 51.91466086251395, 55.680459431239534, 56.46600539343697, 54.47335236413138, 54.567556040627615, 53.290744645254954, 47.460243701934814, 40.943469183785574, 41.824757848467144, 41.57229505266462, 42.240732601710725, 42.46371071679251, 41.88546078545706, 43.60906219482422, 44.319512026650564, 45.48570115225655, 44.33154630661011, 48.52730287824358, 58.02941608428955, 57.4414039339338, 57.147839069366455, 58.33273274557931, 59.43362617492676, 60.274274826049805, 56.543443066733225, 54.828815255846294, 57.14153357914516, 54.243370464869905, 51.21224662235805, 50.91038908277239, 54.267776012420654, 57.114171573093955, 62.05063738141741, 61.0708441053118, 61.16328293936593, 63.213849203927175, 59.822440419878276, 63.40151309967041, 60.728158950805664, 70.60370309012276, 36.23212153570992, 0.5681760204689843, 0.7616293398397309, 1.8947513912405287, 0.8767372689076832, 0.0456453594379127, 1.0573100937264306, 48.485158579690115, 63.24337904793875, 42.26671191624233, 40.9368440764291, 34.290155615125386, 24.315735135759624, 27.087399346487864, 41.626484053475515, 50.6091742515564, 64.45893859863281, 28.808638368334087, 0.6263262544359479, 0.07364095095545053, 0.03423713659867644, 0.03124046472034284, 0.04435505385377577, 0.09388790665460484, 0.06047631986439228, 0.11153558468712227, 0.060544872257326326, 0.05938187002071312, 0.020157757181940333, 0.07341587410441466, 0.06004720753324883, 0.10698190225022179, 0.14795871345060213, 0.09872146443064723, 0.10256089376551764, 0.1724774135010583, 0.12396998996181147, 0.12515032876815113, 0.12626835091837815, 0.2485344580241612, 0.20533514608229908, 0.21570872515439987, 0.22031406446227006, 6.144053603921618, 89.63094888414655, 72.8992280960083, 77.22245979309082, 58.00291565486363, 36.17554930278233, 48.17593594959804, 49.13382502964565, 44.70176717213222, 85.10568441663469, 51.808805056980674, 0.22686295876545565, 0.22484713979065418, 1.3054574068103517, 6.1395212071282526, 11.772061892918178, 11.235222356660024, 3.5711156896182468, 26.26256479535784, 70.62813295636857, 75.45052324022565, 71.53626946040562, 66.82102039882115, 64.3082252229963, 65.15357780456543, 64.73880508967808, 67.63566194261823, 67.0024448122297, 69.26844692230225, 66.27102184295654, 65.66547243935722, 68.3419463293893, 65.97516059875488, 66.85980524335588, 66.24554974692208, 65.03156048910958, 66.4311500276838, 66.05826800210136, 59.531936236790244, 50.85984788622175, 51.217916352408274, 50.39372798374721, 51.33665064402989, 49.27123955317906, 48.88275187356131, 48.011506829942974, 49.836103779929026, 50.34218972069876, 46.520753451756065, 45.98546770640782, 46.075787339891704, 45.771748065948486, 50.94369527271816, 60.699775559561594, 62.91070624760219, 57.892328126089915, 59.80652904510498, 60.66993999481201, 59.56837953839983, 59.771065439496724, 56.90521839686802, 55.3841951915196, 54.044387953622, 48.90447541645595, 56.180719307490754, 54.036803994859966, 59.77137810843331, 57.394642557416645, 59.189529010227744, 57.263363293239046, 60.9452554157802, 58.221596309116904, 62.62767137799944, 55.74815573011126, 59.21648107256208, 33.62533460344587, 37.89894574029105, 58.94622394016811, 53.14466571807861, 54.16108989715576, 51.73735325677054, 54.32700593130929, 48.64474133082798, 53.29220724105835, 49.76182058879307, 49.66241271155221, 51.9250032561166, 56.66665199824742, 52.46088654654366, 56.46390356336321, 57.99253852026803, 55.435792514256065, 54.247779096875874, 54.34802770614624, 58.41804967607771, 58.15936476843697, 55.76227446964809, 57.435400690351216, 54.66230167661394, 50.41140767506191, 43.526486328669954, 44.924689701625276, 45.272902148110525, 45.13589409419468, 44.43439701625279, 42.91109480176653, 45.43708113261631, 45.88770307813372, 48.75814288003104, 46.57675245829991, 51.019701617104666, 61.07036467960903, 60.68747724805559, 60.18122455051967, 61.74176910945347, 62.09389686584473, 64.87161990574428, 59.72339384896414, 56.80891636439732, 59.63818808964321, 57.97818354197911, 54.64663348879133, 54.62462159565517, 57.714419501168386, 58.86234528677804, 64.9922684260777, 65.64238357543945, 63.51510919843401, 64.78060545240129, 62.47979286738804, 64.67932850973946, 63.687132699149, 73.99810654776437, 38.38925927025931, 0.8682091150965009, 4.522509506770542, 4.421873535428729, 0.7879214318735259, 0.12077210870172296, 1.8814002105167933, 58.43421813419887, 66.17177377428327, 48.498408794403076, 50.31847204480852, 44.34129810333252, 30.589242798941477, 32.348165375845774, 50.48000029155186, 59.23342078072684, 73.34992994580949, 34.18366057532174, 0.9864530158894402, 0.15388758959514753, 0.21133708687765257, 0.09242366879646267, 0.13028820950005734, 0.19696594588458538, 0.16054842860570975, 0.28950548810618265, 0.1441808883100748, 0.1260093269603593, 0.12562634822513374, 0.15560189474906239, 0.148709308888231], [0.0378245207081948, 0.039015302168471475, 0.018716475859816586, 0.03640207042917609, 0.14269286101417883, 0.012610164504232151, 0.13475526337112698, 0.09571879769542388, 0.03374177889366235, 0.026685745821201375, 0.11784869485667773, 0.1133770744449326, 10.970984969820295, 65.15316091264997, 55.733567987169536, 60.5551974432809, 30.591792787824357, 20.25079229899815, 34.69346032823835, 35.97926269258772, 36.30847181592669, 81.86186926705497, 14.70972204208374, 0.10031997758362975, 0.08084119137908731, 0.5238759347370693, 1.510493318949427, 7.530081561633518, 3.870670335633414, 1.309771261044911, 32.49204519816807, 67.60912677219936, 68.16305800846645, 63.517874581473215, 61.175046239580425, 61.17864540645054, 60.13495649610247, 62.900707789829795, 62.501610210963655, 60.28225135803223, 60.37160519191197, 65.29875346592495, 60.23970058986119, 60.63237803322928, 62.0650965826852, 59.9982784816197, 61.43943214416504, 59.041316986083984, 60.38638401031494, 59.05328178405762, 57.192394392830984, 48.70653860909598, 45.56939220428467, 42.76586702891758, 46.5221917288644, 43.41753510066441, 45.67391395568848, 42.14527824946812, 44.04506165640694, 43.99665355682373, 41.35722051348005, 41.27205991744995, 43.12342480250767, 41.102565561022075, 50.99167953218733, 54.68605409349714, 55.25037636075701, 57.626479625701904, 56.857088225228445, 54.49751125063215, 56.92758117403303, 51.85606670379639, 55.19015979766846, 47.29272263390677, 56.02785893848964, 47.127911363329204, 48.336241313389365, 52.34607451302664, 53.79215097427368, 54.560823236192974, 54.97349412100655, 52.05751929964338, 53.72251960209438, 49.78484344482422, 55.974812916346956, 50.37240048817226, 62.5407007762364, 21.257051263536724, 18.651459421430314, 53.90530586242676, 42.966263498578755, 54.792222567967, 47.83231626238142, 49.013013226645334, 43.40487200873238, 48.34756687709263, 42.759394781930105, 45.68601771763393, 44.924040045057026, 52.69978993279593, 51.616020338875906, 50.05552441733224, 50.594885281154085, 48.935638087136404, 46.68124294281006, 46.655350480760845, 49.51990515845162, 53.42312519890921, 49.587729998997276, 52.25732169832502, 52.081462791987825, 47.53462069375174, 42.0861942427499, 40.84041697638375, 40.137314864567344, 40.08118731634957, 39.02606167112078, 42.221103940691265, 39.2312593460083, 41.66718660082136, 41.42509399141584, 42.62602758407593, 42.61761678968157, 51.43137543542044, 53.4392762865339, 53.76319783074515, 56.387723514011924, 53.539587429591585, 53.39352934701102, 52.98870645250593, 53.65298203059605, 52.37543412617275, 49.410842759268625, 46.307429858616416, 48.02706037248884, 52.42161185400826, 55.712316921779085, 58.2509628704616, 57.93264157431466, 59.31587505340576, 60.52221434456961, 58.315591539655415, 55.25548676082066, 61.7695758002145, 58.91170528956822, 63.351909909929546, 6.281379972185407, 1.4934290860380446, 1.1737410575151443, 1.2848447071654456, 0.22459286557776587, 0.16413198917039803, 16.603950364249094, 65.64761556897844, 50.23530558177403, 41.31236294337681, 45.60861825942993, 28.720503943307058, 22.14636857169015, 31.428870064871653, 45.98614168167114, 49.76144191196987, 39.21108872549874, 2.526705686535154, 0.015672052079545598, 0.016137874851535474, 0.058517809957265854, 0.015273551855768477, 0.022021065233275294, 0.02244538880352463, 0.029564778387014354, 0.06467626164002077, 0.029126672074198723, 0.010079664843423026, 0.014717738376930356, 0.02311302994244865, 0.02937505321045007, 0.014710785089326757, 0.07956532841282231, 0.043707181832620075, 0.0863564054348639, 0.04414598364382982, 0.05144569730120046, 0.03462339944339224, 0.0528641645796597, 0.04776600528774517, 0.1763315059776817, 0.21858206311506884, 18.48457063947405, 78.00998251778739, 62.10543782370431, 68.32858494349888, 35.234360218048096, 22.039943013872417, 27.069179432732717, 35.69153778893607, 45.4773667880467, 85.6313920702253, 16.49363555227007, 0.27260893476860865, 0.1347052553402526, 2.2352285385131836, 3.841400614806584, 9.250919325011116, 2.8125450227941786, 2.499311979327883, 35.1634191104344, 72.47406782422746, 70.97111688341413, 67.00732939583915, 62.54070772443499, 65.6419597353254, 63.38790157863072, 65.84704971313477, 65.76800700596401, 62.99604402269636, 64.12406321934291, 66.5020980834961, 62.06169196537563, 62.64675807952881, 65.1409181867327, 61.214303561619346, 63.61006328037807, 62.306713240487234, 61.80965300968715, 62.01947471073696, 60.627632413591655, 51.29816804613386, 46.71094649178641, 46.26401056562151, 47.67025647844587, 46.3979058265686, 48.30805594580514, 46.1457313810076, 45.437810693468364, 45.51854876109532, 43.77476978302002, 43.75456442151751, 45.20288862500872, 43.97754601069859, 51.99841097423008, 55.38428551810128, 57.01587540762765, 59.388956206185476, 58.81999601636614, 55.66859885624477, 58.14683716637747, 54.46518823078701, 55.671704701014924, 50.58246885027204, 53.67759255000523, 48.77388402393886, 49.230102743421284, 52.46156399590628, 56.702942439488, 56.63593053817749, 56.598563126155305, 54.314912591661724, 55.513004371098106, 51.88175071988787, 56.85556656973702, 53.50825105394636, 60.39236640930176, 27.074581657137188, 23.88541235242571, 51.83702516555786, 47.614837646484375, 56.83334623064314, 51.2540990965707, 51.78191900253296, 46.569839000701904, 50.27067191260201, 47.52179779325213, 47.66066101619175, 48.21229239872524, 53.716005665915354, 53.10193429674421, 52.01816470282418, 52.710031577519004, 49.84223556518555, 49.10323905944824, 49.220531599862234, 52.64374228886196, 52.485646452222554, 51.027890069144114, 54.624246392931255, 53.72268288476126, 49.98852988651821, 44.53248820986067, 42.44852542877197, 41.72204957689558, 42.079451016017366, 41.92112936292376, 43.059935637882774, 40.83025871004377, 43.468614782605854, 44.130086762564524, 44.62566007886614, 43.64933047975813, 54.102033683231895, 55.628136021750315, 55.896777697971885, 59.94683401925223, 57.11438349315098, 57.188673632485525, 55.94275392804827, 55.16175208772932, 54.52696813855852, 50.56478221075875, 48.37573834827968, 51.973776136125835, 55.83901732308524, 56.332294259752544, 61.996448380606516, 59.5765506199428, 63.494730131966726, 62.51802880423409, 61.88306072780064, 57.8992589541844, 63.459537506103516, 60.421534946986604, 69.38241822378976, 9.71133475644248, 1.8586053422519138, 1.2992650419473648, 1.966898228440966, 0.3029981298106057, 0.166344054043293, 15.805654457637242, 69.43532875605992, 56.306870801108225, 43.38506964274815, 31.71165132522583, 27.64492280142648, 30.67904131753104, 37.22088841029576, 53.06767620359148, 55.46057326453072, 50.890388693128315, 3.7460821866989136, 0.11392220269356455, 0.11822271692965712, 0.04515595927036234, 0.014268521053184356, 0.05322897553976093, 0.030627214948513677, 0.014562235114031603, 0.02012469895583178, 0.07131752491529499, 0.012966056121513247, 0.07642650684075696, 0.04578074413750853, 0.11374800918357712, 0.1861895884254149, 0.10576109561536993, 0.15734677469091757, 0.23311819668327058, 0.13986058799283846, 0.1958044432103634, 0.14657978101500443, 0.18320396648985998, 0.12376307749322482, 0.3066761695912906, 0.40009697952440804, 22.62505602836609, 89.25828920091901, 70.47810745239258, 77.60464545658657, 42.40653051648821, 30.094763823917933, 44.32545968464443, 50.943201950618196, 50.83830499649048, 96.75387382507324, 18.922195979527064, 0.4473612319145884, 0.16118479945829936, 3.646109334060124, 7.478323561804635, 17.804128340312413, 9.236738920211792, 2.7156688954148973, 37.751873220716206, 73.83423328399658, 74.50544316428048, 69.89282594408307, 67.37469455174038, 68.66264738355363, 64.50519970485142, 68.39064625331334, 66.83616052355084, 66.42450754983085, 65.62634018489292, 67.29938997541154, 65.28539902823312, 67.59124210902623, 70.8659142085484, 64.97778143201555, 67.92622171129499, 64.43413352966309, 66.0028144291469, 64.36832019260952, 62.02645765032087, 53.25806031908308, 51.493162291390554, 47.35619790213448, 49.406468868255615, 47.90687738146101, 49.50349003928048, 46.91138465063912, 46.64220448902675, 47.79434435708182, 45.03132717950003, 45.29232931137085, 46.65840073994228, 43.99504157475063, 55.025195666721885, 59.76655605861119, 60.14824145180838, 61.356505393981934, 60.48446478162493, 57.92050654547555, 60.64116750444685, 58.76913520268032, 56.460227966308594, 53.22419132505144, 58.52947793688093, 47.9857394354684, 50.807149274008616, 53.498110158102854, 57.977085726601736, 58.57855306352888, 58.017413071223665, 56.723623752593994, 59.079073497227256, 53.843821253095356, 58.88333579472133, 55.04572064535958, 64.25617626735142, 26.647765977042063, 25.47124661718096, 54.02851479394095, 48.45082058225359, 58.70332186562674, 53.334660734449116, 54.75591128213065, 47.82958214623587, 52.544709614345, 48.62591518674578, 50.49404607500349, 50.060944012233186, 56.31582702909197, 55.972822257450645, 55.11624138695853, 55.14166137150356, 54.23651606695992, 52.16597720554897, 51.77288981846401, 55.88285003389631, 57.35036516189575, 52.5206549508231, 57.095015389578684, 56.406334263937815, 51.81417601449149, 48.12413018090384, 45.58407374790737, 43.40599414280483, 44.82540341785976, 44.08839757101876, 46.34336246762957, 42.89462757110596, 44.35608386993408, 46.95594344820295, 47.50192941938128, 45.32469054630825, 57.138493742261616, 57.51144872392927, 58.650647572108674, 62.06616660526821, 59.27845900399344, 59.10289192199707, 58.87279537745884, 59.53768239702497, 57.078919887542725, 55.1461638041905, 50.87286186218262, 53.7445627621242, 58.65176623208182, 59.37657451629639, 64.73210702623639, 62.74983460562569, 66.71941689082554, 65.95970085689, 64.19444152287075, 60.53702790396554, 67.54267420087541, 62.539582116263254, 71.1142497743879, 11.69779086112976, 3.4187390889440263, 6.541277774742671, 2.5933538930756703, 0.7264271602034569, 0.22927592428667204, 20.990428039005824, 76.99982561383928, 62.917911529541016, 56.2630033493042, 59.927288736615864, 37.56261471339634, 32.41914469855172, 44.9461943762643, 61.870880535670686, 64.03992748260498, 60.14334297180176, 4.258134024483817, 0.21725699278925145, 0.1774805100368602, 0.11196003548268761, 0.11633903586438724, 0.11590938749057905, 0.13173829311771051, 0.08448349272033998, 0.12245771182434899, 0.16100691471781048, 0.20930723579866545, 0.140139940860016, 0.32698366418480873], [0.05532194394618273, 0.037266941341970644, 0.04051401299823608, 0.05532121452103768, 0.15655751632792608, 0.05326461898429053, 0.07013914028980903, 0.028962819437895502, 0.03502996066319091, 0.00807947592277612, 0.08514462331576006, 0.035996367556176016, 36.358092376164024, 66.2556802204677, 59.78649044036865, 44.920694487435476, 28.148460490362986, 31.406076499394008, 64.07636383601597, 37.30018472671509, 52.80742795126778, 67.36546734401158, 2.603369504213333, 0.025569543841161897, 0.10505786870739289, 1.8355169125965662, 1.5886580560888564, 2.3852460086345673, 3.111283472606114, 6.041870355606079, 46.06963471003941, 71.41882405962262, 63.957591329302105, 65.29391057150704, 61.656132561819895, 63.61054270608084, 62.98310647691999, 64.1737219946725, 65.1149388722011, 62.915757587977815, 57.907086099897114, 67.23493153708321, 63.370225361415315, 64.67647974831718, 59.22247041974749, 59.49083069392613, 58.66827515193394, 57.55617427825928, 60.98403331211635, 59.08270740509033, 58.95980766841343, 51.66367455891201, 45.29690817424229, 44.35350956235613, 45.85177394321987, 43.630591188158306, 45.011444909232004, 44.446813447134836, 44.17102207456316, 44.18480730056763, 40.9464464868818, 40.72585507801601, 41.183814321245464, 45.389711788722444, 53.28627347946167, 54.038450717926025, 52.5543189729963, 54.162378787994385, 54.87247078759329, 53.73980672018868, 52.35859169278826, 54.48874262401036, 56.09682328360421, 54.47481843403408, 49.049373149871826, 52.15006235667637, 50.7835636138916, 49.55080379758562, 54.11341135842459, 53.511495862688335, 53.23346369607108, 47.35080262592861, 49.18122216633388, 47.985312121255056, 54.042188848767964, 50.302352224077495, 57.00114175251552, 16.191338539123535, 16.369455610002788, 49.860755988529746, 42.464478492736816, 51.1898421560015, 48.303049768720356, 53.789948395320344, 47.35233817781721, 49.432406493595664, 47.20395939690726, 48.1355356488909, 44.69580561774117, 49.1513101713998, 48.70745577130999, 53.66627740859985, 50.53422055925642, 47.19174793788365, 44.59623098373413, 44.36884423664638, 44.69949858529227, 48.13789108821324, 48.78877053941999, 51.63842827933175, 50.96466841016497, 48.857887744903564, 46.58754301071167, 39.9254538672311, 38.16882072176252, 41.07748256410871, 41.62858240944998, 39.91358634403774, 40.471689973558696, 40.41825485229492, 40.40068980625698, 42.817971570151194, 39.594910689762656, 48.83018527712141, 53.62982021059309, 52.64876931054251, 54.28329481397356, 52.47296946389334, 52.13331024987357, 49.812323570251465, 48.23704883030483, 46.297466141836985, 46.33531992776053, 48.644109044756206, 54.776609965733115, 56.54775789805821, 56.36988401412964, 58.23085478373936, 58.273853710719514, 58.50916140420096, 58.09633765901838, 55.73036139351981, 53.06308344432286, 56.71541098185948, 59.73252378191267, 67.67018754141671, 37.49768379756382, 0.5346774522747312, 1.3340807280370166, 2.246180202279772, 0.1044098949059844, 0.04388070698561413, 1.5500976166554858, 45.7180940764291, 61.563624245779856, 44.215469700949534, 59.359996114458355, 32.93398536954607, 12.717837657247271, 23.83380287034171, 41.10167619160244, 49.46106433868408, 52.86207205908639, 16.905326741082327, 0.6904146469065121, 0.1709959679948432, 0.015982139190392833, 0.08115314106856074, 0.02218113503684955, 0.04185263027570077, 0.03605092177167535, 0.05932208430022001, 0.03147263904767377, 0.027120425532172834, 0.05688464741355606, 0.06155907854970012, 0.029778944394950355, 0.05027843725734523, 0.056084084657153914, 0.05539561927850757, 0.15379164474351065, 0.046308155836803575, 0.06071384104767016, 0.06447110657713243, 0.050399803423455784, 0.018035148669566427, 0.0787323113264782, 0.03770787714581404, 46.33485439845494, 78.02214186532157, 65.0594436100551, 55.12971741812569, 36.6610928944179, 37.99238164084298, 44.39270435060774, 42.675703729902, 61.214491162981304, 70.9677539552961, 2.8966913989612033, 0.11843656402613435, 0.5122144147753716, 2.965212796415601, 2.448016034705298, 4.543395357472556, 3.03469261101314, 7.871810470308576, 48.5933871950422, 71.30374104636056, 66.19584928240094, 68.45017841884068, 64.0765027999878, 66.39955656869071, 66.13179383959088, 68.75147315434047, 65.77882535117013, 65.70422254289899, 62.109724862234934, 67.16856234414237, 65.01938029697963, 65.88705049242292, 61.21727739061628, 59.9595422744751, 62.19577830178397, 60.93501377105713, 61.30922985076904, 61.99673325674874, 62.80777563367571, 54.409081527165, 48.2776506287711, 46.456784861428396, 46.409620489392964, 45.4943516595023, 47.18773535319737, 46.19075918197632, 45.947846685137065, 44.93878064836775, 43.20531974520002, 43.283090932028635, 43.20949213845389, 47.398168495723176, 56.06922156470162, 56.80523729324341, 56.55477557863508, 56.73121813365391, 55.503624303000315, 56.48583902631487, 55.44614880425589, 56.11840091432844, 58.07653529303414, 57.08153241021292, 51.17556013379778, 52.391866615840364, 51.98161023003714, 53.917479106358115, 54.701183795928955, 56.87364230837141, 54.175215584891184, 50.96446691240583, 51.91203791754586, 52.11234753472464, 55.10749707903181, 54.3297643661499, 53.872340134211946, 21.385829176221574, 22.095231567110332, 47.18183980669294, 45.98836510522025, 50.74650887080601, 52.87645483016968, 56.00004529953003, 51.74992254802159, 50.66733762196132, 51.41874361038208, 50.619137968335835, 47.140355587005615, 51.75776011603219, 51.07629122052874, 54.396446228027344, 52.33067383084978, 49.24606622968401, 48.047276156289236, 46.58328376497541, 46.02570472444807, 48.79469387871878, 52.16620997020176, 53.58886405399868, 53.87256595066616, 51.89303459439959, 48.03516892024449, 41.35998937061855, 41.15597288949149, 41.973581314086914, 43.04981211253575, 42.73781367710659, 42.349784578595845, 42.35015978131975, 42.15161848068237, 45.253273487091064, 42.9854405266898, 49.194892747061594, 53.420939990452354, 53.94112035206386, 54.76550327028547, 55.58914620535714, 54.965323039463584, 50.5817358153207, 51.362338134220664, 48.28220517294747, 50.512340681893484, 51.84269142150879, 55.488866329193115, 59.066254070826936, 58.40023449489048, 60.11369500841413, 61.45954023088728, 60.480087416512625, 59.45961243765694, 57.22837911333357, 56.159169469560894, 59.800400733947754, 61.85939516339983, 69.4865300314767, 46.53018910544259, 0.17745606920548848, 1.6006469556263514, 1.872344536440713, 0.6776032000780106, 0.0627565842920116, 1.162020749279431, 47.162975447518484, 66.3529827935355, 49.03358336857387, 45.49051972797939, 21.312246016093663, 19.971398285457067, 33.977177483694895, 47.64482954570225, 55.10364082881382, 62.288543701171875, 25.904927117483957, 0.6854052671364376, 0.16438866539725236, 0.027757883737129823, 0.10265020254467215, 0.044681361344243796, 0.053111205609249215, 0.04659331017839057, 0.04220612666436604, 0.05036311503499746, 0.018941988669601933, 0.036698159362588606, 0.032545019539871385, 0.21597616294664995, 0.17541126321469033, 0.1281756857143981, 0.17697976476379804, 0.23709074780344963, 0.14199236860232695, 0.1349636007632528, 0.15566326145614895, 0.13041300566068717, 0.054684738495520184, 0.2340622560254165, 0.18788159691861697, 58.37827123914446, 87.45976189204625, 74.30666215079171, 63.48442595345633, 41.74317557471139, 42.85867064339774, 83.42668001992362, 55.20698486055647, 67.82110936301095, 78.2743753705706, 3.5669220175061906, 0.2471536664026124, 0.5239259834800447, 7.329553944723947, 8.820329904556274, 7.930901425225394, 8.621604476656232, 9.56057448046548, 52.78811195918492, 76.20060907091413, 69.40469414847237, 70.55643449510846, 65.87427275521415, 70.205703326634, 69.6942047391619, 71.5492000579834, 70.4148371560233, 65.75298500061035, 63.448003496442524, 67.59910052163261, 67.22819178444999, 68.43991592952183, 65.4499740600586, 65.63933331625802, 64.17641789572579, 62.87035805838448, 64.53005341121128, 66.0391674041748, 64.6864434650966, 56.51456982748849, 50.22820104871477, 49.57713399614607, 50.49855545588902, 47.10594115938459, 49.60221699305943, 48.09318290437971, 48.53127724783761, 45.96940694536482, 45.44961220877511, 47.112694808415, 45.03666339601789, 49.224759578704834, 59.32446302686419, 58.93524578639439, 59.811635971069336, 58.37449141911098, 57.30873155593872, 58.45030321393694, 57.299045767102925, 59.04884883335659, 60.00424698420933, 59.55499035971505, 53.573161125183105, 52.68734918321882, 53.278713839394705, 55.492698260716026, 57.08734457833426, 58.88386385781424, 57.5105037689209, 52.328335762023926, 52.52063410622733, 54.5143015725272, 58.21489477157593, 56.334500312805176, 58.41965470995222, 19.79753872326442, 22.367039884839738, 52.451423100062776, 46.31474978583199, 55.2852771622794, 52.248233454568044, 59.40197018214634, 54.769818101610454, 54.33882829121181, 52.79184314182827, 54.16604396275112, 50.07843610218593, 54.16056530816214, 52.656172616141184, 57.40122250148228, 54.66113437925066, 52.03250231061663, 50.36573716572353, 48.73965719767979, 47.82756716864449, 52.43152693339756, 54.52228157860892, 55.58643988200596, 55.58969511304583, 54.66713414873396, 53.205629212515696, 44.98283917563302, 43.61382171085903, 45.927755968911306, 47.24287278311593, 44.156489917210166, 45.58513682229178, 44.43659264700753, 44.44094221932547, 47.57527807780674, 44.46081059319632, 53.16271366391863, 58.73515851157052, 56.5408479145595, 57.7990277154105, 57.179241452898296, 59.07495321546282, 53.01797226497105, 53.12251138687134, 52.18630763462612, 52.97014781406948, 53.38109901973179, 60.01668425968715, 62.4084209714617, 61.14525236402239, 62.08598286764962, 64.24988119942802, 62.35513523646763, 61.95440483093262, 59.50613757542202, 59.13509682246617, 60.94680486406599, 65.79570947374616, 73.55941118512834, 49.61014836175101, 0.602893780384745, 4.1034184864589145, 5.714487739971705, 0.9397467906985963, 0.09163099061697721, 1.924854461635862, 54.94262327466692, 69.9540604182652, 56.42237070628575, 77.30588681357247, 44.45380333491734, 20.657287972314016, 37.37800802503313, 57.43597739083426, 63.521355628967285, 72.17522580283028, 29.852410657065256, 0.9410880101578576, 0.22426783373313292, 0.10336214862763882, 0.256428100168705, 0.13702580439192907, 0.15534468926489353, 0.17658552234726294, 0.1755916178226471, 0.1911852075053113, 0.07921529255275216, 0.13664117003125803, 0.1979396300656455], [0.055276736550565274, 0.012799105972849896, 0.035537243621157746, 0.014393152669072151, 0.043061358987220695, 0.02952194247128708, 0.10303418551172529, 0.02692783184881721, 0.08906037426952805, 0.019300136415820037, 0.12547791190445423, 1.570965011204992, 40.788173471178325, 60.72308676583426, 57.625381810324534, 42.018345083509175, 19.449918610709055, 21.27941230365208, 43.28867033549717, 38.68390110560826, 72.69617394038609, 35.45221056256975, 0.11445303420935359, 0.019433446494596343, 0.18001297914556094, 2.053160548210144, 1.9137851127556391, 3.1179858786719183, 1.815159016421863, 11.208046214921133, 51.49704286030361, 68.92452498844692, 62.51371397290911, 63.119520459856304, 61.83540998186384, 66.89442116873605, 60.94088499886649, 65.08989061628068, 63.45572294507708, 67.17942932673863, 55.55941833768572, 65.46352304731096, 67.54393182482038, 57.58339384623936, 63.37562411172049, 57.75209958212716, 61.22339180537632, 56.7575865473066, 61.45842851911272, 56.734567165374756, 56.682917731148855, 51.27535016196114, 46.85608046395438, 45.41496501650129, 43.745041915348594, 43.617059571402415, 45.09034170423235, 43.27814381463187, 41.79084369114467, 41.02321713311331, 40.47374664034162, 43.13208225795201, 41.15469789505005, 46.32230595179966, 56.052483354296, 54.01215526035854, 57.38659654344831, 57.00050251824515, 55.28250135694231, 51.7151711327689, 55.832149028778076, 55.58696794509888, 55.917591026851106, 55.4256967817034, 55.181300844464985, 45.60984809058053, 51.56532975605556, 49.03230837413243, 53.911135401044575, 51.7831905228751, 51.96734210423061, 46.06060900006975, 47.010125500815256, 45.858253138405935, 56.201351983206614, 49.275825364249094, 58.60323306492397, 17.734184299196514, 15.041387353624616, 51.366044998168945, 47.968441895076204, 52.24826124736241, 48.784483500889365, 50.4842004776001, 50.57113286427089, 50.64407157897949, 47.68031399590628, 48.482938630240305, 46.299679143088206, 48.05239003045218, 48.83714042391096, 49.719856943402974, 49.571662289755686, 44.7809453691755, 43.212594509124756, 42.02964980261666, 44.084277289254324, 45.339531898498535, 46.330963407244, 48.21768767493111, 48.34838329042707, 50.67521340506417, 49.30877372196743, 40.94773537772042, 39.761396476200645, 39.51566301073347, 41.231673513139995, 40.54933261871338, 41.228717054639546, 39.359332016536165, 42.92537334987095, 42.40732955932617, 41.87577152252197, 43.44501870019095, 50.562951360430034, 50.923410006931846, 51.94172757012503, 50.22659601484026, 47.93411431993757, 46.130018029894146, 44.89829002107893, 45.35859775543213, 48.08786058425903, 49.12389952795846, 53.029620919908794, 54.583832195826936, 58.52831758771624, 58.902623994009836, 57.939457757132395, 58.84494699750628, 55.78253889083862, 50.807378564562114, 51.749457018715994, 54.9186554636274, 59.76173400878906, 60.081948689052034, 66.12873663221086, 5.923548179013388, 4.208066173962184, 1.4719590438263757, 1.0999832153320312, 0.17182078159281186, 0.18516833893954754, 20.993264641080582, 63.73425538199288, 55.41511467524937, 45.83851678030831, 52.85191379274641, 22.839350632258824, 17.519460644040787, 30.501223019191197, 44.34226042883736, 51.43669775554112, 40.70967272349766, 2.0558644831180573, 0.1355804840901068, 0.06288642196782998, 0.06328029119010482, 0.023385293815018873, 0.012064632527264101, 0.05060649876083646, 0.07162798861307756, 0.037262123743338246, 0.027791785042999045, 0.08387104022715773, 0.04375987686216831, 0.01902705490855234, 0.020654083495693545, 0.043775707084153376, 0.029508646577596664, 0.056538265464561324, 0.06116603035479784, 0.04382863620828305, 0.022149449147816216, 0.10848389379680157, 0.0886066582586084, 0.04793854656496218, 2.0742450739656175, 55.01745884759085, 64.88126400538853, 65.11046423230852, 46.17312117985317, 25.856558970042638, 20.668955734797887, 40.43526751654488, 45.05389492852347, 78.61656720297677, 40.98017304284232, 0.0596568463370204, 0.05603736073576978, 1.8383374469620841, 4.709121184689658, 4.322456538677216, 5.492324735437121, 1.2416469965662276, 13.361946088927132, 56.00885214124407, 71.52694497789655, 65.08740316118512, 65.36491421290806, 65.9150447845459, 69.54804243360246, 65.41102940695626, 69.00332450866699, 66.30817386082241, 69.50754833221436, 59.980643953595845, 64.1245287486485, 65.59505244663784, 61.389599663870676, 65.47900363377163, 61.79564544132778, 61.341087341308594, 59.52204895019531, 61.894163949149, 58.746560505458284, 57.21961396081107, 54.963082245418, 47.19223083768572, 45.38807201385498, 46.28866624832153, 45.2799927847726, 47.073572976248606, 45.8937097958156, 44.84279128483364, 43.72162996019636, 43.10225016730172, 44.624770709446494, 43.759921482631135, 49.14806188855852, 58.11476080758231, 57.93918677738735, 59.32609585353306, 59.03020681653704, 57.350900173187256, 54.83692380360195, 57.767198017665315, 57.22176095417568, 58.22932618004935, 55.96361589431763, 56.40153653281075, 48.991223675864084, 52.972871507917134, 53.6480244909014, 54.23365340914045, 53.190450872693745, 53.662521907261436, 49.61049229758126, 47.73431192125593, 49.60456201008388, 58.01319204057966, 53.799349308013916, 58.352729661124094, 22.333563464028494, 20.877971444811138, 52.15689243589129, 53.69494915008545, 52.13991451263428, 50.830370153699604, 52.272493089948384, 53.16370725631714, 52.90986524309431, 50.6080972807748, 50.95298154013497, 49.241560322897776, 50.109230518341064, 50.94155870165144, 51.54256745747158, 51.016734736306326, 47.84898151670183, 45.84919616154262, 44.10877316338675, 46.22493042264666, 46.7172589302063, 48.93772949491228, 50.74494900022234, 52.000238350459504, 51.315562861306326, 51.36774035862514, 42.36732530593872, 40.69452217647007, 40.815323557172505, 42.28181035178048, 42.76215321677071, 43.440547534397666, 41.42626823697771, 44.64642129625593, 43.73516852515084, 43.68348087583269, 45.054912839617046, 50.77484709875924, 52.12295743397304, 54.5873201915196, 51.16044085366385, 52.00357001168387, 48.54802935464041, 47.04159389223371, 47.626010349818635, 49.627529280526296, 52.24835157394409, 56.20214407784598, 58.49425751822335, 60.33928912026541, 59.906451089041575, 59.63367176055908, 60.16422230856759, 58.88027163914272, 53.66154568535941, 55.137909344264436, 57.526262283325195, 62.40569032941546, 61.56973171234131, 71.37496008191789, 9.360028624534607, 4.819134184292384, 1.103518111365182, 2.326279035636357, 0.6235064257468496, 0.3066820592752525, 20.01342793873378, 66.4459844316755, 61.5921049118042, 45.27154377528599, 40.468875953129356, 25.349439484732493, 24.902088403701782, 38.67881155014038, 51.55806194032942, 58.106263160705566, 51.528361865452354, 3.075771446738924, 0.1326191265668188, 0.07756625568228108, 0.03661768510937691, 0.04292296159214207, 0.05426607221098883, 0.07440546993166208, 0.03234027838334441, 0.08198096057666199, 0.07936059404164553, 0.03496345405333808, 0.03543376703081386, 0.14638464791434153, 0.0850725628967796, 0.08345259446650743, 0.13907314810369695, 0.11122072408241884, 0.13656901461737497, 0.2105557130915778, 0.06713029888591596, 0.1882597037724086, 0.19887808470853738, 0.20826189831963607, 2.871842686619077, 71.22873524257115, 76.36351653507778, 77.37308979034424, 56.69830104282924, 30.786998953138077, 29.748767852783203, 60.41433661324637, 52.6355607850211, 87.85414164406913, 44.3008839062282, 0.4275289832481316, 0.1294896959194115, 2.5525043479033878, 9.116740924971444, 5.974154080663409, 9.012097580092293, 8.283080424581255, 15.189710548945836, 61.48381723676409, 74.18502698625836, 68.15312208448137, 66.27792835235596, 69.35136672428676, 72.69545827593122, 68.83466393607003, 68.99891935076032, 69.97134058816093, 70.60764271872384, 64.55693599155971, 66.5814117704119, 65.97096388680595, 63.30370330810547, 67.0871364048549, 63.84427315848214, 66.07611097608293, 62.58416175842285, 65.77376706259591, 61.22197437286377, 61.03130190713065, 57.48677567073277, 50.96988650730678, 47.53184488841465, 48.318387917109895, 47.71047265189034, 49.406923975263325, 48.714080878666465, 47.540738582611084, 44.63392843518938, 45.872326714651926, 47.94660370690482, 45.125739301954, 49.64338506971087, 59.25948347364153, 60.63375377655029, 63.34200872693743, 60.4146214893886, 60.862377302987234, 59.30555003029959, 60.305923870631624, 60.15380001068115, 61.2565347126552, 58.468014172145296, 57.94753851209368, 50.91247354234968, 54.16660329273769, 53.574026175907676, 57.29166678019932, 56.72059433800833, 56.231878893715994, 51.01279163360596, 49.52048880713326, 51.14749983378819, 62.673793520246235, 55.64155994142805, 64.13376985277448, 21.62781408854893, 21.312890461512975, 56.072587966918945, 54.39890589032854, 55.334348814828054, 51.31709841319493, 52.930074078696116, 55.89740998404366, 55.73375906263079, 52.1874679837908, 53.547984327588765, 52.24527352196829, 54.15613235746111, 53.49766199929373, 53.614509854997905, 53.253432818821494, 51.13793911252703, 47.82499633516584, 45.97973196847098, 50.3131879397801, 49.88008935110909, 51.15465300423758, 51.6116429737636, 53.354921681540354, 54.4735677582877, 53.80234398160662, 44.68228094918387, 41.77801036834717, 44.63620049612862, 43.77056959697178, 44.95837456839425, 45.80610343388149, 43.802489621298655, 47.860182012830464, 46.15607377461025, 45.85302809306553, 48.54818221500942, 54.33717114584786, 55.2287084034511, 57.33246660232544, 54.47506856918335, 55.01485327311924, 51.56247752053397, 50.51567929131644, 49.541663442339214, 52.6979729788644, 55.72842632021223, 58.39563478742327, 62.026339530944824, 63.444786480494905, 64.9210285459246, 62.86378506251744, 62.2254957471575, 62.0186687197004, 56.20638247898647, 58.58865574428013, 60.974396160670686, 65.08734062739781, 64.29578099931989, 74.9807277406965, 9.450748647962298, 6.6905837059021, 6.243654293673379, 2.3366681124482835, 1.1081686275345939, 0.28835100148405346, 26.036824771336146, 73.43543447766984, 69.22263744899205, 59.52202115740095, 70.39657034192766, 32.35561384473528, 27.982989140919276, 48.13244717461722, 62.01834215436663, 67.28880786895752, 60.882846696036204, 4.782362580299377, 0.23485570773482323, 0.17433440099869454, 0.14387052639254502, 0.11653944796749524, 0.1505118507359709, 0.17315974831581116, 0.1091372212395072, 0.2123243689004864, 0.1304969268717936, 0.08606500178575516, 0.09391472235854183], [0.07347196859440633, 0.02591996476985514, 0.043002000743789334, 0.045775047836026976, 0.02817120316571423, 0.046180587860622575, 0.027070599009415934, 0.09250264348728315, 0.048531457249607356, 0.04922465201733368, 0.15198036336473056, 4.940278632300241, 57.03951317923409, 61.47605609893799, 63.74132169995989, 41.05955968584333, 22.621500287737163, 53.01756926945278, 48.54575381960188, 45.18888453074864, 77.84321185520717, 12.28064831665584, 0.09005600227309124, 0.04574184033221432, 1.2661041127783912, 1.095649927854538, 1.3328196299927575, 3.034457892179489, 2.9968023470469882, 18.245698520115443, 63.07031331743513, 67.75970813206264, 65.74788502284459, 65.07618876865932, 62.455279622759136, 61.9446565083095, 62.957648277282715, 61.31839452471052, 62.7618202481951, 61.689532552446636, 60.286941392081125, 48.46242407390049, 67.8591090611049, 61.933754784720286, 60.353637150355745, 60.04396983555385, 58.36205414363316, 57.50539336885725, 58.72053255353655, 54.51793200629098, 55.635518482753206, 52.082630089351106, 46.30831227983747, 43.88539900098528, 43.78412900652204, 43.2104058265686, 43.21144805635725, 43.51204102379935, 43.29622997556414, 41.5328813961574, 43.46291378566197, 42.326330934252056, 41.78137329646519, 49.57316310065133, 56.33810642787388, 53.867684841156006, 50.174428939819336, 52.74883031845093, 52.14286402293614, 51.88859816959926, 55.78136464527675, 52.122881003788535, 55.33117001397269, 54.21067224230085, 56.427960532052175, 53.25647612980434, 51.223909173692974, 47.935764517102925, 53.87936476298741, 52.42775406156267, 49.147360120500835, 47.577911445072715, 45.76684611184256, 42.57956845419747, 53.98824650900704, 46.564985683986116, 55.957696029118125, 17.83750401224409, 22.09170535632542, 59.61657919202532, 46.07209089824131, 53.384927477155415, 48.43614598682949, 51.91586637496948, 49.21471248354231, 51.405045236860005, 52.561211585998535, 53.18277658735003, 48.40629652568272, 50.699254172188894, 51.206924302237375, 51.77385561806815, 49.154204096112935, 46.890661648341585, 43.90148408072335, 45.73403671809605, 44.088977745601106, 45.53152104786464, 44.389991079057964, 47.9786696434021, 48.52409628459385, 48.672655718667166, 46.95201424189976, 42.40967457635062, 38.177363531930105, 39.93679680143084, 39.23983689716884, 40.30487414768764, 40.67869070598057, 38.83445814677647, 42.236438614981516, 41.001934800829204, 41.866040570395334, 43.32310560771397, 45.421277454921174, 48.750423431396484, 49.846856117248535, 47.31325456074306, 46.816152640751426, 43.180556365421836, 42.19290120261056, 46.31010838917324, 47.55452380861555, 51.969419615609304, 54.64291967664446, 58.07913391930716, 58.016471590314595, 59.884814398629324, 58.200234072549, 57.231686455862864, 51.61507190976824, 48.332614353724885, 52.479910714285715, 54.31267874581473, 59.5025314603533, 57.34428201402937, 67.08710166386196, 34.12513589859009, 2.5230135875088826, 0.4655400535890034, 1.3835458223308836, 0.10327505865799529, 0.039471576256411414, 2.238264249903815, 51.22939477648054, 60.80807713099888, 43.39790643964495, 40.88887023925781, 27.444467272077286, 25.98202780314854, 33.96929475239345, 37.33687468937465, 48.603736536843435, 48.23417227608817, 16.57924257005964, 0.5841486805251667, 0.15930308614458355, 0.03589915045137916, 0.12297004647552967, 0.09615335866276707, 0.05925685672887734, 0.0681586390627282, 0.033022491061793904, 0.05778884621603148, 0.07524171005934477, 0.03288732349340405, 0.014014636997931769, 0.03528054025290268, 0.03731771272474101, 0.028954157938382456, 0.03345423610880971, 0.06669096781739167, 0.04371777376426118, 0.07592962921730109, 0.028613781024302756, 0.12930664074208054, 0.11631478502282075, 10.856419597353254, 75.26271343231201, 69.7380131312779, 74.8860307421003, 49.85704912458147, 31.00798293522426, 42.923643248421804, 52.98360300064087, 52.19118527003697, 84.13971110752651, 13.572902083396912, 0.2585817431764943, 0.1333095630896943, 2.492619127035141, 2.512071043252945, 4.706639809267862, 2.6317307480743954, 2.819548372711454, 20.027154105050222, 64.45597866603306, 68.47116892678397, 68.03953988211495, 66.95218849182129, 67.62148761749268, 65.96829577854702, 66.25747980390275, 64.83589921678815, 64.98083169119698, 64.30987889426095, 63.0761775970459, 51.73493528366089, 65.53863307407924, 61.21036393301827, 62.88189901624407, 63.62297303336007, 60.507873262677876, 60.889621189662385, 61.16686126164028, 58.426220757620676, 56.53069312231881, 55.397650378090994, 48.36329412460327, 44.53664323261806, 45.81217615944998, 44.83402613231114, 46.14555072784424, 45.40899998801095, 45.13481364931379, 44.45043693270002, 44.12904453277588, 43.96141924176897, 44.219610827309744, 50.542294366019114, 58.60203102656773, 55.70475728171212, 50.76374387741089, 54.78955445970808, 53.62278515951974, 55.967051778520855, 57.23037324632917, 55.02630737849644, 58.377520833696636, 55.36364936828613, 59.191314697265625, 55.100871971675325, 53.89000940322876, 52.41967330660139, 55.39068480900356, 53.775655950818745, 50.155707018715994, 50.443612575531006, 47.77772079195295, 46.64744343076433, 55.95805038724627, 52.55979415348598, 56.08323955535889, 21.031035048621042, 27.68909249986921, 59.15501730782645, 49.52165263039725, 55.10656949451992, 51.34645455224173, 53.18206787109375, 50.440447671072825, 51.15774495261056, 52.944832052503315, 55.149846349443706, 50.95034122467041, 53.32031617845808, 53.84951182774135, 52.52187783377511, 50.66287340436663, 49.005578654153005, 47.46575014931815, 49.0627623285566, 46.36419664110456, 46.27862957545689, 45.57070541381836, 49.63338661193848, 51.033104692186626, 50.62860141481672, 48.43064301354544, 45.30634730202811, 40.583184242248535, 42.91865791593279, 43.23051391329084, 42.166386876787456, 42.96845218113491, 40.933901514325825, 44.91274574824742, 43.22260686329433, 43.85493809836251, 44.34782941000802, 47.987782205854145, 52.078874588012695, 50.55010066713606, 49.92006581170218, 49.41558837890625, 45.81040089470999, 45.77876574652535, 47.16595622471401, 50.309845856257844, 53.858429840632844, 57.25436537606375, 58.868869645254954, 61.46026284354073, 61.773133277893066, 59.71910681043352, 58.38994421277727, 53.02798809323992, 52.00022445406233, 54.830642632075715, 56.447075026375906, 61.743797983442036, 60.44333144596645, 68.21576704297746, 39.16853795732771, 1.6380359722035271, 1.7638466783932276, 1.8574623635837009, 0.5959387421607971, 0.051002732677651305, 1.8079611169440406, 53.82183020455496, 65.4037754876273, 49.47157348905291, 42.44307109287807, 21.600426026753016, 33.183988503047395, 43.80766255514962, 43.1211701120649, 55.67091608047485, 58.300138745989116, 24.065193516867502, 0.6055535290922437, 0.14807429510567868, 0.04151184284793479, 0.1045584940750684, 0.03008675162813493, 0.025045821676030755, 0.06030326629323619, 0.05307402189022728, 0.06154280049460275, 0.10665312489228589, 0.034727035489465506, 0.1345222680164235, 0.14180144241877965, 0.10333398263901472, 0.18272319728774683, 0.10707218133445297, 0.17694492877594062, 0.09275356573717934, 0.19052454509905406, 0.22336383509848798, 0.26764664532882826, 0.35510220964040073, 15.647739274161202, 91.62404659816197, 77.68452194758824, 83.15918827056885, 57.6094982283456, 34.94779566356114, 70.34709221976144, 68.08719757625035, 57.402890069144114, 91.63908944811139, 15.885114056723458, 0.2698229242648397, 0.20158257601516588, 5.0521350758416315, 4.4823979905673434, 7.215248695441654, 10.953683955328804, 6.967050790786743, 24.000015939985, 69.57090200696672, 73.47120380401611, 72.28823130471366, 70.42416163853237, 70.99446977887834, 67.14900316510881, 68.85258334023612, 68.19435269492013, 68.51943111419678, 67.03947871071952, 64.67641026633126, 59.329298973083496, 66.73132610321045, 63.90723078591483, 64.05353900364467, 65.55570479801723, 64.89836352212089, 63.108827182224815, 64.45736135755266, 60.015412739345, 61.169147218976704, 57.81968470982143, 52.37221016202654, 46.82740872246878, 48.56139768872942, 48.13871444974627, 47.32323217391968, 48.01672840118408, 47.34860004697527, 45.52654266357422, 46.423134735652376, 46.34267807006836, 46.225569656917024, 53.97108793258667, 61.52339417593819, 57.095202990940635, 52.30472925731114, 56.323410987854004, 57.251752853393555, 57.170160157339915, 59.385336194719585, 57.144802706582205, 60.15612070901053, 58.773839133126394, 61.054411615644185, 56.39923667907715, 57.09921210152762, 54.95829841068813, 57.973441396440776, 57.79994140352522, 52.854679175785606, 52.32144662312099, 50.842675413404194, 49.381267751966206, 58.468597820826936, 53.06229829788208, 60.077585220336914, 22.535104649407522, 26.357727323259624, 63.21517630985805, 51.42113379069737, 58.797747884477886, 52.41596296855381, 55.84643799918038, 51.877432414463584, 54.11421734946114, 53.95994302204677, 57.824645723615376, 53.77136543818882, 55.40595000130789, 55.73179619652884, 55.40331663404192, 55.1546162877764, 50.969712802342, 49.37824181147984, 50.4955746786935, 48.817146982465474, 47.98746953691755, 49.55429526737758, 53.87736020769392, 53.69510895865304, 53.460739271981375, 52.211376735142295, 46.66581446783883, 42.54960434777396, 45.72052247183663, 45.042854240962434, 44.33075073787144, 46.193990094321116, 43.13690778187343, 46.4918281010219, 44.62247085571289, 46.93509537833077, 46.554320199149, 49.78218923296247, 54.06070579801287, 55.26653092248099, 52.43322229385376, 53.12560680934361, 48.05085447856358, 48.941985266549246, 51.21840272630964, 52.608504499707905, 56.61516237258911, 61.22249548775809, 61.89588015420096, 65.02383409227643, 66.41295269557408, 63.54053265707833, 60.812169619968955, 56.87239163262503, 55.649317605154856, 56.199090344565256, 59.53848838806152, 64.322906766619, 62.84666470118931, 71.18788678305489, 42.86539997373308, 2.4494558317320685, 8.553383588790894, 4.388117449624198, 0.5868767169969422, 0.1373765527137688, 2.818431015525545, 62.4078859601702, 70.43800245012555, 56.83981500353132, 55.45830815179007, 37.37591314315796, 36.09259475980486, 46.90697601863316, 52.25246838160923, 65.2358375276838, 70.49704129355294, 29.76363352366856, 0.7050461417862347, 0.24200467126710073, 0.24583022456083978, 0.2500145328896386, 0.27818983101419037, 0.12564029890511716, 0.21896858380309173, 0.1833544655569962, 0.15860954193132265, 0.17315749557954924, 0.17534582529749188], [0.04384614580443927, 0.05698836488383157, 0.03782068019998925, 0.017050316158149923, 0.055283515115401576, 0.040585612013403854, 0.05131253141111561, 0.08810471197856323, 0.016228554271427647, 0.03396665896954281, 0.24391824858529226, 33.90061180932181, 68.83371203286308, 52.578550815582275, 51.69353791645595, 27.227426392691477, 20.955462966646465, 53.706573486328125, 43.29509047099522, 60.409729957580566, 61.74558367047991, 2.2844797585691725, 0.07390030061027833, 0.14750272434737, 2.101502857037953, 2.52715927362442, 3.9087473324366977, 3.278685118470873, 3.0069999141352515, 27.784871680395945, 62.556980405535015, 63.021842684064595, 64.99623584747314, 62.09500857761928, 64.97783006940568, 63.50317219325474, 61.05584989275251, 61.020865712847026, 61.229137965611045, 60.678055490766255, 61.72050067356655, 51.35793645041329, 44.03786332266671, 55.90135308674404, 58.3043007169451, 61.08553259713309, 60.30574321746826, 58.527421270098, 57.501220975603374, 57.50445883614676, 55.11131511415754, 52.45346587044852, 47.20514753886631, 42.381478786468506, 43.1047237260001, 42.09573411941528, 42.57884236744472, 43.38052552086966, 42.15870564324515, 43.591153212956016, 42.6690126146589, 43.053310530526296, 41.301940645490376, 46.685321535382954, 54.275606632232666, 54.61424446105957, 51.12162126813616, 47.91038274765015, 50.70657409940447, 53.472075257982524, 53.86688232421875, 53.73443923677717, 53.130269050598145, 51.880694593702046, 50.39133432933262, 52.15063558306013, 54.60593441554478, 49.86054406847273, 53.73971291950771, 50.05510752541678, 48.15740857805525, 44.22898047310965, 43.255965164729524, 43.868150097983225, 53.813471521650044, 49.98529897417341, 51.87799869264875, 15.410526037216187, 20.771356548581803, 59.39142976488386, 45.694998264312744, 52.70362533841814, 48.71252795628139, 54.68921552385603, 51.43231691632952, 51.69071694782802, 41.9222480228969, 47.83670404979161, 49.303677218300955, 52.20094401495797, 46.71002932957241, 47.84490639822823, 48.86438431058611, 47.9796701839992, 47.51952920641218, 47.57787670407976, 48.12863956178938, 48.566466399601524, 46.90300512313843, 44.03197125026158, 44.103555066244944, 46.36442245755877, 44.992903641292024, 43.177016258239746, 39.56650297982352, 39.93149880000523, 40.18047360011509, 41.67578847067696, 41.00540542602539, 39.04835844039917, 40.59218215942383, 41.037711075374055, 40.79927669252668, 41.54322031566075, 43.061634472438264, 45.34878689902169, 45.612325123378206, 42.24225425720215, 42.902208055768696, 43.08086708613804, 43.48538078580584, 43.403048106602256, 47.01019845690046, 48.704735551561626, 51.25534977231707, 51.33275270462036, 51.1766232081822, 51.991931779044016, 50.45602553231375, 48.34225150517055, 47.82545491627285, 50.31325394766671, 51.5357790674482, 52.58681917190552, 55.791380473545615, 57.28965875080654, 62.50308322906494, 58.69807597569057, 1.983898081949779, 2.269905912024634, 2.0647002032824924, 1.1981139268193925, 0.18575413179184708, 0.034620118726577075, 24.583582980292185, 66.9984495980399, 53.51397289548601, 45.700101716177805, 49.91638674054827, 20.12235484804426, 15.378797088350568, 37.436056750161306, 43.19206953048706, 47.11717292240688, 41.19187423161098, 3.7463809592383246, 0.25361584393041475, 0.011905958809490715, 0.05216465943625995, 0.04385134677535721, 0.07087232451885939, 0.024156129952254038, 0.023621001613459418, 0.02902327012270689, 0.05898921537612166, 0.052728393115103245, 0.09706898738763162, 0.06276801760707583, 0.041090496350079775, 0.058987580106726716, 0.011928448852683817, 0.018995659093239477, 0.09614533837884665, 0.06978623422660998, 0.05347791646740266, 0.05649593845009804, 0.3716903823826994, 47.38374056134905, 76.53711032867432, 59.656010219029014, 58.77711868286133, 36.21336487361363, 24.79071225438799, 46.283385617392405, 51.97042710440499, 64.94784164428711, 69.45275483812604, 2.136078178882599, 0.05239643342792988, 0.5895848859633718, 3.0427240771906714, 4.793841872896467, 4.0293715340750555, 1.1516162561518806, 3.797500593321664, 31.600646904536656, 66.70135852268764, 66.22391305650983, 67.29073946816581, 64.37077985491071, 68.06649889264787, 65.48891871316093, 63.43967260633196, 62.41183253696987, 64.57895483289445, 62.25421265193394, 62.919155257088796, 55.6263781275068, 45.92723832811628, 55.7396685055324, 61.777573176792686, 62.5203286579677, 62.42343602861677, 59.91038376944405, 59.16436958312988, 59.89771720341274, 58.94581399645124, 55.367484773908345, 48.40947185243879, 44.70030457632882, 44.340693610055105, 43.818557330540244, 44.05574451174055, 44.151525429316926, 42.7945213999067, 45.35474150521414, 43.55009978158133, 46.332127230507986, 42.25507715770176, 48.14931740079607, 57.621813910348074, 54.71510451180594, 53.84949793134417, 50.46356780188424, 52.16029357910156, 55.540797165461946, 56.04952689579555, 56.435214451381135, 54.03531360626221, 56.376835686819895, 52.30733483178275, 55.32346098763602, 56.11348853792463, 54.15693140029907, 54.6595710345677, 52.776421615055625, 50.316175665174214, 46.26332269396101, 43.26391390391758, 47.76074981689453, 54.75078351157052, 53.986568519047324, 52.928837299346924, 16.362971203667776, 27.23967432975769, 57.34815910884312, 50.751400402614046, 53.66399839946202, 52.21308946609497, 55.14694895063128, 53.52796309334891, 52.4723858152117, 41.14248991012573, 48.13162381308419, 50.06472383226667, 54.34800338745117, 49.83845921925136, 49.36452954156058, 50.79450702667236, 50.538549286978586, 50.438509123665945, 50.7290688923427, 50.67344856262207, 50.965884344918386, 49.414907455444336, 46.98741878782, 45.76903826849801, 47.30186298915318, 47.11911841801235, 46.31499992098127, 43.00778940745762, 41.94176551273891, 42.611662183489116, 43.502528939928325, 43.52933856419155, 41.64194032124111, 42.69326530184065, 43.27639981678554, 41.53061628341675, 43.97312000819615, 43.6332870892116, 47.48894323621477, 47.35152871268136, 45.736492906297954, 44.893586090632844, 44.57508066722325, 45.24373013632638, 46.171728066035676, 47.90738459995815, 51.81464501789638, 53.488823890686035, 53.94978822980608, 53.49457005092076, 54.58120230266026, 52.334999084472656, 50.7887921333313, 51.22125496183123, 53.0970253944397, 53.48367527553013, 55.501814297267366, 56.67413520812988, 60.48925903865269, 62.37978049686977, 63.388311522347585, 2.882784362350191, 2.8112834904875075, 1.2706988262278693, 1.8182737635714668, 0.41999672885452, 0.10645027684846095, 25.886566502707346, 71.69958686828613, 60.907262665884836, 45.65228073937552, 39.070648261478965, 27.331725801740372, 22.37822995867048, 46.54896313803536, 49.55987467084612, 54.97770472935268, 49.30613340650286, 5.151103479521615, 0.29221145861915176, 0.05190719610878399, 0.020960167249930755, 0.019054077565670013, 0.12206532859376498, 0.042244402824768, 0.016002532560378313, 0.13243521643536432, 0.06615355451192174, 0.1642687546887568, 0.1400169360318354, 0.1453969587704965, 0.21275734209588595, 0.16604969198150293, 0.17331672060702527, 0.22519486184631074, 0.19856091029942036, 0.16732550066496643, 0.17061738616653851, 0.10368333317871604, 0.5182252579501697, 56.9006256375994, 91.71384511675153, 66.3159349986485, 69.38951233455113, 40.118829182216096, 32.582267556871685, 66.97422817775181, 58.056705134255544, 74.09281744275773, 75.78421742575509, 3.956358560494014, 0.12311047608298914, 0.9625374249049595, 8.275740521294729, 11.273794412612915, 11.435080340930394, 11.798676099096026, 5.372636369296482, 34.71279716491699, 69.26452119009835, 68.52221039363316, 70.0993264062064, 67.23215225764683, 71.47023378099713, 68.43401690891811, 63.96511622837612, 65.23446873256138, 66.73653030395508, 66.59874752589634, 65.1163215637207, 58.77015658787319, 51.27586085455758, 56.932139192308696, 64.1678855078561, 66.65039348602295, 65.8639268875122, 63.10180255344936, 61.95504406520298, 63.56404536111014, 60.6611088344029, 58.157051018306184, 52.19896725245884, 48.587675775800435, 46.504077775137766, 46.22150148664202, 46.29356472832816, 47.62110144751412, 46.235648018973215, 48.4984643799918, 45.92180831091744, 49.51817853110177, 45.33961875098092, 51.416210991995676, 60.69630146026611, 57.78999505724226, 54.71235302516392, 49.30450752803257, 55.12336676461356, 58.712382316589355, 57.93382624217442, 58.04012325831822, 56.48247957229614, 55.47059604099819, 54.97135754993984, 57.23740829740252, 58.2159925869533, 56.685936723436626, 59.560416902814595, 56.43742397853306, 52.83918121882847, 48.691391536167686, 44.81907360894339, 47.95436831883022, 59.2200038092477, 55.57605232511248, 56.50208044052124, 18.051159381866455, 27.68669363430568, 63.55027403150286, 52.00319133486067, 57.505827631269185, 54.57293742043631, 59.96452413286482, 56.57632194246565, 55.76689502171108, 44.00339330945696, 48.517033440726145, 53.91086789539882, 56.03200701304844, 52.93944025039673, 53.22443451200213, 52.76899399076189, 54.77065883363996, 52.22579077311924, 53.51768323353359, 52.775778906685964, 54.23303501946585, 52.038769585745676, 48.26370212009975, 48.11152267456055, 50.64600665228707, 48.40559128352574, 49.52700274331229, 44.8605751991272, 44.85840041296822, 45.361012254442485, 45.69098220552717, 45.36624772208077, 44.19614676066807, 45.24116277694702, 44.46567433220999, 42.865375655038015, 47.577473708561485, 45.769781725747244, 51.189428738185335, 50.67244454792568, 47.74671445574079, 48.52309921809605, 48.77514164788382, 48.96841968808855, 47.62316853659493, 50.44658987862723, 55.24693700245449, 57.96402658735003, 57.790995597839355, 55.912796769823345, 57.755948884146555, 54.26972498212542, 54.425635610307964, 55.2624488558088, 57.820355210985454, 57.23253066199166, 58.69671412876674, 59.07605103084019, 63.69232995169503, 65.49687440054757, 70.08582605634416, 3.073373232569013, 6.2210075088909695, 6.982292098658426, 2.878289746386664, 0.5769470898168427, 0.2230017145297357, 31.559034143175396, 78.41260978153774, 65.70456995282854, 59.54710415431431, 65.78882380894252, 28.045344012124197, 26.78616714477539, 53.91523136411394, 60.560248783656526, 63.55137879507882, 61.32472433362688, 6.136398860386439, 0.5141551877771104, 0.16034885788602488, 0.12885560494448456, 0.2975366014455046, 0.2211263794451952, 0.2356958697949137, 0.10782781150192022, 0.22435480835182325, 0.14579671089138302, 0.28822134701269014], [0.09494364607547011, 0.02976751447256122, 0.05448726784171803, 0.010867671309305089, 0.06678852758237294, 0.020986156837482537, 0.10180609819612332, 0.05823389733476298, 0.19007718696125916, 0.1830796588744436, 6.646232051508767, 68.31591142926897, 65.98989077976772, 39.0461037499564, 57.35958194732666, 53.48830277579171, 36.24116461617606, 76.66629818507603, 40.55842433656965, 77.0148823601859, 33.30167709078108, 0.32390064533267704, 0.03344757289492658, 0.5068612620234489, 1.4814231417008807, 1.6846633787666048, 3.505471497774124, 0.7975669428706169, 7.369919504438128, 48.228005749838694, 59.4076954977853, 61.229457582746235, 62.29479013170515, 68.59491634368896, 62.86585562569754, 64.01375361851284, 62.53819942474365, 62.46125507354736, 55.728311674935476, 59.90629822867257, 57.81727368491036, 61.86643368857247, 50.392341818128315, 47.7695323399135, 58.73715959276472, 59.83562115260533, 60.55257102421352, 59.26746000562395, 59.99491555350167, 58.40570272718157, 56.02437094279698, 55.35681234087263, 49.95530707495553, 43.59669092723301, 42.48815447943551, 42.9490840775626, 43.236399037497385, 42.96992519923619, 42.7880665234157, 42.05180760792324, 43.35813842500959, 43.04423270906721, 41.403537205287385, 42.89963722229004, 52.00592197690691, 55.193519251687185, 54.027611528124126, 55.41576433181763, 53.31666490009853, 54.44764402934483, 53.05011810575213, 53.40489659990583, 53.01499496187483, 50.72009529386248, 54.71091822215489, 51.740327085767476, 47.645065784454346, 50.19068772452218, 53.220849241529194, 49.96369702475411, 48.997063636779785, 43.829448631831575, 41.01698807307652, 43.386292525700156, 51.94461107254028, 49.888076305389404, 51.20470435278756, 16.135902336665563, 21.88643819945199, 54.84201683316912, 45.10660743713379, 46.70930324281965, 44.42840419496809, 51.15608433314732, 51.204040799822124, 55.805394990103586, 44.21360410962786, 38.256159578050884, 43.99432591029576, 46.346148695264546, 46.528823784419465, 64.05039841788155, 50.53312621797834, 52.58434908730643, 52.1399735723223, 52.182169982365195, 49.80354799543108, 49.92562437057495, 50.73785488946097, 49.82895755767822, 49.73362479891096, 46.09716347285679, 44.35846710205078, 41.61647169930594, 39.85610042299543, 40.50795957020351, 41.930808203560964, 40.51756545475551, 40.612022740500315, 38.90635115759713, 39.890566962105886, 42.33415807996477, 40.37377595901489, 42.3189971106393, 41.486255509512766, 42.175836426871165, 41.85932513645717, 40.912032059260774, 40.55895587376186, 41.19486543110439, 41.35691131864275, 42.883176939828054, 42.480924878801616, 44.388260977608816, 44.58660772868565, 45.26852478299822, 44.446003981998985, 44.579134941101074, 43.82964318139212, 44.34826714651925, 45.174401010785786, 46.47544424874442, 51.90769876752581, 55.855369908469065, 54.347353730882915, 60.046019554138184, 58.36267253330776, 69.64283670697893, 18.831018243517192, 1.7239471908126558, 1.136824518442154, 0.9811067027705056, 0.12082887494138309, 0.18460809971605027, 4.479338611875262, 53.107294831957134, 58.974523953029085, 46.205694334847585, 43.79441581453596, 23.381287540708268, 11.341424703598022, 26.940910475594656, 39.85848018101284, 47.545088154929026, 49.6126948765346, 16.757038286754064, 0.3573269902595452, 0.06088954769074917, 0.047776736319065094, 0.02780451944896153, 0.056666043786598105, 0.010259947357034045, 0.02238060058360653, 0.019213417944099222, 0.03310757935313242, 0.05112729813637478, 0.02384940328608666, 0.047055989636906555, 0.03982998863128679, 0.020814312754997184, 0.1193341708609036, 0.020365141232364943, 0.10435572745544569, 0.0779326306656003, 0.24477046142731393, 0.24177201517990657, 8.382501329694476, 81.61378383636475, 72.1526997429984, 50.88635178974697, 60.55434281485421, 63.81400680541992, 38.20888403483799, 73.38895797729492, 49.03637307030814, 82.9905207497733, 37.03813689095633, 0.12740606415484632, 0.03515610371583274, 1.323946237564087, 3.4914812999112264, 4.234619583402361, 1.093204379081726, 1.7849509630884444, 9.596259559903826, 50.55835860116141, 60.83862141200474, 65.21118531908307, 64.46036992754254, 70.06107657296317, 67.16676276070731, 67.4676822934832, 64.14726325443813, 65.69994245256696, 59.16801043919155, 61.57756928035191, 62.074560029166086, 62.68406295776367, 53.547150543757844, 50.78914301736014, 61.43633324759347, 62.845184734889436, 61.51023428780692, 62.302676337105886, 60.46632998330252, 60.68404483795166, 59.20402990068708, 57.311469146183555, 51.83208499635969, 46.100741795131135, 44.729921272822786, 44.818288462502615, 45.66123349325997, 44.66254459108625, 43.94214841297695, 45.09092535291399, 44.376143319266184, 44.88965688432966, 44.703045640672954, 45.06733969279698, 54.62986748559134, 58.47360747201102, 55.10201147624424, 56.77767031533377, 55.70007766996111, 56.039118494306294, 54.8105970791408, 55.303880964006694, 56.053619384765625, 51.34627389907837, 56.51007086890084, 52.62845277786255, 50.7573550088065, 52.522503171648296, 53.72022322246006, 52.76097924368722, 51.33281871250698, 47.35071577344622, 43.476726804460796, 46.44486175264631, 55.07069247109549, 54.9922125680106, 52.02703755242484, 17.469113997050695, 25.83549898011344, 56.582509313310894, 50.13304894311087, 49.419149330684114, 46.9412966455732, 53.21548523221697, 52.99000923974173, 57.205463954380576, 47.559252057756694, 39.991135188511436, 44.57249246324812, 45.8348377091544, 45.87932007653372, 60.18950680324009, 54.12574788502285, 55.57133102416992, 52.297437122889924, 52.962914739336284, 51.94564288003104, 52.21492031642369, 52.08752162115914, 52.19497898646763, 52.12800530024937, 48.33730786187308, 45.8734974861145, 44.61729792186192, 42.147494724818635, 43.45242895398821, 43.45423548562186, 42.446771008627756, 43.767845903124126, 41.17318705150059, 41.04575708934239, 44.5346108845302, 43.27859197344099, 43.57333108357021, 43.159169810158865, 45.17747211456299, 44.710052898951936, 43.77794163567679, 43.60529627118792, 42.512525285993306, 44.082898071834016, 44.83840697152274, 44.2523055757795, 46.69393035343715, 46.82262488773891, 46.98247514452253, 46.524460315704346, 46.621762888772146, 45.37536375863211, 47.27652638299124, 46.163682052067344, 50.13111386980329, 53.65557370867048, 56.16207381657192, 56.567511626652305, 62.28880078451974, 59.832001141139436, 69.07347352164132, 23.78401902743748, 1.140971073082515, 1.8055422753095627, 2.8210986895220618, 0.4117381434355463, 0.1778009007019656, 4.148598713534219, 57.479021481105256, 64.59396989004952, 52.3036835534232, 42.204932008470806, 23.773357016699656, 16.199928249631608, 34.17192506790161, 47.93225220271519, 54.11239692143032, 60.22726331438337, 22.286155905042374, 0.3722679242491722, 0.06934038243655648, 0.015907125447743704, 0.01252705923148564, 0.04373459464737347, 0.06290856256548848, 0.04501437954604626, 0.03730991975005184, 0.04685551307297178, 0.09689943505717175, 0.17642375959881715, 0.14226486826581614, 0.19539976492524147, 0.08965171753828015, 0.17446427260126385, 0.11401717045477458, 0.2739021139485495, 0.16359586508146354, 0.42859838157892227, 0.486320215676512, 10.517152088029043, 92.03107901981899, 82.92182391030448, 59.255481311253135, 71.55956677028111, 64.30110331944057, 50.5965632711138, 93.02690873827252, 54.069252082279746, 90.69637870788574, 42.31892762865339, 0.6339364860739026, 0.13384921556072576, 3.097795933485031, 6.486948072910309, 8.757962005478994, 11.404496107782636, 5.87064893756594, 11.159605979919434, 56.16967861992972, 63.31303473881313, 66.33367374965123, 67.52687399727958, 74.79523168291364, 70.03244999476841, 70.65544632502964, 67.23623085021973, 67.1699241910662, 59.50711032322475, 65.12528473990304, 63.02999986921038, 64.84086717878068, 55.77928713389805, 54.69928346361433, 62.093327113560264, 64.24559416089738, 64.15678228650773, 66.0619227545602, 63.228016580854145, 64.68288598741803, 61.52588857923235, 59.96666417803083, 53.82976852144514, 49.17323521205357, 46.50314671652657, 47.17803566796439, 48.49261747087751, 48.455746855054585, 47.41863094057356, 45.96686043058123, 45.86871017728533, 47.91807787758963, 46.669361523219514, 46.58208172661917, 56.539069175720215, 61.62849957602364, 56.966953141348704, 60.14849853515625, 57.2219694001334, 58.82315049852644, 57.25816256659371, 57.595198835645405, 58.0711087499346, 53.31299277714321, 58.55614512307303, 55.01451628548758, 53.39190346854073, 56.75285134996687, 56.79258462360927, 55.702440057482036, 54.51280770983015, 50.39122315815517, 44.31991502216884, 48.65098776136126, 57.65612064089094, 56.724120548793245, 57.1597170148577, 21.888970817838395, 26.868032557623728, 58.91659682137625, 51.92549657821655, 52.48847436904907, 51.10927084514073, 57.52933686120169, 55.606912749154226, 60.80290767124721, 49.1176426751273, 42.26205314908709, 46.18364422661917, 50.038209506443565, 46.78852660315377, 59.86963258470808, 56.02439873559134, 57.68192972455706, 56.63560397284371, 57.03827639988491, 54.441199575151714, 53.68163292748587, 55.0772203036717, 55.15486294882638, 55.763855184827534, 49.748361928122385, 49.28530270712716, 46.53014394215175, 44.34165940965925, 44.29063878740583, 45.755829742976594, 42.82178613117763, 44.97816998617989, 42.843447140284944, 43.520628997257774, 46.35759237834385, 45.91074330466134, 46.13821690423148, 44.52026285443987, 46.61144481386457, 46.5246513911656, 44.964898926871165, 46.77170501436506, 46.6511607170105, 47.263981410435264, 47.50216565813337, 47.51687152045113, 50.245679242270334, 49.80623000008719, 50.72387858799526, 50.677277020045686, 50.299180371420725, 49.4923277582441, 49.13463796888079, 50.6776556968689, 50.94891684395926, 57.87886599131993, 59.76361697060721, 60.29504993983677, 65.20138835906982, 65.39500686100551, 71.38958603995187, 27.267048495156423, 2.6982471559728896, 8.598379254341125, 4.730513385363987, 0.3315517247787544, 0.18129319830664567, 5.6616367016519815, 65.19905376434326, 70.1256183896746, 60.577014786856516, 57.684490135737825, 32.44526992525373, 21.1956604548863, 40.87486267089844, 58.11239147186279, 61.51414612361363, 69.66734995160783, 29.181492601122173, 0.5571939583335603, 0.17736414128116199, 0.13191754849893705, 0.09259330933647496, 0.13218083365687303, 0.13366607895919255, 0.1538823784462043, 0.1640898928578411, 0.19024482582296642, 0.11400885161544595], [0.12264498748949595, 0.033793188099350245, 0.037751340706433566, 0.059714684662009986, 0.007383231140140976, 0.0074763829720073515, 0.06177080183156899, 0.012010563464303101, 0.1844014586614711, 0.4305274837783405, 22.334857566016062, 69.9470774786813, 53.99008430753435, 40.34460047313145, 53.88643108095442, 41.844893727983745, 36.93037380490984, 51.75118364606585, 45.157096522195, 75.50754015786308, 15.068754570824758, 0.08947610589010374, 0.07173915979053293, 0.3135511949658394, 1.0378414584057671, 3.8357182911464145, 1.27738071339471, 1.334258884191513, 34.9170047215053, 64.38332135336739, 61.015119552612305, 60.737017904009136, 62.488867214747835, 63.238390241350444, 60.81885378701346, 65.47053377968925, 62.77741200583321, 65.57720252445766, 60.358243806021555, 61.23640578133719, 60.079377855573384, 59.01415647779192, 62.181062017168315, 61.15253407614571, 58.65084212166922, 58.01896251950945, 58.29170363289969, 59.312574659075054, 56.51731784003121, 57.233718803950715, 58.242496490478516, 58.805557659694124, 53.53763498578753, 45.96307366234915, 42.642953395843506, 42.682005746024, 41.2271398135594, 41.75207274300711, 41.84882640838623, 44.415539605276926, 43.63092122759138, 45.070792947496685, 41.19192286900112, 40.17714193889073, 43.30723244803292, 49.773743697575156, 51.79866416113717, 51.94188390459333, 52.572488512311665, 53.766901220594136, 51.64133262634277, 51.097820213862825, 49.65477664130074, 47.4321278163365, 50.454382283346995, 47.41906867708479, 51.33354132516043, 51.30669348580496, 51.82991368430001, 51.031329427446636, 48.94897515433175, 42.56726319449288, 40.93081651415144, 43.75235142026629, 53.209829398563926, 51.574911321912495, 50.69112825393677, 14.668376786368233, 19.98837273461478, 53.44755506515503, 47.14994062696184, 45.24757249014718, 38.94622686931065, 44.60638230187552, 48.62480347497122, 54.54487712042672, 55.57923807416643, 52.29648174558367, 51.26183591570173, 38.365486008780344, 42.22127417155674, 48.4123831476484, 47.565342153821675, 53.076750550951274, 51.429346561431885, 52.957453455243794, 49.177904401506694, 49.27304955891201, 51.5034247807094, 52.67491538184029, 50.111075265066965, 49.74147973741804, 46.052490030016216, 42.50984328133719, 39.30802304404122, 40.73404353005545, 39.736949239458355, 40.378604957035606, 40.740581784929546, 40.62390068599156, 41.217919554029194, 43.247665541512625, 40.78366756439209, 41.94915492194039, 41.580469608306885, 40.69246898378645, 41.05921575001308, 42.05263444355556, 41.13002484185355, 43.11480903625488, 43.341709409441265, 43.69972576413836, 43.226688929966514, 43.23658316476004, 43.33056449890137, 43.30772577013288, 42.92868069240025, 43.00010469981602, 44.813376086098806, 43.96021025521414, 47.2546569279262, 48.2573618888855, 53.690210478646414, 54.850545746939524, 60.60618332454136, 59.04056658063616, 64.15274538312639, 60.28403009687151, 55.718622412000386, 12.024830409458705, 4.114155190331595, 3.4460522404738834, 0.38451504707336426, 0.04149172428463187, 0.19730727614036628, 32.367460523332866, 65.4338959285191, 52.74314669200352, 44.993094716753276, 44.36872959136963, 13.43485701084137, 22.778889145169938, 42.65388291222708, 43.51562976837158, 49.46580301012312, 37.92968804495675, 1.8502049701554435, 0.042943314250026426, 0.01999416747795684, 0.0554520360726331, 0.08123310642050845, 0.033883962514145036, 0.01876481299820755, 0.033215032158685584, 0.023189597530290484, 0.06769959655191217, 0.02122778315762324, 0.04299336299300194, 0.01258487465591835, 0.03597584865721209, 0.0891633148172072, 0.01081548263651452, 0.069392833193498, 0.0904309878657971, 0.22015859851879732, 0.3329326521073069, 28.84669712611607, 80.58304636819022, 59.94705636160714, 45.22567176818848, 61.23282745906285, 48.46509565625872, 37.81980228424072, 57.39065776552473, 51.188553265162874, 83.05463872637067, 15.428436756134033, 0.053659811349851746, 0.03863882379872458, 0.7761961839028767, 2.9097746397767748, 2.647663401705878, 0.762794303042548, 2.0242058847631728, 38.64452913829258, 67.43843732561383, 61.95182704925537, 62.54819788251604, 66.58104351588658, 66.27642059326172, 65.94365746634347, 68.41470786503383, 65.63130814688546, 66.62977123260498, 62.824597222464426, 62.53073011125837, 62.82224873134068, 62.298799242292134, 63.679447991507395, 62.792121342250276, 61.342539514814106, 60.00459439413888, 60.772898401532856, 60.59337084633963, 59.105407169886995, 58.94486209324428, 59.38634368351528, 61.24120698656355, 56.078014510018484, 48.99403769629342, 45.795927797045024, 44.91280133383614, 42.264828954424175, 44.19942283630371, 43.54381513595581, 45.912129470280235, 46.12525156566075, 46.25527320589338, 43.90059123720442, 42.12376315253121, 45.490856715611045, 51.81917871747698, 53.89201743262154, 55.43834250313895, 54.425979546138215, 54.949974468776155, 54.71877316066197, 51.286415168217246, 52.76674277441842, 51.365023612976074, 52.74264989580427, 49.910216740199495, 54.33692795889718, 53.92111996241978, 54.3263076373509, 53.056204727717805, 48.67513622556414, 45.175728116716655, 42.567944117954795, 45.880275453839985, 55.57440907614571, 53.51864903313773, 51.70197650364467, 16.89834553854806, 23.790010111672537, 54.2425297328404, 50.7553574017116, 49.039218357631135, 41.43031556265694, 47.034246172223774, 50.28876502173287, 54.76603133337838, 57.13050331388201, 54.741059507642476, 53.01723575592041, 41.88531834738595, 39.46974931444441, 48.95051418031965, 50.509974820273264, 53.12642322267805, 52.73525006430489, 54.33956132616316, 49.71407604217529, 50.62564843041556, 52.853685583387104, 54.579322814941406, 52.71554149900164, 52.437960965292795, 47.94870206287929, 43.80900355747768, 42.0791974067688, 42.49360534123012, 43.9155124936785, 42.295845712934224, 42.89850466591971, 43.174605233328684, 42.332275118146626, 44.30944408689226, 42.91596548897879, 44.81450169427054, 44.61751331601824, 42.84091452189854, 43.62155505589077, 44.56967844281878, 43.38061237335205, 44.94407517569405, 45.63857889175415, 45.404101508004324, 44.52801356996809, 44.426205090114046, 47.13562386376517, 44.94498886380877, 46.09568698065621, 44.865220069885254, 46.357053892953054, 46.28548397336687, 50.86618116923741, 51.598448344639365, 56.4875031198774, 56.675045422145296, 62.236654554094585, 61.96007456098284, 65.97457695007324, 61.689018385750906, 63.858273778642925, 22.316397939409526, 3.649246879986354, 3.9152690853391374, 0.8104339752878461, 0.1413089617022446, 0.1180465149560145, 33.268138136182515, 71.30351175580705, 57.92883743558611, 44.61174283708845, 34.66080379486084, 18.5356833253588, 34.894353594098774, 50.68131044932774, 51.04586158479963, 57.61568212509155, 46.78998225075858, 2.7002108905996596, 0.039789829536208084, 0.02956851032961692, 0.013460354463729476, 0.026541606323527436, 0.0405463825113007, 0.021927386688600694, 0.03908527609226959, 0.07431268705321209, 0.014259925710835626, 0.2056402697094849, 0.25693667573588236, 0.1251366359314748, 0.3829631560615131, 0.16861524645771298, 0.14131557063332625, 0.16872672976127692, 0.22388341650366783, 0.3930891512760094, 0.3772270924278668, 34.93245751517159, 90.63529709407261, 70.66319356645856, 54.623047828674316, 68.49035290309361, 51.58107784816197, 47.430119786943706, 66.86335577283586, 56.491682461329866, 89.61256395067487, 19.065506049564906, 0.24124862040792192, 0.3316156970603125, 3.4878612884453366, 6.192700113568987, 10.830870202609471, 6.6767476711954385, 2.2776377371379306, 43.867747102464946, 68.1888427734375, 63.98907361711775, 64.38026414598737, 69.36608300890241, 69.54367201668876, 67.71142510005406, 71.7131428037371, 66.69949640546525, 68.00233227866036, 64.81902204241071, 65.35925837925502, 66.73254898616246, 64.48097133636475, 66.48080880301339, 64.43622493743896, 64.20325183868408, 62.63375105176653, 62.29994569505964, 62.62330790928432, 61.21765259334019, 62.3782935823713, 61.111213139125276, 63.29625483921596, 57.30071333476475, 50.71143089021955, 47.72255209514073, 47.46050773348127, 45.289727210998535, 45.771480560302734, 46.05069044658116, 47.7925934110369, 48.81985330581665, 49.68786743709019, 47.04028763089861, 44.450294494628906, 47.611502511160715, 55.44533239092146, 56.738965375082834, 56.91720403943743, 57.25531380517142, 57.11295216424124, 56.01622417994908, 53.69437592370169, 53.92006036213466, 52.966552121298655, 56.92065382003784, 54.676246711185996, 57.20968498502459, 56.24903747013637, 58.17798246656145, 57.43549101693289, 52.85331732886178, 47.198324407849995, 44.68596349443708, 47.43923929759434, 58.47013337271554, 59.39051260266985, 54.381775106702534, 21.250143017087662, 27.251437629972184, 57.99239955629621, 54.12807205745152, 49.031082017081125, 42.361884866442, 49.584644998822895, 54.32012026650565, 58.66427298954555, 60.269654273986816, 57.40896279471261, 55.86104311261858, 44.394142627716064, 42.774906635284424, 55.335609912872314, 52.4364914212908, 57.5543851171221, 54.391669341496055, 57.40498842511858, 51.99315118789673, 53.13918358939034, 55.567148208618164, 57.02756575175694, 53.940039907182964, 55.18125568117414, 49.91669940948486, 46.954918588910786, 44.52352850777762, 44.710070269448416, 44.922587871551514, 45.252005440848215, 44.18635674885341, 44.55310698917934, 44.60189723968506, 46.61186865397862, 45.28412348883492, 46.22424602508545, 45.60001291547503, 45.23808472497122, 46.157904624938965, 47.75617095402309, 46.17434058870588, 47.2236818586077, 48.91795144762312, 47.85213252476284, 47.50711972372872, 46.60137687410627, 49.40128551210676, 47.66264820098877, 48.36848095485142, 48.688004289354595, 49.23987191064017, 48.14789302008492, 53.36638968331473, 53.393140247889924, 59.329340662275044, 59.17447921207973, 65.48795986175537, 62.997496196201865, 70.06644753047398, 63.878736223493306, 67.53425298418317, 22.33415232385908, 7.2449661408151895, 8.387483188084193, 1.41579284625394, 0.2544187137058803, 0.3144971270646368, 41.71594558443342, 76.90182822091239, 66.09598282405308, 55.21768161228725, 56.26994112559727, 22.38984908376421, 36.301773752485005, 58.17485925129482, 60.95856816428048, 66.78137397766113, 55.61451060431344, 4.265673688479832, 0.15578466494168552, 0.11025114503822156, 0.19011956825852394, 0.1330053215580327, 0.10979587518210922, 0.09837359309728656, 0.11990072046007429, 0.1109287165371435, 0.2197275116507496], [0.022395063557529023, 0.05660330304609878, 0.03545774985104799, 0.036398497942302904, 0.024426224209102135, 0.07893710676580667, 0.014770343500588621, 0.02725249219552747, 0.0315340702155871, 0.27804647013545036, 39.01443386077881, 70.11764185769218, 54.21038736615862, 34.20884084701538, 20.954097645623342, 46.394004413059776, 54.54193108422415, 50.49842691421509, 59.376150676182334, 68.00295066833496, 5.278733202389308, 0.08004420450223343, 0.06240931006946734, 1.1445551493338175, 1.9003761751311166, 2.1036500675337653, 0.15680995849626406, 26.430982181004115, 72.74826458522251, 63.48259857722691, 68.8857192993164, 63.93598937988281, 64.28762381417411, 65.12741783687046, 62.09293106624058, 57.96107707704817, 61.09289073944092, 60.48982879093715, 61.544405528477256, 61.430079868861604, 59.01368400028774, 58.96708243233817, 61.903516224452424, 58.45774473462786, 60.363267353602815, 56.99371065412249, 58.67967714582171, 57.35071952002389, 59.70901802607945, 57.96749026434762, 59.21905885423933, 57.620844636644634, 57.31780590329851, 49.056995323726106, 42.413471766880576, 43.08047798701695, 41.71944052832467, 41.15076521464756, 41.90043067932129, 42.800083432878765, 44.41423681804112, 45.585168089185444, 42.103703703199116, 41.58152226039341, 40.76388256890433, 41.333530630384175, 45.96435907908848, 51.13180732727051, 52.95086308888027, 50.4852739742824, 51.45163985661098, 50.88089745385306, 50.49879169464111, 50.71653781618391, 50.3818222454616, 50.40564761843, 51.20894970212664, 52.40061092376709, 51.26225628171648, 49.23308004651751, 43.57772581917899, 39.944776807512554, 39.889260700770784, 42.73840774808611, 49.227358204977854, 50.93480157852173, 48.04427106039864, 16.125909090042114, 17.668912921633037, 48.49568510055542, 48.44466100420271, 48.04490682056972, 42.96894550323486, 40.95993641444615, 40.761058126177105, 45.27058144978115, 46.492234570639475, 49.863587379455566, 50.804248401096885, 50.50057738167899, 39.269147872924805, 43.070906843457905, 53.099571909223286, 49.194746834891184, 51.42177997316633, 47.66735560553414, 49.13818849836077, 50.93744189398629, 50.153264726911274, 50.52851261411394, 51.72784117289952, 50.44187205178397, 46.00238309587751, 38.86163255146572, 38.00723688943045, 41.63638176236834, 41.84578309740339, 41.84806905473982, 40.390243189675466, 40.363666330065044, 39.46558734348842, 42.64643096923828, 41.73101275307791, 42.537778513772146, 41.35714060919625, 41.92760508401053, 39.76820223672049, 40.87386907849993, 42.168238571711946, 41.33207150868007, 40.99331208637783, 41.529678276606965, 38.343755517687114, 41.957725524902344, 40.449615546635215, 42.7022944859096, 42.09243025098528, 43.306353500911165, 44.3330888066973, 48.30130229677473, 50.417397022247314, 53.193546295166016, 53.11442715781075, 59.30902412959507, 57.469415596553254, 61.06618881225586, 57.89686529976981, 64.19652598244804, 61.05645438602993, 68.74746404375348, 3.0756965364728654, 5.053551639829363, 1.2608071970088142, 0.14519003273120948, 0.08459696413150855, 10.672075203486852, 62.462088857378276, 56.0831527028765, 52.16506699153355, 55.36428165435791, 25.71163170678275, 4.809468371527536, 25.640070472444805, 49.40618746621268, 43.68697234562465, 55.09734576089041, 12.043090275355748, 0.20732497716588633, 0.07113896163978747, 0.039774657493191104, 0.046912574475365024, 0.07076436281204224, 0.07906980107405356, 0.00862314277661166, 0.11944543703326158, 0.08005797876311199, 0.036444855454776964, 0.04946409345471433, 0.07029435517532484, 0.026944788438933234, 0.06598237369741712, 0.0854976854420134, 0.0341556784696877, 0.06965691223740578, 0.027106091479903886, 0.2960274581398283, 50.57001073019845, 77.3254668372018, 64.3922428403582, 43.29079301016671, 33.1916697365897, 42.0466867855617, 47.4442697933742, 57.102491651262554, 64.40354755946568, 75.47739887237549, 4.646712030683245, 0.10102112138909952, 0.20211272899593624, 2.0580905122416358, 3.367742568254471, 0.7833485401102475, 0.30894027810011593, 30.9368577003479, 76.93589523860386, 66.05740642547607, 70.69826112474713, 63.87909058162144, 65.07459763118199, 67.09104129246303, 64.66694681985038, 60.702818870544434, 62.34313569750105, 64.18583270481655, 63.1351261138916, 63.707025391714915, 60.98638875143868, 61.577729088919504, 63.038587842668804, 61.79012162344796, 61.43843855176653, 58.97899859292166, 60.42956706455776, 60.14821365901402, 61.35822854723249, 59.48366710117885, 59.969874245779856, 58.070994104657856, 60.189208030700684, 50.64585379191807, 43.921442781175884, 44.94134105954851, 44.753527777535574, 45.459746156420024, 42.61709220068795, 45.25381892068045, 45.24960483823504, 46.99022586005074, 45.118909222739084, 42.210521834237234, 41.89936760493687, 44.18488025665283, 46.97379337038313, 52.52401440484183, 55.47363240378243, 53.39858416148594, 53.10707943780081, 53.20101908275059, 53.87728030341012, 53.29615729195731, 52.371108872549875, 54.73287452970232, 54.77771472930908, 54.865064007895334, 53.0594391141619, 50.85932329722813, 45.092523438589915, 43.29911347797939, 41.81642001015799, 45.21316501072475, 50.25098419189453, 52.92411599840437, 50.215204443250386, 18.91166251046317, 19.915783166885376, 50.060162339891704, 51.959789412362234, 49.56096206392561, 45.74872520991734, 41.81980378287179, 43.02883897508894, 47.89313037054879, 50.26251820155552, 51.728473458971294, 53.18624721254621, 52.5361007962908, 44.64322165080479, 46.37270818437849, 54.95832967758179, 52.416744640895296, 52.79603637967791, 52.31226110458374, 50.73219905580793, 53.0107113974435, 52.68643202100481, 51.59208379473005, 54.11667701176235, 54.02467244012015, 47.23611913408552, 42.07486867904663, 41.44215529305594, 42.27439314978463, 43.3069406236921, 44.214166913713726, 43.89815936769758, 43.09445081438337, 41.730168546949116, 43.27226563862392, 43.08471986225673, 44.359592710222515, 43.713667324611116, 44.91304104668753, 42.30307183946882, 44.1049690246582, 42.94708299636841, 44.43554694311959, 44.16575186593192, 44.420604842049734, 41.641318457467214, 44.40809808458601, 42.31383807318551, 45.38486542020525, 43.65983963012695, 45.65722785677229, 47.08823367527553, 50.42142697743007, 52.52655744552612, 55.33021116256714, 54.489503451756065, 60.651589802333284, 60.106989996773855, 64.19638007027763, 61.05268151419503, 66.87151990618024, 62.347172600882395, 72.81275081634521, 6.336982062884739, 3.988651616232736, 1.5783575688089644, 0.15759207867085934, 0.1863315108099154, 10.945207153047834, 65.1488321849278, 63.14121273585728, 54.94997794287545, 48.439529759543284, 25.47785609109061, 13.950475880077907, 36.587567056928364, 56.0560998916626, 49.95837470463344, 64.1186158316476, 16.4069550377982, 0.23403639027050563, 0.16057657423828328, 0.13407944249255316, 0.07021153997629881, 0.020473243735198463, 0.061484887530761104, 0.01243867410812527, 0.063927525388343, 0.01913642118285809, 0.14331665182752268, 0.12232100058879171, 0.1830511332622596, 0.18500912748277187, 0.11320215490247522, 0.13480311366064207, 0.10188082525772707, 0.21379725129476615, 0.12227796789790903, 0.49216348784310476, 61.58237048557827, 89.15959698813302, 71.72875540597099, 50.841105120522634, 32.18348264694214, 53.95078182220459, 71.13722051892961, 66.8481114251273, 70.93502793993268, 80.30787685939244, 6.457538953849247, 0.18790268578699656, 0.4011050925723144, 4.154722247804914, 8.868193439074926, 9.918008055005755, 1.5339517401797431, 33.502240317208425, 80.40946647099086, 67.35863031659807, 75.8186388015747, 65.18237808772496, 69.17116519383022, 69.70375851222447, 68.26336915152413, 63.765397208077566, 65.60227162497384, 68.28408867972237, 66.3931016921997, 65.6750887462071, 63.51057202475411, 63.5953608921596, 68.04024859837124, 64.30636310577393, 64.49262346540178, 61.30048206874302, 62.73179708208357, 61.379093987601145, 63.252856390816824, 60.2994064603533, 63.52848448072161, 61.34398474012102, 63.720282554626465, 52.03740773882185, 46.023651531764436, 47.51650674002511, 45.73489482062203, 46.006037848336355, 44.605666637420654, 47.05270406178066, 47.96039240700858, 49.18500893456595, 47.29914624350411, 46.04069546290806, 43.8791560445513, 45.51951456069946, 47.72247913905552, 55.685264110565186, 57.29484558105469, 55.004163469587056, 55.81160320554461, 55.65063081468855, 56.153812408447266, 55.65169388907296, 57.23683854511806, 55.74324335370745, 58.13539695739746, 58.59507587977818, 56.97081633976528, 55.590250968933105, 49.48569222858974, 46.40466294969831, 45.213752133505686, 46.725760051182334, 54.147690296173096, 55.43359340940203, 52.96959890638079, 23.42206825528826, 23.720298835209437, 53.408200468335835, 55.04012387139456, 51.35199574061802, 47.24112531117031, 44.45807647705078, 46.03303854806082, 50.92417083467756, 52.143478938511436, 53.597340856279644, 57.34797845567976, 54.54820530755179, 48.12764596939087, 49.30888141904558, 55.71140670776367, 54.24874837057931, 55.731886523110525, 53.526048864637104, 54.324897153036936, 56.34375531332833, 54.870577403477256, 54.41594287327358, 56.32495696204049, 55.55147654669625, 50.07244675500052, 44.52115569795881, 43.259883948734824, 45.38616473334176, 45.3248017174857, 45.571379389081685, 46.761032581329346, 44.37949929918562, 42.274629388536724, 48.078643798828125, 45.20009544917515, 45.6260860306876, 46.00264712742397, 47.25148854936872, 44.33415535518101, 45.86983578545706, 45.431661537715364, 46.71426773071289, 46.16308798108782, 47.650047642844065, 42.928368023463655, 46.68687445776803, 45.52789756229946, 48.91826411655971, 46.6705253464835, 47.98409618650164, 50.609841278621126, 54.140168871198384, 55.07148803983416, 57.766298225947786, 57.0711795943124, 64.36105237688336, 61.88338034493582, 67.3859645298549, 63.508751596723286, 71.48741667611259, 64.5436440876552, 78.99601527622768, 5.818009385040828, 8.335999642099653, 6.290010503360203, 0.2610414597604956, 0.23458795781646455, 14.271776216370718, 71.82088851928711, 66.94216224125454, 66.17963913508824, 69.00114972250802, 34.75420495441982, 11.759200777326312, 38.973953655787874, 64.66987895965576, 57.334151540483745, 72.86362552642822, 21.372994116374425, 0.45064859837293625, 0.3640653043985367, 0.1613471864589623, 0.17911630868911743, 0.15141097748918192, 0.20851085281797818, 0.11477619329733507, 0.2007270519222532, 0.1756257481340851], [0.006502898110608969, 0.031458298210054636, 0.08828950420554195, 0.0439385045985026, 0.035705927426793745, 0.08185005081551415, 0.02647834820007639, 0.1480732365910496, 0.06987411808222532, 4.308640045779092, 52.956765583583284, 58.57929652077811, 46.597753388541086, 26.428468670163834, 18.355546065739222, 40.47194358280727, 53.29398945399693, 42.34158917835781, 68.2234239578247, 47.412961210523335, 0.7777753791638783, 0.1450154185295105, 0.1418147145637444, 0.15592383247401032, 1.2652607751744134, 0.8363985248974392, 7.755414247512817, 69.33372524806431, 63.8045711517334, 64.1043928691319, 63.94285420009068, 65.95311396462577, 60.684399196079795, 60.12191472734724, 60.77503844669887, 61.37885774884905, 55.851399012974326, 55.02175978251866, 50.96527290344238, 53.47944382258824, 55.702328886304585, 53.90241888591221, 55.75601414271763, 56.244458607264924, 55.517996651785715, 57.21512542452131, 57.572947229657856, 57.28861652101789, 57.47722537176949, 57.27758625575474, 54.99588121686663, 53.417153222220286, 58.59383910042899, 46.795443534851074, 40.786328724452424, 41.63206345694405, 42.32641083853585, 39.96560055868966, 40.75510351998465, 44.523379121507915, 43.77371713093349, 44.87091064453125, 43.03368534360613, 41.99717044830322, 39.31984192984444, 40.53149311883109, 41.011863776615684, 42.46912336349487, 44.9595661844526, 47.558515548706055, 50.96772561754499, 48.96613025665283, 50.12732710157122, 53.46194478443691, 51.12276424680437, 51.008886745997835, 51.26829079219273, 48.892864976610454, 44.170452322278706, 43.04315226418631, 39.05163451603481, 39.81936877114432, 43.81915487561907, 49.33187300818307, 48.87666525159563, 51.59212548392159, 44.74683666229248, 15.303421292986188, 18.93114525931222, 43.49214833123343, 50.79798807416643, 48.458206517355784, 47.9898110798427, 42.910087312970845, 37.981754371098106, 39.03847115380423, 46.68248667035784, 49.79430341720581, 50.80409901482718, 48.22033493859427, 52.66236693518502, 51.61109059197562, 47.07463952473232, 53.45915160860334, 51.777156012398855, 50.86107076917376, 49.90948370524815, 47.50587599618094, 50.53101396560669, 51.62905863353184, 50.923580237797324, 50.39807755606515, 43.742120197841096, 39.60744524002075, 38.00140735081264, 38.83079644611904, 42.17052105494908, 40.22424725123814, 40.14438813073294, 40.67310088021414, 39.53583710534232, 41.020920753479004, 42.05978413990566, 44.64093916756766, 42.185560430799214, 41.55638367789132, 41.44146742139544, 41.214702538081575, 40.89245898383004, 41.010699953351704, 40.27556664603097, 40.83348267418997, 41.58827590942383, 41.86795479910714, 42.34300661087036, 40.790702615465435, 40.45135607038225, 47.45238528932844, 45.57154614584786, 47.365633555821006, 51.6287841796875, 52.48517050061907, 55.81824915749686, 56.73758615766253, 56.42453159604754, 61.80989619663784, 61.238691738673616, 64.45260878971645, 58.84252207619803, 67.51927266802106, 45.26296622412545, 1.0035554638930728, 3.7603485754558017, 0.559985559965883, 0.052248465296413214, 0.8080431978617395, 45.237393379211426, 63.715224266052246, 51.178256034851074, 47.345251015254426, 45.99569892883301, 15.363121952329363, 15.651164736066546, 33.0295786857605, 43.650907720838276, 48.98449781962803, 28.80227381842477, 0.6877495242016656, 0.014137880161537655, 0.04546162911823817, 0.0691606860075678, 0.022739842467542206, 0.0249823667774243, 0.04385658506570118, 0.0803411246410438, 0.07673667876848153, 0.026954408369160125, 0.037607403072927675, 0.09433469482298408, 0.07264485476272446, 0.11342569826436893, 0.09123195095786027, 0.027564150114942874, 0.08384507947734424, 0.1467032336762973, 4.991939791611262, 69.78417696271623, 64.46876335144043, 54.524789878300254, 31.998021330152238, 24.07597017288208, 40.81081417628697, 49.73189122336251, 50.220742157527376, 73.98978955405099, 50.988643169403076, 0.7737198567816189, 0.12058747932314873, 0.319295129605702, 1.3795927315950394, 1.5930709221533366, 0.47396914128746304, 8.867053065981183, 75.06792763301304, 67.41368089403424, 67.90967110225132, 67.00587722233364, 67.14464664459229, 62.089040075029644, 63.410976546151296, 62.9556610924857, 62.16334411076137, 57.56427935191563, 57.8216267313276, 55.062267780303955, 55.07070289339338, 59.41131550925118, 56.646241664886475, 57.48577513013567, 59.47735118865967, 57.44951248168945, 58.014421871730256, 59.66381304604666, 58.68064294542585, 59.27570751735142, 60.63992377689907, 57.87744508470808, 57.088772433144705, 60.11414664132254, 49.524376324244905, 42.34930167879377, 44.290141991206575, 44.70300742558071, 43.069114208221436, 43.82784707205636, 47.80637516294207, 46.12864923477173, 47.11138159888131, 45.23056329999651, 44.86681815556118, 41.34109721864973, 41.78541019984654, 41.55283314841134, 42.864861488342285, 46.9042557988848, 49.95329557146345, 52.08982842309134, 51.537557806287495, 51.819672039576936, 54.58373492104666, 55.02292707988194, 53.8716835294451, 51.7019556590489, 51.05132286889212, 46.20335626602173, 45.67912857873099, 40.66766044071743, 41.15191861561367, 45.378136089869905, 51.15891224997384, 50.54120349884033, 54.7634083884103, 47.84671292986189, 19.37823404584612, 21.461250134876796, 45.38294076919556, 53.481698513031006, 52.673365933554514, 51.534048965999055, 44.09638105119978, 41.234265191214426, 41.93071092878069, 47.62986660003662, 51.75449793679373, 51.901469707489014, 51.5197183064052, 54.73398624147688, 52.42247690473284, 50.10292502811977, 53.07432215554373, 52.79126991544451, 52.29473427363804, 51.348233291081016, 50.72390638078962, 51.252028533390586, 52.13235834666661, 54.128961426871165, 51.636489731924875, 45.102952684674946, 41.153047697884695, 39.51235219410488, 40.6615321295602, 44.93337147576468, 41.015535899571006, 43.077097688402446, 42.297450746808735, 41.51341254370553, 42.67405700683594, 44.70774609701974, 44.91424308504377, 43.518103327069966, 42.51187562942505, 43.20405517305647, 43.47300951821463, 42.911192076546804, 43.4336062840053, 42.82118163790022, 44.40383883884975, 43.719910281045095, 43.85604286193848, 45.62573167255947, 41.822367668151855, 42.611603123801096, 50.542697361537385, 47.935010637555806, 51.314002990722656, 54.04587139402117, 54.45849364144461, 57.30324942725045, 58.80817018236433, 59.5341249193464, 63.841674532209126, 64.17861352648053, 64.822023664202, 61.795735767909456, 68.34295381818498, 53.9214882169451, 0.29069656133651733, 3.8011992062841142, 0.6752435266971588, 0.044798473095787425, 0.5114723688789776, 46.322434493473594, 69.28444862365723, 55.581965242113384, 48.667246546064106, 38.41979660306658, 17.761546305247716, 25.401052440915787, 42.00968415396554, 49.952680655888145, 56.799428599221365, 35.34143890653338, 0.8486960764442171, 0.06993874854275159, 0.03561110894328781, 0.08298588450998068, 0.043789026726569445, 0.04303273498745901, 0.0671473979683859, 0.022795065040034906, 0.055361319333314896, 0.11134971358946391, 0.09295918898923056, 0.20736450861607278, 0.15983151564640657, 0.14650450434003556, 0.2129074883248125, 0.1936253144272736, 0.3540039600006172, 0.3019272929855755, 7.993691427367074, 86.48300497872489, 73.3903476170131, 67.16292040688651, 39.4838923726763, 27.618816682270594, 48.99375976834978, 71.49915218353271, 55.2102644102914, 80.44730636051723, 56.90791777202061, 1.2433895830597197, 0.22913685174924986, 0.6729049693260873, 1.9450259506702423, 6.5606571691376825, 4.368861820016589, 10.753174577440534, 76.71157959529332, 70.74568258013043, 71.75390093667167, 70.5053791318621, 70.42949090685163, 63.76723848070417, 64.23638084956578, 67.69881411961147, 64.58795969826835, 60.38635621752058, 59.93315996442522, 56.63441235678536, 58.69144739423479, 61.92693860190255, 58.818008831569124, 60.305659839085166, 61.580327715192524, 61.83249173845564, 60.954913411821636, 62.81928879874093, 61.52541610172817, 62.92133699144636, 61.38882146562849, 61.709202902657644, 59.31644480569022, 63.20646326882498, 51.62062699454171, 45.60116284234183, 45.06431027821132, 47.14207179205758, 44.493494919368196, 44.53767156600952, 50.59075805119106, 49.338501589638845, 49.92715644836426, 48.028390952519004, 46.01813466208321, 43.22716488157, 44.75793988364083, 45.34800522668021, 46.28287492479597, 48.592470032828196, 50.90811007363455, 53.8493971824646, 54.241063662937705, 56.050353731427876, 57.98613575526646, 56.63017395564488, 56.28399385724749, 55.54913847787039, 54.40834501811436, 48.31331920623779, 48.23441546303885, 43.43310601370675, 44.12454557418823, 48.415106841496055, 53.3536571093968, 54.417412417275564, 58.08425126756941, 50.61683464050293, 23.33492394856044, 24.80760853631156, 49.08026484080723, 57.29459197180611, 53.96378884996687, 53.237938335963655, 46.81851155417306, 43.601391383579795, 44.50164515631539, 49.9235850742885, 54.199002742767334, 55.51721845354353, 53.42948974881853, 57.01209906169346, 54.43111079079764, 53.36244658061436, 56.908977372305735, 56.986540113176616, 55.46798004422869, 54.84964942932129, 52.26370014463152, 54.438739912850515, 53.444883482796804, 55.752567836216514, 53.98606824874878, 47.95806476048061, 45.02871813092913, 43.12348733629499, 42.7611665725708, 46.84637383052281, 43.28261498042515, 44.16051639829363, 45.8047068459647, 44.69402687890189, 45.0527206829616, 46.69072723388672, 49.08377020699637, 46.90462752750942, 45.49144731249128, 44.584075110299246, 46.37765530177525, 44.524049622671946, 44.995995589665, 44.64539991106306, 47.92392826080322, 46.622610569000244, 48.531388419015066, 48.82967458452497, 45.334042821611675, 46.371196951184956, 54.86035312925066, 51.22792523247855, 52.17226185117449, 56.948095730372835, 57.47408478600638, 61.13027899605887, 60.94611004420689, 62.734736170087544, 66.06420176369804, 67.21023069109235, 68.0709387915475, 66.00744887760708, 71.60778032030377, 54.00298711231777, 1.2908366599253245, 10.822146739278521, 1.5211236285311835, 0.18928024758185658, 1.260486277086394, 54.74030910219465, 75.14580304282052, 63.19114249093192, 60.57654925755092, 58.32391548156738, 22.898954016821726, 25.471189294542583, 49.4708890914917, 59.018797874450684, 66.36675412314278, 45.56794350487845, 1.3386107363871165, 0.17650150614125387, 0.13120581954717636, 0.21478365122207574, 0.10435281654021569, 0.1077830417613898, 0.09172285068780184, 0.12324326538613864, 0.20515483218644345], [0.06611875245081526, 0.02372956382376807, 0.04263749512444649, 0.06264788298202412, 0.013990496418305805, 0.04851339804008603, 0.04584500479644962, 0.08501480599599225, 0.18768199905753136, 11.95943570137024, 64.75573784964425, 56.54771620886666, 50.249511173793245, 36.0570512499128, 17.20931737763541, 19.79366683959961, 46.852571623665945, 52.60940776552473, 76.22030026572091, 27.43140118462699, 0.05237718338945082, 0.10925337964934961, 0.0727494645065495, 1.3536395813737596, 1.6418078669479914, 0.09145499220384018, 45.056483132498606, 75.25786358969552, 61.3882725579398, 64.44094276428223, 64.4298186983381, 63.04903098515102, 62.59571661267962, 63.34954752240862, 57.75927012307303, 59.448175702776226, 56.794102805001394, 55.30177913393293, 50.507643699645996, 47.878087520599365, 44.20952899115426, 44.98265504837036, 44.03379167829241, 45.64703484943935, 47.691267830984934, 47.14734547478812, 48.68165363584246, 48.99094922201974, 53.94724866322109, 57.83088173185076, 57.97253465652466, 58.98701681409563, 52.78764295578003, 43.44346925190517, 41.17991290773664, 42.89384937286377, 41.96694231033325, 43.11004952022007, 39.69726807730538, 44.08912713187081, 43.809524672372, 45.62081234795706, 42.76726361683437, 40.99641098294939, 40.05179991040911, 40.38082838058472, 39.62729971749442, 42.572679315294536, 43.32452998842512, 45.91889006750924, 47.50869696480887, 47.56243085861206, 47.805360725947786, 49.12851660592215, 46.6724465233939, 46.67317608424595, 42.47416080747332, 40.118700640542166, 38.612049783979145, 41.427727358681814, 40.16196012496948, 41.87356546946934, 47.638718605041504, 51.624782017299104, 47.45730808803013, 52.82300928660801, 38.9398102079119, 16.29726903779166, 20.95512424196516, 35.31600502559117, 51.384721755981445, 49.54479360580444, 51.814561639513286, 47.27389996392386, 41.3747820854187, 37.30665002550398, 40.02254452024187, 44.044318199157715, 47.999639306749614, 47.7742223739624, 48.80579015186855, 45.49406678336007, 49.8136055128915, 47.252117361341206, 52.36398002079555, 46.938958576747346, 51.41123955590384, 51.0005384853908, 52.91022307532174, 49.38735784803118, 50.0334221976144, 44.68497337613787, 37.70431627546038, 36.31582301003592, 38.216329029628206, 39.148829392024446, 42.32835633414132, 41.59445285797119, 41.86971269335066, 41.81965787070138, 39.67932782854353, 37.952787331172395, 45.718316418784006, 41.3883866582598, 42.297579288482666, 40.059248379298616, 42.594510555267334, 41.50575910295759, 42.460438115256174, 40.74319430759975, 41.787456444331575, 39.341864245278494, 40.039876801627024, 40.19206319536482, 42.345796312604634, 41.95298685346331, 44.085170132773264, 45.88818597793579, 47.32092884608677, 47.36659240722656, 52.64620542526245, 49.130173751286094, 55.705775192805696, 54.95928852898734, 61.70189339773995, 58.62590503692627, 60.855943271092, 51.29658038275582, 65.01572554452079, 57.179241452898296, 73.36070660182408, 13.899034023284912, 2.5846480173724036, 1.2854772103684289, 0.04252982858036246, 0.05344431880595429, 15.280632938657488, 66.69567489624023, 54.89400325502668, 55.1924283845084, 58.80448068891253, 37.26142072677612, 11.19576006276267, 17.546739271708898, 38.41430752617972, 47.32669585091727, 43.640478474753245, 2.311143687793187, 0.125634762059365, 0.025789183930360844, 0.029730161119784628, 0.05076650071090885, 0.05140080203169158, 0.029664119306419576, 0.07522318605333567, 0.0453187398213361, 0.02217950824914234, 0.024978716259023974, 0.02228032158953803, 0.07467900096837964, 0.07064403141183512, 0.20734078703182085, 0.0396501564952944, 0.266372519412211, 0.2835696366216455, 15.50160997254508, 79.46605396270752, 61.150074413844514, 59.566392353602815, 41.206111090523855, 26.888446365083965, 27.299461841583252, 47.975331033979145, 58.585195541381836, 80.19357204437256, 31.18701716831752, 0.07081164313214165, 0.10486912740660564, 0.9802293841327939, 2.5604155233928134, 0.24944646337202617, 0.21951899783951895, 48.58624792098999, 77.70840985434396, 63.451234408787315, 67.50113786969865, 64.58725098201207, 64.90556185586112, 64.35222816467285, 66.54746287209647, 60.94827788216727, 61.88543701171875, 59.29205662863595, 58.4039865221296, 53.24624490737915, 50.746460233415874, 48.16800110680716, 45.967562198638916, 45.41350589479719, 48.28655474526541, 49.7167580468314, 48.054658617292134, 51.72752502986363, 50.95588936124529, 56.654207774571006, 59.070728710719514, 58.61555222102574, 58.184183733803884, 55.057001045772004, 44.38010726656233, 44.07471309389387, 44.7286045891898, 44.04767417907715, 44.691650594983784, 42.56823941639492, 45.79508359091622, 45.38327080862862, 47.78103160858154, 43.752323627471924, 42.71141052246094, 41.22904709407261, 41.88338327407837, 43.56812688282558, 43.9264246395656, 44.182396275656565, 47.97450072424752, 48.31723799024309, 49.48620639528547, 48.628176825387136, 52.44354731695992, 48.10022490365164, 48.086411884852815, 44.66747433798653, 42.88533435549055, 41.366631848471506, 43.214908259255544, 42.704462323869976, 44.30375698634556, 49.96385335922241, 52.41746030535017, 51.295694487435476, 56.20628867830549, 41.10078682218279, 18.302380187170847, 24.288637161254883, 37.07178006853376, 53.936704771859304, 51.11575698852539, 54.17736257825579, 49.150629247937886, 44.73780400412423, 39.19395446777344, 42.96449170793806, 45.98433862413679, 51.33120673043387, 49.92686462402344, 51.85768215996878, 48.49204771859305, 50.99566779817854, 48.762471607753206, 54.84938192367554, 50.09156124932425, 54.036255087171284, 52.94477994101388, 54.63364035742623, 52.16487939017159, 53.67891270773751, 46.82137768609183, 39.466435023716514, 39.8385979107448, 40.30326911381313, 41.36275822775704, 43.47538232803345, 42.86045285633632, 45.50398881094796, 43.49380547659737, 41.81873723438808, 41.209995133536204, 45.55725022724697, 42.998642104012625, 44.91608783176967, 42.854091780526296, 45.423507826668875, 43.268392017909456, 44.181340149470735, 42.87131983893258, 43.32206685202462, 42.90715169906616, 43.29336036954607, 41.71606370380947, 43.56281845910208, 45.10141365868704, 47.02925736563546, 48.79084457669939, 48.9274947983878, 49.919992855616975, 54.67538513456072, 52.112875597817556, 57.651666845594136, 57.486542906079976, 64.76527077811105, 60.84358242579869, 61.97545787266323, 53.29392344611031, 66.87252739497593, 58.00937747955322, 77.8748539515904, 19.88897180557251, 1.633474696959768, 3.382578492164612, 0.2154063428086894, 0.10831920656242541, 15.327936274664742, 73.1645450592041, 59.66828073774065, 58.74572672162737, 53.97941882269723, 30.437553201402935, 14.379300458090645, 24.632732800074987, 46.3241993359157, 55.76421649115426, 52.59579624448504, 3.9170743141855513, 0.09948528451578957, 0.017033900699711273, 0.0204106217383274, 0.03922475914337805, 0.012583709272023822, 0.07353237178176641, 0.08064539331410613, 0.11522581774209227, 0.09766942302563361, 0.08795528499675648, 0.10707180135484252, 0.19920607496585163, 0.16115985651101383, 0.19551363667207106, 0.12849059381655284, 0.4582458021385329, 0.3464978427759239, 19.672445092882427, 90.84884997776577, 70.83630793435233, 68.6675111225673, 50.19200093405587, 26.47844706262861, 27.631742068699428, 65.28792817252022, 64.40827233450753, 90.0120575768607, 35.09069578988211, 0.24109513578670366, 0.18164277954825334, 2.025298706122807, 5.044478160994394, 9.234683121953692, 0.38952800950833727, 52.726206983838765, 78.54853044237409, 66.69880853380475, 70.31562382834298, 70.87170900617326, 66.47577830723354, 67.71199485233852, 65.91587162017822, 65.5713243484497, 63.49354199000767, 63.132325989859446, 60.430345262799946, 57.025891235896516, 54.2615191595895, 49.71251964569092, 48.2633547101702, 48.320986543382915, 51.74416249138968, 53.00949546269008, 50.16371481759207, 55.55819892883301, 53.521358830588206, 59.449349948338096, 60.63337162562779, 62.93030711582729, 61.18193885258266, 57.11029100418091, 47.922712326049805, 46.14429310389927, 47.06040961401803, 45.883325713021414, 47.58594356264387, 44.3645224571228, 47.9645231110709, 48.77178914206368, 49.90351520265852, 46.36976214817592, 45.45859970365252, 44.333655084882466, 47.238026414598735, 43.508146558489116, 46.219062668936594, 46.53850609915597, 49.195236682891846, 52.41678633008684, 52.4981358391898, 51.67834915433611, 54.485876492091585, 51.74875177655901, 51.505220890045166, 47.94194841384888, 45.56561585835048, 45.78455012185233, 46.98509461539132, 44.969536849430625, 44.99656534194946, 52.70596688134329, 54.873099599565776, 52.91342966897147, 58.55999442509243, 43.774995599474224, 21.45651146343776, 27.5728109223502, 39.84245416096279, 55.93691396713257, 54.10182523727417, 58.13848543167114, 52.00672796794346, 46.80606733049665, 42.16949272155762, 44.58763606207711, 47.161158493586946, 54.63004119055611, 52.90476179122925, 57.763831615448, 51.42324256896973, 55.08833394731794, 49.34406362261091, 59.099695750645225, 51.0506523677281, 56.759347915649414, 55.49708604812622, 56.747754846300396, 54.26485429491316, 57.044422081538606, 50.23145975385393, 42.188433510916575, 42.002023765019004, 43.687899930136545, 42.67903191702706, 45.508522510528564, 45.818224566323416, 47.45113113948277, 47.374534198216026, 43.67400005885533, 42.127876486097065, 49.35848460878645, 45.56531013761248, 47.48912736347744, 44.442773069654194, 46.54568011420113, 44.7222261428833, 47.69884484154837, 45.307372161320274, 45.975441455841064, 45.31439331599644, 44.336517742701936, 44.676659856523784, 47.619597162519185, 47.92080157143729, 49.69791105815342, 51.808645248413086, 51.79966817583357, 53.373032161167686, 58.02672365733555, 53.930402755737305, 61.14890711648123, 59.96489238739014, 68.54473645346505, 62.96206733158657, 65.72267695835659, 54.69642775399344, 69.09503378186906, 62.05296502794538, 83.4907146181379, 19.67800886290414, 3.166064373084477, 5.4362223744392395, 0.4354183099099568, 0.23093847078936441, 19.234159673963273, 79.3065094266619, 66.73680823189872, 69.12034606933594, 71.43909890311105, 54.08187001092093, 18.55697086879185, 31.484170777457102, 54.64255837031773, 64.21529306684221, 64.51030663081578, 6.81701225893838, 0.28471736503498896, 0.08875555598310061, 0.12987473740109376, 0.2357510482626302, 0.24052853190473147, 0.17726069183221885, 0.17117541336587497, 0.1911617980471679], [0.07860222937805311, 0.08910783100873232, 0.038066170777061155, 0.025893886972750937, 0.0257821526112301, 0.14089945224778994, 0.07670203955577952, 0.08314709085971117, 0.11492331326007843, 25.428195578711374, 65.02982343946184, 50.165545667920796, 35.8128776550293, 13.174265691212245, 15.880491767610822, 18.872471196310862, 43.27670553752354, 59.4325978415353, 66.80444199698312, 15.524182932717459, 0.11514797620475292, 0.2662832242037569, 0.8064150395137923, 0.5686243964093072, 1.752308217542512, 13.685466374669756, 70.75202628544399, 64.52510629381452, 62.656652314322336, 53.55237906319754, 62.87816088540213, 60.50625433240618, 61.4931069782802, 63.632360049656455, 64.81144850594657, 60.968830653599326, 62.185752051217214, 60.91314779009138, 57.54733616965157, 57.42824751990182, 51.68407446997506, 48.0356969833374, 48.60022422245571, 44.381813049316406, 43.344763142721995, 42.98218182155064, 42.443602630070274, 43.382040228162495, 46.93513011932373, 48.30724300657, 50.99021693638393, 46.4519419670105, 43.40475736345564, 41.918923309871126, 41.520058495657786, 43.74922125680106, 42.53813634599958, 40.56208603722708, 41.475065435682026, 44.35423912320818, 44.15596532821655, 43.1945743560791, 44.96576050349644, 41.421116147722515, 40.663672174726216, 40.53826413835798, 37.02001598903111, 38.918121406010215, 40.75042738233294, 41.44457674026489, 42.01499605178833, 43.737610816955566, 40.40229484013149, 43.00884553364345, 41.65201868329729, 39.68442433220999, 39.9670318875994, 41.10906212670462, 39.68858630316598, 40.858739376068115, 39.51592704227993, 47.80736528124128, 50.32334620612008, 51.71251344680786, 48.09800148010254, 55.14242219924927, 39.44532987049648, 23.526581321443828, 30.245928832462855, 28.8505186353411, 47.996175629752024, 46.441297326769146, 49.17076860155378, 48.14286599840437, 46.84372656685965, 38.415558201926096, 42.23060212816511, 41.46420887538365, 45.169193335941856, 43.947227546146934, 46.49308225086757, 45.3931303024292, 41.736116204942974, 42.71080255508423, 45.70013645717076, 46.11095217296055, 47.166011810302734, 45.625016008104595, 44.95350388118199, 41.422530106135774, 39.428431851523264, 36.013895988464355, 34.70985460281372, 37.10079574584961, 36.82001904078892, 39.185745171138215, 41.52806976863316, 42.09290272848946, 41.30647087097168, 40.676422119140625, 39.30067184993199, 39.18712438855852, 44.199502740587505, 40.60152053833008, 40.25808150427682, 42.132917404174805, 43.55016578946795, 42.78639200755528, 41.408536434173584, 41.94871718542916, 40.30662509373256, 40.25288772583008, 40.17173624038696, 39.493981157030376, 40.802709102630615, 40.14199447631836, 43.291484355926514, 43.11949907030378, 43.77280344281878, 47.035163334437776, 52.58753831045968, 50.500594752175466, 53.233668667929514, 53.68008000510079, 52.49305670601981, 48.93447426387242, 52.358869620731895, 50.09949261801583, 56.20765399932861, 62.081153869628906, 66.00516292027065, 53.111189297267366, 1.2396846732922961, 3.463917144707271, 0.2427770069667271, 0.06035883152591331, 2.4014029588018144, 50.31958723068237, 61.65655640193394, 47.46313067844936, 57.86743967873709, 51.79118095125471, 22.10850783756801, 13.694849048342023, 27.42014683995928, 48.00191484178816, 51.209745270865305, 12.833451339176722, 0.22592731325754098, 0.09061411089662995, 0.06740488165191241, 0.05485091172158718, 0.050173165941877026, 0.0702628982918603, 0.09986892821533339, 0.06587301420846156, 0.07228014897555113, 0.03430994340617742, 0.04365734004282525, 0.020176120035882508, 0.1011944870863642, 0.12888183710830553, 0.026482181922931756, 0.1495095866599253, 0.050821061711758375, 31.054824216025217, 76.59894929613385, 55.64963722229004, 43.189491748809814, 22.041904142924718, 23.18512773513794, 21.13975351197379, 48.221832275390625, 65.10693454742432, 73.19394288744245, 15.347208840506417, 0.10181190645588295, 0.044523242328848155, 2.0999942294188907, 1.0409592453922545, 1.2414291054010391, 15.56856107711792, 75.9310884475708, 65.73476682390485, 68.04015827178955, 56.09734787259783, 65.24469648088727, 63.52522577558245, 64.55760996682304, 63.999329158238, 65.8219667162214, 63.45952360970633, 66.58201626368931, 62.38763196127755, 60.29586982727051, 58.393411363874165, 53.658526693071636, 50.14810916355678, 48.87086350577218, 45.771018505096436, 44.494266169411794, 46.175466196877615, 47.02859033857073, 44.53396817616054, 47.77519164766584, 52.1999226297651, 52.64112629209246, 49.75266286305019, 45.265186173575266, 43.638189043317524, 43.35708924702236, 44.35096999577114, 44.751377310071675, 42.357045446123394, 44.044978278023855, 46.670539242880686, 45.93462426321847, 45.756809438977925, 46.23186125074114, 42.26406117847988, 42.38223614011492, 40.634326457977295, 39.61833654131208, 40.52319696971348, 41.768043177468435, 41.13847732543945, 44.784065110342844, 45.7108644757952, 43.60965279170445, 44.2510792187282, 42.56992435455322, 41.100123269217356, 43.24658162253243, 43.49747065135411, 41.8286349432809, 42.58470664705549, 42.05949926376343, 48.73386240005493, 51.122792039598735, 52.72968455723354, 50.37281043188912, 57.27063110896519, 41.288725171770366, 27.104681253433228, 33.48174660546439, 29.737021923065186, 49.279733725956504, 48.84363351549421, 51.99321372168404, 50.42571749005999, 49.90249034336635, 39.70302813393729, 43.529189177921836, 44.24017749513899, 46.657365458352224, 45.061093262263704, 49.82489633560181, 46.38919973373413, 44.17347478866577, 43.908470494406565, 48.54378400530134, 47.74849319458008, 49.082436152866904, 47.8137263570513, 47.811440399714876, 44.41797147478376, 42.42356749943325, 38.14428663253784, 37.329054491860525, 38.94171748842512, 39.906217779432026, 41.264448165893555, 44.27685356140137, 44.462408678872244, 43.57448101043701, 43.224590573992046, 41.16862555912563, 40.79427746364048, 45.72511175700596, 43.10878842217581, 41.299494879586355, 43.544940744127544, 46.33077580588204, 44.455575125558035, 43.47167893818447, 44.348923751286094, 43.18669509887695, 41.80499022347586, 41.327416215624126, 42.96366139820644, 43.391069412231445, 41.759639331272666, 45.87385184424264, 45.10449865886143, 46.63164670126778, 49.97207307815552, 53.95821986879621, 53.68874093464443, 55.542315346854075, 56.466950348445344, 53.62838193348476, 52.264971664973665, 53.673308985573904, 52.60815708977835, 58.68507589612688, 64.2975388935634, 68.3579410825457, 58.912949017116, 1.8645651595933097, 2.7676722535065243, 0.6321094898240907, 0.1728822546345847, 2.524669430085591, 53.4855443409511, 67.42875153677804, 53.489185197012766, 57.789366245269775, 43.422718456813264, 20.097780806677683, 21.011086770466395, 34.34576899664742, 53.306138379233225, 58.972543716430664, 16.374103954860143, 0.26839642652443474, 0.05415737090100135, 0.05695457383990288, 0.06622880404548985, 0.02265353450950767, 0.0750731619607125, 0.030663262121379375, 0.031120893279356614, 0.2911354920693806, 0.2702451358948435, 0.16658333263226918, 0.14296652775790009, 0.22549799058054174, 0.2308942031647478, 0.1436196312840496, 0.24838838300534657, 0.3396689034998417, 37.24216379438128, 89.1717563356672, 64.404832976205, 52.80278655460903, 22.914370332445415, 21.68614247867039, 27.43275782040187, 61.86291095188686, 69.17541749136788, 79.2330322265625, 19.320041145597184, 0.2150461357086897, 0.896280651646001, 3.2422196694782803, 5.028573734419687, 6.71639061825616, 14.684784957340785, 80.85984175545829, 67.168534551348, 70.07211726052421, 57.14570597239903, 69.03301416124616, 65.38772514888218, 67.08234909602574, 66.61322757175991, 68.22269439697266, 65.67925071716309, 68.47763769967216, 64.54659012385777, 63.141310010637554, 60.706473623003276, 57.47547789982387, 53.53892387662615, 52.52824585778372, 46.44898203441075, 47.588212149483816, 48.523696763174875, 48.03380012512207, 46.51686246054513, 52.0453599521092, 54.683674335479736, 56.22956166948591, 52.877226080213276, 48.80531767436436, 46.71712691443307, 45.17061076845442, 47.10812636784145, 45.83561243329729, 44.77458429336548, 48.131783621651785, 48.7325005531311, 49.6622633252825, 46.430569308144705, 50.55712529591152, 44.902333872658865, 44.46112673623221, 44.385429586683, 42.55050761359078, 44.010084424700054, 44.674644878932405, 43.66841370718819, 46.086567470005576, 48.37615524019514, 46.237867968423025, 47.06682627541678, 45.582030977521626, 44.62316220147269, 45.62180594035557, 46.466060706547324, 45.14650746754238, 45.13065167835781, 43.663873059409006, 51.55303144454956, 55.384737151009695, 56.24167932782854, 51.67081730706351, 60.52961417606899, 43.06365639822823, 29.847904750279017, 36.65867492130825, 31.77000229699271, 51.04783139910017, 51.55405977794102, 54.691091537475586, 54.09315735953194, 51.94780029569353, 42.77247129167829, 46.89073460442679, 46.8532212802342, 50.91027096339634, 49.31046560832432, 52.49918849127633, 49.04534319468907, 48.17385149002075, 45.22521666118077, 51.51734897068569, 50.57436030251639, 50.63066502979824, 50.70010532651629, 50.266106946127756, 45.73097603661673, 43.59144851139614, 41.828530720302034, 39.062209674290244, 41.74022259031023, 41.75112083980015, 42.18750592640468, 46.016706807272776, 47.35583312170846, 45.57101113455636, 45.159219196864534, 43.36672639846802, 43.574807575770784, 49.38337305613926, 44.46440976006644, 43.70148365838187, 46.78747395106724, 50.02408034460885, 47.39848116465977, 44.22890404292515, 47.66457632609776, 45.94683919634138, 43.99847051075527, 44.20407465526036, 45.37112883159092, 46.030443395887104, 44.62858179637364, 49.20728485924857, 48.62525510787964, 47.68970448630196, 52.620062828063965, 58.640204429626465, 57.18321234839303, 59.09993198939732, 59.29101439884731, 57.605635029929026, 53.21150391442435, 56.96090126037598, 55.3821176801409, 63.160056250435964, 68.55866064344133, 71.57916069030762, 59.433237075805664, 2.387426874467305, 6.758786789008549, 0.8079554225717271, 0.20202546939253807, 3.5829232845987593, 63.25535079411098, 72.42329733712333, 61.18318258013044, 70.2468227658953, 66.74001829964774, 31.039017064230784, 24.49041632243565, 43.97934212003435, 60.29454272133963, 69.1789332798549, 23.178438356944493, 0.39349008404782837, 0.1681504092578377, 0.1395843970988478, 0.18941827517535004, 0.204062445089221, 0.14558248381529534, 0.24381654975669725, 0.1405419592878648], [0.031653790934277434, 0.03820372339604156, 0.01807646805952702, 0.03944724738331778, 0.03146907673882587, 0.08141543556536947, 0.03394655058426516, 0.049327969151948176, 0.14994441904127598, 44.16380984442574, 63.20515005929129, 52.309238638196675, 37.89510338647025, 17.699154956000193, 29.302137647356304, 40.44358451025826, 51.32749291828701, 65.22961888994489, 62.28773076193673, 4.698727982384818, 0.1162720373166459, 0.1056612084752747, 0.9117066838911602, 1.0909858409847533, 0.9487311371735164, 45.207387583596365, 67.20871598379952, 67.37712642124721, 61.302524839128765, 54.415988036564414, 53.5784660748073, 64.32381698063442, 59.875073024204795, 66.50607940128872, 61.47275570460728, 63.01991803305489, 59.12099197932652, 61.040980747767854, 57.56070450374058, 61.44192654745919, 55.19253955568586, 57.546516282217844, 52.33427994591849, 53.507938385009766, 45.25802952902657, 43.89467484610421, 42.04894495010376, 44.48522308894566, 42.448792934417725, 42.725574425288606, 42.19427694593157, 43.10611336571829, 41.99258116313389, 41.640769549778526, 41.51286016191755, 42.0273152078901, 41.95071479252407, 40.874504838671, 41.37770727702549, 44.961126055036274, 43.0699132510594, 41.39525842666626, 40.763719286237446, 41.538794313158306, 40.58763108934675, 39.15792458398001, 39.571252073560444, 39.75623396464756, 39.61780847821917, 40.88322830200195, 39.50386496952602, 39.85845586231777, 38.828889165605815, 40.64109400340489, 40.461774894169395, 39.784971714019775, 38.94898877825056, 38.59041656766619, 38.178030558994834, 41.30115897314889, 40.70750488553728, 46.14603015354702, 54.61707237788609, 50.97141163689749, 51.65657697405134, 54.0307034764971, 47.87742049353463, 31.272820472717285, 34.54132604598999, 32.0630703653608, 51.36509656906128, 46.06307213647025, 48.98423031398228, 49.380854334150044, 47.86796399525234, 38.57064546857561, 39.63710709980556, 41.32089185714722, 41.32388653073992, 40.992255960192, 41.19950335366385, 40.22708559036255, 39.62789378847395, 39.70756183351789, 39.54614128385271, 38.272223813193186, 38.765698773520334, 38.39616925375802, 37.55682338987078, 36.49453067779541, 35.55071864809309, 35.77720560346331, 37.184903689793174, 35.66974476405552, 36.829003061567036, 39.417363371167866, 41.89961426598685, 43.82547426223755, 39.895753792354036, 42.6566343988691, 39.23775591169085, 38.65461792264666, 40.599887711661204, 41.67824465887887, 43.091348443712505, 40.00845357349941, 42.74053042275565, 41.851935727255686, 40.21155636651175, 40.69813176563808, 39.92364386149815, 40.5603038242885, 39.904904569898335, 43.79719509397234, 40.66755969183785, 43.63911315373012, 40.53035361426217, 44.29843119212559, 43.86415488379342, 44.84490006310599, 45.003770623888286, 47.878257751464844, 44.324914251055034, 45.96885108947754, 43.448162760053364, 49.63878883634295, 46.85020923614502, 52.96947036470686, 51.345652035304475, 64.67190783364433, 58.80898312159947, 73.70160606929234, 12.029391033308846, 1.4722810494048255, 0.8529926144651004, 0.08380597550421953, 0.03915064615596618, 22.091279779161724, 63.833218574523926, 55.403935023716514, 51.89038038253784, 62.324507577078684, 25.69433069229126, 12.339175598961965, 27.048949752535137, 43.73204530988421, 50.57516976765224, 27.50961705616542, 0.1279565460447754, 0.02561833050900272, 0.062011267856827805, 0.054956094827502966, 0.055427150800824165, 0.041998902069670815, 0.040237615151064735, 0.04571703648460763, 0.03711005386763385, 0.017996992949130278, 0.05983789983604636, 0.005350777879357338, 0.05159636939476643, 0.023648906366101334, 0.03260754654183984, 0.02690098561080439, 0.24798194052917616, 51.78458363669259, 70.88655035836356, 58.2781720161438, 45.84166431427002, 17.483689580644878, 21.39869897706168, 34.83203520093645, 57.919280188424246, 71.18815776279995, 69.15098762512207, 5.117873719760349, 0.10186988048787628, 0.05936314245419843, 1.2567632368632724, 0.535947886960847, 1.4687689521483012, 50.93074383054461, 69.89468111310686, 70.42894199916294, 63.98614147731236, 57.85441180637905, 55.79010895320347, 65.92921216147286, 62.71999904087612, 67.59354891095842, 62.38817392076765, 64.44524369921002, 59.81209455217634, 62.653629847935264, 61.00372450692313, 62.649301120213096, 56.4313964162554, 58.43851212092808, 53.82267441068377, 57.06325517381941, 48.68074689592634, 45.44048227582659, 43.83722366605486, 46.70386627742222, 44.09177786963326, 45.47203751972744, 44.82445846285139, 42.85991437094552, 43.78813116891043, 44.429790360586985, 43.20657736914498, 43.37022481645857, 44.070241928100586, 43.049346583230154, 42.981070109776084, 46.40792512893677, 44.266657079969136, 44.205582414354595, 43.7643266405378, 43.61157396861485, 43.39934124265398, 40.05012539454869, 42.89132022857666, 42.001356737954275, 41.44484772000994, 41.597388471875874, 41.55741548538208, 42.02910089492798, 40.94044671739851, 41.649440901620046, 41.29243550981794, 43.13674449920654, 41.460863317762104, 40.5784455708095, 39.80134514399937, 42.751178537096294, 43.461847237178254, 50.29856892994472, 55.55262647356306, 53.89840282712664, 54.180214813777376, 55.14952673230852, 49.829878193991526, 36.39348302568708, 37.03514221736363, 33.92460741315569, 51.1793885912214, 49.06623295375279, 52.97008180618286, 49.95946557181222, 50.149679456438335, 41.76967600413731, 41.31954390662057, 43.105293478284565, 44.22300502232143, 43.224823338644846, 43.365281173161094, 43.24644960675921, 41.801015853881836, 40.4649259022304, 41.09157003675188, 39.81388316835676, 40.736155782427105, 40.36679649353027, 39.26364837374006, 38.323289598737446, 37.138694695064, 38.18875510351998, 39.02802801132202, 39.224377155303955, 38.56226246697562, 40.79464224406651, 44.372318335941856, 45.15318121228899, 42.68176603317261, 44.94805301938738, 41.761293002537315, 41.78335353306362, 42.297954491206575, 44.73235314232962, 43.611184869493755, 42.18092598233904, 44.588240555354524, 44.13911942073277, 42.58066974367414, 43.29216875348772, 42.759189810071675, 42.366366454533164, 42.926516328539165, 45.40408761160714, 43.01873629433768, 46.07522106170654, 43.45416600363595, 46.108238901410786, 45.19901500429426, 47.269178662981304, 47.10225861413138, 49.97563402993338, 46.64123174122402, 48.31656401497977, 45.32530198778425, 51.23160777773176, 49.17009462629046, 55.86167887278965, 53.09635489327567, 67.08151531219482, 59.987307276044575, 77.01591764177594, 14.09339337689536, 0.363664018788508, 1.1838316874844688, 0.05524857395461627, 0.044556561790938885, 23.994080441338674, 71.26456015450614, 60.253214836120605, 57.9565920148577, 57.24351576396397, 22.82628107070923, 13.395372135298592, 33.635336535317556, 50.60683618273054, 60.07738372257778, 34.476544516427175, 0.20873084744172438, 0.1302825098059007, 0.0678229813597032, 0.067274460435978, 0.03739134734496474, 0.020909553626552224, 0.06017175942127194, 0.06909380959612982, 0.08549334960324423, 0.09774295586560454, 0.10510396837655987, 0.18661926394062384, 0.16142204244221958, 0.23968421721032687, 0.1589021940848657, 0.07043550402990409, 0.5654572663562638, 63.49617535727364, 79.83708081926618, 68.05039296831403, 53.927289962768555, 28.25043225288391, 39.76314742224557, 55.66167150224958, 64.93352140699113, 76.74883583613804, 75.53483963012695, 6.519098690577915, 0.13779353962412902, 0.6151562652417591, 3.7197411315781728, 6.221797432218279, 1.4356227879013335, 55.828991072518484, 71.75254603794643, 72.37136650085449, 65.10621888296944, 59.34144442422049, 58.79476015908377, 69.92340496608189, 64.46553243909563, 69.70607921055385, 65.10760157448905, 67.0789236341204, 65.96502317701066, 67.35306480952671, 64.54098987579346, 65.55476679120744, 61.52729211534773, 61.40305137634277, 56.42222826821463, 61.12815979548863, 50.77215467180525, 47.81500135149275, 47.52336113793509, 48.99735198702131, 47.40769795009068, 46.20359945297241, 46.80937467302595, 47.24987309319632, 45.45022017615182, 44.34963246754238, 46.34586729322161, 46.80325331006731, 46.81074346814837, 45.254972321646555, 46.485758849552695, 49.030644280569895, 46.245191369737896, 45.855807372501914, 45.462629658835276, 45.63335037231445, 44.80676140104021, 43.047203063964844, 44.86958701269967, 44.5908773967198, 44.691994530814036, 45.004309109279085, 43.56807129723685, 44.141037123543875, 43.7628675188337, 45.34211662837437, 43.31513949802944, 45.28002405166626, 44.361315863473074, 42.481112480163574, 42.05742870058332, 45.80395296641758, 44.62226240975516, 51.807908739362446, 61.30846554892403, 55.82293571744646, 55.855943134852815, 59.98342323303223, 52.73652505874634, 40.525208473205566, 39.9856287411281, 37.19375916889736, 54.15459680557251, 51.884088788713726, 55.30646569388253, 53.035839557647705, 54.007538182394846, 44.77019303185599, 43.88293239048549, 45.44748606000628, 46.03087765829903, 46.09143468311855, 48.09808485848563, 44.03411824362618, 41.81285211018154, 43.75035728727068, 43.700503962380544, 42.67951829092843, 42.91670199802944, 43.826422691345215, 42.16340957369123, 40.52107776914324, 39.55287756238665, 40.990042958940776, 41.450222151620046, 41.06736251286098, 40.70868955339704, 43.82533877236502, 46.357491629464285, 48.60412563596453, 43.626019273485454, 46.14798954554966, 44.0534793989999, 43.46877459117344, 44.402879987444194, 46.910248620169504, 47.04327188219343, 45.0703239440918, 46.97296306065151, 46.19971193586077, 43.92860984802246, 45.31161403656006, 44.6200077193124, 45.45240885870797, 45.29745708193098, 48.863383769989014, 45.112589836120605, 49.0041994367327, 46.37501498631069, 49.77723864146641, 48.38072715486799, 50.99335057394845, 50.215451104300364, 52.907742568424766, 49.96127210344587, 51.023405006953645, 47.08472830908639, 54.51200519289289, 52.81251055853707, 60.943122318812776, 55.60622835159302, 71.86251517704555, 62.69110148293631, 80.84017835344586, 14.61668392590114, 4.966141130243029, 3.491190126964024, 0.16590854312692369, 0.27991488416280064, 28.582656894411357, 75.93955135345459, 66.33903081076485, 67.28385380336216, 72.68404933384487, 38.397763865334646, 21.692590406962804, 43.85690096446446, 60.17010743277413, 68.42745780944824, 46.3254326411656, 0.628924120749746, 0.2773651124111244, 0.15636728225009783, 0.24499752638595446, 0.10528460796922445, 0.09078810763146196, 0.10476657362388712, 0.24803299350397928], [0.030724801854895692, 0.00774069017331515, 0.061379063209252696, 0.04672351087044392, 0.06002644436167819, 0.03778247528576425, 0.08465514172400747, 0.07355831217552934, 1.3749502492802483, 53.40829426901681, 63.79053579057966, 42.14144631794521, 29.352918556758336, 18.557544095175608, 43.09575012751988, 43.63435016359602, 50.92768314906529, 68.892181124006, 47.64207111086164, 0.7814376769321305, 0.023973748220929077, 0.22472346999815532, 0.6113049547587122, 0.30530894867011477, 20.59255681719099, 74.05313628060478, 68.14000388554165, 67.4452257156372, 62.94965090070452, 57.56734003339495, 47.0293025289263, 59.99245589120047, 59.58852236611502, 62.75121034894671, 61.34572178976876, 59.490219252450125, 53.158687182835166, 53.406828199114116, 58.65298911503383, 58.52303695678711, 56.39809717450823, 59.39132554190499, 57.866473879132954, 57.844375133514404, 55.58995567049299, 48.90563229152134, 41.400382723127095, 42.404904638017925, 41.00641638892037, 43.36815425327846, 42.70968042101179, 42.09482390539986, 39.5274714742388, 41.59319175992693, 41.19695336478097, 43.21771533148629, 38.74692126682827, 42.449873379298616, 41.04264429637364, 41.13387066977364, 41.80294745309012, 42.4831656728472, 39.888937609536306, 41.601856163569856, 39.05773156029837, 39.492761748177664, 36.995606967381065, 38.71525137765067, 38.90686879839216, 39.36892400469099, 38.37283025469099, 39.56940037863595, 39.43754093987601, 38.951257365090505, 41.0571278163365, 40.148800236838206, 41.37215566635132, 43.00674717766898, 41.258215631757466, 41.39428220476423, 39.53344692502703, 42.97542469842093, 47.764672074999126, 50.41806057521275, 52.27912514550345, 51.034911223820274, 52.147192750658306, 40.786613600594656, 38.864519527980256, 38.90025063923427, 51.00167798995972, 47.60130950382778, 50.61672346932547, 47.2840929712568, 45.65854801450457, 40.3544773374285, 39.66603939873831, 39.972750255039756, 39.65837900979178, 39.335888794490266, 40.99730730056763, 40.17312240600586, 38.54993288857596, 39.32083204814366, 38.96055405480521, 39.983460903167725, 39.05801296234131, 36.572037833077566, 37.112110887254985, 37.808355127062114, 35.8517667225429, 35.91542959213257, 37.13082933425903, 37.88197823933193, 37.09594242913382, 39.550945963178364, 38.6103127343314, 41.54104552950178, 41.31586136136736, 40.13443831035069, 38.996775014059885, 37.70813431058611, 39.5577586718968, 42.27789504187447, 41.35931886945452, 41.75322961807251, 42.378887108394075, 42.430331570761545, 40.588603837149485, 40.22740520749773, 41.310987200055806, 41.488937514168875, 40.5740647315979, 42.46248088564192, 42.62572881153652, 42.88243348257882, 42.24567971910749, 42.489259243011475, 41.15632029942104, 43.53634582247053, 42.2289171900068, 43.658255440848215, 42.76405354908535, 47.297753129686626, 47.50588641847883, 54.4901704788208, 54.67966522489275, 58.2955390385219, 50.7771886416844, 63.707574299403596, 58.389860834394185, 73.48802539280483, 31.8995167187282, 0.6831367888620922, 2.345362263066428, 0.31836914643645287, 0.08800263995570795, 17.423905542918614, 64.67274856567383, 57.007909297943115, 49.45188924244472, 53.23363045283726, 40.17422022138323, 24.880701848438807, 29.357823984963552, 38.01719018391201, 51.402290276118684, 43.77210514886038, 1.9633941650390625, 0.070059527776071, 0.04822433872946671, 0.08687657038015978, 0.04009784711524844, 0.03164668667263218, 0.0747942365705967, 0.05726258124091795, 0.055515730154833624, 0.01935966090033097, 0.10649513479854379, 0.06562446683113064, 0.020969739682706337, 0.056447477479066165, 0.04360915727115103, 0.05427266757137009, 2.499425104686192, 63.26823970249721, 72.25920173100063, 51.49529191425869, 36.42950248718262, 20.57042854172843, 32.957011699676514, 38.113822255815776, 59.31621551513672, 72.62920025416783, 51.864699840545654, 0.587075012070792, 0.08698412496596575, 0.2561475937919957, 0.3425884225538799, 0.15746527404657432, 24.468383584703716, 75.37761579241071, 69.13946751185826, 69.92786570957729, 66.78230503627232, 59.25071484701974, 50.371809891292024, 59.068672043936594, 60.83921895708357, 64.98761313302177, 62.46365220206124, 63.66261945452009, 57.09359795706612, 57.167776925223215, 60.0154961177281, 61.01783629826137, 58.86689635685512, 60.25896099635533, 59.46858951023647, 59.52211843218122, 58.268263884953086, 51.2372636113848, 43.90501029150826, 44.423453603472026, 44.09771163122994, 44.64826256888253, 44.3769771030971, 44.7934694971357, 41.11182056154524, 41.968658515385215, 42.64515250069754, 44.388427734375, 40.6047306060791, 43.165523937770296, 44.259444849831716, 45.34134537833077, 43.489726884024485, 44.024665219443186, 43.06826652799334, 42.28484671456473, 41.47188663482666, 42.19586113521031, 39.691073758261545, 40.90019927706037, 41.17431960787092, 41.4287348474775, 41.16126046861921, 41.34163570404053, 40.41505173274449, 41.84258345195225, 43.58929804393223, 41.63504423413958, 42.42384890147618, 44.2898953301566, 42.93499313082014, 43.54934590203421, 41.22774083273751, 46.43498141424996, 49.680849756513325, 54.280508586338584, 54.36093398502895, 53.93066678728376, 53.52371079581124, 44.02063526426043, 41.90161187308175, 42.68488924843924, 52.77143628256661, 48.380643776484895, 52.38829871586391, 49.41886445454189, 46.34066309247698, 42.05301659447806, 43.91640533719744, 41.088082041059224, 40.734151227133616, 41.999307019369944, 42.567523751940044, 42.15976176943098, 40.99748795373099, 39.86874614443098, 40.09610162462507, 40.57359225409371, 40.88914469310215, 39.35700784410749, 39.26142495019095, 39.68078695024763, 37.48497206824166, 36.61611720493862, 39.37499673025948, 40.0081513268607, 39.156034673963276, 41.51936367579869, 42.44240059171404, 42.79752649579729, 43.37797205788748, 41.30218035834176, 40.47080060413906, 41.045670236860005, 42.80413770675659, 44.88786424909319, 43.05487387520926, 42.82731342315674, 42.78379338128226, 43.02574702671596, 44.72403962271554, 44.00052717753819, 43.749210834503174, 43.56093897138323, 43.614905629839214, 45.52703945977347, 45.1235089302063, 45.10335568019322, 44.07384804316929, 45.406085218702046, 44.17633744648525, 45.636035851069856, 45.304551192692344, 45.95954050336565, 44.42878981998989, 48.54434680938721, 50.67885773522513, 54.87070941925049, 56.46165929521833, 59.91046714782715, 54.545964513506206, 64.52600261143276, 59.95920876094273, 73.8887835911342, 36.33537524087088, 0.5324672737291881, 1.1680455974170139, 0.4175130735550608, 0.05482696282810398, 17.85555022103446, 70.29536288125175, 60.36605358123779, 56.621829169137136, 54.41301768166678, 38.1566162109375, 31.395237309592112, 36.26907205581665, 45.837818486349924, 56.67701871054513, 51.94415943963187, 3.020818578345435, 0.15572743729821273, 0.045430487753557305, 0.039335424812244515, 0.040916387656969685, 0.04672267966504608, 0.05810671951621771, 0.05863569863140583, 0.17728206568530627, 0.07408860086330346, 0.12650461681187153, 0.24325716548732348, 0.15859126219792025, 0.22353046972836765, 0.18903134736631597, 0.26644181140831535, 3.9036247730255127, 75.22057955605644, 78.63554273332868, 57.960875579289024, 42.86428131375994, 28.238830498286656, 58.34438487461635, 60.874536650521414, 64.87635162898472, 80.31158024924142, 58.30341829572405, 1.022891866309302, 0.1604485618216651, 0.6233293552483831, 4.5790760942867825, 1.724927863904408, 24.079263619014196, 74.38129275185722, 70.65874671936035, 74.3460167476109, 67.21890899113247, 63.97148077828543, 51.73924664088658, 63.35446684701102, 64.30873244149345, 67.31286948067802, 65.54635947091239, 65.39196355002267, 57.76979316983904, 59.51262719290597, 62.37913431440081, 62.75550433567592, 59.825851985386436, 65.23149490356445, 62.35951260157994, 62.475526673453196, 61.23983819144112, 53.766779627118794, 45.505777972085134, 47.85874720982143, 44.38027054922921, 47.74905947276524, 47.0621987751552, 46.48525163105556, 43.27770260402134, 45.12563507897513, 44.9789342880249, 45.91113935198103, 42.48702539716448, 46.30937882832119, 45.74532754080636, 47.6889123916626, 45.42053747177124, 45.039741447993684, 44.564137254442485, 44.57058865683419, 44.061195373535156, 44.34075961794172, 41.26595592498779, 42.91664988654, 43.37469598225185, 44.1244934626988, 42.85090603147234, 44.81241028649466, 41.05886139188494, 43.560463019779746, 44.90821899686541, 44.18678753716605, 44.72323710577828, 47.50132492610386, 45.30860199247088, 46.88920947483608, 44.199725082942415, 46.62347214562552, 52.68058858598982, 56.48853145326887, 59.155719075884136, 56.26929841722761, 56.79726423536028, 47.09617894036429, 44.450815609523225, 44.45211492265974, 55.4250853402274, 51.84902817862374, 55.831787722451345, 52.66492734636579, 50.60736424582345, 44.19264486857823, 45.52536146981375, 43.21991096224104, 44.464364596775596, 44.25890983854021, 46.48500844410488, 44.48182194573538, 42.1812629699707, 41.656180654253276, 43.02559764044625, 42.8568571635655, 43.9304198537554, 41.413691997528076, 42.2558970451355, 41.53994771412441, 40.0523488180978, 40.7669814654759, 41.34098604747227, 42.34540373938424, 42.38254533495222, 44.570380210876465, 43.58251312800816, 44.608254841395784, 45.86539936065674, 43.333427156720845, 42.83400453839983, 42.375183718545095, 44.93021004540579, 47.437425817762104, 44.44308573859078, 44.536413942064556, 43.60082163129534, 45.40336152485439, 46.17480959211077, 45.95170988355364, 45.41672985894339, 46.10359403065273, 43.58298907961164, 48.19388314655849, 46.91318423407418, 48.28100313459124, 47.740179674965994, 48.102430956704275, 46.35826287950788, 48.90923145839146, 47.880710465567454, 49.00699608666556, 46.55289929253714, 53.37889296667916, 52.82060520989554, 58.693052428109304, 60.222601073128835, 62.527172633579795, 55.79136310304914, 69.24145317077637, 64.47199426378522, 79.68329633985246, 37.26402282714844, 1.142220554607255, 6.381915628910065, 0.962353949035917, 0.18066045083105564, 22.087642397199357, 76.62719372340611, 67.97641549791608, 61.87958662850516, 65.30527782440186, 56.40436792373657, 38.07430437632969, 42.71065664291382, 55.25471551077706, 65.24202142442975, 63.21335588182722, 4.3436989188194275, 0.2791199396763529, 0.20113928908748285, 0.10409144485103232, 0.14632382403526986, 0.14254810235330037, 0.1718735173344612, 0.1841812197651182], [0.013382088842003472, 0.05359734541603497, 0.02718466074605073, 0.03899942784171019, 0.010542408762765782, 0.07830109553677694, 0.2208069930119174, 0.2991751549499375, 7.601707935333252, 66.63151523045131, 54.682044982910156, 42.129033361162456, 31.925992829459055, 17.894741535186768, 36.497243949345176, 47.619631903512136, 53.771056243351524, 73.33172566550118, 29.505907467433385, 0.02724225479843361, 0.009242841175624301, 0.23924278946859495, 0.7029487629021917, 9.854019488607134, 78.34640039716447, 72.4305373600551, 70.14580290658134, 67.65057972499302, 64.81677777426583, 54.53919696807861, 50.090536390032085, 46.523789814540315, 55.52870382581438, 59.75238173348563, 59.53070640563965, 59.41428933824812, 61.1819805417742, 59.20217473166329, 61.20971080235073, 60.47285434177944, 60.500188555036274, 57.77977078301566, 61.42625835963658, 57.036421230861116, 58.6381825038365, 54.981300422123496, 44.61417818069458, 40.18395464760916, 42.403257914951865, 40.08296605518886, 42.15460620607649, 40.90694597789219, 42.59513936723982, 40.190954957689556, 39.59537969316755, 39.88935797555106, 41.215164593287874, 40.675692558288574, 40.75071573257446, 40.68998152869088, 41.10474034718105, 41.86996282849993, 40.608711923871724, 39.497924259730745, 40.794544969286235, 38.86197648729597, 38.44378178460257, 37.80522843769619, 36.95655461720058, 38.84962606430054, 38.02204697472708, 38.57949052538191, 39.328780787331716, 38.289003712790354, 41.68356697899954, 41.08483028411865, 41.779320103781565, 38.40958969933646, 39.07382011413574, 39.34330947058541, 40.50144215992519, 39.036727155957905, 39.971086161477224, 42.84252997807094, 47.5163608278547, 48.83398246765137, 51.507552010672434, 42.12402718407767, 41.53696346282959, 45.16041081292288, 49.11731958389282, 47.39609793254307, 45.63666813714163, 42.38346597126552, 39.960788931165425, 39.56229931967599, 39.06235211236136, 39.7152395929609, 38.630354813167024, 39.143791948046, 37.560679640088765, 38.093693324497764, 39.260476521083284, 37.22041245869228, 36.90583971568516, 37.50940193448748, 37.50539629799979, 37.44724334989275, 35.15706845692226, 35.93738589968, 35.554213591984336, 33.87943370001656, 37.03790412630354, 35.758584431239534, 37.405981472560335, 39.38863951819283, 39.115429401397705, 41.29071583066668, 41.039006914411274, 39.38991103853498, 38.39688491821289, 38.71405281339373, 40.74419484819685, 43.31852674484253, 40.82587092263358, 41.821415764944895, 41.030217443193706, 42.17461701801845, 41.34917797361101, 41.01629672731672, 40.467125007084434, 43.63946056365967, 41.21555021830967, 43.40237413133894, 42.63670349121094, 44.111924171447754, 42.517583574567524, 43.90027509416853, 44.52053383418492, 43.79472153527396, 43.89324351719448, 43.88558660234724, 47.4255131312779, 50.54480961390904, 57.5899772644043, 57.67792061397007, 57.90894474302019, 57.93149164744786, 60.83194419315883, 60.83659948621477, 60.94747189113072, 65.6673970903669, 51.455193860190256, 2.0939977169036865, 1.3230659876550948, 0.14858208357223443, 0.044836766219564846, 4.38518009866987, 53.08854511805943, 61.557037353515625, 54.69101858139038, 50.87463017872402, 37.11223248073033, 8.437746456691197, 13.864009022712708, 38.190335818699424, 51.09537444795881, 55.39363431930542, 11.46392057623182, 0.29859508893319536, 0.012127074712355222, 0.09118687587657145, 0.037315680512360165, 0.008260598971641489, 0.0762900330924562, 0.01571411276901407, 0.029825125488319566, 0.029727867671421597, 0.034167267847806215, 0.05418169977409499, 0.10811090309705053, 0.08565726330769913, 0.07312157311077629, 0.21731195412576199, 9.88796317577362, 75.9743548801967, 60.44729886736189, 52.40250778198242, 39.27531439917428, 22.18328956195286, 31.71280472619193, 50.16371829169137, 58.59243556431362, 80.13201795305524, 32.01788970402309, 0.003948764226931546, 0.04312313960066863, 0.1272678194301469, 0.40243854959096226, 9.939656904765538, 83.15588787623814, 73.68100466047014, 72.92602034977504, 69.1150654384068, 67.2259475163051, 56.85995435714722, 52.604196616581504, 49.99426909855434, 58.01814958027431, 63.08145127977644, 61.745194571358816, 61.86862931932722, 63.32622936793736, 62.562462534223286, 62.957432883126394, 62.113025256565635, 61.86880997249058, 61.65892573765346, 62.209924834115164, 59.67099053519112, 60.019387108939036, 57.161558287484304, 48.689633641924175, 44.03323582240513, 45.396771158490864, 41.36586059842791, 44.42365162713187, 43.62167317526681, 44.50519568579537, 42.09346900667463, 41.92813662120274, 42.29990346091134, 43.5563496862139, 43.71243749346052, 43.39556837081909, 43.1443076133728, 45.1849171093532, 44.04940775462559, 41.93432746614729, 41.11695875440325, 41.92842844554356, 41.02594082696097, 42.15718398775373, 41.42791148594448, 39.65287256240845, 40.446794578007285, 40.323801040649414, 41.48954895564488, 40.69088132040841, 40.4799096924918, 42.55638926369803, 42.00192649023873, 43.772588048662456, 42.27748162405831, 40.906862599509104, 41.41904558454241, 42.59731067929949, 41.71330526896885, 44.79433454786028, 44.80786616461617, 49.346116815294536, 50.79235308510916, 53.08923646381923, 43.99762977872576, 45.013109002794536, 44.58983169283186, 50.60841342381069, 49.94966861179897, 47.92992455618722, 45.204344272613525, 43.28837503705706, 41.75265986578805, 41.33294350760323, 39.86000183650425, 41.67045225415911, 41.30049194608416, 38.17573765345982, 39.98703922544207, 40.45873505728585, 39.46973541804722, 39.64159216199602, 40.341175011226106, 39.440994194575715, 38.653030259268625, 39.073684624263215, 36.0918721471514, 37.45762395858765, 38.236051491328645, 38.791337626320974, 37.40159021105085, 39.45673186438424, 40.76145069939749, 41.85396112714495, 42.02476521900722, 43.361845288957866, 41.06075825010027, 41.593785830906455, 39.79035309382847, 42.00224610737392, 44.661894934517996, 42.98117780685425, 43.342386858803884, 43.84938996178763, 43.821687494005474, 43.266641071864534, 42.19995362418038, 44.672810554504395, 45.65123503548758, 43.69905178887503, 45.29352787562779, 46.299411637442454, 47.49027729034424, 46.17974281311035, 47.094400201525005, 46.95872620173863, 45.73647206170218, 46.56234884262085, 46.2474946975708, 50.352810042245046, 51.97031940732683, 59.701951708112446, 58.64792387826102, 60.776976994105745, 61.770020484924316, 63.071466718401226, 63.185910497392925, 62.07000895908901, 68.79658085959298, 55.6130028452192, 2.63374268582889, 1.604744872876576, 0.566932347204004, 0.1252946395959173, 3.674096243722098, 57.635672092437744, 67.22339057922363, 61.0311073575701, 56.371999740600586, 46.24197782788958, 17.79180744716099, 24.01173060280936, 46.06633084160941, 56.36613198689052, 64.39616162436349, 14.237966282027108, 0.3311363256403378, 0.05857971949236734, 0.06562813092023134, 0.07224814926407166, 0.07357440702617168, 0.06774492947650806, 0.030401948107672588, 0.11817572159426552, 0.08393720417682614, 0.15011066012084484, 0.16049525860164846, 0.24132746617708886, 0.2666894495487213, 0.38198666274547577, 0.3805283010005951, 13.754063333783831, 89.65546212877545, 67.586336680821, 60.72210012163435, 44.73147766930716, 25.709858179092407, 48.93804563794817, 63.89669731685093, 63.18142890930176, 85.98849473680768, 36.715813432421, 0.1826018345143114, 0.09230018899376903, 1.1622099791254317, 3.2066277393272946, 9.899763822555542, 84.66762134007045, 75.4561026436942, 76.41642011914934, 74.31001118251255, 70.40561689649309, 59.49447849818638, 56.4042706489563, 52.00282308033535, 61.32374463762556, 65.48723724910191, 64.55077988760812, 64.23438671657017, 66.19092300959996, 63.15955598013741, 65.45907620021275, 65.27184309278215, 64.62654999324253, 62.66649791172573, 67.00279917035783, 61.80249636513846, 64.56972762516567, 59.80037988935198, 49.91685574395316, 46.72600323813302, 47.00847182955061, 43.60552903584072, 47.13295228140694, 45.89935173307146, 46.33315208980015, 43.873767716544016, 42.49203852244786, 43.19810404096331, 44.873794146946494, 46.70284489222935, 44.49774374280657, 44.96269287381853, 45.34622996194022, 46.48692962101528, 45.25075823920113, 43.89480338777815, 46.292783055986675, 44.38586732319423, 44.98706020627703, 42.82781369345528, 40.8156327520098, 42.80260910306658, 42.227336474827354, 43.49911042622158, 42.92401497704642, 41.83665663855416, 45.03128201620919, 44.63835096359253, 46.54216432571411, 44.80122716086251, 43.11054284232003, 42.81367063522339, 45.946293762751985, 41.928588254111155, 46.14470999581473, 46.903842381068635, 51.88944237572806, 53.69694675718035, 55.60000971385411, 48.22386809757778, 48.02545533861433, 49.85093123572213, 52.675648416791645, 54.28796400342669, 52.31421702248709, 48.737604004996165, 45.17218106133597, 43.37431035723005, 44.11637101854597, 42.67952176502773, 43.94649451119559, 43.33646351950509, 41.673638003213064, 41.504063742501394, 42.97631059374128, 41.03226021357945, 41.64695692062378, 43.0493882724217, 41.43766328266689, 42.83621406555176, 40.617348534720286, 38.52118819100516, 39.99478299277169, 39.664361408778596, 41.57560239519392, 39.77931240626744, 42.563667501722065, 43.948353154318674, 42.9015097618103, 44.53320040021624, 45.858482428959434, 43.375581877572195, 42.94416127886091, 43.12460599626814, 45.74820409502302, 47.82637207848685, 43.783858026777, 46.07907036372593, 46.162226404462544, 46.135145800454275, 44.538289955684114, 44.60577433449881, 45.648521763937815, 48.41595452172415, 45.19637468882969, 47.17356102807181, 48.57744802747454, 51.12544277736119, 48.92444453920637, 50.588659695216585, 48.882275921957834, 48.13971846444266, 48.86081293651036, 48.29614325932094, 53.21218483788626, 54.76765373774937, 64.0816375187465, 62.59821796417236, 62.90726688929966, 64.4718552998134, 65.81720720018659, 67.6193962097168, 66.62962532043457, 71.86053494044712, 59.34482819693429, 2.998736551829747, 4.783245870045253, 1.2345993518829346, 0.1663754837853568, 5.72107550076076, 65.48413140433175, 71.28321606772286, 67.47026702335903, 63.692274366106304, 50.6994799886431, 16.11211691583906, 27.964691059929983, 55.016440936497276, 63.787958008902415, 75.08513137272426, 18.589681250708445, 0.5509193550263132, 0.14706558494695596, 0.2703313912664141, 0.1398441945867879, 0.14666451646813325, 0.2753587115023817, 0.08347466042531387], [0.027301229669579437, 0.03430973984567182, 0.044665911101869175, 0.09140828863850661, 0.07082174651856933, 0.07002285974366323, 0.03400247544050217, 0.25051996005432947, 16.44009099687849, 69.59153120858329, 53.80636698859078, 30.51446975980486, 34.64362437384469, 25.48190689086914, 44.02317830494472, 45.442862033843994, 58.41892514910017, 66.42955194200788, 17.09992320196969, 0.3828392012843064, 0.3248120807111263, 0.3882155870752675, 1.4291138457400459, 45.62891742161342, 63.97615691593715, 64.0337644304548, 68.06481048039028, 63.6201103755406, 61.83695943014962, 55.02881220408848, 48.924284730638774, 48.45145981652396, 50.82342195510864, 52.47978912081037, 54.57715150288173, 55.83518539156233, 57.107073988233296, 57.9916387285505, 60.13212857927595, 59.21381991250174, 59.78103610447475, 59.75955922263009, 57.87256050109863, 56.56317247663225, 59.490802901131765, 54.47961616516113, 48.80100284303938, 40.761530603681294, 43.65978404453823, 40.53237206595284, 42.04272978646414, 43.010714599064414, 42.40612057277134, 39.67094830104283, 41.86804165158953, 40.658096245356965, 40.54482671192714, 40.27921445029122, 41.140520095825195, 40.88723393848964, 43.57350826263428, 40.89443922042847, 42.07868324007307, 38.98547724315098, 39.77359403882708, 38.668514319828574, 38.617184502737864, 35.85873923982893, 38.64846876689366, 36.37180812018258, 37.348700523376465, 36.61384514399937, 36.74454770769392, 36.39496994018555, 38.240588665008545, 38.423437459128245, 40.019640173230854, 38.10677678244454, 38.00762946265084, 40.31848914282662, 37.89049673080444, 40.3716150692531, 40.75403349740164, 39.57425022125244, 42.20314632143293, 48.21866042273385, 53.88922773088728, 42.38046782357352, 42.09603289195469, 44.77733925410679, 50.68609080995832, 46.938013621738975, 40.422795500074116, 36.033319677625386, 38.76519850322178, 36.84227064677647, 35.71671111243111, 38.42858954838344, 37.05478824887957, 39.548604420253206, 39.83200754438128, 38.60602569580078, 40.046866689409526, 36.46654680797032, 36.34533200945173, 36.35099131720406, 37.26827165058681, 34.723577295030864, 37.626183782305034, 35.04732166017805, 35.758362088884624, 35.534310477120535, 37.468873092106406, 36.09132671356201, 38.07282441002982, 40.716176237378804, 40.84855679103306, 39.919697284698486, 41.080577986580984, 39.68238851002285, 40.31342043195452, 38.79891811098371, 42.17446763174874, 42.63313211713518, 43.28554017203194, 41.1927045413426, 42.38598121915545, 42.443588733673096, 43.41673258372715, 41.60778645106724, 43.76135975973946, 42.01282473972866, 42.70653288705008, 42.726724352155415, 43.576026984623496, 42.74416433061872, 43.56193256378174, 42.01379748753139, 42.99998658043997, 44.27906656265259, 50.318003041403635, 49.75322566713606, 56.25043058395386, 56.47301959991455, 59.579058919634136, 56.91615833554949, 67.70763833182198, 65.07188783373151, 60.45740154811314, 61.63494750431606, 64.44231850760323, 62.27952493940081, 62.39499010358538, 5.316404163837433, 0.9319042286702565, 0.6314115758453096, 0.09797612763941288, 0.0926850133442453, 31.174955095563615, 66.78950337001255, 53.68531199863979, 48.490321091243196, 50.43415607724871, 19.43242825780596, 9.587803602218628, 31.42668833051409, 44.56203542436872, 53.03839996882847, 17.24941716875349, 0.5577455258795193, 0.13450336403080396, 0.14012635658894265, 0.0344260746746191, 0.06606634919132505, 0.026517786351697784, 0.030524077625679116, 0.06995390022971801, 0.04906119293134127, 0.031002926573689495, 0.05162981777851071, 0.05728549536849771, 0.033568436945123334, 0.1637250038662127, 0.20846418317939552, 21.954521860395158, 78.81170736040387, 60.864677156720845, 39.4904271534511, 42.17462396621704, 30.868824413844518, 37.041690894535606, 53.907275676727295, 64.31680624825614, 73.71511336735317, 18.850652115685598, 0.35477398868118015, 0.10673518013209105, 0.5023968272975513, 1.117719469325883, 56.61503383091518, 68.486830166408, 66.29709843226841, 70.39245700836182, 65.44388743809291, 63.67586966923305, 57.286636284419465, 52.340040002550396, 51.62572002410889, 53.66526297160557, 54.534944670540945, 57.10035508019583, 58.356863839285715, 60.62625667027065, 59.81579794202532, 61.974158559526714, 59.9616892678397, 61.892044748578755, 60.24657930646624, 60.59274550846645, 57.677149363926475, 59.29249436514718, 59.779347692217144, 52.061226163591655, 42.76108666828701, 44.6028665133885, 43.59133734021868, 44.319119453430176, 44.34977837971279, 43.54558345249721, 42.00895459311349, 43.05779211861746, 42.26039252962385, 43.11051852362496, 42.02110004425049, 42.50707789829799, 42.57338455745152, 44.50816604069301, 43.04280138015747, 43.23771572113037, 41.196077891758506, 42.86345100402832, 40.61554547718593, 40.41332163129534, 39.43618951525007, 39.785760334559846, 38.616489682878765, 39.16335112707955, 39.468606335776194, 39.80675431660244, 38.47060530526297, 39.496784755161826, 39.49161876950945, 41.47609724317278, 39.357678345271516, 40.520987442561555, 42.139400073460166, 40.14000381742205, 41.01955195835659, 41.79784400122506, 42.140247753688264, 44.39009877613613, 49.54454347065517, 56.85365581512451, 45.15343482153756, 45.069438048771445, 46.94407939910889, 51.93358080727713, 48.96432025091988, 41.35340942655291, 39.210741315569194, 40.0307468686785, 38.32824713843209, 37.80707318442208, 39.94183424540928, 39.25303152629307, 41.49110882622855, 42.03572252818516, 40.26684318270002, 41.22174106325422, 37.71122625895909, 38.77902889251709, 38.61986303329468, 38.81623649597168, 37.16375684738159, 38.53034591674805, 37.748551981789724, 38.64137813023159, 37.78977216993059, 39.18074941635132, 40.35276460647583, 40.73598207746233, 42.01375927243914, 42.355468205043245, 42.659733295440674, 43.144272872379844, 43.37894480569022, 43.79802540370396, 41.3823903628758, 44.65858064379011, 42.64235585076468, 44.060827119009836, 42.9916661126273, 44.09593636648995, 42.4973087310791, 44.61045394624983, 43.44050931930542, 45.81693914958409, 44.157330649239675, 44.06566653932844, 44.940646239689414, 45.87203141621181, 45.087548528398784, 46.754866055079866, 44.614258084978374, 44.03263480322701, 46.58554540361677, 52.034395694732666, 52.740989276341026, 59.46504592895508, 57.00848599842617, 61.5679738180978, 60.844867842538015, 69.21749578203473, 66.05654484885079, 64.72760459354946, 63.01977906908308, 68.05355439867292, 63.373741149902344, 66.15343053000313, 6.443130561283656, 1.342670004282679, 1.3150917355503355, 0.03378952061757445, 0.09827920887619257, 33.13845695768084, 73.71494661058698, 59.33610125950405, 56.23482492991856, 51.19044317517962, 19.31843090057373, 12.875957812581744, 37.796789850507466, 52.684205123356406, 62.80952657972063, 23.108068738664898, 0.3845314404794148, 0.06747207697480917, 0.10368667835635798, 0.0602215774623411, 0.0809412549382874, 0.028057093931628124, 0.010239478500027741, 0.14678317867219448, 0.1199973574174302, 0.20920417990003312, 0.206555627020342, 0.16905573782111916, 0.1537914276123047, 0.23082374408841133, 0.33483366295695305, 27.660010814666748, 89.77183055877686, 68.52204363686698, 47.22176762989589, 40.86919641494751, 31.76346751621791, 60.90088421957833, 61.64097159249442, 69.26850250789097, 79.8505116871425, 21.969003643308366, 0.5555422955325672, 0.7066080208335603, 1.21922005712986, 1.4440595294748033, 57.33375549316406, 76.47197791508266, 68.67348657335553, 72.68723160879952, 68.01712499346051, 64.97769110543388, 59.809329169137136, 51.96331214904785, 54.45860481262207, 57.19223458426339, 57.990881374904085, 58.47281537737165, 61.05628068106515, 62.169013840811594, 62.454987798418315, 64.94886997767857, 63.58058902195522, 62.90196541377476, 64.72406796046666, 62.984635080610005, 60.26260880061558, 63.09630652836391, 61.365677016122, 52.381440843854634, 43.807436738695415, 46.93882308687483, 46.57281282969883, 45.786797864096506, 49.45238951274327, 47.14809588023594, 44.653918402535574, 44.453448976789204, 45.776809828622, 45.61990908214024, 45.0617880821228, 44.65335212435041, 44.28210639953613, 48.10414021355765, 43.6302889415196, 46.41739204951695, 43.317560945238384, 44.464510508946006, 43.01892736979893, 43.3675080708095, 40.76554666246687, 43.33411850248064, 41.59053407396589, 42.39255768912179, 42.68567092078072, 42.82101140703474, 40.34314482552664, 41.89445522853306, 42.03143548965454, 44.66598047528948, 42.064453329358784, 43.3726601600647, 45.299809047154014, 44.20864656993321, 43.13680703299386, 44.31784445898873, 45.322039808545796, 46.759556089128765, 53.358010155814036, 57.99367455073765, 47.727394989558626, 49.16287544795445, 49.66667890548706, 54.9269585609436, 53.18099437441145, 43.35226719720023, 41.73795747756958, 42.32678256716047, 41.24236331667219, 39.61046075820923, 42.780618054526194, 41.24449988773891, 44.157441820417134, 43.74182142530169, 41.870480469294954, 44.90322324207851, 41.056766510009766, 41.060942377362935, 40.53739561353411, 41.55344458988735, 37.33880628858294, 40.82609673908779, 40.5497008732387, 41.757968289511545, 40.559449195861816, 41.72026736395699, 42.136707646506174, 43.28339317866734, 45.05972446714129, 43.98358052117484, 44.06566653932844, 45.461959157671245, 45.41508313587734, 45.56236410140991, 44.19869327545166, 46.794835567474365, 46.01911088398525, 46.459835120609824, 45.113600799015586, 45.69678047725132, 45.74025188173567, 47.32192938668387, 46.051409585135325, 48.455798966544016, 46.01873915536063, 46.57069362912859, 47.398793833596365, 48.71912179674421, 48.90956497192383, 47.11326108660017, 47.66031360626221, 47.35255357197353, 48.31739779881069, 54.97642278671265, 54.205193587711875, 62.12936741965157, 60.84474277496338, 64.34740611485073, 63.77252605983189, 70.51663521357945, 64.79905986785889, 67.64117186410087, 64.34969902038574, 70.10054234095982, 65.45385810307094, 68.09497261047363, 6.809052663190024, 3.0400750764778683, 2.9099765717983246, 0.1657882117267166, 0.5446962118148804, 37.51413018362862, 78.68954413277763, 64.85664653778076, 63.165072849818635, 61.589554922921316, 31.281602995736257, 18.182834693363734, 47.908374718257356, 60.62354687282017, 71.33656433650425, 32.16266236986433, 0.8028473023857389, 0.17160341968493803, 0.2461956835218838, 0.14301626437476703, 0.21244465958859238, 0.11591298372617789, 0.13250391132065228], [0.029615529413734163, 0.04136612066732986, 0.028684572582798343, 0.019386593651558672, 0.0506841944131468, 0.05140581640547939, 0.11705676306571279, 0.11945363373628684, 25.71687238556998, 70.17208794185093, 46.20701101848057, 39.43085329873221, 26.571019649505615, 16.48875617980957, 45.524225439344136, 49.74159090859549, 61.44472667149135, 62.86183956691197, 7.616802896772112, 0.40291824670774595, 0.44761994374649866, 1.1520437874964304, 18.917591060910905, 55.5627361025129, 64.11563505445207, 68.12915079934257, 66.11638968331474, 63.92205129350935, 58.14123344421387, 53.934630734579905, 45.905219486781526, 48.682490893772666, 49.98348549434117, 50.29293394088745, 49.84842988422939, 50.701210090092246, 55.32027523858206, 53.775937352861675, 56.201404094696045, 56.07237952096121, 58.17820828301566, 57.74163906914847, 55.53937973294939, 55.594725608825684, 55.43837724413191, 57.0922395842416, 51.69991636276245, 42.53607620511736, 41.85987751824515, 41.99139996937343, 40.06565114430019, 41.15764045715332, 42.44442251750401, 41.63151454925537, 41.44820717402867, 41.75978176934378, 40.6368590763637, 40.053846154894146, 39.94583640779768, 42.829161643981934, 41.52985198157174, 42.06776067188808, 39.222181524549214, 40.3070558820452, 39.39560508728027, 39.120908055986675, 39.02277864728655, 36.80605663572039, 36.94314806801932, 37.179504939488, 36.283506938389365, 35.54856470652989, 35.7795158794948, 34.72725984028408, 35.98546743392944, 35.23060819080898, 35.42211444037301, 38.542081424168174, 40.91105931145804, 43.1754390171596, 45.58488668714251, 44.00090932846069, 44.03882564817156, 41.250051498413086, 45.879723072052, 47.95217268807547, 47.537660530635286, 42.730712618146626, 35.96052687508719, 43.539892877851216, 46.831126008714946, 46.58625759397234, 43.59519706453596, 43.30051701409476, 40.01882723399571, 43.883790493011475, 39.468185969761436, 36.680804933820454, 35.61502422605242, 38.984615666525706, 37.6939252444676, 35.12345654623849, 37.57423210144043, 35.913696016584126, 36.64532395771572, 35.74675512313843, 36.518689564296174, 35.960085664476665, 35.01357773372105, 36.04757738113403, 35.31177357264927, 37.52852685110909, 39.2089695249285, 36.56436702183315, 42.0836546761649, 39.53657708849226, 39.406461647578645, 40.32655252729143, 41.362393447331016, 41.14255591801235, 41.640102522713796, 40.86639281681606, 39.65056228637695, 41.38424900599888, 41.68255254200527, 40.681463037218364, 41.54615592956543, 41.66905219214303, 40.28880991254534, 41.654335907527376, 41.47985274451119, 39.208205223083496, 43.484751973833355, 44.70107235227312, 45.20278787612915, 45.8817206791469, 46.64600167955671, 47.08027103969029, 53.30910178593227, 51.09934881755284, 55.51694399969918, 55.885879448481965, 57.245836462293354, 58.51119722638811, 62.60745212009975, 57.34060294287545, 61.11609772273472, 67.70308031354631, 67.12230123792375, 60.234253202165874, 69.05910464695522, 58.98062447139195, 69.46735995156425, 10.203541670526777, 0.6438316979578563, 0.6751017943024635, 0.08712413388171367, 0.060243751986750534, 17.320613622665405, 67.35644858224052, 58.48803193228585, 53.30409560884748, 53.67133569717407, 28.967531510761805, 20.87667907987322, 26.25855221067156, 37.021846839359824, 56.60301692145211, 30.630025250571116, 0.5940569745642799, 0.022475995821878314, 0.10106184706091881, 0.037246907595545053, 0.023898873577958772, 0.037200753643576584, 0.05312386028734701, 0.0696189007056611, 0.022478847365294184, 0.0342748088629118, 0.009619245754687913, 0.07296993410480873, 0.04898624534585646, 0.11001109291932412, 0.10363914019295148, 33.717005661555696, 77.86530712672642, 50.23881442206246, 40.23666715621948, 33.03052364076887, 22.431036267961773, 47.08936275754656, 56.03067295891898, 65.12528473990304, 68.51130172184536, 8.608038987432208, 0.5348813384771347, 0.5886393881269864, 1.3527819131101881, 27.93527238709586, 64.88870552607945, 65.60224383217948, 71.38559777396065, 68.15260096958706, 66.70523561750139, 59.30341693333217, 56.40009478160313, 49.34573119027274, 51.556818212781636, 52.03822067805699, 51.33047022138323, 52.3836920601981, 54.07646083831787, 55.665781361716135, 57.13392877578735, 56.72900513240269, 58.08653027670724, 59.18498488834926, 59.40841811043875, 55.56380959919521, 59.5586381639753, 57.875322410038535, 59.65081991468157, 53.303084645952495, 44.12167249407087, 43.966258662087576, 44.68000194004604, 42.528843130384175, 43.39993878773281, 43.954408509390696, 44.078833375658306, 43.545757157461985, 42.142186301095144, 42.987747328622, 41.79485280173165, 41.639157567705425, 44.92614187513079, 42.556778362819124, 44.26021262577602, 42.934218406677246, 42.370097637176514, 41.57073518208095, 42.35402992793492, 40.37565892083304, 39.44242899758475, 39.4278620992388, 38.58042505809239, 38.44642210006714, 38.139711243765696, 37.63515738078526, 37.37301574434553, 38.76452452795846, 38.93536683491298, 38.90979746409825, 39.385221004486084, 43.1254814692906, 44.694600105285645, 48.1604449408395, 46.51989882332938, 45.83935751233782, 42.59551804406302, 48.45598309380667, 49.59298631123134, 51.713493142809185, 45.6321587562561, 38.00882107870919, 43.79917185647147, 47.91134507315499, 48.20255102430071, 45.974472182137625, 45.591761929648264, 41.124956130981445, 46.8048027583531, 40.443056447165354, 39.04880312510899, 37.53780617032732, 40.32816103526524, 39.62659794943673, 37.9675418308803, 39.69391209738595, 39.223724024636404, 38.26396240506853, 37.36086334500994, 37.21446132659912, 38.06843662261963, 38.085918290274485, 38.08430283410208, 37.83937883377075, 39.23401778084891, 40.672485964638845, 39.013360364096506, 43.7000731740679, 41.455075468335835, 41.493551118033274, 42.802157470158164, 42.79472984586443, 44.00840296064104, 42.95552505765642, 41.691800594329834, 42.00005742481777, 43.71367427280971, 42.96651710782732, 42.660247462136404, 43.97310263769967, 43.651335035051616, 42.87825414112636, 42.642317635672434, 43.29685183933803, 42.32058129991804, 44.31816407612392, 45.31795426777431, 46.89814485822405, 48.17543567929949, 48.837143898010254, 49.714472089494976, 54.84617533002581, 55.587944167000906, 58.36893286023821, 58.43371091570173, 60.411529541015625, 60.11558491843087, 64.77005113874162, 58.990671566554475, 60.36865220751081, 63.36709867204939, 68.5458551134382, 61.19949695042202, 71.50057656424386, 60.8363493510655, 70.65667615618024, 12.106141703469412, 1.1974153071641922, 1.3297267045293535, 0.10445685631462506, 0.05134169823889222, 17.73513272830418, 73.60873644692558, 62.655860219682964, 58.99792548588344, 56.42813423701695, 37.59942626953125, 24.115941422326223, 32.90380239486694, 44.96842166355678, 62.47686767578125, 39.8646571295602, 0.6082897079842431, 0.09045550333602087, 0.08615817142916576, 0.030632996066872562, 0.02043543237128428, 0.0268296156012054, 0.03759341846619334, 0.13931629434227943, 0.19523194964442933, 0.13694695862276213, 0.08389263121145112, 0.13953923380800656, 0.15133180602320603, 0.2428018684898104, 0.18798207438417844, 43.036235332489014, 89.75286197662354, 57.973465715135845, 53.24257278442383, 36.61347688947405, 29.18834352493286, 59.686241831098286, 62.77247183663504, 70.39999580383301, 74.87902000972203, 10.71058646270207, 0.49741317757538384, 1.1487109320504325, 3.243650781256812, 28.367655311311992, 73.42510945456368, 66.62761034284318, 74.24712998526437, 72.52113492148263, 71.070983341762, 64.04036521911621, 59.30498027801514, 50.76809344972883, 54.09125355311802, 54.65971347263881, 56.31985698427473, 55.81748832975115, 56.29741430282593, 60.238602774483816, 58.421065194266184, 61.92664677756173, 60.86598341805594, 62.25501864297049, 61.85464259556362, 57.8723520551409, 60.67654078347342, 59.98457663399832, 61.879892349243164, 56.30482455662319, 46.94554546901158, 47.30062620980399, 46.11586454936436, 43.79663923808506, 45.289383275168284, 47.740026814596995, 47.29786777496338, 45.18443073545183, 44.75496258054461, 45.8490571975708, 44.01983969552176, 43.79789686203003, 47.19946738651821, 45.069900103977744, 46.95319196156093, 42.60295261655535, 45.411657673971995, 42.554235322134836, 43.36124774387905, 44.26256111689976, 41.9818114553179, 41.62370477403913, 41.7146566935948, 40.72815840584891, 40.378195013318745, 40.506701946258545, 39.34426137379238, 41.71336432865688, 40.99128668648856, 41.5731566292899, 42.74973331178938, 44.13772630691528, 46.96207870755877, 49.46090800421578, 49.386788095746724, 48.25423519951956, 44.873915740421836, 51.00571141924177, 53.791723660060335, 53.59292875017439, 48.318457399095806, 42.012553759983604, 48.66164282390049, 50.10767412185669, 51.27859844480242, 49.128759792872835, 48.11131770270211, 44.76228598185948, 49.78995384488787, 44.485879693712505, 41.99882411956787, 39.272330147879465, 43.141969544546946, 41.49735525676182, 39.27502952303205, 41.748536109924316, 40.629883084978374, 40.111137526375906, 39.832657200949534, 40.312645707811626, 40.90769638334002, 40.18181807654244, 41.34172603062221, 41.06128978729248, 42.29688099452427, 44.65066317149571, 41.50671795436314, 45.99313851765224, 43.61109801701137, 42.459399359566824, 44.99292795998709, 45.362676348005024, 45.73106288909912, 44.39521265029907, 46.14753096444266, 44.89060878753662, 45.64901161193848, 45.68347815104893, 44.936814308166504, 44.15442630222866, 44.92768437521798, 43.73178475243704, 45.78275053841727, 44.558957372392925, 43.93117025920323, 48.015873772757395, 46.88477652413504, 49.41641174043928, 50.59190450395857, 50.9674859046936, 51.37988233566284, 58.76685619354248, 57.92411266054426, 61.29456220354353, 60.84171336037772, 63.48479420798165, 63.578407287597656, 68.61846378871373, 60.85756914956229, 65.53321347917829, 65.83609240395683, 69.03812108721051, 63.7964973449707, 73.8571137019566, 64.02451637813023, 74.46430982862199, 13.48346313408443, 2.725916619811739, 3.9905306696891785, 0.163840829793896, 0.11645027489534446, 21.764650174549647, 80.11792700631278, 67.2253360748291, 67.45462662833077, 67.67518329620361, 43.13080031531197, 33.282114437648225, 41.714020933423726, 55.56141594478062, 71.44533838544572, 52.329218183244976, 0.9134942165442875, 0.18394834654671804, 0.22616131284407207, 0.15931960168693746, 0.0646430609215583, 0.06821886583098344, 0.11842535462762628], [0.09939810633659363, 0.06902551504650287, 0.05455615271681121, 0.0197164888959378, 0.07234182102339608, 0.09708213061094284, 0.02880784882498639, 0.23485665768384933, 32.66971411023821, 67.00379971095494, 46.9969482421875, 36.494141578674316, 15.017961502075195, 30.703756059919083, 41.198718207223074, 52.313893931252615, 62.72710009983608, 53.224330289023264, 1.5322164275816508, 0.012480946839787066, 0.6544050648808479, 8.093894873346601, 55.00209290640694, 60.89813273293631, 76.64794799259731, 60.89029516492571, 63.21225111825125, 52.45654739652361, 57.114241055079866, 45.07266896111624, 46.357484681265696, 44.96017067773001, 48.12287950515747, 48.60266304016113, 49.55718919209072, 48.089118208204, 50.143985407693044, 49.23100253513881, 53.608583041599815, 52.085854053497314, 54.76049361910139, 54.165713923318044, 57.977325439453125, 54.34902824674334, 54.55854770115444, 54.544265678950715, 50.467125279562815, 41.58690711430141, 43.7797030040196, 41.10630021776472, 43.68533951895577, 41.06992292404175, 41.09308474404471, 38.82377529144287, 41.245163440704346, 40.7386223929269, 40.49516446249825, 40.81741843904768, 41.12780836650303, 40.95785542896816, 42.52301706586565, 41.40542711530413, 40.735162190028596, 40.31349686213902, 42.10664626530239, 40.935822691236226, 41.14888572692871, 37.076463154384065, 37.079655851636616, 35.63016782488142, 35.94498722893851, 35.71546391078404, 37.027026721409385, 34.707123960767476, 36.72220230102539, 34.1755450793675, 36.17823478153774, 35.02794313430786, 37.96455757958548, 41.65975897652762, 49.003897190093994, 50.30860560280936, 49.30547332763672, 45.56139830180577, 50.162926197052, 48.37738854544503, 55.29005752290998, 41.18168817247663, 36.55345140184675, 36.12811395100185, 45.81893675667899, 49.26919330869402, 44.66432680402483, 45.764799867357524, 47.447518076215474, 46.96753651755196, 43.00444037573678, 39.33748688016619, 37.443293298993794, 37.086117676326204, 36.59767321177891, 36.288026741572786, 36.25065585545131, 35.75888320377895, 36.647901739392964, 37.53687858581543, 37.24042327063424, 33.44140189034598, 34.9273054259164, 35.87214578901018, 36.124403612954275, 35.95125102996826, 38.44886091777256, 40.556350299290244, 41.2060033934457, 39.14380237034389, 39.31678819656372, 41.65290457861764, 40.82014560699463, 40.21020494188581, 40.024580342429026, 39.24542324883597, 40.507660797664094, 41.65453045708792, 42.69009344918387, 41.56429420198713, 41.66416760853359, 41.96291930334908, 41.856462478637695, 41.4594007219587, 41.823639188494, 46.52323048455374, 51.62230845860073, 50.40598808016096, 51.99019125529698, 52.89136219024658, 54.68774250575474, 52.699202810014995, 55.28914383479527, 54.08951302937099, 55.83366026197161, 54.21944086892264, 59.77878488813128, 57.159560680389404, 56.70564876283918, 50.453979287828716, 49.73907913480486, 38.687920638493125, 61.645446232386995, 58.55003765651158, 67.00161797659737, 59.6356589453561, 73.39076450892857, 19.371574197496685, 0.8961425019162041, 0.5565359422138759, 0.046445935765015225, 0.10339133920414106, 5.9126256108284, 63.96223272596087, 59.049772943769185, 55.47057867050171, 40.55151435307094, 19.920273440224783, 7.0443560140473505, 24.874111482075282, 39.306320735386436, 57.00550869532994, 50.725330761500764, 2.0082039662769864, 0.12759015070540564, 0.057670862546988895, 0.04982052111466016, 0.03790228760668209, 0.033643452384110005, 0.09702495725027152, 0.013853154993349952, 0.06988800090870687, 0.02435399585270456, 0.03533567461584296, 0.09978395527494804, 0.0843561113412891, 0.026896147656121423, 0.1365763156541756, 42.50558056150164, 74.92249488830566, 51.72346380778721, 43.544461318424766, 17.543242590767996, 30.94051592690604, 44.1392479624067, 58.232206208365305, 66.46909414018903, 59.52029800415039, 1.9980068334511347, 0.04889418849987643, 0.6131640321442059, 11.9402699640819, 65.4185265132359, 60.27303804670061, 78.21726812635148, 62.94826126098633, 64.77956322261265, 55.45023781912667, 58.22192982264927, 47.62713943208967, 50.70162350790841, 48.98522738048008, 52.14042173113142, 52.18076297215053, 51.73744010925293, 50.69712802342006, 52.9375399180821, 50.48995358603341, 57.13068049294608, 53.949360915592735, 55.6312175478254, 57.20112827845982, 59.46852697644915, 57.93962798799787, 58.16427367074149, 57.718501567840576, 51.29863704953875, 43.87442084721157, 45.91751085008894, 42.96770524978638, 45.91003111430577, 44.07425798688616, 44.02063179016113, 41.3535692351205, 42.06928580147879, 42.93337767464774, 43.639672483716694, 43.00132410866873, 43.930937494550435, 42.15056930269514, 44.688742773873464, 43.22949947629656, 43.22721004486084, 42.14334317616054, 44.59321199144636, 42.133570534842356, 42.08144167491368, 38.9626350402832, 39.60728195735386, 37.50542756489345, 40.92037337166922, 38.25515556335449, 39.57379164014544, 36.9068089893886, 39.068067005702424, 35.39763593673706, 38.096114771706716, 36.092914376940044, 40.972797530038015, 44.420083727155415, 51.45709071840559, 51.00151470729283, 52.87991850716727, 49.195003918239046, 52.52063758032662, 50.854080881391255, 57.237088680267334, 42.27599818365914, 38.930652482169016, 37.972339562007356, 46.62206513541085, 52.133841787065776, 48.57802472795759, 47.55729961395264, 49.64227335793631, 47.59500053950718, 45.19673599515642, 41.27332101549421, 37.360328333718435, 37.80294942855835, 38.627318450382774, 37.88227006367275, 37.646833828517366, 38.85004643031529, 38.73804841722761, 39.23101268495832, 39.14572007315499, 37.30876922607422, 37.190754073006765, 37.83802740914481, 38.41464103971209, 38.76955849783761, 40.86011164528983, 42.22252137320382, 44.408959661211284, 41.417933872767854, 41.436826024736675, 43.86358165740967, 41.12885407039097, 41.55661991664341, 41.44994074957711, 41.96760586329869, 42.090495177677695, 43.958848408290315, 44.41400752748762, 43.06693594796317, 44.413264070238384, 43.78214529582432, 43.610809666769846, 42.60154560634068, 44.57083879198347, 48.95798001970564, 54.66518865312849, 53.74868304388863, 55.93567718778338, 55.0402524130685, 57.22508219310215, 54.777537550245015, 56.510633672986714, 57.08332851954869, 57.700432777404785, 55.124617440359934, 61.51095690046038, 58.32983534676688, 57.935691833496094, 51.04974562781197, 52.536239760262625, 40.26505054746355, 63.73322010040283, 60.92562675476074, 69.02523912702287, 61.32400172097342, 74.07028443472726, 21.267534358160837, 0.611944026180676, 1.5189509051186698, 0.1745297648012638, 0.08813904585050684, 5.99011322430202, 70.30213042667934, 63.18105370657784, 62.372804505484446, 46.21156556265694, 25.532177107674734, 17.605225733348302, 32.71093429837908, 46.476767880576, 63.68887669699532, 59.576237951006206, 2.903726884296962, 0.17859570948140963, 0.02833036712503859, 0.05244476208463311, 0.05394521674939564, 0.05321276533816542, 0.02416642502482448, 0.1600775524441685, 0.13567870881940636, 0.12302446498402528, 0.0767799150198698, 0.15909420592444284, 0.20216083712875843, 0.16244017066700117, 0.3281306326389313, 55.6815641948155, 83.02234349931989, 59.56903266906738, 51.98236410958426, 21.494379145758494, 45.543270451681956, 55.893657956804546, 64.97616250174386, 71.0242567062378, 65.96994944981166, 2.422508112021855, 0.07259941327252559, 1.231122647012983, 13.953725899968829, 69.70129190172467, 63.36495862688337, 80.31438037327358, 66.73363290514264, 67.03729002816337, 56.389894826071604, 59.94864749908447, 50.461320059640066, 52.06074673788888, 50.64947727748326, 52.183104515075684, 54.465872628348215, 56.070076193128315, 54.22000714710781, 55.19014937537057, 54.12547690527779, 59.23833315713065, 56.39442157745361, 58.74709551674979, 60.3409914289202, 60.68899890354702, 59.58537483215332, 60.88224915095738, 59.67422839573452, 54.73790155138288, 46.52788577760969, 48.71161079406738, 45.15058953421456, 47.95075525556292, 45.505701541900635, 45.27221080235073, 42.92836454936436, 44.22368247168404, 44.439222540174214, 45.553859506334575, 45.487101214272634, 44.95865249633789, 45.16217565536499, 46.834794657570974, 45.35493605477469, 44.18700987952096, 44.84740488869803, 45.30330746514456, 44.868256432669504, 44.932398727961946, 39.36134352002825, 42.13208362034389, 40.107010296412874, 41.83855349676949, 41.661315373011995, 43.485637869153706, 39.039624554770334, 42.30128615243094, 38.06305871691023, 41.46556724820818, 40.1079135622297, 42.753467968532014, 47.317802156720845, 53.07584728513445, 53.79471485955374, 54.436870847429546, 50.133139269692556, 54.99286569867815, 54.512418610709055, 58.17749956675938, 46.90673630578177, 43.27005958557129, 42.905174936567036, 50.25427763802664, 56.072671345302034, 50.704434054238455, 50.18314545495169, 52.7370913369315, 51.24631016595023, 47.94467558179583, 42.97461175918579, 41.59535959788731, 40.53422028677804, 42.58245890481131, 39.61024536405291, 40.36717864445278, 39.84117916652134, 42.040478570120676, 41.24387454986572, 42.07512576239449, 38.478276116507395, 39.340262685503276, 40.62615190233503, 40.72746358598982, 40.64627388545445, 44.212256159101216, 43.6381265095302, 45.980819361550466, 44.15928309304373, 42.84681701660156, 45.26883397783552, 43.0360164642334, 44.54351847512381, 44.497121879032676, 44.15563528878348, 44.52275725773403, 45.93653849193028, 45.57693099975586, 44.5510642187936, 46.326047556740896, 45.89802810123989, 44.7305257661002, 45.220061097826274, 46.508621897016255, 51.25070142745972, 58.446078709193635, 56.75554377692086, 57.04232719966343, 56.89995861053467, 58.79114709581648, 57.36055816922869, 58.70145280020577, 60.32086944580078, 62.01104654584612, 57.32292325156075, 63.85766928536551, 59.98967661176409, 60.506379399980815, 51.77819129398891, 53.29725163323538, 45.7764242036002, 67.6835697719029, 62.73225566319057, 72.32856559753418, 64.31402002062116, 78.96032238006592, 22.675159488405498, 2.2439118325710297, 4.986414670944214, 0.21159045185361589, 0.1460843418857881, 7.992971420288086, 75.47949028015137, 70.15403652191162, 68.25211306980678, 54.0033414704459, 28.566964387893677, 17.283463341849192, 38.40980856759207, 56.81917537961687, 71.36421816689628, 70.64642061505998, 3.904944062232971, 0.290378138422966, 0.2717125900089741, 0.1942728811076709, 0.15754255918519838, 0.10809305762606007, 0.115282678976655], [0.04948552159060325, 0.05236069838117276, 0.0483010030085487, 0.020317352011001537, 0.014594504543180977, 0.1019775029271841, 0.06732539805982794, 0.44817577249237467, 41.45668397630964, 59.822516850062776, 42.01603133337838, 27.518877267837524, 19.66053066934858, 39.54342801230294, 44.40214000429426, 56.68962274278913, 60.90772819519043, 42.409945556095664, 0.06505396137280123, 0.227754893047469, 0.5282544940710068, 9.695029939923968, 60.926161766052246, 62.56189973013741, 66.61172676086426, 60.590126037597656, 55.74764156341553, 48.08295515605381, 47.82163340704781, 44.93451445443289, 46.63926887512207, 43.32832023075649, 47.84131070545742, 47.18843364715576, 48.32898391996111, 48.255162784031455, 48.51916306359427, 49.13147306442261, 48.5859317779541, 48.57730558940342, 48.946605818612234, 51.67872435706002, 51.92326620646885, 52.299188068934846, 53.74157156263079, 51.850549834115164, 47.22194133486067, 42.544414043426514, 41.5067457471575, 40.98274040222168, 41.79013844898769, 40.83936085019793, 40.188168730054585, 39.96214382989066, 40.23421791621617, 41.81697586604527, 40.04910748345511, 40.83267668315342, 41.680732113974436, 40.66964067731585, 42.72146456582205, 43.50121920449393, 42.27783945628575, 45.33436243874686, 46.444187777382986, 48.80206591742379, 45.04252072743007, 42.63294104167393, 38.98629713058472, 36.257225377219065, 34.19736589704241, 36.166874476841514, 35.657467297145296, 35.874539443424766, 34.33154256003243, 36.46557753426688, 34.4749881199428, 34.972440923963276, 34.126049586704795, 35.89491850989205, 39.241653851100374, 46.73583146503994, 47.222976616450715, 48.72407933643886, 50.766981737954275, 50.80155944824219, 50.84816101619175, 31.513836111341202, 34.453063079289024, 33.26273591177804, 42.64214045660836, 46.896348748888286, 48.1941054889134, 48.330786977495464, 48.081833021981375, 42.56614453451974, 37.97596999577114, 36.25829539980207, 36.24330813544137, 38.39522082465035, 33.532708168029785, 34.38619014195034, 35.17822572163173, 36.7594759123666, 37.10870974404471, 35.991342135838096, 34.79077679770333, 36.638521671295166, 36.44369418280465, 35.75044461659023, 39.541023935590474, 42.884000301361084, 41.914945466177805, 40.344760281699045, 40.78476537976946, 39.94455793925694, 40.14363425118582, 41.74528782708304, 40.80652018955776, 39.93738045011248, 37.95360721860613, 38.55741262435913, 38.944232736315044, 43.531082562037874, 40.649751458849224, 40.00741481781006, 40.330457414899556, 40.183541229793, 40.28388711384365, 40.511159215654644, 48.34069858278547, 53.145499501909526, 51.66440759386335, 58.70699051448277, 54.69040366581508, 53.89983415603638, 54.993167945316856, 55.11125258037022, 55.735402311597554, 56.40405525479998, 56.21907336371285, 55.515019348689485, 54.19450725827898, 52.80677134650094, 57.857135500226704, 56.47934940883091, 58.77491610390799, 47.7055151121957, 58.48765672956194, 61.15115138462612, 64.93250696999687, 61.00704574584961, 72.29134409768241, 35.39881018229893, 0.45634785826717106, 0.37563731202057427, 0.3461505685533796, 0.04083627302731786, 1.6988666909081596, 54.18208735329764, 62.94709396362305, 57.176462173461914, 55.194874150412424, 52.34578616278512, 12.059636541775294, 20.405059678213938, 34.876868452344624, 47.231071267809185, 52.261963094983784, 3.375254656587328, 0.34822107745068415, 0.08065118800316538, 0.0956468458420464, 0.024529000212039267, 0.04232389659487775, 0.1099736513569951, 0.04277203844061919, 0.06543369671063763, 0.01575773748170052, 0.035828277468681335, 0.048907294403761625, 0.005862845781458808, 0.027887667130146707, 0.49790894240140915, 52.468255111149375, 67.21844346182687, 46.624875681740896, 35.61385692868914, 22.29677448953901, 40.03022575378418, 48.23457179750715, 63.79583031790597, 66.83818939753941, 49.52643299102783, 0.1192183042211192, 0.36339977011084557, 0.538746925336974, 11.95944699219295, 64.7139583315168, 63.6192626953125, 70.74455002376011, 63.373477118355886, 58.678579330444336, 51.98641838346209, 49.61157274246216, 46.922091824667795, 47.160001618521555, 46.78748437336513, 50.49186781474522, 48.84884466443743, 50.945088386535645, 49.1201822417123, 49.9660142489842, 50.61834934779576, 50.1965902192252, 51.11734812600272, 52.09655775342669, 53.28258398600987, 53.39731611524309, 54.52461269923619, 55.976306779044016, 55.33901800428118, 48.578535420554026, 43.59274435043335, 42.71203933443342, 42.71207754952567, 43.15602922439575, 42.755465575626914, 41.245934690747944, 42.24469307490757, 42.68184246335711, 43.573310238974436, 43.66539471490042, 41.992584637233186, 43.291911670139854, 41.071677344185964, 43.84721864972796, 45.53982414518084, 43.634673254830496, 45.70234945842198, 47.35070187704903, 51.09137575966971, 45.917712347848074, 45.62879582813808, 42.464787687574116, 38.77827501296997, 35.231553145817344, 37.50290536880493, 37.62844542094639, 38.399719783238, 36.82597017288208, 37.717271191733225, 37.15258066994803, 37.724507740565706, 37.00040817260742, 37.419558252607075, 40.68123722076416, 47.875349930354524, 50.20462581089565, 51.15346833637783, 52.27975048337664, 52.90075962884085, 53.78381661006382, 35.447583062308176, 36.24547249930245, 36.831445353371755, 46.23456409999302, 50.26158019474575, 49.951172896793906, 52.168620995112825, 49.846202986580984, 45.78028392791748, 40.597417627062114, 37.633232729775564, 37.159841537475586, 39.26716763632638, 36.22162628173828, 36.55778707776751, 37.45401784351894, 38.43510001046317, 38.62239565168108, 38.02075808388846, 36.850472995213096, 38.65194981438773, 38.53385475703648, 37.391671657562256, 42.090814794812886, 44.81665563583374, 43.58941963740757, 43.2590605872018, 41.659025941576274, 42.25145019803728, 42.51100015640259, 42.391355650765554, 41.84913212912423, 40.49012354442051, 40.340591362544465, 40.5879020690918, 40.4444009235927, 44.12851299558367, 42.49951478413173, 42.34813438143049, 41.78158174242292, 41.5956757409232, 42.389229501996724, 42.44967188153948, 51.133040632520405, 55.76327848434448, 55.43709530149187, 57.4880610874721, 55.9570255279541, 56.402981758117676, 58.591754640851704, 56.78766182490757, 57.27510574885777, 59.09022535596575, 58.43979058946882, 55.39100095203945, 56.32869161878313, 55.123338971819194, 59.62765462057931, 57.7875006539481, 60.14710194723946, 49.73059885842459, 61.06420857565743, 63.853146008082796, 67.77404921395438, 61.71155834197998, 75.38580077035087, 37.429796423230854, 0.2098917258637292, 1.1250620867524828, 0.8289129265717098, 0.01639003542784069, 1.8678531774452753, 58.66276523045131, 69.01387187412807, 65.12602819715227, 55.58132253374372, 35.71199328558785, 12.949138845716204, 27.077081271580287, 42.73104960577828, 54.52889278956822, 61.834214891706196, 5.3050673093114575, 0.3462339740778719, 0.027610948675179055, 0.10087590810975858, 0.05141163145058921, 0.04930417971419437, 0.06615830425705228, 0.21742703366492475, 0.18323663116565772, 0.15383276396564075, 0.14813435902552946, 0.09619028453848191, 0.14831465935068472, 0.22785702613847597, 1.338480131966727, 69.59831265040806, 75.02051312582833, 54.877650669642854, 41.77087804249355, 29.874630996159144, 57.53291865757534, 57.87723663875035, 71.1448426927839, 70.3592654636928, 55.50835950034005, 0.1426408580903496, 0.6348481657249587, 1.63907233944961, 13.987166711262294, 67.62486444200788, 66.74057415553501, 72.36752414703369, 65.692077091762, 63.248604093279155, 54.45870903560093, 53.30244541168213, 49.32372277123587, 50.73431478227888, 49.26115076882498, 53.29649427958897, 52.19852256774902, 53.481834002903526, 52.45976441247122, 54.58809144156319, 54.06417989730835, 54.58158792768206, 53.25710841587612, 54.28706073760986, 55.254507064819336, 55.35684013366699, 57.633073466164724, 58.9609054837908, 57.85035058430263, 52.331465925489155, 45.68031324659075, 45.03369998931885, 44.419552189963206, 45.166226455143516, 44.78738634926932, 43.51581736973354, 43.201609407152446, 42.48701844896589, 46.250524112156455, 45.618422167641775, 45.258529799325125, 45.95065723146711, 44.75570603779384, 46.84467847006661, 47.10507958275931, 45.53997005735125, 48.59081636156355, 50.11265598024641, 53.229339940207346, 47.856513363974436, 46.45700025558472, 44.216713428497314, 41.144963468824116, 37.74329219545637, 40.55885165078299, 40.92417403629848, 42.092364243098665, 39.26612540653774, 40.398688725062776, 38.57800013678414, 39.68674850463867, 39.325014863695415, 38.8202942439488, 44.08534036363874, 51.23893117904663, 51.539784703935894, 54.176612172807964, 55.16815137863159, 54.82908623559134, 58.24007156917027, 40.19636065619332, 39.158914702279226, 40.263244015829905, 50.06110034670149, 53.19503320966448, 50.874953269958496, 54.16017620904105, 54.109436988830566, 49.54576635360718, 42.24043035507202, 41.617461817605154, 40.09817566190447, 43.30897297177996, 38.99778250285557, 39.210435594831196, 39.67486361094883, 42.63605383464268, 41.35336078916277, 43.39459562301636, 39.74815320968628, 42.24572835649763, 41.45880665097918, 40.33550875527518, 46.55132205145699, 49.29333482469831, 46.182730538504465, 44.57355901173183, 43.744520800454275, 43.13615390232631, 44.38076387132917, 44.47043037414551, 43.09715018953596, 43.87060628618513, 41.03636312484741, 43.49220391682216, 41.3657876423427, 46.55494206292288, 43.571284839085166, 43.672565255846294, 44.733951228005544, 44.007426738739014, 45.11093963895525, 43.956388745989116, 51.61661788395473, 57.53822013310024, 54.628457001277376, 59.72113568442208, 58.269174098968506, 59.080358913966585, 60.25920418330601, 59.96479511260986, 61.21416459764753, 61.63756002698626, 61.235836029052734, 56.88666670663016, 56.91610969815935, 57.83721154076712, 62.35880388532366, 60.93379088810512, 61.649948665073936, 52.279500348227366, 63.37185818808419, 66.59169510432652, 71.23662839617047, 66.08762414114815, 76.84415817260742, 39.786601066589355, 0.903628480221544, 5.6117733887263705, 0.9716506387506212, 0.1332079863974026, 2.7112902275153568, 64.74872016906738, 76.46452249799455, 69.99768815721784, 71.89021069662911, 63.55326175689697, 20.23492956161499, 33.50666284561157, 52.84205777304513, 62.40070152282715, 72.8797036579677, 7.816473279680524, 0.8237928098865918, 0.16019333765975066, 0.2413350929106985, 0.12012872179704052, 0.1904176486922162, 0.1658901141158172], [0.05649872722902468, 0.023175909782626798, 0.015374010661616921, 0.01683854028981711, 0.015482608495014054, 0.022607115928881934, 0.023083662946841547, 1.923145204782486, 55.87658623286656, 60.34617478506905, 42.59610169274466, 22.596766437802994, 14.262778299195425, 37.9356495993478, 50.043851443699424, 52.569427830832346, 64.81458214351109, 26.263874530792236, 0.1868300304881164, 0.25759292766451836, 0.2081987267093999, 15.771649973733084, 60.37254319872175, 65.76757621765137, 66.91916370391846, 59.836906569344656, 53.91245903287615, 50.80196591785976, 52.50944750649588, 51.21629394803728, 50.08128138950893, 46.306127071380615, 45.666896275111604, 45.28145885467529, 47.29272263390677, 44.190397126334055, 44.305355072021484, 43.57931695665632, 45.91801806858608, 46.98996877670288, 46.97062151772635, 47.430821555001394, 48.52140038354056, 47.784464018685476, 48.66345630373274, 46.122249943869456, 42.353331633976524, 40.82721887316023, 41.06340898786272, 41.15732084001814, 41.69849170957293, 38.983792304992676, 41.43504728589739, 41.487429755074636, 40.45479890278408, 40.090084484645296, 39.7832589830671, 39.029146671295166, 39.09388651166643, 41.29264048167637, 40.334536007472444, 40.73131288800921, 39.96953671319144, 39.58766719273159, 43.13430220740182, 43.82237189156668, 41.891971247536794, 40.6579190662929, 40.82371003287179, 43.71781192507063, 38.313537802015034, 35.82243837629046, 35.902658803122385, 36.38612835747855, 35.08511291231428, 33.19229507446289, 34.95416716166905, 35.288615226745605, 35.40151303155081, 36.229140758514404, 35.74496596200125, 35.52144588742937, 40.40621362413679, 44.11125019618443, 43.44049889700753, 46.035664967128206, 33.16094480242048, 29.99096815926688, 40.268062591552734, 36.7609280858721, 30.82290029525757, 37.02623462677002, 44.532297134399414, 41.97629805973598, 39.38447059903826, 35.54243639537266, 35.35966750553676, 34.88186420713152, 36.05782944815499, 34.45211812428066, 34.32147462027413, 34.55559417179653, 34.00836794716971, 33.5986396244594, 35.66323777607509, 35.89115606035505, 36.69814763750349, 36.61949750355312, 39.43821491513933, 42.548093114580425, 43.43806702750069, 43.43886259623936, 39.46072013037545, 40.045477049691335, 43.78980221067156, 41.35155425752912, 40.28938661302839, 40.62107276916504, 42.109224046979634, 38.457584381103516, 37.33761814662388, 37.24238961083548, 37.036743777138845, 41.18961954116821, 38.876397473471506, 40.294955594199045, 40.715422357831685, 39.9672611781529, 42.438064915793284, 44.30944408689226, 52.325014523097444, 54.691244397844585, 51.24280827386038, 47.405474526541575, 51.9990884235927, 55.7796310697283, 56.94893993650164, 58.274618012564524, 56.61840370723179, 55.80167770385742, 53.72091109412057, 54.52646092006138, 56.40986394882202, 58.05879654203142, 58.98359135219029, 58.850387437003, 58.12979670933315, 58.85420199802944, 58.83827672685896, 61.290580885750906, 58.09563589096069, 61.16124711717878, 62.565658705575125, 61.79128892081124, 0.8397118385349001, 1.0253369808197021, 0.16331720432000502, 0.11714818887412548, 0.1757293740021331, 38.612511839185444, 65.93513897487095, 56.31133501870291, 61.235544204711914, 59.36018371582031, 20.252386910574778, 12.577279942376272, 33.23854923248291, 43.88483272280012, 60.415309361049104, 10.96286860534123, 0.4555424100586346, 0.09514995464789015, 0.05838699519102063, 0.03700580374736871, 0.057951545342803, 0.08256298755960804, 0.07963789094771657, 0.02100467066546636, 0.06623141640531165, 0.08933049906045198, 0.07911378371396235, 0.0856038151042802, 0.13679530604609422, 3.521543332508632, 64.86898653847831, 65.78541919163295, 50.39434289932251, 29.9117100579398, 22.5323931149074, 41.61758688517979, 55.07733494894845, 58.89500182015555, 70.40720108577183, 30.692927292415074, 0.17253176415605204, 0.1372804314430271, 0.259105029382876, 19.68787704195295, 63.97446155548096, 69.01143305642265, 68.58159664699009, 63.299548285348074, 59.28288500649588, 54.2509822164263, 54.56454747063773, 52.56432090486799, 53.93785122462681, 48.02156434740339, 47.49337271281651, 48.50177867071969, 49.03971862792969, 47.340019021715435, 47.09269094467163, 46.48616879326956, 47.975226811000276, 48.7700833593096, 50.395812443324495, 50.44402599334717, 51.56865446908133, 51.023439747946604, 51.537331989833284, 48.16035461425781, 43.30855260576521, 42.798172678266255, 42.62009382247925, 42.69087164742606, 43.440307821546284, 41.6509347643171, 43.946157523563926, 43.585407052721294, 43.9065180506025, 43.16980055400303, 41.653554235185894, 42.49417856761387, 41.44606365476336, 42.29141623633248, 42.40523815155029, 42.88894394465855, 41.56818866729736, 42.74845831734793, 45.170617716653005, 45.6496821131025, 43.01346608570644, 42.32504899161202, 42.15894535609654, 46.5208854675293, 41.50231279645647, 37.641139779772075, 37.97329146521432, 38.991355419158936, 36.38507570539202, 35.28817401613508, 37.925425325121196, 37.43307249886649, 36.54694093976702, 39.29910850524902, 37.49336896623884, 36.96794618879046, 41.72932434082031, 46.49137994221279, 47.15797274453299, 47.79930189677647, 40.472315311431885, 34.327880859375, 40.60337223325457, 38.22476066861834, 35.602930886404856, 40.37260518755232, 45.38322217123849, 43.464136668613975, 40.24065542221069, 38.17385469164167, 35.59815747397286, 38.24681772504534, 37.71158409118652, 37.46938378470284, 36.12128734588623, 37.93355471747262, 36.63509620938982, 36.889841488429475, 37.26621150970459, 38.446033000946045, 39.57952042988369, 38.67455925260271, 42.499566895621165, 45.8090876851763, 46.5517042023795, 44.91318348475865, 40.377361229487825, 41.48497009277344, 44.33821310315813, 42.11375079836164, 41.1446646962847, 42.12975944791521, 42.467924799237935, 41.681847299848286, 39.82480921064104, 38.53260408129011, 39.56609303610665, 42.389497007642476, 40.07318993977138, 41.80896806716919, 43.795645645686555, 41.568087918417795, 43.68451268332345, 46.69688333783831, 54.61853149959019, 56.656299182346885, 53.10873310906546, 50.01764978681292, 53.65315226146153, 56.88298763547625, 58.569423130580354, 59.57575157710484, 58.43762969970703, 55.72719996316092, 55.94142682211739, 55.63318041392735, 58.184492928641184, 60.17825766972133, 59.51212692260742, 60.44256714412144, 61.50930322919573, 60.740610122680664, 61.427918979099815, 63.65560177394322, 59.833946636744905, 63.84928280966622, 64.24745627811977, 65.37308529445103, 1.0597509741783142, 0.774607272020408, 1.6247364687068122, 0.12395719279135976, 0.19372036361268588, 41.69308253696987, 73.04823916299003, 60.87975474766323, 64.80905137743268, 42.827952657427105, 21.36514786311558, 20.921847581863403, 39.2999700818743, 50.409747055598665, 69.15102931431362, 15.760852473122732, 0.4915800020098686, 0.06282849543328796, 0.054918843254979165, 0.015423138293304613, 0.01891104068740138, 0.042694709197218926, 0.1780951406274523, 0.15597578111503804, 0.1257564505296094, 0.17841943965426513, 0.1781622070286955, 0.2527875969452517, 0.37652190455368584, 6.182415911129542, 79.97555146898542, 72.6045480455671, 59.83839348384312, 34.01048019954136, 24.871403421674454, 48.048175948006765, 63.76582104819161, 65.47156211308071, 76.67573383876255, 31.658146721976145, 0.2924470731190273, 0.43511009216308594, 1.7865586025374276, 18.42697181020464, 63.657005310058594, 68.74401773725236, 70.79754393441337, 65.3372186933245, 61.38121318817139, 55.07213422230312, 56.13115085874285, 55.80382122312273, 57.120501382010325, 50.79371493203299, 50.64641659600394, 51.62445545196533, 52.32670293535505, 50.25879396711077, 49.07040534700666, 48.81552805219378, 51.781203338078086, 52.894356863839285, 53.01764222553798, 52.620226110730854, 53.74060228892735, 52.485955647059846, 52.51205308096749, 52.49750702721732, 45.35765280042376, 45.44735057013375, 45.0074496950422, 43.64920541218349, 46.089996406010215, 42.98354714257376, 45.12636463982718, 45.24290330069405, 45.84827899932861, 43.622058800288606, 45.59359972817557, 44.09368167604719, 44.06919275011335, 45.268674169267925, 43.80443511690412, 45.57564558301653, 44.65302208491734, 43.62619297845023, 46.827360085078645, 46.46525818961007, 44.27441126959664, 42.72985798971993, 43.14586400985718, 48.481993675231934, 44.60012197494507, 42.23149149758475, 41.206659998212544, 40.831898484911235, 38.35611983707973, 36.9181866645813, 40.99342673165457, 39.59008169174194, 40.27703619003296, 41.76438842500959, 41.166898931775776, 38.99620526177542, 44.516396181924, 49.43503291266305, 50.51835087367466, 50.16106060573033, 44.87910951886858, 37.12506232942854, 45.175220898219514, 42.2675005367824, 38.59672553198678, 42.6485710144043, 48.544301646096365, 46.73398324421474, 42.79576860155378, 40.68628508704049, 38.41368218830654, 41.14267751148769, 40.16728591918945, 40.34549331665039, 38.92305810110909, 40.961454595838276, 39.0563245500837, 39.260844775608604, 39.18118020466396, 41.248953683035715, 43.090010915483745, 41.03790215083531, 44.99366099493844, 47.30328736986433, 47.90868738719395, 46.114092758723665, 40.32279702595302, 42.91959244864327, 46.68725313459124, 44.71034819739205, 45.171646050044465, 43.75983115604946, 45.77855035236904, 43.21352904183524, 41.04715020315987, 40.074305125645225, 41.14509548459734, 45.391480105263845, 43.169734546116416, 43.7116836139134, 44.52505016326904, 44.54386935915266, 46.827582427433555, 50.52403450012207, 57.18771825517927, 59.644941738673616, 54.9730007989066, 56.91856936046055, 55.59844984327044, 58.1171475137983, 62.36919839041573, 63.128045899527415, 60.30884211403983, 57.09969847542899, 57.297305243355886, 56.04683099474226, 60.55386338915144, 63.570875440325054, 64.48538344247001, 62.69875144958496, 64.79823998042515, 63.881779534476145, 63.19875771658761, 65.3699586050851, 62.550685337611604, 67.15661144256592, 66.13804027012416, 68.81153338296073, 1.0391165614128113, 4.615470324243818, 3.151763243334634, 0.26786065527370995, 0.5570809958236558, 46.290854930877686, 78.74548407963344, 66.79062897818429, 77.24659088679722, 75.17055947440011, 31.04886266163417, 22.39129604612078, 50.12832416806902, 58.895015716552734, 80.36236463274274, 21.542314767837524, 0.8491257791008268, 0.22313512808510236, 0.15570032303886755, 0.09378554964704172, 0.138486649574978, 0.20669723727873393], [0.10488603649927036, 0.04322952710624252, 0.08239123677568776, 0.02592965085724635, 0.08952491291399513, 0.04005216135244284, 0.28947424835392405, 7.718022516795567, 67.93433720724923, 49.485032149723594, 33.3119604246957, 27.067126240049088, 23.48080485207694, 45.79032754898071, 49.47056600025722, 54.818663937704905, 64.22876562391008, 29.72124603816441, 0.041892344930342267, 0.28774420118757654, 0.021929941372945905, 26.466013261250087, 63.85396589551653, 64.79644734518868, 66.8359659739903, 63.77267892020089, 63.05433940887451, 60.946346282958984, 62.6861891065325, 59.62660544259207, 57.10486446108137, 52.77027245930263, 50.09792579923357, 49.51383590698242, 46.036523069654194, 43.41903591156006, 43.1920347894941, 43.10163525172642, 42.16178716932024, 42.572189467293875, 42.92716598510742, 43.728425298418315, 42.21606649671282, 42.80816418784005, 44.406284604753765, 40.80146190098354, 41.312255246298655, 40.576864855630056, 41.4619402885437, 41.484838077000205, 40.501060009002686, 39.3061956678118, 40.65170390265328, 40.23302977425711, 40.68703549248831, 40.71886171613421, 39.64226613725935, 39.33498205457415, 40.467864990234375, 39.85126795087542, 41.30172872543335, 40.20100552695138, 39.86741556440081, 41.04339470182146, 43.75802115031651, 40.08208015986851, 38.902328150612966, 40.77454457964216, 38.720257554735454, 40.63031734739031, 41.31150484085083, 42.61208602360317, 36.58600371224539, 35.59726463045393, 34.474640710013254, 34.0710163797651, 35.51862491880144, 34.4699923651559, 34.95083550044468, 35.43371793201992, 34.556601660592214, 35.96886471339634, 34.579353536878315, 36.64943034308297, 37.10082701274327, 39.17328357696533, 39.906464440482004, 34.848801204136436, 41.35307591302054, 37.23345422744751, 33.40812349319458, 40.30105611256191, 34.66645268031529, 34.649770055498394, 34.50681781768799, 34.01729638235909, 34.8605123928615, 35.334414277757915, 33.412664140973774, 34.67149359839303, 34.56002017429897, 34.72348002025059, 36.67079257965088, 36.05507101331438, 38.22850227355957, 36.85683059692383, 38.789315700531006, 40.95529154368809, 44.93817962918963, 40.94671399252755, 36.91152334213257, 37.03790065220424, 37.43540709359305, 40.9799541745867, 41.13529852458409, 41.33288444791521, 39.680526392800466, 40.00311388288225, 40.9620486668178, 38.50095851080758, 36.906367778778076, 37.247058800288606, 37.90541451317923, 40.58281251362392, 38.95597519193377, 41.15138360432216, 38.535901001521516, 40.270001138959614, 40.79398911339896, 41.782870633261545, 51.03572416305542, 54.23659944534302, 48.16799068450928, 40.39497143881661, 52.01890468597412, 54.36133350644793, 53.52371426991054, 55.31315680912563, 54.778479031154085, 55.88046680177961, 55.106156076703755, 58.0481345312936, 55.32188374655587, 57.12844317299979, 54.22290107182094, 58.153552600315635, 56.613331522260395, 61.60737010410854, 57.3985926083156, 60.23465619768415, 51.854888984135215, 64.59074592590332, 56.47318288258144, 76.58503205435616, 10.552270889282227, 2.0813721886702945, 0.6158215552568436, 0.07001068682542869, 0.028386171541309783, 24.408629076821462, 64.31916863577706, 57.74022511073521, 56.515480041503906, 54.25477245875767, 30.976330416543142, 12.93533798626491, 24.14921634537833, 42.05056735447475, 62.90646089826311, 22.65009559903826, 0.41710554542286055, 0.10430624868188586, 0.16849271660404547, 0.022774105093308857, 0.053043484421713014, 0.08388056007346936, 0.10212709954274551, 0.06105756653206689, 0.08351748955569097, 0.02522836116674755, 0.08598564032997404, 0.19558503212673323, 0.32743567707283155, 9.920863764626638, 78.25942979540143, 57.25111709322248, 41.90760122026716, 29.462922436850413, 20.631058522633143, 38.60643563951765, 56.8491325378418, 60.685601234436035, 71.80661691938127, 31.414150306156703, 0.07117051351815462, 0.2815822889762265, 0.12511010521224566, 31.09597839627947, 65.42084721156529, 67.97768701825822, 69.9009622846331, 64.02933147975376, 66.86083357674735, 64.48712744031633, 64.5319572176252, 62.45523793356759, 60.70037310464041, 55.679775033678325, 51.771531445639475, 51.340406145368306, 49.08131749289376, 45.66342912401472, 46.26163080760411, 45.97260659081595, 45.00794301714216, 45.595236028943745, 44.99339001519339, 45.51711743218558, 44.89702197483608, 44.677497114454, 45.227238586970735, 40.56411838531494, 43.13169315883091, 42.88039766039167, 42.8778407233102, 43.62307671138218, 41.669830390385215, 41.87527820042202, 42.15124327795846, 43.473030362810405, 43.3778087752206, 42.205772740500315, 41.88346665246146, 42.4322874886649, 41.446980816977366, 42.44138615471976, 42.78011431012835, 42.03982891355242, 42.53679881777082, 42.96901845932007, 45.306687763759065, 40.9220791544233, 39.03668199266706, 40.75654527119228, 38.23021500451224, 41.030165331704275, 44.66505983897618, 44.40874774115426, 38.93789945329939, 37.77088696616036, 37.074396065303254, 36.823100566864014, 38.06672041756766, 37.768402985164094, 35.88739708491734, 37.05775165557861, 37.74256263460432, 36.99785818372454, 36.86875717980521, 38.47415236064366, 39.66450384684971, 42.00116566249302, 41.75415372848511, 39.16450105394636, 44.11047894614083, 40.29965257644653, 36.08495174135481, 40.12233107430594, 37.25104011808123, 37.584133284432546, 36.07978228160313, 37.08180284500122, 36.54879263469151, 36.62641443525042, 36.04997798374721, 36.42341586521694, 37.52594212123326, 36.83654533113752, 37.151326520102366, 38.20329768317086, 40.11985751560756, 38.20060178211757, 41.56228617259434, 43.57096522194998, 46.469705036708284, 41.81093093327114, 38.00262328556606, 37.46796635219029, 38.503831590924946, 42.25505978720528, 41.51188046591622, 42.842411858694895, 40.34319346291678, 40.93287318093436, 42.278301511492046, 40.3579340662275, 39.9120785849435, 39.81257690702166, 40.02493470055716, 40.75397443771362, 41.14111416680472, 42.013147830963135, 40.675136702401296, 42.389024530138286, 42.40368175506592, 44.5591276032584, 53.67798164912632, 57.13199717657906, 50.336919512067524, 46.305946418217246, 54.262940066201345, 56.281958035060335, 54.889136041913716, 57.03585842677525, 55.886918204171316, 56.51206847599575, 57.54076664788382, 58.839061873299734, 57.56343167168753, 58.42559541974749, 56.41713176454817, 60.78813580104283, 60.828782762799946, 64.06095967973981, 59.082589285714285, 62.935935156685964, 56.55293083190918, 68.16396822248186, 58.54435403006417, 79.2593172618321, 12.72500819819314, 1.4044889956712723, 0.9640512636729649, 0.12683823890984058, 0.09240300061979465, 25.113509927477153, 72.06483977181571, 61.2237183707101, 62.43712397984096, 50.65815557752337, 25.769032512392315, 15.24702102797372, 36.02088935034615, 48.72887706756592, 71.69047083173479, 27.95713836806161, 0.4395006208547524, 0.06438198100243296, 0.12748775977109159, 0.061680834873446395, 0.03288572893611022, 0.07106957464878048, 0.18897506967186928, 0.1520300864108971, 0.14712069556117058, 0.2349728500204427, 0.30072471180132454, 0.37197528566632954, 0.4615464136004448, 13.538091608456202, 90.67989758082798, 64.28307969229562, 50.090689250401084, 37.65544959477016, 31.465362003871373, 59.03309031895229, 63.96556091308594, 66.81662218911308, 76.99470479147774, 37.514595712934224, 0.2139047041003193, 0.7033477414931569, 1.1431850514241626, 31.64831154687064, 66.0293218067714, 69.18523529597691, 73.78460230146135, 68.31484140668596, 70.2731078011649, 66.32498850141252, 66.95047228676933, 65.15561362675258, 64.05107239314488, 59.5355840410505, 55.340942655290874, 53.95302261625017, 52.05778680528913, 47.812725816454204, 49.59473378317696, 48.5584203856332, 47.58208383832659, 48.31197125571114, 48.13162728718349, 48.76619931629726, 47.06869534083775, 48.616608074733186, 48.4528876713344, 44.55145679201399, 45.98779535293579, 44.68265962600708, 46.02046578271048, 45.64920963559832, 44.58330386025565, 44.01668173926217, 43.98492152350289, 44.756425176348, 45.55064249038696, 44.91297156470162, 43.727935450417654, 43.8167507989066, 45.3456254686628, 46.049015930720735, 44.95738445009504, 43.82706192561558, 44.748323576790945, 44.064297744206016, 48.153864996773855, 41.87653235026768, 40.72116504396711, 42.185664653778076, 39.5853464944022, 42.21468033109392, 45.57264048712594, 48.17631810052054, 41.33835962840489, 41.012527329581125, 40.52724429539272, 38.598928110940115, 40.76716559273856, 39.85486364364624, 39.419426986149375, 39.627865995679585, 39.206471647535054, 40.60314294270107, 39.13567645209176, 41.94022648675101, 42.40586001532418, 44.00128105708531, 44.09309802736555, 40.670908723558696, 45.716641902923584, 43.23756980895996, 38.60371194566999, 42.7902204649789, 39.2951271874564, 38.8996913092477, 39.60790729522705, 39.20092698505947, 40.73747941425869, 39.04224055153983, 38.10513353347778, 40.37488419669015, 39.70354230063302, 39.306758471897666, 41.21582119805472, 41.76149102619716, 42.843440192086355, 41.76815782274519, 44.3383138520377, 45.24032204491751, 46.832036222730366, 42.993608134133474, 37.32516002655029, 38.20377363477434, 38.9576392854963, 42.90931953702654, 42.397796630859375, 43.99044534138271, 42.180262429373606, 42.51131977353777, 46.5149621282305, 42.18234688895089, 42.643554415021626, 42.46277618408203, 43.31007773535592, 42.47697830200195, 42.018782820020405, 45.174991607666016, 42.77981553758894, 43.356502124241416, 44.753878661564414, 45.61170673370361, 55.9056852885655, 59.02733026232038, 54.73124170303345, 48.4014710017613, 56.956645488739014, 57.54544278553554, 56.907879556928364, 58.834816523960654, 57.93849890572684, 59.36352579934256, 60.314226967947825, 61.59096540723528, 59.873377663748606, 61.5066351209368, 58.62674576895577, 62.95748846871512, 62.46709850856236, 67.07533141544887, 62.60644463130406, 65.380797794887, 58.994152614048545, 70.45763111114502, 62.03639357430594, 81.64885139465332, 13.355767403330121, 4.148574394839151, 2.6000599903719763, 0.25261305059705463, 0.22845937524523052, 29.887318406786235, 78.3081853049142, 68.823776108878, 70.2353651864188, 69.08711978367397, 43.313916615077424, 22.216937950679235, 41.15780373982021, 56.275666441236226, 79.8322309766497, 37.24712133407593, 0.48567680163042887, 0.15928179371569837, 0.253167983676706, 0.12063797589923654, 0.12989421135612897, 0.15718963955129894], [0.027368626856644238, 0.035623091871717145, 0.02387071098200977, 0.012220412293182952, 0.04607755231804081, 0.18180973987494195, 0.4039892463811806, 12.176354987280709, 68.9891779763358, 47.162162508283345, 39.382073470524375, 20.978944403784617, 27.83130301748003, 48.59789310182844, 46.78568478993007, 54.58902250017439, 64.31687573024205, 21.748554672513688, 0.28763506561517715, 0.32326667649405344, 0.4211675003170967, 33.62745380401611, 58.20575441632952, 62.85103511810303, 65.2804936000279, 64.13666725158691, 60.537952014378135, 61.570954595293315, 62.133195877075195, 62.28837694440569, 57.01504509789603, 55.49707562582833, 49.2786671774728, 46.84336873463222, 43.157738481249126, 42.81287506648472, 43.481194496154785, 41.58571202414376, 42.26038210732596, 42.383254051208496, 43.18370042528425, 40.24501541682652, 40.26125683103289, 40.19974095480782, 39.174287591661724, 40.79955809456961, 39.499779428754536, 40.43865476335798, 40.634024211338584, 42.25813089098249, 41.85631309236799, 40.14389133453369, 39.751783643450054, 40.677870818546836, 39.66958992821829, 40.090907846178325, 39.70811421530587, 40.25866862705776, 38.08914572851998, 39.162392275674, 42.174926212855745, 41.58857120786394, 42.141293457576204, 39.813466276441304, 41.11081654684884, 42.359852518354145, 36.143973214285715, 39.1194280896868, 38.68958820615496, 37.673098019191194, 38.44017914363316, 39.340339115687776, 40.48395354407174, 35.5289568901062, 34.109082085745676, 33.38763325554984, 34.110075678144185, 34.713801179613384, 33.794971397944856, 34.36109324863979, 34.36786774226597, 33.90998840332031, 34.59611259187971, 35.84456491470337, 35.3717052595956, 37.743854999542236, 36.14265305655343, 36.19851657322475, 39.191765785217285, 35.71728433881487, 34.900398526872905, 35.91231679916382, 36.05276073728289, 34.741448061806814, 33.97334902627127, 34.86184992109026, 35.00387804848807, 35.123421805245535, 35.79545504706246, 34.30242960793631, 35.206181798662456, 36.5425739969526, 34.93966627120972, 36.6872250693185, 36.32302481787545, 40.68896014349801, 40.93503059659685, 40.137985365731375, 38.52136537006923, 38.04865162713187, 39.18765592575073, 38.39529725483486, 36.16057940891811, 39.098243032182964, 42.953086239951, 41.84796830586025, 39.09242738996233, 41.2156857081822, 41.139943395342144, 37.397956303187776, 36.8696882384164, 37.402295453207834, 38.556756019592285, 41.22096633911133, 40.04213844026838, 38.953567641122, 39.15090342930385, 41.499606473105295, 40.102546078818186, 41.951475620269775, 45.51040199824742, 53.975218636649, 52.25766216005598, 57.335103443690706, 53.265578269958496, 54.300199781145366, 52.41263478142874, 56.82666553769793, 52.03055681501116, 55.47772489275251, 52.71057006290981, 54.08365222385952, 51.06331545966012, 52.622713565826416, 49.45798281260899, 54.725116865975515, 49.743918555123464, 54.249088832310264, 51.5304081099374, 56.48887538909912, 49.6514310836792, 59.86841664995466, 56.32284470966884, 72.42580563681466, 31.190098694392614, 0.2744298242032528, 1.444181774343763, 0.1058776340048228, 0.16095101700297423, 12.50480501992362, 64.63877187456403, 55.07175554547991, 61.95179925646101, 45.15213203430176, 53.29115111487252, 18.126441376549856, 17.117285013198853, 36.8168854032244, 53.81308242252895, 32.17138235909598, 0.2208023246909891, 0.03995230135374835, 0.07513739208557776, 0.05993444179849965, 0.05848728266677686, 0.04643717248524938, 0.18750689631061895, 0.09120915218123368, 0.04400750482454896, 0.11554519060466971, 0.052354388005499325, 0.29618957372648375, 0.3751217611134052, 16.082006897245133, 79.5214102608817, 53.32157380240304, 46.05157634190151, 29.181367533547537, 33.48791660581316, 49.36598171506609, 53.7817634173802, 63.24271202087402, 70.69134766714913, 23.30840962273734, 0.3667510002851486, 0.17483727687171527, 0.3372585028409958, 39.355559144701274, 60.954920360020225, 64.83584363119942, 68.59070573534284, 65.26875114440918, 63.24144744873047, 63.35111781529018, 63.09880787985665, 64.67516653878349, 60.8270457131522, 56.75239624295916, 51.05857678822109, 49.81355340140206, 45.063469546181814, 45.162342412131174, 46.471695695604595, 43.98548085348946, 44.37202303750174, 43.42006424495152, 45.36431959697178, 42.388089997427805, 41.625789233616416, 41.93841300691877, 41.20641681126186, 43.11138357434954, 41.09668391091483, 42.274990694863455, 42.18663740158081, 43.64778103147234, 42.16469151633126, 42.01518712724958, 42.29815946306501, 43.10728761128017, 41.65183803013393, 42.29897240230015, 40.49755464281355, 40.35665907178606, 40.18609816687447, 41.188275064740864, 43.03285155977522, 42.98151479448591, 41.52312959943499, 40.777334281376426, 42.06446375165667, 43.2139424596514, 37.52264520100185, 40.28113562720162, 40.211493832724436, 37.960736070360454, 39.44252627236502, 40.31227050508772, 40.85595662253243, 38.46556438718523, 36.885022912706646, 35.104359422411235, 36.201160362788606, 37.3307637487139, 36.48343440464565, 36.41177415847778, 35.67096764700753, 36.91023097719465, 36.872957365853445, 37.58914293561663, 37.45921509606497, 39.41100924355643, 38.57254580089024, 37.67471694946289, 41.31012909752982, 36.79366799763271, 37.38472693307059, 37.014523438044954, 38.52048642294747, 37.5850122315543, 36.264340332576204, 36.53912074225289, 37.76170492172241, 38.013955797467915, 36.564860343933105, 36.615436281476704, 38.020556586129324, 38.90088292530605, 37.32841525759016, 39.26540279388428, 39.88111393792288, 41.892648696899414, 40.94666535513741, 39.66391324996948, 37.898275239127024, 37.31909077508109, 39.66479219709124, 38.97858463014875, 35.344582966395784, 39.13957439150129, 43.58016463688442, 42.854244640895296, 39.94327252251761, 42.98252575738089, 42.380422660282676, 39.33615630013602, 39.10340901783535, 39.034264019557405, 40.05432905469622, 43.450452191489084, 40.973756381443565, 41.254894392830984, 40.58233308792114, 42.11778770174299, 41.05145461218697, 42.447754178728374, 48.42070361546108, 55.665833473205566, 55.13398013796125, 56.848667008536204, 56.80117607116699, 55.02802358354841, 56.44913516725813, 57.166335174015586, 53.528845514569966, 57.75857877731323, 54.41924326760428, 56.73701293127877, 53.84719807761056, 56.05920921053205, 52.77381951468331, 55.57890803473336, 52.24267142159598, 56.36137247085571, 53.103806836264475, 58.81557696206229, 51.38168886729649, 62.70114857809884, 57.98100798470633, 74.31538214002336, 35.21669789722988, 0.35515171555536135, 2.061683599437986, 0.10194121487438679, 0.16588005822684082, 13.579838122640338, 71.23933819362095, 59.70307731628418, 68.6171714237758, 50.70682076045445, 42.56795801435198, 16.958893878119333, 21.64846760886056, 40.37829923629761, 62.61342757088797, 39.93818991524832, 0.09744575074208633, 0.03781053610146046, 0.012681098555081656, 0.03144162999732154, 0.016658082205270017, 0.03566390914576394, 0.31325299239584375, 0.16569415320243153, 0.1933323365769216, 0.1519265826791525, 0.10462379628526312, 0.5206164696386882, 0.7598478868603706, 21.39521619251796, 90.47936562129429, 59.33009106772286, 55.768527848379954, 30.18074083328247, 39.89011880329677, 62.957141058785574, 60.2611357825143, 67.01019900185722, 79.17272881099156, 29.546755926949636, 0.38014085750494686, 0.7279342679040772, 0.8463810235261917, 37.48710516520909, 58.92137023380825, 67.91135951450893, 69.06237724849156, 67.21589347294399, 64.75364644186837, 65.97759941646031, 66.6986139842442, 68.34746319907052, 62.7633627482823, 60.49453966958182, 55.442549637385774, 51.575175353458945, 46.86838224955967, 47.4262044770377, 49.78527075903756, 47.56888573510306, 48.156084946223665, 48.47014004843575, 48.40479918888637, 45.00310707092285, 43.94217273167202, 45.430480343954905, 43.98564413615635, 45.450237546648296, 42.45454256875174, 44.69130318505423, 44.31540216718401, 47.4459582056318, 45.53817742211478, 43.68227883747646, 43.88328327451433, 44.921601227351594, 43.401675837380544, 44.42880024228777, 42.44319268635341, 42.96935544695173, 41.44875260761806, 43.73563405445644, 46.82769359861101, 45.421089853559224, 45.07810592651367, 42.56492165156773, 43.60951035363333, 45.2391790662493, 37.515453815460205, 41.49584402356829, 39.634904520852224, 37.32390587670462, 38.66683285576956, 40.60368837629046, 42.786183561597554, 41.179280621664866, 39.12352057865688, 38.219612053462434, 38.69180120740618, 41.24434355327061, 39.00873286383492, 38.460533891405376, 38.451546396527974, 38.817372526441304, 40.38493129185268, 40.53831972394671, 39.933211530957905, 44.48075887135097, 42.13428272519793, 40.002575397491455, 43.92311382293701, 39.58816746303013, 39.102599552699495, 39.45577996117728, 41.07184757505144, 40.04595994949341, 38.902415003095356, 39.61321919304984, 40.2655542918614, 40.97517728805542, 38.839575495038716, 38.28580059323992, 40.32485369273594, 41.82742943082537, 39.05874947139195, 41.89550788061959, 42.08899089268276, 44.27796179907662, 41.43935169492449, 40.12271669932774, 38.46267393657139, 37.77939503533499, 39.55409697123936, 38.14272676195417, 35.24292734691075, 40.18693195070539, 45.4308624948774, 45.447458267211914, 41.36424514225551, 43.77769150052752, 46.52476256234305, 41.560670716421946, 41.607053416115896, 41.96053607123238, 42.81754425593785, 45.70044912610735, 44.19604253768921, 42.904445375714985, 42.80937664849417, 45.5141818182809, 44.256794112069265, 45.83347238813128, 49.55649437223162, 56.95153856277466, 56.567942414964946, 58.93243176596505, 59.78503826686314, 59.03389630998884, 57.234611647469656, 60.60916410173689, 56.63507243565151, 60.81050205230713, 57.98919643674578, 58.35065909794399, 57.498598030635286, 58.88940852028983, 55.11439664023263, 58.87407384599958, 55.65541464941842, 61.106349400111604, 56.9725638117109, 62.18291023799351, 54.488999707358225, 64.03475107465471, 60.40199661254883, 76.20667484828404, 36.02242142813546, 1.1205632367304392, 5.5948514853205, 0.17580565490892955, 0.20088114722498826, 14.932279791150775, 79.07687146323067, 65.08314391544887, 77.95334775107247, 56.523557322365896, 72.0555500302996, 30.692711898258754, 30.392560141427175, 52.441157136644634, 70.63979203360421, 50.22421973092215, 0.4139271245471069, 0.11670954312597003, 0.11287186441144773, 0.22427182351904257, 0.12799287480967386, 0.09550098116908755], [0.05325671744399837, 0.05268544524109789, 0.016226993640884757, 0.05403809801542333, 0.06334169182394232, 0.12880022291626247, 0.2092670529548611, 18.273567744663783, 66.09209183284214, 47.9174143246242, 40.36366980416434, 16.40198186465672, 28.100121872765676, 35.41756337029593, 48.62175668988909, 59.71445846557617, 60.92279188973563, 11.546881198883057, 0.2818313384694712, 0.41077000967093874, 0.36602203654391424, 36.83705602373396, 60.96029131753104, 61.462333406720845, 65.07753671918596, 63.65411485944475, 62.61112771715437, 62.31057643890381, 62.13402966090611, 63.83657455444336, 57.91350276129586, 53.74916941779, 48.50431476320539, 48.714518615177695, 42.494720527103965, 43.22402776990618, 42.96202857153756, 42.389333724975586, 40.04450082778931, 43.20744936806815, 40.06209019252232, 40.50222730636597, 38.08285413469587, 40.43513550077166, 40.167313711983816, 39.401135853358674, 39.861377579825266, 40.515328134809224, 40.06807606560843, 40.43011542728969, 40.18004976000105, 41.91337169919695, 40.41534008298601, 39.2316449710301, 39.51783432279314, 41.251395974840435, 39.21144308362688, 39.66218662261963, 38.20527444566999, 40.93224089486258, 40.63731418337141, 40.39512777328491, 40.855591842106406, 42.52418436322893, 41.7360953603472, 40.65889181409563, 40.70359304973057, 39.7264609336853, 38.85922152655465, 37.87024620601109, 39.95984397615705, 37.251894746507915, 37.9391063281468, 40.572678565979004, 35.13988208770752, 34.21155411856515, 33.60842963627407, 32.58689158303397, 34.03191539219448, 35.12568344388689, 34.484468936920166, 33.863925320761545, 34.89210932595389, 35.85340997150966, 34.31891073499407, 36.47759444372994, 38.722084930964876, 35.66106646401541, 36.51280096599034, 34.03932217189244, 35.31047773361206, 33.98483092444283, 35.39195578438895, 34.859581334250315, 32.92263548714774, 35.34521525246756, 33.80010264260428, 34.42407866886684, 33.80736698423113, 35.65043224607195, 35.34752900259835, 35.067613874162944, 36.61092690059117, 34.351362296513145, 40.81280830928257, 40.298367159707205, 38.467138154166086, 38.36314099175589, 35.99938814980643, 39.4437005179269, 37.65652309145246, 36.79011051995413, 37.73513848440987, 37.44573906489781, 39.710393224443706, 39.92027051108224, 40.936913558415, 40.8004161970956, 38.71714128766741, 37.32287406921387, 38.16428007398333, 38.171506200517925, 37.47276060921805, 40.54022005626133, 39.50445556640625, 40.22347600119454, 41.24208538872855, 39.18877111162458, 39.9634188243321, 38.93507501057216, 40.8894156728472, 45.41535758972168, 49.03148848669869, 49.333297388894216, 49.03385782241821, 47.66712631498064, 46.602123805454795, 49.102613721575054, 49.25019345964704, 46.631038733891074, 44.7020138331822, 45.60422352382115, 44.842933722904746, 44.48590748650687, 46.17641462598528, 47.618850231170654, 45.20496613638741, 48.09497206551688, 47.23318004608154, 48.31591088431222, 46.7029595375061, 54.65670142854963, 60.10315459115164, 66.5403687613351, 53.52382544108799, 0.47486355900764465, 1.4641716331243515, 0.15157032465296133, 0.2997828780540398, 7.5915244817733765, 63.604525566101074, 54.81850412913731, 62.45862865447998, 43.38819285801479, 68.46497113364083, 29.862033912113734, 37.07486159460885, 36.71445853369576, 60.276248114449636, 41.2772467476981, 0.6175516024231911, 0.1120675764977932, 0.06425311363169126, 0.03995040145569614, 0.04320973423974855, 0.035624588041433265, 0.02494308299251965, 0.1024059367233089, 0.03325571033305355, 0.020490079885348678, 0.048993814403989484, 0.10892457515001297, 0.2537094274801867, 22.050533805574688, 77.83256721496582, 51.04707057135445, 48.058396748134065, 16.972635677882604, 30.40659897668021, 43.080842767442974, 55.176840100969585, 64.4192087990897, 68.40057522909981, 12.787121619497027, 0.4272498610828604, 0.05909500577087913, 0.5870324000716209, 43.056499753679546, 62.23107515062605, 63.462351526532856, 64.88469641549247, 66.4372991834368, 64.87159211294991, 65.85356712341309, 63.575016566685264, 64.96637943812779, 59.575223514011924, 58.27925246102469, 51.65807778494698, 49.43386214120047, 44.29690606253487, 45.5785151890346, 45.95019517626081, 45.82727459498814, 42.44445031029837, 45.02921492712838, 41.077517305101665, 42.286198139190674, 40.50763995306832, 42.343916824885774, 42.833139487675254, 41.77947991234915, 42.034621238708496, 42.123888220105854, 41.6301075390407, 42.36530338014875, 40.138569014413015, 43.71143347876412, 41.981728076934814, 40.92045675005232, 41.85956137520926, 42.89004176003592, 40.656122956957134, 42.063543115343364, 39.94014235905239, 40.94492483139038, 41.843643052237375, 41.107377188546316, 42.180286748068674, 43.66442196709769, 43.817049571446006, 41.70729855128697, 41.10035950796944, 41.77724606650216, 39.00450835909162, 38.020445414951865, 39.57446214130947, 37.70634167534964, 36.986202580588206, 41.71599422182356, 37.43557385035923, 35.62671109608242, 36.621849468776155, 36.80053629193987, 35.91922330856323, 36.155368259974885, 36.833411693573, 36.15003204345703, 37.455720152173726, 37.699407373155864, 36.23169769559588, 38.66085045678275, 40.79106044769287, 38.20269318989345, 37.40357392174857, 37.16100188664028, 37.68010180337088, 36.088019371032715, 35.42272588184902, 36.384009156908306, 35.36448608125959, 37.17710086277553, 35.92335401262556, 37.737174306597026, 37.2267735345023, 37.73402329853603, 38.11505208696638, 37.83320188522339, 38.32519687925066, 39.015802655901226, 43.32780606406075, 39.86935758590698, 37.23946441922869, 38.0601543698992, 37.06078107016427, 38.92980480194092, 37.13298674992153, 37.666118553706575, 38.34569753919329, 38.388064180101665, 40.60946927751814, 41.402592250279014, 42.532153947012766, 42.38377169200352, 40.409218720027376, 39.127140590122764, 40.71090950284685, 39.19571583611624, 39.17504841940743, 42.07344429833548, 42.15092713492257, 40.20281205858503, 42.20962899071829, 41.47905370167324, 41.65966864994594, 40.55560336794172, 42.837443896702354, 46.95119088036673, 50.87622479030064, 50.96862540926252, 50.487198625292095, 49.56259489059448, 48.40937457765852, 48.53860412325178, 49.90526614870344, 49.77669668197632, 47.34608479908535, 48.22384377888271, 47.10267898014614, 46.33881834575108, 48.45109156199864, 49.969790594918386, 48.83424997329712, 51.04325601032802, 51.61587790080479, 51.38818195887974, 49.49485342843192, 57.07918044498989, 62.47361591884068, 68.18492398943219, 56.29990175792149, 0.5578576741474015, 1.9774794663701738, 0.23620137838380678, 0.2941148036292621, 7.969438740185328, 69.61322348458427, 58.792293548583984, 68.35942799704415, 49.01732110977173, 68.16519805363247, 31.275526796068462, 39.96636138643537, 45.22223935808454, 66.11648695809501, 50.781190804072786, 0.7761023832218987, 0.09283648271645818, 0.045076316222548485, 0.01866404545892562, 0.03361899458936282, 0.03532623280105846, 0.23807975330523082, 0.17727897156562122, 0.10389739062104907, 0.1856046098151377, 0.17996305253888878, 0.3087653789137091, 0.361219229974917, 28.070800474711827, 87.79719420841762, 60.391025406973704, 56.906326634543284, 25.529161589486257, 36.484157017299104, 45.97657053811209, 65.9453180858067, 68.39812251499721, 75.42402975899833, 13.753930449485779, 0.36622133584959166, 0.32823737976806505, 0.9917643708842141, 42.98661477225167, 60.551570483616416, 66.17703356061662, 68.25015367780412, 70.36229487827846, 66.9457266671317, 65.4463471003941, 65.53569398607526, 67.09473773411342, 62.627831186567036, 59.197693143572124, 54.303475856781006, 54.48166935784476, 46.66302129200527, 48.52031993865967, 50.63564688818795, 48.99005290440151, 45.78862871442522, 49.53018501826695, 43.76236030033657, 45.72827318736485, 42.61771059036255, 45.898351192474365, 46.689275060381206, 43.30515841075352, 45.19465500967843, 43.03275081089565, 44.09230245862688, 45.38539348329817, 43.235874448503765, 46.96196753638131, 43.37605782917568, 42.28858137130737, 43.40254436220442, 45.522147927965435, 43.67990255355835, 46.3942927633013, 41.589283398219514, 44.31576347351074, 42.84330817631313, 42.146303108760286, 44.888486112867085, 45.76782580784389, 44.5644325528826, 41.381903988974436, 43.21760416030884, 42.02474784851074, 37.83935104097639, 37.79519871303013, 39.94487060819353, 37.30204336983817, 37.11665153503418, 44.20199714388166, 39.957967962537495, 40.065192563193186, 38.054189341408865, 38.60098130362374, 39.28167200088501, 39.81407424381801, 40.007616315569194, 38.561446053641184, 40.95302990504673, 41.44354145867484, 38.62362895693098, 41.36335577283587, 42.89673982347761, 40.085804394313264, 40.89183712005615, 39.39864492416382, 40.51026289803641, 37.235722814287456, 38.96714094706944, 40.02899244853428, 37.44984892436436, 40.77798741204398, 39.05556719643729, 39.282755919865195, 40.52801554543631, 41.20010437284197, 40.6795140675136, 38.56295728683472, 41.539402280535015, 41.3945358140128, 43.8418859073094, 40.601253032684326, 38.831505162375315, 37.94801044464111, 37.1899585042681, 40.58204821177891, 37.14824846812657, 37.3598940713065, 38.50727442332676, 37.67468568256923, 43.369269439152305, 44.48659883226667, 46.75552265984671, 42.85874707358224, 43.7149874823434, 41.64414290019444, 43.64986201695034, 41.01439292090279, 40.93786893572126, 45.10770525251116, 44.10264137813023, 43.23681592941284, 44.83162900379726, 42.694856439317974, 43.58207886559622, 41.99183770588466, 45.062913690294536, 47.85509940556118, 54.95304209845406, 53.05448504856655, 53.75675685065133, 52.56369209289551, 50.793298040117534, 52.225842884608674, 53.817980902535574, 50.90190533229283, 48.61201878956386, 50.799155371529714, 51.45870964867728, 49.36426203591483, 53.07167141778128, 53.173393045152935, 51.980679171425955, 53.524419512067524, 54.663006918770925, 54.27030168260847, 51.77579763957432, 59.899787766592844, 65.61286067962646, 71.99414879935128, 59.863976751055034, 0.47355756908655167, 7.034803109509604, 0.3499049299529621, 0.3107932758118425, 9.526509199823652, 75.92237540653774, 65.88844013214111, 74.36197675977434, 58.14713593891689, 78.52240521567208, 42.746290479387554, 50.64013542447771, 52.996418952941895, 76.86236245291573, 64.34564127240861, 1.6762372766222273, 0.30268410380397526, 0.12224235838013035, 0.205804990870612, 0.1562842024224145, 0.21114415223045008], [0.00746589366878782, 0.015020307319770967, 0.053972480286444934, 0.019406293219487582, 0.06571372132748365, 0.04994332577501025, 0.14219746259706362, 17.956246989113943, 63.4042854309082, 44.520266328539165, 45.298120634896414, 32.39995377404349, 43.58844688960484, 35.23618064607893, 51.65936320168631, 57.64743191855294, 61.77274417877197, 7.484023690223694, 0.5347335806914738, 0.2886044207428183, 1.3130742609500885, 36.72167771203177, 62.00320897783552, 59.696400097438264, 60.94567230769566, 62.74530438014439, 59.48529992784773, 61.62056473323277, 59.426316670009065, 58.90037277766636, 57.77273225784302, 54.54915721075875, 48.13990606580462, 46.69276653017317, 44.03256184714181, 40.799526827675955, 42.33399479729788, 40.86584390912737, 40.9193172454834, 40.827764306749614, 38.20008414132254, 41.03196491513933, 39.10745634351458, 40.953683035714285, 38.39055510929653, 38.70829970496041, 38.770406178065706, 38.89543901171003, 38.87860005242484, 40.00572293145316, 38.57346991130284, 39.02755553381783, 40.35284798485892, 38.50774342673165, 38.942690236227854, 39.13628441946847, 37.37659406661987, 38.94476774760655, 38.16331774847848, 40.15084995542254, 40.15762792314802, 39.274678639003206, 38.43029533113752, 39.71384995324271, 44.07221869059971, 41.80110270636422, 37.16030011858259, 39.267157214028494, 39.54659291676113, 37.87604795183454, 37.39853300367083, 35.37121541159493, 37.23125859669277, 36.166283879961284, 40.626891885484966, 35.170030321393696, 35.28198317119053, 34.74665921075003, 34.72172907420567, 35.6179598399571, 34.13556514467512, 36.333707673209055, 34.053204672677175, 34.830906118665425, 34.42131675992693, 37.19079228809902, 36.42032044274466, 34.67863287244524, 35.98045778274536, 34.92983457020351, 34.90453617913382, 34.630572182791575, 35.198583943503245, 35.00466319492885, 35.44143043245588, 34.38589136941092, 33.921129839760916, 34.76742737633841, 36.72518307822091, 33.91293791362217, 37.15031208310808, 36.299758774893625, 37.7632543700082, 39.53220667157854, 37.93933909279959, 36.97882011958531, 36.341458388737266, 37.364403452192036, 37.625815527779714, 35.46309838976179, 35.23972075326102, 38.75090258462088, 35.18503843035017, 37.850426469530376, 41.00588485172817, 40.16966220310756, 39.03280142375401, 38.66172245570591, 39.44334615979876, 38.23045819146292, 36.30082184927804, 35.837255409785676, 39.888044766017366, 39.08425978251866, 39.46974584034511, 40.64487034933907, 39.21314539228167, 40.47549063818795, 39.52299336024693, 40.9248480115618, 39.435807364327566, 40.1030706678118, 42.591310909816194, 42.72030421665737, 43.386257784707205, 41.01191588810512, 41.15441649300711, 41.4668596131461, 41.15044559751238, 40.87137120110648, 43.158662591661724, 41.83522878374372, 42.29258353369576, 43.3359180859157, 43.287548201424734, 43.79650027411324, 45.17302526746477, 46.287380831582205, 46.368775503976, 47.531681605747764, 49.74525260925293, 53.39860153198242, 61.55611324310303, 60.952245303562705, 64.14788859231132, 3.5805374469075884, 1.6851583293506076, 0.48414304107427597, 0.09927888094846692, 3.1859779102461676, 61.46140234810965, 54.51988097599575, 61.45722648075649, 49.64740112849644, 54.904380389622276, 21.677033390317643, 17.659536327634537, 33.57779155458723, 55.2338604927063, 55.402309145246235, 3.264390719788415, 0.28072540781327654, 0.03415649949706026, 0.010684102989866264, 0.06301807811749832, 0.011980298257965063, 0.06335566285997629, 0.0409813913117562, 0.026634519819968512, 0.027008823484980633, 0.07716541790536471, 0.08676763158291578, 0.12708029949239322, 25.92652906690325, 72.38888985770089, 53.61510392597744, 50.86551414217268, 36.36063889094761, 34.847481046404155, 33.43511029652187, 62.66053635733468, 59.60771329062325, 69.36045496804374, 8.04463301386152, 0.2606844689164843, 0.1041774559499962, 1.3246447486536843, 41.705429485866, 65.51742717197963, 60.358174324035645, 61.558725765773225, 63.724722453526084, 62.69054562704903, 62.30489976065499, 62.971725327628, 59.94522898537772, 59.30668953486851, 55.547623770577566, 51.89543867111206, 49.20508575439453, 45.86194610595703, 43.699173382350374, 43.4229998588562, 43.01512323107038, 42.17978647777012, 44.10334314618792, 41.01235709871565, 44.55602175848824, 42.34235348020281, 42.701005595070974, 41.00809785297939, 40.64341122763497, 40.17889983313424, 41.82714108058384, 41.59017971583775, 41.23409148624965, 41.21579340526036, 40.5922064781189, 41.13504491533552, 39.82702221189226, 41.164394106183735, 41.65837975910732, 39.84378126689366, 39.64060204369681, 39.780007226126536, 42.2248420715332, 41.24009820393154, 40.04587657111031, 40.095674310411724, 41.308892318180625, 45.11026218959263, 42.82201542173113, 38.615600313459126, 37.04828473499843, 39.63436256136213, 39.15938023158482, 36.192096437726704, 35.79801893234253, 38.41314022881644, 36.13696943010603, 41.39995888301304, 38.64420257295881, 36.89528887612479, 37.005994524274556, 35.983643531799316, 38.56963103158133, 36.478754792894634, 37.94757270812988, 36.210721084049766, 36.98938832964216, 37.77513926369803, 39.665004117148264, 38.221585341862266, 36.12151663643973, 37.57573986053467, 37.840942178453716, 37.85146522521973, 36.86451530456543, 36.95989670072283, 36.68075977052961, 37.862696988242014, 37.22464738573347, 38.78706448418753, 37.68125173023769, 39.45238924026489, 35.36039706638881, 39.178268909454346, 37.66993658883231, 40.71862200328282, 41.91564376013619, 38.12261520113264, 36.573899950299946, 35.80529369626726, 38.11110551016671, 37.792151927948, 37.02833298274449, 35.84898396900722, 37.70453861781529, 35.82070827484131, 38.160545417240684, 43.04597323281424, 42.387336117880686, 41.120811530521934, 41.55440691539219, 39.164059843335835, 39.34932313646589, 37.777751786368235, 37.646781717027935, 40.68181392124721, 39.7062486239842, 42.22794096810477, 41.44822801862444, 42.407795088631765, 41.73050900868007, 40.898236410958425, 41.44169323784964, 42.17025007520403, 41.63392210006714, 42.76529727663313, 44.86377484457833, 44.53691073826381, 42.7226561818804, 44.11097574234009, 44.13082674571446, 42.35106304713658, 44.33910594667707, 45.50229345049177, 43.02984993798392, 46.30841997691563, 45.833409854343955, 47.66234942844936, 47.700932775224956, 48.650077547345845, 47.69626011167254, 48.33763442720686, 50.02921158926827, 51.74735171454293, 55.85320207050869, 64.73911081041608, 63.71960163116455, 67.41920471191406, 4.399238041469029, 1.4198028253657478, 0.248881460832698, 0.15115009434521198, 3.5302014393465857, 66.20631326947893, 61.78659193856375, 65.82084110804966, 55.02932637078421, 58.53174304962158, 25.852108648845128, 27.45774006843567, 41.64403520311628, 61.64722497122628, 61.89144720349993, 3.8507880653653825, 0.22634379805198737, 0.06090779349740062, 0.06497331070048468, 0.0919520462464009, 0.04134305047669581, 0.14955924185259, 0.1595402341336012, 0.16909644992223807, 0.10103135369718075, 0.16508078468697412, 0.21274839900434017, 0.22999508998223714, 33.17882946559361, 79.91158635275704, 58.98113863808768, 59.758718490600586, 42.662144320351736, 60.478801999773296, 45.956594467163086, 68.387373651777, 65.52990613664899, 75.87785829816545, 9.182530811854772, 0.5899275190063885, 0.29317736678889816, 1.8003952886377061, 44.68877404076712, 62.544605663844514, 62.64760575975691, 63.14709786006382, 67.31270967211042, 62.59955896650042, 63.52293981824602, 63.940269470214844, 61.119606563023154, 61.99706677028111, 59.75028337751116, 53.620735440935405, 51.57902465547834, 47.79209314073835, 46.65837642124721, 46.92310973576137, 46.57704080854143, 45.32542358125959, 45.832767145974294, 41.92672961098807, 47.28963763373238, 43.448444162096294, 45.778202942439485, 43.973085267203196, 43.74624742780413, 41.800456523895264, 43.16335957390921, 43.63910967963082, 43.32399150303432, 43.05566944394793, 43.062454359872, 44.39763757160732, 42.74131209509713, 43.25071580069405, 43.44018622807094, 41.87112317766462, 42.43057823181152, 40.87357725415911, 44.987477098192485, 43.75850405011858, 43.29094934463501, 41.548424516405376, 42.848585333142964, 45.99829408100673, 44.083662373679026, 39.44898809705462, 39.0205135345459, 40.70951638902937, 38.88157735552107, 38.1570782661438, 36.210464000701904, 37.55262320382254, 35.82602712086269, 44.02791002818516, 41.544092314583914, 40.17959117889404, 39.957186290196006, 39.43419190815517, 40.55438048498971, 39.85516241618565, 41.66212831224714, 37.93149110249111, 39.35329750605992, 40.72488580431257, 42.938300473349436, 41.26616089684622, 39.80979067938668, 40.74468469619751, 40.7765143939427, 38.38808849879673, 40.434437206813264, 39.780066285814556, 40.48519032342093, 42.55893577848162, 38.70166417530605, 39.507950510297505, 41.43968520845686, 42.32126569747925, 37.88687671933855, 43.444004263196675, 41.235206672123496, 45.25579220908028, 41.88788570676531, 37.77665049689156, 37.41882174355643, 36.02236931664603, 38.47175523212978, 37.58245529447283, 36.66751650401524, 36.41579021726336, 37.75260278156826, 36.21195786339896, 39.66647713524954, 43.99994700295584, 44.830722263881135, 43.183009079524446, 42.57142516544887, 41.9975699697222, 42.66390568869454, 40.69646767207554, 39.94886234828404, 44.104496547154014, 42.635081086839946, 44.10861682891846, 43.05248022079468, 44.29809767859322, 45.17690931047712, 42.82873085566929, 44.37046316691807, 43.02397176197597, 43.6828590120588, 47.086871828351704, 47.53578104291643, 47.380811895642964, 44.571057660239084, 47.20642253330776, 47.10294648579189, 44.86827032906668, 46.59109354019165, 48.52531221934727, 46.1991491317749, 48.65949583053589, 49.329531465257915, 49.765252998897004, 49.92915405545916, 50.8513537134443, 50.966551371983115, 50.63517093658447, 52.81876046316964, 54.988220827920095, 58.25654922212873, 67.8310661315918, 67.31122275761196, 70.48088673182896, 4.709403889519828, 5.011471612112863, 2.0248427305902754, 0.1807543057948351, 4.210465473788125, 72.51264422280448, 67.42654200962612, 74.12863540649414, 65.4129887989589, 66.95985930306571, 35.130383900233674, 30.45563588823591, 51.017436504364014, 69.35355540684291, 75.34753009251186, 7.8047508001327515, 0.49767981469631195, 0.2495504692196846, 0.2404574214347771, 0.1607495599559375, 0.23044634291103908], [0.031614374835044146, 0.04413216867085014, 0.0414167054529701, 0.10991885286888906, 0.05473825455244098, 0.07137796881475619, 0.10576549252229077, 27.98599249976022, 66.97670868464878, 42.38334437779018, 43.92545883996146, 17.58906943457467, 41.18042707443237, 47.61553246634347, 52.87055580956595, 57.65830932344709, 58.7181145804269, 7.151664861610957, 0.37149197874324663, 0.2981843581157071, 1.8578833809920718, 35.53770467213222, 53.07084458214896, 65.92267390659877, 62.14598056248256, 65.4375228881836, 59.917512621198384, 63.14022609165737, 56.713462012154714, 57.1664845602853, 54.33778606142317, 52.22294895989554, 45.554397991725374, 47.385303906032014, 41.77297292436872, 42.87473835263933, 39.7887932232448, 40.86125462395804, 39.153349195207866, 39.53589269093105, 39.35002143042428, 39.47418226514544, 38.771813188280376, 39.76147985458374, 38.095308780670166, 40.48038911819458, 36.72015953063965, 42.85679810387747, 40.63893658774239, 43.26130485534668, 43.29987777982439, 40.90727949142456, 38.944792066301616, 39.04035064152309, 37.75608382906233, 40.80157307216099, 37.74988603591919, 39.415518624441965, 38.37399755205427, 39.41623428889683, 36.97971643720354, 39.15273775373186, 39.61181565693447, 40.6612229347229, 44.404304368155344, 43.4615866797311, 38.36819928033011, 38.230048247746055, 36.37427125658308, 41.019805567605154, 37.0233268056597, 39.89595181601388, 40.26635333469936, 36.69347497395107, 37.05010516302926, 40.740821497780935, 34.51321710859026, 36.753632477351594, 34.635963984898154, 35.44541869844709, 35.46311923435756, 36.448425906045095, 34.496628284454346, 36.19588668005807, 35.128448826926096, 38.167347703661235, 37.07956552505493, 35.08012063162667, 34.42298085348946, 34.295248644692556, 35.73014545440674, 34.52730458123343, 33.29239777156285, 34.44200849533081, 33.973310811179026, 34.293636662619456, 32.84605591637747, 35.91794831412179, 34.105083397456575, 35.02705029078892, 34.67004837308611, 38.975874832698274, 39.94357476915632, 37.05110570362636, 36.005089146750315, 35.396944590977256, 36.01121398380825, 38.93514796665737, 40.71959475108555, 38.25803559167044, 34.72597442354475, 37.70959690638951, 36.84811755589077, 38.44719682421003, 39.49506507601057, 37.956191948481965, 38.08845090866089, 38.36630589621407, 37.84186628886631, 36.61731576919556, 36.403012480054585, 36.8715364592416, 36.92339433942522, 38.41751759392874, 39.682068892887656, 38.87807546343122, 39.95334741047451, 39.62865114212036, 37.643523011888774, 39.45067303521292, 40.19435610089983, 39.12567452022007, 38.35318769727434, 38.45871693747384, 39.271214962005615, 40.40355593817574, 40.20226662499564, 38.68220574515206, 41.87488562720162, 43.313833236694336, 42.85038491657802, 42.033401829855784, 42.289877210344585, 43.66472768783569, 45.98361948558262, 45.00174174989973, 50.06669364656721, 50.90589707238333, 50.97920404161726, 51.379302161080496, 51.71943385260445, 54.891679082598, 62.97579002380371, 60.934152194431846, 67.92027405330113, 6.0987144368035455, 0.9002286940813065, 0.42489729874900406, 0.11380016138511044, 0.6644506944077355, 51.18275499343872, 59.532290594918386, 52.992034639631, 52.712279319763184, 45.584935324532644, 20.170255729130336, 12.825503468513489, 36.59863206318447, 49.437958104269846, 61.21523462023054, 5.949604792254312, 0.5905401004212243, 0.08312664659959929, 0.09469692395733935, 0.1695150788873434, 0.006762090854213706, 0.02381397018741284, 0.08672919935945954, 0.06388441805860826, 0.09660655220172235, 0.04321267229637929, 0.044174421046461375, 0.04295385529154113, 32.957758631025044, 75.73912361689976, 47.418491976601736, 53.29653249468122, 23.671558959143503, 34.246746744428364, 49.27651671000889, 58.711395672389436, 63.59403378622872, 64.69011906215123, 7.731442093849182, 0.39677438352789196, 0.16561703091221197, 1.9290342373507363, 40.979075227464946, 56.22462150028774, 68.1483347756522, 63.12964398520333, 67.5718079975673, 61.68550954546247, 64.38381467546735, 57.75632061277117, 59.77489389692034, 57.158369064331055, 53.764594418661936, 49.0438562801906, 49.74209812709263, 43.40543828691755, 45.9751044682094, 42.01584373201643, 43.68696539742606, 42.68685906273978, 41.306912081582205, 41.678268977573936, 44.04842458452497, 39.87263018744332, 41.9463061605181, 40.98605816704886, 43.007011209215435, 40.14335979734148, 43.85937104906355, 41.96484742845808, 44.75088398797171, 43.785886900765554, 44.117927415030344, 39.907433714185444, 40.63390956606184, 39.09988628114973, 41.99608652932303, 40.29351731709072, 40.9513658114842, 39.49471419198172, 40.06270163399832, 39.89130694525582, 40.78961522238595, 41.06498622894287, 42.654056617191856, 46.40003892353603, 44.01274905885969, 37.79963166373116, 37.466291836329866, 37.32680674961635, 40.15939276559012, 39.27663108280727, 40.79637581961495, 40.390500273023335, 37.69894879204886, 38.20282520566668, 41.934195450374055, 35.01790298734392, 39.639122077396934, 37.517222132001606, 38.20805719920567, 37.51821225030081, 37.91019139971052, 38.15703657695225, 39.402403899601524, 36.866346154894146, 40.58191272190639, 38.884165559496196, 36.85045562471662, 37.00125585283552, 36.81028461456299, 38.17781169073922, 36.17929438182286, 35.481959274836946, 36.787720339638845, 36.15898479734148, 36.5336594581604, 34.70592539651053, 38.10844087600708, 36.36854941504342, 37.951911858149934, 36.55880151476179, 41.997583866119385, 41.258052349090576, 37.07591424669538, 38.021174975803916, 36.77816309247698, 36.694920199257986, 40.271098954336985, 40.84276894160679, 39.09194796425955, 35.373525687626426, 38.511179310934885, 37.054340090070454, 38.06304482051304, 40.76912498474121, 39.47318172454834, 39.111434187207905, 40.00174856185913, 39.08372477122715, 38.17865589686802, 38.59447431564331, 38.443580286843435, 39.02723591668265, 40.75439827782767, 40.84769174030849, 39.999118668692454, 41.31893941334316, 40.64156995500837, 41.01744665418352, 40.06945875712803, 40.66285923549107, 42.6244329724993, 40.25016403198242, 40.64378295625959, 40.51432064601353, 41.460693086896626, 42.51565892355782, 41.06860971450806, 43.154427664620535, 44.38155596596854, 44.94130631855556, 44.17028209141323, 45.39272035871233, 44.974365847451345, 48.280468123299734, 48.38348906380789, 51.552204608917236, 52.66585145677839, 53.275740010397776, 53.440777097429546, 55.39461401530674, 58.45645931788853, 65.95863778250558, 62.81132616315569, 70.53206716264997, 6.89797397170748, 1.0657021062714713, 0.9518304680074964, 0.10545142580355917, 0.6786781623959541, 55.01507561547415, 65.91555200304303, 61.03176743643624, 57.44834171022688, 53.65458359037127, 26.76671392577035, 16.142034121922084, 43.16143144880022, 54.75151654652187, 71.63110542297363, 8.687009607042585, 0.5400031379290989, 0.14521513852689946, 0.1464780821864094, 0.0418127052752035, 0.09158283498670373, 0.1640923355839082, 0.12323453942579882, 0.18360333863113606, 0.2559726946055889, 0.13578731513449124, 0.12928701750934124, 0.22060339179422173, 42.82167148590088, 86.68688596997941, 54.76243216650826, 61.80016871861049, 26.421350240707397, 55.45870072501046, 62.20267786298479, 63.42743682861328, 68.15403924669538, 71.29969024658203, 8.470292687416077, 0.3709909756268774, 0.893364742398262, 2.505498915910721, 43.67291613987514, 56.07011440822056, 71.15410464150565, 64.2872416632516, 69.31564603533063, 62.76358509063721, 66.34557601383754, 60.654688698904856, 62.46497235979353, 60.543448039463584, 55.77539961678641, 50.758081095559255, 54.38927568708147, 46.30088465554373, 48.17369862965175, 44.140119961329866, 46.20512458256313, 46.802537645612446, 43.5126941544669, 45.651822158268516, 45.36345107214791, 42.79019267218453, 43.10573468889509, 42.931060450417654, 45.43633072716849, 42.87388025011335, 47.505059582846506, 44.44361727578299, 48.1558278628758, 45.70666776384626, 47.33940758023943, 42.35471779959542, 42.07516050338745, 41.69467714854649, 45.216923986162456, 41.73345504488264, 43.05502673557827, 41.90679522923061, 41.71178708757673, 41.176595142909456, 43.4167742729187, 44.34013080596924, 44.97077362877982, 48.33982310976301, 44.90448086602347, 39.93963861465454, 37.5477351461138, 37.32433666501726, 40.20911407470703, 38.653165749141145, 41.23172909872872, 40.6038863999503, 38.97391196659633, 39.07655423028128, 43.74110576084682, 38.91052007675171, 42.13843427385603, 41.04701471328735, 41.39816277367728, 41.667534010750906, 40.86854675837925, 40.83101953778948, 42.41086619240897, 40.66284533909389, 42.84583037240164, 42.12911673954555, 39.190410886492046, 39.53793198721749, 38.7149213382176, 40.49319812229702, 38.795127868652344, 36.86489398138863, 39.98719208581107, 40.478085790361675, 40.25399248940604, 37.34612274169922, 40.77793877465384, 39.55971111570086, 40.14036512374878, 39.40568344933646, 44.978583403996055, 41.179801736559185, 37.548357009887695, 39.44274861471993, 37.511594091142925, 37.01947750364031, 39.89371102196829, 41.35363524300711, 38.15578242710659, 34.953847544533865, 38.807460921151296, 38.30322320120675, 39.091725621904644, 41.75979219164167, 41.25007929120745, 41.50751004900251, 40.71278551646641, 41.941682134355815, 38.964959212711875, 40.872159821646555, 40.9516715322222, 40.19389404569353, 41.42928722926548, 41.82353496551514, 42.467167445591514, 44.595539637974326, 43.48275089263916, 42.34326369421822, 43.65189783913748, 43.258692332676475, 44.28619541440691, 42.81091914858137, 43.93219511849539, 43.64334808077131, 43.988784721919465, 43.883318015507285, 43.19530044283186, 46.7768223626273, 47.977696895599365, 47.86351714815412, 46.4245730127607, 48.241030148097444, 48.669612407684326, 50.29615095683506, 50.78821890694754, 54.0132600239345, 55.94113499777657, 56.4061153956822, 55.818068504333496, 56.101332664489746, 61.825467109680176, 68.50202587672642, 65.6961417879377, 74.25842775617326, 8.200463737760272, 2.531408314193998, 1.7651557624340057, 0.22703222611120769, 1.2813594256128584, 59.17737661089216, 72.07371956961495, 66.3898846762521, 67.76901871817452, 57.89043821607317, 34.692758560180664, 21.790492262159074, 53.3996124948774, 63.97469779423305, 81.44756208147321, 12.402306062834603, 0.8846774314131055, 0.2985200972429344, 0.26680447480508257, 0.22375032864511013, 0.21785086020827293], [0.05167966974633081, 0.09318543292049851, 0.03326160340969052, 0.027026063363466944, 0.026700797424252545, 0.02275915357417294, 0.05820480175316334, 35.09040396554129, 65.96228558676583, 51.10557787758963, 41.422762870788574, 33.69164473669869, 32.93531247547695, 37.02395214353289, 61.62540762765067, 52.69332810810634, 57.85924080439976, 6.287846573761531, 0.3894106229501111, 0.24663982540369034, 1.3494336413485664, 46.153068678719656, 54.23214912414551, 63.55688871656145, 61.645404543195454, 63.125336102076936, 58.159486361912315, 56.242846625191824, 53.67037337166922, 52.82287032263619, 50.00195380619594, 47.55305773871285, 44.15604175840105, 40.73735087258475, 40.70163018362862, 40.250198772975374, 40.36522967474801, 42.03663969039917, 40.394735200064524, 39.36797904968262, 38.745024408612935, 40.118624210357666, 39.605322565351216, 37.26486355917794, 38.06147105353219, 44.84540033340454, 46.558228560856406, 48.50066001074654, 49.73670979908535, 51.5625296320234, 50.926592281886506, 51.10024513517107, 44.79804836000715, 38.9392717225211, 37.58319180352347, 38.201477255140034, 37.80992194584438, 38.60669272286551, 37.37733057567051, 37.36030401502337, 38.62009927204677, 38.41088553837368, 39.81073216029576, 38.521761417388916, 44.214243343898225, 43.93321997778756, 38.983052321842735, 37.64334235872541, 40.15044001170567, 41.698307582310264, 37.75613941465105, 41.0820301600865, 38.70324836458479, 40.969848019736155, 40.75947393689837, 39.76086493900844, 38.22587932859148, 35.647031102861675, 35.47966289520264, 35.197451387132915, 34.91874871935163, 34.75228030341012, 35.39088576180594, 38.01365007672991, 35.72690411976406, 37.661918367658345, 35.353862285614014, 35.217451776777, 34.8065561567034, 34.5914295060294, 35.83937808445522, 34.63991403579712, 35.6304144859314, 34.061882972717285, 35.310686179569785, 34.92257717677525, 33.86354316983904, 34.042674677712576, 35.23839712142944, 34.18754461833409, 38.83331516810826, 39.59131152289254, 37.556663581303184, 38.52664600099836, 41.18178544725691, 40.025195258004324, 41.60253708703177, 40.236410072871614, 38.9408871786935, 39.49218504769461, 36.56023631777082, 34.79539734976632, 34.40871620178223, 37.42125708716256, 37.805989265441895, 38.65086242130825, 38.56912381308419, 38.454805101667134, 38.89027650015694, 36.72317157472883, 36.58252613885062, 36.74266127177647, 38.76600796835763, 39.35248109272548, 38.76266935893467, 39.555823598589214, 39.63816670009068, 39.11660712105887, 39.25020013536726, 38.041977882385254, 37.44991145815168, 37.27883291244507, 38.2662935256958, 38.95439100265503, 40.414252689906526, 38.655378750392366, 38.81429100036621, 36.596151556287495, 39.533356598445344, 40.71344559533255, 40.29841232299805, 41.51431580952236, 43.65060200010027, 44.53765072141375, 47.30655302320208, 48.057952063424246, 49.72778831209455, 49.55382973807198, 55.00254801341465, 52.382806164877756, 56.68815319878714, 54.54041290283203, 64.17263112749372, 60.870284352983745, 69.14417144230434, 8.37116881779262, 0.5454770156315395, 0.47991674499852316, 0.04247368998559458, 0.08675013216478483, 39.52102354594639, 64.81539508274624, 53.53417478288923, 51.636256967272075, 48.047217096601216, 22.640753746032715, 14.289076362337385, 34.93650484085083, 42.52929128919329, 60.97759233202253, 9.77621442931039, 0.4535474085382053, 0.09239696844347886, 0.07515375835022756, 0.021447859205571667, 0.06612474391502993, 0.026666718002940928, 0.009682905910137509, 0.037495570323829136, 0.03529033829857196, 0.03481295159352677, 0.015214590555323022, 0.08043985827160732, 43.05424158913748, 73.26943506513322, 56.239132813044954, 46.90649311883109, 31.548959255218506, 36.09066316059658, 44.50856556211199, 66.24069990430559, 59.041977064950125, 66.22476768493652, 6.020167223044804, 0.35943332580583437, 0.24469460121222905, 1.7416454468454634, 49.59238876615252, 56.38446133477347, 65.74083954947335, 63.57049328940255, 65.43347208840507, 59.52937235151018, 58.38970797402518, 55.45767586571829, 55.14165789740426, 51.56858846119472, 50.7687292098999, 46.17918348312378, 44.246865136282786, 44.10817561830793, 41.75568928037371, 42.248330456869944, 43.595235279628206, 42.59280824661255, 41.90322732925415, 41.545638288770405, 42.08174392155239, 41.39677313395909, 39.87446798597063, 40.568127495901926, 46.075641427721294, 47.54207958493914, 50.166942255837576, 50.742749895368306, 53.84150055476597, 52.32277372905186, 54.2110161781311, 48.03048236029488, 41.118876457214355, 41.06776550837925, 40.296077728271484, 39.05788789476667, 40.76110676356724, 38.62012359074184, 39.07751308168684, 40.51731531960623, 40.95116778782436, 41.27820559910366, 39.7530551637922, 45.15735707964216, 43.89489024026053, 39.01364524023873, 37.43865885053362, 40.18486138752529, 43.3751163482666, 37.46241821561541, 41.21161406380789, 40.71624919346401, 41.70392172677176, 40.77171318871634, 40.63123798370361, 40.78928518295288, 38.975593430655344, 37.18933316639492, 37.587242603302, 36.4626419203622, 37.60858399527413, 36.97046838487898, 39.649575642177034, 36.48407711301531, 39.71073368617466, 37.95215851919991, 36.28858607155936, 37.39254018238613, 37.60992499760219, 38.35071413857596, 37.305180481501985, 37.09466396059309, 35.36322845731463, 36.85979400362287, 36.4658658845084, 35.93842118127005, 37.1324691091265, 37.71908119746617, 37.710521016802105, 39.305077007838655, 40.74993058613369, 37.1779693875994, 39.49685771124703, 42.12242562430245, 40.854226521083284, 41.90340450831822, 40.86699731009347, 37.63756840569632, 39.259149415152415, 37.395691190447124, 33.881855147225515, 35.57110813685826, 37.93651812417166, 40.2252755846296, 38.80552237374442, 40.78860078539167, 39.88017593111311, 39.4048045022147, 39.109881264822825, 37.651002747671946, 38.03726700374058, 40.27972166878836, 39.4994980267116, 39.78066383089338, 41.93459497179304, 41.411030837467735, 39.050779887608115, 40.30422796521868, 41.215578011104036, 38.886712074279785, 39.019280229296, 39.81717661448887, 41.12855529785156, 42.49904925482613, 41.18388727733067, 40.78901072910854, 39.4699056489127, 42.45418126242501, 43.193247250148225, 41.876382963997976, 43.385219029017854, 45.44482837404524, 46.629565715789795, 49.79467167173113, 50.382979120527, 52.25946521759033, 51.931451184409006, 57.65624918256487, 56.410110609872, 59.02130617414202, 56.22953735079084, 66.97640991210938, 63.51683929988316, 73.23981489453996, 8.964729104723249, 0.7922945086445127, 0.9349765266690935, 0.03589634131640196, 0.12375975267163344, 41.77245875767299, 71.5194548198155, 57.99118709564209, 59.56860882895333, 49.649575914655415, 30.59643418448312, 16.082797254834855, 39.05848543984549, 49.609957286289756, 71.42133930751255, 12.625412719590322, 0.48049404259238926, 0.13239962048828602, 0.06913931215448038, 0.053562617993780544, 0.04664795260344233, 0.11479692932750497, 0.24317956822259085, 0.13640092792255537, 0.10420404773737703, 0.08817430253007583, 0.08686453995427915, 0.17530322686902114, 51.823326792035786, 84.54132393428257, 64.32003021240234, 57.47854552950178, 40.505287987845286, 44.95706135886056, 48.68672234671456, 76.37999766213554, 60.951432364327566, 73.68128258841378, 7.239123574325016, 0.6507179598723138, 0.4278943607849734, 2.0338234944002966, 51.28026601246425, 60.28271688733782, 67.19461808885846, 65.95143250056675, 68.51581110273088, 60.060305050441194, 60.91184152875628, 58.34984615870884, 57.52490391050066, 53.072095257895334, 52.44228621891567, 49.0167270387922, 46.38198750359671, 45.605918884277344, 45.58866650717599, 44.685167925698416, 47.93190826688494, 45.336700507572715, 44.20676013401577, 44.99603380475725, 44.952944551195415, 43.0899692262922, 41.78194999694824, 42.788653646196636, 48.78683546611241, 51.41779865537371, 53.28676332746233, 54.0581488609314, 57.37263413837978, 55.89636080605643, 58.02804381506783, 50.7701153755188, 44.478924546922954, 42.69509267807007, 41.83398853029524, 40.98648548126221, 42.4541152545384, 39.811426980154856, 41.18161521639143, 41.67131035668509, 43.37374407904488, 44.28478145599365, 41.9493008341108, 46.74149424689156, 45.00370809010097, 38.600335121154785, 38.33547673906599, 41.084121567862375, 43.91279574802944, 39.83809069224766, 42.78961249760219, 40.44203506197248, 41.692161900656565, 41.7905900818961, 41.11855684007917, 41.316326890672954, 40.17814942768642, 40.36826951163155, 39.28604589189802, 37.96814285005842, 39.49736840384347, 39.83021490914481, 43.62256949288504, 39.05971874509539, 42.34802321025303, 42.22742680140904, 39.552085467747276, 39.73632042748587, 40.89492212023054, 40.945449420383994, 40.64415468488421, 39.85472467967442, 37.7879204750061, 40.32392610822405, 40.400721073150635, 39.37627519880022, 39.174846921648296, 41.35104356493269, 40.462160519191194, 42.97155802590506, 42.0469890322004, 38.128983225141255, 38.98270838601248, 40.88839776175362, 40.24154131753104, 43.989837374006, 40.99654994692121, 39.29400157928467, 40.14449235371181, 39.008531366075786, 34.20461286817278, 34.26975917816162, 38.41041306086949, 40.45281866618565, 41.90155628749302, 42.13380677359444, 40.827284881046836, 42.5448066166469, 40.12956414903913, 40.78057214191982, 40.2628618649074, 43.44365337916783, 41.61507511138916, 43.388529845646445, 43.81004578726632, 43.35409804752895, 42.212651457105366, 41.528736795697895, 40.62025982992989, 41.231458118983674, 41.457517760140554, 41.96077230998448, 42.774965694972444, 45.83573750087193, 43.339333125523154, 43.06736673627581, 41.347190788814, 44.62709140777588, 46.09993232999529, 45.27670628683907, 46.21634244918823, 48.219094685145784, 49.037092208862305, 53.671363489968435, 52.71620852606637, 55.834959575108115, 54.76262671606881, 61.87381962367466, 58.302153723580496, 62.50461878095354, 57.64107084274292, 70.00294794355119, 66.49692862374442, 76.66715281350272, 10.773815938404628, 1.5470869839191437, 1.7258083309446062, 0.11169679782220296, 0.32278923211353167, 47.06076397214617, 75.64645549229213, 63.57334899902344, 67.17488520486015, 60.49237183162144, 37.09191942214966, 24.66851602281843, 50.13883679253714, 57.54219797679356, 84.12823963165283, 18.66205542428153, 0.7035120555332729, 0.371270803468568, 0.12017849912600857, 0.22660769389144012, 0.20649303895022186], [0.046475604708705626, 0.03402652272156306, 0.11934592308742659, 0.03486723778769374, 0.06948533108724014, 0.03476848719375474, 0.2137030027806759, 39.38277176448277, 58.78975050789969, 38.104285853249685, 37.750466210501536, 45.43239804676601, 33.2582300049918, 36.23765924998692, 59.4405118397304, 56.41495697838919, 55.13651623044695, 4.6265431472233365, 0.4731030591896602, 0.24281234507049831, 1.3290578318493707, 44.13178212302071, 67.33294282640729, 63.798908369881765, 59.623402323041645, 59.133047103881836, 58.1747932434082, 54.595341886792866, 50.402802331107004, 49.17935310091291, 47.20398371560233, 43.58410079138619, 42.03508676801409, 41.08976697921753, 40.92378841127668, 39.82318680627005, 40.02505281993321, 42.112663405282156, 40.52954762322562, 43.269618374960764, 41.50034645625523, 41.070322445460725, 38.89598444529942, 41.71099846703665, 50.16024766649519, 51.892919949122835, 50.37632622037615, 53.28899022511074, 51.80429915019444, 51.714351245335166, 51.99389117104666, 50.978658608027864, 48.30466175079346, 45.00924233027867, 39.784662519182476, 39.11626318522862, 38.73273304530552, 37.96660729816982, 38.073310783931184, 38.51975686209542, 37.37166779381888, 38.67009503500802, 40.95586824417114, 37.650408676692415, 39.909938539777485, 39.92885153634207, 38.928369998931885, 38.29761253084455, 38.808447565351216, 43.87184306553432, 42.3136956351144, 39.22070850644793, 42.35611091341291, 39.48368740081787, 38.33386128289359, 38.495323521750315, 38.1178800037929, 38.000389439719065, 35.66595104762486, 36.38231379645211, 35.52419737407139, 35.39082670211792, 36.55140863146101, 35.45772743225098, 35.659867899758474, 37.21439184461321, 36.00738205228533, 33.822197914123535, 32.64092772347586, 34.616321427481516, 36.971211842128206, 35.475080558231895, 35.39425563812256, 34.8518306187221, 32.911903994424, 33.76295062473842, 35.099943842206685, 34.63618632725307, 34.436602796827046, 36.813411303928916, 37.44075720650809, 36.89956201825823, 39.42544412612915, 41.52812882832119, 39.69312347684588, 40.944407190595356, 44.763613087790354, 41.71745334352766, 37.41943665913173, 35.63411440168108, 35.35756567546299, 36.09430054255894, 34.53742115838187, 38.49845021111624, 39.747173513684956, 36.37853397641863, 38.025649615696494, 36.15176909310477, 36.48986496244158, 37.80468300410679, 36.13897745949881, 36.93474769592285, 37.958550861903596, 39.15674686431885, 38.410513809749055, 38.85250261851719, 39.24123348508562, 37.97059209006173, 38.51166568483625, 38.37830890927996, 36.71171399525234, 37.01189007077898, 37.81242329733712, 36.97316081183297, 39.570932456425254, 37.723934514181956, 40.090900897979736, 38.60071727207729, 42.129040309361045, 40.53733307974679, 41.11122301646641, 41.213014125823975, 42.84113686425345, 42.359088216509136, 45.85072129113333, 48.42230864933559, 52.42277567727225, 53.112999303000315, 57.58208758490426, 55.095917906079976, 58.13352789197649, 56.40280457905361, 65.06901127951485, 59.30243723733084, 71.09459332057408, 9.249765924045018, 0.31763980271560804, 1.5336672982999255, 0.13832290550427778, 0.07477112566786152, 31.05319138935634, 67.13922704969133, 58.44683606284005, 52.71485015324184, 49.49297046661377, 21.320298978260585, 7.902372121810913, 25.40283465385437, 42.60515866960798, 68.1774685723441, 18.087411608014786, 0.38266460065330776, 0.10702013769852263, 0.06965631512658936, 0.037924516413893015, 0.05838730053177901, 0.03574494658304112, 0.028827930068863288, 0.04577327346695321, 0.07663305290043354, 0.04733844680179443, 0.029910020397177765, 0.24021198174783162, 46.44927038465227, 66.85998589651925, 47.97871480669294, 50.2498516355242, 47.02344172341483, 36.70964343207223, 39.029976981026785, 66.76135621752057, 60.49881975991385, 62.32680743081229, 4.546419560909271, 0.2784320137330464, 0.17386143494929585, 1.4958979764154978, 47.269102232796804, 68.80097212110246, 63.84498187473842, 61.7704929624285, 61.88652787889753, 58.71005467006138, 57.96459286553519, 52.496218136378694, 52.44538164138794, 49.52325766427176, 46.66952133178711, 44.09556811196463, 42.71060800552368, 42.03975943156651, 41.35653611591884, 42.15969576154436, 43.83053255081177, 42.88778706959316, 44.96012551443917, 43.57813228879656, 41.94076844624111, 40.30581215449742, 44.312747955322266, 51.80100222996303, 54.76483971732003, 52.90357364927019, 55.63163096564156, 53.95875140598842, 53.00278697695051, 53.27888059616089, 52.40478679112026, 50.511142117636545, 45.736346994127544, 43.435385022844585, 40.830807617732454, 40.49140548706055, 39.54527970722744, 39.9758699962071, 40.09299577985491, 39.84000144686018, 40.12875815800258, 42.43038020815168, 37.913675921303884, 41.598013809749055, 43.77446058818272, 40.127531800951274, 38.65452759606497, 37.96211528778076, 43.65340212413243, 42.548496110098704, 38.64616196496146, 42.093625341142925, 39.85405765260969, 37.78374113355364, 39.44552789415632, 39.10835613523211, 40.254711627960205, 38.6766471862793, 38.14836869921003, 38.25227206093924, 38.976521015167236, 38.522216524396626, 37.92539405822754, 38.16570445469448, 37.296443121773855, 37.645430292402, 36.61649240766253, 35.68070902143206, 37.56151342391968, 39.20008625302996, 37.372317450387136, 36.659706728799, 37.822967188698904, 34.830287728990825, 35.7882011277335, 36.645355224609375, 37.512580735342844, 36.39099209649222, 39.7895644732884, 38.87606395993914, 38.26484482628958, 39.73966251100813, 40.60596738542829, 39.21779721123831, 41.744391509464805, 45.64701053074428, 41.65097992760794, 38.509035791669575, 36.03044659750802, 35.74491385051182, 35.07318632943289, 33.64305945805141, 40.0273630959647, 40.781458037240164, 36.75886794498989, 39.13881703785488, 38.407915183476035, 37.690746443612234, 38.58437163489205, 37.69869518280029, 37.898841517312185, 39.50551169259207, 41.86027009146554, 39.795560768672395, 40.93982832772391, 41.95218086242676, 41.27447441646031, 39.84808567592076, 39.92870909827096, 38.330626896449495, 39.942831311907085, 38.481774534497944, 39.27021789550781, 40.84855679103306, 40.202822480882915, 42.381760188511436, 39.88067272731236, 44.206937313079834, 41.17255129132952, 43.7390456199646, 43.666461263384136, 44.8496595791408, 44.38611051014492, 48.956579957689556, 50.2015894481114, 55.07705354690552, 55.693716594151084, 60.8893015725272, 57.44667761666434, 60.6941614151001, 59.64779050009591, 68.45718915121896, 61.310105323791504, 72.67620481763566, 9.977534140859332, 0.29821793202842983, 1.1797576546669006, 0.12331204169562884, 0.010072629283448415, 33.64858327593122, 72.72072887420654, 63.840034757341655, 61.93113531385149, 53.651571546282085, 30.739726884024485, 14.474843399865286, 31.640661580221995, 49.619639601026265, 76.0178575515747, 23.03769564628601, 0.4251925157649176, 0.08027678595057555, 0.10646538103797606, 0.031052537661577975, 0.01943985865052257, 0.16432279321764195, 0.10668567421713046, 0.16758844655539307, 0.14003947696515492, 0.2822130551295621, 0.1397365653621299, 0.7087845983249801, 59.99814646584647, 77.10848849160331, 52.02385180337088, 50.550715582711355, 53.78013753890991, 41.37321874073574, 50.91212265832083, 71.95674664633614, 64.79994228907994, 69.40786252702985, 5.239457641329084, 0.6902662377272333, 0.38174920263034956, 2.371053227356502, 49.645792620522634, 70.84429141453334, 68.30362701416016, 63.54967648642403, 64.77201053074428, 62.444259779793875, 61.24694619859968, 54.6469635282244, 55.942423888615195, 52.094660895211355, 49.474043573652, 46.24554572786604, 46.42525046212332, 45.23967933654785, 42.38242026737758, 43.48918839863369, 46.975085735321045, 43.6360524722508, 48.25989103317261, 46.37013387680054, 44.638038294655935, 43.36982182094029, 46.922157832554404, 54.4647331237793, 56.7077054296221, 54.44633081981114, 57.34745386668614, 54.829381534031455, 57.47785765784127, 56.568842206682476, 54.449183055332725, 51.84860781260899, 48.811762128557476, 45.361484731946675, 42.98944616317749, 43.00904355730329, 41.63685771397182, 42.77882194519043, 41.95719746180943, 41.440341813223704, 42.562371662684846, 43.66551978247506, 40.79651825768607, 43.07123688289097, 44.227903502328054, 40.11867979594639, 38.70222697939192, 38.86108711787632, 45.380529744284495, 44.10498292105538, 40.70521892820086, 42.890715735299246, 39.2028203691755, 39.38456439971924, 39.6995609828404, 41.27428681509835, 42.49030842099871, 41.32639830453055, 42.3242186818804, 39.74455056871687, 39.696423871176584, 40.352931363242014, 40.464891161237446, 41.1312129838126, 40.443184988839285, 38.55501549584525, 39.72091627120972, 38.16256734303066, 39.30238110678536, 42.56230565479824, 40.27770321709769, 39.73874882289341, 40.28636762074062, 36.624826771872385, 38.77944925853184, 39.44756371634347, 39.818594047001426, 39.11680514471871, 41.28834649494716, 40.44057246616909, 38.91176380429949, 41.326255866459434, 41.40898806708199, 39.02399805613926, 42.50942291532244, 46.54139654976981, 41.71533761705671, 38.768040316445486, 36.415206568581716, 35.43397848946707, 36.18732302529471, 35.0660331589835, 41.069843019757954, 43.08093309402466, 39.2171927179609, 41.73419850213187, 40.40225315093994, 41.51324578693935, 42.024706159319194, 41.116124970572336, 40.093284130096436, 43.432143688201904, 43.952108655657085, 41.95607532773699, 43.21902854101998, 43.47712285178048, 43.946105412074495, 42.55615649904524, 42.202642577035085, 40.85350390842983, 40.65502514157976, 41.41435555049351, 41.086504799979075, 44.16843039648873, 41.96535464695522, 43.87953124727522, 42.961708954402376, 47.71744516917637, 43.58699124200003, 46.21050248827253, 45.738698959350586, 47.97292695726667, 47.9938896724156, 52.40695115498134, 54.49763284410749, 57.972572871616904, 59.067317145211355, 64.43452957698277, 61.133912903921946, 64.4265877859933, 63.37559631892613, 71.42155470166887, 64.00113568987165, 77.81819834027971, 11.846144454819814, 0.9832518505198615, 3.539532001529421, 0.28540602379611557, 0.12093978827553135, 38.34481859207153, 79.76092856270927, 69.35895415714809, 68.66585050310407, 63.5704585484096, 35.78078045163836, 19.11353373527527, 41.53899233681815, 57.594907011304585, 87.61923694610596, 30.842233657836914, 0.5494837377752576, 0.180496910320861, 0.1356570499816111, 0.2599876405937331, 0.14890037077878202], [0.020474734815901945, 0.05565052452896323, 0.035850275573985915, 0.08447026807282652, 0.045246011045362265, 0.0268690249150885, 0.4991219458835465, 45.76692601612636, 57.251384598868235, 38.41403654643467, 23.664200816835674, 40.95766087940761, 46.398704869406565, 39.98595183236258, 58.71383449009487, 53.90990209579468, 53.535592215401785, 3.0381352262837544, 0.16541851870715618, 0.3590732679835388, 0.8467718054141317, 40.87862859453474, 63.62049947466169, 62.23109599522182, 58.19176074436733, 57.080326897757395, 52.1900075503758, 50.94496331896101, 47.89666700363159, 45.82856695992606, 43.43766055788313, 41.59574522290911, 42.64490931374686, 41.52080542700631, 41.6441706929888, 41.3341247013637, 43.53311143602644, 42.28187983376639, 40.552330766405376, 41.97814975466047, 39.48929459708077, 41.19547687258039, 45.33390038354056, 49.8959173474993, 53.883624008723665, 52.03398922511509, 52.6899790763855, 48.146162918635774, 47.77279451915196, 51.35919754845755, 50.979627881731304, 50.35615907396589, 47.3505003792899, 42.986541816166465, 40.07588931492397, 38.828065804072786, 37.24405370439802, 38.94907563073294, 38.23365783691406, 37.93777922221592, 39.34833649226597, 39.05926363808768, 38.14804213387625, 37.44865036010742, 38.8727878843035, 42.83436931882586, 42.74889605385916, 37.64854308537075, 37.202604225703645, 41.048310552324565, 42.14796372822353, 43.16372088023594, 41.750412123543875, 43.187118938991, 40.289963313511436, 41.9306310244969, 38.74157115391323, 36.75538689749581, 35.16381515775408, 35.07862329483032, 35.0082345690046, 36.872116633823936, 34.96123695373535, 36.51405511583601, 34.500220503125874, 35.79234920229231, 34.10038641520909, 34.685855524880544, 32.97321489879063, 32.83722823006766, 35.27888427461897, 35.288271290915354, 34.6986471584865, 36.671904291425435, 34.13254615238735, 34.31217098236084, 35.14314774104527, 35.19267450060163, 38.08538327898298, 37.57115404946463, 35.01562397820609, 38.60252727781023, 41.143949031829834, 40.69884395599365, 38.44538681847708, 39.27052709034511, 36.853818552834646, 36.53786311830793, 35.89191688810076, 34.99351481028965, 35.31707157407488, 34.58444309234619, 33.861642837524414, 38.91277476719448, 38.831564222063335, 35.22729737418038, 34.53924853461129, 35.86158800125122, 38.24856172289167, 37.60842418670654, 37.284926482609336, 38.89460522787911, 38.5251521383013, 37.84809534890311, 37.448601722717285, 39.48603936604091, 38.53933341162545, 37.31928879874093, 36.305984360831125, 37.06044408253261, 39.18263932636806, 38.17777694974627, 39.39735950742449, 40.3842955316816, 40.22203424998692, 39.291340419224326, 38.00777537482125, 38.989288330078125, 41.59888233457293, 39.08886991228376, 41.44542442049299, 41.175573757716585, 41.554340907505576, 40.64174018587385, 44.213155950818745, 45.10743079866682, 49.553968702043804, 52.74771165847778, 56.66730860301426, 55.60848651613508, 59.239180837358745, 58.287138666425435, 63.93812247685024, 59.11296680995396, 70.55584389822823, 10.276847771235875, 0.35106880749974934, 0.3666657491454056, 0.04892464793686356, 0.0360558648992862, 21.307286739349365, 71.8640924181257, 57.106841223580496, 61.21453285217285, 40.5423218863351, 31.992876189095632, 8.033394302640643, 21.13145215170724, 38.476490429469514, 61.76200226375035, 21.673937967845372, 0.3765206831906523, 0.11941427870520524, 0.002303155866684392, 0.026473466140617217, 0.048707007829632075, 0.032076372365866385, 0.04293172826458301, 0.07224915349589926, 0.03943033829065306, 0.03592733679605382, 0.05166461983961718, 0.6869423932262829, 52.919346060071675, 65.56012385232108, 45.941714899880544, 31.316430841173442, 43.20149476187569, 49.92855651038033, 44.704014914376394, 65.03966903686523, 59.819001061575754, 60.89541598728725, 3.3219884634017944, 0.2603399088340146, 0.10606696563107626, 0.8827695537890706, 44.82997185843331, 65.94335869380406, 63.85179110935756, 59.7640894481114, 58.30418954576765, 53.46721151896885, 53.161157267434255, 51.41910144260952, 48.80239595685686, 45.79146357945034, 43.48047883169991, 44.06064993994576, 44.9607195854187, 44.70429284232003, 43.2619753565107, 45.76522370747158, 43.28932694026402, 42.76471710205078, 43.2001885005406, 42.44854627336775, 43.580571106501985, 48.18711560113089, 51.98846810204642, 53.52498231615339, 54.87604910986764, 53.794999735695974, 50.53444984980992, 49.757519653865266, 54.59742982046944, 53.30791711807251, 52.248080594199045, 49.62380852018084, 44.99193089348929, 41.955119950430735, 39.41912473951067, 39.65841722488403, 40.63746356964111, 40.20165170942034, 40.18766845975603, 39.963137422289165, 39.5915720803397, 39.84709555762154, 38.96638011932373, 40.91211543764387, 44.83624260766165, 41.17074128559658, 37.53566265106201, 36.68475151062012, 41.883414540972026, 42.61532735824585, 41.51952348436628, 42.59748785836356, 44.50650542122977, 40.294156551361084, 42.14197785513741, 40.18233224323818, 37.956775597163606, 36.8179588999067, 37.28682681492397, 36.94502408163888, 38.556669167109895, 37.0116468838283, 37.16588299615042, 36.40542350496565, 38.784042017800466, 36.56742422921317, 36.92938021251133, 34.6807416507176, 37.0932673726763, 37.847998074122835, 37.30792849404471, 36.42230762754168, 39.42713948658535, 36.21569946834019, 36.958545276096885, 36.93472337722778, 38.917992864336284, 41.237152167728965, 39.73511144093105, 35.691416195460725, 40.25652163369315, 41.96349947793143, 41.30848584856306, 38.15058517456055, 40.49293409075056, 37.855776582445415, 35.666145597185405, 36.231259959084646, 34.35695907047817, 36.59797893251692, 34.515398842947825, 34.31082650593349, 40.00688328061785, 40.987194197518484, 36.5680148260934, 36.53568138395037, 39.12538269587925, 38.38314485549927, 38.39156607219151, 39.29951844896589, 40.15416772024972, 40.39491932732718, 39.844406604766846, 39.339925697871614, 41.14136777605329, 40.15220138004848, 37.81202030181885, 38.42921141215733, 38.96967356545584, 39.86220441545759, 39.95333351407732, 41.22582312992641, 40.50633021763393, 41.00378996985299, 38.6814866065979, 39.94800077165876, 41.404489108494346, 42.865316595349995, 40.710860865456716, 43.52666003363473, 42.52296495437622, 44.47331040246146, 43.622017111097065, 46.25519330160958, 45.951174872262136, 52.20718002319336, 54.39925330025809, 57.730615752083914, 57.93838773454939, 63.270907810756135, 59.79841354915074, 66.57646465301514, 62.029890060424805, 74.79182706560407, 10.857493094035558, 0.23222861013242177, 2.6371084366525923, 0.2348034605383873, 0.06030213313975504, 22.72701563153948, 78.37956414903913, 61.90308543613979, 69.42468411581856, 45.175213950020925, 36.37467425210135, 15.604733398982457, 29.696333272116526, 45.413936683109824, 69.62152658190045, 28.867053610937937, 0.4067028436277594, 0.09918687838528838, 0.07596410558159862, 0.017799356054248552, 0.031190890951880386, 0.13983327017298766, 0.07920880575797387, 0.23089146188327245, 0.21370075004441397, 0.1193417025996106, 0.265784745237657, 1.021836934345109, 64.8826744897025, 77.1307783126831, 54.144671303885325, 34.90466124670846, 48.7245066506522, 61.21091978890555, 51.12793023245675, 73.39555876595634, 61.48517213548933, 67.94031265803746, 4.212420088904245, 0.2701360546052456, 0.3359883667102882, 1.7587379068136215, 47.14432995659964, 67.63597461155483, 66.93722207205636, 62.43233667101179, 62.20715945107596, 58.40435477665493, 55.80767052514212, 53.0108642578125, 50.194741998400005, 47.9943517276219, 46.415436131613596, 47.33487040655953, 47.3087660244533, 46.672175543648855, 46.241838863917756, 48.661524704524446, 45.69209739140102, 45.44624580655779, 45.89379317419869, 44.29729168755667, 45.9302955354963, 50.02791575023106, 55.24077047620501, 58.47809600830078, 58.1302935055324, 56.99688598087856, 48.88198062351772, 50.476248264312744, 56.82189907346453, 55.7173786844526, 55.07694237572806, 53.48111139025007, 46.76301976612636, 44.95360115596226, 42.312868799482075, 43.31838083267212, 42.70542117527553, 41.33955124446324, 41.48881939479283, 43.60145739146641, 42.82650743212019, 42.29658917018345, 41.61732632773263, 42.54098858152117, 46.34722914014544, 44.21845047814505, 37.36628641401018, 37.03426674434117, 44.117705072675435, 41.97393914631435, 42.584915093013215, 40.96241692134312, 44.02485976900373, 42.422045843941824, 43.619442803519114, 40.20817606789725, 38.80193362917219, 39.440462657383506, 39.68028667994908, 38.89702320098877, 42.37085846492222, 39.73936373846871, 40.24267039980207, 38.48103107724871, 40.383638926914756, 39.546408789498464, 39.76276527132307, 37.61507708685738, 38.610135555267334, 39.81625945227486, 39.9614212172372, 39.070068086896626, 41.85925912857056, 39.189174107142854, 39.64279072625296, 39.30329826899937, 41.1869410106114, 43.42920460019793, 40.826735973358154, 35.53123589924404, 40.71773958206177, 44.517094475882395, 40.86693477630615, 38.833631311144146, 40.64874744415283, 37.94677019119263, 35.799412046160015, 36.33516679491316, 34.54679427828108, 37.17293541772025, 35.22337859017508, 34.2729275567191, 41.2239853313991, 43.028929301670615, 38.87167269842965, 38.704255853380474, 39.43275015694754, 41.884699957711355, 41.424760477883474, 40.37402956826346, 41.95682920728411, 43.02047681808472, 41.74325547899519, 40.12788615907942, 42.74363626752581, 41.74126829419817, 39.45254904883248, 40.21598931721279, 41.41403940745762, 40.97632721492222, 41.05515800203596, 42.74183668409075, 43.22149862561907, 43.75592974254063, 41.702313218797954, 43.49311760493687, 42.883340222494944, 46.263645785195486, 42.97785309382847, 46.82962172372, 45.3553911617824, 47.06729180472237, 46.09638180051531, 49.265680994306294, 47.94935866764614, 52.96593025752476, 57.455713748931885, 60.58453968593052, 62.114220346723286, 65.40506090436662, 63.11865888323103, 69.38859517233712, 64.69676154000419, 78.06205926622663, 12.984678012984139, 0.6729173458048275, 6.682646691799164, 0.553733266890049, 0.12352744942264897, 25.076262371880667, 82.19163772038051, 68.34447547367641, 75.05701201302665, 54.43937914712088, 43.35235752378191, 18.50749100957598, 38.01203809465681, 52.94634328569685, 79.72213676997593, 38.58689383098057, 0.4327449362192835, 0.1886197208826031, 0.16222645927752766, 0.28513694394912037, 0.11621734739414283], [0.05592338042333722, 0.04285187826358846, 0.07971041277050972, 0.026733606288741742, 0.05006375556279506, 0.07488340964274746, 0.6019400858453342, 44.62194626671927, 52.12481607709612, 42.41847446986607, 50.37835856846401, 17.31114843913487, 26.257273742130824, 39.96823392595564, 58.98662076677595, 55.72585548673357, 52.515343053000315, 3.1068767947810034, 0.27061732592327253, 0.42571547627449036, 0.5044751529182706, 34.16998652049473, 67.042799949646, 58.7359436580113, 58.98024926866804, 53.38759905951363, 51.515156814030235, 50.6688106400626, 47.26892852783203, 46.361771719796316, 45.68229695728847, 48.20082092285156, 46.16808026177542, 48.58606726782662, 49.988053934914724, 47.88033526284354, 48.99602835518973, 49.929178374154226, 48.595753056662424, 45.82745177405221, 49.43060343606131, 47.09334407533918, 52.04614509854998, 50.04478945050921, 55.72193670272827, 45.642803396497456, 38.612838404519216, 45.06281641551426, 46.8685177394322, 52.26543024608067, 47.287230082920615, 46.75362580163138, 43.18155690601894, 46.46261440004621, 48.12364380700247, 46.22641038894653, 41.124348163604736, 37.89955718176705, 39.88714497429984, 39.52678707667759, 37.68201950618199, 38.997518471309114, 37.682960987091064, 37.5203731400626, 37.837409019470215, 40.45743921824864, 42.32343353543963, 38.79789672579084, 37.0511543410165, 41.25148630142212, 40.54801940917969, 38.26363583973476, 40.11717203685215, 39.31550972802298, 40.9588941846575, 40.439780371529714, 40.10125371388027, 36.58783803667341, 37.25742203848702, 37.17248378481184, 36.887854303632466, 35.58333696637835, 35.652982234954834, 35.87555040631975, 36.318564074380056, 35.315643719264436, 34.367099966321675, 34.43282297679356, 32.668536390577046, 32.40857996259417, 35.611230509621755, 34.81698887688773, 32.9249700818743, 34.52929524012974, 35.795785086495535, 34.44337729045323, 33.357825483594624, 37.22334112439837, 37.04395948137556, 34.780715806143625, 36.13499961580549, 38.91426168169294, 42.440774713243755, 40.83559145246233, 43.14426245008196, 41.21107905251639, 32.859212330409456, 36.112751483917236, 36.02466917037964, 36.42252996989659, 34.08778585706438, 33.82409129823957, 34.91259608949934, 43.119287150246755, 37.27808598109654, 34.95875992093767, 36.44653252192906, 36.74416903087071, 36.570957388196675, 36.977079595838276, 37.24093048913138, 37.83356319155012, 38.851227624075754, 37.75957529885428, 38.86442225319998, 38.91762113571167, 38.48867756979806, 40.048589842660085, 41.57106522151402, 41.84722137451172, 41.27139636448452, 38.202495166233604, 37.4953943661281, 37.20754092080252, 37.78243487221854, 37.67418541227068, 40.305023533957346, 39.17806741169521, 39.836113929748535, 40.42650931222098, 40.1175993510655, 39.61581434522356, 41.821672848292756, 43.07337692805699, 41.99808761051723, 41.522365297589985, 46.70800392968314, 48.69202034814017, 53.31266621180943, 52.03770651136126, 58.92062677655901, 55.40189225333077, 62.61569963182722, 57.7522246497018, 71.43895299094063, 11.145595805985586, 0.12346544489264488, 0.3260446531432015, 0.23978789736117634, 0.10650300580476012, 13.719745312418256, 72.27319540296281, 57.676419803074424, 64.29153564998082, 46.99417243685041, 51.05600595474243, 15.66385735784258, 30.394637652805873, 40.53608240400042, 64.66856575012207, 27.278961181640625, 0.3281375808375222, 0.05284599680453539, 0.011330748558975756, 0.07206912458475147, 0.05394536263442465, 0.03977319525022592, 0.016278441862336228, 0.11928049874092851, 0.06552516323115144, 0.021029062303049222, 0.08667666717831578, 0.7960278625999178, 56.12580074582781, 62.549365179879324, 48.250983442579, 44.80637230191912, 25.393279143742152, 28.669003895350865, 45.40423699787685, 65.92568942478725, 61.04973547799246, 59.83055591583252, 3.177505884851728, 0.42847358541829245, 0.3202952359403883, 0.4954407034175736, 35.80720097678048, 70.95582389831543, 61.466259138924734, 62.1276581627982, 54.552051135471885, 54.38031945909773, 52.822908537728445, 49.47812564032418, 48.56842231750488, 47.876096861703054, 49.01408672332764, 49.275738511766704, 50.74252755301339, 53.09970045089722, 49.96946055548531, 51.8927184513637, 51.0192152432033, 51.60331208365304, 47.99408769607544, 51.688198225838796, 50.10488789422171, 53.506583486284526, 51.64091226032802, 57.69709069388253, 47.06814990724836, 38.06885698863438, 46.01998635700771, 47.79060970033918, 53.82109022140503, 49.19446890694754, 48.50137220110212, 44.999421051570344, 50.41943631853376, 48.86161892754691, 48.496838501521516, 43.19874674933297, 39.912155015128, 40.09191533497402, 41.006343432835166, 40.38180112838745, 40.66647924695696, 39.33652455466134, 39.74052061353411, 39.72318833214896, 42.47205202920096, 42.560777051108225, 38.86568682534354, 36.90282072339739, 40.44423416682652, 41.21170091629028, 39.20687811715262, 42.14733144215175, 40.26205587387085, 41.219667025974815, 41.46169015339443, 39.476134708949495, 38.28123910086495, 38.7402023587908, 39.31892129353115, 38.70535714285714, 38.29453795296805, 36.34707600729806, 36.79494994027274, 37.570723261152, 37.74524116516113, 35.9788110596793, 35.85171113695417, 35.1143022945949, 35.32344307218279, 37.036194869450156, 36.69731385367257, 35.74386814662388, 37.596737316676546, 37.33726726259504, 36.357442719595774, 35.73452629361834, 38.23890372685024, 37.91341188975743, 36.36505447115217, 36.15191847937447, 38.664786611284526, 42.22667639596121, 42.55968965802874, 43.25427327837263, 41.74746608734131, 33.315893105098176, 35.97457960673741, 34.85453346797398, 35.59948110580444, 33.15758187430245, 34.163576807294575, 36.69992290224348, 44.31075382232666, 39.80417653492519, 35.89078433173043, 37.9588565826416, 38.720757825034006, 37.209514209202354, 37.94977181298392, 39.56230279377529, 38.55293798446655, 39.955796650477815, 38.670435496738975, 39.988220419202534, 41.0331426348005, 40.148876667022705, 41.06338814326695, 43.15928098133632, 43.12079838344029, 42.83030809674944, 39.82043531962803, 39.104076044900076, 38.71517494746617, 40.777608735220774, 39.97297259739467, 42.19203962598528, 41.00986269542149, 42.792881625039236, 42.71014595031738, 42.42331041608538, 42.51281016213553, 44.35489920207432, 43.29095976693289, 45.715304374694824, 45.06206948416573, 49.419708660670686, 51.484775815691265, 56.65257147380284, 54.93666519437517, 61.69100557054792, 58.61569813319615, 66.27922071729387, 60.47871862139021, 74.57757936205182, 12.167525563921247, 0.17406450690967695, 1.3486564201968056, 0.37141343152948786, 0.10154060779937676, 15.871697085244314, 77.98872797829765, 63.525281361171174, 68.90400000980922, 53.007379736219136, 44.812851497105186, 20.016962834766932, 36.390029770987375, 45.65313884190151, 74.65943608965192, 34.31105579648699, 0.23384732327290944, 0.05256566684693098, 0.04237294110602566, 0.05597119000075119, 0.014681436753432666, 0.10644918440708093, 0.09488402320338146, 0.4151316327708108, 0.18950283420937403, 0.1617095920124224, 0.17916912585496902, 1.2259769631283624, 65.57745265960693, 71.1063427243914, 57.04285178865705, 65.84385354178292, 24.18425784792219, 35.56778342383248, 54.36530787604195, 69.57139532906669, 70.14527484348842, 64.94749423435756, 4.0469057474817545, 0.5753390703882489, 0.763486463044371, 1.084113855447088, 39.083443369184224, 72.55503518240792, 63.73529066358294, 63.623528889247346, 57.976571559906006, 57.86815186909267, 55.9428824697222, 51.75947632108416, 50.33896575655256, 52.33609689985003, 53.271227155412944, 50.31404604230608, 54.34520673751831, 53.871353490012034, 51.56187302725655, 54.62631695611136, 55.12715353284563, 54.54898003169468, 49.539287158421104, 54.65782356262207, 51.751079423086985, 57.5223400252206, 53.47484411512102, 59.8973628452846, 50.38318756648472, 39.64654622759138, 44.791669913700645, 51.15535477229527, 56.910064765385215, 52.58282395771572, 50.94349724905831, 46.339124066489084, 51.87183911459786, 52.54030793053763, 50.80675670078823, 45.30894245420183, 41.83325549534389, 43.649938447134836, 43.603364671979634, 41.84418848582676, 43.090167249952046, 41.30452537536621, 41.30128056662423, 40.93816770826067, 44.29113905770438, 44.084423201424734, 39.850246565682546, 35.68132046290806, 41.395091669900076, 41.557203565325054, 40.86121640886579, 41.80738040379116, 39.12217957632882, 41.719190393175396, 40.5251007761274, 38.77927555356707, 38.67988504682268, 39.3504695892334, 42.64479466847011, 42.38821159090315, 39.52357700892857, 38.83507306235177, 39.82458339418684, 40.31831891196114, 39.54612043925694, 38.09288733346121, 39.254167556762695, 38.359027658190044, 37.63436528614589, 39.2038174356733, 39.277523926326204, 38.653304713112966, 39.80549669265747, 39.8923213822501, 39.834911891392295, 37.5891672543117, 40.695192677634104, 39.87751129695347, 37.393342699323384, 37.51006201335362, 39.956338609967915, 44.47070482798985, 42.60539838245937, 44.28158875874111, 43.405431338718955, 33.08215570449829, 35.98376859937395, 34.950210162571494, 38.00738974979946, 33.66408123288836, 34.429765769413535, 37.07025841304234, 47.561183656964985, 41.98149183818272, 38.85484068734305, 40.969309534345356, 40.14111205509731, 40.40319810594831, 39.10619177137102, 41.90414101736886, 39.52250003814697, 42.30798421587263, 39.921712262289866, 42.91751493726458, 42.75069216319493, 42.09133243560791, 43.57498475483486, 46.21099581037249, 45.94344847542899, 45.96644006456648, 42.08542994090489, 40.416893005371094, 40.91807004383632, 41.70677743639265, 42.393943854740684, 44.18808685030256, 42.67721496309553, 44.634994983673096, 44.315739154815674, 45.01486689703805, 44.10832500457764, 47.09438977922712, 47.53977973120553, 47.65214599881853, 47.07495566776821, 52.48214456013271, 54.265990325382774, 59.33738667624337, 57.31707981654576, 67.04239000592912, 60.36820752280099, 70.79075554439, 62.689030919756206, 79.80657127925328, 14.188319666045052, 0.4410711037261145, 2.886783702032907, 1.0826019708599364, 0.1196883525699377, 17.863012586321148, 85.52588367462158, 68.72599411010742, 77.43434510912213, 61.94713006700788, 67.64837714603969, 27.853730065482004, 47.68818283081055, 55.84175838742937, 83.63802337646484, 45.10564511162894, 0.35444324357169016, 0.13144284539989062, 0.1327275971748999, 0.17150993113006863, 0.1472903293158327], [0.07577216838087354, 0.034827774191009145, 0.030811291321047714, 0.028898423071950674, 0.039248192350247076, 0.010323447208585483, 0.3675883396395615, 37.56346934182303, 54.676705292293, 43.26187808173043, 37.94378246579851, 19.184537376676285, 33.1006691796439, 42.78653791972569, 61.52172660827637, 50.48556579862322, 53.562777042388916, 3.849215166909354, 0.28171834881816593, 0.25004398130944794, 0.37754983082413673, 24.948401621409825, 65.33751051766532, 59.70059680938721, 57.26623289925711, 54.17085559027535, 50.35978603363037, 49.16432067326137, 48.69573763438633, 49.14874281202044, 51.613070828574045, 50.934704303741455, 53.479700905936106, 51.825692653656006, 55.02922214780535, 53.27931833267212, 52.853650842394146, 54.290225642068044, 53.05709062303816, 53.33564737864903, 51.63459287370954, 51.05247279575893, 53.728894574301584, 52.665114947727744, 47.89993960516793, 50.58201374326433, 43.94178710665022, 52.58784750529698, 51.21140589032854, 49.91760267530169, 47.26846994672503, 44.182326793670654, 44.75318036760603, 44.926131452832905, 49.16507455280849, 49.213107449667795, 48.08698163713728, 41.88200058255877, 38.43738596779959, 38.2610650062561, 36.861114161355154, 38.430323123931885, 37.722096715654644, 37.04765592302595, 38.89549807139805, 38.918500082833425, 42.07346166883196, 41.06487505776541, 38.53624493735177, 38.08760322843279, 42.46153245653425, 38.13771711077009, 39.30787018367222, 41.01587288720267, 41.82071399688721, 42.3450528553554, 39.3858185495649, 34.24867139543806, 35.653909819466726, 38.89729070663452, 37.946718079703196, 36.80909647260393, 37.32080003193447, 33.99134486062186, 35.3932273047311, 35.040276186806814, 34.74073934555054, 35.62009293692452, 33.307037625994, 34.8679712840489, 36.94381856918335, 34.61961834771292, 35.126294885362896, 34.42010082517351, 36.1471346446446, 35.5434820992606, 36.63541235242571, 36.380826881953645, 34.47534942626953, 38.159270422799246, 38.14640930720738, 39.39156470979963, 39.41860362461635, 41.34147242137364, 39.354881695338655, 35.77438810893467, 34.39179039001465, 33.66443906511579, 36.0745780808585, 35.2094544001988, 34.24516255514962, 32.84638595581055, 37.30677161897932, 44.341371059417725, 35.64721523012434, 35.21315779004778, 35.91736119134085, 37.078144618443076, 35.39286599840437, 36.25249712807791, 36.81370312826974, 38.30300085885184, 37.37267180851528, 38.28262179238455, 36.94149439675467, 38.035425731113975, 43.57339709145682, 46.90017720631191, 48.42476136343819, 48.9613151550293, 44.87059450149536, 45.066172395433696, 42.00228084836687, 42.06732293537685, 43.485662187848774, 42.161995615277974, 41.57140220914568, 41.51856810706002, 42.46000732694353, 41.01602227347237, 42.8683842250279, 41.556133542742046, 44.620646953582764, 42.400395257132395, 41.45439454487392, 41.81588152476719, 42.3316775730678, 41.92826516287667, 44.072117941720144, 46.40767151968819, 53.87825652531215, 55.62738561630249, 63.2714011328561, 59.28500420706612, 71.3080975668771, 15.348068680082049, 0.28239321974771364, 0.9916358292102814, 0.5371757096477917, 0.0434625292462962, 7.629504203796387, 72.44876943315778, 54.21774203436715, 72.8241389138358, 43.746827602386475, 59.161722319466726, 26.976549523217336, 25.475954021726334, 39.73027549471174, 58.861580984933035, 28.920063155038015, 0.5835310508097921, 0.08021801803261042, 0.045956769692046304, 0.036254268538739, 0.03780936562855329, 0.08507375711841242, 0.04628616451684918, 0.03459552861750126, 0.03196296202284949, 0.08141240251383611, 0.014015813408020352, 0.7409704455307552, 49.926756926945274, 63.55942480904715, 49.01201268604824, 44.923977511269705, 26.076759542737687, 32.90364606039864, 48.96945149557931, 67.92410251072475, 57.441727025168284, 58.19427946635655, 3.6315576348985945, 0.40454141103795593, 0.17251075671187469, 0.37741830359612194, 28.41917794091361, 68.0695491518293, 62.447671345302034, 60.76021099090576, 55.304850237710134, 54.15096984590803, 50.921429770333425, 51.69320787702288, 50.70782477515084, 52.81030797958374, 53.52250528335571, 55.11560215268816, 56.30840982709612, 58.15518542698452, 54.69017090116228, 56.995072501046316, 57.06845590046474, 55.20990310396467, 54.152439389910015, 53.60388605935233, 53.73943151746477, 55.42854554312569, 54.122339793613975, 49.219280924115864, 51.80419840131487, 44.85695171356201, 52.815936020442415, 55.3237840788705, 50.579401220594136, 48.57318183353969, 47.084332261766704, 47.801313400268555, 46.50456414903913, 51.94631338119507, 50.59276608058384, 50.85165596008301, 43.398795809064595, 38.36524282182966, 38.15174552372524, 38.7741825239999, 39.84380211148943, 39.83623552322388, 39.903160572052, 40.93858807427542, 39.821519238608225, 43.26680782863072, 42.50345441273281, 38.16289390836443, 38.85428483145577, 41.686895166124614, 39.9800180707659, 39.76256029946463, 41.47428723743984, 41.651181425367085, 43.16187265941075, 41.18175418036324, 34.887638160160606, 37.10452692849295, 39.60818869726998, 38.55533858707973, 37.9371017728533, 38.18947771617344, 36.41408790860857, 35.49872180393764, 37.9080548286438, 36.69898836953299, 35.728787081582205, 36.572190693446565, 38.081655570438926, 38.065740721566335, 37.736007009233745, 37.131833348955425, 37.38228464126587, 38.19672121320452, 37.9055951663426, 39.784773690359934, 39.89336708613804, 36.46553931917463, 38.91163873672485, 38.09051104954311, 40.297700132642476, 41.42856809071132, 42.09546661376953, 38.655945028577534, 35.94885737555367, 33.94301666532244, 33.00572204589844, 36.07088163920811, 34.56054128919329, 33.09628139223371, 33.554077352796284, 37.978950772966655, 46.792459283556255, 37.487223284585134, 38.09791088104248, 37.771859713963096, 39.268727506910054, 37.11859703063965, 38.30583572387695, 39.447879859379356, 39.21938140051705, 39.61921548843384, 38.4812707901001, 38.33579635620117, 39.61365692956107, 44.434216363089426, 47.703548771994456, 50.09757144110543, 51.80691514696394, 48.87771790368216, 46.67026131493704, 43.56268296922956, 44.318320410592214, 45.106801986694336, 44.78562845502581, 43.56436095918928, 43.126464639391216, 43.28651291983468, 42.06732988357544, 44.37285682133266, 44.164841651916504, 46.52615220206124, 44.78385319028582, 44.42484671728951, 43.59588146209717, 45.157496043613975, 45.350447518484934, 47.13454341888428, 49.18156957626343, 56.87166901997158, 57.16784988130842, 64.99367891039167, 62.84319755009243, 74.14710371834892, 17.301182985305786, 0.5844862652676446, 2.221525388104575, 0.5859040777598108, 0.04323028367278831, 7.978727613176618, 78.0208911895752, 59.13873767852783, 76.47172777993339, 52.34371559960501, 55.29817649296352, 22.70179714475359, 30.791195665087017, 43.66680867331368, 66.90685844421387, 38.96247523171561, 0.5039461127349308, 0.09112157366637673, 0.03975398592384798, 0.04992138195250716, 0.0224708321703864, 0.1596599141401904, 0.19256363782499517, 0.08519687051219599, 0.08346147648990154, 0.2033787396337305, 0.11729191616177559, 0.9848997678075517, 60.68504537854876, 73.81384726933071, 60.54471261160714, 52.08679206030709, 28.24339199066162, 47.58595745904105, 57.068396840776714, 73.10256017957414, 63.210958753313335, 64.5404965536935, 5.473217189311981, 0.642671023096357, 0.48899451217481066, 0.667246801512582, 31.772010326385498, 70.47902461460659, 63.931591170174734, 64.24499661581856, 57.71306112834385, 56.297428199223106, 52.633431162152974, 55.45371191842215, 54.48495585577828, 55.63295112337385, 55.56078018460955, 57.65095118113926, 57.29526594706944, 60.22584588187081, 56.6971754346575, 58.22622380937849, 60.431088720049175, 58.605373110089985, 56.642684187207905, 57.97277436937605, 56.31593472617013, 59.160624504089355, 54.89305135181972, 51.8404541015625, 51.07513434546334, 46.60225929532732, 56.18521479197911, 57.38416467394148, 55.25858565739223, 50.46891096660069, 48.83112675803048, 50.68319688524519, 50.545844895499094, 55.2355489049639, 53.133948121752056, 53.24738788604736, 46.01565415518624, 41.994978291647776, 41.71174539838518, 40.52698026384626, 42.664520604269846, 41.30281959261213, 40.5231101172311, 42.69147614070347, 41.80172457013811, 44.24658373423985, 42.56397322246006, 39.5342390196664, 39.58078152792794, 41.7154974256243, 41.696886675698416, 40.67703356061663, 41.74919618879046, 43.076100621904644, 44.11079508917672, 41.85368319920131, 34.93497971126011, 38.53626578194754, 43.93450539452689, 42.25653975350516, 41.59154503686087, 41.50772891725813, 37.41389547075544, 37.584105491638184, 39.65630497251238, 39.312056473323274, 39.63378586087908, 39.48229776109968, 41.291692052568706, 41.438455377306255, 41.32131569726126, 39.7575888633728, 39.27147204535348, 41.43057612010411, 42.583303110940115, 42.287184783390586, 40.365726470947266, 38.48254925864083, 39.63687086105347, 38.484567710331504, 42.081886359623496, 42.008791310446604, 42.34538984298706, 40.16707399913243, 36.13718482426235, 35.781919956207275, 34.17752184186663, 36.44238444737026, 36.209710121154785, 33.776159150259836, 32.98320640836443, 39.395942074911936, 48.92269011906215, 39.110079288482666, 39.14398302350725, 39.22627748761858, 41.72692026410784, 39.42546844482422, 40.011628900255474, 41.81809800011771, 41.41319520132882, 39.72667285374233, 40.383889062064036, 39.706474440438406, 42.1977892603193, 47.28560767854963, 50.94012042454311, 52.07757527487618, 53.998446464538574, 49.560777936662944, 48.42226348604475, 44.4786605153765, 47.08162593841553, 46.755550452641074, 46.68975101198469, 44.840317726135254, 46.135430676596506, 46.61113909312657, 44.99311556134905, 46.37447302682059, 46.325679302215576, 49.23365674700056, 47.39758137294224, 47.17604848316738, 46.47150114604405, 47.28921379361834, 48.48853193010603, 49.059402874537874, 51.80972916739327, 59.528448241097585, 61.12016936710903, 69.34532179151262, 65.97019958496094, 78.93623297555106, 19.762028217315674, 0.9529325174433845, 5.030167477471488, 1.7133423941476005, 0.1173591318407229, 9.229504976953779, 86.78903143746513, 62.47449834006173, 83.99170752934047, 57.450808320726665, 76.87493174416679, 38.4641295841762, 40.07346439361572, 55.12291860580444, 74.74585083552769, 51.6339362689427, 0.8613352839435849, 0.23861908007945332, 0.14181964072797978, 0.1687418068093913, 0.07423449267766305], [0.03897733134882791, 0.03779878726761256, 0.08153872537825789, 0.09566560733531203, 0.03563206549733877, 0.01991671440191567, 0.28472678310104776, 31.137007508959087, 59.957430022103445, 34.033961636679514, 22.403795855385916, 20.853816032409668, 30.81389890398298, 44.00915336608887, 60.12747328622, 48.07445750917707, 55.81519195011684, 4.728647794042315, 0.24532227324587957, 0.18982462265661784, 0.26254851317831446, 14.010092292513166, 66.73158318655831, 59.320738792419434, 57.61508805411202, 54.75362532479422, 50.512701988220215, 52.03130374635969, 50.89744111469814, 54.402876785823274, 55.10023968560355, 55.6809458051409, 54.868298394339426, 57.38476569311959, 56.100311279296875, 54.02697229385376, 52.97815213884626, 51.38284574236189, 50.82920285633632, 52.694349493299214, 52.56835780824934, 53.02289506367275, 51.67871046066284, 49.75413588115147, 51.99078185217721, 50.98970971788679, 51.83579880850655, 50.83914920261928, 47.44459983280727, 47.690006732940674, 42.36190571103777, 46.430947984967915, 52.18282658713204, 58.74022374834333, 52.27087763377598, 47.75457981654576, 49.714996678488596, 47.631336144038606, 39.29771539143154, 39.335930483681814, 38.32394620350429, 38.01026977811541, 36.393295424325125, 37.483922890254426, 39.40837240219116, 37.63222871507917, 41.30635622569493, 45.11553239822388, 35.64509950365339, 36.964249747140066, 39.147293840135845, 41.55952773775373, 39.07137087413243, 40.14528792245047, 40.9101699420384, 41.465226786477224, 39.91397196905953, 35.45447220121111, 34.01172392708914, 36.61430025100708, 39.632820061274934, 37.96570750645229, 36.4810129574367, 35.7290163721357, 35.45523650305611, 35.23003149032593, 35.169359820229666, 34.749389852796284, 33.30471692766462, 35.39309876305716, 37.42778491973877, 34.29460941042219, 33.896724292210166, 34.950512409210205, 33.48864269256592, 36.76641368865967, 35.89061062676566, 34.56162520817348, 35.491777079445974, 39.934514318193706, 36.288627760750906, 39.087525435856406, 40.73865365982056, 36.088276454380576, 34.03726550510952, 32.62086827414376, 34.2250440461295, 34.61481366838728, 34.77541780471802, 32.906119619097026, 33.76640040533883, 30.748349598475865, 41.91601548876081, 42.136853558676584, 34.479073660714285, 35.88465254647391, 36.1692681312561, 38.14529412133353, 37.00258295876639, 37.14769261223929, 36.74713591166905, 38.22867945262364, 37.73894262313843, 39.48122426441738, 39.448567731039866, 44.48098121370588, 48.08036347797939, 49.03768627984183, 50.92385469164167, 49.167221546173096, 53.616149629865376, 49.43462296894619, 47.948187896183555, 47.31356028148106, 47.16739102772304, 46.24745300837925, 48.992019244602744, 48.23482193265642, 48.02410738808768, 47.40722894668579, 47.64452035086495, 48.93576315471104, 49.614185265132356, 50.308588232312886, 48.965626512254985, 46.768081528799875, 47.94718735558646, 44.72471359797886, 45.437074184417725, 43.337200028555735, 48.78000886099679, 52.88438272476196, 60.664694104875835, 59.21748161315918, 69.96095303126744, 17.617520570755005, 0.4217039772442409, 0.4969786437494414, 0.5742045055542673, 0.06222723876791341, 3.784774099077497, 68.23773724692208, 57.52528606142317, 67.50155476161412, 49.754226207733154, 54.88654783793858, 42.450644629342214, 27.819972242627824, 39.413149288722444, 60.902440616062705, 39.54634278161185, 0.5041262773530824, 0.10296006234628813, 0.023701218023364033, 0.08167962996023041, 0.021621905134192536, 0.044301184958645275, 0.05323362350463867, 0.07910956322614636, 0.11023765576205083, 0.026672471979899064, 0.06510238163173199, 0.16904861320342335, 41.536296435764854, 70.31802790505546, 43.17788478306362, 29.67476258959089, 19.163777896336146, 34.09172895976475, 49.777971676417756, 65.2351496560233, 55.04352848870413, 60.650478090558735, 5.061777438436236, 0.27233315099562916, 0.299320605716535, 0.47215625856603893, 15.05514131273542, 69.42769268580845, 60.85683958871024, 61.12071132659912, 54.78939465114048, 53.64932727813721, 52.19609069824219, 53.07700416019985, 56.02880389349801, 55.95463187353951, 57.696409770420615, 57.4884467124939, 57.40168455668858, 58.452853202819824, 55.61687299183437, 56.24633462088448, 52.46845660890852, 53.21340077263968, 54.788307258060996, 55.2629074369158, 54.2934878213065, 53.09214081083025, 50.08023221152169, 51.609357016427175, 52.7315536226545, 56.22229732785906, 53.284255027770996, 49.05063077381679, 49.28848845618111, 45.4579222542899, 48.22082826069423, 56.30384833472115, 61.11486094338553, 53.39831665584019, 52.25774206433977, 51.80209657124111, 48.50550985336304, 41.32868773596627, 41.221376282828196, 39.925860336848665, 39.714930398123606, 37.99320500237601, 38.81915473937988, 40.7260148865836, 39.90171534674508, 43.97735840933663, 45.88995429447719, 36.66012709481375, 36.85920340674264, 38.93655845097133, 42.29610627038138, 38.98565789631435, 41.25259106499808, 40.55351196016584, 42.81229141780308, 40.87350082397461, 35.6370187486921, 34.294425283159526, 36.31051458631243, 42.59323903492519, 39.42897033691406, 39.200433662959504, 38.402676241738455, 37.3175482749939, 38.18359954016549, 36.659435749053955, 36.135458196912495, 35.04962846211025, 37.8935226712908, 37.80947726113455, 36.20294257572719, 36.790489196777344, 37.71028825214931, 36.10672739573887, 37.0232503754752, 37.440739836011616, 36.36574929101126, 38.24916621616909, 41.243662629808696, 36.691230705806184, 40.376162665230886, 42.82268592289516, 36.13317918777466, 35.743433884211946, 34.46786969048636, 33.79607268742153, 34.722934586661204, 34.04201807294573, 32.023670605250764, 34.02276461465018, 31.268672398158483, 43.267947333199636, 43.343109471457346, 36.12889562334333, 38.559267793382915, 38.08937154497419, 38.24906546728951, 38.42374665396554, 38.450035163334434, 38.63447509493147, 40.395447390420095, 39.30817590441023, 41.27358852113996, 40.80934810638428, 47.37644495282854, 49.58594083786011, 50.77123403549194, 53.09483323778425, 50.40198939187186, 54.74770545959473, 52.33947719846453, 49.66009896142142, 49.2734351839338, 50.87508528573172, 49.05886091504778, 49.970895358494346, 50.34169292449951, 51.87914514541626, 50.067642075674875, 49.7351325580052, 49.723150389535085, 52.20045416695731, 51.906111104147776, 50.65886081968035, 50.50059127807617, 49.79806934084211, 46.97013861792428, 47.03806420734951, 45.347591808864046, 51.9080114364624, 55.12499959128243, 62.770227568490164, 60.85378932952881, 72.61940329415458, 20.226508344922745, 0.29948158136435915, 0.5970731441463742, 0.8952435244406972, 0.1539865200008665, 3.960848833833422, 73.66785172053746, 64.08799512045724, 74.81067058018276, 54.31535727637154, 60.670037269592285, 36.216175419943674, 32.55410303388323, 48.50996364865984, 66.83506965637207, 50.75272056034633, 0.554928465613297, 0.11131951878113405, 0.021819282489429628, 0.01868022682278284, 0.06597925922168152, 0.16679023153015546, 0.17911423237196036, 0.21179817856422492, 0.3330997074288981, 0.11767228932252952, 0.14720148194049085, 0.6906469772968973, 54.41865961892264, 78.97413539886475, 48.87451825823103, 35.19920233317784, 30.41347074508667, 43.91196543829781, 58.80789920261928, 70.60403660365513, 61.221738134111675, 65.76174667903355, 6.453799085957663, 0.5452569531542915, 1.1436407012598855, 0.6500313909990447, 17.47436683518546, 72.41480663844517, 62.6886487688337, 64.51518426622663, 57.30315910066877, 56.66062791006905, 54.487054211752756, 56.28376109259469, 61.01067270551409, 58.28123964582171, 60.377872467041016, 58.998314585004536, 61.80310780661446, 62.315384592328755, 58.17775665010725, 58.86464514051165, 55.138611112322124, 54.34702021735055, 58.30938679831368, 57.286712714603965, 57.04778848375593, 55.784109183720176, 51.574386732918875, 53.134632519313264, 54.901086943490164, 57.93324259349278, 56.6957962172372, 51.09711844580514, 52.41204071044922, 47.23296465192522, 52.10129642486572, 56.50886883054461, 59.68984794616699, 56.71104403904506, 54.60714340209961, 53.24890259334019, 52.10640682492937, 43.89132581438337, 43.53181559698922, 41.14777748925345, 40.8838084765843, 39.74059704371861, 40.888005188533235, 43.91338287081037, 42.02163852964129, 46.166641984667095, 47.49608598436628, 37.47324350902012, 37.14482648032052, 38.833502769470215, 41.221744537353516, 40.127900055476594, 43.22460099628994, 41.54409578868321, 43.19820826394217, 41.63734061377389, 34.80356843130929, 36.08880451747349, 37.374794483184814, 43.75132308687483, 41.6355688231332, 42.185473578316824, 41.19456665856497, 39.73410742623465, 39.959510462624685, 37.93453441347395, 39.28716107777187, 37.79094294139317, 40.30061490195138, 41.31853641782488, 38.13842582702637, 39.24685457774571, 40.2785439491272, 37.061587061200825, 40.19085768290928, 39.549229758126394, 37.16280147007534, 39.504820346832275, 41.60880088806152, 36.870959758758545, 41.544839245932444, 44.33223417827061, 36.1549722126552, 35.377531324114116, 34.522805622645784, 34.30896438871111, 35.14361327035086, 34.06652784347534, 32.49275391442435, 34.33649662562779, 31.616895266941615, 45.08645418712071, 46.87557710920061, 38.02424955368042, 40.045880045209614, 39.534763608660015, 40.9401409966605, 40.063639640808105, 40.55180270331246, 41.207010882241384, 42.64492668424334, 40.68512126377651, 44.2440059525626, 43.394720690590994, 50.04893405096871, 52.637770312173025, 52.620483194078716, 53.78196838923863, 53.3963885307312, 57.885390349796836, 52.97080441883632, 52.04746525628226, 51.343439034053254, 52.18559544427054, 51.37867334910801, 52.05230120250157, 52.44787604468209, 54.574948923928396, 51.18321010044643, 51.58306155885969, 52.424477985927034, 54.34293120247977, 55.1209522656032, 53.40904467446463, 52.054656641823904, 53.411671093532014, 49.70236832754952, 50.34426028387887, 47.604846136910574, 54.72934831891741, 58.369460923331125, 68.12406471797398, 64.5278855732509, 78.92736707414899, 21.208952358790807, 0.9605200588703156, 3.5968776558126723, 1.448510393500328, 0.3681501666350024, 5.172453122479575, 79.95724991389683, 67.87932137080601, 80.55251598358154, 64.27312987191337, 72.58152866363525, 57.90369537898472, 41.27233784539359, 58.17638438088553, 76.38199874332973, 63.96947274889265, 0.8308835551142693, 0.3184838459960052, 0.07812464250517742, 0.1182256346302373, 0.13648543267377786], [0.033485038205981255, 0.07021578082016536, 0.027865954009549956, 0.07678657144840274, 0.11969614215195179, 0.058572845932628424, 0.2525780110486916, 26.54711263520377, 59.527871540614534, 36.5051440511431, 37.68213415145874, 28.302621909550258, 37.555121081215994, 42.369190897260395, 61.728456360953196, 49.929143633161274, 57.23599433898926, 5.1785123859133035, 0.20519018386091503, 0.25653213315776413, 0.2117809166333505, 5.437379249504634, 56.70931393759591, 60.21523598262242, 58.48375184195382, 59.7978299004691, 50.45439270564488, 52.860178674970356, 51.80789484296526, 54.810569286346436, 53.52908522742135, 55.34652900695801, 51.682504177093506, 51.93269491195679, 50.01472112110683, 42.49496718815395, 40.20926693507603, 43.145012855529785, 46.75515440532139, 50.51109348024641, 51.86236524581909, 52.29182297842843, 52.16190208707537, 54.80794286727905, 56.16329322542463, 51.760487283979145, 47.416536058698384, 47.599589824676514, 44.23169721875872, 42.668970925467356, 44.539346081869944, 48.44526202338082, 46.55881568363735, 36.15710530962263, 40.56779745646885, 49.84834997994559, 48.83822086879185, 42.17387703486851, 38.183964320591514, 40.011628900255474, 39.125358377184185, 38.35505676269531, 36.880683762686594, 36.30376788548061, 37.734231744493755, 38.15615068163191, 36.353933879307334, 46.75619663511004, 40.63758168901716, 37.370549133845735, 37.704767908368794, 38.89215251377651, 38.76438903808594, 41.288749490465435, 41.73312847954886, 41.956217765808105, 44.72081913266863, 35.97393342426845, 34.971537658146445, 33.59494318280901, 35.34455517360142, 40.80284111840384, 37.08788251876831, 36.13127538136074, 34.13089942932129, 35.7940410886492, 37.11573089872088, 35.67404222488403, 33.70751789637974, 37.552626677921836, 33.67237738200596, 37.36409078325544, 35.46254253387451, 36.83621529170445, 34.4140419960022, 37.74787105832781, 34.106876032693044, 33.77908781596592, 39.16097831726074, 37.21291535241263, 39.887092862810405, 41.56146281106131, 37.64436026981899, 35.44091279166085, 35.191448143550325, 35.56009871619088, 34.7129430770874, 33.59051023210798, 32.89855650493077, 36.6851475579398, 35.06717961175101, 35.0873259135655, 41.30871861321585, 35.87127379008702, 37.42875419344221, 36.44611215591431, 35.271206515175955, 37.47311496734619, 37.47473737171718, 39.72287218911307, 37.58354616165161, 37.00132533482143, 37.55925178527832, 40.10823665346418, 38.60450751440865, 48.4269118309021, 48.87109974452427, 50.69585302897862, 47.64661523274013, 49.0127283505031, 52.55353035245623, 52.24370322908674, 52.13954973220825, 51.05177797589983, 50.64049325670515, 50.42511994498116, 48.931694984436035, 50.39424215044294, 53.61725786754063, 51.409846442086355, 53.43280403954642, 51.71938174111502, 53.22224930354527, 52.33518321173531, 55.433298110961914, 53.07446806771414, 54.46321841648647, 50.73675012588501, 47.41868305206299, 44.93598052433559, 47.33001708984375, 53.40176296234131, 62.44333566938128, 58.152149064200266, 71.08499091012138, 22.928091287612915, 0.3903325077678476, 1.2605829004730498, 0.6318181540284837, 0.05376568656148655, 1.7964210276092802, 61.228950364249094, 61.65985679626465, 66.71907642909459, 54.07368155888149, 48.89103412628174, 25.11521918433053, 21.756763969148906, 37.66169255120413, 57.663600376674104, 43.46728767667498, 0.3765640551490443, 0.016006759833544493, 0.043525622825005224, 0.059457248475934775, 0.07540251607341425, 0.024583512019099932, 0.0400458577621196, 0.03663660945104701, 0.022183716862595508, 0.036157543371830664, 0.0015706430692392001, 0.28376600465604235, 35.23768840517317, 69.16446713038853, 41.24170323780605, 40.253245558057515, 21.39715995107378, 38.163505349840435, 50.648146697453086, 64.59469945090157, 55.2573002406529, 63.58757196153913, 6.30729284456798, 0.17454233126980917, 0.26358224770852495, 0.6694643082363265, 5.970787678446088, 59.83614921569824, 60.78197969709124, 59.63900102887835, 60.2448422568185, 53.452123505728586, 54.216786657060894, 53.14741373062134, 56.60609497342791, 56.651643889290945, 56.572639397212434, 53.708348751068115, 55.25950281960623, 53.277015004839214, 45.702707290649414, 43.603159700121196, 44.656798430851524, 47.764842305864605, 51.401185512542725, 52.54761743545532, 52.91415228162493, 53.850533212934224, 56.632143769945415, 56.620498589106965, 54.98825209481375, 50.52387121745518, 50.51346281596592, 48.34911979947771, 45.36734553745815, 46.20189714431763, 49.88433470044817, 49.1962684903826, 41.285612378801616, 44.454699652535574, 50.93553113937378, 50.16222790309361, 46.465386731284006, 41.24808515821184, 41.954716954912456, 39.171237332480295, 39.96590280532837, 38.679440362112864, 38.218500341687886, 38.07892492839268, 40.273232051304404, 37.65902096884591, 47.726161684308735, 41.75618955067226, 36.28029687064034, 38.34800781522478, 39.204446247645784, 39.041698592049734, 41.70149333136422, 41.14986889702933, 43.50394984654018, 45.37536028453282, 36.41103070122855, 35.54320069721767, 35.03355033057076, 36.25563423974173, 41.90022918156215, 38.52424887248448, 38.89888531821114, 36.62436124256679, 37.1284704208374, 39.64655664988926, 36.9692177091326, 35.35395956039429, 40.06481736046927, 36.3031599181039, 39.37711593082973, 38.20145641054426, 39.26989133017403, 35.88472897665841, 38.9743948663984, 36.042074407849995, 33.95873696463448, 39.84377779279436, 39.53260966709682, 40.46508918489729, 42.34796067646572, 36.367621830531526, 36.24658073697771, 36.09235157285418, 34.88302108219692, 34.92821911403111, 33.50234106608799, 33.543759277888704, 35.279877867017476, 34.09309775488717, 34.02457809448242, 43.10345220565796, 37.68764754704067, 38.25980043411255, 38.226292746407644, 36.9214905330113, 39.851677894592285, 38.76409721374512, 40.49948624202183, 38.7842504637582, 37.76912212371826, 40.962576729910715, 42.444849831717356, 39.88160726002285, 49.600584166390554, 50.38649838311331, 49.534468582698274, 48.90872771399361, 50.110561098371235, 53.16770941870553, 52.937268938337056, 53.01861844744001, 53.598636695316856, 51.63294962474278, 52.99382727486746, 51.93253510338919, 54.76448883329119, 55.75697646822248, 54.623568943568635, 54.450402464185444, 53.47808197566441, 55.43929788044521, 57.291774477277485, 58.91649954659598, 56.67342301777431, 56.91004392078945, 53.62291717529297, 51.86459214346749, 47.48366955348423, 49.81080191476004, 55.33326489584786, 65.94306686946324, 61.78813443865095, 71.8927537373134, 25.116832903453282, 0.319144711962768, 0.5027391346437591, 0.616389624774456, 0.09321553273392574, 2.0236719591276984, 68.91067028045654, 67.69650036948067, 71.13091155460903, 60.743243489946636, 56.64976440157209, 44.68181194577898, 30.969510759626115, 45.61793579374041, 65.59986754826137, 52.69785833358765, 0.3723541796207428, 0.06351533572056464, 0.08369964906679732, 0.028776324088019983, 0.04492329639781799, 0.12616233660706452, 0.16258285301072256, 0.20610509333865984, 0.15953191529427255, 0.14541848190128803, 0.15678642690181732, 0.5704112776688167, 47.31774309703282, 79.84798254285539, 52.970762729644775, 52.301751954214915, 40.426686491285054, 54.0637560571943, 54.28535842895508, 72.43529687608991, 60.464266368321006, 70.30905083247593, 6.784331406865801, 0.27985753438302446, 0.6676399175609861, 0.9735740955386842, 7.9930330855505805, 62.82802963256836, 62.39556680406843, 63.254384994506836, 61.47900908333914, 56.11947441101074, 55.46763610839844, 55.90580340794155, 58.911670548575266, 60.18433734348842, 60.29966354370117, 56.834114006587434, 56.975648811885286, 55.29376786095755, 47.643050806862966, 44.782651151929585, 45.5722096988133, 48.95720876966204, 52.925255502973286, 53.62797198976789, 53.915790694100515, 55.67551231384277, 59.2582814352853, 62.21375329153878, 57.943091664995464, 53.60007149832589, 53.94850281306675, 49.6633437701634, 47.205696446555, 48.6395023890904, 50.851259912763325, 52.22051361628941, 41.02951914923531, 42.78644411904471, 54.04977280752999, 52.240003313337056, 47.99830525262015, 42.07578584126064, 43.77715648923601, 40.56231532778059, 41.24054636274065, 39.85920974186489, 39.495096342904226, 40.730058738163535, 40.76185022081648, 39.206471647535054, 50.16903713771275, 41.83214725766863, 36.57871505192348, 37.359737736838206, 39.81798260552542, 40.63620941979544, 43.62508474077497, 42.64104611533028, 44.53894656045096, 46.35632085800171, 36.38984564372471, 35.65962471280779, 35.00812687192644, 38.21046822411673, 45.086596625191824, 42.32423257827759, 41.019214970724924, 37.81472315107073, 39.99555424281529, 43.11472565787179, 38.955638204302105, 37.34547308513096, 44.37776572363717, 39.14131491524832, 42.0098682812282, 42.73049027579171, 42.47430671964373, 37.68205772127424, 43.129233496529714, 36.72461680003575, 35.072331701006206, 41.88818447930472, 40.680948870522634, 42.48138345990862, 44.84051922389439, 38.44154446465628, 37.54229818071638, 35.85793324879238, 35.220439502171104, 35.600561550685335, 33.88915075574602, 33.08386148725237, 37.21749421528408, 34.1235864503043, 33.89742258616856, 45.61069229670933, 39.01499319076538, 41.13938059125628, 40.752595220293315, 39.35982881273542, 41.76761238915579, 41.22283887863159, 43.5618839263916, 41.68164232798985, 38.76560844693865, 41.62703990936279, 43.92471885681152, 40.84355408804757, 52.17359937940325, 52.76395307268415, 52.33653463636126, 52.31736108234951, 51.21408094678606, 56.33873176574707, 55.71505798612322, 54.18987280981881, 55.11304521560669, 54.55930852890015, 54.72045462472098, 52.396403789520264, 56.93594333103725, 58.65099498203823, 55.05988107408796, 55.8467367717198, 56.90979378564017, 58.67879472460066, 58.705871854509624, 60.832124846322195, 57.500460147857666, 61.40678950718471, 58.071918215070454, 54.19808210645403, 49.082721029009136, 52.88395193644932, 59.179634775434224, 69.03919110979352, 65.05152961186, 76.99787317003522, 26.313920668193273, 0.5426576212048531, 4.136457170758929, 1.6781016737222672, 0.4459454007446766, 2.527415922709874, 74.26504938943046, 73.97908932822091, 77.70346968514579, 69.02043792179653, 65.99808270590646, 38.08691535677229, 37.18138095310756, 57.16253103528704, 72.78782762799943, 66.15008844648088, 1.1915737177644457, 0.2091486757355077, 0.13599288410374097, 0.1658214328012296, 0.13430843449064664], [0.0314930561663849, 0.02801173216929393, 0.028195703368900076, 0.05812305185411658, 0.01264914040387209, 0.1268331498972007, 0.1480854230799845, 36.63704170499529, 62.6304715020316, 42.090957232883994, 32.74954891204834, 25.63005290712629, 45.1935259274074, 38.97797666277204, 65.930330821446, 48.84551995141165, 60.56446634020124, 6.986647316387721, 0.16242657282522746, 0.34710038187248365, 0.1586647339697395, 0.4195880065006869, 40.63072729110718, 65.19086878640312, 55.916194438934326, 58.273923192705425, 53.89886835643223, 53.29181119373867, 50.72187403270176, 53.64206641060965, 51.33202314376831, 52.46199131011963, 54.3204676764352, 54.77895498275757, 53.11615725925991, 51.22478117261614, 50.72077621732439, 52.12815121241978, 47.82186269760132, 46.8953412600926, 52.779346806662424, 53.183763231549946, 50.87352541514805, 48.95853934969221, 51.61680548531668, 49.67212976728167, 48.18891518456595, 47.1079352923802, 42.185518741607666, 42.566460677555625, 47.16862085887364, 48.15312501362392, 49.62957205091204, 38.14870221274239, 35.49912132535662, 48.69664090020316, 47.035840783800396, 45.21602419444493, 40.539674622671946, 40.11637299401419, 40.00481619153704, 39.22413396835327, 37.227586473737446, 37.92932326453072, 37.98641661235264, 38.172458103724885, 36.37915236609322, 38.38132790156773, 48.73709331239973, 41.986692564828054, 37.86575766972133, 37.55567693710327, 41.93135711124965, 42.26643746239798, 41.93606798989432, 43.3718124798366, 40.74411146981375, 40.08220870154244, 36.379454612731934, 36.955303941454204, 34.006505829947336, 38.49017143249512, 39.955289431980674, 34.80077525547573, 36.68279211861746, 35.03840364728655, 34.87484652655465, 36.69012246813093, 34.852970123291016, 37.47989640917097, 35.46407461166382, 36.90282767159598, 34.78237295150757, 35.77609389168875, 37.85761438097273, 34.95824228014265, 34.432767391204834, 37.851625033787315, 38.501000199999126, 40.67412921360561, 39.632076604025706, 37.49710709708077, 36.223120144435335, 34.628195898873464, 35.267510073525564, 36.1717277935573, 36.18638849258423, 33.9693329674857, 34.363455636160715, 33.28439692088536, 33.869480405535015, 43.4369136265346, 39.138521739414756, 34.97516809191023, 38.07542303630284, 35.405091353825156, 35.895231178828645, 35.51260083062308, 37.98980038506644, 37.64284208842686, 39.1858354977199, 37.23854030881609, 39.741305759974885, 39.28192908423287, 40.46465492248535, 48.3764887537275, 51.506283964429585, 48.672346523829866, 46.82414306913103, 45.979950836726594, 45.55412701198033, 49.49084084374564, 51.34941101074219, 51.81840399333409, 52.724098205566406, 50.273875032152446, 52.964683055877686, 54.21022408349173, 55.138552052634104, 54.66920471191406, 54.85504470552717, 55.0099652154105, 55.64836917604719, 55.086895670209614, 57.36072492599487, 54.381139346531455, 60.83877427237374, 59.32155173165457, 55.6370644569397, 49.47069106783186, 48.89143712180001, 52.960858072553364, 60.28755283355713, 57.79833289555141, 66.2627534866333, 27.48948117664882, 0.21281773171254567, 0.0999614464651261, 0.9228880724736622, 0.11185567679681949, 1.001011228987149, 56.4426976612636, 60.83361176082066, 65.97866249084473, 56.44096755981445, 50.87950086593628, 18.743814877101354, 10.353849445070539, 36.192902428763254, 52.510138852255686, 47.958109923771445, 0.5793736938919339, 0.09879466478845902, 0.0539552794237222, 0.04503335477784276, 0.06505200719194752, 0.03986683986814959, 0.03809899151591318, 0.06269343303782599, 0.0400840592836695, 0.012175292258949151, 0.17117852105626039, 0.3630351253918239, 43.49102619716099, 68.57340472085136, 48.912194865090505, 37.548982347760884, 26.081718819481985, 48.05702447891235, 44.118271350860596, 72.37433338165283, 53.391288552965435, 68.74726949419293, 7.099606786455427, 0.1760084011725017, 0.41652580510292736, 0.6460912195699555, 0.32112380862236023, 41.0658095904759, 67.88808304922921, 58.21055909565517, 60.32374600001744, 54.104917185647146, 55.67092302867344, 52.295106002262656, 55.190413406917024, 53.43089328493391, 55.90511553628104, 56.423148904527935, 56.764055320194785, 53.51738793509347, 52.58325127192906, 51.19754076004028, 51.25945963178362, 47.8852094241551, 47.871406827654155, 54.18053443091256, 55.023302282605854, 55.00900288990566, 51.694441182272776, 53.26098551068987, 51.918416363852366, 52.213402135031565, 48.29962778091431, 44.30848870958601, 44.65157338551113, 48.94312824521746, 51.61367532185146, 50.6459892817906, 38.14621475764683, 36.79592268807547, 51.8671212877546, 49.89889465059553, 45.88801922116961, 42.11276762826102, 43.21693365914481, 40.58016177586147, 39.47689206259591, 39.35740041732788, 39.235428265162874, 39.091298307691304, 40.468149866376606, 38.37693664005825, 39.48299258095877, 50.25444439479283, 42.9928994178772, 37.00922196252005, 37.66668830599104, 40.59024361201695, 42.49226781300136, 40.54568134035383, 43.818105697631836, 41.30731855119978, 40.72402422768729, 36.58629901068551, 37.03025068555559, 34.73673023496355, 41.02264043263027, 41.48140219279698, 38.1324052129473, 38.609673500061035, 36.630750111171174, 35.91806295939854, 38.29311009815761, 36.87574706758772, 39.17615665708269, 36.725019795554026, 40.40655408586775, 36.70987967082432, 38.04308612006051, 39.54005813598633, 36.93456356866019, 34.73736946923392, 38.11181770052229, 39.18089880262102, 40.682203020368306, 40.35033968516758, 38.04911368233817, 36.46580335072109, 35.035860606602256, 35.77134827205113, 35.62968839917864, 35.78575536182949, 34.090266363961355, 34.26537833895002, 32.51982062203543, 33.58763715199062, 44.785444327763145, 39.77730437687465, 35.15612350191389, 39.81421668188912, 36.56837613242013, 38.329470021384104, 37.186706747327534, 37.987886156354634, 40.00682422092983, 39.78590277263096, 38.45621906008039, 40.583604608263286, 41.4111385345459, 40.973937034606934, 50.32767840794155, 51.359312193734304, 51.37323290961129, 47.68342331477574, 46.78901645115444, 47.269970757620676, 49.57697071347918, 52.340734822409495, 54.565103326525005, 56.0554849760873, 51.91684259687151, 53.554414885384695, 55.59967967442104, 56.14567954199654, 55.610796792166575, 56.432640143803184, 56.43133388246809, 56.27760846274239, 56.43511717660086, 58.74150916508266, 57.390789781297954, 62.02276815686907, 60.46149403708321, 57.71820279530117, 52.51315089634487, 51.74766090938023, 54.30095018659319, 63.66803904942104, 60.295918464660645, 70.92789213997978, 30.720612389700754, 0.13932497959051812, 1.14956154354981, 1.0963389937366759, 0.07838017200785023, 1.1987832337617874, 62.71318285805838, 66.8919198172433, 71.24781499590192, 64.26908602033342, 55.92476504189627, 25.52114510536194, 18.119201353618077, 43.10510587692261, 58.418431827000205, 59.06894997188023, 1.0029552046741759, 0.13505319452711514, 0.05411557314385261, 0.03487700529928718, 0.03262446241985474, 0.16731701897723333, 0.18650442867406777, 0.2288293396787984, 0.1559980506343501, 0.05384788090097053, 0.3119187211351735, 0.5963286012411118, 56.93956681660244, 76.83237402779716, 56.411701747349326, 46.261484895433696, 36.52317115238735, 59.28501810346331, 52.284447465624126, 76.75463758196149, 60.297787530081614, 75.78034727913993, 9.118154883384705, 0.3482310383447579, 1.2648544141224451, 0.6409249625035695, 0.4766278586217335, 45.76731858934675, 69.47452354431152, 60.87345967973982, 61.4941839490618, 57.160804407937185, 58.62703759329659, 55.62041309901646, 58.30326543535505, 56.56791114807129, 58.25883865356445, 59.60362080165318, 58.20968362263271, 55.43256507601057, 51.70023945399693, 50.914912360055105, 50.777751445770264, 48.10636363710676, 48.02280460085188, 55.02243028368269, 58.106568881443565, 57.03898859024048, 54.031898566654746, 56.391419955662315, 55.842831884111675, 52.8602933202471, 49.76216799872262, 47.074163573128835, 47.538723605019705, 52.74536664145333, 53.124352659497944, 52.147071157182964, 42.14012963431222, 40.732657364436555, 53.10331351416451, 52.71919625146048, 47.82424245561872, 45.1709303855896, 44.27107613427298, 42.94389377321516, 42.25654322760445, 40.830085005079, 40.812276772090364, 40.87079797472273, 42.720102718898225, 38.93326847893851, 42.80595466068813, 52.16466399601528, 44.26629229954311, 37.5293675831386, 37.0434696333749, 41.598837171282085, 43.946286065237864, 40.7914252281189, 44.05419506345476, 42.415948799678254, 41.27700008664812, 37.940113816942485, 37.78241055352347, 35.154386452266145, 42.86120326178414, 44.63895893096924, 39.83123976843697, 40.26823629651751, 40.34234925678798, 39.136617933000835, 41.085688386644634, 40.60160391671317, 42.6380375453404, 39.95347595214844, 42.98199769428798, 38.07178912843977, 41.436544622693745, 42.419283935001914, 37.86121702194214, 36.74946008409773, 39.01097713197981, 40.462942191532676, 41.66490411758423, 41.53474003928048, 38.62565088272095, 37.38030440466744, 36.22039992468697, 35.78995902197701, 36.744672775268555, 34.84879078183855, 33.30907344818115, 33.66262558528355, 32.33722196306501, 34.130277565547395, 46.25242791857038, 42.004615443093435, 38.14557204927717, 42.26912294115339, 37.90939235687256, 39.74565880639212, 40.48922722680228, 42.914836406707764, 41.30029739652361, 42.8958990914481, 39.84876659938267, 42.648741245269775, 43.2024119240897, 43.00141096115112, 53.396246092660085, 53.77372782570975, 52.39523996625628, 48.49763407026018, 49.09148965563093, 48.63997834069388, 51.664650780814036, 55.29063074929373, 56.087620394570486, 57.5148846081325, 55.262462752205984, 56.03069380351475, 57.74834755488804, 58.097438948495046, 57.16003315789359, 60.39456898825509, 58.55064214978899, 58.978324617658345, 60.46044485909598, 61.24254104069301, 61.195077896118164, 64.67520822797502, 63.24583176204136, 60.9172055380685, 54.885053975241526, 55.24968154089791, 57.774041993277415, 65.96435614994594, 63.84251526423863, 71.9085886819022, 33.221949986049104, 0.3967785904450076, 2.5792171316487447, 2.6194259226322174, 0.2407259584537574, 1.4382587607417787, 68.91317163194928, 71.16909885406494, 76.41350187574113, 70.18247549874442, 65.11405645098004, 25.131134033203125, 21.122860704149517, 53.52332517078945, 65.48633398328508, 72.33906432560512, 2.689351507595607, 0.47733603204999653, 0.2074431643954345, 0.26883953703301294, 0.12277969026139804], [0.0622805580496788, 0.026765594125858376, 0.09961894912911312, 0.03467776027641126, 0.023554961496431912, 0.06499897968024015, 0.11114605130361659, 39.70335469927107, 60.251053946358816, 40.55627734320504, 48.644710063934326, 25.783507347106934, 32.339591298784526, 44.90695789882115, 62.61273275102888, 50.01873023169381, 60.65029048919678, 9.3565171786717, 0.12540810422173568, 0.1871715100216014, 1.2974189924342292, 0.6354028273906026, 14.586382831845965, 66.41509274074009, 57.15684046064104, 62.98767144339425, 54.23648132596697, 53.73616933822632, 51.8124806540353, 55.52357605525425, 50.93206398827689, 54.73607417515346, 52.195309025900706, 55.083362511226106, 53.25325563975743, 54.30575834001814, 50.11894062587193, 50.17989369801113, 52.07812418256487, 56.54197352273123, 50.18205458777291, 51.72320325034005, 48.56438888822283, 48.525788170950754, 45.240127495356965, 45.32889420645577, 42.188353606632774, 43.91958066395351, 44.103530747549875, 47.01647615432739, 45.03623955590384, 50.83465371813093, 48.471001625061035, 51.62106473105294, 48.937184061322895, 44.99393197468349, 45.087850775037495, 46.36149379185268, 50.13216304779053, 45.363103662218364, 44.66424689974104, 38.85371855327061, 36.804416860852925, 39.93855816977364, 37.52170024599348, 38.41321665900094, 36.114474637167795, 34.31382465362549, 43.23218495505196, 48.13760968617031, 38.36499616077968, 38.13827991485596, 37.38793005262102, 44.28853695733206, 43.36465930938721, 42.34991659436907, 45.21596166065761, 45.2507825578962, 39.36129488263811, 35.33586992536272, 35.45596258980887, 38.44884007317679, 38.45457928521292, 36.03577586582729, 36.64953804016113, 36.904394490378245, 36.770902224949424, 37.16922855377197, 33.66206625529698, 35.31777334213257, 37.18324654442923, 37.97088738850185, 35.37159408841814, 36.92413779667446, 35.99819653374808, 34.21018532344273, 34.499327659606934, 38.06445530482701, 40.25974212374006, 39.24613543919155, 37.58860445022583, 34.71029233932495, 34.45683595112392, 36.15678916658674, 37.31513377598354, 33.576784065791536, 35.79831770488194, 34.55017805099487, 33.754300117492676, 31.663434301103862, 41.80262783595494, 44.56773294721331, 36.68716253553118, 35.625953742435996, 34.60199424198696, 34.94941806793213, 36.05905927930559, 35.760807854788645, 36.55091183526175, 36.78011206218174, 36.42959976196289, 38.19649887084961, 38.61422457013811, 38.6018602507455, 38.27013240541731, 44.184154169900076, 46.6908175604684, 49.31138277053833, 51.57078409194946, 48.86420365742275, 50.43253019877842, 48.795176778520855, 49.68318435123989, 53.575165680476594, 51.01938894816807, 53.6111295563834, 55.007300581250874, 50.99140855244228, 53.679638794490266, 53.46196215493338, 54.671994413648335, 51.9993246623448, 56.435780729566304, 53.85867302758353, 57.63587359019688, 53.09551068714687, 76.0296277999878, 71.12657587868827, 56.079310349055696, 57.47678068705967, 50.90026903152466, 53.16718135561262, 59.803951263427734, 59.46373271942139, 68.39880343845913, 30.49671711240496, 0.19643915843750748, 0.1352066927190338, 0.5366678940398353, 0.0879246559260147, 0.9551584380013602, 54.462287357875276, 64.64856883457729, 64.44761998312813, 60.45898573739188, 47.59449332101004, 65.58474131992885, 21.970266478402273, 32.33402231761387, 50.86047669819423, 58.94619614737374, 1.6716194386993135, 0.25532349944114685, 0.07212282384612731, 0.08882378267922572, 0.05097310105338693, 0.06559841108641454, 0.007188509401333119, 0.14290988365454332, 0.0059776640846394, 0.017667944177186916, 0.044921851118228266, 0.5604238393051284, 49.19914504459926, 67.39974280766079, 47.34448323931013, 56.00997427531651, 29.12808006150382, 41.31678547177996, 50.73462397711617, 68.70918641771588, 54.8562502179827, 69.74394689287458, 9.798546808106558, 0.07115786562540702, 0.3472914301923343, 2.8121305193219865, 0.9458156079053879, 14.510955793516976, 68.8670494897025, 58.17182983670916, 65.11099229540143, 54.53094250815255, 56.52115324565342, 53.82078102656773, 57.42374856131417, 53.67361123221261, 56.94961738586426, 55.65536253792899, 56.23247643879482, 54.06059462683541, 55.91568374633789, 49.03942332948957, 52.339491094861714, 53.30580139160156, 57.16522346224104, 52.15986279078892, 53.86135850633894, 50.19910199301583, 51.251910414014546, 46.66747856140137, 47.69299793243408, 44.239308970315115, 46.35068586894444, 45.70635856900896, 49.11239331109183, 48.83804716382708, 53.88184526988438, 49.44999933242798, 52.61779424122402, 50.45797102791922, 46.63715314865112, 48.249854360307964, 49.75062009266445, 49.03343745640346, 47.0752648626055, 45.43932887486049, 41.73998287745884, 39.31346000943865, 40.942868164607454, 40.1850767816816, 39.60653155190604, 37.69234800338745, 37.582750592912944, 45.12053162711007, 51.25300475529262, 39.40617329733712, 38.268433570861816, 37.05314152581351, 44.054615429469514, 44.20768771852766, 43.403725555964876, 44.56442560468401, 45.086940561022075, 40.490821838378906, 36.43845871516636, 35.0324455669948, 38.38540996823992, 39.8301489012582, 37.056535720825195, 38.71338926042829, 39.21974270684378, 38.91557489122663, 39.05400037765503, 36.281877585819785, 38.14883770261492, 39.7313038281032, 39.22193833759853, 37.73466600690569, 40.21184124265398, 36.82435124261038, 34.5623790877206, 35.75737197058541, 38.90811947413853, 42.080531460898264, 40.33634948730469, 36.83860547201974, 36.24149465560913, 34.719880853380474, 34.53951951435634, 35.42281968252999, 33.373149735586985, 34.851066316877095, 33.66430010114397, 33.569905349186485, 31.740083353860037, 41.799393449510845, 45.362384523664204, 37.62493658065796, 37.49057579040527, 36.284236499241416, 36.22659771783011, 37.56922245025635, 40.19688524518694, 36.888667242867605, 37.739720821380615, 39.17585093634469, 39.52623469488961, 40.34544120516096, 39.92181995936802, 40.82498502731323, 46.4208904675075, 50.57875503812517, 50.725983892168315, 53.50724703924996, 50.25288452420916, 51.03872231074742, 49.59638050624302, 52.44575684411185, 52.99302475793021, 53.15758241925921, 54.64632429395403, 55.78840317044939, 52.2197527885437, 55.29751293999808, 55.73332827431815, 55.78411613191877, 55.44954299926758, 58.111456939152305, 55.78146539415632, 56.32462344850813, 55.019143785749165, 70.97732857295445, 69.41862528664726, 60.319028173174175, 60.44564519609724, 53.94769334793091, 54.07711396898542, 62.89544105529785, 61.51003973824637, 71.38100501469204, 34.593434061322895, 0.2539619510727269, 1.5990368191684996, 0.39767973923257416, 0.09661632989134107, 0.8608589523604938, 60.20004722050258, 70.04516519818986, 69.90907083238874, 67.16782583509172, 53.870658670152935, 45.71208735874721, 19.59941952569144, 39.50570624215262, 56.762863704136436, 69.05576256343296, 3.862254330090114, 0.35690586428557125, 0.0755780055852873, 0.05118275819612401, 0.038675400228904824, 0.1408810368073838, 0.17294697330466338, 0.20282346728656972, 0.12162459295775209, 0.09295718052557536, 0.09103857526289565, 0.7547331441726003, 60.163319042750764, 74.42090443202427, 55.098342827388215, 62.25508117675781, 35.63353075299944, 46.34654474258423, 58.56894370487758, 73.1017541885376, 60.37783077784947, 74.1207492010934, 11.568024567195348, 0.1821288684649127, 0.8396305771810668, 4.646325971399035, 1.2740917184523173, 18.01487241472517, 71.13945089067731, 60.74070044926235, 68.07640007564, 57.36375434058053, 60.954941204616, 55.318305424281526, 59.93163136073521, 55.145121574401855, 59.87002168382917, 56.506416116442, 58.83872141156878, 55.73637853349958, 57.80889763150896, 51.99236604145595, 53.04336445672171, 53.934029715401785, 60.191952569144114, 53.95050736836025, 57.22414766039167, 52.56216696330479, 52.53376620156424, 48.73274374008179, 51.3420216015407, 46.84971938814436, 48.87276383808681, 48.547331060682026, 50.859840938023154, 50.970289502825054, 55.813986437661306, 52.105552196502686, 54.36729506083897, 52.49097572054182, 48.772657666887554, 51.246258054460796, 52.20432778767177, 50.0444872038705, 49.55498661313738, 49.80515650340489, 43.36710507529122, 40.025855336870464, 43.75207349232265, 42.44532925742013, 42.51984173910958, 38.197756494794575, 38.14361265727452, 48.2818786076137, 53.794092995779856, 39.0930631501334, 37.334731170109336, 37.43579271861485, 44.65719795227051, 44.87784842082432, 44.28532688958304, 46.57017946243286, 46.23326826095581, 40.39791400091988, 35.83425726209368, 35.86834512438093, 39.6521430015564, 43.0016576222011, 40.228926862989155, 41.41418531962803, 42.637686661311555, 39.94877896990095, 41.55330562591553, 38.01187481198992, 40.3823048727853, 41.96337441035679, 41.733517578669954, 41.16568299702236, 41.2697183745248, 38.45616347449166, 35.175217151641846, 36.87392316545759, 40.79873125893729, 43.05528034482683, 41.24816158839634, 37.39306129728045, 34.88393129621233, 34.324900082179475, 35.596559388296946, 37.068462303706575, 33.07137557438442, 36.14594997678484, 35.486221994672505, 34.13610710416521, 31.335486275809153, 43.55343839100429, 47.852841241019114, 40.03644439152309, 41.05436243329729, 37.543462003980366, 38.256434031895225, 40.950149876730784, 40.892240115574424, 38.428023270198274, 38.48462677001953, 39.27675267628261, 41.5196659224374, 42.460764680589946, 42.72171122687203, 42.45489345278059, 48.86196633747646, 52.76705544335501, 51.84440415246146, 56.04429490225655, 52.810241971697124, 52.37601777485439, 51.624028137751985, 53.93902894428798, 56.14636393955776, 54.318313734872, 57.35084458759853, 59.68685327257429, 54.789377280644004, 56.38478790010725, 57.790325096675325, 57.62902266638619, 55.81487928118025, 59.24380138942173, 57.74210112435477, 58.261781215667725, 56.76378781454903, 72.05602250780377, 71.51780114855084, 62.889319692339214, 63.874421392168315, 57.05068588256836, 57.909649985177175, 66.85584477015904, 65.71478380475725, 74.65258516584123, 38.5559013911656, 0.5313970340149743, 3.8217363442693437, 1.3362921008041926, 0.4037192980093615, 1.4862723329237528, 65.08991146087646, 76.12525585719517, 76.56582723345075, 72.72063159942627, 64.58454813276018, 85.05641474042619, 33.07278953279768, 50.05361366271973, 65.38269465310233, 80.65779508863176, 6.97579379592623, 0.5667750356452805, 0.2643514350056648, 0.13471835106611252, 0.14687509302582058], [0.040418091895324845, 0.040121534772749455, 0.03516473128859486, 0.027923232543149164, 0.04513991191717131, 0.094158621770995, 0.1888100906674351, 32.957425117492676, 59.88261876787458, 34.69648279462542, 35.5987411226545, 27.139423983437673, 36.02186557224819, 39.90015547616141, 65.1266257422311, 49.55278403418404, 63.236778259277344, 11.212293301309858, 0.04330240176724536, 0.22491998731025628, 1.303030748452459, 2.2739252277782986, 1.106550457222121, 54.65988022940499, 62.062178339277, 59.027219091142925, 53.2506604875837, 56.83412095478603, 51.37831899097988, 55.0283327783857, 53.29591757910592, 55.481595039367676, 53.76639747619629, 55.52107122966221, 48.4138457434518, 50.39245646340506, 46.593000820704866, 52.117197377341135, 52.13587760925293, 51.17120361328125, 49.886936800820486, 49.629481724330354, 46.357630593436106, 44.26817178726196, 44.07456718172346, 48.496650900159565, 46.068953786577495, 46.73890256881714, 45.97385031836373, 49.312793254852295, 51.78497968401228, 51.126943588256836, 45.85572052001953, 44.2583018711635, 47.18849965504238, 46.38474246433803, 46.294051102229524, 44.25234031677246, 57.11477606637137, 55.4709712437221, 47.67741659709385, 46.601258754730225, 35.6887480872018, 39.05881200517927, 37.53780617032732, 37.33690595626831, 36.75899996076311, 36.2121558870588, 37.1582920891898, 44.94339772633144, 45.696749210357666, 39.883722986493794, 41.22756017957415, 51.33350658416748, 46.56432213102068, 44.15352998461042, 44.57271480560303, 43.84070471354893, 42.66015018735613, 39.8253789629255, 34.52560574667794, 35.173313345227925, 38.671036515917095, 37.92976100104195, 35.435430662972585, 37.38964973177229, 34.79232277188982, 37.86331190381731, 36.43325104032244, 37.2731944492885, 37.19398498535156, 36.91093969345093, 36.3672570501055, 40.22071409225464, 32.93856423241751, 34.44590643474034, 35.19993884222848, 38.43655218396868, 39.80928693498884, 39.766364438193186, 35.36826590129307, 37.825378213609966, 36.1472110748291, 35.85098157610212, 40.09288460867745, 35.886657101767405, 31.957919801984513, 32.47649165562221, 32.64426285879952, 38.827370984213694, 45.7876490184239, 39.443429538181846, 32.67821870531355, 36.869990485055105, 35.620294434683665, 36.462582860674175, 35.020904609135215, 37.78825398853847, 36.91190896715437, 38.41623912538801, 39.197852407182964, 46.087665285382954, 44.396070752825054, 46.78314174924578, 39.17608717509678, 40.302577768053325, 45.025911058698384, 45.08835799353463, 48.26418154580252, 49.969043663569856, 47.70918723515102, 49.524018492017476, 47.52937480381557, 50.41779654366629, 50.71342849731445, 53.20838417325701, 55.606422901153564, 53.93751771109444, 50.56586265563965, 55.10829612186977, 54.55283628191267, 56.020184653145925, 50.68593794958932, 55.62179579053606, 54.21623774937221, 55.08564152036394, 55.97117900848389, 54.663701738630024, 62.812590735299246, 59.201424326215474, 55.011038712092805, 47.712362561907085, 59.96832479749407, 59.10020991734096, 67.23662689753941, 33.2037422316415, 0.04656411281653813, 0.8487573617271015, 0.3609828012330191, 0.036912569643131325, 0.47102201942886623, 45.43506268092564, 65.667633329119, 62.01651477813721, 64.19027955191476, 43.905468872615266, 32.8016152381897, 18.59125154359, 37.419554778507774, 47.7879832812718, 65.30591011047363, 5.523783138820103, 0.5099699294992855, 0.08176184126308986, 0.044027382507920265, 0.043469633507941446, 0.051006003216441186, 0.037508343745555194, 0.007214057092954005, 0.057870433266673765, 0.06100913270243576, 0.02392657137742, 0.2980942486652306, 41.41877113069807, 66.5585105078561, 42.876968724387034, 43.525159222739084, 31.066045556749614, 42.307602064950125, 46.494833196912495, 70.23223154885429, 53.36967270714896, 72.35288429260254, 12.14186065537589, 0.07544573196875197, 0.7147313877940178, 4.226877987384796, 4.808421799114772, 0.3347247445157596, 59.5383494240897, 60.942490032741, 61.717408725193565, 54.37428494862148, 60.96479375021798, 53.07244961602347, 58.584174156188965, 53.15671042033604, 58.58580003465925, 54.33198431559971, 58.16630254473005, 51.49733121054513, 52.03620570046561, 47.5791586467198, 54.60507978711809, 53.59593384606497, 51.85747718811035, 50.78028059005737, 51.19235045569283, 47.53615624564034, 46.07213953563145, 45.707140241350444, 49.61810057503836, 48.28476211002895, 48.15017897742135, 47.131892681121826, 51.4203451701573, 51.97299793788365, 54.06592389515468, 46.722786222185405, 45.900063923427034, 48.42925337382725, 48.36589275087629, 48.20026854106358, 47.865764890398296, 56.80955212456839, 55.48348147528512, 51.508059229169575, 47.73730312074934, 36.52027027947562, 41.463684286390034, 36.96336037772042, 39.301140853336875, 38.051170349121094, 37.88464982169015, 39.85157367161342, 47.1845635005406, 46.76448236192976, 40.1483416557312, 42.28006635393415, 51.59751033782959, 47.17390496390206, 45.0304343359811, 45.75477014269148, 44.93098129544939, 43.989100864955354, 40.10319920948574, 35.07104628426688, 35.766998699733186, 40.679739883967805, 39.398325307028635, 37.51994582584926, 40.742965017046245, 36.126290048871724, 39.49910197939192, 38.824532645089285, 39.001121112278526, 38.601158482687815, 40.02602556773594, 39.44353723526001, 40.045536109379356, 33.33784246444702, 35.48417227608817, 33.66138880593436, 37.65534537179129, 39.22966473443167, 40.70098400115967, 37.063720158168245, 38.06133903775896, 36.46349654878889, 36.4502671786717, 41.09231349400112, 34.99212864467076, 31.977426869528635, 32.959645066942485, 33.7598100389753, 38.64228139604841, 46.89775228500366, 41.34550585065569, 35.38424675805228, 37.99412216459002, 38.19491468157087, 37.675019196101594, 37.509158747536794, 38.455440861838206, 36.82332638331822, 40.92926706586565, 41.05285814830235, 47.43446935926165, 48.29279770169939, 48.07895646776472, 41.185308183942524, 43.818498270852224, 47.38342094421387, 48.32746226446969, 50.94031844820295, 51.971556186676025, 49.835124083927695, 51.25095156260899, 49.700707708086284, 50.99871110916138, 53.217548847198486, 54.73717199053083, 56.50671141488211, 56.08552203859602, 52.008583136967246, 56.28794738224575, 55.93678889955793, 58.98518248966762, 54.20496777125767, 56.12789910180228, 55.04023156847273, 55.65315648487636, 56.53071049281529, 55.82142448425293, 63.9729676927839, 64.03586278642926, 57.12193271092006, 50.9236010823931, 61.150220326014924, 62.22326537540981, 70.41833904811314, 35.88893263680594, 0.0996980798829879, 1.4577119797468185, 0.6225931718945503, 0.11875312775373459, 0.5652146222335952, 49.51003871645246, 73.10876492091587, 67.36234065464565, 70.74935817718506, 49.746885435921804, 47.36726985658918, 30.229913234710693, 48.26367780140468, 54.101606369018555, 74.81836223602295, 7.988262278693063, 0.804539894419057, 0.10867883012230907, 0.12239710507648331, 0.035697788399245055, 0.09808549391371862, 0.1799862448658262, 0.12660760485700198, 0.12150031248373644, 0.23057453174676212, 0.11285595276526042, 0.8364360885960715, 51.487152099609375, 75.41696344103131, 48.917725631168906, 45.56650870186942, 36.06012235369001, 51.40356527056013, 54.52028744561331, 77.97666590554374, 57.331295830862864, 79.36845956529889, 14.13932010105678, 0.16771716464843067, 2.866177950586591, 8.374159148761205, 4.913923680782318, 1.523458440388952, 65.09572710309709, 61.58716474260603, 64.61334146772111, 57.2074476650783, 62.959552083696636, 55.28322049549648, 59.21743297576904, 56.96807874952044, 60.35100378308977, 56.4912759917123, 60.14350972856794, 50.17910507747105, 53.042819023132324, 49.132980823516846, 54.63081244059971, 54.796203885759624, 56.5632905960083, 52.900644983564106, 53.821420260838096, 50.48310266222273, 49.172460487910676, 47.28014986855643, 53.27179690769741, 50.1430196080889, 50.69136449268886, 50.16115093231201, 55.46725048337664, 54.93421248027256, 57.30562571116856, 47.89628137860979, 49.8701673235212, 50.14244985580444, 51.24623373576573, 49.88604048320225, 51.312679358891074, 58.387630462646484, 55.85951450892857, 54.6921580859593, 49.685008253370015, 37.672740186963765, 42.9726801599775, 40.0716370173863, 40.61098051071167, 40.11516400745937, 39.67490530014038, 41.71452815192086, 48.91017293930054, 48.76422602789742, 41.584013189588276, 43.5704163142613, 54.79584257943289, 49.26742499215262, 46.5637662751334, 47.682186535426546, 45.76075948987688, 44.47311585290091, 40.57949474879673, 34.814362457820344, 36.76126159940447, 43.94229432514736, 40.93512092317854, 39.57692180361067, 41.98426069532122, 39.446191447121755, 43.13750185285296, 41.469652788979666, 41.306241580418174, 41.8468461717878, 44.06140729359218, 41.03258677891323, 44.79221882138933, 34.42083386012486, 36.30580023356846, 35.75623941421509, 39.222963196890696, 42.435379437037874, 40.255312647138325, 37.11620685032436, 39.112135955265586, 36.451034954616, 36.89822449002947, 43.47267600468227, 37.030747481754844, 32.57519081660679, 33.69785990033831, 33.548411096845356, 40.16030992780413, 48.87583146776472, 44.86602258682251, 36.95241001674107, 39.430568422589985, 38.969058649880544, 40.78563737869263, 39.908455099378315, 40.560057163238525, 38.1822863306318, 41.37240580150059, 43.34015301295689, 49.18829543249947, 49.24337727682931, 51.925781454358784, 42.96875442777361, 46.46311467034476, 48.96923957552229, 50.188731806618826, 51.374320302690776, 54.61971616744995, 51.42378452845982, 53.70368650981358, 51.613748277936665, 53.85373633248465, 54.29706266948155, 57.56489426749093, 58.58063057490757, 55.58352858679635, 55.28390141895839, 56.75050980704171, 58.39280687059675, 59.30928121294294, 55.7044689314706, 57.77832555770874, 57.7560670035226, 55.89697572163173, 59.56805297306606, 61.98991707393101, 65.56768349238804, 66.84252507346017, 60.745883805411204, 53.397350856236045, 63.910447801862446, 65.35487406594413, 71.96036665780204, 39.42980064664568, 0.4954856495772089, 4.884426840714045, 2.806475119931357, 0.17509818715708597, 1.0414735206535883, 55.85801369803292, 78.03038242885044, 75.57964856284005, 76.78559875488281, 62.17441953931536, 47.54878112248012, 29.229813848223003, 52.68623399734497, 61.33648068564278, 89.0420195715768, 12.666985528809683, 0.7763914934226445, 0.22614885494112968, 0.2195623969393117, 0.16831096421395028], [0.06499074905046395, 0.04718387991722141, 0.018303485520716225, 0.034232872006084235, 0.07981182661439691, 0.03497731313109398, 0.29372559594256537, 32.35123300552368, 62.40167427062988, 36.44897828783308, 40.695321219308035, 26.88834387915475, 41.90424176624843, 42.270324979509624, 61.97167110443115, 51.382567814418245, 62.447115489414756, 15.706455026354108, 0.2847496090190751, 0.3559207671454975, 1.2658728680440356, 1.394338220357895, 0.2941601840513093, 16.924072980880737, 67.6483701978411, 66.55268791743687, 56.98711681365967, 55.051463331495015, 55.15557166508266, 53.497133936200825, 54.69383260181972, 53.74675839287894, 55.07802629470825, 53.11519840785435, 53.963177408490864, 53.09887361526489, 54.36569350106375, 52.82057394300188, 51.44011626924787, 51.96512215478079, 47.58981718335833, 43.83552483149937, 45.392689091818674, 46.57980966567993, 47.171559946877615, 53.99587563105992, 49.14788123539516, 49.177734170641216, 48.471960476466585, 49.119351931980674, 49.48963533129011, 49.39405243737357, 46.04486438206264, 51.36798701967512, 49.43909413473946, 45.25522245679583, 46.453025885990684, 46.03255564825875, 53.76616471154349, 53.35982016154698, 49.17316920416695, 48.67236736842564, 37.537611620766775, 36.84917368207659, 35.481031690325054, 38.66917439869472, 36.72336612428938, 37.24823651994978, 34.41312830788748, 38.831717082432334, 47.0891821043832, 42.25358329500471, 39.9242969921657, 42.48334632601057, 42.966784613473074, 47.92047848020281, 43.32944583892822, 42.40435573032924, 48.386191913059776, 44.310750348227366, 38.39038140433175, 35.84245613643101, 38.97251190458025, 39.89028556006295, 36.25412648064749, 37.107601506369456, 38.08804096494402, 38.71409797668457, 37.303099496024, 38.487183707101, 37.33437333788191, 35.326792103903635, 39.20245211465018, 36.87241888046265, 34.32101951326643, 35.179750851222444, 35.4971376146589, 37.63472311837332, 39.421650409698486, 38.75461292266846, 37.45613704408918, 38.44325372150966, 38.20424958637783, 39.90138530731201, 41.01260723386492, 36.20435653414045, 31.797423362731934, 33.571861267089844, 36.28959008625576, 44.52289622170584, 42.65407746178763, 35.08557496752058, 34.82278367451259, 37.53360251017979, 35.9712792124067, 35.42179134913853, 36.237065179007395, 36.484295981270925, 36.13024704796927, 39.58091354370117, 47.647834641592844, 49.183556761060444, 48.7722407749721, 52.02941383634295, 46.311320849827354, 47.420576436179026, 43.583333015441895, 47.16118628638131, 50.64028481074742, 50.32698358808245, 49.24759830747332, 52.81100974764143, 50.579852853502544, 51.04662241254534, 47.698143073490684, 52.20213910511562, 43.581884316035676, 39.09101690564837, 57.728583403996055, 51.88287285396031, 52.66999953133719, 53.660110882350374, 55.7946982383728, 55.94837154660906, 51.03546360560826, 53.96772500446865, 43.83051865441458, 43.003752504076274, 56.00681979315621, 57.2340418951852, 59.034500803266255, 49.028875964028494, 58.03178194590977, 57.99742310387747, 68.30801132747105, 32.197104590279714, 0.2009244513298784, 0.40027502711330143, 0.4850640030843871, 0.12940128280648164, 0.7033803111740521, 49.90363679613386, 64.09090641566685, 64.06657382420131, 61.14152812957764, 48.749652181352886, 28.6086414200919, 7.541904790060861, 24.51858605657305, 43.43664264678955, 65.30619498661586, 8.94871003287179, 0.58644109751497, 0.03039087102349315, 0.17425083262579782, 0.013439508171619048, 0.055732345674186945, 0.03945521338443671, 0.025150322854252796, 0.01652259742175894, 0.039674682143543444, 0.07087414977805954, 0.41069268382021357, 41.90477677753994, 67.83258083888462, 42.03903681891305, 38.014014857155935, 33.73232296534947, 49.192415714263916, 47.81302111489432, 69.64379555838448, 56.23106942858015, 68.867125919887, 17.79153299331665, 0.42551590555480545, 0.6091800544943128, 1.8803175943238395, 3.424658954143524, 0.6029481174690383, 16.403951678957256, 70.34568868364606, 65.12296404157365, 58.68174770900181, 55.177576610020225, 57.71467311041695, 53.48432493209839, 59.230057852608816, 54.38511371612549, 56.60305513654436, 54.70295558656965, 56.045403139931814, 54.66278110231672, 54.44604941776821, 55.961649554116384, 53.50012166159493, 54.26401356288365, 49.133425508226665, 46.62546280452183, 47.3621803011213, 49.39071730204991, 49.35204015459333, 56.53162418093, 52.321578638894216, 49.86413976124355, 50.608837263924734, 49.872957025255474, 52.420250007084434, 50.79081058502197, 48.53631121771676, 51.196710450308665, 51.0046101297651, 45.85487283979143, 49.02873352595738, 46.05740935461861, 56.34582587650844, 55.51202814919608, 50.55741712025234, 51.92798055921282, 39.54942083358765, 37.57830374581473, 37.78253909519741, 39.46327359335763, 39.006078651973176, 39.61205884388515, 36.56167459487915, 41.298782689230784, 49.097555433000835, 43.99892214366368, 39.777432918548584, 42.93901266370501, 43.543443407331196, 47.64947441646031, 44.40011807850429, 45.738559995378765, 48.72036552429199, 45.1823011125837, 37.75240823200771, 35.99240868432181, 40.71433843885149, 41.38198389325823, 38.88798706872122, 39.45779841286795, 39.60324852807181, 40.19290392739432, 38.0641565322876, 40.56798505783081, 38.59864323479788, 38.362845693315776, 42.868926184517996, 38.10053730010986, 34.73590339933123, 34.43819046020508, 35.49750239508492, 38.16443640845162, 39.290843623025076, 39.63487325395857, 37.55239738736834, 38.744590146201, 38.10985483442034, 38.7865503174918, 41.83405801228115, 36.075703689030235, 31.814300537109375, 32.71832718167986, 36.56052814211164, 46.44733878544399, 43.97045884813581, 37.38134316035679, 36.438667161124094, 39.818312644958496, 38.024169649396626, 36.221782616206575, 38.25250482559204, 37.733512605939595, 37.03355802808489, 41.70765290941511, 47.18042932237898, 51.699412618364605, 50.18572671072823, 51.769756180899485, 48.50558280944824, 50.12421778270176, 45.89418574741909, 48.804508209228516, 51.872092723846436, 52.89429085595267, 51.62514679772513, 53.440030166081016, 53.918156555720735, 53.10843781062535, 49.396102155957905, 55.20592873437064, 47.919804504939485, 40.327532223292756, 58.91371331896101, 53.47753306797573, 55.96924046107701, 54.33746991838728, 56.99894959586007, 56.623792035239084, 53.01102406638009, 53.665523529052734, 47.43693944386074, 44.611874852861675, 59.02557931627546, 62.80389159066336, 60.34463923318045, 52.40369244984218, 63.04992730276925, 60.87858050210135, 70.79684216635567, 34.916949135916575, 0.2263301866395133, 0.934806512934821, 1.2027542378221239, 0.026714785423661982, 0.8539290470736367, 55.947072233472554, 69.28389971596854, 70.01089668273926, 66.59563473292759, 53.761429514203755, 32.882450580596924, 15.321422338485718, 32.069778851100374, 49.402987820761545, 77.10397911071777, 11.82954694543566, 0.7600847770060811, 0.12499438785016537, 0.15427248179912567, 0.016478290781378746, 0.16482850536704063, 0.08823374219770942, 0.0941634461549776, 0.1264911682478019, 0.15483923495880195, 0.265375371490206, 0.5724290236830711, 54.21932274954659, 76.75715977805001, 52.09969139099121, 53.30059371675764, 37.31873641695295, 54.27122926712036, 55.6138505254473, 73.29468481881278, 59.90521430969238, 77.39961801256452, 19.683739389692033, 0.49464958586863106, 2.2177431796278273, 3.3848459933485304, 4.375567265919276, 0.6514252104929515, 21.350535801478795, 70.48248481750488, 65.74238899775914, 60.41934626443045, 59.14009952545166, 58.9074182510376, 57.902170249394004, 60.5762574332101, 55.883058479854036, 58.733296394348145, 56.99534695489066, 57.44657686778477, 56.262544768197195, 56.877446447099956, 58.00451374053955, 54.71606683731079, 56.4409293447222, 52.79775953292847, 49.100025517599924, 47.981323855263845, 53.002498626708984, 51.617003508976524, 57.79807581220354, 52.94090979439871, 52.95524740219116, 51.991799763270784, 52.97976412091936, 53.380028997148784, 53.959894384656636, 50.687480449676514, 53.80963264192854, 53.1827974319458, 47.60058341707502, 50.57413101196289, 49.6205324445452, 56.45527042661394, 56.00545794623238, 54.07110377720424, 52.657475403376985, 40.36790125710623, 39.79553644997733, 39.523340770176475, 41.833943367004395, 40.75450250080654, 41.35220391409737, 38.603395802634104, 44.664226055145264, 51.01496989386422, 45.297675950186594, 41.03088447025844, 43.26239572252546, 44.05284711292812, 47.601142747061594, 46.4360271181379, 46.24709170205252, 49.40665994371687, 46.40489224025181, 38.09860570090157, 36.674871172223774, 40.20819691249302, 43.58530282974243, 41.28882939474923, 41.289916787828716, 43.74631690979004, 43.513958726610454, 39.841147899627686, 43.34604855946132, 40.361060755593435, 40.563691071101594, 45.6309358733041, 39.233989988054546, 35.03241082600185, 35.74145017351423, 36.73012324741909, 39.67953974860055, 42.0087114061628, 39.23115512302944, 39.13386992045811, 39.624666350228445, 39.303756850106375, 42.74155528204781, 43.57036420277187, 36.435092312949045, 33.04119259970528, 34.07765885761806, 37.12550354003906, 49.508228710719514, 46.13365193775722, 39.37352023805891, 37.45234680175781, 41.81424869809832, 40.04943404878889, 38.08459118434361, 39.851625783102854, 39.149343558720176, 38.93301139559065, 43.73847239358084, 50.07777254922049, 53.11898865018572, 51.123486859457834, 54.35903712681362, 49.87391240256173, 50.65346206937517, 47.57652875355312, 50.32996089117867, 55.418335165296284, 55.85374402999878, 52.48625094549996, 57.58714587347848, 54.32696076801845, 56.53736686706543, 49.478056158338276, 56.40427759715489, 43.88374532972063, 40.15281629562378, 60.92775290352957, 54.53345775604248, 57.8744330406189, 56.548834868839805, 58.975184031895225, 57.363497257232666, 55.58460208347866, 54.655065127781455, 49.16880920955113, 47.111218316214426, 60.84811265127999, 62.86432702200753, 64.20710808890206, 55.47288547243391, 65.09458065032959, 65.27570629119873, 75.27758952549526, 39.031331879752024, 0.5014672886048044, 2.467614080224718, 1.7050394053970064, 0.2543763459793159, 1.8752540946006775, 63.05552060263497, 75.86731093270438, 75.21370083945138, 73.33523450578961, 67.61250359671456, 38.51181159700666, 15.842869009290423, 40.171833515167236, 58.45643152509417, 89.67690426962716, 18.097014018467494, 1.0191286568130766, 0.21266890184155532, 0.2259945153657879, 0.08576477718140398], [0.11561731887715203, 0.011134514535245086, 0.0346344629568713, 0.007775124977342784, 0.11101333663931914, 0.09366276873541729, 0.0219533372603889, 37.736007009233745, 62.405655588422505, 37.28912319455828, 51.56192513874599, 20.290619373321533, 36.24757432937622, 43.37631491252354, 63.5010529926845, 53.525645869118826, 63.313013894217356, 17.480807815279277, 0.25231096680675236, 0.3134145108716828, 0.5037091140236173, 3.8972988724708557, 0.6507336476019451, 1.138494691678456, 39.9513532774789, 59.7394163949149, 57.02925763811384, 57.8303884097508, 54.5526556287493, 54.32644312722342, 53.79938404900687, 54.151633398873464, 53.180650438581196, 53.10174322128296, 49.68174260003226, 54.47194535391671, 53.82382433755057, 51.522139753614155, 48.488656997680664, 44.507530280521934, 46.06232173102242, 46.56741407939366, 47.94781616755894, 46.77092681612287, 53.10703774860927, 53.99531282697405, 48.62803438731602, 50.5047150339399, 48.48220212118966, 50.074458258492605, 48.21151420048305, 50.77840110233852, 47.40244163785662, 46.097424030303955, 44.04071208408901, 47.088681834084646, 44.305038928985596, 52.201927185058594, 49.38205637250628, 42.099798815590994, 49.26783146177019, 46.456680638449534, 38.32001004900251, 38.201914991651265, 37.85803822108677, 36.2284494127546, 35.9834246635437, 38.05560677392142, 36.7945226260594, 37.04387957709176, 42.09989261627197, 46.53613328933716, 40.518645899636404, 38.29767159053257, 38.259359223502024, 46.01013381140572, 45.960982254573274, 41.8706750188555, 48.09727191925049, 48.7647818837847, 45.78159713745117, 37.62064954212734, 36.565075738089426, 40.28882728304182, 36.35348572049822, 36.54428672790527, 38.558520862034385, 42.40605803898403, 42.499396664755686, 39.7529752595084, 37.91331461497715, 36.304799692971365, 35.70727545874459, 38.102124963487896, 32.95421852384295, 33.69281203406197, 34.195885930742534, 38.13719252177647, 42.02077347891671, 38.43908480235508, 37.77884265354702, 39.05943386895316, 41.81047582626343, 43.41682638440813, 42.56741952896118, 37.00417757034302, 31.72381067276001, 37.00466741834368, 42.01890441349575, 45.04053354263306, 35.61875540869576, 34.668137618473594, 34.80203635351998, 36.2538937159947, 34.39463915143694, 35.71699946267264, 35.776302337646484, 38.7131530216762, 35.90356206893921, 43.55033949443272, 47.19051810673305, 50.76021071842739, 47.22409527642386, 47.29260104043143, 50.730083329336985, 48.602784633636475, 47.961326939719065, 46.76288080215454, 45.68810217721121, 46.96295765468052, 49.54143067768642, 50.99041496004377, 49.0483135495867, 50.12354728153774, 49.134019579206196, 54.139824935368125, 33.69422251837594, 43.927581514631, 49.308558327811106, 51.04813364573887, 52.55162654604231, 53.56446198054722, 53.22474718093872, 52.46822384425572, 53.62585973739624, 53.059397424970356, 43.708779266902376, 49.16032893317086, 58.452380725315635, 70.18938895634243, 61.80408750261579, 52.935062885284424, 57.16237122671944, 56.65587534223284, 66.72506577627999, 29.180422578539165, 0.045986272394657135, 0.5427288402404103, 0.3203347809612751, 0.08087871436561857, 0.7117406225630215, 54.58498559679304, 63.107423646109446, 62.78602082388741, 59.92565590994698, 43.187997886112754, 45.84599651609148, 31.296347073146276, 29.735149383544922, 37.6569573538644, 59.81825760432652, 11.8054792540414, 0.49205155670642853, 0.060975294161055765, 0.09122773725539446, 0.0712524534070066, 0.06569396238774061, 0.04386222029903105, 0.07748600534562554, 0.030430270159350972, 0.06906447652727365, 0.08580585569143295, 0.08059788907745055, 48.162637097494944, 69.02492645808628, 44.794080938611714, 55.69620404924665, 26.574370418276104, 41.81598227364676, 48.64668682643345, 68.40276391165597, 58.03223010471889, 71.21904945373535, 19.610448053904943, 0.1344486741083009, 0.4910069927573204, 3.9023172089031766, 8.367078065872192, 0.49625950519527706, 0.8197338134050369, 46.37473358426775, 58.715793882097515, 59.44161660330636, 59.16607883998326, 56.389939989362446, 56.8655754498073, 55.07195356913975, 54.79913255146572, 52.39415257317679, 55.50197063173567, 50.81889172962734, 56.05796895708357, 54.349111625126426, 53.25251565660749, 50.49255568640572, 47.23491709572928, 48.22185659408569, 47.427475997379844, 50.43879052570888, 50.09776251656668, 55.1862027985709, 57.84405204227993, 50.089139802115305, 52.453240053994314, 48.74219329016549, 51.67167888368879, 50.60243797302246, 51.508795738220215, 51.70508929661342, 49.176087447575156, 45.8004024369376, 49.17349576950073, 47.04711076191494, 51.503212860652376, 52.48133856909615, 43.460210936410085, 51.56226560047695, 48.318019662584575, 40.258199623652864, 39.017233984810964, 37.98253256934029, 38.15293713978359, 37.23775168827602, 39.80529866899763, 38.713062695094514, 38.221731254032676, 43.54949181420462, 47.68816198621477, 43.43164341790335, 40.08682925360543, 37.766825744083945, 47.258339473179404, 47.10661860874721, 43.18959944588797, 49.21577903202602, 50.55859136581421, 44.423484870365684, 37.05548306873867, 36.22448546545846, 40.88035869598389, 38.713347571236746, 38.61124379294259, 39.035518169403076, 43.13319744382586, 43.377853938511436, 42.01236963272095, 39.46430540084839, 38.11246735709054, 40.26485252380371, 38.36461400985718, 33.25720167160034, 33.419754777635845, 32.78990057536534, 38.527764660971506, 41.953910963875906, 38.42523009436471, 39.02213593891689, 39.783564703805105, 42.626274245125906, 45.55615588596889, 43.16815383093697, 38.660780974796836, 31.310583932059153, 37.292010171072825, 41.232437814985005, 45.80073595046997, 37.767444133758545, 36.200389112745015, 36.47697605405535, 38.029116766793386, 36.23822900227138, 38.095176764896934, 37.7209780556815, 38.903252261025564, 37.344385692051475, 45.005879402160645, 50.52659838540213, 52.16059235164097, 48.229652472904746, 49.07574156352452, 52.39874185834612, 51.638838223048616, 49.33025755201067, 48.42694657189505, 47.90277099609375, 49.857257570539204, 51.88865375518799, 53.11762680326189, 49.0374048777989, 53.083354813711985, 52.39084870474679, 54.639681816101074, 36.45571804046631, 44.95496995108468, 51.1982182094029, 53.04088742392403, 54.062324728284565, 55.25775187356131, 54.02174724851336, 53.487416880471365, 53.3445098059518, 53.179250376565115, 47.313042640686035, 49.67457205908639, 56.38520131792341, 68.39792101723808, 64.54838970729283, 55.41027525493077, 60.8060691016061, 59.25662776402065, 70.48876598903111, 32.52011244637625, 0.059106445871293545, 1.039004847407341, 1.284741352711405, 0.12986006747399056, 1.3323034005505698, 59.38867827824184, 69.57469572339738, 67.946197782244, 66.73486273629325, 49.64609834126064, 42.244720867701936, 21.026381492614746, 33.813064507075715, 44.22114290509905, 70.70140171051025, 15.8064170224326, 0.5537024342588016, 0.16108757896082743, 0.1389355683433158, 0.07234930526465178, 0.15981000608631543, 0.1364096538828952, 0.13451705686748028, 0.14315562189689704, 0.1504357462482793, 0.34217375623328344, 0.5717735588550568, 60.95496899741036, 77.25582504272461, 53.66488776888166, 65.55200835636684, 27.4219742161887, 45.83595289502825, 58.65321840558733, 72.30027253287179, 63.07258537837437, 77.29874406542096, 21.767573629106792, 0.6736163997224399, 1.007588567478316, 7.068859270640782, 11.064334886414663, 0.7826633283070156, 1.723117423909051, 51.61983837400164, 61.08922209058489, 61.00594793047224, 60.054802077157156, 60.05506610870361, 58.55416488647461, 58.75648948124477, 56.49339171818325, 54.19520207813808, 56.510324478149414, 52.98484672818865, 59.977211543491904, 56.47036191395351, 54.42730665206909, 52.50888122831072, 49.201076643807546, 51.76170321873256, 49.34497731072562, 53.37606157575335, 52.22687816619873, 56.783350467681885, 54.39313193729946, 53.102844510759624, 54.38580158778599, 53.41458933694022, 53.73085049220494, 52.307206290108816, 54.75600160871233, 53.344836371285574, 51.41658966881888, 48.52794211251395, 49.912516593933105, 46.45209830147879, 51.427408014025005, 53.286561829703196, 48.778310026441304, 51.80311795643398, 51.96779373713902, 42.0807329586574, 41.90266105106899, 41.53851638521467, 41.06887027195522, 38.72380461011614, 40.82934849602835, 41.13671595709664, 40.14636836733137, 45.60522753851754, 51.211517061506, 43.142706053597585, 41.05371625082833, 39.49955013820103, 47.05685908453805, 48.561554023197715, 44.07006127493722, 53.106033733912874, 53.8979685647147, 46.08575453077044, 37.931605747767854, 37.53661802836827, 43.17077677590506, 40.23279700960432, 40.50689649581909, 41.322184222085134, 45.12290096282959, 46.84775652204241, 44.574246883392334, 41.74334927967617, 41.484917981284006, 42.17666326250349, 40.286523955208914, 33.325558049338206, 35.40343768256051, 34.95857926777431, 40.74056788853237, 41.96637603214809, 40.01866742542812, 39.82863766806466, 40.83905512945992, 44.30914184025356, 47.772853578839985, 45.03012861524309, 39.37313461303711, 32.11050571714129, 37.72411864144461, 44.05269772665841, 48.415537629808696, 40.74493483134678, 37.817978382110596, 37.5923946925572, 39.91559784752982, 36.03119700295584, 39.955609049115864, 38.62561614172799, 41.89279113497053, 38.925969396318706, 47.8447014263698, 52.38641227994646, 54.81878900527954, 49.42255047389439, 50.951529366629465, 53.36621945244925, 52.32964897155762, 52.6511664390564, 49.87487472806658, 49.305469853537424, 50.63927384785244, 54.06120606831142, 54.63643700735909, 52.115206718444824, 53.15145410810198, 53.10960510798863, 52.91653898784092, 34.92094782420567, 47.79097448076521, 51.142521449497764, 54.90990073340279, 56.80767958504813, 58.120204721178325, 57.28191498347691, 56.577339853559224, 55.814062867845806, 53.527351651872905, 48.476532391139436, 51.78950643539429, 56.476306097848074, 69.61239664895194, 66.1801324571882, 59.82920796530587, 63.076816831316265, 62.30149514334542, 74.48705128261021, 34.65829202107021, 0.11748528507139001, 2.8923144681113104, 1.8940294299806868, 0.2484711914190224, 2.0633455216884613, 68.43653910500663, 75.40941074916294, 74.40071991511753, 73.58395222255162, 58.37798636300223, 61.881566865103586, 42.874988487788606, 46.19360794339861, 51.23272296360561, 81.89818055289132, 24.346524340765818, 0.7047321157796043, 0.3930409752896854, 0.1692794779581683, 0.3021982455892222], [0.029967105548296655, 0.020620816620066762, 0.06828664469399623, 0.09004589210131339, 0.07204973883926868, 0.11316047249627964, 0.46273384988307953, 40.42045395714896, 59.5491886138916, 42.18955911908831, 38.263097354343955, 25.028788805007935, 38.84148972375052, 44.88958045414516, 69.1612570626395, 51.91791956765311, 66.54047993251255, 20.78404917035784, 0.17392388731241226, 0.08094957377761602, 1.2851616101605552, 4.692392093794687, 1.0186610647610255, 0.10647238351936851, 18.01553770474025, 58.285182748522075, 50.84280048097883, 57.667435782296316, 52.825514112200054, 56.20386723109654, 51.99664613178798, 54.88695778165545, 54.31176158360073, 53.324342659541536, 54.52639838627407, 55.66400957107544, 50.32046965190342, 50.33197586877005, 47.22012438092913, 46.52098969050816, 43.48885835920061, 49.37440987995693, 48.549721240997314, 48.57069785254342, 46.02602086748396, 40.88685873576573, 45.388822419302805, 51.03087084633963, 49.03280169623238, 49.224759578704834, 45.27931186131069, 50.37985937935965, 44.97751338141305, 51.30676644189017, 47.158893380846294, 46.27634709221976, 45.7220128604344, 59.7149726322719, 41.22418335505894, 41.66129452841622, 51.94491331917899, 43.868935244424, 37.725939069475444, 36.35263109207153, 37.646938051496235, 35.92935030800955, 34.70565094266619, 36.214014530181885, 37.69364384242466, 36.503848212105886, 37.59957218170166, 43.648100648607524, 43.13125542231968, 40.57181004115513, 39.75544534410749, 38.28972979954311, 43.24628632409232, 48.99144949231829, 47.278569153376985, 48.76878752027239, 45.299440792628694, 44.23423678534371, 38.08492817197527, 39.84748118264334, 39.60605212620327, 35.72014004843575, 38.807777064187185, 42.15307412828718, 40.63230800628662, 39.63982037135533, 39.612885679517476, 36.690699168613975, 40.161782945905415, 36.5183664730617, 35.100301674434114, 35.503714084625244, 31.29621853147234, 40.83088404791695, 40.70199843815395, 38.62191275187901, 38.13437850134713, 40.742707933698384, 44.18346282414028, 45.32086903708321, 39.57823153904506, 36.169962951115195, 38.79855333055769, 37.454910687037874, 43.41672910962786, 39.27217033931187, 34.69534676415579, 36.71305847167969, 35.589388847351074, 34.520929609026226, 33.90047631944929, 35.6480837549482, 37.048851013183594, 36.66574471337454, 35.878037861415315, 44.6057083266122, 48.04670640400478, 51.15522275652204, 49.84879813875471, 47.900304385593955, 53.59083039419991, 52.6995849609375, 49.23936816624233, 51.56236982345581, 56.041769232068745, 51.42423963546753, 51.15086623600551, 50.00140489850725, 52.6877487046378, 50.214440141405376, 54.18032251085554, 48.868400369371685, 41.84009599685669, 49.90071507862636, 46.664595058986116, 50.046818324497764, 51.79727104731968, 52.04501601627895, 55.8362832069397, 51.391461508614675, 52.74325091498238, 51.51428828920637, 44.14374344689505, 48.23245259693691, 43.51145042691912, 49.73229769298008, 63.47888823917934, 56.47501025881086, 58.346399852207725, 55.451537132263184, 67.1620032446725, 28.81248767035348, 0.08730957071696009, 0.5193004916821207, 1.3095184117555618, 0.12909347218062195, 2.4262043365410397, 62.1554787499564, 58.209968498774934, 67.0237340927124, 59.679800851004465, 45.98517935616629, 28.616776023592266, 19.0089807169778, 33.24141883850098, 42.52347217287336, 62.539658546447754, 14.264232209750585, 0.6948277301021984, 0.05229220366371529, 0.0912643645757011, 0.012667094440465527, 0.05698309266673667, 0.058324393550200124, 0.05837408945496593, 0.034435835400862355, 0.023863394678171192, 0.007797653188130685, 0.5313811834369386, 50.62517247881208, 67.1655329295567, 48.15482037408011, 43.81775828770229, 19.487445831298828, 47.9444706099374, 49.282092639378135, 75.32656042916435, 56.39672837938581, 72.2093414579119, 23.470655270985194, 0.17906453646719456, 0.48060233678136555, 3.0041431188583374, 5.4007631114551, 1.4999280401638575, 0.4707069620490074, 21.75711832727705, 61.01309067862374, 50.45701217651367, 58.50237996237618, 52.659198556627544, 56.890727928706575, 56.365920066833496, 56.30868428094046, 56.099651200430735, 55.5876419203622, 56.82327134268624, 56.106752259390696, 53.15027986254011, 52.96501309531075, 49.81204216820853, 49.32365328924996, 46.946188177381245, 50.49168021338326, 51.31625073296683, 50.397452218191965, 47.641504832676475, 46.00293547766549, 46.07952894483294, 50.93386009761265, 50.131329263959614, 52.412672996520996, 49.78528812953404, 51.74037224905831, 49.02392884663173, 52.98783097948347, 48.08971922738211, 48.750621455056326, 46.62238127844674, 57.11157642092024, 46.25237233298165, 44.86248595373971, 55.75194944654192, 45.167126246861045, 39.373190198625835, 37.75043841770717, 39.77115174702236, 37.13556800569807, 35.6143467766898, 36.87081732068743, 38.93421343394688, 38.229012966156006, 41.17843641553606, 46.65924147197178, 45.36570923668997, 41.938645771571565, 41.280251843588694, 38.79224436623709, 45.58516461508614, 47.791606766836985, 47.13193784441267, 50.3418527330671, 46.671650954655235, 44.411780629839214, 37.73765025820051, 40.78546714782715, 39.907117571149556, 37.97969423021589, 39.95378514698574, 44.301436288016184, 41.44578225272042, 41.71306208201817, 41.12423351832798, 38.520149435315815, 41.6483986718314, 36.69936009815761, 35.67287145342146, 35.179545879364014, 33.01765905107771, 41.29609373637608, 41.024693625313894, 39.83657945905413, 36.614074434552876, 40.60532815115792, 46.532707827431814, 47.653236865997314, 42.27279506410871, 36.12886783054897, 37.906481061662944, 39.861606870378765, 44.934260845184326, 41.616492543901714, 36.86106899806431, 37.304426601954866, 37.58077383041382, 36.80171748570034, 35.753706795828684, 37.30285978317261, 37.888481753213064, 38.63799435751778, 38.72894627707345, 46.117146492004395, 50.31678015845162, 52.80153587886265, 51.704884324754985, 49.93501486097063, 54.315881865365164, 52.36904525756836, 50.664019857134136, 53.18575736454555, 55.753015995025635, 52.146678583962576, 54.39811726978847, 50.45611238479614, 53.25693818501064, 52.27349363054548, 55.595764364515034, 50.47184658050537, 44.82525403159005, 51.29404776436942, 49.053601128714426, 51.94362790243966, 52.96525975636074, 53.25557286398751, 57.35175480161394, 55.05756732395717, 52.62974166870117, 55.11172505787441, 45.991887841905864, 48.65438890457153, 43.4764905657087, 52.05008125305176, 65.56186090196881, 59.00755568913051, 62.885908126831055, 58.50091389247349, 70.56280599321637, 30.98818404333932, 0.133237909791725, 0.8413209979023252, 1.1503006581749236, 0.21560827483023914, 2.8812190634863715, 67.5894216809954, 64.9587572642735, 72.76559339250836, 64.64562279837472, 52.520668847220286, 28.987766402108328, 19.572974681854248, 38.07532923562186, 49.20423460006714, 73.41534028734479, 18.861131736210414, 0.6503269065703664, 0.008355911089373487, 0.15414622000285558, 0.018710404667737227, 0.10847258940339088, 0.12167291822178022, 0.2298299888414996, 0.26903932488390375, 0.13061371631920338, 0.20515914766916207, 1.3817101951156343, 62.801827975681846, 74.43500232696533, 55.84349891117641, 55.06486988067627, 35.041863850184846, 52.692838260105674, 57.17610086713518, 82.69413144247872, 60.77398926871163, 81.16716752733502, 25.206687007631572, 0.23973418452910014, 1.763016477227211, 6.198373317718506, 14.510398200580052, 3.478199601173401, 0.3518057236714022, 25.052522114345006, 61.07154587336949, 51.5040396962847, 62.07874979291643, 54.81248698915754, 60.434792109898154, 56.054126603262766, 59.359766823904856, 59.67358916146414, 57.37735196522304, 59.25039522988455, 59.37000152042934, 56.014549664088655, 54.903522287096294, 51.70736830575125, 51.42891577311924, 47.307855810437886, 54.73280157361712, 52.57333271844046, 54.54194498062134, 48.182696546827046, 43.95959186553955, 49.78952653067452, 52.15897689546858, 52.50045306341988, 54.41556767054966, 52.217689173562185, 55.279468468257356, 51.478112493242534, 54.283357347760884, 50.344190801892964, 49.357914856501985, 48.88051802771432, 55.42233385358538, 49.20820549556187, 48.82492896488735, 56.638730662209646, 47.681766169411794, 40.05271012442452, 39.43988248280117, 41.81249080385481, 39.4862825529916, 36.90363713673183, 39.54544298989432, 43.00247403553554, 39.443446908678325, 43.10118709291731, 48.03918497903006, 47.896541936056956, 44.16948652267456, 43.70065682274954, 38.994339670453755, 46.582984992435996, 51.507294927324565, 49.9148268699646, 50.74561602728707, 48.25244951248169, 45.25488199506487, 38.047373158591135, 42.445457799094065, 42.89150782993862, 40.04668256214687, 42.968938555036274, 44.95881230490548, 44.57855824061802, 42.593020166669575, 43.59577029091971, 40.59529842649187, 44.31819881711687, 37.55414138521467, 38.11588587079729, 37.32109533037458, 32.773315225328716, 43.39237567356655, 42.52370841162545, 40.96515451158796, 38.64368493216378, 41.781814507075715, 50.09177664348057, 49.12028299059187, 42.52576507840838, 37.618339266095845, 40.56720685958862, 41.91586262839181, 47.972937379564556, 43.14506149291992, 39.24838318143572, 39.14722088405064, 39.137674059186665, 39.16496658325195, 38.25927931921822, 38.19898632594517, 39.209403787340435, 39.34357002803257, 38.64203126089913, 48.52379751205444, 52.746117046901155, 55.56821128300258, 52.91525704520089, 51.772646631513325, 56.22878347124372, 56.320350306374685, 52.20774630137852, 54.4998527935573, 59.15016746520996, 54.63006898335048, 56.659300804138184, 53.89451878411429, 55.64512436730521, 54.89523656027657, 56.010787214551655, 47.92119761875698, 46.96660893304007, 51.366038049970356, 50.454423972538535, 53.64078794206892, 55.02060638155256, 56.62471267155239, 59.47869219098772, 56.20706687654768, 53.20468773160662, 53.810772146497456, 50.14690365110125, 47.841786657060894, 46.11870983668736, 56.90889399392264, 69.37091895512172, 62.61518546513149, 66.21726363045829, 62.325612340654644, 73.7642718723842, 33.94561876569475, 0.1713140516408852, 2.2817536762782504, 2.904911986419133, 0.48185909220150536, 3.722271144390106, 75.18461568014962, 69.28198201315743, 77.64201981680733, 70.79058878762382, 62.960906982421875, 44.50581407546997, 29.92195517676217, 49.26000084195818, 55.23121322904314, 88.02717958177838, 26.96040712084089, 0.8517184342656816, 0.25597744435071945, 0.25106577362333027, 0.12183059618941375], [0.06024003361484834, 0.03479448865566935, 0.0805540828566466, 0.010785534645297697, 0.050916233033474, 0.07892822474241257, 0.35576076858810013, 49.09096506663731, 52.984534059252056, 35.8019585609436, 32.87606518609183, 55.16681037630354, 23.047084399632045, 43.203179700034006, 65.20951080322266, 53.501841340746196, 61.18612861633301, 27.32325073650905, 0.0589484286361507, 0.4296311933015074, 2.163872710296086, 7.212993570736476, 0.7685809582471848, 0.21212065911718778, 3.6721507481166293, 57.902396065848215, 55.57406514031546, 58.78729779379708, 52.38320568629673, 58.855647223336355, 54.03915596008301, 56.98650189808437, 52.60168136869158, 53.99964502879551, 49.94051783425467, 53.45907865251814, 49.1769802910941, 47.88481685093471, 44.15795946121216, 44.940211977277485, 46.94105345862252, 51.61578062602452, 47.58091654096331, 49.97128793171474, 46.14905956813267, 39.61443165370396, 42.321571418217246, 44.183653899601524, 45.02671010153634, 48.73246233803885, 49.43361895424979, 49.61550889696394, 49.965715476444785, 43.22997195380074, 48.425921712602886, 45.04639087404524, 51.293248721531455, 52.97662353515625, 34.08401645932879, 52.71892874581473, 45.79582009996687, 42.818339824676514, 35.619856698172434, 39.40018047605242, 34.097308363233296, 35.614583015441895, 34.90476546968733, 39.64057077680315, 36.76821327209473, 39.104392187935964, 36.855010168892996, 42.07045657294137, 43.0128789629255, 41.572590351104736, 41.633883884974885, 40.40153748648507, 38.25587470190865, 43.4718074798584, 47.4108315876552, 51.27915777478899, 46.705311502729145, 46.98018223898751, 37.871924195970806, 37.48657710211617, 37.377684933798655, 37.54180833271572, 39.11153841018677, 42.3195355960301, 39.309958117348806, 38.214341844831196, 38.02098390034267, 38.768349511282786, 37.47103745596749, 33.92328725542341, 33.6854955809457, 33.01640142713274, 35.85974325452532, 44.08084487915039, 38.43385975701468, 39.4421580178397, 45.054336139133994, 41.478424889700754, 42.8617730140686, 42.024490765162874, 34.64281838280814, 38.18687214170183, 37.21251235689436, 40.35917779377529, 41.782676083701, 38.87018925803048, 34.56301484789167, 36.82585205350603, 36.75412927355085, 35.477894578661235, 34.07879836218697, 36.01683160236904, 37.26326894760132, 38.448461396353586, 37.98362691061837, 47.03870344161987, 45.92235027040754, 49.40272726331438, 50.68170302254813, 48.34586804253714, 48.52632665634155, 48.671471050807405, 50.547088623046875, 46.396627358027864, 28.224944523402623, 43.22491019112723, 52.23578923089163, 50.41267572130476, 50.5283145904541, 50.26128837040493, 49.96589265550886, 50.82848719188145, 46.08709553309849, 50.551410402570454, 49.84183604376656, 52.57356200899397, 53.662240505218506, 56.624674456460134, 51.713778018951416, 52.553210735321045, 56.68975823266165, 45.4140304837908, 52.72739165169852, 52.63742290224348, 47.764467103140696, 51.9490509714399, 63.24390016283308, 54.93309382029942, 58.1331353187561, 57.011303492954795, 64.66782229287284, 23.139967918395996, 0.0811406560242176, 0.753759853541851, 1.5518380318369185, 0.5076897804226194, 4.866674193314143, 65.89899444580078, 58.49681445530483, 62.970759528023855, 61.58016095842634, 42.25345127923148, 33.86839648655483, 17.2972537790026, 24.19494765145438, 50.560060909816194, 60.56217343466622, 12.933630466461182, 0.8196811048047883, 0.1341941827642066, 0.1920484397560358, 0.009144019335508347, 0.05625836976936885, 0.013741837930865586, 0.09060232474335603, 0.012869773698704583, 0.01883532975002059, 0.052658707568688054, 1.0524406007358005, 57.95171785354614, 59.50462981632778, 44.96274845940726, 50.89028099605015, 41.72570085525513, 26.281344039099558, 50.34627178737095, 69.10435131617955, 59.65686484745571, 68.80401543208531, 30.7753746168954, 0.10971032548695803, 0.0264054497903479, 3.5574772443090166, 4.8800477385520935, 4.918567248753138, 0.603868265237127, 4.402256599494389, 60.48581273215157, 55.61859267098563, 58.99647331237793, 55.27009882245745, 59.36078820909773, 55.971168586185996, 58.75693416595459, 55.34278392791748, 57.10050099236624, 52.836791038513184, 55.39806727000645, 50.85671424865723, 50.31645359311785, 45.91506161008562, 45.307545866285054, 48.92890875680106, 52.21587569372994, 50.958689485277446, 51.45568023409162, 48.052258014678955, 42.91206407546997, 42.311281136104036, 45.35043362208775, 47.02556092398507, 52.3471097946167, 51.34733349936349, 50.59047664914812, 50.1172765323094, 45.8955580166408, 49.587233202798025, 49.36120482853481, 50.53479725973946, 56.353399412972585, 38.81802565710885, 54.15873098373413, 47.590518951416016, 43.77315432684762, 36.12031807218279, 41.20391893386841, 35.868511881147114, 37.43316977364676, 36.35360731397356, 40.5505485534668, 38.503254890441895, 41.247254848480225, 39.45463350840977, 42.48239094870431, 44.04988023212978, 43.558319500514436, 41.92963743209839, 42.517882347106934, 39.310489654541016, 45.54916252408709, 46.95696135929653, 53.029485430036274, 48.53313589096069, 46.98705400739397, 38.347212246486116, 37.83679757799421, 39.4600704738072, 39.015802655901226, 39.613028117588584, 42.99392775126866, 39.699748584202354, 39.76387350899832, 39.46980837413243, 40.590052536555696, 39.441372871398926, 34.551800455365864, 33.559517792293, 32.638374260493684, 36.19885008675711, 43.71381671088082, 38.22898517336164, 40.80068717684065, 46.756214005606516, 43.22461141858782, 45.227162156786235, 42.83546713420323, 36.380038261413574, 39.38266059330532, 40.14430127825056, 42.18005050931658, 44.89197063446045, 41.75140571594238, 37.038793495723176, 37.71499913079398, 37.92459154129028, 37.14520863124302, 36.09460973739624, 36.99401235580444, 37.811912604740684, 40.04784985951015, 41.63312653132847, 47.43553590774536, 50.07858548845564, 51.13788005283901, 50.41297101974487, 50.50652503967285, 49.36553355625698, 50.06521020616804, 51.004874161311555, 46.944173199789866, 32.79673065458025, 45.23475653784615, 54.05997276306152, 52.423880440848215, 50.81403146471296, 53.98419918332781, 51.119766099112375, 51.7100259917123, 48.25275870731899, 52.295001779283794, 50.531670570373535, 54.9367207799639, 55.508682591574534, 57.49728829520089, 51.92886298043387, 53.12975140980312, 61.65918282100132, 46.35134942190987, 54.32405989510672, 53.52849810464041, 51.23929943357195, 52.210487365722656, 63.64131627764021, 58.521841866629465, 62.71309947967529, 59.419868741716655, 70.13852119445801, 25.214772973741802, 0.019257118991975273, 1.1988470703363419, 1.6919129554714476, 0.40567551446812494, 5.120028095585959, 72.75641482216972, 62.29784039088658, 70.72186415536063, 67.20421355111259, 49.82097407749721, 30.212389877864293, 17.520198890141078, 32.76253162111555, 52.47722176143101, 71.95614215305874, 17.130696773529053, 0.7816627334271158, 0.0778443261182734, 0.15930574600185665, 0.04730942246637174, 0.1860082567270313, 0.3093349412083626, 0.2099340393074921, 0.2065085909728493, 0.17368568080876554, 0.2888358554669789, 2.4089298120566776, 72.96236637660435, 67.37601470947266, 52.16153730664934, 44.87404775619507, 65.21661186218262, 37.29947253635952, 54.357154164995464, 77.0394650868007, 63.60147530691964, 76.69000543866838, 32.63003294808524, 0.16048457846045494, 1.022531428507396, 11.317850334303719, 16.531338214874268, 7.107620230742863, 0.5709516629576683, 5.621206436838422, 64.32888221740723, 53.39849036080496, 62.493550300598145, 56.07018041610718, 63.04825278690883, 57.84102610179356, 61.93099634987967, 54.62353767667498, 58.14811216081892, 54.11787210191999, 56.822461877550396, 53.32559333528791, 52.25407688958304, 48.578379086085725, 47.871476309640066, 51.535542828696116, 55.28945997783116, 53.81961372920445, 54.94788653509957, 47.62530858176095, 41.778941426958355, 45.06837150028774, 47.8257988521031, 50.45100198473249, 55.37928281511579, 51.61183752332415, 53.796399797712056, 52.48810264042446, 49.40423502240862, 52.47172573634556, 51.01442446027483, 48.732097557612825, 57.597675868443076, 44.201535088675364, 55.07899556841169, 50.63132510866438, 44.84861734935215, 38.84156962803432, 43.374928746904644, 37.91837290355137, 40.399682317461284, 38.52819544928414, 44.84375013623919, 40.519437994275776, 43.619915281023296, 42.247465406145366, 44.73422915594918, 46.76907164709908, 46.67133133752005, 43.70779609680176, 44.17195660727364, 39.73282895769392, 46.773275307246614, 49.9989139693124, 56.500371183667866, 51.05686753136771, 48.60835708890642, 39.684334005628315, 38.45353010722569, 40.73503017425537, 42.83013091768537, 42.27754415784563, 45.516617161887034, 41.29179974964687, 40.75668770926339, 42.323912961142405, 42.55615302494594, 41.31707034792219, 35.111331939697266, 32.802737372262136, 33.1799133845738, 38.82842711039952, 45.29276009968349, 39.2671537399292, 41.42264127731323, 48.09606988089425, 45.32096631186349, 46.15109886441912, 44.16199289049421, 38.02887010574341, 40.074520519801546, 42.74267394202096, 45.54976354326521, 47.37339816774641, 42.811231817517964, 38.16486372266497, 39.27747876303536, 40.91064589364188, 39.55538238797869, 37.48067113331386, 39.394250188555034, 39.71789033072335, 41.58510405676705, 42.25721720286778, 50.78799309049334, 50.54164123535156, 52.378724098205566, 55.442758083343506, 53.43282488414219, 52.36943783078875, 52.803606442042756, 52.9230876650129, 49.423002106802805, 33.595460823604036, 48.365131923130576, 55.83218376977103, 54.2219317981175, 55.35494327545166, 56.00671904427664, 50.53743062700544, 51.522257872990195, 50.700841835566926, 53.640183448791504, 53.92972183227539, 55.387540749141145, 58.1943176814488, 59.318140166146414, 56.54675735746111, 54.28589344024658, 59.051093101501465, 49.392311913626536, 54.37636593409947, 55.14688989094326, 54.51317596435547, 53.59439482007708, 66.81630952017647, 59.62342316763741, 67.65308107648576, 62.434560094560894, 72.97998006003243, 27.81508765901838, 0.1735800193356616, 2.6127076659883772, 3.188054335968835, 0.6757809807147298, 6.400654486247471, 77.51407568795341, 70.83089528764997, 74.91679041726249, 74.01754760742188, 59.34511307307652, 49.85300179890224, 26.25878323827471, 42.55680268151419, 62.546578952244346, 83.60287938799176, 27.744033643177577, 1.0145648845604487, 0.3192927140210356, 0.24127825881753648, 0.24105279520154], [0.10694774479738303, 0.07430658702339445, 0.11364457330533437, 0.10326521990022489, 0.04993386699685028, 0.023089045425876975, 2.676507328237806, 59.64158575875418, 46.2102940423148, 33.806633949279785, 17.11697929246085, 31.213854585375103, 37.83262171064104, 43.219188349587576, 64.9521495274135, 54.42003536224365, 58.13930531910488, 35.138832909720286, 0.04896787740290165, 0.4737054354378155, 2.2155145449297766, 1.3258184513875415, 1.376420987503869, 0.5195373275450298, 0.08740797865071467, 32.32578175408499, 56.77024616513933, 53.60446623393467, 57.53886978966849, 52.25221477236067, 53.85287822995867, 51.6583765574864, 53.80332715170724, 51.35787739072527, 52.51536737169538, 52.1249098777771, 46.65659073420933, 44.758245604378835, 48.63802242279053, 50.118836402893066, 48.37893104553223, 47.730309758867534, 50.761864389692036, 47.85986934389387, 38.59515871320452, 35.76815904889788, 42.42727436338152, 39.661644663129536, 43.56954778943743, 42.31534930637905, 43.407234396253315, 49.911477838243755, 52.66655669893537, 58.4389637538365, 49.59771108627319, 44.123399121420725, 54.509621960776194, 34.78871318272182, 47.34464652197701, 50.08663150242397, 45.03244236537388, 36.94958209991455, 36.32517181124006, 34.35331474031721, 35.540681975228445, 40.44912222453526, 37.03457941327776, 37.88182885306222, 37.740036964416504, 37.95059864861624, 36.5573284966605, 36.71372202464512, 41.718891620635986, 39.849173069000244, 40.09785257066999, 39.678886617933, 38.206038747514995, 36.656031131744385, 43.47537537983486, 46.75190264838082, 50.58362225123814, 50.05508320672171, 39.728639193943565, 38.90583004270281, 38.958400113242014, 37.1187881061009, 35.249271052224294, 39.39100537981306, 35.88927657263619, 36.89065095356533, 37.69003077915737, 37.86018868855068, 37.76933751787458, 31.85828263419015, 33.36834505626133, 34.90422698429653, 39.634716919490266, 42.49068709782192, 40.052977630070274, 43.55614471435547, 46.4695382799421, 44.313717229025706, 45.18362821851458, 40.879712513514924, 36.18922683170864, 38.54531233651297, 36.28697061538696, 39.33673994881766, 40.32108082090105, 37.02183294296265, 35.786147935049875, 35.3438012940543, 34.086920806339805, 34.72304228373936, 32.766961097717285, 34.080257483891074, 36.751318727220806, 36.989176409585134, 40.174883774348665, 43.96155820574079, 48.141643115452354, 51.57502596718924, 48.54389517647879, 47.93962771551949, 46.861677237919395, 47.04930291857038, 50.015735558101106, 46.04803623471941, 37.133393219539094, 42.62468310764858, 47.74433817182268, 49.855732440948486, 52.01933547428676, 49.532773222242085, 51.720455237797324, 49.337257862091064, 46.75672469820295, 49.832028661455425, 50.21049356460571, 51.796722139631, 49.59765897478376, 50.87780897957938, 57.29335171835763, 58.76286097935268, 44.06743138177054, 53.8222644669669, 57.879574707576204, 59.69689341953823, 59.3143881389073, 59.45998764038086, 64.78316933768136, 60.405679157802034, 61.378399167742046, 57.13252523967198, 64.56697613852364, 17.161386966705322, 0.06306765867131096, 0.369384937520538, 0.8187498290623937, 0.2760728288974081, 6.241514682769775, 69.53850950513566, 56.13417679922921, 66.79220621926444, 61.694229534694124, 48.826089314052034, 31.17767878941127, 19.872002567563737, 25.437716347830637, 45.35466160093035, 62.79185731070382, 18.017165320260183, 0.9008837246469089, 0.07714289054274559, 0.08700443351907389, 0.06199921028954642, 0.14979790976004942, 0.13451108575931617, 0.021039756014943123, 0.048046542198530266, 0.044245694364820204, 0.1544036561889308, 3.5821470405374254, 70.02994169507707, 52.6507009097508, 40.439651829855784, 25.076887709753855, 43.59981414249965, 35.961405822208945, 50.83038752419608, 70.66591726030622, 58.12912968226841, 63.24063450949532, 38.14540181841169, 0.06314594125641243, 0.14395746029913425, 2.3756657455648695, 2.73796067067555, 4.842655139310019, 1.2209685061659132, 0.18011725640722684, 36.149827071598594, 57.256185804094585, 56.23338665281023, 58.20274584633963, 56.877943243299214, 55.42002705165318, 54.05880546569824, 54.93548400061471, 54.01493106569563, 54.1204012462071, 52.99088471276419, 49.13502359390259, 46.68850728443691, 49.75615780694144, 52.48179020200457, 50.096101897103445, 51.039569990975515, 54.02392898287092, 50.944171224321636, 41.64087724685669, 40.89761107308524, 43.59069810594831, 43.051465783800396, 45.511635303497314, 44.340394837515696, 45.00126927239554, 50.19744137355259, 52.440875734601704, 56.832922390529085, 51.111449105399, 43.944528170994346, 55.27122095652989, 41.32309443610055, 48.983274936676025, 53.06899983542306, 46.66988263811384, 39.39413901737758, 36.30949320111956, 36.37303795133318, 36.553472246442524, 41.28948252541678, 36.65058721814837, 38.01501192365374, 38.8738648550851, 38.98999009813581, 37.761930738176616, 38.79197686059134, 42.86067519869123, 40.814250060490195, 42.08528750283377, 42.919759205409456, 40.54898520878383, 38.18238707951137, 43.49318013872419, 48.80136067526681, 51.49443728583199, 51.39486960002354, 39.96761901038033, 39.265375001089915, 39.17936325073242, 38.670206206185476, 37.4199230330331, 40.45535128457205, 37.99278811046055, 38.750579493386404, 39.494425841740195, 40.38407318932669, 38.67789786202567, 34.25900336674282, 34.35371426173619, 34.531984192984446, 41.437708445957725, 42.2270689691816, 40.987107345036094, 44.24841111046927, 47.44677809306553, 46.485116141183035, 47.29110370363508, 41.78511837550572, 38.30399097715105, 39.3443968636649, 40.19488416399275, 42.08084065573556, 43.29179702486311, 38.09032344818115, 37.19962344850813, 37.234934193747385, 36.22043119158064, 37.481949601854595, 34.944971220833914, 34.578967911856516, 37.45398310252598, 38.00716740744454, 41.190606185368125, 45.91213641847883, 49.4426828793117, 51.607032843998496, 49.84453541891915, 49.054160458701, 48.45637914112636, 48.27240126473563, 50.611581802368164, 48.42970848083496, 40.39988728931972, 46.33076190948486, 48.660847255161826, 50.84824092047555, 53.605317388262065, 52.999875681740896, 53.02492046356201, 51.48488698686872, 48.142160756247385, 51.71261419568743, 52.00336503982544, 52.200950963156565, 51.166732447487966, 51.60160630089896, 57.34153747558594, 64.97161143166679, 48.07563870293753, 55.03120238440377, 59.76765387398856, 59.76100444793701, 59.844118799482075, 59.87579563685826, 67.10541711534772, 64.01644257136753, 64.23192705426897, 59.76558331080845, 65.80418627602714, 19.641789640699113, 0.18711722722010954, 1.1420184054544993, 0.6313100127237183, 0.4324122912117413, 7.584518092019217, 74.99789673941476, 62.458614758082796, 71.87890597752163, 67.59234687260219, 55.798669133867534, 31.893443993159703, 16.7723799092429, 31.85255037035261, 50.501289572034565, 71.61850139072963, 23.470815079552786, 0.9330611037356513, 0.10642808875335114, 0.14878101646900177, 0.05803918492581163, 0.23102315195969172, 0.30641409222568783, 0.20313347636588983, 0.12683637972388948, 0.2522367350757122, 0.2672989639852728, 5.069903790950775, 81.65043558393205, 59.72633988516671, 48.79661852972848, 26.184703281947545, 38.70754582541329, 51.519033908843994, 54.409154483250205, 78.01078156062535, 63.449400084359304, 69.85946764264787, 42.63346215656826, 0.14973025981869015, 1.1996136520590102, 8.266970157623291, 9.300595470837184, 9.663536361285619, 1.7340023198298045, 0.22829687967896461, 38.40408672605242, 61.61505481175014, 57.82038300377982, 59.090607506888254, 58.0982414654323, 58.00638975415911, 56.26088067463466, 58.148494311741416, 56.39052711214338, 55.75460018430437, 53.53301790782383, 51.20054933003017, 49.009368896484375, 50.67398009981428, 52.47921936852591, 53.49671357018607, 54.51532295772007, 56.71222870690482, 51.3108936718532, 45.48392241341727, 39.72195850099836, 45.861004625047954, 43.96108225413731, 46.98993056161063, 44.82120323181152, 49.61313956124442, 52.56427921567644, 53.14258473260062, 55.67715556280953, 50.89606884547642, 46.10443128858294, 52.65927846091134, 47.73743513652256, 51.17615073067801, 55.71296657834734, 47.94799682072231, 41.304838044302805, 38.0760622705732, 37.48641381944929, 37.931511947086875, 42.35622555868966, 38.65122372763497, 41.24705682482038, 40.99789789744786, 43.19152757099697, 40.812217712402344, 41.68243094852993, 45.53429337910244, 42.10338061196463, 42.6835378238133, 44.50060987472534, 41.50455706460135, 39.47412320545742, 45.28668737411499, 50.95014320101057, 54.588984285082134, 53.56175913129534, 40.576718943459646, 41.46629333496094, 40.05168179103306, 41.79772588184902, 40.19906350544521, 42.8658481325422, 38.17728015354702, 40.518190792628694, 43.41932078770229, 43.855910846165244, 39.0595554624285, 33.890457017081125, 34.9199229649135, 35.55850757871355, 42.3246807370867, 45.33000939232962, 42.02312544413975, 44.844090597970144, 47.049792766571045, 48.11317981992449, 50.12877580097744, 42.99215248652867, 39.69591317858015, 40.90108517238072, 39.905554226466585, 43.33329166684832, 44.90060029711042, 39.63757610321045, 37.49957023348127, 39.20549889973232, 38.56152595792498, 39.48027583530971, 35.83805445262364, 37.22718347821917, 40.33499458857945, 39.46415254047939, 44.066983222961426, 47.91577802385603, 52.736264501299175, 54.143264293670654, 52.58149685178484, 52.6805990082877, 51.38432570866176, 50.8764853477478, 53.11435072762625, 51.51415974753243, 37.596883228846956, 44.546867506844656, 49.59733240944998, 52.288383620125906, 54.83686126981463, 53.19379990441458, 52.55929388318743, 51.56872395106724, 50.24722869055611, 52.152980600084575, 55.5100861276899, 54.079361711229595, 54.17170327050345, 54.17791496004377, 61.83929402487618, 58.663008417402, 50.49888896942139, 59.173659324645996, 60.960854121616904, 60.91560745239258, 62.345345224652974, 62.620403562273296, 69.88092367989677, 67.89117499760219, 68.01896626608712, 62.760659899030415, 70.47357027871269, 22.400813341140747, 0.2901596230055605, 2.12717210820743, 3.381675660610199, 0.8139617602740015, 8.256507907594953, 80.64479500906808, 67.25309412819999, 77.66774899618966, 74.16877514975411, 64.20867143358502, 48.06078692844936, 31.32052333014352, 40.45414924621582, 60.101139613560264, 82.40073680877686, 30.74451766695295, 1.01019501047475, 0.20901409509990895, 0.2498221274997507, 0.1627169315304075], [0.023324010228472095, 0.10747356872473444, 0.12168587824063641, 0.012141450324894061, 0.07842023950070143, 0.04312854752476726, 1.4211720547505786, 54.14701632090977, 48.112290450504844, 33.77771207264492, 24.636837448392594, 28.849066461835587, 32.66235249383109, 40.8197843006679, 60.78168092455183, 53.82102768761771, 56.23557186126709, 41.395314012254985, 0.0953416068639074, 0.11645092628896236, 0.7326835787722042, 1.5394052075488227, 5.196808295590537, 0.38091965285795076, 0.26987612141030176, 16.757811273847306, 66.68497467041016, 48.753810678209575, 56.55920852933611, 50.78766999925886, 52.53396422522408, 50.41469764709473, 52.85592637743269, 50.13436910084316, 48.7036064692906, 45.715613569532124, 47.544111933027, 51.17761680058071, 48.25446796417236, 47.80559696469988, 49.25716250283377, 53.49785654885428, 40.93634728022984, 37.231279441288535, 41.0847920690264, 46.572618280138286, 49.91389233725411, 44.55387823922293, 40.817310741969514, 39.404592582157676, 43.95489488329206, 41.41822222300938, 38.531697341373985, 42.60917820249285, 51.443684169224326, 52.23679671968733, 35.53295905249459, 40.16712958472115, 51.69492060797555, 45.95155702318464, 43.62190593991961, 35.01685380935669, 35.70605952399117, 35.73668370928083, 35.82604449135916, 33.555783135550364, 34.44546175003052, 34.467435428074424, 35.49943399429321, 34.00408785683768, 39.44448913846697, 37.29187815529959, 39.90228162493025, 39.194576331547324, 39.56549896512713, 40.962944984436035, 41.88203532355172, 40.833538259778706, 41.78237383706229, 48.11471537181309, 49.92492955071585, 47.79233285358974, 44.64294719696045, 40.86029577255249, 37.3693470954895, 34.52003329140799, 36.44044589996338, 39.077544348580496, 40.191281523023335, 35.01759031840733, 36.21648114068167, 37.32634122031075, 37.97431285040719, 34.80151523862566, 33.49698053087507, 35.685406003679546, 41.74300881794521, 44.548965862819124, 42.263105801173616, 43.78205844334194, 44.271329743521555, 44.1520847593035, 44.58357484000069, 39.719172273363384, 39.348736013684956, 39.99821540287563, 37.16691827774048, 38.52321011679513, 36.87448596954346, 35.61205039705549, 34.542726108006065, 33.933004311152864, 33.043999671936035, 35.17408806937081, 34.85584667750767, 35.700608662196565, 34.839341231754844, 38.03868096215384, 39.25625549043928, 44.80698026929583, 47.19886984143938, 46.75721802030291, 46.598180702754426, 47.47663797651018, 46.84907667977469, 47.057508741106304, 48.858127457754954, 50.785488264901296, 50.08901820863996, 48.13113049098423, 47.05764423097883, 46.988513129098074, 49.60917908804757, 50.26234449659075, 52.104454381125315, 46.951923915318076, 45.558292457035606, 49.40713936941964, 50.806794915880474, 53.40628276552473, 53.27516678401402, 57.24200453077044, 55.94656848907471, 38.939389841897146, 49.30790172304426, 57.65063851220267, 56.303216048649375, 56.31980834688459, 55.866903918130056, 57.24999148505074, 57.80280753544399, 58.78356661115374, 65.77234963008335, 61.604389326913015, 62.37488896506173, 10.836372307368688, 0.14382134617439338, 0.7626451881868499, 1.2318796749625887, 0.3195805214345455, 6.923458661351885, 69.56485707419259, 59.54395662035261, 65.8470149721418, 64.98188781738281, 45.90050860813686, 55.45984022957938, 29.409396989004954, 25.08057372910636, 44.574966021946494, 61.31694235120501, 11.308726481028966, 1.1190122685262134, 0.10040934064558574, 0.16816330142319202, 0.0222948965217386, 0.09354108705052308, 0.12303621721054826, 0.09548690156745059, 0.12804941034742764, 0.09209259799016373, 0.07379047971751009, 2.6923327190535407, 66.47362436567033, 54.411687101636616, 39.541958468300955, 28.220798185893468, 24.444483518600464, 34.85834108080183, 48.226101943424766, 67.77957303183419, 58.57793467385428, 61.54311316353934, 45.33968128476824, 0.12856429629027843, 0.06771079916507006, 2.323731000934328, 1.1653718437467302, 3.2568723346505846, 1.7030022804226195, 0.5629191654069083, 19.91625564438956, 65.64366899217877, 52.587270804813926, 56.326256275177, 53.83123459134783, 53.961506366729736, 50.468976974487305, 52.184990950993125, 50.579811164310996, 50.41086571557181, 48.02520520346505, 48.38549361910139, 51.540507316589355, 51.38816806248256, 50.51977525438581, 53.87042243140084, 54.29380049024309, 43.584302289145334, 39.89313779558454, 44.46725157329014, 48.620047433035715, 47.4071420942034, 44.98833172661917, 43.12719767434256, 41.934737409864155, 45.681063652038574, 44.03945446014404, 42.78758014951433, 47.470457553863525, 51.95398071834019, 50.620475496564595, 41.43381745474679, 41.568112237112864, 54.26694917678833, 48.808204650878906, 44.43634251185826, 36.599083696092876, 36.7951340675354, 36.80986424854824, 37.92797531400408, 35.8748208454677, 35.04136010578701, 35.014963899339946, 36.33135223388672, 36.422641141074045, 40.32065698078701, 38.10813168116978, 40.99551119123186, 40.66720880780901, 41.83484663282122, 43.64715569359915, 43.65025111607143, 42.59184939520699, 44.65020111628941, 50.69512346812657, 50.74429586955479, 50.5134037562779, 44.24781009129116, 39.57348244530814, 39.92824704306466, 36.60253695079258, 38.502285616738455, 38.20986025674002, 39.2742235319955, 36.25825718470982, 40.320886271340505, 38.16074691499983, 36.59810747419085, 36.29511737823486, 34.34360115868704, 36.56426279885428, 41.446758474622456, 47.89361327035086, 45.603090967450825, 44.93901341302054, 45.91774014064244, 43.02653217315674, 44.539749077388215, 40.58673129762922, 41.44353798457554, 41.01518848964146, 40.29610899516514, 39.46903017589024, 39.82724455424717, 36.947219712393625, 36.67178269795009, 36.42434344972883, 34.825820037296836, 35.64565535954067, 36.90592656816755, 37.612534046173096, 37.13483844484602, 37.50551789147513, 39.54221902574812, 46.71001195907593, 47.587576389312744, 48.5559572492327, 46.88457155227661, 49.36265352794102, 48.06360789707729, 49.14402151107788, 49.57741887228829, 53.38981900896345, 50.28856699807303, 47.453743662152974, 48.41413409369332, 46.82087394169399, 50.717183998652864, 51.02729599816458, 53.5009936605181, 48.17407383237566, 45.19371700286865, 51.08614724023001, 50.5662830216544, 53.406390462602886, 53.635354450770784, 57.06309189115252, 61.245980398995535, 43.45571545192173, 51.99390506744385, 59.70949050358364, 58.743357385907856, 57.97520276478359, 59.01474707467215, 58.62860093797956, 59.744370460510254, 60.95651149749756, 66.98408767155239, 62.41006769452776, 64.00230993543352, 11.561931865555898, 0.19506965763866901, 1.040981718472072, 1.5589337710823332, 0.32905743005020277, 7.472493154661996, 77.10382625034877, 64.08592455727714, 72.41064466748918, 68.14137962886265, 55.9259740284511, 50.20325354167393, 23.808773721967423, 30.823556900024414, 49.89210973467146, 71.00971412658691, 15.396513257707868, 0.8079947776028088, 0.1527885664254427, 0.2092765795865229, 0.1269921035106693, 0.2372144583080496, 0.24333766688193592, 0.2424899595124381, 0.2361386546066829, 0.20564750289278372, 0.1932675636240414, 4.175344066960471, 79.07714939117432, 61.516786439078196, 47.28492675508772, 35.77485016414097, 38.26694665636335, 44.52764184134347, 53.07730988093785, 72.74801445007324, 62.75435788290841, 69.1016971043178, 50.546831539699006, 0.24705867150000163, 0.4369206135826451, 7.797643661499023, 9.424993412835256, 15.112180812018257, 3.285855225154332, 0.5741042995027134, 22.425910234451294, 68.49762766701835, 56.20062242235456, 60.6550361088344, 57.392797810690745, 56.03754472732544, 53.63301290784563, 55.758925437927246, 53.54377371924264, 53.4448105267116, 50.88848141261509, 52.19502762385777, 54.37760271344866, 53.37565163203648, 51.73248256955828, 54.405329499925884, 55.142675808497835, 46.43098620006016, 42.874620233263286, 47.90045377186367, 46.81107350758144, 46.79353278023856, 44.68897901262556, 42.01568739754813, 44.03995473044259, 47.58536686216082, 46.29594448634556, 44.9715587752206, 48.64366436004639, 47.267448561532156, 49.49836574281965, 44.92954996653965, 45.78179863521031, 55.78921610968453, 49.945590019226074, 48.111564363752095, 39.619323185511995, 37.61396884918213, 40.34521538870675, 38.90169586454119, 37.742739813668386, 37.81096764973232, 38.790354456220356, 38.60548026221139, 36.51235975537981, 44.27050985608782, 41.660895006997244, 42.4399721963065, 43.508445331028526, 44.31752831595284, 45.67357349395752, 47.794785567692344, 45.486142362867085, 45.8122421673366, 51.93751348767962, 54.171640736716135, 52.25344807761056, 44.87095580782209, 42.912908281598774, 41.956276825496126, 38.71101297651018, 39.45367465700422, 40.77486767087664, 38.48178843089512, 36.379652636391775, 40.8277017729623, 41.14004067012242, 38.715310437338694, 38.540479864392964, 34.49601684297834, 37.986215114593506, 42.39921406337193, 48.465342317308696, 45.648295947483604, 45.611449650355745, 47.990446840013774, 47.45144380841936, 47.50704329354422, 42.195148944854736, 44.412089824676514, 41.988975048065186, 42.632937567574636, 42.62669461114066, 42.46278313228062, 40.09075151171003, 38.59157691683088, 36.836812836783274, 37.595500537327354, 38.221199716840474, 39.595879963466096, 39.02455391202654, 39.07191630772182, 40.52199493135725, 41.80800921576363, 48.877457346235005, 50.61951664515904, 50.26128142220633, 49.04812247412545, 49.923619815281455, 50.58983394077846, 52.572325229644775, 53.46690232413155, 54.47602047239031, 50.692636013031006, 46.51492738723755, 46.77412298747471, 47.08006606783186, 51.71582773753575, 52.897393226623535, 54.94712223325457, 50.96165289197649, 46.57063109534127, 52.10390199933733, 54.34021793093, 56.127433572496685, 55.401854038238525, 57.87247364861624, 57.180811745779856, 46.10310765675136, 55.513640131269185, 60.003600801740376, 62.50243009839739, 59.2575101852417, 63.157596588134766, 61.40712302071707, 64.37320477621896, 61.581390789576936, 70.3853976385934, 64.17202663421631, 70.80474921635219, 13.605949452945165, 0.31755300451602253, 3.287255504301616, 4.4813344819205145, 0.5812260402100426, 9.05329258101327, 82.28889165605817, 70.30859919956752, 75.65881633758545, 76.9958998816354, 61.028897830418174, 65.22351837158203, 41.18502678189959, 40.91920607430594, 58.7059691292899, 83.09124183654785, 22.92243892805917, 1.3172982228653771, 0.24417804607323237, 0.2824181355535984, 0.1885570106761796], [0.19870944161500248, 0.04746094612138612, 0.120705815830401, 0.01530784840828606, 0.034397688162113936, 0.06034000217914581, 2.1537083642823354, 54.217352935246055, 48.39581169400896, 38.29745967047555, 25.664458649499075, 65.28178596496582, 53.60600525992257, 39.36493921279907, 58.92462199074881, 60.209121567862375, 52.65265335355486, 49.261230673108784, 1.4421003546033586, 0.23333831344332012, 1.104593345097133, 1.5342291252953666, 2.4439643664019446, 0.9621487600462777, 0.32427796508584705, 6.646255501679011, 62.695478848048616, 53.526236465999055, 57.91452762058803, 52.37418692452567, 53.58250297818865, 48.44954558781215, 51.04589285169329, 47.37435007095337, 49.89155387878418, 48.34202568871634, 49.7982291494097, 49.46155071258545, 51.26536212648664, 53.65743235179356, 46.43045118876866, 37.01320675441197, 39.683260508946006, 50.1095848764692, 48.206858907427105, 40.03226157597133, 48.11087301799229, 38.822611468178884, 46.140891960689, 44.97464377539498, 47.305906840733115, 44.30427115304129, 42.07980190004621, 34.028371810913086, 37.898626123155864, 40.65405586787632, 41.06947823933193, 49.530233655657085, 48.345013414110454, 44.36846555982317, 38.10640852791922, 35.630661146981375, 34.473671436309814, 35.135872977120535, 32.64552048274449, 34.649436541966026, 33.51292664664132, 35.04009205954415, 34.24811206545149, 34.550952775137766, 35.68592364447457, 39.40568692343575, 38.551061970846995, 41.12719692502703, 38.67348575592041, 40.529234954289024, 40.99614347730364, 42.92407751083374, 41.29780994142805, 45.061530998774934, 47.58841017314366, 48.655333859579905, 47.280886377607075, 43.9579416683742, 39.07536956242153, 35.77677828924996, 33.75691958836147, 37.58671106610979, 40.670582158224924, 35.31207929338728, 36.23118700299944, 40.060988903045654, 34.31174714224679, 35.4763103893825, 34.921906675611226, 38.47510426385062, 44.168649264744346, 43.800825527736116, 44.460959979466026, 45.18971831457955, 44.80912031446184, 42.741430214473176, 38.89664452416556, 41.35784237725394, 39.73509407043457, 39.46196385792324, 35.91802127020699, 36.70523132596697, 35.537944384983604, 34.893280097416465, 33.8354411806379, 36.847394943237305, 35.82872649601528, 35.77043458393642, 37.07669939313616, 35.916291168757844, 32.58781916754586, 36.82162060056414, 37.62254292624337, 45.75863334110805, 50.00362832205636, 49.869246687207905, 49.23490742274693, 47.16722774505615, 47.51873016357422, 44.20298031398228, 44.667408330099924, 47.397584847041536, 45.00098787035261, 46.78667490822928, 51.05024242401123, 51.23720455169678, 49.90849011284964, 48.93344940458025, 48.46813201904297, 44.028205326625276, 47.632777895246235, 47.68822104590279, 46.77435227802822, 48.71468537194388, 45.71194839477539, 41.57516465868269, 33.99179649353027, 46.92368296214512, 55.39938047954014, 55.7572717666626, 56.806512287684846, 54.13105283464704, 57.12730714253017, 55.56730106898716, 55.288473333631245, 55.8744809286935, 63.52894306182861, 65.13215650830949, 54.909508160182405, 7.827595608575003, 0.36611627148730413, 1.1829383011375154, 0.3048102797142097, 0.4866836390325001, 8.060406293187823, 65.16406958443778, 62.37443038395473, 62.75519861493792, 70.11589785984584, 43.74700478145054, 67.96527753557477, 39.12281881059919, 16.10809738295419, 56.38382904870169, 64.4833823612758, 13.489512409482684, 0.843420113836016, 0.1652612207191331, 0.1547636461577245, 0.047626644372940063, 0.17729784840984003, 0.09204836429229804, 0.12570595395352158, 0.0909849845671228, 0.04407745160694633, 0.05619952721255166, 2.9415335527488162, 64.11556557246617, 54.84723145621163, 42.023976598467144, 20.081586292811803, 46.801085472106934, 50.14619493484497, 45.21471445901053, 63.625245094299316, 63.97382926940918, 57.372849532536094, 56.047685623168945, 1.584198723946299, 0.2645220729921545, 1.2515478538615363, 2.1485224025590077, 4.432222442967551, 3.958362247262682, 0.7067350425890514, 8.023640768868582, 65.6251242501395, 54.41009943825858, 60.63778373173305, 53.13570254189627, 55.89294229234968, 49.54557180404663, 51.05522428240095, 49.38304649080549, 51.5416259765625, 49.99674613135201, 50.82243531090872, 50.52106761932373, 53.82323374067034, 54.53632041386196, 48.18809182303292, 39.04480791091919, 41.86991419110979, 49.27513401848929, 48.136296476636616, 44.35927309308733, 47.845535210200715, 39.78116062709263, 47.085961614336284, 44.338824544634136, 49.38775042125157, 45.22283342906407, 43.93212563650948, 34.867120129721506, 42.988025256565635, 47.799538135528564, 41.796419620513916, 51.05827801568167, 50.304520062037874, 48.05854960850307, 39.7785758972168, 38.31684514454433, 35.87659611020769, 36.48032855987549, 33.30639839172363, 36.249808175223215, 33.76040063585554, 35.67763444355556, 36.116343702588765, 37.00479596001761, 38.19955260413033, 41.12061698096139, 41.073723588671, 42.905029024396626, 40.12069477353777, 43.933133125305176, 43.431921345846995, 43.01682553972517, 44.46208211353847, 45.733835220336914, 48.90630279268537, 49.85367577416556, 49.484135832105366, 44.11954287120274, 39.45135743277413, 37.295730931418284, 36.018790994371685, 38.898468426295686, 41.74371406010219, 36.19098472595215, 38.16501310893467, 41.810343810490195, 35.89646448407854, 36.370897906167166, 35.74800927298409, 39.950387477874756, 45.073367255074636, 45.437588351113455, 46.88625301633562, 47.1949371610369, 47.37427364076887, 41.8005815914699, 40.57980394363403, 42.77833209718977, 42.73690346309117, 40.58150972638811, 38.942235129220144, 38.632293360573904, 38.129341057368684, 36.30539376395089, 36.327721800122944, 38.949628012520925, 37.274354798453196, 36.988276617867605, 38.94250610896519, 37.99393456322806, 36.9356301171439, 37.72594601767403, 40.75211926868984, 46.14441122327532, 50.60596765790667, 52.61482041222708, 50.873348236083984, 50.67484515053885, 48.475365093776155, 45.96946253095354, 44.909546102796284, 49.46480246952602, 48.223993165152415, 48.561494963509695, 50.86206783567156, 52.41658483232771, 50.86538907459804, 48.18134164810181, 48.397597381046836, 45.13511937005179, 48.56219673156738, 48.296667848314556, 46.3668578011649, 50.30939074925014, 48.33472660609654, 46.25419970921108, 38.30961554391043, 48.49622706004551, 58.364631925310405, 57.64811979021345, 61.3493834904262, 57.218248639787944, 61.840266772678916, 58.65943704332624, 59.78749792916434, 57.68126269749233, 66.55064514705113, 64.82942349570138, 58.60496316637312, 8.622278451919556, 0.41175901517271996, 2.368574023246765, 1.419473437326295, 0.4767028231705938, 9.620319434574672, 72.24899482727051, 68.06864588601249, 66.86452307019914, 75.39119952065604, 47.827261447906494, 74.62912804739815, 46.42313820975167, 22.01305522237505, 62.105694907052175, 72.06956454685756, 16.934158291135514, 1.0584245196410587, 0.15604090690612793, 0.21645444871059485, 0.11196217965334654, 0.3359167134123189, 0.18634626216122083, 0.20214349377368176, 0.16247808720384324, 0.1471372518156256, 0.220956596412829, 4.3488258208547315, 79.47710854666573, 61.56434685843331, 52.44111197335379, 35.372445242745535, 74.36741025107247, 63.35120814187186, 52.445840222494944, 69.77574184962681, 70.42130592891148, 62.214871951511924, 62.19005993434361, 1.8443472044808524, 0.4750463292002678, 4.216886477810996, 5.036991477012634, 6.989744475909641, 6.207511067390442, 1.1418707562344415, 9.584279128483363, 67.11127444675991, 56.18472146987915, 62.83055877685547, 56.20794234957014, 58.17701319285801, 51.78170708247593, 54.95646756035941, 51.67267942428589, 52.763619559151785, 53.51095042909895, 53.25738634381975, 52.37497901916504, 54.6058475630624, 54.149934564317974, 47.561909743717735, 41.78586530685425, 44.8352872303554, 51.21790245601109, 46.586552892412456, 47.30467006138393, 46.435012681143625, 42.20177752631051, 47.90783623286656, 44.546523571014404, 47.83007199423653, 47.52454580579485, 44.93699843542916, 38.915790285382954, 43.08579683303833, 43.71989985874721, 47.998586654663086, 52.17597566332136, 54.58915799004691, 48.1746574810573, 41.78995432172503, 37.78852496828352, 37.61377082552229, 38.40681389399937, 34.919916016714915, 39.037533146994456, 36.641068186078755, 37.520334924970356, 38.79943922587803, 38.505269868033274, 41.46658863340105, 42.687870025634766, 42.74869803019932, 44.136183806828086, 41.24137667247227, 45.97829369136265, 45.74073478153774, 46.267804282052175, 44.48520571844918, 47.91570506777082, 50.63587965284075, 51.804855006081716, 50.81397587912423, 45.842748233250205, 41.08791528429304, 39.78177554266793, 38.67025484357561, 39.03905132838658, 41.776050976344514, 37.60619034085955, 39.73743561335972, 45.32291875566755, 36.25645760127476, 37.61159603936331, 35.79548978805542, 40.748075417109895, 47.77091155733381, 47.08711848940168, 47.59487894603184, 51.3850656918117, 48.85954141616821, 45.22230189187186, 43.29498277391706, 44.539165428706575, 44.37792553220476, 43.61247376033238, 41.85512842450823, 40.17181267057146, 39.480869906289236, 35.96641547339303, 39.3694555418832, 41.27395330156599, 38.862014702388215, 38.54984951019287, 39.651361329214915, 40.125096457345144, 38.48126036780221, 39.860130378178184, 43.127812589917866, 48.03452621187483, 54.26683105741228, 55.384007590157644, 52.963651248386924, 50.37844542094639, 51.7388471194676, 47.33701739992414, 47.86804737363543, 49.6766426222665, 48.70581252234322, 49.798972606658936, 53.244625977107454, 53.941978454589844, 51.41937937055315, 49.646008014678955, 50.47132199151175, 47.2807856287275, 49.75335768290928, 49.30599791663033, 46.676462582179475, 49.48173870359148, 49.09540843963623, 44.86473369598389, 42.00823198046003, 52.10855381829398, 61.40357249123709, 59.97634996686663, 63.772282872881206, 61.701552936008994, 63.966116768973215, 61.99012551988874, 61.91465418679373, 59.56482206072126, 66.7939224243164, 66.8344373703003, 62.634063720703125, 10.237811923027039, 0.7049991328801427, 3.718784885747092, 2.5859325655869076, 0.7102468141487667, 11.540514043399266, 79.00546482631138, 71.90098040444511, 72.38001700810024, 82.57944447653634, 57.089279651641846, 80.87911605834961, 50.738358633858816, 28.620745182037354, 71.26330253056118, 84.68129539489746, 24.549894639423915, 1.3962837159633636, 0.5651379749178886, 0.37840502922024044, 0.17465367886636937], [0.03214495868555137, 0.0652938506432942, 0.05848111478345735, 0.07447995272065912, 0.05603590188547969, 0.04673004176999841, 2.2325235179492404, 56.42427798679897, 49.716917855399, 32.40799978801182, 36.14098201479231, 90.05692904336112, 73.6120993750436, 40.669519083840505, 52.97352811268398, 63.499927384512766, 49.61239262989589, 60.23457281930106, 5.470736248152597, 0.2575255627078669, 0.8624220799122537, 0.3250025590615613, 0.9867377834660667, 1.8185031626905714, 0.2060730664857796, 2.9851849590029036, 58.71532140459333, 54.206822940281455, 57.762257848467144, 53.032924788338796, 53.155171394348145, 45.62395640781948, 51.33523668561663, 49.6229886327471, 48.78117963245937, 50.27563292639596, 52.13183723177229, 52.68465328216553, 46.20463820866176, 36.06886666161673, 37.51629454748971, 48.502754892621724, 54.8132825578962, 47.07370499202183, 46.50622476850237, 38.20091792515346, 49.11411993844168, 53.03497798102242, 42.19934565680367, 43.393271991184776, 40.6993442262922, 42.7025203023638, 42.261844703129356, 43.560661043439595, 26.486612933022634, 35.927484716687886, 51.83380120141165, 47.98260579790388, 48.267256123679026, 40.70741803305489, 38.40519496372768, 33.980932985033306, 33.14001682826451, 34.91882862363543, 32.82303653444563, 33.42385768890381, 36.11294255937849, 33.066810607910156, 33.29601430892944, 33.589895316532676, 34.15438781465803, 36.550908361162456, 39.52693993704659, 40.882397992270334, 40.79097359521048, 42.121143681662424, 41.99376583099365, 44.004015173230854, 42.34793635777065, 41.38552747453962, 43.91571051733834, 48.701400416237966, 47.947767530168804, 42.14211334500994, 39.04907757895333, 33.71096420288086, 33.31953396115984, 37.501981258392334, 37.330444131578716, 37.2884909084865, 35.97997835704258, 37.104658944266184, 35.54789073126656, 34.99419920785086, 31.579180444989884, 40.322515623910085, 42.1858036177499, 44.88926431110927, 44.343573638371055, 45.58937522343227, 41.739222049713135, 42.33122246606009, 39.98497561046055, 40.90174872534615, 38.80316693442208, 39.80843578066145, 37.057564054216655, 36.9191073008946, 36.23205552782331, 34.187207630702424, 32.52102960859026, 35.55717352458409, 35.79744570595877, 33.975555079323904, 35.454621587480815, 35.75463090624128, 36.18312978744507, 35.88241522652762, 37.17522484915597, 42.73296730858939, 48.08462619781494, 51.70647198813302, 50.59128958838326, 49.045892102377756, 48.845179489680696, 47.32343019757952, 42.99285772868565, 45.84612853186471, 51.09190729686192, 51.08132519040789, 49.60464538846697, 53.62679427010672, 52.5235002381461, 51.74078219277518, 44.93834638595581, 39.62579543249947, 45.19546447481428, 47.94966786248343, 46.32571751730782, 44.742560046059744, 44.544730935777935, 44.09412636075701, 54.61144781112671, 51.610024043491904, 49.34788860593523, 54.031940255846294, 57.70476150512695, 56.4161034311567, 57.32962826320103, 56.699767112731934, 56.15644577571324, 53.42218371800014, 55.82603461401803, 63.09063679831368, 46.719065461839946, 4.56934210232326, 0.24663279578089714, 1.172715004001345, 0.6833870325769696, 0.25529684658561436, 12.589427130562918, 70.9212566103254, 58.58452156611851, 69.26231861114502, 59.90649972643171, 53.57722234725952, 27.750674383980886, 15.592511517660958, 25.326876946857997, 49.30211387361799, 65.67592947823661, 12.084032535552979, 0.7803672743695123, 0.049028460402041674, 0.12442445914660182, 0.048531121374773126, 0.08642987042133297, 0.09313083799289805, 0.031188088602253368, 0.05641009698488882, 0.09798136592975684, 0.054949618210749965, 2.969135705913816, 68.0663321358817, 54.410064697265625, 40.89056559971401, 39.031880787440706, 89.19740908486503, 76.30449853624616, 45.51519972937447, 57.320380210876465, 68.00512545449394, 54.92067044121878, 65.87452983856201, 6.156926444598606, 0.3822041196482522, 0.2913146253143038, 2.1964104729039327, 1.4415813024554933, 4.329867226736886, 0.6894855967589787, 3.9785276566232954, 60.182614190237864, 56.60770000730242, 59.59874316624233, 56.12798595428467, 55.35526984078543, 47.90310798372541, 54.21777677536011, 51.242116928100586, 51.54491247449602, 50.36912093843733, 52.7171847479684, 53.044587339673726, 47.950400897434776, 38.62808275222778, 39.77485861097063, 47.184869221278596, 52.08881746019636, 45.11840895244053, 46.39351803915841, 40.088215419224326, 53.02958965301514, 51.21531425203596, 43.210954734257285, 44.75306919642857, 42.49228170939854, 43.272929191589355, 42.818221705300466, 44.600410325186594, 30.474076407296316, 41.95308065414429, 53.269754137311665, 49.206082820892334, 47.77504226139614, 41.472088132585796, 39.90350798198155, 35.31936795370919, 34.79821831839425, 34.65328931808472, 35.33945172173636, 33.4760490826198, 37.201061725616455, 35.75643048967634, 35.46993889127459, 35.96296221869332, 35.784793036324636, 38.06834977013724, 41.10924277986799, 42.75533703395298, 41.42378078188215, 42.78533935546875, 43.77775403431484, 44.64883579526629, 44.73646647589547, 45.16405166898455, 46.632018429892405, 51.19821126120431, 48.559573786599294, 41.82469878877912, 40.7851162637983, 35.6902836390904, 36.02928972244263, 39.35472536087036, 37.40114900044033, 38.454548018319265, 36.97243472508022, 38.69900301524571, 36.73852709361485, 35.79898125784737, 33.55502578190395, 39.7924028124128, 44.04367896488735, 45.50743859154837, 45.60235793249947, 47.48218263898577, 43.854677540915354, 42.40797921589443, 42.05445834568569, 42.991895403180806, 40.31984404155186, 42.020617144448416, 40.22257273537772, 38.18157066617693, 36.493196623665945, 37.01019818442208, 34.46564279283796, 36.420049462999614, 36.476826667785645, 35.684676442827495, 38.43967192513602, 37.7982941355024, 39.172762462071006, 36.43816689082554, 37.5923946925572, 43.481691292354036, 49.354812485831125, 53.22195053100586, 52.402028356279644, 51.6789744922093, 51.25890030179705, 48.49164819717407, 44.39889172145298, 48.2441394669669, 52.415945598057334, 53.410642760140554, 51.72352286747524, 53.45373201370239, 54.45818097250802, 52.36482770102364, 46.43292474746704, 42.60134063448225, 46.93754809243338, 47.872605391911094, 47.576584339141846, 45.60533176149641, 47.60138940811157, 46.52071871076311, 55.91926554271153, 51.58399261747088, 51.321607794080464, 56.96473666599819, 59.27242796761649, 58.20259646006993, 59.716612407139365, 60.35442229679653, 59.826324462890625, 56.20683411189488, 57.95979166030884, 64.91205842154366, 51.02267892020089, 4.471827609198434, 0.21660494777773107, 3.8304398315293446, 1.137424451964242, 0.5896881861346108, 14.111961569104876, 75.42142418452671, 66.96584865025112, 73.95094912392753, 69.03554330553327, 56.731496061597554, 49.277353967939106, 26.792267663138254, 25.403935943331035, 58.06079762322562, 73.3478524344308, 17.297538655144827, 0.9483993606907981, 0.1700898659016405, 0.19747385648744448, 0.0639653740716832, 0.21756354133997644, 0.16785751283168793, 0.2842033611876624, 0.26241739307131084, 0.3932830494429384, 0.190651783985751, 3.730362755911691, 81.29348577771867, 63.14936992100307, 45.448573453085764, 47.94699975422451, 96.96302155085972, 77.07665879385812, 55.73474918093, 63.03958143506731, 73.93894958496094, 59.16871220724923, 75.45050239562988, 7.32330230304173, 0.5405606765832219, 2.1752655846732, 2.235885360411235, 6.605513870716095, 8.373250671795436, 1.3348291793039866, 5.237861292702811, 63.55804211752755, 57.879473958696636, 63.00736263820103, 58.75334194728306, 59.45659691946847, 49.95905910219465, 56.80522339684622, 53.33378873552595, 54.19269377844674, 53.27770982469831, 56.24500751495361, 54.3300770350865, 48.553476742335725, 40.716871057237896, 42.851302078792024, 49.39952066966465, 50.83633518218994, 47.6086676461356, 49.52958747318813, 45.96789918627058, 56.33107137680054, 49.51182092939104, 46.64680767059326, 46.86010694503784, 43.90144239153181, 45.936726093292236, 43.58088377543858, 44.123242786952424, 32.671621390751426, 37.32553175517491, 54.29992880140032, 52.40212563105992, 51.24855095999581, 44.196244035448345, 42.23149149758475, 37.267597675323486, 35.94414302280971, 38.30657223292759, 36.802940368652344, 36.104476179395405, 39.31275824138096, 36.471323694501606, 35.98404305321829, 36.38492979322161, 38.463869026729036, 39.814640522003174, 42.85090603147234, 45.41360316957746, 44.93381616047451, 44.75317341940743, 47.33649975912911, 49.032402174813406, 47.07881539208548, 45.98399816240583, 48.61518716812134, 52.78717395237514, 51.40991244997297, 44.98032392774309, 42.69798312868391, 39.95292009626116, 38.431212493351524, 41.15708807536534, 38.10123906816755, 41.607463359832764, 39.69083751950945, 42.0914922441755, 37.835154329027446, 37.64807755606515, 33.827770369393484, 41.72404718399048, 45.44117709568569, 47.55512482779366, 47.66192558833531, 49.26281138828823, 47.55817856107439, 45.40409108570644, 41.950996194567, 44.02581862040928, 42.32979808534895, 44.72033623286656, 42.0135612487793, 40.33144405909947, 39.5482292175293, 38.10029411315918, 35.78616530554635, 39.4780524117606, 39.23381628308977, 35.390597411564414, 40.408499581473215, 40.42555740901402, 40.19660036904471, 38.627457414354595, 40.58313907895769, 46.7681371143886, 52.72526897702898, 56.37070737566267, 54.67659412111555, 53.39281368255615, 54.09187194279262, 51.1406489099775, 46.02843189239502, 49.22931064878191, 55.07249205453055, 55.048930713108604, 53.6391863822937, 57.042379311152864, 55.72204439980643, 55.19555854797363, 46.45502001898629, 45.252682890210835, 45.96764210292271, 49.14896168027605, 49.14222540174212, 47.09697798320225, 51.751961844308035, 50.10717732565743, 56.77410936355591, 54.13127865110125, 51.71014758518764, 58.951594897678916, 61.4457619530814, 62.003813471112935, 62.39239842551095, 62.10586861201695, 60.31615856715611, 56.17549426215035, 59.93357685634068, 64.85867541176933, 52.379717690604075, 5.646401039191654, 0.35862038657069206, 3.3437495699950626, 2.5190281442233493, 0.622982922409262, 16.499171529497417, 82.63768427712577, 70.48165103367397, 82.12001568930489, 70.85590880257743, 69.25967829568046, 39.432058811187744, 24.50543659073966, 39.799649783543174, 65.24712140219552, 85.7178624016898, 25.815555913107737, 1.29485456432615, 0.3038819081016949, 0.34245062566229273, 0.21139155966894968], [0.10833489429205656, 0.09757590732936348, 0.02904977709321039, 0.08377742953598499, 0.10884365984903914, 0.027704023323687058, 2.4444151307855333, 60.22430338178362, 50.419693401881624, 27.501124620437622, 20.82018675122942, 81.58557415008545, 70.00254494803292, 45.05733776092529, 47.267945357731406, 64.11459282466343, 50.0293470791408, 60.05766473497663, 9.794256295476641, 0.4158464287008558, 0.44340444994824274, 2.1971333026885986, 2.343599157673972, 4.429003255707877, 0.42120061282600674, 1.8136003400598253, 51.4394075529916, 53.71906287329537, 57.09851033346993, 52.21586527143206, 52.71923794065203, 49.69600377764021, 50.004698344639365, 49.98511137281145, 53.38398252214704, 53.2940102985927, 50.522700445992605, 42.17520066670009, 42.0177857535226, 50.04427180971418, 58.49707153865269, 52.634494236537385, 48.37078080858503, 50.29553951535906, 53.08124603543963, 50.026335035051616, 35.798606055123464, 46.9210843358721, 50.37784787586757, 47.205130168369834, 46.15897812162127, 43.770993437085835, 38.916057791028706, 31.816457952771867, 39.319313866751536, 37.51674618039812, 49.890091282980784, 48.162011759621755, 41.82603631700788, 39.05232586179461, 36.602950368608745, 33.56366239275251, 35.90641777856009, 32.005372524261475, 34.209375858306885, 35.93086501530239, 36.956172466278076, 33.78696359906878, 34.448682240077424, 33.76587929044451, 35.10338320050921, 35.297189303806846, 39.098475796835764, 40.073808329445974, 40.49561609540667, 39.89982196262905, 43.30447053909302, 41.59345579147339, 41.890418325151714, 40.99388531276158, 44.32522691999163, 45.493834018707275, 49.54194484438215, 44.63828148160662, 39.520783833095, 35.97649383544922, 32.82899808883667, 37.88920783996582, 39.63234758377075, 33.75428622109549, 38.09762947899954, 36.90064593723842, 35.85903453826904, 33.67445141928536, 36.07891375677926, 42.011803354535786, 45.02917323793684, 46.35052606037685, 45.20831516810826, 44.662416049412315, 42.7209677696228, 42.540623801095144, 42.052137647356304, 39.14822489874703, 39.97214923586164, 38.123167582920615, 36.68453959056309, 37.48793200084141, 34.68310751233782, 34.75392355237688, 32.377723012651714, 32.12328345435006, 35.06398344039917, 35.674170766557964, 33.348247391836985, 33.38102899278913, 36.74441221782139, 36.36455767495291, 36.50140939440046, 38.78675181525094, 43.55736064910889, 49.22432879039219, 50.47345508847918, 50.33580780029297, 48.68173701422555, 49.7661771093096, 45.33161442620413, 43.78809642791748, 45.28108712605068, 44.17511803763253, 48.6810109274728, 52.11642612729754, 48.229388441358296, 53.2198417527335, 50.96090248652867, 41.26504571097237, 52.610338824135916, 50.967451163700645, 53.69391734259469, 55.66608360835484, 58.5803804397583, 56.03200353894915, 52.41667863300869, 53.86608328138079, 55.60997690473284, 51.317629950387136, 53.42097473144531, 54.95358058384487, 52.74758659090315, 55.30337027141026, 56.64386885506766, 55.127414090292795, 49.16611678259713, 61.021421568734304, 38.69861044202532, 0.6113621688314846, 0.15259434256170476, 2.3094674348831177, 1.070768103003502, 0.2854036082114492, 23.378497838974, 69.51494121551514, 57.71784496307373, 66.97490215301514, 60.823377064296174, 53.69862822123936, 31.610374382564, 22.51258553777422, 34.26135533196585, 50.345938273838584, 61.819387435913086, 9.653149672916957, 0.4803816229104996, 0.0699688619268792, 0.16218064459306852, 0.020627654556717192, 0.07702673891825335, 0.029268475715070963, 0.0929852786606976, 0.05670618252562625, 0.03998311023627009, 0.07324123954666512, 3.859147616795131, 67.43152386801583, 57.62282139914376, 31.732037339891704, 29.818732738494873, 96.52007389068604, 73.3466156550816, 51.77405364172799, 54.132195813315256, 69.21754441942487, 54.930554253714426, 66.41264002663749, 10.659072518348694, 0.44142828455993105, 0.6746581952486719, 1.1316183635166712, 2.3674805504935126, 2.957773664167949, 0.6202919068081039, 2.6710071776594435, 54.12213829585484, 54.64764097758702, 58.47947869982038, 53.985602719443186, 55.765953540802, 51.14669384275164, 52.02470990589687, 51.95765284129551, 55.07448271342686, 53.65914855684553, 53.555745465414866, 44.00064877101353, 43.33900656018938, 48.83915192740304, 59.68655450003487, 53.483491148267476, 51.00187601361956, 51.10494906561715, 53.483206272125244, 50.50967604773385, 40.19483552660261, 51.09712886810303, 50.55889708655221, 47.39148432867867, 47.573127610342844, 45.18212740761893, 40.80462680544172, 34.922205448150635, 43.98254871368408, 41.48185729980469, 50.30668095179966, 49.22275849751064, 43.76419115066528, 42.09239550999233, 38.8238308770316, 33.806693008967805, 37.55322422300066, 33.60438925879342, 35.49166938236782, 37.8699300629752, 37.88168641499111, 36.54940755026681, 36.99044792992728, 33.79761518750872, 37.47061014175415, 36.57760681424822, 40.10087503705706, 41.79622507095337, 42.28728205817086, 43.46187155587332, 43.9956773349217, 43.54963077817644, 44.52014126096453, 42.96265738351004, 45.76140219824654, 48.30235842296055, 50.39049359730312, 44.629867213112966, 40.37511696134295, 38.27154288973127, 34.84611572538103, 39.95389979226248, 39.602869851248606, 36.5076037134443, 39.9770998273577, 37.40965706961495, 36.16039180755615, 33.5081775529044, 35.12498862402779, 43.43871668406895, 47.936945710863384, 47.57063668114798, 48.12624938147408, 46.7959611756461, 44.08997481209891, 45.71911546162197, 45.636077540261404, 42.61132172175816, 41.74309914452689, 41.17534099306379, 39.31592314583914, 39.55886690957205, 36.38169888087681, 35.83515010561262, 34.12103646142142, 34.23717907496861, 35.64021839414324, 36.065191064562114, 35.382787636348176, 34.70657505307879, 36.0465212549482, 36.71300983428955, 38.21377209254673, 40.10104874202183, 46.206319672720774, 50.719998019082205, 52.013658796037944, 51.436610903058735, 49.044860294886995, 51.472557408469065, 48.144971302577424, 45.68837315695626, 46.02469028745379, 48.258070605141775, 49.625427450452534, 54.229658194950645, 51.84812143870762, 54.8145158631461, 50.88644906452724, 42.466500418526785, 51.08895083836147, 53.811970710754395, 54.66929851259504, 57.77353824887957, 59.771023750305176, 58.410288538251606, 55.270088400159565, 54.857261180877686, 57.53482941218785, 54.14711706978934, 55.57012203761509, 57.229285853249685, 57.19194275992257, 58.856084959847585, 59.525272914341514, 57.56669732502529, 54.25708620888846, 63.912031991141184, 45.00198493685041, 1.0706024318933487, 0.22067927915070737, 4.75062016929899, 1.4653335022074836, 0.28576735726424624, 26.040444782802037, 77.13291835784912, 62.35192516871861, 73.69883373805455, 67.09432084219796, 60.965203693934846, 34.848217555454795, 16.346153088978358, 39.157490321568076, 55.11371224267142, 76.23116030011857, 13.477800352232796, 0.6825020600642476, 0.04958322724061353, 0.13245775736868382, 0.017267903678917458, 0.24349443561264447, 0.17870525217482022, 0.18563050271144935, 0.22567389399877616, 0.2616641920592104, 0.1599832767886775, 4.699741985116686, 81.30689580099923, 63.76457732064383, 40.829918248312815, 30.402569021497452, 89.44315297263009, 73.61264133453369, 57.80353709629604, 60.01923424857003, 73.27970450265067, 60.31160749707903, 73.22654383523124, 13.109424233436584, 0.5826925443751472, 4.034112811088562, 4.156616934708186, 9.571701151984078, 11.33974323953901, 1.1968632510730197, 3.9216058424540927, 58.01271261487688, 56.15872825895037, 61.33366666521345, 57.10371800831386, 56.083573068891255, 52.64096300942557, 55.49419559751238, 55.39532273156302, 56.86817060198103, 54.14363602229527, 53.885229042598176, 47.325108187539236, 46.63218171255929, 50.94591869626726, 58.69135706765311, 52.890104566301616, 54.495465006147114, 53.95441920416695, 57.65252494812012, 52.544841630118235, 46.995322363717214, 54.0121031488691, 48.06642539160592, 47.63791608810425, 48.279999119894846, 46.49005283628191, 43.22480249404907, 37.97759240014212, 37.93818916593279, 42.04166323798043, 55.318913391658235, 50.415288243974956, 45.54435089656285, 44.39592831475394, 39.043004853384836, 35.83949967793056, 40.04285757882254, 36.86790949957711, 36.94548266274588, 39.71922091075352, 39.95643588474819, 38.1268744468689, 37.65723875590733, 37.55283512387957, 39.220378467014854, 38.24004670551845, 44.34104101998465, 43.278185503823416, 45.56969097682408, 46.070735999516074, 46.89327417101179, 46.471157210213796, 46.816711970738, 46.00012493133545, 49.14267703465053, 50.12564216341291, 52.6248779296875, 46.89927394049508, 42.17563840321132, 41.17325305938721, 38.5955617087228, 40.99523326328823, 43.5350604057312, 36.519453866141184, 41.79795169830322, 38.76265198843819, 37.97231871741158, 34.80587523324149, 38.768269606998985, 44.426736627306255, 48.37587036405291, 50.94416080202375, 50.657321793692454, 49.422751971653526, 47.11429984228951, 48.6480347769601, 49.092135838099885, 46.25801427023751, 44.07267379760742, 43.131807804107666, 42.21943289893014, 43.18298476082938, 38.164860248565674, 38.138818400246755, 35.94589744295393, 35.47318022591727, 38.75163909367153, 38.753744397844585, 37.27475779397147, 37.34754364831107, 39.02797589983259, 38.98911115101406, 40.65734583990914, 40.71476922716413, 47.955820492335725, 52.629272665296284, 54.43712098257882, 53.12189299719674, 51.75204174859183, 54.053927830287385, 49.13456153869629, 47.82616710662842, 48.85613679885864, 49.64664377485003, 53.26012045996529, 58.263341086251394, 53.24300009863717, 56.41455398287092, 53.93288326263428, 44.96106699534825, 54.3030937058585, 54.120394298008506, 55.59358957835606, 59.39521653311593, 64.0050961630685, 59.65726089477539, 57.78011819294521, 57.601921217782156, 60.0593045098441, 55.556916986192974, 58.198100975581575, 61.24268000466483, 60.50412123543875, 63.04326398032052, 64.79473808833531, 57.106104714529856, 55.04123558316912, 66.47772380283901, 47.030514989580425, 1.6880064393792833, 0.44025778451136177, 6.516563466617039, 4.596628546714783, 0.6556657829454967, 29.85478346688407, 80.0255993434361, 68.0438060760498, 79.13764040810722, 73.56596333639962, 67.44383607591901, 44.37479884283883, 32.071324825286865, 50.863999434879844, 64.4000804083688, 87.75782571520124, 18.24582358769008, 0.8206193830285753, 0.2985616778688771, 0.3169089933591229, 0.20957573210554464], [0.07027693718139615, 0.12036618191216673, 0.1416383497416973, 0.017961023807791725, 0.05031440979135888, 0.05791949813387223, 1.3907076780285155, 54.10162026541573, 51.31069564819336, 39.3148809160505, 29.579544476100377, 47.900339126586914, 52.44921704701015, 44.35304403305054, 47.97557769502912, 63.749617849077495, 51.319189820970806, 63.04259695325579, 20.36508321762085, 0.32133469730615616, 0.10876110249332019, 2.4080311059951782, 0.4815073939306395, 2.778513614620481, 0.2877113058098725, 2.791368216276169, 57.98466273716518, 52.747617857796804, 56.618963037218364, 52.86079706464495, 53.59192820957729, 50.07729312351772, 55.06483861378261, 55.096216678619385, 49.1703690801348, 44.03844697134835, 47.86182178769793, 54.872394357408794, 60.57996777125767, 56.912475790296284, 48.386647020067485, 48.68109777995518, 49.486585072108674, 51.46012360709054, 50.216215406145366, 49.91331216267177, 47.98560047149658, 39.63249002184187, 43.50799022402082, 46.50849682944161, 45.12806347438267, 45.407780579158235, 43.091341495513916, 58.3874637058803, 40.01605142865862, 37.04929222379412, 52.63530717577253, 45.28188269478934, 40.799877711704795, 35.433714457920615, 35.88621589115688, 30.96997628893171, 36.33885628836495, 32.82963037490845, 39.285938194819856, 36.42289127622332, 36.02891799381801, 32.09503902707781, 33.2379412651062, 32.303172315870015, 34.88029391424996, 35.41550670351301, 38.14909826006208, 39.69413096564156, 38.796131883348735, 41.046768052237375, 41.43970605305263, 40.02039057867867, 40.923437527247835, 40.51820816312517, 42.38788849966866, 44.2695301600865, 47.56389345441546, 46.256315435682026, 42.67070797511509, 37.48821687698364, 32.95422894614083, 36.76188693727766, 37.118774209703716, 36.2961630821228, 39.82005664280483, 36.21576547622681, 35.840392521449495, 33.86827836717878, 39.05596671785627, 44.90280982426235, 46.0618805204119, 43.24120371682303, 44.316750117710654, 43.92702913284302, 39.608185223170686, 40.13346208844866, 39.66272858210972, 41.14509201049805, 38.15610204424177, 38.67391654423305, 37.66973509107317, 37.689426285879954, 34.58682632446289, 34.91186652864729, 33.99471473693848, 32.8077609198434, 33.3534585407802, 34.243668692452566, 35.66777147565569, 34.27081877844674, 35.13759960447039, 36.94279718399048, 34.60644456318447, 38.87741885866438, 40.071108954293386, 47.64029237202236, 49.54917097091675, 51.18519728524344, 49.49297046661377, 50.30979374476841, 49.19241224016462, 47.81724214553833, 46.17669950212751, 46.9433012008667, 44.00498792103359, 47.001464571271626, 47.071349552699495, 51.47635459899902, 48.89050258908953, 45.83789144243513, 51.097083704812185, 53.50247015271868, 52.48197085516793, 52.2487337248666, 49.726888520377024, 50.88885661533901, 50.77788346154349, 53.59469011851719, 50.73750747953142, 55.8953081539699, 54.81510646002633, 56.23880624771118, 51.92263044629778, 53.66680894579206, 53.28904233660017, 56.446474007197786, 44.306102003370015, 52.20025961739676, 31.88232340131487, 0.07801851962826081, 0.10586611926555634, 4.611460779394422, 1.5205805833850587, 0.17001833473997457, 28.904843126024517, 68.74517113821847, 58.539608410426546, 60.529016630990164, 59.46188449859619, 54.01319054194859, 45.35521050861904, 44.681197030203684, 32.069334166390554, 52.813577107020784, 54.19742897578648, 5.148506156035832, 0.5116274005600384, 0.08779995476028749, 0.2111693937331438, 0.021003544297335402, 0.09464145371956484, 0.15398409084549972, 0.1025650328291314, 0.07238537618624312, 0.06791366756494556, 0.030794022604823112, 2.127339299236025, 65.70292322976249, 58.651224272591726, 41.04923118863787, 27.769665547779628, 67.61941010611397, 59.553211620875764, 49.30484104156494, 53.04710258756365, 70.53207411084855, 56.034727232796804, 67.45753792354039, 22.76645186969212, 0.32147550689322607, 0.3250504636338779, 1.6020275843994958, 3.4389199146202634, 4.251217092786517, 0.39065815029399736, 3.828528208392007, 58.0690347126552, 52.0103132384164, 58.99864115033831, 55.284974915640696, 55.44243846620832, 51.20919983727591, 57.11416115079607, 57.21701186043875, 53.27547597885132, 47.12129667827061, 49.23549107142857, 54.34193761008126, 57.764165128980366, 56.35412202562605, 49.90857349123274, 50.41819953918457, 52.754725864955354, 53.267103399549214, 51.21563039507185, 50.548717975616455, 49.15494407926287, 44.10102939605713, 46.316365242004395, 48.28957026345389, 46.43850762503487, 47.0205443246024, 42.973656381879536, 61.28261825016567, 44.79729100636074, 37.28529473713466, 53.47329466683524, 46.09883451461792, 42.133011204855784, 37.860091413770405, 38.216433252607075, 33.84172582626343, 38.00199099949428, 35.108587401253835, 40.480976240975515, 36.49464879717146, 36.13275882175991, 34.82556990214756, 34.97846501214163, 33.948332037244526, 35.89809036254883, 38.012333393096924, 38.91669355119978, 39.95745032174246, 43.031038079942974, 42.66121326174055, 43.748224190303254, 41.040327072143555, 43.49898188454764, 42.53538485935756, 45.15837846483503, 45.695401259831016, 48.578250544411794, 46.62144674573626, 43.74575410570417, 38.15718248912266, 36.10273565564837, 39.30237068448748, 38.25321701594761, 36.9623806817191, 41.043954031808035, 37.48010832922799, 36.281894956316265, 34.563932010105674, 38.86845220838274, 45.533400535583496, 47.06190000261579, 45.62718732016427, 47.21231460571289, 45.05351972579956, 40.9319942338126, 41.67736223765782, 42.54074192047119, 43.202450139181956, 39.50593205860683, 42.623606136866975, 38.67300633021763, 39.30914865221296, 37.34843301773071, 36.22869259970528, 34.657618045806885, 34.52919796534947, 35.08802768162319, 35.37612778799874, 36.7925945009504, 35.90690762656075, 36.935855933598106, 37.88954830169678, 35.69271550859724, 39.5849643434797, 42.94613804136004, 49.50602960586548, 50.35834428242275, 53.11191538402012, 50.4543753351484, 52.42465516499111, 51.42907558168684, 50.194818428584504, 47.44879307065691, 47.9124950000218, 47.0547468321664, 49.26672669819423, 49.73968710218157, 54.167259897504536, 51.19405276434762, 47.29166650772095, 52.44014617374965, 53.21443952832903, 55.02588701248169, 53.89111416680472, 52.22356040137154, 53.20549719674246, 52.810978480747764, 55.25574731826782, 55.753436361040386, 57.666723591940745, 57.22720486777169, 59.16614832196917, 56.556707177843364, 56.608717918395996, 57.111875193459646, 57.49717364992414, 49.483757155282156, 53.7763785634722, 32.76280607495989, 0.06933452667934553, 0.08959223037319523, 3.78413964169366, 1.1945684999227524, 0.2303326204419136, 32.021322114127024, 72.90793418884277, 63.58340999058315, 67.58671188354492, 64.19435119628906, 63.626898765563965, 42.23612594604492, 29.970467499324254, 37.993177209581646, 57.94204943520682, 68.76020009177071, 8.072950397218976, 0.5565912563885961, 0.08441312185355596, 0.2111166444207941, 0.07322308873491627, 0.21498056208448751, 0.36296336352825165, 0.20561572031251021, 0.25955663514988764, 0.20772333150463446, 0.1819035541266203, 2.28088840842247, 75.77408695220947, 67.79882649012974, 52.549865177699495, 41.34298365456717, 57.756223337990896, 60.63303811209542, 57.864295618874685, 58.13867998123169, 76.07282475062779, 62.473886898585725, 76.0878814969744, 25.781530584607804, 0.5657458337289947, 1.1791112550667353, 6.937614747456141, 4.164203933307102, 9.135544487408229, 1.5333140258278166, 5.244140727179391, 59.788679122924805, 51.51792914526803, 61.36289773668562, 55.215753487178254, 57.371300084250315, 54.17208889552525, 58.930798939296174, 58.153048855917795, 54.977614402770996, 49.804399149758474, 52.14798484529768, 54.068772656576975, 58.1603444644383, 56.41887576239449, 51.07570062364851, 53.88827582768032, 53.88170978001186, 54.91369444983346, 54.06074748720442, 52.53214727129255, 52.11132614953177, 47.59767212186541, 51.18947390147618, 49.19423614229475, 49.225978987557546, 49.169528348105295, 44.662631443568635, 54.17237377166748, 44.4061039515904, 41.07635695593697, 55.74968433380127, 49.05494907924107, 43.76045649392264, 39.17649017061506, 39.68725572313581, 35.288288661411826, 41.258069719587056, 36.2965521812439, 42.47314984457833, 38.74998194830758, 39.03546953201294, 34.877427782331196, 36.467161723545615, 36.02745539801461, 39.3417843409947, 38.71957663127354, 42.00718975067139, 42.17922714778355, 45.647236347198486, 46.30061367579869, 45.71771887370518, 43.339506830487935, 45.80107293810163, 45.14629554748535, 47.634636538369314, 49.600764819553916, 51.1282776423863, 48.4239901133946, 45.2092844418117, 40.24951090131487, 40.129341806684224, 42.45215933663504, 39.55394063677107, 39.173172405787874, 44.786406653267996, 39.37147051947457, 37.523975781032014, 35.10995619637625, 41.31805351802281, 46.42168256214687, 50.10475935254778, 47.47518580300467, 48.14508247375488, 48.57870217732021, 43.00501707621983, 44.28635522297451, 43.95734759739467, 45.79372869219099, 41.55674498421805, 45.7140154838562, 42.73662206104824, 42.63229833330427, 39.781386443546836, 38.63689654214041, 36.953049251011436, 35.97043153217861, 36.33619512830462, 38.25870956693377, 39.961928435734336, 36.995276927948, 38.694385937282014, 39.55692488806588, 36.5099904196603, 42.77185637610299, 45.6279307774135, 52.10227959496634, 52.25162764957973, 54.45213603973389, 50.625954151153564, 53.649504457201274, 55.531260762895855, 51.897217409951345, 51.80296162196568, 50.711844308035715, 48.653815678187776, 51.034740992954795, 51.56662212099348, 54.65244565691267, 53.15691539219448, 48.52844933101109, 54.83599621909005, 56.70314046314785, 57.53531926018851, 55.48132405962263, 54.00778831754412, 56.29104280471802, 54.579322814941406, 57.00940316064017, 56.55333730152675, 58.92129380362374, 60.051334926060264, 59.34506443568638, 57.537726811000276, 59.08907195499965, 60.31638090951102, 62.001583099365234, 53.03855630329677, 58.98914296286446, 38.41507182802473, 0.28031646832823753, 0.21205119070197853, 10.94238531589508, 5.295616890702929, 0.6281531964029584, 35.62329258237566, 79.93669019426618, 69.21693297794887, 70.92336191449846, 71.83738354274205, 70.08753531319755, 62.57553904397147, 55.7345164162772, 48.172166551862446, 67.14659214019775, 80.48268658774239, 11.23582945551191, 0.913036395396505, 0.324739260332925, 0.4073068212185587, 0.1872105664972748], [0.032314952063773356, 0.06489515025168657, 0.04193696200049349, 0.04512380688850369, 0.044244130341602225, 0.11858843373400824, 0.635827861726284, 47.78534296580723, 55.519257749829976, 33.88669456754412, 17.18457136835371, 21.211874076298304, 38.617903641292024, 43.5486649785723, 56.94152273450579, 61.239386558532715, 54.380642550332205, 58.27694565909249, 27.82191947528294, 0.19229230524173804, 0.46041092595883776, 0.5451230374830109, 0.7352211911763463, 1.2321065770728248, 0.3276574765997273, 3.308116384914943, 64.09172630310059, 58.152388777051655, 53.09057746614729, 52.993743896484375, 56.79289034434727, 56.12026997974941, 50.2989684513637, 43.18629905155727, 48.31370483125959, 54.03064441680908, 58.6977424621582, 54.041983876909526, 50.06114550999233, 48.1914894921439, 49.251927035195486, 50.47407695225307, 48.040407861982075, 48.03618335723877, 49.23530694416591, 47.78325155803135, 48.25195966448103, 47.93659482683454, 45.431175163814, 45.95342261450631, 52.27094711576189, 52.420833655766074, 52.701877866472515, 39.660279342106406, 35.06160715648106, 50.962684699467246, 46.65575000217983, 44.94475262505667, 38.81128590447562, 40.5190349987575, 33.188310282570974, 34.27742304120745, 33.76700142451695, 37.03737258911133, 32.82715681621006, 33.885492529187886, 34.043661321912495, 34.62370041438511, 32.59874868392944, 33.56478105272566, 34.41137388774327, 35.87085689817156, 38.727737290518625, 38.96950680868966, 40.73575626100813, 41.41686732428414, 40.70838383265904, 41.99450581414359, 41.67958218710763, 42.40716280255999, 40.187713623046875, 44.07537317276001, 45.07197414125715, 45.33743354252407, 43.370693819863455, 37.12810216631208, 32.29659237180437, 35.09459720339094, 37.60183382034302, 35.64133358001709, 36.9367800440107, 37.067493030003135, 35.39536040169852, 35.430389744894846, 39.97697128568377, 43.88753209795271, 43.2163986478533, 45.13020699364798, 45.19593000411987, 41.43849359239851, 41.193823201315745, 42.91658387865339, 40.92306579862322, 39.70015505381993, 40.832190309252056, 39.91641078676496, 37.01565252031599, 38.02929047175816, 34.43188149588448, 31.741525105067662, 32.489328452519004, 33.19606099809919, 32.348808084215435, 32.065234729221885, 34.40560340881348, 34.4494708606175, 35.04104396275112, 36.328003202165874, 35.3314335005624, 37.240266936165945, 38.88632297515869, 42.67933068956648, 49.31207759039742, 49.58423505510603, 49.4316143989563, 50.9579564503261, 48.03163228716169, 49.03055395398821, 47.79675885609218, 47.90581430707659, 47.00446271896362, 49.11291790008545, 45.646760395595, 52.40287603650774, 47.42111839566912, 49.34859037399292, 51.82245479311262, 51.144428730010986, 50.240662642887656, 50.45617491858346, 52.222302777426584, 51.42799513680594, 50.4802747453962, 51.67547607421875, 52.986093929835725, 53.40147461209978, 53.37329966681344, 54.02191053118025, 53.245296478271484, 57.69749368940081, 53.95559344972883, 57.248855454581125, 44.197890758514404, 45.213029520852224, 22.677954401288712, 0.03892889751919678, 0.142270065844059, 5.347056141921452, 0.8621619024447033, 0.08604506642690726, 33.81977646691458, 65.55286298479352, 61.331568309238975, 58.02747753688267, 55.33891378130232, 50.241235869271414, 46.74640662329537, 44.27795137677874, 35.73637104034424, 52.66923175539289, 57.761333738054546, 2.578682771750859, 0.4642189730490957, 0.042984548823109696, 0.13037390847291264, 0.016719688095950654, 0.04498086330880012, 0.08951447704540831, 0.02585663540022714, 0.11253050701426608, 0.008027942036278546, 0.07033497906689133, 0.9311198421886989, 56.96555655343192, 60.52671677725655, 40.026619638715474, 24.584435871669225, 31.160315241132462, 40.22803749356951, 50.99724503925869, 59.10816560472761, 68.04267351967948, 59.33499649592808, 65.07001876831055, 28.55885410308838, 0.16124423912593297, 0.5513723992875644, 1.0389433992760522, 3.1254994869232178, 0.9953552867685045, 0.24865436873265676, 4.141223634992327, 67.77951049804688, 57.924081393650596, 56.077938079833984, 55.12659420285906, 58.59082358224051, 57.532658100128174, 52.92005130222866, 46.220535687037874, 50.503474780491416, 55.104061194828574, 58.00823450088501, 54.52308062144688, 52.52418116160801, 50.93539217540196, 50.97991623197283, 51.444507530757356, 50.65876007080078, 49.951423031943186, 51.1222813470023, 49.38924428394863, 50.54043919699532, 48.51857941491263, 47.529531138283865, 48.17110695157732, 51.842295374189106, 50.772126879010884, 53.14100054332188, 42.169979095458984, 38.151422432490754, 51.17105075291225, 48.61074726922171, 47.47561659131731, 40.654358114515034, 40.491231782095774, 35.66342885153634, 36.15846020834786, 35.41495779582432, 37.43945094517299, 34.54780871527535, 34.33296346664429, 36.51613957541329, 36.6530955178397, 34.535757064819336, 34.82256828035627, 35.577160017830984, 37.073367731911794, 39.426552363804404, 42.25641121183123, 43.24413585662842, 43.252494539533345, 43.177408831460134, 42.380096094948904, 42.41137341090611, 41.80944054467337, 42.524083614349365, 44.19806793757847, 46.342493942805696, 47.654463223048616, 44.53763335091727, 38.48490469796317, 35.90892260415213, 37.1004934992109, 38.56219298498971, 37.513153961726594, 38.4066401890346, 39.10561159678868, 35.473246233803884, 37.229042121342246, 41.87747035707746, 47.237203053065706, 47.32021318163191, 46.72447810854231, 45.689665521894185, 44.362330300467356, 43.10385520117623, 44.10199172156197, 43.351742608206614, 42.3693402835301, 43.52408920015608, 40.922572476523264, 39.28860630307879, 39.32442774091448, 35.60222911834717, 34.260038648332866, 33.62371219907488, 34.863791942596436, 33.23739930561611, 34.611516748155864, 35.594850131443565, 36.85447515760149, 36.163386481148855, 39.38566221509661, 36.61445311137608, 38.202780042375835, 40.67310782841274, 45.36741501944405, 51.7793481690543, 50.42610311508179, 52.21826587404524, 52.725091797964915, 49.943008763449534, 49.03190885271345, 49.92529433114188, 48.753425053187776, 48.05555146081107, 50.474233286721365, 47.4357374055045, 55.894668919699534, 50.18217270714896, 51.94665036882673, 53.70127895900181, 51.22616039003645, 52.797877652304514, 52.151799406324116, 53.87150982448033, 54.112942355019705, 51.69033827100481, 52.95719289779663, 54.759083134787424, 56.6761223929269, 55.981458868299214, 56.15489980152675, 56.06053631646292, 61.64038099561419, 58.34844262259347, 58.21530818939209, 47.57297474997384, 49.4084803717477, 23.605919327054703, 0.04229341680184007, 0.09492904400186879, 3.900832465716771, 0.2808533252349922, 0.11012053383248192, 38.62517840521676, 71.91851765768868, 67.04421738215855, 62.74854918888637, 58.76624475206648, 56.51254790169852, 48.132308210645405, 41.799393449510845, 43.32642684664045, 59.517685481480186, 68.63172789982387, 4.203251940863473, 0.5313115386026246, 0.03064519612650786, 0.1180415887917791, 0.03411221490906818, 0.26513639145663803, 0.29238508215972353, 0.17195608147553035, 0.2010763617498534, 0.14070507910634789, 0.2190022255693163, 1.0354070918900626, 68.55533245631626, 69.11769880567277, 49.373530932835166, 29.47500535420009, 33.06241239820208, 52.538091455187114, 56.067811080387656, 65.96471745627267, 72.29776423318046, 64.23910454341343, 69.53888470785958, 32.62924780164446, 0.4067714570888451, 1.9448177218437195, 3.5205994631562914, 5.352639888014112, 5.875899604388645, 1.0094150751829147, 6.725203973906381, 70.39673015049526, 57.42908477783203, 56.761432375226704, 57.867186069488525, 61.191958154950825, 57.736174310956685, 54.12027965273176, 48.52880021503994, 49.558505875723704, 54.77949694224766, 59.29273755209786, 55.8152232170105, 55.391984122140066, 54.64352764402117, 53.98253856386457, 52.46229703085763, 51.587654318128315, 52.90677329472133, 55.50925929205758, 51.1612468447004, 53.25447504861014, 49.88268797738211, 49.89404133387974, 50.127212456294465, 53.58483409881592, 50.77858870370047, 50.54708514894758, 43.14998776572091, 41.28226334708077, 53.58197144099644, 49.60989475250244, 51.11022274834769, 41.627307415008545, 44.90462677819388, 37.67736768722534, 36.70341089793614, 37.16668898718697, 38.15894733156477, 36.32560954775129, 35.95908859797886, 38.03456762858799, 39.61311149597168, 37.03536108561924, 36.46636962890625, 37.92228473935808, 38.59258787972586, 42.79158926010132, 45.51524141856602, 44.9891550881522, 45.782080037253245, 45.82324463980538, 46.33836671284267, 45.29296507154192, 44.991267340523855, 46.11220632280622, 49.24971750804356, 47.80688238143921, 49.150361742292134, 47.282487937382285, 40.396837030138286, 38.25901876177107, 40.18175554275513, 40.04362882886614, 37.82313394546509, 41.39519936697823, 41.33511829376221, 36.91420534678868, 38.42893695831299, 43.96582439967564, 49.02683319364275, 48.762044293539866, 48.18333578109741, 48.86272369112287, 48.69788462775094, 46.34569011415754, 48.86541959217617, 46.64455992834908, 44.046736172267366, 47.04876095908028, 43.183551039014546, 42.18973282405308, 42.558258329119, 36.56331784384591, 35.316338539123535, 35.788812569209504, 35.9818126814706, 34.838684626988, 36.412854603358674, 38.685256004333496, 37.658426897866384, 39.443162032536094, 40.26673201152256, 39.150031430380686, 39.908229282924104, 43.108611243111746, 46.82876014709473, 52.56947299412319, 51.98627247129168, 53.19757972444807, 54.46531677246094, 49.79728419440133, 52.5461722101484, 52.12662608282906, 51.03912878036499, 49.30432687486921, 50.730649607522146, 49.5080862726484, 56.85742521286011, 52.143676962171284, 55.02219751902989, 56.26247876031058, 54.00935861042568, 54.74232060568673, 54.00834764753069, 56.34692716598511, 55.22572415215628, 55.49174288340977, 55.04895155770438, 56.49078266961234, 58.24840245928083, 57.77548027038574, 60.6208370753697, 59.75853088923863, 64.4125176838466, 61.798195430210654, 61.12400477273123, 54.00885139192854, 57.00482777186802, 27.564546040126256, 0.17505491019359656, 0.42591493842857225, 10.428750157356262, 2.0270568174975256, 0.12490537762641907, 42.61033855165754, 78.01993233816964, 71.86381449018205, 69.23543603079659, 65.90964603424072, 62.912644795009065, 61.66658960069929, 58.23610067367554, 53.05643054417202, 68.6953456061227, 82.41811425345284, 6.894257988248553, 0.6531782735671315, 0.2297732090311391, 0.220910713874868, 0.14286397397518158], [0.040677964022117, 0.03668544361633914, 0.10544963447110993, 0.04094578179397753, 0.16495606995054654, 0.013198189736743058, 0.12728934256093843, 40.449563435145784, 61.64937891278948, 37.53623587744576, 29.586374555315288, 21.353947366986954, 27.079073667526245, 42.03614984239851, 52.193773474012104, 64.54388032640729, 53.974110398973735, 59.0644405909947, 32.762931142534526, 0.04483711566509945, 0.06597383772688252, 0.6434769598501069, 2.980504695858274, 1.3894593907254082, 0.19471771509519645, 7.320251175335475, 55.613506589617046, 49.368934699467246, 52.66884960447039, 50.93675054822649, 53.72542742320469, 44.679380076272146, 47.174175943647114, 53.33460167476109, 59.202563830784385, 53.74780409676688, 52.78345319202968, 47.8775177683149, 50.39267880575997, 49.09811476298741, 44.35136604309082, 45.391976901463096, 44.87826183864048, 45.120819977351594, 47.20873975753784, 46.3603959764753, 48.595589773995535, 46.859036922454834, 53.07461397988455, 48.397375038691926, 41.88911206381661, 36.39836760929653, 33.85667487553188, 39.59009906223842, 48.45879364013672, 48.663984366825645, 49.623600074223106, 40.802014282771516, 40.348842348371235, 37.57885960170201, 35.32120227813721, 35.64628069741385, 35.026178291865754, 35.19235140936715, 34.939020088740754, 34.249981130872456, 33.4701361656189, 33.7011707169669, 33.65864774159023, 34.589418002537315, 35.007605757032124, 36.074015276772634, 38.781794275556294, 40.01643010548183, 39.84775563648769, 40.16544812066214, 40.606749057769775, 40.58746085848127, 40.67749214172363, 42.60049990245274, 40.32286998203823, 43.21966082709176, 43.68129914147513, 45.37871279035296, 43.31497621536255, 36.54759407043457, 35.36743211746216, 36.18474871771676, 37.69664546421596, 36.064221790858674, 37.8779239654541, 36.088439737047466, 35.817779609135215, 41.09660748073033, 43.87890938350132, 44.311135973249165, 44.649822439466206, 45.458915846688406, 42.0144054549081, 39.635102544512065, 40.0440457207816, 40.15846170697893, 39.50153037479946, 40.72330508913313, 38.53086355754307, 39.46424634116036, 37.60457835878645, 34.71962029593331, 33.08629335675921, 33.24211365836007, 33.958243642534526, 33.45334931782314, 31.848127841949463, 34.4655350957598, 33.3061135155814, 35.214884417397634, 35.392185074942454, 37.42429344994681, 36.330956186567036, 36.3966201373509, 38.956333024161204, 39.06291839054653, 45.80452619280134, 46.67007718767439, 50.19862951551165, 50.385598591395784, 47.70059578759329, 49.55719614028931, 48.378722599574495, 52.12343338557652, 50.02627944946289, 52.60957104819161, 47.408653327396934, 48.76133557728359, 47.92614126205444, 48.24587304251534, 50.32892560958862, 49.43726675851004, 45.72887768064226, 45.686524936131065, 46.1036183493478, 50.76149613516671, 52.907923221588135, 51.77985191345215, 50.306340490068706, 52.22626672472273, 51.2530186516898, 56.42458718163626, 54.837528296879356, 56.039264406476704, 53.9527724811009, 54.709827354976106, 41.85750470842634, 44.08992270060948, 14.701174020767212, 0.31069999081747873, 0.10647948099566357, 1.2144347024815423, 0.1081880796700716, 0.1799138994621379, 44.80909252166748, 62.34920842306954, 61.14577347891671, 57.45811087744576, 58.677189690726145, 52.42154584612165, 37.36722789491926, 25.762678384780884, 33.96955530984061, 56.363731384277344, 53.09539604187012, 2.1298132921968187, 0.3155253247490951, 0.050070008262991905, 0.06942348262029034, 0.025961484327646236, 0.08075286647570984, 0.03984854995672192, 0.058019724541476796, 0.05434084677004388, 0.12954619074506418, 0.044959489455712695, 0.19376471266150475, 50.3185658454895, 68.7370000566755, 45.48944970539638, 29.320199489593506, 26.057976824896677, 40.603542464120046, 45.76440034593855, 58.305565289088655, 68.33214936937604, 58.530666078839985, 64.70631531306675, 37.59173113959176, 0.10712555489901986, 0.252944501382964, 0.6875948725002152, 4.480597538607461, 1.0115294988666261, 0.2120994616832052, 8.757816093308584, 63.16808836800711, 49.6728002684457, 55.199393953595845, 51.9571282523019, 55.790505000523154, 45.07916552679879, 50.31098536082676, 54.662492752075195, 59.665848868233816, 53.898527894701274, 56.12678739002773, 50.01546457835606, 52.948670932224815, 50.05852256502424, 48.007348333086284, 46.75228132520403, 47.570341382707866, 46.71304137366158, 47.93957212993077, 47.8937418120248, 49.53208882468087, 48.94566781180245, 51.208157607487266, 49.202146666390554, 44.34304557527815, 38.57167727606637, 37.22302845546177, 39.59209319523403, 49.262543882642476, 50.255309445517405, 51.83959947313581, 42.05934292929513, 41.88231325149536, 39.357702663966585, 36.95466470718384, 37.820823669433594, 36.88992486681257, 36.76421805790493, 36.262471267155235, 36.70334836414882, 34.57477119990757, 34.097374371119905, 34.66051197052002, 35.802524839128765, 35.75764989852905, 38.69605697904314, 39.967073576790945, 42.07253755841936, 41.92530175617763, 43.003658703395296, 42.75631325585501, 41.41065216064453, 42.88427128110613, 44.69027137756348, 43.24178736550467, 44.62983594621931, 47.37921033586775, 45.76410852159773, 45.426912443978445, 39.56524535587856, 36.91782188415527, 37.801212378910606, 38.61656263896397, 37.28745215279715, 39.86523730414254, 37.974663734436035, 37.136499064309255, 42.290999344417024, 44.803891795022146, 46.12596375601632, 46.66546010971069, 45.8131662777492, 44.94962331226894, 42.44173009055001, 42.6620192527771, 42.04827444893973, 42.876565728868755, 43.0718274797712, 41.43828167234148, 42.89345679964338, 39.602723939078196, 36.4478874206543, 33.96250983646938, 34.586590085710796, 35.24130146844046, 35.82585688999721, 34.0982255254473, 35.2745485986982, 33.650719846997944, 36.09635026114327, 36.990326336451936, 38.13765457698277, 36.29280015400478, 36.82436861310686, 40.18202652250017, 41.743286745888845, 47.339136600494385, 48.35245840890067, 50.063257762363975, 53.08760363715035, 50.209850856236045, 52.63523074558803, 50.35302543640137, 52.093316418784006, 52.06705917630877, 56.25999130521502, 50.84608697891235, 51.009564195360454, 49.735292366572786, 49.994769368852886, 52.131448132651194, 50.793881688799175, 48.04614707401821, 47.188975606645855, 48.98571375438145, 53.563812323978965, 55.34322166442871, 53.81568799700056, 52.919689995901926, 54.30730084010533, 53.80532823290144, 61.5127842766898, 57.45203120367867, 59.10627569471087, 54.329722676958355, 57.44190073013306, 48.07147673198155, 48.26752362932478, 16.180933611733572, 0.33355535726462093, 0.6048518696001598, 5.7518178054264615, 0.3324588718158858, 0.06633312880460705, 48.27728584834507, 68.73937634059361, 67.25431006295341, 61.15268693651472, 62.672660963875906, 55.67239952087402, 52.69056619916643, 39.03439603533064, 40.053561278751914, 65.5062336240496, 64.16079139709473, 3.713910290173122, 0.34090533001082285, 0.015209603322935956, 0.09229540532188756, 0.07062370928802661, 0.15306139178574085, 0.16307800715523108, 0.22793741896748543, 0.16017537005245686, 0.21837162226438522, 0.2450032260801111, 0.20363618939050607, 55.606544494628906, 78.70310006822858, 52.04359858376639, 43.38005999156407, 31.990816048213414, 40.815007414136616, 55.2629074369158, 61.863772528512136, 75.87418964930943, 62.63478633335659, 69.84079783303397, 41.52582202638899, 0.10274436284920999, 0.9868117166416985, 4.33329268864223, 10.718116572925023, 7.004030840737479, 0.6270229199102947, 12.939791781561715, 67.44127219063895, 52.6959684235709, 55.77161979675293, 50.942642620631624, 55.856631006513325, 47.940058503832134, 51.70778867176601, 53.75353288650513, 60.13646425519671, 56.4214848109654, 58.12934160232544, 51.38746282032558, 54.7720172064645, 51.56317581449236, 48.705642291477744, 49.957089287894114, 48.9140430859157, 50.26473120280674, 50.25096682139805, 51.25310550417219, 53.353052616119385, 52.32033838544573, 54.26313808986119, 50.54743603297642, 47.07732152938843, 41.07311562129429, 40.9780329976763, 44.916914667402, 51.636111055101665, 52.41630343028477, 53.4780923979623, 43.94082825524466, 45.53779179709298, 41.69696657998221, 37.46554143088204, 40.28580829075405, 38.558923857552664, 38.23202153614589, 37.79496594837734, 38.725944655282156, 35.798769337790354, 36.83155999864851, 37.499003955296104, 37.82078545434134, 37.970668520246235, 39.44906105313982, 43.48151758738926, 43.75196232114519, 43.09076826913016, 44.69344670431954, 44.96894972664969, 44.11956371579851, 45.143116746629985, 46.925117765154155, 44.97842012132917, 46.71165868214199, 48.956444467817036, 47.80421427318028, 48.01747880663191, 40.20101942334856, 39.20186499186924, 43.72550010681152, 40.71241726194109, 39.35294314793178, 42.88151979446411, 39.69203608376639, 37.99409089769636, 43.86829948425293, 47.65066603251866, 48.64788886478969, 48.88992936270577, 48.57242100579398, 47.532188824244905, 43.871794428144185, 44.44805717468262, 44.73205784388951, 46.11800112043108, 46.09527356284005, 43.624692167554585, 46.2395772252764, 41.18902199608939, 38.177457332611084, 36.16646453312465, 37.29781886509487, 37.116863455091206, 38.32426929473877, 36.11807727813721, 37.18871130262102, 35.86440202168056, 39.64141845703125, 38.46899332318987, 40.62391458238874, 38.42127309526716, 40.25788695471627, 41.98525081362043, 43.659704140254426, 48.617438384464805, 50.315025738307405, 53.44105155127389, 54.445573466164724, 51.52605506352016, 54.48815202713013, 50.319024426596506, 54.06135198048183, 55.42507839202881, 55.55603109087263, 50.67567893436977, 54.34354611805507, 52.02036033357893, 52.446277959006174, 53.01260825565883, 53.460207734789165, 49.56982101712908, 49.101998805999756, 50.2629211970738, 56.27719504492623, 57.53012548174177, 56.26244054521833, 56.549324716840474, 56.99430472510201, 56.34351560047695, 62.135572160993306, 58.289487157549175, 60.98689596993582, 58.04172134399414, 60.36763777051653, 51.20763649259295, 55.2252516746521, 18.553696530205862, 0.22063722355025156, 0.7244159281253815, 3.9032708491597856, 0.8817953946334975, 0.2475014291703701, 53.69310440335955, 73.94911479949951, 72.50984409877232, 70.16513279506138, 68.08399445669991, 65.00537272862026, 53.58006068638393, 38.770149094717844, 53.402555056980674, 70.84185259682792, 78.29060636247907, 5.775922843388148, 0.8029784496341432, 0.16423945554665156, 0.2827235577361924, 0.14151632200394357], [0.09431147535464593, 0.02174513727160437, 0.015893268066325357, 0.03480482613667846, 0.1296706883502858, 0.08039145836872713, 0.14386359176465444, 27.779813391821726, 68.02881186349052, 41.8003488268171, 42.54521656036377, 21.3658253124782, 15.034265450068883, 40.022881507873535, 60.58061395372663, 59.765791756766184, 56.273074763161794, 55.96411616461617, 44.51277617045811, 0.41476427391171455, 0.32385529205203056, 0.40104912700397627, 3.4628304030214037, 0.5269784139735358, 0.09414035560829298, 13.24536487034389, 54.770436491285054, 43.251799719674246, 49.80220699310303, 41.91467796053205, 46.763339383261545, 48.17618261064802, 59.76561805180141, 52.93191187722342, 53.28399099622454, 51.618841307503835, 50.919234139578684, 47.847258363451274, 46.75870840890067, 43.235231740134104, 41.284445081438335, 40.71258749280657, 42.467751094273154, 42.25382995605469, 44.967025075639995, 46.72428355898176, 44.75523356028965, 45.65742935453142, 38.76527493340628, 33.4350825037275, 40.22590092250279, 46.244618143354145, 53.240599496024, 50.453395639147075, 48.66881683894566, 47.08102144513811, 45.24152755737305, 39.808303764888215, 40.89188575744629, 37.07579960141863, 33.40080009187971, 34.08006293433053, 33.52185855593, 35.48464822769165, 33.50660726002285, 31.830128533499582, 36.27017681939261, 34.5039621080671, 34.54585974557059, 33.86211878912789, 34.209118774959016, 36.4209874698094, 37.14506619317191, 39.16412932532174, 39.95578275408064, 41.45859473092215, 41.80852338245937, 41.94297449929373, 43.060623509543284, 41.70553718294416, 40.02153703144619, 40.85050228663853, 42.68662282398769, 44.223487922123496, 42.41488225119454, 36.381796155657085, 34.75494841166905, 33.13659484045846, 38.94524022511074, 34.24591990879604, 37.57852608816964, 37.495731353759766, 40.834813254220144, 42.728541306086946, 44.65455068860735, 45.80559621538435, 45.828626019614084, 45.431508677346365, 40.58730104991368, 39.48222133091518, 40.942697933741975, 38.57161126817976, 40.626360348292756, 39.488363538469585, 40.44490466799055, 38.674218790871755, 38.81263385500227, 37.016712120601106, 32.66658047267369, 32.83549118041992, 32.705295835222515, 30.93319947378976, 32.12618432726179, 33.16928611482893, 33.07999134063721, 34.581274713788716, 35.02059194019863, 34.11248670305525, 36.92775433404105, 33.92961706433977, 39.3103472164699, 39.46585137503487, 41.34348739896502, 47.40389033726284, 48.467965262276785, 48.08494928904942, 49.664281776973176, 48.807791233062744, 53.11245386941092, 47.852525097983225, 49.898067814963206, 48.29567425591605, 53.15142631530762, 51.3682336807251, 47.624638080596924, 51.560323578970774, 49.62639325005667, 45.551194872174946, 40.98825379780361, 43.226768834250315, 52.43296521050589, 55.62569720404488, 52.42554106031145, 58.06326770782471, 50.10379007884434, 50.91894578933716, 46.675416878291536, 45.607985973358154, 50.48976945877075, 61.570662770952495, 48.91970239366804, 51.350651264190674, 41.68369552067348, 53.73077753611973, 9.638851148741585, 0.34629756637981957, 0.10614642886711018, 0.6585625846471105, 0.3615687297923224, 0.17254567412393435, 46.90447814123971, 65.82847717830113, 58.09051854269845, 61.3150246483939, 60.12923812866211, 54.79378938674927, 28.887767927987234, 14.862332275935582, 35.5599284853254, 52.52107531683785, 49.766805921282085, 1.9614276077066148, 0.11238967028579541, 0.04206548671105078, 0.026695565919258764, 0.0692618487934981, 0.15299116341131075, 0.09226529872311012, 0.1167507709137031, 0.10864197888544627, 0.06424999237060547, 0.08199462627193757, 0.1527284210813897, 34.59468126296997, 75.07477160862514, 49.274845668247764, 40.738959380558555, 22.8100848197937, 27.974097183772496, 42.68361077989851, 65.18700558798653, 63.438963890075684, 62.30265549251011, 60.905956404549734, 48.16580547605242, 0.33509848160403116, 0.34284406740750584, 1.05762080848217, 3.5603420734405518, 0.9166984217507499, 0.28605869305985315, 15.572921071733747, 59.89463915143694, 44.26373188836234, 52.92937578473772, 43.8370360646929, 49.63041278294155, 51.87081772940499, 61.314204760960166, 53.48981053488595, 54.0018093926566, 54.068376609257285, 53.21962635857718, 49.968553815569194, 48.24408040727888, 44.70790590558733, 43.669105052948, 42.99506030763899, 43.81177241461617, 44.18209055491856, 47.13197258540562, 47.42629827771868, 45.46343912397112, 48.68752138955252, 41.64109264101301, 35.861820765904014, 41.54966129575457, 47.724521909441265, 51.8704251561846, 52.24352257592337, 50.59603868212019, 49.92903593608311, 46.55003663471767, 42.3621106828962, 42.29484864643642, 38.30535282407488, 34.81098563330514, 36.132421834128245, 35.87215273720877, 36.42936699731009, 34.68027612141201, 33.72842502593994, 37.62364421572004, 34.664812905447825, 35.822229930332725, 34.96389463969639, 36.704136984688894, 37.96726042883736, 38.38869299207415, 40.119385038103374, 41.24315193721226, 41.41477591650826, 42.64291518075125, 43.510915415627615, 43.47563941138131, 44.113914830344065, 40.38087354387556, 42.59072726113455, 46.0311347416469, 46.10924291610718, 43.44617210115705, 37.4209965297154, 38.821652616773335, 36.502020835876465, 39.54813889094761, 35.82238279070173, 38.570030553000315, 38.55223969050816, 42.19283172062465, 44.70263569695609, 47.530722754342214, 47.3089953150068, 46.52026012965611, 47.748757226126536, 42.889711720602854, 42.6922995022365, 43.341573919568745, 41.366913250514436, 41.04775469643729, 44.01966946465628, 42.38143014907837, 39.708333083561485, 40.8069475037711, 38.082736015319824, 34.02102756500244, 34.56923001153128, 33.975152083805625, 33.575043542044504, 33.87684897014073, 33.60306910106114, 34.89175149372646, 35.70522574016026, 35.72860295431954, 36.952990191323416, 38.02425650187901, 35.91896275111607, 40.95876564298357, 39.88948304312569, 41.61785439082554, 48.472064699445454, 49.22010428564889, 51.342702525002615, 51.65201895577567, 51.19441407067435, 54.05805506025042, 49.4372215952192, 51.397909436907085, 51.578632082257954, 56.89210019792829, 54.42517008100237, 49.608147280556814, 53.960870606558665, 50.7319906098502, 49.452927998134065, 44.43925033296858, 45.20479243142264, 52.39363840648106, 57.666938986097065, 54.67919274738857, 60.099478994097026, 53.00565310886928, 53.34059797014509, 50.140143053872244, 50.55044460296631, 52.828911781311035, 64.54813957214355, 53.179670742579866, 53.54881811141968, 44.640174865722656, 56.94971118654524, 11.435349583625793, 0.28198873145239695, 0.26367878967097824, 3.945123323372432, 0.39043670360531124, 0.34027307108044624, 51.45261607851301, 68.79769257136753, 63.769177028111045, 67.35596220833915, 66.07527024405343, 59.873454093933105, 44.52263566425869, 23.243037496294292, 41.88577692849295, 60.630154609680176, 61.23248699733189, 2.197571039199829, 0.3169060892292431, 0.011660522515220302, 0.12769801063197, 0.047379352285393646, 0.22769292922956602, 0.24238014540502004, 0.20850835580910954, 0.29010555733527454, 0.19302937069109508, 0.23776331171393394, 0.24767494414533886, 37.34791190283639, 88.48942238943917, 56.53143310546875, 56.52206345966884, 29.4777637890407, 28.21411054474967, 52.55012226104736, 70.52156843457902, 69.24953392573765, 66.76546260288784, 65.13603360312325, 53.75326190676008, 0.6613180339336395, 1.0505118242331912, 3.2424585138048445, 7.40700204031808, 2.336546301841736, 0.3808076131556715, 18.97237413270133, 64.76518045152936, 45.01346683502197, 52.98866128921509, 46.0351299558367, 52.68816907065255, 51.36034400122506, 61.75376864842006, 56.044736112867085, 58.86609731401716, 56.051698207855225, 53.855824266161235, 51.52647195543562, 50.61419085093907, 47.2095388003758, 45.86543410164969, 45.04473025458199, 45.78195149557931, 46.819821289607454, 50.93667759214129, 49.58554131644112, 48.13737692151751, 47.76285164696829, 44.001843861171174, 40.93086862564087, 42.32032074247088, 49.6766391481672, 52.98935610907418, 54.433834484645296, 53.578768321446006, 50.60489068712507, 49.45496382032122, 44.578450543539866, 45.88686582020351, 39.956800665174214, 35.97033078329903, 37.29893752506801, 37.787312507629395, 38.56703240530831, 37.7116813659668, 35.62606838771275, 40.10405036381313, 37.04813882282802, 39.54798950467791, 36.82644265038626, 38.8378176007952, 39.05012675694057, 40.55040264129639, 41.03385829925537, 44.00024230139596, 43.760154247283936, 46.542834826878135, 45.46426248550415, 47.5770012310573, 45.866698673793245, 42.676686900002615, 45.54419456209455, 47.60685069220406, 51.74125119618007, 45.77564600535801, 41.3221321105957, 40.75940098081316, 39.03298555101667, 40.77154990604946, 38.532882009233745, 41.28437212535313, 40.75889376231602, 43.566268239702495, 45.70444086619786, 49.278740133558, 49.53654261997768, 49.31684752873012, 50.48782743726458, 46.76528140476772, 43.76162379128592, 46.00275829860142, 44.38866744722639, 44.81134373801095, 46.86291401726859, 46.308871609824045, 43.03754506792341, 43.812540190560476, 40.44257354736328, 36.31912340436663, 37.655581610543386, 35.77801854269845, 33.934557233537944, 35.851575647081646, 35.9462240082877, 36.95050621032715, 37.30369356700352, 37.91400943483625, 37.074868542807444, 41.133839402879985, 37.05544832774571, 42.066287653786794, 41.58325236184256, 43.413133416857036, 50.071630341666086, 50.75981814520699, 51.644438471112935, 53.37071146283831, 51.946817125592915, 57.18785374505179, 51.73695720945086, 53.13207558223179, 54.493064403533936, 54.10251658303397, 54.34609610693795, 52.99420942578997, 55.46303640093122, 53.3335142816816, 51.302083356039866, 46.318192618233816, 47.54185724258423, 57.328294209071565, 59.184762545994346, 56.29108796800886, 62.9787152154105, 54.85974516187395, 54.20852524893624, 50.92199257441929, 52.448053223746165, 56.66278879983084, 67.98651817866734, 55.87442534310477, 55.81479590279715, 49.654370171683176, 61.24461160387312, 13.205968584333148, 0.3474262143884386, 1.2420874472175325, 3.242014697619847, 0.6091500361050878, 0.2661215157381126, 58.0568128313337, 75.51959528241838, 70.6961419241769, 72.44556631360734, 70.23466341836112, 68.13678686959403, 43.96252400534493, 23.175202233450754, 54.514947754996165, 68.29174559456962, 73.67070743015834, 3.208181313105992, 0.39307813186730656, 0.08948734921536275, 0.15077056256788118, 0.1428944401975189], [0.051115539124501605, 0.02433539381516831, 0.04991497318925602, 0.04203970916569233, 0.08304838437054839, 0.1036542918799179, 0.26772019852484974, 11.187311921800886, 66.82091617584229, 49.74985926491873, 46.2295891898019, 31.17333616529192, 27.679359810692922, 41.74291501726423, 61.880906786237446, 57.09872920172555, 58.28503336225237, 53.109806605747764, 52.117204325539724, 2.3343895375728607, 0.4023426318807261, 0.702301983322416, 2.883460508925574, 0.5179087349346706, 0.29991093118275913, 18.43484238215855, 52.10373176847185, 39.89162656239101, 53.173486845833914, 51.4028183392116, 58.52930423191616, 54.514923436301096, 53.15335096631731, 49.84869738987514, 51.39734663282122, 48.83484751837594, 46.91310780388968, 41.483674253736226, 41.21016883850098, 39.98634440558297, 40.01089933940342, 40.010301794324604, 42.28847714832851, 43.96581745147705, 47.46188695090157, 46.467099462236675, 50.20475435256958, 47.43255513054984, 48.98699917112078, 46.861969062260215, 49.2626758984157, 47.78796591077532, 47.549451623644146, 44.83240720203945, 46.60656023025513, 44.469586168016704, 41.15604931967599, 39.466438497815815, 40.35069751739502, 35.50084795270647, 35.77985634122576, 34.17768859863281, 34.36786426816668, 33.88361998966762, 33.962478569575715, 35.59274482727051, 34.940420150756836, 33.3020453453064, 31.689542157309397, 33.95127807344709, 33.28351449966431, 33.2410922731672, 38.92977006094796, 39.61174617494856, 40.158058711460654, 39.87650033405849, 42.349475383758545, 41.981641224452424, 41.75591162272862, 40.78964301518032, 41.670629433223176, 39.46139063153948, 44.4433810370309, 43.165388447897776, 39.6429123197283, 36.597162519182476, 35.592133385794504, 34.31356062207903, 37.95566388538906, 38.00428043093, 35.83399323054722, 38.20483323505947, 42.38031496320452, 43.727053029196604, 44.87449244090489, 47.30761957168579, 44.99532856260027, 42.17690297535488, 39.597311292375835, 38.89137431553432, 40.94524097442627, 41.03517498288836, 40.10903917040144, 38.976580074855256, 37.744007859911235, 38.933317116328645, 37.24071509497506, 34.84653956549508, 33.98287500653948, 35.69860063280378, 33.20429808752877, 31.87692812510899, 34.67722586223057, 35.38766874585833, 33.30124977656773, 31.987915175301687, 33.82213190623692, 35.36909621102469, 36.32802752086094, 36.683771814618794, 36.88485268184117, 41.92948109763009, 36.97821910040719, 41.28799908501761, 47.47972992488316, 48.012510844639365, 50.06626633235386, 49.91294043404715, 50.96622480664934, 50.937011105673655, 50.53548860549927, 50.57976600102016, 46.05558197838919, 56.951510769980295, 48.34201526641846, 51.66566521780831, 47.851719106946675, 46.5484732900347, 38.65402732576643, 40.64576319285801, 44.62321778706142, 54.16687079838344, 54.71681376865932, 55.33517912455967, 52.03881822313581, 58.17618983132498, 53.05827529089791, 54.608453137534006, 39.672619342803955, 52.72968455723354, 51.8939482825143, 57.13521419252668, 38.146218231746126, 47.03597279957363, 7.39274867943355, 0.835648390863623, 1.331854916044644, 14.147769110543386, 0.6706140179719243, 0.7198911852070263, 52.79924297332764, 62.378807749067036, 59.23301083700997, 58.98093714032854, 66.65704986027309, 54.58495780399868, 35.771699156079976, 32.92920848301479, 36.37973601477486, 64.48065171922956, 41.37014416285923, 0.6040950044989586, 0.13791712799242564, 0.04936737507315619, 0.02575921473492469, 0.02864643552207521, 0.02514852473645338, 0.032732712504054816, 0.07216307454343353, 0.11033680329897574, 0.12216223696512835, 0.2125086182994502, 0.3655620983668736, 16.246920653751918, 78.09109578813825, 54.40609032767159, 51.68526956013271, 24.831828219549998, 31.134818826402935, 47.79914903640747, 66.84258065904889, 62.14285387311663, 62.78397805350167, 57.40327222006661, 55.86002172742571, 2.343673199415207, 0.5260405700121606, 0.36812571223293034, 2.73038518003055, 0.39125222127352444, 0.3327500447630882, 20.0361259664808, 54.061355454581125, 41.50696808951241, 53.35536636625017, 52.86992004939488, 60.84322806767055, 56.30429996762957, 54.52712447302682, 51.341434478759766, 54.36049277441842, 48.77622209276472, 48.838877473558696, 44.29600279671805, 45.058112485068186, 42.89925159726824, 41.79031910215105, 40.69566862923758, 44.866515908922466, 46.98225280216762, 49.85253626959664, 50.07839093889509, 51.66535949707031, 49.59519236428397, 50.77324206488473, 48.30895226342337, 48.521233626774375, 49.93338203430176, 49.46016454696655, 45.51930611474173, 49.55893666403634, 46.073807103293284, 42.47233690534319, 41.07044751303536, 41.265605040958945, 37.57569817134312, 36.294731753213064, 36.1347599029541, 36.67164025987898, 35.64187206540789, 36.326606614249094, 37.03494766780308, 35.90334667478289, 33.253275939396445, 33.52008329119001, 34.182253565107075, 36.25463717324393, 35.04552207674299, 40.683394636426655, 41.30840247017996, 41.85502420152937, 42.42590209415981, 41.991643156324116, 43.160569872174946, 46.55133594785418, 42.66592761448452, 42.5660993712289, 42.84029265812465, 46.30173928397042, 46.403488704136436, 41.19741194588797, 37.487876415252686, 37.048680782318115, 37.279670170375276, 39.69812617983137, 39.66702951703753, 37.9378000668117, 39.593385560171946, 45.10051734106881, 45.815771852220806, 46.909168175288606, 47.85276133673531, 47.64773736681257, 45.67043290819441, 42.55365514755249, 42.46661853790283, 43.716849599565776, 42.18362535749163, 42.84301635197231, 41.50173609597342, 39.55562904902867, 40.20801625932966, 39.727791513715474, 37.36507395335606, 35.54547275815691, 34.70127705165318, 34.375312737056184, 32.56518193653652, 36.323716163635254, 36.888761043548584, 34.623592717306956, 33.91923645564488, 36.68192706789289, 37.26572166170393, 36.86857305254255, 38.37715550831386, 39.401052474975586, 43.09302295957293, 39.15753895895821, 43.20684487479073, 48.71838181359427, 49.542323521205354, 52.20144428525652, 52.11663109915597, 52.02147551945278, 52.256105763571604, 53.988781520298545, 51.69515684672764, 49.42650747299194, 58.6564701625279, 48.99676833833967, 52.83362265995571, 50.24683264323643, 47.694001947130474, 41.845880372183665, 41.94825165612357, 48.32879284449986, 56.03744050434658, 57.01758119038173, 58.17258371625628, 53.99430186407906, 59.88076359885079, 53.29538951601301, 55.001992157527376, 44.18208360671997, 55.6138505254473, 53.8815986088344, 59.30836405072893, 41.174090317317415, 51.992737770080566, 8.854207583836146, 0.9399979029382978, 2.5619580234800066, 16.07601407596043, 0.7869266995361873, 0.9797130461250032, 60.14445468357631, 67.65506826128278, 64.52001326424735, 63.95379066467285, 72.1168053490775, 63.141740798950195, 45.7150924546378, 25.915957382747106, 46.01924637385777, 69.52956717354911, 52.88461201531546, 0.9175196119717189, 0.16864552269024508, 0.026168980336348926, 0.1145349062447037, 0.016397322893940976, 0.09656362807644264, 0.17235563003591128, 0.1391355326133115, 0.17902486931000436, 0.22065691463649273, 0.3474843512688364, 0.5468491220048496, 19.218847581318446, 89.98589760916573, 61.14257730756487, 61.81000736781529, 40.53090599605015, 40.685819557734895, 54.35880436216082, 74.58608395712716, 66.35881928035191, 69.91811738695417, 62.500658307756694, 63.31179101126534, 2.73686328956059, 0.9061070872204644, 2.0435431557042256, 9.191230825015477, 1.882571416241782, 0.6296099839465958, 23.861260414123535, 58.235763686043875, 45.55835151672363, 57.882878576006206, 54.730828285217285, 59.18105220794678, 57.27189915520804, 58.17168045043945, 54.19538967950003, 55.04481043134417, 51.29374899183001, 49.941490582057405, 46.586587633405415, 45.35077060971941, 43.20593466077532, 43.4399847303118, 44.54889290673392, 47.581461974552695, 49.06395047051566, 52.83084338051932, 51.289375100817, 54.976429734911235, 51.2617038999285, 52.968834604535786, 46.392468861171174, 50.243278639657156, 52.2975309235709, 51.92936325073242, 48.060686179569785, 51.13303368432181, 47.85430383682251, 45.20480285372053, 43.27964115142822, 42.33238628932408, 40.95707375662667, 38.54553815296718, 37.65385845729283, 38.29578168051583, 38.08875662939889, 38.57479701723371, 39.19522598811558, 38.0328722681318, 35.36610501153128, 35.797629833221436, 37.523454666137695, 36.975276538303916, 35.48193148204258, 43.33543518611363, 44.13172306333269, 43.94550439289638, 44.71580253328596, 45.03456504004342, 46.047678402491975, 47.62849085671561, 45.24684640339443, 46.21292393548148, 44.3771264893668, 48.26386540276663, 51.05346638815743, 42.82332515716553, 38.890339033944265, 41.40669516154698, 39.00579724993025, 41.935456548418315, 43.370318617139546, 39.183782305036274, 41.42699432373047, 46.9258508001055, 46.09111854008266, 49.23585932595389, 49.368601185934885, 50.538788999829976, 48.15073135920933, 46.15479530606951, 44.98959282466343, 45.466204507010325, 43.84501607077462, 45.05197722571236, 43.622760568346294, 41.52531828199114, 42.091276850019185, 41.289315768650596, 40.00948190689087, 37.57024383544922, 39.03702940259661, 35.68545464106968, 34.56254237038748, 39.11962958744594, 40.492253167288645, 36.484820570264546, 35.159875529153005, 40.85314955030169, 38.680093492780415, 38.04277345112392, 40.33304909297398, 41.8153395652771, 46.53549058096749, 40.14016710008894, 45.378952503204346, 51.23540844236101, 51.66054439544678, 54.11061123439244, 54.18986586162022, 54.49826513017927, 52.73119926452637, 54.338025774274556, 54.28445168903896, 52.07670675005232, 53.866284779139924, 52.36572054454258, 54.550817830221995, 51.07726744243077, 49.83794852665493, 43.25248064313616, 44.042740958077566, 50.18013688496181, 59.56373814174107, 58.85164506094796, 59.414122581481934, 56.503549984523225, 60.96987983158657, 53.78384787695748, 54.47110114778791, 43.597156456538606, 56.907417501722065, 56.778813294001985, 60.740756034851074, 45.866177558898926, 55.857127802712576, 10.16338803086962, 0.7427877251591001, 5.142835123198373, 35.28804547446114, 1.5753990475620543, 1.2341176463024957, 65.48751517704555, 72.54095813206264, 72.35578169141496, 70.63027300153459, 78.41551412854875, 69.39167322431291, 49.98082433428083, 45.13166958945138, 56.09627090181623, 78.82015636989048, 65.46973473685128, 1.5362870948655265, 0.3141672776213714, 0.16815589182078838, 0.16204396049891198, 0.11586692476911203], [0.013944760613542582, 0.0539220956686352, 0.13725782265620573, 0.06217744786824499, 0.02436796688873853, 0.04601933740611587, 0.1468815662498985, 4.659786803381784, 64.75574479784284, 45.69412973948887, 38.42269400187901, 28.498882464000157, 36.07463019234793, 40.6611465045384, 65.8458754675729, 55.22170114517212, 60.507803780691965, 51.25787544250488, 57.65049607413155, 5.731492153235844, 0.48158154423747745, 0.4702367644224848, 3.0317741504737308, 0.2934330387839249, 0.28895812747733934, 19.374779054096766, 59.699360030038015, 45.854539326259065, 57.35719871520996, 54.32101311002459, 53.99654265812465, 52.33019093104771, 55.04235424314226, 48.680698258536204, 44.185258933476035, 44.47553730010986, 43.1858161517552, 42.53536401476179, 40.31298616954258, 41.0544353893825, 42.68793603352138, 42.63899292264666, 45.76415021078927, 46.92314795085362, 47.32327733721052, 46.22221367699759, 45.986648900168284, 46.229137556893484, 41.17462880270821, 38.2851231438773, 47.17602416447231, 49.090815680367605, 46.93294143676758, 46.16276141575405, 39.76714263643537, 39.03675842285156, 37.07308980396816, 39.16866997310093, 40.94847536087036, 36.73337153026036, 34.44981132234846, 35.90521226610456, 34.6235545022147, 34.04922335488455, 36.54448127746582, 34.99623850413731, 35.84794521331787, 33.72882454735892, 34.5148777280535, 34.918707030160085, 32.7449700491769, 34.94005537033081, 34.96234171731131, 38.48537022726876, 39.33430460521153, 39.348134994506836, 41.08587598800659, 40.31816257749285, 41.28103699002947, 41.944510051182334, 40.91392544337681, 40.79333945683071, 42.15253216879708, 46.062075069972444, 42.641949381147114, 38.370304584503174, 35.93607269014631, 32.397181442805696, 36.621276242392405, 37.608167103358674, 35.5204245022365, 38.42468466077532, 41.48888192858015, 43.1872752734593, 46.18310226712908, 45.93425253459385, 44.63132980891636, 43.25356456211635, 38.21571411405291, 42.47763838086809, 40.2972172328404, 40.72626502173287, 39.264843463897705, 39.28342989512852, 39.85401596341814, 39.32417413166591, 36.04007332665579, 36.56404740469796, 32.48993641989571, 33.75079475130354, 33.22905451910836, 33.97964756829398, 32.503144945417134, 34.889541966574534, 36.18208408355713, 36.1388315473284, 33.414043358394075, 37.183868408203125, 35.58546658924648, 36.35249212809971, 37.637967927115305, 42.24121897561209, 38.59953955241612, 37.57851219177246, 38.65025097983224, 43.22183561325073, 45.32135888508388, 46.99601023537772, 47.72022097451346, 50.834949016571045, 50.175328731536865, 53.21344246183123, 44.30597346169608, 47.55297783442906, 52.739078521728516, 45.55877535683768, 47.11125653130667, 44.30938155310494, 40.742760045187815, 41.438094070979524, 39.514012813568115, 46.84043312072754, 49.78073011125837, 54.82402099881853, 53.06611980710711, 57.20478303091866, 55.407134669167654, 59.88216713496617, 57.125080244881765, 59.42885276249477, 54.79029096875872, 63.33714498792376, 49.866870403289795, 53.606133801596506, 3.930428317614964, 0.6391003546970231, 0.7291520482727459, 3.6829247985567366, 0.6118662389261382, 1.421209292752402, 57.87238679613386, 60.422222818647114, 59.683941977364675, 57.674870354788645, 68.80243124280656, 51.89518158776419, 44.642120361328125, 41.294332368033274, 38.98145771026611, 62.24891117640904, 36.06423568725586, 0.23858963165964397, 0.07521169167011976, 0.06803098626966987, 0.04228393766762955, 0.06925475810255323, 0.02054012014663645, 0.034797134942242076, 0.09312506365988936, 0.04308578624789204, 0.03544856248689549, 0.06633533404341765, 0.21964018419384956, 6.20889549595969, 75.74314662388393, 50.60432093484061, 50.035468442099436, 31.325574670519146, 37.34626865386963, 48.650814056396484, 71.21723597390312, 61.12490803854806, 65.74026979718889, 56.30527966363089, 63.4105874470302, 6.548473502908434, 0.6358437123043197, 0.5424475467630795, 2.882781973906926, 0.03740349651447364, 0.25668002665042877, 21.460411139896937, 59.41645022800991, 47.893675804138184, 61.213386399405344, 56.81218201773507, 55.12289081301008, 54.33767489024571, 55.334056990487234, 50.04831913539341, 47.158893380846294, 46.47753913061959, 45.017069475991384, 44.30482006072998, 41.14026996067592, 44.78636843817574, 46.10760661533901, 44.26223802566528, 48.2117087500436, 48.963482992989675, 49.43941027777535, 47.61583818708147, 47.339341572352815, 46.89421565192086, 42.623178822653635, 42.481247970036094, 50.0576297215053, 50.919421740940635, 47.62294272014073, 47.32921804700579, 41.32653726850237, 40.51694359098162, 39.07628672463553, 41.090062277657644, 42.311298506600515, 38.45700420652117, 36.01028292519705, 37.45557771410261, 36.095947265625, 35.51091936656407, 38.85300983701433, 37.636088439396445, 37.15647166115897, 34.498281955718994, 36.29890414646694, 36.56557600838797, 34.762827668871196, 35.04970489229475, 37.14957209995815, 41.15523290634155, 40.37673241751534, 39.947865281786235, 41.92321382250105, 42.832396030426025, 42.19706664766584, 43.84348399298531, 42.75696291242327, 43.58127982275826, 44.13104213987078, 47.23200927461897, 43.48818090983799, 40.82322365897042, 38.70737559454781, 34.87318590709141, 38.665266036987305, 38.8954633304051, 38.58292988368443, 39.72544649669102, 43.8587908744812, 44.76920291355678, 47.64825848170689, 48.022749015263145, 46.05033261435372, 44.4592159816197, 42.79581029074532, 44.18546043123518, 41.936140945979524, 42.819204875401084, 43.7400461605617, 42.584383555821006, 41.82553604670933, 41.52973733629499, 38.71037026814052, 37.09185688836234, 35.64203882217407, 35.627607413700645, 34.960198198046, 35.75926535470145, 33.77366474696568, 38.091483797345845, 38.40888793127877, 37.946509633745464, 34.60504102706909, 38.52966151918684, 37.03144577571324, 36.710338251931326, 38.52412380490984, 42.26753527777535, 40.2972207069397, 40.617484024592805, 40.85019309180123, 45.271109512874055, 46.01317364828927, 49.27442182813372, 50.901637826647075, 52.4796918460301, 52.48815475191389, 54.1426910672869, 45.91628449303763, 49.287890911102295, 55.03207090922764, 49.11796229226248, 48.507333755493164, 45.99578925541469, 43.39053092684065, 42.47957345417568, 41.79731593813215, 49.21061999457223, 52.42294590813773, 55.39845289502825, 56.11809866768973, 59.02841418130057, 55.51468930925642, 61.5741994040353, 58.94573061806815, 62.11249024527413, 58.156613281794954, 65.2017844063895, 52.98844242095947, 56.32008627482823, 5.642744549683162, 0.9258431196212769, 3.7154558300971985, 7.672768030847822, 0.6950886675289699, 1.7711674741336276, 63.42183658054897, 65.9648494720459, 66.24915586199079, 65.78129890986851, 72.16205201830182, 61.750398772103445, 36.484698976789204, 30.360438619341167, 47.42544712339129, 69.16951152256557, 46.383585589272634, 0.4035521884049688, 0.1121162206732801, 0.10430528516215937, 0.06469332679573979, 0.04285274000306215, 0.0733624869691474, 0.1827338095754385, 0.28331076194133076, 0.1951227733599288, 0.15874280620898518, 0.23746785042541368, 0.3851473874279431, 7.157199101788657, 85.23121057237897, 57.972722257886616, 54.05770417622158, 37.07529238292149, 50.35743406840733, 51.57340703691755, 75.93944018227714, 65.52327755519322, 70.91605240958077, 59.27207360948835, 69.97690609523228, 6.900501813207354, 0.9176465251616069, 2.315470027072089, 7.823477063860212, 1.5684576886040824, 0.4813859090209007, 25.4038873059409, 60.637700353349956, 51.560007435934885, 62.75016811915806, 57.85272339412144, 57.09632165091378, 58.2865480695452, 59.51824133736746, 51.348636286599294, 48.50122628893171, 49.26449632644653, 47.36245475496565, 45.990275859832764, 43.4866384097508, 47.61760997772217, 49.25316381454468, 45.76265287399292, 51.098351751055034, 52.14586911882673, 51.11235931941441, 49.874270234789165, 47.99906955446516, 48.157929692949565, 43.32382822036743, 43.220970562526155, 49.40680585588728, 53.769284452710835, 51.63664954049246, 49.4584379196167, 43.78507743562971, 42.44809116636004, 40.797202655247276, 42.615476744515554, 44.15021916798183, 39.727603912353516, 38.2256361416408, 39.821998664310996, 39.51428379331316, 37.781722681862966, 41.142218930380686, 38.71533128193447, 39.713453905923025, 36.22873081479754, 40.12967879431588, 38.92979437964303, 37.34368739809309, 36.76013251713344, 38.895630087171284, 45.51657894679478, 43.94681065423148, 42.79095349993025, 45.49631452560425, 44.119376114436555, 43.75797598702567, 47.22349773134504, 45.773307936532156, 46.06457642146519, 47.054166657584055, 51.00621863773891, 46.5106577192034, 42.42279624938965, 41.669118200029644, 38.21267080307007, 40.478912625994, 42.042639459882466, 39.64486823763166, 42.15955679757254, 46.52406426838466, 45.614486013139995, 49.48081806727818, 51.27913345609392, 49.28615386145455, 47.32163061414446, 44.283027035849436, 46.05958066667829, 44.75700535093035, 46.87734195164272, 44.81654099055699, 44.0116651398795, 44.7253007207598, 44.67661121913365, 41.66216305324009, 40.527984278542654, 38.48962599890572, 37.97186361040388, 37.7089125088283, 38.25655909946987, 35.8795873097011, 39.183379309517996, 39.46363489968436, 39.95248930794852, 37.254441261291504, 41.90371717725481, 37.60282046454293, 39.166099139622276, 41.95540482657296, 44.761907305036274, 42.523413113185335, 41.47624315534319, 42.094681467328755, 46.54353659493582, 48.25899124145508, 51.563401630946565, 52.56207316262381, 57.96269253322056, 54.835787773132324, 56.30600227628435, 47.86656045913696, 52.70607457842146, 53.483574526650564, 51.67708110809326, 49.80663299560547, 48.790219238826204, 44.89621945789882, 45.643303666796, 44.31993586676461, 51.89998279299055, 53.53359113420759, 58.42707538604736, 57.39069945471627, 61.930134773254395, 57.820768628801616, 63.42788846152169, 57.341339451926096, 62.20547103881836, 59.55011967250279, 68.2539404460362, 54.7108348437718, 58.09581307002476, 6.793862164020538, 0.8176774723189217, 4.346178122929164, 14.277894973754883, 1.4356339701584406, 1.9487920914377486, 71.58273206438336, 70.54175295148576, 74.99919605255127, 70.73744201660156, 80.03404835292271, 64.46285043443952, 60.65366036551339, 51.0435791015625, 58.98782280513218, 77.39451108660016, 59.783412388392854, 0.7771016210317612, 0.2826521758522306, 0.29779287055134773, 0.1535332314670086, 0.17118409861411366], [0.11923771032265254, 0.02350645642062383, 0.06630655058792659, 0.03050376907257097, 0.025111603949751173, 0.04625147441402078, 0.0521628273917096, 1.7343684030430657, 57.8702780178615, 50.2559243610927, 40.27290896006993, 15.786143915993826, 23.97721368925912, 40.600050994328086, 54.00320945467268, 59.03622395651681, 58.558868816920686, 52.71490226473127, 61.020830971854075, 13.069377422332764, 1.0592230196510042, 0.39864757444177357, 0.9754014717681068, 0.27439410611987114, 0.322115636829819, 21.076384203774587, 67.32895456041608, 54.98224190303257, 55.66306114196777, 52.986865179879324, 55.480264459337505, 52.90636682510376, 48.591525077819824, 44.97123220988682, 42.76271602085659, 42.81441061837332, 45.75563866751534, 45.49771111352103, 44.50888170514788, 46.76380491256714, 46.99580873761858, 49.51128939219883, 48.61385311399187, 48.29424640110561, 47.32180084500994, 45.05266857147217, 45.46652065004621, 43.77712869644165, 44.72471359797886, 41.4620931489127, 35.238834857940674, 46.82969467980521, 48.06710284096854, 43.39115973881313, 42.6814672606332, 41.9459205354963, 44.31321348462786, 38.700090408325195, 40.452061312539236, 39.58953973225185, 35.01926136016846, 35.29665429251534, 36.41688108444214, 34.6686726297651, 35.06433432442801, 32.461691992623464, 33.40977716445923, 35.49326399394444, 36.88462686538696, 34.308161871773855, 33.86414418901716, 33.79873037338257, 36.63166379928589, 38.530074937003, 40.107288224356516, 38.4924886567252, 40.41899136134556, 40.413627352033345, 41.289135115487234, 41.40492337090628, 39.35274165017264, 41.63931737627302, 41.30703714915684, 44.5424484525408, 45.42545332227434, 39.02454348972866, 36.571110248565674, 34.368951661246165, 38.64211116518293, 35.76134981427874, 35.396909849984304, 38.71096781321934, 41.01657812935965, 45.33830901554653, 45.20261069706508, 45.989744322640554, 44.111281463078086, 39.8545092855181, 40.469341482434956, 42.39464214869908, 41.708521434238975, 42.75915854317801, 40.088319642203196, 39.699380329677034, 41.503052779606406, 39.05975348608834, 35.631501879010884, 33.60567467553275, 31.30533456802368, 33.39491149357387, 34.14647729056222, 35.06801339558193, 34.25675562449864, 32.89793116705758, 32.546407903943745, 33.86374119349888, 35.117540155138286, 34.798996516636436, 36.26126575469971, 35.872267382485525, 38.84453303473336, 39.854422433035715, 40.51539761679513, 38.28762796946934, 38.48696483884539, 39.81272976739066, 43.183617046901155, 44.74279628481184, 44.14380250658308, 49.79694720676967, 53.07891838891165, 51.59920917238508, 49.40106316975185, 39.83371680123465, 50.48643432344709, 49.856649603162495, 46.32944522585188, 49.2762839453561, 49.586548805236816, 51.40839426858084, 46.437833649771555, 41.77660683223179, 43.407217025756836, 47.87672567367554, 50.992579323904856, 56.10738107136318, 54.75643934522356, 55.21073688779558, 52.71812275477818, 60.413947514125276, 54.86013078689575, 59.41852079119001, 57.96404048374721, 58.67006083897182, 2.8696194802011763, 0.8692587816289493, 3.390799948147365, 8.967210480145045, 0.9750115041221891, 3.959587735789163, 61.954189436776296, 56.52498517717634, 62.91376345498221, 56.22122035707746, 71.4054696219308, 49.09994213921683, 69.0651912689209, 37.714217458452495, 34.37584774834769, 63.11663695744106, 29.903441701616558, 0.3801444944526468, 0.016562140746308223, 0.08210568209843976, 0.027791388100013137, 0.030997349015836204, 0.03220148743795497, 0.005591970785254878, 0.07886785548180342, 0.038027653736727576, 0.030694006543074335, 0.024280775138842206, 0.0446466712414154, 2.606925679104669, 67.81363310132707, 57.24488108498709, 44.92374127251761, 22.40054062434605, 39.52753748212542, 45.68085173198155, 60.49376841953823, 64.35424314226422, 64.32246208190918, 54.94243914740426, 67.37270736694336, 13.637273669242859, 0.7488859636443002, 0.15158734231122903, 2.3013343513011932, 0.12913885260266916, 0.32762295273797853, 23.432738951274327, 67.49129227229527, 56.91073874064854, 56.644956248147146, 56.64359787532261, 56.352061884743826, 54.70743370056152, 49.930616651262554, 46.05923325674874, 44.76620476586478, 46.25471387590681, 46.481214727674214, 48.117181982312886, 47.66843952451433, 46.92668458393642, 48.43901211874825, 49.59489359174456, 51.18069832665579, 50.94430324009487, 49.520228249686106, 45.57209505353655, 46.2908410344805, 47.91691058022635, 44.508860860552105, 42.65372657775879, 38.361025265284944, 49.29936933517456, 49.76347426005772, 44.76542656762259, 44.383723803928916, 42.70442063467843, 45.00911031450544, 42.264227935246055, 43.11798783711025, 40.80306346075875, 35.75083718981062, 36.14134332111904, 37.387412411826, 36.870188508714946, 37.35260541098458, 33.819074698856895, 33.09048312050955, 34.14395162037441, 36.968175479343955, 35.08235100337437, 34.32723815100533, 34.84800216129848, 36.589342321668354, 40.474983419690815, 41.795679637363975, 41.32532480784825, 41.81320994240897, 42.27457727704729, 41.84680100849697, 43.98648139408657, 40.57404388700213, 43.05575977052961, 42.8411750793457, 45.40154109682356, 45.9799473626273, 39.944349493299214, 38.714025020599365, 35.22195420946394, 39.016900471278596, 37.23744249343872, 37.61938149588448, 39.931880950927734, 42.92273998260498, 46.31281818662371, 46.63234152112688, 46.86368179321289, 47.104992730276926, 42.0157082421439, 42.31023890631539, 44.25233336857387, 43.70571511132376, 42.72453219549996, 41.558895451681956, 42.63996914454869, 42.91756010055542, 40.503127098083496, 36.581247670309885, 36.97825036730085, 33.02891165869576, 34.721204485212056, 36.349254267556326, 35.19339363915579, 35.69697822843279, 33.569015979766846, 33.696133272988455, 35.40488290786743, 36.73215906960623, 36.34434189115252, 37.599360261644634, 38.208474091121126, 39.380180086408345, 43.683077880314414, 40.695022446768625, 39.57442740031651, 40.04008524758475, 42.58677026203701, 46.10375036512102, 46.785118511744905, 45.818481649671284, 51.089315618787495, 54.990270546504426, 52.51254292896816, 51.443409715379985, 43.1604517527989, 51.63973454066685, 51.80317006792341, 49.110975878579275, 51.526134967803955, 51.000733034951345, 52.544754777635845, 48.52008717400687, 44.22769158227103, 46.04706001281738, 50.71218824386597, 53.15185362952096, 57.114334855760845, 56.625171252659385, 57.46301630565098, 55.26076391765049, 61.88221304757254, 56.25089611325945, 63.20413562229702, 59.823955127171104, 62.134807859148296, 3.3133705258369446, 0.8015180251428059, 3.4081695760999406, 3.8419959885733466, 0.8235719331673214, 4.408212508474078, 70.12086582183838, 63.29259313855852, 69.1206031526838, 61.96810667855399, 77.94646208626884, 56.213469641549246, 59.96851239885603, 37.259381430489675, 42.10508292061942, 69.1451997756958, 39.92907040459769, 0.3503977635077068, 0.06472761995558228, 0.04453535417893103, 0.049646846683962007, 0.09021807036229543, 0.22598661721817084, 0.09007211747978415, 0.12087080840553556, 0.14835705421864986, 0.22385904352579797, 0.13053678401878901, 0.12918282167187758, 2.581888279744557, 77.22481523241315, 65.6222893851144, 56.09438793999808, 25.303341661180767, 34.11050646645682, 55.33509922027588, 68.07817186628068, 69.07262584141323, 70.26907089778355, 59.866318293980186, 72.47214317321777, 15.65767172404698, 1.1941393400941576, 0.507755842592035, 3.937642284802028, 1.157878320131983, 0.5273013966424125, 26.922082594462804, 70.27665833064488, 59.066219329833984, 59.166335923331125, 59.52575928824288, 59.118768555777415, 56.24717535291399, 53.167692048209055, 49.33210924693516, 46.91658190318516, 47.92308405467442, 49.447678634098594, 50.39614248275757, 50.285999638693674, 50.7779529435294, 51.14120823996407, 53.74826267787388, 53.263990606580464, 52.75594874790737, 50.990741525377544, 47.93282542909895, 47.83042287826538, 50.633360930851524, 47.43307624544416, 44.4785041809082, 39.32885026931763, 49.961421489715576, 53.17765229088919, 47.96275132043021, 48.26628337587629, 46.282089778355186, 47.235222816467285, 43.92057425635201, 45.061301708221436, 43.06011629104614, 36.666258880070274, 37.777366161346436, 39.520384311676025, 39.160439831869944, 39.94552721296038, 35.582603931427, 34.571317945207866, 38.405410357883994, 40.496189321790425, 37.47481380190168, 36.70459903989519, 37.27391011374337, 39.06276553017752, 43.13894707815987, 44.43463325500488, 42.936806610652376, 45.125263350350515, 46.550401415143696, 44.311865534101216, 47.40281684058053, 42.275084495544434, 47.727499212537495, 46.15881483895438, 50.47686665398734, 50.21036154883248, 41.8808228628976, 42.02622781481062, 39.57766873495919, 42.393627711704795, 39.5836615562439, 38.148094245365684, 41.87637254170009, 44.24168178013393, 48.24124206815447, 49.33431877408709, 49.42495107650757, 49.10976341792515, 45.526136193956646, 44.40435995374407, 47.59979132243565, 47.74150678089687, 46.11071593420846, 45.57614585331508, 45.72456979751587, 46.417989594595774, 42.71322052819388, 39.76217467444283, 38.15314558574131, 35.32975203650338, 36.619997773851665, 38.38667106628418, 37.5795578956604, 39.27681521006993, 34.70425088065011, 35.20579617364066, 37.08664921351841, 39.090672969818115, 37.178928239004954, 38.66575241088867, 39.98081363950457, 42.230918271201, 44.77409791946411, 43.62437949861799, 40.663053785051616, 41.75899314880371, 45.05973836353847, 48.099547454289024, 48.44295869554792, 48.991661412375315, 51.3345661844526, 57.58769825526646, 54.34047154017857, 54.0083406993321, 47.308529785701204, 54.211582456316265, 53.29179382324219, 52.02899694442749, 53.25419364656721, 53.789701734270366, 55.321307046072825, 52.154411928994314, 46.986105578286306, 47.568805830819265, 53.42534862245832, 55.84999200275966, 61.212580408368794, 59.020882334027974, 59.717383657182964, 57.47977883475167, 65.89472130366734, 58.50431850978306, 66.44374016353062, 62.471545355660574, 63.42766611916678, 5.429232052394322, 1.3703594441924776, 7.114146326269422, 16.171874897820608, 1.147305007491793, 5.577957808971405, 76.52930055345807, 67.91228362492153, 75.54622077941895, 69.66024194444928, 83.51242773873466, 62.60499940599714, 85.37613609858921, 50.12436369487217, 51.25798313958304, 78.18595259530204, 50.31530366625105, 0.6454220754759652, 0.14285200461745262, 0.15289006169353211, 0.1858870703727007, 0.19749037202979836], [0.09630286706877605, 0.07100237932588373, 0.061160595289298465, 0.07288250486765589, 0.05281208701697843, 0.20456727514309542, 0.09665626167718853, 0.33660075813531876, 44.6724214553833, 53.56428827558245, 43.87142269951956, 30.89560971941267, 29.690597534179688, 38.388046809605186, 62.61507429395403, 61.75580447060721, 59.40578474317278, 55.88955157143729, 58.487823486328125, 20.29890510014125, 0.6891324328524726, 0.44312600631799015, 1.0170231355088097, 0.39962135361773626, 0.25015241120542797, 20.157814979553223, 67.54185431344169, 52.55712604522705, 56.00749029432024, 53.870238304138184, 50.44636753627232, 47.45728724343436, 45.345295429229736, 43.41541242599487, 44.736171177455354, 46.19174582617623, 49.08017104012625, 51.48381001608712, 48.73625258037022, 47.66579573495047, 49.17573308944702, 49.22745200565883, 49.848037311008994, 49.06669153485979, 48.372927801949636, 49.09855597359793, 47.477437019348145, 49.648221015930176, 48.455736432756694, 47.76706920351301, 43.97986323492867, 41.135416643960134, 48.48935529163906, 48.23081629616873, 47.191410950251985, 45.49156195776803, 49.21623066493443, 48.542835576193674, 42.174026421138215, 37.72126988002232, 35.47473314830235, 34.13689225060599, 34.803259236471995, 33.012579917907715, 31.446327413831437, 36.07345942088536, 37.38928147724697, 35.447596958705354, 34.401906967163086, 33.212073121752056, 32.623574597494944, 33.873048305511475, 35.93414109093802, 37.038088253566194, 39.05323954990932, 38.36808116095406, 41.03942033222744, 39.009003843579976, 39.75446217400687, 40.19402258736746, 42.338000433785574, 39.2401738848005, 41.37474387032645, 42.88666146142142, 45.4905093056815, 39.62372139522007, 36.01658146721976, 34.54089873177664, 37.902767249516074, 34.89790759767805, 37.120264598301475, 38.79529809951782, 43.64345925194876, 44.7892484664917, 45.99452815737043, 43.974936962127686, 42.79939208711897, 40.12200103487287, 39.84115137372698, 40.608541693006245, 40.899580887385774, 42.25886392593384, 39.912460735866, 39.955289431980674, 39.02051700864519, 36.24784878322056, 35.50182070050921, 34.461821283612935, 31.623836517333984, 31.416547434670584, 30.861824103764125, 31.309083121163503, 32.231765678950715, 34.29933418546404, 33.70815365655081, 33.89471626281738, 33.635277475629536, 34.09713813236782, 35.56916611535208, 36.25294876098633, 40.430417673928396, 42.05563606534685, 40.41787617547171, 42.22365045547485, 46.92636844090053, 47.369201455797466, 48.61965485981533, 48.42700910568237, 62.47016266414097, 56.93830224445888, 49.69629907608032, 47.77046339852469, 48.531329359327046, 46.941633633204866, 43.87230512074062, 53.76499394008091, 49.43133994511196, 52.34997245243618, 50.49156209400722, 52.11337586811611, 54.43793044771467, 52.787382398332866, 44.70165947505406, 44.31437035969326, 44.000172819410054, 50.49212837219238, 50.614548683166504, 54.35500022343227, 54.02326890400478, 55.26684706551688, 54.45566919871739, 60.88973930903843, 58.33280222756522, 61.16357476370675, 2.63976742540087, 0.7893970012664795, 1.9552982108933585, 4.460280571665082, 0.8996492794581822, 8.150226524897985, 64.2906184877668, 56.80305208478655, 58.7095057623727, 58.77119186946324, 64.73335075378418, 52.26239388329642, 47.84576450075422, 21.076054164341517, 39.71068157468523, 64.03784997122628, 21.54920390674046, 0.5176010600158146, 0.07466324538524662, 0.19413375428744725, 0.08070259381617818, 0.031452364421316555, 0.013974385452456772, 0.04336894230384912, 0.11528886721602508, 0.07523886021226645, 0.07770745203431163, 0.08386346099099942, 0.04043539793097547, 0.38606164551206995, 57.322944096156526, 61.07830647059849, 52.30372176851545, 30.69890969140189, 29.854199818202428, 45.67171137673514, 68.84665652683803, 66.20270020621163, 64.35561193738664, 58.75967870439802, 63.77149772644043, 22.437906299318584, 0.7734762355685234, 0.18496306852570601, 3.5677501559257507, 0.2330334069473403, 0.2718806495623929, 22.365500858851842, 70.12527792794364, 55.54825258255005, 58.01907369068691, 55.28007296153477, 53.3378186907087, 50.535676206861226, 48.30740281513759, 45.84392942701067, 46.3843811580113, 48.85648420878819, 50.88880797794887, 52.883809498378206, 48.909724780491416, 49.401956013270784, 50.828052929469514, 49.971451214381624, 49.81326157706124, 51.45762572969709, 50.94710683822632, 51.65017768314907, 51.41097205025809, 50.56212452479771, 49.84451804842268, 48.77058015550886, 43.47853333609444, 43.173625537327354, 50.95086233956473, 50.1409455708095, 49.35823794773647, 48.84906005859375, 52.281282561165945, 49.26011896133423, 42.95730379649571, 40.9015611239842, 38.6248379434858, 36.67228991644723, 38.22923878261021, 34.69308165141514, 32.82785163606916, 35.26915679659162, 38.1174943787711, 37.119667053222656, 37.03655964987618, 36.224561895642964, 34.48506300789969, 34.34170430047171, 37.386338915143696, 37.60750355039324, 40.54149157660348, 38.597041675022666, 42.15568317685808, 42.60340772356306, 42.90601566859654, 41.581292969839915, 43.97837632043021, 41.71679326466152, 43.59382479531424, 46.47117805480957, 46.218214988708496, 40.68223776136126, 37.22945553915841, 36.485049860818044, 38.00367941175188, 36.506377356392996, 38.75144107001168, 39.24671213967459, 44.12885693141392, 46.275891985212056, 47.902388845171245, 45.72046341214861, 45.07107434953962, 41.998261315482004, 42.34311778204781, 42.87838615689959, 41.75888545172555, 43.66317129135132, 42.3663386617388, 42.17779581887381, 41.38467979431152, 38.44940635136196, 36.38229642595564, 35.48803200040545, 34.0838497025626, 33.533875465393066, 34.3543187550136, 34.4341014453343, 35.14580890110561, 33.911885261535645, 34.1617876461574, 35.85934720720564, 35.809591157095774, 37.29454973765782, 36.59812831878662, 36.893065452575684, 43.23366839545113, 42.17375544139317, 41.562831606183735, 44.671730109623496, 46.72249787194388, 48.11707428523472, 50.650307587214876, 49.78275203704834, 58.81522955213274, 58.21227182660784, 50.81417390278408, 47.72514724731445, 49.2495368548802, 49.467060634068076, 46.233657360076904, 55.846750668116975, 51.41760063171387, 54.35555955341884, 54.044186455862864, 56.898266724177766, 56.57414020810808, 54.15976973942348, 47.87225798198155, 47.59800910949707, 47.74968481063843, 52.0092327935355, 51.96990598951067, 56.35720355170113, 56.97431823185512, 58.66494696480887, 57.59422261374337, 63.78967421395438, 58.57316820962088, 66.11607701437813, 3.7526473658425465, 0.5844132006168365, 2.5511464093412672, 2.8518442511558533, 0.5912982140268598, 8.483654941831317, 71.46606486184257, 59.418333189828054, 65.9955118724278, 65.46623284476144, 71.73821885245187, 56.37525497164045, 55.123759337833945, 28.258789198739187, 45.09720999853951, 73.8787225995745, 28.581515652792795, 0.6293433468256677, 0.04918396705761552, 0.16773445372070583, 0.01388333538281066, 0.02991546903337751, 0.1479281929454633, 0.10721109102347068, 0.17663434972720488, 0.2270725853741169, 0.2403804212808609, 0.22804679881249154, 0.1359229271433183, 0.7828541323542595, 65.52135985238212, 68.08321625845772, 59.73999309539795, 40.3584760257176, 42.87033666883196, 51.52578060967581, 72.73784923553467, 70.46636499677385, 70.70606395176479, 64.58651447296143, 69.43784400394985, 25.806333916527883, 0.8553212923663003, 0.5486509853175708, 2.180470436811447, 1.2765152284077235, 0.4379209913313389, 24.210982356752666, 71.28045068468366, 57.54671777997698, 61.42217281886509, 56.556832245418, 54.1116395677839, 53.976795877729145, 49.76319980621338, 49.49815034866333, 49.99630492074149, 50.03059775488717, 54.01135969161987, 55.28054196493966, 51.94099800927298, 51.78602191380092, 51.94847774505615, 52.218658447265625, 54.70234414509365, 53.29479544503348, 52.52122470310756, 53.09304755074637, 54.09370279312134, 55.80970982142857, 53.29205090659005, 51.654221534729004, 46.18357821873256, 44.40711144038609, 53.73661749703543, 52.65280621392386, 49.91904442650931, 49.20244543892996, 55.23027522223336, 51.85028232846941, 46.11834853036063, 43.639794077192036, 39.885831764766145, 38.30406045913696, 40.17309808731079, 36.52579757145473, 34.244797774723594, 37.68701178686959, 40.56617157799857, 39.218804700034006, 37.89257076808384, 37.805242334093364, 36.44711964470999, 37.88394110543387, 38.784417220524375, 39.46743556431362, 42.4801709992545, 42.03992618833269, 45.09513596126011, 43.93889665603638, 44.41109275817871, 45.189523765019004, 46.92034435272217, 42.782976967947825, 44.92939363207136, 47.93080002920968, 48.502035754067556, 41.89505277361189, 39.366825648716514, 40.57942874091012, 41.55026231493269, 40.01418236323765, 41.567108222416465, 41.37653650556292, 47.866011551448274, 49.07831934520176, 50.7332204410008, 47.96131999152047, 48.86265420913696, 45.639398779187886, 44.72904232570103, 45.50969328199114, 44.083002294812886, 47.88807903017317, 46.008087566920686, 46.39588042667934, 44.16417809895107, 40.33512313025338, 41.45013182503836, 37.89640269960676, 35.179323537009104, 35.587922777448384, 36.32246201378958, 35.26973697117397, 38.896418707711355, 37.26851136343819, 36.68961524963379, 38.272599015917095, 36.8668464251927, 38.2628367968968, 38.84804882322039, 39.271214962005615, 43.88531909670149, 43.47989518301827, 44.61626958847046, 44.949720587049214, 49.98923165457589, 49.08943993704659, 52.60617685317993, 51.123632771628245, 57.804638385772705, 59.952774729047505, 50.96058634349278, 49.68835381099156, 50.57149417059762, 51.71062701089041, 49.65921654020037, 59.271698406764436, 53.03455414090838, 56.812696184430806, 54.93152700151716, 57.24616302762713, 59.22342927115304, 56.69032451084682, 49.38021509987967, 50.41176898138863, 49.320717675345286, 56.76803316388811, 52.91959272112165, 58.58051940373012, 57.79420566558838, 60.28899111066546, 60.81219046456473, 65.97838456290108, 61.232570375714985, 66.20930794307164, 5.090001889637538, 1.3270747725452696, 9.268955111503601, 16.153948545455933, 1.1598772300141198, 9.932085973875862, 75.0014820098877, 64.84240967886788, 69.51045267922538, 72.6810268674578, 74.16773986816406, 66.6519637789045, 61.89467116764614, 32.26256704330444, 57.83397715432303, 81.64501598903111, 39.369486808776855, 0.9999178647994995, 0.15238396956452302, 0.3065929811980043, 0.1947503119174923, 0.14512483908661775], [0.1308573918151004, 0.030115742036806684, 0.11812822414296013, 0.04850346428741302, 0.020829454263938323, 0.04244081157126597, 0.00949379226325878, 0.058428908299122534, 40.331492696489605, 56.01084974833897, 42.30605261666434, 31.267116001674108, 41.23138516289847, 40.35453292301723, 51.07673243113926, 59.67348493848528, 56.62828057152884, 53.851106439317974, 58.60368469783238, 28.975063358034404, 0.2019407203687089, 0.4886716923543385, 2.3877371549606323, 0.29668769985437393, 0.37011859672410147, 20.86199927330017, 68.57631601606096, 53.90330478123256, 55.356645584106445, 47.681981563568115, 47.392731530325754, 44.93759250640869, 43.38444777897426, 41.839620045253206, 44.72190999984741, 46.70326178414481, 48.43851184844971, 51.70515530450003, 50.24690907342093, 48.53579357692173, 48.1174008505685, 44.65710415158953, 45.79132808957781, 47.817082336970735, 46.350348881312776, 47.68043211528233, 46.52938311440604, 44.11387661525181, 46.27118110656738, 49.885401248931885, 46.71661274773734, 44.00575222287859, 43.58129024505615, 46.517359256744385, 47.29501553944179, 49.21994795118059, 48.98590135574341, 48.278463568006245, 46.08803701400757, 37.291245869227815, 35.935329232897075, 33.76986060823713, 35.61713647842407, 35.132767132350374, 41.499981675829204, 39.61461230686733, 35.82364041464669, 32.28130633490426, 33.538485595158164, 33.531158719744, 33.3048072542463, 34.2497935295105, 36.89361088616507, 34.61558491843087, 37.5468874658857, 38.549793924604145, 38.63224819728306, 40.0689480645316, 38.29827608380999, 40.93465191977364, 41.93882989883423, 41.146961075919016, 41.27433892658779, 43.521890095302034, 45.09461832046509, 40.820621558598106, 36.16490466254098, 34.136812346322195, 37.82626758302961, 35.4469438280378, 37.32300955908639, 41.18445702961513, 44.259743622371126, 44.614087854112896, 45.66467979976109, 42.309102875845774, 41.30391045979091, 39.56191022055489, 39.28727919714791, 40.70377022879464, 41.966952732631135, 39.87823043550764, 40.60392114094326, 38.316692284175325, 38.25209835597447, 36.105066776275635, 36.049533299037385, 34.51426976067679, 31.250384739467076, 33.086755411965505, 34.15298775264195, 32.53227526800973, 32.542145184108186, 32.12510388238089, 34.1597900390625, 34.84893321990967, 34.50764465332031, 34.80649014881679, 35.53091280800955, 35.27015733718872, 40.4487088067191, 40.30068090983799, 46.68926116398403, 49.055324281964985, 47.04258748463222, 48.3007846559797, 47.53069148744856, 53.692492961883545, 45.52400657108852, 39.663392135075156, 48.075666495731895, 46.29265798841204, 44.14779077257429, 43.60626901899065, 41.5612404687064, 45.91486358642578, 49.850712367466514, 53.11858218056815, 54.39359746660505, 50.52748775482178, 51.64825998033796, 51.65923466001238, 52.14297866821289, 50.77678564616612, 41.60176931108747, 42.34556354795183, 44.497886180877686, 49.66781146185738, 48.3743382862636, 54.2306170463562, 47.73959255218506, 56.939208984375, 56.96199212755476, 65.08518668583461, 3.419311446802957, 0.5519197870578084, 1.221504385982241, 0.05457137564995459, 0.6627227642706462, 9.194980246680123, 65.71207400730678, 56.63387039729527, 53.17841311863491, 59.349414008004324, 63.63210991450718, 48.92458002907889, 32.010757378169465, 24.1903965813773, 39.689117840358186, 67.18256296430314, 22.93263714654105, 0.5943999875869069, 0.1368227188608476, 0.05939962728215115, 0.027357537898101976, 0.07668991413499628, 0.007182548471194292, 0.08067869581282139, 0.04579522068213139, 0.06458049999283892, 0.049374252025570185, 0.05324783881327935, 0.09354842201407466, 0.19718363348926815, 50.25192219870431, 63.20722757066999, 49.303017139434814, 38.32737513950893, 43.807589599064414, 44.464965615953716, 61.04681028638567, 63.51429625919887, 61.647523743765696, 57.86123146329607, 63.01283087049212, 29.908103942871094, 0.20998688361474446, 0.40162110488329616, 4.481454772608621, 0.29977066442370415, 0.3171558172575065, 21.871593373162405, 68.91121223994664, 56.8250744002206, 58.431209564208984, 49.16786772864205, 49.1251779964992, 46.32986906596592, 44.67923069000244, 43.78408036913191, 47.1323755809239, 49.41750260761806, 51.96521595546177, 51.0726329939706, 50.45477833066668, 50.11815547943115, 51.626633712223594, 48.054050649915425, 49.13454416819981, 49.56251498631069, 48.27758114678519, 47.90020016261509, 48.041658537728445, 45.761353560856406, 49.428842067718506, 51.36682319641113, 46.53411136354719, 44.296454429626465, 44.06679562159947, 48.021130084991455, 48.683484486171174, 50.135314055851524, 48.50080244881766, 51.416714736393516, 47.98126826967512, 39.66872140339443, 38.531759875161306, 35.335699694497244, 36.45054163251604, 35.72265182222639, 42.322565010615754, 41.37187426430838, 36.69201932634626, 33.69746732711792, 34.23793990271432, 35.11839130946568, 35.56405571528843, 35.6008221081325, 38.8034657069615, 36.950245652879985, 39.614872864314485, 40.138586384909495, 40.51569291523525, 41.794112818581716, 41.158741746629985, 43.27366917473929, 43.11339855194092, 41.27187579018729, 42.76542929240635, 45.44072198867798, 48.35523074013846, 41.441866942814414, 38.09818533488682, 36.7253463608878, 38.952963147844585, 37.11874641690935, 38.424003737313406, 42.361756324768066, 47.208229064941406, 45.30509662628174, 46.779716287340435, 43.492245606013704, 42.86141518184117, 41.08781453541347, 40.77016026633126, 43.717613901410786, 44.36442518234253, 41.79549898420061, 42.55048329489571, 39.11757639476231, 40.32228980745588, 38.45153944832938, 38.569575445992605, 36.21226358413696, 33.62917695726667, 35.22976745877947, 35.91380371366228, 34.55555248260498, 35.14095558438982, 35.37402943202427, 37.641508034297395, 36.11044120788574, 35.46845892497471, 35.69339643205915, 37.4864833014352, 37.40572786331177, 41.54876150403704, 43.03270217350551, 48.31644936970302, 51.04892226627895, 49.26247092655727, 49.90959140232631, 49.45091649464199, 53.507302624838694, 46.138779708317344, 42.182353837149485, 48.30730206625802, 46.97784069606236, 45.18392699105399, 44.85369995662144, 41.26015417916434, 48.380362374441965, 51.72677115031651, 54.19255134037563, 54.700874601091655, 53.051240239824565, 54.59049204417637, 53.74246788024902, 53.55318505423409, 53.26518222263881, 43.49754360743931, 45.69504690170288, 47.14027568272182, 52.74319185529436, 50.18929461070469, 58.251567363739014, 49.601838316236226, 60.77068887438093, 58.56320449284145, 69.58980110713414, 4.189606547355652, 0.3555301752473627, 1.3601179080350059, 1.9222808054515292, 0.5942967959812709, 9.432769315583364, 72.26512159620012, 61.41214656829834, 58.62197930472237, 65.24309144701276, 68.69176033564976, 55.632516860961914, 43.94419118336269, 23.208987849099294, 45.197027819497244, 75.63615826198033, 28.563775164740427, 0.6224277721984046, 0.17260219609098776, 0.0658786189077156, 0.04523978887924126, 0.03709852895034211, 0.2301500402390957, 0.15382714569568634, 0.1739573119474309, 0.11797465809753963, 0.2126569596252271, 0.13100721234721796, 0.11916149726935796, 0.2686807598386492, 59.085695130484446, 68.95033754621232, 57.00337907246181, 38.85724476405552, 55.09809269223894, 52.788591384887695, 60.78003420148577, 67.79088469914028, 65.66433293478829, 63.32527051653181, 69.27490179879325, 36.215206146240234, 0.42904138352189747, 1.4100232358489717, 7.0852066448756625, 1.275122548852648, 0.6385943847043174, 25.30535316467285, 71.2603564943586, 59.376143727983745, 58.99636214120047, 51.53105429240635, 50.50018828255789, 49.026690755571636, 46.857973848070415, 45.7908729825701, 49.71204021998814, 51.82387222562517, 53.33242341450283, 55.54843323571341, 51.21890994480678, 50.22955594744001, 53.731013774871826, 49.282968112400596, 51.44668231691633, 52.75217587607247, 50.04752009255545, 50.20144353594099, 50.582812786102295, 48.86783409118652, 50.6119396345956, 55.464109897613525, 49.028184618268696, 45.29353829792568, 46.04032373428345, 49.56071540287563, 51.33755390984671, 52.36028357914516, 48.24810341426304, 53.24215241840908, 51.02196672984532, 41.15970754623413, 40.86353710719517, 37.261757714407786, 38.64425468444824, 37.752171993255615, 46.74114683696202, 43.91795825958252, 39.28046996252877, 36.27873352595738, 36.28725896562849, 36.35261719567435, 36.39199263708932, 36.957989420209614, 40.87314993994576, 38.79501322337559, 42.48126186643328, 41.7443185533796, 43.285449845450266, 46.23316751207624, 42.49084690638951, 45.94415371758597, 45.29398645673479, 43.54560777119228, 44.96700075694493, 47.925964082990376, 50.9096108845302, 43.85735607147217, 40.50346408571516, 38.28856250217983, 41.939024448394775, 37.8721604347229, 39.21698079790388, 45.199532645089285, 46.722793170383994, 47.87900815691267, 49.803499358040945, 45.889877864292686, 46.949505942208425, 44.04751784460885, 42.575955390930176, 47.06123992374965, 47.3062299319676, 44.21047394616263, 46.420629910060335, 42.8302629334586, 42.710576738630024, 40.2706230027335, 41.6051287651062, 38.72913040433611, 36.05522039958409, 37.56060320990426, 38.65239102499825, 35.86819921221052, 36.16224350248064, 36.498505047389436, 38.50330352783203, 37.62214340482439, 37.425002166203086, 38.378597259521484, 39.48200593675886, 38.725208146231516, 45.94585950034005, 43.35346576145717, 51.310084206717356, 51.78355530330113, 51.816079820905415, 52.109849657331196, 51.12670734950474, 55.07680688585554, 51.03663090297154, 45.12849078859602, 49.32201698848179, 49.00724969591413, 45.303422110421316, 44.895816462380544, 43.386198725019185, 49.2327013696943, 53.801954882485525, 55.50905084609985, 57.25830153056553, 54.53411088671003, 54.89416306359427, 54.27967480250767, 55.317464692252024, 56.57407072612217, 46.758416584559846, 47.09040151323591, 47.46053900037493, 55.34856482914516, 53.55465112413679, 60.193161555698936, 51.26859303883144, 62.34062739780971, 60.6847813470023, 71.14260537283761, 5.834539149488721, 0.5802595892122814, 5.961923948356083, 6.392903336456843, 1.0074510148593356, 11.421767592430115, 77.90837900979179, 66.88204642704555, 67.3018079485212, 70.25045667375836, 75.5078180858067, 61.6287636075701, 47.45070729936872, 35.32299491337368, 57.05737699781145, 84.04742513384137, 38.65040731430054, 0.719943893807275, 0.43376284731285913, 0.2789680835391794, 0.15546852190579685, 0.14380002660410746], [0.028535257559269667, 0.06087494561714785, 0.0633887889395867, 0.03393881867772766, 0.07165740310613598, 0.06331541894802026, 0.036164790125829835, 0.057119437493383884, 33.950096879686626, 59.411447525024414, 43.4093987601144, 20.527111734662736, 20.075728961399623, 37.28134816033499, 49.66471951348441, 63.67100593021938, 56.127947739192415, 57.33911950247628, 52.88032150268555, 40.4321026120867, 0.054428537243178914, 0.10024349990167788, 7.074789558138166, 0.11351261181490761, 0.12452360668352672, 17.01864664895194, 68.36617469787598, 52.891449042728965, 53.17198950903756, 46.608582156045095, 48.845582485198975, 41.12446280888149, 44.055192129952566, 39.24992568152291, 39.89491653442383, 41.796006202697754, 48.31607416697911, 48.992057459695, 48.8218126978193, 48.21635709490095, 50.820274421146934, 48.45843580790928, 47.70186035973685, 47.63580730983189, 46.586507729121614, 45.501105308532715, 42.56050259726388, 42.10647256033761, 46.44312470299857, 48.886691502162385, 48.04324967520577, 41.954904556274414, 40.68616001946585, 40.24758277620588, 40.32402685710362, 41.62047038759504, 36.39614071164812, 43.05093077250889, 46.77649579729353, 38.4917174066816, 37.66022300720215, 35.76628303527832, 38.04103292737688, 39.70921550478254, 38.88213668550764, 32.45439291000366, 34.32948241915022, 31.275961058480398, 34.31623567853655, 34.41768285206386, 33.98970855985369, 32.94597101211548, 33.849688461848665, 35.82619735172817, 36.919503348214285, 38.132387842450825, 38.31650815691267, 39.72319875444685, 40.948444093976704, 39.83888626098633, 41.760917799813406, 38.888202462877544, 43.520698479243684, 43.09779289790562, 44.6568957056318, 42.20133978979928, 37.772641386304585, 35.640711716243196, 36.86427559171404, 37.540578501565115, 40.244556835719514, 39.56970957347325, 43.39662797110421, 41.85164737701416, 43.02991247177124, 40.01137181690761, 42.52959353583199, 36.44469472340175, 40.42687061854771, 41.343890394483296, 41.51473617553711, 38.88718802588326, 40.060971532549175, 38.03502968379429, 37.512049198150635, 35.249795641217915, 35.66285909925188, 35.344739300864084, 31.883855479104177, 32.52982602800642, 32.6541953086853, 32.49992445537022, 33.31321804864066, 31.2749605178833, 32.53631911958967, 32.664624554770334, 36.47867488861084, 35.568398339407786, 36.161909988948274, 39.62017433983939, 38.351586137499126, 45.231793131147114, 48.886684553963796, 48.69319806780134, 50.80665595190865, 47.09405626569475, 49.296569211142405, 41.12016534805298, 32.444328444344656, 44.097527503967285, 43.585709299360005, 47.01697989872524, 47.58798633302961, 49.60072660446167, 46.71890912737165, 44.20420667103359, 39.340165410723, 38.27780669076102, 44.14297219685146, 51.12579713548933, 53.022290570395334, 55.52491705758231, 50.648754664829795, 51.92274161747524, 43.706969261169434, 44.54068013599941, 43.002491406032014, 50.059210436684744, 46.171547412872314, 48.88547556740897, 45.46887608936855, 58.75810146331787, 54.36297675541469, 64.39126314435686, 5.0763291375977655, 0.3245084227195808, 1.4900573641061783, 0.6742300125105041, 0.3342476529734475, 12.494637199810573, 66.48942456926618, 54.48060975755964, 56.67889125006539, 57.37696286610195, 63.53709329877581, 47.42861897604806, 26.28195548057556, 27.265486887523107, 44.1544679914202, 62.867161887032644, 12.934294887951442, 0.6270184144377708, 0.06495657802692481, 0.1680160050413438, 0.04126012331939169, 0.03775879780628851, 0.04589684147919927, 0.030728462551321303, 0.07870911221419062, 0.015493371756747365, 0.10512319805898837, 0.031193021551838944, 0.10640324080096823, 0.10471941544009106, 40.618171896253315, 65.98879296439034, 50.504555225372314, 25.855499369757517, 30.742930003574916, 45.79401009423392, 51.43207025527954, 69.6646887915475, 59.859467370169504, 62.79792308807373, 56.50992843082973, 42.6628634589059, 0.038495588448962996, 0.28133579077465193, 5.36197566134589, 0.30789745120065554, 0.23468664394957678, 18.653936454227992, 69.67814745221818, 55.51913268225533, 56.04454503740583, 48.64617960793631, 49.01816184180123, 42.904358523232595, 45.62549543380737, 41.426202229091096, 43.54101153782436, 43.26141255242484, 50.898747376033235, 51.072865758623394, 51.067300251552034, 50.61298533848354, 53.27166836602347, 50.162655217306956, 49.570203168051584, 49.99051359721592, 49.78087254932949, 47.896917138780864, 44.87834869112287, 44.926273890904014, 47.98923437935965, 49.84490367344448, 49.841582434517996, 43.091209479740684, 40.5187987600054, 41.06459018162319, 41.093828201293945, 41.4225891658238, 38.49734197344099, 45.48003142220633, 47.19008731842041, 40.56162745612008, 39.59039436067854, 37.453052043914795, 39.504434721810476, 42.15993200029646, 40.693459102085654, 34.027041230882915, 34.85153184618269, 34.51482214246477, 36.463896070207866, 36.122312205178396, 35.37888274874006, 34.42299822398594, 36.56219570977347, 36.754876204899375, 37.95645250592913, 40.94519928523472, 39.93099158150809, 41.1366742679051, 41.65314776556832, 41.56450612204415, 40.76898602076939, 39.97993469238281, 43.97994661331177, 45.30736868722098, 45.49336501530239, 43.83102934701102, 39.392975194113596, 37.111020020076204, 39.05846112115042, 40.02882916586739, 41.27474192210606, 40.658620834350586, 45.38619600023542, 44.55139078412737, 44.08768885476248, 43.445616245269775, 44.260865756443565, 39.90677016122, 42.84679617200579, 43.95323773792812, 42.49863583700997, 40.75835527692522, 41.66879163469587, 41.73752668925694, 40.2884590285165, 36.709101472582134, 36.6458728654044, 36.22038950238909, 33.75119079862322, 33.952865736825125, 34.21687643868582, 33.8575051852635, 33.798184939793174, 32.82680940628052, 34.28694902147566, 35.168029240199495, 37.86498989377703, 37.55207429613386, 38.001178060259136, 39.77766568320138, 40.56113065992083, 46.3487160546439, 50.34258229391915, 49.28527838843209, 51.01192658288138, 49.5143118585859, 50.179633140563965, 42.70847143445696, 33.49730362210955, 44.50926038197109, 44.375500610896516, 46.87091139384678, 49.21423653193882, 50.64604834147862, 46.097774914332796, 45.821851525987896, 39.65066998345511, 39.965385164533345, 44.519109453473774, 51.09331430707659, 54.58239391871861, 58.727584975106375, 53.119353430611746, 54.062262194497244, 44.88980974469866, 46.17996515546526, 44.314752510615754, 51.168233258383616, 49.40866449901036, 51.18712888445173, 49.19043895176479, 61.66292095184326, 55.78284113747733, 70.43684904915946, 6.889307831014905, 0.33367773784058435, 2.843511623995645, 1.805112789784159, 0.4871324492352349, 14.368261507579259, 73.30659403119768, 58.155543259211946, 60.521359716142925, 62.426826749529155, 69.06777599879673, 52.66900246483939, 33.74571214403425, 29.301154477255686, 51.155716078622, 70.34362506866455, 19.088534116744995, 0.5758819526859692, 0.25746514594980646, 0.17343863977917603, 0.047455677296966314, 0.026022057148760984, 0.14805478043854237, 0.21797706772174152, 0.2027386368385383, 0.05186792589457972, 0.20535079309982912, 0.2990579040987151, 0.23787421147738183, 0.24691569060087204, 49.05601910182408, 76.22308649335588, 56.03689159665789, 29.20103440965925, 28.821466479982647, 51.96641451971871, 59.01585878644671, 73.26611382620675, 65.90348993028913, 67.61818722316197, 62.84351716722761, 47.74384137562343, 0.11061475838401488, 0.6710146793297359, 18.33706906863621, 1.2731511060680663, 0.29035493252532824, 20.132869209562028, 71.74561173575265, 57.750237464904785, 58.9364686693464, 49.807067258017405, 53.75479745864868, 44.30714075905936, 49.62284619467599, 43.32135813576834, 45.27359001977103, 45.66374526705061, 54.03876338686262, 53.1413687978472, 52.53047970363072, 53.169241496494834, 54.8344224521092, 53.11783177512032, 51.79550273077828, 50.44883067267281, 51.250399180821006, 50.133980001722065, 47.409236976078574, 46.76382228306362, 52.15350866317749, 52.93731757572719, 52.465340341840474, 44.04382487705776, 40.2626325743539, 41.913597515651155, 42.55978345870972, 42.37609740665981, 41.206093720027376, 46.654099805014475, 49.22892154966082, 42.35248395374843, 42.17763601030622, 39.91596610205514, 41.43979637963431, 43.44065523147583, 43.9999817439488, 36.18902880804879, 37.21585096631731, 36.1389878817967, 38.97065673555647, 38.3022643498012, 37.231890882764546, 36.07769087382725, 37.45932279314314, 38.69657461983817, 41.031846795763286, 42.293650082179475, 43.19041933332171, 43.15171786717006, 45.23551389149257, 42.45570639201573, 44.20219169344221, 41.37937831878662, 45.75557265962873, 48.039650508335654, 48.82283408301217, 44.81067671094622, 42.19184160232544, 39.83032955442156, 41.00342518942696, 42.93656342370169, 42.70103686196463, 41.37369816643851, 47.38941376549857, 45.28100722176688, 47.00429943629673, 46.92314100265503, 48.13574409484863, 41.577811922345845, 45.86043834686279, 46.425903592790874, 45.98104517800467, 45.19256360190255, 45.81479563031878, 43.52718809672764, 43.6875490461077, 39.68059587478638, 38.80571344920567, 40.44091987609863, 35.878802163260325, 35.863245146615164, 37.16168628420149, 35.63691105161394, 37.40879896708897, 33.76361417770386, 35.78094720840454, 36.66645342963082, 40.376881803785054, 39.990499428340364, 40.69922958101545, 42.531097820826936, 41.72757339477539, 49.051412446158274, 53.116685322352815, 52.46409314019339, 53.20109551293509, 50.04731512069702, 51.283552510397776, 45.17828505379813, 35.689109393528526, 43.147139004298616, 45.33239957264492, 47.68341636657715, 51.146520137786865, 50.94891684395926, 48.28228160313198, 44.27600935527256, 41.21912159238543, 41.877807344709126, 45.89006199155535, 51.532652378082275, 56.27012872695923, 59.06045927320208, 56.44474043164934, 55.14710875919887, 47.190785612378804, 48.11481959479195, 46.91852739879063, 53.34094885417393, 49.03501122338431, 53.720952783312114, 51.20747320992606, 63.542339188711985, 58.87221867697579, 71.56659834725517, 8.648604307855878, 0.3986925748842103, 6.091113541807447, 3.697582457746778, 0.7609394597155708, 16.69600531033107, 77.78484003884452, 62.05652945382254, 67.66647025517055, 68.29499040331159, 76.01308413914272, 61.91325759887695, 38.69694287436349, 40.386195863996235, 61.87162399291992, 81.29452800750732, 25.727638619286672, 0.9480046161583492, 0.3487276445542063, 0.2495494107050555, 0.10728576380227293, 0.17491486056574754], [0.05095976444759539, 0.0659508625311511, 0.003213327473661463, 0.08525329748434679, 0.04295473738706537, 0.05473082798666187, 0.1287175909216915, 0.17257098348012992, 23.269675152642385, 65.14380168914795, 39.14806161608015, 42.03068855830601, 39.25018276487078, 38.93525218963623, 51.09570101329258, 55.33094767161778, 54.2366098676409, 55.44019767216274, 51.59547451564244, 49.29101760046822, 0.3426503049475806, 0.16086150466331414, 1.7608010875327247, 0.2804716085749013, 0.09529554112149136, 13.941319022859846, 68.617185320173, 51.399917466299875, 56.78996862683977, 45.55813264846802, 46.911183152879985, 42.343687534332275, 42.77954455784389, 38.94399649756295, 39.678428036826, 37.36995158876692, 40.00792898450579, 41.61992495400565, 45.67929186139788, 48.336859703063965, 48.57820190702166, 48.36424602781023, 49.8284329686846, 44.996388162885395, 45.75969988959176, 41.59001643317086, 38.399247305733816, 39.82735572542463, 45.675369603293284, 45.84898771558489, 48.101367882319856, 49.52489743913923, 45.273423263004844, 43.80109650748116, 45.753206798008506, 41.084694794246126, 44.979948725019185, 48.766296591077534, 41.67030981608799, 37.557910782950266, 38.74149819782802, 35.93609006064278, 39.14119332177298, 39.244460923331125, 37.892977237701416, 37.44826820918492, 36.650604588644846, 32.41626814433506, 33.90442289624895, 33.60696356637137, 34.297802107674734, 35.16937371662685, 33.88689259120396, 36.02977957044329, 37.795261246817454, 38.146107060568674, 38.75993871688843, 36.98885331835066, 41.67049046925136, 41.914618900844026, 40.815983636038645, 38.59717716489519, 42.659545694078716, 44.86560916900635, 46.163470132010325, 43.24779060908726, 38.223676749638145, 35.046682425907676, 35.86393649237496, 37.86091130120413, 41.83205345698765, 39.28488554273333, 44.148086071014404, 44.47953946249825, 43.71827745437622, 40.72430215563093, 42.03396463394165, 38.53061689649309, 39.08910615103585, 38.09728554316929, 41.211374350956504, 39.48952388763428, 39.12756790433611, 36.139880725315635, 35.723548139844624, 35.330443382263184, 33.34180293764387, 33.02507972717285, 33.39035694939749, 32.91420384815761, 33.2752183505467, 34.82318319593157, 35.06180170604161, 33.63977643421718, 34.728680746895925, 34.417939935411724, 34.987521989004954, 36.077395575387136, 37.61242982319423, 38.96544211251395, 39.36650603158133, 45.119861125946045, 50.29401438576834, 48.381449767521445, 48.62200335093907, 48.53309767586844, 47.84091813223702, 46.40975945336478, 49.041209016527446, 47.240777901240754, 47.65979596546718, 50.25980840410505, 48.07291848318917, 49.806296007973806, 50.62566580091204, 49.70465081078665, 47.672351360321045, 46.24796370097569, 47.64517000743321, 53.56614691870553, 50.44559976032802, 50.19275481360299, 50.395068986075266, 50.630981172834126, 42.71459627151489, 43.47559077399117, 41.70047194617135, 42.62122985294887, 44.76788970402309, 49.33495453425816, 45.83580003465925, 60.421458516802105, 54.385016441345215, 65.45593561444963, 7.177985072135925, 0.38070423156023026, 0.6409661631499017, 0.8236692079475948, 0.2904058226517269, 21.41817651476179, 66.83631338391984, 53.173521586826865, 60.91694150652204, 59.20166751316616, 62.837569509233745, 47.06470707484654, 27.048657928194316, 31.58066041128976, 48.57439776829311, 64.27751418522426, 8.533750585147313, 0.48140099963971544, 0.013887214906779783, 0.14349913703543798, 0.05102372655112829, 0.04873541469818779, 0.0654733299410769, 0.05660659054826413, 0.04604877225522484, 0.0035483954873468193, 0.06299275519060236, 0.017827035193996768, 0.10394570231437683, 0.10234874300658703, 29.665243557521276, 72.85847691127232, 42.57987070083618, 30.663988045283727, 27.626068864549907, 47.108609267643516, 54.87161615916661, 63.87283720288958, 58.73419966016497, 63.894091742379324, 55.22140237263271, 52.90592908859253, 0.22514203110975878, 0.20047338839088166, 4.111061070646558, 1.6127545173679079, 0.11094881474439587, 15.50343040057591, 72.10022694723946, 54.15761579786028, 57.39507334572928, 47.12240491594587, 48.67617845535278, 43.12318161555699, 44.92653097425188, 41.53369780949184, 41.92577770778111, 38.73229530879429, 42.22534581593105, 44.66794681549072, 48.10430697032383, 49.97805895124163, 50.47338908059256, 49.73537574495588, 51.41223314830235, 47.38875716073172, 46.09278610774449, 42.46585076195853, 41.106776169368196, 43.04580300194876, 47.99661684036255, 48.062332902635845, 49.581066676548545, 49.42797701699393, 48.369891439165386, 43.97293240683419, 45.8263852255685, 43.23379693712507, 47.59550428390503, 50.7069354057312, 44.162493160792756, 39.04998084477016, 40.258922236306326, 36.576283182416645, 41.12872205461775, 41.20281764439174, 40.721922397613525, 38.67686605453491, 38.194754873003276, 35.590907028743196, 35.79560790743147, 34.340988636016846, 35.4045980317252, 34.89449603216988, 35.61444405147007, 36.20727825164795, 38.60144683292934, 40.02602904183524, 40.74300670623779, 40.581502778189524, 42.77117197854178, 41.27426944460188, 42.424752167293, 40.065842219761436, 43.27668816702706, 46.971990312848774, 48.46192380360195, 44.67402996335711, 41.157369477408274, 36.6222767829895, 37.292086601257324, 39.98943287985665, 43.52063594545637, 40.73027065822056, 44.90066283089774, 44.82427086148943, 44.61547401973179, 41.300686495644705, 43.09182439531599, 41.11957127707345, 42.607545375823975, 40.09703615733555, 42.36946882520403, 41.30780145100185, 41.82818678447178, 37.73330415998186, 37.55759116581508, 36.9077330998012, 35.642587729862754, 34.83767713819231, 34.849110398973735, 34.10444416318621, 35.56963511875698, 36.486713954380576, 37.93854004996163, 35.4386442048209, 34.95899615968977, 35.42116253716605, 37.16915559768677, 38.65096664428711, 39.0017533983503, 40.222989627293174, 41.805379322596956, 47.905098642621724, 54.13851867403303, 50.296342032296316, 49.44002519335066, 48.71340690340315, 48.75015592575073, 47.500470297677175, 50.73913335800171, 46.24631002971104, 49.064867632729666, 50.585119588034495, 49.632570198604036, 52.72016205106463, 51.60979127883911, 51.18234157562256, 47.90777022497994, 45.938397135053364, 50.1366411617824, 53.40582765851702, 52.220579624176025, 51.71610219138009, 51.06535823004586, 52.82201222011021, 44.46002892085484, 45.235541684286936, 44.100692408425466, 45.635316712515696, 46.9655111176627, 52.0884804725647, 47.88924980163574, 63.7102632522583, 55.8587189401899, 69.67647988455636, 9.710766741207667, 0.45325373858213425, 3.062372062887464, 1.9327549976961953, 0.2835865185729095, 22.750262566975184, 74.50072533743722, 57.83666958127703, 67.54430702754429, 64.12700230734688, 68.71767016819545, 54.851636614118306, 33.982055119105745, 32.05963100705828, 57.46648345674787, 71.0169402531215, 13.11098062992096, 0.6804187947085926, 0.08115536666342191, 0.18407630468053476, 0.08327596501580306, 0.08196164268468108, 0.1735542757170541, 0.20775370273206914, 0.11909498726683003, 0.15212681836315564, 0.11386554501950741, 0.10135837364941835, 0.22001107143504278, 0.2830540585730757, 33.13660178865705, 83.38915279933384, 51.8087876864842, 54.755866118839805, 51.11052846908569, 54.48914214542934, 60.99294090270996, 67.31735106876918, 62.0800074168614, 67.8343665259225, 60.45590073721749, 58.50373486110142, 0.5918187318103654, 0.5453103131481579, 8.94017503942762, 2.1558473237923215, 0.3208037572247641, 16.85880855151585, 72.58581570216587, 55.28656605311802, 59.74661472865513, 49.40458938053676, 51.824396814618794, 45.84004885809762, 47.99676622663225, 43.51705067498343, 43.818414892469136, 41.37417411804199, 42.776202474321636, 47.27147156851632, 50.06150334221976, 53.38129356929234, 53.104310580662315, 51.99012524741036, 54.77759313583374, 49.9028377532959, 49.8817013331822, 45.65594591413225, 43.005392278943745, 45.807847431727815, 49.44991595404488, 49.68095745359148, 51.115975856781006, 51.542119298662456, 50.43528515951974, 47.26870618547712, 49.37892968314034, 44.94725745064871, 48.88534007753645, 52.444193499428884, 44.853498458862305, 41.22888381140572, 44.0743795803615, 40.28762871878487, 43.052066802978516, 42.80319275174822, 44.19240862982613, 41.48317398343767, 40.78805535180228, 36.60105698449271, 37.481925283159526, 35.73884807314192, 38.481534821646555, 37.956139836992534, 37.83529676709856, 37.67881291253226, 40.607332706451416, 42.87483215332031, 44.52911833354405, 42.22689526421683, 46.55114834649222, 43.937729358673096, 45.16795308249337, 40.448621954236714, 44.81766659872872, 49.60793883459908, 51.08465685163225, 46.318234307425364, 43.43528774806431, 38.91540118626186, 39.3823687689645, 41.44113738196236, 44.46308612823486, 41.71194689614432, 47.35140017100743, 46.19550827571324, 47.34641831261771, 45.281399794987266, 46.56938736779349, 41.18517616816929, 43.761252062661306, 42.18667561667306, 46.01816940307617, 44.29871259416853, 43.445623193468364, 41.1420521736145, 40.082761083330425, 39.38036073957171, 38.710363319941926, 37.29228809901646, 37.47912515912737, 37.61770698002407, 38.70399529593331, 39.53665351867676, 40.32812976837158, 38.126349857875276, 38.31639698573521, 38.19097852706909, 39.609376839229036, 40.430184909275596, 42.299323286329, 43.12815652574812, 43.138040338243755, 48.436632360730854, 54.30676235471453, 51.97799369267055, 51.62890577316284, 51.0015355518886, 49.82507004056658, 49.66165535790579, 50.41772011348179, 49.13062538419451, 49.96425288064139, 54.22699008669172, 52.66020951952253, 54.163827487400596, 54.62806095395769, 50.641448634011404, 50.39984587260655, 48.351523876190186, 53.14934532982962, 55.952596051352366, 53.923190525599885, 53.871989250183105, 54.43547078541347, 54.26278025763375, 47.51769140788487, 47.164229597364155, 44.98582690102713, 47.34842981610979, 49.40012168884277, 53.56963491439819, 50.31023842947823, 66.0835941859654, 59.73873547145298, 72.88982718331474, 12.702050481523786, 0.33257612266710823, 3.5178911856242587, 3.1666747289044515, 0.5633143984845707, 27.30387568473816, 80.42052800314767, 64.51176575251988, 72.49148695809501, 68.85876028878349, 75.31450530460903, 60.78636401040213, 41.75481033325195, 45.71441847937447, 66.48531123570034, 81.58117594037736, 19.902274131774902, 0.9013827464410237, 0.18422491742031916, 0.3244478702545166, 0.2256457076541015, 0.1737632645027978], [0.04848081139581544, 0.01264971461413162, 0.05153024954987424, 0.006620232506455588, 0.03390227956697345, 0.019306126183697155, 0.05199452356568404, 0.09660734608769417, 18.139761073248728, 67.14181177956718, 43.35907643181937, 56.00727142606463, 43.16239377430507, 37.14118562425886, 47.51844528743199, 48.51151309694563, 49.355632373264854, 61.15572329929897, 46.45556197847639, 54.10105398723057, 2.9628879725933075, 0.22838430213076727, 1.37830579493727, 0.7479947486094066, 0.1622432598045894, 7.595022899763925, 67.12223870413644, 50.9520400592259, 54.68706158229283, 44.42480155399868, 44.73130396434239, 39.74902173451015, 45.051386628832134, 42.11584915433611, 43.124362809317454, 39.69675391060965, 36.29905353273664, 36.208191939762656, 37.600683893476216, 37.58275754111153, 42.66117852074759, 42.12541682379586, 41.552968638283865, 42.30474288122994, 40.21471432277134, 38.26107195445469, 35.902502468654085, 37.25686618259975, 42.16984013148716, 44.8789427621024, 46.24420125143868, 44.53231103079659, 49.23870461327689, 47.45063434328352, 46.381355217524934, 45.46981062207903, 48.0683604649135, 44.68882615225655, 40.34731027058193, 39.490798882075715, 38.151141030447825, 37.1314685685294, 39.87423522131783, 39.24846655981881, 39.10323878696987, 39.01936708177839, 34.92366804395403, 32.78103814806257, 34.491517884390696, 34.405488763536724, 33.87461512429373, 32.10405778884888, 34.88915286745344, 35.31130804334368, 37.03871011734009, 37.01580885478428, 38.66210113252912, 37.825478962489534, 38.50421721594674, 39.1123617717198, 38.88071230479649, 38.73403583254133, 40.68660123007638, 43.36492681503296, 46.98159967150007, 44.2149520601545, 40.44955996104649, 35.87486948285784, 35.357551779065815, 40.0564934185573, 43.01654413768223, 39.44652843475342, 45.31783962249756, 44.052669933864046, 39.55065066473824, 40.52093880517142, 41.019986220768516, 38.39063153948103, 40.22843354088919, 40.41760172162737, 41.06929758616856, 38.93096167700631, 37.175422872815815, 36.051402364458355, 36.699954169137136, 35.08357388632638, 32.398303576878135, 31.80409015927996, 33.04759883880615, 31.522406714303152, 31.94405119759696, 34.28815105983189, 39.13381780896868, 38.80003329685756, 42.60055896214077, 38.91031510489327, 38.718277318137034, 37.55160181862967, 36.793275424412315, 37.972614015851704, 37.834793022700715, 45.46980019978115, 49.228754792894634, 48.314917291913716, 49.42924158913748, 49.386301721845356, 48.38253716060093, 50.23070240020752, 47.14120674133301, 50.29553951535906, 49.40982484817505, 49.171678815569194, 47.70470217296055, 47.46787977218628, 47.00311129433768, 49.42312022617885, 45.90659523010254, 52.874926226479666, 50.48443324225289, 53.82962955747332, 47.061573437282014, 51.016467230660574, 45.42428255081177, 43.742161887032644, 40.33000578199114, 42.74753768103463, 41.28212438310896, 49.55468784059797, 43.93639530454363, 49.87780686787197, 48.22762707301548, 62.332928793770925, 54.098483153751914, 64.06831782204765, 9.653759377343313, 0.4041797247316156, 2.8836242258548737, 1.6660026886633463, 0.08073544848178114, 21.949300289154053, 67.6926371710641, 53.9110381262643, 59.56516252245222, 60.628327233450754, 59.256836209978374, 39.76938343048096, 27.887694597244263, 40.92622028078352, 46.70481818062918, 59.83865751538958, 4.425825757639749, 0.4305267781019211, 0.04643699945881963, 0.043546131545943875, 0.027469236636534333, 0.034123190212994814, 0.03244477956156645, 0.00750553368457726, 0.05338442791253328, 0.04269711460386004, 0.037766828268234215, 0.04264705568285925, 0.13664041007203714, 0.07426668237894773, 21.74990609713963, 74.55963216509137, 47.90642922265189, 52.08554138456072, 36.34401185171944, 48.20223488126482, 50.977915150778635, 54.07629060745239, 54.27332067489624, 65.07802309308732, 51.65350587027413, 60.122192655290874, 2.7865203278405324, 0.07856490316667727, 1.6610794556992394, 3.061338952609471, 0.13416292944124766, 9.031224233763558, 69.93295873914445, 53.33626576832363, 57.15743800571987, 45.00991630554199, 46.9323091506958, 41.0105470929827, 45.620892252240864, 43.98970883233206, 44.590026242392405, 41.06146001815796, 38.77075706209455, 38.09136915206909, 39.68214184897286, 40.96016917909895, 44.372558048793245, 44.17395074026925, 44.716820444379536, 43.689022064208984, 41.851709910801475, 38.20878676005772, 37.785589354378835, 38.37752376283918, 45.01953608649117, 47.64956474304199, 49.09470319747925, 46.940768582480295, 49.30465691430228, 48.7875337600708, 48.92308269228254, 47.54840244565691, 50.15567922592163, 47.28172363553728, 42.5199042728969, 40.34776190349034, 39.0784649848938, 37.92308030809675, 41.28077295848301, 40.83216251645769, 40.40692581449236, 41.80719975062779, 36.99201474870954, 36.1326858656747, 36.407101494925364, 35.05191789354597, 35.04389272417341, 33.70664242335728, 35.94049521854946, 35.73704154150826, 38.01239592688424, 38.759226526532856, 40.43679959433419, 39.42252588272095, 41.64364262989589, 40.83524751663208, 39.83865349633353, 38.99295350483486, 41.57444552012852, 43.241182872227256, 49.412607601710725, 45.67045027869088, 42.37536784580776, 37.85900402069092, 37.984891482761924, 41.72813967296055, 42.694165093558176, 40.31839186804635, 46.61078126089913, 44.035125732421875, 42.628956249782014, 42.12082059042794, 41.33666426794869, 39.03976699284145, 42.12336710521153, 42.32073416028704, 43.62670714514596, 42.54756505148751, 40.124033382960725, 38.27345017024449, 39.43199627740042, 37.481810637882774, 35.06201710019793, 33.69421557017735, 34.39263459614345, 32.45058182307652, 34.14454569135393, 35.71246228899275, 42.29394538061959, 42.751300130571636, 43.60545260565621, 41.30580036980765, 40.87902464185442, 40.06227431978498, 38.74948515210833, 39.27628019877842, 41.12350743157523, 47.26229647227696, 50.87273679460798, 49.10484756742205, 50.649553707667756, 50.69099971226284, 50.19311611992972, 52.61593212400164, 49.179241929735454, 51.64370196206229, 49.97806242534092, 49.86837468828474, 49.065020493098665, 48.7851505279541, 48.10841335569109, 50.0938263620649, 50.70097385134016, 54.27510983603341, 53.351458004542756, 55.975215911865234, 49.84804425920759, 51.891266277858186, 47.232853480747764, 46.128336565835134, 42.48288427080427, 45.077240875789094, 43.595252650124685, 50.82857404436384, 45.856040137154714, 51.49864442007882, 49.54998391015189, 64.39272226606096, 56.18459292820522, 69.24971457890102, 13.453494685036794, 0.3513451341007437, 3.85447712455477, 1.5267570976700102, 0.1357733373131071, 24.2495413848332, 73.88493428911481, 58.337353297642295, 65.32551097869873, 65.55569090162004, 65.47314630235944, 48.03184073311942, 29.860588686806814, 39.29022870744978, 53.54946429388863, 69.03027657100132, 7.851252487727574, 0.7573117943746703, 0.10668899225337164, 0.08186107700956718, 0.1350416594317981, 0.1290305855550936, 0.16204047282891615, 0.12360966072550841, 0.1667502522468567, 0.11884189370487418, 0.14334156763340744, 0.1885892953723669, 0.1718827182693141, 0.15888888122779982, 25.75519691194807, 87.23594651903424, 54.97346632821219, 69.86634635925293, 54.113800457545686, 53.953658376421245, 58.649389948163716, 59.92683015550886, 59.35140814099993, 72.8217556817191, 55.72919757025582, 63.663196155003135, 4.446938293320792, 0.5870780519076756, 7.096273388181414, 4.271723398140498, 0.38896900521857397, 9.305328931127276, 73.11837427956718, 54.814640930720735, 59.36110782623291, 46.368546213422505, 49.1528457232884, 42.5172153200422, 47.75142880848476, 47.05406938280378, 46.57867363521031, 43.36743858882359, 40.2707793372018, 40.06558861051287, 42.24061448233468, 41.57646744591849, 47.135338987622944, 45.28087173189436, 46.528156757354736, 46.67909247534615, 44.40034736905779, 40.87702703475952, 39.93702956608364, 40.158812591007774, 46.69073418208531, 49.558405126844136, 49.79937212807791, 49.312279088156565, 51.17232574735369, 51.034518650599885, 50.88495520183018, 50.66157756532942, 52.28394372122628, 47.90950380052839, 44.978955132620676, 43.10850702013288, 42.00767959867205, 41.202793325696675, 44.05441740580967, 43.56694916316441, 43.03239645276751, 44.11741672243391, 38.299492018563406, 36.53507341657366, 38.245150157383506, 37.38392441613333, 37.69217429842268, 35.80676324026925, 39.18485927581787, 38.545993259974885, 39.778607164110454, 41.43294545582363, 43.02752229145595, 42.78650317873274, 43.092248235430034, 43.28748219353812, 42.436831610543386, 40.855498041425435, 43.55174650464739, 44.689093657902305, 50.00234637941633, 46.28012343815395, 43.623642989567344, 37.981028284345356, 38.774644579206196, 43.12525565283639, 45.00634493146624, 41.31651449203491, 47.67564828055245, 46.17534460340227, 42.47629737854004, 44.41685281481062, 44.2130308832441, 41.77239622388567, 44.3891955103193, 45.36721352168492, 46.97531155177525, 44.30323587145124, 43.23398453848702, 42.06983470916748, 41.30115897314889, 40.14808804648263, 37.81157909120832, 35.67784636361258, 37.51557888303484, 34.24186216081892, 36.743189334869385, 37.586971623556956, 42.764797006334575, 44.35995054244995, 46.77783679962158, 43.37072161265782, 43.76960379736764, 42.586648668561665, 41.08224902834211, 42.03320033209664, 41.730012212480815, 49.17019190107073, 54.13284199578421, 50.84592717034476, 52.369854722704204, 52.42558969770159, 52.505556515284944, 55.37267507825579, 53.28073923928397, 51.83471488952637, 52.279319695064, 51.811111858912874, 50.939231055123464, 51.34518650599888, 49.092146260397776, 53.12998764855521, 51.93961531775338, 54.21346889223371, 55.29793678011213, 58.876992089407786, 52.186939920697895, 55.137350014277864, 48.74263102667672, 48.814034189496724, 43.44245481491089, 47.07790865216936, 45.03648969105312, 54.92370332990374, 47.70934704371861, 55.344486236572266, 52.62084450040545, 66.59290409088135, 58.56323228563581, 70.64873436519078, 16.93775919505528, 0.2693395902003561, 7.297296932765415, 4.930903341088976, 0.27592743241361206, 27.550555842263357, 79.48801027025495, 63.36909975324358, 72.80816500527519, 70.19280052185059, 70.52996185847691, 55.40684284482683, 42.66685519899641, 54.242359501974924, 60.65969835008894, 79.40694563729423, 11.290083595684596, 1.1710154094866343, 0.25835739235792843, 0.22405272456152098, 0.20132443415267126, 0.20364549889096192], [0.07154444059623138, 0.09730709889637572, 0.03429513777207051, 0.020274448241772394, 0.0469460194664342, 0.01321013958659023, 0.09285693376192025, 0.28927644182528767, 15.101854051862444, 68.63250609806606, 40.929305280957905, 33.800554275512695, 21.64434037889753, 34.44340508324759, 53.00937039511544, 54.386517252240864, 46.96711615153721, 63.58323628561837, 47.47855915342058, 62.1242743900844, 7.06500779730933, 0.19476357049175672, 0.9339371195861271, 1.805012366601399, 0.11963879237217562, 2.4951923489570618, 60.366887365068706, 53.30440132958548, 56.532037598746165, 43.90789031982422, 45.40103040422712, 42.12857130595616, 46.97348070144653, 45.83219391959054, 48.46965714863369, 46.37052297592163, 45.18208571842739, 37.19145931516375, 35.91880294254848, 35.56088386263166, 35.50286293029785, 34.27714163916451, 37.424616541181294, 36.12482050486973, 35.095166955675396, 35.74827330453055, 38.941411767687114, 36.033170291355674, 38.42952755519322, 39.666633469717844, 42.81924656459263, 44.57725545338222, 44.669551849365234, 43.11059495380947, 47.93925946099417, 44.531390394483296, 47.71201862607683, 44.65783371244158, 40.836387021201, 38.62455654144287, 40.47510848726545, 38.10700607299805, 40.226102420261924, 40.06456027712141, 34.98736218043736, 34.85738222939627, 33.97564540590559, 33.95942483629499, 35.70896734510149, 35.059133597782676, 34.703399726322715, 34.44645186832973, 35.17103781018938, 34.85629136221749, 35.932900837489534, 37.34246104104178, 41.23955624444144, 41.425559520721436, 37.8624781199864, 37.39909928185599, 39.53448568071638, 38.19925383159092, 37.40118721553257, 37.334241322108674, 43.09325919832502, 46.77324404035296, 40.905782154628206, 39.70304203033447, 36.362167494637625, 39.1157351221357, 40.28499187741961, 41.647665636880056, 44.97078057697841, 41.9840453011649, 38.75172247205462, 39.15766750063215, 38.94858578273228, 38.567713328770225, 39.43622425624302, 40.40917008263724, 39.830555370875764, 36.98269721439907, 36.30240951265608, 34.884473255702424, 36.60477774483817, 33.8698729787554, 33.16137211663382, 32.560898372105186, 34.89268255233765, 32.14575045449393, 32.95613970075335, 32.57900537763323, 33.05403634480068, 33.54016705921718, 38.210711411067415, 32.61150210244315, 34.28387096949986, 36.734587465013774, 37.813569750104634, 38.870932715279714, 41.27265746252877, 44.46422215870449, 44.972368240356445, 45.71036073139736, 45.85991375786917, 45.448076656886506, 45.687424727848594, 45.0972204208374, 47.02425466264997, 46.86854553222656, 48.774485043116975, 47.026974882398335, 45.162745407649446, 45.13887139729091, 45.29657118661063, 48.703912190028596, 49.38915743146624, 45.142953463963096, 49.42314107077462, 52.03654963629586, 47.40395287105015, 46.24818951742989, 44.86821474347796, 42.79298932211739, 39.208365031651084, 41.34087140219552, 40.410625730242046, 42.159956318991526, 42.108907903943745, 45.19377606255667, 46.1858537537711, 60.401683943612234, 53.120482512882774, 62.990568842206685, 15.729608161108834, 0.3034043551555702, 2.952572286128998, 1.938020863703319, 0.07144295889884233, 24.831960235323223, 67.26096643720354, 51.37587669917515, 63.427749497549875, 57.34778390611921, 55.67571381160191, 38.692225047520225, 25.1829571723938, 33.63021918705532, 49.31231035505022, 48.40885693686349, 1.3901393370968955, 0.14875633136502334, 0.033245898716683896, 0.04496492452121206, 0.0314951630176178, 0.07224016290690218, 0.10177365065153156, 0.028228300191195946, 0.014283677829163415, 0.01343043106940708, 0.12589650015745843, 0.0779561215479459, 0.11764054745435715, 0.14258565248123237, 18.030637877328054, 78.06616565159389, 45.757538999829976, 43.825432573046, 29.82403768811907, 44.758485317230225, 57.275077956063406, 58.213244574410574, 51.040306500026155, 68.25129318237305, 51.238771370479036, 65.99759633200509, 7.80724172932761, 0.1170577130147389, 0.6457052688513483, 3.2335999948637824, 0.03929118772170373, 3.4131266815321784, 63.277161189488, 56.110952445438926, 58.16802569798061, 44.37086616243635, 46.64042227608817, 43.47173452377319, 48.8263463973999, 46.68012775693621, 53.206581115722656, 48.44156905582973, 45.933165141514365, 39.75093943732125, 37.30414867401123, 38.069239139556885, 38.833509717668804, 37.11145428248814, 38.43450246538435, 37.854077747889924, 37.07502835137503, 36.87781415666853, 40.54363856996809, 37.673615659986226, 41.30654730115618, 41.36061470849173, 45.19697918210711, 45.320545945848735, 46.912558896201, 45.04482058116368, 49.148475306374685, 46.34911905016218, 48.8724615914481, 44.95225320543562, 42.470412254333496, 41.54402978079659, 41.65866116115025, 38.92410727909633, 40.72403812408447, 41.753945282527376, 36.0719655581883, 36.834342752184185, 35.36884607587542, 36.79642643247332, 37.18486200060163, 36.15127924510411, 36.78970752443586, 34.14698450905936, 36.17132132393973, 35.47348594665527, 36.95194101333618, 39.501697131565635, 42.345831053597585, 41.93495627811977, 41.01574781962803, 40.14218207768032, 40.622219221932546, 38.492999349321636, 37.79536894389561, 39.51827553340367, 44.61151702063424, 47.92092316491263, 41.441269397735596, 40.79551771708897, 37.81303473881313, 41.28405598231724, 41.19399690628052, 43.09295695168631, 46.47357518332345, 42.93421493257795, 41.69611195155552, 40.40249286379133, 39.79921899523054, 38.80632836478097, 42.30713653564453, 42.66974564961025, 42.69131285803658, 39.25396258490426, 39.16182599748884, 36.19421216419765, 40.541071210588726, 36.44685213906424, 35.93334204810006, 33.71030412401472, 35.83327409199306, 34.53671244212559, 34.30760601588658, 33.89371224812099, 34.394093717847554, 35.33334078107561, 41.375761781420024, 34.65017652511597, 38.39905275617327, 38.24344090053013, 39.19646276746477, 40.41261291503906, 43.01713126046317, 45.080193860190256, 46.23728084564209, 46.58983939034598, 47.03302328927176, 47.40009314673287, 45.88669558933803, 46.72079903738839, 50.20618568147932, 48.94976030077253, 49.87318284170968, 48.49749163218907, 45.97911705289568, 46.86577320098877, 47.85948371887207, 49.03964914594378, 49.92948409489223, 49.0537748336792, 51.84308399472918, 53.702491419655935, 50.09948566981724, 47.21324913842337, 45.07443380355835, 43.351356983184814, 41.11683021272932, 42.784092153821675, 43.786015442439485, 45.30465194157192, 44.32395887374878, 48.941394669669016, 47.14156109946114, 63.02765832628523, 56.591257095336914, 65.78546782902309, 20.857953684670584, 0.210115927404591, 1.221022788967405, 1.2082449431930269, 0.13509660719760827, 27.379800387791224, 73.28135817391532, 57.09562335695539, 72.30485139574323, 62.18543938228062, 59.98319394247872, 47.739502225603374, 30.849581377846853, 40.65239177431379, 56.96981232506888, 58.77720900944301, 2.7647789801870073, 0.34652826828616007, 0.09486143477261066, 0.07532107830047607, 0.03740349990714874, 0.0401841635549707, 0.1949001188789095, 0.20724625353302273, 0.15715635062328406, 0.12364161972488676, 0.2346951120666095, 0.13572058800075734, 0.2219173205750329, 0.33239047548600603, 20.44959589413234, 89.98244435446603, 53.47537217821394, 46.98876673834664, 30.804657799857004, 49.033972467694966, 64.18199035099575, 64.93516813005719, 55.68533706665039, 73.66995007651192, 56.77761125564575, 71.36977672576904, 11.203863399369375, 0.4331882367176669, 3.711458444595337, 6.8662497997283936, 0.24998473163161958, 3.8842201914106096, 65.1260073525565, 56.23729848861694, 60.028211321149556, 47.217119285038535, 49.55717529569353, 44.31169877733503, 50.910024302346365, 48.83121361051287, 54.16827086039952, 50.59177943638393, 49.08172743661063, 41.90860523496355, 38.85894012451172, 38.68410260336739, 39.52088458197457, 37.410372734069824, 41.702469553266255, 39.045825822012766, 38.376443317958284, 39.46512876238142, 43.19903857367379, 40.51793718338013, 43.512930393218994, 44.722597871507915, 47.05443068913051, 47.42581190381731, 49.3180947303772, 47.526793548039024, 51.533586910792756, 47.44734437125069, 51.67592075892857, 48.80451168332781, 43.79136208125523, 43.87071745736258, 44.47323397227696, 42.22546740940639, 44.825413840157644, 44.20843812397548, 37.070442540305, 38.83698034286499, 36.17224543435233, 38.948151520320344, 38.36912339074271, 39.31201478413173, 37.94189255578177, 35.97972822189331, 37.96265377317156, 37.96540525981358, 38.5246970312936, 41.419994013650076, 46.25555113383702, 43.72616365977696, 44.233528069087434, 42.01495436259678, 43.18309940610613, 40.142703192574636, 38.41915389469692, 40.20013700212751, 44.87992940630232, 47.8779033933367, 43.126558440072195, 41.07674952915737, 38.73036370958601, 41.29309906278338, 42.70952408654349, 45.04290982655117, 48.65883575166975, 44.21650150844029, 41.81493656975882, 42.089911528996055, 40.23471818651472, 42.01425954273769, 44.55651160648891, 46.085931709834504, 43.461485930851524, 42.52968038831438, 42.78998422622681, 39.020555223737446, 42.168092659541536, 38.19008568355015, 38.26841967446463, 36.00680187770298, 39.433080196380615, 37.18305894306728, 38.001931939806255, 35.84595455442156, 37.69226115090506, 37.251012325286865, 43.90857819148472, 37.197049140930176, 39.746218136378694, 39.60813658578055, 41.93338598523821, 42.37507254736764, 46.80176292146955, 47.9056510244097, 48.69234691347395, 48.961801528930664, 49.81389733723232, 48.874678066798616, 49.02332782745361, 48.15635940006801, 52.17539201463972, 50.430122647966655, 52.75919703074864, 51.48672825949532, 48.338412625449045, 48.91011387961251, 50.63228396006993, 52.55404451915196, 53.61692435400826, 51.28838150841849, 53.47492749350411, 55.94427905763899, 51.93831947871617, 49.66759259360177, 48.628235885075156, 44.59261792046683, 43.869984422411235, 45.12294612612043, 46.209783349718364, 46.57492855616978, 46.12384802954537, 48.909835951668875, 50.45902715410505, 64.60171018327985, 58.9399288722447, 64.35956546238491, 25.36352869442531, 0.20679411850869656, 5.842633366584778, 6.379413843154907, 0.4732621077980314, 31.082617010389054, 80.30186666761125, 60.84208161490304, 77.6614886692592, 65.674393926348, 66.73901081085205, 52.93989535740444, 35.90839106695992, 47.60048961639404, 65.03818907056535, 67.91364547184536, 5.652457697050912, 0.84799903099026, 0.32002976589969223, 0.1325745875281947, 0.12401625247938292, 0.19031314072864397], [0.03653717692941427, 0.07336430544299738, 0.019664882915094495, 0.038920113883380375, 0.025671849958598614, 0.07501043139823846, 0.13001773187092372, 0.12548865989914962, 7.34863543510437, 62.48606014251709, 42.588319710322786, 25.55919517789568, 17.552919694355555, 30.76946864809309, 53.03314365659441, 62.04512051173619, 42.981869152614046, 58.48547499520438, 47.997408935001914, 60.10540580749512, 13.414081028529576, 0.29960173634546144, 0.618069514632225, 3.7859882967812672, 0.22349334029214724, 0.029050703293510845, 46.246831144605366, 59.50304562704903, 54.38507202693394, 52.585162026541575, 44.16348327909197, 42.85953222002302, 45.948885440826416, 48.89631823131016, 50.28139993122646, 49.754441601889475, 50.85109315599714, 45.84001759120396, 41.13891158785139, 35.892358098711284, 37.74189908163888, 36.647095748356406, 35.728290285382954, 35.065598896571565, 37.021204130990164, 33.686100074223106, 36.1312232698713, 36.41696098872593, 36.091330187661306, 37.300222941807334, 38.94515684672764, 38.79678848811558, 40.733487674168174, 44.639813559395925, 45.16469437735421, 44.21105759484427, 45.511465072631836, 41.17203712463379, 40.26690224238804, 38.00839376449585, 36.67950562068394, 37.10177891595023, 39.09246213095528, 37.31501913070679, 35.885687828063965, 36.40368298121861, 33.97726086207798, 36.10961784635271, 34.47250066484724, 35.48363379069737, 35.30627407346453, 34.711470058986116, 34.93741505486624, 34.5389358656747, 36.78938095910208, 40.160306453704834, 41.44670288903372, 42.71977615356445, 43.40494496481759, 45.801475933619905, 40.78903157370431, 36.03415693555559, 37.91607652391706, 36.32005098887852, 40.72407633917672, 50.52296795163836, 44.88969162532261, 39.757231031145366, 35.986787591661724, 42.74294144766671, 41.799977098192485, 42.28163317271641, 45.007859638759065, 35.97125836781093, 39.40678126471383, 37.78624248504639, 37.32310683386666, 35.647771086011616, 37.903670515332905, 39.61165584836687, 42.429122584206716, 38.3582946232387, 35.736350195748464, 36.64646346228463, 36.85440567561558, 33.27824429103306, 33.12985856192452, 32.91964776175362, 32.63981601170131, 32.63478551592146, 32.525115149361746, 32.86043521336147, 33.24610539845058, 33.462322916303364, 33.682431425367085, 39.53188705444336, 36.558617387499126, 36.5396522794451, 36.40972096579415, 39.14701591219221, 40.534407888139995, 42.116669041769846, 43.784017835344585, 44.90708991459438, 43.71034608568464, 44.36918469837734, 45.78531789779663, 41.8126471383231, 40.06686360495431, 43.87992034639631, 42.2705785887582, 43.25259876251221, 40.57470396586827, 38.93130908693586, 45.056688104357036, 48.35069704055786, 49.31935930252075, 50.43640381949288, 49.260337829589844, 49.34779827935355, 51.10863161087036, 51.13715744018555, 44.065207958221436, 46.35137721470424, 44.7528920173645, 42.75398908342634, 42.617835657937185, 44.820133209228516, 42.47036361694336, 45.00569180079869, 44.35036897659302, 59.29929665156773, 51.67030314036778, 63.68652125767299, 24.78653986113412, 0.7555394609059606, 2.7110796102455685, 1.0460700797183173, 0.09684948130909886, 25.474178756986344, 65.92315333230155, 49.367065634046284, 53.829619135175435, 59.81746550968715, 53.47072383335659, 41.773514883858816, 21.477866751807078, 24.14969229698181, 49.37703629902431, 47.08462756020682, 0.5286215543746948, 0.12603684834071568, 0.08053124336791889, 0.0995978806167841, 0.0606272192671895, 0.037556574014680724, 0.04053913914997663, 0.05372738665235894, 0.0546229782381228, 0.014971656358933874, 0.07805549300142697, 0.017553078376555016, 0.16983766800590924, 0.16110475946749958, 9.291638374328613, 72.32243728637695, 50.74614061628069, 31.593736921037944, 24.386662346976145, 46.843782152448384, 54.90258080618722, 66.66455391475132, 47.39555597305298, 66.50056253160749, 51.82123538425991, 67.44002846309117, 15.587010281426565, 0.25683565544230597, 0.2624623120895454, 4.713519394397736, 0.46490869032485144, 0.124219433005367, 48.23091009684971, 61.74975953783308, 56.565444537571494, 54.26337085451399, 46.02633006232125, 44.49974134990147, 48.23595101492745, 51.88660751070295, 52.65878166471209, 51.44521277291434, 51.17121056147984, 48.40230825969151, 43.51913513456072, 37.92171846117292, 38.62908329282488, 37.57523264203753, 37.243834836142405, 38.56976304735456, 39.26466975893293, 35.09179013116019, 37.05265167781285, 37.49303892680577, 38.23795182364327, 37.68791505268642, 39.68570627485003, 42.59144639968872, 42.81759636742728, 46.46452515465872, 47.54379231589181, 47.214614459446494, 47.59328086035592, 43.28766284670149, 41.33683449881417, 39.76611082894461, 39.552540574754985, 40.026887144361226, 39.762296267918174, 37.15656198774065, 36.722257886614116, 38.51702969414847, 35.91247313363211, 35.92753682817732, 36.32980973379952, 36.50270523343767, 36.52287932804653, 36.84510898590088, 36.362862314496724, 36.080515316554475, 37.104436601911274, 41.5821475982666, 41.12412929534912, 45.29456663131714, 44.8996136529105, 47.944654737200054, 40.13032150268555, 37.14527811322893, 37.04185765130179, 36.04010459354946, 40.14030606406075, 51.070312295641216, 45.262062958308626, 41.490017959049766, 38.41081258228847, 44.456124033246724, 42.094747475215364, 43.37332023893084, 45.33237872804914, 37.87071520941598, 39.113146918160574, 41.10406289781843, 37.729406220572336, 36.08398246765137, 39.202347891671316, 41.21958017349243, 45.39656966073172, 40.50705977848598, 39.25502565928868, 38.469889640808105, 38.9095264843532, 36.92664609636579, 34.13174710954939, 34.64674064091274, 34.42096587589809, 33.74258892876761, 34.22167764391218, 35.15980952126639, 35.14440189089094, 33.228623730795725, 35.447975635528564, 41.485129901341026, 37.566596031188965, 38.48577669688633, 38.550975118364605, 41.40003183909825, 41.34045103618077, 44.28148453576224, 45.758445739746094, 47.332754680088584, 46.16088540213448, 47.423036098480225, 46.178495611463276, 45.12700734819685, 41.94911323274885, 44.64383656638009, 43.32028463908604, 44.071492603846956, 42.67375823429653, 40.81860658100673, 46.13411399296352, 49.20998076030186, 51.50324065344674, 51.502406869615825, 50.76199640546526, 52.86400713239397, 52.709802286965505, 53.84358501434326, 46.315746852329795, 47.69764280319214, 46.85325602122715, 44.85085466929844, 44.34983049120222, 46.819591999053955, 45.296911648341585, 46.68162509373256, 46.615613733019146, 61.353649684361045, 54.955533027648926, 66.34464495522636, 31.004904883248464, 0.5731297060847282, 1.5504037716559, 0.9222522037369865, 0.027136191293331127, 29.600069454738072, 70.82241153717041, 53.64043010984148, 60.38108948298863, 66.84546416146415, 58.586480958121165, 47.94235488346645, 22.92339777946472, 29.37429816382272, 57.12206472669329, 56.625410965510774, 1.6152940839529037, 0.2627852133342198, 0.040531101902680736, 0.07006692380777427, 0.07927046423511845, 0.017923689114728143, 0.07315880432724953, 0.1691340814743723, 0.16258647638772214, 0.18305870571306773, 0.26387217215129305, 0.0795619764498302, 0.2641462188746248, 0.3305795740868364, 10.343616485595703, 85.67336613791329, 56.17680399758475, 37.116338866097585, 24.738696302686417, 45.5150260244097, 63.18557698386056, 73.90886388506208, 51.50132295063564, 69.70970617021833, 55.36898211070469, 74.20480850764683, 18.276909828186035, 0.3602899898375784, 1.1916901000908442, 11.30895403453282, 0.37093340871589525, 0.20019764533000334, 51.21363278797695, 63.35212530408587, 59.844271659851074, 56.97766031537737, 47.54849624633789, 47.481063979012625, 50.65815905162266, 52.841286523001536, 54.39983000074114, 53.8410176549639, 53.85794346673148, 49.40643760136196, 45.01865019117083, 40.33394193649292, 40.63974257877895, 40.007487773895264, 39.62503113065447, 40.2622469493321, 41.0768780708313, 37.350295134953086, 40.056066104343955, 40.17560986110142, 40.179344517844065, 41.76008749008179, 42.92821168899536, 44.8008519581386, 44.93847145353045, 48.07705266135079, 50.62143782206944, 48.04512568882534, 51.04970741271973, 47.14938129697527, 44.68618583679199, 42.26925843102591, 41.6603113583156, 41.60591043744768, 42.276772907802034, 39.93311425617763, 40.12431131090437, 40.35775341306414, 37.13826738085066, 38.791757992335725, 38.077163560049875, 39.563518728528706, 38.907549721854075, 39.18119410106114, 38.32963677815029, 37.04051317487444, 40.141021728515625, 43.393219879695344, 41.96546581813267, 46.8033366884504, 47.00388254438128, 50.03568383625576, 42.125868456704275, 37.741846970149446, 39.30860669272286, 36.05919476917812, 40.37866749082293, 53.83347538539341, 47.45515414646694, 41.809221676417756, 39.588942187173025, 45.70170327595302, 46.7002705846514, 43.71661683491298, 46.18829951967512, 37.99293402263096, 40.237191745213096, 42.892841884068076, 38.19162123543875, 38.6304520879473, 41.29117441177368, 43.82886845724923, 46.818039076668875, 43.817942414964946, 41.28495577403477, 42.349836690085276, 41.209977763039724, 38.53417437417166, 36.755779470716206, 36.76850162233625, 36.81970289775303, 35.919275420052664, 36.61458512714931, 36.59962565558297, 36.95934779303414, 35.714904580797466, 37.03180013384138, 43.188890729631694, 40.828486919403076, 40.112766878945486, 40.26449816567557, 43.06640441077096, 43.8763941356114, 45.89177472250802, 48.43296718597412, 49.16436583655221, 46.9026438168117, 48.32083715711321, 49.434723717825754, 45.59571198054722, 44.81167377744402, 46.47298458644322, 45.37809092657906, 45.22129092897688, 45.03454419544765, 41.64416027069092, 49.783922808510916, 52.958902154650005, 53.939268657139365, 53.98285470690046, 53.615117822374614, 53.85559150150844, 55.10446419034685, 55.363764013562886, 48.455892767224995, 51.397892066410606, 49.78694180079869, 46.85776540211269, 47.35854639325823, 48.46178136553083, 47.573308263506206, 49.56977932793753, 49.31949826649257, 62.48444121224539, 57.300598689488, 66.41833754948208, 39.03707456588745, 0.38083765868629726, 5.780876474721091, 4.074719386441367, 0.43941260129213333, 33.65638957704817, 76.36680998120988, 59.534305572509766, 65.1841151373727, 71.09753240857805, 64.44928060259137, 54.18767370496477, 31.81415809903826, 37.842012201036724, 66.05354322705949, 66.89583165305001, 3.147065826824733, 0.47854279300996233, 0.21359700204006263, 0.3230770123856408, 0.23531795293092728, 0.13564550131559372], [0.04814667021855712, 0.04217959255246179, 0.031147885402398448, 0.049319612993193526, 0.0240759746105011, 0.037544604656951766, 0.07879047534827675, 0.04418943363374897, 3.278892913034984, 56.08118288857596, 44.45213576725551, 26.675808906555176, 21.123755284718104, 31.814720903124126, 52.29709318705967, 60.277533531188965, 41.37326042992728, 54.27613469532558, 51.75910806655884, 55.40322978155953, 27.960216420037405, 0.17987880563097342, 0.28240014080490383, 1.5202538009200777, 0.13501599723739283, 0.08227322596524443, 22.5334301335471, 67.38600621904645, 52.55132777350289, 56.28628328868321, 41.68162495749337, 41.266181741442, 43.48322684424264, 48.66693387712751, 49.29962641852242, 51.883359227861675, 48.42126294544765, 52.01351983206612, 48.28285830361502, 41.6397898537772, 36.434112616947715, 37.27928107125418, 36.975818497794016, 38.02633053915841, 36.599854946136475, 37.03221007755825, 35.92054694039481, 35.779175417763845, 37.60450540270124, 38.16252217973982, 39.661429268973215, 42.87310900006975, 42.848328249795095, 44.10011223384312, 44.87357527869088, 43.99005971636091, 45.085603032793315, 39.06135851996285, 38.7769444329398, 39.36636706760952, 36.91191938945225, 37.14914131164551, 35.80997678211757, 34.51088946206229, 38.45453759602138, 36.26666797910418, 35.72413526262556, 36.229453427451, 34.69594430923462, 36.26094266346523, 34.49660396575928, 36.049241474696565, 34.15355750492641, 36.100084917885916, 35.92633131572178, 40.45227323259626, 42.80791752679007, 45.00817925589425, 39.171588216509136, 36.29321704592024, 41.901653562273296, 35.40506356103079, 37.44506161553519, 35.115841320582796, 40.08996636526925, 44.78434998648507, 44.82349961144583, 43.82841682434082, 40.025855336870464, 43.55376148223877, 40.73751415525164, 42.85704129082816, 43.55623156683785, 37.29491451808384, 37.536180291857036, 36.39438281740461, 35.76335089547293, 35.44000605174473, 35.0984673500061, 42.06015239443098, 38.45496143613543, 34.94702788761684, 39.88729783466884, 37.86440971919468, 35.354136739458355, 34.86130796160017, 34.308752468654085, 32.3920328276498, 32.59918294634138, 31.370223794664653, 34.115040166037424, 32.62136507034302, 32.65029042107718, 33.06529590061733, 30.392699105398997, 32.743764536721365, 36.782429286411826, 37.1595983505249, 36.55253076553345, 37.21651799338204, 38.76889147077288, 41.21239226205008, 43.96512263161795, 45.25959287370954, 46.42759895324707, 46.96546595437186, 45.72121034349714, 43.44785009111677, 40.95410687582833, 39.8672661781311, 39.166279792785645, 39.58261585235596, 38.54626076562064, 37.63644279752459, 37.64460345676967, 47.6467159816197, 49.763383933476035, 47.69185495376587, 50.77904381070818, 51.97537769590105, 51.67039694104876, 49.03229100363595, 46.161548955099924, 46.46693965366909, 43.649928024836946, 43.869769028254915, 43.23866067613874, 44.37422561645508, 41.29788637161255, 44.7498903955732, 41.65069852556501, 53.71694367272513, 52.00759301866804, 59.1080961227417, 20.56998211996896, 1.3486347070762088, 0.20812988254640782, 0.9284767040184566, 0.07864830869116954, 33.863907950265066, 61.02256107330322, 51.63297394343785, 56.214060238429475, 55.97221776417324, 53.19640547888619, 45.25500011444092, 27.797508716583252, 30.89774281638009, 56.34284509931292, 32.04015520640782, 0.21964492036827973, 0.09389673439519745, 0.04041537775525025, 0.08228542602487973, 0.08283223704035793, 0.02018086638833795, 0.06140796201569693, 0.05009589098127825, 0.07326003496668168, 0.03406834762011256, 0.05745470164609807, 0.0314850732018905, 0.07985779736191034, 0.1428139523736068, 4.288405154432569, 67.30230127062116, 47.97302075794765, 31.16926452091762, 23.181551149913243, 38.43941831588745, 58.65933282034737, 65.19035461970738, 45.628736768450054, 60.62377616337368, 54.75093984603882, 60.74678707122803, 31.59598813738142, 0.1636422768767391, 0.3269322583717959, 4.146458234105792, 1.05344081563609, 0.2599929060254778, 26.07596049989973, 69.34425871712821, 53.05974136080061, 56.52254983357021, 43.57645429883684, 43.971977029527935, 44.86042928695679, 50.003815923418315, 50.78382069723946, 52.625260080610005, 49.89743900299072, 52.36900009427752, 52.25544915880476, 42.37791436059134, 37.999986444200786, 38.385979720524375, 39.2424806867327, 38.61036484582083, 37.22645739146641, 38.65869304112026, 36.93841634477888, 36.64811365944998, 36.39112411226545, 39.43503264018467, 42.35737895965576, 46.22995744432722, 45.523846762520925, 46.00734063557216, 45.536461217062815, 46.08658831460135, 46.43372031620571, 40.89036757605416, 41.42899193082537, 41.599198477608816, 38.21021808896746, 40.13824592317854, 38.99040699005127, 35.45507322038923, 41.615961006709504, 39.441671643938335, 36.64472641263689, 36.79991790226528, 36.006503105163574, 38.12423413140433, 36.447025844029014, 37.7107572555542, 35.84732682364327, 38.30124296460833, 37.16673762457711, 43.154212270464214, 44.4938770702907, 47.531685079847065, 41.55184303011213, 38.16067395891462, 42.41507332665579, 35.5774553162711, 37.11317048754011, 33.91464022227696, 38.76871081760952, 45.947853633335654, 43.7435028893607, 45.182999406542095, 40.97314493996756, 45.25837346485683, 42.179463386535645, 44.51781708853585, 43.62441423961094, 38.44859341212681, 38.25363390786307, 38.578090463365825, 35.71839257649013, 35.350381238119944, 37.04805197034563, 44.0427166393825, 41.55770036152431, 37.23280804497855, 40.89467545918056, 40.870005880083355, 38.483403887067524, 36.490170683179585, 35.20736299242292, 34.45857300077166, 33.94747740881783, 34.010011196136475, 35.41119187218802, 34.58888299124581, 34.35003866468157, 34.35081686292376, 32.277644634246826, 34.01760557719639, 40.53066280909947, 37.873560496738975, 39.18323687144688, 39.11022172655378, 39.47315740585327, 43.17483799798148, 44.05537278311593, 47.46366221564156, 48.78281940732683, 47.457721505846294, 47.69312300000872, 44.33798728670393, 42.67384161267962, 40.57507569449288, 39.92139611925398, 42.15912600925991, 39.330503940582275, 40.021252155303955, 40.243340900966096, 49.544546944754465, 50.8704890523638, 50.941200869424, 52.63704422542027, 53.16696943555559, 53.249670369284495, 51.58780370439802, 48.37769774028233, 48.717263153621126, 45.39364446912493, 45.76369162968227, 45.327285698481965, 46.52390098571777, 43.40905482428414, 46.233546188899446, 44.43180881227766, 55.80276162283761, 54.34045416968209, 60.81726264953613, 27.607148919786724, 1.1208446387733733, 1.1585811738457, 0.7793511546083859, 0.03200016949059708, 36.36196599687849, 67.91088008880615, 53.30010734285627, 59.7703080858503, 61.42950316837856, 56.82118340900966, 52.09284046718052, 31.795738424573624, 34.40725360597883, 64.5339582988194, 39.924001693725586, 0.03448906986575041, 0.09062147978693247, 0.029218908731958697, 0.03983091143891215, 0.06726398385529007, 0.056129807739385536, 0.12587585912219115, 0.1042449769697019, 0.19880002603999206, 0.11991340906492301, 0.11751253503773894, 0.1481513495423964, 0.17096490466168948, 0.3678537282560553, 5.076686101300376, 76.74566745758057, 58.612703459603445, 39.63240664345877, 28.678224154881068, 43.84893485477993, 66.24807889120919, 71.27855382646833, 52.167808055877686, 65.93459006718227, 60.9608610698155, 66.13025828770229, 37.01126820700509, 0.2558497440602098, 0.6565136803047997, 9.740710003035408, 1.3208069545882088, 0.2767995127609798, 27.811148030417307, 71.38112313406808, 55.567860398973735, 59.501753262111116, 44.1510842187064, 45.58310794830322, 46.88443258830479, 52.262442520686555, 52.39819989885603, 54.67308875492641, 50.38730090005057, 55.01101786749703, 53.96718651907784, 46.18520757130214, 39.99865313938686, 40.96225711277553, 41.53306204932076, 41.28327430997576, 37.82563877105713, 40.14176171166556, 40.395308426448274, 40.20272173200335, 41.319971220833914, 42.1087828363691, 45.15238911764962, 48.11358281544277, 46.04701484952654, 49.851605210985454, 47.06265040806362, 47.70403514589582, 49.342076437813894, 43.3543620790754, 42.80983870370047, 44.38315405164446, 39.7990209715707, 42.41968693052019, 40.22771440233503, 37.783383301326204, 43.17782572337559, 41.028004441942485, 38.84378262928554, 39.11406755447388, 38.2071852002825, 40.6704466683524, 38.42669269016811, 40.511596952165874, 37.35534300122942, 41.04282494953701, 40.217896597726, 44.985410009111675, 46.889265060424805, 49.228386538369314, 45.33964654377529, 42.268688678741455, 41.2664075578962, 36.73423310688564, 36.13519416536604, 34.22545746394566, 39.13212939671108, 45.44258063180106, 45.03823716299874, 45.31387914930071, 42.32148803983416, 45.64186886378697, 43.300805364336284, 45.67132575171334, 44.24926226479666, 37.76560980933053, 40.74327073778425, 39.20393902914864, 37.42528009414673, 34.98359278270176, 37.10680941173008, 44.53126185280936, 44.314022949763704, 40.58611290795462, 44.145247731889995, 42.01384612492153, 40.5337894984654, 39.757026059286936, 37.773815631866455, 37.704535143715994, 36.09276499067034, 36.169063159397666, 37.62815359660557, 37.30759150641305, 36.039236068725586, 35.97409323283604, 34.36618627820696, 36.79250764846802, 43.13498660496303, 39.82690061841692, 41.37696034567696, 40.67983021054949, 42.649495124816895, 46.36161191122872, 46.32045773097447, 48.02011217389788, 51.50387641361782, 49.171473843710764, 50.42838907241821, 45.65225642068045, 45.40415014539446, 41.75805514199393, 43.75394950594221, 43.51948949268886, 41.82071052278791, 41.24771342958723, 41.91252054486956, 52.17199434552874, 53.91822256360735, 52.22113200596401, 55.57057367052351, 54.62043183190482, 56.466634205409456, 52.073128427777974, 51.74693482262747, 49.255717277526855, 49.47869191850935, 46.500388281685964, 47.229563508714946, 48.310981137411936, 46.10150957107544, 47.7523946080889, 47.960666860852925, 58.003933565957205, 58.3890756879534, 63.060224533081055, 39.209233556474956, 0.9974617851631982, 2.3836991659232547, 2.469925659043448, 0.22856680090938294, 42.827567032405305, 73.2696782520839, 62.25021743774414, 67.13135474068778, 66.43891116550991, 63.47716508592878, 60.562854358128135, 41.399833815438406, 43.716043608529226, 74.29447501046317, 50.955180644989014, 0.5337779319712094, 0.16054602659174375, 0.24955274909734726, 0.11528023625058786, 0.14557337787534508, 0.13386564967887743], [0.038083042550299845, 0.08206237120819942, 0.037768385506102016, 0.052055727424366136, 0.024384572336982404, 0.03020349357809339, 0.06707019425396409, 0.18240277948124067, 2.486546401466642, 52.00144733701433, 56.38392284938267, 34.40664216450283, 31.827109541211808, 41.82128374917166, 45.50189045497349, 58.336186000279014, 46.6235659463065, 53.25108780179705, 54.06312377112252, 50.32419736044747, 44.05779423032488, 0.7323291120784623, 0.18426750227808952, 1.8866979948111942, 0.9127291547400611, 0.30001433991960114, 6.831457129546574, 64.84259728022984, 52.681717668260845, 55.53333132607596, 41.37400041307722, 41.98150226048061, 41.146314893450054, 47.35772997992379, 48.670727593558176, 46.576648235321045, 47.22075319290161, 52.22280304772513, 47.924265248434885, 47.06406784057617, 38.97273424693516, 36.62406594412667, 35.85186399732317, 36.18112523215157, 37.311270577566965, 36.697612626211985, 34.88527577263968, 35.66033690316336, 37.28581237792969, 41.44732822690691, 42.82178613117763, 43.413748332432334, 46.42354120526995, 45.82706267493111, 46.19979531424386, 44.10809571402413, 42.91141789300101, 38.00025394984654, 40.391476494925364, 37.24187544413975, 37.13185766765049, 36.64309358596802, 38.125655038016184, 40.41231761659895, 41.84662382943289, 41.560094015938894, 38.541629791259766, 37.654799938201904, 34.700012479509624, 34.57801948274885, 35.50172689982823, 37.12634079796927, 36.755862849099294, 35.726018224443706, 36.218645504542756, 39.612882205418174, 43.31945085525513, 48.21734373910086, 43.09977660860334, 45.22615466799055, 41.87464244025094, 37.862259251730784, 34.79232972008841, 37.00989593778338, 35.77434294564383, 44.495211124420166, 39.50816590445382, 47.97864185060774, 43.57700668062483, 46.334194319588796, 40.23635448728289, 40.0230621610369, 39.27147204535348, 34.06384236471993, 36.81623922075544, 36.590363706861226, 35.92471933364868, 35.50057349886213, 36.10530996322632, 39.334533895765034, 33.53659568514143, 40.74861390250069, 39.779868262154714, 39.5670553616115, 34.49125732694353, 35.287861347198486, 32.78960875102452, 33.356460162571494, 32.75947788783482, 32.92479985100882, 33.27781350272042, 34.84789793831961, 35.19885492324829, 33.60198518208095, 32.291888441358296, 34.945624351501465, 32.898942129952566, 35.1448917388916, 37.58677012579781, 35.219678674425396, 41.06856802531651, 39.438996587480815, 42.32148803983416, 46.54573222569057, 45.92920814241682, 49.681895460401265, 45.97849518912179, 46.55130468096052, 40.611574581691194, 40.182895047324045, 38.30037791388375, 39.483159337724956, 37.10798018319266, 38.6171532358442, 36.25430365971157, 40.14749050140381, 46.84144755772182, 50.21453046798706, 49.12993403843471, 51.43644414629255, 50.49650226320539, 51.92834186553955, 44.67211920874459, 48.25626059940883, 45.855223723820274, 45.88724102292742, 42.53642361504691, 44.107988016945974, 40.560939584459575, 44.7590446472168, 43.09484338760376, 51.62222160611834, 50.15209395544869, 57.75450365883963, 15.49255473273141, 1.0598144850560596, 0.8223016070468085, 0.545988033924784, 0.5847166957599776, 44.83594036102295, 58.91866043635777, 55.79296118872506, 60.36118984222412, 60.63801997048514, 56.45511409214565, 38.07441554750715, 17.73622359548296, 29.929553031921387, 56.43088919775826, 24.37664999280657, 0.23948649210589273, 0.0797820117856775, 0.04796212226418512, 0.04562120019857373, 0.04034111209745918, 0.029425990834300007, 0.032509851069854837, 0.07011125250054256, 0.05283993409414377, 0.1176856564623969, 0.09593269228935242, 0.018042985749031817, 0.08083395819578852, 0.13215314942811215, 2.946248774017606, 61.38086577824184, 59.456777572631836, 38.30020420891898, 20.507807901927404, 40.26579747881208, 53.93644074031285, 63.539740562438965, 48.665537289210725, 57.15515899658203, 58.36595903124128, 55.221920013427734, 48.42170763015747, 0.8647896242993218, 0.09934810509106942, 1.2002173853772027, 2.1892848781176975, 0.1926022193261555, 7.931754316602435, 68.02831159319196, 53.57812213897705, 57.5413989339556, 43.68296670913696, 42.435226576668875, 41.96602862221854, 48.60031107493809, 51.698085512433735, 49.72804192134312, 49.30304145812988, 53.67175258908953, 49.457541601998464, 48.35335125241961, 40.37463753564017, 38.90838003158569, 36.848708152770996, 38.23983131136213, 40.14727510724749, 39.014260155814036, 37.322227886744905, 37.826278005327495, 39.10184914725167, 43.05422421864101, 45.40368114198957, 45.37354680470058, 47.81523411614554, 47.93734870638166, 48.231486797332764, 46.93126344680786, 43.73106213978359, 39.16842678615025, 41.55667897633144, 39.66739429746355, 38.68457508087158, 38.73784691946847, 39.93917655944824, 43.57286902836391, 43.62130144664219, 41.384603364127024, 40.43647650309971, 37.08851480484009, 36.897852761404856, 37.044015066964285, 36.60468047005789, 38.369439533778596, 36.31205013820103, 36.9523092678615, 37.189673628125874, 42.48417663574219, 45.06402540206909, 49.86706495285034, 44.94168846947806, 46.66376822335379, 41.463041578020366, 37.43223524093628, 35.08277484348842, 36.50366061074393, 36.526707785470144, 44.35747003555298, 39.16394867215838, 48.31829064232962, 45.50690358025687, 47.85499170848301, 40.93422113146101, 39.58075373513358, 39.30223866871425, 35.34301267351423, 36.82730770111084, 35.53253173828125, 36.939260550907676, 35.41942548751831, 36.76730653217861, 43.525013310568674, 36.51666416440691, 44.076860087258474, 41.52905641283308, 42.02725267410278, 37.86567429133824, 36.90143803187779, 35.74514314106533, 34.350188050951274, 33.33881173815046, 33.90775803157261, 34.41776623044695, 34.42494371959141, 37.06146894182478, 33.943322386060444, 35.432814666203086, 37.17494344711304, 35.439040252140586, 39.13515881129673, 39.071402141026084, 37.52312462670462, 42.83938591820853, 41.782491956438335, 44.15215424128941, 46.985744271959575, 47.46575709751674, 48.02777256284441, 49.014385495867046, 48.56983627591814, 43.277619225638254, 42.70425040381295, 38.96346535001482, 41.43359163829258, 39.477284635816304, 40.51498072487967, 37.70871795926775, 40.66388756888253, 48.67398282459804, 52.465673855372835, 50.725407191685264, 53.18429824284145, 51.94164419174194, 52.59538630076817, 47.555169991084504, 50.94943101065499, 46.86171545301165, 48.53361184256417, 44.56841387067522, 45.64383520398821, 43.034751892089844, 47.702826159340994, 44.70837490899222, 54.94351264408657, 54.29915755135672, 61.412355014256065, 23.576749052320206, 0.8870353677443096, 0.5822530165314674, 0.43166210289512363, 0.616676997925554, 49.487839221954346, 63.86225509643555, 58.788409505571636, 64.75049195970807, 64.46057142530168, 58.66217463357108, 45.05177572795323, 19.848644460950577, 35.138916288103374, 63.87811088562012, 31.836121354784282, 0.15735866262444428, 0.04669888344194208, 0.008336247992701828, 0.023851633969960467, 0.04322624299675226, 0.042117730514811616, 0.06393561352576528, 0.14469866481210503, 0.09073273238859006, 0.2094015928783587, 0.18754946759768895, 0.12900952382811479, 0.22239063946264132, 0.14933702163398266, 3.6445972323417664, 71.24279839651925, 71.34725066593715, 47.92539433070591, 42.5890805380685, 57.21015746252877, 58.017173358372276, 69.69100161961147, 55.96136815207345, 64.5594095502581, 63.71686404091971, 60.86045265197754, 54.207569871629985, 1.7304608012948717, 0.5959583925349372, 7.683796559061323, 3.7672329374722073, 0.3308113616492067, 8.551418117114476, 71.46190289088658, 54.440001010894775, 57.97517497198922, 44.720961570739746, 46.12393488202776, 43.21481098447527, 51.52957432610648, 53.56042160306658, 52.581740038735525, 50.07340213230678, 56.03499821254185, 50.48263365881783, 50.51208707264492, 43.224778175354004, 39.15193523679461, 39.29290723800659, 39.54097877229963, 42.47440052032471, 41.72555841718401, 38.57938630240304, 40.27579593658447, 41.77157286235264, 46.626564093998496, 47.41617822647095, 47.715336390904014, 51.10912145887102, 51.41260140282767, 49.82393748419625, 49.513280051095144, 45.2047437940325, 41.79847281319754, 44.65452984401158, 41.66239929199219, 39.8546656199864, 41.1495805467878, 43.2794257572719, 44.85560376303536, 46.56247738429478, 44.18023191179548, 42.09876353400094, 39.52386883326939, 37.878622259412495, 38.72080646242414, 39.04772962842669, 41.96985707964216, 39.989530154636924, 37.85682923453194, 39.171904359545024, 44.10650110244751, 47.1830974306379, 51.98154769624983, 47.019891193934846, 49.44021626881191, 47.624783992767334, 38.113103117261616, 34.90348352704729, 37.01604161943708, 35.11956902912685, 46.2260490826198, 41.09782688958304, 50.24338286263602, 45.790442194257466, 46.22661188670567, 40.91075359072004, 40.85471984318325, 39.43348319189889, 34.66124847957066, 38.009863308497835, 37.99488994053432, 37.33776753289359, 36.34440095084054, 38.12649924414498, 46.39411905833653, 42.875982080187114, 45.50014993122646, 43.401943343026296, 46.673460960388184, 39.810620989118306, 38.82217025756836, 37.046578952244346, 35.24131189073835, 34.826754570007324, 36.0077155658177, 36.46545246669224, 37.726453236171174, 39.061097962515696, 37.30234561647688, 36.220976625170024, 40.63496569224766, 38.96826308114188, 40.74458047321865, 41.91914217812674, 38.498717716761995, 47.21611874444144, 43.797935077122276, 47.127081053597585, 48.81584072113037, 48.45850528989519, 50.854998043605256, 49.685821192605154, 50.094910281045095, 43.5609632900783, 44.184779507773264, 41.05332715170724, 43.44091578892299, 41.70254945755005, 41.759434359414236, 39.29440457480294, 43.38768911361694, 50.11788102558681, 52.418822152274, 53.141810008457725, 54.94907815115792, 53.87350395747593, 53.8947446005685, 49.94723326819283, 53.3745607648577, 49.615394251687185, 49.56338351113455, 47.28427015032087, 47.4259751864842, 46.15491342544556, 49.483798844473704, 49.29068408693586, 57.466980252947124, 59.359405517578125, 66.99277986798967, 32.71518659591675, 0.8148549294897488, 3.6657236644199918, 1.0391357775245393, 1.07770859343665, 56.29838010243007, 68.93717765808105, 66.25208800179618, 71.27085522242955, 70.35038566589355, 66.64814226967948, 50.55509989602225, 27.641434805733816, 43.76016814368111, 70.76979977743966, 41.24299560274397, 0.33144022790449007, 0.20687980391085148, 0.1088606978633574, 0.16405365908784525, 0.13739442532616003, 0.21397513603525503], [0.04372782965323754, 0.05521351405020271, 0.0785344640857407, 0.006987994669803551, 0.05611039485250201, 0.02712394203990698, 0.054413232885833294, 0.06226476853979485, 0.728410545204367, 45.772501945495605, 50.918101583208355, 41.090798786708284, 41.03595665522984, 24.248830931527273, 41.94320726394653, 52.28548274721418, 56.39157281603132, 47.24590914590018, 57.71203626905169, 47.53505148206438, 52.92872265407017, 3.7162236060414995, 0.18511360830494336, 0.40411618671246935, 1.6923930325678416, 0.052310150914958546, 0.9299856573343277, 54.59483814239502, 57.78338732038225, 53.005687849862234, 46.287502425057546, 39.45599882943289, 40.65662670135498, 43.74220357622419, 49.64246790749686, 45.67427526201521, 47.17132370812552, 50.823150975363596, 48.289584159851074, 46.99120903015137, 41.30103390557425, 38.51871810640608, 35.9354681968689, 37.6690229007176, 35.052265303475515, 36.12516096660069, 35.49345506940569, 36.476732867104666, 40.57063232149397, 44.82224546160017, 45.421253136226106, 47.14222812652588, 45.356339590890066, 44.56628424780709, 46.624882629939485, 44.937311104365754, 38.24076236997332, 38.44704743794033, 40.02123825890677, 38.13597311292376, 36.35201965059553, 37.424342087336946, 39.27609607151577, 40.06144748415266, 37.425919328417095, 34.34670352935791, 33.79903609412057, 32.35108361925398, 32.94599880490984, 36.05464022500174, 36.11348104476929, 38.29567745753697, 37.02995886121477, 39.30430228369576, 36.733388900756836, 38.69107859475272, 45.83444166183472, 48.30597843442644, 47.941673960004536, 50.726428576878135, 50.24440424782889, 38.98598793574742, 34.15107004983084, 34.04106616973877, 36.238760539463584, 38.63879687445504, 36.90493992396763, 45.5266364642552, 45.71373060771397, 45.96072169712612, 38.805494580950054, 37.15492916107178, 37.77268654959542, 33.77101748330252, 35.29731089728219, 35.58599465233939, 35.879017557416645, 33.34991495949881, 39.67354692731585, 36.186402388981406, 44.50423683438982, 44.8113055229187, 41.748695918491904, 37.462536334991455, 34.87949487141201, 34.5878963470459, 33.141097273145405, 32.837064947400776, 32.88348586218697, 34.29181970868792, 30.348727430616105, 32.589806352342876, 34.91010168620518, 37.56231941495623, 33.87043578284127, 33.95215007237026, 35.99559095927647, 35.11928415298462, 36.58185911178589, 36.568504674094065, 39.318935189928325, 40.29163088117327, 41.24353756223406, 46.56515938895089, 48.45427731105259, 48.74927003043038, 48.42565768105643, 47.67847967147827, 46.63297380719866, 41.7145733152117, 40.66489505767822, 37.29707888194493, 38.17487607683454, 38.806713989802766, 37.155106340135845, 37.17390816552298, 38.32696172169277, 42.33195897511074, 47.71345690318516, 50.715710980551584, 47.65345573425293, 47.14978429249355, 46.90552384512765, 47.230171476091655, 43.79035111836025, 44.274525914873394, 42.59413535254342, 41.517338275909424, 41.051603998456685, 45.279624530247276, 46.568039417266846, 51.00334208352225, 49.38610022408621, 53.95319979531424, 18.045922177178518, 0.5090044555919511, 0.9492128427539552, 0.7117254776614053, 2.079158101763044, 54.823763915470664, 54.917415210178916, 56.08943040030343, 58.65120342799595, 59.79354286193848, 51.22083112171718, 38.23896278653826, 35.6732223374503, 33.43619074140276, 50.94064153943743, 15.841064214706421, 0.2170029899903706, 0.011128084567774619, 0.04588451589058552, 0.09025982740734305, 0.08176165127328464, 0.02018205721729568, 0.06268450351698057, 0.04311952300901924, 0.03935688008953418, 0.04391406037445579, 0.048701606690883636, 0.02735131573198097, 0.04709966015070677, 0.08235534905855145, 1.2153868228197098, 56.05095475060599, 58.55214296068464, 46.07659680502755, 34.75496230806623, 41.35140487125942, 49.47571808951241, 57.87603112629482, 59.616600036621094, 53.2880973815918, 62.68937138148716, 51.43457160677229, 56.35906566892351, 4.275517548833575, 0.43326360838753836, 1.1991377004555293, 4.3037988884108405, 0.12507028877735138, 1.320077393736158, 55.67361198152815, 58.81370094844273, 54.344247886112754, 46.668923786708284, 42.50646298272269, 41.32145813533238, 45.555353369031636, 50.186233929225374, 48.140479292188374, 48.895960399082725, 53.27394042696272, 50.61612245014736, 49.63195180892944, 43.64896222523281, 40.25061913899013, 38.3383915083749, 38.352468558720176, 37.47148561477661, 37.23584788186209, 36.96085902622768, 38.332773889814106, 42.37485020501273, 46.88197987420218, 47.71083048411778, 48.283633027757915, 47.02975763593401, 46.30241673333304, 47.3938432421003, 46.56037902832031, 40.29986449650356, 40.027554171425955, 42.17228937149048, 40.43590327671596, 38.028679030282156, 39.52410854612078, 40.90795694078718, 43.10230575289045, 39.95787068775722, 36.999914850507466, 36.01334013257708, 35.24312884466988, 34.79123885290963, 37.921659401484895, 36.98749841962542, 39.63114901951381, 39.19763353892735, 39.341822556086946, 37.728968484061106, 40.25676482064383, 46.41453981399536, 48.64869832992554, 50.08369588851929, 53.019014494759695, 48.862174783434185, 37.79221446173531, 33.335504395621165, 35.100159236363, 35.77699020930699, 38.12817028590611, 36.7676226752145, 46.649614742824006, 46.81958852495466, 46.58186633246285, 39.21410076958792, 36.85321058545794, 37.44646167755127, 33.29411745071411, 34.377577849796836, 34.98990174702236, 36.58270331791469, 34.75619213921683, 39.57327052525112, 38.519419874463765, 46.464389664786204, 46.84728751863752, 44.2759815624782, 39.949640546526226, 37.17553751809256, 36.16502625601632, 35.77253988810948, 34.39995104925973, 34.414521421704976, 35.494660581861226, 31.54493624823434, 34.53299168178013, 36.200816426958355, 39.27303886413574, 35.23551709311349, 35.41373143877302, 38.37404618944441, 37.004945346287315, 38.084330626896445, 39.05278096880232, 42.87333481652396, 41.74399546214512, 42.438561711992534, 48.76468808310372, 48.596034458705354, 50.32069199425833, 49.44015026092529, 49.60476350784302, 48.428023542676655, 43.64548117773873, 41.39060313361031, 39.35698005131313, 39.816690240587505, 41.33132805143084, 37.1713616507394, 39.74113205501011, 40.82947703770229, 43.804633140563965, 49.156774929591585, 51.79653801236834, 49.51602111543928, 50.2812123298645, 49.70762116568429, 50.61321810313633, 46.46622051511492, 46.33179719107491, 44.685852323259624, 44.16159336907523, 44.68144021715437, 48.54901947293963, 49.341235705784385, 53.656692368643625, 52.46757766178676, 58.299923351832796, 22.877093247004918, 0.40070017001458574, 0.8260465232389314, 0.5177651569247246, 2.1082530319690704, 59.79425157819475, 61.77121557508196, 60.66240814753941, 64.3634842463902, 65.82038252694267, 57.15779931204659, 45.687410831451416, 28.28774929046631, 35.319013595581055, 61.01190253666469, 22.34606327329363, 0.13445072328405722, 0.04506899482969727, 0.008994058855543179, 0.07551492218460355, 0.09985712170600891, 0.015936735019619976, 0.12232541106641293, 0.1702933856951339, 0.16641688799219473, 0.14138746820390224, 0.13273028417357377, 0.06645309379590408, 0.2060434552175658, 0.2358886008816106, 1.3861194785152162, 64.27820205688477, 66.49737330845424, 55.75683403015137, 51.82334763663155, 37.146462781088694, 54.52942432676043, 62.505633217947825, 68.0427360534668, 58.41510363987514, 68.84562819344657, 57.05350685119629, 63.5539287839617, 5.938300941671644, 0.847784831055573, 3.928893199988774, 6.402691176959446, 0.13298842603606836, 1.7797006219625473, 58.47627558026995, 60.46498898097447, 57.575698716299875, 49.88107252120972, 44.85384586879185, 43.966352462768555, 47.86351019995553, 52.07136011123657, 48.555182525089805, 50.05918264389038, 54.57166242599487, 52.08167471204485, 53.0462201663426, 45.036177022116526, 42.65783296312605, 39.5333114351545, 42.00628301075527, 39.48306901114327, 39.34906605311802, 40.05767113821847, 41.0419807434082, 43.772751331329346, 48.13492768151419, 50.08966786520821, 50.633360930851524, 49.678994587489534, 47.76294892174857, 49.995068141392295, 49.947212423597065, 41.153784206935335, 41.998243944985525, 43.14021165030343, 42.173821449279785, 41.13822371619088, 41.416304520198274, 41.86899355479649, 44.87413113457816, 39.95679371697562, 38.39485951832363, 37.89240401131766, 37.31507471629551, 37.48518051419939, 39.77595295224871, 39.36636011941092, 42.30989497048514, 41.83973816462925, 41.27506153924124, 40.618109362465994, 42.0848845073155, 48.884120668683735, 50.46714612415859, 52.87139654159546, 51.870772566114155, 49.88325425556728, 38.65817540032523, 32.94381359645298, 34.34919793265206, 36.014323302677695, 39.78524964196341, 36.50147887638637, 45.57160520553589, 49.127474376133506, 49.35409682137625, 38.06609855379377, 38.4329252243042, 37.069584437779014, 34.02718366895403, 34.90771497998919, 36.293102400643484, 36.71587944030762, 34.9134646143232, 41.00908102308001, 46.02156359808785, 48.29469803401402, 48.35999373027256, 47.961069856371196, 42.09304864065987, 38.397996629987446, 38.68043395451137, 38.18358564376831, 37.33085060119629, 37.242726598467144, 38.18664632524763, 32.6262183870588, 35.92403146198818, 38.04995788846697, 40.52378409249442, 37.98388051986694, 38.150428840092246, 41.02464151382446, 38.64279556274414, 40.245981216430664, 41.76951272147042, 43.962649072919575, 45.57780647277832, 45.00509425571987, 48.96885395050049, 51.276149204799104, 52.45475128718785, 52.89886277062552, 49.20277547836304, 50.90132515771048, 45.46877186638968, 45.31087752750942, 40.734321457999094, 41.73254483086722, 42.543350969042095, 39.81086417606899, 41.87732444490705, 42.77507339205061, 44.89278704779488, 52.9575958933149, 54.98119967324393, 52.010316712515696, 52.05898536954607, 53.11343009131295, 52.223827907017295, 49.87820986339024, 49.086306299482075, 47.36882625307356, 47.76365416390555, 47.35020855494908, 48.75231334141323, 52.47958067485264, 55.99759953362601, 57.26951592309134, 60.79336779458182, 30.214241572788783, 0.39335174432822634, 2.3111532415662492, 0.9308964141777584, 2.7662024923733304, 64.58044869559151, 66.64588410513741, 64.3581132888794, 70.80772304534912, 69.7321696962629, 63.76054041726248, 53.126186983925955, 48.48732641765049, 45.621972697121755, 71.17676271711076, 32.05778973443167, 0.3067684774952275, 0.07841924205422401, 0.09744387798543487, 0.16875459040914262, 0.24224994810564177, 0.16998345804001602], [0.07981889694929123, 0.10418660260204758, 0.15509325132838317, 0.042237379987324984, 0.03958580084145069, 0.09446417287524257, 0.07961715491754667, 0.0314803573835109, 0.13629595855517046, 38.55682897567749, 54.2658930506025, 38.955047607421875, 22.165034907204763, 17.90291087968009, 36.795662130628315, 50.78339338302612, 54.70208011354719, 49.92277908325195, 55.75745241982596, 48.61102172306606, 53.009221008845735, 11.226663044520787, 0.2704476650272097, 1.0851783411843436, 3.7290478093283514, 0.2124359743403537, 0.05536041688174009, 33.52873379843575, 61.094808442252024, 51.15848840985979, 47.09205865859985, 39.5433064188276, 41.53306204932076, 41.42357928412301, 51.069231850760325, 46.70505094528198, 48.601068428584504, 50.64138262612479, 50.583479813167024, 47.37750802721296, 45.29327426637922, 40.180501392909456, 36.330952712467735, 36.57322597503662, 36.462728772844585, 35.757462297167095, 36.64427130562918, 40.7183267048427, 43.12205948148455, 45.30471794945853, 44.80794259480068, 44.3832791192191, 44.678428173065186, 45.35624926430838, 42.39119931629726, 40.15319497244698, 34.89315502984183, 39.003643308367046, 41.65061514718192, 37.48000758034842, 38.06378480366298, 37.24577685764858, 38.25543349129813, 37.8514860698155, 36.36788238797869, 35.42361525126866, 33.78764452253069, 36.05691576004028, 35.18843609946114, 37.01804617473057, 35.096247400556294, 35.778428486415315, 34.93656390053885, 34.24138273511614, 36.84445585523333, 42.644145011901855, 43.29903704779488, 49.07179498672485, 46.2358912059239, 49.2449996812003, 45.40113115310669, 38.49857875279018, 36.67968627384731, 36.79157658985683, 33.72247389384678, 35.59141424724034, 35.61215462003435, 45.010142121996196, 50.57102516719273, 42.19400596618652, 36.66722815377371, 38.936575821467805, 36.46290247780936, 36.06618465696062, 35.44429656437465, 34.79204484394619, 35.1883944102696, 35.386077608381, 41.46822146006993, 48.44991731643677, 45.37203557150704, 46.243596758161274, 45.35163218634469, 40.76427861622402, 34.252440793173655, 33.02542018890381, 33.77446378980364, 34.14558097294399, 34.62949868610927, 33.01411199569702, 34.139866079602925, 34.84736292702811, 35.03249420438494, 39.06095552444458, 42.214253016880576, 36.42874165943691, 37.718966552189414, 35.67679023742676, 36.57512283325195, 37.00312491825649, 41.151762281145366, 38.652453558785574, 37.629769052777974, 43.833231925964355, 47.109971114567344, 47.55150134222848, 46.73965644836426, 47.701780455453054, 45.424470152173726, 45.06845835277012, 42.197316782815115, 40.82883432933262, 38.414682728903635, 39.80288069588797, 38.61935581479754, 38.75743041719709, 37.201791286468506, 38.46870149884905, 39.11129869733538, 43.17829820087978, 45.9716477394104, 46.52736118861607, 45.92304509026663, 44.95260756356375, 44.19826943533761, 42.29833664212908, 42.22949389048985, 42.026026317051475, 43.14727796827044, 47.97835002626692, 46.98156145640782, 54.64676203046526, 48.951271533966064, 59.48011657169887, 13.411524959972926, 0.7869090576257024, 0.9995449419532503, 0.8647013061812946, 7.2011173622948785, 58.263539109911235, 52.839869090488975, 56.438799721854075, 57.93715442929949, 58.51478944505964, 51.26164484024048, 32.570452145167756, 22.125987768173218, 33.66291046142578, 52.25287137712751, 8.405523317200796, 0.41089144029787605, 0.08180961012840271, 0.07836031807320458, 0.01920894130931369, 0.027106724213808775, 0.009062677405641546, 0.05574824035699878, 0.08276240900158882, 0.059248490392097404, 0.052085525289710076, 0.023874207133693353, 0.03482690905886037, 0.0608236144429871, 0.03413932238306318, 0.20067124920231955, 46.66229867935181, 59.81945964268276, 46.32292781557356, 27.79548852784293, 27.309811183384486, 45.71510287693569, 52.54654393877302, 62.43529660361153, 52.162183489118306, 61.25515896933419, 52.54414333615984, 60.41682406834194, 12.717889768736702, 0.32015963750226156, 0.7854212203196117, 6.005358006272997, 0.228645103850535, 0.03263489828844156, 36.99574245725359, 62.3779114314488, 52.94828878130232, 47.855988774980815, 41.19671712602888, 42.25403492791312, 45.106287819998606, 52.4060583114624, 49.111642905644004, 49.66774892807007, 51.95232009887695, 51.23612758091518, 50.11548737117222, 46.72174399239676, 42.20953171593802, 36.63359539849417, 38.726055826459614, 38.99448905672346, 37.77937419073922, 38.88530853816441, 42.820167200905935, 44.88214935575213, 47.02533858163016, 47.07497303826468, 46.24362455095564, 47.47406019483294, 47.91492339542934, 45.0620243208749, 42.044181959969656, 37.236768518175396, 40.883461066654746, 41.453849111284526, 40.57769863946097, 38.75026682444981, 38.06462900979178, 40.00832503182547, 40.36945765359061, 35.65355198723929, 36.41540111814226, 34.647379875183105, 37.693192209516255, 36.11836910247803, 37.32773780822754, 37.23143230165754, 37.617053849356516, 38.4016444342477, 36.83614233561924, 39.21190166473389, 43.99411746433803, 46.283812931605745, 50.053919383457725, 48.10476207733154, 50.44322347640991, 46.15289497375488, 38.590628487723215, 36.226962498256135, 35.80123247419085, 33.625275543757844, 36.373649392809185, 34.99702712467739, 46.44030720846993, 49.676750319344656, 44.24905034473964, 36.55253076553345, 36.825098173958914, 36.99711125237601, 36.1165452003479, 35.81578547613961, 35.937490122658865, 35.14023297173636, 36.413163798195974, 42.00860023498535, 49.053694929395405, 48.6188314982823, 46.57834359577724, 48.36208861214774, 42.20028713771275, 35.259210450308665, 35.369273390088765, 35.86512810843331, 36.56963723046439, 35.564093930380686, 35.44780193056379, 35.23364107949393, 37.62624979019165, 36.46353823798043, 41.152669021061485, 42.63264226913452, 37.0745141846793, 40.444129943847656, 38.27481549126761, 37.322467599596294, 39.382976736341206, 41.71976014545986, 41.79278918675014, 38.82566172736031, 46.64948967524937, 47.28469399043492, 50.635719844273154, 47.32476772580828, 49.151938983372276, 48.24289921351841, 48.09355115890503, 44.622199875967844, 42.127129554748535, 39.55896765845162, 41.305421692984446, 39.16599144254412, 39.81528670447213, 38.46325758525303, 39.25308016368321, 41.04584046772548, 46.50110742024013, 46.8424585206168, 48.0542208807809, 47.959242480141775, 48.21879243850708, 46.875476360321045, 45.021992274693076, 44.63302864347185, 44.35761594772339, 46.513798304966514, 50.32446139199393, 50.88928740365164, 59.228591782706125, 52.013874190194265, 63.75421755654471, 16.306390285491943, 0.8047274414982114, 0.866789022726672, 0.7441358928169522, 7.621423448835101, 63.72511155264718, 57.164413997105186, 61.982503346034456, 61.819547244480674, 65.04721478053501, 55.04413993018014, 45.94054412841797, 28.031525782176427, 38.409700870513916, 62.90837860107422, 12.6631874697549, 0.41499280450599535, 0.11209406650492124, 0.1161142507834094, 0.03655683748157961, 0.052699599481586895, 0.017391388570623736, 0.22124779650143214, 0.15904007240065507, 0.2447252981364727, 0.23535014263221196, 0.0728376197761723, 0.22653447996292794, 0.24865843994276865, 0.22435351913528784, 0.41627618564026697, 54.71842227663313, 69.50207315172467, 52.67876468385969, 31.700860772814067, 27.709530626024517, 51.587122780936106, 60.34151949201311, 65.69368212563651, 59.35315213884626, 66.9122155053275, 59.91933304922921, 64.25901808057512, 17.079830748694285, 0.3661850749381951, 3.6993038739476884, 10.712566699300494, 0.6021218789475304, 0.21514410259468214, 38.79456506456648, 64.41879885537284, 54.12118986674717, 51.50307389668056, 43.85407304763794, 45.50277635029384, 47.26370695659092, 55.57262338910784, 50.49527938025338, 51.50322675704956, 54.01722744532994, 54.53440271105085, 50.68477760042463, 48.0111003603254, 43.575613566807334, 40.57747629710606, 40.01560326984951, 41.113568033490864, 40.08623170852661, 41.35895756312779, 45.38870082582746, 47.07545593806675, 48.853781359536306, 49.74743434361049, 47.78486006600516, 49.24193899972098, 51.10749210630144, 46.5825194631304, 44.334023339407786, 39.000103201184956, 42.71899100712368, 44.07523420878819, 43.15416710717337, 42.02141618728638, 39.474171842847554, 43.06936781747, 43.9014493397304, 39.737439087459016, 39.48726919719151, 36.39014094216483, 40.464845997946604, 38.399334158216206, 39.830687386649, 39.521867752075195, 39.791068758283345, 40.28972707475935, 38.882355553763254, 41.182640075683594, 47.04293142046247, 48.24673809323992, 52.32563638687134, 50.54040445600237, 53.281409740448, 44.12773479734148, 38.4316919190543, 36.6696252822876, 36.74354369299752, 33.591705322265625, 36.114971433367046, 35.90151929855347, 46.79487030846732, 53.49797814232962, 42.754652636391775, 37.641226632254465, 37.76851415634155, 37.247024059295654, 37.97935724258423, 37.2072490964617, 35.69710677010672, 36.69264119012015, 36.11702462605068, 46.593129362378804, 49.99800722939627, 47.004146575927734, 50.92238514763968, 50.05390201296125, 45.55070502417428, 37.99577236175537, 36.564130783081055, 37.23951653071812, 38.981648785727366, 37.90615449632917, 37.10111883708409, 38.28695746830532, 39.416341985974995, 38.05253219604492, 44.44573647635323, 45.13020351954869, 40.39816761016846, 43.98451157978603, 40.85640130724226, 39.757185867854524, 41.50384487424578, 43.763892378125874, 43.0217205456325, 41.28956937789917, 47.75621264321463, 50.235003335135325, 52.8970353943961, 49.59815924508231, 50.81573724746704, 48.907254695892334, 49.29483216149466, 47.45369502476284, 44.65756620679583, 41.56042405537197, 42.551654066358296, 41.90313352857317, 42.382969175066265, 39.128995759146555, 41.92371756689889, 42.64882809775216, 46.96861348833357, 48.39855623245239, 49.840105942317415, 50.69052028656006, 50.09460456030709, 49.3582136290414, 47.15438052586147, 48.55113172531128, 46.36909512111119, 48.10757957186018, 53.453992571149556, 54.30107525416783, 62.810249192374094, 55.56100947516305, 70.05736623491559, 19.651124545506068, 0.6384050462927137, 4.007087792669024, 1.5038760283163615, 9.342278582709175, 66.74559770311627, 62.00755855015346, 66.58196762629917, 68.62517574855259, 68.19205284118652, 62.88121114458357, 46.857605593545095, 33.0380276952471, 46.72908476420811, 73.29022407531738, 21.445724385125295, 0.4843184288058962, 0.26278230920434, 0.1682890746742487, 0.11729525455406734, 0.22796575458986418, 0.1650503591767379], [0.10256421180175883, 0.03781293133007629, 0.05607427643345935, 0.019992969863648926, 0.05141185536714537, 0.07169301262391464, 0.06932723242789507, 0.03077838576531836, 0.009700751381127961, 28.91416413443429, 59.00453322274344, 39.72574526923043, 40.659433773585725, 59.29637145996094, 34.02807651247297, 50.95652164731707, 58.655400139944895, 50.462716647556846, 53.252696309770855, 48.11610501153128, 52.04588106700352, 21.85684755870274, 0.38311417081526344, 0.8497438430786133, 5.480181455612183, 0.5454632277999605, 0.030684873461723328, 17.708514179502213, 63.83166912623814, 47.542941161564414, 47.381739480154856, 42.11037744794573, 42.450498717171804, 42.89389453615461, 49.768442222050254, 48.73656872340611, 45.55374486105782, 51.18738596779959, 51.51859964643206, 49.42325571605137, 44.60836601257324, 40.98361587524414, 36.43381037030901, 34.05851657049996, 34.79706144332886, 36.32062074116298, 34.654352392469136, 37.649526255471365, 40.5939678464617, 42.790738105773926, 46.526919978005544, 45.417112009865896, 44.71616036551339, 45.553286279950825, 42.54474408285958, 38.74084506716047, 37.2774988583156, 38.221672194344656, 39.074952670506065, 37.54140533719744, 35.650154318128315, 36.152651514325825, 36.32202775137765, 38.23549216134207, 34.40114961351667, 35.24923978533064, 35.55561365400042, 35.132065364292686, 34.76235171726772, 36.067807061331614, 35.44939306804112, 35.94955219541277, 33.85923876081194, 36.46015793936593, 39.578943729400635, 42.51326526914324, 44.49897704805647, 48.29204729625157, 49.03536210741316, 49.387927600315635, 40.76963567733765, 36.51193938936506, 37.010014057159424, 37.623852661677766, 35.537166186741416, 36.93668276923043, 35.16543756212507, 39.85904993329729, 49.277437346322195, 41.050242151532856, 35.6691437448774, 35.33540787015642, 35.384667124067036, 35.074784415108816, 35.9998710496085, 34.3725369317191, 34.94133036477225, 36.165102686200825, 43.0574586050851, 46.25413022722517, 45.46912622451782, 47.23331553595406, 46.21136059079851, 41.09105587005615, 35.74951008387974, 33.44091204234532, 33.597923960004536, 34.606097153254915, 33.64773906980242, 33.36589581625802, 34.17192159380232, 33.860725675310405, 35.86193888528006, 35.39858436584473, 38.25462750026158, 38.22298540387835, 35.43087264469692, 35.69715193339756, 34.83932038715908, 36.765006678445, 39.62633391789028, 40.74874244417463, 37.90924991880144, 40.607287543160574, 44.62230409894671, 48.13824544634138, 44.29848330361502, 47.52125930786133, 49.599455084119526, 46.03525502341134, 45.355901854378835, 45.144016538347515, 42.35910906110491, 38.33112021854946, 37.94416461672102, 38.593046460832866, 39.446705613817485, 38.19651624134609, 36.957756655556814, 38.65588596888951, 39.776095390319824, 39.37471532821655, 40.802184513636995, 42.49261522293091, 41.146589347294395, 41.05302143096924, 40.24012041091919, 41.428971086229595, 42.76169810976301, 47.43698460715157, 48.67790855680193, 53.06537634985787, 50.92683546883719, 62.11435236249651, 6.175894592489515, 0.5579640141555241, 0.4343553440911429, 0.6236116258161408, 9.516745243753705, 60.66248457772391, 51.76147392817906, 57.74886519568307, 54.58453048978533, 55.1662996837071, 49.95910773958479, 29.283683231898717, 24.202509028570994, 30.38528537750244, 48.45933559962681, 11.825794049671718, 0.3593863711825439, 0.058928900398314, 0.11331028624304704, 0.08034302453909602, 0.058663823907928805, 0.11124131083488464, 0.06879498277391706, 0.1415101337645735, 0.049912096200776954, 0.023361674011019722, 0.03982203620086823, 0.06604479891913277, 0.05118236464581319, 0.12065594350653035, 0.09277785729084696, 36.746979577200754, 66.68284852164132, 47.093364919934956, 38.76014368874686, 44.67137575149536, 44.238186836242676, 51.50646114349365, 65.3559718813215, 53.64486653464181, 59.13893222808838, 52.89988415581839, 56.264000415802, 25.27786782809666, 0.47662883571216036, 0.33156735822558403, 4.82175669499806, 1.03533858699458, 0.10156842094979115, 19.713038206100464, 66.36165414537702, 51.25008651188442, 49.735542501722065, 44.498785972595215, 43.710700443812776, 43.19721467154366, 51.76844297136579, 49.63053437641689, 48.12606178011213, 53.55784729548863, 53.81858886991228, 50.202141829899375, 47.082025459834504, 43.31216219493321, 38.158926486968994, 36.7958254132952, 36.780386516026084, 36.99886219842093, 36.32921566282, 38.72004216057913, 41.89164815630232, 44.417405196598594, 47.18396248136248, 47.889802183423726, 47.7673089163644, 47.07803719384329, 44.18961892809187, 41.48127712522234, 38.765448638371055, 41.058559145246235, 42.32469115938459, 40.65924269812447, 37.255455698285786, 37.327004773276194, 38.76256513595581, 42.08742754799979, 36.42996801648821, 36.417530741010395, 37.24280650275094, 36.18380028860909, 35.93422099522182, 37.388058594294954, 37.50543451309204, 37.77471194948469, 35.896287305014475, 37.68771008082798, 40.88708455221993, 42.705560139247346, 46.48524815695626, 50.59654937471662, 49.83800411224365, 50.48872722898211, 40.15993472508022, 36.44220379420689, 35.752344948904856, 36.36983830588204, 35.91484594345093, 34.77757869447981, 34.7192450932094, 38.94602884565081, 50.67210408619472, 42.561944348471506, 34.7716623033796, 34.79666887010847, 35.0694933618818, 35.13015808377947, 37.13297980172293, 32.79249225343977, 35.02952037538801, 35.200470379420686, 43.77342183249337, 49.11707987104143, 48.19811807359968, 48.336105823516846, 48.21868821552822, 42.86763381958008, 39.06506190981184, 34.660105500902446, 34.2236578805106, 34.81083624703543, 34.83508893421718, 36.14617231913975, 34.8643582207816, 35.124554361615864, 37.800948347364155, 36.16852467400687, 40.43447889600481, 39.89773055485317, 38.78587286812918, 37.627795764378135, 37.142794132232666, 38.05712148121425, 40.761940547398154, 43.32037843976702, 38.306916168757844, 43.85767568860735, 47.33599254063198, 48.78711339405605, 46.745819500514436, 49.59368460518973, 52.0028578213283, 47.94215338570731, 46.62790509632656, 48.03610692705427, 42.733078479766846, 41.02290446417672, 40.00084529604231, 40.88256822313581, 41.27488783427647, 39.36177430834089, 38.92561503819057, 40.75725746154785, 41.5473301751273, 42.35202537264143, 43.502598421914236, 44.82362815311977, 44.23400749479021, 43.52672256742205, 42.44648265838623, 44.431992939540315, 45.43721662248884, 48.07796287536621, 51.9816449710301, 55.768562589372905, 54.95960119792393, 64.2415086201259, 7.55418746812003, 0.7650684267282486, 1.3343575703246253, 0.6358539174710001, 10.77174971784864, 67.73235307421002, 56.76476056235177, 64.47465542384556, 62.248584611075266, 59.67275537763323, 57.50932257516043, 39.17096982683454, 23.2810788835798, 36.73159973961966, 56.782474994659424, 14.66576600074768, 0.5705931793366159, 0.07054877188056707, 0.10524165670254401, 0.018266278052968637, 0.05382233066484332, 0.04281268608091133, 0.2509782968887261, 0.22321087973458426, 0.1960929563002927, 0.14538530153887613, 0.15369868544595583, 0.21660329215228558, 0.16774518814470085, 0.3550771581275122, 0.15554670271064552, 44.479011399405344, 78.25429507664272, 51.40959283283779, 52.41888121196202, 68.11291980743408, 48.46368517194475, 59.768800326756065, 70.61910724639893, 60.24577331542969, 64.7565507888794, 57.34146104540144, 63.35751015799386, 29.980375630514963, 0.57577973817076, 2.7619519318853105, 11.729671801839556, 1.699016728571483, 0.12728387356868812, 21.706651823861257, 68.77786241258893, 52.99760709490095, 51.988516739436555, 47.30724784306118, 46.84086390904018, 46.00290073667254, 54.435026100703645, 50.63666132518223, 50.76285103389195, 55.94352170399257, 56.54016351699829, 51.7889575277056, 48.95173011507307, 45.3364851134164, 41.25063862119402, 38.072991166796, 38.413789885384695, 40.60697487422398, 39.46272121156965, 41.22509356907436, 44.18564108439854, 45.855946336473735, 50.72152314867292, 49.0537748336792, 50.38576187406267, 50.014130524226594, 46.20092787061419, 43.26273618425642, 40.92804765701294, 43.02321788242885, 44.17873110089983, 42.101428168160574, 40.35883385794503, 38.82853133337838, 41.00938326971871, 45.27264853886196, 38.148465973990305, 38.877512659345356, 40.330617223467144, 37.62478372028896, 38.099682671683176, 40.07077544076102, 39.578651905059814, 39.408382824489046, 37.69632584708077, 38.61798701967512, 43.065247535705566, 45.64048269816807, 49.98454509462629, 53.695091588156565, 52.141582080296104, 52.45831918716431, 42.01992579868862, 35.49743291309902, 36.71660900115967, 37.06953232628958, 35.11675500869751, 34.778270040239605, 34.77844721930367, 38.58705016544887, 50.96383810043335, 42.223094599587576, 34.70950371878487, 34.41883972712925, 35.77619811466762, 34.5011202948434, 37.377136026109966, 32.640813078199116, 35.43767840521676, 35.77761902127947, 43.31400694165911, 48.50712183543614, 53.30680193219866, 51.74057722091675, 51.98155811854771, 45.67384794780186, 40.96661710739136, 37.59198474884033, 36.31736551012312, 38.97414820534842, 38.14094802311489, 37.87418583461216, 36.936783518110005, 37.04318823133196, 39.70209360122681, 38.61774730682373, 42.61802673339844, 42.901391642434255, 40.84758751732962, 39.71322808946882, 39.0044458253043, 39.713248934064595, 43.64033951078142, 45.74097796848842, 41.65088265282767, 44.96987731116158, 49.6958509172712, 51.457292216164724, 49.41971213476998, 51.85723747525896, 53.79672288894653, 49.36983796528408, 49.47438056128365, 49.82097060339791, 45.56988900048392, 42.02709286553519, 41.30824613571167, 42.06990419115339, 43.656188351767405, 41.30456359045846, 40.95189387457711, 43.507288455963135, 45.09209265027727, 43.19605432237898, 44.63597467967442, 47.76718037469046, 45.62696497780936, 46.44861030578613, 44.86982672555106, 46.836399691445486, 45.97597994123186, 52.687199796949116, 54.95274680001395, 59.037731715611045, 58.92689405168806, 69.36474200657436, 8.964885439191546, 0.5324095711112022, 4.178224963801248, 1.304326370358467, 12.62126898765564, 72.68113109043666, 62.044543811253135, 68.15554700578961, 66.52358886173793, 66.74787671225411, 63.21389089311872, 40.934189864567344, 33.22328404017857, 44.8329039982387, 68.77122688293457, 20.25597218104771, 0.6982144340872765, 0.22551218553313188, 0.23767325654625893, 0.2623917715890067, 0.170194930263928, 0.19799020806593554], [0.00487395647879956, 0.05601048396368112, 0.08322124795189925, 0.028921184529151236, 0.06700500060937234, 0.03161457161019955, 0.03944238228723407, 0.03795182066304343, 0.01951887405344418, 19.14640392575945, 54.063780375889365, 42.247910090855186, 48.54071984972273, 71.9513270514352, 40.15544618879046, 43.476504462105886, 55.345205375126426, 52.75164781297956, 50.99259669440133, 48.023332663944785, 53.225865840911865, 27.27186359677996, 0.16518929600715637, 0.289609928216253, 2.8904095760413577, 0.4526379001992089, 0.05121466630537595, 8.191021135875157, 56.12543249130249, 52.84217936652047, 50.09559120450701, 44.84340272630964, 43.08356646129063, 45.00143255506243, 47.80385296685355, 52.969578061785015, 46.418034757886616, 49.5401417868478, 50.02096060344151, 48.509470326559885, 47.76712826320103, 42.903382301330566, 35.58468491690499, 35.55280658176967, 35.77058744430542, 35.77705274309431, 34.03176948002407, 38.0334072794233, 38.791483538491384, 41.4674780028207, 43.87175273895264, 44.81802790505545, 44.12553916658674, 45.30332483564104, 42.31629426138741, 41.25194835662842, 36.71413891656058, 37.66039671216692, 39.609265668051584, 37.063275473458425, 35.74851649148123, 36.033479486192974, 35.74676554543631, 36.69975961957659, 33.09365497316633, 36.71380540302822, 35.14582974570138, 35.308705942971365, 35.196225030081614, 33.987415654318674, 34.23598745891026, 34.586815902165, 35.053585461207796, 37.34281192507063, 39.258899280003135, 43.50827510016305, 44.85352972575596, 48.01242746625628, 45.95231785093035, 48.03406415666853, 40.848146847316194, 35.385855266026084, 36.77842017582485, 36.356018338884624, 36.61235475540161, 37.297978673662456, 36.681148869650706, 39.4883531161717, 47.189858027866904, 40.91496767316546, 35.73022188459124, 36.36429711750576, 33.73691572461809, 36.911700521196636, 34.35927629470825, 35.080846718379426, 34.33522857938494, 37.17583629063198, 37.1664388520377, 42.69506141117641, 46.895070280347554, 47.28871699741909, 45.71444627216884, 40.683658667973106, 39.02474498748779, 37.19391550336565, 32.91077838625227, 33.97888674054827, 31.362170832497732, 31.542427948543004, 32.58884055273873, 33.556408473423545, 34.89603853225708, 36.59113843100411, 35.77847712380545, 38.04731409890311, 36.821884632110596, 36.63432148524693, 35.30549587522234, 36.49583693913051, 37.795820576804026, 39.604950836726594, 36.905638217926025, 42.364379269736155, 46.668829986027305, 48.51025199890137, 47.98491607393537, 44.37393726621355, 47.526797022138325, 49.514662742614746, 45.993211473737446, 44.016063349587576, 42.182833262852256, 40.83865908214024, 35.586119719914024, 36.89316272735596, 37.101692063467844, 39.575264658246724, 38.71589756011963, 38.26169729232788, 37.38351794651577, 38.27670540128435, 38.02652161461966, 38.622621468135286, 39.258478913988384, 39.688381331307546, 40.78609595979963, 42.383097716740195, 43.2994886807033, 47.75605630874634, 50.51124634061541, 54.260598523276194, 55.545942306518555, 48.30090624945504, 0.9599478095769882, 0.7699864485434124, 1.1163938833134515, 0.4197941997221538, 17.833625180380686, 63.59970351627895, 49.634449686322895, 59.88543973650251, 53.01201071058001, 61.218847683497835, 48.41923407145909, 38.470970085689, 29.923160689217703, 36.770742416381836, 46.59646449770246, 4.748122291905539, 0.4556486415011542, 0.08168866126132862, 0.11202616550560508, 0.050220829634261985, 0.03405304326276694, 0.042082935239055326, 0.036204525136521885, 0.07051082820232425, 0.049644200397389274, 0.048350593740386624, 0.07651917436825377, 0.09707776763077293, 0.046250500716269016, 0.06478397228888103, 0.013541114549817783, 25.61757046835763, 66.09808118002755, 45.540800367082866, 50.019612652914866, 60.419519969395225, 45.16196720940726, 48.44324704578945, 62.17719881875174, 56.63257108415876, 56.472164971487864, 52.64143896102905, 57.5837482043675, 30.022846494402202, 0.20411843779895986, 0.26002010170902523, 6.397808764662061, 3.0496570765972137, 0.03577807605532663, 10.020931720733643, 61.36061872754778, 54.70164932523455, 51.32463720866612, 46.13654933656965, 45.23952647617885, 47.71218190874372, 51.90556567055838, 54.02443620136806, 49.70047146933419, 51.163334778376985, 52.386884757450645, 51.91097484316145, 49.66827004296439, 44.179721219199045, 37.71891791479928, 37.99437229973929, 36.51980822426932, 37.804960932050435, 37.35775055204119, 39.65336241040911, 39.19860628673008, 44.8093079158238, 44.29545041493007, 45.808302538735525, 46.76493746893746, 46.664973735809326, 43.57167741230556, 42.57161624091012, 38.31679303305489, 39.92524889537266, 41.5561717578343, 38.588655199323384, 38.11518062864031, 38.37314639772688, 38.21964679445539, 38.98919800349644, 36.643878732408794, 37.97194351468767, 37.18324307032994, 36.64661284855434, 36.33573307309832, 36.093438965933665, 35.02979135513306, 36.37429904937744, 37.04698889596121, 39.15099375588553, 40.30545432226998, 44.674283572605674, 46.29546158654349, 49.592805658067974, 47.87166738510132, 50.76504666464669, 40.37696865626744, 34.9114670072283, 35.64500222887312, 36.55683517456055, 35.76498719624111, 37.40029437201363, 36.62977041516985, 38.8681013243539, 47.11955615452358, 40.45228712899344, 34.823711259024485, 35.361178738730295, 34.052113805498394, 36.120373657771516, 34.55349928992135, 34.257644993918284, 33.020236832754954, 37.38214915139334, 38.864648069654194, 44.52756888525826, 49.01969391959054, 47.93091467448643, 48.514810017177034, 41.630694661821636, 40.98685720988682, 38.4643554006304, 34.56919527053833, 34.734089919498985, 32.82971027919224, 32.47551195962088, 34.8528276852199, 34.98250191552298, 37.48624011448452, 38.12161118643624, 37.65484857559204, 39.43028007234846, 37.5329841205052, 40.348977838243755, 37.95646292822701, 38.69726596559797, 40.43978384562901, 41.01617513384138, 39.285604681287495, 45.16695601599557, 47.80461032049996, 51.1078325680324, 48.44345201764788, 46.27650690078735, 48.93877172470093, 49.92280340194702, 48.43946027755737, 45.95166819436209, 43.4591964994158, 42.2509742464338, 37.57330799102783, 39.74945599692208, 37.961149488176616, 39.45462656021118, 40.18629271643502, 41.13774429048811, 38.6380603654044, 40.21031263896397, 40.96338619504656, 41.19213131495884, 42.24953249522618, 42.429199014391216, 44.14812776020595, 45.16094929831368, 46.83183472497122, 48.3305333682469, 53.53215980529785, 57.79905203410557, 60.14741461617606, 50.7706503868103, 1.516951126711709, 1.5877493619918823, 1.1666592146669115, 0.3456330363239561, 20.247846262795584, 67.52114173344204, 56.23790645599365, 64.52764238630022, 58.83105754852295, 67.3385569708688, 54.04357154028756, 38.561043058122905, 28.160249846322195, 42.67684323447091, 57.2909893308367, 7.268437155655452, 0.8454440480896405, 0.12165628054312297, 0.13189200844083512, 0.058928947895765305, 0.051422264094331434, 0.051120421183960776, 0.16579359929476464, 0.15754843529845985, 0.14140240954501287, 0.07827841889645372, 0.17122637134577545, 0.19770690612494946, 0.17332757716732367, 0.20776308008602687, 0.08645399234124593, 30.79460723059518, 77.65118449074882, 52.92368173599243, 60.858854566301616, 75.51938683646065, 53.4740172794887, 53.3189890725272, 67.41996206556047, 60.831909452165874, 61.61099706377302, 58.121483189719065, 64.43730885641915, 33.67147411618914, 0.29323382090244976, 0.6131014983568872, 11.749772071838379, 3.6055390196187154, 0.1335255814982312, 10.88586780003139, 60.63706806727818, 56.56502417155674, 55.72447279521397, 48.609319414411274, 48.51941319874355, 50.29084253311157, 53.8480110168457, 56.6529084614345, 50.56083215985979, 53.85649824142456, 53.73966080801827, 54.09148979187012, 51.75427906853812, 46.97590562275478, 39.342131750924246, 40.049402781895225, 39.08535064969744, 40.50605923788888, 39.334714548928396, 42.00934369223458, 41.29362712587629, 47.604682854243684, 47.26827539716448, 49.56154918670654, 49.76060812813895, 49.05084269387381, 45.891910212380544, 45.30331093924386, 40.04095377240862, 40.80031892231533, 44.33176170076643, 39.873759269714355, 41.460133756910054, 39.58892134257725, 39.64833191462925, 42.60657957621983, 37.61617490223476, 40.22930553981236, 38.56184557506016, 38.6326789855957, 38.533628940582275, 36.668767179761616, 37.69249044145857, 38.26685980388096, 39.752752917153494, 41.137108530317036, 42.200797830309185, 48.38334662573678, 48.25949151175362, 51.3303347315107, 50.76863540921892, 52.43597725459507, 40.34177950450352, 34.8339980670384, 35.938303061894004, 35.40351063864571, 36.24247087751116, 37.74362918308803, 36.97119099753243, 39.012912205287385, 49.39886059079851, 41.971437794821604, 35.52958917617798, 36.64222158704485, 33.49502113887242, 36.92499589920044, 34.96572201592581, 35.49435486112322, 33.419525487082346, 38.643844740731375, 37.62915761130196, 45.40918411527361, 52.75401020050049, 50.810491357530864, 52.86281899043492, 43.998216901506694, 45.09899568557739, 40.20334012167794, 36.46687684740339, 38.448235579899375, 34.50896481105259, 35.31039782932827, 36.59670393807547, 37.28840753010341, 38.524752616882324, 40.94160706656319, 40.037045410701204, 42.76134375163487, 40.62918826511928, 41.432375703539165, 39.747180461883545, 42.54405621119908, 41.38366188321795, 43.91665199824742, 40.92651210512434, 47.96165003095354, 50.49487638473511, 52.20133311407906, 51.851512159620015, 48.04546962465559, 50.32145977020264, 51.13524668557303, 50.66926227297102, 47.37527418136597, 45.186265059879844, 45.42478282111031, 37.329207352229524, 41.93435525894165, 38.74231113706316, 43.24005726405552, 42.02805866513933, 43.42551163264683, 40.620398793901714, 41.291434969220845, 42.76442180361067, 42.91343634469168, 43.64680480957031, 45.050848143441335, 44.973997592926025, 48.814565726688926, 48.17245837620327, 51.88140330995832, 55.789539200919016, 61.77830968584333, 62.31500244140625, 56.627787249428884, 2.0011220148631503, 1.16042374925954, 3.288205236196518, 0.9729907725538526, 23.162808384214127, 73.55604130881173, 61.25174740382603, 69.18437371935163, 64.65414823804582, 72.54954610552106, 60.1174887248448, 51.015438897269114, 39.61288915361677, 51.99946710041591, 68.81873171670097, 10.843069502285548, 1.1187293465648378, 0.31494107895663803, 0.3260795569845608, 0.17095228391034262, 0.15958106837102345, 0.15475232819361345], [0.09365447703748941, 0.051096831914037466, 0.04397012772304671, 0.09380446720336165, 0.10082039037453276, 0.08522014426333563, 0.03286307604451265, 0.0788889511355332, 0.059784743402685435, 14.977679320744105, 54.12172835213797, 40.8770409311567, 41.82389627184187, 89.47410024915422, 62.76100730895996, 35.236270972660606, 59.54157338823591, 52.64507981709072, 51.300332409994944, 51.276663371494834, 47.58701705932617, 39.604721546173096, 0.30039296246000696, 0.1746645625680685, 2.256778810705457, 1.8578738272190094, 0.0803788715441312, 4.089250675269535, 42.26905345916748, 53.44283376421247, 51.840520109449116, 51.935984883989605, 42.55165754045759, 44.46876975468227, 47.585936614445274, 50.00645971298218, 46.78264495304653, 48.26128762108939, 51.20338419505528, 49.62526069368635, 45.75461728232247, 42.3906260899135, 36.98891237803868, 35.87898629052298, 34.90500865663801, 36.03165905816214, 36.277298722948345, 36.04448543276106, 36.187114579336985, 37.026085240500315, 39.2135796546936, 42.77173130852835, 43.055033683776855, 42.03140769686018, 41.49853645052229, 41.13335997717721, 39.470367704119, 37.833156721932546, 39.31361286980765, 36.700047969818115, 35.29002571105957, 35.340348039354595, 35.1471221106393, 35.74744994299752, 38.21370608466012, 36.8007482119969, 33.41687822341919, 34.902052198137554, 34.21162360055106, 33.880833762032644, 32.84264782496861, 33.75717667170933, 34.855335984911235, 38.214331422533306, 42.378525802067344, 46.348222732543945, 47.35527726582119, 48.6893869808742, 47.362777846200125, 50.65980577468872, 41.76865461894444, 34.95279141834804, 34.250870500292095, 37.46370015825544, 33.99120937074934, 35.07023681913103, 36.79836845397949, 38.622433866773335, 46.28001226697649, 39.43074560165405, 35.48966482707432, 34.74280990873064, 35.69160727092198, 36.819209575653076, 34.904418059757774, 34.762389932359966, 36.99194179262434, 36.780997957502095, 35.67961468015398, 41.990166664123535, 47.47650596073696, 46.869987283434185, 45.24795811516898, 43.08264235087803, 36.97968169621059, 39.183104855673655, 37.06057957240513, 33.55476175035749, 32.19577401024954, 32.09394815989903, 30.965300151279994, 31.03511217662266, 30.415805339813232, 33.31907885415213, 35.8878938811166, 36.527298382350374, 37.51520715441023, 35.99477802004133, 35.01333107267107, 37.04634618759155, 38.85843985421317, 39.959503514426096, 41.41202790396554, 45.915468079703196, 47.221871852874756, 48.9714560508728, 43.76590040751866, 44.411780629839214, 47.332893644060405, 46.96583073479788, 47.71661138534546, 45.50099066325596, 42.45976413999285, 39.63878508976528, 37.74778420584542, 36.78035177503313, 38.03650965009417, 36.151303563799175, 37.57252631868635, 37.869996070861816, 36.853363445826936, 37.26801456723894, 38.7451251574925, 38.04944372177124, 39.04615238734654, 40.123244762420654, 43.81637212208339, 44.04536737714495, 46.37709249768938, 44.38896969386509, 52.43886423110962, 51.740264551980154, 50.59160920551845, 23.850601877485, 0.07865651217954499, 1.062043554016522, 0.7466693254453796, 0.05371965474582144, 28.902280977794103, 61.88789667401995, 48.92541033881051, 59.80044937133789, 51.22033779961722, 52.2564114843096, 47.20551579339163, 31.081150940486364, 26.24494763783046, 43.72209201540266, 38.73370926720755, 1.5565440250294549, 0.208055297977158, 0.010195445818161326, 0.050712221302092075, 0.035858448528285534, 0.04175690594794495, 0.0514257449789771, 0.08179234819752829, 0.022778086397530775, 0.0700318639033607, 0.09037403842168194, 0.06800940885607686, 0.0537588333577982, 0.017640285393489257, 0.1458983961492777, 0.18195869188223565, 19.19915291241237, 62.912790707179475, 44.89695249285017, 47.10836260659354, 77.2444508416312, 59.31250517708914, 41.7888217653547, 62.671646526881624, 58.8183353969029, 56.461079120635986, 56.020879473005024, 51.94481951849801, 43.732566424778526, 0.15532349183091096, 0.052082872217787166, 2.7271173553807393, 5.213708485875811, 0.1523635863725628, 4.8167935098920545, 47.59591770172119, 55.908363819122314, 54.22978673662458, 52.10840095792498, 44.172696590423584, 46.44584492274693, 49.54512711933681, 52.003583908081055, 49.75482375281197, 50.117891447884695, 53.17217711039952, 49.92065640858242, 48.23255681991577, 45.62958097457886, 39.61963932854788, 36.74838311331612, 36.69940873554775, 38.14398785999843, 37.33071511132376, 38.50842087609427, 38.7932379586356, 39.447230202811106, 41.35267291750227, 44.35174124581473, 43.71670716149466, 45.77909926005772, 43.30837195260184, 43.0124169077192, 40.288344383239746, 38.917659350803916, 41.177866663251606, 40.49896860122681, 36.05609934670584, 36.537505286080496, 36.38469702856881, 37.69432476588658, 38.3268574987139, 38.956624848502024, 34.09456729888916, 35.25892557416643, 34.3285722051348, 35.08139910016741, 34.30472598757063, 35.83847481863839, 37.10285241263253, 39.73341260637556, 43.90784863063267, 46.903234413691926, 48.07144546508789, 51.763169288635254, 49.677059514181956, 52.270512853349956, 42.14310346330915, 35.154525416237966, 34.85573550633022, 37.060600417000906, 33.32676356179373, 34.99470295224871, 36.88122572217669, 38.987565176827566, 46.98036636625017, 39.10490982873099, 35.37721170697893, 35.08693334034511, 35.208127294267925, 36.73682131086077, 35.4371121270316, 34.92114584786551, 35.3381906236921, 36.40711191722325, 36.82416711534773, 42.66492707388741, 49.15723351069859, 48.40621314729963, 46.819098676954, 44.348274094717844, 40.04970155443464, 41.83338751111712, 38.888793059757774, 35.751684870038716, 32.99992030007498, 34.403921944754465, 34.94891084943499, 33.88694470269339, 32.51179892676217, 35.7246390070234, 37.22567571912493, 39.09986891065325, 39.16006115504673, 38.041713850838796, 36.82101958138602, 39.187468324388774, 40.16552802494594, 40.99559456961495, 43.296792779650005, 48.96743999208723, 48.34689290182931, 48.54726505279541, 46.52353620529175, 43.65169286727905, 48.521396909441265, 47.75458329064505, 48.40509101322719, 46.850275244031636, 44.32469885689871, 41.90023960386004, 39.66111660003662, 38.7569579396929, 40.064487321036204, 38.393476826804026, 39.34320524760655, 39.09756905691964, 39.018488134656636, 39.663941042763845, 41.38290105547224, 39.670552253723145, 41.37951728275844, 42.93269675118582, 45.150620801108225, 45.93752861022949, 50.48876196997506, 47.27498388290405, 57.412589754377095, 54.081908226013184, 55.518166882651194, 28.219271319253103, 0.11797958426177502, 1.7337038729872023, 1.4919346805129732, 0.14544685823576792, 32.88893672398159, 68.29387869153703, 54.514329365321565, 64.35693904331752, 59.061459813799175, 58.63686234610421, 55.10878596987043, 37.505076680864605, 26.679673842021398, 50.25719935553414, 48.482170854296, 3.0632058467183794, 0.3970169190849577, 0.02751593172018017, 0.06341651388044868, 0.00945588929711708, 0.012775998462789824, 0.02159633793468986, 0.18291902249412878, 0.13079124822148255, 0.13959974556096963, 0.300227589905262, 0.16669454452182564, 0.3084556412483965, 0.19444514757820539, 0.1668711807578802, 0.3722031648669924, 21.071845293045044, 76.24750246320451, 51.87315232413155, 53.7585494858878, 90.69737924848283, 73.65528242928642, 47.569938387189595, 70.26547173091343, 62.80003534044538, 63.22605718885149, 60.39472879682268, 56.50285169056484, 47.81753396987915, 0.6822507849761418, 0.8548580972211701, 9.249880569321768, 7.228101125785282, 0.22727652585932187, 6.727329688412802, 47.73244980403355, 57.19174126216343, 57.97640480313982, 56.22776208605085, 47.34930876323155, 47.30617087227957, 51.86326156343733, 53.54670238494873, 49.840408188956125, 52.94471393312727, 54.33799450738089, 51.21637732642037, 50.21666703905378, 48.72933912277222, 43.06908988952637, 40.48893540246146, 38.482941831861226, 40.4110460962568, 39.69712216513497, 41.32564442498343, 40.382113797324045, 41.77118376323155, 43.9139769417899, 46.36890751974923, 47.83872250148228, 47.81366729736328, 45.868182114192415, 45.71611383983067, 43.74728618349348, 43.009668895176475, 43.31518118722098, 42.51820196424212, 36.99253586360386, 38.92885289873396, 37.969330992017476, 39.695840222494944, 41.6390255519322, 41.14461605889456, 37.17815351486206, 37.312375341142925, 36.62879071916853, 36.49152210780552, 35.8501547404698, 36.36847645895821, 38.29653903416225, 43.04645960671561, 46.513353620256694, 49.91552516392299, 51.04473945072719, 53.106412410736084, 52.19853299004691, 54.95297956466675, 43.49358660834176, 34.66850239889962, 34.71276242392403, 36.864595208849224, 32.52006728308541, 34.23593534742083, 37.20991025652204, 39.2434777532305, 47.256856032780235, 41.02108056204659, 34.43405975614275, 35.349985190800254, 35.99253722599575, 37.67164931978498, 34.95763431276594, 35.43859556743077, 36.23411219460623, 37.62131309509277, 36.75550849097115, 44.40676055635725, 52.91989149366106, 50.32203994478498, 49.96189396721976, 48.93699645996094, 41.51446519579206, 44.49947731835501, 43.543158531188965, 38.3213996887207, 35.691200801304404, 36.46472985403878, 35.46374109813145, 34.54495300565447, 33.322222914014546, 38.00737237930298, 39.16296897615705, 41.20686844417027, 40.885868617466514, 40.998283522469656, 40.25774451664516, 42.10808801651001, 42.34417390823364, 43.90639645712716, 45.500882966177805, 52.23409039633614, 50.13762433188302, 52.46082401275635, 48.277414390019004, 44.449349539620535, 49.052499839237754, 49.97493921007429, 50.643946511404856, 50.67640849522182, 45.11929832186018, 43.5508189201355, 42.16538981028965, 41.07384865624564, 41.99022919791085, 40.18804713657924, 41.33849859237671, 40.98392159598214, 40.39340114593506, 42.560922963278635, 43.04905128479004, 43.207362515585764, 43.757614680698936, 44.26985672542027, 47.71978323800223, 48.52631623404366, 51.03776345934187, 48.991505077907014, 58.556297983442036, 57.51564196177891, 60.29592541285923, 32.19678497314453, 0.33605391319308964, 1.8253927358559199, 4.820898158209665, 0.21607218922248908, 35.90393727166312, 74.06908239637102, 59.27007252829415, 70.8957428250994, 61.13511494227818, 62.49691322871617, 61.83759866441999, 44.80050802230835, 35.5665396962847, 56.95063182285854, 61.47652857644217, 4.742167251450675, 0.5248214868562562, 0.12510325200855732, 0.25065843548093525, 0.1872745252081326, 0.22864673233457974, 0.14812222681939602], [0.038027969255511246, 0.07026998219745499, 0.01917641912586987, 0.01561956400317805, 0.02785007968278868, 0.04163530568725296, 0.025735460920259356, 0.11742200489555087, 0.07727183255233935, 7.712548204830714, 60.58212171282087, 40.40775612422398, 46.84426505225045, 78.64841774531773, 63.9442994253976, 39.70411900111607, 52.25280884334019, 55.55440868650164, 43.97925526755196, 51.27421760559082, 48.05331761496407, 52.92176055908203, 6.734874997820173, 0.6145587201629366, 2.8699256352015903, 5.605358464377267, 0.1921227393405778, 0.21354000509849616, 28.779735599245342, 55.1240268434797, 54.6574136189052, 51.16037137167794, 43.4479022026062, 45.54412855420794, 50.371948855263845, 51.765003613063264, 49.1101073537554, 49.56753158569336, 52.64697320120675, 50.78409515108381, 46.662621770586284, 40.25747006280081, 37.82757037026541, 36.2485887663705, 36.54002400806972, 36.055870056152344, 35.86926228659493, 36.48727675846645, 34.70301062720162, 33.99996062687465, 37.89612824576241, 38.56639664513724, 39.38845886502947, 41.64793314252581, 39.81339679445539, 37.98397779464722, 37.33035380499703, 37.262494223458425, 39.27333068847656, 37.8320380619594, 35.98713847569057, 35.390771116529194, 36.589238098689485, 36.751037325177876, 36.25885820388794, 35.04163803373064, 34.86102655955723, 34.46978391919817, 34.52590104511806, 35.479558672223774, 33.55085686274937, 34.25667919431414, 35.02398266111101, 40.48712192262922, 46.84110362189156, 46.14120462962559, 46.59439046042306, 45.725507804325645, 46.21921900340489, 48.50679874420166, 42.184723172869, 36.5095248903547, 37.2878794670105, 36.368754386901855, 35.97590323856899, 36.414244243076865, 38.72762959344046, 38.54323829923357, 46.1085341998509, 36.14329923902239, 36.222949913569856, 36.87901619502476, 35.40070704051426, 38.058632714407786, 35.6599999155317, 37.55364458901541, 35.12007277352469, 38.40829038619995, 36.03508799416678, 45.0316606930324, 47.81684609821865, 45.64831679207938, 45.08497422082083, 41.9384685925075, 40.411473410470144, 36.28442062650408, 37.27938529423305, 36.163525445120676, 33.879266943250386, 33.070378507886616, 31.401581014905656, 31.70270551953997, 32.113882541656494, 32.79864140919277, 33.32597494125366, 34.40309510912214, 36.93642915998186, 36.29406125204903, 35.56648063659668, 37.215236050742014, 40.02741868155343, 40.247217995779856, 44.391537053244456, 44.602022307259695, 48.25312001364571, 46.58740752083914, 46.55069671358381, 50.529422828129356, 48.657390526362825, 46.70596463339669, 48.30713530949184, 43.17489010947091, 40.922391823359895, 37.329217774527415, 37.28886958530971, 37.06629793984549, 38.83813026973179, 37.654466424669536, 37.83738817487444, 36.66184677396502, 39.395563398088726, 37.92778771264212, 37.15875761849539, 37.40698548725673, 40.38289199556623, 38.8613407271249, 46.6952018737793, 46.50650617054531, 50.422542163303916, 46.554702350071494, 55.24211842673165, 50.70565693719046, 59.619851793561665, 14.756478207451956, 0.32167287915945053, 0.7491423955985478, 1.7355788009507316, 0.3033352260078703, 41.824372223445344, 58.60276753561837, 48.62564073290144, 56.524095807756694, 44.60752180644444, 51.80298246656145, 40.144554887499126, 25.332331282751902, 24.325858661106654, 41.93369518007551, 35.78442130770002, 0.4462522342801094, 0.1054893151990005, 0.0789812726101705, 0.08087637341980423, 0.08021901547908783, 0.04818447479712112, 0.054883284627326896, 0.03477637516334653, 0.05892987748874085, 0.05806290651006358, 0.0743365307737674, 0.061677706827010424, 0.028609448578208685, 0.07465333198862416, 0.10649370987500463, 0.08871674378003393, 10.484941107886177, 67.37345082419259, 46.96645607267107, 49.52643299102783, 81.02741840907505, 64.81870242527553, 43.95849405016218, 58.966901779174805, 61.569863728114534, 51.88320984159197, 56.36880704334804, 51.860986028398784, 57.450655460357666, 5.9642984952245435, 0.4420106847371374, 1.058002416576658, 5.644759093012128, 0.1791665202804974, 0.5536737729396138, 33.682764938899446, 57.392412185668945, 56.330418246132986, 53.83884981700352, 45.70789064679827, 45.946450097220286, 53.53678730555943, 54.403390952519004, 49.48175259998867, 50.871048382350374, 53.52598285675049, 51.45954690660749, 48.040390491485596, 42.44213308606829, 39.03931188583374, 37.5399740082877, 37.60926144463675, 37.50530597141811, 37.15700319835118, 38.23551648003714, 36.63456467219761, 37.58843421936035, 38.781168937683105, 41.0211500440325, 42.106444767543245, 42.340126582554404, 43.363551071711946, 40.81439249856131, 39.5220935685294, 40.03386313574654, 40.609125341687886, 39.9079270362854, 36.7507072857448, 37.30219970430647, 37.647959436689106, 38.322997774396626, 37.783317293439595, 37.53899083818708, 36.0145525932312, 35.53786448069981, 36.69654260362898, 36.938239165714805, 35.09486470903669, 36.66569260188511, 36.78120640345982, 41.52229234150478, 47.13868801934378, 48.79112945284162, 48.32457528795515, 47.99787793840681, 48.26299687794277, 50.33211135864258, 43.501278264181956, 37.18721743992397, 36.31756353378296, 36.012214524405344, 36.547444684164866, 36.55124882289341, 36.373993328639436, 38.71720382145473, 46.992115770067485, 36.61279944011143, 36.07774993351528, 36.224999632154194, 34.48251301901681, 37.08745520455496, 34.98582315444946, 35.81470850535801, 36.347315720149446, 37.44237266268049, 35.84967878886631, 44.44134521484375, 51.17643560682024, 47.7783739226205, 47.14961406162807, 45.03342553547451, 43.351485524858745, 39.20537035805838, 38.87591804776873, 38.04511499404907, 34.70243392671858, 34.86871474129813, 32.97343029294695, 33.29927996226719, 34.9016353062221, 33.52494355610439, 34.69947052001953, 37.40870516640799, 37.78237233843122, 37.80348443984985, 35.65167597361973, 39.435831683022634, 39.776522704533164, 40.95335647038051, 46.099643979753765, 47.36098173686436, 49.885710443769185, 49.37132487978254, 47.457328932625906, 52.35130998066494, 51.740462575639995, 47.76581505366734, 47.80236605235508, 45.98946292059762, 43.523786953517366, 38.699207987104145, 37.868589060647146, 38.812817982264924, 40.27122402191162, 38.789082935878206, 40.70214435032436, 37.71862609045846, 40.81825917107718, 39.46273858206612, 40.371239866529194, 39.85889707292829, 41.95227466310774, 41.65682683672224, 49.06082378114973, 48.52470425197056, 53.23559331893921, 51.16372735159737, 57.9967109135219, 53.62889610018049, 61.88900143759591, 16.837399414607457, 0.33733794572097914, 2.1165411472320557, 0.9242171325853893, 0.4439934454858303, 46.16690949031285, 62.68635586329869, 55.01353658948626, 65.33824702671596, 51.371301310403005, 57.77367721285139, 47.91145971843174, 29.36688096182687, 25.470395462853567, 51.859804834638325, 44.00149645124163, 0.5530445809875215, 0.21473001981420176, 0.02797487414708095, 0.09235318936407566, 0.0428069796014045, 0.033493601317916594, 0.08021604349570614, 0.17305647528597287, 0.196676157148821, 0.1360972292189087, 0.2027199635548251, 0.15733062555747374, 0.18875356870038168, 0.16392661019095353, 0.23920338015471185, 0.2706837680722986, 10.702239070619855, 80.20273671831403, 52.78736502783639, 57.209264619009836, 83.87546416691372, 69.47871330806187, 52.84078277860369, 64.77063478742326, 66.3413862500872, 55.184052331107004, 62.37563937050955, 57.09817681993757, 63.558632714407786, 8.300386650221688, 1.0315412878990173, 7.466480357306344, 10.139712044170924, 0.5157833461250577, 1.1165723651647568, 37.402740137917654, 58.398427963256836, 59.6029885155814, 54.55955866404942, 47.967681067330496, 47.796665055411204, 55.18688719613211, 54.28259652001517, 52.0510470526559, 52.90051991598946, 56.35389968327114, 53.48011432375227, 52.028580052512034, 44.02040597370693, 41.33702904837472, 40.440562043871196, 40.62753806795393, 39.735302516392295, 38.966032709394185, 40.748759814671104, 39.34750618253435, 38.386761392865864, 42.52721725191389, 43.14332791737148, 44.01204034260341, 46.52885157721383, 45.842286178043906, 41.53101233073643, 41.49180712018694, 43.81342955998012, 43.933946064540315, 43.324498721531455, 39.33306435176304, 40.022040775844026, 40.127858366285054, 41.28017888750349, 40.432887758527485, 39.40990447998047, 38.21348374230521, 37.799027170453755, 38.032931327819824, 39.33268567493984, 37.341276373182026, 38.99021938868931, 39.03013331549508, 44.22123670578003, 49.59081847327096, 51.160385268075125, 52.714544432503835, 48.754317896706716, 49.16275385447911, 54.28583090645926, 44.24542685917446, 36.656854493277415, 37.000960554395405, 36.30409445081438, 36.77176032747541, 36.16539798464094, 37.956518513815745, 38.985042980739046, 48.55550561632429, 35.07230390821184, 36.77367455618722, 35.53173964364188, 34.83767713819231, 38.18590634209769, 35.02770342145647, 37.069817202431814, 37.07070657185146, 39.385874135153635, 35.98117692129952, 47.02330275944301, 54.683337347848074, 51.160829952784944, 49.20210150309971, 48.439133712223594, 47.25876678739275, 41.75322961807251, 41.45136513028826, 40.350033964429585, 37.70294748033796, 36.749988147190635, 35.67686666761126, 35.33201714924404, 35.403882367270334, 36.50776699611119, 37.756733485630576, 39.194055216653005, 39.62858166013445, 41.10075208118984, 39.21039737973894, 42.372303690229145, 42.809414863586426, 42.172244208199636, 48.91834054674421, 48.999231474740164, 52.2895439692906, 49.87715373720442, 47.245742389133994, 53.46913964407784, 52.09335463387625, 50.168502126421245, 51.373677594321116, 48.05659369059971, 45.976772035871235, 40.65821783883231, 39.03638669422695, 41.48134313310896, 42.58633599962507, 41.00616972787039, 41.46110650471279, 40.566341808864046, 42.81929520198277, 42.03304052352905, 42.061142512730186, 41.31166464941842, 43.976128578186035, 43.39985540934971, 51.91173219680786, 51.26258979524885, 55.77408640725272, 52.839862142290386, 60.64379392351423, 55.72251687731062, 64.20974145616803, 19.24931022099086, 0.4041537775525025, 4.008916471685682, 2.601159977061408, 0.5791974376354898, 50.857339586530415, 67.64261708940778, 59.36412334442139, 69.2501106262207, 52.98267541612898, 62.97875690460205, 51.217669691358296, 37.63000529153006, 35.607659135546, 59.4567289352417, 54.24896723883492, 1.3075555456536156, 0.39961079561284607, 0.17671498682882103, 0.22411417269280978, 0.20145769843033381, 0.18641593413693563, 0.14165329108280794], [0.04745201660054071, 0.06658686697483063, 0.012149925227276981, 0.10993851681372949, 0.01991825637274555, 0.08239253956292357, 0.01904825403887246, 0.09722290627126183, 0.006338354216755501, 1.5151065971170152, 49.89040742601667, 49.48961101259504, 36.3296012878418, 55.44938319069998, 48.32990108217512, 36.82763079234532, 55.95618479592459, 54.718967710222515, 40.93251882280622, 51.10432025364467, 48.14703491755894, 52.314932686941965, 23.750811849321636, 0.49052306158202036, 2.0306464305945804, 4.198758627687182, 0.9574304989406041, 0.11592012191457407, 12.504044192177908, 48.01946251732962, 56.06784929547991, 47.55376992906843, 42.9321791103908, 47.344590936388286, 51.78134230204991, 47.21753965105329, 45.89226457050869, 48.593661648886545, 50.929927417210166, 50.19632271357945, 45.00389916556222, 39.126028878348215, 34.81834030151367, 34.34193359102522, 35.50083058220999, 34.6945755141122, 36.4408905846732, 33.89364971433367, 35.43070241383144, 34.4632317679269, 33.39226075581142, 36.530980927603586, 36.84114851270403, 36.261057308741975, 38.77768441608974, 37.983119692121235, 38.35138463973999, 37.40189593178885, 37.79303434916905, 38.78857224328177, 37.54179443631853, 36.061591897692, 35.40394837515694, 36.25862543923514, 35.31373643875122, 34.69942535672869, 34.21372890472412, 33.996608121054514, 33.51871449606759, 34.6794319152832, 33.403343132564, 32.46566983631679, 36.31828614643642, 45.10126427241734, 45.359983921051025, 44.917991638183594, 46.35824203491211, 46.52739592960903, 46.43877165658133, 47.01569448198591, 44.75667878559658, 35.121347767966135, 36.22433607918875, 34.70531048093523, 35.8653678212847, 37.28698314939226, 36.67627123423985, 38.42629664284842, 47.23983989443098, 37.144354002816335, 35.05507584980556, 37.04796164376395, 36.13516289847237, 35.89807299205235, 36.620769023895264, 37.968000411987305, 36.588414737156455, 35.62883377075195, 38.61858456475394, 46.365631444113596, 47.47551236833845, 45.0014533996582, 45.435076577322825, 43.78620304380144, 41.92281777518136, 37.467594623565674, 32.39641714096069, 35.68752520424979, 34.83358464922224, 34.932804925101145, 32.50817196709769, 32.6788683618818, 34.11375822339739, 33.280846391405376, 33.15921817507063, 35.1533476965768, 34.05289200374058, 34.8831843648638, 35.70847054890224, 36.77932344164167, 38.08776651109968, 42.63809660502842, 43.5070035798209, 44.75835330145699, 46.93571029390608, 46.767341545649934, 49.307502201625276, 44.34156213487898, 45.37542281832014, 46.82535205568586, 44.79491819654192, 40.890096596309114, 37.610550335475374, 36.956839493342805, 36.191471099853516, 37.0907347542899, 36.33649042674473, 35.203840255737305, 37.36107179096767, 37.09121765409197, 36.69194637026106, 36.51501744134085, 39.9943973677499, 37.18410117285592, 39.12127978461129, 38.35030766895839, 46.308037825993125, 47.65037073407854, 51.47957508904593, 50.15684999738421, 54.74944598334176, 50.6808796610151, 51.31353746141706, 2.8427512305123463, 0.11222138681582042, 2.490495583840779, 1.453934222459793, 2.0207204946449826, 51.830212456839426, 50.85915306636265, 50.41796677453177, 40.18821736744472, 47.014343057359966, 42.70204087666103, 36.674238886152, 27.950254440307617, 23.196220534188406, 48.13291270392281, 22.505595649991715, 0.02952688220622284, 0.043052225905869684, 0.0684537271569882, 0.0365002646243998, 0.053745245694049766, 0.0970845597663096, 0.06751628353127412, 0.02015725167335144, 0.09115679641919476, 0.03127021508823548, 0.03913185412862471, 0.023734425527176688, 0.06239656039646693, 0.01819122359821839, 0.05327519055988107, 0.09528406030897583, 2.696123395647321, 59.990427017211914, 54.76308529717581, 43.400716985974995, 61.75428281511579, 55.694911684308735, 44.00054802213396, 58.016308307647705, 60.91944980621338, 46.09836203711373, 54.73383685520717, 52.157003607068745, 56.57219818660191, 23.55834674835205, 0.7255200403077262, 0.8700745435697692, 5.551086953708103, 1.6128595003059931, 0.18853506685367652, 16.479028701782227, 51.84730849947248, 55.617630345480784, 50.87727744238717, 44.51544080461775, 47.423696177346365, 53.51093305860247, 49.91210317611694, 48.60631431852068, 50.13275017057146, 53.645526613507954, 50.405769211905344, 46.74879332951137, 40.5524662562779, 37.47115904944283, 36.44239486966814, 37.36610228674752, 37.66632352556501, 37.244991711207796, 37.17445707321167, 38.29622289112636, 36.84506382261004, 36.21194396700178, 39.18204525538853, 38.961238452366416, 37.55911976950509, 39.04962996074131, 41.11065673828125, 41.405107498168945, 38.73612029211861, 39.867095947265625, 39.93093599591936, 39.53466285978045, 38.19310120173863, 37.74804128919329, 37.62047931126186, 37.271780490875244, 36.458202021462576, 36.378322056361604, 35.36613975252424, 35.29166201182774, 35.17488016401018, 34.207162857055664, 34.90104818344116, 38.03019373757498, 46.538634640829905, 46.29764679500035, 47.24674640383039, 48.57384191240583, 47.673473494393484, 47.464079107557026, 49.97353914805821, 44.9476534979684, 35.837529863630024, 34.48613650458199, 35.256028175354004, 34.69858462469918, 35.23268570218767, 36.48020349230085, 39.10064016069685, 46.39156559535435, 36.18373428072248, 34.838226045881, 36.14530726841518, 35.66151809692383, 36.17942639759609, 36.783544472285676, 37.85038478033883, 35.90281513759068, 36.410196917397634, 37.90822853360857, 46.82292366027832, 50.47745030266898, 46.53004319327218, 47.19169235229492, 46.21477215630667, 43.7171379498073, 38.33902726854597, 34.93743589946202, 36.7590069089617, 38.231823512486045, 35.90899556023734, 34.56316076006208, 34.00642939976284, 35.68471813201904, 34.26440211704799, 36.070593288966585, 36.83148009436471, 36.47553430284773, 38.0050482068743, 37.25302382877895, 37.441347803388325, 39.49130262647356, 42.58468232836042, 46.52435609272548, 46.49825518471854, 48.83504901613508, 48.613811424800325, 50.482988016945974, 47.49136815752302, 46.5974372455052, 46.0153797013419, 46.21935101917812, 41.900725977761404, 40.34285647528512, 37.661949634552, 37.78627722603934, 38.47073037283761, 37.53342533111572, 36.44746010644095, 39.10343681062971, 38.950597286224365, 39.841130529131206, 38.920876366751536, 41.753740310668945, 39.58402633666992, 42.25730752944946, 42.51276499884469, 49.1589948790414, 50.10158749989101, 54.220767974853516, 52.04295934949602, 58.02470520564488, 53.884867736271445, 53.70586824417114, 3.6610774908746992, 0.11782711744308472, 3.8772615705217635, 1.27126173887934, 2.359102108648845, 57.05206509998867, 55.31790937696184, 56.16636432920183, 43.73103434698922, 47.08523205348423, 46.90882076535906, 42.84189074380057, 31.37807525907244, 26.035751274653844, 55.985266481127056, 29.58451591219221, 0.09182499056415898, 0.0015950291937250377, 0.06733560322650842, 0.08947313390672207, 0.04303115400086556, 0.11540803153600011, 0.07767114362546376, 0.13122803478368691, 0.19560058414936066, 0.20381159069282667, 0.11967388620334012, 0.13388019746967725, 0.17223133599119528, 0.14957396606249468, 0.2621474718408925, 0.21196968507553848, 2.8625095188617706, 69.6598458971296, 64.45806312561035, 47.519001143319265, 64.41316386631557, 57.25570290429251, 48.79759127753121, 65.6387357711792, 66.06528568267822, 52.06754207611084, 61.124213218688965, 57.05390984671456, 61.5408411026001, 26.71312247003828, 0.8979614100285939, 4.939014060156686, 14.269752553531102, 1.6592608732836587, 0.1593809819647244, 20.247068064553396, 51.349417958940776, 58.0466684613909, 52.85878208705357, 47.451951026916504, 49.73378113337925, 53.406400884900776, 50.30824777058193, 49.51663255691528, 50.43361759185791, 54.96466643469674, 53.28087820325579, 49.407497201647075, 43.94477483204433, 39.28776209694998, 39.24359239850725, 39.322409289223806, 40.01089586530413, 40.247363907950266, 39.92427614756993, 41.44501100267683, 39.87291158948626, 38.43500620978219, 41.67692450114659, 42.84059490476336, 40.34941904885428, 42.231474127088276, 44.466449056352886, 44.010824407849995, 41.07043709073748, 42.69012819017683, 42.82091760635376, 42.31029101780483, 39.47096177509853, 40.73606545584542, 40.13920477458409, 40.01097924368722, 40.181025981903076, 37.84013966151646, 36.66976424625942, 36.59298317773001, 36.82663025174822, 36.03105803898403, 36.36760098593575, 39.58831684929984, 49.89356885637556, 49.511591638837544, 50.06174652917044, 51.205114296504426, 50.19112893513271, 50.44756610052926, 52.210640226091655, 46.7237138066973, 33.85813399723598, 35.789302417210166, 35.17165272576468, 35.37544339043753, 36.40672629220145, 36.046069622039795, 39.62515619822911, 49.190518856048584, 36.425528117588584, 34.06161199297224, 35.93566274642944, 35.43797370365688, 36.48529304776873, 36.86152063097273, 38.4698166847229, 36.94380119868687, 36.920542103903635, 38.11773409162249, 47.909163338797434, 52.82020568847656, 49.182639598846436, 49.649867738996235, 48.287294728415354, 45.97385726656233, 40.33621399743216, 35.919018336704795, 39.100379603249685, 40.54348223549979, 38.01498065676008, 36.06373541695731, 35.9469188281468, 38.64491823741368, 36.52738176073347, 37.410518646240234, 40.82571806226458, 37.025338309151785, 39.75316286087036, 39.09553323473249, 40.11980193001883, 40.26914651053292, 47.253152642931255, 47.680866377694265, 48.05890049253191, 50.26065608433315, 50.441545486450195, 52.498149735586985, 50.859688077654155, 49.009573868342805, 48.525402545928955, 49.11509616034371, 45.31894786017281, 42.6594796861921, 40.624480860573904, 38.68383509772164, 41.48341022218977, 39.49138600485665, 37.573259353637695, 41.155201639447895, 40.419140747615266, 42.29905925478254, 40.2470303944179, 44.61353199822562, 42.66688993998936, 42.4782463482448, 44.15122318267822, 51.44006415775844, 51.030162130083355, 56.31424631391253, 53.57068409238543, 60.26133033207485, 55.670155252729145, 56.23211513246809, 4.725769937038422, 0.1739918358091797, 7.9678423915590555, 3.1371822314602986, 2.937091265405927, 63.44475173950195, 59.161798749651226, 61.34841769082205, 50.01815700531006, 56.31549004146031, 51.510536261967246, 49.161878381456646, 39.93879788262503, 32.649282932281494, 64.67799445561, 38.78013365609305, 0.25437574886849945, 0.1436785009822675, 0.10579573482807193, 0.1636845360377005, 0.18592740249420914, 0.2570444270968437, 0.16305523552000523], [0.09856509603559971, 0.061593602411448956, 0.018604841582211, 0.056320699996181896, 0.06825966614165477, 0.033323926851153374, 0.045121011324226856, 0.015964441300768937, 0.09448005738002913, 0.11857077825282301, 29.510896274021693, 53.64305305480957, 39.13731970105852, 29.569031851632253, 26.543893882206508, 33.72166442871094, 46.24413871765137, 56.307332856314524, 48.97880377088274, 55.10806335721697, 50.6897212437221, 50.25807135445731, 42.870656285967144, 0.4047405203538281, 0.6478190411414418, 1.6072120262043816, 0.6731203634824071, 0.1276498617870467, 4.9239212700298856, 53.68908487047468, 54.326620306287495, 49.38263654708862, 45.79299218314034, 50.33400821685791, 51.16782678876604, 48.804970264434814, 45.51449448721749, 52.778224672589985, 51.21959434236799, 48.90109511784145, 41.17570229939052, 37.90073490142822, 35.60311848776681, 35.90631702968052, 33.58203342982701, 36.40552077974592, 36.44077941349575, 36.67749759129116, 35.501983983176096, 35.12207385471889, 33.55143356323242, 35.8393155506679, 35.66049671173096, 35.65824549538748, 35.69106878553118, 37.42572477885655, 37.02622420447213, 36.57556751796177, 37.71881021772112, 36.79921613420759, 35.764942032950266, 36.831685066223145, 36.475787912096294, 36.33956847872053, 33.62479959215437, 33.76792206083025, 34.63080842154366, 34.69737563814436, 34.59360081808907, 34.050640787397114, 33.437993798937114, 34.25206906454903, 42.98376601082938, 45.95938069479806, 44.79532814025879, 45.073530537741526, 45.4124984060015, 43.54175846917288, 46.72567319869995, 49.121061188834055, 44.827182156699045, 38.45899486541748, 33.17383023670742, 34.523038387298584, 35.90224538530622, 36.92414474487305, 38.28779820033482, 39.11018698556082, 44.69986336571829, 39.11882012231009, 35.287406240190776, 37.5175313268389, 36.011672564915244, 35.75515896933419, 37.150840146201, 36.02345323562622, 35.3787750516619, 35.04275321960449, 38.75109018598284, 49.03936079570225, 46.09212602887835, 47.88917337145124, 45.62023564747402, 44.018130438668386, 43.27697999136788, 42.03256804602486, 37.87171227591378, 32.0414753641401, 33.43264716012137, 33.988093103681294, 33.9225993837629, 35.4370322227478, 34.90506771632603, 37.72850295475551, 34.596845626831055, 33.966567584446494, 33.57072523662022, 34.10830388750349, 37.28407532828194, 38.2174893787929, 38.57472406114851, 41.278348037174766, 43.7226687158857, 44.156899860927034, 45.596066338675364, 46.77714197976248, 44.16286488941738, 44.80191503252302, 42.081320081438335, 41.363011837005615, 38.28026635306222, 37.01219926561628, 37.06347002301897, 36.04791784286499, 35.68063953944615, 37.035242966243196, 37.757848671504426, 37.54631771360125, 38.42678649084908, 36.44644219534737, 37.80881718226841, 36.76454809733799, 37.49664504187447, 37.90968765531267, 38.5218482698713, 38.761675766536165, 46.23630114964077, 49.43825340270996, 50.709183147975374, 53.52088982718331, 53.29455573218209, 57.95830127171108, 33.888886724199565, 0.16411246093256132, 0.19454452581703663, 1.100859014051301, 0.6607045297111783, 6.19616596187864, 57.51722615105765, 47.804589475904194, 50.822796617235454, 47.04173980440412, 58.881348609924316, 52.66805403573172, 32.583605085100444, 26.950019563947404, 26.602232694625854, 46.35863808223179, 17.37628606387547, 0.49531460446970804, 0.030200077154274498, 0.09882515815219708, 0.05380340971584831, 0.08291047212800809, 0.039683798261518986, 0.024004066861899834, 0.0411412405914494, 0.03432879310899547, 0.02445157427739884, 0.08281727534319673, 0.10548818883086954, 0.02472896787471005, 0.11934810797018663, 0.0214935280050018, 0.11713176832667418, 0.2010701327983822, 40.03073992047991, 62.215851647513254, 41.691963876996724, 42.97757169178554, 39.51804971694946, 39.512838568006245, 56.26981258392334, 61.0580872126988, 53.00209910529, 57.20787845339094, 54.7255094391959, 55.356715066092356, 46.59346635001046, 0.28541587612458635, 0.15318563154765538, 4.868350446224213, 3.2994504613535742, 0.11334902380726167, 6.82154335294451, 55.857676710401265, 53.32595116751534, 49.901625292641775, 47.35051427568708, 53.5906914302281, 52.86783558981759, 50.118784291403635, 46.05390051433018, 55.04407392229353, 52.36715187345232, 51.00673280443464, 43.024958406175884, 39.354899065835134, 37.1829651423863, 38.46081529344831, 36.78219304765974, 37.69082982199532, 37.7869234085083, 38.220960003989084, 36.801877294267925, 37.051817893981934, 36.48543895993914, 37.73955406461443, 38.39837530681065, 37.585342270987375, 38.85615389687674, 41.03541122164045, 39.4214072227478, 39.09687771115984, 40.125964982169016, 38.59986959184919, 38.071907247815815, 37.906620025634766, 37.99906928198678, 39.13281726837158, 36.00131280081612, 36.1882540839059, 36.96503141948155, 35.77003506251744, 35.794833183288574, 34.958718231746126, 34.79781532287598, 36.35346140180315, 43.51501137869698, 48.556735447474885, 44.72078439167568, 47.22592612675258, 46.964795453207834, 45.95747341428484, 49.756060532161165, 50.03513492856707, 46.71765150342669, 37.135178906576975, 33.573344707489014, 34.31062500817435, 34.16248941421509, 35.73768424987793, 36.21671737943377, 37.91986676624843, 47.688259260995046, 38.758427483694895, 34.20757974897112, 36.95655114310128, 34.1271265574864, 36.43219838823591, 35.35849673407418, 36.95719385147095, 34.975776059286936, 35.898000035967144, 38.345746176583425, 49.38807698658535, 49.20613840648106, 50.3289464541844, 47.26579489026751, 46.60451398577009, 45.88099806649344, 44.33500303540911, 38.591861792973106, 34.77072777066912, 35.36496203286307, 35.52673346655709, 34.60761186054775, 38.18585423060826, 37.060916560036794, 38.21632555552891, 36.154332978384836, 37.209086894989014, 35.70831421443394, 37.14682756151472, 39.64044223512922, 39.640900816236226, 41.23045410428728, 43.206865719386506, 45.854532378060476, 45.491002627781455, 47.16924272264753, 48.07422127042498, 46.134701115744456, 47.52191243852888, 44.67359222684588, 42.2978572164263, 39.14350707190377, 38.21284450803484, 38.80910417011806, 37.145552567073274, 37.64592361450195, 38.47836644308907, 38.9853070122855, 38.870564460754395, 40.771067006247385, 39.98267575672695, 38.76398951666695, 38.62312521253313, 38.29502085277012, 41.00572156906128, 40.76925005231585, 41.264653137751985, 48.53656482696533, 52.18700245448521, 53.84388378688267, 56.056079047066824, 55.03521844318935, 59.882868903023855, 37.65322617122105, 0.37832479923963547, 0.21418877957122667, 0.7032836877873966, 0.7226510314004762, 6.718809025628226, 62.10008771078927, 52.609042985098704, 54.965590545109336, 49.18971981321062, 64.48851013183594, 53.248478753226145, 40.016499587467735, 26.695685965674265, 28.140272038323538, 55.16324595042637, 22.52991608210972, 0.5226363326822008, 0.06475463922002486, 0.046209846290626695, 0.013535234195712422, 0.06737765204161406, 0.020974908423210894, 0.020444283860602548, 0.18421862061534608, 0.1885661437575306, 0.20294275374284812, 0.16408267324524267, 0.1960763321923358, 0.10006777290254831, 0.1948830605085407, 0.16281575337052345, 0.24332993158272334, 0.25856274419597214, 44.96158116204398, 70.4228275844029, 51.87581695829119, 41.05749259676252, 36.49027143205915, 47.33604465212141, 56.68119805199759, 67.86613368988037, 58.25002486365182, 62.73311723981585, 58.22308669771467, 59.664132663181846, 49.340575626918245, 0.7242188815559659, 2.5962979750973836, 9.50446777684348, 2.803898641041347, 0.18387661182454654, 9.381717426436287, 57.204769134521484, 54.67615638460432, 53.882321221487864, 50.29783589499337, 54.842176641736714, 53.59355756214687, 51.527687890189036, 47.2260650907244, 54.249964305332725, 55.44588129861014, 52.05107137135097, 45.2885286467416, 41.49570505959647, 39.94071211133684, 40.34649038314819, 38.64658580507551, 40.55333478110177, 41.251079831804546, 42.517128467559814, 39.83768074853079, 39.67809452329363, 38.288472175598145, 40.63956192561558, 41.37156506947109, 39.58151108877999, 41.47967209134783, 43.05758714675903, 41.82181181226458, 40.95534712927682, 43.19307701928275, 41.339954239981516, 39.675954478127615, 39.89448227201189, 40.17326831817627, 40.22173547744751, 37.48611157281058, 39.539738518851145, 39.94725036621094, 39.86601550238473, 37.593040875026155, 38.204496247427805, 38.687562806265696, 39.18377535683768, 45.82635048457554, 50.53129536764962, 48.704600061689106, 48.87681811196463, 50.19037505558559, 48.39867435182844, 51.493249143872944, 54.41398695537022, 47.89648635046822, 38.34278971808297, 31.501291138785227, 34.970731667109895, 34.66520547866821, 36.34468930108206, 36.78142874581473, 37.84558357511248, 48.31081090654646, 38.30557516642979, 34.681096008845735, 37.214840003422324, 34.375667095184326, 37.138712065560476, 37.528342723846436, 36.27230296816145, 34.9210763658796, 34.7561400277274, 38.42588322503226, 52.6478590965271, 49.528364590236116, 52.7091178894043, 52.640000683920725, 48.8200443812779, 46.96670273372105, 47.78551319667271, 42.58660697937012, 36.79967124121529, 37.42288991383144, 37.183038098471506, 37.350312505449565, 39.5144088608878, 39.602748257773264, 42.20727355139596, 39.422463348933626, 40.16337408338274, 36.5212847164699, 39.50977093832833, 41.05582502910069, 43.30092348371233, 44.202761445726665, 44.904880387442454, 47.90569618770054, 47.60471759523664, 47.89569772992815, 50.327949387686594, 48.28451197487967, 49.98850556782314, 46.22003889083862, 43.485960960388184, 40.62107971736363, 40.24537672315325, 40.4919821875436, 39.060729707990376, 38.913104806627544, 39.32223905835833, 40.314083984919954, 41.993425369262695, 42.65258012499128, 40.74216944830758, 41.54153537750244, 41.47378349304199, 41.624573298863, 42.188037463596885, 42.85701697213309, 43.16268907274519, 50.99995831080845, 54.83861568995884, 55.125558921269004, 59.69774109976632, 57.350684779030935, 59.68916702270508, 40.29049832480294, 0.7906090276581901, 0.40647417732647484, 4.361581410680499, 1.592273073537009, 8.409966690199715, 68.93393979753766, 56.59874030521938, 61.45617035457066, 57.96875483649117, 68.66570459093366, 64.8297153200422, 44.91785614831107, 36.30059950692313, 37.46696581159319, 62.327217374529155, 31.54641968863351, 0.6277924329042435, 0.09459223278931209, 0.17589447514287063, 0.14081274904310703, 0.1481432614049741, 0.16520533657499722, 0.10938834704990898], [0.050811049927558215, 0.02846357033454946, 0.10594005244118826, 0.02478195128164121, 0.04827500493930919, 0.006748670703798, 0.09929465688765049, 0.06501342569078718, 0.10662482319665806, 0.18267841397651605, 8.066414747919355, 57.472924436841694, 43.32543325424194, 29.306442056383403, 11.939826147896902, 24.960359471184866, 44.39878402437483, 55.20360108784267, 54.442828927721294, 52.229942321777344, 53.47320086615426, 46.41072177886963, 54.409884044102256, 6.879757532051631, 1.0819651250328337, 2.319885173014232, 4.808641970157623, 0.11594186217657157, 0.5673913082906178, 35.44088847296578, 55.87006882258824, 51.628454140254426, 49.97349051066807, 53.31834289005825, 49.86358043125698, 46.364676066807334, 53.888522488730295, 51.16327224458967, 49.05001238414219, 44.82231841768537, 38.616583483559744, 34.44319316319057, 35.650383608681814, 36.717223916734966, 38.878249168395996, 41.53661952699934, 39.8960907799857, 38.85243313653128, 35.49875654493059, 35.01426560538155, 34.68262461253575, 34.09815604346139, 33.663462843213765, 33.3187210219247, 34.54843405314854, 35.76394844055176, 34.784360136304585, 36.39725242342268, 37.27256563731602, 37.26002761295864, 36.4387331690107, 35.17992108208792, 35.80091980525425, 37.42641265051705, 34.943574632917134, 35.69552952902657, 35.3420364516122, 34.47415781021118, 34.14446578707014, 33.07783045087542, 31.70683969770159, 39.21574054445539, 44.02189636230469, 43.59677430561611, 45.77249847139631, 43.89426490238735, 45.01929637363979, 44.69856752668108, 47.67451572418213, 49.37239490236555, 45.88660178865705, 39.24573591777256, 34.59521280016218, 36.64354174477713, 36.880794933864046, 36.50783995219639, 37.35802500588553, 36.850643226078574, 46.00612817491804, 39.98206778935024, 35.31051247460501, 37.43916606903076, 35.162345613752095, 38.14013508387974, 37.603358949933735, 37.077227456229075, 38.34423494338989, 36.72214324133736, 41.285115582602366, 48.506569453648154, 48.405410630362375, 48.48679835455758, 46.88709027426583, 42.72869069235665, 44.43090902056013, 42.83807618277413, 39.368166651044575, 34.013287271772114, 30.69215256827218, 32.5693439074925, 33.73946571350098, 34.741534914289204, 36.59203127452305, 36.77304227011544, 37.84631661006382, 36.817090375082834, 35.46666281563895, 34.532512256077354, 36.651931694575715, 36.91060617991856, 37.84106724602835, 42.2489766393389, 39.71513189588274, 42.09696395056588, 41.12031126022339, 42.24587426866804, 42.08947031838553, 40.67927088056292, 40.58253805977957, 36.7610079901559, 35.43467330932617, 36.476791926792686, 36.58043820517403, 37.16494846343994, 36.43296616418021, 36.08885662896292, 40.3037485395159, 40.058511870247976, 38.48154524394444, 38.400550092969624, 36.22495446886335, 37.45164155960083, 37.37089654377529, 38.075593267168315, 37.570969922201975, 40.39175789696829, 42.34798846926008, 52.18515075956072, 49.94460684912545, 56.57838903154646, 50.76962552751814, 55.837224687848774, 16.827395745686122, 0.03973745681079371, 0.03818052089107888, 1.2171864062547684, 1.1450558538947786, 12.68367510182517, 60.255195072719026, 44.44146680831909, 54.703626087733674, 52.13672528948103, 54.3266133580889, 48.1018716267177, 32.55533633913313, 53.90597983769008, 48.04187740598406, 41.15750844138009, 11.155827896935598, 0.6118553823658398, 0.0643777876560177, 0.11393368350608007, 0.05283456348947116, 0.059177305283291, 0.03460907556914857, 0.06334693689963647, 0.11196132469922304, 0.07233416036303554, 0.21652597987226077, 0.08195507446570055, 0.05449156975373626, 0.03271134543631758, 0.11791586982352392, 0.08935185934283904, 0.1453617699444294, 0.19971857246543678, 14.653790780476161, 65.97381264822823, 48.47394071306501, 28.097542354038783, 24.233864511762345, 36.72186531339373, 46.12195117133004, 62.78137247903006, 58.08280256816319, 59.11166054861886, 56.80018942696707, 50.885764666966026, 60.31277479444231, 7.080667734146118, 0.9945570038897651, 2.706432785306658, 4.829394502299173, 0.0973657446780375, 0.3418061802429812, 40.52127231870379, 55.25787694113595, 54.61221906117031, 50.703499521527974, 55.0223434312003, 51.07475914273943, 49.39108555657523, 55.09360763004848, 53.27767160960606, 50.38367394038609, 46.87547288622175, 40.41931445258004, 36.68079798562186, 38.03097193581717, 38.63807773590088, 40.31394502094814, 42.648501532418386, 40.72003596169608, 41.2844694001334, 38.27548599243164, 37.33640916006905, 36.44969047818865, 36.7982086454119, 35.9283949307033, 35.649782589503694, 36.28274263654436, 37.948809487479075, 38.30428280149187, 38.57843787329537, 37.57514578955514, 38.15443795067923, 38.21205588749477, 37.88092558724539, 37.675759179251536, 37.963765484946116, 36.80440296445574, 38.93531819752285, 36.83172675541469, 35.884197439466206, 34.7013395854405, 33.97742414474487, 33.33340951374599, 41.084941455296104, 47.35455812726702, 46.792330741882324, 46.15206813812256, 46.15472929818289, 47.58197266714913, 46.33833197184971, 49.20443957192557, 49.46566752025059, 49.394007274082725, 39.80448572976248, 34.0528016771589, 35.80533538545881, 36.5308141708374, 35.952102184295654, 38.23424843379429, 37.391748087746755, 45.73252548490252, 40.366299697331016, 33.80699872970581, 36.58433614458357, 35.22648096084595, 36.431885719299316, 35.263504437037874, 36.67341205051967, 37.26772274289812, 36.42097009931292, 39.35366228648594, 49.28525754383632, 50.09518820898873, 50.6527533531189, 47.66497932161604, 45.387467520577566, 45.38472645623343, 43.87298257010323, 40.384573459625244, 35.10174689974104, 32.79698426382882, 34.862232072012766, 36.04101480756487, 36.31001431601388, 37.91095570155552, 38.46915660585676, 39.292052609579905, 38.47008766446795, 37.77955484390259, 35.81007405689785, 37.19555875233242, 38.697429248264854, 39.8756491797311, 43.07777166366577, 41.676049028124126, 43.30258757727486, 42.89143139975411, 42.11856937408447, 44.34896544047764, 41.628644943237305, 40.91763925552368, 37.84593445914132, 37.54702295575823, 39.35432236535208, 38.45241492135184, 39.749125957489014, 37.02818707057408, 38.96339239392962, 41.824212414877756, 41.53662647519793, 39.25442811420986, 41.106956822531565, 38.7879364831107, 37.920273235866, 38.663601943424766, 40.47346523829869, 39.31574944087437, 41.36389078412737, 43.4485171181815, 54.55401052747454, 52.50110966818673, 59.56724003383091, 51.14283064433506, 56.330213274274556, 18.543093579156057, 0.09628350846469402, 1.226052959050451, 2.0318276243550435, 0.584099066044603, 14.116831387792315, 66.47275584084647, 47.70362172807966, 62.02942453111921, 56.11886644363403, 62.69905022212437, 52.6999705859593, 43.15151636941092, 52.87453712735857, 46.88859108516148, 50.510242325919016, 16.87139000211443, 0.7509820940239089, 0.04730086613978658, 0.16894053614565305, 0.03185905456276877, 0.15494058094918728, 0.04833058374268668, 0.07240111141332559, 0.1418396167989288, 0.1259822262717145, 0.2707970291376114, 0.22615987434983253, 0.21224287684474671, 0.11560845720980849, 0.22796838730573654, 0.2146921982722623, 0.35364246368408203, 0.39291115796991755, 17.352485009602137, 79.93134702954973, 54.23085675920759, 39.24393286023821, 21.11162199292864, 39.411787441798616, 55.964067527226035, 65.87563460213798, 64.9830551147461, 63.2086797441755, 62.81404290880476, 55.61862046377999, 66.12567247663225, 8.29036387375423, 2.086992847067969, 8.808981759207589, 8.60029695715223, 0.1966179795563221, 1.3682046341044563, 42.1004832131522, 57.02825709751674, 57.580955028533936, 53.19677373341152, 57.73026139395577, 52.097558294023784, 49.81539814812796, 55.9693238394601, 55.829213414873394, 52.293441908700125, 48.73792362213135, 43.499176434108186, 38.02398204803467, 40.52654947553362, 41.77432434899466, 41.74719510759626, 46.10920817511422, 43.80315317426409, 43.480009828295024, 42.49459545952933, 40.91413388933454, 38.55000931876046, 38.86227525983538, 38.620342458997456, 37.8898366519383, 39.615241118839805, 40.970046043395996, 40.650689465659006, 41.64208623341152, 41.59452928815569, 41.67151880264282, 40.59811592102051, 39.125042234148296, 40.016002791268484, 41.5912184715271, 39.04074668884277, 41.009720257350374, 39.45491491045271, 38.10779121943882, 37.20561279569353, 36.6209705216544, 35.52808836528233, 42.666723183223176, 49.485469886234824, 48.65907893862043, 49.533645221165244, 47.946732248578755, 50.72099161148071, 48.138704027448384, 52.57029982975551, 53.44075972693307, 50.55000686645508, 39.29406411307198, 34.50241960797991, 36.27258784430367, 36.46649817058018, 36.84015492030552, 38.99297087533133, 36.26438896996634, 48.33088077817644, 41.15158857618059, 33.677473885672434, 36.490889821733745, 34.84046336582729, 38.291293144226074, 36.67919642584664, 36.74272380556379, 36.69072001320975, 36.60645573479788, 42.54514013017927, 52.45005777903965, 53.89533519744873, 53.7639273915972, 51.27854980741228, 49.014864921569824, 49.02880648204258, 47.566009180886404, 44.23001575469971, 37.02892357962472, 34.76548188073294, 36.178495338984895, 38.047734464917866, 37.75178984233311, 41.28131144387381, 41.41416447503226, 42.079329422542024, 40.934561593191965, 41.1503517968314, 39.345981052943635, 39.2652325630188, 40.23881414958409, 42.63025556291853, 46.42699098587036, 43.87943744659424, 44.99610676084246, 44.44505555289132, 44.89616387231009, 45.775597367967876, 43.26622765404837, 43.06482022149222, 40.54901647567749, 39.48740816116333, 41.052118165152415, 40.56515714100429, 41.7927440234593, 39.576789787837434, 42.12811272484915, 43.94755758558001, 43.687159946986604, 41.51693180629185, 44.03119305201939, 40.68629550933838, 42.19118847165789, 40.1183671270098, 43.255805356161936, 40.64415468488421, 43.7686310495649, 45.856220790318076, 58.34094551631382, 53.977257932935444, 60.639972414289204, 51.53707838058472, 59.079768317086355, 21.99128304209028, 0.130653654890401, 1.0319124736956187, 7.972930209977286, 1.9904068069798606, 17.101352793829783, 72.85155650547573, 53.4843874658857, 65.27865927559989, 62.52759647369385, 65.81068284170968, 60.61077608380999, 45.66188662392752, 59.981748717171804, 55.805186544145855, 58.332329750061035, 23.71335584776742, 0.8927071605409894, 0.1771519226687295, 0.20140410773456097, 0.10720212079052414, 0.2963678927293846, 0.10248599707015923, 0.1449923211974757], [0.04099877877160907, 0.05475846811064652, 0.036154086235910654, 0.05188380361401609, 0.020528863250677074, 0.05928933820022004, 0.04001209046691656, 0.060148234612175396, 0.011151699282761132, 0.06654312860752855, 1.5768872648477554, 49.18477964401245, 45.18051889964512, 38.84756244931902, 20.6947318145207, 30.140149457114084, 42.25232914515904, 48.5828572000776, 54.472139903477256, 52.2749353817531, 51.262586321149556, 45.983647278376985, 52.086812904902864, 21.925273418426514, 0.5861214803797858, 1.9816373118332453, 4.524207038538797, 0.4587051974875586, 0.20888011157512665, 7.639246446745736, 57.2129784311567, 53.282111508505686, 52.56657559531075, 52.93020609446934, 47.08000005994524, 54.15260962077549, 52.9260128566197, 49.8086827141898, 48.63123403276716, 40.48361308234078, 36.41711037499564, 36.04934222357613, 36.66984067644392, 42.89580529076712, 47.53483608790806, 47.241594314575195, 47.37875870295933, 42.474775723048616, 37.56476518086025, 36.239670753479004, 34.77939564841134, 33.99178607123238, 34.43847533634731, 33.43850449153355, 32.316203662327354, 33.01883677073887, 33.68921981539045, 36.734604835510254, 34.88376106534685, 33.96937118257795, 35.20342683792114, 36.38469008037022, 35.95111206599644, 33.99706322806222, 33.920014653887065, 33.97006600243704, 32.71741696766445, 33.08300338472639, 33.120627880096436, 34.28108474186489, 35.025803089141846, 42.15072216306414, 44.85771254130772, 46.689737115587505, 45.0785471371242, 43.710957527160645, 46.766271523066926, 45.014599391392295, 43.48234442302159, 48.64224345343453, 44.330111503601074, 38.893014090401785, 36.047389779772075, 37.555027280535015, 36.90924433299473, 36.6694724219186, 36.54520041601998, 38.33947890145438, 45.26842056001936, 40.26128114972796, 35.678690569741384, 38.67010545730591, 35.74000147410801, 36.308433600834434, 38.218507289886475, 36.74142449242728, 37.28854649407523, 37.394113949366975, 40.8290809903826, 49.48050887244088, 46.86386592047555, 47.760864462171284, 45.71970953260149, 44.94238328933716, 43.33635582242693, 45.625762939453125, 41.59430347170149, 37.75365890775408, 33.35962854112898, 33.156428473336355, 33.913361753736226, 34.038908754076274, 34.875437123434885, 33.95430748803275, 35.78538015910557, 35.86962359292166, 34.28411068235125, 35.30569737298148, 35.953404971531455, 38.73784691946847, 39.21106093270438, 40.49124220439366, 39.55473967960903, 40.26718364443098, 38.93974420002529, 38.59644760404314, 38.22449663707188, 37.90584877559117, 36.12534856796265, 37.05825539997646, 36.14035667691912, 36.13273450306484, 34.68490709577288, 36.22471475601196, 36.12050567354475, 42.2632725579398, 44.203643866947715, 44.06787954057966, 45.664658955165315, 45.46869543620518, 45.076539107731406, 44.06617028372628, 37.71243177141462, 37.138659954071045, 36.26010887963431, 39.189938408987864, 38.592650413513184, 50.42156246730259, 49.151897294180735, 56.54815741947719, 48.12653773171561, 54.42179325648716, 7.698326979364667, 0.1889991440943309, 0.6724808577980314, 0.7742958515882492, 0.2677791496472699, 20.35343108858381, 59.8429445539202, 46.68327529089791, 54.26562901905605, 51.60078641346523, 56.29948139190674, 47.536503655569895, 26.192249025617325, 40.116890634809224, 52.095459938049316, 35.64820882252285, 4.185911408492497, 0.7463861320699964, 0.0359605816192925, 0.11495960131287575, 0.05199661345354148, 0.036117475878979476, 0.0404048570697861, 0.06340238678136043, 0.0764521418937615, 0.034442997337984185, 0.03554236316787345, 0.09850732556411199, 0.007999293439622437, 0.04596880351060203, 0.07533564644732646, 0.0350535635038146, 0.05793384914951665, 0.03323769862098353, 3.153196309294019, 58.99671649932861, 52.42091008595058, 36.276999950408936, 17.045294727597916, 36.59194789613996, 51.353215149470735, 56.172343254089355, 60.62513106209891, 56.4278632572719, 57.87967893055507, 51.30270869391305, 57.429404394967214, 23.188796383993967, 0.5111716964415142, 2.1623022002833228, 7.59791248185294, 1.9336689029421126, 0.23959798898015702, 10.337851217814855, 59.21364620753697, 54.3326096534729, 55.25456265040806, 55.554141180855886, 50.529662540980745, 54.23970876421247, 53.538267271859304, 52.4610150882176, 50.42881291253226, 43.676390239170615, 38.150171756744385, 38.0331779888698, 38.24212074279785, 42.9070474760873, 50.03554139818464, 49.32658542905535, 49.03340966360909, 44.035115310123985, 39.413055488041465, 36.947011266435894, 37.66893604823521, 35.71888937268938, 35.64896617616926, 37.2483720098223, 34.26934923444475, 35.709940092904226, 36.03786032540457, 38.883067744118826, 37.9257310458592, 36.34862198148455, 37.912915093558176, 38.06408705030169, 36.64439637320382, 35.27653578349522, 37.13001292092459, 35.74090821402413, 35.31159291948591, 35.56657443727766, 35.878128187997, 36.76599679674421, 36.44740104675293, 43.61452695301601, 46.876289299556184, 47.06213276726859, 47.410310472760884, 46.12360136849539, 49.206204414367676, 47.016288552965435, 46.338877405439106, 50.44295597076416, 47.00722810200283, 39.75062676838466, 35.362043789454866, 36.16386243275234, 36.718352999006, 36.06279393604824, 35.66418967928205, 37.83363267353603, 47.42763580594744, 39.269241673605784, 34.97668974740164, 37.48155008043562, 35.288983481270925, 36.27970279966082, 36.893683842250276, 36.34025287628174, 38.041352544512065, 36.63012129919869, 41.21642221723284, 50.61866896493094, 49.60779987062727, 49.441025733947754, 47.37979398454939, 46.95139585222517, 46.73738438742501, 47.641334601810996, 44.89681700297764, 38.21631513323103, 35.28727422441755, 33.79575307028634, 36.03543887819563, 35.33278839928763, 36.930915764399934, 36.194729804992676, 38.83592421667916, 36.86764546803066, 35.833746569497244, 36.46450056348528, 37.753964628492085, 39.2224941934858, 39.74246958323887, 43.05535330091204, 42.31340033667428, 43.20098754337856, 40.83556365966797, 40.69758980614798, 39.857833998543875, 38.48305647713797, 37.202246393476216, 37.53816747665405, 36.92636122022356, 37.91386699676514, 38.236961705344065, 37.74682535443987, 38.60472985676357, 43.43196650913784, 44.94477694375174, 47.226339544568745, 47.664333139147075, 46.808162212371826, 46.86994559424264, 44.93394817624773, 41.08157852717808, 38.928352628435405, 38.40143598828997, 40.78752381461007, 40.61331510543823, 51.32258749008179, 52.01783813749041, 59.1041703905378, 51.16234466007778, 56.02790410178048, 9.818535038403102, 0.2537149643259389, 2.583610781601497, 0.6473780476621219, 0.5081730602043015, 23.544391291482107, 64.59586674826485, 51.84046799795968, 59.8573898587908, 56.056895460401265, 60.1416962487357, 52.051175594329834, 38.76028960091727, 48.45916536876133, 57.1467273575919, 45.611074447631836, 6.635979115962982, 0.8002097010612488, 0.16662511681871756, 0.2072694730013609, 0.013324728036033255, 0.13933329842984676, 0.03690919732408864, 0.12205554411879607, 0.16113031309630188, 0.19066791954849446, 0.13507688896996634, 0.12690236046910286, 0.1311094540038279, 0.17784434051385947, 0.19890770954745157, 0.18236233879412922, 0.1880719938448497, 0.0633318123540708, 3.2240132178579057, 70.13704817635673, 60.04453958783831, 50.175690037863596, 27.88149333000183, 43.37836463110787, 53.58565051215035, 59.49605573926653, 65.30659103393555, 62.1701602935791, 62.55251966203962, 53.855251039777485, 62.03546251569475, 27.39807415008545, 0.6528414487838745, 9.475323557853699, 14.209844316755023, 2.014296233654022, 0.41635812552911894, 12.214628270694188, 60.77872099195208, 57.3987489427839, 57.550254413059776, 56.37586293901716, 52.65844120298113, 54.526874337877544, 56.972174712589805, 53.816810131073, 54.3031770842416, 46.14463356563023, 40.9857246535165, 40.93754237038748, 39.49146243504116, 46.84258358819144, 54.229873589106965, 52.57197434561593, 51.82232625143868, 48.18623317990984, 41.447356019701274, 40.56910024370466, 40.365872383117676, 37.34866925648281, 38.15785993848528, 39.43605055127825, 36.7595488684518, 37.36048466818673, 38.70665993009295, 42.023059436253135, 40.70443378176008, 38.262437275477815, 40.43608045578003, 40.87910107203892, 38.61306422097342, 36.78493063790457, 39.2101229258946, 36.49548258100237, 36.57119710104806, 36.646581581660676, 38.00102519989014, 39.71605600629534, 38.44811398642403, 47.4192145892552, 49.44702550343105, 49.75992373057774, 49.19433341707502, 47.91335310254778, 50.41474281038557, 47.914318902151926, 47.58883401325771, 53.176113264901296, 48.37059668132237, 41.45374836240496, 34.48317657198225, 37.17234482084002, 36.58391925266811, 36.474373953683035, 37.1599075453622, 38.923388140542166, 49.86572047642299, 39.81832306725638, 34.62904010500227, 38.17707518168858, 35.69539056505476, 36.36994252886091, 37.88493817193167, 37.44364070892334, 38.10094724382673, 37.202965532030376, 42.34496947697231, 52.521697180611746, 50.64908817836216, 52.82200179781233, 50.81639037813459, 50.04311840874808, 50.60198286601475, 51.21770095825195, 47.556563104902, 40.96434504645211, 36.964628423963276, 35.32408230645316, 38.05315405981881, 38.3570613179888, 39.343768051692415, 37.33851446424212, 41.20442615236555, 38.96153027670724, 38.3862680707659, 38.441134520939414, 41.08838428769793, 42.21491656984602, 42.21839414324079, 44.472202164786204, 43.887229851314, 45.91791384560721, 42.63036673409598, 43.42412199292864, 42.509412493024556, 41.757297788347515, 39.14599452699934, 40.03075034277779, 38.5911773954119, 39.223724024636404, 37.905907835279194, 39.184261730739046, 38.968947478703086, 46.20062909807478, 48.46807643345424, 48.647899287087576, 49.59612342289516, 50.01070506232125, 48.49494511740548, 47.08561420440674, 43.23357459477016, 40.07925571714129, 41.918871198381694, 43.04974263054984, 41.205148765019004, 54.38587801797049, 53.74070303780692, 62.088046482631135, 51.62622724260603, 55.11854471479143, 12.180807914052691, 0.21857356785663537, 2.9412184953689575, 2.8390233048370908, 0.8890755868383816, 26.767078706196376, 71.54223796299526, 57.38497413907732, 63.70587199074881, 61.299259185791016, 65.22590160369873, 59.319168499537874, 37.40326125281197, 45.85558155604771, 61.99294648851667, 55.41627155031477, 11.278471418789454, 1.035318285226822, 0.3021919216428484, 0.28058690524527, 0.21568570924656733, 0.25847051771623747, 0.2159303618328912, 0.1862681627805744], [0.04031491046771407, 0.046950647075261386, 0.001281655004796838, 0.015057660672547562, 0.08989585443798985, 0.04514620193679418, 0.05109070813549416, 0.0651569494179317, 0.04300279462976115, 0.04453228720064674, 0.09124353355062859, 26.80495159966605, 58.50808443341936, 29.479921204703196, 32.29740878513881, 27.161734649113246, 42.95814105442592, 52.857208320072715, 56.08151292800903, 50.65537977218628, 51.70887606484549, 45.234304904937744, 51.10073150907244, 29.753454412732804, 0.10212946084461041, 2.2236057221889496, 1.9330385710511888, 0.8586382429514612, 0.03734267942075219, 0.5288913398981094, 34.23043237413679, 59.87735203334263, 48.903603417532786, 49.34629052025931, 54.132296562194824, 52.795483997889924, 48.750534602573936, 47.760899203164236, 41.1315256527492, 36.850747449057444, 35.84809807368687, 38.025361265454976, 41.75394875662667, 47.69578068596976, 47.11421993800572, 48.88732726233346, 48.11299221856253, 45.553706645965576, 40.404938629695344, 35.974464961460654, 33.763416154044016, 36.207702091761995, 34.551397459847585, 34.996082169669016, 32.99689088548933, 34.81454658508301, 35.40344115665981, 35.57687514168875, 36.206614698682515, 34.10741104398455, 34.84130409785679, 34.50924621309553, 35.020762171064106, 34.43368802751814, 33.387890338897705, 34.236480781010215, 34.134050437382285, 33.677456515175955, 32.40437977654593, 32.093645913260325, 36.97272654942104, 44.27478647232056, 44.479893820626394, 47.90614087241036, 45.40181902476719, 47.44035448346819, 45.765074321201865, 44.5583633014134, 46.05866003036499, 46.41402217320034, 46.15282549176897, 39.53175503867013, 35.06541476930891, 35.624720437186106, 35.05305044991629, 36.06890140260969, 35.394064562661306, 35.68523924691336, 44.74921989440918, 38.31174169267927, 34.569490568978445, 36.08383308138166, 35.83241598946707, 35.46066304615566, 37.19670173100063, 36.42644527980259, 35.48482193265642, 37.410056591033936, 41.88065610613142, 49.414768491472515, 47.46593427658081, 47.675231388636995, 43.191635268075125, 45.726553508213584, 44.281025954655235, 43.90850176130022, 44.77023472104754, 40.565396853855674, 34.477506841932026, 32.799707957676475, 32.09940596989223, 32.40657193320138, 33.614061151232036, 32.09532390322004, 32.352872780391145, 33.62456682750157, 33.75587388447353, 35.63251979010445, 34.47799321583339, 36.22784839357649, 36.27604109900338, 38.649691649845664, 39.811562470027376, 42.16969074521746, 38.72801521846226, 37.53268534796578, 36.80809940610613, 35.68627105440412, 37.38832262584141, 36.08303056444441, 35.244014739990234, 36.22902263913836, 36.607470171792166, 36.7107447215489, 47.52170746667044, 49.57012326376778, 48.65100513185774, 48.74757466997419, 48.04747070584978, 49.214101042066304, 47.80149405343192, 50.82831696101597, 48.55330998556954, 43.269430773598806, 34.40225437709263, 37.26914712360927, 37.517527852739605, 46.253939151763916, 48.70937694822039, 52.18114512307303, 49.636367389133994, 41.92522185189383, 9.369069967951093, 0.3307903813464301, 2.5874136175428117, 0.5443703521575246, 0.09135361228670393, 35.71696819577898, 51.12579018729073, 47.50824533190046, 53.74846764973232, 49.997555596487864, 54.05609219414847, 38.59192780085972, 26.47411138670785, 21.097331285476685, 41.22799791608538, 42.13815982001168, 1.403261118701526, 0.26830376578228815, 0.018463300873658488, 0.07590094075671264, 0.08143366780132055, 0.06597343060587134, 0.09715471350188766, 0.05341828002461365, 0.017247931000643542, 0.08735869665231023, 0.02628150688750403, 0.023439610543261682, 0.03322243158306394, 0.04825203652892794, 0.02549700335865574, 0.03835122333839536, 0.022044113371521235, 0.09491095425827162, 0.13705036735960416, 35.97889791216169, 64.26060921805245, 32.575743198394775, 30.219261646270752, 41.10180820737566, 45.375256061553955, 55.817939962659565, 60.419950757707866, 54.83400903429304, 57.2196695463998, 50.22729083469936, 56.61589888163975, 34.05646685191563, 0.028776809240558317, 1.5204086154699326, 5.0172551189150125, 3.645748027733394, 0.14377006249768393, 0.7619582393339702, 35.98713847569057, 58.93461350032261, 51.9724941934858, 50.44690602166312, 54.95282670429775, 54.76396771839687, 50.80380719048636, 50.94618272781372, 44.08411748068673, 39.63435908726284, 37.845260483878, 39.64300612040928, 42.7411071232387, 49.262748854500906, 49.50364637374878, 50.62145519256592, 50.1706873348781, 47.068066528865266, 42.52746043886457, 37.101803234645296, 36.24394736971174, 38.370408807482036, 35.8798166002546, 37.87720830099923, 35.556846959250315, 35.84376239776611, 38.076767512730186, 37.67028399876186, 38.67692858832223, 37.64474242074149, 37.65701641355242, 37.58859402792794, 36.30468504769461, 36.106386934007915, 35.887084415980745, 37.31580775124686, 35.40865230560303, 35.55077770778111, 35.08439724785941, 34.48473644256592, 39.17555216380528, 45.966301100594656, 48.06359052658081, 48.63801894869123, 49.447664737701416, 49.697862420763286, 46.85619510923113, 47.90732554027012, 50.17841720581055, 49.261494704655235, 48.579786096300396, 38.814516816820415, 33.760035855429514, 35.00951303754534, 34.19939129693167, 34.497389112200054, 35.85285758972168, 36.26623371669224, 45.7066330228533, 39.28049080712454, 33.80890948431832, 37.0192551612854, 35.62233720506941, 35.95412063598633, 36.676688126155305, 36.58794225965227, 36.59876407895769, 36.95313262939453, 42.76359496797834, 49.417898654937744, 48.40985400336129, 49.700092792510986, 46.02500295639038, 49.40469012941633, 45.584164074489046, 46.87527486256191, 48.0725919178554, 43.43043443134853, 37.183791978018625, 36.156052657536094, 33.55605411529541, 34.797245570591514, 35.680910519191194, 35.570309094020296, 34.80092116764614, 36.27298041752407, 36.90554789134434, 37.690482412065776, 37.2366156578064, 38.548161097935264, 38.453894887651714, 41.369529247283936, 41.82535539354597, 41.92237309047154, 40.9027145249503, 38.031062262398855, 37.439631598336355, 37.459517342703684, 38.506520543779644, 37.67886502402169, 36.255199977329795, 38.418737002781455, 36.8188830103193, 38.445734228406636, 47.49888958249773, 50.700327668871196, 50.19486359187535, 49.99690246582031, 50.90708521434239, 50.61499336787632, 50.68031338282994, 52.492122173309326, 49.53899533408028, 44.53480543409075, 38.21824325834002, 40.03410632269723, 39.63396998814174, 49.9862300327846, 51.70055559703282, 55.03911638259888, 51.8182372365679, 42.121734278542654, 12.264195850917272, 0.4603547975420952, 4.231597985540118, 0.909456878900528, 0.07216999560062375, 39.11756944656372, 55.86476387296404, 53.696126869746614, 57.936928612845286, 55.5919463293893, 58.44671794346401, 47.11837496076311, 31.17013304574149, 19.620531627110072, 47.26505838121687, 48.09892906461443, 3.029717049428395, 0.4717463148491723, 0.01852669470411326, 0.07995789484786135, 0.07686984805124146, 0.08641511907002755, 0.13175159240407602, 0.035010829368340116, 0.1403526615883623, 0.19599934560911997, 0.1361112884644951, 0.16401620395481586, 0.16089553997984954, 0.09295328573456832, 0.059113448352686, 0.145880469254085, 0.12167844149683203, 0.2378974716578211, 0.18172048537858895, 43.207199232918875, 75.12011555262974, 41.09550619125366, 42.4984586579459, 40.50117465427944, 55.0118134362357, 61.38725117274693, 68.2464155469622, 59.558700697762625, 63.58416734422956, 54.715771538870676, 61.24574416024344, 36.84794385092599, 0.28682503050991465, 5.258269889014108, 9.81358357838222, 4.7319603477205545, 0.13587883593780653, 1.4364560289042336, 38.597291810171946, 61.931371552603586, 53.37648541586739, 53.06403534752982, 56.16474192483084, 55.131940841674805, 52.95447615214756, 53.33990315028599, 46.191596439906526, 40.613471439906526, 38.56692123413086, 41.714833872658865, 45.36278404508318, 52.06212942940848, 51.40729297910418, 50.58692264556885, 53.21605151040213, 48.43973125730242, 44.48458385467529, 39.75851992198399, 38.46892384120396, 41.66963931492397, 40.18479537963867, 41.38121264321463, 38.39304256439209, 39.793570109776084, 42.02048165457589, 39.717605454581125, 41.3325856753758, 39.2782222202846, 38.52773339407784, 38.5673485483442, 39.57046692711966, 37.315112931387766, 37.42862565176827, 39.46317284447806, 38.565288407461985, 38.35771444865635, 36.88657236099243, 36.10428510393415, 41.369244371141704, 48.286464418683735, 49.12037679127285, 51.89851672308785, 49.94030591419765, 50.84246349334717, 48.86305373055594, 49.48825263977051, 50.805544240134104, 51.34967851638794, 52.69731289999825, 38.8096148627145, 33.99644136428833, 34.72012751443045, 34.05953795569283, 35.4557089805603, 35.3725459916251, 34.175416537693565, 46.96115459714617, 39.49351215362549, 34.24606234686715, 36.84403896331787, 35.31724180494036, 36.32340349469866, 36.22307498114449, 35.9305419240679, 34.90552977153233, 37.5471202305385, 44.06860910143171, 52.640813623155864, 51.71266630717686, 51.96059192929949, 47.15686798095703, 52.173707076481406, 47.92711053575788, 50.15032911300659, 52.29172222954886, 45.31974342891148, 40.03112554550171, 37.92407737459455, 36.51622642789568, 37.97024468013218, 37.805687018803184, 36.23825332096645, 36.95308746610369, 38.35394852502005, 38.04307917186192, 40.90206834248134, 38.94216912133353, 39.831277983529226, 41.232503822871614, 43.19244473321097, 43.96161379132952, 45.39346381596157, 42.83573463984898, 41.045489583696636, 40.0596479007176, 39.00207648958479, 41.233414036887034, 38.91325419289725, 38.91381352288382, 39.87978335789272, 39.583539962768555, 39.98230402810233, 51.904137815747944, 54.11030898775373, 52.59452819824219, 51.5012777873448, 52.558817931583945, 52.60952935900007, 53.35900722231184, 55.5583552633013, 51.089749881199424, 47.032179083142964, 39.69792815617153, 42.22920901434762, 42.22411251068115, 51.32030153274536, 54.18808364868164, 56.78840528215681, 54.18615552357265, 44.48458732877459, 16.351419823510305, 0.5647071323224476, 7.869455899511065, 2.8548589008195058, 0.15316891244479588, 46.71962479182652, 59.54417201450893, 60.068246841430664, 61.710953848702566, 58.483543395996094, 63.756913457598, 50.927287101745605, 36.92002098900931, 29.46434334346226, 54.37647015707833, 59.94452026912144, 5.245436131954193, 0.5815699217574937, 0.12359648357544627, 0.13248284959367343, 0.1261725960565465, 0.21231071677591118, 0.25906331304992947, 0.20070890789585455], [0.06273626895355326, 0.02830985501142485, 0.035273782044116936, 0.06473441209111895, 0.0698895954660007, 0.021848140583772744, 0.04770805839715259, 0.07209172658622265, 0.0200704958822046, 0.0500012319535017, 0.052824605988072496, 6.491289394242423, 54.45795863015311, 42.20574147360665, 27.61588975361415, 19.651741198131017, 42.951804297310964, 53.14215047018868, 54.30072437013899, 50.661987509046284, 52.66892950875418, 49.820015226091655, 48.70855706078665, 38.40501431056431, 0.8972580677696637, 2.0338395621095384, 3.729827744620187, 3.8378956828798567, 0.3184821089463574, 0.08526283768670899, 14.674760443823677, 54.02296665736607, 44.400625297001426, 59.045124598911826, 52.227284635816304, 49.739812169756206, 45.241103717258994, 41.556501797267366, 38.469194820949006, 40.02639382226126, 42.4919308253697, 43.206306389399934, 45.10588829857962, 48.2117782320295, 49.65275124141148, 49.614647320338655, 46.6530054637364, 47.43803725923811, 42.241257190704346, 36.70599562781197, 35.118606703622, 34.82067837033953, 34.113591466631206, 33.79591635295323, 32.89343220846993, 34.24837957109724, 34.20106928689139, 34.760826587677, 35.03465856824602, 38.89504296439034, 34.53791448048183, 36.769936425345286, 35.72275604520525, 35.719424383980886, 35.21507201875959, 35.96492508479527, 34.67760453905378, 33.09166431427002, 34.07987533296858, 34.96452692576817, 38.47855404445103, 42.48225893293108, 45.45942306518555, 46.61331387928554, 45.78693682806832, 44.932673181806294, 46.57144056047712, 46.783273765019004, 45.38187769481114, 46.93022469111851, 48.859861033303396, 38.43065663746425, 35.11842605045864, 34.93526111330305, 35.440172808510916, 37.24612079347883, 36.18639891488211, 38.74461793899536, 46.73237126214163, 40.84035096849714, 36.07522426332746, 38.69464996882847, 36.46755082266671, 36.58001089096069, 36.55099173954555, 36.844375950949534, 36.289374692099436, 37.50414909635271, 46.08185659136091, 47.106938225882395, 47.35663216454642, 46.47329378128052, 44.33979729243687, 46.458233560834614, 44.04106296811785, 43.58752972739083, 42.56904888153076, 41.27065985543387, 35.29294742856707, 31.903682163783483, 31.447477340698242, 31.314728532518657, 30.470188890184673, 32.871027742113384, 32.14163712092808, 32.60474497931344, 34.060020855494905, 35.80039174216134, 35.031580516270225, 36.56588172912598, 37.47274323872158, 39.92027051108224, 40.50049720491682, 40.073697158268516, 39.923348563058035, 36.47894934245518, 35.834469182150706, 34.06908130645752, 34.54407753263201, 33.99745580128261, 34.37597976412092, 36.51256125313895, 37.711028235299246, 42.80545439038958, 50.42963974816458, 47.878139632088796, 51.37635612487793, 48.910502978733604, 51.452105385916575, 49.48356260572161, 52.28251934051514, 51.454693589891704, 49.73296472004482, 48.28616912024361, 44.98020233426775, 37.790022305079866, 35.70086921964373, 40.848706177302766, 51.46129437855312, 49.58065325873238, 50.62607227052961, 23.267156430653163, 21.893980469022477, 0.19279402760522707, 1.618297117097037, 0.37831937095948626, 1.2188761212996073, 50.7723457472665, 47.445847034454346, 51.472008500780376, 49.5474408694676, 52.76953247615269, 52.10194608143398, 35.79475327900478, 26.908575296401978, 24.77859459604536, 43.28761420931135, 26.988780089787074, 0.3211524428001472, 0.07964652869850397, 0.09333331962781292, 0.09414317152862038, 0.04769757163843938, 0.03221852205959814, 0.06563192393098559, 0.024205993794436966, 0.0499036857592208, 0.01028551540470549, 0.05698221057121243, 0.047932439749794345, 0.03603353091914739, 0.03644837365884866, 0.04914797077487622, 0.06229902098753622, 0.07512162293174438, 0.11300933560622589, 0.13020660887871469, 10.815927233014788, 65.45893723624093, 44.81995603016445, 27.692187922341482, 28.825022220611572, 51.05257701873779, 56.027608803340364, 60.30474962506975, 54.691004684993196, 58.21586057118007, 53.54636539731707, 53.09129313060215, 42.34734228679112, 0.8247027524880001, 1.896794161626271, 4.163377097674778, 5.684737290654864, 1.3258525409868784, 0.07348268266235079, 19.486209051949636, 54.87671266283308, 46.00811883381435, 58.593880789620535, 52.97643593379429, 50.30785519736153, 48.58126258850098, 43.95876155580793, 40.02514662061419, 41.297042165483745, 43.517519678388325, 44.93942335673741, 49.36549186706543, 50.42046117782593, 52.6855912889753, 50.08676699229649, 49.25448744637625, 50.32808140345982, 43.8648601259504, 39.380881854466026, 37.138653005872456, 37.873623030526296, 34.67855644226074, 36.59938594273159, 34.032759598323274, 37.018150397709434, 38.06389944893973, 37.06799677440098, 36.62022706440517, 39.10901968819754, 38.34659038271223, 39.6056421824864, 37.597216742379324, 37.094486781529014, 37.23095287595476, 36.90931728907994, 37.78057622909546, 35.94254841123308, 37.31530400684902, 35.52214765548706, 39.06231042316982, 47.05368028368269, 47.489818709237234, 48.30671494347708, 48.17137098312378, 46.53468458993094, 48.77433565684727, 48.0974942616054, 47.12175873347691, 47.572012424468994, 49.5588880266462, 41.07765974317278, 34.97357695443289, 35.122428212847026, 36.479091780526296, 36.23516137259347, 35.756715365818565, 36.70580802645002, 48.69389636175973, 41.26906871795654, 34.722753933497835, 36.83334568568638, 36.0204689843314, 37.09554985591343, 36.82746056147984, 36.10852003097534, 35.96492855889456, 37.27047075544085, 45.747033323560444, 48.513225827898296, 47.57646969386509, 49.194927488054546, 47.22893469674246, 49.195149830409456, 46.4126638003758, 45.5692914554051, 45.381703989846365, 43.589464800698416, 37.989463397434776, 33.96905503954206, 35.07891511917114, 32.6669556753976, 31.848179953438894, 34.081021785736084, 33.72329725537981, 34.15595463344029, 35.16515268598284, 37.64511414936611, 36.99614545277187, 38.6207662991115, 40.340521880558555, 40.89295925412859, 43.12598521368844, 41.64416027069092, 41.56442969185965, 37.883475576128276, 36.47823715209961, 36.026645932878765, 36.66129091807774, 37.68249198368618, 37.51712138312203, 37.46669135774885, 39.28554214750017, 45.28456817354475, 52.29132618222918, 51.20523588997977, 51.97926868711199, 51.055304186684744, 52.548843792506624, 50.95033080237252, 53.992571762629915, 54.066233089991975, 51.343824659075054, 51.44611603873116, 45.9617326600211, 39.41734947477068, 38.88666691098894, 43.58066143308367, 54.02857732772827, 51.54965809413365, 53.58935737609863, 25.612585135868617, 25.04079702922276, 0.23702072298952512, 2.6139663755893707, 0.7595365749938148, 1.047555040035929, 54.829117502485005, 51.09889371054513, 57.956189019339426, 54.11528042384556, 59.160263197762625, 55.312034675053184, 43.265379973820274, 32.0203389440264, 23.246895483561925, 49.163525104522705, 34.35927629470825, 0.13515414696718964, 0.037014292220452, 0.022473395336419344, 0.04611008128683482, 0.02289649923997266, 0.059445536961512904, 0.03551812928968242, 0.10031395897801433, 0.1743253357708454, 0.10767997907740728, 0.11089018253343445, 0.16739646185721668, 0.11048753985336848, 0.16948416483189377, 0.14664772951177188, 0.2255976538040808, 0.16039134774889263, 0.15842867163675173, 0.22714621999434062, 14.23253800187792, 77.27515493120465, 52.06320640019008, 35.80991424833025, 27.61403111049107, 57.308665548052105, 61.360278265816824, 64.54155267987932, 61.30800001961844, 63.211834226335796, 59.76581954956055, 57.050758838653564, 49.20961945397513, 1.6916535922459193, 5.315814001219613, 10.666714668273926, 7.820531896182469, 1.0806483328342438, 0.1501006313732692, 22.49071955680847, 56.46170098440987, 48.53457416806902, 59.177585056849885, 55.651784215654644, 52.04047189440046, 51.21199996130807, 44.96841124125889, 42.71734775815691, 43.3025597844805, 47.34417404447283, 47.57876259940011, 50.46856703077044, 52.15199048178536, 55.39036866596767, 49.90040588378906, 49.28159236907959, 53.32239021573748, 46.156643526894705, 41.08845029558454, 39.41104051045009, 39.83893142427717, 38.738395827157156, 38.93309129987444, 36.78939138139997, 39.805670397622244, 40.17287574495588, 41.21531397955758, 38.791150024959016, 42.57837336403983, 39.754007066999165, 42.048760822841096, 40.48043080738613, 38.03959117616926, 39.58284166881016, 40.615055629185264, 40.594211033412385, 36.985980238233296, 39.51244946888515, 39.7466002873012, 41.99779578617641, 48.059504985809326, 51.163223607199534, 50.001905168805806, 50.42558894838606, 49.59867341177804, 50.83503934315273, 50.57348830359322, 49.41359077181135, 48.518815653664724, 53.12358488355364, 41.611528056008474, 34.792472158159526, 34.73263774599348, 35.395023414066856, 35.62733990805489, 35.14246334348406, 38.30415078571865, 52.68083872113909, 42.05549362727574, 34.20947313308716, 38.4605165209089, 35.17443200520107, 36.59002324513027, 36.03536592211042, 36.67144571031843, 36.07668685913086, 37.274292264665874, 46.61337641307286, 50.46264716557094, 51.321899618421284, 50.53178521565029, 49.4094739641462, 53.10583223615374, 48.54602132524763, 46.951538290296284, 48.609104020254954, 45.889242104121614, 40.252637590680806, 37.84015008381435, 36.14074230194092, 34.903837885175435, 32.84711899076189, 36.75996923446655, 36.68462296894619, 35.20388889312744, 36.48175294058663, 38.28856945037842, 39.310041495731895, 41.46469872338431, 43.65637247903006, 43.928192956107004, 44.88270173754011, 44.44815444946289, 43.6920862197876, 38.99006305422102, 39.54856620516096, 35.78674895422799, 38.591066224234446, 37.68779345921108, 38.516109057835166, 40.97689001900809, 42.741694246019634, 47.505872522081646, 54.67562484741211, 51.739673955099924, 54.33501720428467, 52.5319561958313, 54.555980341775076, 52.69131313051496, 55.681918552943635, 55.489981515066965, 51.70760801860264, 53.19580793380737, 49.53185953412737, 42.632652691432405, 41.165773323604036, 45.341967242104666, 57.92243119648525, 53.451977593558176, 56.55963584354946, 28.984632764543804, 31.733215059552872, 0.48510096967220306, 7.408475926944187, 2.6234450212546756, 1.2345727533102036, 61.89664445604597, 55.660875933510916, 63.60585267203194, 59.826977593558176, 64.96086951664516, 60.71224062783377, 46.720729555402485, 37.71353653499058, 34.150969300951274, 57.0708703994751, 44.39010572433472, 0.6674391254782677, 0.4409671521612576, 0.18230132492525236, 0.20051496901682445, 0.16773203813603946, 0.11516876651772431, 0.19385223010821, 0.15383925076041902], [0.02795918981012489, 0.02312971342221967, 0.024110647749954035, 0.07960952139858689, 0.006912111130077392, 0.03447789439399328, 0.03163320078913655, 0.017103698204404542, 0.05723953140633447, 0.032165236704583676, 0.04470005837668266, 1.4296985800777162, 47.41443770272391, 45.2737671988351, 31.51520143236433, 36.93035296031407, 35.957066672188894, 52.83804171425955, 53.94673102242606, 53.81007385253906, 50.63372918537685, 50.7664224079677, 47.83682564326695, 49.05772141047886, 7.514316099030631, 2.2112155641828264, 1.512616753578186, 4.059598369257791, 3.4431930567537035, 0.058370398224464486, 8.464237332344055, 50.51184388569423, 53.41846990585327, 51.4038154057094, 49.235626561301096, 49.68600531986782, 45.47737373624529, 43.08102689470564, 43.708049706050325, 46.95770829064505, 45.84034068243844, 48.6408086504255, 46.822197573525564, 49.55346843174526, 49.12382657187325, 46.37006092071533, 49.62335341317313, 49.47371006011963, 43.20932190758841, 36.45405742100307, 34.82728958129883, 34.77869735445295, 33.84084687914167, 31.850170612335205, 34.16688414982387, 34.51149048124041, 34.188048362731934, 35.168974195207866, 34.260038648332866, 34.7024895123073, 35.80300079073225, 36.937287262507844, 36.090729168483186, 35.990296431950156, 34.220086506434846, 35.47252362115042, 34.09918785095215, 34.28174134663173, 34.660842009953086, 35.52870675495693, 38.974221161433626, 41.213684626988, 45.363989557538716, 45.60729462759835, 44.76091718673706, 45.66378695624215, 45.645332540784565, 45.793999671936035, 46.45919936043875, 47.24713550295149, 45.9349820954459, 38.87566096442086, 35.99514627456665, 37.16372210638863, 34.82396139417376, 38.420991693224224, 39.335228715624126, 38.80172865731375, 44.22347749982561, 40.75989777701241, 35.17787136350359, 36.50123916353498, 37.222027914864675, 37.311020442417686, 36.50505025046212, 36.87150866644723, 33.95226124354771, 37.730903557368684, 45.903544970921104, 48.458189146859304, 48.930357456207275, 47.555986404418945, 44.326957021440776, 44.838191577366416, 48.18375962121146, 43.87366696766445, 45.67010634286063, 43.36570153917585, 41.91797488076346, 34.73980481284005, 32.75397491455078, 31.781904561179026, 31.816784518105642, 33.45528786523001, 31.584290845053538, 34.29746164594378, 34.04805258342198, 33.90704584121704, 34.12555626460484, 35.12323072978428, 35.92715120315552, 37.143117223467144, 38.54303332737514, 40.28480427605765, 39.572957856314524, 36.79280642100743, 35.41058043071202, 33.404388836451936, 34.82271071842739, 35.268173626491, 35.06867694854736, 34.934201513017925, 35.87627649307251, 42.214503152029856, 50.3233323097229, 50.580061299460276, 50.729114055633545, 51.615377630506245, 49.405284200395855, 50.6589789390564, 48.578163691929404, 47.423609324863975, 53.59871312550136, 49.33121987751552, 49.83761501312256, 40.55974449430193, 36.84771456037249, 36.81978975023542, 47.9819769859314, 50.7770288331168, 55.666740213121685, 45.610146863119944, 11.562341809272766, 0.06977786110447985, 1.859674062047686, 0.07189191837928124, 2.5843757348401204, 51.2223527772086, 45.60720082691738, 51.61242812020438, 51.80164493833269, 55.16055004937308, 46.08165856770107, 33.27006278719221, 20.904906136648997, 21.652910981859478, 46.8081830569676, 20.961857046399796, 0.19762879317360266, 0.03958988222958786, 0.053005506816719256, 0.05145295762589999, 0.043646028864064386, 0.026317986626444117, 0.05843417373086725, 0.03808505779930523, 0.04172037701521601, 0.0848807410470077, 0.007743890314096851, 0.015286822304395693, 0.060379330068826675, 0.05221879296004772, 0.06103695942355054, 0.054580108395644596, 0.06928640497582299, 0.04442803029503141, 0.005722756713761815, 2.1141058036259244, 55.87062120437622, 50.82144866670881, 26.322965485709055, 34.87827198845999, 44.579590048108784, 55.57420410428728, 60.51995618002755, 58.669254847935264, 55.951418331691194, 56.185325963156565, 53.301139150347026, 53.759654249463765, 7.691596780504499, 1.4141999717269624, 1.659285191978727, 5.549752899578639, 2.0507938180650984, 0.07578843286527054, 10.068076985222952, 51.56710502079555, 54.83401945659092, 53.00322471346174, 50.958053725106375, 51.45029885428292, 47.5094438961574, 44.778464862278526, 44.77519573484148, 47.96869203022548, 49.4324551309858, 48.99806765147618, 49.49001400811331, 51.44618899481637, 51.56559031350272, 46.69962092808315, 51.918774196079795, 51.88539852414812, 45.112520354134695, 38.95253235953194, 36.30504982812064, 37.054538113730295, 35.16068499428885, 35.06588724681309, 35.42180871963501, 37.044907910483225, 37.14097023010254, 36.15988111495972, 37.67564453397478, 38.464289392743794, 36.92858811787197, 37.020735127585276, 37.683534213474815, 36.978125299726216, 36.24072687966483, 35.641184193747385, 36.12289932795933, 35.23816435677664, 35.68415185383388, 36.45439093453543, 42.49309464863369, 44.27720097133091, 47.74141992841448, 47.18085663659232, 48.485433033534456, 47.47704097202846, 47.70100225721087, 47.096338748931885, 48.4259147644043, 48.629993779318674, 47.27711350577218, 39.78829295294625, 35.63344390051705, 35.74280159814017, 34.721958364759175, 36.990711961473735, 37.48593091964722, 38.81264427730015, 47.21498966217041, 40.952783243996755, 33.61013541902815, 36.41179847717285, 35.959741728646414, 36.55497653143746, 36.08345440455845, 36.99148668561663, 33.931566034044536, 37.38868393216814, 46.018985816410606, 49.69961336680821, 50.89718055725098, 47.196882656642366, 47.22320590700422, 46.82579674039568, 48.19154507773263, 46.127752917153494, 45.80607564108712, 47.71958521434239, 43.21990748814174, 37.071505614689414, 35.503088746752056, 34.13044432231358, 34.94020823069981, 34.28231457301548, 34.592079162597656, 35.99638305391584, 36.0130170413426, 36.759489808763774, 34.75068916593279, 37.13537345613752, 38.46370921816145, 40.92511204310826, 41.66417455673218, 41.8247196333749, 41.294613770076204, 39.91727236339024, 37.763233525412424, 36.11183084760393, 37.567770276750835, 36.55803721291678, 35.54293319157192, 36.48918056488037, 36.83036143439156, 45.127431188310894, 50.76886469977242, 52.14280496324812, 51.761216844831196, 54.01846769877842, 52.106896672930034, 51.89254822049822, 50.084970882960725, 49.500384194510325, 54.678286007472444, 51.186976024082725, 51.63933849334717, 42.12649379457746, 39.78367587498256, 39.28456939969744, 50.20111002240862, 54.57443128313337, 58.77278995513916, 49.82273891993931, 13.44404947757721, 0.1447344778903893, 1.8193627851349967, 0.647974778498922, 4.273563367979867, 57.88093655450003, 50.21160875047956, 58.66386999402727, 54.62073755264282, 62.0161326272147, 50.41561828340803, 44.198988573891775, 23.6534606388637, 22.485407658985682, 56.425254208701, 25.806088992527553, 0.1692100502550602, 0.027569692049707686, 0.05669698498344847, 0.027474573314456, 0.018967420162100877, 0.03220902596201215, 0.06302662765873329, 0.015335552993097475, 0.11197763668107134, 0.18109000420996121, 0.16926602939409868, 0.13713899760374001, 0.11210627334990672, 0.13146393426827022, 0.1199479600680726, 0.11666850532804217, 0.12599226858999046, 0.12325828815145151, 0.12972355979893888, 2.4610469469002316, 66.291720526559, 56.375539847782676, 42.71834135055542, 49.62121336800711, 49.24967929295131, 62.38378960745675, 65.24524538857597, 62.72321605682373, 62.55650097983224, 61.605785914829795, 56.84563411985125, 60.641146659851074, 10.145630172320775, 4.1081858192171365, 9.658721259662084, 10.553574545042855, 6.239133187702723, 0.1822681309921401, 12.94008013180324, 55.436824321746826, 51.813154629298616, 53.36500699179513, 52.21387113843645, 53.93024294716971, 50.24153116771153, 47.482015882219585, 46.23019715717861, 50.51492541176932, 51.31958934238979, 52.31751046861921, 52.02622808728899, 54.10474348068237, 50.242173876081196, 46.96229410171509, 53.826478549412315, 55.18156835011074, 49.3294689314706, 41.57257298060826, 38.89937169211251, 40.28091328484671, 38.19221878051758, 37.0647554397583, 38.62595312935965, 40.406321321214946, 39.30749498094831, 38.45298119953701, 39.15568378993443, 38.82049921580723, 39.36491142000471, 39.31587103434971, 40.24335479736328, 40.28615917478289, 37.81343426023211, 38.05252872194563, 38.65648698806763, 37.87219517571585, 37.897649901253835, 38.60630014964512, 45.25635501316616, 46.363546984536306, 49.90566219602312, 49.29538106918335, 50.44372027260916, 49.449377468654085, 52.031856128147666, 49.88617597307478, 50.966492312295095, 50.395333017621724, 49.29909488133022, 41.93564067568098, 36.48974336896624, 36.193538188934326, 34.69389459065029, 38.53849267959595, 39.101640701293945, 38.82089178902762, 48.636726583753315, 43.309716429029194, 34.40255314963204, 37.165261132376536, 35.10568305424282, 36.84988587243216, 36.06989846910749, 36.271879128047395, 33.74657719475882, 38.13331890106201, 46.81785147530692, 52.098906244550435, 53.50575317655291, 49.54425859451294, 50.21776485443115, 49.21198878969465, 53.28306688581194, 48.15165894372122, 49.17032044274466, 48.93353278296334, 46.781689575740266, 40.36784567151751, 37.659611565726145, 35.91082641056606, 36.26900257383074, 35.658446993146626, 36.86018310274397, 38.91972991398403, 38.22658804484776, 38.00256422587803, 37.04280260631016, 40.69968121392386, 40.24592215674264, 42.524142674037385, 43.42233630589077, 44.53151546205793, 42.68881845474243, 41.24858890260969, 39.2277261870248, 37.483151640210835, 38.73007883344378, 38.32140663691929, 38.42049837112427, 38.082402501787456, 40.29449006489345, 44.898098945617676, 53.474135398864746, 54.29615592956543, 54.80796371187483, 54.55658483505249, 53.889929498944966, 53.71806928089687, 54.03863831928798, 54.153297492435996, 56.26462227957589, 54.87641389029366, 53.486096722739084, 43.800849846431184, 43.08657503128052, 41.07966429846627, 54.13666350500924, 58.04991674423218, 61.09985283442906, 50.49921900885445, 17.128527198519024, 0.2554924546607903, 8.784445064408438, 2.0694894662925174, 4.312220973627908, 61.96468816484724, 55.23778622491019, 62.63686384473528, 60.816046714782715, 63.93545436859131, 57.028660093035015, 46.53762367793492, 31.20195926938738, 31.56904649734497, 62.99000603812081, 33.936634744916645, 0.21418784319290093, 0.10467871690967254, 0.1778905080365283, 0.12608129238443716, 0.14090968455587113, 0.10052486801786081, 0.14527969434857368, 0.19190995075872966], [0.01723527123353311, 0.11478041378515107, 0.016304463680301393, 0.04195459373295307, 0.018672547502709285, 0.024536606589598314, 0.04304380189361317, 0.010812778674465204, 0.0030051845242269337, 0.009277614398992487, 0.05204437553350415, 0.0863714214148266, 26.379155567714147, 54.48710632324219, 28.388713564191544, 18.251330035073416, 32.428969451359336, 49.99074636186872, 49.111559527260916, 52.58532183510916, 50.06818403516497, 52.34278106689453, 46.13452046258109, 49.44992985044207, 18.231300115585327, 1.0635416507720947, 0.8834711047155517, 4.7500187158584595, 2.0150420793465207, 0.1552383763981717, 10.121597221919469, 61.64237512860979, 48.61770936420986, 53.86585051672799, 51.70013175691877, 50.24788529532296, 49.10381228583199, 50.77330459867205, 48.41583292824881, 49.280386856624055, 46.914535658700125, 48.75676366261074, 47.48574359076363, 52.71497869491577, 40.84290443147932, 43.78218003681728, 49.39305189677647, 46.95949397768293, 42.160991600581575, 35.81827640533447, 34.6447743007115, 32.12131364004952, 35.361682483128135, 35.69291353225708, 34.18478618349348, 35.36577844619751, 33.8817891393389, 34.95210354668753, 35.8621438571385, 36.40046943937029, 37.07550777707781, 37.510496275765554, 37.39047309330532, 37.17190708432879, 36.122020380837576, 33.633460521698, 33.05837549482073, 33.73097154072353, 35.6321758542742, 35.76982314246041, 40.68417978286743, 42.55221339634487, 44.17358595984322, 45.513024943215505, 44.90148966653006, 46.96756778444563, 46.627265862056184, 46.56102173668997, 47.37666729518345, 45.77284588132586, 43.87203414099557, 38.518947396959575, 38.52614573069981, 39.18776362282889, 37.36815547943115, 39.656291076115195, 38.74236672265189, 38.34364087241036, 46.8449980872018, 39.95211410522461, 37.5827888080052, 37.101799760546, 37.3789564541408, 37.92099584851946, 37.84119231360299, 36.54186528069632, 36.00328608921596, 36.73519890648978, 44.26736579622541, 48.54102209636143, 47.018407753535676, 46.29333543777466, 44.747423785073416, 43.87404564448765, 46.32703767504011, 45.20292684010097, 43.07117782320295, 43.30465119225638, 45.240203925541465, 37.145142623356406, 31.805410317012242, 34.50620985031128, 33.54452357973371, 32.431884220668245, 31.133745329720632, 33.613418442862375, 33.8914019720895, 33.81264066696167, 32.36423308508736, 34.65446703774588, 35.6586137499128, 38.02777576446533, 39.52100270135062, 39.77520602090018, 38.928592341286794, 39.59413249152047, 35.77172000067574, 36.37266274860927, 35.39843497957502, 35.87089163916451, 33.75149999346052, 36.14256967817034, 33.61606223242623, 39.59798526763916, 46.078976563044954, 50.050368853977744, 47.247347423008506, 49.15961674281529, 49.01154715674264, 51.453512396131245, 43.517151423863, 44.72129855837141, 50.575162819453645, 49.527437005724224, 51.208407742636545, 49.064523696899414, 38.024621282305034, 37.58061402184622, 42.9261828150068, 50.288136209760395, 50.49893413271223, 48.88734115873064, 3.6128205146108354, 0.3342087050633771, 1.961073249578476, 0.662019313446113, 9.124089513506208, 50.778352464948384, 45.64072241101946, 51.05464063371931, 50.62272323880877, 56.025510447365896, 45.67821489061628, 34.70249646050589, 26.775649309158325, 31.026961939675466, 44.62814058576311, 7.227948265416281, 0.4051097791109766, 0.07435269347791161, 0.20245179294475488, 0.06009587885013648, 0.051816228311508894, 0.005205707516454692, 0.03271757099511368, 0.07675473458532776, 0.06663291914654629, 0.048760082838790755, 0.023830019236941422, 0.037252128922513554, 0.06288506489779268, 0.07176239961492163, 0.02948665865031736, 0.014748652432379978, 0.041437729860522916, 0.047521807319883785, 0.0120918926716383, 0.21179918279605253, 34.06941481998989, 60.95414216177804, 28.801339285714285, 26.110710178102764, 44.46202652794974, 55.76399414879935, 54.86203806740897, 56.03978899547032, 54.5728714125497, 56.533270903996055, 50.05582318987165, 53.45127929959978, 18.963145187922887, 0.8761351097907338, 0.40577574766107966, 4.837460492338453, 2.924228195633207, 0.08138920340154852, 11.946186355182103, 60.2715094430106, 49.38329662595476, 55.32517719268799, 53.519065925053184, 51.17319427217756, 49.895545618874685, 51.419476645333425, 51.17865555627005, 51.37150975636074, 50.932164737156455, 51.348945481436594, 50.40999371664864, 53.386702741895405, 42.263939585004536, 45.365386145455496, 51.63067408970424, 49.452716078077046, 44.12863458905901, 36.54268864222935, 36.60833869661604, 35.17082936423165, 37.10694490160261, 37.150305134909495, 37.30393327985491, 37.58764212472098, 35.69244452885219, 35.852913175310405, 37.73508637292044, 37.910066332135884, 38.46608550207955, 39.628508704049246, 38.21044390542166, 37.52158907481602, 37.41667127609253, 37.556872027260916, 36.27866056987217, 37.110172339848106, 37.206738403865266, 38.050124645233154, 43.49720661980765, 45.36452456883022, 47.015791756766184, 47.75091116768973, 46.914594718388145, 48.361435481480186, 47.92875378472464, 48.69486910956246, 49.5653463772365, 49.3668988772801, 44.6592754636492, 39.44645895276751, 38.46399409430367, 37.77511494500296, 36.45702082770211, 37.85936880111694, 37.861779826028005, 38.70787239074707, 48.25162615094866, 42.29924685614449, 36.20267507008144, 36.49513864517212, 37.17693758010864, 36.65279674530029, 37.75389862060547, 36.55797815322876, 35.305044242313926, 36.50812482833862, 45.0881530216762, 50.76889944076538, 50.63400363922119, 49.31958859307425, 47.64753239495413, 46.76669536318098, 48.106342792510986, 47.46918255942208, 44.82255813053676, 46.87344053813389, 47.40561349051339, 40.07636179242815, 33.93584959847586, 36.46138082231794, 36.239378929138184, 34.63326113564627, 32.91407183238438, 35.29580313818795, 35.258258547101704, 36.95271226337978, 34.59167616707938, 37.518990448543, 37.75496864318848, 40.170964990343364, 40.821667262486045, 42.938085079193115, 40.67832245145525, 40.982719557625906, 37.026154722486226, 38.45733424595424, 37.56731169564383, 37.992458071027485, 35.70674392155239, 38.4174759047372, 35.52280078615461, 41.19830478940691, 50.95916543688093, 51.181695393153596, 49.550084659031455, 52.813809871673584, 51.14847605569022, 53.78558840070452, 46.140554973057334, 48.205983434404644, 51.36703164236886, 53.59121254512242, 53.70662212371826, 52.24152496882847, 39.46519824436733, 40.623376096997944, 46.503733839307515, 53.05663551603045, 54.11688198362078, 51.541827474321636, 5.110401366438184, 0.39658146245138987, 1.8275119364261627, 0.9033015891909599, 10.59417460645948, 57.34211417606899, 51.24707099369594, 55.82824066707066, 55.32452406202044, 61.24507018498012, 50.051108837127686, 43.016547611781526, 24.157015698296682, 31.28174195970808, 53.58622373853411, 11.083444169589452, 0.42704282647797037, 0.04442772495427302, 0.1359435138957841, 0.026793814397283962, 0.03859114992831435, 0.029963095406336442, 0.0801206821841853, 0.053461207542568445, 0.18915660493075848, 0.3244985432497093, 0.11018864517765385, 0.10373889841139317, 0.1290569534259183, 0.1261899122702224, 0.12898721359670162, 0.1127460708043405, 0.13057366918240274, 0.13627280694033417, 0.12454958100404058, 0.2515008774186884, 41.01517111914498, 69.07147938864571, 37.80327251979283, 25.390534605298722, 43.836636543273926, 61.07658331734793, 58.50383908408028, 61.81857449667794, 59.62108857291085, 62.312237058367046, 55.23897089276995, 59.469159262520925, 24.75053950718471, 2.4898031524249484, 8.855335797582354, 12.949819769178118, 8.05630338191986, 0.1359529048204422, 15.725849185671125, 59.61068017142159, 47.426885400499614, 57.7514533996582, 54.64694963182722, 53.98387261799404, 52.02441808155605, 54.94490228380476, 53.191934313092915, 53.55342476708548, 52.05564328602382, 52.38710362570626, 50.64511728286743, 55.49420254571097, 43.229787826538086, 46.52277537754604, 53.29764420645577, 52.08107369286673, 46.14554030554635, 39.55692488806588, 38.877064500536235, 36.81202861240932, 39.8036276272365, 41.044252804347444, 40.1857716015407, 39.86482736042568, 39.194871629987446, 39.960118430001394, 39.30829749788557, 41.35256174632481, 42.18926382064819, 40.8098657471793, 41.316226141793386, 40.91341127668108, 40.28641973223005, 38.552330017089844, 37.148950236184255, 38.37213543483189, 39.142732347760884, 40.831332206726074, 45.35574204581124, 48.30234105246407, 50.668762002672466, 49.34965344837734, 49.1648383140564, 51.3203501701355, 51.24691118512835, 51.038343633924214, 51.64324338095528, 50.326389517102925, 45.812151840754915, 39.969019072396414, 38.06031765256609, 38.69784961427961, 37.229368686676025, 38.772789410182405, 39.302513122558594, 38.995437485831125, 51.11024011884417, 42.69348069599697, 37.57721287863595, 36.83189351218087, 36.94480868748256, 37.72948612485613, 37.94891371045794, 36.1605863571167, 35.390614782060894, 35.55286564145769, 46.01785326004028, 52.39430890764509, 51.736835615975515, 51.855507373809814, 49.58223744801113, 48.365243094308035, 51.562939575740266, 49.57112727846418, 45.772046838487896, 49.224922861371724, 48.764778409685405, 41.6911300931658, 37.021916321345735, 39.449227809906006, 38.08230522700718, 36.31195633752005, 34.04752104622977, 37.17417567116873, 38.7309820992606, 38.66983447756086, 35.75225114822388, 38.64200346810477, 40.86701815468924, 42.06017671312605, 43.43962342398507, 44.185422216142925, 43.08505684988839, 43.08673831394741, 39.650531019483296, 40.50113296508789, 39.58334541320801, 41.13519777570452, 37.00345148359026, 38.82706526347569, 37.49960150037493, 42.84775502341134, 51.25093419211251, 52.28257145200457, 52.0447485106332, 53.96142298834664, 53.65346840449742, 55.23996795926775, 48.749336038317, 47.13416126796177, 51.65723010471889, 55.98774698802403, 55.94880928312029, 53.26526212692261, 41.135031018938335, 43.127621514456614, 47.98002106802804, 56.63631616319929, 55.935975960322786, 52.065985679626465, 7.429784314973014, 0.5774433431880814, 9.28559170450483, 1.9702550768852234, 13.849053025245667, 63.268232754298616, 55.262216091156006, 59.68050261906215, 62.67072936466762, 64.46098136901855, 57.0654855455671, 46.67735889979771, 36.83297048296247, 41.00597170421055, 61.28552259717669, 15.833365610667638, 0.4934896709663527, 0.11533758603036404, 0.23103957250714302, 0.07531691888081175, 0.12107424677482673, 0.11175871414265462, 0.1685360749917371, 0.1588920432009867], [0.054221970827451775, 0.045041405595839024, 0.12463694917304174, 0.0232598734021719, 0.053407647380871434, 0.08081442995795182, 0.03896425258634346, 0.10852288241897311, 0.1383007445505687, 0.13340282094265732, 0.12270095305783407, 0.09013334847986698, 11.67584671292986, 55.97440297263009, 30.250167233603342, 22.045282704489573, 28.978846652167185, 46.32089894158499, 55.06102752685547, 51.76689004898071, 50.913738114493235, 46.47106688363211, 48.405563490731375, 48.05839327403477, 38.35717248916626, 0.1348420615707125, 0.7555689364671707, 2.55959780727114, 3.8056256430489674, 0.1371186686945813, 13.748088751520429, 45.71546070916312, 45.92040824890137, 53.88053553444998, 51.0172905921936, 52.16101966585432, 52.11885799680437, 52.198411396571565, 47.97825275148664, 54.10886376244681, 49.23581763676235, 50.75302628108433, 48.984827859061106, 47.90475818089077, 42.08885540281023, 51.50655494417463, 47.21190118789673, 46.469698088509695, 37.3025610106332, 33.64459500994001, 35.0715708732605, 34.52124922616141, 33.58358287811279, 33.35477869851248, 34.128432818821494, 34.999132428850444, 35.516807964869905, 35.56080395834786, 35.498416083199636, 35.96924339021955, 35.125110217503135, 35.069990158081055, 36.0658928326198, 35.129126276288716, 34.53039305550711, 35.37010717391968, 33.637143066951204, 33.79809808731079, 32.97278411047799, 35.51626947947911, 41.75605753489903, 43.61090694155012, 42.072950976235525, 44.570741517203196, 47.18219416482108, 46.62388556344168, 45.62681559153965, 46.8023361478533, 46.91405275889805, 45.63284662791661, 44.50183623177664, 38.63562502179827, 37.88809265409197, 38.21373735155378, 38.09737239565168, 38.1626854624067, 37.41665390559605, 38.08364970343453, 44.62187678473336, 41.78601121902466, 36.32141978400094, 37.6948424066816, 38.10130507605416, 38.35244076592581, 35.03533949170794, 37.25359010696411, 36.59342438834054, 38.006604603358674, 44.90669386727469, 47.03294685908726, 45.65693950653076, 46.608797550201416, 45.02768979753767, 47.57583045959473, 46.3536353792463, 46.613623074122835, 42.81899642944336, 43.808722155434744, 44.06371756962368, 42.63010965074812, 34.59705407278878, 33.76153319222586, 30.717767102377756, 32.666785444532124, 30.974746227264404, 32.3585216658456, 33.47452047892979, 34.14868681771414, 33.15944399152483, 34.315613814762656, 34.34523745945522, 37.40803466524397, 38.612786293029785, 39.58608995165144, 37.97079358782087, 39.089335441589355, 34.23052617481777, 36.15962403161185, 34.78336654390608, 34.56771183013916, 33.60530294690813, 35.14139332090105, 34.63367107936314, 36.25467191423689, 38.904652323041645, 44.139921937670024, 47.03847415106637, 47.765804631369456, 48.42681803022112, 48.04471574510847, 50.151027406964985, 51.326759883335654, 48.2805688721793, 48.2501357623509, 48.549703870500835, 51.61324800763811, 43.94762359346662, 39.1184275490897, 42.60061454772949, 50.984352656773154, 49.37167576381138, 49.09358106340681, 2.309195803744452, 1.1130937061139514, 0.30654054401176317, 0.09409874105559927, 20.84678966658456, 52.984019892556326, 46.820877415793284, 52.11344882420131, 51.142813273838584, 55.28929322106497, 36.85060501098633, 33.32258422034127, 22.996913194656372, 37.09147473743984, 39.526686327798025, 1.1958312264510562, 0.17781633058828966, 0.029927363752254417, 0.06289737352303096, 0.05236086801492742, 0.04755517427942582, 0.06406833497541291, 0.06653898275856461, 0.03953074790271265, 0.05425930382417781, 0.07143024993794304, 0.09479355412934508, 0.021284766528489332, 0.06343896660421576, 0.06260403604911906, 0.04576899869633572, 0.01596001216343471, 0.07369942710335765, 0.041768793881471665, 0.1123596043991191, 0.0664913428149053, 17.08068711417062, 63.97043854849679, 30.94087723323277, 17.160820688520158, 36.29091371808733, 50.50736229760306, 57.724803583962576, 58.39545413425991, 55.64255700792585, 52.142019816807334, 53.447242396218435, 53.73202821186611, 40.00948190689087, 0.08135147006916148, 0.7556428153600011, 3.3683683403900693, 5.023116358688899, 0.3579032564801829, 15.601330518722534, 48.663720335279194, 45.3135004724775, 54.45448453085763, 51.640425886426655, 52.97088432312012, 54.59173229762486, 53.24384430476597, 50.47730439049857, 57.463106632232666, 51.75740575790405, 52.532751764569966, 48.81223808016096, 48.70064653669085, 43.85158906664167, 52.639715807778494, 49.595602308000835, 48.699864864349365, 39.24561085019793, 37.43027932303292, 36.26313829421997, 37.340296677180696, 36.6235865184239, 35.6055850982666, 35.78909397125244, 38.6951710837228, 37.020026411329, 38.363606521061485, 38.300958088466096, 40.07834897722517, 37.195583071027485, 39.13728496006557, 38.94324609211513, 37.08079188210623, 34.93772077560425, 35.87827410016741, 34.92286900111607, 36.15634100777762, 34.15300512313843, 38.26425075531006, 44.06791080747332, 46.43191725867135, 45.852944714682444, 46.45095879690987, 49.505859375, 48.72367981501988, 48.22498675755092, 49.80170324870518, 46.937739167894634, 48.03930309840611, 45.840604713984895, 39.038794245038716, 36.91394131524222, 38.03360530308315, 37.55770581109183, 37.049639633723665, 37.270151138305664, 38.70813642229353, 45.50531939097813, 41.74013921192714, 36.172863824026926, 38.00175476074219, 37.551528862544465, 37.496106556483674, 35.5724595614842, 36.92351245880127, 35.95849800109863, 36.55700887952532, 45.3427072252546, 48.104796818324495, 48.2204669543675, 49.79520320892334, 44.91300630569458, 48.81864431926182, 49.38155262810843, 48.69111360822405, 45.533699308122905, 45.19770179476057, 47.07788780757359, 43.956208092825754, 36.27822978155953, 36.3720235143389, 32.68013293402535, 34.811207975660054, 32.87095478602818, 34.825837407793315, 34.80545139312744, 35.07654230935233, 36.05324363708496, 36.84505687441145, 37.37731320517403, 40.54246432440621, 41.24476739338466, 42.980687958853586, 39.413913590567454, 40.74093614305769, 36.58201892035348, 38.8089165687561, 37.081893171582905, 35.88505901609148, 36.374858379364014, 36.944860798971995, 36.281905378614155, 37.60456098828997, 40.25239440373012, 47.44617359978812, 49.262078353336875, 50.403316497802734, 49.93524762562343, 51.89490713391985, 52.420003346034456, 54.04171289716448, 49.401855264391216, 49.35413156236921, 50.912688936506, 53.8829847744533, 47.42580842971802, 40.778449467250276, 44.262668813977925, 54.70254216875349, 51.382807527269634, 50.68335321971348, 2.4102810195514133, 2.054529343332563, 0.457116394170693, 0.18858439634953225, 22.885220902306692, 56.09317895344326, 50.88772405896868, 55.959575516836985, 57.34286110741751, 59.36060755593436, 42.92293453216553, 42.339237213134766, 21.47545746394566, 40.96648161751883, 48.31680025373186, 2.535088905266353, 0.5124977709991592, 0.051065229145543914, 0.05676419387704559, 0.0196048868487456, 0.15310856354023727, 0.04950499554563846, 0.021309901161917617, 0.05244490457698703, 0.13923355378210545, 0.15296626117612633, 0.2760241100830691, 0.086374128769551, 0.19542236014136247, 0.14977770298719406, 0.11649763663964612, 0.16240849665233068, 0.2667672639446599, 0.1708796399512461, 0.2607242853513786, 0.2473413763301713, 20.390999998365128, 73.63266604287284, 37.515144620622905, 30.65649093900408, 40.91326536451067, 57.45418861934117, 64.52757290431431, 63.122487340654644, 61.53592872619629, 56.17101614815848, 58.021793910435264, 56.259372915540425, 47.52800253459385, 0.2853429743221828, 4.095648229122162, 7.68999000958034, 8.135513714381627, 1.0383275066103255, 19.62123339516776, 51.61749683107649, 46.491042954581125, 56.346065589359824, 52.136628014700754, 55.03204311643328, 57.26483978543963, 57.333217007773264, 52.11818402154105, 58.30767059326172, 53.99674415588379, 55.30991200038365, 51.09042733056204, 50.56391021183559, 43.9680061340332, 55.720901421138215, 50.17251123700823, 50.72212764195034, 40.49983017785208, 39.69727849960327, 37.85802085059029, 39.647150720868794, 38.725291524614605, 36.68448053087507, 37.81552219390869, 41.258069719587056, 39.8923248563494, 40.4214197567531, 40.101722717285156, 42.09117610113961, 39.05867304120745, 39.427299295152935, 40.85107203892299, 39.2783716065543, 36.93912853513445, 38.62397289276123, 36.707458223615376, 38.18345362799508, 35.91359526770455, 39.6476023537772, 46.55302783421108, 49.51851551873343, 46.23314666748047, 48.06532410212925, 51.90292535509382, 49.675933906010215, 49.36826419830322, 51.485804149082725, 48.055155413491384, 48.5876201902117, 47.960632119859966, 39.29763896124703, 37.57829679761614, 37.90181882040841, 37.91426999228341, 36.85450989859444, 37.249108518872944, 38.50408867427281, 46.47487102236067, 43.386754580906455, 36.27827841894967, 38.86997733797346, 36.73583814076015, 38.08188138689314, 35.35731554031372, 37.29575872421265, 35.8646035194397, 37.812513623918804, 45.43341595785958, 50.202603885105674, 49.85536418642317, 52.324184213365825, 46.969513280051096, 54.37376383372715, 50.69113520213536, 53.038535458701, 47.39933231898716, 48.249399253300254, 49.38447434561593, 48.5206812449864, 39.42405448641096, 39.310368061065674, 33.38413136345999, 36.503990650177, 34.263321672167095, 36.653029509953086, 37.706164496285574, 37.7469608443124, 36.65413427352905, 39.26182099751064, 39.80531256539481, 43.53386878967285, 43.17808280672346, 43.804306575230186, 40.870092732565745, 44.17365196772984, 37.592578819819856, 40.020050116947715, 39.88281972067696, 38.24043927873884, 38.586098262241904, 39.406555448259624, 37.764404296875, 39.83128145762852, 42.87401226588658, 48.60593564169747, 51.11071607044765, 51.92800835200718, 53.099776881081716, 51.91296897615705, 54.3038649559021, 55.050087588174, 49.32392774309431, 50.67791625431606, 53.56060573032924, 56.76211329868862, 48.17952469417027, 42.939561571393696, 45.615660258701865, 56.61885186604091, 53.2729503086635, 54.66047082628523, 4.441058380263192, 2.0593199091298238, 2.6662763229438236, 0.8832335631762231, 27.78877135685512, 62.068334443228586, 56.60859285082136, 62.03053624289376, 62.8069349016462, 62.866022382463726, 48.64780896050589, 42.61339575903756, 32.152222701481406, 47.36146811076573, 58.24126318522862, 3.9234002147402083, 0.6489631054656846, 0.214098154434136, 0.18689530555691036, 0.14758769050240517, 0.29408304819038933, 0.21437625879687922, 0.14000727369316987, 0.15275314689746924], [0.062061309814453125, 0.06621705181896687, 0.021609174120905142, 0.011737181705289652, 0.06473577594650642, 0.010056959365361502, 0.027495039626955986, 0.08602629814829145, 0.03355863211410386, 0.05487098618011389, 0.12188168987631798, 0.0494450842961669, 3.230865227324622, 46.60394770758492, 40.864082540784565, 34.24875824792044, 29.97482749394008, 37.15061085564749, 51.44878414699009, 53.48314026423863, 50.01565912791661, 48.29058470044817, 49.34447009222848, 34.52281257084438, 50.678784779139924, 3.1050270540373663, 0.6930760240980557, 1.8442553579807281, 10.460415703909737, 0.4110653352524553, 13.890655364309039, 56.9169921193804, 46.013034684317454, 57.60166760853359, 50.3677590915135, 54.70932361057827, 51.97708347865513, 54.114915643419536, 47.05323907307216, 50.405956813267295, 48.04136323928833, 48.52934912272862, 45.94105134691511, 49.2172520501273, 50.21619456154959, 51.3692307472229, 46.55058554240635, 44.03421204430716, 35.69213533401489, 36.92515223366873, 34.0518810408456, 36.0403026172093, 33.039841175079346, 32.45726599012102, 34.55483334405081, 33.50257730484009, 36.445090770721436, 36.384617124285015, 32.86073746000017, 34.906221117292134, 35.10171563284737, 38.00158452987671, 34.8472899709429, 35.991866724831716, 35.36600078855242, 34.18186099188668, 33.23850059509277, 34.356861795697895, 32.80550970349993, 38.23745502744402, 41.87224531173706, 43.74831799098423, 46.61481816428048, 44.16070747375488, 46.642968790871755, 46.777659620557515, 46.27863652365548, 47.500195843832834, 45.810807364327566, 47.2054636819022, 42.5325083051409, 39.39517429896763, 38.02275916508266, 37.595691612788606, 38.97269255774361, 39.607257638658794, 36.79288979939052, 38.90986347198486, 44.220468929835725, 44.75966303689139, 39.53345387322562, 38.957576751708984, 38.310536180223735, 39.868159021650044, 37.369906425476074, 36.02909517288208, 38.229773793901714, 38.12434530258179, 42.33457497188023, 45.82973425728934, 45.75076798030308, 47.032734939030235, 44.778697626931326, 44.906527110508506, 44.64333629608154, 44.594827447618755, 43.489785943712505, 43.012302262442454, 41.60298524584089, 42.170844146183555, 34.11409173692976, 30.255427019936697, 30.640002863747732, 33.17989253997803, 32.42352901186262, 32.696989263807026, 33.33538280214582, 35.45324237006051, 32.14332900728498, 35.27473620006016, 34.905449867248535, 36.56551694869995, 35.672027247292654, 37.42314004898071, 36.654992376055034, 35.23714297158377, 35.68924140930176, 35.840100697108674, 32.778356143406455, 36.26085581098284, 34.67787899289812, 34.270902156829834, 34.45524133954729, 36.17959662846157, 36.02295296532767, 34.11047172546387, 38.05215351922171, 40.02322544370379, 41.76362412316458, 46.13376658303397, 47.12550033841814, 49.72437327248709, 49.914145946502686, 37.987622124808176, 43.7871549470084, 53.402839933122905, 46.44664396558489, 41.79602704729353, 42.737108434949604, 51.598097460610525, 51.25230646133423, 39.570616313389365, 1.0668946994202477, 4.204219911779676, 1.2101629717009408, 0.14871560569320405, 30.643713201795304, 49.90338666098458, 46.7346259525844, 51.05761793681553, 46.0914694241115, 48.89972979681832, 36.37726245607649, 28.66673183441162, 26.838533980505808, 45.68633386066982, 25.64733133997236, 0.32714254994477543, 0.07661044411361217, 0.03565360898418086, 0.052893752099147866, 0.052819537331483195, 0.11805792791502816, 0.010692767882054406, 0.03395808567958219, 0.04846900827916605, 0.08003258798271418, 0.04671845578455499, 0.035390103302363835, 0.02645772582452212, 0.053416922954576354, 0.013670785136387816, 0.040374533339802704, 0.03664356782766325, 0.13045892891074928, 0.026107778174004385, 0.16105061237301144, 0.07398463572774615, 4.791684457233973, 55.989424977983745, 43.50189317975725, 28.295592069625854, 39.48447254725865, 46.194983686719624, 57.43847526822771, 57.60915429251534, 56.012586797986714, 53.07557283129011, 54.825976916721885, 41.61517933436802, 54.76675394603184, 2.988620843206133, 0.5127373752849442, 3.6063532616410936, 13.973943420818873, 1.3098149044173104, 16.075018746512278, 59.13874462672642, 46.8161734853472, 59.71967656271798, 50.347115993499756, 56.28041206087385, 52.41869708469936, 55.30392612729754, 49.68520975112915, 51.67078256607056, 48.36712953022548, 50.38585567474365, 47.006581919533865, 51.42538608823504, 52.50879784992763, 54.32534531184605, 48.117925439562114, 46.02785519191197, 37.249073777879985, 38.01761402402605, 36.655336311885286, 37.91923795427595, 35.85064458847046, 34.9703495161874, 36.00818109512329, 36.89083855492728, 38.80659587042672, 39.355097089494976, 36.26914153780256, 37.440034593854634, 37.69951854433332, 39.03653608049665, 36.1029441016061, 38.121618134634836, 36.55350351333618, 36.218586444854736, 34.86337852478027, 36.89054325648716, 35.56670992715018, 40.05644130706787, 43.369193008967805, 46.24056734357561, 46.68499149594988, 46.802381311144146, 50.0468739100865, 48.83089746747698, 48.06246491840908, 49.075123173849924, 47.76386955806187, 49.276794637952534, 42.91306114196777, 38.06816216877529, 37.69687475476946, 37.56721442086356, 39.02675649097988, 38.76578910010201, 37.88204424721854, 37.995199135371614, 44.444760254451204, 45.29480634416853, 37.849867139543804, 38.257834093911306, 37.959606988089426, 39.099524974823, 36.033173765454976, 36.923258849552695, 38.224510533469065, 37.46725068773542, 41.87578889301845, 46.7266389983041, 47.15880305426461, 48.10381017412458, 45.431328024183, 47.54417446681431, 46.77905968257359, 46.3879143169948, 44.7228410584586, 44.83373430797032, 43.06292336327689, 43.017027037484304, 36.83485344478062, 32.82074015481131, 31.39515393120902, 35.38980531692505, 34.6157169342041, 34.59562969207764, 36.23125301088606, 36.91050543103899, 34.773364612034385, 38.30594342095511, 36.06790086201259, 38.30422374180385, 37.82860565185547, 40.054238728114534, 37.72861760003226, 38.89771107264927, 36.843014104025706, 37.78482852663313, 34.89026457922799, 38.18072993414742, 36.135440826416016, 36.25563423974173, 35.85004704339163, 37.614906855991904, 37.05352715083531, 37.03173760005406, 38.44908673422677, 41.89364228929792, 43.65605286189488, 48.664953640529085, 48.79639618737357, 51.48138509477888, 50.909649099622456, 40.49116577420916, 45.68686887196132, 55.96349777494158, 49.17344018391201, 44.48487220491682, 45.32776859828404, 54.66668251582554, 52.61559861046927, 40.75763266427176, 1.7162217710699355, 5.327082676546914, 1.8292118566376823, 0.17244991926210268, 34.630770206451416, 53.70203978674752, 53.50508267538888, 54.91882222039359, 55.29380260195051, 53.355547019413535, 42.735333170209614, 34.77809633527483, 25.879163197108678, 50.76471662521362, 32.72919763837542, 0.5931173392704555, 0.14837762740041527, 0.048256962693163326, 0.0878569788432547, 0.05830143192516906, 0.02343754779680499, 0.08606434360678707, 0.030547711000378643, 0.022823918045365384, 0.12990818917751312, 0.1943140546126025, 0.14585492919598306, 0.09222199461821999, 0.10303371732256242, 0.10384724688317094, 0.3239912161869662, 0.17316679150930472, 0.1924023229096617, 0.12070733574884278, 0.24239463891301835, 0.2556175765182291, 5.365866652556828, 66.14006914411272, 52.867182459150044, 43.78783587047032, 42.51541573660714, 50.11430617741176, 61.58546938214983, 63.28642313820975, 62.61276749202183, 57.21969039099557, 61.657709802900044, 47.81677314213344, 57.49408170155117, 4.398976615497044, 3.8436687673841203, 11.491533585957118, 17.193954910550797, 1.8656419132437025, 20.13448813983372, 59.57771096910749, 46.85784183229719, 61.28046430860247, 51.150094985961914, 57.796328340257915, 54.164762020111084, 55.5111665725708, 50.123432636260986, 51.451803139277864, 49.95178433826992, 51.5180298941476, 49.23668616158621, 51.85150521142142, 52.741315841674805, 56.53622388839722, 49.237099579402376, 48.50867823192051, 38.71108940669468, 40.66907092503139, 38.660687174115864, 40.09854391642979, 38.225386006491526, 37.07279797962734, 39.23788792746407, 39.47677046912057, 41.92972428458077, 42.39528833116804, 37.33796555655343, 40.08095455169678, 39.82195350102016, 42.84999581745693, 37.7005295072283, 41.830451897212434, 39.41927065168108, 39.20387996946062, 37.39534378051758, 38.909168652125764, 36.559774262564524, 44.59504631587437, 46.80964912687029, 48.40417037691389, 48.6136029788426, 48.42230517523629, 53.51383393151419, 51.76262732914516, 50.28634704862322, 51.234637192317415, 50.322821617126465, 51.50628049033028, 42.903260707855225, 38.58308274405343, 38.23936230795724, 36.20800086430141, 38.687330041612896, 39.32549428939819, 37.09244401114327, 39.24256406511579, 46.21353885105678, 46.59584958212716, 40.02141196387154, 39.51030247552054, 38.48385899407523, 39.58251510347639, 37.60178518295288, 36.09569018227713, 39.70558507101876, 37.350190911974224, 43.39646816253662, 50.41359288351876, 49.98487165996006, 50.53070477076939, 48.06245102201189, 49.55507346561977, 48.637445722307476, 48.81217207227434, 46.75386551448277, 46.8433826310294, 45.37224054336548, 44.62118891307286, 39.61054066249302, 34.3817571912493, 33.079421588352744, 37.882447242736816, 35.6264887537275, 37.19076449530465, 37.892171246664866, 38.76777975899832, 36.10844012669155, 41.25693368911743, 38.315809862954275, 40.32498223440987, 40.373786381312776, 41.90670142854963, 40.149116379874094, 41.56158787863595, 39.01538576398577, 39.74315398080008, 35.8685987336295, 41.39489712033953, 39.04736137390137, 36.90333489009312, 38.09528793607439, 40.0174514906747, 39.365995338984895, 36.74465193067278, 41.49032367978777, 43.33418451036726, 45.95017433166504, 51.611500535692485, 50.290349211011616, 54.769759041922434, 52.55250896726336, 41.17791877474104, 45.7962508882795, 58.77222715105329, 49.421216419764924, 46.926531723567415, 47.03017800194876, 57.4078163419451, 54.88792705535889, 45.91891091210501, 3.184761106967926, 7.50554312978472, 4.065418788364955, 0.23445021520767892, 40.65643909999302, 57.83313642229353, 58.69510909489223, 57.477041244506836, 58.365708896092, 57.27335480281285, 48.22639724186489, 39.32149907520839, 36.20775072915213, 58.75682994297573, 39.97858674185616, 1.0213938781193324, 0.2336107316826071, 0.17518598958849907, 0.16026142186352185, 0.18223974108695984, 0.18142468482255936, 0.15343888795801572, 0.1396485457995108, 0.099577646702528], [0.050508772754775624, 0.019128507768203105, 0.04746402667037078, 0.05810049056474652, 0.0638049751786249, 0.027480188191735318, 0.037156255317053626, 0.07758722241435732, 0.04455726746735828, 0.029121172547872578, 0.08496093710086175, 0.06984723452478647, 0.15688873641192913, 30.55856302806309, 51.59864984239851, 20.980797835758754, 17.984819718769618, 36.61832673209054, 47.300445556640625, 52.73881796428135, 53.306763717106406, 50.29534149169922, 48.91271250588553, 45.14117125102452, 50.76360143933977, 11.033926963806152, 1.6145332562071937, 1.7143917892660414, 2.412895279271262, 3.4502246337277547, 24.061252151216777, 55.654650347573416, 54.485501289367676, 52.848623820713584, 50.18265560695103, 51.715740885053364, 50.44236189978463, 51.78654302869524, 49.21729026521955, 51.671741417476106, 51.07036093303135, 52.019738469805034, 50.65846129826137, 51.842687947409495, 48.02348552431379, 47.698007583618164, 43.9879161970956, 36.6201992716108, 35.6839850970677, 37.416726861681255, 36.03687368120466, 34.77365296227591, 33.32699632644653, 33.98874276024954, 36.46797466278076, 37.558880056653706, 38.60717214856829, 40.32214042118618, 38.113940375191824, 37.822043078286306, 35.85189873831612, 36.59004061562674, 34.8228566305978, 35.31802347728184, 36.26102951594761, 34.31887946810041, 32.903451510838096, 33.451303073338096, 34.084169319697786, 35.30525268827166, 42.45639426367623, 45.91422782625471, 44.69477728434971, 45.641688210623606, 46.73098857062203, 44.72077744347708, 44.35374927520752, 45.2613924571446, 46.339544432503835, 45.672830036708284, 38.6841755594526, 38.636187825884136, 36.04686519077846, 37.670332636152, 37.0672151020595, 36.4807767186846, 36.062463896615164, 40.28637456893921, 41.50394214902605, 43.56022678102766, 38.18410675866263, 36.572260175432476, 38.018534660339355, 38.18294988359724, 38.715807233537944, 39.299032075064524, 35.71460580825806, 36.58254698344639, 41.11782380512783, 48.00245680127825, 44.89225551060268, 45.45935705729893, 44.16662039075579, 45.00899566922869, 44.23920127323696, 43.430479594639365, 44.09429311752319, 44.8378962789263, 41.175386156354634, 42.89654874801636, 37.07250615528652, 32.31294495718819, 32.17289011819022, 31.41397660119193, 33.50583948407854, 33.699305125645225, 33.6135504586356, 35.36634125028338, 33.220810481480186, 35.4378799029759, 35.41711868558611, 35.86459657124111, 35.07536458969116, 34.94022907529558, 35.90335014888218, 35.163801261356895, 34.477479049137656, 35.292738982609336, 35.03954315185547, 33.85637262889317, 34.24866444723946, 35.391910621098106, 35.60108961377825, 35.43544108527047, 35.741735049656455, 37.57480880192348, 38.79061848776681, 37.021600178309846, 37.827264649527415, 41.72229623794556, 47.66665383747646, 47.75334998539516, 51.18170234135219, 43.567168031420024, 48.130206380571636, 52.13803155081612, 48.50685780388968, 45.74043253489903, 42.16998256955828, 51.17250987461635, 50.14361367906843, 34.62296043123518, 2.211419233254024, 1.5180417767592838, 0.9645609791789735, 1.8226184504372733, 38.36789355959211, 47.3876246043614, 45.99875613621303, 52.2461906841823, 41.98285715920584, 44.14122472490583, 32.17735433578491, 27.67877616201128, 29.049792970929825, 41.14977857044765, 12.64674803188869, 0.6354292631149292, 0.017658943410164545, 0.11660119465419225, 0.06959054472723178, 0.13044976868799754, 0.017835186095908284, 0.06597611760454518, 0.05945811021540846, 0.015092993687306131, 0.02676759071515075, 0.0160888133770121, 0.02620415898439075, 0.020096573679308807, 0.09582076115267617, 0.05390292705435838, 0.008018113456533423, 0.06634990897561822, 0.027724041803074733, 0.0499155872634479, 0.056490320180143626, 0.05388349720409938, 0.3528012702507632, 39.29488400050572, 57.02504702976772, 25.721070834568568, 27.274387529918126, 44.48347561700003, 50.056295667375835, 58.52515615735735, 55.30161932536534, 54.024960790361675, 54.26040397371565, 48.60609892436436, 56.14368540900094, 13.030987756592886, 1.751212247780391, 3.0605003918920244, 3.472366154193878, 3.125994546072824, 27.83492476599557, 56.94667829786028, 56.08027614865984, 54.85218552180699, 53.51927784511021, 54.22898769378662, 52.786267212459016, 54.699186188834055, 50.67614098957607, 52.33778183800833, 51.088766711098806, 52.788014684404644, 51.81092773165022, 52.51695156097412, 47.940041133335654, 49.55561542510986, 46.26815169198172, 38.67842592511858, 37.13530397415161, 39.803947244371685, 37.32374259403774, 36.64776972361973, 35.27695614950997, 35.16540976933071, 39.01654263905117, 39.27885798045567, 41.88902521133423, 42.46720566068377, 41.547128677368164, 39.715170110974995, 38.47700112206595, 38.46290670122419, 36.50827768870762, 37.21906450816563, 36.16346985953194, 36.61623879841396, 35.56813430786133, 34.856538023267476, 35.40899971553257, 36.12634563446045, 44.97908367429461, 47.28818198612758, 46.74526364462716, 47.781736850738525, 47.177118505750386, 45.62312609808785, 47.12389530454363, 48.05769498007638, 47.63658550807408, 46.15806443350655, 39.25958020346505, 38.80721426010132, 36.48947933741978, 36.44808891841343, 37.43025153023856, 36.067053181784495, 36.85819591794695, 40.53192390714373, 43.838272844042095, 44.055362360818044, 39.41944783074515, 37.520189012799946, 37.66807794570923, 36.93216296604702, 37.342930044446675, 38.683994906289236, 36.17779704502651, 37.065137590680806, 41.356192180088584, 47.14509425844465, 46.02538858141218, 48.13678979873657, 46.91161394119263, 46.53968729291643, 45.23162637438093, 44.258329663957866, 45.23920338494437, 45.61635855266026, 44.637909752982004, 44.744126864842, 38.89786740711757, 34.20391110011509, 33.70766380855015, 33.83231101717268, 34.44751146861485, 35.50709090914045, 36.31319659096854, 36.71824877602713, 35.33209705352783, 37.97417736053467, 37.44642693655831, 38.258056436266216, 38.371676853724885, 37.56844425201416, 37.72900322505406, 36.54054512296404, 36.06980814252581, 36.3900089263916, 36.24203314099993, 35.66565922328404, 37.771533148629324, 37.350715500967844, 35.398025035858154, 36.45958818708147, 36.453682218279155, 38.11901256016323, 39.46258919579642, 39.083915846688406, 39.87025390352522, 43.20138011659895, 49.45012092590332, 50.32374572753906, 51.7323123386928, 46.29939774104527, 49.45822947365897, 54.178397859845845, 50.818492208208355, 49.16888216563633, 45.3844450541905, 54.346891675676616, 51.411406312670024, 37.79717547552926, 3.0860777965613773, 2.0791693925857544, 1.366088364805494, 2.369581946304866, 44.51977300643921, 49.90846926825387, 51.389943327222554, 55.427930627550396, 46.92847721917288, 47.187252453395296, 43.36660827909197, 28.414322887148174, 27.654989004135132, 49.594778946467805, 15.89156893321446, 0.5024828112551144, 0.05485709996095725, 0.11273921081530196, 0.02737681507798178, 0.05130780541471072, 0.06954518466123513, 0.05675313375624163, 0.07533316979450838, 0.03066154882045729, 0.08685569185763597, 0.11190903679068599, 0.19077542663684913, 0.08509856435869421, 0.27312055017266956, 0.1410051001501935, 0.12074423448315688, 0.14429524860211781, 0.34388323021786554, 0.17858363155807766, 0.1343794906777995, 0.12821662851742335, 0.4866515578968184, 46.00173691340855, 64.33578872680664, 30.056058883666992, 26.954509837286814, 49.53470829554966, 56.9839380128043, 62.857677595955984, 61.98575510297503, 58.20170709065029, 58.45723056793213, 54.39170060838972, 60.38543905530657, 15.38496014050075, 2.534052320889064, 8.610652378627233, 5.5474995119231085, 5.027266604559762, 33.97475603648594, 55.92879499707903, 57.78992210115705, 54.597422872270855, 57.448279176439556, 55.24282019478934, 55.842696394239155, 56.68160799571446, 52.31221941539219, 54.88182306289673, 53.20410755702427, 54.492703097207205, 54.64129032407488, 56.61425563267299, 50.447315965379985, 53.39176797866821, 48.49436494282314, 40.573046820504324, 41.588599000658306, 42.39899866921561, 39.49739619663784, 39.05904476983206, 38.731739452907014, 37.85664163316999, 42.574419839041575, 41.56960957390921, 44.32528945377895, 44.682815960475374, 43.65145662852696, 41.986821106501985, 39.608477047511506, 41.045506954193115, 37.75049747739519, 38.69315958023071, 40.52632713317871, 38.81359618050711, 37.435952527182444, 36.4721713747297, 37.85200023651123, 38.68678460802351, 47.44597905022757, 48.00099073137556, 49.71854720796858, 50.446013178144185, 49.32303837367466, 49.27938631602696, 49.763342244284495, 49.98540667125157, 48.54463515962873, 46.43921981539045, 39.93762363706316, 38.03845167160034, 35.4545590536935, 36.50266701834542, 37.835025787353516, 35.881432056427, 37.28655236107962, 41.796127796173096, 45.89247301646641, 45.48561429977417, 39.25676965713501, 37.26384217398507, 38.72065360205514, 38.8090729032244, 37.71778883252825, 38.902696405138286, 35.256181035723, 37.45983695983887, 41.94300924028669, 50.08461652483259, 48.211079938071116, 50.14452736718314, 48.37594332013811, 48.373028550829204, 48.394373416900635, 47.488609722682405, 49.0152644429888, 48.9360237121582, 46.26186009815761, 46.90884508405413, 41.17154032843453, 37.048816272190635, 36.35024438585554, 36.252629143851145, 36.723671845027376, 37.208058561597554, 38.93457474027361, 38.95300831113543, 36.70012092590332, 40.22824246542794, 40.90972178322928, 40.29141896111624, 40.509074756077354, 39.073392799922395, 39.94567312513079, 39.80546542576381, 39.53635127203805, 39.05179779870169, 39.07059267589024, 37.663519927433555, 37.4141560282026, 39.46517392567226, 38.94461836133684, 38.51415661403111, 37.31381361825125, 41.30747488566807, 44.12645285470145, 42.266604219164165, 43.76247147151402, 44.58614567347935, 51.82811757496425, 53.21322359357561, 54.33964817864554, 45.64806318283081, 50.134191921779085, 56.04427753176008, 53.08928510120937, 51.0137574332101, 46.09471423285348, 58.59408923557827, 52.90386547361101, 41.16745131356375, 6.449930242129734, 3.6356488210814337, 2.414550253323146, 2.2454224143709456, 50.43573331832886, 57.83204902921404, 55.20115532193865, 61.89688069479806, 53.255416529519216, 53.93858078547886, 42.688682964869905, 36.81659357888358, 36.18968193871634, 56.34675693511963, 22.801488161087036, 0.8002023728830474, 0.14522693146552357, 0.16249712689646653, 0.1638945969087737, 0.14915765768715314, 0.19980485497840814, 0.2013588494488171, 0.14046026367161954, 0.13714012397187098], [0.03401956434494682, 0.038163228426128626, 0.049983915739825795, 0.057283676894647736, 0.10945212255631175, 0.05540455219202808, 0.036218404570328336, 0.01939322124235332, 0.045551151635923555, 0.11133040248283319, 0.02571388181032879, 0.09704024464424167, 0.06884438690862485, 12.616882937295095, 53.71645382472447, 24.724386487688335, 22.73421917642866, 31.568765095302037, 46.30095761162894, 51.05639852796282, 49.598430224827354, 48.74320772715977, 50.540279388427734, 44.18443209784371, 50.20593554633004, 22.14005787031991, 0.5700193558420453, 0.2803444782538073, 2.0394435014043535, 23.307014771870204, 30.72717148917062, 58.673715591430664, 50.88565002168928, 52.42207390921456, 48.9823716708592, 51.298147201538086, 49.313838958740234, 49.84882245744978, 50.93134137562343, 52.36596373149327, 49.54206991195679, 50.18845040457589, 46.54250826154436, 47.63981294631958, 47.42596129008702, 43.16049344199044, 38.24663707188198, 37.0573764528547, 37.31658942358834, 36.40817151750837, 35.53823273522513, 34.91628210885184, 34.98397493362427, 35.63257190159389, 35.15238537107195, 37.522596563611714, 37.41748421532767, 40.97662251336234, 39.41722093309675, 38.48008959633963, 38.4504520552499, 36.09906005859375, 35.851645129067556, 34.72945547103882, 35.56759582247053, 33.961450236184255, 33.38847051348005, 32.844033990587505, 32.748583112444194, 33.92517716544015, 42.70919752120972, 46.53237778799874, 44.715851170676096, 45.123418603624614, 45.46805967603411, 45.52380854742867, 47.85390084130423, 46.474732058388845, 46.272483893803184, 41.67064332962036, 39.51585061209542, 37.20005771092006, 37.92017248698643, 37.02109643391201, 37.446510314941406, 36.42692123140608, 37.92480346134731, 39.51633698599679, 40.52316917691912, 42.41941247667585, 40.27027906690325, 38.65617431913103, 37.40321956362043, 37.15974078859602, 37.567877973829, 37.883722237178254, 38.228658608027864, 37.62624979019165, 38.543936593191965, 43.66431079592024, 46.661902632032124, 46.747250829424175, 46.623638902391704, 44.24619810921805, 44.67263337544033, 42.37409285136631, 42.524972983769004, 43.821089948926655, 41.35468789509365, 40.89355679920742, 38.05613831111363, 31.964930534362793, 32.26023939677647, 31.154558658599854, 32.57228299549648, 33.69190876824515, 33.28706850324358, 33.844730922154014, 35.19063867841448, 33.59225075585501, 34.01608739580427, 35.458258969443186, 33.42057466506958, 32.8971460206168, 34.065568992069785, 33.75678062438965, 32.44410957608904, 34.327189513615195, 34.163858209337505, 34.42036485671997, 33.067488057272776, 35.3257429259164, 34.358129841940745, 37.24997704369681, 41.937172753470286, 44.11898701531546, 47.01938050133841, 46.83067784990583, 47.10195289339338, 48.406696047101704, 48.304383822849815, 48.878030572618755, 50.26365770612444, 45.65598412922451, 44.193492548806326, 53.12094109398978, 48.83849532263619, 49.40934542247227, 47.01441601344517, 52.57648025240217, 49.90577336720058, 19.402111530303955, 1.6233218588999339, 1.3042282270533698, 1.0420279651880264, 2.865571285997118, 48.27915838786534, 46.00127138410296, 48.5850875718253, 49.465705735342844, 50.488452775137766, 43.586171354566304, 27.183173315865652, 29.413065637860978, 39.152320861816406, 39.73635516847883, 2.9910019040107727, 0.5620271361299923, 0.042656789267701764, 0.1369299545351948, 0.11237850159938846, 0.0722999961248466, 0.08499860257974692, 0.03721695027447172, 0.11036695060985428, 0.1016017370192068, 0.05092353746294975, 0.049476978834718466, 0.07913336623460054, 0.02614944531316204, 0.030948094158832515, 0.03627303342467972, 0.01970139827712306, 0.029773441475949118, 0.016380873508751392, 0.05533475468733481, 0.05798364004918507, 0.1945329907217196, 0.0754567649481552, 17.466185331344604, 63.83851310185024, 23.151013817105973, 20.275976044791086, 43.19465773446219, 51.305272579193115, 56.01826695033482, 60.68635163988386, 56.19800295148577, 54.62607029506138, 50.8206913130624, 52.98098005567278, 24.99001090867179, 0.8468406902892249, 2.270762711763382, 3.442081562110356, 26.26367129598345, 32.59090416772025, 56.41792038508824, 55.416028363364084, 52.67916073117937, 50.37785482406616, 52.355610915592735, 50.2693760735648, 50.98142051696777, 52.85431786945888, 52.1793212209429, 51.80944081715175, 51.231034551348, 47.7042818069458, 51.158311230795725, 48.37083639417376, 45.83344112123762, 40.40263877596174, 37.26940768105643, 38.95698268072945, 36.983909675053184, 36.22293949127197, 37.53251164300101, 37.25545917238508, 37.8624016898019, 37.91265801021031, 40.625846181597026, 40.90330859592983, 42.88243348257882, 42.41154711587088, 40.03778886795044, 40.32023661477225, 39.84641810825893, 38.145780495234895, 35.63741479601179, 35.11378812789917, 36.160496030535015, 35.947061266217915, 36.77569648197719, 35.737156186785015, 36.48234006336757, 44.228195326668875, 47.83814927509853, 47.97400740214756, 48.485578945704866, 48.35910088675362, 46.37040833064488, 47.53183446611677, 48.865853854588096, 47.49163218906948, 41.71796751022339, 39.33697271347046, 36.426181248256135, 38.112929412296836, 36.848854064941406, 38.03165980747768, 36.857914515904014, 38.84393201555525, 41.79885843821934, 41.15340553011213, 41.71087687356131, 40.22692925589425, 37.14206804547991, 37.5952330316816, 37.45930889674595, 37.13218423298427, 38.090712547302246, 37.486983571733745, 36.172596318381174, 38.64290673392159, 45.06516490663801, 47.73370395387922, 47.878525257110596, 48.77495404652187, 46.45728513172695, 46.26644243512835, 45.30076095036098, 44.950707231249126, 45.26290716443743, 43.259001527513774, 42.574023791721885, 40.284811224256245, 34.43154450825283, 33.812199456351145, 34.21223851612636, 34.14281906400408, 35.591445514133994, 35.72120312282017, 35.79638957977295, 36.170411109924316, 35.39694111687796, 36.15756736482893, 36.54340083258492, 37.043612071446006, 34.612399169376914, 35.135188579559326, 35.36129338400704, 34.41751956939697, 36.67922074454171, 35.196294512067524, 35.3351959500994, 35.39031253542219, 37.41699089322771, 36.665567534310476, 40.479801995413645, 42.45904500143868, 47.09504290989467, 48.28802081516811, 49.10962445395333, 49.19026524680001, 50.29654353005545, 51.74221699578421, 51.828392028808594, 50.82595109939575, 49.041507789066856, 45.74503224236624, 54.58997440338135, 51.07168803896223, 52.47785404750279, 49.26476035799299, 54.606754302978516, 51.386667251586914, 24.196213960647583, 0.5422284613762582, 2.207739076444081, 0.6385833652956145, 3.1363343341009955, 52.600732939583914, 51.85734864643642, 54.78685508455549, 53.66192436218262, 53.51231575012207, 47.25270101002285, 39.58840717588152, 29.206686769212993, 39.8733423777989, 48.030235699244905, 5.2028610450880866, 0.5133757953132901, 0.02361575823410281, 0.20777974490608486, 0.053286125151706595, 0.15230848932904856, 0.0959452994699989, 0.03251114028639027, 0.017830599199182222, 0.039337592731629095, 0.19140927333916935, 0.14758087801081793, 0.1247216167726687, 0.14595875862453664, 0.20951830090156623, 0.18386951434825147, 0.1882167796471289, 0.09807349741458893, 0.2305753459887845, 0.18740837302591118, 0.13312234170734882, 0.2776457273534366, 0.26212603013430325, 20.635666915348597, 72.72965730939592, 32.60580110549927, 32.19151129041399, 45.39471101760864, 59.053761209760395, 62.25061348506382, 60.404831477573936, 59.624875341142925, 61.835139002118794, 53.286947454724995, 58.85406303405762, 30.20589678628104, 1.2014534047671726, 5.418787172862461, 4.925593180315835, 32.74277094432286, 36.63489818572998, 55.91148356028965, 56.636885915483745, 55.296970980507986, 53.09875896998814, 53.76176997593471, 54.424735818590435, 54.025235244206016, 55.26019763946533, 55.450380257197786, 53.16457230704171, 54.52507128034319, 49.98455899102347, 52.59460115432739, 52.182882172720774, 47.471958364759175, 42.03852265221732, 38.91005802154541, 41.56244945526123, 39.418843337467735, 39.25859008516584, 39.27583203996931, 39.83034692491804, 40.68240451812744, 40.11428158623831, 43.147371768951416, 43.558635643550325, 45.41862671715872, 44.937905175345286, 41.386858054569785, 42.05074800763811, 41.89666822978428, 39.02485268456595, 37.326181411743164, 37.960069043295725, 37.564428193228586, 38.3426125390189, 38.614433016095845, 38.038392611912315, 38.678377287728445, 46.430631841932026, 51.29487460000174, 50.17656551088606, 50.65079396111624, 50.06348010471889, 48.57619387762887, 50.241159439086914, 50.875561237335205, 50.329543999263215, 43.36211279460362, 39.46008089610508, 35.681494167872835, 37.474334376198904, 35.97198445456368, 37.56544263022286, 38.49404157911028, 39.845907415662495, 42.271217823028564, 44.06560400554112, 44.163695199149, 42.914749554225374, 40.33794757298061, 38.03266034807478, 37.76812505722046, 36.41857297079903, 38.49938474382673, 38.72952992575509, 37.76873302459717, 39.9731775692531, 45.804519244602744, 49.68476506641933, 50.96113525118147, 49.37831129346575, 47.88438606262207, 50.2981207711356, 46.43913991110665, 46.37991694041661, 47.28690351758684, 45.419950348990305, 45.060561725071494, 42.218144008091514, 37.46879666192191, 37.07856845855713, 35.994472299303325, 36.5702417237418, 36.425215448652, 36.23385511125837, 36.52949748720442, 37.96269546236311, 37.37156009674072, 38.61223043714251, 40.490373679569785, 38.45777893066406, 37.336746147700715, 38.87514679772513, 37.55433246067592, 35.4143637248448, 39.754580293382915, 36.62446893964495, 37.61694267817906, 36.87750496183123, 39.3941216468811, 38.02317953109741, 42.24001693725586, 45.435580321720664, 48.64917080742972, 50.66192150115967, 51.05842392785208, 51.83832100459507, 52.622935908181326, 52.783685956682476, 54.85660457611084, 51.93694026129586, 47.96836199079241, 45.21874441419329, 56.6056363923209, 53.626961026872905, 55.680282252175466, 50.32491649900164, 59.545735359191895, 52.62835202898298, 31.112358774457658, 2.037075251340866, 2.729304300887244, 2.1755409070423672, 3.5981876083782742, 63.16728237697056, 54.8050593648638, 58.814263752528596, 58.263855252947124, 60.16853019169399, 53.627568994249614, 40.33916003363473, 37.36517122813633, 47.86773123059954, 55.76659277507237, 7.488051039831979, 1.0380925706454684, 0.2136258262076548, 0.36365821052874836, 0.2568709392632757, 0.18191138442073548, 0.2873791493475437, 0.11625772022775241, 0.1376074038978134, 0.1564626842737198], [0.0011256664833386562, 0.014955005109576243, 0.03420738283810871, 0.0638302777494703, 0.027274424143667732, 0.02648003605593528, 0.10173652121531111, 0.011863688622335238, 0.007177404327584165, 0.021234892508281127, 0.053414402196982076, 0.10844122751482896, 0.10374584660998412, 0.9965930432081223, 37.14272117614746, 38.23571102959769, 24.43877383640834, 22.347895860671997, 43.75457484381539, 51.21385165623256, 40.19143785749163, 46.87668882097517, 48.881007875714985, 46.79508917672293, 48.82737473079136, 33.16551324299404, 0.22993803875786917, 2.38373064994812, 0.18562092179698603, 9.649164012500218, 23.683876378195627, 55.25728981835501, 55.15980659212385, 54.0533059665135, 47.94230972017561, 41.692960943494526, 42.114848613739014, 41.97737503051758, 43.16841091428484, 44.00978912625994, 46.81451633998326, 42.99737058367048, 43.51582779203142, 41.84420933042254, 39.301724502018516, 35.95165055138724, 37.8047524860927, 33.96208252225603, 34.68346187046596, 35.53849676677159, 34.9561265536717, 35.16370051247733, 34.449008805411204, 34.18728058678763, 35.60223606654576, 36.70024946757725, 39.20639869144985, 40.644231115068706, 39.00570344924927, 39.14066178458077, 38.70152868543352, 37.56522028786795, 35.74578237533569, 35.69392796925136, 34.3392515863691, 33.10354573386056, 33.76146371023995, 32.66052859170096, 32.87596443721226, 33.22338478905814, 40.59615305491856, 43.7086055619376, 43.778375898088726, 46.150341510772705, 44.690861974443706, 45.84965474264962, 47.37667076928275, 45.59118522916521, 44.29838950293404, 39.603460448128835, 38.07793133599417, 39.90819106783186, 38.07084764753069, 36.462881633213584, 35.986044134412495, 35.507917744772776, 38.16274452209473, 37.174366746629985, 37.971978255680625, 39.98458998543875, 39.2972846031189, 37.478906290871755, 36.6717722756522, 37.30969681058611, 34.704549653189524, 36.700767108372276, 36.12652281352452, 37.80392565046038, 36.51286697387695, 40.475118909563335, 44.77728714261736, 45.655278887067524, 44.86494909014021, 44.90427589416504, 45.68061201913016, 46.543592180524556, 43.734213147844585, 44.59007487978254, 43.11599370411464, 42.086611134665354, 37.02781186785017, 31.159290381840297, 31.070356913975306, 32.05118547167097, 33.65650074822562, 33.39399085726057, 34.433239868709016, 32.77859933035714, 32.99722787312099, 32.67796857016427, 34.09073536736624, 32.29422651018415, 32.07512896401541, 34.20972326823643, 32.712337834494456, 34.328169209616526, 33.484668322971885, 34.3807601247515, 34.68743624005999, 34.11257355553763, 35.15168707711356, 35.651634284428184, 38.85071693147932, 44.0822970526559, 46.937284060886924, 50.49198940822056, 48.55170842579433, 49.861106872558594, 48.21669408253261, 49.132834911346436, 47.46619135992867, 49.77316352299282, 46.27718782424927, 48.16661146708897, 42.93579912185669, 49.00492204938616, 51.104268142155235, 50.539577620370046, 47.85033641542707, 55.165358202798025, 34.78051083428519, 2.7014917475836615, 0.07120040977107626, 0.4909210630825588, 1.3900326171091624, 11.415451679910932, 52.524174213409424, 42.87087515422276, 51.247682435171946, 49.497820309230256, 53.820256437574116, 36.1300698689052, 24.720144612448557, 26.806303024291992, 42.62945304598127, 25.490720680781774, 0.20566551121217863, 0.08015881585223333, 0.04184311721473932, 0.05111079616472125, 0.03906366814460073, 0.10283744428306818, 0.014542323503909367, 0.06315242126584053, 0.03901716474709766, 0.034664369387818236, 0.024558652192354202, 0.02417432317244155, 0.09213044667350394, 0.09439339488744736, 0.0437960292079619, 0.04822118693430509, 0.04561062862298318, 0.061281971633434296, 0.005585456849075854, 0.03896329245929207, 0.07584642725331442, 0.05209864815697074, 0.178614898451737, 2.6923472668443407, 51.4720675604684, 38.564746447971885, 19.57604057448251, 35.43047659737723, 49.780671051570344, 57.90032202856881, 44.39742912564959, 51.837129388536724, 55.925987924848286, 52.06313344410488, 53.61087247303554, 37.52786677224295, 0.1455102198358093, 1.981893309525081, 1.128293867622103, 11.179706249918256, 27.326082127434866, 55.07155752182007, 56.17443118776594, 55.811043875558035, 50.685232707432334, 44.03508404323033, 44.11427961077009, 44.340846470424104, 46.43507521493094, 47.3978454044887, 49.22565937042236, 44.870750835963655, 45.68604551042829, 43.41251850128174, 41.69876963751656, 38.91420609610421, 38.70434965406145, 35.57496091297695, 37.816699913569856, 37.73417615890503, 36.57832942690168, 36.84802028111049, 36.127895082746235, 37.33343185697283, 38.18800122397286, 38.77455425262451, 40.45344052995954, 41.189122744968955, 42.2638839994158, 42.49245194026402, 41.08349622998919, 40.63722733088902, 38.46990353720528, 37.4669623374939, 38.18597929818289, 36.907180718013215, 35.67027630124773, 34.46007033756801, 34.847592217581614, 34.22013514382498, 43.20145654678345, 47.112323079790386, 46.8774288041251, 49.67361668178013, 47.38544634410313, 48.28454671587263, 49.16928168705532, 47.39344719478062, 46.60575423921858, 39.977252687726704, 38.306249141693115, 38.81150824683053, 37.53822306224278, 37.72240938459124, 37.035843985421316, 35.22771774019514, 38.66172245570591, 38.86792761938912, 40.39315448488508, 39.90039866311209, 39.487171922411235, 37.90896504265921, 39.12550776345389, 37.28117445537022, 36.1199254989624, 37.379818030766074, 37.04702016285488, 38.00747660228184, 37.75520488194057, 39.11187539781843, 46.244830063411165, 47.8410883631025, 47.197191851479666, 46.31499992098127, 47.534488677978516, 47.517774786267964, 46.13876233782087, 48.05659369059971, 44.91821050643921, 44.268310751233784, 39.14774547304426, 34.17426661082676, 33.20522219794137, 34.34366716657366, 34.338938917432515, 36.07508182525635, 36.17890180860247, 35.11649792534964, 35.42918075834002, 35.41398852212088, 35.86791781016758, 34.262779712677, 33.89333357129778, 36.592805998665945, 34.55087634495327, 36.079872608184814, 36.524838720049175, 36.636471952710835, 36.17530958993094, 36.25945227486746, 36.319755690438406, 37.339438574654714, 40.65707833426339, 45.83618565968105, 49.98999943052019, 51.62600490025112, 50.83287845339094, 52.06658322470528, 51.177929469517295, 50.87163897923061, 48.83386434827532, 50.221273694719585, 46.99472829273769, 48.58768272399902, 45.45709541865757, 50.85310813358852, 54.1706679889134, 53.1217679296221, 50.53696509769985, 57.8009488923209, 35.3376590864999, 3.6287336264337813, 0.11826600746384688, 0.44860642509801046, 1.377170632992472, 11.502825277192251, 56.56093863078526, 49.960528646196636, 55.41144950049264, 52.81655788421631, 57.925297328404014, 43.660100187574116, 34.34416396277291, 28.10505509376526, 47.71516268593924, 32.45381620952061, 0.2602431225989546, 0.07944287998335701, 0.014696021863658513, 0.06322185575429883, 0.03304891660809517, 0.10350401672933783, 0.06563296208956412, 0.05303618338491235, 0.036174924046333344, 0.030475056863256862, 0.12052623475236551, 0.1582889069936105, 0.2456902020743915, 0.19892742777509348, 0.12590046280196734, 0.19982222547488554, 0.2250265580202852, 0.1518783795514277, 0.1350058192121131, 0.11771545772041593, 0.13709961543125765, 0.1668680323553937, 0.3885310244347368, 3.6339141598769595, 61.70814677647182, 47.794615336826865, 32.701908588409424, 35.55889320373535, 54.994387354169575, 61.02363109588623, 51.205645833696636, 54.920726026807515, 59.38835866110665, 55.631068161555696, 57.56140627179827, 42.01196663720267, 0.259271786149059, 9.032286439623151, 1.1169862172433307, 11.764656850269862, 31.800511837005615, 54.26847778047834, 59.84407711029053, 59.13815402984619, 53.330370221819194, 46.53626877920968, 46.47019835880825, 45.739744663238525, 48.6102226802281, 48.03066996165684, 51.762182644435335, 46.08689056124006, 48.23149027143206, 46.45046200071062, 44.841064657483784, 40.38902725492205, 42.012463433401926, 37.76439387457711, 38.844616413116455, 40.45149850845337, 39.41104051045009, 40.73346682957241, 38.80026606151036, 40.248100417000906, 40.50933878762381, 41.272799900599885, 44.364807333265034, 44.39274951389858, 45.2522416796003, 44.72283411026001, 43.03476926258632, 41.10118981770107, 41.20831019537789, 39.99405690601894, 38.27412761960711, 36.59616892678397, 37.62779229027884, 36.801432609558105, 36.624524525233674, 36.509858403887065, 44.81483520780291, 48.28760739735195, 48.5288280078343, 49.72549888065883, 48.745219230651855, 49.97265672683716, 51.46856566837856, 47.77221087047032, 46.61562762941633, 40.45118931361607, 39.6931790624346, 39.41090849467686, 38.76098789487566, 37.8916779245649, 38.18671580723354, 37.19782386507307, 41.21993800571987, 40.78849308831351, 40.6966552734375, 42.94357763017927, 40.333757809230256, 39.14843334470476, 38.82652677808489, 39.872154235839844, 37.385984557015554, 38.22712653023856, 37.65140226909092, 38.65770639692034, 37.685781955718994, 40.2771577835083, 46.313457420894075, 48.9843692779541, 48.8784578868321, 48.91720451627459, 50.57305751528059, 50.267357621874126, 47.54719693320138, 50.38246842793056, 49.12761681420462, 46.07096529006958, 41.184776646750315, 35.357840129307334, 35.455024582999094, 36.11635759898594, 37.387030260903494, 37.234711851392476, 38.500545092991416, 36.31190422603062, 37.48898465292794, 37.212894507816856, 39.01230076381138, 37.79654318945748, 36.35797078268868, 38.82804148537772, 35.757830551692415, 38.206021377018516, 37.75511108125959, 38.73357377733503, 37.879511628832134, 37.81615447998047, 38.43849073137556, 38.223770550319124, 41.44768953323364, 49.6020884513855, 52.03150871821812, 54.73517090933663, 52.462536743709016, 53.971761907849995, 53.008776324135916, 53.705107416425435, 51.52914006369454, 54.37664386204311, 48.50882414409092, 48.66617999758039, 45.06067289624895, 50.59687941414969, 53.82751383100237, 54.75710637228829, 54.1882712500436, 58.71420969281878, 39.847206728799, 6.123012721538544, 0.41358188592961853, 1.0824875427143914, 4.586951008864811, 15.131510700498309, 63.80031190599714, 52.86079011644636, 60.674873215811594, 59.73658152988979, 63.28415107727051, 47.18368802751814, 35.57577732631138, 35.99221413476126, 52.553217683519634, 41.24753277642386, 0.6560004906994956, 0.1956222972699574, 0.1370908623295171, 0.18877255411020347, 0.1155825914548976, 0.17232227325439453, 0.15211308481437819, 0.1516053642013243, 0.16230279446712562, 0.1309728106217725], [0.07681187401924815, 0.029925894723939042, 0.044861739700926204, 0.012317214643449655, 0.07834327327353613, 0.09607616851904563, 0.09879039001784154, 0.06267463761780943, 0.055628197334174595, 0.010817520786076784, 0.028264698505933796, 0.0681232941736068, 0.07700174847351653, 0.16382454495344842, 18.928558792386735, 47.063282694135395, 30.986745766230992, 22.39200302532741, 34.44049726213728, 47.578436034066335, 63.01431778499058, 45.28410611833845, 46.01598766871861, 49.778152329581125, 45.33860083988735, 41.566132000514436, 0.3355625995567867, 2.77853576200349, 0.3541326916643551, 0.22770546855671064, 16.3041547025953, 45.037813322884695, 53.8588467325483, 53.0056392124721, 50.532716274261475, 43.5010871887207, 38.0699964932033, 36.449770382472444, 36.83453730174473, 36.52886520113264, 36.91610220500401, 35.637786524636404, 36.20989772251674, 35.27339172363281, 35.63830763953072, 35.81212724958147, 34.580586842128206, 36.819251264844624, 35.614822728293284, 36.00108698436192, 33.63267537525722, 34.88117980957031, 33.65407930101667, 34.115015847342356, 34.237227712358745, 36.70052392142159, 36.01119313921247, 40.24793366023472, 36.760167258126394, 39.86101974759783, 39.758148193359375, 36.00170884813581, 37.06247990471976, 34.75471217291695, 34.72121838160923, 34.66394438062395, 33.222835881369456, 33.837212971278596, 34.53061887196132, 35.45799493789673, 38.36252607618059, 43.359211921691895, 46.070367744990754, 45.26856647218977, 43.368393966129844, 45.23365524836949, 44.477732930864605, 45.5703684261867, 40.03574957166399, 38.54357876096453, 37.58628722599575, 35.767221042088096, 35.333969593048096, 36.07955993924822, 35.68871682030814, 38.49457311630249, 35.82593332018171, 36.98764085769653, 38.29830387660435, 35.67693267549787, 38.212434564317974, 39.45463350840977, 37.62942859104702, 38.613001687186106, 36.27073267527989, 36.755341734204976, 36.71748447418213, 37.53272703715733, 34.97731508527483, 37.46184846333095, 42.97488273893084, 47.32122414452689, 44.98699767248971, 47.56689507620675, 44.50388595036098, 45.77571896144322, 43.86717735018049, 44.43478611537388, 42.58186135973249, 42.920961243765696, 36.45443262372698, 31.390575068337576, 31.89581332887922, 32.01992205211094, 33.84609624317714, 33.28364304133824, 31.81302206856864, 33.0631662777492, 31.618423870631627, 33.716362953186035, 33.789301667894634, 33.35627256120954, 33.422266551426475, 32.80734750202724, 32.03869955880301, 33.484918458121165, 34.546912397657124, 34.51535367965698, 33.80466760907854, 33.74296065739223, 34.73309980119978, 36.96902663367135, 38.45069176810128, 43.96848555973598, 47.45854139328003, 49.39872510092599, 48.6002311706543, 50.276119300297324, 49.618524415152415, 48.99325254985264, 49.9932998248509, 49.6733318056379, 48.07709782464163, 50.72635562079293, 48.969434125082834, 44.402487414223806, 46.56571524483817, 51.59948015213013, 52.05644927706037, 48.81098740441458, 12.028764826910836, 3.2103741211550574, 0.2257699609867164, 0.36066481258187977, 0.23108850845268794, 22.936163357325963, 46.32618999481201, 40.21831348964146, 48.910506452832905, 51.529153960091726, 45.21359232493809, 29.680209977286204, 26.05821132659912, 21.954122338976177, 43.55535609381539, 11.472941075052534, 0.3897659310272762, 0.04839303610580308, 0.045133672787674835, 0.02344027381124241, 0.10200602853936808, 0.023428396055740968, 0.054532105435750315, 0.01739734610808747, 0.07057275130812611, 0.022959777719474266, 0.05094519630074501, 0.0358538989509855, 0.06373773914362703, 0.06859612451600176, 0.02745528595655092, 0.01309908291191927, 0.005079670484909522, 0.08223380308066096, 0.06677366766546454, 0.020160947992865528, 0.04145342776817935, 0.026464375467704873, 0.028932770514594655, 0.2525492140225002, 27.841268471309117, 54.137545926230295, 30.02732113429478, 33.112095492226736, 44.90707949229649, 51.02618081229073, 58.19434894834246, 47.093295437949045, 52.27959762300764, 53.89157969611031, 49.09495333262852, 43.68422085898263, 0.3968777379819325, 3.622334769793919, 2.5937269244875227, 0.14747444300779275, 19.61116198131016, 45.90925986426217, 56.68670449938093, 55.799117292676655, 54.22927604402815, 44.252868379865376, 40.174585001809255, 38.30190304347447, 39.24971376146589, 40.40911797114781, 40.20799541473389, 39.22371360233852, 37.65908350263323, 36.86717993872506, 38.54983213969639, 37.36643232618059, 37.36332300731114, 38.526708534785676, 37.73248774664742, 36.995051111493794, 36.602957316807334, 36.40585776737758, 35.7126498903547, 37.48369707380022, 36.23132944107056, 37.96011768068586, 39.339720726013184, 42.691187790461946, 39.10463190078735, 42.131117820739746, 42.52948236465454, 37.723270961216514, 36.92893900190081, 36.47322402681623, 35.94992739813668, 36.86210427965437, 35.84868172236851, 36.00103487287249, 36.39671393803188, 36.56252227510725, 41.54744134630476, 48.285390922001426, 47.47534213747297, 47.61045333317348, 46.16337980542864, 46.505738394601, 46.91192313602993, 43.918587071555, 41.33673027583531, 38.99266862869263, 38.50676373073033, 37.63033185686384, 36.139880725315635, 35.90367324011666, 36.991250446864534, 39.8771083014352, 38.331450257982524, 39.03785971232823, 39.95806523731777, 37.14533717291695, 39.155381543295725, 39.61211095537458, 38.595745835985454, 39.13761499949864, 36.79399108886719, 35.9722067969186, 35.94619274139404, 37.58301115036011, 35.52822038105556, 37.4050851549421, 42.88341317858015, 49.00082261221749, 46.44482701165335, 48.64074264253889, 46.290556158338276, 47.94518974849156, 45.80457483019148, 46.78406238555908, 45.19312640598842, 44.64940554755074, 37.1282446043832, 34.03086274010794, 34.65981715066092, 33.502188205718994, 32.96924747739519, 35.83229439599173, 33.91505364009312, 35.24495274680001, 34.71362052645002, 34.650002820151194, 34.672709533146445, 35.16852256229946, 35.80871915817261, 34.40239681516375, 34.82346459797451, 37.05413859231131, 35.19185808726719, 36.238746643066406, 34.53639282499041, 36.74912657056536, 36.46042544501168, 38.22889832087925, 41.26376724243164, 46.68695436205183, 49.04453372955322, 50.81244032723563, 50.64805637087141, 50.7585848399571, 50.36772435052054, 49.965527875082834, 51.88805273600987, 51.88984189714704, 49.4548978124346, 51.22603532246181, 49.13945654460362, 45.813405990600586, 47.73659440449306, 53.173994064331055, 54.24038968767439, 50.294427803584504, 15.610908610480172, 3.904769923005785, 0.760089173913002, 0.5559851889099393, 0.5216334579246384, 25.608692407608032, 52.08379391261509, 46.3760780606951, 52.74002347673689, 57.194204398563926, 50.465273584638325, 37.30989136014666, 28.553559575762065, 20.229423114231654, 50.86769240243094, 14.526402507509504, 0.4165896416774818, 0.054619768767484596, 0.07195796697799649, 0.07091321982443333, 0.08249401447496243, 0.030043484842670814, 0.01372594918523516, 0.03587343736684748, 0.048508522765977044, 0.02671760643300201, 0.21195842139422894, 0.07546244428626128, 0.13533075606184347, 0.1268189006618091, 0.13801752403378487, 0.1239581291696855, 0.0977842922189406, 0.18708771094679832, 0.07366605675114052, 0.11197159771940537, 0.1298694991107498, 0.1759183867169278, 0.1162499984992402, 0.3322566955217293, 35.65157869883946, 64.17778669084821, 39.29199702399117, 34.33814682279314, 46.11976943697248, 56.95818451472691, 70.17902224404472, 53.7016715322222, 55.1799042565482, 62.005203110831125, 53.952473708561485, 51.52298048564366, 0.4991281884057181, 7.779595715659005, 2.1940079161099026, 0.3343606969075543, 23.656563009534562, 48.75619043622698, 58.62637056623186, 58.51414326259068, 56.882803508213584, 48.200094836098806, 41.06395442145211, 40.60956655229841, 41.67136594227382, 42.87361969266619, 42.77517761502947, 40.782204968588694, 40.1873835836138, 39.252065726688926, 40.53033971786499, 39.56214298520769, 39.325581141880576, 41.27628442219326, 39.6206294468471, 39.87248774937221, 39.78909199578421, 40.043607984270366, 38.011638573237825, 39.46208197729928, 39.757710456848145, 41.62097413199288, 42.57007721492222, 45.100986344473704, 40.95422152110508, 43.845742157527376, 45.11882584435599, 39.47112158366612, 39.97905574526106, 38.838974475860596, 37.41453470502581, 37.46044840131487, 37.794566426958355, 36.90290410178048, 38.67513942718506, 39.0996014050075, 43.9551728112357, 49.025387968335835, 50.0354198047093, 48.894657611846924, 48.013556548527305, 50.02494886943272, 47.014600140707834, 46.17854077475411, 41.69772393362862, 39.22217110225132, 38.48441137586321, 35.86150809696743, 36.105719906943186, 36.077951431274414, 37.422837802342, 41.38268218721662, 40.91997732434954, 39.65672186442784, 40.80364710944039, 39.31394638334002, 40.73937627247402, 43.298679215567454, 40.18851613998413, 40.97223820005144, 37.18112734385899, 36.722772053309846, 37.18695688247681, 37.76067658833095, 34.33245972224644, 38.10960469927107, 43.71814543860299, 51.15226282392229, 47.6965970993042, 52.34007821764265, 48.68911600112915, 51.29480859211513, 46.98993403570992, 49.5140061378479, 46.76626457486834, 47.334161690303254, 40.21769162586757, 35.82589857918875, 37.56329911095755, 35.83254105704171, 36.17438200541905, 37.3276127406529, 35.50894955226353, 36.67809861046927, 36.429825578417095, 37.1561416217259, 37.111322266714915, 36.95041935784476, 37.93777922221592, 36.168489933013916, 38.86577020372663, 38.30601985113961, 37.68251282828194, 38.115510668073384, 36.7619286264692, 37.736538546425955, 37.80135481698172, 40.22148881639753, 42.31127766200474, 47.967243330819265, 52.23828363418579, 53.03247662952968, 52.006912095206125, 52.54373686654227, 51.76769951411656, 51.26753691264561, 53.20340231486729, 52.2505715233939, 50.7914046560015, 51.24023744038173, 49.6063928604126, 45.163124084472656, 48.86459623064314, 53.73381042480469, 55.23207480566842, 51.23776388168335, 20.98791800226484, 5.301321361746107, 0.7837017040167535, 0.7150813490152359, 1.034635841846466, 28.889305216925486, 58.38145351409912, 49.53187690462385, 57.86679349626814, 60.729256766183035, 54.875792026519775, 40.26049600328718, 35.81821039744786, 31.52163199016026, 59.478421211242676, 21.175828559058054, 0.5854244349258286, 0.11723930255642959, 0.0744813708588481, 0.1639524216630629, 0.2090456605489765, 0.1320846445326294, 0.0986210819599884, 0.1134743152984551, 0.22942930034228734, 0.10465288508151259], [0.011534761138526457, 0.0567493814575885, 0.013850109219284994, 0.039526557948972495, 0.05275253199839166, 0.015228911036891597, 0.03810603131673165, 0.03042409209800618, 0.05148204642214945, 0.06293009248163019, 0.05395827515582953, 0.032769380536462576, 0.10814825644982712, 0.11944980679878167, 6.049089099679675, 45.20970480782645, 32.21391575677054, 21.494299241474696, 26.89750334194728, 51.135149410792756, 57.64827612468174, 52.69751787185669, 47.52478551864624, 48.37382064546858, 44.637951442173545, 47.08874436787197, 3.0003737211227417, 1.9685310551098414, 2.37486018879073, 0.16077921193625244, 14.078180296080452, 52.49595757893154, 53.70101840155465, 55.59405510766165, 50.24859748567854, 47.397654329027446, 44.84167262486049, 42.5685590335301, 36.61773266111101, 35.88615335736956, 36.26439591816494, 36.29073306492397, 36.116764068603516, 33.68286221367972, 33.923968178885325, 34.515242508479524, 35.08727032797677, 35.36053950445992, 35.35300765718733, 33.88745192119053, 33.86277886799404, 35.38912786756243, 34.20354284558977, 34.33274112428938, 33.983865124838694, 36.45996338980538, 37.49761431557791, 39.103749479566304, 40.97280100413731, 38.77607938221523, 38.615520409175325, 36.986348492758616, 35.16131033216204, 35.21108027866909, 36.28529609952654, 35.22888503755842, 35.33494234085083, 34.9409099987575, 35.444640500204905, 34.82567759922573, 37.43972192491804, 40.99730035236904, 42.04431050164359, 43.60096754346575, 45.382381439208984, 47.00761372702462, 48.76036630358015, 43.68126440048218, 38.57220533915928, 40.29033504213606, 35.229687554495676, 35.10534259251186, 36.13516984667097, 36.320586000170024, 36.00810466493879, 34.36292062486921, 34.398227896009175, 38.52050379344395, 39.09714521680559, 35.89760398864746, 36.21226358413696, 36.575630051749094, 35.567342213221956, 35.86472858701433, 36.62098789215088, 36.2664213180542, 36.751026902879985, 36.28852006367275, 36.69723742348807, 37.73236962727138, 39.49900470461164, 41.939417021615164, 43.90204341070992, 45.02941642488752, 45.41209193638393, 47.24249063219343, 42.9703004019601, 43.27637897218977, 43.28639827455793, 40.48554120744978, 33.57184737069266, 33.026917525700156, 34.15315450940813, 31.279313564300537, 32.24462332044329, 33.544447149549214, 33.495483194078716, 34.40502323423113, 33.24426065172468, 32.89347389766148, 34.18649196624756, 33.12914637156895, 33.32752091544015, 34.211297035217285, 33.190248829977854, 33.17578615461077, 34.262748445783345, 33.603135108947754, 34.75275278091431, 35.416100774492534, 34.2083648954119, 36.15665020261492, 39.57501799719674, 42.83714165006365, 46.7774372782026, 49.570838928222656, 48.142167704445974, 48.85811703545706, 48.79040336608887, 49.72885486057827, 53.10127421787807, 48.24931240081787, 48.12201792853219, 50.604386942727224, 50.46623938424246, 44.7299143246242, 45.903986181531636, 43.673124585832866, 45.53146546227591, 31.415262017931255, 1.2566072280917848, 0.009506986376696398, 0.17639834167701857, 0.5394403881260327, 0.09189099166542292, 27.130662305014475, 49.720440592084614, 45.02899258477347, 48.8362580026899, 52.21039703914097, 41.91798530306135, 27.097375222614833, 23.479955434799194, 28.16179060935974, 39.93857901436942, 2.417002316032137, 0.22666926415903227, 0.021074042389435426, 0.05030898151120969, 0.09499508581523385, 0.08332779152052742, 0.0360524518681424, 0.042297789960035255, 0.028804432401167493, 0.0226527168748102, 0.007823676702433398, 0.056723400351724455, 0.08896268558289323, 0.020219466549211314, 0.025496229828734483, 0.05079833757398384, 0.07413057503955704, 0.03466763314125793, 0.042423936405352185, 0.012903929455205798, 0.06452821886965207, 0.027377398618097817, 0.07632719645542757, 0.09756623141999755, 0.11001565267464944, 10.662772434098379, 57.331955909729004, 32.2867294039045, 21.853026049477712, 42.2213853427342, 53.37028414862496, 63.810699462890625, 55.495331627982004, 52.13552325112479, 50.89981392451695, 48.7923766544887, 49.09822940826416, 2.9011590906551907, 3.369332185813359, 0.8305205117378915, 0.39042961969971657, 16.109384536743164, 52.421101161411826, 53.28382076535906, 57.427160126822336, 51.22328730991909, 48.043742997305735, 45.24206256866455, 43.19799634388515, 38.21389716012137, 38.333611147744314, 38.96976736613682, 38.48324407849993, 38.05549212864467, 35.34107412610735, 35.12050008773804, 36.669812883649556, 37.18053674697876, 36.90951183864048, 37.72446257727486, 36.658841678074424, 35.50906419754028, 37.14832837241036, 37.111099924360005, 35.66878591264997, 37.01004532405308, 39.23752314703805, 40.16322122301374, 40.87724937711443, 42.556146076747346, 40.91721888950893, 41.70545727866036, 39.208906991141184, 36.399350779397146, 36.78804690497262, 37.43524381092617, 36.675496510096956, 36.52693360192435, 36.00127111162458, 36.678386960710796, 36.07318844114031, 40.51122522354126, 42.812697887420654, 43.671905176980154, 45.675852503095356, 47.851771218436106, 48.110080923352925, 49.39990976878575, 43.879024028778076, 38.0211124420166, 39.3075783593314, 35.84124367577689, 35.351326193128315, 36.49278667994908, 38.28931290762765, 37.00497661318098, 37.18745715277535, 37.35354341779436, 40.13926036017281, 39.77360793522426, 36.81882742473057, 37.777967180524556, 37.4666531426566, 37.80393607275826, 39.840838704790386, 37.04563052313668, 37.088890007564, 36.38253961290632, 36.01667874200003, 36.27258784430367, 37.812336444854736, 37.54216616494315, 44.04835162843977, 45.104245049612864, 46.013899735042024, 46.92824445452009, 47.51853561401367, 45.45680359431675, 46.52881683622088, 44.50938892364502, 44.56337642669678, 35.61541332517351, 33.949881485530305, 34.47991091864449, 33.22723756517683, 33.182737827301025, 35.19291768755232, 35.77100781032017, 36.701368127550396, 34.689492906842915, 34.319035802568706, 35.62293127604893, 34.38361930847168, 34.545102391924175, 35.80909088679722, 34.31576320103237, 34.98277636936733, 35.74460118157523, 35.648316519601, 36.04217515672956, 36.86393165588379, 36.53172785895211, 38.928818157741, 40.77891499655587, 45.209979261670796, 46.83307497841971, 50.81882224764143, 48.71409477506365, 50.52012613841465, 50.579647881644114, 51.39231961114066, 53.03235503605434, 51.0282096862793, 49.74163954598563, 52.42220592498779, 50.72289889199393, 45.732865946633474, 46.162052699497764, 45.82170908791678, 48.15894065584455, 34.597950390407014, 2.240447287048612, 0.029177155079586164, 0.24386996403336525, 0.2641721931951386, 0.05307420509468232, 31.585475512913295, 54.27079847880772, 50.33462313243321, 52.11195148740496, 57.67660045623779, 43.72439881733486, 39.56933784484863, 22.24227281979152, 28.659834010260447, 49.09740604673113, 3.914997237069266, 0.19879326783120632, 0.03989560975294028, 0.018149792249979715, 0.04884775295587523, 0.0333787355172847, 0.060805490772639, 0.04962401058790939, 0.03858856810256839, 0.0372577302290925, 0.05311813684446471, 0.11449327133595943, 0.20782889798283577, 0.0588829160801002, 0.11309394213770117, 0.156511267381055, 0.16946346951382502, 0.1381036979811532, 0.18692685743527754, 0.11919394481394972, 0.1383788167898144, 0.10655438447637217, 0.15375022696597235, 0.2586853419031416, 0.28981804847717285, 13.747194170951843, 67.88937541416713, 41.390075070517405, 30.64984498705183, 37.64513151986258, 61.84299741472517, 66.36278670174735, 61.968363761901855, 56.70179598672049, 56.46640144075666, 53.279075145721436, 55.91200120108468, 3.586351352078574, 4.711422775472913, 7.182726349149432, 0.26890939899853294, 19.56095950944083, 55.59553854806082, 54.53921433857509, 60.26499898093087, 54.08145659310477, 50.13198586872646, 47.45257289069039, 45.81332608631679, 39.46986395972115, 39.618517194475444, 40.970251015254426, 40.10885851723807, 40.5594596181597, 37.55519751140049, 37.314914907727925, 39.227340562003, 39.68934713091169, 38.95393589564732, 41.096030780247276, 39.51389469419207, 39.11408839906965, 41.07311909539359, 40.44353934696743, 37.15814617701939, 39.03029312406267, 40.86373165675572, 43.639474460056846, 43.91672495433262, 45.8132392338344, 44.49492972237723, 44.01325627735683, 41.37340981619698, 37.01350552695138, 39.33847352436611, 40.264793464115684, 38.22952018465315, 39.16544600895473, 38.994225025177, 39.26042788369315, 38.54286657060896, 42.69695826939174, 43.249371324266704, 46.14929233278547, 46.99612488065447, 50.10484273093087, 49.96214410236904, 51.17522314616612, 44.78054584775652, 38.211965560913086, 40.302303314208984, 36.24950245448521, 36.45451600211007, 38.06174203327724, 38.479603222438264, 39.164101532527376, 38.89587327412197, 37.880241189684185, 41.61906337738037, 42.51536362511771, 37.27409424100603, 38.61126116343907, 39.942258085523335, 38.556043829236714, 40.739567347935264, 39.46816512516567, 37.91289077486311, 37.9591657774789, 37.090331758771626, 35.9252473967416, 38.92564977918352, 38.882713385990684, 43.554588317871094, 45.34039000102452, 48.40711293901716, 49.19778667177473, 51.479641096932546, 47.919127055576865, 48.51647411073957, 46.30777032034737, 46.225632190704346, 37.48843921933855, 38.04753296715872, 36.84750264031546, 33.90960277829851, 34.01339149475098, 38.20016404560634, 37.56385496684483, 37.43945441927229, 36.37157188143049, 36.24508687428066, 39.225544452667236, 37.43252011707851, 38.05881684167044, 37.740398270743235, 36.14460550035749, 36.65431145259312, 36.75482061931065, 37.043045793260845, 37.81007828031267, 38.495684828077046, 38.820749350956504, 41.238430636269705, 42.76220532826015, 45.61021981920515, 49.37581689017159, 52.92240674155099, 50.211334296635215, 53.12198679787772, 51.21486609322684, 53.400925704411094, 56.94196741921561, 53.25982516152518, 51.28356293269566, 55.35121904100691, 52.86048786980765, 46.22456564222063, 45.69083629335676, 47.80674341746739, 48.861591134752544, 37.831628118242534, 5.156527851309095, 0.15789475957197802, 0.7324527683002608, 0.8358997745173318, 0.41447098393525394, 35.00443043027605, 62.043730872017996, 54.16041939599173, 59.746705055236816, 58.89436953408377, 52.84673738479614, 37.899508544376914, 34.03511503764561, 38.2144148009164, 59.8311882019043, 5.531011436666761, 0.446941218738045, 0.13348424514489515, 0.21737618425062724, 0.20798151407923016, 0.20295506236808641, 0.09905176170702491, 0.09843747038394213, 0.17708773325596536, 0.15279080559100422, 0.21759285405278206], [0.024022456857242754, 0.011019567310410951, 0.00995447937332626, 0.004629626196609544, 0.025402985546471815, 0.06085967857922826, 0.03548656723328999, 0.10300786513835192, 0.04793368486155357, 0.02856835989015443, 0.07062769907393626, 0.01754059672488698, 0.10295744998646633, 0.046112714002707174, 0.5073309168219566, 26.429175649370464, 50.72331925800869, 34.03175210952759, 22.288929973329815, 41.43221589497158, 53.340076855250764, 54.92846632003784, 46.46928119659424, 51.63278634207589, 43.32616628919329, 50.24262203489031, 6.308306413037436, 3.5601429641246796, 2.507201224565506, 0.11348504293709993, 5.484467191355569, 48.211017404283794, 53.541063921792166, 55.60522781099592, 53.57181664875576, 55.13410520553589, 51.58405862535749, 49.32430641991751, 47.951825278145925, 43.20168236323765, 38.624337673187256, 36.68670048032488, 35.3501102583749, 34.37159892490932, 35.6512382371085, 34.381086690085276, 34.2085142816816, 35.28866386413574, 35.34236649104527, 34.106935092381065, 33.66282360894339, 34.51393624714443, 34.20007222039359, 34.14062343324934, 33.66826752253941, 33.493176392146516, 36.868910040174214, 36.71394089290074, 42.312986918858115, 41.61206306729998, 36.10887786320278, 34.785061904362266, 36.60538223811558, 36.482152462005615, 36.08850921903338, 34.90828473227364, 35.44701331002371, 35.44125325339181, 35.651387623378206, 35.09910658427647, 36.47959899902344, 40.37221608843122, 42.5514942577907, 41.78239468165806, 46.04165084021432, 48.10614129475185, 48.871874468667166, 41.12855877195086, 35.65661266871861, 37.879289286477224, 37.222086974552695, 38.02209561211722, 37.6996887751988, 36.24687603541783, 35.30405412401472, 34.76335225786482, 37.20495966502598, 35.90086269378662, 35.74925300053188, 36.486241476876394, 35.37468951089041, 34.90496001924787, 34.21255118506295, 35.12389428274972, 35.85628652572632, 36.784162861960276, 36.27011775970459, 36.538491930280415, 37.47539397648403, 36.33486802237374, 37.299205030713765, 38.310939175742014, 41.434227398463655, 45.84186233792986, 44.26855741228376, 44.355795519692556, 42.50687640053885, 44.61543927873884, 40.748297759464805, 38.78772108895438, 32.474341188158306, 32.94139562334333, 33.50046157836914, 32.024949073791504, 32.23699072429112, 32.42266743523734, 33.26831184114729, 34.527916022709434, 33.404944692339214, 33.10016196114676, 34.16691541671753, 33.32426221030099, 33.248620646340505, 31.527732508523123, 33.00352988924299, 32.64729922158377, 33.78140156609671, 32.76227453776768, 35.66732679094587, 33.44841609682356, 36.35782834461757, 34.327404907771516, 38.16478729248047, 39.41766561780657, 43.516790117536274, 43.61406142371041, 46.094825404030935, 44.74011428015572, 46.05261857169015, 46.182813916887554, 45.58372286387852, 42.9903563771929, 46.85970742361886, 47.41402428490775, 51.0448853628976, 45.05967582975115, 47.40224014009748, 44.10584797177996, 48.95195593152727, 9.912745663097926, 0.7039905041456223, 4.065959879330226, 0.3503686136433056, 0.13755918719938823, 0.14451768595193112, 32.45700543267386, 48.07895646776472, 45.78271927152361, 48.2572090285165, 50.028367383139475, 34.15565933500017, 22.50392460823059, 20.407964025224956, 36.95114197049822, 20.86094662121364, 0.5920175154294286, 0.015555450925603509, 0.030777025302605968, 0.0941442164725491, 0.08771201662187066, 0.03483312104695609, 0.015697035738932233, 0.018176657147705555, 0.03715575320113983, 0.04886441777593323, 0.08616450216088976, 0.03013627789914608, 0.007413363183981606, 0.05072318982066853, 0.032745713235012124, 0.0077566001231649095, 0.043177032244524786, 0.003525425592670217, 0.07504048371421439, 0.0709519370325974, 0.017681041599384377, 0.027757983821045076, 0.07925291731953621, 0.027770353514435034, 0.007760372777868594, 1.3483830520084925, 39.20002024514334, 51.31809547969273, 25.175380161830358, 34.62180355616978, 53.82529388155256, 55.09813438143049, 60.093329838344026, 50.240103312901084, 56.0235857963562, 48.271362509046284, 53.888897691454204, 6.650859986032758, 3.549981006554195, 1.1368488371372223, 0.17992666949118885, 6.351965418883732, 50.32413135256086, 54.29077107565743, 57.46553155354091, 55.64077132088797, 56.72576379776001, 53.02817569460188, 50.41213376181466, 48.8878344808306, 44.601216316223145, 40.52898481913975, 37.922354221343994, 36.842798709869385, 36.368014403751914, 37.17062166758946, 36.641780376434326, 36.48403889792306, 36.54176800591605, 36.09805256979806, 35.70470462526594, 35.3783129964556, 37.68298183168684, 36.660926137651714, 37.07048422949654, 35.13479600633894, 35.70377704075405, 37.92501538140433, 40.12463787623814, 45.24936512538365, 44.34037399291992, 38.88980402265276, 38.860402720315115, 37.513515268053325, 37.5894729750497, 36.652223518916536, 36.056151458195274, 37.30081353868757, 36.40602452414376, 38.24055739811489, 37.2280832699367, 39.66307599203927, 41.45281382969448, 42.92584582737514, 44.79519265038626, 46.858873639787944, 49.37970788138253, 50.679139137268066, 42.87337303161621, 35.2399639402117, 37.81420203617641, 38.00261633736746, 39.81244489124843, 39.267039094652446, 38.28578322274344, 37.75020912715367, 37.74998331069946, 38.607092244284495, 37.674703053065706, 36.26889487675258, 35.81858907427107, 35.888116223471506, 36.018971647535054, 36.50001975468227, 36.70073584147862, 35.22553947993687, 37.89799383708409, 36.78165456226894, 36.193684101104736, 36.94290835516793, 36.323031766074045, 37.83569976261684, 38.510731152125764, 42.391518933432444, 46.22616025379726, 45.550395829336985, 45.893306800297324, 43.273238386426655, 44.64331545148577, 42.30933911459786, 40.36812359946114, 34.60410302025931, 34.29522780009678, 34.829627650124685, 33.60796410696847, 33.610364709581646, 34.125205380576, 34.94614199229649, 35.77016360419137, 35.30637829644339, 36.09015941619873, 35.42006124768938, 35.70154319490705, 35.40568195070539, 34.03120667593819, 35.688355513981406, 33.81667062214443, 35.09863063267299, 34.36406707763672, 36.63524906975882, 35.408812114170615, 38.11791474478585, 36.76438134057181, 40.5961982182094, 41.94666746684483, 45.543194021497456, 44.37073762076241, 48.493743079049246, 47.159675053187776, 48.30966097967965, 48.03650297437395, 48.209665979657856, 44.69528797694615, 48.54663971492222, 49.56965773446219, 51.91076292310442, 45.85383408410208, 47.75044911248343, 42.75903694970267, 49.912877900259836, 11.579794815608434, 1.2521963162081582, 4.709258845874241, 0.30982617342046326, 0.058596608228981495, 0.08402827036167894, 37.1791227885655, 52.261921405792236, 51.02668455668858, 52.796752044132774, 53.936551911490305, 42.225384031023296, 33.36836590085711, 17.675610985074723, 40.59430135999407, 28.403824159077235, 0.6833100052816528, 0.08700991608202457, 0.050087012350559235, 0.11140356891389404, 0.048703309813780446, 0.08013590172465358, 0.034795112907886505, 0.01919847829932613, 0.08032668541584696, 0.020083891859810268, 0.025307856633194854, 0.06970792450010777, 0.0720808089577726, 0.12273076788655349, 0.20874601948474134, 0.11071637578840766, 0.17533138607229504, 0.11857195890375546, 0.1517955439963511, 0.21448889560997486, 0.23161364027432033, 0.10758154400225196, 0.0966663718489664, 0.16804774690951618, 0.18220178383801663, 2.1103112186704363, 52.76561369214739, 61.55127729688372, 43.362359455653596, 31.401105063302175, 55.76448747089931, 61.33567469460623, 65.11816283634731, 55.101396560668945, 64.03286116463798, 51.12676640919277, 62.20154530661446, 7.593618495123727, 7.022861327443804, 12.392774871417455, 0.9842673731701714, 9.333321486200605, 52.96879638944353, 56.64764520100185, 60.188429832458496, 57.77142252240862, 59.388747760227744, 56.66018669945853, 53.30327224731445, 51.58398566927229, 47.45175300325666, 42.64659425190517, 40.07946068899972, 38.75753116607666, 38.93277168273926, 39.173148087092805, 39.33023643493652, 39.63451542173113, 38.8770922933306, 39.08579880850655, 37.83873265130179, 37.679309708731516, 40.46282754625593, 38.48453644343785, 39.25815234865461, 37.917775358472554, 37.08557571683611, 40.521525927952354, 41.93476520265852, 46.72765343529837, 47.03797735486712, 43.22637626102993, 40.692149366651265, 39.93606376647949, 39.06964424678257, 39.65986245019095, 39.22788946969168, 39.32853412628174, 38.53965997695923, 40.46775034495762, 38.51999657494681, 40.51985141209194, 44.69194936752319, 44.937450068337576, 46.067463397979736, 49.452285289764404, 51.732829979487825, 51.62588678087507, 42.798978669302805, 34.17604187556675, 40.48160852704729, 40.29540375300816, 40.79463529586792, 40.75265080588204, 39.84001186915806, 40.7586019379752, 39.48975665228707, 41.07437324523926, 40.23339108058384, 37.24033294405256, 37.86645596367972, 37.24735757282802, 36.75848926816668, 36.620675223214285, 38.45872735977173, 36.7816858291626, 39.429581778390066, 37.72045694078718, 36.78249529429844, 37.8776147706168, 38.06167949948992, 37.44309180123465, 39.42371402468, 44.622165134974885, 48.77275494166783, 48.98855904170445, 46.64086348669869, 45.834302697862896, 47.66873482295445, 43.762589590890066, 43.582450594220845, 37.449668271201, 36.59690196173531, 38.25200802939278, 35.68740013667515, 36.72306735174996, 36.95982027053833, 36.70179891586304, 38.93620409284319, 36.37680734906878, 38.52925157546997, 38.465960434504915, 38.048477922167095, 37.338684695107595, 36.44201966694423, 37.72713763373238, 35.30805628640311, 37.989883763449534, 37.757452624184744, 39.157226290021626, 35.914415155138286, 40.721345697130474, 38.68072925295149, 42.164611612047466, 44.70574501582554, 46.9416857446943, 47.39626121520996, 50.171253613063264, 48.08375767299107, 50.14674384253365, 51.081280027117046, 49.86881937299456, 45.7182434626988, 50.848789828164236, 52.08996738706316, 53.65944732938494, 46.855906758989605, 49.83317511422293, 44.208174092429026, 50.941384996686665, 15.990613767078944, 2.5108377380030493, 6.500399351119995, 0.40683434371437344, 0.37900821971041815, 0.19375654309988022, 42.53143828255789, 57.00113133021763, 56.63284206390381, 56.44666855675833, 59.164981024605886, 46.51129000527518, 33.745184080941335, 27.955182450158254, 48.7064482825143, 37.13453272410801, 0.7139528095722198, 0.14367342554032803, 0.06375228014907666, 0.22976897497262272, 0.17686539090105466, 0.16143572170819553, 0.17371510208717414, 0.06527213752269745, 0.15659555500107153, 0.1081618746476514, 0.12250157232795443], [0.029888816177845, 0.020815361091600995, 0.07579507572310311, 0.09093323270125048, 0.05260785136904035, 0.013407906251294273, 0.04870917574901666, 0.05786447572921004, 0.028044354436653, 0.04441222721444709, 0.051994252151676586, 0.05278018569307668, 0.04979084538561957, 0.040701532935989757, 0.04590624936723283, 17.750225952693395, 52.420395919254844, 26.958461625235422, 33.28119032723563, 32.980406284332275, 47.944244793483186, 60.00508771623884, 47.08190386635916, 51.260870116097585, 43.87486205782209, 52.791214329855784, 11.726250682558332, 1.9858967747007097, 1.0158907962696893, 0.37306200021079605, 1.016540995665959, 33.137244497026714, 60.00007806505476, 48.4770257132394, 57.28899867194039, 54.739280768803184, 55.835595335279194, 52.03970411845616, 51.516265051705496, 50.012726988111226, 47.19259214401245, 44.389581135341096, 41.43143769672939, 38.10654401779175, 35.565723282950266, 35.94305910382952, 36.65906402042934, 34.49000665119716, 36.21781519481114, 33.59168100357056, 35.4909085546221, 32.64478397369385, 33.82847213745117, 32.98779221943447, 35.51445599964687, 33.81887320109776, 37.69401904514858, 36.85581963402884, 38.050631863730295, 38.196040289742605, 38.054498536246165, 37.17841754640852, 35.668761593954905, 35.8726669039045, 35.44653388432094, 35.05446440832955, 34.542142459324424, 35.217184271131245, 36.29467616762434, 33.93819114140102, 36.517223494393484, 39.657569544655935, 40.366918087005615, 42.27235037939889, 46.8873473576137, 49.35203668049404, 47.58047185625349, 40.64036444255284, 38.357519899095806, 37.28779261452811, 38.094509737832205, 35.68400246756417, 34.27894817079817, 32.684628418513704, 34.3086656161717, 34.790095874241416, 33.423906326293945, 35.06400081089565, 34.83761807850429, 36.19507374082293, 34.80903318950108, 35.05610418319702, 35.08819096429007, 34.07510192053658, 33.37941353661673, 36.41928516115461, 35.18510096413748, 37.82520450864519, 36.77136080605643, 36.051933901650564, 36.886985778808594, 37.74450118201119, 37.896499974387034, 43.484126635960166, 44.40758739198957, 43.10266011101859, 42.05161305836269, 42.195892402103965, 39.028434480939595, 35.05076796667916, 32.807007040296284, 32.14612913131714, 32.989762033735005, 33.34514502116612, 32.42042664119175, 32.734196867261616, 33.26525810786656, 34.17092105320522, 34.335652419498985, 32.73477356774466, 32.77528156552996, 32.246384688786094, 33.76340920584542, 33.05334152494158, 32.78998742784773, 31.189317022051128, 34.49719108854021, 32.80083009174892, 33.325050830841064, 33.3553032875061, 34.83335535866873, 34.13629470552717, 35.3287410736084, 38.46139199393136, 40.171548639025005, 39.26393672398159, 40.59418324061802, 40.40066548756191, 41.76657363346645, 39.54011719567435, 39.998656613486155, 39.10504184450422, 45.281469276973176, 47.53775780541556, 51.68141678401402, 45.65319790158953, 45.686688218797954, 43.62731163842337, 45.01522125516619, 1.9135013222694397, 0.48867543786764145, 5.116206586360931, 0.043856710594679625, 0.2311548963189125, 1.0317736182894026, 45.12268904277256, 44.33797339030674, 48.786362988608225, 47.54442112786429, 46.95333092553275, 25.237116643360682, 22.288617304393224, 23.79920952660697, 42.95780406679426, 7.022252925804683, 0.3852002317351954, 0.01439591939561069, 0.07664134459836142, 0.02515391230450145, 0.015046965264316117, 0.02689543180167675, 0.031575498171150684, 0.08401767164468765, 0.043970602697559764, 0.07615598171417202, 0.03904281337080257, 0.03643934575042554, 0.02184456809689956, 0.02656937706550317, 0.021802057877981236, 0.06094150311712708, 0.07332362726862941, 0.01730185078590044, 0.050257921751056395, 0.020091233608712043, 0.07994414772838354, 0.09709787262337548, 0.035553070450467725, 0.054061585505093844, 0.028780877057995116, 0.07520121508943182, 24.639637572424753, 61.17376777103969, 25.558555943625315, 30.104762281690324, 48.425494398389546, 53.8932055745806, 62.555479594639365, 50.039112772260395, 57.805159500667024, 47.52429914474487, 56.43664925439017, 12.824925030980792, 3.602368686880384, 1.4924135633877345, 1.0978035437209266, 1.1934729644230433, 38.21696131569998, 59.791826656886506, 51.727566719055176, 59.13210909707205, 56.70892136437552, 55.28461708341326, 52.38648176193237, 53.85658509390694, 51.84655114582607, 49.50174256733486, 45.25286701747349, 42.6742376599993, 39.173978396824424, 36.3316718510219, 37.7384284564427, 38.1870562689645, 36.997924191611155, 39.12554250444685, 37.55277953829084, 36.14030109133039, 34.55165106909615, 36.59632526125227, 35.77449928011213, 36.297014236450195, 36.05122518539429, 39.915260859898154, 39.03935010092599, 40.88471174240112, 41.32030473436628, 41.749168395996094, 37.906234400612966, 36.81915051596505, 37.47922590800694, 37.67673887525286, 36.91026224408831, 37.74041216714041, 37.304374490465435, 37.67059319359915, 36.7670807157244, 40.27918665749686, 42.460559708731516, 43.17639092036656, 44.20931012289864, 47.02659273147583, 50.0189664704459, 47.584147453308105, 42.87690271650042, 38.09246696744646, 37.34116172790527, 39.21149172101702, 38.205611433301655, 36.94986697605678, 36.999497958592, 35.5428706577846, 35.786505767277305, 35.98443910053798, 36.08991275514875, 37.34245409284319, 36.64721734183175, 35.591007777622764, 36.68475498471941, 36.643923895699636, 35.82938657488142, 35.92526476723807, 37.42106948580061, 36.823444502694265, 39.187701089041575, 36.689097608838765, 36.00971664701189, 37.13858699798584, 37.27112736020769, 38.38884585244315, 44.18966061728341, 46.56586810520717, 43.966883999960764, 44.39786338806152, 43.49405908584595, 41.2627979687282, 38.075721808842246, 34.39150898797171, 33.20579889842442, 34.190570558820454, 35.21574946812221, 34.16243730272566, 33.8453597341265, 34.9382175718035, 35.000591550554546, 36.32520307813372, 34.98552090781075, 35.233397892543245, 34.80602461951119, 35.335598945617676, 34.529555797576904, 35.033519063677105, 33.485672337668284, 35.98776381356375, 34.360308102199006, 36.95457090650286, 35.12946673801967, 37.13519280297415, 36.259900433676584, 36.22815064021519, 39.16141605377197, 43.945007596697124, 40.899188314165386, 42.81321900231497, 42.4964645249503, 45.03520427431379, 41.30984422138759, 42.54458427429199, 40.960200445992605, 47.92698894228254, 48.509845529283794, 53.220282963344026, 45.15625579016549, 46.93212849753243, 43.567254883902415, 46.95080872944423, 3.0593304889542714, 0.8491287646549088, 8.531640938350133, 0.27472021004983355, 0.48666268587112427, 1.3172002966914858, 49.90464775902884, 49.828384331294465, 51.36777509961809, 54.58507244927542, 50.80370991570609, 34.77149207251412, 26.55691306931632, 22.47784628186907, 51.71850626809256, 9.677632519177028, 0.5082002016050475, 0.04027617968884962, 0.06996063808245317, 0.04263006855866738, 0.036423644450094016, 0.028300861029752662, 0.025738792527200918, 0.05081676658509033, 0.06247478869876691, 0.04235918041584747, 0.03640745460454907, 0.19183046716664517, 0.09818933691297259, 0.11176862075392689, 0.18859172452773365, 0.10748420136847667, 0.1621583750737565, 0.11900745624942438, 0.17713016883603164, 0.12809156094278606, 0.21684719835008892, 0.1532038977103574, 0.1318100414105824, 0.13514676450618676, 0.20867803027587278, 0.1020646607503295, 35.616521562848774, 66.74516691480363, 36.69920028959002, 43.49584477288382, 43.546399865831646, 58.101083278656006, 69.25455747331891, 55.39461401530674, 62.515305110386436, 53.82125350407192, 60.73624665396554, 15.173672369548253, 4.287471055984497, 2.461048249687467, 2.7224813870021274, 2.686621299811772, 40.55840349197388, 60.36915247780936, 51.72762925284249, 61.178819111415315, 58.16746289389474, 57.29539448874337, 56.030259541102815, 57.64534051077706, 54.44239466530936, 53.21582916804722, 46.9460700580052, 47.03850194386074, 42.23174858093262, 39.11645426068987, 40.5276438168117, 41.09558262143816, 38.620116642543245, 41.61124665396554, 39.140547139304026, 38.89952802658081, 37.048218727111816, 39.41599457604544, 38.77650669642857, 39.07219770976475, 38.37070410592215, 43.44254514149257, 40.98500551496233, 41.544161796569824, 44.042164257594514, 44.23799923488072, 40.61519806725638, 40.180973870413645, 39.81355660302298, 39.23163454873221, 38.96672405515398, 40.20220409120832, 39.032506125313894, 39.66945096424648, 38.96204096930367, 42.205602509634836, 43.36822026116507, 44.73036595753261, 47.312896728515625, 49.48920454297747, 51.50394589560372, 49.96543754850115, 43.730089391980854, 39.47602353777204, 37.96460274287632, 40.78062425340925, 39.20433855056763, 37.914474964141846, 37.21851907457624, 36.72624962670462, 38.01617922101702, 37.093906606946675, 38.35958003997803, 39.33254323686872, 39.86392409460885, 37.187418937683105, 38.470924922398154, 37.99000883102417, 37.44739621026175, 36.74218184607369, 39.15089300700596, 37.18279838562012, 41.02874442509243, 38.58069951193673, 36.78282880783081, 36.01884657996041, 38.57830238342285, 38.06167255129133, 44.64402069364275, 46.88484948022025, 47.83547421864101, 47.039683137621196, 44.760844230651855, 43.32135813576834, 39.13015958241054, 36.06370415006365, 35.72584451947893, 36.893315587724956, 37.92808648518154, 36.19203042984009, 35.96155868257795, 36.2053987639291, 37.246638434273855, 38.11098391669137, 36.62582036427089, 37.21651451928275, 36.81386988503592, 36.90960216522217, 36.47848381314959, 36.581143447331016, 35.0214569909232, 38.08784294128418, 36.065604482378276, 38.254488536289756, 37.58723912920271, 39.94878939219883, 37.95126567568098, 37.66672304698399, 42.121716908046174, 46.75034277779715, 44.00455365862165, 46.17150919778006, 43.91044725690569, 46.53426422391619, 42.61726243155343, 43.10425124849592, 43.649747371673584, 49.49949829918997, 52.5365697996957, 55.30458620616368, 47.618850231170654, 47.43425743920462, 43.392115116119385, 48.779373100825715, 5.596230702740805, 1.5577166421072823, 14.048878005572728, 0.4792383728282792, 0.4990611491458756, 1.5038500811372484, 55.694091796875, 54.49545110974993, 59.91913155147007, 56.32590191704886, 57.01719903945923, 36.7135900088719, 32.602274894714355, 31.394962855747767, 59.367465427943635, 15.717447076525007, 0.7545003252370017, 0.1693526240331786, 0.17304628368999275, 0.17788541902388844, 0.12017332868916647, 0.17151383949177607, 0.10106217954307795, 0.20195458962449006, 0.1754321620932647, 0.1414939167776278, 0.13026756846479007], [0.05477355872946126, 0.02366049574421985, 0.08152848628482648, 0.047489163000136614, 0.008989389686446105, 0.014905743467222368, 0.03664406655090196, 0.027830827947972075, 0.1498194464615413, 0.043169548003269095, 0.02721331867256335, 0.07085923557834965, 0.025478959416172335, 0.031105334471379007, 0.07307449635118246, 3.983030523572649, 47.04989698954991, 38.267412185668945, 25.114645957946777, 26.99367162159511, 35.050688062395366, 56.31279761450631, 48.7488739831107, 48.336533137730186, 45.28010048185076, 49.53960330145699, 14.856759820665632, 2.109538448708398, 0.60532125298466, 0.5103783532977104, 0.23543433525732585, 25.938662358692714, 60.27765165056501, 48.70450278690883, 55.053367137908936, 49.60660825456892, 53.08908707754952, 49.84270804268973, 51.883487769535606, 49.780233315059114, 48.598118918282644, 47.07814141682216, 43.63560778754098, 41.30553981236049, 39.108519417899, 35.600168977464946, 36.59078407287598, 34.5510778427124, 35.38918692725045, 34.0465726171221, 34.71945701326643, 33.09977286202567, 34.31260177067348, 33.85648032597133, 34.3848352432251, 35.05021905899048, 33.62243373053414, 35.62193073545183, 37.68926647731236, 36.30841623033796, 37.13856267929077, 35.90216548102242, 36.28642518179757, 34.62658044270107, 35.65540715626308, 33.725562368120464, 37.630679266793386, 35.335168157305034, 36.203408105032786, 35.58150264195034, 37.430369649614605, 38.94972876140049, 41.27029854910714, 42.74484177998134, 47.11583539417812, 47.03992632457188, 43.89979566846575, 40.81906516211373, 37.53460305077689, 36.99027075086321, 35.83972896848406, 33.336001191820415, 33.00087915148054, 33.94928394045149, 35.325642177036826, 33.208609444754465, 34.80107750211443, 33.137390409197124, 34.29597473144531, 34.60931069510323, 35.21147632598877, 35.00295046397618, 35.295730182102744, 33.744968686785015, 32.52298205239432, 34.00057206835066, 35.17536653791155, 35.63933597292219, 36.79854563304356, 36.83876180648804, 37.164753913879395, 34.24252571378435, 36.029015268598286, 36.58089331218174, 42.343110833849224, 42.76114572797503, 42.077144214085166, 39.29659673145839, 38.35350384031023, 36.926774638039724, 33.10719353812081, 32.68737990515572, 35.50683729989188, 33.47032724108015, 32.42850044795445, 31.847433022090367, 33.02716071265084, 33.67667484283447, 32.85327509471348, 32.17633295059204, 31.833484513419016, 32.233325549534385, 32.44643374851772, 31.126995154789515, 31.873367173331125, 31.43884072984968, 33.826377255576, 32.40300055912563, 34.21759557723999, 35.53764908654349, 34.53465577534267, 32.800215176173616, 33.142570291246685, 34.65264660971505, 34.97490406036377, 35.89963633673531, 36.78843947819301, 35.08946943283081, 35.66051755632673, 36.75409800665719, 42.88931219918387, 44.03249931335449, 47.947461809430806, 47.57434701919556, 50.050209045410156, 45.68850864682879, 51.07838610240391, 44.45495326178414, 44.64214468002319, 2.033182523080281, 0.05933216054524694, 0.722301395876067, 0.2230467421135732, 0.378801945064749, 3.999953729765756, 53.188237871442524, 41.39173568998064, 50.11202369417463, 40.9683506829398, 39.90816674913679, 24.519657816205704, 21.755721739360265, 29.411908762795584, 35.02621303285871, 0.9141338850770677, 0.0941910557448864, 0.03224626735651067, 0.042086226133895774, 0.030103609830673252, 0.040458196707602055, 0.03208036215177604, 0.06972109486481973, 0.024268144209470068, 0.06148954228098903, 0.056053479335137775, 0.017136700451374054, 0.020605963488508548, 0.025000777128817778, 0.03906175806852324, 0.021850640985316465, 0.03925397346860596, 0.037543071167809625, 0.013854447602560478, 0.05359245317855051, 0.06519526629043476, 0.02681911357545427, 0.040510074102452824, 0.03579037110986454, 0.008863724152823644, 0.08236412251634256, 0.06638203760875122, 7.514578393527439, 56.87324973515102, 35.08906296321324, 23.92213531902858, 39.25366381236485, 40.23180341720581, 61.53602600097656, 53.98225368772234, 54.28101927893502, 49.198227882385254, 54.531748499189106, 17.052859578813823, 2.1527660148484364, 1.2888849760804857, 0.2182792057948453, 0.20585581314350876, 28.832085064479283, 60.628660746983115, 48.83354820523943, 57.21899904523577, 48.9121983391898, 55.53518649509975, 52.465604373386924, 53.84514141082764, 50.494539397103445, 52.38355309622628, 49.58695180075509, 45.24528305871146, 42.108178343091694, 41.309580189841135, 38.615134784153526, 39.89600740160261, 37.266378266470774, 37.70095682144165, 37.15879235948835, 35.956510816301616, 34.814115796770366, 36.5846905027117, 36.13956805637905, 36.89252349308559, 36.3921663420541, 37.24854918888637, 36.80039037976946, 39.48419809341431, 39.52360132762364, 38.75261878967285, 38.31619201387678, 36.563838958740234, 35.90827294758388, 38.02484015056065, 36.16752413340977, 40.62975801740374, 37.540741784232004, 38.870804173605784, 36.4805474281311, 39.055813857487266, 39.891980920519146, 43.29171364648001, 43.35358040673392, 47.03466306413923, 48.828458649771555, 44.73379141943795, 39.91241904667446, 39.25954893657139, 37.95897470201765, 36.68571383612496, 34.49107319968087, 36.43701001576015, 36.63735089983259, 37.88706432070051, 36.37060955592564, 36.52901806150164, 33.781585693359375, 36.19807536261422, 35.37461655480521, 36.97511672973633, 35.959946700504844, 36.38262299128941, 34.22375168119158, 35.5163563319615, 35.50926916939871, 35.45549358640398, 36.38786540712629, 37.58643313816616, 38.458928857530864, 38.16458926882063, 36.38464144298008, 37.389073031289236, 37.261851515088765, 43.366038526807515, 42.78171239580427, 43.65965550286429, 41.41850015095302, 38.92994029181344, 39.22919920512608, 34.7811987059457, 34.9622757094247, 35.92132861273629, 35.5397960799081, 33.96267659323556, 33.42387158530099, 35.15364646911621, 35.77759122848511, 34.06705938066755, 34.095237800053184, 34.21019574574062, 33.716859749385286, 35.00911699022566, 33.896098954336985, 34.47899375643049, 33.51154048102242, 36.78420107705252, 33.785563537052695, 35.37036425726754, 37.22491489137922, 37.53983504431588, 33.93510266712734, 35.75320652553013, 35.96477917262486, 37.16787018094744, 37.642751761845176, 38.99931110654558, 38.239848681858604, 38.21465451376778, 38.45760522569929, 45.25234590257917, 46.189779485974995, 49.49928985323225, 49.71393013000488, 52.232155323028564, 45.39124386651175, 52.580169745853965, 45.456195626940044, 46.59056895119803, 2.885987264769418, 0.15291165267782553, 3.2855942334447588, 0.10753058602235147, 0.470131727201598, 4.425641630377088, 57.09527942112514, 46.76945032392229, 55.47016177858625, 46.387830938611714, 45.36155768803188, 37.78118419647217, 19.507948228291102, 30.80503647668021, 45.506215708596365, 1.971486210823059, 0.0987416644181524, 0.010751466250180133, 0.03515137432675276, 0.015868223338787044, 0.056959432150636397, 0.03956117341294885, 0.06903853613351073, 0.008002375684944647, 0.04190413108361619, 0.042228219764573235, 0.028729664627462626, 0.2432234287261963, 0.11462445929646492, 0.17273858162973607, 0.18345971990908894, 0.09797971708966152, 0.14476442842611245, 0.101156638403024, 0.12880452482828073, 0.2734001066003527, 0.0844487381566848, 0.1270088633256299, 0.12710225688559668, 0.16034003693078244, 0.2873709797859192, 0.2612520498888833, 9.89302841254643, 66.85608795710972, 48.29043184007917, 34.0149895804269, 35.47181143079485, 46.58524315697806, 64.21342400142125, 59.38997759137835, 58.64852837153843, 54.217439787728445, 59.8622327532087, 20.147253717694962, 6.092203974723816, 3.1955562191350118, 0.5557492215718541, 0.5510421970060894, 31.03930194037301, 59.987237794058665, 50.457693099975586, 58.44573129926409, 51.72361319405692, 56.163310595921104, 52.63120773860386, 54.55186006001064, 52.29201405388968, 53.47582728522164, 52.9745112827846, 47.193134103502544, 44.64925616128104, 42.739175524030415, 40.2549478667123, 41.577846663338796, 39.97221176964896, 40.18828337533133, 38.60610212598528, 39.14738416671753, 37.571699483054026, 39.108755656651084, 39.098989963531494, 37.74114520209176, 39.22699662617275, 38.508142948150635, 39.52234370367867, 42.83054780960083, 43.341692038944785, 41.54010057449341, 40.02055386134556, 40.301017897469656, 38.71531738553728, 40.13609545571463, 37.196465492248535, 43.26630408423287, 39.37201247896467, 40.19189296449934, 39.32628638403756, 40.90961756025042, 41.66006817136492, 46.464552947453086, 45.58151681082589, 48.22076572690691, 50.2669164112636, 44.84546634129116, 41.61761467797415, 40.34455183574131, 39.15800796236311, 38.31681040355137, 36.42254039219448, 39.497024468013215, 36.766684668404714, 39.75377777644566, 36.121377672467915, 37.65307331085205, 35.03018045425415, 37.828275612422395, 37.990509101322715, 39.131104537418906, 38.5849518094744, 38.95736830575125, 35.92427117483956, 36.65887294496809, 36.54632602419172, 37.95418739318848, 37.93922444752285, 38.871679646628245, 40.60514749799456, 38.13910327638899, 37.062340940747944, 37.523961884634836, 36.958107539585654, 44.060920919690815, 45.481226512363975, 45.126885754721506, 42.91948127746582, 41.790510177612305, 41.240959780556814, 36.725867475782124, 37.182437079293386, 38.385680947984966, 37.78447764260428, 35.620867661067415, 34.37509734289986, 37.24853529248919, 37.473785468510215, 36.67487464632307, 36.07908051354544, 37.05705336162022, 36.87259953362601, 36.83751460484096, 34.66421883446829, 36.855010168892996, 34.83682598386492, 39.90950427736555, 33.933726923806326, 37.092826162065776, 40.21877554484776, 40.000251225062776, 36.91286087036133, 37.873629978724885, 39.45064524241856, 37.70011608941214, 39.96798379080636, 40.34359645843506, 39.29067686625889, 39.50458410808018, 39.96620852606637, 46.86032581329346, 48.23960229328701, 52.84070634841919, 51.426431792122976, 54.561073371342246, 47.10959243774414, 53.66332789829799, 44.32449388504028, 48.403840337480815, 4.277683649744306, 0.33218610073838917, 6.594769350119999, 0.5488661623426846, 0.7679298903260912, 4.633546497140612, 64.20221655709403, 48.55967453547886, 61.73931639535086, 50.45077964237758, 53.30049991607666, 36.139359610421316, 31.159669058663503, 39.935723304748535, 54.438010351998464, 3.5312388922486986, 0.278542832072292, 0.07492156366684607, 0.14291601761111192, 0.15603703925652163, 0.14131721268807138, 0.168468940736992, 0.12197418777006012, 0.11407021832253252, 0.1348452778267009, 0.08748247501041208, 0.17618359891431673], [0.01205737644340843, 0.014960234918232476, 0.054838779515453746, 0.04841922077217272, 0.012113233446143568, 0.034155295097402165, 0.03054628607683948, 0.024120925859149014, 0.06074286877576794, 0.013268500383544182, 0.03248454171365925, 0.05656140690137233, 0.025276501529983113, 0.01756489336756723, 0.013758139734688615, 0.04798380485070603, 25.339291640690394, 45.53933082308088, 25.360450642449514, 34.24489157540457, 30.931844575064524, 50.5791962487357, 52.565206800188335, 49.20497805731637, 45.21859850202288, 51.31604923520769, 21.62919156891959, 2.7843427189758847, 1.1808668694325855, 0.18193207973880426, 0.18121467823428766, 19.938126836504253, 64.09727791377476, 51.58279405321394, 58.405570711408345, 51.793852533612935, 51.91498395374843, 47.995265415736604, 52.1013902255467, 49.42001438140869, 53.03930670874459, 49.88226761136736, 48.89660658155169, 43.83985703332083, 41.58226571764265, 36.860353333609446, 37.065137590680806, 36.352228096553254, 35.074002742767334, 35.2227497782026, 35.66144861493792, 35.214387621198384, 36.39804104396275, 34.319504805973594, 35.424101625170024, 34.91476045336042, 34.927291529519216, 35.01971646717617, 36.07960857663836, 36.31365864617484, 36.99290411812918, 36.32066937855312, 36.48901728221348, 35.667285101754324, 36.71416670935494, 34.83969211578369, 35.67493854250227, 37.477429798671174, 37.28371054785592, 36.923123359680176, 40.01186513900757, 36.72554438454764, 40.52799122674124, 42.45320504052298, 45.04194402694702, 45.598776136125835, 44.059222085135325, 38.84420299530029, 38.64095776421683, 33.52223375865391, 34.788278920309885, 34.02417857306344, 34.530483382088796, 34.74894169398716, 34.16425773075649, 34.15831354686192, 34.437467847551616, 34.54470634460449, 33.845109598977224, 34.34426818575178, 34.212849957602366, 34.61031470979963, 34.12946115221296, 31.118938718523296, 33.29695231573922, 33.13637944630214, 33.47806406021118, 34.856305258614675, 35.87958036150251, 37.141008445194785, 38.68255662918091, 37.62273052760533, 37.08221278871809, 38.231472628457205, 44.52261134556362, 42.263210024152485, 40.038084166390554, 40.088694844927105, 39.46408653259277, 37.5148423739842, 35.36459725243704, 31.319745131901332, 34.256720883505686, 32.75881086077009, 32.3268587248666, 31.79019376209804, 33.147451400756836, 31.495631831032888, 32.72792264393398, 31.394347940172466, 32.686747619083945, 32.76368849618094, 32.28492634637015, 31.018947192600795, 33.392983368464876, 31.048807076045446, 35.03024646214077, 33.64126334871565, 35.73395654133388, 33.07631574358259, 34.47734703336443, 33.1051299231393, 35.43036195210048, 33.10122503553118, 35.099103110177175, 33.49411787305559, 37.55440541676113, 35.31712368556431, 40.20202691214425, 43.17565441131592, 47.76124313899449, 45.41271380015782, 50.14162996837071, 46.24291583469936, 50.372324057987754, 45.339524950299946, 52.76302201407296, 46.24182844161987, 53.583288124629426, 5.176304595811026, 0.1962413519088711, 0.35445884987711906, 0.19150341328765663, 0.12538975663483143, 10.608931711741857, 56.8551983152117, 39.241775444575715, 49.25700616836548, 47.38892044339861, 38.68338346481323, 20.504967825753347, 24.621323857988628, 42.50227321897234, 15.307984522410802, 0.4962900121297155, 0.07852963970175811, 0.059496684931218624, 0.0926274328625628, 0.1338205135294369, 0.039431634292538674, 0.04139137574072395, 0.03324388686035361, 0.05645184724458626, 0.04375254189861672, 0.061989941501191685, 0.12620695706989082, 0.024313407584226558, 0.04935776023194194, 0.05032210098579526, 0.03843298680814249, 0.04555684793740511, 0.039026752446911166, 0.021047806832939386, 0.06286891576434885, 0.033820614484804015, 0.01584759757055768, 0.011250848516023584, 0.05562220247728484, 0.025549630534702113, 0.04188734751992992, 0.015970663466889943, 0.28973255306482315, 34.68575477600098, 53.50605542319161, 17.756526231765747, 35.46126753943307, 42.136311599186485, 53.62285116740635, 60.15578024727957, 53.82547800881522, 48.88369682856968, 54.86900363649641, 22.624189240591868, 2.1634636351040433, 1.4825892448425293, 0.21737910195120744, 0.19106032992047922, 21.698279244559153, 63.7422319139753, 52.346890926361084, 60.70578575134277, 53.73461641584124, 54.276145117623464, 49.81056915010725, 53.93507889338902, 51.602016244615825, 55.15897280829293, 51.38166107450213, 50.11397613797869, 46.49986021859305, 43.55702018737793, 39.05780799048287, 40.60343129294259, 38.13782133374895, 37.63385806764875, 36.54394279207502, 38.5017089162554, 37.70197473253523, 37.41427067347935, 37.296144349234446, 36.67268943786621, 36.28047404970442, 37.41891207013811, 37.25539663859776, 39.06118828909737, 37.57329409463065, 40.9153984614781, 38.07175438744681, 37.53449535369873, 38.1964293888637, 37.44183070319039, 37.41462503160749, 37.771078041621614, 38.71856566837856, 40.29663011005947, 38.792907919202534, 40.974340030125205, 41.470253808157786, 41.42426715578352, 44.59432370322091, 47.74856267656599, 49.30554975782122, 45.32262693132673, 40.430150168282644, 40.467274393354145, 36.87505919592721, 36.32763147354126, 35.542912346976145, 36.62698418753487, 35.86947420665196, 35.61133820669991, 35.874737467084614, 36.6591717175075, 36.24588244301932, 35.00057765415737, 35.488827569144114, 37.53702449798584, 36.60750143868582, 35.38273205075945, 32.52864483424595, 35.70819609505789, 35.17043679101126, 35.154087679726736, 36.751867634909495, 37.77011571611677, 37.48794937133789, 39.18080152784075, 38.48501239504133, 36.10789469310215, 37.36500447137015, 45.05911997386387, 43.22422579356602, 40.54650470188686, 40.6307828766959, 40.7625207219805, 38.20781053815569, 36.415814535958425, 33.73600203650338, 37.326250893729075, 34.14776965550014, 34.96271344593593, 33.794498920440674, 35.2822402545384, 34.39269018173218, 34.85332795551845, 32.5787969316755, 34.15930019106184, 33.827290943690706, 33.48710366657802, 32.70433003561837, 34.35145957129342, 33.57899359294346, 37.542492730276926, 34.383966718401226, 36.38265773228237, 33.431632723127095, 35.79274524961199, 34.8698160307748, 37.7336619922093, 35.26754134041922, 37.34793274743216, 35.02541399002075, 38.704985414232524, 37.358622550964355, 42.231032916477744, 43.85830797467913, 50.20019286019461, 47.07533087049212, 53.160813331604004, 48.56939853940691, 52.06467247009277, 47.09612682887486, 55.11210026059832, 48.50984900338309, 55.462695939200266, 6.208230640207018, 0.13716187780456884, 0.7763216857399259, 0.12073704201195921, 0.17378394625016622, 10.980459707123892, 63.59134483337402, 43.773189067840576, 54.36036075864519, 49.36669390542166, 46.09481150763375, 26.89456946509225, 20.45353725978306, 47.76197617394583, 20.646320240838186, 0.45475330097334726, 0.12475652061402798, 0.09486809798649379, 0.09554615124527897, 0.03698860966999616, 0.047322887993816815, 0.03464666980185679, 0.059339414084596295, 0.07439483050256968, 0.02405457022333784, 0.03516510109018002, 0.03584528834159885, 0.08889315609953233, 0.13487567619553634, 0.10908601898699999, 0.1315980399293559, 0.11316211455102478, 0.15668594943625586, 0.16565443176243985, 0.15751605560736998, 0.17145464409674915, 0.15582355856895447, 0.10152919484036309, 0.09269947971084289, 0.06851269863545895, 0.14117154479026794, 0.11382837487118584, 0.4016087826873575, 41.869049140385215, 59.29841423034668, 32.5019394329616, 43.401512554713655, 42.29533849443708, 58.849567549569265, 62.25113459995815, 57.1804643358503, 53.701001031058176, 60.03918947492327, 27.574653932026454, 5.6376827870096475, 4.774352175848825, 0.4234792962670326, 0.4260048578892435, 24.043379647391184, 65.11933013371059, 53.371875286102295, 61.50075694492885, 55.77119248253958, 56.07648243222918, 52.79753719057356, 55.96030855178833, 51.649479389190674, 56.094453947884695, 53.04174552645002, 51.38400609152657, 48.37348713193621, 44.74330350330898, 41.87935331889561, 42.82317229679653, 39.63459880011422, 40.92080068588257, 39.448609420231406, 40.36021654946463, 40.14620508466448, 41.00766706466675, 40.10844509942191, 40.93465191977364, 39.9513498033796, 39.44461073194231, 40.19013854435512, 42.724202156066895, 41.029359340667725, 44.79335832595825, 40.56913151059832, 39.15638555799212, 40.43107080459595, 40.094493116651265, 39.24245636803763, 39.2940536907741, 41.773865767887656, 42.44569056374686, 41.44888809749058, 43.42171791621617, 41.627984864371165, 43.49774163109915, 46.479258809770855, 47.909368310655864, 49.943738324301584, 46.119453293936594, 41.87433671951294, 42.29041569573538, 36.85347809110369, 38.23179571969168, 37.46240431921822, 36.91656078611101, 38.344109875815256, 36.79302181516375, 36.390759331839426, 39.77753019332886, 37.3716538974217, 35.63841186250959, 36.84295851843697, 39.34880896977016, 38.27409635271345, 36.35616077695574, 34.51993254252842, 36.96319709505354, 36.0476781300136, 37.00116900035313, 38.247707094464985, 39.95214537211827, 39.95494549615042, 40.25562531607491, 39.74448108673096, 38.04659148624965, 38.324891158512656, 48.29018170492989, 46.56163665226528, 42.73391226359776, 43.96764830180577, 45.4998059953962, 39.92825051716396, 38.507371698107036, 36.47438437598092, 38.34297384534563, 35.87673854827881, 36.84165225710188, 35.69963591439383, 37.30104282924107, 35.64048589978899, 37.53015620367867, 35.58618572780064, 37.03938409260341, 37.34872831617083, 36.22817843300955, 34.54338618687221, 36.71018539156233, 34.747586795261924, 40.02066503252302, 36.17263453347342, 39.57060241699219, 35.45062984739031, 38.22072376523699, 36.259514808654785, 39.396661213466096, 37.35734060832432, 39.06748683112008, 37.9603921345302, 41.12293420519148, 39.189389501299175, 45.3015148299081, 45.90010561261858, 52.849739006587434, 50.149012429373606, 55.129171984536306, 48.54809883662632, 53.57155956540789, 49.78211627687727, 58.12031241825649, 52.42478718076433, 58.07132761819022, 7.874430809702192, 0.2664383373090199, 1.8894390591553278, 0.2664432499025549, 0.4314954275531428, 12.051607029778616, 69.38764326913017, 47.257380621773855, 59.41736044202532, 55.85601609093802, 51.906409876687185, 30.141625949314662, 34.1062194279262, 55.604494776044575, 28.82630068915231, 0.7741080873778888, 0.20779170069311345, 0.14059801985110554, 0.2573301989052977, 0.2401861431343215, 0.16183472744056157, 0.10324877899672304, 0.14764969503240927, 0.23800212889909744, 0.14767504510070595, 0.14819824988288538, 0.21900973016662256], [0.03209498118875282, 0.06024320237338543, 0.04569646330284221, 0.033751580332006724, 0.02661412475364549, 0.03102182038128376, 0.017116553050332835, 0.03440383568938289, 0.003213886416883075, 0.027288992290518115, 0.01483360501671476, 0.05834791835929666, 0.04444879007392696, 0.026969161416803087, 0.06805634312331676, 0.12093885189720563, 7.758151837757655, 53.12102794647217, 35.25554180145264, 24.68178187097822, 24.255624532699585, 47.51458903721401, 44.93507031032017, 48.85070330756051, 46.62329496656145, 50.90265226364136, 28.336235557283672, 0.19850334338843822, 1.398585306746619, 0.4030860891299588, 0.1058013259566256, 13.643413271222796, 67.73242950439453, 49.821491718292236, 54.621939590999055, 50.613718373434885, 55.153250966753276, 51.60791873931885, 53.83278056553432, 47.08012165342058, 50.37554802213396, 48.705875056130544, 48.400564261845176, 43.92375653130667, 41.75757919039045, 38.95947013582502, 39.937627111162456, 36.708656787872314, 36.28454916817801, 35.54265873772757, 35.32957138334002, 34.622460160936626, 34.60583312170846, 33.11104284014021, 34.24981090000698, 34.016226359776084, 34.57131447110857, 34.571418694087434, 35.67494549070086, 35.48285559245518, 36.20325871876308, 36.52846220561436, 36.75746093477522, 36.408765588487896, 36.00313670294625, 35.99931866782052, 36.17290898731777, 36.3299104826791, 37.0967310496739, 38.91911499840872, 41.010613100869314, 37.666281836373464, 39.30417026792254, 42.80891806738717, 42.895464829036165, 40.96459518160139, 36.00496755327497, 35.72318683351789, 36.376925468444824, 35.432324818202424, 34.110951151166645, 34.508624349321636, 34.66171400887625, 35.47221095221383, 35.5811448097229, 34.81657893317086, 35.05617366518293, 33.37048510142735, 34.05471937997, 34.984100001198904, 36.50162478855678, 34.30058486121041, 35.63944019590105, 34.1676276070731, 33.787286690303254, 34.120501450129915, 33.63695893968855, 33.43915414810181, 34.71197032928467, 32.65837812423706, 34.107880047389436, 36.34153134482247, 37.365963322775706, 38.97701433726719, 41.72091007232666, 42.07667868477957, 39.73527819769723, 36.46249253409249, 34.93225254331316, 37.305197851998464, 34.275463649204795, 33.07297713415963, 33.50749315534319, 33.399594579424175, 34.666862624032156, 30.938938685825892, 31.77054078238351, 33.24405567986624, 33.31330837522234, 31.547593934195383, 32.15773262296404, 32.75562858581543, 31.272167342049734, 32.277078356061665, 33.11658750261579, 31.834050791604177, 33.00206381934029, 32.61141872406006, 33.77812549046108, 33.97603103092739, 34.10271406173706, 33.6240040234157, 35.17236144202096, 34.005484444754465, 35.580179010118755, 34.718251500810894, 36.42393003191267, 37.42689902441842, 42.21213034221104, 43.19697148459298, 49.20713894707816, 46.74432563781738, 47.508967944553916, 47.42931032180786, 50.97438199179513, 42.63039800098964, 48.04285710198538, 44.94986997331892, 53.85147469384329, 11.921145047460284, 0.24487878275769098, 0.07000271403895957, 0.13911837924804005, 0.09970228680010353, 14.952856881277901, 50.463995116097585, 41.65617370605469, 53.91546412876674, 41.36933817182268, 33.84602676119123, 25.99494276727949, 27.238269056592667, 38.75992829459054, 2.510667941399983, 0.36488809596214977, 0.025879965130505816, 0.10519538739962236, 0.015601323285539235, 0.06587035435118846, 0.018735658044793775, 0.02827694945569549, 0.03171141891341124, 0.07230961096606084, 0.02370790159329772, 0.0406187245223139, 0.04736921497221504, 0.015337339236534067, 0.08786040544509888, 0.003961980816841657, 0.07025489836399045, 0.027436117342274104, 0.01798016019165516, 0.02881116686122758, 0.056527473365089724, 0.02165943999508662, 0.011509834306447633, 0.06413915367530924, 0.053639597791646204, 0.07004670346421854, 0.02478345762938261, 0.08925838435867003, 0.05393635508205209, 12.336848820958819, 59.98733506883894, 31.10752977643694, 24.784839289528982, 36.18539490018572, 56.51789454051426, 50.775753838675364, 53.57489122663225, 51.66817351749965, 55.5406026159014, 31.18615559169224, 0.29225108506424086, 1.9206369050911494, 0.16671297353293213, 0.10121124011597463, 15.020751203809466, 70.44766044616699, 52.15492956978934, 58.26647472381592, 53.13331583568028, 55.97390617643084, 54.08526768003191, 55.17600284303938, 49.3667425428118, 53.89014489310128, 50.54718937192644, 51.031336375645225, 46.67674398422241, 44.84610210146223, 39.58997399466378, 40.67327805927822, 40.11519527435303, 37.36806167875017, 38.23175403050014, 38.80440023967198, 36.448648248400005, 36.98178700038365, 34.87434278215681, 37.30456904002598, 36.30630397796631, 37.06989710671561, 35.52392292022705, 37.8540985924857, 38.1566162109375, 37.356041295187815, 37.5949273109436, 38.63042082105364, 37.42299066271101, 37.19773701259068, 36.85195296151297, 38.73775659288679, 37.837415967668804, 40.14046239852905, 40.46540185383388, 42.741412843976704, 39.98935297557286, 39.833643845149446, 46.04998867852347, 45.736701352255686, 43.627641677856445, 40.04402835028512, 38.2340851511274, 38.317637239183696, 35.41751820700509, 36.17424304144723, 37.04427562441145, 34.75843988146101, 35.67065150397164, 37.92438309533255, 35.38600812639509, 37.672069685799734, 35.07083783830915, 37.170242990766255, 37.42106948580061, 36.71479899542672, 35.83087001528059, 36.944766998291016, 35.28880977630615, 36.675315856933594, 35.32577766690935, 35.2382755279541, 34.307081426892964, 36.034330640520366, 34.70003679820469, 36.41177415847778, 37.98377629688808, 37.68857513155256, 39.66555997303554, 43.14312294551304, 43.72768184116909, 41.380952085767476, 38.75899028778076, 37.968865462711875, 39.30611228942871, 35.91013853890555, 36.38768475396292, 36.13148382731846, 35.17178126743862, 36.04309926714216, 32.3446113722665, 34.106396606990266, 35.18722711290632, 34.01852968760899, 34.4125794001988, 34.2647773197719, 34.25709956032889, 33.6146239553179, 33.98779433114188, 35.757695061819895, 34.34758595057896, 34.77223552976336, 36.54093769618443, 35.77039636884417, 34.86208268574306, 35.23321376528059, 34.45395939690726, 36.27490159443447, 35.43089001519339, 37.7364308493478, 36.37495218004499, 38.75198997770037, 39.004112311771934, 42.57150159563337, 45.804668630872456, 50.14534725461687, 48.88874469484602, 49.61218418393816, 47.61114815303257, 52.904956340789795, 45.6715897832598, 51.6922663961138, 47.99221168245588, 54.85425608498709, 13.401717577661787, 0.3131930099001953, 0.3526523182434695, 0.09387629692043577, 0.11034279476319041, 17.6841972214835, 56.746090752737864, 44.727263586861746, 60.495422090802876, 46.375643798283164, 46.24745995657784, 28.767555407115392, 24.694778476442607, 49.20233079365322, 4.412582491125379, 0.427597949547427, 0.13184083332972868, 0.030909312489841665, 0.023536010013361062, 0.057691537509007115, 0.03728214731173856, 0.0548143556474575, 0.06801890834633793, 0.05662239023617335, 0.04935895784624985, 0.06735904661140271, 0.07222951669245958, 0.08987217356583901, 0.24489400908350945, 0.12099612025277955, 0.15762288416070597, 0.25411885551043917, 0.15641977371914045, 0.08550626212464911, 0.11312328877725772, 0.10759053459124905, 0.11323982716671058, 0.21131793861942633, 0.11523622646927834, 0.15188683409776005, 0.16421843453177384, 0.1323539007987295, 0.20042640662619046, 16.02961574281965, 69.94871725354875, 43.62537656511579, 34.21807500294277, 34.381934370313374, 60.230688776288716, 56.78230128969465, 61.14475209372384, 55.56992401395525, 59.78451715196882, 35.435653005327495, 0.9474953349147524, 4.2216920256614685, 0.558762785579477, 0.15095322419490131, 16.470498050962174, 71.469573702131, 53.504009178706575, 59.381924629211426, 55.76966735294887, 57.646080493927, 56.229179518563406, 58.000942366463796, 51.861792019435335, 55.96367495400565, 53.01081214632307, 51.83495807647705, 49.326102529253276, 46.18805285862514, 42.42999805722918, 43.875480447496685, 42.82710150309971, 40.39820235116141, 40.70597628184727, 40.87166997364589, 39.63020406450544, 40.0189140864781, 36.666741779872346, 39.522750173296245, 39.287584917885916, 40.30405078615461, 38.63281447546822, 40.388791016169954, 40.256118638174875, 40.58148888179234, 41.25618328366961, 40.98462683813912, 39.53465591158186, 39.79576921463013, 38.843414374760215, 39.41021020071847, 40.52167878832136, 41.64751277651106, 42.89853245871407, 46.493770122528076, 42.202489716666086, 42.290092604500906, 48.46324743543352, 46.04871368408203, 43.65862716947283, 39.691657406943186, 40.16233532769339, 39.41252742494856, 37.311920234135215, 37.50199168069022, 39.110103607177734, 37.5785573550633, 38.72848769596645, 40.470015457698274, 37.39569466454642, 38.73157269614083, 36.358446734292166, 37.906679085322786, 39.18101692199707, 39.48509093693325, 37.69299071175711, 39.445152691432405, 37.95415265219552, 38.83459711074829, 37.81827368055071, 37.19194221496582, 36.596835953848704, 37.733578613826204, 34.731425285339355, 37.5238368170602, 39.79050595419747, 39.66277721949986, 40.94150979178292, 44.36151736123221, 45.33170475278582, 43.6192239352635, 40.725316592625205, 38.90765741893223, 42.01140035901751, 36.87118557521275, 38.34418978009905, 39.96305751800537, 36.463850906917024, 37.98567662920271, 33.08057846341814, 35.58621004649571, 37.36968755722046, 35.49561595916748, 35.458137375967844, 36.69971445628575, 36.57872200012207, 34.65243468965803, 36.566705090659006, 39.15365491594587, 36.546499729156494, 37.15531826019287, 38.336400849478586, 37.664336340767996, 36.91152681623186, 38.034682273864746, 36.43385205950056, 39.5936461176191, 37.49237189974104, 40.22974675042288, 36.920549052102224, 40.87493562698364, 40.87002672467913, 43.82970918927874, 47.011914661952424, 53.768537521362305, 48.28086764471871, 51.55455657414028, 50.98945958273751, 56.056207588740754, 47.49465812955584, 53.27496876035418, 49.424982343401226, 58.532361439296174, 15.63651272228786, 0.1983765387641532, 1.3004405902964729, 0.275113081825631, 0.27969924573387417, 20.0008100100926, 61.98344135284424, 50.8470458303179, 62.42695876530239, 50.26669406890869, 46.101110049656455, 35.57792779377529, 34.203522000994, 57.17092445918492, 8.541808758463178, 0.6891139224171638, 0.36177579153861317, 0.17767580598592758, 0.12339961342513561, 0.11613054919455733, 0.1336117418748992, 0.1765126883983612, 0.21740361063608102, 0.1909822305398328, 0.12264954724482127, 0.19862116420907633, 0.18182398911033357], [0.03836841741576791, 0.1335400478648288, 0.024145393831921474, 0.06843354074018342, 0.054782413611454625, 0.050235533488116095, 0.033995045482047966, 0.04116956603580287, 0.08880895668906824, 0.06862726927335773, 0.09566729010215827, 0.0357042921573988, 0.02947184962353536, 0.043303904722311666, 0.028512940542506318, 0.054794328686382086, 0.5851232196603502, 35.96089860371181, 39.9172272000994, 29.397696222577775, 23.84960307393755, 33.60246808188302, 43.0430827822004, 51.03591523851667, 48.169213567461284, 48.63793209620884, 33.94040414265224, 0.06410342202122722, 1.2801168922867094, 0.29844939389399117, 0.1424855278538806, 10.570547257150922, 67.54684312002999, 52.55902985164097, 55.13629041399275, 47.09660972867693, 45.47875990186419, 47.61742237636021, 52.691604954855784, 50.72082485471453, 51.293610027858186, 46.21188170569283, 44.52413994925362, 43.22371857506888, 40.36730718612671, 36.436933585575645, 36.300939968654085, 34.52921186174665, 34.827035972050254, 34.663732460566926, 35.02887419291905, 35.69749239512852, 35.800621032714844, 34.47108323233468, 36.30055781773159, 36.26359340122768, 33.89742258616856, 35.39948763166155, 36.15539952686855, 35.73971659796578, 35.2151380266462, 33.650959559849326, 35.13904135567801, 35.25885261808123, 35.00295393807547, 35.828163691929404, 37.45715842928205, 37.271096093314036, 37.440520967756, 40.13724538258144, 40.69309432165963, 37.185348374503, 40.490939957754954, 40.28689568383353, 39.601410729544504, 36.84852749960763, 37.27232592446463, 35.40204456874302, 35.063344206128804, 34.063050270080566, 33.73805522918701, 33.66572795595442, 34.27414001737322, 34.048538957323345, 34.16682856423514, 34.43531738008772, 33.787811279296875, 33.97914382389614, 32.860643659319194, 34.25398676736014, 34.41471597126552, 34.31764268875122, 33.99157762527466, 33.339808804648264, 33.44328137806484, 33.31810958044869, 33.855639593941824, 32.14604227883475, 34.49761145455496, 31.992150102342876, 34.095838819231304, 32.18216943740845, 35.77857787268502, 37.49392482212612, 38.65308237075806, 39.78568390437535, 41.23605782645089, 38.667607579912456, 35.8271700995309, 36.952347482953755, 37.73591668265206, 35.32012530735561, 32.32255778993879, 32.86954777581351, 32.966951097760884, 32.062879289899556, 33.516174929482595, 32.772672516959055, 33.3928895677839, 33.336035932813374, 33.848489897591726, 32.87422043936593, 32.22177069527762, 32.591821329934255, 32.98000676291329, 32.517051764896934, 33.360844475882395, 33.603857721601216, 34.85783038820539, 33.220914704459055, 34.71007694516863, 33.669327122824534, 33.32520021711077, 33.29569469179426, 34.934500285557334, 34.341871057237896, 35.032105105263845, 36.31803253718785, 42.36248588562012, 43.666565486363, 48.51630735397339, 45.41930069242205, 49.19598708833967, 47.20332711083548, 48.136414596012656, 38.56759868349348, 47.498250348227366, 43.786102294921875, 55.186769076756065, 19.432016577039445, 0.15112219298524515, 0.17071394169969217, 0.08448824246547051, 0.04552919763539519, 13.749654701777867, 52.61278806413923, 40.35415424619402, 48.26523419788906, 35.4097466468811, 35.544857842581614, 17.752084595816477, 32.50952686582293, 28.679900407791138, 0.2269277995718377, 0.04827202617057732, 0.05053375641416226, 0.08824225102684327, 0.044483917831842384, 0.00732767947816423, 0.019815621165824786, 0.025052447570487857, 0.03619956843821066, 0.01401261072273233, 0.03443015606275626, 0.014854254533669778, 0.13633026528571332, 0.015259434934705496, 0.01332728865755988, 0.04569698916748166, 0.05427903562252011, 0.011706209126194673, 0.02630190534650215, 0.0867162121992026, 0.04825670824253133, 0.03613013055707727, 0.018641060085168908, 0.058849253957825046, 0.03470150221671377, 0.06489291787147522, 0.024408483911039572, 0.06887647482965674, 0.06262176616915635, 1.804358041712216, 45.241207940237864, 42.35693774904524, 21.016023465565272, 27.805994204112462, 44.458517687661306, 45.9762578691755, 56.24998242514474, 51.89467784336635, 53.74816540309361, 38.18480852672032, 0.07667987181672029, 1.71809507054942, 0.29231855858649525, 0.18496240356138774, 11.725426452500479, 67.7961653300694, 52.84696667534964, 56.78354501724243, 48.7514899798802, 48.05490180424282, 49.751224585941856, 54.63631888798305, 53.654917103903635, 53.8583082471575, 48.951476505824495, 46.0624989100865, 44.790249007088796, 42.57129314967564, 39.894346782139365, 38.839547702244346, 37.90296527317592, 37.853546210697715, 36.965465681893484, 36.81946665900094, 38.04588276999337, 37.170611245291575, 36.33215822492327, 37.548440388270784, 38.238358293260845, 36.57555014746529, 37.017104693821494, 38.14667681285313, 38.39781250272478, 37.657082421439036, 37.57564605985369, 37.56040518624442, 38.05686092376709, 36.914212294987266, 37.18247182028634, 39.225721631731304, 39.11378615243094, 38.31099476133074, 41.411864621298655, 42.91763653073992, 38.31521231787545, 42.5124523299081, 42.2418338911874, 41.676604884011404, 39.71584408623831, 38.22424650192261, 37.928948061806814, 36.58865097590855, 36.06039333343506, 36.484834466661724, 36.99969598225185, 35.885385581425254, 35.768207686288015, 35.95358215059553, 35.259630816323416, 35.94481699807303, 34.52543551581246, 35.25890472957066, 36.061195850372314, 36.396998814174104, 36.65750067574637, 35.29731437138149, 36.23197214944022, 35.396155970437185, 33.95244189671108, 35.50056307656424, 34.05829422814505, 35.18364879063198, 34.15345328194754, 34.39948551995413, 33.76669570377895, 36.669587067195344, 37.54448686327253, 41.16058996745518, 41.84709978103638, 41.472970553806846, 39.76563140324184, 36.1748023714338, 39.54787138530186, 39.09697846003941, 36.05714505059378, 34.22755929401943, 36.08875240598406, 34.63436937332153, 33.93951824733189, 35.47281197139195, 34.89989825657436, 36.429832526615684, 35.204517705099924, 34.21964529582432, 33.75376510620117, 34.48711967468262, 35.01490136555263, 34.374722140175955, 34.68639401027134, 34.97840942655291, 35.97993319375174, 35.906660965510774, 35.39787564958845, 36.374319893973215, 34.80536454064505, 35.02379853384835, 34.25396244866507, 35.98533541815621, 35.88088314873831, 37.39208507537842, 38.78938865661621, 43.984858989715576, 46.08150918143136, 49.3579808643886, 46.72230679648263, 50.00286054611206, 49.55291257585798, 49.67158433369228, 42.10429777417864, 50.22878122329712, 47.9888140133449, 56.72475283486502, 21.753982952662877, 0.08441954758018255, 0.1006108723314745, 0.053189929242112806, 0.12708605346935137, 17.108676195144653, 59.20566272735596, 45.38054711478097, 54.746461732046946, 40.336828913007466, 47.33449867793492, 18.070360728672572, 34.027478967394146, 37.32044914790562, 0.8114121513707298, 0.13642030688268797, 0.07091352516519171, 0.06158294941165617, 0.01882253257956888, 0.01945918332785368, 0.004514422824805868, 0.0448956257397575, 0.015373863080250365, 0.06020462765757527, 0.020242801368502632, 0.01847412689988102, 0.03547922209171312, 0.11531002393790654, 0.1607674461390291, 0.16709798787321362, 0.16945371218025684, 0.1095577704587153, 0.20466506560998304, 0.12409520681415286, 0.20651685552937643, 0.20842199187193597, 0.19512060204786913, 0.16141993898366178, 0.12905744197113173, 0.16939637597118104, 0.10583471666489329, 0.21450747389878544, 0.1852190119347402, 2.033634807382311, 53.38308620452881, 48.49279464994158, 38.772601808820454, 32.456717082432334, 45.62890005111694, 53.752021653311594, 60.917886461530415, 57.99560962404524, 58.89151382446289, 43.02717835562569, 0.16994555507387432, 3.9806772555623735, 0.6387257490839277, 0.23180680562342915, 13.43423341001783, 70.88609872545514, 53.829987389700754, 59.686325209481375, 52.494057246616904, 48.5177560533796, 52.772204058510916, 57.567617961338584, 56.72047274453299, 56.75135053907122, 51.85331521715437, 48.82679108210972, 47.78509283065796, 45.64254631314959, 41.54045145852225, 41.37482377461025, 39.859539781297954, 40.98057951245989, 39.24702828271048, 38.55064507893154, 40.41423184531075, 40.627346992492676, 39.693064417157856, 41.37126977103097, 41.20348467145647, 39.13500942502703, 40.04446956089565, 41.37692560468401, 40.880435126168386, 39.27110031672886, 38.96905517578125, 40.51568944113595, 40.21799734660557, 38.35573768615723, 37.76859753472464, 41.52090964998518, 42.530257088797434, 40.93792104721069, 42.1834203856332, 44.789682728903635, 40.432411806924, 45.37295273372105, 43.411375522613525, 42.79416356767927, 40.87114191055298, 41.327767099652974, 39.29534952981131, 37.97695663997105, 37.51025308881487, 38.54556247166225, 37.52857896259853, 37.56966366086687, 35.99623366764614, 38.55655104773385, 37.94244841166905, 36.72814995901925, 36.42489930561611, 36.802839619772776, 37.18145043509347, 37.755145822252544, 38.92992639541626, 37.33488750457764, 37.43568502153669, 38.71933344432286, 36.70993178231375, 38.7502772467477, 34.819174085344585, 39.563216481889995, 35.65519176210676, 37.47280577250889, 35.289313520704, 38.948495456150596, 39.433653422764365, 42.720026288713726, 43.289615290505544, 43.63457250595093, 41.04893241609846, 38.04673392432076, 40.19915730612618, 41.13050079345703, 40.38505635942732, 35.54149144036429, 37.809703077588765, 37.72287143979754, 37.06589494432722, 38.567852292742046, 37.33440807887486, 38.35791942051479, 38.15021692003523, 37.797310965401785, 36.58433267048427, 37.257863249097554, 37.53916106905256, 36.56628472464425, 37.3462165423802, 37.43992689677647, 37.96101747240339, 38.93301139559065, 38.64665528706142, 38.92933232443673, 37.36229814801897, 36.46734932490757, 36.4116074017116, 38.34931755065918, 37.548718316214426, 37.97195046288626, 40.72468430655343, 45.82190363747733, 46.85880763190133, 51.690494605473106, 48.73604066031319, 51.866964953286306, 51.921021938323975, 52.84258583613804, 44.32351071493966, 53.52184520448957, 49.84689085824149, 60.382597242082866, 24.26290798187256, 0.1638813926173108, 0.9390195097242082, 0.38594040487493786, 0.43756305053830147, 19.498516048703873, 65.86336408342633, 48.182797295706614, 60.353637150355745, 44.36426189967564, 47.44937671933855, 24.737329244613647, 42.05629961831229, 46.18859134401594, 1.1852015682629176, 0.31082022722278324, 0.1670160208429609, 0.2180742203657116, 0.08473818083958966, 0.11148361569004399, 0.08881002198904753, 0.0868315767230732, 0.13311213654066834, 0.16988973878324032, 0.18065110061849865, 0.09414940048009157, 0.32958622596093584], [0.08082684714879308, 0.02043727459385991, 0.02113197062031499, 0.08572304727775709, 0.03723908408678003, 0.01655778964050114, 0.08701238594949245, 0.08762842789292336, 0.04913721599483064, 0.026454882762793983, 0.0390194548027856, 0.028466762841812203, 0.06563621905765363, 0.024268033947529535, 0.05491477204486728, 0.08725321159831115, 0.06841190225843873, 10.731557863099233, 52.27902092252459, 27.83787775039673, 20.24923242841448, 26.281675815582275, 40.66718101501465, 52.877799306597026, 48.80226394108364, 50.21877581732613, 40.17665556498936, 0.5952505448034832, 1.2987672686576843, 0.2227274099630969, 0.11040297403399434, 6.062374489648001, 64.39703709738595, 52.96527017865862, 55.21023314339774, 45.385348320007324, 40.80747209276472, 37.049365179879324, 41.896070684705464, 40.91162558964321, 42.87169851575579, 42.41690765108381, 42.8112005506243, 38.520524638039724, 38.28390720912388, 34.61929178237915, 36.515493392944336, 35.993666308266775, 36.40125111171177, 36.28579984392439, 36.778802326747346, 36.44054317474365, 35.96384463991438, 34.63836111341204, 35.555287088666645, 33.8605762890407, 34.86498703275408, 34.60258831296648, 33.79044464656285, 33.17356620516096, 37.44655895233154, 35.034026282174246, 36.75390693119594, 35.09096676962716, 35.79416963032314, 35.56784248352051, 38.585368701389854, 36.299390520368306, 35.626356737954275, 41.78368009839739, 41.12403896876744, 36.67926590783255, 37.62936953135899, 38.585594517844065, 37.31081894465855, 37.06658281598772, 36.20340463093349, 34.88778754643032, 36.00212574005127, 34.88572045734951, 34.84003952571324, 34.26950904301235, 34.77105433600289, 34.271124499184744, 35.066561222076416, 35.11481646129063, 32.87698234830584, 35.264140197208945, 35.156564712524414, 34.50882932118007, 34.11470317840576, 34.831951822553364, 34.77646698270525, 33.747042724064414, 34.030668190547395, 34.53080994742257, 33.25778532028198, 33.23856312888009, 33.029036726270405, 33.27598960059029, 33.07793467385428, 34.29425157819475, 33.793050221034456, 34.33146265574864, 36.629568917410715, 38.81173753738403, 37.04774277550833, 36.06875549043928, 33.9531158719744, 36.191127164023264, 38.06614719118391, 34.415855475834434, 32.21875517708914, 33.29232481547764, 34.67356068747384, 31.81281362261091, 33.12317786897932, 34.03501428876604, 33.38196005140032, 33.292738233293804, 30.81928375789097, 31.81494324547904, 32.10549259185791, 31.63310888835362, 32.53146580287388, 32.09099517549787, 31.704463413783483, 32.86714717320034, 32.190656661987305, 32.821789332798545, 33.62855509349278, 33.4442263330732, 34.316968713487896, 33.01641532352993, 34.81645733969552, 35.07029240471976, 34.94384561266218, 35.13554988588606, 39.220604283469065, 41.37450415747506, 43.98876735142299, 45.57027115140642, 46.177679198128835, 40.435920647212434, 39.327210494450156, 38.141587257385254, 47.81827742712838, 45.80574212755476, 52.58835819789341, 25.89664486476353, 0.14268741916332925, 0.07732147417430367, 0.24390025383659772, 0.08558214948113475, 15.757630246026174, 50.85787807192121, 40.61363124847412, 47.70185341153826, 33.23119803837368, 28.32111975124904, 24.98391386440822, 42.4968466758728, 8.995940412793841, 0.40182754237736973, 0.004840777812725199, 0.0750792823465807, 0.026615018723532557, 0.05026706161775759, 0.06618323363363743, 0.08757332406405892, 0.024367554678714702, 0.01436057620282684, 0.019449907754148756, 0.0430056817962655, 0.012607768427447548, 0.03918134986556002, 0.05256841152108141, 0.0584046778136066, 0.05717878895146506, 0.036980925260909965, 0.017567743214645555, 0.016158973897940347, 0.039389507445905886, 0.034045796508767774, 0.060657936547483714, 0.012904049047002835, 0.024399803751813512, 0.02828259825972574, 0.10745087172836065, 0.12979055834668024, 0.010005107415573937, 0.06859657913446426, 0.13340500582541737, 16.499659640448435, 57.16506365367344, 29.64520147868565, 19.71833620752607, 35.361762387411936, 45.32702514103481, 57.67446041107178, 52.84796721594674, 52.58887931278774, 44.77328150612967, 0.3991282215075833, 2.669781906264169, 0.22672398122293608, 0.19936137806091989, 7.186491404260908, 66.65551430838448, 55.327077525002615, 56.23319557734898, 46.535417624882285, 42.61766542707171, 39.987233775002615, 44.919217995234895, 43.218305928366526, 46.31645556858608, 44.80562884466988, 45.348053864070344, 41.33711590085711, 40.73521430151803, 36.502312660217285, 38.03413684027535, 38.05407122203282, 38.03732606342861, 37.117009367261616, 37.90163121904646, 38.2611449105399, 39.18588413511004, 36.62438556126186, 37.489290373665945, 36.22105652945382, 37.536694458552766, 38.05810465131487, 35.218066692352295, 36.00229597091675, 38.81934234074184, 36.722737312316895, 37.77254063742501, 36.64915241513933, 37.41974932806832, 36.58067096982683, 39.59023802621024, 38.97650017057146, 38.52824756077358, 43.79337705884661, 41.95123938151768, 38.56814759118216, 38.443451745169504, 40.09880447387695, 40.516537121364046, 37.886560576302664, 38.77526991707938, 36.966692038944785, 36.65295655386788, 37.3562011037554, 36.299637181418284, 36.392763887132915, 37.57003538949149, 35.34853301729475, 36.51212699072701, 35.765334606170654, 35.83976370947701, 35.4365736416408, 35.40048817225865, 36.19706439971924, 35.83475405829293, 35.55475902557373, 34.75190510068621, 36.145480973379954, 34.959110804966514, 35.809556416102815, 34.0993024962289, 33.698568616594585, 34.632844243730815, 33.994697366442, 34.07025555201939, 35.08045414515904, 35.64953940255301, 35.729891845158164, 39.04007966177804, 39.57388196672712, 39.891741207667756, 38.49630321775164, 36.15967614310128, 37.01447480065482, 40.73030192511422, 36.52669736317226, 34.869072573525564, 36.696632930210654, 36.51143217086792, 34.79868384769985, 35.77999530519758, 34.70383051463536, 34.06517989294869, 35.226074491228374, 33.799654483795166, 33.99974523271833, 34.826462745666504, 33.91101673671177, 33.88024663925171, 33.44308335440499, 33.732225690569194, 34.11384160178048, 34.5453907421657, 34.49732657841274, 35.52122701917376, 35.361272539411274, 36.3159932409014, 34.99765593664986, 36.11656257084438, 36.66227061407906, 36.799931798662456, 37.08697230475289, 39.87284210750035, 43.73073557444981, 46.01363917759487, 46.45864003045218, 48.898885590689524, 42.67398057665144, 41.15893629619053, 40.989108426230295, 49.80871398108346, 48.28500877107893, 53.75722932815552, 27.4460323538099, 0.12112049572169781, 0.09536426993353025, 0.28409563696810175, 0.12867609171995095, 17.978180715015956, 54.219506876809255, 44.54885469164167, 51.949276787894114, 41.525940145765034, 37.949563367026194, 19.635187114988053, 48.30169139589582, 13.36744385106223, 0.3062680714896747, 0.0743827186524868, 0.06479030302060501, 0.04210561187937856, 0.02324935102037021, 0.09809928174529757, 0.06790051077093397, 0.01373251316337181, 0.050892650548900874, 0.03892889412652169, 0.02502127567173115, 0.07599392041031804, 0.057159043582422395, 0.18419445119798183, 0.10599605872162751, 0.20218174957803317, 0.13042706490627357, 0.1796054510133607, 0.1719953143703086, 0.23533668049744197, 0.14183266860033783, 0.26869614901287214, 0.14175505776490482, 0.2332102603146008, 0.14569947682321072, 0.2184405614222799, 0.2543107180723122, 0.07069061962621552, 0.3258518949151039, 0.2384725979396275, 21.81436800956726, 68.04017911638532, 37.556236267089844, 26.69995563370841, 38.17347254071917, 49.80027191979544, 62.2767665045602, 57.48340926851545, 59.10449000767299, 46.787064007350374, 1.0531235869441713, 4.454468837806156, 0.30377279967069626, 0.28421527626258986, 7.926065479006086, 70.05025822775704, 58.37879235403878, 59.65298775264195, 48.005875314985005, 45.250966685158865, 40.38984366825649, 47.466458865574424, 44.553631578172954, 48.52074377877371, 47.628223351069856, 48.49763059616089, 43.45629562650408, 44.09527628762381, 38.15421213422503, 40.42120436259678, 40.672836848667686, 41.16781956808907, 39.91551446914673, 40.5376353263855, 40.123366355895996, 41.82703685760498, 40.31418473379952, 40.64340080533709, 39.004998207092285, 39.37274203981672, 40.341192381722585, 39.37148094177246, 37.97587966918945, 41.470844405038015, 38.3829642023359, 39.81991767883301, 37.91693115234375, 37.619659423828125, 39.656669752938406, 41.773952620370046, 41.99436337607247, 39.60828249795096, 44.994817870003835, 45.48426982334682, 39.11145503180367, 42.35520069939749, 42.48230062212263, 41.80720669882638, 39.9069299697876, 39.67901168550764, 37.91945334843227, 38.59684017726353, 38.42194707053048, 38.30486645017351, 38.60116195678711, 39.34148209435599, 36.82022053854806, 38.832182611737935, 37.937303270612446, 35.427155358450754, 37.92862844467163, 38.024819305964876, 39.030713490077424, 38.203804901668, 37.26244558606829, 38.09343276705061, 38.49007763181414, 38.06294754573277, 38.598233291081016, 37.041117668151855, 36.13763645717076, 37.04508856364659, 36.33132791519165, 36.001760959625244, 37.85689524241856, 37.50402055467878, 37.84783131735665, 40.36767544065203, 41.41361904144287, 41.49488169806344, 39.96506207329886, 36.68122182573591, 39.67092745644705, 41.51410388946533, 40.52139738627842, 37.59740086964199, 39.496663161686485, 40.87597785677229, 36.448349475860596, 37.47500140326363, 36.338456766945974, 36.94920342309134, 37.90508794784546, 33.62626913615635, 36.617253235408235, 36.31162977218628, 35.13972922733852, 36.90484264918736, 36.64643219539097, 34.93935360227312, 36.0662784576416, 36.74575669424874, 36.95385176794869, 36.37624454498291, 37.69389745167324, 38.99925899505615, 35.12527002607073, 38.32695129939488, 39.22470372063773, 37.86606339045933, 38.55017954962594, 42.618933473314556, 45.43320403780256, 48.15833963666643, 49.27577672685896, 50.73633323396955, 44.63711418424334, 44.06257111685616, 44.220917088644846, 51.292307240622385, 50.48023305620466, 55.370580196380615, 29.65074266706194, 0.15150849654206208, 0.6751641109585762, 0.664361236350877, 0.30396908628089087, 21.135900735855103, 62.27080495016915, 47.16061305999756, 59.12749549320766, 44.059263774326865, 41.18001365661621, 32.09175600324358, 56.89130462918963, 17.650644370487758, 0.5606695232646806, 0.23345730134419032, 0.1572544260748795, 0.09742627678705112, 0.12025017956537859, 0.22344145950462135, 0.1575821449181863, 0.11341783404350281, 0.2044780342174428, 0.1143214391278369, 0.09108542132058314, 0.12958561362964766, 0.11860740557312965], [0.08365171735308, 0.046365156171045134, 0.05958443986518042, 0.04617842333391309, 0.07813010471207754, 0.03191629916961704, 0.00819587690888771, 0.040456846422914944, 0.056794171554169486, 0.04193257187892284, 0.018285360154030577, 0.06797926833054849, 0.022633546564195837, 0.050517081416078975, 0.04658070299774408, 0.07399513266448464, 0.05101828809295382, 1.3428142879690443, 36.9201078414917, 35.02149173191616, 21.70040191922869, 24.64042271886553, 34.262960365840364, 48.32529442650931, 51.43119478225708, 44.446889877319336, 48.08995546613421, 0.8964683615735599, 1.5428059164966856, 0.17889722330229624, 0.04948605424059289, 1.8536113245146615, 57.353790623801096, 55.88674797330584, 53.54607357297625, 51.79186882291521, 44.38248702457973, 38.71697800500052, 38.68041658401489, 38.27888713564192, 36.93928139550345, 36.40401302065168, 35.7410888671875, 34.54285464968, 34.68024138041905, 35.13185344423567, 34.71744550977434, 36.235505308423726, 35.648222718920024, 35.93134791510445, 35.457595416477744, 36.004786900111604, 35.47025156021118, 34.554819447653635, 35.79608038493565, 35.64870909282139, 34.937623500823975, 34.797075339726035, 35.12967865807669, 35.16609764099121, 36.28435809271676, 35.715522970472065, 36.30971901757376, 34.21317304883684, 36.018947328839985, 36.98890542984009, 37.767819336482454, 35.793179512023926, 36.44067519051688, 40.88791833605085, 37.63202721732003, 37.863770484924316, 36.53738021850586, 39.7074784551348, 38.53479276384626, 36.759027753557476, 35.306201117379324, 36.2820200238909, 34.94331407546997, 34.838913917541504, 35.59696933201381, 36.19227014269148, 35.129133224487305, 34.549639565604075, 34.02427237374442, 35.08624199458531, 34.116815430777415, 34.75599758965628, 35.56034885134016, 35.695550373622346, 37.56935446602957, 36.48827035086495, 34.39179039001465, 33.7809499331883, 34.626875741141184, 33.565541880471365, 33.08679015295846, 34.215156759534565, 31.878289972032817, 33.62397970472063, 31.81868485042027, 32.55525296075003, 33.14927182878767, 34.95494883401053, 34.456822054726736, 36.80780063356672, 37.90076616832188, 36.43464068004063, 34.39656727654593, 36.786903926304404, 38.72691740308489, 34.8042563029698, 30.718545300619944, 33.74806758335659, 32.32964495250157, 31.51604563849313, 32.86916562489101, 32.761343479156494, 33.94518102918352, 32.75328356879098, 34.12865168707711, 32.46448169435774, 32.078519684927805, 32.295143672398154, 34.39653948375157, 31.977888924734934, 33.90308536802019, 32.086305141448975, 32.731775420052664, 32.29288898195539, 33.26109266281128, 32.73970678874424, 33.73113134929112, 34.25587320327759, 33.59929970332554, 35.22676236288888, 35.62862185069493, 34.98273120607649, 37.66020911080496, 33.855632645743235, 37.569872106824604, 35.51894801003592, 37.19837277276175, 35.74488953181675, 39.73221404211861, 40.71979277474539, 50.38826322555542, 44.1228015763419, 52.78992543901716, 21.724519116537913, 0.046006530057638884, 0.053780509158968925, 0.09376690350472927, 0.09391735507441418, 22.439176082611084, 49.368351050785606, 43.89878470557076, 44.648731572287424, 25.038109813417705, 21.213458265577042, 25.640831300190516, 35.47057465144566, 1.1053710005113055, 0.03489900340459176, 0.022524210823965923, 0.05689656248848353, 0.023597288510895202, 0.05164902710488864, 0.005098993465903082, 0.036876237485557795, 0.040216275224728246, 0.058508025482296944, 0.04674217736880694, 0.055684661625751426, 0.1161371852670397, 0.040849470533430576, 0.06586640527737991, 0.07705892183418785, 0.03009776764416269, 0.07833434375269072, 0.09726346909467663, 0.03131702382649694, 0.03232336250532951, 0.11179112776049546, 0.0020521138129489763, 0.03270042102251734, 0.009251910644317312, 0.015772755158000758, 0.0416721365680652, 0.007989503027472113, 0.03341328312775918, 0.054741406347602606, 0.07345072366297245, 3.028318290199552, 49.12068598611014, 35.6434006690979, 20.108232634408132, 30.796042033604213, 43.139440400259836, 51.833349568503245, 58.85227039882115, 48.03156280517578, 51.58345760617937, 0.7362085953354836, 2.460012968097414, 0.1531668904104403, 0.1432561400745596, 1.9851798074586051, 58.07778944287981, 54.009612219674246, 57.120869636535645, 53.88749415533883, 45.389267104012625, 39.227111271449495, 40.20286069597517, 39.46508012499128, 39.956842354365754, 37.024987425122944, 38.88894592012678, 36.491998059409006, 38.76081766401018, 37.71884148461478, 37.00730773380825, 38.39393193381173, 38.00841460909162, 37.91087927137102, 37.03276245934622, 36.693666049412315, 37.4557340485709, 37.57275560923985, 37.938432352883474, 37.68104328427996, 37.2926459312439, 37.56142657143729, 38.71120057787214, 36.753882612500874, 38.44220454352242, 36.18034355981009, 38.374070508139475, 36.97492218017578, 38.58801596505301, 39.06849084581648, 38.31155756541661, 38.344141142708914, 38.725162982940674, 41.858307225363596, 41.61148984091622, 39.85759775979178, 38.69024133682251, 40.66115345273699, 40.95839044025966, 37.7248968396868, 38.12478651319231, 37.85968841825213, 36.22025053841727, 36.55922882897513, 37.32049778529576, 37.90602248055594, 36.04880026408604, 35.356460911887034, 35.44979953765869, 36.71004295349121, 34.547391823359895, 37.35021175657, 37.36680058070591, 36.957166058676584, 39.34068305151803, 37.016892773764475, 35.996403898511616, 35.38968024935041, 36.78303377968924, 36.095575537000386, 34.868231841496055, 35.10040937151228, 34.51009389332363, 33.89990309306553, 33.263962268829346, 35.40781504767281, 34.68319089072091, 35.079217365809846, 37.00460141045706, 37.44310917173113, 38.188400745391846, 37.97522306442261, 36.882580620901926, 37.673803261348176, 41.62893329347883, 35.76263870511736, 33.29576417378017, 36.138466766902376, 34.84135620934622, 33.84127419335501, 35.693552766527446, 34.834147453308105, 35.54546233585903, 35.11247839246477, 37.30742127554757, 34.755083901541575, 34.200113909585134, 34.535944666181294, 36.44034515108381, 35.05808094569615, 34.39734894888741, 35.300979546138215, 35.64904955455235, 33.47500337873186, 36.245107718876426, 34.792729241507395, 35.95900174549648, 36.30170774459839, 36.436214447021484, 36.87311370032174, 38.38914115088326, 36.83521127700806, 36.905363764081685, 35.009339332580566, 38.71533823013306, 35.83842270714896, 39.99812160219465, 38.44659580503191, 42.16663006373814, 43.25950179781233, 53.91165999003819, 46.66259397779192, 54.70916380201067, 22.424732514790126, 0.07175768379654203, 0.11022859731955187, 0.08546160773507186, 0.09193396328815392, 24.74407594544547, 55.29663051877703, 48.584854807172505, 48.10352529798235, 32.887484550476074, 23.607689380645752, 26.33693310192653, 45.066231455121724, 2.1117058524063657, 0.08502715533333165, 0.04163494945636817, 0.04061273984344942, 0.04050155848796878, 0.022421419553990875, 0.05261902684079749, 0.08202828160886254, 0.01110026378384126, 0.03722888570544975, 0.0538621029949614, 0.02400375812846635, 0.07846608132656131, 0.027063820444579636, 0.13065947672086103, 0.2123350083295788, 0.1464901329683406, 0.15742689610591956, 0.16764502280524798, 0.15335404393928392, 0.13821754258658203, 0.16880295638527187, 0.1294455368603979, 0.10112272522279195, 0.14811434224247932, 0.1723998569484268, 0.11849485018423625, 0.11806803808680602, 0.0767064161066498, 0.1557745819113084, 0.15556889080575534, 3.353592996086393, 56.1354900087629, 44.26785217012678, 31.49264063153948, 36.69869654519217, 46.449544838496614, 54.87079627173287, 62.64179706573486, 51.98130798339844, 58.067877837589805, 1.5555635690689087, 5.294495190892901, 0.37296306980507715, 0.39919403940439224, 2.288542717695236, 60.388899258204866, 55.63803720474243, 59.27387319292341, 56.01564053126744, 48.57480076381138, 41.80865887233189, 42.925786767687114, 42.549156188964844, 41.81967176709856, 38.40063694545201, 41.483500548771445, 38.986922468457905, 39.679744720458984, 40.59417281832014, 39.924953596932546, 40.322352341243196, 40.40884699140276, 41.28807898930141, 39.71114362989153, 39.39964199066162, 41.70177125930786, 38.204127992902485, 40.952560901641846, 41.151366233825684, 40.64731958934239, 40.08279929842268, 41.508642605372835, 39.855964933122905, 41.79049628121512, 39.05706800733294, 41.294658933367046, 39.994873319353374, 39.55095985957554, 41.68343496322632, 40.73281022480556, 41.36726066044399, 41.15935666220528, 43.53845807484218, 41.005040645599365, 40.74374321528843, 40.29730755942208, 44.016584464481895, 42.40120472226824, 39.713314941951204, 39.12206145695278, 39.49878236225673, 35.982896600450786, 37.84859561920166, 38.60660934448242, 39.5632130077907, 37.736601080213276, 37.713206495557515, 37.015100138528005, 39.287362575531006, 35.851353304726736, 39.87156016486031, 39.67048624583653, 39.23743976865496, 41.999720437186106, 39.177831172943115, 37.641150202069966, 37.77527822766985, 39.315745966775076, 38.999380588531494, 37.31069040298462, 38.051747049604145, 35.006688594818115, 36.48717253548758, 33.91229520525251, 35.80751711981637, 37.04342794418335, 37.89555154527937, 37.80721909659249, 38.6488161768232, 42.10610430581229, 40.00549711499895, 39.46545532771519, 40.66757358823504, 42.94549880708967, 37.49106216430664, 34.630811895642964, 38.18294988359724, 36.16091292245047, 36.602547373090474, 38.16103526524135, 37.41712638310024, 39.02728802817208, 36.14125299453735, 39.711755071367534, 37.789216314043315, 35.80264643260411, 37.52147095543997, 39.04397760118757, 37.28848396028791, 36.73857225690569, 37.626631941114155, 37.54432010650635, 35.696193081992014, 37.24147939682007, 36.58495453425816, 37.22112464904785, 38.35602603639875, 35.789997237069265, 39.49128178187779, 41.25367498397827, 38.88807739530291, 39.63014153071812, 36.690553256443565, 40.444796970912385, 37.581774371010916, 42.01038244792393, 40.551104409354075, 42.48587547029768, 45.35189969199044, 56.0049854687282, 49.474880831582205, 55.19990464619228, 25.667277881077357, 0.09458103696150438, 0.29207263035433634, 0.20994405448436737, 0.32839851826429367, 29.172737870897564, 61.32085418701172, 52.06114625930786, 54.221487113407676, 35.49051250730242, 31.41920859473092, 33.06365612574986, 53.93788596561977, 2.6122558159487586, 0.2382552767438548, 0.12735304342848913, 0.0853361873222249, 0.09614224425916161, 0.11794701458087989, 0.10024718434682914, 0.2160731798836163, 0.1162958267543997, 0.12763717318219797, 0.12157439493707248, 0.16161870903202466, 0.37826560384460856, 0.16589494528514998], [0.0370938131319625, 0.056327132508158684, 0.02807406578878207, 0.04169807696182813, 0.02916260389611125, 0.030588691122829914, 0.0031481910804619213, 0.01670144059296165, 0.01563629158772528, 0.04244087263941765, 0.03527163787345801, 0.039481906952070336, 0.06741735312555518, 0.04758384238396372, 0.03824263059401086, 0.08542080063905035, 0.10470420947032315, 0.08137221288468156, 10.74924189703805, 42.09063066755022, 32.5235344341823, 30.614676679883683, 28.965872628348215, 39.93458380017962, 55.01543344770159, 42.91298123768398, 50.086454323359895, 1.8080295132739204, 1.5547217513833727, 0.29308752875242916, 0.367560194006988, 0.03819512635735529, 37.08176462990897, 63.34535081045968, 51.54413080215454, 55.93605586460659, 47.866588251931326, 44.91850233078003, 40.286412784031455, 38.94117552893502, 37.766697202410015, 38.67626850945609, 36.17946113858904, 35.739667960575645, 36.15065390723092, 35.9338492665972, 35.908651624407085, 36.46524402073452, 34.172279426029746, 35.660382066454204, 35.529655184064595, 35.24953160967146, 35.72039018358503, 35.40139838627407, 35.268017292022705, 35.65099505015782, 34.42492287499564, 35.220588888440815, 34.87063244410923, 36.23717287608555, 35.22981609616961, 34.3575496673584, 35.71319532394409, 35.58373301369803, 34.78007309777396, 36.071771008627756, 37.37935250146048, 36.12366362980434, 36.15573998859951, 38.54626076562064, 38.51453876495361, 38.245320388248985, 37.15498127256121, 37.499580655779155, 36.93450798307146, 36.805452142442974, 36.446101733616416, 36.241873332432334, 36.3420489856175, 34.169708592551096, 33.41952201298305, 33.851397718702046, 34.01266540799822, 34.56625618253435, 35.45237037113735, 37.94640193666731, 37.30026463099888, 38.58119283403669, 37.822067396981375, 38.16379370008196, 38.75222969055176, 39.75294746671404, 36.116103989737375, 34.921906675611226, 34.37515640258789, 34.267702511378694, 34.31217793055943, 33.31478486742292, 33.88465179715838, 34.17284917831421, 33.172044549669536, 32.99542828968593, 32.10759789603097, 33.40222099849156, 35.05149752753121, 34.635151045663015, 36.456951345716206, 35.113569259643555, 34.87847696031843, 35.747314453125, 37.067871706826345, 34.73795311791556, 32.03230026790074, 33.43256378173828, 34.06081295013428, 31.72569363457816, 32.15483522415161, 33.497404370989116, 33.05427605765206, 33.38244989940098, 34.09403576169695, 32.337086473192485, 34.152317251477925, 33.02753244127546, 32.00822475978306, 31.726864406040736, 34.40203550883702, 32.98928608213152, 32.88095324380057, 33.399080412728445, 35.648445061274934, 34.408889906747, 36.147155489240376, 34.38880613871983, 35.76266997201102, 34.78960950034005, 35.91896969931466, 33.593789781842915, 36.77368150438581, 34.82399960926601, 35.806624276297434, 34.46895013536726, 38.82624190194266, 37.06243821552822, 40.44786460059029, 42.752860001155305, 50.18219007764544, 46.46860722133091, 53.46716635567801, 11.0147716488157, 0.4873939294900213, 0.11143928699727569, 0.03916661887030516, 0.22555102487759932, 31.191919122423442, 47.03972135271345, 45.85201713017055, 36.873096329825266, 24.469130516052246, 26.079113245010376, 37.960284437452046, 20.29999075617109, 0.3681101602103029, 0.07112722976931504, 0.097987011341112, 0.08324775152972766, 0.06102244555950165, 0.029126583864646297, 0.09069628827273846, 0.027558806651671017, 0.0734539127775601, 0.07777978386729956, 0.040263694644506486, 0.018126906960138252, 0.07872255399291005, 0.03318511215703828, 0.011475949963953878, 0.013401405037646847, 0.021182060075391616, 0.036139104182698896, 0.033606689356799634, 0.028494430107197592, 0.007676556739690048, 0.06062769424170256, 0.038865549489855766, 0.058172639193279405, 0.042029751664293666, 0.05088197719305754, 0.07149223411189658, 0.0229271520594401, 0.11091363270367895, 0.04744133985202227, 0.10532166276659284, 0.029793868772685528, 17.938831329345703, 50.972221102033345, 31.455259323120117, 31.24653196334839, 42.803352560315815, 45.00612953730992, 60.018879890441895, 47.118368012564524, 55.93693481172834, 2.3816787600517273, 1.42985372032438, 0.18419886167560304, 0.22976704793316977, 0.07752863091549703, 39.23730427878243, 63.29692881447928, 53.527591364724294, 57.48028257914952, 48.729672636304585, 45.312506880079, 42.24561023712158, 40.90868302753994, 39.887537547520225, 40.66927589688982, 37.669481481824604, 37.75237001691546, 38.098848887852256, 38.32079866954258, 36.54551655905587, 39.11264664786202, 36.40702853884016, 37.78142738342285, 38.52494369234358, 37.75402021408081, 37.39449610028948, 37.30881091526577, 36.321221760341096, 36.4375832421439, 35.94347252164568, 36.96595900399344, 37.34704337801252, 38.19234037399292, 37.85301814760481, 36.035598686763215, 37.952589307512554, 37.21737609590803, 37.58600582395281, 38.64943109239851, 38.14918163844517, 38.316692284175325, 38.55811786651611, 42.596483843667166, 41.11139324733189, 38.372389044080464, 40.25328377314976, 38.87238141468593, 38.45532274246216, 37.44522142410278, 37.89862264905657, 38.40988499777657, 37.24950456619263, 35.5949786731175, 36.99340786252703, 36.691644123622346, 35.651703766414094, 35.86785875047956, 37.584588391440256, 38.343818051474436, 38.11986024039132, 40.16981853757586, 39.21634503773281, 37.94063145773751, 39.17114005770002, 40.07897431509835, 37.63423327037266, 36.92125429425921, 35.81601129259382, 35.106155531747, 34.4320968900408, 34.459007263183594, 35.47986786706107, 34.59852361679077, 33.615784304482595, 35.62378243037632, 34.595706122262136, 35.917270864759175, 36.84718997137887, 36.63333831514631, 38.30830233437674, 36.81743778501238, 38.13957922799246, 37.423268590654644, 39.29100343159267, 37.43358319146292, 34.91630642754691, 35.22812768391201, 35.945345061165945, 33.88322741644723, 34.11015905652727, 34.81966045924595, 34.339897768838064, 35.67510182516915, 36.263784476688926, 33.81549290248326, 37.23504189082554, 34.84040778023856, 34.66570574896676, 33.68125370570591, 36.29752492904663, 34.838434491838726, 34.941827160971506, 35.838592938014436, 36.18436656679426, 36.52573503766741, 38.79423155103411, 36.61334834780012, 37.11974695750645, 35.12906721660069, 37.88538633074079, 34.83720466068813, 39.28699779510498, 36.665960107530864, 37.88117572239467, 35.84062876020159, 40.88706023352486, 37.817161968776155, 43.99130344390869, 43.809013979775564, 52.39782122203282, 48.894410950796946, 55.255868911743164, 12.40423766204289, 0.48851047243390766, 0.16391960770956107, 0.056131602464509864, 0.26738046961171286, 34.50684213638306, 51.8703487260001, 50.37980726787022, 42.323680196489605, 36.217735290527344, 23.73705267906189, 41.562727383204866, 26.79469953264509, 0.45826295550380436, 0.08042961917817593, 0.045181173631655316, 0.04558312759867736, 0.03023110656067729, 0.06079498705055032, 0.1008361866697669, 0.004769260221759656, 0.05893706317458834, 0.044797197449952364, 0.008617012212718171, 0.04932663583063653, 0.04897631837853363, 0.025005728738116365, 0.11025038507900067, 0.15597189989473137, 0.11775888396160943, 0.09182847823415484, 0.16286500144217694, 0.10302203973489148, 0.08065191403563533, 0.17824011641953671, 0.14875346794724464, 0.1578531518046345, 0.18302334046789578, 0.1399397730295147, 0.1970011211399521, 0.13705257938376494, 0.28352653607726097, 0.15694766039294855, 0.2541427942258971, 0.2025020316775356, 24.420194353376115, 60.77686582292829, 38.576975277491975, 40.64768089566912, 41.33890158789498, 49.92348085130964, 64.18306037357875, 51.953254631587434, 57.868978704724995, 2.0303500464984348, 4.479253930704934, 0.4893764459661075, 0.5855183441724096, 0.12929559419197695, 41.29417603356497, 65.98675714220319, 57.067583901541575, 59.95122528076172, 51.39507457188198, 47.3709454536438, 44.60872384480068, 42.28412062781197, 41.391454287937705, 44.160922867911204, 40.411080837249756, 39.94885540008545, 41.12173911503383, 41.022140162331716, 39.885633741106304, 42.53759438650948, 38.6804895401001, 40.30212613514492, 39.93864849635533, 40.22123520714896, 40.19871262141636, 40.95068488802229, 38.351627826690674, 40.35657221930367, 39.677208627973286, 40.603997571127756, 40.48108393805367, 40.939439228602815, 40.57241106033325, 38.18379756382534, 39.87706661224365, 39.47663845334734, 40.8678936277117, 42.72791249411446, 39.69011838095528, 40.21644442422049, 39.900443826402935, 43.84409890856062, 42.25508410590035, 41.605208669389995, 42.34136683600289, 41.850956031254356, 40.30299465996878, 41.06558377402169, 39.44591004507882, 40.1707044328962, 40.0093047278268, 36.215782846723286, 38.48309121813093, 38.61594424928938, 36.183821133204866, 37.632975646427695, 40.815184593200684, 41.0342960357666, 40.324547971997944, 42.741610867636545, 41.81388391767229, 41.46570621218, 39.95973627907889, 42.24935531616211, 39.22650677817208, 39.5114107131958, 38.23356751033238, 37.53350176130022, 36.500151770455496, 36.128846985953196, 36.91641139984131, 38.491481167929514, 34.845688411167686, 36.630604199000764, 35.974218300410676, 37.82292202540806, 39.79822192873274, 38.41489117486136, 39.89521530696324, 39.169100761413574, 39.173082079206196, 39.088751792907715, 41.794925757816856, 39.986351353781565, 36.68400805337088, 39.20830249786377, 37.8652400289263, 34.88433429173061, 35.6924341065543, 37.5791722706386, 36.358015945979524, 38.034765652247835, 39.29475893293108, 36.96133150373186, 39.637357234954834, 37.36441387448992, 36.57882622310093, 36.04949508394514, 38.3821964263916, 37.29855537414551, 37.41237381526402, 37.46435676302229, 39.580590452466694, 38.07477337973458, 41.136497088841026, 38.70043087005615, 38.981363909585134, 37.12106016704014, 41.16889306477138, 36.432663917541504, 39.58045843669346, 38.05778156008039, 39.07822527204241, 38.62295150756836, 42.577240807669504, 39.488766533987864, 45.12544400351388, 47.18857261112758, 54.44056381498064, 51.17786693572998, 56.441947255815776, 13.993092656135559, 0.42464539940868107, 0.2294495478272438, 0.13774904129760607, 0.8045235010130065, 40.0480374608721, 58.97824123927525, 53.88746983664376, 48.70661851337978, 36.49987036841256, 35.6743722643171, 49.709514549800325, 34.76377957207816, 0.3136765882372856, 0.17661825487656252, 0.24980391561985016, 0.19649379407720907, 0.08528299696211304, 0.1080288817839963, 0.342896504593747, 0.14299246136631283, 0.22792409253971918, 0.09322500508278608, 0.1755897043538945, 0.12768532202712127, 0.20098737866750785, 0.14490842712777002], [0.04436193419886487, 0.032439137542886395, 0.028266030130907893, 0.018106929192851697, 0.004638478958180973, 0.023941071670768515, 0.02974009487245764, 0.03996371431276202, 0.03505463558914406, 0.10296571454299347, 0.023876291932538152, 0.03257273769538317, 0.07457557866083724, 0.013859986144650196, 0.02390326539586697, 0.05286499239238245, 0.09375177895916359, 0.15061224677733012, 0.4512525759637356, 22.12832931109837, 41.66237497329712, 36.16386938095093, 25.699154479163035, 30.630938938685826, 53.06892340523856, 44.40876163755144, 46.99291481290545, 4.80088951757976, 1.3568201192787714, 0.18924864142068795, 0.8864199093409947, 0.1919381506741047, 13.493660484041486, 65.8255033493042, 49.53787667410714, 56.54519053867885, 50.77685512815203, 50.84386355536324, 40.13720369338989, 41.75382021495274, 37.374784060886924, 40.03343234743391, 35.65402446474348, 37.194596426827566, 34.80970369066511, 37.742413248334614, 35.7781331879752, 36.796165875026155, 35.79916885920933, 37.588521071842735, 34.41585200173514, 36.456127984183176, 35.145590032849995, 35.07980101449149, 34.728447982243125, 34.62966544287545, 33.69583797454834, 35.51724222728184, 34.63128089904785, 35.60737425940377, 34.985034533909385, 36.10344089780535, 36.598010199410574, 37.552584988730295, 35.975041661943706, 36.61755895614624, 37.5863983971732, 36.11797652925764, 36.68207992826189, 37.350586959293906, 38.43965802873884, 36.358429363795686, 37.43636247089931, 38.17560911178589, 36.59762110028948, 36.57083232062203, 35.794523988451274, 36.038506507873535, 36.32727364131382, 35.50366544723511, 35.46901478086199, 34.7376960345677, 35.228148528507774, 36.6064453125, 36.4429680960519, 41.59448412486485, 40.072616713387625, 42.290485177721294, 40.89235476085118, 43.398038455418174, 41.891891343253, 40.55585697719029, 41.242648192814414, 38.31359338760376, 37.45025886808123, 36.78840821129935, 34.576994623456685, 33.43849059513637, 34.925394671303884, 33.30415759767805, 33.3134890283857, 33.42105409077236, 32.74113464355469, 33.091567039489746, 32.6694153376988, 33.84346982410976, 35.44798258372715, 35.92197479520525, 36.02167102268764, 35.93269239153181, 35.67401443208967, 36.15611866542271, 33.18262318202427, 33.662750652858186, 33.29272781099592, 32.258238315582275, 33.05412319728306, 34.07375744410923, 33.85794986997332, 34.7632098197937, 35.35066611426217, 33.9683324268886, 33.3927367074149, 33.16111503328596, 32.60632222039359, 34.3641539301191, 32.74520628792899, 35.14829288210188, 37.313782351357595, 37.15833377838135, 39.39736645562308, 39.72453280857631, 39.53765753337315, 41.069961139133994, 41.65237651552473, 41.57297250202724, 36.90456472124372, 35.96009956087385, 35.22800956453596, 35.07966552461897, 36.456280844552175, 34.90645735604422, 37.2698905808585, 38.476174286433626, 41.30959061213902, 44.25182615007673, 50.06576606205532, 47.140630040849956, 46.462819371904644, 2.4880061745643616, 0.3303523191383907, 0.03183388091357691, 0.13019134184079512, 0.5815157475216048, 36.91642182213919, 46.57343816757202, 44.35723727090018, 32.23768207005092, 16.540707860674175, 24.649493592126028, 34.40795537403652, 4.520074597426823, 0.24091806528823717, 0.014347412623465061, 0.046517606026359966, 0.04249220720625349, 0.06261323019862175, 0.05168500303157738, 0.010868949499646468, 0.11310483262475048, 0.03220509385157909, 0.01727820892951318, 0.02100991065214787, 0.03244503401219845, 0.05765599584473031, 0.1309066941695554, 0.025664625256987553, 0.09994440845080785, 0.041428790161652226, 0.015897067862429788, 0.002362465552453484, 0.04794312667633806, 0.08574073668569326, 0.01659894109304462, 0.027589001460000873, 0.030908725557050536, 0.08014645972954375, 0.03023860097995826, 0.06765410077891179, 0.02139378335726048, 0.017892959960071102, 0.06612784482006516, 0.0876453234148877, 0.20419292737330708, 1.2026585915258952, 34.36581107548305, 45.97068541390555, 35.06870821544102, 34.19244657244001, 38.21221569606236, 59.310330390930176, 48.54013967514038, 51.2900664465768, 4.689491655145373, 1.1921340248414447, 0.1494815903050559, 1.3008902690240314, 0.41380444541573524, 14.693086317607335, 65.40711757114956, 51.03724929264614, 58.868105343409944, 52.85640580313546, 54.226837226322715, 42.28452362333025, 44.05183267593384, 39.35925906045096, 41.626122747148784, 38.43214702606201, 39.693807874407085, 35.30697931562151, 40.07556969778878, 39.699981348855154, 39.0337359564645, 37.47802734375, 40.10638843263899, 35.29665081841605, 38.921887329646516, 36.501103673662456, 37.801889828273225, 36.140499114990234, 37.13411235809326, 34.76957089560372, 36.73393433434622, 36.20352275030953, 37.52590043204171, 36.93950721195766, 36.8251051221575, 37.51425872530256, 38.10566854476929, 38.04129695892334, 36.830632414136616, 39.4248674256461, 38.2598421233041, 37.88265221459525, 40.496043409620015, 41.791041714804514, 39.61456019537789, 38.64754465648106, 38.81487117494856, 38.45837647574288, 38.49680001395089, 37.03159168788365, 39.148270062037874, 37.09191247395107, 36.82022748674665, 36.902181489127024, 35.878739629473, 37.174109663282124, 36.777857371738975, 38.51505640574864, 42.60162203652518, 41.24797746113369, 42.956178188323975, 42.75004250662667, 43.996306146894185, 42.91217177254813, 41.722636699676514, 42.55896009717669, 39.672817366463796, 38.044395855494905, 38.29652861186436, 35.47593866075788, 36.96805041176932, 36.68550191606794, 34.85047919409615, 34.372818333762034, 35.34774439675467, 33.95847988128662, 34.729674339294434, 35.606512682778494, 35.227755955287385, 36.364491667066304, 37.683398723602295, 36.97933081218174, 37.14997162137713, 36.11776808329991, 37.60325125285557, 34.93528543199812, 35.846044881003245, 35.301135880606516, 33.59783363342285, 34.88442809241158, 35.682894229888916, 35.18218272072928, 37.023469243730815, 36.39555011476789, 35.62550210952759, 34.79085322788784, 34.748528276171, 34.87364796229771, 34.95295122691563, 35.06075600215367, 36.49436044692993, 40.223427363804404, 38.49196754183088, 41.554076875959126, 41.36123309816633, 41.25669745036534, 41.86065224238804, 42.79050881522042, 41.30780145100185, 39.672198976789204, 36.92666694096157, 37.68043531690325, 36.704960346221924, 36.89331211362566, 37.25365611485073, 38.33614376613072, 40.61269324166434, 43.53520631790161, 46.53360761914934, 52.537552969796316, 49.44857842581612, 48.61789001737322, 2.8336651580674306, 0.2888421251305512, 0.18072324246168137, 0.10693221991615635, 1.1366125983851296, 40.31050566264561, 53.41847685405186, 49.09509229660034, 39.47348744528634, 23.551389864512853, 23.931739466530935, 44.93741880144392, 7.111788281372615, 0.3382161871663162, 0.025953752421108738, 0.1118865365694676, 0.0576380757348878, 0.0346177472466869, 0.03572904511487909, 0.05869513151368924, 0.08170065776045833, 0.01003156349595104, 0.035334154697401185, 0.05299371387809515, 0.04694901180586644, 0.04481661033683589, 0.07088231933968407, 0.17146654560097627, 0.13744025358131953, 0.18155946901866368, 0.1124757288822106, 0.13342047642384255, 0.0967907744592854, 0.15324915599610123, 0.1118010411571179, 0.20086643658578396, 0.18445906628455433, 0.14493356006486074, 0.16540877494428838, 0.250803641974926, 0.09629882300006491, 0.23113046905824117, 0.15059630120439188, 0.1939235305679696, 0.36666154222829, 2.393951232944216, 47.86158554894583, 52.18007162639073, 44.39195741925921, 38.9935371535165, 39.36302498408726, 64.21008191789899, 52.15040976660592, 58.177829606192454, 5.76057470696313, 3.0587709418364932, 0.4331718704530171, 2.0612749585083554, 0.671554467507771, 16.668017966406687, 65.69895580836705, 51.675410066332134, 61.209217480250764, 56.01331288473946, 56.40791497911726, 43.20103965486799, 46.91280903135027, 41.015122481754844, 44.87755312238421, 40.28129196166992, 42.638416222163606, 36.08923183168684, 42.481831618717735, 42.105993134634836, 41.06231117248535, 40.05826868329729, 42.550254004342214, 38.194626331329346, 42.30533695220947, 39.20261539731707, 39.41000870295933, 39.46024417877197, 39.721823011125835, 37.58786794117519, 40.35086080006191, 40.12948077065604, 40.86720923015049, 38.75398063659668, 38.639154706682476, 40.215874671936035, 41.93934406552996, 40.64775732585362, 39.72402906417847, 41.639980929238455, 40.710569041115896, 40.25674397604806, 41.942161560058594, 43.42758566992623, 41.17389576775687, 42.52790512357439, 40.872802530016216, 39.96483278274536, 40.584761483328684, 39.02749647412981, 40.178691387176514, 39.325007915496826, 38.83862359183175, 39.301366669791086, 38.04027904782976, 38.79468665804182, 41.08543477739607, 38.68173326764788, 44.203292982918875, 42.99418830871582, 45.75438451766968, 42.776734011513845, 45.5946489061628, 45.61876957757132, 44.966166973114014, 45.757469517844065, 40.637439250946045, 41.67012916292463, 40.2575603893825, 37.29337549209595, 38.52668421609061, 40.12755264554705, 36.608164991651265, 36.68004758017403, 38.05879947117397, 35.40250314985003, 36.21823903492519, 37.704219000680105, 37.700206415993826, 38.26405620574951, 40.382756505693706, 38.99177578517369, 38.93528345652989, 37.399842739105225, 40.833458355494905, 37.04622112001692, 37.927165848868235, 37.40398733956473, 35.34543759482247, 37.923667430877686, 38.903457232883994, 37.465614386967246, 39.76236227580479, 39.54938956669399, 38.24714081627982, 37.727790764399934, 37.21377345493862, 38.235023157937185, 37.68736614499773, 37.66503463472639, 38.74407250540597, 42.51554775238037, 40.202975341251914, 43.908109188079834, 43.72587183543614, 43.18670899527413, 42.771839005606516, 46.243655817849294, 44.910796778542654, 40.459238801683696, 39.991625036512104, 39.335847105298726, 38.366034916469026, 40.197969164167134, 39.16549464634487, 40.733515466962544, 42.15331384113857, 45.89000988006592, 47.686584745134624, 56.412851674216135, 50.97846753256661, 51.084316389901296, 3.6566150103296553, 0.3883045565869127, 0.18825833313167095, 0.15925834354545387, 1.6332017630338669, 45.19389418193272, 57.66120324816023, 55.426540987832205, 42.73846333367484, 25.394074712480815, 33.37199286052159, 51.3992087500436, 10.186966742788043, 0.6183520023311887, 0.15516784946833337, 0.23678966824497494, 0.131558929170881, 0.15597183204122952, 0.197776713807668, 0.13526083981352194, 0.20744064024516515, 0.10179276498300688, 0.130921744076269, 0.1239060719630548, 0.10200040348406349, 0.1958263734621661, 0.22680159205836908], [0.047866082417645624, 0.14899252940501484, 0.04210019038457956, 0.01830671025839235, 0.0324411426138665, 0.02038699175630297, 0.024801521927916577, 0.04319864697754383, 0.0975337770900556, 0.06157722257609878, 0.05310412848900471, 0.03560344149757709, 0.0166544757916459, 0.07808741807405438, 0.036442029356424294, 0.06688461492636374, 0.05864760692098311, 0.08777283371559211, 0.08745193414922271, 14.148886901991707, 37.28861597606114, 42.81500816345215, 42.165202208927695, 20.64515815462385, 48.25719165802002, 45.650373458862305, 51.66595356804984, 16.351593528475078, 0.839665806719235, 0.14576487402830804, 0.6562244072556496, 0.04397725234074252, 0.8708558359316417, 49.14529997961861, 57.42581565039498, 55.94873980113438, 55.00153010232108, 49.6990053994315, 45.56894404547555, 41.78053603853498, 38.75882005691528, 38.555838857378276, 37.66570166179112, 36.96410730906895, 35.38823502404349, 33.702129568372456, 35.59783785683768, 36.642739227839876, 35.4182790347508, 36.17969390324184, 35.61052526746477, 35.98938274383545, 34.97491448266165, 35.16063635689871, 34.54642949785505, 33.839116777692524, 35.02159595489502, 35.77165399278913, 33.428818702697754, 35.76155826023647, 37.141060556684224, 35.98562029429844, 35.02970102855137, 36.688531330653596, 35.452853270939414, 36.71871083123343, 37.241809436253135, 36.65568719591413, 36.832706451416016, 37.762761047908235, 37.88108886991228, 36.52407094410488, 36.11168840953282, 35.62885808944702, 36.635870933532715, 36.79754161834717, 37.09602233341762, 35.05826507295881, 36.279073987688335, 37.304082666124614, 33.923565183367046, 35.866024426051546, 36.296583448137554, 36.21494558879307, 42.274698870522634, 47.36350393295288, 46.63181345803397, 47.94458178111485, 47.67372710364205, 45.49703713825771, 44.18269852229527, 43.2921096937997, 42.621247223445344, 43.28754472732544, 42.124162673950195, 39.73716810771397, 33.712795053209575, 33.39476558140346, 33.31519481113979, 33.84582526343209, 33.92745964867728, 31.667377403804235, 34.29630824497768, 32.93875183377947, 33.628989355904714, 32.85777405330113, 32.79885680334908, 33.0460250718253, 34.93557378223964, 32.93938759395054, 34.112948758261545, 34.83896950313023, 33.787595885140554, 34.68320826121739, 34.05266618728638, 32.105384894779746, 32.25703975132534, 34.0903115272522, 33.0293459211077, 33.33460112980434, 34.570477213178364, 33.17823192051479, 33.10154117856707, 34.67423118863787, 34.15965454918997, 33.331696782793315, 37.75250898088728, 38.45790747233799, 40.27718210220337, 41.88682263238089, 41.63341835566929, 43.923072133745464, 41.64304161071777, 44.76693780081612, 42.8630028452192, 44.259118284497944, 41.78149141584124, 40.72131790433611, 37.828515325273784, 38.98608521052769, 34.90046453475952, 36.53900957107544, 36.3794025012425, 41.80433709280831, 42.4677163532802, 45.06938941138131, 47.09072807856968, 51.69122764042446, 30.103185040610178, 0.02775826202040272, 0.1624115907720157, 0.14563942647406034, 0.076065526210836, 2.2290229286466325, 43.47202287401472, 42.45186751229422, 45.94795438221523, 25.56046669823783, 26.283701215471538, 35.37288645335606, 17.34196891103472, 0.22152557516736643, 0.052460595699293275, 0.1297802310436964, 0.06728601588734559, 0.04228299789662872, 0.007832977721201522, 0.030587907414883375, 0.05281291822237628, 0.04316319013014436, 0.05936478450894356, 0.024514350640986646, 0.01788329253239291, 0.0198825094516256, 0.037673760405076404, 0.024168426703129495, 0.03361742038811956, 0.06232039484062365, 0.06584910263440438, 0.02713788254186511, 0.035188103427312205, 0.0306420646873968, 0.03522210142442158, 0.03526679652609995, 0.03605100319587758, 0.0813381572120956, 0.028798250947147608, 0.030637223340038742, 0.04282909645033734, 0.07702928342457328, 0.009825787573520626, 0.02010810368561319, 0.031198222522756884, 0.11666062075112547, 0.11198489700577088, 20.58701389176505, 46.81295299530029, 43.41849742616926, 42.566933155059814, 29.062892062323435, 50.81875623975481, 50.00863797324044, 55.06712804521833, 15.961236783436366, 0.7638802847691945, 0.1658793254090207, 0.6812974704163415, 0.0820406987997038, 0.9585039956229073, 52.65164933885847, 56.789447511945454, 57.67896979195731, 55.207162039620535, 51.987995624542236, 46.35688018798828, 43.5655734198434, 39.836645466940745, 42.18693617412022, 38.75645419529506, 39.29509244646345, 36.77258716310774, 36.37850618362427, 37.028141907283235, 37.78238276072911, 38.676695823669434, 39.004192216055735, 37.468727179935996, 37.155947072165354, 36.82146079199654, 37.788247040339876, 36.55544900894165, 37.02249302182879, 36.68279211861746, 37.16787365504673, 36.25065932955061, 38.83952685764858, 40.38961785180228, 38.79632643290928, 37.87210137503487, 38.283896786826, 38.21454334259033, 38.583457946777344, 40.342390945979524, 39.35562515258789, 38.39202812739781, 38.576221397944856, 39.59174925940377, 37.19250501905169, 37.204483713422505, 37.01047958646502, 37.22031518391201, 39.93277032034737, 37.54301037107195, 36.70770141056606, 37.570361954825266, 37.68646287918091, 36.901347705296104, 37.52489294324602, 36.4561071395874, 36.06241873332432, 42.47810391017369, 47.12257514681135, 46.02572209494454, 48.691770212990896, 48.3237692969186, 47.16338191713606, 44.46062299183437, 43.35410846982683, 44.50429936817714, 44.39267308371407, 41.90366506576538, 40.534314087459016, 35.48126098087856, 35.07640681947981, 34.858612060546875, 35.599088532584055, 34.920635155269075, 33.14552674974714, 35.55551985331944, 34.79155847004482, 35.85314246586391, 34.75761999402727, 35.223416805267334, 34.649506023951936, 37.149429661887034, 35.15236105237688, 35.00541707447597, 36.83546141215733, 35.29413557052612, 36.305529253823416, 35.26480027607509, 34.13653094427926, 34.054233006068635, 35.581276825496126, 35.30011102131435, 35.34636517933437, 36.53495877129691, 34.987410817827495, 35.704159191676546, 35.536617279052734, 35.68669489451817, 36.272831031254356, 39.58329330171858, 41.36535337993077, 40.90376022883824, 43.60458060673305, 44.37337098802839, 45.454045159476145, 44.10885306767055, 46.71027946472168, 43.664300373622346, 45.569871629987446, 44.02156979697091, 42.80373123713902, 38.46172203336443, 39.99925763266427, 37.17445707321167, 38.234199796404155, 38.96212434768677, 44.219860962459016, 44.47526632036482, 48.58924259458269, 48.99998882838658, 54.54853534698486, 31.420712879725865, 0.08237206137606076, 0.1502826280359711, 0.46549499886376516, 0.12478605045803956, 2.737474079642977, 47.251592772347585, 47.923459257398335, 49.5801807812282, 38.01879521778652, 24.277975150517054, 34.94578068596976, 26.26154167311532, 0.3086565418967179, 0.10940748852278505, 0.050874431883650165, 0.018686985031568577, 0.00810418647181775, 0.025455605937168002, 0.07737671371017184, 0.09380493539252452, 0.037714818559054814, 0.07216937134840659, 0.023200301420209662, 0.07164877214069877, 0.05668865596609456, 0.043763232217835527, 0.016409714639719044, 0.17281741382820265, 0.2473797814122268, 0.1529174337961844, 0.24176438844629697, 0.14379229130489485, 0.15713296830654144, 0.13261342687266214, 0.08310250432363578, 0.1744103833500828, 0.22402964080018656, 0.16930663292961462, 0.1053968376613089, 0.09463110606053046, 0.22921938874891826, 0.08134463722152369, 0.22647816155638012, 0.17061129292207106, 0.31165173117603573, 0.22630867707942212, 30.72292266573225, 55.361248765672954, 47.43971177509853, 56.69674812044416, 31.45623901912144, 57.56957040514265, 52.5888306753976, 60.474667821611675, 20.99902469771249, 1.2925806577716554, 0.4727793165615627, 1.5175357524837767, 0.19498664566448756, 1.4858868164675576, 54.325282778058735, 57.85165684563773, 60.06508541107178, 58.496175221034456, 54.885522978646414, 49.6888610294887, 45.99673421042306, 41.83250508989607, 43.97242866243635, 41.232514245169504, 42.88504600524902, 39.13163260051182, 38.05918509619576, 39.83345276968819, 39.677146094185964, 41.49758454731533, 40.91702781404768, 41.25774662835257, 41.083398955208914, 39.7389920098441, 40.31898593902588, 39.40521444593157, 39.84944404874529, 40.415746552603586, 39.759284223829, 38.9301244190761, 40.148723806653706, 44.01230090005057, 39.957530226026265, 39.70419890539986, 40.861053126198904, 40.48881033488682, 40.848806926182334, 42.53198024204799, 42.75769247327532, 40.06049905504499, 39.81634283065796, 42.90933690752302, 39.13670825958252, 39.60337012154715, 39.6658934865679, 40.36290897641863, 41.33969368253435, 39.86911787305559, 38.0314930507115, 39.869291578020366, 41.35608100891113, 37.811912604740684, 38.98076983860561, 38.75626311983381, 38.376488481249126, 46.487544536590576, 49.937297344207764, 49.083346366882324, 49.63465813228062, 50.77719906398228, 47.196556091308594, 45.17971290860857, 45.559664726257324, 45.13890961238316, 46.111160618918284, 44.05612318856375, 42.49315370832171, 35.63802971158709, 37.32471881593977, 35.89055504117693, 37.54298605237688, 37.480705874306814, 35.37368202209473, 37.94854198183332, 35.68499953406197, 37.74977139064244, 36.174576554979595, 36.25746856416975, 37.14156430108206, 39.741177218300955, 37.18116208485195, 37.20307322910854, 40.12882416588919, 37.59494468144008, 38.042047364371165, 36.433674880436485, 36.01705047062465, 35.333695139203755, 37.9377201625279, 37.833267893110005, 37.44565568651472, 38.68586049761091, 36.31853975568499, 38.22091831479754, 40.09456607273647, 38.93877492632185, 36.93860742024013, 43.19795118059431, 42.38975756508963, 45.30471100125994, 46.061098848070415, 46.328746931893484, 48.429566042763845, 46.58608388900757, 49.91198853084019, 46.40211990901402, 47.6460211617606, 46.71301358086722, 43.39320945739746, 41.420515128544395, 43.05897331237793, 39.66474008560181, 39.44812652042934, 40.66227558680943, 46.95450169699532, 46.59161465508597, 49.0304844720023, 50.502839020320344, 54.70641926356724, 33.94585500444685, 0.4886488935777119, 0.22530873359314033, 0.6787885736141885, 0.16497791877814702, 4.46750886951174, 54.26925597872053, 51.97892475128174, 55.60896941593715, 38.38131053107125, 35.48144858224051, 46.313596384865896, 34.576094831739155, 0.2093295053179775, 0.14449127736900533, 0.2074701293770756, 0.14290569030812808, 0.10631463091288294, 0.07264094640101705, 0.15708766930869647, 0.21759300333048615, 0.1044906744999545, 0.12030161251979214, 0.1635663623788527, 0.09842066985688039, 0.10580119024962187, 0.1342080927320889, 0.10700377143387284], [0.010766747706968869, 0.012907004915177822, 0.04282724065706134, 0.020249261021880165, 0.06373311153479985, 0.02192709661488022, 0.09992372670343944, 0.035541952654187164, 0.03211170029161232, 0.004247941342847688, 0.058979064492242675, 0.04236595219533358, 0.034401803477002044, 0.09409656974353961, 0.019374444482049773, 0.0660847442756806, 0.053692808507808616, 0.0556406484517668, 0.20302481576800346, 3.5920126140117645, 38.61165721075875, 45.96591547557286, 50.118558474949424, 30.733692373548234, 40.92845065253121, 46.71609510694231, 47.5953722681318, 30.178486142839702, 0.23883382284215518, 0.2919803767332009, 0.22243204366947922, 0.10886991915426084, 0.11245136947504111, 20.908979518072947, 67.86662701198033, 51.497261728559224, 56.89125599179949, 48.0279358455113, 49.77020706449236, 41.12010976246425, 43.484745025634766, 39.137125151497976, 41.750078610011506, 38.60131481715611, 38.03990037100655, 37.10304001399449, 36.05061721801758, 35.013206005096436, 36.68147196088518, 35.679659843444824, 35.75396040507725, 35.486847332545686, 35.02369083677019, 35.63552836009434, 35.46695811407906, 35.35734333310808, 37.37103203364781, 35.84013543810163, 35.56585529872349, 35.557437556130544, 37.335828985486714, 35.76214190891811, 36.96772732053484, 36.643409729003906, 36.4554887499128, 37.3137024470738, 37.974225997924805, 38.00010456357683, 36.75605739865984, 37.27743979862758, 37.563698632376536, 36.042185579027446, 36.37925658907209, 39.17698349271502, 35.6700713293893, 37.17657279968262, 36.562904426029746, 36.36517259052822, 35.91534621374947, 37.59112664631435, 37.40905952453613, 36.174069336482454, 37.01560735702515, 38.126787594386506, 41.768282890319824, 48.747182096753804, 50.22250699996948, 50.593103068215505, 50.30168172291347, 51.83589955738613, 44.86724199567522, 44.892470904758994, 48.10213565826416, 47.721350056784495, 46.94309622900826, 42.994396754673545, 36.98361437661307, 36.95867034367153, 33.9534215927124, 33.327847480773926, 32.958026136670796, 34.11144099916731, 33.33674464906965, 33.08930540084839, 33.16563483646938, 32.609539236341206, 34.39348922457014, 33.91916002546038, 32.65452534811837, 34.66100876671927, 34.28707756314959, 35.49095719201224, 33.33034883226667, 33.69952399390084, 36.161604268210276, 34.74275779724121, 32.255511147635325, 33.80783598763602, 33.49021298544747, 33.4740514755249, 32.28323793411255, 33.16026735305786, 32.16718564714704, 34.4078893661499, 32.68042475836617, 34.61551891054426, 37.50126211983817, 39.69399547576904, 41.95062446594238, 41.427703039986746, 41.952510901859824, 44.24914067132132, 44.037929330553325, 44.98293645041329, 43.69810683386666, 44.42900174004691, 42.709367752075195, 41.97808027267456, 40.348814555576865, 39.253642967769075, 35.53561326435634, 37.23306165422712, 38.942433152879985, 46.47057703563145, 43.39682599476406, 46.684981073652, 46.69769627707345, 52.06874411446707, 16.47113033703395, 0.1796662884631327, 0.11883342558784143, 0.1707236718918596, 0.12351591432733194, 7.028908865792411, 47.02110365458897, 43.452133655548096, 36.43402229036604, 18.1375150680542, 22.313933065959386, 30.057538849966868, 4.115025886467524, 0.15995648822614125, 0.030048414399581294, 0.08339175023138523, 0.03284545109740325, 0.07660046964883804, 0.02964053342917136, 0.10295845421829394, 0.04418721482423799, 0.02410127378867141, 0.0043542037435275105, 0.08123552879052502, 0.017547684023156762, 0.028526959075991596, 0.048294037846582274, 0.033329463696905544, 0.00629509421664157, 0.04602647898718715, 0.018081468862614462, 0.024652027092607956, 0.01148032397031784, 0.02017328206316701, 0.014844783881146992, 0.023961217375472188, 0.01679981799264039, 0.04783837104748402, 0.04159341293520161, 0.048507922262485535, 0.00735333319088178, 0.05677821580320597, 0.0512404947408608, 0.04963973563696657, 0.018237051853377904, 0.08610010240226984, 0.18136092967220716, 6.717012047767639, 48.60841267449515, 47.56088488442557, 49.665396962847026, 33.747866085597444, 47.71675729751587, 51.56703553880964, 53.2770219530378, 32.7554201398577, 0.3045096615595477, 0.21634732160185063, 0.383123941719532, 0.04144744648198996, 0.27662417931216104, 23.8277370929718, 68.66138975960868, 53.05322047642299, 58.98090239933559, 50.79341615949358, 51.785893372126985, 42.35287652696882, 46.339405468532014, 41.21260418210711, 44.13601010186331, 40.52214779172625, 39.5270163672311, 39.09855917521885, 38.345447404044016, 38.53557096208845, 38.46729448863438, 37.613708291734966, 39.05195413316999, 37.48121656690325, 38.27940477643694, 37.361099583762034, 37.645874977111816, 37.658461638859336, 37.773513385227744, 37.963463238307405, 37.90844392776489, 37.79231521061489, 39.798829896109446, 39.06849431991577, 39.82544149671282, 37.55624668938773, 38.058528491428916, 39.08886643818447, 38.782221589769634, 39.97096109390259, 39.599625042506624, 38.922109672001426, 39.15450954437256, 37.87929970877511, 39.385641370500835, 39.660407883780344, 37.61376387732369, 38.88576364517212, 38.03921944754464, 37.75811965124947, 38.429663045065745, 38.59981400626046, 38.65918288912092, 37.63770389556885, 38.99959945678711, 39.630308287484304, 43.077128955296104, 50.29054723467146, 50.861678736550466, 50.975452014378135, 52.327453340802876, 51.396724769047324, 46.11759465081351, 48.0043362889971, 49.22031620570591, 48.02923168454851, 48.39158024106707, 44.16565111705235, 37.5943158694676, 38.08620664051601, 36.024933201926096, 33.7506696837289, 34.35920333862305, 34.79297242845808, 35.921359879629954, 35.2669437953404, 35.97423914500645, 33.73116956438337, 36.16360534940447, 35.516953877040315, 33.70736851011004, 35.17415755135672, 35.89469269343785, 37.07984345299857, 35.51042257036482, 36.58629553658621, 37.20154462541853, 36.50234045301165, 33.48143393652779, 35.68449578966413, 35.480302129473, 35.89653744016375, 34.52121448516846, 35.590066296713694, 34.783526352473665, 35.20348937170846, 35.48109075001308, 37.765446526663645, 40.58166953495571, 42.28950548171997, 42.30884231839861, 43.92062289374215, 42.78808389391218, 46.107790742601665, 44.945579460689, 45.96373374121529, 45.560109410967144, 46.58940165383475, 45.91072940826416, 45.41866840635027, 42.70054701396397, 40.88001128605434, 38.35915272576468, 39.63925061907087, 42.03337403706142, 47.830141476222444, 45.92659214564732, 50.48259196962629, 48.94336448396955, 54.39919771466936, 18.98287980897086, 0.18144270671265467, 0.6952554785779544, 0.4750917639051165, 0.09928343391844205, 7.944916810308184, 53.47526100703648, 46.6706782068525, 43.2292389188494, 29.494713919503347, 21.841733489717754, 37.58909429822649, 7.791522298540388, 0.23498392371194704, 0.046926762642604966, 0.10246695737753596, 0.04637267773172685, 0.032575753783541064, 0.03919425220893962, 0.11596144469720976, 0.03489774811480727, 0.09176885536206619, 0.06257998876805816, 0.052333380561321974, 0.08878239204308816, 0.01822526061109134, 0.10111454887581722, 0.028281249671376178, 0.06749559499855552, 0.15238269391868794, 0.12966821848281793, 0.09333669873220579, 0.19274840291057313, 0.103642688931099, 0.21430449693330697, 0.05556620637487088, 0.10015617244477783, 0.1018845775563802, 0.12689220958522388, 0.1421641329569476, 0.10191341529467277, 0.32966936007142067, 0.09468852369380848, 0.1677936084036316, 0.18391296773084573, 0.22904790937900543, 0.3248148762754032, 8.460239512579781, 59.19965948377337, 51.19108588354928, 56.524585655757356, 43.575530188424246, 50.853882857731406, 57.24907432283674, 58.112443583352224, 40.148428508213584, 0.3332743080598967, 1.6329511936221803, 2.2154887063162665, 0.24955559894442558, 0.36344707757234573, 23.892428295952932, 67.01741123199463, 55.14281129837036, 61.122566495622905, 53.08966377803257, 54.457777976989746, 45.49630757740566, 49.000176429748535, 42.72402497700283, 46.90469700949532, 42.52569212232317, 42.80087552751814, 42.166574478149414, 40.731576919555664, 40.775704928806846, 41.135684149605886, 39.07537303652082, 41.1950113432748, 40.71104151862008, 41.71489640644619, 40.340678215026855, 40.58619628633772, 40.07353040150234, 41.80152654647827, 40.3686968258449, 41.82137407575335, 39.78858477728707, 41.37825271061489, 40.97000435420445, 40.83834988730294, 40.28979655674526, 40.40488651820591, 41.13761574881417, 41.08059188297817, 42.19030952453613, 40.44177450452532, 40.62723929541451, 42.361401966639924, 39.08447865077427, 41.35168974740164, 42.98357146126883, 39.04111841746739, 41.140158789498464, 41.17391313825335, 40.212393624441965, 39.70886809485299, 41.426160539899556, 40.48908131463187, 39.42672259466988, 41.139106137411936, 42.06138917378017, 44.39967686789376, 52.6241831098284, 53.65000125340053, 51.82046413421631, 54.58636828831264, 52.55710520063128, 47.29004062925066, 48.58998952593122, 51.58033439091274, 49.16435888835362, 51.31051846912929, 45.38623421532767, 40.30206707545689, 40.63941601344517, 38.16110127312796, 35.44954245431082, 36.895827361515586, 36.75160707746233, 37.96333122253418, 37.23986741474697, 37.810654980795725, 36.51301288604736, 39.252239431653706, 37.979857512882774, 37.20352833611624, 38.569644927978516, 37.99501153400966, 39.850031171526226, 37.23689011165074, 37.87723956789289, 40.99808897290911, 39.47377926962716, 35.53273671013968, 38.753890310014995, 37.85165630068098, 38.25484984261649, 36.401938983372276, 37.015041078839985, 35.59763635907854, 37.764400822775706, 36.371207101004465, 39.59235722678048, 43.03060381753104, 44.39920786448887, 45.304398332323345, 45.311506339481895, 44.64226279939924, 47.95047385351998, 46.91663748877389, 48.65700837544033, 48.97389486857823, 49.45614153998238, 47.37880734034947, 48.030843666621614, 44.740993227277485, 43.55582162312099, 38.6386718068804, 41.2000070980617, 43.37419918605259, 51.48306655883789, 48.774339130946565, 52.74940701893398, 51.11173745564052, 55.85954230172293, 20.08028871672494, 0.1337697726807424, 0.7886068608079637, 0.6971652561000415, 0.4360347454036985, 11.15357060091836, 60.63171100616455, 51.017787388392854, 48.17298991339547, 28.839479684829712, 30.326430661337717, 45.460621629442485, 12.200274160930089, 0.35215709624545916, 0.12575463205575943, 0.11508590382124696, 0.14997124831591332, 0.17917173142944062, 0.11267300615353243, 0.24373887106776237, 0.13669888621994428, 0.17272874287196568, 0.13976912147232465, 0.18294761595981462, 0.13475077146930353, 0.11201298835554294, 0.22112031334212848, 0.1349935241575752], [0.01780471478455833, 0.030995425369058336, 0.06379147233175379, 0.10646562531058278, 0.03713691367634705, 0.07050706233297076, 0.03654626590598907, 0.00782458933203348, 0.0879998579621315, 0.014988258414502655, 0.07243127908025469, 0.028191574483311603, 0.01250373204571328, 0.020226589470569576, 0.05717054475098848, 0.06453925863440547, 0.005687793500588408, 0.0707549379606332, 0.024565793773425475, 0.14069912156888417, 14.224581445966448, 49.971419947487966, 49.78320366995675, 42.23152623857771, 33.12324735096523, 50.9179105077471, 46.30303512300764, 42.00606761659895, 0.6520092934370041, 0.6235474635447774, 0.1694791436727558, 0.03408934149358954, 0.08538198165063347, 3.100620376212256, 58.52830369131905, 54.99003083365304, 56.74324199131557, 49.85270997456142, 51.42478854315621, 42.38670383180891, 44.142503193446565, 43.58989558901106, 44.65809079578945, 42.94598170689174, 43.47114740099226, 39.17905752999442, 41.12134654181344, 36.48272916248867, 38.487013476235525, 35.21416527884347, 35.76008871623448, 35.997275897434776, 36.699523380824495, 34.65610681261335, 37.59359325681414, 36.422210352761404, 36.425778252737864, 36.691164697919575, 38.059000968933105, 37.387554849897114, 38.05202497754778, 36.60609442847115, 37.26340443747384, 37.24342836652483, 37.55170256750924, 37.71747268949236, 37.256723744528635, 38.18177911213466, 38.200775487082346, 38.224604334150044, 38.03372342245919, 37.17021867207119, 35.56140497752598, 38.675504207611084, 37.09997238431658, 36.202893938337056, 38.439491271972656, 35.94486563546317, 37.832263878413606, 38.81811598369053, 37.21154655729021, 36.7548588344029, 37.75120619365147, 37.79855816704886, 41.77836125237601, 45.184045110430034, 47.17121601104736, 49.01574386869158, 50.202899183545796, 52.22986241749355, 48.95926891054426, 48.74907200677054, 51.83231776101248, 49.33937358856201, 50.08151762826102, 44.61582142966134, 36.749046666281565, 37.153126103537424, 34.74438714981079, 35.48482888085501, 34.20253535679409, 34.81379965373448, 33.45278998783657, 33.84629079273769, 33.493416104997905, 32.7638760975429, 32.908749512263704, 34.0153682572501, 31.893058368137904, 33.65400634493147, 34.58770874568394, 34.29505409513201, 34.576675006321494, 35.0962369782584, 34.08636842455183, 34.7339266368321, 33.66187865393502, 34.14715473992484, 34.149333000183105, 33.86670112609863, 32.66216836656843, 33.541608810424805, 32.422066416059224, 33.00285938807896, 32.442056383405415, 35.040637493133545, 38.09382881437029, 39.7070163999285, 39.38937950134277, 45.095069953373496, 44.23351069859096, 45.89098957606724, 45.695203236171174, 45.59010131018502, 46.77857330867222, 47.33055904933384, 44.92231341770717, 45.18874209267752, 43.105376856667654, 42.53508608681815, 39.64905105318342, 41.7892803464617, 44.66297885349819, 46.51026514598301, 45.87121500287737, 47.6527852330889, 47.50019931793213, 45.35579763139997, 4.497443011828831, 0.26230478339961594, 0.4555736226694924, 0.39326500041144236, 0.16268733383289405, 21.01800196511405, 52.0395165170942, 38.28500155040196, 25.899168797901698, 18.87715949331011, 30.1494357245309, 25.863611391612462, 0.4556676947644779, 0.25945398637226647, 0.010866164961563689, 0.04126638959028891, 0.017829347302072814, 0.01800852974078485, 0.01799404132179916, 0.04443083264465843, 0.04586461785116366, 0.06466506581221308, 0.010763236288247364, 0.03720187322635736, 0.00779452090085085, 0.10788723081350327, 0.12914299166628293, 0.03271821899605649, 0.02069161835658763, 0.057027190657598634, 0.016314824910036156, 0.10526702712689127, 0.014878936244973114, 0.03212023965482201, 0.022892892826348543, 0.11808816343545914, 0.034115037614745755, 0.03593160817399621, 0.047483680437185934, 0.046968998054840734, 0.07014754055333988, 0.03539112110489181, 0.024733446205833128, 0.11808919480868749, 0.04250678553112915, 0.03171916099797402, 0.0573447925437774, 0.2286619043775967, 24.729905094419205, 54.88862534931728, 47.67567607334682, 49.17160585948399, 41.922053473336355, 54.111809798649375, 51.148080008370535, 46.620512213025776, 0.42181281426123207, 0.7585158411945615, 0.4328684295926775, 0.13808243269366877, 0.15182157259966644, 4.036682341779981, 60.64610072544643, 53.97011171068464, 57.11582177025931, 50.88475717817034, 54.11534990583147, 44.49039602279663, 47.26740339824131, 45.19587441853115, 47.54717261450631, 44.11724649156843, 44.36589820044381, 41.583349636622835, 42.492483207157676, 38.89222894396101, 40.25145639692034, 37.938123158046174, 38.823358399527415, 36.52786466053554, 38.29530920301165, 37.98447111674717, 39.55356195994786, 37.48639644895281, 38.34808424540928, 39.151084082467214, 39.25299678530012, 40.277248110089985, 40.47269746235439, 39.466608728681294, 40.05711875643049, 38.901949473789756, 39.3378620828901, 39.23565755571638, 40.9806489944458, 40.08286878040859, 39.86690487180437, 39.79199286869594, 38.933848653520855, 39.18569653374808, 37.315126827784944, 39.192922660282676, 38.59745856693813, 38.54754965645926, 39.58117757524763, 37.98935917445591, 39.70508132662092, 39.3245667048863, 39.454543181828086, 37.911841596875874, 38.64220496586391, 38.863140310559956, 43.59119837624686, 47.31564474105835, 49.644969258989605, 50.92646721431187, 50.401978969573975, 52.872164317539756, 49.85260227748326, 50.18281888961792, 54.41813155582973, 48.73501927512032, 50.22337205069405, 46.35784598759243, 37.47580392020089, 36.588939326150076, 36.210481371198384, 35.386216572352815, 36.7387945992606, 35.81281164714268, 37.02175998687744, 35.578480175563264, 35.00864451272147, 34.098635469164165, 35.14096948078701, 34.482273306165425, 34.66981560843331, 35.46665934153965, 35.978908334459575, 36.51542043685913, 36.63343906402588, 36.166353361947195, 37.62153891154698, 35.40510525022234, 36.91651214872088, 36.77941376822335, 37.196903228759766, 37.07648747307913, 34.983439922332764, 34.6327817099435, 34.465663637433735, 34.4768328666687, 33.15446560723441, 37.2283889906747, 40.62607199805123, 41.11580187933785, 42.881926264081685, 45.61040047236851, 46.96204744066511, 48.14301885877337, 47.45734282902309, 47.5776960509164, 48.09104980741228, 49.219194071633474, 46.602287088121685, 48.065584659576416, 45.90818984167916, 44.37857518877302, 41.6938989503043, 43.921751976013184, 46.205822876521516, 47.904028620038716, 47.68853718893868, 50.12539202826363, 48.33788456235613, 47.74181250163487, 5.535442650318146, 0.20928891535316194, 1.697514832019806, 0.905288828270776, 0.07413253600576095, 21.199891907828196, 59.83701079232352, 40.69001279558454, 36.65887989316668, 21.59517318861825, 27.319620302745275, 36.50865636553083, 0.5685852042266301, 0.30302255707127707, 0.07337961997836828, 0.10855297544705016, 0.02651729271747172, 0.026572442347449914, 0.04913597088307142, 0.0491043511512024, 0.07816514426044055, 0.0309411731016423, 0.017922859605667845, 0.045350698820714436, 0.027657862586368407, 0.07691767798470599, 0.04646601700889213, 0.030105122963764837, 0.1760910331670727, 0.11919315771332809, 0.1697884470756565, 0.11646560978676591, 0.15470997403774941, 0.15686098432966641, 0.09185121594262974, 0.1934582862470831, 0.1469640489667654, 0.1671524742352111, 0.15431636944413185, 0.18797906168869563, 0.10384576767683029, 0.14969387677099022, 0.1897297498903104, 0.22469866275787354, 0.06969801788883549, 0.12401720242840902, 0.10832731505589825, 0.3343201476548399, 29.567788124084473, 64.36697224208287, 53.26730489730835, 55.627594062260215, 42.95887756347656, 61.58961050851004, 54.6239788872855, 52.69050366537911, 1.7922052081142152, 1.2252391512904848, 1.9018750318459101, 0.40890477118747576, 0.2668687185006482, 4.932479279381888, 58.753439222063335, 56.302385738917756, 59.5802401133946, 52.796592235565186, 57.12155750819615, 46.10455635615757, 50.04099920817784, 48.24957990646362, 50.805561610630576, 46.62882225854056, 47.24778168542044, 43.04419101987566, 46.58632360185896, 41.269332749503, 42.666389669690815, 39.41396917615618, 41.23622805731637, 39.62246377127511, 40.36392341341291, 39.92158719471523, 43.07482215336391, 40.992158685411724, 40.26765264783587, 41.756568227495464, 41.984302384512766, 42.90141943522862, 44.26112978799002, 41.01434080941336, 41.11007308959961, 41.66283702850342, 40.919279030391145, 42.74378565379551, 41.228671891348704, 42.745116233825684, 41.80370133263724, 42.56342084067208, 41.69525037493025, 42.637061323438374, 38.83488198689052, 41.60126904078892, 40.61497572490147, 41.306182520730154, 42.13011728014265, 38.003821849823, 41.11659744807652, 42.83236476353237, 40.13137068067278, 41.2690999848502, 39.933499881199424, 41.27065985543387, 45.17624575751168, 48.45751517159598, 50.500216075352256, 51.51645960126604, 52.93729673113142, 54.94205699648176, 50.91712188720703, 52.42498867852347, 56.02626085281372, 50.071866580418174, 52.565953731536865, 48.67222145625523, 39.59102317265102, 39.42384604045323, 37.349197319575715, 37.475334916796, 38.22757468904768, 39.00374058314732, 39.045738969530376, 37.5202967098781, 35.978779792785645, 35.95925882884434, 36.746500151497976, 37.48408964702061, 34.99442155020577, 37.933467864990234, 37.77292626244681, 39.0637834412711, 39.5095659664699, 38.37464720862252, 39.17392628533499, 37.64375925064087, 39.41198199135916, 38.633846282958984, 39.532175404684885, 40.15322623934065, 37.22681522369385, 37.123610155923025, 35.4495632989066, 35.66944251741682, 34.7977180480957, 39.58399159567696, 41.90443631580898, 42.60043042046683, 44.54421329498291, 49.273827757154194, 48.51419857570103, 49.67650713239397, 49.44332906178066, 49.80793925694057, 50.8296023777553, 51.091688428606304, 48.354059968675884, 48.35015160696847, 46.50671809060233, 47.61315965652466, 44.06266144343785, 46.82085657119751, 48.54384306498936, 50.270779609680176, 50.85208327429635, 52.92413684300014, 51.438462597983225, 50.321185316358296, 6.712403655052185, 0.30778397300413673, 1.312736187662397, 3.816362346921648, 0.34770517370530535, 27.352016278675624, 62.31789289202009, 47.09764848436628, 37.77080706187657, 28.262258086885723, 41.13760880061558, 43.49527154650007, 1.602138864142554, 0.6727783275502068, 0.2687629168587071, 0.1964646577835083, 0.060749586272452555, 0.08424388843455485, 0.09794547142727034, 0.2136677596718073, 0.19872507506183215, 0.1815776808985642, 0.08816854176776749, 0.1303344313055277, 0.1827264813972371, 0.1475507646266903, 0.2529386116990021, 0.17548120660441263], [0.05710754277450698, 0.06966827769896813, 0.053391182728643925, 0.11022144556045532, 0.07465011573263577, 0.0479950651393405, 0.007794744817407003, 0.05786801768200738, 0.022850893205031753, 0.04981387147147741, 0.054133930908782144, 0.036783712450414896, 0.015653545036911964, 0.03313072757529361, 0.08517644660813467, 0.020447323697486093, 0.06091177649796009, 0.022423862280058007, 0.006652792433409819, 0.06982531105833394, 2.401760139635631, 40.29825251443045, 43.377204281943186, 37.51304973874773, 27.321371248790197, 39.26619141442435, 44.58844205311367, 47.11489391326904, 5.363298858915057, 0.5306854950530189, 0.3911038392356464, 0.5550227005566869, 0.17283748489405426, 0.12401123132024493, 24.48772736958095, 63.1188325881958, 53.987040996551514, 58.15952805110386, 49.020558970315115, 48.79054580415998, 44.377807412828716, 46.162174292973106, 45.168755599430625, 46.268592902592246, 43.59407493046352, 43.97935601643154, 42.5881599017552, 41.29027114595686, 36.64540386199951, 35.97934259687151, 35.90532691138131, 38.15932253428868, 37.95588622774397, 37.86391292299543, 37.27787058694022, 36.68565477643694, 36.979580947331016, 37.84314823150635, 37.39404099328177, 37.677927017211914, 37.48413481031145, 39.05158240454537, 38.997716494968955, 38.41645451954433, 36.372819083077566, 36.636326040540425, 38.05324786049979, 37.40358086994716, 37.24822262355259, 37.160456453050884, 35.37530790056501, 36.72807352883475, 35.36628566469465, 37.76950427464077, 37.308199473789756, 36.54658310753958, 37.550278186798096, 37.30120611190796, 37.55862644740513, 39.19358273914882, 37.47229160581316, 37.32044219970703, 35.656310422079905, 38.21974059513637, 38.94284657069615, 41.92093481336321, 45.92372253962925, 48.4668778691973, 52.538539613996235, 55.33776732853481, 50.41028206689017, 50.507351875305176, 50.4712872505188, 48.021995135716026, 45.24966389792306, 40.44621787752424, 37.914353370666504, 37.34418766839163, 35.7564582824707, 35.426057543073384, 34.45532124383109, 34.85890735898699, 34.32630014419556, 34.73750843320574, 33.33419466018677, 33.71925687789917, 34.449866907937185, 34.284829820905415, 34.01761947359358, 34.483892236437114, 33.84890331540789, 33.94892610822405, 35.690540722438264, 35.6731459072658, 33.373903615134104, 32.99810682024275, 32.4159311567034, 34.97766596930367, 34.39758171354021, 34.71036182131086, 33.872429915836875, 33.59413024357387, 32.58454656600952, 33.47265836170742, 35.092352935246055, 32.862985202244346, 36.42934267861502, 38.25433915002005, 44.08578852244786, 45.02241958890642, 45.914575236184255, 48.068259716033936, 45.963563510349815, 45.741749218532014, 46.31489222390311, 45.293670313698904, 46.25785446166992, 45.961805616106304, 46.690331186567036, 44.889368534088135, 46.53411136354719, 43.695737498147146, 45.362624236515586, 46.2089078766959, 47.531709398542134, 47.074035031454905, 50.02391011374337, 25.24264567238944, 0.8769923437918935, 0.21911727796707833, 0.9646837668759483, 1.618163364274161, 1.044001253587859, 46.408505303519114, 43.992043427058626, 39.01074089322771, 17.068402699061803, 22.904971156801494, 31.109881741659983, 6.932252040931156, 0.17373262186135563, 0.0497228052866246, 0.08064110497278826, 0.03005084694762315, 0.05703854254846062, 0.05457900916891439, 0.058202460807349, 0.010146935653340603, 0.04435665858909488, 0.03855826472863555, 0.055657849314489534, 0.048674909730574915, 0.08887106978467532, 0.02059100179134735, 0.04592037646632109, 0.06161887784089361, 0.06613309668110949, 0.014566632020952446, 0.017521911566810947, 0.014470931441922272, 0.041786683457238336, 0.039930890181234906, 0.020396150282717178, 0.014770977930831057, 0.031119356397539377, 0.020521750507344092, 0.05492882789777858, 0.07932615160409894, 0.03327621566131711, 0.05373971902632287, 0.03888077920834933, 0.056591245478817394, 0.09325031443898167, 0.05518760758319071, 0.04585839907771774, 0.044434218534401486, 5.340683775288718, 53.088044847760884, 45.84310259137835, 43.731607573372976, 39.898651191166465, 48.77361651829311, 48.618039403642925, 51.26418440682547, 5.833693640572684, 0.44297029610191074, 0.2947834048952375, 1.0039831038032259, 0.06028690681393657, 0.177420866808721, 29.28091437476022, 63.81953757149832, 56.33136320114136, 57.396268435886924, 50.806204319000244, 50.3423147882734, 46.71321855272566, 48.49212414877755, 47.97617176600865, 48.247102873665945, 45.106669970921104, 47.32839815957205, 44.98684481212071, 42.01755993706839, 39.428390162331716, 36.981818267277305, 39.2143543788365, 40.94483797890799, 39.58183765411377, 39.71938419342041, 39.84188093457903, 38.978087833949495, 39.12930147988455, 37.87352922984532, 39.504083837781636, 38.338492257254465, 38.56566708428519, 39.8286828313555, 41.77037082399641, 40.22557088306972, 39.28222438267299, 39.30224561691284, 40.07249511991228, 39.094247817993164, 39.521867752075195, 39.48014381953648, 38.92358616420201, 40.2075229372297, 37.82899822507586, 39.61822189603533, 38.84063856942313, 38.706545284816194, 39.64359671728951, 39.55047695977347, 38.92875214985439, 39.20070464270455, 39.246611390795024, 37.152132511138916, 37.24787173952375, 39.15929337910244, 39.47183724812099, 44.462384360177175, 47.600086620875764, 48.2377610206604, 51.897380692618235, 52.58026007243565, 50.97980853489467, 51.41991090774536, 52.62609039034162, 48.50989416667393, 48.35233334132603, 41.44601501737322, 39.68206194468907, 38.64840275900704, 36.43075663702828, 37.95260667800903, 36.95073550088065, 36.484320299965994, 35.735742228371755, 35.53260816846575, 36.322951861790244, 35.55058315822056, 37.157850878579275, 35.27311379568917, 34.77942344120571, 35.644057273864746, 35.79899862834385, 35.65744297845023, 36.28707831246512, 37.81272554397583, 36.42134877613613, 34.89775126320975, 35.0943991797311, 37.66676126207624, 37.14737299510411, 36.33663286481585, 34.62712240219116, 35.928238596235005, 35.26608221871512, 33.80459465299334, 36.39074543544224, 35.96909747804914, 38.837491035461426, 40.998085498809814, 46.29480498177664, 46.35454906736101, 47.3042288507734, 49.419090270996094, 48.01776368277413, 47.34206179210118, 47.733141149793354, 48.42215231486729, 48.34937688282558, 47.864684445517405, 49.322548525674, 46.83595500673567, 47.39608056204659, 45.88020944595337, 46.410940647125244, 47.442862783159526, 49.35559415817261, 49.58627782549177, 52.60317175728934, 27.264531510216848, 1.0570462793111801, 0.07817549870482512, 3.9175268156187872, 1.3143965899944305, 1.1374436680759703, 48.35779462541853, 50.104241711752756, 44.795168331691194, 25.87403542654855, 19.45889220918928, 37.960881982530864, 11.952461447034564, 0.20873882701354368, 0.08438123070767947, 0.057917951074029715, 0.03221061373395579, 0.08240404751683984, 0.03710214214931641, 0.013313948659093251, 0.05175923476261752, 0.032081498697932274, 0.04805484068180833, 0.044851171518010755, 0.029970318411609957, 0.011027223729927624, 0.05851563185985599, 0.07179019919463567, 0.03912195430270263, 0.11338782922497817, 0.1295947874230998, 0.1139596306851932, 0.2047803487096514, 0.21093770116567612, 0.10593879715140377, 0.10700865010065691, 0.11531223596206733, 0.10691655932792596, 0.11536812010620322, 0.17555383699280874, 0.17391613844249929, 0.1321051770022937, 0.18211457851741994, 0.1207019074686936, 0.19837934789913042, 0.18854700907000474, 0.1451906162713255, 0.24089255237153598, 0.18610608790602, 7.405633245195661, 61.14657252175467, 49.93353836877005, 48.54395771026611, 41.003550257001606, 50.472982610974995, 52.7626051221575, 57.71113995143345, 9.572358625275747, 0.59111956932715, 1.4738918372562952, 1.4856549203395844, 0.18987084446208818, 0.15960173654769147, 28.337632145200455, 65.07042176382882, 59.31639616830008, 61.232396670750205, 53.038188048771445, 53.14001389912197, 49.57944079807827, 51.81677464076451, 50.01727458408901, 50.70299577713013, 48.47258234024048, 49.54731232779366, 47.50139788218907, 44.73339884621756, 40.99107476643154, 39.76179947171892, 40.43601097379412, 44.15841456821987, 42.25699833461216, 41.40313768386841, 42.3502014705113, 41.52262238093785, 40.60790245873587, 41.62216574805123, 42.55798387527466, 41.81197663715908, 42.02903836114066, 43.661333492824006, 43.5830967766898, 43.37675264903477, 42.31521034240723, 40.72715091705322, 41.245986802237375, 40.94470248903547, 41.089145115443635, 42.70125225612095, 40.41179302760533, 41.8882018498012, 38.502278668539866, 43.41505459376744, 40.242687770298545, 40.400686332157676, 41.206823280879426, 42.00945833751133, 41.19707495825631, 41.23016227994646, 41.8015786579677, 38.63544436863491, 37.41070972170149, 40.22156177248274, 40.658784117017476, 45.05825144904, 50.844638279506135, 50.21064642497471, 53.41861234392439, 53.479537623269216, 53.30542966297695, 52.9035701751709, 54.02343218667166, 50.71314014707293, 47.944595677512034, 41.64550474711827, 42.13124636241368, 40.488487243652344, 37.78675317764282, 38.60722426005772, 38.01879174368722, 39.32325349535261, 38.37970549719674, 38.64684288842337, 38.11501734597342, 37.680431842803955, 39.256988525390625, 37.810422216142925, 37.7611768586295, 38.87600837435041, 39.06202207292829, 37.30573286328997, 39.22315774645124, 39.928990500313894, 37.893404551914756, 37.183816296713694, 36.51059143883841, 39.81543609074184, 38.86887257439749, 38.77951526641846, 37.22882672718593, 38.633005550929475, 37.95658104760306, 36.58274153300694, 39.029452392033164, 37.901895250592915, 39.604026726314, 42.72279861995152, 48.95188297544207, 48.6331239427839, 48.621888705662315, 52.934916973114014, 50.02109956741333, 47.440528188432964, 49.479039328438894, 50.6917952810015, 49.42113651548113, 50.21260929107666, 52.12064715794155, 49.16111060551235, 50.123877320970806, 48.08886112485613, 48.401971272059846, 51.16196598325457, 52.126560074942454, 51.58280100141253, 53.60989277703421, 28.261280127934047, 2.026756307908467, 0.521846843617303, 5.079919184957232, 4.800240729536329, 1.2746038224015916, 54.93697438921247, 52.54591165270124, 49.77809674399239, 29.349215166909353, 31.763828822544642, 46.69834245954241, 18.93261480331421, 0.2913301501955305, 0.19520404828446253, 0.23698386496731214, 0.15288140358669416, 0.12625847144850663, 0.23821863585284778, 0.15362342234168733, 0.10953381138720683, 0.15944617560931615, 0.13647248622562203, 0.12467513712389128, 0.10326212578053985, 0.14708892655159744, 0.12571796402335167, 0.15143277203398092, 0.12318743552480425], [0.014241623925045133, 0.06280672124453954, 0.08453219117862837, 0.10610664635896683, 0.01506002536708755, 0.05442887990336333, 0.07163709455302783, 0.07018782517739705, 0.03431931058210986, 0.11840448289045266, 0.08688364750040428, 0.036694943106600215, 0.011438258191836732, 0.02576123337660517, 0.11841858284814016, 0.044840878141777854, 0.054407492479575534, 0.08050793569002833, 0.05891376228204795, 0.07828143159193651, 0.06809031737170049, 19.187950679234095, 46.219635895320344, 38.30873659678868, 34.210894039699006, 31.6381185395377, 43.60510172162737, 51.48488351276943, 18.569182327815465, 0.2500545935971396, 0.08665691502392292, 0.525627857872418, 0.02790849985155676, 0.14956253953278065, 3.4154291408402577, 53.1474415234157, 55.297339235033306, 54.214782101767405, 52.64586843763079, 48.52079241616385, 49.270826135362896, 45.685437543051584, 47.18511240822928, 46.288985865456716, 47.551379748753135, 43.97310263769967, 45.49483455930437, 42.048201492854524, 38.93260840007237, 37.918855803353445, 38.14374467304775, 37.305343764168875, 37.50808872495379, 38.27323130198887, 36.96319014685494, 36.086834703172954, 38.39883041381836, 37.27200978142874, 35.247197014944895, 38.263090406145366, 38.916825566973, 37.21837316240583, 39.2450966835022, 39.42784472874233, 38.30658265522548, 34.508916173662456, 36.57327461242676, 37.334328174591064, 39.54243094580514, 36.82431302751814, 36.10399327959333, 36.60479164123535, 35.77732024874006, 36.916484355926514, 38.81150477273123, 36.17438547951834, 36.468155315944124, 36.40363086972918, 37.97880138669695, 38.38254731042044, 37.9603956086295, 37.22000251497541, 39.59108918053763, 39.23066874912807, 44.77539375850132, 41.752976008823936, 48.713969707489014, 47.87102467673165, 61.45910249437605, 79.78596987043107, 48.428443908691406, 54.80705349785941, 48.579793044498985, 45.796838011060444, 41.942300524030415, 40.82871968405587, 42.547707489558626, 40.55779899869646, 40.946797370910645, 39.36870861053467, 35.45106063570295, 34.92594705309187, 35.94295488085066, 33.59683656692505, 33.52341147831508, 33.941144125802175, 34.026603494371685, 33.093401363917756, 33.691384179251536, 33.04438877105713, 34.81699582508632, 32.328484603336875, 33.72468342099871, 33.71436187199184, 34.9924065726144, 34.94838278634207, 35.62283400126866, 32.617606094905305, 33.27316515786307, 32.75144577026367, 34.05752297810146, 32.37641327721732, 33.64726659229824, 34.58876487186977, 33.08656433650425, 32.08902188709804, 35.63110930579049, 37.98499570574079, 44.874405588422505, 46.04906456811087, 48.1724271093096, 48.29789073126656, 49.000405720302034, 47.82506929125105, 47.563625948769705, 46.31898123877389, 47.57164069584438, 46.53592831747872, 49.67391892841884, 45.927196638924734, 46.29648297173636, 45.66827549253191, 49.97765595572335, 45.896051338740754, 48.79133095060076, 48.25379398890904, 40.62488385609218, 11.317883338247027, 0.02449816758079188, 0.2236658510352884, 1.2155583564724242, 0.6960326454469136, 12.110390526907784, 52.08464854104178, 42.18397971561977, 31.42399937765939, 29.03093034880502, 29.58537401471819, 25.54311878340585, 1.6236904391220637, 0.46322179798568996, 0.008584483243924166, 0.01640525327197143, 0.03643521007948688, 0.014156373633470918, 0.04633933452091046, 0.08074336020009858, 0.03170531888359359, 0.036327149985092025, 0.03685019191886697, 0.011516533991588014, 0.06960370830659356, 0.039033296917166026, 0.03910258552059531, 0.0954128937529666, 0.045956545775490146, 0.01497458593387689, 0.04567612760833331, 0.04066691407933831, 0.04168954438396862, 0.027898476192993776, 0.03629404426153217, 0.10687022895685264, 0.019720792504293577, 0.014591630947377001, 0.07187168446502515, 0.06966400292835065, 0.03170464713392513, 0.014191235066391528, 0.04169570208926286, 0.03453894218962107, 0.02956651882933719, 0.026405997707375457, 0.08288746300552573, 0.05016105069911905, 0.08609514909663371, 0.2641343037996973, 29.997398717062815, 50.898987088884624, 39.217533179691856, 37.03524991444179, 38.93568992614746, 48.59989765712193, 58.97010489872524, 17.41549301147461, 0.20178505086473056, 0.15796996839344501, 1.1151452703135354, 0.010867047057087933, 0.16361216349261148, 4.242885334151132, 55.39622252328055, 56.36887305123465, 56.45962347303118, 53.103567123413086, 51.76806082044329, 51.09817109789167, 48.73292786734444, 50.45500067302159, 47.8864357812064, 47.786916732788086, 46.6817501613072, 45.897760595594136, 45.50858851841518, 41.44330174582345, 39.70545652934483, 39.90742676598685, 39.434570584978374, 39.58472810472761, 41.657903807503835, 39.40351561137608, 37.844002859933035, 40.21043075834002, 39.54091623851231, 38.74297816412789, 40.53524514607021, 41.66911472593035, 39.180909224918906, 40.85203783852713, 40.423111643110005, 40.549037320273264, 37.95590707233974, 38.25457886287144, 38.619602475847515, 40.399435656411306, 38.582259382520405, 36.67594466890608, 37.30790070125035, 38.888264996664866, 40.20510149002075, 40.53877483095442, 37.55475630078997, 38.80966697420393, 37.68935680389404, 39.96577078955514, 39.19557339804513, 38.847420011247905, 39.2582357270377, 40.41072300502232, 38.48951135362898, 42.46612868990217, 43.90802580969674, 48.17405298777989, 49.532547405787874, 52.52672072819301, 58.477755546569824, 53.41747978755406, 53.578955922807964, 51.10549797330584, 46.74883501870291, 41.164289883204866, 40.42484869275774, 41.71508748190743, 41.65751123428345, 42.08079201834542, 38.81918600627354, 37.33265018463135, 35.81289849962507, 35.89233725411551, 36.03334747041975, 36.49842861720494, 36.86135734830584, 35.90855087552752, 35.21697929927281, 36.72501632145473, 35.76542840685163, 36.720284598214285, 36.79391813278198, 37.33453662054879, 34.7336174419948, 36.73659202030727, 36.91523020608084, 36.00028099332537, 34.74789946419852, 37.062750884464805, 36.72820554460798, 36.714958803994314, 33.37337902614048, 36.10288156781878, 35.95420401436942, 35.69911479949951, 34.91288791384016, 37.84356164932251, 41.73616484233311, 46.2418075970241, 47.45840242930821, 49.57756131035941, 49.078142166137695, 50.58915301731655, 48.06797136579241, 48.367417880467, 47.621355056762695, 47.97334384918213, 48.343050548008506, 51.44237443378994, 47.78411660875593, 48.50440856388637, 48.270382813044954, 52.431502614702495, 47.15376213618687, 52.84186669758388, 47.87245600564139, 44.345873492104666, 12.8273013148989, 0.11605061776936054, 1.1970735426459993, 2.438770805086408, 0.8896500617265701, 12.3222028868539, 59.92453724997384, 45.498419829777305, 36.24546207700457, 28.44945124217442, 30.734119687761577, 34.457773957933696, 2.4255053911890303, 0.6042550301977566, 0.06230507351990257, 0.038151045329868793, 0.01326011199437614, 0.09839498052107436, 0.021583688345604708, 0.014170099548729402, 0.022787714809445397, 0.0994611286691257, 0.06606268510222435, 0.05892900896391698, 0.0929891938077552, 0.010888473496639302, 0.04197488871536084, 0.026610547177759663, 0.01816343080385455, 0.1273444260337523, 0.17283439077436924, 0.17410589754581451, 0.21284891718200274, 0.08806098039661135, 0.16777660431606428, 0.3551330694130489, 0.14737111569515296, 0.10020117967256478, 0.2644916746233191, 0.16019214343811783, 0.12127117120793887, 0.11955968875970159, 0.1077673336757081, 0.15039305282490595, 0.10592954871909958, 0.15925771929323673, 0.1767340400921447, 0.12795964016446046, 0.23693007071103367, 0.31682781342949184, 36.6504100390843, 58.52600383758545, 46.030537196568076, 46.20427690233503, 42.06179216929844, 55.607760429382324, 63.13347939082554, 25.556725093296595, 0.3104762099683285, 0.5227674256478037, 1.201764988047736, 0.0749209394146289, 0.16781312307076796, 5.504312549318586, 58.19931691033499, 58.39163957323347, 58.681768553597585, 56.57937567574637, 52.13403981072562, 54.550268922533306, 50.32898466927664, 52.55025427682059, 51.64763464246477, 51.07072571345738, 49.14066900525774, 49.5500499180385, 46.58104991912842, 43.57907724380493, 42.66453102656773, 43.34991523197719, 42.7131336757115, 42.54753378459385, 44.5888728414263, 41.76023687635149, 39.229786327907014, 42.34848179136004, 42.34281553540911, 38.815288066864014, 43.51153727940151, 44.78556939533779, 41.799257959638325, 41.94277647563389, 43.27375602722168, 41.48335811070034, 39.41849940163748, 40.771949427468435, 39.986274923597065, 42.13955640792847, 40.07085534504482, 37.58699246815273, 39.3477007320949, 40.40838146209717, 42.252808570861816, 42.50625801086426, 39.807713168007986, 39.80175508771624, 40.18782132012503, 41.77382755279541, 41.5429493359157, 40.25879716873169, 38.81841128213065, 42.29360144478934, 40.31644984654018, 45.4601491519383, 45.214797837393625, 49.80032055718558, 50.95884929384504, 55.182329177856445, 62.417120116097585, 54.07289988654, 56.67734180177961, 51.87053632736206, 49.18287236349923, 44.39552184513637, 42.60290397916521, 44.20635713849749, 44.13379710061209, 43.97819914136614, 42.10982854025704, 39.69585411889212, 38.30796882084438, 38.71561963217599, 37.84750475202288, 38.67534787314278, 39.59690134865897, 37.75514234815325, 36.66367762429373, 37.696680205208914, 37.76575919560024, 38.54648310797555, 37.80939735685076, 38.4461476462228, 38.21939665930611, 39.59678322928292, 39.779704979487825, 39.693901675088064, 35.8766655921936, 37.55658367701939, 38.977198464529856, 38.874903610774446, 34.024529457092285, 37.846969740731375, 38.4460642678397, 37.42116328648159, 38.092623301914756, 39.83665936333792, 43.85734217507498, 48.51395191465105, 49.21714435304914, 51.871929441179546, 51.383700370788574, 50.1213447025844, 48.23232405526297, 49.38231692995344, 47.96433898380825, 50.47235032490322, 49.109346526009695, 53.38880109786987, 50.24334117344448, 49.83145196097237, 51.039722851344514, 54.95334087099348, 49.81547110421317, 53.47825220652989, 48.67344781330654, 45.12728875023978, 14.356998477663312, 0.28926360394273487, 0.6812318425093378, 5.680949653897967, 1.7111626139708926, 13.783465504646301, 62.460330963134766, 51.20756353650774, 40.71568986347744, 40.79035867963518, 39.81866700308663, 44.20331382751465, 5.910272342818124, 0.8641546240874699, 0.1537212399499757, 0.1927778920424836, 0.2144745106675795, 0.1500813609787396, 0.17531260422297887, 0.16270740489874566, 0.180519396971379, 0.20623866974243096, 0.14287564477750234, 0.07138735295406409, 0.15542494638689927, 0.16416736798627035, 0.1318005419203213, 0.18586603578712257, 0.16530034504830837], [0.05119368260992425, 0.018160591134801507, 0.049050835094281604, 0.026842156624687568, 0.014163204784771162, 0.045160705622817786, 0.03746866641033973, 0.015383942717952388, 0.02265968034043908, 0.021466897201857398, 0.022419533226639032, 0.04886843470324363, 0.029744162689894438, 0.034073263606322665, 0.03909401562330978, 0.03427014732733369, 0.002887159931041034, 0.05331622835780893, 0.04659055193353977, 0.05171048541420272, 0.05515642211373363, 2.705732537167413, 39.82073756626674, 42.97049495152065, 35.28421354293823, 25.72166837964739, 38.150609493255615, 47.431036949157715, 44.22621161597115, 1.6811188203947884, 0.23166474753192492, 0.24476875151906693, 0.31617316284349983, 0.12737696857324668, 0.029564652858035903, 24.019875628607615, 59.52334131513323, 57.5251818384443, 54.821828842163086, 52.14607061658587, 51.50060033798218, 47.073305470602854, 46.45596497399466, 45.561148166656494, 47.42931727000645, 46.458369050707134, 46.70582219532558, 43.59036111831665, 41.9553006035941, 39.785134996686665, 37.86045619419643, 38.18842158998762, 37.668873514447895, 38.67909642628261, 40.58817999703543, 38.99223436628069, 40.751111779894146, 38.47452408926827, 37.377882957458496, 36.44206830433437, 37.35221631186349, 38.38895007542202, 37.61590739658901, 38.51133564540318, 39.555121830531526, 36.41342088154384, 37.556562832423616, 36.81343214852469, 39.67241784504482, 37.01653494153704, 38.341236795697895, 37.14225217274257, 36.68319858823504, 37.839184284210205, 39.42587144034249, 37.46230009623936, 36.71270758765084, 37.39680290222168, 37.59599733352661, 38.207737582070486, 38.330731119428364, 37.001248904636924, 41.51734869820731, 40.97537183761597, 47.86428492409842, 47.302502223423545, 49.192061356135774, 50.875613348824636, 66.51889882768903, 99.95643751961845, 54.36429691314697, 54.77734994888306, 51.65572929382324, 45.749062197549, 43.78382328578404, 45.19539499282837, 47.09013748168945, 48.45114367348807, 47.04729836327689, 42.57226242337908, 37.29905564444405, 36.744519914899556, 34.414201804569785, 35.59807756968907, 34.68200969696045, 35.769020625523154, 33.39390400477818, 35.481469426836284, 35.06167663846697, 35.18481956209455, 34.17132404872349, 35.940450055258616, 36.18444994517735, 34.363876002175466, 33.09147671290806, 32.981375558035715, 34.168437072208945, 33.53239549909319, 33.836559840611045, 33.79938350405012, 33.01884024483817, 34.79819399969918, 33.97581216267177, 34.00170462472098, 34.548131806509836, 34.981324195861816, 34.64404126576015, 35.936673709324424, 42.43058865410941, 45.22621372767857, 46.11191102436611, 46.48763138907296, 48.97375937870571, 46.12468181337629, 48.03932741710118, 48.99367986406599, 48.02817208426339, 49.1777480670384, 47.10527065822056, 46.81538486480713, 48.0111038344247, 48.03199359348842, 46.95562383106777, 46.32915687561035, 47.4866155896868, 42.70358337674822, 30.848990780966624, 2.8893688661711554, 0.1487230695784092, 0.45820547001702444, 2.273869207927159, 0.30394677604947773, 25.742017916270665, 53.54176568984985, 37.90560558864048, 41.21775279726301, 38.030770438058035, 25.55323883465358, 19.765293870653423, 0.20128624620182173, 0.06094530291323151, 0.043875909743032286, 0.0051349121411996225, 0.045509411554251394, 0.03374462534806558, 0.04123543143006308, 0.015339086464207088, 0.06792664115450212, 0.0633682564699224, 0.06940746919385024, 0.027978417796215842, 0.0187079839940582, 0.02503215428441763, 0.0671479000842997, 0.056116128473409584, 0.04781863246379154, 0.06401234905102424, 0.04571449537096279, 0.033299815109265704, 0.02756048772217972, 0.12378645980996744, 0.030414884377803122, 0.03920128183173282, 0.047963591292500496, 0.03637322251285825, 0.1107171628890293, 0.07298396620899439, 0.032032712030091455, 0.0430692401714623, 0.07295843293624264, 0.05167688775275435, 0.07695941467370306, 0.08414133465183632, 0.038053037731775215, 0.033408323036772866, 0.03342156804033688, 0.1903744260115283, 6.95167920419148, 52.71746615001133, 45.5877354485648, 41.20535026277815, 37.04857308523995, 45.90127290998186, 49.82961416244507, 47.22232001168387, 1.0641242137977054, 0.3003613698695387, 0.24382290084447178, 0.4848519744617598, 0.4405911351953234, 0.1723960842937231, 28.31056891168867, 58.16778598512922, 56.27558306285313, 57.24729905809675, 54.08892938068935, 50.799085889543804, 48.83717169080462, 48.05181680406843, 47.56723206383841, 48.872913224356516, 47.30509737559727, 47.25963183811733, 44.90287930624825, 44.148499488830566, 41.5254294531686, 40.014074666159495, 40.15539755140032, 41.54423475265503, 39.22233438491821, 43.38092851638794, 40.655205794743125, 41.00282417024885, 39.863545417785645, 40.34250211715698, 37.4386762210301, 38.02162313461304, 41.5417229788644, 40.69749253136771, 38.694215706416536, 42.186203139168875, 39.46097721372332, 38.295152868543354, 38.9947635105678, 41.5975204876491, 40.69753769465855, 38.558110918317524, 39.14113426208496, 39.713523387908936, 38.92098406382969, 41.402491501399446, 38.49473639896938, 37.827744075230186, 38.335594858442036, 39.670732906886506, 38.577010018484934, 37.62955365862165, 40.65231187002999, 42.85752419063023, 42.79776273454939, 47.389841079711914, 45.648942129952566, 51.6579145022801, 51.932288442339214, 63.66499573843819, 82.31163311004639, 49.938985756465364, 56.311269010816304, 51.417416504451204, 45.918143136160715, 42.98564549854824, 46.000121457236155, 47.175058364868164, 48.33473355429513, 48.09060164860317, 42.7729298727853, 38.412007672446116, 38.78084584644863, 36.971795490809846, 35.50840759277344, 35.589156082698274, 37.416890144348145, 35.79873807089669, 36.65397099086216, 37.8145946093968, 36.487492152622764, 37.36570623942784, 38.4255427633013, 38.94613306862967, 37.2555946622576, 36.51933922086443, 35.84963362557547, 37.06960875647408, 35.33722134998867, 37.65014811924526, 35.34610462188721, 35.60545308249337, 36.98701899392264, 34.811242716653005, 36.86025953292847, 36.44686256136213, 36.17793253489903, 35.096435001918245, 38.328545910971506, 44.77452175957816, 48.34858478818621, 48.839450699942454, 49.19595234734671, 51.18295996529715, 48.07957138334002, 48.8942928314209, 49.68810020174299, 49.715535163879395, 48.28758307865688, 49.117663519723074, 48.286377566201345, 51.35148157392229, 50.349846635546, 49.17513901846749, 45.83618218558175, 48.76079709189278, 44.49035433360508, 33.886510440281455, 3.8692568114825656, 0.0703493504385863, 2.5396751505987982, 2.687240340879985, 0.32363650522061754, 28.651216506958008, 59.90063544682094, 43.64629759107317, 50.30182763508388, 41.8235627583095, 30.47288826533726, 26.69910969052996, 0.18061736385737145, 0.025683742981137972, 0.06574488644089017, 0.03916475289900388, 0.05372189391138298, 0.0368720678878682, 0.10009090416133404, 0.02410204053324248, 0.009340942072282945, 0.025042106696803654, 0.07051688752004079, 0.08416342096669333, 0.0410191958903202, 0.05944466165133885, 0.0506209379860333, 0.027148884987192493, 0.02820266004917877, 0.10964114884180681, 0.10852717076029096, 0.0847165694992457, 0.2060244426663433, 0.20068059941487654, 0.10535037836858205, 0.06811050378850528, 0.23955591980900082, 0.16500791002597126, 0.13043607585132122, 0.14447736740112305, 0.23942748670067104, 0.1196444242128304, 0.10983196645975113, 0.10874776928020374, 0.1796709160719599, 0.1916236632636615, 0.18403294629284314, 0.15388145563857897, 0.15736505442431994, 0.23897913790174893, 7.890032121113368, 61.14619731903076, 51.47589601789202, 49.20440135683332, 34.766419887542725, 50.482970646449495, 52.815352371760774, 55.600857394082205, 2.0505573621817996, 0.3082489866231169, 0.6499145744102341, 0.5167615222079414, 0.30849676047052654, 0.24007364202822956, 27.8646856376103, 59.866901942661826, 59.73556709289551, 58.08107246671404, 57.39588975906372, 55.14653205871582, 51.93722513743809, 51.0836215700422, 50.242865221840994, 51.989666666303364, 49.56480441774641, 51.38634416035244, 47.865917750767295, 45.39233125959124, 45.40718650817871, 42.699796608516145, 42.94448437009539, 42.309009075164795, 42.91991206577846, 45.751087597438264, 44.34674201692854, 45.146194798605784, 42.45831544058663, 41.33267600195748, 40.963674545288086, 40.48530496869768, 41.93304204940796, 42.66683088030134, 42.052113328661235, 44.5842661857605, 39.154325417109895, 39.04430069242205, 40.19518641063145, 44.21200254985264, 42.61573035376412, 42.54504632949829, 40.354612827301025, 40.7825072152274, 41.307804925101145, 44.64520188740322, 40.54814795085362, 39.58408887045724, 39.7266137940543, 41.85385343006679, 40.70108822413853, 40.35633945465088, 41.48335811070034, 45.828591278621126, 43.598890032087056, 51.88459600721087, 47.44132375717163, 53.742975098746165, 52.5201164654323, 71.99519102913993, 89.75571073804582, 47.96718079703194, 59.07798263004848, 53.350179536002024, 50.02253089632307, 45.76075254167829, 49.07147536958967, 50.08033990859985, 50.35291426522391, 50.15534223828997, 46.41752406529018, 39.72770118713379, 41.47588184901646, 38.14633635112217, 38.090264388493125, 38.27107041222708, 39.9516589982169, 38.66326148169381, 38.46893426350185, 39.43297597340175, 37.26575640269688, 38.34817109789167, 39.8463590485709, 40.20400020054409, 38.53151321411133, 38.22716474533081, 37.42949070249285, 39.52646745954241, 37.95964172908238, 39.8774904523577, 39.200006348746165, 37.84926264626639, 40.88769251959664, 35.90583412987845, 38.54645878928048, 38.67316266468593, 38.93179893493652, 37.93685163770403, 39.78267880848476, 47.78488785879952, 50.20818328857422, 49.18356023515974, 49.182271344321116, 52.98804289954049, 48.417344161442344, 51.15546594347273, 50.97826256070818, 50.55558974402291, 50.24549511500767, 51.43270948954991, 48.95491933822632, 52.54505007607596, 51.00385972431728, 51.22524322782244, 47.055848121643066, 49.16667263848441, 45.916882038116455, 36.07523121152605, 4.205048484461648, 0.2115174957684108, 2.5553882845810483, 8.157300659588405, 1.9238960444927216, 30.8061968258449, 63.147820472717285, 47.856308392116, 51.052983488355366, 48.58330883298601, 40.44557516915457, 35.733591760907856, 0.328468135957207, 0.1871292372899396, 0.1516288686543703, 0.12244437182588236, 0.14343444550676004, 0.1373794297022479, 0.1348144587661539, 0.1045758645715458, 0.14397939055093698, 0.1830054678555046, 0.10315496474504471, 0.12638185625629766, 0.10632340437067406, 0.143382157598223, 0.15965285737599644, 0.07776418434722082, 0.12658433110586234], [0.018809111156900014, 0.008799023294289197, 0.06511976569890976, 0.1091049365433199, 0.10558668497417655, 0.045279873335467916, 0.08114383835345507, 0.02769310399889946, 0.08044977845357996, 0.0632926540981446, 0.053966407398028035, 0.038943424953946044, 0.09396337331937892, 0.07258938452494995, 0.04802662041038275, 0.02020933771772044, 0.012397632917522319, 0.05723709546561752, 0.0532043922160353, 0.02949799018512879, 0.039647055590259175, 0.1431968632553305, 19.437939916338237, 48.983674458095, 37.13130528586251, 25.458524465560913, 27.803986174719675, 42.16740131378174, 53.04016828536987, 16.317531721932546, 0.5103356327329363, 0.14582586075578416, 0.2739191858896187, 0.5390278388346944, 0.07637273972587925, 7.210096171924046, 53.93521090916225, 54.09876108169556, 57.634247711726594, 50.937355041503906, 50.98407472882952, 45.660441398620605, 47.47505031313215, 46.05959456307547, 46.95656531197684, 46.493391445704866, 45.27313838686262, 44.974056652614046, 46.08306210381644, 41.23971257890974, 39.81865658078875, 39.60183456965855, 40.703520093645366, 42.50381919315883, 43.384611061641145, 42.42379331588745, 43.4662697655814, 41.09973069599697, 43.143348761967246, 43.52384601320539, 42.54116576058524, 37.87245225906372, 37.68403448377337, 39.00326810564314, 37.47063446044922, 40.0901643889291, 38.33414615903582, 38.618872914995464, 38.96917676925659, 38.967259066445486, 37.07379504612514, 36.887850829533164, 36.331984519958496, 38.41911220550537, 37.79224920272827, 38.01721797670637, 36.809002671922954, 37.518566608428955, 37.7421144757952, 37.85926110403878, 38.124206338609966, 37.21341214861189, 38.74724783216204, 42.71547521863665, 48.58023772920881, 50.73013891492571, 50.439478397369385, 53.5665533883231, 43.148698874882285, 44.041410378047395, 81.07210227421352, 53.44231264931815, 50.07849168777466, 48.22476094109671, 47.899345534188406, 50.59765413829258, 49.423585755484446, 51.35084581375122, 49.62220001220703, 48.117755208696636, 42.35809462411063, 36.31977653503418, 35.194262163979666, 35.599217074257986, 34.74749646868025, 35.35949032647269, 34.732470989227295, 35.6938967023577, 36.712634631565635, 36.415376799447195, 34.987066881997244, 35.07082741601126, 35.737482752118794, 35.61143895557949, 35.08075291769845, 33.99050065449306, 36.31667069026402, 36.621119907924104, 33.373424189431326, 34.90672486168997, 33.708643504551475, 33.773428508213584, 34.30631365094866, 33.97525978088379, 32.80566256386893, 34.83624928338187, 35.116817542484824, 35.61883183888027, 35.99215160097395, 42.27186400549752, 45.219845703669954, 45.88691793169294, 45.17898334775652, 46.741487298692974, 44.671806539808, 46.40229361397879, 45.163739000047954, 48.28761434555054, 47.273090498788015, 47.68701205934797, 45.37973070144653, 47.907388074057444, 45.3123505456107, 49.41620676858084, 44.3841997555324, 42.38105494635445, 19.917356933866227, 0.04201193333470395, 0.25297419407538, 3.145978433745248, 2.220490106514522, 0.3290919539119516, 35.35601970127651, 50.35909816196987, 26.94772318431309, 26.43171521595546, 23.26576852798462, 38.27787617274693, 8.10833844116756, 0.560950871024813, 0.008539508246550602, 0.09804784200553383, 0.03554314687581999, 0.13971306090908392, 0.04342612584254571, 0.02889229590073228, 0.0594421782131706, 0.06207642078931842, 0.00296739415248989, 0.03957183659076691, 0.01327160298491695, 0.021641202670122896, 0.018702900070430975, 0.0415680153694536, 0.042964766134641, 0.021909147667299424, 0.040085860794144015, 0.02769916331661599, 0.027256644829841595, 0.065177081551935, 0.10960391083998339, 0.04273379620696817, 0.02653008819158588, 0.035356227441557815, 0.043973764670746665, 0.0634594787178295, 0.07499409906033959, 0.04692581269357886, 0.09270370698400907, 0.0838170356250235, 0.06216585849012647, 0.057393986332629404, 0.0473646145047886, 0.0419348483639104, 0.031721980310976505, 0.1165670779134546, 0.10882620114300932, 0.334927246506725, 28.234065771102905, 52.58238969530378, 35.625550746917725, 30.338965211595806, 38.17517484937395, 48.00661529813494, 59.167510168892996, 16.272795745304652, 0.8453412907464164, 0.4785024066056524, 1.8646635200296129, 1.0336376896926334, 0.4365941025316715, 8.747386847223554, 55.429542609623496, 56.054904801504954, 59.14941011156355, 52.66733142307827, 53.3185270173209, 48.16168172018868, 50.39461735316685, 49.07579367501395, 50.83716549192156, 47.35696567807879, 48.57410594395229, 47.92075988224575, 46.4922137260437, 43.151985372815815, 39.467696121760774, 40.95099755695888, 44.034517765045166, 44.967772006988525, 43.13251999446324, 43.46833685466221, 44.04929658344814, 43.07016338620867, 45.340928486415315, 42.98438787460327, 44.32046740395682, 39.81519290379116, 41.063360350472585, 41.52752086094448, 39.2154278755188, 42.74890647615705, 39.62464203153338, 40.47523702893938, 39.50527892793928, 40.02832194737026, 39.808237757001606, 38.42906897408621, 39.967879567827495, 40.13825287137713, 39.03604275839669, 40.191340582711355, 37.922576563698904, 37.71093443461827, 40.307302543095176, 39.682909624917166, 40.21156331471035, 37.43825932911464, 41.66427183151245, 44.167044230869834, 49.874485628945486, 51.754251275743755, 51.9858729498727, 53.78530352456229, 47.797693388802664, 58.10804884774344, 63.74443449292864, 53.55234432220459, 51.56174795968192, 47.306379318237305, 48.58152314594814, 49.07456384386335, 48.73574536187308, 50.00232206072126, 50.57936647960118, 51.441335678100586, 44.7961619240897, 37.7700149672372, 38.41894544873919, 37.24794122150966, 36.19792945044381, 36.6142828805106, 36.98689045224871, 36.83861242021833, 38.17348991121565, 39.14041512353079, 36.52715594427926, 36.33337763377598, 38.076732771737234, 37.182228633335654, 37.177198137555806, 34.7899569102696, 38.88317544119698, 38.3608307157244, 35.870276723589214, 37.52834619794573, 36.55338191986084, 34.94157702582223, 37.074337005615234, 34.91886336462838, 35.838943822043284, 36.64681434631348, 36.93537998199463, 37.42572130475725, 38.161782196589876, 43.626620292663574, 46.01783241544451, 48.04823848179409, 47.5873818397522, 49.64767210824149, 47.229820592062815, 47.77835307802473, 47.2180746623448, 49.79476547241211, 48.106881277901785, 49.8292042187282, 45.83011293411255, 48.7950690814427, 45.99459763935634, 50.08749655314854, 44.82942642484392, 44.59196826389858, 20.426696368626185, 0.15978177902953966, 1.2703843116760254, 4.177041164466313, 2.0574267421449934, 0.3514745442995003, 39.712571484701975, 54.040816579546245, 33.66596072060721, 39.912467684064595, 31.3380605833871, 40.998599665505544, 13.217660665512085, 0.728483718420778, 0.03403618845290371, 0.20324255765548774, 0.06179834356797593, 0.04587867031139987, 0.045166018552013805, 0.05969744308718613, 0.06049067088003669, 0.09588767149086509, 0.028287203816164817, 0.020692215467404042, 0.010763235440078591, 0.006646275952724474, 0.006431830897262054, 0.02939606404730252, 0.03265173613492932, 0.02587344271263906, 0.10631022043526173, 0.08397446253470012, 0.2281446164207799, 0.14102772250771523, 0.19685672888798372, 0.10692884759711367, 0.22825605901224272, 0.1371437202074698, 0.11874668167105742, 0.1380286520080907, 0.16618170775473118, 0.11153645999729633, 0.15361774978893145, 0.17593423729496344, 0.14479659098599637, 0.15807417780160904, 0.2052207722195557, 0.10902313914682184, 0.23022098786064557, 0.23225898135985645, 0.27461254011307445, 0.28306944774729864, 36.283295018332346, 59.16869136265346, 44.892919063568115, 33.83703926631382, 39.32731124332973, 51.92534024374825, 63.4800694329398, 21.03178719111851, 0.9425777473620006, 0.9997857404606683, 1.3291437072413308, 1.8639771682875497, 0.346740432615791, 9.599393197468348, 55.26728132792881, 58.23951571328299, 61.024715014866416, 54.1446122441973, 56.08504956109183, 51.73056486674717, 53.821017265319824, 51.39660317557198, 53.486878395080566, 51.00685092381069, 51.22054624557495, 50.208075591496055, 51.6340856552124, 45.77861636025565, 43.46875374657767, 43.310737814222065, 45.55992528370449, 48.12683997835432, 47.640545981270925, 47.14432648250035, 46.77085386003767, 45.85211787905012, 49.10958971296038, 46.102447577885215, 47.96341139929635, 41.55058888026646, 42.81856216703142, 43.65167897088187, 41.374868937901084, 44.154725074768066, 42.77129009791783, 41.8865829195295, 42.933780670166016, 42.10238354546683, 40.77769211360386, 40.68117816107613, 39.70589426585606, 43.576079096112935, 41.46539354324341, 43.09971407481602, 39.52979564666748, 39.808543477739605, 40.961590085710796, 41.21646390642439, 41.115607329777305, 40.010524136679514, 43.143081256321494, 45.17680161339896, 54.80033458982195, 51.01454952784947, 54.26757451466152, 53.86143841062273, 51.791785444532124, 67.06203951154436, 63.48289734976632, 54.390324865068706, 52.000710827963694, 49.8710914339338, 51.4657655443464, 52.23351716995239, 51.9518962587629, 52.48300266265869, 51.98214176722935, 52.2047620500837, 47.12839426313128, 38.17891298021589, 39.924762521471294, 39.0696234021868, 38.643469538007466, 38.85948208400181, 38.89945159639631, 39.55063329424177, 39.78624323436192, 41.389321190970286, 39.27390044076102, 38.58228717531477, 39.097937311444966, 40.28048597063337, 38.61823715482439, 36.65962335041591, 41.675010272434776, 42.14513233729771, 38.250354358128135, 39.48939882005964, 38.337231159210205, 37.58098227637154, 38.47239099230085, 37.72568893432617, 37.36252049037388, 38.000542300088064, 39.36514071055821, 39.43483461652483, 39.59646361214774, 45.98345620291573, 50.165809699467246, 50.061802114759175, 51.37172515051705, 52.379787172589985, 48.98915311268398, 50.91643401554653, 49.29562773023333, 52.44733755929129, 49.86733940669468, 51.70048611504691, 46.417072432381765, 48.517186301095144, 47.245846612112864, 50.080520561763215, 47.32827309199742, 45.319739954812185, 22.011641263961792, 0.31872336885758806, 1.4788654446601868, 8.325830084936959, 7.617062585694449, 0.42886241312537876, 44.59668609074184, 58.94579315185547, 36.795008999960764, 37.22197927747454, 34.777550901685444, 51.52458899361746, 19.552639041628154, 0.8508981125695365, 0.1910212870155062, 0.2620135833110128, 0.12702077840055737, 0.22960202821663447, 0.15078312903642654, 0.12957664339670114, 0.13714594580233097, 0.18516232711928232, 0.10597253391253096, 0.12038313171693257, 0.16259722438241753, 0.16657384671270847, 0.08191742255751576, 0.15928385646215507, 0.1260280002440725, 0.13524241080241545], [0.04247140332258173, 0.06419974006712437, 0.04828070802614093, 0.05435253114306501, 0.0455370720342866, 0.09639171444411788, 0.01819186651014856, 0.046710126767201085, 0.009936214058793016, 0.028345573094806502, 0.035394127015024424, 0.08512367693973438, 0.01953081626977239, 0.08254445676824876, 0.008331963892227836, 0.04293829648356352, 0.017769157853243605, 0.01283485459030739, 0.03842968573527677, 0.015265825038243617, 0.09893958629774195, 0.1257428933999368, 5.743353162493024, 48.15170758111136, 47.20962217875889, 42.04089893613543, 29.20400129045759, 35.83680725097656, 48.600220748356406, 36.22993632725307, 0.05736549464719636, 0.5597127888883863, 0.6437899544835091, 0.8666560841458184, 0.13492351291435106, 0.3964464339826788, 34.69798707962036, 60.73491259983608, 54.320822034563335, 53.72222082955496, 50.11983346939087, 48.69624137878418, 46.24316596984863, 47.70360435758318, 44.74492938177926, 46.81293909890311, 45.62581157684326, 47.9487680707659, 44.01142195292881, 40.87080144882202, 38.26154443195888, 41.74159138543265, 41.600355352674214, 42.97428171975272, 44.96853283473423, 44.27270548684256, 46.475941044943674, 47.13696486609322, 52.56683962685721, 53.518930435180664, 50.0728497505188, 44.36746154512678, 40.60015869140625, 38.02445452553885, 38.57521390914917, 40.745511531829834, 40.85170432499477, 37.1622108731951, 37.72038745880127, 38.46065548488072, 38.550905636378694, 38.67174523217337, 38.585208892822266, 38.2049617767334, 38.91847229003906, 39.40174034663609, 37.35509981427874, 36.741021496909006, 38.14390100751604, 38.16210181372506, 37.658298356192454, 35.759477274758474, 38.66589137486049, 43.30623885563442, 49.956523009708945, 53.927494934626985, 52.057091985430034, 49.576189041137695, 42.60720491409302, 18.004679407392228, 65.78155599321637, 62.74306011199951, 47.00064468383789, 53.72077213014875, 51.121548312050955, 52.34769344329834, 50.051991258348735, 52.937585081372944, 48.91651317051479, 50.85508489608765, 41.46140875135149, 36.071684156145366, 36.76449251174927, 36.27551998410906, 34.58706603731428, 35.097532817295615, 34.859570911952424, 35.45105021340506, 35.507942063467844, 36.23026636668614, 36.33840118135725, 35.16370746067592, 35.55723605837141, 36.31948471069336, 35.02080733435494, 34.63052701950073, 33.76338141305106, 35.27523299625942, 34.59687689372471, 32.8098349571228, 35.16811956678118, 35.96099935259138, 33.317213262830464, 33.672714369637625, 35.26312576021467, 33.402210576193674, 33.25134434018816, 35.38075876235962, 33.417166573660715, 36.51740067345755, 37.38592897142683, 38.97514527184622, 40.722127369471956, 41.29137590953282, 41.49246025085449, 43.71048852375576, 44.174885272979736, 46.40880407605852, 46.46293749128069, 49.81658629008702, 46.54480464117867, 48.63331849234444, 45.129501751491, 50.663839203970774, 47.760940892355784, 40.10643359592983, 2.5901292775358473, 0.2037196491977998, 0.9538555421999523, 1.0128302233559745, 1.8380879632064273, 2.807390979358128, 50.97352041516985, 42.89350891113281, 23.64943242073059, 27.301659209387644, 27.720369815826416, 35.11919035230364, 1.6706887057849338, 0.22286180060889038, 0.029668081950928484, 0.06071620234953506, 0.05043008644133806, 0.03796223278290459, 0.014180303019072329, 0.014480318973905273, 0.08513986678527934, 0.07963843377573149, 0.027690154067905884, 0.0832782041813646, 0.04248462797009519, 0.04282024156834398, 0.04232588470248239, 0.03503699707133429, 0.03174003612782274, 0.10551646338509661, 0.048974923989070315, 0.032824752386659384, 0.01971884850146515, 0.057015295938721726, 0.020428399355815988, 0.02658034728041717, 0.060628155645515235, 0.06864056855972324, 0.04196141640256558, 0.10020125431141683, 0.07751753686794213, 0.07224188638584954, 0.0783157315371292, 0.1959964550499405, 0.056810239263411076, 0.06178551247077329, 0.057087858473615985, 0.0456906448650573, 0.09493481833487749, 0.03980088626433696, 0.03095870983919927, 0.12248954868742398, 11.062695980072021, 58.63389546530587, 45.7562118938991, 38.24847139630999, 35.39558274405343, 40.475129331861226, 54.52361910683768, 38.62541464396885, 0.12684226940785134, 0.2669324465095997, 3.6529910905020575, 3.8801398617880682, 0.6245222740939685, 0.6346600758177894, 40.489515577043804, 59.08373573848179, 55.42407785143171, 56.50568308149065, 54.60814394269671, 50.688640798841206, 48.49576153073992, 49.04014594214303, 48.43414837973458, 49.350198881966726, 48.36185932159424, 50.14297097069876, 46.12211792809622, 42.3139978817531, 41.223304407937185, 44.05799225398472, 43.14341824395316, 44.53336020878383, 45.41617400305611, 46.1843147277832, 48.45786258152553, 47.65173258100237, 54.85345356804984, 56.71990646634783, 51.8735032081604, 44.765801770346506, 42.199151107243125, 41.41258028575352, 39.939041069575715, 41.99140344347273, 41.236398288181846, 39.61106872558594, 39.13694797243391, 40.15260437556675, 39.90289306640625, 40.33928162711007, 41.486022744859966, 39.65189634050642, 40.9492952483041, 42.22381026404244, 39.536976609911235, 38.565201554979595, 38.504807812826975, 39.56231321607317, 38.891905852726524, 36.90756981713431, 38.51163789204189, 44.09299727848598, 51.43821593693325, 54.00069420678275, 51.60822098595755, 52.67086805616106, 41.182007789611816, 23.86495164462498, 67.02890355246407, 56.8414443561009, 51.54277242933001, 53.916964939662385, 52.04520014354161, 52.00702674048287, 49.852841990334646, 53.87012365886143, 50.29745374407087, 53.06536245346069, 44.4270875113351, 37.29426138741629, 37.32018164225987, 37.16262429101126, 36.43755892344883, 37.521731512887136, 37.01730271748134, 37.759460653577534, 36.187027726854595, 38.407873494284495, 38.086439405168804, 36.99090303693499, 36.692158290318076, 38.68550961358206, 36.650740078517366, 35.634760584150044, 37.02351788112095, 37.87525238309588, 36.0881861277989, 35.53764908654349, 37.01420382090977, 37.05273158209664, 34.95238842282976, 35.821271078927175, 37.03020204816546, 36.02620472226824, 36.40852240153721, 36.45424502236502, 35.59808104378836, 38.676525592803955, 40.46335908344814, 41.5264230455671, 42.90296540941511, 44.58804600579398, 43.423844064985005, 45.64670133590698, 46.30368477957589, 48.0695173399789, 49.21805109296526, 50.84162276131766, 47.369795526777, 48.15622738429478, 47.350677558353965, 49.45027378627232, 47.342541217803955, 40.79169620786394, 3.7351604870387485, 0.3460034621613366, 2.4757823390620093, 2.59736539210592, 1.3983737123864037, 2.7831934435026984, 53.90762308665684, 46.95506797518049, 32.21668461390904, 29.37764024734497, 27.016595465796335, 43.059466634477886, 2.8321708611079623, 0.3137689232826233, 0.01303487823211721, 0.09845285277281489, 0.034689509110259156, 0.07872966503990547, 0.020543015794828534, 0.05148779022108231, 0.03973632365731256, 0.06178779913378613, 0.05497368584786143, 0.07558699617428438, 0.07705434850816216, 0.0821106286187257, 0.054738410615495274, 0.029186627428446497, 0.10187585838139057, 0.018458211861018623, 0.15540184905486448, 0.15847791970840522, 0.1313332755650793, 0.10845751235527651, 0.12170729280582496, 0.24731464205043657, 0.16594264629696096, 0.15641577036253043, 0.11010559249137129, 0.18459253412272247, 0.1482267483536686, 0.12053128305290427, 0.15640950069895812, 0.1778984468962465, 0.1394150076167924, 0.1666553659098489, 0.22778062309537614, 0.13244236819446087, 0.20327865571847983, 0.11189980871443238, 0.30045367777347565, 0.266097007053239, 11.889218943459646, 67.12927722930908, 52.759322098323274, 54.309579849243164, 39.36675616673061, 47.155224731990266, 55.31849997384207, 47.36020353862217, 0.14248380437493324, 1.957572877407074, 5.655018542494092, 7.746551820210048, 0.38167193106242586, 0.9431590076003755, 42.18075575147356, 62.62507969992501, 59.14812469482422, 58.15998663221087, 57.05097770690918, 55.44155951908657, 50.403014251164024, 53.09277657100132, 48.55573838097708, 53.5284286226545, 51.15382269450596, 53.54140438352312, 48.519889150347026, 45.321539538247244, 42.59468078613281, 47.08495759963989, 46.61133711678641, 46.560920987810405, 48.39217778614589, 49.71934625080654, 52.10315159388951, 51.527986662728445, 59.01804052080427, 59.36674281529018, 54.07536997113909, 47.796209948403494, 44.89280789239066, 44.357647214617046, 41.180607727595735, 43.82494967324393, 43.979626996176584, 41.23404284885952, 41.87370443344116, 42.03728239876883, 41.68216691698347, 43.273717812129426, 42.88799898965018, 42.83605773108346, 42.214638641902376, 43.719472544533865, 39.52769381659371, 40.41616691861834, 40.9990999358041, 41.453658035823274, 40.33516481944493, 37.78772245134626, 40.94645690917969, 46.237044606889995, 52.15363025665283, 57.37720257895333, 54.11946323939732, 53.352090290614534, 44.635432720184326, 32.56740883418492, 71.7031443459647, 58.03991133826119, 51.77431072507586, 55.34882191249302, 55.94595009940011, 53.94667196273804, 52.000891481127056, 56.451653889247346, 52.50379514694214, 54.30145740509033, 46.922630310058594, 39.23094320297241, 41.299348967415945, 38.45103222983224, 38.56032044546944, 39.55230433600289, 39.45082936968122, 39.72553334917341, 37.8517917905535, 39.978093419756206, 40.14551721300398, 37.79744645527431, 38.30723925999233, 40.691729000636506, 38.355616092681885, 37.832642555236816, 38.563367230551584, 39.70613397870745, 38.33591447557722, 36.972163745335166, 39.037025928497314, 40.02181148529053, 37.48027161189488, 38.122646468026296, 38.815871715545654, 36.79549537386213, 37.38533837454659, 39.80414874213082, 36.36558253424508, 40.87629052570888, 42.59402765546526, 43.316591671534944, 43.780741759708945, 43.83586181913103, 45.51695762361799, 47.78769840512957, 47.975039209638325, 51.1377341406686, 51.341236455099924, 53.764431135995046, 49.994442803519114, 49.926142011369976, 46.89510154724121, 52.30453470775059, 47.65419919150216, 42.12650769097464, 4.034670404025486, 0.3582018661711897, 3.225134266274316, 6.537045019013541, 6.736257689339774, 3.3759592473506927, 60.905254636492046, 50.54761668613979, 34.518605436597554, 37.78066308157784, 35.34620884486607, 51.431285108838765, 4.740378524575915, 0.657300238098417, 0.19102792308798858, 0.22350498395306723, 0.10451580743704524, 0.15870099488113606, 0.2652031050196716, 0.13901178139661038, 0.12694555600839003, 0.1517697868070432, 0.2502189076372555, 0.24922387674450874, 0.14152126173887933, 0.12225451772766453, 0.14033552179379122, 0.08463162370026112, 0.15005237396274293, 0.22738828057689325], [0.037730502896010876, 0.04484619107097387, 0.06292449456772634, 0.0434546955595059, 0.09468108016465392, 0.01143881374238325, 0.020793634400303875, 0.034973845817148685, 0.04472685033189399, 0.05066347195367728, 0.0328357887587377, 0.03920155663841537, 0.055933599160718064, 0.060038495143609386, 0.05366181981350694, 0.029054845749799694, 0.0417664665063577, 0.02056081885738032, 0.04509376475055303, 0.011858378237645541, 0.021911118811528598, 0.024474654646058167, 0.2314506018800395, 18.81891621862139, 44.1138071332659, 36.34391457693917, 28.524787085396902, 36.78315189906529, 32.53354331425258, 50.623063700539724, 6.900057128497532, 2.203790979725974, 3.9990482926368713, 1.8674868771008082, 0.6222604183214051, 0.11482325648622853, 4.0466486641338895, 52.33695500237601, 60.037695612226216, 53.212831020355225, 52.9069504737854, 51.76377378191267, 49.63411964688982, 47.87407841001238, 46.9094808442252, 48.07718120302473, 48.05067035130092, 43.95054183687483, 43.839440141405376, 40.58018262045724, 40.600377559661865, 43.964424337659565, 43.00027840478079, 43.67969758169991, 44.29263639450073, 45.39278636659895, 47.61562974112374, 49.56119135447911, 50.968284947531565, 52.38923672267369, 52.35431855065482, 48.064726557050435, 38.956239223480225, 39.883260931287495, 38.544356959206716, 38.1555392401559, 41.45558616093227, 36.81758369718279, 37.00379194532122, 36.871935980660574, 38.1827449117388, 36.32919829232352, 38.69429561070034, 37.72768306732178, 38.038403034210205, 39.419145584106445, 39.854773317064556, 40.444522517068044, 40.13839878354754, 39.58671528952462, 39.24597215652466, 39.292163780757356, 41.098664147513254, 41.085879462105886, 50.55860526221139, 51.6775118964059, 51.11976262501308, 50.02399001802717, 48.02092858723232, 30.856880460466655, 25.618802036557877, 49.90255635125296, 49.788776125226704, 50.87895890644619, 51.18868180683681, 48.98079095567976, 52.06370319638933, 48.74978419712612, 49.50244780949184, 46.29867512839181, 40.15329919542585, 35.713567052568706, 37.225199767521445, 35.482647146497456, 35.06832259041922, 33.9418181010655, 34.21468775612967, 33.51488603864397, 36.13246699741909, 35.01995965412685, 37.09287132535662, 34.789074489048545, 33.840728759765625, 34.59500782830374, 34.844993591308594, 35.98483862195696, 34.89422852652413, 35.74366317476545, 35.17304931368147, 33.7473658152989, 34.153936181749614, 34.5264846937997, 35.20182875224522, 36.183529308864046, 32.823446478162495, 33.90626416887556, 34.46870000021798, 36.30726630347115, 34.2573253767831, 37.134133202689036, 36.08132825578962, 39.34708234242031, 40.01104872567313, 41.41791650227138, 41.000281129564556, 40.07932867322649, 42.33774682453701, 43.85984352656773, 43.61577068056379, 48.289101260049, 47.805892263139995, 47.18784999847412, 45.33230229786464, 45.487882886614116, 44.71796689714704, 14.205248951911926, 0.26186438703111237, 0.17362708252455505, 1.6200810670852661, 2.7859034580843787, 1.0706171968153544, 8.992750321115766, 58.02257905687605, 32.32698379244123, 22.257539749145508, 18.596558230263845, 38.47290515899658, 22.437451192310878, 0.3430977852216789, 0.06505404958235365, 0.04062084494424718, 0.025582205304609876, 0.016854457025017058, 0.022501086350530386, 0.03601425713194268, 0.048990615111376555, 0.02117753085414214, 0.0517152690860842, 0.054922548056180985, 0.039991279797894616, 0.04143570104081716, 0.04869213094934821, 0.06673091995928969, 0.032159591293228526, 0.01617031391443951, 0.04933737364730664, 0.09451283740678004, 0.017433679961998547, 0.02200373205622392, 0.05856075443859611, 0.07331416170511927, 0.03475296570520316, 0.04961438896134496, 0.017544172604435256, 0.031932159925677946, 0.026612143431391035, 0.06305456973080124, 0.03101307406489338, 0.01955210360964494, 0.03929525214646544, 0.11571082100272179, 0.05160984510023679, 0.028129753157762543, 0.07654087391815015, 0.029948835992919545, 0.05979523355407374, 0.044508853993777714, 0.017711575675223554, 0.6048022551195962, 30.651717526572092, 52.10374219076974, 36.76152215685163, 35.340132645198274, 42.65582493373326, 38.69734934398106, 54.98990229197911, 6.328414499759674, 1.028656916958945, 2.372641976390566, 5.0806973831994195, 2.2154980429581235, 0.42171494237014223, 6.251198734555926, 55.43190152304513, 58.46675654820034, 57.07881913866316, 54.95719017301287, 55.0690735408238, 51.04325253622872, 48.75495365687779, 48.173066343579976, 48.52339104243687, 48.552389349256245, 47.87326199667794, 45.68380124228341, 42.938727787562776, 43.73962232044765, 46.694840567452566, 45.85864918572562, 46.76030649457659, 46.22517360959734, 47.714610304151265, 49.53448942729405, 51.156073910849436, 52.70092943736485, 54.37691136768886, 55.31249325616019, 49.642304624829976, 41.39470951897757, 41.606994356427876, 41.22703559058053, 40.24991042273385, 41.57336507524763, 38.52895975112915, 37.498698234558105, 39.013297830309185, 39.65842417308262, 38.28945881979806, 39.37840829576765, 39.506011962890625, 39.77130460739136, 40.53126035417829, 41.32360165459769, 40.54536172321865, 41.08943346568516, 41.4738564491272, 40.82342168263027, 39.809488432747976, 41.21780143465315, 43.54111228670393, 51.08347565787179, 53.20363507952009, 53.35277121407645, 49.42266859327044, 45.59186267852783, 29.50823163986206, 32.632895605904714, 52.67154550552368, 52.24137210845947, 53.476893833705354, 50.068583556583945, 51.52143451145717, 52.13641609464373, 49.35643836430141, 50.23000063214983, 48.812877314431326, 42.455421515873496, 36.73812409809658, 39.78622933796474, 37.69896616254534, 36.69570534569876, 36.57742268698556, 36.90382126399449, 35.18917260851179, 37.18163456235613, 37.840872696467805, 38.82049574170794, 37.83790928976876, 35.628215381077354, 36.2215324810573, 37.69389745167324, 38.28544623511178, 37.10966512135097, 37.3967855317252, 37.49805205208914, 35.95516633987427, 36.88554055350167, 36.87098755155291, 37.00856188365391, 38.04352733067104, 35.30515888759068, 35.58015816552298, 35.85575498853411, 36.71579953602382, 36.33438164847237, 38.0603107043675, 39.02967473438808, 42.168780531202046, 41.00077792576381, 42.381562164851594, 41.58931466511318, 41.5322664805821, 44.765937260219026, 45.65711668559483, 46.58811623709542, 48.79617037091936, 47.77320793696812, 48.429506983075825, 47.78970296042306, 46.663941928318565, 47.44587482724871, 16.236260380063737, 0.3326157219707966, 1.605058953166008, 4.6067299246788025, 1.265851046357836, 0.9309166073799133, 9.064843961170741, 63.63167217799595, 35.12317167009626, 29.52836057118007, 22.97943847520011, 38.166472230638774, 30.61833143234253, 0.45919797675950186, 0.10749823347266231, 0.03991170460358262, 0.02944667258166841, 0.037110081009034596, 0.05629366037568875, 0.026005483930930495, 0.054845154351953945, 0.043196557089686394, 0.031043675994234424, 0.057706648483872414, 0.05764986867351191, 0.009621869988872536, 0.04470381746068597, 0.06858899989830596, 0.03694065420755318, 0.027643957707498754, 0.04978253672431622, 0.3826703546302659, 0.14348985467638287, 0.23138893661754473, 0.16467094953571046, 0.2051351818123034, 0.1731977734182562, 0.12977198005786963, 0.08019072056881019, 0.18040773724871023, 0.15948167656149181, 0.14168716355093888, 0.07702585003737893, 0.12067484749214989, 0.15294856498283999, 0.159894660115242, 0.08348762722952024, 0.14155498492930615, 0.16391227953135967, 0.1375333485858781, 0.12018974923661777, 0.07226723645414625, 0.24407414879117692, 0.4800775306565421, 36.983756814684185, 57.69391884122576, 43.054140840257915, 42.71859148570469, 48.08405991962978, 41.73702641895839, 59.045458112444194, 9.582280652863638, 4.191659305776868, 11.57417024884905, 6.281360864639282, 3.077128733907427, 0.3235952502914837, 6.831440193312509, 56.369050230298726, 62.45466123308454, 59.34742682320731, 56.48823268072945, 56.69628259113857, 53.63991246904646, 52.7133458682469, 51.82756519317627, 50.96293830871582, 51.121464933667866, 50.0681597164699, 49.74150058201381, 45.667035239083425, 45.876116956983296, 49.80035877227783, 47.75619527271816, 49.0151115826198, 48.146892479487825, 50.01928956168038, 52.216421127319336, 52.9843499319894, 55.3767397744315, 56.87281199863979, 56.978994369506836, 50.92493166242327, 44.2318639755249, 43.84904255185808, 42.818701131003245, 42.14945759092058, 45.43214791161673, 40.59054238455636, 38.60099867412022, 39.76305709566389, 42.71202891213553, 40.107354232243125, 44.00917421068464, 40.434009892599924, 42.04526240485055, 42.85882697786604, 43.768832547324045, 44.4126352582659, 43.71941695894514, 42.00685971123831, 43.697116715567454, 42.32033463886806, 44.036890574863975, 44.53975602558681, 53.746299811771934, 53.6620911189488, 54.79777070454189, 51.10742957251412, 50.002794538225444, 36.136271136147634, 39.96865776606968, 52.420972619737896, 51.83171326773507, 54.70694385256086, 51.5063464982169, 53.00880411693028, 53.62500510896955, 51.33288124629429, 52.86295795440674, 50.67968804495675, 44.241306577410015, 39.51088612420218, 41.44313498905727, 39.394079957689556, 38.87976040158953, 38.38684129714966, 38.16140351976667, 38.57650627408709, 39.37077569961548, 40.21034737995693, 41.59027699061802, 39.89992618560791, 37.170524392809185, 38.752295698438374, 39.53347471782139, 40.16366938182286, 39.04876143591744, 40.241530895233154, 40.01777458190918, 37.02604355130877, 38.41590561185564, 38.483070373535156, 39.164271763392854, 40.455841132572715, 36.384109905787874, 37.2786522592817, 38.674159731183735, 39.82382256644112, 38.34908478600638, 41.33998550687517, 41.0745712688991, 45.61024413790022, 44.2728270803179, 45.49263545445034, 42.914648805345806, 42.897549288613455, 46.03521680831909, 47.60366494315011, 47.59130757195609, 51.89399691990444, 49.370049885341096, 51.049019541059224, 48.09030982426235, 48.6953763280596, 46.66510575158255, 18.82022074290684, 0.3626198076776096, 1.495248754109655, 7.504702397755214, 10.032041021755763, 2.495418382542474, 11.286725878715515, 67.06071240561349, 41.36305700029646, 33.591979776109966, 26.727941240583146, 48.1408371244158, 36.50234045301165, 0.45570699551275795, 0.2183176651597023, 0.09971773704247815, 0.10538959769265992, 0.1390196524028267, 0.08304147009870835, 0.11176828148641757, 0.1509787778237036, 0.1482456930513893, 0.13405112044087478, 0.2535179177565234, 0.09656774678400584, 0.10721063640500818, 0.16786166546600206, 0.13887517872665608, 0.16363857207553728, 0.07535972765513829, 0.15876532000090393], [0.050927279583577595, 0.03550992240863187, 0.011123640163402473, 0.02252219896763563, 0.06630300863512925, 0.044861217228961844, 0.031473819698606215, 0.013837578373828104, 0.018507505733785883, 0.047219024638512304, 0.03770675077768309, 0.016381328127213886, 0.013118243044508355, 0.011001967808364757, 0.06333951372653246, 0.028136421460658312, 0.04596274080021041, 0.03560003525178347, 0.04285315390942352, 0.03464576395760689, 0.06645736856652157, 0.06830628828278609, 0.13866290583142213, 1.8713283623967851, 34.83167389460972, 42.39723382677351, 32.72168663569859, 37.52411127090454, 31.85829653058733, 48.69770050048828, 30.598098278045654, 0.046381525828370025, 1.505503535270691, 2.209820930446897, 2.456561233316149, 0.10260125981377703, 0.023842081893235445, 18.972268172672816, 66.11518069675991, 54.84328487941197, 57.0498868397304, 51.42179386956351, 53.2209187235151, 47.43513638632638, 49.77024875368391, 46.90551342282976, 47.26227910178048, 43.72239773614066, 43.52420037133353, 41.02280371529715, 42.112388951437815, 40.78053045272827, 45.66241121292114, 45.66493340900966, 48.090212549482075, 49.43209382465908, 49.51581614358084, 50.912897382463726, 54.807147298540386, 52.9467636517116, 53.206529004233225, 46.80760983058384, 40.915078844342915, 38.87620987210955, 39.7455233165196, 39.1885209764753, 39.21600110190255, 37.7752365384783, 38.72053895677839, 37.406891686575754, 36.889747687748496, 37.12321063450405, 37.92113481249128, 38.31193971633911, 36.8519355910165, 37.30941193444388, 40.21926539284842, 43.08222198486328, 41.79587766102382, 41.54583631243025, 41.537422043936594, 41.38009050914219, 38.670001234327046, 38.40826606750488, 44.25826365607125, 51.4787517275129, 49.83124698911394, 53.73827811649868, 50.89315755026681, 47.858570030757356, 30.404761178152903, 35.677773407527376, 52.47404990877424, 49.86352831976754, 52.23541055406843, 49.848398617335725, 50.36681761060442, 51.0031544821603, 49.07011699676514, 43.539462089538574, 39.99481078556606, 36.35436814171927, 37.231828348977224, 35.101100717272075, 35.84455796650478, 34.29640204565865, 36.38837609972273, 35.48321342468262, 35.35970572062901, 35.723068714141846, 34.79607479912894, 35.69012035642351, 34.076640946524485, 35.26960495540074, 34.97752005713326, 34.64028923852103, 34.22956384931292, 34.85268872124808, 35.42867701394217, 34.78547184807913, 35.15452889033726, 34.63429989133562, 33.957538400377544, 35.65995127814156, 36.23933029174805, 34.70872204644339, 35.15577956608364, 33.38350602558681, 35.70531954084124, 37.01263352802822, 39.68575838633946, 38.58190155029297, 39.2798307282584, 39.6884195463998, 41.06383282797677, 39.96587153843471, 41.898405279432026, 42.05424989972796, 44.137094020843506, 46.09658677237374, 47.34033863885062, 46.54172658920288, 46.620974268232075, 46.65827914646694, 30.147980076926096, 2.1231471470424106, 0.16491861481751713, 1.1929910417113985, 3.5328973403998782, 1.1949507594108582, 0.07477126137486526, 22.0404953956604, 53.25068828037807, 25.717153787612915, 24.510604313441686, 22.999167885099137, 37.17786169052124, 8.098007338387625, 0.26577928981610704, 0.008917141822166741, 0.05873732960649899, 0.05985982330249889, 0.058507021250469346, 0.08552382939628192, 0.012896346826372402, 0.03421138619471874, 0.06890717853925057, 0.0015015598286741547, 0.06493192006434713, 0.05392188532277942, 0.0737663713682975, 0.08238039378608976, 0.06789214443415403, 0.05001758125477603, 0.014119563108709241, 0.030936874582299163, 0.05970296636223793, 0.01512849294314427, 0.021948231284373572, 0.03917804879269429, 0.06375424111528055, 0.05860242327409131, 0.041121440939605236, 0.04222629951047046, 0.016565876081585884, 0.04512686708143779, 0.0095434084401599, 0.0639471486210823, 0.03203953130702887, 0.060477880494935174, 0.12136662751436234, 0.039660334520574124, 0.027883024254281605, 0.09500987787864038, 0.04099977282541139, 0.09090237292860236, 0.0655157451650926, 0.07843997129904372, 0.011293141603735941, 6.646618979317801, 45.38720348903111, 42.598516191755024, 32.729367869240896, 45.06858342034476, 35.43986708777291, 57.48745312009539, 27.93207447869437, 0.26919058391026085, 1.6440183711903436, 2.344402326004846, 5.824295333453587, 0.9502508384840829, 0.03986455320513674, 23.759735073362076, 65.53329685756138, 55.847369057791575, 59.022306714739116, 53.27927664348057, 53.41884510857718, 50.54784945079258, 52.16396222795759, 49.00212887355259, 50.10590580531529, 46.28326749801636, 46.52806643077305, 43.463848318372456, 43.02609096254621, 43.38462495803833, 45.873233454568044, 47.92729466302054, 49.94763626371111, 51.619320733206614, 51.736182485307964, 53.42208644321987, 54.005325181143625, 54.901225907461985, 56.131428786686485, 49.72081579480852, 41.86038473674229, 39.65757996695382, 39.94055230276925, 39.71474627086094, 40.948812348502024, 39.83929967880249, 38.34574965068272, 39.27747876303536, 39.700634479522705, 39.41589035306658, 39.26206418446132, 40.29653630937849, 38.85359001159668, 37.8019871030535, 41.65267876216343, 43.95725727081299, 44.072694642203196, 43.20006343296596, 42.853567191532676, 41.00967856815883, 41.46645661762783, 40.55340773718697, 46.02082708903721, 52.75831460952759, 51.88095167704991, 55.101712703704834, 51.29459319795881, 47.03458315985543, 27.70837548800877, 39.980865750994, 53.38043199266706, 50.83539717538016, 54.52753789084298, 51.68238953181675, 53.04733535221645, 51.71762384687151, 52.02534219196865, 45.92665120533535, 41.40555565697806, 38.05698946544102, 37.897726331438335, 36.401132992335725, 37.64310611997332, 35.92425727844238, 37.43872485842024, 36.33085891178676, 37.509537424360005, 37.513772351401194, 36.63809783118111, 37.1326219694955, 36.540875162397114, 36.46528918402535, 36.31536790302822, 37.28314079557146, 36.86246906008039, 36.67051117760794, 37.897528307778494, 36.14847217287336, 36.946910517556326, 37.741992882319856, 34.76118441990444, 36.5820814541408, 37.979096685137065, 36.34658963339669, 36.379927090236116, 35.118912424360005, 37.00928449630737, 39.37118216923305, 42.12425994873047, 41.862139156886506, 41.23020396913801, 40.95381505148751, 42.54064464569092, 42.79735973903111, 44.101067611149375, 43.98103748049055, 47.37789365223476, 47.91459683009556, 49.895622049059185, 49.193899154663086, 47.093337127140586, 46.18719128199986, 34.17783103670393, 2.637117773294449, 0.7788902936237199, 4.450880093233926, 3.388783233506339, 1.94076692206519, 0.2621442420142037, 24.009196247373307, 57.74969897951399, 31.856062684740337, 29.9062557220459, 20.785913024629863, 45.56998974936349, 11.133164610181536, 0.30655036919883316, 0.04750073541487966, 0.04996959525825722, 0.014845570981768625, 0.1165270172059536, 0.01890426212256508, 0.039514083082654645, 0.003967452353598284, 0.015798208702887808, 0.03043678409553, 0.011871561324889106, 0.0172297801888947, 0.009655518540447312, 0.03367399324529937, 0.043641221443457265, 0.036869842293007035, 0.05611966364085674, 0.024342230055481195, 0.15420035352664335, 0.1302377807774714, 0.16359711358589785, 0.08329733886889049, 0.17653094099036284, 0.24443930919681275, 0.23467065766453743, 0.25056658898081097, 0.12309467978775501, 0.10462959775967257, 0.10620048096669571, 0.18068384671849863, 0.09792248266083853, 0.15779820403882436, 0.20385503050472054, 0.1442357546516827, 0.10175629372575454, 0.20930518662290915, 0.21561677008867264, 0.1437098357294287, 0.21096599607595376, 0.16223837435245514, 0.16999345964619092, 6.063531798975808, 53.05042382649013, 48.096281800951274, 42.50464950289045, 49.16839231763567, 41.059347765786306, 58.84702450888497, 38.12972668239048, 0.8803050603185381, 8.401104262896947, 8.955095427376882, 7.539452075958252, 0.6301143254552568, 0.16930576440479073, 22.322494983673096, 69.79697554452079, 58.002193042210166, 61.320465087890625, 56.70311614445278, 58.53897612435477, 53.40718603134155, 55.50894314902169, 51.54302256447928, 51.681687763759065, 48.4747189113072, 48.997723715645925, 45.47498008183071, 46.360288279397146, 45.25181089128767, 50.26743057795933, 50.639270373753135, 52.39834581102644, 55.17140660967146, 54.706936904362266, 56.971431255340576, 57.797804832458496, 57.42597893306187, 57.651889187949045, 51.723356110709055, 46.11973817007882, 40.78143719264439, 41.707072734832764, 41.27583278928484, 41.3763176373073, 41.841353620801655, 40.995719637189595, 40.37639542988369, 42.403574057987754, 40.13905538831438, 41.121996198381694, 41.999498094831196, 39.71320029667446, 40.6684455871582, 44.33551025390625, 47.030431611197336, 45.31182248251778, 45.120976311819895, 44.86758245740618, 43.38767521721976, 43.00470093318394, 41.75994505201067, 47.35083736692156, 55.339587756565635, 53.301747117723735, 57.09524120603289, 55.0248829977853, 49.06649003710066, 35.22813810620989, 43.16863325663975, 52.53138991764614, 54.78607341221401, 54.80210638046265, 53.44253846577236, 53.195748874119346, 54.43308407919747, 54.03948252541678, 47.19537837164742, 44.29572139467512, 40.80537026269095, 41.22970369883946, 37.801528521946494, 39.5452310698373, 38.83469091142927, 40.46001352582659, 38.40237052100045, 39.22396721158709, 39.17716414587838, 37.671666690281455, 38.78379535675049, 38.16763605390276, 40.60022817339216, 39.18941729409354, 40.094475746154785, 37.553450039454866, 38.5623562676566, 39.71048355102539, 38.02584763935634, 39.84245068686349, 39.35142496653965, 37.41245371954781, 38.604021140507285, 40.05081674030849, 37.27019282749721, 38.788801533835276, 36.95012058530535, 39.40393945149013, 41.50977168764387, 44.645660468510215, 43.37425824574062, 43.828851086752756, 44.29176092147827, 44.583866664341514, 44.76122638157436, 45.95945712498256, 46.10488292149135, 48.40759583881923, 49.3869618007115, 52.547207491738455, 50.21049356460571, 50.09616790499006, 47.718272004808696, 35.04806511742728, 3.505092820950917, 0.4742900069270815, 7.405855587550572, 6.84421706199646, 5.466415337153843, 1.2264224077974046, 26.872451611927577, 61.998400824410574, 36.39973293031965, 37.40837165287563, 31.7116756439209, 52.987073625837056, 13.935620631490435, 0.48485132306814194, 0.12424490520996706, 0.14920904992946557, 0.1352903696575335, 0.17870086883859976, 0.18169402251286165, 0.1488817110657692, 0.134175604475396, 0.15418788205300057, 0.10041417181491852, 0.1013633201697043, 0.1052697684083666, 0.14029414472835405, 0.1936370666537966, 0.17894225088613375, 0.20023865598653043, 0.056158469058573246, 0.12753190525940486], [0.049790214348052225, 0.052394557278603315, 0.009890272997186651, 0.03909539644207273, 0.027601520431094935, 0.051533744005220275, 0.006459725895963077, 0.0688415574175971, 0.01226065366063267, 0.10898418445140123, 0.019249327713623643, 0.023806960920670202, 0.0715004036735211, 0.04804282043395298, 0.016845807399866835, 0.049695195696715794, 0.026757897842409353, 0.07720606215298176, 0.0297477962449193, 0.04903707101142832, 0.034303456611399136, 0.02313959289209119, 0.07536474881427628, 0.07505846489220858, 15.151356492723737, 46.28066192354475, 34.90784352166312, 37.31298678261893, 33.4047258240836, 31.677174363817485, 51.48745782034737, 0.38317241626126425, 1.922737649508885, 2.5019829102924893, 4.111761101654597, 0.8989432230591774, 0.12684612348675728, 1.0765215371336256, 48.08089501517159, 62.40154920305525, 54.08013990947178, 55.34723424911499, 51.46937165941511, 50.01495041166033, 48.697318349565776, 46.71632787159511, 45.9718005997794, 48.358041286468506, 43.529644284929546, 44.867578983306885, 43.09159857886178, 43.56576796940395, 44.031867027282715, 48.54893609455654, 50.05405487333025, 50.78679800033569, 52.503628390175955, 51.579326902117046, 53.1314571925572, 52.92087813786098, 51.29004907608032, 48.741592270987375, 40.62048217228481, 39.35781730924334, 38.05947692053658, 38.000132356371196, 38.73612029211861, 38.51598399026053, 39.044366700308665, 39.27657897131783, 39.20135082517351, 37.80377973828997, 38.02932868685041, 38.06715815407889, 37.604738167354036, 39.13731622695923, 46.11955751691546, 48.530214173453196, 47.92621769223894, 47.27659239087786, 46.06767879213606, 44.00022840499878, 44.04093790054321, 40.737013884953086, 39.54766641344343, 42.556403160095215, 48.76353815623692, 50.30022954940796, 49.08624029159546, 52.6927444594247, 45.269004208701, 37.851496492113384, 51.438146454947336, 53.16312708173479, 49.68829127720424, 48.79386356898716, 49.40730960028512, 45.59967245374407, 42.75150857652937, 38.73979588917324, 36.84364291599819, 35.86524622780936, 35.30896650041853, 35.5085118157523, 35.99480581283569, 36.04149770736694, 36.447543484824045, 35.60938923699515, 35.136234283447266, 35.376690592084614, 34.48956196648734, 34.7239351272583, 33.53218705313546, 35.73237582615444, 35.35678400312151, 35.94489342825753, 34.309370858328684, 35.116021973746165, 34.227142402103965, 34.99871206283569, 33.49209942136492, 34.90937212535313, 34.89104972566877, 33.85538945879255, 33.41125018256051, 34.97046416146414, 35.60655437197004, 35.564562933785574, 34.85100030899048, 36.51276275089809, 37.895589760371614, 38.8928473336356, 40.95087248938424, 41.04163680757795, 41.61026348386492, 41.45999131883894, 42.4131486756461, 42.671489647456575, 43.749638148716514, 47.31487001691546, 47.1864082472665, 47.49068028586251, 45.45327043533325, 46.47918585368565, 14.15804636478424, 0.05119412026501127, 0.5628586943660463, 2.7041411825588773, 3.0147356476102556, 0.493588031402656, 0.04456952180979507, 35.43548624856131, 44.008291789463584, 21.29367174421038, 24.43517640658787, 27.071864911488124, 30.166469233376638, 0.4000092042343957, 0.1847433860280684, 0.05153888051531144, 0.001140210563400095, 0.03310968620436532, 0.04581104751144137, 0.005274522841708469, 0.017477374224524413, 0.00884417979978025, 0.0277852303947189, 0.05905990515436445, 0.044390476774424314, 0.06254985502787999, 0.011385781989832009, 0.02381150201628251, 0.02680347503961197, 0.08337495648967368, 0.049839343676077466, 0.03951334008680923, 0.07634398341178894, 0.0225971923542342, 0.045412791560270956, 0.06073802403573479, 0.04168050629752023, 0.06379859016409942, 0.03702322513397251, 0.010055140043342752, 0.043591474648565054, 0.11075657220291239, 0.0364941883433078, 0.016484967565962245, 0.029967261611350944, 0.023158344207331538, 0.04653186883245196, 0.11043073290160724, 0.07798908477915184, 0.01554710155219904, 0.08809283761573689, 0.025828528783417175, 0.07666636218449899, 0.0683583929868681, 0.10059202262865645, 0.21055983858449118, 25.079131977898733, 52.26750775745937, 36.82006420407976, 45.40399728502546, 35.98973362786429, 37.61850949696132, 53.55037103380476, 0.36927373920168194, 0.6469745093158313, 1.1386363697903497, 3.015313216618129, 2.2274307055132727, 0.1261367965489626, 2.0122771305697302, 54.18438720703125, 60.814768246241975, 57.13368558883667, 57.94007962090628, 54.63304628644671, 53.3281363759722, 51.441540649959016, 49.202952657427105, 49.214952196393696, 48.07965128762381, 46.05693340301514, 45.58738456453596, 44.994456563677105, 46.17915221623012, 47.54473032270159, 50.65572370801653, 52.19335658209664, 52.86680030822754, 54.7509502683367, 53.79033749444144, 53.74057102203369, 53.02836677006313, 53.40268359865461, 50.57617378234863, 41.511765820639475, 41.845279353005544, 39.61403908048357, 40.311780657087056, 41.515976428985596, 39.624527386256624, 40.097289766584126, 40.013174874441965, 39.46687970842634, 37.793093408857075, 39.63827787126814, 38.75261531557356, 38.73764194761004, 40.70227984019688, 47.38659974506923, 48.53572062083653, 48.93846600396292, 47.74195841380528, 48.300027302333284, 45.27104697908674, 44.30615758895874, 41.39103044782366, 41.46455628531319, 45.75026076180594, 50.04009246826172, 52.29613086155483, 50.94974715369088, 54.22381475993565, 43.07997076851981, 37.13382053375244, 52.846789496285574, 52.88310425622122, 52.156975814274375, 50.82711492265974, 51.19723503930228, 47.61236408778599, 44.23211063657488, 41.57248265402657, 38.15949623925345, 38.04250247137887, 38.098883628845215, 37.829689570835654, 38.064333711351665, 38.192413330078125, 37.70003965922764, 38.39801747458321, 36.05130161557879, 37.30877617427281, 37.225356101989746, 36.29386322838919, 35.87077004568917, 37.411453178950715, 37.01169899531773, 37.46713604245867, 35.52085876464844, 36.49704245158604, 37.07183218002319, 36.99841056551252, 35.777605124882285, 36.84977470125471, 36.12915618079049, 34.58617319379534, 35.935044356754844, 36.29800088065011, 37.44183417728969, 37.549684115818565, 36.742004667009624, 38.03019721167428, 39.41463620322091, 42.07696008682251, 41.48942388807024, 43.20753622055054, 44.99664524623326, 43.34103543417794, 43.90686198643276, 46.22411748341152, 45.975500515529085, 48.70828260694231, 48.32535001209804, 49.62492023195539, 47.43657118933541, 48.73328569957188, 16.371072803224834, 0.08285897810544286, 2.756978541612625, 6.693409017154148, 4.00891603742327, 1.030141443014145, 0.1252059686396803, 38.423572949000764, 50.57439851760864, 27.73666855267116, 27.445476497922623, 30.325680255889893, 42.011775561741416, 1.0210204124450684, 0.26700485976678984, 0.06974009384534188, 0.031302761020404954, 0.0361722370476595, 0.042319302912801504, 0.004511106060817838, 0.008084065364008504, 0.020361811321760927, 0.022690969286486506, 0.037163152625518184, 0.02872548145907266, 0.055375290369348865, 0.07121424510010652, 0.03952427128595965, 0.00919232763616102, 0.03718615835532546, 0.041192863535668166, 0.08212337829172611, 0.2602110414632729, 0.13103602294410976, 0.12531034089624882, 0.1076093367966158, 0.14196012461824076, 0.10258641346756901, 0.1027576621355755, 0.14793991803058557, 0.11300742892282349, 0.2593600499842848, 0.14040402668927396, 0.09083351519490991, 0.10909517920975174, 0.1151629989700658, 0.12450506910681725, 0.22314020352704184, 0.2225411113883768, 0.18749982597572462, 0.14081957510539464, 0.12888256992612565, 0.11156476169292416, 0.13267266297979013, 0.1386588889041117, 0.3095344847866467, 26.54639870779855, 60.92063099997384, 42.59477458681379, 50.23910277230399, 43.63118525913784, 39.348520619528635, 60.93022646222796, 0.7611825381006513, 4.87521048954555, 11.670896121433803, 9.59347333226885, 2.6837831778185706, 0.32945966560925755, 2.0881206265517642, 52.54710326875959, 64.64198194231305, 57.75500045503889, 60.02267360687256, 56.34779221670968, 55.618773324149, 53.890725067683626, 50.914019516536165, 49.85527385984148, 52.899408204214915, 47.7467040334429, 48.18421820231846, 47.74749960218157, 47.92051322119576, 48.1795768056597, 54.34615864072527, 54.608512197222026, 54.53463894980294, 56.45844227927071, 56.59940038408552, 55.759773118155344, 55.596056188855854, 55.60467542920794, 52.853299958365305, 43.66054139818464, 43.9003723689488, 42.00053685052054, 42.477023465292795, 42.25352423531668, 41.297813415527344, 41.61907727377755, 40.95775120598929, 43.04812370027815, 39.376455851963584, 41.43987280981881, 40.71492903573172, 41.066028458731516, 41.91913175582886, 49.600646700177876, 51.889421531132285, 51.99895988191877, 50.753467491694856, 50.716002804892405, 48.50358867645264, 47.37540967123849, 42.834331103733604, 42.77802290235247, 46.3849960735866, 51.624552726745605, 52.830464703696116, 52.81935453414917, 54.78741788864136, 45.92592511858259, 39.12201281956264, 54.09119449343, 56.373858383723665, 53.62055478777204, 51.04909944534302, 53.12071875163487, 49.53808512006487, 45.2263457434518, 43.01762110846383, 40.27246427536011, 40.696366923195974, 39.17676115036011, 39.186148166656494, 38.81210231781006, 40.719236918858115, 39.89650419780186, 39.83302198137556, 38.73116970062256, 38.93898337227957, 38.714907441820415, 37.70116179330008, 37.32565334865025, 40.023190702710835, 39.478066308157786, 38.98907988412039, 36.71453496388027, 38.29940864018032, 38.16709756851196, 39.1513237953186, 36.76974534988403, 38.29621246882847, 39.711817605154856, 36.922487599509104, 37.102633544376914, 37.86065074375698, 40.25931133542742, 39.235438687460764, 38.47365209034511, 40.213345527648926, 40.74447625023978, 43.705398968287874, 45.113440990448, 45.53858041763306, 47.15228564398629, 46.59574883324759, 46.80617502757481, 46.19654703140259, 49.62609447751726, 50.932105677468435, 50.6704295703343, 51.43478005273001, 48.589089734213694, 51.38567018508911, 18.836866889681133, 0.12792489917150565, 3.1335817618029456, 7.767708216394697, 8.564688307898384, 2.7940552149500166, 0.2601521174822535, 44.26021957397461, 53.99226256779262, 31.964708192007883, 38.310133184705464, 39.625729424612864, 51.0770902633667, 1.8709807353360313, 0.5306300723126957, 0.18611725659242698, 0.11265123196478401, 0.12081903618361269, 0.16490232997706958, 0.09240771643817425, 0.18206921166607312, 0.07328829595020839, 0.09421709791890212, 0.23540019137518747, 0.13343464423503193, 0.20864714336182388, 0.0792041238663452, 0.2531179077923298, 0.08910725425396647, 0.1366324983537197, 0.07484104870153324, 0.08198416326195002], [0.07587734130876404, 0.048778735766453404, 0.027371705709291354, 0.030985861417970488, 0.021218305719750266, 0.026248055111084665, 0.03021390569795455, 0.04012374001156006, 0.027335901112694825, 0.05036428890057972, 0.04474859059389148, 0.024942316247948577, 0.03161870049578803, 0.030727936686681848, 0.038240096265716214, 0.09558824077248573, 0.029185935322727476, 0.06638237687626056, 0.00862086798796164, 0.010042029050444918, 0.02241721942222544, 0.06736920428063188, 0.0318741485742586, 0.005445681179740599, 2.120460582630975, 35.220467294965474, 42.3385979788644, 33.00535726547241, 40.54127618244716, 25.67426429476057, 57.01427384785244, 13.290750503540039, 1.5790526057992662, 0.1392368921743972, 4.1069677131516595, 2.685289416994367, 0.38898775992648943, 0.08514693712017365, 6.170021193368094, 66.37692628587995, 53.241704259599956, 56.03399419784546, 56.155278478349956, 53.720455987112864, 48.34495782852173, 49.32799938746861, 45.87562710898263, 48.14858089174543, 45.70029626573835, 46.72346714564732, 43.6649500301906, 48.34141077314104, 48.74257891518729, 50.3586083139692, 51.662257126399446, 50.94180188860212, 51.16627386638096, 52.743150166102815, 53.789281368255615, 52.74030140468052, 50.18059546606881, 48.2057089805603, 39.62343304497855, 39.50082860674177, 38.49313831329346, 40.364020688193186, 37.71835511071341, 40.27661582401821, 37.939599650246755, 38.87454925264631, 38.08669648851667, 36.872974736349924, 35.89238936560494, 39.00200353349958, 37.24696847370693, 44.81754500525338, 52.118826729910715, 52.06697927202497, 51.97914361953735, 49.835485390254426, 49.339324951171875, 49.21139471871512, 45.851093019757954, 43.431910923549104, 39.478135790143696, 40.472777366638184, 44.98270715985979, 49.69057723454067, 50.45711987359183, 53.28575931276594, 51.043273380824495, 47.052252428872244, 51.42682089124407, 51.23068019321987, 49.43692977087838, 50.22205189296177, 46.50458499363491, 42.542315687452046, 39.924606187003, 36.614828314099995, 36.280626910073416, 38.71323640005929, 38.07210527147566, 36.10554967607771, 36.526006017412456, 36.29709414073399, 37.57468026024954, 37.19102505275181, 35.34740393502371, 36.38102837971279, 35.252383845193044, 35.28189631870815, 35.813912936619346, 35.815705571855815, 34.71522903442383, 35.99712651116507, 34.85935204369681, 35.41985974993025, 34.975345270974294, 34.80954040799822, 33.63625022343227, 35.758560112544465, 34.83853524071829, 34.926954541887554, 35.74184274673462, 34.82019199643816, 35.967280524117605, 34.657103879111155, 35.477679184504915, 36.02177177156721, 38.323056834084646, 40.051720006125315, 42.89262301581246, 42.34258277075631, 43.60556377683367, 44.42551721845354, 42.728541306086946, 46.12533841814314, 46.36309882572719, 48.806384222848074, 48.48600278581892, 47.0499838420323, 48.20183883394514, 40.21680573054722, 2.7188683237348283, 0.48655927713428226, 1.5151870442288262, 2.384299316576549, 3.2014495943273817, 1.068596356681415, 1.8466127514839172, 51.8187826701573, 27.621434416089738, 29.353081839425222, 26.254313809531077, 25.271746465138026, 18.69738875116621, 0.05403621508074658, 0.03684567626831787, 0.026512841527749385, 0.04707635586549129, 0.06497464741447143, 0.007745267740184707, 0.07636829532150712, 0.05842694054756846, 0.053369863158358, 0.02317533302786095, 0.05815768428146839, 0.058962718583643436, 0.03449232344116483, 0.013719730411789246, 0.03537015776549067, 0.12096110784581729, 0.043221252371690104, 0.03169228761856045, 0.05014662504462259, 0.0746967378737671, 0.04700841415407402, 0.06143259283687387, 0.05317874359233039, 0.004085094634709614, 0.053083497631762705, 0.03088671388104558, 0.04507020601470556, 0.014912817194791777, 0.02057057449461094, 0.03369599813595414, 0.05187756787719471, 0.02136902361443, 0.058889491084430895, 0.027427535570625747, 0.08224121946841478, 0.015828868307705437, 0.033809089567512274, 0.01682171262135463, 0.03520206767799599, 0.02875911643994706, 0.031691863534173796, 0.02347308267573161, 0.06297509970941714, 5.157408969742911, 45.578160830906455, 44.13981424059187, 36.16814252308437, 48.086411884852815, 27.171418700899395, 62.32265240805489, 11.865740980420794, 0.9510556352990014, 1.043714097567967, 3.1017155860151564, 4.969309508800507, 0.8441670451845441, 0.19290466952536786, 10.177202786718096, 70.66311018807548, 52.32700865609305, 57.39438547406878, 57.78808082853045, 55.83160359518868, 51.75666924885341, 52.56110041482108, 47.84745291301182, 50.25681720461164, 48.707275118146626, 48.82225043433053, 45.709499154772075, 51.58531624930245, 49.89398922239031, 51.65083776201521, 52.38365731920515, 53.31390993935721, 52.71087230954851, 54.40556921277727, 55.13704081944057, 54.03790528433663, 50.909277370997835, 50.09206846782139, 41.41878502709525, 40.86656999588013, 40.13835709435599, 41.39246525083269, 39.116468157087056, 41.730373518807546, 40.946790422712056, 40.293513842991416, 41.24755709511893, 39.24839012963431, 37.41995429992676, 41.025183473314556, 39.950078283037456, 45.87454319000244, 52.19459683554513, 52.39162342888968, 52.566520009722026, 51.285171440669465, 50.24856621878487, 51.16391147886004, 46.72772639138358, 43.276351179395405, 40.663772923605784, 43.46152414594378, 47.063967091696604, 52.269807611192974, 50.91753530502319, 54.8648590360369, 50.44252518245152, 45.693257740565706, 51.96532365253994, 52.26136902400425, 51.305647781917024, 50.91998454502651, 48.524603503090994, 44.88018648965018, 43.07686839784895, 39.282627378191265, 39.51127174922398, 40.61326994214739, 39.901979378291536, 38.51871810640608, 36.53830432891846, 37.92787456512451, 38.313245977674214, 38.407512187957764, 36.88622842516218, 37.34987129483904, 36.11757353373936, 37.62935216086251, 37.55728544507708, 38.51273570741926, 36.76504141943795, 37.549291542598176, 35.6096567426409, 37.3019426209586, 37.44092396327427, 37.15672527040754, 35.71353578567505, 37.75746999468122, 36.4438088280814, 37.25794662748064, 37.07953773226057, 37.723118100847515, 36.302861145564485, 35.394901820591514, 38.16632979256766, 36.696858746664866, 38.50387675421578, 42.93950598580496, 45.26095472063337, 44.24909898212978, 44.75897169113159, 46.66027675356184, 44.20959152494158, 47.19659430640084, 48.86223384312221, 51.05899715423584, 49.52848618371146, 48.92125531605312, 48.471008573259624, 43.115597656794954, 3.316392775092806, 0.702552389885698, 4.249468752316066, 9.026397841317312, 4.4082528948783875, 1.9481849925858634, 2.053660818508693, 56.74799803325108, 32.97206497192383, 33.76018524169922, 28.114713089806692, 29.508005823407853, 26.618418523243495, 0.03962905066353934, 0.018743237280952077, 0.044015348689364533, 0.014022625899607582, 0.05173616796465857, 0.019704489004133, 0.022740273337279047, 0.007319714325214071, 0.07073363874639783, 0.03177519102713891, 0.07870327681303024, 0.06326747366360255, 0.006848723660888416, 0.021723413972982338, 0.045342152672154565, 0.03288597999406712, 0.03237682427944882, 0.03327202231490186, 0.04267324713457908, 0.18837622180581093, 0.131138929565038, 0.10017745130296264, 0.07540406991860696, 0.13849464271749767, 0.12056126073002815, 0.07851260847279004, 0.16334307007491589, 0.16969130800238677, 0.11212711794567959, 0.10464863745229584, 0.12323360304747309, 0.19311167698885712, 0.16934045111494406, 0.08663472692881312, 0.16607690123575075, 0.10825551926557507, 0.07768208839531456, 0.0967728475640927, 0.11986037476786546, 0.20240805457745278, 0.15950936079025269, 0.17694209249956266, 0.1488609614648989, 4.7584421038627625, 54.20908110482352, 52.52754756382534, 42.84945385796683, 50.5525290625436, 34.84304462160383, 65.96381419045585, 16.272670677730016, 3.2663058170250485, 0.7219140880874225, 10.609537942068917, 10.930477840559822, 0.6714156121015549, 0.22467027285269328, 9.30304297379085, 71.0961149760655, 57.24816410882132, 60.499278341020855, 61.53675556182861, 59.98917634146554, 53.43852240698678, 56.463597842625205, 52.030699253082275, 52.59543146405901, 51.85954427719116, 51.20462097440447, 48.46652698516846, 53.374112606048584, 53.204468863351, 54.12433740070888, 55.82726444516863, 56.252914564950125, 56.67315551212856, 54.79510607038225, 58.630094800676616, 57.57824870518276, 51.95094435555594, 52.05546958105904, 44.96004213605608, 43.36211279460362, 42.34861728123256, 43.62296206610543, 41.36866072246006, 44.00494623184204, 42.50773450306484, 42.77407285145351, 42.8454065322876, 40.93839005061558, 39.53437103543963, 43.40943350110735, 41.88585335867745, 48.721046447753906, 54.4530462537493, 54.66515391213553, 54.89051873343331, 51.79317161015102, 52.50394105911255, 52.22652728216988, 49.45637777873448, 46.252327169690815, 43.44585248402187, 45.17433500289917, 48.746977124895366, 53.72842557089669, 53.42727674756731, 57.173564774649485, 51.799984318869456, 47.78617327553885, 54.24378388268607, 53.730190413338796, 52.772426400865825, 53.971511772700715, 49.3827303477696, 46.083718708583284, 44.780205386025564, 39.94387354169573, 41.98551484516689, 43.99589620317732, 41.78510447910854, 39.891595295497346, 39.65468256814139, 40.58318771634783, 41.45487397057669, 39.93094989231655, 38.95075709479195, 39.258023806980674, 38.33808926173619, 38.23725005558559, 38.93711083275931, 40.11747080939156, 38.926146575382774, 38.55271564211164, 37.84207820892334, 40.27615376881191, 40.086242130824495, 37.85227121625628, 37.37445054735456, 40.09014007023403, 37.94223649161202, 38.98813492911202, 38.97091381890433, 39.66079350880214, 39.51587493079049, 36.69724784578596, 41.231826373508994, 39.36277832303728, 41.913823332105366, 44.94301210130964, 47.39941917146955, 46.89960050582886, 47.48493412562779, 48.89393499919346, 45.729138238089426, 49.778228759765625, 50.76540797097342, 52.75181804384504, 51.83679934910366, 49.34354598181588, 49.10040072032383, 45.44236523764474, 4.445162160055978, 0.9278755762747356, 4.057168236800602, 5.023210159369877, 7.356842994689941, 4.327188696180071, 2.6919014964784895, 63.31040831974575, 37.86023037774222, 44.26516669137137, 36.677605288369314, 39.570136887686594, 36.15621246610369, 0.12452941494328634, 0.14821479256664002, 0.1487709198679243, 0.12204375118017197, 0.15121602080762386, 0.07148858359349625, 0.17137898744216987, 0.1337242429809911, 0.08937751475189414, 0.13700795892093862, 0.15937115677765437, 0.18200017751327582, 0.14239905535110406, 0.15002441831997462, 0.1284371388277837, 0.15579568435038837, 0.11574026942253113, 0.11549744888075761, 0.12096292631966726], [0.05824837727206094, 0.09448205227298395, 0.022885927664382116, 0.02386134719875242, 0.03664338801588331, 0.04961523713011827, 0.0367250225639769, 0.031014376852129186, 0.05598026201395052, 0.03680352906563452, 0.039807135571858714, 0.036353999615779946, 0.08890907453106982, 0.044856613368860314, 0.00578665266013039, 0.0566254809631833, 0.009000302225883518, 0.012488328452621187, 0.058815205070589266, 0.03945798859266298, 0.03710425239322441, 0.01635069736013455, 0.03491471488294857, 0.026827725881178464, 0.011274950079885977, 15.359847613743373, 46.68946613584246, 34.101612772260395, 31.88254921776908, 34.80875873565674, 35.107729298727854, 37.69047893796648, 0.14220814273825713, 3.3734372683933804, 1.3637708148785999, 1.5161931216716766, 1.1893179416656494, 0.22665553061025484, 0.12738570810428687, 18.147147008350917, 67.31163270132882, 56.502660615103586, 60.53356770106724, 54.73883260999407, 57.72420603888375, 47.6145145552499, 53.1301509312221, 50.16522257668631, 51.44836378097534, 51.403405461992534, 49.46783535821097, 52.98787614277431, 53.15245117459978, 55.811756065913606, 53.23329693930489, 52.68551138469151, 53.76679004941668, 53.96825654166085, 52.780583586011616, 50.1029007094247, 49.51151173455374, 46.37769004276821, 40.3959824017116, 39.537654059273855, 39.36925057002476, 37.68891906738281, 38.535977431706016, 39.992875712258474, 38.34209489822388, 39.910167830330984, 38.064719336373464, 36.8576192174639, 36.53772415433611, 36.04900871004377, 38.85555982589722, 48.65001848765782, 53.04966299874442, 50.67653356279646, 52.8362386567252, 50.74553264890398, 51.938892705099924, 52.96837254932949, 57.016354833330425, 52.46756376538958, 45.83765172958374, 39.83453321456909, 41.79341799872262, 45.5725918497358, 50.23695925303868, 52.34650182723999, 51.04405157906668, 52.85851805550711, 50.61406578336443, 51.113085406167166, 48.85403496878487, 45.04686682564871, 41.682573386601035, 36.9663793700082, 38.09283174787249, 38.21640893391201, 38.466262681143625, 40.453346729278564, 40.3931371143886, 40.48917858941214, 38.87733548028128, 34.9053178514753, 37.193581989833284, 35.849122932979036, 36.626970291137695, 33.6815698487418, 36.27670465196882, 34.92646816798619, 35.33408423832485, 37.09509127480643, 37.132580280303955, 34.96452692576817, 35.1764817237854, 36.355274881635395, 34.89676809310913, 34.52461910247803, 34.20193433761597, 34.52112763268607, 35.85320847375052, 34.75324957711356, 35.11186695098877, 33.86393574305943, 36.77954578399658, 35.35141651970999, 33.29044880185808, 35.02296822411673, 38.16702808652605, 38.738764081682476, 40.526337555476594, 39.89771318435669, 42.530677454812185, 42.76168073926653, 45.00427089418684, 44.88952486855643, 47.751251629420686, 46.143403734479634, 47.67552668707711, 44.482311793736045, 50.30890090124947, 25.39259648323059, 0.20708493861768926, 0.7071162164211273, 5.986631742545536, 17.818849836077007, 1.8507464953831263, 1.4959080730165755, 5.361540964671543, 39.99310152871268, 23.369892495019094, 41.91752324785505, 35.498492513384136, 28.95733676637922, 10.629844052450997, 0.3339628582554204, 0.10449612313615424, 0.08447356575301715, 0.018808429229206274, 0.12889814909015382, 0.029059076415640966, 0.05808752376054015, 0.020684602304494808, 0.027274312185389653, 0.04569281617711697, 0.07310699139322553, 0.03833939986569541, 0.03841230845344918, 0.041030330649976215, 0.06652989038931471, 0.022037115979141424, 0.02508979583425181, 0.031548411053206236, 0.03273324515404446, 0.015173250809311867, 0.07629263866692781, 0.08879826976252453, 0.056781031723533354, 0.04950761129813535, 0.09833333561463015, 0.006635748057825757, 0.023128339388806905, 0.037595993506589105, 0.015283526320542608, 0.00762953595923526, 0.04252667339252574, 0.01996709223437522, 0.03414269470210586, 0.021366993098386695, 0.06993551871606282, 0.014232231304049492, 0.04555733648261853, 0.02907954781715359, 0.01844931287424905, 0.02709509581992669, 0.051409154797771146, 0.0675128297880292, 0.04223073373681732, 0.15307982079684734, 22.23766269002642, 56.830709389277864, 34.805993352617534, 41.39866304397583, 39.356382506234304, 42.50093221664429, 40.076115131378174, 0.18457574716636113, 0.4607668040054185, 1.7723321659224374, 1.4177655918257577, 3.147574348109109, 0.4133406531597887, 0.13915823639503547, 24.538864374160767, 68.80683640071324, 58.59624317714146, 63.4783810206822, 57.81112452915737, 57.35649694715227, 48.503543513161794, 54.72225073405674, 51.80246829986572, 52.014610699244905, 53.026612349918906, 52.08691365378243, 54.721215452466694, 56.49733829498291, 56.768731457846506, 54.59517860412598, 53.1677372114999, 54.92746925354004, 55.08087853022984, 54.17717497689383, 52.62439850398472, 51.408446380070274, 49.770484992435996, 42.67554044723511, 40.73744119916643, 40.23643091746739, 41.170696122305735, 39.87745223726545, 41.024540764944895, 39.793048994881765, 40.870975153786794, 38.86446394239153, 37.817300932747976, 37.58188206808907, 39.07868732724871, 39.57840176991054, 48.22927379608154, 54.09128482001168, 51.1498761177063, 54.03527886526925, 52.763765471322195, 54.028535638536724, 53.661580426352366, 58.16328355244228, 54.129347051892964, 47.27902773448399, 41.67139026096889, 44.1032007081168, 48.287878377096995, 52.31507165091378, 53.064598151615684, 52.516242844717844, 53.26082917622158, 52.53579160145351, 52.45292738505772, 50.4357020514352, 45.92075913293021, 44.79561301640102, 38.99289444514683, 39.820779255458284, 39.518018450055806, 39.93792240960257, 41.94460037776402, 42.71582957676479, 42.63453912734985, 40.00683811732701, 36.69574703489031, 38.12729133878435, 37.29042945589338, 38.16502700533186, 37.520703179495676, 38.84330667768206, 37.602209023066926, 36.901625633239746, 38.622433866773335, 37.95188406535557, 36.605472564697266, 37.187582220349995, 38.558531284332275, 36.74355411529541, 36.40350580215454, 36.14437620980399, 36.21469892774309, 38.42789125442505, 37.86574377332415, 37.25931542260306, 35.91744109562465, 37.615052768162315, 37.212689535958425, 35.823209626334055, 37.24135085514614, 38.98965311050415, 41.53421197618757, 42.95302023206438, 42.483290740421836, 44.60196672167097, 45.91921663284302, 46.763269901275635, 48.39773287091936, 49.227271352495464, 50.013018812452046, 49.901865005493164, 46.70482512882778, 51.82595668520246, 28.870110818317958, 0.4710909585867609, 1.0000925468547004, 6.464916203703199, 10.779600313731603, 1.739576837846211, 0.9061891085335186, 6.268908389977046, 48.309059960501536, 28.248808111463273, 53.01004784447806, 39.81275756018502, 38.047869954790386, 15.498061180114746, 0.3690041708094733, 0.07088997321469442, 0.08469680377415248, 0.036098938302270005, 0.06737480219453573, 0.030242237927658216, 0.04059021926618048, 0.036662746619965346, 0.08939637124006238, 0.07706213130482606, 0.021547323957617794, 0.03914944514898317, 0.07015836997223751, 0.03902845556980797, 0.058011880676661215, 0.08896288914339882, 0.03285527967714837, 0.08766029189739909, 0.028600183182529042, 0.11012925300747156, 0.20068655695234025, 0.11200384170349155, 0.12014264533562319, 0.14608412475458213, 0.19432738104036876, 0.10625086897718054, 0.13047449450407708, 0.11947481759956904, 0.11188597338540213, 0.12875695952347346, 0.10266324398773057, 0.2092747746833733, 0.1311546987188714, 0.08896753032292638, 0.12035850089575563, 0.048567914936159334, 0.17706353669720037, 0.10365807810532195, 0.13656680259321416, 0.152591004169413, 0.13971280306577682, 0.19334080469395432, 0.13401829291667255, 0.23752468451857567, 23.963211332048687, 65.54988915579659, 42.79788432802473, 44.31010069165911, 46.21993119376046, 43.38035876410348, 47.02744735990252, 0.2169336708528655, 8.479646699769155, 3.95983179126467, 7.915578041757856, 3.352610260248184, 0.16367150816534246, 0.17995766497084073, 21.489812442234584, 72.50881576538086, 60.25505610874721, 66.46758638109479, 59.55230140686035, 62.4204135622297, 50.98760093961443, 58.79180717468262, 53.32746934890747, 56.61437375204903, 54.662947859082905, 54.772041525159565, 56.85957220622471, 58.4832307270595, 60.68558733803885, 55.53485298156738, 55.656074728284565, 57.30508722577776, 57.960330145699636, 56.519638538360596, 54.021719455718994, 53.67391695295061, 52.597099031720845, 44.69940478461129, 43.1785101209368, 42.2037855557033, 43.01868418284825, 41.67999560492379, 43.912809644426616, 41.814418928963796, 43.77457523345947, 40.09010532924107, 38.50734390531267, 39.27879892076765, 40.31385816846575, 42.91223430633545, 52.09950031552996, 57.16089473451887, 53.07463482448033, 56.650143078395296, 53.07878984723772, 56.99687555858067, 55.767259802137104, 60.63027272905622, 54.981154509953086, 50.22010292325701, 41.994582244328086, 45.556079455784385, 50.4282466343471, 54.34030130931309, 55.374429498400005, 52.37578501020159, 54.82293707983834, 53.343766348702566, 56.50478676387242, 52.54151691709246, 46.79189995356968, 45.84539202281407, 38.63061189651489, 41.10091188975743, 42.62587472370693, 40.12252214976719, 45.2769182068961, 45.10196604047503, 45.0783108983721, 42.52149541037423, 37.83128070831299, 38.725208146231516, 39.4293246950422, 41.96457644871303, 37.92259393419538, 40.68844250270298, 39.24331099646432, 39.71282856804984, 41.462704590388704, 41.45561742782593, 37.928281034742085, 39.07683910642351, 40.51791981288365, 39.16769027709961, 39.71756029129028, 36.6547074999128, 38.17860378537859, 39.63724953787667, 39.641800607953755, 37.590178217206685, 38.21765266145979, 40.28080906186785, 39.122700691223145, 36.8385603087289, 38.61040653501238, 41.69496897288731, 42.970772879464285, 46.044944286346436, 44.12475402014596, 46.264417035239084, 48.39380366461617, 49.410662106105256, 49.08827263968331, 50.09140144075666, 50.26743752615792, 49.771436895642964, 45.95532294682094, 52.387204374585835, 29.917081015450613, 0.631141681756292, 0.8740440277116639, 13.558958785874502, 28.371876341956003, 8.276001947266714, 1.6210595688649585, 7.556304063115801, 51.75704097747803, 32.34713356835501, 54.70942088535854, 41.23379271371024, 48.020615918295725, 19.473042215619767, 0.5530109256505966, 0.2090202019150768, 0.14945334967757973, 0.15755299505378517, 0.1914547758975199, 0.11145280341484717, 0.19431317251707825, 0.09343293535390071, 0.2125946565398148, 0.13204736581870488, 0.17824114779276506, 0.10219355526247195, 0.1216512458132846, 0.18830637341099127, 0.10588306228497199, 0.2871854954532215, 0.17671016923018865, 0.23091450493250573, 0.17160089553466865], [0.031989743800035546, 0.05352785664477518, 0.05988815213952746, 0.055068921630403826, 0.019045453385582993, 0.05465608735435775, 0.058341716549226215, 0.038243444836033244, 0.04034482029133609, 0.0765856775854315, 0.028943131744329418, 0.030149007216095924, 0.04735070453690631, 0.003419488252672766, 0.060355398138718944, 0.039706827740051916, 0.0434444564660745, 0.02398093051410147, 0.05887560147259917, 0.039355119291160784, 0.031215844077191184, 0.05276123421000583, 0.03527160394670708, 0.04454598342999816, 0.12230255800698485, 1.1282425160918916, 22.08391295160566, 32.34808199746268, 21.67995858192444, 41.371363571711946, 26.898107835224696, 53.890940461839946, 4.769936595644269, 0.4256158944751535, 0.7786272934504918, 2.308181583881378, 1.644295756305967, 0.8920660263725689, 0.1542103144207171, 0.04309414240664669, 38.625536237444194, 65.80200454166958, 55.952224322727744, 60.447055680411204, 55.719984258924214, 54.73882566179548, 52.070512431008474, 53.00305100849697, 52.503927162715364, 53.672238962990896, 53.04657105037144, 56.46576220648629, 54.96037939616612, 55.63239179338728, 51.909943035670686, 51.69961759022304, 52.37551403045654, 53.98961183003017, 54.98797416687012, 51.54489510399954, 48.43679911749703, 48.649083954947336, 40.312732560294016, 38.71603652409145, 39.41904483522688, 37.39008052008492, 39.94205658776419, 38.645818029131206, 40.731920855385916, 39.716163703373496, 40.51509537015642, 39.439007009778706, 37.45031097957066, 38.07705238887242, 37.80327251979283, 46.25027050290789, 51.63918910707746, 51.147034304482595, 52.549882548195974, 49.74491562162127, 49.49472141265869, 46.737346172332764, 33.6230069569179, 46.1582589830671, 55.106618131910054, 47.14285346439907, 45.19024290357317, 45.74971532821655, 49.638941696711946, 50.96800354548863, 52.41494853155953, 54.16208348955427, 51.107766560145784, 50.41787644795009, 45.05936663491385, 42.46307495662144, 40.349571909223286, 39.044873918805806, 41.44063016346523, 40.11670650754656, 42.604561124529155, 43.45863369532994, 46.48397316251482, 46.24835627419608, 44.849187101636616, 36.97940724236624, 37.76694386345999, 36.00061450685774, 35.10022177015032, 35.42461926596505, 37.564667906079976, 36.77008581161499, 36.79832329068865, 37.18622037342617, 35.332194328308105, 36.61790984017508, 35.405793121882844, 35.66183076586042, 37.1572151184082, 38.77968897138323, 37.251509121486116, 34.006863662174766, 34.015764304569785, 34.53195640019008, 36.301061562129426, 36.436085905347554, 34.89355802536011, 34.20976843152727, 34.74292802810669, 34.80464540209089, 37.754041058676584, 39.17444740022932, 43.180410453251426, 40.953040327344624, 44.39656754902431, 43.304296834128245, 46.15621968678066, 46.98467077527727, 51.731492451259065, 48.95899445669991, 51.16256352833339, 45.9869441986084, 44.83752802440098, 9.65008899143764, 0.1834430279476302, 0.6643180272408894, 4.844664471490042, 15.05527332850865, 4.782016473157065, 1.0366278035300118, 13.107035790170942, 32.85455008915493, 23.432349852153234, 39.071336133139475, 32.336127621786936, 30.284710202898296, 2.561187207698822, 0.2553516450737204, 0.00544082117266953, 0.07779378204473428, 0.10452269456748452, 0.08587444879646812, 0.06329454042549644, 0.02420875203928777, 0.013440275764358895, 0.05138188447537167, 0.018930833553895354, 0.08187640511563846, 0.05824824156505721, 0.05894460169864552, 0.03156697237864137, 0.11712224169501237, 0.13743098479296478, 0.05131900802786861, 0.02811811288951763, 0.025036485034174154, 0.05845018715730735, 0.048197336428399594, 0.009501474976007427, 0.04596764321572014, 0.018565440750015632, 0.05400075823334711, 0.087700495097254, 0.039418670881007395, 0.023132142577586428, 0.0576983703566449, 0.04364679560863546, 0.06543529805328165, 0.06314854004553386, 0.03225093907011407, 0.056956623015659194, 0.013686782447621226, 0.048887297976762056, 0.03079389707584466, 0.03502030171720045, 0.04175273974293044, 0.06870606754507337, 0.009089157234744301, 0.11840792984834739, 0.0917963156742709, 0.005303850397467613, 3.9837292517934526, 34.297322681971956, 35.95949159349714, 25.574189390454972, 51.0860777582441, 31.251201152801514, 58.817932401384624, 4.074679868561881, 0.4383774282676833, 0.5904273007597242, 1.927492388657161, 7.466264963150024, 3.225332941327776, 0.7966824589031083, 0.1724649148860148, 45.79069580350603, 66.21508189610073, 59.34786455971854, 63.320893151419504, 58.02885675430298, 55.20771442140852, 56.22769955226353, 55.29103374481201, 54.44651147297451, 55.85237523487636, 54.9743834904262, 58.4723915372576, 56.415509360177175, 56.51797097069876, 52.118354252406526, 53.01045778819493, 54.97624560764858, 56.228099073682515, 56.82236807686942, 54.860613686697825, 51.066539423806326, 50.10961266926357, 41.61074985776629, 39.91009834834507, 41.572579928806846, 38.833700793130056, 40.696050780160085, 40.42844785962786, 42.024476868765696, 40.967308453151155, 42.37308536257063, 40.23635448728289, 39.54094403130667, 38.51799201965332, 39.40315430504935, 48.615517207554404, 52.61580358232771, 53.10969196047102, 53.17313248770577, 50.67236464364188, 51.304886954171316, 49.8020715032305, 38.59997728892735, 49.69418682370867, 55.62689576830183, 46.937225001198904, 46.21665859222412, 46.330609049115864, 50.045157705034526, 51.227692467825754, 53.164440291268484, 55.82365138190133, 52.92016247340611, 51.49341590063912, 47.63479634693691, 44.880829198019846, 43.7317430632455, 40.97467354365757, 42.10493353434971, 42.30691419328962, 43.71136399677822, 45.65387882505144, 47.67943852288382, 48.19381366457258, 45.40070036479405, 37.894478048597065, 38.4923357963562, 37.93082407542637, 37.74753059659685, 36.969523429870605, 39.29792731148856, 38.61741726739066, 38.178426606314524, 40.14971045085362, 38.62391035897391, 37.091314928872244, 37.82703535897391, 37.176972321101594, 38.34224428449358, 38.31567784718105, 38.60277393886021, 36.31637191772461, 35.832787718091694, 35.7175726890564, 37.44476284299578, 37.18218347004482, 37.306889738355366, 33.710668904440745, 37.28474235534668, 37.374863965170725, 39.78515584128243, 39.910400594983784, 45.426988874162944, 42.6023759160723, 46.280793939317974, 44.06111894335066, 49.38016298839024, 48.525617940085276, 53.5089111328125, 48.48803513390677, 51.80166230882917, 45.90812383379255, 48.69285413197109, 10.53422120639256, 0.38676219220672337, 1.8977977420602525, 5.232565462589264, 8.536786947931562, 0.9215519555977413, 0.811149422611509, 13.434865696089608, 38.06691149302891, 30.445359502519878, 44.484903471810476, 34.1297390801566, 39.60856737409319, 5.252462497779301, 0.3627767121153218, 0.03526444879493543, 0.06581625475415162, 0.061107425285237174, 0.05006452230736613, 0.03715304245374032, 0.04365166070471917, 0.04384483962452837, 0.07854412642440625, 0.029729051715029136, 0.05074065191937344, 0.01983288479303675, 0.08784671260842256, 0.01586590105268572, 0.06889915146997996, 0.05356195981481245, 0.04404164531401225, 0.047884436789900064, 0.018003115031336035, 0.16216877023024218, 0.14098482552383626, 0.2550801767834595, 0.1138895923005683, 0.07945473399013281, 0.16584409587085247, 0.15727463284773485, 0.10938513757927076, 0.13828144701463835, 0.08519766439816781, 0.10975035905305829, 0.08354773186147213, 0.19300247356295586, 0.0816663849566664, 0.15723094876323426, 0.10735787850405488, 0.19627169599490507, 0.11293772302035775, 0.17777128943375178, 0.12502007718597138, 0.1447554581931659, 0.08994511608034372, 0.12207192395414625, 0.15478911836232456, 0.2178885731846094, 3.016763653073992, 39.900058201381135, 47.57448945726667, 29.899707044873917, 54.37372561863491, 36.26408324922834, 64.29368264334542, 6.864751160144806, 2.1753048854214803, 4.416982437883105, 7.855116554668971, 8.39240859236036, 5.762863704136439, 0.4755365571805409, 0.2064025223787342, 45.9236113684518, 67.39787374223981, 63.36019216264997, 65.00842298780168, 59.9199583871024, 58.089969635009766, 60.165069988795686, 57.094372681209016, 57.39702231543404, 57.158945764814106, 57.43723848887852, 60.33333451407296, 60.18156501225063, 58.44002682822091, 53.710130964006694, 56.22962072917393, 56.91803087506975, 58.66313348497663, 61.296361786978586, 56.66170835494995, 54.09169823782784, 51.10674517495291, 44.6123924936567, 41.45534644808088, 45.10410955974034, 39.1636255809239, 42.5938400541033, 41.91302081516811, 44.01293666022164, 44.46977376937866, 46.12794051851545, 43.11011552810669, 39.78340489523751, 40.18107461929321, 40.69528300421578, 51.28594963891165, 53.942621162959504, 53.2522759437561, 54.82652929850987, 53.05025012152535, 53.34508303233555, 48.02969373975481, 38.457747663770405, 51.40951292855399, 57.95356954847063, 50.792620590754915, 48.8203501020159, 49.70222588947841, 50.94640507016863, 53.33723851612636, 55.14117499760219, 60.329797880990164, 53.631925514766145, 54.66861064093453, 47.049243858882356, 46.529285839625764, 44.980521951402935, 43.86991146632603, 45.64181327819824, 44.538807596479145, 47.33016300201416, 50.12452350343977, 51.124813965388704, 49.812066486903596, 48.128121920994346, 40.426300866263254, 40.78018651689802, 40.235444273267476, 40.01342153549194, 38.61250489098685, 40.60550880432129, 41.119706766945974, 39.552189690726145, 42.22299385070801, 40.192229952131, 40.13545969554356, 40.76937164579119, 39.66715111051287, 41.75645010811942, 41.51679284232003, 40.748144899095806, 38.07821273803711, 37.28265789576939, 37.406881264277864, 40.9323069027492, 39.11231313432966, 38.55283028738839, 36.57948977606637, 39.377546719142366, 39.18846191678728, 40.95953689302717, 42.49944877624512, 47.575469153267996, 44.60291862487793, 49.15543392726353, 47.509318828582764, 50.38704034260341, 51.213664054870605, 55.81876679829189, 49.43503986086164, 52.163142340523855, 47.843975339617046, 48.808340140751426, 13.066991584641592, 0.5794285195214408, 3.455012376819338, 12.010294778006417, 30.15553276879447, 9.157888157027108, 1.3067155735833305, 17.774866001946585, 44.86557790211269, 33.41649259839739, 47.43756825583321, 38.93943847928728, 50.10877193723406, 5.142958887985774, 0.41970460595829145, 0.1785642933100462, 0.15395791296448025, 0.20474547200969287, 0.15795012802949973, 0.16345052288046905, 0.157749688784991, 0.18703110755554267, 0.2421953124659402, 0.11599212805075304, 0.14596125563340528, 0.13586746369089397, 0.12874330739889825, 0.09652714324848992, 0.19813650021595614, 0.19624424246805056, 0.1037132226462875, 0.12726133263536862, 0.12600783418331826], [0.04199758231905954, 0.025073388857500892, 0.04877739565979157, 0.08335894306323358, 0.026490962166073065, 0.03775533727769341, 0.03327385096677712, 0.08058116318924086, 0.042216579496328316, 0.051620922184416225, 0.03800077696463891, 0.05962872784584761, 0.018123889175642813, 0.044034937995352914, 0.03205610113218427, 0.08016107537384544, 0.054286662356129715, 0.07655574740575892, 0.033166913847838125, 0.15417731047741004, 0.02956893780667867, 0.05607150461790817, 0.03723424273942198, 0.051252949251128097, 0.14024613159043448, 0.1040517437670912, 3.728098511695862, 39.97347286769322, 21.097876719066075, 28.988221509116038, 34.637878213609966, 32.346869536808555, 22.53485972540719, 1.2716581118958337, 0.8916018541370119, 0.9643849943365369, 6.18837616273335, 4.861051797866821, 0.3091181085578033, 0.021741132218656794, 2.5791465640068054, 62.458864893232075, 60.64592702048165, 56.75619690758841, 57.26774065835135, 56.47461073739188, 57.08632319314139, 55.60805572782244, 55.02347946166992, 54.88024582181658, 56.38723366601126, 56.440540245601106, 54.54355696269444, 54.307478019169395, 52.25537967681885, 51.72471448353359, 54.13989789145333, 51.31991590772356, 53.55616235733032, 51.02194935934884, 53.06843703133719, 47.89140026909964, 37.61644588197981, 39.30298907416207, 40.01163584845406, 39.082981313977925, 39.039016587393625, 38.92871046066284, 40.28343548093523, 38.64746822629656, 41.185280391148154, 39.506439277103965, 36.91799211502075, 35.84265068599156, 38.02197401864188, 41.94025427954537, 50.966269969940186, 54.18699972970145, 49.213569504874094, 49.91571971348354, 47.08673286437988, 41.850400175367085, 39.907937458583284, 40.458596093314036, 53.8384815624782, 50.80909824371338, 49.10771369934082, 48.03441504069737, 49.01766504560198, 48.74808188847133, 53.507080282483784, 53.18475334984915, 51.50393547330584, 47.72450801304409, 44.96812636511666, 43.695223331451416, 41.30816970552717, 40.226901463099885, 44.23603984287807, 44.24675049100603, 48.145221437726704, 49.15289783477783, 51.03344515391758, 50.00248186928885, 50.53551639829363, 40.96104465212141, 35.773182596479145, 35.780957630702424, 35.32807404654366, 35.89283752441406, 37.461257866450715, 36.93610954284668, 36.531682695661274, 37.79151964187622, 37.43219007764544, 38.0384065083095, 37.341498715536936, 40.46020112718855, 46.0588059425354, 44.04545770372663, 44.28719595500401, 41.50324385506766, 40.68443686621529, 35.96892029898507, 33.60129383632115, 33.16039936883109, 35.649132932935444, 36.11290087018694, 32.56687034879412, 35.22087376458304, 36.36521775381905, 38.544450759887695, 40.9761882509504, 43.97121620178223, 45.29916633878435, 45.10395669937134, 47.36229494639805, 48.29299225125994, 47.66379812785557, 51.93379620143345, 52.47874689102173, 53.41894933155605, 22.828214406967163, 0.4806680732539722, 0.31118845460670336, 1.8103116708142417, 5.46856233051845, 4.421495292867933, 0.2553359573440892, 0.13692740324352468, 22.332889488765172, 34.152661187308176, 33.357783794403076, 31.836242948259624, 38.43120901925223, 18.29063425745283, 0.27953183757407324, 0.01856059261730739, 0.044523323753050396, 0.012098054617776402, 0.08072237311197178, 0.08198186302823679, 0.06908186059445143, 0.04231332162661212, 0.021294037013181617, 0.014711422912244285, 0.009828829106741717, 0.02236568638389664, 0.046023313621325154, 0.05704046958791358, 0.08336802864713327, 0.020005931578842655, 0.0813762569533927, 0.003169706789776683, 0.031149232294410467, 0.024373108487842337, 0.07845130961920534, 0.02141394602533962, 0.051600077588643344, 0.06657339126936027, 0.05377875514594572, 0.033527538246874294, 0.0444574549661151, 0.00612342612917668, 0.0738857053220272, 0.07360352974917207, 0.0420088460003691, 0.016889598353632858, 0.041352756920137575, 0.07389900460839272, 0.02862109223912869, 0.08003084414771625, 0.07431048859975167, 0.04830985449786697, 0.020902771669040834, 0.07136846253914492, 0.1037306949230177, 0.061573470277445655, 0.009918279530081366, 0.027995862931545292, 0.11933451012841292, 0.05189646168478897, 7.921516145978655, 51.138303892953054, 18.37875304903303, 43.560935497283936, 39.37987436567034, 40.75834832872663, 21.978713750839233, 1.215499296784401, 0.8957886323332787, 1.962729526417596, 4.3647215621812006, 5.364426638398852, 1.5943921655416489, 0.14501201228371688, 3.845202147960663, 66.52336651938302, 58.848400252205984, 59.82462910243443, 58.36805738721575, 59.512585503714426, 57.912769726344514, 56.47498941421509, 57.93435083116804, 57.52623101643154, 56.40836661202567, 57.03092867987496, 56.847836698804585, 55.248441287449424, 53.26898636136736, 53.963312898363384, 57.03840494155884, 54.55800921576363, 55.65760680607387, 52.68414258956909, 55.66017763955252, 49.1307817186628, 39.59602240153721, 41.01167617525373, 40.861713205065044, 41.544967787606375, 41.342261041913716, 40.85556404931204, 41.81754561832973, 40.874595165252686, 42.66756738935198, 41.25644384111677, 38.62690155846732, 37.953989369528635, 39.49371712548392, 44.61575889587402, 53.22825949532645, 54.15262351717268, 53.189196722848074, 52.30519131251744, 49.702826908656526, 41.62839480808803, 40.994156292506624, 41.50146164212908, 55.7389736856733, 51.03888559341431, 50.550416810171946, 49.65039580208914, 50.74959734507969, 51.224791594914024, 53.4388107572283, 54.50279188156128, 53.95370006561279, 49.12296152114868, 46.03890977587019, 44.625364780426025, 42.91076823643276, 42.840525422777446, 44.235536098480225, 45.21933501107352, 48.94249248504639, 49.916074071611675, 52.20993150983538, 51.254995414188926, 51.313940456935335, 42.20763485772269, 37.76466138022286, 37.256345067705425, 38.15559482574463, 38.281944343021934, 38.463518142700195, 38.979331561497276, 38.590430464063374, 38.75735398701259, 37.670047760009766, 38.2689824785505, 36.68819086892264, 43.09809514454433, 46.93481397628784, 46.52627032143729, 45.49334069660732, 41.40578842163086, 41.55922549111502, 37.03372131075178, 36.29480818339756, 33.624316692352295, 36.84335109165737, 36.61950445175171, 35.49364961896624, 36.388254506247385, 39.14278098515102, 40.41854667663574, 42.97912808826992, 46.34976870673043, 47.116637911115376, 46.5670736176627, 49.21334021432059, 49.225565569741384, 52.04222631454468, 52.64048705782209, 53.22236047472273, 50.694487707955496, 26.17564456803458, 0.44653928173439844, 1.725469931960106, 5.352797091007233, 5.769127070903778, 3.280662532363619, 0.17422291769513062, 0.1311192384787968, 26.984852620533534, 38.11030299322945, 41.64617872238159, 28.897241796766007, 41.965948717934744, 26.816292796816143, 0.49817753370319096, 0.08572547643312387, 0.05473855310784919, 0.024706605056832944, 0.042873031592794826, 0.03057219593652657, 0.03888805988909943, 0.074622689347182, 0.012711742044692593, 0.038594603671559265, 0.041173111381275315, 0.08141694869846106, 0.039381578764212985, 0.06110865343362093, 0.03406875134844865, 0.02139406155661813, 0.024921805830672383, 0.03240315822352256, 0.06213961275560515, 0.047920897869127135, 0.09376127166407448, 0.08233560368950878, 0.15238482451864652, 0.1820260432681867, 0.060289213832999976, 0.14336215438587324, 0.1439909799290555, 0.15693114485059464, 0.1303656032042844, 0.16455805487930775, 0.14440629764326982, 0.11675370218498365, 0.14348931184836797, 0.09766476149005549, 0.1301526382033314, 0.1523119905697448, 0.15919595903583936, 0.17551473980503424, 0.18081688029425486, 0.25326398281114443, 0.1818554459937981, 0.14001058494406088, 0.16353512262659414, 0.11647855623492173, 0.2672263878796782, 0.11438884479658944, 7.930907504899161, 59.20751094818115, 29.074851649148123, 41.37753357206072, 44.07934406825474, 42.4581104687282, 26.500148023877824, 1.2460339154515947, 3.931417567389352, 2.8375850277287618, 14.603227002280098, 10.515612193516322, 2.3305636857237135, 0.12612858627523693, 3.427398498569216, 68.19891766139439, 60.50569152832031, 61.783465249197825, 60.423911230904714, 62.39765126364571, 60.62351213182722, 58.87850679670061, 61.45312704358782, 59.89393738337925, 58.59565258026123, 59.90943186623709, 55.08087158203125, 58.567699977329795, 55.108598368508474, 55.58795458929879, 59.921285493033274, 57.34860726765224, 58.173174313136506, 56.14198310034615, 58.88323851994106, 53.08115918295724, 40.08645405088152, 42.2497478893825, 43.615610871996196, 43.348845209394185, 44.947028160095215, 44.153418813432964, 43.16182402202061, 42.76704127447945, 43.03253889083862, 43.569381032671245, 40.06512655530657, 40.03726775305611, 41.40586832591465, 47.86252702985491, 54.79884420122419, 58.03130946840559, 52.97494554519653, 54.72631890433175, 50.196885517665315, 42.135411807468955, 39.45491491045271, 44.22316830498831, 57.151629311697825, 53.34280749729702, 52.80228281021118, 52.85398088182722, 51.424743379865376, 51.700579915727886, 55.521613189152305, 57.72833326884678, 56.10522018160139, 51.16684709276472, 48.78837101800101, 47.82551745006016, 45.151888847351074, 45.31095395769392, 48.26295518875122, 47.63881240572248, 52.5826849937439, 51.69185297829764, 54.28997203281948, 52.462519373212544, 53.96092619214739, 44.280796664101736, 39.941604954855784, 39.23191247667585, 39.7105530330113, 40.80740261077881, 40.592435768672395, 41.839800698416575, 40.806996141161235, 41.470045362200054, 42.37808806555611, 40.620013168879915, 39.962255001068115, 46.28740515027727, 48.82486643110003, 48.595607144492014, 47.661519118717735, 43.07084083557129, 44.3210962159293, 38.737659318106516, 35.946595736912315, 35.02419458116804, 39.31384563446045, 39.522288118089946, 35.99706745147705, 39.786437783922466, 40.960930006844656, 41.49621227809361, 43.77604825156075, 48.74020610536848, 49.01432991027832, 48.850237778254915, 50.93030609403338, 50.648754664829795, 54.09698929105486, 54.84696395056588, 53.35731533595494, 51.85146699632917, 27.0697318145207, 1.0064514513526643, 1.6790697532040733, 4.400239016328539, 14.057254058974129, 11.674678547041756, 0.9865317259516034, 0.20766158481793745, 29.41546971457345, 46.098855359213694, 44.04843153272356, 39.666984353746685, 50.08150373186384, 32.18628971917288, 0.3882781208625862, 0.21571644688291208, 0.11203623496528183, 0.09390993190131017, 0.16993976038481506, 0.27978343835898806, 0.17264909643147672, 0.18787407875061035, 0.0740703007738505, 0.11864464357495308, 0.09246489658419575, 0.1916637375418629, 0.08218530818287816, 0.2541130743920803, 0.14601225432540688, 0.10332643054425716, 0.09152450133115053, 0.1370650508574077, 0.19461457777236188, 0.12430625834635325], [0.026111978305769817, 0.07562403061560222, 0.03306475022275533, 0.03749286296910473, 0.02214343223853835, 0.037501239483909946, 0.040670510314937146, 0.04572325865072863, 0.03839084978348442, 0.05687555504430618, 0.03731939209891217, 0.03199632219704134, 0.005413170022490833, 0.006559984109896634, 0.017871959301243936, 0.04574405574905021, 0.03631826117634773, 0.023059430764988065, 0.02556454303807446, 0.048568366161946736, 0.01856293695579682, 0.03557964188179799, 0.027915115567988584, 0.014308948169595428, 0.04110039956867695, 0.06345212339822735, 0.10171596838959626, 9.708932416779653, 43.40399653570992, 21.804246221269878, 44.3001196043832, 26.831716060638428, 36.244635241372244, 0.18032040979181016, 0.7154290303587914, 0.3821130602487496, 5.368419247014182, 3.3025686826024736, 1.9762524579252516, 0.7724309116601944, 0.03812476906127163, 14.66704273223877, 69.72825091225761, 53.25674016135079, 60.61909307752337, 58.42968790871756, 59.54286575317383, 54.507513182503835, 57.86977774756295, 55.713904585157124, 57.839153562273296, 53.37699958256313, 53.827225480760845, 50.72928428649902, 54.76593753269741, 52.28109843390328, 54.41746800286429, 53.77647583825247, 53.951018060956685, 53.502751554761616, 54.64932244164603, 45.434475558144705, 39.4615295955113, 38.62601566314697, 38.61156341007778, 39.06398146493094, 41.33130720683506, 39.50441040311541, 40.712486743927, 39.9646486554827, 38.570398807525635, 37.878097670418875, 37.676898683820454, 35.626339367457796, 36.98740809304373, 39.1859883580889, 46.46679721559797, 50.057709625789094, 52.56266723360334, 52.31945596422468, 55.0414822442191, 53.63885286876133, 52.595007623944966, 53.72785929271153, 52.92246927533831, 51.710456780024934, 51.41425507409232, 50.39892176219395, 51.03463676997593, 52.00251735959734, 51.79654843466622, 51.782652037484304, 49.636308329445974, 50.762093680245535, 45.43881123406546, 44.65401567731585, 46.04847049713135, 46.4603909764971, 50.20070355279105, 50.12709433691842, 50.90309000015259, 50.735416071755544, 51.880263805389404, 50.923000063214985, 51.050544670649934, 42.31062453133719, 35.32593400137765, 36.74063587188721, 35.81806101117815, 36.41846179962158, 37.29731512069702, 38.411785330091206, 36.53132138933454, 35.84309537070138, 36.07371303013393, 36.08461127962385, 40.76854828425816, 48.43177209581648, 50.17551633289882, 47.08035789217268, 47.4145245552063, 48.764872210366384, 45.49494225638253, 43.51836388451712, 40.493656703404014, 38.7175303867885, 34.22761140550886, 35.314368724823, 35.30447449002947, 34.0370466368539, 33.75317798342024, 37.43676894051688, 40.289886883326936, 42.7603987966265, 43.94694267000471, 45.502050263541086, 46.13856084006173, 48.27840798241751, 49.30297197614397, 46.850421156202046, 49.5298376083374, 35.59650380270821, 3.6455825737544467, 0.2289279986705099, 1.3860428311995097, 3.071917150701795, 2.2905516156128476, 1.569195174745151, 0.15970651592527116, 0.6541814740215028, 17.745836428233556, 34.20430019923619, 24.015869992119924, 27.17155245372227, 36.439758028302876, 2.0203049055167606, 0.11382190843245812, 0.08037513960152864, 0.02794987352431885, 0.05673540024352925, 0.03450328856706619, 0.013404187879392078, 0.0654623308884246, 0.03225238774237888, 0.040482159171785624, 0.0073068874688552955, 0.048195019231310914, 0.04006379144266248, 0.09399667581809418, 0.008136257429474165, 0.032676360170756064, 0.021458982090864862, 0.02210540883243084, 0.05981846659311226, 0.020107543894222805, 0.04837800994781511, 0.08472087819661413, 0.04484451508947781, 0.06329695601016283, 0.01862408822801496, 0.04171229227046881, 0.04206688788586429, 0.014472721078033959, 0.04872941644862294, 0.09200699401221105, 0.06796228459903172, 0.021389408502727747, 0.026712122173713784, 0.046689618046262434, 0.021064218898702945, 0.042614787950047424, 0.061714340932667255, 0.012547497554416103, 0.03365813588191356, 0.030164016410708427, 0.011881696093561394, 0.012014910329266318, 0.06147019046225718, 0.030524891867701496, 0.1262796688824892, 0.04123533643516047, 0.1040195676365069, 0.4804742836526462, 20.609093529837473, 41.05003717967442, 20.774960926600865, 55.52747399466378, 29.113933529172623, 40.71596431732178, 0.04657824330830148, 0.22759927782629216, 1.1613210439682007, 3.76069598538535, 3.7894263522965566, 4.048144263880594, 3.1734079676015035, 0.3298979720899037, 19.209726333618164, 71.39308098384312, 51.451698916299, 63.680698667253765, 58.51802035740444, 62.173085485185894, 55.348457132067, 59.861628259931294, 57.00582136426653, 60.90435137067522, 56.027740819113596, 54.868725708552766, 51.657626152038574, 57.09626259122576, 53.31397942134312, 55.447722571236746, 54.55674464362008, 56.93891021183559, 54.39062016350882, 54.86457068579537, 46.78189107349941, 40.4716135433742, 41.02671902520316, 40.935450962611604, 39.50950343268258, 42.60623564038958, 40.748075417109895, 42.39164400100708, 41.775522913251606, 40.7260148865836, 38.85954809188843, 40.09826251438686, 37.86144978659493, 39.89595876421247, 40.07736580712454, 47.067628792354036, 52.19947099685669, 53.73646116256714, 53.607617241995676, 53.560949666159495, 50.06714527947562, 52.29775326592581, 57.382834093911306, 53.76000165939331, 54.04818514415196, 52.34544570105416, 52.19173070362636, 53.44545323508126, 53.14164672579084, 52.22604438236782, 53.82774312155587, 51.45288011005947, 50.1660806792123, 46.26511880329677, 46.565749985831125, 46.22809532710484, 46.83548600333077, 51.67111260550362, 51.06789779663086, 52.87040989739554, 52.51753520965576, 52.97848217827933, 51.92454467500959, 53.43909215927124, 45.02167613165719, 37.27170753479004, 37.00074168613979, 36.7304949760437, 38.70445735113961, 40.01624597821917, 39.083881105695454, 38.11158840996878, 38.2838203566415, 39.388385908944265, 38.47083459581648, 42.87951176507132, 51.02725430897304, 49.950314794267925, 48.83708483832223, 48.92944376809256, 50.707605906895225, 47.792687211717876, 45.57419688361031, 42.582163606371196, 39.58171606063843, 36.00142397199358, 36.49127892085484, 36.89832523890904, 34.72674914768764, 36.101123673575266, 39.55541018077305, 43.43912315368652, 44.848540919167654, 46.624531745910645, 47.361270087105886, 47.52476119995117, 49.39420877184187, 50.692559582846506, 49.882562909807476, 49.79147202627999, 38.9666337285723, 3.729614087513515, 0.9174626150301525, 4.573996961116791, 8.035668100629534, 8.29477424280984, 0.7202311041099685, 0.17936117840664728, 0.6091767432434219, 20.92069070679801, 40.288858549935476, 32.38536255700247, 27.78186658450535, 45.4700607572283, 4.294317202908652, 0.07777335135532276, 0.026627541087301712, 0.07945495790668897, 0.045120875617223125, 0.075730268843472, 0.028857269923069646, 0.048383404301213365, 0.019326473752568876, 0.03316809789144567, 0.007348258597111064, 0.03600322754521455, 0.0049860207779732135, 0.015753026752333556, 0.030843185859599283, 0.03541489697194525, 0.013355490269272454, 0.04083338246813842, 0.04119962174445391, 0.06376360489853791, 0.05934465916029044, 0.13331043161451817, 0.1608415421630655, 0.15061937139502593, 0.13400005389537128, 0.10341494543743984, 0.09248804141368185, 0.1108838382310101, 0.10487675414021526, 0.19235726818442345, 0.13494680023619107, 0.13383829114692553, 0.18073894376201288, 0.15090696167732986, 0.08078751247376204, 0.07170723471790552, 0.17895462736487389, 0.10412596192743097, 0.06895639946950333, 0.07907770600702081, 0.07363451165812356, 0.09534982392298323, 0.11309174368424074, 0.09685053303837776, 0.23550718277692795, 0.1633551615689482, 0.1657071675040892, 0.5250387809106282, 25.186834267207555, 58.60836778368269, 30.079536846705846, 56.05743047169277, 35.4056715284075, 44.85125419071743, 0.6889109047395843, 3.041271469422749, 3.6585896015167236, 17.04507064819336, 11.334563357489449, 5.101345258099692, 3.379295902592795, 0.3412697304572378, 18.833955594471522, 72.86744008745465, 52.66302006585257, 63.559661047799246, 61.34413760049002, 64.4026859828404, 57.55256468909127, 60.72437913077218, 58.488928249904085, 60.53118446895054, 57.0706376348223, 58.794086183820454, 51.552520751953125, 56.195049967084614, 55.86790098462786, 58.10898338045393, 58.616476331438335, 58.532278060913086, 57.42536401748657, 58.05168853487287, 48.93781982149397, 43.092626912253245, 42.90138469423567, 43.245744364602224, 42.59900256565639, 45.710708141326904, 43.12068026406424, 44.64641087395804, 45.00710228511265, 43.25315809249878, 40.30723306110927, 41.89377777917044, 39.80024038042341, 42.11308377129691, 41.756182602473665, 48.72026130131313, 53.453912666865754, 55.51114920207432, 56.61869553157261, 56.58645589011056, 54.66560207094465, 54.48281233651297, 55.58158656529018, 56.86001341683524, 55.79059880120413, 55.97125891276768, 53.51017223085676, 56.37364993776594, 55.605891363961355, 53.444042750767295, 55.09864854812622, 53.37646804537092, 54.536375999450684, 49.10223504475185, 49.99016966138567, 50.531472546713694, 50.0795373916626, 54.944857120513916, 53.768210956028526, 56.07232046127319, 54.46309682301113, 55.03642742974417, 54.96286685126168, 56.559142521449495, 46.24962779453823, 39.577981403895784, 40.64940752301897, 38.75813218525478, 39.959357602255686, 41.335458755493164, 40.076775210244314, 41.88608612333025, 40.32310274669102, 40.303408077784944, 41.69998904636928, 46.39218051092965, 52.773173332214355, 53.22065816606794, 49.33938748495919, 50.6696583202907, 53.6248904636928, 51.89534139633179, 46.62527520315987, 45.30488470622471, 42.71993596213204, 37.849714279174805, 38.95351900373186, 39.95583486557007, 37.038828236716135, 38.79543011529105, 42.60125378199986, 45.644533497946604, 45.34037263052804, 49.010397229875835, 49.786983489990234, 50.57705967766898, 50.74861764907837, 53.05083377020699, 50.26511335372925, 50.71225077765328, 38.67820358276367, 5.667764578546796, 0.651361916746412, 5.283539618764605, 11.144205297742571, 7.604369963918414, 7.35810843535832, 0.34150995899524006, 0.8256281656878335, 26.7890020098005, 44.15664625167847, 34.768341064453125, 36.44460787091936, 53.746285915374756, 4.854242563247681, 0.240167714123215, 0.1557374931871891, 0.11689250330839838, 0.1704340460044997, 0.15501876175403595, 0.12680347077548504, 0.18054653837212495, 0.10517414925353867, 0.15523061395755836, 0.09251565100359065, 0.08471186046621629, 0.16607437708548137, 0.1317189820110798, 0.11546551702278, 0.1411070025392941, 0.0882647783894624, 0.14318391680717468, 0.16835494685385907, 0.19006046785839967, 0.22146191501191684], [0.024089864222332835, 0.0833636995937143, 0.009903646922404212, 0.02874457204182233, 0.08206240513495036, 0.035255285179508586, 0.030320486586008753, 0.04116258730313607, 0.09433863711144243, 0.05027321253770164, 0.06391059593962771, 0.023832117606486593, 0.031908791179635694, 0.021668111672624946, 0.008533824667600649, 0.06349298477705036, 0.022111435919733982, 0.04686017121587481, 0.055712478168840916, 0.05628101248294115, 0.0051379769990619805, 0.0025424830133228427, 0.059371888770588806, 0.002997453465858208, 0.04939106612333229, 0.039720578252204826, 0.07879415300807782, 1.1801933284316743, 44.78762953622, 24.59697389602661, 32.74371937343052, 34.1240485055106, 33.97788619995117, 9.752083335603986, 1.3513670861721039, 0.2842055596411228, 1.5310984190021242, 4.8564282059669495, 3.179294611726488, 3.8039819598197937, 0.2663953181888376, 0.17966315363134655, 39.1932874407087, 67.41116564614433, 56.4423120362418, 61.76729679107666, 55.124541010175435, 61.18406500135149, 56.492960929870605, 60.483054297310964, 55.133622305733816, 55.23120628084455, 53.7558570589338, 58.05134807314192, 53.125054427555625, 55.17558247702462, 54.37956557955061, 57.1747841835022, 52.50645978110177, 55.51127774374825, 54.42955786841256, 44.90756586619786, 37.45993423461914, 40.71597473961966, 38.06750556400844, 39.99352189472744, 41.62001528058733, 48.26413638251168, 45.804512296404155, 42.38239247458321, 39.79947260447911, 37.58168057032994, 36.537446226392476, 37.752300534929546, 36.93420573643276, 36.82514681134905, 39.765179770333425, 48.00755330494472, 49.53833525521414, 51.036686488560264, 51.088867459978374, 51.2995194707598, 50.36555303846087, 50.8853304045541, 50.64073644365583, 51.5887382371085, 51.762200014931814, 50.93511077335903, 54.5733299936567, 50.86669186183384, 51.04820312772478, 50.80875778198242, 50.225741386413574, 49.15973833629063, 49.94624662399292, 48.31326709474836, 48.83814096450806, 49.933646065848215, 50.05900893892561, 50.29556730815342, 51.64634575162615, 52.98628847939627, 52.95478534698486, 50.18448993137905, 51.03946229389736, 39.422710009983604, 35.58104406084333, 36.62906864711216, 36.34228522436959, 37.750018051692415, 37.09582083565848, 36.49804994038173, 36.74622917175293, 36.54632602419172, 37.024362087249756, 36.55910376140049, 43.79184150695801, 50.146934917994905, 50.249591078077046, 49.98237725666591, 49.55086285727364, 46.2993734223502, 48.450240407671245, 46.144022124154226, 46.3921422958374, 47.120178018297466, 44.57683856146676, 37.485284737178254, 34.1285057749067, 35.825353145599365, 35.8286257471357, 34.17334597451346, 36.93018967764718, 41.56204645974295, 42.96064240591866, 43.68790340423584, 46.166350160326274, 46.018506390707834, 48.722846031188965, 51.649899755205425, 43.15242658342634, 10.209324308804103, 0.028640800288745334, 0.8810713706271989, 3.825348104749407, 7.941287245069232, 5.275727237973895, 0.44267795607447624, 0.07760964121137347, 0.6846545902746064, 22.7570891720908, 41.44916949953352, 20.45486089161464, 37.392734731946675, 22.805240188326152, 0.12414840395961489, 0.04328716526340161, 0.08855097088962793, 0.016356040823406408, 0.05589355541659253, 0.03550647545073714, 0.07202409700091396, 0.03848680820582168, 0.030066412540950944, 0.05498027103021741, 0.041705839402441464, 0.093234789557755, 0.07407548478139298, 0.060774658141391616, 0.03817045821675232, 0.04211463300245149, 0.07810463929282767, 0.02929472823494247, 0.05615017736064536, 0.018634239111893942, 0.01212229358498007, 0.02559507541757609, 0.06434959452599287, 0.06417854941849198, 0.022778675026659454, 0.05634548009506293, 0.05423433712816664, 0.0558914112459336, 0.058824093879333565, 0.015485268352287156, 0.05628492084464856, 0.06844493334314652, 0.03491262838776622, 0.021983934100717306, 0.011268285169665302, 0.008130474614777734, 0.049583797210029194, 0.03213295879374657, 0.047347396678690395, 0.03768453893384763, 0.053597884851374795, 0.0496656726380544, 0.024511648375274878, 0.017684771845649396, 0.005320069504835243, 0.05084915306153042, 0.06828894492770944, 0.00707442858090092, 2.102498403617314, 60.24094431740897, 19.227023874010357, 46.013910157339915, 41.45618370601109, 39.06573241097586, 9.75783383846283, 1.2925405970641544, 0.26289478316903114, 2.45228157724653, 3.747622949736459, 6.248833307198115, 6.456650452954428, 1.9444288398538316, 0.4304219037294388, 45.792755944388254, 64.74965122767857, 55.43116848809378, 62.78162956237793, 56.01604005268642, 62.66371168409075, 57.21588972636631, 60.94265678950718, 55.826538358415874, 57.92393895557949, 56.35231549399239, 60.38451494489397, 54.77756186894008, 56.18036494936262, 54.64314201899937, 58.474712235586985, 53.931955678122385, 55.97805425098964, 54.47056613649641, 46.0144555909293, 39.27596752984183, 40.76563351494925, 39.73127256120954, 42.55392265319824, 43.53572743279593, 49.17015716007778, 46.994269711630686, 44.03090817587716, 40.101062638419016, 38.23836176736014, 39.26108796255929, 38.91722508839199, 37.70974629265921, 40.34481586728777, 41.378798144204275, 49.53193596431187, 51.992668288094656, 54.221883160727366, 52.870354311806814, 54.85603134972708, 51.2771532194955, 53.99682753426688, 53.754088742392405, 51.84916019439697, 54.33480181012835, 52.30340215138027, 53.56258944102696, 52.0167681149074, 52.31734371185303, 54.68074219567435, 52.27367080960955, 50.72532728740147, 51.2059828213283, 48.111640793936594, 49.6610369682312, 51.2785359110151, 51.74106706891741, 52.381312302180696, 52.76450545447213, 54.946948528289795, 54.277628558022634, 51.63563162939889, 52.786499977111816, 42.02727699279785, 36.3858573777335, 38.71950020108904, 37.94985171726772, 39.265058858054026, 38.5971736907959, 37.870673520224436, 36.85057026999337, 37.346914836338584, 38.123553207942415, 37.83544615336827, 47.3578758920942, 51.144067423684255, 50.71986252920968, 52.10997819900513, 51.273022515433176, 47.88934012821743, 49.63945933750698, 49.59591497693743, 49.33527415139334, 47.49928910391671, 45.13386174610683, 39.38086795806885, 36.071795327322825, 36.20779936654227, 36.02574266706194, 37.504486083984375, 39.63190984725952, 44.04841763632638, 46.029515811375205, 45.847500801086426, 47.118864808763774, 48.17472348894392, 50.08009672164917, 51.12398712975638, 45.1177453994751, 11.331177847726003, 0.373019279646022, 3.2223656262670244, 6.59110460962568, 11.040083936282567, 4.871876222746713, 0.0671160225091236, 0.09579702599772386, 1.1609451898506709, 24.92879727908543, 49.707593372889924, 19.19202058655875, 38.57671124594552, 29.602549961635045, 0.24341198003717832, 0.026121995178982615, 0.05670769565871783, 0.047052342511181316, 0.07123783776270491, 0.019974481480728303, 0.04342824626447899, 0.030298128857144287, 0.045178534130432775, 0.03203451354056597, 0.030717806158853427, 0.05668438119547708, 0.05167732880051647, 0.10629367775150708, 0.033305633547050614, 0.03347137590338077, 0.053837472173784456, 0.02928947637389813, 0.017362683146659817, 0.06382275279611349, 0.01923315822412925, 0.1669072245380708, 0.15179977805486747, 0.18441718710320337, 0.1002126604850803, 0.10576836272541966, 0.06641801353543997, 0.1955553801464183, 0.12489388324320316, 0.2734320791704314, 0.1558951304427215, 0.13775079191795417, 0.07249419963253395, 0.09141757778291192, 0.06789645991687264, 0.09493804137621607, 0.1619824038020202, 0.17523518337735108, 0.1384948327073029, 0.12480916136077472, 0.15754612827939646, 0.16919170266815595, 0.17634920217096806, 0.12817932266209806, 0.12808766615177902, 0.15687661777649606, 0.1869296801409551, 0.11677137123686926, 4.825077499662127, 67.88965334211076, 34.81854179927281, 45.378420966012136, 45.93914754050118, 45.5532237461635, 12.189051083156041, 1.8641710664544786, 4.413708533559527, 4.1041267684527805, 13.403029918670654, 12.21122886453356, 9.920411263193403, 1.6829161239521844, 0.5616355400000299, 44.88354941776821, 65.50126566205705, 57.21724462509155, 63.33441434587751, 57.22887938363211, 64.06726169586182, 58.62144429343087, 63.00627177102225, 57.317798955099924, 61.43594414847237, 55.78569337299892, 63.56881182534354, 57.27379601342337, 57.43001931054251, 57.1965320450919, 61.94180079868862, 55.99585206168038, 58.47642844063895, 57.41617502485003, 48.37327868597848, 40.02775566918509, 44.42716046742031, 42.818016733442036, 45.960777282714844, 46.93893773215157, 52.95246812275478, 50.445335728781565, 46.67719561713082, 43.1775860105242, 41.43092353003365, 41.71923208236694, 41.993741512298584, 40.464905057634624, 42.474845205034526, 42.95225593021938, 52.230946336473735, 53.62179504122053, 56.34054524557931, 54.733048234667095, 55.68246398653303, 54.592218671526226, 53.34187991278512, 54.88679449898856, 52.81804479871477, 54.188000270298545, 53.95225831440517, 56.60791540145874, 53.007483959198, 53.71805191040039, 56.302048751286094, 53.47501087188721, 52.8187187739781, 53.37062461035592, 51.11898790087019, 52.86023773465838, 53.23817457471575, 52.81165593011038, 53.69916670663016, 54.83847325188773, 56.61361639840262, 56.135743618011475, 53.52215092522757, 55.84232813971383, 43.520392758505686, 38.078567096165244, 40.77283532278878, 40.887046337127686, 42.881780351911274, 41.546176774161204, 40.72448280879429, 39.234083788735525, 39.41868352890015, 41.25193098613194, 38.73188189097813, 48.71003702708653, 52.78165708269392, 53.79570497785296, 54.20990446635655, 53.32310240609305, 50.309189251491, 53.80583197729928, 51.20918246677944, 50.968792166028706, 50.57371759414673, 49.42699384689331, 41.82724182946341, 38.632484436035156, 39.353415625435964, 39.93870408194405, 38.4442959512983, 42.37720564433506, 46.835524218423025, 47.58299057824271, 46.88209799357823, 50.74484825134277, 50.15603705814907, 51.8575119291033, 52.6886693409511, 47.14588287898472, 12.79434427193233, 0.44197993353009224, 1.4723793012755257, 10.169511999402728, 15.062310116631643, 15.758952140808105, 2.817059180566243, 0.25779073419315474, 1.6818242796829768, 34.64676495960781, 51.78532361984253, 29.353071417127335, 48.3344521522522, 35.2141409601484, 0.24020519639764512, 0.10517967252859048, 0.15451842360198498, 0.17697820413325513, 0.17334026577217237, 0.08920759601252419, 0.13440786701227936, 0.11919300843562398, 0.21473037265241146, 0.1193187545452799, 0.1329870011125292, 0.14366683017994675, 0.12652464716562203, 0.19567899565611566, 0.1788205759865897, 0.1478664055466652, 0.14148696857903684, 0.09865155496767589, 0.16830514238349029, 0.08576341332601649, 0.08856855173196111], [0.02349826819928629, 0.07267831332449402, 0.026158486792285527, 0.014451238659343548, 0.04948016116395593, 0.011945614092318075, 0.04925130148019109, 0.027042790948014175, 0.009714754647575319, 0.03930407649438296, 0.06917477917990514, 0.17513287386723927, 0.04102845110797456, 0.07698836097759859, 0.03455029408048306, 0.07812936510890722, 0.028814525609569888, 0.019809080088245015, 0.05171957439077752, 0.031982944879148684, 0.03903886429699404, 0.0592493453462209, 0.09806345509631292, 0.023190907102876475, 0.037184835212039094, 0.03670932465632047, 0.15562355358685764, 0.08474311378917523, 15.769419601985387, 37.81773172106062, 20.468178851263865, 56.41629103251866, 26.687884875706263, 18.0019348689488, 0.04742158430495432, 0.9180769877774375, 1.9886437015874046, 1.727286234498024, 3.700630111353738, 3.1292884264673506, 0.866107990699155, 0.056218522800398726, 5.492432866777692, 58.7438576562064, 58.49531364440918, 61.76163400922503, 59.22734110695975, 59.777033942086355, 57.65113183430263, 55.41726861681257, 52.27365343911307, 56.72486400604248, 55.89125735419137, 55.21004901613508, 54.87503467287336, 56.5729763848441, 54.7913818359375, 55.34941250937325, 58.02385752541678, 55.27409751074654, 49.144469669886995, 43.15882240022932, 39.52587686266218, 39.22225448063442, 38.787272930145264, 39.887898853846956, 47.92978211811611, 53.02403456824166, 52.52922902788435, 47.27665145056588, 40.081937721797395, 37.99555001940046, 37.43911395754133, 37.21572937284197, 37.226839542388916, 37.903343949999126, 36.754903997693745, 39.78690331322806, 46.92224815913609, 50.702867235456196, 52.17415870938982, 52.018564224243164, 54.77141618728638, 54.260890347617014, 51.57731192452567, 54.502830096653526, 51.963332993643625, 50.090397426060264, 50.758456298283164, 49.43338966369629, 49.872838905879426, 53.253349440438406, 52.054055622645784, 53.52460363933018, 53.31469161169869, 52.90178448813302, 50.440798555101665, 52.345845222473145, 52.51537431989397, 53.227630683353965, 52.87837600708008, 50.90817608152117, 51.174458844321116, 49.62050117765154, 43.938858440944124, 35.6688414982387, 36.44315569741385, 36.275686740875244, 36.823819705418174, 36.529469694410054, 36.26332242148263, 36.39721073423113, 38.21970238004412, 37.07379504612514, 39.604652064187185, 39.62714685712542, 48.013414110456196, 50.70354815891811, 50.78250401360648, 50.12877927507673, 48.66730560575213, 50.96213231767927, 48.896724700927734, 48.64601285117013, 47.81959063666207, 48.98560605730329, 48.38295405251639, 44.71334287098476, 39.14690474101475, 35.07063634055001, 35.13257605688912, 36.27837221963065, 37.89458227157593, 38.63735164914812, 40.31752334322248, 43.836369037628174, 45.98845543180193, 50.83449738366263, 51.53133569444929, 50.497944014413015, 26.305541140692576, 0.5418733975716999, 0.6545452230743, 2.734400153160095, 4.751875621931894, 8.175641298294067, 9.475974082946777, 0.06292738512690578, 0.05910016942237105, 5.393998171601977, 38.78613689967564, 32.47074549538748, 28.191303082874843, 38.88238682065691, 2.5991510791437964, 0.2504734939762524, 0.04389299864747694, 0.019500599409054433, 0.04306842253676482, 0.06454295665025711, 0.07779710008097546, 0.012209611712023616, 0.022202291758731008, 0.056363423953631094, 0.01677484790395413, 0.043124666304460595, 0.08224997257015534, 0.0669030575081706, 0.042561828291841915, 0.01711327233351767, 0.02463390172592231, 0.028063222799184065, 0.0448053093361003, 0.029402035155466626, 0.05623940132292254, 0.045208633943860016, 0.029562244058719704, 0.021602926509720937, 0.046102240814694335, 0.03167349898389407, 0.02518252612623785, 0.006924869284765529, 0.0511934044105666, 0.014918830711394548, 0.011424837617336639, 0.041052084482674084, 0.11971902235278062, 0.034026790742895434, 0.02206911569062088, 0.009969857521355152, 0.061783877201378345, 0.02401496413429933, 0.03424409497529268, 0.06006510050169059, 0.08901304645197732, 0.09834684524685144, 0.10120862097080265, 0.03019506617316178, 0.019870514648833444, 0.06154609817479338, 0.04990099536787186, 0.0407851963037891, 0.13355059229901858, 0.2694427546645914, 26.323300736291067, 39.07458094188145, 18.962921108518326, 54.43138524464199, 30.922259535108292, 23.18171443258013, 0.13128655164369515, 0.17722063112471784, 1.0929564152445113, 2.0943907243864874, 5.275742871420724, 6.810905660901751, 4.191779162202563, 0.6430095849292619, 6.91047899212156, 63.74153014591762, 56.290928159441265, 62.812993730817524, 58.60576220921108, 62.72040898459298, 58.73451232910156, 57.745992115565706, 53.55970246451241, 59.80408327920096, 56.188720158168245, 57.884963035583496, 55.61596972601754, 58.95051792689732, 55.69974763052804, 57.0598783493042, 56.85441664287022, 55.483832359313965, 50.593120438711985, 46.81031615393502, 40.175571646009175, 42.18742602212088, 41.26470177514212, 42.92937898635864, 49.873901980263845, 55.123022828783306, 52.449022497449604, 47.97800956453596, 42.227089813777376, 40.85240956715175, 39.50204454149519, 41.18516574587141, 38.25153207778931, 39.65241050720215, 39.33757373264858, 43.38311719894409, 50.168040071214946, 53.36642442430769, 54.86143357413155, 53.4004671233041, 56.61157362801688, 56.292474133627756, 53.70200157165527, 55.58057907649449, 52.76669066292899, 51.508347579411094, 51.96951689038958, 48.66653088160923, 51.02192851475307, 54.74143123626709, 53.584153175354004, 53.52176182610648, 55.092141560145784, 57.08261285509382, 51.59005839484078, 54.28278412137713, 53.716228008270264, 55.436032227107454, 56.18179280417306, 55.04706859588623, 53.2466652733939, 52.50138759613037, 47.063411235809326, 38.2011923789978, 37.65696430206299, 38.82855217797415, 38.19602639334542, 38.798157283238, 38.55558524812971, 37.64340141841343, 40.355425766536165, 38.26914228711809, 41.73200634547642, 41.60563945770264, 50.51500184195382, 51.26944071905953, 52.34765175410679, 49.54633263179234, 49.75652953556606, 53.505423137119834, 49.86379582541329, 50.173605578286306, 50.655529158455984, 51.117605209350586, 50.27067886080061, 46.797038146427695, 40.54029996054513, 36.35524361474173, 36.70341784613473, 38.29151201248169, 40.67957660130092, 40.18767193385533, 42.96614537920271, 44.89067479542324, 48.98602989741734, 50.80150386265346, 52.75829029083252, 50.48338753836495, 29.50042881284441, 1.2035392756972993, 1.2362366297415324, 4.7748624341828485, 6.94298483644213, 4.078622536999839, 2.539225689002446, 0.25124452688864296, 0.06445640272327832, 7.2859861339841565, 42.37055621828352, 40.531878743852886, 24.30883036340986, 47.21612916673933, 5.8109044177191596, 0.27267518692782944, 0.04622075713372656, 0.016382227186113596, 0.0020832339734105127, 0.06450011394917965, 0.04952760772513492, 0.008124517077314002, 0.03675672032737306, 0.028211638763813034, 0.04681045834773353, 0.021081569039129784, 0.06499026050525052, 0.05408775320808802, 0.07097145848508392, 0.03546498642702188, 0.06042842886277607, 0.05674088280647993, 0.004965875073269541, 0.007596519293396601, 0.0456582617812923, 0.04361431074461766, 0.12480988060789448, 0.1203738764992782, 0.0927515301321234, 0.13572434708476067, 0.28445797466806, 0.05907977944506066, 0.17363597133329936, 0.21469401674611227, 0.14284858480095863, 0.12246437503823213, 0.28030943870544434, 0.27292114230138914, 0.18824496599180357, 0.13645324297249317, 0.11708950916571276, 0.1624457346541541, 0.15883956530264445, 0.14859370009175368, 0.29590602751289097, 0.1487400465245758, 0.19782316631504468, 0.10131323749997787, 0.16039692530674593, 0.13420418437038148, 0.12449490465223789, 0.14766811047281536, 0.23883669983063424, 0.3529433012008667, 33.950423445020405, 51.426671504974365, 29.858267988477433, 61.98409448351179, 36.92453384399414, 24.709552083696636, 0.20657040551304817, 2.1902083371366774, 7.685418963432312, 6.32384866476059, 12.132563965661184, 9.666167991501943, 4.212022304534912, 0.3418239307190691, 7.40892321722848, 63.066415378025596, 58.36890506744385, 63.08148602076939, 62.38464423588344, 64.273407799857, 60.53656932285854, 60.202965463910786, 57.80380460194179, 59.180551937648225, 59.38234846932547, 58.90732792445591, 56.92774445669991, 59.965191159929546, 58.822830881391255, 58.50700051443917, 61.269229071480886, 58.117109298706055, 51.69669934681484, 49.219169752938406, 41.85396460124424, 44.25535583496094, 42.87727097102574, 43.96842302594866, 53.12929630279541, 57.767132009778706, 57.515009675707134, 51.80890233176095, 45.80907726287842, 42.63987534386771, 42.48536477770124, 43.42628983088902, 40.89793416431972, 43.30706916536604, 40.09683118547712, 43.689897537231445, 52.53888354982649, 54.80067505155291, 55.592728001730784, 56.02225521632603, 58.17685685838972, 59.379034178597585, 55.57916511808123, 57.03619194030762, 54.01443426949637, 51.02488497325352, 52.71004894801548, 49.780646732875276, 51.99077837807791, 57.49179574421474, 55.65332324164254, 56.396797861371724, 57.48064735957554, 59.35217939104353, 54.74919237409319, 57.38503319876534, 55.4641237940107, 56.87131813594273, 56.914233684539795, 55.874936035701204, 54.6346617426191, 54.06562164851597, 47.354544230869834, 38.99246365683419, 40.2664749281747, 41.48691211427961, 41.38687889916556, 40.167862619672505, 40.13931941986084, 39.342378411974224, 42.16718939372471, 39.76135131290981, 44.0171194757734, 44.096721512930735, 53.15486567361014, 55.21557978221348, 53.66046176637922, 50.973120893750874, 50.542207513536724, 55.815984044756206, 52.27202408654349, 52.78276184626988, 51.51782144818987, 52.82224498476301, 51.91336154937744, 47.902225562504356, 43.28237179347447, 39.371946471078054, 38.32804911477225, 41.559270654405864, 42.24047204426357, 42.37877593721662, 45.779908725193565, 48.34738622392927, 50.062976360321045, 56.38234213420323, 53.17712770189558, 52.60020835059029, 28.75317437308175, 1.4914831561701638, 1.6928361973592212, 10.14224466255733, 13.46066175188337, 15.915204967771258, 17.21949127742222, 0.47348037894283024, 0.1253444847783872, 10.198365262576512, 50.847348076956614, 42.102810859680176, 37.28254325049264, 53.95480830328805, 7.444042018481663, 0.721069447696209, 0.1697555516979524, 0.18104345670768193, 0.18322797305881977, 0.1768944864826543, 0.13849927032632486, 0.15287171410662787, 0.13147437013685703, 0.16629890432315214, 0.12275302383516516, 0.1750277280807495, 0.2316190685544695, 0.1310958018792527, 0.20936340492750916, 0.12637152895331383, 0.16271990351378918, 0.07201710809022188, 0.20071918091603688, 0.1380494423210621, 0.08851658273488283, 0.08965909321393285], [0.004680335238975073, 0.008500238032346326, 0.04932811503697719, 0.0336183533737702, 0.029460063470261436, 0.05389343434944749, 0.019375502996678864, 0.018851254966908267, 0.03847550720508609, 0.0499037875394736, 0.08005837231342282, 0.0388472086883017, 0.016229756974748204, 0.008363274042494595, 0.05916275070714099, 0.008807587254393314, 0.06433583383581468, 0.13881436841828482, 0.019779054913669825, 0.07672249060124159, 0.08052961488387414, 0.03731630815725241, 0.013064112913395678, 0.013605672915998315, 0.023351031189252223, 0.028887006720261912, 0.03265725940998111, 0.061248886265925, 2.4398397420133864, 48.2542838369097, 34.52215944017683, 48.06964588165283, 46.114676407405305, 20.318775211061748, 0.9772647832121167, 1.3450255521706171, 0.5569759043199676, 1.8454467569078719, 2.141106937612806, 4.57803647007261, 4.099283005510058, 1.6405631623097827, 0.12664250869836124, 24.00237659045628, 69.25791345323834, 57.083054065704346, 63.015505926949636, 59.122242655072895, 56.72068813868931, 52.33321687153408, 55.20845440455845, 54.261182171957834, 58.015116691589355, 56.159360545022146, 56.23822259902954, 53.310665130615234, 57.996387822287424, 54.214688301086426, 55.02644634246826, 53.89357730320522, 50.061569350106375, 41.83619805744716, 38.26246159417288, 41.389998640332905, 39.69000026157924, 46.21172884532383, 52.55249159676688, 55.37533276421683, 54.93267345428467, 53.01631511960711, 45.09137698582241, 37.74786063602993, 38.87042897088187, 37.279190744672505, 38.03806604657854, 36.28325680324009, 38.236430168151855, 38.48765965870449, 42.2907839502607, 45.33626971926008, 48.0752773966108, 48.52103212901524, 48.65417003631592, 53.04308305467878, 52.7848219871521, 54.21108913421631, 53.48548180716378, 56.29999555860247, 51.79285199301583, 51.29907478604998, 48.73899711881365, 50.20921857016427, 50.40517861502511, 52.546470982687815, 53.92535488946097, 52.862044266292024, 52.737886905670166, 51.14661741256714, 53.889620304107666, 52.53625018256051, 51.59747212273734, 51.03077357155936, 50.07225915363857, 46.681823117392405, 36.817826884133474, 36.99042361123221, 35.86261633464268, 37.07473305293492, 37.48709126881191, 37.629074232918875, 36.52786466053554, 39.445170061928884, 38.91314649581909, 38.16375548498971, 38.73675952638899, 41.78523302078247, 45.97512878690447, 49.959191117967876, 50.4803581237793, 51.791528361184255, 48.71207979747227, 48.22871446609497, 50.38479954855782, 47.46797704696655, 46.537338801792686, 48.38659838267735, 51.403784138815745, 48.783000060490195, 43.78910739081246, 38.20602832521711, 35.52300228391375, 37.02237490245274, 37.762385845184326, 39.1056671823774, 38.80820785249983, 43.74768223081316, 46.23272977556501, 48.81649037769863, 50.63900981630598, 44.1171874318804, 5.6265943305833, 0.5958718657493591, 0.8477559526051793, 6.065158545970917, 5.59120020696095, 7.123618457998548, 0.7111238070896694, 0.04562678114910211, 0.01715474439385746, 17.117952040263585, 43.033122539520264, 25.582636662891932, 35.56179060254778, 28.749573469161987, 0.06192273260759456, 0.02536247530952096, 0.0523228225564318, 0.018105875767235245, 0.0058824516267382675, 0.004472544067539275, 0.07141201770199196, 0.05765279994479247, 0.013640308736025222, 0.01943061700356858, 0.027809638995677233, 0.03240116672324283, 0.02862616428839309, 0.02394142620531576, 0.007500202943837004, 0.04297336995867746, 0.008955347584560513, 0.005788504636646914, 0.037371069325932434, 0.04014461174873369, 0.011621747631579638, 0.05001174585361566, 0.02505090390332043, 0.03380830246689064, 0.030184202827513218, 0.03450924610452993, 0.008908918825909495, 0.04853916201474411, 0.044931465959442515, 0.03914223571441003, 0.10070155175136668, 0.019508558624823178, 0.039559371902474334, 0.09183292263852698, 0.017619922557579618, 0.06942172521459204, 0.05291218450292945, 0.044272733985313346, 0.054314512825970135, 0.008236650078158294, 0.0194179809851838, 0.040603952814957926, 0.06981991670493569, 0.02945027220994234, 0.02622286619485489, 0.04799480051068323, 0.0581541151872703, 0.05848302825220993, 0.05207361360745771, 0.0373518091094281, 4.983304483549936, 57.61935077394758, 28.72925693648202, 59.733739716666086, 49.30474029268537, 22.47188299042838, 1.3785837228809084, 1.1338742481810706, 1.2978124341794421, 2.5078890962260108, 3.103000351360866, 3.9660208991595676, 7.764624084745135, 2.788956322840282, 0.3352090556706701, 27.01706099510193, 67.58443982260567, 56.81908852713448, 64.09808390481132, 59.98268672398159, 59.76128237588065, 54.88505744934082, 57.22569016047886, 55.49447699955532, 59.44133172716413, 58.270459515707834, 56.68331725256783, 54.80059862136841, 57.96626043319702, 56.466728006090435, 56.979567595890586, 54.60429116657802, 53.242756911686485, 43.012875488826204, 41.334763935634065, 42.904125758579795, 41.79001685551235, 47.002534593854634, 55.066916125161306, 55.07152625492641, 56.515539101191926, 54.2673556464059, 44.86987883704049, 39.95269080570766, 40.93506186349051, 38.465574809483115, 39.86339603151594, 37.55766064780099, 39.40738575799124, 41.23408453805106, 45.18377413068499, 47.213065011160715, 52.120525564466206, 50.02234329496111, 51.11417627334595, 54.88658257893154, 53.91420303072248, 54.84958689553397, 54.580674239567344, 56.60777643748692, 53.30952910014561, 51.78189468383789, 48.92784915651594, 50.748287609645296, 53.173771721976145, 54.296444279806956, 53.83011940547398, 53.9460084097726, 53.966324942452566, 53.111866746629985, 53.36832823072161, 53.143005098615376, 54.6055383682251, 51.788116795676096, 52.7586898122515, 49.04778896059309, 38.91379615238735, 39.114769322531565, 37.857037680489675, 39.3316364969526, 40.698496546064106, 39.506380217415945, 37.55292545046125, 40.27472243990217, 40.124797684805735, 39.62806054524013, 40.11854083197457, 42.82675756726946, 48.27865464346749, 51.69618170601981, 51.6357810156686, 54.173853737967356, 50.26052059446062, 49.283749784742085, 51.90782036100115, 48.96688066210066, 50.332014083862305, 50.299479143960134, 52.21795667920794, 50.438370159694124, 45.83243015834263, 39.83111470086234, 38.67338848114014, 39.31800413131714, 39.030327865055625, 42.34971162251064, 41.710324491773335, 46.106908321380615, 48.27937030792236, 50.23553139822823, 50.7022488457816, 45.84489175251552, 6.665693087237222, 1.1845356268542153, 2.5475303062370847, 9.241846714700971, 7.893000738961356, 3.7216935753822327, 0.2641207602407251, 0.04972337864871536, 0.17532225299094403, 18.013769388198853, 52.210195541381836, 28.02636500767299, 34.81084319523403, 36.811080183301655, 0.17460173022534164, 0.0362301228701004, 0.07660709893597023, 0.04943600549761738, 0.0463967996516398, 0.03403645647423608, 0.03167349559121898, 0.057444666113172255, 0.03172894886561802, 0.01880253106355667, 0.054432506673038006, 0.10682884510606527, 0.028733284611787115, 0.004503959390733923, 0.03703778988814779, 0.0130494302637609, 0.014282670204660721, 0.08562624747199671, 0.030457984922187667, 0.04304333709712539, 0.026684721233323216, 0.0620452556759119, 0.13708347986851419, 0.1041998001081603, 0.24026116196598324, 0.12848220712372235, 0.11324449548763887, 0.16255653942269938, 0.15224257643733705, 0.0943122895966683, 0.29325911668794497, 0.08357684101377215, 0.16052640335900442, 0.16509252334279673, 0.08109515346586704, 0.13814970265541757, 0.15492528676986694, 0.1166034202490534, 0.1531969630824668, 0.273449748222317, 0.06302735369120326, 0.11480181477963924, 0.2691774203308991, 0.11177698709070683, 0.10589780685092721, 0.10098772389548165, 0.10198521787034613, 0.12160414191229002, 0.09920055765126433, 0.10592270230076142, 7.353850058146885, 66.29731382642473, 44.445997033800396, 58.09162678037371, 54.42825855527605, 34.17077166693551, 1.8852647117206027, 2.303512611559459, 3.4053724919046675, 7.877110208783831, 7.228928395680018, 13.41651463508606, 10.508365222385951, 3.4671660789421628, 0.37270270234772135, 27.85193395614624, 71.19416795458112, 58.815834045410156, 65.93321432386125, 65.70453521183559, 61.906469208853586, 57.6533830506461, 59.738693782261436, 58.58479254586356, 61.86181313650948, 60.39522211892264, 60.640048844473704, 56.239073753356934, 59.86472715650286, 57.88909026554653, 58.92425373622349, 56.367264543260845, 54.16898305075509, 47.311868395124165, 43.02040038790022, 45.75823729378836, 44.07437610626221, 51.805626256125315, 58.7914319719587, 58.5587020601545, 59.59459509168352, 57.90819433757237, 47.452371392931255, 42.047225270952495, 43.56867579051426, 41.243155411311555, 42.279131821223665, 41.370925835200715, 42.62163632256644, 43.44595670700073, 47.67431075232369, 48.83237395967756, 52.46158136640276, 52.10424246106829, 53.14243534633091, 58.18565675190517, 56.18734441484724, 58.456111907958984, 56.40999943869454, 60.19093118395124, 54.93909706388201, 52.39219665527344, 48.462563037872314, 52.143874985831125, 54.75354194641113, 56.93115949630737, 57.23907239096505, 55.619318757738384, 56.021317209516255, 53.35078750337873, 55.073183400290354, 55.55140011651175, 55.66271373203823, 54.13748686654227, 54.92355394363403, 50.697110652923584, 39.796693325042725, 41.053209032331196, 38.76801252365112, 40.93509660448347, 42.02248968396868, 41.879898752485005, 39.833991255079, 43.8992919240679, 42.95776237760271, 42.5662522315979, 41.490695408412385, 45.59871012823922, 49.98451035363333, 54.048011439187185, 53.75220578057425, 56.13182135990688, 50.86478805541992, 51.423197405678884, 55.9441887310573, 51.14261872427804, 51.070388725825715, 52.539199692862375, 56.5486854825701, 51.886694363185335, 47.21260295595442, 42.63045358657837, 39.94282783780779, 40.75500277110508, 42.50266579219273, 43.857463768550325, 43.237142494746614, 48.67973940713065, 49.622502258845735, 52.2172132219587, 52.58881330490112, 46.12054763521467, 6.868815856320517, 1.6786724030971527, 4.057741463184357, 15.920796530587332, 14.332169089998517, 17.53439232281276, 2.2759501934051514, 0.15978971788925783, 0.21633394089128288, 27.19438249724252, 53.12557554244995, 34.90872246878487, 44.51844242640904, 42.759679658072336, 0.22091987409761973, 0.2182094252535275, 0.11050270511103527, 0.13929881528019905, 0.1260239833167621, 0.10938594503594296, 0.14383403477924211, 0.1766035578080586, 0.09735490168843951, 0.13536834690187657, 0.13724506619785512, 0.2231748088129929, 0.16912874818912574, 0.1070033914542624, 0.14195340712155613, 0.20350496071789945, 0.11798372332538877, 0.11712813137897424, 0.12215349743408815, 0.1627852057239839, 0.1349032518586942, 0.11546163580247334], [0.05221929846863661, 0.012092321845037597, 0.026451652936105217, 0.013872769744401532, 0.06084427583430495, 0.04222358537039586, 0.012455668865836092, 0.025123612323243703, 0.03565541049465537, 0.03215837332287005, 0.0367194992889251, 0.028579287696629763, 0.060986048941101344, 0.02804203045421413, 0.059314939326473644, 0.036508223840168545, 0.05888090083109481, 0.007419777884414154, 0.008995384543335863, 0.02158137284485357, 0.028926107300711528, 0.055714703763702085, 0.0065585392543913, 0.022079285234212875, 0.0069211212269562694, 0.04164429966892515, 0.07314866022872073, 0.02791755659771817, 0.13307377217071398, 16.30720148767744, 36.918919699532644, 22.107236317225865, 38.70595121383667, 35.34075450897217, 4.232118231909616, 0.10210395471325942, 0.16634436616940157, 0.6141354771597045, 2.041831076145172, 3.9837969967297147, 4.789581758635385, 2.646267682313919, 0.23886829242110252, 2.2490098561559404, 34.22613838740757, 66.20522240230015, 62.585210936410085, 60.20316001347133, 59.02836554391043, 56.29631648744856, 53.19368873323713, 56.31585829598563, 58.67352104187012, 58.145982537950786, 56.67978409358433, 58.648194858006065, 55.365709509168354, 56.03601612363543, 56.432626247406006, 50.679128714970176, 46.10390322549002, 41.94233526502337, 43.94599076679775, 40.971692766462056, 42.79478195735386, 46.84267738887242, 51.98304850714547, 55.446117537362234, 55.844443866184776, 53.38028955459595, 51.1080618585859, 43.63023683003017, 38.89718648365566, 38.44696405955723, 38.85440642493111, 38.25522157124111, 38.79437746320452, 39.098149231501985, 38.57271950585501, 42.13628033229283, 41.03684255055019, 46.899940967559814, 48.651852812085835, 50.14010831287929, 49.77665499278477, 50.74750593730381, 54.08637244360787, 52.11520324434553, 52.596129758017405, 53.19745813097273, 49.06839036941528, 48.4192271232605, 49.49114656448364, 51.25662824085781, 52.95553575243269, 52.870406423296245, 52.73573991230556, 52.01496158327375, 53.40897866657802, 51.53807544708252, 50.85825327464512, 50.44089582988194, 45.1568672316415, 38.98752696173531, 36.90864331381661, 36.94197729655674, 37.36406299046108, 36.45788587842669, 38.481312479291645, 37.78952898297991, 36.8145021711077, 37.95627532686506, 37.38240276064192, 39.48430231639317, 42.134254932403564, 45.9520503452846, 48.282288551330566, 47.96725375311715, 50.63041142054966, 51.03530727113996, 50.32967601503645, 50.3233323097229, 48.64492893218994, 49.479692459106445, 49.46891580309187, 49.33307504653931, 49.53636196681431, 50.63206509181431, 49.04929324558803, 42.651871408735005, 38.61206368037632, 37.61871099472046, 39.41761350631714, 38.14753144127982, 44.12453862598964, 43.270347935812815, 48.76719638279506, 47.9572240284511, 57.551842076437815, 22.421991450445994, 0.02023751218803227, 0.6472935836230005, 1.1827305065734046, 2.714976463999067, 4.545423797198704, 0.9182639377457755, 0.4762960278562137, 0.008561824415145176, 1.593109354376793, 37.54921163831438, 38.768887996673584, 22.032397270202637, 42.660626138959614, 9.223185590335301, 0.2678062639066151, 0.08573333386863981, 0.0210996350340013, 0.0177111261457737, 0.03963441448286176, 0.051936834518398554, 0.01666099651317511, 0.018849329623792852, 0.02267708137099232, 0.015952851922650422, 0.048926822641598325, 0.03989555886281388, 0.029010961497468606, 0.021421984968973056, 0.031223063689789603, 0.036962309652673345, 0.026927239827013442, 0.030339889294867004, 0.060415224571313174, 0.017672651513878788, 0.00970860627213759, 0.06392675185842173, 0.0565981224312314, 0.07036635452615363, 0.04068340248029147, 0.04277746672076838, 0.025798310226361667, 0.030980500991323164, 0.02018217256824885, 0.020534208410286477, 0.05914096294769219, 0.02228364471479186, 0.017361890957025543, 0.03563445054792932, 0.08589105254837445, 0.029965765441634824, 0.027784093848562667, 0.03359542228281498, 0.0206107064482889, 0.028403494540335875, 0.06198398396372795, 0.02528687972309334, 0.05265108762042863, 0.012752680606873972, 0.06106586501534496, 0.049231661284076314, 0.06561592407524586, 0.009899066811028336, 0.06248736873801265, 0.10408655261354786, 0.1344807959560837, 26.612076554979595, 43.22443076542446, 27.044310092926025, 52.29746144158499, 37.73151152474539, 5.322813008512769, 0.22340472361871175, 1.3331658457006728, 1.9226740300655365, 2.6563651519162312, 4.341426857880183, 6.287774920463562, 4.959270230361393, 1.4550203127520425, 3.3800352343491147, 41.395640577588765, 65.73769201551164, 64.27020468030656, 63.80701691763741, 62.24839006151472, 57.604502473558696, 54.67238351276943, 58.51996585300991, 59.89047718048096, 59.57461902073452, 59.273782866341726, 59.81158038548061, 58.08590841293335, 57.744157791137695, 59.167697770254954, 52.82739012581961, 47.73071622848511, 42.078506061008994, 44.99398756027222, 41.60595212663923, 44.30608115877424, 49.4100159236363, 54.87041064671108, 57.35546861376081, 57.84565707615444, 56.15016460418701, 52.92723573957171, 45.329960754939485, 40.82607242039272, 39.838351249694824, 40.81135613577706, 39.794025216783794, 39.79633549281529, 40.04700217928205, 40.80327190671648, 43.36068146569388, 44.90132638386318, 48.779689243861604, 53.231962885175435, 51.66423041479928, 52.02024916240147, 54.17064714431763, 56.074001925332205, 55.149724755968364, 54.04087216513497, 55.71473836898804, 48.73689876283918, 49.994863169533865, 49.19238792146955, 51.92850514820644, 54.13207769393921, 54.13520785740444, 54.31189359937395, 53.305023193359375, 55.63972561700003, 53.37634645189558, 52.27206924983433, 53.574651513780864, 48.96864897864205, 40.6296329498291, 39.10791145052229, 38.1575368472508, 38.39187526702881, 38.58132832390921, 39.90234068461827, 39.27047150475638, 39.27043328966413, 39.205425943647114, 40.00005667550223, 40.46203545161656, 43.03909451620919, 47.70932967322213, 50.01715646471296, 49.79914631162371, 51.19676603589739, 52.21118218558175, 52.579794543130056, 52.097252573285786, 50.907932894570486, 51.30210420063564, 50.62417541231428, 50.36495549338204, 52.33171258653913, 53.311154978615896, 49.164939062935964, 44.32837792805263, 40.030350821358816, 38.76614693232945, 40.69276428222656, 40.364302090236116, 45.07855061122349, 45.113437516348704, 49.90518624441964, 49.45843097141811, 57.32993050983974, 25.371435744421824, 0.2232959001724209, 2.771387585571834, 3.0039807047162737, 6.059857938970838, 4.38118531874248, 1.0581698247364588, 0.47944122765745434, 0.037261238255138905, 2.051204196044377, 42.16089085170201, 46.51830073765346, 21.548191206795828, 48.23744140352522, 13.083239947046552, 0.3360850986625467, 0.059833455431674204, 0.04366977419704199, 0.026291932578065565, 0.025603044811370115, 0.019366434376154627, 0.05887209344655275, 0.09035417091633592, 0.027758340051929866, 0.02814444344091628, 0.018485461827367544, 0.07125220913439989, 0.045653837732970715, 0.03718885892469968, 0.061621435917913914, 0.05085951429126518, 0.056237131623285155, 0.009463197967436696, 0.03327530642439212, 0.023765431184853827, 0.03529313386284879, 0.06622703306909118, 0.10683544725179672, 0.1033483472253595, 0.07729046512395144, 0.11033517481493098, 0.11076352718685355, 0.15124495354081902, 0.053532803165061135, 0.08946929339851652, 0.11864463000425271, 0.12229825609496661, 0.11148683194603239, 0.21032399338270935, 0.30197120777198244, 0.09920203685760498, 0.12160798242049557, 0.16297698686165468, 0.13146485707589559, 0.06858754104801587, 0.12544013107461588, 0.10270913331104176, 0.08041836906756673, 0.16315179105315888, 0.11704389804175921, 0.1912942480828081, 0.1598543551351343, 0.13360838991190704, 0.14260264299809933, 0.244204047535147, 0.2628997229039669, 31.187882219042095, 53.032820565359934, 33.9274457522801, 49.502958502088276, 47.32945081165859, 8.714660831860133, 0.5562131766762052, 3.019700352634702, 4.2152115276881625, 9.232103603226797, 10.691688231059484, 11.389964818954468, 6.921341632093702, 1.1914056582110268, 3.7333318080220903, 39.246295247759136, 69.12517506735665, 66.98349012647355, 64.28436510903495, 64.75503608158657, 60.389524596078054, 55.55951908656529, 59.51141125815255, 63.56678295135498, 60.73322418757847, 59.31434644971575, 61.34363733019148, 60.330603872026714, 59.04571519579206, 61.7976256779262, 54.97305291039603, 50.79205778666905, 44.023796694619314, 49.38590914862496, 45.30401965550014, 47.33993216923305, 51.51043551308768, 56.54587146214077, 59.12760666438511, 60.03973838261196, 58.85764830453055, 55.44358491897583, 49.705390793936594, 44.09408119746617, 43.81103590556553, 42.318715708596365, 42.34700877325875, 43.065716539110454, 42.40994208199637, 42.58495330810547, 46.62148148672921, 45.56415673664638, 51.27403000422886, 54.78674391337803, 53.823751381465364, 54.36137866973877, 56.91973318372454, 59.33623327527727, 56.87761320386614, 56.49793931416103, 56.86234106336321, 51.24698066711426, 50.9259808404105, 50.12676429748535, 51.578597341264995, 54.4512015070234, 54.12228420802525, 55.93552432741438, 53.45874513898577, 58.7912026814052, 54.61202103751046, 55.00851304190499, 56.00320325578962, 50.725692067827495, 41.7271078654698, 41.854610783713206, 39.37819290161133, 40.173230103084016, 39.78842496871948, 42.37016364506313, 41.05411229814802, 40.662650789533345, 40.28936924253191, 40.440450872693745, 43.29491329193115, 45.2899808202471, 51.512339319501606, 54.08749805177961, 51.93396643229893, 53.102083683013916, 53.86191783632551, 53.889866965157644, 55.15525552204677, 52.92498104912894, 52.85250786372593, 52.90662738255092, 51.68239300591605, 53.11214467457363, 54.29157011849539, 52.20635666166033, 47.56870855603899, 43.8537186895098, 42.5742461340768, 43.99547583716256, 41.242915698460166, 47.782379559108186, 47.99247223990304, 52.72645364488874, 51.24299587522234, 59.98227678026472, 25.231505972998484, 0.5232684559055737, 3.129641047545842, 4.887279510498047, 7.647024955068316, 15.850777796336583, 4.436663210391998, 1.6409805970532554, 0.22514294034668378, 3.2597536657537733, 51.11690691539219, 48.14819526672363, 32.56644650868007, 56.04123422077724, 15.76720312663487, 0.6317644140550068, 0.2889708567942892, 0.16637973141457352, 0.17737957116748604, 0.08345011781368937, 0.12309580615588597, 0.15222008978681906, 0.16229062154889107, 0.08105553380612816, 0.10724850544439894, 0.1933145182473319, 0.14096646436623164, 0.15606825186737946, 0.11307187617889472, 0.1988083855914218, 0.16136376985481807, 0.11184024691049542, 0.1754495868725436, 0.1485353053680488, 0.1589204195354666, 0.04918782113652144, 0.1774877839322601], [0.0285439258441329, 0.1072555079257914, 0.04832727588447077, 0.00865955975106252, 0.06261095032095909, 0.1035203422818865, 0.07073600683361292, 0.02987670772043722, 0.021472440832959752, 0.021366884532783712, 0.021139230945014527, 0.03904256231284567, 0.048443176451006105, 0.01855144087624337, 0.058890712447464466, 0.034284698510808606, 0.017046363691666296, 0.024457457176010524, 0.03433459119072982, 0.021322598248454075, 0.014011528459377587, 0.04695106776697295, 0.01702044704662902, 0.06326802327696766, 0.01601625423479293, 0.05573689525148698, 0.00985502649564296, 0.08484169135668448, 0.016170648092936193, 0.7802244563187871, 34.530670983450754, 33.9352068901062, 27.645037446703228, 52.4185859135219, 18.835220166615077, 0.07994901282446724, 0.5297549792698452, 0.6859603087816919, 2.3478366902896335, 1.947299748659134, 5.7692955647196085, 4.146126023360661, 1.0149526808943068, 0.342211618487324, 5.879574767180851, 47.63659940447126, 63.151954650878906, 63.54668876102993, 56.957520961761475, 58.061867645808626, 57.204967158181326, 55.58631134033203, 56.4076509475708, 57.92327887671334, 59.728327069963726, 56.01461567197527, 55.060259750911165, 54.413316454206196, 51.36710459845406, 49.280789852142334, 47.19512128829956, 42.01564570835659, 39.54724604742867, 41.41925403050014, 42.42131628308977, 48.42095027651106, 53.056864806583945, 54.04802533558437, 54.8464879989624, 53.68728528703962, 52.48186315808977, 47.40810094560896, 39.61144045421055, 38.45491974694388, 39.01148782457624, 38.64310128348214, 38.913466112954275, 37.37107719693865, 37.757942472185405, 39.997308662959504, 40.242413316454204, 42.251780237470356, 43.1307030405317, 46.46201685496739, 49.133126735687256, 49.83706610543387, 47.27555363518851, 52.36456019537789, 52.13454008102417, 53.267454283578054, 45.49716567993164, 50.12702832903181, 57.55490970611572, 53.43409293038504, 51.780543259211946, 50.224077292851035, 53.0093287059239, 50.51450851985386, 52.71792125701904, 50.52948883601597, 49.29240724018642, 44.64966263089861, 39.49518666948591, 37.46172339575631, 36.62444462094988, 36.83311986923218, 37.79115833554949, 38.58808197293963, 37.30395759854998, 36.06410714558193, 37.21578843252999, 37.22521366391863, 39.77274635859898, 45.318694250924246, 47.27800982339041, 47.81787443161011, 47.72903823852539, 48.11177280970982, 48.27515969957624, 51.65678889410836, 49.470069204057964, 46.850855418613975, 50.679549080984934, 49.62342636925833, 49.788904666900635, 49.96853297097342, 52.25961460386004, 49.11554779325213, 48.73381723676409, 43.54978711264474, 40.906004496983115, 37.56981652123587, 40.45578554698399, 39.32104744229998, 43.345569133758545, 47.096835545131135, 50.739060401916504, 50.64317178726196, 44.83235856464931, 4.336673855781555, 0.4185682497918606, 1.2058366324220384, 2.4610204568931033, 10.229917900902883, 4.784628561564854, 0.7483768995319093, 0.14789470045694283, 0.10984496719070844, 7.594086630003793, 45.74459797995431, 22.262382643563406, 30.397378717150005, 32.4395307132176, 0.3560174176735537, 0.12409208555306707, 0.020365190426153795, 0.11273393181285687, 0.08946479471134287, 0.0404737385522042, 0.08147585232342992, 0.041542380316449065, 0.06813480212752308, 0.03616465102615101, 0.02463048869477851, 0.02154811953992716, 0.039206849211560826, 0.027254020595656972, 0.02556255493046982, 0.0059267705655656755, 0.0246301171968558, 0.04236204383362617, 0.0395897125958332, 0.04867313536150115, 0.03706716027642999, 0.058018469251692295, 0.029571655339428356, 0.033035959981914075, 0.12843321689537593, 0.044986461222703965, 0.06283203060073511, 0.04751935441579137, 0.050931961475206275, 0.048750284793121476, 0.02723284182138741, 0.034661899520350356, 0.04099399849240269, 0.009954525174440017, 0.08007577673665114, 0.0727045319176146, 0.07345442846417427, 0.017143105821950094, 0.03904238589374082, 0.0357850717513689, 0.02150291214430971, 0.03166216066373246, 0.03675175345103655, 0.05655636877885886, 0.01715009642897972, 0.026509021375594393, 0.02321975671553186, 0.016405809670686722, 0.03380161550428186, 0.015161856510011213, 0.10791823307850532, 0.024264167994260788, 2.0230694200311388, 44.08618456976754, 31.601154123033794, 31.767299447740825, 55.586443356105256, 21.333295583724976, 0.1337501901601042, 0.2753662025289876, 2.0298721407141005, 0.9325799409832273, 3.424668073654175, 4.233124417918069, 7.587781139782496, 3.402215838432312, 0.5194538405963353, 7.727981890950884, 52.75088698523385, 63.46185820443289, 65.63524082728794, 59.46189144679478, 61.06562600816999, 58.032369068690706, 56.433842182159424, 58.916478702000205, 59.257850646972656, 59.1880281993321, 59.81589521680559, 57.83817734037127, 57.17205354145595, 52.61914913994925, 52.14824192864554, 48.52407891409737, 43.30536685671125, 41.764089652470176, 44.3583767754691, 44.98940174920218, 50.26702410834176, 54.27355343954903, 55.34434379850115, 55.93973840985979, 55.65847880499703, 54.25716611317226, 48.83420828410557, 40.91695485796247, 40.46493285042899, 39.46640375682286, 40.870589528764995, 40.79028919764927, 39.62490953717913, 41.45259496143886, 42.96747943333217, 42.94359152657645, 45.501251220703125, 45.93374531609671, 50.27839136123657, 51.67742504392351, 50.18439960479736, 51.03255231039864, 53.58745356968471, 54.23125975472586, 53.471192836761475, 47.64193909508841, 47.505441733769004, 54.225878374917166, 54.60997131892613, 52.1104610988072, 51.57507460457938, 53.924753870282856, 51.67127936226981, 53.72307545798165, 52.087973254067556, 50.284043720790315, 45.47397606713431, 42.7760009765625, 39.01181786400931, 38.78303452900478, 38.39448431559971, 39.272715772901265, 39.44424247741699, 41.44093588420323, 38.60783570153372, 40.059119837624685, 39.156830242701936, 40.94759293964931, 45.040085383823936, 47.389313016619, 49.47459942953927, 50.865760803222656, 50.3557630266462, 50.7943228994097, 52.079843861716135, 52.42036465236119, 48.02285671234131, 52.93018524987357, 50.62812546321324, 52.54885074070522, 51.46820436205183, 53.97298131670271, 51.64979900632586, 51.513958249773296, 45.78082588740757, 43.23142065320696, 39.06397104263306, 42.494164671216694, 39.55633429118565, 46.403651986803325, 48.56737661361694, 52.7401693889073, 51.76684488568987, 46.75806222643171, 4.537786424160004, 0.8838670977524349, 3.3229581713676453, 3.6287460029125214, 8.81894200188773, 3.6086796053818295, 0.4423333417092051, 0.5253302795546395, 0.03466054245031305, 8.727525421551295, 56.35002953665597, 29.499803474971227, 29.608695643288748, 39.78939424242292, 0.8866476256932531, 0.14812316319772176, 0.04572001864601459, 0.0903998159670404, 0.05859763960220984, 0.06587239674159459, 0.02167650345446808, 0.04599849959569318, 0.06168719274657113, 0.01061217742972076, 0.02613697892853192, 0.07921052923692123, 0.033826734870672226, 0.03410972807822483, 0.01295811980630138, 0.03424648341855832, 0.0361115929803678, 0.03334863570385745, 0.046372453815170696, 0.04299785828750048, 0.042574605106243064, 0.021071026301277534, 0.08478456549346447, 0.07228881386773926, 0.23185780431543077, 0.15505564691764967, 0.10302404819854669, 0.10250726235764367, 0.16965652629733086, 0.1090599089594824, 0.0838674914890102, 0.07289902041000978, 0.12033395149878093, 0.07140500164989914, 0.2214009418551411, 0.13916857726871967, 0.1913964490273169, 0.09622447591807161, 0.12359162526471273, 0.1263047203953777, 0.07321291749498673, 0.1706442425825766, 0.15781055337616376, 0.18994651468736784, 0.13394966588488647, 0.08553731867245265, 0.1464320368000439, 0.1142313296773604, 0.1268099575702633, 0.10785877305482115, 0.10274412536195346, 0.1480610365314143, 2.851990814719881, 58.63377734592983, 45.238386971609934, 38.89895132609776, 63.55904960632324, 31.333808285849436, 0.3191819228231907, 1.3481304198503494, 2.413609206676483, 4.899091882365091, 7.818030544689723, 16.86635082108634, 11.735199093818665, 5.4954822574343, 1.2002183624676295, 7.913470132010324, 52.409344809395925, 63.7181008202689, 66.2995719909668, 63.46808379037039, 61.809757232666016, 60.42202826908657, 59.568476813180105, 60.489210401262554, 61.521768297467915, 62.341746057782856, 59.90357453482491, 58.50460338592529, 58.90312426430838, 54.03733900615147, 52.38201059613909, 52.02603701182774, 48.00604207175118, 44.284885678972515, 45.6321587562561, 47.11053391865322, 53.540327412741526, 58.398427963256836, 58.81520870753697, 58.9666724886213, 56.68712486539568, 54.99672889709473, 51.93533870152065, 44.137986864362446, 42.2930977003915, 43.25876876286098, 43.15003987721035, 43.9472588130406, 42.5001540184021, 43.16369308744158, 45.45254782267979, 45.69543252672468, 47.743893487112864, 48.37354619162423, 52.99700607572283, 53.54642098290579, 53.013501099177766, 50.8361371585301, 57.582282134464805, 56.06215524673462, 57.06889016287667, 46.03316361563546, 46.06439576830183, 54.853932993752615, 53.39693743841988, 52.95197132655552, 53.682768957955496, 55.70879418509347, 53.413755553109304, 56.171672752925325, 54.72810459136963, 52.72362920216152, 46.708354813711985, 44.59407704217093, 40.34470469611031, 40.74327768598284, 41.52052749906267, 41.297344412122456, 42.6295850617545, 42.89442607334682, 41.82362529209682, 43.092696394239155, 41.82580007825579, 43.766369410923545, 48.92712654386248, 49.853835582733154, 51.481141907828196, 52.11651297977993, 51.82174260275704, 53.32004519871303, 54.54502650669643, 51.489816733769004, 49.43781566619873, 55.026508876255576, 52.22923013142177, 54.734892981392996, 53.99165807451521, 56.712777614593506, 52.445180143628804, 53.306669916425435, 47.329273632594514, 45.0052227973938, 41.384287221091135, 44.222768783569336, 43.15380580084664, 48.498141288757324, 50.994875703539165, 55.943469592503135, 52.78684043884277, 47.752828870500835, 5.410026797226497, 0.9315563844782966, 5.758577968393054, 4.888876727649143, 27.216681003570557, 14.778639486857823, 2.5125013973031725, 0.6954536650862012, 0.15840706708175795, 13.730555840900966, 60.002183369227815, 30.947092396872385, 41.67979758126395, 45.90921122687203, 1.493433102965355, 0.32150378823280334, 0.11252266993480069, 0.318503197814737, 0.21351692133716174, 0.14451797093663896, 0.19425964967480727, 0.11641679597752434, 0.12688367361468927, 0.1008480338911925, 0.1181673484721354, 0.15391173187111104, 0.15905633009970188, 0.12286724842020444, 0.06589857462261405, 0.13242015295795032, 0.0866838867909142, 0.21199454659862177, 0.08527108188718557, 0.14883027811135563, 0.10328615949090038, 0.10390989602144275, 0.22604873031377792], [0.06278579522456441, 0.04760098896388497, 0.059806687225188525, 0.03985225136524864, 0.06251442871455636, 0.0076889773232064074, 0.04164907316278134, 0.023279673054016063, 0.07013878066624914, 0.007517109491995403, 0.0030898487311787903, 0.015141525904514959, 0.07963369760130133, 0.008548280856172954, 0.039591958546744924, 0.030880003169711148, 0.01171054326862629, 0.045220437060509405, 0.03556574209194098, 0.019261636338861923, 0.052870030514895916, 0.02069261241038995, 0.03231713355385831, 0.029538586935294524, 0.0693522703700832, 0.062302277955625734, 0.07583238836377859, 0.07744037386562143, 0.0521959636493453, 0.08069106550621134, 14.606245994567871, 46.43098620006016, 26.208075284957886, 40.085873876299175, 44.50662701470511, 5.031589252608163, 0.1768476404249668, 0.7105046031730515, 1.238016454236848, 2.713686487504414, 1.665503829717636, 4.083297806126731, 2.777285520519529, 0.30150206866008894, 0.030556474280144488, 17.69282862118312, 61.94979122706822, 60.87811497279576, 62.382670947483604, 60.21398530687605, 56.253428731645855, 54.897734437670024, 55.8056138583592, 55.31184359959194, 59.30152702331543, 57.95829084941319, 51.40610136304583, 51.94379813330514, 52.728829928806846, 49.4359188079834, 44.38365432194301, 42.25170728138515, 43.54118524278913, 44.28926304408482, 45.77754633767264, 51.268124035426546, 53.305075304848806, 55.14975254876273, 56.03373711449759, 55.24127769470215, 54.80863421303885, 50.44426570619856, 43.54227263586861, 38.184325626918245, 38.30463368552071, 36.89993027278355, 40.00913797106062, 39.21981913702828, 39.92794132232666, 41.214532307216096, 38.03382764543806, 40.08757618495396, 39.070022923605784, 42.417741434914724, 44.30318375996181, 43.96804434912545, 44.87413808277675, 52.904132979256765, 50.77898475102016, 54.33009787968227, 35.06675229753767, 34.2138991355896, 50.12420736040388, 49.11254269736153, 52.78226505007063, 52.83767345973423, 53.013956206185476, 49.916202613285606, 50.3700658934457, 45.51201050622122, 44.957856927599224, 38.95886564254761, 37.794986792973106, 36.933021068573, 37.538872718811035, 37.64435679571969, 36.055484431130544, 37.1277790750776, 37.363274369921, 38.16036476407732, 37.24938644681658, 39.950248513902935, 48.02744599751064, 49.7808586529323, 51.17699146270752, 50.07048041479928, 49.42858498437064, 47.057786669049946, 49.05147497994559, 48.753741196223665, 51.687725748334614, 50.73075383050101, 49.631653036390034, 50.52550057002476, 51.13355827331543, 51.43651362827846, 50.6565123285566, 51.13129663467407, 50.117213998522075, 46.10284015110561, 42.09014081954956, 40.678951263427734, 40.7438509123666, 47.51489128385271, 45.03508268083845, 48.085658005305696, 48.85088048662458, 55.774548462459016, 21.981833492006572, 0.15863362992448465, 1.1435761047261102, 3.3732008125100816, 1.483520194888115, 2.999310212475913, 0.9040972122124263, 0.09226143785885402, 0.402508981525898, 0.10393002137009587, 25.501924651009695, 44.66291631971087, 20.30318692752293, 42.27666173662458, 18.619794743401663, 0.1660638190805912, 0.026467115052842667, 0.013828726036341062, 0.018376802925818732, 0.0507957455702126, 0.010505675421362477, 0.03212182403409055, 0.0178655505379928, 0.04304824969066041, 0.07964780434433903, 0.01937304500357381, 0.02435638938498284, 0.012998589331151118, 0.04451309144496918, 0.09565395010369164, 0.02138498275806861, 0.03807371947914362, 0.05443514956693564, 0.03975213013057198, 0.018505682170923268, 0.01603584354078131, 0.06544604604797703, 0.0569920628996832, 0.10084302630275488, 0.10794793934162174, 0.03456662641838193, 0.04471014479973486, 0.03685376440574016, 0.01342506894642221, 0.12331846063690526, 0.06695139634289912, 0.09351507880325828, 0.05439902775521789, 0.030374141742608378, 0.06469302824033157, 0.007126724547041314, 0.055195397165204794, 0.017102631208087717, 0.06472792529634067, 0.0577944577006357, 0.026381044582064663, 0.028772235914532627, 0.016430230146007876, 0.047907595190086534, 0.03717678100136774, 0.05006089214501636, 0.02136519837326237, 0.058743728191724846, 0.04068999444799764, 0.0472692294445421, 0.10106447977679116, 0.054943575856408904, 0.2424515001475811, 23.206165143421718, 52.15331411361694, 24.853761945452007, 56.757308619362966, 47.816946847098215, 5.865502493722098, 0.4719315820506641, 0.5117831922003201, 0.6917757881539208, 2.0719938576221466, 4.296666996819632, 7.2336766208921155, 5.143412692206247, 2.381726094654628, 0.1097201235326273, 21.16795972415379, 64.45006574903215, 62.322423117501394, 66.45826884678432, 61.11869634900774, 58.40339592524937, 56.920011111668174, 57.956512110573904, 54.41397305897304, 60.40283039637974, 57.326699597494944, 53.682570934295654, 54.49290459496634, 54.33880397251674, 49.30037334987095, 47.20382738113403, 44.27312237875802, 46.19998638970511, 45.40769025257656, 49.34702008111136, 52.36234719412667, 55.23029606682913, 57.80034439904349, 58.99877316611153, 56.66258730207171, 56.42600808824812, 53.00768198285784, 45.92209666115897, 38.90928677150181, 40.60026638848441, 39.08168894904, 41.650253840855186, 41.339651993342805, 42.53377635138375, 41.628721373421804, 40.761290890829905, 41.428199836185996, 42.84918982642037, 44.562507901872905, 47.85916062763759, 48.15253789084298, 46.89105422156197, 54.496406487056184, 52.05731085368565, 57.77331938062395, 35.84510687419346, 35.544652870723176, 51.548153809138704, 51.54683712550572, 54.596547399248394, 55.53013168062483, 54.73116874694824, 50.76107924325125, 50.691020556858604, 48.85438585281372, 49.05012355531965, 42.85143756866455, 41.95417152132307, 39.523566586630686, 38.283618858882356, 38.177568503788535, 37.80981077466692, 39.62918962751116, 38.16828918457031, 39.190581117357524, 38.74608400889805, 41.428835596357075, 48.85259321757725, 52.143128054482595, 54.241244316101074, 51.27552039282662, 50.85610628128052, 49.87768874849592, 51.098584515707834, 50.85475138255528, 53.27812671661377, 52.63252789633614, 51.53789826801845, 51.732322760990684, 52.035740171160015, 53.409656115940635, 52.64078235626221, 52.112667151859824, 51.89482375553676, 48.177659102848594, 43.37503644398281, 42.1488287789481, 42.934378215244834, 48.42782204491751, 47.59949949809483, 49.05097818374634, 52.54116950716291, 54.91184970310756, 24.615315403257096, 0.3232376351952553, 0.6572195738554001, 5.652886314051492, 4.988045326301029, 2.3698616112981523, 0.6601639272911208, 0.1974555224712406, 0.08402644510247878, 0.15747876332274505, 26.235538039888652, 56.18246677943638, 19.575495140893118, 44.099010944366455, 25.076201575142996, 0.227116907281535, 0.017642265019406165, 0.04270459884511573, 0.05436206456007702, 0.01962357370315918, 0.03810067428275943, 0.007732482444095824, 0.07620368951133319, 0.03503024225522365, 0.018714533553325703, 0.022216851423893656, 0.03217733159129109, 0.01464862619260592, 0.11568382887967996, 0.06615213637373277, 0.0606461978916611, 0.04999728627236826, 0.021255212935752103, 0.0653986232355237, 0.08020654400544507, 0.04404437302478722, 0.05757673616920199, 0.0451367024465331, 0.11489675539944853, 0.17892703813101563, 0.1324647327086755, 0.16593998643968785, 0.15675140092415468, 0.14720910867410048, 0.15845847289477075, 0.09117607359907456, 0.2865412671651159, 0.057669763320258687, 0.12374460777001721, 0.14239035653216497, 0.16331043254051889, 0.10232154053768941, 0.155116932200534, 0.09902929541255746, 0.12517339895878518, 0.12284009344875813, 0.18431201417531284, 0.10374193146292653, 0.1309530245406287, 0.20186848353062356, 0.14745517261326313, 0.12314034519451005, 0.15001729370227881, 0.10804190965635435, 0.1249429141836507, 0.15900504642299243, 0.16593778798622744, 0.3324270620942116, 26.880822454180034, 63.24487291063581, 36.57165220805577, 50.41810573850359, 58.670859881809776, 9.19715676988874, 0.9617508671113423, 3.1672746624265398, 3.1001444246087755, 9.030114259038653, 10.734089612960815, 11.181132367679051, 6.703497801508222, 1.5041308317865645, 0.14761017715292318, 22.024427686418804, 63.92403847830636, 64.41394206455776, 68.01370647975376, 64.42131410326276, 60.92213181086949, 59.92034748622349, 61.09564222608294, 56.668767724718364, 60.979537827628, 60.725775718688965, 54.49095562526158, 56.39905602591378, 57.73547601699829, 53.42685638155256, 49.52624886376517, 47.12256472451346, 48.77793482371739, 48.267468043736045, 51.26976728439331, 55.57020889009748, 57.99223974772862, 58.931966236659456, 60.193231037684846, 60.6667924608503, 60.30921731676374, 56.534028257642476, 48.171006202697754, 42.364268098558696, 40.10249049322945, 41.154875074114116, 43.94008132389614, 43.524995940072195, 45.02169697625296, 45.749288014003206, 42.84906823294503, 42.664527552468435, 44.15761205128261, 46.35397931507656, 50.21644817079817, 50.45551831381661, 49.42400959559849, 58.14855337142944, 55.24970585959298, 59.401490756443565, 38.50676720482962, 36.82790872028896, 56.00809826169695, 54.173019954136436, 57.206533976963584, 57.41356945037842, 57.284510135650635, 53.98241697038923, 55.212564264025005, 51.24368722098214, 51.192996638161794, 43.7400461605617, 42.713157994406565, 42.05757461275373, 41.798212255750386, 42.01335975102016, 39.04461683545794, 42.219696930476594, 41.00258445739746, 41.047230107443674, 40.81504910332816, 42.20662389482771, 51.41239990506853, 54.822134562901084, 56.17573397500174, 52.74620737348284, 53.62234394890921, 51.47391925539289, 53.95918914249965, 52.07729387283325, 56.81677825110299, 53.94793653488159, 53.23911952972412, 52.54104791368757, 55.884010383060996, 55.031601905822754, 55.27578592300415, 54.98767539433071, 54.384279932294575, 48.85569211414882, 46.94502782821655, 44.730470180511475, 43.98801694597517, 50.01395681926182, 49.94146626336234, 50.68306139537266, 54.807883807591026, 55.840594564165386, 25.422178438731603, 0.2570278165595872, 3.1525505610874722, 5.311677651745932, 7.254638467516218, 10.00119970526014, 5.3108751348086765, 0.6991284478987966, 1.640221180660384, 0.3926875942519733, 34.56254584448678, 56.21060698372977, 29.07727309635707, 54.20339053017752, 28.801047461373464, 0.39203687916908947, 0.07953289443893091, 0.11572690228266375, 0.23273954700146401, 0.13870885622288498, 0.1217657553830317, 0.06413549637155873, 0.12444242675389562, 0.0902766143637044, 0.1560685775641884, 0.0720513401819127, 0.11317675055137702, 0.07502197327890567, 0.2200649335448231, 0.18576658969478949, 0.10930480581841298, 0.10503884258547, 0.20533738524786063, 0.16482361991490635, 0.15202323320720876, 0.06693540327250957, 0.1159921009093523, 0.08651149818407637], [0.036725582355367284, 0.019721011331837093, 0.032030822310064516, 0.019391295899237906, 0.06346296638782535, 0.03146347543224692, 0.10432199747966868, 0.030476637849850313, 0.01507493108510971, 0.0486914354509541, 0.03215555400986757, 0.014687531694237674, 0.041474916972219944, 0.07484279932188136, 0.029878451555435146, 0.04516737901472619, 0.024997555783816745, 0.028085383752893125, 0.07750442757138185, 0.010117878239335758, 0.06713290446038757, 0.03284116954143558, 0.025403348562706794, 0.043165917840919325, 0.006673446191208703, 0.08703216524528605, 0.055098902700202804, 0.022027429891750216, 0.04713015690711992, 0.11491673147039753, 1.2360080991472517, 41.00621836526053, 35.762649127415244, 21.116214752197266, 52.73765761511666, 22.288761479513987, 0.02482667182838278, 0.3878313462649073, 0.12380161828228406, 1.3007717153855731, 1.9554942803723472, 5.33032922233854, 2.785617930548532, 1.2300877996853419, 0.20964418271822588, 0.39201997007642475, 27.465167692729406, 69.59942436218262, 62.69606944492885, 61.814891951424734, 60.897271156311035, 55.575739656175884, 55.66008036477225, 59.23900713239397, 54.95261131014143, 55.99272537231445, 53.26558174405779, 52.26987361907959, 49.272170611790244, 48.085168157305034, 43.97822346006121, 44.531817708696636, 44.24586459568569, 45.58989633832659, 49.94560391562325, 54.19416332244873, 53.11006021499634, 54.540423325129915, 56.03415400641305, 54.6632570539202, 54.002254077366416, 52.10064329419817, 45.51946939740862, 38.99095937183925, 39.790742192949565, 38.48328924179077, 39.34136744907924, 41.28203058242798, 41.231708254132954, 40.28962285178048, 41.22496850149972, 40.83729723521641, 38.746851784842356, 40.280770846775596, 42.0421530859811, 42.989526067461284, 49.62124810900007, 51.94068534033639, 55.329961027417866, 51.121770654405864, 50.08141687938145, 57.13770512172154, 51.38623298917498, 55.2274820463998, 52.607472692217144, 52.957255431583945, 50.61132819311959, 48.752216066632954, 48.87227399008614, 43.98377159663609, 39.61972270693098, 40.94218724114554, 38.15397936957223, 38.1244113104684, 36.687562056950156, 39.40263319015503, 37.38640144893101, 39.73432282039097, 36.98385756356375, 40.295101506369456, 37.99098852702549, 45.31746441977364, 50.71699639729091, 53.623393126896445, 51.54210192816598, 49.815898418426514, 49.48992715563093, 51.60445506232125, 47.25815882001604, 51.847103527614046, 51.74140058244978, 49.79836811338152, 50.80427966799055, 52.32018205097744, 46.94496182032994, 49.48928444726126, 50.37564877101353, 49.07472365243094, 47.49444620949881, 47.219797815595356, 45.0690142086574, 40.519142695835654, 40.61744580950056, 50.874668393816265, 46.212837082999094, 52.05475044250488, 54.32374722617013, 44.90450865881783, 1.7821838429995944, 0.49948710628918236, 0.2193984357374055, 4.233606883457728, 6.823893581117902, 2.586838436978204, 0.48236625641584396, 0.15112706486667904, 0.08514112207506384, 2.4414269711290086, 40.56744657244001, 25.599981103624614, 28.76067669051034, 45.36379500797817, 2.3678815918309346, 0.18214269700859273, 0.09270205814391375, 0.039800553782177825, 0.04738856000559671, 0.033348639096532545, 0.018573834228196313, 0.015627896413207054, 0.06631558867437498, 0.0010444211386909175, 0.029400155613464967, 0.022500480758026242, 0.07240117926682745, 0.014679345169237681, 0.05117217304983309, 0.05947705491312912, 0.029491673024105172, 0.08052015610571418, 0.10161348924572979, 0.04028948576056531, 0.06837348360568285, 0.06911951250263623, 0.05440874776936003, 0.044404135684349706, 0.006821407113290791, 0.04845867419083204, 0.02612463298386761, 0.013700440509377845, 0.0285203806789858, 0.053116627104048214, 0.04222010787842529, 0.01967380056157708, 0.03411053214222193, 0.04317333422867315, 0.05842879294816937, 0.03439814278057643, 0.039759526162275245, 0.01684683877309518, 0.03362340506698404, 0.056354932087872706, 0.0140023470324065, 0.03900867627401437, 0.04862984482731138, 0.03819659538567066, 0.05757825608764376, 0.04727667636637177, 0.01314714185095259, 0.00898805636513446, 0.035138210747390985, 0.004415732026765389, 0.05132352028574262, 0.09633456143949713, 0.05064655946833747, 0.07701093583766903, 2.4104859914098467, 52.406068733760286, 33.5445305279323, 25.88148215838841, 67.07482419695172, 21.717353786740983, 0.09079132388745036, 0.2963899315467903, 0.36870423118983, 0.754652099949973, 1.8315570907933372, 3.5545920048441206, 5.5467278276171, 4.185408532619476, 1.3437412210873194, 0.7818077770727021, 32.00154406683785, 70.67270565032959, 64.52674606868199, 63.7858179637364, 62.767913818359375, 57.60168150493077, 59.70995603288923, 61.90389142717634, 57.54966729027884, 57.76858070918492, 56.38880048479353, 53.54205404009138, 51.01565081732613, 49.61575208391462, 46.89114454814366, 45.616184847695486, 47.417821475437705, 46.88493633270264, 52.29083980832781, 56.38790764127459, 55.50352702822004, 57.18710681370327, 55.884180613926475, 55.796372754233225, 55.65762070247105, 53.54120288576399, 49.66054712023054, 41.44852679116385, 43.061481612069265, 41.7131940977914, 41.72547851290022, 43.24109601974487, 43.315785680498394, 42.49600594384329, 42.25658144269671, 43.470518589019775, 40.21273756027222, 43.0792099407741, 45.408947876521516, 45.25506264822823, 49.082967690059114, 52.07911082676479, 56.86485978535244, 53.39880302974156, 49.62940876824515, 53.4950008392334, 53.49240916115897, 55.053530420575825, 53.142504828316824, 54.59574488231114, 52.15547152927944, 50.86982897349766, 50.150780745915, 45.43449987683977, 42.031591824122835, 42.295220375061035, 39.11621454783848, 41.350508553641184, 39.65401554107666, 40.00033460344587, 39.84356934683663, 41.92112588882446, 39.050484589168, 41.70904949733189, 40.53504712241036, 47.00364630562918, 52.63533844266619, 53.78281259536743, 52.13152456283569, 51.136650221688406, 51.218944685799734, 51.346485819135395, 50.14283200672695, 52.88226005009243, 53.16049371446882, 51.17387172154018, 51.8642829486302, 53.54859576906477, 50.76143707547869, 50.978564807346885, 50.35398428780692, 51.64298282350813, 48.9905948638916, 50.151583262852256, 45.92949996675764, 43.22159242630005, 43.19529696873256, 52.833191871643066, 48.38255105699812, 54.43532487324306, 54.376758507319856, 48.56466334206717, 2.638651588133403, 1.3117766848632266, 1.8791285838399614, 6.996535905769893, 6.4679000207356045, 3.28973970242909, 0.43184416741132736, 0.29699814319610596, 0.09750413868044104, 2.988068461418152, 49.531991549900596, 35.022568702697754, 26.745243992124283, 51.561702796391074, 4.470708080700465, 0.34571522048541475, 0.05817455266203199, 0.07770805593047823, 0.06357011385262012, 0.03529812448791095, 0.036722780005740266, 0.045692056217896085, 0.08066382232521262, 0.019549233406516056, 0.013372466367270266, 0.0241722400699343, 0.049731046094426086, 0.08800719292568308, 0.052795137212212594, 0.028406363047127212, 0.08719360229692288, 0.049900476288582594, 0.10227865712451083, 0.03023426853386419, 0.006997341065601046, 0.05753940995782614, 0.023406046808564236, 0.03400440587263022, 0.11422311940363475, 0.13181880808302335, 0.11718184421105043, 0.12251286315066473, 0.160293665847608, 0.15093347882585867, 0.17797813404883656, 0.1058537834989173, 0.16637711226940155, 0.13475145000432218, 0.12746828581605638, 0.09881794532494885, 0.09682236026440348, 0.14312503353825637, 0.1332843487284013, 0.07722864379840237, 0.10917513777634927, 0.10977397207170725, 0.13290526478418282, 0.10370794364384242, 0.1499197475079979, 0.09246604330837727, 0.09490950219333172, 0.1638538169541529, 0.14836757151143892, 0.33781411445566584, 0.07465154744152512, 0.08312475348689727, 0.17070873055074895, 0.20781611438308442, 2.79676935502461, 59.912711415972026, 46.24400322777884, 30.574741908482142, 62.82174151284354, 33.89365666253226, 0.24386719561048917, 2.424498119524547, 1.1181481948920657, 4.686302431992122, 6.235799355166299, 13.434186509677343, 10.976879647799901, 4.627446413040161, 1.566428814615522, 0.833042924957616, 31.832306793757848, 73.90290233067104, 67.53806754520961, 66.63512829371861, 64.94477054050991, 61.64376476832798, 61.44928468976702, 65.74534893035889, 60.12313066210066, 60.65836429595947, 57.60610750743321, 56.15207535879952, 53.65865870884487, 52.66288110188076, 49.00547095707485, 49.97289643968855, 49.326866831098286, 49.076373849596294, 55.13342775617327, 59.26346479143415, 59.56685788290841, 59.52074268886021, 59.53951672145298, 58.39935902186802, 58.22685956954956, 56.1269645690918, 51.205301897866384, 44.05384765352522, 45.095910685403005, 43.95172650473458, 45.320580686841694, 45.898368562970845, 45.51299715042114, 44.930845805576865, 44.87416240147182, 44.90026330947876, 43.481701714651926, 44.97772877556937, 47.55009433201381, 47.28432921000889, 52.071002279009136, 54.58848401478359, 58.865207944597515, 54.60425642558506, 52.214517320905415, 60.59169633047921, 55.30751139777047, 56.819477626255576, 55.721443380628315, 56.3483168057033, 55.994914054870605, 52.57163388388497, 52.692240715026855, 48.138172490256174, 43.721831457955496, 45.24491480418614, 41.654002393995015, 42.6006840297154, 41.95329257420131, 42.49649231774466, 41.23483494349888, 44.26011882509504, 41.270013672964915, 44.68649155752999, 42.95648043496268, 50.30956792831421, 54.81971311569214, 57.67781291689192, 54.71841185433524, 53.71715211868286, 54.06907490321568, 54.01878384181431, 53.0345332963126, 57.0335134097508, 54.6947706086295, 51.921956471034456, 53.027967248644146, 56.404162951878135, 49.25748559406826, 54.686081886291504, 55.46037176677159, 52.90811429704939, 50.30545112064907, 52.596275670187815, 48.815937995910645, 44.75410795211792, 45.36314187731062, 55.691729409354075, 49.820008277893066, 56.4978038242885, 56.12376492364066, 46.39487641198294, 2.887895630938666, 1.3171807548829486, 2.362950542143413, 10.380256942340306, 15.01454472541809, 10.229076300348554, 2.140064056430544, 0.6705557182431221, 0.7888841916407857, 5.015682654721396, 53.100975445338655, 34.773510524204795, 39.05017886843, 60.09943730490548, 5.652797290257045, 0.6025370880961418, 0.1853912105517728, 0.18621169509632246, 0.15185932628810406, 0.1621401903352567, 0.1608636895460742, 0.14308989899499075, 0.1625049707612821, 0.08955447668475763, 0.22038619273475238, 0.13492085305707796, 0.16144801676273346, 0.1734720915555954, 0.2061144028391157, 0.140352905860969, 0.17076738311776093, 0.1522142408149583, 0.19340787109519753, 0.11982975926782403, 0.2218830409858908, 0.10979544091969728, 0.13804324051099165, 0.11031207748289619], [0.016814676213211248, 0.08364390741501536, 0.0015740921475558675, 0.03442424263006874, 0.030845906785024062, 0.02484497700684837, 0.13605788775852748, 0.05884688587060996, 0.06404616723635367, 0.023829958168789744, 0.03432434531194823, 0.05901426010365997, 0.03366132499650121, 0.03766287670337728, 0.06885763191218887, 0.028339291556871364, 0.027297034626826644, 0.012024342814194304, 0.027120634181691066, 0.016698838411165134, 0.03985095875603812, 0.01656427134626678, 0.06826473479824406, 0.03211703696953399, 0.0384848404542676, 0.007423860120720097, 0.04377794964239001, 0.0385543733303036, 0.012853798439859279, 0.055963325779885054, 0.04455205971109016, 9.388858437538147, 48.922631059374126, 31.928535870143346, 34.865438665662495, 52.95837756565639, 5.728539603097098, 0.4031916420374598, 0.3226240224071911, 0.3933927821261542, 1.2026982179709842, 3.630816783223833, 5.468478083610535, 6.9496707405362805, 1.1791309054408754, 0.26658194246036665, 2.2249469416482106, 43.972560678209575, 70.92557838984898, 63.40642547607422, 61.279227529253276, 60.16945430210659, 58.059439250401084, 54.581379481724326, 56.861983231135774, 54.70326130730765, 51.88705219541277, 49.09714548928397, 50.28639221191406, 46.053851876940044, 43.75950459071568, 46.11582980837141, 47.52337156023298, 46.79153864724295, 51.24947854450771, 54.20378310339791, 55.575114318302695, 56.342963218688965, 57.71745238985334, 56.357575280325754, 56.40324578966413, 52.84228358949934, 46.56565618515015, 39.31261927740914, 39.10707071849278, 39.908753871917725, 40.976879596710205, 40.701977593558176, 40.47657455716814, 41.342549392155235, 41.157848903111045, 41.42832142966134, 42.47616883686611, 41.44397572108677, 41.54496431350708, 48.456997530800955, 55.59348882947649, 53.512704849243164, 57.134786878313335, 51.646495137895855, 49.04680926459176, 53.32993595940726, 52.42722599846976, 50.98009688513619, 52.12396839686802, 54.409328188214985, 48.25093133108956, 48.722752230507986, 45.72733170645577, 43.570145334516255, 39.97768695013863, 38.08463634763445, 37.302599225725444, 38.183151381356375, 39.33135162081037, 38.26252065386091, 39.82635865892683, 41.29574632644653, 38.220358984810964, 38.25284876142229, 39.164435046059744, 43.28563744681222, 52.87153550556728, 53.21726744515555, 55.57906436920166, 53.59970324380057, 52.564418179648264, 50.152799197605674, 50.73951898302351, 49.0960476739066, 50.77886315754482, 54.838601793561665, 48.01984119415283, 51.316386222839355, 53.16079943520682, 49.95251737322126, 47.053016730717246, 47.74648863928658, 49.6860921723502, 45.09085587092808, 43.22040775844029, 42.45088086809431, 49.99584286553519, 48.70245654242379, 50.21117101396833, 48.674250330243794, 54.985691683632986, 18.949137619563512, 0.11989446436720234, 1.1153435111045837, 0.8028955055134637, 8.282194529260908, 4.582785129547119, 0.9430716122899736, 0.12417357760880675, 0.12765823490917683, 0.0863171453986849, 20.756645475115093, 45.13379921231951, 20.416661432811193, 38.97717067173549, 17.580236537115915, 0.106717931771917, 0.059132318411554606, 0.06414650220956121, 0.010620149368021106, 0.07692825634564672, 0.0751557939552835, 0.033312327295009575, 0.02194232802971133, 0.01996550106975649, 0.02727736559297357, 0.049636719548808675, 0.028928566990154128, 0.04179542977362871, 0.04222252007041659, 0.013071029729742025, 0.02358334800893707, 0.01864344852843455, 0.06629017075257641, 0.024724092600601058, 0.04368515658591475, 0.06867421032594782, 0.04622506922377007, 0.024406575531299626, 0.020686666747289043, 0.03788801122988973, 0.055039663200399706, 0.021415866279442395, 0.02739124751782843, 0.08953200360494, 0.026722028784986054, 0.051742240853075466, 0.0049899363491152015, 0.047588368212538104, 0.028078033522303616, 0.021293741850448505, 0.0550742549156504, 0.037677017373165915, 0.025266216635437946, 0.0142636288156999, 0.07840712341879096, 0.02048584073781967, 0.05422238812648824, 0.018411031624834453, 0.03721313351499183, 0.08405642277960267, 0.047324926991547854, 0.04372484749183059, 0.03299726312980056, 0.036181339594934664, 0.018808076390996575, 0.030776146599756818, 0.07166541660470621, 0.032888527893062146, 0.06494146705205951, 0.08552895233567272, 15.795906135014125, 55.73983178819929, 23.371719871248516, 44.67448854446411, 60.6870881489345, 4.706822633743286, 0.3007456921041012, 0.3175452692168099, 0.5230876398938042, 0.1814258654734918, 1.91988519685609, 4.958502454417093, 5.822413240160261, 2.9841954920973097, 0.6663370760423797, 3.0096730164119174, 52.76319571903774, 71.10809367043632, 66.33082498822893, 62.349590573992046, 62.37129674639021, 58.51288563864571, 57.41669961384365, 58.29312106541225, 56.346357413700645, 54.70899704524449, 51.46435158593314, 50.89094802311489, 48.23672921316964, 45.67323998042515, 49.463614327566965, 49.58681978498186, 49.65008313315255, 54.07250036512102, 55.33060720988682, 57.15774025235857, 58.55642305101667, 58.42815930502755, 57.95363903045654, 58.24542168208531, 54.7012289592198, 48.81428779874529, 41.78693880353655, 38.92015722819737, 41.29122999736241, 41.23150675637381, 40.9565873827253, 43.26884365081787, 44.52620356423514, 43.1790520804269, 42.78710419791085, 44.92110095705305, 43.15589026042393, 44.815022809164866, 49.275293827056885, 55.90478202274868, 55.093086515154155, 59.80399990081787, 51.407240867614746, 50.47100237437657, 56.303810119628906, 54.773431164877756, 53.29238442012242, 53.86529466084072, 57.04338679994856, 50.25793239048549, 50.744695390973774, 49.03019264766148, 45.10751417704991, 41.983347007206504, 41.26189122881208, 40.219039576394216, 39.49285207475935, 40.85190234865461, 39.85915068217686, 41.897741726466585, 41.50855575289045, 38.76575435910906, 40.72688341140747, 39.809283460889546, 46.76501737322126, 54.98352384567261, 55.880115917750764, 57.517799377441406, 55.67156573704311, 53.6236571584429, 50.72747080666678, 52.72234378542219, 51.773442200251985, 51.612237044743125, 54.69828292301723, 50.92789159502302, 52.9091773714338, 54.67529828207833, 51.4823647907802, 49.36242076328823, 49.1408566066197, 51.987717696598594, 47.00654717854091, 46.036325045994346, 43.357068402426584, 51.77694756644112, 51.46366024017334, 53.70294305256435, 51.456253460475374, 56.88693421227591, 22.157523904527935, 0.11977084885750498, 1.0551915445498057, 3.1000710342611586, 8.204349517822266, 1.70154869556427, 0.21716621837445668, 0.08630563065941844, 0.024065163851316487, 0.06318452275757279, 21.10063862800598, 52.23870747429984, 18.6057767527444, 39.00684642791748, 26.492916686194285, 0.0797186501856361, 0.05289753493187683, 0.058539244878504954, 0.022019745482664024, 0.05701911609087672, 0.07141057242240224, 0.040130158952836475, 0.12601714368377412, 0.012235295958817005, 0.0509117139902498, 0.03047380157347236, 0.05511069903150201, 0.05317365118701543, 0.034109493983643394, 0.06975671116794858, 0.035648967804653306, 0.02721047561083521, 0.04181238297106964, 0.002477142847575513, 0.021940428131659116, 0.02192227901624782, 0.058149738636400015, 0.011871021041380507, 0.013683849480003119, 0.08865698520094156, 0.20685255394450255, 0.09464475139975548, 0.14344804334853375, 0.18915638779955252, 0.1724164132028818, 0.15738086429025444, 0.14052315029714788, 0.18047289018120083, 0.145826145740492, 0.13491545191832952, 0.2361170229102884, 0.20819025859236717, 0.19606964183705194, 0.19029085763863154, 0.15831877610513143, 0.14851089167807782, 0.13752205776316778, 0.1393021536724908, 0.06970542070588895, 0.06263030213969094, 0.11336835526994296, 0.18726803841335432, 0.15079906103866442, 0.1111859627334135, 0.1540068896221263, 0.13553780423743383, 0.22667571024170943, 0.23611213745815413, 0.19098007279847348, 0.2095500427697386, 18.867232254573278, 66.45972102028983, 40.8468405859811, 44.556685311453684, 66.0019667489188, 10.530554294586182, 0.6911866026265281, 1.1641461380890437, 1.1452956753117698, 4.669681038175311, 10.644102624484471, 13.381453156471252, 16.70947960444859, 2.757801251752036, 0.5046765421118055, 3.8844816173825945, 47.62938717433384, 71.92654282706124, 67.12421894073486, 63.86192853110177, 64.2577326638358, 64.900892666408, 59.451503889901296, 59.08301312582833, 60.24763543265206, 57.837479046412874, 53.903964860098704, 54.19962460654122, 51.20207445962088, 48.453919478825156, 51.263020583561485, 53.68944270270211, 53.073759351457866, 56.161590916769846, 57.289106369018555, 60.097936494009836, 59.69686562674386, 61.00764329092843, 61.837702887398855, 62.52567182268415, 57.675613812037874, 49.56541238512312, 42.83760370526995, 41.88513422012329, 44.143875462668284, 44.755442006247385, 43.0921231678554, 43.607411997658865, 45.74656432015555, 44.269630908966064, 45.3672308921814, 47.64084127971104, 45.54104355403355, 46.156341280256, 54.169052532741, 60.6418206351144, 57.11082948957171, 62.569730349949424, 53.34899834224156, 51.50915009634835, 55.94378226143973, 55.29832240513393, 56.344856602805, 56.455023765563965, 59.92424542563302, 52.622609342847554, 52.94218826293945, 51.64017227717808, 49.146682671138215, 44.68806185041155, 42.85773958478655, 42.01601396288191, 43.17020007542202, 43.30579417092459, 42.74477924619402, 42.65529339654105, 45.56125238963536, 40.64792060852051, 42.12468031474522, 41.35387148175921, 46.10583135059902, 55.87127433504377, 57.98729610443115, 59.50286497388567, 58.95986325400216, 56.16380739212036, 54.317358357565745, 53.909342765808105, 52.853650842394146, 54.293783119746614, 58.161185196467805, 50.726720401218955, 53.85105432782854, 57.95202704838344, 53.827552046094624, 50.87459543773106, 51.68041276931763, 54.485939025878906, 48.93475219181606, 47.23308277130127, 47.71105630057198, 53.97691747120449, 52.901954718998496, 55.24555778503418, 53.044260774339946, 57.98343985421317, 21.68488485472543, 0.20777213174317563, 2.681812060730798, 4.599669686385563, 21.288418906075613, 12.430415868759155, 2.763008709464754, 0.2779082932642528, 0.29350100085139275, 0.14327849101807388, 31.622050830296107, 57.21660886492048, 31.478601796286448, 49.74875102724348, 29.61998646599906, 0.1704124685909067, 0.17846078957830155, 0.23297809277262005, 0.10838613725666489, 0.19297135594700063, 0.09848789910652808, 0.12718385750693934, 0.17034566003297055, 0.09467065786676747, 0.09829808572041136, 0.14435090204434736, 0.14679383167198726, 0.2301705048552581, 0.0829505803329604, 0.12476260028779507, 0.13356154385421956, 0.1186248032110078, 0.22022479639521667, 0.14108338952064514, 0.1458015963435173, 0.21646389391805443, 0.1088697834472571, 0.1663340660078185, 0.09327430065189089], [0.0646577715607626, 0.03568472320746098, 0.031424737868032286, 0.024174107737573128, 0.03198516368865967, 0.037586751859635115, 0.02622351928481034, 0.043344450582351, 0.033592161922050376, 0.023253983718210032, 0.018564441607200673, 0.029330710946981395, 0.02299198947314705, 0.06435507030359336, 0.035069122311792204, 0.0514235363474914, 0.01748158283797758, 0.03728746024093457, 0.035310636673654826, 0.027211864911285893, 0.023352751275524497, 0.020120967013229216, 0.040867163334041834, 0.12060883960553578, 0.054341118184051344, 0.07285409460642508, 0.03897140434544001, 0.03746336365916899, 0.04829341359436512, 0.110302136944873, 0.04004895527447973, 0.6348214043038232, 33.073557308741975, 42.80433920451573, 20.64718529156276, 48.36184195109776, 35.316911765507285, 0.42816444486379623, 0.08832763787358999, 0.2014854233711958, 0.24456844798156194, 1.2900683411530085, 3.0291249326297214, 3.0574996386255537, 2.0456412945474898, 0.7141602784395218, 0.13137785531580448, 11.475199239594595, 57.767997060503276, 56.67297485896519, 66.79857771737235, 58.95372799464634, 59.16307026999337, 58.3703989301409, 51.40915509632656, 53.83772420883179, 52.78164666039603, 47.634699072156636, 46.94880070005144, 48.546893324170796, 50.28983851841518, 47.979927267347065, 49.145713397434776, 50.111134324754985, 54.61371987206595, 57.36771828787667, 57.93401731763567, 56.71907615661621, 53.70230381829398, 55.08088547842843, 57.043359007154194, 53.16848414284842, 47.604985100882395, 41.44173492704119, 40.36607388087681, 40.70525366919381, 40.108573641095845, 40.50378370285034, 38.48557867322649, 39.55788721357073, 41.25663839067732, 41.73336124420166, 41.03677306856428, 44.72605112620762, 46.92203623907906, 52.10197387422834, 54.68425103596279, 55.61874205725533, 54.224850041525706, 54.675312178475515, 54.262356417519705, 55.45986802237374, 52.43400396619524, 51.60499702181135, 46.40944331032889, 46.638233593532014, 46.37128380366734, 41.913924080984934, 41.42854029791695, 39.36511639186314, 39.44862331662859, 39.73893642425537, 40.364635603768484, 38.6137694631304, 39.43104437419346, 39.912443365369526, 38.98413624082293, 39.15069498334612, 39.27588415145874, 39.97598811558315, 38.05576310838972, 44.308613777160645, 53.80400112697056, 52.413812501089915, 53.94518504823957, 52.91249861036028, 54.79252828870501, 50.62310191563198, 50.79704311915806, 49.84947558811733, 51.706624848502024, 50.82348101479666, 53.121754033224924, 51.13752222061157, 50.97452790396554, 49.75832217080252, 50.73846285683768, 48.43136215209961, 45.7978698185512, 44.9576484816415, 45.289529187338694, 43.51380239214216, 47.65181595938546, 49.78511095046997, 50.41874844687325, 53.52669504710606, 33.62360102789742, 0.1976333257875272, 0.5005431781922067, 0.9629922062158585, 3.2188448437622617, 4.718670615128108, 1.6758495888539722, 0.26822253156985554, 0.21903812007180282, 0.12526478405509675, 5.506459976945605, 45.25525719778878, 28.781048808779033, 28.24273017474583, 40.77041040148054, 1.128500576530184, 0.130341501640422, 0.07034524530172348, 0.020571875585509197, 0.0336113780337785, 0.06063419460718121, 0.031550114176103046, 0.025249539941017116, 0.05143946156437908, 0.08421144767531327, 0.06936759847615447, 0.036120559820639234, 0.05657516759155052, 0.0180259748761143, 0.02699909668548831, 0.040796636404203515, 0.04145380774778979, 0.005456164545778717, 0.015556385607591696, 0.0345058975342129, 0.06142234017274209, 0.05080720602667757, 0.018990539546523775, 0.053091266857726235, 0.035263101902923415, 0.027164591376536658, 0.04295149738235133, 0.02153102385013231, 0.0405613442084619, 0.08114525649164404, 0.01062375832615154, 0.04885327623092702, 0.043635104450264146, 0.014977303466626575, 0.0476382710704846, 0.027913044339844158, 0.07488967252096959, 0.05688668980396219, 0.05288145025925977, 0.04662293840997985, 0.04406621506703751, 0.03253936055781586, 0.024647850709568177, 0.09865661005356482, 0.03272720958505358, 0.029312522815806524, 0.004728662199340761, 0.05704055101211582, 0.049021708978606124, 0.040120208236787996, 0.03402857868266957, 0.06275540364107915, 0.056043810211122036, 0.023278054747996584, 0.05715929464037929, 0.03686071599700621, 1.3548113299267632, 44.29846593311855, 42.85528687068394, 21.178541830607823, 62.662148339407786, 32.99939571108137, 0.46833046099969317, 0.14902446126299246, 0.3290137323950018, 0.19280687905848026, 0.8769890325410026, 2.003609904221126, 3.998621412685939, 7.411887492452349, 4.663846288408552, 0.17255825416318007, 13.534138083457947, 63.71735041482108, 59.19808224269322, 70.23088359832764, 61.36025047302246, 61.204270362854004, 60.64313384464809, 56.05365412575858, 54.54624244144985, 55.365546226501465, 50.71352924619402, 48.32134090151106, 51.19088438579014, 52.93664012636457, 49.77826697485787, 51.109621729169575, 51.68700660978045, 56.649799142565044, 59.26078973497663, 60.331632205418174, 59.58066395350865, 54.68421629496983, 56.908171381269185, 59.89215169634138, 55.24509572982788, 49.81555100849697, 43.04004989351545, 41.77236843109131, 41.86554377419608, 41.511988162994385, 43.08847188949585, 41.14172213418143, 43.97059086390904, 43.42955201012747, 43.972671849387034, 42.895089626312256, 46.1298999105181, 46.82741914476667, 52.779416288648335, 56.193702016557964, 55.7616491317749, 56.18853950500488, 54.367145674569265, 54.20311607633318, 56.940449237823486, 54.39925330025809, 54.62338829040527, 49.99790300641741, 49.22228602000645, 49.29334872109549, 44.61064849581037, 43.91256298337664, 41.16226100921631, 41.68979603903634, 40.16322817121233, 41.95182303019932, 40.56318385260445, 41.448769978114534, 41.15675456183297, 41.74576030458723, 40.41346754346575, 41.10719306128365, 42.08323778424944, 40.01826442990984, 47.377646991184776, 55.43384007045201, 53.09607349123274, 54.85651772362845, 54.982766492026194, 54.910803999219624, 51.20873778206961, 51.40761259623936, 53.38273532049996, 53.73400150026594, 54.55741514478411, 54.405607427869526, 52.520161628723145, 53.27007375444685, 51.61990090778896, 52.038922446114675, 50.26705537523542, 47.07854788643973, 48.192642893110005, 45.990421772003174, 46.611264160701204, 49.07172550473894, 52.08320331573486, 51.66878843307495, 54.10830095836094, 37.21002490179879, 0.4174075477889606, 1.3360310005290168, 2.5371979006699155, 4.0713881594794135, 4.467515383447919, 0.19483383957828793, 0.21385271474719048, 0.19214338037584508, 0.049390082247555256, 6.214196537222181, 52.73934602737427, 40.5954304422651, 25.761033398764475, 49.61890309197562, 2.432806645120893, 0.3810436619179589, 0.036021585310144086, 0.05399323667266539, 0.049256566911935806, 0.09691293790404286, 0.022031370483871018, 0.003919214026869408, 0.028762081637978554, 0.060922130942344666, 0.018064765026792884, 0.02798002931688513, 0.02666711324958929, 0.06201810070446559, 0.021942015903602754, 0.022199974561642324, 0.006416003219783306, 0.049706839357635806, 0.031850610194461684, 0.05209958114262138, 0.10792553411530596, 0.05770426004060677, 0.03203475442049759, 0.0477019787233855, 0.03739011919658099, 0.1744961773178407, 0.1609639770218304, 0.1018183593239103, 0.09438725414552859, 0.14076792501977511, 0.13624432204025133, 0.09509985840746335, 0.18382207117974758, 0.10604403793279614, 0.1301138395709651, 0.11163505792085614, 0.22290988160031183, 0.10403269728911774, 0.12841864196317537, 0.13091580010950565, 0.26944025765572277, 0.06655097247234412, 0.08345418223845107, 0.16745219672364847, 0.14579505526593753, 0.13715167263788836, 0.11603069598121302, 0.13744869455695152, 0.22128310746380261, 0.12896575831941196, 0.10668713306742054, 0.19004410159374985, 0.11079433946205036, 0.10815419363124029, 0.13973614467041834, 0.16136588688407624, 1.7469556076186044, 49.18887908118111, 57.33642012732369, 31.131386416299, 58.04224245888846, 48.467795031411306, 0.9503138065338135, 0.30511016505105154, 0.6853192288960729, 1.495355799794197, 6.153652106012617, 9.310717259134565, 9.342718056270055, 9.014407856123787, 1.4866647975785392, 0.276292158556836, 14.394466638565063, 65.94087818690709, 62.876722608293804, 71.0063442502703, 66.14612797328404, 64.12156881604875, 63.51441437857491, 57.06817102432251, 58.60774939400809, 58.09172405515398, 52.90436921800886, 51.23291056496756, 54.0653715133667, 56.16065638405936, 52.26553446905953, 54.32866655077253, 54.989190101623535, 59.40426308768136, 62.23399339403425, 62.39269024985177, 62.21459402356829, 56.631320408412385, 56.649337087358745, 61.2211822782244, 57.106660570417134, 52.694116728646414, 45.44590187072754, 45.29331942967006, 43.81584405899048, 45.30677809034075, 44.667245047433035, 43.685624395098, 44.29137877055577, 46.915925298418315, 46.77200378690447, 44.58799042020525, 47.84252316611153, 50.3495443889073, 55.56675910949707, 59.605691364833284, 57.940854345049175, 57.38365398134504, 55.16448967797415, 58.23719154085432, 62.09769058227539, 57.469168935503276, 57.87409952708653, 49.922160693577354, 49.57429565702166, 50.39595488139561, 45.44171905517578, 46.63545778819493, 42.86616774967739, 44.471191201891216, 43.665158476148335, 44.67923069000244, 43.013031823294504, 43.12722199303763, 42.79825953074864, 44.545700209481375, 42.42270244870867, 43.74255446025303, 44.56534971509661, 42.23485442570278, 49.596915517534526, 58.003874506269185, 53.95317547661917, 54.93859331948416, 55.20814520972115, 57.70130130222866, 54.00055524281093, 53.51337535040719, 54.65304667609078, 55.88165841783796, 56.20214407784598, 56.92205735615322, 52.87318570273263, 53.75462375368391, 55.128407682691304, 55.87368883405413, 50.953756264277864, 48.40432671138218, 50.04663419723511, 49.74589531762259, 46.99496800558907, 52.426030908312114, 53.85186031886509, 54.27816704341343, 54.892908913748606, 37.230577673230854, 0.5095902213028499, 1.2268256204468864, 2.943540496485574, 6.592756978103092, 13.668825439044408, 7.71043074131012, 1.0526360188211714, 0.5319053381681442, 0.34573128819465637, 9.98537084034511, 57.445107323782786, 40.96893433162144, 37.911806855882915, 58.585417883736746, 3.9307414208139693, 0.6198409795761108, 0.1323001201131514, 0.21705120668879577, 0.11786119347172123, 0.1589970804218735, 0.17267621069082192, 0.1042146057422672, 0.1420399203364338, 0.16140464480434144, 0.154368114524654, 0.13306761107274465, 0.11919315771332809, 0.1649970534656729, 0.12413747954581465, 0.12892021504896028, 0.17307672277092934, 0.10555509238370828, 0.10656384325453214, 0.0893148791843227, 0.2187725007534027, 0.19269314301865442, 0.07380455931914703, 0.22563278834734643, 0.17446617249931606], [0.05128446041739412, 0.039859593114150424, 0.08314955394182887, 0.035192625863211494, 0.050646817311644554, 0.0024756006647034413, 0.06038113497197628, 0.01670677218187068, 0.01312409371270665, 0.004433518550026098, 0.04132393614522048, 0.04842546329434429, 0.008889060650419976, 0.03137122859646167, 0.029750846259828125, 0.10819548927247524, 0.007067459602175015, 0.026744663016870618, 0.03377674041049821, 0.01136853702233306, 0.024230017326772213, 0.042777884019804854, 0.05489070780043091, 0.08457333754215922, 0.10878598437245403, 0.033411054140222926, 0.04300123739189335, 0.017180291237309575, 0.0184055354911834, 0.026673667897869433, 0.04484062369114586, 0.088639499353511, 6.040651815278189, 43.16817467553275, 29.587924003601074, 30.672833102090017, 63.86517333984375, 15.889366354261126, 0.014355168278728212, 0.051671225378023725, 0.057785575677241595, 0.5136812446372849, 1.6216259556157249, 2.8207082876137326, 4.628258049488068, 9.898367234638759, 0.29308516745056423, 0.3899010680615902, 21.55785267693656, 63.282851764133994, 62.74574211665562, 64.52778829847063, 61.154715810503276, 55.4669760295323, 54.35592085974557, 54.75213493619646, 47.87910543169294, 51.14006873539516, 50.855606010981965, 53.190287590026855, 50.23945713043213, 53.71502249581473, 53.06980235236031, 55.29270478657314, 55.26625299453735, 57.1717825617109, 56.244458607264924, 57.60827881949288, 56.47931119373867, 60.96166706085205, 55.60689190455845, 52.754170009068076, 44.76940093721662, 38.821944441114155, 38.8623343195234, 41.08874906812395, 39.06833103724888, 39.116388252803254, 41.542386531829834, 42.35428006308419, 43.05795192718506, 44.32451820373535, 45.559570925576345, 44.91818618774414, 50.96574885504586, 54.27292462757656, 55.17234114238194, 56.22213404519217, 54.60158831732613, 52.06463425500052, 52.402149949754985, 56.70636095319475, 51.50559261866978, 49.566044671194895, 45.437956605638774, 41.92625713348389, 40.89444964272635, 40.57837956292288, 40.8156292779105, 40.90995454788208, 39.88948999132429, 40.583750520433696, 38.49341971533639, 39.466299533843994, 38.82108286448887, 41.74185194287981, 41.72574601854597, 41.426306452069966, 40.28017330169678, 39.59462233952114, 38.304532936641145, 41.99842459814889, 51.937016691480366, 56.62299646650042, 55.479347297123496, 55.41026135853359, 56.04720967156546, 56.369547026497976, 53.56347186224801, 49.24405820029122, 52.003007207598, 54.92457185472761, 52.43468141555786, 53.4324357850211, 53.5955308505467, 52.149586405072895, 47.9274822643825, 48.04656049183437, 46.69313131059919, 44.41242333820888, 45.557778290339876, 49.06403037479946, 49.3451440674918, 51.69597673416138, 53.35700266701834, 42.77948202405657, 2.8394473620823453, 0.05579839088022709, 0.21072935020284994, 0.8762666370187486, 1.8418586637292589, 2.862606793642044, 0.14178974447505815, 0.12331520366881575, 0.09019500017166138, 2.051192036696843, 35.5653133392334, 36.44186333247593, 17.120719160352433, 42.90961830956595, 13.688222203935895, 0.22298424903835568, 0.051261397012110264, 0.030928630381822586, 0.010298510198481381, 0.0590243838461382, 0.10629997455648013, 0.06327707493411643, 0.054897778135325224, 0.026818748862881745, 0.04140682937577367, 0.06451747087495667, 0.014528634059908134, 0.03251498079459582, 0.028127739605094706, 0.03256106350038733, 0.06369374293301787, 0.05786428573940482, 0.06058648681002004, 0.04261350551886218, 0.026495666110089848, 0.05325388116762042, 0.05160396898697529, 0.07892979215830564, 0.04400109266862273, 0.04114046027617795, 0.03580731752195528, 0.04105302764635001, 0.038079677016607354, 0.019537815358489752, 0.04347368436200278, 0.009599922773694354, 0.032579163422009776, 0.03196042769455484, 0.03164209299055593, 0.04964326401906354, 0.012988839631101914, 0.01690636495394366, 0.004396380632117922, 0.02507142280228436, 0.051825395319610834, 0.034713437647691796, 0.0489925523288548, 0.02523631020449102, 0.0599691556500537, 0.059802982423986704, 0.028599165380001068, 0.05627994718296187, 0.022429083607026508, 0.06799927154289824, 0.06196609099528619, 0.06164133056466069, 0.03124433915529932, 0.026074051590902463, 0.024567708938515613, 0.015726043110979453, 0.042732500205082555, 0.07089481116937739, 11.245090535708837, 54.23234019960676, 22.66338402884347, 37.527484621320454, 73.15009280613491, 15.168838160378591, 0.01770332977840943, 0.053431667520531585, 0.08795248943247966, 0.7301548687475068, 0.5576718641178948, 2.0907442229134694, 12.084013428006854, 14.016056452478681, 0.33176204349313465, 0.31303105716194424, 29.265023844582693, 64.6347210747855, 64.64312144688198, 68.49252768925258, 63.050406728472026, 56.990886211395264, 58.295636313302175, 56.24559811183384, 50.637675762176514, 53.63581303187779, 51.97318206514631, 54.4336017199925, 53.01829883030483, 55.489321436200825, 55.14292941774641, 56.187598024095806, 58.075972488948274, 58.42871516091483, 58.67776639120919, 59.032784598214285, 56.91272245134626, 60.37559345790318, 57.22430052076067, 55.85877799987793, 48.14958143234253, 41.38572549819946, 39.51115710394723, 42.42933103016445, 40.247242314474924, 40.36570562635149, 42.40383461543492, 43.194577830178396, 43.141865321568076, 45.40823221206665, 47.662026337214876, 48.16214724949428, 53.24573768888201, 57.03453826904297, 57.31721878051758, 57.36460549490792, 56.12763854435512, 52.7440117427281, 54.59087072099958, 59.26520184108189, 53.907425062997, 52.71609040669033, 46.83751140322004, 43.133221762520925, 43.464970452444895, 43.48121881484985, 43.139388288770405, 42.331184250967844, 41.85726152147566, 43.73277487073626, 40.62789590018136, 42.71521813528878, 40.092915875571116, 42.993087019239155, 43.17684602737427, 43.67839132036482, 40.491968291146414, 42.433795247759136, 40.53698219571795, 45.103088174547466, 54.34278181621006, 56.773327691214426, 55.878417083195274, 56.988707951136995, 57.04421016148159, 56.31496197836739, 54.14055102212088, 50.99602563040597, 53.20722034999302, 55.133941922869, 54.00352907180786, 52.72752366747175, 54.04296357291085, 53.68609367098127, 51.17306225640433, 50.171771253858296, 48.495723315647666, 48.53007173538208, 47.04277508599417, 50.6776556968689, 50.93782751900809, 52.44977985109602, 54.562504700251985, 47.11819430759975, 5.067171846117292, 0.34588450140186716, 1.8256337514945438, 2.874933115073613, 3.7130843230656216, 0.5259690252797944, 0.3115595861205033, 0.11146771082920687, 0.23218966222235135, 3.4644814687115804, 35.574408531188965, 49.32083579472133, 19.687536580221995, 43.530061176845, 21.717659507478984, 0.13812055279101643, 0.03241409281534808, 0.03762415610253811, 0.037252054283661504, 0.047662023188812394, 0.0696085530466267, 0.04035904917067715, 0.042154921019183736, 0.054270570898162465, 0.012039162867170359, 0.009431288161847209, 0.06729129488979067, 0.028731608630291054, 0.10287871278290238, 0.024714857738997256, 0.00465616285302011, 0.05359012919611164, 0.01615622074210218, 0.10428756861282246, 0.06569641868450812, 0.04445932772276657, 0.04002165441800441, 0.02837093503746603, 0.029384976785097803, 0.04765710380992719, 0.13373607663171633, 0.12943929433822632, 0.12122568222028868, 0.14090872103614466, 0.290174197937761, 0.13899271456258638, 0.10825525463691779, 0.11572388958718095, 0.09428898870412793, 0.11284751178962843, 0.1437602373106139, 0.12843897087233408, 0.11872509068676404, 0.0759009068299617, 0.13582833936171873, 0.3070664629340172, 0.08084043141986642, 0.11957300161676747, 0.12213528555418764, 0.1905313575906413, 0.16527540210102284, 0.1402682111199413, 0.08279140958828585, 0.2084084347422634, 0.18769886743809494, 0.14621057654065744, 0.10950529256037303, 0.12007134487586361, 0.12967216755662644, 0.0720257865531104, 0.1355707946100405, 0.24967719241976738, 13.744983775275093, 64.85987745012555, 38.578107833862305, 43.70787252698626, 77.48482377188546, 25.402488980974468, 0.12236791449998106, 0.257528656827552, 0.23070947879127093, 2.1031087594372884, 7.248269574982779, 9.89828211920602, 11.139274682317462, 18.29722809791565, 0.2885800206235477, 0.6153587943741253, 29.096615144184657, 68.55335916791643, 64.3964603969029, 72.26046630314418, 67.47242791312081, 59.79641941615513, 59.53541728428432, 61.31182152884347, 52.736941950661794, 56.44228771754673, 55.676516328539165, 57.45902803965977, 55.64916821888515, 58.68283857618059, 60.22379616328648, 61.23362650190081, 61.65889794485909, 60.62954316820417, 60.55872712816511, 60.03180353982108, 58.68745218004499, 63.48780277797154, 60.798551150730674, 59.30065849849156, 51.060682092394146, 43.2231696673802, 41.691981247493196, 45.058539799281526, 42.52330889020647, 42.391869817461284, 46.95995603288923, 46.07885496956961, 47.381815910339355, 47.827261447906494, 51.312818322862896, 50.52888434273856, 55.75541659763881, 60.060847009931294, 61.652818271092, 61.09988757542202, 56.57951463971819, 53.36511468887329, 57.62196677071707, 61.37712069920131, 55.8369710786002, 53.497175625392366, 49.54199695587158, 45.73256022589547, 46.785643100738525, 46.59196901321411, 46.60554926736014, 44.81846911566598, 43.95854268755232, 44.84147112710135, 42.43960394178118, 43.980888094220845, 42.89498887743269, 45.756423813956125, 45.2963662147522, 46.3662428855896, 43.46493223735264, 43.78456326893398, 41.622857093811035, 47.04546403884888, 55.90500089100429, 60.529968534197124, 58.740849086216514, 57.43518877029419, 60.14355141775948, 59.58783449445452, 56.36771617616926, 53.21137537275042, 55.78658274241856, 57.58798313140869, 55.72062349319458, 54.232934270586284, 57.09749242237636, 55.24064193453108, 53.12573535101754, 52.63609232221331, 52.33153540747506, 49.767782143184114, 49.050366742270334, 54.783651965005056, 53.25290128162929, 54.782863344464985, 56.446269035339355, 45.85562324523926, 4.533768628324781, 0.1404148018253701, 1.2798679513590676, 3.316525225128446, 14.29883337020874, 8.24266014780317, 0.7915379692401204, 0.22608509979077748, 0.2701647702072348, 4.762276206697736, 46.824323722294395, 46.96742187227522, 28.235969577516826, 53.61394010271345, 25.312560183661326, 0.27654519783599035, 0.10811339332056896, 0.1471579742750951, 0.15288045363766806, 0.17781037305082592, 0.2662850155362061, 0.18591319397091866, 0.123046286670225, 0.17686224249856813, 0.08769691921770573, 0.1539823945079531, 0.17789699483130658, 0.1050786047375628, 0.13459960743784904, 0.21443082658307894, 0.09481019859335252, 0.16338872191097054, 0.1729198997574193, 0.1408268761421953, 0.17105091576065334, 0.12268329757664885, 0.10703279916197062, 0.1855112976793732, 0.16191411603774342, 0.11572937215013163], [0.056272004930568595, 0.014115251866834504, 0.12095371181411402, 0.08451011843447175, 0.03517636816416468, 0.046570117851453166, 0.04409767195050206, 0.018754238029941916, 0.06696584235344614, 0.04722804915426033, 0.04277044727600046, 0.013773009829622294, 0.09684412766780172, 0.05318980710580945, 0.0696774311363697, 0.03607183761362519, 0.024972897821239064, 0.006681044935248792, 0.07579014277351753, 0.07703465742192098, 0.0038390565646945363, 0.05419833745275225, 0.026292967343969003, 0.02922421826847962, 0.041153145488351583, 0.04170890298805066, 0.033194849134555886, 0.07686660465385232, 0.06976861945752587, 0.07277309788124901, 0.04381144891626068, 0.050435684355241914, 0.2801136406404631, 20.901065519877843, 46.82593223026821, 26.281875576291764, 37.55366543361119, 50.8225291115897, 6.928454416138785, 0.026273435713457208, 0.08261675467448575, 0.17271608140851769, 0.18341199175587722, 0.8546947602714811, 25.83658116204398, 16.30607066835676, 0.7824837065168789, 0.3438814388854163, 2.4561947158404758, 33.808930328914094, 71.97996752602714, 65.85894502912248, 65.05217579432896, 62.60053866250174, 55.21666022709438, 53.079880714416504, 52.666754722595215, 52.55037587029593, 55.593210901532856, 55.76758636747088, 57.3141268321446, 54.678348541259766, 53.3852470942906, 56.60737344196865, 59.2309958594186, 58.68693801334926, 60.15297317504883, 56.10807589122227, 56.4536897114345, 56.52600656236921, 54.7357302393232, 53.740779467991416, 45.683714389801025, 41.20897722244263, 41.322392668042866, 40.76988928658621, 41.233309813908164, 40.997758933476035, 44.77829463141305, 46.76296418053763, 49.44623688289097, 48.071518421173096, 46.024919578007285, 47.050650869097026, 54.511532715388704, 52.674762521471294, 54.69255413327898, 55.15603372028896, 53.466151918683735, 51.04177951812744, 52.974414008004324, 55.93423196247646, 53.142060143607004, 52.04768065043858, 48.9583934375218, 48.82826410021101, 46.17882912499564, 42.54681812013899, 39.98105335235596, 41.19503913606916, 42.92207990373884, 41.42739037105015, 39.81325783048357, 42.78720842088972, 40.882175649915425, 44.00462314060756, 46.20666708265032, 44.792778151375906, 42.273413453783306, 42.582608291081016, 42.42304638453892, 41.86299378531319, 49.02653094700405, 57.18619659968785, 54.02218151092529, 55.83280215944563, 53.143355982644216, 55.579734870365684, 52.69963012422834, 53.71259062630789, 52.01287712369646, 52.93366977146694, 51.99620492117745, 55.86511823109218, 50.80821582249233, 52.58479724611555, 51.571659564971924, 50.39191797801426, 47.33731617246355, 48.536213942936485, 50.21993269239153, 47.07725204740252, 48.65864815030779, 54.21246140343802, 46.42583063670567, 7.537379775728498, 0.09115991089493036, 0.3564906551369599, 2.7228822112083435, 3.659488524709429, 3.1239773971693854, 1.15858736208507, 0.1123975073652608, 0.09987325726875237, 2.2950453630515506, 22.065151078360422, 45.6284692628043, 26.864605358668737, 32.57324184690203, 39.922653743198936, 1.5471701451710291, 0.30910749627011164, 0.12512465300304548, 0.04558934297944818, 0.032651074563286135, 0.048452513092862706, 0.058343440028173585, 0.05193864620689835, 0.03490233840420842, 0.07034475675651006, 0.00430548153651346, 0.0698529952870948, 0.030677165303911482, 0.03874249716422387, 0.06676671268152339, 0.07130246143788099, 0.0214548718649894, 0.04909553358863507, 0.007853807049936481, 0.017066148076472536, 0.05639991217425891, 0.09246468623833996, 0.06577569193073682, 0.013674098931785141, 0.010309184402493494, 0.0531751236080059, 0.0699641393231494, 0.037649458673383505, 0.0660538709323321, 0.03554221049749425, 0.07430641738963978, 0.026323250361851284, 0.03767929046547838, 0.020905721600034406, 0.020543989492580295, 0.007958597453710223, 0.06717723315315587, 0.08467640022614173, 0.07556218214865242, 0.03635393515495317, 0.06324864431683506, 0.01574089454620012, 0.022798761359548995, 0.08660816228283302, 0.09284357340740305, 0.051624009518751075, 0.04241719176726682, 0.05339334047000323, 0.08281499546553407, 0.017009183365319456, 0.021846242382058075, 0.02094275943402733, 0.02023652322324259, 0.026574135292321444, 0.10903250971542937, 0.05166388702179704, 0.029787093600524322, 0.03535378132281559, 0.5129152057426316, 33.844063895089285, 49.51842171805245, 25.45591367994036, 58.81195000239781, 54.22895295279366, 5.641668013163975, 0.0750562935801489, 0.050063646997192075, 0.20202470943331718, 0.37660620574440273, 1.6788474108491624, 11.610824601990835, 14.901582649775914, 4.642958700656891, 0.5711098973240171, 2.7687262083802904, 40.508716923849924, 75.20599528721401, 67.37787682669503, 67.60074724469865, 65.37009756905692, 57.65154872621809, 55.70834255218506, 52.94896623066494, 53.79014294488089, 57.44563538687569, 58.1653402192252, 59.47367559160505, 56.77153853007725, 55.13110358374459, 58.33344841003418, 60.98393603733608, 61.24973242623465, 61.626686096191406, 56.234668595450266, 57.03557702473232, 57.850444384983604, 57.95057487487793, 54.116277490343364, 47.35691704068865, 41.57283353805542, 43.993905544281006, 42.21301623753139, 43.23758717945644, 41.599875926971436, 46.622575828007285, 48.611754758017405, 50.86252989087786, 48.99229717254639, 48.97193200247628, 48.74693543570382, 55.950605392456055, 53.69675915581839, 55.68799475261143, 56.8931702205113, 53.912017822265625, 53.04856865746634, 53.25480508804321, 56.919952051980154, 56.05575248173305, 53.02947848183768, 49.395636626652305, 49.55212048121861, 47.068212441035676, 42.420263631003245, 40.67122139249529, 41.953858852386475, 43.50775745936802, 42.761281217847554, 42.304652554648264, 43.75816011428833, 42.130113806043354, 44.39831502096993, 47.175023623875205, 46.712513310568674, 44.64380529948643, 43.58381591524397, 44.389667987823486, 43.94493811471121, 50.4550701550075, 57.07468148640224, 56.3267947605678, 56.66542911529541, 54.61979954583304, 57.14744649614607, 55.07341616494315, 55.43771716526577, 55.90710619517735, 53.59931761877877, 54.472167696271626, 56.08932270322527, 53.61514561516898, 54.06664303370884, 54.12522677012852, 52.3099855695452, 49.79033599581037, 48.981068883623394, 52.92418548039028, 50.35103825160435, 50.85372999736241, 54.96391255514962, 49.13806343078613, 9.452004534857613, 0.10888452122786216, 1.454630236540522, 4.673027030059269, 3.8928876348904202, 0.2908219817493643, 0.48018718191555565, 0.07602321276707308, 0.20608917490712234, 3.4190508893557956, 23.48423378808158, 56.17095708847046, 29.681999138423375, 26.885210241590226, 50.74287496294294, 2.7375633205686296, 0.3239585922232696, 0.021964314260653088, 0.06166560176227774, 0.05649268826735871, 0.03429583666313972, 0.08091085656945195, 0.0393175623778786, 0.030468142591416836, 0.07732315694114991, 0.029973948573959724, 0.02059438089574022, 0.0034118880243373235, 0.03853744048891323, 0.10179660549121243, 0.042056950740516186, 0.02588079633590366, 0.024276642860578637, 0.045892173158270974, 0.013424700841174593, 0.029752488314573253, 0.02132124457109187, 0.04848793601351125, 0.04801960775096502, 0.05263830402067729, 0.07783042293574129, 0.16401526757649013, 0.11712283880582877, 0.14713531120547227, 0.16829957839633736, 0.20499529503285885, 0.13931583293846675, 0.15292134215789183, 0.06627143640071154, 0.18109676241874695, 0.10784561626080956, 0.0841300506144762, 0.2412393923316683, 0.15422929983053887, 0.12404765508004598, 0.15845761794064725, 0.14811287660683903, 0.08721247235579149, 0.20589626740132058, 0.22966051793524198, 0.15467778433646473, 0.11436217837035656, 0.15564380107181414, 0.14466085684086594, 0.14402478454368456, 0.1991038333092417, 0.13404738849827222, 0.08025001095873968, 0.1587128692439624, 0.23705991517220223, 0.15953263454139233, 0.11469611259443419, 0.15176579702113355, 0.5587094255856105, 40.167338030678884, 64.81274087088448, 38.84000628335135, 51.29641015189034, 65.50847094399589, 12.447496277945381, 0.15542099731309073, 0.2524377985724381, 0.8254988640546799, 1.8909505094800676, 5.623579246657235, 41.1613438470023, 28.89767258507865, 3.963426181248256, 0.364969574447189, 2.9955249641622816, 36.25300782067435, 77.68395219530377, 70.09961823054722, 69.71432672228131, 67.35458646501813, 60.60230622972761, 58.4739340373448, 57.70950712476458, 59.01676205226353, 60.23942266191755, 60.01542663574219, 62.77098492213658, 59.7334965297154, 58.20411811556135, 60.24111107417515, 64.20566981179374, 65.59999956403459, 63.09133856637137, 56.69107491629464, 57.501575333731516, 58.52878311702183, 60.622581073216026, 56.76036582674299, 49.848700863974436, 47.10268592834473, 48.63894305910383, 46.062676089150564, 45.75445747375488, 45.58142648424421, 50.713848863329204, 52.584331716809956, 56.524773257119314, 51.82072121756417, 50.28179250444685, 50.944772243499756, 59.391964776175364, 55.684242725372314, 57.429182052612305, 58.404591015407014, 53.85741540363857, 53.798671858651296, 54.21311106000628, 61.365843772888184, 59.311066899980815, 55.92518540791103, 53.24055780683245, 53.21827840805054, 52.419513498033794, 45.1491755758013, 43.373883043016704, 44.377293246132986, 46.30592209952218, 44.163247040339876, 44.22798688071114, 47.680567605154856, 42.99898256574358, 46.884342261723106, 51.12982014247349, 49.741827147347585, 46.68892765045166, 47.918209893362864, 47.03997496196202, 47.88344805581229, 52.70569937569754, 60.43396527426583, 56.10318783351353, 58.06034599031721, 54.72693381990705, 57.418506145477295, 57.34636647360665, 57.844882352011545, 57.22050680433001, 56.433081354413716, 56.93104485103062, 59.50187138148716, 52.17268916538784, 55.82129941667829, 56.42013338633946, 55.85937901905605, 50.92727320534842, 54.37156472887312, 54.524216651916504, 52.13135780606951, 52.412832805088584, 58.21542978286743, 48.196259430476594, 10.068525144032069, 0.29590206486838205, 0.8751563365970338, 4.280292264052799, 9.298293011529104, 9.312894650868007, 2.4108950666018893, 0.18312992474862508, 0.30592188292316025, 4.494949042797089, 33.27902248927525, 56.95983471189226, 37.63175971167428, 40.84673636300223, 54.44300610678536, 3.5673176305634633, 0.625270236815725, 0.24186516446726664, 0.16290979832410812, 0.22973985224962234, 0.13946308860821383, 0.17608940468302794, 0.16251201395477566, 0.12076879745083195, 0.14398445242217608, 0.11986611517412321, 0.22497082315385342, 0.11031004187784024, 0.10118054997708116, 0.20985143445432186, 0.1318585973765169, 0.15979893239481108, 0.12370669123317514, 0.1066502614745072, 0.1053966883836048, 0.1478920948824712, 0.18049875593611173, 0.13769413424389704, 0.12295188887843064, 0.07808917547975268, 0.1971221175044775], [0.056185688490846326, 0.03507205358307276, 0.03620829100587538, 0.0537696288499449, 0.038361842411437204, 0.012416837154887617, 0.06728921178728342, 0.02419011777133814, 0.04224485744323049, 0.02273802229735468, 0.04893374369878854, 0.052485399546899965, 0.022154991082581024, 0.025022201872031604, 0.0216267176438123, 0.016950179656435336, 0.04459834258471217, 0.03642220934852958, 0.023509255377575755, 0.07447846672896828, 0.03753250637756927, 0.024243457409154092, 0.07269245399428265, 0.026370744420481578, 0.015215767813580377, 0.08696072907852274, 0.03186824871227145, 0.1519619207829237, 0.02212637217183198, 0.02035947037594659, 0.03733731899410486, 0.048449330763625245, 0.0548939240564193, 2.386110407965524, 37.78024271556309, 40.055638790130615, 23.152245385306223, 49.94688238416399, 43.33875642504011, 7.036988752228873, 0.049503991313810856, 0.04169753413381321, 0.019234606896394064, 1.0379328706434794, 10.313584634235927, 14.642246348517281, 3.7498368195125034, 0.4661727196403912, 0.11490302506302084, 3.7405509863580977, 46.01835353033883, 65.86600439889091, 67.36318138667515, 59.84339618682861, 59.527343477521626, 54.171665055411204, 53.61461755207607, 58.158666474478586, 58.83442047664097, 59.39534160069057, 56.18357501711164, 56.107721533094136, 58.84947027478899, 57.64282873698643, 59.08379132407052, 58.14639595576695, 58.53900391714913, 62.64396490369524, 61.22011225564139, 57.40426581246512, 57.98659781047276, 49.209504808698384, 45.242760862622944, 40.23024007252285, 42.271870953696116, 40.420728410993306, 41.64946174621582, 42.759342670440674, 50.76092985698155, 52.97147492000035, 53.65351356778826, 52.17397805622646, 52.18756873267037, 49.37723779678345, 55.188683305467876, 53.14787231172834, 57.71159158434187, 54.47538818631853, 59.79180581229073, 41.88587072917393, 35.812335695539204, 64.58878653390067, 53.14358874729702, 58.006678104400635, 56.85440969467163, 57.65127774647304, 53.31653635842459, 52.496082646506174, 45.59575366973877, 42.6504157611302, 39.56255987712315, 42.23991618837629, 40.796844823019846, 41.84832613808768, 43.370770250047954, 45.994684491838726, 47.968980380467, 48.95125068937029, 44.577411787850515, 40.75708375658308, 41.963850361960276, 40.48836217607771, 46.45141737801688, 56.030440194266184, 56.2869051524571, 58.6428655896868, 53.048745836530415, 55.29072107587542, 56.82419892719814, 55.243410791669575, 54.29858432497297, 57.31464099884033, 53.68563856397356, 51.2939852305821, 55.8837776184082, 54.85643434524536, 52.257349491119385, 51.45913348879133, 49.412642342703684, 49.06158460889544, 47.6931403705052, 52.70280545098441, 52.220871448516846, 47.07158579145159, 12.379459517342703, 0.04442451209095972, 0.038816908707043955, 3.2765233601842607, 4.92757385117667, 2.7056033440998624, 0.7817968662296022, 0.019256326802341, 0.20254051818379334, 3.366110610110419, 22.66381655420576, 48.79171657562256, 26.22471969468253, 27.324477093560354, 44.078319208962576, 8.115947587149483, 0.3788772353104183, 0.07634697575122118, 0.10599056258797646, 0.09077332235340561, 0.025895052356645465, 0.0445911976109658, 0.043009373026766946, 0.013818037413459803, 0.031747835887862105, 0.11249647169773068, 0.0757907195282834, 0.03342174445944173, 0.04207565116563013, 0.03330040882740702, 0.031198724638670683, 0.0799324701407126, 0.06018932669290474, 0.03617185028269887, 0.04757954725729568, 0.04375258261071784, 0.02639086976913469, 0.01595229043492249, 0.03248605823942593, 0.09603720703827483, 0.030441489735884324, 0.04776072967797518, 0.044733703535582335, 0.05296050976695759, 0.041471212171018124, 0.0519368650524744, 0.04628843082381146, 0.00981075971919511, 0.026231671883059398, 0.017455971533698694, 0.04528315405228308, 0.03782210512352841, 0.047504691274038384, 0.0405977883243135, 0.030637036742908613, 0.04082673621763076, 0.035394948042396984, 0.034038281733436246, 0.06407396003071751, 0.07432971828218017, 0.0715234535081046, 0.008511907138329531, 0.036619547688003094, 0.048878130968660116, 0.02327155098984284, 0.032375321324382506, 0.06137918534555605, 0.01650773750485054, 0.06745925266295671, 0.07023894600570202, 0.062277925333806446, 0.018946697702631354, 0.05490349140018225, 0.0030108526240967748, 0.03003067410151873, 5.286565124988556, 49.4944816998073, 36.72216756003243, 25.960943494524273, 72.07235772269112, 44.91474335534232, 6.15620904309409, 0.06243551509188754, 0.11046554853341409, 0.06386665401182004, 0.31956382947308676, 4.206017758165087, 9.920564992087227, 4.76630789893014, 2.4218747402940477, 0.1551402738051755, 5.681171127728053, 51.00311279296875, 69.38651071275983, 69.38306440625871, 63.65219715663365, 62.27908025469099, 56.30600227628435, 55.52712658473423, 60.096296719142366, 60.980288233075825, 60.08368573869978, 58.67551517486572, 60.03420761653355, 60.234399114336284, 58.62465436117989, 60.33390426635742, 59.061821120125906, 59.50774955749512, 61.271174567086355, 62.11630480630057, 58.83028629847935, 58.431279046194895, 51.595550945826936, 48.72341578347342, 40.99552508762905, 42.71948432922363, 42.09352111816406, 42.45023468562535, 43.52644811357771, 50.53150381360735, 52.47985512869698, 55.58643640790667, 53.27560452052525, 53.493993350437705, 50.939755644117085, 56.64146130425589, 56.411976201193674, 58.227908747536794, 56.16217803955078, 57.967420782361714, 45.785432543073384, 40.995007446834016, 64.82114819117955, 54.79326827185494, 58.26566178458077, 56.82887159075056, 58.62976128714425, 55.657968112400596, 51.60094622203282, 45.89097567967006, 44.504341057368684, 41.792730127062114, 45.32669162750244, 42.2902524130685, 44.44174126216343, 44.031856604984824, 48.06580352783203, 48.949180126190186, 48.916124071393696, 45.31971216201782, 42.29789195741926, 44.72463369369507, 41.796409198216026, 47.946353571755544, 57.695252895355225, 58.93981075286865, 59.630725724356516, 53.62899684906006, 56.43135820116316, 56.866221632276265, 56.15732472283499, 54.81485285077776, 58.0534325327192, 55.080961908612935, 54.60314123971121, 55.072641440800254, 57.61115537370954, 52.74487679345267, 51.94870703560965, 50.689530168260845, 52.117239066532676, 48.94749171393258, 55.26686791011265, 53.89331674575806, 52.23249231066023, 15.175362518855504, 0.048671764720763476, 1.248597692166056, 3.1230780397142683, 4.494263342448643, 1.6122908336775643, 0.4603581630757877, 0.07681804190256766, 0.08153728009866816, 4.60326885325568, 24.32845207623073, 51.39602994918823, 34.26513515199934, 22.20118464742388, 51.6889625276838, 13.746990067618233, 0.2438212452190263, 0.07358204733048167, 0.05473577789962292, 0.01870077625582261, 0.03471322051648583, 0.02718513402422624, 0.09219125698187522, 0.01863372851429241, 0.010027698390851063, 0.09982071151690823, 0.08759739170117037, 0.037761406773435216, 0.010186041322802859, 0.011285735394007393, 0.05607441892581327, 0.04393067091171231, 0.02952009007068617, 0.049340637400746346, 0.04002838209271431, 0.03416317628164377, 0.06043695804796048, 0.03177707735449076, 0.014832222501614263, 0.08290118976895298, 0.026671070805085555, 0.013888230164801436, 0.1639915867043393, 0.06625967738883835, 0.08919469027646951, 0.09711606414722544, 0.11432100486542497, 0.10665865495268788, 0.17545297954763683, 0.08239903992840222, 0.10830593441746064, 0.07492108869233302, 0.13886646633701666, 0.07995849874402795, 0.20943584532610007, 0.2093502413481474, 0.1162034102848598, 0.16851757812712873, 0.15837352031043597, 0.13744878955185413, 0.18514003045856953, 0.19304098721061433, 0.11514500422137124, 0.13728515404675687, 0.18179350931729588, 0.08852844352700881, 0.1308203980858837, 0.14340416927422794, 0.10263268277049065, 0.21926732920110226, 0.16418256717068808, 0.13215028601033346, 0.13647661171853542, 0.13426674529910088, 0.20747064506368978, 5.37724997316088, 62.16127354758126, 52.741454805646626, 34.47755895342146, 61.881865637642996, 58.47118255070278, 11.035501599311829, 0.1380413541836398, 0.25980421900749207, 0.14136644718902452, 2.174325406551361, 21.19722727366856, 29.832590920584543, 13.134367397853307, 2.2156096483979906, 0.15145504155329295, 5.1438539028167725, 50.015099797930034, 68.61904743739537, 73.63962813786098, 62.782234055655344, 63.513740403311594, 59.00658294132778, 58.84724685123989, 61.81362737928118, 64.8366287776402, 63.26011725834438, 60.04737445286342, 59.87639318193708, 63.872406414576936, 61.755158288138254, 62.79444898877825, 60.76490102495466, 59.06640693119594, 61.85656029837472, 65.39557661328996, 62.06319972446987, 62.615393911089214, 54.01152644838606, 51.42659854888916, 44.29774679456438, 45.18172441210066, 43.213511671338765, 46.03016546794346, 47.831687450408936, 53.81556292942592, 56.32276133128575, 60.39347812107631, 57.14773832048689, 58.759150641305105, 54.39523376737322, 60.48281805855887, 58.52692099979946, 60.347738129752024, 58.18727568217686, 61.636684553963796, 44.99535982949393, 40.222725595746724, 68.13475104740688, 57.682965006147114, 61.03586687360491, 59.93350737435477, 62.013124057224815, 59.00328949519566, 57.679164341517854, 51.04892226627895, 47.845097473689485, 43.879211630140034, 48.685655798230854, 44.70720761162894, 46.802860736846924, 47.78211900166103, 50.9715575490679, 52.258575848170686, 51.44842284066336, 47.99916335514614, 44.479362283434185, 47.38892044339861, 42.17722954068865, 49.90105554035732, 59.162750652858186, 62.09720420837402, 62.55664689200265, 54.70881986618042, 58.54588263375418, 58.92690099988665, 57.63402884347098, 57.33161892209734, 60.78666973114014, 56.44793660300118, 53.63251611164638, 57.729656900678364, 58.394946915762766, 54.837288584027974, 55.97486850193569, 52.94545044217791, 52.8147999899728, 51.1901478767395, 57.768476486206055, 55.87945931298392, 51.34716326849801, 16.286367314202444, 0.17882025028978074, 1.0971938392945697, 6.968255000455039, 13.354542783328466, 11.296746918133326, 2.328530251979828, 0.14117390609213284, 0.2675685052360807, 6.491383629185813, 36.26429169518607, 56.42406606674194, 37.46402324948992, 36.498282705034526, 59.89324256352016, 15.756732191358294, 0.5426556670239994, 0.27716847296272007, 0.1363813861140183, 0.11514022733483996, 0.10406772326678038, 0.1728193001555545, 0.12401824737233774, 0.11965433082410268, 0.06671443155833653, 0.11926952004432678, 0.1265290712139436, 0.08471904615206377, 0.11753712514681475, 0.17041349996413502, 0.13936670949416502, 0.11242932387228523, 0.12907652237585612, 0.14764172903129033, 0.15847729545618805, 0.13884457679731504, 0.1622357823486839, 0.07435452552246195, 0.09935909735837153, 0.1625244447163173, 0.09169724277619805, 0.08107276181025164], [0.09659007737146956, 0.02498787478543818, 0.04020217526704073, 0.05196443732295718, 0.045907830353826284, 0.04728509698595319, 0.027949093209047402, 0.021411946043372154, 0.036423098229404004, 0.005147227975872478, 0.01952817676854985, 0.07702854382140295, 0.017232385763366307, 0.045995741350842376, 0.047242746222764254, 0.03634560613759926, 0.03324241783203823, 0.02413544650854809, 0.030122310255787203, 0.04977976830144014, 0.06932660817567791, 0.01766106383209782, 0.0571490012641464, 0.009786882071888872, 0.041466387787035534, 0.05207778659782239, 0.03474017192742654, 0.049835187649088244, 0.027776648623070548, 0.05935890839568206, 0.02582612168043852, 0.08266499172896147, 0.04039066211719598, 0.033299516553857496, 14.108074920518057, 51.44546290806362, 35.091272490365164, 25.30980348587036, 47.97587646756853, 48.78352812358311, 10.40912844453539, 0.4207289224224431, 0.005842093211997832, 0.07475606219044753, 0.4554837303502219, 7.2814546057156155, 6.504094924245562, 2.4187521764210294, 1.133423809494291, 0.06839787015425307, 12.956529991967336, 62.71486432211739, 66.32382120404924, 69.55755451747349, 59.3285277230399, 57.55881459372384, 59.901330266680034, 60.25986426217215, 59.30350031171526, 62.79902785164969, 62.063324792044504, 60.136471203395296, 59.06462124415806, 59.13841111319405, 59.7211217880249, 62.63310486929757, 56.37961844035557, 60.26399844033377, 58.72815472739083, 56.35013028553554, 55.647590977805, 49.167350087847026, 43.70647593906948, 41.096701281411306, 41.346829482487266, 41.1879380771092, 44.27669027873448, 50.63153008052281, 53.98467860903059, 55.17377594539097, 56.25574595587594, 52.51709747314453, 52.43535539082119, 49.68091229030064, 54.219208104269846, 52.12834576198033, 58.35330636160714, 53.907532760075156, 60.251679284232004, 37.50391633169991, 27.80349632671901, 63.61387089320591, 54.14983034133911, 60.40075288500105, 54.58695541109358, 59.18082291739327, 53.937281472342356, 53.542675903865266, 47.96212945665632, 42.35238320486886, 40.835636615753174, 42.07841226032802, 41.50801031930106, 45.28826461519514, 44.62413842337472, 50.69575922829764, 52.704261098589214, 52.13818441118513, 49.55730731146676, 44.34460891996111, 42.384897300175254, 44.029858997889924, 42.46186249596732, 50.015613964625764, 53.070372104644775, 55.65626927784511, 56.78116178512573, 54.913892473493306, 55.19698987688337, 58.041648387908936, 55.14863041469029, 55.58224664415632, 56.594936166490825, 54.88898318154471, 50.28464821406773, 54.566201141902376, 56.00536414555141, 52.27410159792219, 51.473370347704204, 50.205744470868794, 52.47349752698626, 53.937205042157856, 45.47840901783535, 15.456642968314034, 0.09886288469923393, 0.07273252827248403, 0.5295680293015071, 3.0511272719928195, 4.711731536047799, 0.33655581197568346, 0.06664640842271702, 0.14209581805127008, 5.314121246337891, 30.396326065063477, 43.191756861550466, 28.974547454289027, 26.855336461748394, 40.750604561397004, 22.442796094076975, 0.037911892269871066, 0.16588798351585865, 0.08170407079160213, 0.05639485030301979, 0.036568942546312294, 0.04261667767007436, 0.026105126798419014, 0.03212951862120202, 0.08265469835272857, 0.03974328881927899, 0.02962222316169313, 0.013796014711260796, 0.10390569588967732, 0.07232006040534802, 0.06683514293815408, 0.06381307688674756, 0.027346252164404308, 0.04018939845263958, 0.06723790775452342, 0.045691910332867076, 0.07070482136415583, 0.015170745318755507, 0.044882485909121375, 0.04722414079255291, 0.07365021974380527, 0.04286594090184995, 0.019990264205262065, 0.05690679818923984, 0.02972321631386876, 0.009349330461450985, 0.028520180511155298, 0.053675058031720776, 0.03244742245546409, 0.049771619095866165, 0.026174931088462472, 0.0209280403131353, 0.03782816444124494, 0.030707492426569973, 0.03931047847228391, 0.03994522762617894, 0.031409579395715675, 0.013551927005339946, 0.04215509404561349, 0.029094234707632234, 0.010556194898007172, 0.013276674186012574, 0.011993775659772967, 0.09858368110976048, 0.07029069108622414, 0.06215642685336726, 0.014074934164195188, 0.03919735989932503, 0.003220335680193135, 0.03526716972036021, 0.08041574992239475, 0.056285042980951924, 0.0248969731453274, 0.025680328253656626, 0.045705732091196945, 0.04012442872460399, 0.1576509890811784, 22.753893000738962, 60.36726256779262, 28.43409398623875, 31.15768882206508, 66.77068764822823, 48.73863928658621, 9.496616312435695, 0.6468661608440536, 0.04453301662579179, 0.04637366500017898, 0.2447758897074631, 1.569068695817675, 6.574258702141898, 4.492372129644666, 1.928314447402954, 0.19575632150684083, 16.46294014794486, 67.26064682006836, 70.97948251451764, 72.58821283067975, 62.975706645420615, 59.67434651511056, 61.11163697923933, 62.69019821711949, 62.74756949288504, 66.79144886561802, 63.411817278180806, 60.01469012669155, 60.89919580732073, 62.616929462977815, 61.45213345118931, 65.73443331037248, 57.692355496542795, 61.772883142743794, 60.65858663831438, 59.80726555415562, 59.736206327165874, 52.3843104498727, 44.73140818732125, 42.52911063602993, 43.99413136073521, 42.63633176258632, 45.79389892305647, 51.16667686189924, 56.462826592581614, 57.14053303854806, 58.939616203308105, 54.20560353142874, 53.5109851700919, 51.03531769343785, 55.61307232720511, 51.941216877528596, 57.984673159463064, 54.51073019845145, 60.300796100071494, 37.074792112622944, 28.562052011489868, 65.35438074384416, 54.61403948920113, 61.16634014674595, 55.46465880530221, 60.213992255074636, 55.64393275124686, 55.330489090510774, 48.51907968521118, 44.38489804949079, 43.543811661856516, 42.676902294158936, 43.6365180015564, 46.18329334259033, 45.601941040584016, 52.386235100882395, 53.5027619770595, 53.30743769236973, 51.8203182220459, 46.694170066288535, 43.480628217969624, 46.439386572156636, 44.827713693891255, 51.99072626658848, 53.9715256690979, 57.70246859959194, 58.320538657052175, 56.71172843660627, 56.941564423697336, 59.09063529968262, 58.33737414223807, 57.2742406981332, 57.374857561928884, 56.602516651153564, 52.60834469114031, 54.767306327819824, 57.652382510049, 55.18724850245884, 52.489926542554585, 52.39610154288155, 55.00667871747698, 55.716725553785054, 47.92169788905552, 19.354990584509714, 0.5023577436804771, 0.330613690827574, 2.7733854097979407, 2.65084393961089, 0.4394543990492821, 0.1837049831769296, 0.016040252322064977, 0.12351002464337008, 5.717802899224417, 30.994864736284526, 49.18779516220093, 41.41115937914167, 23.929219007492065, 45.97888428824288, 32.87475545065743, 0.31804825365543365, 0.1418230469737734, 0.04185019094230873, 0.056725965214094946, 0.03814353733988745, 0.04104589285062892, 0.1137788011027234, 0.035710571998996396, 0.09611882801566805, 0.03851567647819008, 0.020911205859322633, 0.023004754413185374, 0.04265174096716302, 0.00940528161091996, 0.03716692528022187, 0.0928161402365991, 0.0807801503688097, 0.03639579737292869, 0.05639370018616319, 0.03790233849680849, 0.08446290596787419, 0.04143271209406001, 0.024032426233004247, 0.008472766693947571, 0.023623629240319133, 0.05665804385872824, 0.07134314639759914, 0.1727152807371957, 0.0862665470423443, 0.08855532029909746, 0.2125564143061638, 0.09232723539961235, 0.08427364898047277, 0.11321146440293108, 0.1358840742281505, 0.1423595103302172, 0.13588138722947665, 0.07273889293095895, 0.11328910916511502, 0.13367698980229242, 0.23106340265699796, 0.08881652913987637, 0.09987129630254847, 0.1331681971039091, 0.1397214883140155, 0.14343992806971073, 0.10566840773182255, 0.10328655982656137, 0.15045245178043842, 0.15260114148259163, 0.15275082630770548, 0.14684679811554296, 0.15131804533302784, 0.11086943971791438, 0.16366871260106564, 0.16012096511466162, 0.18698783059205326, 0.19137246959975787, 0.20588625222444534, 0.14064812287688255, 0.19576677094612802, 24.585733447756084, 72.38615226745605, 45.77787985120501, 35.23812961578369, 57.78175796781267, 64.07650974818638, 15.555463722773961, 1.077327202473368, 0.1875133966760976, 0.18473385939640657, 1.6175005712679453, 23.28343779700143, 18.57316885675703, 8.212354711123876, 4.499461463519505, 0.2608160504273006, 16.772532769611903, 69.43006202152797, 71.30561011178153, 76.04020990644182, 66.24570955548967, 61.74700110299246, 64.09834793635777, 65.41439233507428, 63.29736655099051, 67.88162122453961, 67.07275363377163, 64.4969869341169, 63.33136408669608, 64.75004727499825, 64.82669980185372, 66.96611962999616, 58.63044221060616, 62.99475860595703, 61.35585921151297, 59.674304825919016, 61.634933607918875, 54.82898896081107, 46.35305520466396, 45.999152183532715, 46.33838408333914, 46.87196752003261, 49.94699355534145, 56.09728186471121, 59.56503050667899, 61.01905918121338, 61.3457704271589, 58.9214049748012, 56.73764521735055, 54.40811225346157, 58.392424719674246, 56.90084450585501, 60.73104245322091, 56.237110887254985, 59.755536215645925, 39.95420898709978, 31.907090255192347, 65.46591322762626, 57.60962677001953, 63.47560868944441, 57.530344349997385, 62.08825492858887, 58.00079298019409, 57.610804489680696, 51.26628623689924, 46.652460030147004, 45.513462679726736, 45.32843909944807, 44.92438050678798, 49.29036099570138, 48.84401914051601, 56.704655170440674, 55.87080880573818, 57.44457926068987, 54.85091747556414, 49.05418477739607, 47.66178662436349, 51.78784234183175, 46.63437386921474, 52.85073259898594, 54.053267751421245, 59.117128780909944, 59.89224897112165, 57.09258699417114, 59.24435029711042, 62.75549043927874, 59.2832602092198, 58.96904182434082, 59.05558858598982, 57.522694383348735, 51.537675925663535, 56.73890631539481, 59.33149460383824, 55.7323659488133, 54.24904714311872, 54.7031466620309, 56.43556533540998, 57.47766310828072, 50.538024697984966, 18.67362070083618, 0.34599640539714266, 0.18113210052251816, 2.2297175313745226, 6.951130296502795, 14.45236771447318, 1.9885299248354775, 0.20863073638507298, 0.2621140336351735, 8.629550610269819, 43.04475729806082, 51.78548342841012, 40.19221952983311, 38.13530608585903, 53.51481362751552, 38.713385786329, 0.3558046833745071, 0.3331522260393415, 0.09613284654915333, 0.2020453911806856, 0.24517342980418885, 0.13959863276353904, 0.16976965165563992, 0.07967629602977208, 0.21512979907648905, 0.12577121545161518, 0.22847715286271914, 0.07480505920414414, 0.19910183841628687, 0.19794507191649505, 0.2591036451714379, 0.2918998481971877, 0.1780749067131962, 0.11190926749259233, 0.0961808054042714, 0.14739753784877913, 0.17961735251758779, 0.17502766022724764, 0.06508677532630307, 0.18370407394000463, 0.19538630279047148, 0.14553846046328545, 0.14539824798703194], [0.017275796737521887, 0.034096683242491314, 0.08631625651781048, 0.04227555436747415, 0.03136237032179322, 0.05951796378940344, 0.10550965767885957, 0.13494525317634853, 0.04539898337264146, 0.09216110967099667, 0.04797071251752121, 0.04227948308523212, 0.0529721025377512, 0.019132563711277077, 0.026406279299408197, 0.0696321999920266, 0.06595965634499278, 0.035668414618287764, 0.053903734511030574, 0.06831847477172102, 0.002921375059356381, 0.021958270209974477, 0.060932607523032596, 0.049326679935412746, 0.042156342550047805, 0.03062556271574327, 0.05259993625804782, 0.06465404640351023, 0.05502889145697866, 0.07200556620955467, 0.02940793501745377, 0.02430137715834592, 0.046622965551380596, 0.03617016412317753, 0.258405188364642, 24.240946463176183, 54.23316356113979, 39.41942351205008, 24.6289165019989, 49.13227558135986, 49.91450725282942, 12.330609338624136, 0.7636421461190496, 0.021690537254991274, 0.19566573708185128, 0.8115499754037175, 3.6808268768446784, 4.3931944114821295, 0.44979288429021835, 0.4227790209863867, 0.3757048669670309, 32.86504881722586, 73.40516812460763, 62.891543115888325, 68.26089559282575, 62.617950848170686, 60.99419157845633, 63.304564884730745, 65.71872343335832, 64.83755983625139, 57.65063156400408, 62.37992640904018, 61.74421487535749, 59.92547525678362, 60.160053389413015, 55.714832169669016, 58.36393015725272, 58.50171988351004, 61.51756463732038, 58.625738280160085, 55.223156792776926, 49.42538186482021, 43.21288285936628, 39.82546928950718, 40.581999574388774, 41.20420033591134, 50.7977031980242, 52.98762600762503, 53.12641280038016, 55.10991505214146, 55.412915570395334, 54.236846106392996, 57.39761986051287, 53.10689531053816, 52.51343577248709, 53.708185468401226, 57.032630988529746, 57.87110832759312, 57.329169682094026, 46.24195350919451, 31.92801128114973, 58.359177589416504, 56.334542001996724, 60.687505040849956, 58.70425987243652, 60.23119599478585, 56.131724085126606, 55.568186964307515, 47.78589187349592, 45.278082030160085, 42.850763593401226, 43.9787723677499, 43.817299706595286, 44.75288159506661, 44.59257970537458, 51.9223073550633, 51.59790291104998, 53.81750842503139, 51.24809237888881, 52.12353413445609, 45.490061146872385, 41.86607183728899, 42.45290279388428, 46.79036092758179, 52.895162854875835, 54.8725437436785, 54.266455854688374, 57.83021123068673, 57.08641699382237, 56.00723321097237, 55.8874636377607, 58.056430680411204, 56.00404051371983, 54.85438462666103, 57.50555317742484, 56.42089768818447, 52.24093437194824, 53.37759712764195, 53.56566054480416, 53.503925800323486, 52.96910211018154, 43.54469060897827, 13.27385335309165, 0.09169273051832404, 0.11221177875995636, 0.7370785857949937, 3.7584643108504157, 1.3186206604753221, 1.9739812655108315, 0.028024719329550862, 0.0034630521092497346, 4.878796194280897, 33.609850542885916, 40.175981589726035, 21.404200213296072, 28.206613438470022, 34.71998855045864, 22.9618821144104, 0.6103396979825837, 0.10049350612929889, 0.028573720316801752, 0.0714737983154399, 0.05855168242539678, 0.12463139875658921, 0.05755274995629277, 0.062004122883081436, 0.12602103847478116, 0.022768279870173762, 0.019008210294746926, 0.03711337190387504, 0.026573577197268605, 0.015491972278271402, 0.06856308664594378, 0.045041615941694806, 0.012351640117620783, 0.029775039425918033, 0.026259366289845536, 0.06398416270634957, 0.04296498326584697, 0.03726490234423961, 0.029665150679647923, 0.03737940852131162, 0.08835608884692192, 0.03799294327784862, 0.06472752496067967, 0.023003670453493084, 0.02938752807676792, 0.07854553099189486, 0.023659559365894114, 0.037699432777506967, 0.028646839250411307, 0.10525388390358005, 0.047547472906964164, 0.06800339025046144, 0.03644250772361245, 0.09088230186275073, 0.016640067100524902, 0.05685705817969782, 0.029596856130020957, 0.021340250336964215, 0.05325799648250852, 0.06341199483722448, 0.03397799050435424, 0.008137607714161277, 0.03770101376410041, 0.0488957084183182, 0.03773962240666151, 0.02241845944497202, 0.05216048305322017, 0.035391470550426414, 0.03360523729185973, 0.02296192358647074, 0.06910537861819778, 0.07881999162158795, 0.02942929869251592, 0.025628099716933708, 0.04047545863847647, 0.02163477015814611, 0.03071855254737394, 0.05905427331370967, 1.117164807660239, 37.94802434103829, 58.402979033333914, 29.30204037257603, 33.405142715999055, 68.24936158316476, 52.105343750544954, 14.599662576402936, 1.4923674230064665, 0.04518207269055503, 0.03769277295629893, 0.28671836480498314, 1.180583404643195, 7.746939182281494, 3.7441462448665073, 0.5189071585025106, 0.5447541315640722, 38.87564359392439, 73.88747038160051, 64.9403097970145, 71.78670338221959, 65.45254489353725, 63.3803836277553, 65.39962046486991, 66.87403515407017, 64.74256406511579, 61.77762876238142, 63.23060825892857, 63.950267927987234, 62.72637053898403, 61.68724659511021, 58.67120729173933, 58.94835703713553, 60.528863770621165, 63.25242560250418, 62.099462372916086, 57.237363134111675, 51.556352683476035, 45.69880935123989, 42.88742923736572, 42.449230670928955, 42.81914234161377, 51.300478322165354, 55.573040281023296, 57.27069016865322, 55.28580869947161, 57.17940820966448, 56.76040751593453, 58.507563318525044, 54.22481530053275, 55.38694320406233, 55.032751832689556, 59.219475746154785, 58.56263474055699, 59.50986875806536, 46.132769516536165, 34.47425855909075, 59.98846762520926, 57.3289612361363, 62.65299756186349, 61.182772636413574, 61.3424630846296, 58.626037052699495, 57.9259226662772, 50.71395308630807, 47.57243626458304, 45.58655078070504, 47.222316537584575, 45.075687953404014, 45.844231673649375, 47.511309487479075, 53.765810353415354, 54.598590169634136, 55.96673910958426, 53.779512201036724, 52.14570236206055, 45.741509505680625, 44.175038133348735, 43.88486398969378, 48.879152706691194, 55.27071026393345, 58.340236800057546, 56.779706137520925, 59.18904263632638, 58.51226030077253, 56.54671914236886, 56.82613400050572, 58.88653891427176, 58.514706066676546, 56.74593094417027, 57.66140127182007, 57.71938746316092, 52.835418769291465, 53.715251786368235, 55.474021502903526, 55.77152599607195, 54.05251734597342, 46.33390596934727, 18.010423830577306, 0.41307941717760904, 0.1177307383290359, 0.9003462706293378, 2.604012646845409, 0.8807350886719567, 0.23709123634866305, 0.04254180133076651, 0.0373702822253108, 5.565346394266401, 33.79505130222866, 44.20525584902082, 26.69414520263672, 24.89676434653146, 40.51902805055891, 36.05503627232143, 3.2914674154349735, 0.288623148309333, 0.02053134499250778, 0.17286230570503644, 0.025405772629060915, 0.09104464815131255, 0.028454377881384323, 0.08443545922636986, 0.024452205314966183, 0.008542813560260194, 0.09103358803050858, 0.042528417227523665, 0.05500814524878349, 0.05167604636933122, 0.0761037820151874, 0.01423129322938621, 0.021259815099516084, 0.027793304961440817, 0.05009682735960398, 0.014582911772387368, 0.07187404576689005, 0.023319536986361657, 0.03879066975787282, 0.03663871630227991, 0.11787684048925128, 0.021031401552526013, 0.03520466307444232, 0.05573873747406261, 0.1139861885458231, 0.18405155172305449, 0.15349635987409524, 0.11050232513142483, 0.07217729663742439, 0.12219688296318054, 0.20684420796377317, 0.2516275463359696, 0.08205403879817043, 0.2607946901449135, 0.2041880012090717, 0.20678548754325934, 0.13490242404597147, 0.09092069337410585, 0.19552984008831636, 0.1712879958961691, 0.1362294214112418, 0.11374555288680963, 0.1444373202643224, 0.1205240362989051, 0.09920359070279769, 0.15568927648876393, 0.1585442397211279, 0.10122485152844872, 0.1310070902109146, 0.1092250304562705, 0.1774617824703455, 0.13136728374021395, 0.16459602569895132, 0.15387614949473313, 0.10303836528744016, 0.13374586110668524, 0.15239238339875424, 0.14201056691152708, 0.8069551533886364, 40.849220343998496, 73.5097176688058, 50.01394292286464, 36.5192106791905, 58.613141196114675, 64.64462920597622, 19.40205420766558, 1.4263326121228082, 0.21528225232447895, 0.5590506472757885, 2.3283181147915974, 11.80067457471575, 12.93005474976131, 4.942065187862941, 0.9969142888273511, 0.7713960643325533, 37.328634125845774, 79.32419259207589, 66.0669115611485, 71.49776254381452, 68.98653071267265, 66.56068529401506, 67.69411713736397, 69.66890634809221, 69.00953619820731, 63.41924490247454, 65.12813350132534, 66.93913977486747, 66.02849497113908, 63.51130158560616, 57.60735470908028, 58.59711170196533, 63.3063644681658, 65.76339340209961, 64.48308358873639, 61.50277887071882, 55.67481401988438, 48.81019530977522, 44.922778947012766, 43.82709666660854, 44.046017033713206, 55.74180160249983, 58.5359536579677, 59.08629962376186, 57.96042742047991, 59.72322709219796, 57.819385937282014, 65.15274402073452, 59.19593524932861, 57.625124726976665, 56.92608036313738, 62.76803888593401, 61.08719321659633, 60.07477119990757, 48.3027023587908, 41.25370625087193, 65.3552770614624, 58.351520674569265, 67.55584798540387, 63.92011969430106, 64.08214473724365, 60.951216970171245, 61.85983289991106, 54.09012794494629, 50.734523228236604, 46.60766151973179, 50.48323815209525, 47.805986063820974, 48.62209367752075, 48.917166301182334, 56.02800832475935, 56.75391442435128, 58.00185605457851, 56.8923225402832, 55.34525053841727, 48.67205817358834, 44.87793179920742, 46.21108961105347, 50.88401024682181, 59.264889172145296, 60.35369273594448, 58.5299643107823, 61.27261979239327, 60.92198589869908, 58.06474767412458, 59.923772948128835, 61.767678941999165, 59.53130395071847, 58.52683762141636, 59.79707949502127, 58.01243468693325, 50.52888434273856, 57.00681495666504, 54.90579087393624, 57.20226430892944, 52.95262793132237, 50.778498377118794, 16.515866313661846, 0.40894100495747154, 0.26254259635295185, 2.249652998788016, 5.992018333503178, 7.182904396738325, 4.4386955584798535, 0.1271533098603998, 0.18928317885313714, 8.614886437143598, 46.50338295527867, 50.76067624773298, 31.16970225742885, 38.44853435243879, 47.43288516998291, 46.66291012082781, 3.013572475739888, 0.3705068544617721, 0.06945489879165377, 0.22434955649077892, 0.2003216136779104, 0.26314673679215567, 0.11096103516008173, 0.19577263348868915, 0.1524452277060066, 0.11874331613736493, 0.22971208659665926, 0.10671536690954651, 0.1601646491991622, 0.1749113593250513, 0.16709602012165956, 0.13259568996727467, 0.12029182804482323, 0.11795055653367724, 0.12145643840943064, 0.14347301343722002, 0.1157459555459874, 0.14442449595246995, 0.1925985145249537, 0.12643888033926487, 0.22040152762617382, 0.24590366919125828, 0.17438018854175294, 0.147457751046334], [0.04486599411549313, 0.03229330340400338, 0.07563980655478579, 0.01553111696349723, 0.022032473103276322, 0.02386681449466518, 0.031160289022539343, 0.027589854717786823, 0.11981751849608761, 0.05549532321414777, 0.017397537794230238, 0.019233041176838533, 0.05023239865632994, 0.02005042990536562, 0.026878521012674485, 0.03684297909161874, 0.03630563024697559, 0.05829731321760586, 0.07399131251232964, 0.046780277110104046, 0.12083004202161517, 0.08342965998287712, 0.01518827018194965, 0.01580416624035154, 0.08262324146926403, 0.05163590423762798, 0.03145742289988058, 0.03899035243583577, 0.052248543327940364, 0.09357483059700046, 0.033376177440264394, 0.0621335127257875, 0.03475970695061343, 0.026699872920289636, 0.03990913974121213, 1.4897965895278114, 31.837198325565883, 45.23646926879883, 35.499263763427734, 22.105066742215836, 46.39026280811855, 60.327636991228374, 22.3305983202798, 1.990657159260341, 0.061659114967499457, 0.13958480421985897, 0.7534567383783204, 6.232462048530579, 2.981114617415837, 0.0849679938650557, 0.21461804796542439, 1.1314478069543839, 45.951866218021934, 77.08901963915143, 62.33050387246268, 68.7078662599836, 68.66746943337577, 63.38710948399135, 63.74619238717215, 63.87714508601597, 67.69673660823277, 63.2498756136213, 61.03066962105887, 60.88732133592878, 60.6317526953561, 57.863232544490266, 60.58413669041225, 58.5899133682251, 57.95899609157017, 56.19407374518258, 54.720607485089985, 48.300173214503694, 44.0158931187221, 41.61918149675642, 42.838784899030415, 49.9465697152274, 57.471242972782676, 56.36780997685024, 60.361321857997346, 55.14643825803484, 58.55902167728969, 55.517996651785715, 59.267668451581685, 53.25348840441023, 55.32792867933001, 51.79185492651803, 58.32648631504604, 54.78809533800398, 63.055534499032156, 39.39836004802159, 30.9525363104684, 64.57456357138497, 54.95381334849766, 58.961704526628765, 53.938129152570454, 54.260574204581125, 49.42493718011038, 49.38608285358974, 45.70636551720755, 44.313414982386995, 42.541429792131694, 45.76641879762922, 43.661660058157786, 44.961751392909456, 46.33621971947806, 51.29063272476196, 54.17835964475359, 57.639625617435996, 55.50571918487549, 56.107308115277974, 53.71458823340279, 48.44546352113996, 43.4094751902989, 42.824231897081646, 47.56372322354998, 49.95493534633091, 51.600755146571565, 55.083970478602815, 55.602007320949006, 57.422296387808665, 54.79673194885254, 52.669242177690776, 57.49871267591204, 57.897216183798655, 56.34409230095999, 52.20070777620588, 52.90419551304409, 55.175648484911235, 52.57861334936959, 52.55274173191616, 35.206438882010325, 7.39656845160893, 0.15444915874728135, 0.03417213972924011, 0.41585077132497517, 1.155459912759917, 5.79714264188494, 0.45262517088225906, 0.07404450965779168, 0.02054242546936231, 5.513204072202955, 36.43241378239223, 43.05314724785941, 50.711114747183665, 55.608455249241416, 25.5485748563494, 32.72699505942208, 3.4819244870117734, 0.445819084665605, 0.08803001205836024, 0.11171898591731276, 0.04213940292330725, 0.082511500322393, 0.08277598648731198, 0.0463336450047791, 0.055419700486319404, 0.17197384552231856, 0.027964550236772214, 0.07164582051336765, 0.06798766180872917, 0.060278703325561116, 0.0684490656214101, 0.02001147181726992, 0.09688753355294466, 0.06139897142669984, 0.1116740329723273, 0.06964361295104027, 0.03718552053240793, 0.03712510716702257, 0.05280426011553832, 0.06040885991283825, 0.03830885561183095, 0.047957491262682846, 0.05387039469288928, 0.04995289651144828, 0.061836348314370425, 0.035844623377280574, 0.027818911176707064, 0.052813138746257336, 0.032576055731624365, 0.0399294347236199, 0.07108705371086087, 0.07255292683839798, 0.0705068384164146, 0.09151769562491349, 0.04438189330643841, 0.008843736207511808, 0.052886227145791054, 0.02970223261841706, 0.04484996372567756, 0.06785565960620131, 0.05013861833140254, 0.059116976734782965, 0.052847428513424735, 0.05287839685167585, 0.032272465593580685, 0.04729613335803151, 0.04273824400401541, 0.016048421883689504, 0.009590443639483835, 0.014938041734110032, 0.05087514095274465, 0.02756029603603695, 0.06542989012918302, 0.017949783875207816, 0.05264837348035403, 0.02131383157601314, 0.028259382184062685, 0.02237419012401785, 0.046879445003079515, 0.06045702232846192, 4.0920243092945645, 45.6927227292742, 50.93711532865252, 26.398865870067052, 30.86801494870867, 69.13886301858085, 57.09903492246355, 21.87150652068002, 2.8701855412551334, 0.014714661220620786, 0.12341612896748952, 0.3035534428698676, 3.3378746509552, 6.088566158499036, 1.859652566058295, 0.1402756885758468, 2.4889876076153348, 53.607940333230154, 79.66832297188895, 66.8102228982108, 71.7764617374965, 69.44047737121582, 66.44936125619071, 66.20016411372593, 67.38897309984479, 70.76878534044538, 64.50000245230538, 63.32174777984619, 65.32740783691406, 59.47201497214181, 58.9951878956386, 60.136547633579795, 61.57160772596087, 60.748808997017996, 58.57990796225411, 57.254035336630686, 51.89311102458409, 47.30479512895857, 44.71937043326241, 44.336628913879395, 50.38388238634382, 57.99267053604126, 57.6043496131897, 60.57099764687674, 57.79803759711129, 60.935423714774, 58.05061156409127, 58.59108761378697, 54.39905527659825, 56.744273798806326, 52.59675162179129, 59.37945801871163, 56.83331148965018, 62.52527577536446, 41.91274288722447, 33.05768067496163, 62.77561937059675, 57.19998529979161, 60.849696840558735, 57.81341743469238, 58.15927791595459, 51.66863904680525, 53.05802168164934, 48.62321581159319, 48.46206276757376, 46.330556937626426, 45.58936480113438, 44.37362459727696, 46.14094059807913, 48.74408320018223, 53.40425736563546, 55.705570220947266, 57.56882347379412, 57.23966646194458, 58.83551134381975, 53.194369656699045, 48.723367146083284, 43.51702288218907, 45.163071972983225, 48.788377966199604, 51.66738837105887, 54.968078000204905, 57.626298972538535, 58.1243771144322, 58.25797012874058, 57.76301520211356, 55.81671360560826, 59.8769976752145, 60.331257002694265, 58.24495962687901, 53.68212972368513, 54.82337481634957, 57.09391757420131, 53.661167008536204, 54.74858440671648, 39.546905585697715, 11.659248335020882, 0.5166449227503368, 0.24562555125781468, 0.41839525050350596, 1.7735653626067298, 0.8842341580561229, 0.2129029014280864, 0.15529056931180613, 0.03766546192179833, 5.532955629484994, 35.916075774601524, 50.48989800044468, 52.801521982465474, 46.12280232565743, 28.14063855579921, 41.99852534702846, 9.05739722933088, 0.522133891071592, 0.08179958816617727, 0.12136038499219076, 0.10318826045840979, 0.0394213782357318, 0.06388570727514369, 0.05022827994876674, 0.031542273703962564, 0.06567999813705683, 0.02878324853788529, 0.030488203479243175, 0.0594409704208374, 0.00932062673382461, 0.11090700341654675, 0.03689407277852297, 0.03141076343932322, 0.06257944594004325, 0.012943560989307505, 0.05739922462297337, 0.08793722239456006, 0.023643769856010164, 0.06939833611249924, 0.041268852672406604, 0.05987826588430575, 0.05607046985200473, 0.0439072309194931, 0.03993755678779312, 0.1011297752016357, 0.15166104478495462, 0.08458390233239957, 0.08804793216820274, 0.19396789318748883, 0.21465102476733072, 0.19123475413237298, 0.2825608178973198, 0.10102316377950565, 0.20420096122792789, 0.15604132759783948, 0.10099763050675392, 0.10149971249380282, 0.13643275121492998, 0.13146301146064485, 0.19727997189121588, 0.11009547553424325, 0.14277254816676888, 0.0976904101137604, 0.14448564552835055, 0.17600058444908687, 0.26292094747935024, 0.14310059270688466, 0.15678304779742444, 0.04554860373692853, 0.15835302855287278, 0.14669433129685266, 0.2101402732410601, 0.196662912145257, 0.19578829407691956, 0.3051695232944829, 0.07720279839954206, 0.10262120195797511, 0.20854319179696695, 0.17276680868651184, 0.18466815006520065, 2.984119496175221, 49.024658407483784, 64.31133801596505, 46.9208585194179, 33.94371495928083, 57.44059099469866, 70.34010928017753, 32.081597736903596, 3.315322969641004, 0.15549191779323987, 0.19508967442171915, 2.7440247109958102, 15.353926011494227, 13.749382853507996, 1.7392905503511429, 0.2907685674726963, 2.3228746354579926, 52.28656319209507, 81.97970376695905, 69.45931393759591, 74.63631248474121, 73.41116441999162, 68.21311977931431, 67.35457951681954, 71.07668086460659, 75.33462033952985, 67.50793320792062, 63.98013823372977, 64.94966207231793, 60.39956474304199, 61.129271507263184, 61.99703202928816, 62.40252889905657, 61.350495202200754, 59.57621710641043, 59.630656242370605, 53.06312165941511, 50.125051566532676, 48.07656281335013, 47.84950957979475, 54.92489494596209, 62.34556756700788, 60.289102281842915, 65.0997987474714, 59.67375591823033, 64.32547065189907, 60.73516273498535, 60.78054141998291, 56.95606184005737, 59.174798829214915, 56.729984828404014, 62.90430695669991, 58.21404709134783, 64.95045416695731, 44.880374091012136, 36.60776547023228, 64.39914934975761, 59.917915616716655, 62.836249351501465, 59.180954933166504, 60.04497732434954, 55.034113679613384, 54.4412065233503, 50.6753454208374, 49.16333750316075, 48.02754674639021, 48.57819495882307, 47.20948321478707, 48.82670422962734, 51.67288439614432, 55.731233392442974, 58.98229898725237, 60.350190843854634, 60.140202386038645, 63.49911444527762, 58.708136967250276, 53.401888029915945, 47.74565832955496, 46.04156051363264, 52.25843688419887, 53.658620493752615, 56.15683140073504, 59.19067546299526, 61.72469738551548, 60.77835273742676, 58.93399511064802, 56.691029753003804, 61.72488498687744, 61.97716018131801, 59.27113560267857, 54.38152844565255, 59.13823046003069, 55.2858156476702, 53.882355962480815, 54.17991951533726, 40.98958090373448, 9.776053752217974, 0.5505634769797325, 0.22250533902219363, 1.1192330909626824, 6.121521030153547, 13.663683772087097, 0.6563787875430924, 0.38981329277157784, 0.09637271546359573, 9.975224733352661, 50.447830132075715, 52.82851573399135, 61.63656643458775, 60.59068884168352, 35.83865547180176, 53.40035595212664, 11.27588060923985, 0.6680637576750347, 0.21299466650400842, 0.31204354443720406, 0.11746936663985252, 0.19385311220373425, 0.08479611415948186, 0.13801822971020425, 0.1669929370816265, 0.3414290233382157, 0.13671431610626833, 0.2399248257279396, 0.17930063951228345, 0.10331057996622153, 0.1549745077001197, 0.14865263764347347, 0.202514489580478, 0.13723251330001013, 0.12342478707432747, 0.1327499888305153, 0.15150138549506664, 0.07695599485720907, 0.07351564589355673, 0.12287938062633787, 0.1720763043101345, 0.161351759784988, 0.1266086090888296, 0.1350694793675627, 0.1169729232788086], [0.030278525980455533, 0.0523987811590944, 0.07131293123321873, 0.008221841899545064, 0.09809350741228887, 0.0429360471399767, 0.044884131356541596, 0.03813604631328157, 0.04841195705479809, 0.050387457478791475, 0.04071701031976512, 0.08005567852939878, 0.023716585145198872, 0.1291303573442357, 0.022801251583067433, 0.05688895271824939, 0.09378280836556639, 0.05391648079135588, 0.04739238355042679, 0.05310304622564997, 0.028660806893770183, 0.041639471892267466, 0.039523005818149874, 0.06825941508369786, 0.04642488082338657, 0.07829238993248769, 0.06831158764128174, 0.020756128377148082, 0.10561473561184746, 0.05139426434678691, 0.03475115740937846, 0.015870879803385054, 0.0864015890817557, 0.04570297384634614, 0.029862516160522188, 0.029999332569007362, 2.6191045684473853, 28.005218165261404, 52.621674810137065, 35.11823150089809, 22.54107662609645, 42.55895662307739, 60.81473350524902, 33.85301317487444, 3.774622346673693, 0.08100838919303247, 0.12733841421348707, 1.2157571400914873, 4.985126214368003, 1.3973742574453354, 0.03946558139952166, 0.06796060183218547, 1.654669525367873, 41.90887968880789, 78.01766027723039, 67.99816335950578, 65.94235815320695, 71.450973374503, 69.24858897072929, 66.08893040248326, 63.36463900974819, 65.37396076747349, 65.92495291573661, 58.230232919965474, 59.359078952244346, 60.82778222220284, 60.940523692539756, 58.022526945386616, 63.238973890032085, 61.009915351867676, 58.6103549684797, 50.84789003644671, 43.41621841703142, 42.19415882655552, 44.833769048963276, 52.87193850108555, 58.20756094796317, 55.210625716618125, 58.442014013017925, 56.39887537275042, 60.02150630950928, 57.611645221710205, 59.09737505231585, 57.58334868294852, 59.188570158822195, 55.5143974849156, 62.441070556640625, 60.053669520786826, 66.19643987928117, 39.24026421138218, 35.32179634911673, 71.31098106929234, 54.82295445033482, 62.64395100729806, 57.76960209437779, 57.17763294492449, 50.520025389535085, 53.95379039219448, 49.24653870718819, 49.26039341517857, 43.61252587182181, 46.43723610469273, 44.51261636189052, 46.855229309626985, 46.56824786322457, 52.23063019343785, 52.334484917776926, 53.441565717969624, 53.91199697766985, 55.65639781951904, 52.41421897070748, 49.657642773219514, 44.93523359298706, 46.0242977142334, 49.25669002532959, 53.79600027629307, 52.99806220190865, 54.97186129433768, 56.146839891161235, 52.88376433508736, 56.16863291604178, 59.663542066301616, 54.71547624043056, 56.34863294873919, 58.68754250662667, 55.80908795765468, 47.73827934265137, 52.94464097704206, 49.51256091254098, 24.50393056869507, 3.771348876612527, 0.08485942826207195, 0.14169660875839846, 0.08243196244750704, 0.4683724216052464, 0.30800156561391695, 0.27647121037755695, 0.13933055714837142, 0.11257685095603977, 9.110325132097516, 40.9742705481393, 46.51746695382254, 24.44434802872794, 41.25018351418631, 38.79300519398281, 30.91155583517892, 14.93674921989441, 0.0706808894340481, 0.0720953635339226, 0.16930556084428514, 0.09272307915879147, 0.04778866496469293, 0.05389211799151131, 0.0658239968387144, 0.03779720288834401, 0.10117299109697342, 0.07110544200986624, 0.0838228099580322, 0.08833170908370189, 0.08351645139711243, 0.0698225697768586, 0.05054891149380377, 0.01595776790886053, 0.036346060756061754, 0.037291487346270254, 0.015585611807182431, 0.05614441999101213, 0.04663723175014768, 0.0485505647957325, 0.058737682444708686, 0.04048557559560452, 0.04026243596204689, 0.05106802810249584, 0.020234570738726428, 0.03773245707686458, 0.011853262931773705, 0.08442766285900559, 0.02057184844410845, 0.03182775034968342, 0.04381027505067842, 0.17540648632815906, 0.03779046503560884, 0.09889103033180748, 0.03114572087568896, 0.046437236946076155, 0.060870046594313214, 0.03713411811207022, 0.062971455976367, 0.038720451561467986, 0.04793949651398829, 0.030105967739863054, 0.13650380740208284, 0.02216178152178015, 0.05792883477572884, 0.03310975066519209, 0.08106874488294125, 0.061169294108237536, 0.03852483330826674, 0.033880518948925395, 0.019339354043560367, 0.027868189782436405, 0.07335032083626304, 0.0777779518227492, 0.040372253462140045, 0.05497745850256511, 0.1010216370757137, 0.057620087771543434, 0.04046063943366919, 0.03559397254139185, 0.04372627580804484, 0.04901602964050003, 0.03644705390823739, 8.17920138154711, 42.69044433321272, 56.88262980324881, 25.30313147817339, 25.333020891462052, 62.10681356702532, 64.01350348336356, 30.834545476096018, 4.2755496842520575, 0.03214324199195419, 0.06455461388187748, 0.44381333515048027, 2.368686931473868, 2.4656221185411726, 0.09488493244030646, 0.029743602898504053, 3.8648360201290677, 50.81294059753418, 80.38988644736153, 70.99713788713727, 70.21725123269218, 72.1141024998256, 70.89561080932617, 66.78709234510148, 67.06857776641846, 67.38829217638288, 65.20487635476249, 58.93299457005092, 60.40505381992885, 58.82093402317592, 62.29549189976284, 61.36120932442801, 63.38665090288435, 62.531932149614605, 59.00511687142508, 51.879648889814106, 45.30155304500035, 42.94886868340628, 46.12802389689854, 54.37402786527361, 61.05450194222586, 57.96154955455235, 59.763116700308665, 57.75907904761178, 58.6899813243321, 58.44177082606724, 59.38775416782924, 59.11619772229876, 60.394937242780415, 56.0042142186846, 64.62041473388672, 60.64061859675816, 65.99255888802665, 39.32050895690918, 36.63000317982265, 69.9885721206665, 56.83680643354143, 63.523120471409385, 59.219044957842144, 58.82501261574881, 53.81053590774536, 54.40351602009365, 50.504093170166016, 51.386795793260845, 45.57471105030605, 49.82426404953003, 46.22733449935913, 47.716590540749685, 48.629305907658164, 52.28894642421177, 54.28676543916975, 56.90480497905186, 55.13279547010149, 57.3994402885437, 54.278205258505686, 51.91090536117554, 46.85906818934849, 48.24574450084141, 52.46488870893206, 56.516164439065115, 54.77028363091605, 55.27444839477539, 57.49112524305071, 53.96726642336164, 55.53707640511649, 61.77853202819824, 58.100447518484934, 57.99193055289132, 58.186163970402305, 59.10314205714634, 49.632080350603374, 53.5797758102417, 53.47590371540615, 30.57762541089739, 5.82257912840162, 0.3176674326615674, 0.6114676945975849, 0.7358240016869136, 0.927832584295954, 0.34501413096274647, 0.2683828015412603, 0.2680595745997769, 0.07966569731278078, 8.436008538518633, 40.40395198549543, 52.338007654462544, 30.86698661531721, 47.47742312295096, 49.08378062929426, 37.292531285967144, 23.271603277751378, 0.021219286202852215, 0.05926673619874886, 0.09489333270383732, 0.029470299171017747, 0.05647662395079221, 0.03510143754205533, 0.09596435273332254, 0.06844933025006737, 0.08035807444580964, 0.01729483134113252, 0.06448334734886885, 0.046112327237746546, 0.13729716411658696, 0.037218510905014615, 0.07422900332936219, 0.013892795857308167, 0.047361340573323626, 0.03601623506152204, 0.08706841937133245, 0.13619079919798033, 0.06736655799405915, 0.018196969093488793, 0.024448420785899674, 0.09229009917804173, 0.043858244083821774, 0.023101230218474354, 0.05853343661874533, 0.08529799258602516, 0.03943904050226722, 0.20462238575731004, 0.20187685665275368, 0.16524940063910826, 0.09772893054676907, 0.24240473551409586, 0.08942043209182364, 0.19017276540398598, 0.15445514342614583, 0.09302299163703408, 0.2079592174185174, 0.10722884149955851, 0.20814593668494905, 0.13344550079533032, 0.14891999401152134, 0.10419049739305462, 0.2589432666344302, 0.15704166463443212, 0.13160618234957966, 0.08480225490140063, 0.23826830461621284, 0.1410121704850878, 0.15518854478640215, 0.1402072243924652, 0.13517432659864426, 0.1624591425061226, 0.1327815271381821, 0.14939424927745545, 0.12336095049977303, 0.1838562557739871, 0.20955605459000382, 0.16222115313368185, 0.17906121164560318, 0.15395124975059712, 0.17668038154286997, 0.14581773190626077, 0.17791098622339113, 6.05889995609011, 46.50285141808646, 72.29747240883964, 44.50723498208182, 31.298699038369314, 53.72673715863909, 70.54533127376011, 48.125019550323486, 7.09747325522559, 0.1894482664231743, 0.18396115728787013, 2.9480257758072446, 15.474046468734741, 9.066271815981183, 0.25187198179108755, 0.13931230455636978, 3.4539073961121693, 46.0553492137364, 82.41149262019566, 73.54948220934186, 72.05364622388566, 74.27505479540143, 74.7967255456107, 70.23970781053815, 68.01857716696603, 66.32186876024518, 67.43256609780448, 60.24928910391671, 60.60356385367257, 60.93545845576695, 63.6124187197004, 65.02420929500035, 66.86937986101422, 67.30854075295585, 63.8140207018171, 55.426308223179404, 48.62306989942278, 46.39962550571987, 51.25795882088797, 57.44583341053554, 62.69699355534145, 60.506532260349815, 62.3829836164202, 60.46059077126639, 62.67551667349679, 60.29140908377511, 64.67539582933698, 63.69528293609619, 64.47449561527797, 60.67452580588204, 66.77412700653076, 65.79728671482631, 68.0493437903268, 42.231446334293906, 40.704958370753694, 71.36505889892578, 60.48933546883719, 67.91795335497174, 64.98522295270647, 62.43273271833147, 57.106274945395334, 59.33426693507603, 54.45362295423235, 54.9185060773577, 47.664701393672395, 52.85963324138096, 48.61505862644741, 49.78479133333479, 51.98412200382778, 56.503859179360525, 56.70738581248692, 58.86939770834786, 57.66163403647286, 58.70307867867606, 55.77466310773577, 53.81693172454834, 49.521635259900776, 51.67890848432268, 55.816522530147004, 58.19830942153931, 58.274822984422954, 58.34810216086251, 61.528216225760325, 57.127918584006174, 60.11616161891392, 64.46200275421143, 59.291431290762766, 59.385343142918174, 60.959492274693076, 60.064251627240864, 52.53693110602242, 56.773831435612266, 52.821588379996165, 29.691820417131694, 4.881753955568586, 0.20448290609887668, 0.5752006492444447, 0.6382512631160873, 1.0149823193039214, 2.3787257756505693, 1.5192501119204929, 0.6072145828178951, 0.20344068988093308, 14.889532736369542, 53.626523290361675, 54.23535571779524, 36.56216096878052, 47.123891830444336, 49.24432570593697, 49.649051325661794, 24.66247456414359, 0.11537928879261017, 0.20927025564014912, 0.20098678155669145, 0.18406105121331556, 0.1285851001739502, 0.092766288268779, 0.1812654733657837, 0.12600999192467757, 0.1335881288562502, 0.14061876945197582, 0.1898501491440194, 0.10322213292654071, 0.23449605703353882, 0.2074522160525833, 0.15439125256878988, 0.11881814497922148, 0.14478175821048872, 0.09883769747934171, 0.13181177846023015, 0.1819749360105821, 0.21768831035920552, 0.14769808814993926, 0.1231084404779332, 0.2015969066747597, 0.1853609343192407, 0.12777244592351572, 0.1727282271853515, 0.1431896843548332, 0.19475631016705716], [0.024811121502092907, 0.043234534694680145, 0.020229778585157225, 0.026920084675241793, 0.012421321423192109, 0.08781262979443584, 0.04371910369289773, 0.02915199500109468, 0.03340812286894236, 0.029672081914863417, 0.04636248613574675, 0.019015329823430096, 0.027214199071750045, 0.03698020262111511, 0.036545597548995695, 0.0017274560107450399, 0.06137938890606165, 0.0880788801504033, 0.038128036207386425, 0.08213268779218197, 0.03971964865922928, 0.036962686239608696, 0.08867890866739409, 0.09879717536802803, 0.016201796242967248, 0.05318450774731381, 0.04156583048669355, 0.04736207339114376, 0.021313794256587113, 0.05572438306574311, 0.0574812934334789, 0.049415615520306995, 0.04629783192649484, 0.06472865132881062, 0.03335922424282346, 0.028745243791490793, 0.02215470779421074, 1.8409547465188163, 20.765431472233363, 49.019297872270855, 44.40459966659546, 27.190402916499547, 40.522262437003, 57.652181012289866, 51.05145141056606, 9.359994752066475, 0.059809068883103986, 0.04336354455777577, 0.2848865645272391, 2.786556154489517, 1.343263532434191, 1.072864396231515, 0.2276104193712984, 1.3735409591879164, 26.900185346603394, 78.70042501177106, 75.46383598872593, 65.07932935442243, 64.92752511160714, 69.22071974618095, 68.62024252755302, 62.718616349356516, 57.90791988372803, 63.44030489240374, 62.97286483219692, 67.3280165536063, 61.92967619214739, 57.828116348811555, 58.827256883893696, 55.991884640284944, 56.2095091683524, 48.400512150355745, 44.84985760280064, 45.84656279427664, 50.57671226773943, 56.353114536830354, 60.99093982151577, 59.88820511954171, 62.31799711499895, 60.216820171901155, 60.84228311266218, 58.91681916373116, 60.64450263977051, 60.41747719900948, 56.81827906199864, 55.148953505924766, 61.61158766065325, 55.21705627441406, 62.05744661603655, 40.86070919036865, 29.34363923754011, 66.02773761749268, 60.16563974108015, 60.074472427368164, 57.08683041163853, 56.356890882764546, 49.91918339048113, 50.892890044621055, 48.83792904445103, 45.75473540169852, 45.16541699000767, 44.34078393663679, 45.053061144692556, 45.67634235109602, 46.340822901044575, 49.50264583315168, 49.048796449388774, 55.370288372039795, 54.1328524180821, 56.93065227781023, 55.08438737051827, 54.75805132729666, 50.34240858895438, 46.86708293642317, 49.2105644089835, 52.52839176995413, 55.716148853302, 57.625451292310444, 55.476911953517366, 61.331526620047434, 56.698248931339805, 56.8588912827628, 61.5311553137643, 59.44782134464809, 53.37553351266043, 58.11266245160784, 59.196741240365164, 35.92749513898577, 10.745528953416006, 0.6557244083711079, 0.12334094728742327, 2.066754915884563, 0.8383694248540061, 1.245551341346332, 0.8295372330716678, 0.14396653909768375, 0.1153811344078609, 0.05243287754378148, 13.521201406206403, 49.36573852811541, 34.56846570968628, 27.922968864440918, 23.90589564187186, 29.727947575705393, 36.622363635471885, 12.131090947559901, 0.21961043721863202, 0.13017982031617845, 0.0963558606537325, 0.09539433582020657, 0.02025105065799185, 0.04364944189520819, 0.04418754730639713, 0.03298960586211511, 0.10215318242886237, 0.11842091700860433, 0.04970381648412772, 0.023698953412739292, 0.048190306805606396, 0.05683550790750554, 0.07152589623417173, 0.05060998982350741, 0.06387047416397504, 0.02771175523022456, 0.06987307992364679, 0.03348690756995763, 0.07725435349025897, 0.04642306913488677, 0.05719248857349157, 0.03299202823213168, 0.05297842987680009, 0.09203991653131587, 0.028840839197593074, 0.05294457097936954, 0.045010759561721764, 0.008406577299215963, 0.013491202362014778, 0.024990519375673363, 0.012361146393232048, 0.049233683318431885, 0.01937534354094948, 0.023390625403927903, 0.06187984919441598, 0.01786892455337303, 0.03272660229621189, 0.019504197340990816, 0.05700477186058249, 0.02193069624315415, 0.07374412899038621, 0.04665524006954261, 0.03668661069657121, 0.032822116278111935, 0.03318958370281117, 0.03914437309971877, 0.010383603578832532, 0.051348765181111436, 0.0505430726999683, 0.036097611766308546, 0.04438573042196887, 0.09538969464067902, 0.05222526279145053, 0.04348695311429245, 0.0853264367740069, 0.026445152570626566, 0.047726002255720754, 0.07171516679227352, 0.054075149420116625, 0.04117205625932131, 0.0353759660252503, 0.04548007509272013, 0.03915574534663132, 0.01570636050642601, 0.03450505615078977, 6.244415555681501, 37.99452863420759, 55.46454416002546, 31.07106215613229, 23.73766585758754, 51.685040269579204, 69.2375830241612, 48.00469759532383, 6.260283938476017, 0.012580601581638413, 0.06007861013391188, 0.16997119012687886, 0.9829128001417432, 0.5625481424587113, 0.35082138649054934, 0.22077782957681588, 3.175817689725331, 35.89889982768467, 80.75597313472203, 76.21148300170898, 68.68720231737409, 67.39654663630894, 71.67559473855155, 69.38420391082764, 63.92568520137242, 59.88149315970284, 64.8534712110247, 61.497678892953054, 65.62852886744908, 65.42415455409459, 60.473632540021626, 61.595780508858816, 58.37306703839983, 60.04975768498012, 50.910521098545615, 46.68335172108242, 47.36197880336216, 51.86839280809675, 57.549441473824636, 62.01842553274972, 60.31673526763916, 62.215226309640066, 60.781041690281455, 61.99301597050258, 60.10569068363735, 61.51683507646833, 61.707222666059224, 58.37697887420654, 56.440634046282085, 62.14575127192906, 59.419500487191335, 62.75814465114048, 41.656812940325054, 32.960409368787495, 67.47892447880336, 60.28343949999128, 61.53277424403599, 58.92676898411342, 58.89313275473458, 52.98378365380423, 54.494092736925396, 51.36083384922573, 48.73477956226894, 46.52365779876709, 44.72630820955549, 45.808163574763704, 47.219092573438374, 46.65655599321638, 50.227217878614155, 52.8612174306597, 57.420872007097515, 56.50707966940743, 59.18139961787632, 56.38320371082851, 54.724567958286826, 50.87928894587925, 49.84756830760411, 49.64294038500105, 54.279111998421804, 56.1240359033857, 57.97647775922503, 59.03099891117641, 60.90042563847133, 61.082100187029155, 59.81457505907331, 60.63581044333321, 62.333741733006065, 57.50733191626412, 56.46816280909947, 60.82924829210554, 43.527337482997346, 15.079871688570295, 2.1465762555599213, 0.2421354656772954, 1.2796626538038254, 1.3358771630695887, 0.7882235156638282, 0.6599765430603708, 0.15555879420467786, 0.17025791188435896, 0.19156412860112532, 9.853151832308088, 52.61404568808419, 50.891698428562705, 36.83808088302612, 25.34208481652396, 32.326417514256065, 41.30659941264561, 21.05161213874817, 0.4790686305080141, 0.1243927851319313, 0.04379679934520807, 0.07960457487830094, 0.0614272595516273, 0.018408022322026745, 0.051067363138177564, 0.06770285352000169, 0.021108142166797603, 0.05593513264986021, 0.049323813124958954, 0.05451245166893516, 0.03338649795789804, 0.0035432823018969168, 0.043270249385386705, 0.04645927915615695, 0.09898036625236273, 0.0907943162268826, 0.03420075694365161, 0.03125345188059977, 0.0707433417971645, 0.030024546930300336, 0.06942528073808976, 0.04331009974703193, 0.03726439005030053, 0.06198635883629322, 0.014009662488076304, 0.02929636350433741, 0.031340141514582295, 0.06485337963593857, 0.08798456378281116, 0.14981162973812648, 0.05728824343532324, 0.10622902693493025, 0.10347960303936686, 0.16532745930765355, 0.1377516333013773, 0.09862259509307997, 0.17201306484639645, 0.10460806105818067, 0.13708892171936377, 0.09661033164177622, 0.12487777482186045, 0.1235459598579577, 0.10835693989481245, 0.1013285791767495, 0.0772014684709055, 0.2650771960616112, 0.1120200315490365, 0.11592953998063292, 0.16166940916861805, 0.10291109925934247, 0.18656393619520323, 0.24287398319159234, 0.11293198939945016, 0.12701545868601116, 0.15681502036750317, 0.11811595622982297, 0.08559900429099798, 0.1835900800568717, 0.18405362804021153, 0.21003484246986254, 0.12232640172754015, 0.17076153414590017, 0.12460109538265637, 0.07967807379152093, 0.1394316724368504, 4.286487885883876, 40.58691542489188, 66.7940752846854, 54.48038741520473, 38.25663900375366, 54.62207508087158, 67.02682604108537, 65.3573476246425, 14.546382052557808, 0.16619968893272535, 0.12373741529881954, 1.3355044573545456, 8.356759990964617, 3.507129511662892, 1.5895219125917979, 0.42780308425426483, 2.723125181027821, 31.65865741457258, 83.2131757736206, 78.32553495679582, 68.64672211238316, 67.4401604788644, 73.16842215401786, 72.08353042602539, 65.38013771602085, 58.804883684430806, 63.54349258967808, 63.99385397774832, 67.0913748059954, 68.2074361528669, 64.07303564889091, 63.937962668282644, 60.111415999276296, 61.44481699807303, 52.39434364863804, 47.93372869491577, 51.708365372249055, 55.98229612622942, 61.27089663914272, 66.99762276240757, 63.451171875, 65.1908826828003, 65.96220220838273, 64.7114291872297, 64.0757246017456, 63.77555547441755, 66.21205942971366, 61.30770819527762, 60.403580801827566, 64.17101219722203, 60.27207919529506, 63.72113023485456, 45.81527158192226, 34.23759249278477, 65.03465243748256, 64.2904725755964, 64.51687267848423, 60.97795363834926, 61.52117075238909, 54.93994474411011, 55.07495171683175, 53.73727062770298, 49.728114877428325, 48.498422690800254, 47.70506695338658, 48.74717514855521, 49.00836140768868, 48.72193234307425, 52.57918657575335, 54.57567153658186, 60.940259660993306, 60.31372669764927, 62.993139675685335, 59.883667945861816, 58.780127252851216, 55.18726934705462, 51.393837792532786, 53.06715161459786, 58.15569611958095, 60.12437438964844, 61.55764879499163, 61.3562969480242, 65.44053145817348, 61.30106571742466, 60.86490644727434, 64.5364179611206, 61.59878213065011, 54.5617265020098, 58.824922289167134, 62.89204338618687, 42.030038901737754, 13.50290071964264, 1.508607642991202, 0.13539733391787323, 2.457952392952783, 1.959970005920955, 2.4605987880911147, 3.0745403128010884, 0.4696584354553904, 0.5382483378052711, 0.2999234162271023, 20.848877600261144, 60.62768799918038, 43.45202595846993, 38.73297275815691, 34.38787508010864, 40.07170649937221, 52.76172964913504, 24.54705630029951, 0.42799405114991323, 0.36483145185879295, 0.1527377577232463, 0.14532799247120107, 0.16365151852369308, 0.10480229849261896, 0.10995956497000796, 0.2166407879974161, 0.20515266087438377, 0.15498582566423075, 0.15454142593911716, 0.15886294761938707, 0.08760338316538505, 0.13099179603159428, 0.17163175530731678, 0.11939169705978461, 0.11489564260201794, 0.13776361622980662, 0.1604734504861491, 0.14619655800717218, 0.19097256820116723, 0.15859248356095382, 0.16159512315477642, 0.1426063070872, 0.14372708408960275, 0.23473777834858212, 0.07693721300789289, 0.17077045009604522, 0.11670328703309808, 0.17625046175505432], [0.14399954304099083, 0.0363477944130344, 0.031059390865266323, 0.010172088098313128, 0.022215638542547822, 0.07605942618101835, 0.05488042799489839, 0.0479844732076994, 0.02068881261428552, 0.03941870141508324, 0.0765486770708646, 0.021875938467149223, 0.01497727632522583, 0.03569795124764953, 0.039232440159789154, 0.022060126797961335, 0.03051035086225186, 0.03126943138028894, 0.07355310102658612, 0.011612575534465057, 0.008213248253533883, 0.07250676610107933, 0.0316541573431875, 0.025044540941183056, 0.047159554436802864, 0.05419148764173899, 0.047591906772660356, 0.036944654171488116, 0.054491942947996516, 0.03308507573923894, 0.05084390120048608, 0.023404328418629508, 0.0491745388135314, 0.06398264957325799, 0.03286266213815127, 0.018584310808884244, 0.014799924234726598, 0.012481309856022043, 1.5763147984232222, 7.9760317121233255, 49.290041378566194, 50.538271359034944, 38.2968829699925, 33.660391739436555, 45.40330246516636, 61.88749367850167, 20.271885292870657, 0.49743858192648205, 0.06293153097586972, 0.11486962756940297, 0.039832170121371746, 0.7884661055036953, 0.06817090019051518, 0.08095399782593761, 0.07100113082144942, 10.038297874586922, 47.972242559705464, 74.71275656563895, 74.210207257952, 61.875049454825266, 59.560090337480815, 65.71414457048688, 66.22628934042794, 62.96870286124093, 63.456758226667134, 62.826917920793804, 57.70375401633126, 64.0134687423706, 62.209480149405344, 63.93419674464634, 54.614609241485596, 48.5448123386928, 47.71969985961914, 45.47714444569179, 50.606599943978445, 56.00480481556484, 58.07670552389962, 57.992983204977854, 59.87334987095424, 59.21598775046212, 61.358256340026855, 59.50203119005476, 63.13209669930594, 60.195461409432546, 65.51308454786027, 59.33822740827288, 61.766400473458425, 58.03482525689261, 63.259262629917686, 37.77464941569737, 17.768824543271744, 66.79459639957973, 63.447746413094656, 64.29656614576066, 61.35474749973842, 59.119463375636506, 54.04398843220302, 54.89821038927351, 51.15723773411342, 50.434993335178916, 44.7312970161438, 46.54051065444946, 47.09068291527884, 48.21645436968122, 48.08520289829799, 46.83711882999965, 47.79977437428066, 48.54543072836739, 51.06026520047869, 52.15824386051723, 51.179791586739675, 52.32083518164498, 52.68399320329939, 52.44107028416225, 54.834689957754954, 56.16689934049334, 56.58060203279768, 59.9422482081822, 61.8737918308803, 57.28562184742519, 61.211586815970286, 63.94249289376395, 57.49975837979998, 60.41972146715437, 64.91924980708531, 46.816708496638704, 17.806391716003418, 2.2448852317673818, 0.12322806620172091, 0.04437812743708491, 1.998152528490339, 1.4593151680060794, 0.8304924475295203, 1.4404743675674712, 0.32538139873317307, 0.06646003520914487, 0.3873236392225538, 25.00787125314985, 53.309747968401226, 25.355149166924612, 19.32643869944981, 26.728566578456334, 37.09997238431658, 36.96832486561367, 6.78559467622212, 0.13594396172889642, 0.07298212059374366, 0.05957373258258615, 0.04003124211781791, 0.10266829228826932, 0.055777240943695815, 0.05776642741901534, 0.05272282234260014, 0.07991703346903835, 0.07443891492273126, 0.052842729658420594, 0.07936639551605497, 0.028005883197433183, 0.06455941112445933, 0.05660577630624175, 0.05493524005370481, 0.045592552450086386, 0.05269169115594455, 0.06006441518132176, 0.021930713206529617, 0.1085599372163415, 0.091435009347541, 0.03027094674429723, 0.04876020497509411, 0.02183193207851478, 0.0590793587533491, 0.07887297842119421, 0.018527451270659055, 0.19752435306353228, 0.01015438766418291, 0.023295386228710413, 0.013608158050504113, 0.028124095872044563, 0.08228404181344168, 0.04352985688352159, 0.1031920670398644, 0.059694220045847554, 0.02862183184229902, 0.004401999750241105, 0.02734635564099465, 0.051086786203086376, 0.03162437304854393, 0.01632564075823341, 0.018463638444830264, 0.08761846021349941, 0.034036313981882164, 0.008587219436386866, 0.05866242612579039, 0.0390350678935647, 0.03703517074297581, 0.013299215119332075, 0.08129405922123364, 0.09276788282607283, 0.01484068383329681, 0.03711542107963136, 0.03683252965233155, 0.00978598216482039, 0.02139144410778369, 0.028338490885549357, 0.026029592280143073, 0.031170870776155164, 0.01978753151239029, 0.11252678864236389, 0.031036218894379478, 0.01667188530388687, 0.03514282478551779, 0.028209375849525844, 0.008093312948143907, 0.06962806771376304, 4.7873387932777405, 19.254104478018625, 59.029671805245535, 44.48171077455793, 35.91498490742275, 42.20565462112427, 68.71084703717912, 67.42981461116246, 14.581694534846715, 0.1338789082531418, 0.29669616797140663, 0.04916720384997981, 0.06136509217321873, 1.7230284001146043, 0.13415189646184444, 0.16133213655224868, 0.047051365420754464, 17.12234503882272, 58.36844648633684, 73.90641811915806, 70.68619210379464, 60.53624970572335, 61.42320810045515, 67.38830607278007, 65.6135277066912, 62.79726300920759, 63.0684095110212, 65.13205923352922, 61.221446309770855, 66.06625843048096, 66.49621295928955, 65.47245148250035, 56.40297828401838, 47.92452580588204, 48.86340808868408, 46.726569516318186, 52.59065457752773, 56.65655626569475, 59.674026897975374, 60.98890399932861, 63.10089928763253, 60.19892856052944, 63.99466691698347, 62.07783957890102, 65.12657710484096, 61.75500542776925, 66.89772156306675, 60.53665964944022, 64.37908295222691, 58.7224155153547, 63.883690289088655, 40.230837617601665, 21.569926909038, 66.11946773529053, 64.1091593333653, 66.33855833326066, 63.000497817993164, 60.26209463391985, 55.99537263597761, 55.25866208757673, 52.72230209623064, 51.446668420519146, 48.33399704524449, 48.94075543539864, 48.10486282621111, 48.4406657900129, 49.42639282771519, 49.084993089948384, 50.72033500671387, 52.23787369046892, 53.61352321079799, 54.464535100119456, 53.1842565536499, 54.681263310568674, 53.270490646362305, 52.543691703251426, 56.08292688642229, 59.41251754760742, 58.41932814461844, 59.987091881888254, 62.184140069144114, 59.52667645045689, 61.278386797223774, 65.45130811418805, 62.0474967956543, 59.858696120125906, 62.23322214399065, 52.76869521822248, 24.858047246932983, 3.879991344043187, 0.8101189721907888, 0.08732655444847685, 2.1823136636189053, 2.4326170895780836, 0.22279368926371845, 0.3562807435435908, 0.20114697010389396, 0.11912187082426888, 0.09271775265889508, 19.441856963293894, 62.43820095062256, 43.33077294485909, 20.20221049445016, 26.58224446432931, 41.99506514413016, 44.67665638242449, 15.595473187310354, 0.07059418622936521, 0.08085098942475659, 0.019019010875906264, 0.026950530541528548, 0.0672140165365168, 0.04928400347541485, 0.08762590374265398, 0.035216574756694694, 0.049313960796488185, 0.019134904657091414, 0.021077133116445372, 0.026354530826210976, 0.09442559815943241, 0.08460762391665153, 0.07276518616293158, 0.07237079446869236, 0.035326874016651084, 0.08607232317860637, 0.03587690807346787, 0.04674268287739583, 0.05789690291775124, 0.021915071278012226, 0.025632729022098438, 0.027437985009912933, 0.03803217617262687, 0.0014964178054859595, 0.08482828350471598, 0.02555092314391264, 0.122882624023727, 0.012004758597218564, 0.0595893185319645, 0.23421104518430574, 0.10463416430034808, 0.10727287163691861, 0.1194667566035475, 0.12176461544420038, 0.1234044853065695, 0.11563546290355069, 0.12546073139778205, 0.13943277166358062, 0.19561851104455336, 0.13802064529487065, 0.12835784522550447, 0.05440930416807532, 0.1280072190399681, 0.10979063010641507, 0.06523679941892624, 0.12959360677216733, 0.1450362088424819, 0.10782839504203626, 0.059782877431384156, 0.1474645771086216, 0.16512589369501385, 0.15923207066953182, 0.12973307285990032, 0.19780907992805752, 0.12967246611203465, 0.1497911379805633, 0.10239835070180041, 0.09387722651341132, 0.1160355271505458, 0.08419179051582303, 0.1575954577752522, 0.17120573031050818, 0.14543805085122585, 0.11992372279720646, 0.0987984442285129, 0.07970056722738914, 0.30770024178283556, 2.9639425788606917, 21.31971185547965, 74.34024279458183, 64.96794278281075, 52.38552638462612, 46.18692030225481, 56.61114283970424, 75.26906408582414, 30.336092131478445, 0.6177742704749107, 0.6381596880299705, 0.3554035063300814, 0.12747330697519438, 2.4116736991064887, 0.31218934804201126, 0.23037691520793097, 0.10113949182310275, 14.191464594432286, 57.03989880425589, 75.87214687892369, 73.7453727722168, 63.2939202444894, 61.484310558864046, 68.64411653791154, 66.48010703495571, 64.10148852212089, 64.05340698787144, 65.33136136191231, 62.791683605739046, 68.36032431466239, 70.22861848558698, 69.83304364340646, 60.24466160365513, 53.45596933364868, 54.58767802374703, 51.25057635988508, 57.260962690625874, 60.90845080784389, 61.69935730525425, 62.9648813520159, 64.51603889465332, 64.34696143014091, 65.14884608132499, 64.87848472595215, 67.73518099103654, 65.93636880602155, 69.43982424054826, 63.65772097451346, 66.62088448660714, 62.90555763244629, 67.36489759172711, 41.62830795560564, 23.392118045261928, 67.17624705178397, 66.75128132956368, 69.80086653573173, 67.87167140415737, 62.98636518205915, 60.64384256090437, 60.569295338221956, 58.2831642968314, 56.74080317361014, 50.19252552304949, 52.74745804922921, 52.987518310546875, 53.138467924935476, 52.23938144956316, 51.254877294812886, 53.41569062641689, 54.09714215142386, 57.19573647635323, 56.00957127979824, 55.1193402835301, 56.654673303876606, 57.038884367261616, 57.360176018306184, 61.13996478489467, 62.093542507716585, 62.541708265032085, 62.80321066720145, 65.39292240142822, 61.92425659724644, 63.967819077628, 67.9062247957502, 60.92063099997384, 61.98192664555141, 66.45542008536202, 50.56692573002407, 21.30935209138053, 3.619705310889653, 0.45687814695494516, 0.14585875613348825, 3.130040786096028, 5.102640662874494, 2.727080225944519, 4.5070580158914835, 1.8178017203296934, 0.20128678902983665, 1.0657072088548114, 34.50115850993565, 63.97038296290806, 35.092276505061555, 28.255278621401104, 37.30082743508475, 51.48218413761684, 52.79048476900373, 14.73978863443647, 0.25391323225838797, 0.202997145109943, 0.08703644001590354, 0.059924189134367874, 0.23963427703295434, 0.23457501136830874, 0.13163149170577526, 0.14889639456357273, 0.1548540677343096, 0.12839113415351935, 0.17393368535808154, 0.16011124849319458, 0.14333638362586498, 0.1415774580091238, 0.10536050211106028, 0.20112831039088114, 0.12390479631721973, 0.2889102229050228, 0.10638932404773575, 0.18774451927414962, 0.15384667393352303, 0.16956474765070847, 0.23809652669089182, 0.1737921836652926, 0.09346926411879913, 0.23787022169147218, 0.1698120329529047, 0.08427563708807741, 0.4502174843634878, 0.09065589508307831, 0.1932786237448454], [0.06370338491563286, 0.014105049244660352, 0.029017814701156955, 0.010974940910403217, 0.04597296293026634, 0.030153926594981124, 0.016013214397909384, 0.034017572844667096, 0.052281299605965614, 0.04787240975669452, 0.020993135570149337, 0.011151429565091218, 0.07580678723752499, 0.04525731883144804, 0.02634960805465068, 0.05331367706613881, 0.0654998335189053, 0.059015617173697264, 0.04200395715555974, 0.0580928163336856, 0.008534434500948658, 0.031863427720963955, 0.029217507557145188, 0.010305431255671595, 0.009190351402919208, 0.04387735162994691, 0.08514684891062123, 0.050748553459665606, 0.04176454285957983, 0.017147779231891036, 0.038509613767798455, 0.12702231188969954, 0.026574851146766117, 0.02705200036455478, 0.04991219798102975, 0.03583221975713968, 0.06583144036786896, 0.08610461466014385, 0.10283488620604787, 0.5696081093379429, 11.125399998256139, 41.806873185294016, 49.977214745112825, 36.49749755859375, 20.06408030646188, 37.161554268428254, 61.37017250061035, 37.821442059108186, 1.9625849170344216, 0.12879718307937893, 0.08416044219796147, 0.12522799388638564, 0.6126579535858971, 0.12799553466694696, 1.4588335709912437, 0.22625499138874666, 0.8692286003913198, 18.172414132526942, 54.000788007463726, 77.75455978938511, 75.66841874803815, 64.77674920218331, 62.29265008653913, 65.9993542262486, 68.11990969521659, 61.687302180698936, 69.92473902021135, 63.67115879058838, 60.275157247270855, 57.07717588969639, 51.076503140585764, 49.6909350667681, 50.04965318952288, 49.85539197921753, 58.18153647014073, 60.027335848127095, 64.56642028263637, 63.92872156415667, 66.97031634194511, 62.736195291791645, 63.48794869014195, 62.082307270595, 62.5722108568464, 59.290041651044575, 63.726369176592144, 59.4954651423863, 59.92512089865548, 52.27864571980068, 52.71094526563372, 31.449012892586843, 25.744038105010986, 64.02220262799943, 65.74732221875871, 61.75037097930908, 58.030027525765554, 57.32707480021885, 55.07702922821045, 53.74427093778338, 48.656852040972026, 46.307926654815674, 44.9513395173209, 48.29346472876412, 50.40678364889962, 51.80698115485055, 50.4840476172311, 48.33136715207781, 47.41713012967791, 47.48110566820417, 48.95010771070208, 51.983277797698975, 54.17194298335484, 54.0824328150068, 53.232543059757774, 51.28041887283325, 54.43724257605416, 56.93176051548549, 58.57166739872524, 59.93177727290562, 59.91360773359026, 67.44446836199079, 63.33617918831961, 59.284844398498535, 67.0786109651838, 54.22299139840262, 19.561049836022512, 3.484357442174639, 0.10374030297888176, 0.2565252392419747, 0.25861621275544167, 3.3104596648897444, 2.787883911814008, 1.1155102678707667, 0.909289145043918, 0.46585445957524435, 0.11879440982426916, 2.600223707301276, 37.233888489859446, 49.28853014537266, 16.130474056516373, 16.175746781485422, 28.37753564970834, 39.5688236781529, 25.269840921674454, 1.7415944210120609, 0.2627839376883847, 0.027606953800256764, 0.03433375659265688, 0.028172209093879377, 0.023429546172597578, 0.018986522619213377, 0.03361078431563718, 0.10559796222618648, 0.013474023551680148, 0.040994955226778984, 0.037721895679299317, 0.05028489351804767, 0.00965953292325139, 0.03393840816404138, 0.04413763766310044, 0.05633538010131035, 0.04762420503954802, 0.06641291095209972, 0.026254194156665887, 0.034820028713771274, 0.03763996596847262, 0.06099131437284606, 0.03445550613105297, 0.01495902712589928, 0.03507870322625552, 0.038761811663529704, 0.028711065982601473, 0.015506504802033305, 0.012076796115642148, 0.047048580034502914, 0.11185919160821609, 0.03664801901738558, 0.04079206647085292, 0.024201082897239497, 0.0749052856117487, 0.027687102356659513, 0.06377927905746869, 0.012445667259661215, 0.05413487067978297, 0.06099856112684522, 0.05237918506775584, 0.06473622377961874, 0.04372258797021849, 0.04489647390853081, 0.06738232714789254, 0.0602355349276747, 0.048241152827228816, 0.0734434158408216, 0.052388212976178954, 0.046324651023106914, 0.060560417494603565, 0.030725901081625904, 0.01592528643751783, 0.040285730069237094, 0.03062929805102093, 0.019587604561820626, 0.016534814444769706, 0.031886158644088676, 0.00601612132907446, 0.05640651431999036, 0.01434853220624583, 0.033097699883260896, 0.010248786304146051, 0.04047668000151004, 0.04032432174842272, 0.05393432965502143, 0.03817548616124051, 0.0551056337675878, 0.007507781331826533, 0.025295061159080694, 0.03641192275764687, 1.5060155306543623, 22.11873037474496, 53.754738398960654, 56.4692189352853, 31.824948651450022, 21.157440151487076, 59.324650628226145, 76.0167875289917, 32.037382875170024, 0.5534346029162407, 0.06805622777236359, 0.053175954813403745, 0.12672851979732513, 0.6650561647755759, 0.9754227506262916, 2.215379272188459, 0.7417219909174102, 2.0974904894828796, 28.98572189467294, 63.768600327628, 78.87073925563267, 72.27955300467355, 61.58979116167341, 64.17128317696708, 67.37057426997593, 67.7990835734776, 63.13737038203648, 68.7097909109933, 66.52883475167411, 60.519421168736045, 58.76195076533726, 53.72854021617344, 52.245422908238, 52.69361298424857, 53.17632865905762, 58.81766836983817, 62.0806188583374, 65.15868473052979, 64.93410505567277, 65.33771201542446, 63.411379541669575, 64.9095014844622, 63.12604481833321, 63.99288122994559, 60.987111364092144, 64.6796064376831, 59.45976529802595, 61.46996947697231, 56.29575368336269, 57.1492599759783, 32.5912515776498, 23.05359833581107, 64.036376953125, 64.99544375283378, 64.28991671970913, 60.57763317653111, 60.46691363198416, 57.0401246207101, 56.00105626242501, 50.71551643099104, 48.737089838300435, 45.39137588228498, 48.71712418964931, 50.135213306971956, 52.469894886016846, 50.09192950384957, 50.29368087223598, 49.61788170678275, 50.13889585222517, 52.680466992514475, 52.400392055511475, 56.23788561139788, 56.48206615447998, 54.949991839272634, 54.33034454073225, 56.76325280325753, 56.95406423296247, 60.67230238233294, 63.30951200212751, 62.09024906158447, 66.26120403834751, 65.60063879830497, 60.536256653921946, 66.59835147857666, 58.16623306274414, 28.247144017900737, 4.825586889471326, 0.8274306261113712, 0.9239146688154766, 1.667208201118878, 3.573785100664411, 2.120060844080789, 1.0481250094515937, 0.526198858661311, 0.2890433243342808, 0.03338714595884085, 1.1147030826125826, 35.305516719818115, 70.64577443259103, 31.220333780561173, 13.441272803715297, 25.194793428693497, 44.82435423987252, 35.29701559884207, 5.258824007851737, 0.4223320021161011, 0.06801917976034538, 0.054423875707600794, 0.044173264144254584, 0.01500753898705755, 0.01810288173146546, 0.03858284805236118, 0.021207959757053425, 0.03489683548520718, 0.015515727789274283, 0.037055587861686945, 0.03786831335829837, 0.043356362264603376, 0.056642094893114905, 0.03297123113381011, 0.028047300974971483, 0.04242706445178815, 0.03074446240706103, 0.019692071813291738, 0.05324482951047165, 0.05500514612400106, 0.07036171334662608, 0.012322160315566828, 0.016148577045117105, 0.06251045928469726, 0.047210705799183676, 0.020538269442373087, 0.03668286179059318, 0.005812212650198489, 0.08506644251091139, 0.051357983079339774, 0.03940751576530082, 0.17543339702699864, 0.10736273002943822, 0.12611397063093527, 0.1360307192163808, 0.07939827987658125, 0.13824248553386756, 0.13350789887564524, 0.17306712828576565, 0.14857590890356473, 0.20980742467301233, 0.11356935769851718, 0.09269426856189966, 0.1364819857158831, 0.13491250707634858, 0.10894484299102, 0.13856770736830576, 0.190645962155291, 0.10754235181957483, 0.14013494684227876, 0.12681713647076062, 0.09414593316614628, 0.12885701629732335, 0.13578987999686173, 0.07152228642787252, 0.08002584334462881, 0.18159762982811245, 0.1675191002764872, 0.17866714564817293, 0.11578791615154062, 0.09503148243363414, 0.08754905286644186, 0.18589582347444125, 0.15096113591321877, 0.09790661172675234, 0.14284080878964492, 0.17673622497490474, 0.0917244248890451, 0.15016568931085722, 0.20612395661217825, 0.9595405800001962, 20.69617009162903, 63.27791854313442, 69.20321028573173, 48.77956070218767, 32.01279320035662, 50.10983501161848, 76.36684472220284, 50.92433064324515, 3.385055742093495, 0.24568575088466915, 0.46484789358718054, 0.2258071039936372, 1.2412274990762984, 1.2214857126985277, 2.76104627762522, 0.795615801853793, 1.4822655022144318, 22.768397365297588, 60.196489742824006, 79.00203241620744, 74.26543848855155, 64.16463375091553, 62.35943617139544, 66.11466653006417, 67.02781963348389, 66.93272658756801, 73.96574183872768, 69.34804548536027, 62.29503331865583, 61.71917356763567, 54.46965939658028, 53.9699102129255, 54.796186515263145, 56.180291993277415, 63.52115413120815, 67.9539519718715, 70.62437398093087, 70.16391686030796, 71.90382916586739, 68.7840393611363, 69.0084661756243, 67.78959233420235, 65.00278105054582, 63.832190241132466, 65.32627528054374, 61.38190105983189, 60.80196271623884, 55.92965657370431, 55.73833792550223, 39.605784620557515, 33.29313080651419, 61.8936984198434, 68.57950523921421, 66.63200855255127, 62.54774624960763, 61.40574727739607, 60.023014068603516, 57.69562809807913, 53.120100361960276, 49.49524252755301, 49.39224590573992, 51.897578716278076, 54.672842093876426, 54.21922894886562, 52.422112124306814, 52.11159018107823, 52.17902592250279, 52.147373403821675, 55.57501704352242, 56.915810925619944, 60.557059560503276, 58.82362992422921, 57.179060799734934, 55.66292565209525, 59.254084723336355, 61.31685202462332, 64.0278515134539, 64.04734815870012, 65.46425260816301, 69.29000718252999, 63.70630972726004, 61.1242618560791, 68.19939013889858, 57.57168960571289, 24.098478862217494, 5.154954084328242, 0.6335845706718308, 0.3502956304166998, 0.8425156537975583, 7.356616309710911, 7.126699549811227, 4.579484300954001, 4.013915266309466, 0.9693563218627657, 0.2194006477615663, 4.2649871196065625, 49.98058809552874, 58.66724681854248, 25.50533274241856, 24.290872744151525, 39.10216876438686, 54.453935623168945, 37.78135442733765, 4.634911818163736, 0.3782590627670288, 0.16670109917010578, 0.08667246026120015, 0.09550889288740498, 0.11638395488262177, 0.16339640292738164, 0.09912430388586861, 0.22617877833545208, 0.12340178473719529, 0.1191915427999837, 0.10270702306713377, 0.10311742140246288, 0.08209597904767309, 0.10028748254158668, 0.07332246018839733, 0.17385364536728176, 0.12914400946881088, 0.10878779606095382, 0.1245612653770617, 0.14405340515077114, 0.14309718646109104, 0.2177513734038387, 0.08930633642843791, 0.12971203827432223, 0.15092498356742517, 0.13289169408380985, 0.1310777799891574, 0.12627225928008556, 0.0792888661048242, 0.1103452103478568, 0.2740128237221922, 0.13971209738935741], [0.04838654252567461, 0.03683700459077954, 0.03165224048175982, 0.028863495481865745, 0.07151001172938518, 0.021365987170221548, 0.028655022382736206, 0.05697478739810841, 0.04857898862766368, 0.042068380662905316, 0.04157727397978306, 0.04727899017078536, 0.03729245086599674, 0.05436280416324735, 0.04816320950963667, 0.006813137467751014, 0.03921586015660848, 0.12152537756732532, 0.05764250656855958, 0.03602737999920334, 0.01575667896707143, 0.034414576898728094, 0.047113627794065645, 0.044425400971834145, 0.07951785131756749, 0.06512967231018202, 0.02646880630137665, 0.03666927751951984, 0.08530478472156183, 0.024358219733195643, 0.028724382232342447, 0.041474916972219944, 0.05814112802701337, 0.07640437981379883, 0.0930202639262591, 0.06000118250293391, 0.03369167247521026, 0.039927185380033085, 0.08778166145618473, 0.012435867517654384, 0.1877658659858363, 6.943345274244036, 28.610206501824514, 53.81824493408203, 43.332381452832905, 28.222615139825002, 29.7683687210083, 53.029707772391184, 55.78065592902047, 10.125601989882332, 0.40722306285585674, 0.14067157304712705, 0.18677519128790923, 0.513503468462399, 11.770703520093646, 13.453503370285034, 0.1614906151912042, 0.3341977670788765, 0.8147218823432922, 17.68957339014326, 49.62377725328718, 71.10746833256313, 73.1524760382516, 63.82325485774449, 59.96173790522984, 64.35427788325718, 66.39250414712089, 63.79223115103585, 64.65976933070591, 60.0022736958095, 58.63960688454764, 56.17491756166731, 56.27727147511074, 49.886353152138845, 56.14287594386509, 59.71880108969552, 62.32371548243931, 60.749476024082725, 63.37306022644043, 61.63213348388672, 59.46954836164202, 61.80728367396763, 63.9094820022583, 64.72162219456264, 66.24601527622768, 60.64881747109549, 50.93538522720337, 64.02314063480922, 55.27701922825405, 38.053202697208945, 54.81644398825509, 55.306100913456504, 69.84181921822685, 64.29975536891392, 68.13887827736991, 61.104473386492046, 60.516086033412385, 56.28124931880406, 52.261997835976736, 50.07640027999878, 51.54055595397949, 60.17908450535366, 57.879196030753, 56.487787996019634, 58.068711621420725, 52.50541755131313, 51.48949711663382, 48.01022836140224, 49.02069446018764, 47.53416906084333, 49.72418219702584, 47.425478390284944, 55.658002853393555, 56.88288688659668, 59.58610439300537, 61.705652373177664, 62.60137244633266, 65.09931237357003, 68.9375945499965, 59.50356674194336, 66.15287467411586, 66.99251583644322, 33.01787097113473, 6.100809752941132, 0.3882048933633736, 0.07530197753970112, 0.1925445031374693, 0.6375540548137256, 3.1024670771190097, 1.2150366987500871, 1.494254184620721, 0.2637349452291216, 0.036711390795452256, 0.11742960448775973, 8.479968053953987, 50.5603666305542, 38.088430064065115, 15.212075063160487, 28.08759774480547, 37.75671264103481, 37.552428654261995, 14.013196400233678, 0.2954003560755934, 0.07457709179392882, 0.03501506342685648, 0.010679392260499299, 0.034750794393143485, 0.05865133886358567, 0.024657514744571278, 0.05194376914628914, 0.044354589057288, 0.05709068796464375, 0.038593911565840244, 0.033985227080328126, 0.018687151272648146, 0.021248273218848875, 0.03359348167266164, 0.0644261943442481, 0.015747148942734514, 0.044632198089467626, 0.041360817916159115, 0.025187715222792964, 0.049976037948259285, 0.021028874009581547, 0.05197181299860988, 0.0628537776480828, 0.038241083534168344, 0.01671947944643242, 0.03995405197409647, 0.04921926444928561, 0.035276421545339484, 0.04108530216451202, 0.07163000386208296, 0.013350145109663052, 0.008895235319089676, 0.05379709594749978, 0.1146028818828719, 0.03157829034275242, 0.007189639162139169, 0.09846999256738595, 0.02457051976983036, 0.029384338962180272, 0.028162972535938025, 0.022339118345241462, 0.09991680564624922, 0.048744815800871165, 0.041634379486952505, 0.004169322882911989, 0.08390377954180751, 0.04549251603228705, 0.053877621090837886, 0.05243063837821994, 0.034956505854747126, 0.05473050907520311, 0.028816340690744773, 0.06572223694196769, 0.07629918652985777, 0.018016957145716463, 0.06232110730239323, 0.0407728503591248, 0.004949549096636474, 0.04247667893235173, 0.053907266285802634, 0.04411877778225711, 0.034577089428369484, 0.01480843815287309, 0.03680959177602615, 0.023229196833978807, 0.03348129269267831, 0.06106028067214148, 0.04373933082180364, 0.04572027988199677, 0.10720309788095099, 0.016489632494215454, 0.0310364597743111, 0.012625194054895213, 0.42752716477428165, 13.20116651058197, 40.53853164400373, 59.57761369432722, 32.85829864229475, 23.159237010138376, 43.03188576017107, 77.74516582489014, 56.41406413487026, 3.9343323366982594, 0.21109662763774395, 0.18602264166942664, 0.18614437085177216, 0.8698184373123306, 13.21724898474557, 14.857979229518346, 0.47452114309583393, 0.6123493015766144, 2.047350985663278, 25.8034382547651, 59.09321308135986, 75.59642151423863, 70.82144573756626, 64.32517187935966, 63.43462126595633, 64.92791421072823, 71.3199234008789, 67.77031108311245, 69.48122160775321, 61.502188273838584, 57.55003901890346, 56.89265605381557, 56.11494765962873, 52.82551758629935, 58.44675963265555, 63.374317850385395, 63.74834632873535, 63.451408113752095, 66.32679503304618, 62.89123044695173, 61.19176360539028, 63.83107852935791, 65.26723643711635, 65.72019645145961, 66.46732234954834, 63.596423966544016, 53.05225120271955, 62.667130197797505, 54.16599185126168, 41.69019208635603, 49.09124994277954, 55.48431525911604, 70.5677878516061, 64.86613777705601, 68.88509396144322, 62.433934756687705, 61.754393986293245, 56.25851828711373, 53.68263694218227, 50.18046692439488, 51.16739252635411, 58.754641260419575, 57.47203506742205, 57.06702109745571, 58.51156548091343, 54.375292437417166, 52.90716239384243, 49.872821535382954, 51.70413391930716, 51.28980588912964, 53.43159852709089, 50.76115567343575, 56.95191376549857, 57.871309825352256, 60.88010910579136, 63.85201345171247, 64.23574161529541, 64.76929378509521, 69.5898288999285, 61.98305920192173, 62.88203798021589, 69.44747420719692, 43.10829857417515, 10.874173981802803, 0.4420392374907221, 0.461351429777486, 1.5194744084562575, 3.631906130484172, 5.549623489379883, 1.3298763079302651, 0.6821939508829797, 0.2936927548476628, 0.2506677449813911, 0.049682184787733216, 6.555554151535034, 51.507805619921, 58.186243874686106, 21.808621849332535, 16.33803411892482, 31.80470507485526, 44.50586271286011, 21.808361291885376, 0.9179051284279142, 0.13504843121128424, 0.08747288731059857, 0.03154460447175162, 0.03333988938746708, 0.04206053001273956, 0.052895808060254366, 0.014939222385042479, 0.030768655573150942, 0.01648337470500597, 0.02141149142490966, 0.07579418684222869, 0.05160521070605942, 0.048389670572110584, 0.07316890092832701, 0.059383539216859, 0.034136062022298574, 0.02424787636846304, 0.059874316810497215, 0.030650308887873377, 0.014950791407110435, 0.047407131509057114, 0.053868023212999105, 0.06538007208811385, 0.037700196129402945, 0.045759875793009996, 0.04425695465345468, 0.048436550556549, 0.05625219849337425, 0.056049326700823646, 0.029834984602140527, 0.029141766085688556, 0.0509230624884367, 0.03761450733457293, 0.19995546261114733, 0.10008320957422256, 0.14640095989618981, 0.11819353992385523, 0.2036814476762499, 0.1443501149437257, 0.222099615793143, 0.0949110696092248, 0.17840722602392944, 0.15205505649958337, 0.15229282874081815, 0.0814964526465961, 0.1414471250027418, 0.17029270716011524, 0.20019995234906673, 0.13950282361890587, 0.13185706388737473, 0.30446927515523775, 0.15579006608043397, 0.1534202146743025, 0.15632906715784753, 0.1342586028788771, 0.21815067769161292, 0.10664682808731284, 0.09007563907653093, 0.13040901587477752, 0.11177581322512456, 0.1281943182860102, 0.1513106764427253, 0.07753262748675686, 0.1742365698197058, 0.11572215253753321, 0.09608253317752055, 0.16806389604296001, 0.22067230381071568, 0.10169537485178028, 0.18337411593113626, 0.2351253575512341, 0.17752868602318422, 0.1316453745322568, 0.2782872143600668, 11.075264402798243, 47.607333592006135, 71.4772584097726, 52.85730559485299, 42.11830881663731, 43.141455377851216, 65.6497278213501, 69.81888321467808, 15.43135152544294, 0.41356150273765835, 0.2451950886419841, 0.8945622209991727, 1.394191439662661, 16.16243577003479, 18.940037216459, 0.496112833065646, 0.3920044723365988, 1.3438090745891844, 22.172412157058716, 55.913595812661306, 75.17495073590959, 73.85607842036656, 66.135087285723, 60.43988513946533, 66.54746982029506, 70.73576055254254, 71.05362674168178, 70.7059805733817, 67.17431545257568, 64.07746859959194, 64.26106779915946, 62.26750455583845, 55.254138810294016, 60.119510650634766, 65.29890632629395, 65.76652703966413, 65.85719408307756, 67.35950578962053, 65.17725031716483, 61.09366198948452, 65.41930471147809, 68.3619224003383, 67.42436027526855, 67.00633580344063, 64.7386313847133, 55.27738400868007, 70.60038879939488, 59.349191665649414, 49.92635045732771, 61.95951175689697, 57.373818806239534, 72.71442685808454, 68.58693981170654, 72.97868769509452, 65.82878289903913, 67.03232901436942, 62.1526369367327, 58.4631712777274, 53.99730348587036, 56.60785634177071, 66.38855757032121, 63.752765383039204, 60.69814968109131, 63.43119580405099, 57.465788636888774, 57.512970379420686, 52.96552726200649, 54.934049197605674, 52.01632343019758, 53.62088482720511, 52.245343003954204, 62.32167271205357, 63.67799581800188, 63.96887520381382, 65.98345674787248, 66.19014481135777, 68.76825305393764, 69.49799455915178, 62.66224561418806, 66.74846036093575, 68.29446928841728, 38.6214576448713, 8.748221499579293, 0.8683366796800068, 0.20152446627616882, 0.7406633677227157, 1.6453103018658501, 9.753822990826198, 7.756344437599182, 3.285832643508911, 1.9624133833817072, 0.44367488686527523, 0.42752534630043165, 12.487679447446551, 61.403857367379324, 48.47909280232021, 25.598160675593785, 37.858514172690256, 47.18584891727993, 55.06647491455078, 24.41132324082511, 0.6812546955687659, 0.2796068292643343, 0.1456309447863272, 0.16614322124847344, 0.19645689534289495, 0.09647105554384844, 0.16487659992916243, 0.21911436026649816, 0.19029974644737585, 0.126892358862928, 0.22720760027212755, 0.15421384280281408, 0.08689974235104662, 0.11537115994308676, 0.08427888048546654, 0.1482470908335277, 0.13544582203030586, 0.0803970969947321, 0.2790214978158474, 0.19140185016606534, 0.13452553855521338, 0.12920249918741838, 0.14742809906601906, 0.22149649315646716, 0.18358488247862884, 0.08975520091397421, 0.1186341398528644, 0.13716060215873377, 0.1226437118436609, 0.15135669468769006, 0.1134062921628356, 0.15471845572548254, 0.09746598465634243, 0.1581483959619488], [0.02771017254729356, 0.016045454989320466, 0.06632928151105132, 0.06268141618264572, 0.028088942669065933, 0.0363926761118429, 0.054556444486869235, 0.06337180520806994, 0.04998979185308729, 0.05911530753863709, 0.06685673392244748, 0.09210046221102987, 0.0607290334467377, 0.04879034889329757, 0.02243903262673744, 0.05099506523194058, 0.04152784270367452, 0.046869022705193074, 0.0179696971816676, 0.020356410183012486, 0.05137355885069285, 0.05132905713149479, 0.03417024661653808, 0.04769070486405066, 0.11384080563272748, 0.07938128935971431, 0.024059170690764273, 0.060258014792842526, 0.061267844534346035, 0.03682253822418196, 0.07786441075482539, 0.02227229282392987, 0.028855230925338607, 0.025895944630194987, 0.09300126494573695, 0.022956741275265813, 0.031040632764675787, 0.02801919266182397, 0.02316438825801015, 0.03832447888063533, 0.05962764218981777, 0.10404226463288069, 1.40225373847144, 25.38265882219587, 58.00899185453142, 53.334837913513184, 35.95266151428223, 26.468512875693186, 33.683056763240266, 63.940700258527485, 25.116775580814906, 0.8691849570189203, 0.28481971525720184, 0.5743731079357011, 0.6651369375841958, 7.57914366040911, 11.28515384878431, 1.7553173303604126, 0.06385961081832647, 0.3629001783473151, 1.5865739222083772, 14.3230938741139, 50.49308374949864, 71.2726617540632, 65.23671994890485, 71.50695501055036, 72.1055770601545, 68.75331442696708, 63.89553001948765, 60.41982569013323, 59.24414185115269, 61.23880985804966, 61.86553042275565, 59.487690108163015, 64.35652909960065, 68.70082078661237, 65.40783323560441, 66.5779585157122, 67.72013814108712, 63.271713801792686, 62.82740429469517, 64.88301495143345, 66.25845255170549, 65.70822470528739, 66.63609409332275, 56.76745298930577, 59.350942611694336, 65.98383889879499, 46.06653928756714, 30.099999291556223, 47.61184992109026, 55.6074720791408, 59.280890873500276, 66.88153226034981, 60.83638409205845, 61.322521754673545, 56.551099981580464, 51.845199721200125, 48.69755458831787, 53.41908482142857, 59.783405440194265, 60.59168938228062, 63.83268356323242, 59.616363797869, 59.362483569553916, 63.44707938602993, 59.98191547393799, 58.00450679234096, 58.88615676334926, 58.26443542752947, 61.57507487705776, 64.87938104357038, 62.429508754185264, 61.56221376146589, 63.57808767046247, 64.51615701402936, 63.13122122628348, 59.263645444597515, 61.626769474574495, 78.54742567879813, 51.33704669134957, 10.887810690062386, 0.6990338329757962, 0.10795589177204029, 0.09121958804982049, 0.3166325039097241, 4.199262372085026, 11.763694524765015, 5.058641195297241, 2.228479883500508, 0.5169774049094745, 0.07999901406999145, 0.21577455662190914, 19.87290757043021, 51.80290256227766, 37.39858511516026, 16.66433194705418, 33.83030993597848, 39.37917954581124, 33.959004470280235, 11.058624335697719, 0.0916399812059743, 0.06375154054590634, 0.08494867597307477, 0.10768226574042014, 0.023601749878642813, 0.019268981480438794, 0.06868276665253298, 0.006651835274949137, 0.06847187118338686, 0.126054761665208, 0.02863061547811542, 0.04472333891317248, 0.03081469078149114, 0.018219574487635067, 0.037668199810598574, 0.0692836908357484, 0.12930719714079583, 0.033273681333022456, 0.017112897442919866, 0.009901836930241967, 0.05935643852821418, 0.07234280489917312, 0.019088599731081297, 0.04432750193934355, 0.007936125222061361, 0.039752024957644086, 0.04861595521547964, 0.0611570126244, 0.008834702361907278, 0.08523181506565639, 0.008839897395643805, 0.03140667526583586, 0.014938145210700375, 0.05884848042790379, 0.033860949998987575, 0.0324919954208391, 0.029642423149198294, 0.06273643180195775, 0.03250427690467664, 0.013554877784502293, 0.03073768044954964, 0.03159288223832846, 0.05898854362645319, 0.05838276791785445, 0.02268401769522045, 0.06276234505431992, 0.045318895884390385, 0.05256331233041627, 0.0335381776759667, 0.0351904138390507, 0.01020386050056134, 0.020396794890984893, 0.054426291292267184, 0.04530100630862372, 0.07838964435671057, 0.07295711657830647, 0.029947516242308275, 0.04889593572754945, 0.00543808752471315, 0.08070697715239865, 0.02848422833319221, 0.015070349277396287, 0.0705736605450511, 0.05262377658592803, 0.010994263043228005, 0.023158059222623706, 0.03897087508812547, 0.027831815216424208, 0.01887855921605868, 0.015181603575391429, 0.050399898418358395, 0.09560683941734688, 0.033106134073542695, 0.012443238104294454, 0.08312372211366892, 0.07199652133775608, 0.21246762121362345, 4.2755496842520575, 39.463846819741384, 65.89043426513672, 47.76237916946411, 29.823672907693044, 31.6005357333592, 59.61831624167306, 76.80037757328579, 17.846124989645823, 0.4606855426515852, 0.14249885428164685, 0.5218320244124958, 0.7673546011958803, 8.496954662459236, 15.164375679833547, 4.285913356712886, 0.22344391580138886, 0.08986102523548262, 4.060197651386261, 22.263610737664358, 61.192104067121235, 75.06048611232212, 64.66074207850865, 72.75407327924455, 73.02582427433559, 68.77157429286412, 63.80061762673514, 61.14039557320731, 62.45852443150112, 63.72206129346575, 65.76742335728237, 60.51314694540841, 65.97419479915074, 70.73265470777238, 68.12054892948696, 66.53878457205636, 67.49650342123849, 63.61490617479597, 61.11897427695138, 65.2568141392299, 63.542380877903526, 65.15386268070766, 65.58499840327671, 57.12776572363717, 58.0204633304051, 67.36817019326347, 53.98054790496826, 36.370682512010845, 53.22174555914742, 53.34291172027588, 64.35644572121757, 66.7852371760777, 62.02572808946882, 64.08152634756905, 58.83838789803641, 54.475732122148784, 51.97819519042969, 53.38325990949358, 58.99767535073416, 61.48589474814278, 64.61576638902936, 60.76670755658831, 61.260592460632324, 64.64346190861293, 62.39477470942906, 58.93327249799456, 60.35837582179478, 56.99433946609497, 60.771814482552664, 63.189467975071494, 63.34697668892996, 64.48573780059814, 63.116143635341096, 65.47547394888741, 66.38392312186105, 63.388248988560264, 63.883176122392925, 76.24753025599888, 61.691102845328196, 18.003282819475444, 1.5580968388489314, 1.0391061391149248, 0.6374219847576958, 3.82412565605981, 6.432495474815369, 5.939204207488468, 0.3992093471544129, 0.6038805331502641, 0.41785082114594324, 0.1742054522037506, 0.3315787304724966, 15.09618432181222, 59.04224804469517, 51.0543383870806, 18.72328121321542, 21.476470163890294, 39.84988178525652, 44.64613989421299, 16.362856558391027, 0.06856759890381779, 0.12726574311298983, 0.05712979193776846, 0.050656581430562904, 0.011324783387993063, 0.05757970815258367, 0.07667683876518692, 0.05808835157326289, 0.05055804118247969, 0.07723911359374012, 0.0049391378249440876, 0.014503071949418102, 0.07678144172366176, 0.0060604021003070685, 0.061662948690354824, 0.07653881117169346, 0.05272819294727274, 0.01939646463974246, 0.01430677346486066, 0.026745317803163613, 0.05680913325133068, 0.02611495368182659, 0.08557989674487285, 0.0373554223084024, 0.029543129727244377, 0.0024432006175629795, 0.02231201935293419, 0.060905140425477705, 0.019848735371072377, 0.09488909864532095, 0.011282117954189224, 0.05266900433759604, 0.012103130059715892, 0.05390952920008983, 0.022132160075541054, 0.12020722829869815, 0.10161757402654205, 0.14080113252358778, 0.08371749453778778, 0.10324034480644123, 0.1020373497158289, 0.09544162971100636, 0.20593649095722608, 0.1439907627978495, 0.17160506173968315, 0.1386612502059766, 0.14104864852769033, 0.09824135340750217, 0.1465480662882328, 0.11926637164184026, 0.09127337552074875, 0.17956161765115602, 0.10868824140301772, 0.10283463514809098, 0.2349286095372268, 0.14129408821463585, 0.13315305220229284, 0.06837430463305541, 0.09650611544826201, 0.16975693590939045, 0.18064460025302, 0.050925824125962596, 0.18346654597137654, 0.1851532483207328, 0.08761189877986908, 0.1857972051948309, 0.1393535187734025, 0.10915640342448439, 0.0441566400362977, 0.2862469729568277, 0.19593424695943082, 0.1442818950329508, 0.17807346821895667, 0.15590357141835348, 0.18598391089056218, 0.23252065160444804, 0.24607086021985325, 3.3099012034279958, 39.95753717422485, 77.83520058223179, 68.1129128592355, 48.77768816266741, 40.51776695251465, 48.432216780526296, 82.79253877912248, 34.724991253444124, 1.9927843936852045, 0.5821604643549237, 1.5578628799745013, 2.0717712981360297, 8.646465131214686, 15.39276123046875, 3.4038226093564714, 0.14333277381956577, 0.2915432373327868, 3.0851345786026547, 18.969504526683263, 54.43918807165963, 73.54633467538017, 68.4517000743321, 74.66065897260393, 78.17390441894531, 75.85802119118827, 68.06837490626744, 64.10310745239258, 65.40829181671143, 65.99781867436, 67.04443277631486, 64.28345489501953, 70.57950946262905, 76.21867438725063, 72.17643478938511, 69.28833961486816, 70.15646144321987, 65.84888403756278, 66.19796848297119, 68.6601460320609, 65.5441221509661, 65.9537740434919, 67.19727230072021, 56.621794428144185, 62.23181165967669, 65.6582532610212, 54.10181481497628, 39.25907645906721, 52.89948116030012, 59.080685479300364, 62.884296144757954, 71.11546570914132, 61.72382886069161, 66.40913813454765, 61.30286530085972, 56.60852336883545, 53.20733152117048, 57.0335898399353, 63.598584856305806, 62.88608183179583, 68.71096515655518, 62.877000536237446, 65.18715844835553, 68.84858812604631, 66.04898520878383, 64.93083940233502, 66.19583538600376, 63.81697368621826, 67.4012644631522, 69.91711684635708, 67.48706081935337, 65.20145784105573, 68.57645498003278, 71.30595057351249, 69.38004193987165, 62.141068186078755, 63.45436804635184, 79.36414473397392, 57.039131028311594, 13.430012379373823, 1.4795753551380975, 0.5685688108205795, 0.1666603327861854, 2.186000334365027, 9.868802649634224, 22.59308910369873, 17.372179678508214, 5.0102105140686035, 1.441483050584793, 0.4422384553721973, 0.9482373808111463, 27.532019785472325, 63.12041677747454, 47.515870979854036, 28.224247966493877, 42.94714205605643, 50.95879718235561, 54.260348388126914, 16.513172149658203, 0.09394628102225916, 0.13329562598041125, 0.17131312883325986, 0.16841528218771729, 0.1114689050508397, 0.23229301667639188, 0.2062641012349299, 0.11895124640847955, 0.127813280160938, 0.23576850018330983, 0.23536998299615725, 0.0763398307774748, 0.13772044783192022, 0.18497435934841633, 0.15882599460227148, 0.22221214404063566, 0.21442915738693305, 0.14156831135707243, 0.14381853703941616, 0.09317834901490382, 0.10806398918586117, 0.19906127559287207, 0.15151834887053284, 0.13030473861311162, 0.07995030882635287, 0.07981658993022782, 0.07913833989628724, 0.1281025939221893, 0.10956220807773726, 0.14938967595142977, 0.1936239166451352, 0.09248067930872951, 0.12139545168195452, 0.1907677591911384, 0.09436936117708683], [0.050481780631733794, 0.06724516807922296, 0.00726595484385533, 0.03865872523082154, 0.0749696446582675, 0.026244396110996604, 0.03415217722899147, 0.019308545161038637, 0.01590388035401702, 0.07326652176145997, 0.025732056370803287, 0.09080016519874334, 0.036349785913314135, 0.014815433848915356, 0.03537522642207997, 0.016772245722157613, 0.07660608791879245, 0.061573470277445655, 0.04727504448965192, 0.03630816796794534, 0.019157937528299432, 0.027582351816818118, 0.05856903935117381, 0.07103384299469845, 0.07697654089757375, 0.005306803721136281, 0.025138843738074814, 0.002518128483123811, 0.06896490151328699, 0.04603595472872257, 0.03948480768927506, 0.10029989973242794, 0.012238336643869323, 0.040906657464802265, 0.042108298878052404, 0.11823274567723274, 0.017537489034501568, 0.02789115480014256, 0.021988995971956422, 0.1215423002306904, 0.08330656015979392, 0.0706737580310021, 0.09139885021639721, 0.36891959820474896, 17.17363837787083, 54.56138604027884, 52.56954595020839, 46.28518867492676, 35.12010056631905, 26.74597007887704, 54.186964988708496, 52.78114986419678, 13.022951296397618, 0.3845968783966133, 0.3461610722754683, 0.5793454125523567, 2.8920897373131345, 0.671842383486884, 0.5241298153996468, 0.5964150737438882, 0.35815765282937456, 0.4045162781008652, 2.6295985196317946, 29.1912339755467, 61.645369802202495, 73.94137450626918, 67.74465138571603, 66.18788664681571, 72.95689119611467, 71.92670263562883, 70.62973799024309, 68.74902738843645, 63.212237221854075, 61.53556741986956, 61.5502142224993, 63.36591747828892, 62.14692551749093, 64.13524981907436, 60.452107020786826, 60.8681651524135, 59.09078121185303, 63.17310496738979, 67.2721391405378, 71.39055183955601, 68.43032741546631, 58.946057183401926, 63.84851850782122, 68.73158740997314, 38.14168800626482, 36.35532004492623, 40.011621952056885, 64.78010518210274, 60.6062319619315, 67.97929205213273, 71.63625403812954, 66.17484487806047, 60.91154275621687, 64.16845526014055, 63.055173192705425, 70.58588790893555, 68.86609063829694, 68.53181975228446, 68.81429181780133, 64.55221121651786, 65.06241743905204, 64.88855266571045, 65.25976017543248, 63.06975051334926, 63.51365007672991, 60.94272627149309, 57.39280475888933, 60.60270227704729, 66.29338114602226, 67.65536703382219, 69.81765338352749, 69.95408126286098, 69.46474048069545, 75.94878550938198, 72.2579093660627, 34.65981715066092, 4.127732838903155, 0.22840560813035282, 0.32528482962931904, 1.5675987175532748, 4.593789773327964, 7.84019182409559, 4.844671419688633, 7.962371553693499, 3.188241068805967, 0.1367677575243371, 0.16532872138278826, 5.2495043022292, 40.73850427355085, 48.71598815917969, 28.231798921312603, 20.39849363054548, 31.95560952595302, 38.91304227284023, 26.190591880253383, 5.68191545350211, 0.16341834674988473, 0.07146695189710174, 0.030298305276249136, 0.05979332687067134, 0.0027389365007236066, 0.03127788931929639, 0.01662912911602429, 0.0489033928274044, 0.061472802822078974, 0.04521990780319486, 0.032248279212840965, 0.03368957919467773, 0.014159545784683099, 0.05685587413609028, 0.041718382122261186, 0.03249224308612091, 0.07761245034635067, 0.00316225817160947, 0.03946826161284532, 0.05465248094073363, 0.10788890679499932, 0.06799908155309302, 0.08323356336248772, 0.06805325578898191, 0.061979539559355805, 0.09859154533062663, 0.0721491374341505, 0.02615129092841276, 0.011968103287342404, 0.05038750836891787, 0.05741671047040394, 0.03267601411789656, 0.04784719878807664, 0.04531578480132988, 0.022654911935595528, 0.0827720102721027, 0.06329949373113257, 0.036288765259087086, 0.05649611486920288, 0.03494872984343341, 0.08287629431911878, 0.030395668266074996, 0.03670069029820817, 0.009424832749313541, 0.050447019282728434, 0.015978017090154544, 0.036453221791556904, 0.053857828224343915, 0.019470421564100043, 0.04878444563863533, 0.018085928534024527, 0.012833685813737767, 0.10254910761224371, 0.026167202574600066, 0.0522835659129279, 0.01228244396458779, 0.025951805025605217, 0.01701109004872186, 0.051851885326738865, 0.019737291083272015, 0.032680628156023364, 0.10750651838524, 0.043961903878620694, 0.04933020492483463, 0.048098918316619735, 0.021164553871910487, 0.05066680695329394, 0.02503912283905915, 0.011341185275731342, 0.02124726559434618, 0.07583211016442094, 0.1142382100224495, 0.03820836118289402, 0.04492984765342303, 0.005091673769389412, 0.02546894593563463, 0.026606594711276035, 0.0733643936525498, 0.1025359168914812, 1.1723158082791736, 27.70487185886928, 64.96262046269008, 54.51159177507673, 37.96063879558018, 26.629332406180247, 44.54284797395979, 74.52876826695034, 56.49918304170881, 6.840227493218013, 0.4537960780518395, 0.287438724722181, 0.9765357651880809, 1.6905819411788667, 3.1949523772512163, 1.3762448940958296, 2.0632004780428748, 0.7644599165235246, 0.24819185212254524, 5.44259387254715, 37.81103365761893, 66.39515835898263, 74.17760631016323, 71.69272204807827, 72.49942874908447, 77.74098995753697, 70.32363510131836, 70.36893040793282, 68.8163206917899, 62.63291031973702, 62.26413467952183, 64.1975543158395, 66.5631935937064, 63.275299072265625, 65.50526087624687, 63.50010108947754, 60.830512864249094, 60.533588545663015, 62.76138251168387, 66.61746597290039, 69.29180676596505, 67.89165442330497, 62.0828492300851, 64.54630524771554, 65.46425955636161, 42.58955996377127, 36.02552032470703, 47.33566944939749, 61.53947230747768, 61.33294405255999, 73.52505929129464, 69.31679943629673, 65.40165628705705, 60.0005783353533, 61.627832548958914, 59.97621100289481, 67.90442521231515, 70.27313559395927, 69.88109738486153, 69.43655858721051, 65.56118692670549, 68.12592683519635, 69.55180835723877, 64.58769566672188, 65.32944365910122, 64.77375452859062, 66.63057722364152, 59.027913911002024, 64.8331755229405, 68.44748251778739, 67.59492465427944, 74.01792975834438, 73.34797055380685, 67.92112173352922, 70.1423704964774, 72.2329375403268, 47.85749305997576, 6.663348938737597, 0.7923183930771691, 2.0729168823787143, 6.676134058407374, 9.142864414623805, 7.346348609243121, 2.131527543067932, 0.8249751435858863, 0.8896623296397073, 0.2562853364007813, 0.42263954132795334, 3.024197791303907, 40.23614256722586, 66.77183410099575, 41.022227014814106, 22.20775764329093, 26.691021987370082, 43.75411973680769, 34.680658272334504, 9.003331559044973, 0.05617997183331421, 0.06308080189462219, 0.06409381396536316, 0.1541619755859886, 0.06447194796055555, 0.013683868987884904, 0.0561808844629143, 0.03314313458810959, 0.017121884639241865, 0.06449977468167033, 0.057979948818683624, 0.07145794095205409, 0.015071434933426124, 0.04157132322766951, 0.09883432516029902, 0.021839906561321447, 0.03289543877222708, 0.037482942787132094, 0.0935352041519114, 0.03952501088912998, 0.02322866757666426, 0.07077483939273016, 0.07709434814751148, 0.057959898108882565, 0.06110350335282939, 0.1497445497661829, 0.029948381374457052, 0.03911221393250993, 0.05159134484295334, 0.01907478306176407, 0.04881866415962577, 0.045426823664456606, 0.0915779359638691, 0.02102178331863667, 0.01902631700171956, 0.06805039237120322, 0.1653624310025147, 0.16034128543521675, 0.15951431409588882, 0.1355194973626307, 0.19553461697484764, 0.09558844433299132, 0.1444158921284335, 0.11505215348941938, 0.12777049174266203, 0.11478763339774949, 0.09046779839055878, 0.27960680212293354, 0.11855347560984747, 0.29985187149473597, 0.0968746142461896, 0.1398893850190299, 0.1494669746607542, 0.13371342713279383, 0.1710802149027586, 0.18134815964315618, 0.1653460647378649, 0.06772960815578699, 0.15606317642543996, 0.1832558744187866, 0.2737243377736637, 0.16942414162414415, 0.12492068537643977, 0.15087900603456156, 0.1816104541399649, 0.14530524797737598, 0.14296850908015454, 0.16049771489841597, 0.12452679579811436, 0.15493428414421423, 0.24428506461637362, 0.39244218170642853, 0.12307766212948731, 0.14694304152258805, 0.12031873874366283, 0.14128400518425874, 0.1853645034134388, 0.43435838392802645, 0.15298736361520632, 0.821506743984563, 25.031316212245397, 74.79392542157854, 70.17478384290422, 59.333620752607075, 49.198801108769004, 39.98364503043038, 68.36919021606445, 68.92137745448521, 19.406299557004655, 0.6056726798415184, 0.9602908768824169, 2.3238717019557953, 5.512885757855006, 4.307426282337733, 1.393636235169002, 1.2448821429695403, 0.37582559191754883, 0.36205518511789186, 4.915286830493382, 35.12150410243443, 65.67344202314104, 75.06276512145996, 73.199216570173, 74.49438163212368, 79.85991954803467, 75.41164806910923, 79.15927015032086, 75.11883013589042, 67.83014896937779, 66.64129829406738, 68.30810165405273, 68.41608360835484, 65.22686045510429, 67.67021533421108, 63.8551401410784, 61.870553970336914, 60.268493924822124, 64.24444770812988, 70.56111758095878, 69.57871178218296, 68.36662633078438, 61.720299175807405, 62.33555521283831, 68.01424843924386, 53.38342319216047, 41.10555676051548, 53.25221340996878, 70.26655564989362, 61.779622895377024, 73.39302962166923, 73.93011842455182, 70.24739251817975, 63.96583884102957, 68.90603583199638, 66.9292802810669, 76.72105693817139, 74.55659580230713, 76.01834392547607, 73.19868850708008, 70.35674326760429, 70.92826039450509, 71.61122662680489, 70.4403578894479, 67.88296222686768, 69.08921119144985, 68.20293372017997, 61.24365970066616, 64.41030815669468, 76.37020765032086, 73.12064634050641, 74.97171592712402, 72.36411258152553, 71.72926262446812, 78.78948007311139, 74.86953571864537, 40.70035171508789, 6.198850572109222, 0.6007062920502254, 1.0355260797909327, 4.185752034187317, 11.38552405153002, 17.59737774303981, 13.30596011025565, 15.166420187268939, 9.957431265286036, 0.9476484124149595, 0.6929847204259464, 8.306748594556536, 49.632587569100515, 59.84273610796247, 37.00392048699515, 32.03837646756853, 39.98611511502947, 54.4030122756958, 43.31613656452724, 9.065580470221382, 0.2951124400964805, 0.14323959739080497, 0.21240911792431558, 0.22356987904225076, 0.22719910501369409, 0.12966331945998327, 0.1349525542131492, 0.11874907011432306, 0.16884699330798217, 0.15963288130504744, 0.05865823956472533, 0.16409213202340261, 0.10567006335726806, 0.20294032458748135, 0.12300839727478367, 0.1312398820051125, 0.1580107890601669, 0.2745598857956273, 0.14477396862847464, 0.16840903966554574, 0.17995212812508854, 0.16776428212012562, 0.199469156563282, 0.13964596736643994, 0.21801928617060184, 0.1900340321340731, 0.13626178753163132, 0.17685344868472644, 0.0760499674028584, 0.14611927286854812, 0.13021582338426793, 0.11778272768216473, 0.2581299745610782, 0.15503773359315737, 0.1592711407159056, 0.23919469490647316], [0.031004728084164004, 0.023667752676244293, 0.03379536619676011, 0.05324076508570995, 0.04248849901237658, 0.051289084633546214, 0.05916888466370957, 0.05791547442121165, 0.07848550778414522, 0.04061463974150164, 0.032379663948501856, 0.022847643022292426, 0.06392281635531358, 0.018779196244265352, 0.02458367486750441, 0.07307133437799555, 0.007182806314501379, 0.022061533061787486, 0.035152409092656205, 0.0516090376435646, 0.049788884419415674, 0.048162992378430705, 0.004272783782133567, 0.041047677397727966, 0.116154406485813, 0.02709907033879842, 0.02901279354201896, 0.013398069189861417, 0.07004246940570218, 0.022295559789719324, 0.03443193382450512, 0.05555358901619911, 0.007060128455382905, 0.06394459732941218, 0.07632363414657967, 0.08292445673474244, 0.07187239014144454, 0.045237427577376366, 0.025983214411618452, 0.0933066735576306, 0.05672225023486784, 0.023008876513423662, 0.06645812174039227, 0.1548460881624903, 0.40910404335175243, 6.808388241699763, 40.43626805714199, 56.0764650617327, 49.59349700382778, 32.4917950630188, 24.772049392972672, 30.64623887198312, 58.67984390258789, 45.724385670253206, 3.8226530722209384, 0.20335044472345284, 0.9564578597034726, 2.4066479802131653, 1.2891855942351478, 1.7333133625132697, 7.748737028666905, 0.2059718697730984, 0.10191664512136153, 0.13338192206408295, 9.583269034113203, 49.45559958049229, 72.54055513654436, 75.18871511731828, 64.52398068564278, 64.84761387961251, 67.64930820465088, 67.50460502079555, 69.91193349020821, 68.64885520935059, 71.77103519439697, 70.12517370496477, 70.23232187543596, 68.17123603820801, 65.9202628816877, 65.48926612309047, 66.97010789598737, 69.19788796561105, 65.77186325618199, 70.22046824863979, 56.46617215020316, 70.280563218253, 75.11294501168388, 45.831481729234966, 37.393606730869834, 56.605414049965994, 29.413968903677805, 60.4526698248727, 54.36837550571987, 61.2565347126552, 64.77281652178083, 64.23432418278286, 64.55774198259626, 60.83862141200474, 64.16860117231096, 64.99778529575893, 69.75853810991559, 65.2296883719308, 63.898218972342356, 67.02646473475865, 64.87655312674386, 70.3268312726702, 68.05745233808244, 70.17112909044538, 69.01067570277623, 72.98842212132045, 77.19286741529191, 76.09873458317348, 70.85102421896798, 71.59471770695278, 66.88343606676374, 64.07701001848493, 77.50030435834611, 55.19032308033535, 11.005562680108206, 0.695575584258352, 0.13498848942773684, 0.32213175882186207, 5.057317563465663, 9.01252749988011, 17.384898356028966, 6.5928902966635565, 3.7956805995532443, 0.886040418275765, 0.4980205478412764, 0.5479563283068793, 22.590704134532384, 51.10827030454363, 36.14649888447353, 19.529511962618145, 23.662733009883336, 30.158888748713903, 33.78271130153111, 17.19377425738743, 1.0861257932015826, 0.33875537823353497, 0.050692336833370585, 0.08014778287283011, 0.022994199800970297, 0.043154080797519, 0.035168066288211515, 0.0444450038485229, 0.04154919620071139, 0.018983927222767046, 0.010079613953296627, 0.017508534248918295, 0.07796825375407934, 0.04631820833310485, 0.12015038063483578, 0.10161257322345461, 0.020201760177899684, 0.04467680158891848, 0.05581787162061248, 0.08821148624909775, 0.026760208254147853, 0.06483693194708653, 0.041260306523846726, 0.03165901565392103, 0.013666880167355495, 0.04804656933993101, 0.12491882619048868, 0.08442253991961479, 0.1270457213478429, 0.03572275170258113, 0.07535343085016523, 0.06389355792530946, 0.033164952881634235, 0.023929439884211336, 0.021995755877079706, 0.06913070154509374, 0.041209830303809473, 0.027732576077271785, 0.05343440540933183, 0.053364285600504706, 0.06730897072702646, 0.020443235523998737, 0.03887273856837835, 0.04286881449765392, 0.004122327971604786, 0.04020468245393463, 0.07534000264214617, 0.03367802035063505, 0.0911244438695056, 0.03197223759655442, 0.013116869011095591, 0.04954481876588293, 0.0314252298059208, 0.04441875132865139, 0.07228675790663276, 0.027057628812534467, 0.07609687452869755, 0.035652832061584504, 0.0713802690484694, 0.045517275775117536, 0.12834716508431093, 0.0203805999564273, 0.08173712901771069, 0.03063987980463675, 0.05056895202557955, 0.025717930968052576, 0.05248906702867576, 0.015463716383757336, 0.011953179757776005, 0.02741946609291647, 0.025718755388100232, 0.018448836203398447, 0.05868825116860015, 0.08730955036090952, 0.0805621234966176, 0.14033702814153262, 0.09879613042409931, 0.0979456953438265, 0.07963926158845425, 0.04150945440466915, 0.056304008034723144, 0.0902022197842598, 0.44380019871251924, 13.028832946504865, 54.865508692605154, 66.06302056993756, 51.04298850468227, 25.106467928205216, 30.51111725398472, 55.45408712114607, 84.11594826834542, 40.12119504383632, 1.1146382689476013, 0.21918529431734765, 0.4875691000904356, 0.8901475093194416, 3.0450009150164465, 3.3359480457646504, 10.8995019027165, 0.7115187144705227, 0.25198860839009285, 0.338649825326034, 16.264961651393346, 59.27153859819685, 72.28421524592808, 71.2683608191354, 65.44345664978027, 65.81436538696289, 73.06468554905483, 70.84224169594901, 71.71171842302594, 70.47865636008126, 71.6361220223563, 69.82196821485246, 71.43824427468437, 66.42297894614083, 64.94111578805106, 65.99640819004604, 62.97692952837263, 65.55414145333427, 64.0302208491734, 70.467942237854, 59.0061799458095, 64.47735827309745, 74.39200687408447, 57.79101644243513, 46.65485715866089, 54.57680409295218, 38.77991826193673, 68.01891762869698, 58.529755864824565, 63.302952902657644, 66.4329913003104, 66.8110636302403, 67.64271436418805, 65.97780091421944, 66.83151912689209, 68.26535633632115, 72.00685010637555, 67.82961395808628, 68.06428936549595, 67.91152627127511, 68.31905896323067, 70.69487040383476, 70.46405124664307, 73.67105484008789, 71.7770801271711, 71.65166514260429, 74.00635405949184, 73.71012456076485, 71.54913752419608, 72.27942098890031, 67.28134550367082, 65.81429590497697, 77.96923133305141, 68.29694284711564, 20.81726155962263, 1.242932304739952, 0.7021999316556113, 2.1267515250614712, 5.5662118792533875, 11.13686192035675, 6.7940063391413, 1.422833759869848, 0.3031569884291717, 0.11053646901356322, 0.26376474648714066, 0.7893005950110299, 18.05802767617362, 62.11685371398926, 55.32784877504621, 26.259486743382045, 19.806580066680908, 31.973077297210693, 43.51925325393677, 25.04088388170515, 2.77015905720847, 0.18483702386064188, 0.050135351185287745, 0.1352164636233023, 0.021208489014367973, 0.029895381004150425, 0.06783149697418724, 0.07153734311993633, 0.018116438861138055, 0.06599452625960112, 0.07377198963825192, 0.07968825181680066, 0.062223018280097415, 0.03718866893489446, 0.08612047202352967, 0.08948137810719864, 0.04546901157924107, 0.11435966779078756, 0.05212205082976392, 0.08669886205877576, 0.034733769949525595, 0.07712513328130756, 0.09887688287666865, 0.043842685275844166, 0.0784708107156413, 0.07918635981955699, 0.09956753653075014, 0.14136810281447001, 0.12016484700143337, 0.055393139233014414, 0.06798125643815313, 0.08655769284814596, 0.029056833857404332, 0.028349264325307946, 0.02684145773361836, 0.027047622117346952, 0.07022190120603357, 0.048653468023985624, 0.20206756570509501, 0.16995381963040146, 0.17998439925057547, 0.16065240731196745, 0.09586893035365002, 0.10117362891989094, 0.11791413277387619, 0.11712344948734556, 0.1112609137115734, 0.1473492532968521, 0.15388662607542106, 0.10434457233973912, 0.11158811686826603, 0.1124910366322313, 0.2061708298112665, 0.1395421786499875, 0.1685138326138258, 0.17118153375174316, 0.15278919067765984, 0.14457931050232478, 0.22627351539475576, 0.15223501755722932, 0.17933707684278488, 0.23639177531003952, 0.20915482326277665, 0.25312987715005875, 0.14427147273506435, 0.1713182178458997, 0.2048520834318229, 0.08765149129820721, 0.11385850182601384, 0.1297619105981929, 0.12833853411887372, 0.19004030179764542, 0.07548399455845356, 0.15801798153136457, 0.20443591076348508, 0.182663567630308, 0.20755827107599803, 0.16808265075087547, 0.18360173728849205, 0.22014805408460753, 0.19621973378317698, 0.20651247219315597, 0.6551059644137109, 11.436984147344317, 60.13411576407296, 83.68099103655133, 64.79380702972412, 48.784723213740754, 39.819153376988, 43.52985967908587, 73.83976405007499, 60.119795526777, 6.884405876908984, 0.27254631955708775, 1.6702430439846856, 11.82506275177002, 10.186159883226667, 2.9595947435923984, 12.96673515864781, 0.40058886313012665, 0.1987517550587654, 0.26402424541967257, 13.623565741947719, 53.54350273949759, 74.40527098519462, 78.3280154636928, 70.88054016658238, 67.90009648459298, 73.19017696380615, 70.49435234069824, 73.73820223127092, 73.74783243451799, 77.98598343985421, 75.19287708827427, 75.01287010737828, 65.90655408586774, 67.85928971426827, 68.55331053052629, 66.21566554478237, 70.50548335484096, 63.31775256565639, 69.29389817374093, 61.86704513004848, 66.04248169490269, 76.54152938297817, 54.35999945231846, 50.78609275817871, 66.01438317980084, 42.25304133551461, 72.11773640768868, 61.76393386295864, 63.22262477874756, 64.22717448643276, 68.64331749507359, 69.76940509251186, 67.0963636125837, 68.77897412436349, 69.67649378095354, 75.4464168548584, 67.75752639770508, 67.9389716557094, 71.8567898614066, 70.88147817339215, 74.7160291671753, 74.6178789138794, 76.7999815259661, 75.94036429268974, 77.30025877271379, 82.12649835859025, 81.23489161900112, 71.81168215615409, 73.34322493416923, 73.94903142111642, 71.11741120474679, 76.41492625645229, 60.58656855991909, 16.09346447672163, 1.2565664074250629, 0.22171021811664104, 0.9013296578611646, 10.500041280473981, 15.946550028664724, 30.965828214372905, 15.405799525124685, 9.695783819471087, 2.712420178311212, 0.8106102858270917, 1.8636178161416734, 30.156665325164795, 63.19204575674874, 47.608285495213096, 29.50949273790632, 34.99937561580113, 41.154461656297954, 54.729198932647705, 27.741011176790508, 2.3051673684801375, 0.4198847977178437, 0.09374724634523902, 0.2628025295478957, 0.197761650330254, 0.09964418384645667, 0.11771537629621369, 0.09883306987051453, 0.17385747230478696, 0.11945562862924167, 0.13820216698305948, 0.11320353232856308, 0.19806906740580285, 0.17615286127797194, 0.27918024786881035, 0.27297344378062655, 0.10831244156828948, 0.2099064772150346, 0.18310042204601423, 0.1896331129329545, 0.22292011390839303, 0.15570970039282525, 0.20271894575229712, 0.19736698722200735, 0.12071737806711878, 0.1627363104905401, 0.13170314500374453, 0.15808925484972342, 0.16322622634470463, 0.26080337539315224, 0.13583338766225747, 0.23929796793631145, 0.10459688558642354, 0.11991701887122222, 0.168452384482537, 0.2012780359280961, 0.14462260103651456, 0.12535566703549453], [0.09640383986490113, 0.10869143730295555, 0.04362202908045479, 0.12270349077880383, 0.026269181298890283, 0.014511684255142297, 0.05530861412574138, 0.039734199842704196, 0.036295048493359766, 0.06112257018685341, 0.06739142630249262, 0.08701892024172203, 0.045762359231178246, 0.08941994354661022, 0.03932394399972899, 0.027491543475272398, 0.11685333826712199, 0.11170627017106328, 0.05536980441372309, 0.06214478997779744, 0.13096962150718483, 0.06659366589571748, 0.04376574619007962, 0.00041753607313564444, 0.047060780094138215, 0.10999317280948162, 0.058981086526598246, 0.008538758465354996, 0.06718823899115835, 0.02454489659118865, 0.007327704075058656, 0.04186885404799666, 0.06713770170296941, 0.04775928100571036, 0.14984528507505143, 0.057170660101941655, 0.036630305860723765, 0.07569595532757895, 0.027759113581851125, 0.04364936047100595, 0.12143779226711818, 0.1530191461954798, 0.047362154815346, 0.05155367597139307, 0.04459122135969145, 0.09906626200037343, 0.5986484853284699, 16.979997294289724, 47.0169312613351, 57.115151269095286, 40.9936386517116, 28.617906842912944, 15.416640451976232, 32.00051573344639, 66.1698282786778, 27.25712299346924, 2.0585152208805084, 0.7191644470606531, 0.42073122944150654, 3.439406071390424, 7.3670733485903055, 1.2467551167522157, 0.5684286526271275, 0.016206686784114157, 0.16373220990811074, 0.4822644218802452, 18.99498530796596, 51.101551396506174, 76.52768162318638, 80.66987800598145, 78.75193200792584, 71.53112084524972, 71.2150959287371, 65.81807572501046, 67.71375969478062, 65.6656391961234, 63.57589898790632, 62.01021276201521, 62.69219235011509, 63.22423676082066, 67.0311061314174, 61.75837530408587, 68.12332126072475, 63.788979394095286, 70.0377584184919, 58.36315195901053, 17.272737060274395, 0.8365178927779198, 2.5737493336200714, 32.090602602277485, 29.360620634896414, 51.49243967873709, 64.23672825949532, 61.6160067149571, 75.21793924059186, 75.18892356327602, 73.95702879769462, 74.73101643153599, 71.35332339150565, 76.17963245936802, 72.08138343266079, 75.8307773045131, 75.77669947487968, 77.21988201141357, 72.65108707972935, 67.64279774257115, 70.41093921661377, 71.37352875300816, 70.67540849958147, 61.90349537985665, 57.586871419634136, 63.88722692217146, 64.37426785060337, 81.64168780190604, 91.22216279166085, 63.610973494393484, 22.759578364236013, 1.3485082281487328, 0.07053041750831263, 0.07730385261986937, 2.035941175052098, 8.266231042998177, 1.579254646386419, 8.956170661108834, 5.9471299307686945, 1.406006742800985, 0.15441490629953997, 0.12189895180719239, 8.103827323232379, 44.62956149237496, 45.87199667521885, 31.235758781433105, 27.4334283215659, 35.34909929547991, 42.296179226466585, 29.94764961515154, 4.354877267565046, 0.0835007568821311, 0.2293800658413342, 0.033748849228556664, 0.12831536893333706, 0.025659790694979683, 0.14149963004248484, 0.03802348074636289, 0.03401321664984737, 0.0056395623832941055, 0.08567209608320679, 0.04450202114613993, 0.00821819986283247, 0.05444770925013082, 0.025732248056946055, 0.115129967885358, 0.07512813008257321, 0.06485471634992532, 0.03800458015341844, 0.04272139937217746, 0.10844504088163376, 0.09132615875984941, 0.10973597411066294, 0.1457639512206827, 0.07408288081309625, 0.05615290167874523, 0.0704954933109028, 0.029096925098981177, 0.05595223173233015, 0.09754879985536848, 0.06626043056270906, 0.08231784642807075, 0.04389364664841976, 0.03221117691802127, 0.11609246980931077, 0.16348839870521, 0.04864522382350905, 0.11151103529014758, 0.060097106998520236, 0.06426455373210566, 0.019138935155102184, 0.12843605317175388, 0.010089457800079669, 0.03684246340500457, 0.04383268706234438, 0.03563725629023143, 0.011729795851611664, 0.040094166062772274, 0.05010412161105445, 0.035112691045339615, 0.03626312342073236, 0.04405972487958414, 0.04831082819561873, 0.04436589005802359, 0.002884164623018088, 0.018965572850512605, 0.011443403183615633, 0.08868649468890258, 0.02317102433049253, 0.022604193139289106, 0.16572197313819612, 0.04861696623265743, 0.03581418090366891, 0.13361312608633721, 0.09194949495473079, 0.06479642340647322, 0.008705286225969238, 0.030689138054315532, 0.04901117132976651, 0.06324554341179983, 0.03129778057336807, 0.05701328068971634, 0.06123051832297018, 0.031125829621617283, 0.07370376294212681, 0.08712515846959182, 0.012998444294290883, 0.06706605519035033, 0.030632368421980312, 0.053260812402835915, 0.130936807553683, 0.034100052168858905, 0.011929835608628179, 0.0744555118892874, 0.040576316083648374, 0.052397067858172316, 2.813141699348177, 28.947340045656475, 60.583462715148926, 57.19438852582659, 36.6700039591108, 18.062941789627075, 30.032897063664027, 69.07519667489188, 78.30353696005685, 19.88960235459464, 0.931900428874152, 0.48349191887038095, 0.8234670587948391, 1.7580316875662123, 5.329427693571363, 1.8608978135245187, 1.0466076965842928, 0.09025084360369615, 0.21790816927594797, 1.317626308117594, 28.852618728365215, 65.1695030757359, 81.98928533281598, 79.42767211369106, 72.95603656768799, 66.79309558868408, 68.61503137860979, 66.84781960078648, 67.10123429979596, 67.24989795684814, 62.33729921068464, 61.82600906917027, 62.378015654427664, 61.89991705758231, 67.55787685939244, 63.636598450796946, 65.82225854056222, 63.90026869092669, 67.54458495548793, 71.38058812277657, 31.94753919328962, 4.091249585151672, 7.126253996576581, 53.93384906223842, 36.411586557115825, 63.04614053453718, 63.148925236293245, 63.22356973375593, 79.85666084289551, 69.34548160008022, 73.00005340576172, 70.83262538909912, 70.76476233346122, 76.61556243896484, 78.87980665479387, 75.52114473070417, 75.84302697862897, 77.70235102517265, 74.07967145102364, 72.4444546018328, 69.90318570818219, 70.16120706285749, 70.83088139125279, 65.94883387429374, 62.2983615057809, 67.69736194610596, 69.52911554064069, 74.76431914738247, 92.5626995904105, 74.76599366324288, 35.77872725895473, 3.26608065196446, 0.11388557537325791, 0.3323367897953306, 2.6204746663570404, 6.038758431162153, 3.8807747534343173, 2.7296156670366014, 1.4839480519294739, 1.3788810840674808, 0.2133667751082352, 0.17940446894083703, 5.102701025349753, 48.74783175332205, 63.87609590802874, 40.04298264639718, 22.662489448274883, 25.462589161736624, 45.96578345979963, 40.7717409815107, 9.094606569835118, 0.07118693406560592, 0.48027962552649633, 0.057494077033230236, 0.10112459797944341, 0.04465892897652728, 0.13718307523855142, 0.08257968630641699, 0.010261184835274304, 0.04079930983217699, 0.06147511662649257, 0.05165409915415304, 0.035638820313449414, 0.029281890352389643, 0.022121118614450097, 0.08383303548076323, 0.034899013582617044, 0.0948096082678863, 0.03687127400189638, 0.07038145871566874, 0.050061645318887064, 0.12387069314718246, 0.06874547685895648, 0.13465492161256926, 0.06716166077447788, 0.038921145256608725, 0.13338623754680157, 0.002904171864169517, 0.062009300105273724, 0.11602191573807172, 0.08211140214864697, 0.01903138735464641, 0.03658238771770682, 0.048819726066929955, 0.09489973807441336, 0.11176050547510386, 0.07559766953012773, 0.039974811752992015, 0.08082944593791451, 0.021125989334125603, 0.13662949922893727, 0.19249144169901097, 0.24395032972097397, 0.3477834223636559, 0.16799830884805747, 0.09817955243800368, 0.20070964071367467, 0.1873949651739427, 0.18634523078799248, 0.14810560271143913, 0.21470342124147074, 0.12917690484651498, 0.16969820191817625, 0.37805631650345667, 0.13541505725256034, 0.1039412511246545, 0.12693001755646297, 0.2848665070320879, 0.14580764887588366, 0.22926889466387884, 0.45239305762307985, 0.23881533954824719, 0.28080740198493004, 0.11951044068804809, 0.3965170016246182, 0.2508079574576446, 0.12975646874734334, 0.13681631349027157, 0.1606991719454527, 0.1692590947662081, 0.1732359749398061, 0.18928256817162037, 0.2712076785308974, 0.11690798747752394, 0.30326471264873234, 0.1436549693878208, 0.12514502262430532, 0.14087193086743355, 0.15507900209299155, 0.25367859484893934, 0.21750112968896115, 0.21655994733529432, 0.10441575066319533, 0.2572588441627366, 0.16007544898561069, 0.2907149632062231, 2.2055692843028476, 34.78839009148734, 76.03224727085659, 73.96916730063302, 55.199077810559956, 42.55137613841465, 26.217167002814158, 45.291922841753276, 81.4325053351266, 36.30556399481637, 3.801735954625266, 1.0538013620035989, 1.6663605208907808, 12.620608908789498, 17.177411249705724, 5.337948790618351, 1.9411458160196031, 0.18385450515363896, 0.19923333850290093, 0.579407349228859, 22.489441088267736, 54.67264059611729, 80.96176488058907, 81.06227057320731, 81.63999938964844, 76.11615371704102, 73.7845675604684, 70.38036714281354, 71.08557455880302, 68.39263343811035, 62.22433539799282, 65.63426807948521, 61.726920809064595, 63.4362610408238, 67.65711797986711, 62.64198466709682, 71.4174552645002, 67.77107538495744, 67.32567501068115, 62.61847196306501, 21.507283687591553, 1.3905756622552872, 3.6883413536208014, 46.66779123033796, 42.57549680982317, 70.67301137106759, 66.8461937223162, 65.61258275168282, 87.32033933912004, 73.34638636452812, 76.35271208626884, 81.62555408477783, 74.99172673906598, 81.72001484462193, 80.30787685939244, 83.00434071677071, 82.10142230987549, 82.1801870891026, 76.50216088976178, 73.59604903629848, 74.90227563040597, 74.01619270869664, 75.71921702793666, 67.24743829454694, 54.08255440848214, 66.1570019040789, 72.17400986807687, 74.8603571483067, 89.75237560272217, 74.3800629207066, 28.16997558729989, 1.9672471582889557, 0.24180729900087627, 0.2662505730986595, 3.475604448999677, 17.839329651423864, 11.679561393601553, 16.876898186547415, 14.017228092466082, 5.674149104527064, 0.807445978479726, 0.2287023722061089, 12.327404482024056, 56.32490485055106, 56.40777254104614, 40.21288694654192, 39.72969879422869, 47.540078503744944, 59.104149545942036, 50.79230097361973, 11.200521315847125, 0.17706805574042456, 0.4504672666745526, 0.11583340513919081, 0.31050199429903713, 0.13176390102931432, 0.26984208609376636, 0.2591282624219145, 0.16211520667587007, 0.14793419119502815, 0.1732411046645471, 0.1503767137016569, 0.14456176358674253, 0.23649371841124125, 0.08266384500477995, 0.23439207832728112, 0.12126249953040055, 0.1399599662316697, 0.1474285197577306, 0.2569836032177721, 0.23756705224514008, 0.22451039643159934, 0.13394195772707462, 0.2687608269708497, 0.15834420759763035, 0.131740165874362, 0.289033689137016, 0.09839798643120698, 0.10800397276346173, 0.15463186108640262, 0.12608228304556438, 0.15922855585813522, 0.14913008202399525, 0.17087104969791003, 0.22779940494469234, 0.3377793463213103, 0.1621161023420947, 0.13843616656959057, 0.20518662833741733, 0.1111065334241305], [0.049191424157470465, 0.08517903861190591, 0.0930931114458612, 0.10546810419431754, 0.059040634759834835, 0.0903551819335137, 0.22062648912625654, 0.006712781290324139, 0.034196896079395495, 0.04337793289284621, 0.05803584653351988, 0.18264295373644146, 0.06442360912582704, 0.07343983317592315, 0.08832674220736537, 0.033990685894553146, 0.019854647107422352, 0.09259804551090513, 0.035705628871385536, 0.04347932977335794, 0.01766420036022152, 0.03061667051432388, 0.11259148017104183, 0.05521684904981937, 0.05218550742470792, 0.05678406138239162, 0.01333709857759199, 0.016995175009859458, 0.03684476703139288, 0.006776390131562948, 0.10453585136149611, 0.03502423382763352, 0.1055728971425976, 0.07494955323636532, 0.06546406115272216, 0.06055169153426375, 0.023732910697747554, 0.06192191158022199, 0.22249756301087992, 0.05184406181797385, 0.12250941619277, 0.02174654692810561, 0.05517997406423092, 0.11534163009907518, 0.10109731408634356, 0.06100055601980005, 0.056666023430547545, 0.2672222895281655, 5.739737059388842, 36.778305530548096, 56.32498822893415, 52.56582171576363, 42.55586467470442, 26.113162892205374, 20.66509427343096, 53.33089133671352, 56.05424124853951, 17.76691378865923, 0.8327151111194065, 1.6704999102013451, 1.9019638385091509, 1.9626839288643427, 2.0246084460190366, 0.10866329167038202, 0.5976635238953999, 0.40330986997910906, 0.07597161696425506, 1.396340821470533, 8.840862699917384, 27.754787717546733, 48.16814701897757, 66.52368613651821, 71.33405603681291, 76.23339762006486, 77.69664655412946, 74.7863518851144, 74.86872972760881, 71.98802048819405, 62.95851680210659, 62.54040200369698, 66.84781265258789, 58.41943236759731, 48.44694001334054, 37.43249579838344, 17.24354420389448, 0.6477655182991708, 0.4999300539493561, 0.23821005917021207, 0.18366758232670172, 0.22263390783752712, 1.6974841079541614, 19.507275990077428, 53.67220769609724, 52.8919632094247, 58.955847195216585, 68.64848000662667, 76.78049877711705, 69.04978016444615, 67.33371407645089, 70.91111224038261, 67.57048783983502, 69.19572012765067, 74.50477613721574, 77.49031979697091, 69.57540443965367, 82.16115597316197, 84.93271596091134, 75.81850678580147, 91.39826488494873, 85.3503165926252, 76.34839725494385, 70.27657495226178, 65.06364032200405, 38.2427738734654, 12.36782910142626, 1.7685640709740775, 0.038855066123817644, 0.03346260923093983, 0.17846718137817724, 0.13208509236574173, 6.286135579858508, 10.198776943343026, 3.4585633405617306, 5.960769244602748, 1.5252205686909812, 0.6254223372255052, 3.181600328002657, 30.651623725891113, 54.69661882945469, 32.37929677963257, 21.234323705945695, 35.405897344861714, 47.4832352910723, 38.52505486352103, 14.832930973597936, 1.4494710905211312, 0.3058839663863182, 0.031685254603092156, 0.019269542968166724, 0.16475860268941947, 0.06497562450489827, 0.0592927715874144, 0.04933271550440362, 0.22218703824494565, 0.13339969968157156, 0.09224258815603596, 0.13255096093884536, 0.07805103502635445, 0.13282713826213563, 0.05217026074283889, 0.033021330766912015, 0.017336622312931076, 0.049028328087713034, 0.1909269570772137, 0.27145566950951305, 0.10233070754579135, 0.08243445267102548, 0.05795490409114531, 0.13284636794456414, 0.026581127595688616, 0.04549509446535792, 0.07128741153116737, 0.049037556163966656, 0.035088423240397654, 0.13963046962661402, 0.03866520184757454, 0.021604877297899554, 0.07288905951593604, 0.17513600869902543, 0.40980545857122963, 0.08287995840821948, 0.07108828185924462, 0.12640173733234406, 0.10444498195179872, 0.01023779488501272, 0.08585480520767824, 0.06542197841086558, 0.04729243194950478, 0.051591514476708004, 0.17074176163545676, 0.07149365225008555, 0.07042289006390742, 0.08951936249754258, 0.11935979234320776, 0.014619318568812949, 0.06754553517592804, 0.06662633057151522, 0.1164937282779387, 0.01346399141142943, 0.02976501067834241, 0.0529013143719307, 0.01271407026797533, 0.11782304623297282, 0.0842064604429262, 0.015822542664994086, 0.04329699045047164, 0.05222149692209704, 0.04187044181994029, 0.06591977205659662, 0.10396260462169137, 0.19698931463062763, 0.06946016422339849, 0.06741210126451083, 0.048954381341380734, 0.10561262536793947, 0.017753098625689745, 0.13062249656234468, 0.024171654833480716, 0.02458830756534423, 0.06225301631327186, 0.06947292746709925, 0.053590790767754824, 0.08292168831186635, 0.1213082056492567, 0.1808032010282789, 0.09891141352376767, 0.11270896172417061, 0.02102498770026224, 0.04848674518455352, 0.0427853411196598, 0.037020751873829534, 0.24556833718504223, 0.056603951047041585, 0.2541215696505138, 12.957378540720258, 52.77863114220755, 65.67527634756905, 52.09320524760655, 17.681299822671072, 14.691347530909947, 47.20014830998012, 82.21476132529122, 61.494086674281526, 11.610690849167959, 1.1738996718611037, 0.480686149426869, 1.0863217541149683, 1.5389067828655243, 2.6376221690859114, 0.9532376953533718, 0.6693921663931438, 0.43965470258678707, 0.026531983000625457, 3.2318857439926694, 17.266389880861553, 41.00274774006435, 64.4032209941319, 77.09093734196254, 80.82068170819963, 78.65560218266079, 78.68005289350236, 71.59152848379952, 75.13630485534668, 81.99923515319824, 75.03393704550606, 72.09152085440499, 66.47049072810582, 61.09609385899135, 54.77985824857439, 46.31377703802926, 27.421143906457083, 4.106222518852778, 0.16971044268991264, 0.503300853073597, 0.09637565352022648, 2.2408732984747206, 6.198440194129944, 38.97593041828701, 72.4008755002703, 57.44120938437325, 65.71593025752476, 79.54336656842912, 78.16394765036446, 75.56473078046525, 73.28958484104702, 73.21314770834786, 66.77398109436035, 68.56615080152238, 73.11536570957729, 76.39142744881767, 72.35703931535993, 79.49424280439104, 86.29978793007987, 79.59459563664028, 89.977705683027, 80.99278163909912, 70.22508185250419, 77.61277484893799, 74.79398795536586, 53.433891432625906, 27.2728328704834, 5.456894133772169, 0.355776700590338, 0.21790924136127743, 1.6113721515451158, 1.7451190033129282, 3.526585553373609, 11.845212527683803, 2.8337533133370534, 4.331920853682926, 0.17712368204125337, 0.6668984144926071, 1.2851299090044839, 28.364401817321777, 66.22517762865338, 49.403870241982595, 21.98225212097168, 28.162186656679424, 48.54053572246006, 49.61351823806763, 22.585937670298986, 2.7885468133858273, 0.16669287532567978, 0.12297014147043228, 0.06221651112926858, 0.10804165859839746, 0.13060710738812173, 0.09259714984468051, 0.04347405755626304, 0.060242259209709506, 0.16958644720060484, 0.01341864321979561, 0.16509521034147057, 0.13194912751870497, 0.15346311165818147, 0.11414732704205172, 0.04194595258949058, 0.05758750451994794, 0.05027405731379986, 0.07543070241808891, 0.10893516708165407, 0.06679588290197508, 0.08247711895299809, 0.06263881096882479, 0.06953166824366365, 0.0395875039643475, 0.027207968423941305, 0.0745506967817034, 0.0806119211816362, 0.08770715152578694, 0.11934058980218001, 0.01728588655324919, 0.12513047483350548, 0.1778980940580368, 0.22510730368750437, 0.10330726192998034, 0.03413209937778967, 0.13260042614170484, 0.20513273908623628, 0.07507344016007014, 0.04395082340176616, 0.07420159051460878, 0.16196158634764807, 0.170550781169108, 0.14745129139295646, 0.35578875137226923, 0.21943285103355134, 0.2703990004956722, 0.6109745896288327, 0.3303939811885357, 0.189907078232084, 0.10914343662027802, 0.12818997566189083, 0.21882083958813123, 0.10937124796743904, 0.1382225366043193, 0.2856928812605994, 0.26908701232501436, 0.17073162432227815, 0.24574812182358333, 0.14622292587799685, 0.1019646514739309, 0.1777979422892843, 0.14350618022893155, 0.3471894599497318, 0.12830287031829357, 0.1904464185770069, 0.18691273033618927, 0.1484998586986746, 0.1866544663373913, 0.13942063945744718, 0.12600957123296602, 0.32746363271559986, 0.1906371819121497, 0.13846524858048984, 0.26541502507669584, 0.16029465650873526, 0.156422813556024, 0.1739235751863037, 0.22606238243835314, 0.19800080678292684, 0.23518490578447068, 0.2513739913702011, 0.08639799963150706, 0.1694184826420886, 0.3507052755781582, 0.20314887911081314, 0.26146529987454414, 0.1920515610171216, 0.2944565952888557, 14.005306720733643, 60.010778290884836, 80.12241554260254, 72.04795564923967, 57.91609443937029, 42.79863820757185, 40.89345952442714, 71.09874139513288, 70.7886710848127, 26.152604341506958, 0.9332379571029118, 2.8204205887658254, 8.809950164386205, 9.477011970111302, 10.382961528641836, 3.4657308416707173, 2.3193345282758986, 0.4025370185928685, 0.16573738945381983, 2.5641297698020935, 12.50518717084612, 33.25972039358956, 54.1987213407244, 70.34129047393799, 77.51478440420968, 80.94174712044853, 79.39737796783447, 71.30474158695766, 73.95292936052594, 85.86326735360282, 84.20951271057129, 75.58851446424211, 68.58544594900948, 61.89601911817278, 46.37632472174508, 36.15824828829084, 17.372841494424, 1.4184875530855996, 0.3469951818031924, 0.40279149636626244, 0.1687028453286205, 1.2776222718613488, 3.2133961532797133, 36.96536145891462, 79.56301607404436, 62.69867501940046, 67.30109923226493, 79.00743811471122, 80.86532388414655, 72.38401917048863, 71.3473618371146, 73.77966213226318, 66.77615588051933, 65.14371136256626, 67.54974051884243, 75.66852991921562, 70.76003755841936, 83.84029933384487, 91.75347069331578, 80.99052347455705, 93.68101215362549, 98.27229145595005, 81.72001484462193, 90.60816437857491, 80.17252595084054, 40.27905464172363, 16.355210065841675, 2.033448943070003, 0.26798819271581514, 0.15614472276398114, 0.3591208740004471, 2.9888948627880643, 16.590245042528423, 25.937682662691387, 13.4142165184021, 17.09045454433986, 3.7943582705089023, 0.8322115295699665, 6.111679341111865, 38.94162368774414, 67.43335124424526, 47.05307579040527, 30.915995734078543, 46.06313814435686, 56.82257652282715, 58.24732548849923, 26.409083196095057, 2.5877742724759236, 0.3468513052378382, 0.23862771104489053, 0.13721187226474285, 0.28076161444187164, 0.2630186565220356, 0.21645372946347508, 0.09568620765847818, 0.3931590403829302, 0.19416242917733534, 0.11653290688991547, 0.36067781331283705, 0.40313833632639473, 0.2194664656583752, 0.22146704473665782, 0.24565858234252247, 0.1886274426111153, 0.24898128690464155, 0.371489264603172, 0.4784576232944216, 0.3296339405434472, 0.2407314952995096, 0.3357931657561234, 0.15992877685597964, 0.1569140050560236, 0.09811722221119062, 0.16479957263384545, 0.20122183965785162, 0.1609136297234467, 0.15841746223824366, 0.12960170848029, 0.35830777191690033, 0.2951511980167457, 0.4025183453091553, 0.4381148623568671, 0.14174766173320158, 0.17987100247825893, 0.38770912853734835, 0.20860609199319566, 0.15898733665900572, 0.2368006333708763], [0.10509714909962245, 0.05128895231921758, 0.012436119423780059, 0.01907920202107302, 0.14370865507849626, 0.08908049961818115, 0.10198471575443234, 0.015373566221179706, 0.09117154777050018, 0.07481430763644831, 0.08640314292694841, 0.09666523191013507, 0.07564960460045508, 0.08162732169564281, 0.09811815858951636, 0.0747974935386862, 0.10664346933897052, 0.05127080150746873, 0.03152529336512089, 0.05645130102389625, 0.04689066797228796, 0.06962983190481152, 0.0575270809765373, 0.027061155498293892, 0.0406676740385592, 0.030937481871140853, 0.022787209300856506, 0.037141117200787575, 0.03639123761760337, 0.058607627637684345, 0.028904842013227086, 0.015775537151577215, 0.09364635497331619, 0.027699953809912716, 0.028509992307850292, 0.09680475228066955, 0.029318907830332006, 0.01574266721893634, 0.027767556253820658, 0.11199573999536888, 0.053360163500266414, 0.09835852283452239, 0.04030769085511565, 0.07583046810967581, 0.1644458116165229, 0.058706286629395824, 0.04822085445214595, 0.15058556678039686, 0.05909641712371792, 0.293200246989727, 19.78359716279166, 51.874878951481406, 64.38296004704067, 62.02030154636928, 34.68904822213309, 29.84575775691441, 38.15019260134016, 52.816168785095215, 45.541846070970806, 8.90286408151899, 0.6366190335580281, 1.7191455513238907, 0.6825278986777578, 1.127766673054014, 0.7919426475252423, 0.388863560876676, 0.0960079011108194, 0.41358259160603794, 0.2123716085084847, 0.18376010736184462, 1.6224381348916461, 4.748764131750379, 11.035776053156171, 16.69879674911499, 16.64670784132821, 16.969135522842407, 13.016307950019836, 6.386229157447815, 6.411922293049948, 8.739949669156756, 10.500765630177089, 7.0795577594212125, 2.2925133960587636, 0.9499476147549493, 0.35489805202398983, 0.17306190356612206, 0.19893763294177397, 0.10792124577398811, 0.10079751695905413, 0.3091978228517941, 0.05375448734100376, 0.6854168836559568, 11.774817722184316, 43.10742310115269, 67.97770091465541, 84.04042829786027, 84.66441822052002, 77.6107598713466, 87.16017641339982, 81.41416903904506, 83.1252532686506, 83.40905938829694, 69.18023259299142, 52.889031069619314, 33.88405772617885, 27.37544560432434, 27.740385838917323, 22.940047400338308, 23.1710524218423, 22.87367125919887, 18.215015275137766, 8.78978909764971, 4.201292983123234, 0.4144924799246447, 0.09234634973108768, 0.1598202655357974, 0.31365422372307095, 1.844790586403438, 11.075242689677648, 12.032480376107351, 5.750674826758249, 5.407419051442828, 0.8920468102608408, 0.8510020098515919, 1.2601607974086488, 22.712287187576294, 52.77220753261021, 42.35997758592878, 29.349037987845286, 38.47406898226057, 44.34769739423479, 42.65893077850342, 17.143431084496633, 2.6747665873595645, 0.0797057037374803, 0.1866271078054394, 0.0660615519487432, 0.12472659721970558, 0.078035191233669, 0.22307806329003402, 0.07815744967332908, 0.06881708265947444, 0.07028502531881843, 0.08944321729774986, 0.016788637431870614, 0.04848937111507569, 0.05367582477629185, 0.0814405210050089, 0.05325030868074723, 0.07092567772737571, 0.013292434009989458, 0.0521048940718174, 0.055573649904025454, 0.013280348453138555, 0.02474551904015243, 0.08915160330278532, 0.06191035612885441, 0.10424304993024894, 0.04326595086604357, 0.15330993916307176, 0.02626561899004238, 0.06223860422947577, 0.061578186095825264, 0.0467847181218011, 0.06421341933310032, 0.1274910303098815, 0.13130898401141167, 0.07223928759672812, 0.06731486719633852, 0.0436602306020047, 0.09714532257722956, 0.09210773610642978, 0.19438262736158712, 0.052909836771764925, 0.048102416164640865, 0.060689223797193596, 0.04344261424349887, 0.03795077232643962, 0.02036663400940597, 0.03214716053168688, 0.12715297059289046, 0.03255718228008066, 0.14947115443646908, 0.08673120103776455, 0.11362870237124817, 0.10518888024879353, 0.012073046361495341, 0.055633103142359426, 0.08086629038942711, 0.047808203380554914, 0.06745383116815772, 0.034686513378151825, 0.07683011304054942, 0.0626803237412657, 0.06868556221680981, 0.028451916495604173, 0.08664200082421303, 0.038516813024346314, 0.023876838153228164, 0.0225142329665167, 0.10171250786100115, 0.010586049590658928, 0.08022728682096515, 0.03356701202158417, 0.09754084063959972, 0.05654445031125631, 0.01619646804673331, 0.03586796498192208, 0.089671069357012, 0.0060701250830399135, 0.14804006979933806, 0.10206400935671159, 0.024384496001792804, 0.02888664709670203, 0.09207876944648367, 0.15719756484031677, 0.06917409385953631, 0.07605844230524131, 0.046902087716651816, 0.0697695558358516, 0.02970488229766488, 0.03477923179577504, 0.03865945465596659, 0.14013224627290452, 0.09998826895441328, 1.9708671697548457, 31.943064553397043, 65.2360737664359, 68.19315065656389, 47.972430161067415, 17.384504045758927, 30.80894136428833, 58.16000747680664, 74.39073535374233, 44.90362276349749, 1.8154627829790115, 1.2990923140730177, 0.2683774818267141, 1.3029165374381202, 1.8633763662406375, 0.36761778805937084, 0.5565431618264743, 0.42418524410043446, 0.35846103940691265, 0.15947323558585985, 0.3799074685999325, 4.071645677089691, 10.380158799035208, 20.01891701562064, 27.695781878062657, 29.94230992453439, 25.294449704033987, 24.239706209727697, 18.398739542279923, 16.72664165496826, 22.29642013141087, 22.243513073240006, 16.012007270540508, 6.046090517725263, 2.3693007613931383, 0.0987919167216335, 0.5554850814597947, 0.9399685902254922, 0.9375083850962775, 1.0013324746063776, 0.23774770540850504, 0.1300402320921421, 2.6457902107919966, 25.45210085596357, 61.74188028063093, 70.91251577649797, 78.43510110037667, 83.82420035770961, 72.91395827702114, 80.42756652832031, 82.90469660077775, 85.70383398873466, 84.19915989467076, 72.86972604479108, 61.24006748199463, 47.217112336839946, 41.54558617728097, 40.01372030803135, 35.41191448484148, 39.17529508045742, 39.243627139500205, 30.98937565939767, 17.621823242732457, 9.487790363175527, 1.921775758266449, 0.08885596559516021, 0.4981335646339825, 0.6522360326988357, 4.279416356767927, 11.461071814809527, 11.635138085910253, 9.459247163363866, 4.778673955372401, 0.4498218170234135, 0.7091032383697373, 0.38699568967734066, 19.686145203454153, 62.82071317945208, 60.12612533569336, 35.236562797001426, 30.642247131892614, 40.73538105828421, 52.975650787353516, 31.02630533490862, 6.336597306387765, 0.09840249868908099, 0.3165279009512493, 0.015312492980488708, 0.09714662536446537, 0.18305110612085887, 0.1459516475775412, 0.043907726250056706, 0.0608433937387807, 0.1095838804862329, 0.026763943589425514, 0.03826215883184757, 0.12541107620511735, 0.15135775320231915, 0.028177594965589896, 0.014037246632921909, 0.04931611514517239, 0.056999350365783484, 0.052645065622138124, 0.01312757799002741, 0.08018736182046787, 0.12125365143375737, 0.0916317030787468, 0.03619624022394419, 0.12114807138485567, 0.025671753267358457, 0.22101538468684467, 0.07931454865528004, 0.1035260691174439, 0.019151905351983647, 0.15498710131006582, 0.23768433023776325, 0.19914772095424788, 0.03572584582226617, 0.05660726908328278, 0.1681757593261344, 0.21404696575232915, 0.10172090812453202, 0.03672264090606144, 0.15117078966328076, 0.10752034014356987, 0.028912156620728116, 0.04591767589694687, 0.2586869703871863, 0.1620632851762431, 0.1810076300586973, 0.17151675719235623, 0.25613926138196674, 0.12452907567577702, 0.19328452699950763, 0.13516598061791488, 0.2944518184023244, 0.35105292978031294, 0.15581072068640164, 0.10921627056917974, 0.21018984700952256, 0.3919897616973945, 0.18346893441464218, 0.17403500420706614, 0.26509329091225353, 0.17542339542082377, 0.1783145788524832, 0.12177720905414649, 0.16720601064818247, 0.2712671724813325, 0.1149974228548152, 0.0780372539801257, 0.11065954848059587, 0.16246638926012175, 0.10595366385366235, 0.19836975341396673, 0.2705951513988631, 0.2758124614400523, 0.19765661310936722, 0.25139936857989853, 0.11322171706706285, 0.09082400891929865, 0.20528910069593362, 0.27547628805041313, 0.10079588847500937, 0.0843921076240284, 0.23988424933382443, 0.2516161740890571, 0.14272543069507393, 0.12171368460570063, 0.1106182596247111, 0.1706286362771477, 0.36845849294747623, 0.08799221765782152, 0.0984729713361178, 0.2383069268294743, 0.08853899474654879, 1.7532586008310318, 34.6255521093096, 76.5189824785505, 88.53505815778459, 79.17621680668422, 51.64764853886196, 44.71173783711025, 52.0444393157959, 67.16251741136823, 58.17195837838309, 11.404524769101824, 0.8293494145785059, 2.93871562395777, 5.182449843202319, 5.488091545445578, 3.2655645310878754, 1.3407004071133477, 0.6640560584408897, 0.6787023725254195, 0.28045190391795977, 0.23996597209147044, 2.6833771424634114, 6.566048536981855, 14.487209456307546, 19.82553822653634, 19.954376935958862, 16.391740219933645, 14.209279775619507, 10.056616800171987, 9.04520661490304, 13.339970673833575, 13.111688477652413, 9.018001811844961, 2.8769320249557495, 1.5868713919605528, 0.19828690428818974, 0.2566288379686219, 0.5253840195281165, 0.48915383219718933, 1.1350654299770082, 1.0752204869474684, 0.18296821628298077, 1.5128469126565116, 22.547792060034617, 63.43815095084054, 77.95999717712402, 85.01527445656913, 84.92157799857003, 82.14567538670131, 96.55301530020577, 87.56673635755266, 95.29668372017997, 93.02215617043632, 75.92559937068394, 55.960586479731965, 42.709461552756174, 28.851359367370605, 28.498246703829082, 27.97250257219587, 25.89094213077, 26.820842129843577, 21.998731510979788, 9.84048787185124, 4.177693426609039, 1.0869435093232562, 0.31653824182493345, 0.30603365121143206, 0.4426565415092877, 2.8489303503717696, 19.726071289607457, 21.407210520335607, 19.043080738612584, 11.579283254487173, 5.0548509529658725, 1.4040311745234897, 2.5425249976771216, 29.50478880746024, 64.39800984518868, 53.952800273895264, 43.39085054397583, 51.62511900493077, 54.976061480385916, 64.44805077144078, 40.72340931211199, 6.994097088064466, 0.1010328329035214, 0.3236249972667013, 0.09977033707712378, 0.22930482987846645, 0.24568596801587514, 0.4529023931494781, 0.13548588273780687, 0.1684031228401831, 0.13356294163635798, 0.18582001754215785, 0.10772691334464721, 0.30124723804848536, 0.18305980493979795, 0.16441488399037293, 0.10454465874603816, 0.07637741483215775, 0.09849855210632086, 0.17888354403632029, 0.17900756666702883, 0.14639467666191713, 0.11398423436496939, 0.1241533165531499, 0.18961460249764578, 0.2577594672994954, 0.11872165729956967, 0.4415960726993424, 0.14108917063900403, 0.2693004794418812, 0.20127510465681553, 0.19635282164173468, 0.28576749297125, 0.21316810005477496, 0.15856862626969814, 0.14038858323224954, 0.15725662452833994, 0.2728781503226076, 0.12901833121265682, 0.18201513242508682, 0.27773336693644524, 0.1903506772858756, 0.13405278963702066, 0.10700523706951312], [0.013004081223958304, 0.031016700834568058, 0.03557645955256053, 0.09670968952455691, 0.1053675656606044, 0.013574501017241605, 0.07025298489523785, 0.07241640559264592, 0.03725890409467476, 0.0351483412752194, 0.04744678170287183, 0.09572127434824194, 0.19167215137609414, 0.05191051075235009, 0.12672661989927292, 0.1611694781375783, 0.03757250601691859, 0.08994609317077057, 0.04230949468910694, 0.07684544793197087, 0.036931575409003665, 0.00866265726342265, 0.08977892249822617, 0.18934978385056767, 0.09036782304091112, 0.11294064072093793, 0.07939719422055141, 0.02510239792588566, 0.10002953066889729, 0.019312282192653844, 0.02804190831791077, 0.06418536869542939, 0.08550991264304944, 0.014242051402106881, 0.08062865385519606, 0.05944002725716148, 0.025601088934178864, 0.12233602335410458, 0.004489071484256003, 0.05756316546882902, 0.16524220816791058, 0.018871402367949486, 0.025886202563664744, 0.021172647098345414, 0.07632841103311096, 0.07141464363251414, 0.057877564669719765, 0.078308301578675, 0.14473431504198483, 0.06481333928448813, 0.13050973761294568, 3.368510127067566, 25.70396089553833, 53.21270942687988, 66.36298819950649, 49.49568721226284, 35.65981578826904, 31.433733803885325, 39.84660223552159, 58.7377918788365, 38.811164311000276, 8.413927163396563, 0.819806878055845, 1.3431715773684638, 0.24682881097708428, 2.022378074271338, 0.30854254801358494, 0.5045793216143335, 0.2810068912804127, 0.23959237071020262, 0.355750102017607, 0.4206578390938895, 0.4635307756917817, 0.05816198619348662, 0.08682074051882539, 0.04081209343192833, 0.1735829370362418, 0.51544467572655, 0.4458610181297575, 0.10105046124330588, 0.04195981166724648, 0.05346694794882621, 0.09983044170907565, 0.19335816161973135, 0.2208510706467288, 0.7019123413733074, 1.203948785151754, 0.630237493131842, 0.11258279492280313, 0.10321465547063521, 0.10157955570944718, 0.09025327954441309, 0.07728171880756106, 1.1441334805318286, 16.797520228794642, 41.11181708744594, 55.57950210571289, 58.377409662519185, 54.430277006966726, 39.441011565072195, 29.938571793692454, 15.102682624544416, 7.8107800994600565, 1.464268907904625, 0.7428737091166633, 0.10619805859667913, 0.1966046802699566, 0.2577466294169426, 0.1634183603205851, 0.20815912740571157, 0.18290451541543007, 0.20211718018565858, 0.0951743819085615, 0.043728698178061416, 0.24815464126212256, 0.6092917684997831, 0.10842805715011698, 8.8804144518716, 17.42669003350394, 2.3749040492943356, 1.289056184036391, 0.4797876604965755, 1.066231363586017, 21.324636391230992, 41.75963238307408, 37.566526549203054, 21.832495859691075, 25.03201798030308, 44.018814836229595, 45.86505542482649, 27.57937002182007, 7.019915291241237, 0.20598789677023888, 0.2529001251927444, 0.04999683504658086, 0.05354311689734459, 0.1377514704529728, 0.03946492322055357, 0.052395398662026436, 0.14270222479743616, 0.1841385941952467, 0.046095038165471384, 0.02161382887113307, 0.05851821029292686, 0.012493776240652161, 0.11260562084083046, 0.017471101168277006, 0.037197242224855084, 0.10992041349943195, 0.0747628543259842, 0.017464926499607306, 0.05198625222380672, 0.13977041068886006, 0.09533843132002012, 0.015577545722148247, 0.005742554245184043, 0.026324693945103457, 0.0590976317014013, 0.055943960390452824, 0.10549928966377463, 0.029302412644028664, 0.07573938835412264, 0.0632450616519366, 0.04949905836422529, 0.0464536303521267, 0.12865912834448473, 0.017647269215168696, 0.048140692325042825, 0.0732081134670547, 0.06474358588457108, 0.10380310139485768, 0.0764486745798162, 0.11806494396712099, 0.051978628882872205, 0.03651510079258254, 0.0784728666767478, 0.09088591166904994, 0.0833134472902332, 0.03618135655831013, 0.13629384152591228, 0.09473461657762527, 0.07221885690731661, 0.08867882724319186, 0.03326452789562089, 0.02961989917925426, 0.03375936312867062, 0.05455217989427703, 0.15858573892286845, 0.03601598400356514, 0.049702048900404146, 0.17935013185654367, 0.0074870122230744785, 0.1826717643333333, 0.13557259951319012, 0.08472924453339406, 0.08730676836733307, 0.03934136538633278, 0.02585665405994015, 0.09969290266079561, 0.10936658643186092, 0.10861397574522666, 0.17120304331183434, 0.12870745360851288, 0.053730728437325785, 0.1487851691033159, 0.04376458928787282, 0.016671111773965613, 0.07391841749527625, 0.10038463518555675, 0.016240106330120137, 0.12161719692604882, 0.10652323293366603, 0.0465392784348556, 0.11376806667872838, 0.06218946472342525, 0.06174329402191298, 0.01821698248386383, 0.027097170440746204, 0.07968701009771653, 0.1013182858005166, 0.09006983760212149, 0.16288315903927597, 0.04711213840969971, 0.06105774295117174, 0.22009451767163618, 0.06228004236306463, 0.15079025365412235, 9.013633131980896, 40.322814396449495, 67.58646869659424, 66.99180017198834, 39.830350399017334, 28.028199332101003, 35.48110812050955, 61.17425414494106, 79.11518383026123, 36.530748162950786, 1.3252120039292743, 0.962005996278354, 0.15840972693903105, 0.7642644984381539, 1.5386445969343185, 0.930965461901256, 1.1522166239363807, 0.4804989280445235, 0.29165894112416674, 0.158923635791455, 0.2982095181941986, 0.227921866944858, 0.061163438351026604, 0.4565970706088202, 0.7485123894044331, 0.504556305706501, 0.7659922114440373, 0.6409470556037766, 0.7179805391601154, 0.6440253247107778, 0.11228455842605659, 0.046030366992844005, 1.0965210582528795, 0.7654445522597858, 2.262346054826464, 2.292459547519684, 1.7839660559381758, 0.2828729711472988, 0.3146345982594149, 0.14699029470128672, 0.1506185300116028, 0.08154129024062838, 5.673849897725241, 33.24059895106724, 59.7182799748012, 67.17070933750698, 72.59301403590611, 73.49384103502545, 55.36304834910801, 49.2227098601205, 35.3986052104405, 17.983386652810232, 5.071091064385005, 4.916973505701337, 0.6343236310141427, 1.017082195196833, 1.4639026075601578, 0.7189504099743707, 0.9457827125276838, 1.039860452924456, 1.0222130055938448, 0.39779682723539217, 0.32559568009206225, 0.8445030014429773, 0.797184900513717, 1.7680073465619768, 2.3772894527230943, 7.93011280468532, 6.096595670495715, 1.8034831115177699, 0.9123727338654655, 0.30355737837297575, 15.594767945153372, 52.028159686497276, 53.26901068006243, 31.4432041985648, 20.40210669381278, 41.06108134133475, 52.84034851619175, 40.07534040723528, 13.008674485342842, 0.4338545581059796, 0.44489369860717226, 0.045662556907960346, 0.04071840810190354, 0.19630552775093488, 0.06405364469225917, 0.03201499208807945, 0.14220342013452733, 0.05703088867345026, 0.022557153699121306, 0.07229957543313503, 0.09281946505819048, 0.03592625792537417, 0.037242045892136436, 0.006535255325226379, 0.07595295046589204, 0.1315081747514861, 0.13190832042268344, 0.03280424366572073, 0.01225059522714998, 0.08943094259926251, 0.11700714858514921, 0.042930157456014834, 0.13296158319073065, 0.02622448619721191, 0.008458048421224313, 0.04852276860869356, 0.02376563135268433, 0.034218039230576584, 0.04160961974412203, 0.03494872305808323, 0.025260569527745247, 0.10074529011866876, 0.091383997084839, 0.055003948509693146, 0.04139541302408491, 0.099790102802217, 0.07058195224297897, 0.0039031662495939857, 0.05292004533112049, 0.051873343996703625, 0.043120398319193294, 0.0833823321653264, 0.1962256913206407, 0.13795010479433195, 0.2591342335300786, 0.08000136858650617, 0.4385629668831825, 0.2075219287403992, 0.2052868072475706, 0.26285054268581526, 0.16297514124640397, 0.1494820924209697, 0.11348590467657362, 0.15462601211454186, 0.21717666781374387, 0.3094275476677077, 0.28860653777207645, 0.24437009862491063, 0.17560860833951406, 0.2973739430308342, 0.2023278245968478, 0.3499881997704506, 0.20945709704288415, 0.10773255197065217, 0.07995751486825091, 0.17377800228340284, 0.3424523355705397, 0.21679603680968285, 0.4209812017423766, 0.19955379702150822, 0.14348490137074674, 0.4159551300108433, 0.13305546529591084, 0.14789733317281517, 0.2380910169865404, 0.20176221137600286, 0.09970174397208861, 0.29798557449664387, 0.23079437709280423, 0.1271857845463923, 0.43459093144961763, 0.18845250271260738, 0.13623345190925257, 0.1841028896825654, 0.11631264085216181, 0.20892447419464588, 0.20047143421002797, 0.24392215694699967, 0.2240807344870908, 0.126554882686053, 0.20848793190504822, 0.39073390194347923, 0.14468164715383733, 0.3363882138260773, 8.101887907300677, 44.156618458884104, 77.7863825389317, 85.6767499106271, 65.44521454402378, 54.2723514011928, 47.5043682370867, 54.78926958356585, 76.17439351763043, 51.48098904745919, 10.878210885184151, 0.9805417273725782, 2.365848592349461, 1.6980313871588026, 7.966525707926069, 4.7445326788084845, 1.323022995676313, 0.5229512814964566, 0.45609929731913973, 0.7152214529258865, 0.5539932272263935, 0.524011641740799, 0.15495519659348897, 0.25150977979813305, 0.2875407763889858, 0.25094336590596605, 1.357925642813955, 0.8113957579646791, 0.2639526735459055, 0.34351063306842533, 0.18646310589143208, 0.086514504094209, 0.9390809578554971, 0.4157323533935206, 1.4134492405823298, 2.520066031387874, 1.4806361496448517, 0.13004331264112676, 0.1952715760895184, 0.24666593543120793, 0.3778214891042028, 0.15195144420223577, 2.5215277586664473, 25.063705239977153, 48.680826800210134, 61.61556897844587, 64.4208207811628, 59.38472475324358, 49.91126591818673, 42.0051018169948, 25.356429372514995, 9.776857137680054, 1.8682455335344588, 3.5512787997722626, 0.2934340701571533, 0.2655631628419672, 0.46501470463616507, 0.3807834844504084, 0.4601794640932764, 0.7297149609242166, 0.6212366989680699, 0.39658083819917267, 0.33768017164298464, 0.5610354979123388, 1.3338498089994704, 6.041124292782374, 26.863947016852244, 28.540265934807913, 7.567566224506923, 3.9221113239015852, 0.7606186483587537, 2.1449395205293382, 30.918399810791016, 52.806674071720664, 52.08646202087402, 33.9603385244097, 36.99299097061157, 53.76787049429757, 64.11101450238908, 47.878240380968364, 15.476728473390851, 0.4499216430953571, 0.5183921775647572, 0.18467873521149158, 0.2582460311906678, 0.3443487866648606, 0.2098775716232402, 0.1268310464386429, 0.45333801263145035, 0.20412077195942402, 0.07529413367488555, 0.10213792896164314, 0.2667220192296164, 0.12296715591635023, 0.23005186979259762, 0.13151059033615248, 0.09411006580506052, 0.19885304676634924, 0.200178022097264, 0.12354671981717859, 0.10582027065434627, 0.2016567127513034, 0.13830714992114476, 0.14596820383199624, 0.20814854225942067, 0.13950198223548277, 0.17185097640114172, 0.10826935459460531, 0.12747161063764775, 0.18809647538832255, 0.19662914824272903, 0.23143404562558445, 0.07959395580525909, 0.1746039151081017, 0.32848949623959406, 0.19057360318090233, 0.08112916842635189, 0.3520423152617046, 0.1448085332023246, 0.1496525268469538, 0.2090793973101037, 0.20955905371478625, 0.10434906424156257, 0.17598275254879678, 0.330456867814064], [0.04977568691330297, 0.04804585348548634, 0.027852432502965842, 0.031871977262198925, 0.05091693192454321, 0.06166414969733783, 0.06432019360363483, 0.031029681209474802, 0.013561278066065694, 0.021075146705178276, 0.04200401143836124, 0.08440288276012455, 0.07753581660134451, 0.08596693990486008, 0.1487377802176135, 0.012311096802087767, 0.04266336766470756, 0.06451000020440135, 0.04589580332062074, 0.004509157817145544, 0.06345026421227626, 0.02371907197604222, 0.010263273874962968, 0.08119281501110111, 0.016377740373302783, 0.07806944368141037, 0.013498304079153707, 0.03165275616837399, 0.05192775232717395, 0.06151844108743327, 0.02178535234582211, 0.01924028623450015, 0.02559546727154936, 0.09816049238932983, 0.021601472748443484, 0.019763852336577008, 0.04993833514994808, 0.0744649503113968, 0.03342298957120095, 0.05949276299881084, 0.014916727252836739, 0.11311112942972354, 0.03758599529308932, 0.01045783530987267, 0.11293873403753553, 0.04944804949419839, 0.03572062110262258, 0.04919669637456536, 0.09352085313626698, 0.0614675713170852, 0.11969185381063394, 0.36970604743276325, 0.08808576049549238, 6.809719255992344, 35.86500998905727, 63.93727479662214, 56.0770070212228, 48.21334157671247, 37.02098873683384, 24.21830575806754, 30.933341911860875, 57.35860572542463, 42.84242228099278, 12.69574064867837, 1.0530146956443787, 1.927993961742946, 1.2150879417146956, 1.2142069318464823, 0.9660331287554332, 1.7244144571678979, 0.6220354161092213, 0.5154110203896249, 0.513664145554815, 0.07228080715451922, 0.26352704209940775, 0.29888156641806873, 0.6239919311233929, 0.5207033221210752, 0.8193195813468525, 0.8753835644040788, 0.4733448890703065, 0.23803855265889848, 1.0893143649612154, 0.413485588239772, 0.9778656938246318, 4.3987911854471475, 2.9797529876232147, 3.6142305646623885, 2.841604560613632, 0.251169318067176, 0.3669795037380287, 0.056307397317141294, 0.13626613015575068, 0.04636153957939573, 0.16548481157847814, 0.13063165678509644, 1.9921992250851221, 2.6418436339923312, 0.9758683038609368, 0.835166468151978, 0.009882019466853567, 0.04583719825106008, 0.05867694677518947, 0.08128853594618184, 0.21774963635419095, 0.6647252568176815, 2.708829696689333, 1.2690063970429557, 0.09351678192615509, 0.09046744555234909, 0.5466231969850404, 0.6694621369242668, 0.6575254574418068, 0.6347211982522691, 1.3264151279415404, 2.707634389400482, 1.8182934139456068, 2.078203375850405, 1.4497543381793159, 0.8111242896744183, 3.2544893196650913, 24.382364886147634, 52.80368634632656, 47.54595667975289, 22.286265339170182, 21.68949498449053, 38.481190885816304, 48.98540455954415, 36.824559688568115, 7.702998774392264, 0.22618195387933934, 0.21171694435179234, 0.11270227815423693, 0.04658237219388996, 0.11136681267193385, 0.05362292957891311, 0.04388007255537169, 0.016134907957166433, 0.0662198473832437, 0.03629367106727191, 0.009453489827657384, 0.06194548388676984, 0.03810911525839141, 0.09480296541005373, 0.040944149917257686, 0.01673991692119411, 0.024980756953092556, 0.04017782603789653, 0.023016240314713547, 0.09765946213155985, 0.05403763321893556, 0.015397555826764022, 0.028132996555151682, 0.058748009747692516, 0.029763144707041125, 0.04220966522448829, 0.03008617487336908, 0.03445762994566134, 0.08771171806646244, 0.03062029049864837, 0.07480861472764186, 0.05596472695469856, 0.0443939983711711, 0.03711608265127454, 0.020972528461632983, 0.03850305572684322, 0.0326862328552774, 0.07165419363549777, 0.08952780347317457, 0.03126618119754961, 0.046323999629489014, 0.02538128599657544, 0.11276584331478391, 0.06721143131809575, 0.0664814022768821, 0.011739520954766443, 0.02210724426965628, 0.07803042113248791, 0.03518455468916467, 0.03849458760981049, 0.051549889745989015, 0.09368771168270282, 0.08103657553770713, 0.03931215784645506, 0.024594777396747043, 0.033309915103018284, 0.1022899683032717, 0.13531882741621562, 0.0419579423032701, 0.04920506949669548, 0.05911032709160021, 0.04769276761050735, 0.08601236103900842, 0.07251113586659942, 0.05664354695805481, 0.03830888614590679, 0.033951456392449994, 0.06984323116817645, 0.014789620680468423, 0.028805606266749755, 0.012575988391680377, 0.08790760434099607, 0.0464692943330322, 0.030031515484941856, 0.04529331511418734, 0.0759124079985278, 0.027049388004732982, 0.07626610116234847, 0.05770735416029181, 0.04524781934118696, 0.061439934585775645, 0.04152417861457382, 0.14978367409535817, 0.048439190057771545, 0.03733727488932865, 0.016439371709046618, 0.020381855246211802, 0.029955855437687466, 0.013773953841466988, 0.022158244657995443, 0.09611902479082346, 0.05566354900864618, 0.014753202009680015, 0.03416620594050203, 0.119156150413411, 0.08665142567562205, 0.14096499873059137, 0.3325171172618866, 0.33101684919425417, 13.485346095902578, 50.020331791469026, 73.5703545979091, 56.011676583971294, 45.70465973445347, 33.223367418561665, 34.40431799207415, 55.25029993057251, 78.20492117745536, 32.78677388599941, 2.541589379310608, 1.3614623844623566, 1.0734290459326334, 0.670492478779384, 2.2268609532288144, 1.3205036222934723, 0.9644277691841125, 0.4050424141543252, 0.4644862615636417, 0.8220288902521133, 0.3575236297079495, 0.5845799031002181, 0.7281614957111222, 0.5868973444615091, 1.2907555614198958, 1.5681769379547663, 2.9101352947098866, 1.9113152452877589, 1.4343224976743971, 2.073575875588826, 2.0149406790733337, 5.3563593455723355, 7.01230788230896, 5.496078065463474, 6.9160110609872, 5.01674051795687, 2.477991431951523, 1.4261284002235957, 0.7491243194256509, 0.4519756500210081, 0.29376818080033573, 0.07954933534243278, 2.177845971924918, 6.230629461152213, 9.16262422289167, 4.429636410304478, 1.7850427010229655, 0.2396911382675171, 0.09524535667151213, 0.10188289478953395, 0.7097366100975445, 1.536464165363993, 2.8916209510394504, 3.8008656927517483, 1.6513759706701552, 1.0771634855440684, 0.6752686596342495, 2.020431710141046, 1.4100182418312346, 0.8810580170580319, 2.0620666188853125, 1.957899225609643, 1.6268618575164249, 2.207151302269527, 1.7444848716259003, 1.1404508267130171, 1.2747381180524826, 1.7282128419194902, 17.167596919195994, 53.259686197553364, 65.06709357670375, 33.936864035470144, 20.474242891584122, 31.48134286063058, 52.05997896194458, 51.753959451402935, 15.637445517948695, 1.4229294061660767, 0.12576858273574285, 0.3348234849316733, 0.023008345559771572, 0.1304225865751505, 0.1036571010148951, 0.011616367697050529, 0.027108841243066957, 0.031579986680299044, 0.05449748657909887, 0.05036913024793778, 0.05286850720377905, 0.0495073330987777, 0.11777850719434874, 0.018998766783624887, 0.04553591173940471, 0.04613129907686796, 0.10598689849887576, 0.07284527365118265, 0.01257154653181455, 0.06139853037893772, 0.02589399553835392, 0.10475058055349759, 0.028834464361092875, 0.031240488469068493, 0.02081918633276863, 0.02562134829349816, 0.04737251604508076, 0.036981953241463215, 0.025106647251439945, 0.06530776061117649, 0.06069307109074933, 0.028735469494547163, 0.030170954431274107, 0.05994335774864469, 0.009191284388569849, 0.007938587456010282, 0.08597827143967152, 0.09267019413943801, 0.024049891724384258, 0.06208872262920652, 0.0366403787130756, 0.05564174767849701, 0.00029411195802302767, 0.025798537535592914, 0.08026721860681262, 0.12432485020586423, 0.18015908130577632, 0.08261435266051974, 0.13220382242330483, 0.14386072834687574, 0.16029719422970498, 0.1838641403509038, 0.15502288724694932, 0.13744285915579113, 0.09687770836587463, 0.17860723100602627, 0.21711334692580359, 0.17211883488510335, 0.21661022678017616, 0.1862620288240058, 0.09538391352232013, 0.15582863401089395, 0.10957562950040613, 0.11126725801399776, 0.09694506653717586, 0.20301531627774239, 0.14625461346336774, 0.08598705846816301, 0.19163415341504983, 0.1127906505550657, 0.21177482338888304, 0.08351742848753929, 0.07198363595775195, 0.12297273347420351, 0.12070198889289584, 0.10679984451936823, 0.09960733260959387, 0.15238563876066888, 0.12093875690230302, 0.16655750758945942, 0.10983495201383318, 0.23270198330283165, 0.1996994377779109, 0.17956437250333174, 0.10182089025952987, 0.12000191717275552, 0.18993431462773255, 0.08030817498053823, 0.1001556364021131, 0.24334111383983068, 0.16511418218059198, 0.13965857454708644, 0.13824057206511497, 0.26276838566575733, 0.1157362660659211, 0.17744386914585317, 0.4739040019256728, 0.23230338469147682, 13.29847342627389, 58.891715322222026, 86.51695387704032, 73.13322257995605, 65.70028291429792, 54.24357543672834, 37.660657269614084, 44.89191852297102, 74.98309707641602, 51.0577186856951, 15.70677638053894, 1.176802824650492, 2.169027839388166, 3.1863131608281816, 7.296593427658081, 3.922386646270752, 5.053877770900726, 1.9527052300316947, 1.8248492564473833, 1.003314231123243, 0.481904852603163, 0.4916313535400799, 0.9258928426674434, 1.7672774600131171, 2.587338707276753, 3.3739946441990987, 2.5191141281809126, 1.930098180259977, 1.5056727890457426, 3.4479347680296217, 2.9581844764096394, 8.562416246959142, 13.331264580999102, 10.853752357619149, 12.134069987705775, 7.961810486657279, 2.1834785725389207, 0.6871559960501534, 0.5917736770851272, 0.3682072450007711, 0.1898148517523493, 0.1613237498594182, 1.1300172380038669, 3.7702827623912265, 5.096663475036621, 1.889818821634565, 1.3130033676113402, 0.23315945161240442, 0.20479096099734306, 0.11875375200595174, 0.3976096329944474, 0.8327995208757264, 2.158428145306451, 5.926050399030958, 4.108027747699192, 0.9782750947134835, 0.46790596949202673, 1.360417657664844, 1.3312734386750629, 1.9116787229265486, 4.20985837493624, 8.94150127683367, 12.615091170583453, 7.66394989831107, 11.738663639341082, 3.7854667476245334, 1.6496832157884325, 5.654554315975734, 31.968355996268137, 64.56062548501151, 62.60578455243792, 36.122319153376985, 33.39302158355713, 50.8674179485866, 66.31228024618966, 60.63442775181362, 23.353208133152553, 1.4427299265350615, 0.30074590923530714, 0.3592500127851963, 0.10472373092280966, 0.24432300829461642, 0.21668840758502483, 0.12041536213031837, 0.1515472951744284, 0.1927349679172039, 0.09658145997673273, 0.11709938863558428, 0.19430618360638618, 0.21054081246256828, 0.30597532434122904, 0.08514512543167387, 0.17434318124183587, 0.1095410513558558, 0.23367443255015782, 0.1284370981156826, 0.16048837825655937, 0.13777243718504906, 0.0802361009908574, 0.137954691691058, 0.1608902881188052, 0.16298314795962401, 0.10926887738917555, 0.0798784044704267, 0.1751001684793404, 0.18128261316035474, 0.10288877545722894, 0.15677612674023422, 0.16299190106136457, 0.15983919666281768, 0.08388740649180752, 0.09744053959314312, 0.08694555025015559, 0.07105150526123387, 0.16012510417827538, 0.14619852575872624, 0.1384791721190725, 0.17937253708285944, 0.09072208617414747, 0.19690042654318468, 0.08962305621909243, 0.14128879564149038, 0.08809445252908127], [0.04704894644341298, 0.055609344238681455, 0.025059377109365802, 0.057293624218021116, 0.029922620792474066, 0.08846377913973161, 0.03513144914593015, 0.02234262806762542, 0.03984995113153543, 0.018928809823202233, 0.026322946717430438, 0.02319727685036404, 0.05020009699676718, 0.06036145067108529, 0.010348009328091783, 0.02421741862781346, 0.03909060937751617, 0.02512495921525572, 0.05661116048161473, 0.043475428197000704, 0.02530124600577567, 0.06057436138923679, 0.029899818623172383, 0.06364243890025786, 0.020741919853857586, 0.02587371751932161, 0.059296754587973864, 0.04938718829570072, 0.02892500807398132, 0.03746475126328213, 0.035468250180461576, 0.01812436754283096, 0.032071734579013925, 0.049791971753750525, 0.03209943916382534, 0.024870623934215734, 0.07530632694917065, 0.024315953786884035, 0.06764339349631752, 0.01571387697809509, 0.015528647096029349, 0.056511276734194586, 0.012128418211692145, 0.058260767321501455, 0.042036221495696476, 0.09414921049028635, 0.010523637091474873, 0.06222447034503732, 0.07154610979237727, 0.14381245736564907, 0.10084848172430481, 0.1252000925264188, 0.145847723154085, 0.3502829282411507, 0.3864427650613444, 19.205204793385096, 51.6836610521589, 56.58652884619576, 52.74314669200352, 44.49289042609078, 32.378143378666465, 19.54604172706604, 33.17529630661011, 54.292747838156565, 53.16409635543823, 28.017997639519827, 6.331844738551548, 0.9025410328592572, 1.1482662473406111, 1.676739718232836, 1.5347650051116943, 0.9223145203930991, 1.454837054014206, 0.5042000476803098, 0.1704843525907823, 0.6307584451777595, 0.7393071662102426, 0.7958182767033577, 2.147045041833605, 6.5131193314279825, 3.8034673588616505, 3.2830726887498582, 1.3797918409109116, 2.9111314926828658, 6.489703033651624, 4.52825870684215, 2.4201070751462663, 2.2897249971117293, 3.1208133612360274, 2.174559908253806, 2.357356373752866, 0.5697528815695218, 0.22059398729886326, 0.22378783806094102, 0.04804119873525841, 0.05573328883786287, 0.1899929264826434, 0.07102082869304077, 0.049706927567188225, 0.07952092508120195, 0.11645326044942651, 0.3176429239766938, 0.126869546515601, 0.47287952261311667, 3.3510536466326033, 1.7905111504452569, 4.258588697229113, 1.2760127867971147, 2.3139933177403043, 4.0297727925436835, 4.4909655536924085, 2.670546208109174, 0.5823138132691383, 1.669052622147969, 2.1012535904135023, 1.4165374977248055, 0.4692230873874256, 0.051071179897657464, 5.22019636631012, 32.99797827856881, 45.03816768101284, 36.39183282852173, 29.962133135114396, 23.765046971184866, 44.744078227451865, 50.64667367935181, 48.454082761492046, 17.784503153392247, 1.3544018204723085, 0.0982599656230637, 0.21482873308871472, 0.07318567431398801, 0.008427520282566547, 0.14029402259205068, 0.02001447942374008, 0.0842919083578246, 0.042132430975990634, 0.03391053055280021, 0.04985747752445085, 0.03432174313015171, 0.02363356638566724, 0.025456106356744255, 0.1091665882351143, 0.04393150890246034, 0.06515035405755043, 0.03211701322080834, 0.03644983250913875, 0.0173794344799327, 0.02345351202945624, 0.031771516760012934, 0.05657380373616304, 0.036650454958102534, 0.038514533146683655, 0.12735111638903618, 0.03428528205092464, 0.0726256115095956, 0.09330795598881585, 0.018855899539110915, 0.07281762334917273, 0.05636207027626889, 0.06655503011175565, 0.011409674904176166, 0.05607020522334746, 0.04965493482138429, 0.029143530276737044, 0.08283458477152245, 0.029083988828850642, 0.052752430218138864, 0.02508294432690101, 0.04405406250485352, 0.11865123893533434, 0.053001934329846075, 0.026095009841290966, 0.035949392576834986, 0.02985947293096355, 0.02408126718364656, 0.06142696099621909, 0.05971258120345218, 0.10024600369589669, 0.0401036418043077, 0.03598547028377652, 0.011624136923014053, 0.045165869274309704, 0.03910784077431474, 0.035277897359005043, 0.015046827860974839, 0.022286849096417427, 0.09517444976206337, 0.05300610392753567, 0.057906653465969224, 0.03858729245673333, 0.03844027088156768, 0.005764414098978574, 0.0017390934164203437, 0.015667017349707227, 0.0422181435195463, 0.026988710010690347, 0.035834991572690864, 0.028197847539559007, 0.02642440127341875, 0.0348722284127559, 0.02858782366716436, 0.04521819110959768, 0.04588392895779439, 0.03830291164506759, 0.02253863138944975, 0.003951184900610575, 0.004143432955191071, 0.0522333611068981, 0.030815135221928358, 0.03950774556558047, 0.021095803007483482, 0.077880369898464, 0.015117926456566368, 0.03702082312000649, 0.004033319868280419, 0.01469501423915582, 0.05789137285734926, 0.019747041631489992, 0.010666975917826806, 0.03071794525853225, 0.08892550864922148, 0.053764997848442624, 0.06618651774312768, 0.05518854735419154, 0.03653468670589583, 0.10181069187819958, 0.1667481895004, 0.06092842096196754, 0.42332013909305843, 1.762174550976072, 29.072298186165945, 66.64158317020961, 63.58254146575928, 54.03326736177717, 32.90467439379011, 21.763350861413137, 31.97272641318185, 60.447271074567524, 75.12843949454171, 49.35212353297642, 11.444031357765198, 2.373459041118622, 0.9896073894841331, 0.9671188933508736, 1.3696775436401367, 0.6054307956780706, 0.7220788906727518, 1.6961396315268107, 1.192159972020558, 1.4687664551394326, 0.1854074275387185, 0.9221439638308117, 1.0833487936428614, 1.4301463046244212, 1.7279887625149317, 2.3676822653838565, 2.021745136805943, 4.4709139210837225, 7.490087730543954, 5.0432353019714355, 3.386071047612599, 3.291404664516449, 2.9525748917034695, 3.243323347398213, 3.710414477757045, 2.5841499183859145, 0.7008431330323219, 0.36957395023533274, 0.6654913499951363, 0.2711668850055763, 0.27713886169450624, 0.3313010739428656, 0.22457645860101494, 0.27852812143308775, 0.29153197365147726, 1.0096116874899184, 0.9088554797427995, 1.7762108892202377, 0.6805545017123222, 3.766865985734122, 3.5964555527482713, 1.5572153947183063, 3.469837009906769, 2.416187856878553, 1.874234880719866, 2.331860827548163, 0.6647738399250167, 0.8323398541126932, 1.8110001938683646, 1.4309318853276116, 0.3185490124991962, 0.8719206473657063, 0.272957376071385, 2.5830516687461307, 25.213240895952495, 63.42337213243757, 66.92727225167411, 45.88719238553728, 26.452601500919886, 35.982913970947266, 55.219168526785715, 59.1974846976144, 26.75931235722133, 4.215732642582484, 0.2558863306684153, 0.18074714046503815, 0.08228295615741185, 0.06833516673317977, 0.12445048774991717, 0.031386753477688344, 0.006832149594889155, 0.017741444786744456, 0.04132565623149276, 0.018624142510816455, 0.045358949806541204, 0.023956549054543887, 0.02174063179908054, 0.02677373993875725, 0.045670003829790015, 0.0836644195286291, 0.05718940802450691, 0.005220508485633347, 0.0331910255897258, 0.09338110206382615, 0.05341343867725559, 0.06609720896397318, 0.06435853761753865, 0.04038885721404638, 0.07235753589442798, 0.06668455566146544, 0.04738207321081843, 0.026537329856572405, 0.0515321765893272, 0.039378135198993344, 0.03209622969318714, 0.05082651034795812, 0.046311148176235814, 0.05919975122170789, 0.008469966888826872, 0.021898620196485093, 0.020138123771175742, 0.017265986817489778, 0.02518939968597676, 0.044438632404697795, 0.028171637428126166, 0.03559366720063346, 0.025581815146974156, 0.013094702968373895, 0.02816738810257188, 0.020321748917922378, 0.03235122315319521, 0.1975647530385426, 0.15607537648507527, 0.14719173817762307, 0.15901940422398703, 0.10028989812625305, 0.112191571987101, 0.10887558492166655, 0.15441808184342726, 0.08154164986418826, 0.07589318510144949, 0.08801665170384304, 0.23689467832446098, 0.16461353190243244, 0.12158774850623948, 0.07692462618329696, 0.16615110582539014, 0.12908508548779146, 0.12750447887395108, 0.15950197832924978, 0.11919370054134301, 0.11120962324951376, 0.09613805091274635, 0.20035803743771144, 0.12395185950611319, 0.09556825791618653, 0.14501024809266838, 0.1966673226228782, 0.16891192910926683, 0.1298117557806628, 0.09109439155352966, 0.1365036852657795, 0.08707887559596982, 0.18058691120573453, 0.16579818619149073, 0.226771207260234, 0.13294265206371034, 0.17435886897146702, 0.14568886453551905, 0.14870594335453852, 0.06190260047359126, 0.12790651087250027, 0.17111829428800515, 0.06792197283357382, 0.1641822957566806, 0.15836906912071363, 0.20889627427927085, 0.09373536519706249, 0.16148138711495058, 0.10187535626547677, 0.14432066652391637, 0.31372772263629095, 0.2091217650366681, 0.18123701560710156, 0.8215446333800043, 1.1335062107869556, 31.3995486668178, 80.0901689529419, 77.88964666639055, 68.16560799734933, 59.391936983381, 45.81610883985247, 32.3031827381679, 47.570522035871235, 66.3916425704956, 63.672826358250205, 34.65066637311663, 8.389651026044573, 1.0278039170163018, 1.4883304110595157, 2.910645987306322, 3.7926355515207564, 3.8635684081486295, 4.328736841678619, 3.895879702908652, 3.8995049255234853, 5.456160230295999, 7.87301858833858, 8.034918563706533, 10.13787511416844, 18.49634436198643, 12.770510213715689, 10.40576377936772, 11.649759701320104, 15.623766251972743, 14.866450820650373, 12.875220435006277, 6.463947798524584, 9.609653949737549, 10.296805603163582, 7.535336136817932, 7.406445315905979, 3.5308061497552052, 0.34347993614418165, 0.305375906505755, 0.21427788478987558, 0.23569456700767788, 0.2900530658662319, 0.18158012362463133, 0.13515734965247767, 0.1975048112549952, 0.3129950133817536, 0.5636782018201691, 2.0969743686062947, 2.1977013179234097, 10.978454283305577, 10.382648859705244, 15.639648096902029, 13.535058719771248, 10.568692088127136, 15.116466113499232, 12.98718978677477, 9.981303538594927, 9.49289642061506, 7.293424180575779, 4.936155744961329, 3.870200897966112, 0.7790758865220206, 0.4809653258749417, 8.53768413407462, 42.045602866581504, 53.97313070297241, 47.858733313424246, 44.777283668518066, 35.964834758213584, 59.78123760223389, 67.14449378422329, 67.48858247484479, 30.065425055367605, 6.790447124413081, 0.34612899113978657, 0.41844258510640686, 0.19905708224645682, 0.1421611609735659, 0.4058772293584687, 0.06195735824959619, 0.17299422648336205, 0.11182807399226086, 0.11918805512998785, 0.11145378050527402, 0.2454526876764638, 0.10101936398340122, 0.12136296342526164, 0.15869070829025336, 0.0863482290878892, 0.2570619875831263, 0.16572366947574274, 0.10700286898229804, 0.16740001738071442, 0.12540102031614098, 0.1393747433487858, 0.14871692205114023, 0.14964716642030648, 0.17065015940793923, 0.27553331213338034, 0.11536224399294172, 0.1448114916150059, 0.16935700736939907, 0.09491092711687088, 0.43105190992355347, 0.11218813859990664, 0.24739400350621768, 0.1156405790575913, 0.1457838730088302, 0.12141932254391057, 0.1345766729542187, 0.12904066858547075, 0.14029061634625706, 0.13452116878969328, 0.19424078640128883, 0.1610787987176861, 0.23797316902450152, 0.21600965543517045, 0.11056876728045088, 0.1102297440437334, 0.08559335209429264, 0.17174344217138632], [0.06358052257980619, 0.08225833890693528, 0.06824315059930086, 0.02511640458500811, 0.016276358759828975, 0.02993813549567546, 0.04717219215152519, 0.03450457778360162, 0.03471484900053058, 0.025105461511494856, 0.045798708352127245, 0.017559624543147426, 0.01995068695396185, 0.09179598319211177, 0.03983050771057606, 0.04350499875311341, 0.010554779304324515, 0.01998293772339821, 0.048074202678565464, 0.008242966391013136, 0.04605213100356715, 0.024358246874596392, 0.04426962290225284, 0.03578967221879533, 0.013660390828070896, 0.061172252520918846, 0.04538223034303103, 0.045601152881447754, 0.06468230060168675, 0.11394139166389193, 0.08475823833474092, 0.07089584932795592, 0.018843137991747687, 0.024826994132516638, 0.022563766022878032, 0.029463262762874365, 0.059459270510290346, 0.048844998103699515, 0.03357966330700687, 0.03607000896174993, 0.03825952272330012, 0.06655021929847342, 0.0012040192544061157, 0.03585231796439205, 0.0639011168054172, 0.019033492509541765, 0.02063573760512684, 0.07511981124324457, 0.07144458738288709, 0.09049475658684969, 0.05501823167183569, 0.0037613019646544543, 0.07358892089022057, 0.4420096262225083, 0.14035760132329805, 0.4670977528606142, 1.3902046935898917, 23.9709655216762, 66.05928938729423, 61.730839593069895, 55.33713504246303, 52.5235766683306, 25.43942039353507, 20.709762505122594, 24.23618347304208, 38.89911460876465, 57.216167654309956, 47.91903325489589, 37.24012449809483, 22.139955384390696, 9.637528385434832, 3.590594095843179, 0.8615768966930253, 0.15370207812104905, 1.203816335116114, 2.4269586503505707, 2.3682830674307684, 1.499264052936009, 2.33353990316391, 1.0925347464425224, 1.3511434410299574, 1.1118309795856476, 1.9616245457104273, 3.5907953764711107, 2.446968593767711, 3.759035800184522, 5.3385120289666315, 3.8604204399245123, 2.603744924068451, 4.154621064662933, 4.035744769232614, 0.39148940997464315, 1.2801642268896103, 3.0284672422068457, 1.0642554696117128, 0.8769643881491253, 0.40448604258043425, 2.204205048935754, 1.008358514734677, 0.441787772412811, 3.4520893565246036, 1.7111328669956751, 2.9544359232698167, 1.0868028083017893, 1.2649211819682802, 3.8241907954216003, 0.3716691035245146, 0.8987099155783653, 0.12342796261821475, 0.5946446401732308, 0.8091747228588376, 0.5958525953548295, 0.29263584156121525, 0.5666808549846921, 3.7743448529924666, 14.06138563156128, 24.441695553915842, 53.104536397116526, 79.2380279813494, 36.13295684541975, 15.556535482406616, 27.76282157216753, 32.9200507572719, 53.09028564180647, 47.23077596936907, 25.195771387645177, 4.120088083403451, 0.0443977099577231, 0.21848425907748087, 0.05798777232744864, 0.026479340557541167, 0.08896047355873243, 0.09115835704973765, 0.02097612469723182, 0.021223583025857806, 0.033206747246107886, 0.03107302263379097, 0.011634149555382984, 0.053262040551219664, 0.06351153592446021, 0.02387880760111979, 0.040610178373754025, 0.1399709584989718, 0.03393436748800533, 0.06271331411387239, 0.017100188482020582, 0.03125274620418038, 0.07683791619326387, 0.036104926373809576, 0.01096577475047005, 0.0548950300684997, 0.05190173050920878, 0.021916533520977412, 0.07101044032190527, 0.046958334877022674, 0.03036663035995194, 0.04304142023569771, 0.07658123996640955, 0.08136419260076114, 0.04222652003435152, 0.024444534476580362, 0.06756135861256293, 0.03454578521528414, 0.010341439412773719, 0.016858635104394386, 0.018355052485795956, 0.03057992784306407, 0.04214005092425006, 0.05565214962033289, 0.016847084742039442, 0.09812718310526439, 0.04053844365158251, 0.042873815300741365, 0.03271913841100676, 0.0729503176574196, 0.06722981283175093, 0.024737242609262466, 0.06379989295133523, 0.044106462371668646, 0.04076517273538879, 0.04253929753654769, 0.03108017100021243, 0.09646378843379871, 0.026853008095973303, 0.020893828577495048, 0.0389100613870791, 0.05698494506733758, 0.058127679462943754, 0.02446413565693157, 0.07925977730857474, 0.04009790139804993, 0.016692582318293195, 0.028493598901799748, 0.02509222668595612, 0.08035845442542008, 0.012787615830477859, 0.027061642347169772, 0.004185100942517498, 0.050981270615011454, 0.027286625899640576, 0.030590502811329703, 0.04771797518645014, 0.05533647138093199, 0.005635332989705992, 0.011699321995755392, 0.09158816827195031, 0.050087480539722104, 0.042018277637128315, 0.04143895122355648, 0.06191876317773547, 0.025597222980910113, 0.041320061710264, 0.06853994860180787, 0.06145885892744575, 0.013339032402395137, 0.059969467776162286, 0.0632274875949536, 0.1382023976849658, 0.023246061821867312, 0.02327307260462216, 0.0598024328106216, 0.020564988455069915, 0.02182272944732436, 0.06699551468981163, 0.11068107161138739, 0.023870560007968118, 0.04193285347095557, 0.042154883699757714, 0.0289174865132996, 0.3503015472420624, 0.10771676924611841, 0.33054114186338013, 4.715058854648045, 36.584711347307476, 77.42402703421456, 65.57980115073067, 54.8168226650783, 35.74422597885132, 19.29033933367048, 28.945717641285487, 51.539631843566895, 70.7819104875837, 73.97332232339042, 42.763494219098774, 21.63166686466762, 9.613107204437256, 0.30343209366713253, 1.7782296666077204, 1.4892417107309615, 0.442748062312603, 1.6058853545359202, 1.1763378381729126, 0.421896898320743, 0.4121150017849037, 1.062090345791408, 0.9243217898266656, 1.3388715109654834, 1.79117166357381, 1.8339103588036128, 2.7125752099922726, 2.4694349425179616, 0.7525659576058388, 0.6363964740719114, 1.5352597385644913, 0.6993558928370476, 3.706224714006696, 2.7360229917934964, 1.409915213074003, 1.826067796775273, 2.592711401837213, 1.3949061270271028, 0.6385407532964433, 0.6022198594042233, 0.8968233168125153, 1.3132249500070299, 0.4952757922666413, 0.11270616615989379, 1.315475514956883, 1.1467265699590956, 1.512504062482289, 1.6756220353501183, 1.5954208246299197, 1.853207243340356, 1.5893615611961909, 0.5469952513064656, 0.6988096450056348, 0.47188821009227205, 0.3580980503133365, 0.5403721524136407, 0.8266162212405885, 1.954746697630201, 3.4972871712275913, 24.36420750617981, 38.68042353221348, 63.97789396558489, 58.24386528560093, 27.361123629978724, 18.304841586521693, 30.62436941691807, 53.45915160860334, 60.02116584777832, 37.00663028444563, 7.786328520093646, 0.08160583249160222, 0.21678532952708857, 0.013080172140949538, 0.014448146235996058, 0.10778513164924723, 0.08672179654240608, 0.015991460565211515, 0.09783788291471344, 0.07016020880213805, 0.04380880941503814, 0.04051760244848473, 0.07891611967767988, 0.0670410715309637, 0.04882531041013343, 0.0257704801125718, 0.1464411291692938, 0.025087931559288075, 0.01863939767437322, 0.021088099938684275, 0.041024217049458196, 0.02333154875252928, 0.014095706665622336, 0.05188490962609649, 0.022879903969754065, 0.05671536310442856, 0.04105580624725137, 0.03833461958648903, 0.04970218460740788, 0.03421423264912196, 0.037900421635380814, 0.012029079836793244, 0.022021696270842637, 0.03517106880566903, 0.0338788599308048, 0.07756409794092178, 0.028468839158969264, 0.046914691504623206, 0.04227344751624124, 0.03158971008711627, 0.0761212067944663, 0.10437146268252816, 0.08087635306375367, 0.03551374256078686, 0.02088378625921905, 0.029267128823058944, 0.02306250961763518, 0.03361542210248964, 0.022590211925229857, 0.06068705927048411, 0.09725563201521124, 0.16690227123243467, 0.21255370016608918, 0.09293982359979834, 0.1648549275206668, 0.11713214830628463, 0.22570513375103474, 0.14886051363178662, 0.1518608190651451, 0.15681112557649612, 0.1248345249997718, 0.13166583914841923, 0.1044122019250478, 0.22863864419715746, 0.14981055765279702, 0.10325369837560824, 0.15057880857161113, 0.12108807531850678, 0.2248601812337126, 0.06466243309634072, 0.10213832251195397, 0.15159997663327626, 0.09478448890149593, 0.18197466459657463, 0.13733034447899886, 0.1539953952389104, 0.12213372492364474, 0.17678507949624742, 0.07102699657636029, 0.2513644647385393, 0.13270946671920164, 0.18828273325094155, 0.1406916305422783, 0.09055140069020645, 0.17165581615907805, 0.12021817985389914, 0.14312161372176238, 0.22607175979231084, 0.13528401856975897, 0.21985746467752115, 0.11427970922419003, 0.254400691815785, 0.07608135643282107, 0.15499817500157015, 0.21348467735307558, 0.11927851741867405, 0.13153838313051633, 0.1421604688678469, 0.21787052415311337, 0.18500497484845774, 0.11600466737789766, 0.12308443390897342, 0.1632848246289151, 0.6582588723727635, 0.12207503164453165, 0.5812647981303078, 4.793307730129786, 43.1590690612793, 91.43257508959088, 79.18159471239362, 68.73942497798375, 70.23085580553327, 36.65802526473999, 30.94918727874756, 36.89330169132778, 56.097274916512625, 72.03050872257778, 59.29950509752546, 46.01896497181484, 29.032240084239415, 12.620233706065587, 4.365911441189902, 1.03610451732363, 0.20693800864475115, 1.8152756158794676, 4.23078852040427, 4.238634773663112, 2.991561668259757, 6.614953867026737, 3.4215435556003024, 6.40540314572198, 4.857659774167197, 11.276662281581334, 9.33767192704337, 11.75115476335798, 15.78265939440046, 18.91273079599653, 17.4540433543069, 15.576485497610909, 16.30234295981271, 17.10007779938834, 9.08146926334926, 13.662004913602557, 13.133005550929479, 5.06993853194373, 3.203791788646153, 4.6141775250434875, 6.662921624524253, 4.979863388197763, 6.372316258294242, 8.947061572756086, 11.154087373188563, 10.885893855776105, 9.424030218805585, 8.811995540346418, 13.056320888655526, 4.223989708083017, 5.528198284762246, 4.663632197039468, 2.7268081605434418, 2.6131603845528195, 1.1190714367798396, 0.7195816103901181, 0.8548916439924921, 5.642764525754111, 17.98793772288731, 32.01555510929653, 61.23962279728481, 90.96927615574428, 44.618093490600586, 25.411994116646902, 42.45564385822841, 46.26427459716797, 66.20108822413853, 67.40527357373918, 42.31539446966988, 10.035568969590322, 0.14232103739465984, 0.5916881273899759, 0.11076303864164011, 0.16058698296546936, 0.22715087474456855, 0.15214450098574162, 0.1447221285530499, 0.15538536065391131, 0.162558927865965, 0.1307325413716691, 0.11955943091639451, 0.13674326241016388, 0.1188164215002741, 0.13552378570394857, 0.14903248154691287, 0.2506449190633637, 0.2127657559301172, 0.13579264841973782, 0.08797388364161764, 0.15633463114500046, 0.17141467838415078, 0.15224884610090936, 0.13358523829707078, 0.16664874340806687, 0.2210353064749922, 0.15293635135250433, 0.16442203574946948, 0.27367868593760897, 0.37879621822919163, 0.1275572824691023, 0.12035953226898398, 0.21312915214470454, 0.11727474922580378, 0.1444744225591421, 0.15514817195279257, 0.16272947085755213, 0.18612600969416754, 0.1353495107697589, 0.11739604414573737, 0.14331319129892758, 0.1949855192963566, 0.14760523741798742, 0.10504622504647289, 0.18935522570141725, 0.09002092201262712, 0.18815773352980614, 0.08098740210490567, 0.19175426768405096, 0.2190556398459843], [0.06948438113821404, 0.025351634016260505, 0.024495444959029555, 0.05997208013598408, 0.013971175981818565, 0.0037888759314747794, 0.025351657764986157, 0.04004722501018217, 0.05251173009829862, 0.013083581779418247, 0.027646488643118312, 0.05395892994212253, 0.036863776189940314, 0.009319741245625275, 0.052475092599966695, 0.019605992860825996, 0.06597567655678306, 0.02899917195151959, 0.015857580517019545, 0.016797258219282542, 0.02380725777974086, 0.03313875125188913, 0.046697007292615514, 0.021879643268351043, 0.04456250236502715, 0.029978817062718526, 0.009696144128351339, 0.014118169567414691, 0.03352700559688466, 0.09490963790033545, 0.0219814523588866, 0.081826831347176, 0.06482068781874009, 0.01898409516018416, 0.028070155730737106, 0.02439960528032056, 0.008232946125125247, 0.06357280085129396, 0.058139770956976075, 0.08213038077311856, 0.038998650919113836, 0.024401713827891008, 0.023197487196219817, 0.007275246532766947, 0.023439732679565038, 0.01855161220633558, 0.0005944004930954959, 0.025688178903822387, 0.012018329297591532, 0.023646319451342736, 0.05066010641998478, 0.09178674154515777, 0.027755525827940022, 0.15097888638930662, 0.02348348292122994, 0.0646705280191132, 0.12946065462061337, 0.18045154346951417, 10.362213339124407, 45.49245480128697, 55.852632318224224, 58.487024443490164, 55.96165302821568, 52.05100883756365, 37.0641439982823, 20.317825044904435, 20.964401824133738, 22.78239277430943, 21.40386322566441, 28.9817179952349, 50.01547152655465, 48.14220939363752, 48.61319303512573, 42.93270022528512, 38.89792994090489, 26.44455201285226, 17.039564200810023, 9.602683169501168, 5.8788239274706156, 3.2895312564713612, 2.183108363832746, 0.5486588020409856, 0.04608623417360442, 0.2546602450311184, 0.5250295528343746, 0.6064115773354257, 1.3046658549989973, 1.6345320173672266, 1.5874695884329932, 1.692270570567676, 1.3205536710364478, 0.6557530154074941, 1.4912793785333633, 1.323585799762181, 0.43549178168177605, 0.9632630773953029, 1.031917142016547, 1.4473809855324882, 2.048610346657889, 2.299191700560706, 1.7439158793006624, 2.3373705318995883, 0.9729899040290287, 0.576548274074282, 1.6252480298280716, 0.27446814786110607, 0.2455683100436415, 0.7687576487660408, 2.0391566710812703, 4.929036012717655, 8.998778751918248, 23.17224403790065, 36.96901968547276, 48.707136154174805, 53.645748955862864, 45.10237945829119, 23.32843954222543, 59.12212453569685, 59.08282552446638, 23.785723073141916, 63.12147985185896, 71.03989710126604, 51.33663327353341, 28.401725803102764, 8.00456188406263, 0.06453883794269391, 0.4301972814968654, 0.03048172007713999, 0.04729113594761916, 0.029748773335346153, 0.06046371268374579, 0.04810575794960771, 0.03786775017423289, 0.017923180213464156, 0.07544463274202176, 0.05373466054775885, 0.041134685943169255, 0.04270379478111863, 0.05117312978420939, 0.07276159671268292, 0.04899333603680134, 0.048293627332895994, 0.025295417389965484, 0.0658113421606166, 0.05790226334439857, 0.07177588889109236, 0.042226978045489104, 0.013913049279446048, 0.043533202061163526, 0.044056586655122895, 0.04029404890856572, 0.047731186263263226, 0.01252776151522994, 0.011068050333830928, 0.047509559762797186, 0.028795855718531778, 0.06307384691068105, 0.029158946592360735, 0.08029752876609564, 0.014201737092142659, 0.06389756128191948, 0.037241916970482895, 0.06820724252611399, 0.059934686071106365, 0.03085367940366268, 0.07706941877092634, 0.06743931730410882, 0.06038684145148311, 0.009784586927188295, 0.036235710605978966, 0.06124205341828721, 0.022152879142335484, 0.05410103553107806, 0.04189246028129544, 0.018131736433133483, 0.04261626037103789, 0.02428581835036831, 0.03551021417868989, 0.019087632818679725, 0.022678989750732268, 0.013513839138405663, 0.02588752061793847, 0.05397782714239188, 0.05311481880822352, 0.04385055288938539, 0.026033673668280244, 0.027113969271470393, 0.030629019851663282, 0.01709574238131089, 0.07184119110128709, 0.06465074193796941, 0.04398035663845284, 0.03616129906315889, 0.04871001373976469, 0.032211163347320895, 0.03449769404583743, 0.07018485319401536, 0.02771146685284163, 0.09104296538446631, 0.033930415021521707, 0.07233948007758174, 0.026713584416678975, 0.035974946205637286, 0.062842832878232, 0.07020311257136719, 0.03177669058953013, 0.016120981025908674, 0.07253979718578712, 0.024120060727000237, 0.010984702484815248, 0.10041369684040546, 0.030184620126549686, 0.018142131589619175, 0.04093263178531613, 0.06225815282336303, 0.05130354421479361, 0.037879244557448795, 0.012768571897010719, 0.04756204444648964, 0.04651791136711836, 0.005970108173122364, 0.03142367935340319, 0.04770305420139006, 0.03197599668055773, 0.0018701334774959832, 0.050291414239576886, 0.059630424183394225, 0.09612800180912018, 0.036243825884802, 0.16152603471917765, 0.08266349895192043, 0.07927334122359753, 0.1971744325544153, 0.3638413878423827, 19.098372765949794, 62.09180545806885, 68.39441217694963, 68.73816735403878, 51.36980397360665, 35.03709738595145, 17.860208988189697, 20.786336864743912, 40.413429328373496, 51.404965332576204, 58.05886254991804, 60.18362167903355, 64.83394677298409, 57.13532188960484, 52.355913162231445, 34.47103806904384, 22.035817520959036, 9.006942016737801, 1.882604854447501, 1.444269061088562, 1.9744420179298945, 1.8445884372506822, 1.6894002045903886, 1.3716264047792979, 0.16627871112099715, 1.0469973385334015, 1.0324855915137698, 0.8572663537093571, 0.47145199349948336, 0.3839905123625483, 0.14964994841388293, 1.2023618817329407, 0.964932273541178, 0.6291189960071019, 0.5062506347894669, 0.671855737056051, 0.605989148574216, 0.7205934418099267, 0.2080583513847419, 0.5866068229079247, 0.709666368152414, 0.696838419352259, 0.9684695580175945, 0.5649172067642212, 1.1629492023161478, 0.6790154214416231, 1.1925635103668486, 0.4549120238849095, 0.7728806446705545, 1.0064663248402732, 1.7193130680492945, 1.5433663321392876, 2.31663623877934, 10.173609699521746, 22.569611140659877, 48.64988994598389, 64.957457951137, 65.69048595428467, 48.084396907261436, 84.79156330653599, 81.1957871573312, 21.565410579953873, 27.806803669248307, 58.00369732720511, 63.28371334075928, 43.38371474402291, 12.743210741451808, 0.48260265801634106, 0.5195952472942216, 0.049872459577662606, 0.028232171233477335, 0.06007217083658491, 0.06732260249555111, 0.08344972426337854, 0.0416517024859786, 0.06353628209659032, 0.12006214394101075, 0.03681418885077749, 0.03287184610962868, 0.07882465315716607, 0.028170697657125335, 0.07169585568564278, 0.029130743284310614, 0.015432308694081647, 0.026985934802464077, 0.021184682613238692, 0.06688474384801728, 0.012328737864403852, 0.08170046777065311, 0.03778203423800213, 0.00991067145618477, 0.023484926504482116, 0.09867543940033231, 0.013542691295567368, 0.061595244466194084, 0.013230324307057475, 0.03174599027261138, 0.029059422468500476, 0.030147022501166378, 0.013820680307357438, 0.09618689864873886, 0.024197800484086786, 0.04577090198706303, 0.02094004868662783, 0.010115646707293178, 0.024988288691799556, 0.032526034130049605, 0.0415065672381648, 0.013327413338369556, 0.056028356576072316, 0.0294539566550936, 0.035830560739019086, 0.03747176392269986, 0.023186971599768316, 0.03034558898902365, 0.054077734638537676, 0.03419866366311908, 0.0351430215606732, 0.16287139324205263, 0.10467272544545786, 0.19398298380630358, 0.23515054477112635, 0.16189754621258803, 0.08103776975933995, 0.123729354302798, 0.08080286772123405, 0.15142946078308991, 0.058322914343859465, 0.10581734616841589, 0.10748053727937595, 0.10184335655399732, 0.28049972706607407, 0.15428248340530054, 0.1415657057826008, 0.12437909229525498, 0.1308903279049056, 0.1161719262599945, 0.12086599080690316, 0.12882178675915512, 0.14490002686423914, 0.15112957544624805, 0.1286832841911486, 0.2330760732293129, 0.13756230846047401, 0.1762284500790494, 0.16001953770007404, 0.1437148026057652, 0.1541833087269749, 0.11982483310358864, 0.20478380923824652, 0.11879796534776688, 0.061638799629041126, 0.13922078375305447, 0.10254070056336266, 0.13190381495015963, 0.1519177888653108, 0.16265997530094214, 0.13088929653167725, 0.07277395283537251, 0.20919128773467882, 0.08168712777218648, 0.08865468496722834, 0.12080086501581327, 0.1280727790934699, 0.14849190626825604, 0.12570903450250626, 0.09344345943203994, 0.14200953553829873, 0.1228009962609836, 0.20158374309539795, 0.11775174577321325, 0.3583498139466558, 0.12250603708837714, 0.3806699519710881, 0.27189343316214426, 0.4293121461357389, 18.193646090371267, 72.62982559204102, 83.91732011522565, 78.29927076612199, 68.68136583055768, 65.56183310917446, 51.801106452941895, 33.23653425489153, 34.89191825049264, 35.2100693157741, 37.25622694832938, 44.0161189351763, 64.55473341260637, 60.09782532283238, 60.39857809884207, 54.86066927228655, 49.85816083635603, 34.2106682232448, 20.84386794907706, 13.679271187101092, 8.60810933794294, 4.179897742612021, 3.5714142450264523, 0.8428428162421499, 0.11089853529951402, 0.5848994116697992, 0.8212757163814136, 1.1607119909354617, 1.4568113195044654, 3.2427201569080353, 3.5476101509162357, 3.3082067114966254, 3.0768334354673113, 2.1113395520618985, 2.742890851838248, 3.267657893044608, 4.407839477062225, 3.97841431413378, 3.5162047275475095, 4.144260432038989, 4.890858267034803, 5.699678957462311, 3.6381501725741794, 4.081644134862082, 2.3948898911476135, 1.5609708960567201, 2.360437248434339, 0.5614993444510868, 0.6823132644806589, 1.2278326749801636, 3.4381610410554067, 7.261027770383017, 13.803289583751134, 29.719915458134242, 47.54136044638497, 58.97017438071114, 67.45279925210136, 57.36215625490461, 32.986569336482454, 68.28743771144322, 69.91705431256975, 37.56870828356062, 84.57916382380894, 85.00193391527448, 74.89547334398542, 53.53904547010149, 15.472278152193342, 0.414153592394931, 0.641492054930755, 0.1976073786084141, 0.19839194150907652, 0.15643068456224032, 0.09352191843624626, 0.3760891892015934, 0.1253276706806251, 0.1912883176867451, 0.2378633820584842, 0.17776522333068506, 0.1393394052450146, 0.1674465648829937, 0.07166063971817493, 0.19454396941832133, 0.1327090731688908, 0.130373229937894, 0.12733069248497486, 0.11288377270102501, 0.15009942358093603, 0.16042843647301197, 0.20563860051333904, 0.11618460129414286, 0.1529213964406933, 0.08363847913486616, 0.1912431272545031, 0.13342628468360218, 0.10723514508988176, 0.08382105933768408, 0.20154398094330514, 0.13158681696014746, 0.12169061441506658, 0.23781501608235495, 0.1674696622150285, 0.09407446307263204, 0.14133133978715964, 0.12434614263474941, 0.14227165361600264, 0.14639538233833654, 0.0724259457950081, 0.18789786818836415, 0.10549353568681649, 0.20853304091308797, 0.1743955234331744, 0.14931100660136767, 0.1654298502419676, 0.12310671699898583, 0.09032588279140846, 0.17358166139040673, 0.1422023344784975, 0.09444430536989655], [0.0457825151139072, 0.013531784693311368, 0.03814894526398607, 0.08132125490478107, 0.04477683800671782, 0.024127178559345857, 0.07507268698619944, 0.023756250606051514, 0.058354473007576804, 0.07089424798531191, 0.036243473046592305, 0.07318490756941692, 0.05975401933704104, 0.0048252618372706425, 0.058142871862011294, 0.0883466572101627, 0.04301355619515691, 0.03162007452920079, 0.02069438508312617, 0.05785454197653702, 0.026484680628137927, 0.0623208698151367, 0.06290936323681048, 0.04198745518390622, 0.017000072336356555, 0.044174326051558764, 0.030854140807475363, 0.035469837952405214, 0.06000625115952321, 0.012158155008884413, 0.06762751577688114, 0.01436565673377897, 0.03342082504449146, 0.020539446700630442, 0.06973344420215913, 0.02234905549058957, 0.08093982322939805, 0.05981996615550347, 0.04721226303705147, 0.06367522571235895, 0.03315155520769102, 0.023549828379015838, 0.06106476578861475, 0.04339042132986443, 0.07106489954250199, 0.013404091188151921, 0.09938197755920035, 0.030698769858905246, 0.00905413380158799, 0.027929933076458316, 0.05153206463104912, 0.03200095319854362, 0.10085140621023518, 0.06470461761845009, 0.0051549111127055115, 0.2083573139139584, 0.06368840964777128, 0.08091457494135414, 0.40228031522461344, 0.1596610676497221, 12.053953783852712, 40.08879211970738, 52.667216777801514, 56.65366928918021, 57.20344202859061, 55.37714624404907, 54.485292843409944, 34.30193975993565, 23.2673978805542, 28.856648683547974, 25.7003321988242, 14.818503039223806, 11.548366376331874, 16.241365568978445, 22.358903544289724, 42.96088211877005, 54.151616028376985, 54.91200256347656, 52.186054025377544, 54.58179637363979, 37.75400284358433, 44.708156040736604, 45.62615898677281, 28.004610197884695, 27.430424962724956, 25.25500304358346, 19.76317640713283, 13.260841982705251, 9.030313151223318, 6.3722328799111505, 5.572371023041861, 4.308351695537567, 3.4844353922775815, 3.5718871567930495, 2.0478223775114333, 3.3856048669133867, 4.239764290196555, 6.290764382907322, 7.252748557499476, 7.6183801378522595, 7.928558145250593, 15.669219630105154, 14.621752636773245, 19.86212570326669, 32.86438526426043, 36.73469516209194, 42.41320078713553, 45.21127162660871, 48.24372604915074, 50.24182994025094, 61.56884929112026, 41.50271231787545, 30.211910452161515, 24.03993160384042, 26.468036924089702, 33.020177773066926, 45.89727422169277, 29.68190881184169, 30.881772381918772, 62.86882945469448, 56.79939385822841, 39.59160682133266, 13.476596576826912, 0.5519976285951478, 0.28674640187195366, 0.07699514632778508, 0.03885775990784168, 0.07946220466068812, 0.03823013537164245, 0.01817008214337485, 0.04740891605615616, 0.047841020726731846, 0.034354132999266894, 0.016500134519966583, 0.05393075038279806, 0.014377039158716798, 0.018063031369820237, 0.01892624156815665, 0.03344630403444171, 0.11235672062528984, 0.041127106707010946, 0.053778772109321187, 0.04022059410012194, 0.03965675185567566, 0.05022231562595282, 0.035803432908973525, 0.06594217049756221, 0.10998717455991677, 0.07252771926245519, 0.021344905087192143, 0.07360201661608048, 0.05177519729893122, 0.059805940836668015, 0.10882198744054351, 0.030951673431055884, 0.009149031164789838, 0.0824832393388663, 0.08096322590219122, 0.09119059424847364, 0.0977477463228362, 0.010461476498416491, 0.03426784370094538, 0.07626129034906626, 0.12268401682376862, 0.051854972661073716, 0.07433880386607987, 0.04663764226383396, 0.04900185165128537, 0.05301994943459119, 0.05840093908565385, 0.040618405610855134, 0.05136825270684702, 0.094662562943995, 0.0829507296106645, 0.025845687237701247, 0.02972571671541248, 0.04375451982819608, 0.02209264219605497, 0.026437045773491263, 0.05096725208152618, 0.03618857277823346, 0.03409530920907855, 0.04614339057090027, 0.036779854978833876, 0.03003394464030862, 0.07527176237532071, 0.008404220238194933, 0.05318402259477547, 0.023251235651384507, 0.049548438750207424, 0.06019716377237013, 0.042316480207123926, 0.010912329939726208, 0.018626371498352716, 0.025907145547015325, 0.06483112368732691, 0.050039962732366154, 0.0427207785126354, 0.008757046573529286, 0.0410629715770483, 0.0621014315901058, 0.028798342549375126, 0.03646958127085652, 0.027240702649578452, 0.010868952892321562, 0.03153961384668946, 0.05084422350461994, 0.07068734230207545, 0.038930220662483146, 0.018863660283386707, 0.023235069554565207, 0.03687914161543761, 0.050392488815954754, 0.012141769236352826, 0.04309583535151822, 0.03834624628403357, 0.0652752723544836, 0.017130293384460465, 0.061425135737018924, 0.05080153686659677, 0.024006898049265146, 0.009448249840975871, 0.05761902925691434, 0.014956767604287182, 0.04022627683090312, 0.03581136837601662, 0.05823838923658643, 0.05035715410485864, 0.07274827707026686, 0.09207119021032538, 0.04808647059170263, 0.1382244365023715, 0.10327382372426135, 0.08930758493287222, 0.4114648295300347, 1.6251897300992693, 24.9946905204228, 57.24038907459804, 69.47467640468052, 66.86254283360073, 56.98741906029837, 42.72326414925711, 30.47953769138881, 17.33934596606663, 10.057086672101702, 18.422634397234233, 38.30746855054583, 34.46531275340489, 36.73577560697283, 46.461627755846294, 52.95125218800136, 65.68437848772321, 75.14524718693325, 64.65794195447648, 61.40686593736921, 57.70909718104771, 47.18338925497872, 51.149031911577495, 35.30724334716797, 27.35698597771781, 22.238003151757376, 12.936369793755667, 6.844465460096087, 0.8271726199558803, 1.2453478894063403, 2.4870316897119795, 2.88716259598732, 1.3454041204282214, 1.5730439339365279, 1.7617390943425042, 1.0174249368054527, 1.5464454697711127, 1.691502794623375, 1.753697965826307, 2.886626499039786, 2.78828495315143, 3.068406573363713, 5.37696943964277, 8.971058913639613, 10.586711372647967, 17.986457756587438, 23.92134322438921, 32.27263150896345, 41.36637823922293, 55.27376052311489, 64.76199122837612, 70.5478048324585, 73.93639264787946, 61.787453515189036, 46.440338475363596, 41.93171494347708, 37.00205142157418, 19.604443073272705, 28.61662663732256, 35.90460082462856, 54.0606814793178, 72.19368716648647, 55.193665163857595, 23.049707344600133, 1.260841178042548, 0.24183902729834827, 0.2208765157099281, 0.009127134839738054, 0.04233603558636137, 0.03407379286363721, 0.01829158571282668, 0.0943421654935394, 0.06318294855632953, 0.07266090890126568, 0.04702029869492565, 0.026826650403173904, 0.014842911124495524, 0.06809675666902747, 0.010990813540826951, 0.03195035144952791, 0.006591757784398007, 0.05693452313010182, 0.018557932760034288, 0.0307878038313772, 0.031955637237323184, 0.05943565749164138, 0.020697976229712367, 0.031622941339654584, 0.030960144940763712, 0.051452014462224076, 0.036850181740841696, 0.016571282309346964, 0.04303901143638151, 0.05017259597246136, 0.05944491270929575, 0.03833573577659471, 0.03666366942759071, 0.058764864557555745, 0.03259789098852447, 0.02534164089177336, 0.04365417128428817, 0.01980924972199968, 0.04466306804014104, 0.14308026379772595, 0.02607501850330404, 0.02755996355387781, 0.07139847414301974, 0.10152755957096815, 0.03838897363415786, 0.041159978335989375, 0.02759261296263763, 0.04563521194670882, 0.0711047634748476, 0.02261170112927045, 0.07345708832144737, 0.0448919616506568, 0.02327836857044271, 0.13083229959011078, 0.1399517288165433, 0.1424559030149664, 0.1722825246730021, 0.09577619497265134, 0.0691127475085003, 0.14807930269411632, 0.11484863369592599, 0.11736544221639633, 0.15093432020928177, 0.11547817848622799, 0.1748527746115412, 0.10677530869309391, 0.14918190852871963, 0.15267720525818212, 0.10423773021570273, 0.10101548954844475, 0.09241314471832343, 0.2035025722746338, 0.12890382164290973, 0.11967250199190207, 0.2212001226310219, 0.17642381388161862, 0.1223952051784311, 0.24828858407480375, 0.13828353690249579, 0.24213885835238866, 0.17366548760661057, 0.1141480870012726, 0.09841359952198607, 0.18710365651973657, 0.15100049094430038, 0.14340096658893994, 0.11169707602156059, 0.09003176500222512, 0.11490991897881031, 0.13269643884684357, 0.1306980310806206, 0.14323182137949125, 0.13129444979131222, 0.16106995062104293, 0.10499956897859063, 0.1391184606722423, 0.13380162311451776, 0.13823147969586508, 0.10370716332857098, 0.1393047185348613, 0.06724457096840654, 0.116389057465962, 0.10073878296783992, 0.105610352275627, 0.15803551487624645, 0.21324709510164602, 0.22426205261477403, 0.07676639181694814, 0.6193780015621866, 0.18041910949562276, 0.18774973042309284, 0.5306093362825257, 0.9561996906995773, 24.70973273686, 69.71145016806466, 85.54859038761684, 76.83067866734096, 72.20804909297398, 69.74267537253243, 70.317152432033, 48.43366200583321, 35.5782995223999, 42.71511043821062, 40.399366174425396, 25.71761063167027, 19.705681800842285, 26.624465193067277, 32.50119597571236, 56.23965392793928, 68.5113364628383, 71.32259845733643, 66.8484171458653, 70.96102115086147, 51.689080647059846, 60.75612545013428, 60.81101621900286, 42.017872606004985, 40.62300089427403, 36.22490930557251, 29.482186317443848, 20.62376117706299, 15.538272142410278, 11.541413835116796, 8.811557803835187, 6.6143224494797845, 5.3536747353417535, 5.445549896785191, 4.008319795131683, 6.597064861229487, 6.385579066617148, 9.160075971058436, 11.311323370252337, 11.37102837221963, 11.137923257691519, 21.17032732282366, 21.563581466674805, 27.691786663872854, 42.582618713378906, 46.25732639857701, 54.396783215659006, 59.441769463675364, 63.10356044769287, 66.30872276851109, 76.20484747205461, 55.93616008758545, 42.481755188533235, 33.71487603868757, 38.63610097340175, 51.11607313156128, 63.463094983782085, 46.410787786756245, 45.190982886723106, 79.00180312565395, 76.67360768999372, 61.11005973815918, 26.605130093438284, 1.0905907707554954, 0.6441173883421081, 0.2994125064994608, 0.15082670455532415, 0.18359006648617132, 0.2170256802013942, 0.0817397820896336, 0.2674869996096407, 0.14639652227716787, 0.22551012278667518, 0.128622351746474, 0.1152737494558096, 0.11997879269931998, 0.12910503441733973, 0.11221314940069403, 0.10268178834979023, 0.18375028217477457, 0.13745154440402985, 0.1096467331850103, 0.20606442194964203, 0.12342617128576551, 0.11456431395241193, 0.135719448061926, 0.17462923803499766, 0.15169024893215724, 0.1514905017933675, 0.10076432981129203, 0.14818059440170014, 0.1301762240805796, 0.24904580201421464, 0.15260555196021283, 0.06904287875763007, 0.16037454722183092, 0.15187361623559678, 0.15853133398507321, 0.19603146745690278, 0.1758114495979888, 0.11220737506768533, 0.11569320623363767, 0.3619867887880121, 0.2545015492609569, 0.08762024476059846, 0.14652832091919013, 0.1942176212157522, 0.11718409694731236, 0.11667147731142384, 0.13423683547547885, 0.17121406272053719, 0.15258245462817804, 0.15908123233488627, 0.17702414095401764, 0.10848660115152597, 0.20990602938192232], [0.07950168182807309, 0.10437906227473702, 0.11849858212683882, 0.058830865658819675, 0.04091444704681635, 0.00879037197280143, 0.025854284276387522, 0.09611135734511272, 0.021839809870081286, 0.03538311778434685, 0.004974886442401579, 0.01885310227849654, 0.038994929154536555, 0.01940263930841216, 0.03698922035151294, 0.04217331949621439, 0.027102066070905755, 0.048711611689733605, 0.06108373084238597, 0.013014447542705705, 0.07777718507817813, 0.055514569859951735, 0.05662726890295744, 0.08529828435608319, 0.07268611647720848, 0.024950847129470537, 0.0400714113909219, 0.04629186760368092, 0.034112527035176754, 0.07588925638369151, 0.09517926057534558, 0.03855096708450999, 0.13512902760079928, 0.09858384395816497, 0.07967487110623292, 0.026103644199403267, 0.03921964977468763, 0.05127711866849235, 0.03980419412255287, 0.04023771353864244, 0.014060258299910595, 0.05044966217662607, 0.03763266493167196, 0.06339605604963643, 0.13769804260560445, 0.039176260852920156, 0.10674180263387305, 0.02556347773809518, 0.02417549873436136, 0.10495857189276389, 0.0775635347568563, 0.043566297606698105, 0.025741766206920147, 0.14356262077178272, 0.04443776048719883, 0.034444459580949376, 0.10946330481341907, 0.20571709344429628, 0.03561408771201968, 0.02171860315970012, 0.6858447406973157, 0.2209537737071514, 8.16288353715624, 31.465476649148123, 48.84201111112322, 58.10972683770316, 58.370968682425364, 62.2778434753418, 61.14744104657854, 55.8126871245248, 50.4931184904916, 48.86144869668143, 49.806980405535015, 38.55375439780099, 34.12693895612444, 26.44288965633937, 17.039261954171316, 23.428017650331768, 22.23333396230425, 30.154879638126918, 28.996974502290996, 16.723273515701294, 19.652170249394008, 46.396689891815186, 26.69849477495466, 23.063923358917236, 27.447336878095353, 30.816817147391184, 29.364063467298234, 37.97469847542899, 30.968725613185338, 30.764802932739258, 33.12738152912685, 39.05449717385428, 57.839591298784526, 50.50723375592913, 52.016146251133506, 43.255228655678884, 34.25571339470999, 47.68140833718436, 64.22381850651333, 42.54793330601284, 52.588924476078574, 56.47585446493966, 28.806104012898036, 36.68069723674229, 34.912936551230295, 42.39161273411342, 28.216419083731516, 30.10527297428676, 40.03854274749756, 38.43413421085903, 37.06496735981533, 50.19287640707833, 52.64398200171334, 55.53902884892055, 68.80291761670793, 76.47105380467006, 69.28290612357003, 44.035879611968994, 13.572381837027413, 1.0022344376359666, 0.2421165481209755, 0.1244995186903647, 0.08264551098857607, 0.026635330669315796, 0.12390449776181153, 0.1398865623133523, 0.09624726112399783, 0.057033012488058636, 0.051577360236219, 0.0751326559111476, 0.07105582752930266, 0.06658993395311491, 0.18949713451521738, 0.10307345233325448, 0.11744888845298972, 0.07684103066899947, 0.057942907592015605, 0.03148362792230078, 0.08188745166574206, 0.06682440172880888, 0.04718509449490479, 0.06300455491457667, 0.024787908819104944, 0.04039769173998918, 0.021685354943786348, 0.015006851970351167, 0.015205722102629287, 0.06729109132928507, 0.06876900166805301, 0.09135638070958, 0.047250640977706225, 0.10785470863005944, 0.11633028276264668, 0.03694459988868662, 0.0906598170154861, 0.07935210556856223, 0.04829786478408745, 0.03930268549759473, 0.08160876376288277, 0.056423755894814215, 0.07315362031970706, 0.07443912526858704, 0.0718826020934752, 0.024813531997746656, 0.05532980138169868, 0.1291227713227272, 0.08629545263413872, 0.06737600998686892, 0.10102108067699841, 0.059292025198893886, 0.07874052838555404, 0.09925817205969777, 0.1065665709653071, 0.05941517251942839, 0.04820911579632333, 0.03381995291316083, 0.01701234364216881, 0.03896215930581093, 0.04494711976232273, 0.027476593652474027, 0.04157078379232969, 0.02985205315053463, 0.0181347643956542, 0.022982188034802675, 0.018039708424891745, 0.02784013744842793, 0.0502864371852151, 0.04697323889870729, 0.03213909953566534, 0.05666262736277921, 0.07170213213456528, 0.03923981583544186, 0.06615087429859809, 0.05317672495064991, 0.052691182254680564, 0.06584159125174795, 0.03779949972938214, 0.06195914279669523, 0.05240152244056974, 0.04968840016850403, 0.03537382524726646, 0.015022237751899021, 0.032922050915658474, 0.09095058284167733, 0.13816043707941258, 0.07537368512047188, 0.07744715243045773, 0.06724339710282427, 0.10816638012017522, 0.06986646420721497, 0.02228483384741204, 0.1463699508458376, 0.01695161815067487, 0.06186253298074007, 0.05588304490915366, 0.0721295006307108, 0.020543612905644944, 0.05080366746655532, 0.07691157116953816, 0.09475392089890582, 0.06538360725556101, 0.051207989520792446, 0.03790788891326104, 0.07566229320530381, 0.047037957568785975, 0.05027752462774515, 0.08039613347500563, 0.10694316468600716, 0.04041252790817192, 0.01813235050732536, 0.11507439586733069, 0.12485975293176514, 0.07647059126091854, 0.11106071195432118, 0.6381616422108242, 2.3361415692738126, 20.699355840682983, 49.464788573128835, 66.02006680624825, 68.64341476985386, 62.98649719783238, 52.32912785666329, 46.35957956314087, 44.42023311342512, 34.846546513693674, 20.378903184618267, 9.748931459018163, 10.632559929575239, 16.403077942984446, 29.267796175820486, 29.154912267412456, 35.25055646896362, 36.03037364142281, 46.76908901759556, 40.411303179604666, 37.43204416547503, 47.299309526171, 48.4127687726702, 52.920204162597656, 54.77234724589756, 58.2677184513637, 60.12272766658238, 51.26581375939505, 55.645937306540354, 53.509727546146934, 49.61322293962751, 47.24009002958025, 52.2145277432033, 50.33791657856533, 55.68628896985735, 56.886072635650635, 59.39948967524937, 59.699651854378835, 54.81068740572248, 55.264470781598774, 65.70675863538469, 64.4936101096017, 68.13231222970145, 61.664352280753, 61.85255813598633, 58.547473771231516, 59.235401017325266, 44.67266811643328, 39.68813467025757, 49.652584484645296, 28.83642421449934, 20.061094318117412, 22.509576967784337, 35.029377937316895, 48.9673045022147, 63.02126598358154, 66.99660832541329, 72.64117200034005, 58.52655274527413, 21.74391848700387, 3.448007724114827, 0.26723754299538477, 0.07662713607507092, 0.04394847906327673, 0.032233765348792076, 0.03460155740114195, 0.11438371507184845, 0.09644566476345062, 0.07529102598450013, 0.08560481933610779, 0.040579718936766894, 0.02990249205114586, 0.038481756512607844, 0.09123411548456975, 0.10584418901375361, 0.12548548435526236, 0.012010545652758862, 0.05465432655598436, 0.02319965002659176, 0.019251962125833546, 0.05647446620943291, 0.029744749622685567, 0.07115544325539044, 0.0880180359152811, 0.04779653597090926, 0.06689711354140725, 0.07390752700822693, 0.05183275403188808, 0.06427933901016201, 0.024324460919680338, 0.1447012975279774, 0.07450864796659776, 0.04859131760895252, 0.03777603938111237, 0.08273955594216074, 0.03405601863882371, 0.12314402285431113, 0.1034924816340208, 0.07209668667720896, 0.06836217242692198, 0.026789269908996563, 0.03333502768405846, 0.07053838350943156, 0.06848613398947886, 0.01710485341027379, 0.01866286650433072, 0.06259696571422474, 0.06688521882253033, 0.05795787607452699, 0.0813758634030819, 0.06472081424934523, 0.07546261392001595, 0.06720261714820351, 0.08047784944730145, 0.10897544492036104, 0.14196863344737462, 0.1358643967126097, 0.22166732113276208, 0.19094417829598698, 0.12545029552919523, 0.1326762456446886, 0.08749010852937188, 0.17156297899782658, 0.08362389063196522, 0.12708314933947154, 0.09077350555786065, 0.07515928841062955, 0.1344816509102072, 0.24450775980949402, 0.10984538788241999, 0.15904726487185272, 0.17961546619023594, 0.16698194481432438, 0.26200801932385986, 0.1108420676152621, 0.16308268904685974, 0.125545290431806, 0.1072801116055676, 0.1702638151390212, 0.1689807189894574, 0.10388907178172044, 0.17640389209347113, 0.14876636011259897, 0.18825985305011272, 0.12488997488149575, 0.2197068299033812, 0.1421753287847553, 0.2466115712055138, 0.09799087899071829, 0.21593911493463175, 0.20625750587454864, 0.15169716998934746, 0.163990229634302, 0.07594653152461563, 0.11360234807112388, 0.10605888427900416, 0.21066446868436678, 0.1188235596886703, 0.17850330658257008, 0.3022927519466196, 0.15994542810533727, 0.16818786439086708, 0.2546204285962241, 0.08808198105543852, 0.2024323868432215, 0.2166868198130812, 0.1834622033472572, 0.13581284162189278, 0.267788432006325, 0.14323357199983938, 0.18905730811612947, 0.22098710334726743, 0.24550232929842813, 0.17341007345489093, 0.1389522467340742, 0.8852946811488697, 1.3789613140480859, 19.705747808728898, 59.56277929033552, 81.88072667803083, 84.26056112561906, 76.763003213065, 79.46442113603864, 76.27431556156704, 72.77263191768101, 64.07712118966239, 64.85096985953194, 66.83923162732805, 52.669103213718955, 48.53522382463728, 40.62603725705828, 24.59204067502703, 34.93513951982771, 34.37796694891793, 40.3225017275129, 36.0100223677499, 25.56971996171134, 28.351622343063354, 57.9806501524789, 37.900967666081016, 35.06276055744716, 43.675077029636924, 49.32891654968262, 47.69162218911307, 55.8991505077907, 50.40799958365304, 48.526903356824604, 52.20656163351876, 57.75545903614589, 77.54129178183419, 67.35193225315639, 71.73728779384068, 63.202204023088726, 51.67883552823748, 63.91680540357317, 84.94958618709019, 59.37366322108677, 68.09999615805489, 74.37490735735211, 44.93866947719029, 54.35708815710885, 52.099625383104595, 58.75762898581368, 43.06655379704067, 41.37416022164481, 54.87667097364153, 50.64853579657418, 52.73354428155081, 69.06054987226213, 73.27582740783691, 74.37073148999895, 90.70318794250488, 98.92528315952846, 94.03741305215019, 67.366377558027, 29.548180307660783, 4.870110946042197, 0.5206497992788042, 0.17656341567635536, 0.23621997024331773, 0.10682850583855595, 0.2398472556046077, 0.1766319748546396, 0.16985959825771196, 0.32469254998224123, 0.18748772091099195, 0.21801630061651978, 0.13454613887837955, 0.24660144746303558, 0.30339436712009565, 0.15740601079804556, 0.28692564368247986, 0.10385607462376356, 0.07206322133008923, 0.08003899335329022, 0.16164442550923142, 0.18141513104949678, 0.1805093139410019, 0.12979958286242826, 0.1799192734594856, 0.15395514454160417, 0.0979416784165161, 0.10464745680136339, 0.12956356124154159, 0.14635209180414677, 0.1539813902761255, 0.24584485377584184, 0.13545688215110982, 0.2350265085697174, 0.17360554582306317, 0.10033956688961812, 0.21847000984208925, 0.2600645050406456, 0.1965106488870723, 0.12384095974266529, 0.14673911460808345, 0.04828052821436098, 0.12180458115679876, 0.09705730301461049, 0.1493529672069209, 0.10592074811990772, 0.1173795150326831, 0.20855813313807758, 0.1742890884301492, 0.14932673504309996, 0.13976125046610832, 0.09277972326214824, 0.19330704079142638, 0.17465329888675893, 0.21389242261648178, 0.2278038832758154], [0.1895769845162119, 0.12377865665725299, 0.11180188254054103, 0.0831296050122806, 0.09468777051993779, 0.1189475551779781, 0.052917341369071176, 0.08914379336472068, 0.1398097657199417, 0.08009493178022759, 0.02730560113143708, 0.13901996452893528, 0.06921674657080855, 0.11377413278179509, 0.11020786128938198, 0.07489554863423109, 0.026012718810566833, 0.11999638032700334, 0.047845600838107724, 0.05130632960104516, 0.04414497262665203, 0.08579115862292902, 0.03010121120938233, 0.12454422057739326, 0.05076334552307214, 0.08316813223063946, 0.17723542318812438, 0.12225924033139433, 0.07840019557625055, 0.055030099249311855, 0.12497044913470745, 0.04683401029823082, 0.1311879197933844, 0.04293456454096096, 0.10933262575417757, 0.037061104351388555, 0.12778297678700515, 0.102231180029256, 0.039276290485369306, 0.10082801710814238, 0.08808015579623835, 0.006017103084429566, 0.14291689970663615, 0.05415696717266526, 0.13374511471816472, 0.10834203926580292, 0.030200392673058168, 0.023133419919759035, 0.0438315742649138, 0.05659649055451155, 0.10922580398619175, 0.14453891052731446, 0.07878425996750593, 0.14837985299527645, 0.09743975249252149, 0.08519191720655986, 0.036811325432998795, 0.07042215046073709, 0.15138028056493827, 0.14420161076954432, 0.0816397253157837, 0.06090775957064969, 0.37747326493263245, 0.5469252264925412, 4.378245362213679, 18.34666105679103, 38.4501428604126, 47.919564792088096, 52.44443668637957, 57.00717626299177, 61.14452280317034, 68.99860668182373, 63.62152085985456, 68.60196876525879, 65.42020797729492, 56.13651486805507, 60.12207453591483, 46.874378544943674, 45.52356536047799, 37.66672304698399, 54.45759384972708, 63.18837710789272, 26.96640167917524, 78.97614342825753, 44.41096421650478, 29.741103989737375, 51.09681967326573, 16.05742243358067, 21.742092847824097, 19.7418714932033, 22.24492355755397, 27.43430553163801, 24.376379013061523, 26.782303946358816, 31.576811109270366, 23.753394842147827, 36.62408331462315, 23.39904366220747, 20.210444109780447, 43.62227419444493, 89.27863352639335, 28.33365603855678, 58.64169134412493, 43.617625849587576, 38.515257903507774, 33.835385595049175, 43.48145505360195, 51.514437675476074, 62.2525520324707, 68.02341311318534, 64.74444702693394, 72.02555465698242, 72.92148317609514, 64.85989134652274, 59.44305488041469, 41.870848723820274, 32.25621291569301, 21.545670747756958, 8.819355419703893, 0.7205508298107556, 0.4408532939851284, 0.9464767724275589, 0.024742016103118658, 0.11234114824661187, 0.22427182351904257, 0.18801133281418256, 0.1160198122795139, 0.05829421231257064, 0.09924879470574004, 0.10301450799618449, 0.11644810358328478, 0.24890398819531712, 0.089232695022864, 0.049390360446912904, 0.07639602026236908, 0.1723284072109631, 0.10189911177647965, 0.1025077509028571, 0.09255355396973235, 0.18406631664506026, 0.061873599886894226, 0.1046942417908992, 0.11754616323326315, 0.018418885667675307, 0.07091716889824186, 0.038059042766690254, 0.06924611356641565, 0.12485194977905069, 0.10934055782854557, 0.06971627048083714, 0.13145809886710985, 0.08815554782216038, 0.13975160169814313, 0.08476298807987145, 0.10371765347995929, 0.08891245363546268, 0.08017281402966805, 0.1975124922714063, 0.10274846120072262, 0.13372717425227165, 0.19377695343324117, 0.13010269802595886, 0.09821482268827302, 0.15422696567007474, 0.14358696660825185, 0.09657808087233986, 0.1971921016063009, 0.09358453364776713, 0.15246217751077243, 0.09875296202621289, 0.14766773049320492, 0.08375648315995932, 0.07405023649334908, 0.1691166702657938, 0.0696102629548737, 0.25355393439531326, 0.12680758269769804, 0.04793497747076409, 0.15715023023741587, 0.04020101497215884, 0.12123884579965047, 0.1601405476352998, 0.10855047165283135, 0.038676601235887835, 0.106646543102605, 0.09915538078972272, 0.0621389342205865, 0.0637425228155085, 0.09342119669807808, 0.09123059388782297, 0.07608055576149907, 0.02808392490260303, 0.028292632096314003, 0.05355770540024553, 0.055395626063857756, 0.050009465975953, 0.04859247451115932, 0.03655409620010427, 0.04097423615998455, 0.06553987387035574, 0.05885774243090834, 0.05995200228478227, 0.18841872523937905, 0.09787403526050703, 0.0865319153027875, 0.11129520687141589, 0.2036900243588856, 0.03510683189545359, 0.07700879845236029, 0.05962017151926245, 0.1393195241689682, 0.01730376255831548, 0.1504167608384575, 0.08502540471298353, 0.09434654882975987, 0.10869930830917188, 0.005258670991419682, 0.00559167647069054, 0.10068272918994937, 0.08958523467715297, 0.06861673162451812, 0.10001720847295863, 0.032115679899496694, 0.061505019664764404, 0.08452277311256953, 0.0676737715091024, 0.17743765376508236, 0.13465534230428083, 0.10746391995676927, 0.20437884596841677, 0.05134708919961538, 0.08667952381074429, 0.053593301347323825, 0.06787686382553407, 0.18364053592085838, 0.10162309051624366, 0.2272341852741582, 0.08420877424733979, 0.2869708069733211, 1.2717376904828208, 13.685603601591927, 33.418132373264854, 53.84980365208217, 64.84666197640556, 66.26725591932023, 63.962941442217144, 66.70060811723981, 68.63260337284633, 59.78225898742676, 56.140468393053325, 51.682493754795615, 42.244755608694895, 27.372435297284806, 31.46393414906093, 23.780942712511333, 24.864717517580303, 32.17249059677124, 23.85777415548052, 13.212458201817103, 75.40927873338971, 27.437260253088816, 19.603428636278423, 35.60594293049404, 24.413088083267212, 30.121906961713517, 33.77738550731114, 31.415088312966482, 34.09425115585327, 36.023550510406494, 39.25264590127127, 56.19696419579642, 43.80361522947039, 53.44618279593331, 35.55035039356777, 25.512562343052455, 49.50937863758632, 93.93972832815987, 29.68143286023821, 56.426477091653005, 48.43665320532662, 20.77893008504595, 26.5048154762813, 33.098021915980745, 41.420542921338765, 34.91456937789917, 41.350647517613, 55.786964893341064, 60.72326047079903, 68.40911456516811, 78.23412445613316, 72.802001953125, 66.20732075827462, 53.810890265873496, 40.76464687074934, 18.7739839553833, 2.3839395301682607, 0.3866770224911826, 0.9405097897563661, 0.05139209642740233, 0.10265337808855943, 0.1875837200454303, 0.1390328566942896, 0.018780499031501155, 0.07956099257405315, 0.10170467756688595, 0.20679151293422493, 0.08551381421940667, 0.17042183237416403, 0.12786343746951648, 0.06422730215958186, 0.06440249990139689, 0.06716960641954627, 0.0669811297474163, 0.11896455926554543, 0.14842764900199004, 0.09703221757497106, 0.040558735241315196, 0.031141615738826137, 0.037646524009427855, 0.016948839549773505, 0.07060517171131712, 0.07626821140625648, 0.022651600684704523, 0.17052258125373296, 0.06406755466014147, 0.08698972966521978, 0.12763802813632147, 0.11138594057410955, 0.07463480798261506, 0.06521182933023997, 0.09495782745735985, 0.11829887570015021, 0.09522154009235756, 0.20179231118943008, 0.12055933369057519, 0.12509364395269326, 0.18473240733146667, 0.13322665968111583, 0.058762788240398676, 0.09475325593458754, 0.06513319390692882, 0.04259262021098818, 0.008670203420998794, 0.042005205659994056, 0.15485165214964322, 0.04710263213408845, 0.08245427946427039, 0.12610318192413875, 0.029520408982144933, 0.2106904158634799, 0.05121926338012729, 0.12960994589541638, 0.3011145165988377, 0.1531304530799389, 0.2150026551846947, 0.10070594865828753, 0.20261166936584882, 0.23939583982740129, 0.20373917743563652, 0.1738386226019689, 0.244427746960095, 0.21464725211262703, 0.11212453951260873, 0.21802189174507344, 0.1454360152461699, 0.32361072088990894, 0.15242807434073516, 0.11572368602667536, 0.12175077332981996, 0.22524218287851128, 0.10944665356406144, 0.13396238163113594, 0.13738838636449405, 0.1702655250472682, 0.08641712074833256, 0.2073336217020239, 0.12817314799342835, 0.1339907715363162, 0.3064998319106442, 0.2138612371470247, 0.28775907467518536, 0.1713225468993187, 0.23642572920237268, 0.07686794136783906, 0.2349136003426143, 0.2936690061220101, 0.19524898087339743, 0.1587953112487282, 0.2478005274065903, 0.2261369534369026, 0.2098288256675005, 0.1628535206296614, 0.16442701619650635, 0.1404403554541724, 0.23557921605450766, 0.11100016627460718, 0.2150176236672061, 0.17182340073798383, 0.23316167720726558, 0.16323169533695492, 0.16838081260876997, 0.18687560089996882, 0.29894716718367165, 0.2088172792323998, 0.1683500071189233, 0.35157936438918114, 0.14946656753974302, 0.2955668142863682, 0.23605856033308165, 0.23538176236408098, 0.36140943691134453, 0.2624144618000303, 0.41283623022692545, 0.199616154389722, 0.503033673124654, 0.8271521010569164, 10.445421491350446, 30.776840686798096, 59.39377130780901, 74.67365905216762, 79.35338197435651, 78.7491318838937, 81.06915623801095, 87.54819856371198, 79.89324310847691, 82.69769586835588, 80.93055357251848, 69.5250369480678, 74.69056401933942, 60.06204210008894, 58.7025089263916, 51.4514661516462, 72.6352868761335, 81.3386629649571, 40.02287803377424, 92.43268489837646, 57.38043001719883, 38.821051597595215, 62.590331758771626, 28.699238981519425, 35.23254673821585, 32.36130789348057, 32.342891693115234, 39.599840436662944, 39.34344496045794, 39.16198580605643, 49.6479708807809, 39.56747920172555, 51.762946946280344, 35.126833370753694, 28.810507433755056, 54.21613352639334, 105.42113317762102, 42.66665717533657, 73.7695872443063, 56.44954163687569, 53.61668116705758, 48.70633363723755, 57.909597873687744, 68.99805082593645, 74.68675640651158, 81.36462838309151, 80.1165999003819, 96.11876678466797, 97.52643013000488, 89.57636383601597, 87.51115771702358, 75.09267711639404, 62.604110036577495, 41.566809449877056, 19.147421836853027, 3.4195487712110793, 0.6943691489951951, 1.285690650343895, 0.24540025049022265, 0.2227969869439091, 0.6545921776975904, 0.2366313524544239, 0.24333240145019122, 0.21774407236703805, 0.23743517217891558, 0.22377892211079597, 0.32186900292124065, 0.4097007199057511, 0.2354203574359417, 0.16270375438034534, 0.2837928203599793, 0.18386259329106125, 0.19638697909457342, 0.2974413622702871, 0.2296446402158056, 0.30518846799220356, 0.18210563542587416, 0.18096898070403508, 0.14293684863618442, 0.09053052216768265, 0.13474751450121403, 0.15549935453704425, 0.1613451779953071, 0.4393370124910559, 0.20253749191761017, 0.14127612060734204, 0.26559546110885485, 0.15081274030464037, 0.11676987845982824, 0.18425554649106093, 0.22853656538895198, 0.19408465549349785, 0.23493886898670877, 0.28765417316130226, 0.2750196339828627, 0.1802556232682296, 0.24048733125839913, 0.24442505996142114, 0.17550807659115109, 0.20419561437198094, 0.2125355832810913, 0.12729407873536858, 0.25899092693414005, 0.13737590132015093, 0.4058102715228285, 0.09075261346463646, 0.193779748997518, 0.14765377981322153, 0.09913365409842559, 0.3477033552314554, 0.23283497616648674, 0.34246137365698814], [0.012660647509619594, 0.14355704321392945, 0.15606445207127503, 0.09746716530727488, 0.09139021925096001, 0.11319129834217684, 0.06837562777634178, 0.06627582652228219, 0.1445274975683008, 0.16205538702862604, 0.07038376573473215, 0.17192395962774754, 0.23045804085476057, 0.10009756058986698, 0.08137312212160655, 0.0832400026598147, 0.02946677418159587, 0.023714223843333975, 0.015645217715895603, 0.042039702380342145, 0.017784073749291043, 0.038346934997077496, 0.08940421510487795, 0.036345148126461675, 0.09335632196494512, 0.09731336855994803, 0.11864256725779601, 0.23420708253979683, 0.122003473341465, 0.08430833569062607, 0.18849189845579012, 0.10723715355353695, 0.08990964905491897, 0.02708829689903983, 0.03263290000281163, 0.042001110701156516, 0.10333202845816102, 0.07819647900760174, 0.06094211379864386, 0.11760330945253372, 0.2060868814587593, 0.0539907701978726, 0.14800112188926765, 0.1600795066250222, 0.10740111475544316, 0.08817152732184955, 0.07217360540692296, 0.066344697826675, 0.07033732001270566, 0.08588933585477726, 0.16126241029373237, 0.08911875542253256, 0.08642334291445357, 0.1794438511133194, 0.09190414845943451, 0.060823349814329825, 0.15630221074180944, 0.1947798010494028, 0.02439518123199897, 0.05259243844609175, 0.49135320846523556, 0.19649797385292395, 0.03549229067617229, 0.17982878402939864, 0.42937218291418894, 0.8438429768596376, 0.18030033872595855, 1.3123507797718048, 6.563102500779288, 19.594781603131974, 25.846447604043142, 37.33611386162894, 43.64746141433716, 43.4320707321167, 57.87368958336966, 63.7532309123448, 67.87493010929653, 65.31212874821254, 65.87528024400983, 65.729583467756, 57.349809306008474, 52.218050479888916, 63.39884499141148, 37.570900440216064, 55.568916525159565, 55.87987273080008, 64.52409880501884, 68.26176411764962, 63.6652250289917, 64.99149022783551, 70.20106887817383, 67.76713575635637, 60.09389959062849, 64.02865055629185, 53.006142956869944, 56.24637631007603, 58.747574942452566, 60.423397064208984, 67.45843424115861, 53.169526372637065, 47.21910299573626, 70.0505292075021, 60.298405919756206, 69.45365810394287, 84.89084611620221, 78.06782627105713, 76.60500117710659, 74.65124416351318, 63.54136644090925, 48.3069303376334, 25.710467883518763, 25.513936349323817, 17.179233414786204, 13.700621264321462, 11.211632353918892, 2.6826892708029066, 0.8452860851372991, 0.047333893831819296, 0.32879738828965593, 0.38678015981401714, 0.014531348199982728, 0.05014456908351608, 0.19163053003805025, 0.17052513254540308, 0.0506935344476785, 0.16694909014872142, 0.14902260207704135, 0.1389339670006718, 0.06660197794969593, 0.19829090764479979, 0.10433908977678844, 0.06884012570870773, 0.1683065401656287, 0.07874158690018312, 0.039733595946537595, 0.06167773396841117, 0.020300298729645352, 0.04777741824675884, 0.08770397598189966, 0.10862449982336589, 0.03868587002424257, 0.17143217101693153, 0.07883825099893979, 0.11968723977250711, 0.12009847270590918, 0.11951770101274763, 0.12436815431075436, 0.047784899095339436, 0.0869177778118423, 0.09900454924042736, 0.15693851374089718, 0.07252866242613111, 0.03693393671086856, 0.04040152207016945, 0.09504834402884756, 0.08001181124044315, 0.03171463516939964, 0.14588504258011067, 0.08403459430805274, 0.11227038382951703, 0.13500793624137128, 0.15331250402544225, 0.16187302395701408, 0.18932960421911307, 0.08035214404974665, 0.16505170267607483, 0.22581217943557672, 0.10639625867562634, 0.08295950985380582, 0.1391100332673107, 0.22187518355037483, 0.1110960432727422, 0.18649859327290738, 0.11950699373015336, 0.1015814963196005, 0.07128464989364147, 0.17003466029252323, 0.061939967397068224, 0.12340215114610535, 0.03881650837138295, 0.10521017946302891, 0.09620544301079852, 0.0867826339921781, 0.10523863722171102, 0.08657606757645096, 0.12492820354444639, 0.15472513251006603, 0.1255027869982379, 0.13663924299180508, 0.07894947645919663, 0.07482878757374627, 0.030448661851031438, 0.009088411694392562, 0.02249130866091166, 0.026520614146388004, 0.019124774129262993, 0.01543506863527, 0.07682357196296964, 0.0690719811245799, 0.06690744084439107, 0.09302559042615549, 0.03141955386048981, 0.15801336749323777, 0.09899065962859563, 0.09415721041815621, 0.07799374631472997, 0.1474601530603, 0.07084814831614494, 0.053804963561041017, 0.025327189792213694, 0.019499949711774076, 0.06526145738150392, 0.11879214351730687, 0.03003633308357426, 0.07893830777278968, 0.015605871166501726, 0.08388994421277728, 0.15880486502179078, 0.14386261467422756, 0.07605015739266362, 0.10875837478254523, 0.027925346179732254, 0.038729330192187, 0.08470820994781596, 0.07685392283435379, 0.012600986469936157, 0.029577178614480153, 0.05564860427486045, 0.08818399879549231, 0.1714895072260073, 0.05387197567948273, 0.09011806787124702, 0.11525477761668818, 0.15786445619804518, 0.04316519520112446, 0.05921535074178662, 0.31034899822303225, 0.12121117514158998, 0.10832039399870805, 0.13245558605662414, 0.4064122135085719, 0.38961383061749594, 1.3032124872718538, 5.215070332799639, 15.911357402801514, 34.87440184184483, 42.57107775551932, 55.5273072378976, 60.02622413635254, 62.87497166224888, 70.42168807983398, 71.87460504259381, 73.76509175981793, 66.01361192975725, 62.96263708387102, 57.85470363071987, 53.18761600766863, 50.508199555533274, 40.233196531023296, 47.94154889242989, 41.57623815536499, 36.77336188725063, 53.58897522517613, 31.28614364351545, 34.149614402226035, 31.68583181926182, 33.19745758601597, 37.876311983381, 33.46574143001011, 39.38058655602591, 36.74415166037423, 29.305691650935582, 40.04858636856079, 33.14531135559082, 30.355828489576066, 47.39427750451224, 62.849367550441194, 54.78874152047293, 63.5405604498727, 63.67254148210798, 72.47872311728341, 70.36935424804688, 75.62317902701241, 80.93039376395089, 80.5878962108067, 71.39614513942173, 53.372681277138845, 46.93990005765642, 38.622201102120535, 31.448151315961564, 23.972952706473215, 7.970792770385742, 3.081196904182434, 0.02450409628051732, 0.3785614179713385, 0.5553086623549461, 0.06977917746241603, 0.010916454584470816, 0.2628170773386955, 0.15918093627052649, 0.01736150249572737, 0.10303325591874973, 0.08504287020436355, 0.17696787683027132, 0.10858204388724906, 0.10164419295532362, 0.12042901425489358, 0.054997102091354985, 0.12646570961390222, 0.04075380727382643, 0.02424255495757929, 0.05843167672199862, 0.06531115328626973, 0.07543495004730565, 0.07452203546251569, 0.12042989635041781, 0.13139895775488444, 0.12722979432770185, 0.040844585081296306, 0.14660693598645075, 0.12459076807967254, 0.04731729347258806, 0.06547647834356342, 0.04478559450113347, 0.058083140424319675, 0.09842479534979377, 0.037522939033806324, 0.05448001430236867, 0.04005043787349548, 0.06562410720757075, 0.09110435923295361, 0.13176884076425008, 0.06113785758082356, 0.15542154014110565, 0.07681279004152332, 0.081761664843985, 0.11118871758558921, 0.1031341337199722, 0.05159418451200638, 0.10824088326522283, 0.12494640185364655, 0.16727113643927233, 0.15522483283919947, 0.06864926059331213, 0.04324475343206099, 0.05306793203843491, 0.1998647560498544, 0.1714693954480546, 0.03863387727843864, 0.12779358907469682, 0.06665235917483057, 0.07858620916626283, 0.2245866773383958, 0.17108956511531556, 0.19815312432391302, 0.1762855691569192, 0.19360601689134324, 0.19317019384886536, 0.16086200677922793, 0.2233122800077711, 0.16046141327491828, 0.22251401069973195, 0.19868671069187777, 0.19423830296312058, 0.2468333707324096, 0.15337374859622546, 0.14564389123448304, 0.1437152504388775, 0.16482378276331083, 0.10161896502333027, 0.17169793961303575, 0.1352384210165058, 0.12235309529517378, 0.14859896552349838, 0.11739418495978628, 0.15478670277765819, 0.18251891753503255, 0.14348610916307994, 0.11286015289702586, 0.3875723358775888, 0.2367324541722025, 0.20133538570787224, 0.32827597483992577, 0.1967314306114401, 0.152370615995356, 0.10791766989443984, 0.18379266347203935, 0.22507307838116372, 0.19248920253344945, 0.1480368806847504, 0.1413030991596835, 0.20469245128333569, 0.29570862810526577, 0.3091290736837046, 0.22087030032915728, 0.18127358864460671, 0.19270823363746914, 0.17670821504933493, 0.253590710993324, 0.14035343511828355, 0.17083104327321053, 0.13511433053229535, 0.2240246603531497, 0.15501277707517147, 0.2708005846611091, 0.2128921670040914, 0.16491223658834184, 0.20250370087368147, 0.3605691934270518, 0.25988130058561054, 0.13592585841459887, 0.17759354040026665, 0.4932658629758017, 0.32642965391278267, 0.14756998073841843, 0.407400269061327, 0.5375610632555825, 0.9657626918384007, 0.5224697930472237, 3.0658446422645023, 12.10341887814658, 31.483281408037456, 41.40450300489153, 56.193000248500276, 66.34342207227434, 70.43418094090053, 79.54713249206543, 87.00976875850132, 91.1182107925415, 88.98664937700543, 82.77502931867326, 80.64120279039655, 74.61307076045445, 64.23145457676479, 80.19821344103131, 51.88130603517805, 69.42849867684501, 76.35489382062639, 84.23129531315395, 88.53669793265206, 81.11129011426652, 84.67845358167375, 90.06515571049282, 86.73393222263881, 76.29758507864815, 82.84747123718262, 66.68111147199357, 70.11143016815186, 76.71693665640694, 78.32156753540039, 88.14858545575822, 71.97773715427944, 67.37230437142509, 89.23587431226457, 78.71070834568569, 86.71098927089146, 108.18313939230782, 97.5141248703003, 101.20588343484062, 95.79618276868547, 90.23196111406598, 81.55113887786865, 63.825610297066824, 53.278689520699636, 44.01191874912807, 34.432030882154194, 23.816375051225933, 7.451650295938764, 1.7388294722352708, 0.17021417351705687, 0.3023525987352644, 0.6515105430568967, 0.22684288769960403, 0.21113948390952178, 0.37604980702911106, 0.2901150568255356, 0.12370943251465048, 0.2722441272011825, 0.2764895579644612, 0.1838866677135229, 0.26634828214134487, 0.29460104182362556, 0.2165263055690697, 0.18381445801683835, 0.37065349945000237, 0.2786609243069376, 0.2116787021181413, 0.15055017439382418, 0.26229031703301836, 0.17012970947793551, 0.16660785488784313, 0.19414169314716542, 0.2348211295902729, 0.2880663424730301, 0.15043772757053375, 0.2433114211474146, 0.2321391792169639, 0.1742946252759014, 0.14847866126469203, 0.11640869426940169, 0.19092536930527004, 0.16739537620118686, 0.33245257501091274, 0.11613312762762819, 0.12981805258563586, 0.2911910776581083, 0.23977302387356758, 0.18869454972445965, 0.06731097919068166, 0.15885993492390427, 0.3267435442124094, 0.1437038103384631, 0.1989114143486534, 0.20372756091611727, 0.2145283320652587, 0.1928773924176182, 0.12594606035522052, 0.2421766934650285, 0.29370955537472454, 0.20860815473965236, 0.1460187275494848, 0.253335174705301, 0.3126390810523714, 0.3230817349893706, 0.1698916522519929, 0.21927133255771228, 0.12258417718112469, 0.10885436713163342], [0.03870248395417418, 0.0904199006035924, 0.049205364659428596, 0.030822700887386287, 0.05464875239080616, 0.014809491578489542, 0.040405233656721454, 0.041644167354596515, 0.07206088038427488, 0.08479111335639443, 0.06668593987290349, 0.09154546127787658, 0.04063853095950825, 0.0863505293216024, 0.062498503497668674, 0.05643891775980592, 0.10366952499108655, 0.030263761058449745, 0.06340149111513581, 0.06355304869690112, 0.020767604100650976, 0.06611678469926119, 0.13779562951198646, 0.06615947812263455, 0.09551608535860266, 0.12184620249484267, 0.14359345340303012, 0.1400074636829751, 0.14817602107567446, 0.059064709182296476, 0.10258746519684792, 0.04236328894538539, 0.05092624142499907, 0.06030826709632363, 0.0845641637487071, 0.0671163210645318, 0.08421213978103229, 0.08389969476099525, 0.07134410991732563, 0.10229745254452739, 0.06069684374545302, 0.1589267434818404, 0.10674681700766087, 0.030909549977098192, 0.03427226435659187, 0.06398642901331186, 0.06764306101415839, 0.06917467739965234, 0.016198603735704507, 0.07883498724550009, 0.06441078481397458, 0.08628273010253906, 0.02466378780081868, 0.06875692374472107, 0.044370385352522135, 0.19660801866224834, 0.05814872083387204, 0.06506613429103579, 0.13871705292591027, 0.1496346135224615, 0.055461308253662925, 0.07923747386251177, 0.2170551014798028, 0.11107822494315249, 0.04843243184898581, 0.24202141751136097, 0.04860143795875566, 0.2429425966526781, 0.6045057624578476, 0.746065266430378, 0.25946335015552385, 0.11081650720110961, 0.4218032604881695, 1.0023073937211717, 6.9902582083429605, 11.469033581869942, 17.53223490715027, 30.913925170898438, 37.555183615003315, 33.64253486905779, 48.01082590648106, 59.88493946620396, 54.98999956675938, 63.82236548832485, 58.77927262442452, 59.46170384543282, 58.80165277208601, 64.4347310747419, 66.16901533944267, 73.76745414733887, 71.71172537122453, 65.37906769343785, 67.58189678192139, 68.21531541006905, 68.08534935542515, 70.68763038090297, 59.73351042611258, 63.45861339569092, 55.08427619934082, 52.80984592437744, 61.881726673671174, 51.20519420078823, 42.055406774793354, 39.529052189418245, 33.190926279340474, 33.7977089881897, 31.501044477735245, 17.01353451183864, 6.865518501826695, 3.280808444534029, 0.959949003798621, 0.47964028269052505, 0.2502214860703264, 0.18505928479135036, 0.29527623844998224, 0.05653585327257003, 0.07542304175772838, 0.027481716591864824, 0.04670884094334074, 0.10180394045476403, 0.2904738390019962, 0.23447298684290477, 0.022913347264485698, 0.06408632972410747, 0.0717475600540638, 0.0452001115440258, 0.05184125268299665, 0.06817923938589436, 0.07113730601434197, 0.015561549259083611, 0.06324582839650766, 0.06916103884577751, 0.07487348946077482, 0.07565541286021471, 0.07356582355818578, 0.03960568870284727, 0.029664044667567526, 0.028344395836549144, 0.05084983498922416, 0.09714599432689802, 0.08811976867062704, 0.09090140940887587, 0.12454195427043097, 0.07318297374461379, 0.029144938236900737, 0.1396746558270284, 0.0619745184002178, 0.0929789547143238, 0.02567139364379857, 0.08129648159125022, 0.11258288313235555, 0.08558520967406885, 0.06174949583198343, 0.04027230864656823, 0.02603576355613768, 0.02980092553687947, 0.040834519014294655, 0.04520750079037888, 0.021990841587207148, 0.07907481544784137, 0.07379088005317108, 0.11434594781271049, 0.2248307735260044, 0.025996698598776544, 0.1476185502750533, 0.11424251193446772, 0.07194161428404705, 0.027404884375365715, 0.08136706958924021, 0.08339071885815688, 0.06081640840108905, 0.0058381415936829785, 0.009684459755330213, 0.034168669022619724, 0.02437653678602406, 0.06765734417630093, 0.04550813251574125, 0.041385533554213386, 0.03777123535318034, 0.05372867586889437, 0.02593662280456296, 0.0661364079320005, 0.013442893213193332, 0.014085758494080176, 0.05633083391668541, 0.05801054396267448, 0.04499344334804586, 0.038876714783587625, 0.0471978916653565, 0.06652336288243532, 0.03313742132325258, 0.03001900329919798, 0.09598140431834118, 0.037263107619115284, 0.02745604082675917, 0.0702808794698545, 0.07994402559208018, 0.052372311508016925, 0.06028170245034354, 0.10938112065196037, 0.02782092133669981, 0.09719236541007246, 0.1387585521276508, 0.052268356550484896, 0.06704415207994835, 0.07997887515063797, 0.12304718233644962, 0.044447572103568485, 0.004797200597490051, 0.018357328970783522, 0.06773243086146456, 0.06370801252446004, 0.0526837319401758, 0.12341283128729888, 0.08260568776833159, 0.09672185565744128, 0.03915072758016842, 0.15511151749108518, 0.010830125422216952, 0.04120186769536563, 0.042586014672581635, 0.031665855286909, 0.043001831110034666, 0.0396346451847681, 0.03486980265006423, 0.07280747246529375, 0.07476913756025688, 0.11669122268046651, 0.09997954977942364, 0.08469278006149189, 0.09793441130646638, 0.12429506251854555, 0.05556555837392807, 0.03207530028053692, 0.21977408629442963, 0.07393343347523894, 0.06585543336612837, 0.073161477755223, 0.1247722219143595, 0.08130026781665427, 0.14498354095433438, 0.08835425680237156, 0.037129982441131554, 0.2594107229794775, 0.36250486384545055, 0.09452628597084965, 0.3522901433919157, 0.682807020843029, 3.4409101392541612, 5.633293262549809, 16.13174557685852, 24.524844646453857, 34.58664219720023, 49.767577171325684, 59.494568824768066, 56.67643158776419, 67.45635672977993, 74.67808505467006, 73.04947594233921, 69.69020952497209, 71.08084283556256, 67.26126520974296, 68.95131724221366, 82.07979256766183, 78.73519379752022, 85.52152020590646, 81.18574701036725, 78.98325143541608, 79.93357045309884, 82.91270787375313, 81.55500207628522, 86.05048656463623, 81.45635850088937, 82.70827102661133, 79.20192514147077, 74.4049652644566, 77.53357928139823, 76.09268965039934, 65.61349991389683, 67.30627564021519, 57.539484705243794, 56.82869093758719, 50.21422127314976, 34.90180901118687, 18.82143667766026, 11.348832351820809, 4.179866475718362, 2.0515222932611192, 0.5436448625155857, 0.28946757156934055, 0.4398607329598495, 0.22238004074565001, 0.16186044391776833, 0.028824401686766317, 0.06176661527050393, 0.014427724028272288, 0.319722660950252, 0.3062753996678761, 0.028395991639367173, 0.0008343394874827936, 0.06638188154569694, 0.02656529058835336, 0.021008214314601252, 0.013016185440522219, 0.051685332121061425, 0.01898788647460086, 0.024136119954554097, 0.06747722027025052, 0.034358434911285124, 0.07549394188182694, 0.05178502248600125, 0.06520055207823004, 0.08591777325740882, 0.14649793612105505, 0.07456727339220898, 0.07358364188777548, 0.08513764797576837, 0.06047794156308685, 0.08473682376955237, 0.07818708808294364, 0.03780000523797103, 0.04604947793164423, 0.04128932407391923, 0.0750350079366139, 0.09512335607515914, 0.018013605182724338, 0.09810596531523125, 0.006549245869142136, 0.09429066468562398, 0.09006902336009912, 0.054823509084859064, 0.016118677399520363, 0.019721917176086987, 0.04443945682474545, 0.049484758238707266, 0.15045228893203394, 0.0892775258315461, 0.1051592282684786, 0.12261594619069781, 0.09084996288376194, 0.19608253400240624, 0.09491419765566077, 0.0763982255011797, 0.0712249455973506, 0.08404049756271498, 0.06506805454513856, 0.05042919416778854, 0.03995918169883745, 0.029428304638713598, 0.02962870317112122, 0.055320271357361755, 0.12833906337618828, 0.09547913234148707, 0.14964943272726877, 0.18209188830639633, 0.11466954116310392, 0.11439812715564456, 0.19832967913576535, 0.11895351271544184, 0.1637565828859806, 0.11642401559012276, 0.17044901448701108, 0.14239492985819066, 0.1626298754875149, 0.057606171018310955, 0.16464580302791937, 0.1471646103475775, 0.1662188914737531, 0.1267046896474702, 0.12999994068273477, 0.1858959998935461, 0.140433827947293, 0.14199653480734142, 0.14686586494956697, 0.14475734452051775, 0.14161228042628082, 0.2639001820768629, 0.2236828686935561, 0.24297158366867475, 0.21419795336467878, 0.2176658644207886, 0.18642581360680716, 0.16960638255945273, 0.16933034094316618, 0.16154758499136992, 0.12468745931982994, 0.11505588543202196, 0.17413796511079582, 0.1355528812855482, 0.1755830411400114, 0.13017215287046774, 0.21108437329530716, 0.08314784403358187, 0.24900905255760464, 0.22863769424813135, 0.10556770634970494, 0.11385225930384227, 0.11753532024366514, 0.1696366723626852, 0.1350057649293116, 0.16350401858133928, 0.16779533188257897, 0.20691094866820745, 0.1520104088953563, 0.16540828639907496, 0.15728554369083472, 0.14452318208558218, 0.2740782344979899, 0.18167178013495036, 0.15736536655042851, 0.268707276987178, 0.1541895376784461, 0.14052120968699455, 0.16207688301801682, 0.27833321903433117, 0.18194419837423734, 0.24266787139432772, 0.2860770949295589, 0.10608911979943514, 0.3536469962980066, 0.8188256078532764, 0.8931621589830944, 0.27556145776595387, 0.2516470338617052, 1.439071808542524, 3.504268590893064, 11.156229155404226, 18.646472351891653, 31.523080689566477, 44.3111846106393, 61.70709065028599, 61.25600664956229, 79.27492986406598, 91.76157924107143, 83.64575672149658, 96.87332725524902, 92.84002304077148, 86.3763918195452, 83.98210511888776, 90.54014151436942, 91.16835594177246, 100.0613761629377, 92.95796871185303, 90.12379155840192, 94.06654684884208, 96.31888880048479, 96.61649404253278, 101.49629034314836, 94.0616761616298, 97.8558372770037, 89.14710412706647, 87.01204776763916, 97.93498420715332, 84.0244265965053, 73.76200675964355, 70.79718262808663, 55.04223959786551, 51.92041049684797, 44.2833570752825, 30.03524555478777, 17.505329745156423, 10.567033205713544, 3.9532105922698975, 1.1179095676967075, 0.2667136053953852, 0.2206343872738736, 0.5282060195292745, 0.308954690183912, 0.20847426620977266, 0.13938243793589727, 0.17021563915269716, 0.18351112572210176, 0.6990537004811423, 0.6019204897539956, 0.14045448255326065, 0.11517823886658464, 0.2933005073240825, 0.12408226036599704, 0.16536768286355905, 0.10125268503491368, 0.2608391749007361, 0.09211903371449028, 0.13025642691978387, 0.1296829426927226, 0.13511796747999533, 0.12612652352878026, 0.17242794829819882, 0.16035086634968007, 0.16492212962891373, 0.23592521463121685, 0.15971104853919574, 0.13574554451874324, 0.22582808429641382, 0.08841153194329568, 0.1674772889486381, 0.12744506634771824, 0.11420162341424397, 0.2086963914334774, 0.12125819761838232, 0.22644029930233955, 0.12760093941220216, 0.12828361349446432, 0.1254252711577075, 0.14804312320692198, 0.1783211470714637, 0.13558551881994518, 0.23160077525036676, 0.1286300734749862, 0.11626426130533218, 0.16522090216832502, 0.13503286561795644, 0.2857202397925513, 0.09911178491477456, 0.23437264508434705, 0.27129385247826576, 0.33741163462400436, 0.29552954914314405, 0.24858882224985532, 0.15491810786936963, 0.13875730362321648, 0.15389681767140115, 0.10833658384425299, 0.08708519954234362, 0.14324213511177472, 0.0893819455855659, 0.1182779496801751, 0.12476687505841255, 0.17816466332546302], [0.056522201147994826, 0.07442304398864508, 0.029199916536786726, 0.04450181419295924, 0.04303364083170891, 0.039003159784312756, 0.010853228691433157, 0.01919275994545647, 0.017941115590344583, 0.0797676064872316, 0.03799498566825475, 0.09428597600864512, 0.04137499929804887, 0.05913482220577342, 0.020339541802448884, 0.08137964962848596, 0.011837971296959689, 0.05183150552745376, 0.05336320672982505, 0.00894853678931083, 0.09325167150901896, 0.05084947197298918, 0.03398470800103886, 0.08837586814271552, 0.06141440809837409, 0.1303172915109566, 0.08851345468844686, 0.042028509945209534, 0.09678889491728374, 0.036770497980926714, 0.08232186335538115, 0.04211261436077101, 0.06307288339095456, 0.012431116924355072, 0.07628752929823739, 0.02635993535763451, 0.08539277714278017, 0.01664555475248822, 0.07213380932807922, 0.03320828073525003, 0.018955571244337728, 0.04318936461848872, 0.045771115725593906, 0.05637526099703141, 0.08485711445765835, 0.043162151971565824, 0.0472240457976503, 0.045211643246667724, 0.0797393387183547, 0.09449763143701212, 0.03373044057350073, 0.09151525289884635, 0.013949264389728861, 0.07232903063829456, 0.06592250655272178, 0.07949875055679254, 0.05002386448904872, 0.11662758966641766, 0.06830274632998876, 0.049632156400808265, 0.16861010316227162, 0.1533772905490228, 0.1211422902664968, 0.0442797364667058, 0.086519416687744, 0.18687724295471395, 0.13499979382114752, 0.01470841360943658, 0.10085868689098529, 0.1051971787320716, 0.055836229385542016, 0.03777403770280736, 0.1138559098222426, 0.3015497018183981, 0.4781311665262495, 0.6193131336144039, 0.34541742503643036, 0.18011594004929066, 0.14689831249415874, 0.19390388019382954, 0.13401371959064687, 0.9736642049891608, 5.304999998637608, 3.747863096850259, 3.5159376561641693, 8.226428287369863, 17.79223997252328, 13.791904960359846, 16.19385552406311, 17.05807420185634, 22.27644579751151, 17.282744203295024, 12.580608998026166, 17.837253877094813, 7.046463055270059, 10.23837125301361, 4.907756720270429, 8.065736430031912, 2.5627123372895375, 3.4191320964268277, 3.921561981950487, 3.818735156740461, 3.3997255606310706, 0.20531800628772803, 0.5497675282614571, 0.09225619278315987, 0.05249666322820953, 0.08961703761347703, 0.09375625729028668, 0.172803273158414, 0.07536469453147479, 0.09566078973667962, 0.023175207498882498, 0.10855016631207295, 0.2927961658154215, 0.22782776770847185, 0.108399131202272, 0.07214710182909455, 0.06074290270251887, 0.036998414501015625, 0.021371215282540237, 0.08975941461644002, 0.05107971926086715, 0.0529847538231739, 0.02056348550000361, 0.04482325998001865, 0.06382999955011265, 0.017803788584257876, 0.0699643903811063, 0.01693855974424098, 0.07177433504589967, 0.02502936211281589, 0.03281155827322176, 0.02084436676731067, 0.04866170883178711, 0.010429023864812084, 0.02239166240074805, 0.022268591415403143, 0.03689525003678032, 0.025752692317057933, 0.048914663294064145, 0.030116559671504155, 0.12762855578746113, 0.02741265869034188, 0.0631048423903329, 0.15620485453733376, 0.07709558308124542, 0.02797400053324444, 0.024927000016240135, 0.11264994274824858, 0.04254488527242627, 0.015953874814191034, 0.11891841888427734, 0.03586336112182055, 0.03272148614217128, 0.02180697047151625, 0.02334822714328766, 0.009912374579081578, 0.014631762901054961, 0.06932615355721541, 0.021135666939829077, 0.045497445589197535, 0.057094616682401726, 0.08985420595854521, 0.029636733633066927, 0.02707464647080217, 0.025310104280444126, 0.03126928888793502, 0.0718785851661648, 0.010674645059875079, 0.03726502448054297, 0.04373819088297231, 0.05952170930270638, 0.0426682666875422, 0.04893749260476657, 0.04892570645149265, 0.06604462928537812, 0.030406036281159947, 0.05014286256794419, 0.0447754911147058, 0.024599145465929593, 0.05749858929110425, 0.018342553870752454, 0.006945880545702363, 0.03794711163001401, 0.028848292904772928, 0.013374865836729961, 0.05978155428809779, 0.08544532967997448, 0.04500379100708025, 0.011574707343243062, 0.04267708085743444, 0.029839842912874052, 0.048790050337889364, 0.05631272042436259, 0.07751998637935945, 0.07530081724481923, 0.06528396438807249, 0.07113219664565154, 0.10470716109765427, 0.10699581221810409, 0.0434652908838221, 0.10153951535799674, 0.043206138004149706, 0.0463371089260493, 0.07158021296241454, 0.10053942259401083, 0.06642367930284568, 0.06542853305914573, 0.02216892988820161, 0.04359754753698196, 0.01590015519676464, 0.045704812676246674, 0.07365986851177045, 0.017052243197602884, 0.01632966786356909, 0.11480178763823849, 0.09000134627733912, 0.05656355107203126, 0.06846805103123188, 0.05052925433431353, 0.12836267639483723, 0.03810260471488748, 0.020686500506209474, 0.023269505206761614, 0.061908449445452006, 0.07518467919102736, 0.036917634907045534, 0.07481357481862817, 0.040298737585544586, 0.028659063058772256, 0.06883918933038201, 0.05113647871517709, 0.06944653245487384, 0.05381275653573019, 0.02899511091943298, 0.13733904329793795, 0.10505052017314093, 0.13053151858704432, 0.030242505948990583, 0.14038918034306594, 0.07939222055886473, 0.09844435072903122, 0.047651343047618866, 0.13597696567220346, 0.06750377134553023, 0.09764825951840196, 0.09069623398993697, 0.25444360237036434, 0.5120608487299511, 0.3759327733090946, 0.3263290135988167, 0.12412903857018266, 0.15140065018619808, 0.2602685269500528, 0.8535585126706532, 3.7541260293551852, 7.626552956444876, 15.830278873443604, 15.966397557939802, 18.666345936911448, 23.997132437569753, 35.68228278841291, 29.224147592272075, 32.46545444216047, 32.57135541098458, 36.99149363381522, 33.08270461218697, 27.17128321102687, 32.493351459503174, 19.87792590686253, 22.767316920416697, 16.506215265819005, 21.224630968911306, 14.294950195721217, 14.430411406925746, 17.08943315914699, 12.737543616976057, 9.152930617332458, 3.0663334046091353, 1.9350259729794093, 0.6618088047419275, 0.13578760011919908, 0.10275021182107073, 0.025114031408780386, 0.055854353055890114, 0.03780951490625739, 0.06214750411787203, 0.02756968017534486, 0.07461059106779949, 0.0744477358779737, 0.11941243308995451, 0.08099041480038847, 0.023462470388039947, 0.040303992839264016, 0.15057483235640184, 0.08598843589425087, 0.06390281992831401, 0.08488648823861565, 0.0011573866171862132, 0.018271560448088815, 0.03146641348887767, 0.05698785598256758, 0.02612179161847702, 0.08846804033964872, 0.016780895347307836, 0.1231186320739133, 0.011791685030662587, 0.03693294604974134, 0.08414957206696272, 0.06531658156641892, 0.02555035487083452, 0.06391575959111963, 0.03563772787206939, 0.04209540332002299, 0.053185084502079656, 0.04965979313211782, 0.030581291698451554, 0.12015803450984613, 0.020748834125697613, 0.055266768871141334, 0.13878710488123552, 0.10109621485961334, 0.03413360572553106, 0.04512708081996866, 0.11724663073463099, 0.023307604948058724, 0.025079451567892517, 0.11088151764124632, 0.021054373355582356, 0.014315899760861481, 0.060406288265117576, 0.023356435720675757, 0.04419536402981196, 0.051577797891306024, 0.06634275721652166, 0.038235326164535115, 0.07579190017921583, 0.01744928626742746, 0.029866818072540418, 0.061842204071581364, 0.021026607702619264, 0.05663613396297608, 0.036723584069737365, 0.0903096047363111, 0.08180150842028004, 0.035420562739350965, 0.01974836816745145, 0.07634225993284158, 0.06543985102325678, 0.0516542687879077, 0.0498966086389763, 0.2081449053117207, 0.13590281536536558, 0.1112520791856306, 0.17472310656947748, 0.14829837451023714, 0.1141967379621097, 0.11007222892450434, 0.06392921494053942, 0.1067686861913119, 0.08496173777218376, 0.10383827665022441, 0.13875050470232964, 0.20381228279854569, 0.14575156117124216, 0.06273713747837714, 0.2536989508994988, 0.08881644093032394, 0.15209632499941758, 0.1520650309643575, 0.18975347147456237, 0.13091410377195903, 0.13543537259101868, 0.1516622525772878, 0.17899014188774995, 0.1561791787722281, 0.20051069424620696, 0.16531703700976713, 0.1404164167387145, 0.13297438036118234, 0.10828434343316726, 0.1741372730050768, 0.1173632980457374, 0.18746006382363184, 0.10426511588905539, 0.12633054543818745, 0.12329833528825215, 0.13262416129665716, 0.172529470707689, 0.2051326712327344, 0.12289102428725787, 0.17284827360085078, 0.1328025617237602, 0.20788111803787096, 0.11492091124611241, 0.23446753142135485, 0.18449717281120165, 0.13017388992011547, 0.16125196085444518, 0.1523984766432217, 0.1885506460177047, 0.141868440966521, 0.16646612249314785, 0.1624672170728445, 0.14541850904268877, 0.10848506087703363, 0.22775622297610554, 0.19708349529121602, 0.16998271165149553, 0.22215912331427845, 0.1694795779351677, 0.29877693631819313, 0.2812896232519831, 0.3122269388820444, 0.13614003120788506, 0.23123154363461904, 0.2647940569690296, 0.22665215150586196, 0.11537197418510914, 0.2142108455300331, 0.2784732686621802, 0.23834066359060152, 0.10264157836458512, 0.15475126967898437, 0.41704458583678516, 0.6383103770869119, 0.683872212256704, 0.5176822670868465, 0.1824106911995581, 0.24614064076117106, 0.4149868333978312, 1.92163462298257, 4.471067649977548, 13.972756147384644, 12.11345989363534, 17.601067236491613, 22.30576545851571, 32.9160555430821, 27.207250561032975, 28.94941234588623, 28.619101933070592, 33.15795012882778, 30.894167968205043, 23.009409529822214, 28.61316122327532, 15.207355499267578, 17.550843920026505, 13.406772392136709, 17.12355923652649, 12.885634916169302, 11.518351895468575, 11.68910734994071, 9.616563064711434, 5.906294933387211, 1.6001074931451251, 0.6821120381355286, 0.3133270612784794, 0.11628638154694013, 0.2389816620520183, 0.3791193094636713, 0.37261183293802397, 0.2081899871783597, 0.12405249982007913, 0.10040016006678343, 0.29882763645478655, 0.4646735372287886, 0.37479362157838686, 0.1766512995319707, 0.17289598818336213, 0.10580201806234461, 0.23569901819740022, 0.1991352630513055, 0.22889100494129316, 0.1892194372734853, 0.054830806728984625, 0.09934096011732306, 0.1427928635052272, 0.26249319900359425, 0.07658049357788903, 0.16531728128237383, 0.09522643232984201, 0.17587905882724694, 0.05384741949715784, 0.2733622172049114, 0.20411554723978043, 0.1670400138412203, 0.1263680684247187, 0.12369449117353984, 0.12894412662301744, 0.19027853544269288, 0.22319018441651547, 0.12176875450781413, 0.11322732855166708, 0.28740840777754784, 0.13088989364249365, 0.11888183227607182, 0.21222459711134434, 0.1553049406835011, 0.12277658257101264, 0.17098584425236496, 0.3396001271903515, 0.19197985343635082, 0.06918672139623336, 0.2122062902365412, 0.15358858635382994, 0.14255427702197007, 0.15612781367131642, 0.11836656635361058, 0.2394763683634145, 0.1935113612562418, 0.2126387884574277, 0.09832963759877852, 0.15428199486008712, 0.11598984817309038, 0.2872957166816507, 0.21711452757673605, 0.14355865812727384, 0.11691481353981154, 0.15693208122892038, 0.2251478393695184, 0.17715811090809958, 0.20490362495183945, 0.14714966900646687, 0.17976160906255245, 0.169992116146854, 0.19212311932018825, 0.15249393294964517], [0.029281591796981435, 0.046563960146158934, 0.036379566815282614, 0.013552580943464168, 0.0511375270517809, 0.031652966514229774, 0.023523485953254358, 0.06114092455910785, 0.040135923107819896, 0.05326722116608705, 0.009245544289504843, 0.03284169540607503, 0.08071314503571816, 0.020235951557489376, 0.02590776131754475, 0.012446449271270206, 0.032743657273905616, 0.03021213811423097, 0.02590085213471736, 0.008686529821716249, 0.03311832056247762, 0.03731708847252386, 0.043242863712034056, 0.03563048790342041, 0.026839478107701455, 0.0330738527700305, 0.04149492357724479, 0.025536687479221394, 0.0031648921597349855, 0.025084659324160645, 0.05465461154069219, 0.04561230121180415, 0.024232409162712947, 0.022104301124012897, 0.013014621417304235, 0.0224130735732615, 0.03622335448328938, 0.04155338615445154, 0.0398981610446104, 0.03913643763267568, 0.024756165254595022, 0.047984595344002755, 0.059132752673966546, 0.022823690736134137, 0.056726039852947, 0.005035326525103301, 0.011659367309351052, 0.04643683321774006, 0.04333077810172524, 0.06534587392317397, 0.03199292612927301, 0.03379926438044224, 0.01481155093227114, 0.10459316042917115, 0.004532112656826419, 0.033981335681996176, 0.009356929205491074, 0.047841919785631556, 0.06570517857159887, 0.08724735584110022, 0.012404784676618874, 0.023839746036433747, 0.04020947291116629, 0.053639624933046956, 0.08910704390811068, 0.10180674958974123, 0.027996683958917856, 0.04228691304368632, 0.14810218289494514, 0.1433668362775019, 0.07638991344720125, 0.06055771013987916, 0.03440635644697717, 0.06320385422025408, 0.1863063100193228, 0.1685531876449074, 0.11125675429190908, 0.020276327783774053, 0.18521365150809288, 0.016137469426861832, 0.05846675019711256, 0.07410943188837596, 0.3481426659439291, 0.1386992617377213, 0.15572297253779002, 0.22463483975401946, 0.7315614446997643, 0.47168198972940445, 0.4979436291115624, 0.2764393463730812, 0.527795750115599, 0.4886006904499871, 0.2797387364719595, 0.38217391126922196, 0.49289299441235407, 0.3041966940675463, 0.2069181547101055, 0.5042494450296674, 0.3733033144048282, 0.2399058538888182, 0.15039213001728058, 0.5087207736713546, 0.1721733891006027, 0.060547884952809126, 0.11683185584843159, 0.006951283380788351, 0.023445330593468885, 0.11632348384175982, 0.05026350270158478, 0.02520014259165951, 0.022360458271577954, 0.06211614901466029, 0.04611180476578219, 0.08417380255247865, 0.01700882543809712, 0.01857151703110763, 0.03334597923925944, 0.037171030417084694, 0.052807116747966835, 0.06875336143587317, 0.06566897872835398, 0.047408739637051306, 0.04563603636675647, 0.06824354414961167, 0.042080726607569625, 0.027059242029541304, 0.02213373258044677, 0.0409446927452726, 0.02935445967263409, 0.07446563563176564, 0.06199473874377353, 0.026491828994559388, 0.03698065045422741, 0.039579860267362425, 0.0345725635997951, 0.044019725240234814, 0.019456701586022973, 0.0323317017007087, 0.018261972748275315, 0.047865414060652256, 0.0689113379589149, 0.046634805987456014, 0.022604559548199177, 0.047864250373095274, 0.06993364595941134, 0.03285235179854291, 0.016860813201804246, 0.0427157607461725, 0.06674369677369084, 0.020057800492005687, 0.07290867596332516, 0.004791270201427064, 0.050760054628231695, 0.03394624185083168, 0.03865033853799105, 0.05548786272161773, 0.058907621540129185, 0.03031092942027109, 0.04683653784117528, 0.023810658936521838, 0.05612238456628152, 0.01930706256202289, 0.033562265669128725, 0.006140806379594973, 0.030852285014199357, 0.07960536197892257, 0.01681140567442136, 0.05310757883957454, 0.06091278072978769, 0.02430832535693688, 0.05115533859602042, 0.024686145529683148, 0.05681210523471236, 0.03958412825262972, 0.03137932351923414, 0.007873152083318149, 0.014990636679743017, 0.015787243576986448, 0.016611631394230893, 0.022548663529700468, 0.0294300111542855, 0.06060115673712321, 0.011747119698806532, 0.13381949572690896, 0.035073634569666216, 0.020450636644714644, 0.017898647779864923, 0.009308927941934338, 0.05875989089586905, 0.04865018391449537, 0.020013458228537014, 0.017088159752477492, 0.05195766215079597, 0.03862533112987876, 0.014406967642051833, 0.02217499938394342, 0.02384078249867473, 0.022797539996515428, 0.041139866558036635, 0.048126063110040765, 0.0297998568442251, 0.11268593903098788, 0.007631667407362589, 0.053782456554472446, 0.016325208192159022, 0.03412836404251201, 0.01925766351632774, 0.047873454700623236, 0.02541015935795648, 0.017141954008755938, 0.014212389243766665, 0.06916795311761753, 0.04216160119644233, 0.01355982176028192, 0.1005565081057804, 0.055700692015566995, 0.0428067251507725, 0.013290900520847311, 0.059402436417128356, 0.03058114242074745, 0.03390447462775877, 0.011507777497172356, 0.03387692610600165, 0.028334801351385455, 0.053755851196391244, 0.04320773595411863, 0.02889567839780024, 0.026797931408509612, 0.051837608949946504, 0.02558743002425347, 0.021783885013844286, 0.027225671402577842, 0.03402331664359995, 0.04423288701634322, 0.08515539166650601, 0.07231450998889548, 0.030956202652305365, 0.043388626604740105, 0.02463375075188066, 0.010074837914934116, 0.09821115181382213, 0.09414089843630791, 0.036044889595359564, 0.04839803690889052, 0.08190131413617305, 0.11860820624445166, 0.0776264892358865, 0.1310719988707985, 0.07839053323758499, 0.06702030835939304, 0.09498294003840003, 0.10442115858729396, 0.07267042196222714, 0.05959224980324507, 0.10535573200987917, 0.006362503702153585, 0.059979869717998166, 0.036702030404869995, 0.17198372499219008, 0.2426895573735237, 0.2832513494150979, 0.5593816637992859, 0.24494221221123422, 0.64812861595835, 0.3731071635016373, 0.2642986721226147, 0.3909115424113614, 0.408459055104426, 0.2765630025948797, 0.1567401915256466, 0.40171694116933004, 0.3814007613275732, 0.31860134111983435, 0.3598580615861075, 0.8894184912954057, 0.6693300125854356, 0.4605031524385725, 0.6730252600141934, 0.1834964422242982, 0.07651741017720529, 0.09541038995874779, 0.06641396946672883, 0.13950785834874424, 0.11322304021034922, 0.03234918415546417, 0.02837282306115542, 0.04192973220986979, 0.0032019745225885083, 0.0400644326582551, 0.13723601454070636, 0.07277676875569991, 0.0564223072225494, 0.05623225974185126, 0.020928866429520503, 0.06356973387300968, 0.06177056434431246, 0.0976864474692515, 0.02156497604612793, 0.05048133958397167, 0.031127319005983214, 0.030900186193840842, 0.0027979361808060533, 0.009033777751028538, 0.0318589867092669, 0.12439905479550362, 0.03476275018017207, 0.027048321008416157, 0.037421864457428455, 0.02545945662339883, 0.05332587712577411, 0.0513412029083286, 0.035537219872432094, 0.03128294440518532, 0.04192013433203101, 0.013005261874890752, 0.03165263742474573, 0.06933663013790335, 0.029783097029264485, 0.02568941214121878, 0.015149765015978898, 0.08039397573364632, 0.04995769375403013, 0.05256523258451905, 0.022249879115926366, 0.05072756637153881, 0.020875894896952168, 0.039658502476023774, 0.04839606576466134, 0.01884759766315775, 0.016803899380777563, 0.012274549209645816, 0.04267220219065036, 0.03512081650218793, 0.018012504259656583, 0.03366250904010875, 0.020157121055360352, 0.06058388123554843, 0.02070864280020552, 0.017807227060464875, 0.013152578612789512, 0.04359154589474201, 0.11348477830844265, 0.03507496449830277, 0.014265828965497869, 0.03660562754209552, 0.08874729142657348, 0.02114848107365625, 0.035899438828762086, 0.04962238210386463, 0.018669840147984878, 0.02281702752225101, 0.026168032083660364, 0.07335513843489544, 0.14459874374525888, 0.07692985090294055, 0.12419663422874042, 0.10121534525283746, 0.1590252531958478, 0.11846712524337427, 0.14880591870418616, 0.10116393943982464, 0.11103781139744179, 0.1389473205698388, 0.07687634841672011, 0.10471117123961449, 0.1167726604534047, 0.08598752665732588, 0.08033563529274293, 0.15595108244035924, 0.11037400058869805, 0.11159294125224863, 0.2295412586203643, 0.16036503416086945, 0.07847215421497822, 0.15272657546613896, 0.09968936749334846, 0.14629246214670794, 0.1419204574610506, 0.06923086688454662, 0.15078053703265532, 0.13315446355513164, 0.11687483425651278, 0.10983086723302092, 0.2274150691394295, 0.10052617759044681, 0.2177580501884222, 0.09187218946005617, 0.2142245112253087, 0.14100024183945997, 0.07855620434773819, 0.1919902485928365, 0.12221076578966208, 0.0918368242148842, 0.17002872989646026, 0.15614276858312742, 0.11853374381150518, 0.10844143107533455, 0.1538675728120974, 0.14153730230672018, 0.08796502197427408, 0.11560559379202978, 0.1296623966523579, 0.11199389438011817, 0.12317395981933389, 0.14621437633676188, 0.16860608623496123, 0.1704230130250965, 0.11694845530603613, 0.11960839400334017, 0.09413669151919228, 0.20172122786087648, 0.1891716548374721, 0.1072345751204661, 0.12215513948883329, 0.12938446870871953, 0.106567622694586, 0.18039358300822123, 0.22939393509711536, 0.1748983043112925, 0.13102409429848194, 0.20704919339290687, 0.4213014974125794, 0.26106974110007286, 0.28641001135110855, 0.13267039667282784, 0.2506947506751333, 0.25917719836745945, 0.2508578976350171, 0.25041714842830387, 0.1273871058864253, 0.35804042911955286, 0.08949729653873614, 0.11148646553712231, 0.19265135883220605, 0.7681859965835298, 0.38611799106001854, 0.34163008683494156, 0.5882218448179108, 0.9003731948988778, 0.8402040749788284, 0.7854093323860849, 0.3699939362704754, 0.7767188187156404, 0.7769307930554662, 0.42012187785335947, 0.5103294987763677, 0.5881072538239616, 0.6659953115241868, 0.6011750783239092, 0.758185258933476, 0.8368174252765519, 0.47279950976371765, 0.4333227766411645, 0.7009168490767479, 0.32126402109861374, 0.13894574636859552, 0.22105141489633492, 0.10116664000919887, 0.19738199641661985, 0.25556239805051256, 0.18886931320386274, 0.16556059036936077, 0.1465359612235001, 0.08339911233633757, 0.10026988812855311, 0.229174442589283, 0.3279035676802908, 0.15270028901951654, 0.08090042070086513, 0.17955728859773704, 0.16049590999526636, 0.19472046994737216, 0.190259400755167, 0.12571044585534505, 0.13338569471878664, 0.18802951755268232, 0.16445493112717355, 0.10559554664152009, 0.19472249198172772, 0.15201716710414204, 0.23454542724149569, 0.21678448814366544, 0.11550249718129635, 0.05697820042925222, 0.12456228317958967, 0.17588536920292036, 0.09927114564925432, 0.21499479774917873, 0.06621944704758269, 0.19037353034530366, 0.12330913756574903, 0.15752284095755645, 0.12440517518137183, 0.2094682114464896, 0.09769583160855941, 0.09554661943444184, 0.1541814495410238, 0.07848896831274033, 0.12020023938800607, 0.18331683400486196, 0.18459234413291725, 0.14061543105968408, 0.12518633183624062, 0.16915484464594296, 0.06837869475462607, 0.06692418030330113, 0.06855441496840545, 0.11092071660927363, 0.11294618435204029, 0.19813781657389232, 0.08139351209891693, 0.14415089706225054, 0.10170407367071935, 0.07452909901205983, 0.08835808373987675, 0.0810204196189131, 0.12729909989450658, 0.23640103052769387, 0.10209488270006009, 0.09572641085833311, 0.20283707869904383, 0.13463708971227917, 0.18601276219955512, 0.20650166991565908, 0.1603686846792698, 0.10192385116325957, 0.11235141448144402, 0.15411626946713242], [0.036333138056631596, 0.05606512978140797, 0.01980759748922927, 0.03442463618037956, 0.0363927303946444, 0.030540871367390667, 0.01169662142638117, 0.022424457694536874, 0.024053810264116952, 0.06099808615233217, 0.019694792738716518, 0.01649683344710086, 0.06204837693699768, 0.04528533214969294, 0.02123257191851735, 0.047080515285155604, 0.03365371183359197, 0.02775070314029498, 0.029501104660864388, 0.02094856939012451, 0.03837111459246703, 0.022327978496572802, 0.019477995711245706, 0.019249578771580542, 0.043295480710055144, 0.06066859633262668, 0.08295813921306815, 0.00840424737959568, 0.03280635730230382, 0.02678496460430324, 0.043290452765566964, 0.024793806984754543, 0.02905030295784984, 0.028401196002960205, 0.04320692510477134, 0.010667400850382234, 0.06388954099799905, 0.028410078026354313, 0.08333098742046527, 0.01872248259106917, 0.01776111721327262, 0.07826551316039902, 0.09701507099504982, 0.05180175515956112, 0.036454212452684126, 0.07270966842770576, 0.035799931668277295, 0.032839381601661444, 0.020728717258732234, 0.02889968853976045, 0.0196339298438813, 0.021750117718641247, 0.039153434934892824, 0.04442950950137206, 0.024959944587733065, 0.026260351861960123, 0.012160303420387208, 0.03018924095002668, 0.02426979474590293, 0.029639865072177987, 0.05855456619922604, 0.05906743010772126, 0.10724168616746153, 0.037692186023507795, 0.03158033273315855, 0.12274109518953732, 0.011843471671454608, 0.06695413762437445, 0.03490322728508285, 0.09023651294410229, 0.029575366925980364, 0.055676841509661505, 0.038701109920761416, 0.04324181876810534, 0.14394128402428968, 0.0934266114075269, 0.06872956521276917, 0.144391532721264, 0.06881474849901029, 0.043586463667452335, 0.08158858413142817, 0.028600627622966255, 0.08430140784808568, 0.034055245108902454, 0.02639121242931911, 0.027979052226458277, 0.20055553184023925, 0.2062422524073294, 0.2735345922410488, 0.10282203475279467, 0.19172011023121222, 0.2547350467315742, 0.17332342453300953, 0.11960597841867379, 0.11360553040036134, 0.14602692425251007, 0.08170525144253458, 0.15122796302395208, 0.192142213295613, 0.003176662197802216, 0.030229362725679363, 0.1950117786015783, 0.03433783458811896, 0.03730810806155205, 0.018447411279859285, 0.03074039119694914, 0.04394060466438532, 0.05553365705002632, 0.05747912212141922, 0.06712489096181733, 0.04138854964237128, 0.061637415417603085, 0.01837627706117928, 0.07441686931997538, 0.06460774995918785, 0.03137911317337837, 0.048136183459843905, 0.06171326884733779, 0.0972029844831143, 0.05632404178114874, 0.04810822103172541, 0.03529167840523379, 0.05200682540557214, 0.024539037441302623, 0.07659507529543978, 0.04975884906681521, 0.029052128217050006, 0.027536705069776093, 0.061605571769177914, 0.0957560899800488, 0.024724299553781748, 0.06817716985408749, 0.05304646319044488, 0.02449811838700303, 0.010054031486756035, 0.04790331702679396, 0.046348094408001216, 0.08740423992276192, 0.04689835238137415, 0.03163486319993224, 0.04094520843188677, 0.03654821669416768, 0.020012101158499718, 0.05175925511866808, 0.023891587808196033, 0.017742026630522947, 0.05234353483787604, 0.0821613355406693, 0.07242924347519875, 0.00754361561433013, 0.042349816632590125, 0.024644668380330716, 0.03521046115617667, 0.037163234049720426, 0.023056043178907464, 0.014829174183042986, 0.027497411106846163, 0.048944970060672076, 0.03305596997961402, 0.007175398408435285, 0.021011774927111607, 0.045954734086990356, 0.04592246974685362, 0.04879874576415334, 0.05061483117086547, 0.03329554373132331, 0.02259047655388713, 0.06537380242454154, 0.04233790834301284, 0.02520476171879896, 0.05691091689680304, 0.02719902533239552, 0.04058583253728492, 0.015815365460834334, 0.051795984219227514, 0.02630292993438031, 0.03646353891651545, 0.030643150343426635, 0.05462522079635944, 0.004325400780154658, 0.03548713041735547, 0.07433178102863686, 0.015530024522117205, 0.045169723353215625, 0.04257769583325301, 0.0486363621561655, 0.027123460280043737, 0.05822734268648284, 0.025504792940669825, 0.09573644639125892, 0.03770484748695578, 0.03469561592542699, 0.024912733817473054, 0.0575228604887213, 0.07271435031933443, 0.014053721463174691, 0.035970491623239856, 0.013315865520520933, 0.011536907853691705, 0.07206696005804197, 0.020949756826407144, 0.045045843214860985, 0.03183161799928971, 0.04515929087730391, 0.07417314632662705, 0.03278368744733078, 0.021676384710839817, 0.06582269405147859, 0.05647633218073419, 0.020560847695118616, 0.03537910764238664, 0.014861375758690494, 0.007560018350237182, 0.024935167881527116, 0.0618626686877438, 0.01253360285357173, 0.021205464444522346, 0.0034233423315786888, 0.03452307804088507, 0.014834602463192173, 0.06521022120224577, 0.041781404454793246, 0.009983919311447867, 0.04893627802708319, 0.025111005142597214, 0.02933314010234816, 0.03450279662917767, 0.014133222018634635, 0.022055112424173524, 0.07849820995969431, 0.0162644725226398, 0.0663473576839481, 0.026802357153168747, 0.02877611034948911, 0.034786960309637446, 0.04768313919859273, 0.0730459571682981, 0.018515627797959105, 0.04370930564722844, 0.02023191936314106, 0.028022961923852563, 0.06663630503628935, 0.015598246129229665, 0.08642780767487628, 0.039635143908006806, 0.03914414918316262, 0.06179828249982425, 0.12443915621510573, 0.03417399212984102, 0.03629568970895239, 0.09936943144670554, 0.1163297670760325, 0.02439784787462226, 0.0732269903112735, 0.07063398230820894, 0.023247222116749202, 0.06617374092872653, 0.03702115220949054, 0.12242200731166772, 0.013331440443705236, 0.08570877768631492, 0.14355080069175788, 0.08520401548594236, 0.18246073994253362, 0.11679757625928947, 0.07668943916048322, 0.1102667920557516, 0.09880818120603051, 0.041685150869722874, 0.047693117056041956, 0.1202360660369907, 0.06963813038808958, 0.09578291246933596, 0.08503175580075809, 0.20504709439618246, 0.08018953991787774, 0.05359293493841376, 0.1021200359932014, 0.061482051254383156, 0.12975693015115602, 0.0408966965707285, 0.04715374617704323, 0.09203805734536477, 0.04219206741877964, 0.01595682474518461, 0.020136795538876737, 0.027600024261378815, 0.06479466600077492, 0.02397956496237644, 0.08404587834541287, 0.08450728215809379, 0.08131741439657551, 0.03866364460970674, 0.016115854693842784, 0.08169609121978283, 0.03433349196399961, 0.0343039756906884, 0.03756926261952945, 0.0863973753792899, 0.05351658957079053, 0.055171865570758066, 0.04751053685322404, 0.02305704401805997, 0.06082789599895477, 0.03927506912233574, 0.01601533142716757, 0.007294527953490615, 0.034068042279354165, 0.053192022522645335, 0.013332447220039154, 0.06842322022254978, 0.022354298869946172, 0.041835113894194365, 0.023062950665397302, 0.08508635751370873, 0.036453693373394866, 0.024126946161101972, 0.032009404352200885, 0.04905398688944323, 0.07430076519293444, 0.0561040709061282, 0.027971988676914146, 0.03942099486344627, 0.02133209095336497, 0.024479838653600643, 0.0647117965189474, 0.022805226101939167, 0.026614903372579386, 0.03405689734167286, 0.01973214778783066, 0.05643875830407653, 0.0017108449433830433, 0.029737071998949562, 0.04827362751322133, 0.06035328110946076, 0.0045424972112024465, 0.03823298182604568, 0.03216953183125172, 0.03520586408142533, 0.02526191302708217, 0.0412113196881754, 0.026588810308437263, 0.05823484728378909, 0.08134047780185938, 0.023369640012138655, 0.10292675306222268, 0.05453680768342955, 0.07638555725238153, 0.03647678731275456, 0.026185453470264162, 0.010195969138294458, 0.02854178167347397, 0.10728831509394304, 0.176938102713653, 0.14095326007476874, 0.1289576566112893, 0.13596600054630212, 0.10256546709154334, 0.09839439019560814, 0.11370895270790372, 0.08625785500875541, 0.16432185683931622, 0.0930389372099723, 0.1481140572577715, 0.1126330065141831, 0.15440107775585993, 0.14603731940899575, 0.13674065683569225, 0.08892047391938311, 0.12410789541900158, 0.161610498758299, 0.0893292844827686, 0.08797627887023346, 0.08628422966493027, 0.08574594104928629, 0.1507929406527962, 0.1347242407500744, 0.16262121738067695, 0.16134129677500042, 0.13405014335044793, 0.13608424205865177, 0.09929917593087469, 0.07339618980352368, 0.11125600790338856, 0.07823223101773433, 0.1296659250344549, 0.15393360784011229, 0.07644773141614028, 0.1378312933125666, 0.12621222250163555, 0.12862042470702104, 0.11435626154499394, 0.06259094032325915, 0.14415434402014526, 0.10883954114147595, 0.20804506566907677, 0.15106552174048765, 0.21983339025505952, 0.08526065958929913, 0.11272136534431151, 0.09440031594463758, 0.13132406105952604, 0.10026621725410223, 0.14117009272532804, 0.14191388924207005, 0.1458809577992984, 0.10883091696138893, 0.1436337719538382, 0.13015383242496423, 0.07930091688675539, 0.11696646362543106, 0.12021869554051332, 0.19820944273046084, 0.12456453591585159, 0.3128778710961342, 0.1357001912380968, 0.19215449477945054, 0.20998084465307848, 0.08121142722666264, 0.15670017153024673, 0.13592467776366643, 0.22551074703889235, 0.11764863559177943, 0.19478132096784456, 0.11495338593210493, 0.17139394235398087, 0.4161413200199604, 0.3028299888329846, 0.2431325050336974, 0.29929243294256075, 0.22117208556405135, 0.14845241553017072, 0.2114953212440014, 0.06856077284153018, 0.23311005426304682, 0.09939333623541252, 0.20253293216228485, 0.3416113049856254, 0.3837376359317984, 0.3028050458856991, 0.5087556775127138, 0.20471265805619104, 0.3055020325950214, 0.42890054679342676, 0.3708408565393516, 0.43669675130929264, 0.2339597972376006, 0.22064535239977495, 0.2566255267177309, 0.2795441054872104, 0.3482645851160799, 0.30637707135507036, 0.12392314390412398, 0.2887639578964029, 0.20276261626609735, 0.17120559460350446, 0.19535891711711884, 0.17599721891539438, 0.1454898909266506, 0.2125594677137477, 0.18996176815458707, 0.21260537739310945, 0.08368017511176211, 0.1269864309579134, 0.09190115612000227, 0.1398074451301779, 0.2465184490595545, 0.2246589277471815, 0.14518385806253978, 0.13209155201911926, 0.23035232509885514, 0.1888088828751019, 0.3186127947909491, 0.1862867682107857, 0.17470735098634446, 0.11474407144955226, 0.2127127487744604, 0.11653130554727145, 0.11133446690759488, 0.07737557377134051, 0.13834491718028272, 0.2193721900028842, 0.05558268120512366, 0.13813310568886145, 0.169877538723605, 0.11466219941420214, 0.11412568177495684, 0.13648655904190882, 0.11338601753647838, 0.12145217720951353, 0.1102089062333107, 0.13181308124746594, 0.19970824516245297, 0.179236002266407, 0.18266643104808672, 0.146309493375676, 0.15207651177687304, 0.12432996635990483, 0.16796894185245037, 0.14237133041024208, 0.26278773748448914, 0.14129825441965035, 0.11945767780499798, 0.11743811331689358, 0.12713896563010557, 0.16794612950512341, 0.10892693645187787, 0.1618743131735495, 0.08944141917995044, 0.11147278627114636, 0.11326736890311752, 0.08551780400531632, 0.14953040411429747, 0.16429665604872362, 0.09825524980468409, 0.10729076460536037, 0.1377665882131883, 0.14616834452109678, 0.21007894724607468, 0.18504690831261023, 0.13767490456146853, 0.23235804747257913, 0.16947178835315363, 0.24908390854086193, 0.12017765774258546, 0.0740200009729181, 0.0961827120876738, 0.12267757074109145], [0.028612532519868443, 0.020412910097677792, 0.049643250448363166, 0.04956210105280791, 0.0318166155900274, 0.011885529816416758, 0.027448873800624694, 0.019005329913592765, 0.0073995651743773904, 0.03884711708607418, 0.02687285015625613, 0.04244880810646074, 0.012364457644123052, 0.04541831483532276, 0.054085683676281145, 0.05824931365038667, 0.023770026563267623, 0.006821365553020898, 0.01889858108812145, 0.033896847894149165, 0.01694596086495689, 0.06467274682862417, 0.007755326173667396, 0.03371868834697774, 0.07996658688145024, 0.006788426494624997, 0.028842410006161247, 0.06325603356318814, 0.022257936719272817, 0.00610234065347218, 0.026900676877370903, 0.0058987890536497745, 0.043610989315701384, 0.04745090380311012, 0.0389958587475121, 0.020683940732851624, 0.07955320977738925, 0.0044671857613138855, 0.026216542248481085, 0.011016663180531135, 0.0402624325693718, 0.03726371830063207, 0.046951142405825, 0.03168716128649456, 0.05860956146248749, 0.02380714412512524, 0.034514687955379486, 0.02022791261385594, 0.011045751976780593, 0.025087327663121477, 0.030468278298420564, 0.06884114351123571, 0.043614877321358235, 0.04390248117436256, 0.04612917186958449, 0.039602044969797134, 0.04226917274562376, 0.022632114855306487, 0.019243130992565836, 0.05735350493341684, 0.0710789995001895, 0.04432405498144882, 0.07358280050435237, 0.05599669273942709, 0.03822034411132336, 0.10001641458698682, 0.014956401195377111, 0.04400579830897706, 0.09108916004853589, 0.05201521209840264, 0.08616167945521218, 0.03960477946592229, 0.013037844278317477, 0.006600010466562318, 0.04084311944565602, 0.10375371083085026, 0.02772482211834618, 0.05852261398519788, 0.08080306449638945, 0.022746388634134616, 0.06617259420454502, 0.04327141307294369, 0.057382464808012755, 0.03402124032644289, 0.024299607878284793, 0.027524925701852356, 0.1058446979150176, 0.13458193838596344, 0.11918102550719466, 0.133990255849702, 0.13867108896374702, 0.13489850211356366, 0.06628012843430042, 0.17982611060142517, 0.1315238353397165, 0.12987500881510122, 0.06606449679072414, 0.07384201445217643, 0.03353721754891532, 0.07286620645650796, 0.07607778733862297, 0.08541129436343908, 0.06830694646175418, 0.025318071977900605, 0.0995491821584957, 0.01524404067146991, 0.04182066788364734, 0.031134684503610646, 0.04811191904757704, 0.04603906241910798, 0.02948974598465221, 0.08079914934933186, 0.07294209381299359, 0.0855504415397133, 0.03360236030338066, 0.042243110215557475, 0.06783449609896966, 0.03310184233954974, 0.018099634941401224, 0.002381787685278271, 0.022924614338470355, 0.10149114938186747, 0.05669781279617122, 0.029202009817319255, 0.08611386987779822, 0.04501391474955848, 0.043489460301186354, 0.009611099093620266, 0.035650718425001414, 0.049647830559739044, 0.04508211091160774, 0.03014179438884769, 0.011919222472767745, 0.06368249282240868, 0.07976597121783666, 0.013681957215469862, 0.034735998937061856, 0.01178823468009276, 0.040258398678685935, 0.019634956128097007, 0.05959104879626206, 0.005668342022025692, 0.07228994702122041, 0.11119679215231112, 0.005776502624420183, 0.030213423938091313, 0.040168737061321735, 0.02244837605394423, 0.04964985598676971, 0.030351736516292607, 0.04297583982614534, 0.06812713468181235, 0.007073005777783692, 0.06858897275690522, 0.004827453929465264, 0.018448576663753817, 0.03242009785026312, 0.07669096586427518, 0.053338857500680854, 0.047789346892386675, 0.015280120074748993, 0.03239177579858473, 0.039921977623764954, 0.06714832077601127, 0.06046559901109763, 0.04044752674443381, 0.03805750249219792, 0.023689308037449206, 0.04216832208580204, 0.02034710068255663, 0.00933107447677425, 0.031111811088132005, 0.039844275186104436, 0.01883606256784073, 0.06546620532338109, 0.02407564891369215, 0.0398486585223249, 0.024628459875072752, 0.027338917200852717, 0.008011559656422054, 0.026773687352293303, 0.038912093599459956, 0.028653471930218593, 0.029280838623110737, 0.06997305527329445, 0.04798770642706326, 0.13748294700469288, 0.012982413056306541, 0.017685440202642764, 0.0676153903560979, 0.04087634730551924, 0.06223614793270826, 0.05089545289852789, 0.025656864512711763, 0.023806803161278367, 0.017810551882056252, 0.055773892373378785, 0.08414321419383798, 0.06677300270114626, 0.03668769635260105, 0.056807453877159526, 0.007948185333849063, 0.05973987188190222, 0.009146097349002957, 0.05945740453898907, 0.023342753062024713, 0.007106166632313813, 0.045770308268921714, 0.0004839968023588881, 0.008848200967934514, 0.03440386283078364, 0.08152146344738347, 0.012094826487425183, 0.06047687626310757, 0.01534385486905064, 0.02972371842978256, 0.031178626431418315, 0.0067608928158214045, 0.016642134935994233, 0.05332872358017734, 0.06838984987033264, 0.012606625095941126, 0.012470566102170517, 0.002115333132678643, 0.028735198080539703, 0.038559472520968745, 0.05740391329995223, 0.01681202992663852, 0.022705338961843933, 0.019771782714607458, 0.005118379635470254, 0.04797265312767454, 0.03622664877080491, 0.015930891136771867, 0.014758126477577856, 0.10667001362890005, 0.059232232693050585, 0.028415333280073743, 0.007151008467189968, 0.06429679771619183, 0.07395790823336158, 0.035088090758238516, 0.002002998267666304, 0.0295461288520268, 0.09396857089762177, 0.015417252002017838, 0.0982914903600301, 0.0031844867667781985, 0.04084375387589846, 0.06543479593736784, 0.05397548280390246, 0.07472710910120181, 0.030730725465608493, 0.011014853188368891, 0.10556836452867303, 0.023008172533341816, 0.06421927509031125, 0.018951416913686053, 0.05739637477589505, 0.04666877005781446, 0.010661081993021071, 0.11431244175348963, 0.11639566639704363, 0.040024853710617335, 0.061494115607014725, 0.05129884196711438, 0.03463080904579588, 0.0741302425573979, 0.06440294773450919, 0.10667023754545621, 0.05737123505345412, 0.08742142721478428, 0.04019740516585963, 0.08423229227108614, 0.15379279825304235, 0.09477665860738073, 0.08876912668347359, 0.09993938729166985, 0.02708060570460345, 0.03599810121314866, 0.04954502232638853, 0.09498965753508465, 0.0662405291306121, 0.023420623437102352, 0.025467154603185396, 0.09589683849896703, 0.015630552877805064, 0.06252939719706774, 0.06324607266911439, 0.07915368835840907, 0.054221387287335734, 0.0683433837922556, 0.036902110025818856, 0.00034686620035375066, 0.035459351193692, 0.05662922986916133, 0.059664601992283545, 0.04208856707971011, 0.029148866954658712, 0.010507680492342582, 0.045874025739197216, 0.04841016572234886, 0.05423739392842565, 0.025241743573652844, 0.010246040781826844, 0.03425443584897688, 0.048300453395183594, 0.01846462910595749, 0.0693798256771905, 0.07155009279293673, 0.0307826333945351, 0.03301368706992694, 0.050610373195792945, 0.04451423816915069, 0.014212419777842504, 0.03607397160625883, 0.024358927105952586, 0.0729048897379211, 0.052322476503572295, 0.03330216623310532, 0.028486325006399835, 0.023191599208595495, 0.040495204007519145, 0.02548243012279272, 0.03157163052154439, 0.04473661445081234, 0.032767847047320435, 0.01048993001625474, 0.0519412789227707, 0.05998174247464963, 0.03539778771145003, 0.02765443259184914, 0.03028694660003696, 0.11841513589024544, 0.06708468776196241, 0.03029338250468884, 0.07094804902694055, 0.022423536583249058, 0.044944853455360444, 0.06445678948823895, 0.05596036058185356, 0.055244000628590584, 0.01630439073778689, 0.023250010895675847, 0.03598157888544457, 0.020456997910514474, 0.024968743490587388, 0.038559299494538984, 0.07925621499972683, 0.005831811286043376, 0.055445108230092695, 0.033682739561689753, 0.1115879879466125, 0.1377438980021647, 0.16088675973670824, 0.06451063802731888, 0.07511603858854089, 0.09896161832979747, 0.07631008380225726, 0.09388307548527207, 0.14722337148019246, 0.11395729652472905, 0.21747663457478794, 0.10011596245957272, 0.09915401693433523, 0.14791496151259967, 0.11418525714959417, 0.15767910757235118, 0.07819525085921798, 0.06237148174217769, 0.08354765043726989, 0.10939187543200594, 0.0984487272799015, 0.143745431676507, 0.28408410187278477, 0.12607682762401445, 0.17661809202815804, 0.047197196166962385, 0.12205411919525691, 0.1032326841460807, 0.11880586349538394, 0.09870057233742305, 0.1205629434968744, 0.12511824763246945, 0.1386802356157984, 0.17546728306582995, 0.1868527749819415, 0.12686551601759025, 0.17173243633338384, 0.0861901847113456, 0.06068332732788154, 0.08970516574169908, 0.09267925936728716, 0.11541283556393214, 0.08319061209580728, 0.12799876449363573, 0.21522378974727222, 0.13518128836793558, 0.10480752999761275, 0.1319000965782574, 0.1805092053753989, 0.08887828261192356, 0.09783907035099608, 0.11710090855402605, 0.13289025558957032, 0.16688652922000202, 0.11422001171324934, 0.22289019051407064, 0.099179841977145, 0.13945927524140903, 0.2421820131795747, 0.1512824222445488, 0.15917059539684228, 0.13977373551045144, 0.13336118603391306, 0.22059439441987447, 0.17155599008713449, 0.20899456686207227, 0.12949891042496475, 0.10389637960387127, 0.3026293053158692, 0.25687180778809954, 0.2605110625071185, 0.061401997692883015, 0.13598656015736715, 0.18617394140788487, 0.1560376092259373, 0.21375147732240812, 0.13904591170804842, 0.06946328548448426, 0.14778375998139381, 0.17038753921432154, 0.1609529983252287, 0.09571645674960953, 0.3035320011632783, 0.09676824031131608, 0.09234174247831106, 0.2085389034556491, 0.546582104904311, 0.31758904829621315, 0.4190811408417565, 0.286470319543566, 0.41481725392597063, 0.3109915708856923, 0.21335108737860406, 0.34950272153530804, 0.22702913199152264, 0.29069202872259275, 0.2026569140808923, 0.43718171385782106, 0.3240191989711353, 0.285117754978793, 0.20193736840571674, 0.269547167633261, 0.1466261385274785, 0.14409607143274375, 0.2543910566185202, 0.14186811526971205, 0.18201306967863015, 0.13849989457854203, 0.1272887047380209, 0.20046238255287918, 0.14504840890211718, 0.21550717311246054, 0.13713987969926425, 0.207403850076454, 0.23983360348003252, 0.18399056499557837, 0.17476328941328184, 0.14841382045830998, 0.09804297012409993, 0.10706755372562579, 0.14791334659925529, 0.17673250660300255, 0.09845087823591062, 0.14096092752047948, 0.213412359090788, 0.11374919661985976, 0.3167357769395624, 0.11483975845788207, 0.06602242083421775, 0.15141804782407625, 0.13518009414630278, 0.10691312594073159, 0.16697567515075207, 0.2448354379406997, 0.22876829866852078, 0.14219476202768938, 0.11665730950023447, 0.12151606806686946, 0.0999225867646081, 0.09564561090831246, 0.09103580684001956, 0.14286598243883677, 0.12497439820851598, 0.24078452959656715, 0.0807746813765594, 0.11072261831057922, 0.09465203886585576, 0.104461002163589, 0.09097599397812571, 0.17533819856388227, 0.1189569461026362, 0.18119414576462337, 0.1332156267017126, 0.14655938425234386, 0.10951588449201413, 0.070196883619896, 0.07728377476866756, 0.17667692101427487, 0.12977529130876064, 0.08916640893689223, 0.10120345053396054, 0.12199286105377333, 0.11581444687076978, 0.1634682733565569, 0.15532727805631502, 0.10353878486369338, 0.09533017354884318, 0.20347108824976853, 0.13006498504962238, 0.08247719359185014, 0.09873120819351502, 0.11620959852422987, 0.12186875699886254, 0.09896910257105317, 0.1630765279488904, 0.10016069827335221], [0.04982812409954412, 0.022848833851250153, 0.059236521034368446, 0.07540360172944409, 0.06248719910425799, 0.04170037041019116, 0.04491105562608157, 0.011113336609144295, 0.020590492890083363, 0.0429937836847135, 0.013427228384119059, 0.022015648827488934, 0.046420080188129625, 0.035047809526856454, 0.049680943068649085, 0.03208119335717388, 0.04398578831127711, 0.052673883004380126, 0.03211744748322027, 0.04341228712084038, 0.05945832056126424, 0.08199670937444482, 0.04423577757552266, 0.08226462214120797, 0.027370896556281617, 0.04262589217562761, 0.10587168325270925, 0.07043752606425967, 0.052518366170781, 0.011646255468284445, 0.03587516763114503, 0.008483469735697975, 0.04549754397677524, 0.028921486477234533, 0.010710625227407684, 0.0419252606640969, 0.02491678636787193, 0.04030963825061917, 0.026344670016052465, 0.005611513866045113, 0.01600935183731573, 0.04091257768283997, 0.06517497809337718, 0.013526800005430622, 0.043857741967907975, 0.03350812875266586, 0.011584975274412759, 0.09470611810684204, 0.03908232446493847, 0.00982465611637703, 0.028153959894552827, 0.05548675670953734, 0.053167778466429026, 0.10532006820929901, 0.02086248025963349, 0.05318236357665487, 0.08366360528660671, 0.03522141271137765, 0.04621159012562462, 0.08069643950355904, 0.05306855968332716, 0.007301470214900161, 0.04514802380331925, 0.014912126785410302, 0.018898623496560112, 0.10768588233206954, 0.011532743345014751, 0.058367331246180196, 0.01952125401502209, 0.06604979293687002, 0.08727914520672389, 0.019564687041565776, 0.051570659702909846, 0.04955610619591815, 0.03877745528838464, 0.045442538535488505, 0.04236949754080602, 0.04595005898071187, 0.10054164140352181, 0.028714648647499934, 0.04685600161818521, 0.014937914508794035, 0.022808481373691132, 0.08542122133076191, 0.05938512020345245, 0.06592367363295384, 0.1579940156745059, 0.12014929497880594, 0.13171197952968733, 0.1573687863669225, 0.10620062345904963, 0.10141191006238971, 0.015185527204136764, 0.044677415663110356, 0.0765262379177979, 0.07398051702018295, 0.05811953025736979, 0.06705152775560107, 0.12540928487266811, 0.11133131171975817, 0.003649429775707956, 0.022187808428757956, 0.08985864357756716, 0.027145619537415247, 0.047572806011885405, 0.02450403860504074, 0.06003650025065456, 0.03517438344923513, 0.02902483075324978, 0.04674538005409496, 0.06844852957874537, 0.04166810267737933, 0.03635780280455947, 0.033549146194543154, 0.015427981337000216, 0.04967890067824295, 0.08755216055682727, 0.0656360290678484, 0.07156132254749537, 0.019491449364327958, 0.05635194992646575, 0.049690805575145144, 0.092132522990661, 0.042758667908076725, 0.0678420074816261, 0.026197901195181266, 0.04886418707402689, 0.026514312252402306, 0.008569401106797159, 0.02645714228440608, 0.007626748876646161, 0.02033392183615693, 0.004329809561438326, 0.002908820465173838, 0.04365173873624631, 0.020236265379935503, 0.016218282947582856, 0.04422072088345885, 0.028098270829234804, 0.028630924211548905, 0.048842792864888906, 0.009514608021293367, 0.03908058402261563, 0.01740703049914113, 0.03135949672598924, 0.011413949674793651, 0.022106128079550605, 0.037607779659863026, 0.09002049453556538, 0.050720920121031146, 0.0510740195667105, 0.04274939911972199, 0.031986127208386145, 0.0394271559614156, 0.01986132389200585, 0.050712428255272765, 0.02332730621232518, 0.03633704302566392, 0.01658593866574977, 0.03561140410602093, 0.04087511915713549, 0.07229300721415452, 0.00775829137169889, 0.03864392638206482, 0.0172680834906974, 0.02025069103443197, 0.021012930132980858, 0.06894609930792026, 0.04492482649428504, 0.01953175095176058, 0.0388517277315259, 0.02283621479624084, 0.0555728220913027, 0.027252665221957222, 0.057970272909317694, 0.018689878983423114, 0.04111655209479587, 0.04551442253536411, 0.03425718052312732, 0.012461397397731031, 0.026487639040819237, 0.03027426478053842, 0.041900080229554854, 0.03835429370935474, 0.016974444068702202, 0.001647373929569897, 0.01733694800974003, 0.013452474127656646, 0.04666510257603867, 0.059459270510290346, 0.08030018183801856, 0.011780369611057852, 0.0036740300628090544, 0.023665011394768953, 0.03684659568326814, 0.05144115111657551, 0.067304478825203, 0.022138302513797368, 0.030162717016147714, 0.04255710229543703, 0.023118434473872185, 0.030282285064458847, 0.037894263930086575, 0.017307947423042994, 0.03900810291192361, 0.060878189014536996, 0.08308645018509456, 0.030052275263837407, 0.031968692251081975, 0.016734257939138582, 0.02175087428518704, 0.016737450446401323, 0.014194303741013365, 0.02046996641105839, 0.017797478208584443, 0.09098766478044645, 0.01173641241621226, 0.04300467077908771, 0.05288003212107079, 0.023996416379564574, 0.03215759979294879, 0.06042434408196381, 0.03158273135444947, 0.02804184894609664, 0.05207610722365124, 0.04869237522195492, 0.03672321087547711, 0.05680983892775007, 0.05824926615293537, 0.033919860409306626, 0.013886289554648101, 0.008582368759172303, 0.039138212001749446, 0.0035637405567935532, 0.03663611751315849, 0.04035520187712141, 0.03534082469663449, 0.03141692114461746, 0.08354530270610537, 0.019471961838592376, 0.03174838550122721, 0.08762164932808705, 0.054099247591303926, 0.10806274746677705, 0.04484129883348942, 0.07789780824844326, 0.04852433941726174, 0.048068014439195395, 0.013013596829426075, 0.03622543080044644, 0.018727215372824242, 0.05985683096306665, 0.02812749533248799, 0.04812001057767442, 0.06192282760249717, 0.04817763855680823, 0.01788090748180236, 0.059026901211057387, 0.08209229460252182, 0.06420932098158769, 0.033094456485871754, 0.028322423176307763, 0.09915746389222996, 0.0861348637512752, 0.11169972909348351, 0.09231021095599447, 0.09948548807629518, 0.013207077697318579, 0.009282800102872508, 0.019914181769958565, 0.08078519866934844, 0.10580256089035954, 0.026763463525899818, 0.058760108027075014, 0.008412148071719068, 0.04641895381999867, 0.03980034343632204, 0.061182403404797824, 0.04228704196533986, 0.009871685378519552, 0.048300307510154586, 0.07619064806827477, 0.040737050851540904, 0.03087214912687029, 0.05554531428164669, 0.05172808661258646, 0.01821923691646329, 0.005305137069496725, 0.01697417435103229, 0.040117453384612284, 0.12132800530110087, 0.042239083110221794, 0.053685700853488276, 0.012260121858811803, 0.038529389670916965, 0.017228755601016537, 0.028342377194868665, 0.042689806781709194, 0.051325922299708636, 0.05939409722174917, 0.038904928269663026, 0.04044237666364227, 0.0459787610120007, 0.07009387521871499, 0.031348969255174906, 0.04554079719153898, 0.02988217332001243, 0.0463001593016088, 0.07965199769075428, 0.062458395292716365, 0.028981272197727646, 0.022785445109808018, 0.03793088785771813, 0.010487930882456047, 0.010723769298887678, 0.018224890809506178, 0.02475825514245246, 0.024750182272068093, 0.005103375529870391, 0.046717682254633734, 0.02551155793480575, 0.04031910042145422, 0.03152340364509395, 0.013063575174393398, 0.017294624387951832, 0.022085008677095175, 0.03464429832196661, 0.009827868131521558, 0.051557781108255894, 0.03886688281116741, 0.030701059914593185, 0.024853879386293035, 0.07440720698130981, 0.01644735806621611, 0.017017609073913524, 0.027486369645755206, 0.024958141380921006, 0.01632562549119549, 0.01132294031724866, 0.014963200116263968, 0.07496385675455843, 0.056745473095881085, 0.09541867487132549, 0.07075741461345128, 0.04095792757081134, 0.040238252973982265, 0.033457235233592134, 0.0060536006349138916, 0.07578725899968829, 0.027671679255685637, 0.026736249182639376, 0.01582361475032355, 0.15178923362067767, 0.14700493748698915, 0.22826064590896877, 0.1453554324273552, 0.10970364870237452, 0.14044549874961376, 0.17429659302745545, 0.09042325935193471, 0.12916325272193976, 0.08688518777489662, 0.14404940179416112, 0.10164153309805052, 0.18099781844232762, 0.15344651469162532, 0.12447809055447578, 0.0868638139218092, 0.06593467947095633, 0.07735265964376074, 0.07673352358064481, 0.10176200020526137, 0.22168029472231865, 0.1431080973041909, 0.1192958200616496, 0.09977744133876902, 0.15025233823273862, 0.1712859331497124, 0.2053486489291702, 0.11757424101233482, 0.13028063704924925, 0.12965516346905911, 0.14625379922134535, 0.09773916964020048, 0.12135093978473119, 0.09660165996423789, 0.12600273159997805, 0.1186199856123754, 0.12093184941581317, 0.11808152736297675, 0.11990547020520483, 0.12394898251763412, 0.11851509766919271, 0.11676799213247639, 0.1665732767432928, 0.10170520003885031, 0.13776490544634207, 0.20607061018901213, 0.24155146415744508, 0.13663895800709724, 0.20024276790874346, 0.10489101694630724, 0.15333456998424871, 0.13338885669197353, 0.16037544288805552, 0.19827178652797425, 0.1469227804669312, 0.21783799518431934, 0.14668465538748673, 0.1533700166536229, 0.11310059178088393, 0.11323509099228041, 0.21190481712775572, 0.12199668799127851, 0.2725812505398478, 0.0587500249966979, 0.10957016729350601, 0.24393933745367186, 0.1810648034193686, 0.20306640996464662, 0.1419266321297203, 0.18479355690734728, 0.24099558112876757, 0.18316978189562047, 0.16434888967445918, 0.1413579247891903, 0.12592432009322302, 0.2143946878079857, 0.1237360310873815, 0.13934696412512235, 0.16468542947300843, 0.10891750481511865, 0.13630252677415097, 0.09320967697671481, 0.1931369999157531, 0.15507095466767037, 0.13201292338115828, 0.17605465011937277, 0.41677781300885336, 0.32949475944042206, 0.3759371430746147, 0.2977777527911322, 0.2471232951751777, 0.29509889653750826, 0.11584922857582569, 0.1010189772184406, 0.15215694531798363, 0.1817832634385143, 0.17168324254453182, 0.23834595616374696, 0.3333378732204437, 0.2003955604242427, 0.13986046585653508, 0.16622408905199595, 0.14736593168761047, 0.14590402798993246, 0.1691123412123748, 0.17918322581265653, 0.13057850035173552, 0.12804326282015868, 0.09984817861446313, 0.15032095169382437, 0.13424948336822645, 0.12142370588013104, 0.10602746810764074, 0.14805585252387182, 0.24432661810091563, 0.13878193444439343, 0.18286676172699246, 0.11345371497528893, 0.1020236908059035, 0.13259510642715863, 0.16777246525245054, 0.1322097528193678, 0.12880259778882774, 0.12414440060300486, 0.14255084363477571, 0.18641841757510388, 0.1330047244472163, 0.1731276943215302, 0.09881289702441011, 0.17878958050693783, 0.10137889254838228, 0.11931202347789492, 0.10329409835061856, 0.12995534736130918, 0.12145837901958398, 0.10978553430842501, 0.16134720002966269, 0.10928831741745983, 0.11086889688989945, 0.09335732619677271, 0.10139940466199603, 0.08602394363177673, 0.12319902490292277, 0.12410382420888968, 0.0967268632458789, 0.13118812335389002, 0.08098012820950576, 0.1356494232480015, 0.12264538103980677, 0.16189366499228136, 0.12500168888696603, 0.10738278073923928, 0.17171977486993584, 0.11851091789347784, 0.1639208019311939, 0.1514267059309142, 0.1558825775448765, 0.09308711998164654, 0.09928274181272302, 0.11282951025558369, 0.15089242745723042, 0.16594058355050428, 0.10182872733899526, 0.12072945599045072, 0.20026984145598753, 0.16041398367711476, 0.14665988885930606, 0.25818021329385893, 0.09712710391197886, 0.11670860674764429, 0.09576360814805542, 0.09497028536030225, 0.12317237204739026, 0.0696056421313967, 0.09369560983031988, 0.12137415925306932], [0.009776645522963787, 0.03478988818824291, 0.056050412356853485, 0.03753463697752782, 0.0347595712436097, 0.00919672369491309, 0.020840790887762393, 0.017459569465635077, 0.06420172817472901, 0.031289736540721994, 0.05487380210044129, 0.027261961151712706, 0.02582746178710035, 0.07725813971566302, 0.0243737547924476, 0.018764828265245472, 0.017220865935087204, 0.04477554539750729, 0.06623256991484336, 0.07311103546193667, 0.02437492017634213, 0.02536005124316684, 0.029680665382849317, 0.032894780593258996, 0.0242155899759382, 0.06821344433618443, 0.054536349672291956, 0.05063930253631302, 0.04988015416477408, 0.06129003941480603, 0.030202753974923065, 0.010028125019744039, 0.016880799450778534, 0.03756137464993766, 0.027776534968454922, 0.0713921705526965, 0.06902071780392102, 0.038229884313685555, 0.03403084159695676, 0.043852971866726875, 0.06333401080753122, 0.0015559747324524714, 0.046966382302343845, 0.04048437798129661, 0.045727092373583994, 0.029403273481875658, 0.020601988969636813, 0.02632742335221597, 0.022272055336673344, 0.04218605899118951, 0.009814744416092123, 0.05373146804049611, 0.028518222937626497, 0.044163723941892385, 0.0304849295477782, 0.09845643543771335, 0.002439946830106367, 0.07971940335950681, 0.020377339595662694, 0.04154122341424227, 0.01571815853406276, 0.013832696314368929, 0.07149747918759074, 0.05832173369292702, 0.04306088062003255, 0.16622950376144477, 0.03457332355901599, 0.022913007996976376, 0.062300785178584714, 0.07787517910557133, 0.06666041338550192, 0.04585894190573266, 0.009531315249790038, 0.052940048543470244, 0.07617768804941859, 0.022009558975696564, 0.02625069291596966, 0.042869733912604194, 0.0158826778310218, 0.008507827446529908, 0.01579249543803079, 0.041427042933979204, 0.025881768337317874, 0.009586408052460423, 0.01757573805350278, 0.06471721122839622, 0.05780591815710068, 0.040347242661352666, 0.03571521317852395, 0.027617815449567776, 0.09295401176703827, 0.10717555614454405, 0.06308780437601463, 0.011984433928903724, 0.06336717081389256, 0.07833966346723692, 0.0299463491620762, 0.11130916433674948, 0.03356130214940224, 0.07473274772720677, 0.10202656100903239, 0.11395055188664369, 0.02511844358273915, 0.03629898060379284, 0.07815239458744015, 0.015735445910000374, 0.027978923304804733, 0.018883471809593693, 0.029092246600027596, 0.09533757636589663, 0.0335246273316443, 0.13265021704137325, 0.03000958523313914, 0.03395962934674961, 0.012541952226976199, 0.06335594784468412, 0.06659799494913646, 0.020868541273687567, 0.046497626562735865, 0.004622849328110793, 0.037059441940592866, 0.0298345469470535, 0.011045950448273547, 0.06709969695657492, 0.042203181822385104, 0.041126753868801255, 0.003693091807820435, 0.011732033320835658, 0.024866717268845866, 0.04107921909806984, 0.010163380797686321, 0.013511006254702806, 0.008651236670890024, 0.020679693103634884, 0.057305674999952316, 0.09665388001927308, 0.0005776461912319064, 0.013075246824882925, 0.05724792488451515, 0.042754365996058495, 0.027882854620526944, 0.03783741965889931, 0.01818257736574326, 0.049124822552715025, 0.05615926294454506, 0.017335936992562244, 0.0762140303850174, 0.013886221701146235, 0.08291404800755636, 0.03439442440867424, 0.01200926661424871, 0.009366992727986403, 0.015011004604665297, 0.05267814081162214, 0.013947879330122044, 0.03762937742950661, 0.03531199035101703, 0.00977866501281304, 0.007936742688928331, 0.05038435996643134, 0.02195754587384207, 0.0418683281833572, 0.036623761390468905, 0.030961559686277593, 0.017487177359206334, 0.022007840585761836, 0.013232041848823428, 0.06485022444810186, 0.02190204001297908, 0.02515953396713095, 0.06911649980715343, 0.05421619649444308, 0.0642570016373481, 0.008906976519418614, 0.02852300660950797, 0.051732887247843404, 0.010521575193186956, 0.11437383560197693, 0.06958228695605483, 0.026544128777459264, 0.01894042464638395, 0.031040463130921125, 0.038476335017808845, 0.023961571910019432, 0.05687769582229001, 0.07134978247008153, 0.039639632417155166, 0.05059220202799354, 0.04094041458198002, 0.07634582902703967, 0.034169754678649564, 0.06430489263896431, 0.03138808679899999, 0.01209358561650983, 0.023600196033450108, 0.07920596269624573, 0.060974432421582084, 0.01767816630724285, 0.03662206166024719, 0.023988579300099185, 0.031680783057319264, 0.04549727595544287, 0.08505969108747584, 0.038030517154506276, 0.007945170093859946, 0.028988237359694073, 0.04030536348000169, 0.015474389739600676, 0.010831729309367282, 0.028243652045992867, 0.026147735404915044, 0.024776081953729902, 0.07978329421686274, 0.07987752916025263, 0.02593205456754991, 0.05461803511051195, 0.047644846074815304, 0.025008624386308447, 0.045313752588949034, 0.035520310779767375, 0.028306285917226757, 0.03708117202456508, 0.023843352450057864, 0.03715130540409258, 0.02206558730852391, 0.026967670336099606, 0.053650617200349054, 0.03760572030608143, 0.06623245456389018, 0.007830960775858589, 0.016267008547272, 0.0475087489134499, 0.07984347348766667, 0.040733536040144305, 0.009920570433938077, 0.024945400189608335, 0.03147708684472101, 0.04159315848456962, 0.03674413011010204, 0.06416023575833865, 0.12427311869604246, 0.03700670959161861, 0.03659226379490324, 0.06746269283550126, 0.08578895338411842, 0.06152868018086467, 0.0243827674338328, 0.03293637478990214, 0.019946597084136944, 0.054946812468447855, 0.06362628976681403, 0.021095194022304246, 0.04105208108999899, 0.06295307446271181, 0.016420586467055336, 0.09286110675228493, 0.06262768299451896, 0.07876776478120259, 0.047233674209564924, 0.04795727073880179, 0.053310050296464136, 0.07770353010190384, 0.05357035329299314, 0.039621298400951285, 0.0705184345798833, 0.010167990594969263, 0.047540232938315184, 0.07521621071334396, 0.02364519308321178, 0.0246911904375468, 0.06669349196766104, 0.059083151764103344, 0.0219367708279086, 0.041836101162646494, 0.011819046107120812, 0.05998539299304996, 0.02637976045454187, 0.010183927686219769, 0.01982252865231463, 0.040959562840206284, 0.03922697116753884, 0.02521995920687914, 0.07094529417476483, 0.04225673859140702, 0.027200938801148107, 0.025388042509023632, 0.05387954134494066, 0.054344429434942346, 0.04518047134791102, 0.03494555429954614, 0.02677566188919757, 0.09409656974353961, 0.029233076543148075, 0.04341365436890295, 0.05415008682757616, 0.0056252194252530375, 0.07005388236471585, 0.05734769667365721, 0.011114663993274527, 0.06483241290386234, 0.016783148083569746, 0.040224634776157994, 0.08929110331726925, 0.01421161147300154, 0.03910788827176605, 0.06035364751837083, 0.052430458566440005, 0.018441820151305625, 0.05935468112251588, 0.030885258423430578, 0.058947241199868064, 0.006000759296252259, 0.013081216236709483, 0.01763849236470248, 0.00852885439858905, 0.03285329156954374, 0.04640568167503391, 0.016146675450727344, 0.03286210573943598, 0.04315912909805775, 0.05763579585722514, 0.05637860278199826, 0.029259688686579466, 0.1010434723326138, 0.06006068323871919, 0.08380786861692156, 0.0209489256210093, 0.016998565988615155, 0.04713750883404698, 0.07597684168389865, 0.029984414976622378, 0.025850421715793864, 0.01040479083478983, 0.042850670471255264, 0.001175684480196131, 0.01631935582762318, 0.024810098610552292, 0.050476335388209136, 0.04917138023301959, 0.00759320380166173, 0.025444259135318652, 0.06532393010067088, 0.06043646950274706, 0.11052094413233654, 0.025971767525853853, 0.00892731815110892, 0.029325224991355623, 0.02662956990700747, 0.042393015564552376, 0.06887459528765508, 0.027180928803448166, 0.016173513207052435, 0.10807685420981475, 0.23322032977427753, 0.08592092844524554, 0.10027364042720624, 0.12460637438510146, 0.1300163340887853, 0.10620986510600362, 0.12422768399119377, 0.16886867928717816, 0.18218012500022138, 0.12383454080138888, 0.1759518249226468, 0.1212593646986144, 0.17120269047362463, 0.13991625500576838, 0.2236539495310613, 0.1538380565387862, 0.13565747067332268, 0.16229694549526485, 0.19271474757364818, 0.19460981445653097, 0.09158419884209122, 0.14492718183568545, 0.10942905915102788, 0.22687253967991897, 0.14240832413945878, 0.15869643512581075, 0.09959180772836719, 0.10564342407243592, 0.10808442666062287, 0.10525147510426384, 0.05439994038481798, 0.1229276651782649, 0.18502520876271383, 0.11944243790847914, 0.2045123138065849, 0.16402549988457135, 0.16314995900860854, 0.16270767631275312, 0.16259866287665709, 0.12326568418315478, 0.1079772791958281, 0.12436109754656043, 0.08426387129085404, 0.1248577716095107, 0.1955333820411137, 0.09546241323862757, 0.09403847357524292, 0.1100446396906461, 0.19392490120870726, 0.11582965962588787, 0.09052394037800175, 0.1269245757056134, 0.15446024600948605, 0.12462857605091163, 0.15633649033095154, 0.09875313165996756, 0.09664852637797594, 0.05350010795518756, 0.12730509814407143, 0.16193208364503725, 0.0716786819643208, 0.3111806650246893, 0.1623581357832466, 0.16449257625000818, 0.18689933605492115, 0.12748712194817408, 0.12226092309824058, 0.1534389015287161, 0.1755483408591577, 0.10020863677241973, 0.15687360508101328, 0.09096568024584226, 0.1510698507939066, 0.23163524482931408, 0.15529447767351354, 0.14907324793083326, 0.14104680291243962, 0.06899924895593099, 0.17885383777320385, 0.2973992388163294, 0.12395570001431874, 0.21935115541730607, 0.20180547476879188, 0.18966763679470333, 0.22149942442774773, 0.17060958301382406, 0.13634201751223632, 0.1739524264952966, 0.08409347079162087, 0.17004219203123025, 0.20785797999373504, 0.17447548199977192, 0.2225450604621853, 0.17495014438671724, 0.16865009601627076, 0.1681093850306102, 0.223619954926627, 0.1850959663944585, 0.24973150236266, 0.20368695738060133, 0.1847388669848442, 0.14975750978503907, 0.1172218777771507, 0.1508065384945699, 0.11861011971320425, 0.18812128262860434, 0.11631961619215352, 0.22375384345650673, 0.15217399011765206, 0.1614607460796833, 0.18986146710813046, 0.10075863011713539, 0.10398551196392093, 0.10523134297026054, 0.2750716640480927, 0.11342369658606392, 0.17099148966372013, 0.12376165256968566, 0.08571668940463237, 0.2076993113649743, 0.20975377969443798, 0.07303862899009671, 0.1474076887326581, 0.09474818727799825, 0.0948137201900993, 0.16552595794200897, 0.10215401024158512, 0.16969700769654342, 0.10964529469077076, 0.0906891840110932, 0.08866894777332034, 0.19151946742619785, 0.16986634289579733, 0.13609364655401024, 0.20061547362378665, 0.12198751419782639, 0.09331665480775492, 0.09053460694849491, 0.14191629125603608, 0.11433633975684643, 0.09543969588620321, 0.08444554225674697, 0.15034098204757484, 0.14708784089556762, 0.16185878829232284, 0.11482499353587627, 0.20346465573779174, 0.19207473977335862, 0.2299956056688513, 0.17696128146989004, 0.09954302106052637, 0.1518581999199731, 0.12083131766745023, 0.15212896253381455, 0.1512380460543292, 0.10868466552346945, 0.06997422235352652, 0.08004687793020691, 0.13473930422748837, 0.11594795542103903, 0.16155470960906573, 0.12838901712426118, 0.1685912398887532, 0.165017979485648, 0.1064438239804336, 0.10416132038725273, 0.22961141914129257, 0.16307380023811544, 0.11367394030094147, 0.13464805483818054, 0.1389787367412022, 0.13936182404203074, 0.1133035755317126, 0.20138257103306906, 0.10782558590705905], [0.030511653649487665, 0.016269076382741332, 0.024830257885956337, 0.0782566854198064, 0.03794665022620133, 0.03473544593102165, 0.02612271103342729, 0.010548248404770024, 0.033008384318756204, 0.009427909905623113, 0.0714433320931026, 0.02018641510845295, 0.05492551664688757, 0.010866634847064103, 0.021511850146842853, 0.008555008530882853, 0.03637889167293906, 0.03992666630074382, 0.026547811526272978, 0.02009945236412542, 0.008193974466329175, 0.06414974560695035, 0.027730883132400255, 0.04238802154681512, 0.01669970354331391, 0.056939415367586274, 0.0876144500715392, 0.04816433587776763, 0.025082988431677222, 0.055420304382486005, 0.023049361305311322, 0.05198418947735003, 0.015201862934710724, 0.014146131995533193, 0.043542029801756144, 0.012205440417996474, 0.08132854915623154, 0.06831242902470486, 0.12303061251129423, 0.040152570964502435, 0.043946189007588794, 0.05149044668568032, 0.025477295309039097, 0.01675780480062323, 0.023238073768360273, 0.04171746609998601, 0.09687980503908225, 0.09068706019648484, 0.03657748190952199, 0.042904495261609554, 0.02428596593173487, 0.048406959644385746, 0.020542874998812164, 0.07714069208928517, 0.03949417147253241, 0.011869728432169982, 0.04296797560527921, 0.04068739565887621, 0.015267604496330023, 0.11179147381335497, 0.08489921077021531, 0.019410875027201006, 0.07364430291844265, 0.09992430345820529, 0.005906262268711413, 0.05207403090649417, 0.011467228244457926, 0.047157108318060637, 0.028589998371899128, 0.06541782577655145, 0.06572967368577208, 0.02119508625141212, 0.011848575102963617, 0.040694815439305136, 0.03542706310482962, 0.028156487437497293, 0.07300180489463465, 0.051221309163208516, 0.056896067157919915, 0.027906359073572924, 0.03522904623033745, 0.06961516876305852, 0.053175656257995536, 0.02479976282588073, 0.043607393080102544, 0.08862052072903939, 0.057561516628733704, 0.12197201645800046, 0.09413101896643639, 0.02657301740587822, 0.06047724267201764, 0.07157918158918619, 0.0246692500077188, 0.03639703909201281, 0.047007464205047915, 0.06432414946279355, 0.09570747294596263, 0.10828473698347807, 0.11795823755008833, 0.09274754034621374, 0.053573450805353265, 0.07919040388826813, 0.01291760872118175, 0.03447562808703099, 0.022997745146442736, 0.018606010358780622, 0.03910817325647388, 0.10182936516191278, 0.035745550479207716, 0.07452753838151693, 0.08149547555616923, 0.059832919389009476, 0.03311386937275529, 0.06349096952804498, 0.0941786046272942, 0.008030884333753159, 0.010837004919137274, 0.06164786485689027, 0.04380319453775883, 0.027930591255426407, 0.04908268213538187, 0.08722576485680682, 0.017055040458217263, 0.03066884646458285, 0.016387974377721548, 0.03224828260551606, 0.05307892769841211, 0.013853603674631034, 0.01814469475565212, 0.09653808801834073, 0.041879371340785704, 0.025119805741789084, 0.027305533277935216, 0.06812815926969051, 0.015661244713036076, 0.04663381193365369, 0.05863600397216422, 0.013002653755912823, 0.04048580290483577, 0.010434899129904807, 0.03227877936192921, 0.04403858172840305, 0.008659786212124994, 0.026323786404516016, 0.04890449205413461, 0.0372153557171779, 0.013265501258761754, 0.0238330675555127, 0.05405450499217425, 0.03760329454338976, 0.0063663934041479865, 0.03184978238173893, 0.044645310778703005, 0.01733301081029432, 0.04980435162516577, 0.04486232663371733, 0.05835401838911431, 0.032942966757608313, 0.04185667434441192, 0.027093445283493826, 0.05100021192005702, 0.048363387518163235, 0.09366453292646579, 0.026899886384074177, 0.039249352645128965, 0.03695011977106333, 0.053849536526416025, 0.03767167390989406, 0.01860103669709393, 0.04223656574530261, 0.01751988274710519, 0.023196038523955003, 0.01653263804369739, 0.02443790518944817, 0.042627042292484214, 0.03387703127892954, 0.012663865461945534, 0.09078580739774875, 0.000698978165538782, 0.026676402393994585, 0.040606158053768535, 0.04930908552237919, 0.054875579862190146, 0.04281777848622628, 0.052409105069403134, 0.011206502011711044, 0.06706394494644233, 0.030777999000357728, 0.051195806424532614, 0.019726527821538702, 0.05353335277842624, 0.058883282489010265, 0.04316702385299972, 0.002545702237901943, 0.024735325747834783, 0.02919722275276269, 0.015852852824277112, 0.10513797655169453, 0.01850314105727843, 0.020055673284722225, 0.010429754138125904, 0.04406201832794717, 0.02550752234778234, 0.035498536591018946, 0.031916312740317414, 0.043744877845581086, 0.032061970460095575, 0.04192456855837788, 0.0325383325772626, 0.029083008345748698, 0.014977345875065242, 0.023509777849540114, 0.04784061699839575, 0.04576050004522715, 0.04864801260243569, 0.017803970092375363, 0.049834570182221274, 0.017815228684672287, 0.0637434795498848, 0.01997733811315681, 0.015033099401210035, 0.03416616862107601, 0.01974882957126413, 0.08069697554622378, 0.005088756068809224, 0.04459075317052858, 0.041472280863672495, 0.07048372072832924, 0.046052890962788036, 0.06353929479207311, 0.02982833156628268, 0.053239503010575256, 0.020732191358027712, 0.009237118580910777, 0.057917801796325614, 0.08285685429083449, 0.043272658184702904, 0.03671913966536522, 0.019803348163674985, 0.053316146933606694, 0.04105152129860861, 0.04811440248574529, 0.035079188378793855, 0.03671810489946178, 0.012711257740323032, 0.03650164544316275, 0.03724469557138426, 0.011980450080175484, 0.052273214861218414, 0.01837706076912582, 0.038763178911592276, 0.0355758251223181, 0.026292658610535518, 0.10122749102967125, 0.06893448278840099, 0.022116665728390217, 0.045172400173864195, 0.08510243879365069, 0.029707725359393016, 0.07742947659322194, 0.012867016302022551, 0.05947751631694181, 0.013673074343906981, 0.09505884775093623, 0.03431571773918612, 0.019515096309727857, 0.042913607986910005, 0.04732813646218606, 0.07302235093499933, 0.07594188355973788, 0.044175099581480026, 0.030296354488070523, 0.05340553713696344, 0.021095887824360813, 0.03679423652855413, 0.03589699271001986, 0.02976914295660598, 0.010639810768355216, 0.014911443161379014, 0.0715263169258833, 0.05037796477388058, 0.036436743568629026, 0.039973651458110125, 0.07166530803910323, 0.03361773929957833, 0.014573921183390277, 0.07163097416715962, 0.043839184035147936, 0.024927444456677352, 0.017448298998975327, 0.04202724787007485, 0.03743605941001858, 0.014435366028919816, 0.04387684612135802, 0.021205057323511158, 0.11224746970193726, 0.007549136344875608, 0.12677163391241006, 0.026849344006872604, 0.011139884291748916, 0.021150652385715927, 0.031917140553040166, 0.03089894786743181, 0.010789556661620736, 0.03584317131234067, 0.053844372874924114, 0.041944028942712715, 0.029266660633896078, 0.05210414768329688, 0.06020167603024414, 0.012540527303437037, 0.004309408982018275, 0.03545745468831488, 0.011515495833009481, 0.04930126540628927, 0.047634596803358624, 0.036518303477870565, 0.03708119916596583, 0.022213207690843513, 0.012268466143203633, 0.011831849214753934, 0.020237006679443375, 0.025805721525102854, 0.0745138523301908, 0.07285529561340809, 0.02799230401537248, 0.07935101312718221, 0.0340870989353529, 0.012489684674489712, 0.02526351097705109, 0.04874624072441033, 0.06685162455375705, 0.0698163408253874, 0.039067718998662064, 0.0405353902439986, 0.00877055196490671, 0.027566996569346105, 0.11568775081208774, 0.0437586758551853, 0.024853920098394156, 0.060704110855502744, 0.011160147043743303, 0.04480872915259429, 0.025997831752257686, 0.02067771178138043, 0.024686856295115182, 0.031508170533925295, 0.014583888862814223, 0.04965895514136978, 0.07301039514797074, 0.017492588675980057, 0.03770850818338139, 0.08661408589354583, 0.10766397922166757, 0.06835881367857967, 0.11087308345096451, 0.14984286949038506, 0.1164212878793478, 0.10787534287997655, 0.06979767432702438, 0.11944927754146711, 0.09300943450736147, 0.23891497563038552, 0.22908324748277664, 0.10062035825103521, 0.13030677421816758, 0.16480059043637343, 0.14349414301770075, 0.16649877359824522, 0.11946033766227108, 0.05596237922353404, 0.08158427543405976, 0.09162049368023872, 0.24064485994832857, 0.07429204601794481, 0.13308812997170857, 0.16628101814006055, 0.11998956783541612, 0.2006282436528376, 0.1135198517835566, 0.17297726310789585, 0.1637650238616126, 0.14448048866220883, 0.13981026783585548, 0.1186810809054545, 0.0998122433998755, 0.11411426881594317, 0.1015574015410883, 0.17730045398431166, 0.1640594130648034, 0.21180841087230615, 0.09035187068262271, 0.1506575864872762, 0.09087363018521241, 0.09787996565657002, 0.19832643573837622, 0.1360583355916398, 0.06312046905181237, 0.1537935717829636, 0.17399939468928746, 0.11255280367497887, 0.11632633368883814, 0.11814839020371437, 0.16779990520860466, 0.15179729461669922, 0.15781170688569546, 0.09633477178535291, 0.12167667730578355, 0.14191744476556778, 0.12755840883723327, 0.12449924727635724, 0.3636613317898342, 0.181703494861722, 0.1130426652463419, 0.19809747088168347, 0.22311513844345296, 0.10246386325785092, 0.19687830630157674, 0.08843926366950784, 0.14743162744811603, 0.1005663943610021, 0.19581501478595392, 0.20239763227956636, 0.10217809144939695, 0.20257277573857987, 0.1180028308715139, 0.15813808222966536, 0.12218806200793811, 0.1448254422949893, 0.1390748308705432, 0.20995552172618254, 0.15357430997703755, 0.15176298788615636, 0.21364563943019935, 0.1514498439750501, 0.1548319882048028, 0.15368282129721983, 0.1358662016157593, 0.15561744677168982, 0.23760125041007996, 0.2759695830089705, 0.1245668972177165, 0.1891964485070535, 0.2556273474224976, 0.13366491187896046, 0.23908840918115207, 0.1917313060590199, 0.1763416975736618, 0.18901508966726915, 0.3239386704351221, 0.25805262156895226, 0.23165171965956688, 0.17639560039554322, 0.1710127413805042, 0.10869130159595183, 0.1834118424781731, 0.18616110352533205, 0.18384396071944917, 0.11399369314312935, 0.25938881986907547, 0.16090740077197552, 0.18241405673325062, 0.1677009883735861, 0.17395652484680924, 0.15481810537832125, 0.1529301359717335, 0.13846728418554577, 0.10964616321559463, 0.07731962855905294, 0.12271699362567492, 0.09314487688243389, 0.1261132920959166, 0.07731956749090127, 0.24275423533150128, 0.14487492106854916, 0.0762718076418553, 0.07401408414755549, 0.12233474770826952, 0.2153878595147814, 0.09581863055271761, 0.09972877002188138, 0.19307130415524754, 0.19296180217393807, 0.0972161412771259, 0.1500898426664727, 0.16328430894230092, 0.0757877000474504, 0.08050461086843695, 0.1478121363158737, 0.06980210516069617, 0.1991091123116868, 0.13619872448699816, 0.18057913519442081, 0.18686829986316816, 0.10391039135200636, 0.10381957622511045, 0.09305885221276965, 0.1718286933111293, 0.12787289624767645, 0.1734810753592423, 0.21102216520479747, 0.08278771157243422, 0.12499579920300416, 0.11540594164814268, 0.11745967715978622, 0.09024907262729746, 0.13507075501339777, 0.10046671078141246, 0.13810296516333306, 0.09165859342153583, 0.135685317750488, 0.11248107573815755, 0.11322377981351954, 0.20348677597939968, 0.17425695301166602, 0.045166133902966976, 0.12176167060221944, 0.10741127921002251, 0.14137720875442028, 0.1479803722883974, 0.09570999031088182, 0.2113218062690326, 0.09172375992472682, 0.07769479735621385, 0.16385391194905552, 0.11161876629505839, 0.09277089552155562, 0.08148691922958408], [0.03793228903253164, 0.008577278050194894, 0.026870499032416513, 0.014741191939849938, 0.11403099899845463, 0.020863660910565938, 0.06073978144143309, 0.011117926050376679, 0.013631368188985755, 0.04705477166654808, 0.03601047429921372, 0.03873524362487452, 0.02392635594255158, 0.02634268530112292, 0.033102208748459816, 0.01964659639634192, 0.028026575122826865, 0.06552563142031431, 0.07212496123143605, 0.021081222986270274, 0.018515120593032668, 0.015472411810021316, 0.04978624152551804, 0.03726850197251354, 0.04286766438079732, 0.035506896142448695, 0.037792592242892296, 0.046571949896003516, 0.028153057442978024, 0.04546644671687058, 0.03193254329796348, 0.06977742684206792, 0.008860987112192171, 0.032648530056966205, 0.03899648299972926, 0.06782923745257513, 0.04877260859523501, 0.011653749887565417, 0.044771945769233365, 0.037267711479216814, 0.023489470992769514, 0.020001108891197612, 0.019639800868130157, 0.02677080866747669, 0.0693897662152137, 0.021414431177877953, 0.06406821283910956, 0.02231115591712296, 0.0752570585214666, 0.09864922080721174, 0.044725866456116946, 0.0327310636639595, 0.055508941411972046, 0.035618019822452746, 0.03450176525594933, 0.03684612410143018, 0.03640188383204596, 0.052944187607084, 0.0522359734667199, 0.028335457834016, 0.01749897369050554, 0.03577754679801209, 0.04570476857147046, 0.01666542565050934, 0.04450191258053694, 0.07715229503810406, 0.051951277136270485, 0.09231487249157258, 0.04060003088255014, 0.05798009131103754, 0.030506819087479795, 0.039474945182779005, 0.04419257864356041, 0.02404824288428894, 0.037513096883360825, 0.012196876457892358, 0.007023361187228667, 0.023192650937874402, 0.0335468629242054, 0.07240956595965795, 0.0034176498468566152, 0.01305037851644946, 0.006767809632167752, 0.03590333701244422, 0.012130746434974884, 0.04524773113163454, 0.015921176211642366, 0.04661617002316883, 0.08923589092280183, 0.06557945960334369, 0.034976631203400235, 0.05264137439163668, 0.01810199624326612, 0.07702815027109214, 0.09703463994498764, 0.021189123624935746, 0.05057613771142704, 0.05384672739143882, 0.0032619911570301546, 0.04080721137246915, 0.004841426661836782, 0.035652798134833574, 0.018655277090147138, 0.007879033285592283, 0.023524040655632104, 0.05605475837364793, 0.025414215301030448, 0.10246049772415843, 0.038365513285888095, 0.0652186961046287, 0.060058511926659515, 0.05527342529967427, 0.025502382445016077, 0.059109757122184546, 0.033188090925770145, 0.057651870351816924, 0.051229689070688825, 0.04880564985796809, 0.04788369040137955, 0.06217094750276633, 0.06271433191640036, 0.0771197932107108, 0.09747477847018413, 0.08169047294982842, 0.020970033149101903, 0.03437956788444093, 0.08707172383687325, 0.10028261066015277, 0.026547370478510857, 0.05705554663602795, 0.04398681968450546, 0.03203857796532767, 0.030032034564231123, 0.02257654453361673, 0.010195931818868433, 0.045965220845703564, 0.08051913151783602, 0.0027891154376058175, 0.020010715250724127, 0.020634478922667246, 0.04478186255853091, 0.036153248245162625, 0.04350808269477316, 0.024826198550207273, 0.02735332928464881, 0.03680103544944099, 0.0046609978391123665, 0.004017482436860779, 0.03263814168583069, 0.026084723250408257, 0.01924037274771503, 0.018443211148093854, 0.04043186276352831, 0.03252573896731649, 0.006644884107767471, 0.030839453916996717, 0.0772329999932221, 0.015225613356700965, 0.030785184686205218, 0.0590456219922219, 0.030607981873410087, 0.024726241860272627, 0.035050937573292425, 0.042351757242743454, 0.037613017950206995, 0.03850167151540518, 0.041818330330508094, 0.04234373017347284, 0.033353931669678004, 0.06810829176434449, 0.03088606588010277, 0.03513629049328821, 0.020670183435348526, 0.017451182772804583, 0.019510076846927404, 0.02965912868135742, 0.010748521408199199, 0.08459837548434734, 0.03818958951160312, 0.05838918685913086, 0.07500520667859487, 0.025419183873704503, 0.0482898580708674, 0.03319954798956003, 0.03278798935934901, 0.048229777187641175, 0.027170689710016762, 0.018609213044068644, 0.0046230193859498414, 0.008052236982621253, 0.054052231899861775, 0.03717463004535862, 0.042019268298255544, 0.056735841291291375, 0.03754889639094472, 0.03035661857575178, 0.04374794143119028, 0.007026001112535596, 0.03550312688042011, 0.016382744569065313, 0.008227998756670525, 0.07667772764606134, 0.042747088707983494, 0.061367724889091084, 0.04487960892064231, 0.05948376562446356, 0.023123209664065923, 0.02545497489960066, 0.0767332793080381, 0.05356852464111788, 0.006614207963658763, 0.056950597624693594, 0.05477853239114795, 0.016429672050955038, 0.02244391298985907, 0.016273593729627982, 0.038913308177143335, 0.02397872697162841, 0.0372005466903959, 0.025571470880614858, 0.021322491379188638, 0.049654999282211065, 0.06874914773340736, 0.019173514995990053, 0.032842859093632014, 0.05502360227650829, 0.011705297344763364, 0.05006034931700144, 0.05957695562392473, 0.018585469407428588, 0.03268745082563587, 0.018657597679910914, 0.031041270587593317, 0.042540332302451134, 0.042506171456937275, 0.03817550312461598, 0.011660270609094628, 0.06698015944233962, 0.021082334087363312, 0.008040628944789725, 0.044148623145052364, 0.0046829823737165755, 0.027175395350371088, 0.054994031720395596, 0.06828087036098753, 0.04357550532690116, 0.04964998830109835, 0.026240779519347206, 0.02184423222206533, 0.02133601118943521, 0.03817047857280288, 0.05187991900103433, 0.047333686878638606, 0.03163328899868897, 0.032027287142617364, 0.03641050461945789, 0.02494359019744609, 0.02196670779293137, 0.020040190811934214, 0.03879437455907464, 0.0061091654435066235, 0.014870703918859363, 0.008717781448337649, 0.018882835683013712, 0.01904666457059128, 0.021758090505110364, 0.06732851253556353, 0.04244921522747193, 0.031655022475336275, 0.06398557405918837, 0.028625261836818287, 0.034284545840429406, 0.06444159708917141, 0.03564280331400888, 0.04747753969526716, 0.04231350822374225, 0.029943991252886396, 0.04455229380567159, 0.012791966088116169, 0.036944090987422636, 0.02995163494987147, 0.04095888091251254, 0.017809596844017506, 0.017473772899912934, 0.06922443437256984, 0.04606501977624638, 0.039484227541834116, 0.07052623773259775, 0.05397629704592483, 0.020902630873024464, 0.01012400965139802, 0.039846181869506836, 0.06396069218005453, 0.0749570442629712, 0.04930948925071529, 0.03196192386427096, 0.05544401239603758, 0.052781481694962294, 0.034971487907958884, 0.0503709792558636, 0.03614519064181617, 0.07112610340118408, 0.046337356591331105, 0.07077874775443758, 0.0052126128825226, 0.043841915138597996, 0.024680858045550327, 0.04724380134471825, 0.056680316770715375, 0.0250914327999843, 0.029782981678311313, 0.044815175235271454, 0.046543386964393516, 0.07959981156247002, 0.02365792409649917, 0.05407989237989698, 0.09336614036666495, 0.02554320650441306, 0.039995917584747076, 0.028083695897034237, 0.03977300865309579, 0.0020257665102170514, 0.04243268611441765, 0.07433309060122285, 0.01610051640974624, 0.032104423003537316, 0.020820014145491377, 0.052760738879442215, 0.029908673505165746, 0.03311108737917883, 0.009323017721596574, 0.05855141779673951, 0.03142894139247281, 0.05541291513613292, 0.03274496006114142, 0.05473616805725864, 0.010475558644559766, 0.004943841344876481, 0.019536748362172927, 0.0288345016805189, 0.04098514361040933, 0.03675723262131214, 0.03202654753944703, 0.011754211237920182, 0.04183662024193576, 0.11211304512939282, 0.019130897907806293, 0.025031697969617586, 0.0250402017097388, 0.019104791272963797, 0.059162472507783344, 0.023316916144852127, 0.09045734216592141, 0.17958870476910047, 0.08129369281232357, 0.07695669374827828, 0.14110446481832437, 0.1068780253242169, 0.1121508123885308, 0.10961155114429337, 0.08727584074118308, 0.15680435379701002, 0.1333873774856329, 0.12038652439202581, 0.1351729966700077, 0.08461860261325325, 0.12514863243060453, 0.05156452913901635, 0.09769328710223947, 0.10265407019427844, 0.13864070416561194, 0.09857933848564114, 0.09238314668514899, 0.1576780490577221, 0.0980852564264621, 0.09803341635103736, 0.1066344923206738, 0.18883678423506872, 0.12105053876127515, 0.13570366533739225, 0.14473474930439675, 0.14531305113009044, 0.1151396573654243, 0.13796402833291463, 0.1046291363558599, 0.08036745858511754, 0.12377435474523477, 0.14615032263100147, 0.11800190806388855, 0.049373017091836245, 0.15226734296551772, 0.1088602432448949, 0.1724153139761516, 0.09032615420541593, 0.11123479011335544, 0.15103509623025144, 0.08464122497077499, 0.13418929731207235, 0.16223772295883723, 0.10042472981980868, 0.2412460691162518, 0.1753001870321376, 0.1523208793784891, 0.10806908498385123, 0.14001300052872725, 0.11832603067159653, 0.10083383215325219, 0.1781200428626367, 0.1121933836756008, 0.17109344633562223, 0.136507851470794, 0.13046423505459512, 0.19232676124998502, 0.22170268637793406, 0.129300398219909, 0.1288787294179201, 0.10156198843781437, 0.34093222713896204, 0.17439279572239944, 0.11701526386397225, 0.16494705900549889, 0.21564689704350062, 0.09665965435228177, 0.10033708345144987, 0.17596413354788507, 0.12393887234585625, 0.16000298144561903, 0.19248198292085103, 0.10650827802185502, 0.1357341179890292, 0.08697409621839013, 0.23660852653639658, 0.16807191632688046, 0.06880054676106998, 0.1408854065729039, 0.08434351773134299, 0.0905263288212674, 0.1557631960936955, 0.1641416922211647, 0.2644740327128342, 0.16587680125875132, 0.2151571304670402, 0.25301395622747286, 0.21898116384233746, 0.07929844023393733, 0.21297326550952025, 0.18100161823843205, 0.2829934246838093, 0.15669729454176767, 0.13767641090920993, 0.19211326699171746, 0.16424640374524252, 0.0721483842602798, 0.12436534517577716, 0.09604779218456574, 0.09255637667540993, 0.09216250066778489, 0.11804213161979403, 0.07702859131885426, 0.28407310960548265, 0.18518716150096484, 0.28003406205347603, 0.15137612793062413, 0.23531114043934004, 0.33891817235520905, 0.122706517044987, 0.11184152255633048, 0.1913964083152158, 0.13002359441348485, 0.1786371815417494, 0.1559865562511342, 0.19037956930696964, 0.2941391494657312, 0.13678648509085178, 0.24132496916822024, 0.12301082643015043, 0.1921758143497365, 0.20363776359174932, 0.1507434890206371, 0.226958265794175, 0.09608718792774848, 0.14680770092776843, 0.17024354051266397, 0.22651282112513269, 0.13334426337054797, 0.11311364679464272, 0.07518246038151638, 0.1243583969771862, 0.2917526603809425, 0.16321251993732794, 0.09796807342874152, 0.09240931099546806, 0.19996747268097742, 0.11298429766403777, 0.1065264559750046, 0.10709837957152299, 0.10292627130235944, 0.1217508954661233, 0.10257813534034149, 0.16074464736240252, 0.043780833416219266, 0.14321541440274033, 0.06573001973863159, 0.10785944480448961, 0.17670187753226074, 0.09910960003201451, 0.09323775475578648, 0.11835450200097901, 0.17796001716383866, 0.18976101678396973, 0.08166094989116703, 0.15993755709912094, 0.10709200134234768, 0.08578466504280056, 0.08300556881087166, 0.09573692136577197, 0.104656393107559, 0.11460043915680476, 0.1496533275182758, 0.12135243256177221, 0.09069151817155735, 0.2230009545705148, 0.11231737916490861, 0.07258247703846012, 0.09861834746386323, 0.09938796223806483, 0.11902897938021592, 0.09080699126103095], [0.021627957666558877, 0.04918770578556827, 0.02672902448102832, 0.02277088544464537, 0.03135147304939372, 0.04924987316397684, 0.01951603438439114, 0.018470389868265817, 0.04700831915917141, 0.005305057341632034, 0.019149136929107562, 0.018281882662060003, 0.032471028688762865, 0.04454704872997744, 0.0643185515488897, 0.03525465753461633, 0.03529981064743229, 0.031711055897176266, 0.024958343245089054, 0.07830868834363562, 0.026099779942472066, 0.07096923967557293, 0.02864444741447057, 0.011184425026710545, 0.0698595702914255, 0.015638216930840696, 0.04120369634724089, 0.060501154246074815, 0.004151385809694017, 0.0582438785848873, 0.06370246889335768, 0.04406658147594758, 0.02034193872740226, 0.013064642170710223, 0.021244363160803914, 0.04673487972468138, 0.02569994470104575, 0.02057710539416543, 0.12019231409898826, 0.03404423587822488, 0.024530158810583607, 0.046413403403546126, 0.03244638429688556, 0.022211384127980897, 0.002792791401069345, 0.038309218628065925, 0.02733169080290411, 0.025274504940690737, 0.07530184183269739, 0.07080106477120093, 0.015482829018895115, 0.028474376004721438, 0.06543008011898824, 0.06955868072275605, 0.030598855577409267, 0.021136591443791986, 0.03900620301387139, 0.007620944009561623, 0.04561040470642703, 0.028820211733026162, 0.03040850954130292, 0.03999297274276614, 0.061000678156103404, 0.006964516934073929, 0.04623881973592298, 0.01368713698216847, 0.023659447407616035, 0.025284024787002375, 0.07359509555889027, 0.10079831763037614, 0.022547247087849037, 0.03620554293904986, 0.043514342180320194, 0.05829864314624241, 0.07784937441881214, 0.058094024126018794, 0.06867590666349445, 0.05693485561226096, 0.028721264363931756, 0.09798290620424918, 0.05367868480139545, 0.049513026007584164, 0.021195054020998732, 0.00879833203673895, 0.013370301840560777, 0.03074692888185382, 0.0259619050193578, 0.0665364789643458, 0.04335236230066844, 0.012655831607324737, 0.01597272451700909, 0.09711439495107957, 0.041500158474913666, 0.055140751347477944, 0.00607249147391745, 0.011658356292173266, 0.04014694590919784, 0.033422704586493115, 0.04289741474868996, 0.04484319194619145, 0.021600748412311077, 0.05814801515745265, 0.04502095794305205, 0.06225890599723373, 0.03322235694421189, 0.011591961640598518, 0.019943874462374618, 0.01988157137696232, 0.06426279632640736, 0.039942523664129634, 0.01958394386539502, 0.04097468060042177, 0.05545024134750877, 0.04224491172603198, 0.03162781322108848, 0.04735429737983005, 0.061916232242115905, 0.022163259031783258, 0.0359893956088594, 0.049915146215685775, 0.011568528433729495, 0.07548139576933213, 0.021128508395382335, 0.049405179651720185, 0.048533587849565914, 0.03873323855389442, 0.0600113266014627, 0.03493035511512842, 0.01151254675018468, 0.02625952404923737, 0.08556591892348868, 0.05147729667701891, 0.06412719110293047, 0.053469797795904536, 0.05034626701048442, 0.08843931116695915, 0.01684206867191408, 0.03709537376250539, 0.00851271120232663, 0.01190299361145922, 0.043834525892244916, 0.08546166201787335, 0.03128440664815051, 0.05640310128884656, 0.027085426695910946, 0.01590822128179882, 0.05576224871245878, 0.04645645645047937, 0.08524172167692866, 0.037232000181185346, 0.024008250030289804, 0.0915925380374704, 0.08244693771536861, 0.03412748873233795, 0.04780030184026275, 0.03716458772708263, 0.010458448535895773, 0.020178522049848522, 0.02794542063825897, 0.05395603599026799, 0.029900812676974704, 0.02859115188143083, 0.03817664984879749, 0.00890571020344006, 0.035423778995339356, 0.05451309966987797, 0.07188071576612336, 0.008548883904170777, 0.01816793966905347, 0.026630838767492344, 0.018665580644405315, 0.06678727229258843, 0.021684075905276195, 0.02100407694732504, 0.02877790846728853, 0.08017750270664692, 0.058398157092077393, 0.03749677811616233, 0.006156385119538754, 0.022504640177690556, 0.015650372885699784, 0.030094300330217396, 0.03597431177539485, 0.06362975029540913, 0.03236552667138832, 0.011636720354934888, 0.03481893966506634, 0.05589183872299535, 0.03051542630419135, 0.049792853849274774, 0.06518058279263121, 0.017806019268131683, 0.03749773824321372, 0.00632550021899598, 0.010331537890514093, 0.08811832339103733, 0.03633316519803234, 0.03586678772366472, 0.014610775812928165, 0.008571873518771358, 0.059289908169635704, 0.033283723651298454, 0.025269546546041965, 0.02776952230903719, 0.04199327362169113, 0.05456509920103209, 0.03994631328220878, 0.04437022589679275, 0.005305170148078884, 0.015262288174458911, 0.04521253891289234, 0.10119540989398956, 0.032279451111597676, 0.009464079214792167, 0.06350228070680584, 0.019940244300024848, 0.018697010386469107, 0.010206040294308747, 0.008312517078593373, 0.03746636278395142, 0.04658640269190073, 0.048373453585164886, 0.015928824997640083, 0.09428831695445947, 0.0576487219493304, 0.013956540829635091, 0.005960129043419978, 0.062290512158402374, 0.07101777528545686, 0.09567856056881802, 0.015952251419158917, 0.02909415667610509, 0.020723760560421006, 0.02898940783260124, 0.02220705846723701, 0.011658820240492267, 0.0838140229295407, 0.016664804790967276, 0.04292341960327966, 0.03759805964572089, 0.07004272046365909, 0.05370706792122551, 0.009796473164377468, 0.05611422857535737, 0.061255122002746375, 0.007514211299297, 0.042378997031067095, 0.06905693800321647, 0.012351567175106277, 0.1096410131348031, 0.06931136149380888, 0.08049289935401507, 0.05735148289906127, 0.030633179271327596, 0.046273676079830954, 0.19812759783651146, 0.1007420060091785, 0.023484193686661974, 0.03383054145212684, 0.004430619085074535, 0.052554895103509934, 0.04180255099864943, 0.060964878648519516, 0.06376443949661084, 0.043350462402616224, 0.03596467997080513, 0.021859000536746213, 0.09079288451799325, 0.05338426506412881, 0.006635281565000436, 0.022990583209320903, 0.007130027316244585, 0.048570445871778896, 0.045226964567388804, 0.05536809789815119, 0.02786802693403193, 0.032597867239798815, 0.04632326681166887, 0.025387011135795286, 0.01042794160145734, 0.05766088808221476, 0.03322805663836854, 0.015833999728783965, 0.02771731073568974, 0.02246838605164417, 0.007797665910662285, 0.05823545117995568, 0.01007344522180834, 0.01994751480274967, 0.10614494287541934, 0.03382301989144512, 0.047605056781321764, 0.06249219312199524, 0.06170759629458189, 0.06063262719128813, 0.03727317029344184, 0.05755707222436156, 0.05712573429835694, 0.03520701759095703, 0.001365071555483155, 0.016843334139723862, 0.03412236240027206, 0.04393933241122535, 0.07838657737842628, 0.030923917956118072, 0.0684102534183434, 0.05850695339696748, 0.04200324469379016, 0.0275831881112286, 0.027670676720195582, 0.02419877078916345, 0.038034405160163126, 0.020703262017507638, 0.05292232181610806, 0.024688189616426826, 0.05780339400683131, 0.07467666002256529, 0.049856568287525854, 0.009088253086831952, 0.047134988076452694, 0.05272584182343312, 0.037999721842684915, 0.04700470256752201, 0.026721389265730977, 0.024889205615701418, 0.037096011585422924, 0.03691261035523244, 0.04943996474945119, 0.031083994545042515, 0.03492175129109195, 0.05167204640539629, 0.03834553721493908, 0.030008516540484767, 0.00901569309644401, 0.06105154114110129, 0.006588683172594756, 0.04431425015042935, 0.03840869525447488, 0.029367701283523014, 0.03104594230119671, 0.025301866865317737, 0.06664557382464409, 0.02095685599903975, 0.05306389136239886, 0.028236580014761006, 0.05316780560782977, 0.024563069455325603, 0.06662413890340499, 0.020841250595237528, 0.009962697280570865, 0.015037591303033488, 0.0744927159643599, 0.2100412342697382, 0.1298792835857187, 0.141759793939335, 0.06506458044584308, 0.06894579396716186, 0.07539974086518798, 0.09497125566537891, 0.10795885018472161, 0.13647961084331783, 0.12505209046815122, 0.15742244491619722, 0.09477433801761695, 0.07535849950675454, 0.11694309487938881, 0.16186834206538542, 0.11943562541689191, 0.14326772945267813, 0.09801611370806183, 0.0642693577600377, 0.22018378573868955, 0.11249246155577046, 0.11020181554236583, 0.05271020159125328, 0.14835835700588568, 0.1175962934004409, 0.1041456733697227, 0.17750868281083448, 0.14653193072548934, 0.08154810951756579, 0.19859003302242073, 0.15765109764678137, 0.15753931578780922, 0.05519491879801665, 0.12484410591423512, 0.15160332859626838, 0.13585657998919487, 0.1360942708062274, 0.07085118815302849, 0.19992952900273459, 0.08930196666291781, 0.15427169469850405, 0.0945926331249731, 0.11697143050176756, 0.11990238965622016, 0.1505247021892241, 0.12309439480304718, 0.08990631066262722, 0.1187031197228602, 0.14762140012213162, 0.11369081546685525, 0.06382805893995933, 0.080513017917318, 0.1638487550829138, 0.1250715372817857, 0.12063230334648065, 0.10831504714276109, 0.14810298356626714, 0.09171200091285364, 0.12583844470126287, 0.11986580304801464, 0.18489537787224564, 0.08570478111505508, 0.4219654032162258, 0.0807003750066672, 0.1808314145143543, 0.16133886761963367, 0.15567760568644318, 0.110483265082751, 0.13979045461331094, 0.18170542190117495, 0.1317589884357793, 0.12714514029877527, 0.12109814477818352, 0.22257364035717078, 0.358525418809482, 0.2526290640234947, 0.203501269487398, 0.13202713190444879, 0.11668548227420875, 0.2982468919030258, 0.14847369438835553, 0.1375475978212697, 0.13800969373966965, 0.09001459806625332, 0.25661551154085566, 0.1318593980478389, 0.15946665379617894, 0.15556970504777773, 0.11046970116772822, 0.09242909707661186, 0.11297194154134818, 0.21397472891424382, 0.16173198366803782, 0.19639220381421701, 0.1573637787784849, 0.1255266307187932, 0.12047360757631914, 0.1244059894233942, 0.19012924416788987, 0.15244369421686443, 0.1322241106203624, 0.1510958115437201, 0.09395109862089157, 0.11005493985222918, 0.1473718485129731, 0.06501319498888083, 0.12471631062882287, 0.11313593667000532, 0.19954922369548253, 0.16483284799116, 0.11959725245833397, 0.13319870403834752, 0.2284601894872529, 0.22088308392890862, 0.13923903634505613, 0.17157749964722566, 0.22573809698224068, 0.1483470390417746, 0.09508368213261877, 0.08375537036252872, 0.1264811802123274, 0.3318740560540131, 0.1163951778518302, 0.14190763314919813, 0.1546514436070408, 0.13999944339905465, 0.13240150681563786, 0.13500761054456234, 0.05276343944881644, 0.16842609803591455, 0.17070877126285008, 0.21234699125800813, 0.14345174814973558, 0.13919689932039805, 0.1472896100687129, 0.22389158606529236, 0.08787211695952074, 0.13653458575052874, 0.1543468628078699, 0.12151107404913221, 0.12661158107221127, 0.18962121142872743, 0.15724533370562963, 0.17403178795107774, 0.13996200183672564, 0.11762362479099206, 0.10489853511431388, 0.11998107257698264, 0.1454547428126846, 0.1087497506024582, 0.10260812658816576, 0.17617192811199597, 0.15470379936907971, 0.2265080442386014, 0.14008478953370027, 0.14243615764592374, 0.09851300490221807, 0.12552836776844092, 0.10306035660739456, 0.13258590549230576, 0.09503134672663041, 0.10035583815936532, 0.16910995276910917, 0.1588626762053796, 0.1206609375242676, 0.19052609215889657, 0.143513291275927, 0.0822270041597741, 0.08915113511362247, 0.10139498061367444, 0.12509042769670486, 0.17350414554987634, 0.154363785471235, 0.09852650096373898, 0.10581571089902095, 0.2725701225655419], [0.027721098657431345, 0.06387035202767168, 0.036251357623509, 0.044511761516332626, 0.021158564104033366, 0.04312895803845354, 0.012014573606263314, 0.05246868383671556, 0.0331835447411452, 0.021602415912119404, 0.016625035853524293, 0.05199947687132018, 0.01262208551634103, 0.05268211363415633, 0.03973340595673237, 0.1070012744250042, 0.056950136220880916, 0.005001475261191705, 0.014639917195641568, 0.04847472832937326, 0.01852619937354965, 0.024507904558309486, 0.0422532882408372, 0.04078443295189312, 0.05493973195552826, 0.020531348385182873, 0.021444824457700764, 0.057672640308737755, 0.0682735557534865, 0.06680994214756147, 0.016105015096919875, 0.04047620502699699, 0.010795459068114204, 0.07025823675628219, 0.04834815101431949, 0.01661783829331398, 0.030044587462076118, 0.04200771963223815, 0.02601559240637081, 0.0555710171881531, 0.022806152302239622, 0.032739240010934215, 0.08545674263898816, 0.02838183061352798, 0.037862050480076244, 0.0532627767617149, 0.013963265111669898, 0.014242711277412516, 0.04120363527908921, 0.05504529504105449, 0.01750545539627118, 0.008514293037088854, 0.01221925878365125, 0.03654129902965256, 0.06466530329946961, 0.07110846827604941, 0.006591435904348535, 0.057047078518995216, 0.05550969458584275, 0.07350975620959486, 0.09578948747366667, 0.026030184301946844, 0.020199035859799812, 0.060594561376741955, 0.018853614572435617, 0.038180453037577014, 0.05225611238607338, 0.02523693784938327, 0.006560252131229001, 0.017081657690661292, 0.039170683295066865, 0.031258479825087955, 0.014035208483359643, 0.056219825587634525, 0.033878401919667206, 0.025468691485002637, 0.067907316477171, 0.04824215366638132, 0.027909024019858668, 0.049597042213593207, 0.014414333139679261, 0.06724220288119145, 0.03120178483160479, 0.033276819557483704, 0.04014100194243448, 0.02718104076172624, 0.06496920556362186, 0.05566070255424295, 0.029996360585625683, 0.044894665612706115, 0.011243059782178273, 0.05655509991837399, 0.05361522142110126, 0.07595112520669188, 0.033641135187021325, 0.009765184218330043, 0.025880709822688783, 0.0395650105284793, 0.057131936108427386, 0.03820597952497857, 0.025454956239887645, 0.034707093345267434, 0.028855132537760904, 0.03353923958327089, 0.05803592795772212, 0.05868666339665651, 0.048814128153026104, 0.031592892416353734, 0.04553088379491653, 0.026648037933877537, 0.024901792440297346, 0.020027395337820053, 0.028495488621826683, 0.04202097142115235, 0.03401566955393978, 0.046736667664455514, 0.042572773061692715, 0.07808399825756039, 0.04183362450982843, 0.04985099412234766, 0.026469128605510508, 0.05928266141563654, 0.019453386942456876, 0.0033417660950882627, 0.06714280428630964, 0.09785412704305989, 0.017964684504217336, 0.04316210786678961, 0.011927716883032449, 0.03505784845245736, 0.014969478261524012, 0.011676717449777892, 0.016435602447018027, 0.04932093274380479, 0.0656376914786441, 0.004310713465591627, 0.0410051400374089, 0.03489754455430167, 0.026341589467067803, 0.05716112668492964, 0.06815381467874561, 0.023267807172877446, 0.010724599656116749, 0.059399389794894626, 0.024668559598337327, 0.03809304754914982, 0.07737338888858046, 0.09946374781429768, 0.04729974316433072, 0.03799707216343709, 0.025155846129304597, 0.027160625339352658, 0.04220023698040417, 0.061093399966401715, 0.05475750798359513, 0.06459342608494417, 0.06310081867767231, 0.03735113735975964, 0.03066029692334788, 0.022118738652872186, 0.02684794961740928, 0.008980691715675806, 0.04448267950543335, 0.023853237008942024, 0.052535234551344595, 0.020959941637037054, 0.06738634407520294, 0.010145923787994044, 0.03748155179034386, 0.05050964467227459, 0.03856941305899194, 0.023213873816920177, 0.05697244645229407, 0.04557015061644571, 0.027569710709420697, 0.009734721388667822, 0.028578782188040868, 0.030819942642535483, 0.004437721650382238, 0.05573097503344927, 0.01812817412428558, 0.03384780338300126, 0.03680461132898927, 0.03850622109270521, 0.01391623160868351, 0.017591490243960704, 0.02384855511731335, 0.03682764420019729, 0.013583622224229788, 0.09976585874600069, 0.014187598118691571, 0.04665273966799889, 0.04368169944999473, 0.006866510184149125, 0.041438740877700705, 0.049834946769156625, 0.06843398857329573, 0.05553405060033713, 0.03542354829343302, 0.06706296107066528, 0.026624411344528198, 0.04462290894506233, 0.013800601607986858, 0.08962087133633238, 0.033733066504022906, 0.04932229659919228, 0.07410224620252848, 0.02970047521271876, 0.0037147841482822385, 0.04692440473341516, 0.0563912337113704, 0.08497600736362593, 0.06543522341442959, 0.025168499111064842, 0.03738322867346661, 0.007340459685240473, 0.003152067635840337, 0.021894123205649, 0.022800803749955127, 0.021235608362725804, 0.010488104757054575, 0.0722322172618338, 0.046907186907316954, 0.04088785865211061, 0.02918603710298027, 0.06613949526633535, 0.019831358089244792, 0.0254678059968033, 0.04442734497466257, 0.03725047668974314, 0.031291911245456765, 0.06750638370535203, 0.009477941685223153, 0.030140193046203682, 0.04472934055541243, 0.01928202461983476, 0.08437810944659369, 0.030272487018789564, 0.021548584336414933, 0.04217840511617916, 0.006874879489519766, 0.029172948162470545, 0.058718710605587275, 0.016389051552063653, 0.03994328701602561, 0.007184304180555046, 0.01896359831360834, 0.06571264924215418, 0.018393679788070064, 0.029401115740516355, 0.019374882137136798, 0.017782876134983132, 0.02315412032684045, 0.04994956151183162, 0.03022184795034783, 0.04297597214047398, 0.06537558697164059, 0.06298548129520246, 0.07076839331005301, 0.03440315376168915, 0.03516080935618707, 0.05452203597607357, 0.011617176850060267, 0.037356775985764604, 0.025151167630351016, 0.009344053155343448, 0.08142938624535288, 0.07145176628338439, 0.08290146796831063, 0.05419011360832623, 0.07653304362403494, 0.040420018934777806, 0.038720037655106614, 0.05392723896407655, 0.01868864574602672, 0.046463255371366224, 0.03038323750453336, 0.003980690571812114, 0.032039504165628126, 0.03924296423792839, 0.05214374698698521, 0.03117930835911206, 0.050613650519933016, 0.04334466771355697, 0.03206104425979512, 0.00814690109941044, 0.03721512501527156, 0.023465981806761453, 0.005100054525038493, 0.06988919513033968, 0.09797617513686419, 0.01786315191670188, 0.020861479420480982, 0.04834827993597303, 0.017013788921758533, 0.02301226070682917, 0.03837345214560628, 0.013324493093283048, 0.03600780426391533, 0.05214581312611699, 0.012111370867517377, 0.0375650217756629, 0.025373767828568816, 0.05933863376932485, 0.012940137780138423, 0.013630828753645931, 0.013083687800514911, 0.02838741834940655, 0.02487076133755701, 0.04542308154382876, 0.10749539719628436, 0.0635845395071166, 0.029819395260087082, 0.028540563703115498, 0.036367933332387886, 0.05489605465637786, 0.03172275044822267, 0.049693573998021226, 0.047767606630389176, 0.051449151044445376, 0.020585561636835337, 0.013116993691905268, 0.074163830040821, 0.0486477547591286, 0.06034728285989591, 0.04313105471166117, 0.023541655424716215, 0.047795372283352275, 0.061432511412671635, 0.02024481152849538, 0.04639917791688016, 0.02752739896199533, 0.026315803440021615, 0.07363214357090847, 0.057087783834763935, 0.04225170386156865, 0.00611413359209629, 0.027389418865953172, 0.012992010934145322, 0.021351827840719904, 0.033608959056437016, 0.03926962048613599, 0.029334853403270245, 0.017756104535822357, 0.04664561505030308, 0.007194782457580524, 0.014809484793139356, 0.0631156853799309, 0.062061364097254615, 0.03561070182227662, 0.015913344221189618, 0.029320940042712858, 0.09670558438769408, 0.1539792732468673, 0.05822179905538048, 0.185700351106269, 0.11062776590032236, 0.18740343329097542, 0.12507326076073305, 0.1251898059355361, 0.0650043333215373, 0.12881592421659402, 0.1373127975634166, 0.09746624249964952, 0.06386679650417396, 0.21361080344234193, 0.11627327225037984, 0.138641871245844, 0.1257052889892033, 0.0795723580356155, 0.08289707784673997, 0.18849605109010423, 0.11467454875154154, 0.10157987462090594, 0.12514404553387845, 0.14061243193490164, 0.11963531827288014, 0.12504976987838745, 0.11400323334549155, 0.18592444408152783, 0.2130791712552309, 0.1819567241306816, 0.09757277928292751, 0.09361126792750188, 0.07251986861228943, 0.228671810988869, 0.15921833712075437, 0.17880198412707873, 0.10005521321935312, 0.08075337537697383, 0.1807110152606453, 0.1782831083983183, 0.11527672143919127, 0.13725381929959568, 0.11108387035450765, 0.12305788961904389, 0.09433200782431023, 0.14520897742893013, 0.07055144530854054, 0.14377418799059732, 0.11166327819228172, 0.16509502035166534, 0.11209199697311435, 0.1309615605111633, 0.21451280718403204, 0.19463226039494785, 0.13045970244067057, 0.10057505925319024, 0.09221421182155609, 0.13692496051745756, 0.10414608727608408, 0.2285309742603983, 0.2383915265755994, 0.10042595118284225, 0.08845883261944566, 0.1578660575406892, 0.14801117777824402, 0.12171099760702678, 0.15732162818312645, 0.17012432190988744, 0.12885738270623343, 0.16624166310897895, 0.20197430785213197, 0.12239878784332957, 0.12511619845671312, 0.1450670279030289, 0.12465444180582251, 0.27169910073280334, 0.1327917594462633, 0.2089849045234067, 0.10670499889446156, 0.18828057550958224, 0.18149080127477646, 0.1764795080359493, 0.2739493671272482, 0.15909709648362227, 0.11234264780900308, 0.11943907237478665, 0.11768978195531027, 0.14551144119884285, 0.11624480092099734, 0.1789912682558809, 0.1761793919972011, 0.14511962793767452, 0.13882750485624584, 0.21666621948991502, 0.09675264079123735, 0.12936156136648996, 0.15262087328093393, 0.1749979675348316, 0.10971431527286768, 0.20636352018586226, 0.09442812230970178, 0.18761402341936315, 0.09666257883821215, 0.13513419803764137, 0.11612047973488059, 0.10579712582486016, 0.2131264108632292, 0.09749891396079745, 0.19820003823510238, 0.15981060319713183, 0.15662982101951325, 0.09849169890263251, 0.09355651693684713, 0.14796838935996803, 0.16956766535128864, 0.18414324894547462, 0.1133453461474606, 0.17053284070321492, 0.09044246189296246, 0.12809966265090875, 0.09064252794321094, 0.12323709071746894, 0.17643564753234386, 0.10047587100416422, 0.13296224815504892, 0.2421677910855838, 0.17466380260884762, 0.10557854933930294, 0.11431132895605904, 0.1209057801003967, 0.09835185283528906, 0.057108119529272826, 0.13468082807958126, 0.10101631057581731, 0.1729380302131176, 0.09754371084272861, 0.14209657801049097, 0.1777848872755255, 0.08715675784541027, 0.19494175378765377, 0.15553921168403967, 0.12181121722928115, 0.08273308271808283, 0.14427767454513482, 0.10279005539736577, 0.22514245180147036, 0.1317681757999318, 0.319979690015316, 0.11058009202991213, 0.1356599676821913, 0.12217652691262108, 0.14810493774712086, 0.1313412958489997, 0.12093075018908296, 0.16176840742783888, 0.19481018584753784, 0.23702368140220642, 0.10986323335341044, 0.07170882248984915, 0.09968418348580599, 0.13600124365517072, 0.06968529535723583, 0.11623029384229865, 0.12137293789003577, 0.11751543916761875, 0.16203694444681915, 0.11950673588684627, 0.07612894209367888, 0.10589739294456584, 0.10016606548534972, 0.07695180151079382, 0.16569012270442077, 0.10927736586225884, 0.08245877136609384, 0.1183288533772741, 0.16685926568295273], [0.07651360359575067, 0.05497062565492732, 0.025611631672031114, 0.03904063527339271, 0.029331267345696688, 0.00731775929619159, 0.03073530557698437, 0.02696003851347736, 0.10698688269725867, 0.01632058058333184, 0.054145113165889464, 0.011601296586117573, 0.009614399318317217, 0.023416479284475957, 0.042652260046452284, 0.05005365896171757, 0.019086051832086275, 0.019624213222414255, 0.01278681939999972, 0.0261066653765738, 0.02781389680291925, 0.028651202230581214, 0.017044646998069117, 0.029469657955425124, 0.020273681497201324, 0.002719579805021307, 0.050614807422139814, 0.02799794264137745, 0.015193421959078737, 0.040780826538269005, 0.015817813275914108, 0.019075422581019144, 0.03374631150758692, 0.02850699657574296, 0.029930773390723125, 0.027697811335591332, 0.013863960663521928, 0.022320572286844254, 0.025488350340830426, 0.06561762041279248, 0.04947936049263392, 0.05721124328140702, 0.019319681617032205, 0.05200250313750335, 0.013356620030078505, 0.019957562210038304, 0.013468000705220869, 0.028196042636409402, 0.02357865254660802, 0.02402588345908693, 0.10431781091860362, 0.03237641715843763, 0.03412593149447015, 0.030054219266665832, 0.02579265633331878, 0.043342757637479475, 0.020704805684675063, 0.05235664752711143, 0.044974111885364564, 0.0363654159674687, 0.006278378930541554, 0.03463814061667238, 0.025887641057904278, 0.0019354435332518602, 0.026873627078852484, 0.06255389909659113, 0.052678144204297235, 0.05099846129970891, 0.09327381210667746, 0.014287402986415794, 0.08699269486325127, 0.03173474694735237, 0.015493040970925773, 0.013645915131616806, 0.024265550509361283, 0.027810446452349424, 0.005835399888123253, 0.02786187601408788, 0.015255046509472387, 0.020422375661187937, 0.07318363192358188, 0.028793528343417814, 0.038992252333887985, 0.054512458454285345, 0.04529142200148531, 0.054998048647705994, 0.09332035960895674, 0.04594828800431319, 0.058454448357224464, 0.03135421433086906, 0.052315626692559035, 0.07019471230783633, 0.07119872021887984, 0.03045397138755236, 0.04199041020391243, 0.07448956756187336, 0.05732450434671981, 0.04977335275283881, 0.059491433070174286, 0.05097473632278187, 0.03112183983570763, 0.05439327038558466, 0.03236480403159346, 0.037156682794115374, 0.01634862782832767, 0.027642856784430996, 0.03479641230244722, 0.04962108610197902, 0.06165195642305272, 0.02968306400414024, 0.045229441220206876, 0.052919319298650534, 0.015210940036922693, 0.01800860946864954, 0.05843106604048184, 0.03650255807276283, 0.06316586982991014, 0.020642908023936406, 0.06852354841040713, 0.028375635588807718, 0.030087006078766923, 0.05971071523215089, 0.02312461762422962, 0.07365517983479158, 0.07595529141170637, 0.04179797427994864, 0.018575595026569705, 0.026246776072574512, 0.0051111914051164475, 0.03446283430925437, 0.04311565196673785, 0.05241738998198083, 0.03416179546288081, 0.027368994961891855, 0.06747635853077684, 0.04556962475180626, 0.02476706761600716, 0.005826972907276026, 0.0826042289180415, 0.0674795408600143, 0.13907850853034429, 0.018000112513878515, 0.08096112244363342, 0.06750945746898651, 0.018943630724347064, 0.02394657289343221, 0.0605394168357764, 0.01588928676210344, 0.017423671570473483, 0.05358710292992847, 0.0372586835707937, 0.045060696346419196, 0.032852779275604656, 0.04855172848328948, 0.04394706092508776, 0.00831969258641558, 0.08689770674599068, 0.03115549517263259, 0.04925105381490929, 0.03489970229566097, 0.0251767280445035, 0.02400677421662424, 0.03872440063527652, 0.016749438463843296, 0.008099835366010666, 0.026616384275257587, 0.04176619169967515, 0.041403867570417266, 0.035143109770225625, 0.02276699404631342, 0.02551089466682502, 0.020356360989223634, 0.03626224132520812, 0.04630908542977912, 0.03554041916504502, 0.04887574931074466, 0.011903170878732843, 0.027627350562917333, 0.07183106057345867, 0.0436630940197834, 0.026833306831706847, 0.06517971426780735, 0.025693150869171535, 0.02867173809292061, 0.010614151118456252, 0.0674384216378842, 0.05502135293292148, 0.05052581416176898, 0.02045190041618688, 0.013385098992979952, 0.01549007068388164, 0.04569344721468432, 0.035983363432543616, 0.007594143572662557, 0.009552341353680407, 0.04714406348232712, 0.024207634152844548, 0.037602860280977826, 0.005706850580671536, 0.004640504385211638, 0.02601016582255917, 0.02238474303989538, 0.020941387096952115, 0.031183216720819473, 0.025698402730215873, 0.017619549363319362, 0.0022645758498193963, 0.030002128133284192, 0.03682773580242481, 0.03909564750002963, 0.041878258543355126, 0.060765022944126806, 0.06397135196519749, 0.022163532142128264, 0.09054370610309498, 0.034250398565615923, 0.05970309528389147, 0.05320214626512357, 0.027034180338627527, 0.032440314801143746, 0.016473510502172366, 0.030683373899332116, 0.01573761213304741, 0.08409640884825162, 0.03546952582629664, 0.026030866229640584, 0.06262017161186252, 0.02316976904070803, 0.07288186704473835, 0.04175124018053923, 0.028311663307249546, 0.03213099782754268, 0.031133419035800865, 0.04040439905864852, 0.07201843801885843, 0.013528291934302874, 0.16748212011797087, 0.04051347356289625, 0.036546924084957154, 0.08201988813068185, 0.02334922967877771, 0.03364038879850081, 0.006026013945561967, 0.052150780002453496, 0.023595980634646754, 0.045981634607804675, 0.02276314844909523, 0.032321720450584374, 0.014131544340801026, 0.10219637118279934, 0.07409198675304651, 0.019526376954412887, 0.044610406937343736, 0.08674178618405547, 0.03161114500835538, 0.03286715743264981, 0.02674379788472184, 0.011604173574596643, 0.035949986294976304, 0.03399082160155688, 0.1375615213598524, 0.024619153767291988, 0.036184918867158036, 0.019537759379350712, 0.04812829549025212, 0.06146314048341342, 0.05724650674632617, 0.07131049529250179, 0.053069265359746556, 0.002857792511349544, 0.11279727305684771, 0.059934163599142005, 0.028134150064683387, 0.023895597950156246, 0.06111380351441247, 0.02799010556191206, 0.009509995679504104, 0.018587574562323943, 0.039775149431079626, 0.03907197680590408, 0.02732555175732289, 0.06050219240465334, 0.00960423147106277, 0.038425916473248174, 0.10621165643845286, 0.07898859400302172, 0.021963391453027725, 0.08034294990024396, 0.0339775596346174, 0.013002166907036943, 0.043343208863266876, 0.054645152762532234, 0.01947680488228798, 0.07243385072797537, 0.012993301847018301, 0.005620900973943728, 0.05276035889983177, 0.049119533372244666, 0.043672138891581974, 0.07184412237256765, 0.060429874142365794, 0.01748048191490982, 0.05879383800285203, 0.07452992003943239, 0.03161258689527001, 0.018568848692146794, 0.03860076476952859, 0.04761058684172375, 0.008757185673208108, 0.03271652605118496, 0.03724491609526532, 0.03627089264669588, 0.08543660371963467, 0.023397453162553053, 0.04827839422172733, 0.08560788631439209, 0.0911916731191533, 0.0929161427276475, 0.05728016208325114, 0.06042915489524603, 0.008058425221991326, 0.020721858966031244, 0.030444516002067497, 0.03666043960090194, 0.04412693377318127, 0.04785082555775132, 0.020139546998377358, 0.04496931464278272, 0.033978058357856104, 0.02853915235027671, 0.03318871178531221, 0.024824721040204167, 0.05476138581122671, 0.027303726678448062, 0.011420539946162274, 0.06168538784342153, 0.0809111754809107, 0.03179184227649655, 0.004540546847108219, 0.021498922358400056, 0.013338568454076136, 0.0681208853742906, 0.04633791638272149, 0.07152563839086465, 0.042057344290827, 0.006079674615258617, 0.03708508377894759, 0.03976401127874851, 0.08507951109537057, 0.019054433796554804, 0.024633594688826373, 0.057523878291249275, 0.14630209734397276, 0.1217532567679882, 0.11295225045510701, 0.14610633999109268, 0.09179124023233141, 0.16201394210968698, 0.16771079998995575, 0.10360048405293908, 0.17806953271584852, 0.16561350253011498, 0.1414341242717845, 0.1205494406500033, 0.10696765980018036, 0.09226488481674876, 0.09039157855191401, 0.16761902134333337, 0.10737044497260026, 0.10465738376868622, 0.07046146477971758, 0.13632242142089776, 0.12970130385032722, 0.09946254680731467, 0.10668095161340066, 0.0908796623615282, 0.14899855479598045, 0.09070493280887604, 0.14682064737592423, 0.11637548676558904, 0.07716594716267926, 0.1267955047743661, 0.10994165843086583, 0.1591946291072028, 0.12841628066131047, 0.2019109326813902, 0.16097438574901649, 0.16046040904309067, 0.11033415701240301, 0.23924946625317844, 0.1936923808285168, 0.15249733919543879, 0.22718049958348274, 0.16387751139700413, 0.14651266033095972, 0.08878267702779599, 0.10659629758447409, 0.17916775521423134, 0.06841891831053154, 0.18904964067041874, 0.13674628867634706, 0.17639085065041268, 0.11721847153135709, 0.16133186513824121, 0.1206323711999825, 0.12093849905899592, 0.06482158348496471, 0.15060706276978764, 0.0766455718715276, 0.16549488103815488, 0.2324847706726619, 0.1128428570394005, 0.19066588394343853, 0.130726461697902, 0.15491729362734727, 0.11877108179032803, 0.08747127918260438, 0.2024287363248212, 0.16026780009269714, 0.1386106043521847, 0.15516113197164877, 0.14599109760352544, 0.16107190480189665, 0.12321316557271139, 0.10757039567189557, 0.169065264452781, 0.136191260601793, 0.1763164967830692, 0.20160730183124542, 0.21318840182253293, 0.11401012726128101, 0.14290096770439828, 0.2034727574459144, 0.0703542698174715, 0.12578754100416387, 0.19151929100709303, 0.23522911912628583, 0.17047299391457013, 0.247087902788605, 0.09950532844024045, 0.24183663885508264, 0.1680972528244768, 0.1529740643288408, 0.22685978322156838, 0.2078541394855295, 0.14367860954787048, 0.21410624257155828, 0.22002317649977549, 0.1794453031782593, 0.17853337925459656, 0.14081173124057905, 0.19266490239117826, 0.11334068461188249, 0.17675681172737054, 0.10486193493540798, 0.1267091001250914, 0.1702178783182587, 0.08874069606619221, 0.08729965732033763, 0.1730159396039588, 0.24852004594036511, 0.12457817446972642, 0.1001443387940526, 0.18510191036122187, 0.10545408566083227, 0.0660526699253491, 0.14365224167704582, 0.15916497712688787, 0.1458891545023237, 0.14122054858931474, 0.13541825993784837, 0.14138365483709744, 0.21396913778569016, 0.1425437190170799, 0.1386644257498639, 0.19743148876088007, 0.26949095779231613, 0.08882274452064719, 0.19397836976817676, 0.2103029452264309, 0.08989317422466618, 0.12135958432086877, 0.15530266080583843, 0.10427171124943665, 0.13050593781684125, 0.1364889746265752, 0.15496226692838327, 0.07998284458049706, 0.208327499085239, 0.09954281071467058, 0.10052221494593791, 0.1841688161449773, 0.23641411268285342, 0.12237309850752354, 0.14974331483244896, 0.1763020846992731, 0.05991365827087845, 0.11624128610960074, 0.11826137985501971, 0.14277381024190358, 0.13137173492993626, 0.13918696556772503, 0.14944998414388724, 0.16225433349609375, 0.1313637282167162, 0.11877142105783735, 0.15624332747289113, 0.12945366570992128, 0.21130682421582087, 0.07368427541639123, 0.08317601680755615, 0.09249831443386418, 0.19119371633444512, 0.18345817284924643, 0.14952482655644417, 0.08601799966501338, 0.08441819729549543, 0.12636288441717625, 0.10952615072684628, 0.1337720254170043, 0.15963556830372128, 0.09020358363964728, 0.14507777589772428, 0.17604899113731726, 0.15298448662672723, 0.07310022639908961, 0.07626549048083169, 0.09478547277727298], [0.0610195075028709, 0.04799795909119504, 0.005458394381483751, 0.04811621417424508, 0.011217034571538014, 0.028851950208523443, 0.021673472099272267, 0.033046809756862264, 0.06880666714693819, 0.01593350519293121, 0.03572992381772824, 0.017935921404776827, 0.05134682117828301, 0.016855279748727168, 0.04741122986056975, 0.014476466591336896, 0.016880356706678867, 0.0809869339157428, 0.023706542826922875, 0.09612952851291214, 0.056416166480630636, 0.028002802648448517, 0.012645422031969895, 0.05408380413427949, 0.02390422552291836, 0.028065351702805077, 0.03948416986635753, 0.04869429886873279, 0.03822347555043442, 0.0014853831297451897, 0.06189573369920254, 0.01475616211869887, 0.04689103438119803, 0.03766995382362178, 0.03312798968649336, 0.031121371646544764, 0.05773670079984835, 0.01609365811704525, 0.06955414810883147, 0.061711423232087066, 0.00798056332860142, 0.05866385783467974, 0.036663682998291085, 0.06151913319315229, 0.0449692230405552, 0.022571793092148643, 0.05420281917655042, 0.05741759256592818, 0.048970092819737535, 0.04670938716403075, 0.028263728200857128, 0.0261749429628253, 0.05380313830184085, 0.02967112518048712, 0.03029288038877504, 0.04817910079977342, 0.030165868811309338, 0.05082428136042186, 0.07761925605258771, 0.03670642052644065, 0.030652860179543495, 0.0013400908646872267, 0.06467681125338588, 0.030122208475534405, 0.1281727680138179, 0.07084654018815074, 0.02387871769522982, 0.05339746257024152, 0.019074708422912017, 0.05454887203606112, 0.0219831079843321, 0.03725260389702661, 0.029513440427503417, 0.014967956646744694, 0.060764147633952756, 0.078722879689719, 0.035950471447514634, 0.04809098284957664, 0.03953540265294058, 0.03448759065940976, 0.046846295174743445, 0.02056109027138778, 0.03632986412516662, 0.09295380820653268, 0.029899031522550752, 0.09403029044291802, 0.05745281531874623, 0.06387355471295969, 0.024430037575906942, 0.07170557230710983, 0.0615973954222032, 0.034812622504042726, 0.04695385993857469, 0.021787820516952446, 0.057076146959194114, 0.034328769360269816, 0.02507296816578933, 0.026579692494124174, 0.03144378434600575, 0.024069442014609064, 0.02596069044167442, 0.06318503165883677, 0.032801254718963585, 0.022528353280254772, 0.042337901557662656, 0.06038738427949803, 0.06785840088767664, 0.03014949236863426, 0.04646180330642632, 0.05113519967666694, 0.011521265925174313, 0.028289327630773187, 0.027040480536275675, 0.04436812922358513, 0.047826255804726055, 0.07968322387231247, 0.03280859986054046, 0.03410354323152985, 0.0671885646879673, 0.034268902215574465, 0.017784584346892576, 0.08898401872387954, 0.029697476087936332, 0.0414818651708109, 0.05836967897734471, 0.03712897142395377, 0.04134451611233609, 0.02482840887803052, 0.05544264175529991, 0.03984431250553046, 0.042660402466676066, 0.047179981733539274, 0.031582738139799664, 0.028140736943376914, 0.029885844194463322, 0.020367390575951765, 0.012792212905229201, 0.023282412639153854, 0.011312934470229914, 0.027107448549941182, 0.02762991881796292, 0.028344317805022, 0.019394254311919212, 0.014386296072708709, 0.0069878500570277014, 0.01818957136544798, 0.019706158200278878, 0.023511801580233232, 0.024888993573508093, 0.017544776500601853, 0.07825445982494525, 0.04295455078993525, 0.025419855623372963, 0.016856998138661896, 0.026231653223346387, 0.03191488103142806, 0.03171332898948874, 0.048012808830078156, 0.06265314841376883, 0.06260375784976141, 0.06836021146071808, 0.018721871909552386, 0.05443449478064265, 0.013728286738374403, 0.020375636472765888, 0.0169690734640296, 0.023890542864267315, 0.06728133399571691, 0.01942482401084687, 0.035007083855037174, 0.01449989470919328, 0.012473220870430981, 0.019857352765809213, 0.005770878417284361, 0.038729543930717876, 0.02022995500426207, 0.02638147205912641, 0.03824667466272201, 0.014280938244025623, 0.03689940267109445, 0.02309880275944514, 0.049265041814318726, 0.015251166985503264, 0.021182236494496465, 0.046813498184617074, 0.03258809972820537, 0.04262167168781161, 0.07662408945283719, 0.022159459235678827, 0.009018166356586983, 0.016664073669484684, 0.02128156553953886, 0.04210122515048299, 0.02309365607132869, 0.03114088631368109, 0.01976382010616362, 0.044689988917005916, 0.02868854201265744, 0.012394955248704978, 0.03130868463111775, 0.062028231232294014, 0.044914536510727236, 0.035156565119645426, 0.021990763555680002, 0.025309817599398748, 0.06081064085343054, 0.05003441910126379, 0.04122669189902289, 0.04165874228679708, 0.0085194906153317, 0.024814090092799494, 0.0064810166285107175, 0.041665642987936735, 0.07921538076230458, 0.030364075675606728, 0.07065233668046338, 0.015145015270848359, 0.04529101148779903, 0.05146401774670396, 0.03135762057666268, 0.032239247911742756, 0.014507567243916648, 0.018750402610749006, 0.047444993763097694, 0.018420989126233116, 0.0869578385193433, 0.017547246368069733, 0.029866478805031096, 0.06569880034242358, 0.006083027426419514, 0.02490639121138624, 0.02680700342170894, 0.053482381227825365, 0.004945959222303438, 0.06102910198803459, 0.021631017859492983, 0.041473624363009415, 0.0429721452029688, 0.008068332681432366, 0.016187675929229175, 0.09559828987611191, 0.020818651986441443, 0.011774781027010508, 0.06151458700852735, 0.06640841905027628, 0.04545842982562525, 0.036604100838303566, 0.019193484281588877, 0.06275876917477165, 0.0578558108370219, 0.03291256160342267, 0.07820029237440654, 0.05581578851810523, 0.04528444326881852, 0.018258252680035572, 0.01726287743076682, 0.04892279214358755, 0.04638224507548979, 0.026129757619595954, 0.023037430963345935, 0.07484304359448807, 0.02239168106046106, 0.005473708916854645, 0.046547838154115846, 0.042105591523328, 0.056549118632184606, 0.0140690037681322, 0.03447329392656684, 0.041949209557580094, 0.017798051570675204, 0.05466186847271664, 0.04470969357394746, 0.026737806420507174, 0.0539023638702929, 0.012946700061937528, 0.024099246665303196, 0.024432327631594877, 0.10015976868037667, 0.029270331508346965, 0.024563900660723448, 0.013459380765977715, 0.058325329928525856, 0.10824151430279016, 0.010514682973735034, 0.023028845799022486, 0.03276843737278666, 0.014082525274716318, 0.016031538236087987, 0.02739213639870286, 0.07541451935789414, 0.025264367627512132, 0.02680444873736373, 0.0834697342610785, 0.008502947931577052, 0.04344732666920338, 0.018550312811774865, 0.04292659514716693, 0.07470876829964773, 0.06828431731888226, 0.03851891987557922, 0.030970031195985417, 0.022623858780467083, 0.0200144438006516, 0.01241142159727003, 0.02345417020842433, 0.02144273117716823, 0.025949168917057768, 0.04886727440836174, 0.055452745141727586, 0.022626698449520127, 0.034194504243454764, 0.04311482076134, 0.031999708086784394, 0.025381806772202253, 0.013275209398541068, 0.028083304043060968, 0.05303921643644571, 0.01983307139016688, 0.05077447349737797, 0.018096359313598702, 0.036851576130305014, 0.0654811059523906, 0.08434072216706616, 0.0220388581178018, 0.014696600314761912, 0.012687733779395265, 0.06123186182230711, 0.03144210497183459, 0.03209391588877354, 0.03469692210533789, 0.013190368772484362, 0.06022053251841238, 0.024920397870508686, 0.08544853236526251, 0.018095217678429823, 0.0537202789980386, 0.0037774807840053526, 0.04033982966627393, 0.02444791018829814, 0.02747423743962177, 0.04479961981996894, 0.0777224273021732, 0.018733678418876867, 0.042566995336008925, 0.054451831350369115, 0.028381460811942816, 0.01845187773661954, 0.026053860085085034, 0.05129342386499047, 0.04104580803375159, 0.013541802414692938, 0.013017729107689644, 0.14932714216411114, 0.09703569845961672, 0.09501286343272243, 0.1589551062456199, 0.15239245125225612, 0.08998643886297941, 0.15504196765167372, 0.135826385180865, 0.1754608912659543, 0.0850622763058969, 0.11718796459691865, 0.09476076731724398, 0.12249364703893661, 0.06761220802686044, 0.13261034632367746, 0.09524367390466587, 0.18866968820137636, 0.16263818075614317, 0.13918149657547474, 0.1646871529519558, 0.1297192850283214, 0.1316999558891569, 0.07694534185741629, 0.11226965779704706, 0.1109053206497005, 0.1054384047165513, 0.11521144637039729, 0.09549971230860267, 0.1206314212509564, 0.10216833411582879, 0.127950927774821, 0.11758327909878322, 0.14850671190236295, 0.08279755033020463, 0.06416737394673483, 0.06470253451594285, 0.1100900743954948, 0.2202231679111719, 0.1625044279332672, 0.11264019898538079, 0.09458702842571906, 0.12292522245219775, 0.14112483443958418, 0.17170530850333826, 0.15666906748499188, 0.14157578881297792, 0.1331778865839754, 0.10785510896572045, 0.09663287257509572, 0.13419203859354767, 0.12025270371564797, 0.09920188757990088, 0.13762748853436538, 0.1054471917450428, 0.10582534609628574, 0.09434597207499401, 0.10940699319222144, 0.09060381073504686, 0.15604444885892527, 0.14234382260058606, 0.19085869645433767, 0.11330460011959076, 0.12201484558837754, 0.10228124912828207, 0.22340116809521401, 0.13711596812520707, 0.08450006933084556, 0.15244917677981512, 0.13059680722653866, 0.15328727609344892, 0.1378694541220154, 0.127707143713321, 0.09335534487451826, 0.14014673978090286, 0.08921538559453827, 0.14153214544057846, 0.13124270471079008, 0.16909205301531724, 0.08447165906961475, 0.07296545577368566, 0.11216173680233103, 0.1280778002526079, 0.1156110085014786, 0.19792816282383033, 0.16814563237130642, 0.16679599907781395, 0.13622338244957582, 0.15925453017864907, 0.19849540452872003, 0.17029379281614507, 0.17351618276110717, 0.09486064088663884, 0.14582025605653012, 0.0806767348466175, 0.15817200898059777, 0.1295387947133609, 0.07795905281922647, 0.11942854151129723, 0.11317272005336625, 0.07598832249641418, 0.11594989603119236, 0.21142379008233547, 0.17322667901005062, 0.1852331254631281, 0.18775659719748156, 0.1579971369355917, 0.17656531557440758, 0.1767517634268318, 0.12688591278025083, 0.15162456674235208, 0.19959655829838344, 0.1226718710469348, 0.12449525749044758, 0.1214262843132019, 0.13468553711261066, 0.1620328732367073, 0.10653319382773978, 0.1080712562959109, 0.2089416411306177, 0.18324550640370163, 0.15578013232776097, 0.20794004201889038, 0.14163653126784734, 0.0837873157912067, 0.15108605421015195, 0.14183809688048704, 0.13273449109068938, 0.12336293182202748, 0.1761659841452326, 0.08127875147121293, 0.14792812509196146, 0.1441996565886906, 0.07637641738568034, 0.12801591785890715, 0.06088770886084863, 0.1498797003711973, 0.1582250568483557, 0.1374444333570344, 0.06796082574874163, 0.13512743982885564, 0.09128717013767787, 0.09643087270004408, 0.12279011255928449, 0.08860679396561214, 0.10678745446992771, 0.12850233247237547, 0.1449478907244546, 0.10846091181571994, 0.08955071760075432, 0.10481996075915438, 0.13829671405255795, 0.1085709769810949, 0.1000207911378571, 0.13685405360800879, 0.1022543723561934, 0.09418534926537957, 0.18770690129271575, 0.13939561508595943, 0.09531820419111423, 0.1014661860785314, 0.14043483217912062, 0.13032601747129643, 0.14965165832212993, 0.08837283509118216, 0.10062957275658846, 0.1222703547349998, 0.11882799730769225, 0.17261151916214398, 0.13600574912769453, 0.1398270819336176, 0.04999077912153942, 0.13820374118430273, 0.10619679652154446, 0.22590398522359983, 0.11952771618962288, 0.060249967367521355], [0.023796438538868512, 0.03849374622638736, 0.1038637352841241, 0.05652736479948674, 0.04562050470017961, 0.016303790234295384, 0.03639027409787689, 0.003523352668188246, 0.031936461837696176, 0.05597964454708355, 0.049981561223311086, 0.005990246668391461, 0.05531966067584498, 0.014372574398294091, 0.06493244932166167, 0.008251459953109068, 0.005772652786358127, 0.060301054269075394, 0.029334402177482843, 0.028434379758047204, 0.049940665917737145, 0.0395976955603276, 0.05390902369150093, 0.017390745658693568, 0.01672420205016221, 0.04100901447236538, 0.02135747155573751, 0.003670781576407275, 0.0315589724507715, 0.00864930623876197, 0.02945167338475585, 0.02684961711721761, 0.040175091541771374, 0.04152721166610718, 0.020804563903116753, 0.014389690444139498, 0.013983886639055396, 0.032516677132142444, 0.10492429908897195, 0.029110414375151907, 0.015369047177955508, 0.029704939973141466, 0.04987249011173844, 0.03401258221960493, 0.021616388644490923, 0.023208923903959136, 0.037831614791814766, 0.027486634274412478, 0.014096707504774843, 0.01768840879334935, 0.047667743239019594, 0.04048212863770979, 0.04165152267419866, 0.01578360832562404, 0.028305473371541927, 0.06130946587238993, 0.023747363493644764, 0.019613641646823714, 0.07356318405696324, 0.062191961732293875, 0.021755951423464075, 0.017818158259615302, 0.06433096195438079, 0.016168210455881696, 0.033858256214963536, 0.07074489564235721, 0.02620440664967256, 0.026228250370227864, 0.021393781660922935, 0.030461112968623638, 0.027613689956654395, 0.09520788796778236, 0.03728648993585791, 0.016507008079705492, 0.027509439836389253, 0.06644489030752863, 0.02578726876527071, 0.04650924986760531, 0.03135194802390678, 0.0243391155797456, 0.032100080379417965, 0.004831855925398746, 0.039790823590010405, 0.035385411232709885, 0.019135847820767334, 0.026136946698118533, 0.04755723024053233, 0.06767765272940908, 0.07049422445041792, 0.008588789396786263, 0.056147751597953696, 0.03708187770098448, 0.07570433523505926, 0.07338288373180799, 0.08619762145514999, 0.0824924267030188, 0.02586823495637093, 0.032066533608095985, 0.04400320630520582, 0.03422197473368474, 0.013779356676552976, 0.0789392034390143, 0.03392356860318354, 0.046465073845216205, 0.041377696474747996, 0.04686593197818313, 0.08493212650396995, 0.04018483191196408, 0.06896584467696291, 0.014377992500417998, 0.07647791265376977, 0.02336842713079282, 0.03446085298699992, 0.04587246171597924, 0.042651103144245486, 0.045685060521853824, 0.012557320196979811, 0.032865050581416914, 0.031982201883303266, 0.07915559504181147, 0.04740105862064021, 0.09679779051137821, 0.04565207693459732, 0.0720707598541464, 0.06058412550815514, 0.030271679562117373, 0.026843810553795526, 0.1506473948912961, 0.025119917700067163, 0.02601985360628792, 0.04397046020520585, 0.03719923033245972, 0.03947538283786603, 0.023488836562527076, 0.02107070230080613, 0.008570772595703602, 0.0411747229019446, 0.015395929039056813, 0.05765657938484635, 0.07055624255112239, 0.04203385340848139, 0.030785120225378444, 0.045769935074661455, 0.046996801027229855, 0.026513428460540514, 0.03123779807771955, 0.03815239222188081, 0.038587584226791344, 0.054208705467837195, 0.007404754270932504, 0.05704519897699356, 0.04202711216307112, 0.04234087014836924, 0.11117157100566796, 0.045787200398210964, 0.030986672267317772, 0.01784155753973339, 0.025396749809650437, 0.055417213655476055, 0.00729234646340566, 0.037923356119011126, 0.04356532051627125, 0.013191216941257673, 0.006400082243739494, 0.03351088699751666, 0.041596367955207825, 0.010934745344067258, 0.02413177733043475, 0.05834917364908116, 0.030614970784102167, 0.050334959224398644, 0.036493160362754545, 0.027294298434363942, 0.022739201251949583, 0.009802002376610679, 0.023244689484792094, 0.02179965077500258, 0.028048013436741064, 0.09803163180393831, 0.04351624207837241, 0.018961214959355335, 0.01827975206210145, 0.021451781137979457, 0.010576222707251353, 0.006085816629430545, 0.04696785133065922, 0.023140076348291974, 0.009941335301846266, 0.1026887840458325, 0.08817330508359841, 0.016670718223654797, 0.054090382531285286, 0.005923174329966838, 0.05193032058221953, 0.05355282334078636, 0.07474988073642765, 0.05520069991637554, 0.0688006824680737, 0.05999158801777022, 0.023706110260848488, 0.02626828902534076, 0.019779049824657183, 0.021353167947381735, 0.0072192385559901595, 0.05597023665904999, 0.04600644184808646, 0.05549555052337902, 0.03608117764815688, 0.005571746624939675, 0.022740244499540756, 0.06014148997409003, 0.030426850342856984, 0.035436820438397784, 0.04122567409649491, 0.0743463220340865, 0.06128762383013964, 0.04634050499381764, 0.03932731971144676, 0.042834677400865724, 0.04283826345843928, 0.023231079768655554, 0.023057235704202737, 0.0618194460070559, 0.021798356469454508, 0.03324847036440458, 0.034336589476359744, 0.019623543169083338, 0.06631235884768621, 0.02823614066333643, 0.03708255284332803, 0.03791396180167794, 0.07679420496736254, 0.03788864566013217, 0.006369035449876849, 0.0519271755724081, 0.05506483006424137, 0.00513213947747967, 0.03997177191610847, 0.050628988804029565, 0.02978628614385213, 0.02945539854200823, 0.03524394007399678, 0.03067343675398401, 0.03573665827778833, 0.05230905168822833, 0.02161668211088649, 0.04531410542715873, 0.05956048757902213, 0.08569923748395272, 0.03537453770903604, 0.04474290107776012, 0.012827042955905199, 0.06038134531783206, 0.09304688285504069, 0.04756771021389535, 0.02318805386312306, 0.045069150892751556, 0.03051246449883495, 0.032147048573408804, 0.02506900891395552, 0.03590229885386569, 0.0329307734833232, 0.11554025086973395, 0.05403700218136821, 0.06281343874122415, 0.12274530210665294, 0.04880156507715583, 0.09986875858157873, 0.05187917261251381, 0.009227425708169383, 0.05036368839708822, 0.07785751683903591, 0.038759494466441016, 0.029519971327057908, 0.03617618612146803, 0.021107348280825784, 0.028786851558834314, 0.046057806948998144, 0.021826556384829537, 0.06350658261882407, 0.03178413072600961, 0.010719530151358672, 0.03495108096727303, 0.0160377061194075, 0.08129196933337621, 0.03081734724608915, 0.0721081674897245, 0.03239741103191461, 0.049941995846373696, 0.004331324390867459, 0.025782335815685134, 0.062270760004009516, 0.02728825438368533, 0.04124607425183058, 0.02358653033817453, 0.056081950664520264, 0.02677954819851688, 0.034247111063450575, 0.030593054102999822, 0.052951179910451174, 0.032938407002282996, 0.00977433511122529, 0.049582932077880414, 0.04415702001590814, 0.04633813690660255, 0.03350372166771974, 0.0338186636966254, 0.06184778841478484, 0.055180130127285204, 0.04221045911046011, 0.019502787684489573, 0.018997864332050085, 0.0518707452075822, 0.0340192759675639, 0.05348449147173336, 0.05025142138557775, 0.025238656239317994, 0.019005433390183107, 0.034687972228441916, 0.050318107807210515, 0.042108784030590735, 0.01920263941532799, 0.020685384316103797, 0.002932776356049414, 0.011660283331626227, 0.052293757508907995, 0.022322322907192365, 0.01742114911654166, 0.057196301940296373, 0.020625674930800284, 0.022882911576224223, 0.031249309424310923, 0.02657800803094038, 0.01309700489842466, 0.03974598599597812, 0.010887754249519535, 0.024644062787826573, 0.0157017464682992, 0.013899424296271588, 0.04141150787472725, 0.028218061097764542, 0.05452285361077104, 0.04727336511548076, 0.013779568718746305, 0.03668409672432712, 0.01620645777854536, 0.031101188622415066, 0.021000406072874154, 0.06352212785610131, 0.06485639233142138, 0.028926521207072904, 0.025255204012085284, 0.09386240052325384, 0.08088986269597497, 0.16185957539294446, 0.11661173908838204, 0.0942259935129966, 0.19647669499473913, 0.09309243969619274, 0.15673595746713026, 0.0987908649923546, 0.15466554356472834, 0.18656298624617712, 0.15833165469978536, 0.18627471742885454, 0.16618999945265905, 0.15145102462598256, 0.17323810553976468, 0.07376187946647406, 0.15415615375552857, 0.13680576905608177, 0.10228147983018841, 0.19250916503369808, 0.2188071331807545, 0.1417360994964838, 0.14175277788724217, 0.2034550341112273, 0.08080465905368328, 0.10440707898565701, 0.09229611099830695, 0.15793169901839324, 0.10359452651547534, 0.1302844097039529, 0.11221452682678189, 0.053928877626146586, 0.10737165276493345, 0.11563616857997008, 0.10939540381410293, 0.09989902124341045, 0.11411596515348979, 0.2522921578160354, 0.1915067516799484, 0.11917742927159582, 0.14114645256527833, 0.16723062789865903, 0.11371601625744786, 0.1300622709095478, 0.11376575287431479, 0.17700753041676112, 0.0800510441352214, 0.12666977223541054, 0.08335788454860449, 0.15626922036920274, 0.15268902533820697, 0.10423966404050589, 0.11488954935755048, 0.13405646729682172, 0.2447917674268995, 0.1956400613167456, 0.06311474221625499, 0.277127136609384, 0.1360377081270729, 0.13791737226503237, 0.08905932254024915, 0.31340346432157923, 0.09470986362014498, 0.07862458710691758, 0.22678152099251747, 0.13199148167456898, 0.0967317351273128, 0.1273646056652069, 0.11954235897532531, 0.15403035336307117, 0.21860860740499838, 0.13482025345521315, 0.2070048986268895, 0.1270176571394716, 0.1539397146552801, 0.12694437535745756, 0.18313155323266983, 0.2359260017318385, 0.08158483861812524, 0.11412836877363068, 0.15451850502618722, 0.1109356443796839, 0.18161263902272495, 0.08087456173130445, 0.10353406904531376, 0.1969026249966451, 0.15572335251740047, 0.21002389091466153, 0.1907964747931276, 0.16487147020442144, 0.24258585008127348, 0.18783582294625895, 0.19630464565541061, 0.21683117135294847, 0.1579507387110165, 0.1360424171601023, 0.09533875701682908, 0.11780564859509468, 0.10327959805727005, 0.09445653257093259, 0.14480801751571043, 0.09892144905669348, 0.11314227418707949, 0.17278568553073065, 0.1614927729325635, 0.18814334858741077, 0.11455893995506422, 0.2823341872010912, 0.13193236770374434, 0.13087800570896693, 0.05281926591747573, 0.1348208777074303, 0.14332127943634987, 0.1888842816863741, 0.13721773480730398, 0.06130952015519142, 0.10875152157885687, 0.1269914928291525, 0.12487094875957284, 0.07495609431394509, 0.15393750263111933, 0.1256102126623903, 0.15555930989129202, 0.19299951515027455, 0.09643556816237313, 0.129509726273162, 0.22159447361315998, 0.14105764590203762, 0.11083735179688249, 0.0740096533138837, 0.1343747273619686, 0.11788216020379748, 0.10154133383184671, 0.07260043107505355, 0.061925697805626054, 0.11916166011776243, 0.15582511919949735, 0.15165392016725882, 0.14077369256743363, 0.07121488970837422, 0.10822043221976076, 0.07533098491174833, 0.2004669558789049, 0.13366635037320002, 0.06769276370427438, 0.09734675248286553, 0.1286351489169257, 0.08588193303772382, 0.1219951816435371, 0.15030759812465735, 0.11588538092161928, 0.17560609775994504, 0.2075967847236565, 0.15765271256012575, 0.14388810044952802, 0.10852759145200253, 0.15508175694516727, 0.10317171777465514, 0.06142711027392319, 0.12867090771240847, 0.1213118697383574, 0.10386689047196082, 0.1588106732815504, 0.12440516161067144, 0.07918703156922545, 0.08466967594410692, 0.11582417706293718, 0.19513546196477755, 0.08762698939868382, 0.13847051401223454, 0.16185620985925198, 0.12371525434511048, 0.1971791008753436, 0.11429888462381703, 0.07124388350972108], [0.039736045457954915, 0.02685227697449071, 0.040259168815932105, 0.06650909329099314, 0.0156304341341768, 0.01712259031566126, 0.031405579431780746, 0.01028796237161649, 0.09990082614656005, 0.013000337406992912, 0.06809791696390935, 0.030145305807569196, 0.05359678562464459, 0.012971889826336076, 0.034203335376722474, 0.012728110853848713, 0.03639134957588144, 0.028810026922396252, 0.026440933779148117, 0.049221951447959454, 0.03235615271010569, 0.04299734260088631, 0.013337105362942176, 0.02136329677887261, 0.031133106909692287, 0.019746257923543453, 0.013407510156477136, 0.035087062777685266, 0.04384044611028262, 0.029241982315267836, 0.032407833329801045, 0.0238568128884903, 0.028390938249815787, 0.05812862262661968, 0.034919535874256065, 0.06976911478808948, 0.03168759894158159, 0.027265450518046106, 0.04235367410417114, 0.05988990275987557, 0.038209697896880765, 0.012543596826227648, 0.007343750580080918, 0.10861088162554161, 0.010026119948763932, 0.042083739303052425, 0.024250342843255827, 0.005860008232827697, 0.06897884540792022, 0.04301342048815318, 0.0604874546240483, 0.005485651133182857, 0.02938140429822462, 0.06088357658258506, 0.04022513689207179, 0.028912879260522977, 0.031826423813721964, 0.037857487332075834, 0.08436056931636163, 0.12323000681187425, 0.05628980290410774, 0.014407825988850423, 0.025840786518529058, 0.04824681180928435, 0.03967999507273946, 0.04769757503111448, 0.05616733072591679, 0.02249822802176433, 0.005996505729854107, 0.03803259686433843, 0.005996634227423263, 0.056068335859371085, 0.04630083105127726, 0.05237179921407785, 0.041220944707414935, 0.08908849276070084, 0.03747298189305833, 0.027361637945952158, 0.05248853098601103, 0.04752426700932639, 0.013851136351669473, 0.009405235809806203, 0.031997129653713534, 0.044609266998512406, 0.019497323781251907, 0.022079531203157136, 0.04657160384314401, 0.017137258546426892, 0.03342279279604554, 0.041581141629389355, 0.0463775699692113, 0.024513451582086936, 0.022639005378420864, 0.014918109767937233, 0.019744775324527706, 0.02457444679125079, 0.024406770610117486, 0.05307016781132136, 0.08156008566064493, 0.04435088425608618, 0.02214923540928534, 0.08976943657866546, 0.055870498796658855, 0.020828453424785818, 0.02354281402326056, 0.029384274501353502, 0.017578877974301577, 0.030121614757393087, 0.07911442832223006, 0.08989501305456672, 0.06339262266244207, 0.03912605265421527, 0.05330452362873724, 0.03310248016246727, 0.05425601292933736, 0.03872027174968805, 0.026335526756676178, 0.03359605332038232, 0.04820174690602081, 0.019329184499968375, 0.027448943350464106, 0.04728919533746583, 0.0181518583891115, 0.05124945818845715, 0.02115347339505596, 0.013313248919855272, 0.021894021425396204, 0.018090941211474792, 0.07324949731784207, 0.004505706194322556, 0.011019753059372306, 0.014725088607519865, 0.017776162030973604, 0.055697177204170396, 0.035925494573478184, 0.049910732345389466, 0.017872858360143642, 0.02971242760707225, 0.014966394319864256, 0.04110061330720782, 0.019518838430355703, 0.006485846101505948, 0.034303643208529265, 0.05309134488925338, 0.028000933284472142, 0.08228246761219841, 0.06744215358048677, 0.037200868994529755, 0.001718336606115502, 0.024953281373849938, 0.02701539679297379, 0.028185625427535603, 0.0509313474010144, 0.05004649702459574, 0.129574892776353, 0.05721644085964986, 0.025763133274657384, 0.03791438927873969, 0.07982229640973465, 0.02234583075291344, 0.03993103267358882, 0.017734125090230788, 0.02673690566526992, 0.026420609959002053, 0.07153643388301134, 0.018699035813499774, 0.09392141949917589, 0.03740171536004969, 0.03621168028829353, 0.037675796010132344, 0.03865969553589821, 0.02676539565436542, 0.03789513584758554, 0.0616566858121327, 0.033817075924681764, 0.055311463972819705, 0.03162807784974575, 0.021274423958467584, 0.015181240559156452, 0.11747885255941323, 0.05496724994320955, 0.06775748237435307, 0.07504019872950655, 0.003308989248970257, 0.06512299552559853, 0.028768045960792472, 0.026957339640440683, 0.04313205215813858, 0.020582750805520585, 0.04875831864774227, 0.029037407399820428, 0.03459661766620619, 0.0029298103098491473, 0.03981697093695402, 0.054923223198524544, 0.04387934313022664, 0.08434747359050171, 0.020759721220071827, 0.013576259271108677, 0.027945612324401736, 0.011285243456118872, 0.07884305502687182, 0.03569740841963461, 0.06778505803751093, 0.022582125484145114, 0.00021763638324046042, 0.011810053821786173, 0.02596921962685883, 0.008564077151407088, 0.02412889864561813, 0.008635439527487116, 0.010977006201366228, 0.014011296909302473, 0.04691766009532979, 0.06095734012446233, 0.04643743711390665, 0.057501181294875484, 0.03192352217489055, 0.03625081479549408, 0.05452073997418795, 0.06040663431797709, 0.04330683938626732, 0.03866245038807392, 0.027702715447438613, 0.020107752543741038, 0.05150577139907649, 0.05688635053645287, 0.060988518808569224, 0.05364558586318578, 0.01575511155117835, 0.029518274989511286, 0.019579541869461536, 0.021734462219423482, 0.02221931959502399, 0.049606131190168004, 0.029667162535978214, 0.013227102113887668, 0.016235448187217116, 0.028960929717868567, 0.044027402863970826, 0.03251656178118927, 0.01751248841173947, 0.044221599586308, 0.036501882930419276, 0.009853004461287387, 0.015680147002318075, 0.03545179909893444, 0.024773220232288753, 0.043591308407485485, 0.11579691352588789, 0.08185782004147768, 0.013361157733015716, 0.016680718133492128, 0.063868180715612, 0.055296739762915034, 0.026939182043341652, 0.05226204278213637, 0.0243398433085531, 0.04343378650290625, 0.05054716765880585, 0.040191372989543846, 0.06956782737480742, 0.02900236106610724, 0.04080253287351557, 0.01629733736626804, 0.061207943462899754, 0.018919266228164946, 0.07511373156947748, 0.018666781651388322, 0.006230292850107486, 0.033824543202561994, 0.072722302749753, 0.05163655563124588, 0.026288192153775265, 0.08185872927840267, 0.061019073240458965, 0.04647578791316066, 0.06286139759634223, 0.031845375296792815, 0.036086551645504575, 0.0049612538257081595, 0.060421840287745, 0.031872889891799004, 0.018795616791716645, 0.02453419779028211, 0.04854719586936491, 0.024566713188375746, 0.026138753297605684, 0.017155236331745982, 0.017671954319147126, 0.023363044651757394, 0.09457346451069627, 0.024690844384687285, 0.009006821251075183, 0.06164007527487619, 0.04262589217562761, 0.05221884385017412, 0.024414136107744913, 0.08400429771947009, 0.05464244880048292, 0.05594541584806783, 0.028412300228540386, 0.059604327726577006, 0.051817948397781165, 0.07179792092314788, 0.0436023956696902, 0.028896224618490254, 0.06180906442127057, 0.029148375016770194, 0.009444795249562179, 0.017232172024835433, 0.017756598170048425, 0.04510152719116636, 0.008589085407688149, 0.013182563075263585, 0.04546886230153697, 0.012861459948388594, 0.00949131221776562, 0.07594090646931104, 0.03805067642991032, 0.06374665509377207, 0.021230534617123858, 0.028502182369785647, 0.07079742782350097, 0.027614076721615026, 0.01701877954682069, 0.03303283193547811, 0.029186437438641275, 0.057407495964850695, 0.0312470600807241, 0.04936790433047073, 0.015299059683457017, 0.035708492289164236, 0.034318889890398295, 0.030971374695322344, 0.011572141632703798, 0.04791104554065636, 0.0832278026001794, 0.020838816350858127, 0.0020450254544682267, 0.05011874743338142, 0.034104014813367806, 0.04781787928992084, 0.010028496517666748, 0.03565435876537647, 0.026707735444818224, 0.025051005683573227, 0.040734845612730296, 0.07155231160244771, 0.018214614396648746, 0.06759605210806642, 0.043954925145953894, 0.13641478360763618, 0.16835692817611353, 0.15217500792018004, 0.18993861653975078, 0.13371923539255345, 0.17076696242604936, 0.11151647714099713, 0.1244134668792997, 0.22088973357209138, 0.11474352862153735, 0.12184580894453184, 0.1055938842307244, 0.13279743199901922, 0.09864371110286031, 0.11636646224984101, 0.16540546369339737, 0.09826836588659457, 0.13719394536955015, 0.18713096076888697, 0.15168426425329276, 0.09879505155341965, 0.10671365700129952, 0.10478676004069191, 0.10461424251220056, 0.11202263033815793, 0.22836869582533836, 0.08202953689864703, 0.1897664043520178, 0.14115827264530317, 0.09945162239351443, 0.12090652648891721, 0.09972870216837951, 0.22386415967983858, 0.12130982056260109, 0.12353302698050227, 0.13873417914978095, 0.09293235292924301, 0.11470567993819714, 0.13907316167439732, 0.1300289955522333, 0.27149801009467667, 0.10263454195644174, 0.15193494223058224, 0.2180982269346714, 0.13375371854220117, 0.11994175825800214, 0.1455667553735631, 0.0636460283505065, 0.11466055735945702, 0.08753983157553843, 0.19865769653448037, 0.13448269585413591, 0.15752293595245906, 0.14211370423436165, 0.1300750273678984, 0.12312140049678938, 0.0768126000517181, 0.11180422348635537, 0.14789829669254168, 0.14385475723871163, 0.18571538744228228, 0.10512582398951054, 0.16704134376985685, 0.12941353714891843, 0.0993304903219853, 0.15527581796050072, 0.14491262047418527, 0.09718437905290297, 0.11976179720035621, 0.11594475273575101, 0.09611633100679942, 0.0973041947664959, 0.19572433536606176, 0.15041031475578034, 0.172209568587797, 0.097638800740242, 0.13399378423179897, 0.18155808480722563, 0.1357660498470068, 0.19152665989739553, 0.11971991801900522, 0.14613768830895424, 0.09409902604030711, 0.16731790107275757, 0.08387646172195673, 0.14923773839005403, 0.13665005884000234, 0.12086498657507555, 0.09855399520269462, 0.10670483604605709, 0.09564517664590053, 0.2228929725076471, 0.1190118667270456, 0.041926648268210034, 0.12411128809409482, 0.14519263830568108, 0.12562394621116774, 0.11383290069976024, 0.1470343859067985, 0.1974170088235821, 0.10366294998675585, 0.18206045856433256, 0.09351869539490767, 0.12159161615584578, 0.08534010246928249, 0.10750014015606471, 0.10707215419305222, 0.12128812101270471, 0.19234733443175042, 0.1713517510465213, 0.09822790484343256, 0.06870759424886533, 0.20107929302113398, 0.15245145665747778, 0.1419111072484936, 0.12704751268029213, 0.14817752742341586, 0.14121030271053314, 0.15164912971002714, 0.17148398395095552, 0.11641465180686542, 0.1910988978509392, 0.10671954668526139, 0.15131942954446587, 0.17009988107851573, 0.20911572607500212, 0.15891763754189014, 0.09890892330024924, 0.18365702432181152, 0.11766513756343297, 0.07524466168667589, 0.14501510640340193, 0.1025314928431596, 0.1211828530899116, 0.09018269833177328, 0.12017550000122615, 0.16627841256558895, 0.15260262068893227, 0.1145140752196312, 0.16273502127400466, 0.0692117457677211, 0.09950913502169506, 0.2156588528305292, 0.1485965906509331, 0.16568983771971293, 0.09398397364254509, 0.13418673244970186, 0.16641030620251382, 0.07914036871599299, 0.09797067900321313, 0.08321885950863361, 0.1143666295600789, 0.1230852481509958, 0.12129793262907437, 0.21510904947561876, 0.14173490527485097, 0.08850453195295163, 0.15352366412324564, 0.3107603261513369, 0.0981598613517625, 0.23287324554153851, 0.09959781954863242, 0.07925366370805673, 0.12993309141269752, 0.13873518338160856, 0.12867548103843415, 0.1197216414979526, 0.14796676087592328, 0.2135423528296607, 0.170091412961483, 0.12249380988734108, 0.12233883248908178, 0.16058531376932347, 0.11930935004992144, 0.1117475793829986, 0.12376305035182408], [0.031237981282174587, 0.044904938632888455, 0.00872303670205708, 0.03119273656713111, 0.08499546774796077, 0.023453785139801245, 0.007739907313537384, 0.02523432718589902, 0.050845583967332325, 0.09342775813170842, 0.008269485235879464, 0.0197295914071479, 0.03824548383376428, 0.04153154750487634, 0.014397035585716367, 0.03528198892516749, 0.031825714744627476, 0.03637550239052091, 0.018479110739592994, 0.05675553237753255, 0.06037677199180637, 0.05306435615888663, 0.02018758049234748, 0.02557515023675348, 0.03979568190074392, 0.04058848560920783, 0.03615281059007559, 0.03268662301291313, 0.05296593126175659, 0.022589665704539845, 0.029295101429202726, 0.03859331106234874, 0.033067148844046254, 0.05513296176546386, 0.040993574408016036, 0.025484267256355712, 0.027392947248050144, 0.014538932525153671, 0.058950382817004404, 0.020263557754723088, 0.02623286101567958, 0.033963524137756655, 0.02433971269056201, 0.029194718958543878, 0.011813337931276431, 0.07375932817480393, 0.013915645524061151, 0.03232715890875884, 0.02116766495497099, 0.03095438757113048, 0.06476275449884789, 0.007807949108869902, 0.06298140329974038, 0.026439783662291508, 0.0159102144784161, 0.015337904116937091, 0.030909309097166573, 0.054132458487791676, 0.04282191415716495, 0.018905551339100515, 0.028532838581928184, 0.053891330890889676, 0.09589849412441254, 0.05448290825422321, 0.017413836205378175, 0.06745446220572505, 0.03757327954683985, 0.02178791890453015, 0.017948287705491697, 0.06285467331430741, 0.02769015746058098, 0.029618972978953804, 0.036144149090562544, 0.004019367916043848, 0.019806868064084222, 0.020705570732908588, 0.010854612054702426, 0.02293333181712244, 0.07630035361008984, 0.02147030344765101, 0.034638208470174243, 0.046693808000002585, 0.0562461459610079, 0.04431818226086242, 0.06751623603382281, 0.014030585115376328, 0.03944636189511844, 0.03134403969826443, 0.0654063585347363, 0.047099656758031676, 0.057012303599289486, 0.03683527432648199, 0.05728326298828636, 0.025861210422590375, 0.05624048697895237, 0.04316762774916632, 0.02851783617266587, 0.05305301783872502, 0.045933943774018965, 0.03716310512806688, 0.048111420324338336, 0.05851401016116142, 0.04241967520543507, 0.012625320432042437, 0.01135425640469683, 0.038663692107158046, 0.0762948574764388, 0.054998767894825766, 0.03950821375474334, 0.02501594747549721, 0.06396985918815647, 0.029597242894981588, 0.017432612965681722, 0.04940920675705586, 0.059654932868267806, 0.029010693476136242, 0.018214690731838346, 0.05012039966615183, 0.0021815363101528157, 0.006095036223996431, 0.04451866221747228, 0.08090067854417221, 0.04948073113337159, 0.09110005732093539, 0.02471832505294255, 0.03202559419774583, 0.03316237784123846, 0.04842415711443339, 0.01087095626696412, 0.03594431034954531, 0.01788376920324351, 0.0065174416605649245, 0.05869993554162128, 0.04310059527467404, 0.05052906095183321, 0.036762701613562446, 0.016368871920609047, 0.07157763452934367, 0.019567167087058936, 0.010244848256531571, 0.04048318036698869, 0.025700248345466595, 0.026518035713317137, 0.0049112754807408366, 0.034853555129042695, 0.022971730113827755, 0.01358917772969497, 0.009857773714299713, 0.06666475600962128, 0.05003001880166786, 0.022809838443728428, 0.019644389461193765, 0.031883071309753826, 0.016230505059606264, 0.05892048656408276, 0.058800467289984226, 0.0632943572210414, 0.007502036684724901, 0.05239274219742843, 0.02331591021668698, 0.044169240431593995, 0.046449358974184306, 0.08828267814325434, 0.06537245213985443, 0.03359407878347805, 0.03428498349551644, 0.044004970496254306, 0.028626184644443647, 0.012149081299347537, 0.02745662267053766, 0.01709087728522718, 0.027965242342491235, 0.06355129129120282, 0.07172231176601988, 0.03140856837853789, 0.02314910595305264, 0.006301795598119497, 0.03602080499487264, 0.014218792918005159, 0.008516212443022855, 0.008933199353383055, 0.0028613126238009757, 0.026588447292202284, 0.03490650800189801, 0.0374554281921259, 0.042488797567784786, 0.017680826164515953, 0.01741307624615729, 0.02533248915070934, 0.04286926233076623, 0.03165249493239181, 0.03529100665556533, 0.04869903843583805, 0.019749168838773454, 0.07198248923357044, 0.061669835820794106, 0.061166634250964434, 0.07663070516926901, 0.01095821671853108, 0.03145950939506292, 0.03321356313037021, 0.034341061022132635, 0.019027865757899623, 0.04118219017982483, 0.06576771235891751, 0.0015656806457887537, 0.0802214378491044, 0.017316110199317336, 0.006536852002942136, 0.011375049262174537, 0.022518779151141644, 0.048135908653161356, 0.04446878310825143, 0.028235143216859018, 0.03843174848173346, 0.013488721468352845, 0.035313686688563654, 0.0590570688779865, 0.03277392332841243, 0.044761184203837595, 0.06017661773200546, 0.05669254397175141, 0.04137062953252878, 0.04433748658214297, 0.014780070300080946, 0.022947815147095492, 0.029477267725659267, 0.07641690557024308, 0.017386789799534848, 0.04961037203403456, 0.07114079368433782, 0.026442387540425574, 0.014867492751883609, 0.030982577308480228, 0.014045443335947181, 0.0340003482332187, 0.03143884800374508, 0.04632219472633941, 0.06893771940043994, 0.019638694856049757, 0.050098723864981105, 0.06274534775210278, 0.09773076937666961, 0.0449491926868047, 0.04698014299252203, 0.01526599467199828, 0.0118787436180615, 0.08857313184333698, 0.032469702152801413, 0.02039340221589165, 0.037475271948746273, 0.03826015376086746, 0.03326457878574729, 0.027511356697816933, 0.061670453287661076, 0.024022641758035337, 0.11149906593241862, 0.06133573196296181, 0.020026945808370198, 0.03476621410144227, 0.02273166612056749, 0.01475531394992556, 0.0719918937289289, 0.030912040200616633, 0.016787244738744836, 0.03262133098074368, 0.029780454135366848, 0.1309601627290249, 0.041169219982943366, 0.01614167295130236, 0.04162369256040879, 0.01484520118018346, 0.054165581174726994, 0.03377852835027235, 0.023700378336278454, 0.02603364483054195, 0.03670172506411161, 0.01895715223093118, 0.05925089240606342, 0.04804737001125302, 0.004512581450399011, 0.05040194420143962, 0.03418070623385055, 0.052432640056524954, 0.041250840960336585, 0.08394250353532177, 0.05012654380074569, 0.0769699794639434, 0.07300515685762678, 0.05282383245815124, 0.016059666905286055, 0.015429128061181732, 0.06348725794149296, 0.06693228879677397, 0.021278625786570565, 0.0431294805104179, 0.054970591728176386, 0.0594256083880152, 0.0713806761694806, 0.055073556024581194, 0.02541397442109883, 0.017125986383429596, 0.011418465325342757, 0.030613230341779332, 0.027880547601463537, 0.043268597152616294, 0.06925298034080438, 0.04049120404358421, 0.011804791782716555, 0.038584446002330096, 0.041439317632466555, 0.07343008941305534, 0.051631697320512364, 0.012446166831068695, 0.012056758128372686, 0.014193401289438563, 0.03788067965901323, 0.026595001940482428, 0.03811182600579091, 0.013444482681474515, 0.046002078867916546, 0.03344484857682671, 0.013241569328654026, 0.05408835371157952, 0.03908475022763014, 0.03561196389741131, 0.04104106168129614, 0.011721102121685232, 0.0565538412359144, 0.02038946162377085, 0.005214391492440232, 0.03160517050751618, 0.027934167134974684, 0.015923215209373405, 0.019495437453900064, 0.02962803142145276, 0.06985879676150424, 0.02074043725484184, 0.03383418518517699, 0.03793419571593404, 0.051322573729391606, 0.036942537142229934, 0.03878898359835148, 0.03736359187002693, 0.05871132814458438, 0.040271514760596414, 0.018949160784749047, 0.03473353246226907, 0.02628901318114783, 0.04109454381146601, 0.07181459252855607, 0.04613124479406646, 0.062179877023611746, 0.2466126840029444, 0.07413900922983885, 0.18901314905711583, 0.1460806777966874, 0.12050372096044676, 0.1389643789402076, 0.081254120650036, 0.12869285153491156, 0.24012675774948938, 0.08569476593817983, 0.07055042750601258, 0.18012457101472787, 0.10087836440652609, 0.14867398435516016, 0.11723692768386432, 0.09648706897028855, 0.12386016228369304, 0.1150495343442474, 0.14392163365014962, 0.195579128872071, 0.19142091700008937, 0.13281675667635032, 0.12917686413441384, 0.1373407667768853, 0.10894208813884429, 0.17305420897901058, 0.08458646719477006, 0.11487088964453765, 0.08594336081296206, 0.17146638275257178, 0.22507068993789808, 0.1539804403270994, 0.12519908829459123, 0.14982927164861135, 0.14516408555209637, 0.052031965128013065, 0.13099787570536137, 0.13955333376569407, 0.06608758733740874, 0.09530699479260615, 0.19224301645798342, 0.13302232564560004, 0.16236492113343307, 0.10493854153901339, 0.1662552880921534, 0.11228190535413367, 0.12709796854427882, 0.05762295797467232, 0.1108741962483951, 0.16952585402343953, 0.11596120042460305, 0.12654551890279564, 0.26416972332767075, 0.1402301588760955, 0.15560592524707317, 0.14074520766735077, 0.08829798589327506, 0.08383248586739812, 0.16717319669468061, 0.05519587553239294, 0.17267607498381818, 0.19892490362482412, 0.1388704561229263, 0.10657134785183839, 0.2243807012481349, 0.10743158776313066, 0.18317846714385919, 0.1791259574570826, 0.14559312324438775, 0.12204590892153126, 0.14703997703535215, 0.1409930900803634, 0.07081173134169408, 0.09685836333249297, 0.15636496166033403, 0.07468651913638626, 0.12953871328915867, 0.1562428253569773, 0.09772215198193278, 0.2298133783042431, 0.13716060215873377, 0.29018128184335573, 0.1590500468654292, 0.22081319482198783, 0.1207120990646737, 0.16309579834342003, 0.0887735371610948, 0.13073402057800973, 0.09159502826098885, 0.2300065436533519, 0.2587924690118858, 0.15653887018561363, 0.1487019807100296, 0.14697206925068582, 0.16110177391341754, 0.08512527149702821, 0.27440887104187695, 0.17564033663698606, 0.13640421203204564, 0.12965107868824685, 0.13541163743606635, 0.10636916477233171, 0.08695847634226084, 0.09593122665371213, 0.16700384792472633, 0.10480018146336079, 0.19690529842461857, 0.12498634042484419, 0.2558236340326922, 0.11286632078034536, 0.13458144984075002, 0.11516711089227881, 0.20262122313891137, 0.15477370204670088, 0.0680053715727159, 0.08071281933890921, 0.1764556100325925, 0.13799457597945416, 0.2081433039690767, 0.17947855139417307, 0.22518000192940235, 0.2554136631744248, 0.1862170012401683, 0.10858608117061001, 0.12213367064084325, 0.11045868175902537, 0.1658382061868906, 0.1286594947533948, 0.09961071849933692, 0.16167569240289076, 0.1324269925909383, 0.11574854754975863, 0.14831217591251644, 0.1463723121477025, 0.21455570416791098, 0.1614915651402303, 0.13270137858177933, 0.11885726930839674, 0.11311866116843053, 0.13349835867328302, 0.09775352744119507, 0.13664107503635542, 0.09392968405570302, 0.1110329870134592, 0.11369711227182831, 0.05430606506498797, 0.11775101295539311, 0.1027551990534578, 0.20685131901076861, 0.2376737179500716, 0.1543452071824244, 0.15396114279116901, 0.09449229815176555, 0.13769137939172132, 0.12746367177792958, 0.13232566017125333, 0.14329911848264082, 0.09898804048342363, 0.07363229963396277, 0.12366321070918015, 0.13719898009938852, 0.12630797736346722, 0.1679933148303202, 0.10950169632477419, 0.11995743241693292, 0.14549396213676247, 0.14248499859656605, 0.11166549021644251, 0.14269690508288996, 0.08094970948461976, 0.11435444307114397, 0.13975700283689158, 0.1929369406508548, 0.0757046677172184, 0.11761844078344957], [0.03915247820051653, 0.04325693652832082, 0.05200844371159162, 0.06364102076206889, 0.048150364841733656, 0.02297474959466074, 0.012254592646578593, 0.05038725391828588, 0.007947801961563528, 0.024597574657361423, 0.03581665077113679, 0.034878599856581004, 0.04571678203397563, 0.023695811795602952, 0.042709114495664835, 0.027127628181395785, 0.012777355532827122, 0.006039645290002227, 0.03195248883483665, 0.033102222319160185, 0.024836578439655047, 0.023149192466267517, 0.02655759430490434, 0.015062390061627542, 0.060324361946965964, 0.054933095883045874, 0.031092313384371142, 0.021030626326267208, 0.035615882437144, 0.013901035816940879, 0.03279511397704482, 0.05480745155364275, 0.08173529697316033, 0.022211616526224782, 0.03460044460371137, 0.027757166186347604, 0.08078990770237786, 0.022723013102742176, 0.06187800357916525, 0.07191673240491323, 0.0125783361228449, 0.03307940657915814, 0.00958990165963769, 0.0702970421739987, 0.029751453548669815, 0.06758244069559233, 0.020430156761514287, 0.012687760072627237, 0.034894206162009916, 0.053552707989833186, 0.011030666446978492, 0.04087687995550888, 0.02829652858365859, 0.03117259425510253, 0.04455162544867822, 0.04616806549685342, 0.061408002727798054, 0.02682428740497146, 0.008423755261381822, 0.04830335073971322, 0.02919751452282071, 0.03357970401910799, 0.03196799675268786, 0.016573506207870584, 0.013273768359795213, 0.012778055272065103, 0.023489460814744234, 0.04769556996013437, 0.03883839451840945, 0.09986662798162017, 0.0071669023018330336, 0.052326819127691646, 0.025527245664436902, 0.0090735950340916, 0.027723955289859856, 0.03260109706648758, 0.006506125816875803, 0.02962923582111086, 0.015368110799629773, 0.0538058253005147, 0.04615465425220983, 0.019845678570813367, 0.07289177365601063, 0.13127505726047925, 0.013143633824906178, 0.03978980578748243, 0.10591302639139549, 0.03935688687488437, 0.010564870816389365, 0.07805826820965324, 0.03735209409413593, 0.013195118517614901, 0.0553263238897281, 0.03327193749802453, 0.06092741673013993, 0.03728513286582061, 0.05512252589687705, 0.04854368105796831, 0.02044210915586778, 0.10641165463519947, 0.05854170796062265, 0.05404410644301346, 0.020239737782893435, 0.06261806136795453, 0.01564626774883696, 0.019937380882246152, 0.03128823697833078, 0.023782504822260568, 0.05463246076500841, 0.039740072563290596, 0.10726318894220249, 0.06979748433721916, 0.05667490206126656, 0.038382218818047216, 0.05979424289294651, 0.023091518686019948, 0.01892048928753606, 0.015750695984544497, 0.08495988537158285, 0.06355144056890692, 0.06653748998152358, 0.04557493768100228, 0.021316028333136013, 0.02254452446608671, 0.02242440001906029, 0.04057828722787755, 0.0050348536710121804, 0.017429912396307503, 0.032817566700811894, 0.028314962683777724, 0.01605147189859833, 0.03099151700735092, 0.02849642500015242, 0.061750425424958975, 0.03327904175966978, 0.0078253323278789, 0.045524475031665394, 0.046712108089455535, 0.05723617944334235, 0.014345809584483504, 0.02847902736227427, 0.02568971408930208, 0.05433423783896225, 0.054407061609838686, 0.027827330099950944, 0.057126942090690136, 0.03870361710765532, 0.007207663596740791, 0.039836828264274766, 0.011923385285107153, 0.01995478360913694, 0.03731791289257152, 0.07303944323211908, 0.04859630484133959, 0.02977688504116876, 0.03453195667160409, 0.01988569347720061, 0.024330954499808804, 0.05971160411302533, 0.09051718216921602, 0.05003810015373996, 0.0649102001584002, 0.024738623428025415, 0.004415266806193228, 0.049680383277258704, 0.016385792887636592, 0.056128270857568295, 0.029112120890723805, 0.06499367353639432, 0.04403977255736079, 0.027291716608617986, 0.031811513006687164, 0.1273659627352442, 0.0151481568879847, 0.04027510081816997, 0.050037886415209086, 0.04953192999320371, 0.04756794770115188, 0.06444955630494015, 0.02979627757200173, 0.04308477523071425, 0.039653362573257515, 0.03836456672953708, 0.05676591396331787, 0.015007342211902142, 0.034976234260414324, 0.03794701324243631, 0.030974889506718943, 0.03958937332832387, 0.07195116127175943, 0.01632354747770088, 0.009205269843472965, 0.02324631287982421, 0.0014952859242579766, 0.018004263451855098, 0.023436319648421237, 0.041822506713547876, 0.03364761858912451, 0.04295252875557967, 0.039914574806711504, 0.03792799390586359, 0.05667936342901417, 0.039562927425972054, 0.03233481617644429, 0.01973342682634081, 0.013216863868625035, 0.052399758249521255, 0.05492345050775579, 0.03411858635289328, 0.060416018457284996, 0.02706672457445945, 0.016647972033492157, 0.06449248043021985, 0.09039746145052568, 0.035565586028886695, 0.08566020136432988, 0.026650743592264395, 0.04782968919192042, 0.023773283531357135, 0.027169542985835245, 0.011371430974187595, 0.04211463978780167, 0.021901861897536685, 0.010520190981748914, 0.04747901550893273, 0.0329513568431139, 0.013925528386607766, 0.0137152478398223, 0.019951224692964127, 0.02595773372533066, 0.01926678472331592, 0.04335526643054826, 0.02975508031834449, 0.042952817132962604, 0.006771913072693029, 0.034182120979364426, 0.05496673425659537, 0.05393431269164596, 0.01174854886318956, 0.02887721885261791, 0.04672142776793667, 0.04271784384867974, 0.06803249940276146, 0.09120945752199207, 0.04072115956140416, 0.024879378732293844, 0.04856804046513779, 0.04366649008755173, 0.019917328476107547, 0.03724950299199138, 0.06558308976569346, 0.11221190768160991, 0.02153007559744375, 0.03186207404360175, 0.07629611955157348, 0.04925698421097227, 0.007671734900213778, 0.025993009064612643, 0.015009372727945447, 0.04769716451742819, 0.0506938838932131, 0.028162192220666578, 0.08279799816331693, 0.03744025614910892, 0.013765063336385148, 0.029208622141075984, 0.037259406210588555, 0.04167880317462342, 0.10611942317336798, 0.018519777039598142, 0.032886594068259, 0.034731242406581125, 0.03640413996098297, 0.00719828878728939, 0.05725156861756529, 0.03409734820680959, 0.03503069008833595, 0.03228959181745138, 0.018729617386790257, 0.005083900726666408, 0.04618857761046716, 0.018367237278393338, 0.02277057501487434, 0.035644099315894504, 0.03543155161397798, 0.07024325470307044, 0.038595611296061955, 0.04309270051973207, 0.042937723121472766, 0.06966282906276838, 0.05181546156693782, 0.042134659963526895, 0.06292334105819464, 0.07972812931984663, 0.006125394728899534, 0.06936506075518471, 0.03795916919729539, 0.03861044067889452, 0.02041521033139101, 0.04107124970427581, 0.12461504606263978, 0.03888738135408078, 0.023052401142194867, 0.08053165048893009, 0.038156378615115366, 0.04693305266222783, 0.010793060446823282, 0.0406754025524216, 0.013416051216024374, 0.03349936208022492, 0.02942778216674924, 0.01284899695643357, 0.015671441398028816, 0.03477944553430591, 0.04819791657584054, 0.027868646097236445, 0.0072501390407394084, 0.014156806199545307, 0.06866200348096234, 0.009001096960024109, 0.04714616694088493, 0.036353059844779115, 0.06795755520995174, 0.02267422473856381, 0.07839579188397952, 0.02600082748436502, 0.053275044674852064, 0.046995420208466906, 0.042094059820686064, 0.01741006355067449, 0.04297372618956225, 0.015896245138719678, 0.015130192673365985, 0.035696404187807014, 0.02585611292826278, 0.08692852580653769, 0.01740810088813305, 0.052804701163300445, 0.037662835991276164, 0.06686035729944706, 0.06996627670845815, 0.08840030218873705, 0.056450435891747475, 0.031869636316384585, 0.05326781827690346, 0.0352711900403457, 0.054774013347923756, 0.03344045506258096, 0.0639901745266148, 0.047275095379778316, 0.07140422811997788, 0.020100862020626664, 0.1283723930163043, 0.11734344411109175, 0.1330216471105814, 0.12683776393532753, 0.16936791821249894, 0.07935509790799447, 0.09537478722631931, 0.11596681869455747, 0.09992394383464541, 0.1135757766397936, 0.13337629022342817, 0.19659918413630553, 0.12674707094473497, 0.21043536812067032, 0.11487531369285923, 0.11208432274205343, 0.17593176742749556, 0.1062895522585937, 0.11662684327789716, 0.1250413153320551, 0.07121246055300746, 0.10264201262699706, 0.09677820799074002, 0.13453479377286776, 0.15329963900148869, 0.13078826266740048, 0.180090264284185, 0.11332670679049832, 0.1173299141228199, 0.13607125489839486, 0.2454709538391658, 0.14112339594534465, 0.12646585889160633, 0.11835123146218912, 0.08795673706169639, 0.08246096981955425, 0.19552979937621526, 0.16956966024424347, 0.18850966250257833, 0.19279055350593158, 0.10343460259693009, 0.19003457496208803, 0.12887795588799886, 0.10936015391988413, 0.09626182248549801, 0.1587268877774477, 0.06610690522938967, 0.10050601152969257, 0.1126519919240049, 0.13642125683171408, 0.1257885316652911, 0.11598081008664199, 0.17640708120805876, 0.10387100917952401, 0.12322831047432763, 0.08514603466859885, 0.13079070539346763, 0.13861965600933346, 0.09623670311910765, 0.12074541513408933, 0.09387146575110299, 0.12083726163421359, 0.07261938934347459, 0.09649229368993215, 0.09089222204472337, 0.10983391385525465, 0.17527384630271367, 0.18583833798766136, 0.1449209257428135, 0.2351433794413294, 0.08522566753838744, 0.16247400242303098, 0.06868218989776713, 0.06340372349534716, 0.14093894298587525, 0.18508029223552772, 0.07459334949297564, 0.10912679215627057, 0.18608780817261764, 0.14157103906784738, 0.10658583457448653, 0.19096686850701058, 0.11988621338137559, 0.24925804776804789, 0.09955378262592213, 0.12314240794096674, 0.1626948791423014, 0.14993635804525443, 0.07644399947353772, 0.178606566041708, 0.12870140107614653, 0.1326567716896534, 0.24519831846867288, 0.08882720249571971, 0.184949714956539, 0.10023260941462857, 0.15792802135859216, 0.13422056420573167, 0.1281545018511159, 0.20846718230417796, 0.16058193466493062, 0.09986271283456258, 0.16215860577566282, 0.14249980423067296, 0.11377344746142626, 0.09058763446020228, 0.07809165213257074, 0.15887134788291796, 0.152106747297304, 0.1465869734862021, 0.17119720791067394, 0.12231697009078094, 0.23232336076242582, 0.14204705852483, 0.10140078208808388, 0.14357935344534262, 0.14216832630336285, 0.21069496204810484, 0.15300467982888222, 0.1825670256678547, 0.1691645205553089, 0.15416734958333628, 0.16058924927243165, 0.14078414200672082, 0.20456958216215881, 0.1131973983719945, 0.10138244128652982, 0.11083271061735493, 0.1345072045390095, 0.1153652159763234, 0.1334585558090891, 0.0970391250614609, 0.09857123677751847, 0.1563444427613701, 0.12187426670321397, 0.08409629349729844, 0.15128866476672037, 0.14256788843444415, 0.1780372615903616, 0.08329842452492033, 0.13015426668737615, 0.07658323485936437, 0.16490747327251093, 0.23183218283312662, 0.13015224465302058, 0.11794306550707136, 0.09666557796299458, 0.0806652879608529, 0.08606656920164824, 0.07831601652183703, 0.08461770016167845, 0.10496474656143359, 0.1283648477068969, 0.1896058629666056, 0.10714978538453579, 0.12691168354025908, 0.1222253135804619, 0.085420169601483, 0.1151598369968789, 0.24098985429321015, 0.104960722848773, 0.20589391967015608, 0.16558193708104746, 0.21416513941117696, 0.2688421154660838, 0.14983217577849114, 0.11982472453798566, 0.09058168370808874, 0.12489553886864867, 0.15488705810691628, 0.1008569701973881, 0.16931846658033983, 0.1198395166013922, 0.13600574912769453, 0.12258409575692245, 0.08503279395933662], [0.05009663397712367, 0.011676566475736243, 0.06721675781799213, 0.009925883363134094, 0.018951630652216927, 0.034167227135705094, 0.012071702013989645, 0.03360521015045898, 0.0810952213193689, 0.006801023497246206, 0.07307722406195742, 0.08393615923289742, 0.03320459629009877, 0.06802486588380166, 0.021313928267253295, 0.053993681113102605, 0.012513955872106765, 0.04016557848080993, 0.05534516002184578, 0.037695700834904394, 0.05641450406983495, 0.006989472179806658, 0.03715633674125586, 0.013818386858994407, 0.020665762779702033, 0.027714298040206944, 0.02290082998972918, 0.013086150882632604, 0.050810510492218394, 0.04266452456691435, 0.03978325792455247, 0.00508753300943811, 0.05464827063094292, 0.03824082908353635, 0.05746224695550544, 0.04223273202244725, 0.055899014230817556, 0.0545660491500582, 0.09757640265992709, 0.050425567398113866, 0.012189929955638945, 0.045427888964435885, 0.022355890034564903, 0.03506476950964757, 0.026995037349739244, 0.028702696253146445, 0.029019110703042576, 0.015928541709269797, 0.06033889616706541, 0.039387003651687076, 0.08967552733208452, 0.06342034081795386, 0.045179433189332485, 0.02964571743671383, 0.021377958224288056, 0.014836449774780443, 0.008231969882867165, 0.018732144929734722, 0.029114689145769392, 0.02227951922187848, 0.02731961287957217, 0.024907030730641315, 0.09073256954018559, 0.051506731526127884, 0.005486750783997455, 0.017610119422897696, 0.033786959147879055, 0.02204319734924606, 0.070800521943186, 0.054273040765630345, 0.026671557653961436, 0.009193049427787108, 0.01116143201943487, 0.05996424305651869, 0.03577860191996608, 0.01903883258013853, 0.07425408876900162, 0.03880299534648657, 0.012673587172425218, 0.020926703599148562, 0.05829756427556276, 0.06586850873593773, 0.02754641999490559, 0.029269673329378878, 0.029904622651104416, 0.017430041317961047, 0.008966753758223993, 0.08225073931472641, 0.02184633907329823, 0.05130255016099129, 0.021921385046360747, 0.07806591529931341, 0.04036648252180644, 0.038262284360826015, 0.008170889008657208, 0.037676715425082614, 0.041992106541459046, 0.05819565510111196, 0.026675650916461433, 0.054276426655373404, 0.0038744226580352654, 0.00628173810296825, 0.010638843855953642, 0.06127370029155697, 0.030364574398845434, 0.05167214818564909, 0.038791107412959845, 0.056160094149942906, 0.019338220890079225, 0.04640586148681385, 0.03405883116647601, 0.024085163670991148, 0.03994412500677364, 0.014573305412860853, 0.014524025110793965, 0.08857557456940413, 0.025016017025336623, 0.06344226428440639, 0.02795781916938722, 0.02540706523827144, 0.04481222700061543, 0.01935745226884527, 0.03258514131552406, 0.019070974783971906, 0.028977187416915382, 0.028069253279162303, 0.08522300768111433, 0.03537780485515084, 0.025659464998170733, 0.022022189905068705, 0.008651815121993423, 0.05118149272831423, 0.03917987744456955, 0.036016211312796385, 0.05369672365486622, 0.037082356068172624, 0.05576774823878493, 0.07663768050926072, 0.04002583758639438, 0.021519425990326062, 0.03403793568057673, 0.036674193505729945, 0.038048006394611936, 0.02452638276320483, 0.020180172586281384, 0.03374771268240043, 0.01864325175327914, 0.02972441053550158, 0.022424030217475126, 0.03640835366344877, 0.04973708844876715, 0.01987469781722341, 0.05432978325656482, 0.017917982635221312, 0.051779916509985924, 0.027192085615492294, 0.013675476357872998, 0.06018981523811817, 0.04786246921867132, 0.010357924421051783, 0.044123822690120766, 0.033681691225085936, 0.028481727931648493, 0.09947253484278917, 0.04011510226077267, 0.02140593422310693, 0.02881288355482476, 0.04739001207053661, 0.0060712001369600845, 0.044741245452314615, 0.05356527106570346, 0.04065979963966778, 0.03382285704304065, 0.049530294723808765, 0.028254094699929868, 0.029339355483118976, 0.04345796949097088, 0.01882064455587949, 0.02246735298207828, 0.05731074365654162, 0.021898209682798812, 0.05612717502351318, 0.026710315574226633, 0.06400078681430646, 0.016849537646131854, 0.07513388405953135, 0.0327419100462326, 0.04091289320162364, 0.10135565950934376, 0.10357652498143059, 0.020802148318450366, 0.015021072368004491, 0.025635008899761096, 0.027416366884218793, 0.02843747557406979, 0.04469886076237474, 0.03835262790588396, 0.025683697180024216, 0.045926741124796014, 0.024283095728605986, 0.023450312736843313, 0.020514644549361298, 0.04454082656385643, 0.01865056636078017, 0.07595736094351326, 0.03755788697994181, 0.015652835967817476, 0.028103607507156472, 0.029617833040122474, 0.07398841516780001, 0.034600159619003534, 0.05046721248488341, 0.05094065011612006, 0.024489992930154716, 0.06246461745883737, 0.0032101712256137815, 0.06609340238251857, 0.02674204556803618, 0.020819444176075712, 0.012416800683630365, 0.04591112803401692, 0.013595150534196623, 0.020622557062389593, 0.056426955187427144, 0.01949232637083956, 0.04307467523696167, 0.04736925907699125, 0.013012184628418513, 0.036787396895566156, 0.08607945458165236, 0.027718353983280913, 0.016690446629322002, 0.046197269644056044, 0.032988445567233224, 0.03714605015037315, 0.0939351666186537, 0.04955151929919209, 0.017779220527570163, 0.11265185621700116, 0.014716349076479673, 0.024521275090851953, 0.04780686327389308, 0.04433676054967301, 0.026120324286499193, 0.07359400311751024, 0.05679216309051428, 0.03636843544830169, 0.02441600038270865, 0.03510475557829652, 0.05657418371577348, 0.03131240639569504, 0.08795422648212739, 0.03610398999548384, 0.013738111925444432, 0.04607493317286883, 0.059047555817025046, 0.013272949876928968, 0.03380654166851725, 0.05169510981068015, 0.016843352799436877, 0.035357126500457525, 0.03285767151308911, 0.045873988419771194, 0.046122688467481306, 0.012038990688909377, 0.061512653183724196, 0.02167793346701988, 0.049475143397493024, 0.00528724749373006, 0.026865213244621242, 0.015196933377800243, 0.08423034487558262, 0.028164733334311416, 0.007355594408831426, 0.00178460223001561, 0.007302233566796141, 0.04988798785156437, 0.03391835745424032, 0.0019106617380332733, 0.04181997238525322, 0.02695200465885656, 0.030876987081553255, 0.05570908549374767, 0.03650656821472304, 0.07903936877846718, 0.05570724666384714, 0.05037055856415203, 0.039427132212689946, 0.009819915701102997, 0.020925602676080804, 0.06908257984157119, 0.03774687933868595, 0.023011215762900453, 0.10674391966313124, 0.050606841421020884, 0.021458766655996442, 0.040849935329918347, 0.04839748390285032, 0.04159469536638685, 0.010640064370818436, 0.02394008100964129, 0.003933816100470722, 0.022530938498675823, 0.033190506510436535, 0.08029346434133393, 0.03317040151783398, 0.06552552285471133, 0.021685599216393063, 0.06224059233708041, 0.10822105647197791, 0.033912637404033115, 0.004196189052890986, 0.028605591106627668, 0.0057217927699509475, 0.02147569101569908, 0.019978320292596306, 0.0193076596728393, 0.06509094831666776, 0.036479111295193434, 0.046686795340584855, 0.03882374494735684, 0.05566092307812401, 0.007928220289094108, 0.029331589649830545, 0.029751256773514406, 0.06174458323844841, 0.033504362883312364, 0.017418183918510164, 0.0162312378774264, 0.010893240205145307, 0.05778103627796684, 0.05653644359803625, 0.03103533001350505, 0.035853661463728974, 0.024340221591825997, 0.05564328456031425, 0.05804563100848879, 0.058509470761886666, 0.03339901014364191, 0.035593833441713026, 0.06308785865881614, 0.01090666332415172, 0.031044317209827046, 0.022521113311605792, 0.0237464186336313, 0.05764638100351606, 0.07555001601576805, 0.009012412379628845, 0.028589862664895396, 0.028588994140071527, 0.017173614452726076, 0.04716449756441372, 0.10808982101402112, 0.10464601152177368, 0.1372734968151365, 0.11313984503171273, 0.1113376153100814, 0.1791077455771821, 0.0887151492227401, 0.16247978354138987, 0.14328192440526827, 0.18864992926163332, 0.16588256880640984, 0.11632603513342993, 0.13892353113208497, 0.19575140891330584, 0.11738106209252562, 0.11033199248569352, 0.08872199564107827, 0.0705787834844419, 0.1254973994301898, 0.10402827324079615, 0.10614672742251839, 0.06943710081811462, 0.07237220582153116, 0.06486765601273094, 0.08464116390262331, 0.18362881083573612, 0.08957376743533782, 0.1082967199119074, 0.12122826065335955, 0.11378746599491153, 0.14414090902677604, 0.09945846202650241, 0.17850543718252862, 0.1934640130826405, 0.1129733393234866, 0.14353271094816072, 0.11810824807201113, 0.1345453653484583, 0.12945886328816414, 0.15849522235138075, 0.1283254519637142, 0.2076263688504696, 0.07622162319187607, 0.1050276467576623, 0.10502956701176507, 0.08499869757464953, 0.11279903046254601, 0.11718299772058215, 0.10974505290921245, 0.11286748107522726, 0.1261899122702224, 0.20371384093804018, 0.10313429656837668, 0.16320368541138514, 0.11789885216525622, 0.11643724702298641, 0.15325714913862093, 0.20436560096485273, 0.1356138408716236, 0.18002983395542416, 0.1656232327222824, 0.14356927041496548, 0.32644566733922276, 0.158998844612922, 0.11702097712882928, 0.13383054227701255, 0.1245135779359511, 0.09864284257803645, 0.2243287797485079, 0.23705464974045753, 0.17352579081697123, 0.12396659728671823, 0.1263234479618924, 0.14029855520597526, 0.10274547564664058, 0.18303374919508184, 0.17212441244295665, 0.1308753594223942, 0.04870069406128355, 0.25382599979639053, 0.09445083287677594, 0.117930390472923, 0.09725971679602351, 0.09945150704256125, 0.11553037139986243, 0.09681851297084774, 0.11799531270350729, 0.21417591454727308, 0.07265989109873772, 0.21246948039957456, 0.11188032118869679, 0.1115966189120497, 0.17056013138166495, 0.10924350696482829, 0.12860485911369324, 0.2080241260784013, 0.09929254664374249, 0.13398127204605512, 0.18544054004762853, 0.18640317767858505, 0.1275144126266241, 0.08657563331403903, 0.1440708435007504, 0.148390316005264, 0.11660475017768995, 0.1368695513478347, 0.19449997320771217, 0.12978009533669266, 0.14574242808989116, 0.1649037684713091, 0.09034545852669648, 0.13686596868293627, 0.14146114353622707, 0.0956613529207451, 0.1515227457774537, 0.16301564978701727, 0.08503273289118495, 0.2835258575422423, 0.12760499705161366, 0.14705764608723776, 0.17474399187735148, 0.13309874225940022, 0.11568325891026429, 0.07179443325315203, 0.07628906278737954, 0.12456547229417733, 0.1067707964352199, 0.20568286813795567, 0.1000762138781803, 0.08507919896926198, 0.13122294577104704, 0.10443133661257369, 0.11992759044681277, 0.1757578453315156, 0.16752173299235956, 0.12310632344867502, 0.10048338917217084, 0.14503430894442967, 0.11338897594915968, 0.11429808395249502, 0.07741380921964135, 0.13765737121658667, 0.09910411746906382, 0.1292934093092169, 0.11165905770446573, 0.13202278928032943, 0.10447759913014514, 0.14777484403124877, 0.08830424198614699, 0.15802267699369363, 0.14911381075424807, 0.08475320360490254, 0.13387733405189856, 0.09157423794801746, 0.1733084696211985, 0.12984668676342281, 0.10283295238124472, 0.14683264387505396, 0.11731148511171341, 0.15763370000890323, 0.11409775327358927, 0.18999163726610796, 0.17206613985555513, 0.2112919914403132, 0.12410113721021584, 0.07416224905422755, 0.09905119173760925, 0.08518543041178159, 0.1085102277408753, 0.16602507473102637, 0.16175463316696032, 0.07850699020283562, 0.09758605142789227, 0.10696932899632625, 0.1540353609515088, 0.1732820610382727], [0.00451759243151173, 0.043396392438028536, 0.016750210297427008, 0.0404483850912324, 0.02735464564258499, 0.03142783198771732, 0.04774758984733905, 0.00273521918903238, 0.006798950148679848, 0.0536137456074357, 0.015338882903701492, 0.02813782263547182, 0.014844897535762616, 0.028744147957435677, 0.02583673905714282, 0.08292699445571218, 0.008555206154207034, 0.028597967765693153, 0.00863801032703902, 0.0335717651593898, 0.025509707230542387, 0.03619609433891518, 0.004665454966016114, 0.07528854254633188, 0.07046940363943577, 0.012606706520143365, 0.06312930357775517, 0.06568007956125907, 0.019513973334271992, 0.04082111116232617, 0.006510751729365438, 0.022047814780047963, 0.005961201552833829, 0.04397193601887141, 0.03136183427912848, 0.050734219407396655, 0.05566334544814058, 0.0275355956650206, 0.013278259413449891, 0.08077472208866052, 0.03997050644829869, 0.07096152473241091, 0.021159704042864696, 0.03228995483368635, 0.06510822381824255, 0.047610573271023374, 0.04023546419505562, 0.013439621826234673, 0.026734462939202785, 0.01815599236371262, 0.02466014406776854, 0.05221502709069422, 0.04746992313968284, 0.03654131260035293, 0.0573740577591317, 0.06514751778117248, 0.03267656712393675, 0.07081593147345952, 0.02850806187572224, 0.06010272526847465, 0.08456981594541244, 0.026112054640959417, 0.07892519847622939, 0.02265073555255575, 0.025317300144316893, 0.007514317320393664, 0.030285691310252463, 0.02757743074159537, 0.04155718934323106, 0.028501585258969238, 0.03513331511723144, 0.058556235395371914, 0.05965017633778708, 0.006705161342064717, 0.07470495493284293, 0.058310999268932004, 0.04462144330942205, 0.028504017807011093, 0.003919706812926701, 0.043727402176175795, 0.029890688934496472, 0.025999071775004268, 0.07206280063837767, 0.04364202550745436, 0.010293649343241538, 0.01399183991764273, 0.03484204378245132, 0.043763978606356044, 0.032797661876039844, 0.04888415975230081, 0.020024952611752918, 0.037874681409448385, 0.035989493996437104, 0.036661494722855945, 0.07126948463597468, 0.027822061275531138, 0.05347671206774456, 0.08478739498449223, 0.02554294526843088, 0.06673401407897472, 0.03747260869879808, 0.027702854547117437, 0.020336123682292442, 0.04087483077975256, 0.05252919898235372, 0.05384470535708325, 0.03170758179788079, 0.019754619171310748, 0.05601510478715811, 0.008963415365932243, 0.031436367958251915, 0.004559026748341109, 0.05202879297680088, 0.07991888586963926, 0.007939059886017015, 0.009490042509111975, 0.03608307076085891, 0.007758587382600776, 0.03739726756300245, 0.04935415381831782, 0.07298853274966989, 0.07342419294374329, 0.008406690953831588, 0.08894280450684683, 0.04561115109494754, 0.02102623620469655, 0.03433934772121055, 0.061647986993193626, 0.044184191950729916, 0.023055369732901454, 0.015604076441377401, 0.068027607165277, 0.024215883442333767, 0.02272605293962572, 0.006101203259147171, 0.017897986208221743, 0.021341534464487007, 0.03149650312427964, 0.02798977816876556, 0.04643918773425477, 0.03910603587116514, 0.05232017287718398, 0.017479988280683756, 0.04236405568995646, 0.051629953485514433, 0.03509088632251535, 0.022175961207332354, 0.04703811363184026, 0.04327482610408749, 0.0460171152039298, 0.033576219741787226, 0.021125275176018476, 0.010617894087252873, 0.021053450547956994, 0.0485895194911531, 0.032496697668518336, 0.0800299688375422, 0.012056330651310938, 0.03871270269155502, 0.05297002282791904, 0.011824790754222443, 0.01985017386531191, 0.053527245963258405, 0.0019698119680729826, 0.03783444767551763, 0.04244714230298996, 0.03742044631923948, 0.01863368271317865, 0.0166525945533067, 0.03173601580783725, 0.018583077571487853, 0.011323346590091075, 0.03640367855717029, 0.05813453945198229, 0.007443622453138232, 0.04915081722927945, 0.016021799562232833, 0.011600439087487757, 0.03680596161367638, 0.04945500447813954, 0.030940379215670482, 0.035850574129394124, 0.020963249495252967, 0.03835618342938168, 0.012956611762222434, 0.05333425024790423, 0.007251964299939573, 0.04596007755026221, 0.04325524697612439, 0.03438386979645916, 0.04271424422040582, 0.07823140320501157, 0.03896799131429621, 0.03038912040314504, 0.06186958974493401, 0.017772336789805974, 0.019825481975983297, 0.0470222291270537, 0.025637429573440125, 0.035253595627312145, 0.00859683342943234, 0.047018612535404306, 0.008771697840919452, 0.0553089058957994, 0.035253802580492835, 0.014683033007064035, 0.051811237686446736, 0.05067984839635236, 0.05974245710032327, 0.08962187556815998, 0.04363765574193426, 0.03084446829078453, 0.04460725174950702, 0.04591707878613046, 0.06270544310765606, 0.03888579018946205, 0.038791500963270664, 0.05578539354194488, 0.012522967665323188, 0.04698463828702058, 0.05830511637032032, 0.051223517794694216, 0.020839420247024724, 0.03113760220419083, 0.028396234215636338, 0.02533275547570416, 0.023803230674405183, 0.02517033794096538, 0.0651486577200038, 0.07869916489081723, 0.07047487263168607, 0.04295383154281548, 0.04136249050498009, 0.041807331277855804, 0.09231141874832766, 0.043270921135055165, 0.0029263080089419547, 0.03736786324796932, 0.055077637412718365, 0.017260168379704868, 0.024372202643592442, 0.05190946580842137, 0.029757723212242126, 0.03335734470082181, 0.00948152010927775, 0.055579040864748616, 0.05087895771222455, 0.04118834109976888, 0.06792307206030403, 0.024749376511733447, 0.0285819780879787, 0.024687940254807472, 0.05088164131822331, 0.07943667817328658, 0.02729635948448309, 0.06103104938353811, 0.02583754651381501, 0.00951827465490039, 0.048869466076471975, 0.05697964570884194, 0.03366742502631886, 0.059683560260704586, 0.05455747586009758, 0.04512556768687708, 0.036147670687309334, 0.008180357964842446, 0.06882726747010436, 0.01817201936085309, 0.048129150444375615, 0.023145172146282027, 0.06089501668299947, 0.042244304437190294, 0.05858221650123596, 0.03791176334821752, 0.028580193540879657, 0.014689889603427478, 0.024513176775404384, 0.0452265642317278, 0.06358446486826454, 0.027895188690828424, 0.025589370634406805, 0.022676097495215278, 0.04689472561169948, 0.04162582316036735, 0.014539631416222878, 0.04077670104535563, 0.038381282439721484, 0.012509598829118269, 0.0913624603833471, 0.053499215681638033, 0.024757208502186195, 0.0364774726331234, 0.04931725847667881, 0.03199748249192323, 0.02358883566090039, 0.06701700389385223, 0.0038235685788094997, 0.010950118403083511, 0.05690876594079392, 0.027958363693739687, 0.04166645722995911, 0.01608598727865943, 0.050172602757811546, 0.07464394106396607, 0.036296453060848374, 0.037401827318327766, 0.03495372725384576, 0.0384961380623281, 0.008758591937034257, 0.035660163632461, 0.024322552539940392, 0.04184454553095358, 0.05843818387282746, 0.037432809227279255, 0.05976591405591794, 0.00458934623748064, 0.02772260670151029, 0.029112599257911955, 0.034926121056612046, 0.028753735657249178, 0.006131881523677813, 0.02576401367384408, 0.04158154535772545, 0.03904153433229242, 0.011393105079020773, 0.02761723190945174, 0.02679630970981504, 0.025327143991099935, 0.07326076099915163, 0.011379239215914692, 0.03338125966755407, 0.04025699411119733, 0.05668540917603033, 0.03309725883549877, 0.07354870411966528, 0.03167306811415723, 0.01276106560336692, 0.006570441606787166, 0.04501469506482993, 0.02007451620219009, 0.05702341800289495, 0.02689034448537443, 0.019127388185422336, 0.024861557010029043, 0.017284376812832694, 0.04850339304123606, 0.031195640697010925, 0.011653634536612247, 0.024449062001492296, 0.05331024028626936, 0.01440200415839042, 0.037035153779600344, 0.06736497022211552, 0.10832291814897742, 0.07969161735049315, 0.17852153203317098, 0.11927391695124762, 0.11990141256579331, 0.23044004610606603, 0.09191672171333007, 0.10234430538756506, 0.0957803815337164, 0.08737513755581208, 0.087997693435422, 0.16755063858415398, 0.11285813764802047, 0.2436932192317077, 0.1880980631602662, 0.05091331533289381, 0.11507708286600453, 0.1449840294995478, 0.10680469604475157, 0.06985074933618307, 0.12882549156035694, 0.09590494699243989, 0.14570539364857332, 0.18130771895604475, 0.1296547699187483, 0.09362886234053544, 0.16410867470715726, 0.11415441094764642, 0.09240595903247595, 0.13020381331443787, 0.10288545063563756, 0.10965566949120589, 0.21276477883969033, 0.19725787879100867, 0.10385624425751822, 0.18105041847697326, 0.11438907549849578, 0.11768492364457675, 0.14873908300484928, 0.13975910629544938, 0.16256177771304334, 0.10022583763514246, 0.11707226080553872, 0.13239065025533947, 0.1340926874961172, 0.17475155075745924, 0.1684413786445345, 0.09122276359370776, 0.05592832015827298, 0.11607944193695273, 0.1168559438415936, 0.11093069785939795, 0.14184672784592423, 0.153185726542558, 0.13579806312918663, 0.11667045950889587, 0.1829135806432792, 0.22459217347204685, 0.09705265504973275, 0.21506529753761633, 0.15118970721960068, 0.1972236806260688, 0.11793018691241741, 0.14305793999561242, 0.2001203466206789, 0.23547474880303654, 0.09297599630164248, 0.17768720537424088, 0.15101151035300323, 0.13151326376412595, 0.13787587306329183, 0.1927211665149246, 0.10749695782682725, 0.15668687224388123, 0.0961114726960659, 0.17041025656674588, 0.13594583448554787, 0.12714937435729162, 0.15582317858934402, 0.10011438825832945, 0.07231420464813709, 0.16117340006998607, 0.11146515275218657, 0.12470850747610841, 0.09729540095265422, 0.08922837275479521, 0.09421201569161244, 0.15040780417621136, 0.10235318062560898, 0.18483923588480267, 0.14498731360903808, 0.08798305743506976, 0.13460654206573963, 0.18209676018783025, 0.10860628115811519, 0.07899792385952813, 0.15912681631743908, 0.10449163123433079, 0.24677319824695587, 0.09913539114807333, 0.21205053930836065, 0.17021726763674191, 0.09461634113852467, 0.12525589524635247, 0.12082731431084019, 0.1020025069426213, 0.09273982540305171, 0.13919551510896, 0.1408576952027423, 0.11581435187586717, 0.08642480176474367, 0.18117355901215756, 0.15962541741984232, 0.11314683394240481, 0.08311160347823586, 0.1665647950555597, 0.095804781652987, 0.1621471249631473, 0.15876523857670172, 0.17503934460026876, 0.16718979366123676, 0.10476552189460822, 0.1242256076740367, 0.2034917292850358, 0.0570229905258332, 0.09617912942277533, 0.21532014171992028, 0.1209721001131194, 0.10168808738568, 0.08578706027141639, 0.16411662713757583, 0.05678565933236054, 0.2229610431407179, 0.1028039517945477, 0.11448563103164945, 0.10475773909794432, 0.21131223892526968, 0.16983479101743015, 0.08680911042860576, 0.1081473200715014, 0.11849436163902283, 0.10272233760250465, 0.14459502537335667, 0.09451964311301708, 0.1268981128398861, 0.07483634645385401, 0.09778445506734507, 0.12777239164071424, 0.11752537292029176, 0.16796843973653658, 0.4244323936956269, 0.13189496685351643, 0.1854468232819012, 0.09918839151837996, 0.16830926787640366, 0.21007521530347212, 0.15360731392034463, 0.08685806673020124, 0.2241776157170534, 0.07262118746127401, 0.10967030549155814, 0.10537553166172334, 0.15959538545991692, 0.1594399195164442, 0.11853621367897306, 0.13179706782102585, 0.15254471451044083, 0.08757390081882477, 0.12450736255518027, 0.16055217411901268, 0.07459775318524667, 0.15829852862017496, 0.15011437849274703, 0.09790294763765164, 0.12642102129757404], [0.015726151676582437, 0.019616696750745177, 0.028187708530042852, 0.033497333260519166, 0.03002261310549719, 0.0389383766534073, 0.009622272869039859, 0.038597691005894115, 0.0398350030050746, 0.026391962210514715, 0.03263744958011167, 0.047551425373447795, 0.03756840427273086, 0.04000426356547645, 0.015563718874805739, 0.01445465169048735, 0.04434861794912389, 0.17930244441543305, 0.04489290142165763, 0.018378624792343805, 0.08012663293629885, 0.04552134019987924, 0.09238284134439059, 0.030094561566199576, 0.03398191582943712, 0.05750501501773085, 0.04144398934606995, 0.007126673656914915, 0.039697063621133566, 0.013341921265237033, 0.06482682856065886, 0.04902226198464632, 0.05191802213500653, 0.04261860131685223, 0.022003212976934652, 0.03174684861940997, 0.014481333383758153, 0.048939450178295374, 0.045958343893289566, 0.04965109092050365, 0.05522261320480278, 0.035233239576752694, 0.03567838229771171, 0.07411973204995904, 0.03417872491159609, 0.021115677298179696, 0.026552747868533646, 0.02841939770483545, 0.024433759340484227, 0.03842240844720176, 0.029722554742225578, 0.042820180500192304, 0.033233851327427795, 0.033568213028567176, 0.025307032213147198, 0.023573086863117557, 0.043470159372580905, 0.04700518772006035, 0.013757759755078171, 0.0697425501421094, 0.05448188705902014, 0.0011609822166584699, 0.01272382675337472, 0.009331026979322945, 0.038409214333764145, 0.01724546113317566, 0.015803160312186395, 0.04481142972196851, 0.07740289159119129, 0.03625503867598517, 0.009543271036818624, 0.0313573559480054, 0.021538757453007356, 0.03694482380524278, 0.05200907135648387, 0.03525970244247999, 0.0038325697699162576, 0.02032929931634239, 0.11543707283479826, 0.04388535495049187, 0.022871873507808362, 0.03380445856601, 0.01555070626948561, 0.05455896185178842, 0.007396620332396456, 0.06579659080931119, 0.03805658307724765, 0.013523071455503148, 0.024099268717691302, 0.02133445904058005, 0.036728299888116975, 0.022954810843137757, 0.03392757535246866, 0.058998002404613156, 0.013781233674048312, 0.012235162796319594, 0.039448377144123824, 0.03643602771418435, 0.030672686972788403, 0.07319061404892377, 0.0687611238764865, 0.03637794850926314, 0.026866968953981996, 0.038518818095326424, 0.008442025664927704, 0.05968478162373815, 0.028820510288434367, 0.060876390896737576, 0.01691377116367221, 0.010252861755101808, 0.07648957667074033, 0.05070742405951023, 0.040108710460897, 0.027708756105442132, 0.024040186977280036, 0.02122395622011806, 0.034118084236979485, 0.07436673915279762, 0.04079556431887405, 0.08020737181816782, 0.050426089870078225, 0.01073674373661301, 0.06855831654476267, 0.04387923117194857, 0.03626869758591056, 0.028004054545557926, 0.08510720210948161, 0.04543525446206331, 0.040740925286497386, 0.12897955972169126, 0.03453121028308358, 0.04638065051819597, 0.021700842505586997, 0.03191579705370324, 0.038582518962877135, 0.0712065165862441, 0.06804265707199063, 0.042113038445157666, 0.02744542175371732, 0.07245221188557999, 0.019811163190752268, 0.02698589748303805, 0.06728471310010978, 0.02631020891879286, 0.010034245405612248, 0.03544041667399662, 0.04574581315474851, 0.08435760411833014, 0.022484930431736366, 0.009672665120368558, 0.02549316454678774, 0.04575346024440868, 0.03491406348933067, 0.053408261455063305, 0.019145998704646314, 0.07384753094187804, 0.06902618001082114, 0.06548044777342252, 0.05121451363499675, 0.020046446904806153, 0.03158295187833054, 0.037027693287070305, 0.03160798303516848, 0.06012102535792759, 0.010295006413278835, 0.037073097457843165, 0.09943879129631178, 0.06588076986372471, 0.03397462157798665, 0.03638501884415746, 0.016029044619894454, 0.05515761972804155, 0.014828553323500922, 0.023338571589972292, 0.027874710503965616, 0.08516256378165313, 0.017683435131662657, 0.03391643041478736, 0.12764520703681878, 0.02241368086210319, 0.0349738390317985, 0.015555020055866666, 0.028457409236580133, 0.058527635144335885, 0.05867896880954504, 0.02352983195201627, 0.006977781445519733, 0.017145031165065508, 0.019548573531210423, 0.05024842226079532, 0.01483745061393295, 0.03395848601524319, 0.01590491003090782, 0.001873242440134553, 0.0523563591497285, 0.0570004495925137, 0.04180511586101992, 0.046394363710922856, 0.07135203520634345, 0.10135555094374077, 0.019912454898336103, 0.03185521744723831, 0.018188263489199535, 0.018572166728387986, 0.02985689110521759, 0.03098197341231363, 0.04025140976799386, 0.04214815263237272, 0.048613339462982755, 0.07596633796180997, 0.026063135658789958, 0.026008871517011097, 0.034429769297795634, 0.008649340165512902, 0.04059878237811582, 0.05890689550765923, 0.00787011903178479, 0.02457228396087885, 0.07604666972266776, 0.029330527742526362, 0.02798007002898625, 0.1059640318687473, 0.052582660756473026, 0.01817879792568939, 0.03198217474190252, 0.03709864090862019, 0.0839984691036599, 0.015579401515424252, 0.04424576561099716, 0.05335913212703807, 0.03699943908889379, 0.04663336070786629, 0.024366431703258837, 0.04342366615310311, 0.03883408921371613, 0.033255849432732375, 0.04849183080451829, 0.017313277315614477, 0.010705575230531394, 0.03197139621313129, 0.043825565837323666, 0.0563194922038487, 0.017250545056802884, 0.019797763820471506, 0.03512379866359489, 0.0171959416475147, 0.05791151856205293, 0.03703699939485107, 0.021720358869060874, 0.02407855473990951, 0.023249786979119693, 0.07304918020963669, 0.043122796940484216, 0.046585174543516975, 0.08080154457794768, 0.034848316838698726, 0.0663875744545034, 0.03232581880209701, 0.01682198403536209, 0.0474289769439825, 0.04101881591070976, 0.043412609424974234, 0.01925678820615368, 0.09824447466858796, 0.010765681558820819, 0.06835958720850092, 0.023081596807709763, 0.03495639389646905, 0.002300838881637901, 0.0445541428135974, 0.047752197100115676, 0.0165174218959042, 0.04958204658968108, 0.02487177405107234, 0.060474474249141555, 0.06535024368869406, 0.014312188174309475, 0.04049098012702806, 0.06812397270862545, 0.002607954221145649, 0.025284462442089404, 0.05770672990807465, 0.05463710533721106, 0.020742764629955803, 0.0588089150509664, 0.034080143951411755, 0.036746538909418244, 0.07203266689819948, 0.064563292344766, 0.04385331791958638, 0.029030934175742523, 0.03757217014208436, 0.021669217684705342, 0.013736452059155064, 0.07292491330632142, 0.04544056739125933, 0.04886636517143675, 0.053495867111321004, 0.02136607368343643, 0.029491347327296222, 0.010732487625708538, 0.031240447756967375, 0.004453472992671388, 0.026065692039472715, 0.037157843088997264, 0.05449088443336742, 0.05355521856940218, 0.018902528465592434, 0.018370506120845675, 0.06879908112542969, 0.009382837368840618, 0.02057209610939026, 0.016229237895458937, 0.03923819752942238, 0.02522629333127822, 0.01516953922275986, 0.060580481775105, 0.0546835748079632, 0.03617639307464872, 0.01369039055758289, 0.030780838669410775, 0.04160271904298237, 0.026850295652236258, 0.017109801626897285, 0.01907879320372428, 0.044652516820601056, 0.0366487654059061, 0.018811173903356706, 0.03154479446155684, 0.04924544233030506, 0.01545305659861437, 0.049858871913914166, 0.05051645037851163, 0.006832024065910706, 0.051063451383795054, 0.024845190745379244, 0.036112013672079356, 0.02367209190768855, 0.011364502283478422, 0.004354381858969906, 0.03203039822567787, 0.0125912257436929, 0.058939349837601185, 0.026198998725573932, 0.03891845825793488, 0.033140121892626793, 0.05525108453418527, 0.046435869698013575, 0.025982079561799765, 0.05566344383571829, 0.013758679170028439, 0.035890539841992516, 0.08697594183364085, 0.18472879752516747, 0.22903357871941157, 0.08746455490056958, 0.1505155148250716, 0.11678256706467696, 0.09623142411666256, 0.22160233104867594, 0.15479371882975101, 0.13913945454571927, 0.08193674044949667, 0.13769688909607275, 0.11886096053889819, 0.15989046676882676, 0.1559425736112254, 0.10128258128783532, 0.15982143261602946, 0.23067734337278775, 0.11496967077255249, 0.15893350169062614, 0.11252297527555909, 0.13123752070324762, 0.16934547227408203, 0.14825228841177054, 0.10985019191035203, 0.1334793461220605, 0.11878842514540468, 0.11516707018017769, 0.09648596974355833, 0.12876975669392518, 0.11447614511208874, 0.12372266394751412, 0.16566140710243157, 0.1379840722573655, 0.10324004625103303, 0.11061944706099373, 0.12399932981601783, 0.08619271564696517, 0.20780000596174172, 0.10499763515378747, 0.14290032988148077, 0.10510457905807666, 0.15541923312204226, 0.16644530503877572, 0.12989687121340207, 0.11166477096932274, 0.12319537438452244, 0.13051291315683297, 0.09709955539022173, 0.10189350029187542, 0.11619456218821661, 0.12041365222207137, 0.07641715662819998, 0.17417434815849575, 0.11195553679551397, 0.13444027384477003, 0.12533007269459112, 0.1406161231654031, 0.10219027115298168, 0.1689870022237301, 0.1441546425755535, 0.1068861677444407, 0.1657780065600361, 0.07819683184581143, 0.14277542515524796, 0.164801811799407, 0.1773568538150617, 0.11602818540164403, 0.09084881615958043, 0.1228131963206189, 0.1782951591802495, 0.17989115496831282, 0.11881529513214316, 0.14106139141534055, 0.09719549345650844, 0.15573373410318578, 0.11424350259559495, 0.1264314435954605, 0.2613462848322732, 0.16052854752966336, 0.129132623651198, 0.11587913839944772, 0.1258822102099657, 0.16532937277640614, 0.14598385084952625, 0.18639329820871353, 0.13353566452860832, 0.18574727858815873, 0.21201050574226038, 0.14626240304538182, 0.08759826701134443, 0.10864199924149684, 0.05325442399563534, 0.21493203325995378, 0.13171968768749917, 0.14149691590241023, 0.08526229485869408, 0.09244406555912324, 0.13766434655657836, 0.12006165539579731, 0.1489501888198512, 0.14637619336800917, 0.16826172971299716, 0.06983224568622452, 0.10141431207635573, 0.1656769998371601, 0.12907063269189425, 0.1305622019405876, 0.11729480672095503, 0.11940783262252808, 0.229204460978508, 0.18020413603101457, 0.17683143700872148, 0.2053928351295846, 0.059820685402623246, 0.12749290306653294, 0.12454864462571484, 0.13184292321758612, 0.07399663901222603, 0.14098804177982466, 0.13381237110921315, 0.13304276312036173, 0.187797146450196, 0.11640850427959647, 0.07675983038331781, 0.11767705263836042, 0.19292811969561235, 0.22836804443172046, 0.12078190674739224, 0.19733611387865885, 0.09704502153077296, 0.10975648622427668, 0.11919177350189004, 0.13175033032894135, 0.10849283688834735, 0.15033867502851145, 0.25995930497135433, 0.08554386653538261, 0.12303954203213964, 0.1428332363388368, 0.0910637489120875, 0.09139581037951366, 0.0958595529996923, 0.13533467799425125, 0.0908768939386521, 0.1947117575577327, 0.09720286234681096, 0.1731804572045803, 0.06468871954296317, 0.16375062534851687, 0.0784883779872741, 0.12095090267913682, 0.22660180420747825, 0.22584274065281662, 0.13399366209549562, 0.17116153053939342, 0.13815689512661525, 0.09761642944067717, 0.14041752953614506, 0.14154927166444914, 0.11065229494124651, 0.11642732684101377, 0.1290466125522341, 0.20686772598751954, 0.08006078111273901, 0.1512264431055103, 0.1742617298981973, 0.16701383596020086, 0.14542211884898798, 0.10987990495881864, 0.12748809903860092, 0.09401296744389193, 0.09057756500052554, 0.1793065427669457, 0.059822463164372106, 0.23245016538671084], [0.011446099512145987, 0.005593859657113041, 0.04121682939252683, 0.038940473326614926, 0.01841606296199773, 0.026257103375558342, 0.05128018564677664, 0.04663208166935614, 0.03368375397154263, 0.04993698825793607, 0.04604382573493889, 0.05062097530545933, 0.0735726428351232, 0.032817105296999216, 0.05402682415608849, 0.018085685957755362, 0.05583264672064355, 0.03969084484768765, 0.04497197450005582, 0.08569937997630664, 0.014900160820356436, 0.03158148963536535, 0.05361197463103703, 0.018787121533283165, 0.027835199409829717, 0.0411421939331506, 0.07398004883102008, 0.08833936295871224, 0.0381381904839405, 0.022070269200152585, 0.040649390912481716, 0.020745008884529983, 0.029027358296194246, 0.01670824969187379, 0.03338237585765975, 0.0325625325287027, 0.062119114212691784, 0.0266469268327845, 0.05335263515423451, 0.018674550877351846, 0.030622624659112523, 0.008460575116000004, 0.058947112278214524, 0.03231398515137179, 0.010541020310483873, 0.06911396887153387, 0.06213487658117499, 0.04646023589053324, 0.029193680799965347, 0.03133226033034069, 0.019332845196393982, 0.05393893690779805, 0.06462326126971416, 0.0041959452043686596, 0.009428907352100526, 0.026675325219652483, 0.01603654582452561, 0.044253463590783734, 0.003047103781552453, 0.11417100791420255, 0.04920529341325164, 0.018874801828392913, 0.036546272691339254, 0.02959242868902428, 0.08304447600884096, 0.025843527800004398, 0.026110660251496092, 0.026936883505965983, 0.03163207781368068, 0.03875250555574894, 0.023075325447799902, 0.048347601400954385, 0.04326485503198845, 0.049663603106247525, 0.06961584051272698, 0.06397962330707482, 0.05447408051363059, 0.049739012095545015, 0.009375661012849637, 0.05203337987352695, 0.03738642118072935, 0.032709530355142694, 0.026031001936644316, 0.0320880635242377, 0.015731026950691427, 0.028689010201820304, 0.039231910902474604, 0.02352615598855274, 0.088897037319839, 0.05895769063915525, 0.030829917107309614, 0.03824906649866274, 0.06654700304248504, 0.016203484098826135, 0.06088251806795597, 0.07407534907438926, 0.04159315848456962, 0.15391509740480355, 0.04003972041287592, 0.043937490188649723, 0.040481433139315674, 0.04430038767999836, 0.025274676270782948, 0.03651636286771723, 0.0576164372531431, 0.0066296755934932405, 0.060513578222266266, 0.004843697633727321, 0.032670171931385994, 0.030697263511163846, 0.040582735024924786, 0.04107273569596665, 0.017806178723861064, 0.0026279886036978234, 0.07307434707347836, 0.06091667552079473, 0.0364931875041553, 0.021218471960829835, 0.05158404380615268, 0.037553300083215745, 0.04279053869790264, 0.016202018463185856, 0.04004403928826962, 0.008051288729932691, 0.024029746019680585, 0.03704970157040017, 0.05579536122136882, 0.05922261785183634, 0.015397562612114208, 0.03681603107335312, 0.03663956107837813, 0.03835623771218317, 0.02939884943355407, 0.02016357901240034, 0.060646659295473776, 0.01707227185501584, 0.06865996787590639, 0.0171875837924225, 0.03602187368752701, 0.09015168928142105, 0.03896549430542758, 0.01787301103052284, 0.06084496115467378, 0.015404249574722988, 0.00848506174848548, 0.018437942323674048, 0.02018748889011996, 0.04416044322507722, 0.04078754064227853, 0.018810240917706063, 0.03400218367044415, 0.05471529292740992, 0.08725448724414621, 0.025402352812566927, 0.015072434076241084, 0.0512064594243254, 0.02358193156708564, 0.05526264677090304, 0.01639745181559452, 0.07870620808431081, 0.044762758405080864, 0.03721172894750323, 0.047237307764589787, 0.03219945522557412, 0.03734687615984252, 0.0688107790691512, 0.061086696040417464, 0.06720171469662871, 0.012163049790875187, 0.05089496774598956, 0.01952537102624774, 0.00836618580589337, 0.048989627842924426, 0.03252807312778064, 0.053721032171909294, 0.03503121256030031, 0.029488358380539075, 0.01930122376818742, 0.05176238655777914, 0.021122779863487397, 0.02274487550104303, 0.065823291162295, 0.05987515140857015, 0.08202442752995662, 0.008924444555304945, 0.02910582747842584, 0.018126072362065315, 0.009739588181089078, 0.019445259789271013, 0.09075247097228255, 0.021958784200251102, 0.03482250536658934, 0.05687746172770858, 0.04485904252422707, 0.006554257274339241, 0.014658454772351044, 0.05701548592852695, 0.05426053197256156, 0.019403238115566115, 0.03863751422613859, 0.046560313020433695, 0.016752787034160325, 0.009910570524100746, 0.05114943194868309, 0.054053015607808313, 0.035597799478897026, 0.01577698752017958, 0.03245407888399703, 0.029638219624757767, 0.053396346380135844, 0.021545500394755175, 0.03816553544519203, 0.03191549510561994, 0.016851522361061404, 0.044707291559981446, 0.04815553867125085, 0.03414624683292849, 0.025514813206557716, 0.007896741353241461, 0.03529446039881025, 0.07354826307190315, 0.026798265587006296, 0.056199211693767986, 0.01631610225220876, 0.04984446322279317, 0.024958216019773057, 0.04947943513148597, 0.012212138406799307, 0.06711166631430387, 0.04948930103065712, 0.029458774253726006, 0.015129797426717622, 0.060624437273613045, 0.03838207971836839, 0.06891464920980589, 0.04397568831752453, 0.020738260853769522, 0.028630815645945922, 0.054027207528374026, 0.04023515885429723, 0.0443692963038172, 0.019362380129418204, 0.0648631573255573, 0.019689903893907155, 0.03771803481504321, 0.014841784756364567, 0.027897000379328216, 0.034907156002840826, 0.06085430458188057, 0.01744812766888312, 0.04400576777490122, 0.013194352621212602, 0.027338769619486163, 0.0601667586181845, 0.04084250197878905, 0.029868134430476596, 0.028803343352462565, 0.034217645680265765, 0.07226952311715909, 0.01453350085232939, 0.04035793298057147, 0.017398494528606534, 0.09317767726523535, 0.028866643884352276, 0.018407526991463134, 0.025953949196264148, 0.053639472262667756, 0.0635775573817747, 0.062056295440665314, 0.0708421907786812, 0.023896608967334032, 0.04266591556370258, 0.014268595692036408, 0.018383031877289926, 0.05751807003148964, 0.09048096196992056, 0.05331471522471734, 0.05791074503213167, 0.011112991404453558, 0.02995250347469534, 0.05008681557540383, 0.06056329448308263, 0.02474132739007473, 0.008942848121348237, 0.018975080822461417, 0.017012738888817172, 0.05476913807381477, 0.03424646306250777, 0.010210157305534397, 0.08543767580496413, 0.04880304089082139, 0.039254814852029085, 0.047411416457699876, 0.06206459392394338, 0.06833442713000945, 0.018621039909443686, 0.017220938877601708, 0.01066842459009162, 0.025771201056029116, 0.036534225302083154, 0.038353408221155405, 0.011681786954535969, 0.03302426543086767, 0.03478586447558232, 0.013130149637748088, 0.016214323695749044, 0.06872982305607625, 0.013251981448515185, 0.02003434014373592, 0.018123512588707463, 0.05168458233986582, 0.01946795848198235, 0.05340862447129829, 0.050880158719207556, 0.030905797678445066, 0.05787698791495391, 0.01841340140838708, 0.03514887731788414, 0.017757156265101263, 0.05504554949168648, 0.019411333038338592, 0.012677492989626313, 0.048850555305502245, 0.03660277430234211, 0.019639931486121247, 0.040819984794195206, 0.044901138836784024, 0.042534045675503354, 0.03108604032812374, 0.03137088593627725, 0.016449551430663893, 0.08131558235202517, 0.02214190044573375, 0.04276191469814096, 0.02778558662560369, 0.051062833916928084, 0.06372845678457192, 0.02810901203858001, 0.03552717076880591, 0.021985596511512995, 0.05258182955107518, 0.034670333710632155, 0.06018516727324043, 0.02030117403981941, 0.008167153673379548, 0.043088334146887064, 0.03622748336887785, 0.035644828741039546, 0.036373300544385395, 0.05514268856495619, 0.05565601387726409, 0.02687262793603752, 0.07747736080948796, 0.11308309914810316, 0.12650066773806298, 0.10962431438799415, 0.12103130907884666, 0.19846094852047308, 0.19815403356083802, 0.1530173412923302, 0.14514796356005327, 0.095854884678764, 0.18765212994601044, 0.1171879917383194, 0.15536804444023541, 0.13683901727199554, 0.07071959985686199, 0.1415635073291404, 0.13908445249710763, 0.12855303260896886, 0.1291773391089269, 0.14004813507199287, 0.11926445817308766, 0.10240982472896576, 0.20609499673758233, 0.1895495309893574, 0.13730947274182523, 0.110947545883911, 0.1509481623236622, 0.13205310622496264, 0.16667702474764415, 0.13539035857788154, 0.10295973664947919, 0.08380801789462566, 0.16236019852970326, 0.1247399915009737, 0.11563679283218724, 0.16912589834204741, 0.10980633819209677, 0.13942723481782845, 0.12779352122119494, 0.2317990974656173, 0.14242931801293576, 0.10836191355649914, 0.13061648474207946, 0.10036647758845772, 0.12140206061303616, 0.1394059152475425, 0.1464003220732723, 0.17785991967788764, 0.1909835333270686, 0.09527950055365052, 0.11978754081896373, 0.10444053754742656, 0.2594337931701115, 0.1668149980583361, 0.061272763913231235, 0.0873648848916803, 0.06190319758440767, 0.18030443707747118, 0.23215359130076, 0.22181638170565876, 0.13203749991953373, 0.11752672999032907, 0.1919123392019953, 0.15356863742428167, 0.15766833243625505, 0.1299427401806627, 0.12432577301348958, 0.08964166843465396, 0.12783302552998066, 0.1579528964523758, 0.155408200142639, 0.1457797068038157, 0.1339626530451434, 0.09607117450130837, 0.13303177085305962, 0.0852418980960335, 0.1352719542171274, 0.1689648955528225, 0.13439952103155, 0.14539451604442938, 0.07949917803385428, 0.16148190280156477, 0.12829710277063505, 0.08166798629931041, 0.12368062191775867, 0.10479633416980505, 0.1847156203751053, 0.1520176963614566, 0.21392957919410296, 0.12488667720130511, 0.13722381448107107, 0.14041121916047164, 0.14651013618069036, 0.1279213029359068, 0.14984664214508875, 0.1787648004080568, 0.06479804510516779, 0.25260042984570774, 0.11707671199526105, 0.14557522349059582, 0.13053564407995769, 0.1416611485183239, 0.10350153329116957, 0.1267757322639227, 0.1484777248863663, 0.1010128975446735, 0.15744162031582423, 0.056847823318094015, 0.12699728751821177, 0.1841500885784626, 0.15500224621168204, 0.12297998022820268, 0.09723982893462692, 0.14088349310415132, 0.11344980661358152, 0.13282496695007595, 0.09135785313057047, 0.1697446137134518, 0.15094774163195065, 0.11293833370187453, 0.1587738831128393, 0.2047828050064189, 0.16120172212166445, 0.09442808159760066, 0.11532316037586757, 0.1376460532524756, 0.1043345368068133, 0.09826969581523112, 0.05579817035634603, 0.10165388243538992, 0.19220942897456034, 0.07665809762797185, 0.10622819233685732, 0.08762271462806634, 0.09625732379832438, 0.11918373964726925, 0.10116229738507952, 0.08197348312075649, 0.1300482116639614, 0.2773165021623884, 0.12505023128220014, 0.12927743659487792, 0.12652106450072356, 0.13806561859590666, 0.1225648932158947, 0.10625018365681171, 0.12362487348062651, 0.1554348258567708, 0.13535077284489358, 0.10030031363878932, 0.10185423347034625, 0.1159069040524108, 0.11934334465435573, 0.1497105008789471, 0.10059920152915375, 0.1413923536560365, 0.09272047358431987, 0.1353794341640813, 0.05251413211226463, 0.20478610268660954, 0.0932034548105938, 0.09284450300037861, 0.13741468638181686, 0.16004133224487305, 0.11837797931262425, 0.2538771613367966, 0.10122937057167292, 0.11947698891162872, 0.10586269266371216, 0.14539413606481894, 0.10103984217026404, 0.10103294146912438, 0.1447953289108617, 0.11332499009690114, 0.11688995201672826, 0.11541234701871872], [0.031391245379511795, 0.021575411914714744, 0.013608772972864764, 0.049959837924689054, 0.004487660555501601, 0.020688298624008894, 0.05530668030093823, 0.007190343142221016, 0.024291770798819404, 0.03564076092360275, 0.01416915129604084, 0.022852961040501083, 0.05478187756878989, 0.02103929970014308, 0.04136670420744589, 0.03959707470078554, 0.0580667605889695, 0.034858773063336096, 0.02806788942377482, 0.02597153852028506, 0.039721833541989326, 0.03398467407428792, 0.025692541883992295, 0.015167491743341088, 0.07660278345325164, 0.04501193681997912, 0.0028282599107894513, 0.056521617607878785, 0.0709105192550591, 0.02435824178558375, 0.04985831551519888, 0.07651633809187583, 0.021106661264119402, 0.05450308110032763, 0.04650930075773171, 0.13438417256942817, 0.03788267455196806, 0.022087493811600974, 0.00918811054102012, 0.019530763683308448, 0.03503296318064843, 0.08146397117525339, 0.05587360987971936, 0.03905220429546066, 0.03694761258416942, 0.035821108746209314, 0.013108635836813067, 0.030860800628683398, 0.049863960926554034, 0.06558189554406063, 0.022279946698940227, 0.019918061293927685, 0.03302815004384943, 0.043054963794669936, 0.031977489457598755, 0.039559226017445326, 0.039950068973537, 0.03235743174861584, 0.02062569189417575, 0.03343390380697591, 0.04263988356771214, 0.028338277147018483, 0.04017918989328401, 0.048540400341153145, 0.06277394121778862, 0.025534829989607846, 0.01756064573835049, 0.008539266518450208, 0.03259001658963306, 0.09211190909679447, 0.05103720225659864, 0.022869054194805876, 0.03533140663057566, 0.0383721866777965, 0.03406845618571554, 0.023277042034481252, 0.032058136737240214, 0.036620674056134055, 0.04900571930089167, 0.010984959479953562, 0.030960504564323595, 0.0752869751304388, 0.05621586972847581, 0.02277882260802601, 0.05124346333156739, 0.03750760414238487, 0.04609235455947263, 0.06363054418138095, 0.026380596748952354, 0.02186930918001703, 0.04055599056716476, 0.015357255935668945, 0.029585229432476417, 0.04912094133240836, 0.05354038240121944, 0.053157098325235505, 0.0306177154582526, 0.08374886321169989, 0.07784687062459332, 0.10615035079951797, 0.015252753061109355, 0.0655763383422579, 0.10263721538441521, 0.04062327749228903, 0.03364695023213114, 0.016089904122054577, 0.04387179782081928, 0.04500643050830279, 0.008274973736011555, 0.03979470141764198, 0.057992237087871344, 0.03354098002559372, 0.030881180427968502, 0.031197197934878722, 0.027544479384752255, 0.027384813309514096, 0.06806778322373118, 0.05431890973289098, 0.042162160987832716, 0.031392646554325304, 0.09649709771786417, 0.08960398938506842, 0.012959438708743878, 0.031203308142721653, 0.08313930806304727, 0.0431048836159919, 0.009833530506252177, 0.03149826052997794, 0.03897686655234013, 0.05141636762501938, 0.023404065486309782, 0.012840899489154773, 0.049145670541163, 0.031161598595125333, 0.06689000927976199, 0.06147096399217844, 0.013817233349462705, 0.04855862918442913, 0.042522751460117955, 0.024182251854134456, 0.02809724284868155, 0.04321522358804941, 0.08417097984680108, 0.06886358266430241, 0.03859828472403543, 0.04238066283453788, 0.01025097627591874, 0.030517207458615303, 0.011961499445273407, 0.042428553836154084, 0.05128397526485579, 0.025298350357583592, 0.02822565899363586, 0.02414864910367344, 0.024409533943980932, 0.05096601714779224, 0.054368283333522935, 0.056859701073595455, 0.03222239988722971, 0.04675651142107589, 0.05034427211752959, 0.03795466372477157, 0.07823943027428218, 0.031554582329200845, 0.007506546398092593, 0.08094239487711873, 0.0707331027037331, 0.023469640806849514, 0.04499247304296919, 0.05559157679921814, 0.015566860491942083, 0.025680350306044732, 0.07895757138196911, 0.010756970865518918, 0.008076142619497009, 0.02745345900101321, 0.034042112063616514, 0.07328659282731158, 0.05298922876162188, 0.040720443706959486, 0.01713618646109743, 0.07826444786041975, 0.0078083214549613846, 0.031334411286349804, 0.009372104641183146, 0.08784570837659494, 0.06139933783560991, 0.01921092432790569, 0.007231943276045578, 0.026622178964316845, 0.030259696633688042, 0.020780058610918264, 0.07921282947063446, 0.022245236240061264, 0.03532695883352842, 0.05612275097519159, 0.025106523418799043, 0.018852379638701677, 0.043529907773647986, 0.036307750668908866, 0.07849910562591893, 0.07396868336945772, 0.12448649081800665, 0.042450372129678726, 0.003869909976076867, 0.07220217851655823, 0.020489001014669026, 0.042132997552731206, 0.01742415502667427, 0.047142309469303915, 0.0724539625059281, 0.018136389487023865, 0.022769832019028918, 0.048843617284936566, 0.06348569731095008, 0.021894503185259442, 0.015016902770314897, 0.019850392692855427, 0.07894493705992188, 0.020461130188778043, 0.014886837785265275, 0.07503071280994586, 0.01671940989659301, 0.050792549670274766, 0.032692509304199896, 0.04702169308438897, 0.028440761379897594, 0.020901840379727737, 0.049860127203698666, 0.021010602757866894, 0.025835258154464618, 0.0410688442976347, 0.19423405533390387, 0.0219395833555609, 0.03539179963991046, 0.0076774261126826915, 0.059237810250903876, 0.057430131893072806, 0.02330797814231898, 0.09144316533846514, 0.07609230120267187, 0.007106719638354012, 0.05611092071714146, 0.02197749649972788, 0.03629314859530755, 0.009365165772448693, 0.05623056340430464, 0.010768143792769738, 0.08571763935365848, 0.04056488616125924, 0.013168419012799859, 0.02037529381258147, 0.0505266555451921, 0.03508262176598821, 0.041704271986548386, 0.027803242106788924, 0.014833196199366024, 0.023560062383434603, 0.029499764554202557, 0.031608200166374445, 0.02070773865229317, 0.006683408357535622, 0.04067476472950407, 0.02835029739487384, 0.01592588863734688, 0.037862260825932026, 0.05228806799277663, 0.028718716464936733, 0.041547204700431654, 0.04521974834746548, 0.03827044374442526, 0.03152245369606784, 0.016771090516288365, 0.026836017579106346, 0.023634501067655425, 0.03211436014888542, 0.03693514111052666, 0.03187071518706424, 0.05611140926235488, 0.025065020824383413, 0.03743539105302521, 0.051243439582841735, 0.04704939766920038, 0.03271276357450655, 0.00046326803463411385, 0.019452699925750494, 0.04432966646605304, 0.04041779673259173, 0.020562710273744803, 0.04399800533428788, 0.036552447360008955, 0.058533674106001854, 0.030369001839842116, 0.02632977786873068, 0.010419071452426059, 0.04880944626139743, 0.009292045990670366, 0.025929314982412115, 0.03649081941694021, 0.016831629410652176, 0.011949151804271554, 0.0496018665975758, 0.05262518793876682, 0.01735054754785129, 0.048527118018163104, 0.07806924690625497, 0.02133979571850172, 0.030726654255496602, 0.04231390516672816, 0.01971713180786797, 0.0748709924519062, 0.048478066721665006, 0.014857715062264885, 0.0159937268721738, 0.017643138633242676, 0.009143745376994568, 0.005187375620672745, 0.030868766629802327, 0.04642131172918847, 0.06311867093401295, 0.023382954565542083, 0.05756672777767692, 0.025594469825071946, 0.021883287001401186, 0.05266640894114971, 0.014905271885384406, 0.04714712028258613, 0.014754869509488344, 0.05858951075268643, 0.05302325050745692, 0.012530026974023452, 0.05297628231346607, 0.03940735970224653, 0.03193828370422125, 0.02314025955274701, 0.06222624810678618, 0.15072895480053766, 0.061104975773819854, 0.027878988667258194, 0.03337653706382428, 0.07483531508062567, 0.027441940869071653, 0.05032204670299377, 0.03729294280388525, 0.04369590797328523, 0.02866695442103914, 0.023198359113718783, 0.005516971037390509, 0.08597324349518333, 0.029311946061040674, 0.036896647818918736, 0.08655183709093503, 0.09794351724641663, 0.15942286114607537, 0.22169067630810396, 0.10610448861760752, 0.06686986357505832, 0.1423453153776271, 0.10764833898948771, 0.1298945913357394, 0.13589288161269256, 0.14530200457998685, 0.09620403844330992, 0.07952238393149205, 0.14060713936175617, 0.1431287790515593, 0.12296076411647455, 0.20721698153231824, 0.11483772285282612, 0.09564078652432986, 0.1063019015959331, 0.13982736691832542, 0.1526739482900926, 0.19002818316221237, 0.11726895453674452, 0.11428751237690449, 0.1473973071468728, 0.13654769504708902, 0.20026545811976704, 0.16350838834685938, 0.11820267300520625, 0.2138026931456157, 0.16086917210902485, 0.11863020434975624, 0.12078126892447472, 0.11351428779640368, 0.09802375401237182, 0.1356816672320877, 0.07880834117531776, 0.10907012091151305, 0.10340748155223471, 0.08121069440884249, 0.09088435103850705, 0.22722996478634222, 0.13042094452040537, 0.12522321699985436, 0.123251719932471, 0.13443738328559057, 0.09489243025226252, 0.16033493434744223, 0.0898414562855448, 0.1357624400407076, 0.08405947618718658, 0.09376220804240022, 0.1456038983804839, 0.07887784351727792, 0.10855730450046913, 0.3747624361089298, 0.3548855126968452, 0.06644283434642212, 0.18426995857485703, 0.07619788803692375, 0.13811583018728665, 0.17716227711311408, 0.1423387878707477, 0.1856723954635007, 0.1425041061426912, 0.10000190072293792, 0.18920030258595943, 0.08968604462487356, 0.14380719193390437, 0.20488002550389084, 0.19736130109855107, 0.1334202185805355, 0.21607467266065733, 0.10857514997145959, 0.09719083870628051, 0.06769950155700956, 0.16499265655875206, 0.1457362805626222, 0.202895012018936, 0.0814300783510719, 0.16913949618382113, 0.16140644970749105, 0.12190956409488406, 0.13721147871443204, 0.1843496457274471, 0.0816864153104169, 0.2866022267511913, 0.10890906383948666, 0.16423216808055127, 0.10712760407477617, 0.10248717093574149, 0.12781979409711702, 0.11437982028084141, 0.24764191306063107, 0.23244294577411242, 0.16798431745597295, 0.10217830179525272, 0.16347623935767583, 0.16815977304109506, 0.18303786111729486, 0.1717209962329694, 0.18464316640581402, 0.23164699705583708, 0.1108881469283785, 0.12649456092289516, 0.10796358635915176, 0.143250223249197, 0.15623555146157742, 0.10385412044290986, 0.10522467975637742, 0.2167455538042954, 0.21004668969128812, 0.13186671265533992, 0.13170116368149007, 0.15560116193124227, 0.1259943584778479, 0.3219766185751983, 0.18005975734974655, 0.09925733067627464, 0.08886392481092896, 0.15123476194483892, 0.22400068092559064, 0.13161353766918182, 0.2376519776880741, 0.12499018093304974, 0.10800160467624664, 0.11798939587814467, 0.15077117324939796, 0.2241291140339204, 0.17782874777913094, 0.06833347718098334, 0.09958325818713222, 0.12286426286612238, 0.07730201378996883, 0.1527060294257743, 0.19117513804563455, 0.0751307492277452, 0.0963631956172841, 0.08313263127846376, 0.11945477367511817, 0.17472412437200546, 0.13317605453942502, 0.19736754362072262, 0.1887606933180775, 0.11372759206486599, 0.18226776458323002, 0.10851648383374725, 0.12549055979720183, 0.09541401333574738, 0.21994950116745063, 0.1603857430496386, 0.10482874778764588, 0.10839710916791644, 0.12074876709708146, 0.135825693075146, 0.1310055431510721, 0.08894920309207269, 0.10392404347658157, 0.09626512016568865, 0.1376903208770922, 0.27431897872260635, 0.15315478534570762, 0.2025840665612902, 0.11471766286662646, 0.14550100533025606, 0.203635822981596, 0.23623603795255932, 0.08064758498221636, 0.14089694166822092, 0.15918690737869057, 0.07205801696649619, 0.1294809699590717, 0.1398422268352338, 0.11049811821430922, 0.08479312182004962, 0.1811870482883283], [0.06430418696254492, 0.04521351939599429, 0.02549227566591331, 0.006553469749633223, 0.05651075765490532, 0.062005337460764816, 0.025188017170876265, 0.05695817007550171, 0.011523205687158873, 0.014539546599345548, 0.04022546598155584, 0.0351001483255199, 0.027375568269885013, 0.05406928348488041, 0.03268363067348089, 0.05039274665926184, 0.048357253561594656, 0.004332335408045245, 0.052556204676095924, 0.037793878066752634, 0.08088031570826258, 0.01619204060573663, 0.02661814846630607, 0.02871109651667731, 0.0190702504478395, 0.07347818397517715, 0.0032818357618193007, 0.045813693798014095, 0.025953630284805383, 0.0159253763434078, 0.041735912074467967, 0.11327726872903959, 0.08086999519062893, 0.020481796669108526, 0.025193484466789023, 0.04511386974315558, 0.024541595518322926, 0.046565866829561334, 0.013412294676527381, 0.024880929184811454, 0.08071646307195936, 0.05430961719581059, 0.01956086858574833, 0.01814354124612042, 0.019544000205184733, 0.055029631060148985, 0.03532362722658685, 0.010815259568127138, 0.027808371831529906, 0.09293265827000141, 0.01753649498069925, 0.0391836195651974, 0.04510917088815144, 0.05628922614934189, 0.05267558612727693, 0.025620284689856426, 0.026742021819310527, 0.05636659610484328, 0.024545191753921763, 0.013385771590817188, 0.027355610858649015, 0.05465305769549949, 0.014123183093033731, 0.04315015547243612, 0.059997769471790106, 0.01599467682119991, 0.006087363265188677, 0.010472992934020502, 0.03918032867035695, 0.011277958534524908, 0.0246610923204571, 0.023592531980414475, 0.0583505578605192, 0.03699317281799657, 0.06033094373664685, 0.06188352685421705, 0.07125134739492621, 0.020537110843828747, 0.06131746580025979, 0.027041243888171654, 0.04765326330172164, 0.030309395931128944, 0.07067328305648905, 0.02538776770234108, 0.07523668890020677, 0.030707159944410835, 0.05719528413776841, 0.03228629074458565, 0.04189410572871566, 0.047508379111864736, 0.01582064785595451, 0.029132504082684006, 0.033436675622527084, 0.04510565946942993, 0.022782881943775073, 0.0931606867483684, 0.03302484218563352, 0.054837520832994154, 0.051475729261125834, 0.038233643397688866, 0.0015934278510810274, 0.03572490944394043, 0.023595071397721767, 0.08478328984762941, 0.03833386980529342, 0.002281262510223314, 0.06633001432887145, 0.0031242805666157176, 0.024873740106288875, 0.03821956379605191, 0.057781368760125976, 0.053096013210181675, 0.02408643762048866, 0.0514913627079555, 0.024532314855605364, 0.020464991053034152, 0.05020322843587824, 0.08989699437682118, 0.039139915124646256, 0.05284955232803311, 0.03991800140855568, 0.018143212156636373, 0.023049444425851107, 0.01428346409063254, 0.025842470981712853, 0.01453558904384928, 0.04683350818231702, 0.08381657422121082, 0.05321449560246297, 0.03396628238260746, 0.003311400380750586, 0.01047230591731412, 0.058415256174547334, 0.041402880301965136, 0.04468693890209709, 0.010813329135999084, 0.006794527372611421, 0.03490456399906959, 0.03224338697535651, 0.024876476298751574, 0.1170095641698156, 0.06399301758834294, 0.08878786782068865, 0.032730059432131905, 0.049764267168939114, 0.014568133279681206, 0.02467160452423351, 0.06385665240564517, 0.019421723105811646, 0.04305697565100022, 0.033048098973397694, 0.0633883411064744, 0.045814443579209704, 0.03635599111605968, 0.09278283773788384, 0.05945936550519296, 0.014644704260198134, 0.028630483163786784, 0.0477798948995769, 0.014727132694263543, 0.032401760441384146, 0.041170729723359854, 0.0069410358056692135, 0.06968274406556572, 0.03235229184584958, 0.0737842982634902, 0.02528730720015509, 0.03916325672928776, 0.04588509603802647, 0.0736489508833204, 0.06549878857497658, 0.03824684090380158, 0.016102170338854194, 0.01661903760395944, 0.057821510891829214, 0.08812761932079281, 0.06404045397149664, 0.05761815394674029, 0.07510982320777007, 0.05022978629650814, 0.06422564653413636, 0.05324528752160924, 0.041272180886673074, 0.03457961697131395, 0.05004399662305202, 0.026147866022906134, 0.012408520860065306, 0.06147302673863513, 0.10275728215596505, 0.02641939029230603, 0.007281335536390543, 0.027205814075257097, 0.04158482268186552, 0.028845534659922123, 0.052868588627981286, 0.06548966227897576, 0.02324327643561576, 0.03429866615416748, 0.035285571590065956, 0.012639739301188715, 0.026123918825760484, 0.03404781515044825, 0.038079531131578345, 0.05891539755144289, 0.048173543597970686, 0.01720839785411954, 0.02803038340061903, 0.02930724381336144, 0.023091179418510625, 0.09773466416767665, 0.012649596718672131, 0.07224754536790506, 0.021533354617921368, 0.06177259316401822, 0.0210028420135911, 0.026530001678371003, 0.07005836748118911, 0.04559310884880168, 0.032560452818870544, 0.06330327317118645, 0.0029985015904198265, 0.06704069155135325, 0.04525425185316375, 0.043280664897922955, 0.04377071985176631, 0.03196522493713668, 0.02128057657474918, 0.06521450275821344, 0.03493397170677781, 0.04550481787217515, 0.028396234215636338, 0.013115962318676923, 0.019948921066575816, 0.01685286416406078, 0.045517682896128724, 0.025245295704475472, 0.04087396225492869, 0.02668903162702918, 0.01377782064290451, 0.02332751825451851, 0.05409388377198151, 0.047881444450467825, 0.01356197101995349, 0.060587260339941294, 0.06286279537848063, 0.018849572200062018, 0.019205394267503704, 0.025896400944995027, 0.025756285159981678, 0.017904634155066948, 0.05313587035717709, 0.030538299719669988, 0.020295884859349047, 0.029496792570820878, 0.035460257037941895, 0.01848388762612428, 0.05135064811578818, 0.03149308330778565, 0.061085990363998074, 0.018336134929476038, 0.0735945798722761, 0.12616020600710595, 0.05710278624402625, 0.05814621703965323, 0.1396809254906007, 0.057144095455961566, 0.015052819325189506, 0.015772124120433415, 0.02845582316097404, 0.032778625576091666, 0.053672862970935445, 0.008076082399514104, 0.0437909605513726, 0.025749396333204846, 0.02438168177780296, 0.06963436451873609, 0.009879488531234009, 0.04548374257449593, 0.018319108789520602, 0.033923280225800614, 0.03820376071546759, 0.03272552342553224, 0.03875330622707095, 0.018663200682827404, 0.003799667182777609, 0.021084715745278766, 0.020093430365834917, 0.07000407789434705, 0.03273436812950032, 0.10883392287152154, 0.04240740389962282, 0.06367335974105767, 0.06737449006842715, 0.0428802749541189, 0.0120830199781007, 0.041468504816293716, 0.025661943347326348, 0.03294893786577242, 0.007964712750565792, 0.029064921994826624, 0.03276787758139627, 0.03967419359833002, 0.006617264763917774, 0.0337281980152641, 0.039145241624542644, 0.025577552250719497, 0.022815924902845706, 0.010357812462773706, 0.06240836012044123, 0.020262071763032248, 0.07221362540232283, 0.021907529361279945, 0.018683692440390587, 0.002735308458795771, 0.026430964403386627, 0.026616028044372797, 0.008177201928836959, 0.02158850764057466, 0.040905534489346404, 0.05404612508469394, 0.03886781240414296, 0.05558832322380372, 0.0209476194410984, 0.09723872970789671, 0.047504769305565527, 0.03544438271118062, 0.023779704168971096, 0.07637687878949301, 0.04852336232683488, 0.046836307139268944, 0.04854244273155928, 0.014120305256385888, 0.01135090020086084, 0.029605266571577107, 0.015038156183436513, 0.006116770124728126, 0.02927162411755749, 0.020778587886265347, 0.04213958273508719, 0.07014786625014884, 0.036419590203357596, 0.014226800479393984, 0.039699998285089216, 0.014111557243657964, 0.025124642000134503, 0.01163988996164075, 0.016341467587543384, 0.06273859632866723, 0.02574532851576805, 0.031262595139976056, 0.033748889940657785, 0.028403280801805, 0.09917507866131407, 0.13163921343428747, 0.18144657436226094, 0.13202201575040817, 0.14853434184832232, 0.13808659889868327, 0.11498729911233697, 0.1442839577794075, 0.12753649215613092, 0.10811859089881182, 0.17578411820743764, 0.15983766317367554, 0.1437751922224249, 0.11253168087984834, 0.07884580309369735, 0.1168691481330565, 0.14557252292122158, 0.13796094778392995, 0.14087834980870995, 0.19469229717339787, 0.1680228446743318, 0.12997037012662205, 0.06948633531906775, 0.17402422907096998, 0.10505765836153712, 0.0908695182629994, 0.11292386054992676, 0.16665346601179667, 0.17211608003292764, 0.11858324972646576, 0.11386791989207268, 0.15493486768433026, 0.15900432717587265, 0.2239701739911522, 0.06031879795981305, 0.17688065793897423, 0.09913203239973102, 0.19591720215976238, 0.19853421673178673, 0.0829534437507391, 0.1709792488919837, 0.26438756021005766, 0.1127890424270715, 0.12740545347332954, 0.105460443533957, 0.1984635405242443, 0.17468448435621603, 0.16316821160061018, 0.18091087096503802, 0.17726541443594865, 0.08657880885792629, 0.14873392613870756, 0.14409227163663932, 0.1448096324290548, 0.20607113944632666, 0.07068268755184752, 0.12318869759993893, 0.19748836356614316, 0.15609626179294928, 0.16798874150429452, 0.14280745200812817, 0.18505633994936943, 0.12676716915198735, 0.09214235496308122, 0.07999786056045975, 0.07402741057532174, 0.1385591578270708, 0.12419154521610055, 0.1639206526534898, 0.09260286310953753, 0.0782238578956042, 0.1292345260402986, 0.10703272452311856, 0.13166132010519505, 0.12341697035091263, 0.1838039950068508, 0.25746753439307213, 0.14011487577642712, 0.14869704097509384, 0.16793462155120714, 0.11800336012882845, 0.10500356554985046, 0.16826018265315465, 0.06507781187870673, 0.2034066409936973, 0.18085106488849434, 0.1396118506257023, 0.18739211532686437, 0.3167625383606979, 0.1257067953369447, 0.16658112060810837, 0.10625799359487635, 0.09558708047760384, 0.16571928613952228, 0.17223886772990227, 0.12256429610507828, 0.13357892792139733, 0.10045148445559399, 0.21093927536691937, 0.12972807884216309, 0.11229503500674452, 0.10843930726072618, 0.14643970424575464, 0.16045521146484784, 0.18366485461592674, 0.08571073865251881, 0.15457521698304585, 0.11439862927155835, 0.14626998906689032, 0.09382651280611753, 0.16824692407889025, 0.11852642920400415, 0.09270763570176703, 0.21023473888635635, 0.07855930525277342, 0.12678741663694382, 0.14968800065772875, 0.18655872504626, 0.10549131009195532, 0.17832046853644506, 0.08822717397872891, 0.1935519647917577, 0.1363045759499073, 0.050305256353957314, 0.0893053864794118, 0.06690424494445324, 0.0885804600215384, 0.12466635688074998, 0.14291893531169209, 0.1656524504401854, 0.10613081577633109, 0.10312432888895273, 0.20247489027678967, 0.13101292561207498, 0.22267727979591914, 0.12603550484137876, 0.11880693558071341, 0.13291584993047373, 0.10991014047924962, 0.11473736752356802, 0.16177268219845636, 0.2475194510604654, 0.17091614513524941, 0.14131576062313148, 0.14489415075097764, 0.11667846622211592, 0.11870493819671017, 0.2597215734422207, 0.09270416838782174, 0.09767152648419142, 0.09665432785238538, 0.23245562080826077, 0.11547064674752099, 0.10207555802272898, 0.12684667988547257, 0.08232995149280344, 0.13842577141310486, 0.11451780716223375, 0.1226092694061143, 0.10852970169591052, 0.13070925404982908, 0.1475375196231263, 0.127318980970553, 0.10692290363035031, 0.07604774859334741, 0.11545698105224542, 0.14948217384517193, 0.13717411857630524, 0.09733012837490865, 0.12017285371465342, 0.10419357115668909, 0.1758554865206991, 0.056433000934443305, 0.09926391925130572, 0.15896627493202686, 0.1788845346974475], [0.06839634345046111, 0.0634757906996778, 0.029731993164334978, 0.08350543198840958, 0.055749383688505204, 0.0249945159469332, 0.021231243686218346, 0.009878545367558087, 0.036330196607325754, 0.018288790148549845, 0.03729224391281605, 0.06893192471138068, 0.060572108652974875, 0.08250974970204489, 0.016788384677576165, 0.03201292594894767, 0.07764799879597765, 0.028195177504260625, 0.06024252383836678, 0.03236089566988604, 0.010298790094176573, 0.07123198200549398, 0.025392018724232912, 0.0475064893918378, 0.04856737210814442, 0.03186023521370121, 0.0314278455584177, 0.007256791228428483, 0.006164356209670326, 0.02050630365764456, 0.05714969336986542, 0.014015953355867947, 0.10040799714624882, 0.05722883090909038, 0.050389968058360476, 0.04617986861350281, 0.05302218860015273, 0.010300208232365549, 0.04887555932093944, 0.028336148243397474, 0.04155150321977479, 0.05381293634751013, 0.07467416979904686, 0.06116021530968802, 0.027648671829540814, 0.07356770988553762, 0.03342820072014417, 0.02372059698349663, 0.03835528776315706, 0.04457165240975363, 0.0390639836633844, 0.03723676010434117, 0.04225084212209497, 0.05778648491416659, 0.056604775467089245, 0.01061399166272687, 0.03551018364461405, 0.033271530377013345, 0.0025356041525291012, 0.033800333073096614, 0.0048191762263221395, 0.012088627221861055, 0.009119674347208014, 0.058047917671501637, 0.096963373411979, 0.03550935922456639, 0.0287119548634759, 0.03736878266291959, 0.12744441495410033, 0.028493208744164025, 0.11998418026736804, 0.022588948153757622, 0.08294284503374781, 0.012760705979807037, 0.051334376846040995, 0.042943443171679974, 0.03774266563622015, 0.02463794918730855, 0.03902617569214531, 0.03821523134995784, 0.01574305059122188, 0.004980220151732543, 0.06463502706693751, 0.052355307420449596, 0.036482202022203376, 0.07095009141734668, 0.013241715213683034, 0.008050797640212944, 0.050537474786064455, 0.032633809239736626, 0.036897658836096525, 0.011977427206667406, 0.07605569423841578, 0.043302520510873625, 0.03924782254866191, 0.038638379358287366, 0.07413961312600545, 0.028524295826043402, 0.02924789235528026, 0.014539317593776753, 0.027491786051541567, 0.050194468548787494, 0.01605850661040417, 0.04074396851605602, 0.01725446359653558, 0.019975202424185615, 0.07452532635735613, 0.06806817677404199, 0.025290818618876592, 0.0030794425484990434, 0.01752018808786358, 0.05893499364278146, 0.06914176166589771, 0.03239061211102775, 0.015200572021837746, 0.030199992337397168, 0.06817277973251683, 0.03335859999060631, 0.10331694462469646, 0.0395406612993351, 0.052219468102391274, 0.04967326205223799, 0.027116790280810425, 0.03810290327029569, 0.014325704591880952, 0.05064647125878504, 0.06348582623260361, 0.14829260696257862, 0.035383412947079966, 0.021662182972899506, 0.04473145079932042, 0.030456125736236572, 0.06576961225696973, 0.02233603609991925, 0.026068674200879674, 0.0059369909992840674, 0.0366692978755704, 0.03856622733707939, 0.048966449086687396, 0.023046516547245637, 0.05765292886644602, 0.039083209953137805, 0.010540303607870425, 0.04550415290785687, 0.04726443898731044, 0.04024223597454173, 0.03469000444082277, 0.01828245772048831, 0.07809767073818616, 0.03841662732884288, 0.08204666990786791, 0.039902971857892613, 0.006393632768387241, 0.03230072657710739, 0.04050663053723318, 0.020855644019320607, 0.013361642037385275, 0.057277929703039784, 0.04491128293531282, 0.07815174319382225, 0.012744868972471781, 0.0755633424435343, 0.045475254101412635, 0.08532577180968863, 0.07396174874156713, 0.024211013257237415, 0.009312523329364402, 0.019268338568508625, 0.05028463228206549, 0.026320258022419045, 0.05222913722640701, 0.0526998505395438, 0.02204285468906164, 0.03141606279781886, 0.07971703527229172, 0.012935312547987061, 0.02523779619618186, 0.04281362585191216, 0.03871862630226782, 0.03903829093490328, 0.09145115848098483, 0.08365725419883217, 0.04321890803320067, 0.07896918790148837, 0.020948788217668022, 0.03300900857097336, 0.010283241464224244, 0.03362999703469021, 0.0012172466584680869, 0.028202721117330447, 0.023144510574638844, 0.010595907008142343, 0.07772074453532696, 0.0520294375850686, 0.04062554379925132, 0.024984295513214808, 0.02023695070030434, 0.01428940296838326, 0.08072056142347199, 0.025005854267094816, 0.06629150068121296, 0.055400528479367495, 0.04479857487604022, 0.0015458261810376176, 0.012581833970866032, 0.031093602600906576, 0.04423107872051852, 0.019522887588079487, 0.020085640783820833, 0.06264860901449408, 0.03802354181451457, 0.015375790119703327, 0.011255449831618794, 0.04058899451047182, 0.05260669446683355, 0.006010750724401857, 0.035982369378741295, 0.010037809410797698, 0.04079751171437757, 0.029267220425286462, 0.03566055718277182, 0.019973926778350557, 0.0587566542838301, 0.01388460593963308, 0.032299763057380915, 0.04359540675899812, 0.022862876133461083, 0.04716407687270215, 0.09087168278970889, 0.04205200422023024, 0.0939655921288899, 0.012573792482726276, 0.059398080222308636, 0.07242291274347476, 0.03123776415096862, 0.03430159403277295, 0.027709979164813246, 0.014046311012602277, 0.07235334933336292, 0.05292750921632562, 0.05224733892828226, 0.02877726385902081, 0.06772497376160962, 0.02792498655617237, 0.057082267345062325, 0.04272403208804982, 0.04043200186320713, 0.035162665149463077, 0.02796258418155568, 0.0629492678812572, 0.042492197028228214, 0.06484654000295059, 0.027507696001391326, 0.04087227609540735, 0.05921596820865359, 0.027995961319122995, 0.055964333404387744, 0.027746313018724322, 0.04094979872128793, 0.046617632266134024, 0.03497927748997297, 0.01138963267606284, 0.02202701598538884, 0.04051443708262273, 0.020763960367600833, 0.027807552500494888, 0.0034094978847341345, 0.005275142004912985, 0.02398209929067109, 0.01596872794574925, 0.05697632088725056, 0.053311115596443415, 0.06116614570575101, 0.08450450016451733, 0.034347517282835076, 0.027511796049241508, 0.03665345408288496, 0.03657576182324972, 0.014171212346159985, 0.05603756768895047, 0.014971710641735365, 0.0382050601100283, 0.058233734486358504, 0.07054669556341, 0.01900731462852231, 0.051913845751966746, 0.037627328253750286, 0.061165480741432736, 0.007176356839149126, 0.05782900870378528, 0.02494587516412139, 0.07470690232834645, 0.027777763116838675, 0.025747883200113262, 0.04779241726334606, 0.03100857198504465, 0.043901107140949795, 0.008219770671400641, 0.02310303003261132, 0.045229254623076746, 0.05345858161204627, 0.02501047509057181, 0.05837486977023738, 0.04404834245464631, 0.06416383199393749, 0.03210464692009347, 0.008795786682250244, 0.07468628164912973, 0.050566336273082664, 0.02424621904667999, 0.061282494105398655, 0.0026879645260383506, 0.03385050734505057, 0.04979645008487361, 0.06714954892439501, 0.01726919289545289, 0.016443629516288638, 0.03838720265775919, 0.04988153837621212, 0.03469994497884597, 0.020183029218709896, 0.04213536563994629, 0.08686202258935996, 0.022984810572649752, 0.06721384011741195, 0.04463873238169721, 0.08395829304520573, 0.03991581313312054, 0.023002594975488524, 0.013825672628757144, 0.013141778879798949, 0.017242882700104798, 0.023754187859594822, 0.06149632763117552, 0.016732921225151846, 0.061252916763935766, 0.027069428536508764, 0.0490441617023732, 0.006878041886791054, 0.04835971325103726, 0.02299397249173905, 0.03926634655467101, 0.04826723232067057, 0.03487852182505386, 0.056369391669120104, 0.027459832141175866, 0.012250886149039226, 0.02750389450894935, 0.051688809613032, 0.01131018640340439, 0.03176896207566772, 0.011129796172359159, 0.1533772905490228, 0.12364653231842176, 0.13222962032471383, 0.17736747967345373, 0.11233346044485058, 0.13887496159545012, 0.12691457409943852, 0.1817312062318836, 0.10858394378530127, 0.07435121427157096, 0.14696096841778072, 0.1712531734790121, 0.08469502601240363, 0.09336987230926752, 0.12444975493209702, 0.15464023420853273, 0.1822279074362346, 0.09996109362691641, 0.1534604789423091, 0.14815786347857543, 0.1336415974157197, 0.12414806469210557, 0.26707276755145615, 0.08898654287414891, 0.14700318686664104, 0.1335339139082602, 0.12676902833793843, 0.13129227847925254, 0.1063336773908564, 0.1459806210228375, 0.23393621136035236, 0.08413412860993828, 0.18666942124920233, 0.11629223051880087, 0.13351140011634144, 0.1174910661897489, 0.11619133236152784, 0.2433621755668095, 0.11620121183139936, 0.06446442300719873, 0.08944207735891853, 0.21149346205805028, 0.12490653113595077, 0.16156663825469358, 0.13101752607950143, 0.12335534580051899, 0.1280901903020484, 0.11149152740836143, 0.10373619105666876, 0.08943544807178633, 0.1725223460899932, 0.1277777384966612, 0.09600796217897109, 0.11739809332149369, 0.1943418609776667, 0.08383752738258668, 0.16386981680989265, 0.19347333615379675, 0.14019708707928658, 0.19721176555114134, 0.1885439149503197, 0.12810614944568702, 0.22103579502020562, 0.12078429519065789, 0.12725735642015934, 0.12145084728087698, 0.1415633987635374, 0.14814178219863347, 0.1675616308514561, 0.10186460827078138, 0.17314783324088368, 0.145939705361213, 0.15635907197637217, 0.10715860633977822, 0.1530864161572286, 0.1988042736692088, 0.1735054211957114, 0.22507883235812187, 0.12830225963677677, 0.11948408638792378, 0.08570305085075752, 0.1433068130697523, 0.11664877352969986, 0.1658601500093937, 0.13337118764008793, 0.11184100008436612, 0.16142436303198338, 0.10642392933368683, 0.12021224945783615, 0.15000906985785278, 0.08682439782257591, 0.16379671144698346, 0.18544560191886766, 0.11280441124524389, 0.15317533138607228, 0.11774848880512373, 0.16314638991441044, 0.13243278727999755, 0.0970438476651907, 0.14507548244936125, 0.15996928539659294, 0.12760935324643338, 0.07035491442573921, 0.12404443882405758, 0.11544563594673361, 0.10948253449584756, 0.16435102027441773, 0.17705790485654557, 0.12128432121660028, 0.11621422613305704, 0.1162733401038817, 0.17902343081576483, 0.17614537025136606, 0.16884222999215126, 0.11137203060622726, 0.1521588045039347, 0.1312037432300193, 0.10896626434155873, 0.1410462193723236, 0.09087558436606612, 0.12014715080814702, 0.12198518003736224, 0.09618164678769452, 0.07760056919817414, 0.08203434092657906, 0.11724053749016353, 0.145508862765772, 0.1396597416273185, 0.13463960029184818, 0.14020753651857376, 0.1638359443417617, 0.13396091599549564, 0.11147829597549778, 0.13866340794733592, 0.14925392823559896, 0.0778764547514064, 0.1148830625627722, 0.1027531430923513, 0.1699938124844006, 0.07663697483284132, 0.12495885975658894, 0.13820566822375568, 0.10031245263027293, 0.11422381150935378, 0.17336336310420716, 0.13373360676424845, 0.15395612163203104, 0.12982665640967234, 0.17251033602016314, 0.16539278865924903, 0.2211500738880464, 0.12856585692082131, 0.09239076663340841, 0.1350311692804098, 0.09654157568833657, 0.049059259106538126, 0.13507783891899244, 0.12813630354191574, 0.15346706073198998, 0.15583218953439168, 0.13280337596578257, 0.12206433793263775, 0.08219193747001034, 0.17468912553574356, 0.14784252111400875, 0.13568408281675406, 0.1268527867006404, 0.11523575149476528, 0.09631295688450336, 0.09746669033276183, 0.14285478661102907, 0.11206952389329672, 0.17960827371903829, 0.06433680414089135, 0.17286644476865018, 0.09929146098771266], [0.03287955087476543, 0.03723612228142364, 0.00836042165090995, 0.02449144160241953, 0.05350111218701516, 0.019327834215281264, 0.03498131309502891, 0.016301115109984363, 0.06523021762924534, 0.04287945392674633, 0.09283834868775946, 0.02922815377158778, 0.007239210386095303, 0.005493190081324428, 0.02163708905157234, 0.04476198148248451, 0.06457759586295911, 0.05828902151967798, 0.06057171510266406, 0.02578130953146943, 0.06129052796001945, 0.024708518525585532, 0.03374902904033661, 0.017102514160797, 0.047876151877322366, 0.021377447626686523, 0.07804480607488326, 0.018669444901336516, 0.08336135864789997, 0.01768744527362287, 0.03591172370527472, 0.031806515596274815, 0.038428572937846184, 0.028336010840056196, 0.048497503357274194, 0.03186776016705802, 0.024614807750497545, 0.0403421570413879, 0.050720916728356054, 0.025735199684277177, 0.025927394728309343, 0.030858103451984267, 0.018837414548865387, 0.0366649281100503, 0.002803939307341352, 0.051494867341326814, 0.02986938293491091, 0.062188874397959025, 0.053051776119640896, 0.0508418316686792, 0.030080515891313553, 0.017898050669048513, 0.07052950148603745, 0.012071089636135315, 0.045210055474724085, 0.019688227912411094, 0.03579502925276756, 0.020366974973252842, 0.028766583717827286, 0.02814879285038582, 0.04793054324441722, 0.04442397265561989, 0.00865798385348171, 0.008906120717126344, 0.05756858017827783, 0.03274870218176927, 0.03624967824933784, 0.04343018687463232, 0.019774451053568294, 0.04951921085427914, 0.07346046742584024, 0.04987981489726475, 0.027167811025200144, 0.08217869925179652, 0.057444747537374496, 0.06148788665554353, 0.04200306488201022, 0.0600729782932571, 0.05017945935417499, 0.02076571946963668, 0.036597254419965405, 0.0317442735790142, 0.0026665073403689477, 0.047875737970960994, 0.05608347736831222, 0.08630417180912835, 0.0494576812987881, 0.048733236600777934, 0.06683160777070693, 0.0099601442925632, 0.008002019454059857, 0.03300124952303512, 0.02076976523468537, 0.03812335431575775, 0.035630012928907356, 0.04342253978497215, 0.11947673106832163, 0.006459199183154851, 0.06150403578898736, 0.017009719407984188, 0.03264953089611871, 0.030836227482983043, 0.04009483102709055, 0.06536180592541184, 0.022846584507663335, 0.056793272495269775, 0.02698917650351567, 0.04457253450527787, 0.044838394703609605, 0.04113382420369557, 0.031093192087220292, 0.04860294091382197, 0.013678719755262136, 0.06151046830096415, 0.0228132175481213, 0.0467923007506345, 0.0322167850099504, 0.03949985420331359, 0.01998310226814023, 0.032726520872009654, 0.03925760702363082, 0.04870150491063084, 0.05936960889292615, 0.03947346258376326, 0.01178392767906189, 0.016478467200483595, 0.02889211948162743, 0.03773833658280117, 0.021761333902499506, 0.015824164363688657, 0.016866877608533417, 0.034708586122308455, 0.017011297001902546, 0.048439325764775276, 0.017052887805870602, 0.0258037656479116, 0.07169023063033819, 0.020429812404992323, 0.0274079547463251, 0.025171435471358042, 0.02219791690419827, 0.004149499058257788, 0.035566814177270444, 0.030631357404802526, 0.019625256470005428, 0.07411088395331587, 0.06106540361153228, 0.047552619595080614, 0.04648732300847769, 0.0004268707801072326, 0.05998280777462891, 0.05813425446727446, 0.06923537235707045, 0.04941855018426265, 0.03688023405681763, 0.0222839517518878, 0.02722462815498667, 0.02654724325319486, 0.08950561537806477, 0.03865528505827699, 0.018187932703377943, 0.013454555533826351, 0.04788553262395518, 0.033280263122703345, 0.038492328088198385, 0.012557023337909153, 0.025663587098409022, 0.02446335873433522, 0.025831404075558697, 0.027295377305043594, 0.022912275179156234, 0.04034841652693493, 0.02924577871869717, 0.011969238137161093, 0.015688245317765644, 0.02926323063937681, 0.02857961000076362, 0.04537984189976539, 0.011150437207626445, 0.03340056738150971, 0.017300044186413288, 0.009633821535057254, 0.06502668426505157, 0.02621764486788639, 0.05877777707896062, 0.08945137328867402, 0.00984660248338644, 0.0536045107458319, 0.02837218693457544, 0.037018471996166875, 0.03871329301702125, 0.013622764364949294, 0.029836772541914667, 0.05282513863806214, 0.019434681428330283, 0.04246127279475331, 0.10380592410053525, 0.04531544214114547, 0.036348025114940744, 0.04164003168365785, 0.005146923907367247, 0.04848166974261403, 0.0485563357360661, 0.023755933390930295, 0.05143642851284572, 0.0017971932954554046, 0.028150226255612712, 0.02339989588862019, 0.04503147184316601, 0.06101706477680376, 0.03219380642154387, 0.01246701312317912, 0.00850410059293998, 0.0238783750350454, 0.026449875174356357, 0.00903036302354719, 0.039502968679049184, 0.0807343153283, 0.05977462644555739, 0.03969543513708881, 0.05040894668283207, 0.01899205437595291, 0.13468546925910882, 0.03209513725180711, 0.036320157681724856, 0.03656966857878225, 0.10031676811299153, 0.016054196216698204, 0.05286923662892409, 0.024743849844006554, 0.020516242499330213, 0.016426722119961466, 0.022450791638610617, 0.03355378398139562, 0.0205050789019359, 0.04188276740855404, 0.011571826113920127, 0.03523542106683765, 0.054756985511630774, 0.03086016619844096, 0.039999283118439574, 0.03912850895098277, 0.09049415947603327, 0.022262857794495564, 0.06104938339974199, 0.03463036799803376, 0.022902936840962087, 0.009067634952121546, 0.03786230493070824, 0.059339332660394054, 0.06810143856065613, 0.03216460905969143, 0.04553001527009266, 0.015871417542387332, 0.034958429501524994, 0.030210719976041998, 0.052521545107343366, 0.04430984306548323, 0.027844680240377784, 0.07575008885136672, 0.025864899956754277, 0.04548335920221039, 0.05625865814675178, 0.06662116013467312, 0.05594246082806161, 0.01387179350214345, 0.10185057616659574, 0.019718224249247993, 0.06336880608328752, 0.019134977599605918, 0.013336236838118305, 0.0221296511923096, 0.01857871119864285, 0.0475693929807416, 0.06314204646540539, 0.02467239162485514, 0.04193015968693154, 0.023535392546494092, 0.029420331852244477, 0.022088314838973538, 0.019138582316892486, 0.032461281533219984, 0.050462496666503806, 0.04394784802570939, 0.032798791636845896, 0.02993301934163485, 0.03478318086958357, 0.040827879549137185, 0.03568936099431344, 0.08676248828747443, 0.023789215533595, 0.021393802016973495, 0.01539251091890037, 0.009004943405411072, 0.029193395815257515, 0.02342047755207334, 0.0550666756794921, 0.03266356639297945, 0.043521602505019734, 0.027562787955892936, 0.021964008919894695, 0.03606149334726589, 0.045418274123221636, 0.04529176126899464, 0.007565634075685271, 0.02151856425085238, 0.014924184352691685, 0.04091057261185987, 0.02495246034647737, 0.02561648828642709, 0.028322472370096614, 0.01685276408014553, 0.033826673802520545, 0.006524413183797151, 0.02876892127096653, 0.014001352130435407, 0.03297977388969489, 0.0012055526375271647, 0.07174867963684456, 0.0076917296308758, 0.027164783062679426, 0.02283772623299488, 0.07508910753365074, 0.017658841629911746, 0.11529439049107687, 0.04482391137363655, 0.06208764375852687, 0.028861873783171177, 0.04107952104615314, 0.03147767038483705, 0.01779258597109999, 0.0161171286433403, 0.015891369864610688, 0.03371590296072619, 0.04340870106326682, 0.05254970431061728, 0.020736396578805785, 0.031699398665555885, 0.046571505455566306, 0.0202105115833027, 0.0338565191653158, 0.08740827720612288, 0.014639669530359762, 0.03857760976201721, 0.07293720836085932, 0.005678832597498382, 0.024849251777465855, 0.03828305431774684, 0.04492664836081011, 0.010462281410582364, 0.025537973303081732, 0.021861287199759057, 0.09382108452596835, 0.14350930149001734, 0.10078999200569731, 0.1281453144869634, 0.13399254929806503, 0.1198311299085617, 0.0840331625991634, 0.06243862956762314, 0.12602661603263446, 0.1972716666225876, 0.1780094959373985, 0.102502580466015, 0.09032227977045945, 0.11693238759679453, 0.1602457205631903, 0.09656297668282475, 0.13456701061555318, 0.1664700172841549, 0.18095409364572593, 0.15904024881975992, 0.18541932904294559, 0.14051514358392783, 0.10746796402548041, 0.07028878440282174, 0.11686389627201216, 0.16905309153454645, 0.17813267718468392, 0.10952665284276009, 0.14963176367538317, 0.08870910347572394, 0.12128285558096, 0.11286122498235532, 0.12995666371924536, 0.10582761240324803, 0.14686909477625573, 0.18786096945405006, 0.06602938260350909, 0.11022102486874376, 0.13740606898708002, 0.07557949157697813, 0.12138098531535693, 0.1429524820830141, 0.09447213887636151, 0.18945342328931603, 0.08991973208529608, 0.1527933297412736, 0.3005476141614573, 0.10569110472819634, 0.19335840589233808, 0.13931687788239547, 0.20648979555283273, 0.1142413177128349, 0.1023027722590736, 0.11680791713297367, 0.09327428029584033, 0.08243908706520285, 0.10637667615498815, 0.10280116301562105, 0.14045180912528718, 0.12377447688153811, 0.18778019664543016, 0.11165128169315201, 0.11747745477727481, 0.1895801464893988, 0.13805875182151794, 0.1631039543343442, 0.183596349720444, 0.14037698028343065, 0.11314266095204012, 0.1082966181316546, 0.21295296374176229, 0.15086341329983302, 0.0964447215997747, 0.20541353044765337, 0.11549028355096068, 0.2691515274345875, 0.1418573944164174, 0.13329367179955753, 0.11584727439497199, 0.0987437271646091, 0.20332459253924234, 0.13498340041509696, 0.1139305622449943, 0.14380610627787455, 0.1367188487201929, 0.19558111019432545, 0.13001043083412306, 0.15278155037334987, 0.2290390341409615, 0.06267101424080984, 0.1483198297875268, 0.1984099362577711, 0.12365246271448475, 0.12217730044254235, 0.10072536154517106, 0.09990182359303747, 0.19101714795189245, 0.08130372155989919, 0.15129162317940167, 0.13007500022649765, 0.1473843064159155, 0.1291574173207794, 0.13082334292786463, 0.17254586411373957, 0.10757471115461417, 0.10365992372057267, 0.10554458866161959, 0.13193813525140285, 0.08133981962289129, 0.11822429113090038, 0.0737951887505395, 0.19338036328554153, 0.12882980704307556, 0.1393473441047328, 0.1264138695384775, 0.1153937823006085, 0.14086490124464035, 0.14096898851650103, 0.07209528889507055, 0.09609407505818776, 0.2123532337801797, 0.1846386066504887, 0.12114341663462774, 0.24064100586942264, 0.06363874088440623, 0.13315655344298907, 0.10941312036343984, 0.13003328389355115, 0.16707213568900312, 0.08969704367752586, 0.08952915375786168, 0.12464062683284283, 0.1069792898904, 0.10831964761018753, 0.12960795100246156, 0.10784290212073497, 0.09843967562275273, 0.10576890555343457, 0.15949914205287183, 0.07642958060439144, 0.1533587665430137, 0.06505618018231221, 0.23880347875612123, 0.15203768600310597, 0.10414308136595146, 0.2174146978982857, 0.18828913862151758, 0.15041564804102692, 0.17485550232231617, 0.1619018345539059, 0.1710258913891656, 0.200952054134437, 0.2564350212258952, 0.11203740883086409, 0.17156534029969148, 0.13733642415276595, 0.12033308297395706, 0.13703971435981138, 0.14722474212093012, 0.1687584716294493, 0.13567170633801393, 0.07128172540771109, 0.14011862128973007, 0.20502094365656376, 0.1231375089181321, 0.1042056151532701, 0.13806229377431528, 0.10973919036665133, 0.13580528274178505, 0.10042848211846181, 0.07864843761282307, 0.2623821092503411, 0.07445916240768773, 0.09179533858384405, 0.08110890737069504, 0.10250452107616834], [0.012197041850803154, 0.044684075484318395, 0.013785574601830115, 0.03473544593102165, 0.0411613693327776, 0.04398963221215776, 0.07330217877668993, 0.05015403125435114, 0.046935217188937325, 0.057353376011763296, 0.05256667786410876, 0.009201690571249595, 0.08302858471870422, 0.02454938001132437, 0.02037289010227791, 0.023486860329285264, 0.043771537486463785, 0.007536532556904214, 0.02111516161156552, 0.02105504340891327, 0.033226367086172104, 0.01866244581261916, 0.03584484390116163, 0.03528636208336268, 0.05916985496878624, 0.011715784103476574, 0.011848038212130112, 0.014407094867367829, 0.03943123734955277, 0.017782747213329588, 0.050941389719290395, 0.010894688029241349, 0.0584697425365448, 0.027808853591393148, 0.015291833285508412, 0.0015808566115863088, 0.03866176846038018, 0.02667547619369413, 0.05365182160000716, 0.03850329999944993, 0.046782556987766705, 0.02256259724630841, 0.03564187711370843, 0.023136366458077515, 0.05392267581607614, 0.05118204573435443, 0.04192280776000448, 0.046099265438637564, 0.03845561255833932, 0.020586540423599736, 0.011530768808110483, 0.048430436956030984, 0.06423880332814795, 0.02917360294876354, 0.06574044882186822, 0.029723463979150568, 0.022878007464376942, 0.01812765504499631, 0.039817425555416515, 0.015639979425551634, 0.028399499665413584, 0.03644374944269657, 0.027063033343958, 0.04479455455605473, 0.03306627692654729, 0.011372156158488776, 0.05298159863533718, 0.0685936478631837, 0.07991531677544117, 0.08437639953834669, 0.014794763975909777, 0.027199949836358428, 0.013327588061136859, 0.03730042025979076, 0.013061384354451937, 0.015586415871179529, 0.020805342522050654, 0.04980891816584127, 0.017767743107729723, 0.027009233998666917, 0.015392488866512264, 0.026136349587302123, 0.03932877177638667, 0.05906946571277721, 0.014884496839450938, 0.03555380326828786, 0.056836501961307864, 0.036410100891121795, 0.038519510201045444, 0.03184650166492377, 0.015621988069532173, 0.03680291499144264, 0.032737034772123606, 0.0774505315348506, 0.052077871414699724, 0.01788334172618176, 0.028937971485512595, 0.007854237919673324, 0.0421133200371904, 0.024081214597182612, 0.034330845677426884, 0.02503623397621725, 0.06588341615029744, 0.019913014689726487, 0.05375790376482265, 0.026588189448895197, 0.02193374795440052, 0.015271579015201755, 0.019971355130629878, 0.01638520086583282, 0.00591953398959179, 0.07279252433883292, 0.026845798661400164, 0.03833242113302861, 0.020862351337979947, 0.035803080070763826, 0.026505382731556892, 0.05120873251663787, 0.043725549775574885, 0.03739574085921049, 0.08349327942622559, 0.04296356512765799, 0.07104060798883438, 0.0536583762482873, 0.051846575790217946, 0.017535853765106628, 0.04424186064196484, 0.0177906470572842, 0.027896545760865723, 0.041343857933368, 0.043081060251487155, 0.03625764085778168, 0.04533454290192042, 0.037151817698031664, 0.03522727186126368, 0.0865808173215815, 0.022748794040775726, 0.022132646924416934, 0.010277646094826716, 0.006570987827477178, 0.00811575464571693, 0.02489417079570038, 0.031982670072466135, 0.059596287086606026, 0.024797370989939997, 0.03393025217311723, 0.03323380382997649, 0.013387594305511032, 0.031954755141798935, 0.04318270140460559, 0.03719731347103204, 0.027084721019491553, 0.014513896279303091, 0.031706933796937974, 0.021648376481607556, 0.04928635120657938, 0.028646279459020922, 0.06975132359990052, 0.027839056881410734, 0.027724508295900056, 0.06614818729992424, 0.05977514213217156, 0.0022814459267205423, 0.05090186844712921, 0.020339942138109888, 0.016478731829140867, 0.022282679498727833, 0.0070203438268176144, 0.008399160911462136, 0.00824134554048734, 0.07115537540188857, 0.02524254085229976, 0.00844553199463657, 0.017191884008103182, 0.031575372642172236, 0.06279538292437792, 0.025539849452408295, 0.02646955947524735, 0.013313494040630758, 0.03880432866779821, 0.022407475659357648, 0.012213226607335466, 0.0508947981122349, 0.07699129224887916, 0.05828581204903977, 0.007601490410576973, 0.01861341487217162, 0.01189105139513101, 0.01824517561388867, 0.026382925820403864, 0.044534468690731695, 0.032630457276744504, 0.012171680756312395, 0.046877724916807244, 0.0375645705498755, 0.06733702815004758, 0.05752539142434086, 0.02326718800967293, 0.04685532647584166, 0.06322038333330836, 0.06574990760002818, 0.020531328029132316, 0.04432926613039204, 0.014226668165065348, 0.022783811536750624, 0.07372292477105345, 0.051558385004422495, 0.01875624479725957, 0.014337665467922176, 0.03807235901643123, 0.05899714745048966, 0.03136367989437921, 0.04520454577037266, 0.026667644203241383, 0.04125924461654254, 0.03540737880393863, 0.060238031936543326, 0.0860267731228045, 0.04675454366952181, 0.05178784179900374, 0.0803202868306211, 0.04109650477766991, 0.04987847479060292, 0.02082498441450298, 0.006700995985218989, 0.059822381740169864, 0.0423402391108019, 0.047515483373509984, 0.019050248931827288, 0.059640710774276934, 0.030925661791116, 0.027757993999070356, 0.035706246338252506, 0.041082001091646295, 0.02890940855390259, 0.022348414274996946, 0.03309286532125302, 0.007812884602961796, 0.009114996696423208, 0.04108092561364174, 0.05640320985444954, 0.03413036572081702, 0.02207223016635648, 0.0529662773146161, 0.08921472063022, 0.03654212344970022, 0.03672422867800508, 0.03637761941977909, 0.01860411894241614, 0.014951296915699328, 0.07731619517185859, 0.07250403839030437, 0.09081010573676654, 0.02467921938348029, 0.027703594150287763, 0.03661610073010836, 0.04088747188714998, 0.025860821961292198, 0.02784111114617969, 0.020545811359105364, 0.026438429984929304, 0.04640009733183043, 0.11019477234887225, 0.01382609162413116, 0.032827507238835096, 0.02559969454471554, 0.050430822651833296, 0.041617768949695995, 0.0693327896296978, 0.07973939978650638, 0.03273148435567107, 0.020649991929531097, 0.005950582903876368, 0.011774178827181458, 0.06177044899335929, 0.02075840486213565, 0.06617629222039666, 0.03067931965259569, 0.03870415993567024, 0.028422646191237227, 0.013587460187929017, 0.020882895682007074, 0.018282188002818396, 0.04585508443415165, 0.006773733242880553, 0.025337871629744768, 0.011236911406740546, 0.013532743972193981, 0.0162886470290167, 0.03190479460837586, 0.015760801067309718, 0.014949627719553453, 0.05999022416238274, 0.02950964741674917, 0.031896767539105246, 0.026981697351272618, 0.031706190801092556, 0.0419941896439663, 0.04752584121056965, 0.10772971569427423, 0.03192460783092039, 0.02994289541883128, 0.033001670214746676, 0.028995053243956397, 0.024164343618654778, 0.061075120232999325, 0.045496024058333466, 0.01598919934726187, 0.02363033146996583, 0.027451798286555067, 0.025651719520932863, 0.0061458843660407835, 0.03750366524660161, 0.03808601792635662, 0.006601330217173589, 0.014456524447138821, 0.025095420889556408, 0.014714768089886223, 0.013864645983890762, 0.04597513424232602, 0.053408091821308644, 0.02298466638395829, 0.01153896890381085, 0.02857264823147229, 0.038534987584820816, 0.0598752260474222, 0.013264043256640434, 0.01447574734421713, 0.022623370235253657, 0.036906859770949395, 0.0298365045205823, 0.024033326988241503, 0.04867169347458652, 0.052239277932260714, 0.0271521199028939, 0.022280338552913496, 0.027948131385658468, 0.01955509594907718, 0.020377885816352706, 0.038735379331878254, 0.05699236145509141, 0.060659531104777537, 0.017104034079238772, 0.021567646081426313, 0.028026636190978543, 0.044415260265980444, 0.023383095361558453, 0.03366578636424882, 0.011245252298457282, 0.02291218696960381, 0.05377174587920308, 0.04154827000041093, 0.1153638589062861, 0.1410401804106576, 0.13054745058928216, 0.16753865565572465, 0.12785959696131094, 0.06988808233290911, 0.1794285433632987, 0.16931773376251968, 0.16937212512961455, 0.1017556084053857, 0.13605096670133726, 0.0756026024797133, 0.1335699034056493, 0.08288653341255017, 0.09147074100162302, 0.09963686923895564, 0.213729642065508, 0.11407553803707872, 0.24355900500501904, 0.12903723519827637, 0.15221181165959152, 0.09952251573226281, 0.13490530103445053, 0.09016171802899667, 0.1712377028805869, 0.09686558294509139, 0.139036072950278, 0.09770425901349102, 0.2270772129829441, 0.12042685651353427, 0.20391807997865335, 0.07052994931914977, 0.15959377054657253, 0.19127071648836136, 0.10618004349193402, 0.1109251542282956, 0.10618854553571769, 0.08146924339234829, 0.09611181196357522, 0.19519338171396935, 0.15728087536990643, 0.1681677797543151, 0.11172522165413414, 0.12051129341125488, 0.1460785743381296, 0.21226220152207784, 0.11891674968813147, 0.1985165612506015, 0.08207414379077298, 0.11199160771710531, 0.12177430492426668, 0.13708309988890374, 0.13447357634348528, 0.17778289238257067, 0.12669954635202885, 0.1537403610668012, 0.10375812130847148, 0.14401885414762156, 0.11270495836756059, 0.12940880097448826, 0.09713178580360753, 0.055269784959299226, 0.07600323669612408, 0.21176376326807908, 0.2209601112242256, 0.1131286695599556, 0.11023990849831275, 0.12220373616686889, 0.19526548284505094, 0.18262418545782566, 0.23884899488517217, 0.09056311898997851, 0.065436220860907, 0.09151088313332625, 0.1747081380869661, 0.152522634980934, 0.16169884401772702, 0.12269355702613081, 0.08984650458608355, 0.1292447583483798, 0.059460261171417575, 0.08428193389305047, 0.1314192052398409, 0.14346200759921754, 0.12655033650142805, 0.22798564923661097, 0.179437215040837, 0.09925523400306702, 0.13374094851315022, 0.18714051454194955, 0.1769367592143161, 0.12474862246641091, 0.08616324687110526, 0.3104773499071598, 0.16938694433442184, 0.10850977312241282, 0.1404628963874919, 0.16613787439252647, 0.15992043087525026, 0.05386916993718062, 0.0924453887024096, 0.0955612486494439, 0.192699969080942, 0.14953837011541637, 0.05837565008550882, 0.12864114716649055, 0.07610029434519154, 0.11791282998664038, 0.15454367867537908, 0.08179520482995681, 0.08402769360691309, 0.20719437274549687, 0.08857736590185336, 0.11849087396902697, 0.08048626328153269, 0.06940155236848763, 0.0988205848261714, 0.15970435818391188, 0.170006270387343, 0.12504158674606256, 0.10615963994392327, 0.09820845802979809, 0.12848474484469208, 0.13978969465409005, 0.1796771450234311, 0.14716246617691858, 0.10584811773151159, 0.07331984782857554, 0.10122664964624814, 0.12724997395915644, 0.09601596889219113, 0.13359935182545865, 0.11252196425838129, 0.09625157660671643, 0.10520332625934056, 0.16718291331614765, 0.09391509555280209, 0.11324169992336205, 0.08817011596901075, 0.0675731176244361, 0.1835583924715008, 0.08871288291577782, 0.09931826990629945, 0.13836965656706265, 0.08169763827962534, 0.10321266057768039, 0.06699216272681952, 0.0834808215232832, 0.13585594216627733, 0.10373895269419466, 0.12082622865481035, 0.09663370038781847, 0.12162832490035466, 0.08648031949996948, 0.06974514214588062, 0.15046799023236546, 0.10104240703263453, 0.19427336965288433, 0.13050166304622376, 0.12340844795107841, 0.18910163002354757, 0.09936415244426046, 0.14311458409896918, 0.09331469384155103, 0.10432375488536698, 0.185961817790355, 0.08625199925154448, 0.1621399867747511, 0.09244421483682734, 0.16612678713032178, 0.15219358620899065, 0.1337329689413309, 0.07147633603640965, 0.08651944382914475, 0.07920601019369704, 0.1601482286517109], [0.030690552799829414, 0.014661801646330526, 0.011918638932651706, 0.03817432925903371, 0.008486475645830589, 0.021054790654618825, 0.04668936698830553, 0.04404725679861648, 0.025067550063665425, 0.0255621393277709, 0.021108371172366396, 0.009230924404359289, 0.03921166002484305, 0.02769951445848814, 0.055892242451331446, 0.028619026099996905, 0.05981719773262739, 0.05568087200767227, 0.02673798623228712, 0.03923168020056827, 0.08251996165407555, 0.08694089549992766, 0.07823075859674386, 0.0447757421726627, 0.04284772902194943, 0.039404153624283414, 0.08696595379816634, 0.030473950851176466, 0.013451811707844692, 0.030442225946379558, 0.009317362980384911, 0.06089250610343047, 0.023423821033377732, 0.03657513078568237, 0.04571188979649118, 0.03765197943097778, 0.01226539577224425, 0.027225077684436525, 0.08636249189398118, 0.05789304883884532, 0.04379426162423832, 0.01926632671217833, 0.09773716796189547, 0.033732018167419095, 0.028346463672018478, 0.019961852247693708, 0.034931936101721864, 0.030654997564852238, 0.028971134884549037, 0.03622636039342199, 0.02777039253019861, 0.043871210888028145, 0.004587235145403871, 0.033178869634866714, 0.03952608975980963, 0.0432970108065222, 0.06067112726824624, 0.018344048344131027, 0.016723508248105645, 0.03372439821915967, 0.05949954156364713, 0.026852017434846078, 0.06063667804534946, 0.06603116036525794, 0.04725113970094493, 0.01825567424696471, 0.03085760472874556, 0.05283492989838123, 0.02517919451929629, 0.045320117247423956, 0.11517633896853242, 0.04914333638069885, 0.04929651905383382, 0.015686979849955866, 0.10357850630368505, 0.013501556806399353, 0.056589878230754814, 0.023343514717583145, 0.012398003567276257, 0.03815743712974446, 0.08574997154729706, 0.021170367220682756, 0.014896501820268375, 0.0407398124890668, 0.039460278648350916, 0.019574591956500496, 0.03805040840857795, 0.005789488088339567, 0.046071018025811226, 0.037439706535743814, 0.049203753138759306, 0.04774908601705517, 0.03689021530694195, 0.01244594291451254, 0.0259719693900219, 0.016722537943028977, 0.05468084031183805, 0.03878736189965691, 0.04677153079371367, 0.03795689610498292, 0.06071929646922009, 0.01256050676706114, 0.0451645155969475, 0.048217600876731534, 0.0405790166530226, 0.049980227901999436, 0.01582238999461489, 0.07500082334237439, 0.005423757289203682, 0.04709464916959405, 0.042129065442298136, 0.03847888970215406, 0.028092501585238745, 0.0051391555295724955, 0.0392155989206263, 0.06495320570788213, 0.02491065241130335, 0.032848813238420656, 0.0602430666663817, 0.05411468765565327, 0.03311429006446685, 0.06922940803425652, 0.010429202828423252, 0.03585634846240282, 0.035230233666620085, 0.02248415520547756, 0.006331590070788349, 0.04687251037518893, 0.025730536452361515, 0.010289428007256771, 0.0475920865844403, 0.0379706601878362, 0.012540342402644455, 0.09117065888962575, 0.03744355722197464, 0.028094184352084994, 0.04934834895123329, 0.03289354226684996, 0.022256301449877874, 0.021953681616910865, 0.044138967591736994, 0.013116749419298555, 0.03131746148158397, 0.05705990283084767, 0.010305384606389063, 0.03896266481439982, 0.07643658308578388, 0.01854421617463231, 0.06248179118015936, 0.016697905425514494, 0.024564977835065553, 0.02801529617447938, 0.04829616505386574, 0.06026895956269332, 0.01924796725091125, 0.04101331638438361, 0.05954773790602173, 0.06524891126900911, 0.019600462800424014, 0.03690139417137418, 0.017152354254254272, 0.018431090816323246, 0.007260793736869735, 0.024979618710598776, 0.03928039222955704, 0.049956167050238164, 0.039814297508980544, 0.03829155296885541, 0.028177803615108132, 0.02882946695068053, 0.013234309003954487, 0.028488282579928637, 0.016060336958616972, 0.015507003525272012, 0.01781839913954692, 0.06378010687019144, 0.03332922620964902, 0.04327606443049652, 0.043025328777730465, 0.0029814938981352107, 0.02188638281742377, 0.01766110284786139, 0.05530836646045957, 0.03972577243777258, 0.010852710460312665, 0.01505933326136853, 0.042400516769183536, 0.05180316311972482, 0.049152812122234275, 0.0028147129591421355, 0.05352433165535331, 0.02760931001310902, 0.07177776164774384, 0.07361444737762213, 0.031275914782392125, 0.035820192723934136, 0.020062266948765943, 0.053243282450629134, 0.026431059398289238, 0.028714421338268688, 0.0038789696908289833, 0.02895840896027429, 0.08120599894651345, 0.06386997883341142, 0.016691472913537706, 0.01890323244567428, 0.016666029546675936, 0.042523664089718034, 0.012508636157560562, 0.041981280515236516, 0.032614755976412974, 0.03361207353217261, 0.040092778458659134, 0.028386461615030254, 0.061628879447068484, 0.01857320997597916, 0.03135124234748738, 0.03782795409538916, 0.04623949148559144, 0.032322762001838, 0.048505191159035475, 0.01568689164040344, 0.04249319786738072, 0.01681781274133495, 0.01668049082426088, 0.02471010120851653, 0.014729427838964122, 0.03792064876428672, 0.018675419402175715, 0.09785902606589453, 0.062393181292074065, 0.01615278226589518, 0.03979874887902822, 0.025831066504386917, 0.03935798270893948, 0.005954912381379732, 0.035795348164226325, 0.026051534406308616, 0.0715323423168489, 0.018066673406532834, 0.058139092421957424, 0.03551737950848682, 0.03838928576026644, 0.07577402756682464, 0.09732200631073543, 0.014099114607753498, 0.023513726923348646, 0.04027956218591758, 0.040696701766656976, 0.029451971940164055, 0.07154007761606149, 0.06437053411666836, 0.005260802439547011, 0.004689437786250242, 0.10497716375227485, 0.013968405862604933, 0.023078797850757837, 0.040367167842175276, 0.05900192433702094, 0.015875241087217416, 0.04552001366391778, 0.02659558887327356, 0.05121095811149903, 0.033632463509483, 0.042433062701353004, 0.040120004676282406, 0.05173363024368882, 0.05563859588333538, 0.05849571007170847, 0.0426750418597034, 0.032543577652956755, 0.023503747369561876, 0.010419932343730969, 0.08501509098070008, 0.03949714345591409, 0.038197887994881184, 0.007112873950973153, 0.021850946326074854, 0.024397242282118117, 0.03054811472871474, 0.008115766520079757, 0.006954491155089012, 0.005990380679057645, 0.015779321680643728, 0.02495411766826042, 0.02592344056548817, 0.055042092355766466, 0.0451025653497449, 0.030616436419742446, 0.00813289189578167, 0.007156557187304965, 0.03526377704526697, 0.04914595552587083, 0.038103120401501656, 0.0372770040162972, 0.03640302377087729, 0.07861304522625037, 0.02609100648468094, 0.09400141877787453, 0.03422823761190687, 0.07368869267936264, 0.032330894244036505, 0.011960962554439902, 0.01621136867574283, 0.055918613714831214, 0.03282544109970331, 0.027206589301515902, 0.05238910185705338, 0.02464272777017738, 0.1151033557419266, 0.02036880192879055, 0.025118039854403054, 0.04478933662176132, 0.009653416778227049, 0.048882992672068734, 0.014452734829059668, 0.0990494071905102, 0.04902280820533633, 0.06972828733601741, 0.021079014354784573, 0.06353791736598526, 0.04158346561182823, 0.06888037640601397, 0.014932338647278292, 0.025693091497357403, 0.013181686068751981, 0.02415106468833983, 0.01897430220352752, 0.04587876530630248, 0.029594294660325562, 0.04705870716965624, 0.0481191691942513, 0.04782585886174014, 0.03906013976250376, 0.13508709413664682, 0.041758222305881124, 0.009608380712701805, 0.03890453471935221, 0.05469245683135731, 0.03640175491039242, 0.012742261701662625, 0.026135384371238093, 0.015618649677240422, 0.02025615324133209, 0.007117783151833075, 0.022444946059424962, 0.027532376016357114, 0.010780795078192438, 0.02381572759311114, 0.03828392284257071, 0.021472289858918105, 0.015523385056959731, 0.12083753304822104, 0.1397893689572811, 0.10344741333808218, 0.13556322215923242, 0.09199990332126617, 0.11183848950479712, 0.1962226650544575, 0.13690989704004355, 0.09561779775789805, 0.15994341964168207, 0.16225289500185422, 0.1652190022702728, 0.1732297052762338, 0.10031193694365875, 0.0814353980656181, 0.09964653157762118, 0.13400062386478695, 0.20770110269742353, 0.09669178977076497, 0.12112038715609483, 0.11165459294404302, 0.12683487337614807, 0.14800995641521045, 0.07629487783248935, 0.08701405514563833, 0.18561045878699847, 0.12480191460677556, 0.13798964981521877, 0.09994379776929106, 0.10039553245795624, 0.09079042822122574, 0.2178117630204984, 0.14637520270688192, 0.12303993558245045, 0.08207680364804608, 0.07786392220961195, 0.11959081994635717, 0.10497172190142529, 0.15105371523116315, 0.14056967065802642, 0.12514062571738446, 0.17903667581932886, 0.15592900291085243, 0.13940620023225034, 0.19367760233581066, 0.04945870927934136, 0.076021753916783, 0.07594894032393183, 0.1620979718863964, 0.09421154071709939, 0.07110857005630221, 0.1526262472782816, 0.17073364635663374, 0.22496296571833746, 0.21705843987209456, 0.1246319551553045, 0.14295766609055655, 0.1129728847050241, 0.1297892691301448, 0.12246257013508252, 0.1621167944478137, 0.09598991993282523, 0.08830696291157178, 0.20466189006609575, 0.23833653809768812, 0.19013320681239876, 0.1368073025452239, 0.13309946150652, 0.14119076090199606, 0.13632276068840707, 0.20747707757566655, 0.1284831435020481, 0.1252069864422083, 0.10826531052589417, 0.2044759714709861, 0.1578555673893009, 0.1287427917122841, 0.07716859344925199, 0.28300384698169573, 0.12539029946284636, 0.09248531370290689, 0.09780966942863804, 0.16168573472116674, 0.13299434286143097, 0.11130331536488873, 0.10840348061174154, 0.11843266923512731, 0.11444430824901376, 0.1701630526887519, 0.14319864101707935, 0.09771850824888263, 0.17338838747569493, 0.12663532979786396, 0.14283785037696362, 0.11832046668444361, 0.11591230519115925, 0.18891379795968533, 0.1465563037033592, 0.1284898609987327, 0.10101136405553136, 0.13078497855791024, 0.11408710027379648, 0.14681109360286168, 0.0900284673220345, 0.21251144100512775, 0.1359757985919714, 0.07787393060113702, 0.15104759484529495, 0.20675755904189178, 0.10374896108571972, 0.12903357110917568, 0.12613170753632272, 0.2036934984581811, 0.13352978841534682, 0.2059267879064594, 0.15165018822465623, 0.13852574676275253, 0.11529204275991235, 0.17199699713715486, 0.07732990836458546, 0.20680781134537288, 0.22444983039583477, 0.21336288031722817, 0.08039622168455805, 0.22492859113429273, 0.12274751413081374, 0.13374415119843824, 0.09549738493348871, 0.13611218413071974, 0.12978076030101093, 0.17977492191961833, 0.11111160886607, 0.0752852177247405, 0.280670337911163, 0.09955743992967264, 0.12867926726383822, 0.10716421782438244, 0.05662134189956954, 0.12530561829251902, 0.11021815466561488, 0.20428397320210934, 0.07369457557797432, 0.16587483350719723, 0.11329501920512744, 0.13089286562587532, 0.11270743502037865, 0.1318189845021282, 0.11511091462203435, 0.11478529923728534, 0.09139109456113406, 0.16431436581271036, 0.1351114942559174, 0.15132346004247665, 0.16974276809820107, 0.10531488420175654, 0.08426921136145081, 0.1449399518647364, 0.12204319478145667, 0.15243480540812016, 0.11082542993660484, 0.07581891265830823, 0.11004444970084087, 0.11347320250102452, 0.08582875624831234, 0.1531595215201378, 0.07591058273932763, 0.09129090886563063, 0.09372022029544626, 0.06567111611366272, 0.10284883688603129, 0.08792743113424097, 0.1720474801425423, 0.16239195396857603, 0.1997964954269784, 0.10589445488793509, 0.17687217625124113], [0.01554421438569469, 0.022461235988885164, 0.02065594437798219, 0.05029201474306839, 0.05620475871754544, 0.01473825897223183, 0.021137767005711794, 0.004704163692492459, 0.007310482856285359, 0.013771256664767861, 0.002595023040027757, 0.00498478117931102, 0.012427775139388229, 0.017009006946214607, 0.027339037640818527, 0.011152493168732949, 0.033424858935177326, 0.017835387960076332, 0.07863436479653631, 0.033261443953961134, 0.031997957466436286, 0.03317835734092763, 0.015950510976836085, 0.02312582541656281, 0.01040982302012188, 0.029440192572240318, 0.027888204869148985, 0.03164688344778759, 0.05509223609364458, 0.04616096123520817, 0.01681397053679185, 0.01619026793300041, 0.018244620911510925, 0.03194634470024279, 0.028083385467263203, 0.021831923596827046, 0.0682132543463792, 0.053769886693251986, 0.025266678039250628, 0.008186022884079387, 0.030359373427927494, 0.05127608390258891, 0.04322013618158443, 0.015704391058534384, 0.03285043154444013, 0.06843096230711256, 0.11141643393784761, 0.0765257832993354, 0.0898550134152174, 0.05296114419720002, 0.024364620014759045, 0.050473305729350874, 0.01266348293782877, 0.0357719183500324, 0.07985859803323235, 0.03987346915528178, 0.002095312320826841, 0.02003889820272369, 0.013667120199118341, 0.010605227534792252, 0.0452230528130063, 0.014049377142717796, 0.0764295466776405, 0.04621478263288736, 0.02799409704415926, 0.026711596309074333, 0.04809207868363176, 0.01736992990065898, 0.019687271178034798, 0.022950877036367143, 0.05869711962129388, 0.05042142154914992, 0.035346314044935365, 0.033459840808063745, 0.038782632510576925, 0.0014302283047332562, 0.039992809894361665, 0.023032314809305326, 0.0261924118468804, 0.03333301582772817, 0.007860769667396588, 0.001933282399217465, 0.01905402328286852, 0.03687304497829505, 0.029876765395913805, 0.02504585899545678, 0.057262981576578956, 0.06368731042104107, 0.023404647330088273, 0.021484152347381626, 0.043395177860345156, 0.09550779366067477, 0.055602494427668195, 0.04721028510747211, 0.027527582166450362, 0.034331707416900566, 0.05520556161978415, 0.04014219955674239, 0.05653247416817716, 0.017132259439677, 0.02121464502332466, 0.051989180102412186, 0.028685668416853462, 0.019445565130029405, 0.039296985803438086, 0.09669639702354159, 0.021652354393154383, 0.0586676440600838, 0.048425086707408936, 0.026520115423149297, 0.051782145497522185, 0.025039419698129808, 0.06369982260678496, 0.009800864134116896, 0.08750398457050323, 0.038138828306858025, 0.05866571023528065, 0.04657417209818959, 0.056616073075149737, 0.01012586714101157, 0.04673686104693583, 0.016222450848934904, 0.04219638290149825, 0.04643565935215779, 0.013078278180078735, 0.04405017789187176, 0.03203803513731275, 0.006047354295982846, 0.022072286145495515, 0.07895382586866617, 0.043022896229688606, 0.02036125661938318, 0.028402466559782624, 0.03250201738306454, 0.023234653951866285, 0.01984940712074084, 0.08509709872305393, 0.061101481318473816, 0.0057845555628383795, 0.022980060827519213, 0.055333743670157025, 0.009426031211790229, 0.024470583435946276, 0.0197846647019365, 0.0514860870981855, 0.019862962554075887, 0.01192446839663067, 0.035054340426410945, 0.06685182811426264, 0.021657358588916913, 0.06180240799273763, 0.09837884495833091, 0.01463122685839023, 0.07787089754960366, 0.030686851391302686, 0.013374864988561188, 0.005196948477532715, 0.03065834952784436, 0.05491395101749471, 0.045739017626536746, 0.04264349337401135, 0.018053036548995545, 0.033053561180297814, 0.027952170365356972, 0.006978853954933584, 0.04337809913392578, 0.012616593623533845, 0.10072880850306579, 0.06232099873679025, 0.03091127345604556, 0.04850413603708148, 0.008166683787879134, 0.04570052772760391, 0.027706566133669445, 0.015208831489352244, 0.027322491564388787, 0.036302549697990925, 0.017286921319152628, 0.034418322412031035, 0.027386144934488193, 0.009506267129576631, 0.01852207557697381, 0.033938065503856966, 0.09435337489204747, 0.02032712461160762, 0.03207572436492358, 0.010043044308466571, 0.01423973250868065, 0.03025348803826741, 0.010327643947675824, 0.03675595358280199, 0.026624151804883565, 0.06445683698569026, 0.01111987853489284, 0.033968738679374964, 0.04760487357686673, 0.02573286722015057, 0.02461336416724537, 0.029281503587429012, 0.07293805652963263, 0.01909145636350981, 0.061937409320047924, 0.03136790716754539, 0.02549439269517149, 0.09697237757167645, 0.050301385311675925, 0.051662696192839315, 0.022943004333813275, 0.01698643378248172, 0.03777444821649364, 0.051905085864875994, 0.024358959336365973, 0.030466402149094, 0.021518260606431534, 0.023510520845385532, 0.04920504574796983, 0.04057904379442334, 0.04319635692185589, 0.036333646957895586, 0.10521799618644373, 0.023129268981782452, 0.03298701385834387, 0.02433232174787138, 0.04350548729832683, 0.06850003038666078, 0.07646457265530314, 0.035532826358186345, 0.026567282088633095, 0.07943556537585598, 0.0436038511273052, 0.03442363873390215, 0.07485640394900527, 0.024001892157165066, 0.014911963937005826, 0.026881481121693338, 0.009587309655866452, 0.03789343951003892, 0.023764929068940024, 0.025782617407717874, 0.027707468585244248, 0.02171297980073307, 0.055481453958366594, 0.03616521081754139, 0.03138472465798259, 0.04948187446487801, 0.012333985484604324, 0.007782593103391784, 0.03730112932888525, 0.025823492357241254, 0.03288376457723124, 0.03651434083336166, 0.037852679911468706, 0.015338514798453875, 0.03834060087267842, 0.05055702677262681, 0.04611110926738807, 0.010217303127449538, 0.02423255335140441, 0.024271740445068905, 0.02274396626411804, 0.012852480385585554, 0.033802748657763004, 0.04124749917536974, 0.07194327669484274, 0.02836176802936409, 0.019117720757744143, 0.004657993625317301, 0.008970528109265226, 0.0211259163916111, 0.061536598684532304, 0.034936763878379545, 0.04202494424368654, 0.010318592290527053, 0.027063018076920083, 0.016962910669722726, 0.02820642082951963, 0.006456181398659412, 0.016002978697153072, 0.074729517900518, 0.01398329037640776, 0.046992739995143244, 0.01269900000521115, 0.07563283800014428, 0.07270538008638791, 0.028096070679436837, 0.029259040685636655, 0.0395834361469107, 0.02483900250600917, 0.024350138381123543, 0.02710364875383675, 0.029105023414428745, 0.0441724499022322, 0.04386124999395438, 0.04507705582571881, 0.035556486874286614, 0.04715600230598024, 0.04031234560534358, 0.030969966735158647, 0.061146359624607224, 0.09192416524248463, 0.05107369047722646, 0.019460140062229972, 0.01798407024970012, 0.01967477934834148, 0.020373037683644464, 0.019477792150740112, 0.07736257982573339, 0.03921399757798229, 0.017285028206450597, 0.03862574164356504, 0.07148000012551035, 0.037508313211479356, 0.06650487958852734, 0.09922258289796965, 0.05143609603068658, 0.057237163319119384, 0.042622363793530633, 0.05746366509369441, 0.00473128176859713, 0.03074550735098975, 0.045246540302676816, 0.024094493527497565, 0.014336505173040288, 0.06524099276534148, 0.035226189597908936, 0.06369645707309246, 0.02015149430371821, 0.05840239115059376, 0.04816829512960144, 0.05675481991576297, 0.021612838210005845, 0.02560132133242275, 0.06265415264559643, 0.013376127911864646, 0.0813958937568324, 0.029876745039863244, 0.025327164347150495, 0.011268642248718866, 0.06410045682319573, 0.03471330872603825, 0.04749178893065878, 0.021528306317382624, 0.03413794495697532, 0.07317369817090885, 0.06312103223587785, 0.019528762005003433, 0.054368934727140834, 0.023806733611438955, 0.014394882933369704, 0.00581095227140135, 0.025223845516198447, 0.02418928826227784, 0.12503215510930332, 0.12826570016997202, 0.11367299713726554, 0.1265559954834836, 0.1073496885863798, 0.09979953443897621, 0.10960564788963113, 0.15979657109294618, 0.09263250830450229, 0.10816758791250841, 0.10326896541352783, 0.06510359620941536, 0.0750329519755074, 0.13038119593901293, 0.11323511134833097, 0.10078915740762438, 0.13166518775480135, 0.12406060152820178, 0.14852701367012092, 0.12690515603337968, 0.09652826961662088, 0.11642400201942239, 0.09398652493421521, 0.11866972222924232, 0.06768016330897808, 0.19222172402909823, 0.10591705688940627, 0.1348586178251675, 0.17036228414092744, 0.11452863658113138, 0.12110178172588348, 0.09204790288848536, 0.10331046461526837, 0.08423536603472062, 0.13231602497398853, 0.10491503030061722, 0.10549670444535357, 0.11343800688960723, 0.13437791647655623, 0.1344957644385951, 0.11796525360218116, 0.1831199095717498, 0.09183832377727542, 0.13774967912052358, 0.05714094026812485, 0.2155577511127506, 0.17933612689375877, 0.15962248614856175, 0.2809949219226837, 0.17238315141626767, 0.11782092920371465, 0.11525931023061275, 0.19223161706967012, 0.09283305611461401, 0.1266475027160985, 0.1418170351535082, 0.18104378240449087, 0.09252002076911074, 0.05163858784362674, 0.12599490130586283, 0.17223098315298557, 0.09756441973149776, 0.17226979535605225, 0.11563148668834142, 0.13520711341074534, 0.14339434408715793, 0.1537783590278455, 0.09121314196714334, 0.18932550586760044, 0.15896069737417357, 0.11074846370943955, 0.21655107209725039, 0.09540197612451655, 0.10405346724603858, 0.07994896532701594, 0.18540246066238197, 0.13543610540883882, 0.09874650915818554, 0.060783166970525465, 0.10673437267541885, 0.0638631120590227, 0.10863193656717028, 0.09502674625920397, 0.1267943919769355, 0.1523008490247386, 0.15607563432838234, 0.1443177895354373, 0.16238619999161788, 0.11874695308506489, 0.10451958009174891, 0.08042893385780708, 0.1120012089876192, 0.11881423661751406, 0.1374202367982694, 0.11234202355678592, 0.10553033264087779, 0.09844683416719947, 0.12646519392728806, 0.06477455422282219, 0.10076386840747935, 0.061222423400197706, 0.17787572954382214, 0.11343207649354424, 0.09712077318025486, 0.24654241491641316, 0.16164753319961683, 0.2055883617805583, 0.18267830541091307, 0.1639124152383634, 0.07215933581548077, 0.18757014934505734, 0.13817807898989745, 0.10553344711661339, 0.12024392347250666, 0.1419420755867447, 0.08518500972007002, 0.1403880946870361, 0.13303398287722043, 0.1556726795222078, 0.12370738333889417, 0.08261957738016333, 0.12713732357536042, 0.17551425125982079, 0.17628966750843184, 0.23374779575637408, 0.09165655781647988, 0.07756968228412525, 0.08305734103279454, 0.11660013613956315, 0.18226989518318856, 0.12364935502409935, 0.1646630513880934, 0.2058409803680011, 0.0983512828658734, 0.1639847606420517, 0.08821029202746493, 0.1531612721404859, 0.19360841890530928, 0.19013776656772408, 0.15423179683940752, 0.11902849083500248, 0.09194239747843572, 0.12494671397975513, 0.16257154861731188, 0.14566637788500103, 0.11703205082033362, 0.1340826451778412, 0.2558254525065422, 0.1452310840998377, 0.10364090438399996, 0.10660466392125402, 0.18342016131750175, 0.17947021898414406, 0.19418516010046005, 0.1521616814924138, 0.10481399643634047, 0.10261506800140653, 0.13310484907456807, 0.21526262909173965, 0.09783937569175448, 0.10232628349746976, 0.08286246577543871, 0.13466060773602553, 0.19913358028445924, 0.1795082576572895, 0.09404329117387533, 0.22042666056326457, 0.18813046999275684, 0.16650099919310637, 0.0783291326037475, 0.12012026725070817, 0.06712890788912773, 0.18649148222591194, 0.17349480890801974, 0.1401603647640773, 0.07826548601899828], [0.03961032988237483, 0.030121034609952142, 0.033910635725728104, 0.02908730347241674, 0.029842190644038574, 0.025108340196311474, 0.03796285024977156, 0.017827498294146996, 0.013939836993813515, 0.009719929325261285, 0.04032227935801659, 0.03276493613209043, 0.04901580572394388, 0.03786949740190591, 0.03589063822957022, 0.030602774117141962, 0.010378062492236495, 0.004076076056143003, 0.008332255662285855, 0.004475707737063723, 0.027821389525862675, 0.00549473162806992, 0.03959662686767323, 0.009099325930167521, 0.017460086848586798, 0.040245011182768006, 0.018386209117514745, 0.041250837567661486, 0.025041409502071992, 0.0029036822587451233, 0.06084459474576371, 0.024326450723622526, 0.061885121411510875, 0.028014081596796, 0.013909351263594414, 0.022981814840542417, 0.01562737563758024, 0.07394918227302176, 0.038214145693928, 0.02845721415776227, 0.023271639199395264, 0.02069659371461187, 0.05706482220973287, 0.030774758995643685, 0.04781320418364235, 0.025406637761209692, 0.031225869432091713, 0.05053158849477768, 0.03778219708640661, 0.05234708357602358, 0.06385506463370152, 0.005507926589676312, 0.03130724952955331, 0.06425548850425652, 0.02803107550633805, 0.05145093559154442, 0.005077287130656519, 0.07649305755538599, 0.03986758964934519, 0.016637990783367838, 0.010327224104133035, 0.033687808218279054, 0.017190849242199744, 0.04478420689702034, 0.03421758121943899, 0.023330649693629572, 0.02257944187814636, 0.029749821671949964, 0.037410899331527095, 0.01562597107009164, 0.02452964142763189, 0.030933183351797715, 0.015092749414699418, 0.021714062064087818, 0.012515368073114326, 0.042701090819069316, 0.038636903544621806, 0.0025331749971623397, 0.02962855389341712, 0.08938615928803172, 0.026225600690980042, 0.009452114946075847, 0.03342561889439821, 0.024448083214727894, 0.051481870003044605, 0.028857341169246604, 0.026044808427936265, 0.043928621735955985, 0.029416311532258987, 0.046620739956519434, 0.019664786223854338, 0.03192702002291169, 0.01086454835188176, 0.03579433375437345, 0.007452112622559071, 0.033998824922101836, 0.03945538301819137, 0.01476175494359008, 0.017710978564407145, 0.03430294431746006, 0.042206703419131894, 0.08573999708252293, 0.05208903670843158, 0.04236839831407581, 0.019133868194850426, 0.04538383847102523, 0.019397188975874866, 0.031132431767348732, 0.07254745106079749, 0.03354743967897125, 0.04808102874085307, 0.030860746345881904, 0.10535181686282158, 0.042675286132310114, 0.044449292189840756, 0.05942433952753033, 0.09466855440820966, 0.02544751949608326, 0.0610308526083827, 0.043268563225865364, 0.08706338464149407, 0.05099493291761194, 0.00563046704545351, 0.040717617608606815, 0.023855793389624784, 0.06957016832062177, 0.06275138671376876, 0.03220693946682981, 0.04834012733772397, 0.04195696860551834, 0.03388290399951594, 0.04250575076522572, 0.030649209661143165, 0.022631668718531728, 0.019806464335748127, 0.03392746000151549, 0.03664387656109674, 0.08158986656261341, 0.037398644989090304, 0.04473534898300256, 0.026241076378417865, 0.022458277576203858, 0.03446895469512258, 0.041840911975928714, 0.04941136110574007, 0.06567972672304936, 0.04755946262074368, 0.014951559848019054, 0.03996526476527963, 0.03256649178053651, 0.05147000242556844, 0.013447794780534292, 0.01565118712772216, 0.022139598515682986, 0.05245809529774955, 0.00861882814206183, 0.03505024207489831, 0.05207012254478676, 0.03434333072177001, 0.014834139363041945, 0.005902425577265343, 0.012521736972433115, 0.06900725566915103, 0.030505302561713115, 0.01657607955192881, 0.04039925915588226, 0.01099441062459456, 0.03447445761412382, 0.02873915054702333, 0.008722586324438453, 0.02327000393000032, 0.024223920689629655, 0.00858965961794768, 0.057031702915472646, 0.02054311248606869, 0.04369043558835983, 0.021762701150562083, 0.03025898417191846, 0.030367573523627858, 0.04778121125751308, 0.008049265847408345, 0.05534549928935511, 0.04977793964956488, 0.00995059815301959, 0.017932050362495438, 0.021769352490082383, 0.019394142353641133, 0.005266952935406672, 0.04074867754908545, 0.025424327169145857, 0.024830079770513942, 0.04482982141364898, 0.01219717162062547, 0.01932878077163228, 0.031930568761059215, 0.009000186874930347, 0.025549861236608455, 0.05722800309636763, 0.06501204826469932, 0.029091798766915287, 0.020484936589907323, 0.016316846944391727, 0.043433213140815496, 0.029819117060729435, 0.039497112921838246, 0.011454111314378679, 0.039342138916254044, 0.060412856484098096, 0.01887965335377625, 0.029457715739096915, 0.04446912916111095, 0.04607930633106402, 0.10412997206939117, 0.023014844228912677, 0.05757955887487956, 0.07413658007447209, 0.07063917988645178, 0.03916377580857702, 0.030423783364572694, 0.04480438992115004, 0.058382645781551085, 0.025624975063172833, 0.022577547069106783, 0.10148607393992798, 0.021060151081266146, 0.01770167924197657, 0.03557974366205079, 0.050145960080304315, 0.0224207545896726, 0.0334991720904197, 0.031145218759775162, 0.028325836207451563, 0.03197411713855607, 0.02692101426821734, 0.02162793561417077, 0.015761294701535786, 0.02974306685583932, 0.04362996115482279, 0.006008553967278982, 0.06892715461019959, 0.03355109698272177, 0.033551429464880905, 0.061686894191162925, 0.08418379058795315, 0.09926827544612543, 0.04140178786058511, 0.021822671771847775, 0.05388543102890253, 0.017980799710910236, 0.029773149705891098, 0.049146488175860474, 0.03992379949029003, 0.016265173110046556, 0.022591733540009176, 0.0341251070744225, 0.06244192724781377, 0.03208567847364715, 0.024904106244710938, 0.01934926744018282, 0.07782442468617644, 0.0067402284559128535, 0.023377684044784734, 0.06320879395518984, 0.05789137964269944, 0.06465975288301706, 0.057252484639840465, 0.05794054629015071, 0.022396534282181944, 0.01425609877333045, 0.007955435480523323, 0.023707550451425568, 0.03549654509073921, 0.06687679820294891, 0.06302405601101262, 0.0204585161326187, 0.02948735754138657, 0.010386040367718254, 0.010750666427026902, 0.0575124721175858, 0.04695275392649429, 0.03322270978242159, 0.078462322242558, 0.031176869025720016, 0.045985749922692776, 0.03829118995262044, 0.0442232586044286, 0.01843524005796228, 0.07309860470039503, 0.010282440792902239, 0.03708225428791983, 0.049190491171819825, 0.011678401064792914, 0.07554664369672537, 0.009296419148865556, 0.10695043858140707, 0.03878252733764904, 0.0339938750091408, 0.028817053152514354, 0.03963726772261517, 0.04388615222913878, 0.029554216989449093, 0.05202303221449256, 0.023255468013563325, 0.024785493234438554, 0.00804540837582733, 0.021729534358850548, 0.0236017821090562, 0.0321619118829923, 0.04613530921882816, 0.0467431001764323, 0.03222653895084347, 0.048047325906476805, 0.03540341955210481, 0.03754476072000606, 0.056272354376103194, 0.027741963609254787, 0.012212771140704197, 0.018570597616157362, 0.03680296248889395, 0.013676534872502089, 0.04079284339344927, 0.04407528708023684, 0.02322615190808262, 0.005449215499018984, 0.03848558684278812, 0.03674577555752226, 0.05487563753766673, 0.04722519252183182, 0.008697419460596783, 0.044001679601413865, 0.036468040996364186, 0.022929730492510965, 0.0803024685010314, 0.03528084559366107, 0.02621420469534184, 0.015256717401955808, 0.012175073431405638, 0.050222254557801146, 0.04720159646655832, 0.025896280505029217, 0.041244401663009606, 0.10584209912589618, 0.05737445130944252, 0.049055513593235185, 0.05111996317282319, 0.029777919807072197, 0.0006659194093247477, 0.01869859985475029, 0.03841819813741105, 0.028795509665672268, 0.0602709815970489, 0.01609537989965507, 0.142371873238257, 0.20063838096601622, 0.150920247392995, 0.12842968851327896, 0.156922934576869, 0.11133349660251822, 0.15940386216555322, 0.09000651671418122, 0.06994051951915026, 0.12388408742845058, 0.12266393218721662, 0.14386975286262377, 0.12334296932177884, 0.09681400749832392, 0.07176488983844008, 0.0928194989849414, 0.06622127909213305, 0.08569144790193864, 0.07941043922411543, 0.04468358015375478, 0.1111742580043418, 0.0814992074987718, 0.1279625307236399, 0.09146848826536111, 0.08334933500736952, 0.23298129545790808, 0.19029889149325235, 0.12468432448804379, 0.16829269805124827, 0.09326632786542177, 0.12045642706964697, 0.10172258410602808, 0.13212895286934717, 0.089584617210286, 0.17394106781908444, 0.1616850561861481, 0.2495973695601736, 0.1492566695170743, 0.15051908391926969, 0.16157111658581666, 0.13200113044253417, 0.1504992571260248, 0.14196503721177578, 0.08392502447324139, 0.0997314638059054, 0.07754484790244273, 0.09729719228510346, 0.14421900840742247, 0.11518300218241555, 0.15009896217712335, 0.11584076045879296, 0.10130492544599942, 0.14796216040849686, 0.12915949363793644, 0.16504655938063348, 0.10275574188147273, 0.14864085827554974, 0.15580992001507962, 0.06553573480674199, 0.1197396091052464, 0.10926002929253237, 0.10746852042419569, 0.10469805515770401, 0.12026736007205077, 0.0923512080418212, 0.08561421026076589, 0.11914188760731902, 0.1447989929999624, 0.12436993207250323, 0.1164687310478517, 0.17732777180416243, 0.12262833624013833, 0.12936426193586417, 0.13362058997154236, 0.10376835361655269, 0.08382053008036953, 0.21697785705327988, 0.06939931998827628, 0.0690797164237925, 0.26818437076040674, 0.10926705891532557, 0.11456911798034396, 0.08671309093811683, 0.1329148592693465, 0.1694694949047906, 0.14440465558852467, 0.1563327448176486, 0.09881750427718673, 0.11925997984196458, 0.191519508138299, 0.12420789791004998, 0.09029722825757094, 0.06945272069424391, 0.09100251112665449, 0.09182728401252202, 0.10319704748690128, 0.13397325176213468, 0.181226552597114, 0.10655424876936845, 0.11330221167632512, 0.1832735841827733, 0.1307102854230574, 0.2133384666272572, 0.1628048832395247, 0.10767923268888678, 0.20992652113948548, 0.11067030326064144, 0.08886289343770061, 0.13456831340278896, 0.13714581009532723, 0.23323452472686768, 0.09314664785883256, 0.17517938065741742, 0.1462140099278518, 0.21500443294644356, 0.20143639243074826, 0.16102556086012296, 0.08287892024964094, 0.2245420433048691, 0.13026998404945644, 0.1888335408376796, 0.16944939669753822, 0.12459889692919594, 0.14341183671993868, 0.12058715362633977, 0.18769574617700918, 0.15473889320024423, 0.11628579800682408, 0.16079677242253507, 0.15187292412987777, 0.09929238379533802, 0.1456628902150052, 0.12204829736479691, 0.08542099741420575, 0.17664213930921896, 0.17615269842956746, 0.2018485888838768, 0.1855651190770524, 0.17271887697279453, 0.07550344137208802, 0.1360216811299324, 0.20450451065387043, 0.09015626260744673, 0.07758234374757324, 0.13361229827361448, 0.21736235570694717, 0.1324169502726623, 0.09095337840595416, 0.14889224192925862, 0.08964197377541236, 0.10362801221864563, 0.16881329725895608, 0.07419358380138874, 0.08049043627189738, 0.1302456110715866, 0.09579868840851954, 0.11944957609687533, 0.1420325921582324, 0.0903028261714748, 0.07372745738497802, 0.04699386975594929, 0.10336665410016264, 0.20525274478963443, 0.1517586045499359, 0.19816817423062666, 0.15161509439349174, 0.16236341478569166, 0.15208096296659537, 0.10862997560096638, 0.08653780498674937, 0.14266536677522318, 0.13366527828787053, 0.08888762603913035, 0.16475993261805602, 0.10970120597630739, 0.10324837187571184], [0.0237057031398373, 0.04301334924197622, 0.07452216438416924, 0.06406014505773783, 0.016516329454524175, 0.03112494752609304, 0.06849213223904371, 0.07411114858197314, 0.015192151402256318, 0.10075376502105168, 0.03756463501070227, 0.02440586985488023, 0.012947698356583714, 0.0017028916647957104, 0.04930143504004393, 0.024600609405232326, 0.01060187557180013, 0.031021973051662956, 0.0383871483749577, 0.014527120926816548, 0.01513606878662748, 0.016245583804058175, 0.029072558906461512, 0.030934845762593404, 0.014337309237037386, 0.025246880083744015, 0.06021684128791094, 0.09631746914237738, 0.0342090927463557, 0.04147069987707904, 0.02214832277968526, 0.09523233558450427, 0.03102271944018347, 0.1058739699157221, 0.034773633881871185, 0.009957716833533985, 0.09965225841317858, 0.014868271370817508, 0.019461478472554257, 0.028957978090537444, 0.03008033607953361, 0.052641330286860466, 0.034556458571127484, 0.0032837706468334155, 0.04741887355755482, 0.01560240045988134, 0.0438810225043978, 0.01480409552875374, 0.029998151918074915, 0.027707088605633805, 0.033705826715699265, 0.09518215791987521, 0.0607512215418475, 0.010221188588600074, 0.01497947477868625, 0.07732574215957097, 0.0642477667757443, 0.011494404420123568, 0.05943733347313745, 0.004998340005321162, 0.029012885144246475, 0.009417172088953001, 0.023591656670240418, 0.015413223200344613, 0.05758624244481325, 0.039202937457178316, 0.02213445182756654, 0.014384070477847542, 0.036822453407304626, 0.06751790522996869, 0.038119992174740346, 0.018687278497964144, 0.038008383342197964, 0.038692458599273644, 0.01108713073855532, 0.0356191495832588, 0.030104681916002716, 0.0495772663104747, 0.0484071326708155, 0.03513491985255054, 0.031422563163297515, 0.04064631036349705, 0.051564088091254234, 0.014792302590129631, 0.048519094341567585, 0.08319152811808245, 0.020754109735467603, 0.06677688392145292, 0.02862429492441671, 0.01955216976680926, 0.06307365692087583, 0.026736445957794785, 0.03512178002191441, 0.037339154431330304, 0.03376841478581939, 0.03892799846029707, 0.05190085519903472, 0.07204106716173035, 0.07022418108369623, 0.00953796913381666, 0.05899009068629571, 0.05864301323890686, 0.039937119132706096, 0.02745123510248959, 0.02494784800468811, 0.018671729868011813, 0.022899374532114183, 0.009615956556185015, 0.019746117127527083, 0.03257913967328412, 0.09113357016550643, 0.048614387799586566, 0.012296288623474538, 0.050681520985173326, 0.0228009411532964, 0.011043925021242882, 0.04452609217592648, 0.019911510038322637, 0.04799334166039314, 0.009414764985974346, 0.020694768455411707, 0.019149606814607978, 0.040917093333389075, 0.02020110539160669, 0.018111707775720527, 0.016112229620505656, 0.009028155240230262, 0.020248472224920988, 0.032340733001806905, 0.03006610720019255, 0.005977349414024502, 0.027964238110663633, 0.03986224279339824, 0.012697651416861584, 0.05529697725017156, 0.07095288698162351, 0.03329985921404191, 0.0653447543403932, 0.024955333942281346, 0.027135473742548908, 0.022157793432208042, 0.031177086156925986, 0.039998384059539864, 0.019623729766213467, 0.047962336002715995, 0.03782513817506177, 0.027272112035591687, 0.04017169886667814, 0.04288621213553207, 0.05712305408503328, 0.05080529595060008, 0.022369443771562407, 0.059271072037518024, 0.03748005562062774, 0.055713974338557036, 0.056093400942959955, 0.028120564097272496, 0.02402633468487433, 0.04877595038020185, 0.05391157837584615, 0.048776917292603424, 0.05866501134421144, 0.02937552479228803, 0.05805906600185803, 0.03314634066607271, 0.0078089066914149696, 0.043775764759629965, 0.052728074203644476, 0.06106817203440836, 0.038047460173921924, 0.03885341389104724, 0.0027792162478103167, 0.03988020700801696, 0.04879972624725529, 0.01474271694730435, 0.04478950286284089, 0.00869867135770619, 0.038867754728666375, 0.03862923609891108, 0.06519175826438836, 0.03713998065463134, 0.040542348620614836, 0.04795222583093813, 0.08939715155533381, 0.07115298017327275, 0.10030201676168612, 0.09231638562466417, 0.04131615674123168, 0.06837208582354443, 0.004475086029352886, 0.03764266314517174, 0.019612248953697935, 0.038036800388778956, 0.07861168815621308, 0.02407585925954793, 0.03720765434471624, 0.038941799862576384, 0.03158213424363306, 0.026906632718497088, 0.10470697789319924, 0.04032914273973022, 0.046042360099298615, 0.07049737285290446, 0.052077538932540586, 0.01591267077518361, 0.026205376954749227, 0.015861305674271922, 0.054436601631875546, 0.018103606067597866, 0.0744382431730628, 0.01951764420872288, 0.02286928489671222, 0.03761360149032303, 0.017498936371079514, 0.08390061078327042, 0.0535254376674337, 0.02811609085516206, 0.014084817874910576, 0.04526251640969089, 0.030218241536723714, 0.047402826204363785, 0.012880796500082527, 0.06006361450999975, 0.06650382785924844, 0.01694971146727247, 0.06235775497875043, 0.008145376091956027, 0.03756389540753194, 0.06429025663861207, 0.024808059612821256, 0.013069151884077914, 0.044353584825460396, 0.03981238064755287, 0.08746696369988577, 0.021792127517983317, 0.0436643459168928, 0.007231782972147422, 0.02142647687079651, 0.03296728545267667, 0.03223502742392676, 0.0655951676890254, 0.03162467838930232, 0.049544788231807094, 0.05185258421780808, 0.016495998849027922, 0.061560693463044505, 0.07229767553508282, 0.036734114933226786, 0.016869186323934367, 0.026342069530593495, 0.03004115746755685, 0.04468505257474525, 0.01623978741866137, 0.06868294985698802, 0.015245404526857393, 0.018803326645866036, 0.01800030589635883, 0.048211073369852135, 0.05481117671089513, 0.050732404326221774, 0.03150039452261158, 0.019495003191488128, 0.010389330414389926, 0.0442363577229636, 0.023807692042152797, 0.05609750947249787, 0.04487054030011807, 0.04323181037658027, 0.024074130691587925, 0.10268351861408778, 0.055175848571317535, 0.03245386853814125, 0.05074948983799134, 0.05377541336097887, 0.012032229935617318, 0.03212235668408019, 0.0712172645809395, 0.07660752641303198, 0.056049849172788005, 0.02558738591947726, 0.018290240517152206, 0.01719073049857148, 0.021433180796780756, 0.03289459738880396, 0.02347329132524984, 0.02771682558315141, 0.03574921117563333, 0.08882341627031565, 0.029264258619930063, 0.04042997643617647, 0.0383858930851732, 0.02689766587822565, 0.02592694350252194, 0.028044167839522873, 0.04331357045365231, 0.0821376410978181, 0.019768505390467386, 0.02537910620282803, 0.018424563309443847, 0.027753320589129413, 0.01585855082209621, 0.04282187344506383, 0.04862152938065784, 0.019959962527666773, 0.04388853727972933, 0.019707109845642532, 0.05119529413059354, 0.01848109545452254, 0.04173345238502536, 0.00971312785986811, 0.040928150061517954, 0.04932837966563446, 0.025858596366431032, 0.03973875959802951, 0.035932473306144984, 0.03437207346515996, 0.05167991741161261, 0.009283257265841323, 0.04660983929144485, 0.007373578131331929, 0.03612459031865001, 0.049344189531568966, 0.03853933020894017, 0.04323100631258317, 0.013081553807881261, 0.05848781192409141, 0.020718669851443598, 0.03576613723167351, 0.07482543561075415, 0.05238062695467046, 0.0075980816202770385, 0.04155693828527417, 0.05923583571399961, 0.07926373995308365, 0.014250884231712137, 0.04170043147834284, 0.013675568808269287, 0.037911122132624896, 0.03852072138605373, 0.07705361569034201, 0.03259220825774329, 0.013697472766840031, 0.0660862031259707, 0.04136694508737751, 0.0394232883118093, 0.025064196404335753, 0.013896435349514442, 0.03345678400780473, 0.04307414597964712, 0.10279714608831064, 0.045576349033841064, 0.06648259649851493, 0.07143352047673293, 0.09902601130306721, 0.15991363195436342, 0.11946723157806055, 0.0810151541871684, 0.14488819321351393, 0.14383802456515177, 0.2026412399219615, 0.11441240353243691, 0.23838256991335324, 0.20848550274968147, 0.10157004264848572, 0.12657895710851463, 0.12060227138655526, 0.10519402354423489, 0.17434233985841274, 0.18061665818095207, 0.22206400627536432, 0.09407855463879448, 0.0764962195285729, 0.08627275563776493, 0.1665617280772754, 0.11496042912559849, 0.21309906590197766, 0.14826820684330805, 0.11904496566525527, 0.13387463348252432, 0.2425746406827654, 0.1569539571979216, 0.08161128791315214, 0.13031995136822971, 0.12216203340462276, 0.16101045667060784, 0.24159535180245126, 0.08559373885925327, 0.0863173489591905, 0.15797285895262445, 0.07525298052600451, 0.2535279872162001, 0.13380990124174527, 0.1525206808000803, 0.09382525073098284, 0.13031088614038058, 0.12234014884701797, 0.15117657078163965, 0.06875146153782095, 0.09502330608665943, 0.1138311568647623, 0.10023596816297088, 0.1579871489001172, 0.11205855198204517, 0.14014147434915813, 0.17018043675592967, 0.09744672104716301, 0.1319776259894882, 0.2000715056700366, 0.08882929916892733, 0.21059624877359184, 0.12319371875907693, 0.12370472348162107, 0.09609065524169377, 0.11057391057589225, 0.12950057962111064, 0.17107899353972503, 0.12244568818381854, 0.12947102263569832, 0.1178866656763213, 0.219512049640928, 0.09937471723450081, 0.13693988828786782, 0.1029361372015306, 0.12053350864776544, 0.1296250500849315, 0.11089544117982898, 0.0803974023354905, 0.06914823488997561, 0.11246621582124915, 0.09282897811915193, 0.09045730823917048, 0.06465007697365113, 0.059031128484223566, 0.17806273379496165, 0.13186726905405521, 0.07208023898835693, 0.11468558173094477, 0.17769447926964077, 0.03630475154412644, 0.1904251125774213, 0.15057156181761197, 0.14082929172686168, 0.11312824208289385, 0.14743720500596932, 0.06967854393380028, 0.1519500192786966, 0.22308094027851308, 0.10351388262850897, 0.1253501030483416, 0.12162685926471438, 0.1327073768313442, 0.13367751905960695, 0.15171232846166405, 0.19501688118491853, 0.24648957060916082, 0.10494474334908382, 0.10625289101153612, 0.18618422799876758, 0.17215429512517794, 0.14572686249656336, 0.13034427006329807, 0.07380322939051048, 0.1599178117300783, 0.1687282496797187, 0.1328476978732007, 0.17065953676189693, 0.10724428495658295, 0.14452706330588885, 0.08741169702261686, 0.0976500508508512, 0.27771417796611786, 0.21701774134167603, 0.14895898263369287, 0.08021658632372107, 0.20073319944952214, 0.09479486370193106, 0.09307196829468012, 0.12481910868414811, 0.13697772340050765, 0.11546136438846588, 0.10759903663503272, 0.1267862766981125, 0.1317613497376442, 0.14050601050257683, 0.12307589793843882, 0.11646814750773565, 0.13601623927908285, 0.11343607985015426, 0.10726312787405082, 0.13893803821078368, 0.16099958653960908, 0.15930736091520104, 0.17319674204502786, 0.1242135161800044, 0.09587613639554807, 0.11982366602335658, 0.14687294885516167, 0.16435814489211353, 0.11438659206032753, 0.16978323592671327, 0.10183252713509969, 0.17522002490503447, 0.10963732868965183, 0.09771936998835631, 0.17835181685430662, 0.18239554629794189, 0.1067161268687674, 0.09923288305955273, 0.1529248162571873, 0.1113596609128373, 0.14708306400903634, 0.13845794754368917, 0.11524560382323605, 0.08813150054109947, 0.16207244539899485, 0.14032877715570585, 0.07966600265353918, 0.11198183681283679, 0.14747472799250058, 0.10730386033122029, 0.18914209785205977, 0.21924915803330286, 0.12235186036143984, 0.11754365265369415, 0.09487119889152901, 0.32472311119948116, 0.15757898294499942, 0.16413407905825547]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.025894965843430588, 0.018946339775409018, 0.03474006336182356, 0.007265235596735562, 0.04742700579975333, 0.07659507529543978, 0.04245320162070649, 0.03940061506416116, 0.02114245398635311, 0.0596289314063532, 0.023138137434476187, 0.024750633497855494, 0.05100082938692399, 0.06853788585535117, 0.022300448634528687, 0.019781668969829167, 0.03295517699526889, 0.018524760879310112, 0.028708935382642915, 0.03732032169188772, 0.02523055622753288, 0.014754967897066047, 0.02368244295939803, 0.027748871095744625, 0.09441216995141335, 0.03130166857902493, 0.0205653480786298, 0.04611161138330187, 0.030791912360915115, 0.047654294674949985, 0.04547861963510513, 0.026635802251153758, 0.04052344802767038, 0.026786107935809662, 0.06766497090991054, 0.055204285973949094, 0.026235368202573488, 0.02187804871105722, 0.04750255388872964, 0.06151033259396042, 0.021492113259487917, 0.05321923177689314, 0.056770354975014925, 0.03924076917714306, 0.02753089172100382, 0.019729801753003682, 0.05609075804906232, 0.05782111055616822, 0.037259480849440606, 0.025544193772865192, 0.04934444058952587, 0.03610764729923435, 0.009477777988649905, 0.03029419674671122, 0.03361630080533879, 0.03791029092722705, 0.028983745457870618, 0.07576612941920757, 0.02167228127031454, 0.08717505114951304, 0.03436006000265479, 0.04019897936710289, 0.021465049890269126, 0.03176697736073818, 0.08444435482046433, 0.02820026990957558, 0.04122216946312359, 0.05470772726195199, 0.046372922004333565, 0.024163317334439074, 0.06856640468218497, 0.04013343627697655, 0.004898300194846732, 0.037498379458806345, 0.05351118503936699, 0.02000454567106707, 0.019517184501247745, 0.018034556647762656, 0.030037646048835347, 0.026549699549962367, 0.04994809248351625, 0.06232133800429957, 0.03034736675077251, 0.01530256262049079, 0.02077967523863273, 0.009261219296604395, 0.017625927592494657, 0.02826612173313541, 0.03432934611503567, 0.02843241539916822, 0.06270164331155163, 0.026162062671833804, 0.08544565537678343, 0.09701368678361177, 0.03425228150029268, 0.06338196966264929, 0.012923757096619477, 0.07357227642621313, 0.02260956883297435, 0.011848172222796296, 0.031342679235552035, 0.04221197563622679, 0.019638793243627464, 0.00852765848061868, 0.027744219738191793, 0.04652864918378847, 0.03171549351619823, 0.03123898890667728, 0.0295099832915834, 0.05407568885545645, 0.05127742400925074, 0.05073711335925119, 0.02318159251340798, 0.04502664067383323, 0.03447039658203721, 0.041924755155508, 0.08711713818567139, 0.07673663805638041, 0.019624116531174098, 0.03186166352991547, 0.01951904029452375, 0.05515743652358651, 0.03660506775070514, 0.011094098445028067, 0.02953879049580012, 0.007689739826933614, 0.02864986551659448, 0.05546575605071016, 0.05923039386315005, 0.04011637790660773, 0.026118156367114613, 0.02030385934215571, 0.0325377829638975, 0.03676678300169962, 0.0444510801296149, 0.03183900046029261, 0.010380207511064197, 0.038630874760981114, 0.02825837455955999, 0.040089263647262535, 0.02112769245702241, 0.0610987264662981, 0.04010497512561934, 0.020687706602205123, 0.03522086988336273, 0.03221873579812901, 0.020540730828153234, 0.025478007770808678, 0.041945304588547776, 0.019322853768244386, 0.041378273229513846, 0.02382952899539045, 0.06315858914916005, 0.048803224095276425, 0.07709987142256328, 0.06949698831886053, 0.053851280361413956, 0.02914990850591234, 0.03840099388201322, 0.0367361675016582, 0.05833229848316737, 0.07193273904600314, 0.02850284054875374, 0.022516283838610564, 0.0886668578854629, 0.055781318939157894, 0.0619279844686389, 0.025838140231956328, 0.031789704891187806, 0.054721671156585217, 0.0058934549202344245, 0.01699629459264023, 0.041355040190475326, 0.032417658516871076, 0.05900858755090407, 0.02850468277132937, 0.060779801436832974, 0.011637316617582525, 0.032738863423998864, 0.02772693575492927, 0.035886322746851614, 0.031895084772259, 0.03445726692942636, 0.02248129009136132, 0.029425590498639003, 0.05655329501522439, 0.05618194976289358, 0.02560549771546253, 0.0522199091501534, 0.03814834476049457, 0.03687372690598879, 0.031496408129377026, 0.04982640401327184, 0.06536878805075373, 0.006549663592262992, 0.05527278747675674, 0.016291576603959714, 0.005898695331000323, 0.05676262306847742, 0.008900525347728814, 0.08750371315649577, 0.04320676904171705, 0.026627196730779748, 0.05698033781456096, 0.042109795047768524, 0.0088349050742441, 0.05528358296890344, 0.03530006849073938, 0.04619921025420938, 0.007280446655516113, 0.02467503451875278, 0.08540376941008226, 0.032832820168031115, 0.12081415073147841, 0.08714340427624327, 0.05687866952004177, 0.02878468024677464, 0.03436653661940779, 0.05462226238367813, 0.03742067702114582, 0.03101683993424688, 0.02669691790028342, 0.042493021448275874, 0.027548694783555608, 0.06185107930962529, 0.010317185178532131, 0.011102300237065979, 0.021069886362446204, 0.04907419366229858, 0.01746893664156752, 0.03808418588180627, 0.04107816058344074, 0.06887025266353573, 0.01864531958874847, 0.0401391868612596, 0.012888251903599926, 0.024347110418602824, 0.041665079803871255, 0.016587197348209362, 0.028599236626178026, 0.0472967881443245, 0.04332739221198218, 0.026347470669341937, 0.06641596435968365, 0.023309075672711645, 0.023114717798307538, 0.06545083650520869, 0.0478969693316945, 0.021078927841569697, 0.02971309596406562, 0.03665011229791811, 0.043663687737924714, 0.020364522069160427, 0.00923968683595636, 0.03137846177976046, 0.0236987244071705, 0.03844074585608073, 0.035516853643847365, 0.030833326745778322, 0.03862197916688664, 0.07004855586481945, 0.06993679436189787, 0.011657144258996206, 0.013647323939949274, 0.03045859221102936, 0.014679212854909045, 0.034131105323987346, 0.08965029940009117, 0.031327076322798214, 0.0414142932609788, 0.03175483497657946, 0.053809038163827996, 0.024328569449218254, 0.041253792587667704, 0.042217420879751444, 0.012763124957148517, 0.047430293301918676, 0.04852720283504043, 0.016500185410092984, 0.03628512831138713, 0.029653697008533136, 0.03852090459050877, 0.02270895046448069, 0.03961751217554722, 0.009982851466962268, 0.012581736431457102, 0.023320707459268824, 0.061766696694706164, 0.024070364822234427, 0.023563541571742723, 0.030750732070633342, 0.013481589217138077, 0.047172521241009235, 0.019175550601046, 0.04965830035507679, 0.07550590445420571, 0.012906908223937665, 0.04263442136081202, 0.06503972570811, 0.04539816913061908, 0.08721363943602357, 0.03841200989804097, 0.02760277741721698, 0.042768001157258234, 0.004765557540979768, 0.08498058747500181, 0.011322620557621121, 0.05056452119190778, 0.015482920621122633, 0.0184293571593506, 0.017255243911807026, 0.008835251975272383, 0.019840228238276074, 0.03644640929996967, 0.011655498811575984, 0.06966559748564448, 0.008512804500891693, 0.057860350236296654, 0.02056340916481401, 0.04193668380113585, 0.024640264688059688, 0.02295450210970427, 0.021085358657208935, 0.02748665463046304, 0.049363232616867335, 0.036149540051285706, 0.026818935460011874, 0.011483887127334518, 0.03219927202111908, 0.024287909934563295, 0.0485288279264101, 0.02474656398408115, 0.01635438180528581, 0.029367680927472453, 0.05916978032993419, 0.02524959252748106, 0.02642734781173723, 0.0513340715052826, 0.06850630005023309, 0.008642499684356153, 0.04483184344800455, 0.0666159964831812, 0.07161755952984095, 0.044608493468591144, 0.026204523696963276, 0.014749658360545124, 0.03181829157152346, 0.04171528460990105, 0.0270421259836959, 0.04242269807894315, 0.019232698516654115, 0.07205627991684846, 0.1312989688345364, 0.10252897547824041, 0.10697546973824501, 0.1258932160479682, 0.15500844802175248, 0.22234091641647474, 0.11768618571971144, 0.15465532482734748, 0.11037837713956833, 0.10964023960488183, 0.1750012245029211, 0.11787475060139384, 0.1746218962860959, 0.25534713960119654, 0.05340524875958051, 0.16506595191146645, 0.13084065914154053, 0.11166114080697298, 0.11042956582137517, 0.18218931236437388, 0.085707434186978, 0.07963074597397021, 0.10772649943828583, 0.11735845330570426, 0.2424773930438927, 0.2456360821213041, 0.12472074824784483, 0.15756921204073088, 0.0992967060634068, 0.12795145703213556, 0.13683111912437848, 0.19353059093867028, 0.19419985716896399, 0.18203714410109179, 0.226450613034623, 0.26964935500706944, 0.10881225046302591, 0.20706456899642944, 0.10482536189790283, 0.28096672200730866, 0.09626594119306121, 0.14077051702354634, 0.22272240237465926, 0.1614825270537819, 0.09045025147497654, 0.09569828558181014, 0.14635796791740827, 0.14443779523883546, 0.17726595726396355, 0.17178788621510777, 0.12038368811564785, 0.1396967896393367, 0.10523207578808069, 0.11194607123200383, 0.15947567831192697, 0.12123328181249754, 0.11251238334391798, 0.1396880093961954, 0.10122496687940188, 0.21997508193765367, 0.07532024370240313, 0.13866315010402883, 0.08546261196689946, 0.1731532479503325, 0.12334822118282318, 0.13927510726664746, 0.12708074732550553, 0.13554761585380348, 0.09992594551295042, 0.11127534615142004, 0.11650541265095983, 0.17748280348522322, 0.11981894341962677, 0.09314720425754786, 0.10718565274562154, 0.17067568589534077, 0.12234010813491684, 0.06590810125427586, 0.08578687028161117, 0.267938849649259, 0.1493617067379611, 0.11864000239542552, 0.08206887835902826, 0.10046255814709834, 0.10746292929564204, 0.15752338378557137, 0.10569335746445827, 0.1545194685459137, 0.13409822434186935, 0.16961365645485266, 0.1574517169169017, 0.13470543175935745, 0.11734249416206564, 0.1486828595932041, 0.1328579301812819, 0.1288727990218571, 0.11323646841836826, 0.1906740399343627, 0.157721963844129, 0.10972226091793605, 0.12356789010976042, 0.10506074569587197, 0.18595628094460281, 0.14868686294981412, 0.10835066344588995, 0.0887761970183679, 0.12784534772591932, 0.10847490999315466, 0.08560222054698638, 0.14244453076805386, 0.1262623390981129, 0.13208706011729582, 0.09398380400879042, 0.0765666039660573, 0.17370208778551646, 0.07602763003004448, 0.19680984211819513, 0.15092927190874303, 0.17421139617051395, 0.19507546589842864, 0.14279115359698022, 0.13384207737232956, 0.1781967987439462, 0.12554131421659673, 0.156426925478237, 0.11302452800529343, 0.08569642156362534, 0.26030514069965904, 0.12211361314569201, 0.16216620536787169, 0.1547903532960585, 0.11424244408096586, 0.097058449738792, 0.09623618064714329, 0.19279243983328342, 0.08024361237351384, 0.10696978361478873, 0.09635778769318547, 0.09527576182569776, 0.15595032248113835, 0.09950768295675516, 0.09784230017768485, 0.09454415858324085, 0.07335493487438985, 0.13835666940680572, 0.1434414887002536, 0.0917979712997164, 0.07723760046064854, 0.15278568943696363, 0.16176550329795905, 0.10307440906763077, 0.1277670854968684, 0.14649085221546038, 0.09762693316276584, 0.08433280366339854, 0.09129396905856473, 0.09491624683141708, 0.09600310386823756, 0.08316582521157605, 0.10778633265623025, 0.14518146961927414, 0.12095912652356283, 0.14734287506767682, 0.12005967407354287, 0.2600186089319842, 0.20151054273758615, 0.14192157025848115, 0.1410681360534259, 0.1195576260132449, 0.1660975151296173, 0.13415439347071306, 0.10335782635957003, 0.15331292471715383, 0.11612262390553951, 0.09060744089739663, 0.1910196313900607], [0.033510011687342606, 0.026503923881266798, 0.0032878560637722588, 0.054105642783854685, 0.04033623682335019, 0.04022048553451896, 0.05993935439203467, 0.0719120776546853, 0.019242147116788795, 0.05416397983208299, 0.0798827131677951, 0.015741026860528758, 0.01996198116934725, 0.040470712286021025, 0.013123848591931164, 0.07789690579686846, 0.02126992866396904, 0.0402602748280125, 0.045216491379375966, 0.029878682257341485, 0.02030366935235049, 0.021964555140584707, 0.013130755230252231, 0.044742965538586886, 0.03657812312511461, 0.033640310766973665, 0.047508972830006053, 0.03288370690175465, 0.037169310330812416, 0.021721050974779894, 0.09636970955346312, 0.0545793518290988, 0.00989134084167225, 0.045045052721564255, 0.06979569979012012, 0.08204030524939299, 0.027130435620035444, 0.07912134937942028, 0.05932265426963568, 0.0346102155079799, 0.09565580250429255, 0.04229293164930173, 0.04300075223935502, 0.0024575652039077666, 0.04435069426628096, 0.030283801590225527, 0.03876345032559974, 0.03813826173011746, 0.037285187148622105, 0.0035421048315973686, 0.01836840096595032, 0.07780701347759791, 0.01992184921566929, 0.0632542015186378, 0.006285949260927737, 0.026527340124760355, 0.04333034044663821, 0.010556579966630255, 0.033992704536233626, 0.027004323101469448, 0.044040461270404715, 0.0711953207584364, 0.05113368993625045, 0.026734147420419112, 0.051526744916502915, 0.10836702292518956, 0.020619719089674096, 0.017252875824591944, 0.056417211424559355, 0.03810602453138147, 0.01136699250699686, 0.015212139347568154, 0.010926927772483655, 0.011350912075223667, 0.051094826843057356, 0.044176198808210235, 0.03624778174396072, 0.09864114624048982, 0.05960512161254883, 0.023791420772405605, 0.03414099497188415, 0.0815116111189127, 0.0589804079915796, 0.04160289206941213, 0.0616279702101435, 0.03621598220031176, 0.03965520140315805, 0.03207247757485934, 0.013146536258448447, 0.06210234761238098, 0.029774937645665238, 0.03960508480668068, 0.02000567882454821, 0.02976180799305439, 0.04260655392759612, 0.013296409377029963, 0.020026862687830414, 0.01906763469534261, 0.023855649200933318, 0.019266443759469048, 0.01092426197802914, 0.030475803251777376, 0.027243803554613675, 0.014697207603603601, 0.022797816499535526, 0.016179413069039583, 0.011464868638930576, 0.03600728179195097, 0.02585640300198325, 0.025692979539079324, 0.03181466480184879, 0.030075789894908667, 0.05624024609902075, 0.01711663108185998, 0.02161639542984111, 0.04160585726744362, 0.04299512379137533, 0.027016799664124846, 0.03329400345683098, 0.018187276220747402, 0.0081250828058858, 0.015515666721122605, 0.0432978148705193, 0.04997550869094474, 0.00772297871299088, 0.031197001159723316, 0.00977787621585386, 0.04868739816759314, 0.047877685366464515, 0.043818451397653134, 0.03619072373424258, 0.0212567192834935, 0.019318897909085666, 0.032096222907836945, 0.01788557580273066, 0.007323395377690238, 0.0287086436125849, 0.031944875671927414, 0.015399101190268993, 0.022231160031099404, 0.024744567394788777, 0.03928395114572985, 0.012955474367897426, 0.024800363329372237, 0.04875879022958023, 0.04290557073961411, 0.07872093229421548, 0.017508227211822356, 0.037204332915799956, 0.015808206916387593, 0.05185253332768168, 0.03923016706747668, 0.01967903206657086, 0.014230353458385383, 0.021552565640636852, 0.05004439695871302, 0.04419043447290148, 0.0464256136412067, 0.06622945543910776, 0.03000324432338987, 0.025821041149486388, 0.015374341447438513, 0.02750616251224918, 0.018944280421627418, 0.0763052933450256, 0.05197846942714282, 0.024933686978848915, 0.014808456812586104, 0.04171271635485547, 0.009533722352768694, 0.046359751639621596, 0.03399471299988883, 0.08418214174785785, 0.04587441250415785, 0.02279589624543275, 0.022807149748717035, 0.043033969921192954, 0.00991783763415047, 0.042043105233460665, 0.00817120452744088, 0.04045156063511968, 0.03456786135211587, 0.028869246066148792, 0.0051642642938531935, 0.01639457991612809, 0.07841667040650334, 0.040995521803519556, 0.05935593641230038, 0.027875945437699556, 0.06518965480583054, 0.042615239175834825, 0.09080832797501769, 0.03068671907697405, 0.02798407508193382, 0.03850973251142672, 0.052914684904473167, 0.020403676932411532, 0.015442474844998546, 0.028523688537201712, 0.042244942260107825, 0.08425921654062611, 0.030032363653715168, 0.022843878849276474, 0.019626196241006255, 0.08096084424427577, 0.015089835106794323, 0.01806609665176698, 0.039752978299345286, 0.022083666874095798, 0.045723655593714545, 0.09710549257163491, 0.06385593315852539, 0.044404844753444195, 0.02554785616562835, 0.0731519850503121, 0.00936312083753624, 0.019965826766565442, 0.009035515648845052, 0.009920838455270444, 0.019125873355993202, 0.03157827337937696, 0.03275865289781775, 0.03227247577160597, 0.011318009912169405, 0.014637320102857692, 0.01862365735827812, 0.012911126167247338, 0.02730790475782539, 0.009218788805550762, 0.025023163695420538, 0.040002909888114245, 0.02656060700038714, 0.021460727622200335, 0.010922468949242361, 0.013343817770614155, 0.05942958460322448, 0.05370179231145552, 0.003204138413171417, 0.023083478046048964, 0.04794006648340395, 0.021886537184140513, 0.010509352232994778, 0.007404133411390441, 0.03332794377846377, 0.05298989711861525, 0.008478647048052932, 0.09023578691163234, 0.09617657134575502, 0.013691612768785229, 0.022934666834771633, 0.011625415961524206, 0.012671660132972258, 0.015498464162062322, 0.023234424946297492, 0.019915481164519275, 0.040534039959311485, 0.038023684306868484, 0.0691956848438297, 0.03808049465130482, 0.025763947516679764, 0.020099947694689035, 0.056251445319503546, 0.022637924811403667, 0.0669511995677437, 0.00433040752042351, 0.004340044414025864, 0.037216509226709604, 0.005105686365693275, 0.05891011854899781, 0.014277403076578463, 0.005978361279371062, 0.0811032008911882, 0.004258760583720037, 0.012867319946443396, 0.02943357007045831, 0.07629333755799703, 0.02214284360940967, 0.011820985869105374, 0.07787553872913122, 0.023155743721872568, 0.015774785674044063, 0.015546892902680805, 0.018258581769519618, 0.05729280997599874, 0.0779083323265825, 0.012656749325937458, 0.04242972091638616, 0.021459195829395736, 0.05349655582436493, 0.013175055933451014, 0.03522204714162009, 0.015125629525365574, 0.035726772022566626, 0.013684242182145161, 0.03697992781443255, 0.058334551219429286, 0.030264076577233415, 0.013452306190239531, 0.060229387400405746, 0.04071299678512982, 0.024561281515551463, 0.03694703582940357, 0.05958310315119369, 0.09303853008896112, 0.007980753318406641, 0.01533538505568036, 0.04348530088152204, 0.0447704699555678, 0.015798354587916816, 0.014533148014119692, 0.05038677215842264, 0.03017335305256503, 0.027378543645941784, 0.047166926719780476, 0.021694257323231016, 0.01965485925653151, 0.0657550101833684, 0.03565466071345976, 0.00839447308265205, 0.04258271699239101, 0.03343057559270944, 0.05954040972782033, 0.08318484454814877, 0.026121267450175116, 0.05979878229222127, 0.044837831519544125, 0.02103853295557201, 0.054186405414449315, 0.04577713433120932, 0.03550909798858421, 0.016891201392614415, 0.07678012536572558, 0.04045157081314495, 0.044745883239167075, 0.031417457187282186, 0.05534217107508864, 0.026273201618875777, 0.017757551511749625, 0.02056861013573195, 0.05328450006033693, 0.06497085440371718, 0.0290502249263227, 0.0374405648825424, 0.021897073136642575, 0.04552221890272839, 0.017477864466075386, 0.024502313429755822, 0.03428540757990309, 0.046975566273821254, 0.09644552905644689, 0.0584034225238221, 0.02051915511089776, 0.14218997157045773, 0.0904399241719927, 0.14399859309196472, 0.14906597403543337, 0.11284689432276146, 0.2531429593052183, 0.07796896621584892, 0.10937565844506025, 0.08432552298264843, 0.16010649874806404, 0.13332826351480825, 0.15250138326414994, 0.13183341015662464, 0.13477791287004948, 0.1731658008481775, 0.202907673482384, 0.09100432960050446, 0.183555379776018, 0.1341201274522713, 0.0923225942200848, 0.10340343069817338, 0.09634619831506695, 0.13719486817717552, 0.15025144256651402, 0.2108973419027669, 0.09090729909283773, 0.1317564235734088, 0.14455200625317438, 0.15833848076207296, 0.09033625080649342, 0.12919734232127666, 0.22660693393221923, 0.1414816217230899, 0.21227324807218143, 0.2826567898903574, 0.1717556829431227, 0.1886501328221389, 0.25331357015030725, 0.19767719986183302, 0.10249255850378956, 0.24690453548516544, 0.12560616859367915, 0.055962372438183854, 0.127207931929401, 0.09186874250216143, 0.10293796924608094, 0.06756656297615596, 0.09256250384662833, 0.14787851061139787, 0.08766418668840613, 0.08947242823030267, 0.16667969817561762, 0.06772451914314713, 0.1109907210671476, 0.1927150868411575, 0.10946250414209706, 0.07439148532492773, 0.11018504215670483, 0.1093285952561668, 0.14490359595843724, 0.15286847070923873, 0.17085950103189262, 0.26544281787105967, 0.14467653099979672, 0.18773909099400043, 0.1910164151340723, 0.16143334683563026, 0.12663728397871765, 0.10469029950244085, 0.12015090989215033, 0.21135327672319754, 0.13919650577008724, 0.09472174476832151, 0.08313252271286078, 0.17229563396956238, 0.08547861860798937, 0.12158887487437044, 0.15509174498064177, 0.11802790952580315, 0.11402335869414465, 0.1598498768040112, 0.18503474896507605, 0.20881425296621664, 0.13429627514311246, 0.13670063684029238, 0.09740739315748215, 0.1442428385572774, 0.15385710980210984, 0.11317115263747317, 0.16331724503210612, 0.10237464268824883, 0.18793554045259953, 0.0979943870167647, 0.10387204055275236, 0.18542292527854443, 0.12946548578994616, 0.06573499340031828, 0.1492697381015335, 0.0903430361566799, 0.12321178136127335, 0.1165743110967534, 0.15016684282038892, 0.12110506583537374, 0.11832422576844692, 0.08276962861418724, 0.18226244486868382, 0.12711402268282004, 0.18103037455252238, 0.10984597142253603, 0.09782899410596915, 0.13144816511443683, 0.151742781113301, 0.11567232092576367, 0.05883180203714541, 0.09159480434443269, 0.1598224097064563, 0.11136770833815847, 0.10346922823893172, 0.13637871268604482, 0.08223275813673224, 0.10987402884555714, 0.08720276930502482, 0.1649627603058304, 0.11503532582095691, 0.0576706589864833, 0.1523992908852441, 0.13841800897249154, 0.24798598459788732, 0.16666493325361184, 0.10027085843362979, 0.10242689667003495, 0.13954164939267294, 0.10368203717683043, 0.07630918813603264, 0.13132396606462343, 0.07178252496357475, 0.09579177413667951, 0.19109014474919864, 0.13413415955645697, 0.10837501606770925, 0.17694691009819508, 0.10662873834371567, 0.14918053788798197, 0.1621786497001137, 0.1341302376240492, 0.15645319835415908, 0.18019104030515465, 0.07743217716259615, 0.0860456974644746, 0.11779093795589038, 0.12639356777071953, 0.08401998544910125, 0.06793753164155142, 0.11414126093898501, 0.0882135218541537, 0.20858566808913434, 0.197162924600499, 0.1315108753208603, 0.16308066701250418, 0.17249890949044908, 0.0711233281929578, 0.09414992973740612, 0.1151474876595395, 0.09792602461363588, 0.10341740851955754, 0.08041469819311585, 0.13518054197941506, 0.10546695068478584, 0.09446500747331552, 0.1212275278355394, 0.11028251371213368, 0.1172053079519953, 0.10350704978087119, 0.16294932977429458, 0.176332863047719, 0.10510637039052588], [0.017443727369287183, 0.021789362487782325, 0.06806681970400469, 0.007140458943987531, 0.016269485200090066, 0.014151956370499517, 0.019442774654765214, 0.0482274532052023, 0.05685877148061991, 0.0207415347852345, 0.0195459492970258, 0.019959904852190187, 0.021612928115895817, 0.018799211330977932, 0.09607747809163161, 0.019745679472440054, 0.09141566431415932, 0.010742152508880411, 0.05037076551733272, 0.003257133482423212, 0.010146371621106352, 0.05397117749920913, 0.01791548901902778, 0.0756299610116652, 0.014629215002059937, 0.04324722669220396, 0.03217810172853725, 0.012395057028957775, 0.04736338296372976, 0.01753171130881778, 0.02628209042762007, 0.039055186456867626, 0.03270759653033955, 0.05880696087011269, 0.020608078821429184, 0.06051448745919125, 0.12868694828024932, 0.043696572937603505, 0.04195971667234387, 0.015784259719241942, 0.030995822312044244, 0.013845090604653316, 0.02104938612319529, 0.04805770070691194, 0.08557922499520437, 0.013491485650385064, 0.03503454416724188, 0.054930028904761584, 0.03021452316482152, 0.049004236701875925, 0.017579887295141816, 0.0559520044230989, 0.06024531261729343, 0.040457168727048805, 0.09925844347370522, 0.040521276715610705, 0.019537048613918678, 0.024157386938376085, 0.04132385132834315, 0.0241561248632414, 0.02982948168313929, 0.0544201607283737, 0.010813965262579066, 0.047672313172370195, 0.03025394944208009, 0.06843181047588587, 0.02249492016354842, 0.039353707938322, 0.03666400530242494, 0.02898824753771935, 0.05464334446670754, 0.049347802730543275, 0.06885517561542136, 0.035576975239174705, 0.04676992945106966, 0.07942563162318297, 0.03979648257206593, 0.0652896301554782, 0.03970486677384802, 0.026459905618269528, 0.03370983007230929, 0.014180453144945204, 0.02704016162481691, 0.007173966699545937, 0.0029915512714069337, 0.012439238988528294, 0.026661362665306245, 0.08016434591263533, 0.045035475199776034, 0.05866077050034489, 0.05742393686835255, 0.0194095976850284, 0.04003653469096337, 0.06519920179354292, 0.026279048894398978, 0.08866333628871612, 0.015095707827380725, 0.04683590680360794, 0.013433570990205874, 0.02091257819639785, 0.046272383470620425, 0.011703744347739433, 0.032097759789654186, 0.0317820238747767, 0.023293186078912446, 0.01782584097236395, 0.04001596490187304, 0.010598073231189378, 0.037705488702548404, 0.02452523434268577, 0.07767067543630089, 0.032297065880681784, 0.03159359470009804, 0.04265911325014063, 0.03434103727340698, 0.030737402250191996, 0.010516519259129251, 0.045095101464539766, 0.0079488452091547, 0.022984678258321116, 0.0057014901540242136, 0.09353154684816088, 0.04028340608679822, 0.03203872724303177, 0.07528062404266425, 0.01818636868015996, 0.03414587024599314, 0.06271590611764363, 0.012186870610873615, 0.031199813687375615, 0.02091154343049441, 0.027030139662591473, 0.01257894086718027, 0.012624413739623768, 0.039195904441710026, 0.07368418720683881, 0.1346355697938374, 0.02499911471802209, 0.046341434586793184, 0.04167155981329935, 0.013900383575154203, 0.07408970009003367, 0.02500609684336398, 0.006786399371256786, 0.027223179482721856, 0.08898051748318331, 0.021311736599143063, 0.020731784237016524, 0.03818356412063752, 0.03194898759414043, 0.01066409977751651, 0.03534591710194945, 0.05930166718150888, 0.06248951969402177, 0.02952083306653159, 0.011882870807312429, 0.024439783035112277, 0.009373203867913356, 0.02620156867695706, 0.036973441019654274, 0.014603023550340107, 0.04167471160846097, 0.014582901594362088, 0.03852159669622779, 0.0244027214523937, 0.03859335516712495, 0.04984456500304597, 0.027026970904054384, 0.05274858970993331, 0.033101496286690235, 0.051388442516326904, 0.028703829406627586, 0.06546898731695754, 0.03499596945143171, 0.01748899244038122, 0.04943916068545409, 0.027472693772454346, 0.028127966914325953, 0.036512359511107206, 0.014615922501044614, 0.02291145924079631, 0.009007356445571142, 0.035168778749981096, 0.04135370347648859, 0.04080264483179365, 0.014394964357571942, 0.04537679188485656, 0.05557097986872707, 0.026580194610037973, 0.05698019532220704, 0.07121503220072814, 0.039140101721776385, 0.04630189974393163, 0.005742906235224966, 0.03456419047766498, 0.04027569792898638, 0.010553401030067886, 0.010966372709455234, 0.027601369457053285, 0.08917858185512678, 0.029583468634103025, 0.016055098668273007, 0.06092914699443749, 0.03727025259286165, 0.030734287774456397, 0.05027392499947122, 0.047514122910797596, 0.055839313327201774, 0.02937720755913428, 0.050016577022948434, 0.08017827623656817, 0.03224735301254051, 0.0686082092246839, 0.03578612008797271, 0.023649771498250108, 0.042569047904440334, 0.03416590399241873, 0.030919968882309537, 0.021953688402261053, 0.06356731828834329, 0.019767282331096273, 0.032994226685592105, 0.004332857455925218, 0.036759933190686364, 0.038310344996196885, 0.06323842557945422, 0.03323146627683725, 0.006320490934220808, 0.025559053689773594, 0.017031956696882844, 0.0649761673329132, 0.05109319157366242, 0.0534654958838863, 0.022659973806834648, 0.061922739392944744, 0.028338596058477248, 0.04833919095939823, 0.010557340774019914, 0.046621075831353664, 0.027637457342020104, 0.04151146965367453, 0.01175010864556368, 0.017387911078653166, 0.03573209173711283, 0.04554577763857586, 0.022248545794614723, 0.026718010161338106, 0.016679886928094283, 0.017192073997908404, 0.05808782231594835, 0.01340204370873315, 0.07171786736164774, 0.06982127377497298, 0.044205592945218086, 0.01378519122954458, 0.03683703173218029, 0.0767342292570642, 0.020977266332400695, 0.07332964587424483, 0.03740551854882922, 0.013695421046577394, 0.019658319785126617, 0.08471952791192702, 0.029120599185781817, 0.016344699110569696, 0.055993350954460244, 0.07222053288881268, 0.047504711630088944, 0.04892982855173094, 0.025418817464794432, 0.02872636016192181, 0.055445033591240644, 0.024938647069835236, 0.03175802409116711, 0.026035269921911613, 0.006939558719750494, 0.016251817844542008, 0.0752910463405507, 0.06083170936575957, 0.03762055986693927, 0.056508898468954225, 0.014122559688985348, 0.054822949293468676, 0.02758641624157982, 0.0305618380994669, 0.012982871915612901, 0.06051083694079092, 0.028514002449810505, 0.05177045773182597, 0.04153852963021823, 0.04034057944746954, 0.017605910809444528, 0.0089898061373138, 0.04337036383471318, 0.06144733061747892, 0.031114121499870504, 0.013118815558430339, 0.12289304632161345, 0.011046715496507074, 0.03711953300184437, 0.037036860295172246, 0.027561062780608023, 0.039500217219548564, 0.032464111024247747, 0.031026271571006094, 0.020766204622175013, 0.04344350651704839, 0.016495912335813046, 0.019298526591488292, 0.050440620697502575, 0.049842729565820525, 0.007200763743769909, 0.07158739186291184, 0.01534055040350982, 0.13723761588335037, 0.06409603277487413, 0.018150650596778308, 0.029800626981471266, 0.05060062604025006, 0.03226116120017, 0.06071160188210862, 0.021275284001603723, 0.037944160002682886, 0.02673717199026474, 0.002940070183415498, 0.06301690425191607, 0.045989844881530316, 0.013834601301433784, 0.01849159917661122, 0.06364174679453884, 0.056823168748191426, 0.01123377911946071, 0.0629557886027864, 0.01836671480642898, 0.03048499400860497, 0.03382417679365192, 0.028026352902608256, 0.05965268013200589, 0.05776553175279072, 0.03920524108356663, 0.026145630250019685, 0.06701208451496703, 0.04256090209154146, 0.045370861488793574, 0.010536733665503561, 0.057762736188513894, 0.05441051196040852, 0.027564195916056633, 0.025073382072150707, 0.06220566813967057, 0.028448690061590502, 0.03604424159441676, 0.10041216335126332, 0.12500562439007418, 0.14351733534463815, 0.0909224304237536, 0.14814406207629613, 0.13267220157597745, 0.0958552375169737, 0.16686367616057396, 0.13067928994340555, 0.07306534969913107, 0.10080503512706075, 0.17559615043657167, 0.12061884121171065, 0.07882731979978935, 0.19245040390108312, 0.09256463444658689, 0.2848703882523945, 0.10908462799021176, 0.13120200618037156, 0.12116857671311923, 0.07785544730722904, 0.10384266677179507, 0.1089824948992048, 0.25452345237135887, 0.07530416242246117, 0.09055465765829597, 0.13679351471364498, 0.11100364037390266, 0.110785884915718, 0.20363910709108624, 0.1482696181961468, 0.17350167568240846, 0.09651091269084386, 0.11287665486867939, 0.15958769087280544, 0.14113490389926092, 0.1684494260698557, 0.07487582362123898, 0.06524912840021507, 0.08535605482757092, 0.16112420628113405, 0.1855048244552953, 0.0858841993446861, 0.17303066381386348, 0.14820869932217257, 0.0945400670170784, 0.2079863181071622, 0.11465396199907575, 0.16488683223724365, 0.14684223836021765, 0.08216085378080606, 0.11409180930682591, 0.19226026481815747, 0.09345138472105775, 0.21556355937251023, 0.14003569073975086, 0.14338982504393372, 0.1195150547261749, 0.19085667441998208, 0.11103232883449111, 0.1099921278655529, 0.14150908882064478, 0.20112992530422552, 0.137654982773321, 0.07444804800408227, 0.097785798566682, 0.11124947361115899, 0.08593272816921983, 0.09510471671819687, 0.07430192548781633, 0.20326694420405797, 0.17235279375953333, 0.14821765598441872, 0.1447310173617942, 0.14396378424550804, 0.1446802629423993, 0.2175433345671211, 0.20554189570248127, 0.08415873907506466, 0.0858587949935879, 0.15591316590351717, 0.05254218614261065, 0.18087395866002354, 0.1213983693825347, 0.14480203283684595, 0.12494260205754212, 0.17315312581402914, 0.12800708333296434, 0.10921600594052247, 0.1454164327255317, 0.18717410202537263, 0.12957352213561535, 0.10687440873256751, 0.09085915024791445, 0.073331762903503, 0.17905785968261106, 0.07907529042235442, 0.093276960509164, 0.1059016270030822, 0.07697948573955468, 0.0892907844058105, 0.11422396078705788, 0.0948888272313135, 0.1354128723698003, 0.0528505599525358, 0.10845068629298892, 0.1355349136782544, 0.12918895562844618, 0.13804123204733643, 0.12418566910283906, 0.2702313209218638, 0.17038858415825026, 0.12667505123785563, 0.12303080250109945, 0.1259587218186685, 0.095305461303464, 0.11033301707357168, 0.1087580355150359, 0.15629592750753674, 0.1771192851343325, 0.14176003821194172, 0.2348278606576579, 0.07849346021456377, 0.11494221724569798, 0.14262436968939646, 0.18435629537062986, 0.16086169465311936, 0.14545287005603313, 0.17963530655418122, 0.11287134872483355, 0.11537451190607888, 0.0890842926289354, 0.06589878496846982, 0.12412529305687972, 0.15251310834927218, 0.18778481068355696, 0.19340821036270686, 0.13170336213495049, 0.2532208822667599, 0.14377672571156705, 0.12476289884320327, 0.14950673681284699, 0.11463185532816819, 0.09624973777681589, 0.08698263897427491, 0.1668531181556838, 0.1546966340392828, 0.13386427903813974, 0.10628603066184691, 0.15523961133190564, 0.1049970176869205, 0.09315899719617196, 0.1889352939490761, 0.1839708196265357, 0.19396444622959408, 0.07165745060358729, 0.10524980590811797, 0.08894742533032383, 0.11531915701925755, 0.08697976198579584, 0.12248141983790056, 0.1277186923793384, 0.14440065223191464, 0.13006119882421835, 0.1194095289600747, 0.13949145137199334, 0.17150850620652947, 0.15404875523277692, 0.11273682237203632, 0.15433482559663908, 0.14739964130733693, 0.1503864438938243, 0.144301477553589, 0.12847453967801162, 0.07077374016599995, 0.12478634901344776], [0.04059109118367944, 0.06160960226718869, 0.020377765376386896, 0.028565109707415104, 0.046724080839859586, 0.03485926839389971, 0.05717783900243895, 0.047336343343236616, 0.040680857973971536, 0.03067395244059818, 0.04496109758370689, 0.025394385115110447, 0.014391139116404312, 0.040408992740724764, 0.080746467890484, 0.026163546967187097, 0.03999808889680675, 0.026467930991202593, 0.032945026111389906, 0.014397266287622707, 0.04613053233229688, 0.04090660996735096, 0.053259801385658126, 0.045538676769605706, 0.06065753621182271, 0.0483631025334554, 0.03472036549023219, 0.04179605741852096, 0.01620244254757251, 0.02916023920157126, 0.027486802211829593, 0.05545297245095883, 0.035641653197152276, 0.055570392935935936, 0.018201942755175487, 0.006868491506403578, 0.05116210359015635, 0.045197577215731144, 0.02386456515107836, 0.006678923241062356, 0.014783887059560843, 0.027247180962668996, 0.050072959890323024, 0.04613877653277346, 0.004018123228369015, 0.025160606052460413, 0.04605190030166081, 0.07853696109460932, 0.015465053097744073, 0.020893424849158952, 0.045605685495372326, 0.01678769426819469, 0.02025744754688016, 0.02162311801553837, 0.023828697789992605, 0.017870273141722594, 0.09373051367167916, 0.024152888251202445, 0.05972510017454624, 0.008314316892730338, 0.031325491943529675, 0.023476935058299984, 0.01270494397197451, 0.06371774950197764, 0.01844680738369269, 0.038649995877806625, 0.04103468684479594, 0.06307108527315514, 0.07152143147374902, 0.03815461103139179, 0.06867400676544223, 0.08081744265343462, 0.06871053230549608, 0.05425939881908042, 0.05543969352064388, 0.01661571447870561, 0.10231644473969936, 0.01541127750117864, 0.023266808030062487, 0.012419525001730238, 0.06632864368813378, 0.015921057468014102, 0.060548834901835234, 0.07612589547144515, 0.05338749489081757, 0.039425890493605814, 0.030379600556833402, 0.03881914108725531, 0.022564732935279608, 0.014140239767065006, 0.028293861941035305, 0.015003108153385776, 0.00744071153790823, 0.06528917553701571, 0.024792387150228024, 0.02630291466734239, 0.032179509688700945, 0.013924601338138538, 0.022639280185103416, 0.012576962089432138, 0.03622142744383641, 0.014891816535964608, 0.02014806430919894, 0.014384384300293667, 0.06590865765299116, 0.04332068828599794, 0.026515808422118425, 0.011116900614329746, 0.07171175376112972, 0.011880297463254204, 0.010545309499970503, 0.05137297870325191, 0.08372906355985574, 0.016317033541521857, 0.0369781466600086, 0.055697899843965254, 0.07088308608425514, 0.03990642899381263, 0.014875816680224878, 0.008575927765507783, 0.012393949320539832, 0.06320417313171284, 0.070563869284732, 0.03472284892840045, 0.052176649150039466, 0.022291402066392556, 0.009657484595663846, 0.05740278693182128, 0.028242574871650765, 0.06954437720456294, 0.02531025864716087, 0.04058534738474658, 0.013776863908528217, 0.0062543855081977585, 0.043965405119316917, 0.03671454259061387, 0.03322038579998272, 0.013276418887211807, 0.017011607431673577, 0.04728174502296107, 0.06523750509534564, 0.03824825904199055, 0.04444101066993816, 0.020255076066989983, 0.05496122794491904, 0.041091154529047866, 0.09593060918684516, 0.0702625522390008, 0.029489423680518354, 0.036620952255491696, 0.05125875072553754, 0.0207440199197403, 0.008637814400052386, 0.03930158627086452, 0.04062159133276769, 0.08001292403787374, 0.05808189870523555, 0.03467517166531511, 0.0525219284796289, 0.027512203170252696, 0.016888088613216366, 0.008868325468418854, 0.014809942804276943, 0.021313504182866642, 0.07226125856063195, 0.04952688169266496, 0.015546853886917233, 0.0476266749070159, 0.04132744756394199, 0.038651118853262494, 0.03038646054587194, 0.01807741800855313, 0.01950135258292513, 0.026801549696496556, 0.07419878137963158, 0.0021248039972436216, 0.07109109777957201, 0.07827835782830204, 0.03633946878835559, 0.018196171814841882, 0.04286005461056318, 0.04418363894468971, 0.09091848134994507, 0.10326179329838071, 0.04986290241192494, 0.02248263528703579, 0.05174776752080236, 0.06314007192850113, 0.04985237154843552, 0.04465400281229189, 0.0350399045938892, 0.04126012671206679, 0.022420761375022785, 0.02260003880863743, 0.03429162296067391, 0.016642355459875295, 0.018774975756449357, 0.018036665195333104, 0.00882840046792158, 0.06331210091177907, 0.07468075837407794, 0.03634379105642438, 0.06087388710251876, 0.0264909706477608, 0.03275730261313064, 0.03271082296435322, 0.021128896856680512, 0.021743312012404203, 0.03938064917123743, 0.06534870341420174, 0.06893297644065959, 0.049663005995431116, 0.045719984719263654, 0.040830237458326986, 0.03377935955567019, 0.0415791603071349, 0.042679126640515666, 0.023545236393277134, 0.052605554528002224, 0.05913157880838428, 0.0024268617063561188, 0.015171132083716137, 0.05963375579033579, 0.020035485171579888, 0.02909800736233592, 0.07019024076206343, 0.05149676384670394, 0.02145947402875338, 0.055478763567017655, 0.04397616329203759, 0.03828097800058978, 0.017235810668872933, 0.0464698473390724, 0.0260030717389392, 0.028238603745454123, 0.019128477234127264, 0.0241635802667588, 0.024546762562489936, 0.011039001401513815, 0.05467894719913602, 0.06730253142969948, 0.07865748248462166, 0.0600821656574096, 0.037602375128439496, 0.02593943363587771, 0.033734969794750214, 0.026833532444600548, 0.023150466415765028, 0.02850282358537827, 0.032749010915202756, 0.008987293861407255, 0.06926870199718646, 0.031162110889064412, 0.021823565741734843, 0.03198692787970815, 0.010071463899553885, 0.029783833239759718, 0.020868280037705387, 0.06072859239897557, 0.02931426325812936, 0.06391042630587306, 0.049373078159987926, 0.037771784966545444, 0.030899989418685436, 0.028112017948712622, 0.018097558624244163, 0.049013183186096806, 0.02623643519889031, 0.046290025381105285, 0.06951672011720282, 0.010316156349810106, 0.04248859739995428, 0.02461727931430297, 0.031621445169938464, 0.036960945797285864, 0.014679523284680076, 0.017747951937573295, 0.024582139682024717, 0.05662440209250365, 0.041791769077203104, 0.039388082522366724, 0.04076656712485211, 0.04286016996151634, 0.059838320527757914, 0.020080926661778773, 0.007370430577014173, 0.035018201651317735, 0.037968034257314036, 0.0365584456095738, 0.006643473179013069, 0.06547727901488543, 0.0200935134863747, 0.03186499513685703, 0.11359768653554575, 0.018927154197756733, 0.05507086902590735, 0.03960186515801719, 0.06652983610651322, 0.0068726657690214256, 0.03702397830784321, 0.023802055112485374, 0.0066953276733069545, 0.020992865852479423, 0.004579875160873468, 0.027180764258706143, 0.0162172074695783, 0.011711701019001859, 0.015625626713569676, 0.014972801386777843, 0.022328875859134963, 0.02689681601311479, 0.02099875553644129, 0.036506748026502986, 0.0439145082075681, 0.04163301902424012, 0.06582787127367087, 0.030019824326570545, 0.06907550950667687, 0.03201490727120212, 0.02150629464137767, 0.0815844586385148, 0.03333048489210861, 0.04358742040182863, 0.020231651341808692, 0.025406515624906336, 0.024619645705180507, 0.04556786395343287, 0.029236489574291875, 0.027568989765963385, 0.016702885872551372, 0.0402770957111248, 0.03336832679009863, 0.0306972872598895, 0.029220272587346177, 0.05443326663225889, 0.034245502935456376, 0.0030743200331926346, 0.022461671947634647, 0.033193105299557955, 0.02492200769484043, 0.08935331140777894, 0.06344858823078019, 0.03969135035627654, 0.038827042627547464, 0.1023988596030644, 0.0344043344126216, 0.04682082297014339, 0.012965044256166687, 0.04218536688547049, 0.026696605774174844, 0.00833399610460869, 0.04799332130434258, 0.17152392252215318, 0.09646634651081902, 0.15396389764334473, 0.08557085187307426, 0.08281903274889503, 0.14445732347667217, 0.09737346640654973, 0.169327314676983, 0.08187774861497538, 0.09124411709074463, 0.0901433772274426, 0.07523247519774096, 0.11280367842742375, 0.12165324070623942, 0.2276708497000592, 0.20702636747487954, 0.10670440856899534, 0.13496182300150394, 0.1661049790148224, 0.09963336121290922, 0.1255718075803348, 0.11162231503320591, 0.12131610379687377, 0.2082524395414761, 0.18278620604957851, 0.17117721826902457, 0.15267569891044072, 0.10735441797545978, 0.08649973238685302, 0.1167631202510425, 0.1841085758060217, 0.17212011053093842, 0.12205249071121216, 0.14673906032528194, 0.15334257669746876, 0.08877082302102021, 0.16004232290600026, 0.12577117473951407, 0.1262904168771846, 0.09664094035646745, 0.13604795400585445, 0.10145815900926079, 0.12560459439243588, 0.09745049370186669, 0.06697015105081455, 0.1063410598518593, 0.0955613504296967, 0.13155708355563028, 0.1152188288314002, 0.09591449398015227, 0.08831007738730737, 0.10324166116437741, 0.21628073017512048, 0.08176295406052045, 0.15847311568047318, 0.1558784656226635, 0.1810708695224353, 0.10621015687606164, 0.16411830990442208, 0.051903630407260995, 0.0799417117876666, 0.11636703221925668, 0.14895848051777907, 0.0990739090900336, 0.12429014992501054, 0.10664583064083542, 0.09471656754612923, 0.20248900380517754, 0.1572104977177722, 0.1452136186084577, 0.10685748606920242, 0.09167875269693987, 0.19681373690920217, 0.13536460138857365, 0.16445723814623697, 0.28104545921087265, 0.12987559235521726, 0.11842987367085048, 0.10872499764497791, 0.07613886227565152, 0.09863213529544217, 0.08506758244974272, 0.19004711428923265, 0.14696353328015122, 0.08753008102732045, 0.1520496825022357, 0.10111851152032614, 0.08620447465883833, 0.1253569291106292, 0.1034446449152061, 0.15264295281044074, 0.15318394878080913, 0.11184454203716346, 0.13221249410084315, 0.08269041643611022, 0.11923571542969771, 0.11542384140193462, 0.1468075109379632, 0.16621384317321436, 0.07644927169063262, 0.15107960812747478, 0.07871432336313383, 0.06776111932205302, 0.06943517377866165, 0.1359053530863353, 0.09663986827113799, 0.11162196219499622, 0.10597193001636437, 0.2319284262401717, 0.06740987566964966, 0.14881121127733163, 0.08718352605189596, 0.14271059791956628, 0.15431472738938673, 0.10962368335042681, 0.13845942675002984, 0.1625845900603703, 0.17186506278812885, 0.08712262753397226, 0.09810017741152219, 0.13269911227481707, 0.17444744493280137, 0.16442906537226268, 0.10665975417941809, 0.16244677959808282, 0.17991030322653906, 0.13147233453180107, 0.13317495531269483, 0.13109014289719717, 0.12472308240830898, 0.1574549331728901, 0.11467407377702848, 0.12361226629998003, 0.08804694150707551, 0.11378786633057253, 0.11073329845177275, 0.08654842405979123, 0.17779811870838913, 0.10746336355805397, 0.11341932682054383, 0.11097511476171867, 0.2454470151237079, 0.09977139559175287, 0.10903104407978909, 0.15879604406654835, 0.0888641012300338, 0.10384728759527206, 0.1023556844198278, 0.13163108458476408, 0.13230056794626371, 0.13649506787104265, 0.10667311453393527, 0.1098517118287938, 0.08479372571621623, 0.15284139716199466, 0.17654669657349586, 0.10395860805043153, 0.11012306476810149, 0.1497342631753002, 0.17422132992318698, 0.13178607555372374, 0.07095002356384482, 0.07256065535226039, 0.10127974501145737, 0.21990991543446267, 0.11296542081981897, 0.07679957217936005, 0.14766697053398403, 0.08360191288271121, 0.092575918483947, 0.12900066216077122, 0.13502470962703228, 0.09852145944855042, 0.14150607612516197, 0.11373850290796586, 0.15859712474048138], [0.006306882490337427, 0.056598078326455185, 0.0351949328822749, 0.060445066541433334, 0.047518384110714705, 0.08252447391194956, 0.03889288766575711, 0.006473369962934936, 0.03615854081830808, 0.03599554652880345, 0.03815096729834165, 0.014455364152256931, 0.011464619277311223, 0.0840698034901704, 0.02298185894531863, 0.021345576836860607, 0.05364275976483311, 0.011725210651223148, 0.025282915382246886, 0.039261060766875744, 0.05373752396553755, 0.05074044496619275, 0.028090552493397678, 0.019614902025620853, 0.05595714432586517, 0.010873700941114553, 0.02937998276736055, 0.07440369216991322, 0.020878787152469158, 0.025880499476833, 0.054962300030248504, 0.02173290498155568, 0.021668113368962492, 0.04496767598071268, 0.009785766729951968, 0.0962336632822241, 0.0638424235263041, 0.020696564876873578, 0.017388755854751383, 0.009455355798958667, 0.011035789386369288, 0.021639670877318298, 0.03612784728673952, 0.01682981602581484, 0.005819244393413621, 0.06100643891841173, 0.0819223215803504, 0.08319611501480852, 0.048965248079704385, 0.00682205893099308, 0.024261313058169823, 0.026817810788218464, 0.05811356593455587, 0.017122307027290975, 0.056687370142234225, 0.02703536777491016, 0.015599263931757637, 0.07302705318267856, 0.009892394267288702, 0.03870818025565573, 0.036146734308983595, 0.028453665419614742, 0.04099973550598536, 0.014951273166973676, 0.09281981789640018, 0.027218224480748177, 0.037371910709355555, 0.10173350173447814, 0.03773623312424336, 0.0713052162900567, 0.01234949255428676, 0.022916441384170736, 0.019847251075719084, 0.06522107097719397, 0.04707535502633878, 0.06749456362532717, 0.02671282445745809, 0.05825835173683507, 0.03772766322695783, 0.022348690778017044, 0.04255978590143578, 0.017947466678119132, 0.014591223826365811, 0.17501119896769524, 0.009447477159223385, 0.045589784027210305, 0.016958101552778056, 0.08800686044352395, 0.01567936159803399, 0.03679904055648616, 0.05511764383741787, 0.004716734825966081, 0.04946333349549344, 0.03398675378412008, 0.03933364365782056, 0.019288820148046528, 0.052907757061932764, 0.017134194960817695, 0.0361860927327403, 0.054022098159683604, 0.060564685479870865, 0.023819478195426718, 0.01999129048947777, 0.052613004842506986, 0.03234282288966434, 0.03463766224948423, 0.06886594396616731, 0.013319179315918257, 0.034701312226908546, 0.017932781483978033, 0.017504798913640634, 0.019187521655112505, 0.01338308204763702, 0.021629596328628913, 0.048336843228233714, 0.08428734860249928, 0.06604701772864376, 0.03799863957933017, 0.022167532106063197, 0.0643035423542772, 0.06302936215485845, 0.02712088863232306, 0.04454856186306902, 0.07822341684784208, 0.032138108874538114, 0.04643006143825395, 0.03646636840754321, 0.04694339353591204, 0.05580711344789181, 0.01876964247120278, 0.03984173746513469, 0.021514699993921176, 0.042370749437915425, 0.021044702535229068, 0.06306482239493302, 0.06337034635777984, 0.04200454408835087, 0.003979777094043259, 0.017764594705243195, 0.013968828250654042, 0.01083718303457967, 0.027760399405711463, 0.027735827956348658, 0.01701949200859027, 0.007550520556313651, 0.018568251581330384, 0.0370980811172298, 0.02892281301319599, 0.028992939607373307, 0.04111641638779214, 0.0627769132011703, 0.022993463590475063, 0.02651100609052394, 0.06539679119097334, 0.038307030352630785, 0.02201013233778732, 0.012324505502225032, 0.016803728050685356, 0.05167357310918825, 0.020853109691025953, 0.0339416617394558, 0.024625231744721532, 0.028713264436061894, 0.06635507941246033, 0.03586527459057314, 0.06944836449942418, 0.043771910680724044, 0.02332561326745365, 0.03193631595266717, 0.03937502072325774, 0.025601418023662906, 0.06263600183384758, 0.016464748918744068, 0.0253829619780715, 0.020814424713275263, 0.0039906239004007405, 0.015388935039352094, 0.0019928427188590702, 0.047040576713957956, 0.0038827618534144548, 0.060958683623799255, 0.032554315469626866, 0.06413177799965654, 0.026670327809240137, 0.03562864228816969, 0.07018990827990429, 0.0036483979783952236, 0.03197783551045826, 0.08044018396841628, 0.015537992219573684, 0.06693504364894969, 0.007758393151951688, 0.03600115801340767, 0.035190888813563755, 0.029906620936734334, 0.019295921017016684, 0.0487764796375164, 0.0695233561896852, 0.03223348714943443, 0.05559489144278424, 0.030444149593157426, 0.018636030444343175, 0.0401939582079649, 0.06119370101285832, 0.042723139814500294, 0.04659360194844859, 0.034433569093900065, 0.029444606442536627, 0.03727338742464781, 0.03608884509386761, 0.0578605266554015, 0.060656219853886535, 0.048494453342365365, 0.014695022720843554, 0.05204110160203917, 0.061843031884304116, 0.05477419655237879, 0.033715906353401284, 0.04766945993261678, 0.037389718860919983, 0.055145412883056064, 0.01640267314256302, 0.02749462063158197, 0.09777620408151831, 0.032939149998128414, 0.04985029183860336, 0.023871562543458173, 0.041343159042298794, 0.04730621638840862, 0.043719582060085874, 0.02287176833488047, 0.014900215103157928, 0.016249943391552994, 0.1063894529693893, 0.04722822218069008, 0.03230325751272695, 0.045002776597227366, 0.0076218769952122655, 0.045569299054997306, 0.05938558839261532, 0.039405727825526676, 0.04363858194223472, 0.009794793790206313, 0.08153430811528649, 0.07880900613963604, 0.03576910921505519, 0.027317085336627703, 0.02532312536745199, 0.0400171930502568, 0.03365751502237149, 0.022831371752545238, 0.052618728285389285, 0.011997726429919047, 0.013686868960836103, 0.012115803397526699, 0.035355945849525075, 0.020995902296687876, 0.023050368929814016, 0.044033065238701444, 0.02273296721146575, 0.027787070920956985, 0.010175613935903778, 0.020230073747890334, 0.03380000398361257, 0.041071056321795495, 0.031615097474839, 0.049166864582470486, 0.03266890985625131, 0.0622063602453896, 0.08016718218901328, 0.020094158094642416, 0.021562969278810278, 0.0322466032313449, 0.055325509647705724, 0.09316001499869994, 0.04551449038886598, 0.04681776277720928, 0.019882774080282876, 0.019878153256805878, 0.015359203331172466, 0.025656637203480517, 0.0351162635322128, 0.08028382235871893, 0.02084695707474436, 0.03553309777219381, 0.05053655197843909, 0.1028989806239094, 0.0876765020989946, 0.061043968690293174, 0.037294540753854175, 0.03747442377997296, 0.03527535285268511, 0.05372335954702326, 0.024303287234423415, 0.01898229364970965, 0.03757027363670724, 0.03318316476153476, 0.022320913250691125, 0.09559195235903774, 0.05211838674066322, 0.002144183381460607, 0.040862790175846646, 0.016774836029591303, 0.041285388570811064, 0.003431755953767736, 0.016812342052747096, 0.02702514734119177, 0.024616887460329702, 0.008666508797822254, 0.006993452635859805, 0.07954417169094086, 0.044300811764385016, 0.011009747212353562, 0.040068517439067364, 0.027802874001541307, 0.005994059187027493, 0.03252263806228127, 0.034167101606726646, 0.031142199278942177, 0.029715457265930514, 0.04412897955626249, 0.03461965053741421, 0.007899262959004512, 0.05022422909470541, 0.040195277958576164, 0.02942548193303602, 0.04891696013510227, 0.04127070846568261, 0.05282336426898837, 0.024863684217312505, 0.05523228232881852, 0.06137556196855647, 0.02234940493612417, 0.07221733020352465, 0.01242810592520982, 0.014862821038280214, 0.014630144595035484, 0.033972524904779026, 0.020604743821812526, 0.09078018234244414, 0.07815464053835187, 0.029711514977472167, 0.061911177156226974, 0.07636360664452825, 0.01586891374816852, 0.05687235914436834, 0.01894395811749356, 0.07159110344946384, 0.019447308965027332, 0.038949504627713134, 0.05316907786098974, 0.02724732515136046, 0.12717040894286974, 0.1382076224046094, 0.12028236926666327, 0.18823869632823126, 0.14485238013522966, 0.15704660436936788, 0.17509754933416843, 0.09806762808667761, 0.20824728267533438, 0.1806846745312214, 0.1850593119327511, 0.10209242640329258, 0.12229995243251324, 0.1949340592005423, 0.1763909999281168, 0.13397744510854992, 0.14790197435234273, 0.10189385991543531, 0.11468222976795264, 0.14880609512329102, 0.11823745471026216, 0.144972792959639, 0.17792675537722452, 0.19007207080721855, 0.10548581395830427, 0.10040603618004493, 0.07446371537766286, 0.11139882595411368, 0.13253767522318022, 0.12365799956023693, 0.10447367041238717, 0.11905994771846704, 0.17820294627121516, 0.08646115767104284, 0.1344297836933817, 0.1813192811927625, 0.14242329262197018, 0.08929467919681754, 0.1293785654540573, 0.09276473442358629, 0.11907088570296764, 0.1570675846721445, 0.10439303331077099, 0.09911432942109448, 0.13458881873105252, 0.18413320662719862, 0.1990045772067138, 0.16726129768150194, 0.06653812780444111, 0.1279378320489611, 0.13725423999130726, 0.12990044030760015, 0.1737722075943436, 0.1352134102157184, 0.15799630912286894, 0.14788510597177915, 0.12092224135994911, 0.15389092798743928, 0.23293833062052727, 0.10210774772401367, 0.10473823121615819, 0.04942400560581258, 0.08291835670492478, 0.19629942093576702, 0.21124703170997755, 0.08219149642224823, 0.11407069329704557, 0.21919157755162033, 0.17681969835289887, 0.13156743800001486, 0.10166737171156065, 0.06597478089055844, 0.09568211609231574, 0.09802038847867932, 0.127702122554183, 0.10854935207005058, 0.0755343825689384, 0.10661736609680311, 0.10508978699467011, 0.10944626001375062, 0.11984988461647715, 0.08355798452560391, 0.08803920620786292, 0.26382071205547875, 0.16023460615958485, 0.09300492224948746, 0.08762194788349525, 0.18440046800034388, 0.06420811318925448, 0.12469568316425596, 0.1182091733706849, 0.10955016408115625, 0.239342778388943, 0.1743986446942602, 0.16102912995432103, 0.09831962920725346, 0.159298553530659, 0.15651346583451542, 0.1325707605906895, 0.21206991826849325, 0.09361193967717034, 0.054399149891521247, 0.11584434312369142, 0.10294873759682689, 0.1369816589036158, 0.14478143251367978, 0.14651404454239778, 0.1378489623644522, 0.07139155987117972, 0.19156803696283273, 0.18355183782322065, 0.1347455603203603, 0.11169698781200818, 0.1490196165229593, 0.09738251127834831, 0.11049961777670042, 0.12587858683296613, 0.11180929214294467, 0.1270952679749046, 0.08831913582980633, 0.10947610198387078, 0.18206720320241793, 0.13498069984572275, 0.16450227930077485, 0.0835919248472367, 0.13264755718410015, 0.10750730548586164, 0.09657732091311898, 0.13140848438654626, 0.08832696612392153, 0.07767763042024203, 0.10724554703171764, 0.10600218589284591, 0.11150147473173481, 0.1695705559104681, 0.1559815350919962, 0.18029302411845752, 0.07967951228576046, 0.12793530789869173, 0.08428637829742261, 0.10006570337074143, 0.1256879727755274, 0.09422082307615451, 0.09790561428027493, 0.11590398635183062, 0.1250381940709693, 0.10324524382927588, 0.1289741585829428, 0.11744396228875432, 0.11830168483512742, 0.11772088600056511, 0.15556840226054192, 0.1691234420452799, 0.14059629637215817, 0.18734212086669036, 0.14629934249179705, 0.11166783794760704, 0.17902241301323685, 0.1274638074849333, 0.05889715174479144, 0.1019011948789869, 0.07911324088594743, 0.12296583955841404, 0.1693554331681558, 0.10761415439524821, 0.1268645389271634, 0.1696247844291585, 0.15792675928345748, 0.08002526658986296, 0.08585008260394845, 0.0896486777013966, 0.17383347930652754, 0.07455064928425209, 0.11235351794000183, 0.14871545641549996, 0.06576755629586321], [0.05330898838915995, 0.0996923598327807, 0.027413952995889952, 0.04845947825482913, 0.00924738311940538, 0.049683748810951195, 0.029222474433481693, 0.08751357227031674, 0.014297472446092536, 0.042419597173907926, 0.08756663370877504, 0.028506121265568903, 0.1035749711362379, 0.029161738763962473, 0.06295914056577853, 0.03150722737024937, 0.01876281471257763, 0.03009907721674868, 0.02658010131147291, 0.06917289963790349, 0.030032750418675796, 0.030241851162697588, 0.03484058832483632, 0.05011422160480704, 0.07824595099581139, 0.011932295298070779, 0.011488435008297009, 0.03434466404308166, 0.04181817426745381, 0.051118528071258745, 0.03431695267292006, 0.027214224516813244, 0.004736347880680114, 0.0037337199402307825, 0.024629250368369476, 0.03451184489365135, 0.04881674390552299, 0.01810118878659393, 0.04479964356869459, 0.03381042628149901, 0.02800382045097649, 0.02935351650895817, 0.032969833351671696, 0.060324233025312424, 0.052022329930748255, 0.01855502014846674, 0.04018769193706768, 0.022353915497660637, 0.008097733603790402, 0.027719756854431968, 0.019370471659515585, 0.017485716812578694, 0.03476932857717786, 0.03592290935505714, 0.018480289694187895, 0.04722960639212813, 0.03116872321282114, 0.061704760018203936, 0.045419844931789806, 0.04181176550420267, 0.04346473448510681, 0.05983709916472435, 0.02711535009023334, 0.03787184513307043, 0.01926249298932297, 0.03603646558310304, 0.04553451395726629, 0.06758253569049494, 0.03320273710414767, 0.025649548208873187, 0.03999298970614161, 0.0774273867053645, 0.03571463981643319, 0.04276874754577875, 0.06380293278821877, 0.016856872609683445, 0.02550429421743112, 0.009529222817426282, 0.023379180214500854, 0.021979457465931773, 0.01784983736329845, 0.0026008722239306992, 0.041632001221712144, 0.020347914924579005, 0.021088043959545236, 0.0648277106561831, 0.012832679037403847, 0.003642082089624767, 0.017711290690515722, 0.02674549591860601, 0.061141162046364377, 0.03262016050783651, 0.03761590850938644, 0.032277893873729875, 0.04413572758702295, 0.014456458289974501, 0.017980272149933234, 0.025083076641229645, 0.021466868364119103, 0.06138673744031361, 0.014681940565684011, 0.029632502967225652, 0.02619497840558844, 0.020960172338943397, 0.03988676165629711, 0.06504981552383729, 0.013347557346735681, 0.014648088453603643, 0.02121846517547965, 0.023980221445006982, 0.009833201416768134, 0.004965314009625996, 0.026546866666259508, 0.0424187049003584, 0.046811370977333615, 0.04404067500893559, 0.0627489982705031, 0.021301599285964454, 0.05706434044986963, 0.03178961328896029, 0.057430539014084, 0.02927737809451563, 0.07609411289117166, 0.06434158781277281, 0.03099906910210848, 0.037699076546622176, 0.04072466758745057, 0.060602975210973194, 0.03523003689146467, 0.057565967818456035, 0.04447994161663311, 0.014830931588741285, 0.04056130010368569, 0.03190636880961912, 0.02791119702825589, 0.0273335279364671, 0.01731849355357034, 0.11517314985394478, 0.03407352823497994, 0.053489010514957566, 0.06297213451138564, 0.059160925447940826, 0.01944612492141979, 0.04578368219413927, 0.029719623470945016, 0.06277228559234313, 0.01848706147367401, 0.017381748284346292, 0.02687015467589455, 0.006272909090122474, 0.03976694255002907, 0.037892754189670086, 0.04563045880890318, 0.018649429814623933, 0.05608492943325213, 0.014171523624099791, 0.020615076213808994, 0.032479411988918266, 0.018375210064862455, 0.027050231084493653, 0.08221386772181306, 0.01989093855289476, 0.019019485850419317, 0.018554458660738807, 0.024474749640960778, 0.04755172732153109, 0.010427137537460242, 0.03633137386558311, 0.03202823030629328, 0.036351489036210945, 0.013123226036051554, 0.0041887455237364125, 0.04101771329130445, 0.06472435620214258, 0.018998681966747557, 0.033040397600936036, 0.01246492747616555, 0.04475276019158108, 0.025901778335017816, 0.007590197891529117, 0.028559983375349214, 0.03993338379742844, 0.022903226914682558, 0.0374131554604641, 0.055615420519773445, 0.03155378505055394, 0.04786797892302275, 0.027802680619060993, 0.03456662641838193, 0.025218600440504294, 0.034189381304063966, 0.023312731280124614, 0.048319744145763774, 0.01048968404731048, 0.03324895551694291, 0.043479496014437506, 0.017521906477798308, 0.048498249745794704, 0.04290070903620549, 0.043284091499767134, 0.06600702487464462, 0.026812910069046274, 0.030683669062065225, 0.024313811312562654, 0.010155426670930215, 0.030963456191654717, 0.00907770186729197, 0.014869648796905364, 0.04613237455487251, 0.038669788744300604, 0.018056841434112618, 0.013177586869070572, 0.02805216607105519, 0.021300374530255795, 0.0054598803731745905, 0.04049117011683328, 0.06378269208861248, 0.02898096007161907, 0.0845143592783383, 0.08092085139027663, 0.04219058142708881, 0.0021954339795878953, 0.04727825056761503, 0.011586083830999476, 0.012407078973150678, 0.037836405249046426, 0.0424016872420907, 0.020987145802272216, 0.027363468294164965, 0.0552047813045127, 0.029293842746743133, 0.007464400891746793, 0.030419691798410246, 0.021425238544387475, 0.01588716634017016, 0.0573040736573083, 0.039956124898578436, 0.05383808285530124, 0.05988802321787391, 0.06050504903708186, 0.024663867528683374, 0.018289777417001978, 0.03708030689241631, 0.04082973534241319, 0.09108080049710614, 0.04278951411002448, 0.0041808995384989035, 0.06490046996623278, 0.009273109774637436, 0.005833435105159879, 0.07533080170729331, 0.029674490714179616, 0.03108030670721616, 0.04509078258914607, 0.038789075200579, 0.016588708784963404, 0.04170338310567396, 0.00971665115295244, 0.05435934702732733, 0.012819446756371429, 0.012809581705369055, 0.017894300066732934, 0.007801303706531013, 0.02919354848563671, 0.020614071981981397, 0.06246527563780546, 0.0516376005751746, 0.08598516535546098, 0.032341048520590575, 0.09609849910650935, 0.05095711816102266, 0.08857909616615091, 0.038599692684199126, 0.012010059652051755, 0.025660900099735175, 0.04134134056844881, 0.031567440567804236, 0.012251873417491359, 0.06678100262901612, 0.01695051892394466, 0.04552797966503671, 0.08065284362861089, 0.03311960638633796, 0.09434122232986347, 0.025507417174854448, 0.04531539464369416, 0.026061965185882788, 0.007005580601149372, 0.01387723789749933, 0.027602994548422948, 0.02747613224866135, 0.046272403826670985, 0.03545841481536627, 0.037506511701004844, 0.03019039106688329, 0.051523589728666205, 0.03063306731304952, 0.021590383789901222, 0.0554502243841333, 0.014647243677505424, 0.02884876787928598, 0.03169839443372829, 0.0547058646833258, 0.022371735523587892, 0.008704906246358795, 0.03201569097914866, 0.047666735614516904, 0.02754543611912855, 0.04991738198857222, 0.016957370431295464, 0.021921741277245537, 0.020191889189715897, 0.03155978669279388, 0.11229163554630109, 0.06158913765102625, 0.05787763252322163, 0.01883460202121309, 0.031325434268053086, 0.026296329484986405, 0.0353482512624136, 0.03954446788078972, 0.016849627552021827, 0.015552687591740062, 0.013955765603376287, 0.017025049210393002, 0.02095726312005094, 0.03143912281042763, 0.03478782204911113, 0.033367817888834646, 0.03398974273087723, 0.04221459478139877, 0.0484197839562382, 0.03575205084468637, 0.0066683855922227454, 0.047339335682668855, 0.050737713862742694, 0.05787679792514869, 0.03896178611155067, 0.05636185993041311, 0.03348851909062692, 0.015698309688429748, 0.021779245530654277, 0.011077879761744822, 0.010801660030015876, 0.027264758412327086, 0.05125419436288731, 0.00902909755573741, 0.059453394397028854, 0.03593847494838493, 0.05514727206900716, 0.020585914475045035, 0.043720840742545466, 0.17353687807917595, 0.11808360368013382, 0.09413882890450102, 0.11248703327562128, 0.12516201314117226, 0.145712586119771, 0.1407418285629579, 0.23166713597519056, 0.1377994835908924, 0.16652282087930612, 0.24076829903892108, 0.16359756141901016, 0.1778833834188325, 0.12280504032969475, 0.17945431412330695, 0.19282555234219345, 0.09915271414709942, 0.0972650432959199, 0.15144613917384828, 0.1650237606040069, 0.14365473868591444, 0.09932042764765875, 0.09513038569795233, 0.13734044108007634, 0.27682046592235565, 0.09613242585744176, 0.07224658863352877, 0.16669774720711367, 0.12100408625389848, 0.11217653565108776, 0.13489124178886414, 0.14890844534550393, 0.1254664853747402, 0.1488248226898057, 0.08846325666776725, 0.1453483620924609, 0.12828355921166285, 0.1805877254477569, 0.07120549199836594, 0.11728937844080584, 0.0927706580342991, 0.08877983396606785, 0.13809525700552122, 0.16379848920873233, 0.18722689204982348, 0.10894399482224669, 0.10806776862591505, 0.08544102776795626, 0.1294760573655367, 0.13571414191808018, 0.14473838625209673, 0.10726081406963722, 0.14146210705595358, 0.11183777025767735, 0.0698855242558888, 0.13919394090771675, 0.1682603590722595, 0.11438186945659773, 0.11003989673086575, 0.11635016383869307, 0.11943852954677173, 0.18148222459214075, 0.19042123135711464, 0.07360372652432748, 0.13057060220411845, 0.11914920221482005, 0.13862503000668117, 0.15585644037595817, 0.17329928225704602, 0.08992527571639844, 0.12442425558609621, 0.1417841940586056, 0.12135254112737519, 0.08647745608219079, 0.18410503385322435, 0.062496651097067764, 0.12157755691025939, 0.098096859375281, 0.12908363342285156, 0.15520667524210044, 0.07023193673895937, 0.14868979422109468, 0.1770170706191233, 0.1488596722483635, 0.10348926537803241, 0.1203348743064063, 0.13732418338102953, 0.06809062271245889, 0.06844683324119874, 0.194684806146792, 0.16304413468710013, 0.13779683730431966, 0.06809029701564993, 0.16546155139803886, 0.11185189735676561, 0.21341154484876565, 0.10464667648609195, 0.07294847882751908, 0.11429163786981787, 0.09419315241809402, 0.08373136379356895, 0.06485879434538738, 0.1476399784109422, 0.08415932940053088, 0.13988614162164076, 0.2054815467979227, 0.10457199692193951, 0.106735397263297, 0.07310942054859229, 0.13801789044269494, 0.10566107955362115, 0.0793502599533115, 0.11107097818915333, 0.12092745250889234, 0.20567252726427146, 0.08080516795494727, 0.09862958400377206, 0.16594537400773593, 0.11375326104462147, 0.1643988298518317, 0.23438382734145435, 0.0871875226231558, 0.21784429198929242, 0.1438418107905558, 0.10235060897788831, 0.11736221238970757, 0.2001787820564849, 0.16519954188593797, 0.190244554408959, 0.1906788032501936, 0.1149435064622334, 0.07498556987515517, 0.165700137881296, 0.09459424125296728, 0.06561171037278005, 0.0888070771470666, 0.11942505384130137, 0.2872016988694668, 0.1344077991587775, 0.14316392716552528, 0.1276354497032506, 0.18693277426064014, 0.09075588400342635, 0.10261773464402982, 0.1472427775817258, 0.11951738888663904, 0.07604171641703163, 0.09980699153883116, 0.10443080056990896, 0.17248396814933845, 0.10519227292388678, 0.14324502567095415, 0.13143572078219481, 0.1441923284104892, 0.10537235611783606, 0.18716233622814926, 0.10370995889284781, 0.11861140892973968, 0.16559545349861893, 0.13816552609205246, 0.195606636681727, 0.08813840802758932, 0.14799975124853, 0.04561201622709632, 0.14621874610228197, 0.10528931700225387, 0.13473151464547428, 0.1305894519069365, 0.15667149664035865, 0.08263903776449816, 0.12673458590039186, 0.13085546477564744, 0.15989373730761663, 0.2304708787373134, 0.08942917162286383, 0.10479592026344367], [0.09820568282157183, 0.03039146474163447, 0.017458862092878138, 0.03908447542094758, 0.006259443562677396, 0.026107791744704758, 0.036009215616754124, 0.049920944297420125, 0.036706373028989346, 0.036540922442717214, 0.01979594534662153, 0.07926989426570279, 0.01859584929687636, 0.03804768069780298, 0.02855561360982912, 0.03359368862584233, 0.028190176701173186, 0.06400042719074658, 0.020937897730618715, 0.019380520763141767, 0.0540451412089169, 0.020056663945849453, 0.046505290615771494, 0.03419268237692969, 0.06231109212551798, 0.08843929759625878, 0.025407182285562158, 0.03192374609144671, 0.018942875854138817, 0.04897026584616729, 0.105313954608781, 0.03654493258467742, 0.03175313863903284, 0.044955486099102666, 0.01090255649095135, 0.06335395973707948, 0.044666715165866275, 0.004933536094280758, 0.043210697759475024, 0.033200324912156375, 0.031041073812437908, 0.060791085474193096, 0.059680601848023276, 0.024985467682459524, 0.0076156149651589134, 0.025814430522067205, 0.03482814399259431, 0.03815730142274073, 0.024032763804176023, 0.0021713548921979964, 0.05379591868924243, 0.02342961572243699, 0.018313254728647213, 0.0035504936448497964, 0.07526529593659298, 0.005312774829300386, 0.016228761224608337, 0.0167545325654958, 0.0583017644073282, 0.023295571129502993, 0.005609926094101476, 0.04999793766598616, 0.027747279931125895, 0.059452308740999014, 0.008987189536648137, 0.025796052401087115, 0.04092879127711058, 0.012182692531496286, 0.008458530181087554, 0.017818616270752888, 0.03524990100413561, 0.02900579784597669, 0.028692284133285284, 0.047360624718878946, 0.03351320419460535, 0.006834672472905368, 0.013153893274388142, 0.013467118609696627, 0.05330826574936509, 0.010806097649037838, 0.04730322065630129, 0.049814560184521336, 0.03899590624496341, 0.03490803809836507, 0.027824332671506063, 0.019619231079039828, 0.009343558672948607, 0.011778984551451035, 0.04596834549946444, 0.04550377292824643, 0.022373576049825976, 0.05907141989363091, 0.008608904567414095, 0.07497280663145439, 0.011290959265482212, 0.020227678519274508, 0.01658565877005458, 0.02373942293758903, 0.08235097929303135, 0.03512420917728117, 0.020935712847858667, 0.016940032165231447, 0.012116015439720025, 0.05633971933275461, 0.03549043827557138, 0.022435660307694758, 0.015331142515476261, 0.05888374389282294, 0.03172691326056208, 0.05583879424791251, 0.01163972880957382, 0.042360720690339804, 0.016068077346842204, 0.019072499791426317, 0.035914125719240735, 0.01365014664562685, 0.0462598441434758, 0.04048888684649553, 0.056993779593280385, 0.10279610114438192, 0.03795958988900695, 0.01838682488804417, 0.040726798187409124, 0.03610834279762847, 0.016370907525664995, 0.034792676967169554, 0.012589209646518742, 0.06998913655323641, 0.048594147099980285, 0.08652233438832418, 0.03419295379093715, 0.019935353758877943, 0.04651075621534671, 0.03784589456128223, 0.035638148563780954, 0.04409996879154018, 0.016926405485719442, 0.060034138948789666, 0.046789104850696664, 0.04530536589611854, 0.060179996836398325, 0.01858832434351955, 0.02548856577569885, 0.03808129532262683, 0.016626560860978704, 0.038955306102122576, 0.007673365928764854, 0.03739151019336922, 0.01375728562873389, 0.038129854681236405, 0.037661597664867125, 0.13448614281203064, 0.010414660974804844, 0.04276752957542028, 0.010271641059911676, 0.009600999099867684, 0.01953013943109129, 0.031068520553942238, 0.018161636078730226, 0.03354894941938775, 0.014173226746996599, 0.033487206125365834, 0.02045839569265289, 0.033875131380877326, 0.011127037927508354, 0.03425529758845057, 0.0014645815785375557, 0.04103986067431314, 0.03841780458710023, 0.01593304378911853, 0.05767244353358235, 0.020490235948402966, 0.04529717258576836, 0.05219572616208877, 0.0027384602539573927, 0.02115490340760776, 0.01273464599424707, 0.012233715820392328, 0.011625144547516746, 0.021096347531835948, 0.02412426594777831, 0.0313478700284447, 0.02927387346114431, 0.0653525914198586, 0.01609836206106203, 0.01242194906808436, 0.045526812584804635, 0.054368788842111826, 0.07735073938965797, 0.04952283423127873, 0.07698186739747014, 0.018355174622099315, 0.011780611339158245, 0.05868585593998432, 0.016675725812092423, 0.12284883297979832, 0.039602509766284905, 0.005150191477566425, 0.03829240792297891, 0.03863375514213528, 0.028834264193262373, 0.056752149880464585, 0.03976985007258398, 0.04367987419079457, 0.03993351611175707, 0.07523212914488145, 0.08743894020361559, 0.04292233733992491, 0.04112365296376603, 0.05067954305559397, 0.026934471313974688, 0.09814650099724531, 0.04061760493953313, 0.04486206539773515, 0.016984725570572273, 0.05120680886986, 0.06133343851459878, 0.0023506662525635746, 0.01644023005584521, 0.05568333848246506, 0.04020823797743235, 0.02458125928283802, 0.021486435617719377, 0.032877243855702024, 0.03460965571658952, 0.026560186308675578, 0.08034374378621578, 0.04218714464721935, 0.003624406676473362, 0.02606018742413393, 0.05585077039099165, 0.002874230658302882, 0.05275852685528142, 0.021452329055007015, 0.009940118179656565, 0.031222212128341198, 0.07863234954753093, 0.0347379836519914, 0.03066343514780913, 0.02630109788982996, 0.023235340968572667, 0.012458527194602149, 0.0368164415870394, 0.028110715161476816, 0.028849249639149224, 0.030379909290266887, 0.055731480542038164, 0.0315732827543148, 0.03136903353567634, 0.07592150715312787, 0.02854985963287098, 0.041147530611072264, 0.044876294277076206, 0.03977438947185874, 0.0463381640480033, 0.0520915913927768, 0.03315685795886176, 0.03758292831480503, 0.030686783537800823, 0.044145596878869195, 0.02521683624945581, 0.036645013107252974, 0.08386295887508563, 0.008083173938627754, 0.052693672478199005, 0.04198626774762358, 0.08930470115904297, 0.025058878386127095, 0.04562273029504078, 0.06994337615157876, 0.06287458153175456, 0.03773137820618493, 0.05273193506790059, 0.029689180997333357, 0.011946792198744203, 0.041149630676954985, 0.05404306149908474, 0.03227489814162254, 0.02895034457157765, 0.06294970214366913, 0.018751817356262888, 0.026905324842248644, 0.0185114395405565, 0.05150273156219295, 0.05701917715902839, 0.03232601218457733, 0.07221643453730003, 0.04334499341036592, 0.015272727435720819, 0.04526138325620975, 0.04107599944940635, 0.008765151674327041, 0.012461745995096862, 0.01845432385536177, 0.044238305118467124, 0.047584127368671555, 0.011492909098576223, 0.019470881271575178, 0.024249177459361296, 0.08268906615142312, 0.05895995016076735, 0.06257445192230598, 0.03364642097481659, 0.054689715549881966, 0.028143800528986112, 0.012045872730336018, 0.0340141055307218, 0.02278548582190914, 0.07019098715058394, 0.012513436792817498, 0.06751136415238891, 0.05905968802315848, 0.04549969154010926, 0.052123485931328366, 0.10173992746110473, 0.013606245429920298, 0.0373492985298591, 0.008542097705815519, 0.07036458354975496, 0.0205358793027699, 0.0019862352720727877, 0.02128542640379497, 0.005506899457291833, 0.020059439154075723, 0.02286283202868487, 0.021800281812569926, 0.03150496445596218, 0.07283334500555481, 0.0324059503951243, 0.03511816682294011, 0.04000155621075204, 0.02980640470715506, 0.043638734612613916, 0.056044607489768944, 0.04553955207977976, 0.0163681933855904, 0.03674594519127693, 0.03860192845708557, 0.031212237663567066, 0.036587205316339216, 0.005592854153032282, 0.01485082962816315, 0.02653180488518306, 0.03727780468761921, 0.043883689147021086, 0.01712475823504584, 0.03873351675325206, 0.02151154650242201, 0.02712580461853317, 0.046460785503898344, 0.0378182476519474, 0.05079456152660506, 0.1876757022525583, 0.07163613781865154, 0.09111278663788523, 0.08839815123272793, 0.08735501899250916, 0.11880074734134333, 0.09038655739277601, 0.1146126256457397, 0.18232697354895727, 0.08245504620884146, 0.2937798516026565, 0.11046075807618243, 0.18481326156428882, 0.22499147775982106, 0.23310823578919682, 0.09801453950681857, 0.0849213038704225, 0.15826123633555003, 0.09842319400714976, 0.22043067749057496, 0.13628495271716798, 0.08804384738739048, 0.10107095300086907, 0.13522908437464917, 0.10558857130152838, 0.11895310559443065, 0.11968398280441761, 0.14758424354451044, 0.09549594643924918, 0.15004666069788591, 0.23023805980171475, 0.17048689031175204, 0.07638685325426714, 0.10870736251984324, 0.13683212335620606, 0.1656704316181796, 0.10056713396417243, 0.12053783770118441, 0.18504603978778633, 0.12997654479529175, 0.08632421573357922, 0.08542565894978386, 0.10509813976074968, 0.20328276764069284, 0.09805764005120311, 0.14224206948918955, 0.05924230215272733, 0.13347660484058516, 0.14873000420629978, 0.08498625324240752, 0.1940394514905555, 0.10545394995382854, 0.08865056625966515, 0.13273587530212744, 0.13045990600117616, 0.0893606124445796, 0.09600891891334738, 0.16210292519203254, 0.15409056656062603, 0.05939550178923777, 0.1915160340390035, 0.15417136651064667, 0.07458246579127652, 0.21036285986857756, 0.09415953779327017, 0.10546317803008215, 0.12884393414216383, 0.08043871154742581, 0.1438323384416955, 0.1043758053066475, 0.23258245257394655, 0.07893239773277726, 0.13397477168057645, 0.13386208058467933, 0.0901601981105549, 0.11355376496378865, 0.14658047312072345, 0.15613320123936447, 0.08780670618372304, 0.1256379240325519, 0.22395599260926247, 0.1616578876440014, 0.0897277473871197, 0.13386966660618782, 0.12291623864855085, 0.10493458567985467, 0.19725688812988146, 0.09350900591484138, 0.18717345063175472, 0.12262118448104177, 0.175589650071093, 0.18029360765857355, 0.06870236274387155, 0.17494411899575166, 0.10643916244485549, 0.1413021899227585, 0.08291758996035371, 0.15340185351669788, 0.17765671201050282, 0.14328325433390482, 0.10537352998341833, 0.09447979953672205, 0.09125325017209564, 0.22577404576752866, 0.1877588363630431, 0.09156059939414263, 0.06355188840201922, 0.18141970437552246, 0.11828464003545897, 0.14273912353175028, 0.1349960754492453, 0.09351421027843441, 0.07183935905673675, 0.19092926409627708, 0.20530515483447484, 0.07502900968704905, 0.17091362098498003, 0.06184406325753246, 0.12243593085025038, 0.28177401583109585, 0.1771033802734954, 0.15057794004678726, 0.15950790872531279, 0.16051166557839938, 0.14871731560145104, 0.16788820975593158, 0.09488788406763758, 0.1481965942574399, 0.14992134885064193, 0.13954194794808114, 0.08017611849520888, 0.09674504119902849, 0.2288740687072277, 0.135471660643816, 0.20413873956671783, 0.12306213724826064, 0.12047807233674185, 0.13607662889574254, 0.14360891043075494, 0.08158341369458608, 0.10971151970859085, 0.11771544414971556, 0.1316480886723314, 0.0819031393953732, 0.05937964442585196, 0.11709181618477617, 0.05618949167962585, 0.08588739524462394, 0.12365687319210597, 0.09591388329863548, 0.11640920995601586, 0.15764609005834374, 0.11913474941892283, 0.08938610500523023, 0.14900956063398293, 0.07505502471966402, 0.15437711189900125, 0.1231674323124545, 0.09482488887650625, 0.1350171236055238, 0.10793134916041579, 0.0966147081926465, 0.14918295347264834, 0.10898383839854173, 0.09998735971748829, 0.10682231759918587, 0.10775408867214407, 0.12981198648256914, 0.10948599502444267, 0.09612016472965479, 0.10837500249700886, 0.07954679083611284, 0.1619918897215809, 0.15615551147077764, 0.1208605489560536, 0.28685822444302694], [0.033862520807555745, 0.06889462564140558, 0.03394848780174341, 0.06894660142383405, 0.10459121981901781, 0.07158093899488449, 0.019753465661779046, 0.06412614615900175, 0.011356767832434602, 0.02949951688892075, 0.04985796946233936, 0.03567337810194918, 0.029951750300824642, 0.05362395077411618, 0.01806503813713789, 0.06364607584795781, 0.02036413869687489, 0.06441608417247023, 0.028815953925784146, 0.032082357044730864, 0.03219895650233541, 0.03363107929804495, 0.03721203089558652, 0.0488514306156763, 0.01815026892083032, 0.048000707158020565, 0.02004562078842095, 0.034110810341579575, 0.0473611539761935, 0.017412548685180287, 0.04970248655549117, 0.0656695147710187, 0.05902655515819788, 0.006858526795570339, 0.01375591753250254, 0.04879619786515832, 0.015448622372267502, 0.04813366948759981, 0.014694261065285121, 0.016006437529410635, 0.08036829318319048, 0.05007624060713819, 0.02943371595548732, 0.05202245206705161, 0.019399492602263178, 0.0787284504622221, 0.014347760372662118, 0.020729624799319675, 0.013935780202570771, 0.048230716958642006, 0.04015525457050119, 0.03821878348078046, 0.05234951951674052, 0.023536535878000513, 0.049010150134563446, 0.041440593278301616, 0.040338397957384586, 0.05052891167412911, 0.036429971789142916, 0.04063136902238641, 0.02290052973798343, 0.047098004525261264, 0.03226059801610453, 0.026704020465591123, 0.06901943537273578, 0.011690074411619986, 0.022924342924462895, 0.052158145500080924, 0.021102559519931674, 0.04588413930365017, 0.02853709299649511, 0.06326151612613883, 0.01965902715788356, 0.04979793946923954, 0.07531668139355523, 0.0466604681818613, 0.012814844592607446, 0.0261391468479165, 0.01944554647031639, 0.010435328303304101, 0.0888183204723256, 0.058483184315264225, 0.040411055487181456, 0.01661920893405165, 0.03827934951654502, 0.04622708786545055, 0.03514772041567734, 0.05079065316489764, 0.030664856678673198, 0.010562869986253125, 0.027466251082452278, 0.019665953304086412, 0.03224057784037931, 0.011672938009724021, 0.07436465605029038, 0.033700418791600635, 0.10380918106862477, 0.022756303727094616, 0.043911112139799764, 0.010484415222890675, 0.08972587463046823, 0.054028286399053674, 0.01948416868357786, 0.03408361126535705, 0.026307165689234222, 0.0385584886451917, 0.08129606089953866, 0.036193726251700094, 0.017127747181802988, 0.011723488868613328, 0.03950247674116066, 0.04556111592267241, 0.051496926695108414, 0.03146307848926101, 0.030463202856481075, 0.02449506158674402, 0.014072047845859612, 0.04764377398948584, 0.029337604862770865, 0.023773763594882827, 0.06577317456581763, 0.04317885071837476, 0.08701231809599058, 0.05370895764125245, 0.03582205530256033, 0.04694060814966049, 0.029201517879430736, 0.03459436832261937, 0.045168634304510694, 0.008668130496516824, 0.02396828431769141, 0.03458963893353939, 0.028333094835813557, 0.048598092781113725, 0.025408534266586815, 0.027856963420552865, 0.024625642258407812, 0.03718722704797983, 0.035974196424441676, 0.01251871494709381, 0.008932205299580736, 0.02193703206389078, 0.004812611824101103, 0.03497635639671769, 0.009703828537437533, 0.04108896964628782, 0.11094637201832873, 0.018428520864940116, 0.051181258633732796, 0.03624064016288944, 0.06273776851594448, 0.06255655216851405, 0.010078760695510676, 0.019209217812333788, 0.02888869627245835, 0.014615774919678057, 0.012281208182685077, 0.019727140199393034, 0.028938042731689553, 0.03767038808603372, 0.056822025416685004, 0.027758048281871846, 0.02312603745875614, 0.06444256739424807, 0.019247041050610796, 0.018310087666447674, 0.04455120814964175, 0.029832938819059303, 0.016997102049312422, 0.001757686654205567, 0.04631733302293079, 0.04983081788356815, 0.02065002076726939, 0.014239405115534152, 0.01883008297798889, 0.047619424760341644, 0.02731552640242236, 0.05230989646432655, 0.03127523285469838, 0.004527780634816736, 0.033314518963119814, 0.02437455376743206, 0.031244583427906036, 0.07144506235740014, 0.05956112540193966, 0.0753885857494814, 0.055570284370332956, 0.02796144424272435, 0.011294139050213354, 0.017016184150374362, 0.04014799085312656, 0.07992927424077477, 0.05666928718398724, 0.04553498893177935, 0.03512254337381039, 0.054891813812511306, 0.04327077525002616, 0.053098147202815325, 0.020176839283002273, 0.012082472061073142, 0.04042572541428464, 0.0586615168888654, 0.06788303170885358, 0.01719304091030998, 0.05243239578391824, 0.01933477562852204, 0.02225726157692926, 0.0077458996259208235, 0.02084059071993189, 0.014915660256519914, 0.063499193372471, 0.02170082723854908, 0.020165679078283053, 0.0817619701847434, 0.014434332959353924, 0.013504224297191416, 0.03512247212763343, 0.060501805639692714, 0.029337136673607996, 0.032341988291591406, 0.022651174903980324, 0.022353849340496317, 0.041319101583212614, 0.05946535696940763, 0.010665028522323285, 0.03179494657420686, 0.05595523424978767, 0.022633868868329694, 0.06041456639234509, 0.03504264248268945, 0.06356170001838889, 0.006917603871053351, 0.0388415870256722, 0.04892309409167085, 0.02339844382368028, 0.018981888225036006, 0.0121739877753758, 0.02476588187606207, 0.04994813319561737, 0.050428145831184726, 0.054916787293872664, 0.020960750790046792, 0.032449800720704455, 0.03717040277219244, 0.03287003781380398, 0.07150556053966284, 0.032926413895828385, 0.04067660355940461, 0.01818209221320493, 0.06786737112062317, 0.013049564274427081, 0.0379502803885511, 0.0348542540201119, 0.01476356154307723, 0.014701762269916279, 0.012758389630887126, 0.012233685286316489, 0.030024377296545675, 0.028267801107306565, 0.016511279457647885, 0.03147964831441641, 0.0342326379115028, 0.03059717620323811, 0.026386323584509746, 0.04611785729814853, 0.035712885803409984, 0.024089952431885258, 0.029364108440599272, 0.02325950190424919, 0.025341557771233574, 0.04546369525736996, 0.058897294237145355, 0.02446351310105196, 0.037221353966742754, 0.01911152064401124, 0.008783670591323503, 0.06378888032798256, 0.026030479464679956, 0.039274193812161684, 0.020601363021082113, 0.04359364935329982, 0.05582687917298504, 0.012127958504217011, 0.05412396662203329, 0.018541580066084862, 0.02402071132590728, 0.011814750980452766, 0.025711975126926388, 0.0643207635730505, 0.04376595314326031, 0.014560084158022488, 0.05516919892813478, 0.024901894220550145, 0.022584982116573622, 0.053041201151375256, 0.01915038373720433, 0.003721737435885838, 0.04929084310840283, 0.04625662449481232, 0.01519979679557894, 0.010234000177920928, 0.05331271693908742, 0.027043192980012724, 0.0370312589885933, 0.040771584891315014, 0.0641550924628973, 0.030492627527564764, 0.03808598739228078, 0.009577077347785234, 0.016756110159414153, 0.060493839638573785, 0.022966108451198255, 0.020846548257395625, 0.07335889073354857, 0.04801975363599403, 0.011141885970053928, 0.02491132416097181, 0.04143614548125437, 0.015714837105146477, 0.021062822812902074, 0.015595282627535718, 0.040129612732146464, 0.048060116291578324, 0.03305935926203217, 0.05215664254501462, 0.03709660869623933, 0.026247217120336633, 0.027170764348868812, 0.055904547683894634, 0.049221937877259085, 0.030788719853652374, 0.03701052295842341, 0.024747403671166728, 0.022272216488740275, 0.021386360184156468, 0.029622416544173445, 0.08100197703710624, 0.061207644907491546, 0.02332166419364512, 0.01424579691540982, 0.04625625469322715, 0.038950444398713965, 0.039792282440300496, 0.023615117018510188, 0.038491788652858565, 0.005221826539907072, 0.03993931758616652, 0.028596000014139072, 0.038360220712742636, 0.055437607025461536, 0.031310543817068846, 0.004515245548515979, 0.08255540153809957, 0.09339954464563302, 0.08495406354112284, 0.11426911050719873, 0.15192578200783047, 0.16173790049340042, 0.09950629874531712, 0.15474441647529602, 0.10455510139997516, 0.07356074811624629, 0.10792493021913938, 0.12397513325725283, 0.10653273920927729, 0.10063291793423039, 0.24304443118827684, 0.15856572213981832, 0.12299033467258726, 0.0870692946815065, 0.12973428065223352, 0.1152548183287893, 0.18037762386458261, 0.07869799102523498, 0.12954534936164105, 0.1114701603406242, 0.12104118854871818, 0.2141676228493452, 0.1030206215967025, 0.07010388361024004, 0.13082730557237351, 0.12380233752940382, 0.10193235320704323, 0.16482511269194738, 0.07605965009757451, 0.07327108151678528, 0.12187620731336729, 0.10155657372836556, 0.06323552823492459, 0.13852206910295145, 0.12757785565086774, 0.09774742741137743, 0.32870752311178614, 0.1883597198341574, 0.10007577961576836, 0.12107081338763237, 0.09719188365020923, 0.19727769201355322, 0.14654457861823694, 0.18106974315430435, 0.12942549293594702, 0.10330917539873294, 0.09797628370246717, 0.11506762408784457, 0.09213632957211562, 0.09700838742511612, 0.16726710594126157, 0.20390457713178226, 0.09965713707996265, 0.22312562859484128, 0.07318077529115335, 0.11518026090094022, 0.11055824998766184, 0.09768926338957888, 0.2738763024764401, 0.15375946861292633, 0.24807764110820635, 0.05039702482255442, 0.09252990023898226, 0.13525450229644775, 0.09496290968464953, 0.12668744128729614, 0.1340719921780484, 0.18730470644576208, 0.11751153080591134, 0.07448646665683814, 0.0927551399384226, 0.11363055477184908, 0.11209928443921463, 0.12484696933201381, 0.04229194098817451, 0.09555784918900047, 0.1950838661619595, 0.13209674959736212, 0.21633206813463143, 0.14252480146075996, 0.08485660555639438, 0.17568110302090645, 0.0711166581937245, 0.077513384233628, 0.09977175521531276, 0.07908889504947833, 0.1359893014388425, 0.1405463290533849, 0.13915522369955266, 0.13138727338186332, 0.1707304436713457, 0.11481837103409426, 0.16748989612928458, 0.1302447018346616, 0.0932747484850032, 0.11592951283923217, 0.14951924899859087, 0.13677618492926868, 0.1352401173540524, 0.16157416999340057, 0.16837774563048566, 0.1838404866201537, 0.1255686456071479, 0.13420551429901803, 0.08254695377711739, 0.08143220216568027, 0.08676157905054943, 0.09697381606591599, 0.13032567820378713, 0.0893029233972941, 0.1210637701941388, 0.18044140615633555, 0.13553179241716862, 0.08170455255146537, 0.15429423563182354, 0.11928230364407812, 0.09807574336550065, 0.15905247602079595, 0.19414623933179037, 0.14524732822818415, 0.12234535999596119, 0.15826191487056868, 0.161152949024524, 0.13527826459280082, 0.1794993281364441, 0.19888892769813538, 0.12261005650673594, 0.210303203069738, 0.12072155784283366, 0.11788110168916838, 0.0786102700180241, 0.14473004027136735, 0.09758366298462663, 0.12480257957109384, 0.13565447154854024, 0.11023429701370852, 0.07812511747969048, 0.13932972933564866, 0.10506980413837091, 0.10727572826934711, 0.14620981658143656, 0.15629010567707674, 0.1663617638072797, 0.09340314766658203, 0.12582595965691976, 0.07244343842778887, 0.09689005770321403, 0.13989600752081188, 0.12875362113118172, 0.18341799000544207, 0.07124937964337212, 0.07604550942778587, 0.06792004579412085, 0.10393601283431053, 0.09291574917733669, 0.07534404671085732, 0.17224452671195778, 0.19488893662180218, 0.0913713966895427, 0.08802243282220193, 0.11432058417371341, 0.10304254506315504, 0.11554510918046747, 0.11117476690560579, 0.07124597339757852, 0.11032688990235329, 0.32513975884233204, 0.12283397306288991, 0.16550492335643086, 0.08192271513066121, 0.15967429908258574, 0.156142280037914], [0.04047656465055687, 0.05048418264569981, 0.07235212797032935, 0.03730081720277667, 0.06061728551451649, 0.07187367257262979, 0.04060208345098155, 0.049308332348508496, 0.03753907798922487, 0.023382240407434956, 0.06567209320408957, 0.06213988416961261, 0.01623865935419287, 0.028486840693014007, 0.026056850728179728, 0.028396492058943425, 0.03423229185864329, 0.02300195545623345, 0.023883489492748464, 0.020171266814161624, 0.03880230663344264, 0.010045559977048209, 0.030012390975441252, 0.060962218791246414, 0.024543412295835357, 0.0253730468851115, 0.03999510673539979, 0.07469561829098634, 0.03185280864792211, 0.05810168478637934, 0.005278828570486179, 0.029363222952399935, 0.014917086876396621, 0.01649480632373265, 0.06319926053817783, 0.016369921953550408, 0.0264586638991854, 0.025236216905925955, 0.01856178853527776, 0.05970163643360138, 0.016508241317101886, 0.04195320612883993, 0.0061000366029994825, 0.0714459376675742, 0.027907765337399075, 0.049900683241763284, 0.028013019689491818, 0.012379138597420283, 0.082959916974817, 0.07778643351048231, 0.02637779779200043, 0.039241495209613016, 0.0066127372390058425, 0.03929457361144679, 0.03419508099822061, 0.05706740742815392, 0.015629401064610908, 0.06325504968741111, 0.04122456808441451, 0.06613040289708547, 0.007861243793740869, 0.023160695331171155, 0.02346467223417546, 0.04643331840634346, 0.094385741012437, 0.025827008864975402, 0.019928454754075835, 0.024524011283314655, 0.060768449545970986, 0.05454577113102589, 0.04042914183810353, 0.03346241245578442, 0.028285320881488066, 0.010820903283144747, 0.019698750294212784, 0.09268846030214004, 0.022709715512714217, 0.07686728997422115, 0.03224581613072327, 0.006718648073729128, 0.03144680043416364, 0.04487043512719018, 0.035431728033082824, 0.020054760655122142, 0.04756211229999151, 0.039705664052494934, 0.023169022652187517, 0.01431933993340603, 0.1005638837814331, 0.028228546160140207, 0.029970776422747543, 0.039430850584592135, 0.029521430177348, 0.025482640468648503, 0.03985710289063198, 0.027018648672050664, 0.044922594114073684, 0.072120666104768, 0.02779247545238052, 0.02180662441865674, 0.02828731747078044, 0.03181132980223213, 0.03926030759300504, 0.028757152081068073, 0.02366139310678201, 0.004921656642441771, 0.04857574523027454, 0.03515362706301468, 0.02309496734025223, 0.01604539731384388, 0.017676008565883552, 0.0012710873519868723, 0.06041590989168201, 0.033671309639300616, 0.033589746337383986, 0.03192579187452793, 0.009395663377030619, 0.011317076926518763, 0.039416859192507606, 0.03356530889868736, 0.009553434643229204, 0.025709739354039942, 0.053613765963486264, 0.042271208350679705, 0.06552265943693263, 0.027125550167901174, 0.05130190894539867, 0.06676862615027598, 0.005038881624516631, 0.013351849928897406, 0.032806065532245805, 0.01703666742624981, 0.0661540294864348, 0.034359900546925407, 0.003652691832810108, 0.05471785778978041, 0.014632867216797811, 0.03282827398340617, 0.046324671379157474, 0.09902514956359353, 0.027134998768035854, 0.04051147527726633, 0.03942575478660209, 0.008823840712596263, 0.007522265509968358, 0.0190106835548899, 0.018342682792405997, 0.007642237286615584, 0.08969699618007455, 0.06338794755616359, 0.03106245445087552, 0.02560981998353132, 0.05016942382124918, 0.019277078099548817, 0.06933185325137206, 0.025987585873476098, 0.05397529959944742, 0.08234886226377316, 0.025545642445130006, 0.06565525196492672, 0.02735171776397952, 0.05314526128183518, 0.040676125192216465, 0.09021671329225812, 0.10638545639812946, 0.06609127178256001, 0.010677881671914032, 0.048455295086439164, 0.04089160416541355, 0.040940156738672934, 0.02309113022472177, 0.058966891574008126, 0.0228954492070313, 0.02630004276787596, 0.039344194877360544, 0.006036737767447318, 0.048782508421157084, 0.0646988432854414, 0.02789471371631537, 0.02863866290343659, 0.039715411208037815, 0.019569114482562457, 0.018725405380662, 0.038240354109023295, 0.045470657026661296, 0.01779417713571872, 0.04482277822015541, 0.04238409961440733, 0.02496933381605361, 0.05041190848818847, 0.016026764742231796, 0.04889403582949724, 0.01951110822015575, 0.0009639001301755862, 0.019523868071181432, 0.031073633315307752, 0.014295148463653666, 0.02563419465773872, 0.0053076404396311515, 0.004199146193319133, 0.06592106127313205, 0.015954270060839396, 0.07370816663439785, 0.008091134002565272, 0.023154775113133446, 0.03483631694689393, 0.0205381133793188, 0.007552959041536919, 0.015423329979447382, 0.03651646804064512, 0.02157379700137036, 0.0338218765599387, 0.028160433118630732, 0.036253722318048985, 0.014881182195884841, 0.06917545771492378, 0.03617711571444358, 0.021114405045019727, 0.028360838436388543, 0.013439988235144742, 0.030700052290090492, 0.026021483786670224, 0.04208954756281205, 0.03507330887285726, 0.05315736973924296, 0.04058145259373954, 0.08850374485233001, 0.06412613258830138, 0.026180079472916465, 0.06149665332798447, 0.04640283522063068, 0.014946620113083293, 0.03056054888293147, 0.00977284657502813, 0.012594532753740038, 0.06142668958221163, 0.05924608837813139, 0.008807282761803694, 0.037861660322440524, 0.03219394552122269, 0.05604952008330396, 0.022793333079399805, 0.0313459633450423, 0.020005139389208386, 0.027554238414657966, 0.044036678437675746, 0.0566060002227979, 0.03616721249584641, 0.012818656263074704, 0.013228302272701902, 0.030475548801145384, 0.047764933202415705, 0.024634933099150658, 0.011524673867305475, 0.027639701596594284, 0.02867828934852566, 0.04041689428101693, 0.036475430242717266, 0.04554258513131312, 0.02792970067821443, 0.017427008266427686, 0.02877263625019363, 0.025614260995228375, 0.022311695352462784, 0.010693035055217999, 0.03529292690966811, 0.018386054750798003, 0.019184642970295887, 0.047873553088200946, 0.02133047773635813, 0.03833548132596271, 0.046695460232772996, 0.03827339876443148, 0.027506530617496798, 0.03987538262403437, 0.027192058474091545, 0.024057815317064524, 0.052586891422314305, 0.03687710261770657, 0.013609789927223963, 0.034873368351587226, 0.019310765666887164, 0.030296286634568657, 0.0049913888381394956, 0.06178422325423785, 0.06552867125719786, 0.03828161582350731, 0.08500471618026495, 0.0477274339646101, 0.03412245739517467, 0.010888971371709235, 0.026500290326241936, 0.02638252718108041, 0.022413287311792374, 0.035274270589330366, 0.03664023961339678, 0.02749553326118205, 0.024272914310651164, 0.008732137552994703, 0.04030211329726236, 0.04501916661060282, 0.03274485828088863, 0.030593199988028834, 0.04432012626369085, 0.006824522013110774, 0.00970153000006186, 0.01555870789369302, 0.08445187298847096, 0.06260111834853888, 0.1036812975736601, 0.05493226807032313, 0.09013359275247369, 0.006114706106018275, 0.07670301664620638, 0.02127119243544127, 0.12380297535232135, 0.019195674253361564, 0.03316018617312823, 0.021090011711099317, 0.04241562095869865, 0.1083622324679579, 0.022687943020303334, 0.010743818312351192, 0.019952256066192473, 0.028471108858606646, 0.030117051609392678, 0.01868494433749999, 0.029425498896411488, 0.07095544505864382, 0.02035044246752347, 0.036708659692002196, 0.02687940141186118, 0.05060400853731802, 0.027768446831032634, 0.0680471354031137, 0.0427875463584704, 0.024857217778584788, 0.0318841874998595, 0.03896974193464432, 0.06957537946956498, 0.0765644937221493, 0.10073019271450383, 0.02245694595122976, 0.02166002183886511, 0.007331824478959399, 0.04020547294723136, 0.040904282592236996, 0.042550432296203713, 0.021744284013818418, 0.09821908388819013, 0.07312879950872489, 0.021932747115248015, 0.0930492848690067, 0.1676837671548128, 0.1845126026975257, 0.05463772280407803, 0.13382155847336563, 0.14525290578603745, 0.10520973162991659, 0.08318514310355697, 0.08654123837394373, 0.12119209473686558, 0.10522997232952289, 0.10299730713346175, 0.16107650526932307, 0.1498876799430166, 0.14633466702486786, 0.17048790811428002, 0.09187522251158953, 0.12015013636222907, 0.14557335073394434, 0.07700845239950077, 0.10813138128391334, 0.1535897941461631, 0.10764907180730786, 0.20412824941532953, 0.22585244370358332, 0.12263232602604798, 0.14392748262201036, 0.14276323866631302, 0.06759141771388905, 0.16483094809310778, 0.15570845188839094, 0.10555014586342232, 0.12000263641987528, 0.08777384473276989, 0.1304543555847236, 0.08140411081590823, 0.056371508698378286, 0.062912111303636, 0.12414113006421498, 0.21182390861213207, 0.13472992687353066, 0.1004961117037705, 0.09343431277998857, 0.1324973702430725, 0.15278149609054836, 0.13586880719023092, 0.1303515032465969, 0.06218540029866355, 0.17393933076943668, 0.15732062395129884, 0.15905208247048513, 0.1654409510748727, 0.06586609993662153, 0.11183276266923972, 0.1237386909446546, 0.11526719480752945, 0.11629787593015603, 0.19558919833174773, 0.09113301376679114, 0.143465698829719, 0.1313848713678973, 0.062209590072078366, 0.11930829153529235, 0.15114932081529073, 0.1664252204022237, 0.08498518794242825, 0.07856816013476678, 0.23599982634186745, 0.11287778123681035, 0.1115767378360033, 0.15568335966340133, 0.14186303982777254, 0.11581565466310297, 0.0981919899848955, 0.2057738732546568, 0.1620018370449543, 0.05951233194874866, 0.16331522299775056, 0.1320643156234707, 0.09591663136546101, 0.09032230012651, 0.08554794453084469, 0.09726513150547232, 0.1278534358633416, 0.09219475822257144, 0.10014080362660543, 0.09228980062263352, 0.11530041588204247, 0.22345880285969802, 0.10815994082284824, 0.08090506188039269, 0.10509829582380396, 0.07888685446232557, 0.08470219812755074, 0.12554063568157808, 0.11956825187163693, 0.12832888535090856, 0.1502827773136752, 0.1579243436987911, 0.12257534265518188, 0.12494166567921638, 0.11841552944055625, 0.11821610799857549, 0.09120596985199622, 0.06944972835481167, 0.0587270837277174, 0.13168183900415897, 0.05972047256571906, 0.10890430052365575, 0.1415917208152158, 0.10829389042087964, 0.1302834190428257, 0.20069574431649276, 0.10405993368476629, 0.0814593910638775, 0.07606602154139962, 0.15156112371810845, 0.09059040966842856, 0.1580679759915386, 0.14049780022885117, 0.11722693964838982, 0.10127308179757424, 0.13401367887854576, 0.1706775315105915, 0.1939257968749319, 0.06884301626788718, 0.12851578103644506, 0.12204335762986115, 0.07577303012034722, 0.07634031932268824, 0.08528309195701565, 0.10922408729259457, 0.24838873584355625, 0.15403423458337784, 0.149881545986448, 0.14308950544467994, 0.08353287194456373, 0.14744210402880395, 0.12832470557519368, 0.20667773618229798, 0.0902241093239614, 0.06280006481600658, 0.14790287001856736, 0.07771657154496227, 0.19477534985968045, 0.11408040991851262, 0.099365882708558, 0.11265656525003058, 0.14050153217145375, 0.15891317278146744, 0.09114836901426315, 0.09636679863823311, 0.21026843493538244, 0.08538365763212953, 0.25831801018544603, 0.15687683490770205, 0.24351973139813968, 0.17055367172828742, 0.15186157902436598, 0.15857846502746853, 0.0849318958020636, 0.12024218642285892, 0.12025829484420163, 0.22117820594991955, 0.1947419930781637, 0.21627348342112132, 0.16476097756198474, 0.12998167452003273, 0.13533573650888034, 0.09690199991954224, 0.1076181713225586, 0.12290143301444394, 0.16859931445547513, 0.112077612030719, 0.19234542096299784, 0.10504795531077044], [0.017631537380761335, 0.029302626382559538, 0.027593771561181972, 0.015315556566097906, 0.01785082632808813, 0.11880800766604287, 0.042275601864925454, 0.004254011262673885, 0.0890279131542359, 0.07724401940192495, 0.03828679643837469, 0.04648047998281462, 0.022884928521567156, 0.016305070969143083, 0.019878869111250554, 0.039279174259198565, 0.0949606162362865, 0.10572222234415156, 0.10896624398550817, 0.018260485060246925, 0.04636717481272561, 0.05272868149248617, 0.028561143670231104, 0.02321492045718644, 0.03438536596617528, 0.027008988029722656, 0.05022068714190807, 0.03120908247573035, 0.04336456575297883, 0.0356138773661639, 0.0662051842414907, 0.020524038866694485, 0.029712525994649956, 0.00978261578295912, 0.04675205344600337, 0.030896230334682123, 0.009776140862543668, 0.04604844655841589, 0.0438931716739067, 0.011428628083584564, 0.04683784402108618, 0.0234998949869935, 0.016097004991024733, 0.03333800306011524, 0.07485001893447978, 0.02794781925954989, 0.04684084993121879, 0.01914477225260011, 0.04156263119408062, 0.04534745881600039, 0.05884860934955733, 0.04773364256003073, 0.012013156316243112, 0.07712736566151891, 0.01913842116482556, 0.01417651933817459, 0.014666985653873001, 0.03163873084953853, 0.05043589470109769, 0.014361336162047727, 0.03043917253879564, 0.049101480948073525, 0.024454590365556732, 0.05287406101290669, 0.01734122447669506, 0.012199454042794449, 0.03962563763239554, 0.08186700740563017, 0.0805779808600034, 0.03159572869273169, 0.01862632230456386, 0.09628882139389004, 0.09365417848208121, 0.003171832936849179, 0.044504029609795125, 0.05392132213871394, 0.05162660152252231, 0.031061945549611534, 0.05694709638399737, 0.05876233362193618, 0.039300534541585615, 0.013499296436618482, 0.10771518825952496, 0.013976284502340215, 0.05426441997821842, 0.033465316585664234, 0.03633728729827063, 0.0075274554546922445, 0.015196962215538536, 0.029965504205652645, 0.025707091371129667, 0.01961685111746192, 0.02638137197521116, 0.04572854104584881, 0.01744099287316203, 0.0401711628240134, 0.02559899226097124, 0.05373811089832868, 0.05126997369474598, 0.04961315742028611, 0.051757375576666424, 0.06818518335265772, 0.02773988220308508, 0.02363328818630959, 0.05998932171080794, 0.03583891011242356, 0.09204608441463538, 0.0261649260896125, 0.049078902695328, 0.030686586762645414, 0.11266836497400488, 0.0470142461625593, 0.024261275738743798, 0.07200739825410502, 0.04197204565363271, 0.039984480877007754, 0.060712171851524284, 0.0671302785298654, 0.02380226885101625, 0.02596134862064251, 0.04805523423211915, 0.019695688404941132, 0.04739845983151879, 0.034781342039683034, 0.06484470795840025, 0.018432188346715908, 0.027333256522459642, 0.06836770927267415, 0.033075474468725066, 0.04067112099645393, 0.014849289353670818, 0.08676102943718433, 0.05976146286619561, 0.02234655000003321, 0.030323838549000875, 0.06329245732298919, 0.04545773093455604, 0.04973292563642774, 0.017367817960413437, 0.02566737332381308, 0.04297605695735131, 0.044680197656686814, 0.03833947450454746, 0.02364785802949752, 0.007162206839503986, 0.039726786847625456, 0.014456224195393068, 0.010100708758857633, 0.014768100942351987, 0.06473114833767925, 0.001925741754738348, 0.04945370169090373, 0.01307407211113189, 0.02892561536282301, 0.04891334015077778, 0.05360758111679128, 0.032480718168829165, 0.06436593364924192, 0.012276025023311377, 0.030810429581574032, 0.04277497649724994, 0.0027115624896915896, 0.037954599263944795, 0.04459703979747636, 0.048387275343494754, 0.012048890514831458, 0.03909853466653398, 0.05268507543951273, 0.07212776358106307, 0.03924721525982022, 0.08151958390538182, 0.017836677176611762, 0.028060593475986804, 0.02244322088414005, 0.08601209641035114, 0.07399482732372624, 0.05052331376022526, 0.012942272620940847, 0.025748527808380977, 0.013165946600825658, 0.014636912981846502, 0.061263094789215496, 0.026410598174801896, 0.016228328658533946, 0.07118457276374102, 0.049228465384138484, 0.006653280978623245, 0.04945350152307323, 0.01756950910203159, 0.032587577256241014, 0.06418669862406594, 0.04246242630428501, 0.04528903016554458, 0.09039749537727662, 0.10546574967780284, 0.021889649963538562, 0.030489814999912466, 0.04725143825635314, 0.014369149492787463, 0.0660093454644084, 0.032666395884007215, 0.023957916302606463, 0.027457995007612875, 0.009802806440607777, 0.02399093720928899, 0.005119765543245843, 0.017601234006828496, 0.026998065312259963, 0.04315415882904615, 0.04437082300760916, 0.028407236660963724, 0.04002466032813702, 0.04244720676381673, 0.010029874791923379, 0.01803406810254923, 0.019678982872782008, 0.07234262848006827, 0.08116557183010237, 0.022111398600307957, 0.005167609895579517, 0.018146123071866374, 0.0026751347010888693, 0.028728789317288568, 0.0248561558712806, 0.024174055151109184, 0.051410108139472346, 0.06787959832165923, 0.044171676372310946, 0.004493767370669437, 0.08265345663364444, 0.023385711114055345, 0.022514665532591085, 0.034056870200272114, 0.05340820038691163, 0.023071815725415945, 0.03502466469737036, 0.026582074152039628, 0.029953185402389084, 0.04832156601228884, 0.0495903179315584, 0.04277764653254833, 0.04193115374073386, 0.04577189604086535, 0.07097831168877226, 0.01984406026479389, 0.03313285478257707, 0.02809481369331479, 0.03298104953552995, 0.03118015992056046, 0.041052070911973715, 0.027045751057033027, 0.0567861309141985, 0.0166274158151022, 0.05984611689512219, 0.02802754203522844, 0.05759534838476351, 0.0114064450774874, 0.07795086290155138, 0.06887842901051044, 0.00724784389603883, 0.08683450120900359, 0.06676701802228178, 0.02385706903545984, 0.029647529125213623, 0.05220366162913186, 0.035871038745556555, 0.03353100895349469, 0.004161324227295283, 0.010587012262216635, 0.10258770268410444, 0.05095791543966957, 0.01526488526724279, 0.07786236157906906, 0.016619973982285177, 0.017912961476083313, 0.062462608995182176, 0.07819434840764318, 0.06857618237180368, 0.041818591566490274, 0.06621078894074474, 0.021087418010990535, 0.0382202728651464, 0.08770770792450223, 0.008303194007437145, 0.04967255976849368, 0.03001096605190209, 0.02475951043223696, 0.02757378022319504, 0.048186473082751036, 0.01316041060324226, 0.015155809066657509, 0.020098839986271093, 0.0694404731371573, 0.03235887024285538, 0.025759844076154486, 0.02857641749350088, 0.019011954111712318, 0.010655274581430214, 0.03152617885332022, 0.03152552406702723, 0.013348106960100787, 0.031888886354863644, 0.052168211567082574, 0.07852777373045683, 0.029517267365008593, 0.037245974609894414, 0.05912372815821852, 0.018282037028776746, 0.060054433931197436, 0.025500440138525197, 0.009778861787968447, 0.04667333659848996, 0.012254559567996433, 0.0324983736500144, 0.04156710273985352, 0.024904825491830707, 0.04897696637947645, 0.028560315857508352, 0.028237494340698634, 0.03560352970712951, 0.06129308603703976, 0.014230343280360103, 0.019115910765581896, 0.04106260516813823, 0.028663035881306444, 0.015585153796044844, 0.028309413963662725, 0.13740767032972404, 0.03391771963132279, 0.0007772578880706403, 0.051247517578303814, 0.03654648982254522, 0.060574544593691826, 0.012129727784278137, 0.008307244013329702, 0.015697551425546408, 0.04826082355741944, 0.0379233696897115, 0.03475181219567146, 0.05439245275088719, 0.019193485977926424, 0.05752870946058205, 0.05808545422873326, 0.0053491884110761535, 0.02304041142841535, 0.04691082724769201, 0.07847233063408307, 0.008132006407582333, 0.04278945304187281, 0.005914458123567913, 0.04290894984400698, 0.04078715048464281, 0.1167609625096832, 0.146535011274474, 0.11972378566861153, 0.05216954488839422, 0.11426099522837571, 0.14790649339556694, 0.14446774577455862, 0.08985488449356385, 0.1851056015917233, 0.21111817790993623, 0.11458268868071692, 0.1456367801874876, 0.08940266804503542, 0.13300564725484165, 0.1144249157181808, 0.17039576305874757, 0.18313896283507347, 0.17132843658328056, 0.26459858460085733, 0.11096059411231961, 0.12210977263748646, 0.17393264041415282, 0.0816222530390535, 0.14055031883929456, 0.08801372043256249, 0.08865459675767592, 0.11262136963861329, 0.11064588957067047, 0.12277078788195338, 0.12743521401924746, 0.19637692320559705, 0.15146755373903684, 0.21450055284159525, 0.09856024451021637, 0.1460787778986352, 0.1586329106773649, 0.12221208214759827, 0.15368915881429399, 0.16292953012245043, 0.14419588393398694, 0.14576738460787705, 0.17766127176582813, 0.05457403889990278, 0.1636838439319815, 0.1879367075328316, 0.07514332926699094, 0.08939287678471633, 0.09936822365437235, 0.11684999987483025, 0.09134002801563058, 0.2671955009656293, 0.06343833556664841, 0.0812238444175039, 0.20830609809075082, 0.10479569634688751, 0.17202696124357836, 0.09079011609511715, 0.09375838789024524, 0.06710530844117914, 0.14982480688818864, 0.0971026766513075, 0.09816465180899415, 0.11028421683503048, 0.2280883522970336, 0.10570792561130864, 0.1848653866244214, 0.12246461931083884, 0.17050586215087346, 0.18570500585649694, 0.12112984593425478, 0.05880780225353582, 0.12685441518468515, 0.16445634248001234, 0.09692775710885014, 0.10096040607563087, 0.1556384406451668, 0.16537877012576374, 0.1880118620714971, 0.1316679697483778, 0.11662635473268372, 0.1384346466511488, 0.12076564904834543, 0.21993658186069556, 0.15294274315238, 0.1744681673922709, 0.08137667764510427, 0.13466497750154563, 0.15120045521429606, 0.14799002105636255, 0.1443071501063449, 0.11591568429555212, 0.13824253981666906, 0.1105067084676453, 0.19949352954115185, 0.171623612887093, 0.11733686232141086, 0.1566849180630275, 0.1422028365944113, 0.10223627582724605, 0.06345303263515234, 0.12166169525257178, 0.14007983622806414, 0.10106718713151557, 0.12051658598440033, 0.1270701621792146, 0.08818582405469247, 0.20791684969195298, 0.1144347001931497, 0.10383218340575695, 0.18936807715467044, 0.1815469568329198, 0.2037722628031458, 0.09526472206094436, 0.09359507129660674, 0.0943162115290761, 0.09601441504699842, 0.20422564633190632, 0.12842544088406221, 0.0722935161154185, 0.09582734294235706, 0.13909729037966045, 0.22730345012886183, 0.1507619587438447, 0.20682921233986104, 0.11925977628145899, 0.08777096774429083, 0.14741576329938003, 0.2303102287862982, 0.15259926872594015, 0.12863738808248723, 0.21750757577163832, 0.1516169807208436, 0.12201793970806257, 0.1336383404476302, 0.1259140877851418, 0.20837822636323317, 0.14953307754227094, 0.09929182061127254, 0.1330712887325457, 0.12588789633342198, 0.11981306730636529, 0.1811081210949591, 0.08603023365139961, 0.10004608013800212, 0.13610636230025971, 0.09819507731923036, 0.049387812547917874, 0.13767212256789207, 0.134864711069635, 0.1692018671227353, 0.11575001318539892, 0.19724973637078488, 0.049136591742613485, 0.09706976770290307, 0.17736661114862987, 0.18006724837635243, 0.1615649283464466, 0.11913284952087061, 0.09075884241610765, 0.09914968788091626, 0.1568831724247762, 0.11624706722795963, 0.10191988851875067, 0.15139144925134523, 0.06150062954319375, 0.08477100157844168, 0.18530719434576376, 0.13280493659632547, 0.16891211909907206, 0.19395543528454645, 0.15699724773211138, 0.07739255071750709, 0.14199821757418768, 0.11721537741167204, 0.11124144654188838, 0.13942556562168257], [0.03254098564918552, 0.036505808255502155, 0.03586109820753336, 0.021680723942284073, 0.04384656310347574, 0.07090633269399405, 0.02979068983612316, 0.03678920179871576, 0.02720370892036174, 0.06441992468067578, 0.05417702127514141, 0.08010172391576426, 0.0803785254912717, 0.03048049532143133, 0.016128165015418614, 0.03926866714443479, 0.0327355827071837, 0.030328150639044385, 0.008816815330646932, 0.04751652492476361, 0.032083256103630574, 0.057018844676869254, 0.03688678531242268, 0.016665524038087045, 0.02913218517122524, 0.02963693719357252, 0.020552225211369138, 0.018721125521031872, 0.020257284698475684, 0.05216119551498975, 0.01180399365590087, 0.015420386833803994, 0.06115348424230303, 0.017082322654979568, 0.037500062225652595, 0.012270107349779989, 0.030428492397602116, 0.03454668766685894, 0.051192725875547955, 0.0226237502148641, 0.03783339594623872, 0.02173768186808697, 0.036728523804673126, 0.09101315734109708, 0.021928664030773298, 0.08348708440150533, 0.02101268246769905, 0.02142195782757231, 0.027222709597221444, 0.02632254807810698, 0.01970122185801821, 0.04192127427086234, 0.04039328804771815, 0.026911979574444037, 0.03547553086121168, 0.04590460052713752, 0.05080538076747741, 0.03043493508760418, 0.0207689221549247, 0.07275913363056523, 0.013203517084808221, 0.01161993170223598, 0.021722570893221667, 0.041221134697220156, 0.03926814467247043, 0.007987425862146276, 0.02031946225490953, 0.047724468766578605, 0.04898943446044411, 0.03494161879643798, 0.06677463118519102, 0.038784678293658156, 0.026313314912840724, 0.010881359905137547, 0.035961114269282134, 0.0277918817342392, 0.04039643984287977, 0.03978898476010986, 0.001327433536062017, 0.029299494943448474, 0.03021256559129272, 0.01443533888751907, 0.08546403010508843, 0.01652281285662736, 0.03211987324591194, 0.04199769427733762, 0.07076747728777782, 0.014214049958224808, 0.037749956494995525, 0.06057056837848254, 0.013971355793598508, 0.05190947259377156, 0.0671333862202508, 0.03930804931691714, 0.012047946502986764, 0.056364533358386586, 0.023250178833092962, 0.021435898329530443, 0.02599093783646822, 0.08170156699738332, 0.005609319229344172, 0.03496542859024235, 0.049123217817395926, 0.018688961264810393, 0.039897384122014046, 0.032798601647040675, 0.026125961216166615, 0.034460880128400664, 0.021017420338466763, 0.057234734163752625, 0.038677534221538475, 0.003940068800667567, 0.013170469884893723, 0.020165913172864487, 0.03957754985562392, 0.050037024675735405, 0.02186333298284028, 0.005600802766691361, 0.013762968359515071, 0.0446056571922132, 0.03193542367911764, 0.04409080856878843, 0.027714055463937775, 0.03715753435556378, 0.0180408093479595, 0.04085327711488519, 0.008908199578789728, 0.008019049834859158, 0.015057163645646401, 0.026256479123341184, 0.023011672077700496, 0.025753991711618643, 0.03336584335193038, 0.02287907276435622, 0.03081688584227647, 0.008192999072239866, 0.01757283222728542, 0.02056542271748185, 0.04975660311590348, 0.06890198774635792, 0.006042303450937782, 0.0477719628252089, 0.02228160571706082, 0.01691596283178244, 0.016561448640589203, 0.06903200184128114, 0.03444257664627262, 0.043125131100948365, 0.038842235026615005, 0.015129453070195658, 0.026328827919704572, 0.029217371850141456, 0.03177774910415922, 0.04039284021460584, 0.02804103131139917, 0.04618121550551482, 0.03153217710288508, 0.022132073562326174, 0.024297665571793914, 0.02352266662221934, 0.05825466729168381, 0.03151650633662939, 0.012743447441607714, 0.01853530531349991, 0.0053779578717824605, 0.004037704900838435, 0.03161462928567614, 0.015162504510954022, 0.033372733875044754, 0.03182167067591633, 0.01129948760249785, 0.025615290672119175, 0.03456273162737489, 0.029658551926591566, 0.005519607994106731, 0.08823978115937539, 0.033791522295879464, 0.03586702181824616, 0.03560000132503254, 0.03135951029668961, 0.0035381317970209886, 0.11165806025798831, 0.016703245496111255, 0.03750596208763974, 0.01551104080863297, 0.014422304229810834, 0.042359394154378345, 0.07213990257254668, 0.056920144973056655, 0.02176442462950945, 0.036117828717189174, 0.10281838423439435, 0.028968159508492266, 0.02024695061014167, 0.01296609004826418, 0.02154273197187909, 0.030264965458107845, 0.09351463097014598, 0.09620322420128755, 0.04140950280374714, 0.02944886085710355, 0.01865158077063305, 0.10366095509380102, 0.016674334815304195, 0.008500306734016963, 0.016105953171583157, 0.04217666806653142, 0.01209083161250289, 0.04152664169669151, 0.01489273425457733, 0.013480890326068869, 0.006221101669195507, 0.05127622978761792, 0.03475853308503117, 0.04770131715174232, 0.02395774836518935, 0.05423567384215338, 0.043769851326942444, 0.011325226980261505, 0.04827679966443351, 0.06524497576590095, 0.022786091414413283, 0.017415149170639257, 0.035729482769966125, 0.01721446056451116, 0.047822774920080385, 0.06058177099164043, 0.004637570993509144, 0.02662605848828597, 0.02029788144864142, 0.029978206381201744, 0.036829204830740175, 0.021166443591937423, 0.026861591563959206, 0.033583344359483035, 0.05009863904810377, 0.009041745448485017, 0.028844048668231283, 0.03447511579309191, 0.07021889529590096, 0.012701641202771237, 0.05805559190256255, 0.03304401079991034, 0.02764566252673311, 0.0487938467413187, 0.03849588021902101, 0.015235572554437178, 0.057154999513711245, 0.030144729052803347, 0.017878228964816247, 0.00905291159038565, 0.029038252175918648, 0.023207091859408786, 0.02313383382612041, 0.0117302555590868, 0.018009995376425128, 0.02101774773161326, 0.03960800250726087, 0.08886131245110716, 0.037445453727351766, 0.0058316174794786745, 0.04357530515907066, 0.013184552879205771, 0.03952497696237905, 0.04075997515714594, 0.05803828925958701, 0.04718996298366359, 0.06445550027170352, 0.02314088719763926, 0.02274487550104303, 0.03905498628903713, 0.06208210012742451, 0.009142102474080665, 0.03289478398593409, 0.01840546933401908, 0.030003159506512538, 0.023438548635957495, 0.05846995288240058, 0.04932350439152547, 0.05124377885035106, 0.07421891351363488, 0.04047070889334593, 0.017059930999364172, 0.013820966988402818, 0.011596570589712687, 0.030451253854802678, 0.033816349892211814, 0.016075307137465904, 0.028776276590568677, 0.020906505307980945, 0.025578013654532175, 0.040656722483358214, 0.06487040407955647, 0.03486990782299212, 0.01257769575542105, 0.00882331739246313, 0.021067974590031163, 0.05062748245628817, 0.06170860731175967, 0.0060581459713700625, 0.025673123908096125, 0.01843639017481889, 0.007534897287509271, 0.01038583426270634, 0.0634420607239008, 0.011255449831618794, 0.032034174273056645, 0.05461368230836732, 0.04534367259059634, 0.04967299403090562, 0.041919588111341, 0.025767993281728456, 0.03435154778084584, 0.030544372608086894, 0.05347547713401062, 0.030935833031045537, 0.014597496882613217, 0.05562923888542822, 0.009014656634203025, 0.013243930630518921, 0.02964314239631806, 0.10307101639253752, 0.055435829263712676, 0.03501363850331732, 0.08348973747342825, 0.014967744604551365, 0.0172544788635735, 0.019822498118238788, 0.0056291523838548786, 0.04832694000963654, 0.01280617800408176, 0.05022381518834403, 0.024441236796389734, 0.08232681666101728, 0.07324947017644133, 0.035572693683207035, 0.051872916519641876, 0.03883854379611356, 0.025497926166281104, 0.04465218773111701, 0.014330654504841991, 0.04057879273646644, 0.027428449896563376, 0.06403004524431058, 0.026945029318864857, 0.09751843541328396, 0.016569194117827073, 0.033919188659638166, 0.0504118440273617, 0.030119195780051605, 0.02452685943405543, 0.05406258295157126, 0.15686363061623915, 0.18400598131120205, 0.11389218430433955, 0.12965585557477816, 0.09637008953307356, 0.24364393044795307, 0.10873024950602225, 0.1335017377776759, 0.12451891122119767, 0.13399371637829713, 0.12329088497374739, 0.1390600252364363, 0.21701443009078503, 0.09226385344352041, 0.08487730765981333, 0.24054180404969625, 0.14132958916681154, 0.17058021601821693, 0.10844711041344063, 0.09917473939380475, 0.11086986040962593, 0.29906827211380005, 0.16441853450877325, 0.16859251553458826, 0.108683084536876, 0.14446321316063404, 0.26376610355717794, 0.07485755067318678, 0.06854584507111992, 0.13108669593930244, 0.1512020429862397, 0.07485450405095305, 0.13875555300286838, 0.07196585155491318, 0.1137633847870997, 0.0913010122520583, 0.15385093513344014, 0.13333793942417416, 0.12914372448410305, 0.14719139891011374, 0.13649058953991958, 0.12202600070408412, 0.13088844157755375, 0.3552676907607487, 0.21595953883869307, 0.11452821588941983, 0.08992319939924137, 0.06899781046169144, 0.1578200664371252, 0.11671752269778933, 0.10908135745142188, 0.1448885053396225, 0.1592077791158642, 0.121276124513575, 0.14533074732337678, 0.11540986358055047, 0.09703557632331337, 0.11829092326973166, 0.10187146825981991, 0.11806281336716243, 0.061866862034159045, 0.06539494557572262, 0.11574922608477728, 0.13946270862860338, 0.1071792948724968, 0.10776008013635874, 0.1247231774032116, 0.10727321090442793, 0.11191683315805026, 0.0946261120427932, 0.22968670938696178, 0.15132199440683636, 0.09555580001324415, 0.21773256441312178, 0.12509310112467834, 0.0947762718424201, 0.11922074694718633, 0.12991717298116, 0.090469698288611, 0.11536357392157827, 0.1325146864567484, 0.07654995950204985, 0.2648136802017689, 0.18352979900581495, 0.09082615308995758, 0.1569778552012784, 0.0914008654654026, 0.1324008418513196, 0.08727340480046612, 0.123184042849711, 0.14545785050307, 0.15991414764097758, 0.1562807418938194, 0.1092291423784835, 0.11249874479004315, 0.11583911840404783, 0.1432011244552476, 0.13516945471721037, 0.11298565473407507, 0.13947116317493574, 0.09981045206742627, 0.13738460013908999, 0.14543532314045088, 0.1571011178727661, 0.14282913798732416, 0.14684928155371121, 0.12260640598833561, 0.09687111300549336, 0.06524393760732242, 0.19559906423091888, 0.17644050584307738, 0.08187129574694804, 0.09782384402517762, 0.08682557847350836, 0.12358218005725316, 0.06434344021337372, 0.19062465615570545, 0.14046885392495564, 0.1359172681612628, 0.0921618424888168, 0.05438490744147982, 0.14324621989258698, 0.10223403666168451, 0.12062074110976287, 0.11310066641973597, 0.08073903793202979, 0.058837114966341426, 0.1394929712904351, 0.10335672713283982, 0.0889613488689065, 0.0998391540987151, 0.1620872374624014, 0.12688766340059893, 0.08110810669937304, 0.12139370106160641, 0.11667102947831154, 0.09437922029090778, 0.1291950081608125, 0.10450408913727317, 0.10520165027784449, 0.0678069679332631, 0.09505050177020685, 0.15764359304947512, 0.10349702103329556, 0.1140662149659225, 0.2184782201158149, 0.1540471538901329, 0.09909325412341527, 0.10652919725647994, 0.09530549523021493, 0.14619841719312326, 0.130939426698855, 0.14568129208471092, 0.10119281789021832, 0.1098764037181224, 0.10641611939562218, 0.12415950479251997, 0.10324730657573257, 0.1399794944695064, 0.1078053248514022, 0.20414701769394533, 0.19177592652184622, 0.0976336778008512, 0.08355757740459271, 0.08570246731064149, 0.11171602071928126, 0.13485084181385382, 0.18936731719544955, 0.13058022383068288, 0.25075001056705204, 0.16808402139161313, 0.10948786778109414, 0.21836684537785395, 0.09711145010909863, 0.09338782634586096, 0.13113161495753697], [0.02913238194638065, 0.03617010984037604, 0.036856705855045996, 0.012736944531622742, 0.03604621613132102, 0.0229076747117298, 0.026408581229458963, 0.04605304024049214, 0.04205924758155431, 0.024880427068897655, 0.0459991408112858, 0.02720961387136153, 0.05560458092285054, 0.0746985970597182, 0.0072836408591164005, 0.03706044277974537, 0.011705975879782012, 0.0781384574781571, 0.018150969508237073, 0.048916312134159465, 0.028788890556565354, 0.041862950793334415, 0.039582737255841494, 0.053684445563703775, 0.02515833465648549, 0.04953207927090781, 0.0373587878420949, 0.03826636574896319, 0.03517292799162013, 0.008022587546812636, 0.006325017610963966, 0.01759936803552721, 0.02158221253193915, 0.01418593740423343, 0.038978125234799724, 0.022289637875344073, 0.06552633709673371, 0.07294311161552157, 0.025742895967726196, 0.07393346740198986, 0.03423189152298229, 0.025288423390260766, 0.045515850851578374, 0.018868109776771495, 0.04122336029208132, 0.045194489881396294, 0.059078402018972805, 0.03223030482019697, 0.02042153597410236, 0.02518347098625132, 0.04883587180769869, 0.06882215810141393, 0.04252866150013038, 0.032498003848429234, 0.02034642723655062, 0.07125939482024737, 0.03671822364309004, 0.010089613863133957, 0.056406415932412655, 0.02302363295374172, 0.019075965409034064, 0.08809502249849693, 0.05287906520866922, 0.017308213748037815, 0.08240389145378556, 0.012459877479289259, 0.06931918500257389, 0.04595401823254568, 0.011874940429281975, 0.05553317189748798, 0.06593341061047145, 0.052825348983917914, 0.021635762515610883, 0.01844759109163923, 0.018790419213473797, 0.043892611882516315, 0.01934579842989998, 0.04516585909628442, 0.039189000347895284, 0.05188225994684866, 0.017411876935511827, 0.026073395108271922, 0.018624081442664777, 0.007878295378759503, 0.026137006069932665, 0.07298140813197408, 0.018906177287655215, 0.034148821873324256, 0.022655643057078123, 0.0961081071623734, 0.03954345686361194, 0.037872024944850376, 0.05002659898517387, 0.038371592959655185, 0.05326318388272609, 0.03942312207072973, 0.08900875132530928, 0.05797777072127376, 0.008581705491191574, 0.03598243723224316, 0.02321415031994028, 0.01872209582610854, 0.036085727225456915, 0.03200548241979309, 0.049726815428584814, 0.032084565676216564, 0.054406986970986636, 0.014957746391051581, 0.04088591125660709, 0.007988694722631147, 0.03580404019781521, 0.07849628292024136, 0.07083850633352995, 0.03214128781110048, 0.022964400239288807, 0.10232633778027125, 0.035512622978006086, 0.02381999557837844, 0.020219033983136927, 0.023762727222804512, 0.014969944754349334, 0.0892694919769253, 0.022003299490149533, 0.05026515832703028, 0.02712703955226711, 0.022284245218283365, 0.030391919360096966, 0.010237918717653623, 0.01705983091544892, 0.005250341125896999, 0.060852072201669216, 0.012662562674709728, 0.03895269713497587, 0.03794007522187062, 0.02347867889329791, 0.008971886027471294, 0.06356748792209796, 0.0403968266078404, 0.06595869282526629, 0.024603647545778325, 0.03767476124422891, 0.060309997360621176, 0.03751703577914408, 0.014280359792922224, 0.09515212595994983, 0.02838271949440241, 0.0311172868657325, 0.041141094706420384, 0.03603102033957839, 0.026837540890223215, 0.013260267209261656, 0.022492362086528113, 0.07026156836322375, 0.03219164528750947, 0.06906123312988452, 0.01823794243058988, 0.012254764824839575, 0.06559348492217915, 0.048963772266038826, 0.0196763518532472, 0.04328600496851972, 0.04240206382902605, 0.0339553172567061, 0.06023265793919563, 0.05048114959416645, 0.002155763005638229, 0.054057263237025054, 0.016090540248634558, 0.044170902842389684, 0.07366650458425283, 0.05159748558487211, 0.037713122221508195, 0.012262923360270048, 0.010853339801542461, 0.030464617601994957, 0.11478814908436366, 0.07330138489071812, 0.009907380561344326, 0.043094620773834844, 0.022485982161015272, 0.04954885944191899, 0.012745208239981105, 0.03364575940317341, 0.056454571562686136, 0.045699370825397115, 0.014516603634027498, 0.09841947563524757, 0.055479699945343394, 0.054205974364387136, 0.07695878363613572, 0.018056680282045687, 0.01631705050489732, 0.026364522254360572, 0.04631864259551678, 0.040670025162398815, 0.018756904672565203, 0.007887687151586371, 0.026495094444336634, 0.055724695191851685, 0.011975483203838979, 0.04240127333572932, 0.015664939336212616, 0.020275805311809694, 0.05820927329893623, 0.02643379389441439, 0.019468589519549693, 0.06992211086409432, 0.016971078535009707, 0.048133733948426585, 0.05270861042663455, 0.035907689814588854, 0.03482213217232909, 0.06070230595235314, 0.04014208420578923, 0.02172703226096928, 0.03851149330980011, 0.037981421753231964, 0.06352535768279008, 0.07203839373375688, 0.04182278152023043, 0.00615902801343639, 0.030559592148555175, 0.04554598119908145, 0.021171267975920012, 0.03562437769557748, 0.05058933182486466, 0.05678357283717819, 0.03256101939561112, 0.05499766527542046, 0.033931120697941096, 0.09353740260537181, 0.020744379543300186, 0.007909230638428457, 0.05253943807578512, 0.06768895033746958, 0.09608503697173935, 0.01747676184667008, 0.08193045721522399, 0.043863058289779086, 0.028714448479669433, 0.011078836496121116, 0.058913816564849446, 0.024295747014028684, 0.06608268152922392, 0.06538154450910431, 0.027553130706240023, 0.031293220818042755, 0.021751970119242157, 0.036551066541246006, 0.019771923510623828, 0.028567844203540256, 0.01249690174258181, 0.018048766867390702, 0.06703613858137812, 0.007068897672330162, 0.03774844336190394, 0.06830732644136463, 0.025388924604547874, 0.08421792768474136, 0.07282480224967003, 0.02407165234243231, 0.03221332787403038, 0.04335501876526645, 0.056864077624465735, 0.013075885495969226, 0.074869784659573, 0.004873911101770188, 0.0327577741949686, 0.07782238908112049, 0.03562349220737815, 0.0146253168183778, 0.0239605846415673, 0.041827551621411524, 0.1277331044631345, 0.02951866514714701, 0.029881108020033156, 0.018304118254621114, 0.037113935087940524, 0.020800840442201922, 0.04232404247990676, 0.05050143100587385, 0.01538263653804149, 0.016844753974250386, 0.023624798016888753, 0.0513542036392859, 0.02776894555427134, 0.05558267781244857, 0.06871254076915127, 0.044641907925584486, 0.013207684137991496, 0.013862990358445262, 0.0744626432923334, 0.011551264806517532, 0.016072625227804695, 0.02227529025237475, 0.014192977205051907, 0.08299317197608096, 0.0636860958433577, 0.01453648810274899, 0.086174625903368, 0.016379857402560965, 0.002356115948974288, 0.006381134153343737, 0.054335655977151225, 0.01308102794324181, 0.00913951640749084, 0.053205213243407865, 0.04281309659459761, 0.04330044758639165, 0.047683536141578636, 0.018353664881682823, 0.04153299617714115, 0.059013038740626404, 0.01901938746284161, 0.049290368133889775, 0.009477426846777754, 0.02653030871546694, 0.0064051771935607705, 0.047782595468951125, 0.021244634574811374, 0.05452246684581041, 0.011288551314334785, 0.05684474616178444, 0.04294992657378316, 0.03257791152490037, 0.05185993275206004, 0.11274249492479221, 0.04113084204228861, 0.02330569826465632, 0.0071173633082902855, 0.07155997226280825, 0.02885730724249567, 0.03621468959110124, 0.02821151662750968, 0.009462603401126606, 0.04993033522207822, 0.03561470178621156, 0.06873424710439784, 0.022975706329037036, 0.028327873508845056, 0.03727365205330508, 0.03731095451595528, 0.011836866133048065, 0.02122254147460418, 0.01374935609887221, 0.05089234181546739, 0.03702539983870728, 0.02787043234067304, 0.04251883292038526, 0.019956442627257535, 0.060342621324317794, 0.05096054137019174, 0.14737974666059017, 0.12237164644258362, 0.16932673113686697, 0.0856223391102893, 0.11417435987719468, 0.07951781060546637, 0.12997274499918732, 0.13560801904116357, 0.19363447465002537, 0.09519012392099414, 0.168858121282288, 0.14624953802142823, 0.17052334121295384, 0.2393233451460089, 0.0850610142307622, 0.17263975978962012, 0.05430616684524076, 0.18567905867738382, 0.0925182905048132, 0.1569704727402755, 0.08189599442162684, 0.1803337905023779, 0.10431926976889372, 0.1515317295811006, 0.14924375021031924, 0.11666895316115447, 0.13458887301385403, 0.18837490544787475, 0.1263037161635501, 0.06859283362116132, 0.12075985435928617, 0.13666733434157713, 0.10341239414576973, 0.11420113486903054, 0.08676808620137827, 0.1849940097225564, 0.13461361240063394, 0.17366533832890646, 0.1363930297749383, 0.14376500062644482, 0.07936841076506035, 0.17000622967524187, 0.23859044590166636, 0.10453075556350605, 0.11592840004180159, 0.21168721094727516, 0.16082147109721387, 0.08453533958111491, 0.12325931952467986, 0.20811255276203156, 0.09729795224432435, 0.15243682744247572, 0.15895528266472475, 0.15480809020144598, 0.13356300948985986, 0.14576682820916176, 0.07448743696191482, 0.12450223283043929, 0.19251008784132345, 0.10978693887591362, 0.1232382170855999, 0.14468850035752567, 0.10414207034877368, 0.09644510836473533, 0.12251094968191215, 0.15464421042374202, 0.1176793732281242, 0.14631580375134945, 0.0984005309375269, 0.21686621090131147, 0.09518379997462034, 0.1138034997774022, 0.1316304196204458, 0.15714842533426626, 0.13891751931181975, 0.22564072720706463, 0.1051041583663651, 0.15719324935759815, 0.17309063273881162, 0.08936446652348552, 0.15753483745668614, 0.117913725652865, 0.1334009753274066, 0.15894587816936628, 0.12355829562459673, 0.1629274266638926, 0.14504964383585112, 0.10984705707856587, 0.2081692104360887, 0.154630965420178, 0.14106827176042966, 0.09913910273462534, 0.19356545406792844, 0.13091415805476053, 0.07959006101425205, 0.12750336607652052, 0.14562004751392774, 0.1740886898977416, 0.10012127538876874, 0.09176029225013085, 0.12090830425066607, 0.1313448106603963, 0.09331313321100813, 0.11615828770611968, 0.1385407152452639, 0.10701268059866768, 0.1155150229377406, 0.07380554998027426, 0.1616963877209595, 0.1263192274740764, 0.1299875234918935, 0.15197034818785532, 0.24014469821538242, 0.10058247564094407, 0.0698856735335929, 0.1446076596954039, 0.14470714649983815, 0.12456677508141313, 0.09123823419213295, 0.1030243399686047, 0.23511604805077824, 0.15099172427185945, 0.08073869866452046, 0.18905124201306275, 0.0904367147013545, 0.15188241004943848, 0.0908069641196302, 0.11360033282211848, 0.12320495529898576, 0.03550930154908981, 0.1963623889854976, 0.0911747979532395, 0.12239061828170504, 0.10451809410005808, 0.13561556435057096, 0.135924989889775, 0.09589325583406857, 0.10372912072177444, 0.2033536745501416, 0.0930807146110705, 0.09297541276152645, 0.14619454954351696, 0.09720124743346657, 0.08429136552980968, 0.18005985234464916, 0.07785956601479224, 0.17518750950694084, 0.09645255867924009, 0.16682471467980317, 0.10105816940111773, 0.16353951953351498, 0.13342781817274435, 0.13611468113958836, 0.10767537860998086, 0.16470801111842903, 0.14790580128984793, 0.14808213897049427, 0.15832459793559142, 0.08402648581457989, 0.12332098478717463, 0.0931435130270464, 0.13021020511431353, 0.10406763505722795, 0.07554616872221231, 0.10045056164796863, 0.08933761010744742, 0.12453519606164523, 0.15575759139444145, 0.10550294696752514, 0.14083486928471498, 0.15459071472287178, 0.0988345897889563, 0.07292137813887425, 0.10108681036425488, 0.11551932484975883, 0.22615413394357475], [0.14834037582789147, 0.02049092635778444, 0.04818029162873115, 0.045249566568859985, 0.005657392587246639, 0.02544065272169454, 0.03427815743322883, 0.014465392899832554, 0.011356241967795151, 0.032345408108085394, 0.05567798484116793, 0.03493546787649393, 0.03683344906728182, 0.02473613659718207, 0.048045850092811246, 0.04548875355560865, 0.037733193287359815, 0.011774708932664777, 0.036401927936822176, 0.010979787346773913, 0.06767085380852222, 0.05110031619135823, 0.040436911064067056, 0.027685177013544098, 0.010291214250693364, 0.06632960042251007, 0.022508131240361502, 0.009150615544058383, 0.06644191832414695, 0.04742140110049929, 0.05841771925666502, 0.008526642374428255, 0.04259970750925796, 0.10114839420254741, 0.03961295920557209, 0.025807070113452416, 0.028707479925027916, 0.07398850337735244, 0.01416212591409151, 0.017286018867577826, 0.06989997026643582, 0.02891026350802609, 0.016205735138750503, 0.040758719867361445, 0.03034047962033323, 0.03518192536596741, 0.040221303169216426, 0.020623194885307124, 0.03465804883411952, 0.042433890514075756, 0.0705902303702065, 0.03552116234121578, 0.019767687755769918, 0.029088178782590797, 0.06428410232599292, 0.015139858404706632, 0.03137668741068669, 0.05755454807409218, 0.026186735901449407, 0.013560330661545907, 0.047260425452675135, 0.02409751300833055, 0.034803435139890225, 0.03849734924733639, 0.024159768596291542, 0.045278095573719056, 0.01817778860484915, 0.02958595546494637, 0.01059521405425455, 0.07173544141863074, 0.04167231298717005, 0.08302534810666527, 0.06710543736283268, 0.05926930106111935, 0.038490713174854, 0.05233501922339201, 0.018058408850005696, 0.05368516820349863, 0.03824752961684551, 0.021211192976417284, 0.03910498074921114, 0.008974478031242532, 0.07907830990318741, 0.010208051302470267, 0.01759022138347583, 0.05190747770081673, 0.006399433818712298, 0.023167251675788845, 0.05207599865804825, 0.058956951035984924, 0.01579522654148085, 0.03145882407469409, 0.019863188166969588, 0.0656064177996346, 0.03416568686121276, 0.046012684370258024, 0.019344039327864136, 0.06045106479099818, 0.0342557318508625, 0.03569853478776557, 0.07726408368242638, 0.044028712436556816, 0.04109330887773207, 0.041623492392578294, 0.033071566107017655, 0.02681584982201457, 0.05573334312066436, 0.02233041443728975, 0.05132329636918647, 0.0433949064463377, 0.09253227511154753, 0.03439847526273557, 0.026583295515073196, 0.041230708826333284, 0.030948080588132143, 0.028188095295003483, 0.0862128274249179, 0.1040360831788608, 0.023022465873509645, 0.021568981099075506, 0.018907006796715514, 0.02048046504413443, 0.052680990658700466, 0.03428647287988237, 0.04725932622594493, 0.01800338814168104, 0.06887555880738155, 0.03762031898700765, 0.04610286506691149, 0.10414687437670571, 0.03424587952239173, 0.036300622658537965, 0.004565746789532048, 0.08436495943793229, 0.03196193743497133, 0.013696262430000519, 0.04885346282805715, 0.0667590723772134, 0.016835359656917195, 0.09898352822554962, 0.03485802328214049, 0.0890289173860635, 0.07452865117894751, 0.08610356293086495, 0.06685952270137412, 0.013450284155883958, 0.014208485122903116, 0.061796056904963086, 0.029747477333460535, 0.037661974251802476, 0.024842459641929184, 0.04001499120412128, 0.02606812458751457, 0.056224992631801536, 0.07079729890184742, 0.010438339302449353, 0.1000871586480311, 0.0486882700850921, 0.007731719092199845, 0.016805190293650542, 0.032553959238742075, 0.053352031258067915, 0.05660325215597238, 0.08402883354574442, 0.060455712755875926, 0.022393708183829273, 0.04177558940968343, 0.09131555325750794, 0.012914082883591098, 0.058981514003659995, 0.01406544485195939, 0.02414415550551244, 0.00638919387711212, 0.006658383561963481, 0.050420624270503006, 0.014793649482141649, 0.023101031746981398, 0.018487960532573715, 0.04535957405875836, 0.021981945993112664, 0.0065054277739753676, 0.04761641545753394, 0.04392704753471272, 0.07085962234331028, 0.06375300618154661, 0.03172732038157327, 0.0413355221306639, 0.08484732998268944, 0.042579432882900746, 0.018371459462546876, 0.029599207253860574, 0.029874967278114388, 0.01772276811035616, 0.06178116984665394, 0.07005262707493135, 0.03301167521359665, 0.05144238265763436, 0.01867841004527041, 0.04861681016960314, 0.010926602075674703, 0.009854884851457817, 0.0677304563245603, 0.02527877122962049, 0.027013369669605578, 0.054580987098493745, 0.02126845285030348, 0.031645017476486306, 0.03468659819502916, 0.002754209263782416, 0.01162906308724944, 0.06613229600978748, 0.00871720299723425, 0.02661284401879779, 0.029359392622219663, 0.05234939738043717, 0.003791347495280206, 0.02433114788228912, 0.0256187664677522, 0.023896610663671578, 0.025548407475331, 0.014229331415013542, 0.007100019953213632, 0.02077451328347836, 0.03199726875339236, 0.05862262326159647, 0.07067792423601661, 0.04667208470138056, 0.06932117989552872, 0.013317026663571596, 0.04038752389273473, 0.020604384198252643, 0.0348908508063427, 0.06232224724122456, 0.016659052510346686, 0.030956097479377474, 0.022465432727975503, 0.030580558880631412, 0.04012827601815973, 0.02436439779454044, 0.0013295107013878546, 0.05730201091085162, 0.036432339876357994, 0.06238482174064432, 0.013085035540695702, 0.024841626740193794, 0.07928825542330742, 0.04646882275119424, 0.042035695631057024, 0.032119157391467264, 0.057628732307681015, 0.04590050556829997, 0.03236572005386863, 0.074572986657066, 0.012760574513647174, 0.07336694494421993, 0.02002078471040087, 0.04226395481133035, 0.03511040098965168, 0.06251809280365705, 0.0494519103584545, 0.07482270111462899, 0.057264888259981356, 0.08445996112589325, 0.01437193657537656, 0.07765477736081396, 0.024359877054978694, 0.016064462451530353, 0.07284682071102516, 0.0385912245671664, 0.029794493024902682, 0.015166585899091192, 0.09469297488353082, 0.010028963858660842, 0.032631990765886645, 0.016829537826457193, 0.011222330537358565, 0.011648665963938194, 0.0491354280550565, 0.010463345862392868, 0.03005912507485066, 0.03202688341428127, 0.016081732864092504, 0.01527828463752355, 0.03792780730873346, 0.03313189804820078, 0.015699539533151046, 0.011479111088972007, 0.03498149969215904, 0.030642705902989422, 0.02165277847754104, 0.019128577318042517, 0.02650099091364869, 0.07449802889355592, 0.02207051686543439, 0.025926047836297324, 0.01583726178588612, 0.026131258878324713, 0.03056588556085314, 0.06722930393048696, 0.0905165918437498, 0.003202758230535047, 0.016000513918697834, 0.02117856901272067, 0.031434406992048025, 0.011357577833613115, 0.05381126715136426, 0.016479771684056947, 0.10296568061624255, 0.010642659767264766, 0.07318948089544262, 0.038054218382707665, 0.022424415286098207, 0.051379204262048006, 0.03767214549173202, 0.035563862549939325, 0.1145192456564733, 0.003540281904861331, 0.037708090884344916, 0.05992595332541636, 0.04906978997002755, 0.08702095584677798, 0.0363297759156142, 0.055133443525327105, 0.03653356033776488, 0.03164843050763011, 0.025674309648041214, 0.05049906631133386, 0.07927216735801526, 0.03203024894797376, 0.06004529406449624, 0.03612413230751242, 0.0428966412187687, 0.06683612681393113, 0.06182800911899124, 0.03819443425163627, 0.01315373381865876, 0.05783527836735759, 0.011167487944476306, 0.013139360750626241, 0.05426205528367843, 0.00990544249569731, 0.07424696415130581, 0.03487909518714462, 0.052730808699769635, 0.03948125895112753, 0.0599051969391959, 0.0703995009618146, 0.054115875091935904, 0.0015702257702027314, 0.010661278768176479, 0.012348226238308209, 0.024873641718711172, 0.14271325777683938, 0.16253331995436124, 0.1063028515449592, 0.1540492166365896, 0.10881728519286428, 0.12157968751021794, 0.18221383461994783, 0.1849969681352377, 0.10879861190915108, 0.10757528790938002, 0.11397352708237511, 0.14126970166606562, 0.11477429339928286, 0.07613238905157362, 0.151486335588353, 0.13512152300349303, 0.08821774234196969, 0.08497781905212573, 0.15850788381482872, 0.1321097638990198, 0.13010006531008653, 0.10266061127185822, 0.1967578934771674, 0.12400619659040656, 0.03186985005491546, 0.16520776573036397, 0.1428905725479126, 0.0860633190189089, 0.12102996557950974, 0.09032076663736786, 0.10555636802954332, 0.0761755235227091, 0.09902105121208088, 0.15006677247583866, 0.16821959268833908, 0.1455571608883994, 0.10973621838326965, 0.10598602318870169, 0.13516775837966374, 0.1803401687315532, 0.10364641408835139, 0.06965292923684631, 0.1074151061475277, 0.14629521699888365, 0.13862372721944535, 0.10163336353642599, 0.11957311018237046, 0.07424696415130581, 0.13528369287295, 0.18154350987502507, 0.21451339072414807, 0.15134559385478497, 0.11488504388502666, 0.14816587019179547, 0.1666501819023064, 0.1400507813585656, 0.1535867950213807, 0.06603707719062056, 0.12040385417640209, 0.21489601662116392, 0.26779310032725334, 0.13530695305338927, 0.13508009165525436, 0.1279840674251318, 0.1590914646429675, 0.12555997392960958, 0.09813470127327101, 0.11427011473902635, 0.12387020460196904, 0.14741986165089266, 0.16349242920322077, 0.14887510213468755, 0.11573636106082372, 0.20249076799622603, 0.10254551816199507, 0.10790461488068104, 0.14591020265860216, 0.11921331020338194, 0.1151201698396887, 0.09203309046902827, 0.16368061410529272, 0.10195060579904489, 0.1268669952239309, 0.13350035356623785, 0.14975064301065036, 0.15225899698478834, 0.15794132064495767, 0.08190125985337154, 0.13207408652773925, 0.10015655920973845, 0.06419601490987198, 0.1370910116072212, 0.08630807338548557, 0.10487669985741377, 0.06913839613220521, 0.13895768858492374, 0.09902098335857902, 0.13284264957266195, 0.0995629360633237, 0.18673982604273728, 0.10511432960629463, 0.15395359748176166, 0.11984693977449622, 0.13266950100660324, 0.1303374304303101, 0.1302836226033313, 0.14818288785006317, 0.10017138519989592, 0.077025415774967, 0.10719444655946322, 0.13594484382442065, 0.13234744114535196, 0.07767897391957895, 0.17116619886032172, 0.11448312045208045, 0.1478522920182773, 0.12588021531701088, 0.1549830843827554, 0.21191623008676938, 0.08502461082701172, 0.08693368267267942, 0.13924538743283066, 0.20004641344504698, 0.20454025587865285, 0.1232233571686915, 0.0583965964615345, 0.1793704064829009, 0.15630506058888777, 0.15056693420878478, 0.2611484240208353, 0.06608186728720154, 0.15904294938913413, 0.17497740792376654, 0.23410310383353913, 0.07896574772894382, 0.12688167872173445, 0.1817696520260402, 0.14932799711823463, 0.13611081348998205, 0.14263946030821117, 0.05952006046261106, 0.22797541692852974, 0.1549693372632776, 0.13695240047361168, 0.3291933813265392, 0.0825556797374572, 0.1345627765570368, 0.2335252905530589, 0.10271417482623033, 0.13289383825446877, 0.11547714711299964, 0.12121554490711008, 0.13334946094879083, 0.11779424920678139, 0.2031285094895533, 0.13469453448695795, 0.26509130958999905, 0.18697219714522362, 0.08898066676088742, 0.06146227874393974, 0.16938979418150016, 0.09422013097043548, 0.08201306206839425, 0.15637237126273767, 0.12452153036636965, 0.15978791298610823, 0.11399483308196068, 0.10243898137871708, 0.16237758259688104, 0.1213708615728787, 0.21667812099414213, 0.05968006580535855, 0.1279036338840212, 0.08721879630216531, 0.10446829641503946, 0.08658107516488858], [0.01932449751932706, 0.03670970802860601, 0.02949785108544997, 0.06314648408442736, 0.08573823967682463, 0.08117155650896685, 0.04777951491996646, 0.011214165216577905, 0.04523534447486911, 0.008802125047493194, 0.01974264472456915, 0.017393760050513914, 0.05198311399934547, 0.04647068872249552, 0.05728546144174678, 0.08831344970635005, 0.03297082740547402, 0.021426429373345206, 0.01551747162427221, 0.022186719380053024, 0.09959013174687113, 0.03039174633366721, 0.005246411559970251, 0.03239757727299418, 0.016723684667210494, 0.0050129891522893944, 0.04328363009595445, 0.04756029721881662, 0.020054423083950366, 0.047300615081829686, 0.019444601610302925, 0.019083610802356685, 0.035363409734730206, 0.025636018220601336, 0.02457452821545303, 0.015116187710581082, 0.018043694818126302, 0.019310875928827693, 0.00668769415434716, 0.027209917515782372, 0.04297972443912711, 0.01568653540951865, 0.046925748232752085, 0.07009590403842074, 0.026168805613581623, 0.04507112203698073, 0.059347570075520446, 0.017245276232383082, 0.04013673056449209, 0.005350189250228661, 0.02498474164998957, 0.03372601991785424, 0.05180597225470202, 0.04849495206560407, 0.08367207340363945, 0.018997747284759368, 0.08214681489127022, 0.055558868018644195, 0.04857432709208556, 0.009743745904415846, 0.019007899864975895, 0.03428589612511652, 0.039245983718761375, 0.04712458274194172, 0.054920285141893795, 0.017479606604735767, 0.027823248711813773, 0.0061362563782105485, 0.08892288271869932, 0.03374855745849865, 0.01781181226085339, 0.038737696528966935, 0.02652158954047731, 0.021017464443242977, 0.02599281568213233, 0.05056042962574533, 0.04810630417029772, 0.010469930196580077, 0.04200577902208481, 0.015100686578080058, 0.1331438376967396, 0.04379122857270496, 0.021933620729084526, 0.03748482572180884, 0.015582885792745011, 0.04273072922868388, 0.00448622290943084, 0.015122024808079004, 0.06631584651768208, 0.011013298495007413, 0.06506248377263546, 0.06592011132410594, 0.026658185425081422, 0.031348911579698324, 0.04152075879807983, 0.002818804101220199, 0.02872996996822102, 0.077664894317942, 0.0944822286920888, 0.022371245282036916, 0.016899589781782458, 0.06506981873618704, 0.02045216504484415, 0.036218706518411636, 0.058292047785861154, 0.06124813987740448, 0.022361111361533403, 0.020968777859317403, 0.05197068663047893, 0.025638043647632003, 0.0996689096625362, 0.05306140113888042, 0.020088265018005456, 0.04257452707471592, 0.0090807484895257, 0.03061357300196375, 0.023982540338433216, 0.06157555337995291, 0.012176044584651078, 0.004700472461991012, 0.059888403197484355, 0.016228910502312437, 0.019306682582412447, 0.05489776117194976, 0.08639453910291195, 0.021054454779784595, 0.04211714018934539, 0.03591300952913506, 0.04066580806725791, 0.010828257754578121, 0.030414446722716093, 0.03270591715616839, 0.060806834271975925, 0.024786989404154674, 0.0306672654779894, 0.05051640627373542, 0.03620123424168144, 0.030064655135252645, 0.03871042620656746, 0.037742153342281065, 0.028821816468345265, 0.024243655880647044, 0.05128262158749359, 0.034783306398562024, 0.036962102699492655, 0.03802175387474043, 0.02807615228396441, 0.017452802775161605, 0.005043935862236789, 0.02358806721999177, 0.012553010651442622, 0.02180375251919031, 0.030600233003497124, 0.06402068146105323, 0.05538955656811595, 0.04449252165587885, 0.01592743060817676, 0.01699575685363795, 0.0336220683529973, 0.0378884794190526, 0.020827625612063066, 0.06505864326442991, 0.03192717608596597, 0.01583227964251169, 0.054124275355466774, 0.06341004065637078, 0.03474823970879827, 0.018862998711743524, 0.022652764372261505, 0.024087699695623348, 0.07519943054233279, 0.011453358140507979, 0.06568783521652222, 0.06554985512048006, 0.04976273028712187, 0.016539584545950805, 0.060096876296613894, 0.028603748884052038, 0.005238730119474764, 0.04376557994900005, 0.10404721115316663, 0.045223561714270284, 0.0013946205893132302, 0.02698694073062922, 0.008735299526181604, 0.04604995969150748, 0.041732366728995524, 0.010984828861962472, 0.011060701799578965, 0.05850776085363967, 0.0654303515329957, 0.05342090256246073, 0.028094560939020345, 0.059288021842283864, 0.03279473399743438, 0.01464196467506034, 0.0454864160024694, 0.008346900144325835, 0.014128082964037145, 0.04294481720509274, 0.050810639413871934, 0.013914250286429055, 0.00412441065002765, 0.054801399021276405, 0.024580959031092267, 0.022527091205120087, 0.05775140465370246, 0.0362682260040726, 0.08219158463180065, 0.013836333262068885, 0.03112801111170224, 0.06413495354354382, 0.035465200165552754, 0.026769906215901886, 0.00537103766276102, 0.018477307532780936, 0.06729450436042887, 0.01781955943442881, 0.062413686620337624, 0.017085503287879483, 0.042504827957600355, 0.07371395453810692, 0.036085859539785554, 0.030169007035770586, 0.034633964233632596, 0.03328569479552763, 0.04130880142162953, 0.02557733342317598, 0.07326555824173347, 0.03044903843796679, 0.01443350175395608, 0.0270713182565357, 0.05614925455302, 0.07648299488105945, 0.03636947021420513, 0.08052930275776557, 0.01914280280470848, 0.019219039606728723, 0.04651654072638069, 0.08151884430221149, 0.06588598779801812, 0.00516016933501565, 0.0378178405309362, 0.025529082797999893, 0.07418404359902654, 0.01341010385658592, 0.003828778879583946, 0.025169445667415857, 0.035218274486916404, 0.04792682487251503, 0.030554611701518297, 0.12063051201403141, 0.08662575669586658, 0.05212568438478878, 0.03006926578070436, 0.01752075127192906, 0.06782801608954157, 0.025057894510350058, 0.051747570745646954, 0.03146041863198791, 0.058029502231095514, 0.07942487166396209, 0.026499075748558556, 0.02703048232277589, 0.025925364212266037, 0.05651008251256176, 0.02261482917570642, 0.08535064690347229, 0.04028156725689769, 0.012445933584656035, 0.06007525817091976, 0.051892926517341814, 0.016351903456130197, 0.09960007228489433, 0.025546946928703358, 0.04163624545825379, 0.03133152411984546, 0.019433064818648354, 0.0038092616679412977, 0.03925046204988446, 0.06548776238092355, 0.08109577093273401, 0.010284615497637008, 0.038134061598352025, 0.010549810731650462, 0.05530180163415415, 0.01711869382831667, 0.026558669782908897, 0.02898042063627924, 0.017928995258573974, 0.028131897328421474, 0.018716591210769754, 0.03645803260483912, 0.01382324516972793, 0.05286324516470943, 0.029566637572965453, 0.04767208247046385, 0.006247309236122029, 0.056370070204138756, 0.008223064958916178, 0.007106025412213057, 0.030120607132890394, 0.026553908163415532, 0.036974357041929445, 0.011819366714917123, 0.03367841729362096, 0.025432661275512407, 0.06801520354513611, 0.06672965109880481, 0.04665266163647175, 0.0407700378314725, 0.014923515995698316, 0.02900245945368494, 0.029375782635595118, 0.05437561829707452, 0.004844657760778708, 0.005470146608006741, 0.01041070681198367, 0.009302211293418492, 0.059164569180990965, 0.04702737581517015, 0.06532212519752127, 0.0371662094257772, 0.023295834061822722, 0.03028372016602329, 0.03437689784914255, 0.012901290802152028, 0.050882757508328984, 0.05210162353302751, 0.06734584910529, 0.0688601221357073, 0.039195439645222256, 0.032353058590420654, 0.035133627243340015, 0.014942718536726065, 0.0038251474449810174, 0.018620609039706842, 0.02014104656076857, 0.019419394034360136, 0.05678800027817488, 0.03230458404868841, 0.0362221874030573, 0.06545684832547392, 0.02319271200602608, 0.03555182873138359, 0.006476862721943429, 0.020294619391539266, 0.02450388763099909, 0.011469624321242529, 0.05755982029118708, 0.05283305374905467, 0.022345885035714934, 0.1408685381923403, 0.09884264399962765, 0.14331164423908505, 0.13546057338161127, 0.23592703310506685, 0.14249263890087605, 0.17068947372691973, 0.1074524052175028, 0.10485842690936156, 0.0819484791053193, 0.11528932861983776, 0.0986037046781608, 0.1382581732634987, 0.21069086369659218, 0.13367462850042752, 0.1895717733672687, 0.15031963533588819, 0.2012343925556966, 0.11542040801474027, 0.05189550834308777, 0.13098222868783133, 0.13976716729147093, 0.0804846551535385, 0.12142108673495905, 0.07844195940664836, 0.14733782676713808, 0.08125416136213712, 0.19345717344965252, 0.13661112450063229, 0.14934194779821805, 0.06814584867762667, 0.09184666297265462, 0.18053406689848217, 0.14149310253560543, 0.1813798743699278, 0.19113030045160226, 0.13425968853490694, 0.14270154626241752, 0.09394315976117339, 0.1532721719039338, 0.17625647357531957, 0.0882708512778793, 0.14735886135271617, 0.1841879372618028, 0.1458426205707448, 0.1493843019540821, 0.1631515874926533, 0.16055251338652202, 0.080177869115557, 0.10947042264576469, 0.14700648454683168, 0.12353552398937089, 0.13475618617875235, 0.09617587245468583, 0.18323450056569918, 0.06502713209816388, 0.16742441749998502, 0.10591020368571792, 0.11962932002331529, 0.1630270356046302, 0.13164164258965425, 0.09824463073164225, 0.163138478196093, 0.11015667939292532, 0.1409738603979349, 0.11648843570479325, 0.15448896161147527, 0.14971837188516343, 0.14530906134418078, 0.09889974272144691, 0.05183738164071526, 0.09641462178634745, 0.10192250766392265, 0.12569455456520828, 0.13643047133726732, 0.17274729401937552, 0.1665012434657131, 0.11329328894082989, 0.2444258470620428, 0.11203109166984047, 0.20348341044570717, 0.1418527668075902, 0.10724655804889542, 0.06806597832058157, 0.09614060220441648, 0.14802801901740686, 0.09373169432261161, 0.11234716006687709, 0.14714251724737032, 0.1790080280708415, 0.14338967576622963, 0.12450911317552839, 0.10331475295658622, 0.11224846036306449, 0.11656340025365353, 0.1650379691272974, 0.09414576353239161, 0.1922705785504409, 0.23433201440743037, 0.15455080329307488, 0.14834950890924248, 0.17642992069678648, 0.25063544671450344, 0.09121635822313172, 0.13975411227771214, 0.14783422941608088, 0.0796839634754828, 0.08158634496586663, 0.1671237586332219, 0.12325702607631683, 0.1331773301852601, 0.1915638300457171, 0.13315492495894432, 0.12302533350884914, 0.0921203772138272, 0.16482313136969293, 0.12127640949828283, 0.16069818128432545, 0.0941912525200418, 0.06825355932648693, 0.23179011366197041, 0.09693518706730433, 0.07791506339396749, 0.15960516993488583, 0.15307512533451828, 0.10486691538244486, 0.10694995003619365, 0.08807264441358191, 0.15287575817533902, 0.11015018581279687, 0.1332576008779662, 0.16638111562601157, 0.16383337947939122, 0.10470454873783247, 0.1107247421251876, 0.12971017908837112, 0.17818932128804071, 0.0955215339948024, 0.13418065277593477, 0.1533695688205106, 0.12357866524585656, 0.09958477132022381, 0.18411513045430183, 0.15777426532336644, 0.13025770256561892, 0.12597717797117575, 0.10403011207069669, 0.10298657949481692, 0.11978866718709469, 0.05264704694439258, 0.07823250243174178, 0.14267979242971965, 0.14989422102059635, 0.1797653002930539, 0.21836573258042336, 0.17303962047610963, 0.18705391990286963, 0.08745707065931388, 0.15219654462167195, 0.1282967227910246, 0.12362198292144708, 0.16411670856177807, 0.1428988506751401, 0.16299407237342425, 0.12538998733673776, 0.09180185930537325, 0.0818413927086762, 0.08611250602241073, 0.1632103350545679, 0.12458478340080806, 0.20520508448992456, 0.09390214910464627, 0.21374556049704552, 0.11254280206880399, 0.17863490166408674, 0.08057340753397771], [0.00859026690678937, 0.0485381136781403, 0.014398301053526146, 0.027358487847128084, 0.021893393780503954, 0.011020203436990934, 0.020844451584188, 0.0055813780054450035, 0.023868012108973095, 0.10484014039060899, 0.022744034117619907, 0.04796205780335835, 0.04867416673472949, 0.026028937493850077, 0.023088872399447218, 0.06305417618049042, 0.033423003141901324, 0.010174988835517849, 0.03162461392847555, 0.04663254985851901, 0.06228526708270822, 0.017824522918090224, 0.045468180373843224, 0.0627079401165247, 0.005815504393207708, 0.013768916567122298, 0.022633487192381705, 0.02832613306652222, 0.032640279071139436, 0.020652100477101545, 0.06457552633115224, 0.009358115793604935, 0.011053231129023646, 0.008038396564578372, 0.03941202463049974, 0.03169612134141581, 0.0410712022068245, 0.08672256328697715, 0.06259288093341248, 0.056723057691540034, 0.029262847267091274, 0.015662225196138024, 0.013473877666651137, 0.041302039820168696, 0.049002679464008124, 0.016908541355015974, 0.009303351232249821, 0.06750421917864255, 0.02308018715120852, 0.035078679477529864, 0.0385169724800757, 0.09955383012337343, 0.013219170039519668, 0.05387168051674962, 0.03866755975676434, 0.030466174839862754, 0.05082462062793119, 0.03816455156941499, 0.02179140827086355, 0.08208706988287823, 0.030635194520332983, 0.027890028432011604, 0.044308367251817665, 0.04954942262598446, 0.025463931561846818, 0.04374277777969837, 0.10539868327655963, 0.07063671680433409, 0.0393763472592192, 0.027270726127816097, 0.03500792184578521, 0.03194341682163732, 0.027469570815031017, 0.012596863521529096, 0.004320301165405128, 0.05408887618354388, 0.04051534292687263, 0.026476183673366904, 0.02998644718900323, 0.026944021694362164, 0.04824029787310532, 0.03841992161635842, 0.05216342450252601, 0.036892081278243234, 0.023011108893635016, 0.009226035559549928, 0.030547046036060368, 0.06046249132071223, 0.034868835737662654, 0.03169312560930848, 0.02254522335715592, 0.076968181346144, 0.025873926168839847, 0.05751638047929321, 0.03340095414647034, 0.042986058563526185, 0.012278846032651407, 0.011037529828692121, 0.08380725115005459, 0.0205515178386122, 0.06372705221708332, 0.04585789017645376, 0.05835115497133561, 0.05937127808907202, 0.04403633577749133, 0.03507923926892025, 0.030468875409236977, 0.041176344600639174, 0.01874098284835262, 0.0246630753390491, 0.0317486399518592, 0.07078578416258097, 0.05509378993883729, 0.006339635375687587, 0.025291777049590434, 0.06930214698825564, 0.023257138906046748, 0.036226974467613866, 0.018818383337929845, 0.10765975194850139, 0.019817568561328307, 0.06275826027350766, 0.021903649837310826, 0.035495690136615715, 0.003152380822159882, 0.03892709600872227, 0.04265103868341871, 0.0265672532508948, 0.04141535177560789, 0.088087965734303, 0.004174485262150743, 0.04964218854105898, 0.02699221803673676, 0.07656836815710578, 0.06302911109690156, 0.035371901600488594, 0.03350371827504464, 0.022399088966527154, 0.003730031254235655, 0.03528174125988569, 0.009413567371666431, 0.026333263842388988, 0.032575417908706834, 0.054476072013910325, 0.06531606587980475, 0.026092226151376963, 0.10151871825967516, 0.016671649512967894, 0.036909160004662614, 0.027318050552691733, 0.043635888158210685, 0.04411314594160233, 0.03475258233291762, 0.02069629855187876, 0.08428222566310849, 0.007424054351369185, 0.03955505981243082, 0.043375123757869005, 0.014235681654619319, 0.061302415893546174, 0.03629329787301166, 0.062442646494933536, 0.046497741913689036, 0.01034159547582801, 0.07813207246363163, 0.045878331043890545, 0.03804544831759163, 0.013289210968650877, 0.04257893076698695, 0.09316180633114916, 0.02800533697674317, 0.0144262872303703, 0.03713316137769392, 0.019123506965115666, 0.016083800699561834, 0.06831802693860871, 0.0289713554084301, 0.05217031841831548, 0.032913966170911274, 0.04578780090170247, 0.013507391359390957, 0.016936844746981348, 0.016400040426690663, 0.033183622772672346, 0.012382293785256999, 0.02722001581319741, 0.031466511876455376, 0.014181780529075434, 0.01615401211061648, 0.04976627902526941, 0.06126996156360422, 0.01310489626069154, 0.011816492270944374, 0.007801503874361515, 0.05153477877112372, 0.05381317722744175, 0.044925946077065806, 0.03604781747396503, 0.05273332267201372, 0.05215184869510787, 0.01645221807328718, 0.03627356268199427, 0.014156685759579497, 0.04108790773898363, 0.06820159032940865, 0.01794033357873559, 0.02876529110861676, 0.03213608005483236, 0.05318474184189524, 0.03157746931537986, 0.050053058458226066, 0.03524784165035401, 0.02519921978403415, 0.06740580445953778, 0.08514916950038501, 0.07299016801906483, 0.02468124820318605, 0.013400388083287647, 0.006658664729911834, 0.03632708891694035, 0.07341797756297247, 0.020901470578142574, 0.007402226727988038, 0.026034034988177673, 0.04278520541265607, 0.014163309109530278, 0.028477415841604983, 0.014338942810094782, 0.02151480007783643, 0.0855947770178318, 0.06967483913259846, 0.03812962397933006, 0.0019156063499394804, 0.049829450635505576, 0.011843504750036767, 0.013944623210201306, 0.028654197962688546, 0.039119314801480086, 0.07222602902246372, 0.052053942877267084, 0.06331229090158429, 0.030510947973068272, 0.08243363164365292, 0.01604339393920132, 0.05427028252077954, 0.02836623787879944, 0.029485471214034727, 0.030545230954885483, 0.018763459320845347, 0.010587708608779525, 0.04311165539547801, 0.05743715473051582, 0.012162037077359855, 0.02718747666637812, 0.027566022871594344, 0.02131276627603386, 0.045910697164280076, 0.030827097794307128, 0.06435070732342345, 0.06283551148538079, 0.046881707917366705, 0.04237818618171981, 0.04385614741061415, 0.01865822702114071, 0.020699784525537064, 0.06963804896388735, 0.06005879012601716, 0.011728743274163986, 0.06037797299878938, 0.018559756322896907, 0.022076147009751627, 0.014397624214845044, 0.03848216702629413, 0.051458470722926516, 0.030013547877648046, 0.02049055485986173, 0.053801852477980514, 0.050509410577693155, 0.053278040406959395, 0.01628341382768537, 0.0526591316530747, 0.02152006890225623, 0.05858706124126911, 0.024778996261634996, 0.04161652044526168, 0.04156522319785186, 0.04150086075865796, 0.043247240262904336, 0.027055944349350672, 0.013781182783921915, 0.05804139694997242, 0.06038184064839568, 0.02922095451503992, 0.018512067185448747, 0.030442297192556516, 0.044704780980412445, 0.05150731845891901, 0.0833427125055875, 0.002817787995029773, 0.016396408568003347, 0.029303101357072592, 0.02579286159016192, 0.0389894330208855, 0.04099167790263891, 0.018565096393493668, 0.012527479075028427, 0.036839773013655625, 0.04333811645795192, 0.030017123757196323, 0.047840121667832136, 0.012632820788504822, 0.042965872146721394, 0.011155231057533195, 0.022727829005037035, 0.027580063457467725, 0.015849648442651545, 0.02613961503707937, 0.025040084662448083, 0.08170626924506255, 0.025860523405883993, 0.05252492421173623, 0.035136921530855555, 0.05278916610404849, 0.01627901352808944, 0.06353927443602256, 0.02468858825575028, 0.040730506381286044, 0.030351532955787013, 0.024935527505087, 0.04035142243706754, 0.038028396732572994, 0.04809928133285471, 0.026818431647760526, 0.06045920042587178, 0.002885485645882519, 0.0052465752565435, 0.030218977747218947, 0.028970144223421812, 0.029892493837646077, 0.013958267701257552, 0.04634226918486612, 0.01827662401566548, 0.046878552729529996, 0.07084974965878896, 0.041226030327379704, 0.0674690982060773, 0.007453118550724217, 0.03225382623661842, 0.03629260915996773, 0.04737397150269576, 0.0209463641513139, 0.02595187966445727, 0.12545649733926567, 0.09565093062285866, 0.09414830803871155, 0.09409443235823087, 0.16685705365879194, 0.06460879490311656, 0.10894501941012484, 0.08280464780649968, 0.12240018562546798, 0.12862559514386313, 0.1078631631763918, 0.1794037225523165, 0.14564961807004043, 0.13366206203188213, 0.209723435608404, 0.1575179962175233, 0.1390793499137674, 0.08128003390239817, 0.14716866798698902, 0.2016929600919996, 0.14166383551699774, 0.10620223158704382, 0.17538265617830412, 0.18423812171178205, 0.12490065502268927, 0.1452705476965223, 0.11164023514304842, 0.12603882966297014, 0.15825521094458445, 0.12983006265546593, 0.08259339271379368, 0.11510638200810977, 0.1862835112426962, 0.12965325000030653, 0.10080811567604542, 0.08572928301457848, 0.14797560897256645, 0.20501031779817172, 0.12825082668236323, 0.22148916497826576, 0.10325760673731565, 0.10429186373949051, 0.1445560503218855, 0.20638251916638442, 0.14752565883100033, 0.06637915383492198, 0.17894178948232106, 0.12980883808008262, 0.13697817123361997, 0.10780719760805368, 0.0778729399400098, 0.18494420525218758, 0.1014798924859081, 0.1507414805569819, 0.16878333315253258, 0.17144952794270857, 0.13143996841141156, 0.14508808963000774, 0.07414845443729844, 0.15740747643368586, 0.08344661657299314, 0.0875906063509839, 0.18321282815720352, 0.12832892606300966, 0.16272595604615553, 0.14675222390464374, 0.18804597881223473, 0.1638001041220767, 0.12921929971448012, 0.13872503249772958, 0.11736199525850159, 0.07746752205171756, 0.11442981474101543, 0.19121504947543144, 0.12808750330337457, 0.11765080690383911, 0.15980179581258977, 0.14397910556622914, 0.09797327100698437, 0.06804525586111204, 0.14265874427344116, 0.06833247294915573, 0.1501434197915452, 0.11454497570438044, 0.09644533906664167, 0.1147902389722211, 0.10174222769481794, 0.20020753837057523, 0.1133380586813603, 0.12466555620942797, 0.17462127203387873, 0.1894968088184084, 0.17133637544299873, 0.10708589452717986, 0.11219212160046611, 0.09243055592690196, 0.06654725410044193, 0.1102985135678734, 0.1521861630358866, 0.12399908554341112, 0.17016941734722682, 0.16295994206198625, 0.09322014677205256, 0.21012010718030588, 0.1471160679523434, 0.1519408319145441, 0.11682907385485512, 0.11061859889222042, 0.09569271480930702, 0.15331768803298473, 0.07776432005422455, 0.08141345424311501, 0.13616078080875532, 0.07658078534794704, 0.11488509816782815, 0.14263496840638773, 0.12188479756670338, 0.16734744448746952, 0.1204164477863482, 0.17573131461228642, 0.12155543666865144, 0.20511918195656367, 0.06695548112371139, 0.08229715789535216, 0.08282268326729536, 0.1201993708631822, 0.15080454360161508, 0.12883997149765491, 0.16547320862965925, 0.176558380946517, 0.15186394032623085, 0.0877972881176642, 0.10326990857720375, 0.21809429143156323, 0.13499755465558597, 0.09696576864059482, 0.13308699003287724, 0.10237630509904452, 0.14165038695292814, 0.13914398715964385, 0.10070867636906249, 0.07144802077008144, 0.10922237738434758, 0.11945072960640703, 0.12061559781432152, 0.09617403362478529, 0.1559395202036415, 0.06913739190037761, 0.10715999733656645, 0.11831825466028281, 0.16867560893297195, 0.12323980485754353, 0.17377960362604686, 0.07489178955022778, 0.19294576160609722, 0.1112219997282539, 0.1052636005250471, 0.24543298301952227, 0.07587048131972551, 0.11615954978125435, 0.1984546110033989, 0.15911570191383362, 0.09069935525102274, 0.1864773958389248, 0.119753166234919, 0.14930409911487783, 0.11629839161677019, 0.1305361869079726, 0.07989449932106904, 0.1897863804229668, 0.08973667012261492, 0.08393112450305905, 0.1143021144505058, 0.13523684681526252, 0.0939060981784548, 0.18365976560328687], [0.013992290295261358, 0.08122721673654658, 0.025793148271207298, 0.044912843565855703, 0.017881813326052258, 0.036687774384128194, 0.06908427617911782, 0.02153862513867872, 0.04541967190536005, 0.010012512777133711, 0.060404381581715176, 0.04599540547600814, 0.010395440622232854, 0.06646020484289952, 0.02820445816697819, 0.04442149939547692, 0.03254113153421453, 0.11625147770558085, 0.07010311686566897, 0.03315517179934042, 0.014176082531256335, 0.02145680568979255, 0.06106792776180165, 0.02013370311552925, 0.033816539882017035, 0.04441714998600738, 0.01706766799491431, 0.02209830457078559, 0.05101136025041342, 0.03790231474808284, 0.018407927327124134, 0.047977467333631854, 0.05101349763572216, 0.02342181765873517, 0.03340859445078032, 0.017665740634713854, 0.03358778537118009, 0.026133360640544976, 0.04574750270694494, 0.03360194978969438, 0.014924650845517005, 0.06883456172155482, 0.0444709612056613, 0.04826411105958479, 0.03564931046483772, 0.03843785868957639, 0.042874242777803113, 0.03657709853723645, 0.040763411937015395, 0.02307920327543148, 0.049895838501730135, 0.015726329792024832, 0.049342991917261055, 0.10204791450606925, 0.0417340868152678, 0.045098039521170516, 0.04767801965187703, 0.03463045620758619, 0.035909596497991254, 0.049650731296943765, 0.015334156907296606, 0.029038228427192996, 0.014229609614371188, 0.06712835827576262, 0.03145469518910561, 0.02901324476780636, 0.02731552979509745, 0.02163549619061606, 0.029185507845665728, 0.045809076367212195, 0.009741508435191852, 0.009462712814898362, 0.01767683807494385, 0.04715477415759649, 0.021462948128048862, 0.051824089139699936, 0.014372467529028654, 0.030122042234454836, 0.028536200722945586, 0.007559060767692114, 0.013047610941742147, 0.074830124287733, 0.031695507267223935, 0.0637952382011073, 0.09334998444787093, 0.02243816919092621, 0.029354988929948637, 0.10549957464848246, 0.08388624619692564, 0.013133551642697836, 0.03220731944644025, 0.05307408295837896, 0.01904974172690085, 0.005417108918274087, 0.06855039804109506, 0.01730228674464992, 0.030045076007289544, 0.03423591862831797, 0.04607330129614898, 0.03383715716855867, 0.0254980533915971, 0.04392310185357928, 0.06795319901513201, 0.030911480409226248, 0.08387515893472092, 0.07715416100940534, 0.01625474063413484, 0.053501705905156474, 0.04265111671494586, 0.011666212031351668, 0.025071127639551247, 0.01897635986097157, 0.010186814004555345, 0.02136501856148243, 0.04927347939727562, 0.03449336838509355, 0.11608085328979151, 0.03348897710176451, 0.006274071929510683, 0.008643064564759178, 0.03299004012452705, 0.035472684406808445, 0.05689843863781009, 0.05664654608283724, 0.07670813958559718, 0.03135929995083383, 0.036347709596157074, 0.06591400450893811, 0.005174382523234401, 0.00892526812718383, 0.05637334074292864, 0.04435937272916947, 0.008854531699658504, 0.014575078085597073, 0.03281704083617244, 0.05987832695245743, 0.05868042765983513, 0.06504307088575192, 0.04723404061847499, 0.09101231595767395, 0.020391593920066953, 0.054933679423161914, 0.03788276954687067, 0.014822236162477305, 0.058780301229229996, 0.051529401381100924, 0.023860309040173888, 0.026380956372512237, 0.017276419293401495, 0.014496279813881432, 0.012366935145109892, 0.05085655248590878, 0.060770315517272265, 0.01777052679764373, 0.02819668215566448, 0.05626819495643888, 0.06252986538623061, 0.03268233806427036, 0.033039518898086886, 0.03367196781826871, 0.027787328764264072, 0.009240634240476149, 0.025535466116187826, 0.01689736418692129, 0.06881701480597258, 0.05128630263996976, 0.04482115991413593, 0.043397718973989995, 0.04774610385564821, 0.08338119901184525, 0.031270303297787905, 0.01826391844744129, 0.03355957527777978, 0.02702281148439007, 0.09790597390383482, 0.02714467976641442, 0.04353692043306572, 0.021711558269869004, 0.015611889772117138, 0.038558943263654194, 0.024278552936656133, 0.018964102125859687, 0.051902018886591704, 0.02907702705955931, 0.021631187493247644, 0.01973427669145167, 0.05667146188872201, 0.0037540200116511968, 0.04134680277534893, 0.009737354104540177, 0.06580067559012345, 0.028405121328043084, 0.04917651674311076, 0.02304775996266731, 0.018714207856516753, 0.052860768511891365, 0.09586299317223684, 0.05286164382206542, 0.03602908990745034, 0.026240694702469876, 0.03138072808672275, 0.010433256226990904, 0.02085680770687759, 0.01995138923770615, 0.027865901423086013, 0.0459634973667562, 0.05196032879341926, 0.0315823683382145, 0.0272249385847577, 0.015096408414787479, 0.05226221241589103, 0.016973453407574977, 0.025489171368202994, 0.028502752339201312, 0.025863308792135546, 0.0464667328633368, 0.02461815801715212, 0.061828395883951864, 0.03782252920791507, 0.034823075336005004, 0.025517369587240473, 0.06827381359679358, 0.013812424232518035, 0.04044011714203017, 0.006274338678589889, 0.048303540729518445, 0.03478546413992133, 0.015069441736808844, 0.03347208497247525, 0.020735027634405663, 0.051981064823589156, 0.01978446283776845, 0.018309358241302625, 0.10371062385716609, 0.024385113468659774, 0.04918475755091224, 0.026775824737602046, 0.032178573310375214, 0.04066861720223512, 0.03789206547662616, 0.03363430912473372, 0.04050442869109767, 0.03246184132461037, 0.054626876421804936, 0.04901841129841549, 0.037489751886044226, 0.029075055915330137, 0.06497993998761688, 0.025144938678879823, 0.012701000835347389, 0.05080730441425528, 0.054880383890122175, 0.02101988681325955, 0.04801272740587592, 0.02477919134045286, 0.0230600906402937, 0.03903007387582745, 0.037739384919404984, 0.04351255424054606, 0.013933485906038965, 0.05676590717796769, 0.02844197765391852, 0.020264126027801206, 0.023249398517821516, 0.08117757511458226, 0.029070818464138677, 0.07464520313910075, 0.03897883091121912, 0.043733037409505675, 0.0129926250083372, 0.03866779724402087, 0.047479510839496336, 0.0010080967206574443, 0.048544366378337145, 0.040899529454431365, 0.03189690663878407, 0.09731086476572923, 0.04511559322210295, 0.0494013052167637, 0.12477644240217549, 0.07402289153209754, 0.025894484083567346, 0.0204641377952482, 0.03827495939497437, 0.050664588143782954, 0.05183262511023453, 0.0152147025136011, 0.00853049730150295, 0.010597550759225019, 0.02409226623629885, 0.010166605535362448, 0.03546091182423489, 0.054107400189552984, 0.047916368647877655, 0.02349348452740482, 0.002244460891233757, 0.019760390111644353, 0.04308118238779051, 0.005133131834944444, 0.025146875896358063, 0.08536826845790658, 0.0498149774835578, 0.05744001814829452, 0.023057512207222835, 0.01860529450433595, 0.030754474191261188, 0.01230965745967946, 0.009413228104157107, 0.0061708879573935905, 0.03804790461435914, 0.04276534469266023, 0.04469953929739339, 0.04184751412166016, 0.07329719154430286, 0.019652134938431636, 0.02065156782711191, 0.06189049540885857, 0.012605325701380414, 0.03701632782550795, 0.043511838386101384, 0.00865126890130341, 0.026450241583266428, 0.02183151477947831, 0.02538804929437382, 0.010434524239307004, 0.03398185476128544, 0.03910950318511043, 0.04866023641079664, 0.03718545946425625, 0.03886674710416368, 0.03981253331793206, 0.036568722022431235, 0.043873850389250686, 0.02509954638246979, 0.04817375394382647, 0.012400312282677208, 0.03568046200754387, 0.04086887663496392, 0.03734781593084335, 0.04801784355991653, 0.04282101509826524, 0.010038636375351675, 0.029350320609020333, 0.05902992747724056, 0.03318724614967193, 0.04396410233208111, 0.022753592979695116, 0.026994518270449977, 0.03139555407688022, 0.03191329325948443, 0.022551459093977298, 0.014834125792341573, 0.10823052882083825, 0.14482089611036436, 0.106907500885427, 0.1046478571370244, 0.0854613431064146, 0.1065476873357381, 0.20038402532892569, 0.15390510936932905, 0.08718185685575008, 0.07814875763974019, 0.13291962258517742, 0.10787568893283606, 0.1019036036783031, 0.11900026377822671, 0.20001939418060438, 0.10105375892349652, 0.13000555895268917, 0.16613801009953022, 0.16340363611068043, 0.13624740258923598, 0.2172948143311909, 0.11749581593487944, 0.1025324020800846, 0.06440974665539605, 0.13284609653055668, 0.11621079274586268, 0.09449055431676762, 0.14962028286286763, 0.17746814712882042, 0.21240411033587797, 0.18354106268712453, 0.11932872901005404, 0.16123754877064908, 0.0864314106958253, 0.10404907033911773, 0.08610128305320229, 0.15783601201006345, 0.18405001823391232, 0.11842341401747294, 0.1622313040175608, 0.14947838761976787, 0.2490481361746788, 0.13775008624153479, 0.11297526636293956, 0.13540044160825865, 0.1038707649069173, 0.1151787138410977, 0.1632294561713934, 0.13758703427655355, 0.15235893162233488, 0.13722970416503294, 0.08235134570194141, 0.18820265254804067, 0.11478407787425177, 0.20176689326763153, 0.0973291444991316, 0.17825104083333695, 0.17942312865384988, 0.12286210512476307, 0.10991928713130099, 0.11980715048100267, 0.07853434194943734, 0.08130366049174752, 0.12632167020014354, 0.10976273553179842, 0.08256524708122015, 0.1638467873313597, 0.1471117931817259, 0.1113507246066417, 0.12319637861635004, 0.10391126666218042, 0.13198247072952135, 0.10313671893839325, 0.12166413797863893, 0.08150486648082733, 0.1508465584899698, 0.23761609675628798, 0.13377138759408677, 0.13069499124373707, 0.10090393160602876, 0.05911825916596821, 0.07888029981404543, 0.13166644982993603, 0.10298349894583225, 0.16984680108726025, 0.09221359435468912, 0.08098141742604119, 0.18910800825272286, 0.2426965327135154, 0.11479707860520907, 0.09457692503929138, 0.12805623640971525, 0.183282486562218, 0.06690920503543955, 0.14395353836672647, 0.11902289970644883, 0.06501302535512618, 0.13790973196072237, 0.1004406889634473, 0.16108124144375324, 0.21795786518071378, 0.16536008327135018, 0.15556446675743374, 0.18849187131438935, 0.2603280209004879, 0.13759490528276988, 0.13176685944199562, 0.0937696515715548, 0.13826353369014605, 0.10093530706529107, 0.17243345800255025, 0.12352568523160048, 0.1178687387811286, 0.16102934708552702, 0.14469430861728533, 0.12292678308274065, 0.19011199580771582, 0.11868421573724065, 0.08822178641068083, 0.08735628106764384, 0.17630475812724658, 0.16798600022281918, 0.06896804313042335, 0.1150928655905383, 0.1832596877855914, 0.12312030127005917, 0.20059388263949327, 0.20465058567268507, 0.08160098096621887, 0.12394238715725285, 0.11924012590731893, 0.2859393251793725, 0.09575328763042178, 0.12233260353761059, 0.09560244251042604, 0.1383175179362297, 0.151601713682924, 0.18949771805533341, 0.11993797203259808, 0.1755698232778481, 0.111155781495784, 0.1691506648702281, 0.15598582343331405, 0.08673778282744543, 0.12206162379256316, 0.20766040416700499, 0.09499919773744685, 0.07779798896184989, 0.12047773306923253, 0.10681494870888335, 0.18829672464302608, 0.11576225395713534, 0.13364975340664387, 0.20934589872402803, 0.09565686780427184, 0.12304207975310938, 0.14200427010655403, 0.14365015178918839, 0.10646798661244766, 0.10320065050785031, 0.1441782284528017, 0.15933414947773727, 0.1235316563397646, 0.09584192465990782, 0.16788426068212303, 0.10002079792320728, 0.13646309530096395, 0.14305863210133143, 0.12283527585012571, 0.13995692639478616, 0.1296474010284458, 0.1204010314707245, 0.12423977548522608, 0.08193122395979506, 0.19285318228815282, 0.08404629225177424], [0.03786471712269953, 0.018515541284744228, 0.013540218035424394, 0.05008369431431804, 0.019276341889053583, 0.05534437970657434, 0.010181505316203194, 0.042972053600741286, 0.016682757131223167, 0.020348696936187998, 0.08849429964487042, 0.03406471745776279, 0.02192658432094114, 0.012458262565944875, 0.00655172040153827, 0.07649830941643034, 0.028467895995293344, 0.03728984868420022, 0.03666501971227782, 0.053423901687243154, 0.030323221082133905, 0.06694765761494637, 0.04329765202211482, 0.04024402730699096, 0.05204909135188375, 0.0310557369541909, 0.08322945144027472, 0.016206071013584733, 0.045739010841186555, 0.014916935902354973, 0.03483513290328639, 0.043974796043975015, 0.03754052666148969, 0.059378436633518765, 0.06831884796598128, 0.04676486418715545, 0.025158836772399287, 0.010304913024551101, 0.016972712108067105, 0.00599492304692311, 0.042188498324581554, 0.016064124880358577, 0.03279153809749654, 0.09805464092642069, 0.0441086404690785, 0.029094400948711803, 0.04107379081792065, 0.020404894902770008, 0.025488231597202163, 0.037774577138147185, 0.03833822260743805, 0.00817977188022009, 0.04698000728551831, 0.04337223319868956, 0.02855780188526426, 0.003760981356858143, 0.048366607166826725, 0.06607658149940626, 0.028480435322437967, 0.015071777593610542, 0.04448771084259663, 0.057858470694295, 0.014938335200505597, 0.03232701302372983, 0.04610155210165041, 0.04137224105319806, 0.02081973255345864, 0.011933903426064976, 0.017362722162423388, 0.023580891712169563, 0.028515308629721403, 0.014338454264881355, 0.026896381750702858, 0.025843193621507714, 0.10219374525227717, 0.021945549374712364, 0.02509850143854107, 0.026780874734478335, 0.06488026997872762, 0.03223076622400965, 0.060986557842365334, 0.013207678200810083, 0.043261713414852104, 0.04989628294216735, 0.021502457525847212, 0.03127044918281691, 0.05009053394730602, 0.013788655998983552, 0.008229296454893691, 0.03932737399424825, 0.008710587280802429, 0.008935865996006345, 0.051434162205883434, 0.06858834850468806, 0.02034461045903819, 0.029925616524581398, 0.04082316712343267, 0.01550893735007516, 0.042886368198586364, 0.017669516682092632, 0.026701518367709856, 0.09215336758643389, 0.02648982561991683, 0.0429195824877492, 0.07933130168489047, 0.037320189377559085, 0.021844674966164997, 0.013598524549576853, 0.039357972530914206, 0.042889099302036424, 0.026767758652567863, 0.06006413019661393, 0.11026671063154936, 0.02967601063262139, 0.014578385943812984, 0.04873401013069919, 0.07551972621253558, 0.01592756631518049, 0.050618552935442755, 0.04156115198773997, 0.07210650507892881, 0.05726008423204933, 0.008875307593760746, 0.02704512171580323, 0.029173840436020067, 0.011137372015842369, 0.0481768039587353, 0.05077935894951224, 0.02141773733975632, 0.06491654446082455, 0.02229553604099367, 0.03737400398988809, 0.009248466230928898, 0.04960074701479503, 0.016362527618184686, 0.009426278877072036, 0.06057035803262677, 0.026431583566591144, 0.04343819698052747, 0.02292367287113198, 0.05324677012062498, 0.057432771394295354, 0.02592806308530271, 0.022294446992288743, 0.055633232064012966, 0.06640176940709352, 0.05986467482788222, 0.08317303803882428, 0.04073478454457862, 0.05001044985173004, 0.006675063649059406, 0.017038202611729503, 0.0402821643677141, 0.019152504159137607, 0.05717213252293212, 0.024795108075652803, 0.016230717101799588, 0.005145290758394237, 0.04373287795377629, 0.06849298040781703, 0.0295339796825179, 0.06079595735562699, 0.028960196900048425, 0.0585559436253139, 0.04336220105843885, 0.02609177153291447, 0.07275542882936341, 0.014608295767435005, 0.04042487385283623, 0.06684944645634719, 0.03779598831066063, 0.04232310949425612, 0.05216317344456911, 0.028386505719806467, 0.04440131297867213, 0.049441922322979996, 0.04820058661113892, 0.012977460598839181, 0.007919870915689638, 0.06847453104065997, 0.024195490072348287, 0.03990114659869245, 0.009306094210062708, 0.03261227932359491, 0.04328323993831873, 0.021541022063632096, 0.03932615602388978, 0.040635470766574144, 0.0691024541322674, 0.05153124360367656, 0.02588074205310217, 0.06045169582856553, 0.0371947214672608, 0.03934259353471654, 0.04858397925272584, 0.03342377327914749, 0.05460536346903869, 0.04875781313915338, 0.043235281083200655, 0.04011501405122025, 0.01206800399813801, 0.04608681771372046, 0.046585439172174246, 0.013373577468363302, 0.07858861118022885, 0.010563002300581761, 0.03149955313918846, 0.040005495106535297, 0.0287794283857303, 0.0228474818702255, 0.03350865122463022, 0.06330319853233439, 0.013432447166581239, 0.019093230732583573, 0.05071078280785254, 0.05702144346599068, 0.020055147420082773, 0.07852204010954925, 0.023765002011454532, 0.04472515060167227, 0.04715071312550988, 0.08968603783952338, 0.019518807896279862, 0.007772363339816886, 0.06058105852987085, 0.044055144768208265, 0.047030812595039606, 0.03553100449166127, 0.04223518831921475, 0.01441895735583135, 0.024485166849834577, 0.022728682262822986, 0.020286614374656762, 0.04044836473518184, 0.035425370159958086, 0.03608383750542998, 0.007021812006964215, 0.006551296741236001, 0.023036759213677475, 0.03540992331025856, 0.0486829469778708, 0.08653578973774399, 0.0387420323677361, 0.07315517416489975, 0.02381346807149904, 0.0018188612510649754, 0.025309603860867873, 0.03382090286218694, 0.038777638492839675, 0.04565971384623221, 0.03431864222511649, 0.028218101809865663, 0.014888562960550189, 0.0049885177868418396, 0.06886211024331194, 0.049443734011479785, 0.021916262106969953, 0.05770546104758978, 0.01167396005309586, 0.028389097723577703, 0.03656547183969191, 0.02941076790115663, 0.10358808721814837, 0.038174186766679795, 0.04011285291718585, 0.02336909039877355, 0.051938405326966725, 0.016342234332114458, 0.06604845622288329, 0.02279729742024626, 0.008348486219931926, 0.025966356209080135, 0.016579969253923212, 0.019414193063442196, 0.0172886922955513, 0.007739997219427356, 0.047627041315925975, 0.03574096018980656, 0.022798549317355667, 0.017822748549016457, 0.03751954296603799, 0.0022377860150299966, 0.00547997815634257, 0.017061764740252068, 0.029555529954710176, 0.01543172515396561, 0.05764694418758154, 0.08377462040100779, 0.03913186430664999, 0.03986636150096144, 0.02142161686372544, 0.03624600398221186, 0.012560372756394957, 0.043183875270187855, 0.009777699796749013, 0.08243460873407976, 0.04543928156739899, 0.01917021901213697, 0.02996812335082463, 0.019688212645373175, 0.019976330488654118, 0.05501082206943205, 0.03620969896603908, 0.02144818490238062, 0.019340629689395428, 0.10175482809011425, 0.07784372900745698, 0.04810414303626333, 0.02395452362751322, 0.02038227254524827, 0.029039266585771526, 0.010671161630723094, 0.10338911360927991, 0.07115952803620271, 0.007460238079407385, 0.04061592556536198, 0.07079682392733437, 0.063579715123134, 0.04664007481187582, 0.05030205366866929, 0.01485146236206804, 0.031864886571254046, 0.06318327425313847, 0.02015812019817531, 0.046250253050987206, 0.03934817109256983, 0.014049479771139366, 0.039389839928065024, 0.04770972080794828, 0.013306667130174381, 0.03296875787366714, 0.027887332951650023, 0.08119959357593741, 0.006592929953642721, 0.044230301797922165, 0.01897446674826954, 0.04443845598559294, 0.055465518563453636, 0.03343463662479605, 0.02809709696365254, 0.013960805422227298, 0.06261124887636729, 0.010368166058989508, 0.06288680194744042, 0.014056919907618846, 0.01962927170097828, 0.014172542274796536, 0.03630631556734443, 0.060983063387019296, 0.07497927307018212, 0.06991170892225844, 0.01560001032027815, 0.11310059856623411, 0.13459468127361365, 0.07272247238350765, 0.15030477541897977, 0.18360504853938306, 0.13142284218754086, 0.103654332592019, 0.11108731731240239, 0.12623536054577145, 0.0957635674359543, 0.19784452659743174, 0.15800272806414536, 0.16239857647035802, 0.11016603639083249, 0.09621199087372848, 0.18411974449242863, 0.16987612737076624, 0.09633681417575904, 0.12859434182090418, 0.12633245890694006, 0.15261756203004292, 0.13812079706362315, 0.11795498058199883, 0.14896727433162077, 0.16162344520645483, 0.15314479731023312, 0.1748501147542681, 0.1393857356160879, 0.12120881383972508, 0.09593468039695706, 0.12116029858589172, 0.14727362378367356, 0.08612368827951805, 0.09009332848446709, 0.12467747128435544, 0.16654396403048718, 0.12167279608547688, 0.08660851512104273, 0.17124218121170998, 0.15212601769183362, 0.11075298953801394, 0.17427753976413182, 0.0912237474694848, 0.19232890542064393, 0.14261018830750669, 0.16926752217113972, 0.05737154717956271, 0.08568853020135846, 0.3264632278255054, 0.1305475320134844, 0.18206720320241793, 0.10510074533522129, 0.12039651242750031, 0.1176712443786008, 0.15348544903099537, 0.10070172817047153, 0.092683255938547, 0.15441276212888105, 0.08373718562402896, 0.08462288416922092, 0.09672273775296551, 0.20135336688586644, 0.15341380930372647, 0.09542938215391976, 0.12821622139641217, 0.19874354478503975, 0.08148849343082734, 0.18224388015057358, 0.102899184184415, 0.08207655259008918, 0.10245435698223965, 0.1460307647607156, 0.10440348953540836, 0.0983837168397648, 0.16483014742178576, 0.14051359652408532, 0.06225666004632201, 0.10372693583901439, 0.27475210119571003, 0.10943038907966443, 0.1587510300534112, 0.17085989458220346, 0.14117771945893764, 0.12282128445804119, 0.11724345519074372, 0.11812336583222662, 0.19294468952076776, 0.13004001496093615, 0.14749189492847237, 0.087110610678792, 0.1371733314756836, 0.04602262830095632, 0.15389742835291795, 0.11993881341602121, 0.08355983014085464, 0.1201078500598669, 0.11003505877618279, 0.08765647853059427, 0.12466091502990041, 0.2037868784474475, 0.10508390409605843, 0.17903136967548303, 0.12207075687391417, 0.08225093608988182, 0.21441836868013653, 0.08888381267232554, 0.13940815441310406, 0.0804619106597134, 0.06920743707035269, 0.10148766171187162, 0.10346280251230512, 0.24137686352644647, 0.1587063553077834, 0.08696833545608179, 0.07131742313504219, 0.0882654772805316, 0.14919121802917548, 0.1209964459495885, 0.09848958187337432, 0.08642448963863508, 0.1535635484116418, 0.08655630185135774, 0.11897196886794907, 0.06863840403301374, 0.0775298522785306, 0.221371574859534, 0.15875656689916337, 0.14139803977949278, 0.16099232621490955, 0.24087881882275852, 0.12848535552620888, 0.1675893829337188, 0.0894094058977706, 0.1047842087490218, 0.15789553310189927, 0.09550019406846591, 0.21305238269269466, 0.09269242973199912, 0.08240780660084315, 0.06437123300773756, 0.13814165523009642, 0.13868422540170805, 0.12231618299015931, 0.1286004622067724, 0.13526199332305364, 0.2081950083374977, 0.16978717142982142, 0.17428161097424372, 0.11528115905821323, 0.12462116644850799, 0.17235666140913963, 0.12237095433686461, 0.1298768272889512, 0.06285991160465138, 0.12418235785194806, 0.11509928453181471, 0.17785553634166718, 0.12225645833781787, 0.13762750210506575, 0.15775799405361923, 0.1390395334788731, 0.12517491887722695, 0.15703574780906948, 0.1643864805144923, 0.16263021475502423, 0.15375649662954466, 0.09948865683483225, 0.09218894317746162, 0.13539056213838713, 0.2067980540118047, 0.10220390292150633, 0.15656793862581253, 0.13596331354762825, 0.12343249523213931, 0.14677229497049535, 0.16256378617669853], [0.06265596433409623, 0.02653693630626159, 0.06407523567655257, 0.01560100946309311, 0.009098120682340647, 0.03419164761102625, 0.004808792520114886, 0.03957535818751369, 0.03348615100341184, 0.03509428578295878, 0.0032555431659732547, 0.02075122087262571, 0.05710024173770632, 0.01745490962639451, 0.03598835066493068, 0.033473886482949765, 0.024193405273503492, 0.01765805283295257, 0.019376766768151095, 0.0523885386729879, 0.03290858878088849, 0.002982250464681004, 0.053666413495583196, 0.028832062347126857, 0.0427909627822893, 0.052613154120211086, 0.06443062517791986, 0.0148965900298208, 0.04254187257694347, 0.04384589135380728, 0.07612160034477711, 0.06898810741092477, 0.043875899565007, 0.013752009170795125, 0.06506719280566488, 0.007761516109375017, 0.06646055768110923, 0.05124296121565359, 0.026496039304350103, 0.07306216736989361, 0.005381732222823692, 0.042111817082124095, 0.035204751283994744, 0.07232819604022162, 0.02076048287563026, 0.01655333675444126, 0.034597408159502914, 0.06157298851758242, 0.0383941779977509, 0.029625045867370706, 0.006667746921136443, 0.022000410627307634, 0.017504773468577435, 0.0717847098463348, 0.0647421677463821, 0.12961318929280552, 0.05437859706580639, 0.02151932251373572, 0.0402240783774427, 0.02543042041361332, 0.026013723042394434, 0.031468398203807216, 0.01821867373239781, 0.034441596163170676, 0.07054537920547382, 0.015500791537176286, 0.05216524297637599, 0.037804581956671815, 0.02114233693906239, 0.0167358558891075, 0.009700213642125683, 0.02949197157951338, 0.04516355207722102, 0.06394629366695881, 0.03963296581059694, 0.04703870734998158, 0.03877211182511278, 0.028609095739998987, 0.04329525000814881, 0.08431004559887306, 0.030095514907900776, 0.055622643525046964, 0.03289139809619103, 0.03385661416021841, 0.05447248595633677, 0.018681597463520508, 0.06671907952321426, 0.03811262667711292, 0.004073185921047947, 0.008309363587094205, 0.04642237363649266, 0.03101364742698414, 0.016227853684020892, 0.02299627611812736, 0.015427380833508713, 0.05795664792614324, 0.023844270168670585, 0.013066956823292588, 0.0987008505367807, 0.017594967735931277, 0.04040011750268085, 0.03264879807829857, 0.02838601717459304, 0.026293589899848615, 0.059133987607700486, 0.03793973256168621, 0.011698794434778392, 0.018571157407547747, 0.06396786429520164, 0.0071791693668014234, 0.014123583428694733, 0.009065120131708682, 0.05000290454232267, 0.05044942129669445, 0.014188155365575637, 0.019616588185142194, 0.03477712833721723, 0.07291554273771388, 0.03605341538786888, 0.03169398056343198, 0.05511550645210913, 0.0008738378060765431, 0.044891805587602515, 0.015500567620620131, 0.03328195606757488, 0.03873620375192591, 0.06280300287263733, 0.06913135972406183, 0.03659084904938936, 0.015618308713393552, 0.013408024146753763, 0.016397400925468122, 0.026985802488135438, 0.0998373491955655, 0.01910638583025762, 0.007053059816826135, 0.017160232045820782, 0.026379816433680908, 0.02892726081024323, 0.016025458562320898, 0.028868581101830517, 0.05170189176819154, 0.05978078754352672, 0.040559892143521986, 0.02809455245733261, 0.016401095548644662, 0.011173579492606223, 0.011836347901927573, 0.05198182139013495, 0.030629399831273725, 0.03309774059536202, 0.07125055350895439, 0.0011270360638653593, 0.025332480669021606, 0.011610463594219514, 0.0311910843343607, 0.04511173235784684, 0.030763631021337848, 0.09386535215058497, 0.007965284416319003, 0.04732705080615623, 0.0108429785718077, 0.016077897444899594, 0.016468345154342905, 0.034817972752664766, 0.03907470451667905, 0.047857329315905056, 0.057903830760291645, 0.02210817555896938, 0.015183293127587863, 0.047381985001266, 0.05033974289628012, 0.02298708536129977, 0.037365213568721495, 0.09246879816055298, 0.017401186616293023, 0.02578468354684966, 0.0442795871890017, 0.12418098721121039, 0.08917822901691709, 0.022947798183720027, 0.03592733679605382, 0.025438138749450445, 0.0156476265152118, 0.0299372635781765, 0.011420791004119175, 0.020326500359390463, 0.02117653001498963, 0.03605924739635416, 0.03073372119771583, 0.07266225240060262, 0.05403864084343825, 0.0003089184933092578, 0.057379343546926975, 0.039325175540787835, 0.08599992349211659, 0.0569935692474246, 0.049982697769467316, 0.04670480365997978, 0.04631759425891297, 0.04329156217032245, 0.018970517674461007, 0.09479301808668034, 0.08102832455188036, 0.011661530987891768, 0.04578407574445009, 0.02876300783827901, 0.059491765552333424, 0.025164076759080802, 0.05009441177493759, 0.016839868522116115, 0.010770890163257718, 0.06554593318807227, 0.03070479185719575, 0.017578518350741694, 0.017409954985071505, 0.04688751617712634, 0.023181097182844366, 0.018424088334930793, 0.025952037423849106, 0.0265246565187616, 0.0543343124778143, 0.032979919774723906, 0.057181808432298045, 0.040126118276800425, 0.014251491520553827, 0.02561932286646749, 0.03174413447933538, 0.016976320218028765, 0.05844692340386765, 0.08054410839187247, 0.032920327436711104, 0.02530180410082851, 0.0041335895324924165, 0.0018949909717775881, 0.08610470286969628, 0.022148986047665988, 0.050125492071466785, 0.011781703780538269, 0.029990094314728464, 0.02474476756261928, 0.03517553356609174, 0.08091967073934418, 0.03940721042454243, 0.012556047095651073, 0.019835320733753697, 0.024076715910008976, 0.030864108486899307, 0.023379485555259243, 0.07216503550963742, 0.051234238647988865, 0.06575164464967591, 0.051278964283743074, 0.08589702365653855, 0.03890556948525565, 0.029439113701560667, 0.003493743308354169, 0.05229167779907584, 0.01858505550106721, 0.016379577506865774, 0.05027181475556322, 0.07946618766124759, 0.01936210023372301, 0.026321465814752237, 0.020782167158488716, 0.032375138119927475, 0.0393679639590638, 0.015526747197977133, 0.007699547202459404, 0.0512802060028272, 0.08198152376072747, 0.04304505379072257, 0.03253802384382912, 0.028670279242630516, 0.05146288798589792, 0.04862056925360646, 0.030337283720395396, 0.061774750905377526, 0.009807009965048304, 0.02843123983724841, 0.07998371310532093, 0.0274204313089805, 0.03953835088759661, 0.05009684093030436, 0.10503842189375844, 0.02577141988357263, 0.10030435770750046, 0.01735756529628166, 0.004956476091008101, 0.049170043519032855, 0.02614306878032429, 0.0137523976320933, 0.021741337475499938, 0.04478055637862001, 0.03286367994067924, 0.02837405969122691, 0.02065633962463055, 0.0836864583460348, 0.02815251291862556, 0.01790881053810673, 0.04134195464264069, 0.03920472200427737, 0.06896457581647805, 0.056965885018663745, 0.03366271938596453, 0.03108219981991819, 0.023073844545121704, 0.047568463387766054, 0.039461174314575534, 0.07742379725511585, 0.01312595883583916, 0.030847246891685894, 0.05416888224759272, 0.017676992441660593, 0.048758552742323706, 0.027173147703121816, 0.04438083479180932, 0.03591333183326891, 0.07681604700961284, 0.0446844215371779, 0.0677011368264045, 0.02729945021149303, 0.03873181363035526, 0.04806080500462225, 0.010251958455358232, 0.03837973877255406, 0.03533533874100872, 0.13910347861903055, 0.01392612125658031, 0.023485052033460567, 0.050547384790011814, 0.03353409628782954, 0.0977851946705154, 0.048893221587474854, 0.06828897885446038, 0.062407735868224075, 0.02928154429953013, 0.055878563185355494, 0.09280614541577441, 0.04661337445889201, 0.030786646929170405, 0.017376952738101994, 0.05377286206930876, 0.008415814705326088, 0.03428141100864325, 0.005084692492216293, 0.013633242641974772, 0.044735277736825604, 0.05200864387942212, 0.02156983774953655, 0.05358902318403125, 0.043737977144441435, 0.12745699499334606, 0.1175927785890443, 0.23098898093615258, 0.12419283443263598, 0.14355700250182832, 0.13074244798294135, 0.06828180673931326, 0.10386054616953645, 0.09826213014977318, 0.12955634162894317, 0.1870082952082157, 0.11651400290429592, 0.1163085289299488, 0.07277168652841023, 0.24703030873622212, 0.10765654247786317, 0.1985919057790722, 0.13289630812193665, 0.10302750872714178, 0.1401876283011266, 0.08184502965637616, 0.15330599008926324, 0.19240521346884115, 0.1366385237446853, 0.1133293259356703, 0.13386659962790354, 0.14228218447949204, 0.13214386706905706, 0.11850585602223873, 0.14656539607260907, 0.14160397515765258, 0.14608879307551043, 0.15439962569092, 0.11743698694876262, 0.11713684376861368, 0.15209104599697248, 0.17901101362492355, 0.23398919137460844, 0.13253977868173802, 0.12803699315658637, 0.13575140706130437, 0.16468738365386212, 0.12813915338899406, 0.09351633409304277, 0.11575791133301598, 0.09486607595213822, 0.1374168169817754, 0.15722856031996862, 0.07065102710787739, 0.08931104546146733, 0.12820076436868735, 0.12555138367627347, 0.08785694491650377, 0.14264149591326714, 0.24772363581827708, 0.17883474379777908, 0.17265858235103743, 0.09469120390713215, 0.10226535783814532, 0.1661735653345074, 0.06375547604901449, 0.09697463030793838, 0.1191859245300293, 0.10636365506798029, 0.19393453640597208, 0.09467858315578528, 0.11305069231561252, 0.17898555499102387, 0.15542713126965932, 0.12833846626537188, 0.13096871227025986, 0.15058532250779016, 0.06314819399267435, 0.10314420317964894, 0.18721702615065233, 0.11309956719300576, 0.1410587586994682, 0.1546918164406504, 0.17306397988327912, 0.1376688927412033, 0.12468520658356802, 0.13062499357121332, 0.06503815829221692, 0.10621520517660038, 0.17422932306570665, 0.16928547620773315, 0.17224380746483803, 0.0825314831786922, 0.11234511089112077, 0.07182222604751587, 0.1080360606844936, 0.09550412957157407, 0.08769664101834808, 0.13766034319996834, 0.13471612547125134, 0.1743573083409241, 0.1452780794352293, 0.06731595285236835, 0.17398021928966045, 0.13310746821974004, 0.15818384263132299, 0.12320737088365213, 0.0833361375012568, 0.10542924449379955, 0.14020882573510918, 0.09186235070228577, 0.11251329258084297, 0.10078281310520001, 0.18969916153166974, 0.10659235529601574, 0.19234091549047402, 0.10565655372504677, 0.09861935169569083, 0.14127139800361224, 0.08656041377357074, 0.14705133571156434, 0.11761580806757722, 0.09806205731417451, 0.11711663699575833, 0.15664382598229817, 0.09241026772984437, 0.22441199528319494, 0.13893759037767137, 0.21014334021934442, 0.1776909508875438, 0.13190791330167226, 0.20524762863559382, 0.18384845262127264, 0.1357193123549223, 0.12724740909678595, 0.12092205137014389, 0.13957906381360122, 0.08508227273289647, 0.22370113485625812, 0.10285383768911872, 0.14130666825388158, 0.1366195383348635, 0.055878953342991214, 0.10798176431230136, 0.12561641447246075, 0.10566583608410188, 0.10430051506097827, 0.16992515831121377, 0.16544276954872267, 0.21587454554225716, 0.12591757545513765, 0.11784914268979005, 0.14232171592967852, 0.13197469471820764, 0.10896158923528024, 0.14879413933626243, 0.1981108651629516, 0.07067757139780692, 0.10078395982938153, 0.08856169174292258, 0.17447823685194763, 0.16410415566393308, 0.08424078752951962, 0.16388140618801117, 0.14486253101910862, 0.13885537907481194, 0.10538563504815102, 0.2081366271844932, 0.06859930684523922, 0.19310577373419488, 0.10120866846825395, 0.24216610831873758, 0.13852068489151342, 0.1202628274581262, 0.09103815457118408, 0.1697544524712222, 0.1688034992132868, 0.12101156370980398, 0.14100406877696514, 0.14835067598947457, 0.12179533950984478], [0.021763381381918277, 0.020398799961965, 0.029457851446100643, 0.0022268219493396047, 0.09134007551308189, 0.01206631783861667, 0.019059509238494293, 0.07874657413257019, 0.10914424407695021, 0.04374877263658813, 0.07677984038101775, 0.021463648715455617, 0.010808696438159262, 0.019851703961778964, 0.01697776380128094, 0.056630664970725775, 0.04400212064917598, 0.026116302270176153, 0.031468435523233244, 0.03657573128917387, 0.021531522573371018, 0.07629012130200863, 0.030722552511308874, 0.027740391104349067, 0.022639656772038767, 0.012215496306972844, 0.055892201739230325, 0.03203466960362025, 0.02593343029730022, 0.059722433531922955, 0.01497595148560192, 0.049520791840872595, 0.001736208370337928, 0.008176842305277075, 0.053611112891563346, 0.020527567248791456, 0.0042616091585452, 0.009214325741465603, 0.028746814600058963, 0.05664078192785382, 0.039738576393574476, 0.033634641606892855, 0.012677013774269393, 0.056763583195528815, 0.031136326558355774, 0.012512575901512588, 0.043064968793519905, 0.02335557058852698, 0.050899951585701535, 0.006586221362730222, 0.015366914881659406, 0.016683771541076045, 0.038738168110804896, 0.06384337347533021, 0.022283929699499692, 0.018051710013034086, 0.01575742196291685, 0.04033391623358641, 0.06346618942916393, 0.02819629030169121, 0.011578530039904373, 0.03813350180696164, 0.07518957142851182, 0.023159378973234977, 0.02221375221519598, 0.04647008143365383, 0.02219067863188684, 0.0579950733642493, 0.02471349897262241, 0.07018097197370869, 0.07691596129110881, 0.0418432257803423, 0.02364188352865832, 0.041488240007311106, 0.01691877535943474, 0.11899127997457981, 0.03210611594840884, 0.026412610031132187, 0.03989731966118727, 0.06242127264184611, 0.06742497985916478, 0.0264614764268377, 0.004313997575081885, 0.05897190594779594, 0.046964363660663366, 0.07180864856179271, 0.06919296391840492, 0.021019517011674385, 0.030687238156263317, 0.055021064555538554, 0.06314329496983971, 0.016438969677048068, 0.019016415479459932, 0.04241399247465389, 0.010633568246183651, 0.032237113919109106, 0.05220795675579991, 0.07982069506709065, 0.01033923332579434, 0.080513418252979, 0.04614676967529314, 0.10285723714956216, 0.026932797028816173, 0.024751339174274887, 0.024411639098876288, 0.008619549085519143, 0.01976490406585591, 0.05693912359752825, 0.05468766976680074, 0.05488338640757969, 0.044812203251889775, 0.008433370950764843, 0.028972111974975893, 0.01110558773923133, 0.0288755666198475, 0.04181236261501908, 0.0345234681985208, 0.05953573462154184, 0.018001673144421408, 0.059246882264103205, 0.009487802495381661, 0.04394234510670815, 0.050983743875154426, 0.021800863656348417, 0.014876848053453224, 0.027305373822205832, 0.0759845973391618, 0.02695811995571213, 0.03810720178963883, 0.04465508507564664, 0.007126634641151343, 0.04126214196107217, 0.0701737930732114, 0.005284609264760677, 0.06820281169244222, 0.025716599343078475, 0.035580381484968324, 0.023655532260558436, 0.035711521948022504, 0.03830096764223916, 0.032984689875905, 0.014564294467813202, 0.022450932434626987, 0.04035237577876874, 0.06320550306034939, 0.04391237082225936, 0.04207905062607356, 0.0670779159824763, 0.0589452666629638, 0.004454383501849536, 0.038963462093046734, 0.01992494672802942, 0.029628838878124952, 0.043461548763194253, 0.029695230137024606, 0.043469596188515425, 0.08661101212991135, 0.010692468478477426, 0.027107039732592444, 0.025455005433676497, 0.042520970305694, 0.05463893738176141, 0.051638061978987286, 0.05677751012678657, 0.02371740447623389, 0.026967185183561275, 0.030749185010790825, 0.02754108331698392, 0.03696931552674089, 0.011606760489355241, 0.011989250679367354, 0.03716456058568188, 0.09122557951403515, 0.07996418486748423, 0.018370813157941614, 0.044520718178578784, 0.04880607733502984, 0.026387010601216128, 0.07874080658491169, 0.024843409590955292, 0.10948590681489025, 0.029422662620033537, 0.012574223352463117, 0.04297208413481712, 0.07140997531158583, 0.06022893278194325, 0.06443569383450917, 0.011714999547361262, 0.01877926240142967, 0.01995764872325318, 0.017472135934180448, 0.05728464041437421, 0.03286896233579942, 0.05523959693631955, 0.00404182106389531, 0.007717050861434213, 0.012477239494078925, 0.017336998899866427, 0.03647312322365386, 0.03546184141721044, 0.02860400333468403, 0.024329904466867447, 0.036361857051295896, 0.04614980951217668, 0.009559493960945733, 0.053430564901126285, 0.01669272481064711, 0.02705399695384715, 0.040367727633565664, 0.03018369053357414, 0.039286750102681775, 0.027363183309457133, 0.029224221661154712, 0.027084597186850648, 0.020407497084566524, 0.02255039379399802, 0.030571629359786, 0.05835772319031613, 0.03165428965751614, 0.021770957225401486, 0.032499245567513366, 0.0068120399373583496, 0.03787412840340819, 0.01798137985835118, 0.0288790814312441, 0.008436036745219358, 0.017029186577669213, 0.0510426949975746, 0.02763392387091049, 0.07534177361854485, 0.02312041579612664, 0.055954911945653815, 0.02264396207673209, 0.08102295733988285, 0.042024618546877585, 0.032667647781116624, 0.0391193589062563, 0.054944759900016446, 0.033893122736896784, 0.0363216402807406, 0.034251189058912654, 0.005490229972305575, 0.03482826952157276, 0.04465592985174485, 0.014433861377515962, 0.07459038429494415, 0.088297911254423, 0.02998713929472225, 0.04124555177986622, 0.07348536287567445, 0.01765558635815978, 0.08641049824655056, 0.026113036820398908, 0.023557947050513964, 0.06685594682182584, 0.01092688790855131, 0.053441733587533236, 0.0624903067946434, 0.026411890784012418, 0.019014368000041162, 0.0281155174930713, 0.04476536737222757, 0.0477868261347924, 0.03408934488626463, 0.0796188512550933, 0.034841039550623724, 0.04846091674906867, 0.03959139875535454, 0.07488898041525058, 0.04512487558115806, 0.002917401388653421, 0.027989576304597513, 0.0236917202294405, 0.0590913552524788, 0.023224894921960573, 0.06963192179266896, 0.027447437002722706, 0.03806028448577438, 0.09743174577930144, 0.028986649587750435, 0.04826888794611607, 0.021643852349370718, 0.008723989195589508, 0.00972525921783277, 0.0784937519846218, 0.02966417358922107, 0.04469328320452145, 0.015935820693682348, 0.036222781121198616, 0.025699542669047202, 0.011758217139036527, 0.037957873195409775, 0.027271455552961146, 0.05705629302454846, 0.03198506190840687, 0.07864252078746047, 0.010974283579603901, 0.05773872283420392, 0.039234119533960304, 0.02744647178665868, 0.03935463074594736, 0.028186799293117862, 0.07297393067606858, 0.02774737322969096, 0.03912426810711622, 0.013741636066697538, 0.006406971918685096, 0.027408892820988382, 0.023066638503223658, 0.02007588175391512, 0.023112996015697718, 0.055356942782444615, 0.019526855321601033, 0.07986006366887263, 0.023208306437092166, 0.03803445944296462, 0.0152203241762306, 0.033036489239228625, 0.026391429560525075, 0.05401603205661688, 0.019142102217301726, 0.0008922455599531531, 0.0463855020435793, 0.010214871427576457, 0.03193298095305051, 0.059264429179685454, 0.03883115794243557, 0.017622621430616294, 0.04193396626838616, 0.023812234834102646, 0.06203414805765663, 0.021238132512995174, 0.023618219619882957, 0.021189021844682947, 0.026280109105365615, 0.017014881363138556, 0.008038302417844534, 0.042786267319960256, 0.02313199669255742, 0.06883897898452622, 0.009116896594475423, 0.011670092403489565, 0.020529029491756643, 0.002434191368852875, 0.011519539901720626, 0.021467531632099832, 0.027548782993108034, 0.06554956335042204, 0.036245830955782106, 0.009930860417495881, 0.0122813727274271, 0.025344796079610075, 0.12188605964183807, 0.08934430724808148, 0.18744153981762274, 0.1054282606180225, 0.1596145744302443, 0.06794677328850542, 0.08152488326387745, 0.18618724069425038, 0.21591451125485556, 0.26648420627628056, 0.1911614044968571, 0.10975103080272675, 0.14278453109519823, 0.10083768623215811, 0.10726901755801269, 0.17167564295232296, 0.0703027690095561, 0.10639071504452399, 0.07761327815907341, 0.1220866074519498, 0.08912007178046874, 0.1731504795274564, 0.2763476627213614, 0.09572643121438366, 0.10824490019253322, 0.10154720994510821, 0.2330696950001376, 0.1467706664864506, 0.12211361314569201, 0.17349896154233388, 0.07278353374983583, 0.1536573762340205, 0.08991241069244486, 0.14391559468848364, 0.1539540317441736, 0.08638389967381954, 0.10083122657878058, 0.0847736546503646, 0.1005886367389134, 0.16274396436555044, 0.10131301358342171, 0.13787147615637096, 0.08152127345757824, 0.13219752561833176, 0.09762373047747783, 0.04676337141011443, 0.1832309586129018, 0.13596882325197968, 0.12075500961925302, 0.052862190042755434, 0.11525825171598367, 0.11085888849837439, 0.12808869752500737, 0.14565537204699858, 0.09660171424703938, 0.14996123313903809, 0.04561595173020448, 0.16610234629895004, 0.1091323493580733, 0.09618028293230704, 0.08622060343623161, 0.0880013100270714, 0.1810221914201975, 0.09437561726995877, 0.13124167333756173, 0.13250401988625526, 0.08089137582906655, 0.14837689458259515, 0.09277449854250465, 0.193175893543022, 0.16489969726119721, 0.1507134163486106, 0.15075961101268018, 0.1864943185022899, 0.11212888892207827, 0.2175502691950117, 0.22652392195803778, 0.15416713245213032, 0.11308332306465932, 0.15923683398536273, 0.1639358111258064, 0.13760321055139813, 0.1527169674102749, 0.17691835734461034, 0.11458243083740983, 0.1634904478809663, 0.11777951142617635, 0.08423715058181967, 0.08220981008240155, 0.13226977602711745, 0.15175639252577508, 0.1354520781231778, 0.12825538643768855, 0.0881652712289776, 0.12744205365223543, 0.11525530687400273, 0.1580271010420152, 0.18230204417237214, 0.12082031182944775, 0.23792700150183269, 0.07021379271256072, 0.12368876433798245, 0.18321552872657776, 0.07049550688160316, 0.1558688711374998, 0.12432288245431014, 0.08344329853675195, 0.1921731544924634, 0.18517611495086125, 0.1356067569660289, 0.13963810993092401, 0.12329545829977308, 0.17664009013346263, 0.11877667291888169, 0.09928050264716148, 0.16579380285527023, 0.11709838440375668, 0.17865729331970215, 0.14847623210932526, 0.12268317544034549, 0.11263942545545952, 0.1700050083122083, 0.12638535749699387, 0.13049387346420968, 0.07916573235499007, 0.12004280569297926, 0.18460543985877717, 0.10438611225358077, 0.12500869136835846, 0.18291204715413706, 0.09137553575315646, 0.1021324328279921, 0.20577656025333063, 0.08227907493710518, 0.16407691926828452, 0.07648414160524096, 0.12931698161576474, 0.18502670153975487, 0.10682950328503336, 0.10357748850115708, 0.12856574835521833, 0.1263536156288215, 0.0650460496544838, 0.182561868801713, 0.1801368524985654, 0.07681741086500031, 0.1252100941325937, 0.21940946871680872, 0.17920492536255292, 0.15166358250592435, 0.17254887680922235, 0.07852799764701299, 0.13321561313101224, 0.09841871567602668, 0.2811963925404208, 0.118294465222529, 0.1921938769519329, 0.13649556998695644, 0.1190565957554749, 0.09627585458968367, 0.14032447524368763, 0.13408910483121872, 0.10386091936379671, 0.18309454593275273, 0.07526925179575171, 0.15239509753882885, 0.06651537652526583, 0.1649051798241479, 0.1563710549048015, 0.13802044173436506, 0.09828517319900648, 0.1162090285548142, 0.2961399863873209, 0.2080234068312815, 0.09972085830356393, 0.10610691098762409], [0.04640605486929417, 0.07995434610971383, 0.02031938761605748, 0.06522276731474058, 0.0663400295057467, 0.043547254521399736, 0.024349480202155452, 0.030240636585014205, 0.028325446049815843, 0.020824158298117772, 0.058398360652582984, 0.012136070390364953, 0.028872567495065074, 0.030450361581253152, 0.020590764304090823, 0.04795221904558795, 0.042034854247633896, 0.04980884013431413, 0.021010624810255, 0.04696028905787638, 0.042034498016749106, 0.04288569984159299, 0.062071650688137324, 0.011288102633053703, 0.006843158825566726, 0.06871573666908912, 0.059614023991993496, 0.05989385861903429, 0.046303307704095326, 0.031145340896078517, 0.021883709389450293, 0.03912336565554142, 0.03079787329105394, 0.030150330359382287, 0.025446918992591754, 0.025250554350869994, 0.029103401715734174, 0.03457332355901599, 0.02203088193865759, 0.021343471681965247, 0.05677767297519105, 0.01660898171498307, 0.037816069554537535, 0.057523301536483426, 0.0403570169582963, 0.010576094633766582, 0.04433096246793866, 0.020755242888948748, 0.03918596729636192, 0.04166755984936442, 0.05384045094251633, 0.03535196284896561, 0.06229138068322625, 0.009977573312685957, 0.042854307418955226, 0.028539579827338457, 0.04429455227883799, 0.020225997448765805, 0.03596621685262237, 0.025436878370653306, 0.0891297816165856, 0.048565733446074386, 0.05356154251577599, 0.04632213365818773, 0.03616984181904367, 0.01961546012067369, 0.06558537642870631, 0.019860048246170794, 0.007986644698706056, 0.03240259503945708, 0.0030229617176311357, 0.04805180084492479, 0.06351749346192394, 0.04125342957143273, 0.027148647499935966, 0.03610454300152404, 0.059315108960228305, 0.027942172151857188, 0.015151374840310641, 0.01607720703551812, 0.029197120972509896, 0.0729916879375066, 0.06317744563732829, 0.0814787768093603, 0.03182085643389395, 0.04931446969775217, 0.045712914384369335, 0.05329423025250435, 0.055253055678414445, 0.01720487286469766, 0.03720647369378379, 0.030334396553891044, 0.030645304692110846, 0.0660097932975207, 0.061151577558900626, 0.006714126485998609, 0.050195835796850066, 0.03656749726672258, 0.04858958734465497, 0.09122376782553536, 0.04338353080675006, 0.039409303705074956, 0.014729073304416878, 0.01601201847993902, 0.06932338513433933, 0.018658364424481988, 0.027448692292507206, 0.03141176427847572, 0.034878508254353485, 0.06489663624337741, 0.03318707990859236, 0.012245126234899675, 0.02716053543346269, 0.021323500700028877, 0.06573109860931124, 0.02052839506151421, 0.04222998734829681, 0.0313788926494973, 0.058141718352479596, 0.058980713332337995, 0.04649252397939563, 0.06202615491513695, 0.01598237158863672, 0.028962941574198858, 0.01153029892261007, 0.07229770267648356, 0.05749775469303131, 0.03385981345283134, 0.006647613090795598, 0.04594869851799948, 0.02697259989301009, 0.00976742762473545, 0.034165021896894486, 0.043929164563970904, 0.026014411755438362, 0.04353419950764094, 0.06789686703788382, 0.0270212152307587, 0.005266958448503698, 0.008589547659669603, 0.010909894847178032, 0.0077057651277365425, 0.04037477082705923, 0.034510233372982056, 0.03709884786180087, 0.04257452368204083, 0.03140382202608245, 0.011866885370441844, 0.05395121839163559, 0.02584634711300688, 0.052029122066284926, 0.012301135908014007, 0.03866768528574279, 0.01182943447825632, 0.048470260176275454, 0.0025356690374402596, 0.036063488240220716, 0.0444240676505225, 0.0035329164072339025, 0.006335657040056373, 0.0263577301188239, 0.02302602139700736, 0.03074516129813024, 0.006899151111221207, 0.022151445737108588, 0.018589165726942674, 0.012491024781151541, 0.06490184060697045, 0.03591304345588599, 0.02312290941232017, 0.03937374847009778, 0.026671452481033545, 0.02235692480046834, 0.08168351118053709, 0.01670226501300931, 0.028895427339843342, 0.024052107141220143, 0.07076936361512967, 0.055403639562428, 0.06608984007367066, 0.013282445126346179, 0.03127997920715383, 0.017680877054642354, 0.02705434979205685, 0.01106660335790366, 0.03818222740665078, 0.01923358061217836, 0.03354448465896504, 0.018655253341421485, 0.01770866984900619, 0.02827297493682376, 0.03965091645451529, 0.03151553603155272, 0.03991712270570653, 0.04497403046116233, 0.06317550502717495, 0.03765360112967236, 0.027230409273345555, 0.023998268780165484, 0.021057179097884467, 0.03903377528435417, 0.021411689896402613, 0.016849783615076115, 0.005824609909073583, 0.029447636101394892, 0.09587753417768649, 0.0412800485002143, 0.01658423723919051, 0.01803128780531032, 0.03831320162862539, 0.030755916078175818, 0.024621445519317473, 0.045654227890606434, 0.021329580373795967, 0.04684179648756981, 0.02928325081510203, 0.04338002617337874, 0.008714689873158932, 0.034524055131311925, 0.025876094088224427, 0.04052448279357382, 0.00965840825145798, 0.039219324077878676, 0.025229614760194505, 0.026233680346714597, 0.013767364418267139, 0.057297681857432635, 0.09678016895694391, 0.05537529376202396, 0.033758358896843026, 0.042444964205580096, 0.0742575153708458, 0.036970407968120914, 0.017865477595478296, 0.045358593575656414, 0.037555118557065725, 0.06169520624514137, 0.024381719097228985, 0.009853466713268842, 0.02049747252437685, 0.043208804646773, 0.037964760325849056, 0.03721260765035238, 0.046101080519812446, 0.013204196467995644, 0.04194851405918598, 0.04499388439580798, 0.0707085533067584, 0.02096650985601757, 0.04390965328950967, 0.01997870027220675, 0.016241334478503892, 0.016566218741770302, 0.04868789689083185, 0.07855728321841784, 0.05890694300511053, 0.07100003159471921, 0.02604619094303676, 0.02406505019670086, 0.04265741351991892, 0.04505508825449007, 0.15091043577662536, 0.010639383291293467, 0.04526536286409412, 0.04795574403500982, 0.042156790383160114, 0.020109764400071332, 0.03318331743191395, 0.06792399486792938, 0.016614869702607393, 0.06011388038418122, 0.055426960811018944, 0.029358052515557835, 0.02981317648664117, 0.024597454217395613, 0.03537686508415001, 0.04331726846950395, 0.026739594360281314, 0.04745265103078314, 0.06274862507624285, 0.0611167008589421, 0.010505236918106675, 0.05640402748914702, 0.0410565458504217, 0.031846986817462106, 0.028584084939211607, 0.05054191579776151, 0.027167780491124307, 0.05370765485401664, 0.02094674582726189, 0.09601732596222844, 0.039510846470615694, 0.012013684725388885, 0.02515759166064007, 0.037776877371860404, 0.0436389449584697, 0.01031126665683197, 0.08394478341298443, 0.02361744948263679, 0.02263244055211544, 0.03279062546789646, 0.0637167656262006, 0.026335452117824128, 0.021618505673749105, 0.024695451637463908, 0.035329326920743497, 0.030564358857061182, 0.006310352772873427, 0.02154386512536023, 0.03537175232278449, 0.020581848353945782, 0.09154721868357488, 0.053690559164221795, 0.03197648183309606, 0.04295739045898829, 0.007512665935792029, 0.01847016764804721, 0.0463273719485317, 0.03508998387094055, 0.049161137746913094, 0.07583532642040934, 0.021495304070413113, 0.009583372456420745, 0.04774382397798555, 0.021331480271848183, 0.02485094132966229, 0.03278820649055498, 0.024715843311111842, 0.027571457937093716, 0.016208016712750708, 0.017278970585071614, 0.025847001899299876, 0.018223075728331293, 0.018284457702455775, 0.07999790805791106, 0.04594484443909355, 0.032090183946170976, 0.012090521182731857, 0.03293453596000161, 0.023901455403704728, 0.031317498801009994, 0.033173577061721256, 0.03522623709536024, 0.03881805543122547, 0.01583218973662172, 0.05656020250171423, 0.06566289905458689, 0.05558400774108512, 0.10214870409773928, 0.019516149735344306, 0.026179506110825708, 0.006357597893968756, 0.1240123441176755, 0.12984170631638595, 0.09969584071742636, 0.23526782276374952, 0.1098200853115746, 0.1210231530879225, 0.14946751748876913, 0.09106376248278789, 0.18588724679180554, 0.136095166472452, 0.09129198095096008, 0.13569658143179758, 0.25432987990123884, 0.09376786023910556, 0.14999750762113503, 0.12019878732306616, 0.22973187267780304, 0.18623423602964195, 0.10838541800954513, 0.11023614262895924, 0.08843861227588994, 0.11117564900113003, 0.11329073764915977, 0.0748658695125154, 0.0773180950699108, 0.19926039847944463, 0.1478412997509752, 0.11570540629327297, 0.2083414090531213, 0.1846527744616781, 0.16630380334598677, 0.18090413989765303, 0.0897029469321881, 0.07759040474359478, 0.109947195276618, 0.13386251484709127, 0.24141331442764827, 0.12379544361361436, 0.1904403389032398, 0.08904222345777921, 0.11697844655386039, 0.08373293120946203, 0.22206670684473856, 0.08309544077409164, 0.1385459535356079, 0.0956257094762155, 0.17095117111291203, 0.15657454755689415, 0.13845344207116536, 0.1276984584650823, 0.21190317507301057, 0.24708147027662822, 0.12953560559877328, 0.10932311947856631, 0.1867275717003005, 0.13263295511049883, 0.09992627120975937, 0.1472860409745148, 0.15947955953223364, 0.1336164509079286, 0.1758995641555105, 0.15254274675888674, 0.06654582239155259, 0.1075910638485636, 0.135650970307844, 0.1852022521197796, 0.12400193539048944, 0.10517801011779479, 0.18236202666802065, 0.19256454706192017, 0.11008195911667176, 0.10134048746632678, 0.12348656090242521, 0.126435392669269, 0.09793798040066447, 0.07754113631589071, 0.10002576479954378, 0.17975954631609575, 0.1593855417200497, 0.11722841885473047, 0.1428669188171625, 0.2499926026378359, 0.12250514142215252, 0.21375241370073386, 0.1279951139752354, 0.16942951562149183, 0.20216703893882887, 0.1145721578172275, 0.23060254167233193, 0.12714761016624315, 0.07589554640331439, 0.14892766145723207, 0.11420987440007073, 0.15656849502452783, 0.13596857897937298, 0.1519484586481537, 0.1332900348518576, 0.11622726757611547, 0.18374118980552467, 0.15225181808429106, 0.12187983069036688, 0.11538345499762467, 0.10729959234595299, 0.14516469623361314, 0.1800063295023782, 0.07544785578336034, 0.1831809641527278, 0.18196034750768117, 0.06504688425255672, 0.10656393824943475, 0.11210468557796308, 0.14616060922188417, 0.13832390973610537, 0.10244371076779706, 0.2002884197447981, 0.07741831469216517, 0.12312984147242137, 0.145457049831748, 0.11685470890785966, 0.19776899207915577, 0.06586644598948103, 0.137690022321684, 0.13542428532881395, 0.10260834371937172, 0.1017086673527956, 0.10669416947556393, 0.06959006975271873, 0.09644827712327242, 0.1544045518551554, 0.15144881260182175, 0.1308994609862566, 0.10245235530393464, 0.07330272160470486, 0.10420846500034843, 0.10063856334558555, 0.13761021303279058, 0.1740290873817035, 0.14766823260911874, 0.09433668293058872, 0.10795446684850113, 0.07202530479324715, 0.1833746451884508, 0.10418053649898086, 0.09290521152849708, 0.1671863602740424, 0.1410660325948681, 0.08734544486339603, 0.1254909262061119, 0.14948939345777035, 0.10574284302336828, 0.17861451847212656, 0.08100218738296203, 0.08639583510479756, 0.1149007316146578, 0.07826805766671896, 0.07480176830930368, 0.07466853795839207, 0.11466263367661408, 0.11151360693786826, 0.14202028353299412, 0.10700263149504151, 0.11909054964780807, 0.10799423578594412, 0.09608053149921553, 0.1171661021986178, 0.10781434936715023, 0.062476430753512044, 0.1969642359763384, 0.0978578929124134, 0.13593515434435435, 0.12108377340648856, 0.11425574336733137, 0.17733009239392622, 0.14821682817169599, 0.13417960783200605, 0.09808699347610984], [0.007804506391819034, 0.03698575643024274, 0.048704673669167926, 0.042392747543220005, 0.02551525255798229, 0.045099176067326746, 0.015451687654214246, 0.09094634878316096, 0.05192332149350217, 0.044809041278702874, 0.021597796784979955, 0.003503576765069738, 0.05950961780867406, 0.02824397774280182, 0.030104400323969976, 0.04322262640510287, 0.03073475257094417, 0.005218410116088177, 0.04097294355077403, 0.08974804915487766, 0.07441501691937447, 0.04960320670423763, 0.030987751137997423, 0.023574525357357094, 0.04211100623277681, 0.033134815748780966, 0.06812142820230552, 0.01448032575925546, 0.03951162339321204, 0.060148200685424466, 0.04073953089703407, 0.05213341968400138, 0.013985759395706867, 0.056489868954356225, 0.011450589717631894, 0.03368284473461764, 0.026741336498941694, 0.05899379548749753, 0.03916617103719285, 0.02183059706086559, 0.05662150814064911, 0.04876597930810281, 0.02422360347450844, 0.04986647150612303, 0.03428042374019112, 0.02883142452420933, 0.00800570729188621, 0.01723513043751674, 0.020451320268745934, 0.025861909313659583, 0.03536539784233485, 0.0031720956571267118, 0.026420065434649587, 0.02106458361127547, 0.032095846320901594, 0.03600291541910597, 0.03382276204813804, 0.09494547133467027, 0.04512734544862594, 0.0326402485370636, 0.06883375426488263, 0.03221281558009131, 0.014785900612228682, 0.008759113560829843, 0.04114089114591479, 0.03396912883701069, 0.029144673608243465, 0.02022171250012304, 0.016227444866672158, 0.00975695952573525, 0.003947512753906527, 0.018664515344426036, 0.013374272118588644, 0.040696338750422, 0.007463670618432973, 0.020513022850666727, 0.03407760962311711, 0.03184336344046252, 0.06496500543185643, 0.02812176171158041, 0.0509719102244292, 0.005891016435011157, 0.040559145755001476, 0.0441908246305372, 0.013647516474260815, 0.018434690444597175, 0.006848593466981713, 0.02949851265709315, 0.05475847150332161, 0.057964871770569255, 0.0266744125900524, 0.1056741549234305, 0.02382252990667309, 0.02698942077612238, 0.03407868170844657, 0.02139168668405286, 0.09252000041306019, 0.029417054528104405, 0.029210494897727455, 0.05771287064999342, 0.03249001070590956, 0.01705074363521167, 0.0698000288435391, 0.11885550511734826, 0.049419618876917024, 0.022865028785807744, 0.08619402521955115, 0.053886933983968835, 0.010430223175457545, 0.012931789254902728, 0.10319253522902727, 0.1078275197318622, 0.028775343604918038, 0.05354968172365001, 0.015149966880146946, 0.01812334804396544, 0.029908232457403625, 0.03678394654499633, 0.03150398736553533, 0.019436598289757967, 0.010989439507414187, 0.0826881704851985, 0.03489887787561331, 0.025865498763908232, 0.05786463857761451, 0.0339245931910617, 0.0718629245779344, 0.04661147456083979, 0.09172509663871356, 0.02922580943309835, 0.016149018092879226, 0.04063035800520863, 0.013670729157248778, 0.03098794791315283, 0.051154409003044875, 0.04143941602004426, 0.03286576982853668, 0.02424603414588741, 0.03193789693926062, 0.05318267570276346, 0.04256300555009927, 0.05929933302104473, 0.013525751668826809, 0.04923074186912604, 0.033592457084783485, 0.01356516607172255, 0.026838402629696896, 0.011850857525132596, 0.07750217483511992, 0.0651053875418646, 0.020492205396294594, 0.029923455390547003, 0.02855775778048805, 0.007426898261266095, 0.04490528468574796, 0.0342410754944597, 0.04354227068168776, 0.02985201243843351, 0.037368755521518845, 0.057978299978588305, 0.10681624471076898, 0.06875771763069288, 0.008664650460039931, 0.03536017651536635, 0.017098700793992196, 0.04702724689351661, 0.03888484024043594, 0.07427883494113173, 0.029222219982849698, 0.02807347715965339, 0.06176007419292416, 0.06606089376977511, 0.06681742638881717, 0.02332604244085295, 0.046107462141662836, 0.032491140466715605, 0.03179480068917785, 0.04268977285495826, 0.02244670346512326, 0.052419344162834544, 0.02463446999900043, 0.03654355855126466, 0.02626228399042572, 0.03718130343726703, 0.06403459142893553, 0.01945814856195024, 0.024439469212666154, 0.061879340293151994, 0.04160122965861644, 0.04795461427420378, 0.023006410038630878, 0.04947006456287844, 0.08893444495541708, 0.06113592375602041, 0.05641004948743752, 0.030473475876663412, 0.04104774525122983, 0.04004722501018217, 0.07218358665704727, 0.011413700313174298, 0.021042616040046726, 0.021206548404214636, 0.019050393120518753, 0.018117918067478707, 0.04398075018876365, 0.010713917818585677, 0.04907910625583359, 0.05459297002692308, 0.020951027383229563, 0.01575390206250761, 0.021771623886057308, 0.050395589720989974, 0.01136775840339916, 0.027199915909607495, 0.04150910495913454, 0.053612646380705495, 0.037357247567602565, 0.10417367650994233, 0.019118680884795528, 0.04550751165619918, 0.07415762823075056, 0.0365198912498142, 0.05709389064993177, 0.0374776162872357, 0.040797118164066754, 0.04682204433317695, 0.04109413329777973, 0.043205215196524344, 0.08544980801109757, 0.06454892097307102, 0.06134443078190088, 0.0500849699601531, 0.06679801350193364, 0.03314933979085513, 0.03901681190888796, 0.09029842926455395, 0.0250684406408774, 0.016677688474633863, 0.017163980951798812, 0.06478303591055529, 0.008146678879191833, 0.03719773077006851, 0.031329451195363484, 0.04024490261716502, 0.04818814906424709, 0.023576281066717844, 0.03334827947297266, 0.022974213551996008, 0.0164579822282706, 0.02705420899604048, 0.032226766260074716, 0.026460998059649552, 0.040788592371557436, 0.02809577721304127, 0.03404823923483491, 0.03713416900219662, 0.03297689350854073, 0.023252414605979408, 0.024128142079072337, 0.05466914576079164, 0.019321769808552096, 0.03126148912789566, 0.044691651327801604, 0.023831242296312536, 0.02760530835283654, 0.06970130199832575, 0.09126327891967126, 0.08743501148585762, 0.0008747668689466082, 0.028559735710067407, 0.006809022576947297, 0.04872440207483513, 0.03529158341033118, 0.07672173742737089, 0.02169074590450951, 0.028334211025919234, 0.08176090488476412, 0.0280480948609433, 0.02405655663460493, 0.058984513128442426, 0.04784458303557975, 0.05601584439032844, 0.03851919128958668, 0.02737398219427892, 0.011402492611003774, 0.04116798165653433, 0.04140451217868498, 0.08364026368196521, 0.07565239337938172, 0.04530668564672981, 0.07993843446352653, 0.02081722706290228, 0.039841035181390386, 0.03379434500155704, 0.0420818936878017, 0.049450264911034277, 0.005389598988196147, 0.04698031262627669, 0.01894608702111457, 0.0410352093167603, 0.028357242200789706, 0.040308949537575245, 0.02756138169206679, 0.03976581957457321, 0.02871270464467151, 0.030926058734101907, 0.024296545989013145, 0.027548021337549602, 0.02877560823357531, 0.01860219020662563, 0.019470903323963284, 0.07431536048118557, 0.026495876455945627, 0.03966789000800677, 0.014240307567108954, 0.02563250849821738, 0.05146066917638693, 0.048749229671167474, 0.012018665172425764, 0.07946297819060938, 0.0028710924338416328, 0.014733258169144392, 0.03350141464865633, 0.019024159260360256, 0.03094338851847819, 0.0558990922623447, 0.02291333539012287, 0.0035022688888212933, 0.02400612282300634, 0.03059057405750666, 0.06135648834918227, 0.04500199967463102, 0.04695290320419839, 0.044561576164726696, 0.0172072867530265, 0.04066563164815307, 0.02177253651565739, 0.051584780016647916, 0.010819178107859833, 0.01435256440059415, 0.07088198007217475, 0.008804073291165488, 0.034301475289144685, 0.03290778810956648, 0.023355928515749316, 0.032571136352739165, 0.054014800515558035, 0.07861865671085459, 0.05436834100899952, 0.028044658081073846, 0.03471001783119781, 0.03406661057046481, 0.07341107686183282, 0.07359139075768845, 0.12180889663951737, 0.10770488809794188, 0.10465418786874839, 0.10392088150339467, 0.08758601266890764, 0.1304067631385156, 0.19089544591094765, 0.12733769496636732, 0.20768001382904394, 0.13715575741870062, 0.14507849514484406, 0.10619748184191329, 0.11832201374428612, 0.15799742192029953, 0.19393140157418592, 0.08069675162966762, 0.13308929705194064, 0.1849047009434019, 0.12467258583222117, 0.1173404585570097, 0.21928927302360535, 0.18368507495948247, 0.1018761433660984, 0.16073697991669178, 0.17268497736326285, 0.10740986107183353, 0.1495752688497305, 0.07819361558982305, 0.12152100780180522, 0.10888659075966903, 0.0648944852873683, 0.24152402420129093, 0.14282788948288985, 0.1141846871801785, 0.07862848189792462, 0.16691658832132816, 0.22319706476160459, 0.1199241570596184, 0.10520403872111014, 0.17605490796267986, 0.10539890719311577, 0.1774514958794628, 0.25179186037608553, 0.12587779973234448, 0.10895725339651108, 0.10245564619877509, 0.11974810436367989, 0.25492148101329803, 0.1798005841140236, 0.10458381021661417, 0.09760085706199918, 0.16634835595531122, 0.10958714423967258, 0.1841273440846375, 0.1847404276153871, 0.12740900899682725, 0.14893897942134313, 0.12718045126114572, 0.09685790192868028, 0.11297843512147665, 0.08591514054153647, 0.11944114869194371, 0.17558024557573454, 0.10602793629680361, 0.1505190296364682, 0.09727035622511591, 0.11032214694257293, 0.12210479219044958, 0.1367083042860031, 0.07170914140130792, 0.11684778785066945, 0.14901687524148396, 0.11309807441596474, 0.16244657603757723, 0.1478015918816839, 0.08054689038544893, 0.23814318275877408, 0.09321037586778402, 0.18526101325239452, 0.09501636467341866, 0.1873839729066406, 0.15955102284039768, 0.07686197025967495, 0.09970509593508073, 0.16910923352198942, 0.1021830854671342, 0.1801395530679396, 0.11505592614412308, 0.19118603531803402, 0.15476805663534574, 0.0934650639870337, 0.10709331091493368, 0.1281925676656621, 0.10840504802763462, 0.1775593693767275, 0.12231280388576643, 0.14253541374845163, 0.19948238799614565, 0.1495214474520513, 0.2030695312257324, 0.185087579701628, 0.3119274606662137, 0.09704205633274146, 0.11441610833363873, 0.11075335594692401, 0.12573815722550663, 0.07367748328085456, 0.08537810721567698, 0.1580016424081155, 0.24201319366693497, 0.1852287014148065, 0.18886731831090792, 0.097488600228514, 0.07217229583433696, 0.14320111088454723, 0.25334106438926285, 0.13314995808260782, 0.09861780463584832, 0.15306079467492445, 0.16016607412270137, 0.15758876741996833, 0.1338186679141862, 0.1214005814066955, 0.149155214961086, 0.12114693144602434, 0.11174126900732517, 0.1270442150001015, 0.16559222367193016, 0.11512257185365472, 0.06919094188404934, 0.19698505343071052, 0.12101461711738791, 0.12246345223060676, 0.10923212114721537, 0.1413543014121907, 0.0707645799432482, 0.20455221166568144, 0.09493693536413567, 0.12773201880710466, 0.06897552058632885, 0.08306033337222678, 0.15073586228702748, 0.1629432908126286, 0.1278809979557991, 0.15243331263107912, 0.11584669085485594, 0.15562183010791028, 0.24022870085069112, 0.17687495824481758, 0.10746707514460598, 0.08715495972761086, 0.08482423943600484, 0.1078497621097735, 0.12474071074809347, 0.17506766665194715, 0.1181477252393961, 0.10919156510915075, 0.13503268919885159, 0.14996474795043468, 0.19014561043253966, 0.14126552189035074, 0.11347373175833907, 0.1356206126511097, 0.16006487741002015, 0.10681363235094718, 0.23805562459996768, 0.14792272395321301, 0.16729128892932618, 0.1141990449811731, 0.14421134096171173, 0.13179474723126205, 0.09532921681446688, 0.0926488135010004, 0.10148441831448249], [0.0672200351421322, 0.06671783780413014, 0.020924880036285946, 0.03541745165629046, 0.06217323416577918, 0.02859231217631272, 0.06864525045135192, 0.03437092674097844, 0.06827412572290216, 0.020418224723211358, 0.024852893814178448, 0.103991700203291, 0.014049645164050162, 0.01608088469531919, 0.010174375609494746, 0.02405736918028976, 0.04431776496182595, 0.024378021081377352, 0.05237195866980723, 0.03858828651053565, 0.05073936270283801, 0.026608051865228584, 0.014138835199576403, 0.037155410540955405, 0.046539247900779755, 0.028563718710626875, 0.025184750024761473, 0.029354686981865337, 0.018301139485889246, 0.02904065079720957, 0.018800838118685142, 0.03311520947941712, 0.00474925573715674, 0.018458232217069184, 0.03358193639931934, 0.036219863420618434, 0.007710441082183803, 0.041575828700193336, 0.03828746818804315, 0.1156054852264268, 0.008815241977572441, 0.04372206210557904, 0.10895855618374688, 0.0623032007632511, 0.014805735887161322, 0.03382015986634152, 0.015879422559269836, 0.030666054292981113, 0.0287174781385277, 0.01494747506720679, 0.03920536321986999, 0.048916234102632315, 0.04014510368662221, 0.05205992416345647, 0.05758398292320115, 0.017210699784170305, 0.01918157429567405, 0.04572377433734281, 0.019865534201796566, 0.017962791391515305, 0.01796936639584601, 0.03310039705996003, 0.03297959407791495, 0.01469560117194695, 0.06115113651113851, 0.015143778640776873, 0.033798165153712034, 0.05895732423024518, 0.005141575779167137, 0.04912346887535282, 0.007263653761973339, 0.03842396229239447, 0.07457955487604652, 0.02945507623787437, 0.059945332285548956, 0.01876698261392968, 0.025758442901340977, 0.010186412820725568, 0.018970471873347248, 0.014838217358504022, 0.0366960050139044, 0.10293053250227656, 0.0611066585406661, 0.021762399202478782, 0.02539270743727684, 0.051159460696258714, 0.06112249554800136, 0.023709971125104597, 0.009165377921557851, 0.03812648914754391, 0.07721596197890383, 0.021152475948578546, 0.027472276473417878, 0.019757192515368973, 0.014944525136213218, 0.04113662994599768, 0.041990518769515414, 0.030658573444400514, 0.026063870172947645, 0.05308413206200514, 0.013605322622294937, 0.02544595208019018, 0.009718422129351114, 0.025703990466094444, 0.028776724423680986, 0.04363112144970468, 0.05215800300772701, 0.027063581260985563, 0.021953501805130924, 0.010132991758707379, 0.03395900170185736, 0.02019170089624822, 0.010202777389037822, 0.06503589198525463, 0.015547315290729915, 0.02749046460459275, 0.013525428516524178, 0.0242901660635003, 0.09340774134865829, 0.030842310549425225, 0.043912503136587996, 0.028217813432482735, 0.003156829891460282, 0.03879033727571368, 0.021406399019594704, 0.09698562257524047, 0.019800321897491813, 0.036410396053854904, 0.0319416695939643, 0.026810709919248308, 0.05095458044005292, 0.05350624191175614, 0.04859284431274448, 0.053611353771494966, 0.039828896189906766, 0.009949789000009852, 0.027360667640875493, 0.02595934015698731, 0.06019452427114759, 0.044865722701485665, 0.02304377356943275, 0.008685040437350315, 0.054615612740495374, 0.06354259247226374, 0.09520237826343093, 0.020918037010622875, 0.06756266139979873, 0.034664087795785496, 0.06040166744164058, 0.01975280069746077, 0.04194514513281839, 0.006018494505302182, 0.004387625834039811, 0.03742537248347487, 0.061331321485340595, 0.029128561794225658, 0.007571722231140094, 0.007802834651166839, 0.024831884673663547, 0.04867934734959688, 0.018745554478040764, 0.014449079221646701, 0.037793355594788275, 0.027819009564284767, 0.034753841015377214, 0.12980564896549496, 0.004249380261171609, 0.054210520549012084, 0.061367222773177285, 0.06020228671176093, 0.01856021603037204, 0.020919241410280977, 0.027655584405043294, 0.038859581774366755, 0.035640021320432425, 0.007852377885553454, 0.056246634506221325, 0.02935825946873852, 0.09528558022741761, 0.01863776410131582, 0.017490661636527096, 0.02618110745346972, 0.0617458928110344, 0.038076633787048716, 0.010684894331331764, 0.018628839669483047, 0.030528515244701078, 0.07988960708358459, 0.030831979853766303, 0.04023091122508049, 0.024080195098317096, 0.013684468643207635, 0.026942747744864652, 0.047376298877809725, 0.04770246726859893, 0.06391123376254525, 0.06365334974335772, 0.04462466295808554, 0.025499625896502818, 0.027229912246444395, 0.01995912453691874, 0.020798625025366033, 0.024840802320146134, 0.06209754358444895, 0.0385842933319509, 0.009255593393131025, 0.013171759101429155, 0.005974490237089672, 0.025316321357552494, 0.056662858064685545, 0.04347918388832893, 0.026566528914762393, 0.012397851745065833, 0.01134807919152081, 0.029860755362148796, 0.033383699000946114, 0.005554766286097999, 0.08555725403130054, 0.0759464433150632, 0.04076031442465527, 0.045714576795165024, 0.031665105505713394, 0.024917446243177568, 0.007361248301874314, 0.02835050774072962, 0.008038584009877272, 0.019155591493472457, 0.04645033945728626, 0.047664191108196974, 0.06098563503473997, 0.09266289988798754, 0.005056420482495534, 0.06933884216206414, 0.04537771129980683, 0.015703427538807904, 0.03665480436757207, 0.03087574875514422, 0.02279889367387763, 0.036016794852912426, 0.0667671605146357, 0.0523380862016763, 0.03836986269535763, 0.01958235100443874, 0.029507235224757875, 0.025172801023083072, 0.032241544752780876, 0.026321436977013946, 0.03993334647800241, 0.01242513394182814, 0.028916136228612492, 0.039213074770356925, 0.019838793136711632, 0.030056125950068235, 0.01588891526418073, 0.024296179580103074, 0.044831921479531696, 0.013561352704917746, 0.030808302374290567, 0.03551072307995387, 0.02451580609860165, 0.027995102972324406, 0.04330967905532036, 0.02837686882620411, 0.03936346187921507, 0.018217986715691428, 0.029678392290536846, 0.016710760271442787, 0.030648273282817433, 0.06207509086068187, 0.013463164446875453, 0.036223340912589004, 0.04414346967158573, 0.04330300905608705, 0.0244903271086514, 0.10376082866319589, 0.06210772839507886, 0.02088405767322651, 0.05155528749206236, 0.014525821532255836, 0.02085571696183511, 0.04424851707049778, 0.015505922958254814, 0.015673541463911533, 0.014253695063026888, 0.009816542533891541, 0.026991492004266808, 0.034909941389092376, 0.021340396221993223, 0.04799352825752326, 0.04611561813258699, 0.06557947317404406, 0.01758553779550961, 0.03143317545098918, 0.008986446540802717, 0.06537250642265592, 0.014518898778728076, 0.007618740467088563, 0.009528806366558586, 0.012632917479744979, 0.04251179311956678, 0.01492781112236636, 0.02372968426373388, 0.025882784443508302, 0.0769917197259409, 0.022266365820541978, 0.016718042648530433, 0.06021452748349734, 0.005622922584214913, 0.06731898590390172, 0.034123787323811224, 0.021992889066625918, 0.03439652108188186, 0.020491788097258126, 0.02814983100896435, 0.004870379326998123, 0.028442347455503683, 0.032284557087613006, 0.024437998488013233, 0.04993328345673425, 0.039498554808752875, 0.015677522768133452, 0.01879617658310703, 0.10332081227430276, 0.05010375180946929, 0.04349710060549634, 0.029459642778549875, 0.027978193879659687, 0.04555732969726835, 0.03302648084770356, 0.036234475672245026, 0.06717163523925201, 0.031238659817193235, 0.006176901049911976, 0.032117121786411316, 0.10467573135559048, 0.02196300638440464, 0.03566220263019204, 0.017288739793002605, 0.03101103167448725, 0.025804384811116115, 0.029950366089386598, 0.01568159567458289, 0.054223897866904736, 0.07719344818698508, 0.03465974177899105, 0.029361044854990075, 0.02920979939933334, 0.0325502849716161, 0.06610594170966319, 0.06874554471245833, 0.0353173779190651, 0.035626253844904046, 0.10956616393689599, 0.14928332237260683, 0.16172223990517004, 0.16890093684196472, 0.1477735276733126, 0.19764153606125287, 0.16729351452418736, 0.09697939362376928, 0.14106611401907035, 0.10326118940221411, 0.057165218251092095, 0.18953616384949, 0.09595545713922807, 0.09324494722698416, 0.15172075586659567, 0.09981718313481126, 0.09652520942368678, 0.1390872209199837, 0.12528537080756255, 0.13807294677410806, 0.1765433717519045, 0.1212267814470189, 0.07184910960495472, 0.1256200514201607, 0.07518912359539952, 0.15604990428047522, 0.13001831541103975, 0.1121237456266369, 0.1860477203237159, 0.10461196941988808, 0.10281791604523148, 0.09721798689237662, 0.10305383588586535, 0.2183478463973318, 0.1380271456603493, 0.1640248077788523, 0.07763136790267058, 0.09760785275804144, 0.08872415338243757, 0.16771340556442738, 0.16079768165946007, 0.22161732667258807, 0.14984803992722714, 0.07272781245410442, 0.1267538834363222, 0.20433953164943627, 0.09205238800495863, 0.1335473217602287, 0.0751331037442599, 0.10958951911223785, 0.14948583793427261, 0.10382531663136822, 0.06638373394629785, 0.1123600115201303, 0.23260622844099998, 0.07089624966361693, 0.15649598677243504, 0.1544719168118068, 0.139933598360845, 0.1492967437952757, 0.12147496241543974, 0.11033984313585929, 0.11959797170545373, 0.16984120995870658, 0.08731642392064844, 0.13464063166507653, 0.06593083896275077, 0.1577794493309089, 0.09607969011579241, 0.10498067177832127, 0.13684444555214473, 0.11789898787225996, 0.11878985006894384, 0.17880372117672647, 0.1746721893016781, 0.11066543816455773, 0.06386969384870358, 0.10461912796433483, 0.14053335546382836, 0.10732620448938437, 0.149273795740945, 0.24836308721985134, 0.21627914240317686, 0.09733187899525676, 0.10792411597711699, 0.14032010547816753, 0.08406698078449283, 0.10163927357643843, 0.08868179244122334, 0.10540787742606231, 0.17247627356222697, 0.11443113109895162, 0.1638981117201703, 0.11244471304650817, 0.21283522434532642, 0.21064228058925696, 0.10009583032556943, 0.10179584553199154, 0.2376318116273199, 0.15197749994695187, 0.16893115879169532, 0.11446940047400338, 0.16869397009057657, 0.10653822177222796, 0.11530600701059614, 0.10465349576302937, 0.09252615472567932, 0.07382258120924234, 0.0735523139259645, 0.09129617429737534, 0.12769758994025843, 0.11649344329323087, 0.13664210640958377, 0.14862092291670187, 0.16966331164751733, 0.16121386789849826, 0.1272211226501635, 0.11613865090267998, 0.1993526928126812, 0.07519563074622836, 0.1258010302803346, 0.1337659050311361, 0.05762593674340418, 0.17293068846421583, 0.11148841971797602, 0.2114609330892563, 0.11104081052222423, 0.1535548088806016, 0.13500181585550308, 0.13228497521153518, 0.13951579720846244, 0.14088673650154046, 0.17617620288261346, 0.07040116337261029, 0.10244827052312237, 0.17741254796939238, 0.10513288075370447, 0.08876315557530948, 0.13307181798986026, 0.08001198087419782, 0.09592678224933998, 0.07222613080271653, 0.1346220669469663, 0.10476390698126384, 0.18127848766744137, 0.10394045723868267, 0.28099424338766504, 0.12010508163699082, 0.1395623039986406, 0.13818098311977728, 0.10863201120602232, 0.14487456823033945, 0.16082551516592503, 0.1717144822967904, 0.14834988888885292, 0.11132549667464835, 0.1111934876867703, 0.10703790853066103, 0.24659547635487147, 0.14134258989776882, 0.11248070932924747, 0.04508179539282407, 0.08508503437042236, 0.0973434073052236, 0.08111566557948079, 0.20320755881922586, 0.12553588593644754, 0.154910589701363, 0.14620028994977474, 0.14861632244927542, 0.0735099326286997, 0.1417639601443495, 0.08956582179026944, 0.1430256281580244, 0.12540222810847418, 0.11972975677677564], [0.024854110088199377, 0.05205495389444487, 0.039088631447936804, 0.031268898730299304, 0.025329700371782695, 0.04571219852992466, 0.04052880845431771, 0.022107295159782683, 0.013985441332416875, 0.0321945969148406, 0.016705323509605866, 0.045989373299692354, 0.011198619131131895, 0.04579026398382016, 0.03784301078745297, 0.008163140138744243, 0.06416461230920893, 0.024933478329330683, 0.04813349646117006, 0.031552282095487626, 0.024802517678056444, 0.0054549385178168965, 0.055488056104098044, 0.004800262062677315, 0.011767957509229226, 0.006280855159275234, 0.023662419390997717, 0.05941219375069652, 0.005865230832049357, 0.01998031179287604, 0.027664761591170515, 0.04757877033469932, 0.037816198476191075, 0.04173758127061384, 0.07030141872486897, 0.016445393707337122, 0.022239902954814688, 0.038349292906267304, 0.11424400471150875, 0.04873797616788319, 0.014732647487627608, 0.13063466948057922, 0.03204337181523442, 0.031366404212479077, 0.007827255974656768, 0.06352214821215187, 0.027167926376153315, 0.07050798514059611, 0.03630633592339499, 0.04343071273927178, 0.04137252603790589, 0.05181776858600123, 0.012425258622637816, 0.04663708247244358, 0.040241564224873266, 0.027845078879701238, 0.06028829102537461, 0.019463207040514265, 0.033422409423760006, 0.030949359626642296, 0.055970843947891674, 0.06197947170585394, 0.05680747762588518, 0.07637589491371598, 0.03576563172308462, 0.06454273273370095, 0.0702304168205176, 0.0067441978857719475, 0.019946497000221695, 0.03865180417363133, 0.045357138118041415, 0.04225802102259227, 0.0051940524052562454, 0.028656338740672384, 0.025205854160178984, 0.031228251090007167, 0.01816664875618049, 0.03591515030711889, 0.021598414251846925, 0.052568391165030856, 0.06963151467165776, 0.01974711287766695, 0.12049454716699463, 0.057666689556624205, 0.021092172845133712, 0.02122419370737459, 0.045550123655370305, 0.02722952887415886, 0.05573629474799548, 0.0317603887857071, 0.04277201129921845, 0.048394874935703616, 0.018029024891023124, 0.01774471193285925, 0.022172051149287393, 0.032706202140876224, 0.06457948897566114, 0.049525670507656674, 0.0723429134647761, 0.08719577360898256, 0.01647469454577991, 0.027087552206856862, 0.018320881462256824, 0.010024244647606142, 0.07448050911937441, 0.022015046627659882, 0.02975893100457532, 0.02625059283205441, 0.022619319381192327, 0.04790416180289217, 0.03430791458647166, 0.03060415154322982, 0.036707926874182055, 0.03880969927247081, 0.020127031419958388, 0.04624933363603694, 0.036390979774296284, 0.12110725071813379, 0.008667207688891461, 0.025330848792301755, 0.03688321961089969, 0.03253470920026302, 0.011448714416474104, 0.019775847139369165, 0.016402613770748888, 0.025455982524103353, 0.04593960954142468, 0.06068384301449571, 0.03490921196394733, 0.08201922316636358, 0.07279102477644171, 0.029484120929347615, 0.039223514031618834, 0.06873651341136013, 0.0609123736087765, 0.010240684596023389, 0.17717162732567104, 0.06170926549072776, 0.057964084669947624, 0.06499560057584729, 0.02702572918497026, 0.03389657648014171, 0.028329574935404316, 0.012023691420576401, 0.02197656690675233, 0.027571232324200015, 0.028890219583575214, 0.03312401007860899, 0.027673523174598813, 0.10351647463228021, 0.005173918998999787, 0.03922272353832211, 0.0644411492560591, 0.0188083902134427, 0.04820243561906474, 0.02763405957791422, 0.01976810335846884, 0.01587800611741841, 0.054135986869888644, 0.09351691763315882, 0.0708371764048934, 0.02695797915969576, 0.022751377562859228, 0.048019302410206625, 0.07147258373775653, 0.05872815581304686, 0.1015442990298782, 0.007945908000692725, 0.03110192822558539, 0.005338245761647288, 0.03137463144958019, 0.009536195612911667, 0.05718659210417952, 0.03080208699351975, 0.021626427570091825, 0.011954268806480935, 0.04042371355795434, 0.031880923746419806, 0.05985216942748853, 0.04786721896380186, 0.03308138790141259, 0.06474767066538334, 0.08835873513349465, 0.02434331231883594, 0.026316604111343622, 0.014128564723900386, 0.026377407634364705, 0.09051600830363375, 0.018635518150404096, 0.03334046953490802, 0.019568132303122963, 0.05372218907411609, 0.033987428926463635, 0.033989824155079465, 0.08414255601486989, 0.010350742127879389, 0.025517912415255393, 0.0717242591615234, 0.06339815272284405, 0.02924921889124172, 0.05017725411536438, 0.029649479913392236, 0.011938953422941267, 0.023013454928461994, 0.04363033434908305, 0.05430170887016824, 0.04210374930075236, 0.0034737127425614744, 0.04661787314606564, 0.021529851680887595, 0.039913655391761234, 0.03226976502420647, 0.03993133122899702, 0.04024037678859063, 0.04364354542589613, 0.02407215954735875, 0.006867942317122859, 0.05770402255335024, 0.059820549695619514, 0.0996327641020928, 0.048225590626576116, 0.07793257638279881, 0.048744272972856245, 0.06851824905191149, 0.03271777794829436, 0.05592576886660286, 0.05791618009763105, 0.019382410483168702, 0.020947685598262718, 0.018773515209821717, 0.05260895059577056, 0.032751870940306356, 0.04304980014317802, 0.03117314726114273, 0.04423641539844019, 0.027634303850520934, 0.0944882065856031, 0.05836082409535136, 0.05214685467737062, 0.030054137842463594, 0.009992163511924446, 0.06546480754124266, 0.04103947051667741, 0.04060495026143534, 0.06356581872595207, 0.037184424698352814, 0.06925352316881929, 0.05721794720739126, 0.0254369801509061, 0.011593566375917621, 0.013938189001886972, 0.018126708488645296, 0.016644979694059918, 0.03672781812825373, 0.04894076992890664, 0.05510049047214644, 0.06777215908680644, 0.01837083351399217, 0.08825276153428213, 0.09932144545018673, 0.04237427442733731, 0.03849533060565591, 0.05256200275783028, 0.04570912476629019, 0.0632621335930058, 0.00818854448984244, 0.009957033209502697, 0.07258873313133206, 0.016110573995060155, 0.003132234269287437, 0.058651006381426535, 0.030352140244628702, 0.01679348386824131, 0.038952537679246495, 0.042109147046825716, 0.023606067057698965, 0.020085902019803013, 0.022356039312269007, 0.020403414000091807, 0.03018854545163257, 0.07656070749674525, 0.028554802760481834, 0.018245094189686433, 0.11019595978515488, 0.015622610625411783, 0.049759965256920884, 0.025762892394725765, 0.020490173183913742, 0.04027396427201373, 0.040446654826934846, 0.04281216021627188, 0.05084877647459507, 0.03051543648221663, 0.04010274613808308, 0.012342862418985792, 0.05708620963352067, 0.04479088368160384, 0.032968187904251475, 0.03326789003663829, 0.03695877787790128, 0.008181080604637308, 0.01590044696682266, 0.028251519659534097, 0.04386549423049603, 0.05530253105929919, 0.06872621324977704, 0.04647688713989087, 0.04722925694659352, 0.046945337538740466, 0.041880928578653505, 0.038481966858463626, 0.0020180848576793714, 0.03576559779633369, 0.042877353860863616, 0.05873184025819812, 0.02205968744653676, 0.038917610089161565, 0.025463324273005128, 0.014634538109281232, 0.03855432922552739, 0.002726830799864339, 0.04952050007081457, 0.013593916448631456, 0.09128871041217021, 0.06647208599107605, 0.046682103270930905, 0.031106840819120407, 0.060614930998001776, 0.045482171765927754, 0.02788828290067613, 0.04262903718543904, 0.022443163208663464, 0.04970132286793419, 0.035759660614920516, 0.01642306142353586, 0.07014334720692464, 0.05206875529672418, 0.028663778877151862, 0.027119840295719247, 0.1193480265459844, 0.0450704842140632, 0.005565945998699005, 0.05580827035009861, 0.03362618027521031, 0.07609940546431712, 0.03792993112334183, 0.01824646652676165, 0.011420012385185276, 0.07431561832449265, 0.015771849313750863, 0.015169685107788869, 0.04125333118385502, 0.1386834925838879, 0.2585911069597517, 0.21815369038709573, 0.18848480097949505, 0.09602881356009416, 0.17437849220420631, 0.1312448624521494, 0.12070403806865215, 0.10961414314806461, 0.10678774623998574, 0.16232089778142317, 0.18706033884414605, 0.08371586605374302, 0.1003200997199331, 0.14899987115391664, 0.15152084587940148, 0.171773121293102, 0.08832455053925514, 0.20200117783887045, 0.08407059059079204, 0.06603885495236941, 0.13236949353345803, 0.11935654894581862, 0.11187403116907392, 0.11302929132112435, 0.07788686347859246, 0.17831083333918027, 0.09364718278603894, 0.17032351264996187, 0.11263470285172973, 0.14174721390008926, 0.06517771258950233, 0.1427627094089985, 0.1475006208888122, 0.22148347885480948, 0.09268865707729544, 0.14418984497232096, 0.09306992590427399, 0.1703831423074007, 0.10120937414467335, 0.1316521463117429, 0.20534354634582996, 0.14273106253572873, 0.1813495574252946, 0.11979737957673413, 0.12400098544146333, 0.23007966258696147, 0.1642859759075301, 0.11353452849600996, 0.1597436046493905, 0.10806214357061045, 0.14763588005942957, 0.07665505100573812, 0.11744274092572075, 0.21053519419261388, 0.1173854861408472, 0.13991122027593, 0.16031936875411443, 0.12057928262012345, 0.13974447708044732, 0.14847163164189883, 0.17654107830354146, 0.13314937454249176, 0.16860958747565746, 0.151365352794528, 0.1376612660075937, 0.1669579382453646, 0.09587663851146187, 0.09081459763859, 0.1007263386355979, 0.22213336612497056, 0.11042197979986668, 0.09543601144105196, 0.07905920235706226, 0.16734623669513635, 0.1589501393692834, 0.09235323007617678, 0.11966925859451294, 0.1715530181037528, 0.12461324115949017, 0.24052277792777332, 0.23862076284629957, 0.19659132670078958, 0.15313266510409967, 0.15459901999150003, 0.058958674514932294, 0.13728618541998522, 0.1390657927840948, 0.17847011264945778, 0.14659719222358294, 0.1253193382705961, 0.12323630361684731, 0.12597974283354624, 0.12774438171514443, 0.09178018011152744, 0.05923540145158768, 0.29402230573551996, 0.1619110626301595, 0.1194741390645504, 0.14191550415541443, 0.09382292335586888, 0.12879418395459652, 0.10642524569162301, 0.09674025752714702, 0.16638077635850224, 0.22153519679393086, 0.12139067479542323, 0.26418679526873995, 0.08113737870007753, 0.16022471311901296, 0.14170935164604867, 0.1160784512758255, 0.14892202961657727, 0.09391329064965248, 0.17000850955290453, 0.13877356132226332, 0.1392093300819397, 0.12400103972426482, 0.14154639467597008, 0.2585528918675014, 0.23311086850506918, 0.1627613077206271, 0.14569714266274655, 0.09269688092172146, 0.11001995458666768, 0.1089959027511733, 0.1359055566468409, 0.18023713997432164, 0.09040120017847844, 0.1848193412380559, 0.13873282207974366, 0.10483021342328616, 0.15503952492560658, 0.16993043731365884, 0.17185918667486735, 0.07742723742766039, 0.2522159447627408, 0.1504291644585984, 0.13673989687647137, 0.12328703089484147, 0.13108551528836998, 0.1024805891460606, 0.09743401208626372, 0.0911193752129163, 0.0648583397269249, 0.14348475209304265, 0.11412683528448854, 0.13698140106030873, 0.15074757380144937, 0.16554247348436288, 0.0945088883329715, 0.1446208775575672, 0.1575597125504698, 0.1339595996375595, 0.2621077639716012, 0.13330203135098728, 0.08909070478486163, 0.12168738458837781, 0.11480237117835454, 0.13520730340055057, 0.2213098688849381, 0.08112743137670414, 0.10391811308051858, 0.22141204268804618, 0.14516684040427208, 0.19863305214260304, 0.18297777005604335, 0.07888682053557464, 0.1252562209431614, 0.07443214314324514, 0.0894508779581104, 0.09018019453755446, 0.18896449809627874, 0.07689286395907402, 0.0893620645095195, 0.07690817849444491], [0.05445251327806285, 0.03694171950753246, 0.07720956339367799, 0.0723589268912162, 0.08848357879157577, 0.022261512598821094, 0.013122601783834398, 0.03662295054112162, 0.01597409006873412, 0.019005531777760813, 0.03128000974122967, 0.02276528244172888, 0.023359719830166017, 0.06450940309358494, 0.024587181197213273, 0.052141294082892795, 0.08932714709745986, 0.011700439034029841, 0.022375553979405334, 0.030835769471845458, 0.018572534833635603, 0.039624345023185015, 0.01329579615100686, 0.021175478285710727, 0.04573437644700919, 0.012619468915675367, 0.041693069373390505, 0.11859421485236712, 0.037332440327320776, 0.04520213018570628, 0.03370845943157162, 0.03063643623941711, 0.0545715215349836, 0.030649894981512, 0.012587514157140893, 0.054901296339396916, 0.040263901597687175, 0.048163701447525194, 0.03601586865261197, 0.06414593224014555, 0.0319484006613493, 0.01212106628476509, 0.02848763797166092, 0.030766117852181196, 0.0420269730633923, 0.05972911710185664, 0.0202028305668916, 0.030094710843903676, 0.0315262399214719, 0.02839900433484997, 0.013782288796002311, 0.006585664539930544, 0.04393889814881342, 0.032959692645817995, 0.04339995813955154, 0.001867050171962806, 0.03511247730680874, 0.011392457078077962, 0.030313144837106978, 0.024770205840468407, 0.055016274098306894, 0.0287612538252558, 0.022548178377162133, 0.08685162743287426, 0.10784081901822772, 0.042089048839573345, 0.046938131496842415, 0.03829455209363784, 0.03689128399959632, 0.008742082331861769, 0.045741558740181584, 0.00837385664427919, 0.12581608018704823, 0.053641416265496185, 0.038811877369880676, 0.008885424550888794, 0.015386706051815833, 0.08800785789000136, 0.07007651829293796, 0.018122644063883593, 0.03881226074216621, 0.021678472902359705, 0.06970025026904685, 0.0934794217880283, 0.03749904781579971, 0.016743525031155775, 0.031512190853910785, 0.040623009470956664, 0.02049380504260106, 0.04044189151110394, 0.007073551998473704, 0.03373120392539671, 0.05134247176881347, 0.03134591584759099, 0.018715553052191223, 0.030362284343157495, 0.04723220518124955, 0.03237071067893079, 0.052806309291294644, 0.07510342462254421, 0.027276726073718498, 0.03967504855245352, 0.011406165181792207, 0.018830230559355447, 0.035062533736761124, 0.032326476981065104, 0.014662751595356634, 0.02725165929379208, 0.04005763713004334, 0.03946940155167665, 0.022625519494925226, 0.002559866868458422, 0.016725450554596524, 0.030739800871482918, 0.025448138659287776, 0.02821580327248999, 0.0503524518571794, 0.03691906322325979, 0.04668555701417582, 0.031483699168477736, 0.03239823205928717, 0.07459731892283473, 0.03592723501580102, 0.08211433341992752, 0.06554595354412283, 0.03738460270687938, 0.012509626818687787, 0.07236740857894931, 0.047307756662900956, 0.061015327727156024, 0.036106140951492956, 0.06483522203883954, 0.039095891772636344, 0.020252614681209837, 0.031507668418011496, 0.04063186774562512, 0.022701491668288196, 0.03705157093437655, 0.027092605596408248, 0.01690637513196894, 0.025723281216674616, 0.09068109587367092, 0.04823832333620105, 0.023090626412470425, 0.031216821167618036, 0.016709186070199524, 0.0167302817239293, 0.03686309765492167, 0.038892015748258145, 0.02822410175576806, 0.027423796842672994, 0.056170546981905184, 0.047397625233445845, 0.020070524719942893, 0.05578811786004475, 0.02491255570203066, 0.028676576047603573, 0.053934377152472734, 0.02183082776277193, 0.023537314496934414, 0.020835533937705413, 0.014268823001267654, 0.012625868349069995, 0.038512775740985355, 0.02886242000386119, 0.029405258196805204, 0.009782977102856551, 0.058203356473573616, 0.09399826359003782, 0.0912209926173091, 0.048504444770514965, 0.04982700451676335, 0.07227588777563401, 0.03896243411249348, 0.022991450037807226, 0.04246208703677569, 0.03624340180041535, 0.021197225333058407, 0.020518563089093993, 0.12268909226570811, 0.03551285707258752, 0.039294325946164985, 0.01798329671977886, 0.04485907305830291, 0.04024593738306846, 0.016659580071323683, 0.04936569909166012, 0.03741081451464977, 0.020829518724765097, 0.02849476258935673, 0.04187697271949478, 0.019259943393990397, 0.05544717097654939, 0.04223201616800257, 0.026176344137638807, 0.031466993636318615, 0.006768427099034722, 0.05742523965558835, 0.03848666571346777, 0.021112684958747456, 0.027194345137104392, 0.02363592429485704, 0.012890526692249944, 0.03101919445076159, 0.011217015911825001, 0.04618503226499472, 0.0439743007134114, 0.03766916672300015, 0.03680880128272942, 0.028185876485492502, 0.011837662563526204, 0.0741490244067141, 0.007482440593386335, 0.0519109585854624, 0.04839482743825231, 0.05196645935731275, 0.04418406981442656, 0.03179410858345883, 0.02192254873391773, 0.07665898650884628, 0.044383297873927016, 0.042642048094421625, 0.02326200400213046, 0.030664049222001007, 0.06932330371013709, 0.05083628125222666, 0.050838608627340624, 0.1177596574915307, 0.0430519205651113, 0.026783892518973777, 0.030746766033449342, 0.018900063687137196, 0.02300215562406395, 0.027519707767558948, 0.015650724027571932, 0.04756454484803336, 0.025405854053263153, 0.03764894637944443, 0.022288611591128365, 0.09246932063251734, 0.06354396311300141, 0.023072860669344664, 0.059644252727074284, 0.0735835333221725, 0.02724988492471831, 0.02895856841600367, 0.016917652383978878, 0.030927283489810567, 0.041313452779182365, 0.01479359859201525, 0.025859909331692115, 0.020415147566901784, 0.025789840412991386, 0.03510383955602135, 0.05416103499010205, 0.01640694452050541, 0.012114020546765199, 0.012637617182917893, 0.061537440067955425, 0.03342231782153249, 0.019161311543679664, 0.017260249803907106, 0.015197917253577282, 0.011992153961078396, 0.022183235102732266, 0.003575010599368917, 0.02970474659066115, 0.015088705345988274, 0.013166178150900772, 0.05819644220173359, 0.015215482828872544, 0.07862617487886123, 0.018221554113551974, 0.07761578195329223, 0.03528685062857611, 0.13492013380995818, 0.04669101243572576, 0.04922460112720728, 0.021780324401333928, 0.04184809087642601, 0.030825564305164983, 0.03854842257819005, 0.006577789716954742, 0.0368545447210116, 0.017958609919462885, 0.0517737520193415, 0.018596295433651124, 0.024046607614893998, 0.03743357936452542, 0.013000794569961727, 0.025810912317995514, 0.036817679913448434, 0.028558968965496336, 0.02205471208851252, 0.028793823506150926, 0.033234339872641225, 0.03827523759433201, 0.03515776612662843, 0.020665910361068587, 0.03386928919436676, 0.014117853200462247, 0.057064795068332126, 0.03740777467776622, 0.09849959026489939, 0.033211120404303074, 0.024143493933869258, 0.016198157598929744, 0.05654625521440591, 0.02307884704454669, 0.0664726220337408, 0.01519463992943721, 0.007117698334955743, 0.04310326870264752, 0.07646080000059945, 0.05421049001493624, 0.016230508452281356, 0.036498514004051685, 0.04435262130573392, 0.04059410387916224, 0.009609396818892231, 0.050729829285826, 0.029254898229347806, 0.021977795055136085, 0.03956930904782244, 0.024961830915084908, 0.018081160129180977, 0.00907718448434025, 0.03219422711325543, 0.03035612663786326, 0.01907157359112586, 0.01490610309078225, 0.05281917092257312, 0.013224109774455428, 0.013533277470352394, 0.02140453304829342, 0.014342269328023707, 0.05945656994091613, 0.030971965020788566, 0.04338111522208367, 0.013454475805961659, 0.03320997707279665, 0.025961949124134014, 0.01220302313699254, 0.022410386574587653, 0.05092944750296218, 0.080179470458201, 0.04777036487523999, 0.006070970707306904, 0.01551095599175564, 0.029676892728145634, 0.07171652386231081, 0.018624015285500457, 0.15068376436829567, 0.13004426259015286, 0.12849998474121094, 0.20813512083675179, 0.12185477917747838, 0.12143268968377795, 0.11594718189111777, 0.1386318832103695, 0.08879326217408691, 0.08920370122151715, 0.07368037384003401, 0.17389591809894356, 0.0822278116164463, 0.10526940199945654, 0.1390615315841777, 0.09405256674758025, 0.11913872563413211, 0.15784248523414135, 0.11814239195414952, 0.10910587292164564, 0.160382336803845, 0.1698778915618147, 0.11319600737520627, 0.1284148557377713, 0.1401693621384246, 0.0992512713585581, 0.09572286890553576, 0.18103501573204994, 0.09770742777202811, 0.12722402678004333, 0.09093235060572624, 0.08308769190417868, 0.09036373147474867, 0.14275342704994337, 0.0761584040841886, 0.13136751444212028, 0.1849537454545498, 0.24872735195926257, 0.13722548367721693, 0.14375579969159194, 0.08363583963364363, 0.07911314589104482, 0.11606969817408494, 0.12133046159786837, 0.08797305582889489, 0.1320727565991027, 0.07134450346763645, 0.10981303533273083, 0.1933817882090807, 0.12936703035874025, 0.14316356075661524, 0.18458355031907558, 0.15251955443194934, 0.1400528305343219, 0.08838709111192397, 0.07367959352476255, 0.08525035942771605, 0.16203227612589086, 0.08594174589961767, 0.12337806315294333, 0.18678694351443223, 0.14265915139445237, 0.08309028390794992, 0.16995563810425146, 0.28345816688878195, 0.13335602916777134, 0.1870214452168771, 0.18452060941074575, 0.14057060703635216, 0.14406399029706204, 0.10496510618499347, 0.11124774334686142, 0.219883547563638, 0.11259605349706751, 0.12007169771407332, 0.13297789517257894, 0.10636151768267155, 0.17099309100636415, 0.16125287009137018, 0.1074444188603333, 0.21938004743840012, 0.09323686587491206, 0.297178144965853, 0.08394050185701676, 0.14859923693750585, 0.06303940447313444, 0.07740436401218176, 0.21357709382261547, 0.1121233520763261, 0.0888948252956782, 0.13196389244071074, 0.06260786298662424, 0.07028916438243218, 0.1452769259256976, 0.05231484637728759, 0.2234019280544349, 0.12880258421812738, 0.16402023445282662, 0.14352741837501526, 0.3087327278086117, 0.2650124638208321, 0.14104292169213295, 0.08351841914866652, 0.14265831001102924, 0.1134996178693005, 0.11225072667002678, 0.08822066004254989, 0.13160156831145287, 0.1443425424929176, 0.17991011323673384, 0.11143604359988656, 0.17021087583686623, 0.10278930222349507, 0.15209228093070642, 0.07826965222401278, 0.07105882665408508, 0.1137466181867889, 0.15689335045005592, 0.20114222035876342, 0.0982295401128275, 0.12602391546326025, 0.12580586144966738, 0.09953970302428518, 0.1450891210032361, 0.10557320926870618, 0.2095695167247738, 0.19457947037049703, 0.14104468588318142, 0.14343238276030335, 0.14314351683216436, 0.07988659438810178, 0.23767540071691784, 0.10696031805127859, 0.16420316749385425, 0.11712471156248025, 0.10448959562927485, 0.12986137026122638, 0.15511423163115978, 0.17045178290988716, 0.10815572033503226, 0.16002143759812626, 0.1541079913399049, 0.13372139313391276, 0.05926725867071322, 0.11297351574259144, 0.08486723820013659, 0.08219343024705138, 0.15197269591901982, 0.17048281910164015, 0.11712975986301899, 0.14387724388922962, 0.10454359344605889, 0.10928003929023232, 0.12509358966989176, 0.13333848225218908, 0.12907626453254903, 0.1555818508246115, 0.12181572270180498, 0.08392457664012909, 0.08494603647185223, 0.13659412041306496, 0.10607401560992002, 0.18745498838169233, 0.11531324019389493, 0.14431992013539585, 0.1164916248193809, 0.12675684184900352, 0.09206486626395158, 0.20884056655423983, 0.1890090371349028, 0.13967419442321571, 0.12789006318364823, 0.14012710297746317, 0.0908339223159211, 0.1212411392480135, 0.12306116015783378], [0.028044632636010647, 0.027204587623210888, 0.038162441325506995, 0.03375283222911613, 0.029401712851332765, 0.037169649598321745, 0.005657230587010937, 0.009882709876235043, 0.0373317753630025, 0.01378328793881727, 0.028778963589242527, 0.010417643984380578, 0.027635543873267512, 0.020675918752593652, 0.012421002511733344, 0.041701225364314656, 0.05203000416180917, 0.01046843996404537, 0.045632060151547194, 0.04626587971246668, 0.08155556661742074, 0.03494152380153537, 0.03761328936421445, 0.06872928022806134, 0.04830972557621343, 0.027129796100780368, 0.027420137842584933, 0.0961051962471434, 0.059470554547650475, 0.06680257325725895, 0.015801869399313415, 0.011399192386306822, 0.031799991482070515, 0.0702948844326394, 0.02334005418898804, 0.02436361917560654, 0.05413182745022433, 0.029292064984994273, 0.008199729291456086, 0.05052524419235332, 0.03664835489221981, 0.015216164756566286, 0.04862901362191353, 0.049038092206631384, 0.012443703748951, 0.061994243413209915, 0.07424279116094112, 0.042592382723731656, 0.013223942685207086, 0.052938796646360836, 0.03436956627826605, 0.04331083935020225, 0.042599656619131565, 0.017643048727352704, 0.0028649542364291847, 0.0500617776332157, 0.006623176500267748, 0.050832189686064205, 0.024515363354501978, 0.02397349037762199, 0.02314106361674411, 0.06808790857238428, 0.018446213665551374, 0.061174702032336166, 0.03374360754553761, 0.016698531374069195, 0.03363360005563923, 0.04877335159108043, 0.022539622050576975, 0.05662213239286627, 0.04879035907132285, 0.07864414927150522, 0.03613688537318792, 0.02187127184255847, 0.051812150316046815, 0.044141987072569985, 0.043098172904657464, 0.030912179300295453, 0.11642040578382355, 0.05336343743173139, 0.02317312439637525, 0.019510463611888032, 0.08432827104947396, 0.029113488138786385, 0.05174952831917575, 0.01952172559686005, 0.04613506494622145, 0.048193543417645354, 0.03115231284339513, 0.059342501418931146, 0.029539136548659632, 0.061949819725539, 0.010381509450131228, 0.033441438938358, 0.004997620334117008, 0.06409185978450946, 0.0446276960096189, 0.02865200290190322, 0.02680576509529991, 0.10492480799023594, 0.02044269778499646, 0.024330026603170803, 0.030365945039583103, 0.053232076444796154, 0.02815081488474139, 0.003664305807823049, 0.04289602375190173, 0.013242387811520269, 0.0566576129889914, 0.02504386070982686, 0.024873831708516394, 0.007212797562325639, 0.04070332087576389, 0.014704942902816194, 0.038982430539493046, 0.030022626676197563, 0.035687406813459735, 0.02506455602789564, 0.05110560537182859, 0.022806998774675385, 0.09288345769579921, 0.004257716912044478, 0.02592609872642372, 0.03428753139451146, 0.021618244437766925, 0.04370152963591473, 0.026841881818005016, 0.04468862506161843, 0.03626080961631877, 0.016240510058456233, 0.03320065400164042, 0.08281817100942135, 0.02696996208812509, 0.039382606744766235, 0.06265353517872946, 0.0299344510505242, 0.05728743597865105, 0.014772416425070592, 0.02201267684410725, 0.02380301693587431, 0.04515732651842492, 0.008550327487422951, 0.032796226774475405, 0.03460939108793225, 0.03143060041059341, 0.0527742010142122, 0.03919340404016631, 0.10896154173782893, 0.0027916571873772356, 0.09777477237262897, 0.025426322062100683, 0.05648228971819792, 0.04499725332217557, 0.03770930885470339, 0.05269421869888902, 0.05234735838270613, 0.04148554622328707, 0.023814324721960083, 0.08002259994723968, 0.009352827461303344, 0.028598941463444914, 0.0836107541940042, 0.005076808339383985, 0.02049702129858945, 0.010908374080567487, 0.049999813815312724, 0.02760499283405287, 0.014125585106999745, 0.05918789042958191, 0.06534843200019427, 0.044172568645860465, 0.08094673071588789, 0.017115241781409298, 0.06339763703622989, 0.02115665063528078, 0.010055916965939105, 0.016760769998654723, 0.03288816148415208, 0.04218812852299639, 0.023315932269075086, 0.008095627600726272, 0.044211523341281075, 0.06532173164721046, 0.004760960890312812, 0.027802363403939774, 0.004715768337648894, 0.05644355554665838, 0.010949039532403861, 0.03737307439691254, 0.04869882469730718, 0.020365076771538173, 0.08359168057462998, 0.08257918419050318, 0.07683552774999823, 0.008941532611580831, 0.0484737546316215, 0.002985987072211823, 0.0015277084478709313, 0.10891831227179084, 0.027832824537264447, 0.030499901422964673, 0.02924835036641785, 0.03175499443230884, 0.01616110958691154, 0.06578454681273017, 0.053300377779773304, 0.07048127121691193, 0.027017298387363553, 0.03464130937520947, 0.10505149726356779, 0.018829611396150928, 0.03635746014437505, 0.03991366556978651, 0.02329284341872803, 0.037843048106878996, 0.040353139130664725, 0.055751202162355185, 0.017511624975928237, 0.04097317764535546, 0.019460134973217334, 0.022588749682264667, 0.013842248391093952, 0.03875145043379494, 0.004602623047373656, 0.03793999719034348, 0.06317988836339541, 0.06087566486426762, 0.06821017379739455, 0.07518690478588853, 0.057815302296408584, 0.025710804654019218, 0.1306089801447732, 0.052649387890206914, 0.012246228006136204, 0.020098392153158784, 0.03192830245409693, 0.05892738047987223, 0.03446470367323075, 0.012094437177958233, 0.04135455843061209, 0.0360632948577404, 0.05878110868590219, 0.004699911822431854, 0.025693281487162625, 0.02400423988832959, 0.059014443308115005, 0.04851437173783779, 0.05615694574745638, 0.0355091522713857, 0.06612329185009003, 0.026735587610996196, 0.024522555825699652, 0.031720725021192005, 0.036053286466215334, 0.057197618298232555, 0.034443071976836236, 0.08476611612630741, 0.005981795514734196, 0.10935215399201427, 0.022032130443091904, 0.03170126463685717, 0.03330318403563329, 0.006260452035348862, 0.024642508942633867, 0.02689965907484293, 0.026536189917741076, 0.028672297884310995, 0.055311277375689576, 0.009292945897738849, 0.013703329372219741, 0.018875538038888147, 0.05441365697021995, 0.014013827844922031, 0.02728742826730013, 0.036094632997576676, 0.007916545245929487, 0.04259703068860939, 0.06157182143735034, 0.07521514541336469, 0.038312960748693774, 0.024736097581418495, 0.014776334964803286, 0.05654779548889824, 0.018215806921944022, 0.043521772138774395, 0.026682404036234533, 0.024475053285381625, 0.04658247736681785, 0.020091854468254105, 0.0742473169895155, 0.05953919515013695, 0.012662734004801937, 0.06790186784097127, 0.06077953002282551, 0.03566549352503248, 0.01466243777291051, 0.08118652499147824, 0.021081051656178067, 0.045750050605939965, 0.022975053239081587, 0.02190078641953213, 0.0895314064941236, 0.022822065644764473, 0.02373747045307287, 0.08661053715539829, 0.05115270248747297, 0.005423923954367638, 0.029642457075949227, 0.017221310375524417, 0.03237332643142768, 0.035600656111325533, 0.052373471802898815, 0.04224755122725453, 0.01063857922729637, 0.030492688595716442, 0.03695227751242263, 0.0845016028199877, 0.024736245162785053, 0.07903523650020361, 0.03979277437818902, 0.050024753369923146, 0.047676876320370605, 0.01383014502269881, 0.06271859990166766, 0.009112165509057897, 0.01688344743368881, 0.06022116355597973, 0.06864192562976054, 0.010108664581951286, 0.040428320810730965, 0.015456361064155186, 0.052187237689005475, 0.02749010667737041, 0.06004164354609592, 0.030573549613888775, 0.03446265110479934, 0.03763157927564212, 0.03817560490486877, 0.05175399647227355, 0.014821703512487667, 0.05573918191449983, 0.016719964598970752, 0.010910739623276251, 0.021335437827344452, 0.032072392757982016, 0.05538324619244252, 0.029791110527834723, 0.04435184777581266, 0.06429703520344836, 0.027397610479965806, 0.03896419830354197, 0.0015524929996380316, 0.09423611047012465, 0.11806422472000122, 0.13264682436628, 0.11536256968975067, 0.14140314236283302, 0.14330641951944145, 0.10555908895496811, 0.09014119234468256, 0.10166667282049145, 0.09823580977639981, 0.1436679565480777, 0.10584205841379506, 0.12389373619641576, 0.12550831027328968, 0.12778034407113278, 0.1726805940270424, 0.12966775707900524, 0.13045996028397763, 0.07663600452776466, 0.18127327651849814, 0.16288036347499915, 0.11854134340371404, 0.15783538775784628, 0.14503622241318226, 0.16788983823997633, 0.102588123375816, 0.08854907099157572, 0.1278170392449413, 0.09221413039735385, 0.1567589733749628, 0.10595702260200467, 0.08769987084503685, 0.15390767423169954, 0.2044995573482343, 0.09820680240435259, 0.09643455035984516, 0.1130539153569511, 0.11825546302965709, 0.11052330543420144, 0.11833508232874529, 0.11986117543918745, 0.12169501132198743, 0.06858857920659439, 0.14904479017215116, 0.11806309835187026, 0.12066838783877236, 0.17871587803321226, 0.08017885299133402, 0.10217762326023408, 0.1382032526390893, 0.11925733355539185, 0.18966562833104814, 0.12728546134063176, 0.16343068251652376, 0.11034856231084891, 0.2641915450138705, 0.102256686160607, 0.11436289761747633, 0.09625604815248932, 0.08908772601612977, 0.15483823072697434, 0.14071141662342207, 0.058182511877800734, 0.1190775353461504, 0.12555913254618645, 0.16233989676194532, 0.16519898548722267, 0.0938249725316252, 0.07538625158901725, 0.1757391991892031, 0.11859360417085034, 0.11068679844694478, 0.08443865512630769, 0.2106438683612006, 0.18471674674323627, 0.12555561773478985, 0.1138355266302824, 0.13434451898293837, 0.15754960237869195, 0.17008299912725175, 0.1588604777519192, 0.16980501690081187, 0.23489319000925335, 0.08338746189006738, 0.11522607558539935, 0.06404078645365578, 0.14224382010953768, 0.10166030137666635, 0.11473831747259412, 0.11837457306683064, 0.0986915071095739, 0.1243571484727519, 0.0742834625499589, 0.12807775954050676, 0.08312796974288565, 0.16665247535066946, 0.22040926292538643, 0.18660107920212404, 0.13603787097547734, 0.21931690296956471, 0.1831452732107469, 0.09151827916502953, 0.20339326028312954, 0.15483574728880609, 0.10954035246478659, 0.15355666806655272, 0.18249409672405037, 0.049605422121073516, 0.13587241699653013, 0.09236941992172173, 0.08501624449023179, 0.12563546773578438, 0.14359585541699613, 0.09694077141050782, 0.167732458827751, 0.11753899790346622, 0.21361629957599299, 0.12954830777432236, 0.06538058098937784, 0.181024647716965, 0.16452798220728124, 0.13288817927241325, 0.14445698420916284, 0.11234867319996868, 0.0933648579354797, 0.19016741854803904, 0.07806871086359024, 0.10401240909206015, 0.18811913845794542, 0.11062089912593365, 0.10893360645111118, 0.1464977189898491, 0.12086892207818371, 0.09375319709735257, 0.12491073805306639, 0.11203575320541859, 0.19590310220207485, 0.16618427261710167, 0.09737195327345814, 0.1385397245841367, 0.08263331771429096, 0.15350648361657346, 0.11313493922352791, 0.1212532307420458, 0.12530013572956833, 0.1570485042674201, 0.05515907518565655, 0.19006874598562717, 0.09810642671904393, 0.15014287696353026, 0.1490670189793621, 0.15494515427521297, 0.15029735224587576, 0.10033273404198033, 0.08370659048003809, 0.1848800022687231, 0.1329970434308052, 0.16569821084184305, 0.13844326404588564, 0.17169853672385216, 0.14557525063199656, 0.20399814711085387, 0.16938347023512634, 0.14628696601305688, 0.12690728663333825, 0.13666633010974952, 0.08386787146862064, 0.11331289181751864, 0.16276308548237595, 0.12030144967138767, 0.08285521223608937, 0.11597265409571783, 0.11433093861809798, 0.1272677651473454, 0.11999841593205929, 0.08650644988353763], [0.06291004855717931, 0.04872261752773609, 0.021432987414300442, 0.029647542695913996, 0.06743500182139021, 0.04473371371360762, 0.030696143928383077, 0.022925191093236208, 0.06807246511535985, 0.03519084470878754, 0.0027393531636334956, 0.07501771886433874, 0.002819528861436993, 0.045201058100376806, 0.09890019733990942, 0.033433849524174414, 0.021384297437699776, 0.0617623133584857, 0.04057120671495795, 0.04782310061688934, 0.028571308124810457, 0.014965602130229985, 0.009569652478343673, 0.029042140181575502, 0.04732991761661001, 0.020829678180494478, 0.013455401158093341, 0.05589342988761408, 0.06725962087512016, 0.0441818917170167, 0.04127507483852761, 0.04859127350417631, 0.04772087253097977, 0.02195684189376022, 0.008273868572099932, 0.03646146259935839, 0.04276889343080776, 0.02625809234034802, 0.05498487828299403, 0.05400196263300521, 0.039424397716564794, 0.040745227198515616, 0.025927998624475937, 0.058271508530846665, 0.0036726047151855058, 0.03726535357002701, 0.03573111803936107, 0.04435821921963777, 0.03734281512775591, 0.03157957616661276, 0.028941778066967214, 0.06582757950361286, 0.013884511792899241, 0.04672925466937678, 0.061532038929206986, 0.0494716387641217, 0.0680127472483686, 0.0274582324948694, 0.03881351603195071, 0.008133837603963912, 0.02627394800739629, 0.01722473867370614, 0.039068445031132014, 0.038464511545108895, 0.04665868702743735, 0.035137946118733714, 0.05863415157156331, 0.05408474729795541, 0.03067163863618459, 0.04011426427002464, 0.018195556044312458, 0.07378295476415328, 0.018183523922094276, 0.06506950661007847, 0.021858768138502325, 0.019107381580397487, 0.02733171794430486, 0.07432403894407408, 0.015743009879120758, 0.03759347274899483, 0.006642268779354968, 0.11153832596859761, 0.0353328892295914, 0.09152238430189234, 0.019967914958085333, 0.054175518320075104, 0.033451593214912076, 0.021596422751567194, 0.07904133653002125, 0.05529714349125113, 0.09740546611802918, 0.045627961800034554, 0.030455610049622397, 0.0654565090579646, 0.021503373548122387, 0.05474966411877956, 0.019572424037115912, 0.04094044850873096, 0.05290616250463894, 0.02614848518611065, 0.05507880110027535, 0.08267934274460588, 0.038380909245461226, 0.016608055514682616, 0.10991014047924962, 0.00935866286246372, 0.028996352638517107, 0.046353180027965984, 0.05658938290019121, 0.0025069574642527315, 0.05401234761146562, 0.027973350835964084, 0.016570651271779622, 0.023037632827513983, 0.042158846344266615, 0.043551305375461064, 0.04675478794212852, 0.0312567495607904, 0.01919203221664897, 0.05103574340630855, 0.049687721633485386, 0.029324597346463373, 0.025058454301740442, 0.038780610476221354, 0.0025990548102916883, 0.04788334095584495, 0.004693043775789971, 0.025433148124388287, 0.051847675016948154, 0.037710258803729496, 0.014827111436586295, 0.0161629127937236, 0.010241116313929004, 0.060055275314620564, 0.05758886158998523, 0.06679468189499208, 0.027142357480313097, 0.04481800811897431, 0.03216384910047054, 0.04339920496568084, 0.033670152737093825, 0.03594641720077821, 0.0441905226824539, 0.02670824434608221, 0.01605966520894851, 0.05936648763184037, 0.007805058549690459, 0.030251482967287302, 0.09658176531749112, 0.033047094741570096, 0.01445958633641047, 0.021294683317786882, 0.034724972743008814, 0.06949919355767113, 0.04842656930642469, 0.0355614164311971, 0.04274051709632788, 0.03794130337025438, 0.028044812447790588, 0.0309353512711823, 0.017663465846063833, 0.029237972173307623, 0.04471242467739752, 0.043779221895549975, 0.04168743074738553, 0.021113321085327437, 0.03410051357267158, 0.029972995232258524, 0.07411922314869505, 0.05180411646142602, 0.10657748859375715, 0.01844323320048196, 0.038292777724564075, 0.05592311579467995, 0.029439510644546578, 0.05113917589187622, 0.03063631410311375, 0.08009427360125951, 0.04436891632420676, 0.016538149444386363, 0.02975701753582273, 0.030833876359143426, 0.06241056535925184, 0.09823193534144334, 0.030578689516655037, 0.04860040658552732, 0.010277320398017764, 0.025862519995176365, 0.015201655981530036, 0.03708214232964175, 0.013279756431334784, 0.010202551776144122, 0.024939753081915633, 0.0275001269432583, 0.06831787766090461, 0.011130497607934688, 0.003130825885039355, 0.0327614891741957, 0.020917511145983423, 0.011904055518763406, 0.04312549072450825, 0.06965811324438878, 0.043504727339105945, 0.0012720333782324034, 0.013308563635551503, 0.013253139198890753, 0.027709097069289004, 0.04098603588395885, 0.007254989717953971, 0.015286759539906467, 0.02985749500138419, 0.02834485893669937, 0.028059107484295964, 0.046928615043205876, 0.04106766025402716, 0.01634085351335151, 0.1090673389179366, 0.008444738108664751, 0.057771658924009116, 0.060639792521085055, 0.025072571222803423, 0.03282787025507007, 0.053823236509093215, 0.03355294938332268, 0.03954323633973088, 0.03640004160947033, 0.09891978664589779, 0.05502121722591775, 0.032642579304852655, 0.09682115925742046, 0.04634490868608866, 0.019757718380008425, 0.031051479146948884, 0.06218676415405103, 0.02185219991952181, 0.04135175608098507, 0.022087975571464216, 0.027412158270765628, 0.04562314759407725, 0.031104418449103832, 0.058899085569594584, 0.04203830459820373, 0.061377617929662974, 0.05299319140613079, 0.045775906182825565, 0.061054635260786326, 0.07800777841891561, 0.05923497397452593, 0.03852406656369567, 0.007418951768028949, 0.027902642398008277, 0.0523593209550849, 0.03992766374722123, 0.02755797714261072, 0.045300117427749295, 0.07693458029202052, 0.025569325013618385, 0.01417792305749442, 0.019011161922078048, 0.08691414086414234, 0.013114233750716915, 0.016204257628747394, 0.026760863040440848, 0.041640557548297305, 0.06313241126814059, 0.03802589633102928, 0.0633730333564537, 0.020715663941310983, 0.043175586964935064, 0.01962658979131707, 0.06189536729029246, 0.032252211323274035, 0.028116031483347927, 0.045949567042823346, 0.05486980213650635, 0.02046629214393241, 0.025206037364634018, 0.06257925595023803, 0.0511769397583391, 0.02889452488826854, 0.08798722364008427, 0.09730110064681087, 0.044983112652386935, 0.0025927654267953975, 0.060862223085548194, 0.04112105417464461, 0.037568417843431234, 0.02394071883255882, 0.01749093983588474, 0.014510403520294597, 0.02422362213422145, 0.09352850701127734, 0.061079985329083035, 0.009482822896513556, 0.06080342802618231, 0.04307792881237609, 0.08467061232243266, 0.02254243118555418, 0.03180375735142401, 0.024048823031729887, 0.014107125561817415, 0.028317919400121485, 0.03171856388715761, 0.0649622098675796, 0.0167635418142059, 0.041307654697448015, 0.02603567365024771, 0.02737171758365418, 0.037073379049875906, 0.05023607970880611, 0.06576305760868958, 0.027720416729737605, 0.02121182910299727, 0.014097022175389742, 0.03669330783720527, 0.026385543269238303, 0.03507064223023398, 0.024305054818146994, 0.02220152840683503, 0.02459328292336847, 0.01371870412757354, 0.018935924262872765, 0.05649865598284772, 0.06953609907733542, 0.06748774434838976, 0.08173951067562614, 0.02561493274489684, 0.03871297749823757, 0.04471357140157904, 0.009887333244218357, 0.01535085226143045, 0.054783848713019064, 0.04439131137249725, 0.005648221338300833, 0.022693023551255465, 0.006910400373661625, 0.01830156865928854, 0.011329830840363033, 0.08105643625770297, 0.016863503593153188, 0.05337418881910188, 0.040582134521433284, 0.016563148370810916, 0.028849880676716566, 0.025634754449129105, 0.014303582653935467, 0.05795676327709641, 0.017561078304424882, 0.03578348058675017, 0.048231795829321654, 0.03479844451482807, 0.026188252427216088, 0.17367137729057244, 0.15658829467637198, 0.14267272209482534, 0.09053580117012773, 0.16203902076397622, 0.06752269568720035, 0.1497787343604224, 0.21973319777420589, 0.1368661451020411, 0.1466559397854975, 0.07407895209533827, 0.09508991786944014, 0.07301097190273659, 0.11076178335185562, 0.15063549338706902, 0.1353659720293113, 0.20679657480546407, 0.19601472121264252, 0.158041865964021, 0.13451415273760045, 0.120264130245362, 0.18451267055102757, 0.14887590280600957, 0.10987271248762097, 0.14818554770733627, 0.08528364835573093, 0.09728623394455228, 0.10342459420540503, 0.10475278579230819, 0.11212730793548481, 0.07528332461203847, 0.12681705504655838, 0.12970471009612083, 0.11393350708697524, 0.17569092820797647, 0.10941779546971832, 0.06875013839453459, 0.12143635377287865, 0.1338154516581978, 0.12086495943367481, 0.14761662323560032, 0.1302076131105423, 0.1769225371203252, 0.10978740706507649, 0.08421687595546246, 0.11339854329292264, 0.12901702842542104, 0.14181529810386045, 0.15700002972568783, 0.08292213614497866, 0.14572916951562676, 0.19379091768392495, 0.14244459862155573, 0.17083272604005678, 0.114704037883452, 0.13861453985529287, 0.10516631895942347, 0.1246515783880438, 0.16224047781101295, 0.06961662761334862, 0.19106830949229853, 0.09110695802207504, 0.14006621124488966, 0.11966125188129288, 0.1650218471352543, 0.10205885249056987, 0.15922014202390397, 0.10899940399186951, 0.1336038572979825, 0.24759096865143093, 0.16818512310939177, 0.24665255472064018, 0.11380814095692975, 0.178563085517713, 0.07227928045072726, 0.17129782108323915, 0.11347293787236724, 0.17822944984904357, 0.12282479926943779, 0.23712548879640444, 0.10965386458805629, 0.21059158045266355, 0.08853499138993876, 0.15206386388412543, 0.1314983359937157, 0.20824061946145125, 0.20009064035756247, 0.10342298607741084, 0.1517567996467863, 0.17052188914801392, 0.20958274815763744, 0.1345742709402527, 0.15521727395909174, 0.19732365597571644, 0.12101190297731332, 0.2724001088312694, 0.11766333266028337, 0.15543960274330207, 0.15218960999378137, 0.2224387340247631, 0.1447464201067175, 0.14708998506622656, 0.1446449655507292, 0.16337520549339907, 0.21740555124623434, 0.16620281019381114, 0.14157437746013912, 0.09757919822420393, 0.19346980777169975, 0.14209880360535213, 0.1400975188506501, 0.1303404024136918, 0.11248579155653715, 0.11593217269650527, 0.20171647811574595, 0.13091962704701082, 0.09671916865876742, 0.17355048949165003, 0.16544490014868124, 0.1311916924480881, 0.10615005224410977, 0.12457578602646079, 0.0769232419718589, 0.09240450696753603, 0.10199184037212815, 0.0986822722479701, 0.10776132864079305, 0.07403865390058074, 0.07265808619558811, 0.15870545964155877, 0.11288978452129023, 0.07853379233607224, 0.15055355349821703, 0.13051925067390713, 0.11132970359176397, 0.14227088008608135, 0.06419394537806511, 0.09850243332662753, 0.11202145647257566, 0.14176192453929357, 0.13596669265202113, 0.1770206397133214, 0.1362517045012542, 0.06379308724509818, 0.15323078126779624, 0.15271478252751486, 0.134297713637352, 0.12914053536951542, 0.2551977533314909, 0.11967270555240767, 0.2107951816703592, 0.08465620702398674, 0.10770361245210681, 0.12094334379902907, 0.11318451977734055, 0.08828021506113665, 0.18055808703814233, 0.15311401896178722, 0.17949446982571057, 0.1206887031772307, 0.09215887729078531, 0.14335019859884465, 0.1881474062268223, 0.08927825864936624, 0.1430794359850032, 0.10522247451756682, 0.07329091509538037, 0.10174885019659996, 0.10602915765983717, 0.10350821686110326, 0.2541743596749646, 0.09000009098755461, 0.12473419681191444, 0.2031856421381235, 0.10615931424711432, 0.12692135944962502], [0.04576071717643312, 0.03788780427670904, 0.023534135560372045, 0.035990321809159856, 0.018046064601678933, 0.007935019209980965, 0.05071896594017744, 0.01594918274453708, 0.05108768865466118, 0.009605044016747602, 0.02378428597668452, 0.030228640085884502, 0.01090269219795508, 0.051226696731256585, 0.02022839437371918, 0.016408281234492148, 0.04166991775855422, 0.025036278080993464, 0.03200436283701232, 0.03872917752180781, 0.0012650292005024052, 0.052235766513539214, 0.017377448068665605, 0.01164145059218364, 0.038280523382127285, 0.05997349148882287, 0.03031094299097146, 0.12122317164071969, 0.05539834359660745, 0.04002379858866334, 0.027316936058923602, 0.030890808839883124, 0.07906668659831796, 0.054760354437998364, 0.006431620127321886, 0.041684163601270745, 0.033102056078080616, 0.04584933045719351, 0.018254602161635245, 0.009243446768128445, 0.02439142045165811, 0.02368713333271444, 0.06929467631770031, 0.027539599021630626, 0.03264936465503914, 0.03071785026362964, 0.0224809474311769, 0.02532709140463599, 0.04126674242849861, 0.012389001103916338, 0.04127072882173317, 0.04795950651168823, 0.02373692423238286, 0.019371978007256985, 0.020812238134177666, 0.053149522481752295, 0.0380882367358676, 0.017444584019748226, 0.005877338017203978, 0.03198062089670982, 0.032176595380795855, 0.053298284499240775, 0.01320729058768068, 0.04313036599861724, 0.016406286341537322, 0.037388324471456666, 0.032169348626796684, 0.027000648834343468, 0.023669031714754443, 0.013573007392031806, 0.033293433487415314, 0.03866493382624217, 0.024248743196949363, 0.012286068189756146, 0.006098008207378111, 0.006776677236692714, 0.06720456454370703, 0.04944525732259665, 0.07945638961557831, 0.029277205068085874, 0.04047605235661779, 0.054229790943541696, 0.01678398607431778, 0.021915106901100705, 0.08152839128992387, 0.018967425251113515, 0.0427645541993635, 0.08250063019139425, 0.050028549773352485, 0.008235811239241489, 0.02117352749753211, 0.05140336689406207, 0.06743995512702636, 0.04532560659572482, 0.05813516370419945, 0.04081198147365025, 0.017029156043593372, 0.03145667651136007, 0.06599486552711044, 0.10112208739987441, 0.03695098151053701, 0.030775430745312145, 0.03207309843440141, 0.0653650357521006, 0.07260714857173817, 0.024537185040701712, 0.010808081515798611, 0.01578736232061471, 0.0074668096910629955, 0.0031909909490163302, 0.01565853735831167, 0.054076893255114555, 0.06341025100222655, 0.024491514544934034, 0.04758238692634872, 0.0845024645594614, 0.07053246668406896, 0.022754497127607465, 0.020241520633654933, 0.09356649818697146, 0.036480308909501345, 0.05619653148044433, 0.014456731400319507, 0.021804559975862503, 0.06051713374576398, 0.04155508588467326, 0.06982332973607949, 0.0438815246203116, 0.041846971293645244, 0.0697591131819146, 0.03845387890136667, 0.03877698370654668, 0.029578108207455704, 0.04253013052844575, 0.07834738519574914, 0.058416586103183885, 0.0274699049935277, 0.11888864476765905, 0.02073703270538577, 0.032244428526610136, 0.04060940145115767, 0.022341820610953227, 0.07478046230971813, 0.02145330105642123, 0.05201975828302758, 0.010182115149551203, 0.024607864640919224, 0.024129694227927496, 0.02657842024096421, 0.06728973425924778, 0.026968330211405243, 0.02236960661996688, 0.01042866169674588, 0.04705608123913407, 0.03675790097830551, 0.028929900311465775, 0.08182158627148185, 0.02964942902326584, 0.03643609217501112, 0.03331628993951848, 0.027910750891481127, 0.05085557200280683, 0.01004285431866135, 0.06737101596913167, 0.022266733925789595, 0.010116565274074674, 0.0309457430349929, 0.010295734990255108, 0.03617206062855465, 0.030365904327481985, 0.00560780948892768, 0.05075665516778827, 0.04523573802517993, 0.05283301642962864, 0.025033972758267607, 0.01931715407408774, 0.03219659520047052, 0.02471924277155527, 0.010553058369883468, 0.03708962317822235, 0.014043701197286802, 0.03729479181181107, 0.05700640034462724, 0.02280392331470336, 0.025551567752180353, 0.020182742537664514, 0.06341486504035336, 0.024958948837593198, 0.02684661968877273, 0.05504030102331724, 0.006380376738629171, 0.014203586948237248, 0.020171076824356402, 0.03409465442278555, 0.018527681972565394, 0.012030809252922024, 0.022835787319179093, 0.044177226788763485, 0.01981051349347191, 0.03280204181958522, 0.03609561348067863, 0.09036164158689124, 0.00324009928486443, 0.1090492627450398, 0.05057918433366077, 0.02056801811392818, 0.013199970042998237, 0.04420894490821021, 0.061713180637785366, 0.03158202567803008, 0.05974405844296728, 0.011053506783874971, 0.037684647499450614, 0.027696208296609775, 0.03959133429452777, 0.04031245077827147, 0.008327595823045288, 0.007675454120284745, 0.02192459790967405, 0.02776754946847047, 0.0569730367777603, 0.08626379219016858, 0.03419969164367233, 0.08246103088770594, 0.05734366617564644, 0.06396187283098698, 0.10538695819143738, 0.025413051613473465, 0.017423149098509123, 0.008860306880835975, 0.06307983837489571, 0.05744651172842298, 0.05102007942540305, 0.049521819821425846, 0.029248743916728666, 0.03483117025877748, 0.028403659085077897, 0.07922625089330332, 0.02774906956723758, 0.07068061123469047, 0.009863349575815457, 0.012276342238432594, 0.022790513766397322, 0.06471068372151681, 0.028713247472686425, 0.018686661031097174, 0.052926823895956786, 0.025653473533956066, 0.06833807764840977, 0.06394682292427335, 0.01995795067133648, 0.08753600463803325, 0.06788627510624272, 0.012141527508252432, 0.01283955090080521, 0.03557661561561482, 0.04484278821785535, 0.04561800769131098, 0.06525858717837504, 0.037700643962515254, 0.036371794196644, 0.03431066943864737, 0.015025218216968434, 0.030808203986712863, 0.03848178365400859, 0.046890444055731804, 0.022193014488688538, 0.020616317932893122, 0.04315516645354884, 0.0185894795493888, 0.031078440735914876, 0.01738872192800045, 0.014700946331556355, 0.04650483938998409, 0.14995849185756274, 0.052662317374987264, 0.07223595598978655, 0.0332045827193984, 0.014747062964098794, 0.07075877168348857, 0.036192155443131924, 0.06320578125970704, 0.012992428233181792, 0.04653256093817098, 0.03194687395755734, 0.01835449947975576, 0.00908033034232046, 0.051621760175164254, 0.013363186552721475, 0.04734870625127639, 0.034721444360911846, 0.00888212856703571, 0.07229167728551797, 0.06177561264485121, 0.055256461924208064, 0.008486013393849134, 0.056834652953382046, 0.03133927977510861, 0.004591961565893143, 0.021020299023283378, 0.04770391933353884, 0.026362437455515777, 0.05471129296347499, 0.0624756504382406, 0.049480602211718044, 0.04403842905802386, 0.050363640899636915, 0.01719460154085287, 0.021269935449319224, 0.057764737866818905, 0.06802791250603539, 0.042327143384941986, 0.04780832212418318, 0.0008403706565981597, 0.010955757877257253, 0.03239765191184623, 0.005630894098430872, 0.01921888184733689, 0.0555707627375211, 0.033227469705577405, 0.060215877768184455, 0.13128097408584186, 0.03730217766548906, 0.03343601405088391, 0.03099218536434429, 0.0422253258127187, 0.030100010202399323, 0.027286491888974394, 0.020337187285934175, 0.02755927144815879, 0.011538482054934969, 0.047190668660082986, 0.02816285039963467, 0.054528400634548495, 0.057304718265576024, 0.023703379157398428, 0.02459903690032661, 0.024272271398720995, 0.016021433153322766, 0.13838771916925907, 0.0385456880820649, 0.011829569337091275, 0.0019247672088178141, 0.025547335390001535, 0.056236514156418185, 0.02020269655622542, 0.06791345721908978, 0.01991066356588687, 0.08004024864307471, 0.03675133954467518, 0.015136211278981395, 0.02678407572342881, 0.08979478664696217, 0.13616010227373668, 0.1413502844848803, 0.16569335253110953, 0.11797168611415795, 0.09695206223321812, 0.1955077469881092, 0.0714918269908854, 0.1195786063160215, 0.1062345230685813, 0.0843049090887819, 0.09852329827845097, 0.12586934518601212, 0.14765331840940885, 0.13888181479913847, 0.10531301823045526, 0.11255591136536428, 0.11398930980690888, 0.07258682644792966, 0.13559974091393606, 0.13874542926039013, 0.06571807752230338, 0.06158637601350035, 0.1311562050666128, 0.08104258735797235, 0.19780224029506954, 0.0892801381913679, 0.23444874957203865, 0.08827667310833931, 0.16741426661610603, 0.10686719590531928, 0.22452132084539958, 0.2328529166323798, 0.12021781344498907, 0.13094486854970455, 0.11718216990785939, 0.14671575943274157, 0.17485274747014046, 0.13092669738190515, 0.08866831673575298, 0.09127102778958422, 0.1353610051529748, 0.14425057385648998, 0.1432564386299678, 0.11805249963487897, 0.14308035879262856, 0.13896251975425652, 0.15171760746410914, 0.16099151197288716, 0.13237610246453965, 0.16197709765817436, 0.0866868452035955, 0.08970401223216738, 0.1262893583625555, 0.08857306398983512, 0.23175515553780965, 0.16536194245730126, 0.1060308539973838, 0.13652443486664975, 0.0778162619099021, 0.07542148112718548, 0.14353902132383414, 0.11104366715465273, 0.18220551578061922, 0.06083134974219969, 0.1304595260215657, 0.1647993555026395, 0.1701418145426682, 0.1369516405143908, 0.13944062909909657, 0.17868956444518908, 0.12051669455000333, 0.1523524448275566, 0.1148625300931079, 0.09783395419695548, 0.15776587863053593, 0.1517238635569811, 0.10805817414075136, 0.1360325241195304, 0.07649759695466075, 0.2120152690580913, 0.22594201032604488, 0.12277017720043659, 0.06844804103353194, 0.11480990291706153, 0.1423705161682197, 0.07553092882569347, 0.1427397070718663, 0.1115116731130651, 0.11766952089965343, 0.12639876534896238, 0.10687830352357455, 0.17693833341555937, 0.11889329951788698, 0.13893604331782886, 0.12893314792641572, 0.07720680175615208, 0.10939486777143818, 0.316961973373379, 0.2057324961892196, 0.1336195043155125, 0.09275056661239692, 0.0840847651873316, 0.16788268648087978, 0.15991706534155778, 0.14823581358151777, 0.13474659169358866, 0.06930263553346906, 0.16990664787590504, 0.07498850114643574, 0.1612970834331853, 0.15061014331877232, 0.20589108339377812, 0.1126921069143074, 0.1872332974203995, 0.15516504033335618, 0.1515981581594263, 0.2221365688102586, 0.0911906621019755, 0.17312712435211453, 0.12943256327084132, 0.11798875805522714, 0.08903785369225911, 0.07772615245942559, 0.13913288632673876, 0.06979989992188555, 0.13466200551816396, 0.12735126566674027, 0.13630650298936026, 0.19054120991911205, 0.17518213550959313, 0.10684741660952568, 0.09442441750849996, 0.12918453158012458, 0.18412260791020735, 0.1568172731037651, 0.09763141149388892, 0.17267156951129436, 0.09815804287791252, 0.06898062995501927, 0.08899982180446386, 0.09852416680327483, 0.20924597765718186, 0.10651304812303611, 0.12623156074966702, 0.1899861954152584, 0.09956608446581022, 0.21828763319977693, 0.12915618238704546, 0.15172979395304406, 0.12014702867184367, 0.11886983577694211, 0.11703111444200788, 0.1678770003574235, 0.07972269425434725, 0.14790303286697182, 0.1758240974907364, 0.22140870429575443, 0.09467379948390381, 0.1286450419574976, 0.04987149605793612, 0.09893123353166239, 0.08800110646656581, 0.234516440225499, 0.08045525423118047, 0.14219553555761064, 0.1002545328810811, 0.05532295157068542, 0.10263498300420386, 0.11676424661917345, 0.1346350269658225, 0.15407523166920456, 0.14561788977256843, 0.1490755413791963, 0.13880747450249536, 0.07137915625103883], [0.018495556732107486, 0.0569922664601888, 0.030687760628227676, 0.03450237593746611, 0.05584171534116779, 0.015331229028691138, 0.04014457442930766, 0.025532587431371212, 0.06774019330207791, 0.029740681805248772, 0.016199258521997502, 0.012476377754605241, 0.02224473242780992, 0.014251308316098792, 0.015246549554701363, 0.014885272065709745, 0.02819839715292411, 0.03386338933237961, 0.024249053626720394, 0.006615738060125815, 0.03427632538867848, 0.018885751687256352, 0.035613588988780975, 0.012713135585987141, 0.04072782616796238, 0.007003142115926104, 0.04103323138718094, 0.02017109209139432, 0.007052199349605611, 0.07085433655551501, 0.01337154780048877, 0.02712655609606632, 0.01774309023416468, 0.02845624046001051, 0.0016568222116412862, 0.017878781970856444, 0.039978160323309045, 0.02167030842974782, 0.030552562525761977, 0.024008540104010274, 0.010275657987222075, 0.017411581772778715, 0.03788888654006379, 0.005963528927947793, 0.00165655673481524, 0.009148454410023987, 0.005128171319873738, 0.03322892516319241, 0.004445031168870628, 0.026860254849972467, 0.03850283181028707, 0.03664066030510834, 0.07073868704693657, 0.03694452864250966, 0.0803365581003683, 0.025847252957256775, 0.024267511475565176, 0.03858742816373706, 0.029126098712107966, 0.013415728063721741, 0.1001968506191458, 0.02173393126577139, 0.07070791548384087, 0.04709464916959405, 0.019603758784277097, 0.017841791634314826, 0.06513031691844974, 0.04259370925969311, 0.05089513737974422, 0.05164897282208715, 0.029351983019816022, 0.0164956850265818, 0.010227099476781274, 0.004197692856126065, 0.024639041628688574, 0.032695223444274495, 0.03933380989890013, 0.01142827354903732, 0.05655118816399148, 0.05134914176804679, 0.08944017746086631, 0.050494689760463576, 0.0350995478220284, 0.02178220563967313, 0.030656554802720035, 0.04463370443720903, 0.07412350470466272, 0.09302215025361095, 0.020137187392850007, 0.03855518078697579, 0.052939023955592086, 0.022294613233368312, 0.05571177927777171, 0.03533578996679612, 0.0166202878047313, 0.0467707640491426, 0.029444206106875623, 0.051388194851045094, 0.10619790931897503, 0.11192794077630554, 0.0747373006971819, 0.026162434169756513, 0.02958420823727335, 0.012298221600108912, 0.08857509959489107, 0.024714155455252955, 0.07396199979952403, 0.03863187899280872, 0.03209710500336119, 0.03569506747382028, 0.03639933254037585, 0.00321456410373295, 0.025384551446352686, 0.03851195810628789, 0.06972457574946539, 0.06923680406595979, 0.02243342623114586, 0.024809401415820633, 0.05858980930809464, 0.052549660205841064, 0.035425912987973006, 0.03233019535296729, 0.08448879886418581, 0.023816813249140978, 0.028682587867868797, 0.03887762402051261, 0.07622302097401448, 0.057952658140233586, 0.04178911939795528, 0.04775661436308708, 0.034628993964621, 0.02771578912091042, 0.05732781559761081, 0.010630201864322382, 0.02726627154541867, 0.024974723080439225, 0.04328384044181023, 0.042078914919069836, 0.030657803307154348, 0.017180260703233734, 0.0806491184713585, 0.03804876635383282, 0.03244106797501445, 0.0759268132969737, 0.03434731372232948, 0.050973206226314814, 0.055100046031709225, 0.04131618727530752, 0.023228299471416643, 0.029575183721525327, 0.012520156834008438, 0.062188630125352314, 0.04976074557219233, 0.021580843587539027, 0.03498271426984242, 0.038650894936706336, 0.0684681935235858, 0.03460662605773125, 0.04934741257290755, 0.048709253780543804, 0.037160255280988555, 0.037697146114494116, 0.06550737882831267, 0.05463621984901173, 0.02273709948972932, 0.09097016536231552, 0.10578752455434628, 0.04385703629148858, 0.029319827245282273, 0.031032171432993243, 0.040941320426229916, 0.020576197853577987, 0.05858049302228859, 0.04195355557437454, 0.03309822574790035, 0.012966905986624104, 0.022764953352244835, 0.05547841751415815, 0.015723217012626783, 0.04123172662886126, 0.09895932488143444, 0.030332662896918397, 0.017022815133844103, 0.08287344447204045, 0.0647716840196933, 0.015845455096236298, 0.03813926935462015, 0.0044774418181207564, 0.036118748132139444, 0.023736715582864623, 0.015902392665988634, 0.023561731579580476, 0.008884436434267886, 0.03955059165933302, 0.0523145376438541, 0.03831154600317989, 0.030380584432610443, 0.0052205674333630925, 0.01991756257068898, 0.01747271099260875, 0.03073857950844935, 0.043626164751393456, 0.03511732543951698, 0.04137755737506917, 0.025054593437484333, 0.04509331691744072, 0.0328680700622499, 0.015274459396355917, 0.016723772876762917, 0.047907764823841195, 0.04444728711886065, 0.07760550214775971, 0.051042240379112105, 0.05510456168225833, 0.01973966256316219, 0.013921939784527888, 0.03899236089949097, 0.01025654111124043, 0.06598146446049213, 0.0172837220265397, 0.013723014521279504, 0.011928314842017633, 0.021736760756799152, 0.08369971692029919, 0.011896856262215545, 0.031836150613214285, 0.055732457632465024, 0.012379572859832218, 0.022693725834999765, 0.0064015025023504025, 0.07163315904991967, 0.07161583605089358, 0.028587810096463988, 0.042340839614293406, 0.030389032193592617, 0.021889734780415893, 0.045752089603671005, 0.01448564208112657, 0.04459726371403251, 0.06383177052651133, 0.03240077317293201, 0.06279530150017568, 0.007590963787931416, 0.026789821218699217, 0.023203466786071658, 0.03879581644598927, 0.04576423877317991, 0.028448681579902768, 0.0671875129586884, 0.02124513838706272, 0.04652846597933343, 0.07609615528157779, 0.03547293207209025, 0.009597092434497816, 0.01917063970384853, 0.07649370216365371, 0.05813068537307637, 0.052162413485348225, 0.12729169029210294, 0.09676201814519507, 0.061968221595244746, 0.03944624315149017, 0.03514987476436155, 0.04723395240892257, 0.007502114716252046, 0.05602662291909967, 0.07880931148039443, 0.04739763541147113, 0.029509962935532843, 0.05021231062710285, 0.07814776697861296, 0.16121993400156498, 0.012741370276281876, 0.06255940880094256, 0.11789954427097525, 0.1449426252927099, 0.053482218379420896, 0.054212953097053936, 0.048985471815935204, 0.01911119494720229, 0.011565319811260062, 0.028904770767050128, 0.056668567936867476, 0.043249275867960284, 0.05298226020698037, 0.10832689436418669, 0.027867088859368647, 0.038097597126449854, 0.03451950555401189, 0.05186779358025108, 0.024074929666572382, 0.07162033473806721, 0.049878929409065416, 0.0665947583370975, 0.05230196778263364, 0.04382863960095814, 0.0660768664841141, 0.02671355557894068, 0.02714423362963966, 0.040815940725484064, 0.024717677051999738, 0.022140348296878592, 0.03577768250501581, 0.056996269816798825, 0.050155836157500744, 0.10320960038474628, 0.041311786975711584, 0.05352039954492024, 0.007262263613353882, 0.008189078836169626, 0.007810824401011425, 0.024851652095094323, 0.030431267605828385, 0.011269943339617124, 0.04612689199192183, 0.007228859334385821, 0.06767489109188318, 0.04939504233854158, 0.009736558522230812, 0.03739524552864688, 0.03384646327633943, 0.033137821658913574, 0.01236301745354597, 0.01959660872151809, 0.05772734380194119, 0.027162627017657672, 0.02556298071119402, 0.04336450807750225, 0.02352424930515034, 0.014238521323672362, 0.08457689306565694, 0.02699494405117418, 0.026102295611053705, 0.049116500320711305, 0.03162407110046063, 0.03579680362184133, 0.059551700550530634, 0.03722678563956704, 0.0022702195648370044, 0.0435395395782377, 0.02703585971279868, 0.028958992500390326, 0.0298854540368276, 0.00413903732052339, 0.03030386587072696, 0.02046639901319785, 0.017083136897001947, 0.012187386297487786, 0.0705145737156272, 0.018858527165970633, 0.06590373827410595, 0.05057497402387006, 0.15024228234376225, 0.15568410605192184, 0.12340179830789566, 0.09013260209134646, 0.17330593190022878, 0.10441902120198522, 0.13186173220830305, 0.177020042602505, 0.12419439506317888, 0.10846179391124419, 0.11167791419263397, 0.07536537985184363, 0.10243184319032089, 0.10424945530082498, 0.1955137045255729, 0.0859390249741929, 0.09043119142630271, 0.10381397831120662, 0.10437227013920035, 0.10655344809804644, 0.07210617938211986, 0.127636956050992, 0.10262456070631742, 0.10495542349027735, 0.11651328365717616, 0.15964171583099024, 0.0962311594880053, 0.07774920229400907, 0.10611024937991585, 0.14531078482312815, 0.18051825703254767, 0.14828457310795784, 0.10501731266932827, 0.09856000023760966, 0.06037622916379145, 0.11236855427601508, 0.16191825510135718, 0.12374364425029073, 0.11834508393492017, 0.1549516139285905, 0.1365532318928412, 0.05734752703990255, 0.10409038633640323, 0.1222010220267943, 0.07620592189154454, 0.07003313276384558, 0.14763373588877066, 0.14204327229942593, 0.15467018474425587, 0.136850131675601, 0.08997676295361348, 0.1335583683103323, 0.2077005598694086, 0.10666474819715534, 0.1940491816827229, 0.17210329643317632, 0.12076634115406445, 0.18982230206685408, 0.1520379302757127, 0.1255271871175085, 0.1796453624431576, 0.06912162953189441, 0.11750686248498303, 0.12179419957101345, 0.17376075392322882, 0.188219439504402, 0.1109770621572222, 0.18440482419516357, 0.10561262536793947, 0.1504173579492739, 0.12902344736669744, 0.11608868358390671, 0.09178837002920252, 0.055811941224549494, 0.1667770136679922, 0.22822253938232148, 0.11058986293418066, 0.16523889691701957, 0.17451428063213825, 0.1280814100589071, 0.19538611280066626, 0.15908894049269812, 0.17193523687975748, 0.13214839968298162, 0.09931259735354356, 0.14360435067542962, 0.15387061264898094, 0.23202806232231005, 0.0883670471874731, 0.24271403891699656, 0.1579131478709834, 0.09546981605568103, 0.1515468337706157, 0.14121616525309427, 0.1302038404558386, 0.22379032149910927, 0.08866733285997595, 0.13729531850133622, 0.3583671844431332, 0.34541449376514977, 0.19174402180526937, 0.15811750904789992, 0.16121663632137434, 0.11128593808306114, 0.13902293651231698, 0.2718931888895375, 0.16473887089107717, 0.13929323772234575, 0.11237941083631345, 0.321873671242169, 0.14982184847550734, 0.14137587882578373, 0.18268085670258316, 0.08921333641878196, 0.16722198336252145, 0.2048188080745084, 0.05899048423660653, 0.10630229514624391, 0.13596059940755367, 0.1899705891098295, 0.16796625485377653, 0.10222142269568783, 0.16284573104764732, 0.0798236331237214, 0.1066329859729324, 0.22365940495261125, 0.15236415634197847, 0.11111327806221587, 0.157355487080557, 0.1906040422618389, 0.111952008413417, 0.14329147817833082, 0.0877564742362925, 0.10479176762912955, 0.13070375791617803, 0.10614111593791417, 0.16545803658664227, 0.10617582300411803, 0.09305844509175845, 0.16776160869215215, 0.21251000251088822, 0.17681137951357023, 0.07991923870784895, 0.16911225978817257, 0.09205419290810823, 0.14802967464285238, 0.13570861864302838, 0.10264676915747778, 0.10671062394976616, 0.11903254847441401, 0.09986046009830066, 0.17986410856246948, 0.07850791979581118, 0.0872103146144322, 0.12152049211519104, 0.08973059723419802, 0.11329427960195712, 0.07585666634674583, 0.13929429623697484, 0.11079101464045898, 0.09643298972930227, 0.14087723701127938, 0.15661660315735, 0.12268325686454773, 0.09159859056983675, 0.16851536610296794, 0.1423021334090403, 0.11798756383359432, 0.11535803707582609, 0.11863731539675168, 0.14496332061077866, 0.1396716974143471, 0.15627057743924005, 0.12716677199516976, 0.14000050191368374, 0.09550590733332293], [0.021187211852520704, 0.038336417704288445, 0.03029527222471578, 0.03345809018771563, 0.025122723442369273, 0.02155314409174025, 0.014487679382520062, 0.023032572652612413, 0.0077781682069014224, 0.006153258769440332, 0.0340074762435896, 0.005364148411899805, 0.019182812622083083, 0.15101284028163978, 0.01968662826610463, 0.06267375552228518, 0.0026763083546289374, 0.03745957064841475, 0.022243600970666324, 0.023872463298695426, 0.045343927041228325, 0.04801362307210054, 0.014617810524734003, 0.007659168431668409, 0.029759019214127744, 0.018308947727616345, 0.006757514135512922, 0.04507514914231641, 0.01958531789880778, 0.04485310873548899, 0.07543798988418919, 0.023661963076197674, 0.06937158826206412, 0.009679782104545405, 0.029751497653446028, 0.015200180167864476, 0.06578878087124654, 0.07371520304254123, 0.03247556469536253, 0.04730513412505388, 0.06325329228171281, 0.04869260253118617, 0.012159403513318725, 0.025763879663177898, 0.07066197187772819, 0.028091185227302567, 0.07349341030099563, 0.06539583445659705, 0.0345413883083633, 0.041961501219442914, 0.060426868232233186, 0.03315558570570179, 0.009074314281211367, 0.09036318186138358, 0.04974090520824705, 0.050951116518782716, 0.006935029498501015, 0.08942068314978055, 0.04254239844158292, 0.012864526926672884, 0.012062730084705566, 0.03276375548115798, 0.06928091562752213, 0.03321594478828566, 0.023185170089293803, 0.09385060079927955, 0.06294152579669442, 0.04292372155136295, 0.05174351649891053, 0.06318224287991013, 0.1320887700255428, 0.046696953009814024, 0.03952532640791365, 0.06672308966517448, 0.03126057989097067, 0.04577678149299962, 0.042307540508253236, 0.056270786960210116, 0.024817611689546278, 0.04470818044085588, 0.08438867423683405, 0.2675346870507513, 0.14145448032234395, 0.035561433394572566, 0.44514703644173487, 0.1368950099817344, 0.1474478037229606, 0.08288095585469689, 0.06108774098434618, 0.027019430683659654, 0.10139422743980374, 0.04382952508915748, 0.03796314541250467, 0.02229004160368017, 0.009289619379809924, 0.031044232392949716, 0.0638993593997189, 0.013251594683554555, 0.15705995793853486, 0.10786464916808264, 0.11923510474818093, 0.0689887520191925, 0.012295593973249197, 0.029429376724043062, 0.1559032050094434, 0.028983039781451225, 0.03727365205330508, 0.03341178356536797, 0.04054309840181044, 0.06513263072286334, 0.050317076433982165, 0.011479519906320741, 0.05716245661356619, 0.009222229826264083, 0.07384882015841347, 0.016244696619521295, 0.019717700080946088, 0.027879100625536272, 0.050761177603687556, 0.024381432416183606, 0.028349634126893113, 0.0551676824023681, 0.0254786489864013, 0.05333599069022706, 0.02724408345030887, 0.033207249362021685, 0.05255376534270389, 0.030393110189054693, 0.04777685845536845, 0.038172992545046976, 0.038432857886488946, 0.0065578891330265576, 0.042855817159371715, 0.019762069485815506, 0.033719146358115334, 0.026593573624268174, 0.022374570103628293, 0.01592165288249297, 0.016245217395148108, 0.030168325108076845, 0.024906041765851632, 0.007928694415438389, 0.018040510792551295, 0.03868925930666072, 0.10791802951799971, 0.014576204453728028, 0.020834604344729866, 0.043295144835220914, 0.07477115959461246, 0.03822324484852808, 0.1355487693633352, 0.16480263961212976, 0.017512284851233875, 0.04229860759473272, 0.07359379955700465, 0.03949638010401811, 0.011390062697630907, 0.052968730218708515, 0.03767530407224383, 0.033008615020662546, 0.06044116496507611, 0.03007942344993353, 0.012103128363378346, 0.009898378946153181, 0.0236719154885837, 0.034218615985342433, 0.024711493901642304, 0.01961032021790743, 0.048636297695338726, 0.07257949826972825, 0.021838027019319788, 0.026846295688301325, 0.05548821555982743, 0.01056240264525903, 0.019051395656008805, 0.0057338961383460885, 0.039519379048475196, 0.012900995639418917, 0.013997775402718356, 0.03195521993828671, 0.05428317129345877, 0.06540646031498909, 0.022456440442640866, 0.019598417017342787, 0.03256387263536453, 0.01970775954292289, 0.020415670038866143, 0.11531083817992892, 0.013123136130161583, 0.09731710728790079, 0.05216343468055129, 0.038171235139348676, 0.027831877980913435, 0.020021911078531827, 0.012043170464624251, 0.03987980667235596, 0.044006466665970426, 0.04616396714534078, 0.03215263630928738, 0.0342789241777999, 0.017472242803445885, 0.04572375737396734, 0.040031571207301955, 0.04656967680369105, 0.00942948749954147, 0.07788652421108314, 0.026215292047709227, 0.027641257138124535, 0.10315231167312179, 0.015945532226136754, 0.0340251995782767, 0.02521382355397301, 0.007439269650993603, 0.03856503990079675, 0.02941537176125816, 0.024518516846001148, 0.039359105684395344, 0.029411073241915022, 0.02751113278126078, 0.03302315263343709, 0.052859346981027296, 0.011324437335133553, 0.04082237323746085, 0.023427206923120787, 0.035720275049763064, 0.04093395492860249, 0.0543593639907028, 0.03422938094341329, 0.03368111447032009, 0.058064134658447335, 0.049877205930118046, 0.02816608701167362, 0.03208026037152324, 0.004719615207120244, 0.03692439990118146, 0.03941486429955278, 0.08435327506491117, 0.011705036956949957, 0.05898868611880711, 0.025098932308277914, 0.04306329620469894, 0.00395283755746537, 0.03571159319419946, 0.030658960209361145, 0.035404830904943604, 0.007756527180650404, 0.04416242115465658, 0.045630472379603555, 0.024959498450958302, 0.01832370586427195, 0.07296152027057749, 0.07537645354334797, 0.023478047855730568, 0.029905447071152072, 0.024669750427295054, 0.01316878542170993, 0.04599187709391117, 0.1256362684071064, 0.13178355140345438, 0.07151250195290361, 0.30005304355706486, 0.2106206217514617, 0.12138094460325581, 0.08067830226251058, 0.019119440844016414, 0.022056745997230922, 0.04047399639551129, 0.02608957647212914, 0.07132466988904135, 0.035848066942500215, 0.04811077910874571, 0.02236235816963017, 0.03644183597394398, 0.02915579479719911, 0.1747452403817858, 0.20572435376899584, 0.08992412220686674, 0.022922144471002475, 0.06095423921942711, 0.03276277160538094, 0.07251288648694754, 0.012230269710666366, 0.0677921080163547, 0.03496450578261699, 0.03436802939644881, 0.08290414818163429, 0.030815077546451772, 0.011263135088873761, 0.06235837923096759, 0.05407916634742703, 0.062297473927693706, 0.05200546155018466, 0.06212020665407181, 0.06204221583902836, 0.051529347098299434, 0.036490079813769886, 0.04546031954565218, 0.023907278930502276, 0.004745329139820699, 0.018073526610221182, 0.04124954156577587, 0.09934643589492355, 0.03148128019113626, 0.018137166409620216, 0.04360077397099563, 0.056304062317524634, 0.034141863496708016, 0.0635017514494913, 0.04431185831448861, 0.019265220700097934, 0.011234133654007954, 0.053009489817278724, 0.018851041228377392, 0.01796987868978509, 0.0619670884417636, 0.004861798827602927, 0.01419139961113355, 0.057618893549910614, 0.06470308412930795, 0.021311906232897724, 0.040796392131596804, 0.0119905458330842, 0.04813838191330433, 0.022389284135507684, 0.03498879394360951, 0.021740087274728075, 0.09957780276558229, 0.053697168095303435, 0.08390906532960278, 0.031626961659640074, 0.02216000545636884, 0.07075107031102691, 0.03137298260948487, 0.05902665015310049, 0.03316879678251488, 0.020625746176977242, 0.06779328188193695, 0.028717925971640006, 0.04437890435968127, 0.03512070793658495, 0.018084423882620673, 0.08681829779275826, 0.042462938598224094, 0.052065715459840636, 0.024937171256169677, 0.03403952684519546, 0.012503420767773474, 0.015213454009166785, 0.03397912365783538, 0.04579236065702779, 0.08938517541225467, 0.016104178802509393, 0.13600804257605756, 0.1136785407683679, 0.10780034440436534, 0.09660398055400167, 0.12747612968087196, 0.09886321039604289, 0.15371658519974776, 0.11159582502607789, 0.09389385740671839, 0.05477498026032533, 0.1460292177008731, 0.11622744399522032, 0.11938402961407389, 0.19647833704948425, 0.10365672782063484, 0.27529444066541536, 0.133672972874982, 0.08351169486663171, 0.173726012930274, 0.12978276876466616, 0.11434871623558657, 0.11249922654990639, 0.10700797835098845, 0.10510833135672978, 0.11870822230620043, 0.07503669070346014, 0.09396179233278547, 0.11718033786330904, 0.12171364389359951, 0.2285031814660345, 0.19649635893957956, 0.10946933698973485, 0.14134743463780197, 0.10029903120760407, 0.1536065675318241, 0.1676724763321025, 0.22715006050254616, 0.14603508024343423, 0.11659255011805467, 0.13763770727174623, 0.17266052296119078, 0.17878305300005845, 0.14435240839208874, 0.11560240467744214, 0.17838786063449724, 0.16803822027785437, 0.15307988865034922, 0.12058122323027679, 0.0707064498482006, 0.0891126078952636, 0.10049635597637721, 0.09329137937831027, 0.09243301900901965, 0.15015297356460774, 0.12807322692658218, 0.16087755880185536, 0.15366137959063053, 0.10553084154214178, 0.0880587955138513, 0.10090233026338474, 0.20914948997753008, 0.13844882803303854, 0.13638522662222385, 0.13100057627473558, 0.20277989176767214, 0.17142583349985735, 0.13872887300593512, 0.2166533408952611, 0.1248659004590341, 0.1987070667424372, 0.19518230802246503, 0.17851275179002965, 0.13723385679934705, 0.13920945221824305, 0.1445234263581889, 0.1452075932174921, 0.09785174538514443, 0.07316312659531832, 0.10806787040616785, 0.0726265614586217, 0.13204864146453993, 0.36212702840566635, 0.22113477970872605, 0.1868720589471715, 0.9429173405681337, 0.8245172681553024, 0.43085782176681925, 0.25316741370729035, 0.17883721366524696, 0.1022071327481951, 0.19968696630426816, 0.16082334385386535, 0.15359443532569067, 0.11282366128372294, 0.097484271175095, 0.2368851788341999, 0.14857635673667702, 0.13298031075724534, 0.27507215259330614, 0.3580545426479408, 0.3122018330863544, 0.15869163109787873, 0.13024563821298735, 0.1819331789655345, 0.2307831405528954, 0.18178699538111687, 0.18446245895964758, 0.19424004001276834, 0.11137963019843612, 0.16242855414748192, 0.07215494569391012, 0.10140859202614852, 0.20576355952237332, 0.11338671642754759, 0.16241995032344544, 0.1430034672043153, 0.1234167939318078, 0.12888081930577755, 0.1587333202894245, 0.11891978952501502, 0.2255706073982375, 0.1761378656540598, 0.11249662097543478, 0.1374130036149706, 0.14625061010675772, 0.1513670084199735, 0.12906038681311266, 0.10091928006815058, 0.12104977880205427, 0.14423128989126, 0.12635451129504613, 0.13072384255273, 0.10497213580778667, 0.12183705584279128, 0.10474793426692486, 0.13798511720129422, 0.16741514871163027, 0.12076548619994096, 0.0933685288099306, 0.09483442229351827, 0.06587059862379517, 0.10796078400952475, 0.11003998494041817, 0.061880310598228655, 0.1772767731121608, 0.14220275517020906, 0.14576182062072413, 0.09922787547111511, 0.16346885689667293, 0.07380239479243755, 0.2078971043229103, 0.3581773303449154, 0.10985307568418128, 0.14148140459188394, 0.15901849498706205, 0.17599806029881748, 0.10562150739133358, 0.13718418803598198, 0.15064445004931518, 0.09266818567578282, 0.14472235925495625, 0.09762501969401326, 0.09845091216266155, 0.09237106197646686, 0.09654099214822054, 0.09635449679834501, 0.13450531821165765, 0.10646774912519114, 0.1316896557275738, 0.20967209764889308, 0.13037622906267643, 0.2095701138355902, 0.12816394705857548, 0.143090672524912, 0.14605779759585857, 0.09906335108514343], [0.0933154605861221, 0.07103038246610335, 0.10483680878366743, 0.05460986554888742, 0.02117590237009738, 0.0796483200309532, 0.042694352966334136, 0.05526978156662413, 0.03834146600482719, 0.006698169462781931, 0.06313741207122803, 0.04509867395141295, 0.03140650223940611, 0.06388067254530531, 0.015775920523862754, 0.026617422433836118, 0.0006495080326983173, 0.08055303791271788, 0.034689488754208596, 0.0784614672884345, 0.016208557844428078, 0.053589857782104185, 0.040446729465786896, 0.025357009709945748, 0.05005225778690406, 0.005667688932070243, 0.05056447369445648, 0.018513434433511326, 0.019648341927677393, 0.043257825409195254, 0.019922678724729588, 0.04862719854073865, 0.05928739080471652, 0.02443998829195542, 0.01025030537441905, 0.004286439723468253, 0.03990742644029004, 0.05477723299658724, 0.09158793757004396, 0.019637392068813955, 0.023723188987267867, 0.02958509711814778, 0.02510151922303651, 0.053079368746174235, 0.057760042404489856, 0.05468807688781193, 0.034121527802199125, 0.026130658374833207, 0.05091408207746489, 0.014752854260482957, 0.01985584302539272, 0.01816598209552467, 0.05580705577241523, 0.03197593900508114, 0.05963800341955253, 0.039572264067828655, 0.026448755591575588, 0.1145216476704393, 0.05601731341864381, 0.009107174035826964, 0.037072632661355395, 0.05467577844059893, 0.04082629856254373, 0.08951396135879414, 0.06576526284750019, 0.19491294319076197, 0.1060253782197833, 0.06474264272089515, 0.2421918383666447, 1.1362939583403724, 3.4801240350518907, 3.4505008246217455, 4.14139951126916, 5.418287771088736, 12.666987265859332, 9.972431557519094, 19.269123009272985, 15.260695082800728, 18.777098485401698, 17.75905363900321, 18.29790554727827, 21.146536690848215, 23.88897851535252, 38.087366989680696, 53.88696609224592, 60.909868240356445, 43.51165887287685, 25.347434929439, 18.112953186035156, 9.270291771207537, 3.077969465936933, 2.330418207815715, 0.9794092795678547, 1.0672386352505003, 0.4313122773809092, 0.4726752021483013, 0.01666309149004519, 0.0989180767376508, 0.09943116456270218, 0.23459048196673393, 0.19907298710729393, 0.023358695242287855, 0.021758092201447914, 0.07251739195947136, 0.09762447686599833, 0.10854760823505265, 0.03868547986660685, 0.015108377772516437, 0.029075985508305684, 0.03434949181973934, 0.03708058848444905, 0.03632712623636637, 0.06306328212044068, 0.0402220699137875, 0.0372408584558538, 0.04381017327042563, 0.05075299107868757, 0.06526764562087399, 0.019484297605231404, 0.008058265766261943, 0.043332878167607954, 0.029453217051923275, 0.0442021222385977, 0.017046282267464057, 0.03189205511340073, 0.04626414266281894, 0.01894039920132075, 0.03680509987420269, 0.07454746016966445, 0.040601153858006, 0.05588893798579063, 0.06778083754969494, 0.024929235789126584, 0.07276728962148939, 0.047568894257502894, 0.021978678846997873, 0.04135723864393575, 0.017470834843282188, 0.052308780274220874, 0.013457990617358258, 0.05642855313739606, 0.004451318219902792, 0.04324579159063952, 0.0347816100610154, 0.06491547916084528, 0.04064911271312407, 0.04556936351582408, 0.01694885820948652, 0.050475473648735454, 0.09927986482424395, 0.036240161795701296, 0.013688982597419193, 0.029531112872064114, 0.022079677088186145, 0.0429956428706646, 0.05098954874223896, 0.04686531111864107, 0.027212210964145403, 0.0379324043834848, 0.03940758701147778, 0.04031473404860922, 0.04072142758273652, 0.03582373128405639, 0.013408851959476513, 0.06748032796063594, 0.011576056779761399, 0.019639480260333846, 0.023135869431176355, 0.09208030293562583, 0.015272337278085095, 0.08189730399421283, 0.062172894898269854, 0.01705048918457968, 0.04939897784164973, 0.02799639049252229, 0.06035579847437995, 0.07167207303323916, 0.09063456872744219, 0.04277813168508666, 0.035885338871074576, 0.02333163356940661, 0.037816235795617104, 0.03514235659635492, 0.060939019678958824, 0.030485326490764107, 0.01658328389748931, 0.052331847072179825, 0.017476980674213598, 0.03781243260683758, 0.008696427951300783, 0.05171071272343397, 0.027421442326158285, 0.03668069726388369, 0.07594765789274659, 0.009345450937481863, 0.021946536643164496, 0.04759396273376686, 0.03169785160571337, 0.011241473706572183, 0.013238141878641077, 0.060259304009377956, 0.05196113625009145, 0.0524827193335763, 0.02046975097618997, 0.028257236317066208, 0.052071737458131144, 0.019688378886452744, 0.013773315170380687, 0.00719318026676774, 0.01724317277382527, 0.04603901831433177, 0.046161765299205265, 0.04702733849574413, 0.026043027273512313, 0.007285050515617643, 0.021543351135083606, 0.0335160879684346, 0.026747304214430705, 0.02496183939677264, 0.10215929602938038, 0.024919989053159952, 0.035862268680440526, 0.07476734622780766, 0.013047819591260381, 0.05913647783121892, 0.01296828595721828, 0.016701315063983202, 0.031505045880164416, 0.03567284205928445, 0.01629172927433891, 0.04686026281810232, 0.06296746619045734, 0.029305282847157547, 0.09769800970596926, 0.005040410024646137, 0.014571593808276313, 0.024723171489313245, 0.019913693224745135, 0.09611672455711023, 0.056523415725678205, 0.07186884140329701, 0.10035055915692023, 0.09725502133369446, 0.07573717632996184, 0.10747793170490436, 0.7536832062261445, 2.9195505380630493, 2.8851345905235837, 2.710513114929199, 4.363014476639884, 10.457068409238543, 8.705126166343689, 17.42151015145438, 14.158625670841761, 15.992272649492536, 16.329746655055455, 17.124101196016582, 19.371405703680857, 24.155040672847203, 40.47450746808733, 62.329781259809224, 69.51587922232491, 51.25960554395403, 27.79185461997986, 18.59494972229004, 9.552943621362958, 3.5013546901089803, 2.8122979274817874, 1.321594923734665, 1.2460442291838782, 0.6464523087654794, 0.35792947507330347, 0.05264078067349536, 0.035442465849752934, 0.05340720294043422, 0.15137555796120847, 0.08553891322974648, 0.05586367612704635, 0.03357535121696336, 0.09359342245651142, 0.11772765778005123, 0.13584166578948498, 0.03318166859181864, 0.01854925599348332, 0.027012743721050874, 0.04719980852678418, 0.003943987340400261, 0.11388739384710789, 0.07906657803271498, 0.026116675464436412, 0.042874860244670084, 0.057024232244917324, 0.06714226824364491, 0.020364708666290556, 0.015759601756664257, 0.05036845849826932, 0.0283649266098759, 0.055732284606035264, 0.0718728651159576, 0.008712713639917118, 0.009877430873789957, 0.050484776363841126, 0.06501177685069186, 0.01847532281785139, 0.08930867058890206, 0.019830508224133934, 0.03263484739831515, 0.04619812799085464, 0.07837166317871638, 0.08093249505119664, 0.06717242912522384, 0.00964501397018986, 0.012952272530778177, 0.01987423132439809, 0.0055506819293701225, 0.03112139200259532, 0.016464815075908388, 0.027731873793527484, 0.06657271273434162, 0.01665198047911482, 0.01377584271332515, 0.01915107075391071, 0.03586832460548196, 0.03628124709108046, 0.05891294804002557, 0.062024065027279515, 0.04466666088306478, 0.05973142412092004, 0.051159494623009644, 0.04354748183063098, 0.011010235757566988, 0.063867780379951, 0.052405315451323986, 0.022233238044594015, 0.018310264085552523, 0.019482484220394065, 0.022687149134331515, 0.02698983298614621, 0.010782610159367323, 0.012071530683897436, 0.03266763760309134, 0.028615786095282862, 0.014565098531810301, 0.03865089832938143, 0.009071280381509235, 0.044926132674195936, 0.019246544023709636, 0.056777181037302525, 0.07021001327250685, 0.03584458605785455, 0.04231465155524867, 0.051651018605168374, 0.1828018802085093, 0.1899835762700864, 0.23129559734037944, 0.11100390500255994, 0.10703628683196646, 0.17364385591021606, 0.11079579831234046, 0.17245046209011758, 0.12482737324067525, 0.054975568782538176, 0.2029523075159107, 0.09391224570572376, 0.16412151258971008, 0.18266668889139379, 0.11117055998849017, 0.13857508982930863, 0.12141165509819984, 0.18679565590407166, 0.22598652222326823, 0.1625385989568063, 0.11275329041693892, 0.11830514536372252, 0.11405459844640323, 0.13607573322951794, 0.08523792866617441, 0.11885615651096616, 0.15193803635026726, 0.05365927530718701, 0.07943175200905118, 0.12383189451481615, 0.14911579207650252, 0.15574170010430471, 0.1752464742000614, 0.10480020181941134, 0.15009893503572258, 0.1393636967986822, 0.22146648833794252, 0.20204878385577882, 0.17135593082223619, 0.07943336013704538, 0.24580628584538186, 0.08401585995618786, 0.09388598640050207, 0.1172401982226542, 0.1100609584578446, 0.1409752717507737, 0.1581057703920773, 0.08806543837168387, 0.31402869362916264, 0.09034872228013617, 0.15395370604736464, 0.13039183536810534, 0.13343984181327478, 0.08998538713370051, 0.19882950160120214, 0.15002014354935714, 0.13303132301994733, 0.20814316826207296, 0.10415819912616696, 0.13120789586433343, 0.15983208561582224, 0.123295200456466, 0.2284101950270789, 0.23752889143569128, 0.17142097518912383, 0.2839390853685992, 0.18814219507787908, 0.13690099466059888, 0.5446623393467495, 2.154505887201854, 5.4480238897459845, 6.558342116219657, 6.795660010405949, 10.040655050958906, 20.129596608025686, 20.485099451882498, 32.178504262651714, 25.61530188151768, 26.69518222127642, 26.339194740567887, 27.55528061730521, 31.399607726505824, 35.20271464756557, 57.190164021083284, 83.16976342882428, 90.10562201908657, 70.61954498291016, 42.21502079282488, 27.37098833492824, 15.353173868996755, 5.776520388466971, 5.024486890860966, 2.1405947250979285, 2.589950144290924, 0.943683379462787, 0.6281189982380185, 0.14146582542785577, 0.12657302671245166, 0.13888177408703736, 0.40048762570534435, 0.2707428549017225, 0.14034405776432582, 0.18027889701936925, 0.2163584902882576, 0.219663960060903, 0.222567099279591, 0.1488450158919607, 0.10133706764983279, 0.136749925624047, 0.14150668680667877, 0.14188863416867598, 0.1283930204808712, 0.1702883102531944, 0.18153532674270018, 0.11883020933185305, 0.15987507759460381, 0.1150814119194235, 0.10868307096617562, 0.16604686927582535, 0.09533383763794388, 0.14706181229225226, 0.1219329871237278, 0.11648722791246005, 0.08214676060846873, 0.09181144700518676, 0.12409349690590586, 0.20093448007745401, 0.04888335568830371, 0.1575435905584267, 0.09678681860012667, 0.14483978652528354, 0.13913957668202265, 0.22600592832480157, 0.20611274721367018, 0.07565788272768259, 0.11308771997158017, 0.09691920078226499, 0.08559645978467804, 0.17712900175579957, 0.1401738676109484, 0.07735190646989004, 0.14151408283838204, 0.19059136722769054, 0.16150398233107158, 0.13926522779677594, 0.09363572911492415, 0.07081441155501775, 0.07159328154687371, 0.12891781303499425, 0.22991754700030598, 0.17054793132202967, 0.18239817901381425, 0.09758600393044096, 0.129358833655715, 0.10030016436108521, 0.0994057534262538, 0.22500181863350527, 0.13021110078053816, 0.14749789317803724, 0.13273360899516515, 0.14532435552350112, 0.09803832894457237, 0.07849834566669804, 0.09880168084055185, 0.11896037948983056, 0.09879060714904751, 0.09707077193473067, 0.09021367345537458, 0.28829139896801537, 0.10548198702079908, 0.18861811953995908, 0.10626323188522033, 0.11817905998655728, 0.14896941850227968, 0.17820635251700878, 0.16668159807366983], [0.026125610074294463, 0.01992133692173021, 0.03623229757483516, 0.02190175502827125, 0.045205458399972746, 0.0296262536597039, 0.043970192183873484, 0.03724616799237473, 0.0703631043434143, 0.055893304358635626, 0.037490332033485174, 0.01949295910474445, 0.04779373362128224, 0.03512554928394301, 0.019961451912032704, 0.08841592885021653, 0.021059243540678705, 0.05425387215135353, 0.05926806612738541, 0.03830013982951641, 0.04115798683570964, 0.04833521135151386, 0.06192682417375701, 0.047674762683787515, 0.01803871097841433, 0.06153646976287876, 0.038246790013675175, 0.017688145861029625, 0.03417961718514562, 0.027517431282571385, 0.041039501050753255, 0.05743853894195386, 0.05994463339447975, 0.045315791586680074, 0.02091267319130046, 0.015036034065165689, 0.013524818683176168, 0.0334852655152125, 0.01872150380430477, 0.006914563610085419, 0.013479524774343839, 0.02257714164443314, 0.03356873210785644, 0.015536908259881394, 0.06618233118206263, 0.020845898560115268, 0.07830913617674794, 0.08128113991447858, 0.05092840255903346, 0.044457166588732173, 0.03479291445442608, 0.008672657173259981, 0.031181259147290672, 0.01777331896924547, 0.015246583481452294, 0.02840821205505303, 0.061388454133910794, 0.040401009776230366, 0.03238122797171984, 0.022611397484849607, 0.06024219814155783, 0.008357214724778064, 0.02425788645632565, 0.07799848248916012, 0.10637060326657125, 2.5003099143505096, 11.257227301597595, 20.55330296925136, 38.27322435379028, 50.15896224975586, 69.05945205688477, 69.79785796574184, 74.67755004337856, 81.58092580522809, 79.7486788885934, 82.80518450055803, 89.11667101723808, 82.70876434871128, 98.52139827183315, 97.32075650351388, 99.95323440006801, 102.92120606558663, 105.90283094133649, 116.26887621198381, 105.65867124285016, 113.66140488215855, 103.75995785849435, 106.37092413221086, 107.80466406685966, 103.23224217551095, 86.52525002615792, 72.78061539786202, 65.71060098920549, 61.29055309295654, 45.1657018661499, 19.425789254052297, 25.635521139417374, 47.6579373223441, 43.70923089981079, 34.655464104243684, 20.082192523138865, 6.236915409564972, 1.5596850450549806, 0.12579850613006524, 0.12288452392177922, 0.32909493946603363, 0.07859623112848826, 0.09260392840951681, 0.07362701384616749, 0.015123280097863503, 0.005639846943917551, 0.02454135972740395, 0.02749423047394625, 0.010715505590529313, 0.02074534136668912, 0.051783655237938674, 0.049964367145938535, 0.006349001703451255, 0.03323008885074939, 0.04157087200188211, 0.012534054079359131, 0.039951707635607035, 0.003803397004958242, 0.0170268575062177, 0.013094089742350792, 0.025164516110505377, 0.04358338651114276, 0.027459265564435294, 0.06674509455582925, 0.04354293903868113, 0.04932202857785991, 0.06919479596295527, 0.05688349390402436, 0.061284889334014485, 0.014494812481903603, 0.03375939366274646, 0.07422749698162079, 0.031680708418467214, 0.09830315437700067, 0.006582804514826941, 0.012649179419635661, 0.061217164753803184, 0.02017558060054268, 0.04665337409824133, 0.05603722842144115, 0.01224179971697075, 0.08645524084568024, 0.021740051651639596, 0.037905079778283834, 0.039168963208794594, 0.04469467420130968, 0.061136086604424884, 0.023505143455362747, 0.04011213027739099, 0.051461537701210806, 0.03117709294227617, 0.06806457375309297, 0.037805104428636174, 0.07717823543186698, 0.09798764916402952, 0.06746724580547639, 0.12051486250545297, 0.048308969009667635, 0.011126920880217637, 0.03022921344797526, 0.03051895129361323, 0.02685197502640741, 0.02637401665560901, 0.02516294190926211, 0.022606001435113803, 0.060203779488801956, 0.04132175126246043, 0.08577070757746696, 0.06298135580228907, 0.025154582357832363, 0.023567008885688016, 0.044112033144171746, 0.022957675957254002, 0.030168189401073114, 0.02273334888741374, 0.08651347950633083, 0.017586769336568456, 0.009908289798269314, 0.035203143156000545, 0.0650365569495729, 0.047855924748416455, 0.03707501431927085, 0.029007253303591694, 0.003787717332930437, 0.0312015778784241, 0.08175237569957972, 0.032419643231800625, 0.01969234153096165, 0.03645273663901857, 0.043937357874321084, 0.08902790636888572, 0.046087479285363636, 0.03250471455976367, 0.06620986613311938, 0.028575742351157323, 0.030435976638857807, 0.011777004077365356, 0.07358691921191556, 0.013109949650242925, 0.033843830560467074, 0.0083824621646532, 0.023203358220468675, 0.04383509586166058, 0.05353900497513158, 0.004584145690647087, 0.03312529590246933, 0.011949942297568279, 0.04624107925753508, 0.04218263578202043, 0.027245566049324613, 0.023838933490748917, 0.015345145781923617, 0.037105796060391834, 0.021629509815414037, 0.022953838841723542, 0.02444608323276043, 0.08419246226549149, 0.0596891242478575, 0.04144138716427343, 0.020459516971771206, 0.03640480153262615, 0.025658645667135715, 0.038857352786830494, 0.005853184290962028, 0.0625683179657374, 0.013010910678921002, 0.044638223480433226, 0.09026721665369612, 0.08429217298648187, 0.0399801382528884, 0.05252555524930358, 0.03602216545758503, 0.027085116266139915, 0.04685860379998173, 0.0572570851072669, 0.12233142288667814, 1.9072746506759097, 10.45974954536983, 20.20789933204651, 38.67135960715157, 52.68986790520804, 73.33557496752057, 75.04286548069545, 80.68954140799386, 90.28295394352504, 92.85970728737968, 94.18130329677037, 103.02258028302873, 93.65754808698381, 112.03249699728829, 110.21263177054269, 114.89864976065499, 122.20038659232003, 126.9571511404855, 139.1003371647426, 124.64127486092704, 132.2025408063616, 122.46151379176548, 124.70204380580357, 128.20631217956543, 118.77399362836564, 101.23996434892926, 87.68902465275356, 77.96641036442348, 73.63665430886405, 56.63158096585955, 24.205458538872854, 34.230616501399446, 54.42311341421944, 50.19762202671596, 38.106874057224815, 21.860203538622173, 6.6133783629962375, 1.2617284847157342, 0.06326572304325444, 0.07955259231052228, 0.30561963628445354, 0.02797716250643134, 0.010664109107373016, 0.07919643606458392, 0.08175432309508324, 0.03749967885336705, 0.07720741922301905, 0.020349735094766532, 0.06829270401171275, 0.03566813641893012, 0.04237148564841066, 0.04479051388001867, 0.041311790368386676, 0.005367631841051791, 0.02346132875287107, 0.02317691740712949, 0.020799344272485802, 0.058252855603184016, 0.032343162157173665, 0.0416630000940391, 0.031586836491312296, 0.05568368114264948, 0.010009612888097763, 0.06550628638693265, 0.05404672898086054, 0.05705123793865953, 0.012467249762266874, 0.07080747692712716, 0.03106588783806988, 0.03154554085007735, 0.059940202560807974, 0.051508075025464804, 0.04159428146002548, 0.0829914484971336, 0.012549609494661646, 0.016264801612123847, 0.006837353958482189, 0.03704596284244742, 0.011922980708602284, 0.009631240557480072, 0.03992069519257971, 0.0493385000154376, 0.016502383863553405, 0.046508567939911566, 0.07475024714533772, 0.02429214060040457, 0.06794205068477563, 0.03084449882486037, 0.004533690250744777, 0.07581103486674172, 0.013775198105057436, 0.030924040092421428, 0.07699289359152317, 0.09004716096179825, 0.05240913899615407, 0.056222543120384216, 0.06685674070779767, 0.06859531705932957, 0.04423376571919237, 0.051377837013985427, 0.0533452085884554, 0.025372563428910713, 0.07358250873429434, 0.03111528858010258, 0.054018973505922725, 0.050651288857417445, 0.027402148182903017, 0.041991339796887975, 0.04751054024589913, 0.026931590932820524, 0.04612867993169597, 0.08734148221888713, 0.07784925228250877, 0.1262675231056554, 0.07436343468725681, 0.11123901060117142, 0.06255611112075192, 0.15236205288342067, 0.12944207633180277, 0.16863613176558698, 0.1457047015428543, 0.12246471430574145, 0.11384360119700432, 0.11956245718257767, 0.11781365530831472, 0.21401903725096158, 0.158271495785032, 0.07724392440702234, 0.13602842576801777, 0.13937061785587243, 0.1675344215972083, 0.23321837559342384, 0.16558717537139142, 0.17200235756380217, 0.17509172750370844, 0.10795992227005106, 0.21164283475705556, 0.1461320836097002, 0.08187588942902428, 0.11774244984345776, 0.07757949390049491, 0.1479433107056788, 0.2524065316787788, 0.1185355894267559, 0.1399718677358968, 0.1518441813864878, 0.12153775404606547, 0.1993950062564441, 0.09574049045997006, 0.1027124784886837, 0.11532747585858617, 0.07981115486472845, 0.10212621744722128, 0.11332256094153438, 0.1012416249141097, 0.13925233563142164, 0.14582189811127527, 0.14449517216001237, 0.15190641661839827, 0.12039040561233248, 0.10526896773704461, 0.13505171532077448, 0.1258133389055729, 0.09320878809584038, 0.11144875934613602, 0.09734779742679425, 0.14521275008363382, 0.1273400155561311, 0.1925244049302169, 0.14511405037982122, 0.15406459224011215, 0.11293487995862961, 0.09526592985327755, 0.12997658550739288, 0.1581709911780698, 0.6184128533516611, 6.006551359380994, 18.466456685747417, 31.01474700655256, 57.54498767852783, 72.50573771340507, 94.96757534572056, 99.27673694065639, 103.05117906842912, 114.10555458068848, 116.04894488198417, 117.9836916242327, 123.91941261291504, 115.33612224033901, 133.0208579472133, 132.47395133972168, 134.67607171194894, 139.76191684177942, 143.362487248012, 154.38509559631348, 138.97325461251395, 148.48588044302804, 141.43571008954729, 144.36705780029297, 147.28455080304826, 140.22212382725306, 119.64097595214844, 105.22172682625907, 95.32769353049142, 90.18274702344621, 74.13107422419957, 38.58020271573748, 48.53541142599923, 70.04870877947126, 66.75777789524624, 51.28151668821062, 34.787222794124055, 10.933475119726998, 2.7558270948273793, 0.2709910087287426, 0.14915921831769602, 0.4955338527049337, 0.2590695284307003, 0.23128172808459826, 0.28081220601286205, 0.16267579873757704, 0.1572711994605405, 0.23921526808823856, 0.07996411701398236, 0.11316155815230948, 0.07517872843891382, 0.15578325358884676, 0.1787833786968674, 0.17784701394183294, 0.07784358651510306, 0.07549611319388662, 0.08081032482108899, 0.1034025689586997, 0.10963786473231656, 0.18778691414211476, 0.11688299024743692, 0.18590668003473962, 0.16566327985908302, 0.17158847834382737, 0.13036576605268888, 0.11109849278415952, 0.13690311168985708, 0.13344391302338668, 0.16806397746716226, 0.09598166894699846, 0.09790963799293552, 0.17551814605082783, 0.12159111403993197, 0.18974691682628222, 0.16030357245888027, 0.07593865373304912, 0.12957250433308737, 0.13802580216101237, 0.11474966257810593, 0.11286172031291894, 0.14660548392151082, 0.14521182727600845, 0.20855282699423178, 0.09555037173309497, 0.23122280410357884, 0.1722229357276644, 0.22711940429040364, 0.15578511277479784, 0.09009716899267264, 0.1452836434223822, 0.14543670735188893, 0.0880757656746677, 0.23754908463784627, 0.17070487647184304, 0.2681202356304441, 0.20186362521989004, 0.15348486549087934, 0.14814700691827706, 0.14912595653108188, 0.11078380181321076, 0.16178524866700172, 0.1575787386723927, 0.15943341915096554, 0.11684425946857248, 0.11822631316525595, 0.1280020757445267, 0.1319006122648716, 0.14422594303531305, 0.1841417561684336, 0.13528656986142906, 0.20600122319800512, 0.1989937884999173], [0.03938737006059714, 0.04517757400338139, 0.011992128516015197, 0.015724562208301256, 0.027249179248298918, 0.021211885082136308, 0.049244020799441, 0.030815328604408672, 0.020505263802728484, 0.1190782410225698, 0.04969701077789068, 0.0624635996563094, 0.007905172150848168, 0.029017845235232795, 0.04103210501904998, 0.04138889569523079, 0.037505843344011476, 0.05290747886257512, 0.050437105886105976, 0.053610600597624264, 0.02766442232366119, 0.053610044198908975, 0.07850525993853807, 0.016242818773857186, 0.05817768070846796, 0.019528110611385534, 0.03584138337256653, 0.032785543240606785, 0.01844713308050164, 0.027009771737669195, 0.033122931207929335, 0.03711708349042705, 0.05216752624671374, 0.024595785021249737, 0.04472391566793833, 0.04958085236804826, 0.0043701192064742956, 0.024153402241479074, 0.029204958051975285, 0.028746926558337042, 0.032231068172092946, 0.026440373987757733, 0.014090635464526713, 0.04222681519708463, 0.022536198841407895, 0.041540412564894984, 0.058101956200386794, 0.042725836991199424, 0.014363234363762396, 0.044491011915462356, 0.06570439825632743, 0.023864030804751173, 0.0907387917063066, 0.06443220616451331, 0.020184269241456474, 0.07409321490143027, 0.02427684811742178, 0.12891579100063869, 0.04868801224178501, 0.0571538188627788, 0.06192774698138237, 0.6655307593090194, 3.3342392231736864, 21.41147150312151, 41.070100103105815, 64.34393896375383, 75.70972578866142, 88.88304478781563, 96.98081588745117, 96.98131615774972, 88.88540022713798, 81.75582586015973, 79.3059744153704, 75.29164573124477, 78.37504087175641, 77.71299566541398, 83.49354948316301, 86.41123008728027, 82.29772281646729, 86.77337714603969, 84.35608495984758, 94.30993529728481, 81.96646744864327, 74.17560522896903, 78.01636791229248, 78.06898662022182, 76.32563495635986, 94.77702099936349, 81.52343641008649, 88.47843728746686, 92.28965623038155, 93.43701226370675, 99.30575956617082, 104.82362978799003, 107.6486075265067, 98.75158514295305, 110.07332733699253, 122.23996353149414, 98.2106887272426, 102.98353835514614, 93.2441372190203, 87.99441187722343, 60.62794508252825, 46.747111865452354, 34.03633792059762, 15.988426821572439, 6.090010949543544, 0.7895889995353562, 0.09712368409548487, 0.2191070592296975, 0.06811412716550486, 0.13487370844398225, 0.012825168502916182, 0.052769624295511415, 0.045405307319015265, 0.035600754498903237, 0.042787933123431036, 0.03048656481717314, 0.024510786635801196, 0.0738660820892879, 0.029781047853508165, 0.030021717439272573, 0.0393147498502263, 0.05053452315873333, 0.05772802233695984, 0.04254221862980297, 0.01924571451464934, 0.046043052205017636, 0.039874968717672994, 0.07184207319681134, 0.0035253810638096184, 0.03228821099868842, 0.012929075962996908, 0.03442222398838826, 0.06079241540282965, 0.03489728331831949, 0.02517309788215373, 0.02364859763266785, 0.048229950214070935, 0.0018221606275931532, 0.008688175269136471, 0.005740191671065986, 0.036417805656258545, 0.03941283547984702, 0.02373454427080495, 0.03905220090278557, 0.003731362031040979, 0.02200919426312404, 0.06304315677178757, 0.05832608310239656, 0.0531597072923822, 0.12341314341340746, 0.007280895336797195, 0.04643926576578191, 0.009373787408029395, 0.024353634532807127, 0.03362315061635204, 0.031127298649932657, 0.03943532213036503, 0.07322585037244217, 0.06663079533193793, 0.07764077918337924, 0.035981897796903334, 0.039443291524159055, 0.04488857576091375, 0.0237276910671166, 0.055694615734475, 0.02964068270687546, 0.0766190140108977, 0.011532788297959735, 0.008777151566131838, 0.06020147925508874, 0.004976351229873086, 0.030093574297747443, 0.09293976253164665, 0.014913975793336118, 0.050914187250392776, 0.009895093140325375, 0.0354352564151798, 0.04643906559795141, 0.03167497819023473, 0.03299314442223736, 0.0051924510626122355, 0.019594006539721574, 0.05836725660732814, 0.02877491952053138, 0.022347594943961928, 0.04992033700857844, 0.023271690089521662, 0.035731260531714985, 0.04146937673379268, 0.009704707240286683, 0.02615130619545068, 0.05203721020370722, 0.01059937008124377, 0.06793316187603132, 0.06310965998896531, 0.058958450598376136, 0.0714412150638444, 0.05187681470332401, 0.0343277719137924, 0.015658036938735416, 0.034047106081353765, 0.04634604183956981, 0.02844818285666406, 0.03301221804161157, 0.0034185656570895973, 0.06401577565286841, 0.0378009246529213, 0.047060271192874224, 0.052732379508337805, 0.057423869014850686, 0.055993842892348766, 0.04250030891437616, 0.039456170118813, 0.02325972242813025, 0.09358644033116953, 0.008234096241981854, 0.0559435227353658, 0.03792794980108738, 0.019803453336602876, 0.021615269061710154, 0.04491852968931198, 0.053139585336404185, 0.07071775424161128, 0.09116924753678696, 0.03856014087796211, 0.006422110883119915, 0.03295657138473221, 0.11340996303728648, 0.021064525935798883, 0.08573612943291664, 0.07198176998645067, 0.07625831836568457, 0.0403361316504223, 0.028586629445531538, 0.08151339566601173, 0.854762613773346, 3.5790794108595168, 23.62212426321847, 43.467120919908794, 71.98085689544678, 86.6637693132673, 103.34933321816581, 112.0855325971331, 111.1964133126395, 107.30562359946114, 102.24443762642997, 95.38508565085274, 93.68067864009312, 95.81870188031877, 90.58838285718645, 102.69979476928711, 105.5868616104126, 99.37675625937325, 107.6286175591605, 106.57258864811489, 109.33172525678361, 101.92760671888078, 97.39692960466657, 97.99780287061418, 96.39968245370048, 96.75776481628418, 111.196031161717, 96.01913656507219, 106.42625958578927, 109.27240153721401, 112.31952013288225, 115.66916329520089, 121.7059805733817, 125.85946083068848, 115.5240432194301, 129.85796846662248, 147.55947712489535, 116.67658260890416, 122.0063373020717, 114.1298941203526, 99.91687447684151, 72.77601569039481, 55.1197259085519, 34.806208746773855, 17.264409644263132, 5.978963536875589, 1.1521162007536208, 0.09517719104353871, 0.10803483253610985, 0.0943279569702489, 0.0422590116837195, 0.04991697486756103, 0.03178402555308171, 0.09373176896146365, 0.017687838823933686, 0.04342791038964476, 0.028605187378291572, 0.0677381916237729, 0.0466061955583947, 0.006925493536982685, 0.01948077091947198, 0.017605646180787256, 0.05447102032069649, 0.021288486596729075, 0.02484228152648679, 0.027925480190398436, 0.05405215386833463, 0.04286738278876458, 0.07367252997521843, 0.017558912081377845, 0.0077440870892522586, 0.010766301570194108, 0.03820447317723717, 0.05679326910259468, 0.02671276847831905, 0.0066677732143684155, 0.023916808954839195, 0.03455681140933718, 0.034208203865481276, 0.027952189025069987, 0.05432665181745376, 0.04422017127009375, 0.06418874101447207, 0.025741981641788567, 0.0028439923813233948, 0.0624313692429236, 0.03375176692913685, 0.08104664499738387, 0.03373599098995328, 0.02793933417914169, 0.035819802566298416, 0.027255118126049638, 0.029046170679586272, 0.007799138331652752, 0.028949031606316566, 0.05622365931048989, 0.035575533352260075, 0.02986754410501037, 0.01857837532380862, 0.07159210768129144, 0.08581767577145781, 0.05789011078221457, 0.06810368451156787, 0.05093825488750424, 0.04340354758980019, 0.019104424864053726, 0.035373211173074584, 0.03245335963687726, 0.0077756762870454365, 0.05527293675446084, 0.04928134361814175, 0.007579611048900655, 0.06729428722922291, 0.01849494096157806, 0.02204374865894871, 0.13937842100858688, 0.2116871430937733, 0.07433054609490292, 0.09775820254747357, 0.1313365325331688, 0.1753475216350385, 0.13191513291427068, 0.0963118847991739, 0.17592804905559334, 0.21696936179484638, 0.09240516514650413, 0.2551513686776161, 0.23689193704298564, 0.09943926627082483, 0.12261737111423697, 0.16665688582829066, 0.12505172405924114, 0.12964129421327794, 0.21209989594561712, 0.15550799907318183, 0.1670940795115062, 0.1556276519383703, 0.1763452530971595, 0.08206448145210743, 0.11075023468583822, 0.21445133191134247, 0.0798336211591959, 0.19792190673095839, 0.13978338427841663, 0.09631067022149052, 0.11103276988225323, 0.1320790805454765, 0.14075565710663795, 0.12691095072243894, 0.09997211303561926, 0.18218026070722512, 0.12338456351842199, 0.0898670574117984, 0.15534985970173562, 0.2748967377202851, 0.12147338821419648, 0.1290603732424123, 0.12875932082533836, 0.07487120279776198, 0.12304510601929255, 0.159707710146904, 0.13668474555015564, 0.19479323604277202, 0.1899776051619223, 0.18103777058422565, 0.1425410048770053, 0.1380773572517293, 0.1769119519740343, 0.18282970014427388, 0.1611466250781502, 0.17998419569006988, 0.293833320162126, 0.22749216428824834, 0.08410989812442235, 0.11313653378082172, 0.31143573990889956, 2.0747776968138556, 8.392042074884687, 34.7631333896092, 65.10546847752163, 93.25444139753068, 103.0767136982509, 119.706942149571, 123.57890919276646, 123.21476800101144, 115.61085401262555, 108.68541077205113, 105.82651887621198, 100.96146665300641, 104.31782872336251, 101.96728788103376, 107.03169087001255, 112.47424956730434, 107.13363483973912, 111.39105319976807, 111.34464618137905, 121.45698492867606, 107.11217880249023, 99.82507487705776, 104.23731299809047, 100.63588101523263, 101.5072546005249, 125.52108355930874, 107.62320491245815, 115.92098685673305, 119.07382229396275, 122.9510977608817, 128.6612663269043, 135.5461529323033, 139.74198940822055, 133.2560544695173, 145.91080856323242, 155.52050072806222, 129.0783805847168, 137.42591857910156, 128.9920700618199, 121.0615907396589, 93.96146924155099, 70.62160859789167, 49.654661996024, 27.753533567701066, 11.502336297716413, 1.9434884446007865, 0.22153434183980736, 0.2608804569712707, 0.2660390873040472, 0.1742460150271654, 0.09380876233002969, 0.14073458180895873, 0.17638014336781843, 0.10552834453327314, 0.20712466005768093, 0.07900830544531345, 0.15266700009150164, 0.1960864287934133, 0.11717387820993151, 0.11865870282053947, 0.09851430768945388, 0.17576700555426733, 0.13589729209031376, 0.0975497430190444, 0.09818985938493695, 0.1765661026750292, 0.1030860934406519, 0.141580375709704, 0.10719473832952124, 0.12430505055402007, 0.07782904550965343, 0.08557528270674603, 0.12296940865261213, 0.20259858721068927, 0.09793947317770549, 0.09241728378193718, 0.09401807681258235, 0.1277720523732049, 0.08804995420255832, 0.06566934513726405, 0.15823451562651566, 0.12378982534365994, 0.094318464265338, 0.152462489636881, 0.107199678064457, 0.12180334622306482, 0.1287538246916873, 0.13586880719023092, 0.1504257039300033, 0.21965892533106463, 0.07896800725055592, 0.09872942364641599, 0.09706657858831541, 0.141590309462377, 0.16818584235651152, 0.0762155842302101, 0.13617135238434586, 0.10261953276182924, 0.13987829775682517, 0.1799872490976538, 0.1257449561463935, 0.13026380938078674, 0.10531409710113492, 0.11384000496140548, 0.17661495719637188, 0.18684502611202852, 0.1312839189278228, 0.10581448953598738, 0.1589236900742565, 0.11331999607916389, 0.1344134852822338, 0.09593518929822104, 0.19253049817468437, 0.07698572147637606], [0.04901249447305288, 0.02863758403275694, 0.02552399378536003, 0.029284166837377206, 0.049382017858858616, 0.022839456497292434, 0.07133759598114661, 0.04410835887704577, 0.05418362681354795, 0.038460511581173966, 0.01923990455855216, 0.014133276301436126, 0.013341929746924766, 0.009445129428058863, 0.015712241708700145, 0.04341601567076785, 0.0036340448423288763, 0.08148636961621897, 0.037709922928895266, 0.007801249423729522, 0.023974898337785686, 0.017182956183595315, 0.05057418353057333, 0.04575215406449778, 0.01991972540106092, 0.03530595478202615, 0.03302938497758337, 0.015366653645677226, 0.06043792835303715, 0.03493052814155817, 0.04216951970010996, 0.013277429904389595, 0.02545721236882465, 0.038134533180189986, 0.016866465398509587, 0.02302397900660123, 0.0432366177971874, 0.038397390861064196, 0.03259238128417304, 0.009801727569928127, 0.04876946358542357, 0.0659770132707698, 0.011454048549889453, 0.11775878896670681, 0.03437148992504392, 0.0301952052728406, 0.0747007548010775, 0.07272807708276169, 0.016255045974893228, 0.023869357304647565, 0.050623146617519, 0.020167670578562787, 0.1246524876249688, 0.04265237879008055, 0.06876983626612596, 0.012253110047562845, 0.052140805537679365, 0.08531011800680842, 0.22283651839409555, 0.8288058808871678, 21.954645190920147, 43.871707575661794, 61.96443802969796, 72.72163908822196, 81.47342327662876, 82.05328519003731, 74.72490896497453, 68.58566134316581, 70.60731615339006, 64.38546139853341, 74.53245081220354, 48.00835929598127, 66.20224857330322, 45.16870696204049, 50.462219851357595, 51.60041121074131, 24.542248146874563, 34.76791375023978, 38.1802122933524, 38.489817074366975, 33.944343771253315, 36.412340436662944, 41.194035121372764, 35.60184696742466, 32.179987703050884, 36.3096147945949, 36.215550082070486, 59.37457343510219, 68.83761692047119, 71.85843658447266, 63.61970043182373, 51.46390342712402, 63.793815340314595, 75.4260447365897, 66.90630258832658, 68.48045172010148, 63.74381610325405, 56.24202673775809, 92.5770754132952, 87.80077253069196, 87.3940875189645, 88.18587643759591, 94.84405721936906, 91.66341509137834, 96.47481332506452, 95.98319353376115, 77.83465167454311, 58.44707924979073, 27.984882525035314, 12.094601614134652, 1.7000878368105208, 0.16773871492062295, 0.04918393652353968, 0.04277581109532288, 0.030966414604336023, 0.07286388586674418, 0.042554930983377356, 0.08931056370160409, 0.02892102507342185, 0.05212078536195414, 0.025791268729205643, 0.07408939474927527, 0.03749022346788219, 0.026219670294917057, 0.009665375957930726, 0.01873504905961454, 0.0311435936684055, 0.01188368335299726, 0.01628505079341786, 0.006452001622944538, 0.03266532040600266, 0.06686454386051212, 0.04486744278775794, 0.03147338204351919, 0.043435435343001566, 0.09864524459200245, 0.032813210505992174, 0.010598589765972324, 0.04657370390902672, 0.03221111924254468, 0.0483728462963232, 0.03170511871576309, 0.02363679281968091, 0.03682305730347123, 0.01717352963584874, 0.07419297311987195, 0.012544295717296856, 0.05258974805474281, 0.04906064671065126, 0.044688621668943336, 0.08816780894994736, 0.018685086829853908, 0.011637580398071026, 0.07055944523641042, 0.05012436231066074, 0.01774563134780952, 0.023488495598680208, 0.017400100960263183, 0.04089277124564562, 0.0221470980239766, 0.04395077590431486, 0.04754475198153939, 0.02698798567455794, 0.03858447992908103, 0.011303878572237278, 0.021076027104364972, 0.036439786798187664, 0.03042206327830042, 0.07092581343437944, 0.04449455726093479, 0.036938537178295, 0.045681711951536794, 0.021403747644009333, 0.023665752694276825, 0.04820543135117207, 0.01714292261749506, 0.022920924804306457, 0.014972994769258159, 0.03700532538018056, 0.035791103927684684, 0.03431164313639913, 0.038933565840125084, 0.033919012240533314, 0.007449076178350619, 0.042212169018707106, 0.009082338805975658, 0.033925152982452085, 0.026740837775702988, 0.02204871892796031, 0.006352571221733732, 0.03811994467728904, 0.04303360351228288, 0.013488880075913454, 0.06282643268683127, 0.0682586415537766, 0.017902391596830318, 0.004680388673607792, 0.021431389464331523, 0.03559301241434046, 0.029724380001425743, 0.039035637862980366, 0.03216701785900763, 0.08467713982931205, 0.009096695758801485, 0.15308093359427793, 0.08255757285015923, 0.028188392154074142, 0.018123636421348368, 0.06687006713556391, 0.005706112673838756, 0.03570032272753971, 0.07118701548980814, 0.05366099539345928, 0.05996621759342296, 0.05067220809204238, 0.047331905724214654, 0.019010259470503246, 0.03393062197470239, 0.03846363962760993, 0.023110358210812722, 0.03125049007524337, 0.031655470308448584, 0.0300505212508142, 0.06268033731196608, 0.06562554570181028, 0.03748181302632604, 0.030355441317494427, 0.05687892736334886, 0.03206980414688587, 0.030042249908936874, 0.02482463452698929, 0.07166414774422135, 0.04454508097842336, 0.14412769116461277, 0.1767040624150208, 1.28708039862769, 24.112922430038452, 50.010420186179026, 74.19068976811, 84.55377510615757, 99.79516288212368, 95.82292638506208, 86.41992923191616, 84.40899549211774, 83.58747523171562, 82.14254869733537, 87.16017641339982, 67.33021913255963, 90.97867706843785, 67.1168885912214, 76.28020068577358, 72.52966036115373, 54.15438488551548, 58.130418573107036, 64.09235164097377, 66.89510904039655, 64.21646731240409, 77.08533709389823, 76.86578096662248, 73.73171261378697, 68.83989592960903, 72.17567743573869, 63.605248178754536, 97.30210753849575, 105.37813772474016, 95.41250324249268, 93.24009336744035, 81.17477580479213, 91.0090684890747, 102.27244581495012, 90.9450547354562, 104.79002829960415, 103.51804937635148, 83.48453766959054, 111.26784079415458, 106.59203665597099, 99.38868631635393, 109.34060505458287, 106.76479666573661, 108.45587008340019, 116.96477999005998, 112.66092681884766, 93.28676441737584, 66.51102651868547, 34.165341649736675, 14.881563152585711, 2.7973193483693257, 0.06786973242248807, 0.03885653515213302, 0.020005373483789817, 0.019109976976843815, 0.025614488304459622, 0.033787108425583155, 0.0551030722978924, 0.05641659056501729, 0.04031055088021925, 0.010385503476884748, 0.058023442913378985, 0.04024965236229556, 0.020742476252572875, 0.08823038344936711, 0.0257960591864373, 0.02865730904574905, 0.04827669109883053, 0.04819503280201128, 0.008829744815427278, 0.01927919852148209, 0.0345380261673459, 0.06304393708705902, 0.03136557300708123, 0.027725381909736564, 0.037516733831060786, 0.03887855700616326, 0.058174695154385905, 0.02464283294310527, 0.07284515151487929, 0.02760053825165544, 0.05213269025885633, 0.08611741861594574, 0.11209354403295688, 0.0524819695523807, 0.014216600401726152, 0.03264002462050744, 0.04812743375077844, 0.03219538740813732, 0.03664954232850245, 0.006741577044262418, 0.08041088482631104, 0.0038073986652307212, 0.026477467800889696, 0.06707024853676558, 0.02154090501634138, 0.02000226579340441, 0.03175813265677009, 0.04676347319036722, 0.07363162788429431, 0.055609272992504497, 0.05202348683295505, 0.028475319168397357, 0.06303783027189118, 0.057650845763938766, 0.04986836122614997, 0.03509507288358041, 0.003252927625518558, 0.053950278620634756, 0.026775880716741085, 0.044330799619534185, 0.09626121858933143, 0.01272842806896993, 0.029384810544018234, 0.05428732732044799, 0.03787064412608743, 0.1023534791810172, 0.10318656412086316, 0.10988841378795249, 0.10052149569881813, 0.10281487620834794, 0.11767052513148103, 0.20363654222871574, 0.09011747076043061, 0.1411230159657342, 0.1360351432647024, 0.06837450140821082, 0.0968251151165792, 0.11460098198481969, 0.10573850039924894, 0.09294178456600223, 0.1205500920436212, 0.05570528230496815, 0.15256735043866293, 0.15083062648773193, 0.11766650820417063, 0.1114104153322322, 0.11372875914509807, 0.12387616213943277, 0.10770349710115365, 0.13328734785318375, 0.11691195012203284, 0.20916391563202652, 0.1235915438405105, 0.20029881490128382, 0.21689603930073126, 0.13145889953843184, 0.15213373942034586, 0.12419229160462107, 0.11693382609103407, 0.09701627200203282, 0.22902008944324084, 0.12119300397379057, 0.07842509781143495, 0.11801132612994739, 0.1181069588554757, 0.09577880054712296, 0.18163663202098437, 0.06763128164623465, 0.22006344076778206, 0.11169003282806703, 0.23704946573291505, 0.11522351072302886, 0.22037681538079465, 0.177218853362969, 0.11166988712336336, 0.11231182196310588, 0.21592884191444942, 0.14768485671707562, 0.14781707605080946, 0.10907051446182386, 0.30012298694678713, 0.16175630236310617, 0.3453300568674292, 0.2562876705612455, 1.8651828978742873, 33.218187536512104, 67.15203952789307, 92.46295125143868, 98.88150256020683, 108.64982904706682, 105.4224602835519, 94.97588539123535, 91.22584533691406, 89.86282416752407, 84.88841424669538, 96.11108902522496, 67.04318904876709, 88.58957372392926, 66.02884238106864, 70.33937277112688, 72.79514408111572, 41.549452849796836, 52.56932708195278, 58.028742109026226, 58.10257714135306, 49.13062538419451, 53.696978024074006, 62.665330614362446, 54.94727161952427, 51.096920422145296, 54.662715094430105, 53.16603490284511, 85.56960868835449, 96.86792850494385, 96.2848287309919, 88.73759814671108, 75.90492847987584, 88.30451692853654, 101.38448687962124, 92.72861562456403, 92.72453008379254, 82.61319882529122, 73.66331454685756, 119.81894711085728, 110.41155174800328, 110.68465069362095, 111.4265307017735, 118.00181252615792, 119.98720468793596, 126.0103896004813, 130.0268096923828, 110.39503587995256, 86.1275976725987, 47.54753392083304, 21.218196937016078, 4.341449873788016, 0.18433953555566923, 0.18053040280938148, 0.11951247629310403, 0.13407618552446365, 0.17007512812103542, 0.10100043285638094, 0.24612517016274588, 0.12250265798398427, 0.12885614777249949, 0.20819411267127308, 0.202540178916284, 0.15619327872991562, 0.18136439020080225, 0.18981790515993321, 0.11100929935595819, 0.16079867232058728, 0.17714181249695166, 0.1430456042289734, 0.10949139616319112, 0.11744523793458939, 0.167512979890619, 0.23808206032429421, 0.13383356854319572, 0.1462972390332392, 0.23647499084472656, 0.15412091064665998, 0.18221979215741158, 0.11849791716252055, 0.2021105441131762, 0.12320860581738607, 0.13578343391418457, 0.2959086602287633, 0.1529020174805607, 0.1398908777960709, 0.15495590226990835, 0.14561292289623193, 0.21687398691262516, 0.1232643678252186, 0.16557711948241505, 0.11936633342078753, 0.1808283068239689, 0.10663285026592867, 0.15943948525403226, 0.1771991622767278, 0.10687780140766076, 0.1246285353388105, 0.2012481532458748, 0.0955766106822661, 0.10584351726408515, 0.14801875022905214, 0.13900743877249105, 0.11121619825384446, 0.16315773501992226, 0.11481055431067944, 0.09962933071489845, 0.17889153717883996, 0.11918996859874044, 0.25735297054052353, 0.11514036304184369, 0.17199363160346234, 0.15907596690314157, 0.16163968933480127, 0.09160762187093496, 0.1364287342876196, 0.11648606083222798], [0.05015655201194542, 0.009489207911039037, 0.04491402082411306, 0.06488981696644, 0.050501067989638875, 0.025246914010494947, 0.022406378128964986, 0.042779227519141774, 0.014940135014642562, 0.06437105658863272, 0.0186655874297555, 0.02959550923800894, 0.03494764758007867, 0.029337326663413217, 0.036351468680160384, 0.03637819956722004, 0.031270265978361876, 0.019200469799605862, 0.03974586385967476, 0.033629162436617274, 0.04075609393683927, 0.03545585334567087, 0.050881987371082814, 0.07351743722600595, 0.034671738278120756, 0.0886743828388197, 0.03737485555133649, 0.00877720584893333, 0.049898478002952676, 0.031054044009319375, 0.03889519129214542, 0.04065181328249829, 0.057800734149558206, 0.029318371787667274, 0.04606919955196125, 0.04384952490883214, 0.0408488055691123, 0.034559990345899544, 0.04968317544886044, 0.029173365461507013, 0.03690853235977037, 0.0028091383698795524, 0.07504069406007018, 0.08254113873200757, 0.036842918023467064, 0.04379959830215999, 0.05436842582587685, 0.07550817754651819, 0.062329555063375404, 0.06898752387080874, 0.054519834129938056, 0.0939973679238132, 0.03965875692665577, 0.11387237108179502, 0.003246625519490668, 0.03645469421254737, 0.021958802859964113, 0.2935103646346501, 5.851798040526254, 44.21479572568621, 46.17985051018851, 79.37676961081368, 70.08607619149345, 66.57872976575578, 63.20364230019705, 53.024819714682444, 53.254773821149556, 48.814197472163606, 43.278922012874055, 29.46079628808158, 40.457710197993684, 36.08404500143868, 16.055060046059744, 21.446448734828405, 24.795527356011526, 29.804457664489746, 34.2155111176627, 28.31321096420288, 24.43549254962376, 28.07952914919172, 34.76740653174264, 30.992933137076243, 26.38436324255807, 26.054434980664933, 27.388483898980276, 20.106646708079747, 31.15290151323591, 18.614889315196447, 18.812273740768433, 28.451341152191162, 17.26836143221174, 17.959783622196742, 18.117679698126658, 32.66282149723598, 47.35319628034319, 27.25486135482788, 27.456861121313914, 34.79186419078282, 29.36737080982753, 37.37729236057827, 51.17916624886649, 48.14433554240635, 65.98699338095528, 77.06231771196637, 94.14963340759277, 85.76352596282959, 92.54351561410087, 85.34819044385637, 89.50383853912354, 90.6232350213187, 57.748736654009136, 22.081632205418178, 2.8175876779215674, 0.10351384870175805, 0.017547068252627338, 0.030522357539406846, 0.016645179861890416, 0.054894544915961366, 0.04525249444746545, 0.08581952138670854, 0.04819829316277589, 0.0686845172728811, 0.041868843869971376, 0.12117593203272138, 0.03328706204359021, 0.02451245752828462, 0.026283981843984554, 0.031049355332340513, 0.003671399043274245, 0.019010359554418495, 0.03929500108850854, 0.01828101752991123, 0.04118245820115719, 0.015127916188378419, 0.010517035793912197, 0.05911156881068434, 0.022321298319314207, 0.017278210625850728, 0.05450072997648801, 0.020182910475081632, 0.01395573591746922, 0.012909121944436004, 0.030698600225150585, 0.04814173726897154, 0.055516646177108796, 0.040149463274117024, 0.0306972363697631, 0.04020433300840003, 0.03380640256883843, 0.022591803089848587, 0.04680264501699379, 0.02622766004476164, 0.02661821971248303, 0.08307766994195324, 0.016488747006016116, 0.0060427296557463706, 0.03232411228652511, 0.05259228916838765, 0.04092262000111597, 0.034228441172412465, 0.03669493292857494, 0.02686359324226422, 0.01758549708340849, 0.06700377246098858, 0.034759639097111564, 0.014836890822542565, 0.010950213397986122, 0.06673294877899544, 0.03533788324732866, 0.05136001868439572, 0.033174360769667795, 0.05536321244601693, 0.08781066882823195, 0.10275895135211092, 0.04027120263448783, 0.034521700614797216, 0.056866211617099385, 0.046475852373987436, 0.06725900340825319, 0.04048208114025848, 0.03004440086494599, 0.06459646592182772, 0.05223010753148368, 0.0465684961527586, 0.027653991544087018, 0.043400304192411046, 0.018716801556625536, 0.10863258117543799, 0.045541088961597, 0.04349225925813828, 0.023684804261262928, 0.06281463974820715, 0.027711239543610384, 0.033511528213109286, 0.013428118961331035, 0.004946736993068563, 0.03195244812273553, 0.025624885157282864, 0.02765662086728428, 0.03326876534681235, 0.042323659107621224, 0.028902117695127214, 0.03897719903449927, 0.04638544776077781, 0.05246656680745738, 0.009341508649023516, 0.05378891620784998, 0.02071811006005321, 0.014519382234928864, 0.09419801751417772, 0.034786149460290156, 0.08632354398391076, 0.018757033594218746, 0.021555793770988072, 0.022930488755394305, 0.00044402337672571387, 0.07996349954711539, 0.031232464792472974, 0.10970710923096963, 0.0033940906869247556, 0.01732754521071911, 0.015979867794417908, 0.03620489154543195, 0.008196145778388848, 0.04098529628078852, 0.07034621560680014, 0.019006023715649332, 0.03785436607099005, 0.027118822493191277, 0.09299825903560434, 0.03942751219230039, 0.03175238546516214, 0.16079312190413475, 0.3127908557653427, 7.659722787993295, 53.26238904680525, 57.05668912615095, 90.33116054534912, 79.5828948702131, 76.04684543609619, 74.77379649026054, 72.9760056904384, 76.84973757607597, 68.65304497310093, 69.17769650050572, 57.16626221793038, 71.92078277042934, 52.50868667875017, 34.59649126870291, 33.07339402607509, 27.325316088540212, 40.31118311200823, 27.845786537442887, 27.89800919805254, 31.141951152256556, 35.05946363721575, 40.01950468335833, 29.88990661076137, 31.795686313084193, 31.293640749795095, 35.975045136043, 27.19485671179635, 41.53308636801583, 35.11617830821446, 38.385990142822266, 49.73985038484846, 35.66542993273054, 28.706126383372716, 44.989130769457134, 54.22207423618862, 61.35569245474679, 43.2987174306597, 34.83969211578369, 51.936731815338135, 60.736969266619, 64.2229082924979, 76.74602876390729, 71.36903326851981, 98.80969292776925, 99.82417161124093, 103.87786184038434, 98.25620637621198, 99.55607536860875, 101.4739796774728, 106.9482638495309, 107.62763786315918, 67.94501658848354, 27.617546898978098, 3.811128182070596, 0.06820794820253338, 0.08967252142195191, 0.01885700724752886, 0.03108351617785437, 0.013404937660587686, 0.06254130548664502, 0.11038606494132962, 0.0349762478311147, 0.0760355553190623, 0.05955100165946143, 0.0367633801485811, 0.038587309420108795, 0.007443150023131498, 0.011714887589083185, 0.025851205423740403, 0.0267843081216727, 0.06559804467750446, 0.03077108133584261, 0.05851931630500725, 0.11256461018430335, 0.010768277803435922, 0.01429846989256995, 0.019459965339462672, 0.021041109692305326, 0.04119848859097276, 0.023289542345862304, 0.05009663736979876, 0.05244138637291534, 0.015733664755576422, 0.07571378722786903, 0.021415925651256527, 0.005000892993328827, 0.04214574722573161, 0.05725515806781394, 0.006640540211394961, 0.025956800739680017, 0.010704142673473274, 0.038331332084323676, 0.05189789339367833, 0.029495425322758298, 0.050267953891307116, 0.07646131568721362, 0.013267641188576818, 0.051912067990217886, 0.022074981625857096, 0.00602454661358414, 0.03956607922113367, 0.041439466910170655, 0.06591213853763682, 0.028579019675297395, 0.10165099866156067, 0.03468121401965618, 0.0669335780133094, 0.038092301160629304, 0.0363403135644538, 0.03194265686241644, 0.01347169023938477, 0.05001646845734545, 0.06404630294335739, 0.03216430711160813, 0.06343434578073875, 0.07787555229983159, 0.05683707532339862, 0.1794558476124491, 0.12534354840006146, 0.2506456790225846, 0.14452767398740562, 0.14618739778442041, 0.10602635531021015, 0.13936489102031502, 0.18220889488501207, 0.09742339979857206, 0.1610464190265962, 0.07105242128350905, 0.1770998247499977, 0.17751682523105825, 0.12795185058244637, 0.06883222077574049, 0.15878438683492796, 0.11050220978047166, 0.09550098116908755, 0.1401256373418229, 0.18522727649126733, 0.15794533757226809, 0.10627305028694016, 0.1751503393586193, 0.19632801440145287, 0.10413365651454244, 0.12455395076956068, 0.09981714242271014, 0.1159105681415115, 0.11189911660871335, 0.08904300377305065, 0.12404213180499417, 0.11615022671009813, 0.12062333311353411, 0.1590575243213347, 0.14435224554368428, 0.13540105228977545, 0.10203524625727109, 0.13974264503589698, 0.10750440135598183, 0.13724813317613943, 0.16725129607532704, 0.13801877253821918, 0.2285579799541405, 0.1786060096429927, 0.10725288878061942, 0.15099966313157762, 0.1361578359667744, 0.12875272546495709, 0.17507369204291276, 0.26182022797209875, 0.2322467134467193, 0.1980904276881899, 0.1278118280959981, 0.21068155419613632, 0.17193052784672805, 0.23707280733755656, 0.37295620303068844, 0.4243549049964973, 10.196117520332336, 70.10913726261684, 69.48341723850795, 101.55330726078579, 91.08442865099225, 85.63474110194615, 85.24952602386475, 75.52538313184465, 75.27066911969865, 70.6599348613194, 62.998621804373606, 48.302438327244346, 55.957706451416016, 51.16443954195295, 26.369169269289287, 36.96241889681135, 36.02872691835676, 43.68208776201521, 50.913223947797505, 44.25847905022757, 36.706641810280935, 44.16544614519392, 47.3783209664481, 41.617899554116384, 40.78267397199358, 35.00767523901803, 38.85806117738996, 28.05732444354466, 45.96168054853167, 28.34257057734898, 27.23650595120021, 41.432573727199006, 29.845344339098247, 29.279010568346294, 31.55153008869716, 45.79108837672642, 65.07452814919608, 36.32879182270595, 37.87063183103289, 52.78772286006382, 44.7468957219805, 51.66484533037458, 72.87873785836356, 67.61417116437639, 90.23527540479387, 97.08052948543003, 116.3083906173706, 107.09812259674072, 116.93090057373047, 107.95913641793388, 121.362183707101, 120.5831377846854, 85.49443612779889, 37.03803614207676, 6.190966972282954, 0.15504327043890953, 0.17943764930324896, 0.11092770551996571, 0.18975330862615788, 0.09501499403268099, 0.2351156680711678, 0.2405930741557053, 0.10626975260674953, 0.14462492162627832, 0.16210129670798779, 0.16995379248900072, 0.08272646700165101, 0.15596117904143675, 0.15438895912042686, 0.11160574520805053, 0.15053562660302433, 0.09177289943077735, 0.16486936674586364, 0.11475325881370477, 0.18149373254605702, 0.08237376449895756, 0.16388779798788683, 0.09203298190342528, 0.15321687129991396, 0.2298938525574548, 0.11988873753164496, 0.1436330662774188, 0.13320569294903958, 0.07409606474850859, 0.13225636817514896, 0.07973916229924985, 0.17101124860346317, 0.11825057757752282, 0.13506876012044294, 0.14945868296282633, 0.15433352280940327, 0.09517263807356358, 0.19548372684844903, 0.08089075157684938, 0.09611525213611977, 0.21493273893637316, 0.18895440149520124, 0.18966185567634447, 0.1272475312330893, 0.13135612862450735, 0.13216072187892028, 0.07683904256139483, 0.0822371414729527, 0.144421659676092, 0.08325846559767212, 0.17310040364308016, 0.14968800065772875, 0.1764165535569191, 0.08116909342684916, 0.15454842842050961, 0.12832490913569927, 0.14820726082793304, 0.15688353883368628, 0.19731722346373967, 0.14137492887675762, 0.14092212888811315, 0.15763280434267862, 0.1754851828196219], [0.02340993651055864, 0.03098346958202975, 0.042091589953218184, 0.04612261043595416, 0.008610981732739933, 0.09119585968021836, 0.0778351862515722, 0.02788460354453751, 0.02607967155719442, 0.03235063282772899, 0.1455268439437662, 0.05815133319369384, 0.02362395663346563, 0.03797142693240728, 0.01400140386873058, 0.0695798374446375, 0.03490189057109611, 0.06201649936182158, 0.03229846027014511, 0.05599998024159244, 0.029625744758439914, 0.016073853376188448, 0.03397405839392117, 0.02978011147518243, 0.019660265484292592, 0.06426335272512265, 0.030904562744711126, 0.017585390214143053, 0.04388112767732569, 0.013755526526698043, 0.0403513919029917, 0.05809244313942535, 0.041660214707787545, 0.0285071763875229, 0.02594467022988413, 0.024221883388236165, 0.03912017993362887, 0.058887828673635206, 0.027024490858561227, 0.03076483542099595, 0.018974524423746125, 0.1240078793572528, 0.042632769128041606, 0.038095649730946333, 0.02796949166804552, 0.07668157493961708, 0.03175845496090395, 0.04473644481705768, 0.009508909175305493, 0.04598998737388423, 0.045220681333116124, 0.015868087631783316, 0.03168716807184475, 0.1395122552556651, 0.03554190854941096, 0.07479933236858674, 1.9609694608620234, 19.30115941592625, 68.55319241115025, 67.83646488189697, 28.356388807296753, 53.70568411690848, 69.63511031014579, 41.9177942276001, 36.214084012167795, 21.33921892302377, 18.117820399148123, 24.666810240064347, 18.67267574582781, 28.243020262037003, 37.238585472106934, 49.28302369798933, 69.36151804242814, 66.90193217141288, 75.90942396436418, 74.09652778080532, 101.11455631256104, 77.23370892660958, 100.30761337280273, 102.26786000388009, 118.29295594351632, 133.44872801644462, 114.58114487784249, 131.074097769601, 128.29420689174106, 132.04238482883997, 100.87157780783517, 115.03056825910295, 97.22728933606828, 75.55358586992536, 85.55230072566441, 87.75903470175606, 82.28759234292167, 78.84746279035295, 74.22816835130963, 88.07716492244175, 101.800934110369, 73.2331029347011, 58.43315505981445, 63.51255226135254, 36.84141949244908, 37.875638008117676, 28.085066863468715, 33.959067004067556, 41.58932508741106, 52.499702657972065, 67.48007787976945, 68.68832097734723, 75.59504577091762, 75.05446202414376, 84.9329730442592, 78.41803632463727, 60.1758952822004, 13.635204843112401, 0.2873133585921356, 0.1347102222165891, 0.02729208132119051, 0.10673955668296133, 0.018783711894814457, 0.03542528873575585, 0.037398271794830046, 0.0498427397438458, 0.03770545477579747, 0.037375055719166994, 0.04278902556481106, 0.08019779768905469, 0.03805714626131313, 0.040801878087222576, 0.03663674515805074, 0.02694055438041687, 0.04410981433466077, 0.04873549612239003, 0.02917439004938517, 0.026670002112431184, 0.05672816027488027, 0.06714355067483016, 0.061867778056434224, 0.05879649107477494, 0.02458425162227026, 0.03563176354925547, 0.026172154183898653, 0.025146458597321595, 0.010932614744108702, 0.0352297722628074, 0.028002568553867083, 0.03611150477081537, 0.02243901227068688, 0.025868623417669108, 0.05701057333499193, 0.07770446648022958, 0.06224903331271239, 0.05132818521399583, 0.01972561688827617, 0.015276028508586543, 0.009540335524694195, 0.049698208392198594, 0.06184314723525729, 0.03869988516505275, 0.04827895401311772, 0.016263045902763094, 0.040924465616366694, 0.02916665475017258, 0.01650310480701072, 0.03278559073805809, 0.00798338942695409, 0.04066846453185592, 0.02826000813261739, 0.03240405049707208, 0.06562282477638551, 0.034586633023406775, 0.014651722008628505, 0.01605629628258092, 0.03325350848691804, 0.026705723588487933, 0.035799239562558274, 0.0527604471093842, 0.023230616668505327, 0.06706173292228154, 0.02786643916208829, 0.03304917784407735, 0.019061578770301173, 0.05725953461868422, 0.04418180011478918, 0.02863839827477932, 0.08436529870544161, 0.03194813942536712, 0.05591561459004879, 0.011907398151899022, 0.025108796511111513, 0.02046280277759901, 0.03262159900207605, 0.0657464267153825, 0.012851208980594362, 0.03178850727687989, 0.024049096142074892, 0.04632247971104724, 0.007587455761885005, 0.007467949629894325, 0.05301941678460155, 0.036590516567230225, 0.03371128213724919, 0.027191076294652054, 0.026812860875257423, 0.028799295891076326, 0.04933493431391461, 0.01838283340579697, 0.04320439416915178, 0.05389027576893568, 0.018408663537619368, 0.07175612995134932, 0.033892773291362185, 0.02125515865295061, 0.030838833057454655, 0.014664839786876525, 0.046272685418703725, 0.007147526734375528, 0.01859938955333616, 0.1001657262178404, 0.027814968888248717, 0.04186816194227763, 0.046018869216953, 0.06026798247226647, 0.018007583184433833, 0.05987162981182337, 0.01774072553962469, 0.013087585136028273, 0.08847084947462593, 0.0009871210828090885, 0.02234111663087138, 0.13637177805815423, 0.08475100515144211, 0.05594766179897955, 2.8606530470507483, 27.589637722287858, 82.28314549582345, 81.93965435028076, 37.18968405042376, 71.6030763898577, 94.80097143990653, 64.73835345676967, 59.545804841177805, 43.12358113697597, 38.76332943780081, 34.21137693950108, 30.33445930480957, 30.165378366197857, 34.15498883383614, 42.286034856523784, 32.50983953475952, 39.6861127444676, 46.97537408556257, 51.045333521706716, 70.50503172193254, 56.121346950531006, 67.10694571903774, 64.56954002380371, 70.9407046181815, 82.69264452798026, 67.89204352242606, 61.75221920013428, 63.13684926714216, 61.69381264277867, 59.33162661961147, 56.92381525039673, 50.85461936678205, 48.60666172845023, 51.508948598589214, 51.266435623168945, 48.57043729509626, 55.34655679975237, 69.17550781794957, 53.441694259643555, 61.47940513065883, 62.56280299595424, 37.481025491442, 41.72727114813668, 37.4769538470677, 40.856783458164756, 39.72162846156529, 46.84948314939226, 72.21426773071289, 83.84777559552873, 100.48869732448033, 84.43437031337193, 86.97654942103794, 89.29237706320626, 101.02163110460553, 94.89425795418876, 76.19867052350725, 18.73569243294852, 0.28726998663374353, 0.17312662223620073, 0.1016947573849133, 0.07853416553033249, 0.013797577886310006, 0.11532955217574324, 0.028480774589947293, 0.07163953049374477, 0.02700942738114723, 0.026129842436473285, 0.06093328605805125, 0.015794313911880766, 0.02901433381651129, 0.06339485504265342, 0.05208093500030892, 0.040397081058472395, 0.03677364977608834, 0.06862021250916378, 0.0558332268680845, 0.04164397736479129, 0.0316258929669857, 0.027685019254152263, 0.02097033679352275, 0.05555799270847014, 0.02381962916946837, 0.07298393906759364, 0.004039331688545644, 0.046128445837114535, 0.048086484162403006, 0.16154428731117929, 0.014586630144289561, 0.012463604332879186, 0.018455494328268936, 0.03700938641226717, 0.0362496986053884, 0.07611307794494288, 0.060808537394872735, 0.02556681613038693, 0.043587081134319305, 0.030909319275191853, 0.0012893888197140768, 0.03916590301586049, 0.020432217811633433, 0.06886753173811094, 0.029957575523959737, 0.032086309511214495, 0.025717618841943995, 0.044231702972735674, 0.05093894020787307, 0.014015446150941508, 0.05033476923459342, 0.023456411070323417, 0.0033563946739637424, 0.027746601396107247, 0.03188597883230873, 0.04301233822479844, 0.10995007226509707, 0.04880409940545048, 0.007034114695021084, 0.06777266798807041, 0.08470504797462906, 0.04099547769874334, 0.1599357250545706, 0.13528488709458283, 0.11060268724603312, 0.12518441836748803, 0.09088741123144116, 0.18073551037481853, 0.24471227026411466, 0.13237684885306017, 0.09757826863122837, 0.10494557116180658, 0.23811286581414087, 0.0825142619599189, 0.07544208145035164, 0.1323662365653685, 0.13657162019184657, 0.1477242796016591, 0.11229099093803338, 0.1471190806478262, 0.2023214599383729, 0.19036084174045495, 0.13275507784315518, 0.06378904317638703, 0.10790787863412074, 0.11481451695518834, 0.05322960318465318, 0.1782411885048662, 0.16942034182803972, 0.1146678448255573, 0.09525915128844124, 0.14054235283817562, 0.16629828007093497, 0.16445096848266466, 0.13549771638853209, 0.15107977097587927, 0.07125108955161912, 0.18120664437966688, 0.09007137109126363, 0.20420199260115623, 0.21938722633889743, 0.07633844656603676, 0.0839048855538879, 0.19391586312225886, 0.1301533438797508, 0.1471701879054308, 0.09267695913357393, 0.20993212583873952, 0.17011617948966368, 0.10446559584566525, 0.13242657189922674, 0.12291899350072656, 0.16335905635995523, 0.045172288215586116, 0.1321994119456836, 0.29368854793054716, 0.14349016680249146, 0.12481957008796078, 3.9274983491216386, 36.02378674915859, 97.40738664354596, 90.44295011247907, 47.116224493299214, 77.85049356733049, 96.4732152393886, 62.10777241843087, 53.23755965914045, 35.71828835351126, 26.16189582007272, 40.43530225753784, 30.52525336401803, 42.92592920575823, 53.076760973249165, 69.01618562425885, 96.94371250697544, 97.58863735198975, 107.75849328722272, 104.73163563864571, 147.04515756879533, 111.39664649963379, 132.3332086290632, 137.03791727338518, 161.280946459089, 173.37143734523227, 153.76385716029574, 176.83466965811593, 174.56908443995883, 174.75733893258231, 138.92219924926758, 152.84919629778182, 135.38717814854212, 108.03171035221645, 117.64578683035714, 117.87727301461356, 109.93941470554897, 105.2200870513916, 100.64634500231061, 116.0401554107666, 140.3801258632115, 100.9854518345424, 80.47624560764858, 86.79839066096714, 52.33421046393258, 55.51825373513358, 40.54676178523472, 47.916625704084126, 60.439329283578054, 73.50861985342843, 89.8526520047869, 89.10188525063651, 96.6149515424456, 95.7049320765904, 110.48190225873674, 104.7516325541905, 90.05419145311627, 26.36112151827131, 0.967189678124019, 0.20983932938958916, 0.30429030475871904, 0.22644073356475147, 0.09049829853964703, 0.15227526825453552, 0.12191584732915674, 0.19944709060447557, 0.07379155180283956, 0.09946104045957327, 0.09540481918624469, 0.25284277541296823, 0.15668012760579586, 0.12348866436098303, 0.23779205445732388, 0.2005440103156226, 0.2018876046474491, 0.12341711962861673, 0.1583870095866067, 0.10309589827167136, 0.14314777803208145, 0.1597236692905426, 0.09908091835677624, 0.21359081380069256, 0.06366302565272365, 0.1738633212766477, 0.0927348585267152, 0.14779282520924295, 0.12491461927337305, 0.19839268789759704, 0.10164715815335512, 0.0899396063759923, 0.14460206856685026, 0.08890899310686759, 0.09473632648587227, 0.1328328786683934, 0.13005179432885988, 0.14295622759631701, 0.16123771161905356, 0.11553984374872275, 0.06310200611395494, 0.07838718127459288, 0.17210655340126582, 0.17137478052505425, 0.12232767737337522, 0.16100339990641388, 0.15157212955611093, 0.07770107380513634, 0.0859751637492861, 0.12835224052625044, 0.1888967395893165, 0.18007597433669226, 0.13052329474261828, 0.1510043450232063, 0.14818816685250827, 0.10364146756806544, 0.119370716757008, 0.14319247991911002, 0.10031878336199693, 0.1501080138342721, 0.16376806369849614, 0.17456397653690406], [0.03721182394240584, 0.012784607375838926, 0.01739908824674785, 0.0474685355355697, 0.03606945595570973, 0.04057634661772421, 0.03619258970554386, 0.023723933679450835, 0.05941469754491534, 0.035086706546800475, 0.07199933725808348, 0.036695526646716256, 0.02427522641872721, 0.022601328025172864, 0.062123830031071386, 0.02602171109590147, 0.018382629845291376, 0.042096685751208236, 0.01746069244109094, 0.07688805314579181, 0.05614732072821685, 0.0488888789633555, 0.04791867905961616, 0.023986837161438804, 0.04994521549503718, 0.03598992147349885, 0.03137812590492623, 0.06667602647628103, 0.04147007562486189, 0.022933233429544737, 0.1009789640083909, 0.03943269619984286, 0.031809755600988865, 0.026667552601013864, 0.03516206803864666, 0.07400626742414065, 0.05121673583718283, 0.05110796667369349, 0.04652290538485561, 0.02496034831606916, 0.03960992954671383, 0.09069099569959299, 0.04552661241697414, 0.03659972768010838, 0.018827433298741068, 0.18807298450597695, 0.05555683241358825, 0.03172150194378836, 0.03907152218744159, 0.12297168853027479, 0.017815325375912443, 0.05598909314721823, 0.12245910960648741, 0.17834090601120675, 1.8771146919046129, 20.186203581946238, 51.88006230763027, 79.23628398350307, 78.6880224772862, 63.358941486903596, 20.148643357413157, 22.797407831464493, 19.45356641496931, 18.733123336519512, 21.948400497436523, 32.42606510434832, 50.72520569392613, 48.56119271687099, 69.7784446988787, 89.13859258379254, 97.87445150102887, 76.80840969085693, 61.527993883405415, 35.172052247183665, 22.706111976078578, 21.50421953201294, 16.48659529004778, 12.007455570357186, 27.28121587208339, 24.85684868267604, 23.180350848606654, 18.258742025920323, 27.21264931133815, 34.17440904889788, 43.65567071097237, 39.58616290773664, 37.834459509168354, 41.70720822470528, 52.21810259137835, 45.549572467803955, 45.19876834324428, 39.59212098802839, 65.55366202763149, 44.904512132917134, 30.989657061440603, 34.6504579271589, 27.69005482537406, 51.48939636775425, 70.10131359100342, 69.97274412427629, 66.58945083618164, 85.75220039912632, 90.39018549237932, 70.48550033569336, 36.754532269069124, 27.469656229019165, 20.649363551821025, 33.62609543119158, 42.63222885131836, 55.861519064222065, 61.65980815887451, 71.43620150429862, 81.35535253797258, 80.9801915032523, 38.88052470343453, 4.766495500292097, 0.029044677902545248, 0.14293325240058558, 0.04086355692041772, 0.04412721536521401, 0.028999070171266794, 0.02565302570084376, 0.11132076050021819, 0.0930111308449081, 0.03934513804103647, 0.014375914486923387, 0.06414116213896445, 0.03590161692617195, 0.0457474246754178, 0.0452251596642392, 0.04604195637096252, 0.061367446689733436, 0.029398761224001646, 0.07326437759080104, 0.037746234730418236, 0.017041825988729085, 0.01178513207871999, 0.05286661069840193, 0.02797600899689964, 0.07858087588101625, 0.03411042696929403, 0.05744341082338776, 0.0443610147839146, 0.0371373411534088, 0.03596549082015242, 0.030628273463142768, 0.0455088076580848, 0.01144786031051938, 0.009998503573504942, 0.0467879818752408, 0.03011224079611046, 0.053254464707736454, 0.004195221716405025, 0.02376523780237351, 0.012302083312533796, 0.027264666810099567, 0.01840650409992252, 0.04780104144343308, 0.03447756191183414, 0.061768365890852044, 0.0163068436418793, 0.03810183457764132, 0.03180593544883387, 0.03083806292020849, 0.049680848073746474, 0.03724877356684633, 0.06261830564056124, 0.02560585394634732, 0.060104156977363994, 0.11752834490367345, 0.024111154954880476, 0.06145233820591654, 0.013240850929703032, 0.03471699317118951, 0.033323723290647776, 0.10230801054941756, 0.04611889884940215, 0.030554808476673703, 0.021968818036839366, 0.0320382115564176, 0.015250047402722495, 0.05894751939922571, 0.012186591563347195, 0.02440808866439121, 0.031657027546316385, 0.04841226918090667, 0.02499467200998749, 0.030559819457786422, 0.06315168844802038, 0.08025038415299994, 0.023339599570525543, 0.011485742072441747, 0.062247303048414845, 0.018022446494017328, 0.0307805231506271, 0.05213683610782027, 0.07586944316114698, 0.0302571080225919, 0.050590003574533124, 0.029662256727793386, 0.029317903598504405, 0.01646599911951593, 0.0442733582375305, 0.11514604916529995, 0.006225752602663955, 0.048211422815386734, 0.03229125762092216, 0.0104029613347458, 0.03632001858204603, 0.019402922596782446, 0.03910134380151119, 0.028035706507840326, 0.03969989311216133, 0.05716682637908629, 0.014005582796276679, 0.016161046822422316, 0.03805858475555267, 0.037994931385453255, 0.01915184937284461, 0.01704176322423986, 0.04977664364767926, 0.04382692290736096, 0.05597420269623399, 0.08455108159354754, 0.09629684167781047, 0.07836008737129824, 0.006711986556183547, 0.058109983269657405, 0.129145760089159, 0.17292801503624233, 3.1881568218980516, 27.96353939601353, 65.36100237710136, 91.35496371132987, 88.07318360464913, 77.56340094975063, 42.12363461085728, 32.925036089760916, 36.15038987568447, 25.718107427869523, 24.03967104639326, 23.682592698505946, 24.504449946539744, 31.55936418260847, 32.598116397857666, 51.552013533455984, 59.25491850716727, 59.978628976004465, 55.97833217893328, 36.74813992636544, 26.871058498110088, 23.337454829897197, 17.416259050369263, 13.4024566922869, 23.200544050761632, 22.501791511263164, 19.532463209969656, 19.148940018245153, 24.040060145514353, 30.431796618870326, 32.87211166109358, 34.074615546635215, 28.28249818938119, 34.66339199883597, 39.20127092088972, 35.94257967812674, 34.787017822265625, 34.34562308447701, 36.42632368632725, 32.295101983206614, 23.589895044054302, 25.34758084160941, 24.40186674254281, 32.746234621320454, 52.32342685971941, 62.64847428458077, 56.31033795220511, 68.1715487071446, 56.918152468545095, 55.169259616306846, 32.82777867998396, 32.439381326947895, 29.60410635811942, 57.44930056163243, 72.80906132289341, 72.5623446873256, 72.21081447601318, 79.3964399610247, 93.8690026147025, 94.06138433728898, 54.34281308310372, 8.915955356189183, 0.15356510904218468, 0.10016730041908366, 0.017472256374146258, 0.054027651968811236, 0.029717944096773863, 0.01197207102086395, 0.020197044359520078, 0.01734869005823774, 0.047625640141112466, 0.013009483210875519, 0.022796537461025373, 0.05958057900092431, 0.08701668786151068, 0.10160897698785577, 0.02707967271895281, 0.06716303820056574, 0.07576950852360044, 0.03122648350628359, 0.057306828509484015, 0.029984621929803064, 0.018771338808749403, 0.034695178270339966, 0.011071903564568077, 0.02841259878394859, 0.06312891681279455, 0.025521296608660902, 0.027399756346962283, 0.012995208530420703, 0.019729192767824446, 0.04413539510486381, 0.015479950334078499, 0.010238837284435118, 0.0245503961175148, 0.03904611783634339, 0.029040667760585035, 0.027208022706742798, 0.019824537115969827, 0.036705419687288146, 0.07303824901048626, 0.015865989262238145, 0.021440851635166576, 0.02477594285405108, 0.020836427907592485, 0.00428863351200042, 0.05595962097868323, 0.011506015002461416, 0.030874045632247413, 0.12584060244262218, 0.040743486756192784, 0.07678532294396843, 0.042750868148037365, 0.060029314564807076, 0.03376448946073651, 0.08422388522220509, 0.10261390770652465, 0.02307289289975805, 0.045003210859639306, 0.02660392806865275, 0.018621246862624372, 0.028692460552390133, 0.26462979721171515, 0.07402865907975606, 0.16826358889894827, 0.14017404403005326, 0.08117942751518317, 0.10771645033465964, 0.13131879562778132, 0.18025863596371242, 0.16641249108527387, 0.15744835138320923, 0.22671552667660372, 0.15145951988441603, 0.2275079877248832, 0.2107795617942299, 0.1515510542584317, 0.12076946241515023, 0.06376408665840115, 0.17920968867838383, 0.19104309513100556, 0.20461152919701167, 0.2247833710696016, 0.18758534852947506, 0.1433138291218451, 0.07847689038940839, 0.14342688662665232, 0.1351443896336215, 0.15306816356522696, 0.16724597636078084, 0.1731621774711779, 0.12851191338683876, 0.3045017905533314, 0.1659347481493439, 0.15237056171255453, 0.21439841975058826, 0.12680395932069846, 0.18348125661058085, 0.17528304723756655, 0.17114421432571753, 0.12098482943006925, 0.10241896459566695, 0.1426981942994254, 0.192984723086868, 0.095031658852739, 0.1812810796712126, 0.20401129711951527, 0.2606139826987471, 0.13233230981443608, 0.2124712717320238, 0.21884308196604252, 0.18371339701116085, 0.10163916501083545, 0.1979555349264826, 0.3198276438883373, 0.3809786039803709, 3.8179647752216885, 31.879328727722168, 75.35960606166294, 102.50928211212158, 96.0591790335519, 86.65265219552177, 37.642692702157156, 35.39590583528791, 29.278829915182932, 30.753143855503627, 31.477041925702775, 48.82462671824864, 78.50276265825543, 73.71949073246547, 102.74866839817592, 124.46611077444894, 141.8601894378662, 114.31235381535122, 90.61981650761196, 53.63100835255214, 33.88754572187151, 33.90613215310233, 25.569582734789165, 18.16671313558306, 41.78809567860195, 37.01507234573364, 35.132520471300396, 28.52223709651402, 40.69818387712751, 54.916119371141704, 66.55851745605469, 61.43352617536272, 55.528387682778494, 63.45884268624442, 78.68866171155656, 66.51944078717912, 65.30546542576381, 57.035973072052, 91.64276504516602, 64.4679365158081, 44.22519370487758, 50.58489029748099, 38.79522166933332, 72.5107821055821, 99.03858048575265, 96.83074869428361, 96.85533836909703, 117.11690385001046, 129.62128502982003, 100.15066051483154, 51.99842834472656, 41.98673077992031, 30.164304869515554, 47.99440383911133, 61.342073985508506, 78.49001271384103, 81.69630759102958, 88.41659832000732, 101.10622542245048, 108.91141482761928, 62.837930815560476, 10.690661634717669, 0.24513589324695723, 0.2095602343657187, 0.11171080957033805, 0.25643811534558025, 0.18667733296751976, 0.14469197445682117, 0.28518490280423847, 0.16496531159750052, 0.18379985594323703, 0.13849247140543802, 0.18688245410365717, 0.15194381746862615, 0.24213839694857597, 0.2452734187245369, 0.09451103928898062, 0.28908930186714443, 0.17352161104125635, 0.22934782185724803, 0.09469916312290089, 0.1562930369483573, 0.1021154626671757, 0.2370539169226374, 0.16452973282762937, 0.11898499674030713, 0.13660611691219465, 0.22648729463773115, 0.14682125805744103, 0.10061387824160711, 0.131548778287002, 0.09682158673448221, 0.07380177732557058, 0.08972377117191042, 0.07912477598126445, 0.1147575064429215, 0.16123077699116298, 0.17339175300938742, 0.12978757279259817, 0.12392011763794081, 0.2667004146746227, 0.10704668877380234, 0.1422088077025754, 0.15211969374545983, 0.13998188291277203, 0.21770786573844297, 0.1372834305678095, 0.15976638985531671, 0.1149752347597054, 0.1993822633687939, 0.20874836721590587, 0.19436479546129704, 0.153352591874344, 0.13957241417041846, 0.16884581265704973, 0.23538162665707724, 0.19619724713265896, 0.13882304009582314, 0.11578012656952653, 0.12901932187378407, 0.09318809277777161, 0.18210769817233086], [0.02917185572109052, 0.013404368539340794, 0.05473428851525698, 0.026750771528376, 0.06067823152989149, 0.022672911773302724, 0.051948060880282095, 0.036179663613438606, 0.02897629514336586, 0.00710368319414556, 0.013150811877234705, 0.013375056674703956, 0.0049517623930504275, 0.06556772773287126, 0.05689498828724027, 0.02965701504477433, 0.014651971370247858, 0.01609144439654691, 0.04492660764870899, 0.05604490604517715, 0.023621586849913, 0.010710505635610648, 0.006039784813765436, 0.001905561063072777, 0.05951828948621239, 0.0566210603075368, 0.012980889745189675, 0.031922168497528346, 0.06166457038904939, 0.03681692334690264, 0.025809324546051875, 0.03277764170031462, 0.02883085116211857, 0.011737205454015305, 0.04004954559994595, 0.03766469517722726, 0.04047480724485857, 0.011217030330694147, 0.08176531536238534, 0.048166490226451836, 0.017787673377564976, 0.10031456287418093, 0.07127491291612387, 0.12782258966139384, 0.05776171838598592, 0.046422702725976706, 0.07292653500501599, 0.05759958244327988, 0.09767519057329212, 0.1415506965879883, 0.159999086654612, 0.03448572808078357, 2.274702340364456, 18.86789059638977, 53.27583033697945, 72.41044316973004, 77.86383410862514, 65.88564000810895, 63.68557630266462, 37.0931179864066, 22.025219781058176, 39.564477579934255, 61.42489651271275, 58.83933980124337, 68.06292751857212, 73.83579662867955, 79.6926486151559, 47.95366655077253, 50.80107307434082, 32.7923880304609, 14.315736600330897, 7.3138362509863715, 0.3860875384083816, 0.06633266061544418, 0.07354629532034908, 0.07937286195478269, 0.0945564807791795, 0.16997479993317807, 0.370228465114321, 0.09638801642826625, 0.1678791038159813, 0.0510383252320545, 0.15671507215925626, 0.32914230121033533, 0.2473608638559069, 0.360264178365469, 0.1782763773309333, 0.2390640904860837, 0.45775264288697926, 0.26341437814491137, 0.19828245309846743, 0.1605335415474006, 0.3018493971654347, 0.22330048706914696, 0.41244941098349436, 0.24058884009718895, 0.15596234612166882, 0.31870078721216744, 0.2813040353357792, 0.06334211251565389, 1.35206700861454, 7.405427404812404, 15.080556086131505, 36.67754275458199, 82.03472655160087, 92.38398497445243, 74.87412847791398, 34.57540348597935, 23.116971118109568, 22.930083683558873, 43.54950223650251, 58.319809096200125, 70.69374479566301, 64.80677236829484, 70.05031381334577, 66.66811139242989, 29.492570400238037, 8.620555298668997, 0.18180242526744092, 0.15930950508585998, 0.03172902689714517, 0.04917007405310869, 0.03790922562724777, 0.013208806265278586, 0.01622929048192288, 0.06238286755979061, 0.009690349439292081, 0.06746459273355347, 0.062019193145845614, 0.019246711961126754, 0.036013459853295765, 0.020973079771335636, 0.010726787931551891, 0.0399902348539659, 0.05344135360792279, 0.021914260428664938, 0.0053808628498310486, 0.032922254476164065, 0.03439341339149645, 0.03794831942234721, 0.034266021834420304, 0.03365101126421775, 0.052348796876945665, 0.046503984435860596, 0.005330042273271829, 0.03413108157526169, 0.017489007707419138, 0.01773140416480601, 0.051270960963198116, 0.025208783735122, 0.018615608236619403, 0.015471858803981116, 0.0643501780661089, 0.0035691510253985015, 0.014792178757488728, 0.05729752579437835, 0.04136921478701489, 0.07650493191821234, 0.030585759851549352, 0.07190796573247228, 0.0755218771685447, 0.09310620717172112, 0.023793325759470463, 0.084119709740792, 0.021797160551484143, 0.038906536397657225, 0.022045651949676018, 0.05251577077433467, 0.023990262066945434, 0.02110428808789168, 0.07260736570294414, 0.013498807891405054, 0.03512601747310587, 0.019786405144259334, 0.08903490206492798, 0.08245232528341667, 0.0439510574963476, 0.009980630961113741, 0.024010484106838703, 0.031233072081314664, 0.02428607958635049, 0.05150910300601806, 0.033645477811140675, 0.047524294150727134, 0.013778665419002729, 0.027981769759207964, 0.07430484318839652, 0.04064014587285263, 0.0418094924118902, 0.058256953954696655, 0.021133383669491326, 0.03557122126221657, 0.04793323702844126, 0.026664198941684196, 0.017601234006828496, 0.07334462792745658, 0.061305150389671326, 0.0171406681848956, 0.0434778912791184, 0.045909811676080735, 0.02225976706748562, 0.04368747039032834, 0.006663354679143855, 0.023067016786496555, 0.07579755916127137, 0.0274219631017851, 0.030888070951082876, 0.03315628120409591, 0.04585036861577204, 0.042898340948990414, 0.050348265296114345, 0.04869321321270295, 0.04648326536906617, 0.053569840999054055, 0.08024025362517152, 0.03087482594751886, 0.021133987565657923, 0.0336020854966981, 0.08872848243585654, 0.10281211457082204, 0.03999274543353489, 0.1438365453588111, 0.05206432446305241, 0.08823085163852998, 0.11877129892153399, 0.05953739703233753, 0.08842469552265746, 0.12405434543532984, 4.103093658174787, 26.210039888109478, 67.96989808763776, 83.17161859784807, 87.33226244790214, 84.09361675807408, 85.50348963056291, 54.79406384059361, 31.343824114118302, 33.571183817727224, 31.843809536525182, 36.29541615077427, 41.82055071422032, 50.26505429404122, 65.41514274052211, 50.66643435614449, 50.46758386066982, 37.0488475390843, 19.88561929975237, 10.110428861209325, 0.9464594019310815, 0.15006267412432603, 0.08605392809425082, 0.13678734004497528, 0.08267994664077248, 0.14694635277347906, 0.09746643927480493, 0.07029309310019016, 0.1707838579480137, 0.11316083211983953, 0.101313569982137, 0.21904504112899303, 0.12334055373711245, 0.17746844568422862, 0.2273815902216094, 0.5525108724832535, 0.38036205992102623, 0.24145082384347916, 0.03641613646011267, 0.06358641904911824, 0.14921624240066322, 0.07867697679570743, 0.30423447489738464, 0.27808617800474167, 0.10490525261099849, 0.3517200382692473, 0.2283990399113723, 0.37071918163980755, 2.858961594956262, 9.935552256447927, 22.088818379810878, 40.22257620947701, 65.66124098641532, 61.66185787745884, 51.05399792534964, 37.03522906984602, 31.394643238612584, 41.80492768968855, 73.60012068067277, 85.64986038208008, 89.26789161137172, 79.7441417149135, 80.50903415679932, 83.47206565311977, 45.29556022371565, 14.948481253215245, 0.3924596607685089, 0.18375455694539206, 0.04483977552237255, 0.05761315992900303, 0.017580788050379072, 0.006450522840688271, 0.0064209883317484385, 0.027160915413073132, 0.04528072150424123, 0.10100621397473983, 0.02350798312441579, 0.042897309575762065, 0.07239172048866749, 0.06385570245661906, 0.04462937538379005, 0.07846318398203168, 0.04986568779817649, 0.03783500407423292, 0.03904009244537779, 0.048160091641225984, 0.03331318224913307, 0.04834326895486031, 0.019983336362721663, 0.01624817241515432, 0.07886391319334507, 0.0463005630299449, 0.05373376488153424, 0.0641882321132081, 0.014761439424806407, 0.07313319641564574, 0.02000947522797755, 0.05760919049914394, 0.03818022572834577, 0.006596894294489175, 0.015291560175163406, 0.045226537090327056, 0.03484825577054705, 0.027961272912632142, 0.0056381056534259445, 0.05030936488349523, 0.04229760675558022, 0.049173649932656965, 0.0837108516799552, 0.03361610063750829, 0.06622841728052922, 0.0705378610374672, 0.01958981658598142, 0.008738787196177458, 0.005997061280400625, 0.07354495860636234, 0.030905448232910464, 0.018502238605703627, 0.14512848960501806, 0.032817061192223, 0.03457027693678226, 0.03629112316827689, 0.05520053706797106, 0.04052327160856553, 0.12418672761746816, 0.16027181702000753, 0.10978746813322816, 0.1043637613100665, 0.11119624253894601, 0.10283737642956631, 0.09961046744138002, 0.10648745378213269, 0.0823050153308681, 0.19368384485798223, 0.23226161407572882, 0.09751288499683142, 0.12390314069177423, 0.201796965939658, 0.13944311253726482, 0.15330950490065984, 0.10688924829342536, 0.08685274701565504, 0.16402132010885648, 0.17085465629185947, 0.2106672642486436, 0.10296719374933413, 0.09201887516038758, 0.1142307732786451, 0.1114722163017307, 0.22446228829877718, 0.11047869175672531, 0.15667415649763175, 0.14840827004185744, 0.11821670510939189, 0.13047662510403565, 0.13075546228459903, 0.1565743847084897, 0.12570743315986224, 0.09565503575972148, 0.18902080293212617, 0.09916310930358511, 0.1772361695766449, 0.20082511380314827, 0.13377934002450534, 0.11220455236200776, 0.3834583509181227, 0.19793573527463845, 0.19727769201355322, 0.1253555313284908, 0.27678691915103365, 0.10704120621085167, 0.19463137829942362, 0.28522922471165657, 0.2501664161682129, 0.277670046048505, 0.14805130633924687, 4.39172226190567, 30.43169239589146, 80.112215587071, 98.47597789764404, 97.73410483769008, 83.00442409515381, 83.13229179382324, 50.75985983439854, 32.34365599496024, 58.05064630508423, 83.15584618704659, 82.31268923623222, 98.11437279837472, 106.22260788508824, 118.23974663870675, 70.32824175698417, 72.85662869044712, 49.64678273882185, 22.259540830339702, 13.18278591973441, 1.0596015879086085, 0.39638737429465565, 0.21839634808046476, 0.1757604509059872, 0.21424387661474092, 0.2866947517863342, 0.44007571999515804, 0.25947499381644384, 0.29726301612598555, 0.3604886920324394, 0.3316880017518997, 0.6435941564185279, 0.5747492877500398, 0.5702029945594924, 0.3487452593232904, 0.46932074214730946, 0.7950203738042286, 0.48812767011778696, 0.4700031855276653, 0.5030976725476128, 0.45207061778221813, 0.49709714310509817, 1.417577121938978, 0.4377843343785831, 0.49893016474587576, 0.9996599129268101, 0.48638568073511124, 0.3651738134878022, 2.7357075001512254, 12.997456618717738, 23.562187365123204, 53.37135417120797, 119.84593391418457, 125.43345287867955, 102.51568140302385, 48.87027638299124, 35.62401866912842, 37.67203147070748, 62.80726841517857, 78.06038475036621, 92.80160645076207, 81.15685640062604, 89.86591611589704, 98.49759374346051, 53.932605334690635, 16.520168985639298, 0.6067717980061258, 0.43326401550854954, 0.1132842915664826, 0.23690398782491684, 0.14000371816967214, 0.09812826876129423, 0.07679729230169739, 0.1399517830993448, 0.1254070457071066, 0.23108981123992375, 0.18848249396043165, 0.09174725759242262, 0.227383395124759, 0.08945292713386671, 0.0709912513515779, 0.14984642501388276, 0.22467536186533316, 0.0875624403623598, 0.14408723690680095, 0.10863151587545872, 0.14194586181214877, 0.09717925611351218, 0.12212581320532731, 0.09310338446604353, 0.15266241319477558, 0.14210356692118303, 0.1868306411696332, 0.22857746747987612, 0.09659862012735435, 0.14024393313697406, 0.14442569017410278, 0.12055090628564358, 0.07991652456777436, 0.19574522067393574, 0.13670451806059905, 0.07878174260258675, 0.08254784265799181, 0.169840097161276, 0.08982593140431813, 0.15770054927894048, 0.11940290645829268, 0.07552113078002419, 0.23307523184588977, 0.11972895610545363, 0.16877391508647374, 0.18064191325434617, 0.1272772510669061, 0.09611866516726357, 0.07248272560536861, 0.2354914407644953, 0.11117977449404341, 0.1235366774989026, 0.2096394058316946, 0.08294985430049044, 0.15078234193580492, 0.10599263211978333, 0.1999332880867379, 0.17082508573574678], [0.019328656938991377, 0.0487322493323258, 0.02695162807192121, 0.06339402722993068, 0.008730591341320957, 0.03543509356677532, 0.023312068012143885, 0.05025978432968259, 0.0792331448090928, 0.13314553403428622, 0.061216343726430617, 0.04495579483253615, 0.06097498203494719, 0.062241935836417336, 0.029285126964428594, 0.06921477881925446, 0.009500397801665323, 0.048913838874016485, 0.03370943312932338, 0.02333307545632124, 0.005673250798801226, 0.024934319712753807, 0.04684985409091626, 0.01915161018925054, 0.09144684299826622, 0.048884261532553604, 0.04867304036659854, 0.06132620533129998, 0.026814050007877604, 0.030993318517825434, 0.058665601669677665, 0.039363746863922904, 0.06190787269068616, 0.02673394894892616, 0.01333263042449419, 0.024631345345239555, 0.03658350730048759, 0.0077800511415781716, 0.05473306715222342, 0.06629331915506295, 0.028638730756938457, 0.07089742352919919, 0.007829442553754364, 0.1007413546155606, 0.036523019296250174, 0.09795923211744853, 0.09266114248228924, 0.09681801764028412, 0.18221429602376052, 0.052502247571413, 7.111925508294787, 31.960188388824463, 55.410164083753315, 75.07722432272774, 60.34903744288853, 67.53838716234479, 54.92045852116176, 27.054054941449845, 28.536390577043804, 37.70980535234724, 59.18809073311942, 32.17299781526838, 51.95727069037301, 42.92284073148455, 29.36113827569144, 25.267237084252493, 10.399049213954381, 3.2508677882807593, 0.22688719603632176, 0.03713637084833213, 0.0389464613981545, 0.118231008627585, 0.03870058744879706, 0.07522773223796062, 0.1070728123720203, 0.08275194599160127, 0.039224979667259116, 0.07945612498692103, 0.0965888017256345, 0.09598648654563086, 0.02024492179043591, 0.02888084901496768, 0.03760917404932635, 0.24968275640692028, 0.11793535734925951, 0.18717881105840206, 0.1161791051604918, 0.08983765648944037, 0.22168148894395145, 0.2364811519426959, 0.15500329115561076, 0.06107604982597487, 0.12745244880872114, 0.028357535667185272, 0.011017928648340915, 0.19964385218918324, 0.0892931389223252, 0.024214774037578275, 0.2791590504348278, 0.24634525978139468, 0.03350094645949347, 0.19042063424629824, 0.2840476238301822, 0.11484809086791106, 0.38904950661318644, 12.903180854661123, 39.68627255303519, 91.03877898624965, 84.63766070774624, 40.86722660064697, 18.70468783378601, 18.4472553389413, 40.51586314610073, 42.5206755229405, 57.10718863351004, 60.93874495370047, 72.1393939426967, 63.26445293426514, 36.80373246329171, 6.129038546766553, 0.026836458626868467, 0.15382687428167888, 0.02420443486023162, 0.004562776502487915, 0.05421189458242484, 0.0646414595789143, 0.057280922042472024, 0.010277099874136704, 0.053106713707425764, 0.05545794950532062, 0.05964902961360557, 0.014476732916331716, 0.027768555396635617, 0.035159852621810775, 0.03996998397633433, 0.04662533363859568, 0.009852042637898453, 0.0991469533847911, 0.032503954600542784, 0.036324866714754274, 0.09044778160750866, 0.044332336501351426, 0.046130152352686436, 0.044114801567047834, 0.04213414766958781, 0.0158047396024423, 0.054109310265630484, 0.041502533347478936, 0.025835967223559107, 0.06578801412667547, 0.03611896526334541, 0.017573235955621515, 0.07085164955684117, 0.041595991368272474, 0.07064969039389066, 0.06899496061461312, 0.07804245155836854, 0.023280358374384896, 0.04850645323417016, 0.07032420393079519, 0.023914082940401774, 0.06179941565330539, 0.018730192445218563, 0.009392491225818438, 0.012152043104703938, 0.019796489870973995, 0.034829969251794476, 0.016608418530917594, 0.04674383977960263, 0.03645736764052084, 0.047261551820806096, 0.04393639096191951, 0.018374789373150895, 0.05033837564821754, 0.021650851438088075, 0.03161508051146354, 0.025469953560137322, 0.013262875328239585, 0.0193864783006055, 0.019106248426916342, 0.0422888807952404, 0.010294521260740501, 0.04060997481324843, 0.048447610677352974, 0.05947471396731479, 0.06864917916910988, 0.09830335115215608, 0.026608041687203304, 0.031702859194150994, 0.06299784420324223, 0.08197698436145272, 0.052892605374966345, 0.061276882620794434, 0.030018759026591266, 0.031969496315079074, 0.006476839397302163, 0.01566702583139496, 0.05379330972209573, 0.043744433405143876, 0.034914429898240736, 0.0733307586716754, 0.04193950311413833, 0.0028480606228445788, 0.05464410442592842, 0.06238881152655397, 0.02337024899731789, 0.050355783464120965, 0.019296628389773623, 0.01250173630458968, 0.015776280147422637, 0.039284388800816875, 0.048947874190551896, 0.05030269827693701, 0.02994643058627844, 0.03744800501902189, 0.041412583352731805, 0.02961470160101141, 0.10030933136918715, 0.02197028706515474, 0.09966038726270199, 0.013525559134515268, 0.12285840032356125, 0.038439205581588407, 0.1315080797565835, 0.13806674496403762, 0.04879954304280026, 10.830432466098241, 42.254187788282124, 68.92282962799072, 82.18958800179618, 75.72228118351528, 84.05777100154332, 75.87755952562604, 53.428840092250276, 41.09937981196812, 39.17112616130284, 38.81582307815552, 33.5400767326355, 48.443629196711946, 47.380262987954275, 39.06726448876517, 32.285145214625764, 15.53761032649449, 5.266568643706186, 1.0147218704223633, 0.0962602279282042, 0.10891826477433954, 0.15418263019195624, 0.06246085837483406, 0.027634765254333615, 0.09799837001732417, 0.11194336387727942, 0.05779529908405883, 0.05476047657430172, 0.1281084157526493, 0.17961908956723555, 0.045515311416238546, 0.1731187105178833, 0.060341522097587585, 0.254788162452834, 0.36169336310454775, 1.0500486833708627, 0.7176943602306503, 0.9652322403022221, 0.1588444100426776, 0.158581355586648, 0.2041321170649358, 0.08992687705904245, 0.15987054498067924, 0.21381542246256555, 0.005022813067106264, 0.16401017856385025, 0.10114119494599955, 0.1299975658101695, 0.2780082550432001, 0.2804047593048641, 0.20635277219116688, 0.36898457471813473, 0.5408826821616718, 0.18497629995856965, 1.5911827491862434, 17.55109405517578, 43.45764010293143, 62.143124852861675, 52.04448447908674, 35.765824454171316, 29.796995299203054, 35.74329144614083, 65.57989147731236, 59.98177650996617, 74.82160704476493, 73.22586985996791, 84.43509292602539, 80.41364233834403, 56.095920017787385, 13.186196616717748, 0.06564945049051728, 0.1586644896971328, 0.011815099577818598, 0.003843648126348853, 0.03704598319849797, 0.0931050604475396, 0.039296551541026147, 0.014919052931613155, 0.04896090206290994, 0.06474395907883133, 0.0971627270004579, 0.006802344520110637, 0.04957682187003749, 0.013755484118259378, 0.012403480193045522, 0.028361091190682988, 0.033150530619812865, 0.06693979339408022, 0.07252288130777222, 0.020605893938669136, 0.04926260926627687, 0.036861024730439694, 0.012203983264043927, 0.027720618593905653, 0.0024184092804456925, 0.03812646879149335, 0.10680039413273335, 0.040489830010171445, 0.010228282672220042, 0.023710062727332115, 0.04044037837801235, 0.07064391606088195, 0.00452537480409124, 0.023053340913195695, 0.06412835818316255, 0.039026206226221154, 0.020858064692999636, 0.05609305149742535, 0.05493225110694766, 0.015232229073132788, 0.03823580792439835, 0.06054219204400267, 0.006730958819389343, 0.03941774468070694, 0.013831404553327178, 0.051517357384519916, 0.04840701053451214, 0.023610889745344008, 0.00824670766347221, 0.05496174702420831, 0.0436156508512795, 0.05841877098594393, 0.03212003609431641, 0.032875622157007456, 0.01794353117501097, 0.04179405913289104, 0.15086113342217036, 0.10382832932685103, 0.10046512300946883, 0.16439142024942807, 0.10700758480067764, 0.11276922920452696, 0.11657908798328467, 0.1146781856992415, 0.18367841174559935, 0.2703195847570896, 0.17921017722359725, 0.1444919966161251, 0.16107685810753278, 0.11754901308034148, 0.16666136415941374, 0.19104073382914066, 0.12788584269583225, 0.14874342562896864, 0.13741168725703443, 0.07276614289730787, 0.12452181535107748, 0.12434333349977221, 0.1181296490664993, 0.10599067115357944, 0.11876450000064713, 0.20186884993953363, 0.14314191548952035, 0.16752117659364427, 0.14368624985218048, 0.16995839295642717, 0.17646862433425017, 0.09032463428697415, 0.08739157845931393, 0.09309712158782141, 0.0916062444448471, 0.1779148538729974, 0.12626183698219912, 0.07249491209430353, 0.13388340015496525, 0.15072999974446638, 0.15728069895080157, 0.1679650199200426, 0.1380681020340749, 0.2331601030060223, 0.12305474121655736, 0.23289892130664416, 0.1933714473353965, 0.2636172058326857, 0.31447519681283403, 0.17229505042944634, 14.078162057059151, 49.631256989070344, 80.47143050602504, 97.45591981070382, 80.60220949990409, 86.22657476152692, 71.53416415623256, 37.650846413203645, 41.82549435751778, 53.989580563136506, 85.23816571916852, 51.29749754496983, 74.27103873661586, 64.3036880493164, 46.206243242536274, 40.68918595995222, 15.969439131872994, 6.096345969608851, 0.8944347106984684, 0.1232092979231051, 0.24626996953572544, 0.24181685277393886, 0.20394948257931642, 0.22565040311643056, 0.3068702034652233, 0.24129063529627665, 0.10101592381085668, 0.28092782838003977, 0.23672963146652493, 0.33639236646039145, 0.2475665413907596, 0.28254328455243793, 0.3817959129810333, 0.5802143716386386, 0.481374129652977, 1.1572398458208357, 0.9704826899937221, 1.8539721965789795, 0.5272660042558397, 0.6831985084073884, 0.3573429765445845, 0.2996572405099869, 0.39414573886564797, 0.3813651518097946, 0.09560607267277581, 0.3853521692965712, 0.3134183920919895, 0.18505680135318212, 0.7215609784637178, 0.6476744317582676, 0.2629623923982893, 0.5665788576006889, 0.5877230944378036, 0.5921588678445134, 0.9604287551982063, 20.973531757082256, 56.44727305003575, 127.80006490434918, 119.93845612662179, 58.60629027230399, 26.751922948019846, 29.6543869972229, 55.279357297079905, 60.70520210266113, 78.65940979548863, 79.33403124128068, 96.74020671844482, 92.16613810403007, 63.65228053501674, 13.467645559992109, 0.12701034253197058, 0.36155130501304356, 0.08601736862744604, 0.11178560448544365, 0.10031320580414363, 0.23986571175711496, 0.11834581675274031, 0.07423095072486571, 0.15741688092904432, 0.17915174178779125, 0.14086582405226572, 0.1308924313634634, 0.08979414203869444, 0.1953389953289713, 0.19181936633374008, 0.17111718149057456, 0.22479580183114323, 0.1712214451815401, 0.1781678252986499, 0.21190725985382283, 0.1680272687226534, 0.21572210586496762, 0.267115623823234, 0.12317412266773836, 0.10880982809300933, 0.14896276885909693, 0.20801028396402085, 0.08913607163620846, 0.12514333985745907, 0.15343747660517693, 0.09275520779192448, 0.12161465920507908, 0.1272220725991896, 0.11843321206314222, 0.17893572337925434, 0.16292845803712094, 0.11400676172758852, 0.18907029527638639, 0.15443300961383752, 0.21800864674150944, 0.06485413959515945, 0.23290144545691355, 0.07126235323292868, 0.10025447181292943, 0.08631021755614451, 0.11749569379857608, 0.15843248500355653, 0.12051114413355078, 0.09368265659681388, 0.14006847755185195, 0.2015262304672173, 0.0977712847026331, 0.11465256421693734, 0.10886806675365993, 0.07469255131270204, 0.11935302056372166], [0.017349952133372426, 0.08546930910753352, 0.08907906112394162, 0.030460251229149953, 0.04069188416802457, 0.06416627472000462, 0.025232985382899642, 0.06418178603053093, 0.03365317918360233, 0.09084202402404376, 0.05014301523832338, 0.03553671097116811, 0.04023610880332334, 0.032879659440368414, 0.0436045059135982, 0.021309880805867057, 0.005630407249554992, 0.023093377871971046, 0.052021281594144445, 0.07346040635768857, 0.05967011848198516, 0.049607854669115374, 0.04185981596154826, 0.01887454228874828, 0.05569001187437347, 0.04459344695455261, 0.07674579149378197, 0.022736678798017756, 0.0255825700171824, 0.04546929317127381, 0.047012814453669956, 0.004264234664982983, 0.062462527570979934, 0.04467493901029229, 0.05689681015376534, 0.04082392368997846, 0.03721885356519904, 0.06555181608668395, 0.030547076570136205, 0.013276484196207352, 0.04667948751843401, 0.04885638392131243, 0.0431881161140544, 0.05199180603293436, 0.10785795202744858, 0.02527474582062236, 0.043565747993333, 0.42742793581315447, 3.2676730922290256, 39.51819562911987, 69.81975868770054, 78.92552580152238, 74.95384516034807, 61.82899679456438, 39.52412591661726, 30.374077933175222, 25.377458095550537, 46.34437690462385, 46.63967187064034, 49.8969908441816, 44.346405029296875, 27.88232363973345, 16.486831528799875, 6.7953994529587884, 1.7924589259283883, 0.05598348166261401, 0.09193395650280373, 0.02398689483691539, 0.2762746252119541, 0.030073520195271288, 0.08135169398571764, 0.08639389449464423, 0.025633254886737893, 0.04466082208922931, 0.014395826097045625, 0.1635646660413061, 0.0844796657828348, 0.024014243190842013, 0.06222619382398469, 0.07511593002293791, 0.08287716284394264, 0.040039242045687776, 0.06572123271014009, 0.09029369987547398, 0.06892597395926714, 0.2895852295415742, 0.28864228299685885, 0.6989225532327379, 0.2745309259210314, 0.08844372842993055, 0.19760452876133577, 0.0747213890509946, 0.17266224644013814, 0.0291832110046276, 0.08481804441128458, 0.090648824748184, 0.024715347980548228, 0.05370311884741698, 0.14279736897775105, 0.176516501765166, 0.032024613714643886, 0.13739472388156823, 0.1965568299804415, 0.14644161771450723, 0.2354172361748559, 0.040007720701396465, 0.5100873431989125, 7.916461331503732, 33.797715936388286, 83.4572034563337, 94.94531331743512, 55.095907483782085, 17.878958702087402, 22.554080179759435, 26.127396277018956, 52.54086031232561, 72.24095576150077, 60.75982883998326, 69.4800751549857, 64.01674134390694, 31.8995931489127, 5.766172349452972, 0.321352339216641, 0.17362135568899767, 0.04185516460399542, 0.030469733756035566, 0.05664902952100549, 0.0035667829381834182, 0.06539376492479018, 0.05380315865789141, 0.043696966487914324, 0.07834692379193646, 0.02687953711886491, 0.04070863041228481, 0.033753025611596446, 0.02847570593335799, 0.044461563495653014, 0.08336477846439395, 0.09320344123989344, 0.04258597396048052, 0.012185089456449662, 0.05100817792117596, 0.035765940456518104, 0.017104912782087922, 0.06462133423026119, 0.0777916582301259, 0.028794909162180762, 0.029704434464552572, 0.02106624432573361, 0.0283030272527997, 0.06750787648239306, 0.09434406539159161, 0.054649305396846364, 0.025766145970140184, 0.06742746329733304, 0.03287306068731206, 0.047069349991423745, 0.02216236336555864, 0.02852489972221, 0.00836294240850423, 0.010300487279891968, 0.06023463926145008, 0.06014927277075393, 0.035578471408890824, 0.012109551545498627, 0.051203070141907246, 0.05283717245661786, 0.03782023575955203, 0.04605449230543204, 0.022741374260346805, 0.07522991033537046, 0.07282153171088014, 0.08085518277117185, 0.026713072122739892, 0.044702036306262016, 0.0742440057386245, 0.031156244953828197, 0.025851556565612555, 0.04441396087141974, 0.02234913352211671, 0.07841494692755596, 0.032135340451662026, 0.005266086106920349, 0.0251948771599148, 0.01602213204439197, 0.045717575919947455, 0.0422635273342686, 0.017157017486169934, 0.041485634432839494, 0.04693195004282253, 0.04420389321499637, 0.041697747872344086, 0.02987343378897224, 0.015640949730628302, 0.03651524667761155, 0.01325799581328673, 0.04014855742986713, 0.029286894548152174, 0.054471044069422145, 0.0207933697716466, 0.030928426821316992, 0.026061418965192776, 0.038308431527444294, 0.06029911365892206, 0.005655265379963177, 0.07583638493503843, 0.02088790157410715, 0.013552711561455258, 0.08581656297402722, 0.05049544293433428, 0.03688165898035679, 0.05808695379112448, 0.02031892112323216, 0.06983947886952332, 0.046386411280504296, 0.025279236026108265, 0.03239589111347284, 0.029519920436931506, 0.012514348574248808, 0.15254947782627173, 0.12624169806284563, 0.10160275482173477, 0.03862248467547553, 0.3442698323300907, 5.161957434245518, 53.48939364297049, 87.83365835462297, 91.59370381491524, 80.39342308044434, 82.90146568843296, 58.346837588718955, 54.880089487348286, 31.366951193128312, 28.4731411252703, 35.35700634547642, 43.28389344896589, 43.45802920205252, 37.06359509059361, 23.069429806300572, 10.968265618596758, 2.65145776953016, 0.18406520384762967, 0.13258458913436957, 0.0636649119800755, 0.1288865189999342, 0.12063656454639775, 0.10262728841709239, 0.03249249075140272, 0.06361372329826866, 0.06748125755361148, 0.18778576063258307, 0.3310552271349089, 0.22984950350863592, 0.23615317525608198, 0.24759050724761827, 0.41140316426754, 0.6523309733186449, 0.29813675209879875, 0.48933600527899607, 0.5730168521404266, 0.6935805827379227, 0.9832635756049837, 2.5619693143027167, 2.3911617483411516, 1.0325066532407488, 0.8359697993312563, 0.6276969494564193, 0.5590515700834138, 0.3507839042161192, 0.20111285336315632, 0.6545563510486058, 0.37999893512044636, 0.26991794630885124, 0.15159779175051621, 0.21949208714067936, 0.20029105246067047, 0.021396136177437644, 0.032993609218725135, 0.20362979759063038, 0.15074321760662965, 0.2327879944017955, 0.1817909987377269, 0.5660158906664167, 9.785387788500104, 37.55185195377895, 65.42073604038784, 55.010798999241416, 33.49987098148891, 19.386392968041555, 41.71072053909302, 44.96044513157436, 63.50083759852818, 85.38147231510708, 67.12397575378418, 80.98968274252755, 79.25972720554897, 48.68501308986119, 11.087645224162511, 0.5675577393599919, 0.035394578240811825, 0.0448613393652652, 0.032963156567088196, 0.0821558190509677, 0.023560121755248735, 0.0278275540165071, 0.09798770344683103, 0.01695863589910524, 0.05069252343050071, 0.019629502402884618, 0.04213519261351653, 0.06258387677371502, 0.018925573211163282, 0.0328899596019515, 0.03822350608451026, 0.04934478664238538, 0.014318668183737567, 0.041831612653498135, 0.07868273077266556, 0.02325659607803183, 0.04343718596334968, 0.049309038024927886, 0.061397247947752476, 0.0102137577819771, 0.00574390749846186, 0.028211662512538687, 0.08066012430936098, 0.07895105066043989, 0.03915790987334081, 0.002621294219612277, 0.0417688278082226, 0.04335214177678738, 0.014676739594766071, 0.017563861994338886, 0.03476894859756742, 0.06127332031194653, 0.014593206844957811, 0.021220962184348276, 0.0114986936096102, 0.03568115411326289, 0.06260263826698065, 0.026501750872869576, 0.017953117178486924, 0.011936714257379728, 0.04908992210403085, 0.0207882247798677, 0.029582484758325985, 0.027422214159741998, 0.014775793833125914, 0.017356213315257003, 0.03137554407918027, 0.017522110038303902, 0.03539977242637958, 0.09110867471567222, 0.1469636011336531, 0.12141001304345471, 0.14923482068947383, 0.12341676679040704, 0.1812916241054024, 0.07129931982074465, 0.14460980386606284, 0.08823184908500739, 0.2231429855206183, 0.20679927537483828, 0.0654606209801776, 0.10566176487398998, 0.18460738046893052, 0.1842092161199876, 0.05109590571373701, 0.08549219609371253, 0.08611339490328516, 0.1495310826493161, 0.22110307855265482, 0.17520433717540332, 0.08821667025664023, 0.16482334850089891, 0.114102000902806, 0.13473554514348507, 0.09383166967225925, 0.1683342651064907, 0.12800276785024575, 0.1335548534989357, 0.24103138063635143, 0.09769351780414581, 0.11840361436562878, 0.2961354266319956, 0.09319031158728258, 0.2004397330539567, 0.12375835488949503, 0.08306847579245057, 0.1797115331781762, 0.1696951620812927, 0.09659460320004395, 0.09267657915396349, 0.18264839558729104, 0.17673884412007673, 0.18073912018111774, 0.20898886716791562, 0.1816120147705078, 0.2045199405401945, 0.5130234999316079, 5.7888747198241095, 67.03622695377895, 100.70067296709333, 102.96115125928605, 89.41966111319405, 80.35404069083077, 51.38674715587071, 43.799884046827046, 33.51789460863386, 63.518472126552034, 68.2570879799979, 71.35117639814104, 67.77259009225028, 47.61354180744716, 28.937103612082346, 12.019872869764056, 3.5412864216736386, 0.35027527436614037, 0.26501827208059175, 0.309352094573634, 0.6401071920990944, 0.2793879067259175, 0.2808212712407112, 0.24465011645640644, 0.13285113126039505, 0.1552557876067502, 0.17838681569056852, 0.3433054983615875, 0.21481451099472387, 0.14012335746416024, 0.19763099162706307, 0.2680273577570915, 0.3408427962235042, 0.22654335520097188, 0.23140880412289075, 0.23676070837037905, 0.26500627558146206, 0.7019489822643143, 2.0310311870915547, 2.0004067846706937, 0.6133848002978733, 0.44583745939391, 0.4538741638617856, 0.32902627172214644, 0.38603713682719637, 0.10541974500353847, 0.41573257052472656, 0.3124204027865614, 0.24124294785516603, 0.23100274162633078, 0.46934652647801806, 0.25362352494682583, 0.09388649530176606, 0.3314081196274076, 0.4164423181542328, 0.29114786854812075, 0.3663102782198361, 0.2747435787958758, 1.1321324216467994, 13.07329533781324, 50.44846241814749, 120.51928383963448, 133.87969698224748, 73.81003965650285, 29.127522468566895, 30.95200824737549, 38.052337646484375, 72.0642283303397, 92.08072389875139, 75.72185039520264, 91.27337101527623, 88.8593166896275, 52.760291372026714, 10.081797071865626, 0.672516793012619, 0.31214619321482523, 0.14539683663419314, 0.1503120900264808, 0.16948313345866545, 0.0985313660598227, 0.18511085345276765, 0.3067056994353022, 0.14733371484492505, 0.19317556784621306, 0.10891449890498604, 0.23929737082549504, 0.11163668640490089, 0.13349535954850061, 0.14784014624144348, 0.16913406790367194, 0.18472897394427232, 0.12603891108717236, 0.11687848477491311, 0.12944063783756324, 0.10464307346514293, 0.15556077552693232, 0.16879798950893538, 0.17307771343205655, 0.11642867034035069, 0.0800997968763113, 0.13821246714464255, 0.27078815389956745, 0.25637327453919817, 0.1124938050551074, 0.16806889006069728, 0.11794333692107882, 0.16008478562746728, 0.15205249163721288, 0.08334440205778394, 0.1035695428560887, 0.17003030409770353, 0.08463777122753006, 0.11569528255079474, 0.10882791105125632, 0.09854264331183263, 0.12998816131481103, 0.0804703923474465, 0.1808302067220211, 0.10409563141209738, 0.15818381548992225, 0.08783377294561692, 0.05786436037825687, 0.2528829446860722, 0.21109433418938092, 0.17592203723532812, 0.08832510693797044, 0.1523312066814729, 0.22826238295861653], [0.03621509671211243, 0.10082927918327705, 0.05184108644191708, 0.02878892787599138, 0.046087536960840225, 0.060787862432854514, 0.02300944139382669, 0.024656819246177162, 0.02721687589239861, 0.035450045085911236, 0.06679701605545622, 0.04013355502060481, 0.010978161407235478, 0.02874980015414102, 0.010911468200252523, 0.03587661969608494, 0.01064539680789624, 0.0323292895087174, 0.030812868914966072, 0.030527568688350062, 0.0064172237346481, 0.02707157949251788, 0.014001049334183335, 0.040403086093387434, 0.03950612725956099, 0.02560551807151309, 0.020072672283276916, 0.049653598107397556, 0.05246090104005166, 0.03273772009249244, 0.006909531848837754, 0.03942557836749724, 0.015739035360249023, 0.011548593923050379, 0.025773597980982492, 0.017802896310708353, 0.03558295652536409, 0.019561282492109706, 0.0740142809227109, 0.0449248468503356, 0.04427030482994659, 0.07586371632558958, 0.09865999594330788, 0.01817932039765375, 0.02895038528367877, 0.4451908426625388, 0.11822199768253736, 10.194822549819946, 61.37187480926514, 79.36869580405099, 62.37733473096575, 63.33658913203648, 46.319321700504844, 20.735875572477067, 24.40468771117074, 20.96015821184431, 34.45118011747088, 60.4157748903547, 46.28043958118984, 33.02321066175188, 15.907026938029698, 3.754063061305455, 0.5759835158075605, 0.04678462312689849, 0.1578783525952271, 0.06976961690400328, 0.05307563341089657, 0.06287188774773053, 0.14411861236606324, 0.04693735118157097, 0.020622881062861, 0.0807537417858839, 0.104329868485885, 0.07683269825897046, 0.15526536852121353, 0.1970186951969351, 0.3020877529467855, 0.11926377963806901, 0.23984367293970926, 0.4738906483565058, 0.17337208906454699, 0.4864344266908509, 0.4033976452691214, 0.016690266817542057, 1.159629374742508, 1.5254335744040353, 0.984818017908505, 1.4552484090839113, 0.4604741654225758, 0.4833365072097097, 0.49526254726307734, 0.22701571056885378, 0.26642604225448197, 0.17050127525414738, 0.026009483894865428, 0.09084577632269689, 0.033901241408394914, 0.05192675148802144, 0.18971244724733488, 0.1285994986870459, 0.055612071949456415, 0.060625821485051086, 0.20904176575796946, 0.1056821480659502, 0.011830740658167218, 0.14554342733962194, 0.0681444305394377, 0.12065793839948517, 0.1208154670894146, 6.25112794978278, 33.18250853674752, 73.10613850184849, 77.45191710335868, 49.46521241324288, 26.390755585261754, 24.828378438949585, 44.916483879089355, 65.37740012577602, 63.944250788007466, 66.58753313337053, 68.16412108285087, 63.54207515716553, 29.75391299383981, 6.9723692025457105, 0.18533470215541975, 0.1273606023085969, 0.10693800103451524, 0.02395217420001115, 0.03961367506001677, 0.014696172837700163, 0.09012893800224576, 0.019973441625812223, 0.03793726947956851, 0.0073404936119914055, 0.07818037737160921, 0.0445804021188191, 0.077083342309509, 0.06844670431954519, 0.018952220977683152, 0.04626445478892752, 0.0599687078169414, 0.0221520174028618, 0.08639679862452404, 0.05285646320719804, 0.027432482090911696, 0.026253792124667337, 0.033374905187104426, 0.028888848942837546, 0.028104509958731275, 0.03964206496519702, 0.05814621025430305, 0.055654877331107855, 0.028370231057384183, 0.07347810933632509, 0.02654559610943709, 0.007396255619823933, 0.03204587560945323, 0.018083931944732155, 0.04480498703196645, 0.015237625122868588, 0.04392247760136213, 0.07070662626730544, 0.049159227670835595, 0.013500339684209653, 0.027722262344988327, 0.028177937625774314, 0.04004285524466208, 0.03382563564394202, 0.027918705018237233, 0.04580018077311771, 0.021131144503929784, 0.09229765805814948, 0.039076417817601135, 0.028303817746096423, 0.057458772856209955, 0.013160497964625912, 0.0404819216845291, 0.04374066414311528, 0.01739729691429862, 0.024594911407413225, 0.09131268983972923, 0.054915942517774444, 0.05441213705177818, 0.029758686731968607, 0.06932020959045206, 0.03219646288614188, 0.0351097869154598, 0.009367073304019868, 0.02367622248961457, 0.013578418708805527, 0.0419416778188731, 0.08330636338463851, 0.03416181242625628, 0.041497407015413046, 0.012598514057961958, 0.016248888269598995, 0.006984338214221809, 0.07290839097861733, 0.08151028797562633, 0.05851976413811956, 0.023472244684983577, 0.07517519327146666, 0.0005331300531647035, 0.06643291416444949, 0.019629319198429585, 0.0047608387540094554, 0.04021543723398021, 0.033386633664901764, 0.08571318816393614, 0.04246856704620378, 0.04118273979318993, 0.02869922893920115, 0.01765356432380421, 0.03164375540135162, 0.050502285959997346, 0.055887221292193444, 0.02736403826358063, 0.06877539346792869, 0.028575491293200424, 0.25012214854359627, 0.057529354068849764, 0.33705711364746094, 0.4217161365917751, 16.645151444843837, 77.88072517939976, 90.57586220332554, 66.52035100119454, 76.86951909746442, 67.07201017652238, 34.47259446552822, 41.20311989103045, 26.294432708195277, 29.396059921809606, 45.29725211007254, 46.87172433308193, 38.71181896754673, 22.889966521944316, 6.093594917229243, 0.6977870655911309, 0.18415414621787413, 0.0915333019303424, 0.044698663987219334, 0.10187897964247636, 0.07105815490441662, 0.08896419193063464, 0.19834790458636625, 0.40537451633385246, 0.19504267908632755, 0.9119398828063692, 0.5423939153552055, 0.830230207315513, 0.7628584653139114, 1.0818284409386771, 1.222646604691233, 2.1436072034495215, 1.7989255275045122, 0.6800290441938809, 1.9581152711595808, 1.9051048585346766, 2.563258639403752, 4.380045814173562, 6.34954570872443, 4.927805747304644, 4.621823149068015, 2.2355108090809415, 2.1991113679749623, 1.774145971451487, 1.2332835367747714, 2.3033760360309055, 1.6686018577643802, 0.6126729899219104, 1.0757178259747369, 0.5953798464366368, 0.7495453368340219, 0.6663273594209126, 0.5996988032545362, 0.4991539184536253, 0.3270298588488783, 0.44788074546626633, 0.044393190914498906, 0.09557278374476091, 0.21205383698855126, 0.10352409458053963, 0.31118473623480114, 0.11751636197524411, 8.417745198522296, 36.26798118863787, 57.22380372456142, 49.08405160903931, 28.652625254222325, 29.718744686671666, 46.76296418053763, 68.46135807037354, 84.27270657675606, 78.16847787584577, 77.44687271118164, 81.86715684618268, 79.57647473471505, 46.53729363850185, 12.827065076146807, 0.7439091535551208, 0.11442513284938675, 0.04382468034912433, 0.04622278595343232, 0.06718052404799632, 0.03602668110813413, 0.0212315948280905, 0.035998722072690725, 0.10296674591622182, 0.015981732069381645, 0.041983855555632284, 0.014350995288363524, 0.039600718433835676, 0.018982568456392204, 0.05002431571483612, 0.04549567800547395, 0.029487578065267632, 0.009968831237139446, 0.04313593337844525, 0.003953473259960967, 0.030482836267245666, 0.046522657719573805, 0.05568326045093792, 0.033714264298656156, 0.004885538647483502, 0.031798305322549174, 0.04279195683609162, 0.036510466398405175, 0.04025814762072904, 0.009945025684178939, 0.07667979717786823, 0.022619049663522413, 0.02053440348910434, 0.0284350854344666, 0.010072590267684842, 0.02046574422690485, 0.03650912629174335, 0.04375147320596235, 0.01672396625924323, 0.060774006747773716, 0.0915605111845902, 0.016874555232269422, 0.05307913125891771, 0.014846514145444547, 0.0626197305641004, 0.05873614217021635, 0.009101956101533557, 0.028580034085150276, 0.06599376630038023, 0.008755705618698682, 0.07126497237810067, 0.0288632172825081, 0.09595979976334743, 0.3671387423362051, 0.07346996013075113, 0.07192896639129945, 0.12043311260640621, 0.18986248491065844, 0.1430786760257823, 0.13999322801828384, 0.19499476094331059, 0.11451636866799422, 0.11520676447876863, 0.10501488351396152, 0.07172486305769, 0.06716856826096773, 0.12363764350967747, 0.18147026880511216, 0.11830059917909758, 0.134443802226867, 0.12283288740686008, 0.10988009494862386, 0.1528176348656416, 0.14372166938015393, 0.1670431758144072, 0.13584096011306557, 0.16372026769178255, 0.14034565910696983, 0.1198881675622293, 0.21975728576736792, 0.16624458080955914, 0.12115405606372015, 0.10424144858760492, 0.08739735279232264, 0.19858246057161263, 0.09121063138757433, 0.1220355001943452, 0.1175251015062843, 0.1622598296297448, 0.17464913268174442, 0.15725148123289856, 0.11581836880317756, 0.12908474622028215, 0.1786023998366935, 0.3037765180425984, 0.31884059256740976, 0.13040756380983762, 0.572333540235247, 0.3707348693694387, 18.30632676397051, 91.36338492802211, 101.12520095280239, 75.65653038024902, 80.55033424922398, 65.79395852770124, 33.12882675443377, 34.74077756064278, 31.39942012514387, 56.81696237836565, 89.91880580357143, 65.45624133518764, 50.88618850708008, 26.691226959228516, 6.330013453960419, 1.2776715606451035, 0.45649567033563343, 0.20290768705308437, 0.18630453225757393, 0.11361939287079231, 0.4450932964682579, 0.36839674626077923, 0.1655750838773591, 0.3415520010249955, 0.13930804335645267, 0.6300157478877476, 0.5684291411723409, 1.3145702949592044, 0.550987534224987, 1.0762733561652047, 1.4872507261378425, 1.3975279863391603, 0.9693558876003537, 0.23671994198645863, 1.035358454499926, 1.486144334077835, 2.036986444677625, 3.6269318716866628, 6.425279336316245, 3.632426593984876, 3.4785470111029486, 1.1259209492376872, 1.1983370291335242, 1.4913706822054726, 0.46887052059173584, 0.9815444392817361, 0.6991796365806034, 0.2197278644889593, 0.760450154542923, 0.3623819404414722, 0.2894083490329129, 0.6123944648674556, 0.8673751684171813, 0.42188031492488726, 0.3207252100110054, 0.4120376487927777, 0.40969048759766985, 0.170457998290658, 0.407765836587974, 0.3449541756084987, 0.5384439730218479, 0.24247201904654503, 10.533238036291939, 56.538092953818186, 104.8570784160069, 105.69844273158482, 69.46737384796143, 40.32218905857631, 37.21938065120152, 60.13660321916853, 88.11983380998883, 84.25616291591099, 85.76955699920654, 94.03821209498814, 90.68732520512172, 51.170300347464426, 12.540437987872533, 0.6791945004037448, 0.4469987042248249, 0.18326447824282305, 0.17237171131585324, 0.13918981541480335, 0.13723552599549294, 0.24649176906262124, 0.16096460127404758, 0.1791473584515708, 0.1005908487630742, 0.23561954817601613, 0.24040360003709793, 0.22981253692081996, 0.17718386809740747, 0.14022365851061686, 0.17024519613810948, 0.1692616596285786, 0.17502645243491444, 0.19720236105578287, 0.1736407210784299, 0.1722328830510378, 0.17395425853984697, 0.10927186972860779, 0.14660909372781003, 0.1116468712155308, 0.1583402313824211, 0.14535141550004482, 0.17230836328651222, 0.14584962305213722, 0.22447081069861138, 0.20418550420020307, 0.0932918611381735, 0.14237380027770996, 0.07653352538389818, 0.06767291655497891, 0.0943678141172443, 0.07180125253008944, 0.10365159809589386, 0.09887215348758868, 0.09912878900234189, 0.1956120649618762, 0.15768488869071007, 0.169086950431977, 0.1356426514685154, 0.14453021170837538, 0.24206259101629257, 0.08345488112952028, 0.2745247648230621, 0.1139123367943934, 0.06376140644507748, 0.23491137474775314, 0.11014576176447527], [0.041541596608502526, 0.043160116366509876, 0.05514299390571458, 0.022548120701685548, 0.037699653301388025, 0.02591781720652112, 0.03700336102130158, 0.019416074301781397, 0.02592233964242041, 0.04483534808137587, 0.04835377946229918, 0.059540497937372754, 0.029930793746773685, 0.040113005587565045, 0.01700276612038059, 0.014554130013233848, 0.07111312302627734, 0.025831319258681366, 0.06745424507451908, 0.11629252907420908, 0.006661596849361169, 0.07973131843443428, 0.04738673135372145, 0.019903482969052026, 0.02524225247491683, 0.005102288601587394, 0.06346482557377645, 0.054481761530041695, 0.042750606912055185, 0.01171441939992032, 0.01465506718627044, 0.023466896132699082, 0.03740586120901363, 0.04720075847581029, 0.03289365761780313, 0.046894712040999105, 0.08573393776480641, 0.02905128344095179, 0.021158847392403653, 0.07665704589869295, 0.04526134593678372, 0.03338719345629215, 0.08843095840087958, 0.30549351019518717, 0.11192348280123302, 6.561306391443525, 40.714383602142334, 67.20367853982108, 67.30648408617292, 70.96534987858364, 76.87874630519322, 39.789936201913015, 26.488839830671036, 35.56417383466448, 45.56132187162127, 65.22601277487618, 41.73969105311802, 23.94513385636466, 12.371187686920166, 2.850837848016194, 0.010193609532767108, 0.15843688191047736, 0.029446238319256475, 0.06726975140294858, 0.09110897327108042, 0.08491483743169478, 0.02401588694192469, 0.05705203182463135, 0.06821241974830627, 0.11821956852717058, 0.09582981959517513, 0.16592790851635592, 0.6425236452903066, 0.48324759198086603, 1.1195531423602785, 0.5518410769956452, 1.1653253776686532, 1.0612610131502151, 2.691579056637628, 2.3189150307859694, 2.661190241575241, 1.3895638308354785, 1.2848905218499047, 4.0722028357642035, 7.8661667960030695, 3.0607748457363675, 5.410088896751404, 4.979716607502528, 2.6969452372619083, 2.4502255618572235, 2.311931222677231, 2.3289011120796204, 1.0704436004161835, 1.6833677568605967, 2.104227202279227, 1.439920465861048, 0.9511823313576835, 0.4758745219026293, 0.2926100572305066, 0.27362483739852905, 0.12675999025149004, 0.10385693636323724, 0.13342609469379696, 0.02198703839842762, 0.0896164472880108, 0.08214359863528184, 0.05435944880758013, 0.16656259660209927, 0.10217262924249683, 0.05594124285770314, 0.060044540890625546, 5.572207306112562, 40.41180344990322, 82.76633017403739, 57.596004826681956, 21.084577866962977, 24.382503850119456, 18.453394072396414, 33.96098470687866, 55.55909872055054, 67.35089002336774, 65.2784230368478, 74.27943216051374, 60.60586370740618, 36.92872013364519, 7.768058231898716, 0.25307773851922577, 0.013460798904166689, 0.027386988014248864, 0.07796406719301428, 0.03098724562940853, 0.04260462688814316, 0.04650176562634962, 0.043121857169483385, 0.03626546775922179, 0.06313876235591513, 0.027769610518589616, 0.017146096465044787, 0.03178417483078582, 0.07020862906106881, 0.024714830597596507, 0.03165183336074863, 0.03621487279555627, 0.07615560173456158, 0.033834158043776236, 0.012697156086297972, 0.02462493658198842, 0.042546883558056185, 0.016638745653576086, 0.08704296073743276, 0.02000269327046616, 0.03443011535065515, 0.026022377756557295, 0.05449864348130567, 0.07032509959701981, 0.05514104651021106, 0.04433508456817695, 0.013371609716809221, 0.01840527425520122, 0.03761334364701595, 0.02763975757573332, 0.025835836605568017, 0.02324253004709525, 0.10075086767652205, 0.011112390052793282, 0.029426750793520893, 0.014305865924273218, 0.05425337003543973, 0.010744615590998104, 0.05905843273337398, 0.04707455435501678, 0.017511811573058367, 0.04763709381222725, 0.00930982784900282, 0.06960288727922098, 0.03836857347882219, 0.045317738982183595, 0.029415473541510955, 0.04424140941617744, 0.03667504167450326, 0.007352853127356086, 0.02147086663171649, 0.02063767651894263, 0.04530917587024825, 0.0821679173303502, 0.04255407602925386, 0.057326852077884335, 0.047269215873841725, 0.051226065693689246, 0.034966751733528714, 0.01585890874931855, 0.03244635037013462, 0.04905662639066577, 0.023290466849825213, 0.017067399973581945, 0.040301190489637, 0.011001517430746129, 0.04809756124658244, 0.07241848869515316, 0.04820389446935483, 0.03963750860254679, 0.01896007332418646, 0.008757075411267579, 0.05825883349669831, 0.03273011710760849, 0.04342711650367294, 0.014661369080256139, 0.024999934049057107, 0.027946781100971357, 0.05310640497399228, 0.03696246571572764, 0.030883602797985077, 0.11455936064677578, 0.024817872925528457, 0.022755055222660303, 0.06383497321179935, 0.03057178881551538, 0.04967544354232294, 0.005552704811894468, 0.3490141491804804, 0.5692220500537327, 10.943147880690438, 53.131571837833945, 83.12086200714111, 77.59948989323208, 78.86654949188232, 97.53544889177594, 57.97266667229788, 37.58019712993077, 27.430418014526367, 37.228896209171836, 43.271299839019775, 41.550832067217144, 31.352530206952775, 17.23278318132673, 4.949398577213287, 0.15783350143049443, 0.3238735853561333, 0.08984559534915856, 0.08131645087684904, 0.09603988046624831, 0.2921045215002128, 0.2838013970426151, 0.6275703619633402, 0.8719071309481348, 1.1091921840395247, 0.7055388667753765, 1.032819539308548, 2.4531967852796828, 1.142941647342273, 4.933075521673475, 5.760508699076516, 4.8650166136877875, 5.538795156138284, 7.197180773530688, 5.911744926656995, 7.3035911321640015, 5.2052512254033765, 6.868105403014591, 7.820766397884913, 11.958624499184744, 11.626000336238317, 11.78669045652662, 8.415287273270742, 7.610344546181815, 6.280414606843676, 5.563619332654135, 6.383200611386981, 4.399387427738734, 5.157557487487793, 6.505581838744027, 5.158056454999106, 3.9004047172410146, 2.272385116134371, 1.5206209697893687, 1.219853428857667, 0.39521394297480583, 0.692389075245176, 0.3955840159739767, 0.14359102424766335, 0.36914427472012384, 0.17870812916329928, 0.08913105726242065, 0.24722493972097123, 0.11006474468324866, 0.24019930671368325, 0.13320405089429446, 8.16142007282802, 41.86636018753052, 64.35799516950334, 45.10712507792881, 20.30855962208339, 36.90602731704712, 41.3383526802063, 54.689621993473594, 72.53586510249546, 75.49984850202287, 73.83461543491909, 87.05864933558873, 80.33448845999581, 55.157263551439556, 17.05667587688991, 0.014464763558602758, 0.03881747189110943, 0.0297333875537983, 0.11048639991453715, 0.06791996436991862, 0.0511792976675289, 0.032248204573988914, 0.05788907262363604, 0.019474431706060256, 0.014467737238321985, 0.031448791934443374, 0.007220039227312165, 0.0304690653990422, 0.007243823576053339, 0.02248080324248544, 0.030793147294649055, 0.028842023241200616, 0.045731621594833474, 0.04690244055486151, 0.05645475476714117, 0.023277732443862727, 0.007795134975042726, 0.0381681613757142, 0.013614514227291303, 0.02452914440073073, 0.0050813104192327175, 0.0056558692761297736, 0.06226824263909033, 0.036689962659563334, 0.025014576834759543, 0.02109998956854854, 0.02422354240635676, 0.03148142946884036, 0.012893349397927523, 0.013490750288058604, 0.013784717951369072, 0.007541581705611731, 0.08581344849829163, 0.016781297379306385, 0.024284442620618, 0.004395580384880304, 0.0232767417827355, 0.0384469374881259, 0.022172483715361783, 0.02983398037031293, 0.021622551438797797, 0.007968329342215188, 0.024753837879481058, 0.012883508943819573, 0.032924503819750886, 0.13223962193088873, 0.1531431959675891, 0.15691665134259633, 0.10240093592022147, 0.09392500216407434, 0.12161297643823282, 0.0920588815850871, 0.19230916005160126, 0.13929901884070464, 0.18931425575699123, 0.12540685571730137, 0.17796404766184942, 0.1158486178943089, 0.20662141777575016, 0.08942136847014938, 0.1386900200907673, 0.11861393308000905, 0.11900229938328266, 0.23247193279010908, 0.22395825891622476, 0.11806742740528924, 0.12841306440532207, 0.13805564413113253, 0.15499015471764974, 0.13457812501915864, 0.2085858987910407, 0.11465583475572722, 0.16026306391826697, 0.17800542472728662, 0.09196614620408841, 0.08029461106551544, 0.11439968778618745, 0.12234883409525667, 0.14196278447551386, 0.11976177005895547, 0.116404921614698, 0.17796484833317144, 0.1246560567191669, 0.15063463843294553, 0.21723841450044087, 0.1593407719795193, 0.1941926646977663, 0.16390539918627056, 0.44131999037095476, 0.42249373772314613, 11.033141817365374, 59.97268826620919, 97.3801497050694, 85.85001713888985, 86.20279802594865, 97.17207200186593, 56.2152726990836, 38.040025438581196, 50.900008474077495, 64.19781139918736, 89.85600103650773, 59.93756512233189, 38.4065637588501, 22.574867452893937, 6.278871238231659, 0.43607901302831514, 0.4032531444515501, 0.16563951756272996, 0.22533071812774452, 0.24454155085342272, 0.24551698565483093, 0.2190714089998177, 0.3534193070871489, 0.4258914068341255, 0.918367400765419, 0.7951584692512239, 0.7943170858280999, 2.4924228404249464, 0.9850642446960721, 2.0226249524525235, 3.9964474950517928, 5.525319993495941, 7.982433608600071, 6.232331769806998, 6.980960215841021, 10.734914711543492, 6.953839225428445, 6.940367536885398, 8.716829538345337, 17.254383393696376, 14.174122759274074, 18.198944091796875, 13.209711926324026, 9.603750586509705, 6.927629317556109, 7.9012534618377686, 6.677774267537253, 3.2240486102444783, 3.604073383978435, 6.38957862343107, 5.522044786385127, 3.348516468490873, 1.893761272941317, 1.1507559823138374, 0.9405117439372199, 0.3427601461963994, 0.4009420541780335, 0.2599837865148272, 0.16607810902808393, 0.37361685186624527, 0.28409816111837116, 0.3530156873166561, 0.5827479128326688, 0.30250494341765133, 0.34864955874426024, 0.13971444512052195, 9.593858088765826, 62.53911658695766, 118.20033645629883, 83.74217687334333, 31.486272607530864, 34.58294575554984, 28.028121164866857, 46.40795986992972, 72.14841965266636, 85.90649209703717, 82.0739699772426, 97.97164985111782, 92.2343555177961, 59.70837879180908, 15.945163863045828, 0.2812160700559616, 0.12312254043562071, 0.12084772464420114, 0.2208282175873007, 0.1473611140889781, 0.15677065774798393, 0.17255700565874577, 0.12009402151618685, 0.13140411462102616, 0.08360565839601414, 0.09700670465826988, 0.12052334419318608, 0.09476353574012007, 0.14511284258748802, 0.09182557410427503, 0.07437486121697084, 0.11017258425376245, 0.18035215165998253, 0.1147873755544424, 0.12374323712927954, 0.0859896233305335, 0.09124907039638076, 0.13227356225252151, 0.163759799141969, 0.11876650846430234, 0.1763923027153526, 0.09526999427803926, 0.10451795839305435, 0.13930158370307513, 0.1370390493954931, 0.12602190699960503, 0.1017931110358664, 0.10081486709948097, 0.14583138403083595, 0.15505054433430943, 0.13196199254265853, 0.07422746984022004, 0.1744712343705552, 0.07198322883674077, 0.14957849867641926, 0.09723471956593649, 0.10060260777494737, 0.14075013383158616, 0.10828726791909762, 0.18396883830428123, 0.11098997467862708, 0.1049618288608534, 0.09538177613701139, 0.15662976673671178, 0.19738811680248805], [0.01703551222038056, 0.03297371117930327, 0.02340268127487174, 0.05357267727543201, 0.026841825838865976, 0.0035127361396527185, 0.061501294507512023, 0.01331799612047949, 0.06540787845317807, 0.0729023316609008, 0.023189527980451072, 0.026952109831784452, 0.06609685612576348, 0.048519630384232314, 0.02566751920884209, 0.009601206901217145, 0.02309979511690991, 0.057778885321957726, 0.04188858245366386, 0.06288438636277403, 0.01891354957063283, 0.059213416916983466, 0.04240672197192907, 0.06475546703274761, 0.04232591862923332, 0.039760425221174955, 0.02013134690267699, 0.032593175170144865, 0.027400216054437414, 0.08147292783749954, 0.020915889447288852, 0.1595676333776542, 0.0073459286774907795, 0.03728711079539997, 0.02310429889309619, 0.0354711509176663, 0.028593614963548522, 0.047182326072028706, 0.11215177590825728, 0.05390813481062651, 0.03496519449566092, 0.27730819689376013, 0.03239688855995025, 9.828642930303301, 38.76073775972639, 66.40858922685895, 76.03619384765625, 68.40078367505754, 68.29123837607247, 58.5118225642613, 22.36337992123195, 26.34320558820452, 47.29075629370553, 34.07360110964094, 73.88217585427421, 50.33692993436541, 17.13565605027335, 3.655105948448181, 0.05057601896779878, 0.13946656270750932, 0.05693081154354981, 0.05588392361200281, 0.07767381705343723, 0.1427530199289322, 0.036290074831673076, 0.09913030213543347, 0.10551216147307839, 0.28337467994008747, 0.3023896467472826, 0.5297048219612667, 0.4001876046614987, 0.8712893926671573, 2.2259214265005927, 1.2478739938565662, 4.01848110130855, 3.9240932975496565, 2.071135320833751, 1.2490390113421848, 6.997108697891235, 6.052206235272544, 4.089930730206626, 8.541965961456299, 5.295907412256513, 4.370086874280657, 6.2144701225417, 7.937893050057547, 9.067532045500618, 7.203767665794917, 6.597126092229571, 5.035613996641977, 2.850955750261034, 4.017487943172455, 9.0954281943185, 7.420199275016785, 6.997694952147348, 4.5489261235509595, 2.9565889963081906, 3.536982446908951, 1.2750913905245918, 0.3861633986234665, 0.5466761227164949, 1.6919479135956084, 0.3609732746013573, 0.26571070349642206, 0.08114987052977085, 0.06418552475848369, 0.06021685485861131, 0.04548703346933637, 0.04432719999126025, 0.05614962774728026, 0.05816333647817373, 0.24888751336506434, 0.09767286998352834, 12.040049569947378, 52.13765287399292, 75.58727073669434, 51.154649530138286, 26.13572543007987, 21.482426507132395, 30.65519162586757, 53.73842402866909, 67.86174937656948, 64.16863591330392, 59.97620405469622, 70.94776398794991, 65.9244248526437, 19.107370683125087, 0.16139192905809197, 0.053391223440745046, 0.04161843391401427, 0.06069382426462003, 0.02559608473841633, 0.06062764674425125, 0.06261426835720028, 0.04766142607799598, 0.032449291819440465, 0.06794750610632555, 0.07449966416295085, 0.05434707572151508, 0.024028422876394222, 0.04472685372456908, 0.013786957116930612, 0.06162793628339257, 0.045610492915979454, 0.045857018258954794, 0.07148813576038394, 0.030980144760438373, 0.008889075069289123, 0.03443801010559712, 0.03292397116976125, 0.009389792352781763, 0.05937230946230037, 0.042717697963650735, 0.009638166703682925, 0.0563965059284653, 0.04004815460315772, 0.014824967265927365, 0.04812163566904409, 0.04004743196336286, 0.04361330990546516, 0.09787058151726212, 0.02948250262332814, 0.0297083869310362, 0.05988766359431403, 0.04203660486798201, 0.06254429104072706, 0.019024629145860672, 0.07339264106537614, 0.04241239113200988, 0.019459461527211324, 0.028267495766548172, 0.017186589738620178, 0.027775654569268227, 0.028346733389688388, 0.06059262076658862, 0.014346104747216617, 0.04953845410740801, 0.12214345511581216, 0.018817212865022675, 0.05315776328955378, 0.06208492283310209, 0.05551807788599815, 0.024290707195177674, 0.05392309311511261, 0.043158956071627994, 0.023489767851840173, 0.019134651902796965, 0.05415014111037765, 0.023337541913081492, 0.0689921582649861, 0.033255554269999266, 0.07936504523136786, 0.06513647801641907, 0.03990783016862614, 0.01806308056360909, 0.024106742780921713, 0.0418042710849217, 0.03659199916624597, 0.0340325277564781, 0.005106337759311178, 0.03065455990976521, 0.05145222480807986, 0.03315058150993926, 0.06486710639936583, 0.04766566352918744, 0.05595505443800773, 0.017785870170752918, 0.028846549069775, 0.025784895589042987, 0.05595925796244826, 0.027966170239129236, 0.04558683918522937, 0.05426872189023665, 0.007910956661882145, 0.0569859900112663, 0.05143219445432935, 0.0699423515637006, 0.19687213163290704, 0.12072275206446648, 18.016147409166607, 51.55491440636771, 83.35184792109898, 87.30618585859025, 79.1146696635655, 74.09139306204659, 79.09313024793352, 38.54918943132673, 26.978111130850657, 38.2664463860648, 31.980807168143137, 48.783979756491526, 41.49021945680891, 21.151223250797816, 4.845465685640063, 0.10154910305781023, 0.17020561040512153, 0.05300630070269108, 0.04370378576485174, 0.10127919539809227, 0.6861597980771745, 0.30714118321027073, 1.2856247510228838, 1.6945673844644, 2.481002390384674, 3.0063876041344235, 2.9555717366082326, 4.248786526066916, 5.288532333714621, 6.861016503402165, 3.526454188993999, 7.099355782781329, 6.6373448712485175, 7.895803468567984, 5.781500509807041, 12.593564782823835, 11.413739817483084, 11.913609726088387, 9.486211385045733, 10.558311479432241, 12.903122663497925, 12.735816989626203, 11.138179472514562, 16.045744248798915, 14.605763094765798, 12.275249566350665, 9.429580960954938, 8.187701633998326, 6.14378913811275, 7.209767435278211, 8.743203163146973, 7.178404135363443, 10.093387535640172, 5.838949952806745, 3.4957340317113057, 5.130961520331247, 2.9145743250846863, 3.341475554874965, 3.842962222439902, 2.058859808104379, 1.0974768698215485, 0.19525522339556897, 0.3218266080532755, 0.11948620341718197, 0.28201964550784653, 0.058273455926350186, 0.10048816605870213, 0.059675553547484536, 0.40843500782336506, 0.2435626962355205, 15.411104474748884, 45.41394363130842, 55.04452208110264, 40.19886200768607, 26.897788218089513, 32.98611422947475, 49.15075431551252, 73.5156444822039, 81.27152252197266, 73.89826788221086, 65.52473667689732, 82.36277185167584, 83.23436777932304, 36.96848120008196, 0.18211167438754014, 0.12559404995824608, 0.07069038892430918, 0.026435729415555085, 0.04056301340460777, 0.03497515878240977, 0.03461365568052445, 0.09179864304938487, 0.03214910453451531, 0.03633316519803234, 0.05282609537243843, 0.004810905308529202, 0.05569392362875598, 0.011198883759789169, 0.01853344273487372, 0.04144942780424442, 0.008522783206509692, 0.026742902218497226, 0.028503101784735918, 0.040437579421060424, 0.015881476824038794, 0.14099230297974177, 0.0667448638539229, 0.020935487234964967, 0.03731583996808954, 0.021019734142880355, 0.024307266842307787, 0.01852186692745558, 0.05967338223542486, 0.038247258202838044, 0.05149056203663349, 0.03360558334471924, 0.02535734897745507, 0.04041343714509692, 0.01302591648085841, 0.025681027144725834, 0.05654301181701677, 0.014579705694424254, 0.028218799004597322, 0.0227821915343936, 0.05640517421332853, 0.05203111356656466, 0.041382873696940284, 0.07191355007567576, 0.07206451054662466, 0.02806961120638464, 0.018493436310174208, 0.0481097816622683, 0.018324057006144097, 0.14976116030343942, 0.260334100574255, 0.16182876990309783, 0.12290059163102082, 0.12240171911461012, 0.18891945694174084, 0.13770955055952072, 0.20935248051370892, 0.19316502341202327, 0.11659891477652959, 0.1050127868407539, 0.1253680842263358, 0.10572923839624439, 0.12491030379065446, 0.10928423263664756, 0.12053226014333111, 0.12178330229861395, 0.1633203662931919, 0.1253967455455235, 0.15020861343613692, 0.08791236765682697, 0.12393371547971453, 0.12918117961713246, 0.10804839645113264, 0.07417167390563659, 0.23436993094427244, 0.10309891096715416, 0.24879789245980127, 0.11644298742924418, 0.2760979618344988, 0.05947153163807733, 0.18006207793951035, 0.08891590737870761, 0.14657162502408028, 0.1145897318742105, 0.15359530385051454, 0.16271158467446054, 0.18231922467904432, 0.2435986857329096, 0.17153372056782246, 0.1588467713445425, 0.31966077855655123, 0.1912397074380091, 17.207182543618337, 57.95204094478062, 93.20827061789376, 99.25241824558803, 83.85361208234514, 86.63495513371059, 73.83689444405692, 30.601916313171387, 38.37890992845808, 68.59304727826799, 49.70681170054844, 100.03546633039201, 67.92180265699113, 27.234812327793666, 7.276957818440028, 0.40011725415076527, 0.24745059332677297, 0.19242974929511547, 0.31368245077984674, 0.18463760241866112, 0.518236114510468, 0.31818398780056406, 0.5849849613649505, 0.5062117683035987, 1.54203434075628, 1.5184156766959598, 2.109889332737241, 4.338464319705963, 4.282843121460505, 7.870062129838126, 9.917676278523036, 11.49233089174543, 11.772354585783821, 10.85689902305603, 12.32330070223127, 21.49308851787022, 23.61148136002677, 17.552191870553152, 21.580152920314244, 18.213102783475602, 17.06031847000122, 20.211837223597936, 22.668609074183873, 22.943293946129934, 24.43866613933018, 22.69441294670105, 15.012917109898158, 13.567913276808602, 14.405767015048436, 22.45214663233076, 22.020790304456437, 18.745743002210343, 15.0697603225708, 11.293685368129186, 9.991241199629647, 8.206480009215218, 6.17700890983854, 3.9743231279509406, 4.034164488315582, 1.4289091995784213, 1.1435803387846266, 0.11788019245224339, 0.326529181429318, 0.16441527754068375, 0.23085482099226542, 0.17336963276777947, 0.30693048451628, 0.16211209898548468, 0.5632319429091045, 0.21154033525713853, 19.300210986818584, 74.43749673025948, 101.75486755371094, 70.20558520725795, 35.73798997061593, 30.312037467956543, 39.98606647763933, 71.37731552124023, 84.40531989506313, 80.05578926631382, 73.8998590196882, 92.51675810132707, 93.99921880449567, 36.715910707201274, 0.17238651694996016, 0.18183766837630952, 0.21659472904035024, 0.30545095247881754, 0.10025859052049262, 0.1964508020984275, 0.1795821636915207, 0.26785384278212276, 0.06024115319762911, 0.07757914106228522, 0.23645938453929766, 0.18192597292363644, 0.18065897162471498, 0.11543350374060017, 0.10735105244176728, 0.16851520325456346, 0.10824061863656555, 0.1056838986862983, 0.1626283284276724, 0.11910083623869078, 0.12643110432795115, 0.1783230198281152, 0.1459417545369693, 0.08085089442985398, 0.10528084209987096, 0.15387498241450104, 0.188740554398724, 0.13628754472093924, 0.13868919227804455, 0.11182084759431225, 0.1322875672153064, 0.08769440863813673, 0.11278581938573293, 0.15530209083642277, 0.11445896460541657, 0.11883452481457166, 0.19588734661894186, 0.13520184797900064, 0.2002452513469117, 0.13101656255977495, 0.16605130689484732, 0.17805281361298902, 0.07605058486972537, 0.16391390801540442, 0.12604439365012304, 0.07929442330662693, 0.1559770024780716, 0.1644042038491794, 0.08814197033643723], [0.043407415239406485, 0.06312575483960764, 0.019363676131303822, 0.012643545882643333, 0.020322915998154452, 0.0395642098571573, 0.012585987453348935, 0.06296562057520662, 0.03480034441288028, 0.02927012455516628, 0.03316286638645189, 0.011422884284651704, 0.01117431400676391, 0.042427268012293747, 0.028398580250463316, 0.03178973542526364, 0.08844689718846764, 0.044285188495580635, 0.03219631700111287, 0.04498748581058212, 0.03505223018250295, 0.06489204934665135, 0.01687043482836868, 0.07402970402368478, 0.02963048093287008, 0.08726152365228959, 0.025506060104817152, 0.03530824823038919, 0.029380627375628268, 0.07332630069660288, 0.044135174580982754, 0.007825323846191168, 0.04704950962747846, 0.04367948742583394, 0.08439438071634088, 0.07397654759032385, 0.027904749249241183, 0.022500494328726615, 0.048212847738925896, 0.06612367861505065, 0.2999994664319924, 4.298060979161944, 35.92913143975394, 73.42308058057512, 81.68848391941616, 71.27777562822614, 54.900829860142295, 55.70322520392281, 50.18884645189558, 26.530977181025914, 66.97388076782227, 57.81869459152222, 32.03468002591814, 34.713432925088064, 17.394945451191493, 4.123568262372698, 0.04268117242359689, 0.18803979057286466, 0.02870289981365204, 0.15481654474777834, 0.06279231594609362, 0.055080422798969915, 0.04836549097672105, 0.08787035955382244, 0.25877610274723595, 0.7197391933628491, 2.0722813393388475, 2.6401193950857436, 3.9945914575031827, 3.073276174919946, 2.1698242766516547, 4.155636370182037, 5.773734160831996, 2.5305552056857517, 17.124000447137014, 10.96957187993186, 7.331727862358093, 6.623215275151389, 10.883067675999232, 7.460784571511405, 9.35528300489698, 4.298698910645076, 10.020969067301069, 9.915729914392744, 12.345857160431997, 12.981146591050283, 13.0498651436397, 7.975650429725647, 9.236320291246686, 9.141841292381287, 4.73195035968508, 7.689469763210841, 8.370156117847987, 10.461779287883214, 8.712671041488647, 6.202752419880458, 3.2214753883225575, 4.0443297028541565, 3.944635646683829, 3.2785821982792447, 2.184205310685294, 1.868404039314815, 2.078388805900301, 0.8386809538517679, 0.4040017585669245, 0.34585499869925634, 0.04960825161210128, 0.07762898624475513, 0.06679580826312304, 0.04399656344737325, 0.00808133341238967, 0.08434576368225472, 0.04680408011855824, 0.1510508789547852, 5.019054268087659, 34.50279481070382, 71.15187426975795, 80.67720140729631, 51.23039531707764, 19.161601373127528, 17.472619363239833, 33.85500383377075, 51.234508650643484, 72.24452018737793, 65.63646371023995, 60.58250386374337, 66.87686307089669, 30.412376403808594, 0.6902300853814397, 0.14979290217161179, 0.00795040583969759, 0.02781762196017163, 0.10095710161009006, 0.07965285943022796, 0.026689686413322176, 0.035429560113698244, 0.0516575325413474, 0.013795936679733651, 0.058280974094356806, 0.03186003504587071, 0.06127066724002361, 0.054893740851964266, 0.013113059885134655, 0.017690200125798583, 0.03251900111458131, 0.05708150738584144, 0.04395651291789753, 0.03014747711962887, 0.006074613592188273, 0.05949495466692107, 0.03518253944015928, 0.04712448435436402, 0.015041542073179568, 0.03340746129729918, 0.022896697711465613, 0.03049206095082419, 0.029825644567608833, 0.032184167831603966, 0.09031039183693272, 0.027266741430919086, 0.02600845761064972, 0.05193935866866793, 0.052522515412420034, 0.06500364800116845, 0.07729559484869242, 0.02676139399409294, 0.03391614543007953, 0.02242817267376397, 0.0732124832325748, 0.024807370899777328, 0.041478581061320643, 0.043053297991199155, 0.037725844753107855, 0.02240714317719851, 0.08758190074669463, 0.022964958334341645, 0.04765039649126785, 0.061681133428854604, 0.021259669214487076, 0.028201993388522948, 0.010390855421844338, 0.04392462516469615, 0.010458110964723995, 0.05257538007572293, 0.0274119207835091, 0.05723081901669502, 0.03295869519934058, 0.014678225586456912, 0.026824718274708306, 0.007021902761022959, 0.05335079971700907, 0.008114657115324267, 0.08926501364580222, 0.01590777514502406, 0.01622894442906337, 0.07472818797188145, 0.05370196194521018, 0.03789779231218355, 0.06543656691376652, 0.0437433681051646, 0.04441787601847734, 0.01734393522409456, 0.049438923198197565, 0.032858875912747214, 0.055048633433346233, 0.019321734185463617, 0.03551948296704462, 0.027260271599516273, 0.04372846408347998, 0.05826405143099172, 0.029763704498431513, 0.037741708901843855, 0.07046958005854062, 0.07830095304442303, 0.09654252563736268, 0.1397695964468377, 0.4886685982346535, 8.124572907175336, 52.765679700034006, 88.23459025791713, 94.85365962982178, 76.91441140856061, 71.35310104915074, 82.02035072871617, 64.39091573442731, 34.13974796022688, 43.56176233291626, 45.28849390574864, 35.074405738285606, 36.45500932421003, 23.65512820652553, 6.810418852737971, 0.11682676683579173, 0.13059908710420132, 0.08079474565706082, 0.11390461506588118, 0.15824906341731548, 0.3796117358974048, 0.5837291830352375, 1.2067245904888426, 1.9631381673472268, 4.437060994761331, 5.771589773041861, 10.480418699128286, 7.086189380713871, 6.072609620434897, 9.135108487946646, 7.486115097999573, 7.771312594413757, 5.960999837943485, 10.587472200393677, 7.003208781991686, 8.144084317343575, 4.735902147633689, 12.724749377795629, 10.672692724636622, 12.19936568396432, 10.539738944598607, 14.137602158955165, 13.822985121182032, 10.143997345651899, 14.063903485025678, 13.976858190127782, 11.888690880366735, 7.399397236960275, 6.71242059128625, 4.831602726663862, 3.254800468683243, 7.034398811204093, 7.3300142628805975, 3.8782273701259067, 4.290127873420715, 2.8727090401308875, 4.353694771017347, 6.145679482391902, 4.437129608222416, 3.0792826754706244, 4.78812871660505, 5.531859985419682, 3.4185653839792525, 2.8463167420455386, 1.535736775824002, 0.5977323002048901, 0.1475507239145892, 0.13115133318517888, 0.2935065919799464, 0.06897810580474989, 0.12706250830420426, 0.08257107569703034, 0.14905954152345657, 5.138016547475543, 33.02341563361031, 51.953650678907124, 45.727463722229004, 43.58449683870588, 28.765655074800762, 30.151766845158168, 56.348657267434255, 73.1264202935355, 89.3037165233067, 75.8099674497332, 67.3586928503854, 79.801242010934, 53.105356284550254, 2.6400232059614996, 0.18177233902471407, 0.017753551547814692, 0.00748610044164317, 0.06446550187787839, 0.005648019898217171, 0.015750935168138573, 0.049707192195845504, 0.060813008940645626, 0.00789148609952203, 0.02426392711432917, 0.005098463360419763, 0.07191165017762355, 0.032894156341041834, 0.022531481326690743, 0.03576097697285669, 0.032482214338545284, 0.03700347637225475, 0.05135393901062863, 0.029185399280062745, 0.03421313342239175, 0.048521839015718014, 0.055886444369597096, 0.013995802562151636, 0.0525049617114876, 0.03575029004631298, 0.04694936464407614, 0.04259855739240136, 0.03159953188151121, 0.042801938086215935, 0.013023043733223208, 0.06731776454086814, 0.022367165590237294, 0.03345324544768248, 0.04490548824625356, 0.03425294646461095, 0.0228570441249758, 0.053577735753996034, 0.03980271830888731, 0.023650046304932663, 0.05927458684891462, 0.030077828892639706, 0.04552403398390327, 0.026468604437208602, 0.032263787130692174, 0.03169631811657122, 0.05812063626945019, 0.02177714037575892, 0.18827951699495316, 0.07165487217051641, 0.09410757558154208, 0.16162394732236862, 0.1111287215192403, 0.14732759445905685, 0.10155883324997765, 0.13551017429147447, 0.12689644364374025, 0.12748884542712144, 0.1830834722412484, 0.16007391549646854, 0.07901069388857909, 0.14486318241272653, 0.1832964372422014, 0.08766390848904848, 0.20635229721665382, 0.10543134116700717, 0.10381652281752654, 0.1343992631882429, 0.10266950008060251, 0.16553946078888007, 0.22402532531746797, 0.18630740924605302, 0.0859716014404382, 0.09479292987712792, 0.20728955763791287, 0.148458793759346, 0.16035505969609531, 0.13859942209507736, 0.13001709404800618, 0.08127711620181799, 0.18363217636942863, 0.1667991474803005, 0.1547277109431369, 0.22817354915397509, 0.29788417422345703, 0.11700477371258394, 0.173164145222732, 0.2071638386696577, 0.5417520212275642, 7.762012430599757, 59.7648537499564, 102.68154185158866, 106.98051043919155, 87.16499846322196, 71.75298377445766, 73.78552641187395, 66.17975725446428, 38.15826293400356, 80.99560260772705, 77.02631214686802, 48.90808847972325, 52.247632435389924, 27.95020580291748, 7.687055264200483, 0.1647572320486818, 0.4704763687082699, 0.17164723947644234, 0.617806188762188, 0.14314377467547143, 0.23158009350299835, 0.40024262028081076, 0.34271102026104927, 1.3146380398954665, 4.417285553046635, 7.0883133581706455, 12.837450895990644, 11.793915714536395, 13.925160118511744, 9.805197971207754, 11.638621738978795, 15.343931027821132, 11.727387581552778, 34.37974568775722, 22.245665277753556, 20.104873180389404, 18.165486778531754, 28.533338580812725, 20.18537848336356, 23.933968101228984, 19.88335939816066, 24.50715626989092, 27.465310130800518, 28.89545089857919, 28.075728484562465, 31.244305065699987, 19.083031143460953, 21.064296075275966, 20.628232342856272, 20.209827457155498, 24.8008896282741, 18.43007070677621, 28.05606508255005, 24.327910116740636, 18.492844206946238, 12.541787675448827, 11.10979347569602, 13.165748936789376, 10.52358785697392, 8.905306373323713, 8.993796025003705, 5.68036687374115, 3.706753211362021, 3.8560183218547275, 1.1699707912547248, 0.36580612670098034, 0.2924365693969386, 0.29273474482553347, 0.24193784913846425, 0.29447377579552786, 0.15889801430915082, 0.2036554597850357, 0.5314460513847215, 7.193830439022609, 49.34702008111136, 94.81472887311662, 105.06487124306815, 66.07217134748186, 26.044771773474558, 28.28506554876055, 46.96986763817923, 67.53979069846017, 91.62253883906773, 82.85020882742745, 77.10322870526994, 92.47021906716483, 58.46494306836809, 1.9802511462143488, 0.3707512356340885, 0.12916572258940764, 0.14284023882022925, 0.25599305065614836, 0.20978563012821333, 0.1858832027230944, 0.13202386136565888, 0.20697344174342497, 0.11467730360371725, 0.10616243550820009, 0.152699651196599, 0.14761077426373959, 0.12630754310105527, 0.0667605787249548, 0.1678391516740833, 0.09280938881316356, 0.11657417538974967, 0.2414663758661066, 0.10428028114672218, 0.143301927617618, 0.10032350596572671, 0.11967202701738902, 0.0954367917563234, 0.12512563009347233, 0.102909626838352, 0.14624610463423388, 0.2013829510126795, 0.2174419750060354, 0.1401776945484536, 0.20030019911272184, 0.14240487718156405, 0.07990678759025675, 0.09846284759363957, 0.1532338753874813, 0.10748279001563787, 0.12677193246781826, 0.1653934129114662, 0.15747588633426599, 0.11592423383678709, 0.21564613708427974, 0.1961999884141343, 0.17126768055771077, 0.10000719329608337, 0.14477390077497276, 0.10988372511097363, 0.1672882762338434, 0.1464208545429366], [0.06835139050547566, 0.05918198038956948, 0.035133121734751124, 0.11849679079438959, 0.04221418426771249, 0.05280413458655987, 0.026722035570336238, 0.03896636961560164, 0.016208846221811006, 0.04506761061825922, 0.014946559044931616, 0.02473729519572641, 0.02751291054300964, 0.02183003387680011, 0.018519614191193665, 0.03350757235395057, 0.03534298922334399, 0.02867848951635616, 0.05092122365853616, 0.028766163026115725, 0.044527133727180104, 0.02839013248948114, 0.029325299630207673, 0.0375724008439907, 0.05734800879976579, 0.029443262943199704, 0.036747902764805725, 0.05418944525133286, 0.06949542768831764, 0.05503800418227911, 0.03365882120228239, 0.039824329649231265, 0.02319594522538994, 0.029504721252513782, 0.05243477065648351, 0.04648409318178892, 0.05244806655017393, 0.13589744136801787, 0.16157365430678639, 1.5518714700426375, 22.895071710859025, 66.50081961495536, 72.55723081316266, 77.44894327436174, 62.63579382215227, 42.208371366773335, 28.44942171233041, 19.960498298917496, 19.301148993628367, 39.23017195292881, 62.512963567461284, 40.40578283582415, 21.572089535849436, 6.533169226987021, 0.5018056333065033, 0.11397796470139708, 0.15320412841226372, 0.12180835381150246, 0.04584715235978365, 0.06044485619557755, 0.12753402228866303, 0.19470105027513845, 0.7143817522696086, 3.098538087947028, 1.2431485674210956, 5.252894154616764, 10.068822179521833, 7.53613691670554, 8.547534942626953, 6.084194004535675, 8.98994151183537, 9.360407301357814, 5.465659286294665, 1.6332792788743973, 4.965758979320526, 3.870758490903037, 9.221803767340523, 2.856948788676943, 11.325018269675118, 5.906460387366159, 12.697362184524536, 7.568261912890843, 7.401229824338641, 14.983512333461217, 8.570873941693987, 9.007493530000959, 14.993891205106463, 13.760476521083287, 6.147215468542917, 5.944690244538443, 6.555673139435904, 4.937420317104884, 10.912143281527928, 7.6042744261877875, 11.178116849490575, 15.118913616452899, 10.117765290396553, 5.880513642515455, 4.826578744820186, 1.7232690900564194, 2.311449625662395, 4.425402351788112, 4.929283542292459, 2.160871522767203, 0.9072736789073262, 0.650509948176997, 0.21652929112315178, 0.2987589144280979, 0.2122372585747923, 0.05825664861393826, 0.034149978775531054, 0.08016797607498509, 0.038400325525019846, 0.04939225355961493, 0.07681086978742055, 1.9515288131577628, 22.76909565925598, 57.87247364861624, 73.45313153948102, 66.7429643358503, 34.88870818274361, 13.590361169406346, 14.576108183179583, 21.021121706281388, 51.001469544001985, 73.84185545785087, 59.763999121529714, 67.48276683262416, 50.00032445362636, 4.627230150359018, 0.6765244379639626, 0.05243609719244497, 0.03698415169492364, 0.05257628931264792, 0.08040306131754603, 0.04118664136954716, 0.01186486503242382, 0.06563108254756246, 0.035481454471924474, 0.052975013452981196, 0.03480925697035023, 0.06562123700444188, 0.015680805181286166, 0.06617481979940619, 0.04169449768960476, 0.033481520001909564, 0.02002258282820029, 0.06066189240664244, 0.017563846727300967, 0.031585750835282464, 0.02590352386635329, 0.043093178886920214, 0.06051700482411044, 0.07231255580804177, 0.04047061389844332, 0.01772078509176416, 0.0449258476894881, 0.04027476155066064, 0.028034507197194865, 0.04276745493656822, 0.036321222981704135, 0.047661443041371446, 0.085127083185528, 0.00992322774670486, 0.01539884165062436, 0.042003197196338854, 0.04371376022962587, 0.03759396468688335, 0.025871030520647764, 0.050926122681370804, 0.009558195414553796, 0.04640837206638285, 0.013664691891920353, 0.04487354281757559, 0.0278099324620728, 0.020065333927050233, 0.04899690852367452, 0.0738474088055747, 0.041143771527068954, 0.08882469191615071, 0.043106742801942995, 0.021530757525137494, 0.028515498619526625, 0.024089928683159605, 0.012151099941028016, 0.04102164879441261, 0.013006199949554034, 0.0518832472153008, 0.024041854477088367, 0.014437074240829264, 0.0038864187330805828, 0.054822932330093214, 0.01993684483958142, 0.04906680441594549, 0.04235944504450474, 0.021256914362311363, 0.04202671522008521, 0.00873304933442601, 0.03014780960178801, 0.006548802700958082, 0.05198523781395384, 0.02664026022622628, 0.039778457289295535, 0.0436562136746943, 0.0075494289631024, 0.03373585867562464, 0.03272934018501213, 0.05775000687156405, 0.03707291425338813, 0.016802016446100812, 0.03827200437496815, 0.06315700816256659, 0.011518040339329412, 0.00435844246697213, 0.13305832871368953, 3.3929536725793565, 32.77654961177281, 79.41276822771344, 85.16553619929722, 86.9970257622855, 80.17005239214215, 72.90232004438127, 46.38458265577044, 29.617339202335902, 32.3503714288984, 36.028191907065256, 60.96451582227434, 47.01287351335798, 25.048985481262207, 10.411869508879525, 0.3443116300872394, 0.13257230765053205, 0.10566810239106417, 0.16785961629024573, 0.07428885690335717, 0.1403454691171646, 0.5371865662080901, 1.3456648950065886, 3.3601560039179663, 6.564095224652972, 8.05259564944676, 8.848419734409877, 11.817431892667498, 10.498517887932913, 6.65520521572658, 8.39800797189985, 9.004935724394661, 9.44305612359728, 5.898479078497205, 4.225960825170789, 3.536946620259966, 4.09639081784657, 4.606844569955554, 7.203236997127533, 6.98567977973393, 9.565894195011683, 12.435458523886544, 11.06606846196311, 6.968009642192295, 7.2267449242728095, 10.480613248688833, 5.744464440005166, 4.384352394512721, 1.4992803377764565, 1.1227063217333384, 1.4675710392849786, 3.508103996515274, 5.786857136658259, 9.228883113179888, 10.528255309377398, 13.006365077836172, 14.317159243992396, 9.754957284246172, 7.7107486213956555, 5.771415633814676, 3.7381872960499356, 1.4781675849642073, 5.117836373192923, 7.546610457556588, 5.740232987063272, 6.0111241425786694, 3.7245132412229265, 2.1562390284878865, 2.2574143537453244, 0.8054298066667148, 0.21304455239857945, 0.3281235487333366, 0.034529839642345905, 0.11429994313844613, 0.04791702004149556, 0.2322134923722063, 1.5656915456056595, 23.61496935571943, 52.43018593106951, 45.91139643532889, 36.25808695384434, 31.911099365779332, 28.06525754928589, 23.894962651388987, 32.21627467019217, 71.02861322675432, 83.4000962121146, 69.84398705618722, 77.93091201782227, 71.14794853755406, 13.370743376868111, 0.08757043350487947, 0.07385046221315861, 0.05575893746156778, 0.07685268790061985, 0.023010908725804517, 0.03663392923772335, 0.02658409788273275, 0.03253936055781586, 0.0303438078345997, 0.03752568031528166, 0.018960144570363418, 0.04875234075422798, 0.03015131762783442, 0.012051194989388543, 0.06506456008979253, 0.011624978306437177, 0.035512287103171856, 0.047323899010994604, 0.030542513422135795, 0.04832192563584872, 0.011252358256440078, 0.043819221534899304, 0.007097031854625259, 0.0742223672568798, 0.05176484963989683, 0.024478184724492685, 0.019046891879822527, 0.05550900587279882, 0.015581365874303239, 0.014807630696200898, 0.0949661870087896, 0.04963005294225045, 0.018010967377839342, 0.013238510832057467, 0.027646463198055114, 0.07216314918228559, 0.04621454853830593, 0.041324082030249495, 0.03301509842276573, 0.027421903729970967, 0.03427609468677214, 0.016308409361434833, 0.016737082341153706, 0.037747992136116536, 0.0469526996436928, 0.0472066278037216, 0.11106662877968379, 0.23911028515015328, 0.15940103945987566, 0.21538217339132512, 0.149233735033444, 0.08236731841628041, 0.10026883639927421, 0.10842391808650323, 0.12377700103180748, 0.1877223854618413, 0.10860860174787895, 0.19466149168355124, 0.05380586261994072, 0.28418295085430145, 0.08549516129174403, 0.10542433868561472, 0.25913502063070026, 0.14055654779076576, 0.12138597933309418, 0.06780576692628008, 0.34061309854899136, 0.08215611082102571, 0.1194430078778948, 0.14517627204103128, 0.11173262447118759, 0.13947322592139244, 0.10500694465424333, 0.16789776352899416, 0.161306677918349, 0.10420727077871561, 0.13253292547804968, 0.10328607806669814, 0.09710163170737879, 0.0773106108286551, 0.17500296155256884, 0.11404573677905969, 0.15434062028569834, 0.2198225065533604, 0.33380554669669693, 3.860585459641048, 41.35328435897827, 95.97016566140312, 94.35008893694196, 95.51985985892159, 75.56444590432304, 60.554057938711985, 43.510161536080496, 27.570947068078176, 32.74620335442679, 54.65692377090454, 78.32571560995919, 55.514195987156455, 34.47777434757778, 11.975895983832222, 0.8505035851682935, 0.21594272474093096, 0.23287031427025795, 0.41188622691801613, 0.17918366007506847, 0.20522807325635636, 0.30380246522171156, 0.6869781113096646, 2.2973326231752123, 7.664447563035147, 10.24094990321568, 15.7983466897692, 24.642748628343853, 20.391158069883073, 19.157543625150407, 18.504906279700144, 25.08446298326765, 24.77515697479248, 14.900420563561575, 7.762800182615008, 11.544173138482229, 11.553078992026192, 23.38223249571664, 12.993344153676714, 24.908373049327306, 19.66305981363569, 24.57304082598005, 18.879283905029297, 22.742230449404033, 28.94131943157741, 26.850001982280187, 21.285181045532227, 35.50490917478289, 34.20481436593192, 16.939864499228342, 20.32865728650774, 14.563360844339643, 12.691365020615713, 18.777892317090714, 14.203292165483747, 18.22830891609192, 26.162427357264928, 17.824896505900792, 13.962511897087097, 13.919759631156921, 11.345182810510908, 12.345693009240286, 12.495510935783386, 15.720582451139178, 7.8550965785980225, 6.22797828912735, 4.492547571659088, 2.861777569566454, 2.1696668565273285, 0.5110911407641002, 0.2507274289216314, 0.36199042573571205, 0.2058919926307031, 0.3392665593751839, 0.12372946286840097, 0.33760987541505266, 3.017952880689076, 34.7129430770874, 82.91507720947266, 98.19121292659214, 87.6317367553711, 50.073798179626465, 20.36556438037327, 23.905871323176793, 31.538543905530656, 65.4248354775565, 90.21283967154366, 78.30385657719204, 89.90299170357841, 75.94611740112305, 11.574628829956055, 0.7168996600168092, 0.1354164414639984, 0.13369199899690493, 0.19360334346336977, 0.14676732809415885, 0.07722644534494195, 0.12010628942932401, 0.1808649341442755, 0.10022845678031445, 0.17285511323383876, 0.07477343268692493, 0.17582192617867673, 0.10679940347160612, 0.2070230155118874, 0.17306942173412868, 0.09452441999954836, 0.07782310154289007, 0.1443796990705388, 0.10786192145730768, 0.09047661256045103, 0.09060818050056696, 0.11932895971196038, 0.08699986697839839, 0.1627189807061638, 0.22279105654784612, 0.12467288438762937, 0.09522108547389507, 0.15537510120442935, 0.10736750691596951, 0.12743456262562955, 0.1770207482789244, 0.25762986711093355, 0.1267976625157254, 0.05007621346573744, 0.10771432652005128, 0.12145694052534443, 0.07858463496501956, 0.17920461323644432, 0.09960748188729797, 0.11017930175044707, 0.08301352802664042, 0.18721037650746958, 0.08955212216824293, 0.14177960716187954, 0.12244275691253798, 0.10833475179970264], [0.028164543344506195, 0.010927809868007898, 0.0752569092437625, 0.02194578686196889, 0.014174634707160294, 0.04061604091631515, 0.04390947687040482, 0.03449703247419425, 0.020936628870133842, 0.039796957546578984, 0.060348443154777796, 0.03395718662068248, 0.03266830596008471, 0.037117225982780964, 0.07782683348549263, 0.03313124665458288, 0.028447373703654324, 0.02018531927439783, 0.07328691173877035, 0.0498244667957936, 0.026740927681592957, 0.0035142418512675378, 0.009790715794744236, 0.031190772208252122, 0.057373073883354664, 0.08120575467390673, 0.013658322144432791, 0.05991677274661405, 0.06121515629014798, 0.008418293902650476, 0.02100516769236752, 0.01090757001657039, 0.06675472296774387, 0.06377181517226355, 0.02174629587014871, 0.033099511571760686, 0.02974592348826783, 0.37379769501941545, 4.419125088623591, 40.74003635134016, 17.3173896585192, 59.20654514857701, 80.34101281847272, 49.792507307870046, 38.724426473890034, 20.85600471496582, 25.441312040601456, 49.73306894302368, 42.41293675558907, 42.36838838032314, 22.884941237313406, 12.163924660001483, 2.4002849502222876, 0.0204285197957818, 0.025433455161484222, 0.03386957757174969, 0.07890927325934172, 0.14234023993568762, 0.16477388329803944, 0.08898298735065119, 0.6851571404508182, 3.0792974403926303, 3.388429092509406, 9.46838925565992, 4.7787230270249506, 5.282041413443429, 5.6009789279529025, 8.325544340269905, 4.576520025730133, 2.504788028342383, 9.159051980291094, 5.9797473805291315, 6.101613138403211, 6.964597642421722, 9.111653975078038, 7.799108862876892, 5.7687544737543375, 4.846662512847355, 7.186295986175537, 7.164988032409123, 8.037148066929408, 7.722103714942932, 8.919653534889221, 5.464993562017169, 4.454424108777728, 4.007355298314776, 7.112614682742527, 10.572596107210432, 6.2529188479696, 8.475954600742885, 11.97707109791892, 22.71219686099461, 30.050920690808976, 37.09923587526594, 41.40528467723301, 36.25186136790684, 37.158226081303184, 28.69437871660505, 22.894081592559814, 13.027239203453064, 5.79554238489696, 7.226060092449188, 9.000415921211243, 4.337924097265516, 4.0221076267106195, 2.6726912472929274, 2.2867112159729004, 2.0802239988531386, 0.43141142491783413, 0.6375733794910567, 0.31635644872273716, 0.11899422481656075, 0.057429460143404346, 0.06787844481212751, 0.12701210672301905, 0.1196541679756982, 0.5273097561938422, 9.70937102181571, 50.20818676267351, 69.44046347481864, 59.06810923985073, 46.24874537331717, 91.47459779466901, 121.10806029183524, 28.40184392247881, 60.18983336857387, 63.828090803963796, 64.27462373461042, 69.01990985870361, 60.25787707737514, 19.380742345537456, 0.28840653278997963, 0.06560331010924918, 0.08759444007383925, 0.08712763512240988, 0.027757875255442092, 0.05549532999949796, 0.07765694188752345, 0.03727297351828643, 0.014819610231955136, 0.024301556970125864, 0.023516936393986856, 0.05012808746791311, 0.04935614192592246, 0.04319476575723716, 0.06708055548369884, 0.05415938615000673, 0.07359923462250403, 0.037372904763157876, 0.06113545556685754, 0.022749847466392175, 0.028529639289315258, 0.041149891912937164, 0.03501272587371724, 0.03391005897096225, 0.04416892152013523, 0.00840871553269348, 0.11580900501992021, 0.07013211066701583, 0.016501886836652244, 0.024386953994897858, 0.010702731320634484, 0.016109956528193185, 0.0543328061300729, 0.03558266814798117, 0.025465504066752534, 0.040930338336953094, 0.024574389115774205, 0.024737790526290025, 0.007323510728643409, 0.06890012177505664, 0.008499537444939571, 0.02426364891497152, 0.0035662290839744465, 0.03744005598127842, 0.02365566966389971, 0.022483651393226216, 0.014685775984876921, 0.051165428411747725, 0.02664687085364546, 0.06016300631953137, 0.05176004221928971, 0.07203183908547674, 0.04480278518583093, 0.034637387442801676, 0.05516388260626367, 0.045644599478691816, 0.02989283649783049, 0.011584770017569619, 0.030035837753010646, 0.02017293092129486, 0.05754297226667404, 0.018884416669607162, 0.02191153950324016, 0.03293627640232444, 0.02295108907856047, 0.015121736430696078, 0.04546802431078894, 0.029132670323763574, 0.04184344969689846, 0.018346928725285188, 0.042712873579668145, 0.030431718831615787, 0.027673214441165328, 0.05047223025134631, 0.04410906116079007, 0.04359976973916803, 0.013559798011556268, 0.12021305012915816, 0.03828849277592131, 0.07638834603130817, 0.058641133696905205, 0.05252581309261067, 0.149528422792043, 10.257762806756155, 58.81809220995222, 22.74285752432687, 67.55703612736293, 94.03860814230782, 71.12087835584367, 59.461252212524414, 30.803782326834543, 30.730339867728098, 30.564576693943568, 34.51075744628906, 39.766364438193186, 29.556924615587505, 16.61333043234689, 3.9188708577837263, 0.07018019844378744, 0.08096199096845728, 0.16060058080724307, 0.1381574108132294, 0.23685491617236817, 0.9605549084288734, 2.326723720346178, 2.773778200149536, 6.163631890501295, 6.185857440744128, 10.790160707065038, 9.070827228682381, 7.618325420788356, 5.609729749815805, 6.09506402696882, 3.928565331867763, 2.031537102801459, 3.244592045034681, 3.6621166808264594, 4.460350922175816, 6.251949140003749, 7.654122539928981, 7.636757254600525, 6.104723760059901, 8.0755455493927, 7.747342177799769, 5.6240096007074625, 9.933010952813284, 9.698385919843401, 8.02931136744363, 5.997219494410923, 0.9668294574533189, 1.6192607453891208, 1.5258168109825678, 5.496190539428166, 5.7754833698272705, 7.6907265186309814, 13.588472127914429, 25.895691224506923, 32.52647352218628, 39.51397112437657, 42.51164633887154, 39.5903457232884, 40.7281618799482, 33.59825052533831, 26.587337493896484, 15.40095315660749, 7.312809654644557, 5.973449272768838, 6.31408384016582, 4.068709628922599, 5.7953864846910745, 6.026814477784293, 4.713475099631718, 4.100824637072427, 2.482527954237802, 2.3217205830982754, 1.1052119519029344, 0.42629597655364443, 0.12619604622679098, 0.09761697226869208, 0.1079166792333126, 0.016481050722567097, 0.3828106756721224, 10.757049066679818, 47.65383093697684, 53.95064285823277, 44.9474971635001, 27.998855352401733, 64.068039894104, 106.61317307608468, 40.02777303968157, 74.19986139025006, 78.13107572283063, 73.8216084071568, 77.4102418082101, 80.03008787972587, 37.16417721339634, 1.5661120201860155, 0.5103412781442914, 0.08193757504756961, 0.03827578042234693, 0.03775754251650401, 0.04900147167167493, 0.12325850528265749, 0.06925752652542931, 0.016302497625084858, 0.030861920211464167, 0.020020094301019396, 0.07473099032150847, 0.024385832715779543, 0.03342052309640816, 0.01333262279097523, 0.03940921549552253, 0.040002794537161074, 0.03377813140728644, 0.009948568485145057, 0.012597486925577479, 0.04125869839585253, 0.046591128688305616, 0.05289672747520464, 0.06804962562663214, 0.014770190830209425, 0.0056085732649080455, 0.03467002158452358, 0.04127942764067224, 0.026263166085949967, 0.006437259177411241, 0.014762626861089041, 0.01983494753949344, 0.012389074046430843, 0.009422792055244957, 0.05760788771190813, 0.023086475474493842, 0.021591944420444112, 0.03934504983148404, 0.05772980688405888, 0.08054964523762465, 0.03868672837104116, 0.018887176610795513, 0.024987996921741536, 0.023680780548602343, 0.041733957893614254, 0.1281982809305191, 0.07869689858385495, 0.1898046058735677, 0.08054171994860683, 0.13533813852284635, 0.14460044008280548, 0.09542237288717713, 0.12347731925547123, 0.08494486260626997, 0.13437616585620812, 0.26583522824304445, 0.10685621042336736, 0.19264120794832706, 0.16356368895087922, 0.1634488401136228, 0.11060886870005301, 0.09611487215650932, 0.08011128447417702, 0.18421632716698305, 0.21170382148453168, 0.13454246121857846, 0.13154245434062822, 0.08882435264864139, 0.1322601136884519, 0.10268731162484203, 0.18860563449561596, 0.1945471449622086, 0.07453583686479501, 0.16223008265452726, 0.16097860623683247, 0.10352317855826446, 0.08214952224599463, 0.15707989329738276, 0.1721822643386466, 0.18556073574083193, 0.11631106665091855, 0.1781561952084303, 0.2623042677130018, 12.986292600631714, 70.92637743268693, 35.4574008669172, 74.52785805293492, 99.58164473942348, 66.6099271774292, 50.96015902927944, 25.64113007272993, 36.099879946027485, 69.36848708561489, 57.2676294871739, 59.39554309844971, 38.65914814812796, 22.434395721980504, 4.835444646222251, 0.18479537538119725, 0.1419971590595586, 0.3574094186936106, 0.19393194440220082, 0.3061699553259781, 1.081173138959067, 1.8593153612954276, 2.3259342312812805, 9.514368091310773, 10.573363014629908, 22.345019306455338, 15.288112674440656, 20.049671479633876, 20.520639487675258, 25.6718966960907, 16.58505126408168, 11.982512405940465, 24.190909011023386, 16.061478444508143, 14.162666916847229, 12.877979738371712, 17.29222502027239, 16.249950068337576, 14.363812054906573, 14.915883779525757, 17.267954962594168, 21.083351509911672, 21.889686482293264, 21.75189675603594, 21.12008489881243, 18.25214297430856, 17.311134542737687, 12.990263496126447, 12.62820850099836, 20.362034695489065, 10.577425105231148, 12.702568122318812, 18.06469620977129, 30.332989760807582, 37.38614089148385, 45.131867613111226, 50.001887798309326, 42.713870184762136, 46.55565077917916, 37.44209820883614, 32.14332553318569, 21.471997261047363, 14.501811095646449, 15.668389320373535, 19.32580120222909, 16.56575264249529, 14.875999382564, 11.032630256244115, 8.232104097093854, 5.117650943143027, 3.3425959518977573, 3.95474397284644, 1.459098145365715, 0.4564568581325667, 0.25192146056464737, 0.14768716373613902, 0.26368402796132223, 0.21594110982758657, 0.9898959568568638, 14.391980051994324, 70.16705049787248, 98.47300406864711, 78.63633482796806, 61.095753397260395, 105.30781500680106, 130.46033559526717, 35.296744619097026, 75.20720427376884, 81.36050115312848, 80.76537404741559, 87.51916898999895, 90.91307912554059, 33.908643926892964, 1.119062208703586, 0.6530234590172768, 0.21201435982116631, 0.18816032553357737, 0.13942977253879818, 0.13587682747415133, 0.3767220452427864, 0.14866896319602216, 0.07060020483498063, 0.09062344075313636, 0.0962826127984694, 0.16564675074602875, 0.12473768448191029, 0.09001839786235775, 0.17486369902534143, 0.11301205653165068, 0.1642319509493453, 0.15507674935672963, 0.09167965514851467, 0.06320331817758934, 0.15364641110811914, 0.22918030513184412, 0.20529667314674171, 0.17913351633719035, 0.1644090214478118, 0.12473076342472009, 0.23696014338306018, 0.12345891738576548, 0.07837134426725761, 0.09724476866956268, 0.1007490356319717, 0.1288871703935521, 0.13282890245318413, 0.07687604986131191, 0.18989793158003263, 0.12461793662181922, 0.0973083677568606, 0.13372530149562017, 0.17877881894154207, 0.1341477981103318, 0.17745533638766833, 0.13368152241621697, 0.16518419342381613, 0.11161975017083542, 0.10523776191153697], [0.06268518883734941, 0.007186973367684654, 0.06485676552568163, 0.051935962600899596, 0.04151494036029492, 0.0256998446171305, 0.04018927292366113, 0.06778079005224363, 0.030295899869608026, 0.012889491078177733, 0.027709091980276362, 0.09624513052403927, 0.07201511998261724, 0.062102205120027065, 0.09806662385485002, 0.06657352019101381, 0.035744220550571165, 0.09631949796208314, 0.03651172508086477, 0.007791722792067698, 0.032802320018942864, 0.030609308409371545, 0.04708662210032344, 0.01192881102075002, 0.04230951165248241, 0.08453305291810206, 0.024932645427595292, 0.07004882727882691, 0.011510489940909403, 0.0669383006170392, 0.05864954074578626, 0.03511903534776398, 0.05012155656835862, 0.06602563030485596, 0.04366186247872455, 0.012907807282837374, 0.11467391092862401, 16.927571398871287, 63.07712255205427, 85.58214323861259, 26.477552482060023, 24.040662901742117, 38.884773526872905, 27.963506392070226, 18.434814589364187, 75.41257912772042, 62.00953183855329, 54.74583292007446, 42.16848175866263, 26.34491831915719, 9.436301606042043, 1.5774236874920982, 0.0370644461363554, 0.06478340231946536, 0.09112793832485165, 0.11767718834536416, 0.17502992653420993, 0.6393714430076736, 1.6434245173420226, 1.2562421219689506, 2.7204173377582004, 4.860300958156586, 6.773710216794695, 7.186740670885358, 8.43139840875353, 5.614951755319323, 7.641171966280256, 9.441307783126831, 6.6063693676676065, 7.7232354027884345, 10.592224768229894, 17.416088819503784, 17.66272381373814, 23.804092373166764, 18.652225460324967, 24.64445788519723, 17.71463554246085, 20.501186268670217, 11.572412354605538, 10.111212270600454, 6.662169047764369, 5.788087836333683, 0.803992723780019, 4.974843314715794, 9.002509066036769, 18.25670620373317, 38.90757404054914, 50.63199213572911, 71.49665778023856, 47.97630378178188, 47.373446805136545, 61.06088038853237, 60.08784076145717, 70.00474752698625, 75.07582773481096, 76.2906299318586, 74.60591411590576, 70.75674411228725, 64.62755053383964, 53.51869419642857, 29.255431856427872, 19.80669297490801, 13.906238436698914, 8.514958313533239, 10.275295717375618, 5.174613577978952, 3.042941859790257, 4.108011245727539, 2.3502262192113057, 0.9751542678901127, 2.3224414587020874, 1.0005098730325699, 0.14394920931330749, 0.13981003713394913, 0.10745670712952103, 0.0517438795151455, 0.07807690078126532, 0.36936002171465326, 4.239011279174259, 21.040621825626918, 52.32085950034005, 83.26850427900041, 88.99350724901471, 88.82260240827287, 32.62169163567679, 16.59923948560442, 34.632931096213206, 64.2556482042585, 69.04546533312116, 63.10549899509975, 71.5628741128104, 35.65121739251273, 1.7673770146710532, 0.490378669330052, 0.12939580024353095, 0.03300028261063354, 0.0289740661558296, 0.06933188039277281, 0.017964538619188324, 0.036154744414878745, 0.08433483248310429, 0.05488564932186689, 0.09337101224809885, 0.03936933120712638, 0.020439286450190202, 0.0672435870926295, 0.05777032221002238, 0.04073881504258939, 0.0558809685919966, 0.027271531888150742, 0.11070756840386561, 0.047077299029167206, 0.0529297314185117, 0.06073829544974225, 0.038488548648144515, 0.023413356327052628, 0.01717413862102798, 0.07956776435353927, 0.07102884219161101, 0.03122427487479789, 0.03740429040044546, 0.017674892375777875, 0.016901365847193768, 0.03666865326730268, 0.022053539919267808, 0.054688724888754744, 0.03931154377226319, 0.0184228296524712, 0.025614506964172636, 0.031302140160862885, 0.022763903319303478, 0.038806432126356025, 0.08837298436888627, 0.07556268426456622, 0.04711993816973908, 0.003249609165192981, 0.08568836056760379, 0.004053519007616809, 0.03543026579011764, 0.02730510410453592, 0.012760907843975084, 0.03470395172813109, 0.020205605775117874, 0.022827919705637863, 0.0247674730406808, 0.008622690702655485, 0.00866452238655516, 0.034745220227965286, 0.018827657215297222, 0.05400478194600769, 0.04910949105396867, 0.028460045345127583, 0.030981186311692, 0.05157627458018916, 0.08137643337249756, 0.05136663779350264, 0.013520325933183943, 0.056080678411360295, 0.02338923779981477, 0.08974616282752582, 0.01936380674929491, 0.02698184153996408, 0.013485884343806123, 0.03457978999774371, 0.026617213784317886, 0.05009757714079959, 0.06813611848545925, 0.017821084441883222, 0.04204174816342337, 0.08975384384393692, 0.05413593937243734, 0.017025987285056284, 0.07871540223381349, 26.93717929295131, 80.49907738821847, 94.94655009678432, 33.3867404120309, 31.772083282470703, 64.31442996433803, 46.16138914653233, 29.252916608537944, 51.153996399470735, 48.506107398441856, 49.082505634852815, 40.60210766111101, 27.860412495476858, 11.933839406285967, 1.9235199732439858, 0.1115961167961359, 0.22085313339318546, 0.046125975969646654, 0.2719108850828239, 1.1719169382538115, 3.28999439733369, 6.175123342445918, 4.44695566381727, 3.926599860191345, 4.927451823438917, 6.301012975828988, 9.269546576908656, 5.1280098387173245, 2.8853766918182373, 1.6486287180866515, 2.385813589606966, 4.30437776020595, 8.170919128826686, 10.606590168816702, 15.774540424346924, 17.712634461266653, 23.413603612354823, 22.014543873923166, 25.896389518465313, 18.828633274350846, 17.452942064830236, 9.38046327659062, 8.257062026432582, 6.333349023546491, 3.6575352123805454, 2.1079188670430864, 1.9121789932250977, 8.90574584688459, 19.479109730039323, 40.36956187656948, 53.45308583123343, 70.96305002485002, 50.688929149082725, 53.62602302006313, 67.00891358511788, 64.10981941223145, 73.05005959102085, 79.73586641039167, 82.05505698067802, 80.41738046918596, 78.95352009364537, 71.89499105725969, 60.14703941345215, 37.08644424165998, 19.420459985733032, 11.852876390729632, 6.088409389768328, 1.988419839314052, 3.771961186613355, 3.9494151387895857, 4.541558427470071, 2.6332126685551236, 2.6707791898931776, 3.9929816467421393, 2.1965856977871487, 0.39196867282901493, 0.44579837577683584, 0.2644293036844049, 0.022345121683818952, 0.12811275837676867, 0.07478280325553247, 5.034418906484332, 21.18887553896223, 53.00333588463919, 57.77450404848371, 92.16747215815953, 101.10447447640556, 32.11931603295462, 34.50908293042864, 48.77261945179531, 75.13113539559501, 76.50069481985909, 71.42304856436593, 81.63452420915876, 58.98687090192522, 9.396355543817792, 0.46313369699886864, 0.06798724111701761, 0.0891390639756407, 0.03971445108098643, 0.028288476069324782, 0.025673225688348924, 0.07149065312530313, 0.09077390589352165, 0.045945054784949334, 0.07537103883389916, 0.027200960853536214, 0.1133024220221809, 0.051058291124978235, 0.03655231165300522, 0.007388371891076011, 0.11675367504358292, 0.0011887761772543723, 0.08036464266479015, 0.060125537615801604, 0.10722559131681919, 0.023469284575964724, 0.012787036531205689, 0.03457374425072755, 0.0781780703525458, 0.0779570307848709, 0.03347004258206912, 0.04786141409671732, 0.04933100898883172, 0.014834086776578, 0.07132880895265512, 0.056477353375937255, 0.02757725601882807, 0.0561679278367332, 0.013214796033155705, 0.024983754381537437, 0.03281653532758355, 0.032512711094958444, 0.026240579351516705, 0.07560423774910824, 0.04033228096419147, 0.07516419421881437, 0.04583680470074926, 0.01229158298312021, 0.16774303040334157, 0.08993757755628654, 0.13972805653299603, 0.22120016334312304, 0.1240783112921885, 0.09670635113226515, 0.11320165957191161, 0.11169379869742052, 0.15609491829361233, 0.06146466040185519, 0.09491150387163673, 0.1408038738050631, 0.10615567051406417, 0.1512139444904668, 0.24016806696142468, 0.13990667409130506, 0.11768899485468864, 0.14227527699300221, 0.20846180830683025, 0.2081772850028106, 0.10824712578739439, 0.12866148964634963, 0.08853663344468389, 0.20867047139576503, 0.1065273652119296, 0.14094948742006505, 0.08249189066035406, 0.14019026101699897, 0.09070427462990795, 0.12293983809649944, 0.09334260877221823, 0.08429454107369695, 0.13598341175488063, 0.19292810612491199, 0.15070194910679544, 0.16786584524171694, 0.15737654880753585, 32.90010247911726, 96.11564704350063, 108.83627005985805, 40.72742189679827, 40.58312170846121, 56.13464232853481, 35.95687212262835, 25.574396099363053, 95.13416535513741, 81.74774510519845, 72.41756507328579, 60.36442770276751, 41.05898993355887, 15.427429267338344, 2.6085168165819983, 0.18536200640457018, 0.3783878487135683, 0.2054040173866919, 0.2971099114843777, 1.2543936840125491, 3.719920916216714, 7.372040442058018, 7.161520881312234, 10.566842998777117, 15.704999378749303, 20.71505355834961, 21.976898533957346, 23.102407693862915, 18.92530529839652, 22.222274167197092, 18.464059557233536, 15.464371102196829, 17.642343010221207, 18.821047578539165, 26.670451845441544, 24.119801146643503, 31.66005400248936, 25.197817632130214, 34.350987093789236, 24.396622589656285, 31.78864778791155, 20.288234404155187, 20.00776515688215, 19.697236265454972, 19.75409858567374, 12.363445656640188, 12.894742267472402, 13.246771012033735, 21.31605884007045, 41.2266777583531, 55.10786880765642, 74.40577820369175, 60.276255062648225, 58.46245561327253, 69.44069276537213, 70.5195951461792, 78.76241683959961, 80.63196168627057, 85.9591177531651, 83.72493144444057, 84.08901010240827, 78.74202387673515, 65.15430736541748, 38.16327258518764, 28.16492772102356, 22.399437597819738, 18.08994770050049, 22.785208531788417, 15.823466164725167, 10.774938941001892, 11.470459699630737, 7.116401016712189, 5.032955876418522, 7.392435141972133, 3.312827697822026, 0.39681425424558775, 0.3810895580266203, 0.32030077278614044, 0.15929585296128476, 0.29168426405106274, 0.8230684059006828, 7.278830357960292, 30.533698899405344, 70.36082880837577, 113.72292423248291, 101.09340599605015, 92.69627176012311, 46.015299797058105, 27.749983038221085, 45.60852793284825, 77.3141621180943, 83.11371231079102, 79.80642536708287, 97.3776969909668, 64.78054986681256, 8.347062911306109, 0.834419211106641, 0.22738772417817796, 0.4186822165335928, 0.14999833543385777, 0.21403081661888532, 0.0928378262157951, 0.15084802412561008, 0.15710855461657047, 0.17654023692011833, 0.15089609154633113, 0.1238988930625575, 0.28813457595450537, 0.2205779603017228, 0.10924803279340267, 0.10282744946224348, 0.15804920771292277, 0.15589962234454496, 0.20038555881806783, 0.12293108499475888, 0.1662050357886723, 0.08687983413359948, 0.10586267909301178, 0.1065536177318011, 0.19414972700178623, 0.11635480501822063, 0.0934231915910329, 0.13299242939267839, 0.1438289186252015, 0.1414844851408686, 0.14593908110899584, 0.17407311073371343, 0.08654341647135359, 0.20317798826311315, 0.0721698666789702, 0.1037124287603157, 0.10543417744338512, 0.12038965922381197, 0.1376215581383024, 0.2130614072084427, 0.23019479640892573, 0.196603567472526, 0.17476026314709867, 0.08634751662611961], [0.03889961534046701, 0.2076792267284223, 0.014570022999708141, 0.029798910287874084, 0.009365602579366947, 0.009540061566180416, 0.04301786828520043, 0.036102772025125365, 0.09301467279770545, 0.11152436171791383, 0.0417987986999963, 0.08614523855171033, 0.032571774175656695, 0.16309304349124432, 0.3656175753899983, 0.12732041946479253, 0.05970752611756325, 0.06025074089744261, 0.039806426502764225, 0.0489421507476696, 0.09420481643506459, 0.10659390235585825, 0.1938692070543766, 0.0738417294674686, 0.050077960693410466, 0.09061017539352179, 0.12565893147672924, 0.33832768404058045, 0.11512110621801444, 0.13759262540510722, 0.10213256174964563, 0.3645262196660042, 0.028089860387678658, 0.24660793425781385, 0.11436714524669306, 1.7935176576886858, 40.05737583977835, 92.64944784981864, 79.09136540549142, 92.11372784205845, 74.31850188119071, 31.15856776918684, 26.406217064176285, 25.459295715604508, 49.180572509765625, 48.98551573072161, 57.58818115506853, 30.26898295538766, 15.715848990849086, 2.4206989748137335, 0.5393177632774625, 0.05626323147277747, 0.03639517312071153, 0.020213074749335647, 0.25110040605068207, 0.24999067559838295, 2.562817645924432, 0.4272537151617663, 1.3813728817871638, 3.6779872349330356, 3.5882972819464545, 4.897894620895386, 4.374046913215092, 5.854137412139347, 8.206938590322222, 9.705037951469421, 12.685859441757202, 28.805174691336497, 36.501746382032124, 44.859783104487825, 54.52987248556954, 54.848138196127756, 51.28464337757656, 58.51146125793457, 57.20433487210955, 53.99856458391462, 42.66934265409197, 41.580313273838584, 35.68463127953665, 25.892085109438213, 18.800727571759904, 10.918116126741682, 15.737351928438459, 34.755299295697895, 77.37331908089774, 104.94503566196987, 118.79720061165946, 122.85567120143345, 130.20418330601282, 101.5931899206979, 56.267964363098145, 73.21771267482212, 84.79860877990723, 86.58269078390938, 89.07127843584333, 91.44144099099296, 94.65248148781913, 84.15173149108887, 88.18605014256069, 79.48441805158342, 73.63994775499616, 47.70855147497994, 34.378529753003804, 20.29471707344055, 9.172714744295392, 11.291692972183228, 6.327925086021423, 5.766800727163043, 3.1346413620880673, 1.7879877601351057, 2.2343667447566986, 1.2776587499039513, 0.26903891776289257, 0.1945702965770449, 0.38496100742902073, 0.257172805922372, 0.01628750709018537, 0.10418802074023656, 0.1928805543908051, 2.7171909851687293, 11.77117599759783, 39.31755249840872, 21.488250834601267, 12.043382968221392, 32.36219726290022, 29.804089409964426, 17.33350600515093, 27.592290197099956, 61.54601056235177, 61.42013004847935, 57.90869460787092, 68.90147086552211, 49.94456515993391, 9.048910873276846, 0.2040406641151224, 0.048721732039536746, 0.020753643242642283, 0.0892242608325822, 0.20586547548217432, 0.11262060289404222, 0.06205843282597406, 0.07425159854548317, 0.20607256436986582, 0.08155705260911159, 0.1144384185650519, 0.1026029900780746, 0.11911418980785779, 0.05871901594634567, 0.05640065856277943, 0.08493823331913777, 0.2633593353841986, 0.017202299520639435, 0.1109883054824812, 0.07304569253964083, 0.06926951623920884, 0.17558950079338892, 0.044772369853620014, 0.2072797595922436, 0.3175273287509169, 0.37610973524195807, 0.2160717821014779, 0.060329512027757506, 0.05550586425566247, 0.18370912224054337, 0.1886865294405392, 0.06823740340769291, 0.08665171744568007, 0.11965469723301274, 0.06327230483293533, 0.027493217760430913, 0.05658716069800513, 0.12720647986446107, 0.012809486710466444, 0.014264348062819667, 0.03001925435715488, 0.043347045978797336, 0.04391394163082753, 0.10256303793617658, 0.07574664867882218, 0.030470127306346382, 0.0348039508265044, 0.04101309586050255, 0.03676501881065113, 0.017439545897234763, 0.0392933624264385, 0.15132720555577958, 0.044327695321823866, 0.028527410301778997, 0.07668677251785994, 0.3109990619122982, 0.335692579724959, 0.0904287351295352, 0.04863015356074486, 0.028637461896453584, 0.02081850610141243, 0.09713853722704308, 0.05446378035204751, 0.11965591859604631, 0.1220164740724223, 0.12266846480114119, 0.02876360494909542, 0.06812480730669838, 0.1011442822803344, 0.1903928414519344, 0.07779811788350344, 0.04317552250410829, 0.13051933209810937, 0.1709600327802556, 0.0037629096685642643, 0.3608999656779425, 0.13971876060324057, 3.362235903739929, 59.73193318503243, 117.17030770438058, 89.71855177198137, 102.40769944872174, 87.64602225167411, 34.58736828395298, 20.623825447899954, 17.31744177000863, 20.791546276637487, 41.65278993334089, 54.180961745125906, 33.80012696129935, 17.931216103690012, 4.0327518326895575, 0.4872429690190724, 0.05243262987849968, 0.05933359903948648, 0.018039547272824814, 0.5294786798102515, 0.5123262916292463, 1.9605647282941001, 2.4198701850005557, 3.356492566210883, 1.3582914003304072, 2.113938178334917, 2.1901937893458774, 2.8298855551651547, 0.31943349646670477, 3.726992879595075, 9.164523686681475, 17.842932292393275, 33.50408853803362, 44.6616586957659, 53.26303175517491, 61.61368601662772, 60.73878969464983, 58.97557313101632, 63.71151392800467, 59.54162202562605, 56.49305125645229, 49.27607897349766, 44.03976018088204, 37.58582517078945, 28.009314128330775, 14.811205693653651, 9.435531224523272, 14.49676409789494, 35.16865110397339, 78.95225552150181, 109.48203563690186, 126.57622310093471, 134.38430295671736, 138.518828528268, 109.75245952606201, 59.9928936277117, 77.96858515058244, 91.28706591469901, 91.28042343684605, 93.14657756260463, 97.39082213810512, 100.0393990107945, 90.74136134556362, 91.18835980551583, 88.96681227002824, 80.62522193363735, 56.26671368735177, 37.33687121527535, 20.02127766609192, 12.705762556621007, 7.2003487178257535, 3.4649224621909003, 2.724470091717584, 6.941772375788007, 4.43680738551276, 3.8653436728886197, 2.5555107465812137, 1.9554059079715183, 1.4889137340443475, 0.7692609589014734, 0.7743254899978638, 0.1532976712499346, 0.09683040090437446, 0.09255124016531877, 2.433656713792256, 11.571743590491158, 39.10909611838204, 31.640067509242467, 23.260590382984706, 24.363043682915823, 16.57357805115836, 25.683859757014684, 46.9058712550572, 81.7938950402396, 74.32203156607491, 69.31971767970494, 77.70412281581334, 70.69286237444196, 23.818900721413748, 0.13926281221210957, 0.06598176301590034, 0.11862092199070112, 0.03700847717534218, 0.07397035935095378, 0.05543072668037244, 0.027145996124350598, 0.0819515867957047, 0.017598848956237947, 0.07137729027973753, 0.011075550690293312, 0.13939454300062998, 0.11151783421103444, 0.09150656086525746, 0.03573786607012153, 0.03860454081690737, 0.16362612774329527, 0.12326903614614691, 0.036954153661749194, 0.06899162222232137, 0.08618567245347158, 0.11298077606729098, 0.040506128421319385, 0.20188592188060284, 0.1989018198634897, 0.21410807461610862, 0.11342428691153016, 0.11194400170019694, 0.06070461975676673, 0.06886700926614658, 0.08411120769700833, 0.04009798282225217, 0.02490038956914629, 0.07504925717200552, 0.00610112480353564, 0.028037636939968382, 0.048191687624369345, 0.03939619780118976, 0.013771243094067489, 0.020176204852759838, 0.028149376390501857, 0.09631251583674125, 0.14651012260998997, 0.19395334539668901, 0.2120604459196329, 0.12357164919376373, 0.15622724619294914, 0.1760405365909849, 0.08347963408700057, 0.1731865368783474, 0.1828435558293547, 0.2643756722765309, 0.1226311589458159, 0.14918615615793637, 0.26671108124511583, 0.4509215051574366, 0.4930717476776668, 0.20107181556522846, 0.1708726238991533, 0.1494860957775797, 0.09851896922503199, 0.22590315741087708, 0.13833053223788738, 0.2375664279929229, 0.21609082179410116, 0.27331697248986786, 0.1250444094517401, 0.14017696173063346, 0.12987257965973445, 0.38147540017962456, 0.16176816315523215, 0.2899964489042759, 0.19676906216357434, 0.46375094673463274, 0.08116705103644303, 0.4739813006349972, 0.19774931456361497, 4.481327533721924, 69.82450430733817, 133.90446036202567, 98.98705959320068, 112.05184773036412, 94.11180741446358, 47.26136541366577, 37.22673879350935, 40.418650899614605, 69.86792360033307, 67.6314582824707, 77.22910921914237, 46.399726254599436, 25.015229395457677, 5.646272931780134, 0.9762287416628429, 0.16942492872476578, 0.2681166801069464, 0.09798412078193255, 0.9175356796809605, 0.7530239958848272, 6.342783808708191, 4.9280432888439725, 6.523987182549067, 12.425873483930316, 13.51790622302464, 15.945040532520839, 13.60232596737998, 21.1480097089495, 21.056649582726614, 20.645651476723806, 22.082933255604335, 38.75482831682478, 47.449849196842735, 54.442519732883994, 64.80116517203194, 62.89731706891741, 58.27435050691877, 64.96344035012382, 63.20644242422921, 58.58067226409912, 51.06821741376604, 51.359656129564556, 46.431573322841096, 34.830965178353445, 28.740705830710276, 19.797497034072876, 25.709300586155482, 43.32151099613735, 76.50293908800397, 106.69236169542584, 120.89871106828961, 129.7475199018206, 135.3785901750837, 106.69775349753243, 72.45870535714286, 78.40183312552315, 93.6231267111642, 96.45554597037179, 93.09121431623186, 100.11714240482875, 103.2466527393886, 94.7995331627982, 95.04297024863106, 90.25951072147915, 84.64763832092285, 56.811504568372456, 41.4775389943804, 30.41589914049421, 18.156570502689906, 21.60232809611729, 15.674105950764247, 14.204945836748395, 11.152783717427935, 8.191888792174202, 7.085808098316193, 5.300062869276319, 4.315906558718, 2.286157965660095, 1.2914571123463767, 0.45622203073331286, 0.15517052289630684, 0.20149117734815392, 0.48670193233660286, 5.435828498431614, 19.642969097409928, 57.05699484688895, 33.08450419562203, 23.096920354025706, 48.963448251996724, 38.804097993033274, 25.328754697527202, 37.70070668629238, 80.77919401441301, 76.66344942365373, 76.16242177145821, 86.60937186649868, 80.27404608045305, 19.48155723299299, 0.27958270055907114, 0.14187734334596566, 0.2319095086838518, 0.2821843938103744, 0.3100792398410184, 0.19739800984305994, 0.19931731399680885, 0.26196633013231413, 0.2744040127311434, 0.27559636160731316, 0.2153152155556849, 0.22491789742239884, 0.20889802489961895, 0.21352072113326617, 0.14686323223369463, 0.11386952123471669, 0.37907656175749643, 0.20988899815295423, 0.2390151545405388, 0.2697651945054531, 0.19071818542267593, 0.36913681083491867, 0.09527135813342673, 0.37112125435045784, 0.3529060631990433, 0.3542310521006584, 0.3304397144487926, 0.1503963912171977, 0.14308270652379307, 0.2630631684192589, 0.18882980889507703, 0.17974972112902574, 0.11769559021506991, 0.11793348459260804, 0.10702409355768136, 0.09562078331198011, 0.1129601350320237, 0.15996438637375832, 0.09777097257652453, 0.11333495777632509, 0.11126875079103879, 0.13031396668936523], [0.08029296222542014, 0.062280354489173205, 0.10700922685542277, 0.13545129102255615, 0.03655481544722404, 0.09276363519685608, 0.08896554900067193, 0.08676482244793858, 0.16020912038428442, 0.22996865425791058, 0.08619389629789762, 0.027959934502307857, 0.004030231261692409, 0.29978711211255615, 0.39075860061815804, 0.06982669526977198, 0.05289014568552375, 0.04166064218484929, 0.052955559853996546, 0.16749718359538487, 0.29847205696361406, 0.30382320125188145, 0.39113361335226465, 0.230426801102502, 0.025622510284717594, 0.0373685248196125, 0.18857918520058903, 0.2928049867706639, 0.0842372795034732, 0.05054667232824223, 0.1540333931999547, 0.19512702098914556, 0.1322323480354888, 0.22747839002736978, 8.144135560308184, 72.11228207179478, 99.62399400983537, 79.1989026750837, 72.71704632895333, 66.35219764709473, 61.10316712515694, 27.1882871900286, 70.90480327606201, 106.82265431540353, 78.94958046504429, 46.52130235944475, 30.95952272415161, 11.46417418548039, 1.324072282229151, 0.21792239136993885, 0.14552906953862735, 0.03299206215888262, 0.08275786281696387, 0.024016234691121748, 0.5864318151559148, 1.3099596223660877, 3.0427377564566473, 4.553171472890036, 1.6270995076213564, 2.0889995736735205, 1.2589403028999056, 1.3245784150702613, 3.5793332372392928, 15.363366876329694, 32.88780764171055, 59.30138805934361, 66.82514762878418, 84.43605177743095, 77.6852445602417, 79.48895522526333, 81.68525995526994, 86.336884362357, 81.8796775000436, 89.42064775739397, 87.59292411804199, 86.37056922912598, 74.70642675672258, 69.18836893354143, 57.149607385907856, 64.90110806056431, 54.74206352233887, 41.03774234226772, 49.893693923950195, 88.09771074567522, 96.17196914127895, 86.14167472294399, 70.58169119698661, 82.23406342097691, 76.90774808611188, 78.5334667478289, 40.464057377406526, 75.25139481680733, 86.87750979832241, 86.9475406919207, 90.7380678994315, 92.22715718405587, 87.87579223087856, 83.689711025783, 81.22695677621024, 78.11527551923479, 83.95419420514787, 82.88964680262974, 65.01184844970703, 49.11693048477173, 33.65020220620291, 29.467685426984513, 15.801320518766131, 4.473705794130053, 1.2572187781333923, 3.106968641281128, 3.5429681028638567, 2.872513187783105, 1.6473104059696198, 0.29515301649059567, 0.6824885436466762, 0.2605612469570977, 0.17611408978700638, 0.1618072467723063, 0.06318849218743187, 0.020175680684457933, 1.9403200660433089, 12.164232117789131, 44.714982645852224, 55.07897472381592, 88.53494003840855, 133.24992615836007, 51.693927015577046, 19.28753920963832, 11.424216832433428, 36.134641783578054, 72.74508925846645, 59.403867040361675, 64.64410809108189, 73.54994079044887, 20.18646935054234, 0.49748727359942024, 0.0995565103366971, 0.11003553375069584, 0.1122242027361478, 0.017574430177254335, 0.07235904902751956, 0.02759322534049196, 0.13077808464212076, 0.0845821788534522, 0.03140210872516036, 0.04809516262529152, 0.011634003670353974, 0.1323451476969889, 0.13321178619350704, 0.07522237181131329, 0.2587535211018154, 0.13134148583880492, 0.04192060591386897, 0.10256592171000582, 0.133189516674195, 0.05179364327341318, 0.04328611014144761, 0.18494751650307859, 0.1697806032108409, 0.36251639894076754, 0.09162826290620224, 0.05787682506654944, 0.39984432022486416, 0.2230195328593254, 0.2858908234962395, 0.07570989243686199, 0.06575548515788146, 0.12659510624195847, 0.15879984386265278, 0.13070021596338066, 0.08050505191619907, 0.05469264003581234, 0.055704749654978514, 0.0905919431575707, 0.0556555049760001, 0.07059742284140416, 0.0551144649008555, 0.036183324309864213, 0.05107003317347594, 0.07096274609544448, 0.022930844986279095, 0.021769786752494316, 0.041702514580850086, 0.07698189453887087, 0.18244463152119092, 0.21967654010014875, 0.04867699283308216, 0.1050174008788807, 0.04242048944745745, 0.11297156834708792, 0.37266095887337414, 0.12094464658626489, 0.11572490738970892, 0.011243982589803636, 0.042962974802191765, 0.1773168473903622, 0.23941036047680037, 0.19788868565644535, 0.2764288697923933, 0.2002904282084533, 0.03569481980853847, 0.03874406118744186, 0.052125915086695125, 0.4104869248611586, 0.1351177232073886, 0.10488723750625338, 0.20427713356912136, 0.13329014341746057, 0.2142635134181806, 0.282571267336607, 16.52939098221915, 91.75193514142717, 111.85598496028355, 82.0662088394165, 85.97074208940778, 76.6976067679269, 84.08260386330741, 54.35084867477417, 61.51687676565987, 74.69039031437465, 61.464014870779856, 45.27206836427961, 33.18603127343314, 11.387075236865453, 1.6461635189396995, 0.06419175370995488, 0.17507656903139182, 0.1430855699415718, 0.09516577808452503, 0.11885762214660645, 0.3339416336800371, 1.1772122255393436, 4.504623106547764, 7.990662881306239, 2.005866983107158, 0.7505129277706146, 1.2593966041292464, 1.465530874473708, 3.219994987760271, 16.254855496542795, 36.73826306206839, 64.77156584603446, 77.01914855412075, 94.87687356131417, 88.03216144016811, 86.21679169791085, 86.34453432900565, 90.19972842080253, 84.4707441329956, 91.08256653376988, 89.78317696707589, 90.98783479418073, 76.32955374036516, 70.33548872811454, 63.42476177215576, 67.89432947976249, 59.316701889038086, 46.268790926252095, 55.287469318934846, 98.7779188156128, 106.75900881631034, 99.07082707541329, 81.10029806409563, 94.25785854884556, 88.52139799935478, 88.86465290614537, 49.37605660302298, 75.68093245370048, 88.3129242488316, 89.77759061540876, 91.19286918640137, 94.24087715148926, 92.24952343532017, 87.42119244166783, 86.0310663495745, 83.11538682665143, 87.65192822047642, 87.4182880946568, 72.16817338126046, 57.0837801524571, 37.97754723685128, 32.86381203787667, 17.104884215763636, 5.949048067842211, 2.0393913899149214, 2.7395333520003726, 2.863453822476523, 3.5197498287473405, 3.008064942700522, 1.2954875017915453, 1.7821776547602244, 0.8465114108153752, 0.46403034031391144, 0.2010926737317017, 0.020065995498693416, 0.05302783401150789, 1.097887139235224, 8.548659682273865, 31.505248137882777, 42.40700994219099, 64.5077496937343, 113.1642404283796, 53.877228191920686, 25.862124477113994, 23.608042001724243, 52.82473243985857, 87.62270409720284, 73.41413824898856, 72.97344180515834, 88.43466363634381, 44.18679448536464, 0.7244043116058622, 0.23642144086105482, 0.09842869014080081, 0.020795766696599976, 0.16173092515340873, 0.0392243316663163, 0.016421667034072534, 0.12246698061270372, 0.025484740534531217, 0.055791724273668866, 0.055374096147716045, 0.09125637143318142, 0.01848696478243385, 0.08775778380887848, 0.027128586612109627, 0.27054659543292864, 0.08655723144433328, 0.0692818791472486, 0.09190015188817467, 0.0366615184715816, 0.0021497427036852707, 0.05620410053857735, 0.13614199895943913, 0.14087018024708542, 0.18304413078086718, 0.08322572628302233, 0.09482138085045985, 0.2514292241207191, 0.11952285787888936, 0.10220594531191246, 0.05316859270845141, 0.06362407774265323, 0.2088632567652634, 0.11026504143540349, 0.04952425915481789, 0.04218266631609627, 0.10685093142092228, 0.08482945737029825, 0.04778944527996438, 0.06428569009793655, 0.02435946654129241, 0.15112084948590823, 0.12049974474523749, 0.1390418540686369, 0.1903694455644914, 0.19595317808645113, 0.1278055448617254, 0.21971092825489386, 0.21192777875278676, 0.30500667489000727, 0.3399968801864556, 0.17685705849102565, 0.1938990354537964, 0.24011799107704843, 0.44949753156730105, 0.6643528767994472, 0.2770795305924756, 0.28221628495625084, 0.1883490125515631, 0.24281022804124014, 0.25417384398835047, 0.40507085834230694, 0.4220010127340044, 0.5062903698001588, 0.41006702025021824, 0.1616358488265957, 0.1792160804782595, 0.357428281967129, 0.6091838542904172, 0.24623919118727955, 0.19961056326116833, 0.3941248671284744, 0.2785426692238876, 0.3014084036861147, 0.3270378384206976, 19.786077669688634, 103.96043423243931, 126.55800492422921, 90.93906538827079, 94.02086244310651, 82.85457229614258, 77.64463233947754, 46.52742372240339, 92.79180949074882, 128.12403161185128, 105.0373841694423, 66.1679105758667, 48.141396454402376, 17.759814466748917, 2.6732062825134824, 0.47891017901045935, 0.22644586328949246, 0.17806132244212286, 0.37600192959819523, 0.3097421165023531, 1.5321504196950366, 4.467588773795536, 10.007046614374433, 13.268129774502345, 9.31686554636274, 10.082943524633135, 9.513957279069082, 9.638060791151863, 12.132090619632176, 21.934703860964092, 38.098376410348074, 68.04817649296352, 79.16307776314872, 98.10715362003872, 93.67946965353829, 93.04102052961076, 89.4752675465175, 92.26532363891602, 85.86271844591413, 94.53086021968296, 92.30194064549038, 93.85191699436733, 78.64758396148682, 70.24826799120221, 66.68788596561977, 75.84596606663295, 64.91007123674665, 53.15208986827305, 60.07786314828055, 101.36423982892717, 109.11417715890067, 103.2208332334246, 88.1841880253383, 100.67496463230678, 96.62786129542759, 93.52823516300747, 55.852350916181294, 80.09123202732631, 91.96197918483189, 92.8159544808524, 95.27988992418561, 99.8139716557094, 97.47666018349784, 93.25673430306571, 91.27355861663818, 88.79461506434849, 92.36595439910889, 91.0433509009225, 77.03888838631767, 55.11527211325509, 35.40109613963536, 33.37827403204781, 20.353007248469762, 9.129390120506287, 9.364309583391462, 9.822215846606664, 9.81894063949585, 9.367611714771815, 5.193730243614741, 4.12797211749213, 4.118234217166901, 1.8582668347018105, 1.1032684104783195, 0.38130424650652067, 0.08242868512336697, 0.16973309218883514, 3.4463379851409366, 18.197267838886805, 61.2184933253697, 72.66590758732387, 105.10515689849854, 159.22851807730538, 65.55623980930874, 28.50335189274379, 16.78497873033796, 46.57867363521031, 90.74141693115234, 75.97446605137416, 81.7410192489624, 98.44749723161969, 40.25414882387434, 0.4410582115607602, 0.27461856550404, 0.38372764789632385, 0.25011465751699036, 0.23150773452860968, 0.18009726676557744, 0.12832284638924257, 0.3948228082486561, 0.26273682021668976, 0.23280978894659451, 0.22625168013785565, 0.1769534783171756, 0.3050766997039318, 0.39010441143597874, 0.2098577312592949, 0.5191433972546032, 0.32278003117867876, 0.19571546012801783, 0.22547212482563087, 0.28577302981700214, 0.12058274314871856, 0.1997123435139656, 0.3462904281914234, 0.3948513338608401, 0.45310739214931217, 0.23397640777485712, 0.29912855316485676, 0.49215181704078403, 0.19620305539241858, 0.43896843226892607, 0.27842908246176584, 0.12711666896939278, 0.2668107716100556, 0.27226822876504486, 0.13965662036623272, 0.09022791590541601, 0.158783260466797, 0.21332201893840516, 0.14381694926747254, 0.2891767786017486, 0.19917436023908003], [0.009880526689812541, 0.0856275095471314, 0.0074455113249963945, 0.03658177025083985, 0.04394222975575498, 0.046403975159462006, 0.05727291532925197, 0.06680399139544793, 0.11159488186240196, 0.128938834049872, 0.08237283490598202, 0.021471619805587188, 0.10143037978559732, 0.06863885865147624, 0.0971483624141131, 0.015017196236710464, 0.035112989600747824, 0.018007472922493304, 0.05006818639646683, 0.14079030310469015, 0.2283254052911486, 0.19542301153498037, 0.1764399494443621, 0.10482722108385392, 0.0495871050682451, 0.07259130477905273, 0.06383493928504841, 0.06640260400516645, 0.04464911736015763, 0.288389298000506, 0.055744823933179886, 0.21661570934312685, 0.7449478549616677, 24.548348665237427, 95.94488116673061, 98.1366765158517, 66.93490137372697, 76.71209376198905, 51.5939667565482, 35.7543877192906, 23.835152557918004, 26.418209654944285, 27.609379291534424, 35.45523302895682, 26.01644570486886, 15.961000544684273, 4.935148256165641, 0.4374980197421142, 0.0470350330828556, 0.0652758762506502, 0.050924925067062886, 0.1125839620030352, 0.6469519819532121, 0.04566195301179375, 0.6455005684069225, 0.1528435820447547, 0.1193224729171821, 6.25393545627594, 3.40951253260885, 1.4771839806011744, 0.5360727916870798, 7.0126096946852545, 33.238528387887136, 65.43302740369523, 88.88475404466901, 92.63582938058036, 93.06756959642682, 88.70396191733224, 82.14048508235386, 80.01616368974958, 84.98043618883405, 88.26969255719865, 90.96737234933036, 90.1617078781128, 89.5842569896153, 88.09222166878837, 82.02133042471749, 83.15790285382951, 82.01582745143345, 73.20335074833461, 69.58470112936837, 53.967301164354595, 51.68990748269217, 71.4861729485648, 59.611826624189106, 65.31194114685059, 61.15184620448521, 63.95465224129813, 72.93357304164341, 58.88265487125942, 30.81911700112479, 80.13218470982143, 85.3715294429234, 87.63424505506242, 89.48407786233085, 85.85240731920514, 83.23545864650181, 76.35282325744629, 75.06371007646833, 76.69580023629325, 84.67208903176444, 84.00757721492222, 84.53821808951241, 80.98115730285645, 77.55362483433315, 69.90980734143938, 57.25013739722115, 32.79183564867292, 8.25438870702471, 1.3446914958102363, 3.5481477677822113, 4.794349525656019, 2.670669538634164, 1.0777122846671512, 0.6067960624183927, 1.0482205471822192, 0.47053504841668264, 0.12272004703325884, 0.21490308695605823, 0.12603949462728842, 0.03496186288871935, 0.16863774667893136, 7.4948272705078125, 29.61506019319807, 56.429614203316824, 46.945826871054514, 43.191412925720215, 62.00220148903983, 35.98019027709961, 18.756033284323557, 28.583933625902446, 51.00485331671578, 54.7760853767395, 62.89361367906843, 74.29796300615583, 35.32826164790562, 1.619380384683609, 0.313520579465798, 0.01791714464447328, 0.06453058017151696, 0.05282734048419765, 0.048497242121292014, 0.012172758778823274, 0.01051615793923182, 0.05272447457537055, 0.018151831247710755, 0.07233994148139443, 0.05593028790982706, 0.026456268670569574, 0.035456348676234484, 0.06170251406729221, 0.04905618873557874, 0.022818571189418435, 0.05597358862204211, 0.011724196241370268, 0.05637806673933353, 0.01371417660266161, 0.0441658240077751, 0.04855856133092727, 0.10948318588946547, 0.014806577270584447, 0.2203668544867209, 0.21363680490425654, 0.1553446485527924, 0.09040795838726418, 0.006674171799594271, 0.034079567196645906, 0.1587192067610366, 0.13202770187386445, 0.11947768101734774, 0.025675213795953562, 0.026695967951257314, 0.02442781367738332, 0.009942951063359422, 0.01961808605119586, 0.07423729502729007, 0.02872088777699641, 0.061029420899493356, 0.029592706888381923, 0.012465079298375972, 0.05755264139068978, 0.037840330574129305, 0.040068069605955055, 0.04202091713835086, 0.0977263521136982, 0.13150556917701448, 0.04817407624796033, 0.06258071480052811, 0.06339440720954112, 0.09002964118761675, 0.15921007256422723, 0.09642789393131222, 0.05314013834244438, 0.05983150803617068, 0.0313021333755127, 0.10131166329873459, 0.0686926529077547, 0.1264690887182951, 0.21177139000168868, 0.0670864519530109, 0.12332983288381781, 0.14529501566929476, 0.03661406173237732, 0.11357645517481224, 0.0009917834665559763, 0.16332735520388397, 0.056243642166789086, 0.15654575053070272, 0.9444087062563215, 38.128486428942, 116.68669918605259, 106.10721220288957, 80.78300162724086, 104.28722190856934, 73.68369361332485, 59.11612129211426, 42.31903532573155, 35.75134440830776, 39.31921311787197, 46.93556438173567, 34.95281226294381, 21.996129410607473, 6.3369664294379096, 0.42030633081282887, 0.036485140078834126, 0.014615617160286223, 0.10542732423969678, 0.7854580783418247, 0.9276509540421622, 0.04270141651587827, 0.3852441736630031, 0.5547616545643125, 0.21725419722497463, 4.120561863694872, 2.40499952009746, 0.20137735988412583, 1.0082743763923645, 9.092518636158534, 39.24538503374372, 73.54839134216309, 96.61406912122453, 93.60382461547852, 95.02275793892997, 91.9600475856236, 88.45426450456891, 85.7486012322562, 90.38476589747837, 90.44442313058036, 94.25263350350517, 89.99493026733398, 90.8700350352696, 89.30922644478935, 85.48518807547433, 84.07963003431047, 86.72813742501395, 76.85683863503593, 72.54364708491734, 60.12600026811872, 59.36855629512242, 78.41312394823346, 69.09019088745117, 70.36005755833217, 67.43138490404401, 70.62033707754952, 79.90100424630302, 63.729996136256624, 36.695312772478374, 82.15226227896554, 87.13569096156529, 88.40033258710588, 91.89092690604073, 87.90794849395752, 87.62446199144635, 79.97534302302769, 78.45540373665946, 79.09157385144914, 86.31761005946568, 87.9569193976266, 86.58158602033342, 80.78959546770368, 80.42663546970913, 73.53876113891602, 62.2786077771868, 38.26261445454189, 12.367183787482125, 1.2197084937776839, 4.065237266676767, 4.763815666948046, 2.2230737507343292, 1.4796575392995561, 0.5126837438770703, 1.2667618032012666, 0.264948057276862, 0.0441123079508543, 0.050797004252672195, 0.11691271008125373, 0.05064791653837476, 0.06224173906126192, 5.884250470570155, 19.240746566227504, 54.33265829086304, 52.231985092163086, 34.824069091251914, 44.86412572860718, 34.600198132651194, 30.11612606048584, 49.43517535073416, 70.73681667872837, 66.38153988974435, 72.63616929735456, 83.43795694623674, 63.7865058353969, 8.36980436529432, 0.11527556792965957, 0.05020672967657447, 0.01966692360916308, 0.04604281132508602, 0.08922753137137208, 0.048611392067479234, 0.09770506647016321, 0.05148265031831605, 0.0019862636857266936, 0.11927853098937444, 0.07629468784268413, 0.07175188910748277, 0.04074185148679784, 0.08677335163312298, 0.07700118528945105, 0.037763669687722407, 0.02909629066873874, 0.026336132349180322, 0.04777034451918943, 0.02534147465069379, 0.05278901343366929, 0.02991324004584125, 0.17506998724171094, 0.031235141613121544, 0.09003871998616628, 0.18562869780829974, 0.11132956109941006, 0.08078097818153245, 0.029546217061579227, 0.04198121605440974, 0.09878553170710802, 0.15755146156464303, 0.15264782469187463, 0.038789241441658566, 0.020546001348910586, 0.05914239465658154, 0.02230572254796113, 0.04364295170775481, 0.0344431907204645, 0.1799436600080558, 0.1811463361872094, 0.197342451395733, 0.14913059771060944, 0.09826054237782955, 0.11018981904323612, 0.15369359643331595, 0.20159412468118326, 0.2797567312206541, 0.2568358725735119, 0.16798631234892777, 0.1358233724853822, 0.24389669831309999, 0.27026318492633955, 0.3750016875565052, 0.19979625115437166, 0.13556896256549017, 0.15348596471760953, 0.16237592697143555, 0.35068608660783085, 0.3268224171229771, 0.33873553786958965, 0.47270071506500244, 0.17180441532816204, 0.19577590402747902, 0.21369543032986776, 0.15945159031876496, 0.1651196918849434, 0.18587140978447028, 0.32403065264225006, 0.1474119227911745, 0.3548458862517561, 1.8427239315850394, 45.19930682863508, 130.9522819519043, 120.76922443934849, 86.1958498273577, 103.94651699066162, 67.30767917633057, 49.460449423108784, 33.57883725847517, 35.60016202926636, 42.39209563391549, 53.46025289808001, 42.08902563367571, 28.180189439228602, 8.179422855377197, 0.8049699227724756, 0.1931649555585214, 0.24872072945748055, 0.19236805689121994, 0.8571196272969246, 2.640598386526108, 0.17470770382455417, 2.3709672433989386, 2.3072229496070316, 2.679553461926324, 13.801680207252502, 13.950295226914541, 4.41908209664481, 4.641425320080348, 11.251576679093496, 40.3527124949864, 74.03703730446952, 100.69208499363491, 102.17265578678676, 99.62254183632987, 98.82559040614537, 92.4214357648577, 89.06023774828229, 93.97656072889055, 92.32256984710693, 95.760587147304, 95.70328535352434, 96.7503719329834, 96.29706450871059, 87.26804719652448, 84.59200409480503, 88.05190822056362, 77.14418138776506, 72.7554212297712, 64.65264047895158, 67.3945802961077, 83.7219020298549, 79.57117325919015, 78.15094757080078, 74.12256962912423, 75.82642078399658, 88.1253159386771, 70.064425604684, 43.96251705714634, 87.79708303724016, 90.44133813040597, 92.41054098946708, 95.99988310677665, 93.63498033796037, 92.6523244040353, 85.23766544886998, 82.07791655404228, 83.547974722726, 91.61417320796421, 92.54519707815987, 87.51049068995884, 82.43629768916539, 82.0237761906215, 74.22607694353376, 62.46039349692208, 38.63925198146275, 13.711225083896093, 5.824430389063699, 9.221191457339696, 12.124201808656965, 7.256776341370173, 4.473443499633244, 1.9215171550001418, 4.040233305522373, 0.8352557633604322, 0.1826256239520652, 0.5359065777489117, 0.21318677333848818, 0.15764623933604785, 0.8077058302504676, 12.251917515482221, 46.23957027707781, 69.309677532741, 53.86075748716082, 63.66664246150425, 83.93806048801967, 50.014328547886436, 25.975491285324097, 40.21167795998709, 66.4180804661342, 70.9461589540754, 79.80943393707275, 99.05916799817766, 63.448225838797434, 4.623183258942195, 0.48867619782686234, 0.11362960482282297, 0.18388407570975168, 0.14095828123390675, 0.18541894906333514, 0.09729545523545571, 0.21918973193636962, 0.12969248289508478, 0.11583154595323972, 0.337395648338965, 0.1683857659144061, 0.13275209228907311, 0.09881956702364342, 0.28377998247742653, 0.2087090936090265, 0.174042603799275, 0.13855444879404136, 0.1489067082958562, 0.15270541874425753, 0.0754738843866757, 0.14251081006867544, 0.13800347835889884, 0.280848005520446, 0.13347600772976875, 0.3869339701320444, 0.29070633224078585, 0.2931414858571121, 0.184402110055089, 0.17473096400499344, 0.17011212185025215, 0.2011204393846648, 0.22981465395007813, 0.19628836081496306, 0.12367254735103675, 0.1628197431564331, 0.15284812822937965, 0.08605590941650526, 0.1700933807130371, 0.25551335353936466], [0.028939026607466594, 0.06251744141003915, 0.06043375536267247, 0.03819120103227241, 0.02057688995929701, 0.051771757126386674, 0.039059488368885856, 0.12337312341800757, 0.02195894026330539, 0.04773806660835232, 0.03693906982828464, 0.01780054179419364, 0.07229652202555112, 0.026964347210845778, 0.02277885653477694, 0.017565297095903327, 0.01150004389429731, 0.07633755768516234, 0.06127183432025569, 0.13682683078306063, 0.10051222012511321, 0.05194908546816025, 0.058007653403495035, 0.10566470293062073, 0.029348729444401603, 0.08327550361199038, 0.0949114156620843, 0.03905073865982039, 0.04102229679535542, 0.09546502559844937, 0.14170184704874242, 1.837123032127108, 25.84077787399292, 93.34807532174247, 87.34554740360805, 76.34618077959333, 64.7749079295567, 16.18892925126212, 14.360179884093148, 15.699677058628627, 42.054427078792024, 66.86469677516392, 45.486055510384695, 34.633750983646934, 18.313638005937847, 2.5447286622864858, 0.14953390535499367, 0.18712596675114973, 0.09899140601711613, 0.04468806866290314, 0.12253750754254204, 0.5835305622645787, 0.6046972721815109, 0.1441901299570288, 0.22680718318692275, 0.10563441312738828, 0.34886438293116434, 0.5354881659150124, 0.8269501690353666, 0.9592757884945188, 16.508826051439556, 55.916107586451936, 81.92127636500767, 86.09430190495083, 83.4018749509539, 84.34314046587262, 78.47708211626325, 74.63030229296002, 75.70839173453194, 87.0446834564209, 83.36155455453056, 87.59950406210763, 81.74889155796596, 77.15690353938511, 76.42484133584159, 76.93579796382359, 79.0726261138916, 85.67048958369664, 85.03954451424735, 83.8392640522548, 78.95383276258195, 66.87363910675049, 46.32622473580496, 41.53083862577166, 67.0726146697998, 62.728336879185264, 60.49249689919608, 67.19316591535295, 73.11100224086216, 42.47284412384033, 45.5035753931318, 88.44739968436105, 76.93268517085484, 78.00777993883405, 79.66428606850761, 73.8069338117327, 67.8495900290353, 68.68490246364048, 71.32558618273053, 77.06413119179862, 79.95322690691266, 82.05197892870221, 77.05213165283203, 79.81583322797502, 84.80935069492885, 84.92640699659074, 83.4994068145752, 77.36382784162248, 51.54930026190621, 18.021478414535522, 0.8774086385965347, 0.6996735015085765, 1.4315713367291858, 0.2819285046841417, 0.4778234916073935, 0.38875700373734745, 0.23884351232222148, 1.627723868404116, 0.10599102399178914, 0.41016798626099316, 0.21816024503537587, 0.0395374518286969, 0.05540611282257097, 2.6419411259038106, 12.784392714500427, 37.338702065604075, 66.70526341029576, 48.79254688535418, 49.580323219299316, 40.721269266945974, 14.51566059248788, 16.648441416876658, 39.83504738126482, 55.575430461338584, 66.93306704929897, 80.73114722115653, 62.537574086870464, 11.881407431193761, 0.3757667765021324, 0.06522123382559844, 0.017749658453145196, 0.10060286561825446, 0.07356076847229685, 0.028517737785088162, 0.04687047477013298, 0.11329180973448924, 0.01602016938185053, 0.040126511827111244, 0.06293987017124891, 0.06468046177178621, 0.0467159893097622, 0.03718364777575646, 0.06964622531086206, 0.01613053649530879, 0.052887129597365856, 0.04160148410924843, 0.055466132637645514, 0.07960359778787408, 0.12255793144660336, 0.16968905526612485, 0.14192945483539784, 0.09706368802913598, 0.07292716604258333, 0.047758538009864945, 0.12095246330967971, 0.063347574722554, 0.09420339829687562, 0.10189322209251778, 0.01035259198397398, 0.036863423351730616, 0.023131324942888956, 0.03141650045290589, 0.023535109258123806, 0.023696074727922678, 0.07283158081450633, 0.10327089923833098, 0.1342947959367718, 0.07750273123383522, 0.00148821686161682, 0.012930246435904076, 0.034035469205783944, 0.032106438252542696, 0.04565510320078049, 0.05585056683048606, 0.012870130777758147, 0.024573020171374083, 0.03464173006692103, 0.022735474398359656, 0.03855474991723895, 0.08566494432411023, 0.032609470188617706, 0.031220061172332083, 0.0037695313221774995, 0.04760289903996246, 0.07627802980797631, 0.10577002513621535, 0.13431350993258612, 0.12169156436409269, 0.09301210793533496, 0.09161978800381933, 0.05315212466354881, 0.05478957215590136, 0.0875171549352152, 0.03723079578152724, 0.06105812293078218, 0.08849611133337021, 0.09443806963307516, 1.9443315650735582, 42.45297922406878, 111.68738692147392, 95.08020564488002, 88.20198236192975, 77.85715688977922, 31.002528599330358, 29.47227818625314, 24.0609290599823, 30.12666300364903, 45.598168168749126, 43.85614013671875, 35.53819104603359, 21.85254488672529, 3.146586835384369, 0.1728858101580824, 0.1415689763213907, 0.02698864385352603, 0.19120396221322672, 0.13695339113473892, 0.9150724347148622, 1.093412499342646, 0.47213888806956156, 0.036238180473446846, 0.1557889532830034, 0.20954594441822597, 0.30680924387914793, 1.0506966028894698, 2.001712394612176, 19.70111162321908, 61.84302520751953, 87.00548866816929, 88.89954675946916, 86.79645906175885, 88.74875695364815, 82.9775971003941, 79.90165042877197, 79.94691794259208, 87.9079623903547, 86.0952399117606, 90.19660867963518, 83.90479251316616, 80.48940549577985, 78.45957960401262, 80.98885590689522, 82.72405733380998, 87.74506882258824, 87.96886335100446, 85.38785770961216, 79.77870205470494, 68.33522047315324, 53.3748664855957, 49.56444311141968, 74.31322819846017, 70.52426433563232, 69.07605130331856, 72.77994837079729, 84.53152002607072, 50.00638675689697, 51.0281332560948, 88.42580468314034, 79.62921156202043, 80.01537159511021, 79.86811842237199, 78.25698402949742, 71.58577537536621, 72.5278399331229, 74.65529496329171, 81.95034067971366, 84.33548355102539, 84.6782729285104, 75.54236452920097, 78.79674094063895, 85.02200726100376, 86.82721873692104, 85.7782769884382, 81.09804684775216, 57.080403327941895, 22.406979867390223, 1.606287372963769, 0.16974599792488984, 0.33710754237004686, 0.659711914403098, 0.8183492762701852, 1.2530708121401923, 0.14803249734852994, 2.055104523897171, 0.19267632892089231, 0.5381361352545875, 0.15499703506273882, 0.08491044052477394, 0.0577659456591521, 1.8672538953168052, 14.559845055852618, 36.045847279684885, 47.437853131975444, 41.188754490443635, 37.15112154824393, 35.448868479047505, 20.890419142586843, 30.41403702327183, 64.93072823115757, 65.34715461730957, 78.23182460239956, 84.59926496233258, 85.67504760197231, 31.229157992771693, 0.7445021931614194, 0.06030796854091542, 0.03165945330900805, 0.004693330032750964, 0.11121310413415943, 0.06559760362974235, 0.02720545105902212, 0.06432670075446367, 0.023261198241795813, 0.05208583063046847, 0.04477979302672403, 0.05047980270215443, 0.030287455501300947, 0.07628844532051257, 0.042923612985759974, 0.023091564487133707, 0.04053500008636287, 0.062016784346529415, 0.05952268639313323, 0.05188097073031323, 0.09836885013750621, 0.11559179238975048, 0.0823568282648921, 0.06898493865238768, 0.01870764303021133, 0.06439971112247024, 0.11356004819806133, 0.025309210310557058, 0.046482373095516644, 0.14597435135926518, 0.04811049412403788, 0.007782870454580656, 0.009162023414059408, 0.11562582770628588, 0.020254327982131923, 0.03872940483103905, 0.07305270859173366, 0.036901509522327354, 0.24730424689395086, 0.13127747284514563, 0.1048942535583462, 0.15058794165296213, 0.12955935432442597, 0.13617220733846935, 0.18579735447253498, 0.22737242999885762, 0.09993706670190607, 0.15528538530426367, 0.13520239080701554, 0.10367719922214746, 0.15423020906746387, 0.15910952724516392, 0.1997765600681305, 0.10318721551448107, 0.13536286433892591, 0.13774467153208597, 0.15460123201566084, 0.28337438138467924, 0.28574689264808384, 0.16410144152385847, 0.18770604633859225, 0.2526509671338967, 0.10089935828000307, 0.11792576286409583, 0.23669988449130738, 0.14500064003680432, 0.16747430339455605, 0.2572849270488535, 0.31046000655208317, 2.8960447822298323, 57.86145380565098, 129.86449977329798, 107.58564989907401, 96.56504263196672, 88.46877234322685, 25.41430786677769, 20.676906211035593, 21.284298624311173, 55.80515875135149, 90.07189546312604, 64.79148633139474, 52.913318497794016, 31.347781113215856, 5.926621454102652, 0.25269938739282743, 0.41021111394677845, 0.2782345600426197, 0.2501328151140894, 0.1836820894054004, 2.501343676022121, 1.6057694064719337, 1.0623145337615694, 0.6623394191265106, 0.34790954845292227, 0.5268861874938011, 0.9054280636566026, 1.8096658140420914, 2.7671700290271213, 21.771092891693115, 65.70656408582414, 92.73103359767369, 94.16082000732422, 90.64155047280448, 94.56817204611642, 88.71871294294084, 84.84237548283168, 86.23387731824602, 93.49573843819755, 88.56052330562046, 95.79960128239223, 88.11684608459473, 85.92921965462821, 81.62541512080601, 84.81277615683419, 87.02575656345913, 91.26305988856724, 88.57430853162492, 87.51462486812046, 83.15593651362828, 72.62534400394985, 55.91222701753889, 55.01215042386736, 85.4659902027675, 77.98742866516113, 76.39969580514091, 80.9668995993478, 92.19953114645821, 57.14989921024868, 56.993675913129536, 94.0787478855678, 83.91522870744977, 84.39458492824009, 85.70290987832206, 82.35531643458775, 76.97278322492326, 77.21289212363106, 81.06280558449882, 86.09066104888916, 87.28299971989223, 86.09105014801025, 76.87647424425397, 80.92587048666817, 89.66389724186489, 92.0578921181815, 89.94007423945835, 84.70861571175712, 57.11465447289603, 22.797129903520855, 2.2369037057672227, 2.2260325976780484, 3.845982951777322, 3.139511832169124, 3.476260402372905, 3.757529778139932, 0.35982500335999895, 2.766958326101303, 0.37131895231349127, 1.046011779989515, 0.4902950738157545, 0.16929626491452965, 0.1690374987998179, 4.3168076532227655, 22.28981934274946, 57.422654220036094, 87.77505724770683, 67.46292277744838, 66.96650872911725, 53.37338304519653, 21.744889497756958, 23.24254764829363, 55.09614372253418, 70.89724363599504, 82.021865436009, 99.9878294808524, 96.16711929866246, 26.85530345780509, 0.5219943842717579, 0.15302408593041555, 0.13801698120576994, 0.25831752164023264, 0.2145740246134145, 0.14170405907290323, 0.09882441854902677, 0.19098372331687383, 0.0990782245727522, 0.17066801844963006, 0.1290772416229759, 0.13049111861203397, 0.2208163839365755, 0.1616430820098945, 0.15327128980840954, 0.12410762400499412, 0.11733751371502876, 0.15838977800948278, 0.1292940064200333, 0.21373355042721542, 0.22939863055944443, 0.2386315922651972, 0.23655774497560092, 0.20251579236771378, 0.16682257050914423, 0.1185284105262586, 0.3033672257193497, 0.21253689963902744, 0.18290120416453906, 0.1923000676823514, 0.10826320028198616, 0.05900666729680129, 0.08172958370830331, 0.16935451036053045, 0.09152848433171, 0.18961023273212568, 0.2151858460690294, 0.1806845659656184], [0.094741883687675, 0.06326575018465519, 0.060956865149949274, 0.046515563635953834, 0.0752064465944256, 0.020389383592243706, 0.053922950622758696, 0.020676573538886647, 0.01626355989303972, 0.028607144951820374, 0.048524570119168074, 0.04990556190854736, 0.04125477307076965, 0.040773908873753886, 0.033541085198521614, 0.045469289778598716, 0.023803183176953877, 0.0044472911145671135, 0.05265373729967645, 0.08522265484290463, 0.12611992816839898, 0.03912722312712243, 0.02165606089069375, 0.06317566109022923, 0.016332292097753713, 0.03526859464389937, 0.07172306493989059, 0.001795308876483302, 0.052316413793180666, 0.0326308576124055, 0.5949318504759243, 37.72913176672799, 96.09175913674491, 88.30782427106584, 80.52040140969413, 58.955847195216585, 38.71818004335676, 38.29332201821463, 44.710438523973735, 55.36871460505894, 60.50448254176548, 44.913516998291016, 32.888676166534424, 17.44329101698739, 1.8000907621213367, 0.02418818394653499, 0.21827330254018307, 0.1355353750820671, 0.06337521823921374, 0.030646448023617268, 0.08511045907757112, 0.057481748051941395, 0.09531662320452076, 0.12027892230876855, 0.028286759375727603, 0.17581961915961333, 0.07070623950234481, 0.23335994513971464, 3.111070901155472, 28.039736815861293, 66.36817155565534, 82.07756219591413, 79.24546950204032, 75.22943156106132, 75.65069389343262, 74.23709678649902, 69.09241431100028, 73.5845845086234, 81.6652352469308, 83.41042818341936, 85.00856944492885, 77.71025807516915, 74.62215900421143, 69.376706804548, 70.11488342285156, 71.0792794908796, 77.31850474221366, 77.75902053288051, 81.81857504163469, 78.0284925188337, 80.10017435891288, 80.42713574000767, 73.36064406803676, 33.87244381223406, 46.94000775473458, 63.33586651938302, 67.9740878513881, 75.02065208980015, 65.36062022617885, 29.06162749017988, 67.7401350566319, 85.98300565992082, 78.77935654776437, 72.09004088810512, 66.94273894173759, 64.8569244657244, 67.5696610042027, 74.58733463287354, 82.1205507005964, 80.87168843405587, 81.06336838858468, 79.37862477983747, 76.87221499851772, 80.52591133117676, 81.33807931627545, 75.66935675484794, 73.28678471701485, 80.51191071101597, 82.72833742414201, 72.97112805502755, 42.372456550598145, 21.30847314425877, 3.650517966066088, 0.3193380944430828, 0.6767943863357816, 0.3574613130518368, 0.3033934443124703, 0.34071572018521173, 0.20099301050816262, 0.04111695921580706, 0.1066304753933634, 0.06076082959771156, 0.14618362512971672, 0.19717838162822382, 2.534066217286246, 12.559674075671605, 29.23172460283552, 50.977425302777974, 55.767628056662424, 49.13052463531494, 61.36897046225411, 39.56934131894793, 11.995149442127772, 34.67440489360264, 57.08074378967285, 57.88476153782436, 74.78634493691581, 73.99135289873395, 30.883005687168666, 0.6813351969633783, 0.061187533129538806, 0.035639780440500805, 0.09710817957030875, 0.035285083044852526, 0.03509229428267904, 0.03621609755126493, 0.024319689122161696, 0.006060389377775469, 0.033218207702572854, 0.04762224068066903, 0.026531752298719118, 0.05466032141287412, 0.0369140352787716, 0.027341960430411354, 0.059403650994811735, 0.07098729549241917, 0.08937167256538357, 0.038075789010950496, 0.1393753404596022, 0.2065214424261025, 0.15195125421243055, 0.04837424068578652, 0.035335046970950704, 0.036398335093898435, 0.04752103718263762, 0.046125175298324654, 0.08770569267549685, 0.05494974034705332, 0.05415319791063666, 0.07044684913541589, 0.03321741381660104, 0.03826649467061673, 0.026124860293098857, 0.06174093272004809, 0.07008885405957699, 0.18330041345741066, 0.03101272801203387, 0.09201631708336727, 0.0716822442731687, 0.08154647424817085, 0.030297569065753902, 0.04986902619046824, 0.01937945037414985, 0.01581230866057532, 0.02994982326137168, 0.047424318801079474, 0.031156777603817836, 0.05311618944896119, 0.019705330387556126, 0.03754504909738898, 0.023842740072203533, 0.03170999398987208, 0.032674925069191625, 0.05034187688891377, 0.010547015167373632, 0.07146858716649668, 0.0583775160568101, 0.03239400478612099, 0.015220300427504947, 0.08544609642454556, 0.1552350108644792, 0.010742727567308714, 0.030713812980268682, 0.10434383273656879, 0.03065935375967196, 0.038554824556091, 0.5484807001692908, 58.811845779418945, 114.03608649117606, 99.21873337881905, 98.83934089115688, 72.81644030979702, 61.483907563345774, 45.891833782196045, 26.53161120414734, 36.3250641141619, 44.040184020996094, 42.50294024603707, 36.263287680489675, 23.36427661350795, 2.646282664367131, 0.18146182782948017, 0.1712893665369068, 0.07800070129867111, 0.05680044800309198, 0.04192657023668289, 0.10744382174951689, 0.06278229398386818, 0.13562129118612834, 0.08824348596057721, 0.12773298232683114, 0.21981114787714823, 0.06859769193189484, 0.22636978594320162, 3.490414100033896, 30.78977128437587, 69.81775760650635, 83.57951259613037, 81.860458782741, 79.86240005493164, 79.12407057625907, 76.46795490809849, 71.75429698399135, 75.92959458487374, 85.43259021214077, 86.43677861349923, 87.42270020076207, 83.47872202736991, 77.55536188398088, 72.5715718950544, 72.93541431427002, 73.85489027840751, 79.83632346561977, 81.98013455527169, 86.0094644001552, 81.82168088640485, 81.67949295043945, 82.5028475352696, 74.03056158338273, 38.69056095395769, 54.99022190911429, 70.67729146139962, 72.8697816303798, 83.94254902430943, 71.01798943110875, 36.28694977079119, 68.95363099234444, 88.07892976488385, 78.40901061466762, 73.15412276131767, 68.34950596945626, 67.77291665758405, 69.52642658778599, 80.08003847939628, 84.19471304757255, 85.54790251595634, 82.05534880501884, 79.60100882393974, 76.31414263589042, 81.25414507729667, 84.53739820207868, 78.78113528660366, 77.15784849439348, 84.59467220306396, 86.33252784184047, 77.84708200182233, 48.272734778267996, 26.853437866483414, 5.097925007343292, 0.3780819651271616, 0.3267868890294007, 0.2848172996725355, 0.7910774882350649, 0.20678688532539777, 0.3218758154128279, 0.111119540940438, 0.21941177573587212, 0.08486031714294638, 0.137340318943773, 0.1543702586953129, 2.1975866726466586, 14.171394722802297, 27.33670244898115, 43.437340940747944, 34.71560423714774, 33.09278992244175, 40.94385480880737, 31.811225959232875, 17.9931731905256, 48.68167100633894, 72.87562506539481, 65.3101554598127, 80.82738671983991, 85.91361400059291, 55.57056324822562, 2.489030599594116, 0.2139898602451597, 0.057446443874921115, 0.08124842774122953, 0.05316747651834573, 0.054612847710294385, 0.06101692228444985, 0.05295426045943584, 0.08251347485929728, 0.030124179619763578, 0.03328377114874976, 0.09081064177943127, 0.08417629277599709, 0.03678291177909289, 0.022480192560968653, 0.04434478761894362, 0.06660784727760724, 0.07911904236035687, 0.04019007020230804, 0.07547003030776978, 0.15014322980173997, 0.022959701384284666, 0.05723320745996066, 0.049682459594415765, 0.015996189954291497, 0.04586457035371235, 0.03853461778323565, 0.03947947101135339, 0.06409366468765906, 0.016461661584409218, 0.050880134970481904, 0.03623430264581527, 0.05007064947858453, 0.020856558345258236, 0.040762658763144693, 0.1360906202878271, 0.12599587839628967, 0.16527122232530797, 0.1381267546010869, 0.14906296133995056, 0.09776368511042424, 0.18821771602545465, 0.16557003557682037, 0.1495940506990467, 0.09900343644299678, 0.16911592387727328, 0.12733747783516133, 0.1338395939341613, 0.1378396935760975, 0.0826569918010916, 0.22440678413425172, 0.12541217543184757, 0.17494842090776988, 0.12114826137466089, 0.124652786180377, 0.1246442502098424, 0.14724266901612282, 0.19994041270443372, 0.15177434656236852, 0.14376076656792844, 0.13934514565127237, 0.2307206339069775, 0.10269408340432815, 0.1723997483828238, 0.13759462029806205, 0.19844207167625427, 0.12466660115335669, 2.352114175047193, 75.32634503500802, 129.2942611149379, 111.20813492366246, 108.04834433964321, 81.55564825875419, 51.99628135136196, 53.72893278939383, 54.8224333354405, 74.35469504765102, 84.39951120104108, 65.7328074319022, 51.53461871828352, 30.89100306374686, 4.251911912645612, 0.4436910631401198, 0.7218852096370288, 0.4011336996087006, 0.19877391601247446, 0.16153296934706823, 0.2383770059262003, 0.15253777988255024, 0.48553452640771866, 0.23456059928451264, 0.41152728189315113, 0.5703649744391441, 0.2580690421164036, 0.39683105477264946, 4.753034668309348, 35.62290348325457, 73.9574248450143, 88.38152381352016, 85.50287818908691, 84.20325238364083, 84.04045609065464, 81.7989811216082, 76.45944336482457, 80.6562317439488, 90.16139520917619, 91.68027142116001, 92.01735632760185, 85.55785928453717, 82.06174114772251, 76.42960780007499, 75.99896539960588, 78.36532034192766, 85.20938628060478, 84.82423373631069, 89.68489469800676, 83.86929416656494, 85.08998148781913, 83.05247783660889, 79.44790526798793, 44.58035434995379, 62.20040580204555, 79.83357197897774, 79.80850982666016, 93.278641973223, 78.10968221936906, 41.54307092939104, 73.54077611650739, 92.97590896061489, 83.04871191297258, 76.25147683279855, 73.16080692836216, 71.54842185974121, 73.25598335266113, 83.88795007978166, 88.60115637098039, 88.49154159000942, 84.29537160055978, 83.75172369820731, 79.15883936200822, 85.32396207536969, 89.33027253832135, 83.62826810564313, 81.90247453962053, 91.53168419429234, 90.34550162724086, 80.15470382145473, 47.286236490522114, 27.391181537083217, 5.2480529972485135, 1.3118049119200026, 1.9793837070465088, 1.9802511462143488, 1.992066992180688, 0.5692762242896217, 0.7082177230290004, 0.16889716418726103, 0.538499612893377, 0.5033126867243222, 0.6616944851619857, 0.23536173201033048, 3.699793287685939, 20.172421830041067, 44.6558951650347, 67.77194390978131, 77.93514347076416, 67.56703458513532, 79.14215673719133, 52.74704463141305, 15.859958103724889, 46.583335876464844, 74.66933727264404, 74.45145566122872, 88.41365228380475, 102.34736824035645, 54.08044910430908, 1.938141371522631, 0.2317186232124056, 0.26478827585067066, 0.19296999887696334, 0.1289676446467638, 0.10752988034593207, 0.14655289745756558, 0.1571241066391979, 0.14173504098185472, 0.10408087327544178, 0.15013902288462433, 0.21743512180234703, 0.22003879637590476, 0.1697237826883793, 0.10623711507235255, 0.10649315347628933, 0.23092598574502127, 0.16714973295373575, 0.24219368398189545, 0.26201024491872105, 0.4235266037285328, 0.25032888459307806, 0.14015340299478599, 0.13820159701364382, 0.17431362425642355, 0.16025903342025621, 0.17523785680532455, 0.13363855757883616, 0.18259587697684765, 0.15702699470732892, 0.11162892396428756, 0.07163543892758233, 0.12933861331215926, 0.09659012486892087, 0.17193704178290709, 0.2535690792969295, 0.24213519426328795], [0.10450476088694163, 0.06451032590121031, 0.03953782163028206, 0.03285364101507834, 0.03014207598088043, 0.09021389737193074, 0.03919130736695869, 0.03382026503926941, 0.0303502335612263, 0.03972408967092633, 0.03556669204096709, 0.0785986738545554, 0.014063136984727212, 0.021487801169444407, 0.009321820955457432, 0.04054104244070394, 0.041456762767796, 0.023930011549964547, 0.056630705682826896, 0.05314616373340998, 0.06079767404922417, 0.0645758927400623, 0.07459165315542902, 0.04745400810082044, 0.04062756922628198, 0.1612867018474, 0.06242299612079348, 0.04906925732003791, 0.03466371799420033, 2.8794123147215163, 54.836138657161165, 102.90630217960903, 77.85950538090297, 83.8275841304234, 59.797982760838096, 30.393161160605295, 17.42536813872201, 23.978599854878016, 63.56388555254255, 55.05417660304478, 40.43440246582031, 31.509236403873988, 16.90093547957284, 2.043942025729588, 0.1461288266416107, 0.15519276527421816, 0.06043966540268489, 0.06614752912095614, 0.14730951828616007, 0.17114797340972082, 0.12543747121734278, 0.025440966544140662, 0.02010411220336599, 0.1089699420013598, 0.14215025013046606, 0.12608715492699826, 2.862074387925012, 18.744191816874913, 48.004829611097065, 72.6814090183803, 82.01923901694161, 84.85402066367013, 77.57372597285679, 70.23998573848179, 63.997321128845215, 62.63801029750279, 60.28664261954171, 68.61320400238037, 81.09295381818498, 80.29190989903041, 77.89621966225761, 69.25134740556989, 61.57145486559187, 58.68694496154785, 64.9363910130092, 71.8061444418771, 73.94908005850655, 76.12494318825858, 74.73419175829206, 80.05925641741071, 79.10170432499477, 78.9348224912371, 85.00517872401646, 74.14515822274345, 36.058819566454204, 47.39508696964809, 63.77694511413574, 73.17512716565813, 39.94719130652291, 49.74909496307373, 82.59053380148751, 77.72679478781563, 73.84240436553955, 65.66441631317139, 62.13745512281145, 61.750537736075266, 72.06516633714948, 77.77460534232003, 73.52698394230434, 75.74750314440045, 82.25806944710868, 79.68692329951695, 76.62581103188651, 76.53672817775181, 79.10009929112026, 71.36851215362549, 66.40698419298444, 70.05977031162807, 75.66895375932965, 79.75595365251813, 83.78167043413434, 80.57632746015275, 60.49262196677071, 28.806774514062063, 8.8198869568961, 1.3569467067718506, 0.388698296887534, 0.47173529544046944, 0.07447656004556588, 0.1294987475765603, 0.05924253285463367, 0.023631588456087878, 0.026131050228806477, 0.22283792974693434, 0.021359167893284133, 0.4253901594451496, 3.744341228689466, 16.22580507823399, 42.656304359436035, 63.83702618735177, 56.3615357535226, 61.47608389173235, 57.26970699855259, 20.758735145841325, 22.81419815335955, 45.834413869040354, 59.79714897700718, 60.239999362400596, 76.39675671713692, 39.336823327200754, 2.0754145426409583, 0.2360323688813618, 0.06011922045477799, 0.06006546012525048, 0.06678059550800494, 0.0031841585254629274, 0.04783081216737628, 0.10068376734852791, 0.03140237335381763, 0.026462009076827338, 0.04703410348988005, 0.039761731401085854, 0.026568053922216808, 0.03674180612766317, 0.023373027598219256, 0.0282140170290534, 0.047806948090770414, 0.05845681644443955, 0.10020873176732234, 0.09482416962938649, 0.09677424534623112, 0.062033116684428284, 0.03921538518209543, 0.03488402135138001, 0.0403709744236299, 0.037239555668617995, 0.01192188317820962, 0.05448865544583116, 0.05418439355811902, 0.06833667308092117, 0.03644496062770486, 0.02083479772721018, 0.04260871506163052, 0.07304639143071004, 0.0866802634139146, 0.16754031128117017, 0.10512971878051758, 0.09590449237397738, 0.0359213724732399, 0.03349602708060827, 0.042056180603270016, 0.039064743622605286, 0.03685060582522835, 0.022799402575141618, 0.031535892082112174, 0.08862978273204394, 0.03783834585919976, 0.03789936651342681, 0.02277221198060683, 0.0500932039826044, 0.03957420467798199, 0.028450340598023365, 0.004008807366647358, 0.02329293841363064, 0.04379356273316911, 0.07396833731659821, 0.044948765209742954, 0.12091589027217456, 0.06658695518438305, 0.016302475572696755, 0.032565857350294075, 0.11969311588576861, 0.027958794563476528, 0.07234721537679434, 0.03422083479485341, 3.139412820339203, 80.82254382542202, 119.55156653267997, 90.61733600071499, 100.43933732169015, 72.88330977303642, 56.95107650756836, 22.655364070619854, 23.47218040057591, 57.436272689274375, 52.38974394117083, 44.194315910339355, 35.87617574419294, 19.786758593150548, 2.1007062026432584, 0.07979994546622038, 0.05854212865233421, 0.026263768285779015, 0.1782349052705935, 0.32011908824954716, 0.4190263423536505, 0.019761670846492052, 0.10669245278196675, 0.09488861688545772, 0.16159185261598655, 0.18885943373399122, 0.07244637648441962, 2.4817336882863725, 19.752080133983068, 51.75099604470389, 73.23891857692173, 82.88085733141217, 86.37421008518764, 79.5985769544329, 72.28157493046352, 67.79890292031425, 66.31398255484444, 62.63211127689907, 71.58688708714077, 85.31828539712089, 86.43097686767578, 80.42318221500942, 73.41884912763322, 64.75533485412598, 62.229115758623394, 70.05586542401994, 74.86823640550885, 75.7731419972011, 81.00727558135986, 78.15681185041154, 82.4990816116333, 83.54702976771763, 79.71842643192836, 87.33445807865688, 75.87870597839355, 44.732992376599995, 55.91966506413051, 70.69867106846401, 79.02355793544224, 48.07448182787214, 55.746095589229036, 86.91191727774483, 81.14840739113944, 77.04128551483154, 67.27574525560651, 64.47449561527797, 63.46893841879708, 75.25676577431815, 82.59140232631138, 77.65907764434814, 78.33451897757394, 84.1125019618443, 80.95264189583915, 78.07006359100342, 77.36786474500383, 82.81592641557965, 73.37531171526227, 69.64340645926339, 72.45562730516706, 80.57296453203473, 83.91245637621198, 88.01291493007115, 83.6087714603969, 67.15053871699742, 35.745525291987825, 12.669946329934255, 2.432094237634114, 1.3064770549535751, 0.7685502884643418, 0.12027398257383279, 0.14405862987041473, 0.03662870451807976, 0.0695644754118153, 0.050534818321466446, 0.04888085528675999, 0.1394517977855035, 0.20110424953911984, 4.686292878219059, 17.98724464007786, 41.1980060168675, 45.13256243297032, 50.130908897944856, 51.7748908996582, 36.21955919265747, 31.244006293160574, 36.962999071393696, 66.48378263201032, 71.2601272038051, 67.36501571110317, 83.99161720275879, 63.09770311628069, 9.442102483340673, 0.14790828472801618, 0.06675027177802154, 0.03017303753378136, 0.060316470584699085, 0.049972017628273795, 0.08350180182605982, 0.011159241199493408, 0.07169537392577954, 0.03956659151507275, 0.08093807939440012, 0.053888280875980854, 0.021477667248940895, 0.033294274870838435, 0.024717758476201977, 0.02871605660766363, 0.04768009936170919, 0.04805906795497451, 0.06962765380740166, 0.06458493761186089, 0.05212530101250325, 0.08173406203942639, 0.028388595607663904, 0.0234939459312175, 0.033198815171739886, 0.05122535662459476, 0.005923630220682493, 0.029472874211413518, 0.03632315341383219, 0.053188171836414506, 0.016114548513931886, 0.05378197479460921, 0.022951874482844557, 0.014816107294921364, 0.11934972288353102, 0.11021290958992072, 0.1654039980577571, 0.17648340282695635, 0.181102258552398, 0.14906236422913416, 0.10051073413342237, 0.12676374933549336, 0.14756930220339978, 0.08499365605946098, 0.11565792241266795, 0.13980558594422682, 0.09606160715754543, 0.10990416258573532, 0.08139843826315232, 0.1004674978820341, 0.12540730355041368, 0.23941057760800633, 0.0935787253880075, 0.10220055095851421, 0.09675857118730034, 0.1479709813637393, 0.14454615728131362, 0.18131909120295728, 0.12167982570827007, 0.1996602863073349, 0.11797611016247954, 0.24736941339714186, 0.17934428288468293, 0.1687943254198347, 0.500748801444258, 5.661710526262011, 97.25641618456159, 136.08625030517578, 101.38418810708183, 109.10832677568708, 75.8956526347569, 46.07557541983468, 26.769098894936697, 35.41656282969883, 86.25290843418666, 75.63269805908203, 60.05837345123291, 51.1977596282959, 27.304547922951834, 3.610076193298612, 0.2953074782022408, 0.5170702285000256, 0.23830749679888996, 0.5014381387404033, 0.7800326751811164, 0.9132789309535707, 0.22254489761378082, 0.32670489485774723, 0.2035700050847871, 0.2964940731014524, 0.5179958045482635, 0.42198098238025394, 4.362399561064584, 25.139463186264038, 56.517331736428396, 76.68532930101667, 85.95315619877407, 91.82737173352922, 85.16092954363141, 76.07425607953752, 70.8626902444022, 69.56136213030133, 68.88947132655552, 76.31419127328056, 88.60882023402623, 89.48020771571568, 85.5492365700858, 78.037949017116, 68.931368964059, 66.351989201137, 72.71801212855748, 80.14558778490338, 80.51541260310582, 84.02451692308698, 81.83919034685407, 87.02686132703508, 86.35734680720738, 82.50233336857387, 90.22286592211042, 79.68911893027169, 50.351403032030376, 61.5502906526838, 80.04408155168805, 88.63393102373395, 56.807009083884104, 61.71389293670654, 91.35249015263149, 84.87127998897007, 80.94019767216274, 71.26363604409354, 69.0478207724435, 69.09649290357316, 79.0113777433123, 84.4995722089495, 81.94987515040806, 82.05074214935303, 88.1271641595023, 86.61820997510637, 80.32362147739956, 82.52667985643659, 87.62977736336845, 78.38903454371861, 72.63147926330566, 76.08223261151994, 84.06694957188198, 87.6635525567191, 91.88831438337053, 87.79769447871617, 71.12464427947998, 36.81976890563965, 12.040813871792384, 3.805803256375449, 2.79813272186688, 1.4541507022721427, 0.23178370829139436, 0.23193548300436564, 0.305641593677657, 0.26071470443691525, 0.24149547144770622, 0.4038566063557352, 0.20688705066485064, 1.0096977800130844, 7.2522969245910645, 28.466382265090942, 63.531506947108674, 83.78503336225236, 76.29599394117082, 84.66578006744385, 74.19795758383614, 31.448741912841797, 32.35319239752633, 62.78390162331717, 78.61802632468087, 75.40779181889125, 99.93616962432861, 66.71893051692417, 7.25884473323822, 0.5067076959780284, 0.17748207066740307, 0.14695282599755696, 0.12888518907129765, 0.10018010437488556, 0.2002850134990045, 0.18254904448986053, 0.10407179447689227, 0.10615080541798047, 0.16524182818830013, 0.07897049068872418, 0.10812521340059382, 0.1343610073838915, 0.07652536260762385, 0.147812584148986, 0.16644434151904924, 0.09196420559393507, 0.20341170286493643, 0.21753386221826077, 0.16041635854968003, 0.2586441141154085, 0.16611270074333462, 0.10022214640464101, 0.14729824103415012, 0.14731576080833161, 0.09224456947829042, 0.10392113934670176, 0.1758770096514906, 0.16225327498146466, 0.10903673020324536, 0.16253076866269112, 0.09264474229088851, 0.12719106354883739, 0.1803170306874173, 0.1999970975198916], [0.1539966030312436, 0.09302114602178335, 0.08251779712736607, 0.03465015407917755, 0.020603681914508343, 0.008555714207302247, 0.03022959003491061, 0.027405988691108565, 0.03231679428634899, 0.024754847200321298, 0.051192742838923416, 0.0330452864457454, 0.0503387488424778, 0.08445527244891439, 0.02210577524134091, 0.01861298060975969, 0.06324447132647038, 0.03554733682956014, 0.039836248116833825, 0.050724943833691735, 0.02760886217999671, 0.024106657964044383, 0.06727646211428301, 0.03966837176787002, 0.023028138426265547, 0.17457214609852859, 0.07894104905426502, 0.21999868138560227, 5.8933035390717645, 47.76061085292271, 93.67072187151227, 75.46928337642125, 68.71354988643101, 39.24648632322039, 30.052671636853898, 18.282386745725358, 82.39149570465088, 105.98584106990269, 43.61304351261684, 54.508798599243164, 33.63507945196969, 10.51648940358843, 0.29333636111446787, 0.23477629199624062, 0.06108366298888411, 0.21570078629468167, 0.3210868148931435, 0.0396275137817221, 0.07886147046727793, 0.06152517215481826, 0.13511665112205914, 0.07495181275797741, 0.3663567171565124, 0.9394791764872414, 0.8521276180233274, 18.611524650028773, 56.87491035461426, 79.3194886616298, 80.85618700299943, 69.51102243150983, 77.00311211177281, 78.80944224766323, 77.1442230769566, 75.06060423169816, 64.90112195696149, 60.539119311741416, 61.049721581595286, 57.68385090146746, 67.36227812085832, 67.39545576913017, 62.70512989589146, 59.25687789916992, 60.35694449288504, 58.890325682503835, 63.731601170131135, 70.98262310028076, 70.71889032636369, 72.50297927856445, 78.21310615539551, 75.09150981903076, 80.18442821502686, 76.76128700801304, 76.43335287911552, 77.09061772482735, 72.45926816122872, 30.20765815462385, 51.53827347074236, 51.59087480817522, 43.95844541277204, 76.70775113786969, 73.89660031454903, 71.39508206503731, 65.50298186710903, 62.278760637555806, 58.98749623979841, 64.88917800358364, 70.59588636670793, 79.04049069540841, 75.69383525848389, 79.69601154327393, 75.42805971418107, 75.79354190826416, 78.10983507973808, 80.85374123709542, 77.87229006631034, 68.94730813162667, 60.171622140066965, 64.5614036832537, 72.37040070125035, 74.08900982992989, 72.77703012738908, 77.30783925737653, 76.43984944479806, 80.9817340033395, 58.738827160426546, 11.236666713442121, 0.934765909399305, 0.6875614342944962, 0.1050067614497883, 0.1715156172535249, 0.23507055906312807, 0.040526555718055794, 0.0615063767348017, 0.08983505091496877, 0.08815210086426564, 0.03837406961247325, 0.09741233967776809, 1.678769352180617, 6.55314746924809, 22.210741894585745, 40.29174552645002, 42.393044063023154, 51.829472473689485, 55.173015117645264, 19.12615861211504, 17.224733693259104, 36.71077251434326, 50.214019775390625, 59.74238327571324, 67.1734538759504, 64.72753511156354, 9.71764806338719, 0.07996208819427661, 0.07328049958284412, 0.04554994384359036, 0.047948524422411404, 0.017141675809398293, 0.07027956311191831, 0.036193522691194496, 0.025993441630687033, 0.03561215049454144, 0.07492884434759617, 0.0929974719349827, 0.03917767220575895, 0.03207438765093684, 0.03213232775617923, 0.06425012129225902, 0.06511585733720235, 0.07232077965246779, 0.02130321250297129, 0.06205898243933916, 0.031097114019628082, 0.12433023777391229, 0.021140011260285974, 0.03577180978442941, 0.1518937415842499, 0.035892008870307884, 0.06649100354739598, 0.05824465211480856, 0.10431120877287217, 0.053922407794743776, 0.08114495793623583, 0.07197363435157708, 0.028752090209828954, 0.05731255534504141, 0.05778834410011768, 0.1151887968714748, 0.06666311395487615, 0.03900818772880094, 0.04318728151598147, 0.045333993288555315, 0.01955991524404713, 0.05448945950982826, 0.011286407991844629, 0.10207124254001038, 0.02475653505618019, 0.07570320208157812, 0.06732174075607743, 0.04044537918109979, 0.03348090932039278, 0.023101152186947208, 0.040222093662513156, 0.09041511693171092, 0.021636040714968528, 0.07885904809726135, 0.030465275780963044, 0.019955955778381655, 0.03468781955806272, 0.021543089899101427, 0.02960589082379426, 0.07973374758980104, 0.055126610677689314, 0.09156414813229016, 0.2621799058147839, 6.524438381195068, 71.18412780761719, 108.72498076302665, 84.5784273147583, 80.65610667637416, 57.882697922842844, 57.06007637296404, 25.120404277529033, 70.77033478873116, 70.42518997192383, 37.43162727355957, 52.99083260127476, 37.75540290560041, 14.834914684295654, 0.36502388439008165, 0.31088471519095556, 0.031872068864426444, 0.545841036098344, 0.7169986718467304, 0.03843311572979603, 0.3480689227581024, 0.0747671223112515, 0.3730669128043311, 0.0972210606560111, 0.2563091665506363, 1.3431747257709503, 0.907128526696137, 18.388979060309275, 60.13030815124512, 85.18370573861259, 85.48671667916435, 72.8193029676165, 78.59436770847866, 81.0040933064052, 80.03027548108781, 78.55806337084088, 69.31374222891671, 63.778293064662385, 63.77345017024449, 59.804062434605186, 69.34610693795341, 70.29937894003731, 67.1809162412371, 61.50969927651541, 62.0536390032087, 60.27631064823696, 65.19950539725167, 74.16673932756696, 74.5510789326259, 75.04669393811906, 81.60229846409389, 79.40100492749895, 82.39912482670375, 81.08196176801408, 77.67569773537772, 79.36750071389335, 75.0950117111206, 36.05921908787319, 58.51608875819615, 58.67543179648263, 50.900463581085205, 78.90073462894985, 76.29797417776925, 73.84693459102085, 67.97204508100236, 63.63321467808315, 59.757690157209126, 65.53641659872872, 75.75704302106584, 81.17793028695243, 76.79595851898193, 83.17860153743199, 78.43977723802838, 78.82015636989048, 81.717346736363, 81.64054134913853, 80.26216466086251, 70.56279904501778, 63.29377433231899, 67.05707849775041, 75.66596603393555, 79.03837844303676, 77.26909610203334, 80.78940786634172, 80.56940705435616, 86.57396384647915, 64.76252623966762, 13.61601826122829, 0.903571754693985, 0.6630802165184702, 0.2807370786155973, 0.36689140275120735, 0.5688488557934761, 0.06414743180253676, 0.14060479163059167, 0.15594910111810478, 0.1935974537794079, 0.08761679780270372, 0.1068750669115356, 1.3885801179068429, 7.670263205255781, 24.75750855037144, 35.730409485953196, 36.52500547681536, 49.98600769042969, 45.73552015849522, 27.124820607049124, 30.96697119304112, 52.22364725385393, 65.97419479915074, 66.8040667942592, 74.2440241404942, 85.43928132738385, 25.773628745760234, 0.1795410987521921, 0.030018823487418037, 0.01575151361924197, 0.011940131529367395, 0.033902384739901335, 0.04686117544770241, 0.06261960842779704, 0.010145404708704777, 0.02953938760661653, 0.04473160007702453, 0.01925815036520362, 0.027438763628846834, 0.008421096252277493, 0.058631627421293936, 0.06920415974621262, 0.035778551029839685, 0.062142591524337015, 0.04418867706720318, 0.11917285594557013, 0.06845609524420329, 0.1317581741937569, 0.025073166637282287, 0.039380303118377924, 0.10316353464233023, 0.02664075555678989, 0.07443369698843785, 0.043701834976673126, 0.08402599726936646, 0.02482006968265133, 0.028460849409124682, 0.040027567850691934, 0.027493604525391544, 0.10703543866319315, 0.044825203982847076, 0.18614044891936438, 0.19287565536797047, 0.15073998777994088, 0.10195986780204944, 0.08767038171312638, 0.13197483042521135, 0.1232261663036687, 0.11459669364350182, 0.1523894928395748, 0.08041133265942335, 0.1131816292181611, 0.1410911519612585, 0.13824297407908098, 0.17947315025542462, 0.09202235604503325, 0.11104390464190926, 0.21599180996418, 0.0782806377059647, 0.1405412671821458, 0.12881524568157537, 0.17077376134693623, 0.13281026988157205, 0.09341987355479173, 0.15596579307956354, 0.16297009294586523, 0.2980373331478664, 0.12945484636085375, 0.4246581287256309, 9.842069455555507, 94.42658165522984, 123.65549223763603, 94.8454260144915, 92.63004153115409, 59.32623481750488, 44.16669682094029, 25.21367515836443, 102.60800211770194, 126.87348093305314, 56.38396453857422, 76.89632524762834, 53.46523128237043, 18.911909171513148, 1.1423726550170352, 0.5463910294430596, 0.16227361746132374, 1.14686390544687, 1.8217801068510329, 0.12378469561891896, 0.5039997441428048, 0.3302290971790041, 0.427307916539056, 0.19471339961247786, 0.8686315438577107, 2.5537424300398146, 2.211691950048719, 24.890347685132706, 67.79881259373256, 89.36774417332241, 87.16385895865304, 76.57636765071324, 78.9387343270438, 84.76248509543282, 83.79212052481515, 83.62143107822963, 72.87930066244942, 66.6850233078003, 68.10278238568986, 63.93738596779959, 73.5000388281686, 74.14913954053605, 71.63717814854213, 65.60303592681885, 65.77491351536342, 63.868306977408274, 69.63244915008545, 79.95594365256173, 78.81954492841447, 79.52742045266288, 85.32694980076381, 79.85422897338867, 85.95516422816685, 84.85275609152657, 80.16904490334647, 83.6721112387521, 78.92138467516217, 42.743667534419465, 64.7078161239624, 65.26296329498291, 56.70449536187308, 82.51385348183769, 82.18452971322196, 77.40718460083008, 71.41967173985073, 66.01770441872733, 64.39933000292096, 70.9716032573155, 79.41345609937395, 83.97505964551652, 77.55169323512486, 85.7559871673584, 83.42999431065151, 84.33098111833844, 85.75186688559396, 87.04289082118443, 83.89006233215332, 75.00328854152134, 67.37519482203892, 70.32257897513253, 79.36825806753976, 83.05207484109062, 82.10665430341447, 85.83294541495187, 82.9158901487078, 91.99298899514335, 71.89646407536098, 16.291222367967876, 1.3393738440104892, 1.967218496969768, 0.7004512654883521, 0.8779436498880386, 0.6301517805882862, 0.36258563665407045, 0.21448072604835033, 0.49682822610650745, 0.5048254398362977, 0.29414856753179003, 0.3543989488056728, 3.11980630670275, 12.984967231750488, 36.10917316164289, 57.63675948551723, 59.271003586905344, 71.06114469255719, 63.32477024623326, 29.028526272092545, 23.988393340791973, 48.7149771962847, 68.02655369894845, 74.05660343170166, 85.02199336460659, 94.64871556418282, 22.426308018820627, 0.42133672695074764, 0.10955479168998343, 0.15443062117057188, 0.09761144899364028, 0.20272537826427392, 0.1020365965419582, 0.17495608835348062, 0.06422445231250354, 0.10391671529838017, 0.07921018318406173, 0.16226501363728726, 0.08732494632048265, 0.11761284965489592, 0.11794516896562916, 0.15747701270239695, 0.11266546084412507, 0.16002515597002848, 0.1013699969542878, 0.21991375594266824, 0.19550781484161103, 0.16285546123981476, 0.15470544142382486, 0.10811727454087564, 0.3120181943689074, 0.15636846290103026, 0.158792502113751, 0.13281993222023758, 0.24877683073282242, 0.14227461202868394, 0.12709036895206996, 0.11871759966015816, 0.10373779239931277, 0.19490015959101065, 0.18412958325019904], [0.019119858143052886, 0.03616715142769473, 0.026021052916933383, 0.11235772485711745, 0.022262884935896312, 0.04516479379630514, 0.044749713569347344, 0.04279846737959555, 0.04227674858910697, 0.019571950758940408, 0.01165536225640348, 0.06084167704518352, 0.026428385970315764, 0.029151190937097584, 0.03570507247267025, 0.06684309536857264, 0.10910582542419434, 0.0196028783850904, 0.04696573430140104, 0.049725824767457585, 0.059526018000074794, 0.11104148227189269, 0.04525082525131958, 0.05062793707475066, 0.01600848331249186, 0.04751569711204086, 0.4235011450946331, 5.950370831148965, 47.03080333982195, 79.30534212929862, 76.31896468571254, 76.84577015468052, 66.99283545357841, 28.39646601676941, 18.509889875139507, 51.067310673849924, 45.91013881138393, 75.66050474984306, 56.20556606565203, 36.004786900111604, 13.993220329284668, 0.2731615608291966, 0.0369531460372465, 0.025401757398088063, 0.10534258200121777, 0.11558568557458264, 1.792519939797265, 0.1073426589635866, 0.12488385449562754, 0.06959463629339423, 0.2609165550342628, 0.11755088583699294, 0.03487425723246165, 2.748773370470319, 31.846602712358745, 75.53597218649728, 78.24119772229875, 74.65070915222168, 72.82038688659668, 76.19320923941476, 73.46029513222831, 76.18628883361816, 78.62781633649553, 76.80367101941789, 68.1922195979527, 61.75978578839983, 58.19120141438076, 56.67260660443987, 56.10709619522095, 59.71327032361712, 59.03891290937151, 58.93111160823277, 57.984836442129954, 55.990838936397004, 57.72848265511649, 64.60242584773472, 67.52551215035575, 70.15066664559501, 73.17983109610421, 76.33584880828857, 78.97835295540946, 75.71687548501151, 73.53490488869804, 69.04322801317487, 76.64212540217808, 63.278154781886506, 26.551401410784038, 30.654128551483154, 68.92281573159354, 74.8576751436506, 65.1916400364467, 61.053939138139995, 58.895460401262554, 57.578134059906006, 62.05675179617745, 66.68563474927629, 72.19067859649658, 77.98391287667411, 78.67555046081543, 78.60046822684151, 69.32895183563232, 64.55419840131486, 70.2996985571725, 75.38596057891846, 73.92778382982526, 61.58319732121059, 58.3012296131679, 58.665322167532786, 59.396578380039756, 65.39782782963344, 67.6148659842355, 68.67261110033307, 68.18574387686593, 69.0501206261771, 72.09970583234514, 54.16149984087263, 18.881220715386526, 3.297394011701856, 0.3133639193006924, 0.9401445750679288, 0.2155614152018513, 0.11111091676035098, 0.08639056288770267, 0.11056463500218731, 0.055643389733242135, 0.0391294012245323, 0.06895040800528866, 0.02774324773677758, 1.7658398342984063, 8.99279374735696, 23.533458300999232, 47.58574553898403, 39.86654009137835, 52.470054694584434, 50.30290460586548, 32.814184529440745, 13.874550308500018, 39.54181603022984, 61.319582666669575, 62.48191901615688, 70.9473957334246, 71.58392020634243, 23.093291657311575, 0.43171429580875803, 0.024750424848337258, 0.022912141168490052, 0.028019567552421774, 0.009320670838600822, 0.04996776660638196, 0.0565616240325783, 0.021570874211777533, 0.04076450437839542, 0.008512200604725097, 0.056574485663856776, 0.026812735346278975, 0.031228926232350723, 0.023418542030932646, 0.019124346652201245, 0.016415919842464582, 0.12586496184979165, 0.022251190384849906, 0.044559462528143606, 0.04303667727591736, 0.05124712742066809, 0.021814965310373476, 0.04766652526866112, 0.03878150274977088, 0.06381410825997591, 0.0489587646776012, 0.021151285119620816, 0.1410777305385896, 0.04503586196473666, 0.018731744594073722, 0.09274863278759377, 0.006480279145762324, 0.05557254049926996, 0.0417239461094141, 0.012540750371824418, 0.007261926890350878, 0.04259963287040591, 0.06657981021063668, 0.03460806455197079, 0.08808862391327109, 0.027810205572417805, 0.014396711585244961, 0.0184564171358943, 0.0491786032382931, 0.031114762715463127, 0.021546608103173118, 0.0673777741779174, 0.05640982896355646, 0.0306848870324237, 0.05852412711828947, 0.019850765887115682, 0.06645154673606157, 0.05674039086859141, 0.029858862249446765, 0.08877023269555398, 0.0560142057282584, 0.02843025087245873, 0.07809294813445636, 0.0859350012615323, 0.5331999287009239, 8.816551821572439, 67.50887121473039, 96.66208812168666, 91.18835980551583, 92.48329557691301, 84.8405203138079, 44.128895146506174, 22.91214517184666, 41.47651760918753, 59.91277394975935, 84.48340375082833, 50.063045842306956, 39.39033487864903, 17.872107778276714, 0.26201043490852627, 0.080385304056108, 0.02821403568876641, 0.035525810306093523, 0.2067263192896332, 2.2065374723502567, 0.45684818284852163, 0.13684558549097606, 0.5208800669227327, 0.87331799524171, 0.23743381510887826, 0.01900671242869326, 3.348704286984035, 30.833062035696848, 79.54547187260219, 83.21467658451625, 80.46474633898053, 76.65450709206718, 78.6828669139317, 73.64695153917584, 78.22383417401994, 83.07043892996651, 80.38555771963937, 71.40902015141079, 63.62494632175991, 62.11303915296282, 60.29898262023926, 57.79033899307251, 62.10185950142996, 61.59353624071394, 61.00542681557791, 61.21959808894566, 59.207622119358604, 61.8986941746303, 67.71448925563267, 69.3799307686942, 73.42422703334263, 76.47349957057408, 79.5784341267177, 83.5443616594587, 78.2516895021711, 77.5478995186942, 72.99024949754987, 78.05668830871582, 68.28413731711251, 32.51106936591012, 36.88025992257254, 72.3766610281808, 75.68337821960449, 68.37718064444405, 64.34928907666887, 62.67378657204764, 60.7467314856393, 64.74796281542096, 70.57607010432652, 75.95171764918736, 80.1980814252581, 80.96668420519147, 80.26646559579032, 73.65030057089669, 66.17241300855363, 73.07705334254673, 78.24341419764927, 77.049227305821, 64.73377459389823, 59.76474952697754, 61.863126346043174, 62.69961997440883, 69.97892802102226, 71.41161182948521, 70.71426282610211, 73.19486004965646, 73.28842449188232, 75.59788063594273, 58.97411400931222, 21.933018922805786, 4.4639822244644165, 0.028126550472474525, 0.9127915799617767, 0.5912584790161678, 0.45843839751822607, 0.3173364975622722, 0.15233430080115795, 0.06008829961397818, 0.1164655690746648, 0.08516233986509697, 0.09331476848040308, 1.4451885031802314, 10.083208424704415, 27.50087969643729, 42.85399450574602, 32.610289641789024, 41.673526832035606, 31.743210043225968, 25.94436856678554, 27.881995337350027, 60.612429755074636, 75.19514914921352, 73.70685195922852, 74.98536913735526, 87.03119700295585, 44.22593716212681, 2.10150785105569, 0.11495538082505975, 0.040816446234072955, 0.09257424928780113, 0.050788600596466234, 0.016506109020805786, 0.020705733581313064, 0.028317983860948255, 0.033330661311213455, 0.01019901321602187, 0.03366757769669805, 0.02785109748531665, 0.1487456105117287, 0.05429665378427931, 0.03136431093194655, 0.051217153136219294, 0.1065243457310966, 0.04673159900786621, 0.044343148956873586, 0.09892427176237106, 0.03002930006810597, 0.02500318592813398, 0.0881716562435031, 0.05747712044311421, 0.10524924272405249, 0.04084098206034728, 0.03455578003610883, 0.09032666310667992, 0.05762548891029187, 0.06623003897922379, 0.02768323809972831, 0.07412032237542526, 0.01874175977094897, 0.14925600455275603, 0.1252856965043715, 0.09585820950035538, 0.2017975223383733, 0.15764268381255014, 0.09637893084436655, 0.14474210462399892, 0.18092160538903304, 0.10715025357369866, 0.11566932180098125, 0.09909089282155037, 0.14872258103319577, 0.13352923201663153, 0.1897053633417402, 0.14366588023092064, 0.10695415016795908, 0.1461480970361403, 0.08825627634567873, 0.20511545001396111, 0.15678948030940124, 0.08204306688691888, 0.13843129468815668, 0.18169874511659145, 0.10703509939568383, 0.1416700237563678, 0.1912173700651952, 1.1861372951950346, 16.83242276736668, 93.09729398999895, 110.53454181126186, 102.26968043191093, 105.65494006020683, 86.60843385968889, 43.00753232410976, 24.455338341849192, 72.64786311558315, 59.995436668395996, 86.76139845166887, 81.41610758645194, 53.755461011614116, 23.854141984667095, 0.6388922887189048, 0.36190311184951235, 0.09145842559103455, 0.3270281489406313, 0.6413287722638675, 3.7747200557163785, 0.6764359027147293, 0.5998980754188129, 0.40020451375416344, 0.5777271879570824, 0.7495165669492313, 0.4715968200138637, 4.85823951448713, 39.94361993244716, 85.46666417803083, 86.19757992880685, 85.1759307043893, 81.55698926108224, 82.30326053074428, 75.55943625313895, 81.90313461848667, 86.74722412654332, 84.16175774165562, 73.92928464072091, 68.01546437399728, 64.54529081072126, 62.749084200177876, 60.51798289162772, 65.67818069458008, 65.7770813533238, 64.00994600568498, 64.79439762660435, 63.80361924852644, 64.03192315782819, 70.90993104662213, 72.71541350228446, 76.84218488420758, 80.62314442225865, 84.73563725607735, 88.95159571511405, 79.98185348510742, 79.71913514818463, 75.22384520939418, 82.5084477833339, 71.8421083177839, 41.49904366901943, 42.6644789150783, 76.06857940128872, 82.19351373400006, 72.32181889670235, 67.39833927154541, 66.16819545200893, 63.25917230333601, 67.79449776240757, 75.72747148786272, 80.59191921779087, 83.84190436771938, 82.80772754124233, 85.3723840713501, 77.13512093680245, 69.66556426456997, 77.78027507237026, 83.05928012302944, 82.7631617954799, 66.83897454398019, 63.139663287571494, 64.4132889338902, 66.6200645991734, 73.28416524614606, 74.11847019195557, 74.52591255732945, 76.02764061519078, 75.93941238948277, 79.19663756234306, 63.669449533735005, 24.87491226196289, 4.409282096794673, 0.8530420660972595, 2.733085423707962, 0.9488571818385805, 0.4797246381640434, 0.5385053668703351, 0.35505642209734234, 0.19285611355943338, 0.34184824941413744, 0.29360199400356835, 0.3222337562058653, 2.8506723940372467, 16.6765364578792, 39.269877433776855, 70.64654568263462, 56.89194733755929, 73.51082938058036, 67.59008870806012, 43.89177049909319, 22.847648518426077, 51.06808887209211, 80.50967339106968, 79.85308946881975, 88.33271271841866, 99.61485018048967, 44.766614709581646, 1.223493524960109, 0.13186688907444477, 0.11450309652302947, 0.2242193999035018, 0.13555464547659668, 0.0871631767866867, 0.11023103326026883, 0.08552945445158652, 0.13231986548219407, 0.1187547290963786, 0.18947775555508478, 0.11240296957216092, 0.2574126273393631, 0.10503865259566478, 0.15670559981039592, 0.14620361477136612, 0.2289001244519438, 0.06964534321533782, 0.10492996485637766, 0.22391110073242868, 0.12562980875372887, 0.223204284374203, 0.12841984975550855, 0.16136613115668297, 0.28977467651878086, 0.203533106350473, 0.09408527213547911, 0.2695091968136174, 0.08905495277472905, 0.12584683139409336, 0.1319200862199068, 0.14554694215101854, 0.13876265047916345], [0.026342576735519936, 0.08179949995662485, 0.0841483778453299, 0.09263891367507832, 0.06033468246459961, 0.03251556094203677, 0.05112550341125045, 0.026948744298091958, 0.0073075371661356515, 0.05806408037564584, 0.01788168101172362, 0.014929575313414847, 0.016298573996339525, 0.06393087056598493, 0.06365345830896071, 0.026135262234934738, 0.04437611897342971, 0.025851274973579814, 0.0782443903652685, 0.09397006367466279, 0.029223461701933826, 0.04478449188172817, 0.05693963249879224, 0.07141705243183033, 0.0574283269899232, 0.32088995831353323, 10.281279853412084, 78.62528719220842, 88.05663994380406, 93.1573611668178, 66.73603698185512, 54.795168604169575, 30.38095317568098, 28.101475034441265, 59.433605330330984, 48.577409812382285, 50.041502952575684, 34.96981450489589, 29.18871177945818, 13.744856102125985, 0.42694264756781714, 0.06772472270365272, 0.1007015924634678, 0.0997815668316824, 0.08973411204559462, 0.087084303876119, 0.07867638647024121, 0.0752630839124322, 0.04302081651985645, 0.5033381996410233, 1.0744177528790064, 0.07794208944376026, 0.945514338357108, 35.81198828560965, 76.64532852172852, 75.07415321895054, 70.4151359285627, 72.74429716382707, 74.32556125095913, 76.37514087132045, 77.30628286089215, 71.18410001482282, 74.689500944955, 75.85816710335868, 69.77861145564488, 65.33334854670933, 61.591139112200054, 62.884122439793174, 64.16401536124093, 64.80831486838204, 65.10918576376778, 66.25547872270856, 59.26154014042446, 58.719893319266184, 54.98779698780605, 57.25970506668091, 59.26324244907924, 64.73157201494489, 66.97203254699707, 73.22213867732457, 71.4351384299142, 75.90113476344517, 70.85506112234933, 71.33823885236467, 62.62512138911656, 83.80849742889404, 34.20443221500942, 33.41666282926287, 85.68515723092216, 64.8114901951381, 69.11157744271415, 54.67637177876064, 59.95708956037249, 56.91152736118862, 65.93104648590088, 67.26352337428501, 73.38108566829136, 72.71055671146938, 72.98671286446708, 74.31732763562883, 73.55681255885533, 58.80036735534668, 58.63429151262556, 60.736760820661274, 62.873526436941965, 54.82684891564505, 58.96552603585379, 59.7899089540754, 56.20758104324341, 55.01448154449463, 58.68208817073277, 60.22756208692278, 69.09112889426095, 71.4943996156965, 77.01569529942104, 65.66239438738141, 66.95939377376011, 65.96721880776542, 41.886506489345, 3.5689743416649953, 1.2862941665308816, 0.29157328286341255, 0.19353140518069267, 0.13344277308455535, 0.0321716013630586, 0.05164438592536109, 0.10304201580584049, 0.09323917289397546, 0.11837468163243361, 1.2177834085055759, 8.265305195535932, 21.836697782788956, 42.03258889062064, 36.860231740134104, 57.67238637379238, 70.23672008514404, 37.801024777548655, 11.43247650350843, 19.58599386896406, 45.482480662209646, 57.03008794784546, 67.8433505467006, 75.85822268894741, 39.231999329158235, 1.1555128927741731, 0.09987012243696622, 0.02745993052875357, 0.07528314140758344, 0.013311643336367394, 0.09891498261796576, 0.009056976015147353, 0.052307545340486934, 0.030595452724290744, 0.03606056036161525, 0.02825023383567376, 0.025950256269425154, 0.059433418326079845, 0.03833755425044468, 0.05334989048008408, 0.04779717040115169, 0.07919356586145503, 0.03662107778447015, 0.024627891601994634, 0.013684563638110245, 0.06306306498923472, 0.03601361591635006, 0.06104320873107229, 0.07535083884639399, 0.062624955283744, 0.05102904287299939, 0.08160716920558896, 0.06038633255021913, 0.05657938468669142, 0.0324620754191918, 0.061442309458340914, 0.03396959363349846, 0.01280057754567159, 0.05093227360131485, 0.060377518380326886, 0.045677521997796636, 0.026796891553593532, 0.04407732268529279, 0.06712277393255915, 0.07088029051997832, 0.04606421231957419, 0.04215429337429149, 0.048953953864318986, 0.018182341574824283, 0.019186481800196425, 0.06820997023688895, 0.038657222275755236, 0.03287432276244674, 0.027541863632255366, 0.053797964472323656, 0.03257505149979677, 0.02619470190256834, 0.1013953945200358, 0.027221281281007186, 0.09263007236378533, 0.019482236555112258, 0.067876897752285, 0.13979189310755047, 17.05689821924482, 99.51956953321184, 103.41690444946289, 101.41027859279087, 75.98642390114921, 63.209214755467, 49.34336532865252, 41.78387464795794, 42.216525077819824, 32.73895985739571, 35.5625444820949, 32.963435309273855, 36.37132522038051, 17.539732013429912, 0.6583311227815491, 0.024044943507760763, 0.08832002471068076, 0.2003216136779104, 0.07984790432133845, 0.09160868038556405, 0.3097319927598749, 0.18267822398671082, 0.1605251548545701, 0.6808740102819034, 0.5095951067549842, 0.1432767811098269, 1.0079850490604128, 34.001402378082275, 81.56380544389997, 80.21276296888078, 74.34602369580949, 75.34678663526262, 78.20420551300049, 79.37640830448696, 79.61673259735107, 72.37508378710065, 76.93880653381348, 79.80580697740827, 73.71294552939278, 69.01121071406773, 63.84075042179653, 66.87475776672363, 66.63495458875383, 67.76636450631278, 67.49377972739083, 68.31406320844377, 63.00449998038155, 61.50482858930315, 57.69624648775373, 59.410099574497764, 61.57463019234793, 67.7075480052403, 69.7757487978254, 74.21597426278251, 75.47879546029228, 78.16014003753662, 74.52854592459542, 74.57309082576207, 65.22388662610734, 84.6967898777553, 39.944693429129465, 37.38197544642857, 88.17445359911237, 67.38775021689278, 70.63677651541573, 57.9983993257795, 60.56113120487758, 58.82966790880476, 69.09267139434814, 69.9556724003383, 77.78934247153146, 75.45807593209403, 73.50519439152309, 78.07735919952393, 76.41459274291992, 61.401029450552805, 60.289804049900596, 62.80564948490688, 64.16454342433384, 57.65612064089094, 61.754498209272114, 62.19925240107945, 58.419342041015625, 58.06654378346035, 61.200712885175435, 64.8279504776001, 74.28001580919538, 76.27883189065116, 81.24119363512311, 69.33716460636684, 70.70145034790039, 72.67423847743443, 46.00664928981236, 4.14116153546742, 0.2538859551506383, 1.1938518583774567, 0.8965063595346042, 0.23119362709777697, 0.16303789216492856, 0.051988810300827026, 0.09678693395107985, 0.0644170001947454, 0.13810065814426967, 0.9189462725605283, 9.2079108442579, 26.73720145225525, 45.610799993787495, 37.930782386234824, 48.19032914297921, 50.6559738431658, 22.34759361403329, 15.417658363069807, 36.52421685627529, 56.746281828199116, 70.79061658041817, 75.26687540326799, 86.41710826328823, 62.8728038242885, 4.415698323931013, 0.2982057183980942, 0.07015768465186868, 0.08606067273233618, 0.013016115890682807, 0.05873991482492004, 0.03316252033359238, 0.03071906484131302, 0.046141249792916436, 0.05277979214276586, 0.042417537820126326, 0.00948164054924356, 0.018109818055693592, 0.055114509005631716, 0.02944332401135138, 0.08171050330357892, 0.02386349476208644, 0.037859885953366756, 0.005879999570814627, 0.03519714829911079, 0.031193442243550504, 0.09743563378495829, 0.022328875859134963, 0.0321884188534958, 0.06312939857265779, 0.019118443397539, 0.070077502168715, 0.016654304461553693, 0.038850489405116866, 0.021780487249738405, 0.04090365494734474, 0.052113440220377276, 0.09269197511353663, 0.231971553925957, 0.1854800579271146, 0.1379423423537186, 0.15940198940890177, 0.18979896046221256, 0.20868185721337795, 0.08871588882591043, 0.10017105271773678, 0.13355934540075914, 0.1874902450612613, 0.1067755122535995, 0.07870985181736094, 0.18932530230709485, 0.10456921492836305, 0.1497371265930789, 0.0907845724640148, 0.11719335216496672, 0.15347255686564104, 0.24020408360021456, 0.18226665178579943, 0.20560836499290808, 0.17944018702421868, 0.16116187854536942, 0.20669851292456898, 0.46021713635751177, 26.65031944002424, 118.29044069562639, 113.35050078800747, 116.03245680672782, 89.8913187299456, 72.42319311414445, 45.82951191493443, 38.44571338381086, 84.01536614554269, 67.1323413848877, 63.98773956298828, 56.006687777382986, 44.534499713352744, 24.235830851963588, 1.3702402391604014, 0.12383456794278962, 0.19736378453671932, 0.5933116716997964, 0.3970040540610041, 0.3064505974096911, 0.8718659303018025, 0.7001111837370055, 0.26079908705183436, 1.3925120383501053, 2.199001065322331, 0.34666500666311806, 2.056325452668326, 42.71646533693586, 85.490051814488, 84.34772627694267, 76.12037127358573, 78.02059936523438, 80.96594769614083, 84.30641228812081, 82.77770437513078, 73.14872401101249, 78.68559060777936, 83.13517529623849, 77.22179276602608, 70.58418560028076, 69.64205156053815, 70.73593425750732, 70.81046758379254, 70.95458711896623, 72.01774488176618, 73.728773525783, 66.11281830923897, 64.10049492972237, 61.325113432747976, 62.38762501307896, 66.25856372288295, 71.16788291931152, 74.48625223977226, 77.84920815059117, 77.37210314614433, 80.45648493085588, 77.66599805014474, 76.54151548658098, 69.4447991507394, 87.92331096104213, 44.28707436152867, 42.66235276630947, 89.77987657274518, 73.0413396017892, 73.61103630065918, 61.50567626953125, 63.19357436043875, 61.027355330330984, 73.0777759552002, 73.94849640982491, 79.80006081717355, 78.54451438358852, 75.11623150961739, 82.70523466382707, 81.404538835798, 66.37999044145856, 64.14990356990269, 66.39053085872105, 68.15113489968437, 59.97941412244524, 64.3807783126831, 66.77774006979806, 62.7689699445452, 60.58854879651751, 65.3732659476144, 67.32807213919503, 77.6621070589338, 79.67938450404576, 85.2569328035627, 69.44297872270856, 72.95363249097551, 76.0539881842477, 50.214130946568076, 3.6566093649183, 2.4189048196588243, 2.84063007576125, 0.9033459925225803, 0.26932675231780323, 0.21726147112037453, 0.2418923872922148, 0.31681220712406294, 0.19892978907695838, 0.32863850252968924, 2.728932572262628, 15.111781290599279, 38.32027408054897, 62.206256185259136, 54.29995659419468, 85.42405087607247, 91.87057563236782, 48.81261675698416, 17.140952314649308, 30.9080365725926, 63.38237081255232, 75.38203484671456, 84.69333662305559, 100.99233055114746, 65.43278421674455, 3.6367010389055525, 0.3729094112558024, 0.1539108904876879, 0.16472846216389112, 0.08114930734570537, 0.17223215023321764, 0.15215477400592395, 0.1091319965198636, 0.19589848816394806, 0.11649230335439954, 0.1815737589661564, 0.12849144877067634, 0.12069654704204627, 0.12499208083110196, 0.12373513542115688, 0.09258288025323834, 0.16992859169840813, 0.13907128891774587, 0.09449704789689609, 0.08377725990223032, 0.10675455909222364, 0.24475971343261854, 0.1689635927655867, 0.2246660523648773, 0.1237815607871328, 0.10549456706004483, 0.22721255357776368, 0.14191862541650022, 0.1613472950245653, 0.1204641895102603, 0.1020415091354932, 0.14422583446971007], [0.058519234880805016, 0.06661261059343815, 0.02783377787896565, 0.10552045995635645, 0.06256567846451487, 0.025728880826916014, 0.06030433837856565, 0.03394220456747072, 0.02229542238637805, 0.06618479426418032, 0.02649362711235881, 0.0549657673441938, 0.005946777170590524, 0.041866058483719826, 0.04383274134514587, 0.04791772232523986, 0.053282756225339005, 0.015370460227131844, 0.05236398588333811, 0.034146911797246764, 0.037224010431340764, 0.005840044460325901, 0.011417455156333745, 0.14405450437750134, 0.10314875614962407, 15.873651266098022, 103.54884379250663, 96.20710618155343, 90.37762314932687, 83.27876676831926, 71.35591506958008, 41.11033364704677, 23.297761508396693, 30.81923164640154, 43.21082271848406, 58.37617983136858, 59.994714055742534, 46.76834208624703, 19.413692440305436, 0.9216432592698506, 0.07420686273170368, 0.07767530983047825, 0.023748213358755623, 0.11746453547051974, 0.01854020094365946, 0.0912707903023277, 0.051479230501822064, 0.07242996272231851, 0.01789527546082224, 2.4767982959747314, 1.0051626690796442, 0.7110920516507966, 29.801376138414653, 81.18936007363456, 74.9230854851859, 76.59872695377895, 69.91387203761509, 64.37050887516567, 68.46573543548584, 73.33039855957031, 76.35333047594342, 74.21809346335274, 70.37666375296456, 75.10341208321708, 69.88279274531773, 67.97919477735246, 64.55134269169399, 66.80888189588273, 68.21295302254813, 71.72626100267682, 74.22117151532854, 71.35367774963379, 64.97464779445103, 59.497174399239675, 55.69841357639858, 54.74440506526402, 53.19239289419991, 56.15093585423061, 59.04201875414167, 68.88183525630406, 73.6248562676566, 73.57643427167619, 68.5792064666748, 72.479800088065, 64.71896798270089, 77.46088027954102, 55.88750532695225, 18.896616186414445, 77.39777673993791, 66.11060878208706, 70.90639441353935, 55.945415088108604, 56.594970907483784, 58.5733071735927, 67.62539250510079, 69.2893818446568, 70.20943450927734, 70.63198920658657, 71.28239618028913, 71.84228897094727, 74.0424360547747, 59.6810028893607, 52.82290506362915, 51.45983525684902, 52.73421130861555, 55.26877171652657, 58.87946564810616, 55.15435225622994, 54.29846273149763, 55.8980005809239, 57.80934926441738, 67.47779192243303, 73.0750731059483, 71.80843734741211, 67.70461586543492, 64.76645892007011, 70.5443446295602, 73.01642336164201, 79.1961372920445, 73.55242129734584, 12.30213735784803, 1.5042582878044672, 0.40656681092722075, 0.09924989393247025, 0.08257638862622635, 0.07608879317662545, 0.039064407747771056, 0.1108775142846363, 0.3261125609278679, 0.042282580597592254, 0.5789682556475911, 2.9896930371012007, 14.1259491613933, 25.437240396227153, 33.35572712762015, 32.33579758235386, 64.22248445238385, 55.2355489049639, 12.615332620484487, 15.085169689995901, 35.884847096034456, 54.30403518676758, 60.918880053928916, 72.6815618787493, 40.47634874071394, 2.205307641199657, 0.19580768660775252, 0.03030633573819484, 0.1610526479780674, 0.010638463028174425, 0.019045962286846976, 0.042953102117670436, 0.03340326455820884, 0.04219270524169717, 0.044124440156987736, 0.05725092400929757, 0.026334836347294704, 0.05643280415928789, 0.028752548220966543, 0.004345912469684013, 0.028980654730860676, 0.038694290643824, 0.05255445405574782, 0.01929709148992385, 0.04316946318639176, 0.040534053530011854, 0.05905472793217216, 0.038110804810587845, 0.08710767940751143, 0.009135367165851806, 0.018700845805662017, 0.04094999210376825, 0.043047031720301936, 0.03358972258865833, 0.04789342059354697, 0.032947136355297904, 0.05092833809820669, 0.005314355391809451, 0.050073692708143165, 0.057977777506623945, 0.16627861612609454, 0.03254080244473048, 0.034397650842687914, 0.06282700265624694, 0.02726207989534097, 0.05210906366950699, 0.015876221570319364, 0.05535113113000989, 0.02284383474450026, 0.028085504192858934, 0.0346882809618754, 0.027090973719688397, 0.06312664372048207, 0.047128833763833554, 0.051614286111933846, 0.01165700685565493, 0.010934931093028613, 0.027176932232188325, 0.03607412088396294, 0.050310097701315365, 0.196073319496853, 23.915727342878068, 121.56600216456822, 108.66442721230644, 98.104006086077, 97.71490001678467, 93.87211540767125, 69.53099850245884, 31.853259086608887, 27.74811049870082, 38.68434926441738, 50.038786206926616, 54.23924323490688, 51.55261107853481, 23.039729731423513, 1.1708321507487978, 0.045764941056924205, 0.09332850881453071, 0.001693602732432607, 0.06700003373303584, 0.22392837623400347, 0.11136249040386506, 0.1270114281880004, 0.2465439076934542, 0.018133541336283088, 2.1878001349312917, 0.9611634186335972, 0.7432268187403679, 32.109129973820274, 86.98461627960205, 79.16036101749965, 80.06881713867188, 73.89890016828264, 68.95694528307233, 71.31097412109375, 75.0830330167498, 80.43104757581438, 74.50130203792027, 71.69441740853446, 77.64429187774658, 72.79545675005231, 71.66195542471749, 68.42303875514439, 71.03313650403703, 70.98350552150181, 74.91160011291504, 75.22738879067558, 75.06451606750488, 68.64190701075962, 63.01466519492013, 58.41643074580601, 57.81721115112305, 55.430588313511436, 57.85593693596976, 61.63333552224295, 71.08116940089634, 76.11760589054653, 75.29048538208008, 71.9952952521188, 76.13491385323661, 69.55565071105957, 80.77976376669747, 58.26824304035732, 20.25578110558646, 79.67370087759835, 69.75514044080461, 73.33688122885567, 58.43052864074707, 58.48229272024972, 62.41156850542341, 70.41514982495988, 71.22771385737828, 71.88413102286202, 74.10317720685686, 72.42709800175258, 74.59077399117606, 79.08035251072475, 64.62900965554374, 55.98705564226423, 54.57100234712873, 55.541252272469656, 58.35688468388149, 59.94609751020159, 56.44688742501395, 56.053713185446604, 57.066597257341655, 60.89502688816616, 70.69300828661237, 76.57496411459786, 77.30197497776577, 68.86499977111816, 66.95618370601109, 75.14657429286412, 78.36740480150495, 84.09934902191162, 80.6475464957101, 15.332021815436226, 0.34211005536573275, 0.34492562285491396, 0.5373431178075927, 0.49908861624343054, 0.5507290938070842, 0.21009657558585915, 0.11721327395311423, 0.26425331884196823, 0.07288344124598162, 0.16759018360504083, 1.5620448270014353, 13.856639589582171, 29.60787922995431, 37.55849443163191, 35.49991341999599, 61.35251712799072, 42.91691044398716, 10.304694414138794, 28.73555200440543, 55.76922961643764, 65.70578588758195, 66.68710776737758, 81.23571150643485, 66.76153687068394, 4.772317222186497, 0.09197743024144854, 0.0681285663907017, 0.1200079425637211, 0.017514954886532257, 0.0036947593076287633, 0.05738221375005586, 0.07263220008462667, 0.03222179599106312, 0.0373288644477725, 0.09750806061284882, 0.03872458044705646, 0.09731520060449839, 0.01723826696564044, 0.02168830657111747, 0.03759415806936366, 0.009540775724287544, 0.014884949761575885, 0.017488895749141063, 0.012205529475717672, 0.06494782492518425, 0.03919892731521811, 0.061940645932086875, 0.09896079730242491, 0.07013458053448371, 0.0357357185067875, 0.03600901544892362, 0.036926561035215855, 0.023344157629513314, 0.017652997747063637, 0.011623434639269752, 0.12586395761796407, 0.10919191794736044, 0.11150822615517036, 0.2664503609495503, 0.21056511758693627, 0.133239619699972, 0.19779134302267007, 0.15875909104943275, 0.1315634346434048, 0.12515616416931152, 0.05870602200073855, 0.17047961641635212, 0.05427812299292002, 0.0970443972785558, 0.12253013865223952, 0.20208759605884552, 0.15483611369771616, 0.1479919073837144, 0.15278442736182893, 0.1068950497678348, 0.11149105243384838, 0.12502205850822584, 0.1378333560590233, 0.22446330610130513, 0.41707254147955347, 32.41057756968907, 139.38198934282576, 120.08218656267438, 113.15549264635358, 107.9704063960484, 92.38308865683419, 62.11142717088972, 33.70290081841605, 44.274595396859304, 58.46315738133022, 83.09599440438407, 89.00164358956474, 68.40789863041469, 32.42598172596523, 2.147606326001031, 0.12479246939931597, 0.17351911403238773, 0.22311288570719107, 0.3468802651124341, 0.4889481003795351, 0.7351690254041127, 0.15787015589220182, 0.4681391684072358, 0.2627095431089401, 4.956468803542001, 2.8913469314575195, 1.5175241359642573, 36.25325795582363, 88.15673569270542, 81.36486462184361, 82.76306452069963, 76.61748708997453, 72.75414970942906, 75.86259310586112, 78.61518451145717, 84.84596770150321, 78.18944753919328, 72.03813784463065, 80.44383920942033, 76.07513850075858, 76.24378517695835, 72.67239720480782, 74.20535046713692, 74.63468660627092, 78.2885913848877, 79.25710078648159, 77.72880281720842, 71.51415334429059, 66.78180476597377, 61.820492199489046, 61.773070744105745, 59.0513710294451, 61.30414376940046, 65.79727281842912, 75.59924248286656, 81.02021312713623, 76.90929058619908, 76.42302090781075, 79.806168283735, 74.3616224016462, 83.11509500231061, 60.526709829057964, 26.53680498259408, 83.22967774527413, 73.20911080496651, 76.23084763118199, 60.657002449035645, 60.62372752598354, 65.51106262207031, 72.15220642089844, 75.77177320207868, 75.86831842150006, 78.35112517220634, 75.14494841439384, 77.80556651524135, 82.30741555350167, 66.94209970746721, 58.3079137802124, 55.65432030814034, 57.68414619990757, 61.21069744655064, 64.08891228267125, 60.672385760716026, 58.98301465170724, 61.08142621176583, 63.05447837284633, 74.31516674586705, 79.91312190464565, 80.02132620130266, 70.12439550672258, 67.33592360360282, 76.80014828273228, 79.32398414611816, 85.95376069205147, 82.6065285546439, 15.141121796199254, 3.831327029636928, 2.955247776848929, 0.3724304198154381, 0.3265493203486715, 0.3044254960758345, 0.36007473138826235, 0.34250458276697565, 0.6056302306907517, 0.15785961145801203, 1.1102690462555205, 5.220115593501499, 23.06229748044695, 43.47432620184762, 48.412296295166016, 50.513233525412424, 93.0395405633109, 72.41359765189034, 20.60832749094282, 25.47953234400068, 51.59031547818865, 76.39943177359444, 75.95662307739258, 94.62730816432408, 73.00511864253453, 4.870818793773651, 0.29105906188488007, 0.11645615100860596, 0.22675553310130322, 0.09136427885719708, 0.10796338958399636, 0.17681458219885826, 0.11886997148394585, 0.08118557504245213, 0.12808766615177902, 0.11475059895643167, 0.2027178600962673, 0.2493321437920843, 0.17459841897445066, 0.0967753581436617, 0.18655427385653767, 0.1349414533802441, 0.08763356440301452, 0.14952933202896798, 0.15405058727732726, 0.12968792313975946, 0.13006586714514665, 0.1475851120693343, 0.23632905153291567, 0.11681633096720491, 0.136609550299389, 0.07776712240385157, 0.13222842610308103, 0.08802844464246716, 0.13248977065086365, 0.09030871585543666], [0.03653327874573214, 0.02352759787546737, 0.015472913925935115, 0.0081280318887106, 0.03626808011904359, 0.04287150488900287, 0.051693902018346956, 0.08793617066528116, 0.06617430411279202, 0.03241489687934518, 0.03174870441268597, 0.011565230753538864, 0.006138465857865023, 0.004267944131113056, 0.028600359601633887, 0.03650008820529495, 0.012830087881801384, 0.01228349908654179, 0.02481177119937326, 0.031767588042254956, 0.03450848275263395, 0.07185379149658339, 0.08508248986410243, 0.07147877876247678, 6.663202158042362, 96.34026840754917, 90.88215269361223, 80.62593759809221, 82.30020332336426, 76.8799969809396, 25.474779776164464, 13.290198121752058, 34.54368495941162, 54.20086485998971, 56.97015626089913, 34.466031891959055, 27.073077372142247, 16.580213580812725, 1.1633237536464418, 0.09574829361268453, 0.05346322279157383, 0.021048677054100802, 0.07694507722875901, 0.1243518694703068, 0.038873064265187295, 0.06721891555935144, 0.11015574979994978, 0.13770256164882863, 0.49066701957157677, 0.39699357748031616, 1.0718983794961656, 17.6373542036329, 75.28599684579032, 74.49178995404924, 76.93203898838588, 71.90088312966483, 65.20376464298793, 57.564859526497976, 63.065032686506, 69.93487644195557, 73.36197117396763, 73.77594484601701, 71.40568501608712, 72.7815603528704, 73.6364528111049, 67.16683224269322, 67.32912131718227, 68.11818654196603, 75.55595520564488, 71.05739961351667, 71.23175770895821, 71.90664318629673, 72.95423698425293, 66.2395326069423, 61.33429200308663, 56.61215032849993, 52.08601038796561, 49.24154642650059, 52.963421957833425, 61.62524781908308, 70.79846804482597, 74.57165254865373, 71.59240395682198, 67.29126753125871, 68.71434892926897, 74.0305893761771, 54.08459023066929, 14.81737916810172, 62.51197692326137, 71.40487902505058, 65.69158376966203, 58.17047841208321, 52.393350056239534, 61.47663279942104, 64.08358996255058, 72.31154251098633, 67.45647484915597, 69.5450963973999, 72.02781976972307, 71.59011105128697, 73.48874800545829, 61.55389676775251, 53.99098409925188, 50.97875588280814, 52.73462125233242, 59.759461947849815, 63.66325174059187, 62.71307168688093, 56.43884835924421, 54.02961955751692, 58.16497891289847, 68.80844838278634, 73.28465162004743, 72.22282096317836, 67.11800030299595, 71.20805045536586, 75.6740745816912, 71.46196542467389, 70.06410598754883, 74.01315634591239, 78.39059788840157, 13.93298031602587, 0.8642597155911582, 0.15266925282776356, 0.2541469197188105, 0.17998746622885975, 0.03625174438846963, 0.02840027998068503, 0.048203083620007546, 0.090914695124541, 0.040721335980509005, 0.022871038909735422, 0.1771832031330892, 6.06652169568198, 20.521216188158306, 35.20600461959839, 24.850159304482595, 32.74305234636579, 82.85618427821568, 37.27463967459542, 14.369098765509468, 46.07691642216274, 57.01198789051601, 67.13412707192558, 64.21550846099854, 37.15879235948835, 3.2485803110258917, 0.07046678449426379, 0.02256373379246465, 0.01611772575415671, 0.0130015358694696, 0.033801703713834286, 0.029435324083481516, 0.006249534406898809, 0.024649748911282847, 0.03795029056657638, 0.04973934118502906, 0.0616881630516478, 0.0027591258861191037, 0.041675614060035775, 0.04040395801088639, 0.04684659373015165, 0.004985116205976478, 0.05095359317160078, 0.03408689537484731, 0.04590267348768456, 0.02983591758779117, 0.025189060418467437, 0.012101590633392334, 0.05403787749154227, 0.035522349777498415, 0.059449764234679084, 0.07023799605667591, 0.02651947081488158, 0.03479895341609206, 0.0885680496160473, 0.020234090675200735, 0.024811557460842387, 0.032524867049817524, 0.029833661458854164, 0.03416180903358119, 0.04113470969189491, 0.020953850088907138, 0.029525671021214554, 0.03771955473348498, 0.07013023791036435, 0.06342592516115733, 0.03554443269968033, 0.011815739945242447, 0.0612787553774459, 0.014592294215357729, 0.02449307687181447, 0.03838383712406669, 0.053747637529990504, 0.01526571816897818, 0.04770150714154754, 0.024369098345882127, 0.010687310764166926, 0.10438607154147965, 0.07178416023296968, 11.574083396366664, 115.66689818246024, 101.40048858097622, 91.97479861123222, 95.41649845668248, 85.00219099862235, 39.37784201758248, 22.862844228744507, 32.70214830126081, 37.49277489525931, 44.23864541734968, 42.50091484614781, 35.079818384987966, 21.17645389693124, 1.675582843167441, 0.07146343708570514, 0.07999174695994173, 0.08278348429926805, 0.2776089236140251, 0.14129142835736275, 0.1549030172505549, 0.2953541342701231, 0.3579879919333117, 0.4299756719597748, 0.20511979263808044, 1.0362344703504016, 1.2087696407522475, 17.03747453008379, 80.58848680768693, 78.44455759865897, 81.79846695491246, 76.05426611219133, 68.66120215824672, 61.170467376708984, 68.12111173357282, 72.1894348689488, 77.38340091705322, 76.76389953068325, 71.01892743791852, 74.6948093686785, 77.46075521196637, 69.70324434552873, 69.7581490107945, 71.78662000383649, 77.68050588880266, 73.98584992544991, 75.42294584001813, 74.10953480856759, 76.52729947226388, 67.91409015655518, 64.53520202636719, 59.561334065028596, 54.53819990158081, 50.85807956968035, 56.64661339351109, 64.24432264055524, 73.13053362710136, 76.77948434012276, 72.79328196389335, 69.7647567476545, 71.8670870917184, 74.28089128221784, 58.28472416741507, 18.095242227826798, 65.6647150857108, 74.91022436959403, 68.80005495888847, 58.454868180411204, 54.54914331436157, 63.90527834211077, 67.87516634804862, 73.823609488351, 69.16107640947614, 74.04779311588833, 76.11772400992257, 74.6396267754691, 75.44928646087646, 63.44477258409773, 55.661706243242534, 52.68349640710013, 55.27717556272234, 63.56551143101284, 66.15713391985211, 66.72134154183524, 59.85230377742222, 55.933721269880024, 60.197775159563335, 72.17724078042167, 75.80463123321533, 76.70326260157994, 70.05059174128941, 74.32412297385079, 79.55522714342389, 75.74624552045549, 75.36796474456787, 78.01245607648576, 87.16959122249058, 16.37108496257237, 0.3058646417089871, 0.5118947433573859, 0.6364934774381774, 1.0572479942015238, 0.4832183878336634, 0.25890507868358065, 0.27190260695559637, 0.09010021561490637, 0.09382187841194016, 0.0543422920496336, 0.24349326853241238, 4.738697929041726, 24.513727528708323, 36.710397311619346, 32.2979542187282, 33.42612974984305, 63.404097829546245, 33.90982859475272, 22.60212176186698, 57.90815959657942, 65.69341809409005, 75.28991562979562, 72.67653138296944, 58.33599145071847, 6.578594378062657, 0.06673985626548529, 0.0075712481047958136, 0.03236195757719023, 0.029547092371753285, 0.027602870715782046, 0.038644289398299794, 0.06452106032520533, 0.04863281002534287, 0.01545228306869311, 0.015109784036342586, 0.037946182037038464, 0.055789251013525894, 0.03294309228658676, 0.015311658382415771, 0.039798250155789514, 0.05338291817211679, 0.009611457869011377, 0.037519539573362896, 0.045065856605236015, 0.06505558307149581, 0.0768789132790906, 0.0452757139158036, 0.04136912997013756, 0.0643779980018735, 0.018535020328792076, 0.043165205379149744, 0.022469475100349103, 0.03179335540958813, 0.03466442706329482, 0.13006054743060044, 0.10973467810877732, 0.16031289553003653, 0.11817816432033267, 0.14012516236730985, 0.14301338738628797, 0.09559865628502198, 0.16909399362547056, 0.1764341276139021, 0.1481412529413189, 0.19491184396403177, 0.146368838048407, 0.10106233560613223, 0.1334190515003034, 0.10649119251008544, 0.07805850569690977, 0.08186611852475575, 0.1380997353366443, 0.1107779121292489, 0.1369676539408309, 0.14703365308897837, 0.08096465082573039, 0.2220371498593262, 0.3010550769312041, 17.47819355555943, 136.90199661254883, 109.41733401162284, 106.77377373831612, 106.69979626791817, 94.21068028041294, 39.44341911588396, 20.029130867549352, 50.90115145274571, 76.50605188097272, 78.93977655683244, 55.1515417098999, 43.845474651881624, 29.9840373311724, 2.102884462901524, 0.2065415677747556, 0.2016889431646892, 0.13211977907589503, 0.5890761475477899, 0.33921070237244877, 0.16249996317284449, 0.22887670142310007, 0.27070653970752445, 0.43784705815570696, 1.4772443430764335, 2.2170444514070238, 5.464710857186999, 21.416781663894653, 85.20703084128243, 79.26485497610909, 84.11485045296806, 78.23469420841762, 72.46302713666643, 63.179969787597656, 69.99759088243756, 76.95724705287388, 81.52966894422258, 79.6417669568743, 72.13875470842633, 77.37891238076347, 80.99599865504673, 74.17086655752999, 72.69379070826939, 74.89905861445835, 80.6397019795009, 76.0668979372297, 79.09212275913784, 76.19042301177979, 78.41349915095738, 72.85428019932338, 67.4363042286464, 61.49230793544224, 57.993987219674246, 55.207974978855674, 60.672128677368164, 68.79878343854631, 76.76191234588623, 80.06413405282157, 77.06483990805489, 73.43518434252057, 76.21652739388603, 77.12228761400495, 70.29430675506592, 23.192715167999268, 66.27241148267473, 77.58542673928397, 72.92083699362618, 62.14775930132185, 57.76947355270386, 66.62836074829102, 71.17394174848283, 76.1409935270037, 71.99189758300781, 76.88306113651821, 79.21270179748535, 78.5800335747855, 79.83819253104073, 67.6745023727417, 60.03438826969692, 55.87506457737514, 57.09553303037371, 66.71456010001046, 70.22843088422502, 71.13617134094238, 63.49372264317104, 58.94750240870884, 63.92838110242571, 75.30995423453194, 79.14967468806675, 79.75060353960309, 68.89912237439836, 73.91529096875871, 83.9058277947562, 78.80284145900181, 77.05481365748814, 79.81156703404018, 87.74321365356445, 16.982578550066265, 2.453434109687805, 1.6877121180295944, 1.0301978971276964, 0.8789005471127374, 0.3037135771342686, 0.27747500794274466, 0.3441506272980145, 0.3212450221180916, 0.1473543830215931, 0.13067245031041758, 1.0132574290037155, 10.27435336794172, 36.37782526016235, 53.96622766767229, 34.735496929713655, 49.86015844345093, 106.15496022360665, 48.10622467313494, 23.476217303957256, 58.80871214185442, 77.86176354544503, 83.84060505458287, 87.3030869620187, 64.8575359072004, 6.677820299352918, 0.24693886935710907, 0.11187617533973285, 0.06504079779343945, 0.07458703233195202, 0.17001604129161152, 0.15837529807218484, 0.23624295900974954, 0.11452623456716537, 0.10118909273296595, 0.1533670446702412, 0.11758596609745707, 0.16248274195407117, 0.18435059567647322, 0.09721907254840646, 0.10501625415469919, 0.11690650827118329, 0.09863079858145543, 0.043779167612748485, 0.14682611636817455, 0.12005409651568957, 0.23369937549744332, 0.14320911759776728, 0.20033962199730532, 0.18707053044012614, 0.09690949094614812, 0.13139283736901625, 0.13021392348621572, 0.1654927097260952, 0.13777968393904821], [0.06113350138600383, 0.14292770198413304, 0.014310391752847602, 0.059935771727136204, 0.009400504724388676, 0.0596917366076793, 0.04768536818612899, 0.06359665814254965, 0.011339843472731965, 0.04793523870674627, 0.0379180499751653, 0.02768922786760543, 0.0532174947272454, 0.023879920398550372, 0.09497418693665947, 0.015362560383177229, 0.02391506851251636, 0.048374990466982126, 0.01857756617079888, 0.01666080821970744, 0.08276040053793363, 0.016919516658942615, 0.07643555849790573, 3.233423250062125, 78.62620435442243, 101.44770159040178, 94.96519906180245, 74.4266436440604, 63.3441070829119, 48.28085722242083, 45.17138201849801, 63.02672726767403, 49.537008149283274, 57.32192965916225, 38.457608699798584, 31.27180256162371, 20.387030839920044, 1.9995997079781123, 0.04239625217659133, 0.04538193178762283, 0.021265375693993907, 0.051264229895813127, 0.06213715645883765, 0.04052812313394887, 0.08062880991825036, 0.12048157357743808, 0.27234319331390516, 0.4640879343662943, 0.8131123429962567, 0.17275952122041158, 11.593494057655334, 69.01926367623466, 79.22905785696847, 76.27273832048688, 72.031710760934, 63.61112635476248, 57.684121881212505, 58.756836891174316, 62.30371161869594, 66.81926250457764, 73.99983664921352, 72.42028876713344, 69.21709973471505, 69.55977099282401, 74.13493047441754, 71.00836617606026, 69.17088726588658, 71.05657277788434, 72.20064231327602, 67.57380213056291, 61.13337789263044, 69.12575871603829, 72.14033889770508, 68.61576788766044, 66.41632952008928, 61.63307843889509, 54.592691149030415, 48.734525953020366, 51.63740342003958, 56.61564179829189, 71.78271511622837, 71.82287570408413, 72.57791560036796, 65.85986913953508, 66.86887959071568, 66.43069839477539, 54.65560361317226, 21.449921097074235, 59.121221269880024, 73.41477748325893, 64.80488245827812, 62.45969867706299, 44.55956186567034, 56.57552637372698, 63.742989267621724, 70.69812910897392, 69.30196503230503, 68.19975839342389, 67.78144209725517, 66.42367376599992, 62.03551115308489, 55.25598703111921, 50.278565066201345, 52.46148061752319, 56.33890547071184, 64.92776829855782, 68.13918399810791, 67.99596078055245, 62.17353711809431, 58.505993025643484, 57.781646796635215, 65.56370912279401, 68.54216561998639, 68.91701398577008, 65.00966671534947, 72.98517731257847, 72.87692437853131, 67.30756105695451, 65.03637559073312, 74.70929636274064, 73.48387037004743, 78.8558909552438, 8.459903393472944, 1.5577742904424667, 1.2612565500395638, 1.7894533957753862, 0.8617537500602859, 0.11030642528619085, 0.07379884605429002, 0.02468818113473909, 0.08111467491835356, 0.1108124495616981, 0.11723633057304791, 0.05914899680231299, 1.106070271560124, 16.49245956965855, 46.84229523794991, 51.979258264814106, 79.5237865447998, 134.60214287894112, 61.18568393162319, 22.42224853379386, 60.07003252846854, 62.46580614362444, 68.38335759299142, 68.4623794555664, 40.55563810893467, 1.9326753105436052, 0.03679425009925451, 0.14080084753887995, 0.009357678986686681, 0.03634530079684087, 0.026048156998253295, 0.10614690384162323, 0.047357147226908376, 0.0549543204584292, 0.024866766462634717, 0.01048424728547356, 0.030336425373596803, 0.038554271550050805, 0.09027402235993318, 0.04461196417521153, 0.04010199296421238, 0.03302418061399034, 0.026609447951029454, 0.039965329226106405, 0.04436505545995065, 0.09330490258123193, 0.027954080441434468, 0.031681010366550515, 0.009357556850383324, 0.08173147003565516, 0.059587696833269935, 0.062212595982210975, 0.03091342780472977, 0.06995473482779094, 0.0657020505251629, 0.05367968564054795, 0.015756831637450626, 0.047522109267967086, 0.06133056152611971, 0.08121544415397303, 0.007583377766422927, 0.029273944707321267, 0.08754825219511986, 0.0238751876167953, 0.035817030750747235, 0.08094163491789784, 0.030250566945012127, 0.04713661316782236, 0.06424398055034024, 0.028354606092242256, 0.054736914445779154, 0.0430940372337188, 0.037395089465592585, 0.09522875970495598, 0.052077881592725, 0.0673372656373041, 0.042689789818333726, 5.208679727145603, 98.27112415858677, 111.51512718200684, 105.95096111297607, 88.28059428078788, 76.18539251599992, 75.45693642752511, 46.83985642024449, 37.88538633074079, 38.217760358537944, 52.07352100099836, 43.31460796083723, 36.51845679964338, 23.772757734571183, 1.914548328944615, 0.049695317833019156, 0.07349467916148049, 0.11555014391030584, 0.22264571434685163, 0.12110045179724693, 0.4803740233182907, 0.6381509484989303, 0.528082580438682, 0.11646335705050401, 0.6523013349090303, 0.8048110912953104, 0.18157434250627244, 12.921935779707772, 74.65510736192975, 84.36803586142403, 81.15677997044155, 74.87268325260708, 67.8255978993007, 59.675124713352744, 61.99494062151228, 65.14841529301235, 72.52663789476667, 76.8882861818586, 76.1910205568586, 68.87394210270473, 70.97273581368583, 77.11441530500139, 73.52587223052979, 71.58035578046525, 73.1590907233102, 74.99787589481899, 68.66480132511684, 65.63820770808628, 70.5846163885934, 75.25008855547223, 71.97523580278668, 68.72598716190883, 63.53561333247593, 56.94700486319405, 50.85107578550066, 54.59997633525303, 59.695225851876394, 72.77767630985805, 73.77137987954276, 74.93183326721191, 68.0176808493478, 70.74045058659145, 68.97250229971749, 64.52008274623326, 25.363990749631608, 58.52728230612618, 75.89477021353585, 69.71609851292202, 64.29478740692139, 47.42410264696394, 58.064834526606965, 65.55431515829903, 75.55235603877476, 71.12857695988247, 70.47628007616315, 71.1665905543736, 70.4605632509504, 65.76195512499127, 59.0758912222726, 52.646431241716655, 56.27776479721069, 58.91793087550572, 68.91120529174805, 70.52647386278424, 71.76430933816093, 66.20194285256522, 62.60848045349121, 61.32055541447231, 69.21596023014614, 72.31950514657157, 71.60041522979736, 66.56146349225725, 75.39580617632184, 76.61752183096749, 71.04631723676408, 68.14003862653459, 77.61377538953508, 76.71145452771867, 83.81827354431152, 10.409371631486074, 0.9420086464711598, 0.6785574374454362, 1.4985405717577254, 1.129496123109545, 0.6774639104093824, 0.11295677628368139, 0.12222467575754438, 0.13049314064638956, 0.05492039031482168, 0.047111422555255036, 0.028417116130835245, 0.5284378070916448, 18.582298789705547, 37.284780570438926, 35.77061176300049, 85.87748336791992, 111.66436753954206, 61.02150494711739, 36.70280293055943, 67.3801280430385, 70.45533125741142, 77.38521439688546, 79.48869119371686, 57.367527212415425, 3.4251090671334947, 0.038122071884572506, 0.07930862504456725, 0.02613368464101638, 0.03558535175397992, 0.03257671730326755, 0.1297963937478406, 0.0625229375436902, 0.03658204845019749, 0.014084226701275578, 0.01713255629874766, 0.015051745543522494, 0.02549795330768185, 0.042138195130974054, 0.029431707491832118, 0.013683730736374855, 0.055838851923389096, 0.03065143186332924, 0.04122901248878666, 0.04045427816786936, 0.08066655682133776, 0.050572697538882494, 0.006294234597589821, 0.05545043472998908, 0.0104812905691298, 0.03007513510861567, 0.04346084987212505, 0.029883567709475756, 0.016284457075276544, 0.16691152645008905, 0.13194250501692295, 0.0881655290722847, 0.16482979458357605, 0.08628432465983288, 0.14467948941247805, 0.13704601116478443, 0.08970775096012013, 0.10277759749442339, 0.06287988767560039, 0.13250240497291088, 0.14175592628972872, 0.0701766497056399, 0.14161413961223193, 0.17687085989330495, 0.11558561772108078, 0.12575232503669603, 0.17983474156686238, 0.10619917817945991, 0.22420401072927884, 0.22302744457764284, 0.19557667257530348, 0.3426432753247874, 6.920222103595734, 122.7909973689488, 121.07283292497907, 117.69011633736747, 99.66154902321952, 87.50419562203544, 68.25469779968262, 60.20439679282052, 80.28894301823208, 66.05509267534528, 77.3619726725987, 60.17738219669887, 48.17739159720284, 33.83724076407296, 3.35575019461768, 0.3289013127131121, 0.17703422398439475, 0.21430145709642343, 0.29531290648239, 0.28022839448281694, 0.2936219429331166, 0.4014454728790692, 0.27767341158219744, 0.21449006269020693, 1.6779931081192834, 2.73824011853763, 1.115776470729283, 16.402040924344742, 78.53936576843262, 85.4681510925293, 84.48535619463239, 76.76988887786865, 68.81334686279297, 63.17447376251221, 65.14861679077148, 69.34181989942277, 74.01484475816999, 81.36917250497001, 77.76850482395717, 69.71517440250942, 71.19275052206856, 79.99017742701939, 75.78453009469169, 74.46952097756522, 76.26102365766252, 79.58019896915981, 69.84766265324184, 67.31758035932268, 73.84410667419434, 77.44526072910854, 74.44883619035993, 71.67797102246965, 68.83376067025321, 60.47105475834438, 55.270970821380615, 56.75408812931606, 63.10906342097691, 78.97145339420864, 74.75691236768449, 79.61521094185966, 70.79073469979423, 74.80463259560722, 73.25481605529785, 66.25361660548619, 29.721867901938303, 62.45356341770717, 78.61818613324846, 71.28300762176514, 68.16644872937883, 49.78735521861485, 61.542571204049246, 69.84844085148403, 77.76111194065639, 74.12070751190186, 76.13826983315604, 75.33468982151577, 73.29164150782994, 68.19215706416539, 61.23219517299107, 56.05401543208531, 58.68989099775042, 61.183724539620535, 71.92495863778251, 75.80153928484235, 75.81788839612688, 68.8802719116211, 66.05198683057512, 64.32716601235526, 72.57558795383999, 75.61269419533866, 74.40193584987095, 65.97869028363908, 80.39255455562046, 81.14809472220284, 71.9603249686105, 69.67719554901123, 80.53573608398438, 78.68554891858781, 88.3316010066441, 9.085887449128286, 3.8598975879805426, 3.104888524327959, 3.771054446697235, 2.358162581920624, 0.5213168806263379, 0.22147547214158944, 0.14438885929329054, 0.28455896782023565, 0.24552721796291216, 0.23663553223013878, 0.13455361633428506, 1.8843870673860823, 27.8209901537214, 73.33997317722866, 59.02657985687256, 83.09170736585344, 145.9097524370466, 75.52116557529995, 35.9940310886928, 74.07051372528076, 81.05591297149658, 89.59689576285226, 91.33213193075997, 65.76948002406529, 4.326266322817121, 0.10620312046791826, 0.22118914393442018, 0.08879168118749346, 0.12203662656247616, 0.10419315046497754, 0.2394236054803644, 0.2825182873223509, 0.18582896063370363, 0.11457276849874429, 0.07045195171875612, 0.08543406599866492, 0.18235955680055277, 0.20003988593816757, 0.20980496837624482, 0.15173963271081448, 0.1726133240652936, 0.09924673874463354, 0.22106531129351684, 0.11378799525222608, 0.15576802726302827, 0.16206426226666995, 0.08376459165343217, 0.10948560147413186, 0.2435649489717824, 0.08818384273243801, 0.10780325531959534, 0.11143233201333455, 0.13773567415773869], [0.02843443234451115, 0.034103756970060725, 0.028222393543858613, 0.010644468063089465, 0.03975236422515341, 0.04708713778693761, 0.014533239616347211, 0.02307919649008129, 0.040885894293231625, 0.027583574876189232, 0.045981241057493856, 0.028753525311393396, 0.03439668393028634, 0.01646819248396371, 0.047963099354611974, 0.0331018626956003, 0.025802888641399995, 0.03849022462964058, 0.07408362720161676, 0.04881189916548984, 0.03341318813285657, 0.07232416554221086, 0.2814115695655346, 32.91883829661778, 101.87023544311523, 85.82468400682721, 70.8796785899571, 46.22255761282784, 26.72076027733939, 17.730255092893326, 33.5444540977478, 37.7856901032584, 52.80137259619576, 42.889378207070486, 33.35860020773751, 12.550227131162371, 0.0857006081246904, 0.1050733800179192, 0.04381610027381352, 0.025830611885924424, 0.024891327733972242, 0.020141355294202055, 0.14048169180750847, 0.27500155780996594, 0.2729530063058649, 0.7535891341311591, 0.16447410652680056, 0.8031758761831692, 0.4378327546375138, 20.153953518186295, 66.52816077641079, 80.22396346500942, 74.47161933353969, 72.42759132385254, 61.316184997558594, 55.19290781021118, 55.592932973589214, 65.4611815043858, 65.97162396567208, 67.60499259403774, 73.25282887050084, 69.51050131661552, 68.55012130737305, 64.94087954929897, 67.21860327039445, 67.90318843296596, 68.99730736868722, 67.78443677084786, 63.557236126491, 65.9277252469744, 65.74254880632672, 60.65025574820382, 66.01040881020683, 68.37003789629254, 70.72734628404889, 61.397812434605186, 56.933004243033274, 49.44467006410871, 51.73512288502285, 52.21528162275042, 62.2418657030378, 67.21236378805978, 72.6297561100551, 65.71795218331474, 66.14163943699428, 60.71349825177874, 81.6147426877703, 28.21282512801034, 41.14842714582171, 71.53186430249895, 65.04342106410435, 67.98006330217633, 54.75979879924229, 54.92251518794468, 61.00523921421596, 68.82071890149797, 67.23168672834123, 69.26810646057129, 65.25845391409737, 56.4147242137364, 50.344103949410574, 50.39342226300921, 50.66951240812029, 54.73514659064156, 60.30899497440883, 66.27976962498256, 69.40756375449044, 68.11503205980573, 66.06028297969273, 64.42255783081055, 61.64750984736851, 63.05470766339983, 67.62796333857945, 71.09136935642788, 70.06347370147705, 70.78565556662423, 72.35339845929826, 67.715621812003, 57.00150653294155, 65.40658255985805, 72.90083312988281, 74.55160004752022, 62.58468982151577, 2.2393592425755093, 0.3518564509493964, 2.3467744844300404, 1.8580953010490961, 0.4391028093440192, 0.06353732025516884, 0.10597765006657157, 0.049246012299720726, 0.030084912798234394, 0.17802510224282742, 0.12839711883238383, 0.04694203985854983, 0.09881288345370974, 18.218355621610367, 55.542058263506206, 71.42721748352051, 88.60685389382499, 56.50055878502982, 22.361668927328928, 30.25599329812186, 48.80063458851406, 64.51409339904785, 62.04029846191406, 75.38289642333984, 29.9333849634443, 0.5822517680270332, 0.06592045737696545, 0.046122071000614336, 0.027660765019910674, 0.06210916010396821, 0.013880058906839361, 0.09942802294556584, 0.03654857971040266, 0.017751229261713367, 0.047505929600447416, 0.03632974538153835, 0.021729391866496632, 0.0438605375321848, 0.050457814774875126, 0.023083165919940387, 0.08146181343389408, 0.0852926525154284, 0.03910422418266535, 0.07305640660758529, 0.039934740867465734, 0.03583214172561254, 0.03929902819384422, 0.04609390501199024, 0.019007679341094832, 0.04568619367533496, 0.048929329828492234, 0.02606160386598536, 0.11583006674689905, 0.035884005549762926, 0.022394062718376517, 0.05769027543387242, 0.05844999716750213, 0.01641303946131042, 0.05101165541314653, 0.07974282638835055, 0.00776051781472883, 0.05271888005414179, 0.018869122490286827, 0.03051396066855107, 0.032335718628019094, 0.015260573177199279, 0.018799811834469438, 0.00882852345239371, 0.037117287050932646, 0.03792993451601692, 0.06203473159777267, 0.0536294095883412, 0.06896426369036947, 0.03285699976342065, 0.12727351912430354, 0.26716138422489166, 44.834974561418804, 116.02468177250454, 97.21458802904401, 82.96129662649972, 61.240595545087544, 58.385212489536826, 25.06763792037964, 27.87927164350237, 46.30290310723441, 53.5202089037214, 37.8238912991115, 39.52464703151158, 15.325125728334699, 0.17605828706707272, 0.19584041913705214, 0.04798103982050504, 0.013805996809553887, 0.09103664822344269, 0.3285887523421219, 0.5816739276051521, 1.9999792533261436, 0.32246291105236324, 0.8878934702702931, 1.1928668426615852, 0.20610115783555166, 0.2918469767485346, 20.97490750040327, 73.76402173723493, 85.61664799281529, 78.25357246398926, 75.79229818071637, 64.31832095554897, 58.24339975629534, 57.78363398143223, 68.36626502445766, 69.01201670510429, 70.20144408089774, 74.57494599478585, 71.96482045309884, 71.09760189056396, 63.840437752859934, 67.52988951546806, 69.58541679382324, 70.65267399379185, 69.17121383122036, 66.40396867479596, 67.71065385001046, 68.71723937988281, 64.8568480355399, 66.73728765760148, 70.74763502393449, 72.50377137320382, 64.91904136112758, 59.60250908987862, 52.43231555393764, 53.94140175410679, 53.715380328042166, 65.03934247153146, 69.74580206189836, 75.60753863198417, 69.02373136792863, 68.27680696759904, 64.0959438596453, 82.76098700932094, 29.996933187757218, 43.81540979657854, 74.89022050585065, 66.37445272718156, 71.24284703390938, 57.32445532935006, 58.41572897774832, 63.99331896645682, 71.2996416091919, 69.478761945452, 72.87134497506278, 68.48853247506278, 59.73104381561279, 52.00008201599121, 53.15131514413016, 52.068257740565706, 56.86013501031058, 63.912170955113, 70.41463565826416, 72.57327420370919, 71.62250355311802, 69.36381094796317, 67.72759355817522, 62.782782963344026, 66.59566252572196, 70.30025441305978, 74.61523859841483, 68.59596552167619, 75.08277593340192, 75.098708152771, 70.22162164960588, 59.3258387701852, 69.14684649876186, 76.67217636108398, 78.41487489427838, 67.46985013144356, 3.177942535706929, 0.3285607695579529, 0.7778698312384742, 0.9604912889855248, 1.1696499798979079, 0.8391845896840096, 0.3724866567977837, 0.04986543674021959, 0.04486639105847903, 0.07004051522484847, 0.048806477670690844, 0.04171472142583557, 0.16274225445730345, 18.6107360294887, 51.62827001299177, 70.62917518615723, 97.03891672406877, 55.28448854173933, 26.589244774409703, 51.00149038859776, 60.41073744637625, 73.474976675851, 69.52405030386788, 83.10984911237443, 46.86135414668492, 1.2011599519423075, 0.1295100926820721, 0.07295876541840178, 0.021728391027344123, 0.07715015086744513, 0.0282164258283696, 0.08467876152800662, 0.0014313114162567736, 0.04620903544127941, 0.042246455393199406, 0.04424218973144889, 0.0679116387452398, 0.03099476040474006, 0.0310795331772949, 0.07128451418663774, 0.03959456751389163, 0.012385406564655048, 0.03634191829977291, 0.04575635419626321, 0.026546284822481017, 0.05218922579661012, 0.023174527267526304, 0.06790422235748597, 0.013279290786678237, 0.020213498833722303, 0.06729572572346244, 0.005159965774510056, 0.04749486608696835, 0.11681711806782655, 0.08259489906153508, 0.08860544368092503, 0.10531157295086555, 0.10486611471112285, 0.2279081605374813, 0.16243703583521502, 0.12120343984237739, 0.12173409493906157, 0.10377117632223026, 0.17575709894299507, 0.12244120985269547, 0.11341884506068059, 0.102612828835845, 0.07379303779453039, 0.09957257804593869, 0.09232216674302306, 0.13774361301745686, 0.16554695181548595, 0.20539240086717264, 0.20223430890057767, 0.17647154203483037, 0.29614650032349993, 60.95253017970494, 129.1917334965297, 107.14306354522705, 94.37653378077916, 69.24245371137346, 46.04314817701067, 29.850843838282994, 48.65419088091169, 51.36852550506592, 71.7773997443063, 61.49317646026611, 52.501700265066965, 20.82919682775225, 0.3548841013440064, 0.1809833249343293, 0.19537695257791451, 0.11708610291991915, 0.23227162925260408, 0.1946282298969371, 0.5729948133230209, 1.9620529455798013, 0.25518027426941053, 2.292564421892166, 2.953880935907364, 2.2571568361350467, 1.403996542096138, 27.187894616808208, 77.82183919634137, 85.36764539991105, 81.81420462472099, 79.03286852155412, 67.25513689858573, 61.033351625714985, 60.722072328839985, 71.59983158111572, 72.20261560167584, 74.45537444523403, 79.58254051208496, 72.9654791695731, 71.83220713479179, 63.681247574942454, 70.09185709272111, 71.77274445125035, 73.6814910343715, 72.93913854871477, 68.8881094796317, 69.4899068559919, 72.30615765707833, 68.67275701250348, 72.2918930053711, 71.8735419682094, 75.74629415784563, 67.81764221191406, 63.96486609322684, 54.79818064825875, 57.43212808881487, 58.71721131461007, 68.52430180140904, 70.66782801491874, 80.59404536655971, 72.10348565237862, 70.92490441458565, 67.21633815765381, 83.07042503356934, 35.37060397011893, 49.137198380061555, 79.30678735460553, 70.03049755096436, 74.48017256600517, 61.690171786717, 60.31869465964181, 67.94744150979179, 73.80184078216553, 71.85141890389579, 76.37446689605713, 72.53229372841972, 62.25695024217878, 55.42829540797642, 55.5502849306379, 55.749541895730154, 60.19489165714809, 67.03576142447335, 74.45766040257045, 74.59695788792202, 73.85080473763603, 71.9248057774135, 70.86783191135952, 67.23883642469133, 69.80290235791887, 73.40052672794887, 76.9815240587507, 72.64281177520752, 77.00038841792515, 80.191696030753, 73.51570701599121, 62.2767665045602, 72.2983478818621, 80.59216240474156, 79.17455618722099, 73.33879893166679, 1.8167998769453593, 3.635962141411645, 5.296560977186475, 5.233825692108699, 1.4985002939190184, 0.6077987743275506, 0.6234840069498334, 0.20524771005979606, 0.1105164522305131, 0.6574990760002817, 0.29586911520787645, 0.11666946884776865, 0.6956837155989238, 31.815214225224086, 78.60288619995117, 74.66788509913853, 91.90956197466168, 67.57947186061314, 32.89557920183454, 46.812841824122835, 64.61187539781842, 85.9403715133667, 81.02418749673026, 95.32270472390312, 54.01121725354876, 1.3366796800068446, 0.1942114465470825, 0.19990192619817598, 0.14664559891181334, 0.1782352581088032, 0.08418655222547905, 0.22360185161232948, 0.10728163152400937, 0.1045999186379569, 0.17345373039799078, 0.10557148578975882, 0.15751495638063975, 0.16048551483878068, 0.12898528655724867, 0.1669128970908267, 0.2271629526679005, 0.09215176624378987, 0.26219524070620537, 0.16917217443031923, 0.2425325715116092, 0.13294696754642896, 0.08458212457065072, 0.12724194010453566, 0.0746579799535019, 0.10856875817158393, 0.21733480718519005, 0.08626879299325602, 0.14305262028106622], [0.07128150827650513, 0.04936805021549974, 0.10264875047973224, 0.07899056853992598, 0.012065186381473072, 0.024846561386116912, 0.03925001421677215, 0.019412143887685876, 0.06813816087586538, 0.046380324821387015, 0.08154156843998603, 0.04753177499930773, 0.07424549851566553, 0.0338068673653262, 0.05607014076252069, 0.01563659353580858, 0.06618469248392753, 0.02454290509090892, 0.08514493544186864, 0.03137812590492623, 0.1456114844019924, 0.05057657536651407, 8.122626543045044, 73.71796907697404, 89.79912308284214, 91.5248749596732, 76.21782670702252, 59.925794873918804, 23.96878899846758, 95.09178829193115, 81.58426788875035, 42.44246312550136, 49.64127629143851, 43.925715923309326, 14.487420507839747, 0.05386507158566799, 0.031699788823191605, 0.16609055336032594, 0.11428942584565707, 0.029869440610387495, 0.3708513059786388, 0.2480784553502287, 0.39195556353245464, 2.268034892422812, 1.7058535388537814, 1.4483341915266854, 0.7457591657127652, 7.247058851378305, 40.52177258900234, 70.6578642981393, 79.51667853764125, 75.50545569828579, 76.53567899976457, 67.4703642981393, 53.95503759384155, 55.24089206968035, 66.40551812308175, 69.08755057198661, 69.384690284729, 69.24320411682129, 71.30895914350236, 70.32998575483049, 65.94925771440778, 67.86910057067871, 66.18963064466203, 65.56644671303886, 63.4364903313773, 62.70442117963518, 63.23682689666748, 66.7120726449149, 65.08947372436523, 62.40963690621512, 63.30008329663958, 63.805648122514995, 68.12546130589077, 63.567679268973215, 53.85346187864031, 48.74757466997419, 49.95536960874285, 51.31910991668701, 60.70012296949114, 66.07385281154087, 69.73919432503837, 66.76254435947963, 63.89946269989014, 58.58854457310268, 74.75100639888218, 33.888938835689, 28.324882200786046, 65.73253645215715, 64.57395212990897, 71.3333820615496, 55.61728293555123, 55.46938705444336, 58.030757086617605, 68.60479668208531, 67.58042376382011, 67.22919232504708, 56.89400747844151, 49.63368885857718, 47.594607966286794, 51.28557791028704, 50.862877300807405, 57.88582808630807, 64.35346494402204, 69.57375076838902, 67.29018361227853, 67.29131616864885, 69.76678562164307, 69.25281347547258, 64.73792266845703, 63.38197476523263, 65.84950937543596, 69.84448732648576, 66.59814998081752, 71.09758799416679, 69.82446261814663, 66.65644536699567, 57.961400168282644, 58.623653820582796, 69.91179452623639, 72.52688802991594, 73.95083795275006, 38.83622646331787, 2.5417850145271847, 0.5332802672471318, 0.5249431888972009, 1.4331885299512317, 0.21751826948353223, 0.44129469458545956, 0.20577360184064933, 0.04394175817391702, 0.0731299462329064, 0.08980843198618718, 0.005347998006202812, 0.023809507123327682, 0.13929815031588078, 12.304813282830374, 27.802678176334926, 45.226731368473594, 76.49084227425712, 41.40107754298619, 10.336406861032758, 34.58145189285278, 54.39996896471296, 63.737236159188406, 61.01617567879813, 76.03397042410714, 11.507974760872976, 0.3830966646117823, 0.09836102662874119, 0.031032992460365807, 0.03599220135116151, 0.020409339307142154, 0.10484025574156217, 0.03815072302573493, 0.04424670538199799, 0.017095090987692987, 0.030462415755859444, 0.03599668646763478, 0.049716094575290165, 0.038101620839110444, 0.02633353864907154, 0.023270312663433806, 0.13564662768372468, 0.058781922927924564, 0.02646890977796699, 0.058784372439341884, 0.030625277731035436, 0.03147753467783332, 0.0383278070949018, 0.02027659071609378, 0.03429211150588734, 0.08650437356638056, 0.0896255803693618, 0.05991724093577691, 0.031203162257692645, 0.05794843765241759, 0.05536299531481095, 0.04902140703052282, 0.048724785447120667, 0.0218824252619275, 0.03429867293951767, 0.019128261799258844, 0.037522586195596626, 0.07400668133050203, 0.11447911709547043, 0.02235397486947477, 0.09636650686817509, 0.05424220134903278, 0.013643786227995796, 0.03139000705310276, 0.05583114376557725, 0.036891351853098185, 0.055681085746203146, 0.05372048934389438, 0.1299804395862988, 0.052958107752991576, 11.727062753268651, 90.79466792515346, 102.34370653969901, 99.66670458657401, 87.64166573115757, 72.87672982897077, 27.371478182928904, 64.4913033076695, 63.82347025190081, 37.35746914999825, 45.85548428126744, 49.58258833203997, 18.957656111036027, 0.05088660480188472, 0.06562139985284635, 0.06952288800052234, 0.04750855213829449, 0.19245740638247558, 1.1665369697979517, 1.0031244584492274, 1.3721949628421237, 3.647299213068826, 0.8166447963033403, 1.5637065321207047, 0.7544601559638977, 6.53285699231284, 47.238266127450125, 80.91143907819475, 83.70137705121721, 78.7540442602975, 78.7870204108102, 70.46991552625383, 57.13639191218785, 57.8664356640407, 68.66043785640171, 72.61419214521135, 71.77289036342076, 73.05113656180245, 74.07387665339878, 71.83304786682129, 66.96648788452148, 68.14412416730607, 69.26757144927979, 67.94525977543422, 68.06344863346645, 64.89213098798479, 64.4306663785662, 67.91561181204659, 68.50732735225132, 65.96794836861747, 65.50635869162423, 65.56383419036865, 71.2993219920567, 65.72603293827602, 58.1827141898019, 50.38824585505894, 52.78260203770229, 54.446004254477366, 64.35639013562883, 68.16479505811418, 72.56069796425956, 68.15143367222377, 66.13563619341168, 60.32160595485142, 79.35229110717773, 37.160824707576204, 32.611168588910786, 71.01864950997489, 66.91695417676652, 76.21759046827043, 58.42453234536307, 58.00661557061331, 60.008040700639995, 71.9114304951259, 68.75854642050606, 69.1177613394601, 59.539766856602256, 52.57786989212036, 50.46388047082083, 53.09867211750576, 53.33608511516026, 59.02999142238072, 66.94841561998639, 72.8575666972569, 69.55199595860073, 69.3445713860648, 72.65194170815604, 72.1942777633667, 67.15866810934884, 68.08106926509312, 69.41512339455741, 71.5926262991769, 65.49374076298305, 72.22704546792167, 74.45907783508301, 69.47132042476109, 62.961636543273926, 60.54918725149972, 72.51880032675606, 75.5360416684832, 78.22465406145368, 42.80846643447876, 3.3267395113195692, 0.8700116840856416, 1.1895462551287241, 2.180657603910991, 0.946849695273808, 1.4903091277394975, 0.9352897384337017, 0.17509535088070802, 0.139833392309291, 0.043042556781853945, 0.07085627716566835, 0.04689000979331987, 0.09388359117188624, 15.2933828830719, 30.393446036747523, 48.61788306917463, 70.55056326729911, 35.264689104897634, 19.550724812916346, 42.57458659580776, 64.49736908503941, 71.07816777910504, 69.07569694519043, 88.26136861528668, 18.559644188199723, 0.6125782121505056, 0.07533278302954775, 0.07763238570519856, 0.05983434431254864, 0.05576840302507792, 0.027239932512332286, 0.032287322117813995, 0.040746126257415326, 0.07803695542471749, 0.04943169680024896, 0.0394306198826858, 0.011382092455668109, 0.04428684072835105, 0.03920198750815221, 0.07465333877397434, 0.11819685117474624, 0.040537761723888774, 0.11240170071167604, 0.06307299195655755, 0.047475005366972516, 0.04951813876894968, 0.02907826877864344, 0.025877517315426042, 0.024749135631801825, 0.03998228920889752, 0.05712114740163088, 0.06418097178850855, 0.1439470380012478, 0.1527959895985467, 0.13416222376482828, 0.11641678240682397, 0.12559696765882628, 0.1290200004088027, 0.14344755480332033, 0.12000790185162, 0.21112182842833654, 0.15304214853261197, 0.13405198896569864, 0.18093927444091865, 0.20222418515809945, 0.10750936823231833, 0.12524019394602093, 0.11306776425668172, 0.1733822670898267, 0.11008856126240321, 0.16693490876683167, 0.1133442876328315, 0.37245747979198185, 0.12718004414013453, 19.618077175957815, 113.8565102985927, 110.97901807512555, 111.54130104609898, 96.93360982622418, 76.93777125222343, 33.0690826688494, 106.66131714412144, 97.33832849775041, 58.79401670183454, 68.47531005314418, 68.49483449118478, 24.69022740636553, 0.2799224837550095, 0.1200076440083129, 0.49501626619270866, 0.35406627665672985, 0.4254716650715896, 1.2227079442569186, 1.2943833896092005, 2.8708883949688504, 6.309758586542947, 6.150671328817095, 7.0392438769340515, 2.9413611505712782, 7.944943734577723, 52.90392453329903, 84.51446219852993, 79.84562710353306, 81.36711583818708, 82.8105901990618, 74.33717863900321, 58.5245794568743, 61.14818450382778, 72.44198799133301, 75.48796708243233, 75.85101045880998, 74.09832736424038, 76.68196637289864, 74.88571807316372, 69.34329986572266, 71.14901856013707, 71.59951891217912, 69.41272626604352, 70.25272178649902, 68.51060690198625, 65.75570174625942, 69.91911097935268, 71.30221244267055, 69.67279733930314, 69.09848008837018, 68.46608979361397, 73.12240423474992, 70.30372851235526, 59.28013351985386, 54.63878549848284, 55.340935707092285, 58.099950722285676, 66.79848044259208, 71.41022218976701, 75.49366460527692, 72.41858645847866, 68.66640635899135, 64.44869695390973, 82.45894881657192, 41.29710817337036, 36.21786035810198, 73.57629530770438, 69.15364183698381, 78.60697868892125, 61.18528093610491, 61.9717127936227, 64.34607206072126, 75.0255436216082, 72.23121438707624, 73.07617092132568, 63.68180343082973, 55.8746337890625, 52.92157990591866, 55.874567781175884, 55.268389565604075, 63.36119270324707, 70.91314806256975, 74.48470973968506, 71.55191680363247, 70.46382890428815, 75.54103742327008, 76.0591367994036, 71.03995963505336, 70.17821625300816, 72.04518331800188, 73.98473126547677, 69.0030882699149, 74.88786506652832, 75.55323845999581, 73.5741969517299, 66.4439833504813, 64.0548174721854, 77.17514950888497, 79.55970178331647, 80.384765625, 45.60266365323748, 3.7808292593274797, 4.746638851506369, 5.00765357698713, 5.195706137589045, 1.3317516701562064, 1.7022286419357573, 0.8588782272168568, 0.2796458585986069, 0.3305080293544701, 0.35714595711656977, 0.12188281624444894, 0.22061399051121303, 0.4111571546111788, 20.182349068777903, 43.94171067646572, 56.610646043504985, 89.86820902143205, 56.917586190359934, 15.468095336641584, 49.06258862359183, 70.16883618491036, 83.26288318634033, 78.0357255935669, 99.9788385118757, 20.163884231022426, 0.6118725357311112, 0.18682623069201196, 0.11894644238054752, 0.10461671916501862, 0.14416414206581457, 0.21038195384400232, 0.10985930463565247, 0.14300631705139363, 0.17692682546164307, 0.1163258044315236, 0.12154793207134519, 0.06877954610224281, 0.11302492155560426, 0.1156290303915739, 0.18346482249242918, 0.234160806451525, 0.1412791604442256, 0.16098664009145328, 0.2127027471682855, 0.10687700073633875, 0.15210389745022568, 0.12430290638336114, 0.10002832287656409, 0.1679322195372411, 0.12712695556027548, 0.11402486504188605, 0.17578440319214547], [0.08560714671122176, 0.04745590460619756, 0.0270853995545102, 0.051216087836240015, 0.0439884074564491, 0.05409413482993841, 0.053069842114512406, 0.02629029391599553, 0.03903957675876362, 0.027797634014859796, 0.007468444960457938, 0.02422412933914789, 0.016823858488351107, 0.023691939056984017, 0.0459405560977757, 0.06009387717183147, 0.0121251909295097, 0.03397283024553742, 0.028127547918951938, 0.0631316038114684, 0.06516571609037262, 0.0729012256488204, 46.567275115421836, 97.51283945356096, 87.44371155330113, 78.5411375590733, 51.52907752990723, 21.89170319693429, 56.11418335778372, 110.70967115674699, 90.0209721156529, 47.973090239933555, 43.37753432137625, 19.880573170525686, 0.16561582311987877, 0.05275857435273273, 0.060351788332419734, 0.12401725671121053, 0.12234835912074361, 0.31307839176484514, 0.881347615803991, 0.46145516421113697, 1.4406007379293442, 1.7837616269077574, 0.9706354417971202, 0.4363886964108263, 19.031397342681885, 68.55182361602783, 76.59473868778774, 70.07394463675362, 75.52570969717843, 77.21196106501988, 71.67426068442208, 62.40115315573556, 51.98168666022164, 59.49196325029646, 68.86310986110142, 72.01445143563407, 69.9081119809832, 71.58463587079729, 69.48466791425432, 64.36852169036865, 67.95402840205601, 67.45909432002476, 66.04369762965611, 67.91615377153668, 68.5330148424421, 64.64244747161865, 64.93649523598808, 66.56186648777553, 62.49328626905169, 64.95727729797363, 66.51706450326103, 67.59862109592983, 68.0270609174456, 62.70476164136614, 51.95010709762573, 49.97003378186907, 51.06793948582241, 54.91267653873989, 64.25120830535889, 67.43595681871686, 69.07655852181571, 65.8278032030378, 65.71456146240234, 60.452371052333284, 75.33295277186802, 37.42051362991333, 41.985500948769705, 71.76278073447091, 59.31623635973249, 67.07068307059151, 51.163181918007986, 54.079278332846506, 58.76570279257638, 67.73488916669572, 65.29392446790422, 65.00820064544678, 51.97958483014788, 50.267392362867085, 50.30367585590908, 50.5920295715332, 52.46171338217599, 61.1082740511213, 66.08292715890067, 69.22668824877057, 61.80548409053257, 61.24233259473528, 64.32919488634381, 68.93261269160679, 66.76301683698381, 68.85488319396973, 68.20598397936139, 70.06925460270473, 62.18250724247524, 62.769081115722656, 68.84341171809605, 69.76056003570557, 61.77282060895647, 54.46668904168265, 62.56584630693708, 71.81117493765694, 69.7263262612479, 59.183081081935335, 27.11443305015564, 2.1415505366665974, 0.4697283517037119, 1.279170308794294, 1.7193447692053658, 0.3348733979676451, 0.11010687492255654, 0.18612792316292012, 0.034918952334140024, 0.10933419995542083, 0.145266788612519, 0.023723974391551952, 0.05164375488779374, 2.77448713353702, 27.43727762358529, 32.10812248502459, 28.55541127068656, 39.718925612313406, 33.49524695532662, 22.793049573898315, 39.36118023736136, 56.60029322760445, 67.29984855651855, 67.031724521092, 51.41386944907052, 3.043604327099664, 0.11344897201550858, 0.06474117708525487, 0.03682346103180732, 0.024169208714738488, 0.023386180999555757, 0.011655915262443679, 0.038052610254713466, 0.07164924711521183, 0.036325881124607155, 0.04229813262021967, 0.08402683865278959, 0.09724233272884573, 0.028681017059300627, 0.015607910164232765, 0.043730737175792456, 0.13472958760602133, 0.051519321743398905, 0.04507615337414401, 0.03408371643828494, 0.03138276369177869, 0.06025538207697017, 0.021295904680820446, 0.05365141787167106, 0.035313069221696684, 0.10127520561218262, 0.03912253105746848, 0.0027936556850493488, 0.13798388226756028, 0.04291537557063358, 0.036867762583174875, 0.016863603677068437, 0.02563723110194717, 0.06378159964723246, 0.016852641943842173, 0.055947933212987015, 0.01567750241208289, 0.022018624203545705, 0.020345280512369106, 0.01760161398643894, 0.033243167613233836, 0.03514890445928488, 0.04486871164824281, 0.08054178780210869, 0.05139939407152789, 0.04126567034316914, 0.020476346336571232, 0.051687598428023715, 0.07857008717421975, 59.92188303811209, 114.51709638323102, 96.64556530543736, 91.86011859348842, 63.9787277494158, 34.754173687526155, 58.37135778154646, 115.58315849304199, 103.9512973512922, 52.14405216489519, 45.30370003836495, 24.5194319997515, 0.11127694070871387, 0.05666118208318949, 0.08953497558832169, 0.1419967519385474, 0.25147547306759016, 0.9754789876086372, 2.4114978228296553, 2.1629407831600735, 2.5131949143750325, 0.42945898111377445, 0.10595070544098105, 0.3069339586155755, 20.35094710758754, 75.55329404558454, 81.7492459160941, 74.32132284981864, 82.13187626429966, 79.67678587777274, 76.39847987038749, 64.12282643999372, 55.06094067437308, 62.30879075186593, 72.36202117374965, 74.80854443141392, 73.00648743765694, 73.26801763262067, 72.52135726383754, 65.98308849334717, 67.95425074441093, 69.59296253749302, 70.85151754106793, 70.0617366518293, 71.14298752376011, 65.24016625540597, 67.83212920597622, 68.87396989549909, 66.41994953155518, 66.83563246045793, 69.1333669934954, 70.0291565486363, 70.81754779815674, 62.64540318080357, 53.62223277773176, 50.67512655258179, 53.16295337677002, 56.04574012756348, 67.44382912772042, 69.53378473009381, 72.2994248526437, 66.89861093248639, 71.01900386810303, 62.9027019228254, 78.78512355259487, 39.14103698730469, 44.431916509355815, 73.5271645954677, 61.1739901133946, 69.13288061959403, 55.603386538369314, 55.925557136535645, 61.03398391178676, 71.33778721945626, 68.51990359170097, 68.41223430633545, 55.27307265145438, 51.646915503910606, 51.75295196260725, 53.09708098002842, 55.17911216190883, 65.12435368129185, 67.85444681985038, 69.87245382581438, 63.6513147354126, 61.47694546835763, 64.77688816615513, 70.65395941053117, 70.26517295837402, 72.12467765808105, 70.01466260637555, 70.00408049992153, 62.79633889879499, 65.97517449515206, 72.28019223894391, 72.42003863198417, 64.59401852743966, 58.43168898991176, 64.69495500837053, 74.85033784593854, 72.76815727778843, 65.94935498918805, 32.48301601409912, 2.708148556096213, 0.5596488437482289, 0.4439480107809816, 1.5012134569031852, 1.3495992038931166, 0.6442813224026135, 0.7155609375664166, 0.19472691603004932, 0.10123488027602434, 0.1363519105528082, 0.10931581844176565, 0.026363277142601352, 2.251518807240895, 30.359646524701798, 33.17356620516096, 32.7433511189052, 34.77279485974993, 32.606714793613975, 36.376446042742046, 50.45598384312221, 63.88783836364746, 74.87679658617292, 73.66924136025565, 64.82390662602016, 5.8980417762483865, 0.17257449829152652, 0.033653833969895325, 0.062323400750756264, 0.04899883556312748, 0.05297064029478601, 0.04287261090108326, 0.04914722438635571, 0.04868795795898352, 0.04357407022533672, 0.03580453213570373, 0.016846509683611136, 0.04683193737374885, 0.043676573117928844, 0.03838843419881804, 0.05151978314721158, 0.048119067413998504, 0.07778771594166756, 0.034178830084523985, 0.03640111708747489, 0.027170757563518624, 0.08883033732750586, 0.011955487625008183, 0.00513054831286094, 0.0563147221026676, 0.020734048847641264, 0.024214655293950012, 0.22520193218120507, 0.2196294090577534, 0.19299749311591896, 0.0546314124284046, 0.16117207014134952, 0.1132310333528689, 0.18847370014658996, 0.09993602175797735, 0.11226758147989001, 0.10279964309717927, 0.10759050744984831, 0.10078810567834548, 0.09091106496219124, 0.1060737781226635, 0.0837438895500132, 0.17461853075240338, 0.18195593703005994, 0.1619336578462805, 0.17683016136288643, 0.12944579470370496, 0.15891328134707042, 0.2051189105425562, 73.22540433066231, 121.53737558637346, 107.46210397992814, 100.64337117331368, 70.96463421412876, 38.30748244694301, 74.65660122462681, 112.29047666277204, 98.52471951075962, 64.91997936793736, 66.76619911193848, 31.04017046519688, 0.48517273153577534, 0.10749038282249655, 0.2534593194723129, 0.19194703948284897, 0.45777929574251175, 1.2859605444329125, 3.311619145529611, 5.005468802792685, 6.595422915049961, 7.6260596343449185, 10.140055980001177, 2.24463010260037, 21.246920789991105, 83.10499926975795, 82.40020179748535, 73.01665265219552, 79.5891204561506, 83.25947162083217, 77.07458128247941, 68.03050027574811, 58.39588492257254, 65.15642656598772, 74.36694472176688, 76.97530542101178, 75.74593979971749, 76.16634055546352, 70.95581000191825, 66.28077711377824, 71.56302002498082, 72.46846062796456, 72.88094738551548, 73.69661726270402, 73.47145393916539, 67.72288962772915, 69.27189322880336, 72.380037852696, 67.21175929478237, 72.06963402884347, 71.11443737574986, 73.63857201167515, 74.71504947117397, 67.5099412373134, 57.54546710423061, 53.807509967258994, 56.11771651676723, 60.30692441122872, 69.68540137154716, 73.33226762499127, 74.85199846540178, 71.18602466583252, 72.36187526157924, 67.20191369737897, 78.548752784729, 43.62022794995989, 47.4298210144043, 76.21947343008858, 64.93326432364327, 73.61797755105155, 57.81514058794294, 59.32001617976597, 65.1040232522147, 73.1891416822161, 70.42314720153809, 70.96369620731899, 57.77203743798392, 54.53814084189278, 55.56574467250279, 55.23955454145159, 57.13587079729353, 67.78514548710415, 71.06623772212437, 71.84130927494594, 65.151444707598, 63.01563099452427, 66.83616747174943, 73.46174035753522, 73.45201287950788, 74.29047284807477, 70.95897143227714, 72.96959250313895, 64.71491718292236, 66.97219235556466, 74.86788204738072, 76.388092313494, 67.88037054879325, 60.20166615077427, 66.52274118150983, 78.10142775944301, 76.42803750719342, 67.46518789018903, 31.403665474482946, 2.7361081072262357, 5.275074107306344, 5.5619582789284845, 5.339860848018101, 2.0699921250343323, 0.5384551009961537, 0.950690746307373, 0.35638711069311413, 0.30328572009290966, 0.302558927663735, 0.22388746057237896, 0.1328404511192015, 4.72354998758861, 44.533137866428916, 48.57657602855137, 37.75553839547293, 55.02326059341431, 47.05396168572562, 34.11100673675537, 53.48063543864659, 74.8380047934396, 84.08627251216343, 83.80792767660958, 72.97820826939174, 6.007523238658905, 0.25769291658486637, 0.12571535844888004, 0.12578384977366242, 0.0991458473727107, 0.11724310235253402, 0.13423963103975567, 0.19539517802851541, 0.11383092616285596, 0.09888377000710794, 0.16856679905738148, 0.1483876154358898, 0.19522812270692416, 0.11291443569851772, 0.11982913501560688, 0.10347167096499886, 0.12403550930321217, 0.10316660162061453, 0.17697483859956264, 0.11437933173562799, 0.16204467974603176, 0.215278615376779, 0.11431324242481164, 0.1552140169910022, 0.13721572634364876, 0.10140843596309423, 0.05612031164179955], [0.06495324641998325, 0.04357264530179756, 0.04617763962596655, 0.08546717172222477, 0.08314732156161751, 0.02676105642292116, 0.037091920019260476, 0.029570586646773984, 0.027557357979406203, 0.025077739963307977, 0.0032644510585149483, 0.04077142543558564, 0.042490212313298664, 0.07476730551570654, 0.01609293038823775, 0.04701267196131604, 0.10844895602869135, 0.12404863217047282, 0.05492470919021538, 0.06067173116441284, 0.16059957657541546, 5.633568584918976, 88.696763583592, 84.0930609021868, 97.08817250388009, 63.827618326459614, 75.8166446685791, 88.21958909715924, 41.3934588432312, 64.6533283506121, 49.53633764811924, 37.86358983176095, 28.632541486195155, 1.4023486248084476, 0.024213686685210893, 0.1280652337840625, 0.03714825878185885, 0.11275819622512374, 0.12768057228199073, 0.5411124612603868, 1.3543341841016496, 0.9964261778763362, 0.971611880830356, 2.032540248973029, 0.7456503286957741, 40.90885673250471, 82.89385741097587, 73.88902677808488, 72.91908604758126, 79.14820166996547, 69.33193261282784, 75.58816010611397, 70.58098942892892, 60.213123730250764, 50.879702363695415, 64.29464149475098, 72.40070874350411, 68.2787733078003, 69.49597263336182, 69.41818060193742, 64.56182057516915, 67.7221461704799, 67.83164283207485, 63.37052413395473, 60.42333453042166, 61.312189783368794, 64.32529694693429, 66.21606159210205, 64.11709417615617, 63.32716737474714, 59.47795568193708, 59.625861985342844, 65.56184700557164, 64.09004483904157, 66.35811751229423, 57.702208042144775, 51.39780868802752, 47.35214710235596, 50.597108704703196, 60.59952000209263, 69.41979953220913, 68.53733662196568, 66.24819006238664, 62.9564323425293, 66.68177849905831, 60.21122687203543, 68.22229140145438, 39.18313612256731, 44.25816290719168, 67.2810606275286, 53.776555742536274, 58.698840277535574, 47.99352141789028, 51.50818082264492, 55.48955420085362, 65.9688446862357, 65.99269785199846, 65.24924755096436, 49.83579111099243, 49.0033517565046, 47.29683944157192, 51.181591170174734, 56.05610683986119, 64.17200578962053, 66.51347923278809, 64.23869459969657, 59.8014429637364, 63.01934133257185, 59.831966400146484, 64.5169769014631, 68.34965188162667, 64.71015071868896, 64.46075207846505, 61.484789984566824, 62.56916754586356, 64.4550267628261, 68.22832938602993, 68.27456269945417, 62.766447748456685, 53.83311755316598, 60.35633999960763, 71.22499711172921, 68.24664483751569, 71.34445749010358, 70.04346983773368, 37.18427835191999, 1.4448682346514292, 1.7298749813011713, 0.718991719186306, 1.5092054052012307, 0.6523031262414796, 0.22679795511066914, 0.0574165815487504, 0.11885519299123969, 0.20678704817380222, 0.0801946764279689, 0.10355798740472112, 0.07974616478064231, 5.41242218869073, 35.41035808835711, 33.36307832172939, 39.27011367252895, 46.47425958088466, 12.487332037517003, 36.27209104810442, 67.26537159511021, 57.693255288260325, 63.03454399108887, 66.02065740312848, 39.82636560712542, 0.7127351920519556, 0.06485588343015738, 0.01087401561172945, 0.01854935777373612, 0.021757423844454542, 0.04509622783267072, 0.05422917686934982, 0.05994718468614987, 0.005444000109231898, 0.030903066574995006, 0.062456095059003146, 0.05941410043409892, 0.035731871213231764, 0.06449811905622482, 0.08544478685195957, 0.06479790261281387, 0.09821494482457638, 0.05395764751093728, 0.029471330544246093, 0.04337210088436093, 0.039234214528862915, 0.05942516055490289, 0.0613902047542589, 0.07495421477194343, 0.007518241797307772, 0.0375622126406857, 0.02654631026754422, 0.03631684643083385, 0.02848647428410394, 0.031473524535873106, 0.06512485471154962, 0.023547631621892964, 0.025717540810416852, 0.07132469024509192, 0.030022606320147003, 0.06484163419476577, 0.032475724151091914, 0.02116739014828844, 0.03479233430698514, 0.07806299759873322, 0.027935556435425366, 0.034671300623033724, 0.03567279116915805, 0.03787985184629049, 0.028872136625328233, 0.047611136455088854, 0.19475914644343512, 7.379244855472019, 105.13485349927629, 93.40867750985282, 107.05040236881801, 72.28989887237549, 79.48924010140556, 73.95484706333706, 49.722344398498535, 81.28406402042934, 62.723014559064595, 38.57868800844465, 33.63864735194615, 1.5182648790734155, 0.06579433128769908, 0.08332230217222657, 0.09544534129755837, 0.3406297633690493, 0.4762956478766033, 1.8787299309458052, 1.9414319949490684, 2.6904666934694563, 1.0851041908775056, 0.6436312315719468, 0.6443435847759247, 44.87864398956299, 86.84685434613908, 77.50509861537388, 75.68981225149972, 81.22674138205392, 75.08703517913818, 77.13391889844621, 74.85748059409005, 63.05861949920654, 53.581255776541575, 67.69281087602887, 75.31056567600795, 70.47129126957485, 72.0856704711914, 71.37593282972063, 66.49920763288225, 70.14458002362932, 70.29678726196289, 65.8591673714774, 65.0056437083653, 63.72374275752476, 66.64024216788155, 68.57594081333706, 67.86838490622384, 66.1297163282122, 62.41172136579241, 60.8418801171439, 67.6084041595459, 66.74358967372349, 69.05244132450649, 60.19152178083147, 52.85286569595337, 48.258449281964985, 53.35160391671317, 63.54594530378069, 72.19472244807652, 68.72653606959751, 67.35097340175084, 64.49272074018205, 68.6285595212664, 62.49275820595877, 71.24210357666016, 40.65787042890276, 47.38679082053048, 68.58222893306187, 55.276456424168174, 60.54722091129848, 50.65650190625872, 52.03184570584978, 57.88522359303066, 69.00167778560093, 69.18700013841901, 67.72257695879254, 52.225165435246055, 51.38294301714216, 50.48055614743914, 54.014687878744944, 60.033568382263184, 67.36086763654436, 67.86699526650565, 65.27804783412388, 61.46117305755615, 62.449352809361045, 62.685883385794504, 65.5840881892613, 68.72354834420341, 66.98578303200858, 65.92935807364327, 61.785223143441335, 63.981757164001465, 66.32726056235177, 70.81438636779785, 69.43456445421491, 67.4915771484375, 56.70235184260777, 62.37773772648403, 73.55172647748674, 71.34103202819824, 74.30810042790004, 75.54524803161621, 43.6114627974374, 2.5146271118095944, 0.9306015500000545, 0.49021288965429577, 2.2156174651214053, 1.9133601869855608, 0.7167874574661255, 0.27254862657615114, 0.14797395334712096, 0.17613720068974154, 0.37265382068497793, 0.039332055885876925, 0.1490647933845009, 6.088422851903098, 36.442193371909006, 28.853266647883824, 41.078083583286826, 31.085462297712052, 18.606850249426707, 40.312069007328574, 75.8868075779506, 62.50627245221819, 71.91714191436768, 76.55691964285714, 54.06627477918352, 1.139815392238753, 0.04782398610508867, 0.02621473395265639, 0.01607431817267622, 0.054170656616666486, 0.02966368504400764, 0.04055392103535788, 0.023328994068184068, 0.044299017039260695, 0.017691618263987557, 0.034011954574712684, 0.042707818493779214, 0.08192446575100933, 0.03134432129029717, 0.06852867134979793, 0.05298782419413328, 0.0944944830345256, 0.03237755370459386, 0.06814751108842236, 0.06796940921672753, 0.03616145173353808, 0.04124953138775059, 0.021942275443247387, 0.04777504676686866, 0.04347989635009851, 0.011556938207442207, 0.1607680839619466, 0.1482647191733122, 0.19843131011085852, 0.14400450991732733, 0.08726571021335465, 0.15649289265275002, 0.17164880010698522, 0.12755858525633812, 0.13640666832881315, 0.14197263680398464, 0.15647675709000655, 0.13162674196064472, 0.0847323386530791, 0.2461223474570683, 0.1139127439154046, 0.12724605202674866, 0.20450923325760023, 0.1728053359048707, 0.11164830292442016, 0.14411414760564054, 0.31050278139965876, 10.079279218401227, 117.97026770455497, 102.80024487631661, 118.64000456673759, 84.0337997164045, 91.77999196733747, 96.78462655203683, 52.82583025523594, 73.90705735342843, 65.35290077754429, 56.97724689756121, 46.07954978942871, 2.894373740468706, 0.16002392103629454, 0.2371467405131885, 0.22450643378709043, 0.8311309218406677, 1.3194187262228556, 3.203456755195345, 6.231276077883584, 5.0140315890312195, 6.429772649492536, 7.559008649417332, 0.790495250906263, 49.8916129384722, 91.08061408996582, 78.02589389256069, 76.74547985621861, 83.45429216112409, 76.59028489249093, 80.44203962598527, 78.15672152382987, 65.63409437452043, 56.40837356022426, 69.96210643223354, 77.6474255153111, 74.96329471043178, 73.68898119245256, 72.14625876290458, 65.61648069109235, 70.7945145198277, 72.6191531590053, 68.55668040684291, 67.41139493669782, 67.37856469835553, 68.6197144644601, 70.81159319196428, 70.1078657422747, 70.62839698791504, 65.21461078098842, 65.04824311392647, 69.82693617684501, 69.92990153176444, 72.11152471814836, 64.7338649204799, 55.748350279671804, 50.69198983056204, 56.539652824401855, 65.57099778311593, 76.53772177015031, 73.66425255366734, 70.70399338858468, 68.02476106371198, 71.1030353818621, 65.52165862492153, 72.19900253840855, 44.3144085747855, 52.00656121117728, 71.03661060333252, 59.49470084054129, 64.80043561117989, 54.63038512638637, 55.43279089246477, 62.42608329227993, 72.14152703966413, 71.55409158979143, 71.4721792766026, 55.169971806662424, 54.9552446774074, 53.10175016948155, 56.4677528653826, 62.278218678065706, 70.36102335793632, 69.94973863874162, 68.10586043766567, 63.44639846256801, 65.4644193649292, 64.68358080727714, 69.37936101640973, 73.02576174054826, 68.4739898954119, 67.89737279074532, 62.57398959568569, 64.53167928968156, 69.3517905644008, 71.74044227600098, 72.3024125780378, 69.37230859483991, 59.10180800301688, 66.34417247772217, 78.3731995991298, 73.43543447766984, 76.70471477508545, 77.17079298836845, 43.485849789210725, 1.6126825383731296, 4.776229926518031, 4.33812906912395, 5.748844410691943, 2.897268750837871, 1.1869596796376365, 0.2754644272582871, 0.6032246340598378, 0.37214231384652, 0.4425134249031544, 0.22269750013947487, 0.26019201534135, 8.555846725191389, 55.667914458683555, 44.59805488586426, 55.75378029687064, 62.044682775224956, 18.91988570349557, 46.99044125420706, 84.4141024180821, 75.57093552180699, 81.64612075260708, 87.46060957227434, 57.12431594303676, 1.1231146369661604, 0.22361471663628305, 0.1146760279578822, 0.10057134766663824, 0.25970420294574326, 0.16828142079923833, 0.16400000053857053, 0.13025759400001594, 0.12823159699993475, 0.09074173654828753, 0.09273161512932607, 0.12811285337167128, 0.14635305532387324, 0.1796785563762699, 0.1833332952644144, 0.175023561875735, 0.15456251480749675, 0.147208837260093, 0.09789389598050288, 0.24121382513216563, 0.11126350571534463, 0.1268526374229363, 0.190480589600546, 0.13350165635347366, 0.13629411293991975, 0.06269692749317203], [0.04207776480221322, 0.04064872934083853, 0.052726167520242076, 0.033420998070921214, 0.04070894932374358, 0.031031391117721796, 0.06180308652775628, 0.06385539711586066, 0.016417295572214892, 0.07776129378804139, 0.08070627147597925, 0.08853272508297648, 0.0282043275489871, 0.05657345429062843, 0.042301046928124766, 0.06764693544911486, 0.005288415422130908, 0.076477593742311, 0.1719433928706816, 0.1972335600959403, 0.8046926462224552, 25.801223516464233, 95.90809045519147, 78.11852727617536, 71.69692570822579, 51.40579216820853, 38.50846951348441, 44.64659152712141, 56.04975618634905, 54.19200938088553, 40.80497421537127, 41.96539633614676, 6.838432252407074, 0.17330433055758476, 0.0963382390992982, 0.05167627028588738, 0.05263387657968061, 0.28009526591215816, 0.18815343161778791, 0.8322176092437336, 1.6028185933828354, 1.0849248405013765, 1.384470475571496, 1.7684232613870075, 65.1929462977818, 80.80613912854875, 77.51645892007011, 69.95155211857387, 73.35978943961007, 70.64510740552629, 72.55709879738944, 72.38144833700997, 71.60612664903913, 58.11436128616333, 51.46333714893886, 64.09851469312395, 72.62951292310441, 66.9139039175851, 71.42071396963937, 61.687920570373535, 66.96211746760777, 65.06596102033342, 64.47061852046421, 58.077963147844585, 55.14464214869908, 56.031392097473145, 59.108374050685335, 61.634704317365376, 64.11522511073521, 57.00409821101597, 54.170841693878174, 54.25275748116629, 62.5257899420602, 65.29741941179547, 59.82034206390381, 49.2178634916033, 50.601180349077495, 44.10117878232683, 50.71192421231951, 60.60383483341762, 67.93929127284459, 63.31363228389195, 65.39802932739258, 64.66822528839111, 66.91585636138916, 60.51427950177874, 68.37711116245815, 40.89958783558437, 45.187140532902305, 70.35747282845634, 50.668341636657715, 49.048341342381065, 45.797095094408306, 50.46649299349104, 52.03871400015694, 61.97179617200579, 62.0441130229405, 61.48417159489223, 48.92523315974644, 47.94941772733416, 47.27580377033779, 52.18860054016113, 59.11070169721331, 64.48225675310407, 66.11170659746442, 61.60531343732561, 58.437615803309846, 62.649120467049734, 64.89677238464355, 64.33515644073486, 62.082508768354145, 65.1447535923549, 60.196343830653596, 63.28674275534493, 65.77822780609131, 64.83746256147111, 66.88909884861538, 68.2764595576695, 62.79255213056292, 54.596085344042095, 52.85820538657052, 67.03061280931745, 66.69650868007115, 65.2785758972168, 65.94980662209647, 76.9395569392613, 59.522014209202354, 8.456027167184011, 1.3266471326351166, 0.8731993873204503, 2.1686404773167203, 0.5143528314573425, 0.40805812233260697, 0.07441099320671388, 0.36931515697922024, 0.15931990024234566, 0.05440242721566132, 0.26938757619687487, 0.02241251208553357, 19.922026123319352, 46.50219481331961, 37.3213141986302, 56.10560233252389, 32.81013372966221, 28.599662610462733, 40.73061459405081, 53.39610365458897, 60.848939486912315, 62.18477235521589, 72.13795566558838, 23.37447135789054, 0.3417995848826, 0.04724421864375472, 0.039467593255851946, 0.0417179716085749, 0.09050830014582191, 0.04713611783725875, 0.084579369718475, 0.03156424806054149, 0.0688029962724873, 0.0279534120844411, 0.027213642673034753, 0.05426980754626649, 0.03286710314984832, 0.049564245223466835, 0.05892073762203966, 0.054958859857703955, 0.04252813224281583, 0.04887080279045871, 0.06636328968618598, 0.03530000402991261, 0.06121521735829966, 0.04763757557209049, 0.08116873380328928, 0.05288564021299992, 0.0389315505911197, 0.058015531195061545, 0.04634111228265932, 0.036597342629517825, 0.006572257960215211, 0.01711904157751373, 0.1037748268406306, 0.08067138120532036, 0.03764722290049706, 0.018254089867696166, 0.04833988306511726, 0.050495473468410115, 0.027635459056390182, 0.04618113747398768, 0.09189741739204951, 0.05378349471305098, 0.06757701920079333, 0.01679666110846613, 0.08093092084995337, 0.137734303517001, 0.2520530420754637, 0.7553022993462426, 31.82338183266776, 112.04564993722099, 86.36137676239014, 82.79290703364781, 62.42288712092808, 60.422486850193565, 66.28639820643834, 57.30624062674386, 57.9624354498727, 45.86378737858364, 46.49289117540632, 7.749744517462594, 0.059521940004612715, 0.016302249959803054, 0.19737511607153074, 0.1602828907115119, 0.5876689744847161, 0.6794869218553815, 0.9939545733588082, 1.8986868943486894, 0.8130414496575082, 0.6808386178953307, 2.149677106312343, 68.84073666163853, 85.32058525085449, 82.44943673270089, 76.54782445090157, 77.25686727251325, 73.34196731022426, 74.98085280827114, 75.0178450175694, 74.2278834751674, 59.72171933310372, 53.15301397868565, 67.73169994354248, 76.24325711386544, 68.80426556723458, 72.71336378370012, 64.38537107195172, 67.19173458644322, 68.93929685865129, 67.72987951551164, 61.604938234601704, 59.26274217878069, 57.6319374356951, 61.74998882838658, 63.80862889971052, 65.99293409075055, 60.31688812800816, 57.327043533325195, 59.250680106026785, 64.05317769731793, 68.46175411769322, 61.71358721596854, 51.922856262751985, 53.845672948019846, 46.78527137211391, 52.88237469536917, 64.33585126059396, 69.72216429029191, 66.46287550245012, 68.18016447339738, 66.26371233803886, 68.73654842376709, 63.069674083164756, 68.82636083875383, 42.259041104997905, 48.25708048684256, 71.81246730259487, 53.171763692583355, 51.75095435551235, 47.56800331388201, 52.177070004599436, 56.181209155491416, 66.00606618608747, 64.50349739619664, 63.86338070460728, 51.30332708358765, 50.37210866383144, 49.50201007298061, 52.99900368281773, 61.76531655447823, 69.31465939113072, 68.44060380118233, 61.17312853676932, 59.21653665815081, 64.88537039075578, 64.96658093588692, 67.17867197309221, 64.52036762237549, 66.76719270433698, 60.13897255488804, 64.66895484924316, 66.76757485525948, 67.5681254523141, 69.67043495178223, 71.03597136906215, 64.62637628827775, 58.01180934906006, 55.86658082689558, 70.25149195534843, 69.69434370313371, 68.89206300462995, 69.79415457589286, 80.6294811793736, 64.98317323412213, 12.421303306307111, 0.7124175290976251, 0.32314266743404524, 1.017975581543786, 1.847362939800535, 1.0193618557282855, 0.12814790649073465, 0.4981495780604226, 0.33770128765276497, 0.1376341110361474, 0.251357760812555, 0.04539166876514043, 20.512197426387242, 39.73387118748256, 35.33986861365182, 45.604890550885884, 29.30663660594395, 40.68483638763428, 49.40771606990269, 61.71855517796108, 66.62235055650983, 70.34088053022111, 81.92529937199184, 33.54846320833479, 0.2853396087884903, 0.0009784902233929771, 0.0903956972594772, 0.07949833665043116, 0.05560282690982733, 0.007075629587883928, 0.015114191121288707, 0.02252391566123281, 0.07727977819740772, 0.018348034737365584, 0.07430499925145082, 0.07063162100634404, 0.02037730227623667, 0.09584778041711875, 0.03168998399217214, 0.004891596268862486, 0.07676599826663733, 0.011908279399254491, 0.03285063510494573, 0.0815683366464717, 0.05166021614734616, 0.036507080508662124, 0.06640449711786849, 0.022339362617848173, 0.05037492832967213, 0.15150715304272516, 0.14294466535959924, 0.14664110700998986, 0.185131860896945, 0.11955020284014088, 0.14801894021885736, 0.28959348052740097, 0.15503064968756267, 0.06772739613162619, 0.1330824845603534, 0.19971477266933235, 0.15590985465262616, 0.11233569282506194, 0.10945109796843358, 0.14204266161790916, 0.17075883357652596, 0.17681287229061127, 0.19596475389386925, 0.2017290988670928, 0.5205130609018462, 0.908875184399741, 39.13525608607701, 125.1783150264195, 98.52953461238316, 93.20957687922886, 71.43154621124268, 51.894267899649485, 52.72522381373814, 69.12524454934257, 68.73116356985909, 60.58674226488386, 67.11560317448208, 10.977081145559039, 0.27776390101228443, 0.23638151586055756, 0.1823084766843489, 0.2191292473248073, 0.6680242940783501, 0.7933914554970605, 4.036346656935556, 5.176796615123749, 4.735989000116076, 6.221399647848947, 2.30895847933633, 75.71068464006696, 84.11236994607108, 83.94131224496024, 79.08167266845703, 79.0514132635934, 75.1355197089059, 77.98510101863316, 77.2917263848441, 77.57576874324253, 63.89997686658587, 55.810289996010916, 70.55724048614502, 79.47892897469657, 71.69029017857143, 75.39194297790527, 63.57795565468924, 69.86702728271484, 70.31467887333461, 71.22896453312465, 65.05523994990757, 60.910674231392996, 61.453217370169504, 65.18182918003627, 67.19002532958984, 70.51025676727295, 63.56481661115374, 60.46707344055176, 60.98064259120396, 67.50356973920549, 71.27410697937012, 65.67689527784074, 54.70436259678432, 55.215829917362754, 49.56895249230521, 55.81841244016375, 67.51914065224784, 73.35974080221993, 68.27201271057129, 71.54511451721191, 70.42286232539585, 71.36207117353166, 65.58457456316266, 69.9914139338902, 47.16953107288906, 52.73513541902815, 74.33776923588344, 55.41054276057652, 53.84896986825125, 50.9379734311785, 54.45920235770089, 59.22226892198835, 68.64152485983712, 67.22801113128662, 66.54493372780937, 53.17591176714216, 51.46431337084089, 51.251410143715994, 55.3697429384504, 65.33085414341518, 70.08222688947404, 71.1745115007673, 61.98519924708775, 60.591557366507395, 66.4701919555664, 68.5779002053397, 70.35433224269322, 67.24436024257115, 69.91849258967808, 61.13143239702497, 65.4263640812465, 68.85436902727399, 70.48317268916539, 74.49209567478725, 73.98586382184709, 68.00549370901925, 61.464320591517854, 58.63973890032087, 74.47768511090959, 73.57140377589634, 70.34292330060686, 71.93875081198556, 83.23714011056083, 66.8190610068185, 10.53992394038609, 3.020917807306562, 4.655615712915148, 4.916887956006186, 3.0369416560445512, 1.3193008239780153, 0.1962578267391239, 1.1488171092101505, 0.7736938010369028, 0.2177043780684471, 0.6281686670013836, 0.13053385274750845, 31.2166998726981, 66.52859851292202, 50.566880566733225, 78.62872655051095, 47.40052046094622, 43.052813734327046, 56.30754130227225, 69.66555731637138, 78.80847644805908, 79.16077096121651, 91.56129046848842, 33.748237814222065, 0.3710026464291981, 0.09750919376632997, 0.0932016024099929, 0.1260577336485897, 0.2423256997551237, 0.10691771283745766, 0.11890963864113603, 0.10091140227658407, 0.2176025706742491, 0.11103064606764487, 0.15285610780119896, 0.1845944340207747, 0.10242596707705941, 0.11348788599882807, 0.1514073269707816, 0.08107136402811323, 0.16149939543434552, 0.1564322587634836, 0.17030357729111398, 0.17084192697490963, 0.16177526063152722, 0.19262157114488737, 0.12700210511684418, 0.13329205688621315, 0.12093794266028063], [0.07471453584730625, 0.05483720192153539, 0.046718153836471696, 0.01886900544299611, 0.027154708513990045, 0.02849131902413709, 0.06705350907785551, 0.03710276300885847, 0.07521173238222088, 0.030092135803507905, 0.04025846992486289, 0.044067063235810826, 0.03554456162133387, 0.027564509738502756, 0.05262330839676516, 0.03335716488904186, 0.08500878739037684, 0.028168455098888705, 0.03257075637312872, 0.07918547772403274, 1.18919352548463, 64.53709193638393, 86.42787797110421, 81.20527839660645, 66.71809673309326, 38.820315088544575, 30.693219116755895, 27.376463515417917, 37.7282771383013, 48.83246428625924, 50.055548736027305, 18.697499922343663, 0.05589888530916401, 0.13104477604585035, 0.08294042266373124, 0.1913985117737736, 0.39669065230659073, 0.0686362259356039, 0.8070618733763695, 0.9097476175853184, 0.5744208225182125, 1.9025279453822543, 2.7519708446093967, 74.54299122946603, 83.97558076041085, 75.99740205492292, 75.00763811383928, 70.09418473924909, 65.32835974012102, 75.77287101745605, 74.29507950374058, 71.69723837716239, 70.10661506652832, 57.37813016346523, 48.42025545665196, 62.256463868277415, 67.09806592123849, 68.84322411673409, 74.70168113708496, 63.98231996808733, 67.45254216875348, 64.30779443468366, 60.74687739780971, 56.000253745487754, 51.53381620134626, 48.42917346954346, 48.18923132760184, 53.05547169276646, 54.28660563060215, 48.648746967315674, 47.045651640210835, 47.5534850529262, 51.480026721954346, 52.90601594107491, 47.84088339124407, 46.41153471810477, 45.92520945412772, 45.650741713387625, 47.53561776024954, 54.28207540512085, 63.03276525224958, 59.106574467250276, 64.79632922581264, 60.38665499005999, 64.88825389317104, 60.31782613481794, 69.2391255242484, 39.70068311691284, 44.03160299573626, 70.19021579197475, 52.488356249673025, 53.756086349487305, 45.15038456235613, 48.78759281975882, 49.5004015650068, 60.26649284362793, 56.85577501569475, 59.87340545654297, 48.22572674070086, 49.38086475644793, 48.06714105606079, 52.494710377284456, 58.493395941598074, 66.41787202017647, 58.73321301596505, 59.49302632468087, 60.571532658168245, 61.73782253265381, 58.96072483062744, 59.06619848523821, 60.256549971444265, 64.33319704873222, 64.55934701647077, 63.725042070661274, 65.32083484104702, 62.93708855765206, 60.4933237348284, 59.940802982875276, 59.15950584411621, 53.072585105895996, 50.20394836153303, 58.54369395119803, 62.79365689413888, 68.15811783926827, 66.49541391645158, 65.86251640319824, 68.94500827789307, 72.82921804700578, 19.06228382246835, 0.7559669379677091, 2.0574527978897095, 0.462075942328998, 0.8118491279227393, 0.04886024817824364, 0.14728448034397193, 1.2955834737845828, 0.06987213675997087, 0.04501741259757962, 0.02982048430879201, 0.7733826520187514, 29.13409546443394, 37.534627369471956, 44.04552371161324, 35.07042442049299, 13.757130963461739, 19.19800819669451, 41.04296391350882, 53.557089941842214, 65.76157992226737, 63.634889193943565, 71.60952431815011, 7.990237304142543, 0.19622892114732945, 0.013837953264425908, 0.05646380303161485, 0.07086257397064141, 0.02785516869542854, 0.07065580399440867, 0.014862434273319585, 0.02680136649204152, 0.044458778109401464, 0.06843556955988918, 0.013808104508955563, 0.05189646168478897, 0.04096691815980843, 0.06115477345883846, 0.0687949624178665, 0.026914003305137157, 0.03383173228108457, 0.05097774901826467, 0.06100985873490572, 0.051473093152578385, 0.04032029803576214, 0.017889436666986773, 0.01464452953743083, 0.03457345926601972, 0.0859642189794353, 0.04748897301033139, 0.023037771927192807, 0.03707761310839227, 0.05436876170071108, 0.08299829491547175, 0.1291242233876671, 0.04154604101287467, 0.015933240564273934, 0.023019293722297465, 0.07674268380339656, 0.04571508230375392, 0.013789160659403672, 0.01135872455779463, 0.051440825419766564, 0.02991561491840652, 0.07185376435518265, 0.059282878546842506, 0.08757600427738257, 0.03640389908105135, 1.7667075991630554, 76.87817655290876, 97.27359907967704, 89.42199570792062, 75.29649557386125, 47.99849285398211, 32.840424401419504, 26.288637910570415, 36.787643909454346, 38.246129853384836, 47.932616983141216, 20.95287823677063, 0.012844564426424248, 0.12789492149438175, 0.11470899118908814, 0.40277255166854176, 0.9138413007770265, 0.8473092594317028, 1.8383040087563651, 1.1479041810546602, 0.7515311645609992, 0.4048854825752122, 3.176840594836644, 79.91356658935547, 88.35696193150112, 79.27301216125488, 78.08949770246232, 73.44831643785749, 68.48180661882672, 78.96025289808, 76.38699449811662, 73.65163462502616, 72.8008485521589, 60.950925145830425, 50.55793823514666, 64.51395443507603, 70.81810365404401, 71.34495776040214, 73.5170966557094, 64.19194711957658, 69.37303815569196, 67.3141062600272, 63.23976598467146, 59.37729712894985, 54.86655787059239, 50.81790508542742, 51.8748094694955, 55.503839697156636, 55.662307262420654, 52.279319695064, 48.27659102848598, 51.386194774082725, 53.52399219785418, 54.15663610185896, 50.6416049684797, 48.136525767190115, 49.54990400586809, 46.691623551504954, 48.20290538242885, 58.50683375767299, 66.27726132529122, 63.2634037562779, 66.43743814740861, 63.52359989711216, 67.94364779336112, 63.62698214394705, 70.95989554268974, 43.32589530944824, 46.31830031531197, 72.71912384033203, 56.22692135402134, 57.671962533678325, 47.17050034659249, 50.613409178597585, 52.7446996143886, 62.590637479509624, 59.950613839285715, 62.89742129189627, 51.10571684156145, 51.536571162087576, 49.755633217947825, 53.24204819543021, 59.96701853615897, 66.63130678449357, 62.63780185154506, 63.12459264482771, 61.96458394186837, 63.33070400782994, 60.50710201263428, 62.24764660426548, 62.35773386274065, 65.36938190460205, 65.95305143083844, 65.17975861685616, 68.20318385532924, 65.49092674255371, 62.803481646946494, 62.37557683672224, 61.74811281476702, 56.05606862476894, 54.19651181357247, 62.016632897513254, 65.37645517076764, 70.01300198691231, 67.78152547563825, 68.91793809618268, 70.83550889151437, 78.79888098580497, 24.26622748374939, 0.21258379997951643, 0.8271297908255032, 1.4293689749070575, 2.3764610971723283, 0.48959059161799295, 0.7799296464238847, 0.989994751555579, 0.6877716173018728, 0.10248356112944228, 0.06814156033630882, 0.8106892130204609, 31.656180381774902, 39.36500174658639, 45.99058158057076, 28.744831323623657, 20.213966846466064, 31.489791870117188, 50.28086839403425, 60.97898891993931, 71.67196083068848, 68.45213086264474, 85.02266733986991, 13.152523909296308, 0.2583437130919525, 0.06326332781463861, 0.038404101572398625, 0.02325943235440978, 0.024194572353735566, 0.029673476304326738, 0.03565297116126333, 0.05748800414481333, 0.021152983153504983, 0.042427661562604566, 0.03807882206248386, 0.10656630633664982, 0.04774172051942774, 0.03949700774891036, 0.08868561259337834, 0.016292545212698833, 0.03550410057817187, 0.026642485821087445, 0.034845477169645686, 0.07321028477911438, 0.06752742507628032, 0.013106186325395746, 0.010074048269806164, 0.046995114867708514, 0.15331787802278996, 0.134669102994459, 0.09906952575381313, 0.0873619739764503, 0.24261377858264105, 0.17644304356404714, 0.16241623195154326, 0.12463629777942385, 0.1808057116078479, 0.11907947595630373, 0.1538996539477791, 0.16269069936658653, 0.1087892141991428, 0.1411444983844246, 0.10050197424633162, 0.12475711772484438, 0.18394266042326177, 0.1674550058586257, 0.1495621052703687, 0.21443814119057997, 2.765981452805655, 94.31187384469169, 106.41703932625907, 100.9019970212664, 87.57690157209123, 55.087006841387065, 43.00175142288208, 37.61265216554914, 51.66303532464163, 64.43718378884452, 71.38328402382987, 28.55570830617632, 0.2367293600525175, 0.4226821804685252, 0.30167376516120775, 0.7107026268328939, 1.353784082191331, 1.1707195682185036, 4.72105428150722, 4.980286794049399, 4.252327501773834, 5.047698651041303, 3.4619896709918976, 86.83068588801792, 88.1942629132952, 84.47223799569267, 80.11571053096226, 76.08775642939976, 72.81632913861955, 82.81280667441231, 75.82001454489571, 76.717819077628, 75.80376270839146, 65.03666046687535, 54.27646126065935, 69.01153727940151, 74.21515437534877, 73.72609152112688, 77.80588613237653, 64.42651830400739, 70.40244851793561, 70.83839239392961, 66.9364925112043, 60.84389509473528, 58.49275670732771, 53.344433375767295, 54.51616021565029, 60.240610803876606, 59.22920322418213, 54.27521753311157, 52.31202139173235, 54.64321150098528, 56.00824417386736, 56.58497592381069, 53.88566677910941, 51.46836764471871, 52.78143474033901, 49.94014957972935, 51.05685363497053, 59.96514252253941, 69.20598261696952, 64.75093664441789, 68.28750024523053, 65.3735021863665, 72.5363792691912, 67.55932903289795, 73.93378012520927, 47.417265619550435, 51.792633124760215, 77.90858745574951, 58.529762813023154, 59.77635996682303, 51.33348226547241, 53.21381419045584, 55.60938630785261, 66.05059024265834, 62.12373243059431, 67.0903742653983, 54.42610808781215, 53.79331479753767, 53.42068638120379, 57.24297380447388, 63.63069248199463, 71.039320400783, 65.7095170702253, 65.3476687840053, 64.50651291438511, 67.54764911106655, 64.50781222752163, 65.03881440843854, 66.57251807621547, 69.6450114931379, 69.15882519313267, 67.96170616149902, 72.1787554877145, 67.99621786390031, 66.74346460614885, 66.49546255384172, 65.61357634408134, 58.12736831392561, 56.716189180101665, 64.36078834533691, 68.80057607378278, 73.54132502419608, 72.19825908115932, 71.67519869123186, 72.26170308249337, 78.85610634940011, 23.664063589913503, 1.7092410027980804, 7.005594185420445, 4.040790464196887, 3.6258559865610938, 0.2545906001968043, 1.2455687118428094, 3.234798776251929, 1.0817589589527674, 0.21279293804296426, 0.21625786354499205, 1.5866875903947013, 47.09879493713379, 53.194960253579275, 59.07902485983712, 49.82852329526629, 21.52888216291155, 33.165322167532786, 59.593309674944194, 71.06527192252022, 82.42611163003104, 78.32231099264962, 94.4969460623605, 13.200287563460213, 0.36000172102025574, 0.12191934856985297, 0.1814821431679385, 0.15234902501106262, 0.11784919697259154, 0.14066267066768237, 0.18495582177170686, 0.15382245023335728, 0.10932056818689619, 0.11594136006065778, 0.11324387123542172, 0.14139510850821221, 0.10967149292784077, 0.18180470514510358, 0.1477579077971833, 0.1548785221363817, 0.10942799385104861, 0.08829451179397957, 0.14515022986701556, 0.20308181270956993, 0.18165078626147338, 0.1096684123788561, 0.18460472061165742, 0.12714512672807488], [0.011617634861197854, 0.009556080929801931, 0.028094023200018064, 0.021978024060704877, 0.039590089182768545, 0.05425333950136389, 0.042159406135657, 0.027758837078831027, 0.01596081622743181, 0.05502663193536656, 0.05786773269729955, 0.0319469418110592, 0.033407719140606265, 0.038713269268295596, 0.21719177200325898, 0.047265738381871154, 0.08003667954887662, 0.10506506117859057, 0.1973537557891437, 0.5984080125178609, 13.200710535049438, 84.7402925491333, 77.47631917681012, 79.36636815752301, 51.64503254209246, 31.47101436342512, 108.45691231318882, 86.63337789263043, 54.176184858594624, 57.099278109414236, 36.46478196552822, 3.868112530027117, 0.1570165588387421, 0.026490756909229925, 0.17033251002430916, 0.1183939655976636, 0.6769908357943807, 1.335301113980157, 1.1976041027477808, 0.15961836065564836, 1.2339571863412857, 5.208683201244899, 78.80097239358085, 79.99373490469796, 72.36618314470563, 73.79320417131696, 70.10142476218087, 64.91928454807827, 63.58770397731236, 68.86034447806222, 71.72114018031529, 73.32935632978166, 68.59502751486642, 56.67208201544625, 48.29292276927403, 56.83520834786551, 64.91307285853794, 68.07511465890067, 65.61226313454765, 66.4350757598877, 65.25015776497978, 62.82554912567139, 57.711160796029226, 51.375081130436485, 48.736096245901926, 49.0107307434082, 48.204277651650564, 45.5560690334865, 47.94807325090681, 45.586915561131065, 45.92321184703282, 46.416627747671946, 45.09633799961635, 44.299428258623394, 46.97837918145316, 44.02366120474679, 46.7050335747855, 45.47725909096854, 44.69001082011631, 45.04624496187483, 51.7156331879752, 53.44125999723162, 57.50825950077602, 54.96676131657192, 60.38732201712472, 55.93434313365391, 68.28105231693813, 47.2739451272147, 35.971824645996094, 68.81648050035749, 57.793250288282124, 61.74506255558559, 49.10510812486921, 49.787122453962056, 49.39981944220406, 57.68738406045096, 55.50926276615688, 55.80708687646048, 47.34368072237287, 47.54986504146031, 48.56761632646833, 51.602686745779856, 56.101992743355886, 61.864543778555735, 61.78817612784249, 57.49732998439244, 59.24963092803955, 61.3991881779262, 58.00279058728899, 54.2736611366272, 54.64863109588623, 58.55208737509591, 63.19135788508824, 66.05732999529157, 64.25090258462089, 61.80001585824149, 57.936042717524934, 52.70210368292672, 53.759275572640554, 52.35083055496216, 49.60383244923183, 51.97722939082554, 58.57801110403878, 59.40331813267299, 65.07510484967912, 65.44763946533203, 66.7073061806815, 63.40275682721819, 80.01394721439907, 25.429324660982402, 0.4775899669953755, 1.07961120562894, 1.314285744513784, 0.3822312339075974, 0.04733281496113964, 0.504665902682713, 0.9233348199299404, 0.1427087794457163, 0.10093293897807598, 0.09330505864428622, 9.472764883722578, 28.316203900745936, 31.700502940586635, 48.33840567725045, 35.55757304600307, 18.489093916756765, 32.43317658560616, 52.117186955043245, 56.67664698192051, 59.804173605782644, 69.11891474042619, 44.995735032217844, 0.14461896408881458, 0.012418597953261008, 0.06987818929233722, 0.0059605510073847, 0.06181198212185076, 0.031704392683293135, 0.057605614619595666, 0.04345797288364597, 0.04417930310592055, 0.026481389733297483, 0.032133433768259625, 0.06230991825993572, 0.06362512947193213, 0.04036563774570823, 0.06039315861250673, 0.09779320816908564, 0.028094706824049354, 0.03347656669627343, 0.04274605394208005, 0.01913301493706448, 0.05738720776779311, 0.14753228133278234, 0.14163693838885852, 0.03080815988193665, 0.07440850298319544, 0.031892014401299615, 0.08981304602431399, 0.025177262390830686, 0.015048476701070155, 0.06239384625639234, 0.08538518433592149, 0.03109170270285436, 0.020379655096413832, 0.10248493855553013, 0.09139923019600765, 0.021961589942553213, 0.02583117676632745, 0.015965545616511787, 0.09806428969438587, 0.01694931452428656, 0.07764073847127811, 0.06839093552636248, 0.2571060652179377, 0.4987326296312468, 18.76489223752703, 101.9636539731707, 84.93660695212228, 90.20401545933315, 59.98685564313616, 42.60810470581055, 83.29091916765485, 77.75350366319928, 43.693003382001606, 47.50256865365164, 44.721121379307334, 3.9039999757494246, 0.31173193401523996, 0.08972049384777035, 0.5332611054182053, 0.7658642668809209, 1.1511547437735965, 2.120085379907063, 1.5334399619272776, 0.5179096034594944, 0.8179253818733352, 6.226971668856485, 87.52246243613106, 83.82576370239258, 76.88635458265031, 78.78269168308803, 74.52872657775879, 68.03159809112549, 67.31357819693429, 71.83022689819336, 73.77729279654366, 77.89630304064069, 74.2995958328247, 58.9362393787929, 51.92408609390259, 60.386008807591026, 67.05814157213483, 71.39254597255162, 68.1463406426566, 67.67214693341936, 68.93189007895333, 64.98176274980817, 60.38916328975132, 55.21634408405849, 52.099601064409526, 51.124532563345774, 50.811957427433555, 49.454779693058555, 48.871798038482666, 47.649001938956125, 48.31943709509713, 48.57375158582415, 46.37589045933315, 45.808677741459434, 47.73555217470442, 46.2916122845241, 49.457600661686485, 48.0006502696446, 47.27843713760376, 48.257341044289724, 53.37699958256313, 55.8690960747855, 60.449695995875764, 57.76516914367676, 61.885277203151155, 58.035627773829866, 71.02345766339982, 51.467926434108186, 37.797550678253174, 70.89838314056396, 60.41642107282366, 64.04807077135358, 52.546102728162495, 52.07266984667097, 52.52784286226545, 62.12709535871233, 59.10883263179234, 56.93863228389195, 50.7146235874721, 50.703044414520264, 49.534531116485596, 51.85574361256191, 57.47012083871024, 64.24874864305768, 65.53167792728969, 62.148398535592214, 62.80554526192801, 62.887012890407014, 60.76622813088553, 55.81223201751709, 57.93335723876953, 62.241407121930806, 66.0830522264753, 68.76256942749023, 67.88028717041016, 65.65276418413434, 60.62504073551723, 54.799448694501606, 56.37322609765189, 53.548137187957764, 52.93263448987688, 54.3917909349714, 60.892879894801546, 63.71584265572684, 67.89705317361015, 68.66771262032645, 71.76453168051583, 66.8331241607666, 83.39042431967599, 31.420344625200542, 0.20930955638842924, 0.4075210482946464, 1.6924986668995448, 1.9639673914228166, 0.7277425953320095, 1.289117306470871, 1.3342885226011276, 1.1865788315023695, 0.0757718901815159, 0.14866027794778347, 10.02744826248714, 33.76653242111206, 35.601086139678955, 37.828935691288535, 32.99551861626761, 30.036576134817942, 43.39324072429112, 66.33682823181152, 65.28726809365409, 67.82210295540946, 75.22206647055489, 58.23615625926426, 0.2976667173206806, 0.016280752274074724, 0.050721819179930856, 0.04247206489422491, 0.04513755061530641, 0.022710643409352218, 0.03473840095102787, 0.09338963803436075, 0.025478491227009466, 0.002157542251682441, 0.03342913370579481, 0.06293453688600234, 0.04458080923983029, 0.05144827912694641, 0.03757155267521739, 0.02550778697643961, 0.044028502090701034, 0.01841859898662993, 0.07691376283764839, 0.031247297567980628, 0.031167800405195782, 0.02793771756945976, 0.035177474176245074, 0.014692105020263364, 0.23616758733987808, 0.1368557499455554, 0.16406501776405744, 0.15554891473480634, 0.11751096083649568, 0.1534774966005768, 0.278409730643034, 0.16910223104059696, 0.18104447451020989, 0.16921227584992135, 0.16687282281262533, 0.2324263895196574, 0.15445800684392452, 0.1510165450828416, 0.29980787528412683, 0.18711027902151856, 0.13223819700734957, 0.18207406997680664, 0.2810242889182908, 0.7545007052166122, 26.074428422110422, 116.35537433624268, 98.46107401166643, 99.96720722743443, 72.00623866489956, 46.2191286768232, 119.39785848345075, 102.37012359074184, 77.07591533660889, 78.30837985447475, 56.384322370801655, 6.4768688423292975, 0.40917778653757914, 0.24836455285549164, 0.7111337408423424, 1.387477308511734, 1.54488625058106, 3.585616145815168, 4.51834145614079, 2.8574740290641785, 4.093357494899204, 6.7843939406531195, 92.38201863425118, 86.26263591221401, 75.90081514630998, 79.91513688223702, 76.5770902633667, 71.13783196040562, 70.07354858943394, 74.7663688659668, 77.49617018018449, 81.82573168618339, 76.72328730991909, 62.36920533861433, 53.057326861790244, 62.62182099478585, 70.33583613804409, 74.42767892565045, 68.53891386304582, 69.1801700592041, 71.0609918321882, 69.9120238167899, 63.83144678388323, 58.207970891680034, 54.87087965011597, 56.0168981552124, 53.07984249932425, 50.94606460843767, 51.924357073647634, 51.04179341452462, 51.47035135541643, 52.92300776072911, 48.96289587020874, 48.488469396318706, 50.71886198861258, 48.37469611849104, 51.69102961676461, 50.23917920248849, 50.15091970988682, 51.81385292325701, 56.13155732836042, 58.10114581244332, 64.86196190970284, 60.519303049360005, 66.10698182242257, 62.45370238167899, 72.9554876599993, 55.442910943712505, 42.56396280016218, 72.44717134748186, 63.980186871119905, 68.64352594103131, 54.634133679526194, 55.36151279721941, 54.35587222235543, 63.5865922655378, 60.57389504568917, 62.07580375671387, 51.200035163334434, 53.25969661985125, 52.97917004993984, 55.04451165880476, 60.9789194379534, 66.49537917545864, 67.88856247493199, 63.488838059561594, 65.96767044067383, 67.35992268153599, 64.08393737248012, 59.38334206172398, 60.634219305855886, 66.74853679112026, 68.81534794398716, 71.22456632341657, 70.95471913473946, 68.31991359165737, 63.86042077200753, 58.10720811571394, 59.406542096819194, 56.995159353528706, 55.02214888163975, 57.52539375850132, 64.67513179779053, 65.35321344648088, 71.12796551840646, 70.71849427904401, 74.22876589638847, 69.26507704598563, 88.20611654009137, 31.82076930999756, 1.320298216172627, 5.817484796047211, 5.716891382421766, 2.8771092040198187, 0.5097785826240266, 1.4733203479221888, 4.23893050636564, 2.0930555846009935, 0.270499125123024, 0.20782629240836414, 14.565268124852862, 44.99808699744088, 46.79687833786011, 64.94101156507219, 48.13391324451992, 30.99082088470459, 46.103347369602744, 68.60758985791887, 74.37021732330322, 76.13435104915074, 87.2807901927403, 61.935081890651155, 0.41241597277777536, 0.10149592626839876, 0.12212794380528585, 0.09629288581865174, 0.14607481525412627, 0.12389153774295535, 0.14452957388545784, 0.1731981262564659, 0.15499472804367542, 0.14902029505797795, 0.1062471777466791, 0.10103127905832869, 0.16909153732870305, 0.07629795159612383, 0.14796131902507373, 0.09868037234991789, 0.16912591191274778, 0.1581401178347213, 0.1617316308298281, 0.07922066655009985, 0.16466378420591354, 0.3082710254405226, 0.2958335056900978, 0.09860253081257854], [0.012446847910593663, 0.0299793836394591, 0.029158318947468485, 0.03480652586690017, 0.03117536607065371, 0.08567799933786903, 0.01798447228169867, 0.02179051938998912, 0.060523919095950465, 0.028908136300742626, 0.03321406524628401, 0.069602778713618, 0.07555329333990812, 0.04309420008212328, 0.08107291108795575, 0.06069710837411029, 0.10346631053835154, 0.03182340772556407, 0.1793155808533941, 0.07453863242907183, 45.153389658246724, 85.08526366097587, 86.73426573617118, 70.31155913216728, 64.45139285496303, 46.590711389269146, 72.6415958404541, 48.3528926713126, 53.5730117389134, 43.88633700779506, 12.76294275692531, 0.03790712895404015, 0.0691384504150067, 0.016195692820474505, 0.04885026014276913, 0.6739694007805416, 0.6543304803115981, 0.5225257586155618, 0.7436919137835503, 0.6604416381035532, 3.1430080788476125, 84.99108777727399, 74.96637971060616, 75.16656426021031, 74.09199060712541, 70.3799363545009, 66.71508816310337, 63.46859795706612, 60.386995451790945, 69.97844164712089, 71.86515549251011, 70.61161014011928, 67.74010726383754, 53.73405361175537, 47.13288974761963, 52.8435412134443, 58.69485895974295, 66.75183718545097, 64.35317311968122, 66.52655574253627, 64.17384011404855, 59.89702933175223, 54.233670779636924, 52.34685271126883, 48.16196659633091, 47.10799435206822, 47.627288818359375, 45.149196420397075, 45.15316384179251, 45.63136666161673, 45.013869830540244, 46.41822235924857, 45.3326427595956, 44.650204590388704, 46.560559681483674, 46.01710632869175, 46.08715459278652, 46.84878485543387, 45.4361709186009, 45.34270027705601, 45.08693013872419, 46.43293169566563, 48.0321603502546, 47.39716795512608, 50.875613348824636, 53.464692796979634, 61.486985615321565, 52.34479604448591, 31.93189879826137, 62.907628195626394, 60.187547411237446, 59.29250826154436, 51.57799979618618, 51.25277893883841, 49.95392438343593, 56.1895226751055, 53.358232498168945, 53.30291788918631, 45.76025921957833, 48.94607775551932, 46.119522775922505, 47.91723019736153, 48.37976482936314, 51.25255312238421, 56.29184879575457, 64.25353595188686, 58.012459005628315, 58.41533293042864, 53.48487731388637, 52.37436062949044, 50.19977249417986, 59.015754563467844, 62.0180572782244, 65.14225224086216, 61.627568517412456, 65.12965515681675, 58.15502561841692, 52.79654707227434, 48.33649492263794, 53.26299006598336, 48.891510077885215, 53.84440837587629, 51.32058640888759, 58.95515237535749, 55.99250997815813, 60.318812779017854, 60.68456595284598, 70.2563556943621, 58.69423362186977, 79.54529816763741, 15.42129053388323, 0.48852854860680445, 2.6616898604801724, 2.2566923924854825, 0.6763183804494994, 0.5202571717756135, 0.6969189207468713, 0.8538868693368775, 0.09339767867433173, 0.0407957882354302, 0.22370539605617523, 20.58899760246277, 29.3872252873012, 33.50724649429321, 31.64256191253662, 46.79843473434448, 34.14356599535261, 19.45101468903678, 36.04118503843035, 54.15015343257359, 61.5408411026001, 69.6726027897426, 8.877184408051626, 0.40292647055217196, 0.17362934883151734, 0.24710451332586153, 0.06491460385067122, 0.06691913878811256, 0.03959454037249088, 0.03962838230654597, 0.026225680418844734, 0.05010499692122851, 0.03364826659006732, 0.05345178269115942, 0.004563041979313961, 0.060337444102125506, 0.08730562842850174, 0.0912312249253903, 0.045574947859027555, 0.07229302078485489, 0.06719716851200376, 0.025663354700165134, 0.039520705584436655, 0.04895231859492404, 0.019248501597238437, 0.013146156278838004, 0.010863653533825917, 0.03886435526822295, 0.021819340164906213, 0.10724347071456057, 0.06566793378442526, 0.029613235965371132, 0.02563187406797494, 0.03155910815777523, 0.061608774454465935, 0.033919629707400284, 0.028292435321158597, 0.039640470407903194, 0.06445191760680505, 0.03384440392255783, 0.0627829385921359, 0.021234817869429077, 0.018840361087183868, 0.01125348377640226, 0.1529483071395329, 0.014828449846910579, 58.85842650277274, 94.93093054635185, 95.31180994851249, 78.66872732979911, 72.10882186889648, 46.431743553706575, 76.8785239628383, 41.23659283774239, 42.59797770636422, 51.69833564758301, 14.326640060969762, 0.06201340524213655, 0.09139668568968773, 0.14996382514280931, 0.42634420682276997, 0.9774327341999326, 1.0419141884360994, 2.213527577263968, 0.8395715717758451, 0.5212380077157701, 4.30522848027093, 92.23455006735665, 78.55864701952252, 76.78186062404087, 77.40859508514404, 73.39225142342704, 69.34258420126778, 67.15796634129116, 63.807725633893696, 74.0307422365461, 75.57928030831474, 73.60276794433594, 70.06891414097377, 57.614156995500835, 48.89346252168928, 54.77014119284493, 62.590859821864534, 67.86652973720005, 65.77095304216657, 69.4773097719465, 68.12995679037911, 61.835104261125835, 56.43682643345424, 54.5789406640189, 50.65340995788574, 49.91256175722395, 49.42528806413923, 47.89679207120623, 47.65287555967058, 49.07243422099522, 47.49949754987444, 46.682618686131065, 47.563017981392996, 46.502257347106934, 46.9354566846575, 48.04042175837925, 48.24328831263951, 49.00868102482387, 47.70297901970999, 47.252645424434114, 48.18370403562273, 48.20188052313668, 50.844853673662456, 50.61974940981184, 52.84228358949934, 57.27625567572457, 63.69169071742466, 56.68554415021624, 33.05369588306972, 67.02047538757324, 62.27248641422817, 61.461457933698384, 54.424221651894705, 53.53940677642822, 52.41502148764474, 58.862393924168174, 54.73167596544538, 54.98863771983555, 48.34647600991385, 51.15061957495553, 48.05221632548741, 49.73195028305054, 49.96139369692121, 54.94088969911848, 58.282240186418804, 66.14974798474992, 60.518469265529085, 60.33841364724295, 55.48889412198748, 54.1530647277832, 52.544619287763325, 60.44246292114258, 63.11065455845424, 67.34381675720215, 64.68228844233921, 67.6436106818063, 60.37548228672573, 54.90332078933716, 50.675279412950786, 55.91900845936367, 51.299818243299214, 57.05697052819388, 55.6289176940918, 61.04003579275948, 59.05569975716727, 62.80553831372942, 63.101781708853586, 73.85022108895438, 63.57202884129116, 83.41694559369768, 20.583824668611797, 0.21464143028216703, 0.7843918012721198, 0.8433349984032767, 2.4186027901513234, 1.4751187371356147, 1.6093261241912842, 2.589115926197597, 0.5585042365959713, 0.05954308994114399, 0.07197060130004372, 22.55243866784232, 31.623780931745255, 30.153674125671387, 20.191883734294347, 35.83455950873238, 37.127459457942415, 31.48277071544102, 42.89576012747628, 61.87487574986049, 68.35138893127441, 81.72961725507463, 14.158768108912877, 0.5139860425676618, 0.10792923891650778, 0.18467060636196816, 0.06194699701986142, 0.09212025507752385, 0.11424595889236246, 0.08603710721113852, 0.06164459431810038, 0.039739790971257856, 0.018989589597497667, 0.04116913516606603, 0.03739738630663071, 0.04925485700368881, 0.04999220065240349, 0.07879969663918018, 0.08270201259957892, 0.039744055563850064, 0.03447815902265055, 0.06521972747785704, 0.052784575814647336, 0.048122548298644166, 0.04446346339370523, 0.00726597265539957, 0.06816366022186619, 0.08813300688884088, 0.12945564703217574, 0.14531523601285048, 0.14432962318616255, 0.21266624198428222, 0.0980284291186503, 0.10425392684659787, 0.1727142629346677, 0.13668524766606943, 0.1736180851502078, 0.12234518357685634, 0.1723891632365329, 0.11540714944047586, 0.1592141573450395, 0.15427617302962712, 0.15241368939833982, 0.12664963331605705, 0.17812173920018332, 0.0787263877157654, 71.09255055018834, 105.87247426169259, 106.2786590031215, 89.38542733873639, 82.10256876264299, 61.910867418561665, 81.46526609148297, 58.880473136901855, 74.99745205470494, 61.885200772966655, 21.681311743600027, 0.1729012264737061, 0.11127050141138689, 0.4039563781448773, 0.8007716366222927, 2.1019781572478156, 1.8112928867340088, 2.8668860154492513, 3.360192481960569, 2.579107697520937, 4.087510585784912, 99.77621514456612, 80.22440814971924, 78.9704042162214, 78.5524422781808, 77.25826386043003, 72.99215330396379, 70.23497608729771, 66.06867640359062, 76.47066470554897, 78.36645984649658, 77.38874408176967, 73.70962429046631, 60.318889209202354, 52.72541488919939, 57.25207247052874, 66.16134452819824, 72.34053039550781, 67.73295756748745, 70.62149047851562, 71.79265104021344, 64.09059374673026, 60.93320723942348, 58.464706829616, 53.4358925138201, 53.13875280107771, 53.16371767861502, 50.371504170554026, 50.842797006879536, 51.38213355200631, 50.39039979662214, 51.097778524671284, 51.09852545601981, 49.51921728679112, 50.21257107598441, 50.76598814555577, 50.47206892286028, 51.730679512023926, 51.90258141926357, 50.48187630517142, 50.36021682194301, 49.98877307346889, 52.62139688219343, 53.32920639855521, 54.77597073146275, 60.906679017203196, 67.66699137006486, 59.75391033717564, 36.16184050696236, 68.57198728833879, 66.65096323830741, 64.22687571389335, 57.93616083690098, 55.60051345825195, 55.76844446999686, 62.300557136535645, 59.76645878383091, 57.93549380983625, 51.37832246507917, 54.064322335379465, 50.57232448032924, 51.83428062711443, 53.285797527858186, 57.88266665594918, 63.36536162240164, 70.2286045891898, 63.72939164297921, 62.94407149723598, 58.79116794041225, 57.117294788360596, 56.301013469696045, 63.116185324532644, 66.25278282165527, 68.86026109967912, 67.75376047406877, 71.53400434766496, 62.25894437517439, 56.20286669049944, 53.66886561257498, 58.66827515193394, 54.03394481113979, 59.805597986493794, 58.389381408691406, 65.94715241023472, 62.62108448573521, 66.56052548544747, 66.90193217141288, 76.74824523925781, 64.50485924312046, 87.9815924508231, 19.855279990604945, 1.1568455355507987, 9.096096958432879, 4.880151093006134, 4.671105853148869, 1.6436895259789057, 1.8867907098361423, 3.7431761026382446, 0.5375018407191549, 0.16180517045514925, 0.38767859446150915, 33.32436990737915, 43.428798130580354, 47.92088494982038, 42.69473484584263, 59.24416964394705, 43.3730388368879, 30.9177953175136, 50.35605485098702, 71.396242414202, 74.42157145908901, 91.73706599644252, 14.761550392423358, 0.707215065402644, 0.3685036562383175, 0.4196833813829081, 0.19090719813747065, 0.35410698875784874, 0.13921835459768772, 0.15353620345039026, 0.1338949759623834, 0.15141332522034645, 0.09673346539161035, 0.09803215427590267, 0.21185294991093023, 0.12758317536541394, 0.18747165320175035, 0.11298896598496608, 0.11807987173753125, 0.2230772219066109, 0.07577169340636049, 0.1782379179660763, 0.11565279268792697, 0.18480060010084084, 0.14150098711252213, 0.06416755036583968], [0.017458073295918957, 0.039559860447687764, 0.05018684520785298, 0.0432550400229437, 0.05210903313543115, 0.0678870350654636, 0.03901795184771929, 0.045828061777033975, 0.013388698621253883, 0.012325267157783466, 0.04872651231874313, 0.022557640547997186, 0.08465478888579778, 0.04367231870336192, 0.05312146166605609, 0.06115315854549408, 0.040054244454950094, 0.036864994160298786, 0.12225461272256714, 1.7553302496671677, 73.84339100973946, 77.38891778673444, 74.35715470995221, 73.06080845424107, 47.477343218667166, 33.75565849031721, 16.50471271787371, 57.05492775780814, 62.67711475917271, 29.791075434003556, 4.295236102172306, 0.09548392279871873, 0.11071828925716025, 0.21879593735294683, 0.13345683233014174, 0.9681566719497953, 0.2762133670704705, 2.347332511629377, 0.3579619904713971, 0.3166098136987005, 70.63530349731445, 77.98225920540946, 73.94260433741978, 73.37407493591309, 68.22646032060895, 65.6976009096418, 64.08632755279541, 61.10072830745152, 59.87239101954869, 65.33408505575997, 70.7510187966483, 69.64995861053467, 66.08100945608956, 49.97864607402256, 49.03876325062343, 50.02987861633301, 57.88083233152117, 64.46433734893799, 66.70449216025216, 64.7169669015067, 63.106846945626394, 57.785721915108816, 53.308778694697786, 51.391676902770996, 48.44345896584647, 44.919082505362375, 45.916142054966514, 44.22652081080845, 44.557018824986045, 42.910122053963796, 45.23268250056675, 46.28882605688912, 44.33541645322527, 43.62873601913452, 45.878184046064106, 46.1036114011492, 51.63200466973441, 48.920650822775706, 48.85168647766113, 45.095851625714985, 47.977398123059956, 46.62143284933907, 46.08974279676165, 45.07326998029436, 47.59279448645455, 49.68331289291382, 65.0553719656808, 52.597502027239116, 38.96665457316807, 63.941436767578125, 54.714447907039094, 55.603153773716514, 48.28374419893537, 50.24857316698347, 49.77926056725638, 51.43080220903669, 52.449526241847444, 49.97517197472708, 44.6799533026559, 49.217797483716694, 46.455377851213726, 48.1974058832441, 44.71152939115252, 44.83401223591396, 47.315957409994944, 50.61430549621582, 52.74517209189278, 52.43972928183419, 50.02132190976824, 49.748438358306885, 48.71536629540579, 54.56448146275112, 59.92654527936663, 61.60518142155239, 61.23218127659389, 62.89922782352993, 60.593871116638184, 54.02519008091518, 48.0326258795602, 50.13073519298008, 47.988588196890696, 49.076290471213206, 51.92182445526123, 51.16271986280169, 51.25765657424927, 53.79542357581002, 56.28450454984392, 60.057560511997764, 69.44459765298026, 62.26647622244698, 65.0675243650164, 5.013388446399143, 1.5415906331368854, 2.0770375984055653, 1.4703049382993152, 0.5705101266503334, 0.4679028753723417, 0.31068004188793047, 0.2770066559314728, 0.06925129078860794, 0.07226867494838578, 1.2466820521014077, 25.899332080568584, 36.85135194233486, 69.70021493094308, 136.4480985913958, 106.37130628313336, 22.950513124465942, 39.062459809439524, 49.27055515561785, 55.244591985430034, 65.70854432242257, 38.54812983104161, 0.28576146758028437, 0.08413167231317077, 0.021959204891962663, 0.003802344427510564, 0.01719820456180189, 0.10052336167011942, 0.08778211607464723, 0.02289823968229549, 0.027241845981084874, 0.04367998614907265, 0.0509653318274234, 0.028902304292257344, 0.006193798692298255, 0.06343131951455559, 0.04945053293236664, 0.024229700111650994, 0.024506111529522707, 0.029154973769826547, 0.06170063452529056, 0.11179074778088502, 0.0461665693271373, 0.05160346008571131, 0.12110582579459463, 0.03187181780646954, 0.011561805848032236, 0.039492271574480195, 0.02224445083577718, 0.02813166662651513, 0.020562028346051062, 0.026890539564192295, 0.04404264615316476, 0.011149627206447934, 0.048670964049441476, 0.09267537814698049, 0.06932723921324525, 0.04605153050007565, 0.026497535474066223, 0.0666897939518094, 0.03523697830470545, 0.010380435668464218, 0.13322800318045275, 0.1439774770821844, 2.5809941334383826, 86.89412294115338, 84.30383450644356, 84.11234215327671, 80.27913911002022, 63.72337450299944, 40.963080474308555, 28.479312862668717, 57.75395475115095, 53.30765308652605, 36.14289971760341, 5.104271752493722, 0.06903584234948669, 0.038975563765104325, 0.33284094131418634, 0.8190201031310218, 1.007155499288014, 1.470761348094259, 1.9725937971046992, 0.37013564152376993, 0.48732792160340715, 74.81961291176933, 79.7332330431257, 77.1802008492606, 75.84670952388218, 69.56327288491386, 69.2025363104684, 67.63890675136021, 63.553803716387065, 63.149397713797434, 70.69940062931606, 72.47733347756522, 71.26252433231899, 66.11636883871896, 49.92024646486555, 50.79304095676967, 52.2402013369969, 60.425703866141184, 67.3988117490496, 69.38590621948242, 65.76576968601772, 65.93517371586391, 62.04587091718401, 56.80642543520246, 55.075156688690186, 50.38902752740042, 48.640489033290315, 48.219157218933105, 47.769817216055735, 47.100858552115305, 45.6702800478254, 47.152358600071494, 46.98401417051043, 46.628374099731445, 46.691401209150044, 47.890590803963796, 47.27003329140799, 54.380625179835725, 51.516178199223106, 52.19261659894671, 48.695268630981445, 48.78542150769915, 48.57644053867885, 48.06015811647688, 47.88895797729492, 49.88556800569807, 52.03465972627912, 67.85941478184291, 55.51604768208095, 41.52892092296055, 66.55523095812116, 57.63073192323957, 56.88761166163853, 52.176323073250906, 52.043588161468506, 52.26307828085763, 55.45934343338013, 54.36716999326433, 52.73460735593523, 46.37352112361363, 51.80016497203282, 49.15169579642159, 49.18548141207014, 46.782307965414866, 47.301421778542654, 50.65050908497402, 52.31646129063198, 55.6221536227635, 53.76462915965489, 53.37677376610892, 50.36464629854475, 50.95923491886684, 55.733668736049104, 63.70851925441197, 62.58687155587332, 63.2481107711792, 65.61240904671806, 62.79329558781215, 57.04868827547346, 50.51192726407732, 53.02465295791626, 50.88337101255144, 50.17286559513637, 55.85140596117292, 53.37228522981916, 54.48599113736834, 56.53632116317749, 60.16120679037911, 62.55628558567592, 71.65140805925641, 66.71135003226144, 69.33617796216691, 7.327816895076206, 0.8924512714147568, 0.4128032262836184, 1.1795462774378913, 1.6214805862733295, 1.0345464923552103, 1.2097107959645135, 1.3757650341306413, 0.37104770115443636, 0.08107774225728852, 0.9119742981025151, 28.163522447858536, 36.48218372889927, 55.519170897347585, 109.12572506495884, 103.14133889334542, 28.518398216792516, 41.43641260692051, 57.0886994770595, 61.41910171508789, 74.11424568721226, 51.57565130506243, 0.4186167243335928, 0.07434720412961074, 0.054093137383461, 0.014966139869232262, 0.04738280263596347, 0.04790321185386606, 0.04453903862408229, 0.05881119492862906, 0.0567326148572777, 0.02202336716332606, 0.044107805871005566, 0.0383928175350385, 0.031139949935355356, 0.020988197531551123, 0.02949898423893111, 0.08412539586424828, 0.026966586376407316, 0.024146854378549115, 0.054777304242764197, 0.10165919536458594, 0.06108707602002791, 0.04712946140872581, 0.018730104235666137, 0.11047421342560224, 0.12129348143935204, 0.08067596810204641, 0.16351328736969403, 0.117037777655891, 0.09221920583929334, 0.12206352369061538, 0.1347479216222252, 0.1325660515576601, 0.16869954764842987, 0.18102026438074453, 0.2856880229498659, 0.12752347785447324, 0.07578149823737995, 0.16302221800599778, 0.22127469362957136, 0.11291149085653679, 0.25820084075842586, 0.36513128291283337, 3.8017064247812544, 98.78834806169782, 97.0441209248134, 94.69990989140102, 90.50467096056256, 66.06595270974296, 47.57985346657889, 24.971308095114573, 76.748870577131, 82.65951551709855, 47.57768562861851, 7.616758602006095, 0.19196200796536037, 0.5256806750382695, 0.6575419051306588, 1.9569468881402696, 2.16730403474399, 3.954683610371181, 6.503950749124799, 3.5201044040066853, 0.5961072359766278, 80.1400431224278, 82.67726121629987, 80.91883890969413, 80.0025452205113, 73.49141611371721, 71.7592579977853, 69.19943741389683, 67.28379126957485, 66.34037181309291, 72.46368026733398, 75.34298597063336, 73.17050661359514, 70.98732008252824, 53.52662556512015, 54.17759186880929, 55.060766969408306, 61.51091521126883, 70.86909648350307, 71.14370318821499, 68.62200042179653, 68.97559424809047, 63.36446530478341, 57.75069604601179, 58.52234213692801, 53.4967656816755, 49.996843406132285, 50.33123241152082, 49.42539228711809, 51.216485023498535, 47.571317604609895, 50.05946752003261, 50.628990513937815, 48.92460782187325, 47.9668299130031, 50.4229416847229, 49.66677965436663, 57.51347412381853, 53.50328656605312, 55.01967532294137, 51.64861781256539, 52.74098232814244, 51.32828848702567, 51.24847105571202, 51.51331901550293, 53.41628817149571, 55.30880028860909, 71.15466049739292, 60.25510474613735, 46.295836789267405, 70.0087913785662, 61.719347272600444, 60.80103165762765, 53.90999937057495, 56.01280219214303, 54.566871643066406, 57.2986809866769, 57.904768875667024, 55.363746643066406, 47.8355575970241, 54.1924193246024, 52.2871607371739, 52.836071899959016, 49.92508588518415, 49.580413545881, 53.082642623356406, 55.52187722069876, 59.5618690763201, 57.0938480922154, 55.367047037397114, 54.15995386668614, 55.56351777485439, 60.3384553364345, 66.69885717119489, 64.86139215741838, 66.78932271684918, 69.29047271183559, 64.8724536895752, 61.37602983202253, 53.347796303885325, 57.08027131216866, 52.83268117904663, 53.48142753328596, 57.65140976224627, 56.573619093213765, 56.74636173248291, 59.896598543439595, 62.33891119275774, 65.39212335859025, 74.73558139801025, 70.40886170523507, 71.17084285191127, 7.721801468304225, 3.6291453072002957, 8.560475962502615, 5.149248310497828, 4.338085208620344, 1.4154207919325148, 2.5634158423968723, 2.2395498837743486, 0.6040939731257302, 0.1492902705711978, 2.4810990137713294, 42.59519842692784, 54.45632232938494, 87.84963921138218, 141.06821986607142, 114.13830838884626, 31.636350222996303, 53.1879425730024, 64.83958871023995, 71.61597224644252, 81.12595081329346, 55.98344952719552, 0.4125575151826654, 0.15149223884301527, 0.15600670874118805, 0.1046263204355325, 0.11598222143948078, 0.1362440777676446, 0.2268745888556753, 0.15332610186721596, 0.13093604759446212, 0.14284812339714595, 0.24529724887439183, 0.17058170879525797, 0.1350454863693033, 0.2129711891923632, 0.11020149663090706, 0.144710742735437, 0.09154032476778541, 0.10872365414564099, 0.1842164085911853, 0.18471946088331087, 0.14701135642826557, 0.13458377043051378, 0.24229866691998073], [0.04194155568256974, 0.05312560072966984, 0.053055514847593646, 0.03131171428997602, 0.06497780938765832, 0.05215546189408217, 0.057328025943466594, 0.07833701039531402, 0.04856929236224719, 0.08530633178140436, 0.013901585430305983, 0.009510691177898219, 0.02383634996866541, 0.038517525486115894, 0.003104063615735088, 0.044129298467721255, 0.07402539532631636, 0.12935191259852477, 0.3005897104740143, 14.062913366726466, 84.17531367710659, 69.30604362487793, 76.77275153568813, 51.75796856198992, 29.730369022914342, 13.521728600774493, 34.67474882943289, 25.592987741742814, 43.052372523716514, 20.98131373950413, 0.06302696014089243, 0.04318121202023966, 0.031584088424486775, 0.19770052789577416, 0.3727961501904896, 0.3697219251521996, 1.0408109447785785, 1.1136552074125834, 0.7559454419783184, 39.85621854237148, 89.14168453216553, 71.44085679735456, 77.55211707523891, 60.61139447348458, 66.59636429377964, 61.96629319872175, 63.04284014020647, 57.60942874635969, 57.72284419195992, 62.03551115308489, 66.9945377622332, 62.966979707990376, 55.2131027494158, 46.716595377240864, 48.59917504446847, 48.27239431653704, 57.89338077817644, 63.45513234819685, 65.69562762124198, 61.87858608790806, 63.27903025490897, 57.22633286884853, 58.63997513907296, 49.910004820142476, 49.13905702318464, 44.22820574896676, 44.996558393750874, 43.64192022596087, 44.094577993665425, 43.30690935679844, 45.6506062235151, 44.07582480566842, 44.008969238826204, 43.300968647003174, 45.4270270892552, 50.316596031188965, 56.08185338973999, 54.06672988619123, 51.63899455751692, 47.00827380589077, 48.50582947049822, 44.759874956948416, 48.74685900551932, 44.62443719591413, 46.549386978149414, 47.78992182867867, 64.02457891191754, 50.894529819488525, 40.64917475836617, 62.98293972015381, 52.669429779052734, 52.35012878690447, 45.13348306928362, 47.75997509275164, 47.83730506896973, 49.69817508969988, 49.17600059509277, 46.17458724975586, 46.83326605388096, 45.753026144845144, 46.90122985839844, 44.464760644095286, 44.444770676749094, 44.703785623822895, 44.63774994441441, 45.257570947919575, 45.41612536566598, 46.39579357419695, 47.18888528006417, 48.27394723892212, 46.54976565497262, 49.44629941667829, 57.99728413990566, 58.554727690560476, 60.27659552437918, 61.28912871224539, 60.77799143110003, 53.112311431339805, 46.94570875167847, 46.87298890522548, 49.14936120169503, 49.1320150239127, 48.601318563733784, 50.522186279296875, 56.712579590933665, 59.58126844678606, 63.39599622998919, 60.842887605939595, 64.01311438424247, 67.91154016767229, 60.57723018101284, 45.40049886703491, 0.6132700464555195, 1.4289759674242564, 1.5718968297754015, 1.7546320642743791, 1.155313457761492, 0.7318148910999298, 0.9703401433570045, 0.05327284961406674, 0.2056416403502226, 0.04034477618655988, 6.78145181281226, 26.456322261265345, 43.20552819115775, 66.98210048675537, 62.212551253182546, 37.9040561403547, 28.0426515851702, 40.484165464128765, 54.468985421316965, 54.807060446058, 67.13805280412946, 8.148140328271047, 0.23859964683651924, 0.11150984785386495, 0.0812182736450008, 0.034351649561098645, 0.03948339633643627, 0.017282967156331455, 0.03221889864653349, 0.05089878789814455, 0.076178685495896, 0.02654639508442155, 0.058399032402251444, 0.04624068570722427, 0.004000988522810596, 0.05159970100170799, 0.048142134211957455, 0.06102268983210836, 0.051880672174905024, 0.007544194065433527, 0.04856809474793928, 0.05835390303816114, 0.020694459721978222, 0.031616529183728356, 0.030272802537573234, 0.04664890594514353, 0.09536714692200933, 0.06721258482762746, 0.039719675800630024, 0.0030164072813931853, 0.036742050400269885, 0.07184501125344209, 0.020442112548542873, 0.04114361885668976, 0.030974180437624454, 0.009970755732086087, 0.014789535863591092, 0.05487201076799205, 0.018372719841344014, 0.16147131765527384, 0.06346390276615109, 0.26861179353935377, 0.3964705355465412, 19.43706270626613, 98.57656696864537, 75.8724387032645, 86.49247537340436, 59.487829072134836, 38.00408240727016, 18.57165241241455, 35.53567927224295, 31.365012645721436, 47.35993603297642, 22.770566940307617, 0.03675910537796361, 0.09821742147739444, 0.24095223631177629, 0.24341246858239174, 0.40769247338175774, 1.6541074812412262, 2.2521617327417647, 0.3223119234400136, 0.2814331741205284, 44.28562913622175, 93.4140693119594, 75.29600919995988, 79.40329088483537, 64.6510146004813, 69.33155741010393, 65.62795216696603, 67.47702067238944, 59.50356674194336, 60.69824695587158, 65.61110278538295, 69.91076619284493, 67.84100900377545, 58.189047472817556, 48.86696209226336, 52.2727883883885, 51.06730372565133, 60.65240968976702, 67.37675816672188, 67.81776727948869, 64.62858581542969, 65.43964208875383, 60.29466084071568, 61.13439232962472, 52.89731332233974, 50.34896421432495, 47.415969780513215, 48.66211182730538, 45.277567863464355, 46.211569036756245, 45.83137403215681, 47.819990158081055, 46.33292279924665, 45.98335197993687, 45.35715600422451, 48.5724001611982, 53.0027939251491, 59.461391176496235, 55.86831440244402, 54.200632095336914, 49.45794807161604, 50.56027977807181, 47.852591105869834, 49.443273476191926, 47.2972354888916, 50.56856550489153, 52.12908574513027, 66.51528576442173, 53.14718444006783, 44.53521885190691, 64.10287816183907, 55.64248405184065, 52.40878547940935, 47.298798833574565, 49.192575522831504, 51.10666874476841, 53.26256275177002, 51.86132301603045, 47.654883589063374, 48.589492729731965, 47.692716530391145, 48.9275712285723, 47.5347318649292, 46.539808886391775, 47.61002949305943, 45.361818245479036, 46.06692838668823, 47.76927873066494, 48.612560749053955, 49.493036474500386, 48.491776738848, 48.121270997183665, 52.08441230228969, 61.37834358215332, 60.99638026101248, 63.474663734436035, 63.42404610770089, 64.23468548910958, 55.66233852931431, 49.25341394969395, 49.13657651628767, 51.91876377378191, 51.40254388536726, 51.61351203918457, 53.95909881591797, 59.99033669063023, 63.30191762106759, 67.21795013972691, 64.37318393162319, 67.75235693795341, 70.02163859776088, 66.54230730874198, 53.195491790771484, 1.9835111541407449, 1.1266647321837289, 0.4385761304625443, 1.0515348379101073, 2.5946212879249027, 1.9902537294796534, 1.897025840623038, 0.70322413955416, 0.2797862882060664, 0.0614439718691366, 6.83677293573107, 31.492175102233887, 40.42093685695103, 72.41418130057198, 73.45956557137626, 33.148340770176475, 38.34246662684849, 45.7800407409668, 62.431801659720286, 61.14174352373396, 79.86427606855119, 15.008607489722115, 0.3285698890686035, 0.15365357643791608, 0.20805692646120275, 0.03708237303154809, 0.008433432867085295, 0.02355703102823879, 0.02510286441871098, 0.04264974607420819, 0.034825887863657305, 0.007192283752374351, 0.012425035554250436, 0.024658839584195187, 0.02272010388384972, 0.008313179498405328, 0.01248034548812679, 0.07375725185764687, 0.0572247529136283, 0.05467895059181111, 0.022045718106840338, 0.03095200252053993, 0.04484921733715704, 0.05408019093530519, 0.09318655928862946, 0.08197931173656668, 0.2050428060548646, 0.180536061791437, 0.1610682135713952, 0.10004264675080776, 0.16436805150338582, 0.17203950057072298, 0.10909085694168295, 0.1386819998068469, 0.10442241387707846, 0.07282859526042428, 0.07154472558093922, 0.18551763519644737, 0.08314808830618858, 0.20884078368544579, 0.10954748386783258, 0.5077437375273023, 0.588848485478333, 24.082774196352275, 112.67164094107491, 85.08588899884904, 97.29158796582902, 67.47747230529785, 43.56386763708932, 20.017206021717616, 49.22679540089199, 37.238929407937185, 61.703776359558105, 31.80518797465733, 0.17680202930101327, 0.16194428370467254, 0.22881867310830525, 1.4415012896060944, 0.4624655299953052, 3.2922100041593825, 4.97996153150286, 7.241671391895839, 1.7379776665142603, 46.99100405829293, 94.53618253980363, 79.43996347699846, 83.91981451851981, 67.36124978746686, 72.51564584459577, 68.28991821834019, 69.56795597076416, 63.30557237352644, 62.812305859157014, 68.9622745513916, 73.46872329711914, 71.08459486280168, 61.24054690769741, 52.23503187724522, 54.88905266353062, 54.00973033905029, 64.10535866873605, 70.67843096596854, 70.06054156167167, 66.41717720031738, 67.83625643593925, 62.25521319253104, 65.6911529813494, 56.76395109721592, 53.963160037994385, 50.09695305143084, 50.14067459106445, 47.445836612156455, 48.62585960115705, 48.27298491341727, 50.12385300227574, 48.97694512775966, 48.11416646412441, 47.95647709710257, 51.05241026197161, 55.28092411586216, 62.346846035548616, 57.869412967136924, 56.66973352432251, 52.251266343253, 55.72643218721662, 49.583081654139924, 54.505282810756135, 51.12684631347656, 52.62309224264962, 54.92440857206072, 70.14568478720528, 57.573246002197266, 48.526997157505576, 67.80727549961635, 59.289131437029155, 56.505839415958945, 51.375254835401265, 52.73209210804531, 53.55989006587437, 55.71759407860892, 55.25608777999878, 50.88192926134382, 54.071798597063335, 50.107163429260254, 50.338316099984304, 48.79367249352591, 47.638249601636616, 50.20792620522635, 48.88998147419521, 50.101924487522666, 48.73094415664673, 50.67464017868042, 51.670070375714985, 52.96424184526716, 51.24146727153233, 54.05811759403774, 67.28303391592843, 62.809269496372764, 64.5939143044608, 66.82051318032401, 67.42827211107526, 57.39212383542742, 51.13168225969587, 51.674802098955425, 55.07618154798235, 55.2632965360369, 53.84637124197823, 56.18877921785627, 62.88918072836739, 65.60171576908657, 70.14562920161656, 67.82637609754289, 70.28070218222481, 74.3287991115025, 69.4594806943621, 56.38196693147932, 1.6574914710862296, 3.522606624024255, 8.478389944349017, 6.7665800622531345, 4.741206228733063, 2.8484337713037218, 4.389226121561868, 1.4408337197133472, 0.6526770261781556, 0.1899700734232153, 11.664980598858424, 42.848689556121826, 57.658062662397114, 71.1606776373727, 68.08691270010812, 51.657292638506206, 41.845022269657676, 52.757369654519216, 73.44020789010185, 70.08404731750488, 89.89256940569196, 14.550310390336172, 0.5329969653061458, 0.2665208743086883, 0.4521323916103159, 0.1500879834805216, 0.15412084279315813, 0.16211927788598196, 0.11882569028862885, 0.11317439603486232, 0.10657707468739577, 0.10198369116655417, 0.09478759659188134, 0.14643286461276667, 0.11759955036853041, 0.11930928219641958, 0.08900269879294292, 0.1595988052764109, 0.11223334938819919, 0.1297973029847656, 0.09238553512841463, 0.17322374773877008, 0.12353396335882799, 0.21218703341271195], [0.037806566671601365, 0.03288645496858018, 0.07525810346539531, 0.03437719640455075, 0.02762654310624514, 0.006604516787254917, 0.06535287640456643, 0.0811596346486892, 0.041743745761258264, 0.025668509869969318, 0.04237496992573142, 0.011915033367196364, 0.021069977964673723, 0.03668855469939964, 0.02309320484554129, 0.012376056352098073, 0.03047098565314497, 0.06717433580862624, 0.08044019075376646, 49.37338849476406, 82.38404028756278, 72.77203437260219, 66.9348110471453, 43.27925552640642, 29.919446877070836, 26.713554995400564, 51.18686832700457, 50.46536391122, 39.60495778492519, 3.0356794723442624, 0.052790183906576464, 0.11067784857004881, 0.2197544223495892, 0.12287608294614724, 0.37380195621933254, 1.799674738730703, 0.5944654526455062, 2.0221572518348694, 12.157452413014003, 88.26561396462577, 72.61203125544957, 76.8441720690046, 61.34014238630022, 64.72659710475376, 58.400588853018625, 64.05941717965263, 58.97941548483712, 55.12130314963204, 49.778013365609304, 54.638653482709614, 55.673771790095735, 50.91538136345999, 48.17766605104719, 49.01999964032854, 48.03204223087856, 49.25835064479283, 55.37013898577009, 62.796818324497764, 63.00571591513497, 63.246040207999094, 63.002540588378906, 61.41335555485317, 58.07348155975342, 51.8555907521929, 48.52671228136335, 46.50086075919015, 45.5374687058585, 43.67516735621861, 44.14608151572091, 45.18133183888027, 45.72795704432896, 43.222822257450645, 44.498108523232595, 43.624587944575715, 48.91143751144409, 57.336236000061035, 60.02823216574532, 58.982354572841096, 52.447942052568706, 47.46243238449097, 47.65481758117676, 45.49921539851597, 44.698518889290945, 44.08303356170654, 44.87074736186436, 49.73365953990391, 64.34090954916817, 50.621288435799734, 37.4767975125994, 62.90448760986328, 50.576312746320454, 50.43463550295149, 44.79799624851772, 46.08070319039481, 44.552738734654014, 47.44982140404837, 44.227535247802734, 44.22599969591413, 44.70499808447701, 47.37053203582764, 45.30242504392351, 45.9359062058585, 44.44671617235456, 43.887212480817524, 44.946496622903005, 43.24644960675921, 44.06539208548409, 45.68131031308855, 44.3520712852478, 45.48778561183384, 44.71035861968994, 49.0752968788147, 57.037546839032856, 60.569330079214915, 61.827627999441965, 62.0833078111921, 60.70997551509312, 57.105434213365825, 47.559252057756694, 46.43632589067732, 46.499891485486714, 47.3487355368478, 49.68208653586251, 55.444178989955354, 62.53849819728306, 64.5166711807251, 64.13110869271415, 64.58054597037179, 70.7397210257394, 59.170338085719514, 62.21553203037807, 72.12398978642055, 38.34800781522478, 2.5931202598980496, 1.1778432088238853, 1.0681731679609843, 1.930038686309542, 0.7876891557659421, 0.5971906121288026, 0.3519081010350159, 0.21439988538622856, 0.023218503122084906, 0.41765893144266947, 21.409750086920603, 28.735353980745586, 24.873870032174246, 27.09431106703622, 44.48091867991856, 20.71293088368007, 33.760327679770334, 48.17000218800136, 51.99216454369681, 59.19286414555141, 44.93861736570086, 0.28020038455724716, 0.0845063729211688, 0.04454728960990906, 0.07508775724896363, 0.03747539069237454, 0.017296110379642675, 0.053015718768749914, 0.05435235133128507, 0.055707219522446394, 0.03401371876576117, 0.014834543091378041, 0.04408815549686551, 0.03319894748606852, 0.03632514491411192, 0.020579939974205833, 0.04663184078942452, 0.07864978111216, 0.0253078583295324, 0.048364418891391585, 0.027491426427981684, 0.023388630510973077, 0.0073399567211579, 0.0176489502856774, 0.009777017020886498, 0.015750136193154112, 0.05501487631616848, 0.025837588922253678, 0.07434793694743089, 0.02225269333991621, 0.06634828727692366, 0.05394342202427132, 0.013488116724017476, 0.031721939598875384, 0.055191247923565764, 0.03778016148135066, 0.0927061972075275, 0.045308755178536685, 0.03669232735410333, 0.08170980441250972, 0.025627811339550784, 0.07513114956340619, 59.50931290217808, 91.23494747706822, 78.42937578473772, 74.3439531326294, 53.2894036429269, 39.491660458701, 33.15406608581543, 53.778303214481895, 41.973494461604524, 42.48971782411848, 3.421100825071335, 0.027406165110213414, 0.27118672536952154, 0.24902118476373808, 0.5501067414879799, 1.1444533147982188, 1.9973719418048859, 1.1684276397739137, 1.25070093359266, 14.007845418793814, 93.23354121616909, 74.02907466888428, 79.04081726074219, 64.24149472372872, 68.19802134377616, 61.09160532270159, 67.31890746525356, 61.39676325661795, 60.21840436117989, 53.044629028865266, 57.74718025752476, 57.9047897202628, 54.59094715118408, 49.563661439078196, 50.975702149527415, 50.197872161865234, 51.90687888009207, 59.13798727308001, 64.80978788648332, 64.212374823434, 65.79655715397426, 64.44616780962262, 63.04778725760323, 60.77259268079485, 55.31628349849156, 50.089292662484304, 48.43953323364258, 45.94463314328875, 47.58259800502232, 45.392508438655305, 48.08023493630545, 48.09897770200457, 45.96952159064156, 46.289687633514404, 45.60587024688721, 50.3964968408857, 61.125172070094514, 61.115764209202354, 62.6014975139073, 54.241570881434846, 50.9271377154759, 49.17415237426758, 47.23872818265642, 47.63836424691336, 46.63117074966431, 47.54097134726388, 52.11406373977661, 67.2294841493879, 54.35772739137922, 42.94768748964582, 67.04147284371513, 53.95844568525042, 51.45461368560791, 47.15944923673357, 49.66301373073033, 46.97814294270107, 50.20031792776925, 46.47597231183733, 45.29883977345058, 45.673920903887065, 50.64480461393084, 46.95081915174212, 46.865880898066926, 45.30253274100167, 47.27518885476248, 47.845483098711284, 46.212357657296316, 45.26520701817104, 47.846813678741455, 47.31473452704293, 47.74043328421456, 46.267519405909944, 49.720784527914866, 61.61051763807024, 62.33481870378767, 65.47922597612653, 64.40623651232038, 61.722460065569194, 59.90254620143345, 49.9514925139291, 49.381618635995046, 49.35195330211094, 49.36913619722639, 52.08744171687535, 58.35061740875244, 65.65198598589215, 67.58116722106934, 69.06837354387555, 66.15279129573277, 71.39000988006592, 63.03840718950544, 63.77856404440743, 74.18677793230329, 44.578217778887065, 4.7576773677553446, 0.4240212286157267, 0.6047805962818009, 0.15326481658433164, 1.2316515786307198, 2.948102423122951, 1.3989821140255247, 0.6302677286522729, 0.025538227753713727, 0.18396887901638234, 25.739018031529017, 34.33145918164934, 27.717663492475236, 32.34267977305821, 50.877173219408306, 28.570108447756084, 39.34891319274902, 54.134123938424246, 59.63321317945208, 65.2897972379412, 59.03290271759033, 0.26126779190131594, 0.02847383656938161, 0.06321724171617202, 0.08452292239027363, 0.0387113083020917, 0.029699552405093397, 0.018271913286298513, 0.04041174080755029, 0.09052554172064577, 0.01878945908642241, 0.039655493173216066, 0.05794937403074332, 0.06382542622408696, 0.04994665738195181, 0.0761023774476988, 0.02547751922559525, 0.02273985943091767, 0.04490640766120382, 0.014415912429935165, 0.05352429433592728, 0.043934708195073266, 0.07636169996112585, 0.19811414927244186, 0.07116297499409743, 0.11332131243710007, 0.12805287087602274, 0.086290587538055, 0.14969332037227495, 0.13586400316229888, 0.10740652267954179, 0.17000223988933222, 0.09046325220593385, 0.12182469293475151, 0.12535842188767024, 0.1145935452410153, 0.17719958296843938, 0.11603091311241899, 0.20671414637139865, 0.12139633377747876, 0.22525203520698206, 0.2341293767094612, 67.94034739903041, 102.6210994720459, 88.81233297075543, 84.92558710915702, 58.885197911943706, 44.6555095400129, 38.24214506149292, 70.29053388323102, 71.50948415483747, 62.30662291390555, 5.0194568293435236, 0.10063583563481059, 0.38359468217406956, 1.3182661937815803, 0.678461411169597, 2.4193642692906514, 4.502083105700357, 4.816299319267273, 4.284785142966679, 15.254195043018886, 95.38034003121513, 77.19866916111538, 82.26736613682338, 65.56846169063023, 70.13516521453857, 63.18123435974121, 70.82064669472831, 64.30969824109758, 63.404313223702566, 56.290473052433555, 60.60612773895264, 58.75809451511928, 56.66395262309483, 53.07425962175642, 53.84219537462507, 52.91330112729754, 55.445068359375, 62.745971407209126, 68.45255470275879, 65.8616965157645, 66.71938909803117, 65.44360256195068, 67.19506277356828, 62.797763279506135, 57.03479535239083, 52.91478456769671, 52.04475198473249, 49.08484370367867, 49.53786972590855, 48.547185148511616, 49.811587061200825, 50.14310646057129, 48.08984429495675, 49.23067944390433, 47.91536113194057, 52.887342657361714, 64.22684097290039, 63.35462665557861, 64.84805161612374, 57.54542194093977, 52.99211801801409, 53.160702160426546, 51.699120794023784, 50.28502689089094, 49.630965164729524, 49.74964387076241, 56.20403746196202, 68.8527500970023, 57.130260126931326, 44.40631239754813, 67.21492767333984, 55.60130902699062, 54.97091633932931, 48.99455533708845, 51.83795275006975, 50.06911161967686, 52.337219033922466, 49.92460993358067, 47.118427072252544, 48.08164542061942, 53.06300354003906, 49.77076292037964, 50.26609304973057, 47.08560378210885, 49.351011821201865, 50.447642530713765, 47.7159652028765, 49.50445931298392, 50.52320071629116, 48.33593906675066, 50.86836985179356, 48.94625146048409, 53.287322657448904, 65.65714849744523, 67.47278921944755, 67.38114248003278, 66.25080258505685, 65.55132048470634, 61.38061564309256, 53.66983488627842, 52.743535791124614, 51.63460329600743, 52.199596064431326, 53.90981176921299, 60.90251704624721, 67.21681758335659, 70.4536497933524, 72.19247123173305, 69.69032764434814, 75.45644310542515, 65.98278277260917, 65.08887617928642, 70.22632558005196, 46.87477806636265, 3.9318036266735623, 3.162311694451741, 5.175324899809701, 7.47839651788984, 4.772671146052224, 2.635960246835436, 1.5658797983612334, 1.0246275046042033, 0.13120071696383612, 0.674169867166451, 36.479168210710796, 46.83760520390102, 34.0777005468096, 38.31864125388009, 58.00153643744332, 30.899514607020787, 44.70830542700631, 64.40175492422921, 69.73696395329067, 72.30132171085903, 62.86945479256766, 0.4114913466785635, 0.11976221789206777, 0.09018448287887232, 0.24224709825856344, 0.17045190504619054, 0.1298447461532695, 0.17386986235422747, 0.21440019751233713, 0.13549593862678322, 0.1118020521742957, 0.08918792528233357, 0.1332986251051937, 0.14508302775876863, 0.10356634017080069, 0.20369390557919229, 0.15430995050285543, 0.10831347972686801, 0.1324182530598981, 0.10323790886572429, 0.147251408547163, 0.169811680114695, 0.12502532904701574], [0.0295195234939456, 0.03837333679465311, 0.045181305945983956, 0.009355572135453778, 0.01320949413015374, 0.00788447683277939, 0.04620902526325413, 0.03234919433348945, 0.010689912945963442, 0.005298111263463008, 0.0684874232060143, 0.06316436348216874, 0.0190371905253934, 0.050151201763323376, 0.01911184803715774, 0.06734492629766464, 0.14016317389905453, 0.08808292421911444, 3.6007640872682845, 74.53084577832902, 70.84006690979004, 75.87526662009103, 53.34272064481463, 40.96662752968924, 19.39345407485962, 29.222817012241908, 32.61444466454642, 41.20144884926932, 21.804970570972987, 0.32731905047382626, 0.14908315454210552, 0.10667218494095973, 0.1730065486793007, 0.10013788592602525, 0.3888052611478737, 0.8429492648158754, 1.4147551762206214, 1.7801422668354852, 70.0067833491734, 77.98473971230644, 77.5063909803118, 70.72831208365304, 62.2050541469029, 56.013146127973286, 62.37240150996617, 59.9261839730399, 58.100506578172954, 52.53870289666312, 53.8768356187003, 48.792956829071045, 52.677944796425955, 51.0129132270813, 49.032839911324636, 48.88154288700649, 45.79550395693098, 48.41188287734985, 54.64755759920393, 60.529815673828125, 63.01838248116629, 63.18738351549421, 60.17303262438093, 63.58001232147217, 59.011210441589355, 54.769724300929475, 48.74443061011178, 45.04475804737636, 43.27937364578247, 42.902162892477854, 46.020771503448486, 47.501019205365864, 48.02489948272705, 45.59860590526036, 45.13208300726754, 45.08936895642962, 53.673437527247835, 58.43182795388358, 64.20459978921073, 59.1748057774135, 54.50229855946132, 47.14980166299002, 45.67680093220302, 42.753082343510215, 44.6632011958531, 43.54039314814976, 45.996699469430105, 47.46204675946917, 60.871236256190706, 46.66389329092843, 37.865278244018555, 62.675850187029155, 52.026384421757285, 52.072496141706196, 46.39794404166085, 46.3162818636213, 42.2137770652771, 43.66357428686959, 42.086388792310444, 45.30674682344709, 45.63699122837612, 45.582937717437744, 44.09345585959298, 46.45619426454817, 44.5056368964059, 44.17810576302664, 42.507095268794465, 43.808690888541086, 41.9904202733721, 44.3466169493539, 43.49051897866385, 42.02534539358956, 44.93616812569754, 46.81285572052002, 54.221282141549246, 60.006275858197895, 60.92539051600865, 61.26713766370501, 59.80040768214634, 57.89513519832066, 47.65846191133772, 47.01190076555525, 47.519379820142476, 48.612140383039204, 52.20531095777239, 59.80210999080113, 61.77166025979178, 63.5172700881958, 62.081230299813406, 63.296032496861045, 52.765943731580464, 58.6187344959804, 54.361434255327495, 56.19136047363281, 65.69297340938023, 54.690858772822786, 12.371744411332266, 0.07933212271226303, 1.8526444392544883, 1.1957679327045168, 0.9801812895706722, 0.16996557185692446, 0.289548290095159, 0.162971504298704, 0.06781221979430743, 5.045780948230198, 18.443333080836705, 37.068702016557964, 38.219810077122276, 49.24946737289429, 52.77443790435791, 28.440562759126934, 45.60303885596139, 54.38972037179129, 58.93043763296944, 56.598281724112375, 7.275747529097965, 0.31251898035407066, 0.04825659967692835, 0.005505561471051935, 0.03158686024003795, 0.07777320886296885, 0.07186393559511219, 0.06449165940284729, 0.049788419622927904, 0.05121843896007963, 0.05169624974951148, 0.051743285797004185, 0.005386647784949413, 0.057197204391871176, 0.04991577725325312, 0.032011029443570545, 0.06510256483618702, 0.04477434439052429, 0.1069331020116806, 0.12020322494208813, 0.0817329017445445, 0.07451898205493178, 0.058938745941434584, 0.03567217709496617, 0.13080309544290813, 0.01791999958056424, 0.007893964448677642, 0.011992204851204795, 0.05352284227098737, 0.0258253023494035, 0.05367388416613851, 0.020779310526060205, 0.03996747339676533, 0.04572291599054422, 0.030484756521348442, 0.03339528159371444, 0.06288192328065634, 0.05474023248202034, 0.04926525894552469, 0.12287205244813647, 4.766200201851981, 88.69913291931152, 78.89507184709821, 84.49309648786272, 61.504272733415874, 48.9178854397365, 26.697883333478654, 27.919543402535574, 32.96144117627825, 45.85073171343122, 25.657534769603185, 0.31365449513707844, 0.1563751261149134, 0.2973571696451732, 0.7201849094458989, 1.375807591847011, 2.6258992552757263, 1.8445743237222945, 0.7618430512292045, 2.319863025631223, 72.23133945465088, 80.65637070792062, 80.56145136696952, 72.85328660692487, 64.17839118412563, 56.97121238708496, 65.38176359449113, 64.2401259286063, 61.3089519228254, 54.948122773851665, 56.36242164884295, 52.30842569896153, 54.64400012152535, 52.65964324133736, 51.54971367972237, 51.267971175057546, 48.908474104745046, 50.797439166477744, 55.48802212306431, 63.08869825090681, 66.60444504874093, 66.14612102508545, 63.14270659855434, 65.5335191999163, 63.49547358921596, 56.445685386657715, 52.357403550829204, 46.43973050798689, 45.308018343789236, 46.41704116548811, 50.4034207207816, 51.222126960754395, 51.42761645998274, 48.013942173549104, 46.74786574499947, 46.56067780085972, 56.95533227920532, 60.49779142652239, 64.85786247253418, 60.838343484061106, 55.5265394619533, 50.20994813101632, 47.51770183018276, 45.522276469639365, 47.136572292872835, 46.2755445752825, 49.09006527491978, 49.60521166665213, 63.42948654719761, 50.39681645802089, 41.06633765356881, 64.96226610456193, 54.568817138671875, 54.809537478855674, 48.43083756310599, 48.982399463653564, 43.93467215129307, 46.52628421783447, 45.24103423527309, 46.981405121939524, 46.95428282873971, 47.72656120572771, 46.29505859102522, 49.30121060780117, 45.89783007758004, 46.80176986966814, 44.416328225817, 48.2633512360709, 44.36403260912214, 46.95770134244646, 45.896009649549214, 45.48638554981777, 45.606495584760395, 49.99642651421683, 55.92445584705898, 62.54099260057722, 62.521926743643625, 62.585440226963584, 61.695945739746094, 58.912115233285085, 49.807400771549766, 48.66193812234061, 48.8329576083592, 50.209930760519846, 54.050061157771516, 63.99366637638637, 64.5526350566319, 65.59159919193813, 63.404973302568706, 65.23646981375558, 56.362821170261924, 60.718778882707866, 54.8908383505685, 58.87112086159842, 65.40376853942871, 63.24740900312151, 17.14808985165187, 0.7605605657611574, 0.5266873495919364, 0.7821961705173764, 1.677139891045434, 1.0719854491097587, 1.037796512246132, 0.43835004259433064, 0.19084465077945165, 6.254252467836652, 33.316348212105886, 36.11864355632237, 38.35601214000157, 46.22887005124773, 47.443085125514436, 35.58905185971941, 50.86134869711739, 61.42627225603376, 62.83076722281319, 67.41384765080043, 13.79459912436349, 0.5069591339145387, 0.11011241855365889, 0.05349492394764509, 0.04385415930300951, 0.033035685175231526, 0.0610024355618017, 0.028328747122681568, 0.07453585722084556, 0.021133592319009558, 0.025916244701615403, 0.06565766076424293, 0.1348171050527266, 0.023109255591407418, 0.03630993215899382, 0.03314215410500765, 0.028000957033197795, 0.02852187006335173, 0.03324513875746301, 0.036080529647214074, 0.07246355699109179, 0.05221883367214884, 0.15397552773356438, 0.10444568084286791, 0.1846005544066429, 0.08662184154880898, 0.16656588071158954, 0.14162065354841097, 0.20854308323136397, 0.10510210240525858, 0.14868394524923392, 0.16243406385183334, 0.09552150685340166, 0.15824999979564122, 0.11068102411393609, 0.19471470239971364, 0.13533911561327322, 0.14998568754111016, 0.21074511935668333, 0.2574392801948956, 5.781478796686445, 98.87795897892543, 88.5034646987915, 96.01942838941301, 70.93821716308594, 59.26399285452706, 25.825151375361852, 39.315763337271555, 45.621541908809114, 59.59632519313267, 34.1763927595956, 0.626893835408347, 0.41249981256467955, 0.29646834305354525, 1.183469295501709, 1.179301462003163, 3.6498578871999467, 5.162074250834329, 6.766066764082227, 2.4229117589337483, 78.48460006713867, 81.97941194261823, 85.43797506604875, 75.52862099238804, 67.90389020102364, 60.32002176557268, 67.85310581752232, 66.82395253862653, 65.08401244027274, 57.83025639397757, 59.31379059382847, 54.282217843191965, 58.214856556483674, 54.93839182172503, 56.10404941013881, 54.350021839141846, 50.242934703826904, 54.0509991645813, 58.9116427557809, 65.86849185398647, 69.40117835998535, 69.37244755881173, 62.91267258780343, 67.11997359139579, 65.44144862038749, 60.35730579921177, 55.473531654902864, 48.19185427256993, 48.0303955078125, 49.547274112701416, 52.43628992353167, 51.41817038399832, 53.76528576442173, 52.018598965236116, 48.5259028162275, 49.26914119720459, 58.75789301736014, 63.47623402731759, 66.66443579537528, 63.707428387233186, 60.07744625636509, 53.29527139663696, 50.22684962408883, 47.180794102805, 49.398193563733784, 49.09124299458095, 51.535198892865864, 53.905260699135916, 66.34134456089565, 53.54413155147007, 44.12288842882429, 66.48677035740444, 59.95332363673619, 57.46655988693237, 51.46992751530239, 51.54332481111799, 46.68185091018677, 47.834018571036204, 47.41921806335449, 49.05353512082781, 50.621100834437776, 50.535168988364084, 48.975413049970356, 52.16382673808506, 48.0989533833095, 50.6034072467259, 47.20155184609549, 51.432810238429475, 47.6185062953404, 50.41610813140869, 47.18303837094988, 47.1445939881461, 48.56380871364048, 52.484281131199424, 58.69470609937395, 66.06365285600934, 64.16640554155622, 65.94364356994629, 63.35398742130825, 62.01966231209891, 52.72023500714983, 51.46910067967006, 52.62429428100586, 53.506170068468364, 57.18646757943289, 65.32872104644775, 67.91950280325753, 68.76450102669853, 65.36301735469273, 69.91841615949357, 59.771829741341726, 61.65570177350725, 55.35755927222115, 59.898585728236604, 65.42984512874058, 65.3674989427839, 14.640283482415335, 0.9680731850011008, 5.937425468649183, 6.0498208318437845, 4.460969311850412, 0.777092555803912, 1.1474501597029823, 0.6997790815574783, 0.3365204195891108, 10.010155064719063, 35.74025508335659, 54.468443461826865, 50.73527363368443, 59.16936533791678, 62.29966081891741, 41.41130876541138, 59.68714509691511, 70.67797933306012, 73.45360401698521, 77.1084954398019, 12.599177190235682, 0.611583371247564, 0.14261708222329617, 0.24877683073282242, 0.17024075851908751, 0.13731107408446924, 0.21054075817976678, 0.09282481191413743, 0.15420526612017835, 0.16709747218659946, 0.14184364729693957, 0.19692299461790494, 0.2048570095960583, 0.18656959517725877, 0.1650461929717234, 0.10626074166170188, 0.13461153608347687, 0.10678964613803796, 0.2267614770680666, 0.24832090948309216, 0.1647136565297842, 0.19141167535313539], [0.07264739248369421, 0.05799676291644573, 0.02777929151696818, 0.03430090531972902, 0.046144496582980664, 0.018056961874078428, 0.042777941695281436, 0.027898196297298585, 0.020811130425759723, 0.03196966934150883, 0.019548130787110755, 0.025666789783697044, 0.0894219655809658, 0.025331751243876557, 0.1676900503890855, 0.08166401008410112, 0.11078169156930276, 0.24481904453464917, 21.72026334490095, 87.68511281694684, 66.52811213902065, 72.53053583417619, 59.488711493355886, 47.16458395549229, 31.50383070537022, 69.21778065817696, 56.06997891834804, 43.4589706829616, 5.95490757056645, 0.09063923026302032, 0.12492757929222924, 0.30731431820562904, 0.132918916908758, 1.0796198908771788, 2.3362475293023244, 0.47722415519612177, 1.0395031635250365, 31.894104072025844, 85.12629277365548, 73.57103552137102, 75.40251118796212, 61.6869478225708, 58.53939996446882, 57.516329833439414, 60.7424236025129, 54.78312042781285, 55.62727444512503, 48.90377712249756, 51.05261870792934, 46.8352358681815, 48.55118383680071, 46.560570103781565, 47.29811443601336, 45.649970463344026, 47.00506373814174, 47.306431429726736, 50.434805733816965, 57.7435359273638, 60.794840812683105, 63.1858549118042, 61.87796075003487, 61.1305638722011, 58.73880631583077, 53.72974225452968, 46.20728199822562, 46.62313515799386, 45.547720772879465, 42.8625442641122, 50.52006013052804, 52.49495356423514, 51.22357218606131, 49.41340317044939, 48.736096245901926, 49.80330828257969, 55.63750566755022, 58.25947093963623, 63.135744503566194, 57.90408100400652, 55.21831389835903, 45.66235910143171, 46.130688531058176, 43.6395126751491, 46.548709528786794, 43.57020092010498, 51.403568744659424, 47.661084856305806, 61.850702966962544, 45.85559892654419, 34.62742117473057, 64.93195111410958, 53.57718760626656, 56.25529432296753, 49.56691667011806, 51.818438734327046, 42.84965535572597, 45.28634343828474, 44.314505849565776, 46.21776335580008, 44.239215169634136, 44.08807100568499, 44.851570333753315, 43.25294269834246, 43.305307797023225, 42.277735233306885, 41.81606217793056, 42.39397512163435, 41.983340059007915, 43.80724218913487, 42.50947502681187, 43.113877977643696, 43.203263078417095, 45.47012676511492, 50.069618838174, 59.811274664742605, 58.88859558105469, 61.90410682133266, 59.461509295872276, 59.139495032174246, 51.30853475843157, 45.34024061475481, 45.33187845775059, 47.19699035372053, 54.5125332559858, 61.36480154309954, 63.73836176736014, 62.86447293417794, 55.79176262446812, 52.759367261614116, 57.26491274152483, 64.2345187323434, 58.52048001970564, 60.88395840781075, 64.86357389177594, 64.5423308781215, 69.48223604474748, 28.73445245197841, 0.8097898012825421, 0.9748967502798352, 3.78575553212847, 2.487620983804975, 0.3708585798740387, 0.5615104724253926, 0.08066777139902115, 0.5476282973374639, 10.136263132095337, 22.06997833933149, 37.83714846202305, 93.56777041299003, 87.3232923235212, 29.75646993092128, 26.259189707892283, 42.899675437382285, 50.33381366729736, 55.15419939586094, 42.209305899483816, 0.35271069939647404, 0.039323842219476185, 0.03186095446082098, 0.010347996605560184, 0.08036233564572674, 0.02338517676772816, 0.02501543178888304, 0.006062379605802042, 0.035829020464526753, 0.003852380872038858, 0.048442131507077386, 0.05527119631213801, 0.03599266954032438, 0.002877125670368384, 0.026024491393140385, 0.09759253822267056, 0.03896616605509605, 0.07597633956798486, 0.04959918638425214, 0.08020043719027724, 0.01674070571815329, 0.04547374775367124, 0.06606955187661306, 0.04990753983812673, 0.016458657370614152, 0.037600254706506214, 0.018267646997368762, 0.0557195179696594, 0.044767623501164575, 0.07121823488601617, 0.04330989279385124, 0.030394806526601315, 0.03309042938053608, 0.02689968451990613, 0.04147622315213084, 0.03931899069409285, 0.03141093307307788, 0.1333745124616793, 0.29641528161508696, 26.20050174849374, 100.26954419272286, 73.19349125453404, 81.63728959219796, 65.02030440739223, 53.44883353369576, 34.86877032688686, 42.440406458718435, 53.06640815734863, 46.90710456030709, 6.723668422017779, 0.09823728219739028, 0.13797259144484997, 0.8089068372334752, 0.6568419284054211, 1.8188389561006, 2.0487141353743414, 0.13286931599889482, 0.45143111209784237, 34.48872470855713, 88.27105440412248, 76.2339117867606, 77.7633284160069, 65.30084487370083, 60.73328672136579, 60.395708492824006, 64.99358858380998, 60.00574084690639, 58.20963845934187, 50.848504952022004, 53.40995141438076, 50.48900168282645, 51.38949864251273, 49.78449950899397, 49.19415276391165, 49.969001974378315, 50.19590582166399, 49.84889888763428, 52.99706860951015, 60.6273683820452, 62.261848722185405, 66.46885790143693, 64.22389493669782, 63.77404076712472, 62.73335347856794, 57.49430056980678, 48.08209357942854, 47.47070074081421, 47.02485220772879, 46.0617276600429, 53.422187192099436, 55.335165228162495, 54.2364570072719, 52.64553492409842, 48.90295723506382, 52.13491528374808, 58.74136325291225, 61.47008759634835, 65.25664043426514, 59.184505462646484, 57.707224641527446, 47.6205073765346, 48.484866755349294, 44.77236086981637, 49.46640750340053, 47.06055205208914, 52.07550471169608, 50.16666432789394, 65.15411976405552, 48.67456647327968, 38.754001481192454, 66.25169890267509, 53.27296073096139, 58.180865968976704, 52.64648682730538, 53.39076048987252, 45.78885800497872, 46.68242761066982, 45.71902860913958, 47.53177193232945, 46.24055692127773, 45.27339199611119, 45.57041358947754, 46.028487477983745, 44.94180658885411, 45.62056916100638, 45.07819972719465, 45.202259813036235, 45.31597750527518, 46.00603437423706, 45.34344720840454, 46.58623327527727, 44.77014092036656, 47.34021357127598, 52.563664300101145, 61.72698334285191, 61.755012375967844, 62.5703626360212, 61.10710675375802, 61.42305524008614, 53.930249895368306, 47.85232012612479, 47.04875748498099, 49.01013319832938, 56.86830609185355, 64.39755126408168, 65.79470893314907, 63.858273778642925, 59.90943186623709, 57.1960699898856, 60.99351760319301, 65.24856662750244, 59.62350654602051, 63.19360910143171, 67.39931896754673, 65.71825790405273, 72.86382007598877, 35.76580013547625, 1.4777519958359855, 0.2905839245234217, 0.7827610916325024, 1.4153439274856021, 1.3610357216426303, 1.5332546404429843, 0.0544037944637239, 0.0692822862682598, 15.582273347037178, 32.5004768371582, 26.06135364941188, 78.06719398498535, 75.97598075866699, 39.64540324892317, 38.52129588808332, 47.94542251314436, 56.50996317182268, 61.75726359231131, 58.87570667266846, 0.9075102433562279, 0.12947889364191464, 0.030973009964717284, 0.07307911717465945, 0.014200155257380434, 0.013382097323691207, 0.01810047123581171, 0.014252280317513006, 0.05768076915826116, 0.021324654209560583, 0.05202058270307524, 0.050606125566576204, 0.014434589106323463, 0.032658572375242195, 0.035335603369666, 0.05242967825116856, 0.03018430800044111, 0.037181568065924306, 0.019444725442943827, 0.011063317552075853, 0.05445006037397044, 0.20231410461877072, 0.16250765775995596, 0.16518588976136275, 0.14007556145744665, 0.09032388111310345, 0.1355093057666506, 0.14492914958723954, 0.06988288475466625, 0.1570562802787338, 0.13126434997788497, 0.11908799835613795, 0.17116577816861017, 0.16087902443749563, 0.17010558077267238, 0.22754021813826902, 0.1077726533902543, 0.298572480146374, 0.44828482664057184, 31.56309536525181, 109.40559155600411, 82.61330999646867, 92.33053248269218, 76.27889442443848, 62.50289562770298, 43.79313734599522, 92.80252361297607, 73.1420954295567, 63.674174308776855, 10.444918615477425, 0.1838466070060219, 0.3589506431349686, 2.3731426809515273, 0.5181563730750764, 3.16131506221635, 6.21954882144928, 5.3844878247806, 2.7786847140107835, 40.10267809459141, 89.26841967446464, 80.62148380279541, 81.16614614214215, 67.85162585122245, 64.11055592128209, 61.92984989711216, 67.80888748168945, 61.91715553828648, 61.36391217367989, 54.48850291115897, 56.46927452087402, 52.43689441680908, 53.90814420155117, 52.850941044943674, 52.758106163569856, 51.93744053159441, 51.81627089636666, 52.7246401650565, 53.49356256212507, 64.04923112051827, 65.93805721827916, 69.05234404972622, 65.53711836678642, 64.69999245234898, 63.37098271506173, 60.44825077056885, 50.65164858954293, 49.64846420288086, 50.06669364656721, 46.734570366995676, 56.34885876519339, 56.861837318965364, 57.289158480507986, 55.63079023361206, 53.39122254507882, 54.134148257119314, 62.500366483415874, 62.23600837162563, 66.67062664031982, 63.48270974840437, 61.29012925284249, 51.45940099443708, 49.772072655814036, 47.11110714503697, 52.40847628457205, 49.67104237420218, 54.447623184749055, 51.66165610722133, 66.61215060097831, 53.52893584115164, 41.99679871967861, 68.16441985539028, 60.01282106127058, 60.466274397713796, 56.169220038822715, 57.047757216862266, 47.245735440935405, 48.343342372349326, 49.16710690089634, 51.754553522382466, 48.75244535718645, 47.67578724452427, 47.93363489423479, 49.57329511642456, 47.92026308604649, 47.91995736530849, 48.04388543537685, 47.254781995500835, 47.244036606379915, 48.34824432645525, 48.14436680930001, 49.47742734636579, 47.983474322727744, 50.22221517562866, 55.998009477342876, 67.28942625863212, 64.35966968536377, 65.62188638959611, 63.126176834106445, 64.79788562229702, 56.08844028200422, 50.80846248354231, 48.78304869788033, 50.99941635131836, 59.274623598371235, 66.2325496673584, 68.1495646068028, 66.84265014103481, 63.204003606523784, 58.74441351209368, 61.482003756931846, 67.07565103258405, 59.89318697793143, 64.08009501865932, 70.35912649972099, 68.5231761932373, 76.91487693786621, 34.28943995067051, 0.9039702447397369, 3.3154295810631345, 9.60067253453391, 7.288939986910139, 1.5241767104182924, 2.2662416057927266, 0.1583661785615342, 1.3456809627158302, 18.752988236291067, 36.63014561789376, 49.999435084206716, 99.5318956375122, 92.51729311261857, 40.085050514766145, 39.99315711430141, 57.048882825034006, 63.6387871333531, 71.46547426496232, 61.91092300415039, 0.7308377463902745, 0.23424014076590538, 0.09773621122751917, 0.11460845944072519, 0.23941065903220857, 0.10246871478323426, 0.08848023361393384, 0.11620670796505042, 0.1318368978266205, 0.07546795399061271, 0.12783208915165492, 0.17594110406935215, 0.09058891010603734, 0.08010439055838756, 0.14888323098421097, 0.2253143654337951, 0.11797961140317575, 0.10751999409071036, 0.14854496770671435, 0.1303949701998915, 0.12189125722008091], [0.01868271195728864, 0.03840099388201322, 0.004898670844600669, 0.02947527283270444, 0.03467751261112945, 0.0360200212869261, 0.07462920328336102, 0.05070996856583016, 0.10981961033706154, 0.046679314492004256, 0.08782132861337491, 0.06988456752151251, 0.02049604760083769, 0.018064853236345307, 0.12740079872310162, 0.029634226446173022, 0.06501738833529608, 0.38862067248140064, 54.16994885035923, 73.7891811643328, 69.36164311000279, 55.31815256391253, 44.24679218019758, 24.23639018195016, 42.664902755192344, 96.49339975629533, 58.81743907928467, 31.729317120143346, 0.8103366462247712, 0.03558143321424723, 0.12551182508468628, 0.6723439022898674, 0.29140435478516985, 2.552898006779807, 1.987952790090016, 1.489812114409038, 5.698960687432971, 78.10795211791992, 71.15816933768136, 74.45834827423096, 66.53842326572963, 60.30813339778355, 51.81752157211304, 55.02984401157924, 53.93166037968227, 56.8546633039202, 53.483515466962544, 50.49137101854597, 46.80683510644095, 47.8695308140346, 48.475709029606406, 47.03106737136841, 47.12379108156477, 47.88242319652012, 47.75852639334542, 47.43915244511196, 46.47596536363874, 54.357018675122944, 59.89100524357387, 62.554631914411274, 62.84799875531878, 60.2053347996303, 60.95964513506208, 52.91788693836757, 44.8579592023577, 44.072555678231375, 44.84453180858067, 47.43778017589024, 54.487172331128804, 53.96602269581386, 54.272657121930806, 50.20693608692714, 52.54084294182913, 56.29743167332241, 57.95683520180838, 59.59670039585659, 57.90352514811924, 57.62289088112967, 54.17011560712542, 44.764401708330425, 45.26761456898281, 40.74691506794521, 47.89795936856951, 47.90785707746233, 52.604387692042756, 49.12949630192348, 62.27990709032331, 41.23982375008719, 30.48690973009382, 62.61057186126709, 52.60837595803397, 59.626084327697754, 55.477950709206716, 58.55697890690395, 44.64349263054984, 42.042337213243755, 41.867867946624756, 42.72122137887137, 41.492505414145334, 44.44065734318325, 41.49074751990182, 40.17432444436209, 42.08084412983486, 43.773814405713765, 42.991155420030864, 41.80086299351284, 41.48521327972412, 42.218480995723176, 41.827425956726074, 42.750330856868196, 42.660376003810335, 44.94698647090367, 45.11856181280953, 55.108803340366904, 58.738681248256135, 59.804382051740376, 59.00431782858712, 59.19301700592041, 55.87858731406075, 44.94225822176252, 43.65072359357561, 45.53224713461739, 55.098377568381174, 61.73161084311349, 62.619597571236746, 58.832982199532644, 55.43056399481637, 64.91251700265067, 63.06043297903878, 62.92545032501221, 63.43392644609724, 62.79394177028111, 64.09119129180908, 63.421739305768696, 63.13554995400565, 65.25833579472133, 35.675299848829, 0.9548431634902954, 0.4680691978761128, 2.3636455791337148, 0.75415714936597, 0.8358558054481233, 0.18512210356337683, 0.021600261563435197, 9.633857999529157, 14.24232714516776, 48.16210903440203, 73.41668128967285, 73.43095983777727, 29.229942389896937, 23.379920482635498, 47.92605093547276, 53.310425417763845, 55.71233081817627, 61.027063505990164, 17.176518406186783, 0.7051238747579711, 0.22571979010743753, 0.09754250983574561, 0.04577612331403153, 0.10152019068066563, 0.03488072706386447, 0.04101183717804296, 0.06619254313409328, 0.06194753984787634, 0.04385570975552712, 0.011826264023381685, 0.05551449182842459, 0.1379020916564124, 0.034574365110269616, 0.04992705789793815, 0.07418819623334066, 0.04613789782992431, 0.08112072066536971, 0.038028247454868894, 0.013502039414431368, 0.07799674543951239, 0.027766105885218297, 0.007638640202847975, 0.021967854517112886, 0.028927142066614966, 0.054088903324944634, 0.007043418258295527, 0.010834211051197988, 0.029365326410957744, 0.027674064306276183, 0.062036292228315554, 0.029796033299395015, 0.04343408166563936, 0.018416297056579163, 0.0553923419543675, 0.048876760327922444, 0.038426795176097324, 0.8418539464473724, 65.90028681073869, 84.17971188681466, 75.94641617366246, 62.815557616097585, 57.5050424848284, 34.09152398790632, 39.45446327754429, 86.47010912214006, 50.84129272188459, 34.07264573233468, 1.0230516748768943, 0.036244406032242944, 0.12550395407846995, 1.7637996694871356, 1.386614429099219, 2.4619224199226926, 1.3041344263723917, 0.46874567014830454, 6.5347290975706915, 83.76407759530204, 73.46457522256034, 78.05743176596505, 69.1566504069737, 64.23861122131348, 55.597727230616975, 57.26782751083374, 58.26966742106846, 59.225485937935964, 55.91942187717983, 52.85807337079729, 50.32619496754238, 50.09389584405081, 50.71086808613369, 49.16316727229527, 50.39905725206648, 50.3892047064645, 49.884438923427034, 49.914514201028005, 48.77612829208374, 57.04677057266235, 59.782384055001394, 65.83609935215541, 63.779932839529856, 62.64851597377232, 63.50840418679373, 55.059752532414024, 47.822554043361116, 46.93296575546265, 46.500819069998606, 50.38196120943342, 57.32113756452288, 56.14783695765904, 56.015129838671, 52.42308834620884, 54.883355140686035, 58.982458795819966, 60.65281963348389, 63.78315680367606, 60.3712716783796, 60.6210663659232, 57.39774145398821, 47.6142018863133, 46.29862996510097, 44.250561577933176, 50.307146481105256, 49.442331995282856, 55.50704281670706, 51.35495567321777, 65.06290381295341, 45.16565670285906, 34.1240485055106, 62.74037115914481, 54.4100056375776, 61.7179228918893, 58.37567261287144, 60.50661563873291, 47.79611267362322, 44.21960040501186, 43.280217851911274, 44.994689328329905, 44.11793088912964, 46.66746813910348, 43.55874681472778, 43.86334541865757, 45.18012980052403, 44.7296815599714, 44.949546882084434, 45.91852528708321, 43.905322960444856, 44.4805816922869, 44.38948733466012, 44.87115730558123, 45.264842237745015, 46.445542676108225, 48.518002714429585, 57.95052623748779, 60.83950383322579, 61.5353033883231, 62.480946268354145, 61.16968223026821, 58.837637492588584, 45.844488756997244, 46.611969402858186, 48.62563031060355, 56.53450420924595, 64.10361467088971, 65.35027435847691, 60.45720699855259, 59.638570240565706, 65.22319180624825, 65.34584835597447, 65.03194958823067, 65.85465799059186, 64.01618548801967, 65.94777079990932, 66.91883019038609, 66.20765427180699, 69.32524149758476, 42.62159810747419, 1.9283177043710436, 0.33801976484911783, 2.428332656621933, 2.1675459189074378, 1.7767869383096695, 0.40327227913907593, 0.15306775644421577, 4.742849911962237, 23.27214871134077, 40.42290667125157, 61.13213416508266, 69.16931697300502, 31.00590542384556, 33.37487636293684, 53.09370068141392, 61.274732044764924, 59.857230050223215, 69.51924215044293, 29.097344705036708, 0.7578501169170652, 0.06603493980531182, 0.06570543641490595, 0.047329384966620376, 0.039079878346196244, 0.015023978194221854, 0.03004772907921246, 0.03131658956408501, 0.022274270753509233, 0.06809788303715841, 0.04679091993187155, 0.10173719975032977, 0.0840599172349487, 0.007463909802027047, 0.039250326342880726, 0.02617842554380851, 0.039893452011580975, 0.023889423281486546, 0.0457182035648397, 0.07100362104496785, 0.20883528755179473, 0.06501158007553645, 0.11820971619869981, 0.10424095325704132, 0.15071090576904161, 0.13869565193142208, 0.1271997895091772, 0.12792780330138548, 0.17523023007171495, 0.13497626222670078, 0.32432896377784864, 0.17239471365298542, 0.17769290506839752, 0.10311168099620513, 0.1998906218047653, 0.1067893747240305, 0.21026785139526638, 0.9812631458044052, 74.49595887320382, 91.64079175676618, 89.09872382027763, 72.40163285391671, 62.428438731602256, 34.17153944287981, 54.99731254577637, 114.70102909633091, 76.85536561693463, 46.3816157749721, 1.5546069975410188, 0.17317433681871208, 0.3771612202482564, 2.123524303947176, 2.6172266006469727, 9.083273189408438, 8.249738625117711, 4.5402499948229105, 7.124939484255655, 87.95034640175956, 75.05746364593506, 82.83757700238908, 71.03942462376186, 67.83293519701276, 56.72443321772984, 63.42009258270264, 61.42586926051548, 63.701716967991416, 58.87811074938093, 56.53512259892055, 52.06512757710048, 53.1448324748448, 54.47236224583217, 53.043788296835764, 52.837510177067344, 54.14487974984305, 52.767375060490195, 52.34327091489519, 51.734699044908794, 59.993796893528526, 63.207554136003765, 69.52637795039585, 64.98375688280377, 63.33742291586739, 66.36170973096574, 58.05222702026367, 49.1610689163208, 48.521021706717356, 50.26083326339722, 52.31391824994768, 58.9314729145595, 58.368189402988975, 57.22323744637625, 54.002281870160786, 57.59990276609148, 62.50934355599539, 62.80102893284389, 65.320070539202, 63.01306710924421, 62.77676582336426, 58.82328251429966, 50.34660530090332, 48.668789046151296, 46.53788423538208, 52.8850428036281, 52.47089542661394, 57.26757042748587, 54.738380977085654, 68.89628750937325, 48.67830113002232, 38.36076470783779, 65.45922906058175, 56.74525696890694, 64.89044952392578, 60.9359587260655, 63.94240256718227, 49.77307667051043, 47.08653484072004, 46.11317559650966, 47.189979621342246, 47.89016348975045, 48.53223957334246, 47.3119170325143, 45.09959323065621, 48.36056695665632, 47.72152723584856, 48.58405576433454, 49.841495582035606, 47.063428606305806, 47.16657114028931, 47.23768595286778, 47.84873832975115, 47.42407832826887, 49.95768683297293, 50.324089663369314, 59.78565665653774, 63.49145753043038, 63.6293306350708, 64.32771492004395, 63.30835165296282, 62.82128293173653, 50.25753286906651, 48.34838329042707, 49.57020664215088, 61.276003565107075, 65.29004737309047, 67.80851227896554, 64.07145840781075, 61.454454149518696, 67.73174163273403, 70.36488655635289, 66.0324068069458, 68.9198557989938, 66.83299909319196, 70.94967474256242, 69.70635713849748, 68.47916630336216, 71.8227367401123, 43.236242703029085, 1.1509062371083667, 2.6712269144398824, 7.633644461631775, 4.194028641496386, 2.991960104022707, 0.9439326460872377, 0.18328156375459262, 15.769673211233956, 25.60092432158334, 68.3854490007673, 75.64547579629081, 77.50821140834263, 34.963238034929546, 36.10134949002947, 61.57375471932547, 71.03545720236642, 68.91336618150983, 81.01757975987026, 27.592615025384085, 1.4191356897354126, 0.4017760822815554, 0.20226257666945457, 0.15709275832133635, 0.17880339547991753, 0.14141242472188814, 0.1303930024483374, 0.12046627939811774, 0.16498378132070812, 0.10964779848498957, 0.15798680963260786, 0.21970269083976746, 0.25660769481744083, 0.09732723103037902, 0.13263823411294393, 0.20331042472805294, 0.14789860881865025, 0.1906575108213084, 0.21816066572708742, 0.1505304697368826], [0.03600609774834343, 0.029566067603549788, 0.06950415364865746, 0.057978652816798, 0.017766067126233662, 0.04685356228479317, 0.05743388419172593, 0.002059331941252042, 0.010484179431971694, 0.052119010992880375, 0.05407284918640341, 0.0752293878634061, 0.032087357847818306, 0.09269650094211102, 0.04132725418146167, 0.08601194034729685, 0.1919206716120243, 9.665959545544215, 82.20046193259103, 65.97942679268974, 77.42718151637486, 59.55394812992641, 41.26958983285086, 19.800969396318706, 62.983217648097444, 58.71753093174526, 52.573902470724924, 9.286651304789952, 0.049843947536179, 0.05865485367498227, 0.2427744013922555, 0.14834059295909746, 1.2900347943816866, 1.486016878059932, 0.5785584204963276, 0.3700449892452785, 39.50333343233381, 82.85225854601178, 67.02403286525181, 71.91894149780273, 58.47496237073626, 56.60586220877511, 52.39620576586042, 56.34180286952427, 54.93364272798811, 53.34152902875628, 52.062615803309846, 51.20549644742693, 46.392614773341585, 47.16519887106759, 47.35463455745152, 46.9493704523359, 47.443599292210166, 46.74609048025948, 46.539364201681956, 47.14499698366438, 46.58533000946045, 55.51148271560669, 58.78453935895647, 60.908290999276296, 65.94781943729946, 60.09697069440569, 59.29951899392264, 50.38926029205322, 44.824291706085205, 44.59933682850429, 43.070159912109375, 50.0978285244533, 57.07734612056187, 54.95125641141619, 58.70946407318115, 56.28259032113211, 57.045648438589915, 57.0502724647522, 62.2883699962071, 55.386915411267964, 57.06650693075997, 58.00915513719831, 52.55199480056763, 42.97748483930315, 42.43134600775582, 40.663831983293804, 46.236763204847065, 49.23475456237793, 58.7685307094029, 53.12879255839756, 61.729269300188335, 42.58672857284546, 35.278686250959126, 59.520652362278526, 51.39360155378069, 58.46363680703299, 53.7628504208156, 57.50790861674717, 46.52430745533535, 42.27860375813076, 42.599242278507774, 43.733837945120676, 41.122666699545725, 43.62013414927891, 41.66350058146885, 41.353621346609934, 40.062899657658164, 44.3957268169948, 45.172254017421174, 44.71263415472848, 44.54277849197388, 41.02596861975533, 43.147979736328125, 43.55623156683785, 42.660428115299766, 43.91453627177647, 44.41603640147618, 51.21674905504499, 59.3251439503261, 58.63604245867048, 57.34008877617972, 57.99163178035191, 56.16363368715559, 47.89177199772426, 43.21945932933262, 45.682967458452495, 54.11704874038696, 59.817055565970286, 62.75180789402553, 58.66063213348389, 60.97631386348179, 62.338869503566194, 60.604342051914756, 63.56316293988909, 61.49259975978306, 62.3596168245588, 60.56407724108015, 59.68871538979666, 63.39095183781215, 64.42239107404436, 61.66549178532192, 26.965689488819667, 0.9938454649278096, 0.5647920849067825, 1.5529989238296236, 1.0001052490302493, 0.05217750410416296, 0.021596541495195458, 2.3305886558123996, 21.563211475099834, 22.756416933877126, 43.09270681653704, 35.65482003348214, 26.55051030431475, 27.477980170931133, 33.72475290298462, 39.235567229134695, 56.50447409493582, 46.59901796068464, 52.41190522057669, 2.10068079829216, 0.32111756610018866, 0.027455038291269114, 0.034638792010290284, 0.06563758291304111, 0.0494351403654686, 0.06204749484147344, 0.08350129971014601, 0.055934762848275046, 0.023027505692360655, 0.060988389886915684, 0.0399918870867363, 0.018926475662738085, 0.06261065855090107, 0.023463416944390962, 0.07049590043191399, 0.03533336759677955, 0.05323842413989561, 0.042911080443965535, 0.07249208260327578, 0.004764773833033229, 0.11553121278328554, 0.07538683512913329, 0.04171481302806309, 0.04344352687309895, 0.014830521075055003, 0.05328185038108911, 0.036544535641691515, 0.037210826495928426, 0.019191251901377524, 0.035223516169935465, 0.01803239042471562, 0.07298707389937979, 0.079579543721463, 0.07223661416875464, 0.07247843726405076, 0.32060690064515385, 12.633463944707598, 94.43688583374023, 74.60774149213518, 84.99251910618374, 65.40121160234723, 45.69098220552717, 23.78749312673296, 50.58604369844709, 62.292677879333496, 56.21586329596383, 10.236791406358991, 0.050146614866597314, 0.04881466758836593, 0.34894534572958946, 1.1584109429802214, 3.133372881582805, 3.708772965839931, 1.0484411524874824, 0.068279431866748, 44.37460776737758, 85.85412352425712, 70.3969316482544, 75.08168506622314, 61.09964438847133, 59.78825528281075, 55.96273694719587, 59.883834702628, 56.487332889011924, 56.52141727719988, 54.04605899538313, 53.32632289613996, 50.54978799819946, 50.61938115528652, 49.68063088825771, 50.7778765133449, 49.53895364488874, 48.676352160317556, 49.76770918709891, 49.423377309526714, 50.097567967006135, 55.95737641198294, 60.563757623944966, 64.41119057791573, 66.38146345955985, 62.99070085797991, 61.67021656036377, 52.283578940800254, 46.00961964470999, 46.193166732788086, 46.36065305982317, 52.59347554615566, 58.238327571323936, 58.54434708186558, 60.032276017325266, 57.4927476474217, 59.02137565612793, 59.40716743469238, 65.18905530657086, 59.191599573407856, 58.747435978480745, 60.46586445399693, 53.39443608692714, 45.14954730442592, 44.813435145786826, 43.09649011066982, 47.84282193865095, 51.78275973456246, 60.274017742701936, 57.78547177995954, 64.69202286856515, 44.10129690170288, 37.80236577987671, 60.74527931213379, 52.66896077564785, 60.31116281236921, 55.688623564583914, 61.03173269544329, 48.94381611687796, 45.95555918557303, 45.1401116507394, 46.56198058809553, 43.37091268811907, 46.26738739013672, 43.59127828053066, 43.77182722091675, 42.554749488830566, 46.10687010628836, 47.03381538391113, 47.026057720184326, 47.10850157056536, 42.8510137285505, 44.282981872558594, 44.484670707157676, 42.74307346343994, 46.09882409232003, 45.45295429229736, 53.07480158124651, 61.92183167593819, 59.720420019967214, 58.02424315043858, 61.07094832829067, 57.89694172995431, 49.40074702671596, 46.11262321472168, 46.54214348111834, 55.092718260628835, 63.28932053702218, 64.4331190926688, 62.63598837171282, 64.06963103158134, 64.61436980111259, 63.22061674935477, 66.60113770621163, 64.35252693721226, 65.50057779039655, 62.365307399204795, 63.596361432756694, 66.69741889408657, 66.09491974966866, 63.30705233982631, 33.21545342036656, 1.7269360018627984, 0.30182236433029175, 2.2257555382592336, 1.5745332368782587, 1.0139128395489283, 0.019271135829123, 0.5887478451643671, 19.513711759022303, 31.443388325827463, 40.45517063140869, 42.35928276606968, 24.69019440242222, 32.49645383017403, 45.3731472832816, 44.91178342274257, 63.64203194209507, 53.21212577819824, 65.50372532435826, 5.779358293328967, 0.47064247408083504, 0.0025920955855066753, 0.026450711468766843, 0.026543514703267386, 0.007704409754036793, 0.04186796855979732, 0.045443135646304915, 0.02995130925306252, 0.027358060370066335, 0.04371770251808422, 0.033127219549247196, 0.027871845389849374, 0.07789541301982743, 0.01008084719069302, 0.029094353451260498, 0.06075861078820058, 0.007621664104850164, 0.04432450281456113, 0.07544823576297079, 0.08076512081814663, 0.2067742645740509, 0.14732201690120356, 0.13132669377539838, 0.1598758375538247, 0.13534089337502206, 0.1214580126106739, 0.1806286953921829, 0.06545697046177727, 0.10167783472154822, 0.07482468922223363, 0.11276215208428246, 0.1454325547175748, 0.20435323805681296, 0.15553383768669196, 0.2097878557230745, 0.39271573988454683, 14.993705340794154, 106.63426780700684, 83.0203354699271, 96.90819331577846, 75.63343456813267, 57.13620778492519, 26.968456608908518, 81.66604818616594, 66.99015344892229, 75.2031534739903, 15.519550221306936, 0.1756820801113333, 0.20531503430434636, 0.8257440051862172, 3.0176749527454376, 4.877986294882638, 3.642262203352792, 3.8058618818010603, 0.9782038756779262, 46.59561334337507, 88.15893827165876, 73.1662404196603, 79.22679274422782, 64.71921116965157, 62.915924344744, 56.99758080073765, 61.67325292314802, 59.57746083395821, 58.730482373918804, 57.94431454794747, 56.23369584764753, 51.42520890917097, 53.211733204977854, 51.89824226924351, 53.189634459359304, 53.01212535585676, 51.419330733163015, 51.30478620529175, 52.396876267024446, 52.61699172428676, 60.3874123437064, 62.16489355904715, 66.90964467184884, 67.0334198815482, 64.71093586512974, 65.02742631094796, 55.95066792624337, 49.26017802102225, 47.971978528159006, 48.03266756875174, 57.44489540372576, 62.5281662259783, 60.23917252676827, 63.61608736855643, 60.96411977495466, 61.86901841844831, 61.45746966770717, 66.75136470794678, 60.34463228498186, 61.74687603541783, 62.881912912641255, 56.85459034783499, 47.59166540418352, 46.27887971060616, 44.29411636080061, 51.24474682126726, 54.43490103312901, 63.007591928754536, 59.58911296299526, 65.79413223266602, 46.184797627585276, 41.08437517711094, 61.64216668265206, 55.77948863165719, 62.00147887638637, 57.35397127696446, 64.25532163892473, 51.58048725128174, 48.137512411390034, 48.23383181435721, 48.37715925489153, 45.60289989198957, 48.65690762656075, 46.18722949709211, 46.00096566336495, 45.402618067605154, 47.82386030469622, 50.14458990097046, 49.1230275290353, 51.83885948998587, 45.372966630118235, 48.09788336072649, 47.024883474622456, 45.69304929460798, 48.98873274666922, 48.523061003003804, 55.260670116969514, 66.29423577444894, 63.14568737574986, 58.44703756059919, 63.31462587629046, 60.386328424726216, 53.62820822851998, 47.908631801605225, 49.48035601207188, 58.93220942361014, 65.3000875200544, 67.16326781681606, 64.82973616463798, 67.354843548366, 66.69686303819928, 64.53022711617606, 69.48866312844413, 66.51468127114433, 67.62068857465471, 65.40140615190778, 66.5112419128418, 69.65366200038365, 68.33203819819859, 67.83968884604317, 31.900774342673166, 1.8199841060808726, 3.0621558002063205, 5.797045801367078, 2.6655098497867584, 1.540137591106551, 0.13611447757908277, 4.4314733403069635, 31.266000815800258, 38.04182849611555, 57.306796482631135, 43.12854562486921, 35.64291429519653, 36.981776578085764, 49.95030089787075, 53.2698792048863, 72.67999853406633, 61.25782707759312, 78.56508799961635, 4.9740269013813565, 0.637430941419942, 0.10277007932641677, 0.21688724548688956, 0.12109575633491788, 0.09495490297142949, 0.26111295021006037, 0.1098943306133151, 0.11460141624723162, 0.10246150195598602, 0.1337904951402119, 0.1489724719098636, 0.08290091156959534, 0.15538503495710237, 0.08994054275431804, 0.13678656651505403, 0.1300545356103352, 0.11510885187557765, 0.13130021733897074, 0.21850048963512692], [0.0683674378586667, 0.07299715692975692, 0.03754354274964758, 0.08683718142232724, 0.018990264739841223, 0.03169177532462137, 0.01870017235965601, 0.016715199586802294, 0.022789779252239635, 0.05696787312626839, 0.04856094638151782, 0.04268281787101712, 0.024153215644348944, 0.16465955014739717, 0.0205018405935594, 0.24097430227058275, 0.14202121991131986, 31.940448556627544, 78.14019175938198, 65.9506195613316, 62.522232464381624, 41.85596568243844, 32.93189743586949, 23.783704621451243, 30.781502928052628, 27.741058077130997, 23.977901560919626, 0.4458894080349377, 0.03143336883346949, 0.11267368468855109, 0.15726639543260845, 1.3422496382679259, 0.3502650691994599, 0.8914352602192334, 1.3444563427141734, 5.025218623025077, 79.19560922895158, 69.34516198294503, 71.79173387799943, 60.872083936418804, 60.70611926487514, 58.515949794224326, 61.67677565983364, 57.652101108006065, 60.89007977076939, 60.069636481148855, 57.80228642054966, 54.25700977870396, 53.60373319898333, 48.60204117638724, 48.217097078050884, 47.18613031932286, 47.50822796140398, 44.328311920166016, 45.95885957990374, 45.65496621813093, 49.59788131713867, 55.811919348580496, 60.10045869009835, 62.479744229997905, 64.23098904745919, 59.495089939662385, 59.174576486860005, 48.47762325831822, 44.71809196472168, 42.81501858575003, 45.26455736160278, 52.587826660701204, 58.95675046103341, 58.09963457924979, 59.735337802342, 58.6488618850708, 58.13872514452253, 61.366288457598, 56.85014002663748, 53.86141756602696, 59.50403227124895, 52.19783469608852, 47.984283787863596, 40.79045942851475, 44.01868976865496, 43.47485426494053, 46.892308371407644, 48.56983975001744, 57.25698137283325, 54.75517477308001, 62.07773535592215, 38.793130261557444, 36.77167694909232, 57.93525062288557, 51.06933259963989, 56.94540330341884, 56.06989901406424, 53.00259242738996, 40.996515205928254, 42.580061776297434, 41.34257023675101, 41.524428912571494, 41.450194358825684, 42.08183772223336, 40.88838039125715, 42.189145701272146, 40.52359996523176, 44.939312185559956, 46.967383657182964, 46.9894893510001, 47.79571662630354, 42.61958312988281, 42.46593761444092, 41.893892424447195, 41.768463543483186, 43.59403324127197, 43.79146977833339, 45.837509291512625, 54.76504816327776, 59.888573374067036, 57.92622143881661, 57.95551156997681, 56.98137412752424, 45.05706330708095, 44.804360798427034, 45.02832555770874, 52.40881674630301, 62.09328542436872, 61.032156535557334, 58.033518995557515, 57.5955879347665, 62.02451910291399, 58.25601768493652, 59.49568748474121, 61.50212574005127, 60.59080001286098, 58.00328043528965, 59.86569990430559, 57.46364164352417, 63.871635164533345, 64.22381155831474, 50.21307134628296, 11.010172809873309, 0.37599712557026316, 2.413725806134088, 1.0513058730534144, 0.7036657301442963, 0.11486407715295043, 0.2744503431022167, 11.334083063261849, 44.98587901251656, 26.25280257633754, 15.270396505083356, 18.600984232766287, 19.70745185443333, 18.20081489426749, 48.45280776705061, 49.34401151112148, 54.61399780000959, 52.49500567572457, 29.70298269816807, 0.17762316523918084, 0.0615012062979596, 0.02181359297329826, 0.0347633880030896, 0.06408753751644067, 0.09413004187600953, 0.03427867990519319, 0.03146911405825189, 0.010571619695318597, 0.04073620268276759, 0.023497727067608918, 0.06631690503231116, 0.05187466374731489, 0.0743542473231043, 0.05461938878787415, 0.029115506780466864, 0.03582629953910198, 0.004316418672845299, 0.09778974085514035, 0.059685935133269856, 0.011379531834141483, 0.017364986773048128, 0.038118197449616024, 0.07346246231879507, 0.05294872700635876, 0.02894316227840526, 0.011135053970584912, 0.02639855757089598, 0.050241165328770876, 0.09564093580203396, 0.08378383490656104, 0.05479716835543513, 0.1422946559531348, 0.09510815010539123, 0.2222839601870094, 0.0429373024297612, 42.47500153950283, 88.79168292454311, 73.04432037898472, 69.9714378629412, 53.515379905700684, 47.555830069950645, 27.59282694544111, 33.60395499638149, 29.858215876988, 31.133158206939697, 0.49672899714538027, 0.06536190092031445, 0.1358513416988509, 0.5923713850123542, 1.9508161885397775, 5.146331369876862, 3.9758200304848805, 2.0291766694613864, 6.048931896686554, 83.312013898577, 73.71573175702775, 75.1159188406808, 63.86652129037039, 61.951993806021555, 62.370657512119834, 62.58060428074428, 61.0520144871303, 63.79384313310896, 63.91358838762556, 60.195829663957866, 56.46365342821394, 55.42115265982491, 51.47863013403756, 50.695026193346294, 48.98409135001046, 50.10507549558367, 47.21778283800398, 47.788209097726, 46.72879988806588, 53.131214005606516, 59.019312041146414, 62.88822882516043, 63.87136418478829, 66.35735321044922, 62.37219306400844, 62.19748755863735, 49.31542314801897, 46.7360121182033, 45.05180352074759, 47.038825035095215, 54.899148396083284, 59.96683093479702, 61.829677718026296, 62.80804661342076, 60.9268079485212, 59.902497564043315, 61.5057874407087, 57.96170588902065, 56.59925447191511, 59.58066395350865, 55.232554231371196, 51.3316444669451, 43.81558002744402, 44.74845559256417, 45.81971842902047, 48.82985871178763, 51.03459855488369, 58.861650466918945, 58.80803121839251, 62.968529156276155, 39.56089925765991, 39.90494973318917, 58.55815315246582, 55.49308735983712, 58.256413732256206, 56.52502339226859, 55.19651739937918, 44.04144859313965, 43.43763623918806, 43.892222132001606, 43.71818017959595, 43.86705923080444, 44.347742557525635, 44.19117185047695, 44.31441899708339, 44.284072739737375, 46.7869667325701, 48.98486260005406, 50.362693854740684, 49.743025711604524, 44.998298917497905, 44.21061985833304, 44.20295252118792, 43.40281881604876, 45.68605245862688, 45.426690101623535, 46.92441947119576, 56.773480551583425, 62.4598445892334, 59.587820598057334, 60.10523905072893, 57.86496959413801, 47.3239096232823, 48.20897463389805, 48.16509328569685, 54.33486434391567, 63.63139425005232, 62.76238305228097, 62.62573283059256, 60.67013454437256, 66.6232190813337, 60.608962603977744, 62.24549266270229, 63.759616306849885, 62.652705737522666, 61.742005348205566, 63.35247966221401, 61.24284676143101, 65.08389432089669, 65.76382419041225, 52.911036014556885, 13.907758355140686, 0.21903019478278501, 1.6933665403297968, 2.0393416668687547, 1.8322288947446006, 0.10634819804025547, 0.3147203108029706, 6.785632457051959, 52.65411247525896, 31.79887901033674, 20.02853332247053, 14.219495364597865, 21.926022086824688, 32.00061648232596, 59.59833322252546, 57.53549643925258, 61.08311462402344, 59.779563086373464, 47.620316301073345, 1.064901434949466, 0.07438302399324519, 0.028173393137486916, 0.0925793315150908, 0.082334592672331, 0.024518326856195927, 0.041912432959569354, 0.017223050817847252, 0.03698955622634717, 0.06229377591184207, 0.05670789582654834, 0.023434596169473867, 0.009066086195941483, 0.04385425090523703, 0.08222774376294442, 0.006631996607341404, 0.02221782851432051, 0.005369148790902857, 0.11800008959003858, 0.13396334515086242, 0.1566516019936119, 0.1267282755247184, 0.1917392449187381, 0.12848646832363947, 0.14605976534741266, 0.11705562312688146, 0.09872267222298042, 0.10714823153934308, 0.115992453747562, 0.21143951852406773, 0.14218614463295254, 0.16110273743314402, 0.20366380576576504, 0.15208389423787594, 0.42247506443943295, 0.1734512469598225, 50.812183243887766, 99.42296178000313, 82.19626522064209, 81.29600797380719, 57.92249373027256, 48.516355991363525, 35.94063418252127, 45.65027270998274, 43.69757529667446, 38.231601170131135, 1.5170207172632217, 0.14170298698757375, 0.6540680229663849, 1.620601964848382, 4.930672313485827, 3.552563347986766, 4.127128345625741, 4.57982953957149, 6.258032287870135, 86.72905458722795, 74.0069168635777, 79.69412163325718, 66.13266931261334, 65.09790188925606, 65.48849487304688, 67.88095419747489, 63.66428702218192, 66.86081968035016, 66.44541467939104, 62.4684534072876, 59.38660771506173, 59.12974670955113, 54.488561970846995, 51.65393665858677, 51.800772939409526, 52.25975009373256, 48.93032271521432, 51.74349546432495, 50.509735107421875, 55.42933416366577, 61.85583768572126, 66.20859922681535, 65.34012304033551, 67.35333578927177, 65.5938504082816, 65.9005925314767, 53.04831504821777, 49.56362322398594, 48.84942831311907, 51.76028231212071, 57.47566550118582, 62.341537611825125, 64.15641403198242, 65.45994472503662, 64.86066259656633, 64.99094826834542, 65.13802773611886, 60.27139827183315, 59.15023694719587, 63.37144824436733, 57.70453221457345, 53.062670026506694, 45.748079027448384, 47.27251727240426, 47.560718127659385, 51.509403705596924, 53.57727793284825, 61.927570887974326, 60.35603427886963, 64.95761775970459, 42.73507261276245, 45.02982289450509, 59.28875623430525, 58.09118209566389, 60.04537337166922, 61.00012534005301, 57.83542585372925, 45.772877148219514, 46.53716857092721, 46.65267889840262, 46.39039134979248, 46.78415618624006, 46.762797423771445, 47.23732464654105, 46.410325731549946, 46.484362261635916, 50.556934220450266, 52.33803197315761, 52.412329060690745, 51.89934703281948, 47.79449026925223, 46.91351079940796, 45.83374684197562, 46.689049243927, 47.67994574138096, 47.947107451302664, 49.33646924155099, 59.34512002127511, 65.85805565970284, 62.7528292792184, 63.267753328595845, 62.54309095655169, 49.41164527620588, 50.47922904150826, 51.45096240724836, 56.71780463627407, 66.57454695020402, 64.75107560838971, 65.27802004132951, 62.86369473593575, 67.51238700321743, 63.09748772212437, 64.84206921713692, 66.42926706586564, 65.03834193093437, 64.30620329720634, 66.56081730978829, 63.32299150739397, 69.26784242902482, 69.45069817134312, 55.31103413445609, 14.593324082238333, 2.2634373562676564, 6.973126990454538, 5.729701255049024, 2.3654788179056983, 0.3010101036301681, 0.33363349735736847, 15.94390971320016, 60.13366413116455, 40.561085496629985, 24.755710703986033, 27.083947828837804, 29.56219482421875, 29.28109155382429, 64.53616087777274, 62.12745666503906, 70.93725136348179, 68.55351202828544, 56.350088596343994, 0.9641803481749126, 0.18558323596205029, 0.10163518879562616, 0.1920985970646143, 0.19032846204936504, 0.10190637888652937, 0.1365636270493269, 0.07964796040739332, 0.09645132374550615, 0.1673527913434165, 0.16552061108606203, 0.20855054711656912, 0.12439307011663914, 0.1619827159281288, 0.14301363165889466, 0.17473673155265196, 0.1109140058979392, 0.08018105823014464, 0.20384228761707032], [0.06727421616337129, 0.02704737105939005, 0.05658568149166448, 0.022905954625457525, 0.019387923580195223, 0.018603844135733585, 0.06381922441401652, 0.014678680204919406, 0.021498245519718955, 0.03693871020472475, 0.04343370507870402, 0.014876960011731302, 0.09315428137779236, 0.029973789118230343, 0.05815055966377258, 0.07050977647304535, 2.838571671928678, 61.47159535544259, 69.33274555206299, 66.62685298919678, 53.926852226257324, 33.55599158150809, 10.398526362010411, 35.536290713718955, 43.05779211861746, 43.86782700674874, 15.113443647112165, 0.030503701219069104, 0.03647345231313791, 0.1625176186540297, 0.33765552725110737, 0.2756210059991905, 3.0091935907091414, 5.057853877544403, 0.1971651909074613, 30.685656002589635, 81.92696693965367, 64.12862818581718, 69.48070049285889, 60.536777768816265, 64.77465779440743, 60.45245443071638, 65.05819293430874, 63.372817039489746, 63.643421581813264, 60.14106396266392, 61.31243297031948, 57.16399710518973, 56.32678781236921, 51.417176791599815, 51.57286160332816, 46.461322035108296, 46.59667294366019, 44.54892069952828, 45.90431274686541, 44.972660064697266, 54.9341082572937, 59.94996765681675, 61.4506048474993, 60.24440452030727, 58.39463424682617, 60.756285258701865, 53.08421639033726, 43.55417142595564, 43.90161262239729, 44.014802251543315, 47.389465876988, 55.88583081109183, 60.78311225346157, 56.57615171160017, 59.26138728005545, 57.49710069383894, 59.44510459899902, 51.29104266847883, 56.362282684871126, 55.33816684995379, 53.43682009833199, 49.152137007032124, 45.611335005079, 41.084805965423584, 42.302696636744905, 43.13340241568429, 47.413464954921174, 50.16691793714251, 56.48744406018938, 54.6926930972508, 59.089037214006694, 40.0260568346296, 37.98739978245327, 59.43702384403774, 52.29583208901541, 58.10199349267142, 50.44578388759068, 43.37619679314749, 40.93676764624459, 40.2683231489999, 40.67692238943917, 45.09246090480259, 45.42035334450858, 42.95803683144705, 40.79286003112793, 41.42686925615583, 40.33283717291695, 42.660160609654014, 47.25366333552769, 49.33782761437552, 49.3184768812997, 46.19485167094639, 41.29191092082432, 40.80393198558262, 44.80600752149309, 41.314364024571006, 43.65961728777204, 43.00474957057408, 52.01187310900007, 59.033375195094514, 57.72591182163784, 58.723923274448936, 52.789029121398926, 44.406704970768516, 45.87554720469883, 44.53444760186331, 49.4655042375837, 57.686918531145366, 61.09837981632778, 55.741377762385774, 61.953689166477744, 59.38685785021101, 57.12737315041678, 57.2489527293614, 61.520059040614534, 59.76559025900704, 59.49214390345982, 57.3559376171657, 59.77837494441441, 61.70046206883022, 62.19953727722168, 62.31298746381487, 29.79655408859253, 0.5686297704066549, 0.556485730622496, 1.759261735848018, 0.6865501999855042, 0.24880150226610048, 0.0661487097718886, 0.16683616835091794, 35.3693220274789, 45.32742466245379, 28.172219855444773, 24.536279644284928, 20.65732271330697, 16.43455328260149, 22.52245545387268, 39.918005398341585, 55.39389140265328, 51.64312526157924, 54.754709243774414, 13.804274490901403, 0.4266356240425791, 0.05512259714305401, 0.14166982019586222, 0.04399952864540475, 0.050777550653687546, 0.06631366842027221, 0.08145880073841129, 0.10308535383748156, 0.04488782597971814, 0.0397947421297431, 0.01515020097472838, 0.06330524092274052, 0.027249540568196347, 0.03656527167186141, 0.0643808071368507, 0.06628263222851924, 0.04781518550589681, 0.03156456697200026, 0.03056477615609765, 0.025379555732277886, 0.061757651822907586, 0.023521524987050464, 0.10873000523341553, 0.06333433650434017, 0.031560889312199185, 0.04856882417308433, 0.07394767592528037, 0.047102554102561305, 0.02404207330463188, 0.04586403431104762, 0.08922529220581055, 0.030296632687428167, 0.09867632828120675, 0.08337511933807816, 4.862051469939096, 76.31355898720878, 74.57113143375942, 74.51675483158657, 61.85701193128313, 43.93642309733799, 17.91732665470668, 33.147527830941335, 40.92864172799246, 51.07323401314871, 22.154560497828893, 0.07912433493350234, 0.10434233317417757, 0.39342377760580605, 1.27047290120806, 1.2015131158488137, 7.191878429480961, 4.2618639043399265, 0.30694497802427834, 35.342724323272705, 85.29276466369629, 66.89915289197648, 72.6229885646275, 63.86201885768345, 66.12749985286167, 63.079714230128694, 68.38518496922084, 66.35215595790318, 65.17604133061, 62.6494539805821, 63.99324948447091, 59.92669119153704, 58.821191106523784, 53.37377561841692, 53.24064465931484, 50.34603554861886, 49.207343918936594, 47.43809284482683, 47.1263758114406, 47.38283729553223, 56.970993518829346, 62.30436474936349, 63.11203030177525, 62.12917981828962, 60.07826614379883, 62.58293192727225, 56.19369854245867, 45.667309692927766, 47.25875636509487, 45.09031391143799, 48.52861608777727, 59.19931207384382, 62.26376642499651, 58.48871980394636, 62.28230421883719, 58.22963537488665, 60.892330987112864, 53.035676274980815, 58.43041052137102, 57.61751297542027, 56.574973991939, 50.121553148542134, 48.03337281090872, 42.61826644624983, 44.223505292619976, 46.48828451974051, 49.279657295772004, 51.98432002748762, 58.84897000449044, 57.72774962016514, 60.14191164289202, 42.05377394812447, 40.38035590308053, 61.03781236921038, 54.760274750845774, 58.00282532828194, 52.74711411339896, 43.77971690041678, 43.119346209934776, 43.27156387056623, 43.63896724155971, 48.12198666163853, 48.07332147870745, 44.99128818511963, 43.01676300593785, 42.26246656690325, 42.615931851523264, 45.56625509262085, 50.005823952811106, 52.26961306163243, 52.06708696910313, 49.540482248578755, 44.60263722283499, 42.883451393672395, 46.27995320728847, 43.54891511372158, 46.006826468876426, 45.45525414603097, 53.096577235630576, 61.47577122279576, 59.71889836447579, 60.74564061846052, 56.084379059927805, 45.99020637784685, 47.84646279471261, 46.25956719262259, 51.741595132010325, 61.832575116838726, 62.053145681108745, 60.01307119641985, 64.59325422559465, 61.64748900277274, 62.09465421949114, 59.88428633553641, 63.284352575029644, 60.86441312517439, 62.9874768938337, 60.7819310597011, 65.54648453848702, 64.44251305716378, 65.6397293635777, 65.66440241677421, 33.59889670780727, 1.7345955222845078, 0.9926235590662275, 4.181319083486285, 1.889498118843351, 1.1727768863950456, 0.1350944358855486, 0.13588661194912025, 34.19620207377842, 55.25590712683541, 24.279891116278513, 19.631190163748606, 13.75635015964508, 21.992167200360978, 33.302882603236604, 45.82740313666207, 62.93878391810826, 57.56667995452881, 66.7592578615461, 23.051614625113352, 0.4951491504907608, 0.07921561824956111, 0.07301182685686008, 0.03519877678315554, 0.029981880648327724, 0.01627489142785115, 0.04241852508857846, 0.0504515043992017, 0.02588234339574618, 0.031048425739364963, 0.026718941450651203, 0.0519502661190927, 0.05421710233869297, 0.03545758021729333, 0.07743696761982781, 0.030634519377989427, 0.07824449893087149, 0.015799033122935464, 0.11690877457814557, 0.09809903068734066, 0.12736068373279913, 0.12615959532558918, 0.23631795070001058, 0.14933694020978042, 0.10966759135148355, 0.11897947346525532, 0.1787103276167597, 0.10874965560755559, 0.10686834262950079, 0.17852339121912206, 0.18075286730059556, 0.12741061033947126, 0.18680424615740776, 0.18246768814112457, 5.87481872524534, 90.98308917454311, 84.08671719687325, 85.7516098022461, 69.0701036453247, 50.0809965133667, 15.499468190329415, 49.72661059243338, 61.768992151532856, 64.68831947871617, 28.038694586072648, 0.23343138130647795, 0.24884794120277676, 0.9410492522375924, 2.162522371326174, 3.7340513808386664, 11.643494163240705, 15.981791291918073, 0.9143844544887543, 36.85845300129482, 89.09694508143834, 69.32576956067766, 76.00328023093087, 66.8112929207938, 70.70579992021833, 66.27649702344621, 71.03501946585519, 67.94230679103306, 69.50404644012451, 65.84001118796212, 68.70813029153007, 62.8255352292742, 62.517021315438406, 55.88083158220564, 56.89992386954171, 53.477015427180696, 51.09798002243042, 48.84224040167672, 49.93228074482509, 49.80678238187517, 58.818078313555034, 64.91623428889683, 64.56303650992257, 62.96166433606829, 62.65781961168562, 65.08920969281877, 57.09995903287615, 48.43391908918108, 49.47891426086426, 48.11416646412441, 51.1128317969186, 62.42867497035435, 65.28676782335553, 61.020289012363975, 62.35901233128139, 61.45480850764683, 62.58140332358224, 55.13406351634434, 60.25308976854597, 60.02662713187081, 60.00116893223354, 52.658583641052246, 51.12234040669033, 45.62736102512905, 46.963002817971365, 49.27463027409145, 51.414143902914866, 55.519994258880615, 62.34704753330776, 61.04072366441999, 62.08790751865932, 42.8048221043178, 43.62616171155657, 64.29344640459333, 57.50765153339931, 62.06036485944475, 56.17587641307286, 47.166981084006174, 46.37296526772635, 45.798734869275776, 46.3374981880188, 50.72654322215489, 51.15617118562971, 47.778624057769775, 44.9986115864345, 45.00303064073835, 46.327631746019634, 47.969095025743755, 51.32854904447283, 55.20215238843645, 54.648686681474956, 51.149024963378906, 47.368454524448936, 45.078046866825645, 49.17120286396572, 46.261689867292134, 48.032705783843994, 48.56258235658918, 57.52414655685425, 65.66254029955182, 63.417757987976074, 63.53444603511265, 58.54017816271101, 49.21892309188843, 50.27731786455427, 49.33376291819981, 54.83379711423601, 63.14608342306954, 65.36355931418282, 62.71441963740757, 68.96865994589669, 65.62765339442662, 64.05631133488247, 61.47999572753906, 66.63854680742536, 64.71748106820243, 66.17203085763114, 63.75025708334786, 67.10186658586774, 67.2083407810756, 68.9097878592355, 68.59622955322266, 36.492209979466026, 1.9935719285692488, 3.3043650090694427, 7.344984156744821, 2.835712488208498, 0.9596350320747921, 0.25196705811790054, 0.260384095034429, 44.36571407318115, 62.08721964699881, 42.99516453061785, 35.21340792519705, 32.432398387363975, 22.73404199736459, 35.726316996983115, 53.71640518733433, 70.7514773777553, 64.86069733755929, 78.48279353550502, 27.77338978222438, 0.9269902237824031, 0.19857885076531342, 0.30642603444201605, 0.13350788530494484, 0.19642234433974537, 0.18512880748936109, 0.1337061668080943, 0.20756264084151813, 0.12397547252476215, 0.12376262966011252, 0.14912803284823895, 0.2672378958335945, 0.14588496115590843, 0.11028703954070807, 0.17822573147714138, 0.22647551526980741, 0.13543910453362124, 0.1542756709137133], [0.028819502663931677, 0.02840072102844715, 0.014794102404266596, 0.04817633576957243, 0.040348643836166175, 0.035532917960413864, 0.04243619414046407, 0.03921675582283309, 0.03306436685046979, 0.028858630385782038, 0.06386322740997587, 0.03091929034729089, 0.10309797458882843, 0.06605328060686588, 0.1595813533557313, 0.21365667240960257, 26.93864188875471, 75.79881559099469, 64.30829470498222, 64.83020864214215, 48.44530718667166, 31.90285185405186, 29.033831221716746, 43.48180941173008, 42.21744224003383, 24.82871195248195, 5.360695455755506, 0.20832916828138487, 0.14228964836469718, 0.3195686335010188, 0.1653132779257638, 1.3174812644720078, 12.469066960471016, 5.296025965894971, 1.3710802112306868, 71.64787142617362, 70.52185331072126, 72.18418897901262, 64.00437355041504, 64.23964650290353, 62.55541706085205, 63.809087480817524, 61.08260045732771, 62.798604011535645, 61.60477842603411, 63.34516320909773, 62.10884244101388, 59.924210684640066, 56.484817641122, 53.38577863148281, 50.449786049979075, 49.94938373565674, 45.00946467263358, 47.460226331438335, 44.06815052032471, 46.22021606990269, 57.94796930040632, 62.19665377480643, 61.292158126831055, 58.81251975468227, 58.142063753945486, 58.546681676592144, 49.49316154207502, 43.17485189437866, 45.10412345613752, 43.37481410162789, 47.80115359170096, 58.986016273498535, 57.6577638898577, 57.689180169786724, 56.82332345417568, 58.19022519247872, 55.6676539012364, 52.60008675711495, 55.137290954589844, 52.63865968159267, 52.1743289402553, 45.814007009778706, 44.279045718056814, 45.24179853711809, 46.15891906193325, 44.02968529292515, 48.11476400920323, 52.987570422036306, 56.013649872371126, 54.6761668069022, 55.28552034923008, 43.42751966203962, 42.03235960006714, 58.775881903512136, 50.94423723220825, 51.788731711251394, 43.84313658305577, 39.06646892002651, 38.74784190314156, 42.86533049174717, 45.18031392778669, 49.96971763883318, 52.10168204988752, 46.36342191696167, 39.620900426592144, 42.21794251033238, 39.11405713217599, 41.34119101933071, 48.181365966796875, 49.38812909807478, 51.2647819519043, 51.37078019550869, 44.96527412959507, 41.65735489981515, 41.320117133004324, 42.152195181165425, 42.87019770486014, 43.04771375656128, 45.83939225333077, 54.258437633514404, 55.04539408002581, 58.278682708740234, 51.9783376285008, 43.81784861428397, 43.68803889410836, 43.69432006563459, 48.084063393729075, 57.17379753930228, 58.72517395019531, 56.00792455673218, 60.440434047154014, 59.96456582205636, 57.39003937585013, 59.219107491629465, 61.56055314200265, 60.72348281315395, 57.42163978304182, 59.26479884556362, 58.32088606698172, 62.32840551648821, 63.13915606907436, 62.32459790366036, 48.419352190835134, 4.1406760300908765, 0.6343119059290204, 1.1969962439366748, 1.3185516127518244, 0.5119964693273816, 0.07370072310524327, 0.11221142592174665, 5.707536501543863, 55.213908740452354, 35.67023808615548, 33.62702301570347, 31.197182382856095, 20.003200190407888, 19.192208187920706, 40.01527323041643, 52.89347096851894, 61.461430140904014, 47.655356066567556, 39.86993776048933, 1.9989520055907113, 0.18535230335380348, 0.028208536162440265, 0.056588086898305585, 0.05436026983495269, 0.07410848193934985, 0.022267327643930912, 0.04218603863513895, 0.03229322876515133, 0.09768936516983168, 0.011021984591414886, 0.07174671867064067, 0.051085530913301876, 0.02109765031907175, 0.05869052426091262, 0.09659366003636803, 0.05713741867137807, 0.020601313827293258, 0.02809135995006987, 0.04817841887207968, 0.07127004782004015, 0.05661671089806727, 0.041121902343417914, 0.01033391191491059, 0.06583862605371646, 0.06436043073024068, 0.010283102364545422, 0.06608843550618206, 0.02517020223396165, 0.03306265015687261, 0.0302146351230996, 0.029738093194152628, 0.1294815127870866, 0.07767776612724576, 34.69631603785923, 87.2690338407244, 69.92118154253278, 75.72997978755406, 55.16004630497524, 42.87263304846627, 31.332324845450266, 43.984952790396555, 41.80290923799787, 37.64189713341849, 7.239456653594971, 0.2396762647799083, 0.3495421037077904, 0.7337190232106617, 1.5221934339829852, 2.568128240959985, 7.631245596068246, 1.8269912557942527, 2.9875162967613766, 72.17446150098527, 75.29386220659528, 74.48602989741734, 67.73185975211007, 65.68467726026262, 65.56805174691337, 65.59551102774483, 64.02163982391357, 63.48287650517055, 65.52505629403251, 64.8200295312064, 64.8573135648455, 63.21204962049212, 60.16007423400879, 55.41946077346802, 54.25470297677176, 50.978926113673616, 47.09749909809658, 48.816306250435964, 46.62569556917463, 48.64699602127075, 60.34765475136893, 62.18909413473946, 63.431598799569265, 61.055842944553916, 61.77453681400844, 59.95748560769217, 51.07587432861328, 46.331036363329204, 47.932127135140554, 45.14597940444946, 50.309126717703684, 59.89277008601597, 59.216182300022666, 58.18948868342808, 59.25647490365164, 59.870772089277, 57.61042928695679, 55.758710043770925, 57.198536600385395, 55.11310427529471, 54.82625831876482, 47.96307441166469, 44.55817222595215, 49.414605208805625, 48.65700142724173, 46.67945725577218, 50.672844069344656, 56.0205911227635, 59.584033829825266, 57.062181677137104, 57.524949073791504, 45.07275233949934, 44.80289820262364, 60.29674530029297, 52.56860794339861, 55.49209029333932, 47.01113993780953, 41.40254013878958, 40.41025400161743, 46.05336202893938, 48.40294401986258, 52.98065349033901, 55.402583599090576, 49.244440351213726, 39.95539018086025, 45.117338929857524, 41.34520707811628, 44.202598163059776, 49.63032593045916, 51.978938647678916, 54.45861176082066, 53.52770253590175, 48.30545037133353, 42.7147456577846, 42.57945728302002, 44.37072025026594, 44.82116501671927, 46.035991532461985, 46.677570819854736, 59.322343826293945, 56.75877121516636, 60.568565777369905, 54.3133944102696, 45.838391712733674, 46.20231751033238, 44.46081754139492, 50.231202670506065, 59.22221333639962, 59.13358906337193, 58.30628095354353, 62.222521918160574, 62.2381067276001, 60.424133573259624, 59.4445834841047, 61.75308077675955, 63.41124752589634, 60.62409578050886, 62.88950729370117, 61.00937339237758, 65.27824933188302, 66.5364499773298, 62.08305072784424, 52.4963709967477, 6.293206240449633, 0.763933536197458, 2.593972282750266, 3.6843140040125166, 1.8442069377217973, 0.2451137187225478, 0.04261632143918957, 4.313692254679544, 63.00900936126709, 39.654626982552664, 30.572403839656285, 24.67113549368722, 17.576930931636266, 25.73329966408866, 50.14663961955479, 58.93712180001395, 68.60166304452079, 54.10406603131975, 54.68204845700945, 6.0556599242346625, 0.23948437507663453, 0.02017704114717032, 0.03570548298635653, 0.008469390982229794, 0.04206300327288253, 0.049013926181942225, 0.021807730430737138, 0.026575076759659817, 0.06356315886867897, 0.03270782383957079, 0.051455356247190914, 0.025965195914198245, 0.027394039689430168, 0.060080700021769316, 0.07362246766154255, 0.057953119544046264, 0.06334319817168371, 0.0974278984857457, 0.15265353795673164, 0.13352155100022042, 0.13262492125587805, 0.1174232941120863, 0.178245802542993, 0.1491909601858684, 0.12859842660171644, 0.11785486952534743, 0.1017390860776816, 0.1436646452971867, 0.1271103314523186, 0.20412918579365524, 0.12217807397246361, 0.3009691743978432, 0.35156161391309326, 42.16286414010184, 96.96863569532121, 82.88224002293178, 82.90931020464215, 63.44475868770054, 43.56399270466396, 41.829930782318115, 61.77086121695382, 61.93762493133545, 43.696439266204834, 9.345383558954511, 0.4282726033457688, 0.6532282680273056, 0.8567373135260173, 2.4506107526166097, 4.558051713875361, 24.793884107044764, 12.908200059618268, 2.3377294497830525, 77.93685272761753, 75.37431539808, 79.16242463248116, 70.01378713335309, 69.21459143502372, 68.6432341166905, 70.98298440660749, 66.16039957318986, 68.54552159990583, 67.82217243739537, 68.46599946703229, 68.21341855185372, 67.51351261138916, 61.27517672947475, 59.834822109767366, 57.026655537741526, 54.46543141773769, 48.560682024274556, 51.92790412902832, 49.52694368362427, 50.908686774117605, 62.61237839290074, 65.05995777675084, 67.38827133178711, 63.61377361842564, 64.02797658102853, 64.0445202418736, 54.83728163582938, 48.82901797975813, 50.634990283421104, 47.84248495101929, 52.55850873674665, 62.786187580653596, 61.08799920763288, 58.02175222124372, 60.5034681047712, 63.349491936819895, 60.55733054024832, 57.39985023226057, 58.62325777326311, 57.98884207861764, 58.24376106262207, 51.402780124119346, 48.877370493752615, 52.027346747262136, 51.054713589804514, 49.5037818636213, 52.58705193655831, 60.235267639160156, 61.50091675349644, 60.78650297437395, 59.54091330936977, 48.54706008093697, 47.20452567509243, 63.908627373831614, 55.71622180938721, 58.085679122379844, 48.82367828914097, 43.72519438607352, 42.978714670453755, 50.07457290376936, 51.141374996730256, 54.091677393232075, 59.60910293034145, 52.10797711781093, 42.380037035260884, 46.73709256308419, 42.8145808492388, 46.778681005750386, 52.42213296890259, 56.322632789611816, 57.95688731329781, 55.085026604788645, 49.48018230710711, 46.43168796811785, 45.9965500831604, 48.23173345838274, 47.63823570523943, 47.522482190813335, 47.935000215257915, 61.27929701123919, 59.34477955954415, 62.373096329825266, 57.03444446836199, 48.703867026737754, 47.99475472314017, 46.359642096928184, 53.100617613111226, 61.677887371608186, 63.91189997536795, 61.79247011457171, 66.42117241450718, 64.80481992449079, 63.2384249823434, 62.899380683898926, 65.94730527060372, 65.69487721579415, 62.01409680502755, 66.12190655299595, 64.64182213374546, 68.25553853171212, 68.75694833483014, 64.18276160103935, 56.77566923413958, 6.73764385495867, 4.501664910997663, 8.478847656931196, 6.132420148168292, 1.9630068029676164, 0.2397037861602647, 0.1394589359738997, 7.415079321180071, 68.50990513392857, 51.061529772622244, 44.99026679992676, 43.624244008745464, 30.449941839490617, 28.151257140295847, 56.22061933789934, 64.82134968893868, 78.21378013065883, 62.12311404091971, 69.45907075064522, 5.4439939345632276, 0.438967156623091, 0.12108856386372022, 0.20621322467923164, 0.18750312365591526, 0.10572388475494725, 0.09135263519627707, 0.11051497302417244, 0.09879225598914282, 0.1329079382121563, 0.20940698044640677, 0.1613310237548181, 0.17129275921200002, 0.11257978222732033, 0.19108109309204988, 0.22087252592401846, 0.10904470298971448, 0.24914310393588884], [0.045952786691486835, 0.07952340851937022, 0.07282831027571644, 0.057735777992222986, 0.030813561020685092, 0.03198404749855399, 0.017263929160045724, 0.03754515427031687, 0.04934657118948443, 0.02429700400015073, 0.031496869533189704, 0.04435681465214916, 0.1072128348584686, 0.027529726337109293, 0.045631049134369404, 0.4557289800473622, 55.3655948638916, 65.96289008004325, 61.870262145996094, 58.319037846156526, 39.08951262065342, 16.953371797289165, 23.8494119984763, 43.278272356305806, 33.89312512534005, 32.3213974407741, 2.1447397598198483, 0.006300509774259159, 0.16543222511453287, 0.40558065527251785, 0.47428582715136663, 1.4179455935955048, 5.190192307744708, 0.4166645519435406, 26.51480872290475, 79.95998055594308, 64.64829785483224, 68.72265202658517, 60.03738294328962, 65.0130921772548, 59.94508307320731, 61.29034464699881, 58.25945009504046, 60.595191274370464, 58.46569347381592, 59.733232498168945, 60.49428258623396, 60.34017154148647, 56.95437690189907, 54.56543336595808, 51.59739569255284, 49.75612654004778, 45.20047065189907, 46.73024163927351, 42.663791043417795, 48.47751208714077, 58.840090206691194, 59.55171080998012, 56.06999976294381, 59.02419662475586, 59.02302932739258, 53.58101953778948, 45.149710587092805, 42.55778932571411, 44.062258447919575, 42.63009922845023, 51.67278364726475, 58.913213048662456, 58.23735134942191, 55.61688688823155, 55.79572657176426, 54.17607021331787, 56.946897166115896, 56.64893756593977, 56.15995461600167, 55.293583733694895, 50.18633467810494, 45.002929891858784, 50.71914686475481, 54.58087573732649, 56.23500905718122, 49.15052849905831, 44.94447817121233, 52.94172273363386, 56.88094139099121, 56.43237263815743, 57.689892360142295, 43.024444239480154, 42.5839319229126, 59.50696441105434, 49.64086634772164, 50.99495908192226, 40.07851225989205, 42.18222876957485, 39.75371871675764, 45.08529731205532, 46.6596132005964, 53.2295310156686, 52.72192689350673, 52.2052275793893, 41.00499200820923, 40.434746401650564, 40.14298112051827, 41.506516456604004, 46.582710538591655, 51.10250677381243, 49.05643946783883, 53.55038840430123, 50.444005148751394, 43.974506173815044, 42.01067427226475, 42.06053801945278, 40.08157294137137, 43.652252197265625, 41.65509673527309, 50.33818061011178, 52.84485789707729, 53.89076328277588, 47.73841830662319, 44.413910252707346, 42.137134960719514, 43.62662724086216, 47.26965461458479, 53.01437309810093, 55.68230070386614, 57.31131975991385, 58.65435791015625, 56.20349202837263, 61.11720943450928, 60.16812719617571, 60.80689593723842, 61.175185203552246, 59.13870293753487, 61.304310526166645, 60.46999863215855, 61.572677748543875, 60.625909260341096, 58.9799713407244, 57.20527982711792, 13.452567969049726, 1.1405907677752631, 1.530652105808258, 2.611732312611171, 0.32722728539790424, 0.6560609617403576, 0.09662734930004392, 0.042984002602419684, 30.891666616712296, 53.14437389373779, 29.605131217411586, 38.67565359388079, 32.54109253202166, 21.993919883455547, 22.705642972673687, 33.26818677357265, 46.762224197387695, 53.02132824489048, 50.844638279506135, 31.730574744088308, 0.42775876234684673, 0.054446236829140356, 0.043893113998430114, 0.07418704272380897, 0.05544129486328789, 0.03762761323845812, 0.00692704738217539, 0.01174279912707529, 0.05809465516358614, 0.060769046656787395, 0.048109099734574556, 0.014976943843066692, 0.08775869983115367, 0.022388797286631804, 0.11027134502572672, 0.02582292238782559, 0.022525851182373505, 0.08925771260900156, 0.04378603099446211, 0.040916177311113903, 0.022749321601752723, 0.040232112232063494, 0.07778128342969076, 0.025388885588784302, 0.10081644808607441, 0.027248612671558346, 0.08880967593618802, 0.026475203190264956, 0.05195633561483451, 0.020739745149122815, 0.028771418279835155, 0.07902993035635777, 0.8143875002861023, 70.01518372126988, 75.5440320968628, 67.81721142360142, 65.25123473576137, 46.33291932514736, 22.70945927074977, 24.93954266820635, 32.72391700744629, 36.08748088564192, 38.15871109281267, 1.9721682199410029, 0.08271595649421215, 0.5920170811670167, 1.4695600696972437, 2.5844608502728597, 2.635566587959017, 2.281189352273941, 0.2963494908596788, 30.676446165357316, 82.881149155753, 67.24607644762311, 72.8978523526873, 63.79505211966378, 66.86680207933698, 62.900742530822754, 64.5269614628383, 60.4154691696167, 64.9044223512922, 60.82510716574532, 62.63038812364851, 61.849487032209126, 63.242371559143066, 60.157746587480815, 58.02634150641305, 53.058605330330984, 51.014660699026926, 47.97775248118809, 48.201748507363455, 48.22920431409563, 51.95444277354649, 61.8278294972011, 61.53542845589774, 59.762783186776296, 62.29038497379848, 62.09238910675049, 54.827908515930176, 48.12921278817313, 44.1650744165693, 46.58422177178519, 43.46275397709438, 53.05266114643642, 60.23486464364188, 59.78885282788958, 59.102982248578755, 58.587439809526714, 56.989315918513704, 59.91968045915876, 59.436565262930735, 59.519915853227886, 59.24527440752302, 52.933624608176096, 47.510194301605225, 52.58610003335135, 56.88144860948835, 59.1907935823713, 52.24475588117327, 47.6912956237793, 55.50764383588518, 58.12180280685425, 58.05044480732509, 58.26386220114571, 44.03789458956037, 44.22287648064749, 60.65771116529192, 52.462331771850586, 52.15812921524048, 41.99372066770281, 44.38943174907139, 41.609513078417095, 47.01873779296875, 48.87757199151175, 57.696916988917756, 55.95634807859148, 54.79389360972813, 43.760605880192344, 42.93192550114223, 41.81147289276123, 43.26134654453823, 48.02565336227417, 53.61048684801374, 51.94307899475098, 56.36852216720581, 52.77138417107718, 46.33345086233956, 43.107186862400596, 45.368644850594656, 42.664697783333914, 45.08842747552054, 43.78173882620675, 51.773605482918875, 55.817554337637766, 56.70991495677403, 50.008360045296804, 47.273451805114746, 44.82779359817505, 46.00590583256313, 48.74783175332205, 54.69955096926008, 59.62874548775809, 59.28658839634487, 61.60960047585623, 59.92748328617641, 62.82388850620815, 62.33898762294224, 62.661460467747276, 63.180560384477886, 63.19372027260916, 63.108535357883994, 63.31724534715925, 63.14923790522984, 64.31671592167446, 60.218022210257395, 58.84496784210205, 16.84146237373352, 0.8138358241745404, 0.5791724132640022, 2.767398233924593, 1.9037364976746696, 1.1652176805904932, 0.1849814025419099, 0.21458580398133822, 30.35041584287371, 62.021878787449424, 30.873497077396937, 40.84835181917463, 26.59880723272051, 29.17124400820051, 34.964884757995605, 41.234949588775635, 53.08230563572475, 59.28591442108154, 59.54187910897391, 46.29967566898891, 1.2682270045791353, 0.0497449458842831, 0.0638946367959891, 0.06943293461310011, 0.06633060465433768, 0.03620127834645765, 0.04011260185922895, 0.024684805423021317, 0.024072439443053942, 0.03174904707287039, 0.01802167296409607, 0.05849644288952861, 0.0032067955138960053, 0.05910312783505235, 0.026728373087410415, 0.057087227436048646, 0.030070463395012275, 0.18632164491074427, 0.2201417844210352, 0.20970048755407333, 0.10254040200795446, 0.10556261733706508, 0.15287156482892378, 0.1133981022451605, 0.16876516198473318, 0.23879959753581456, 0.15866223696087087, 0.10201645083725452, 0.20319516876978533, 0.18939960189163685, 0.20489094991769108, 0.1304373922092574, 1.7421941374029433, 81.1329823902675, 83.43849890572685, 78.37196281978062, 75.74139567783901, 55.08649614879063, 26.375610249383108, 33.369057246616904, 59.61157648903983, 49.88438333783831, 48.48104177202497, 4.415049535887582, 0.09998633512961012, 1.1582967319658823, 1.6478131732770374, 4.437750169209071, 3.1568697350365773, 14.960385254451207, 3.518083781003952, 32.016982964106965, 85.24308504377092, 69.43333462306431, 75.5270437513079, 66.33198533739362, 68.12651743207658, 64.9708332334246, 68.36874553135463, 64.32546370370048, 69.5839854649135, 63.640850748334614, 66.5460454395839, 65.76039178030831, 66.56436089106968, 62.50220080784389, 61.35697092328753, 55.07062646320888, 54.156719480242046, 49.73718227658953, 51.924099990299766, 48.16466249738421, 54.52310841424124, 64.72251851218087, 63.494007519313264, 61.147976057870046, 64.18769482203892, 63.874240739004954, 57.98231424604143, 48.97723695210048, 46.184821946280344, 48.39325475692749, 45.66188314982823, 57.56218794413975, 64.15686566489083, 61.14039557320731, 59.5755500793457, 60.095059939793174, 61.044969013759065, 61.84194128853934, 62.653483935764854, 61.297181674412315, 62.29706219264439, 55.22864934376308, 51.51713705062866, 54.85144206455776, 58.28723594120571, 61.82947622026716, 55.973954813820974, 50.19004849025181, 58.60882636478969, 61.982204573495046, 60.339928354535786, 59.84425776345389, 45.596427645002095, 47.1130040032523, 63.42799963269915, 54.51011528287615, 55.94262886047363, 43.815857955387656, 47.39131409781319, 45.21447474615914, 48.62587002345494, 50.779485021318706, 59.91221809387207, 57.438735825674875, 56.41424478803362, 46.66465064457485, 44.35460042953491, 45.258821623665945, 45.91965784345354, 52.43054723739624, 57.364397048950195, 55.76096820831299, 59.87150859832764, 55.19385623931885, 47.813215664454866, 46.52715621675764, 47.4878488949367, 44.96153947285244, 47.735395840236116, 45.70390932900565, 53.66249758856637, 57.36772871017456, 59.288992473057334, 52.4469484601702, 49.30610908780779, 46.26866238457816, 48.57359872545515, 52.31214298520769, 57.05493123190743, 64.6999021257673, 61.97684056418282, 64.37563664572579, 60.27473340715681, 66.35679735456193, 66.1366297858102, 62.82016427176339, 65.25930854252407, 66.04095309121269, 66.63137626647949, 67.77343082427979, 67.32153388432094, 67.20784051077706, 63.86154638017927, 61.064264161246165, 20.74239993095398, 2.988988663469042, 6.802056695733752, 7.074495996747698, 4.383855598313468, 1.3043785904135023, 0.3463815690151283, 0.2605576642921993, 39.582494258880615, 68.35680852617536, 40.80846568516323, 52.14319406236921, 42.80718101773943, 30.637914930071148, 34.352838788713726, 47.418200152260916, 62.623189789908274, 69.62785639081682, 72.46793256487165, 53.726792744227815, 1.1195274123123713, 0.1801976085241352, 0.1663426426904542, 0.1756431593426636, 0.1302413498716695, 0.2026865796319076, 0.12214308870690209, 0.11457683970885617, 0.10801755703453507, 0.160658649834139, 0.07223901618272066, 0.22864100549902233, 0.19826867883758886, 0.13657054810651711, 0.16569340681391104, 0.12242101665054049, 0.11011646262237004], [0.03569036183346595, 0.03903426043689251, 0.029857668027813946, 0.03138824964740446, 0.034989903348365, 0.08428169640579394, 0.02557457857100027, 0.04059827347685184, 0.021903361459927898, 0.12396871431597642, 0.05342997796833515, 0.08531846398753778, 0.024555827790339078, 0.14211629623813288, 0.26144068262406756, 10.503577045031957, 82.74728516169957, 67.05527196611676, 70.1084771837507, 51.041515486580984, 42.97541427612305, 23.56528799874442, 42.636957100459504, 52.96941825321743, 41.883303369794575, 26.8879999433245, 0.13249800806599005, 0.1431769821792841, 0.2876683681138924, 0.7169775015541485, 2.2537793602262224, 2.4474905771868567, 1.6034707469599587, 2.6165917090007236, 64.24000780923026, 72.09558555058071, 68.358156476702, 65.22415065765381, 65.92821856907436, 64.00253227778843, 69.38957486833844, 64.12157576424735, 60.205168042864116, 54.10566759109497, 58.68518706730434, 55.47222539356777, 56.64916685649327, 55.369961806706016, 56.943947655814036, 52.31360558101109, 50.98061452593122, 47.72790220805577, 45.92784629549299, 45.591873100825715, 44.47064924240112, 46.61113561902727, 58.191927501133506, 59.08871064867292, 60.49072510855538, 58.52630955832345, 58.13576521192278, 48.703252111162456, 44.261914934430806, 42.762344292231965, 42.74651282174246, 41.73483773640224, 49.890820843832834, 58.61070932660784, 58.92821420942034, 57.67085082190377, 52.97860377175467, 53.13158573423113, 55.69723585673741, 55.01262290137154, 56.458042757851736, 53.57703474589756, 50.56331614085606, 48.36392641067505, 52.75438887732369, 58.08825690405709, 57.11926807676043, 51.34080219268799, 47.86766869681222, 48.25584718159267, 55.15357058388846, 53.288114752088276, 56.573070185525076, 43.528306756700786, 44.644684246608186, 56.6791170665196, 46.911544459206716, 42.775771686008994, 40.954044342041016, 43.86497129712786, 44.96177223750523, 47.52824224744524, 47.90807941981724, 54.82677248546055, 53.51300014768328, 52.360047340393066, 46.67377710342407, 40.9196229662214, 39.950780051095144, 39.10475696836199, 41.22020551136562, 49.40787240437099, 49.16455691201346, 53.15682506561279, 52.72942052568708, 46.86180230549404, 40.51177413122994, 40.991971084049766, 42.12373883383614, 41.77796173095703, 43.49937445776803, 45.62218461717878, 49.9422653062003, 49.387885911124094, 45.96835429327828, 43.985783100128174, 42.60694088254656, 44.068028926849365, 46.37414298738752, 51.98951728003365, 55.76171513966152, 56.63080276761736, 57.360228129795615, 58.68145588466099, 59.509479658944265, 58.577510833740234, 59.16391795022147, 60.77369049617222, 59.30054037911551, 57.97636658804757, 60.105127879551475, 58.845030375889365, 58.91590894971575, 54.63016973223005, 67.59589045388358, 29.13514985357012, 0.89314126010452, 0.8241283861654145, 3.189637222460338, 1.7819623691695077, 0.9319631797926766, 0.09725127582039152, 0.09700848920536892, 4.896792462893894, 59.89364555903843, 40.115459305899485, 21.999240466526576, 26.61204355103629, 16.871885061264038, 15.48651327405657, 26.284543684550695, 31.734236444745743, 51.19796807425362, 45.43487507956368, 61.96423653193882, 14.643234729766846, 0.6534059356365884, 0.05191950473402228, 0.043445426771151166, 0.027698137032400285, 0.1052718311548233, 0.03802244258778436, 0.06317491470170872, 0.011031407746486366, 0.048683720507792065, 0.05661181187523263, 0.07761035367314305, 0.10560489685407706, 0.040399082736777406, 0.06355178662176643, 0.042877218153859885, 0.018201342251683985, 0.03284780222124287, 0.020346573121579628, 0.020725373777427843, 0.07692036498337984, 0.0708901903459004, 0.05392961044396673, 0.04677658248692751, 0.02594373724423349, 0.031463499180972576, 0.014859375776723027, 0.09038673381188086, 0.07733364030718803, 0.014450566909675087, 0.17608352856976645, 0.3686792882425444, 16.758719750813075, 96.37704522269112, 71.10090923309326, 80.19188363211495, 58.1189922605242, 54.643833364759175, 26.74367196219308, 24.695919718061173, 38.57064199447632, 50.16473967688424, 29.6626866204398, 0.21780807178999695, 0.23828833496996335, 0.7938047104648182, 2.3586063981056213, 3.0000143689768652, 3.44456793154989, 1.9120146249021803, 3.8459047845431735, 69.26315934317452, 73.35220895494733, 70.73593425750732, 68.74555328914097, 68.7439135142735, 66.7074590410505, 70.41178689684186, 68.22743306841168, 63.57444681440081, 56.597319398607524, 60.2309319632394, 58.750541823250906, 58.28398418426514, 58.59997435978481, 59.264375005449565, 55.70862742832729, 54.5253700528826, 49.48542472294399, 48.60358715057373, 48.325447286878315, 46.47805329731533, 48.42521299634661, 60.01384939466204, 61.62234347207205, 61.570892061506, 61.11836978367397, 61.10682882581438, 51.74177231107439, 46.353829928806846, 44.467494760240825, 44.617353507450645, 43.07354021072388, 51.3122798374721, 59.50301783425467, 60.44774355207171, 59.96557331085205, 55.78568295070103, 54.194903305598665, 58.45871748243059, 56.98705775397164, 58.61674036298479, 56.655802386147634, 54.31743131365095, 50.22054065976824, 56.85577848979405, 59.83237634386335, 58.651773180280415, 53.37212542125157, 49.900235652923584, 49.114491667066304, 57.844819818224224, 55.65623801095145, 58.862018721444265, 45.434614522116526, 48.74511153357369, 57.95978123801095, 49.93686308179583, 44.20570053373064, 43.46284777777535, 45.37019429888044, 47.433413233075825, 49.937700339726035, 50.51465790612357, 56.18221664428711, 55.8356648172651, 55.214950970241, 49.512397629874094, 42.67025981630598, 42.85727405548096, 40.30179609571184, 44.69330426624843, 50.26472772870745, 52.98579168319702, 57.12233918053763, 55.65903466088431, 49.00010347366333, 42.165091037750244, 42.30372149603707, 42.90798200879778, 42.77221768242972, 44.72875050136021, 46.92225858143398, 52.989647933415, 51.737950801849365, 47.35339777810233, 46.52822971343994, 45.486948353903635, 45.502331665584016, 47.85449838638306, 55.28441558565412, 60.2262419291905, 59.39904499053955, 59.10404532296317, 59.77800668988909, 61.51204776763916, 61.7687211717878, 61.367671149117605, 61.338558197021484, 61.43932097298758, 59.25655133383614, 63.03325162615095, 61.039514677865164, 60.02120753696987, 56.41877848761422, 69.63006591796875, 34.16734273093087, 0.6770719885826111, 0.346540129078286, 2.6322822613375525, 3.6376418684210097, 1.620829192655427, 0.4046410471200943, 0.04873917378219111, 3.931356336389269, 65.57508332388741, 46.72625684738159, 26.25712088176182, 27.232508999960764, 16.72947825704302, 23.44952232497079, 35.832297870091026, 40.205573967524934, 56.62858976636614, 53.02610513142177, 70.58263615199498, 23.505837474550518, 0.5005798733660153, 0.1652128276016031, 0.014126476532380496, 0.04579129535704851, 0.022873961699328253, 0.028973923663475683, 0.010927300118575138, 0.01793361608205097, 0.06772293815655367, 0.07311409565487079, 0.056061543723834414, 0.1077730537259153, 0.024389405202652727, 0.03218636967773948, 0.0521125716955534, 0.03864481865561434, 0.0854856346600822, 0.09149905626795121, 0.11288103820489985, 0.18959447714899266, 0.13081232351916178, 0.14730257008756908, 0.10069862048008613, 0.22636859172156878, 0.10176185771290745, 0.2340432841862951, 0.13910700700112752, 0.19891008442001684, 0.10692839297865118, 0.3770140867148127, 0.56353560090065, 20.96182404245649, 108.70150974818638, 82.394789150783, 90.90933404650006, 65.7104411806379, 57.56712116513933, 32.36084931237357, 60.54961803981236, 75.7239487511771, 58.964310101100374, 39.801786354609895, 0.3749873840383121, 0.2609155779438359, 2.024817326239177, 3.5800278399671828, 6.724159138543265, 6.8392334665570935, 7.216475921017783, 3.134622471673148, 73.7589009148734, 75.63385840824672, 72.60311671665737, 70.87055560520717, 73.38808945247105, 72.01930127825055, 72.9524929864066, 70.59910338265556, 65.92999730791364, 58.90866892678397, 63.56891604832241, 60.73226533617292, 62.05709225790841, 60.902767181396484, 62.3351800101144, 59.56887286049979, 57.52761370795113, 52.350278173174175, 51.0498046875, 51.55086708068848, 48.51158952713013, 49.657788685389924, 63.17334120614188, 63.621701513017925, 63.200077874319895, 62.09787123543875, 63.818940026419504, 53.377809047698975, 50.2948968069894, 45.07103613444737, 46.79105574744088, 45.781187193734304, 54.01899228777204, 61.3569153376988, 62.463964870997835, 61.5476016998291, 56.86958803449358, 56.834853989737375, 61.432886941092356, 60.30131721496582, 60.71285901750837, 59.41084997994559, 56.30971608843122, 53.430247102464946, 59.394313267299104, 62.73487513405936, 61.659613609313965, 57.23962824685233, 52.12246758597237, 53.790163789476665, 60.069087573460166, 59.51220335279192, 60.80823693956648, 48.053758825574604, 49.94916486740112, 61.301197733197895, 53.7027450289045, 46.540263993399485, 46.22034808567592, 48.48874385016305, 50.21945326668875, 51.31541347503662, 53.409604004451204, 58.93400205884661, 57.220086438315256, 57.377692426954, 52.42222676958357, 45.743670395442415, 45.489161355154856, 42.997509547642295, 46.72431829997471, 54.0064195224217, 54.32813848767962, 59.10767923082624, 59.36415113721575, 53.614457743508474, 45.007414954049246, 44.27202108928135, 46.528823784419465, 44.68097816194807, 48.651182310921804, 49.01927702767508, 54.41902787344796, 54.536077226911274, 49.690848214285715, 49.338425159454346, 48.407390866960796, 48.35469225474766, 51.50635344641549, 58.248600482940674, 62.98600387573242, 62.396615982055664, 61.40120315551758, 61.841982977730886, 64.43983105250767, 62.18905244554792, 65.25777299063546, 63.74919400896345, 63.576621600559776, 62.94671876089913, 65.99399021693638, 63.46098273141043, 61.71989618028913, 58.324096134730745, 71.88941860198975, 37.455212933676584, 1.504025848848479, 6.02124115398952, 9.158398849623543, 7.546884911400931, 3.1003596016338895, 0.47034402723823276, 0.21065103369099752, 6.46694985457829, 72.84568527766636, 53.29497609819685, 34.1025264603751, 34.53618785313198, 25.31039408275059, 22.986780984061106, 39.03179740905762, 45.649782861982075, 66.40173830304826, 60.78145163399832, 82.58768504006522, 27.65684243610927, 0.7170420438051224, 0.21948815163757118, 0.1606896181723901, 0.12119475459413868, 0.1911470466958625, 0.19713486039212771, 0.10678737983107567, 0.10735843490277018, 0.22522748581000737, 0.15885822501565727, 0.1951743420213461, 0.25872906669974327, 0.17294983672244207, 0.17103901425642626, 0.13650314243776457, 0.10741682284112487], [0.020837991930810467, 0.022990360989102294, 0.02302411471360496, 0.06918928625860385, 0.037884537130594254, 0.04029917524063161, 0.05405061698651739, 0.06087900325655937, 0.006420881462483001, 0.07124838219689471, 0.035006900650582144, 0.08452075786356415, 0.051796177601707835, 0.03648437672693815, 0.013067140027747622, 39.29155581338065, 76.35339995792934, 58.433988843645366, 52.66752944673811, 44.41753373827253, 14.182545713015966, 19.288616180419922, 50.24620730536324, 27.0125116620745, 48.18663270132882, 10.162522980145045, 0.02871693531051278, 0.5123290057693208, 0.25359364226460457, 1.073579843555178, 2.345862750496183, 2.875131355864661, 1.2913628774029868, 22.11871474129813, 75.43383366721017, 68.524947983878, 64.13158117021833, 66.49951335362026, 65.30307524544853, 70.0623619897025, 77.76080621991838, 62.87392943246024, 62.02433844975063, 60.33427252088274, 58.14463806152344, 50.79466336114066, 49.73411464691162, 48.474406242370605, 50.600513322012766, 47.86481646129063, 48.0100268636431, 48.326030935559956, 45.59431191853115, 43.33473341805594, 45.88911703654698, 43.235728536333355, 53.46980667114258, 58.812325205121724, 58.45718193054199, 59.09252520969936, 56.873096874782014, 47.49295929500035, 43.30660016196114, 42.78111137662615, 43.728063992091585, 41.20014953613281, 44.66172470365252, 53.88581963947841, 54.33873101643154, 49.996423040117534, 47.82076835632324, 50.59947109222412, 57.65144450323922, 57.280796323503765, 53.54805728367397, 54.856660161699565, 52.04936211449759, 50.90337140219552, 56.51214490618025, 54.026770796094624, 57.24149036407471, 55.09592832837786, 53.61250877380371, 51.52338000706264, 56.37501178468977, 51.94980485098702, 55.571275438581196, 38.48227480479649, 45.69784007753645, 55.840028285980225, 47.262800216674805, 44.60622596740723, 43.49304117475237, 50.76446649006435, 49.23443841934204, 54.412593841552734, 53.25653518949236, 55.39499964032854, 53.57542971202305, 53.122782366616384, 48.29531294958932, 43.18811253138951, 38.84999431882586, 41.43181984765189, 40.322661536080496, 46.082082407815115, 51.81951917920794, 50.20692219052996, 53.35538026264736, 52.409824235098704, 43.33130100795201, 38.82537685121809, 42.17327948978969, 41.86977522713797, 41.88101393835885, 43.06455618994576, 44.111847741263254, 45.99287796020508, 43.680406297956196, 41.647141047886436, 43.323008332933696, 42.25829069955008, 43.55828128542219, 52.827511719294954, 55.835439000810894, 53.9059659412929, 53.748582295009065, 56.786376408168245, 56.030575684138704, 57.34447308949062, 58.83744989122663, 61.06886386871338, 59.36788231985909, 59.88204206739153, 61.23487022944859, 58.75705228533064, 61.342365809849326, 62.32507732936314, 60.83554336002895, 58.198118346078054, 5.946039497852325, 0.5035849692566055, 0.37350451360855785, 1.366869711450168, 0.6221586923514093, 0.4584863835147449, 0.09052571813975062, 0.022810652685750808, 26.628903354917252, 57.44758783067976, 34.49663175855364, 25.843901089259557, 36.205475194113596, 26.339113099234446, 16.745137759617396, 32.79989903313773, 39.01891892296927, 53.70379768099104, 45.20653642926897, 39.880978448050364, 1.4031454963343484, 0.07818126625248364, 0.07152000655020986, 0.029422934034040997, 0.027396314478080188, 0.05852179295782532, 0.03811105926121984, 0.04348397095288549, 0.05203559189768774, 0.0466294421681336, 0.0411246232688427, 0.026030124930132712, 0.04244199222219842, 0.0845416160300374, 0.0986713342634695, 0.038343060562121015, 0.03961534425616264, 0.04007780658347266, 0.008354246134071477, 0.04909055992694838, 0.003670169198552945, 0.06646534813834087, 0.02737628751700478, 0.024374611442908645, 0.041170845074313026, 0.061350082978606224, 0.028008100310606614, 0.10782073438167572, 0.028635999653488398, 0.09436480142176151, 0.020510463077308874, 49.53258909497942, 86.33076994759696, 65.31795133863176, 59.78865133013044, 51.55232620239258, 23.359965256282262, 19.92477934701102, 54.2321560723441, 32.9291980607169, 56.49773434230259, 11.033256462642125, 0.26184207679969923, 1.1099328185830797, 1.7930718873228346, 3.026090524026326, 5.878101749079568, 2.843992135354451, 0.8750269806810788, 24.430625336510793, 80.092698097229, 69.34712137494768, 66.82933044433594, 66.78315966469901, 69.26258264269147, 72.31466920035226, 78.50720950535366, 65.41041796548026, 66.1083436693464, 63.128851890563965, 59.80342320033482, 54.25156933920724, 52.9268605368478, 50.45893335342407, 52.632041522434776, 50.13271542957851, 50.174658230372835, 51.22685520989554, 47.26870618547712, 44.91478157043457, 47.30333948135376, 44.48109933308193, 56.005426679338726, 61.11706352233887, 62.1073694229126, 61.39093371800014, 59.37774181365967, 50.147014822278706, 44.687533787318635, 44.860933031354634, 44.12494509560721, 42.89568369729178, 46.779844829014365, 54.41928148269653, 56.912277766636436, 52.959742886679514, 52.18815932955061, 54.00914669036865, 59.091635840279714, 58.06914240973336, 56.85686240877424, 56.589113576071604, 53.04143285751343, 52.487532888139995, 59.51723384857178, 56.30326121194022, 59.5195962360927, 58.67021369934082, 56.45236955370222, 54.492241042000906, 58.52435711451939, 53.945150307246614, 56.4296350479126, 39.61099576950073, 47.24785464150565, 58.00656345912388, 50.109101976667134, 46.61964021410261, 45.253968306950156, 53.10177101407732, 51.96123811176845, 55.394075529915945, 55.778338704790386, 57.378897939409526, 56.75536659785679, 55.8716321672712, 51.11550685337612, 45.976994378226145, 39.64305823189871, 42.224769115448, 40.70862354551043, 48.71020378385271, 54.01926326751709, 53.89340707233974, 54.53693185533796, 54.006593227386475, 45.55759416307722, 41.86323349816458, 43.687531675611226, 43.836772033146445, 43.34003489358084, 45.47030741827828, 46.551582608904155, 48.40571982519967, 46.55483783994402, 44.875725746154785, 45.09840508869716, 44.67045511518206, 45.222051756722585, 54.78846011843, 59.19536549704415, 57.251787594386506, 55.37373467854091, 58.81526429312569, 58.85585566929409, 59.90653446742466, 59.04985632215227, 59.8701536996024, 61.916363443647114, 62.06624303545271, 62.6683600289481, 60.67236491612026, 63.064289229256765, 64.70360551561627, 63.152253423418315, 62.96246337890625, 10.471983586038862, 0.061656305832522254, 0.8529640074287141, 2.4889263766152516, 1.9150711808885847, 1.0631106453282493, 0.08085869079721825, 0.08298902612711702, 25.95602069582258, 66.42705059051514, 34.92314692905971, 22.70282026699611, 21.8508460521698, 18.584322452545166, 23.084229469299316, 42.73972790581839, 47.25064434323992, 62.238558360508506, 53.849230425698416, 54.856205054691856, 3.6619690316064015, 0.1746572343898671, 0.04901991764615689, 0.0223001653461584, 0.04372404682050858, 0.07868890544133526, 0.015455624853659953, 0.061885779590478966, 0.06305570288428239, 0.037847947129713636, 0.021559434111363122, 0.035727314850581546, 0.02072942632782672, 0.031708792982889075, 0.08702577344541039, 0.030637426900544336, 0.1173231830554349, 0.06699387263506651, 0.0769738538988999, 0.16268778166600636, 0.06480768708778278, 0.11371226395879473, 0.11634176357516221, 0.10939610949052231, 0.06753132665263754, 0.15406837846551621, 0.14174713247588702, 0.27529278503996985, 0.15381282860679285, 0.1492779619459595, 0.08213038077311856, 56.57379974637713, 97.25798647744315, 74.46036325182233, 70.08895969390869, 59.83952604021345, 24.301911694662913, 30.51191282272339, 67.87052495138985, 40.91849735804966, 66.27061189923967, 14.93199838910784, 0.14543301612138748, 1.8121956097228187, 2.2755137596811568, 5.538838582379477, 7.1053208112716675, 10.975855657032557, 2.852034240961075, 28.48948849950518, 83.9188973563058, 72.30449703761509, 70.10537133898053, 70.61802332741874, 72.47851467132568, 74.28173201424735, 78.13667597089494, 68.77273464202881, 68.04286112104143, 67.19087300981793, 62.316121101379395, 57.06694119317191, 54.42026465279715, 52.47902829306466, 53.48730223519461, 52.57590355191912, 52.08603123256138, 53.43305764879499, 49.31815031596592, 45.96775674819946, 51.51667152132307, 47.12712621688843, 58.52823420933315, 64.41280950818742, 64.56296007973808, 64.20514174870083, 62.735729762486045, 53.521014894757954, 47.59843642371041, 46.74025746754238, 46.38050406319754, 45.27568142754691, 49.21861737115042, 58.527636664254324, 60.328880718776155, 55.330336230141775, 53.27429478509085, 55.380526542663574, 61.90747669764927, 60.338656834193635, 58.71819795880999, 59.57721069880894, 56.48811803545271, 54.82148838043213, 62.772812298366, 57.68594578334263, 61.541070393153596, 62.218491962977815, 60.321223803928916, 57.00640501294817, 61.81218910217285, 55.87980324881417, 58.1950090272086, 41.70938301086426, 53.87249299458095, 60.16903741019112, 52.5744583266122, 48.875723770686555, 50.19537081037249, 54.81602014814104, 54.280640602111816, 58.39402280535017, 55.62802137647356, 59.41464369637625, 57.58171238218035, 58.15072815758841, 53.3445063318525, 49.24736206872122, 44.08177246366228, 45.13514716284615, 43.065528937748496, 51.22814757483346, 57.64135571888515, 56.762811592647004, 56.58526079995291, 56.61859130859375, 48.07494388307844, 44.437259674072266, 46.03272587912423, 46.2877699307033, 45.674650464739116, 46.640686307634624, 49.516451903751914, 51.528646741594585, 49.78935282570975, 47.674724170139854, 48.84649269921439, 46.82648808615548, 47.997634751456125, 58.432161467415945, 62.30310017721993, 57.89942571095058, 57.62005254200527, 59.250381333487375, 60.870610918317524, 60.672017506190706, 63.863846233912874, 64.02195944104875, 63.579185485839844, 64.97954627445766, 67.26512840815953, 64.74192483084542, 66.06771060398647, 67.82470158168248, 67.13944244384766, 65.1353040422712, 12.591629709516253, 1.0072649334158217, 6.096384618963514, 4.502385786601475, 3.295231602021626, 1.6720115776572908, 0.2261711244604417, 0.2015122797872339, 33.425313336508616, 72.57294069017682, 48.30175392968314, 35.38833924702236, 48.60866975784302, 38.353830405644004, 24.592125790459768, 46.30238546643938, 51.461509772709434, 71.32704530443463, 60.16702938079834, 64.94585445949009, 3.7666610138756886, 0.3331412337720394, 0.22928775793739728, 0.10361782740801573, 0.10927479421453816, 0.20570520551076957, 0.12253042363694736, 0.09205555676349572, 0.16421812240566525, 0.13925252562122686, 0.11413813967789922, 0.10165601982069866, 0.13104024343192577, 0.15282409451901913, 0.18297607371849672, 0.09911785780319146], [0.03816439889903579, 0.06461062016231672, 0.038515808792518716, 0.08509689516254834, 0.026875342076112117, 0.055268638235117705, 0.048457038921437094, 0.07336918410978147, 0.04477387620136142, 0.04359534569084644, 0.129393873204078, 0.052267603376614194, 0.10555665979960135, 0.02725324367306062, 2.3997855484485626, 64.58388805389404, 65.58756923675537, 59.3143117087228, 46.19085645675659, 60.617112840924946, 47.88635587692261, 58.4355799811227, 38.41141012736729, 35.47237770898001, 48.37300770623343, 0.7671937612550599, 0.3362891748547554, 0.8006891810468265, 0.4825329588992255, 2.1177972512585774, 3.3816404853548323, 2.3777756094932556, 1.3783950358629227, 42.73229333332607, 68.910475730896, 69.85472202301025, 66.38370772770473, 70.69746903010777, 66.26434462411063, 73.05391584123883, 67.32009560721261, 64.30211080823625, 64.23447009495327, 61.34737546103341, 62.619812965393066, 59.650326592581614, 55.69972331183297, 52.929823943546836, 47.91010134560721, 47.05278049196516, 46.02733407701765, 47.757494585854666, 47.49456780297415, 45.64403322764805, 45.71192755017962, 44.464229106903076, 47.98439843314034, 58.180813857487266, 59.259101322719026, 59.31178951263428, 55.47544240951538, 47.02354942049299, 42.48590326309204, 43.16126816613333, 41.038259983062744, 42.40947307859148, 42.232269695826936, 44.26047665732247, 46.151171820504324, 45.58519240788051, 49.07156569617135, 53.4445812361581, 54.029609135219026, 54.216189111982075, 53.69695370537894, 54.8548640523638, 54.64777994155884, 54.116656167166575, 55.12801510947091, 50.33350099836077, 51.207521847316194, 54.288801261356895, 57.76301867621285, 55.13681500298636, 54.7652461869376, 54.06559385572161, 50.98546436854771, 38.85277707236153, 44.68659578050886, 56.987568446568076, 48.592699323381694, 47.45864561625889, 44.81727402550833, 52.30854729243687, 50.306510720934185, 53.62715557643345, 53.30699300765991, 52.13990409033639, 51.96684183393206, 52.56050286974226, 47.97987168175833, 50.19990103585379, 43.88364805494036, 39.70046772275652, 38.39764922005789, 43.49239499228341, 49.099407127925325, 50.10705573218209, 51.96190166473389, 53.29306186948504, 46.1076899937221, 41.72860867636544, 39.2454753603254, 40.825099672589985, 41.003112520490376, 42.7622400692531, 42.48425654002598, 43.38127245221819, 41.28615781239101, 41.091007232666016, 41.2425856590271, 42.44501658848354, 41.76063639777047, 54.24393674305507, 54.753903252737864, 56.81962701252529, 51.24711615698678, 56.73377507073538, 59.07056195395333, 58.42994499206543, 57.04648569652012, 54.898738452366416, 56.80619614464896, 57.45184360231672, 56.77569702693394, 58.38501793997628, 55.6189227104187, 55.28494712284633, 58.10533905029297, 61.93069062914167, 44.5482953616551, 0.7697395160794258, 1.2961558316435133, 2.195138518299375, 0.3633902706205845, 0.4504370040127209, 0.0473683803741421, 0.04746758897921868, 3.006569125822612, 51.048241342817036, 46.62012658800398, 36.0316937991551, 49.656812463487896, 80.4336462020874, 44.83838612692696, 22.68771835735866, 35.94416734150478, 45.84351600919451, 46.588644300188335, 54.86606107439314, 18.289538179125103, 0.0716620103589126, 0.04009529921625342, 0.06822396841432367, 0.05284710281661578, 0.0626934737499271, 0.07579401042312384, 0.04568290617316961, 0.08195887426180498, 0.061212435364723206, 0.03260895110932844, 0.04635437424959881, 0.03832842116909368, 0.057931949251464436, 0.04766159910442574, 0.018470140506646464, 0.05433312504153166, 0.025812457681500485, 0.09935602359473705, 0.0320498586100127, 0.008935990676816021, 0.029405845129596334, 0.025183674546756914, 0.024655894742214253, 0.06522844665284667, 0.005791964741157634, 0.05619101838341781, 0.021218950328017985, 0.14637528413108417, 0.051970496640673707, 3.3450247815677097, 77.5485040119716, 74.10720021384103, 67.6339943749564, 52.24571473257882, 71.28712790352958, 43.41321679524013, 39.04068415505545, 33.781147956848145, 41.350112506321494, 57.799382073538645, 1.1808137808527266, 1.4346814155578613, 3.280088871717453, 1.5616007936852319, 3.5792739604200636, 9.707230108124868, 3.0715510674885342, 2.069894850254059, 48.80380296707153, 73.1367244720459, 70.44147654942104, 69.26916953495571, 74.3264992577689, 70.39974566868374, 72.99334839412144, 68.79008429391044, 66.47290870121547, 67.79189218793596, 65.18899972098214, 63.290355818612234, 62.95785672324044, 57.12027209145682, 52.369701862335205, 50.12653848103115, 49.697209290095735, 49.423377309526714, 48.604577268872944, 49.006864070892334, 46.16908427647182, 46.38959925515311, 46.65722302028111, 50.029687540871755, 58.744538579668315, 59.560097285679404, 59.87269674028669, 57.71314798082624, 48.76156139373779, 44.082776478358674, 44.555792467934744, 44.89702892303467, 45.050042152404785, 43.425831249782014, 45.6745879309518, 48.667826720646445, 45.49349355697632, 50.453927176339285, 55.1943530355181, 57.22321660178048, 55.209545271737234, 54.38870940889631, 55.32950939450945, 57.15343931743077, 56.822479248046875, 58.292377608163015, 50.216993604387554, 51.68596090589251, 55.2556917326791, 59.25869137900216, 55.144701208387104, 56.540827069963726, 55.650286878858296, 51.14028065545218, 40.79371813365391, 46.958569867270334, 58.862456457955496, 50.03279685974121, 48.94024126870291, 48.343516077314106, 53.529529912131174, 52.68922867093767, 53.96218729019165, 55.76816306795393, 52.77142586026873, 55.709162439618794, 54.85270663670131, 51.34450905663626, 52.424085412706646, 47.51346342904227, 42.22744764600481, 40.45129701069423, 45.84143154961722, 51.38897057941982, 53.5787787437439, 53.74801254272461, 55.39282832826887, 49.60113307407924, 43.25155305862427, 42.00032145636422, 40.98213938304356, 41.89985745293753, 45.000699520111084, 46.054675238473074, 45.95161260877337, 43.995402881077354, 44.19226271765572, 43.94191564832415, 44.24913372312273, 45.52461453846523, 55.624053955078125, 59.37444141932896, 58.739376068115234, 54.50111041750227, 57.85484259469168, 61.29133823939732, 60.211650712149485, 59.28332274300711, 56.33831834793091, 59.50817339760916, 60.81262820107596, 59.26977375575474, 59.431076186043875, 59.11750398363386, 57.61613375799996, 61.382137298583984, 64.59119755881173, 49.0028966494969, 2.031331479549408, 0.24529325908848218, 2.0171721364770616, 1.9456067766462053, 1.4912317182336534, 0.4684299613748278, 0.07695019338279963, 2.0640299192496707, 55.80867106573922, 53.88528462818691, 28.712979044233048, 41.26343720299857, 67.27147906167167, 45.11471251079014, 31.34450156348092, 44.388698714120046, 53.92649091993059, 52.994129521506174, 66.06186022077287, 26.302082674843923, 0.04199223546311259, 0.05574054576988731, 0.02756364630269153, 0.008772752114704676, 0.026984911910923462, 0.06463527133954422, 0.027314476369481002, 0.06307542111192431, 0.016912176606378386, 0.035398639272898436, 0.023407478517453586, 0.004216570124429251, 0.04985643597319722, 0.03708755025374038, 0.047775447102529664, 0.11580251822514193, 0.2432523886007922, 0.11321560346654483, 0.1568435595503875, 0.09533903521618672, 0.15984347143343516, 0.1645238838557686, 0.08502047854874815, 0.14575287752917834, 0.11485429267798151, 0.18481689851198876, 0.14415392332843371, 0.2635277749172279, 0.14240432078284876, 4.453674137592316, 87.46682126181466, 82.8922871180943, 75.94587421417236, 61.554362297058105, 71.71591513497489, 57.80990512030465, 77.05015836443219, 55.65726287024361, 52.874721254621235, 68.23892538888114, 1.6115747349602836, 1.4753652896199907, 3.5425533822604587, 2.2883616302694594, 6.67953303030559, 8.209321822438922, 8.556450349943978, 2.7591809034347534, 52.68100547790527, 73.64442934308732, 74.74941526140485, 71.17109993525914, 76.6229692186628, 71.02398572649274, 76.91975457327706, 69.33775520324707, 70.57367992401123, 70.36016178131104, 67.27096489497593, 66.01999037606376, 64.90546458108085, 59.57337529318673, 56.24265207563128, 52.09195457186018, 52.97195087160383, 51.027785846165244, 51.82067952837263, 51.327051707676475, 49.77556759970528, 48.76227010999407, 50.277151107788086, 53.00265496117728, 62.78903634207589, 61.93645763397217, 64.42640018463135, 60.59164769308907, 51.39066593987601, 45.50458983012608, 46.955860069819856, 45.91324118205479, 47.37562506539481, 46.921456064496724, 48.919817038944785, 51.63189002445766, 46.68970932279314, 52.96671540396554, 58.03231348310198, 59.597958019801546, 57.526689597538535, 57.00625215257917, 59.158463614327566, 59.54819502149309, 59.85754271915981, 59.373433930533274, 52.23277718680245, 52.352327891758506, 57.35306453704834, 61.02466637747628, 58.63591044289725, 59.30951745169503, 58.30160481589181, 52.84444795336042, 42.33121204376221, 49.899044036865234, 61.68859454563686, 52.35123355048043, 52.23683840887887, 51.75021437236241, 56.70875113351004, 54.833328110831125, 57.70890610558646, 57.26465218407767, 54.52922282900129, 57.495304584503174, 56.809357575007844, 52.27087415967669, 56.18805660520281, 49.832612310137065, 44.05791234970093, 42.31571061270577, 48.499006339481895, 55.71731615066528, 57.27518565314156, 54.55002226148333, 58.02109214237758, 51.983312538691926, 44.75564002990723, 43.53088106427874, 42.11929893493652, 43.95213992255074, 47.020947320120676, 47.94249037333897, 47.35457897186279, 46.62928083964756, 45.851940699986045, 45.85355615615845, 46.73379911695208, 47.35934543609619, 58.797087805611746, 62.019231523786274, 61.774780000959126, 55.201975209372385, 59.47944259643555, 64.65938023158482, 62.66118948800223, 61.97308158874512, 61.4100273677281, 61.55914265768868, 62.422213145664756, 62.696833746773855, 63.351256779261995, 61.24000494820731, 59.955345562526155, 64.9919627053397, 66.23733697618756, 52.85398783002581, 3.3350575906889777, 3.702252081462315, 6.918101600238255, 3.128411650657654, 2.133927277156285, 0.5835833794304303, 0.1841836217790842, 4.247951005186353, 63.934884616306846, 61.22314861842564, 47.77557379858834, 57.70129435403006, 91.02303436824253, 54.71463898250035, 35.12895951952253, 49.67201164790562, 61.785299573625835, 61.89112063816616, 78.64181695665631, 33.099112783159526, 0.15138304898781435, 0.14377540935363087, 0.15090321616402694, 0.14114660184298242, 0.17715317117316381, 0.1331154206501586, 0.132274525772248, 0.21409876511565276, 0.16650987443115028, 0.09808012670172112, 0.18022903826619896, 0.11192642764321395, 0.1610005907714367, 0.21584980615547725, 0.12485416180321149], [0.06515542949948992, 0.05714024816240583, 0.16212091994072708, 0.05408484907820821, 0.03096689297152417, 0.06172332473631416, 0.042184159093137295, 0.06342060544661113, 0.062128206581941674, 0.01780742553195783, 0.08675855956971645, 0.029704471783978597, 0.1367243312831436, 0.12656869765903267, 8.518456731523786, 73.3595323562622, 58.4382689339774, 52.945679732731406, 34.199710914066856, 27.80008476121085, 41.10958671569824, 70.96157700674874, 42.071682929992676, 48.734619753701345, 29.5596205166408, 0.1422938552818128, 1.5828723779746463, 1.7604465122733797, 1.191458638225283, 1.970177561044693, 10.818114178521292, 1.8048507124185562, 8.13529658317566, 68.26770482744489, 67.0975170135498, 65.13547774723598, 68.34204360416958, 67.77351420266288, 66.62690162658691, 62.24453381129673, 59.065371649605886, 63.40375736781529, 63.517221450805664, 64.3990034375872, 60.56678009033203, 60.30966200147356, 59.96264811924526, 61.79640974317278, 57.29105186462402, 49.662763595581055, 45.072415351867676, 45.343457630702424, 44.77822167532784, 45.85160023825509, 45.21299130575997, 45.8780311856951, 44.72919518607003, 53.77907446452549, 56.87129034314837, 58.18291221346174, 54.13536419187273, 47.011838231767925, 43.31248181206839, 42.73398869378226, 42.691288539341514, 43.582853589739116, 41.36541591371809, 44.375997407095774, 45.24906982694353, 46.01446601322719, 47.011487347739084, 50.672183990478516, 54.69359636306763, 57.12913799285889, 53.71237175805228, 56.44296169281006, 51.89889539991106, 55.71800054822649, 51.489980016435894, 54.804840496608186, 55.258210454668315, 52.74203150612967, 50.92332662854876, 50.922447681427, 55.51216016496931, 53.62111064365932, 58.52476705823626, 43.09487812859671, 40.173640046800884, 58.75470379420689, 46.74844939368111, 48.48677403586251, 45.70745985848563, 52.62230709620884, 52.49632235935756, 50.73428698948452, 49.39362512316023, 53.21682970864432, 48.67729364122663, 53.61187996183123, 51.91770417349679, 53.96954543249947, 47.414708682468955, 42.05508368355887, 38.222940240587505, 41.7225672176906, 46.727563108716694, 51.02991546903338, 47.269310678754536, 54.909893785204204, 50.95646258762905, 41.703206062316895, 38.16369295120239, 39.679195812770296, 40.509745257241384, 43.2100236756461, 40.488633155822754, 40.712403365543906, 40.247891971043174, 41.61383138384138, 38.4380738394601, 41.278622491019114, 43.36510051999773, 50.26188938958304, 53.775329385484966, 58.083021436418804, 58.90064375741141, 58.070323603493826, 54.213281290871755, 58.44523102896554, 52.38648523603167, 53.56112337112427, 55.868404729025706, 58.556819098336355, 53.92752620152065, 57.85000317437308, 53.11990928649902, 55.555110454559326, 54.80668871743338, 61.364704268319265, 50.46784789221627, 20.416451249803814, 0.4194414700780596, 0.3487218905772482, 0.60407904535532, 0.5534331915634019, 0.6055596630488123, 0.15841913143438952, 0.15835304212357315, 20.107155663626536, 56.985167843954905, 42.42204931804112, 70.66650785718645, 86.48577730996269, 78.59146336146763, 26.304243564605713, 23.005051272256033, 39.688131196158274, 46.83628852026803, 42.89403697422573, 33.52428000313895, 0.07976301280515534, 0.030726172495633364, 0.0692624051922134, 0.033016659053308625, 0.0463713953005416, 0.04946920960875494, 0.009519157598593404, 0.08037742626454149, 0.01344735118826585, 0.07168328921709742, 0.1106830257922411, 0.04811928793787956, 0.06650085587586675, 0.07732453436723777, 0.12161258288792201, 0.012861366649823529, 0.010736904888679939, 0.03631886507251433, 0.07508036800261055, 0.01673222572675773, 0.00768342351407877, 0.05797386235956635, 0.05185897941035884, 0.048830820114484856, 0.06287904629217726, 0.052170963026583195, 0.03515032599014895, 0.1974299688424383, 0.3812546863087586, 12.30956324509212, 84.69125216347831, 63.796198572431294, 60.75952311924526, 37.617832047598704, 38.501024518694194, 45.45771033423287, 65.3502118246896, 41.9380829674857, 54.71772745677403, 33.46827752249581, 0.23869428890092032, 1.5713016731398446, 4.289696650845664, 2.5764000713825226, 2.9434783969606673, 8.595326389585223, 1.2589411714247294, 9.902735045978002, 71.49346855708531, 70.1517505645752, 68.3024319240025, 69.74541296277727, 68.86923122406006, 67.52260085514614, 63.1299774987357, 61.227734429495676, 64.3493516104562, 65.92516136169434, 67.84868676321847, 63.3322743007115, 63.66731643676758, 64.46433734893799, 63.644394329616, 60.81255871909005, 52.37655973434448, 46.114085810525076, 47.60569034303938, 46.489045347486226, 47.72417449951172, 48.10884414400373, 47.56791646139962, 47.35799053737095, 55.122432231903076, 59.471389634268625, 60.08638163975307, 56.86967141287667, 48.95663554327828, 44.915455545697895, 45.431876931871685, 43.241294043404714, 44.81839268548148, 42.697969232286724, 46.38073335375105, 47.312990529196604, 47.01847723552159, 50.15856620243618, 53.27967963899885, 58.72755023411342, 59.16072872706822, 56.291890484946116, 56.4529254095895, 53.00444412231445, 56.1729234286717, 54.519088881356375, 55.5490585735866, 56.34196267809187, 52.645538398197715, 52.15595095498221, 53.17744384493147, 57.54826375416347, 56.06921809060233, 60.29151330675398, 43.85967329570225, 42.32001849583217, 59.57929515838623, 49.19751569202968, 50.63072061538696, 48.01812498910086, 53.881344999585835, 53.13114104952131, 52.282894543239046, 51.99434280395508, 53.11609125137329, 50.16872794287545, 54.15166119166783, 55.34787695748465, 54.83813279015677, 51.415693351200645, 44.803839683532715, 41.51446866989136, 42.70679691859654, 48.05038547515869, 52.88586963926043, 50.51827791758946, 57.176281520298545, 53.48871966770717, 43.4970885004316, 40.48070526123047, 42.45088086809431, 42.48058441707066, 44.88541153499058, 43.44956629616873, 42.9992014339992, 44.392127650124685, 44.4533725466047, 41.27663878032139, 43.03851434162685, 46.86809389931815, 53.676036153520855, 56.72977985654558, 58.74480955941336, 58.129775864737375, 61.75621441432408, 57.4778333391462, 59.654238428388325, 55.049594266074045, 55.62743772779192, 58.53562709263393, 61.955850056239534, 57.66511160986764, 58.85278456551688, 54.51304047448294, 57.08176864896502, 57.84558759416853, 63.50821658543178, 55.846493584769114, 28.078059605189733, 0.5410993791052273, 0.7320834824017116, 0.4078731808279242, 1.3101594916411807, 1.1286379120179584, 0.2773863641279084, 0.280852700982775, 19.461362293788365, 64.59569304330009, 43.05210501807076, 65.66431209019252, 90.07576560974121, 77.84811728341239, 34.26624338967459, 32.84901932307652, 44.50361149651663, 56.10039813177926, 50.61287416730608, 47.63818359375, 1.1824248944010054, 0.036135714900280745, 0.07539317264620747, 0.054484848864376545, 0.07324602321854659, 0.02489077642426959, 0.03166856264163341, 0.014795685087197592, 0.039842066554618735, 0.03202701233593481, 0.060916743374296596, 0.07584079541265965, 0.04019120674846428, 0.047378901059606245, 0.07247758230992726, 0.22611984078373226, 0.10439146589487791, 0.15033611016614096, 0.15030964730041368, 0.09366819701556649, 0.16085490930293286, 0.3392580912581512, 0.15568444531943115, 0.146186000002282, 0.10027753521821328, 0.1500406488776207, 0.1543108190276793, 0.332469429820776, 0.6831589362451008, 15.975418056760516, 95.04225458417619, 73.7063238961356, 70.91844258989606, 48.37898663112095, 39.81030832018171, 49.48742233003889, 82.39175278799874, 62.004730633326936, 65.7213568006243, 41.36061123439244, 0.5191127817545618, 3.8150044083595276, 7.456146648951939, 4.029280773230961, 8.596553615161351, 23.773294482912334, 6.694859019347599, 10.210604514394488, 74.62691157204765, 74.0757109778268, 73.44389043535504, 72.14198562077114, 75.8693675994873, 68.7581364767892, 68.9086275100708, 63.650154386247905, 66.266512462071, 67.98358603886196, 69.71630001068115, 64.03731495993478, 66.31027221679688, 65.07028974805559, 67.61911133357457, 62.11000279017857, 54.595578125544954, 48.522091729300364, 50.057549817221506, 49.29745858056204, 50.07436793191092, 50.22655085154942, 51.502389499119346, 49.95693295342581, 58.69815240587507, 61.52832044873919, 63.72338145119803, 58.76788452693394, 51.17831856863839, 48.40536199297224, 47.58398069654192, 46.049839292253765, 48.02372176306588, 44.121175697871614, 49.88280609675816, 49.372836112976074, 50.94846521105085, 52.6922024999346, 56.184374059949604, 60.0722142628261, 61.48721490587507, 56.275972161974224, 57.46266542162214, 56.365037645612446, 59.34019374847412, 55.377483231680735, 57.14907237461635, 58.35131222861153, 54.85399900163923, 52.832830565316335, 56.18212979180472, 58.454312324523926, 58.09083121163504, 62.74863256726946, 46.94880070005144, 45.19743776321411, 61.581786836896626, 51.13876594815935, 53.76913506644112, 52.262751715523855, 56.105782985687256, 55.63875634329659, 53.648441382816856, 53.79177924564907, 55.59482635770525, 51.75851746967861, 56.51432316643851, 58.11801603862217, 56.11395059313093, 54.556435448782786, 47.01083769117083, 43.520622049059185, 45.014095646994456, 51.90710122244698, 56.219789028167725, 52.43734952381679, 60.03018460954939, 57.69918557575771, 47.16563660757882, 41.91304165976388, 43.3094801902771, 45.32988085065569, 47.920329093933105, 45.75704915182931, 44.895156383514404, 47.26955039160592, 46.08548355102539, 43.40327044895717, 45.589156355176655, 48.68511036464146, 54.960136209215435, 59.68774264199393, 61.53980582101004, 61.86855983734131, 64.02422455378941, 59.88951138087681, 62.65857001713344, 57.29890332903181, 59.775053705487935, 62.71204335348946, 63.983515058244976, 58.30804579598563, 62.85614204406738, 57.904247760772705, 60.53265748705183, 60.79738385336739, 66.41564859662736, 59.30111707959856, 30.718698160988943, 0.714025657091822, 5.697861569268363, 5.963530285017831, 2.8483699347291673, 1.7391942526612962, 0.47322964668273926, 0.35590871636356625, 26.027609722954885, 72.38884122031075, 54.64741168703352, 73.60298333849225, 87.03319113595145, 82.59737082890102, 33.699478830610005, 34.82581308909825, 51.77177463259016, 65.92161083221436, 59.68858337402344, 60.35515185764858, 2.287457061665399, 0.2727455917213644, 0.1243251623319728, 0.26761904252426966, 0.1105876373393195, 0.22598288527556828, 0.10002994457525866, 0.18900413811206818, 0.11136203578540257, 0.2408863641321659, 0.23309466508882387, 0.34362099000385826, 0.10701658217502491, 0.14304476284555026, 0.2102307491004467], [0.07185178981827837, 0.023200694970520477, 0.04092256571831448, 0.03842441012550678, 0.04058952037511127, 0.055670385248959064, 0.10953391995280981, 0.09006052810166564, 0.03460274823009968, 0.010010847821831703, 0.21346194642995084, 0.034417589594210894, 0.2188309361892087, 0.06870578256036554, 26.049088341849192, 74.60406589508057, 62.43585245949881, 52.33510678155081, 26.04564377239772, 16.804214818137034, 24.812395845140728, 39.51746954236712, 26.816845178604126, 60.77252319880894, 10.589928388595581, 0.2563575325267655, 1.5634734417710985, 3.731523539338793, 1.108994486076491, 5.224493392876216, 16.80354952812195, 0.6768270102994782, 23.94264987536839, 68.30524594443185, 67.61455331529889, 63.23902252742222, 65.43963514055524, 59.94188690185547, 60.68405178615025, 57.83468587057931, 55.85735361916678, 60.768882342747276, 59.26507677350725, 63.0364408493042, 61.3835825238909, 63.22892679486956, 63.132854052952354, 60.52712672097342, 60.23197419302804, 56.5847362109593, 44.96623298100063, 45.98131615774972, 43.37082930973598, 45.29472643988473, 43.12681204932076, 44.71678917748587, 43.159607546670095, 50.03076103755406, 54.200093609946116, 55.441292013440815, 47.24527338572911, 45.03151478086199, 43.90024382727486, 42.826385838644846, 43.02934271948678, 41.72058350699288, 43.00371428898403, 43.217499937329976, 43.15734243392944, 43.41679164341518, 47.71190398080008, 51.02147340774536, 51.95253201893398, 53.240092277526855, 58.50241470336914, 46.85660852704729, 55.42030150549752, 53.54761607306344, 54.58322422845023, 53.39687837873186, 56.08870431355068, 56.48519284384591, 57.43308694022042, 55.46952254431588, 57.959326131003245, 52.513095310756135, 58.5816867010934, 42.90424387795584, 38.92402737481253, 57.220538071223665, 48.22299609865461, 50.63604988370623, 46.35940933227539, 50.756212030138286, 52.862843309129985, 50.28549242019653, 49.34129129137312, 49.99142033713204, 51.442093031747, 50.8361371585301, 49.50384439740862, 53.60262496130807, 49.69213710512434, 50.15386922018868, 46.93351466315133, 45.99650491986956, 46.14086069379534, 51.11825834001814, 45.40336847305298, 51.14054121289934, 52.80692073277065, 43.39633962086269, 39.20720815658569, 40.969187940870015, 40.230014256068635, 43.204687459128245, 40.43691771371024, 41.62859630584717, 42.184924670628135, 41.216985021318706, 42.48202964237758, 40.827840736934114, 42.923403535570415, 48.89505365916661, 52.5354893548148, 54.71874189376831, 53.48891074316842, 57.01487486703055, 55.42697525024414, 52.402014459882466, 54.63065610613142, 52.20050975254604, 53.49089445386614, 52.34670679909842, 51.016793795994346, 48.862080982753206, 49.10645954949515, 53.208210468292236, 55.25849533081055, 60.09233624594552, 49.87400272914341, 52.18067264556885, 19.63370714868818, 0.9315886284623827, 1.3393399715423584, 1.482383404459272, 0.8275879919528961, 0.2600538656115532, 0.06647274417004415, 1.2000922092369624, 54.03257949011666, 34.51939058303833, 28.961027996880667, 45.915996142796104, 56.47194610323225, 41.75787796292986, 17.694961718150548, 32.6392115184239, 48.24444171360561, 45.83186388015747, 48.91562727519444, 7.731824244771685, 0.28344760888389176, 0.05657607004312532, 0.0871887779129403, 0.09128040514354195, 0.10225657080965382, 0.0411662378215364, 0.04294964498175042, 0.11357608876590218, 0.03881994175857731, 0.017928672954440117, 0.04387923117194857, 0.011616794325943505, 0.05015408553715263, 0.011513308405743113, 0.048914812571768246, 0.030151612790567533, 0.043357441135283024, 0.024816293635272553, 0.06618518781449113, 0.026948211648102318, 0.09481520618179015, 0.022453052856560265, 0.056018717986132414, 0.040965133612709384, 0.09887504404676811, 0.054371553872312815, 0.19613423837082727, 0.08127709584576742, 35.71657909665789, 84.43737888336182, 70.43577902657645, 60.73743479592459, 33.496330874306814, 24.818253176552908, 18.34777624266488, 43.33368076596941, 31.181218896593364, 67.80373191833496, 11.498216015951973, 0.34426413263593403, 1.3453498376267297, 3.1402342276913777, 1.7786696829966135, 6.105521934373038, 7.67714626448495, 0.3930535688996315, 26.352754150118145, 73.30298791612897, 67.39863109588623, 67.97058595929826, 68.13046400887626, 64.5908432006836, 62.58591965266636, 61.15900979723249, 58.41648633139474, 61.43345669337681, 61.68397399357387, 64.95839595794678, 64.10172476087297, 64.53798130580357, 64.83003493717739, 63.418786321367534, 62.77111693790981, 59.94095584324428, 47.93612582342965, 46.94153635842459, 45.04960094179426, 47.24188266481672, 44.24650730405535, 47.54860741751534, 45.54190860475813, 50.77087620326451, 56.742884159088135, 57.69835179192679, 50.1267990384783, 48.287440640585764, 45.972241810389924, 44.41512271336147, 43.77371365683419, 44.27248314448765, 43.55806589126587, 44.89306150163923, 45.98596797670637, 46.96087319510323, 49.08304064614432, 53.195627280644004, 54.620011465890066, 55.34756428854806, 56.742568016052246, 47.207669734954834, 57.614535672324045, 55.91212626865932, 56.717398166656494, 56.20262350354876, 56.936467920030864, 58.73408154078892, 59.26091480255127, 57.378838879721506, 59.0652882712228, 54.12120376314436, 60.41806779588972, 46.26078312737601, 42.13013465063912, 59.87526757376534, 51.030916009630474, 54.08605282647269, 49.37182515008109, 53.37589481898716, 53.75040967123849, 51.777972425733296, 51.554956095559255, 51.7521459715707, 53.401467663901194, 50.89387321472168, 51.42405203410557, 54.3176189150129, 52.32639374051775, 53.17584923335484, 48.63667447226388, 46.54781321116856, 48.80036013466971, 54.43872949055263, 47.800201688494, 53.93061120169503, 53.37126384462629, 45.67063440595354, 41.38794197354998, 42.18205506461007, 41.9137920652117, 44.1038156236921, 43.32680204936436, 42.99700232914516, 44.49481160300118, 43.96579313278198, 44.81740951538086, 43.30693367549351, 45.65746062142508, 52.1869329724993, 54.46246106284005, 55.34080369131905, 56.01468167986189, 59.405958448137554, 57.224484648023335, 53.698273863111226, 56.89303125653948, 54.89694929122925, 54.3855688231332, 54.5598817552839, 54.41772508621216, 50.64440509251186, 51.712562084198, 55.12787961959839, 57.84478160313198, 62.21319048745291, 55.10990115574428, 56.57186467306954, 25.611016580036708, 0.01745841425976583, 0.45179236414177076, 1.4635710482086455, 1.4087364077568054, 0.6115196432386125, 0.048515107948333025, 1.0329887930835997, 55.860831192561555, 42.02112088884626, 37.682874134608674, 66.18625382014683, 54.92343929835728, 40.60147190093994, 27.190696477890015, 39.21583087103707, 55.74194056647164, 52.21433319364275, 62.02565165928432, 13.670306273869105, 0.42192925087043215, 0.07622700397457395, 0.05177055272672858, 0.06643392518162727, 0.0824754022594009, 0.03505450666749051, 0.013014595972241035, 0.06251779424824885, 0.027731517562642694, 0.015327176478292261, 0.05807890636580331, 0.02649485526074256, 0.014903293955805046, 0.07628919170903307, 0.14149360465151922, 0.11469451125179018, 0.08512099672641073, 0.15330707574529306, 0.1584304358278002, 0.12415684493524687, 0.24951404545988354, 0.1261036976107529, 0.2083854866879327, 0.0640461468803031, 0.2857634217611381, 0.14818592768694672, 0.32483946638447897, 0.1154092393283333, 40.51289626530239, 97.68420287540981, 78.12931782858712, 71.74752249036516, 41.66731514249529, 29.172043051038468, 35.06924670083182, 53.91995961325509, 40.817081451416016, 77.3546006338937, 15.350257362638201, 0.3983534430818898, 4.1379410454205106, 10.645621674401418, 3.9978197642735074, 16.155591794422694, 36.529650347573416, 2.117446150098528, 27.702136005674088, 75.01473917279924, 71.39104516165597, 69.99550642286027, 70.39329079219273, 64.8124976839338, 64.32162134987968, 62.78865419115339, 61.17378861563546, 63.20635904584612, 62.804614203316824, 66.54784502301897, 66.19422340393066, 67.36498097011021, 66.97112233298165, 66.61267171587262, 65.65019335065568, 62.1967510495867, 51.4843658719744, 49.617176464625764, 48.01707581111363, 50.066888196127756, 48.29769270760672, 48.74752950668335, 47.163183893476216, 53.2305246080671, 59.96393353598458, 60.329610279628206, 52.42492961883545, 50.708651610783164, 47.72137784957886, 47.686063630240305, 47.34933655602591, 45.28270953042166, 46.718342849186485, 46.260394028254915, 47.366474287850515, 49.802762848990305, 51.756533758980886, 55.09112017495291, 57.367270129067556, 57.996644905635286, 61.17895112718855, 49.61862863813128, 60.63512257167271, 58.622882570539204, 59.12329878125872, 59.150987352643696, 60.02039459773472, 60.449918338230674, 62.21565014975411, 61.0970527103969, 63.22136715480259, 58.28329978670393, 63.688501494271414, 48.30020795549665, 44.68037714276995, 61.15159606933594, 54.29858432497297, 55.80811173575265, 51.401699679238455, 56.39340714045933, 56.794161864689414, 52.89432907104492, 53.93811873027256, 53.38520540509905, 56.39860439300537, 53.627054827553884, 52.22251122338431, 55.91895982197353, 53.87118673324585, 56.68513420649937, 52.70841612134661, 50.81449351991926, 52.81100974764143, 57.23512234006609, 50.48716041019985, 56.041460037231445, 57.06468997682844, 47.746610232761924, 43.8203569139753, 44.82975993837629, 45.806826046534944, 47.562073026384624, 44.74555124555315, 44.90586355754307, 47.85164267676217, 46.74403033937727, 48.05484274455479, 45.30054555620466, 48.00284242630005, 55.28672238758632, 57.863899571555, 57.65203857421875, 59.33535780225481, 62.7027188709804, 61.46729442051479, 56.653502532414024, 60.65336159297398, 58.20529236112322, 57.15317528588431, 57.27156911577497, 58.54258918762207, 54.352318218776155, 54.56199400765555, 57.247729846409385, 61.05886541094099, 64.93758610316685, 55.59760911124093, 56.8285311290196, 26.922303199768066, 1.1881163375718253, 7.038635475294931, 7.977040069443839, 3.11531668475696, 0.694269485771656, 0.14826703976307595, 2.2433314408574785, 65.7238164629255, 49.29968547821045, 39.757488114493235, 49.67368616376604, 68.17254229954311, 50.81575461796352, 27.560396228517803, 45.239450045994346, 64.30665493011475, 60.20029040745327, 73.34901973179409, 17.04667568206787, 0.5804271602204868, 0.22010586277714797, 0.22134986173893723, 0.23161027474062784, 0.24720249378255435, 0.17797567775206907, 0.11811933533421584, 0.20283493452838489, 0.1418573401336159, 0.16018234539244855, 0.1364164256623813, 0.12995751867336885, 0.10987765900790691, 0.14291304562773022], [0.019739102771771804, 0.005194621950587524, 0.047680598084947894, 0.024920168864939893, 0.04952511750161648, 0.03756706416606903, 0.04393510513805917, 0.06511899895433869, 0.02246007739034082, 0.05088798901332276, 0.0641539389533656, 0.07418086805513927, 0.07844268543911831, 0.5208620993154389, 56.64302812303816, 68.73915399823869, 59.708045278276714, 48.06113086427961, 26.18686417170933, 31.564391204289027, 52.10859203338623, 37.381516865321565, 46.153839928763254, 61.826349530901226, 1.7115869969129562, 0.09759148649339165, 0.3586584659559386, 0.6453879858766283, 2.5182712248393466, 2.233316263982228, 2.5762852089745656, 0.7711969550166811, 40.2916829926627, 69.18246296473912, 69.01806163787842, 67.99824673788888, 67.3896540233067, 63.38247503553118, 65.5904596873692, 63.41752174922398, 57.401458740234375, 63.60233688354492, 60.77373218536377, 61.654492786952424, 61.71858297075544, 60.41622652326311, 62.240274565560476, 60.246148518153596, 61.416739327566965, 55.8216780935015, 46.184891428266255, 45.42431034360613, 42.34667525972639, 43.26808282307216, 43.05582925251552, 44.02637447629656, 44.08622973305838, 45.18662289210728, 50.53142738342285, 49.296207904815674, 48.30784749984741, 44.846428666796, 41.369056769779746, 42.27916308811733, 40.93063933508736, 42.12025431224278, 42.5238230569022, 42.891316754477366, 43.629486424582346, 43.33418798446655, 45.21824761799404, 50.008394786289756, 53.869519165584016, 56.217107023511616, 47.078263010297505, 45.817571435655864, 58.45101887839181, 52.633267879486084, 53.90595204489571, 50.71128150394985, 54.33717461994716, 50.46596145629883, 57.284458024161204, 52.305139201028005, 52.178261620657786, 48.351607254573274, 58.85532760620117, 41.61541904721941, 34.257773535592214, 54.18190670013428, 47.75717844281878, 53.063545499529155, 49.54683985028948, 52.91176904950823, 51.99935940333775, 48.461791787828716, 48.01264633451189, 51.03013433728899, 51.742390700748985, 53.304620197841096, 49.65710081372942, 51.53850276129586, 52.56820494788033, 53.04876320702689, 50.59569822038923, 49.573368072509766, 49.87986353465489, 52.14140142713274, 41.771388735089985, 51.260585239955354, 53.685134819575715, 45.86176545279366, 40.514709745134624, 40.92975343976702, 39.07863174165998, 41.58873101643154, 40.07906811577933, 41.074852670942036, 42.78825412477766, 40.512944902692524, 41.49055644444057, 40.433186531066895, 41.710744857788086, 46.150358881269185, 50.79608079365322, 50.684402397700715, 52.25366347176688, 50.32083443232945, 49.61698191506522, 48.66067355019705, 50.32876232692173, 47.61932965687343, 50.4260162625994, 45.450425148010254, 49.9828462600708, 45.73422084535871, 55.122637203761506, 55.013071060180664, 62.02654102870396, 55.273781367710654, 61.81362737928118, 56.559656688145225, 62.69755635942732, 21.45209240913391, 0.21662157188568795, 1.8645842671394348, 0.6215520277619362, 0.4750964322260448, 0.029369136385087456, 0.09329380174832684, 18.892056431089127, 62.66914517538888, 30.339833736419678, 13.6773430619921, 47.66274200166975, 76.82548141479492, 27.299152646745952, 24.280111721583776, 41.69794627598354, 41.40645892279488, 52.921625069209504, 17.870985644204275, 0.5318407416343689, 0.07373577622430665, 0.03350596761863146, 0.08145867181675774, 0.039655812084674835, 0.05884548130312136, 0.04120004582884056, 0.03918540071962135, 0.02501886008706476, 0.03231812760766063, 0.05207684004147138, 0.045973960376743755, 0.14618025959602424, 0.03723310958594084, 0.01740450974154685, 0.025834538907344853, 0.028084583081571118, 0.047489108717335124, 0.06367019098252058, 0.0433416414473738, 0.01507812868138509, 0.04758087040058204, 0.008971929284078735, 0.062280205211469104, 0.07324934804013797, 0.0477005741558969, 0.05873048997351101, 0.8132343707340104, 67.85379368918282, 73.98807334899902, 67.58601706368583, 54.773524965558735, 39.623415674482075, 34.74456780297415, 42.923473017556326, 42.54878098624093, 51.351801191057476, 69.84313242776054, 1.396535805293492, 0.040794146180685074, 0.7024305249963487, 1.7815877092736108, 3.3550319245883395, 5.502790893827166, 2.6786827657903944, 1.2014755521501814, 43.26309054238455, 70.90893745422363, 70.56349386487688, 70.21161624363491, 69.14507470812116, 64.83112580435616, 67.53374576568604, 64.12074892861503, 60.371570450919016, 64.72098990849086, 62.99896921430315, 64.62048421587262, 65.61031069074357, 63.87121132441929, 63.397983414786204, 63.05554839542934, 63.778980936322895, 59.959479740687776, 47.419940676007954, 48.606182302747456, 44.60841812406267, 46.2827741759164, 44.12166207177298, 47.06761142185756, 47.10667419433594, 48.49820729664394, 52.548246247427805, 51.48176029750279, 50.974430629185264, 47.779447419302805, 44.13250820977347, 45.0251259122576, 43.74551439285278, 43.7340463910784, 43.7465809413365, 45.250084263937815, 45.88776213782174, 46.310483591897146, 47.228535175323486, 52.21155391420637, 55.213241713387625, 57.164361885615754, 47.14115462984358, 47.91963079997471, 60.153383118765696, 55.216698442186626, 55.701564584459575, 53.23779937199184, 55.83359425408499, 52.665486676352366, 57.74864632742745, 53.52138662338257, 55.78125694819859, 50.852305616651265, 61.49202305930001, 44.307095595768516, 36.36005176816668, 56.615534101213726, 50.105725152151926, 55.61201967511858, 50.63220058168684, 55.84768172672817, 52.52512959071568, 50.6949462890625, 49.03296845299857, 53.01126377923148, 54.3661208152771, 55.245338916778564, 51.72614928654262, 53.50609016418457, 54.315968717847554, 54.28806822640555, 53.227151257651194, 51.30345562526158, 52.08979715619768, 52.825951848711284, 44.25439003535679, 51.86126743044172, 54.675114154815674, 47.41001170022147, 41.80839484078543, 43.002724170684814, 41.74472154889788, 44.46831464767456, 41.94299186979021, 43.931441238948274, 44.281929220472065, 43.24089799608503, 43.76884644372122, 42.79847492490496, 43.16366182054792, 47.84849861689976, 53.51335103171212, 52.875742639814106, 55.862992082323345, 52.587913513183594, 52.52572366169521, 51.514361245291575, 52.09928839547293, 50.40984780447823, 52.22454357147217, 47.63736718041556, 52.70303821563721, 48.607380867004395, 57.274341447012766, 57.5855165209089, 64.78777599334717, 57.24520765032087, 62.91613279070173, 59.33456570761544, 68.19757665906633, 26.3542115347726, 0.23008891780461582, 0.5301288249237197, 1.0429065866129739, 1.2766236854451043, 0.26591640817267553, 0.08844795570309673, 18.357830286026, 67.75485828944615, 35.39789302008492, 13.83759023462023, 46.75373002461025, 63.4958279473441, 33.6136268888201, 34.967653615134104, 46.0711007799421, 47.8526154245649, 61.40984671456473, 25.798732587269374, 0.4929381034203938, 0.12463974473731858, 0.06085787367607866, 0.02909966298778142, 0.05494642909616232, 0.08059217581259352, 0.05741345350231443, 0.041047823282756975, 0.11798843235841819, 0.04206947649696043, 0.08829972294292279, 0.05245339644274541, 0.04959342562194381, 0.015632313676178455, 0.09948442277631589, 0.11077118784721408, 0.13620329781302384, 0.1798057681215661, 0.15377466779734406, 0.16184324984039578, 0.13210365708385194, 0.10844635045421974, 0.13247246800788812, 0.155320655554533, 0.136114450437682, 0.33304648314203533, 0.1614774651825428, 1.2188084849289484, 76.87736361367362, 84.48578003474644, 74.240953036717, 63.85016523088728, 41.23828819819859, 46.32352883475167, 68.64290755135673, 53.12534972599575, 63.882655007498606, 75.31293501172746, 2.487183464424951, 0.23392483911343984, 1.251416598047529, 4.6268293261528015, 9.78862738609314, 10.4864810023989, 7.80865568774087, 1.8695211793695177, 46.11642387935093, 74.1836165019444, 74.01179449898856, 72.596328326634, 73.16751194000244, 66.73929568699428, 70.46721267700195, 68.16325950622559, 61.6946325302124, 66.38016414642334, 66.14826801845005, 65.82885932922363, 66.69909340994698, 64.45645809173584, 66.87368774414062, 64.68802070617676, 66.74312414441789, 61.39375468662807, 49.99025303976876, 51.345558234623496, 46.468301500592915, 47.18365676062447, 46.21440042768206, 49.49861240386963, 48.66731602805001, 50.624832017081125, 55.050605228969026, 55.275848456791465, 53.4577237537929, 51.636719022478374, 46.067873341696604, 48.16377660206386, 45.590629373277935, 46.792553084237234, 45.84875495093209, 46.945277963365825, 47.79306936264038, 49.45865331377302, 48.640377862112864, 54.9925217628479, 59.22358213152204, 58.67973273141043, 49.90063170024327, 50.09304468972342, 62.28708457946777, 59.38708019256592, 58.324096134730745, 55.76760026386806, 59.27561719076974, 54.89914492198399, 61.8887026650565, 57.111496516636436, 58.394807951790945, 53.0841885975429, 64.30457047053746, 46.75920867919922, 38.304105622427805, 58.162557465689524, 51.28024516786848, 58.08676651545933, 54.65788262231009, 57.29522773197719, 54.986744335719514, 51.40578869410923, 52.27652651923043, 56.08774893624442, 56.60899584633963, 59.05437959943499, 53.33609553745815, 55.20374352591378, 56.84019020625523, 57.02581827981131, 55.60681547437395, 53.68138974053519, 55.301351819719585, 55.28413418361119, 46.65920673097883, 55.45762722832816, 57.79869767597744, 50.762840611594065, 44.318973541259766, 45.41448211669922, 43.167403425489155, 45.860483510153635, 44.6306071962629, 46.12516123907906, 46.91541460582188, 45.475730487278526, 45.94675929205758, 43.96238156727382, 46.42340571539742, 50.691374914986746, 56.033740588596885, 55.09809269223894, 59.56453718457903, 55.69541195460728, 54.30299643107823, 54.847099440438406, 56.687746729169575, 53.38661936351231, 55.602403368268696, 50.66757386071341, 56.09532594680786, 51.460689885275706, 59.5945325578962, 60.74930231911795, 68.63759217943463, 59.23241329193115, 65.64805330548967, 61.20432594844273, 71.89193384987968, 26.3326130594526, 0.5453825092741421, 6.4242062738963535, 4.28564932516643, 1.579555155975478, 0.33138667792081833, 0.24197633564472198, 24.103922775813512, 75.95567117418561, 43.24165187563215, 19.147901262555802, 58.25082738058907, 90.61135360172817, 35.244271823338096, 37.76297296796526, 54.35114049911499, 56.52657284055437, 70.32230104718889, 33.67684159960066, 0.722431511751243, 0.27766589341419085, 0.12068156498883452, 0.24939440616539546, 0.11730617896786757, 0.1341952412788357, 0.18696751525359495, 0.13454364186951093, 0.3201051918523652, 0.16648816131055355, 0.1652232227580888, 0.09822569281927176, 0.1712526170802968, 0.15171037428081036], [0.03605496584038649, 0.029722948292536393, 0.011979076046762722, 0.1010845440572926, 0.08665353591953005, 0.10723642073571682, 0.033709490804799964, 0.05228914686345628, 0.03237810331795897, 0.1100905290139573, 0.02766402198800019, 0.06268703445260014, 0.07365646226597683, 5.626325956412724, 64.83827550070626, 58.83686624254499, 62.0627133505685, 45.99625131062099, 16.904451268059866, 25.768785851342336, 33.92597620827811, 26.120234421321324, 65.76482473100934, 32.37216097967965, 0.03327221909005727, 0.05350877624005079, 0.7866403577583176, 0.896778044956071, 0.9130520288433347, 6.025994156088148, 1.7320652923413684, 3.145155506474631, 51.49790791102818, 72.12795025961739, 66.39615195138114, 68.28105926513672, 65.78624602726528, 65.0782801764352, 65.57260976518903, 62.03664370945522, 56.88722256251744, 64.11843517848423, 62.888249669756206, 60.585477692740305, 61.48184394836426, 59.56047248840332, 59.434182030814036, 59.35683468409947, 56.26623773574829, 52.42642000743321, 44.847144331250874, 43.53894097464425, 43.87983001981463, 43.39843102863857, 42.565355913979666, 42.765380655016216, 43.271470069885254, 45.51236139025007, 47.663165841783794, 46.67567048754011, 44.92191737038748, 43.45650407246181, 42.063004629952566, 41.029411452157156, 39.22012485776629, 41.69814082554409, 44.10011223384312, 44.59969118663243, 43.27955082484654, 42.892893995557515, 48.603274481637136, 51.07323748724801, 48.45683077403477, 51.11661161695208, 52.215160029275076, 51.62373283931187, 55.116230964660645, 51.91230542319161, 51.93259416307722, 47.663878032139365, 50.706494195120676, 48.108295236315044, 54.03699507032122, 45.95790072849819, 48.93144832338606, 48.965695994240896, 59.58140046255929, 39.66356584003994, 31.37091166632516, 53.51762417384556, 47.40101030894688, 53.128417355673655, 48.35526895523071, 53.39358145850045, 49.25554357256208, 49.7378180367606, 48.96866634913853, 51.957559040614534, 52.50569895335606, 53.641566140311106, 48.906653676714214, 52.925116539001465, 53.6361118044172, 54.607928548540386, 50.52479532786778, 53.31441020965576, 48.14716693333217, 53.57613148008074, 40.56288160596575, 46.640231200626914, 54.84074183872768, 49.234466212136404, 41.155184268951416, 39.951561723436626, 38.88199077333723, 41.257673672267366, 40.673910345349995, 41.57170792988369, 40.39577742985317, 40.34586157117571, 40.52131053379604, 40.97942958559309, 39.98143202917916, 46.448370592934744, 45.73957443237305, 48.05265058789934, 47.72247566495623, 48.34131697246006, 46.254477637154714, 44.9442731993539, 45.84374182564871, 45.725973333631245, 42.76504714148385, 43.970194816589355, 46.562043121882844, 53.859743050166536, 55.5895630972726, 57.925543989454, 56.80402135848999, 60.92167322976248, 57.010268211364746, 60.06538418361119, 54.84271165302822, 66.47513212476457, 16.28890688078744, 1.611885124019214, 0.7966936954430172, 0.9153160559279578, 0.09257537565593209, 0.11136138439178467, 2.261984097106116, 49.726099899836946, 55.70140824999128, 71.62015506199428, 65.70815522330147, 86.64783014569963, 25.790346111570084, 17.322731086186, 38.86904280526297, 45.713574273245676, 53.753032616206575, 24.680956772395543, 0.28184398636221886, 0.03978639275633863, 0.035299186395215135, 0.00680174444070352, 0.03317962620141251, 0.03673026424699596, 0.04791561886668205, 0.0642836612782308, 0.020635204955137203, 0.061280940260205946, 0.044095066376030445, 0.03570688755384513, 0.033391916060021946, 0.06544413257922445, 0.034953900280275514, 0.020684393654976572, 0.025064596739996756, 0.059620510786771774, 0.049047432241163084, 0.027592528145760298, 0.026385841824646507, 0.04019402606146676, 0.04107634210959077, 0.04279031817402158, 0.04015877955992307, 0.061416213001523695, 0.12945575559777872, 8.348772168159485, 78.80183397020612, 62.69570813860212, 71.33023452758789, 50.60668332236153, 29.266097341264995, 27.17195544924055, 33.350449970790315, 33.485192911965505, 72.18193776266915, 35.22159290313721, 0.03054732084274292, 0.12467411932136331, 0.9436061893190656, 1.5745665665183748, 2.0401302874088287, 7.403437614440918, 3.342766182763236, 4.955479988030024, 52.495464256831575, 72.28453486306327, 67.40973431723458, 70.91250188010079, 67.63987949916294, 66.85870742797852, 65.57880061013358, 65.48477063860211, 60.19967201777867, 66.80181557791573, 66.52996730804443, 62.57502487727574, 65.3027764729091, 61.72886630467006, 62.58622537340437, 61.343213490077424, 58.96578311920166, 54.22643075670515, 47.27838502611433, 46.095204080854145, 44.56117384774344, 46.31749085017613, 44.8879337310791, 43.87435136522566, 46.072761399405344, 47.47122532980782, 49.950467654636924, 48.76296840395246, 48.08563021251133, 45.545799595969065, 45.564604895455496, 43.5166129384722, 42.17190374646868, 43.023165770939414, 46.21782241548811, 48.67642164230347, 45.95225879124233, 46.31375619343349, 51.53077636446272, 54.82048436573574, 50.275761468069895, 53.410858154296875, 54.38388735907418, 53.3963121005467, 57.86223547799246, 53.85720000948225, 54.92645134244646, 51.13854707990374, 52.45557464872088, 50.86498260498047, 55.91601725987026, 47.065082277570454, 50.677370820726665, 50.57809495925903, 59.879540715898784, 41.74065337862287, 32.79085942677089, 54.86656829289028, 48.66880294254848, 55.698177337646484, 50.64942864009312, 53.05323089872088, 49.76082699639456, 52.16680056708199, 50.36027588163103, 54.691810676029746, 54.657663754054475, 56.38333225250244, 49.89101191929409, 54.271611418042866, 54.17393364225115, 55.71825415747506, 54.222320897238596, 55.78960868290493, 53.55411958694458, 54.17572627748762, 41.35551473072597, 50.36005353927612, 54.964749813079834, 52.60023614338466, 42.414767605917795, 41.653967653002056, 41.212593759809224, 42.440559319087434, 43.103448731558665, 43.50896297182356, 43.063840525490896, 43.52651759556362, 44.051419258117676, 42.2148505619594, 41.513454232897075, 48.15050554275513, 47.15656573431832, 49.941817147391184, 49.0282575743539, 50.8800949369158, 48.20711251667568, 46.77085733413696, 48.67766884395054, 49.512911796569824, 45.438095569610596, 46.62175594057356, 49.65725367409842, 57.7538401058742, 58.72517395019531, 59.4408939906529, 58.99807139805385, 61.61366517203194, 58.54222093309675, 63.11656052725655, 57.975386892046245, 70.3440489087786, 21.190944365092687, 0.7616407392280442, 0.2454122198479516, 1.4651466608047485, 0.27135625055858065, 0.13834912409739836, 2.2053252288273404, 51.23337262017386, 58.79611505780901, 48.83748435974121, 67.10647324153355, 75.06147970472063, 24.272611141204834, 28.76055335998535, 45.438832078661235, 51.11072301864624, 59.98708493368966, 37.510273933410645, 0.2572676108351776, 0.03586188870083008, 0.04950744166438069, 0.029849274549633265, 0.07557255016373736, 0.055783585246120176, 0.05930842539029462, 0.04272136205275144, 0.06578460109553166, 0.04506427561864257, 0.026240952545776963, 0.07443561045719044, 0.06741269837532725, 0.03782904314409409, 0.1067520145859037, 0.157425674742886, 0.14422789721616677, 0.18698152021637984, 0.1815406871693475, 0.22452205366321973, 0.094125583900937, 0.1786088187779699, 0.08414786894406591, 0.2465771830507687, 0.15536022771682056, 0.170517342963389, 0.36110955157450264, 10.889962026051112, 88.84230749947685, 73.1345774786813, 78.71457849230084, 60.72465705871582, 26.850542204720632, 36.665505000523154, 46.62294060843331, 39.26210934775216, 81.2725578035627, 39.81851066861834, 0.37312648817896843, 0.23843090874808176, 2.8142282239028384, 4.962621433394296, 5.935048750468662, 15.134078059877668, 7.686086859021868, 5.783627961363111, 57.45417472294399, 73.31589766911098, 70.69255665370396, 71.98302473340715, 70.4506481715611, 67.96185207366943, 71.4567403793335, 68.14659077780587, 63.66360609872, 67.45500183105469, 69.51653930119106, 64.09333828517369, 68.15052345820835, 63.08466134752546, 66.38847419193813, 63.63259628840855, 62.530459131513325, 56.624073437282014, 48.95258126940046, 47.353046894073486, 48.63949544089181, 47.85562399455479, 47.6365716116769, 45.94257995060512, 50.00594207218715, 50.28468295506069, 52.30757801873343, 51.41136114937918, 50.485492842538015, 48.36000067847115, 48.314913817814414, 45.547849314553396, 43.4932530948094, 45.987128325871055, 49.449763093675884, 51.62664066042219, 47.32014717374529, 49.10227673394339, 55.421628611428396, 57.65378604616438, 54.136215346200125, 54.85030950818743, 55.57517337799072, 55.67975071498326, 60.58205917903355, 55.84338426589966, 56.90655939919608, 53.82468244007656, 55.35193123136248, 53.23137576239449, 59.5959986277989, 49.2273199898856, 53.91108676365444, 54.52837514877319, 64.24307891300747, 44.26434680393764, 35.960009234292166, 55.28268895830427, 51.12172896521432, 56.93033266067505, 50.83327450071062, 55.64034400667463, 52.38284437997, 52.650572368076865, 54.920100688934326, 57.07910054070609, 57.29304599761963, 59.8591616494315, 53.57601336070469, 56.645796980176655, 56.31492723737444, 57.18626260757446, 56.771792139325825, 58.839423179626465, 54.60293626785278, 56.45464161464146, 45.47609874180385, 51.55137429918562, 56.750586237226216, 54.43403598240444, 45.63220739364624, 45.02926009041922, 43.95881714139666, 45.355078492845806, 44.81235122680664, 45.44517230987549, 43.32135118756975, 45.925483907972065, 46.573886326381135, 43.85398619515555, 43.3718889100211, 50.90913840702602, 50.93696246828352, 52.54073871885027, 54.10908610480172, 54.48794705527169, 52.23306553704398, 50.08900778634207, 50.84399209703718, 53.01299040658133, 48.52870988845825, 49.26022318431309, 52.54751321247646, 59.93616853441511, 61.91179847717285, 62.72432082039969, 60.83712060110909, 65.13836124965123, 61.88683359963553, 66.869247845241, 61.032920837402344, 72.66437203543526, 21.18569847515651, 2.5317748316696713, 4.747588583401271, 3.3423924999577657, 0.4638943618961743, 0.1942046204847949, 2.99891459941864, 58.7299473626273, 70.18606771741594, 94.66535649980817, 70.92935126168388, 94.24554634094238, 35.01435940606253, 27.491013254438126, 51.63757017680577, 59.08054651532854, 69.59815979003906, 47.025456701006206, 0.770075363772256, 0.2529224625655583, 0.1786261349916458, 0.08519529631095273, 0.13858325939093316, 0.13689609563776425, 0.1648990051554782, 0.11250813571470124, 0.20332141699535505, 0.13967492724103586, 0.07255142049065658, 0.15446719420807703, 0.2865598318832261, 0.09826209622302226], [0.04879333444737962, 0.03185282561129757, 0.04019487762291517, 0.052200167173785825, 0.06272151081689767, 0.024157522645379816, 0.012079829167175506, 0.08640027272381953, 0.02609119817082371, 0.037411085928657224, 0.0125069856211277, 0.1507873223828418, 0.3449976018496922, 20.136838368007115, 69.27365112304688, 57.89451680864607, 56.86217778069632, 24.301392316818237, 24.38445803097316, 31.476750101361954, 35.440839835575645, 41.028542927333284, 79.56806741441999, 11.453151736940656, 0.019624705160302774, 0.05184985311435802, 0.6073579979794366, 0.24691056087613106, 0.9763569576399667, 8.024447628429957, 2.174834144966943, 8.475685358047485, 61.73755155290876, 67.46989182063511, 66.56514603751046, 62.99230589185442, 59.35655675615583, 62.96360983167376, 63.3360332761492, 65.14536503383091, 56.69867624555315, 61.45331464494978, 61.05974088396345, 59.6550235748291, 57.75820357458932, 55.47812441417149, 54.82445526123047, 55.37720877783639, 51.94380855560303, 50.94912528991699, 46.282124519348145, 43.94936759131295, 43.03093038286482, 43.910561902182444, 43.48315041405814, 43.07510355540684, 43.18717452457973, 41.974217074257986, 43.67999635423933, 41.58321762084961, 42.88956233433315, 42.24071870531355, 40.704256602696006, 40.735992499760215, 41.23758295604161, 42.70005021776472, 45.1723895072937, 44.02590547289167, 46.42188058580671, 49.819139753069194, 51.330689089638845, 55.55604498726981, 49.73512213570731, 44.53988456726074, 58.2597210747855, 52.92124291828701, 53.888616289411274, 49.4586637360709, 47.70463269097464, 47.078690324510845, 45.59159517288208, 41.214351654052734, 46.36541952405657, 41.013778005327495, 48.924524443490164, 50.24182646615164, 59.43471009390694, 39.07444545200893, 27.923232895987375, 52.44675391060965, 48.885600634983604, 55.02886084147862, 49.59403548921858, 52.80150808606829, 46.30281972885132, 47.036056177956716, 46.308948040008545, 52.80181033270699, 50.414009775434224, 52.22181292942592, 48.40319068091256, 52.491767815181184, 50.47607108524868, 52.30715765271868, 51.4187262398856, 51.38207796641758, 48.3721843447004, 48.70111206599644, 42.945724623543875, 44.77496644428798, 53.35505369731358, 50.88189104625157, 43.06665454592024, 38.938375404902864, 38.87643916266305, 40.16564614432198, 40.73248365947178, 41.52933781487601, 40.82956041608538, 41.08788749149868, 40.93362358638218, 40.0327444757734, 41.414119311741416, 42.03580938066755, 42.7997533934457, 43.654051780700684, 44.40463440758841, 42.33814287185669, 43.86878933225359, 43.344290665217805, 42.452336515699116, 44.63197946548462, 46.846894945417134, 48.534414359501426, 54.23926407950265, 56.81980071749006, 57.73975958142962, 58.50660446711949, 60.05419758387974, 57.58458546229771, 58.0777963910784, 55.48001432418823, 59.64339229038784, 55.7878612109593, 63.206456320626394, 4.671327326978956, 0.8439375917826379, 0.9774458706378937, 1.1423631012439728, 0.18194011359342507, 0.07666702036346708, 21.79444578715733, 64.2199136189052, 40.753039905003135, 58.962913513183594, 45.45700856617519, 28.798447098050797, 16.010659320013865, 23.410230261938914, 41.59940692356655, 43.222026688711985, 47.07702623094831, 1.151553396667753, 0.10078184280012335, 0.025080788281879256, 0.0476476111050163, 0.07089361016239439, 0.05040553365168827, 0.047391043443764956, 0.017837773010666882, 0.04846271825954318, 0.02202246810442635, 0.012561064013945205, 0.04056561219372919, 0.1140150534255164, 0.049583329020866325, 0.026429519123796905, 0.05687414029879229, 0.01995285996235907, 0.03955944314865129, 0.0539771689634238, 0.042477567813226154, 0.029527238437107632, 0.08089582023343869, 0.0916213554197124, 0.08696684946439096, 0.05828423784779651, 0.24202584155968257, 0.2957008385232517, 26.71833709308079, 81.25217873709542, 62.87130996159145, 63.67370877947126, 30.064778872898646, 23.515999214989797, 17.429233074188232, 41.4302009173802, 46.31841148648943, 86.35306671687535, 12.748791881969996, 0.03699718974530697, 0.30624907250915256, 2.7277585438319614, 2.890093867267881, 4.774012582642691, 10.916413818086896, 0.03670104992176805, 9.82461210659572, 63.44995594024658, 66.60555676051548, 67.35766451699394, 64.0761970792498, 62.43054403577532, 62.68741198948452, 63.3085948399135, 67.62324551173619, 59.08893993922642, 62.58285549708775, 64.93661335536412, 61.541396958487375, 60.29501519884382, 57.78308159964425, 58.43916525159563, 57.25274644579206, 54.69734839030674, 52.22276830673218, 49.80969715118408, 46.69416659218924, 43.632880619594026, 44.358255181993755, 46.26244027273995, 45.06037064961025, 45.49248259408133, 43.92229740960257, 44.19929082053048, 43.37754474367414, 45.59560775756836, 43.55047498430525, 42.66033084051949, 42.408712250845774, 41.874777930123464, 45.21569415501186, 48.04365267072405, 46.74075426374163, 48.694823946271626, 52.07718964985439, 52.97648457118443, 58.676974296569824, 51.97619063513619, 45.90978445325579, 58.090775626046316, 53.26785727909633, 56.891235147203716, 51.38113995960781, 52.28472539356777, 48.84606885910034, 47.222736903599326, 44.30153703689575, 46.96238790239607, 44.36354276112148, 51.719812529427664, 53.207644190107075, 61.780394145420615, 40.21182039805821, 29.644621304103307, 54.158519063677105, 51.746542249407085, 56.28567879540579, 50.85202074050903, 53.56192241396223, 46.17822115761893, 49.5545905658177, 49.81820869445801, 54.75354889460972, 51.48199306215559, 55.58288587842669, 49.72484574999128, 53.255357469831196, 52.63090896606445, 52.336506843566895, 53.58724512372698, 52.945019653865266, 51.29247052328927, 51.324494770595, 45.21629517418997, 45.72666467939104, 55.367338861737935, 53.641281264168875, 46.345829078129356, 41.65771620614188, 41.23752737045288, 41.284497192927766, 42.29197209221976, 42.584091731480186, 43.25480481556484, 42.5148355620248, 43.89364651271275, 42.85036407198225, 44.33847713470459, 44.01917266845703, 45.38033172062465, 46.73297575541905, 47.01528453826904, 46.18825435638428, 45.29750919342041, 46.254554067339214, 45.43539272035871, 48.079321248190745, 50.12569774900164, 50.82134791782924, 55.92833989007132, 58.00713668550764, 60.88455595288958, 61.677963801792686, 62.56597832271031, 59.97501591273716, 59.64979158129011, 58.131978443690706, 62.384602546691895, 57.72211463110787, 66.22279439653668, 7.091360143252781, 1.38670215010643, 1.079029185431344, 2.069320103951863, 0.33061911910772324, 0.04615432516272579, 21.602824892316544, 69.35344423566545, 45.43905789511544, 58.41561780657087, 46.625723361968994, 31.98242609841483, 20.205265964780533, 25.295743806021555, 46.58917236328125, 49.28851624897548, 57.21160616193499, 2.3115909780774797, 0.2342813956950392, 0.12332950718700886, 0.055867109514240704, 0.03597689360114081, 0.03040112368762493, 0.0037030789951261666, 0.03182877493756158, 0.13586943144244806, 0.0389466581733099, 0.02122221068878259, 0.039781354633825164, 0.020613123729292835, 0.10538058674761228, 0.20953320153057575, 0.20386250796062605, 0.11350893415510654, 0.2147071667547737, 0.17458380333014897, 0.160896612065179, 0.09237824087696415, 0.15000503935984202, 0.12735317913549288, 0.15639346013111727, 0.22608406841754913, 0.28419614157506395, 0.4620695912412235, 33.12031173706055, 91.1279799597604, 70.93446513584682, 76.33533464159284, 36.95026649747576, 32.45073815754482, 44.07939270564488, 53.30121210643223, 56.01513678686959, 95.76466573987688, 14.8243499483381, 0.10342454670795373, 0.4937737328665597, 3.7988871932029724, 5.3792310782841275, 5.839051570211138, 15.62044848714556, 8.164196746689932, 12.148608224732534, 64.87201595306396, 68.01588821411133, 70.468247958592, 65.55390521458217, 64.0356057030814, 64.30851704733712, 66.88532597678048, 71.06119332994733, 61.03338636670794, 63.41887664794922, 66.86821256365094, 63.797365869794575, 62.663843699863975, 59.02752481188093, 60.37159129551479, 60.10325881413051, 57.70204128537859, 55.68359654290335, 50.84595496313912, 48.95853240149361, 46.026052134377615, 46.873444012233186, 48.740758487156455, 48.21586724690029, 48.09098379952567, 45.52249881199428, 46.666370323726106, 46.43792397635323, 47.97565412521362, 46.030724797930034, 44.95632484980992, 45.6672853742327, 44.966364996773855, 46.9960276058742, 47.521839482443674, 47.94954974310738, 51.272136620112825, 55.9350449017116, 56.52360248565674, 61.55931636265346, 52.797551086970735, 45.77254710878645, 62.36074938092913, 56.92708437783377, 58.8215663092477, 54.982200213841026, 54.94902951376778, 52.03534064974104, 48.35624170303345, 46.16858748027256, 50.08627019609724, 46.84624181474958, 52.89755303519112, 56.51814814976284, 63.402993065970286, 43.126763411930625, 32.61153336933681, 54.38516582761492, 53.644077914101736, 58.55267102377755, 54.48494890757969, 54.45708663122994, 48.872399057660786, 49.16562346049717, 51.31661898749215, 56.29122345788138, 52.703267506190706, 56.61447102682931, 52.64647987910679, 55.97222123827253, 55.223830768040244, 55.84812641143799, 57.82663985661098, 56.08381278174264, 53.71679081235613, 53.72905090876988, 47.31309127807617, 49.50500822067261, 56.73694692339216, 56.26710626057216, 47.12212698800223, 44.501374176570344, 43.69778026853289, 44.15635095323835, 44.99486303329468, 46.6677599634443, 45.39062547683716, 45.95686197280884, 47.31754159927368, 45.02791561399187, 46.281652041843955, 46.728636605399, 47.23867607116699, 49.793740613119944, 49.91965586798531, 49.064283984048025, 49.27324758257185, 48.355373178209575, 47.494328090122764, 49.24828617913382, 53.59306424004691, 53.881119183131624, 59.04656287602016, 60.739185741969514, 62.84446212223598, 62.51891122545515, 65.48338794708252, 63.05719511849539, 62.83111463274275, 61.974450383867534, 66.03160081590924, 60.31418527875628, 71.14534991128104, 6.310366988182068, 2.9411357683794837, 5.642683752945491, 3.0445950967924933, 0.5904123187065125, 0.11570392708693232, 27.506818669182913, 76.39770862034389, 55.209152698516846, 65.41986751556396, 54.08695609228951, 39.68269075666155, 23.901044062205724, 34.520140988486155, 56.643952233450754, 56.27139677320208, 66.87806510925293, 3.3148066316332137, 0.38374216854572296, 0.3469850037779127, 0.18753827176988125, 0.0996278515085578, 0.10897256114653178, 0.08513416709112269, 0.14765129637505325, 0.2632868949856077, 0.1321855155485017, 0.20119312405586243, 0.1018295076542667, 0.15302101895213127, 0.3409880841416972], [0.10495238365339381, 0.01537517095649881, 0.018910762488043735, 0.051204433997294733, 0.07437577723924603, 0.02367821568623185, 0.018480109882407954, 0.022713023370930126, 0.03205992467701435, 0.04170795643169965, 0.05505684370707188, 0.038681917557758946, 0.08413957724613802, 42.212804317474365, 62.37768908909389, 61.965466363089426, 52.63719361168997, 36.94899845123291, 32.671207972935264, 41.310841287885395, 29.24569395610264, 55.30513858795166, 56.333298274448936, 1.9842287727764674, 0.021854335608493005, 0.262997459088053, 0.8937265915530068, 0.6761374015893254, 2.0540381925446645, 11.252032654626028, 1.4174321868589945, 21.8665246622903, 68.6406146458217, 65.06303582872663, 67.65281009674072, 63.571389607020784, 63.83947890145438, 60.93177591051374, 61.92946774618966, 61.7504335130964, 55.23967613492693, 58.702745165143696, 59.9367104939052, 57.89931801387242, 59.14574841090611, 56.15407643999372, 54.982724802834646, 52.48155048915318, 52.780152797698975, 51.01755462374006, 49.38054166521345, 45.96833692278181, 43.79597915921892, 42.38111400604248, 44.217099053519114, 41.50170135498047, 44.006982054029194, 41.45072589601789, 43.04406247820173, 43.77453701836722, 43.50645467213222, 40.49385820116316, 41.98854078565325, 39.887058121817454, 42.07512576239449, 43.00567020688738, 45.62434550694057, 48.2178544316973, 46.907917499542236, 49.962192739759175, 54.461714131491526, 52.93981197902134, 54.26715414864676, 52.45364999771118, 52.99251753943307, 51.64362553187779, 52.081035477774485, 47.22050653185163, 45.902363777160645, 43.16390153339931, 45.120246750967844, 41.04531240463257, 43.707400049482075, 43.47750500270298, 51.24128314426967, 48.26635980606079, 58.58632114955357, 34.7511442729405, 26.752056700842722, 57.1202894619533, 48.20912749426705, 53.67312833241054, 50.20539011274065, 53.56074816840035, 49.48824569157192, 47.007808276585166, 46.21743679046631, 50.15837860107422, 50.9801663671221, 50.71532188143049, 49.81833723613194, 50.97081756591797, 51.08542810167585, 49.83423818860735, 47.99545301709856, 49.969189575740266, 49.41362203870501, 49.609880856105256, 47.308307443346294, 40.71567249298096, 51.284692014966694, 52.413211481911794, 46.3187450000218, 40.5494715826852, 38.277170930589946, 39.05535875047956, 41.55791922977993, 40.6711414882115, 40.61199494770595, 40.635215827396934, 40.21755266189575, 41.466102259499685, 40.28579439435686, 41.21304191861834, 42.18855857849121, 42.39087275096348, 40.00535815102713, 42.655633858272004, 41.27682638168335, 43.5835588318961, 47.69579110826765, 48.568894795009065, 48.954436438424246, 54.33362061636788, 54.12467786243984, 59.36678450448172, 59.248220443725586, 57.83660009929112, 57.651826654161724, 56.994763306209016, 54.58712911605835, 50.927662304469514, 55.282390185764854, 59.519547598702566, 62.47715950012207, 37.438738754817415, 0.029718269793582813, 0.2230183250669922, 0.5654907588447843, 0.1491766023848738, 0.05686984856479934, 2.6769878395966122, 55.561349936894004, 50.075257301330566, 43.24412543433053, 31.65924106325422, 15.975133180618286, 29.531056472233363, 25.999707494463237, 40.6514641898019, 47.19255740301949, 49.989228180476594, 5.048720036234174, 0.3394215367734432, 0.06618132695023503, 0.04293238983622619, 0.03329820358859641, 0.03279064243127193, 0.09765369458390133, 0.01598467182234994, 0.054757063543157916, 0.038521437240498405, 0.049829128331371715, 0.01881262257562152, 0.04202386537300689, 0.0283760715475572, 0.06456516510141747, 0.009802761487662792, 0.06481170401509319, 0.022888073531378592, 0.025315878613452827, 0.010595398106878358, 0.01631852631856288, 0.03936660349635141, 0.02625005678938968, 0.013254512384134744, 0.0876063144366656, 0.03403233776667288, 0.32383034910474506, 56.97752135140555, 69.17704336983817, 69.95991774967739, 59.49506214686802, 42.92870153699602, 39.78276913506644, 38.82484878812517, 36.2663448878697, 62.875513621738975, 63.0348288672311, 1.8009633038725172, 0.06246223580092192, 0.5930559454219682, 2.2712115219661166, 2.5031569387231554, 3.511149913072586, 12.22331438745771, 1.4328640273639133, 25.200252975736344, 69.77472741263253, 68.20547676086426, 69.7552238191877, 66.7900036403111, 66.1451552254813, 62.43449756077358, 61.97149739946638, 64.17970439365932, 58.948225021362305, 63.74775573185512, 62.97450460706438, 61.22717162540981, 60.39563206263951, 56.5371549470084, 56.75122894559588, 55.7611905506679, 55.27139466149466, 52.89696591241019, 51.75511632646833, 47.56710352216448, 44.9849340575082, 44.38937268938337, 46.67441633769444, 45.466256618499756, 43.59026384353638, 44.57419129780361, 45.89200748716082, 45.43105009623936, 44.93432337897164, 42.149148396083284, 44.036338193076, 41.21594279153006, 43.54850517000471, 46.062297412327354, 48.789837087903706, 50.00922509602138, 50.21123354775565, 51.23911878040859, 55.793610845293315, 55.84480169841221, 54.9998208454677, 54.56145204816546, 54.01030356543404, 52.36002996989659, 53.39497457231794, 49.995214053562705, 48.566879817417686, 46.11320686340332, 47.49570383344378, 43.900528703417095, 45.515838963644846, 45.42046104158674, 53.68838657651629, 50.761270318712505, 59.828853607177734, 36.68321943283081, 28.719829968043737, 57.38850729806082, 50.69061061314174, 54.240601607731406, 52.484204701014924, 55.952981676374165, 51.09747627803257, 47.70422969545637, 47.76372364589146, 51.220341273716514, 52.19567033222744, 53.46308428900582, 52.12288795198713, 52.94594723837716, 52.387416294642854, 53.11081756864275, 51.015765462602886, 53.26246895108904, 51.075749261038645, 51.21329232624599, 50.01616287231445, 43.609350545065745, 53.6683167048863, 54.235977581569124, 49.75755092075893, 42.16568858282906, 40.45923185348511, 41.58182103293282, 42.73286655970982, 43.40593160901751, 42.16724497931344, 42.07832888194493, 41.37511212485177, 43.413922037397114, 42.81338575908116, 43.43089996065412, 43.074745723179404, 44.0593193599156, 42.70402111325945, 44.64677912848336, 43.947495051792686, 46.50039870398385, 48.59711490358625, 52.10871362686157, 52.44046926498413, 57.42406817844936, 54.53403098242623, 62.24336651393345, 60.64220973423549, 58.631887435913086, 60.01422459738595, 58.597056116376606, 56.152106625693186, 54.2811895098005, 57.11184740066528, 61.4559827532087, 63.62691961015974, 42.09112398965018, 0.0800592340528965, 0.5434709404196058, 1.3235855826309748, 0.3475859686732292, 0.051364646293222904, 2.497602505343301, 56.62908656256539, 57.472451959337505, 47.78068767275129, 37.51040594918387, 12.845941594668798, 27.21082714625767, 33.19152729851859, 48.06523377554757, 51.81534678595406, 60.11882972717285, 9.428479671478271, 0.41371637157031466, 0.059477862369801314, 0.04362267368872251, 0.07329641801438161, 0.028062830945210795, 0.0681023138708302, 0.020680300392476574, 0.07531412331653492, 0.04416326932342989, 0.013741267961449921, 0.06332409741090876, 0.025137566395902207, 0.01996915158815682, 0.2345369862658637, 0.09725392889231443, 0.1462814970208066, 0.11701282113790512, 0.1103510796757681, 0.07700275949069432, 0.10962696745991707, 0.1660953981003591, 0.17431327141821384, 0.1210355567080634, 0.1260625376765217, 0.11203283550483839, 0.486443926181112, 66.2858840397426, 78.08415453774589, 77.32282652173723, 68.36145687103271, 49.560110909598215, 45.36182171957833, 63.12758731842041, 43.361956460135325, 68.72629288264683, 67.9388952255249, 3.329891387905393, 0.15596647161458219, 0.6518589300768716, 4.305575021675654, 5.7651839682034085, 7.154091085706439, 18.66021067755563, 4.095610014029911, 26.562504632132395, 72.8189138684954, 69.13706343514579, 71.861097744533, 66.4001054763794, 69.3019858769008, 64.95082242148263, 65.51986598968506, 66.29040731702531, 60.94992460523333, 63.012872559683665, 64.814957346235, 63.9383031300136, 62.56145504542759, 59.79797581263951, 60.26264354160854, 58.846857752118794, 56.139148235321045, 55.06022848401751, 54.22109454018729, 50.58763831002371, 46.35255146026611, 47.095299993242534, 48.52889748982021, 46.594338348933626, 46.80168301718575, 46.6031243460519, 46.63646180289132, 48.07454088756016, 48.006663935525076, 44.79721805027553, 46.838088103703086, 42.72263881138393, 47.26390150615147, 48.03102431978498, 51.68040582111904, 53.9326296533857, 51.050767013004844, 53.46026332037789, 58.211573532649446, 58.17862517493111, 56.14696495873587, 56.18306085041591, 57.99333756310599, 55.98670475823538, 56.48123237064907, 53.49499041693551, 51.787727696555, 47.77826969964163, 50.810140473502024, 45.548978396824424, 48.46669374193464, 47.51214674540928, 53.878530979156494, 54.83612476076399, 62.8004035949707, 40.5334073475429, 31.926163060324534, 58.352542059762136, 53.52355098724365, 56.298567703792024, 54.44226612363543, 56.68992846352713, 53.14392573492867, 49.831858430589946, 50.21879318782261, 54.40182760783604, 53.42333017076765, 55.58027335575649, 54.175396238054546, 55.78554398672921, 53.61825493403843, 55.1599976675851, 53.71517883028303, 54.84920127051217, 53.35699919291905, 53.92555291312081, 51.98685959407261, 46.70952558517456, 55.84693479537964, 56.991977078574045, 52.45236110687256, 44.74850075585501, 42.89070531300136, 44.2411641393389, 45.24917752402169, 45.12866449356079, 44.21385424477713, 44.26864079066685, 43.82119764600481, 46.72249092374529, 46.1284373147147, 45.77936329160418, 46.2588654245649, 47.1772574697222, 45.888720989227295, 48.589451040540425, 47.60673952102661, 48.43004894256592, 53.285318102155415, 55.617262090955464, 53.55914660862514, 60.49458135877337, 56.777423654283794, 64.40844603947231, 64.66636317116874, 61.25633321489607, 62.56912585667202, 62.885102135794504, 59.91076592036656, 57.73851237978254, 60.571490968976704, 66.27086203438895, 65.07556343078613, 44.47736815043858, 0.3619780221155712, 3.685426150049482, 3.817891384874071, 0.4209827759436199, 0.14886020150567802, 3.3267093300819397, 65.66354084014893, 62.09582846505301, 55.77354792186192, 41.56596524374825, 23.19505671092442, 40.95603152683803, 39.11716297694615, 56.21435553686959, 60.194516454424175, 69.19167627607072, 12.354727404458181, 0.5433670431375504, 0.2676008035029684, 0.14657281924571308, 0.19598310148077352, 0.15800745066787514, 0.1715231082801308, 0.14932875707745552, 0.15909700148871966, 0.2683089497898306, 0.07531796382474047, 0.11226209891693932, 0.1587516271642276, 0.10839505999216012], [0.11086999611662966, 0.052215878652142625, 0.049478756596467326, 0.02413838795785393, 0.022020186530426145, 0.028468669525214603, 0.06077965894447906, 0.024993569390582185, 0.1903573947825602, 0.03931474306487611, 0.18668223199035439, 0.28368677890726496, 6.305401197501591, 71.10173606872559, 59.090795108250205, 60.50798443385533, 49.42986692701067, 19.297266687665665, 13.474726642881121, 20.697992256709508, 34.17664636884417, 75.53106675829206, 31.959566525050572, 0.09557412045874766, 0.024256858475772396, 0.400900880673102, 3.2087182785783495, 2.753960417849677, 8.106281774384634, 4.315927403313773, 0.3419240010636193, 35.31748499189104, 67.47119113377163, 66.31736632755825, 67.45074258531842, 66.74210970742362, 64.57207611628941, 63.60513005937849, 62.45920535496303, 62.51265089852469, 56.37219776426043, 57.015635694776265, 59.27577699933733, 59.78931835719517, 59.06111240386963, 56.39375455038888, 57.17488840648106, 57.103745801108225, 55.617588656289236, 52.73966564450945, 50.476679052625386, 47.67241736820766, 42.470634596688406, 42.49789237976074, 41.77789224897112, 42.10006284713745, 42.310645375932964, 42.516836643218994, 42.07423986707415, 43.431448868342805, 42.65201384680611, 41.89800923211234, 40.09258931023734, 40.556061949048726, 40.73795536586216, 42.26664243425642, 46.9332332611084, 48.7759302684239, 48.893174171447754, 51.77696146283831, 54.3626571382795, 52.24423476627895, 55.33625609534127, 51.61280679702759, 52.27970879418509, 48.87150274004255, 48.85694626399449, 45.17115272794451, 44.170518330165315, 43.86788954053606, 42.816960607256206, 40.34115069253104, 44.35770974840437, 44.24606956754412, 53.195245129721506, 48.19674580437796, 58.24794387817383, 31.47176824297224, 27.198627846581594, 57.47465453829084, 47.56352172579084, 54.305626324244905, 48.69359758922032, 52.699821199689595, 50.74055426461356, 47.94299064363752, 45.311085973467144, 49.835527079445974, 47.25919757570539, 51.35309355599539, 47.814879758017405, 53.78788478033883, 51.490264892578125, 53.05383539199829, 49.59832600184849, 50.47330570220947, 50.93112250736782, 50.302887235369, 47.923594747270855, 44.592305251530235, 45.292034012930735, 54.25833341053554, 50.147004399980815, 41.648384775434224, 38.57317461286272, 40.053168705531526, 41.04322099685669, 40.908182757241384, 41.5361852645874, 40.88316229411534, 39.61810725075858, 41.52911894662039, 39.15251541137695, 41.61462000438145, 40.02748816353934, 40.45149850845337, 39.49922357286726, 43.189842632838655, 44.289620876312256, 46.38489532470703, 48.58614369801113, 51.74965156827654, 53.788569177900044, 57.94527687345232, 56.70358862195696, 57.76309510639736, 56.49716806411743, 57.11197246823992, 56.83205386570522, 55.36745350701468, 48.02474662235805, 48.68669802801949, 54.21887459073748, 60.12971060616629, 59.04104600633894, 60.029545375279014, 5.249592023236411, 0.39858205510037287, 1.2494575317416872, 0.5881378693240029, 0.12189258714871747, 0.061233144253492355, 27.509068148476736, 62.77202715192522, 47.941534996032715, 33.297549860818044, 38.95486348015921, 19.77779367991856, 15.282700027738299, 36.3772485596793, 42.29975407464163, 50.44440119607108, 22.79313816343035, 0.22685621412737028, 0.02603254560381174, 0.048530147677021365, 0.037079608001347096, 0.05118662245305521, 0.04899715958163142, 0.06282099762133189, 0.013728641272921647, 0.028835899462657313, 0.021526879697505916, 0.02997127853866134, 0.05750334582158497, 0.037965394756091494, 0.06943438667804003, 0.06512735850576844, 0.04530009028634854, 0.08345921018293925, 0.0715563828125596, 0.0413537475812648, 0.1327247337571212, 0.07734582679612295, 0.1267753251429115, 0.05936177859881094, 0.24782490038446017, 0.22949956942881855, 10.634621807507106, 83.79703290121896, 64.0773435320173, 71.4133071899414, 56.28895487104143, 31.094675609043666, 19.502309765134537, 26.546261480876378, 42.479594298771445, 82.1871839250837, 34.75717878341675, 0.15358950916145528, 0.033829947733985524, 1.2219753435679843, 1.7713808055434908, 4.7537959303174695, 8.2289947782244, 5.604768301759448, 0.6107786829982484, 38.8999970299857, 68.47315611158098, 68.85039465767997, 69.40777220044816, 69.22275556836809, 66.42841938563755, 67.4827320916312, 63.54444449288504, 64.6882222039359, 57.55181428364345, 60.64516966683524, 63.02112701960972, 62.546905517578125, 61.819165093558176, 58.338228770664756, 58.407335553850444, 59.73849923270089, 57.5884347643171, 54.325734410967144, 52.48446873256138, 50.170138427189414, 44.601654052734375, 44.50244072505406, 44.56671156202044, 44.17435720988682, 42.83395937510899, 44.60891144616263, 43.574543544224326, 45.04591492244175, 44.57671001979283, 44.55877324513027, 42.968844754355295, 42.87628780092512, 43.68645470482962, 46.40073026929583, 49.0347888810294, 50.72130428041731, 52.12246758597237, 54.22845268249512, 55.53527682168143, 54.54218816757202, 56.173809323992046, 54.7821546282087, 55.40612718037197, 50.768458230154856, 51.06981897354126, 48.122420924050466, 46.78123099463326, 46.88030535834176, 45.10694095066616, 42.30233185631888, 45.51655115400042, 45.74032136372158, 55.02602250235421, 50.16028240748814, 58.86123357500349, 35.261937618255615, 30.05533974511283, 60.06607205527169, 49.13294608252389, 54.950634547642295, 50.21375226974487, 54.36082281385149, 52.054906776973176, 50.3211019379752, 47.28054591587612, 52.60249430792672, 49.62182133538382, 52.35773706436157, 48.54195662907192, 53.84091690608433, 53.865642070770264, 54.61991766520909, 53.41853938783918, 53.44833673749651, 53.18331854684012, 53.70427710669381, 51.46547719410488, 46.531825406210764, 47.21578523090908, 55.82256746292114, 53.70795617784773, 44.761417457035606, 40.54604264668056, 42.78885166985648, 41.74851526532854, 42.716639041900635, 41.943259375435964, 43.56385374069214, 41.913451603480745, 43.565556049346924, 41.22440569741385, 43.5028589793614, 40.93554823739188, 43.4659640448434, 42.61692544392177, 45.70895024708339, 45.225234031677246, 49.551001821245464, 50.940836088997976, 54.437840121132986, 57.13855627604893, 59.93265274592808, 59.48417431967599, 60.16823141915457, 59.34950433458601, 61.28349372318813, 58.565566880362375, 56.88564184733799, 48.98279203687395, 51.63993256432669, 57.18716239929199, 62.55242238725935, 61.25782012939453, 64.00817421504429, 7.420545816421509, 0.4986354634165764, 1.142882696219853, 1.426714654479708, 0.10867336791540895, 0.006351950786276055, 27.33075131688799, 67.553145136152, 53.618355682918, 36.3465826851981, 24.646467651639664, 26.318982430866786, 20.350637912750244, 41.04518386295864, 48.029283796037944, 57.82605273383004, 34.584033148629324, 0.3154317954821246, 0.023291698390884057, 0.052268281911632845, 0.0056869750177221635, 0.03901055581601603, 0.04237432192478861, 0.10030737718833344, 0.044947309752127955, 0.03586899635515042, 0.05451751354017428, 0.03867762582376599, 0.051382213564855714, 0.03662887754450951, 0.22054697839277132, 0.20611989897276672, 0.15005527809262276, 0.2019269053957292, 0.1479697735714061, 0.14046346635690757, 0.39839252669896397, 0.12353719318551676, 0.453153451106378, 0.1980429438075849, 0.2885604788150106, 0.41035547905734604, 13.265875084059578, 94.86255332401821, 73.17395986829484, 78.5331471306937, 63.162182399204795, 30.963354655674525, 19.6934494972229, 33.82746464865548, 48.947634152003694, 91.63542079925537, 40.908766405923025, 0.6189239802105087, 0.11421032223318305, 3.088409568582262, 8.11274446759905, 8.267500826290675, 17.684165954589844, 8.71898695400783, 0.9511082896164486, 43.0576878956386, 71.23995658329555, 72.40596158163888, 72.4927167892456, 72.94598252432687, 69.00415134429932, 67.47315052577427, 65.773238999503, 66.88695880344936, 59.99670818873814, 61.953647477286204, 62.18910108293806, 64.31810556139264, 62.85055569240025, 61.45449583871024, 60.812711579459055, 62.96998132978167, 61.323397227696006, 56.99771629061018, 52.690336908612935, 53.19419595173427, 46.466602666037424, 46.397579261234824, 46.32876430238996, 45.58216994149344, 45.370256832667756, 46.10700907026018, 46.404621260506765, 47.56851748057774, 45.75618757520403, 48.29382950919015, 44.8809403691973, 44.8554995400565, 44.53601442064558, 48.27085181644985, 51.65705987385341, 51.609864234924316, 53.56643179484776, 55.66937705448696, 59.55728326525007, 55.624474321092876, 58.64465822492327, 57.55402728489467, 56.12564441135952, 53.93395675931658, 53.805779865809846, 50.09090117045811, 49.519113063812256, 49.59564052309309, 48.14434943880354, 45.37423815046038, 49.798395906175884, 48.636254106249126, 59.16474478585379, 53.1864070211138, 62.02204554421561, 38.208421979631694, 32.186265400477815, 62.43658202035086, 51.56225865227835, 59.89582034519741, 52.3536376271929, 55.21067435400826, 55.255542346409385, 52.21253708430699, 48.17709629876273, 54.38866771970476, 52.204192297799246, 54.37076916013445, 49.41536603655134, 57.236036028180806, 54.726155621664866, 54.96660498210362, 55.47143677302769, 55.59136268070766, 54.28175926208496, 55.884979656764436, 52.538598673684255, 49.767844676971436, 47.75955472673689, 56.809117862156455, 57.345557008470806, 46.16772937774658, 42.81008883884975, 44.702455043792725, 44.46191883087158, 44.81981011799404, 46.07613822392055, 45.809924943106516, 44.312386648995535, 47.116773400987896, 44.23503930228097, 45.91060086659023, 43.62139177322388, 46.72796263013567, 45.45731428691319, 49.40531199319022, 48.38561173847744, 51.12745080675398, 53.96715177808489, 56.724936962127686, 58.438602447509766, 62.0495673588344, 61.048220770699636, 61.88497148241316, 61.77444648742676, 62.4701418195452, 60.57121998923165, 61.58844321114676, 51.41224357060024, 54.90846940449306, 61.97827884129116, 66.75028078896659, 64.63819517408098, 66.91178471701485, 7.186556109360286, 1.5034303665161133, 6.995266556739807, 1.8131203715290343, 0.26263666844793726, 0.1278616189956665, 33.31703608376639, 74.08862767900739, 60.359265191214426, 46.84483827863421, 52.72003698348999, 30.02299588067191, 24.871214083262853, 51.379798957279746, 55.435424259730745, 66.46161093030656, 40.66252224785941, 0.4088446529848235, 0.1002451962392245, 0.15843507700732776, 0.08836746109383446, 0.23179651903254644, 0.20154394023120403, 0.1500599735549518, 0.14794588913874968, 0.10461395074214254, 0.11705495816256319, 0.2184505494577544, 0.08277020536895309, 0.1779349927923509], [0.01794422328072999, 0.04519680029313479, 0.0862050921257053, 0.036106157914868424, 0.1165587455034256, 0.02682326451343085, 0.06967586372047663, 0.03125852392986417, 0.26899771711656023, 0.07176931388676167, 0.26580065009849413, 0.3739332663161414, 26.988384042467388, 68.79381547655377, 57.66770328794207, 40.40340307780674, 26.705076456069946, 22.83653834887913, 50.65208980015346, 42.366960525512695, 44.11456101281302, 72.94175107138497, 13.17205616406032, 0.14253993279167584, 0.12844488769769669, 0.8697385873113359, 0.7394686032618795, 1.6829131926809038, 1.6993581673928668, 0.7564599343708583, 1.181612280862672, 55.06492894036429, 65.5979915346418, 66.76897839137486, 62.899686404636924, 65.68414224897111, 61.34143475123814, 63.255892753601074, 61.68291091918945, 64.30437592097691, 58.12343910762242, 58.7123475755964, 63.04307637895857, 59.75986494336809, 59.36499186924526, 57.77555670057024, 57.74482829230172, 57.038891315460205, 58.04883977345058, 57.509419849940706, 53.322275570460725, 51.18673283713204, 43.734977449689595, 42.789973803928916, 42.05862379074097, 44.22172655378069, 43.18198422023228, 41.933038575308665, 41.50395951952253, 43.38674415860857, 41.603082520621165, 42.280469349452424, 39.76871987751552, 42.1857202393668, 41.47850826808384, 43.49014030184065, 47.022121565682546, 49.73230116707938, 51.49822057996477, 50.91378675188337, 53.236652919224326, 54.202733925410676, 50.801952021462576, 51.238660199301584, 49.04623256410871, 44.813685280936106, 43.66646473748343, 43.06073120662144, 43.1403888293675, 40.63257898603167, 41.60825892857143, 41.49235255377633, 43.60079383850098, 42.98053857258388, 52.04547807148525, 51.39309433528355, 58.55545030321394, 29.481849329812185, 35.803716455187114, 56.3272568157741, 48.74317646026611, 56.82009254183088, 48.25788647787911, 52.02621766499111, 52.034274101257324, 50.65476485661098, 44.29175049918038, 50.97760248184204, 48.62263911111014, 48.72013970783779, 44.461807659694124, 46.50303207124983, 48.08777720587594, 47.60745865958077, 49.81725679125105, 49.730800356183735, 50.654681478227886, 50.30716732570103, 51.51431955610003, 45.43196031025478, 44.21958998271397, 52.9261657169887, 51.913698537009104, 43.72254712241036, 37.19037192208426, 39.74418926239014, 39.79687745230538, 40.99538264955793, 40.236823490687776, 39.38240698405674, 40.03722953796387, 42.23156792776925, 38.961502483912874, 39.55991608755929, 38.93110064097813, 41.12850318636213, 39.90459884916033, 42.715103490012034, 45.533271993909565, 47.4386556489127, 49.20945964540754, 54.7989102091108, 56.701441628592356, 56.71441044126238, 56.115572997501914, 57.39237397057669, 55.18885006223406, 55.139778409685405, 51.003706863948274, 46.23595373971121, 44.21682807377407, 52.546272959027974, 55.36493131092617, 59.44765458788191, 58.536134311131065, 59.932604108537944, 31.886197022029332, 0.07895236023302589, 0.9819562286138535, 1.4491827402796065, 0.08914683320160423, 0.09007890961532082, 5.3450824192592075, 57.52489348820278, 51.98531361988613, 39.894895689828054, 29.93772758756365, 23.064522641045706, 16.16202061516898, 25.280442135674612, 52.01920345851353, 45.06374747412545, 46.73564386367798, 6.048509793622153, 0.2224274024899517, 0.013519233491803919, 0.029480748610304933, 0.04892249698085444, 0.028273348131084015, 0.02106588639851127, 0.07171052561274596, 0.014740291184612682, 0.009985887063001948, 0.0071272096995796475, 0.046667192463896105, 0.03172270295077136, 0.04693139025143214, 0.027284561456846337, 0.04605101481346147, 0.00742313578458769, 0.09179986441241843, 0.04135882641587939, 0.07093668356537819, 0.015274033615631717, 0.16275231034627982, 0.10694736481777259, 0.2430686413177422, 0.44457435288599556, 34.07041883468628, 78.61608777727399, 63.17725304194859, 50.003371238708496, 35.473322663988384, 25.013111931937082, 23.029567990984233, 44.451819624219624, 49.87618446350098, 80.65671811785016, 13.048403416361127, 0.08279095496982336, 0.24592508375644684, 1.784671080963952, 3.075771229607718, 4.460529404027121, 3.0634796491691043, 1.2529344537428446, 2.594250644956316, 55.28293561935425, 70.3149220602853, 69.34522451673234, 64.90404020036969, 68.41412421635219, 64.86039161682129, 66.05876132420131, 63.962024280003135, 66.69680745261056, 58.773582049778526, 61.027709688459126, 66.33290944780622, 61.154972893851145, 62.78996740068708, 61.69839150565011, 61.27366897038051, 58.443292481558665, 60.32878344399588, 59.03731482369559, 56.730940205710276, 53.44405664716448, 46.59031186785017, 43.08561965397426, 43.95971693311419, 45.257477147238596, 44.23699174608503, 43.303619384765625, 44.434813908168245, 43.55214255196707, 44.38486678259713, 43.81078577041626, 43.36013603210449, 43.81704262324742, 43.703529902866904, 47.51662833350045, 50.30431856427874, 52.6698397227696, 53.14415849958147, 53.886900084359304, 56.10576214109148, 55.879164014543804, 55.06958075932094, 53.071365697043284, 51.15463215964181, 46.536789894104004, 47.33785465785435, 45.785804271698, 44.76006950650896, 42.75438165664673, 44.505543095724924, 44.307877268110005, 45.93449224744524, 44.79214586530413, 56.35826662608555, 53.67195756094796, 59.029414721897666, 31.45771551132202, 37.8341954776219, 57.12932906832014, 52.819924286433626, 57.52068287985665, 50.95791476113455, 52.928083419799805, 54.40166432516915, 52.1707888330732, 45.829835006168906, 52.35411705289568, 52.586395331791465, 51.20042426245553, 47.168909209115164, 47.744834968021934, 49.440341336386545, 50.314014775412424, 51.892200810568674, 52.23961421421596, 53.30097239358084, 52.65459884916033, 52.97013391767229, 47.63525840214321, 46.792907442365376, 55.87874712262835, 54.163587774549214, 45.174116134643555, 39.47180250712803, 40.52666064671108, 42.10549981253487, 43.05029501233782, 42.51123639515468, 41.23754474094936, 42.410008089882986, 44.72603028161185, 41.95628029959542, 42.62422105244228, 40.63809585571289, 43.44333723613194, 42.400256293160574, 45.341880389622276, 49.214340754917686, 50.04599148886544, 51.884790556771414, 57.39487879616873, 58.98864964076451, 58.56151608058384, 58.56915215083531, 58.66110461098807, 57.066076142447336, 56.28234713418143, 54.08857502256121, 47.79896490914481, 47.48183870315552, 54.9623943737575, 57.64098399026053, 61.72243227277483, 60.86566380092076, 62.855078969682964, 38.16063574382237, 0.12658855159367832, 0.6943774542638234, 2.088730982371739, 0.19293069812868321, 0.0835841895480241, 4.886120464120593, 61.14242444719587, 58.07168197631836, 45.39527382169451, 32.46596513475691, 23.44770015989031, 19.50977734157017, 29.84010887145996, 59.38528060913086, 50.20009558541434, 56.289451667240684, 9.362759266580854, 0.3174910135567188, 0.1241745004164321, 0.03832101835204022, 0.07356056491179125, 0.12184952731643404, 0.04689152631908655, 0.061492880673280785, 0.04999754072300025, 0.04280033674357193, 0.036883290857076645, 0.1024087458582861, 0.052460073227328916, 0.19315051633332456, 0.058497813530266285, 0.20391261098640306, 0.1523902935108968, 0.166838244668075, 0.13544107228517532, 0.16627705549555166, 0.1744063121399709, 0.37824684913669315, 0.13899207673966885, 0.3014441489108971, 0.43638438092810766, 39.053826672690256, 87.5127558026995, 73.03160517556327, 57.76339040483747, 38.86245938709804, 32.06023897443499, 67.9557307107108, 63.270685468401226, 56.541341236659456, 87.99585710253034, 16.844477891921997, 0.359400566135134, 0.399152404495648, 4.166270588125501, 4.745213168007987, 8.366671596254621, 5.543854747499738, 2.912404532943453, 2.630629675728934, 63.43663624354771, 68.92380237579346, 72.9259786605835, 65.78229250226701, 71.91680145263672, 67.14772469656808, 68.67072119031633, 66.84978594098772, 69.33621270315987, 62.54143033708845, 63.699298994881765, 66.14812210627964, 65.331604548863, 64.97411973135812, 63.462949071611675, 62.9773325238909, 61.90231418609619, 62.55865492139544, 63.58418818882534, 59.708476066589355, 57.03854043143136, 49.111566475459504, 46.97259133202689, 47.58309827532087, 48.17376116343907, 47.709336621420725, 45.883086000170024, 45.16551079068865, 47.031946318490164, 45.81652920586722, 47.34738411222185, 44.89035170418875, 46.975652013506206, 46.379350662231445, 48.17693649019514, 53.318117073604036, 54.55887426648821, 56.0680125781468, 57.0362822668893, 57.97264582770211, 57.31255653926304, 57.037536416734966, 56.271136215754915, 52.083161626543315, 50.90441710608346, 49.50237832750593, 47.92443895339966, 46.932990074157715, 45.592105865478516, 47.484385217939106, 46.67587545939854, 48.343873909541536, 47.12244313103812, 57.431909220559255, 56.532534394945415, 60.774697984967915, 35.290842124394004, 41.88977561678205, 58.880327224731445, 56.50783354895455, 60.328213691711426, 53.95282111849104, 55.31569984980992, 56.11792843682425, 54.41803775514875, 47.8945061138698, 53.87531396320888, 53.63731384277344, 53.777326992579866, 49.5838737487793, 49.456443786621094, 50.90744652066912, 52.0107752936227, 52.94494669778006, 55.52649777276175, 55.83636311122349, 54.63693380355835, 54.92306409563337, 50.48343270165579, 48.532819747924805, 58.51427527836391, 57.62999194008963, 46.664525577000205, 41.3180569921221, 43.860114506312776, 44.363674776894705, 46.81623601913452, 44.04183421816145, 43.133683817727224, 44.322715146201, 46.64232260840279, 44.10487869807652, 43.85228041240147, 44.07266337530953, 45.973426478249685, 44.42405809674944, 47.716135433741975, 52.93368714196341, 52.6031231198992, 54.911901814596995, 60.529301507132395, 61.92173440115792, 59.55886050633022, 61.49867248535156, 60.7969183240618, 59.261373383658274, 59.51300239562988, 57.546877588544575, 49.96226569584438, 49.43349388667515, 58.107746601104736, 60.82095909118652, 64.75511251177106, 64.3103861127581, 63.654510906764436, 41.14060694830758, 0.3062565635357584, 4.53552999666759, 3.8174223814691817, 0.38321752526930397, 0.14279200855110372, 6.891874321869441, 67.47219167436872, 62.963721002851216, 54.208153520311626, 43.91708278656006, 33.19708238329206, 25.935827493667603, 38.94560153143746, 69.34544685908726, 58.81494467599051, 68.29937471662248, 10.932078531810216, 0.590455419250897, 0.21790442376264504, 0.17651840166321822, 0.20655288573886665, 0.22361337313694613, 0.12469847872853279, 0.10228577495685645, 0.18794354716581957, 0.14070400702101843, 0.08447406786893095, 0.2153817391289132, 0.16489486609186443], [0.0642072514497808, 0.02630551515280136, 0.057561726974589486, 0.016428102938724414, 0.024016070146379725, 0.008709133519524974, 0.043593645960624726, 0.035082292676504166, 0.031759150459298065, 0.013855302556683975, 0.0688498355448246, 0.06588976723807198, 48.227029527936665, 72.88107245309013, 50.31755140849522, 49.73141527175903, 42.06771550859724, 23.315199749810354, 52.21519129616873, 32.50328738348824, 63.068652697971885, 55.52816186632429, 3.0814937225409915, 0.09709267504513264, 0.19696038189743245, 0.5266203103320939, 0.43592775400195805, 5.131722782339368, 1.558453259723527, 0.907723140503679, 8.390227726527623, 65.72339957101005, 66.1279375893729, 64.17846066611153, 59.99744469778878, 58.96479647500174, 58.08234051295689, 59.81986958639962, 60.11022785731724, 59.928310121808735, 59.72533239637102, 59.48967729296003, 62.49778175354004, 61.614311354500906, 59.01577540806362, 58.19731930324009, 59.81766700744629, 58.478714397975374, 58.37419959477016, 56.42047732216971, 54.60348864964077, 51.597267150878906, 47.36466428211757, 41.99295636585781, 41.98395150048392, 42.20840610776629, 44.23570285524641, 41.73392057418823, 41.59346273967198, 41.025148732321604, 42.5026866367885, 43.401179041181294, 40.190756934029714, 38.46173940386091, 42.75802251270839, 43.76005002430507, 47.646625655038015, 50.65445566177368, 53.46023552758353, 51.367167132241384, 54.67341184616089, 53.65710926055908, 50.77243259974888, 50.147852080208914, 45.35210813794817, 42.677124636513845, 46.20312697546822, 39.4596848487854, 40.86266163417271, 39.17022636958531, 43.662928104400635, 43.54369701657976, 43.80186775752476, 42.97381966454642, 51.076322487422395, 49.48816926138741, 57.200026988983154, 29.038118260247366, 39.743477072034565, 54.23520980562483, 46.95518956865583, 52.69328989301409, 50.667740617479595, 53.127232687813894, 53.5743145261492, 50.7190009525844, 45.13980940410069, 50.834792682102744, 50.1002881867545, 52.27257994243077, 49.73208924702236, 46.34601320539202, 41.21878807885306, 45.94828789574759, 47.122571672712056, 48.52022961207798, 51.30753074373518, 48.81850535529, 48.61614949362618, 48.611813817705425, 42.380919456481934, 49.00699608666556, 51.45901189531599, 46.0883218901498, 41.04197726930891, 38.73732580457415, 39.407010555267334, 38.268947737557546, 42.32859604699271, 40.13182578768049, 43.68102468763079, 41.3184426171439, 40.77195290156773, 38.42619936806815, 40.591046128954204, 39.13413395200457, 40.93334913253784, 43.735043457576204, 47.834807191576274, 49.468432903289795, 51.099150793892996, 52.86247852870396, 56.93669721058437, 55.90329858234951, 57.61720378058297, 54.01739420209612, 52.96747275761196, 46.32362610953194, 44.93684210096087, 42.40464408057076, 52.67502655301775, 55.61329466956002, 60.99678325653076, 57.72569295338222, 62.105250222342356, 56.00776474816458, 58.48155621119908, 6.917874480996813, 0.8138289302587509, 0.868636320744242, 0.23302062334758894, 0.046363809279033115, 0.24885722356183188, 29.76985216140747, 66.10506411961147, 45.028527055467876, 38.10785722732544, 34.66517768587385, 15.944304023470197, 25.99713839803423, 31.282957894461497, 47.02689150401524, 48.23616988318307, 21.028379099709646, 0.1961844635329076, 0.09028557102595057, 0.052319297567009926, 0.06137136183679104, 0.09559698708887611, 0.0577782949964915, 0.02257480748396899, 0.014442265033721924, 0.037773698435298035, 0.07405265886336565, 0.12008490200553622, 0.03219977752970798, 0.013010091347885984, 0.06225873636347907, 0.04749949708847063, 0.027559731155633926, 0.02586344619547682, 0.042513933897550614, 0.02074622515855091, 0.045736958272755146, 0.00945092666162444, 0.012846777298753815, 0.031284223443695476, 0.6701595623578344, 61.24361106327602, 76.52634062085832, 59.50360843113491, 52.995894363948274, 43.36222743988037, 29.11364691598075, 42.90499428340367, 36.38220262527466, 70.31426198141915, 59.811566489083425, 3.1335370327745165, 0.09257374038653714, 0.6003323921135494, 1.1225548727171761, 2.1163624482495442, 4.116105462823596, 1.1233127691916056, 0.4303204763148512, 10.583575129508972, 69.22269303458077, 69.45652076176235, 66.9119792665754, 61.81318964276995, 60.261163575308665, 59.73555319649832, 62.524893624441965, 63.21177169254848, 62.97121810913086, 62.60326930454799, 62.25477545601981, 63.8139442716326, 64.79878888811383, 61.97190734318325, 60.15970597948347, 61.94018186841692, 62.281581606183735, 60.38421617235456, 57.149339880262104, 57.21501425334385, 55.102417945861816, 48.252195903233115, 43.233199392046245, 44.24013928004673, 43.627339431217735, 45.055093492780415, 43.540559904915945, 43.77404717036656, 42.55682005201067, 44.41595649719238, 45.016187054770334, 43.472832339150564, 40.96155881881714, 45.69139909744263, 45.5576080594744, 50.90365975243704, 53.097355433872764, 55.66541658129011, 53.65075165884835, 57.29163898740496, 54.229248251233784, 54.42510059901646, 51.87645271846226, 47.662342480250764, 45.37937634331839, 46.54121937070574, 43.40999630519322, 42.53486374446324, 41.17096710205078, 46.286644322531565, 45.214349678584504, 45.302744661058696, 44.58438777923584, 53.388328620365684, 51.07211535317557, 57.846039227076936, 32.167126587459016, 43.23743084498814, 57.12942286900112, 49.278972898210796, 53.75046525682722, 53.020181792122976, 53.5039952823094, 53.15422643933977, 51.481586592538015, 45.94124242237636, 52.56381368637085, 51.93831600461687, 53.91376876831055, 52.309992517743794, 48.24343075071062, 42.21913065229143, 46.68014860153198, 50.18577882221767, 50.85609585898263, 52.343677384512766, 50.659878730773926, 51.62914201191494, 51.22279051371983, 46.05810417447771, 50.689752510615754, 54.240337576184956, 48.83669226510184, 42.14620235988072, 40.108549322400776, 41.375515120370046, 40.08871568952288, 43.6485036441258, 41.92039285387312, 45.65801647731236, 43.24747099195208, 42.86413540158953, 41.81336975097656, 43.10018655232021, 42.13006516865322, 44.25454289572579, 45.35003410066877, 49.5063214302063, 52.41422244480678, 53.900355270930696, 55.17123985290527, 59.51476723807198, 58.99007402147566, 59.40706321171352, 57.16914572034563, 55.08639887401036, 49.93006774357387, 46.9924874986921, 44.39648069654192, 55.41773762021746, 58.171211447034565, 62.477659770420615, 58.46303926195417, 65.0623618534633, 57.99880926949637, 64.28183596474784, 9.82186496257782, 1.1727283575705119, 0.791988190795694, 0.671902094568525, 0.1152080265539033, 0.13318875671497413, 31.673762798309326, 69.70072909763881, 51.59497424534389, 35.06918069294521, 25.764186143875122, 23.07222124508449, 35.62378243037632, 38.72271374293736, 52.376003878457205, 57.523448262895855, 27.486833912985666, 0.30862112236874445, 0.051548318937420845, 0.025619869087157503, 0.0475389708631805, 0.05811471265873738, 0.025274582972217883, 0.053808474979762516, 0.05159445931868894, 0.08302327857485839, 0.08558657352945634, 0.0700707236038787, 0.009398014500870236, 0.10774214645581585, 0.1880386777754341, 0.13796488328703813, 0.11008829663374595, 0.11862029773848397, 0.12781123098518166, 0.19961812214127608, 0.14727046181048664, 0.14024800434708595, 0.07716270376529012, 0.16155397679124558, 1.0709534244877952, 70.58324064527238, 87.67339120592389, 66.44019658224923, 64.53050504411969, 53.1998622076852, 33.15358666011265, 71.03505420684814, 44.72342470714024, 76.45206437792096, 66.1312449319022, 4.268899389675685, 0.16107973509601184, 1.2057359921080726, 3.4533254844801764, 3.69036979334695, 14.631414106913976, 3.9729816913604736, 2.460648294006075, 13.054701089859009, 73.78680488041469, 72.25654057094029, 70.25216593061174, 64.547333581107, 63.524169649396626, 62.24395016261509, 63.64996678488595, 65.4097648348127, 65.07810647147042, 64.94383948189872, 66.28728062765938, 67.42629187447685, 67.58570439474923, 63.660264015197754, 62.71959604535784, 64.05009964534214, 64.18007959638322, 63.441819599696565, 59.77808312007359, 58.6140444619315, 56.30553674697876, 51.37830856868199, 45.59905406406948, 46.70713540485927, 45.888870375497, 46.949530260903494, 45.54634155545916, 45.617213181086946, 44.86328847067696, 46.06866543633597, 47.62094858714512, 46.110226086207796, 43.17580727168492, 49.19080720629011, 48.36123398372105, 52.468942982809885, 54.186020033700125, 59.53431946890694, 54.8334184374128, 58.236896242414204, 57.98275893075125, 56.82909393310547, 56.02278675351824, 49.66535874775478, 48.215092522757395, 48.97433607918875, 44.40869215556553, 45.31453922816685, 43.352816104888916, 47.685111727033345, 47.62192133494786, 46.14416456222534, 47.10429443631853, 57.026801449911936, 52.931050300598145, 60.709044456481934, 35.52141114643642, 46.330744538988384, 58.26621069226946, 52.862252712249756, 55.74438285827637, 56.23382438932146, 55.855463709150044, 57.384178570338655, 54.75769696916853, 48.352493149893625, 54.43581472124372, 54.17551783152989, 56.23024606704712, 56.4055734361921, 50.38514001028878, 45.223663738795686, 46.13176550183977, 51.350720746176584, 52.681582178388325, 55.671183586120605, 52.4767701285226, 53.15488999230521, 52.29150683539254, 45.87508862359183, 55.63205827985491, 56.503789697374614, 50.69827447618757, 45.27287782941546, 41.31058420453753, 43.836428097316194, 42.00122472218105, 48.44852072851998, 42.96836532865252, 49.352752344948904, 45.79675810677664, 45.94114167349679, 42.2668091910226, 45.29982989174979, 42.89158426012312, 46.44447265352522, 46.48946571350098, 51.79046528679984, 55.91981445040022, 56.43750040871756, 56.04848119190761, 62.165240968976704, 60.30823762076241, 61.635378292628694, 60.17552702767508, 59.420195307050435, 52.15457173756191, 49.83974116189139, 45.36393049785069, 58.27682753971645, 59.84300708770752, 65.91223076411656, 61.126631191798616, 68.2591724395752, 60.00348963056292, 65.65424415043422, 9.859012637819562, 1.8964439289910453, 5.709611841610499, 0.9836404068129403, 0.2827467093510287, 0.4385393810059343, 38.26566123962402, 74.79321670532227, 57.47627346856253, 52.36836780820574, 46.61168105261666, 23.47892710140773, 38.93149668829781, 47.267549310411724, 59.96474647521973, 66.20313099452427, 34.10477420261928, 0.673925974539348, 0.15365588345697948, 0.25722689873405863, 0.2233624780284507, 0.12666324472853116, 0.15683718132121222, 0.2250625610883747, 0.10607073150042977, 0.2017062050955636, 0.219604615388172, 0.16820077012692178, 0.059031915584845204], [0.019459878826247792, 0.09318672213703394, 0.05711252322154386, 0.08951230573334865, 0.0734022491212402, 0.044250990330640755, 0.03738888765552214, 0.12528572364577226, 0.040784232784062624, 0.12859495250242098, 0.08560192199157816, 4.507940002850123, 66.29585470472063, 60.3001012802124, 48.07583672659737, 54.6182917867388, 19.25283990587507, 16.70991734095982, 36.74318586077009, 36.710063798086985, 73.02195412772042, 33.685036999838694, 0.18063202021377428, 0.0035483689820726533, 0.38763288834265297, 0.6614232340029308, 2.601446155990873, 2.664502578122275, 0.8471232865537915, 0.33455367226685795, 35.080141476222444, 71.97310270581926, 64.88103471483502, 64.07801750728062, 57.48870032174246, 56.2516256741115, 53.33675561632429, 53.937931128910606, 57.00090551376343, 56.39691250664847, 57.8316946710859, 59.3020133972168, 58.664745467049734, 59.24684470040457, 58.423490115574424, 59.07902485983712, 62.36943462916783, 58.25881780896868, 57.825114727020264, 56.20096983228411, 56.13553864615304, 56.29194607053484, 50.09432315826416, 41.8074186188834, 42.0190885407584, 41.06961372920445, 42.35777848107474, 40.4610036441258, 42.40696825299944, 41.615318298339844, 42.00415686198643, 41.32552283150809, 41.17588990075247, 41.058472292763845, 41.190984862191335, 44.09789228439331, 49.29744121006557, 51.91343103136335, 54.761296136038645, 53.28540842873709, 51.73047454016549, 50.67617573056902, 48.677912030901226, 45.36880465916225, 42.90577942984444, 40.076990604400635, 42.63133600779942, 39.039589813777376, 41.691116196768625, 40.31224618639265, 45.48718459265572, 44.12585530962263, 45.64266095842634, 41.711575167519705, 50.29930196489607, 49.77154459272112, 56.48356696537563, 31.943085397992814, 37.63576534816197, 56.240147250039236, 44.71791478565761, 51.56685835974557, 49.14798893247332, 53.229954855782644, 49.51881776537214, 48.18694537026541, 45.512681007385254, 50.843839236668174, 47.53435318810599, 50.00565024784633, 47.91092470714024, 49.26880420957293, 53.255534648895264, 53.89471333367484, 44.7479692186628, 48.716012477874756, 46.83555548531668, 49.43319858823504, 45.31189891270229, 49.17587205341884, 43.98496668679373, 48.274878297533306, 53.5219737461635, 47.43174566541399, 39.98276260920933, 40.654684679848806, 39.46313810348511, 39.075991426195415, 38.11220332554409, 39.98791469846453, 43.32956395830427, 41.28596673692976, 41.11364098957607, 40.68630593163626, 40.35771867207119, 42.35061141422817, 40.14610780988421, 43.55311529976981, 45.35505417415074, 47.71736526489258, 51.819484438214985, 54.295044217790874, 56.697376932416645, 54.60447529384068, 49.474092211042134, 47.841050148010254, 43.2380040713719, 43.19929218292236, 45.29057489122663, 50.1927478654044, 54.78809533800398, 58.52224486214774, 58.398949078151155, 60.96418925694057, 58.998245103018625, 58.785185541425435, 59.477142742701936, 40.11289889471871, 0.14270712382027081, 1.6070051001650947, 0.5979241356253624, 0.040393148948039324, 0.16417278269571917, 9.056318521499634, 54.988828795296804, 55.28459276471819, 47.55576753616333, 35.26840986524309, 16.048217807497295, 22.34305817740304, 34.06595114299229, 43.962860992976594, 47.38780525752476, 35.528616428375244, 1.188125348516873, 0.18152141677481787, 0.12228146913860526, 0.028334356910948242, 0.057203019436980994, 0.056124437134712934, 0.02135635875830693, 0.06381855944969825, 0.054153065596308024, 0.021532441988321285, 0.08712188114545175, 0.033515640135322294, 0.05085644731298089, 0.06719477328338794, 0.023710636089422872, 0.0015872419441750804, 0.004378598773785467, 0.09678679824407611, 0.0611169994143503, 0.06550378937806402, 0.08266339038631745, 0.1871463092310088, 0.16946162389857428, 7.941370623452323, 76.35164206368583, 65.03245680672782, 56.71453203473772, 59.98040076664516, 31.23095062800816, 19.918536390577042, 40.05203267506191, 42.65112100328718, 80.35596534184047, 36.78939138139997, 0.09326649071382624, 0.02663378869848592, 1.0916513481310435, 3.303957236664636, 4.441499590873718, 2.036213240453175, 1.060848355293274, 0.23709088351045335, 38.08639076777867, 75.84527819497245, 67.88893072945731, 66.3798167364938, 58.5006776537214, 58.84712873186384, 56.43414790289742, 56.58551788330078, 60.43542439596993, 59.336122104099815, 59.59797886439732, 62.72785745348249, 62.036622864859446, 60.601409912109375, 61.05591937473842, 60.101167406354634, 63.62277848379952, 61.93876443590437, 58.962802342006135, 58.990602084568565, 58.076636041913716, 57.62974875313895, 52.1628748348781, 44.23111704417637, 42.74794067655291, 44.76199763161795, 43.12480749402727, 43.30691977909633, 43.43858119419643, 43.12973724092756, 44.465795925685335, 43.5483523096357, 42.73483984810965, 42.684670380183626, 43.33420535496303, 46.7760580607823, 51.77491174425398, 53.11215162277222, 57.44067784718105, 56.13616745812552, 52.78701761790684, 54.26665735244751, 51.48517533711025, 47.7644601549421, 45.054353509630474, 41.63288681847708, 46.34670107705252, 41.26180437632969, 44.14128031049456, 42.7455609185355, 47.69775397436959, 46.390019621167866, 48.14996010916573, 43.64013801302229, 52.59896462304251, 51.87515687942505, 55.251856327056885, 34.8969452721732, 40.46522120067051, 56.6791205406189, 46.114016328539165, 51.31745624542236, 52.16853066853115, 53.90012945447649, 51.463385786329, 50.108323778424946, 47.784787109919954, 52.17078535897391, 49.521187101091655, 51.671036175319124, 49.10383660452706, 49.42429447174072, 50.77927657536098, 54.41736377988543, 45.29485845565796, 48.96588012150356, 49.40918908800398, 51.31252302442278, 46.56704929896763, 51.03153092520577, 46.84967769895281, 50.34584099905831, 54.78978027616228, 50.44765295301165, 42.50177294867379, 42.271457535879954, 40.86779982703072, 40.49260752541678, 40.44044392449515, 41.587442125592915, 44.48149190630232, 42.805350167410715, 42.700619970049175, 43.567230565207346, 42.59367677143642, 43.73605442047119, 43.15472296306065, 44.8261399269104, 48.59932443073818, 48.87946884972708, 54.39181177956717, 55.92327465329851, 57.500039781842915, 58.85954516274588, 51.536793504442485, 50.249872480119976, 44.79510579790388, 45.64123657771519, 48.11445134026663, 52.483322279793875, 57.024817739214214, 62.12644917624337, 61.31095995221819, 62.05791909354073, 60.376079831804546, 62.11130210331508, 63.25071634565081, 47.536545344761436, 0.8950355127453804, 0.5130308823926109, 0.7701815952147756, 0.2968427858182362, 0.29462658188172747, 8.49451584475381, 60.98687512534005, 59.556171553475515, 49.22010775974819, 22.981208528791154, 15.055292436054774, 31.179335934775217, 40.66858802522932, 51.40707411084856, 53.760734694344656, 47.41921806335449, 2.5739553911345343, 0.17835166757660254, 0.11077983238335166, 0.0354747641166406, 0.04565768163385136, 0.02858754207513162, 0.011270481926788176, 0.048156088284615955, 0.0027174131578898853, 0.020121699831049358, 0.08614683310900416, 0.04184013844600745, 0.12489728948899678, 0.2404538659112794, 0.10923972073942423, 0.188006691634655, 0.11871556405510221, 0.17457190182592186, 0.19949141251189367, 0.18359917242612156, 0.26265175906675203, 0.32168777978846, 0.3115067689546517, 9.829508849552699, 88.81000532422746, 72.42872388022286, 66.75016266959054, 66.0712194442749, 30.896655423300608, 25.29722203527178, 52.01168203353882, 50.94889947346279, 86.20229775565011, 41.77995586395264, 0.3628450541624001, 0.06651317128645522, 2.9541280312197546, 4.098874364580427, 9.44326022693089, 9.23853155544826, 6.724921703338623, 0.7161064254386085, 45.56769684382847, 75.18738106318882, 72.58238329206193, 68.78768021719796, 62.75400352478027, 62.71233517783028, 59.49539566040039, 57.18068320410592, 63.0166871207101, 61.231222425188335, 63.38343388693673, 65.56483473096574, 65.30607686723981, 64.23476191929409, 64.13115038190568, 63.30051408495222, 66.01555742536272, 63.732407161167686, 60.39136586870466, 60.60068729945591, 58.91495704650879, 61.83141476767403, 54.28920773097447, 46.658112389700754, 45.38386140550886, 45.410834312438965, 46.65894269943237, 44.119824273245676, 44.90956694739205, 45.11390651975359, 46.54199409484863, 44.43818031038557, 45.03580181939261, 46.22181762967791, 47.11202778135027, 48.44768347058977, 54.43500525610787, 56.19416407176426, 60.53476973942348, 58.53612041473389, 56.29678201675415, 58.39808750152588, 55.105777399880544, 49.386788095746724, 48.74899557658604, 44.78219257082258, 47.50662292752947, 43.70119530814034, 47.301612854003906, 44.65852853230068, 49.97630105699812, 48.48818104607718, 52.33431468691145, 46.69476066316877, 55.190705231257844, 55.33522776194981, 59.03557082584926, 38.19027328491211, 44.88900375366211, 59.686471121651785, 50.40056848526001, 55.830286911555696, 54.08697346278599, 56.03401156834194, 54.579399245125906, 51.63194561004639, 50.27284322466169, 54.85560403551374, 50.63674817766462, 54.61359827859061, 51.602624211992534, 49.786813259124756, 50.12743827274868, 55.8388922555106, 47.06538799830845, 51.05727400098528, 51.36890418188912, 53.26192699159895, 49.579875060490195, 51.942081928253174, 48.104807240622385, 54.8806905065264, 58.260082381112234, 54.419496876852854, 43.246164730616975, 44.31174741472517, 43.89679752077375, 43.571138926914756, 42.790376799447195, 43.276702063424246, 45.769611494881765, 45.994017464774, 46.673110076359336, 45.35734707968575, 44.307352679116384, 47.18586976187569, 44.86301054273333, 46.43471390860421, 51.876841817583355, 51.24394430433001, 56.97258118220738, 60.098971775599885, 61.47725118909563, 61.71082878112793, 54.68469572067261, 54.17737994875227, 46.409224442073274, 47.60714251654488, 49.45142023903983, 55.02407700674874, 59.167989594595774, 64.41546372004917, 63.383037839617046, 66.18792833600725, 62.56084360395159, 64.47745554787772, 64.86563055855888, 50.16220358439854, 0.7748007359249252, 4.5271031345639905, 2.485063829592296, 0.29247008902685984, 0.2852252077843462, 11.318118708474294, 68.39047949654716, 66.11837686811174, 63.177378109523225, 45.87960147857666, 24.748364721025737, 31.920198031834193, 48.805269036974224, 61.82976804460798, 63.051476751055034, 56.21125316619873, 2.988568948847907, 0.33347577867763384, 0.2787199025707585, 0.2184660200561796, 0.17339605492140564, 0.13722646076764378, 0.15224818113659108, 0.15162491958056176, 0.18004056837941917, 0.09974137041717768, 0.11285299435257912, 0.15991508401930332], [0.0885162502527237, 0.04743022205574172, 0.07135709029223238, 0.0035808421837698135, 0.05398003238120249, 0.03863161775682654, 0.05382666311093739, 0.04431359536413636, 0.06907452563089983, 0.03445048836459007, 0.17623599538845675, 15.435786213193621, 69.35013689313615, 55.50098746163504, 57.10078239440918, 35.89778464181082, 13.953717214720589, 41.8113443510873, 43.93494660513741, 45.08349078042166, 76.5965243748256, 15.463090896606445, 0.050978838066969595, 0.07271820439824037, 0.4296844447297709, 0.6348140761256218, 2.002509049006871, 0.3977286751781191, 0.37116003941212383, 12.528243899345398, 66.38766125270298, 65.01861599513462, 64.53807858058384, 61.41525936126709, 58.7813640322004, 54.65212951387678, 52.62692417417254, 51.808558395930696, 53.31821434838431, 51.219358103615896, 54.87395770209176, 54.63521065030779, 56.21831948416573, 54.62896074567522, 55.472100325993125, 54.00074631827218, 58.2540409224374, 57.35748011725289, 59.00340066637312, 56.237239428928916, 56.32683992385864, 55.61467388698033, 55.530979360852925, 43.280784130096436, 42.99533476148333, 41.29034410204206, 42.02028015681675, 41.92233487537929, 41.326109954289024, 43.50958830969674, 42.82224818638393, 44.847015789576936, 42.30228669302804, 41.48348317827497, 39.62498249326433, 44.537056650434224, 48.83416312081473, 52.47565146854946, 54.41996588025774, 52.53998483930315, 51.082026958465576, 49.89767871584211, 47.12151207242693, 40.65070683615548, 41.76547234398978, 41.37988901138306, 42.18692227772304, 39.36863565444946, 41.25260148729597, 41.474770137241904, 46.1900817326137, 47.67286900111607, 47.88498708180019, 44.57567126410348, 49.70065212249756, 48.62668643678938, 56.42414597102574, 35.00457634244646, 38.00234535762242, 57.80009773799351, 44.52667951583862, 46.91346911021641, 50.39406844547817, 51.924023560115266, 50.48035117558071, 52.21327706745693, 50.38871485846383, 51.09890760694231, 48.637754917144775, 50.475862639290945, 47.00437934058053, 47.50872475760323, 41.64009557451521, 39.4461601802281, 46.68873657499041, 47.476853370666504, 45.975330284663606, 45.32213013512747, 47.643624033246724, 50.003395557403564, 40.15879174641201, 48.636803013937815, 49.69025066920689, 49.70571041107178, 40.12596845626831, 40.41323477881295, 39.03747756140572, 39.347329003470286, 40.23668105261666, 39.66034882409232, 40.97684832981655, 40.047335692814414, 41.34854916163853, 40.66758748463222, 40.91970981870379, 41.337664808545796, 40.71422726767403, 44.002719334193635, 40.44561685834612, 43.32685416085379, 45.223382336752756, 46.303802898951936, 45.81129373822893, 43.949603830065044, 42.23324244362967, 42.80770213263375, 43.95791734967913, 50.068395955221995, 53.12076391492571, 56.01022093636649, 56.89396926334926, 58.35729462759835, 58.974440574645996, 59.437586648123606, 54.996701104300364, 58.82752786363874, 56.62294782911028, 62.08956813812256, 20.170497179031372, 1.3905517778226306, 0.15918795232261929, 0.1886919712913888, 0.03204291041142174, 0.44756446672337397, 41.29937676021031, 61.79384585789272, 44.391811507088796, 40.62383120400565, 27.863167456218175, 12.543791362217494, 21.631409781319753, 39.882420199257986, 49.10739755630493, 47.262953077043804, 12.624294059617178, 0.4023847553346838, 0.08629168676478521, 0.07149587784494672, 0.07105367657329355, 0.05463054051090564, 0.05493860219472221, 0.04389833193272352, 0.03788978899163859, 0.020663532095828226, 0.031271331278341155, 0.03614967915096453, 0.06926559430680104, 0.06670780905655452, 0.05173001025936433, 0.031173425460500375, 0.03433133422264031, 0.030113774285252606, 0.008080258782553886, 0.05826273507305554, 0.08563473594508, 0.09930080441491944, 0.1311865627233471, 22.137716327394756, 81.40869385855538, 60.319903646196636, 63.676404680524556, 42.250824860164094, 23.116795676095144, 42.25246116093227, 46.11678171157837, 50.587836333683555, 80.86704008919853, 16.03735429900033, 0.04681404101263199, 0.07909288483538798, 2.1815484932490756, 3.2779156054769243, 2.28316068649292, 0.876408043716635, 0.43780032066362246, 14.398348076002938, 69.57449422563825, 67.10303388323102, 67.76838643210274, 63.422329902648926, 64.10213470458984, 56.321635723114014, 56.55867004394531, 55.31199993406023, 55.24835443496704, 54.39414984839303, 57.213044439043315, 55.860025201525005, 59.41005788530622, 58.46923010689871, 58.37966087886265, 57.7453042439052, 60.34507696969168, 58.775527545383994, 61.523449761526926, 57.71483986718314, 57.18816293988909, 58.889339038303916, 57.47496720722744, 46.40835591724941, 45.436629499707905, 42.81738097327096, 44.010376249040874, 43.20558377674648, 43.02311018535069, 44.47465140478951, 44.29546083722796, 45.91405759538923, 44.03574759619576, 43.168970244271414, 41.595588888440815, 46.69450010572161, 50.27348245893206, 54.6607209614345, 56.632008280072895, 55.64173017229353, 52.19148751667568, 50.88576119286673, 49.16554355621338, 41.680944034031455, 44.00796522412981, 43.142858913966585, 43.29378420966012, 41.61607912608555, 42.57749441691807, 44.67813287462507, 47.86593164716448, 49.00280284881592, 49.809047494615825, 47.457714557647705, 51.17970820835659, 49.84862443378994, 57.33867481776646, 37.2048693384443, 41.0109292439052, 59.10377434321812, 46.39780160358974, 48.211899825504844, 52.4364983694894, 52.83502967017037, 53.347358567374094, 54.037849698747905, 52.36447334289551, 52.66555963243757, 49.644986629486084, 52.104443958827424, 50.09730740955898, 44.92832708358765, 42.34522656032017, 42.616498129708425, 46.53672388621739, 49.56309168679373, 48.35282318932669, 47.6099009513855, 46.463378701891216, 53.362689767565044, 42.8414113180978, 50.64331422533308, 52.33092049189976, 52.67561714989798, 42.829856463841026, 42.17956413541521, 41.52783005578177, 41.19870778492519, 42.086524282182964, 43.12984493800572, 43.702220167432515, 41.839620045253206, 43.322792938777376, 42.27585574558803, 43.34752852576119, 43.39463036400931, 44.567173617226736, 45.23197725840977, 44.02225766863142, 45.251387051173616, 46.021886689322336, 47.95067882537842, 46.77763877596174, 45.98485279083252, 45.82808058602469, 45.4005058152335, 46.939729826790945, 53.348842007773264, 56.04405171530587, 58.20414590835571, 60.01307119641985, 61.01196507045201, 60.37720543997628, 60.6759432383946, 57.64778627668108, 60.803373200552805, 59.80803680419922, 66.00145953042167, 28.662045274462017, 1.8016021038804735, 0.1472117006778717, 0.6307975830776351, 0.04934485449588724, 0.6705688003982816, 41.78481960296631, 66.53134305136544, 49.60692439760481, 38.78700195040022, 23.57246027673994, 18.806001254490443, 28.756563356944493, 47.66606671469552, 55.323895250047954, 57.63151706968035, 18.05537520136152, 0.5148599413888795, 0.04782824730500579, 0.11206085900110857, 0.10000548338783638, 0.029759606146918874, 0.05060671589204243, 0.06985271708773715, 0.07064220615263496, 0.02062349344071533, 0.03125908711392965, 0.060045694400157244, 0.16076842322945595, 0.15957671217620373, 0.17010905487196787, 0.12011031992733479, 0.14183477205889566, 0.12660352007618972, 0.11831397988966533, 0.20502320996352605, 0.14528361628098146, 0.35015794209071566, 0.2902883546692984, 24.919403314590454, 91.11911405835832, 70.08486720493862, 71.81947803497314, 47.80502026421683, 22.300384078707012, 54.46248885563442, 60.76483849116734, 55.69159391948155, 90.15607288905552, 20.035326923642838, 0.2359136523944991, 0.16003856382199697, 2.5373362132481168, 5.647901850087302, 8.980946200234548, 7.473822866167341, 1.3029665861810957, 21.588765212467738, 69.01260035378593, 68.92117595672607, 70.1735679081508, 64.97948374067033, 64.14929907662528, 59.139578410557334, 59.67656299046108, 57.597040108272004, 58.371406418936594, 56.38885607038225, 60.63547692980085, 58.841361727033345, 60.55455820901053, 60.50662953513009, 60.427600724356516, 59.26989882332938, 65.25894028799874, 61.50132669721331, 63.5525460924421, 60.9128976549421, 60.52979482923235, 60.278492382594514, 60.81811727796282, 49.71355145318167, 48.64843429837908, 44.835780552455354, 45.60138518469674, 45.06666224343436, 45.779755864824565, 47.469453539167134, 45.784480639866416, 49.19052233014788, 45.171079771859304, 45.14369344711304, 43.62351097379412, 49.59067950929914, 52.89244610922677, 56.56209897994995, 59.70178495134626, 58.58015809740339, 55.27061646325247, 53.65866218294416, 51.10697446550642, 43.37278175354004, 47.19949517931257, 46.51772403717041, 46.29178251538958, 43.696046692984446, 46.939969539642334, 46.62277037756783, 50.832426820482524, 51.73619638170515, 51.4686073575701, 49.45860120228359, 53.62205212456839, 52.7024302482605, 58.87480340685163, 42.12306138447353, 44.38652392796108, 61.97995335715157, 49.72055523736136, 50.624144145420615, 55.39642402103969, 55.662616457257954, 56.072080748421804, 55.82214709690639, 55.104936667851035, 54.10050160544259, 52.05914865221296, 55.01899092538016, 52.44100775037493, 47.26297739573887, 47.085148675101145, 46.10419157573155, 47.86455937794277, 50.37080935069493, 47.30471175057547, 48.06117950166975, 48.302757944379536, 52.80674702780587, 44.21278074809483, 54.073066643306184, 54.33856773376465, 54.73570244652884, 43.91809374945504, 44.22268540518624, 44.07018286841256, 43.54656662259783, 45.494355133601594, 44.42268582752773, 46.6347108568464, 45.42729459490095, 45.67086717060634, 43.927515506744385, 45.63919728142874, 47.01247746603829, 47.038936206272666, 49.49020160947527, 46.0883184160505, 48.163432666233604, 48.81606306348528, 52.09384100777762, 51.055509158543174, 48.12099654333932, 46.58378750937325, 48.063646112169536, 49.1393141065325, 55.83888530731201, 59.182087489536826, 60.52884292602539, 62.05104037693569, 62.96433939252581, 63.08960846492222, 62.94953972952706, 61.959831374032156, 64.14178112574986, 63.10781969342913, 68.11340618133545, 29.870204993656703, 3.217670815331595, 3.1963739352566853, 1.3256372553961617, 0.10157889753047909, 1.1596408826964242, 49.06388446262905, 73.33517892020089, 56.055891445704866, 54.20903941563198, 37.05644539424351, 19.634469713483536, 34.31686796460833, 57.18716239929199, 62.66422585078648, 69.08083166394914, 21.8328206879752, 0.9210367032459804, 0.1495095052357231, 0.18694631781961235, 0.1789767611771822, 0.11809108113603932, 0.19674471632710525, 0.11517760104366712, 0.1475076505116054, 0.04939024170328464, 0.1668920117829527, 0.11287738768649952], [0.003367676166817546, 0.030610115866043737, 0.08326192612626723, 0.04973572798605476, 0.010963533040402191, 0.01439768189032163, 0.01205664108108197, 0.058701950790626664, 0.05661530972325376, 0.03298171789252332, 0.28661750735981123, 38.56678921835763, 69.33200904301235, 50.017097405024934, 53.859555448804585, 23.61329310280936, 25.6392662184579, 50.673580578395296, 38.2932699067252, 58.323290143694194, 58.883287157331196, 5.485489879335676, 0.07071117923728057, 0.2512285406036036, 0.7238657719322613, 3.423672309943608, 3.699132774557386, 0.6306054762431553, 11.83287513256073, 75.36752005985805, 66.19368839263916, 67.65847982679094, 61.11452742985317, 61.804011072431294, 57.016757828848704, 56.72348131452288, 49.9219765663147, 51.26010928835188, 48.82580443790981, 48.933769021715435, 52.21780381883894, 52.74292434964861, 52.74608925410679, 54.386343547276084, 52.916816915784565, 56.82139532906668, 56.841729232243125, 55.99509818213326, 55.1989631652832, 55.93447167532784, 56.061130387442454, 56.136754580906455, 56.57702718462263, 50.29098149708339, 40.91062157494681, 42.92665876661028, 40.38082490648542, 41.448523317064556, 42.83417476926531, 41.41877807889666, 42.79710265568325, 42.66292251859392, 46.22616720199585, 44.07896886553083, 41.4151337487357, 41.21355261121477, 46.65533658436367, 50.06864956447056, 50.822060108184814, 49.79277828761509, 49.18669734682356, 46.28943402426583, 41.52324424471174, 39.58789300918579, 39.613639559064595, 40.41692427226475, 40.96546023232596, 42.43719291687012, 41.406597886766704, 42.45433064869472, 48.55239282335554, 46.96674789701189, 50.951880250658306, 48.242822783333914, 50.9945387159075, 48.98472711018154, 55.756618635995046, 33.435850279671804, 37.492344106946675, 57.04369946888515, 48.18835238048008, 43.368334906441824, 45.477821895054404, 52.91374233790806, 50.26840679986136, 52.830961499895366, 49.48161711011614, 52.49023226329258, 50.5381497655596, 48.71550873347691, 48.24794707979475, 37.569545541490825, 35.38397230420794, 49.088533197130474, 51.6366981778826, 52.35741744722639, 50.02866962977818, 49.07487998689924, 45.03991862705776, 39.53830024174282, 41.05762113843645, 49.92223364966256, 48.64386585780552, 49.59787089484078, 40.137686593191965, 40.91919912610735, 40.41977998188564, 39.54982730320522, 36.22077860151018, 39.339703355516704, 40.67602954592024, 41.348493576049805, 41.45965085710798, 40.92543166024344, 40.82134069715227, 42.082049642290386, 41.27899769374302, 40.85091570445469, 41.162257535117014, 40.95928675787789, 41.617017132895334, 41.346770422799246, 42.4803273337228, 41.894604614802766, 45.16702202388218, 48.30949422291347, 52.95274257659912, 53.49451446533203, 55.633531297956196, 55.895158767700195, 58.37314346858433, 56.99134826660156, 57.44931445802961, 54.85428735188076, 53.73055519376482, 53.95047262736729, 61.55632863725935, 57.62667417526245, 57.06735808508736, 2.940444205488477, 0.8740175377045358, 0.9283458824668611, 0.11230251924800021, 0.01858222940271454, 16.677476201738628, 61.73107583182198, 51.04663978304182, 41.95516511372158, 15.866487673350743, 14.744971990585327, 14.41453216757093, 37.12014995302473, 43.26575517654419, 52.06964043208531, 23.42688683101109, 1.294828617147037, 0.06440490870071308, 0.022658484422468712, 0.009801875999463456, 0.04182085787345256, 0.06316818363432374, 0.05438494136823075, 0.0853042486788971, 0.041955889734838686, 0.03719631263187953, 0.08496641287846224, 0.025222888781822154, 0.02953239530324936, 0.027971993765926788, 0.08697951092783894, 0.0739649310708046, 0.03905864020011254, 0.02567899662868253, 0.07960486664835896, 0.018054899127621735, 0.03285439079627395, 0.370285516338689, 50.562642165592735, 78.29731137411935, 57.392405237470356, 62.58240386417934, 33.14645086015974, 27.248578446252004, 42.73569795063564, 44.247233390808105, 63.72396509987967, 66.64393166133335, 6.058324124131884, 0.13545727570142063, 0.1377908254840544, 1.878957050187247, 3.3873039186000824, 0.3722527522061552, 0.3022788826908384, 14.31836996759687, 78.86640357971191, 67.441084589277, 70.32787350245884, 65.54545620509556, 65.00944437299455, 59.66242340632847, 59.71377059391567, 54.26076875414167, 54.12659209115164, 50.77868250438145, 52.14222478866577, 54.386704853602815, 56.21780184337071, 54.909834725516184, 57.158591406685964, 54.30918380192348, 58.662661007472444, 57.769206047058105, 58.03804227284023, 58.258369650159565, 58.356356620788574, 58.07328701019287, 57.37633058003017, 58.38731779370989, 52.1894655908857, 43.76731436593192, 44.476739338466096, 43.01782955442156, 43.400869846343994, 44.06370367322649, 44.26443713051932, 45.04125268118722, 45.418828214917866, 49.029810496738975, 46.57117305483137, 44.01941932950701, 42.11717973436628, 48.13217619487217, 51.75217029026577, 53.77263001033238, 52.07460144587925, 51.44939906256539, 47.82205377306257, 44.28158181054251, 42.28955411911011, 44.64526094709124, 42.999312605176655, 42.6586389541626, 44.40054191861834, 44.31175436292376, 44.63304601396833, 49.24506916318621, 49.25029420852661, 51.22878680910383, 51.657525403159006, 53.53954921449934, 50.02918379647391, 57.82430178778512, 37.16278062547956, 40.29282249723162, 58.016301359449116, 51.25974798202515, 45.0726237978254, 47.11832284927368, 54.94958536965506, 53.16231414249965, 54.066535336630686, 50.2870522907802, 53.33479969842093, 51.83638940538679, 50.6848783493042, 50.62479727608817, 41.05517537253243, 39.27415752410889, 48.57558938435146, 51.64563703536987, 54.60724415097918, 52.94092716489519, 49.251704692840576, 46.38351263318743, 41.100112846919465, 42.2729548726763, 52.295380456107004, 49.53518077305385, 51.0733208656311, 41.773025035858154, 42.355023520333425, 41.52165310723441, 42.48260634286063, 40.21772289276123, 41.44100884028843, 43.17476504189627, 42.933763299669536, 42.21356861931937, 41.9869635445731, 43.03121873310634, 43.89747497013637, 44.408591406685964, 41.67002841404506, 44.19291237422398, 43.73552288327898, 42.927631514413015, 42.685604912894114, 43.21027728489467, 43.1113349369594, 47.602702617645264, 49.538706983838765, 55.44037137712751, 55.24714197431292, 58.23506191798619, 58.13998276846749, 60.574457849775044, 59.799698965890066, 61.55062416621617, 56.62821108954293, 58.10335186549595, 56.722793442862375, 65.31919506617955, 58.45421504974365, 64.16568987710136, 5.3295288767133435, 0.5751225905758994, 1.060819911105292, 0.19167299275951727, 0.02085373055056802, 17.03498533793858, 68.4206485748291, 57.53372117451259, 45.39684411457607, 16.816841432026454, 17.035174676350184, 21.510948862348283, 43.79925870895386, 49.68026263373238, 61.643750871930806, 32.54733896255493, 1.3373767797436034, 0.049536428680377345, 0.04516855627298355, 0.02836047881282866, 0.020258745245103325, 0.06395660061389208, 0.04530400882608124, 0.016484982833000164, 0.05373949171709163, 0.0962855237136994, 0.04966754539470587, 0.1335634301815714, 0.1797601841390133, 0.13697188799934729, 0.11121410836598702, 0.10736596664147717, 0.052243366105748076, 0.15002188059900487, 0.219162129131811, 0.19204785621591977, 0.12531153511788162, 0.36705636818494114, 58.886122022356304, 88.42504732949394, 63.9856481552124, 72.00625950949532, 35.04073824201311, 35.252453327178955, 63.20870753696987, 55.12543037959507, 70.88930879320417, 72.17241873059953, 8.10345733165741, 0.17164794515286172, 0.5043431914278439, 4.100069889000483, 11.305544206074305, 13.504136630467006, 1.74275618152959, 18.417054993765696, 82.52281665802002, 68.25155026572091, 71.94535160064697, 67.78194236755371, 66.24547331673759, 63.473635401044575, 63.503408432006836, 56.14198310034615, 56.68600620542254, 54.76072985785348, 53.230906758989605, 58.1580411366054, 59.712909017290386, 57.78539882387434, 59.668079239981516, 57.45643983568464, 63.488692147391184, 61.61607619694301, 60.54963193620954, 60.60181985582624, 60.10798358917236, 59.0433806010655, 60.074284826006206, 60.20899650028774, 55.812270232609336, 46.209647859845845, 47.086048466818674, 43.72487129483904, 44.63160078866141, 46.49944332667759, 45.65532752445766, 47.4630959374564, 46.14896576745169, 50.55096224376133, 48.39504739216396, 45.52039350782122, 46.65240444455828, 51.95937252044678, 54.497889927455354, 55.346449102674214, 54.836576393672395, 53.790250641959055, 51.224399021693635, 44.96792139325823, 43.5882453918457, 45.129731042044504, 45.62825039454869, 45.22306619371687, 46.95384856632778, 47.764175278799875, 46.379333291734966, 52.14978790283203, 52.32631731033325, 53.97146313531058, 53.88487468447004, 56.39365380150931, 53.51504291806902, 60.364545822143555, 40.64549568721226, 43.66938992909023, 61.59597505841936, 55.796688897269114, 48.50160843985421, 50.23069545200893, 57.90359115600586, 54.70839255196707, 56.18379735946655, 54.26468406404768, 55.65534169333321, 54.86008562360491, 52.519682203020366, 53.96036686216082, 44.34275027683803, 39.99791663033621, 49.75897877556937, 55.51718718664986, 57.753110545022146, 55.158479486192974, 51.70798322132656, 46.511185782296316, 41.684150627681184, 46.640300682612825, 53.901102202279226, 52.7473156111581, 53.56204400743757, 43.72609417779105, 45.48483610153198, 45.93788296835763, 44.933374949863975, 40.31235040937151, 42.471405846732004, 45.01276159286499, 44.872380188533235, 44.52897242137364, 43.247519629342214, 45.78831257138933, 45.943378993443076, 45.951286043439595, 45.06514058794294, 46.774605887276785, 45.11153023583548, 47.0298410143171, 45.57599994114467, 46.65247392654419, 44.939458097730366, 49.15021235602242, 52.04131957462856, 57.37212691988264, 58.424254417419434, 62.123635155814036, 60.799308504377095, 61.78224931444441, 62.41056101662772, 62.66320446559361, 58.914269174848286, 60.428670746939524, 58.78308023725237, 68.77185222080776, 61.69196442195347, 68.0637126650129, 5.604741811752319, 2.6090242522103444, 4.362069521631513, 0.24515369800584658, 0.16411702068788664, 21.49763090269906, 75.8433118547712, 63.06505353110177, 57.008353982652935, 24.322200434548513, 22.89198844773429, 25.019332306725637, 54.56314046042306, 59.65898404802595, 70.82774080548967, 41.821697166987825, 2.1570552246911183, 0.13583368621766567, 0.09665691985615663, 0.06937081473214285, 0.17403108227465833, 0.13853521911161287, 0.13164827866213663, 0.17208466386156424, 0.17401391533868654, 0.13469533515827997, 0.16175907078598226], [0.07778529357165098, 0.047225440187113624, 0.028824920766055584, 0.07197152410766908, 0.061733570615095754, 0.014236507771004523, 0.058978521664227755, 0.023208849265107086, 0.11328844420079674, 0.05419574544898101, 3.1921318428856984, 59.107790402003694, 61.36802550724575, 48.52349179131644, 39.755257742745535, 21.856981311525615, 33.933751242501394, 60.524986675807405, 42.10937343324934, 68.13287503378731, 45.963428020477295, 1.0132234479699815, 0.053079087154141495, 0.20680216593401773, 2.132437974214554, 1.4562834735427583, 0.8073136370096887, 6.647101879119873, 75.25863483973912, 67.48929119110107, 66.27205712454659, 67.45312581743512, 63.506708826337544, 62.74192755562918, 60.10071577344622, 55.996303694588796, 50.715318407331196, 48.77135835375105, 46.80711998258318, 47.094716344560894, 49.00451905386788, 49.184970719473704, 49.381076676504954, 50.58800309044974, 51.07290397371565, 50.49072136197771, 52.278117656707764, 54.1735063280378, 55.50676488876343, 54.29630184173584, 56.30038465772356, 53.09908206122262, 55.80849041257586, 51.685992172786165, 40.690863949911936, 42.00005395071847, 42.65652322769165, 42.05622666222708, 42.69532891682216, 42.079621246882844, 42.641341413770405, 43.32699659892491, 46.772083691188264, 42.51253570829119, 40.630887099674766, 39.914722374507356, 40.26113176345825, 41.899447509220664, 42.467452321733745, 43.13632413319179, 43.837706565856934, 39.324851581028526, 39.17586483274187, 40.74998964582171, 40.394408634730745, 41.416460854666575, 41.63570431300572, 40.16669879640852, 41.58978019441877, 43.37501212528774, 46.86858722141811, 48.04164811543056, 51.31936700003487, 49.808832100459504, 50.60736077172415, 47.41656385149275, 56.80694307599749, 36.032965319497244, 36.15913418361119, 57.12533385413033, 47.090516158512656, 43.35165922982352, 38.06612982068743, 46.14985166277204, 47.70862790516445, 49.573527881077354, 47.98508283070156, 50.50898470197405, 53.79463495526995, 51.94756753104073, 47.1141608783177, 50.29296520778111, 49.89226606913975, 48.530273233141216, 49.12568868909563, 50.78080865315029, 50.396041733878, 49.36263615744454, 48.321594510759624, 44.40853929519653, 48.51825284957886, 50.546720368521555, 51.93882669721331, 46.03717620032174, 37.89338023321969, 40.31514705930437, 39.236373220171245, 40.28318534578596, 40.81181124278477, 40.86649356569563, 41.06550734383719, 42.92914622170584, 41.260136808667866, 40.54214123317173, 40.54352739879063, 41.61821569715227, 42.514401299612864, 41.13190432957241, 40.672569343021934, 40.789983476911274, 41.16400153296334, 42.858788762773784, 43.23613500595093, 46.01077651977539, 49.91132845197405, 52.86793981279646, 53.63959632601057, 53.75045830862862, 57.35080637250628, 56.11742469242641, 57.125750746045796, 55.472058636801584, 57.473414284842356, 52.764297008514404, 53.390399183545796, 53.18491663251604, 58.00933926446097, 57.65331704275948, 66.7850843157087, 37.0928122656686, 0.06015331683946507, 0.4909098265426499, 0.08279174207044498, 0.0541083976360304, 3.097822423492159, 51.59075321469988, 57.66948202678135, 46.5002076285226, 36.66555711201259, 24.663353511265345, 13.739991494587489, 24.44347950390407, 43.72988442012242, 47.57026495252337, 38.54648310797555, 7.050103042806898, 0.22817924884813173, 0.045331411462809355, 0.08730603554951293, 0.052850553167185614, 0.020620468870869706, 0.07771647655005966, 0.07197582601968731, 0.013394986944539207, 0.03646886541641184, 0.025473110444311584, 0.04558513266965747, 0.0573805852660111, 0.048063695563801696, 0.026089700304770043, 0.09806456789374352, 0.05511307729674237, 0.07635129123393979, 0.020523339975625277, 0.046790288894304206, 0.0044083873092729065, 4.263810268470219, 71.06213133675712, 68.80104855128697, 57.40170540128435, 47.18725940159389, 26.747535160609655, 29.29696818760463, 51.585416998182026, 48.91055509022304, 75.311906678336, 50.430278982434956, 0.9833009221724102, 0.011608662083745003, 0.7547966550503458, 3.3800810490335738, 0.4856540028538023, 0.3989000166101115, 8.161829148020063, 80.59330190931047, 71.21284471239362, 69.69709518977574, 68.97048037392753, 66.48850740705217, 65.38366740090507, 63.18013654436384, 58.633687019348145, 53.510314668927876, 50.235920497349326, 48.50990458897182, 49.37053278514317, 51.76752928325108, 50.80736466816494, 50.1409455708095, 53.06551531382969, 51.97049311229161, 52.25276368004935, 54.854971749441965, 56.854774475097656, 57.1411896433149, 57.34758240836007, 57.61068984440395, 55.4460688999721, 59.05682536533901, 53.65996844427926, 41.99777841567993, 43.14130251748221, 43.52680941990444, 44.47385931015015, 42.61525787625994, 44.63785069329398, 44.95347956248692, 45.285130977630615, 46.44727625165667, 43.903332301548545, 42.98338038580758, 40.48609011513846, 42.996953691755024, 44.197272368839805, 44.39601516723633, 45.41871704374041, 45.23443692071097, 41.355372292654856, 42.492278235299246, 43.832648277282715, 43.25151136943272, 43.513437611716135, 43.23398453848702, 42.72594962801252, 43.00525678907122, 44.899290561676025, 48.44831575666155, 49.93358700616019, 52.598419189453125, 51.03007527760097, 53.379747595105854, 49.95984077453613, 57.98371083395821, 38.687715666634695, 39.41147824696132, 57.898887225559776, 50.472305161612375, 44.968369552067344, 41.03178078787667, 47.26201159613473, 48.39610004425049, 51.52625308718, 51.66515105111258, 52.01922082901001, 54.05975389480591, 54.40060472488403, 50.191490241459434, 51.25964723314558, 51.52172980989729, 51.35428169795445, 52.4125930922372, 51.478480747767854, 52.092201232910156, 51.60033130645752, 50.852423736027305, 46.89504943575178, 50.99056434631348, 51.93330635343279, 54.036477429526194, 48.95628465924944, 40.033404554639546, 42.41844320297241, 42.238745416913716, 41.830358096531455, 41.733809403010774, 42.09847518375942, 42.348867416381836, 44.1703758920942, 44.321929999760215, 43.02215828214373, 42.979280948638916, 42.818614278520855, 43.717825821467805, 43.00813681738717, 43.24423313140869, 43.19455698558262, 43.08683558872768, 43.892503534044536, 45.0222875731332, 48.17499794278826, 52.65770469393049, 54.705401352473665, 55.47702659879412, 55.99455622264317, 58.488337653023855, 57.504111426217214, 60.34613309587751, 57.17841461726597, 59.39164515904018, 54.89400325502668, 55.5371424130031, 55.25705705370222, 59.96601104736328, 62.315940448216026, 68.06674207959855, 44.30396890640259, 0.06106714066118002, 0.47000416261809214, 0.4272171285535608, 0.025845212263188193, 2.876554216657366, 54.85491268975394, 64.53414590018136, 53.344881534576416, 35.19337279456002, 25.952166182654246, 19.357570103236608, 31.584405490330287, 51.660183089120046, 52.12164075034005, 49.984333174569265, 9.84159697805132, 0.24540692727480615, 0.09419122537864105, 0.06013680129711117, 0.04957556997292808, 0.015146818477660418, 0.10191030760428735, 0.028137517294713428, 0.002554440708731168, 0.045126263185271194, 0.005643087372715984, 0.1203824124698128, 0.13090934045612812, 0.14077010990253516, 0.23402328097394534, 0.18694185305918964, 0.11079184923853193, 0.1983475110360554, 0.15907265565225057, 0.17211697569915227, 0.3057023361325264, 5.930211501462119, 83.88621997833252, 76.26674897330147, 67.4779030936105, 55.357521057128906, 31.818181106022426, 45.05176183155605, 77.08442687988281, 54.26615013395037, 81.74817589351109, 56.94541719981602, 1.6168724106890815, 0.12138215239558901, 1.5268302708864212, 5.845766569886889, 10.478231753621783, 4.368861820016589, 9.968068957328796, 83.89711475372314, 72.41876016344342, 72.02745151519775, 69.83745574951172, 66.44296196528843, 67.96601404462541, 64.46689428601945, 61.66285146985735, 54.715795857565745, 54.07792343412127, 50.935294900621685, 52.84398937225342, 54.24787984575544, 53.87914936883109, 53.84704869134085, 56.85515315192086, 55.71950830732073, 54.81570747920445, 56.585854870932444, 60.59041786193848, 58.20404168537685, 59.52470316205706, 60.106705120631624, 59.20796258108956, 61.492252349853516, 55.54041848863874, 45.51440416063581, 47.30554206030709, 45.47718613488333, 45.37239340373448, 45.75796283994402, 46.6205677986145, 47.243300097329275, 47.26423154558454, 49.19071340560913, 46.83949858801705, 45.27281876972744, 41.780143465314595, 45.418800422123496, 46.92038951601301, 46.860777446201865, 47.31238603591919, 49.05440364565168, 44.15664625167847, 41.91182572501046, 45.22795425142561, 45.74347931998116, 46.31248467309134, 45.996091502053396, 45.16445813860212, 46.36064263752529, 46.778799125126426, 50.37764637810843, 52.830162457057405, 55.76491131101336, 54.895566599709646, 54.93630388804844, 52.546891348702566, 60.826739992414204, 41.618698596954346, 41.60152612413679, 62.79008552006313, 53.68876872743879, 47.56617246355329, 44.481585706983296, 49.77904517310006, 52.121689387730186, 54.616245542253765, 52.879960196358816, 54.71053607123238, 58.572897229875835, 56.80197858810425, 50.71240016392299, 53.7567846434457, 53.88904707772391, 53.182884284428184, 54.69475323813302, 55.114438329424175, 55.244807379586355, 54.79005125590733, 53.15163128716605, 50.267065797533306, 51.41410916192191, 54.05918761662075, 57.28843239375523, 51.42097050803048, 40.68746975490025, 44.932930265154155, 43.61950881140572, 44.71653209413801, 44.77914925983974, 45.11452143532889, 44.353735378810335, 47.77190167563302, 45.73792423520769, 45.062045165470664, 44.5924859046936, 44.858084269932334, 45.94009944370815, 45.64001022066389, 45.92632464000157, 45.60090228489467, 45.627152579171316, 46.35982275009155, 47.43400035585676, 51.1059878213065, 54.659070764269146, 58.47666467939104, 58.06547723497663, 58.61845656803676, 61.463764735630576, 59.90944576263428, 62.284221921648296, 60.16347190311977, 62.46854373386928, 59.10092558179583, 59.328020504542756, 58.723631450108115, 62.67330714634487, 64.65733746119908, 71.15304851531982, 45.87587377003261, 0.10516475154353039, 2.6462987320763722, 0.9259272579635892, 0.12735076355082647, 4.262313365936279, 62.40585708618164, 69.45065648215157, 61.93795844486782, 52.838378701891216, 34.17501354217529, 23.828074080603464, 39.16678353718349, 59.698331696646555, 62.51798711504255, 61.3127178464617, 12.821499569075447, 0.39520905752267155, 0.24616018256970815, 0.20612789211528643, 0.07732056493737868, 0.07440663022654397, 0.19815537706017494, 0.16520231030881405, 0.08563507521258933, 0.1713402159512043, 0.10137505204017673], [0.020680313963176947, 0.02734359909248139, 0.06083813509238618, 0.03949704167566129, 0.020601020360897695, 0.04716855859650033, 0.1348717814045293, 0.008766742838945771, 0.09069544010396514, 0.0682811282042946, 11.436225056648254, 65.65871184212821, 61.80157920292446, 47.924598761967246, 33.79158762523106, 35.23017392839704, 43.13232544490269, 47.0319949558803, 46.0185307094029, 73.39609377724784, 25.1941785131182, 0.03513885874833379, 0.031197160615452697, 0.21945376348282608, 1.898222233567919, 0.718150335763182, 0.10983959319336073, 53.25289780752999, 70.72062042781285, 63.035989216395784, 68.15856252397809, 62.93773474012102, 64.08417361123222, 60.8861540385655, 60.29438291277204, 58.61368315560477, 52.919398171561106, 46.471320492880686, 45.46956048692976, 45.08286196844918, 44.62658766337803, 43.63289104189192, 43.4454460144043, 43.76084906714303, 45.09572308404105, 45.759988239833284, 47.67082275663103, 49.37505258832659, 53.2774909564427, 53.72842904499599, 55.6881719316755, 56.57709666660854, 57.43623794828142, 47.2007736478533, 40.316307408469065, 41.41197231837681, 41.493825571877615, 41.94455868857247, 45.33246905463082, 41.78933245795113, 40.56042194366455, 42.48063652856009, 43.41385950360979, 41.15733126231602, 42.06491191046578, 41.487488814762656, 40.69898639406477, 41.5381099155971, 40.39073998587472, 39.86135673522949, 41.025371074676514, 39.26606634684971, 41.82305901391165, 41.80601160866873, 41.161041600363596, 40.9119347844805, 40.96147544043404, 40.558247157505576, 40.793464524405344, 41.635659149714876, 47.689621107918875, 48.9222662789481, 51.82146120071411, 52.34477867398943, 53.3247560773577, 51.14547790799822, 53.3450482913426, 34.686241149902344, 39.34766946520124, 52.28873797825405, 47.792127881731304, 48.12907382420131, 42.49327877589634, 38.7552695274353, 38.81581960405622, 44.521002837589805, 47.70586947032383, 50.53243487221854, 50.35411630358015, 48.75074652263096, 48.91297306333269, 49.201597758701865, 48.87298618044172, 51.837695666721885, 48.29820340020316, 47.12411069869995, 48.09223447527204, 48.903832708086284, 51.28613029207502, 52.24441541944231, 52.13509246281215, 49.96407222747803, 49.38156305040632, 44.121828828539165, 39.60594095502581, 38.804289068494526, 39.947281633104595, 40.31715508869716, 38.25523199353899, 39.907725538526265, 40.17034660066877, 40.94876718521118, 40.50656645638602, 40.25364507947649, 41.80377081462315, 41.201111861637656, 40.30478729520525, 42.81493520736694, 41.83685118811471, 41.23422350202288, 41.571277141571045, 45.9532767023359, 45.30932807922363, 48.18505546024868, 48.039796420506065, 49.879894801548545, 51.73432036808559, 54.48974663870675, 51.95878887176514, 54.97426537105015, 52.66652543204171, 54.118216037750244, 50.81959349768502, 51.23297657285418, 48.25772666931152, 53.22534820011684, 54.27913284301758, 62.7836514881679, 56.3320198059082, 67.88813168661935, 13.059350303241185, 1.526176923087665, 0.286932781870876, 0.04553786252758332, 0.06466403443898473, 24.08317198072161, 65.77806799752372, 46.48485558373587, 42.89270639419556, 22.493460621152604, 13.04547735622951, 16.331591401781353, 32.224949496132986, 42.97149549211775, 48.160990374428884, 19.96599084990365, 0.6458540580102375, 0.07327881003064768, 0.06475195222135101, 0.024542765991230096, 0.025039887887292674, 0.08599804395011493, 0.04203608239601765, 0.06336593588015862, 0.035853060960237465, 0.031311870353030305, 0.04005529957690409, 0.019743075594305992, 0.026739156705194285, 0.0566878824361733, 0.06101419457367488, 0.054722990907196484, 0.09197424791221108, 0.06816798248993498, 0.12554125993379525, 0.12291306310466357, 16.289348091397965, 75.90187127249581, 66.67034176417759, 56.49900586264474, 41.77340371268136, 42.48609781265259, 32.63902391706194, 44.86491782324654, 52.63772514888218, 78.84245313916887, 27.927999360220774, 0.05340190018926348, 0.013281836989335716, 1.1235553047486713, 3.695671703134264, 0.6850806559835161, 0.39215315292988506, 57.48547635759626, 74.48709992000035, 66.42401422773088, 68.45257554735456, 66.12836142948696, 64.74468326568604, 63.87154483795166, 63.87271908351353, 60.6140695299421, 54.91121046883719, 49.431499753679546, 47.33296660014561, 47.125545501708984, 47.087882791246685, 46.56896700177874, 46.392913545881, 46.70425885064261, 46.92816802433559, 46.93606465203421, 49.221691949026926, 50.8551196370806, 54.89358983721052, 54.973188400268555, 57.138427734375, 56.966980934143066, 59.14148221697126, 49.74396024431501, 42.0718149457659, 43.418021474565776, 43.58549737930298, 42.57567746298653, 46.66403225490025, 45.295070375714985, 42.75591720853533, 45.58001252583095, 45.46764625821795, 43.376627581460134, 43.76860325677054, 41.879005908966064, 43.49510826383318, 42.64040340696062, 41.81661803381783, 40.645523480006624, 43.48423433303833, 41.205732413700645, 43.729978220803396, 43.685815470559255, 42.283359800066265, 42.91649355207171, 42.722881998334614, 41.838959966387065, 43.78309719903128, 44.615949971335276, 50.91140351976667, 51.81189700535366, 54.165637493133545, 54.31501334054129, 54.595856053488596, 53.74641445704869, 56.51043912342617, 36.60142176491873, 42.06867436000279, 53.91797590255737, 50.14915486744472, 49.527360575539724, 43.64745099203927, 40.96133647646223, 39.38736799785069, 46.072334085192, 49.78790760040283, 52.41456985473633, 51.50225053514753, 51.57835415431431, 50.11385801860264, 52.63984782355172, 50.762514046260286, 51.41102416174752, 51.242030075618196, 47.640983717782156, 49.473894187382285, 52.07528584344046, 52.15517623083932, 54.98033809661865, 54.082936559404644, 55.12696940558297, 51.33089753559658, 46.26621314457485, 40.52160930633545, 39.97247232709612, 42.94258403778076, 41.67394372395107, 39.25257989338466, 40.7305520602635, 43.29706375939505, 42.040409088134766, 43.03278207778931, 42.94605813707624, 43.46662412370954, 43.81163692474365, 42.82650743212019, 43.552024432591026, 43.339360918317524, 43.47390236173357, 44.76948084150042, 47.23066132409232, 47.914478710719514, 51.223207405635286, 51.29620518003191, 52.68108538218907, 54.724293504442485, 55.178924560546875, 54.56928614207676, 56.48018666676113, 53.259488173893516, 55.26816027505057, 52.87331077030727, 53.785619667598176, 49.73333297457014, 55.45749521255493, 55.79257903780256, 64.61671134403774, 57.51337684903826, 72.86752346583775, 17.408652509961808, 1.0859805324247904, 0.44756324536034037, 0.08465058875403234, 0.07124309640909944, 24.20094915798732, 70.69594042641776, 51.41647849764143, 43.692350251334055, 23.39762101854597, 21.952658006123134, 25.393584864480154, 38.729536873953684, 50.8984694480896, 57.61045707975115, 27.86344885826111, 0.8669638133474759, 0.0015431704585872857, 0.07782969011792115, 0.01758135123444455, 0.044602193270942996, 0.0195352555851319, 0.12176282411175114, 0.028618157575173036, 0.05832335539162159, 0.037014947006745, 0.15997635573148727, 0.18835165883813584, 0.12165617197751999, 0.14371810028595583, 0.08773092739284039, 0.16987947933375835, 0.2176573420209544, 0.12869583708899363, 0.2885705754160881, 0.2702484471457345, 22.196008239473613, 88.29631110600063, 74.63204629080636, 65.63782555716378, 46.50987952096121, 49.48731115886143, 56.19254166739327, 63.413839203970774, 57.744612898145405, 86.55528708866665, 32.329196793692454, 0.20884337568921701, 0.15069372526236943, 1.7507683230297906, 7.416747757366725, 7.837401253836496, 0.6342798790761403, 61.82741955348423, 75.50675501142229, 69.36147635323661, 71.48326860155377, 68.07676138196672, 66.50403663090297, 65.62238665989467, 65.15427262442452, 66.11941909790039, 56.386121954236714, 52.998854296548025, 50.503353187016074, 49.82511172975813, 48.34262670789446, 48.81224502835955, 49.74928603853498, 48.59250824792044, 50.056622232709614, 50.5004940032959, 52.93452787399292, 54.09433855329241, 58.835949080330984, 58.870405197143555, 58.62013108389718, 59.5548791885376, 61.19316019330706, 52.66613285882132, 44.54157297951834, 46.08411128180367, 46.478796754564556, 44.66109241758074, 48.98432411466326, 45.8341498374939, 43.880823612213135, 47.68948561804635, 47.062681674957275, 46.44269044058663, 46.0687175478254, 44.70411566325596, 44.44076156616211, 44.59112058367048, 44.02294206619263, 43.71623815808977, 45.890812397003174, 43.67911045891898, 46.586261068071636, 46.30904878888811, 45.673424107687815, 46.29981115886143, 46.030881132398335, 45.780579226357595, 47.21834216799055, 47.465055329459055, 52.351177964891704, 54.881381852286204, 57.41480622972761, 58.387852805001394, 57.63768012183053, 56.005753244672505, 58.161126136779785, 39.708333083561485, 45.60791996547154, 56.44019283567156, 52.19328015191214, 53.389822483062744, 46.41476910454886, 43.14921651567732, 43.25679200036185, 48.29681723458426, 53.056291580200195, 54.85282128197806, 55.18184627805437, 53.93728494644165, 52.502349921635215, 54.96069206510271, 54.03248221533639, 55.39700072152274, 54.4002434185573, 50.86562531335013, 51.3035945892334, 54.32661683218819, 55.02281938280378, 58.8279447555542, 56.11165768759591, 56.209926060267854, 55.09287459509713, 49.48737716674805, 42.63758938653128, 43.2564480645316, 44.812962668282644, 45.15821170806885, 41.808089120047434, 44.2878942489624, 44.202813557216096, 44.6124723979405, 45.02814143044608, 45.24441453388759, 45.71509940283639, 47.16676916394915, 45.23981135232108, 46.67687599999564, 46.51847096851894, 46.4418740272522, 46.68172236851284, 51.0046101297651, 49.361983026777, 53.6999066897801, 54.40215417316982, 55.380731514522004, 57.20485946110317, 59.15840802873884, 58.553991181509836, 59.69832474844796, 56.27877228600638, 58.76769692557198, 57.889402934483115, 57.467428411756245, 53.70726483208792, 57.68204436983381, 60.57046263558524, 68.06019687652588, 60.89747265407017, 75.67089925493512, 17.340982266834803, 2.425166883638927, 2.8157713753836493, 0.19942520106477396, 0.2134395276329347, 30.384548868451798, 77.70025266919816, 56.6079466683524, 58.42396259307861, 32.881755760737825, 23.654515027999878, 28.210712875638688, 49.290128231048584, 60.00367028372628, 66.88767446790422, 34.46500703266689, 1.1620075042758669, 0.17828522542757647, 0.15657471040529863, 0.1369648448058537, 0.16287603442158016, 0.24800273084214755, 0.1334754377603531, 0.1778013078229768, 0.20357052077140125, 0.09416146483272314], [0.0691183725638049, 0.044853190159691234, 0.03474371048754879, 0.048463491789464436, 0.025369343780247227, 0.060267005381839614, 0.06662499385752849, 0.04300056564222489, 0.09283056589109556, 0.09145995229482651, 20.479898725237163, 66.1452386038644, 52.21231126785278, 50.559529372623985, 24.672730105263845, 46.16030870165144, 41.446567399161204, 40.99759565080915, 58.44844109671456, 65.0486877986363, 12.669050880840846, 0.38294494418161257, 0.37725442381841795, 1.6508238060133797, 1.9299073219299316, 1.405518957546779, 14.859330654144287, 77.7569499697004, 64.69055679866246, 64.59996618543352, 60.10860892704555, 64.43585668291364, 65.07516738346645, 64.21872547694615, 59.96026488712856, 60.49399076189314, 56.843205724443706, 54.23855536324637, 49.26060880933489, 46.77349417550223, 43.67541054316929, 41.94863033294678, 40.249653339385986, 43.14964730398995, 42.3668771471296, 43.01699577059065, 43.000198500497, 42.13070092882429, 44.44227974755423, 48.45406539099557, 52.65612050465175, 53.566633292606895, 49.07838882718767, 42.75927318845476, 42.04459885188511, 39.434195382254465, 40.775149072919575, 41.77403947285244, 45.28895248685564, 42.68789087023054, 42.53199413844517, 41.995037351335796, 42.710267543792725, 42.104377678462434, 41.10548380443028, 38.23952211652483, 39.27541514805385, 41.48749576296125, 41.617531299591064, 39.98245688847133, 41.41085018430437, 41.563182490212576, 38.71030078615461, 40.25577122824532, 40.60450826372419, 42.87910876955305, 39.87671225411551, 37.776643548692974, 37.62095873696463, 40.86483294623238, 47.18985455376761, 50.69328914369856, 52.279086930411204, 52.94110434395926, 51.844737665993826, 50.476008551461355, 52.00311837877546, 23.89984549794878, 33.632692745753694, 51.78571271896362, 47.625958238329204, 50.00253745487758, 47.755128724234446, 45.4104973248073, 40.55520037242344, 39.321224621364046, 39.20714562279837, 45.69392129353115, 49.18577323641096, 49.54668698992048, 50.42981692722866, 53.255503382001606, 51.51843983786446, 47.85836158479963, 43.84244523729597, 44.32405267442976, 43.66662802015032, 46.94991588592529, 45.65861749649048, 45.36299596514021, 46.34158025469099, 44.74225432532174, 41.486787046704976, 36.976082529340474, 40.119805404118125, 39.25864219665527, 41.94010489327567, 39.09200702394758, 39.06749030521938, 38.79389803750174, 39.57550089699881, 40.82816730226789, 41.049700192042756, 40.503373759133474, 39.892050402505056, 41.733201435634065, 41.60873488017491, 41.0337610244751, 39.3935102054051, 42.04635327202933, 44.83063888549805, 47.19040693555559, 47.10148041588919, 49.009796210697715, 47.45128399985177, 49.474488258361816, 50.517666476113455, 50.844398566654746, 49.124396324157715, 47.5955251285008, 47.24138239451817, 45.80364377158028, 45.783785820007324, 48.71145445959908, 49.81685726983206, 50.92193351473127, 52.927107197897776, 54.99777112688337, 57.29239286695208, 63.03314740317208, 48.55582175936018, 0.3797619906919343, 0.8662178590893745, 0.12284814087407929, 0.15547696288142884, 5.09904453584126, 56.442701135362896, 55.89042704445975, 45.809365613119944, 36.89930840900966, 18.238521030970983, 7.620413354464939, 27.88916414124625, 40.919348512377056, 51.38203975132534, 39.644684110369, 2.421191428388868, 0.10125054086425475, 0.07932610410664763, 0.020474566878484826, 0.04438457351976207, 0.04310661727296455, 0.016431824703301703, 0.03735633833067758, 0.016443977265485694, 0.038873983680137565, 0.05267144027831299, 0.02222353669016489, 0.014752693108416029, 0.029955723123358827, 0.03674563645784344, 0.026503791566938162, 0.07361264925982271, 0.0851727689483336, 0.14611474025462354, 0.1153840928205422, 29.12152443613325, 76.89419909885952, 58.153792313167024, 58.16086557933262, 36.56103188650948, 44.484524794987266, 28.121628284454346, 48.15148523875645, 63.91789627075195, 72.35557324545724, 13.086864301136561, 0.3596309423446655, 0.15368189848959446, 2.9280520933015004, 1.750991316778319, 1.8537190215928214, 17.316246679850988, 83.24688148498535, 66.29468045915876, 67.0199751172747, 62.56895215170724, 67.81263950892857, 65.60471739087785, 66.67285006386894, 62.39073085784912, 65.11577265603202, 57.401674134390696, 56.83971078055245, 51.67008079801287, 50.26409544263567, 45.67697811126709, 44.20133359091622, 41.74162612642561, 45.45256519317627, 44.49791397367205, 44.35035160609654, 43.986811433519634, 45.21252230235508, 45.88214451926095, 52.20793737683977, 53.60791948863438, 55.323870931352886, 50.74206549780709, 44.858268397195, 42.98933151790074, 40.95733431407383, 42.522909368787495, 44.21834625516619, 45.959603037152974, 44.03990609305245, 44.9682549067906, 44.28007057734898, 44.35093872887747, 43.54119219098772, 42.574993065425325, 41.22571543284825, 41.131633349827354, 42.51139620372227, 42.316415854862754, 42.649126870291575, 44.29240362984793, 41.49991914204189, 40.92140517915998, 43.64402205603463, 42.67183010918753, 44.65999460220337, 41.970829827444895, 41.941696030753, 40.08856282915388, 43.53449412754604, 51.5440092086792, 52.72211796896798, 53.59077480861119, 54.08902318137032, 53.617115429469514, 51.964806011744905, 52.919696944100515, 25.286679880959646, 35.991290024348665, 53.32448509761265, 49.53395094190325, 51.27033008847918, 50.37891442435128, 48.19674580437796, 40.4198842048645, 40.13826676777431, 40.96501554761614, 46.64018603733608, 52.568680899483816, 52.628584793635774, 50.84371069499424, 53.46449129922049, 54.14950377600533, 50.10664231436593, 47.48663643428257, 47.212755816323416, 45.18616083690098, 47.69031940187727, 47.888607093266074, 48.54724768229893, 49.190286091395784, 46.454075063977925, 44.04269232068743, 40.947433131081716, 41.64430965696062, 41.47247723170689, 42.676919664655415, 40.85481364386422, 41.407396929604666, 41.099021979740684, 42.260781628744944, 43.052966594696045, 44.12174197605678, 42.41096346718924, 42.20572410311018, 43.62884719031197, 43.47574710845947, 41.36890738351004, 41.94189058031355, 43.40604625429426, 46.97770868028913, 49.39953456606184, 49.713871070316856, 51.27752147402082, 50.72324630192348, 52.03119952338082, 53.00484364373343, 52.995578220912385, 52.64351647240775, 50.001509121486116, 50.88123444148472, 48.56842579160418, 48.179000105176655, 50.7388345854623, 52.72055115018572, 54.468377453940256, 55.40923997334072, 56.98239203861782, 58.76095717293875, 64.10645648411342, 53.651571546282085, 1.1685833228485925, 1.7579884784562247, 0.18689043367547648, 0.10656952259263822, 5.140787575926099, 59.93484837668282, 62.988741465977256, 47.93507317134312, 34.224905082157676, 24.555826663970947, 13.46227981363024, 33.85802282605852, 47.49088873182024, 58.53383445739746, 50.523214612688335, 3.6772394350596835, 0.17377163762492792, 0.09220567585102149, 0.054158083362770934, 0.04475165417950068, 0.05025713125775967, 0.023011595742510896, 0.026562812239197747, 0.04895019817299076, 0.03488897804969123, 0.15385375783911773, 0.11967765885804381, 0.10593504485275064, 0.21420610935560294, 0.08576630388519593, 0.26582537591457367, 0.13709098446582044, 0.21286453705813202, 0.22236993057387217, 0.1958621593990496, 39.08012213025774, 89.9381217956543, 67.79938929421562, 67.71520492008754, 37.968146324157715, 54.764193534851074, 54.19414247785296, 58.25244631086077, 70.45735318320138, 77.61450495038713, 16.03630338396345, 0.34065861467804226, 0.7467256709933281, 4.575638038771493, 10.235512937818255, 5.634244731494358, 22.10127649988447, 87.2613491330828, 69.83118152618408, 67.65125370025635, 66.59382820129395, 70.52838461739677, 67.76777499062675, 68.19303948538644, 65.9930591583252, 67.20205266135079, 62.325820786612375, 59.87773418426514, 53.60723161697388, 51.67204019001552, 48.1118666103908, 46.22216156550816, 44.18679795946394, 47.268570695604595, 46.49648339407784, 47.08873394557408, 47.17299474988665, 47.51669781548636, 47.831406048366, 54.843865053994314, 57.37390218462263, 58.01114232199532, 52.32535151072911, 47.03888062068394, 45.17384515489851, 42.90542507171631, 43.51613003867013, 46.165620599474224, 49.05682509286063, 46.0479667527335, 47.34305885859898, 46.69020611899239, 46.264684540884836, 48.23374496187483, 46.19015121459961, 42.0924128804888, 42.237373147692, 44.15146289552961, 45.24068682534354, 43.75410236631121, 46.436315468379426, 43.75693028313773, 42.47830540793282, 44.6899413381304, 44.849273954119, 46.4907546043396, 43.353938238961355, 42.45578977039882, 42.22312586648123, 44.55362115587507, 52.15617329733712, 55.41303021567208, 56.93160765511649, 58.18369735990252, 57.230717182159424, 54.586531570979524, 54.454380307878765, 27.99746397563389, 40.737965788160054, 54.96291201455252, 53.94013370786394, 54.5933963911874, 51.93550198418753, 52.08460337775094, 44.99913270132882, 42.47568246296474, 42.90187454223633, 49.63036067145211, 54.577554498400005, 54.48197160448347, 53.97460719517299, 57.76645108631679, 58.11559459141323, 52.630078656332834, 50.184521198272705, 49.540774072919575, 46.799001012529644, 51.61043746130807, 50.4449223109654, 51.14060027258736, 50.6646660396031, 48.696915354047505, 47.00241300037929, 42.56643288476126, 45.82021522521973, 44.45834745679583, 46.361351353781565, 43.78426797049386, 44.0563941683088, 43.904610770089285, 43.82801382882254, 44.600538866860525, 47.31959131785801, 43.06885365077427, 45.14121641431536, 46.4025993347168, 45.8492864881243, 45.205004351479666, 44.76332821164812, 46.41384499413626, 49.64145347050258, 52.873303822108674, 52.67902871540615, 54.19040434701102, 52.23986782346453, 53.44663095474243, 56.17682831627982, 56.425987243652344, 54.91764102663313, 53.2561217716762, 52.97005748748779, 51.70010396412441, 50.341772828783306, 53.63510431562151, 56.23071159635271, 56.71411166872297, 57.75127969469343, 59.43154171534947, 62.12895747593471, 66.15402807508195, 56.05261884416853, 0.8318304643034935, 3.480429755789893, 0.8935241167034421, 0.17575006932020187, 6.822395810059138, 66.27122334071568, 68.19456114087785, 58.54544489724295, 49.71792881829398, 25.201545340674265, 14.883652823311941, 40.92473684038435, 58.39266095842634, 67.2726811000279, 59.97732966286795, 5.492617862565177, 0.2966930467103209, 0.2412669137120247, 0.14755641003804548, 0.1566683618085725, 0.11667461214321, 0.10978262339319501, 0.15415586877082074, 0.11393866395311696, 0.07872869473482881], [0.034642143973282406, 0.031858260676796944, 0.045164742906178744, 0.026029497285240462, 0.046378832044345994, 0.08190828269081456, 0.006385753280483186, 0.01816200079130275, 0.020246682588809302, 0.38945931462304934, 28.432461159569876, 62.02416474478585, 45.145826544080464, 34.004730565207346, 17.38817616871425, 61.62816606249128, 56.95452628816877, 39.85289035524641, 64.63088566916329, 57.646716254098074, 3.401097829852785, 0.21333428685154232, 0.2565990909934044, 1.3609486520290375, 1.6131235318524497, 1.0616793164185114, 42.48405851636614, 69.63363034384591, 63.89945575169155, 55.110950333731516, 56.03848620823452, 61.45272404806954, 63.06039128984724, 61.61360958644322, 58.71339675358364, 61.25083024161202, 59.502587045942036, 55.7668776512146, 58.60470608302525, 54.56366504941668, 51.38361004420689, 46.10765872682844, 42.15629461833409, 41.98958996364048, 41.0341397012983, 42.72933340072632, 43.20612226213728, 40.519615173339844, 42.96595777784075, 42.77864476612636, 42.355429989951, 42.167957169669016, 41.64007125582014, 41.549317359924316, 41.95521027701241, 41.05786085128784, 42.225015776497976, 40.152281284332275, 42.76040574482509, 43.093116760253906, 40.491937024252756, 42.08479765483311, 42.956848689488, 41.82779768535069, 41.10059922082083, 39.62935985837664, 40.45176253999983, 38.957903317042756, 38.52672937938145, 38.916432993752615, 41.06409338542393, 39.51532602310181, 41.25293847492763, 40.08197941098894, 41.016300201416016, 38.423659801483154, 40.24786417824881, 38.695949281964985, 39.93340608051845, 39.088425227573936, 47.251797744206016, 49.91145351954869, 51.927282265254426, 52.230268887111116, 51.620203154427664, 50.29654353005545, 51.814579010009766, 28.743300982883998, 30.173816953386577, 45.570170402526855, 50.784637110573904, 51.05096503666469, 49.38704170499529, 49.36944539206368, 46.16182688304356, 38.5954783303397, 38.90017768314907, 38.571580001286094, 39.963463987622944, 42.64202233723232, 45.0340439251491, 45.475438662937705, 43.92131771360125, 41.13002136775425, 40.86765391486031, 39.50025885445731, 38.73099946975708, 38.95778519766671, 38.77639899935041, 39.6188576562064, 40.35397359303066, 36.236377307346885, 38.37186792918614, 35.65387855257307, 38.97031627382551, 37.98298420224871, 40.477974619184224, 39.90350798198155, 39.10759878158569, 39.38896608352661, 40.27535820007324, 39.55658095223563, 40.64287274224417, 39.97410862786429, 41.08996500287737, 40.013122762952534, 41.9239364351545, 40.64733001164028, 42.369920458112446, 43.4558961050851, 47.761413369859966, 48.360268184116904, 49.84550469262259, 48.063156264168875, 50.909353801182334, 52.11573130743844, 51.36266469955444, 46.66012041909354, 50.89707286017281, 45.12021548407418, 48.523404938834055, 46.77516521726336, 49.570647852761404, 49.717824595315115, 50.720956870487754, 50.59981850215367, 54.449794496808735, 52.14480951854161, 60.00970826830183, 57.80600370679583, 68.31116580963135, 10.744963543755667, 1.0244596621819904, 0.6854334399104118, 0.037131895909884145, 0.2182732346866812, 29.60361303601946, 64.74072279248918, 47.642251764025005, 46.03581782749721, 25.43764512879508, 17.795797450201853, 23.82664101464408, 38.010248933519634, 44.196244035448345, 52.83755881445748, 13.484877961022512, 0.2271554209291935, 0.05142754988212671, 0.01025752753152379, 0.002998179498328162, 0.0474611089697906, 0.07763672832931791, 0.017805885257465497, 0.04161343311092683, 0.06584499749754157, 0.019859232307810868, 0.027497524761461785, 0.018613979752574648, 0.07278506045362779, 0.046368728657918315, 0.06908665783703327, 0.04911697868789945, 0.048770783336034844, 0.07285077657018389, 0.5114374650376183, 39.4212578364781, 68.5540053503854, 52.74366780689785, 42.72903462818691, 21.796933242252894, 60.931067194257466, 51.208518913814, 46.731884888240266, 71.24262469155448, 62.98924173627581, 3.513440430164337, 0.1482493028576885, 0.16882114112377167, 1.7245883792638779, 0.5535829578127179, 1.442492059298924, 50.88922834396362, 72.19972515106201, 66.64625235966274, 57.426566055842805, 59.59244809831892, 63.91681235177176, 66.05981745038713, 62.545258794512065, 60.91969299316406, 61.98672785077776, 62.59421580178397, 58.92720672062465, 61.50823320661272, 58.05148008891514, 53.94663722174508, 48.120892320360454, 44.444291251046316, 43.8214373588562, 44.74661431993757, 43.84200750078474, 45.558011054992676, 41.6917519569397, 43.74031714030674, 43.649882861546104, 43.881424631391255, 44.234910760607036, 42.763716561453684, 42.67545706885201, 42.91064664295742, 42.08299807139805, 42.34388208389282, 42.54124219076974, 43.809958934783936, 44.689934389931814, 42.81749561854771, 43.320975984845845, 44.710007735661094, 43.344033581869944, 42.69733347211565, 42.84980126789638, 41.95774289539882, 40.12416539873396, 40.641048840114046, 41.337077685764854, 42.21209560121809, 42.18342733383179, 43.5739494732448, 41.264291831425254, 42.196031366075786, 40.08275066103254, 44.01992654800415, 41.03294113704136, 41.96023382459368, 42.27575499670846, 49.182973112378804, 50.8267605645316, 54.25128098896572, 54.39249965122768, 54.304973193577354, 51.93193408421108, 53.109740597861155, 31.496319702693395, 31.703952721187047, 45.9499728339059, 52.7692997114999, 52.417432512555806, 53.63607011522566, 50.56884690693447, 48.78326409203665, 39.38798986162458, 39.940833704812185, 40.002686568668906, 42.65943104880196, 43.68029165267944, 46.055404799325125, 48.08621733529227, 45.522585664476665, 43.551006521497456, 41.97714226586478, 41.89426415307181, 41.959938526153564, 42.03287724086216, 41.45165695462908, 42.37232106072562, 42.21260976791382, 38.035179070064, 39.788959980010986, 38.171832765851704, 41.401108809879844, 39.16245828356062, 42.46888712474278, 42.034551756722585, 40.645148277282715, 41.18198694501604, 42.618342876434326, 40.86302988869803, 41.9220187323434, 42.520369802202495, 42.79968043736049, 41.3092987877982, 44.277117592947825, 42.55062920706612, 43.56427410670689, 45.21911266871861, 49.62210273742676, 52.12844998495919, 51.91679048538208, 52.417894567762104, 52.55173771721976, 55.13181924819946, 53.60118668419974, 50.15037080219814, 51.81085130146572, 48.37921939577375, 51.127568926130024, 49.536160469055176, 50.66856050491333, 53.18447889600481, 53.06835017885481, 52.78824397495815, 58.227411951337544, 54.097145625523154, 63.015985352652415, 59.961862972804475, 70.22763184138707, 13.873402987207685, 1.2222677107368196, 2.114599559988294, 0.09291576953338725, 0.12653557157942227, 31.427998065948486, 69.25512027740479, 53.220995153699604, 40.49546670913696, 24.556267874581472, 23.75151709147862, 29.742691653115408, 46.517574650900706, 50.44944558824812, 61.851397786821636, 18.826658248901367, 0.21011017342763288, 0.0616677798596876, 0.01973766427753227, 0.01678777908507202, 0.025632313419399515, 0.060108594596385956, 0.03277666800256286, 0.020226881240627596, 0.03815749480522104, 0.1545756919575589, 0.0822035064920783, 0.11330562470746891, 0.11395363243562834, 0.06381289368229252, 0.13400426081248693, 0.10557284285979611, 0.1438023607645716, 0.17140705165054115, 0.923530672277723, 52.35254328591483, 79.282149042402, 60.41729654584612, 48.759400503976, 27.175509452819824, 69.32386575426374, 70.47359112330845, 54.93386159624372, 74.07835129329136, 70.58174678257534, 4.305473404271262, 0.22416996184204305, 0.7294575518795422, 3.5908761492797305, 8.224553142275129, 3.128777299608503, 60.295147214617046, 72.17810930524553, 70.23914500645229, 57.98891156060355, 62.59516770499093, 65.23860985892159, 66.64375100816999, 62.87331799098423, 64.87586525508335, 64.68387263161796, 66.08289241790771, 60.94142695835659, 64.45292840685163, 58.14702476773943, 55.54930870873587, 51.75427212033953, 46.58920363017491, 46.15418039049421, 45.886789390019004, 45.913769245147705, 48.3617377281189, 44.11461659840175, 46.710550444466726, 46.73843356541225, 46.56191805430821, 47.532181876046316, 45.784814153398784, 45.297512667519705, 44.77954878125872, 44.84430946622576, 45.140664032527376, 44.983259541647776, 45.75710473741804, 46.30527591705322, 44.49722262791225, 47.378539834703716, 46.73827028274536, 45.37707301548549, 45.37223359516689, 43.129174436841694, 45.361338819776265, 42.225161688668386, 42.99725941249302, 42.20632859638759, 44.78211266653878, 44.66214854376656, 46.14531796319144, 42.90837458201817, 44.38438040869576, 42.67333092008318, 45.06553316116333, 42.66346795218331, 43.88760852813721, 43.861552783421104, 51.24180425916399, 52.95209986822945, 56.51693221500942, 57.02967105593, 55.983466897692, 54.63537393297468, 56.312488419669016, 34.63528306143624, 36.041782583509175, 49.16866329738072, 55.60772221429007, 55.2900401524135, 54.523077147347585, 53.446443353380474, 50.55757345472063, 42.54299661091396, 43.52134466171265, 42.2648914882115, 44.432851042066304, 46.9333096912929, 49.28017841066633, 50.3961181640625, 49.42512130737305, 45.79549700873238, 43.572434765951975, 42.22272287096296, 43.32083702087402, 44.01298529761178, 43.124526091984336, 43.832175799778526, 44.1566983631679, 40.5662966455732, 42.78900800432478, 39.127884047372, 43.53472689219883, 42.84411416734968, 44.429258823394775, 44.18354620252337, 43.689751625061035, 43.329035895211355, 44.9147572517395, 43.441985811506, 43.86959532329014, 43.904826164245605, 44.07806212561471, 43.23747253417969, 46.540983131953645, 44.912203788757324, 45.63731779370989, 47.26076092038836, 52.053218364715576, 54.38930695397513, 54.955988134656636, 54.96519449778965, 57.04255996431623, 58.62678050994873, 57.37490272521973, 51.732899461473735, 55.493024826049805, 49.88856267929077, 53.775423186165945, 53.023009708949495, 54.59391403198242, 56.04201241901943, 56.089909826006206, 53.82405710220337, 61.15033149719238, 57.22400522232056, 65.48946762084961, 62.15415164402553, 74.56257125309536, 14.31649569102696, 2.208198526075908, 3.3079980484076907, 0.09567590749689511, 0.48514803286109653, 38.58191544669015, 76.17469923836845, 59.56471783774239, 59.611680712018696, 35.3992965562003, 28.26070863859994, 36.87339162826538, 58.470105579921174, 59.119574546813965, 71.67508057185582, 23.636878762926372, 0.3469915177140917, 0.13210048153996468, 0.08647495907332216, 0.11890891939401627, 0.1317528680499111, 0.25294517991798265, 0.09980889822223357, 0.06560152556215014, 0.2186837483729635], [0.005457861307409725, 0.02830865909345448, 0.007910457090474665, 0.07164096898798432, 0.039519640284457376, 0.04277076618745923, 0.026463886922491447, 0.030864973619048084, 0.06547900249383279, 3.029595673084259, 49.91278062547956, 53.08436230250767, 45.82559313092913, 27.518606288092478, 22.509002004350933, 16.671040432793752, 35.97702884674072, 53.07636840002877, 66.90596212659563, 42.31260824203491, 0.3953193873167038, 0.046720823871770074, 0.1011371033798371, 1.6254176092999322, 0.9944130459002086, 3.3939479163714816, 75.0146974836077, 70.91703905378068, 65.58395617348808, 55.725678307669504, 52.38751009532383, 63.441597257341655, 62.34105123792376, 61.49510111127581, 56.38515615463257, 57.04605490820748, 62.16276741027832, 60.07183906010219, 57.70186758041382, 60.02875328063965, 59.60510771615164, 54.113286290849956, 48.80329574857439, 42.152247292654856, 40.80242075238909, 40.2516370500837, 40.14067084448678, 41.532353333064485, 42.27985790797642, 42.12059824807303, 42.71316146850586, 42.24484246117728, 42.576090880802695, 40.78552620751517, 41.54524918964931, 41.77248307636806, 42.63083226340157, 41.61269882747105, 41.69969722202846, 43.55889967509678, 42.40137842723301, 41.98716504233224, 42.64055279323033, 41.349066802433555, 38.59946312223162, 40.877989360264365, 39.214152881077354, 39.888645785195486, 40.7751282283238, 40.85039111546108, 39.81229897907802, 39.73997170584542, 38.795478752681184, 41.37863833563668, 41.40932852881295, 39.76071902683803, 39.68623433794294, 39.85436684744698, 41.0681928225926, 40.53185442515782, 43.93347011293684, 50.2020480292184, 51.46206562859671, 51.15180771691458, 50.240620953696116, 51.888195174080984, 51.12063462393624, 40.78140592575073, 28.005230324608938, 44.14484821047102, 51.175744261060444, 50.98817416599819, 49.96873099463326, 48.813683305467876, 49.6405154636928, 42.37093489510672, 38.425348213740754, 37.495814732142854, 39.792687688555034, 39.89252288000924, 37.30161605562483, 38.71274307795933, 39.572461060115266, 36.092299461364746, 38.21385547092983, 39.06331443786621, 38.0040476662772, 38.70480476106916, 37.46539899281093, 36.49137966973441, 35.77189370564052, 37.384931904929026, 35.824838978903635, 37.60373762675694, 39.01319013323103, 38.8062276159014, 40.27573340279715, 38.230572836739675, 38.30369220461164, 36.917634282793315, 36.333690302712576, 39.36908381325858, 39.87357514245169, 39.905279772622244, 41.08013677597046, 41.06560114451817, 42.3106175831386, 38.891752992357524, 42.47158997399466, 45.249319962092805, 49.457388741629465, 49.979386057172505, 51.32271603175572, 53.5273551259722, 54.21982996804373, 51.516119139535085, 54.494092736925396, 53.71455349240984, 52.62980072838919, 50.641361781529014, 51.38597937992641, 50.74437229973929, 51.002730642046245, 51.855542114802766, 55.53024632590157, 53.612314224243164, 56.99759122303554, 56.459001609257285, 60.30036531175886, 57.730077266693115, 65.00050898960659, 28.43472453526088, 0.5514504036733082, 0.601493772651468, 0.1762750790055309, 0.21109176932701043, 11.670151795659747, 61.31414917537144, 53.06718635559082, 56.03031512669155, 52.964151518685476, 19.648915018354142, 9.924587999071393, 25.009651729038783, 42.262007985796245, 51.92915480477469, 29.400180203574045, 0.7122733539768628, 0.049704101468835554, 0.07071904345814671, 0.009762603240752859, 0.0416878514390971, 0.030051094612904956, 0.007220574421808124, 0.020295187664617385, 0.14321721930588993, 0.03926791397056409, 0.02617141288439078, 0.03683226502367428, 0.10714878115270819, 0.05458441709301301, 0.0610659464395472, 0.055989049042442014, 0.18724656956536428, 0.09237640204706363, 4.616038339478629, 63.5825206211635, 61.70237977164132, 54.8258900642395, 32.153560229710166, 24.59872657912118, 30.158308574131556, 45.080576011112754, 57.84339196341378, 74.30880219595772, 46.274860177721294, 0.348931829312018, 0.025773153540545275, 0.4069153879370008, 0.5446617965187345, 1.4468036336558205, 9.044271213667733, 75.39682756151471, 71.7999049595424, 68.34050110408238, 58.00367300851004, 56.747779164995464, 66.32390458243233, 66.24236052376884, 60.325024468558176, 58.406967299325125, 59.30080441066197, 64.61462688446045, 61.09504468100411, 61.32660034724644, 61.00300189426967, 60.17245592389788, 56.35527195249285, 51.76778984069824, 44.55349261420113, 42.442414488111226, 41.69048391069685, 43.08711004257202, 43.58409036908831, 44.32710293361119, 44.69952985218593, 44.20646136147635, 42.76311206817627, 43.6464261327471, 41.46535185405186, 42.44914729254586, 42.517514092581614, 43.41780260631016, 42.76284456253052, 44.388483319963726, 45.35841710226876, 43.21456779752459, 43.54266520908901, 44.44939470291138, 43.44194759641375, 41.29472146715437, 42.417734486716135, 41.336754594530376, 41.488638741629465, 41.24926635197231, 41.70418575831822, 42.18666519437517, 40.935426643916536, 42.2696544783456, 42.85599906103951, 42.174036843436106, 40.651512827192036, 41.30024528503418, 40.45064735412598, 42.9152706691197, 41.18704175949097, 44.64070292881557, 51.39312560217721, 53.0791893686567, 52.86519180025373, 53.29586546761649, 53.78102690832955, 52.37710516793387, 43.011617864881245, 30.595378058297293, 43.97467293058123, 54.1845782824925, 50.74381991795131, 52.482790742601665, 50.939463819776265, 51.53896829060146, 45.84031636374337, 38.91764545440674, 40.86758095877511, 40.912007740565706, 41.45983845846993, 39.704782554081504, 40.564121859414236, 39.664034843444824, 37.80453014373779, 39.417009013039724, 40.34163359233311, 40.425908293042866, 40.24708250590733, 38.414338793073384, 37.70241246904646, 37.85247618811471, 39.40539509909493, 38.39630126953125, 39.63459185191563, 42.3038535118103, 41.317504610334126, 41.26601151057652, 40.72372545514788, 40.140618732997346, 39.78420046397618, 39.07443502971104, 40.89180237906319, 41.926736559186665, 40.579710142953054, 42.62047944750105, 43.14640596934727, 42.87128857203892, 40.30440861838204, 45.15103769302368, 49.4884923526219, 51.833092485155376, 53.972352504730225, 54.11711822237287, 55.33964681625366, 55.661091327667236, 55.584814003535676, 57.18076310838972, 56.48669712884085, 54.16309445244925, 53.71968126296997, 53.46426895686558, 52.55711909702846, 52.60899434770857, 53.734407969883506, 56.805939061301096, 56.719962051936555, 60.987319810049875, 60.14896406446184, 62.77440343584333, 59.19512925829206, 66.45457240513393, 32.29447317123413, 0.5666255950927734, 1.9913956224918365, 1.1282101635422026, 0.42885869475347654, 13.35043031828744, 67.73186670030866, 59.23963247026716, 52.389267989567344, 44.883090836661204, 21.60016894340515, 13.821725760187421, 31.527544907161168, 48.5732547896249, 58.38093934740339, 35.85028675624302, 0.7695286816784314, 0.04924609711659806, 0.01810670188362045, 0.051325566068823845, 0.04462128046101757, 0.014889665579955493, 0.027252873871475458, 0.024957098133329834, 0.0822957804692643, 0.1387548880385501, 0.08252247901899473, 0.09269063839954989, 0.22920307676706994, 0.13716080571923936, 0.1846172735095024, 0.1505344459520919, 0.30767063051462173, 0.3794761917420796, 6.929200913224902, 76.89100292750767, 70.39898831503731, 66.18475300925118, 41.22962726865496, 34.689346994672505, 24.63893927846636, 50.83158608845302, 67.95370878492082, 79.03982366834367, 52.77465329851423, 0.5973772364003318, 0.18336950189300946, 1.4338058339697974, 6.826969461781638, 3.7341994643211365, 15.042087384632655, 74.84540462493896, 74.52390452793666, 70.7893659046718, 60.15700313023159, 58.556381361825125, 68.53506456102643, 69.29637173243931, 63.21094485691616, 59.68235778808594, 62.16745049612862, 66.31956890651158, 65.6602473940168, 62.47135080610003, 64.75320870535714, 63.11392021179199, 57.930435521262034, 53.869307245527, 44.90711770738874, 43.93137870516096, 44.524417877197266, 43.8443420955113, 46.90132365907942, 47.48365913118635, 47.08709764480591, 46.84894118990217, 46.78560835974557, 46.48848601749965, 43.59613159724644, 45.08696140561785, 45.25987080165318, 45.95909929275513, 44.86055435453142, 45.494261332920615, 48.893309661320274, 46.448790958949495, 45.97053950173514, 46.8129425730024, 45.17762844903128, 43.45683411189488, 46.40151194163731, 43.56037616729736, 44.10718550000872, 44.54110745021275, 44.12609154837472, 43.78189516067505, 43.59535687310355, 41.7777532849993, 45.29091535295759, 45.029433795383994, 41.7840553011213, 44.63214274815151, 42.198946135384695, 46.253115790230886, 42.04386234283447, 45.79438877105713, 53.390399183545796, 54.03649827412197, 54.7729343686785, 55.45505639484951, 57.45181233542306, 55.384070123944966, 44.65728480475289, 32.99526500701904, 47.731657709394185, 56.21234750747681, 53.93841402871268, 52.18944822038923, 53.452113083430696, 54.66589042118618, 49.20603765760149, 41.58393675940377, 41.93099580492292, 43.995027678353445, 44.52067627225603, 40.643317426954, 42.425443513052805, 42.65184709003994, 41.571791308266775, 41.99440506526402, 43.651084899902344, 41.45901509693691, 42.93432262965611, 41.465143408094136, 41.246292522975374, 40.23350919995989, 41.96299225943429, 39.71873106275286, 42.5902339390346, 45.14051117215838, 43.17565093721662, 44.11293166024344, 42.682474749428884, 42.03949540002005, 42.41485445840018, 40.913602352142334, 43.12387990951538, 44.31674664361136, 43.17973300388881, 45.76662376948765, 46.00178555079869, 45.723176683698384, 41.48854841504778, 48.23019790649414, 51.16092027936663, 53.76470906393868, 56.800227642059326, 57.53482941218785, 60.123874119349885, 58.35771151951381, 57.24019105093819, 58.60938222067696, 58.38258607046944, 57.16958693095616, 54.90877512523106, 57.0979961667742, 55.48488848549979, 55.581211362566265, 57.141630853925435, 60.61879430498396, 57.890775203704834, 63.36354119437081, 62.87351948874337, 66.33457701546806, 61.97923074449812, 69.42777606419155, 33.21511990683419, 1.0710198666368211, 1.9675376798425401, 1.5764655960457665, 0.4273637192589896, 16.33687550680978, 74.08161694662911, 65.5692537852696, 68.68160901750836, 65.4785589490618, 27.9082247870309, 20.601382766451152, 41.61592626571655, 59.31588894980294, 67.59514004843575, 46.41138185773577, 1.4583954002176012, 0.16745970132095472, 0.11437032079058033, 0.11179427616298199, 0.08198957118604865, 0.17636696621775627, 0.12418541125953197, 0.09379601944237947, 0.30558180117181366], [0.052862736263445446, 0.13655842947108404, 0.04975118162110448, 0.04998109642682331, 0.08014089574239083, 0.029937772479440485, 0.05358590870829565, 0.12121770264846937, 0.236682405429227, 11.573536225727626, 55.773683411734446, 51.74344335283552, 41.544436250414165, 43.74468755722046, 25.2196558203016, 19.709407772336686, 38.29089362280709, 55.30483981541225, 70.87459945678711, 23.12414687020438, 0.033415637644273896, 0.026761226056675826, 0.2713763080537319, 0.2584224502955164, 2.785949272768838, 29.8540678024292, 82.32688440595354, 61.42555659157889, 66.54488509041923, 58.446043968200684, 51.03414344787598, 57.451339857918875, 62.91456249782017, 62.03660896846226, 61.72086892809187, 56.343564237867085, 57.32616458620344, 53.733549867357524, 57.17053883416312, 54.282867499760215, 58.32675034659249, 54.76037202562605, 56.02476699011666, 50.624755586896626, 45.49346229008266, 40.55909831183297, 39.46226263046265, 40.10632242475237, 41.89892986842564, 41.782029901232036, 41.92022957120623, 42.36871147155762, 39.40126092093331, 40.837470940181184, 40.848198958805625, 42.12158489227295, 40.91230303900582, 42.748934268951416, 41.02256052834647, 41.16466508592878, 42.06569010870797, 42.046471391405376, 41.500058106013704, 40.03729901994978, 39.93149880000523, 38.13056741441999, 39.15601035526821, 37.916993686131065, 39.15034062521798, 38.807947295052664, 40.695474079677034, 40.18597309929984, 41.09868846620832, 39.539651666368755, 40.898347582135884, 41.54844536100115, 41.62667165483747, 38.92129325866699, 39.44643463407244, 39.68622044154576, 39.84803009033203, 45.02348961148943, 48.91191693714687, 50.07666778564453, 46.729248046875, 48.050472327641074, 49.87978710447039, 47.67709697995867, 38.69981942858015, 49.1678329876491, 51.48969166619437, 49.57951028006417, 49.417360169546946, 46.79479735238211, 48.6468049458095, 45.31246519088745, 37.46248074940273, 38.55953529902867, 37.4760297366551, 38.991157395499094, 39.31298058373587, 40.45698758534023, 39.270245688302175, 40.13931247166225, 39.03576830455235, 39.826858929225374, 37.870159353528706, 37.596900599343435, 38.136091232299805, 36.841332639966694, 35.4654711995806, 38.09033039637974, 36.320276805332725, 37.530673844473704, 37.62992886134556, 39.74125712258475, 38.320406096322195, 40.63095310756138, 38.67195020403181, 37.45134278706142, 38.67067868368966, 40.54992321559361, 39.451461655753, 40.15390368870327, 38.91609600612095, 42.213961192539756, 39.43327822004046, 41.39257294791085, 41.12855877195086, 44.605829920087544, 48.67982278551374, 52.805208001817974, 48.71421636853899, 51.27470050539289, 53.53049223763602, 53.18011195319039, 51.20685134615217, 56.30681521551949, 51.18990468978882, 51.182237352643696, 51.23600598743984, 52.208402906145366, 52.37271043232509, 56.05533558981759, 55.85525526319231, 59.13505513327462, 58.518180165972026, 60.42402935028076, 59.012975284031455, 61.147941316877095, 62.53626782553536, 50.35041291373116, 0.21828460693359375, 2.406930902174541, 3.843629683767046, 0.44246744737029076, 9.28405441556658, 55.24064193453108, 57.7721277645656, 47.79927410398211, 56.04839433942522, 40.04802009037563, 19.013681173324585, 31.65008681161063, 44.28060558864048, 47.49711431775774, 38.99972799846104, 3.8692520345960344, 0.08116951411856071, 0.15644882858863898, 0.059471300936170986, 0.024963971693068743, 0.03199962666258216, 0.122245547494718, 0.039622438339782615, 0.052115923658545525, 0.03771101876295038, 0.1387474105826446, 0.08891325430678469, 0.18068082045231545, 0.06637092320514576, 0.06281389335968665, 0.046157449816486666, 0.11501351770545755, 0.27105818369558876, 15.034442629132952, 68.04939937591553, 58.90949576241629, 52.970290252140586, 48.6508800642831, 36.504035813467844, 18.510789666857036, 40.358323165348594, 62.88055106571743, 75.5245840890067, 25.15791412762233, 0.055571855178901126, 0.06397624420268194, 0.9600446500948497, 0.3457163061414446, 2.0205548235348294, 35.32246337618147, 81.15062386648995, 65.5233678817749, 66.0677592413766, 61.99470438276018, 50.95028911318098, 59.96389879499163, 64.90796593257359, 63.28165667397635, 63.56410094669887, 60.045178822108674, 58.64326858520508, 58.02992330278669, 58.0010917527335, 56.93535968235561, 57.80250876290457, 58.39463424682617, 59.02141039712088, 52.01824113300869, 46.776012897491455, 43.98098536900112, 41.038808890751426, 43.98854153496878, 42.177396297454834, 43.448572703770225, 43.946491037096294, 43.58477129255022, 43.13378804070609, 42.94249371119908, 42.01221677235195, 43.665818555014475, 42.53152860913958, 43.54963077817644, 41.354562827519004, 43.45321410042899, 43.69338205882481, 44.20202841077532, 42.986698150634766, 42.30363464355469, 41.4260493687221, 42.13678755078997, 39.437891823904856, 41.202115876334055, 41.521479402269634, 40.51630783081055, 41.872599669865195, 42.115946429116384, 42.815664768218994, 41.395616258893696, 40.92585897445679, 42.841314043317524, 42.56292404447283, 41.83930042811802, 41.84672457831246, 41.084336962018696, 41.729053361075266, 45.93812615530831, 49.998712471553254, 51.663028376443044, 50.06709664208548, 52.17735835484096, 52.82449620110648, 50.09030015127999, 39.831833839416504, 51.47246708188738, 52.258360454014365, 51.27540922164917, 50.90985059738159, 51.01127345221383, 51.058194637298584, 46.4648551940918, 39.64853688648769, 41.08269371305193, 40.01787533078875, 40.53963988167899, 41.91778033120291, 42.49457114083426, 40.29985754830496, 43.12173639025007, 40.64894199371338, 40.91776084899902, 38.39885125841413, 40.014974457877024, 40.365650040762766, 38.968252658843994, 38.298154490334646, 40.339879172188894, 37.454670974186485, 40.02336440767561, 39.59401089804513, 41.273324489593506, 40.80294186728341, 41.104031630924766, 40.47992011478969, 40.65370150974819, 40.84298086166382, 42.065318380083355, 41.9483072417123, 42.66075815473284, 42.085172857557026, 42.28942557743618, 42.80740336009434, 42.863214765276226, 42.698907239096506, 47.18329892839704, 50.72466720853533, 54.367531299591064, 51.221817765917095, 53.666305201394216, 55.361078534807476, 56.840332644326345, 54.10698774882725, 57.68463952200753, 53.009523255484446, 54.17830058506557, 54.66057504926409, 56.18249109813145, 56.15435784203665, 58.24468864713396, 58.73210825238909, 61.33982276916504, 59.5130649294172, 62.14270101274763, 60.848967279706685, 63.948169572012766, 64.30195099966866, 51.08195400238037, 0.5951950677803585, 1.2078011270080293, 5.824898523943765, 0.39243678056768005, 8.248077137129647, 58.5401086807251, 63.904458454677034, 52.340116432734895, 47.84998900549752, 32.799127783094136, 25.161478553499492, 40.65305185317993, 52.190198625837056, 54.444003173283164, 49.80649403163365, 4.884859366076333, 0.16745022897209438, 0.020429926059607948, 0.03294748240815742, 0.02466867834196559, 0.055932218341955116, 0.0849924957645791, 0.06148396472313574, 0.029159241755093847, 0.10331106172608477, 0.21879836650831358, 0.18126153786267551, 0.1971651909074613, 0.1960197016596794, 0.1763650934611048, 0.1977053183530058, 0.1867121011018753, 0.3892202531652791, 21.518148933138164, 82.06232479640416, 68.61974225725446, 58.41709082467215, 56.928074496132986, 35.73183386666434, 26.790983983448573, 55.609973430633545, 66.1652911049979, 84.0006081717355, 27.745987824031285, 0.1329344825020858, 0.1798038546528135, 1.9826189620154244, 3.8979276844433377, 5.474816577775138, 37.750841413225444, 82.86637728554862, 70.43860694340297, 68.1896001270839, 66.65408992767334, 53.83855104446411, 62.08765043531145, 65.85381725856236, 66.83234596252441, 63.487330300467356, 60.386113030569895, 61.17603983197893, 59.82225281851632, 61.048853056771414, 59.35055351257324, 61.4177120753697, 60.85151726858956, 60.79842608315604, 55.2208708354405, 49.201976435525076, 45.63954816545759, 43.112109661102295, 44.276165689740864, 44.96583693368094, 46.30685315813337, 46.28373302732195, 46.84172548566546, 43.13532011849539, 43.79857431139265, 43.67161335263933, 45.69568961007254, 43.15423311505999, 46.68119083132063, 44.427928243364605, 45.460482665470664, 44.782512187957764, 46.23159374509539, 45.19226482936314, 42.68091140474592, 43.7513439314706, 43.16867841993059, 42.122147696358816, 42.25703654970442, 44.0113524709429, 41.315041473933626, 44.780181067330496, 44.05519560405186, 45.27017845426287, 42.75560106549944, 43.976872035435264, 45.12588174002511, 45.48134463174002, 43.14196607044765, 44.99933072498867, 42.06878553118025, 42.9327905518668, 49.94931077957153, 53.25072302137102, 53.04215199606759, 52.553638049534385, 51.867274148123606, 54.758440426417756, 50.554926191057476, 43.62894793919155, 52.93920053754534, 55.26484251022339, 53.21039915084839, 52.75813743046352, 51.455416202545166, 53.5315831048148, 49.751610210963655, 42.419725145612446, 44.05982657841274, 41.67951617922102, 43.15968745095389, 44.74374123982021, 46.58638266154698, 43.60535185677664, 45.43565675190517, 43.70381825310843, 43.85900279453823, 41.29308516638619, 41.99167094911848, 43.73833342960903, 41.21734980174473, 39.85881716864449, 42.867672034672324, 40.7938814163208, 41.22293267931257, 41.084017344883506, 43.69401781899588, 42.99337189538138, 45.981194564274375, 43.719368321555, 42.1937940461295, 43.06386831828526, 45.2988988331386, 44.051728452954976, 44.56181655611311, 44.7278402873448, 46.713017054966514, 44.41965641294207, 45.81715454374041, 45.54458018711635, 49.98157821382795, 52.74163198471069, 58.018375396728516, 55.40592915671212, 58.26042284284319, 58.26605435780117, 60.311628341674805, 56.94937072481428, 61.422492436000276, 55.24594688415527, 56.576276779174805, 54.738030093056814, 59.17087309701102, 58.91911901746477, 60.726213455200195, 61.08422633579799, 66.05318886893136, 62.214420318603516, 65.93685517992292, 63.380626814705984, 68.54391656603131, 65.67936883653913, 57.16741909299578, 0.5074902911271367, 5.623270920344761, 7.48056435585022, 0.5956926782216344, 11.773845842906407, 62.74570042746407, 70.76443576812744, 58.55871595655169, 69.6746108191354, 51.50216368266514, 31.958249841417583, 46.045569624219624, 61.743151800973074, 62.71246024540493, 60.21753583635603, 7.234010568686894, 0.30944106408527916, 0.23381423790540012, 0.15623909341437475, 0.1795316128326314, 0.14576586468943528, 0.19880002603999206, 0.08616925869137049, 0.14675449021160603], [0.07426721163626228, 0.011866467223236603, 0.0912546750956348, 0.036326176287340264, 0.05060741139043655, 0.035582552797027996, 0.02602097318906869, 0.03281569733683552, 0.11182109865226916, 21.661504166466848, 55.60711077281407, 41.942418643406455, 44.68254498073033, 36.88823992865426, 15.462644474846975, 40.606328691755024, 47.62064981460571, 61.12262902941023, 63.60989652361189, 9.959515724863325, 0.12543211079069547, 0.10105765371450356, 0.22788137197494507, 0.7094876148871013, 3.710521306310381, 53.97640677860805, 49.74460642678397, 67.36454323359898, 62.818156242370605, 65.05033452170235, 48.46521030153547, 48.00338438579014, 59.878804206848145, 61.705902508326936, 59.97161824362618, 61.397075925554546, 57.54483829225813, 54.746854305267334, 53.21173667907715, 54.7179810660226, 51.72327273232596, 54.90569359915597, 53.87062740325928, 57.222973414829795, 50.95251601082938, 46.553736550467356, 40.80400146756853, 41.028674943106516, 41.51587568010603, 40.558205468314036, 40.470265592847554, 41.11417947496687, 41.483278206416536, 41.07623188836234, 42.01934215000698, 42.501863275255474, 42.33127110345023, 41.80003268378121, 38.342470100947786, 40.32922410964966, 40.60146495274135, 41.70503691264561, 40.887911387852256, 41.21835034234183, 39.85067040579659, 39.38640914644514, 38.6914051600865, 38.55615152631487, 39.31905330930437, 37.92959771837507, 37.84338794435774, 37.37121268681118, 38.69452837535313, 41.72307096208845, 41.526985849652974, 39.84089081627982, 39.506011962890625, 40.30271673202515, 39.62749774115426, 41.05813877923148, 38.31775883265904, 39.87653160095215, 40.06518561499459, 43.92015389033726, 44.40121589388166, 47.22586359296526, 50.69436264038086, 52.98898785454886, 42.28397471564156, 49.61461952754429, 49.003862449101035, 46.514246463775635, 48.59398474012102, 47.22117703301566, 46.567900453295024, 42.94998039518084, 38.8829357283456, 37.63975361415318, 37.622112137930735, 39.20482839856829, 39.12767212731497, 38.159861019679475, 39.4228698185512, 37.624248708997456, 36.48990317753383, 37.27562631879534, 37.77978066035679, 37.70515005929129, 37.11083589281355, 36.57780483790806, 35.35631152561733, 36.836642605917795, 37.50896419797625, 37.78656905038016, 37.68064028876168, 38.323963574000764, 38.207001073019846, 40.76851006916591, 37.14392668860299, 40.302560397556846, 37.07080384663173, 40.34381185259138, 39.99616568429129, 41.0940957069397, 39.36394214630127, 39.59704378673008, 40.6112653868539, 40.24675246647426, 40.15190608160836, 44.00803470611572, 45.60503298895699, 52.84704657963344, 50.71626683643886, 48.18741437367031, 52.89052145821707, 52.50227696555001, 51.94153649466378, 53.91350473676409, 52.363167081560405, 52.997370856148855, 51.258031776973176, 54.02760110582624, 54.36117369788033, 57.39808191571917, 55.48575006212507, 58.205733571733745, 58.24941342217581, 61.08105100904192, 58.30390466962542, 63.35662078857422, 58.03231348310198, 61.54138306209019, 4.757591383797782, 1.691508874297142, 3.1166642010211945, 0.2193831279873848, 0.3021519695009504, 30.930805819375173, 68.35524518149239, 49.38434927804129, 63.44728088378906, 47.4474972316197, 10.466356413705007, 17.957146780831472, 40.31739827564785, 47.261702401297434, 51.365805285317556, 11.413236941610064, 0.14439591605748447, 0.10578204199139561, 0.03207729856616684, 0.06192495820245572, 0.10278559063694306, 0.0737615537696651, 0.03588457551917859, 0.066763896761196, 0.05897280161402055, 0.016879829145701866, 0.04040238380964313, 0.02329692311052765, 0.059507704339921474, 0.04770684042679412, 0.045966381140585454, 0.03439358302525111, 0.06374435486005885, 30.196204049246653, 69.75127029418945, 49.638976437704905, 51.25192778451102, 44.84815182004656, 22.072286878313335, 32.00638001305716, 53.357871191842214, 66.18242536272321, 69.89516748700822, 10.368025507245745, 0.14148491940328053, 0.0919745871797204, 0.7173835369093078, 1.143717891403607, 6.718485934393747, 57.37275573185512, 55.829043184007915, 72.45821203504289, 64.71447249821254, 67.85606575012207, 50.974937847682405, 50.086016586848665, 61.27752522059849, 63.02753325871059, 62.593597412109375, 63.27363150460379, 58.95321382795061, 57.357897009168354, 54.688871588025776, 57.11182655606951, 54.76539557320731, 55.27441712788173, 55.45763765062605, 58.349728039332796, 53.50799397059849, 47.53553785596575, 42.132910455976216, 42.37019491195679, 43.13760607583182, 43.003015995025635, 42.47531073434012, 43.14751420702253, 43.932035309927805, 43.2513758795602, 41.63370670591082, 45.00857182911464, 43.53045722416469, 42.75802251270839, 41.88170181001936, 41.60582358496529, 41.69944361277989, 43.074377468654085, 42.90431335994175, 42.53502007893154, 42.12032379422869, 42.027905804770334, 39.79697125298636, 40.22421251024519, 41.59117678233555, 39.80927651269095, 39.30407299314226, 40.56631054197039, 41.31086908067976, 43.22776937484741, 42.99653679983956, 40.66367564882551, 41.45523180280413, 41.99562100001744, 41.259327343532014, 42.25437191554478, 43.228328704833984, 43.73348011289324, 42.32234614236014, 46.66480350494385, 44.4466849054609, 49.1647618838719, 52.569083895002095, 54.946441309792654, 44.08455521719796, 51.91926751817976, 50.277432509831016, 48.08429615838187, 49.78702517918178, 49.740711961473735, 48.0646709714617, 44.769737924848286, 41.76500334058489, 40.12165362494332, 38.90350934437343, 39.83972699301583, 41.220052650996614, 40.42415039879935, 39.525657994406565, 39.665500913347515, 38.8473470551627, 39.18186807632446, 39.55133506229946, 40.33025591714041, 39.19432272229876, 37.98615605490548, 37.98416192190987, 39.350372314453125, 39.26933894838606, 38.86360583986555, 39.05750226974487, 41.33668858664376, 40.09677907398769, 42.35187946047102, 39.26424591881888, 42.52402802876064, 38.91625581468855, 43.338725158146445, 41.58561127526419, 41.18681941713606, 41.557040282658164, 41.59812845502581, 42.60749673843384, 40.9138629095895, 42.227527550288606, 46.045027664729524, 48.24112742287772, 55.176822730473106, 53.84239339828491, 51.499672753470286, 54.61318138667515, 55.117269720349995, 54.22182410103934, 57.24957111903599, 54.69235610961914, 55.71623223168509, 54.47458219528198, 56.36897380011422, 55.92050232206072, 58.62746838160923, 56.99129615511213, 61.91267395019531, 59.34741292681013, 63.24891676221575, 60.697621617998394, 67.21398271833147, 57.77249949319022, 64.75933701651437, 5.634960830211639, 1.6711679143565041, 6.67019465139934, 0.12486024147697858, 0.12676228369985307, 32.798919337136404, 73.26374449048723, 54.31195960726057, 60.4146214893886, 48.34255027770996, 20.678724902016775, 24.08943404470171, 49.43066944394793, 51.84610646111624, 61.28471660614014, 15.750628198896136, 0.06303011532872915, 0.03376858102689896, 0.026980833915461386, 0.03378641292718904, 0.04372034541198185, 0.02458677577253963, 0.0767936214272465, 0.04341095719220383, 0.11450239084661007, 0.07553023671997444, 0.12399886841220514, 0.11451963920678411, 0.1562777291983366, 0.08206612350685255, 0.17020418548158237, 0.10982919803687505, 0.27060790785721367, 39.216873100825715, 80.20712797982353, 58.662438665117534, 60.5575806753976, 49.15621559960501, 23.57454126221793, 55.859048979622976, 63.19016279493059, 70.22731917245048, 76.93213626316616, 12.082170418330602, 0.24078262969851494, 0.2557021219815527, 1.6892158601965224, 3.6979146684919084, 7.843080537659781, 61.05007593972342, 59.417561939784456, 71.52118492126465, 67.82736274174282, 70.26562459128243, 53.77141407557896, 50.91292864935738, 63.70524665287563, 65.88262448992047, 66.54910264696393, 66.0912094116211, 60.49299022129604, 59.35855088915144, 56.77220555714199, 59.24196011679513, 57.703219005039756, 57.36524472917829, 56.9293703351702, 62.743157386779785, 55.10075732639858, 49.29560341153826, 43.46444238935198, 44.76327610015869, 45.00236708777291, 45.04962873458862, 45.47547687802996, 46.49938079289028, 47.32966273171561, 44.26377705165318, 46.13379437582833, 45.733724049159456, 45.27464614595686, 45.747015953063965, 44.11171225139073, 43.24241270337786, 43.630153451647075, 45.84711170196533, 46.69593143463135, 44.17776182719639, 44.60035473959786, 44.81072882243565, 42.25945104871477, 42.09153045926775, 44.39231872558594, 43.21564129420689, 42.7089056968689, 42.36608852658953, 43.66169479915074, 45.62488399233137, 45.70899888447353, 43.401943343026296, 43.74729313169207, 44.731224060058594, 44.51758084978376, 44.1229544367109, 45.330422810145784, 45.043104376111714, 45.160980565207346, 50.10080930164882, 47.45766939435686, 51.647603375571116, 56.75598498753139, 57.97519929068429, 46.683650493621826, 53.79387412752424, 52.84349257605416, 49.96598298209054, 53.24627270017351, 52.841019017355784, 51.6614476612636, 47.76458522251674, 44.01721327645438, 41.906798703329905, 42.265423025403706, 42.16095685958862, 44.560055187770296, 43.66335194451468, 43.26430300303868, 42.155641487666536, 40.780766691480366, 41.46633849825178, 42.08002424240112, 42.9593048776899, 40.122876507895334, 40.20543500355312, 39.980712890625, 41.16660015923636, 42.10020181110927, 41.679616928100586, 40.914470876966206, 41.85363803591047, 42.26605183737618, 45.29429565157209, 41.64024843488421, 44.18088851656233, 42.47412954057966, 47.0226982661656, 42.03770623888288, 45.26203516551426, 43.707243715013774, 43.90866156986782, 45.12716020856585, 45.10046870367867, 45.23737948281424, 49.441206387111116, 50.54556696755545, 56.678408350263325, 58.163339138031006, 55.13915654591152, 56.33837740761893, 58.64854921613421, 56.51606021608625, 61.34018407549177, 55.35186522347586, 56.254182611192974, 57.536938190460205, 57.67733349118914, 58.686639240809846, 61.62157222202846, 59.90793800354004, 63.351840427943635, 60.627521242414204, 66.07242843082973, 63.64346327100481, 69.1055464063372, 61.02535424913679, 67.17519092559814, 6.234062305518559, 5.85329190322331, 6.480692088603973, 0.3615502193570137, 0.9438649011509759, 40.242722511291504, 79.67726530347551, 61.35474055153983, 77.04056290217808, 58.092352867126465, 19.016333648136683, 28.554462841578893, 60.03996767316546, 59.337101800101145, 70.34660584586007, 20.542206696101598, 0.35703549161553383, 0.08678977896592446, 0.14040572302682058, 0.13803356460162572, 0.19170474819839, 0.09990280746881451, 0.26533596217632294, 0.10185958032629319], [0.08975032224719014, 0.0123133011927296, 0.06693626501198326, 0.07267966360918113, 0.06319958623498678, 0.007734645274467766, 0.06599954741873912, 0.06471516205263989, 0.9390200525522232, 34.29284804207938, 57.207187107631135, 40.18412487847464, 29.886995315551758, 14.748487779072352, 24.305451801845006, 34.151038782937185, 50.43679986681257, 62.24916131155831, 52.99970892497471, 3.0850635766983032, 0.14289134607783385, 0.06165171215044601, 0.44819026600037304, 0.572222966168608, 23.484298058918544, 59.06473241533552, 59.45298385620117, 63.2757784979684, 61.16598578861782, 62.215483392987935, 55.08476604734148, 46.58116456440517, 49.03126614434378, 57.816627502441406, 57.48577165603638, 58.951622690473286, 56.68990761893136, 57.69155992780413, 58.032900605882915, 57.665309633527485, 55.39223773138863, 53.3429707799639, 54.82837751933506, 54.62515313284737, 51.542376382010325, 48.19315358570644, 43.63035494940621, 42.22262559618269, 42.608052594321116, 40.96645729882376, 41.53792231423514, 40.72575085503714, 39.63332380567278, 40.96479320526123, 41.09591613497053, 42.218574796404155, 42.327463490622385, 40.03155633381435, 40.19759743554251, 40.32518025806972, 40.50948469979422, 39.64466673987252, 39.47120148794991, 40.30425228391375, 40.30643401827131, 38.722411496298655, 37.88579627445766, 37.09586599894932, 37.99842657361712, 38.48311901092529, 37.37325545719692, 38.09070907320295, 36.46022742135184, 38.12975100108555, 38.856080940791536, 39.06025723048619, 39.95486559186663, 41.389018944331575, 39.90301465988159, 39.18215642656599, 38.66706909452166, 40.75989082881382, 39.379287242889404, 40.792926039014546, 45.01361274719238, 47.84172412327358, 48.895748479025706, 49.55693905694144, 40.75071573257446, 50.27343382154192, 49.13588864462716, 44.37671307155064, 40.31359066282, 42.2617370060512, 40.63645955494472, 38.21226780755179, 37.043337617601665, 37.45453895841326, 39.01172406332833, 37.285124506269185, 38.748418603624614, 38.6471277645656, 36.17564310346331, 37.445582730429514, 36.533961704799104, 35.746939250401084, 35.82459579195295, 36.98586211885725, 37.3837229183742, 37.08897338594709, 34.81218767166138, 36.521281242370605, 36.34655141830444, 39.19778639929635, 39.33104590007237, 40.79882505961827, 38.63031312397548, 40.85537297385079, 38.98161404473441, 38.13791166033064, 36.88215330668858, 40.46075003487723, 40.68595157350813, 40.03724690846035, 38.90800482886178, 38.27843202863421, 40.20392377035958, 39.933753490448, 44.37540333611624, 41.80802311216082, 44.99111100605556, 52.4472576550075, 48.84553037370954, 46.822815963200156, 50.46802159718105, 51.477358613695415, 51.11844594138009, 51.93340710231236, 51.064274311065674, 53.09150505065918, 52.01806047984532, 55.419947147369385, 53.511770316532676, 57.583769048963276, 58.81171376364571, 61.66817378997803, 57.614525250026155, 62.6824231828962, 58.27711936405727, 66.10517529078892, 58.51952811649868, 73.03861590794155, 16.51605565207345, 1.4626633312020982, 3.840985894203186, 0.04401820871446814, 0.07514647088412728, 11.765574012483869, 64.86724254063198, 51.70834452765328, 51.422012737819124, 42.91082729612078, 17.66312680925642, 14.981889929090228, 31.679429054260254, 44.598009722573416, 56.90020874568394, 22.52686755997794, 0.3838529054607664, 0.06956509287868227, 0.12128274701535702, 0.03709990298375487, 0.04245105066469737, 0.004814234370964446, 0.02547595520237727, 0.06961268532489027, 0.05752074345946312, 0.013424114756552237, 0.1084005425551108, 0.019466655694746544, 0.0672870676166245, 0.03811289809112038, 0.007011216258563633, 0.06951244534658534, 0.9750067272356578, 44.22213649749756, 65.5596444266183, 46.21038089479719, 37.502495425088064, 25.1947534765516, 25.026330879756383, 30.423809664590017, 57.64637926646641, 68.09636919839042, 58.65936061314174, 2.9623814054897855, 0.14689395629933902, 0.0945511067818318, 0.8766507964049066, 1.3596052612577165, 28.280125379562378, 61.93217754364014, 60.039717538016184, 65.4132389341082, 63.96870844704764, 65.79981585911342, 56.09656967435564, 48.64297996248518, 52.627240317208425, 58.222127846309114, 59.412031173706055, 60.20067950657436, 57.77532046181815, 59.37209987640381, 58.86361680712019, 59.164334842136924, 56.638206073216026, 55.913099016462056, 56.47224487577166, 55.30144214630127, 53.71756553649902, 50.52711255209786, 46.24503156117031, 43.74793931416103, 43.51458406448364, 43.30828857421875, 43.28135388238089, 42.27340303148542, 40.07476370675223, 42.478326252528596, 42.17501653943743, 44.84372929164341, 44.535538469042095, 42.54256929670061, 41.48218386513846, 41.91038397380284, 42.35003818784441, 41.669719219207764, 40.60703393391201, 40.90192243031093, 42.52337837219238, 40.51500851767403, 39.11745480128697, 39.53011873790196, 40.681240694863455, 40.166591099330354, 40.664287090301514, 39.624357155391145, 39.43073170525687, 40.48608316693987, 41.83149412700108, 42.45784991128104, 42.340418406895225, 42.5510322025844, 41.80379165921892, 40.73467581612723, 41.0359844480242, 42.34275300162179, 41.29542670931135, 44.25495283944266, 46.85884237289429, 50.84627110617501, 51.446136883326936, 50.904323305402485, 41.894500391823904, 53.40282603672573, 53.09133134569441, 46.680766991206575, 42.10942554473877, 44.605975832257954, 42.083720684051514, 38.82765586035592, 40.78247594833374, 38.18976606641497, 39.67859131949288, 39.494134017399375, 40.923343726566856, 38.758743626730784, 37.65683576038906, 38.630434717450825, 38.27708060400826, 37.511079924447195, 38.72193554469517, 38.19830887658255, 37.50453472137451, 39.20054483413696, 38.142598220280235, 37.75145285470145, 39.18762813295637, 41.10363558360508, 41.09231696810041, 41.97808027267456, 42.20445953096662, 42.735829966408865, 40.68977655683245, 39.50099188940865, 39.40273741313389, 42.55092797960554, 43.75620767048427, 42.25526475906372, 40.89066287449428, 40.47429207393101, 42.134393896375386, 43.459206921713694, 44.423717635018484, 42.86236013684954, 47.067878927503315, 52.32999638148716, 52.267347948891775, 52.659698826926096, 53.308486870356965, 54.5450473512922, 53.315692152295796, 54.21146781103951, 54.086608682359966, 54.82502153941563, 53.31929479326521, 56.76085914884295, 54.79036045074463, 59.65960243770054, 58.26415402548653, 63.924559593200684, 56.57139566966465, 63.13491071973528, 60.79995468684605, 67.95990657806396, 61.277657236371724, 74.08688368116105, 18.34494137763977, 0.4993132927588054, 3.303554892539978, 0.26528710765498026, 0.16185060515999794, 12.903486575399127, 71.7326602935791, 56.47251238141741, 57.74387638909476, 42.55829654421125, 22.635532174791607, 20.27746295928955, 38.45712232589722, 51.74285275595528, 64.94240815298897, 29.284378051757812, 0.4091675542294979, 0.053415016271173954, 0.012685247796720691, 0.018701972173792974, 0.0226614021230489, 0.06121160076665027, 0.048757090499358516, 0.03146154839279396, 0.20772972330451012, 0.13323808621082986, 0.3073234648576805, 0.08546968908714396, 0.11694628399397645, 0.17635517327913217, 0.13388922198542527, 0.2640475056001118, 1.9195423466818673, 55.13802398954119, 75.48578534807477, 53.94640098299299, 42.75832823344639, 25.448291506086075, 34.88706840787615, 48.30612782069615, 63.21343231201172, 73.78882680620465, 64.6873675755092, 4.206804641655513, 0.18914390275520937, 0.28957054604377064, 2.386938980647496, 3.001086780003139, 31.390752247401647, 62.634869711739675, 59.50157955714634, 66.93643692561558, 66.55348001207624, 66.11927318572998, 58.232522351401194, 51.45777859006609, 53.74797780173165, 61.439334869384766, 61.70898750850132, 63.703690256391255, 60.18398993355887, 63.40903799874442, 62.42549269539969, 62.80380821228027, 59.059264183044434, 58.433731760297505, 60.40369892120361, 59.31470775604248, 56.70089619500296, 52.569598061697825, 49.7251375743321, 45.32584742137364, 46.55276032856533, 45.37554441179548, 46.66240985052926, 45.73706265858242, 41.68269150597708, 44.460310322897776, 45.12371390206473, 46.35477488381522, 47.04750680923462, 45.018028327396934, 43.480371134621755, 44.71971436909267, 44.257377760750906, 43.811056750161306, 43.28830902917044, 41.34482840129307, 45.09749140058245, 43.421665804726736, 42.090658460344585, 40.82844870431082, 41.15383284432547, 43.29358966009957, 42.019192763737266, 43.15424353735787, 42.30011885506766, 42.706407819475444, 43.85651881354195, 44.14825630187988, 43.98093673161098, 45.38871124812535, 43.37575905663626, 43.50231007167271, 43.85407999583653, 45.40234013966152, 44.35134867259434, 45.63730737141201, 50.96764918736049, 53.07256078720093, 54.56218160901751, 52.74654088701521, 45.10515178952898, 54.20767409460885, 54.20443623406546, 50.364677565438406, 43.328942094530376, 47.94201094763619, 45.2633171081543, 41.189292975834434, 42.720352854047505, 41.22924164363316, 43.20554903575352, 41.0778751373291, 44.335121154785156, 42.4778641973223, 41.02616664341518, 42.07491731643677, 40.76934732709612, 39.65841375078474, 40.53382076535906, 40.65623760223389, 41.84261819294521, 41.578763825552805, 40.868821212223594, 40.41646569115775, 41.41409499304635, 44.20211178915841, 44.23943403788975, 44.53327335630144, 43.54741430282593, 44.67262295314244, 43.95112548555647, 42.71093109675816, 41.654586042676655, 45.47011981691633, 44.0398713520595, 43.858648436410085, 43.631473609379356, 42.40895543779646, 44.48764106205532, 45.830390862056184, 48.18184886659895, 45.51210083280291, 50.85321583066668, 55.21288735525948, 54.914483070373535, 56.296142782483784, 55.8481194632394, 58.447287695748464, 56.036641461508616, 55.91246325629098, 56.533795492989675, 58.12534638813564, 56.73840257099697, 60.6254437310355, 57.180519921439036, 61.66606848580496, 61.81812981196812, 66.48911190032959, 58.08658586229597, 66.21273340497697, 65.54527555193219, 70.85719421931675, 63.70931829724993, 76.81399604252407, 20.16398845400129, 2.5257249048777988, 10.510211706161499, 0.21633164744291986, 0.32178505456873346, 15.94978962625776, 76.85061304909843, 63.01062829153878, 66.25838306971959, 52.25751972198486, 27.64690998622349, 24.530173914773123, 47.23454189300537, 61.08660956791469, 73.71637099129813, 36.96971450533186, 0.55546271694558, 0.1456986354397876, 0.17447160077946527, 0.10465736341263567, 0.09154295748365776, 0.126789425100599, 0.12581415314759525, 0.16210072673857212], [0.03817400695489986, 0.044982515541570525, 0.03858337052432554, 0.06815269509596483, 0.014959176403603383, 0.03760428859719208, 0.023681031606559242, 0.12478541263512202, 2.322844454220363, 47.015552043914795, 55.31164557593209, 50.62204926354544, 31.19227695465088, 28.454719713756017, 35.59918580736433, 41.0034738268171, 57.17892530986241, 67.17824813297817, 41.73715843473162, 0.1768654723252569, 0.0939685030441199, 0.03822331948738013, 0.7940565826637405, 7.856778911181858, 53.474965708596365, 69.36287988935197, 65.09389972686768, 64.25008269718715, 64.52113887241909, 62.68157550266811, 56.55141612461635, 47.37986694063459, 43.31741155896868, 44.71440594536917, 49.75969444002424, 49.40783766337803, 49.13960245677403, 51.80752311434065, 52.08835540499006, 53.63920375279018, 54.842510155269075, 55.69673558643886, 53.278765950884136, 54.87314823695591, 51.7414561680385, 47.210011277879985, 42.17087541307722, 39.77991689954485, 40.45155756814139, 40.02058860233852, 42.13836479187012, 40.45175906590053, 41.46051590783255, 39.81499488013131, 41.588845661708284, 41.582158020564485, 41.0233804157802, 39.27961533410208, 38.67501088551113, 39.80591011047363, 41.759663649967735, 39.12263468333653, 40.619200229644775, 39.00642606190273, 41.09068414143154, 38.85577869415283, 38.883752141680034, 39.44768530981881, 39.01427057811192, 38.97918217522757, 37.90927423749651, 34.726526805332725, 37.65397310256958, 37.651162556239534, 37.627590792519705, 37.43463931764875, 37.29888193947928, 39.897383144923616, 37.771362917763845, 39.80410705293928, 39.13237953186035, 37.92116955348423, 39.06592696053641, 40.72151592799595, 46.13403408867972, 50.10086836133684, 51.274057797023225, 48.3401392527989, 35.00816856111799, 50.474611963544575, 50.29016508374895, 44.853925773075645, 38.29102911267962, 39.67636789594378, 38.094356877463206, 37.01422813960484, 36.987376826150076, 36.645483766283306, 36.64655378886631, 39.29708310535976, 36.46230493273054, 37.7755457333156, 35.37114245550973, 36.60537528991699, 36.6720085144043, 35.01878193446568, 36.12760673250471, 35.36415951592581, 36.288481848580496, 36.06094224112374, 37.064845766339985, 36.243238653455464, 36.38050379071917, 40.080464703696116, 39.78204304831368, 41.41580424989973, 40.01876470020839, 40.405456270490376, 38.70925160816738, 38.76619209562029, 36.86112458365304, 39.86993081229073, 40.54816879544939, 39.76914719172886, 40.10062142780849, 39.5205580166408, 41.12992409297398, 42.06884111676897, 40.84913001741682, 40.41491971697126, 44.98507649557931, 48.09319332667759, 48.63098042351859, 48.4512756892613, 51.50847612108503, 52.269421986171174, 51.48713820321219, 54.72861180986677, 52.59923560278756, 54.33186272212437, 54.724276133946006, 55.588381903512136, 54.60530907767159, 56.12629059382847, 52.0504321370806, 55.1489257131304, 42.408239773341585, 55.28600672313145, 59.82551152365548, 61.02375616346087, 58.37469291687012, 72.12046704973493, 39.318257740565706, 0.4224085137248039, 7.245948442390986, 0.16781091104660714, 0.02703744069939213, 4.217557847499847, 56.115420137132915, 61.319110189165386, 49.04689264297485, 59.16455718449184, 34.75031048910958, 9.79072574206761, 37.63110658100673, 37.409170695713584, 55.831634862082346, 36.55347572054182, 1.001370255436216, 0.015558857171397125, 0.019442381104454398, 0.08643515620912824, 0.059986471863729615, 0.011866455348873777, 0.02943554800003767, 0.011035908129997551, 0.06684460171631404, 0.028052579977416565, 0.02882176897089396, 0.016776839404233863, 0.0475082942949874, 0.0689943227916956, 0.01488803031056055, 0.039908736012876034, 3.095226837056024, 59.70179189954485, 64.86510944366455, 58.75063214983259, 37.23952347891671, 33.61365120751517, 33.16758380617414, 43.79110152380807, 62.642957414899556, 71.98350415910993, 44.681857109069824, 0.12009304442575999, 0.034847662052405734, 0.4436613161649023, 0.7820413559675217, 10.167065364973885, 54.822162355695454, 69.74642045157296, 67.9823214667184, 65.03164386749268, 67.52128764561245, 63.69326795850481, 58.22639751434326, 49.180110454559326, 47.55630949565342, 47.38330977303641, 51.224329539707725, 51.69119984763009, 51.162049361637656, 55.01005901609148, 53.97055639539446, 55.64699690682547, 56.964851311274934, 58.25587177276611, 56.729164940970286, 56.98776994432722, 54.49826513017927, 48.23978989464896, 44.36254916872297, 42.52476453781128, 43.532208170209614, 42.57507644380842, 42.24552685873849, 42.928600788116455, 43.20705679484776, 41.79711791447231, 42.26909514835903, 42.72025210516793, 42.136975152151926, 40.93542316981724, 40.88504525593349, 41.25981024333409, 43.02085549490792, 40.835174560546875, 41.446233885628835, 41.562796865190776, 41.13642413275582, 40.43980469022478, 40.5898197719029, 40.82134417125157, 41.27760110582624, 41.357171876089915, 39.366287163325715, 37.7214401108878, 39.8049373626709, 39.26677853720528, 39.62928342819214, 39.6864983694894, 40.2432609966823, 41.957416330065044, 41.45719119480678, 41.784249850681846, 40.47978115081787, 40.84332479749407, 42.585300718035015, 43.128736700330464, 49.20073618207659, 51.729786668504985, 53.90090765271868, 49.75627940041678, 38.489817074366975, 50.66296720504761, 50.462494305201936, 47.86320447921753, 40.85833290645054, 41.084927558898926, 40.50031655175345, 39.21362134388515, 38.70011820111956, 38.63915123258318, 38.1449293409075, 40.5071952683585, 37.59492383684431, 39.781789439065115, 37.992774214063374, 37.54421935762678, 38.15678644180298, 37.14014686856951, 39.85229281016758, 38.273252146584646, 36.635818822043284, 38.49744619641985, 39.73804358073643, 38.027786186763215, 39.101699760981965, 41.890574659620015, 41.42157820292881, 42.2649644442967, 40.87405667986189, 42.99399028505598, 40.707532678331646, 40.624567713056294, 40.001373359135215, 42.70328460420881, 40.93096937452044, 41.71456636701311, 41.569227422986714, 40.12473167691912, 43.44627285003662, 43.33419145856585, 41.909730843135286, 41.900930949619834, 47.42162561416626, 49.36786815098354, 51.497664724077495, 50.957452705928254, 51.66385868617466, 54.323198318481445, 54.259097712380544, 56.73819065093994, 56.00450951712472, 56.85884264537266, 56.54769883837019, 57.271638597760884, 57.55963100705828, 57.4059750693185, 52.81414338520595, 57.38655138015747, 44.64571257999965, 56.541855403355186, 61.464904240199495, 62.57991640908377, 59.949668884277344, 71.29816859109062, 42.70311089924404, 0.23366398311087064, 4.163159097943987, 0.3350183330476284, 0.12302769481071404, 4.447951427527836, 61.19404261452811, 62.7634391784668, 56.47026811327253, 54.1743609564645, 31.861899171556743, 17.816883495875768, 44.42560059683663, 43.15782880783081, 61.62604686192104, 44.6368327822004, 1.5579021807227815, 0.027522396462570344, 0.03830455030713763, 0.05375092163948076, 0.03275026281231216, 0.0067075154344950405, 0.06134962836014373, 0.03981354433510985, 0.15944466926157475, 0.16656883912427084, 0.11017758505684988, 0.2066698923174824, 0.16847917304507323, 0.1253275621150221, 0.12663950957357883, 0.22109410831970827, 5.42541184595653, 73.62409891401018, 71.44092627934047, 67.84215545654297, 44.778867857796804, 37.755823271615164, 46.29068470001221, 57.96749373844692, 65.73469734191895, 79.60552515302385, 49.727308886391775, 0.31392528489232063, 0.16271039045282773, 1.3148663533585412, 2.3706882297992706, 11.117684892245702, 58.661549295697895, 73.00200584956578, 69.4610926764352, 68.66801139286586, 70.45123876844133, 66.19399411337716, 61.308889389038086, 52.21033797945295, 50.01525960649763, 50.0371846471514, 54.7937650680542, 54.08177273614066, 52.84267963681902, 56.63548585346767, 54.64157520021711, 57.89789015906197, 58.9154086794172, 61.16965443747384, 58.69481727055141, 59.326491900852744, 55.415041719164165, 50.36518825803484, 47.32983991077968, 44.321064949035645, 44.99725668770926, 43.50889348983765, 45.61274896349226, 45.725792680467876, 44.93661628450666, 43.42813457761492, 44.621873310634065, 46.09544379370553, 44.23314591816494, 42.83288240432739, 41.94479840142386, 43.75181640897478, 45.8441378729684, 43.46672139848982, 43.86526312146868, 44.28245380946568, 44.10421167101179, 42.00878783634731, 42.69149351119995, 42.814216068812776, 45.52382591792515, 44.504205567496165, 41.11019468307495, 39.88500492913382, 42.48541341509138, 42.01191452571324, 41.686294146946494, 42.20037399019514, 42.08021184376308, 43.8914543560573, 42.305493286677766, 44.98413154057094, 42.74602992194039, 43.71526888438633, 43.822392736162456, 46.4143522126334, 51.08061300005232, 53.37437663759504, 54.580059323992046, 51.837911060878206, 41.37503569466727, 54.23310797555106, 53.98670053482056, 50.35211869648525, 42.87043046951294, 44.05146789550781, 44.213805607386995, 42.67737477166312, 41.41708271844046, 41.49541323525565, 39.32874952043806, 43.02155378886631, 39.1251985686166, 41.511449677603586, 40.015165533338276, 41.303274699619834, 40.52952330453055, 38.59842784064156, 41.61694417681013, 40.74463258470808, 39.673494815826416, 42.221465247017996, 43.25785854884556, 40.051650524139404, 40.753943170819966, 44.39326368059431, 43.65997511999947, 44.651698453085764, 44.31638881138393, 45.16835955211094, 42.88582072939192, 43.54826545715332, 42.227989605494905, 45.24974380220686, 43.06891965866089, 43.988211495535715, 45.82365458352225, 43.01868765694754, 45.62927872794015, 46.80201653071812, 45.21663563592093, 43.84616599764143, 49.717293058122905, 51.49957547869001, 53.500819955553325, 53.68741730281285, 55.33681889942714, 56.65108803340367, 57.979691301073345, 61.049353327069966, 58.37720121656145, 60.135741642543245, 59.460328102111816, 60.61049815586635, 60.257571356637136, 59.21640464237758, 53.750433989933555, 57.228684834071565, 49.674790927342, 60.8351195199149, 64.82927758353097, 67.31614903041294, 62.22712162562779, 76.69107546125139, 43.682702677590505, 1.0225800658975328, 13.646909083638873, 0.8015958123973438, 0.28116243864808765, 5.860657427992139, 66.72663606916154, 70.76274040767125, 62.84219006129673, 72.36789934975761, 47.33077096939087, 19.39637405531747, 52.97326060703823, 54.45531831468855, 70.04491506304059, 56.377547877175466, 2.6438985637256076, 0.12848334706255368, 0.13606988425765718, 0.10137704014778137, 0.18768588027783803, 0.11865708790719509, 0.17526484892836638, 0.1233320449079786], [0.07468050053077084, 0.05180259654298425, 0.05172075164903488, 0.019514565356075764, 0.10523378569632769, 0.029833254337842976, 0.06882270092942885, 0.08936482614704541, 6.661589307444436, 62.63855225699288, 51.13215821129935, 38.47393001828875, 24.130675077438354, 25.112356526511057, 40.48402302605765, 43.90396458762032, 57.31463752474104, 65.6712394441877, 24.146039281572612, 0.0965885506676776, 0.031820903931345255, 0.3250390642455646, 2.4038852027484348, 32.058734689440044, 71.16168512616838, 60.58950764792306, 63.46542957850865, 61.97329698290144, 63.04515389033726, 60.66635472433907, 54.55378123692104, 44.70865283693586, 46.84443528311593, 42.38342080797468, 41.3795485496521, 41.36323070526123, 40.985471044267925, 42.85060378483364, 43.806391034807476, 44.61330270767212, 45.242878981998985, 47.523965631212505, 49.42121294566563, 49.07006141117641, 47.13747555868966, 44.729097911289756, 42.31451552254813, 40.26603371756417, 40.638776779174805, 39.42681639535086, 42.11006825310843, 39.52104091644287, 40.93717411586216, 39.891577925000874, 41.499922616141184, 39.375111375536235, 40.447857652391704, 39.26271036693028, 40.42700958251953, 39.114751952035085, 40.21491582053048, 40.84154258455549, 40.77219956261771, 40.46730218614851, 39.2512423651559, 36.908629417419434, 37.29471302032471, 38.37831585747855, 37.32724796022688, 37.45990644182478, 36.57729761941092, 35.843282972063335, 37.95233569826399, 38.54115383965628, 37.54034226281302, 37.01274469920567, 36.484758036477224, 39.4685959134783, 39.73640727996826, 40.928943974631174, 43.24481678009033, 41.197064535958425, 43.194449288504465, 40.9369170325143, 46.54676750728062, 47.605610438755576, 51.437792096819194, 45.77556957517351, 31.959517887660436, 45.05560071127755, 49.00630126680647, 45.805919306618826, 44.292612075805664, 42.096567903246196, 40.26830230440412, 40.04909706115723, 38.960175377982004, 37.19033718109131, 39.443155084337505, 37.38704068320138, 36.795669078826904, 34.91482993534633, 35.24685307911464, 36.49183130264282, 37.77450350352696, 36.76373168400356, 37.370187827519004, 35.6050500869751, 37.273684297289165, 35.79426690510341, 36.471466132572715, 36.557457038334434, 38.80923271179199, 37.924105167388916, 39.09161445072719, 38.89287860052926, 39.58003807067871, 39.43456016268049, 38.95168815340315, 38.487989698137554, 38.06166212899344, 37.52592475073678, 38.8903112411499, 38.747880118233816, 39.173696994781494, 39.03505264009748, 40.21783753803798, 39.89203998020717, 40.60241685594831, 39.42719507217407, 43.2320807320731, 49.53986733300345, 51.52862589699881, 49.83484615598406, 51.01737744467599, 53.03832353864397, 52.69529792240688, 52.780882358551025, 54.37823152542114, 54.66778727940151, 55.70481286730085, 55.19846289498465, 55.80010393687657, 55.786947522844585, 52.92233031136649, 52.968473298209055, 56.11026457377842, 55.88553898675101, 58.92699132646833, 56.321086815425325, 60.0178029196603, 62.226294789995464, 62.367648942129954, 1.824644067457744, 1.4623294919729233, 0.28995807096362114, 0.13797926822943346, 1.321119840656008, 41.445143018450054, 65.72145407540458, 49.29654141834804, 54.51483310971941, 39.17538888113839, 12.81173300743103, 23.508251973560878, 42.89999852861677, 51.995781081063406, 49.861388274601524, 5.208556396620614, 0.1844271615679775, 0.04658828562657748, 0.00420497141645423, 0.01191356179437467, 0.02597921614402107, 0.0468424003837364, 0.02672363182396761, 0.03148541586207492, 0.029007076884486845, 0.020182069091658508, 0.01953587305199887, 0.00838067168037274, 0.031582833134702275, 0.046290663204022815, 0.08470335842243262, 9.09918109008244, 73.97685895647321, 57.346397740500315, 46.460453510284424, 30.623420987810405, 33.557395117623464, 32.6777149609157, 46.08711290359497, 62.33737564086914, 71.25249808175224, 28.060673475265503, 0.13606643729976245, 0.02383449417538941, 0.2877107086990561, 4.4596118075507025, 34.652146339416504, 72.43121828351701, 63.28504739488874, 67.52544266836983, 62.339738028390066, 66.42800249372209, 62.60174070085798, 56.44356618608747, 47.44515568869454, 48.92636571611677, 44.405857290540425, 43.20807818004063, 42.62565932955061, 43.79847008841378, 44.48306219918387, 46.34935876301357, 44.857778549194336, 48.67203038079398, 49.6129206929888, 52.30424288340977, 51.242200306483674, 49.155208110809326, 47.53313030515398, 44.756341797964915, 41.74655934742519, 42.577299867357524, 40.304095949445454, 42.986576557159424, 41.92614943640572, 42.76363665716988, 42.00453553880964, 42.89380073547363, 42.74097858156477, 42.93718876157488, 41.34056568145752, 41.59562015533447, 41.52378273010254, 40.83551849637713, 42.925178800310405, 42.07488257544381, 42.32485096795218, 42.306247166224885, 37.79713378633772, 40.554602827344624, 40.16747004645211, 39.454421588352744, 38.23665598460606, 37.695763042994905, 39.23577914919172, 40.56947544642857, 39.502513544900076, 38.784340790339876, 39.47048234939575, 38.556387765066965, 41.022584847041536, 41.10516766139439, 42.94559260777065, 46.521073068891255, 42.96203204563686, 45.50203289304461, 42.24054847444807, 47.8726818220956, 50.17440809522356, 54.075203214372905, 48.69907624380929, 32.4505158151899, 46.61619390760149, 51.56842170442854, 48.38376351765224, 46.842194489070344, 43.18702861240932, 42.68233578545706, 41.744245597294395, 40.48260906764439, 37.94412987572806, 40.64081260136196, 38.77332442147391, 39.071026938302175, 37.68507323946272, 36.77931996754238, 39.559888294764924, 39.70011683872768, 39.00115237917219, 39.43825313023159, 38.56769595827375, 38.238511153629844, 38.83496536527361, 37.65586996078491, 37.73040328707014, 39.87786218098232, 40.17872960226876, 40.98848308835711, 39.9728753226144, 41.83636828831264, 40.55250447137015, 41.4268935748509, 40.64978272574288, 41.198530605861116, 40.269830908094136, 40.83372238704136, 41.13482257298061, 41.8774425642831, 41.426744188581196, 41.44610186985561, 41.53915909358433, 43.36378036226545, 40.77962718691145, 44.53866515840803, 50.41299533843994, 54.365901947021484, 52.845083713531494, 54.349712644304546, 56.02112265995571, 54.885283265795024, 54.19958986554827, 56.525475025177, 56.90669141496931, 57.084975242614746, 57.0607260295323, 56.913135869162424, 56.711738858904155, 53.75520045416695, 52.92900405611311, 60.770244189671104, 58.11938483374459, 61.11372143881661, 58.541032791137695, 63.54666791643415, 61.65732765197754, 66.27440561567033, 2.713855415582657, 1.2470727797065462, 0.2822121594633375, 0.09492574632167816, 1.334959892289979, 46.30028363636562, 71.6530339377267, 56.55221864155361, 57.93370117459978, 39.99196549824306, 22.581011397497996, 33.46731867109026, 50.78747544969831, 57.95710965565273, 58.61975588117327, 7.205097811562674, 0.19043590128421783, 0.049861022869923284, 0.02584872198557215, 0.04417403428150075, 0.0454971097143633, 0.06037773551153285, 0.043635888158210685, 0.1555886904575995, 0.07305503596684762, 0.10781685316136905, 0.07654036501688616, 0.21734468665506157, 0.16313589976302215, 0.1708850818020957, 0.15753242187201977, 13.280289990561348, 87.23714855739048, 65.36590085710797, 54.67482233047485, 35.01528351647513, 33.43297719955444, 52.45203801563808, 59.034250668116975, 68.38462216513497, 77.83046885899135, 30.766025815691265, 0.16904591263404914, 0.2308363648397582, 1.0502393245697021, 5.066447930676596, 37.39292928150722, 75.02766282217843, 67.54832308632987, 66.70176151820591, 65.44918196541923, 68.65525450025285, 66.8403572354998, 59.983610834394185, 49.41163485390799, 51.62329510280064, 47.570004395076204, 46.24852997916085, 45.92572014672415, 45.822108609335764, 46.66045045852661, 48.3984728540693, 48.00616019112723, 49.5907107761928, 52.059760093688965, 53.40743269239153, 54.56097609656197, 50.96434531893049, 50.3474634034293, 46.78049448558262, 43.94296135221209, 43.81531252179827, 42.10401289803641, 45.56859316144671, 43.401272841862266, 43.7201360974993, 43.73513725825718, 45.84086527143206, 43.90062597819737, 43.626064436776296, 43.349557399749756, 45.1414144379752, 41.91677631650652, 43.41428334372384, 45.761405672345845, 44.097680364336284, 44.67037868499756, 43.74185616629464, 40.69681855610439, 43.1301645551409, 43.03988313674927, 41.27820907320295, 41.57916682107108, 41.48236799240112, 41.41383443559919, 42.68450709751674, 42.80864013944353, 42.40053769520351, 43.761516094207764, 41.66744021006993, 43.70578111921038, 42.21490614754813, 45.82574946539742, 48.30385228565761, 46.1793988772801, 48.498929909297395, 44.42888362067086, 49.95284046445574, 50.782142707279746, 55.251085077013286, 51.12201384135655, 37.5581122807094, 47.131024156297954, 53.026542867933, 51.436687333243235, 49.60867534364973, 45.378643308367046, 45.43016767501831, 42.299413612910676, 43.16617012023926, 39.93246807370867, 43.372899872916086, 42.859459263937815, 40.88984298706055, 39.76970304761614, 39.19867924281529, 42.16254104886736, 42.663815362112864, 42.046857016427175, 42.6505651473999, 41.36457518168858, 41.99785137176514, 41.819716930389404, 40.360418047223774, 39.791572502681184, 42.108668191092356, 42.06973743438721, 44.61419555119106, 41.82808256149292, 44.09803124836513, 45.01636075973511, 43.98749235698155, 43.093578815460205, 43.11214787619454, 42.441660608564106, 42.5524947983878, 42.237261976514546, 43.48746177128383, 43.18859543119158, 42.437748772757395, 43.60890933445522, 45.66734790802002, 43.63879701069423, 46.6299478667123, 53.48665605272566, 55.94187845502581, 55.25400332042149, 56.738117694854736, 59.20661463056292, 56.63937684467861, 57.21889482225691, 59.338533129010884, 60.281167439052034, 58.72855772290911, 59.08048398154122, 59.04896000453404, 58.738347734723774, 55.051452909197124, 53.660301957811626, 60.70728656223842, 59.86597783224923, 63.81675829206194, 62.3789884022304, 65.30870328630719, 64.52878189086914, 70.31673554011753, 2.5504550635814667, 5.654538248266492, 1.782867697732789, 0.1493393693651472, 2.311496526002884, 51.096062319619314, 77.8735546384539, 60.802164213997976, 71.49991648537772, 48.7345016343253, 20.45991223199027, 37.56498752321516, 59.81984874180385, 66.6130677631923, 70.32997185843331, 11.814277410507202, 0.4938185161777905, 0.21409651237939084, 0.12025179447872297, 0.16926871639277252, 0.17367007450333663, 0.11633020133844443, 0.14020453739379132], [0.05244543383430157, 0.033588209455566745, 0.05827617006642478, 0.03614625254912036, 0.08482992555946112, 0.04359296403293099, 0.10281200600521904, 0.1230315760310207, 14.047823616436549, 65.78796223231724, 50.741950852530344, 32.816748414720806, 14.19687897818429, 16.25386016709464, 31.964016846248082, 48.89055470057896, 59.87305804661342, 64.3363515308925, 10.98227231843131, 0.29535283148288727, 0.15442906054002897, 0.17127450661999838, 20.44535575594221, 61.421721185956685, 63.912358556474956, 62.619535037449424, 61.26863847460066, 58.7082759312221, 57.09658220836094, 54.331369400024414, 48.047901494162424, 44.60944645745413, 44.900902543749126, 42.262060097285676, 43.24361474173409, 41.77089193889073, 41.61468948636736, 39.49235527856009, 40.23608003343855, 40.060697078704834, 40.13478224618094, 43.36167853219168, 42.10053185054234, 43.55762815475464, 41.90745530809675, 41.43036767414638, 39.935139656066895, 39.2040502003261, 40.156491892678396, 40.806867599487305, 39.61313928876604, 40.41979735238211, 42.56278508050101, 39.11385563441685, 40.19178179332188, 39.49109418051583, 42.238915647779194, 41.019058636256624, 38.45280749457223, 39.780212197984966, 40.59398521695818, 40.16347483226231, 39.006592818668906, 40.15989998408726, 43.248395102364675, 40.2455677986145, 40.63332939147949, 39.015528202056885, 39.24061162131173, 37.24332414354597, 37.92209018979754, 36.226913860866, 36.47941139766148, 35.64000647408621, 36.25168071474348, 36.06280435834612, 36.37314217431204, 35.09721320016043, 34.31714589255196, 42.982254777635845, 46.94924191066197, 46.48292051042829, 44.37701531818935, 42.97547680991036, 43.86146593093872, 50.81410442079817, 51.41870539528983, 50.545261246817454, 29.29700640269688, 37.9813027381897, 54.42255408423287, 48.306829588753835, 47.18900339944022, 43.34300524847848, 44.35373190471104, 45.0683228628976, 41.30020012174334, 37.24736452102661, 34.43469551631382, 35.1794798714774, 37.220818928309846, 35.57317522593907, 37.09126629148211, 35.50977291379656, 37.23715761729649, 34.65837887355259, 37.440507071358816, 36.801106044224326, 37.20575523376465, 37.23300954273769, 36.531536783490864, 35.79678215299334, 41.24016073771885, 37.99684933253697, 38.75262573787144, 38.68785115650722, 40.102476596832275, 39.00234399523054, 38.84306001663208, 39.11345611299787, 38.20053230013166, 38.929999351501465, 41.24464579990932, 39.67523186547415, 39.03108869280134, 38.79226868493216, 40.279742513384136, 39.65586723600115, 41.393695081983296, 39.0127523967198, 47.469109603336875, 52.025349140167236, 54.54821572984968, 48.841517789023264, 51.4371007510594, 53.89994532721383, 52.18649523598807, 54.98042147500174, 55.953349930899485, 54.192811897822786, 57.743462971278596, 54.72361258098057, 56.6164790562221, 53.43779979433332, 60.27223205566406, 56.570565359933035, 58.25584397997175, 57.54964644568307, 61.71301746368408, 49.264197553907124, 63.297748701913015, 56.674538203648154, 75.3326609475272, 12.59306103842599, 1.081052956836564, 0.5894344683204378, 0.1282878475529807, 0.24727327855569975, 30.69302109309605, 67.70207977294922, 53.46484565734863, 52.791231700352256, 31.971267291477748, 12.700055480003357, 15.077868870326451, 35.44973700387137, 42.91728217261178, 54.387750557490754, 16.230007001331874, 0.1050468153719391, 0.059330823831260204, 0.03170995667044606, 0.019777338220072643, 0.042952820525637696, 0.023189068272975937, 0.05412910652479955, 0.019566503819078207, 0.023087800314117755, 0.047727908939123154, 0.0357582085499806, 0.049381905900580544, 0.02391245954536966, 0.05248834099620581, 0.09867862851491996, 18.53190176827567, 77.47053132738385, 55.66786582129342, 41.01841940198626, 18.40359459604536, 22.217952387673513, 32.98606906618391, 54.59084987640381, 64.46014758518764, 69.96870027269635, 12.95085939339229, 0.26452988971556934, 0.12628336011299066, 0.561608724296093, 23.364283561706543, 64.48435510907854, 67.38524191720145, 65.14398929050991, 63.7101103918893, 60.63724872044155, 60.74403558458601, 53.99493762425014, 48.935304573604036, 47.12651130131313, 46.08332960946219, 43.94672727584839, 45.088430949619834, 43.73124279294695, 43.0737521307809, 41.93945871080671, 42.46515246800014, 41.73454591206142, 41.75143698283604, 44.208601406642366, 43.397826535361155, 44.669972215379985, 43.941356318337576, 44.09093713760376, 41.4965284211295, 41.13745594024658, 41.36145544052124, 42.874001843588694, 42.045321464538574, 41.98802661895752, 42.92538377216884, 41.96901287351336, 41.033569949013845, 41.19185338701521, 42.98455115727016, 42.522443839481895, 40.33642591748919, 42.26406812667847, 41.86013112749372, 42.544962951115195, 42.77617468152727, 41.77777412959507, 43.07361664090838, 41.903529575892854, 42.74846873964582, 38.93119444165911, 39.469120502471924, 39.55342994417463, 38.97218186514718, 38.28547402790615, 38.46030807495117, 39.27894830703735, 38.5127773966108, 38.63807078770229, 38.01402875355312, 37.70179755347115, 37.79609850474766, 43.45323494502476, 49.20438398633684, 49.28263112476894, 46.05126019886562, 44.752183301108225, 47.52091884613037, 52.790099143981934, 52.686973980494905, 51.61204249518258, 31.868770939963206, 39.20212207521711, 54.80103983197893, 49.75018930435181, 49.41064126150948, 48.089972836630686, 47.33134766987392, 46.53346518107823, 42.94057253428868, 38.474253109523225, 36.681968757084434, 36.72586400168282, 37.94959115982056, 37.55583674567086, 38.60879455293928, 38.12808690752302, 38.93825728552682, 37.86417695454189, 40.93844216210501, 38.80455310004098, 39.90381022862026, 39.524525438036235, 39.01533712659563, 39.14766556876046, 42.19479806082589, 39.98369714191982, 40.242489746638704, 39.750814369746614, 41.263701234545024, 39.692324434007915, 41.808679716927664, 39.747041497911724, 40.02346863065447, 39.666154044015066, 43.46409845352173, 41.68811804907662, 41.75405297960554, 41.03472682407924, 41.7654584475926, 40.50636495862688, 42.409448759896414, 40.93874093464443, 50.17685038702828, 54.09264666693551, 57.32210683822632, 52.116957664489746, 53.68969283785139, 56.06477471760341, 54.593566622052876, 57.35528448649815, 58.587175777980256, 57.75111641202654, 58.802882603236604, 57.9280001776559, 58.64548506055559, 56.5479177066258, 62.168534415108816, 57.81435544150216, 60.62888308933803, 59.474175861903596, 63.41561794281006, 51.611215659550254, 65.66950239453996, 59.69464915139334, 77.31651060921806, 14.755071197237287, 1.3474758778299605, 0.32333664702517645, 0.09365833790174552, 0.2549861589712756, 32.843040398189, 74.86870888301304, 56.78137023108346, 60.79524380820138, 29.47394575391497, 14.849057742527553, 19.17036999974932, 41.897588866097585, 48.80938931873867, 66.05616269792829, 21.734376873288834, 0.12355521507561207, 0.09595084310110126, 0.014173591459569122, 0.03437037712761334, 0.021619253758607165, 0.06594507462744202, 0.07653734553605318, 0.14647741722209112, 0.1294726375490427, 0.1393279108617987, 0.16072754827993257, 0.3766573672848088, 0.206961580951299, 0.15409132651984692, 0.2518417462706566, 26.65589884349278, 86.94370528629848, 63.857766560145784, 50.00386803490775, 25.896212339401245, 23.69340409551348, 46.00918190819876, 64.24066093989781, 68.07300240652901, 76.70792484283447, 13.648965750421796, 0.40254051983356476, 0.21964245050081185, 1.5056579155581338, 24.983724525996617, 67.82393727983747, 70.31782640729631, 67.63427925109863, 66.6034653527396, 62.36750302995954, 61.8856315612793, 58.161622932979036, 51.182021958487375, 50.46700021198818, 48.73910134179251, 48.29488910947527, 46.72295992715018, 45.93907458441598, 45.28111491884504, 45.50600378853934, 44.259444849831716, 45.300111293792725, 44.752749579293386, 47.46153259277344, 45.92855848584856, 48.72443716866629, 46.069047587258474, 46.577249254499165, 44.511376108442036, 42.92754118783133, 43.27029235022408, 44.850976262773784, 44.25053031103951, 44.27873304912022, 46.33200216293335, 43.84698241097586, 43.40860666547503, 43.32157700402396, 45.80891745431082, 45.079120363507954, 41.45516232081822, 44.36531802586147, 43.8961443901062, 45.86800840922764, 42.307146957942415, 43.20606320244925, 46.05397694451468, 44.344921588897705, 44.95935426439558, 43.12396328789847, 43.45652491705758, 41.771763937813894, 42.174464157649446, 40.801646028246196, 40.25012581689017, 40.59123373031616, 40.667976583753315, 41.088655267442974, 41.540225642068044, 40.131811891283306, 39.578283650534495, 46.45974479402815, 51.787602628980366, 51.96036263874599, 47.80892515182495, 47.77534103393555, 49.97275400161743, 56.70666319983346, 57.35443680627005, 55.6538200378418, 35.34470803397042, 43.17624153409685, 58.51952116830008, 53.51435852050781, 51.4370243208749, 49.30627931867327, 49.04717404501778, 48.44532108306885, 45.45328433173043, 40.65081105913435, 38.49527488436018, 39.252701486860005, 40.88654606682913, 40.694292885916575, 40.89050306592669, 39.85482542855399, 42.934381689344136, 40.30377285821097, 43.49393054417202, 42.36411871228899, 40.46900796890259, 43.01799978528704, 41.64270462308611, 41.13033403669085, 44.780368668692454, 41.76317596435547, 42.68149505342756, 42.09993083136422, 43.68735102244786, 42.5345128604344, 44.41136026382446, 43.721306868961875, 43.31761653082711, 42.199922357286724, 46.06099115099226, 43.93704843521118, 42.96333483287266, 42.89380420957293, 43.26223938805716, 42.919863428388325, 44.899811676570344, 43.492513111659456, 53.690724645342144, 57.83762843268258, 58.59327629634312, 55.32385008675711, 57.910841601235525, 59.219176973615376, 57.79295151574271, 59.84585584912981, 61.26204463413784, 58.88639300210135, 62.756379808698384, 59.122576168605256, 60.44408185141427, 57.94197300502232, 65.20844772883824, 62.080285344805034, 62.65727765219552, 62.206624439784456, 68.13131168910435, 54.532964433942524, 69.25140299115861, 61.166006633213584, 80.7905821119036, 15.382721083504812, 3.6260700779301778, 3.4141285249165128, 0.12273554477308478, 0.7171161941119603, 37.066704409463064, 80.43561949048723, 63.21116719927107, 69.88193116869245, 40.627148968832834, 18.304115499768937, 24.25669629233224, 50.16288103376116, 57.37086582183838, 74.59405354091099, 28.452473708561488, 0.24017276242375374, 0.1293447744101286, 0.14694224085126603, 0.10794960853776761, 0.10918108852846281, 0.17262578196823597, 0.16646294694926056], [0.06718890395547662, 0.07528787758201361, 0.05936895749930825, 0.048601346356528144, 0.07241743018052407, 0.023185631493106484, 0.1541038387055908, 0.12653136466230663, 28.046705859048025, 68.8037166595459, 46.45649651118687, 35.043889250074116, 16.280714954648698, 25.05849061693464, 34.243171896253315, 48.37106915882656, 63.030194418770925, 58.77810532706124, 10.816047089440481, 0.19933544445250714, 0.4445507127259459, 0.9167477105345044, 18.584292922701152, 66.89843027932304, 61.30075304848807, 60.17127473013741, 54.504323959350586, 56.108687332698274, 51.54939406258719, 47.35877568381173, 47.26651055472237, 48.1958772795541, 49.4203895841326, 46.1436573437282, 46.01606409890311, 41.31925903047834, 41.08644921439034, 41.896859305245535, 39.65257378986904, 42.24933794566563, 40.32769203186035, 39.409654344831196, 42.660025119781494, 39.81197588784354, 39.861669404166086, 40.05668101991926, 39.95228781018938, 40.74071380070278, 40.196965149470735, 40.25081021445138, 40.287159715379985, 41.167986324855256, 40.1312039239066, 39.93655708857945, 40.367362771715435, 40.76783261980329, 41.823336941855295, 38.59814296449934, 39.68394143240792, 39.80774096080235, 39.3132689339774, 39.73208897454398, 39.48553214754377, 40.449650287628174, 40.370458194187705, 39.467550209590364, 41.49912009920393, 40.768551758357454, 41.354444708142964, 40.849605969020296, 36.847249031066895, 36.778242996760774, 36.06828301293509, 35.48709051949637, 34.58610718590872, 34.93688004357474, 36.1093190738133, 34.59853751318795, 36.028858934129985, 38.46616193226406, 43.24605008534023, 47.14867605481829, 47.899585247039795, 47.43115854263306, 45.22110332761492, 47.812625067574636, 49.61509200504848, 51.9704965863909, 30.36822407586234, 32.838708196367534, 49.148895672389436, 45.169057846069336, 49.57731464930943, 45.38517461504255, 49.03484794071743, 42.778592654636924, 40.35480737686157, 35.348529543195454, 35.80338641575405, 33.79313359941755, 36.40080642700195, 34.13507529667446, 37.068392821720664, 36.16259091241019, 36.3016973223005, 36.75307314736502, 36.88979285103934, 37.88808223179409, 37.346838406154085, 38.78213126318795, 38.313100065503804, 40.04104062489101, 40.37628425870623, 38.55017607552664, 39.760976110185894, 38.08633518218994, 38.63833481924874, 37.67489412852696, 37.890163217272075, 38.61452681677682, 37.46531214032854, 36.86244821548462, 38.81817156927926, 37.99346555982317, 38.536578450884136, 36.97094086238316, 41.12359775815691, 38.00981814520699, 39.85776104245867, 39.0580928666251, 49.14755467006138, 50.41378743307931, 54.67928307397025, 34.634953022003174, 43.59783043180193, 56.845185961042134, 56.0004517691476, 54.3660443850926, 55.95643145697457, 52.58367511204311, 56.83728585924421, 54.71040752955845, 56.80242327281407, 54.503069809504915, 56.53902748652867, 55.96954965591431, 58.83727618626186, 50.93881068910871, 54.22486741202218, 48.73955992289952, 60.60343183789934, 55.73317888804844, 72.35655294145856, 35.61080666950771, 0.3484235794416496, 0.10145144829792635, 0.13414414759193147, 0.030003125579761605, 17.61298860822405, 62.19304765973772, 57.028368268694194, 47.31197609220232, 59.347843715122764, 45.68375607899257, 18.803293194089616, 29.62517329624721, 45.21333176749093, 54.58810881205967, 31.327784197671072, 0.21539844466107233, 0.04332660511136055, 0.07533021816717726, 0.03858847989301596, 0.03430737854380693, 0.0060615780863112634, 0.030608534879450287, 0.01952308775590999, 0.06695869059434958, 0.0749464998287814, 0.11299900151789188, 0.06132611712174756, 0.06385745307696716, 0.08773868304810353, 0.028301463229581714, 36.39054046358381, 76.02973202296666, 52.962014947618755, 41.162087304251536, 21.820564065660747, 27.450678961617605, 34.318014417375835, 56.06994765145438, 67.76799038478306, 66.9043709891183, 10.136016471045357, 0.179230981107269, 0.2385320918900626, 0.6357649479593549, 19.67835627283369, 70.74004064287458, 64.75138132912772, 63.21323081425258, 57.07461200441633, 57.59173168454851, 52.48640380586897, 50.11289916719709, 47.94375147138323, 48.64707939965384, 51.86570038114275, 49.95254169191633, 47.30851241520473, 43.28016921452114, 42.158789021628245, 43.84647866657802, 42.157878807612825, 43.28949022293091, 41.90219899586269, 42.27821118491036, 44.76979003633772, 41.37168318884713, 43.252039432525635, 42.87029497964041, 42.41206823076521, 42.377782344818115, 41.6229578426906, 43.2585186277117, 41.03072118759155, 42.28388786315918, 40.69836105619158, 41.23548460006714, 41.25366803577968, 42.48229019982474, 42.81720379420689, 40.691829749516074, 40.828504289899556, 40.118724959237234, 41.68762125287737, 42.59927354540144, 41.0109292439052, 41.50063133239746, 41.2140702520098, 41.75993115561349, 42.050782748631065, 42.671104022434776, 43.95653813225882, 41.91712372643607, 38.57484565462385, 38.618567194257466, 39.02963304519653, 37.55281775338309, 37.74977486474173, 37.842314447675435, 37.77265875680106, 37.15591580527169, 38.29480198451451, 40.63039377757481, 46.92595154898507, 49.67363405227661, 49.815693446568076, 48.81845671789986, 48.24420894895281, 49.6943952696664, 51.17033856255667, 54.14213521139962, 34.349479334695, 35.983977045331685, 50.88450009482247, 48.35228817803519, 50.20818328857422, 47.51226486478533, 49.61388649259295, 44.00542565754482, 41.935713631766184, 37.83696780885969, 38.012590476444785, 37.3823367527553, 38.24448313031878, 36.39301402228219, 37.544111660548616, 37.67674234935215, 37.290502411978586, 39.00431380953108, 39.07504647118704, 40.22109624317714, 39.74473122188023, 40.36447926930019, 39.92066308430263, 41.16336924689156, 42.282605920519146, 41.813234261104036, 41.51132461002895, 40.6935042653765, 39.584363324301584, 40.663164956229075, 40.33904191425869, 40.05232449940273, 39.83855274745396, 39.05674491609846, 40.41268239702497, 39.79479994092669, 40.56339577266148, 38.974099567958284, 43.1396974836077, 40.86759832927159, 42.93463182449341, 41.47479445593697, 51.12592567716326, 54.33408614567348, 55.712473256247385, 36.935967104775564, 46.31747695377895, 57.166071142469136, 57.71436391557966, 55.34596620287214, 57.62553814479283, 52.8672137260437, 58.03731618608747, 58.52328709193638, 58.42272581372942, 56.98772825513567, 59.4270601272583, 57.869895866939, 61.000729833330425, 53.86680589403425, 56.894004004342214, 51.29758439745222, 60.93189402988979, 59.790617670331685, 74.55011313302177, 40.39143133163452, 0.2927466056176594, 1.4199701249599457, 0.34864125347563196, 0.056711987392710786, 17.20519014767238, 70.28224468231201, 60.9974433353969, 57.66236359732491, 45.37309169769287, 30.74839128766741, 24.0989739213671, 36.06301280430385, 52.008392061506, 60.67090579441616, 37.529516969408306, 0.20446124726108142, 0.019282625123326267, 0.022244469495490193, 0.04877156025863119, 0.030543694073068242, 0.04901763776849423, 0.03500967585880842, 0.11448876586343561, 0.20081375512693608, 0.1307466006172555, 0.22889548327241624, 0.16977388571415628, 0.10929747764021158, 0.16575337573885918, 0.2219839934259653, 46.28799227305821, 84.8515054157802, 60.67518588474819, 50.36459418705532, 26.194239684513636, 35.00329439980643, 46.16216387067522, 63.00555610656738, 73.63732133592877, 71.09165423257011, 13.510292734418597, 0.37834884652069634, 0.9655514231749943, 2.5380586087703705, 22.881720747266495, 72.31746237618583, 67.77060985565186, 65.63865934099469, 57.162649154663086, 61.01738466535296, 56.830865723746165, 52.271860803876606, 52.349242891584126, 50.96692310060774, 55.24212190083095, 52.5713837487357, 51.41476229258946, 46.096875122615266, 45.46072237832205, 44.480616433279856, 44.188482897622244, 45.98643350601196, 43.860722473689485, 44.282589299338206, 47.333630153111045, 43.641378266470774, 44.386468342372346, 45.85499095916748, 44.078979287828716, 44.69492319652012, 43.483886923108784, 44.57962131500244, 43.15905516488211, 45.29756825310843, 43.0615302494594, 45.234065192086355, 43.411007268088206, 44.470093386513845, 46.45064960207258, 43.600766045706614, 43.049843379429404, 44.00728777476719, 43.07277590887887, 45.07933575766427, 42.43713733128139, 42.929920945848735, 43.6032326562064, 43.22569186346871, 44.916859081813264, 44.28816870280674, 45.57051433835711, 43.96476132529122, 42.520644256046836, 41.14817006247384, 42.80484642301287, 40.07754646028791, 39.15137243270874, 39.371133531842915, 40.80120134353638, 39.17185572215489, 40.95644147055489, 43.63111230305263, 48.80906970160348, 52.80797338485718, 51.7190134865897, 51.13175521578108, 49.44453457423619, 52.04365764345442, 53.98014838354928, 55.93595858982631, 37.984686510903494, 39.04862247194563, 51.04359299795968, 50.43300267628261, 53.60435506275722, 50.0181222643171, 52.23173843111311, 47.328915800367085, 43.5227620942252, 40.608764035361155, 40.80015911374773, 39.20286553246634, 40.05853966304234, 39.03768253326416, 40.45770672389439, 41.421168259211946, 41.03757211140224, 43.406254700251985, 42.54700224740164, 43.51413590567452, 40.75043780463082, 43.22796739850725, 41.52351522445679, 44.01460770198277, 44.01968336105347, 43.624004295894075, 45.028304713112966, 43.76754018238613, 41.68603358949934, 41.94594138009207, 42.78282758167812, 43.13665417262486, 41.73615094593593, 42.27755110604422, 42.01949848447527, 40.93608324868338, 42.11696086611067, 40.62205246516636, 44.76056282860892, 42.28843198503767, 44.92742034367153, 44.97554704121181, 53.611035755702424, 57.03216198512486, 59.05024542127337, 40.73090989249093, 48.776138714381624, 60.024487086704795, 60.2728921345302, 56.69421897615705, 60.16882201603481, 56.245299339294434, 61.6857944216047, 61.074478013174875, 61.71207250867571, 59.07038824898856, 61.83252647944859, 61.644056592668804, 63.933571406773154, 55.85651288713728, 60.046304430280415, 54.33412436076573, 66.06942680903843, 62.062407629830496, 77.61677701132638, 42.05639689309256, 0.4859622206006731, 3.232715836593083, 0.4951592470918383, 0.19078283623925277, 22.576189347675868, 74.77645765032086, 66.12597819737026, 62.50789138248989, 77.12904126303536, 60.45985426221575, 29.83650275639125, 44.104892594473704, 61.49052919660296, 69.34155586787632, 48.65455218723842, 0.7791754411799567, 0.22722562216222286, 0.16723411556865486, 0.08300373676632132, 0.09547811453895909, 0.16234003246894904, 0.06251026929489203], [0.04579718164833529, 0.036319163627922535, 0.058319060264953544, 0.14783513865300588, 0.030172450600990226, 0.024618161409827213, 0.038945613229381185, 0.505097396671772, 42.950980935777935, 61.47762639181954, 46.22909934180123, 33.97424186979021, 12.831842831202916, 31.492397444588796, 36.855903012411936, 52.6683806010655, 62.31228569575718, 56.064208439418245, 7.177572088582175, 0.2362335409436907, 0.32705545318978174, 0.3645069764128753, 30.156964097704204, 70.5654046194894, 62.13340432303292, 60.80052443913051, 52.535409450531006, 50.36661263874599, 50.32819604873657, 50.73959193910871, 55.245081833430696, 55.506521701812744, 56.50292812074934, 57.72080142157418, 53.19852120535714, 48.40653623853411, 46.86814948490688, 41.71647712162563, 43.17934043066842, 40.830293451036724, 39.59875651768276, 40.33197907039097, 40.18716818945748, 39.40896994726998, 40.63622679029192, 38.2636844771249, 38.60173518317086, 39.24533987045288, 41.792490414210725, 39.048209054129465, 40.16071292332241, 40.17654439381191, 40.08455719266619, 40.1001489503043, 40.02691841125488, 39.40494694028582, 41.38935940606253, 39.50330563953945, 38.67298201152256, 38.22718211582729, 37.01441921506609, 37.85333776473999, 40.036524295806885, 40.650171824863975, 40.042305197034565, 39.63579389027187, 39.57920776094709, 40.95172711781093, 42.55220644814627, 42.67122909000942, 40.95771299089704, 37.23671293258667, 37.269661290305, 36.69084160668509, 36.90446744646345, 34.771915912628174, 35.163297516959055, 35.626641614096506, 34.318976742880686, 36.348173822675435, 39.50610228947231, 43.01853479657854, 45.413936683109824, 49.53235980442592, 47.619690963200156, 50.04839556557791, 49.33318969181606, 47.87848009381975, 34.123520442417686, 35.651912212371826, 46.8089508329119, 46.8645989554269, 47.838882310049875, 44.41012001037598, 44.09999758856637, 41.647321701049805, 37.010357992989675, 36.35486493791853, 34.933002948760986, 35.06328167234148, 35.37526273727417, 35.32881055559431, 35.06904520307268, 36.372165952410015, 35.184030941554475, 36.67127200535366, 37.37267528261457, 38.57943146569388, 39.8779490334647, 41.32999052320208, 42.74127040590559, 41.41641221727644, 41.71270077569144, 39.579808780125205, 38.89808974947248, 39.36744751249041, 37.474789483206614, 38.63185909816197, 37.709853989737375, 37.28260578427996, 36.37433726446969, 36.87255784443447, 39.65384183611189, 38.39834751401629, 38.97537803649902, 38.698912688664024, 39.17007350921631, 38.431660652160645, 40.58053003038679, 39.80454478945051, 49.25059992926461, 51.78739765712193, 51.35972908564976, 43.240401199885774, 50.653361320495605, 53.15673473903111, 51.06747395651681, 54.20612812042236, 53.88157429013933, 53.77690315246582, 54.16884756088257, 52.47275059563773, 50.704347201756065, 49.17725821903774, 47.98360633850098, 48.25828947339739, 48.666086196899414, 45.99337823050362, 49.473414761679514, 45.504294531685964, 53.33639430999756, 60.07939175197056, 66.4631186894008, 55.81211042404175, 0.7762858590909413, 0.8697437984602792, 0.22360459289380483, 0.21985076075153692, 8.69719045502799, 57.63122871943882, 60.33057607923235, 53.95920303889683, 52.78565229688372, 37.794788769313264, 13.732263360704694, 25.80385340963091, 39.163740226200645, 54.75219052178519, 40.06063454491751, 1.3692430640969957, 0.056287421246192286, 0.04686756385490298, 0.0300833046702402, 0.04352993152237364, 0.02991414928276624, 0.09439589868166617, 0.014595870094906007, 0.07533082206334386, 0.03371883423200675, 0.14541636487202986, 0.014533948685441698, 0.016970081088532294, 0.027476006719682897, 0.8087106049060822, 51.46566826956612, 69.71393762316022, 52.61554997307913, 39.73972157069615, 16.47636580467224, 26.108203615461075, 37.13705144609724, 60.69466168539864, 67.05342374529157, 63.52768543788365, 7.696081842694964, 0.39486555595483097, 0.23514232092670032, 0.5515913761087826, 32.31876754760742, 73.32670906611851, 64.21682861873082, 62.75569888523647, 54.72124671936035, 53.63914469310215, 51.78844683510916, 55.34796033586775, 56.06595591136387, 59.168274470738, 58.76835700443813, 58.800825936453684, 55.36376748766218, 51.122243131910054, 47.73451689311436, 44.72049951553345, 45.06107241766793, 43.814544745853965, 43.021762234824045, 41.201539175851, 41.9963436126709, 42.40124293736049, 42.975257941654746, 40.73519345692226, 41.7601534979684, 41.00084393365042, 42.828984464917866, 41.22487817491804, 41.83810881205967, 42.3416690826416, 41.134200709206716, 41.380111353737966, 40.81388875416347, 41.49354764393398, 43.12815999984741, 41.86011028289795, 39.81814936229161, 40.550503390175955, 38.43749019077846, 41.437958581107004, 40.99292646135603, 41.63746220724923, 41.773994309561594, 39.54489060810634, 40.59469393321446, 42.25805446079799, 44.2197984286717, 43.92798451014927, 42.343909876687185, 39.7147775377546, 38.46734312602452, 39.480637141636436, 39.08104624067034, 36.79244858877999, 37.39661182676043, 37.79341650009155, 37.04748569216047, 37.61753327505929, 40.558212416512625, 44.886168888636995, 46.62077624457223, 51.25828538622175, 49.754879338400706, 51.20107044492449, 50.84676790237427, 49.56339740753174, 37.61264869144985, 38.42989233561924, 49.61909416743687, 49.60595859800066, 49.51406519753592, 47.69729886736189, 46.15758500780378, 42.72283683504377, 40.081364495413645, 37.03628519603184, 37.36830139160156, 36.848715100969585, 37.552112511226106, 37.85573141915457, 37.45098842893328, 39.003584248679026, 36.88521746226719, 38.10651969909668, 40.15322971343994, 40.62673207691738, 43.409985882895334, 43.241637979234966, 42.383931500571116, 42.53983518055507, 44.000756468091694, 41.69427415302822, 41.2142265864781, 40.022589683532715, 39.93441704341343, 41.105035645621165, 38.818873337336946, 40.163832664489746, 38.337092195238384, 38.8582626751491, 41.1471243585859, 39.10089724404471, 40.02821772439139, 40.40763800484793, 41.59263242994036, 41.035439014434814, 41.58159521647862, 41.51352024078369, 49.79533175059727, 54.545526776994976, 53.21164982659476, 48.3759502683367, 52.94687829698835, 53.71972990036011, 52.27589075905936, 53.889807905469624, 55.48066398075649, 55.208061831338064, 54.994971002851216, 55.05018833705357, 52.71201876231602, 51.31270367758614, 51.386187825884136, 50.422722816467285, 50.299086570739746, 49.29845217296055, 51.6669019971575, 48.33433403287615, 54.60973508017403, 62.90959453582764, 68.02630356379917, 59.17290197099958, 0.9499020172016961, 1.8138949871063232, 0.8948973087327821, 0.27324309359703747, 9.290501475334167, 61.74434689113072, 64.52234785897392, 60.10261263166155, 56.704801082611084, 34.66163410459246, 15.717603410993304, 31.3820253099714, 45.339299133845735, 61.74464566367013, 49.5255366734096, 1.9343815275600977, 0.08421856550765888, 0.06077824080629008, 0.06841439248195716, 0.0612074684883867, 0.02959585189819336, 0.06682438815810851, 0.2327996109213148, 0.14172855418707642, 0.11248690435396773, 0.24813420378736087, 0.1230502086026328, 0.11005713830568961, 0.14146157779863902, 1.5713959080832345, 62.853272438049316, 76.31216934749058, 62.175093514578684, 49.08635146277291, 22.96905091830662, 42.26487759181431, 49.94669130870274, 66.80569267272949, 71.9712266921997, 71.95280701773507, 9.348109858376638, 0.4921633249947003, 0.7117801947253091, 0.8702932489769799, 36.41984101704189, 75.89175469534737, 67.19550745827812, 65.95433684757778, 57.69709069388253, 55.59630632400513, 54.394646644592285, 56.85349600655692, 61.75465106964111, 61.36472511291504, 62.61226027352469, 60.910896573747905, 58.38342680249895, 53.51108244487217, 51.60725171225411, 46.581529344831196, 48.20767879486084, 45.57524258749825, 43.53430652618408, 43.62946557998657, 45.27905477796282, 44.03201641355242, 46.12557118279593, 42.29560252598354, 42.36538675853184, 42.964780058179585, 44.708499976566856, 42.181057998112266, 43.26275702885219, 43.35143688746861, 43.4119348526001, 43.315007482256206, 42.97902039119175, 43.892072745731895, 45.284331934792654, 43.875327587127686, 42.162655694144114, 41.776738848005024, 41.56341872896467, 42.378716877528596, 43.188206332070486, 44.37520183835711, 44.19761977876936, 41.81762204851423, 43.5091609954834, 44.54202113832746, 44.88739177158901, 46.889240741729736, 44.74961246762957, 42.726713929857524, 40.77786234446934, 42.63500118255615, 42.21206086022513, 39.739711148398264, 39.74042681285313, 39.25273622785296, 39.3718387739999, 40.15992430278233, 43.59541245869228, 46.99569409234183, 51.14425155094692, 52.915785108293804, 51.58037608010428, 55.24639504296439, 52.94255999156407, 51.30007880074637, 41.0749568939209, 41.10492100034441, 52.68901675088065, 52.54203803198678, 52.52670335769653, 48.940706798008506, 48.795982769557405, 46.85103954587664, 42.62013898577009, 40.69808660234724, 39.56085409436907, 38.96069301877703, 40.703606946127756, 40.08674240112305, 38.369620186941965, 40.69338614600045, 38.75928558622088, 40.87615850993565, 43.15676573344639, 43.01202086039952, 45.359243937901084, 46.34142392022269, 45.03726788929531, 45.637554032461985, 45.81230470112392, 44.239816188812256, 44.184769085475374, 42.98856026785714, 42.06552335194179, 43.44290297372, 41.908212661743164, 42.84445115498134, 41.71758883340018, 40.334914684295654, 44.112507820129395, 41.01139824731009, 43.68813616888863, 43.161698954445974, 43.158287388937815, 42.80016681126186, 44.78275884900774, 43.795141901288716, 52.86090823582241, 56.0060589654105, 54.966122082301546, 50.72725888660976, 55.68265158789498, 57.648946625845774, 54.02776091439383, 57.7494592666626, 58.06948287146432, 58.52007007598877, 58.374046734401155, 58.52706691196987, 55.36047056743077, 55.51490122931344, 53.76933309010097, 52.69464479173933, 52.36615480695452, 53.20443412235805, 54.93475096566336, 51.248940059116904, 56.82536622456142, 66.2295480455671, 71.39607565743583, 63.42305946350098, 0.9039601481386593, 3.9193624428340366, 1.69076726266316, 0.3442572115787438, 11.67530996458871, 69.77945913587297, 71.0796616418021, 65.9564768927438, 69.7544525691441, 50.09532369886126, 21.010925224849156, 40.252825192042756, 55.805909156799316, 69.32877813066754, 61.50812898363386, 2.9079338014125824, 0.2726035879126617, 0.15812331730765955, 0.16284886587943348, 0.1677681633404323, 0.08614398326192584, 0.1485151664486953], [0.008800974082467812, 0.0481884985097817, 0.06064210632549865, 0.011642793243351792, 0.024139268357040625, 0.05028186385918941, 0.1318135019391775, 2.1490237585135867, 52.93576465334211, 57.53645181655884, 42.37831735610962, 24.181952783039637, 17.776373761040823, 42.359859466552734, 38.26877750669207, 51.13548639842442, 65.5792452948434, 50.89865704945156, 1.9898407459259033, 0.12268720593835626, 0.0716433913580009, 0.520331050668444, 36.49330084664481, 66.28359808240617, 59.47154944283621, 58.2204498563494, 51.56323487418038, 52.0003217288426, 52.60126795087542, 55.41241530009678, 57.03123092651367, 57.08153241021292, 58.68724373408726, 57.29588781084333, 57.45448391778128, 52.13671834128243, 51.77292455945696, 49.293654441833496, 46.767918246132986, 44.85774033410208, 43.23599604197911, 41.25026689256941, 39.41079732349941, 39.04927212851388, 40.76738446099417, 42.085461207798545, 42.28004898343767, 40.853021008627756, 41.38486392157418, 39.11469636644636, 38.49925620215279, 40.83763769694737, 39.05356611524309, 39.03752967289516, 39.364456312997, 39.22268526894705, 40.01296990258353, 39.51212985174996, 39.2723787852696, 39.7990904535566, 37.54344810758318, 38.82057564599173, 40.08752407346453, 38.26737397057669, 39.819049154009136, 38.42998961039952, 39.643693992069785, 39.489426612854004, 38.7143828528268, 41.133745602199006, 40.12967879431588, 39.450256143297466, 37.597129889896934, 36.29306765965053, 36.75148548398699, 35.379751273563926, 35.36974239349365, 34.57137353079659, 35.695876938956125, 34.724504879542756, 38.24539334433419, 39.843228885105674, 43.61760153089251, 45.53244515827724, 46.6506222316197, 47.49872977393014, 47.0374492917742, 44.74768781661987, 37.75021260125296, 35.49038396562849, 42.859056268419536, 44.32534851346697, 42.60911914280483, 42.65825680324009, 42.197824001312256, 39.22782693590437, 36.79361588614327, 35.633020060403005, 33.77030529294695, 35.95433950424194, 35.88945722579956, 35.582426752362935, 34.61789172036307, 35.87346247264317, 34.98652492250715, 37.4145416532244, 37.529027121407644, 38.456701959882466, 41.07852479389736, 38.19874313899449, 40.115973472595215, 39.338640281132285, 39.31957442419869, 38.34444338934762, 38.55236823218209, 36.2104674748012, 37.923236642565044, 38.024854046957834, 36.56243889672415, 37.913005420139854, 36.58019849232265, 37.32398578098842, 39.17341559273856, 39.962856020246235, 37.67126022066389, 39.160481521061485, 40.27008104324341, 39.22428682872227, 38.55099596296038, 38.98708922522408, 37.962493964603965, 47.739297253744944, 50.62322003500802, 54.188594341278076, 51.642277581351145, 50.23259231022426, 49.148895672389436, 49.37609829221453, 49.677333968026296, 49.17616387775966, 47.884132453373496, 45.74389968599592, 42.815775939396445, 41.5773811340332, 41.93171146937779, 44.53004591805594, 44.33303322110857, 45.24150323867798, 45.36004992893764, 49.67591306141445, 52.67443595613752, 60.65930230276925, 61.951813152858186, 68.47066865648542, 6.3341085485049655, 2.4451353549957275, 0.4224713732089315, 0.15718341059982777, 3.6797642367226735, 55.4633594921657, 59.85475649152483, 59.38840729849679, 43.84290729250227, 38.74622992106846, 18.21554160118103, 20.437820434570312, 39.761980124882285, 47.07492787497384, 44.870375633239746, 3.2477743199893405, 0.24506665553365434, 0.11859850319368498, 0.04309667334226625, 0.0614314732540931, 0.04423742302294288, 0.022136170217501264, 0.012768818714123751, 0.030060163233429193, 0.02174979541450739, 0.03635529222499047, 0.0757253969620381, 0.04586706057723079, 0.08386635155017887, 3.0017236258302415, 60.95920739855085, 64.90970993041992, 50.01103162765503, 31.940187999180385, 23.805136340005056, 33.498088768550325, 40.05148376737322, 60.0443172454834, 68.36705711909703, 56.32772234507969, 2.2376004798071722, 0.13851474092475005, 0.12501749875290052, 0.7346782545958246, 38.19820465360369, 68.24178109850202, 62.098517417907715, 60.10939407348633, 53.40787042890276, 54.95015164784023, 55.686594690595356, 56.239983967372346, 59.52509226117815, 59.54977921077183, 62.377862794058665, 59.33012580871582, 58.18429837908064, 53.78264583860125, 54.18299756731306, 51.67580611365182, 47.83329248428345, 47.6310373714992, 45.8181585584368, 43.490994930267334, 42.30083104542324, 42.24286569867815, 41.787397384643555, 44.04687861033848, 43.207268714904785, 42.709187098911826, 42.3622670173645, 41.426202229091096, 40.095806326184956, 40.727821418217246, 40.86745589120047, 42.83552271979195, 40.72297852379935, 41.328281266348704, 42.4817795072283, 41.59983076368059, 40.67600522722517, 41.228553771972656, 39.332466806684224, 39.34929881777082, 42.27718979971749, 39.77122470310756, 39.51771967751639, 40.831478118896484, 40.16912024361746, 40.8629013470241, 40.1374295098441, 42.346473761967246, 41.82970149176461, 41.96565341949463, 39.74357782091413, 37.573568548474995, 37.99181883675711, 37.38984775543213, 37.053739070892334, 35.95719173976353, 37.44309180123465, 36.124747548784526, 40.22000190189907, 42.51952559607369, 45.88448258808681, 46.62143284933907, 49.185092312949045, 49.09633949824742, 48.96113102776663, 46.73556743349348, 40.23740019117083, 39.54327515193394, 46.14226075581142, 47.232572078704834, 43.7799322945731, 44.1414783341544, 44.67532927649361, 41.08287436621529, 38.60451793670654, 36.80195025035313, 36.560250214168, 38.22408321925572, 38.61765003204346, 35.81019217627389, 37.091092586517334, 36.968800817217144, 38.43141051701137, 40.73817770821707, 40.166677951812744, 40.52571221760341, 42.06731946127755, 40.828955922807964, 40.85505335671561, 41.211728709084646, 40.60946580341884, 40.797838415418354, 39.72639839989798, 38.62303141185215, 39.12891238076346, 39.94948768615723, 37.923872402736116, 39.576174872262136, 38.82701662608555, 40.916680404118125, 40.8294666154044, 40.83158234187535, 40.787197249276296, 41.385478837149485, 40.612887791224885, 42.14570903778076, 41.03228800637381, 41.86952856608799, 40.95373167310442, 49.15513515472412, 52.25758225577218, 55.048333168029785, 53.26923997061593, 52.476658957345144, 50.81216934749058, 50.97605650765555, 52.2449608530317, 50.33738156727382, 49.45904588699341, 46.8107191494533, 43.098612785339355, 44.32830497196743, 43.92560822623116, 46.81393616540091, 46.2734740121024, 48.760456630161826, 47.47575902938843, 53.267086029052734, 54.61207662309919, 64.79209082467216, 63.10139260973249, 72.62548296792167, 6.675584716456277, 1.6958985073225838, 0.3512917198240757, 0.25375947622316225, 3.9682087131908963, 59.11108384813581, 66.52142797197614, 63.30955369131905, 49.997006688799175, 41.42352369853428, 23.92514215196882, 25.99859925678798, 48.012837409973145, 53.58474029813494, 57.22111824580601, 4.805148329053607, 0.3300400844642094, 0.07525217306933232, 0.12966523292873586, 0.07997327045138393, 0.04009591668312039, 0.041439483873546124, 0.05564850249460765, 0.10643160356474773, 0.1726365571043321, 0.17633694782853127, 0.17817036301961967, 0.3363552913069725, 0.4241602197289467, 4.701434305735996, 74.70769132886613, 71.70934213910783, 58.615371567862375, 40.325319222041536, 29.476179599761963, 57.07476486478533, 51.09724003928048, 63.22115176064627, 75.26183101109096, 62.788126128060476, 3.0323130701269423, 0.20545249192842416, 0.35037078495536533, 1.1701447133507048, 42.33287613732474, 69.38301576886857, 65.0980339050293, 63.29540021078927, 56.01587329592024, 56.32117714200701, 57.83900417600359, 58.49523721422468, 64.20754582541329, 63.40822505950928, 64.53855105808803, 61.92433302743094, 62.5662145614624, 55.0242646081107, 55.38092606408255, 53.808712005615234, 49.883035387311665, 50.67073876517159, 48.33453900473458, 47.684038230351035, 44.20874037061419, 43.03871931348528, 44.136569431849885, 46.04248114994594, 46.49492352349417, 44.88715900693621, 44.686564513615195, 42.656387737819124, 41.533597060612266, 43.44776323863438, 42.036479881831575, 44.24090705599104, 42.96776778357369, 41.26386799131121, 44.085211821964805, 43.47901276179722, 43.56440612248012, 43.31491368157523, 41.52123621531895, 41.96365581239973, 43.78199243545532, 41.37045335769653, 42.23061255046299, 43.12364714486258, 42.99132217679705, 44.347836358206614, 41.41893093926566, 44.21129730769566, 44.281387260981965, 43.97839716502598, 42.93069566999163, 40.51552268436977, 40.65088748931885, 40.000199113573345, 40.42671428407942, 39.37232167380196, 40.082392828805105, 37.766690254211426, 42.8552417073931, 44.035365445273264, 47.51736831665039, 49.36976153509957, 51.59991094044277, 51.16523163659232, 50.82402644838606, 49.63095474243164, 43.261673109872, 42.997443539755686, 48.82160077776228, 49.76224095480782, 44.95448357718331, 46.57915653501238, 48.46656172616141, 44.922417640686035, 41.44682795660836, 39.92752095631191, 38.89659936087472, 41.31298828125, 40.76698841367449, 39.98415919712612, 39.326216902051655, 39.331421102796284, 40.529992307935444, 41.80882910319737, 42.81262493133545, 42.46951246261597, 44.1352527482169, 41.90254293169294, 44.191046782902305, 42.40407085418701, 43.1878867149353, 41.258041926792686, 40.67256586892264, 39.40478713171822, 41.417378016880576, 43.28416442871094, 40.22190570831299, 41.81323078700474, 41.76398542949131, 42.29057550430298, 43.939872877938406, 44.418374470302034, 42.18168681008475, 43.59064599445888, 44.60366208212716, 44.41845784868513, 43.511943749019075, 42.66369029453823, 42.81774227959769, 52.054246698107036, 55.16493088858468, 58.89348016466413, 57.49562767573765, 55.25463908059256, 53.59652096884591, 52.76644400187901, 54.982888085501536, 53.25939089911324, 53.26654059546334, 48.91899715151106, 44.95551191057478, 45.91662495476859, 47.57059151785714, 50.771133286612375, 49.927872112819124, 50.9004670551845, 50.46870599474226, 56.03039503097534, 58.171784673418315, 66.05904620034354, 67.61045387813023, 74.47516291482108, 7.268012012754168, 5.119521311351231, 2.0675645981516158, 0.33571396714874674, 5.2293784107480725, 65.08470726013184, 72.49305030277797, 68.34786619458879, 59.32950047084263, 50.785331930433, 31.4228355543954, 35.641184193747385, 59.320877756391255, 61.04395457676479, 67.15275519234794, 7.735763004847935, 0.5229046525699752, 0.14702808910182544, 0.1985904537141323, 0.1809179141585316, 0.10490468942693301, 0.11907929953719888], [0.056242834710116894, 0.08012149642620768, 0.05799146355795009, 0.06418633900050606, 0.05760907514819077, 0.040583498376820765, 0.12484018398182732, 3.296989062002727, 54.099205766405376, 51.1554867880685, 39.3136545589992, 19.67601125580924, 6.2766682250159125, 40.24910790579659, 44.985701833452495, 57.62266853877476, 62.22579451969692, 47.2839366367885, 1.1548537909984589, 0.07294178168688502, 0.09444497033421483, 0.46815919876098633, 39.31720508847918, 67.33966173444475, 60.129661968776155, 60.70287445613316, 54.56409583772932, 56.6416836466108, 58.03280333110264, 58.86866814749581, 60.673233440944124, 56.29030629566738, 54.924464157649446, 57.59616116115025, 55.796372754233225, 54.34333419799805, 50.68605259486607, 50.87950781413487, 48.36794246946062, 46.287307875497, 46.57302474975586, 41.14201743262154, 39.25789526530674, 40.67475455147879, 40.907498359680176, 38.02515976769583, 39.344240529196604, 38.22789083208357, 41.036314487457275, 41.463288239070344, 41.66445595877511, 40.42769398008074, 38.16236237117222, 39.61798913138253, 39.02031203678676, 38.05749320983887, 39.08392626898629, 39.34232977458409, 38.32076045445034, 37.42258766719273, 39.71475669315883, 37.918042864118306, 39.77834660666329, 39.413229193006245, 39.620139598846436, 39.1802213532584, 38.44383042199271, 38.91499124254499, 42.273746967315674, 39.446945326668875, 35.379167624882285, 37.951897961752756, 38.159690788814, 37.39014652797154, 35.46067694255284, 34.963915484292166, 36.71309321267264, 35.603966167994905, 34.9259991645813, 35.59403371810913, 35.71277495792934, 36.58949518203735, 39.79818023954119, 40.69530037471226, 43.353639466421946, 43.16442959649222, 45.042176791599815, 38.77005181993757, 40.81542430605207, 36.83898762294224, 39.1075154032026, 44.70604031426566, 42.81585236958095, 40.104568004608154, 37.37912668500628, 36.56175797326224, 31.778767449515207, 35.75949117115566, 35.43209900174822, 35.49982309341431, 34.611356939588276, 35.95500653130667, 35.91644055502755, 35.71844121388027, 34.447507994515554, 37.71141733442034, 37.578421865190776, 37.84827600206648, 36.87825884137835, 35.72207512174334, 38.04282208851406, 40.128706046513145, 39.71202605111258, 38.26240600858416, 36.81006574630737, 37.62640959875924, 37.471711431230815, 35.97065387453352, 35.61686897277832, 38.069760254451204, 36.756797381809776, 36.72674642290388, 39.33792461667742, 38.67042507444109, 37.61440658569336, 38.90773384911673, 38.63191468375069, 38.53805146898542, 38.72907134464809, 38.87154068265642, 39.18502950668335, 39.76610735484532, 41.3778531891959, 41.70975126538958, 42.47949354989188, 44.33833122253418, 42.51295607430594, 42.58140277862549, 41.471959590911865, 40.07329068865095, 40.555339336395264, 41.90316826956612, 41.70900085994175, 44.048744201660156, 44.662099906376426, 49.275575229099815, 50.88173123768398, 54.46500062942505, 51.73900692803519, 53.269101006644114, 51.64645344870431, 60.87479373386928, 58.94855853489467, 70.60119479043144, 13.244808145931788, 1.4730726012161799, 0.6294335105589458, 0.2307744010218552, 1.120131471327373, 44.33286646434239, 66.05734389168876, 56.96873188018799, 57.07557780402047, 33.473134313310894, 13.653424756867544, 21.006372417722428, 35.23153577532087, 44.53241525377546, 51.56703206471035, 6.220069936343601, 0.2117227390408516, 0.09380367331738983, 0.048470470522131236, 0.08053901937923261, 0.03746615922344582, 0.02708858866909785, 0.03796161531603762, 0.0017646172532944807, 0.04624388499983719, 0.05713890466306891, 0.05647728552243539, 0.07674229703843594, 0.14312173585806573, 4.949184485844203, 63.116324288504465, 57.31213617324829, 46.862931387765066, 25.871388162885392, 12.2925158398492, 33.23513419287545, 45.71963657651629, 63.63042845044817, 68.58586978912354, 51.45500973292759, 1.2730005255767276, 0.1238531055194991, 0.09980658441781998, 0.46401231842381613, 41.90829604012625, 69.13816125052315, 64.80031749180385, 62.381927490234375, 57.47188915525164, 57.17432560239519, 58.36454159872872, 61.215283257620676, 63.0940066746303, 58.72793238503592, 56.63624668121338, 58.11001866204398, 58.660965647016255, 55.54876674924578, 51.556818212781636, 52.65199327468872, 50.11011641366141, 47.93920040130615, 48.997115748269216, 42.779784270695274, 43.16287667410714, 42.81967387880598, 42.55207095827375, 40.35574190957205, 41.0145388330732, 40.31310428891863, 41.531529971531455, 43.10170473371233, 42.218755449567524, 42.59739405768258, 41.58149446759905, 41.885540689740864, 40.99805770601545, 39.498507908412385, 41.51127249853951, 42.84914813722883, 39.92480073656355, 39.76388045719692, 40.729023456573486, 38.69034208570208, 41.88868127550398, 41.09153529575893, 41.11178582055228, 40.28960200718471, 39.79428577423096, 41.35628250667027, 43.6750978742327, 40.51532118661063, 37.3808776310512, 38.740462916237966, 39.446278299604145, 40.164294719696045, 37.148759160723, 37.509012835366384, 38.494371618543354, 36.03194740840367, 35.74112013408116, 37.393540722983225, 36.5754702431815, 38.72688961029053, 40.484311376299175, 42.996224130902974, 45.1600147656032, 47.1030124936785, 47.91384295054844, 41.19945819037301, 42.482269355228965, 38.982823031289236, 41.43053790501186, 45.50752544403076, 44.386742796216694, 42.14018521990095, 39.80728585379464, 40.02826288768223, 35.12247337613787, 37.072631222861155, 38.03969539914812, 38.06979152134487, 38.00588893890381, 38.229825905391145, 38.17309386389596, 37.87590203966413, 37.99433408464704, 39.97661345345633, 39.54487323760986, 39.12124851771763, 37.64643430709839, 38.31692852292742, 40.49783604485648, 41.37092236110142, 40.753279617854524, 41.07629789624895, 38.464410986219136, 38.5825685773577, 39.11471026284354, 38.55327149799892, 37.95246076583862, 39.60039976664952, 39.48962811061314, 38.503098555973594, 40.43477419444493, 41.13208498273577, 39.60779959814889, 40.63144642966134, 41.72145203181675, 41.42031363078526, 40.62030846732003, 42.36356633050101, 41.513023444584434, 42.28952980041504, 43.473992688315256, 44.71925231388637, 45.44020782198225, 46.57418509892055, 43.09116431644985, 44.65137883595058, 43.10680818557739, 43.18894631522042, 42.37721259253365, 43.36288404464722, 43.14704867771694, 46.79924419948033, 48.27068158558437, 51.625591482434956, 52.596574442727224, 57.41772099903652, 54.885293688092915, 56.24776594979422, 53.51438978740147, 62.05953107561384, 61.17644282749721, 74.5961241040911, 15.241999217442103, 1.2513044497796466, 1.0061824257884706, 0.32470693492463654, 1.1593525324548994, 47.17100756508963, 69.84340340750558, 61.82764189583914, 61.926618984767366, 39.90581130981445, 23.1099499634334, 28.461169379098074, 43.67250272205898, 50.799645219530376, 62.777835845947266, 10.097386223929268, 0.3787058102233069, 0.10283004146601472, 0.0786891904260431, 0.09583492217851536, 0.035426421889236996, 0.02467648997636778, 0.11170466882841927, 0.24963349476456642, 0.1155458419982876, 0.18531723666403974, 0.27758845899786266, 0.25213655616555897, 0.33195515455944197, 8.601295760699681, 73.68404797145298, 64.93882288251604, 54.455648354121614, 33.547087465013774, 11.08319924558912, 51.23517220360892, 59.47774723597935, 67.62418351854596, 72.34581102643693, 56.37317746026175, 1.8104379326105118, 0.21291569859853812, 0.37841748712318285, 0.7514538115688733, 45.53938640866961, 71.49275984082902, 67.1191189629691, 64.16903890882219, 59.96989509037563, 58.64971651349749, 60.9493270601545, 63.749506677900044, 66.63869271959577, 59.90620790209089, 59.36402606964111, 60.63622038705008, 59.23849991389683, 57.12254762649536, 53.86388417652675, 56.42253398895264, 53.961968421936035, 50.268017700740266, 52.024550097329275, 44.13044459479195, 45.07810592651367, 45.67933702468872, 45.246575423649375, 42.44333165032523, 43.954210485730854, 41.866110052381245, 44.51179300035749, 44.02676010131836, 44.7009333883013, 46.3485666683742, 43.885847159794395, 43.8398049218314, 42.99965654100691, 40.910764013017925, 42.128672054835725, 45.40994841711861, 41.2116105897086, 39.96598270961216, 43.076906612941194, 40.37031923021589, 44.74776077270508, 42.53208793912615, 43.03003059114729, 43.34228263582502, 41.77572788511004, 42.989654609135215, 47.28404780796596, 42.80695172718593, 38.043058327266145, 41.1661832673209, 43.27455159596035, 41.91064453125, 38.23587431226458, 39.481179101126536, 41.94388818740845, 38.57174675805228, 38.29384313310896, 40.14521844046456, 39.44941193716866, 41.46175963538033, 43.98023496355329, 45.16443381990705, 48.316828046526226, 49.737633909497944, 48.714605467660085, 44.56364393234253, 45.50323493140084, 42.74763148171561, 44.8236003603254, 47.06859111785889, 47.9936534336635, 44.50570985249111, 42.58133677073887, 42.25454562050955, 36.89913470404488, 37.794337136404856, 41.546065602983745, 39.93376043864659, 39.18159709657942, 39.67711482729231, 39.56719432558332, 41.02392584936959, 39.325529030391145, 41.785785402570454, 41.276145458221436, 40.29483052662441, 40.25398901530674, 38.725524289267405, 42.05772399902344, 43.668827125004356, 42.923268045697895, 43.65160254069737, 39.670586994716096, 41.225295066833496, 42.16672733851841, 40.41339111328125, 40.58293063299996, 43.21485614776611, 41.77856275013515, 40.69195829119001, 43.10305963243757, 43.01519618715559, 43.18778249195644, 42.605377537863596, 44.64495175225394, 43.69783932822091, 43.07355063302176, 44.72567592348371, 43.71619994299752, 44.39711993081229, 45.83881902694702, 47.70339591162545, 48.41936608723232, 49.653710092817036, 46.44635214124407, 48.13246801921299, 45.84637866701399, 44.62185594013759, 45.245342118399485, 47.446430683135986, 46.16941084180559, 49.4655111857823, 51.15286731719971, 52.93167911257063, 55.86524329866682, 58.45484038761684, 58.458925928388325, 59.44342313494001, 57.39110939843314, 66.31483023507255, 64.50008583068848, 75.729403087071, 16.486306939806255, 2.9472747189658026, 3.5367360029901778, 0.5006980470248631, 1.4251153745821543, 51.35854441779, 78.76384122031075, 64.11937318529401, 72.3196302141462, 44.015104498182026, 24.695443766457693, 33.257837431771414, 53.02914844240461, 59.81723621913365, 76.13700526101249, 16.50475788116455, 0.7368536378656114, 0.22149460682911531, 0.14019658496337278, 0.2214611279112952, 0.15031447846974644, 0.10706908721476793], [0.045667791805629215, 0.06757358581359897, 0.04557389273707356, 0.0422640837329839, 0.04368426770504032, 0.027371356263756752, 0.14248484931886196, 8.334655165672302, 61.00068814413888, 49.70373364857265, 35.29085949489048, 16.419032743998937, 21.22518856184823, 48.02479525974819, 48.65514278411865, 58.14136545998709, 59.0552133832659, 39.43735333851406, 0.25266071089676445, 0.03729518875479698, 0.40509599127939766, 0.8571692960602897, 33.20989138739449, 66.3639053617205, 60.992343357631135, 59.10601166316441, 57.48525054114205, 57.762386390141074, 57.58003091812134, 59.59020383017403, 54.29251854760306, 52.5803747177124, 55.17653785433088, 57.55452408109392, 55.58043663842337, 53.262243134634836, 52.07027619225638, 49.7428103174482, 48.12870556967599, 46.62686634063721, 44.07283360617501, 42.76910488946097, 39.97437265941075, 38.668232917785645, 37.75006668908255, 38.807478291647776, 40.43976994923183, 38.20756387710571, 37.15958792822701, 40.624241147722515, 38.36205359867641, 39.08300910677229, 38.406087807246614, 39.25289603642055, 39.912398202078684, 40.267805508204866, 41.145859786442344, 39.27289990016392, 39.73586532047817, 39.03618172236851, 35.98787151064192, 36.974640778132844, 37.00082853862217, 38.345179898398264, 38.49206829071045, 37.00147124699184, 40.03294597353254, 38.55450480324881, 39.46810259137835, 38.11215468815395, 38.23633984157017, 37.67419236046927, 37.287775244031636, 35.98246233803885, 37.01231391089303, 37.19685459136963, 36.255199977329795, 36.0857264654977, 37.04391779218401, 34.28050109318325, 35.24417454855782, 35.37080546787807, 37.532612391880576, 38.65573310852051, 40.44856289454869, 41.5231157030378, 41.612771783556255, 36.18054158346993, 41.708702087402344, 37.09824228286743, 37.35596833910261, 41.81652423313686, 39.58549240657261, 38.422398703438894, 36.86547415597098, 36.50993830817086, 35.80960505349295, 35.45810610907418, 36.183633531842915, 35.662848676954, 34.7549866267613, 35.91691998073033, 35.15130145209176, 36.683452197483604, 37.60962969916207, 39.4342474937439, 36.04017407553536, 36.43416820253645, 36.011787210192, 34.2205867767334, 36.80608095441546, 39.54118374415806, 39.818482875823975, 37.4478200503758, 36.899027006966726, 37.50474664143154, 37.39427375793457, 37.557601588112966, 37.22930267878941, 35.585668087005615, 36.30617891039167, 37.77031373977661, 38.28814908436367, 37.73651075363159, 37.71122278485979, 37.85557508468628, 37.259697573525564, 37.81271512167794, 38.18102175848824, 37.14927332741873, 37.57397501809256, 38.339176654815674, 37.071668897356304, 40.36751215798514, 38.74110909870693, 39.55611889702933, 38.0051281111581, 38.9152135848999, 38.11746311187744, 41.19466740744454, 40.73865713391985, 45.461521421160015, 47.67460605076381, 52.163597447531565, 52.608494077410015, 54.036314146859304, 55.22451169150216, 58.545021057128906, 56.096750327519004, 61.84852123260498, 56.54244600023542, 65.1179335457938, 57.26001426151821, 73.39172336033413, 18.648108652659825, 0.30475230568221634, 0.27607776863234385, 0.16152950881847314, 0.04940507787146738, 34.160464014325825, 65.8852231161935, 61.380629539489746, 50.70425340107509, 46.582925932747976, 35.778713362557546, 10.37866233076368, 37.281025069100515, 38.52063233511788, 58.43175152369908, 11.550474286079407, 0.3071449558649744, 0.06335773917713336, 0.036829021626285145, 0.02098074721704636, 0.020462868934763328, 0.07033583402101483, 0.037312199627714496, 0.06463130190968513, 0.03714552767840879, 0.07805388487343277, 0.023517911788076162, 0.04114963746230517, 0.23694217577576637, 11.612464376858302, 68.95305429186139, 56.37553637368338, 40.618599210466655, 23.217987503324235, 21.662546396255493, 47.093972887311665, 54.75012690680367, 60.663047381809776, 67.21250970023019, 44.9908504486084, 0.38299662140863283, 0.12307182672832694, 0.22603752091526985, 1.0380667320319583, 35.639624323163716, 68.03162588391984, 63.17261859348842, 60.25869696480887, 59.905902181352886, 60.86184923989432, 60.52509784698486, 60.469359397888184, 56.47721283776419, 54.69677168982369, 57.563615798950195, 58.04258986881801, 58.1422061920166, 56.722157682691304, 53.75481482914516, 52.15439108439854, 49.82362481525966, 48.343154770987375, 46.78834247589111, 44.44022308077131, 42.44660077776228, 40.259960991995676, 41.52356038774763, 42.34717205592564, 41.11483607973371, 40.965241364070344, 39.55078615461077, 40.52268280301775, 41.520795004708425, 40.66088247299194, 41.85244641985212, 41.19664764404297, 42.406756332942415, 41.79685388292585, 40.840722697121755, 42.394117559705464, 40.94134998321533, 41.25705528259277, 39.72402906417847, 39.898154394967214, 39.279139382498606, 40.04160690307617, 40.72849191938128, 40.95781026567732, 40.632860388074604, 39.39648750850132, 41.01279483522688, 39.554930755070274, 38.017589705330984, 40.032039233616416, 37.47755834034511, 37.333247729710166, 38.68168463025774, 38.73142678397042, 37.710024220602854, 36.780473368508474, 39.36961882455008, 36.40573269980294, 37.20700938361031, 38.376575333731516, 39.093132632119314, 39.98630619049072, 43.51638017381941, 43.59980372020176, 42.6234324319022, 38.984038966042654, 43.563704354422434, 39.959003244127544, 39.96991886411394, 42.78208065032959, 39.71236998694283, 40.407023089272634, 39.06594780513218, 37.575531414576936, 37.87079163960048, 38.09554154532296, 38.39284454073225, 37.08607598713466, 36.41369880948748, 37.79682111740112, 36.89247138159615, 38.53128392355782, 39.687359946114675, 40.229072775159565, 37.06207343510219, 36.52354635511126, 37.09531361716134, 36.11818150111607, 38.19861459732056, 41.017616885049, 39.37134892599923, 39.2631515775408, 40.11159610748291, 39.459104674203054, 39.73535810198103, 39.91443402426583, 38.7886313029698, 38.098814146859304, 38.8518842288426, 39.27310139792306, 40.75402307510376, 39.17578492845808, 39.63506085532052, 40.39496449061802, 39.95235729217529, 40.06532457896641, 39.190334456307546, 40.28953947339739, 38.98574474879673, 41.077364444732666, 40.25142513002668, 40.78347648893084, 40.19040257590157, 41.98410088675362, 39.075616223471506, 40.97020237786429, 40.83285733631679, 42.710799080984934, 44.43971586227417, 48.42648799078805, 51.05486645017351, 54.45322690691267, 54.0205591065543, 56.88139649799892, 59.05788843972342, 62.72526577540806, 58.657310894557405, 63.3820720400129, 60.42389733450753, 65.84750829424176, 60.09770025525774, 75.36765207563127, 20.302655390330724, 0.5399630229387964, 1.5373591801949908, 0.04033324448391795, 0.05771468233849321, 35.93355049405779, 73.45182527814592, 64.06056363242013, 60.9150515965053, 39.82006706510271, 33.36799417223249, 17.68786413328988, 44.669715132032124, 44.13750396456037, 68.57029192788261, 16.731272629329137, 0.4994039993200983, 0.10065085840012346, 0.01067350766555007, 0.09053021004157406, 0.021153917835493172, 0.06541065366140433, 0.12534495975290025, 0.13523791890059197, 0.09184081400079386, 0.1581965990896736, 0.17645533861858503, 0.1643614697137049, 0.510226904281548, 16.552801200321742, 80.41983318328857, 63.25213377816336, 50.913884026663645, 28.825298411505564, 30.61688620703561, 56.726882457733154, 65.19569083622524, 66.53859002249581, 71.818512235369, 49.95967749186924, 0.6555015231881822, 0.3308798394032887, 0.8939370459743908, 1.351953340428216, 37.6182141985212, 70.07140854426792, 67.07477555956159, 62.61829825810024, 62.64127595084054, 63.26607881273542, 61.61767428261893, 61.02588926042829, 58.01507500239781, 55.56043972287859, 58.218691962105886, 59.282607078552246, 59.67729949951172, 59.25958769662039, 56.01135001863752, 55.63015794754028, 52.98216124943325, 51.43316807065691, 48.5825514793396, 48.43217509133475, 45.45162718636649, 43.07932111195156, 43.19609601157052, 43.40683140073504, 44.045954499925884, 42.62528412682669, 41.82577575956072, 44.08948843819754, 42.65657533918108, 43.19709307806832, 42.22528675624302, 43.6577273777553, 44.051874365125386, 43.650674956185476, 43.16891813278198, 44.48657103947231, 42.92466810771397, 43.62193373271397, 40.81882892336164, 42.443748542240684, 41.624013968876426, 42.10241828645979, 42.75659465789795, 41.52567958831787, 43.47677544185093, 42.97399336951119, 41.44098799569266, 40.14161927359444, 40.49377134868077, 41.196574687957764, 39.795303685324534, 40.376169613429475, 41.394730363573345, 41.86656863348824, 40.34213733673096, 39.755403654915945, 41.24357577732631, 39.17153263092041, 39.75929117202759, 39.818250111171174, 42.86176259177071, 43.424580574035645, 45.01162208829607, 45.9356039592198, 45.80336931773594, 41.70743751525879, 46.41326134545462, 44.20075341633388, 44.299556800297324, 46.13057735988072, 43.77172647203718, 44.04552371161324, 41.910123416355674, 40.35837180273873, 41.51292964390346, 41.89830800465175, 41.66593245097569, 40.31908668790545, 37.99916655676705, 40.529467718941824, 39.24883828844343, 40.13969462258475, 41.163508210863384, 42.36256231580462, 37.54210363115583, 37.70710597719465, 38.45230722427368, 37.515683106013704, 39.60501684461321, 43.99740048817226, 42.76721150534493, 39.991076128823416, 40.78813178198678, 40.80424118041992, 41.44215529305594, 42.19208826337542, 41.4311180795942, 39.991479124341694, 40.40630742481777, 41.03435509545462, 43.13422925131661, 41.43238959993635, 42.086628505161826, 41.669618470328196, 41.72617333275931, 41.59278876440865, 41.30648476736886, 42.4378217288426, 40.39614915847778, 43.46760729381016, 42.60290397916521, 45.054218019757954, 43.626971176692415, 45.0668637411935, 42.35060099193028, 42.445423058101106, 42.92229182379586, 46.41225733075823, 46.547868796757285, 51.573031834193635, 53.91180937630789, 57.78338732038225, 57.23635911941528, 59.45162895747593, 60.98309530530657, 65.8234258379255, 62.89390550340925, 67.56155245644706, 62.34064129420689, 69.83108425140381, 64.23904200962612, 78.96035017286027, 22.239001955304825, 0.6854745862739426, 2.245637591396059, 0.23578619637659617, 0.1689742864774806, 40.64555127280099, 79.43968554905483, 70.04141317095075, 66.14698260171073, 57.69445732661656, 46.93020384652274, 21.938961369650706, 56.54495082582746, 52.675217628479004, 79.92206423623222, 25.708492858069285, 0.6766035822885377, 0.14961915649473667, 0.1987775529601744, 0.18394499458372593, 0.11529895024640219, 0.19792831210153444], [0.08360586195651974, 0.0458708230539092, 0.05676291144586035, 0.08542685995676688, 0.040765115059912205, 0.1702179326010602, 0.2736941836774349, 14.59103638785226, 67.23643234797886, 49.79762813023159, 34.814147063664024, 12.438609531947545, 29.649165425981792, 32.348346029009136, 46.22129998888288, 61.02506937299456, 57.938481535230366, 41.42287056786673, 0.4166237312768187, 0.0411479173760329, 0.11959045353744711, 0.6976475587912968, 38.42376402446202, 61.815399169921875, 59.181212016514365, 62.85027081625802, 58.62084674835205, 61.20895344870431, 59.97322327750069, 58.56655352456229, 52.309676374707905, 58.72895377022879, 56.193618638174875, 55.35266426631382, 54.662801946912495, 52.866616180964876, 49.380656310490195, 46.649802344185964, 45.017816407339915, 44.41971547263009, 43.81777913229806, 40.73010737555367, 38.239403997148784, 38.11040374210903, 38.96518155506679, 37.81109619140625, 39.10996116910662, 39.53443356922695, 40.100100312914165, 41.58552442278181, 41.95968839100429, 41.192614214760916, 39.817454542432515, 38.80955580302647, 36.479407923562185, 39.6108672278268, 38.758726256234304, 38.01333045959473, 38.467238903045654, 39.48357275554112, 36.32159696306501, 37.66098730904715, 37.80875812258039, 36.51675796508789, 38.25913340704781, 41.38189009257725, 41.0925532068525, 39.90789924349104, 39.68374688284737, 38.97863326753889, 37.92484515053885, 38.669705935886924, 39.08782420839582, 35.405553409031455, 34.70557451248169, 36.16993168422154, 34.809630734579905, 35.25693838936942, 34.444704396384104, 35.33421277999878, 34.836520263126914, 35.86425610951015, 35.28228194372994, 36.33779321398054, 36.49771295275007, 39.28854029519217, 39.78784826823643, 35.39128875732422, 40.52360691343035, 36.40513515472412, 35.26803813661848, 40.31345864704677, 35.80051333563668, 37.763216154915945, 35.738031659807476, 35.95613213947841, 34.801313740866526, 34.07774918419974, 35.28426218032837, 35.00318322862898, 35.539337498801096, 36.25295223508562, 36.70657580239432, 38.52097627094814, 37.55056653703962, 35.520983832223074, 39.57193647112165, 37.44171258381435, 37.057855878557476, 35.03531517301287, 38.0098146711077, 37.497506618499756, 37.677103655678884, 38.471004826681956, 37.868613379342214, 37.60605832508632, 38.00595842088972, 36.91458402361189, 36.189171246119905, 37.88694967542376, 36.131143365587505, 38.23689569745745, 37.40305280685425, 37.83375079291207, 38.9478041103908, 38.44576549530029, 39.082526206970215, 39.34203795024327, 38.782430035727366, 38.7848619052342, 38.02481235776629, 37.70387159075056, 37.66698360443115, 37.307813848767964, 37.7536415372576, 38.676139967782156, 37.970453126089915, 39.481821809496196, 39.67598574502127, 43.94298914500645, 44.29095493044172, 49.06692429951259, 50.9070018359593, 56.192725794655935, 53.74713706970215, 60.40428951808384, 55.66563197544643, 62.46561854226248, 56.16448136738369, 63.23270661490304, 58.14671209880284, 67.68746076311383, 59.27745846339634, 73.23881435394287, 19.09680768421718, 0.11652263386973313, 0.9335802644491196, 0.13024261194680417, 0.12983405244137558, 21.062951598848613, 67.0929034096854, 60.63960415976388, 57.025745323726106, 71.04149518694196, 82.14372294289726, 13.612346138272967, 33.4374657358442, 38.439421789986746, 59.851219858442036, 29.840522289276123, 0.36215487548283165, 0.018230834776269536, 0.01398446424199002, 0.10625442450067826, 0.03361702683780875, 0.10228930333895342, 0.13412919268012047, 0.03168202816907849, 0.028831743435668092, 0.0645295080861875, 0.09365459238844258, 0.19965242887181894, 0.26872187906077927, 20.6348591872624, 75.97968414851597, 54.828061376299175, 42.63974680219378, 19.999081645693096, 24.357961075646536, 36.194239956992014, 53.96835381644112, 66.41628783089774, 62.80069541931152, 45.9345999445234, 0.47714327382189886, 0.024307322821446826, 0.0675542475655675, 0.8444332480430603, 41.18029505865914, 63.22048473358154, 64.11191082000732, 63.00192219870431, 61.98049531664167, 62.26310634613037, 62.53327315194266, 60.15156269073486, 55.37226513453892, 58.12662833077567, 57.79660974230085, 57.911244596753804, 56.673888547079905, 53.66561385563442, 52.39591046742031, 47.63038771493094, 47.32496574946812, 45.9610413142613, 45.693858759743826, 42.958613531930105, 40.58218370165144, 40.95988082885742, 41.799084254673545, 38.085470131465364, 39.63198280334473, 40.58517142704555, 41.90225805555071, 42.925925731658936, 44.48077276774815, 42.34479577200753, 41.883508341653005, 41.064055170331685, 39.22259841646467, 40.66252224785941, 40.3291893686567, 40.286878313337056, 39.14213480268206, 41.24478128978184, 39.147766317640034, 39.809137548719136, 39.712477684020996, 38.80389302117484, 39.270930085863384, 42.53007990973336, 41.61663498197283, 42.35034390858242, 41.09799712044852, 40.55860498973301, 39.95970153808594, 38.63165760040283, 40.131367206573486, 36.62825918197632, 37.83382027489798, 38.18203966958182, 36.28912108285086, 37.80410630362374, 36.504070554460796, 36.443374565669465, 37.13104820251465, 39.08008391516549, 37.10681635992867, 37.72217314583914, 39.612197807856965, 41.34390081678118, 41.04460368837629, 37.592467648642405, 41.71692875453404, 38.45332513536726, 39.04127475193569, 42.237407888684956, 38.08571679251534, 39.34375762939453, 36.99433544703892, 38.362786633627756, 36.831848348890034, 37.62645476205008, 36.5741674559457, 36.62126234599522, 38.221609660557334, 37.92691918781826, 40.03730596814837, 40.40002972739083, 38.30680499758039, 36.71769986833845, 40.788475717817036, 38.694754191807334, 38.284021854400635, 35.73913989748274, 38.422923292432515, 39.500206742967876, 40.5025052343096, 40.875349044799805, 39.409935746874126, 40.54576471873692, 40.24842698233468, 37.990467412131174, 38.669570446014404, 38.65041773659842, 38.071914196014404, 39.68517473765782, 39.63670410428728, 38.954352787562776, 40.25490270342146, 39.811638900211875, 41.785097530909944, 41.64222519738333, 41.40022986275809, 40.25469078336443, 40.61758477347237, 38.7361341885158, 39.27258375712803, 39.28896760940552, 40.23608350753784, 41.49847739083426, 38.740393434252056, 41.1485869543893, 41.95097534997122, 46.08102628162929, 47.615549836839946, 50.61353077207293, 53.13526480538504, 57.506247997283936, 55.40591178621565, 59.550307273864746, 58.44524492536272, 63.243115016392295, 59.375782421657014, 64.10590062822614, 59.7958288192749, 69.49587535858154, 62.14850275857108, 75.73266179221017, 20.495547805513652, 0.25169561696904047, 1.4770013732569558, 0.07489852061761276, 0.12864918102111134, 21.49292176110404, 73.94532803126744, 65.37885229928153, 62.160738536289756, 64.50526223863874, 65.73932484218052, 16.364979233060563, 40.93486731392996, 44.806650229862754, 68.21742071424211, 37.866779054914204, 0.4094966708549431, 0.039837761249925406, 0.11729739872472626, 0.08493416210902588, 0.029032277675079446, 0.05388316132926515, 0.24176213571003505, 0.1377520811344896, 0.13560542703739234, 0.25882275881511824, 0.2026401949780328, 0.41785065829753876, 0.33855200771774563, 28.412502459117345, 87.53498308999198, 61.56620897565569, 52.21454511369978, 23.365813902446202, 41.009327684129985, 44.05414990016392, 59.49425615583147, 71.90260628291539, 67.2693042755127, 51.40517030443464, 0.7284325840217727, 0.11936139368585177, 0.6859807733978543, 1.2310344917433602, 38.813627447400776, 65.03451347351074, 64.50788865770612, 66.15225628444126, 64.26345103127616, 64.96668515886579, 66.21346296582902, 62.27005454472133, 56.86447068623134, 60.30224132537842, 60.41833182743618, 60.63449028560093, 59.15510763440813, 57.006877490452354, 54.85144206455776, 50.34009483882359, 48.710401807512554, 49.6612662587847, 47.36474071230207, 44.45576620101929, 41.97998407908848, 42.27850995744978, 44.25767305919102, 40.645054476601736, 44.02514811924526, 42.280427660260884, 43.91664505004883, 44.535399505070274, 45.91702447618757, 43.94161687578474, 43.99209206444876, 42.333755084446494, 40.66557945523943, 43.65841177531651, 42.393575600215364, 40.97863054275513, 41.4411165373666, 44.293411118643625, 40.15944487707955, 42.56086390359061, 41.22239419392177, 41.5813033921378, 40.74900647572109, 44.77901724406651, 43.97698668071202, 42.637009211948936, 43.11262730189732, 41.86949382509504, 41.260237557547434, 39.36550201688494, 41.46073825018746, 39.280904224940706, 39.764589173453196, 39.53699050630842, 37.904716219220845, 38.905097007751465, 38.645689487457275, 40.47109242847988, 39.27063826152256, 41.08912079674857, 41.65840755190168, 39.71357202529907, 41.356588227408274, 42.93362086159842, 45.849043301173616, 40.281250272478374, 44.455446583884104, 41.53910003389631, 42.207325662885395, 45.700306688036235, 40.26268121174404, 42.58995253699166, 40.71345601763044, 40.13444178444998, 37.97664049693516, 39.06592001233782, 38.37503283364432, 39.688930238996235, 41.85824121747698, 40.70082766669137, 42.75780364445278, 42.798078877585276, 39.663708278111045, 37.54809992653983, 42.3468211718968, 39.417745522090364, 39.514148303440635, 36.34410912649972, 39.79465402875628, 39.66525077819824, 42.37262330736433, 44.10778651918684, 41.38225834710257, 41.653161661965505, 43.98149258749825, 40.77045209067208, 42.15667676925659, 42.18681458064488, 41.26670285633632, 42.986541816166465, 39.50760310036795, 41.46227380207607, 43.12808356966291, 42.777550424848286, 43.46821526118687, 42.872851916721885, 43.19537339891706, 41.85221018110003, 42.084304332733154, 41.11826848983765, 41.358363492148264, 42.39213384900774, 43.53797517504011, 44.72747550691877, 42.17356784003121, 44.31545775277274, 44.876017570495605, 47.59269026347569, 49.09009654181344, 53.06387553896223, 54.68337556294033, 60.54652609143938, 57.94999122619629, 63.6369389125279, 59.717341967991416, 65.81846482413155, 60.26583276476179, 68.54406942640031, 62.579791341509136, 71.5402090890067, 63.35915688105992, 80.0904677254813, 21.025700569152832, 0.2961717146847929, 4.513692677021027, 0.1687233777982848, 0.23956596212727682, 25.318862199783325, 80.22508212498256, 69.48067270006452, 70.41379492623466, 83.1965000970023, 88.52569198608398, 23.93608382769993, 49.423241819654194, 55.232415267399375, 77.06739684513637, 49.5679588999067, 0.6671553349920681, 0.09081186992781502, 0.2891414947807789, 0.2176814300141164, 0.13940033768968924, 0.21713336370885372], [0.021527739740642052, 0.038839296969984255, 0.0365827982313931, 0.07169050204434566, 0.031510419877512116, 0.05783009435981512, 0.032586752836193354, 26.08360525539943, 66.06809970310756, 48.94921834128243, 37.02118328639439, 21.001281125204905, 55.678642477308, 53.94983686719622, 46.96272141592843, 58.56269032614571, 57.14150926045009, 40.014227526528494, 0.09856686022664819, 0.11710788389401776, 0.3281885252467224, 1.2750283139092582, 22.549235548291886, 63.64131627764021, 55.32687602724348, 60.20958709716797, 57.65359844480242, 57.160606384277344, 57.12694583620344, 58.0139285496303, 56.988940715789795, 57.17934914997646, 52.81646408353533, 54.382271902901785, 51.1405794279916, 46.13849483217512, 46.79814638410296, 47.38363286427089, 45.26222276687622, 41.362772124154226, 41.47453737258911, 40.71381384985787, 40.1654828616551, 38.454033851623535, 37.9253454208374, 43.59198004858834, 43.77948760986328, 45.74428183691842, 46.310063225882395, 48.91205937521798, 49.512012004852295, 47.918407917022705, 40.100548471723286, 37.14749806267874, 39.283287457057405, 39.92498138972691, 36.544623715536936, 38.7738698550633, 39.76167787824358, 38.49044936043875, 37.52166550500052, 37.59806094850813, 37.35019438607352, 37.88159956250872, 36.512387548174175, 40.127010686056956, 43.89892019544329, 43.91009289877755, 39.74957064219883, 37.522346428462434, 36.28622368403843, 38.55146844046456, 38.97984920229231, 37.33189977918352, 37.0276312146868, 35.69807604381016, 35.28836856569563, 35.37968179157802, 34.67826114382063, 35.45808873857771, 34.319212981632774, 36.648315157209126, 35.80924722126552, 35.072185788835796, 38.31905814579555, 37.11023487363543, 36.856872286115376, 33.83931132725307, 37.76168755122593, 34.143896034785676, 35.36272471291678, 39.293939045497346, 36.46058872767857, 34.98694181442261, 34.52705444608416, 35.22394834245954, 35.150519779750276, 34.846143518175396, 35.587460722242085, 35.02728305544172, 34.74930647441319, 35.40289919716971, 37.64552409308297, 38.232553073338096, 37.519886766161235, 36.554722922188894, 38.712524209703716, 37.24499518530709, 37.61264174325125, 37.61713375364031, 36.78724091393607, 37.973274094717844, 37.58913598741804, 37.4387526512146, 36.926079818180625, 38.86592306409563, 36.69349234444754, 37.254125118255615, 35.63209594999041, 35.92233610153198, 38.195988178253174, 37.85152428490775, 38.74407597950527, 39.15834494999477, 38.679346561431885, 37.97995826176235, 40.05151156016758, 39.60705961499895, 39.19738687787737, 39.46149832861764, 37.757265022822786, 37.838781288691926, 37.54871484211513, 39.010949339185444, 39.099993978227886, 38.25069829395839, 37.84314128330776, 39.42558309010097, 41.41729463849749, 45.124019622802734, 44.95266662325178, 50.07640722819737, 51.07050337110247, 56.81256416865757, 54.79237542833601, 58.28285162789481, 57.584665366581504, 57.974924836839946, 56.356595584324424, 61.13295405251639, 58.657964025224956, 64.1270717893328, 61.552639143807546, 73.4830574308123, 20.658179078783306, 0.36030144350869314, 1.4287881489310945, 0.2151623009038823, 0.12916110855128082, 12.199317915099007, 68.40341009412492, 60.337927273341585, 58.59301226479666, 45.61910309110369, 41.491741112300325, 15.271329300744192, 26.190327848706925, 37.658492905753, 57.427226134708945, 39.48448296955654, 0.5338458940386772, 0.029326388678912605, 0.028279035950877836, 0.09445614580597196, 0.053372044648442946, 0.042976538717214546, 0.08179642619299037, 0.04559197908799563, 0.0169564476236701, 0.021666715586824075, 0.026195480521502237, 0.05040398998452084, 0.027302820834198167, 30.99836662837437, 76.23789310455322, 52.85895231791905, 44.42815405981881, 26.26345763887678, 57.337274755750386, 53.73553357805525, 54.14935438973563, 63.74729020254952, 62.72218772343227, 42.65523781095232, 0.13266838820917265, 0.08621044576700244, 0.2864341671977724, 0.955186556492533, 27.024052619934082, 65.78873348236084, 56.463024616241455, 62.50091539110456, 58.68709087371826, 60.58629758017403, 59.623478753226145, 60.13378919873919, 59.53766850062779, 60.843915939331055, 55.7508134160723, 55.708992208753315, 52.40598882947649, 48.60229478563581, 48.51595994404384, 47.99530015672956, 47.15291098185948, 45.50368309020996, 42.50833552224295, 44.0576239994594, 41.59054102216448, 40.3636975969587, 40.201853207179475, 45.13804456165859, 45.950316769736155, 47.600541727883474, 48.47941241945539, 50.25807135445731, 50.82543345860073, 50.338670458112446, 41.40003183909825, 38.74292605263846, 42.096421991075786, 41.03040157045637, 37.97431632450649, 39.00101341520037, 41.15455545697893, 40.58679035731724, 39.57208585739136, 39.515350341796875, 39.38724640437535, 39.84524733679635, 37.51667669841221, 41.43204913820539, 45.05557639258248, 44.452841009412495, 42.61661972318377, 39.31327935627529, 37.08729192188808, 39.75830800192696, 40.83106470108032, 38.318210465567454, 40.14214733668736, 37.4031639780317, 37.97652585165841, 37.65990686416626, 37.120146478925435, 39.69040673119681, 36.607407638004844, 38.30022157941546, 36.430624621255056, 37.06003066471645, 40.2490280015128, 40.473652839660645, 40.13881914956229, 37.09902742930821, 37.52464975629534, 37.095963273729595, 38.89407021658761, 40.2710850579398, 38.35166604178292, 37.17682293483189, 37.17692715781075, 36.254310607910156, 36.8270262990679, 37.575274331229075, 36.8661516053336, 37.20196846553257, 36.687812192099436, 37.91733067376273, 38.892242840358186, 39.41758918762207, 38.338575635637554, 36.997007029397146, 38.62544938496181, 37.67622470855713, 38.628847054072786, 37.86917618342808, 37.202246393476216, 38.64941372190203, 40.56158924102783, 39.15755632945469, 38.70012862341744, 41.87102590288435, 37.8307318006243, 39.95693962914603, 38.374664579119, 38.61456503186907, 39.57494504111153, 38.948238372802734, 40.954669679914204, 40.491447176252095, 40.415333134787424, 40.95379420689174, 41.55544914518084, 40.48125416891915, 41.85467331750052, 40.33494595118931, 40.55420330592564, 39.51752512795584, 40.027984959738596, 41.970152378082275, 40.27479192188808, 39.733964988163535, 40.746334893362864, 42.35033001218523, 42.8231966154916, 46.813255241939, 47.91549662181309, 51.49192898614066, 54.24809871401106, 58.39819867270333, 57.80111564908709, 59.681933947971885, 59.17830072130476, 60.028794969831196, 58.52039664132254, 63.560175214494976, 60.493414061410085, 66.94000829969133, 63.911330223083496, 75.45445592062813, 21.814027547836304, 0.34972234975014416, 2.63132558124406, 0.43193699100187843, 0.15640593160476002, 13.597545606749398, 74.92981828962053, 64.91543524605888, 64.9473900113787, 52.89820963995797, 47.02098206111363, 22.147935390472412, 34.74244165420532, 44.65445341382708, 65.02309758322579, 48.89376476832798, 0.6887034358722823, 0.09463044109621219, 0.045700235957545896, 0.018432312179356813, 0.018455143186396787, 0.026507353875786066, 0.17061416991055012, 0.14062113075384072, 0.15663575141557626, 0.13049575979156153, 0.17093409917184285, 0.20673543880028383, 0.10576027458799736, 41.64667551858084, 84.26101970672607, 60.11432729448591, 52.031161308288574, 31.37883608681815, 68.25369725908551, 64.81732668195451, 61.46558516366141, 67.16652652195522, 68.46825763157436, 47.06248712539673, 0.2946552432009152, 0.3476085231772491, 0.6876344446625028, 1.8682123124599457, 29.836040701184952, 61.927675110953196, 59.593823841639924, 64.39432729993547, 60.871486391339985, 60.190048762730186, 62.360582624162944, 64.1990134375436, 61.59997027260916, 62.38201781681606, 58.730218342372346, 58.49320139203753, 55.68004253932408, 49.55378457478115, 51.783287797655376, 51.746267795562744, 49.70104816981724, 46.396988664354595, 46.153600215911865, 46.21143354688372, 44.08933905192784, 42.65359803608486, 42.83332361493792, 47.90518202100481, 48.0575247492109, 49.62311370032174, 50.76307685034615, 53.103935377938406, 54.87529523032052, 52.407295090811594, 43.84014538356236, 40.87207644326346, 43.68622541427612, 42.12991925648281, 40.93764659336635, 41.94722332273211, 43.534865856170654, 42.41639001028878, 42.12229708262852, 41.352137906210764, 41.05285120010376, 43.30830594471523, 40.02975327627999, 43.693465437207905, 47.22710732051304, 45.45702246257237, 42.28682695116316, 39.79516819545201, 38.10833665302822, 40.657752309526714, 42.80068097795759, 40.937167167663574, 42.7131267275129, 41.30514029094151, 41.17364910670689, 39.75027241025652, 39.344077246529714, 41.18137897763933, 39.4152615410941, 40.72958973475865, 39.563987731933594, 39.57037660053798, 42.91197027478899, 42.27897548675537, 42.20352152415684, 38.79679891041347, 40.5825206892831, 40.143328530447825, 40.75595814841134, 42.735239369528635, 40.7985714503697, 39.198738302503315, 39.53662919998169, 39.40915754863194, 38.59498153414045, 41.07055868421282, 40.15920863832746, 38.8116854258946, 38.870262214115684, 40.80488388878958, 41.70768765040806, 41.04091419492449, 39.92525584357125, 38.629361220768516, 39.761990547180176, 39.654977866581504, 39.38356385912214, 39.59099537985665, 40.180834906441824, 40.61404466629028, 42.43282944815499, 41.25063514709473, 40.036308901650564, 44.755209241594585, 41.15679625102452, 42.32100166593279, 41.369237422943115, 39.899561405181885, 43.51030397415161, 42.210368973868235, 43.2667452948434, 41.79416145597185, 43.492822306496755, 42.264391217912944, 44.370887007032124, 42.098231996808735, 45.15221193858555, 42.427131925310405, 41.83986323220389, 40.99234628677368, 41.80920083182198, 44.5860310282026, 43.8434944152832, 41.96356201171875, 43.931854656764436, 44.789133821214946, 46.15934637614659, 50.528325012751985, 50.54149184908186, 54.32738808223179, 57.134804248809814, 60.794041769845144, 60.90890938895089, 61.19801698412214, 62.68389620099749, 61.08035618918282, 60.672788756234304, 65.31121853419712, 61.91838536943708, 70.25454916272844, 67.81449467795235, 77.94478757040841, 25.31317162513733, 0.8159955197146961, 7.01112972838538, 0.87591010757855, 0.258097622011389, 15.266397816794258, 80.22003773280552, 70.2185366494315, 70.22876439775739, 58.06466776984078, 52.9762726511274, 25.283812011991227, 41.77973699569702, 54.44061592647007, 72.19037982395717, 60.81246839250837, 1.293605842760631, 0.39650750213435715, 0.23109276965260506, 0.19109009046639713, 0.12579853327146598, 0.10324678410376821], [0.09116702872727599, 0.10815907908337456, 0.11727264576724597, 0.04068109206855297, 0.025193126539566686, 0.044128324769969494, 0.12206724206251757, 29.929445334843226, 65.73198754446847, 47.45536259242466, 36.268450192042756, 16.060564756393433, 22.412858043398174, 37.452812331063406, 53.13628966467721, 59.2037867137364, 58.913977350507466, 38.2539952141898, 0.03287182914625321, 0.06616150015699011, 0.05430714054299252, 1.1616583572966712, 19.271403755460465, 45.10004833766392, 57.3632401738848, 57.0717111315046, 57.10638264247349, 58.44726685115269, 57.824058600834434, 57.43643944604056, 58.48322377886091, 53.746782711574006, 52.36923285893032, 48.59851843970162, 47.79905523572649, 46.545812129974365, 46.59218440737043, 44.918874059404644, 43.46197925295149, 46.09034729003906, 43.042572089603965, 40.83912461144583, 39.9757206099374, 44.302516732897075, 49.0146530015128, 48.785692487444194, 50.36508403505598, 51.31995759691511, 48.746188504355295, 51.55328505379813, 50.50850875037057, 49.543212890625, 46.69900253840855, 38.639686243874685, 38.36217519215175, 37.80719477789742, 38.29863044193813, 37.86126913343157, 38.024923528943745, 38.28909751347133, 37.055969442640034, 36.531759125845774, 38.10928160803658, 35.41440888813564, 35.93877553939819, 36.458594594682964, 40.002505915505544, 42.00106838771275, 39.33195263998849, 37.69854579653059, 38.28233691624233, 35.76286799567086, 34.51506532941546, 36.37935038975307, 36.49010814939226, 38.131022521427695, 34.895708492824006, 35.816535881587434, 34.92636047090803, 34.00188527788435, 34.72346264975411, 33.88205664498465, 33.99168184825352, 35.35408115386963, 35.900143555232454, 37.595504011426655, 37.0461551121303, 36.77697842461722, 35.30458913530622, 36.51655994142805, 36.948025703430176, 36.693589619227815, 35.57665627343314, 35.367591926029746, 34.198383808135986, 35.369752815791536, 36.01332623617989, 34.837329728262766, 35.38943011420113, 35.44851064682007, 35.26200362614223, 37.43149178368704, 36.68549844196865, 38.042432989392964, 37.643224239349365, 38.38796690532139, 38.5788825580052, 36.633126395089285, 36.85817854745047, 35.48175777707781, 35.489831583840505, 36.91299636023385, 39.610790797642295, 37.738365922655376, 35.72754682813372, 36.09795182091849, 36.230992453438894, 35.13730778012957, 36.2701872416905, 37.7010714667184, 36.7423347064427, 38.82715559005737, 37.440652983529226, 37.17784432002476, 38.86064938136509, 37.25531326021467, 37.77749122892107, 37.363903181893484, 37.78844853809902, 37.80811888831002, 37.18720006942749, 36.0882625579834, 36.07263258525303, 37.77651848111834, 38.22642823628017, 38.937486035483225, 38.24282945905413, 39.20851789202009, 39.47053446088518, 42.31675631659371, 43.13440990447998, 45.88438531330654, 48.97114338193621, 53.8679176058088, 54.99577004568917, 59.54922335488455, 56.6325398172651, 62.36143030439104, 57.227107592991416, 61.206396511622835, 59.834530285426546, 64.76288754599435, 55.378160681043354, 66.36312021527971, 23.360660076141357, 0.1638193338045052, 0.2877385014934199, 0.423802631774119, 0.18637903540262155, 8.143795098577227, 67.38444287436349, 59.29903956821987, 63.191392626081196, 49.77630410875593, 40.53502280371529, 9.611392736434937, 19.91371260370527, 39.07873943873814, 56.84670066833496, 42.44508607046944, 1.6051311492919922, 0.16217767260968685, 0.07660854421555996, 0.03692232358402439, 0.07669767657560961, 0.08251139854214021, 0.04552961493443165, 0.05492106545716524, 0.010635814197095377, 0.05362548087058323, 0.029541932112936462, 0.09899244417569467, 0.018181973469576666, 38.90560075214931, 73.94509179251534, 52.08462422234671, 43.46202789034162, 23.738885266440256, 35.53567927224295, 44.464322907584055, 57.80113301958357, 64.27022552490234, 63.37481812068394, 42.42258085523333, 0.036469537166080306, 0.162608447351626, 0.28153441154531067, 1.4768021553754807, 21.49322053364345, 51.794203417641775, 61.12321962629046, 56.251729897090364, 58.66630186353411, 59.27494321550642, 57.7722840990339, 59.112014906747, 59.11028480529785, 55.673712730407715, 54.57100929532732, 50.352987221309114, 49.61062778745379, 48.37224687848772, 48.42628649302891, 47.704559734889436, 46.098837988717214, 47.815241064344136, 44.13793127877371, 43.70144544328962, 41.821895190647666, 46.837066718510215, 51.525773661477224, 50.430793149130686, 52.96433564594814, 53.42692586353847, 50.93791784558977, 52.732731342315674, 51.43792758669172, 53.93326541355678, 49.43650593076433, 40.24209022521973, 38.69689771107265, 38.928095545087544, 39.925200257982524, 38.68007264818464, 39.16511944362095, 38.74682051794869, 39.44420426232474, 37.84876932416643, 39.76203571047102, 38.599452699933735, 37.97189140319824, 38.16940437044416, 42.794424125126426, 43.043096678597585, 39.66336781638009, 39.94427653721401, 38.61363397325788, 35.830008438655305, 36.13095576422555, 39.42287329265049, 39.23440687997, 38.57525559834072, 36.439876147678916, 37.94553688594273, 37.300799642290386, 35.94383730207171, 36.12762410300118, 36.62108516693115, 36.855163029261995, 36.997906821114675, 38.966744899749756, 40.519135747637065, 37.5601863179888, 37.95208903721401, 37.996314321245464, 37.49830913543701, 37.512545994349885, 39.82377392905099, 38.99600723811558, 38.944389070783345, 37.0201028415135, 36.413542475019185, 36.56423153196062, 35.616135937826975, 36.16965028217861, 37.42318868637085, 38.6851761000497, 38.8995349747794, 39.65993888037545, 39.75829063143049, 39.872883796691895, 38.09365858350481, 37.434795652117046, 37.769872529166086, 37.60904605048043, 36.543018681662424, 37.09775243486677, 38.91158662523542, 40.317568506513325, 38.32863276345389, 37.58093711308071, 39.37100151606968, 38.816583905901226, 36.61072192873274, 37.96825054713658, 39.786326612745015, 39.40681253160749, 39.44588572638375, 40.71449129922049, 38.60199921471732, 40.68449592590332, 39.62809181213379, 39.73436450958252, 39.10455894470215, 41.17074128559658, 40.04192999431065, 40.33875356401716, 38.541699273245676, 38.81602110181536, 39.57322883605957, 42.19398512159075, 40.762155941554475, 39.97108268737793, 40.934339250837056, 42.46275881358555, 44.20445333208357, 45.85848937715803, 47.96002067838396, 50.58452551705496, 55.72273574556623, 57.17970698220389, 60.01773343767439, 57.830576011112754, 63.59922409057617, 59.81746550968715, 62.48617131369454, 60.88677242824009, 66.96504960741315, 56.7466014453343, 66.52498544965471, 24.521365336009435, 0.10047517889844519, 1.6879924344164985, 0.42512316948601175, 0.08507222362927028, 8.418105636324201, 72.00206279754639, 64.15422534942627, 69.43416145869664, 53.93364061628069, 42.48638268879482, 14.398185661860875, 26.290368012019567, 46.81592335019793, 63.095424107142854, 52.027353695460725, 2.1874214581080844, 0.1923691425472498, 0.014418665585773332, 0.041655281758201976, 0.11770135776272841, 0.06307089528334991, 0.18265178826238426, 0.1528218960655587, 0.2105167651815074, 0.1810367799230984, 0.12314532564154693, 0.20593611097761563, 0.21531771256455354, 46.51829031535557, 82.37060941968645, 58.74709551674979, 50.36495896748134, 27.00168810571943, 29.786934307643346, 49.49026761736189, 65.88586929866246, 67.42920316968645, 69.19943741389683, 45.69391087123326, 0.24237520567008428, 0.1898682253169162, 0.5590286084583828, 2.200645617076329, 24.883232729775564, 52.5761467388698, 60.32835265568325, 58.96237850189209, 60.28510706765311, 62.35194601331438, 60.32732432229178, 61.82966382162911, 63.56264182499477, 58.41508279527937, 58.711430413382395, 51.89814846856253, 53.40093960080828, 51.66220848900931, 51.463114806583945, 48.76869024549212, 47.742205074855256, 51.62213127953665, 46.960386821201865, 45.37166036878313, 43.26944119589669, 48.46522767203194, 53.12797614506313, 50.156165599823, 55.5857971736363, 56.751235893794465, 54.04923432213919, 55.37972749982561, 54.29135125023978, 55.506806577954976, 50.99762371608189, 42.76676334653582, 39.991538184029714, 42.14190142495291, 42.20368480682373, 40.871857575007844, 41.673870767865864, 40.14679568154471, 40.559671538216726, 39.56841026033674, 40.81769984109061, 40.01040949140276, 39.995456968035015, 40.42813171659197, 44.695475578308105, 43.849421228681294, 40.265661988939556, 40.4713842528207, 39.03882551193237, 37.41666085379464, 37.74923290525164, 40.008578641074045, 42.60980006626674, 42.84097358158657, 40.92816925048828, 40.35567937578474, 39.48941271645682, 37.46804278237479, 38.64424078805106, 37.770025389535085, 40.11565038136074, 38.89409800938198, 40.25299889700753, 42.66849497386387, 39.41447639465332, 41.22677155903408, 40.81153678894043, 40.83559145246233, 40.817098821912495, 41.53092895235334, 41.17598370143345, 40.99722392218453, 39.093792710985454, 39.65817403793335, 39.700120312826975, 38.1993476322719, 39.019599846431184, 38.853068896702354, 40.67333711896624, 40.87680121830532, 42.18035275595528, 42.36036321095058, 41.05196877888271, 39.98872763769967, 39.869392326899934, 38.72540964399065, 39.07983030591692, 36.1617362839835, 37.40517200742449, 39.59442778996059, 43.15817621776036, 40.93504796709333, 40.3660808290754, 41.32895871571132, 40.47388560431344, 37.80201489584786, 41.150963238307405, 41.94411052976336, 43.077792508261545, 42.107268129076274, 42.32772752216884, 40.521897656576975, 43.289375577654155, 42.26577043533325, 42.3318304334368, 41.692915780203684, 41.54674652644566, 42.02134323120117, 41.88569702420916, 40.90297160829817, 40.27516712461199, 40.507500989096506, 43.91877467291695, 43.33900308609009, 43.204284463609966, 43.666753087724956, 44.905960832323345, 47.18330935069493, 49.561747210366384, 50.59635829925537, 54.33432238442557, 58.36055333273751, 61.202172006879536, 64.51312065124512, 62.12767205919538, 66.14212581089565, 61.75638117109026, 65.3496698651995, 63.64816720145089, 68.38358688354492, 58.654635838099885, 68.87930611201695, 27.894264119012014, 0.4091850332915783, 4.063729073320117, 1.8672232798167636, 0.25444343952195986, 9.80930609362466, 76.65773800441197, 71.19605786459786, 72.89621952601841, 64.79200744628906, 52.03398922511509, 17.94385835102626, 32.20882272720337, 55.357597487313406, 72.72688497815813, 64.98925290788922, 4.05793514422008, 0.5971877351403236, 0.2970345126731055, 0.23437275364995003, 0.17230780688779695, 0.1935253662190267], [0.04919437578480158, 0.046100588581923924, 0.11679737269878387, 0.0403674562195582, 0.11032752093992063, 0.035685218538024595, 0.09051959775388241, 30.375821931021555, 63.705378668648855, 48.6078324999128, 30.488796166011266, 26.123923914773123, 30.24294110706874, 34.991510254996165, 56.94307565689087, 57.20278542382376, 62.42502021789551, 31.881284645625524, 0.12719635612198285, 0.06952398722725255, 0.14157661662570067, 0.2661091392593724, 21.66859654017857, 44.59139156341553, 46.14831611088344, 58.84087535313198, 55.32230758666992, 58.99299226488386, 53.723346437726704, 54.49371406010219, 53.10642283303397, 51.932562896183555, 49.67270646776472, 49.684038979666575, 47.20894125529698, 45.87127753666469, 47.84586524963379, 48.638963903699604, 45.20872163772583, 46.688552447727744, 44.13311965124947, 45.840750626155305, 46.92581953321184, 51.95048230034964, 50.71424491064889, 56.160413197108674, 51.923474652426584, 49.95964275087629, 48.76250982284546, 49.85004186630249, 53.534768853868755, 51.10317380087716, 45.7591301373073, 39.34624508449009, 39.232034070151194, 39.18920884813581, 36.7545496395656, 35.959647927965435, 39.10516343797956, 37.127914564950125, 38.71241651262556, 36.63041659763881, 35.52471154076712, 36.467599460056846, 34.67467934744698, 37.93543420519148, 40.792196478162495, 41.939538615090505, 38.71544940131051, 36.374097551618306, 38.63566671098982, 35.08242743355887, 36.33107083184378, 39.36907686505999, 36.80006381443569, 37.708832604544504, 36.50159699576241, 36.270774364471436, 34.42117779595511, 36.06453793389456, 34.56644378389631, 34.96766056333269, 34.47196912765503, 36.17742531640189, 34.16218021937779, 37.76931667327881, 37.369374888283865, 35.37201792853219, 33.47134862627302, 34.72281299318586, 35.93678488050188, 36.983680384499685, 36.53507341657366, 36.01837757655552, 34.990370750427246, 33.69926691055298, 34.515732356480186, 35.88372496196202, 36.043891361781526, 36.451590810503276, 36.42840119770595, 34.91532325744629, 36.717001574380056, 37.85989686420986, 35.5346439906529, 37.159917967660085, 37.90286799839565, 36.113050256456646, 37.91026088169643, 36.276475361415315, 36.53885671070644, 37.62376580919538, 37.810731410980225, 36.842687538691926, 35.96225697653634, 35.78853464126587, 35.7746000289917, 34.558675697871614, 36.35136999402727, 36.88062817709786, 37.26035417829241, 38.20889098303658, 36.302423409053254, 38.53451483590262, 37.51918499810355, 36.859529972076416, 37.39457253047398, 36.45440135683332, 37.33738885607038, 37.173981121608186, 37.173123019082205, 38.58584812709263, 37.80294942855835, 36.32542889458792, 35.41964782987322, 37.81757191249302, 37.41896070752825, 38.54735510689871, 38.10810388837542, 39.34190593447004, 40.11207553318569, 40.936729431152344, 41.64268030439104, 45.56641142708914, 45.905862195151194, 52.15683337620327, 53.58824219022478, 57.7868127822876, 56.50878197806222, 60.61685575757708, 58.31084592001778, 65.01074368613106, 58.536314964294434, 66.06457696642194, 27.314657551901682, 0.16258187592029572, 1.2267190090247562, 0.5672489245023046, 0.030766643716820648, 3.3717794716358185, 61.503834996904644, 61.0387920652117, 63.444869858878, 51.66543245315552, 49.37557717732021, 25.567633765084402, 19.383096047810145, 29.83503668648856, 52.90740558079311, 51.31098747253418, 2.494497529097966, 0.2313805499247142, 0.06134855627481427, 0.017130188211532574, 0.01987822789565793, 0.04044690588489175, 0.04639954771846533, 0.009068887697399726, 0.008059439631844205, 0.06809493819517748, 0.020045988893668567, 0.028455265065921203, 0.09766150452196598, 37.99670689446585, 72.14598083496094, 53.10242067064558, 37.15202481406075, 21.93537609917777, 21.90997174807957, 39.204661641802105, 61.747647285461426, 62.451075962611604, 68.00989191872733, 35.79693153926304, 0.06389596672462565, 0.08094538721655097, 0.28741304895707537, 0.4613712430000305, 23.120405265263148, 46.13369710104806, 51.60582733154297, 61.04273864201137, 56.26180478504726, 60.245488439287456, 57.12256152289254, 56.629621573856895, 54.65653467178345, 55.20379563740322, 51.505373750414165, 52.29666239874703, 49.81580809184483, 48.873288427080425, 50.45988525663103, 49.7393605368478, 48.44202068873814, 49.5311403955732, 46.148197991507395, 47.731459685734336, 48.035116808755056, 54.217207023075645, 53.63480206898281, 57.587396008627756, 52.72760704585484, 51.17086662564959, 51.25381769452776, 52.585238456726074, 54.650625228881836, 52.00432736533028, 46.594070843287874, 40.47116538456508, 39.99849680491856, 40.544020720890586, 38.382429191044395, 38.684078284672324, 40.9814167703901, 39.454525811331614, 39.39539316722325, 39.921340533665244, 37.38681834084647, 37.81969458716256, 36.54123646872384, 38.2297077860151, 44.360169410705566, 42.81136730739048, 39.133727482386995, 37.301709856305806, 39.606142452784944, 35.63247462681362, 38.06377438136509, 40.173977034432546, 38.378906454358784, 39.98090396608625, 37.449115889413015, 38.970017501286094, 35.380678858075825, 37.71330724443708, 37.058894634246826, 37.52372564588274, 35.71831267220633, 37.61002574648176, 35.094360964638845, 39.398471219199045, 39.65655858176095, 36.85683059692383, 35.69917038508824, 36.83262307303292, 37.53986283711025, 38.93705872126988, 37.67306675229754, 38.35223926816668, 35.91083335876465, 35.40353148324149, 36.668739386967246, 38.2826634815761, 37.831850460597444, 37.173852579934255, 38.863876819610596, 37.72994818006243, 38.750631604875835, 38.95483568736485, 38.06126260757446, 37.73464863640921, 36.89216218675886, 35.930159773145405, 37.66370752879551, 35.85424028124128, 38.10505362919399, 38.35917704445975, 40.46088899884905, 38.363540513174875, 36.167656149183, 37.37730973107474, 37.79927383150373, 37.461706025259836, 38.11500344957624, 38.70774037497384, 38.46645723070417, 39.8090854372297, 39.0714681489127, 37.73804630552019, 39.54125322614397, 38.33461168834141, 39.633653845105854, 39.06405094691685, 40.2657036781311, 38.431712763650076, 37.899442536490305, 41.10433387756348, 39.856051785605295, 39.37523644311087, 39.39663689477103, 39.69357163565499, 39.294769355228965, 40.319632121494834, 41.33183874402727, 42.230348518916536, 42.871052333286826, 43.28654418672834, 44.9005377633231, 46.9244681085859, 48.24803045817784, 53.793551036289756, 56.200049195970806, 59.7351085117885, 59.864998136247905, 62.38980674743652, 59.98043550763811, 66.24368068150112, 60.43147781917027, 68.26353590829032, 28.4219137941088, 0.11301112693867513, 1.9635387744222368, 1.919090062379837, 0.12361963519028255, 3.890770605632237, 65.53949465070451, 64.33375290461949, 67.59773172651018, 58.87030097416469, 48.550905908857075, 23.779202188764298, 28.630059242248535, 38.71534865243094, 59.048563957214355, 63.458516120910645, 4.637461807046618, 0.3031539214508874, 0.08295339625328779, 0.09974712439413581, 0.024191792056496655, 0.023616619973576496, 0.137644356914929, 0.17380445157842977, 0.12954962413225854, 0.12717833423188754, 0.11188023297914437, 0.24680158815213613, 0.181730093434453, 49.281012194497244, 82.4574202128819, 62.770151138305664, 45.96316051483154, 32.81368773324149, 38.58947161265782, 47.200526986803325, 67.83212225777763, 66.84892436436245, 75.56764207567487, 38.31941597802298, 0.20014541170426778, 0.33828406780958176, 0.7959739054952348, 0.6162601060100964, 27.315255096980504, 50.68165438515799, 51.88586057935442, 60.95525387355259, 59.01007093702044, 63.56005709511893, 58.28699970245361, 58.3115268434797, 58.62946251460484, 55.490401881081716, 54.302589961460654, 54.657802718026296, 51.707354409354075, 49.68296895708357, 51.760185037340435, 51.190519605364116, 50.07495158059256, 49.58030932290213, 48.95889023372105, 50.913790225982666, 51.1640921320234, 56.87324626105172, 56.97170918328421, 60.812607356480186, 55.32317263739449, 52.73131043570382, 52.15282426561628, 54.96199137823922, 58.95178944723946, 57.25154788153512, 50.75470774514334, 42.57603529521397, 41.41031864711216, 44.250224590301514, 39.90606491906302, 40.10953596660069, 43.84498132978167, 42.06408160073416, 41.472876753125874, 42.550684792654856, 39.03330169405256, 39.979250294821604, 38.17333705084664, 41.32162489209856, 46.33423948287964, 44.22858442578997, 40.814173630305696, 37.65797873905727, 40.69831936700003, 35.10797595977783, 39.4725216456822, 41.57532099315098, 40.04966333934239, 42.567079067230225, 40.391528606414795, 42.265489033290315, 38.968537534986226, 40.15940318788801, 39.78054223741804, 38.43206712177822, 38.90789713178362, 40.39273064477103, 37.04217379433768, 42.01715694155012, 42.83676644733974, 39.113292830330984, 37.03354065758841, 39.04872669492449, 39.14898920059204, 39.75658484867641, 41.31643458775112, 40.38788775035313, 38.14053807939802, 36.668548311506, 37.91720560618809, 39.81968491418021, 39.55888428006853, 40.36054311479841, 40.792255537850515, 40.10273715427944, 40.59595850535801, 40.513573714665, 38.617528438568115, 37.89754220417568, 37.09691865103585, 35.459690298352925, 39.98934950147356, 38.23499883924212, 38.88993951252529, 39.11710739135742, 40.91245242527553, 40.516203607831685, 39.333529881068635, 38.63882119315011, 40.50574309485299, 40.76430640901838, 41.11455120359148, 41.114724908556255, 41.416554655347554, 41.284170627593994, 41.04532977512905, 39.58272007533482, 41.57459143229893, 40.082451888493125, 41.00638859612601, 41.754337855747764, 42.34873192650931, 41.14602654320853, 41.99500608444214, 43.58152995790754, 41.47020517076765, 41.481819084712434, 40.044969831194194, 42.174564906529014, 40.76070029394967, 42.87498501368931, 43.6489691734314, 44.19650111879621, 44.348180294036865, 45.67203794206892, 46.0804009437561, 50.35137871333531, 51.25144835880825, 55.368419306618826, 58.75068078722273, 62.54412623814174, 61.1443977355957, 65.70411831992013, 63.35192380632673, 70.11642592293876, 61.913910729544504, 70.36839539664132, 30.530016354152135, 0.2766224965453148, 6.484727254935673, 3.2645220841680254, 0.21214638916509493, 4.669155146394457, 71.96286800929478, 70.35974488939557, 73.31762777056012, 65.93352699279785, 61.669090952192036, 37.74183307375227, 30.933501720428467, 48.39036430631365, 67.00063828059605, 75.44975199018205, 7.804338250841413, 0.6624482018607003, 0.1817476132086345, 0.21743380544441088, 0.16564124104167732, 0.09555615963680403], [0.0951447638549975, 0.055685767637831826, 0.0524232796659427, 0.07987775986215898, 0.04893364870388593, 0.08952835987188987, 0.06317901305322136, 39.36367464065552, 59.48374353136335, 42.248056003025596, 34.173995631081716, 36.30244772774832, 73.19026729038784, 39.819306237357004, 56.30010672977993, 59.990830012730186, 60.08061463492257, 34.46027530942644, 0.07609652847583805, 0.08752310568732874, 0.900549342589719, 0.7869448842746871, 12.247032931872777, 53.227279799325125, 51.48276778629848, 58.09594508579799, 57.214621680123464, 57.63181584221976, 58.794781003679546, 56.19188158852713, 55.060621057237896, 53.04862771715437, 53.89634963444301, 52.51669447762625, 51.18422106334141, 51.12697485515049, 51.77990402494158, 49.69491638456072, 51.292845726013184, 46.81841080529349, 51.24142210824149, 47.22576631818499, 52.044616494859966, 49.314148153577534, 58.255812713078086, 32.02430289132254, 31.901865209851945, 51.90395368848528, 45.57580886568342, 53.54555593218122, 47.69061470031738, 51.01642901556832, 41.812966755458284, 39.77262823922293, 37.97485480989729, 37.94751017434256, 37.23800877162388, 39.40896299907139, 36.02574266706194, 36.64726945332119, 38.49769980566842, 37.270880699157715, 36.139821665627615, 36.52708993639265, 36.704196044376914, 37.62799726213728, 39.894312041146414, 41.03834336144583, 36.182560035160606, 36.34418903078352, 38.510123184749055, 41.72096218381609, 37.83122512272426, 38.915703432900564, 37.555885383060996, 35.668223108564106, 35.59360987799508, 35.60970190593174, 34.67892122268677, 35.25558001654488, 35.8783574785505, 35.22176660810198, 35.24594981329781, 35.90340573447091, 35.35342454910278, 38.060286385672434, 37.401892457689556, 34.582105023520334, 35.0525849206107, 36.8544716835022, 36.0030255317688, 36.58989470345633, 37.308011872427805, 36.00939008167812, 33.978713035583496, 36.344744886670796, 34.96443312508719, 36.428258759634836, 36.0764228275844, 36.761171272822786, 34.83084011077881, 37.33417878832136, 36.20165368488857, 36.96127939224243, 38.25793136869158, 35.557566097804475, 36.062387466430664, 36.52830934524536, 34.392849990299766, 36.87877648217337, 35.73593330383301, 37.615601675851, 37.98753874642508, 34.69865410668509, 35.776868615831646, 34.55338117054531, 34.18657881872994, 34.38588442121233, 34.54918098449707, 35.77478068215506, 36.567354747227256, 36.929373264312744, 37.13973345075335, 35.808451652526855, 37.08268526622227, 38.54969664982387, 37.52326706477574, 41.063881465366904, 45.499938011169434, 45.31968436922346, 48.371117796216694, 43.69496277400425, 42.89816420418875, 42.655342033931184, 41.40028544834682, 39.3243339402335, 39.40812226704189, 40.1137569972447, 38.828777994428364, 40.461990288325715, 40.41915116991316, 39.04490171160017, 39.46277679715838, 40.42140586035592, 38.079442569187705, 41.50211477279663, 45.3814503805978, 52.88645676204136, 54.35650798252651, 57.37310314178467, 58.094267095838276, 63.0353638785226, 60.569663592747276, 66.16686834607805, 37.78287608282906, 0.12537809940321104, 0.7228962268148149, 0.43628984742930954, 0.07805771859628813, 1.1125464269093104, 53.77590608596802, 61.27685819353376, 63.65517793382917, 52.31580121176583, 44.43394538334438, 24.35010266304016, 12.04066709109715, 28.4714092867715, 46.73079054696219, 60.99071747916085, 6.910836824348994, 0.3081274474305766, 0.11105277309460299, 0.06959638012839214, 0.045694861960198195, 0.07142471987754107, 0.046513490711471865, 0.034903335850685835, 0.08345135274742331, 0.02387431400295879, 0.013381183845922351, 0.07929774812821831, 0.35067495863352505, 49.56549228940691, 67.20360210963658, 49.524772371564595, 39.98141813278198, 37.11293772288731, 49.53528152193342, 40.817665100097656, 64.10633141653878, 63.21685082571847, 66.18892192840576, 36.3266726221357, 0.14625481702387333, 0.08235113535608564, 0.27524553186127115, 0.9420322052070073, 14.909340313502721, 55.91474226542881, 53.177749565669465, 58.433738708496094, 59.63837569100516, 57.58915042877197, 60.09044633592878, 58.415027209690635, 56.96824203218733, 54.276162488119944, 55.85482447487967, 54.37433706011091, 53.50544398171561, 53.37313985824585, 53.31493132455008, 50.50251592908587, 53.41879647118704, 49.22430794579642, 51.846519878932405, 50.325343813214985, 55.10901526042393, 51.24581684385027, 61.425605228969026, 32.47096783774239, 34.32304491315569, 51.37187106268746, 48.350287096840994, 55.45378834860665, 50.22524459021432, 51.927855491638184, 43.38052552086966, 40.90802642277309, 39.808519159044536, 40.09924568448748, 39.61690173830305, 39.438645703451975, 37.958199977874756, 38.01460892813546, 39.64508015768868, 39.232607296534944, 36.783707754952566, 38.20129312787737, 37.812437193734304, 38.22781440189907, 41.56820951189314, 42.36000885282244, 36.80072736740112, 36.49244621821812, 38.82294845581055, 42.54417085647583, 38.864630699157715, 38.95932422365461, 37.74659606388637, 36.28468813214983, 38.058115073612754, 37.08257409504482, 34.809460503714426, 36.4558743749346, 36.22462442943028, 36.56055246080671, 36.89076907294137, 36.78546564919608, 37.170531341007774, 40.61100482940674, 39.11948020117623, 37.108331067221506, 36.61047526768276, 39.8562776020595, 37.937539509364534, 38.963708536965505, 38.387925216129844, 36.99843488420759, 35.55402251652309, 38.5778785433088, 37.490457671029226, 38.55272259031023, 37.18464660644531, 38.14473826544625, 37.45027623857771, 39.53904022489275, 37.33666624341692, 38.76421185902187, 37.48030982698713, 35.09788717542376, 36.52125692367554, 35.79498951775687, 34.06483595711844, 36.78352015359061, 36.84445238113403, 38.517241614205496, 39.590734822409495, 37.477481910160606, 36.67287356512887, 36.72569029671805, 36.069693497249055, 36.152161666325156, 36.16887903213501, 37.54486901419503, 38.1766791343689, 38.06459426879883, 39.9689495904105, 38.149664538247244, 38.54119552884783, 39.06926209586007, 37.954041481018066, 43.17508813313076, 49.307373659951345, 47.63169745036534, 50.589997223445344, 46.596877915518625, 44.828526633126394, 43.560212884630474, 43.09880038670131, 41.703351974487305, 41.65979719161987, 41.33103622709002, 41.77005468096052, 41.277566364833284, 41.96862724849156, 39.727628231048584, 40.54050145830427, 41.48836428778512, 39.46051515851702, 43.04147774832589, 45.34550734928676, 54.17000791004726, 56.47868585586548, 59.9055061340332, 60.297231674194336, 63.768440519060405, 62.15741729736328, 67.79631124223981, 41.52676003319876, 0.12739520759454795, 1.7862463678632463, 1.9150470793247223, 0.016520797607621977, 1.1915341998849596, 57.05832542691912, 66.93360206059047, 69.73906230926514, 58.32169205801827, 47.128675665174214, 29.735694817134313, 16.705920389720372, 33.915196078164236, 54.34562362943377, 69.10096059526715, 9.248939956937518, 0.393304138311318, 0.1506561887051378, 0.04247295377509935, 0.03456299286335707, 0.1215195150247642, 0.2705356031656265, 0.13872790948620864, 0.1834429736648287, 0.1611716765910387, 0.12291941419243813, 0.17393500171601772, 0.597802922129631, 61.35332311902727, 76.60466766357422, 56.87566076006208, 47.3445839881897, 46.59012426648821, 86.57938344138009, 52.73539250237601, 67.01207501547677, 70.1167733328683, 69.97885159083775, 42.62548215048653, 0.26512740765299114, 0.36537010009799686, 1.7161162453038352, 1.2002731880971362, 16.877830982208252, 57.823263032095774, 55.941756861550466, 59.90115656171526, 61.94989545004708, 60.07616778782436, 63.2408846446446, 61.02939115251814, 58.52256447928292, 56.9882424218314, 59.8607736315046, 55.47609554018293, 55.38935770307268, 56.453839097704204, 55.20517485482352, 54.12291301999773, 56.975391728537424, 50.105019909994944, 54.970683574676514, 52.550990785871235, 57.60093109948294, 54.179127420697895, 62.673473903111045, 34.290770530700684, 34.300077642713276, 52.84683118547712, 50.33796174185616, 58.196044308798655, 52.910924843379426, 54.30212443215506, 44.108957290649414, 44.12247501100813, 41.99769851139614, 41.28029005868094, 42.43082141876221, 42.59667144502912, 39.257127489362446, 38.820322036743164, 42.4230637550354, 41.06962762560163, 38.88274812698364, 39.323746817452566, 40.66353668485369, 41.439886706215994, 45.35499511446272, 43.105866704668315, 36.609304496220176, 36.972042151859824, 38.795780999319895, 44.13359907695225, 38.49109206880842, 39.753996644701274, 39.37503147125244, 37.048910072871614, 40.083778994424, 38.118494919368196, 37.299170289720806, 38.2529182434082, 39.15358543395996, 38.68476963043213, 39.681262901851106, 40.64934498923165, 39.455547196524485, 44.13030563082014, 42.01201180049351, 38.81397138323103, 39.52265984671456, 41.74965476989746, 41.15748412268502, 40.38974986757551, 41.651893615722656, 40.29048442840576, 38.417545386723106, 41.836163316454204, 39.14748838969639, 41.652362619127544, 40.34173434121268, 40.539921283721924, 39.3733743258885, 41.03459480830601, 38.91446317945208, 39.806288787296836, 38.758649826049805, 35.53973702022007, 37.04271922792707, 35.846781390053884, 34.93961763381958, 37.42997012819563, 39.101279394967214, 39.1184275490897, 41.553131920950754, 38.861097540174214, 38.8089964730399, 38.89228800364903, 38.91307701383318, 37.44987324305943, 38.45686524254935, 38.230934143066406, 39.966705322265625, 40.276793003082275, 40.800846985408235, 39.56847626822335, 41.58487476621355, 41.40627479553223, 41.16298362186977, 44.41900328227452, 50.68886661529541, 50.74854816709246, 52.1382816859654, 47.85054833548409, 47.12467002868652, 46.257444517953054, 46.60282557351248, 43.63953004564558, 44.73086622783116, 43.442812647138325, 43.50114972250802, 44.28086267198835, 44.95736013139997, 42.168617248535156, 45.01611409868513, 45.47031436647688, 42.70272874832153, 46.089336327144075, 49.35301290239607, 57.96683365958077, 59.700930322919575, 62.30746364593506, 64.51915863582066, 68.06834016527448, 66.20209571293422, 70.24921989440918, 45.28571115221296, 0.25154989478843554, 4.141316567148481, 2.932839184999466, 0.26720201490180834, 1.4605446734598704, 61.818150656563894, 73.2171151297433, 75.42633656093052, 66.77165344783238, 59.80270058768136, 34.56981713431222, 20.451737676348003, 44.426451751164024, 61.34881373814174, 80.35964093889508, 14.124028853007726, 0.7703137195536068, 0.3165375632899148, 0.2870618663728237, 0.13968281181795256, 0.1564572967056717], [0.10624242121619837, 0.028450359257736375, 0.06684154152337994, 0.060299507209232876, 0.09113884916795151, 0.0049139048039380994, 0.13593182952276298, 40.196975571768625, 61.99790055411202, 43.603656496320454, 37.02151679992676, 12.290975076811653, 49.1808956010001, 49.92893866130284, 54.262339047023225, 62.46836308070591, 59.063467843191965, 36.53792912619454, 0.015591026516631246, 0.02533519989810884, 0.17808414836015019, 0.11212197465023824, 8.165159940719604, 44.736841678619385, 57.916004112788606, 59.52441828591483, 57.948479993002756, 55.285343170166016, 55.03699023383004, 54.1810416494097, 54.79889283861433, 57.45276076453072, 53.11429861613682, 53.32492283412388, 52.47025619234358, 52.574725832257954, 49.49931764602661, 52.09692600795201, 53.35410874230521, 50.8119261605399, 51.95943505423409, 48.366597993033274, 50.7748019354684, 51.36122989654541, 48.949162755693706, 45.98314700807844, 47.01220996039254, 54.04454428809029, 51.408064229147776, 51.43697220938546, 48.08975396837507, 42.7259635244097, 37.3050936290196, 40.026678698403494, 41.492616585322786, 44.88423728942871, 43.42942346845354, 39.257881368909565, 36.15588937486921, 37.281650406973704, 36.627140522003174, 38.37165600912911, 36.97061429704939, 35.95204312460763, 36.893357276916504, 36.86208690915789, 36.78878688812256, 40.253363677433555, 38.00463131495884, 38.69471945081438, 37.695867265973774, 39.2676887512207, 41.08268329075405, 41.42951651981899, 37.06449835641043, 39.2581592968532, 36.896212986537385, 34.62528460366385, 32.9277389390128, 36.79116664613996, 34.12675830296108, 34.83031552178519, 33.94271789278303, 36.20433221544538, 36.31743846620832, 36.24137653623308, 37.10905020577567, 35.582916600363596, 33.08770036697388, 36.70993873051235, 38.90409299305507, 35.306569371904644, 35.61862339292254, 35.37578732626778, 34.462387561798096, 36.259421007973806, 36.01404537473406, 35.429889474596294, 35.672301701136995, 37.09233283996582, 36.431163106645855, 36.07557167325701, 36.87077215739659, 40.33959082194737, 35.53959458214896, 35.2111428124564, 33.03552286965506, 37.0986452783857, 34.826146602630615, 35.39737885338919, 35.72669914790562, 37.0187201499939, 38.0219601222447, 36.14627654211861, 35.769861357552664, 36.48066554750715, 35.12869896207537, 35.92234304973057, 36.28186368942261, 36.8670722416469, 37.89028828484671, 37.03633730752127, 36.37800938742501, 37.84623670578003, 35.177617754255024, 38.45851196561541, 40.76977464130947, 47.37415552139282, 49.377637318202424, 51.35077633176531, 50.56783594403948, 50.959835938044954, 51.3047445161002, 48.371531214032856, 47.31529038293021, 48.09738309042794, 48.63441283362252, 47.781795910426546, 46.750356674194336, 45.34118209566389, 44.199777194431846, 42.94738176890782, 43.384003094264436, 45.18116855621338, 42.616789954049246, 42.206321648189, 42.687053612300325, 41.33779682431902, 44.5175495828901, 52.48937068666731, 56.11917911257063, 58.28025994982038, 59.42296763828823, 63.8373874936785, 50.426957743508474, 0.1598691064864397, 0.9387330050979341, 1.7838808319398334, 0.040395730773785284, 0.34132311759250505, 45.234211104256765, 65.69608620234898, 62.28563935416085, 55.84955426624843, 51.09564195360456, 33.87063728060041, 20.02801741872515, 37.90864542552403, 42.65810741697039, 63.583208492824006, 12.632549388068062, 0.3327519989439419, 0.135925790561097, 0.0523298012890986, 0.06905962500189032, 0.011728217409524535, 0.02670645640630807, 0.013148546418441194, 0.056748356869710345, 0.05406976863741875, 0.025057258383770074, 0.015783796619091715, 0.23694475420883723, 48.88320003237043, 69.9158661706107, 48.81723383494786, 43.936767033168245, 15.011044570377894, 48.08497708184378, 51.19343090057373, 58.158656052180696, 67.40029866354806, 65.5711784362793, 39.13565213339669, 0.11163642177624361, 0.06730494022901569, 0.919729464820453, 0.6381156103951591, 8.800825442586627, 47.212304183415, 60.00025871821812, 59.57105459485735, 59.81190000261579, 56.678175585610525, 57.59056438718523, 55.631610121045796, 57.17184509549822, 59.66623796735491, 56.15421192986624, 55.529409067971365, 54.26889814649309, 52.9522179876055, 51.79199389048985, 54.17180054528372, 53.427975041525706, 52.05370126451765, 54.218607085091726, 50.475056648254395, 55.11862809317452, 53.51332671301705, 50.04877076830183, 45.49836424418858, 48.054022857121055, 53.365941524505615, 52.96449545451573, 53.6924477985927, 50.275744097573416, 46.05105522700718, 39.446156706128804, 42.139400073460166, 44.75891957964216, 46.6122716494969, 45.148734365190776, 43.048669133867534, 38.99907486779349, 38.54750796726772, 37.40774631500244, 39.123850618089946, 37.559984820229666, 38.77439096995762, 39.160842827388215, 39.60612508228847, 38.935967854091096, 42.157236099243164, 38.366361481802805, 37.91569437299456, 37.082775592803955, 40.38362850461687, 39.620507853371755, 40.926567690713064, 38.51356601715088, 39.79010990687779, 38.67539998463222, 37.41543102264404, 34.288060733250205, 38.69237790788923, 35.6752963747297, 36.646477358681814, 36.338661738804404, 37.784439427512034, 38.62800979614258, 38.60298238481794, 38.52878257206508, 36.7338752746582, 36.5111403465271, 39.01222780772618, 40.486680712018696, 37.13772194726126, 37.43685231889997, 37.14952693666731, 37.36008514676775, 39.30623735700335, 37.90200294767107, 37.894929681505474, 37.684975964682444, 37.76156595775059, 38.00574997493199, 36.84671401977539, 38.97319630214146, 39.517750944410054, 36.87740421295166, 35.2855406488691, 33.85120664324079, 36.20432874134609, 34.305469444819856, 34.78828934260777, 35.81337792532784, 38.20438855034964, 40.39237976074219, 37.12428413118635, 37.458829471043174, 38.42538642883301, 35.86260938644409, 37.84025083269392, 37.85837868281773, 38.94837038857596, 41.21150984082903, 38.3921914100647, 38.137849126543315, 39.386961528233115, 36.9683700289045, 40.9027145249503, 41.337286131722585, 49.548413617270334, 51.26534823008946, 54.656496456691194, 52.33550977706909, 52.632256916591096, 53.85951723371233, 50.08209432874407, 50.17402594430106, 51.139856815338135, 50.199706486293245, 50.61350992747715, 48.60817643574306, 46.66434144973755, 47.624030113220215, 46.23484550203596, 47.01933881214687, 48.54901599884033, 44.155416420527864, 45.25606666292463, 44.81781598499843, 42.98127508163452, 47.70706803458077, 54.74166052682059, 58.143349170684814, 62.35927636282784, 61.812946455819265, 66.90968636104039, 55.46680579866682, 0.18062967248260975, 1.3278621988637107, 1.7965884357690811, 0.008608863007144203, 0.43211889266967773, 48.19130189078194, 72.1470925467355, 66.0562391281128, 63.90499346596854, 52.605905873434885, 34.15750060762678, 22.662656205041067, 42.245585918426514, 48.68826484680176, 71.41620458875383, 17.074485846928187, 0.608591194663729, 0.12140040498759065, 0.04824337502941489, 0.05859092210552522, 0.08943871182522603, 0.12573430314660072, 0.13711884511368616, 0.17058531860155718, 0.10674366181982414, 0.2217859019126211, 0.09008247870951891, 0.616697082562106, 59.03244413648333, 77.73678629738944, 57.45627655301775, 51.194556508745464, 20.683731079101562, 59.26198482513428, 62.97738116128104, 64.2437389918736, 73.22286823817662, 70.3176040649414, 43.701754638126914, 0.16862079687416553, 0.16988091782799788, 1.5826018324920108, 1.3450773379632404, 10.415477360997881, 51.00497491019112, 63.30981077466692, 63.103588240487234, 61.52394308362688, 60.285447529384065, 59.646081243242534, 57.699230739048545, 59.81082303183419, 60.74152033669608, 58.56514304024832, 58.56526115962437, 56.28332683018276, 54.87819957733154, 53.62536294119698, 56.384443964277, 56.5904997416905, 53.587523051670615, 57.94373089926583, 51.138321263449534, 57.11495671953474, 54.826956612723215, 51.90874447141375, 44.63392843518938, 47.582535471235005, 56.773702893938335, 53.90112999507359, 55.807632310049875, 52.08003493717739, 48.34196662902832, 41.61932046072823, 45.630213260650635, 46.5848262650626, 49.54847962515694, 48.13718237195696, 46.09480108533587, 39.52160372052874, 39.74572481427874, 38.80189888817923, 41.71220397949219, 40.57189341953823, 40.81522628239223, 40.00516707556588, 41.41393518447876, 41.429665906088694, 43.35631104878017, 40.137168952396934, 39.0601738521031, 38.51007802145821, 41.541556222098215, 41.45615938731602, 42.52742222377232, 39.076738357543945, 41.660373892102925, 40.63618857519967, 38.79192474910191, 36.152571610042024, 42.30696630477905, 38.2616034916469, 37.90977450779506, 38.45852933611189, 39.28901972089495, 40.97446162360055, 40.336387702396934, 40.88582345417568, 38.42918709346226, 38.35200997761318, 42.34447268077305, 42.728179999760215, 40.33685670580183, 39.71043838773455, 39.993289130074636, 39.59705768312727, 40.773415497371126, 39.78520447867257, 39.87686858858381, 40.43629584993635, 39.88399396623884, 39.47085755211966, 38.78203746250698, 40.43833862032209, 40.758073874882285, 36.3847838810512, 35.33994851793562, 33.435912813459126, 37.620774609701975, 35.087902614048545, 35.59815052577427, 36.5107547215053, 39.27648169653756, 41.8863571030753, 39.697959423065186, 40.11814131055559, 40.30298771177019, 37.793013504573274, 39.335305145808626, 40.430726868765696, 40.09195007596697, 42.49997683933803, 41.2016156060355, 39.47131960732596, 41.74835893086025, 39.33567687443325, 42.24335902077811, 44.47717012677874, 52.6812173979623, 53.97194603511265, 58.67381286621094, 57.83767359597342, 57.09443174089704, 57.066030979156494, 51.22295379638672, 51.384061677115305, 55.06806605202811, 54.441303798130576, 53.245331219264436, 50.88078280857631, 49.56120525087629, 49.19032430648804, 49.189771924700054, 49.39431299482073, 50.544087001255576, 46.90419673919678, 48.069614614759175, 47.634869303022114, 44.65390798023769, 52.47333077022007, 56.82458455221993, 61.53713076455252, 64.64130101885114, 65.79131821223667, 67.87108080727714, 59.711116382053916, 0.13976579665073327, 5.90070858172008, 6.552889517375401, 0.19470540646995815, 0.8410263508558273, 52.424384185246055, 78.50522926875523, 71.71771471840995, 71.70142814091274, 65.47511264256069, 50.67115913118635, 31.250586237226212, 55.562690939222065, 56.2408663885934, 83.58128438677106, 23.873923506055558, 0.7516997126596314, 0.28241078023399624, 0.1411132857735668, 0.18122463912836143, 0.22784060559102468], [0.06368226212050233, 0.0664054470668946, 0.069264610431024, 0.011952422343061438, 0.034539210210953436, 0.014324549386011702, 0.09745790330427033, 40.023051738739014, 61.39166327885219, 41.23352868216378, 36.05488688605172, 22.668140070778982, 23.06145327431815, 40.952988215855186, 58.72713334219796, 59.293592180524556, 58.7347902570452, 40.45194666726248, 0.15585061854549817, 0.10953885968774557, 0.04910754705114024, 0.17657976837030478, 6.163986248629434, 37.23778295516968, 58.57325158800398, 58.04968745367867, 58.74102973937988, 56.99834162848336, 58.50868892669678, 56.84365388325283, 54.643576281411306, 55.2337840625218, 53.84009007045201, 56.66415759495327, 56.239716461726594, 58.489213126046316, 55.25565699168614, 53.12696170806885, 52.63720055988857, 52.32728658403669, 51.67708805629185, 52.41086646488735, 50.374033314841135, 47.79304156984602, 49.731665406908306, 54.06094203676496, 51.86887223379952, 49.60563898086548, 49.18370962142944, 47.997846671513145, 42.336312021527974, 37.063970293317524, 38.28645372390747, 44.93742227554321, 44.366693769182476, 45.66040665762765, 47.505580697740825, 46.51253720692226, 36.59841319492885, 38.14826447623116, 39.02890001024519, 36.71576132093157, 37.45274632317679, 35.537048067365376, 36.678247996738975, 35.8332428250994, 34.914847305842805, 40.48065662384033, 39.0231990133013, 35.985186031886506, 36.20612137658255, 40.056410040174214, 41.359572478703086, 39.69905029024397, 40.06802742821829, 36.46685252870832, 37.43996858596802, 35.56813430786133, 34.899592535836355, 33.49535117830549, 33.944632121494834, 34.4596152305603, 36.39415005275181, 36.61136811120169, 35.338941029139924, 34.905293532780235, 35.59511763708932, 36.004231044224326, 32.78277172361101, 37.954083170209614, 37.883531161717, 36.25086777550833, 35.069819927215576, 34.813987255096436, 34.06081642423357, 34.51230689457485, 36.013260228293284, 36.14538369859968, 36.07869141442435, 37.207124028887065, 38.12023196901594, 37.3929431779044, 39.13783734185355, 34.70655073438372, 34.69831711905343, 33.63880021231515, 33.77494321550642, 36.13666370936802, 34.06593724659511, 34.27876056943621, 34.97131184169224, 38.50845561708723, 37.69840335845947, 34.26271023069109, 35.84078509466988, 34.97788831165859, 35.765393665858674, 34.87199081693377, 35.99493088041033, 36.92430802753994, 37.26400893075125, 36.25710378374372, 37.83153779166085, 37.76010683604649, 38.84524869918823, 37.999350684029714, 41.80430582591465, 44.98011200768607, 51.435349805014475, 46.41807644707816, 46.77181965964181, 49.65605163574219, 50.22566148212978, 49.630100114004954, 51.05368873051235, 51.87144306727818, 51.46340315682547, 52.45485551016671, 53.055433477674214, 52.64173773356846, 53.48528725760323, 52.66795328685215, 52.78084414345877, 51.0919246673584, 53.906289032527376, 52.40633623940604, 53.13119316101074, 51.592076846531455, 47.53917523792812, 41.50526230675833, 48.50142778669085, 54.89367321559361, 61.47042110988072, 60.591633796691895, 55.18770708356585, 0.9148826620408467, 1.3500933945178986, 2.45408268060003, 0.05527385277673602, 0.07190282243703093, 37.78637450081961, 65.72339262281145, 63.068569319588796, 60.70346505301339, 54.02362673623221, 42.14827292306082, 17.019407476697648, 37.299753938402446, 42.40266036987305, 64.87958254132951, 24.732583624976023, 0.30445271890078274, 0.07717498524912766, 0.04885122026982052, 0.016091027097510438, 0.028446277869599204, 0.052826268398868184, 0.03655554147969399, 0.08168439327606133, 0.006077010941226035, 0.004621686488722584, 0.011939698963293006, 0.2214929104915687, 49.00794798987252, 68.64212240491594, 47.61010939734322, 41.75269113268171, 22.029883759362356, 33.742217200142996, 47.734374455043245, 61.5369153703962, 65.64528792245048, 61.64754458836147, 42.41790819168091, 0.15687004955751555, 0.037439245131931136, 1.290299260190555, 0.27955588485513416, 6.582865348884037, 40.66202892575945, 60.51375143868582, 60.62848704201834, 59.91084929874965, 58.04069995880127, 57.76917130606515, 57.731473854609895, 54.89288112095424, 55.157708236149375, 56.61529091426304, 57.33730254854475, 57.65757976259504, 58.03739609037127, 56.17901699883597, 56.29391935893467, 54.73615060533796, 56.19418491636004, 54.190675326756065, 54.35629953656878, 53.146055357796804, 48.61194930757795, 51.46656806128365, 56.56756373814174, 53.13756813321795, 51.34089946746826, 50.81926345825195, 49.70287554604666, 43.588273184640066, 39.29556144986834, 40.05440895898001, 45.88115440096174, 47.46369695663452, 46.88772256033761, 49.87826892307827, 47.4078369140625, 39.562327112470356, 41.06370428630284, 39.27307707922799, 38.20452751432146, 38.51461172103882, 37.637307848249165, 37.80453709193638, 37.80445371355329, 36.37337841306414, 42.169815812792095, 39.969345637730186, 35.490439551217214, 36.54029498781477, 40.56332976477486, 41.608012267521445, 39.03139441353934, 39.55563947132656, 37.68836668559483, 36.86177771432059, 36.918457644326345, 36.881712096078054, 35.42380632672991, 35.807336466653005, 37.326841490609304, 37.90028326851981, 37.25678627831595, 37.19775785718645, 37.242994104112896, 37.60590546471732, 36.91320480619158, 36.05295876094273, 39.00209733418056, 39.467602321079795, 38.39735392161778, 36.504876545497346, 38.3744352885655, 36.273619651794434, 37.904483454568044, 37.44822999409267, 37.46399198259626, 36.469030788966585, 37.72761011123657, 38.92648703711373, 39.91226271220616, 39.577904973711284, 36.31189032963344, 34.442175252096995, 34.66413198198591, 33.85989189147949, 35.183527197156636, 34.10899870736258, 34.320706844329834, 35.32201869147164, 39.25786747251238, 38.588749000004356, 36.45511702128819, 36.73416362489973, 36.966042382376536, 37.87242099217006, 37.05671984808785, 39.56553718021938, 38.49374280657087, 38.90090376990182, 38.818546772003174, 39.78816441127232, 39.64580624444144, 40.55941098076956, 39.875704765319824, 43.78576183319092, 47.40533208847046, 52.2303592136928, 48.42864888054984, 49.39091879980904, 50.29659564154488, 51.66617938450405, 51.36562115805489, 53.329341888427734, 54.709664072309224, 54.978128569466726, 54.143323353358674, 54.87668834413801, 53.41172667912075, 56.44014767238072, 53.58659199305943, 55.930754389081685, 54.16947637285505, 55.62162555967058, 54.92487757546561, 57.095453126089915, 53.8008987562997, 50.448278290884836, 43.55921581813267, 51.306703908102854, 56.44199241910662, 64.58404786246163, 63.227585792541504, 62.284110750470845, 0.9144977969782693, 0.8306323343089649, 2.6531255543231964, 0.00873283898857023, 0.06696489240442004, 40.15522732053484, 72.4295437676566, 67.86259705679757, 67.66083526611328, 55.59733465739659, 40.23930399758475, 20.77382489613124, 47.23352745601109, 48.75408165795462, 72.84042549133301, 29.293150152478898, 0.2301926522382668, 0.06643194385937282, 0.05944962852767535, 0.005342741904314607, 0.017055671495784606, 0.14164330304733344, 0.1254470928439072, 0.12231280388576643, 0.060461100323923996, 0.16284943584884914, 0.10800331458449364, 0.5538927497608321, 60.43290219988142, 75.02079105377197, 56.473228045872276, 49.33788319996425, 34.30841548102242, 35.43940503256661, 53.71945892061506, 68.60045405796596, 67.97736740112305, 67.69596535818917, 48.42316327776228, 0.3496850574655192, 0.1851949646536793, 2.186269359929221, 0.3436007968017033, 8.138188770839147, 42.009673731667654, 62.55874524797712, 63.59090709686279, 63.4591623033796, 58.82724298749651, 60.103147642953054, 58.31165191105434, 56.09413433074951, 58.21290063858032, 58.29430225917271, 59.30289581843785, 58.95534692491804, 62.01909255981445, 59.7764641898019, 57.17483976909092, 56.89767265319824, 58.074687072208945, 57.211356026785715, 55.38577243259975, 53.73897641045706, 48.32537085669381, 52.63896887642996, 59.506589208330425, 56.366965770721436, 53.53016914640154, 53.13194704055786, 52.71835551943098, 46.60000113078526, 41.84739507947649, 42.15717356545584, 48.032004015786306, 49.78547920499529, 50.627496651240754, 51.183727741241455, 48.27418000357491, 41.840922832489014, 42.146105085100444, 42.297593184879844, 40.12143128258841, 40.72700500488281, 39.52792658124651, 39.75931201662336, 39.28462845938546, 38.38961362838745, 43.86830643245152, 39.365637506757466, 35.977939060756135, 37.1981851713998, 41.42582355226789, 42.32267270769392, 40.82446043831961, 40.604226861681255, 37.78941781180245, 38.93382086072649, 38.05726044518607, 38.171488830021445, 37.37177549089704, 37.65463318143572, 39.80053220476423, 40.17298691613333, 39.9216844694955, 39.248859133039204, 38.99885252543858, 38.97926555361067, 39.331000736781526, 39.26697308676583, 40.76364285605294, 42.27118655613491, 40.821000235421316, 38.68483911241804, 41.18957437787737, 39.4051901272365, 39.88764871869768, 40.49239560535976, 41.07020780018398, 39.230842454092844, 40.817088399614605, 41.021949086870464, 40.5546931539263, 39.68323619025094, 36.38725049155099, 34.89583356039864, 34.51706641060965, 34.633281980242046, 35.12308134351458, 34.03717865262713, 35.072811126708984, 36.2955446924482, 40.33936153139387, 41.32947635650635, 38.606407846723286, 39.2032789502825, 39.45758996691023, 40.926998479025706, 40.024062701633994, 41.16730540139334, 39.518428393772666, 39.89887353352138, 40.04726273672921, 41.87963124683925, 42.332024982997346, 42.638690676007954, 41.5504012789045, 45.83769689287458, 48.56572641645159, 54.3482118334089, 50.20531715665545, 51.91805158342634, 51.85968324116298, 53.62264966964722, 53.89759683609009, 56.51334694453648, 55.968903473445344, 56.712395463671, 56.54460341589791, 57.83892774581909, 54.54880632672991, 58.67413248334612, 56.67578193119594, 57.4055130141122, 56.47868932996477, 59.81952217647007, 57.52927085331508, 59.629857199532644, 54.95055116925921, 54.61810418537685, 45.45695298058646, 53.868199007851736, 58.926692553928916, 68.71371664319719, 65.79024818965367, 69.02789333888462, 0.9956437455756324, 4.966862874371665, 6.79658933196749, 0.12035403613533292, 0.3131550390805517, 44.68413611820766, 77.81921972547258, 72.37879412514823, 76.05591283525739, 68.13836411067417, 57.71763999121529, 27.921415942055837, 52.838479450770784, 56.98705775397164, 82.41542530059814, 39.20073938369751, 0.45827891464744297, 0.15092620493045875, 0.21301542967557907, 0.10118500795215368, 0.1622720296893801], [0.0815235058377896, 0.06295171739267451, 0.0655629372756396, 0.05249578452536038, 0.06808392557182483, 0.024771264355097498, 0.24388345330953598, 35.93877553939819, 59.193037850516184, 36.4859288079398, 27.062436206000193, 11.397646052496773, 19.62885730607169, 41.936193057468955, 58.620103291102815, 58.026091371263774, 57.807553155081614, 41.09592308316912, 0.16916856462402002, 0.019347723773015395, 0.757480939584119, 0.1257926435875041, 2.7929187502179826, 29.961563382829937, 58.113687310900005, 58.11074474879673, 56.37561280386788, 55.80187225341797, 54.24266522271292, 55.83416053227016, 53.67902735301426, 53.18235969543457, 52.41841568265642, 49.90297671726772, 46.52789619990757, 45.9863292830331, 49.97077029091971, 53.608822754451204, 52.023994241442, 51.72240073340279, 51.122336932591026, 50.457752159663606, 50.85383422034127, 54.85363074711391, 54.89049094063895, 49.81653765269688, 48.52277960096087, 47.055702209472656, 43.66570043563843, 45.85669674192156, 39.02394247055054, 39.962710108075825, 44.60141086578369, 48.45961700166975, 57.35142823628017, 54.929428645542686, 46.54234497887747, 45.939178807394846, 45.19860853467669, 37.4038587978908, 38.2987311908177, 37.54779767990112, 37.19097988946097, 38.69037682669503, 38.913104806627544, 37.85199328831264, 35.02727958134243, 38.00315482275826, 42.997888224465505, 36.66712045669556, 36.74274812425886, 40.3627040045602, 40.59894275665283, 39.75471578325544, 39.10471875326974, 37.172907624925884, 35.222506591251914, 35.9018041746957, 35.49897541318621, 34.0521867615836, 34.46818583352225, 32.18208258492606, 35.55710751669747, 33.95319925035749, 36.281759466443745, 35.22019631522042, 34.69983182634626, 36.67109830038888, 32.814236640930176, 36.40162631443569, 36.846342291150776, 35.90558399472918, 36.32446656908308, 34.668019499097554, 34.402667794908794, 34.18231609889439, 34.17590985979353, 35.10765981674194, 37.24512372698103, 39.42596524102347, 37.235069683619905, 36.059625557490754, 34.70939949580601, 35.59756687709263, 36.37517104830061, 33.39919853210449, 36.326641355242046, 33.831765583583284, 34.28189420700073, 36.03370182854788, 34.69193867274693, 37.888328892844065, 36.88416828427996, 32.93137632097517, 34.18492514746529, 33.94698061261858, 34.07785340717861, 34.6317776952471, 36.86234746660505, 36.17115109307425, 36.760021345955984, 38.45424577168056, 37.756931509290425, 37.35956750597273, 38.47592415128435, 42.546095507485525, 43.40236023494175, 44.705626896449495, 46.919072832380024, 49.705140658787315, 50.717392444610596, 50.12550319944109, 50.620826380593435, 52.17037541525704, 48.92363854816982, 50.057428223746165, 52.19934940338135, 49.39219726834978, 52.842252322605674, 51.53142949513027, 54.90309844698225, 53.459540707724436, 56.12900039127895, 56.97634015764509, 57.330899783543174, 55.78290714536394, 56.38212326594761, 55.684628350394114, 57.61026947838919, 51.33733851569039, 48.233039719717844, 53.31249598094395, 59.477830614362446, 58.976017815726145, 60.78895568847656, 1.5224168619939258, 0.36045614949294497, 0.8119540565780231, 0.07580076184655939, 0.06542449577578477, 30.938653809683665, 68.59779289790562, 59.73747784750802, 62.32778712681362, 58.035294260297505, 45.94773203986031, 20.737848860876902, 35.82708324704851, 41.28707844870431, 65.67936883653913, 27.583069937569753, 0.27742775476404596, 0.029305673004793267, 0.013202265187698816, 0.045904522495610375, 0.022051326198769466, 0.08705181561942611, 0.017908573050850203, 0.07318881593112435, 0.049365271614598374, 0.06259509974292346, 0.040990914550742934, 0.20645333108093056, 43.69880860192435, 66.9153699874878, 42.36662006378174, 30.708300181797572, 16.948589699608938, 27.68957887377058, 45.27818972723824, 63.959272793361116, 60.97809955051967, 64.22024018423897, 44.883709226335796, 0.26148340318884167, 0.06513954499470336, 0.8301561112914766, 0.6940235303980964, 3.195944449731282, 31.281377179282053, 59.98930140904018, 60.228090150015696, 57.5989647592817, 56.68186855316162, 56.662437915802, 57.32620627539498, 54.23193372998919, 52.675054345812114, 52.12239810398647, 49.3831159727914, 47.93741471426827, 47.06914002554757, 49.85780995232718, 54.87582676751273, 52.04173994064331, 52.832813194819856, 51.35766199656895, 51.195998259953086, 49.81546068191528, 55.75545481273106, 56.07536724635533, 50.78408472878592, 49.66309363501412, 48.93082993371146, 47.63673489434378, 47.121737888881135, 42.53841774804251, 41.851960045950754, 47.12989159992763, 51.040907519204275, 58.67820412772042, 54.70721483230591, 47.059891973223, 49.55485807146345, 47.012779712677, 39.01389537538801, 39.426871980939595, 38.38599361692156, 37.51688861846924, 39.813921383449006, 40.83943728038243, 39.13316467830113, 37.0327033996582, 42.19715697424752, 42.431231362479075, 36.29971361160278, 36.62348229544503, 38.33903421674456, 40.34672314780099, 40.21657643999372, 39.77105099814278, 38.72668463843209, 36.046816553388325, 35.842400550842285, 37.0523806980678, 36.972934995378765, 36.28038372312273, 34.12621634347098, 37.496391432625906, 36.73602226802281, 37.501939569200786, 37.62143816266741, 37.278051240103586, 38.00564227785383, 35.42941352299282, 38.94738721847534, 38.47024399893624, 37.73703186852591, 37.059047494615825, 37.57358244487217, 36.91655036381313, 35.73482159205845, 37.60459920338222, 36.66242347444807, 39.312032154628206, 41.18934161322457, 37.712581157684326, 36.11261599404471, 34.584085260118755, 34.147693225315635, 36.52841009412493, 33.89621359961373, 34.9328396660941, 34.258735861097065, 34.04201807294573, 35.899261134011404, 35.67137064252581, 39.44245679037911, 38.806095600128174, 35.27933938162667, 35.945643833705354, 35.42834002631051, 36.20540223802839, 37.92031839915684, 38.279255390167236, 37.50489602770124, 37.61125210353306, 38.71934734072004, 39.5780474117824, 38.73103421075003, 39.72723913192749, 44.630930287497385, 46.16469996316092, 46.57576234000069, 49.37398256574358, 52.32218313217163, 53.63587556566511, 51.731162411826, 53.487941469464985, 53.46581493105207, 51.90449217387608, 51.8407598223005, 53.3458160672869, 52.02153805324009, 55.14814056668963, 52.24264710290091, 56.658390590122764, 56.96548012324742, 59.44333280835833, 58.53862176622663, 60.18127318790981, 57.76300130571638, 61.086387225559776, 58.0499758039202, 59.658018248421804, 53.7447885785784, 51.998251165662495, 53.70562505722046, 63.41975212097168, 60.64737919398716, 66.79825115203857, 1.9383713134697504, 0.7208336432065282, 3.0423836154597144, 0.05248425282271845, 0.026382754490311657, 33.732611315590994, 74.6386331830706, 63.71683624812535, 69.38383565630231, 63.46261555807931, 49.023619651794434, 27.99143293925694, 41.90554455348423, 48.68353312356131, 73.66187626974923, 35.89985520499093, 0.27082449623516625, 0.035923944120960574, 0.02056320899698351, 0.03602596864636455, 0.05856529383787087, 0.21015380322933197, 0.15847406562949928, 0.22648069927734987, 0.15530219940202578, 0.10048573690333537, 0.14182060424770626, 0.6032607321228299, 51.800884110586985, 75.57852295466832, 49.51242889676775, 41.9841182572501, 22.17623540333339, 30.272325038909912, 53.900751318250386, 69.97526632036481, 66.44966002873012, 68.41443688528878, 49.25715208053589, 0.5660872725503785, 0.22185619814055307, 2.6912459773676733, 1.039560160466603, 3.7490160635539462, 34.04627731868199, 61.651588439941406, 63.24930586133684, 60.426211084638325, 60.95073754446847, 59.96385015760149, 61.16788959503174, 54.97819110325405, 54.944040707179475, 55.45421566282, 50.234541279929026, 49.43005452837263, 46.98568173817226, 50.42164584568569, 56.657139914376394, 56.292988300323486, 55.02630737849644, 52.8944228717259, 51.80860355922154, 50.35783011572701, 56.73995549338204, 57.734802041734966, 52.747225284576416, 53.379000663757324, 50.202013288225444, 49.95423705237252, 50.601034436907085, 44.93273571559361, 45.05651092529297, 50.12947756903512, 51.666356563568115, 57.02957725524902, 53.84743084226336, 49.75602231706892, 52.99072143009731, 49.82691478729248, 41.10049499784197, 41.88310882023403, 40.19214309964861, 39.20360204151699, 42.829060895102366, 42.86020619528634, 41.415783405303955, 38.74069915499006, 41.75063793999808, 43.83822420665196, 36.7668514251709, 37.04394211087908, 41.179808684757774, 41.90201139450073, 40.125819069998606, 40.51132597242083, 39.08558341435024, 36.248640877859934, 38.76385055269514, 38.72002479008266, 38.202213764190674, 39.30482339859009, 35.57351916176932, 41.38430806568691, 38.75674254553658, 39.811819553375244, 40.25611516407558, 39.85773324966431, 40.45950978142874, 38.28634602682931, 41.126894678388325, 40.19626338141305, 39.97529329572405, 40.10860143389021, 38.469014167785645, 39.73425333840506, 38.939577443259104, 39.471024308885845, 39.42391552243914, 41.5638564654759, 42.64397478103638, 39.88682188306536, 36.52835103443691, 35.532021045684814, 35.583298751286094, 36.91361474990845, 34.62483297075544, 35.97317607062203, 33.16992882319859, 34.355666705540244, 37.02373327527727, 35.5154252733503, 40.96111066000802, 41.299751962934224, 37.08688197817121, 37.81617532457624, 38.95745168413435, 38.7588825907026, 40.071716921670095, 40.86898449489048, 39.42736530303955, 38.794981956481934, 41.72643389020647, 41.992848668779644, 40.349648339407786, 42.41352735246931, 46.869619028908865, 46.12671068736485, 50.363638809749055, 52.64531258174351, 54.07487317493984, 56.464567116328645, 54.34434168679373, 54.27048233577183, 55.69308778217861, 53.993336064474924, 53.755478382110596, 55.2915791784014, 55.58034283774239, 58.44466822487967, 54.986730439322336, 59.57343782697405, 58.888387135096956, 62.04097243717739, 61.45730985913958, 62.92400509970528, 60.51562050410679, 61.98402500152588, 60.34277016775948, 63.332496643066406, 56.22154344831194, 54.13276556559971, 57.21384695598057, 67.05629335130963, 61.63303674970354, 73.6454507282802, 2.043660406555448, 2.948322377034596, 5.693330909524645, 0.1602201262222869, 0.1292899487806218, 35.4453318459647, 82.10419464111328, 68.98606518336705, 77.21988201141357, 71.17685304369245, 59.873245647975374, 32.14214781352452, 51.069197109767366, 55.4318459374564, 83.00179072788784, 44.28253023965018, 0.4308778792619705, 0.1170432059360402, 0.07794533962649958, 0.2573352743472372, 0.11174919429634299], [0.012461479670102043, 0.052808480603354316, 0.030001242645084858, 0.04239517669858677, 0.04609348092760358, 0.05837564330015864, 0.008839343541434832, 34.83304616383144, 63.588996342250276, 44.932054792131694, 38.100290639059885, 25.008114440100535, 35.05749034881592, 41.68872949055263, 58.0177709034511, 58.63327707563128, 58.27692134039742, 44.54327528817313, 0.054125228697167974, 0.02301869321880596, 1.3667046917336327, 0.12007772310503892, 0.641388863325119, 18.832720552171978, 51.99925865445818, 58.13625505992344, 57.15509646279471, 56.06999281474522, 54.29323421205793, 47.93023027692522, 43.10184717178345, 45.40553283691406, 48.0556070463998, 43.523564611162456, 42.557716369628906, 45.57255710874285, 46.053254331861226, 45.599325043814524, 46.505936418260845, 48.93507528305054, 50.528213841574534, 52.70304863793509, 50.20461886269705, 52.06015961510794, 50.96761097226824, 50.58450467245919, 46.38930743081229, 42.35269587380545, 38.176651341574534, 38.16509301321847, 37.78188249043056, 43.06387179238455, 44.92317846843174, 48.76288155147007, 42.706998416355674, 48.51498719624111, 58.62755175999233, 53.68173715046474, 46.59362268447876, 44.589512075696675, 40.35402570452009, 36.81615236827305, 35.62536314555577, 37.238012245723176, 36.222022329057964, 35.15958023071289, 36.53600794928414, 35.59991536821638, 46.3669307572501, 37.12520129340035, 34.059663023267476, 37.54847860336304, 39.12924936839512, 42.12003891808646, 39.54122543334961, 37.80455098833357, 33.95631551742554, 33.25133391789028, 33.263302189963206, 36.38289744513375, 32.11361851011004, 34.34290633882795, 33.184023244040354, 33.85928739820208, 35.45697007860456, 36.28756816046578, 36.64995493207659, 36.094700063977925, 33.02792501449585, 37.220176219940186, 34.74473455974034, 36.658852100372314, 35.113336494990754, 34.1036034311567, 34.80980791364397, 35.876418931143625, 35.37167051860264, 36.93890271868025, 40.48686483928135, 38.72090026310512, 35.30380746296474, 32.830478055136545, 32.963897364480154, 33.79356786182949, 33.7333721433367, 33.278744561331614, 34.29973718098232, 33.7067084312439, 33.76613637379238, 33.354584148951936, 35.23537465504238, 42.62795570918492, 34.07882615498134, 34.38165296827044, 35.01019396100725, 36.77198961802891, 34.275901385716026, 35.27101196561541, 37.48235607147217, 36.23965685708182, 35.493851116725374, 36.24064350128174, 38.137025765010286, 35.775103773389546, 41.79350137710571, 46.94995757511684, 48.056142057691304, 45.495772566114155, 43.38304076875959, 44.565589427948, 49.96998167037964, 48.73261867250715, 49.679741518838064, 50.50437804630825, 51.8151661327907, 52.81006826673235, 53.465995584215435, 51.0896178654262, 53.52047988346645, 53.58025871004377, 54.44706385476248, 51.24096005303519, 51.93874331883022, 53.049534457070486, 55.96527998788016, 55.37623255593436, 67.48271819523403, 64.62584822518485, 59.31565271105085, 54.19947869437081, 56.12967784064156, 51.913476194654194, 60.43702942984444, 60.28371742793492, 62.03885323660714, 1.520493513771466, 0.6038062199950218, 0.6752806561333793, 0.052542851106928926, 0.026105649270383374, 28.15764774594988, 69.30074909755162, 59.83605194091797, 61.40651852743966, 55.27739095687866, 48.325690473829, 10.316912821360997, 26.53377730505807, 37.60662807737078, 55.50737633023943, 27.81427471978324, 0.1850123165973595, 0.02243157383054495, 0.01637801687632288, 0.04075040102803281, 0.033833055424370935, 0.040500140349779806, 0.020896315408338393, 0.004922301250709487, 0.045499009612415514, 0.078524577830519, 0.08911997000021593, 0.03719337796792388, 44.412058557782856, 70.55828966413225, 50.91754225322178, 44.55709525517055, 28.229155131748744, 35.06046070371355, 46.252087456839426, 64.0040956224714, 63.88129316057478, 64.20150784083775, 47.72692598615374, 0.24924702835934504, 0.03253817990688341, 1.3322495520114899, 1.2859298203672682, 0.8970343683447156, 20.07129774774824, 54.91263484954834, 58.836963517325266, 59.498751640319824, 57.988498142787385, 54.09674610410418, 52.08967208862305, 48.06075913565499, 48.95306069510323, 47.810960974012104, 44.375156675066265, 44.248331206185476, 45.239846093314036, 45.765237603868755, 45.09170355115618, 46.145008768354145, 47.913895062037874, 51.28224624906267, 53.62369884763445, 53.53191314424787, 53.17640161514282, 52.634487288338796, 53.20810277121407, 47.919307708740234, 44.0508634022304, 40.65279129573277, 40.15223264694214, 40.75242846352713, 45.00674792698452, 47.87963349478585, 49.57980210440499, 47.48844296591622, 52.93025820595877, 58.018667221069336, 53.32067748478481, 47.873970712934224, 46.11271006720406, 40.254711627960205, 38.027178219386506, 37.68247808728899, 37.8267365864345, 37.24369934626988, 38.54997457776751, 38.04530954360962, 37.78839642660958, 47.05458007540022, 38.13358988080706, 33.930725302015034, 36.58498927525112, 39.63942084993635, 41.53875262396676, 39.16901043483189, 39.0046056338719, 34.48278052466256, 34.2663927759443, 34.906634535108296, 36.73649821962629, 34.71856416974749, 35.8116443497794, 34.61286817278181, 36.2341434614999, 36.75622068132673, 37.93153279168265, 38.05844511304583, 38.28730140413557, 34.53062929425921, 38.238351345062256, 37.70848519461495, 38.767835344587056, 37.87315402712141, 35.734918866838726, 36.59490782873971, 37.17511020387922, 37.31487669263567, 38.530078411102295, 41.756088801792686, 38.611389705113, 35.594499247414724, 32.90062706811087, 32.9193628856114, 35.131405285426546, 33.37356315340315, 33.19358049120222, 33.515942164829795, 33.206834180014475, 33.76870025907244, 34.34275695255825, 35.03371361323765, 44.512119565691265, 35.34181758335659, 35.55462006160191, 38.185621465955464, 38.09066390991211, 36.083336285182405, 36.09790318352835, 38.708073888506206, 38.39611714226859, 37.32892942428589, 37.67291736602783, 39.58951193945748, 36.65672942570278, 44.59630046572004, 49.99785089492798, 50.57935605730329, 47.93867233821324, 46.186263697487966, 46.36502695083618, 51.46196140561785, 51.312005383627756, 51.126651763916016, 52.133001055036274, 53.2616525377546, 53.29333632332938, 54.286074093409944, 52.15672220502581, 55.188005856105256, 53.8831376348223, 54.99224383490426, 52.25536578042166, 53.86250843320574, 53.91998740604946, 58.41042055402483, 58.551865032741, 64.67046955653599, 65.3200774874006, 63.97221728733608, 55.12061875207083, 57.92491865158081, 53.639130796704976, 63.5289500100272, 61.56907858167376, 66.30784729548863, 1.6098090239933558, 0.654908646430288, 2.3307171974863325, 0.031161411997995207, 0.04763363328363214, 30.870026452200754, 75.37403747013637, 65.21840449741909, 69.0080006463187, 59.392701285226, 50.843300751277376, 18.286524397986277, 35.506218910217285, 43.3256173815046, 64.79434898921421, 34.29286888667515, 0.180746516212821, 0.059367044030555656, 0.03216471423261932, 0.0360243367696447, 0.011517687501119716, 0.09771112578787974, 0.14351382053324155, 0.12216303763645035, 0.10698821941124541, 0.15493874890463694, 0.2284468359180859, 0.2609254302723067, 55.799113818577354, 80.15158408028739, 58.196412563323975, 52.42841414042881, 36.16576623916626, 47.0788049697876, 56.522834709712434, 68.02294063568115, 69.82467801230294, 67.72327872685024, 53.06778737476894, 0.3988954839961869, 0.10861101733254534, 3.6451552595411028, 1.5964979039771217, 1.3930073146309172, 22.516179493495397, 55.234680380140034, 60.285704612731934, 59.91543510981968, 59.37297534942627, 55.12620162963867, 53.02199527195522, 48.079818044389995, 49.263735498700825, 49.782019002096995, 44.5631297656468, 45.06952837535313, 47.459396021706716, 45.72114780970982, 45.75760848181588, 46.44256884711129, 50.053544180733816, 52.76695122037615, 54.99285875047956, 55.14460393360683, 56.080442905426025, 55.02567509242466, 55.969445432935444, 50.51615524291992, 48.02697352000645, 43.522595337459016, 42.23065423965454, 42.52957616533552, 46.809583118983674, 49.983228410993306, 51.887055669512065, 49.10307577678135, 52.669283866882324, 55.30861268724714, 54.68913561957223, 49.29553392955235, 49.70880235944475, 41.45107678004673, 40.5380939074925, 40.317387853349956, 40.55947698865618, 39.41850287573678, 39.83433519090925, 40.44806262425014, 39.145424774714876, 49.29877873829433, 36.6221239226205, 34.48057099751064, 37.133608613695415, 39.416314193180625, 42.44918203353882, 39.526627268110005, 39.387861319950645, 34.73038305555071, 35.213008403778076, 36.75838851928711, 39.16326080049787, 36.74145923342024, 37.58702026094709, 36.72823681150164, 39.91181455339704, 39.22623927252633, 41.58302307128906, 41.382004737854004, 41.179270199366975, 35.729301248277935, 42.46750790732247, 39.223546845572336, 40.08609274455479, 39.552926199776785, 38.177947180611746, 38.20719909667969, 39.22114276885986, 38.988464968545095, 40.34766810280936, 43.247898306165425, 38.9161376953125, 37.120445251464844, 33.09218890326363, 32.330551692417686, 35.24423360824585, 33.34066343307495, 34.035257475716726, 34.167519909994944, 35.363759994506836, 33.923141343253, 35.041304520198274, 35.521765504564556, 47.50938136237008, 37.610303674425396, 36.67525332314627, 38.968620913369314, 40.06042262486049, 37.99686670303345, 37.46948453358242, 40.64270598547799, 40.87762805393764, 38.54056324277605, 40.53282717296055, 41.53839826583862, 39.6357695715768, 45.414694036756245, 52.9790484564645, 53.459547655923025, 51.732444354466026, 47.49267094475882, 50.138951437813894, 55.81010239464896, 52.44309915815081, 54.50436912264143, 54.60120269230434, 54.76108769008091, 56.00064284460885, 56.90091398784092, 55.24550567354475, 57.89131716319493, 55.308477197374614, 57.11934450694493, 54.21858971459525, 54.91339567729405, 56.19404942648751, 60.85385881151472, 60.446214948381694, 67.37654972076416, 65.12490953717912, 67.77305562155587, 58.96476173400879, 62.01445116315569, 56.483692032950266, 67.4908753803798, 64.56072275979179, 72.73691817692348, 1.8628363609313965, 1.5801670317138945, 5.338987112045288, 0.30999111171279636, 0.15670564052249703, 33.77136836733137, 81.54007039751325, 68.32353360312325, 76.17692266191754, 70.34033162253243, 59.44276305607387, 16.5382308278765, 40.994795526777, 53.36783838272095, 74.83502401624406, 45.72051552363804, 0.2638070327895028, 0.27754470705986023, 0.17662732010441168, 0.11763788759708405, 0.08610148661370788], [0.03265590233994382, 0.035995037627539465, 0.03596889367327094, 0.07210064253636769, 0.05445531902036496, 0.016966561188123057, 0.054235626344702074, 34.44325222287859, 55.77947473526001, 39.164487157549175, 29.186186109270366, 19.98737393106733, 44.769838673727854, 45.62791688101632, 55.99789135796683, 58.875894274030415, 56.564211232321604, 46.878735065460205, 0.2844959726291043, 0.040188417969537635, 0.09062938471989972, 1.08798791042396, 0.2036699125809329, 8.458117706435067, 45.765230655670166, 49.359776973724365, 53.8344064440046, 53.327782017844065, 54.48926721300398, 51.161715848105295, 49.93082857131958, 47.45821482794625, 48.77260208129883, 47.89541285378592, 49.155208110809326, 47.91698701041085, 47.252329281398225, 48.24587651661464, 54.48690482548305, 53.478745528629844, 51.49887718473162, 50.646680627550396, 49.33246013096401, 46.47994320733206, 44.63337952750069, 40.60791982923235, 41.24871744428362, 40.59749753134591, 37.818871225629536, 38.501625537872314, 39.31359549931118, 42.67847606113979, 48.8066725730896, 48.238897051130024, 44.752370902470176, 40.767651966639924, 39.503180571964805, 56.40223830086844, 58.279797894614084, 45.503036907741, 45.18949597222464, 37.213794299534385, 38.01189913068499, 35.18571240561349, 37.13460220609392, 35.48082324436733, 36.97000980377197, 35.02084902354649, 41.59976822989327, 43.06609869003296, 35.44103785923549, 38.19547748565674, 37.476839201790945, 39.42728539875576, 38.31505945750645, 35.27413518088204, 37.64639261790684, 35.83156483513968, 33.30809027808053, 35.90899556023734, 35.80992814472744, 33.73894459860665, 32.398161138807026, 34.13005869729178, 35.66267844608852, 35.35668672834124, 37.32702909197126, 37.05979790006365, 33.53920473371233, 35.632207121167866, 36.28882578441075, 35.47238118307931, 35.41768148967198, 34.75337464468819, 34.79456009183611, 36.14087084361485, 36.22450283595494, 36.73282609667097, 36.79719073431832, 34.19009460721697, 34.00244460787092, 34.77164493288313, 33.485714026859824, 31.80178335734776, 35.24895143508911, 32.53666305541992, 34.51522513798305, 31.16744061878749, 33.17097452708653, 32.56518541063581, 34.76937287194388, 38.95438058035714, 34.66745669501168, 35.04517466681344, 36.29894583565848, 35.54613283702305, 35.01280300957816, 34.17202581678118, 34.811044692993164, 36.483910356249126, 36.68822908401489, 37.4625814982823, 37.207012857709614, 37.65675933020455, 43.49767214911324, 48.33555691582816, 49.54738180977957, 51.727274894714355, 47.001686913626536, 45.13438286100115, 43.58394793101719, 46.906020641326904, 50.723840372903005, 49.799340861184255, 50.65093987328665, 50.714964049203054, 50.3813601902553, 50.11200284957886, 52.71827561514718, 53.061926569257466, 54.40483965192522, 54.09307050704956, 53.48984180177961, 53.22457000187465, 48.818234375544954, 55.736406326293945, 46.86364705221993, 46.423735754830496, 63.54418740953718, 57.501283509390696, 59.584117208208355, 54.030005182538716, 62.540131023951936, 61.75708988734654, 63.01667322431292, 2.0998259527342658, 0.19080228305288724, 1.9010058556284224, 0.10773056386304752, 0.06663412693887949, 22.489743334906443, 69.74184853690011, 58.85144356318882, 62.577588762555806, 54.393215315682546, 49.23205171312605, 27.1705310685294, 17.66554478236607, 37.73098693575178, 57.892105783735005, 48.53587695530483, 0.22895516721265657, 0.0035708961326495875, 0.04350762468363557, 0.018820746336132288, 0.018633716639929583, 0.08146168451224055, 0.01169219398538449, 0.03169250814244151, 0.0399993679353169, 0.05359291797503829, 0.07227006594517402, 0.052418221187378676, 43.939341340746196, 63.64160810198103, 46.38197013310024, 40.19913298743111, 23.59317980493818, 45.04192665645054, 50.00853027616228, 61.74919673374721, 63.45691108703613, 61.27038942064558, 48.19895533152989, 0.2905799890203135, 0.11855282421622958, 0.8561308660677501, 2.4376478024891446, 0.31108700005071505, 8.613177180290222, 50.43720633643014, 53.09428433009556, 54.98930127280099, 54.84004007066999, 56.05880968911307, 52.09929186957223, 52.16917337690081, 48.87434107916695, 50.57572909763881, 48.46339682170323, 49.25502940586635, 48.922450406210764, 47.36236095428467, 49.649430002485005, 53.75356067929949, 57.157170500074116, 54.312831606183735, 52.6788306917463, 50.03020518166678, 49.0602297101702, 46.97625650678362, 42.10208477292742, 41.26462881905692, 41.35117558070591, 40.2454948425293, 39.521412645067485, 41.64773859296526, 45.36062315532139, 49.970012937273296, 50.266225065503804, 45.49149942398071, 41.82534844534737, 44.905814920152935, 56.966042927333284, 55.47093997682844, 47.149555001940044, 45.90414946419852, 39.6098632131304, 38.702081067221506, 37.53375537054879, 39.74520369938442, 37.42404678889683, 38.5006354195731, 35.83040101187569, 43.17498738425118, 44.007711614881245, 36.07955299104963, 37.90822853360857, 36.42613608496529, 39.05792958395821, 40.1131386075701, 35.134910651615684, 37.322915758405415, 35.841782161167686, 33.521879400525776, 35.422798837934224, 36.90024988991873, 34.585193497794016, 34.06869568143572, 37.26565912791661, 36.61346646717617, 37.274858542851035, 39.803731850215364, 38.14862925665719, 37.021846839359824, 38.21091290882656, 38.88533285685948, 38.167872292654856, 37.09244748524257, 36.69031006949288, 36.881653036390034, 37.0892721584865, 38.575999055589946, 39.57599769319807, 37.54940618787493, 34.93589339937483, 34.016907283238, 34.78993953977312, 34.0152153968811, 31.700621059962682, 35.522804260253906, 33.20062249047415, 34.18528992789132, 31.59703036717006, 34.11741992405483, 32.38716908863613, 34.842002391815186, 39.61080469403948, 35.93559326444353, 37.865413733891074, 36.612973145076204, 37.81726271765572, 36.73853404181344, 36.79131603240967, 37.17063208988735, 37.94568279811314, 37.57218585695539, 37.28954356057303, 37.42063522338867, 39.913093021937776, 46.424864837101524, 50.272561822618755, 48.67313167027065, 52.83284446171352, 49.58134460449219, 47.34131486075265, 46.07959147862026, 49.02966111046927, 52.186543873378206, 51.3221150125776, 51.56589950834002, 53.674528394426616, 53.43601410729544, 51.536956787109375, 53.1918683052063, 55.60774653298514, 54.69336359841483, 56.99464866093227, 53.17179495947701, 54.51472193854195, 50.63345125743321, 56.53591816765921, 46.935408047267366, 46.54496097564697, 66.36514908926827, 60.4331453868321, 63.32355431147984, 55.23384312220982, 63.67621013096401, 62.9352959224156, 67.89954062870571, 2.3226481676101685, 0.6029129422136715, 3.530302188226155, 0.06613179389387369, 0.09701120334544353, 24.734273774283274, 76.76987498147147, 62.949630056108745, 66.88980756487165, 60.71300492967878, 53.519625255039756, 21.78477042061942, 23.871045214789255, 44.70763145174299, 65.13187163216728, 57.56055859157017, 0.518082928444658, 0.10045972865607057, 0.05990710362259831, 0.014349544919761164, 0.05490964571280139, 0.1263923328369856, 0.11130364106169768, 0.055998104092265875, 0.208026188824858, 0.15712156891822815, 0.22650432586669922, 0.34293832949229647, 55.99362863813128, 69.72073296138218, 55.561805043901714, 44.74607583454677, 29.237453392573766, 59.404749461582725, 57.69987344741821, 67.73194313049316, 67.67807374681745, 66.2807423727853, 54.5940842628479, 0.42341149704796927, 0.2949843598263604, 2.0524292503084456, 2.348495466368539, 0.8184648443545613, 10.125945925712585, 55.41240835189819, 56.16345303399222, 56.3376339503697, 57.51686484473092, 58.62136786324637, 53.64150708062308, 53.93160479409354, 51.55765199661255, 51.89866263525826, 48.850925649915425, 50.262393133980886, 49.77814538138253, 49.39512593405587, 50.460649558476035, 56.68258421761649, 58.4030693599156, 55.666816643306184, 54.02684027808053, 53.17574501037598, 51.42814104897635, 49.68725252151489, 45.017712184361045, 43.579320430755615, 44.343521526881624, 40.80370964322771, 40.44649233136858, 41.99228586469378, 46.904964515141074, 53.4186019216265, 52.027447496141704, 47.457850047520225, 45.540077754429404, 49.1395468711853, 60.81197507040841, 54.77741248267037, 48.69475099018642, 48.46971620832171, 41.675722462790354, 40.659736020224436, 38.870786803109304, 41.86167362758091, 39.678080626896445, 40.67953838620867, 38.94456277574812, 43.885565757751465, 43.59136165891375, 36.312275954655235, 38.90794229507446, 37.17192792892456, 40.2513313293457, 41.00353636060442, 35.291196482522146, 38.20552110671997, 36.136479582105366, 33.738357475825715, 37.8119786126273, 39.788299901144846, 36.55445541654314, 35.882172039576936, 38.41196250915527, 39.98358597074236, 39.732637882232666, 42.94107280458723, 42.05676514761788, 38.6223018510001, 41.55908652714321, 41.573795863560264, 39.373714787619456, 38.89165224347796, 38.23550953183855, 39.91398933955601, 39.87338754108974, 39.295370374407085, 40.007008348192485, 38.623899936676025, 34.68646001815796, 32.84041745322091, 35.975142410823274, 34.18970203399658, 31.88809735434396, 37.14439221790859, 33.74588584899902, 35.36608416693551, 31.489263807024273, 34.66503177370344, 32.95212016786848, 35.59978335244315, 41.858571256910054, 38.74534055164882, 38.00980077471052, 39.33773354121617, 39.62406880514962, 37.46463121686663, 38.716759136744905, 37.289522715977256, 40.43037598473685, 40.47545937129429, 40.623084272657124, 40.21441207613264, 42.132163524627686, 48.082500049046104, 53.29430212293352, 52.918119703020366, 55.34186676570347, 51.29148735318865, 51.6154088973999, 48.27316556658064, 51.868823596409385, 55.566533293042866, 54.37293004989624, 55.976880005427766, 56.84349060058594, 56.153527532305034, 54.45416838782174, 55.01323781694685, 57.15534312384469, 57.458698000226704, 58.27886683600289, 54.7075275012425, 55.19160849707467, 51.66576944078718, 56.845185961042134, 51.883393968854634, 51.062294074467246, 67.11990410940987, 63.220304080418174, 65.89423492976597, 59.287304060799734, 68.80735751560756, 65.93757084437779, 72.17248126438686, 3.524274843079703, 1.664254565324102, 7.78446900844574, 0.13074369648737566, 0.2368851245513984, 26.79874685832432, 82.94087587084088, 67.72038827623639, 74.28972244262695, 67.13303620474679, 64.2246800831386, 38.96042203903198, 31.53312083653041, 54.391832624162944, 74.3502482005528, 70.17686830248151, 1.1394303100449699, 0.24702165062938417, 0.18128397023039206, 0.09160791364099298, 0.15137994129742893], [0.026020377774589827, 0.05159787913518293, 0.027709186975178973, 0.05315259624538677, 0.07321344675230128, 0.048778281147990904, 0.04260722906993968, 39.17398534502302, 56.26657819747925, 41.790808950151714, 33.23350831440517, 20.35093321119036, 32.08268512998308, 42.83448396410261, 57.960594177246094, 58.10590532847813, 55.717403003147666, 46.110236508505686, 0.7108941908393587, 0.05858733944062676, 0.6127095765301159, 2.178761831351689, 0.3378002180584839, 2.6696040758064816, 32.738379682813374, 50.21840408870152, 52.27864571980068, 54.19984694889614, 56.03739881515503, 54.99356051853725, 53.75298397881644, 53.09254380634853, 51.03238902773176, 48.85521616254534, 45.986718382154194, 48.0941104888916, 52.285423687526155, 53.13482706887381, 53.36676836013794, 48.80025938579014, 50.02301379612514, 47.410602297101704, 44.96944304874965, 41.214025088718955, 39.069335051945274, 39.82328060695103, 39.315891878945486, 38.91927828107561, 39.037335123334614, 40.30586426598685, 39.10169281278338, 42.25184971945626, 44.3560664994376, 45.45777286802019, 45.84371403285435, 48.6292850630624, 44.56289005279541, 34.449411800929475, 49.401563440050396, 50.56033188956124, 44.10828331538609, 41.253404004233225, 36.66636310304914, 37.892786162240164, 36.63082306725638, 37.34010560171944, 35.35815279824393, 36.470962388174875, 38.58466693333217, 47.18652636664254, 38.54243925639561, 37.38654041290283, 34.781803199223106, 35.39627756391253, 36.56758056368147, 37.60072905676705, 36.18714237213135, 37.238456930433, 32.17539494378226, 35.4662424496242, 35.837675775800435, 36.83748681204659, 34.68778017589024, 34.45779480252947, 33.83250904083252, 34.76639904294695, 35.147664070129395, 36.45830971854073, 34.19492013113839, 36.34833710534232, 36.462568964277, 34.709017344883506, 36.1542843409947, 34.50321865081787, 34.21372890472412, 36.21648461478097, 36.12432370867048, 35.82762173243931, 37.27804776600429, 33.32004812785557, 34.461623259953086, 35.75851147515433, 34.419399057115825, 34.25264229093279, 35.12849746431623, 32.5919429234096, 33.81294638769967, 33.383731842041016, 35.341324261256624, 32.349930218287874, 42.331604616982595, 36.905766759599956, 35.01474155698504, 34.266205174582346, 34.711633341653005, 35.546306541987825, 33.880465507507324, 35.8829676083156, 34.84434740883963, 35.422903060913086, 36.47611447743007, 42.875530447278706, 45.20345490319388, 44.99144799368722, 43.81441273008074, 47.94999442781721, 48.60790198189871, 48.16094868523734, 49.41533824375698, 46.883897577013286, 45.10214669363839, 43.139471667153494, 43.7378887448992, 47.059891973223, 49.42950562068394, 48.89425809042794, 48.54440239497593, 49.75230850492205, 49.72749301365444, 52.88675553458077, 52.10651799610683, 53.41762917382376, 54.7547995703561, 55.02119697843279, 56.55987903050014, 55.00664745058332, 45.03215748923165, 44.984913212912424, 55.30079596383231, 56.45800454275948, 60.532122475760325, 57.60560376303536, 59.87000778743199, 61.17869404384068, 58.86895997183663, 1.5119256249495914, 0.3552598740373339, 1.4484364603246962, 0.09583069490534918, 0.04703007299186928, 19.595170702253068, 69.4246493748256, 61.21998718806675, 62.746263231549946, 50.606513091496055, 37.40677356719971, 20.729603086199077, 26.874407529830933, 44.18963629858834, 57.608188492911204, 51.160291467394146, 1.1922649549586433, 0.02092441015078553, 0.08012445483888898, 0.07376375222312552, 0.045401941785322766, 0.012404042528942227, 0.08319234914545502, 0.02620498340443841, 0.08401863516441413, 0.02681287783863289, 0.011197045778057404, 0.15672799146601132, 48.24714456285749, 63.135668073381694, 48.04516737801688, 33.82343816757202, 24.420018911361694, 42.89863668169294, 47.979805673871724, 64.52086789267403, 62.19385365077427, 61.81164019448416, 49.51094198226929, 0.6509413878832544, 0.20845652930438519, 1.3101504806961333, 5.673276237079075, 0.902739870761122, 3.065252091203417, 37.77254411152431, 51.51036603110177, 53.40743964059012, 55.54481669834682, 58.03570072991507, 56.967408248356406, 56.70667014803205, 54.840547289167134, 52.26307828085763, 49.19895396913801, 48.24816247395107, 49.03590406690325, 52.979576519557405, 53.71591533933367, 56.68537391935076, 50.516200406210764, 52.54999371937343, 49.87187658037458, 48.68167795453753, 45.132423468998496, 41.61170176097325, 42.053749629429404, 42.44385276521955, 40.19278233391898, 40.28112520490374, 41.5780794279916, 41.32307359150478, 44.72351850782122, 48.2303820337568, 48.4223746572222, 46.10285404750279, 49.28174522944859, 45.35792030606951, 38.88459287370954, 50.7645047051566, 50.894852910723, 45.53227145331246, 41.377168791634695, 38.679603644779746, 39.64187008993966, 37.273555755615234, 38.9164468901498, 37.9463324546814, 39.07490750721523, 39.28431231634957, 46.75820813860212, 39.11721856253487, 36.730884075164795, 35.36997168404715, 34.41683864593506, 37.421684401375906, 36.20461709158761, 37.408510616847444, 35.93443986347744, 33.49528864451817, 36.857178006853374, 39.61387579781668, 38.82587712151663, 35.994104044778005, 37.17895950589861, 35.93078511101859, 36.92348119190761, 38.78483063834054, 37.21179321834019, 35.17866693224226, 38.3110225541251, 37.90657138824463, 37.45384761265346, 36.29248401096889, 37.649759020124165, 35.733675139290945, 37.061670439583914, 38.00890793119158, 36.93202747617449, 36.45301866531372, 35.518221923283164, 33.83363812310355, 34.869954994746614, 33.40411785670689, 33.79814672470093, 35.31777334213257, 33.40209245681763, 34.15950516292027, 32.87238958903721, 34.116815430777415, 32.72888496943882, 40.99026182719639, 39.39553907939366, 35.45812347957066, 36.38139663423811, 37.074680941445486, 37.060075828007285, 35.887369292122976, 37.92337908063616, 37.19839709145682, 37.615876129695344, 40.179702350071494, 45.0412665775844, 47.07609517233712, 46.759625571114675, 47.52076251166207, 49.7632588659014, 50.90263836724417, 49.150274889809744, 50.627857957567485, 47.77228730065482, 47.53639595849173, 46.17854077475411, 45.908794334956575, 49.01209259033203, 50.990578242710654, 50.95900910241263, 48.68039948599679, 52.0263010433742, 51.98212092263358, 55.16373232432774, 54.787483896527974, 56.40471880776541, 56.720802783966064, 56.27593394688198, 59.28013351985386, 56.272696086338584, 46.61299773624965, 46.6102670942034, 56.0614013671875, 58.250935077667236, 62.38637433733259, 60.12729263305664, 62.45317431858608, 63.89191000802176, 61.90286309378487, 1.7359453184264046, 0.5506837676678384, 2.6156702041625977, 0.1330286224505731, 0.10492847207933664, 20.144318103790283, 75.10056332179478, 66.22550419398716, 69.12953853607178, 56.15683487483433, 47.85557883126395, 28.048376900809153, 37.24144812992641, 49.75476121902466, 64.18797969818115, 61.74260984148298, 1.677674142377717, 0.10198962156261716, 0.09753882539059434, 0.045393612767968855, 0.05469890969938465, 0.06227211707404681, 0.20957115877951893, 0.12131094693073205, 0.1618875174650124, 0.13318558117108686, 0.09283990931830235, 0.3707011326083115, 58.45999595097133, 71.432220186506, 55.52255119596209, 47.005998270852224, 28.988367421286448, 44.768612316676546, 56.38992609296526, 67.0766932623727, 68.020751953125, 66.84454005105155, 54.83856357846941, 0.8955715554101127, 0.5119469634124211, 1.516797723514693, 7.320896489279611, 0.6827761339289802, 4.575377481324332, 40.22109624317714, 53.76959017344883, 54.49789687565395, 57.24478381020682, 58.691037450517925, 61.15418079921177, 58.44967787606375, 56.275433676583425, 52.78029523577009, 52.00687388011387, 47.89463812964303, 48.793787138802664, 53.77228260040283, 55.977943079812185, 59.47223036629813, 52.33900472096035, 54.971927302224294, 53.21997029440743, 50.86319344384329, 47.274059772491455, 43.28400809424264, 42.92789902005877, 43.974481855119976, 42.67970936638968, 41.857060023716514, 43.59134776251656, 42.33208751678467, 46.98586586543492, 49.93175962993077, 50.555697441101074, 48.00828633989607, 50.898969718388145, 47.55987392153059, 44.42079939161028, 54.55773476191929, 52.24690634863717, 48.53337907791138, 43.68324811117989, 39.61588382720947, 42.02140576498849, 39.15527384621756, 41.057065282549175, 39.317667143685476, 41.14782265254429, 43.306113788059776, 47.41405207770211, 38.85813413347517, 38.7216089793614, 35.73369598388672, 34.93970448630196, 38.21432100023542, 37.49191679273333, 36.977962017059326, 36.73682131086077, 33.107044151851106, 37.98824746268136, 41.06885984965733, 39.674599579402376, 38.944149357931956, 38.78427825655256, 37.35277564185006, 38.86702782767159, 40.36449663979666, 39.32672759464809, 37.51885148457119, 40.64475222996303, 40.88445118495396, 39.49810143879482, 40.50749404089791, 40.544208322252544, 36.34406396320888, 38.356505462101524, 39.464506898607524, 38.20810236249651, 37.81871141706194, 35.56102977480207, 34.031380380902974, 35.7836674281529, 33.6774982043675, 33.67529215131487, 36.11645139966692, 33.29925216947283, 33.58898857661656, 33.200973374503, 34.904550075531006, 32.55428368704659, 43.21589837755476, 41.26870046343122, 39.11427252633231, 39.13617672239031, 37.83314977373396, 38.93640906470162, 37.21168204716274, 39.34686694826399, 38.151269572121755, 39.30956207002912, 41.425034931727815, 47.698830945151194, 50.50238043921334, 49.4477515901838, 49.95346580232893, 51.782797949654714, 54.17847081593105, 50.49594293321882, 52.75818954195295, 49.67679895673479, 49.81450183050973, 48.98593609673636, 47.96248034068516, 51.155264445713584, 53.71949018750872, 55.02880525588989, 51.36624302182879, 53.63053934914725, 54.2519063268389, 57.62252262660435, 57.65509230749947, 59.0705897467477, 59.11999143872942, 60.36515031542097, 62.92721516745431, 58.16340514591762, 48.62259047372, 46.8421562739781, 58.10885483877999, 59.233830724443706, 66.17846488952637, 63.76254844665527, 65.33266762324742, 67.05241625649589, 67.01667472294399, 2.6621024097715105, 1.3406351591859544, 6.188176836286273, 0.5098345481923648, 0.18763496301003865, 22.622049195425852, 81.85144696916852, 71.6942298071725, 76.29568822043282, 66.6405131476266, 50.254701478140696, 31.62491696221488, 41.93194770812988, 60.1455386025565, 73.29392746516636, 73.02945818219865, 3.29135667851993, 0.3553979694843292, 0.30553574221474783, 0.15554622773613247, 0.13275194301136903], [0.03500852234927671, 0.026020779806588377, 0.03746271226555109, 0.04582879798752921, 0.03896034422463604, 0.04186767339706421, 0.12390139007142612, 36.135993208204, 59.23165593828474, 49.19473641259329, 29.838291917528423, 10.130482230867658, 37.25720664433071, 42.43406622750418, 60.486535344805034, 56.21893787384033, 57.65600946971348, 45.48900849478585, 0.5226566344499588, 0.09108401675309453, 0.4632004105619022, 6.837101238114493, 1.5001981513840812, 0.4512110496205943, 32.33735397883824, 52.09581429617745, 54.5599547113691, 58.65703991481236, 59.53256157466343, 55.34149156297956, 54.632556438446045, 54.09837545667376, 54.30077995572771, 52.62873765400478, 55.70048066547939, 53.96569960457938, 51.743214062282014, 51.66353906903948, 50.73232759748186, 50.06932701383318, 46.06825201851981, 42.841723987034385, 40.37156295776367, 37.41530248097011, 39.64715766906738, 40.37308461325509, 41.52986935206822, 41.19092927660261, 38.22949934005737, 39.8130076953343, 40.53028065817696, 41.894851275852744, 43.387338229588096, 44.40558978489467, 44.12838445390974, 45.10040964399065, 46.91703701019287, 46.39108269555228, 37.13277135576521, 46.88298388889858, 45.27570922034127, 39.38712133680071, 36.35513244356428, 35.77409281049456, 36.826942920684814, 36.19798503603254, 36.05558170591082, 36.670024803706575, 35.34573636736189, 46.634512833186555, 46.97687142235892, 38.1682961327689, 35.81004626410348, 35.74919046674456, 36.49882813862392, 37.104280267442974, 38.1468505178179, 35.826252937316895, 33.71940279006958, 34.728809288569856, 35.58999681472778, 36.589529923030305, 35.71147564479283, 34.322912897382466, 34.83041974476406, 33.52569396155221, 38.12411601202828, 36.757193429129465, 35.12042018345424, 36.83718456540789, 35.55376890727452, 35.96846171787807, 33.330282824380056, 34.97044331686837, 35.53222254344395, 35.284081527165, 34.33987692424229, 36.29983173097883, 36.75491789409092, 35.35275057383946, 36.420348235539024, 33.49738700049264, 32.95383984701974, 34.852059909275596, 33.63972084862845, 34.634042807987754, 32.48383937563215, 34.92459215436663, 34.812486444200786, 39.10784544263567, 46.04087611607143, 36.152265889304026, 33.486909117017476, 35.81803321838379, 37.20708233969552, 35.7461610521589, 35.53063835416521, 36.09908785138811, 36.162055901118684, 35.60337904521397, 41.87933594839913, 46.26341649464199, 43.56183876310076, 49.199318749564036, 46.868830408368794, 47.93491336277553, 47.34416709627424, 47.727499212537495, 49.926458154405864, 48.314041818891255, 44.40635756083897, 45.73880318232945, 45.20370156424386, 43.269583633967805, 42.38784681047712, 46.204749379839214, 51.21255234309605, 46.48476873125349, 49.15773378099714, 48.18305785315377, 49.75481333051409, 49.92511020387922, 50.96501929419381, 53.50610406058175, 55.70372200012207, 55.11510535648891, 54.63080549240112, 53.091525895254954, 51.71287475313459, 70.55844947269985, 66.12542234148297, 57.3839874948774, 60.119663511003765, 63.641802651541575, 56.649055685315815, 0.8107348105737141, 0.1831180096736976, 2.3787566082818166, 0.118483233664717, 0.193840477881687, 19.450472729546682, 71.62480340685163, 56.97700023651123, 66.56384672437395, 54.45003768375942, 45.79563249860491, 17.136842455182755, 10.313984155654907, 30.55436979021345, 54.47630534853254, 57.68030037198748, 3.01152731691088, 0.3670943390045847, 0.0342337948137096, 0.030472101843250648, 0.034860024960445504, 0.046372470778546164, 0.015757601774696792, 0.03556671578969274, 0.03587610061679568, 0.04125636423538838, 0.039139290872429094, 0.17591610683926515, 45.37364755358015, 66.7120726449149, 53.56151941844395, 35.67459460667202, 16.916313580104283, 38.32999113627842, 49.92598915100098, 65.08212947845459, 61.897658893040244, 60.79039396558489, 51.095899036952424, 0.37231976432459696, 0.07522809186152049, 1.9484779025827135, 9.591135263442993, 2.252098764692034, 0.24159421186361993, 37.130065032414024, 52.089328152792795, 57.46119935171944, 58.175627027239116, 62.352418490818565, 56.594328199114116, 56.571732657296316, 54.15661178316389, 55.525479861668174, 53.230701787131174, 56.6263871874128, 56.43369279588972, 55.751602036612375, 52.45203454153878, 52.10447175162179, 51.84818744659424, 47.039047377450125, 44.90993520191738, 43.26156888689314, 38.91193750926426, 41.13109139033726, 42.90701273509434, 42.985798358917236, 41.20430108479091, 38.77760451180594, 40.21744149071829, 42.25479922975813, 43.47370433807373, 45.28808396203177, 46.31462819235665, 46.516758237566265, 46.17632777350289, 50.65967375891549, 46.908977099827354, 39.69384608949934, 48.204166480473106, 46.29161923272269, 40.51829154150826, 38.451289313180105, 37.41566031319754, 39.20690590994698, 38.47774805341448, 38.360855034419465, 37.30839054925101, 37.919140679495676, 47.34821094785418, 48.27594832011631, 38.76058142525809, 36.158352511269705, 34.409383228846956, 36.09873349325997, 36.71923542022705, 37.99348987851824, 36.23609937940325, 34.767458643232075, 34.05776616505214, 36.17081063134329, 38.30278199059622, 37.920860358646934, 36.647943428584504, 37.12346771785191, 35.17308405467442, 39.28052207401821, 37.66929735456194, 37.97773483821324, 37.607447964804514, 37.711285318647114, 38.45462097440447, 35.22437565667288, 35.972192900521414, 36.14468540464129, 35.30863298688616, 36.134290899549214, 37.62468991960798, 37.60337632043021, 34.62049034663609, 34.52591494151524, 34.022000312805176, 31.843344007219585, 35.26022836140224, 34.39273534502302, 34.68568181991577, 32.51065942219326, 35.42301423209054, 34.228653635297505, 40.46201113292149, 47.620333671569824, 37.75012574877058, 36.970398902893066, 35.65707472392491, 39.3361701965332, 35.788916792188374, 37.28892517089844, 37.89597885949271, 37.97591093608311, 36.839821406773154, 43.84662805284773, 48.687483174460276, 44.45911523274013, 50.67421286446707, 46.614731311798096, 48.48469305038452, 48.45307527269636, 50.95141124725342, 51.19208642414638, 50.3137993812561, 46.08238465445382, 47.834515367235454, 47.003615038735525, 45.56396566118513, 45.33721467426845, 48.50750746045794, 51.865960938589915, 48.40936068126133, 50.03299835750035, 50.33544301986694, 51.32264654976981, 51.522497585841585, 50.90750905445644, 55.54078674316406, 55.82342209134783, 55.640680994306294, 58.11824532917568, 53.138433183942524, 52.499171120779856, 65.4654963357108, 65.44080938611711, 59.25416810171944, 62.918279784066335, 64.43319552285331, 59.660582133701865, 1.146022087761334, 0.473070923771177, 4.298564723559788, 0.11713613809219428, 0.20157767699233123, 21.0209983757564, 77.08631678989956, 63.19050325666155, 70.8943601335798, 59.799664224897114, 46.45522499084473, 21.45527468408857, 19.742173739842006, 40.56184632437569, 59.90013517652239, 66.98089150020054, 4.229076657976423, 0.32964987254568506, 0.07165865161057029, 0.04153215140104294, 0.07298073638230562, 0.12507841762687477, 0.12278225512376853, 0.16294943833989756, 0.07313096403543438, 0.12266148946114949, 0.1914516274950334, 0.29865599423646927, 56.282920360565186, 74.65927628108433, 63.700431551252095, 42.94303567068917, 18.07079325403486, 46.474954400743755, 57.49612447193691, 70.72358730861119, 68.59272766113281, 67.00288254874093, 55.59163366045271, 0.6526034186993326, 0.24754433972494944, 4.763181209564209, 18.411444323403494, 2.396845591919763, 0.7092642954417637, 41.39744363512312, 51.53250299181257, 59.23270511627197, 61.54981817517962, 64.55585207257951, 58.45503493717739, 57.966058935437886, 55.84165416445051, 59.33233533586775, 55.205445834568565, 58.31976740700858, 57.49700689315796, 58.89498792375837, 54.01268679755074, 56.02475309371948, 54.146224226270405, 50.58140924998692, 46.77164942877633, 46.05803121839251, 40.4021315574646, 44.59166601725987, 45.23189040592739, 44.854234967912944, 44.05919081824166, 40.830421992710654, 43.978914805821006, 45.45948559897286, 45.45642144339425, 49.88216686248779, 46.80392728533064, 49.67022596086775, 49.318862506321494, 50.701765945979524, 48.678940364292686, 43.96510178702218, 52.454869406563894, 47.42394283839634, 42.66264111655099, 41.81654160363333, 39.23344802856445, 41.870174748556956, 41.611072949000764, 40.16106033325195, 40.99550076893398, 39.17189046314785, 49.18560995374407, 49.373881816864014, 38.85878379004342, 36.02536399023873, 34.91931847163609, 37.142603056771414, 35.834073134831016, 40.38671350479126, 36.589991978236604, 33.10857622964041, 35.29332610539028, 37.527811186654226, 39.12323570251465, 39.402765205928254, 38.97502367837088, 40.73803527014596, 37.26422432490757, 41.71906532560076, 40.79770292554583, 41.574699129377095, 39.58093091419765, 38.5838748386928, 41.002733843667166, 38.73754814692906, 38.93435934611729, 37.77254063742501, 38.065688610076904, 38.15116534914289, 39.63165276391165, 38.579521792275564, 36.01609509331839, 35.38135630743844, 35.32861253193447, 32.42502634865897, 36.4004624911717, 34.096655232565745, 35.65320805140904, 33.149525438036235, 35.851645129067556, 35.05780649185181, 41.187142508370535, 51.33599056516375, 42.01168523515974, 39.13998086111886, 37.646559374673025, 41.87940195628575, 37.59053952353341, 39.44781732559204, 40.60031502587454, 39.90599543707711, 40.018524987357004, 45.72190863745553, 51.278233664376394, 47.35790021078927, 53.824929101126536, 51.4313302721296, 51.47155686787197, 52.838010447365896, 51.35437549863543, 53.483994892665315, 52.53373840876988, 50.253756523132324, 50.91110822132656, 49.25096818378994, 47.42549576078142, 47.58398764474051, 50.030424049922395, 51.49457277570452, 50.76810734612601, 53.35233000346592, 53.22345134190151, 55.21365165710449, 54.925947598048616, 53.66646153586251, 58.423774991716655, 58.711499895368306, 58.67922551291329, 59.323080335344585, 54.831757817949565, 54.577168873378206, 64.79498822348458, 68.78441456386021, 63.67093644823347, 66.25786890302385, 67.16118335723877, 64.30013751983643, 1.6154167630842753, 1.0773761655603136, 8.32459591116224, 0.3133723059935229, 0.2984011364834649, 22.801771300179617, 84.37950038909912, 66.44088445390973, 77.57865224565778, 68.99261038643974, 59.274185861860005, 24.18224287033081, 22.955800703593663, 49.80579226357596, 69.58374922616142, 80.96705940791539, 7.240835002490452, 0.6347563192248344, 0.160923319203513, 0.25157011513199123, 0.1870237115238394], [0.031790033980671845, 0.060766054317355156, 0.0193312302830496, 0.10001530857490641, 0.0365924877114594, 0.1424063699586051, 0.2134455530239003, 31.55815519605364, 62.97199630737305, 47.56929915291922, 31.584468024117605, 27.78359842300415, 40.99466698510306, 38.58880458559309, 60.60102081298828, 58.48758029937744, 56.165773732321604, 48.911659853799, 0.798067430300372, 0.07813859318516084, 1.551265456846782, 2.728401903595243, 2.7994196585246494, 0.2830510730189936, 27.14855739048549, 55.3655219078064, 55.10344975335257, 56.59844848087856, 53.82164260319301, 53.97192171641758, 52.539772919246126, 54.85433598927089, 55.19206707818167, 53.35029418127877, 50.28934867041451, 50.962264333452495, 50.05361018862043, 49.68079417092459, 48.28215306145804, 43.595714705330984, 41.13069881711687, 38.362192562648225, 39.298476219177246, 40.13416385650635, 41.39913899557931, 45.06927476610456, 44.636033739362446, 44.74094111578805, 41.93089853014265, 44.32975019727434, 43.39358466012137, 43.853399072374614, 46.24250936508179, 47.24302911758423, 47.57763351712908, 48.761481489454, 44.10608073643276, 45.49209696905953, 45.19324452536446, 44.05907964706421, 42.67420291900635, 38.68989740099226, 35.871454443250386, 35.814614704677034, 34.83574901308332, 35.43529517310006, 37.180825097220286, 36.213389192308696, 35.36817904881069, 40.06211798531668, 49.745523588997976, 45.11727292197091, 37.2834986277989, 34.58864675249372, 35.70334277834211, 34.964540822165354, 36.37893697193691, 35.967648778642925, 36.972198486328125, 35.144259452819824, 34.48489972523281, 34.20085736683437, 34.54157270703997, 34.424363545009065, 34.364723682403564, 33.553452014923096, 35.07373523712158, 35.75603444235665, 36.294714382716585, 34.46921764101301, 34.16047443662371, 36.87280797958374, 34.46036911010742, 36.208869389125276, 36.3039276940482, 36.758454527173726, 34.46073389053345, 35.26478290557861, 38.11291551589966, 35.208050864083425, 34.850892611912315, 33.04820680618286, 34.440125533512656, 33.75049250466483, 33.42722061702183, 32.84656660897391, 34.74317468915667, 34.34853090558733, 38.80187109538487, 47.14362471444266, 43.61803926740374, 34.81796162469046, 36.10842275619507, 36.0697351864406, 34.61533825738089, 35.552198614392964, 37.042507307870046, 36.725839682987754, 35.92429549353463, 37.05357231412615, 42.05276298522949, 46.84604031699044, 43.85730395998274, 45.41478088923863, 45.531402928488596, 46.99388756070818, 43.314125061035156, 45.1986780166626, 49.00315720694405, 46.04192181995937, 47.02239601952689, 44.45008257457188, 43.696293354034424, 43.863699776785715, 43.154205322265625, 48.995514188494, 43.64315005711147, 45.07155377524239, 46.49768195833479, 43.503123010907856, 47.509645393916536, 45.978467396327424, 50.841139861515586, 53.43425273895264, 54.822933605739046, 54.43165275028774, 57.26185206004551, 54.929206303187776, 55.89111491612026, 38.18364470345633, 54.30604321616036, 62.93857547215053, 58.49228422982352, 62.31969247545515, 48.03279263632638, 0.40655465157968657, 0.24249636488301413, 1.9456971032278878, 0.09948268572666816, 0.16966394947043487, 18.758539846965245, 71.3909409386771, 58.51262855529785, 69.78829724448067, 54.08361748286656, 48.365896224975586, 28.36477354594639, 27.196105650493077, 35.46603747776577, 50.629101685115266, 57.1994537625994, 2.7991297883646826, 0.12774622733039515, 0.04343114700168371, 0.0522952638566494, 0.07026914759938206, 0.04647839009495718, 0.0150822406035981, 0.04680561360770038, 0.09064725054694073, 0.12715123354324273, 0.1088802803839956, 0.1874627915344068, 42.61560181209019, 69.70339025769914, 54.72086109433855, 35.034154823848176, 21.17941904067993, 46.225201402391704, 45.306250027247835, 67.72263949257987, 62.2092022214617, 62.038352966308594, 53.70572580610003, 0.7263892708080155, 0.16446907179696219, 1.5128412672451563, 6.217721879482269, 4.974544542176383, 0.29075730379138676, 30.378941672188894, 55.70792218617031, 58.67634201049805, 57.56880610329764, 54.67400591714041, 55.46498884473528, 54.11851133619036, 56.62992034639631, 55.57554858071463, 56.36904328210013, 54.01744283948626, 51.04111596516201, 51.42790828432356, 51.96950299399239, 51.12795107705252, 45.032032421657014, 43.54932505743844, 38.790059157780235, 40.72150550569807, 41.129524571555, 42.46051801953997, 44.31981427328927, 46.32105527605329, 46.811865602220806, 44.578287260872976, 45.698618275778635, 45.38826308931623, 45.976375988551546, 46.74927970341274, 49.40307814734322, 48.98657533100673, 49.42071614946638, 45.000108923230854, 47.88942003250122, 45.77840444019863, 44.10432979038784, 44.606986795152935, 41.02682672228132, 38.267849922180176, 36.91523715427944, 37.40517200742449, 35.906817299979075, 37.808723381587434, 37.1755861554827, 37.293639523642405, 41.97099658421108, 53.15335096631731, 46.92699725287301, 37.566293784550254, 34.48687996183123, 35.7667589868818, 36.110048634665354, 37.591779776981895, 36.2678804397583, 36.43580797740391, 34.96954699925014, 33.364085810525076, 35.67471620014736, 36.753246852329795, 35.83975328717913, 38.314618246895925, 36.30971554347447, 36.2399834224156, 37.37701790673392, 39.55487169538225, 35.699719292776926, 35.91483899525234, 37.7378864969526, 35.96139887401036, 37.61681066240583, 37.897820132119314, 36.94310637882778, 34.96191440309797, 36.0382251058306, 36.05891336713518, 34.572165625435964, 34.58821249008179, 33.651748180389404, 33.778035163879395, 33.499349866594585, 33.00180673599243, 33.17464665004185, 34.48665761947632, 33.40381908416748, 40.017545291355674, 49.24214049748012, 45.188349519457134, 36.36888640267508, 36.373632022312705, 36.68953881944929, 37.61945445196969, 37.14152261189052, 37.45725222996303, 38.996010712214876, 37.317339829036165, 38.45471477508545, 44.2816686630249, 49.20415122168404, 46.857237339019775, 46.39680106299264, 49.11085428510393, 48.15966326849801, 45.212515354156494, 48.57067353384835, 49.70178467886788, 49.66819708687918, 48.899726322719026, 48.2977865082877, 47.57025800432478, 48.035141127450125, 45.22940642493111, 52.53690331322806, 45.851478644779746, 47.72245134626116, 47.7553128514971, 45.860858712877544, 49.51505184173584, 49.39774887902396, 52.16234677178519, 55.40920870644705, 57.284253052302766, 55.97851283209664, 58.59183801923479, 56.04485075814383, 57.025050503867014, 39.03246791022164, 56.466960770743235, 64.9383851460048, 61.63659422738211, 65.27116216932023, 49.80270031520298, 0.3187063511993204, 0.5990532178963933, 2.986217200756073, 0.20548317528196744, 0.13783252824630055, 20.772093057632446, 76.58474023001534, 62.63767678397042, 72.83115659441266, 63.779418672834126, 49.3319285937718, 20.862784419740947, 25.941082068852015, 39.30815158571516, 58.601933751787456, 65.70966298239571, 4.906727518354144, 0.25359404938561575, 0.08614141839955534, 0.04126334296805518, 0.08000037792537894, 0.06990246727530446, 0.17559410126081534, 0.1236582709742444, 0.1365722037319626, 0.29247117468288963, 0.2416899667254516, 0.42942459295902935, 54.79326827185494, 76.93762534005302, 63.931695393153596, 43.56182139260428, 37.982004506247385, 53.64778825214931, 52.93780047552926, 71.98640850612095, 68.44283417293003, 68.12015983036586, 59.59324714115688, 0.9225478278739112, 0.28199684673121994, 6.77069947549275, 7.839366725512913, 7.646502103124346, 0.34707291477492874, 34.69299132483346, 55.84162984575544, 61.861576897757395, 59.592795508248464, 57.54964644568307, 58.51303155081612, 55.62075356074742, 58.43523257119315, 59.49433258601597, 58.60606792994908, 54.99960197721209, 53.23574617930821, 54.21714448928833, 52.86039754322597, 51.286373479025706, 48.32228933061872, 46.83800472532, 39.96982158933367, 43.97992924281529, 45.304474762507844, 44.63728094100952, 47.080482959747314, 49.04327957970755, 49.985069683619905, 45.75385298047747, 49.23909371239798, 48.89162472316197, 48.095434120723176, 47.595552921295166, 52.568319593157085, 50.5330810546875, 50.817679268973215, 47.61623076030186, 49.93912819453648, 49.70704793930054, 49.39619248253958, 47.76623889378139, 43.557093143463135, 40.107819761548726, 38.476688453129356, 39.313849108559744, 38.04602868216378, 41.10911076409476, 37.3836430140904, 40.498530864715576, 44.36228861127581, 54.97837175641741, 47.26698998042515, 38.2178750038147, 35.12328978947231, 37.64495434079851, 35.79545157296317, 36.99713557107108, 34.598964827401296, 38.368435519082205, 35.61606992994036, 35.15651260103498, 36.09494325092861, 38.216148376464844, 36.462513378688264, 40.45397901535034, 38.57350812639509, 38.65846375056675, 40.08257695606777, 41.800887312207905, 38.77086475917271, 39.607636315482004, 42.35336984906878, 39.59755795342581, 40.01674624851772, 40.50198064531599, 40.340205737522666, 34.80335998535156, 36.92152179990496, 37.68418387004307, 35.21965435573033, 35.300979546138215, 34.26321397508894, 33.66820846285139, 33.40529210226876, 33.37658214569092, 31.793212754385813, 34.94248723983765, 33.86956378391811, 40.38384737287249, 51.808791160583496, 47.567037514277864, 39.25961147035871, 40.31261791501726, 39.755233424050466, 38.71502903529576, 40.41683047158377, 41.22562510626656, 40.94789866038731, 38.69976036889212, 41.3574914932251, 46.439032214028494, 51.5645307132176, 49.098722730364116, 48.689796924591064, 50.687608991350444, 50.400495529174805, 46.20387043271746, 49.58978319168091, 51.89690474101475, 51.91381318228585, 52.163854530879426, 49.56476967675345, 51.050621100834434, 48.943989821842735, 47.960451466696604, 52.64852959769112, 48.001536164964946, 51.975544452667236, 51.07415464946202, 48.766769068581716, 52.91270705631801, 50.96428625924246, 56.624323572431294, 57.93378107888358, 59.314068521772114, 59.74498190198626, 61.473943846566335, 59.82356602805001, 56.839002064296174, 44.592666557856965, 59.983173097882954, 66.15365982055664, 63.230149677821565, 67.18217386518205, 53.59195252827236, 0.8591096347996167, 0.9958013828311647, 6.0982397879873, 0.4626247414520809, 0.23948475505624497, 22.728302785328456, 85.40142059326172, 67.48036275591168, 81.1474415915353, 68.40637697492326, 65.68368366786412, 38.194049630846294, 40.102243832179475, 53.47369418825422, 66.85986082894462, 79.5006490434919, 7.857801164899554, 0.6772915082318443, 0.21940304977553232, 0.13191619142889977, 0.2501090663884367], [0.011211236489803662, 0.03885239269584417, 0.02620568229550762, 0.08627494052052498, 0.009620214363427033, 0.10796681618584053, 0.0681375569796988, 28.913167067936488, 58.474712235586985, 40.49784646715437, 35.78316715785435, 22.44068557875497, 25.79608358655657, 40.15972975322178, 60.467670985630576, 55.03876897266933, 55.09429897580828, 49.343250683375764, 1.319108662860734, 0.12935812797929558, 0.1309933430914368, 4.664405618395124, 5.718514221055167, 0.8979329115578106, 14.578520945140294, 61.78019959586007, 56.97015626089913, 56.23777444022042, 54.80633435930525, 51.29350233078003, 49.60180010114397, 49.19758169991629, 48.7768543788365, 50.15514421463013, 51.53385441643851, 50.061854226248606, 47.63645001820156, 45.2215063231332, 41.25024257387434, 38.84889302934919, 35.47785288946969, 39.26687581198556, 42.42057282584054, 42.68613645008632, 44.74802827835083, 48.37289653505598, 47.810703890664236, 47.498128754752024, 46.57516132082258, 45.55840710231236, 46.63585730961391, 48.94038718087332, 47.296234948294504, 48.99745273590088, 47.171198640550884, 44.16376468113491, 45.20320129394531, 45.73751776559012, 42.610418455941335, 43.92847783224923, 41.45186540058681, 37.44122968401228, 35.284018993377686, 35.07319327763149, 35.3608660697937, 33.250111034938264, 34.913620948791504, 34.382431166512625, 36.660550934927805, 42.169996465955464, 45.013501576014924, 50.05679941177368, 41.18130949565342, 36.22197716576712, 37.11231238501412, 35.17326818193708, 35.53597804478237, 38.145120416368755, 38.264528683253694, 37.489985193525044, 36.34228869846889, 35.13244751521519, 33.76099818093436, 36.38352973120553, 36.34193434034075, 35.62165628160749, 35.305388178144185, 37.386429241725374, 36.51635496956961, 37.320428303309846, 35.16236298424857, 35.184941155569895, 36.289666516440256, 35.24268763405936, 35.611359051295686, 35.42631115232195, 34.76177849088396, 37.269122804914204, 35.86748702185494, 32.76773582186018, 34.63489396231515, 33.91440398352486, 35.41596181052071, 34.3628511428833, 33.82280935559954, 34.16143676212856, 34.019255774361746, 35.36123432431902, 43.981186866760254, 47.282995155879426, 43.72211633409773, 35.87932675225394, 36.654787404196604, 35.25329753330776, 36.09106615611485, 32.967757088797434, 34.91913087027413, 35.38999291828701, 36.78212356567383, 36.58751147133963, 39.44381863730294, 47.15258094242641, 51.147472040993826, 48.937250069209504, 46.955578667776926, 48.494000162397114, 49.25517184393746, 47.61482375008719, 48.83228363309588, 50.31592205592564, 49.44969361168997, 49.571832520621165, 47.809043271201, 44.038554668426514, 46.69500732421875, 48.576999868665425, 42.06367860521589, 47.3119934626988, 44.70872926712036, 42.377910886492046, 42.13371992111206, 44.27687093189785, 48.318638052259175, 49.71364525386265, 52.81872224807739, 54.683587482997346, 54.61526584625244, 58.01476580756051, 53.23741027287075, 34.999340874808176, 55.516117164066856, 62.703504017421174, 66.80396951947893, 67.76367555345807, 40.24154479163033, 0.39911978053195135, 0.04031094103785498, 2.241236124719892, 0.303767697087356, 0.20484115901802266, 18.02157395226615, 73.49497359139579, 56.99250166756766, 72.70132950374058, 54.25667626517159, 52.53922748565674, 34.36734662737165, 19.384928635188512, 40.141594954899375, 50.81754377910069, 55.79275621686663, 2.482245249407632, 0.32901742362550324, 0.059385262695806365, 0.041443599188434224, 0.060857324062713554, 0.026411481966663684, 0.03980094733248864, 0.018710626887955835, 0.06824416840182883, 0.03294218644233687, 0.11027312278747559, 0.11373454026345696, 39.246097224099294, 68.50071961539132, 45.28687497547695, 45.65052284513201, 23.944590159824916, 30.816129275730678, 47.44432190486363, 63.7637574332101, 63.14734104701451, 60.085575648716514, 53.90807819366455, 1.1716816765921456, 0.17007124690072878, 1.1277290007897784, 4.544132300785609, 3.1548078571047102, 1.6244882877383913, 16.987079245703562, 61.991911206926616, 58.206195626940044, 59.915824208940776, 56.34895951407296, 52.204508440835134, 51.21026291166033, 52.63486596516201, 52.90344510759626, 52.356076444898335, 52.58809069224766, 51.89290257862636, 49.278757504054475, 47.6122841835022, 43.48877150671822, 41.695222582135884, 38.37300395965576, 42.042389324733186, 43.003512791224885, 44.41096421650478, 45.72763742719378, 50.28300149100167, 49.26234933308193, 49.90544332776751, 48.868890217372346, 48.32887969698225, 50.356308460235596, 50.98294564655849, 47.94652380262102, 50.38746418271746, 48.6640191078186, 47.842818464551655, 48.26477561678205, 47.37574665887015, 43.67291266577584, 45.808979988098145, 42.68432297025408, 38.46773222514561, 37.05557686941964, 36.780758244650706, 36.65017032623291, 34.853922026497976, 37.6149138041905, 35.56324625015259, 38.259522506168906, 43.66887576239449, 48.09993655341012, 50.71083681924002, 40.320302622658865, 34.91509049279349, 37.020835876464844, 35.95616340637207, 35.0180002621242, 39.32819019045149, 38.338679858616416, 38.642343929835725, 37.03597252709525, 34.65778480257307, 34.524059772491455, 37.45596333912441, 38.27255385262625, 37.743792465754915, 37.033109869275776, 38.651605878557476, 37.91053533554077, 38.691773414611816, 36.64511898585728, 37.17662838527134, 37.637092454092844, 37.41958604540144, 36.95401157651629, 35.24614436285836, 35.701157569885254, 37.739272662571494, 36.96381548472813, 33.25533608027867, 33.9555790083749, 33.86615916660854, 35.00131068910871, 35.23603820800781, 34.80735867364066, 34.657395703451975, 33.0843756539481, 35.7366281236921, 46.06484392711094, 48.03318173544747, 44.55237742832729, 37.511938026973176, 36.9352514403207, 36.347034318106516, 35.94152007784162, 35.597080503191265, 35.86727510179792, 37.18079730442592, 38.65040731430054, 37.08947018214634, 42.36581754684448, 48.59582601274763, 52.746426241738455, 50.00999982016427, 48.89047132219587, 50.827239990234375, 50.0707757132394, 48.99255425589425, 50.77568435668945, 52.81950044631958, 49.356320244925364, 50.651714597429546, 50.64413063866751, 47.62925168446132, 49.063033308301655, 50.06965357916695, 44.77033199582781, 49.41319819859096, 47.442320823669434, 45.805592741285054, 44.29773984636579, 45.22202396392822, 49.97394214357649, 53.51279170172555, 54.30175270353045, 56.02651446206229, 56.66365385055542, 59.77358068738665, 54.188462325504844, 37.958797522953574, 56.576405320848735, 63.592727524893625, 67.74488067626953, 68.13295146397182, 42.011407307216096, 0.2816883847117424, 0.7565448326723916, 3.3621316807610646, 0.28131635753171785, 0.16630613750645093, 21.767535414014542, 78.28417233058384, 62.28798089708601, 75.59403828212193, 64.04102529798234, 44.40609005519322, 16.97867018835885, 23.308145591190883, 44.24380098070417, 58.27783155441284, 67.85561411721366, 4.1800679734775, 0.3082024391208376, 0.1164035645446607, 0.053448529115745, 0.05623828174014177, 0.15316501765378884, 0.09727626626512834, 0.13983382657170296, 0.16263035046202795, 0.15787073943231786, 0.2266977219177144, 0.21954892123384134, 49.92828205653599, 75.92134012494768, 53.57721887316023, 49.45003407342093, 32.817905289786204, 34.407420362745015, 52.35112932750157, 71.04059886932373, 65.94027369362968, 64.7935916355678, 58.58021368299212, 1.5334592866046088, 0.3691355623304844, 3.240288721663611, 15.949949434825353, 11.051826391901288, 1.106524292911802, 18.80937807900565, 65.51082638331822, 61.136657442365376, 61.20743179321289, 60.251790455409456, 54.81829220908028, 53.6421080998012, 55.4185540335519, 54.1859644481114, 54.44055686678205, 55.41100481578282, 54.39080776487078, 51.708949020930696, 48.56924567903791, 45.44085053035191, 42.29430668694632, 40.37042345319475, 44.862305300576345, 44.88652672086443, 47.14025136402675, 49.387371744428364, 52.99569634028843, 50.86027520043509, 52.62256417955671, 51.665765966687886, 50.19657979692732, 51.85407257080078, 54.03136008126395, 50.68703229086739, 53.122157028743196, 50.18957601274763, 49.22956773212978, 49.43130867821829, 49.05512278420584, 46.8878059387207, 48.323609488351, 45.376190594264436, 41.2872382572719, 39.52028703689575, 38.94399649756295, 38.365843841007774, 37.11490058898926, 39.76811191013881, 37.70518480028425, 39.9854793548584, 46.70738206590925, 49.890132972172324, 53.38092531476702, 42.974990436008994, 35.47056770324707, 39.04340090070452, 36.705842767442974, 35.60231597082955, 39.10629946844918, 39.79943438938686, 39.14327083315168, 36.85966198784964, 36.282881600516184, 35.937712465013774, 38.70651401792254, 40.76247903278896, 39.64340564182827, 39.9515825680324, 41.6015157018389, 40.14965833936419, 41.66408770424979, 39.361614499773296, 39.643909386226106, 40.56175947189331, 40.33033234732491, 39.40072590964181, 37.77555962971279, 37.507591928754536, 39.718633787972585, 37.04183333260672, 33.034070696149556, 34.181867940085276, 34.63690546580723, 35.45933941432408, 34.79714134761265, 34.27820471354893, 34.327036653246196, 33.431709153311594, 37.46991532189505, 47.31703438077654, 51.23946966443743, 47.255546297345845, 39.445590427943635, 39.01592772347586, 37.979791504996165, 39.0787741797311, 36.625333990369526, 38.23267814091274, 39.95915263039725, 41.16351168496268, 40.08192729949951, 44.02845893587385, 51.771455015454976, 55.415566308157786, 51.90319980893816, 50.09148134504046, 53.18511813027518, 53.41916125161307, 51.98095709936959, 54.20191056387765, 53.8211145401001, 52.75030333655221, 54.27142381668091, 49.98296785354614, 50.55262633732387, 50.62064225333077, 53.07138654163906, 47.4069162777492, 52.764168466840474, 49.201924324035645, 46.59831271852766, 47.15580838067191, 50.42740242821829, 53.38512202671596, 54.5033929007394, 56.6434519631522, 59.42589977809361, 58.93534306117466, 63.41201182774135, 56.21582160677229, 41.47067764827183, 56.96043573107038, 66.24766199929374, 69.875670841762, 69.84715543474469, 46.36759778431484, 0.8925878469433103, 1.4064458906650543, 8.02789306640625, 0.7240671611257962, 0.3284593964261668, 23.522994313921245, 86.88204002380371, 67.0072043282645, 83.99455629076276, 69.13430500030518, 66.16233117239815, 47.92265674046108, 31.540906293051584, 56.572562967027935, 65.20464706420898, 79.33089065551758, 7.334821547780718, 0.7842986519847597, 0.29358112226639477, 0.11931506331477847, 0.18160001827137812], [0.025997434809271778, 0.057913350606603284, 0.019528882444969246, 0.08938259019383363, 0.031462033545332294, 0.12455956903951508, 0.06951351064656462, 38.41925464357649, 55.9855374608721, 44.96335642678397, 25.11571250643049, 18.622336047036306, 32.262164047786165, 36.874003069741384, 63.17334120614188, 58.91237926483154, 55.54257937840053, 53.414269719805034, 0.9341516452176231, 0.06187252780156476, 0.4728928218994822, 6.0379524401256015, 4.097964150565011, 0.7973969291363443, 2.803485223225185, 53.73113536834717, 58.055426665714805, 53.69771800722395, 51.13139043535505, 46.95925426483154, 45.70993341718401, 43.589489119393484, 44.18655824661255, 43.97734451293945, 42.82328346797398, 41.544050625392366, 40.55343552998134, 37.047840050288606, 39.691490650177, 36.8137343951634, 37.89360952377319, 42.50864471708025, 45.03245278767177, 45.2483298437936, 48.61041375568935, 49.7896203313555, 47.76573167528425, 46.87138387135097, 48.18470457621983, 49.76383556638445, 49.670180797576904, 47.84920038495745, 50.57090704781668, 48.660729135785786, 48.88995368140084, 46.35656751905169, 42.789845262254985, 46.235491684504915, 45.671655791146414, 44.36690221514021, 41.84714494432722, 36.466717038835796, 34.82609101704189, 33.58146367754255, 33.89495250156948, 33.20634780611311, 36.07338299070086, 36.89439950670515, 38.61993946347918, 40.90373591014317, 43.986064502171104, 48.2658873285566, 44.39452477863857, 37.543006896972656, 36.0940260887146, 34.74520008904593, 35.52254717690604, 34.24668768474034, 37.635515213012695, 41.04679584503174, 39.03163065229143, 37.15654809134347, 33.55158294950213, 33.844963686806814, 37.824846676417756, 35.00925595419747, 37.797105993543354, 37.235893045152935, 36.762328147888184, 35.73023578098842, 35.6815254347665, 35.79667445591518, 35.396239348820274, 35.714741298130576, 33.50950118473598, 33.79426268168858, 35.318395205906455, 35.6709155355181, 34.07325369971139, 35.25723368780953, 34.44277627127511, 33.485818249838694, 35.575805119105745, 34.94440146854946, 34.01090751375471, 34.61607129233224, 34.904129709516255, 39.16658203942435, 45.48270647866385, 45.50864062990461, 42.61548369271414, 35.47725534439087, 34.665292331150596, 34.64593812397548, 36.027691636766704, 35.25897421155657, 35.8738237789699, 35.20917647225516, 36.898467676980154, 36.92662525177002, 37.13466821398054, 40.39630549294608, 44.19173812866211, 45.6280836377825, 49.046920435769216, 47.05414233888899, 49.43297971997942, 49.35011550358364, 47.36255202974592, 40.86083773204258, 51.94327354431152, 48.66268505368914, 46.58116109030587, 47.927558694567, 49.01997184753418, 43.77086836951119, 46.15934637614659, 49.60115739277431, 46.780101912362234, 49.37464264460972, 47.87915406908308, 47.70989942550659, 47.65731198447091, 48.44063104901995, 48.76796415873936, 50.84684433255877, 52.33377620152065, 58.335303579057964, 57.8211681502206, 56.85944366455078, 49.82854413986206, 57.47601638521467, 70.3607245853969, 66.98602621895927, 32.22221885408674, 0.14920344523021153, 0.22422343040151255, 1.5478820098297936, 0.19809177118752683, 0.15861596087259905, 21.030614682606288, 74.25244535718645, 56.176432268960134, 70.84090764181954, 57.4497834614345, 62.94784436907087, 52.46187319074358, 20.987176282065256, 39.67975861685616, 51.95737838745117, 56.37833302361624, 2.5651329159736633, 0.2571791298687458, 0.120598987277065, 0.015140075535912598, 0.03948529962716358, 0.032116670560623915, 0.044111507279532294, 0.05865499616733619, 0.0968325382896832, 0.04147232496844871, 0.13449720293283463, 0.019854655589110086, 46.465598651341026, 63.09050478254046, 52.085037640162874, 35.25507974624634, 22.43026328086853, 30.867441722324916, 44.21054342814854, 66.17792987823486, 62.057502201625276, 60.6956969669887, 56.04853677749634, 1.2367726181234633, 0.2522785056914602, 0.6334717167275292, 3.0441150196960995, 6.534698699201856, 1.2351744238819395, 4.181254378386906, 58.39655889783587, 58.39175074441092, 56.77390786579677, 52.710695130484446, 49.72510978153774, 46.795728410993306, 45.16343675340925, 46.50592599596296, 45.865541798727854, 44.92379685810634, 43.25501326152256, 41.78817210878645, 40.48752839224679, 41.10542821884155, 39.17737259183611, 38.949197224208284, 45.05275889805385, 47.1868703024728, 49.09761101858956, 50.95066779000418, 50.96630123683384, 49.835749421800884, 50.10054874420166, 50.25102588108608, 51.73281260899135, 50.98261560712542, 49.35404123578753, 52.326935700007844, 48.94151626314436, 49.774959632328574, 47.26293223244803, 43.91191332680838, 47.108755179813926, 47.67490482330322, 45.953429562704905, 43.5865535054888, 37.6412752696446, 36.674544606889995, 35.36113010134016, 35.76535545076643, 35.47348942075457, 36.57510198865618, 39.333324909210205, 40.9078631401062, 43.367643560682026, 47.876055172511506, 48.499642099652974, 44.32392413275582, 38.43428707122803, 35.7131883757455, 34.49214669636318, 33.92909247534615, 34.58084739957537, 38.370801380702424, 41.62601852416992, 39.26260961805071, 37.462081227983745, 34.72933040346418, 34.95641837801252, 39.98085880279541, 38.96065827778408, 39.25734288351876, 39.78772667476109, 38.92905787059239, 38.308917249952046, 36.17315912246704, 36.78412464686802, 38.21764571326119, 36.478445598057334, 33.639039925166536, 34.000217710222515, 36.005155154636924, 35.90114409582955, 33.86340420586722, 36.15094920567104, 35.51699904033116, 33.55573797225952, 35.14247376578194, 34.18695749555315, 34.73059844970703, 34.45843056270054, 34.194051606314524, 41.14740923472813, 49.11717367172241, 46.952695165361675, 44.422380106789724, 37.65765912192208, 36.60509736197335, 36.45875440325056, 37.64336320332119, 36.17669922964913, 38.02009105682373, 37.285534449986045, 38.10091597693307, 37.93963439123971, 38.31620591027396, 42.239096300942556, 46.726138728005544, 48.54393686567034, 50.795931407383506, 48.64769778932844, 49.75059577396938, 52.811933858054026, 48.441666330610005, 41.83735145841326, 53.43715361186436, 51.34857027871268, 48.47385038648333, 49.83732318878174, 51.67723396846226, 44.895903314862935, 46.71660579953875, 52.772349970681326, 47.706651142665315, 51.3786073412214, 50.408187185014995, 48.497738293239046, 50.00163071496146, 50.05634430476597, 50.82548904418945, 53.515115874154226, 54.87445102419172, 59.35326331002371, 58.3579547064645, 56.44526849474226, 51.65489203589303, 60.528168950762065, 70.82478782108852, 69.20179285321916, 35.22263860702515, 0.10462096000888518, 0.9718684213502067, 2.906205654144287, 0.3355892795537199, 0.22208772785961628, 21.384675775255474, 81.05006953648159, 60.96023573194231, 78.1065833227975, 61.42024121965681, 66.98211438315255, 42.071391105651855, 20.48055533000401, 49.42154993329729, 56.92904029573713, 68.04407010759626, 4.669570301260267, 0.25224197336605614, 0.2285506517759391, 0.06333886911826474, 0.03544012151126351, 0.1223865199301924, 0.23058829243694032, 0.19579589366912842, 0.18528203426727227, 0.12784411279218538, 0.21876509115099907, 0.45148246362805367, 57.18089859826224, 72.34255926949638, 58.40320832388741, 36.767525400434224, 26.79353744643075, 43.34498201097761, 50.23805359431675, 74.36311626434326, 69.1682538986206, 68.65508774348667, 62.570168086460654, 1.4076276272535324, 0.4436133573097842, 2.9837214946746826, 13.747261915888105, 12.416898148400442, 1.2525176703929901, 5.807042522089822, 61.716019085475374, 61.3477715083531, 59.76852934701102, 55.73629515511649, 50.95475680487496, 48.83683122907366, 47.734829562050955, 48.1121688570295, 48.40732485907418, 47.32839468547276, 44.706905364990234, 42.6935328074864, 41.61860132217407, 45.09949595587594, 41.06895365033831, 41.04595511300223, 46.934615952628, 48.921894550323486, 50.82912642615182, 52.398085253579275, 53.875383445194785, 51.88329321997506, 52.35432897295271, 51.660120555332725, 54.341951506478445, 54.286814076559885, 52.445798533303396, 52.994042669023784, 51.05406045913696, 51.70520394189017, 49.61778095790318, 46.161361353737966, 50.9840851511274, 49.6687216758728, 47.766763482775005, 44.92861195972988, 39.491768155779155, 38.1822828565325, 36.785806110927034, 36.942109312329976, 36.020583629608154, 40.149262292044504, 41.1576543535505, 41.05546719687325, 45.166261196136475, 50.39586802891323, 50.91005556924002, 46.70327568054199, 39.803398336683, 35.66526665006365, 33.7830239704677, 34.98975583485195, 34.23850270680019, 39.019756180899485, 42.694033077784944, 40.07996443339756, 38.051007066454204, 36.7434846333095, 36.56512437547956, 41.84755836214338, 41.3624073437282, 42.21770279748099, 41.94225188664028, 42.28505516052246, 40.45186676297869, 39.23392745426723, 40.00409357888358, 40.051994459969656, 38.36408594676426, 34.91504185540335, 35.29137366158621, 36.086997985839844, 35.896141392844065, 33.90637534005301, 35.485509804316926, 36.07512698854719, 33.6241568837847, 35.758963108062744, 35.94557087762015, 34.91395098822457, 35.69250358854021, 33.77464096886771, 40.58868721553257, 50.67685317993164, 49.21130091803414, 46.79367521830967, 39.512612751552034, 38.15718943732125, 37.013185909816194, 40.05411713463919, 38.40300280707223, 39.56829908915928, 38.65962062563215, 41.038937432425364, 41.553930963788716, 40.34842198235648, 44.5545973777771, 48.31142234802246, 52.18092278071812, 54.159359795706614, 51.87887416567121, 53.93313339778355, 56.224565914699006, 51.19577939169747, 45.03291136877877, 55.355332374572754, 53.65721695763724, 51.79963343484061, 51.91766595840454, 53.15140894481114, 48.09602124350411, 49.965218680245535, 55.18413570949009, 50.60120119367327, 54.18855960028512, 53.14631244114467, 52.83837522779192, 54.71478142057146, 52.81911482129778, 53.564774649483816, 55.931549957820344, 57.866817814963206, 62.16734627314976, 60.76230934688023, 57.485966205596924, 53.81192554746355, 61.2396297454834, 73.01078837258476, 68.39512089320591, 38.39182662963867, 0.4380448918257441, 1.849405275923865, 6.606202610901423, 0.9175898539168494, 0.34354529263717787, 26.109787804739817, 89.01349026816231, 66.68273040226528, 84.1380226952689, 70.33646842411586, 75.8204036440168, 64.52784388405937, 35.30312653950283, 57.10646602085659, 65.75505556379045, 79.9968546458653, 7.869733827454703, 0.5586570969649723, 0.4052277627800192, 0.19579855352640152, 0.2181424674178873], [0.014251335457499539, 0.02877954373668347, 0.047092694988740344, 0.06292783974536828, 0.0011752980332987914, 0.08159255356128726, 0.4061928295663425, 50.24867044176374, 53.34287003108433, 36.389334951128276, 32.39424235480172, 23.972902332033428, 29.894422939845494, 39.14387880052839, 54.058558804648264, 62.05133220127651, 53.06744343893868, 54.183060101100374, 1.6859347905431474, 0.05392589885741472, 0.7424224561878613, 0.3491875013070447, 2.3292265917573656, 1.4186773257596152, 0.10382411562438522, 36.62174524579729, 63.58593218667166, 52.693421908787315, 54.99535662787301, 44.25204849243164, 45.07602841513497, 41.01378147942679, 43.064309528895784, 39.770324911390034, 41.401136602674214, 42.624043873378206, 40.980061871664866, 41.209018911634175, 40.6388566834586, 43.6053101675851, 45.6837352343968, 45.56489324569702, 48.52980422973633, 49.88275398526873, 45.8859486579895, 43.16346379688808, 44.14882952826363, 45.72837046214512, 49.08788701466152, 50.8926225389753, 48.22824546269008, 50.48885924475533, 48.25249467577253, 47.77577529634748, 45.81154039927891, 42.81886441367013, 45.01810128348214, 46.839623655591694, 46.160426821027485, 45.38455622536795, 39.99329260417393, 34.94165345600673, 33.6862598827907, 32.90414980479649, 34.57537916728428, 33.98059947150094, 34.92506810597011, 33.70874425343105, 34.80677849905831, 36.7196557862418, 41.49671949659075, 45.54958636420113, 48.162963662828716, 40.49941676003592, 36.34702042170933, 37.78842074530465, 35.945789745875764, 34.136437143598286, 34.399023464747835, 41.356570856911794, 44.19365235737392, 40.582444259098594, 34.91855069569179, 30.296900817326136, 36.323066507067, 37.794483048575266, 36.465935366494314, 37.63263518469674, 38.282545362200054, 37.61389241899763, 36.434713636125835, 35.89692306518555, 34.06011813027518, 30.684686728886195, 31.799097878592356, 33.96620280402047, 36.602015835898264, 35.03190360750471, 32.96233401979719, 35.21003457478115, 34.08834866115025, 34.35171665464129, 35.772786549159456, 35.13918726784842, 33.552319458552766, 36.06193930762154, 34.52751997538975, 44.73732457842146, 46.577141557421, 45.11471251079014, 37.13129138946533, 34.71331827981131, 35.44457796641758, 34.30346488952637, 34.539974621364046, 35.33725956508091, 35.25385686329433, 36.62469823019845, 37.25285359791347, 36.40904351643154, 36.66112763541085, 35.45278031485421, 38.511255741119385, 40.46881341934204, 45.345337118421284, 45.690402030944824, 48.75031573431832, 47.0704254422869, 51.95841714314052, 31.37083523614066, 28.132378884724208, 50.192650590624126, 49.3014920098441, 47.83212866101946, 48.583850792476106, 45.644884381975444, 50.43931858880179, 50.50189406531197, 48.05955014910017, 50.75003855569022, 50.150780745915, 48.78985445840018, 48.081704480307444, 46.918909549713135, 45.596340792519705, 46.96701192855835, 52.542097091674805, 56.325641359601704, 56.53007125854492, 54.030140672411235, 49.940093994140625, 51.9395249911717, 59.362747601100374, 66.03142711094448, 25.720567090170725, 0.18209627164261682, 0.6109962484666279, 1.882745772600174, 0.03683852111654622, 0.23538276659590857, 25.6936480317797, 72.88029425484794, 59.69202273232596, 69.52901131766183, 63.27561174120222, 45.981795583452495, 57.00518560409546, 25.541836840765818, 33.09072630746024, 55.682220799582346, 57.264169284275596, 3.386057368346623, 0.23482593361820492, 0.06000927742570639, 0.04217483941465616, 0.02143500605598092, 0.05121531769899385, 0.008953231403471103, 0.04989129231710519, 0.08852631971240044, 0.10103994395051684, 0.06569656117686204, 0.7494333514145443, 57.660327775137766, 60.38781533922468, 43.16097634179251, 39.43329906463623, 22.78402212687901, 22.23086735180446, 44.44681692123413, 58.17457437515259, 66.22046675000871, 58.12449870790754, 58.458675793239046, 2.3211584304060255, 0.14144378661045007, 0.528246568781989, 1.2829766188349043, 4.12887625183378, 0.7357719987630844, 0.19162088127008506, 42.45276730401175, 63.67718287876674, 53.998505524226594, 56.41482148851667, 47.261660712105886, 46.16389397212437, 43.15888840811593, 43.396728719983784, 42.517882347106934, 42.54034239905221, 45.72426755087716, 42.79601526260376, 42.242004122052876, 41.61767373766218, 44.21636254446847, 47.22940370014736, 48.63499995640346, 50.26358822413853, 49.77972609656197, 47.91021599088396, 47.387527329581125, 48.320027691977366, 45.92847858156477, 48.925066402980256, 51.6380808694022, 48.821941239493235, 52.015795367104666, 50.3518511908395, 48.93339729309082, 48.32663542883736, 44.06502730505807, 45.98492922101702, 50.01882403237479, 48.93923030580793, 47.72333376748221, 42.758227484566824, 35.36089733668736, 36.4774763243539, 35.44607877731323, 36.13320350646973, 36.68079798562186, 36.799716404506135, 34.56833369391305, 36.12234347207205, 38.43441561290196, 43.97472504207066, 48.52079241616385, 49.17159196308681, 40.3745367867606, 36.786674635750906, 36.86671788351876, 36.17397206170218, 33.123216084071565, 33.39376156670706, 41.328677313668386, 45.125117438180105, 40.584942136492046, 36.29490545817784, 32.42160088675362, 37.59191526685442, 38.33912106922695, 39.219996316092356, 38.393122468675884, 41.51000445229666, 38.692329270499094, 36.758607387542725, 39.00497041429792, 36.76519775390625, 32.19751800809588, 32.925421714782715, 33.600595542362754, 35.589288098471506, 34.9895612852914, 34.30715785707746, 34.96026073183332, 34.864066396440776, 34.31267472675869, 36.339530263628276, 34.557338169642854, 33.4158742087228, 35.75549595696585, 35.36480917249407, 46.11913020270211, 47.61805118833269, 46.15095295224871, 38.82697146279471, 36.68022475923811, 37.47872216360909, 36.353127888270784, 34.73520163127354, 37.255469594682964, 37.69174351011004, 38.591955593654085, 37.81062718800136, 37.810429164341514, 38.70698996952602, 37.974535192762104, 41.38272040230887, 42.40619005475725, 46.89190190179007, 46.81973443712507, 50.11749540056501, 49.8484194619315, 53.280558586120605, 35.54528863089425, 30.214307580675396, 50.96014860698155, 51.579205308641704, 49.3682016645159, 51.227827957698274, 46.85602487836565, 52.04553018297468, 51.348653657095774, 50.266318866184776, 52.20128100258963, 51.23619358880179, 52.55415569032942, 48.90315178462437, 49.68077680042812, 47.60800061907087, 49.706248896462576, 55.50314140319824, 58.91016973767962, 57.41214854376656, 55.864392144339426, 51.976941040584016, 55.124377727508545, 62.94002069745745, 68.47123146057129, 27.333719934735978, 0.1173146063727992, 0.6231290517108781, 4.039690043245043, 0.38749628567269867, 0.29514503691877636, 26.93157730783735, 79.33649785178048, 62.847498485020225, 74.36344977787563, 64.98887075696672, 56.397725445883616, 60.37049348013741, 31.915577479771205, 45.20272881644112, 61.55555738721575, 68.41226904732841, 4.67871847323009, 0.29418917106730597, 0.09942976678056376, 0.03440200025215745, 0.04697088098951748, 0.2421092199427741, 0.09057076607963868, 0.12340282968112401, 0.17911583371460438, 0.21063696087471076, 0.1868039204605988, 0.9857393056154251, 68.72215175628662, 68.04473713466099, 50.760825634002686, 42.970352513449534, 32.037976946149556, 42.423265252794536, 52.10279376166207, 63.96822902134487, 71.16977282932827, 62.567777906145366, 64.79706573486328, 2.7804352257932936, 0.447699278060879, 3.256642175572259, 5.2835787023816785, 7.908612472670419, 2.798421072108405, 0.8991255047065871, 45.27266590935843, 66.02046980176652, 56.1148156438555, 60.450592313494, 47.514634200504844, 49.4581287247794, 46.038426876068115, 46.35365274974278, 43.1684421811785, 44.645309584481375, 46.69361768450056, 43.48864991324288, 44.42996059145246, 45.10648584365845, 47.29276084899902, 49.936265536717, 50.163690498897004, 50.28671530314854, 52.94166367394583, 52.37141806738717, 49.6834066935948, 51.58435392379761, 47.293156896318706, 51.17145722252982, 53.28401531491961, 51.29113646915981, 54.264225482940674, 52.3764694077628, 51.448263032095774, 49.798218727111816, 47.984377588544575, 48.75744458607265, 52.58200754438128, 50.890833377838135, 50.06917415346418, 44.364053453717915, 37.20403902871268, 37.31959451947893, 36.01911408560616, 39.02786472865513, 38.04227665492466, 39.20803846631731, 36.35600791658674, 38.71556404658726, 39.699606146131245, 46.328361306871685, 50.74755457469395, 51.44948591504778, 41.03174952098301, 37.15780224118914, 37.15972341809954, 37.10997084208897, 33.20503112248012, 34.720335960388184, 41.668958391462056, 45.94330256325858, 43.60167973382132, 37.188680035727366, 31.78083106449672, 39.92249046053205, 41.31332179478237, 41.560170446123394, 41.7831381389073, 43.84166703905378, 41.99101434435163, 40.203270639692036, 39.8804851259504, 37.89593022210257, 31.977249690464564, 33.85537208829607, 33.88314403806414, 37.01951919283186, 35.0488189969744, 33.32970264979771, 35.34689671652657, 34.89030279432024, 34.94618368148804, 37.085982186453684, 34.9203120640346, 32.962476457868306, 36.120905194963726, 36.80118594850813, 48.3824850491115, 51.12052692685808, 49.67929336002895, 40.76173904963902, 38.71298973900931, 40.22004359109061, 37.710590498788015, 36.351981435503276, 40.362168993268696, 39.327867099217, 39.43149253300258, 40.798540183476035, 40.607391766139436, 39.21598720550537, 39.69569778442383, 43.1357786996024, 44.82707445962088, 50.6607403073992, 49.27349076952253, 53.10482127325875, 52.50622354234968, 56.19305235998971, 34.80160903930664, 32.71234130859375, 55.59213393075125, 52.103064741407124, 52.142356804439, 54.10442386354719, 51.63972759246826, 54.87739706039429, 52.844705036708284, 50.94515092032296, 54.82989222662789, 54.74539518356323, 56.149935313633506, 52.45229509898594, 52.6257256099156, 51.83943619046892, 51.043436663491384, 57.598155294145855, 62.11055169786726, 60.970407894679475, 59.04664625440325, 52.164549350738525, 57.07086345127651, 65.14039012363979, 69.03247220175606, 31.452907357897075, 0.3878233124102865, 2.9761119144303456, 6.911653671945844, 1.0984989064080375, 0.5367036664060184, 30.66021169934954, 85.35464532034737, 69.36734063284737, 79.62029007502964, 71.38881478990827, 60.78198664528983, 69.94115761348179, 38.13404498781477, 52.04360900606428, 69.19565759386334, 80.65981701442173, 6.951309212616511, 0.4983668178319931, 0.26643339757408413, 0.11360013604696308, 0.14011787490120955], [0.033091596460768154, 0.0749429375199335, 0.057383102630930286, 0.07014093840760843, 0.04772191408223339, 0.03755460626312664, 0.15791077299841813, 39.615421772003174, 50.70777266366141, 42.900363309042795, 18.052802630833217, 45.76830175944737, 58.87601934160505, 37.66697665623256, 56.053000995091026, 61.26178755078997, 53.13387516566685, 57.39885663986206, 5.887186084474836, 0.4030270294419357, 0.2995239762323243, 0.8235919092382703, 5.270096591540745, 0.638793439737388, 0.08595942852220365, 28.58949565887451, 69.92769200461251, 50.45397233963013, 56.91149956839425, 50.33092321668352, 52.89605222429548, 48.62813513619559, 48.85445533479963, 44.61358410971505, 42.25781127384731, 38.16435303006853, 39.80608034133911, 39.4064998626709, 48.24589736121041, 46.8919609614781, 49.46063355037144, 50.045612812042236, 46.5686855997358, 42.668470655168804, 46.46244069508144, 48.67451088769095, 48.32063913345337, 48.6196722303118, 46.6870551109314, 48.49363190787179, 48.45013965879168, 46.748570987156455, 47.70354529789516, 44.88351815087454, 42.49169111251831, 44.95281948362078, 47.85069077355521, 47.670728955950054, 48.10537004470825, 44.42506905964443, 37.27793312072754, 32.6686475617545, 33.20799452917916, 32.09359727587019, 33.995159421648296, 32.749906744275776, 34.8841849054609, 32.489929471697124, 34.82953037534441, 32.75429105758667, 37.52569893428257, 45.14865793500628, 46.99255003247942, 40.0418118749346, 39.94774716241019, 38.42353473390852, 36.09931366784232, 35.40379204068865, 36.21442794799805, 39.732651778629844, 43.892288139888215, 44.56760440553938, 40.444685799734934, 33.16190365382603, 35.08844804763794, 38.479217597416465, 36.21670348303658, 36.668558733803884, 39.47095830099923, 36.13621555055891, 35.619418961661204, 37.798759664808, 32.06564119883946, 33.32555457523891, 32.93262699672154, 36.12060989652361, 35.24931621551514, 34.50169352122715, 34.20872967583792, 35.53945214407784, 34.40239334106445, 31.941216332571848, 35.57541254588536, 33.72189024516514, 34.63279560634068, 34.11596080235073, 37.12022985730852, 46.75624179840088, 45.954655919756206, 43.07463455200195, 35.09199857711792, 35.85956607546125, 35.550965309143066, 34.68442072187151, 33.64399746486119, 35.08143036706107, 34.325612272535054, 35.229024001530235, 36.448450224740164, 37.85420628956386, 37.44898039954049, 37.46981457301548, 37.4415215083531, 37.40602663585118, 38.69759600503104, 40.506333691733225, 41.94091088431222, 47.13511317116873, 48.04137713568551, 53.93530123574393, 37.555207933698384, 26.613290752683366, 41.53436483655657, 46.76926967075893, 50.057257992880686, 45.044921330043245, 47.97486897877285, 49.52493218013218, 53.11019570486886, 54.39193337304251, 54.49565955570766, 55.45318385532924, 52.33956752504621, 49.60094199861799, 45.70308596747262, 45.32006652014596, 48.51410130092076, 52.97723845073155, 55.81369113922119, 61.81313405718122, 59.514537947518484, 55.09345129558018, 45.62784392493111, 57.40699645451137, 18.7621841771262, 0.5290220528841019, 0.5171014411108834, 2.422306831393923, 0.2004263794847897, 0.14582942984998226, 24.193669182913645, 73.41132422855922, 58.12947709219796, 68.92881202697754, 59.939552307128906, 54.434564045497346, 41.05400807516915, 19.962674822126115, 33.89955915723528, 56.11783463614327, 54.334972040993826, 2.92373965041978, 0.09394633530506066, 0.07117382476904563, 0.08780659083276987, 0.034127848355897834, 0.027370945750070468, 0.06323824237499918, 0.04702227323182991, 0.044481186728392325, 0.04536473431757518, 0.12587572341518743, 0.260763233261449, 50.272801535470144, 58.593804359436035, 44.7371369770595, 22.5765871320452, 26.795149428503855, 46.77533197402954, 42.149440220424104, 60.41075134277344, 66.57399109431675, 56.9249130657741, 63.16252286093575, 6.171325717653547, 0.41874855011701584, 0.37884007873279707, 1.4899824538401194, 2.747006790978568, 0.7800937976155962, 0.036373904440551996, 31.80005325589861, 69.2053086417062, 52.32015425818307, 59.65800435202462, 53.4673296383449, 54.851334367479595, 50.002572195870535, 50.59760202680315, 46.39125987461635, 43.28689159665789, 40.84259871074131, 41.08453151157924, 39.63422359739031, 49.51595163345337, 48.308809825352256, 52.84028250830514, 51.493342944553916, 47.89574984141758, 46.6028915813991, 47.680567605154856, 49.709017753601074, 48.633030142102925, 49.31683710643223, 48.09264094488961, 50.31936141422817, 48.88078553336007, 47.79005037035261, 48.31286757332938, 44.4416127204895, 44.606757504599436, 45.82610034942627, 47.94833033425467, 48.80821507317679, 51.42531313214983, 45.30048997061593, 41.15203673498971, 35.5812212399074, 36.005943775177, 34.060416902814595, 35.19837897164481, 33.98748861040388, 36.153405393872944, 35.352052279881065, 35.84800427300589, 33.96242993218558, 39.598805155072895, 46.41970927374703, 49.35499313899449, 40.781433718545095, 37.762900011880056, 38.08944797515869, 35.07017081124442, 34.20578016553606, 36.21728713171822, 40.02557740892683, 44.10683809007917, 45.132819516318186, 40.69803449085781, 34.222195284707205, 36.170744623456685, 40.568881375449045, 37.00645310538155, 37.62558971132551, 41.28996889931815, 38.07287652151925, 38.62266663142613, 37.17185844693865, 32.85207653045654, 32.89351906095232, 34.384258542742046, 34.77264199938093, 34.405850069863455, 33.95377595084054, 35.0585812159947, 34.453966345105854, 34.873429094042095, 33.462441035679404, 35.476692540305, 33.914098262786865, 35.467038018362864, 34.622630391802105, 38.31397206442696, 48.59687519073486, 48.35941355569022, 45.799565179007395, 35.97716086251395, 36.153961249760215, 36.18197291237967, 36.027410234723774, 34.729042053222656, 37.26290764127459, 36.63619749886649, 37.49459184919085, 38.473283835819785, 38.16031960078648, 39.44885608128139, 37.58504697254726, 38.37161431993757, 39.48171411241804, 40.22205509458269, 42.586037227085654, 43.89818716049194, 51.449180194309776, 49.42081342424665, 56.962374278477256, 43.275955132075715, 28.655284677233013, 42.63668612071446, 47.47075285230364, 51.273706912994385, 48.18873453140259, 49.46315227236067, 50.58701992034912, 54.69795635768345, 55.68481247765677, 56.30882671901158, 57.47390760694231, 55.17023583820888, 51.539048194885254, 47.42993218558175, 47.6682310785566, 50.63361801419939, 56.02149438858032, 58.01664529527937, 64.72640255519322, 62.27710696629116, 57.16654709407261, 50.551306179591585, 59.86495644705636, 20.345537934984478, 0.5990393214992115, 1.321313630257334, 3.8787098356655667, 0.12068091359521661, 0.171000799164176, 25.906229904719762, 79.19796466827393, 63.105408668518066, 74.11392607007707, 64.08891228267125, 58.80845505850655, 52.73900556564331, 22.184607982635498, 37.858434268406455, 62.902868679591585, 65.76928547450474, 3.8070530635969977, 0.3327811759497438, 0.11839897318610124, 0.05891967232206038, 0.06885708908417396, 0.09333620340164218, 0.14441834842520102, 0.2506856583058834, 0.18800599952893599, 0.18705663404294423, 0.21597909421793052, 0.5431671738624573, 62.04169504983084, 64.43451568058559, 55.21739673614502, 28.25532031059265, 57.13532883780343, 67.0374984741211, 51.408415113176616, 66.29336724962506, 71.40303080422538, 63.389999934605186, 68.2011410849435, 7.688785365649632, 0.790171453995364, 2.290007701941899, 2.6519424063818793, 11.559131741523743, 2.0579333092485155, 0.39858612631048473, 34.69337347575596, 72.29325485229492, 54.31071240561349, 62.17168194907052, 55.25884968893868, 56.79304320471627, 52.44652114595686, 53.9106559753418, 50.136439664023264, 45.69707577569144, 44.011199610573904, 44.1756843158177, 42.4974615914481, 53.14291477203369, 51.69973223549979, 54.26809910365513, 54.72865349905831, 50.76109313964844, 50.675776209150044, 49.91604280471802, 50.586748940604075, 49.07862506593977, 51.330379894801546, 50.57211603437151, 51.717575209481375, 52.383362020765034, 50.140205587659565, 51.79516921724592, 48.484328269958496, 48.460770402635845, 47.74867384774344, 50.204115118299214, 50.73610394341605, 53.78722817557198, 48.17385149002075, 43.94162729808262, 36.65467275891985, 37.5651091166905, 35.17554719107491, 36.696695463997976, 35.9595992905753, 37.24712133407593, 37.410115650721956, 36.76096282686506, 34.97204835074288, 41.38798018864223, 49.91187735966274, 50.318600586482454, 42.356222084590364, 40.06257656642369, 40.01912600653512, 36.8055876323155, 33.80358716419765, 35.90952362333025, 41.211787768772666, 46.11877237047468, 46.21640498297555, 44.848540919167654, 35.26578344617571, 37.29851368495396, 42.437422207423616, 39.38814967019217, 37.834442138671875, 43.03788552965437, 41.22005612509591, 40.95356144223894, 38.822674001966206, 31.90917124067034, 35.03488438470023, 35.34054258891514, 36.48378528867449, 35.531138624463765, 34.94204255512783, 34.72503294263567, 34.921434198107036, 35.17748573848179, 31.56976910999843, 36.1904080254691, 33.44914218357631, 35.78185394832066, 35.035784176417756, 39.055324009486604, 51.12501546314785, 49.26758827481951, 48.81775147574288, 39.213402475629536, 38.697147846221924, 39.48077263150896, 37.534898349217, 36.37837069375174, 39.1071332522801, 37.62666320800781, 38.97737216949463, 42.08400903429304, 40.93308857509068, 41.68971960885184, 39.78406844820295, 40.8188601902553, 41.629975523267476, 43.081572328295024, 44.49547515596662, 46.82029029301235, 52.510521003178184, 53.925900323050364, 57.153189182281494, 38.10122864586966, 30.555276530129568, 47.19628163746425, 48.682327611105784, 54.37583439690726, 49.61418873923165, 52.29654080527169, 54.02249070576259, 58.00750494003296, 56.84267766135079, 58.25844260624477, 60.57395757947649, 57.07190568106515, 54.42090736116682, 49.59851360321045, 50.42444944381714, 53.30107661655971, 59.826400893075125, 61.897617203848704, 67.3035797391619, 63.02307946341378, 56.82472004209246, 52.93529912403652, 65.2401454108102, 23.24317298616682, 0.5976178720593452, 2.7733089796134403, 5.683968211923327, 0.8143209495714733, 0.2639383157449109, 29.358876637050084, 84.84665557316372, 68.57153565543038, 81.15490395682198, 70.77847112928117, 69.01449026380266, 57.59648425238473, 31.52601977757045, 50.327789579119, 71.16078186035156, 78.78667300088065, 5.801836584295545, 0.6869774056332452, 0.25178282228963716, 0.16998690499791078, 0.1586528867483139], [0.07580122325037207, 0.06203319810863052, 0.0012802436519580493, 0.04262628911861351, 0.023495584593287537, 0.07963671029678412, 0.0512513411231339, 32.601750305720735, 55.56618935721261, 33.583808694567, 24.564444167273386, 77.74326201847622, 81.0370764051165, 41.81591279166085, 49.40250492095947, 64.01137733459473, 49.85567338126046, 62.63013798849923, 10.017838903835841, 0.3631750935954707, 0.5357766247221402, 0.32489198499492233, 1.2764003659997667, 0.3993578648992947, 0.0855555169816528, 23.800725970949443, 70.31144101279122, 52.135693481990266, 55.29310778209141, 53.42181198937552, 57.50691849844796, 52.11984116690499, 51.97206340517317, 43.42467090061733, 42.23595571517944, 42.51914691925049, 46.38206740788051, 46.88968890053885, 50.09066840580532, 51.19848224094936, 51.85544831412179, 44.155906268528526, 44.577495166233604, 49.403321334293906, 52.49685042245047, 46.936960969652446, 47.553926263536724, 47.373808111463276, 50.097870213644846, 48.91466842378889, 48.735450063432964, 46.10326746531895, 43.27790410178048, 41.48967054912022, 44.103443895067485, 46.774828229631694, 48.953449794224326, 48.35172189985003, 47.17585045950753, 40.88398218154907, 37.679299286433626, 35.079234736306326, 34.82345070157732, 33.22920390537807, 33.033170904432026, 33.46973664419991, 31.628807953425817, 33.17918382372175, 36.94132416588919, 37.22302845546177, 39.39976011003767, 41.76477057593209, 47.387603759765625, 40.20058168683733, 36.347402572631836, 38.78627238954817, 36.87833527156285, 37.39693144389561, 36.11739635467529, 41.82648794991629, 40.88412461962019, 43.71128061839512, 44.49113253184727, 37.108852182115825, 36.18600286756243, 38.7654138973781, 37.91668449129377, 36.367430755070274, 41.48654038565499, 35.25316204343523, 37.418071338108604, 36.14979927880423, 32.86114740371704, 35.93812935692923, 36.01554618562971, 32.861449650355745, 37.66046966825213, 35.18978404998779, 33.52812583105904, 36.05454989842006, 36.14155524117606, 33.49656711305891, 34.04620436259678, 35.48920277186802, 34.520116669791086, 36.167683941977366, 40.826489312308176, 47.61784621647426, 45.47878074645996, 40.950785636901855, 36.50666570663452, 37.46061863218035, 34.82632725579398, 35.70708090918404, 34.28188725880214, 34.17639970779419, 34.47102069854736, 35.17049585069929, 35.1240679877145, 36.856663840157644, 37.94716623851231, 39.39952734538487, 41.57468523297991, 39.3364793913705, 38.23168107441494, 38.93018000466483, 40.32189723423549, 42.163916792188374, 47.431551115853445, 44.851688453129356, 56.15037999834333, 48.82817029953003, 33.32143429347447, 35.49070010866438, 40.57684053693499, 45.22715173448835, 44.825313091278076, 46.67964833123343, 46.80046360833304, 48.78813130514962, 49.22773340770176, 51.305196149008616, 52.41516045161656, 53.41827188219343, 50.13119724818638, 46.8090237889971, 46.713996750967844, 49.73971836907523, 54.92103174754551, 55.12815407344273, 55.426902294158936, 58.46564483642578, 44.45419938223702, 51.08213465554373, 13.072770748819623, 0.8580579598035131, 0.8821581665958677, 2.3030403511864797, 0.18432086227195604, 0.20251239969262055, 26.003266709191458, 70.84979438781738, 58.55476243155343, 66.10846178872245, 62.036122594560894, 43.1292439188276, 25.816339322498866, 37.218880380902974, 42.61443451472691, 56.34707655225481, 49.46268674305507, 1.1054205064262663, 0.08153502057705607, 0.1000951382198504, 0.03366094162421567, 0.02233849578936185, 0.025946700745927434, 0.0933517147121685, 0.05186930671334267, 0.08975885821772472, 0.021336857661870972, 0.06845572883529322, 0.10723208489694766, 41.468631403786794, 59.683643204825266, 38.962919916425435, 23.804000309535436, 70.06163242885044, 76.24079745156425, 45.817710399627686, 57.45772525242397, 69.0397539138794, 56.969937392643516, 68.61807468959263, 11.805336815970284, 0.41124639553683145, 0.1862938114042793, 0.9546795551265989, 5.2287309254918775, 1.340858587196895, 0.08979854573096548, 26.248155968529836, 71.03256675175258, 54.49459995542254, 60.43165152413504, 54.61834389822823, 58.051355021340505, 52.62035812650408, 54.62902675356184, 44.231582573481965, 45.45874214172363, 43.95657287325178, 47.982644012996126, 49.42207799639021, 52.37787641797747, 52.06063209261213, 51.82778753553118, 46.77857330867222, 48.29819992610386, 51.22059140886579, 50.487327166966026, 47.20412615367344, 49.652581010546, 47.934263706207275, 52.44646903446743, 49.227083751133506, 51.54268210274832, 48.74065426417759, 46.8383069719587, 44.089346000126426, 44.86803061621529, 48.25686509268624, 51.650243691035676, 49.81079149246216, 48.01118721280779, 44.21370138440813, 39.23942347935268, 34.80143533434187, 36.39174597603934, 35.256535393851145, 35.21589885439192, 35.63551098959786, 34.005543504442485, 33.966140270233154, 38.176866735730854, 38.549182483128135, 40.755999837602886, 43.541744572775706, 50.24169792447771, 42.460952281951904, 35.51117297581264, 37.712845189230784, 36.989683628082275, 37.74135364804949, 36.50584234510149, 41.541931424822124, 41.64114127840315, 46.64323282241821, 44.14587654386248, 36.85855027607509, 35.674730096544536, 40.01305328096662, 40.70677532468523, 38.91288941247122, 43.07114308220999, 39.35935286113194, 39.50117254257202, 37.3398311478751, 32.26196255002703, 35.78092636380877, 35.03504766736712, 33.10921893801008, 36.6346549987793, 33.66761439187186, 33.1947477885655, 33.69764798028128, 35.79018831253052, 33.19471999577114, 33.87832546234131, 34.58842093603951, 35.027672154562815, 36.11641665867397, 42.70427124840872, 48.967634541647776, 45.348543712071006, 41.16193791798183, 38.827843461717876, 38.278532777513774, 37.1536784853254, 36.41490779604231, 36.53992325919015, 35.11429534639631, 36.58065707342965, 37.09842988422939, 36.696796212877544, 38.96577215194702, 40.734245027814595, 43.03741305215018, 43.65608760288784, 41.69407960346767, 40.0588002204895, 40.47036286762783, 42.43289545604161, 43.89761740820748, 50.434666769845144, 46.54292515345982, 59.266313552856445, 53.25880030223301, 35.113114152635845, 37.91170610700335, 42.02999373844692, 44.52921213422503, 45.9442093031747, 46.547278199877056, 48.39306368146624, 50.46031257084438, 51.1802327973502, 52.93944719859532, 53.596503598349436, 55.08487721851894, 53.150429248809814, 49.968348843710764, 49.70198965072632, 51.924211161477224, 57.66704668317522, 57.50315604891096, 59.089245659964426, 61.67239829472133, 46.49182462692261, 54.793313435145784, 15.169427020209175, 0.7638275761689458, 1.0736769012042453, 7.165697182927813, 0.2869912715894835, 0.3633965402841568, 29.215403284345353, 76.56183896745954, 63.295622553144185, 71.17354570116315, 67.3458525793893, 50.17839983531407, 33.010443346840994, 38.4264668737139, 48.698405742645264, 65.03857816968645, 60.205098560878206, 2.593290273632322, 0.22675547881850175, 0.11344640715313808, 0.12377325551850454, 0.007168979467158871, 0.17192028196794645, 0.14186905164803776, 0.10923839081078768, 0.2255819117916482, 0.09366120810487441, 0.16654053064329283, 0.26021874962108477, 51.979803698403494, 69.5246547971453, 47.78418609074184, 37.31435905184065, 84.65408624921525, 80.26012883867536, 53.84467935562134, 62.37613269260952, 73.530166217259, 61.12447725023542, 75.23262078421456, 13.129688654627119, 0.8088851241128785, 1.6620363529239381, 2.1083049263272966, 8.792687364986964, 2.8979064651897977, 0.23418816498347692, 29.25205155781337, 72.31541960580009, 58.999384607587544, 61.63250173841204, 57.531244141714915, 59.76091412135533, 54.81535312107631, 57.18976102556501, 46.571614265441895, 47.72696420124599, 44.36096150534493, 51.29973486491612, 50.546831539699006, 56.411642687661306, 53.56537219456264, 56.61558273860386, 49.53561156136649, 50.9761711529323, 49.94026075090681, 51.10930906023298, 49.35509041377476, 51.58894668306623, 52.07688740321568, 53.109122208186555, 50.58372300011771, 53.96408067430769, 49.02184786115374, 49.622064522334504, 47.996825286320274, 45.906049796513145, 50.171976225716726, 53.159375054495676, 50.31529324395316, 49.67080266135079, 46.330199105399, 42.552998542785645, 37.828602177756174, 39.48402091435024, 37.36031791142055, 36.72986963817051, 37.37429421288626, 36.93168354034424, 36.066539015088765, 40.66156687055315, 40.3484080859593, 43.96018941061837, 48.264098167419434, 52.90057897567749, 43.91633932931082, 36.95736060823713, 40.021398067474365, 37.82825129372733, 38.09672621318272, 37.40103782926287, 42.989321095602854, 44.07483121326992, 47.04893466404506, 44.955706460135325, 40.5666093145098, 37.643206868852886, 42.34360763004848, 42.133938789367676, 40.520233563014436, 44.87758091517857, 40.32830694743565, 42.12705659866333, 38.764267444610596, 33.92999921526228, 37.02353177751814, 36.74492638451712, 32.34394434520176, 38.892652784075054, 35.00199161257063, 33.36825820377895, 35.05047614233834, 35.46442896979195, 34.16299663271223, 33.45714998245239, 35.56253405979702, 35.59938383102417, 36.089992659432546, 44.36974402836391, 52.08439145769392, 48.162963662828716, 44.551651341574534, 40.78794765472412, 41.463538374219624, 38.56654603140694, 40.725865500313894, 38.74544130052839, 37.77095297404698, 38.096156460898264, 39.22506502696446, 39.37618487221854, 40.801816259111675, 44.01618841716221, 43.97729934964861, 45.30483954293387, 43.264980452401296, 42.305913652692524, 43.370488848005024, 44.95750604357038, 46.260755334581646, 52.554256439208984, 50.12408924102783, 59.81645107269287, 49.22987692696707, 36.936995438167024, 40.45760250091553, 43.909335545131135, 46.05656514848982, 46.55632128034319, 46.95851080758231, 48.6939172063555, 50.58763831002371, 52.27874299458095, 55.26271983555385, 56.30119412285941, 57.31907742364066, 55.878100940159385, 52.60703842980521, 51.43354327338082, 53.841608251844136, 61.33377088819231, 59.02268886566162, 62.468279702322825, 65.08324119022915, 54.18226800646101, 61.2151859828404, 17.04575330870492, 0.9148910215922764, 2.562743169920785, 8.360446878841945, 0.4769551839147295, 0.38119926356843536, 31.633272171020508, 82.55463245936802, 68.6406910760062, 77.02722236088344, 72.82056753976005, 56.35212789263044, 38.49528530665806, 51.89377457754952, 58.962211745125906, 72.66590758732387, 72.82543822697231, 3.9222772121429443, 0.34541091110025135, 0.25199932924338747, 0.19018857526992047, 0.17775102837809495], [0.05774345900863409, 0.034932648563491445, 0.12001645139285497, 0.04147558193653822, 0.07589967189622776, 0.09886196867695876, 0.16101802912141594, 37.35177162715367, 57.25718634469168, 32.792909145355225, 33.58874191556658, 72.39906896863664, 78.30931786128453, 41.27056605475289, 52.7387033190046, 59.200868470328196, 52.56849677222115, 62.01481941768101, 17.937047379357473, 0.1512868870049715, 0.3291003948875836, 1.086631057517869, 1.6164790775094713, 0.38034870635185924, 0.12739585898816586, 18.630175352096558, 70.76148278372628, 50.21466943195888, 57.91145651681082, 53.45967967169625, 57.54336527415684, 52.17719854627337, 49.61263581684658, 42.03585106985909, 45.06802756445748, 42.92078406470162, 51.01019300733294, 47.54456009183611, 51.255183015550884, 45.44579764774868, 46.12042604173933, 51.03099591391427, 53.50595814841134, 51.91367769241333, 48.6879243850708, 48.49069629396711, 47.65913936070034, 47.408653327396934, 46.92091063090733, 45.639999798366, 45.355662141527446, 43.81140416009085, 42.083790166037424, 43.762982164110454, 47.57261691774641, 47.76217072350638, 48.27833502633231, 47.97416026251656, 45.98246261051723, 39.08457939965384, 37.44917842320034, 34.068271841321675, 32.52643183299473, 33.867833682468955, 32.66899149758475, 32.481115681784495, 36.09020110539028, 41.77771854400635, 43.37293461390904, 41.97730554853167, 40.39051764351981, 42.05734184810093, 46.81422104154314, 44.774983814784456, 35.31318753106253, 35.27959646497454, 35.80130195617676, 36.82960755484444, 33.103795869009836, 39.33528430121285, 40.45405544553484, 42.9679136957441, 46.770944186619346, 38.535411153520855, 35.14912666593279, 36.92321021216256, 39.211196422576904, 37.185181617736816, 42.20704773494175, 39.094609124319895, 39.749487263815745, 36.561111790793284, 35.53558199746268, 34.30732461384365, 35.26334810256958, 36.32300397327968, 35.87256962912423, 34.44832093375069, 35.40064798082624, 36.47712196622576, 35.72983625956944, 35.81799847739083, 34.86324998310634, 34.97039467947823, 32.13511971064976, 34.1378858430045, 46.602082116263254, 44.74273722512381, 39.78374535696847, 35.36988830566406, 33.374726976667134, 33.72143513815743, 33.63727160862514, 33.14579425539289, 34.50430604389736, 34.82929761069161, 34.7725898878915, 34.71766785212925, 35.25491993767874, 34.98777559825352, 39.08226217542376, 38.97345338548933, 41.511077948978965, 43.07539537974766, 41.5887588092259, 38.090042046138215, 37.97434064320156, 37.51854228973389, 43.1945743560791, 50.23564256940569, 48.05587455204555, 54.66654702595302, 55.70540346418108, 45.013494627816335, 40.98492561067854, 37.62503038133894, 37.34162030901228, 38.6184594971793, 40.304172379629954, 44.88337571280343, 48.05116714750017, 52.08577414921352, 50.62203189304897, 53.203364099775044, 54.44410044806344, 53.739476680755615, 49.16985491343907, 48.68812588282994, 47.58241735185896, 57.8895696912493, 56.64199978964669, 58.91272667476109, 44.811618191855295, 49.3907277243478, 8.578485693250384, 0.7145227789878845, 1.3583146333694458, 2.9071265075887953, 0.1109524109799947, 0.10650078699524913, 33.643448557172505, 69.24466323852539, 59.56804602486746, 66.04874202183315, 57.29065581730434, 48.08746106284005, 28.852827174322947, 16.66806139264788, 32.454292161124094, 53.364610944475444, 40.37480429240635, 0.4365578687616757, 0.041306511365941594, 0.04394895743046488, 0.07570385347519602, 0.01274561875366739, 0.023888249415904284, 0.023324709119541303, 0.064845936106784, 0.05713259428739548, 0.021479925074215447, 0.02492632657023413, 0.14318265473204, 44.99505410875593, 66.64468206678117, 39.0169734273638, 37.40434864589146, 80.85293524605888, 87.29810510362897, 49.65618017741612, 55.77134534290859, 65.9290245601109, 56.40413863318307, 66.32767050606864, 19.91569631440299, 0.3836050773305552, 0.4441333051238741, 1.4821485770600182, 3.505565732717514, 0.9797738428626741, 0.01815807885889496, 22.993857724326, 70.76107978820801, 52.83159031186785, 59.96043164389474, 56.719336714063374, 58.84012494768415, 53.34253304345267, 52.3660158429827, 42.99686336517334, 44.78452021735055, 44.661662169865195, 51.53174563816616, 49.13580526624407, 52.68247849600655, 47.56062780107771, 48.829212529318674, 50.96868099485125, 53.056350639888215, 52.65570708683559, 50.305190563201904, 51.291914667402, 49.53486115591866, 50.1019731249128, 48.60041182381766, 48.42062371117728, 47.40023211070469, 45.345354488917756, 43.67382982798985, 45.79665388379778, 48.30641617093767, 49.3984124319894, 49.74962650026594, 50.7771122114999, 46.74143518720354, 40.00511843817574, 38.49750525610787, 35.609361444200786, 35.03415829794747, 35.20273201806204, 33.822368144989014, 33.977184431893484, 36.51693861825125, 42.17118113381522, 44.437756470271516, 43.83494118281773, 41.77286522729056, 44.676711968013215, 47.31416824885777, 45.857335976191926, 36.634627205984934, 35.30269922528948, 37.43798834936959, 37.89765337535313, 34.50018228803362, 39.02506113052368, 40.86391230991909, 40.92800596782139, 46.613265241895405, 37.75546196528843, 34.89383595330374, 37.86130387442452, 39.496673583984375, 38.42601524080549, 42.9221076965332, 40.13141236986433, 41.223457268306184, 37.46776485443115, 36.02294601712908, 34.10381882531302, 35.4413366317749, 35.92135640553066, 36.54100717817034, 36.316764490945, 36.96887724740164, 36.2748772757394, 35.87690530504499, 36.27446385792324, 34.58299091884068, 35.64495359148298, 33.04380512237549, 36.1465926851545, 46.90872696467808, 46.66409478868757, 41.529174532209126, 36.43117005484444, 34.246051924569265, 35.70844623020717, 35.333590916224885, 35.81980848312378, 36.43157999856131, 36.210599490574424, 35.91375855037144, 36.650482995169504, 38.20486797605242, 38.165666239602224, 40.64406435830252, 43.295840876443044, 44.53510420663016, 45.01768786566598, 43.08033207484654, 40.033102308000835, 39.67189673015049, 39.10199853352138, 45.8781110899789, 51.19632135118757, 48.93181657791138, 53.84735788617815, 57.44273451396397, 45.123317854745046, 39.50517817905971, 39.15566989353725, 39.44112621034895, 39.809144496917725, 44.46431943348476, 46.54389442716326, 49.88640873772757, 53.1324577331543, 53.65890189579555, 55.03583335876465, 57.57580641337803, 56.40962423597063, 52.435782705034526, 51.238000120435444, 50.38860716138567, 59.73357990809849, 59.44753646850586, 61.59017331259591, 47.88692215510777, 51.86908415385655, 10.049551350729805, 0.9608236082962581, 2.673701558794294, 10.571955135890416, 0.2021271546504327, 0.07148429525217839, 35.89095456259591, 74.01785332815987, 64.62097058977399, 71.05794852120536, 65.1522854396275, 53.81928368977138, 33.18587841306414, 21.56626868247986, 38.28169420787266, 60.19120216369629, 51.369946411677766, 0.9364760347775051, 0.0597953556903771, 0.040684318502566645, 0.07652278417455298, 0.0022647870438439505, 0.09698773960449866, 0.1270656567066908, 0.24772702849337033, 0.19450958126357623, 0.17111909495932714, 0.18656538826014313, 0.36384092643857, 56.35458755493164, 74.01039791107178, 47.5813820702689, 47.37480865206037, 78.88617120470319, 79.97089617592948, 56.210304737091064, 62.12999275752476, 71.78582096099854, 62.708298274448936, 72.46339539119175, 22.302095072610037, 0.6462867462209293, 1.1147652907030923, 3.245688557624817, 8.26569082055773, 3.858839290482657, 0.20417049500559056, 25.94164660998753, 71.44242014203752, 52.55681685038975, 62.331316811697825, 57.56091294969831, 61.50699642726353, 55.10226508549282, 54.361125060490195, 46.08702605111258, 49.96773740223476, 46.59368174416678, 54.049658162253245, 51.98773506709507, 53.78479978016445, 49.515579904828755, 50.667751039777485, 51.19023820332119, 53.167837960379465, 53.65949944087437, 53.14503397260393, 53.14960936137608, 51.99353681291853, 51.24718911307198, 51.186979498182026, 50.54496247427804, 49.75786358969552, 47.29922962188721, 45.906657763889854, 47.78176811763218, 51.48487656457083, 49.45991093771798, 54.095808097294395, 53.60526875087193, 49.814606053488596, 42.919227668217246, 41.69948182787214, 38.6411384173802, 36.646692752838135, 36.81063549859183, 35.58977099827358, 35.83752638953072, 39.240764481680735, 45.53732279368809, 46.76316567829677, 45.018639768872944, 42.77396515437535, 46.89646339416504, 51.085883208683555, 47.167307649339946, 37.256473609379356, 36.74211931228638, 36.97410576684134, 38.001341342926025, 35.032011304582866, 41.00190005983625, 41.752170017787385, 44.36696474892752, 49.734795570373535, 38.62086704799107, 36.547236238207134, 39.11170516695295, 42.62772989273071, 41.930009160723, 44.500724520002095, 43.20268290383475, 44.29538093294416, 38.03250053950718, 36.45437008993966, 34.01969698497227, 34.804329259055, 35.72192920957293, 36.740257195064, 36.17417355946132, 37.67673887525286, 37.18850633076259, 36.36754192624773, 37.43471227373396, 35.453898974827354, 36.35279090063912, 32.83182600566319, 36.37027604239327, 50.55848714283535, 49.35773767743792, 43.547584533691406, 38.64456387928554, 37.704236371176584, 37.9122758592878, 38.33756119864327, 38.01247583116804, 39.53739697592599, 38.402710982731406, 37.16799872262137, 37.543236187526155, 39.9226850100926, 39.29152454648699, 43.29092155184065, 43.90323502676827, 46.784375054495676, 47.48642798832485, 44.832660811288015, 42.44636801310948, 42.24997023173741, 40.54825564793178, 49.18249021257673, 54.88305984224592, 52.08245638438633, 57.506581510816304, 56.32594013214111, 45.63481991631644, 42.716621671404155, 39.88590472085135, 39.35373871667044, 41.617368016924175, 45.476262024470735, 49.11035054070609, 50.825026988983154, 55.619687012263704, 55.60280288968767, 58.312520435878206, 60.00577558789934, 58.53253514426095, 54.94353001458304, 53.225949219294954, 52.04057959147862, 62.86274283272879, 62.20961216517857, 67.02139254978725, 52.217286178043906, 57.90641907283238, 12.40437923158918, 1.0519791969231196, 4.659818070275443, 18.480386086872645, 0.6455805812563215, 0.14591924074505055, 41.45174380711147, 78.74329539707729, 69.47914409637451, 77.02006571633476, 70.76079491206578, 64.81798676082066, 39.783915587833945, 27.375405652182444, 50.23316553660801, 68.56135654449463, 62.661460467747276, 2.2121500968933105, 0.1435139019574438, 0.1967697949813945, 0.24509526257004055, 0.07563366581286703], [0.02531370221238051, 0.09572274676923241, 0.07921092957258224, 0.09200115861105067, 0.09588172073875155, 0.056438164585935216, 0.030497920100710223, 36.933309418814524, 58.72592435564314, 37.32010868617466, 17.50410338810512, 24.009991816111974, 36.9298665864127, 40.727991649082725, 53.20025478090559, 59.871550287519185, 55.13470622471401, 61.39800698416573, 27.324678591319493, 0.02329180695648704, 0.22384475357830524, 0.20094007120600768, 3.057903068406241, 0.4364310641373907, 0.09360303729772568, 19.92786087308611, 63.202058110918315, 52.36076300484793, 55.05296414239066, 52.15546110698155, 56.098459584372385, 50.15319871902466, 47.641292912619456, 42.491607734135215, 44.55783871241978, 48.10693686349051, 48.702675410679404, 50.50673695972988, 50.32061903817313, 47.090603010995046, 54.35023723329817, 52.623467445373535, 50.20954860959734, 47.39963109152657, 48.50726427350725, 46.65628501347133, 46.133815220424104, 43.647791453770225, 42.72047444752285, 42.26517983845302, 41.04117822647095, 44.12780427932739, 44.3272488457816, 46.23211833408901, 51.66846881593977, 46.85527794701712, 46.866739000592915, 48.15079736709595, 40.82734046663557, 35.696158340999055, 34.969842297690256, 32.30939442770821, 34.112372057778494, 32.27953107016427, 35.75564881733486, 37.80162232262747, 38.23118427821568, 36.22269977842058, 33.94286380495344, 34.45204169409615, 32.47294112614223, 38.5818008014134, 43.98194422040667, 41.18539156232561, 39.27295895985195, 37.43224913733346, 38.44095386777605, 37.842811243874685, 36.11683007649013, 37.12435361317226, 39.937258856637136, 40.93904318128313, 46.07771546500069, 44.40476989746094, 36.711891174316406, 36.68017612184797, 38.26889910016741, 36.70063509259905, 42.782990864345, 38.62081493650164, 38.03376511165074, 36.092066696711946, 34.916768482753206, 33.76821041107178, 34.64416980743408, 35.156342370169504, 34.66142218453543, 33.75160074234009, 36.14447348458426, 35.248774256025044, 36.71594197409493, 34.2495607648577, 34.73910999298096, 32.356725556509836, 34.57050153187343, 40.24904884610857, 41.6844494002206, 42.31629078728812, 35.50747653416225, 33.40169988359724, 34.85665266854422, 36.53697027478899, 35.46760082244873, 33.086220400674, 31.803999832698278, 35.443292549678254, 35.3797721181597, 33.64971930640084, 34.282453536987305, 35.55657597950527, 37.27137402125767, 39.58951888765608, 43.81658404214041, 45.20995494297573, 44.118493693215505, 42.056487219674246, 38.691703932625906, 36.89828702381679, 37.09808942249843, 40.40673473903111, 47.79549428394863, 48.80264956610543, 48.10724605832781, 53.82187189374651, 51.33050843647548, 49.778426783425466, 48.39765296663557, 49.231207506997244, 53.61270332336426, 52.39308255059378, 51.93897260938372, 51.76241888318743, 52.60795211791992, 52.87058012826102, 50.43121351514544, 53.97955778666905, 50.75724383762905, 49.00154522487095, 45.70960337775094, 52.61108922958374, 54.580865315028596, 56.171922888074604, 50.07069928305489, 51.84795468194144, 5.9146544848169595, 0.4700139878051621, 0.9408473202160427, 7.456730297633579, 0.5288805376206125, 0.1504218905631985, 40.0691808291844, 66.33464649745396, 58.039136614118306, 59.91621330806187, 60.66361018589565, 48.36090047018868, 17.30419502939497, 30.483425208500453, 48.274673325674875, 60.53387342180525, 38.97627782821655, 0.4409130593495709, 0.017222687801612274, 0.07061305628823382, 0.053974051095013104, 0.07186601869761944, 0.03513756613912327, 0.06646317004093102, 0.023856745034988438, 0.06405545638075896, 0.10207973779844386, 0.05661218846216798, 0.09594433595027242, 45.932143756321494, 65.2664234978812, 43.76531675883702, 25.73358801433018, 44.82712309701102, 50.48019136701311, 43.65886688232422, 59.377060890197754, 63.43239784240723, 58.43013259342739, 67.40728160313198, 29.471694537571498, 0.14038462058774062, 0.24309287858860834, 2.4108681423323493, 2.9869337337357655, 0.23026867530175618, 0.12179174327424594, 24.6008631501879, 62.981049810137065, 52.766725403921946, 58.48446750640869, 53.219647203172954, 58.332982880728586, 52.823947293417795, 48.866916928972515, 43.126388209206716, 45.971435819353374, 49.50003331048148, 52.69955369404384, 53.225726876940044, 53.566813945770264, 48.35994856698172, 54.80200563158308, 53.22766195024763, 50.4607572555542, 48.775909423828125, 50.43245724269322, 49.43308741705758, 49.214761120932444, 47.466434546879356, 45.371337277548655, 43.25158779961722, 43.915811266217915, 45.17448786326817, 46.2975286756243, 46.9738107408796, 52.62648296356201, 50.86779662540981, 48.81821353094918, 49.52240650994437, 42.4634119442531, 39.283447265625, 35.06643615450178, 33.24295091629028, 35.956312792641775, 34.43211773463658, 37.7457275390625, 39.19712284633091, 37.652691159929546, 38.94131449290684, 35.34594133922032, 35.3498774937221, 35.12591968263899, 39.14372246606009, 46.415741852351594, 43.79389817374093, 40.163926465170725, 37.65378550120762, 39.178970677512034, 37.79452821186611, 35.84381103515625, 35.4814590045384, 39.70098188945225, 40.68075432096209, 46.29802894592285, 43.88992575236729, 36.920465673719136, 37.70441007614136, 39.23201322555542, 40.43496526990618, 43.44855533327375, 40.50635801042829, 40.01859794344221, 34.595421246119905, 34.48124844687325, 34.88321910585676, 35.45223140716553, 36.49390186582293, 34.71272420883179, 34.80684103284563, 35.75911944253104, 35.451018946511404, 37.09338896615164, 34.181850569588796, 34.19900567190987, 33.04999944141933, 35.73786490304129, 39.19351325716291, 44.836433683122905, 42.53991855893816, 37.40574870790754, 35.661789076668875, 34.655217443193706, 37.31795474461147, 37.62257071903774, 34.76193829945156, 34.01989153453282, 36.84545986992972, 36.95870508466448, 36.00015245165144, 37.377059595925466, 37.720425673893516, 40.633211272103445, 41.94004930768694, 45.428739820207866, 47.54457746233259, 46.92721264702933, 43.90981844493321, 39.535927431924, 38.87368072782244, 39.26864412852696, 40.99977043696812, 49.16026987348284, 51.496636390686035, 48.56403800419399, 54.74990109034947, 52.35100425992693, 51.123608452933176, 52.05437871388027, 51.00839689799717, 54.84138454709734, 54.856823444366455, 54.584440163203645, 54.232840469905305, 55.725285734449116, 55.70796387536185, 53.07178258895874, 56.3111891065325, 53.09968308040074, 52.15585715430123, 48.41582250595093, 54.47200093950544, 57.36770439147949, 59.83465535300118, 53.149529457092285, 54.98010880606515, 6.010302518095289, 0.27608865233404295, 1.794865608215332, 6.305973555360522, 0.28989746421575546, 0.05946143503699984, 46.08361448560442, 69.83302974700928, 64.5125161579677, 66.76023060934884, 65.16318716321672, 58.280947821480886, 27.302390507289342, 30.140753950391495, 54.26037965502058, 66.48230266571045, 49.63417523247855, 0.5484442221266883, 0.05768714060208627, 0.08642989077738353, 0.028715350931244235, 0.0644604739333902, 0.12979366603706563, 0.17039064690470695, 0.23622955115778105, 0.21032298915088177, 0.25065360431160244, 0.28236575265015873, 0.28049535730055397, 52.41030018670218, 75.50409385136196, 51.689483642578125, 30.35448748724801, 35.02073090417044, 47.33888993944441, 53.450132846832275, 64.78407955169678, 70.44890417371477, 63.805759293692454, 72.68108245304653, 32.34344407490322, 0.23675348875778063, 1.1872701772621699, 4.427299644265856, 10.507229191916329, 2.267625165837152, 0.5277324020862579, 29.67323398590088, 64.78647668021065, 54.54534264973232, 59.30774566105434, 54.47190366472517, 60.76666586739676, 55.48169231414795, 50.79528522491455, 44.97104113442557, 47.657506534031455, 51.61796930858067, 56.08292688642229, 53.441155774252756, 55.20852041244507, 50.19150761195591, 53.67481327056885, 54.380041531154085, 54.75315979548863, 52.03331177575247, 51.55214902332851, 51.87759222303118, 51.69476079940796, 49.852713448660715, 47.25466387612479, 46.04654932022095, 43.9119029045105, 47.59950644629342, 50.59765066419329, 49.13377639225551, 52.82414531707764, 50.73722260338919, 49.92917142595564, 51.34208066122872, 43.16901193346296, 40.52074078151158, 39.11131954193115, 34.75732469558716, 37.43248190198626, 34.63821520124163, 39.84503541673933, 42.457144669124055, 40.57642364501953, 41.229582105364116, 36.840036800929475, 37.9879869052342, 36.602519580296104, 41.19943734577724, 47.77932582582746, 44.824065889631, 41.80609498705183, 39.00220850535801, 39.512254919324604, 39.221924441201345, 36.22839730126517, 38.98953151702881, 39.73899548394339, 42.367912428719656, 47.88432352883475, 45.79443046024868, 37.32210976736886, 38.58590718678066, 41.56071240561349, 42.050577776772634, 45.12391887392317, 42.00915609087263, 41.416349683489116, 35.78910786764962, 35.967367376599995, 35.22023800441197, 35.11717537471226, 36.51531621388027, 34.404297147478374, 34.742469446999685, 37.20530360085623, 34.18736743927002, 38.03124986376081, 34.95378153664725, 34.19282177516392, 33.240029198782786, 36.01256193433489, 41.67188705716814, 46.39411905833653, 46.63051067079817, 39.72518246514456, 37.25453506197248, 39.21048423222133, 41.207149846213206, 40.80912923812866, 37.02780144555228, 35.2275127683367, 39.959305490766255, 38.49567787987845, 37.226057870047434, 38.33175597872053, 39.63875729697091, 41.75327478136335, 43.43779257365635, 47.93007046835763, 49.574920994894846, 49.98921080998012, 46.71286766869681, 41.74422475269863, 42.61803020749773, 42.47693313871111, 45.23112262998308, 51.51681743349348, 55.39485025405884, 51.4388621194022, 57.80518729346139, 54.66855158124651, 54.27183723449707, 53.48417901992798, 54.330434867313926, 58.908488273620605, 57.06767422812325, 56.72954361779349, 56.939358370644705, 58.510050773620605, 56.81422478812081, 54.73008482796805, 58.14974846158709, 53.08232648032052, 54.94493007659912, 50.77843584333147, 56.84406730106899, 60.60441848209926, 62.71215452466692, 55.649248123168945, 58.49684224809919, 8.612135819026403, 0.6643619963100978, 2.107409260102681, 16.020218304225377, 1.280632796032088, 0.18094736257834093, 50.25713334764753, 76.45953369140625, 69.00629138946533, 71.2768862588065, 74.1471176147461, 63.154567173549104, 27.312555721827916, 44.989867278507774, 64.30959401811872, 76.9483255658831, 61.18722643171038, 0.9898971510784966, 0.16240313622568334, 0.20916500128805637, 0.09929675356085811, 0.18046690550233635], [0.056630081430609734, 0.10102884990296193, 0.03358026041782328, 0.08982876089534589, 0.06162870302796364, 0.13700162140386446, 0.1320425346493721, 22.006226880209788, 63.1804005759103, 44.171789850507466, 26.070766721452983, 22.36769996370588, 34.550959723336355, 40.64849730900356, 49.89414208275931, 59.64364242553711, 54.91576501301357, 59.68927124568394, 36.127936771937776, 0.017880040653316037, 0.2296275682747364, 1.47832923914705, 1.2363691883427756, 0.345778649938958, 0.001733219317559685, 24.288048301424297, 50.641365255628315, 42.63630396979195, 56.658168247767854, 52.108390535627095, 54.536806787763325, 48.87560565131051, 42.70251335416521, 43.245959758758545, 49.36292450768607, 50.46837942940848, 51.40061923435756, 50.04354224886213, 44.51179300035749, 52.82464211327689, 49.80226952689034, 46.91251025881086, 48.27317598887852, 47.163260323660715, 46.034414291381836, 43.31795699255807, 42.32218285969326, 40.04018947056362, 40.19784757069179, 40.991561140332905, 42.61421912057059, 44.14002616064889, 45.50298132215227, 49.74744476590838, 49.364828314099995, 43.546038559504915, 50.09286403656006, 46.132477692195344, 40.41966881070818, 35.02056762150356, 36.084906578063965, 33.578799043382915, 33.391218526022776, 34.90866688319615, 33.820679732731406, 33.184297697884695, 32.72013371331351, 32.245880944388254, 36.098792552948, 33.384895665305, 33.772031920296804, 37.9156631061009, 41.04510048457554, 41.49546882084438, 39.21732473373413, 36.81397410801479, 38.909540380750386, 34.6686691556658, 34.55589294433594, 35.36848824364798, 39.52079772949219, 40.79185601643154, 44.35020221982683, 44.78947080884661, 41.788064411708284, 35.844672611781526, 39.34548773084368, 36.16780553545271, 44.46620239530291, 39.56672879627773, 37.737139565604075, 35.26007897513253, 34.21341623578753, 32.95188045501709, 36.045871598379954, 34.71743161337716, 35.00332219260079, 34.848474638802664, 36.71165146146502, 35.483689376286094, 35.47854770932879, 34.08542694364275, 33.17868702752249, 33.53119693483625, 39.083168915339876, 40.84432881219046, 42.80614921024868, 39.34146472385952, 34.282880851200645, 33.447710854666575, 32.286545276641846, 32.627031326293945, 33.06035573141915, 35.117255278996055, 34.762723445892334, 32.712775571005686, 33.94723769596645, 34.56722545623779, 33.928967407771516, 32.95601463317871, 36.83854293823242, 41.248557635716026, 43.3953286579677, 46.38083757672991, 47.63625199454171, 46.227859088352744, 43.20833873748779, 41.42262043271746, 38.29770285742623, 37.416563579014365, 39.03218650817871, 43.50559309550694, 47.23949595860073, 46.920212336948936, 48.74022694996425, 50.66474594388689, 50.47541100638253, 51.260362897600444, 48.29285676138741, 48.834305558885845, 50.700334617069785, 50.05720240729195, 50.04165928704398, 52.02529008047921, 51.69714403152466, 52.76188250950405, 51.81780992235456, 48.269792216164724, 46.256819180079866, 51.047442299979075, 56.29769570486886, 57.34892341068813, 57.12689025061471, 51.11028528213501, 3.4953091059412276, 0.8463172412344387, 3.1369766082082475, 4.805127050195422, 0.2921845072082111, 0.3337679829980646, 45.63129023143223, 61.74217210497175, 61.70935576302664, 61.525068691798616, 58.447350229535786, 44.473935740334646, 21.5897535937173, 28.41099991117205, 39.70894799913679, 60.59205763680594, 23.72497844696045, 0.21868463046848774, 0.012745344795153608, 0.036938683063324006, 0.03194059072328465, 0.05609061216403331, 0.04873814240896276, 0.08564175878252302, 0.046084598904209476, 0.12111178333205835, 0.060523321985134056, 0.13946182653307915, 0.14002548557307037, 30.746480533054896, 71.38855075836182, 51.05851772853306, 28.98731824329921, 22.338691234588623, 36.495555537087576, 44.388490268162315, 55.56904854093279, 64.88393906184605, 60.24243123190743, 64.84973308018276, 39.35063287190029, 0.061332556419074535, 0.13476290367543697, 2.0716006330081393, 4.62050472838538, 0.2904226503201893, 0.08005202122564826, 27.15438519205366, 52.63124247959682, 46.312960624694824, 58.34562860216413, 55.22664826256888, 55.85547065734863, 48.80580057416643, 43.373136111668174, 43.97866119657244, 51.034661088671, 50.89406429018293, 53.26266697474888, 50.80790662765503, 44.665914467402864, 53.37167031424386, 50.14935636520386, 50.62693384715489, 51.397377899714876, 49.445872102464946, 47.08790710994175, 46.19219398498535, 44.29457494190761, 42.85290363856724, 41.24724095208304, 41.482909951891216, 43.329643862588064, 46.83205359322684, 46.6407801083156, 49.732943875449045, 54.294908727918354, 45.11893006733486, 49.83861207962036, 48.86543696267264, 41.79313659667969, 37.3411408833095, 37.610619817461284, 34.927958556583945, 36.69281489508492, 35.20998593739101, 36.01132862908499, 34.23660932268415, 33.51345123563494, 32.61816889899117, 36.7108975819179, 35.847743715558735, 35.64169488634382, 38.43760483605521, 43.77234833581107, 42.62226513453892, 40.780433177948, 38.0709171295166, 38.881111826215474, 35.26196541104998, 34.06004864828927, 34.93347542626517, 38.91667965480259, 42.017587729862754, 45.94893060411726, 45.267989771706716, 42.60404348373413, 35.988253661564414, 41.940233434949604, 38.886548791612896, 45.27704674857003, 41.848152433122905, 39.58875111171177, 35.2214435168675, 34.27037756783621, 34.28892230987549, 36.26944725854056, 34.552734988076345, 34.860588823046, 36.42298855100359, 37.64862993785313, 36.3500463621957, 35.82834087099348, 35.263414110456196, 34.24778202601841, 33.997698988233296, 40.19752447945731, 42.54808964048113, 44.488829204014365, 40.13694313594273, 35.847066266196116, 33.901174613407676, 33.63935954230172, 33.102757113320486, 34.77831867762974, 35.00517041342599, 35.17925752912249, 35.72153663635254, 36.016022137233186, 36.34379645756313, 36.86916364942278, 35.455865315028596, 39.06627437046596, 42.67265347072056, 45.96336201259068, 47.24419641494751, 49.32718644823347, 48.10035344532558, 46.77311202457973, 42.973010199410574, 39.02949060712542, 40.01526280811855, 41.936536993299214, 44.36636025565011, 49.37353440693447, 49.97169092723301, 51.31163018090384, 52.87210873195103, 50.94770090920584, 52.80738278797695, 50.37419312340872, 51.319207191467285, 52.57033804484776, 53.71034288406372, 52.10365186418806, 53.951598235539024, 55.141296591077534, 56.16690976279122, 53.441419805799214, 51.17093958173479, 47.82763317653111, 53.75982100622994, 57.02193423679897, 60.66304043361119, 59.17686939239502, 54.381518023354666, 3.77397312436785, 0.7380358087165015, 3.3550334445067813, 8.021176763943263, 0.4290228730865887, 0.23553999673042977, 52.03126900536673, 68.6054915019444, 63.889985357012065, 66.50918524605888, 63.196603775024414, 52.59845740454537, 21.18954082897731, 31.680426120758057, 47.61025183541434, 68.82711819240025, 32.31972639901297, 0.32046427258423393, 0.07446295541844197, 0.054294010890381675, 0.028817565446453433, 0.07993924192019872, 0.25616444860185894, 0.183911013549992, 0.09116742906293698, 0.22901561111211777, 0.1919014962123973, 0.31999934038945604, 0.2310087127344949, 36.57067251205444, 80.85532542637416, 56.78267649241856, 38.372639179229736, 30.54576792035784, 47.80751119341169, 54.84859330313546, 60.95621272495815, 70.97668933868408, 64.30355603354317, 70.487459727696, 43.79634741374424, 0.22646479441651277, 0.7466901157583509, 5.406478004796164, 7.925739782197135, 2.8377083582537512, 0.1584296351564782, 31.954108715057373, 55.2654504776001, 48.84806299209595, 60.961208479745046, 58.65168285369873, 59.51439898354666, 53.48459243774414, 46.036377157483784, 48.142904213496614, 55.376222133636475, 53.24910756519863, 54.65162229537964, 52.662665707724436, 48.31135286603655, 55.994837624686106, 52.76313318525042, 52.20766292299543, 52.99611323220389, 51.737797941480366, 49.09176063537598, 48.95975875854492, 45.59323842184884, 44.13009371076311, 43.04058837890625, 43.975697789873394, 44.83155952181135, 49.6781781741551, 47.20048182351248, 51.314888886043, 56.33901316779, 47.3188339642116, 52.39723757335118, 51.48151363645281, 43.10638781956264, 38.565931115831646, 39.268025738852366, 37.74820457186018, 37.811363697052, 38.402797835213796, 37.250668389456614, 36.4934606552124, 34.82749802725655, 33.73001616341727, 39.264027050563264, 38.71878801073347, 38.45538527624947, 42.616421699523926, 45.93804277692522, 45.95392288480486, 41.34828165599278, 38.94203363146101, 39.804169586726594, 35.6358688218253, 34.12448276792254, 34.673644065856934, 40.49666179929461, 42.70861039842878, 45.746355874197825, 47.28019503184727, 45.29103694643293, 36.03566122055054, 42.57553849901472, 38.982256753104075, 46.674610887254985, 46.604757172720774, 38.99588564464024, 35.975427286965505, 34.86895792824881, 33.3892765045166, 37.45310762950352, 34.78129250662667, 34.93471915381295, 36.34699610301426, 37.63338211604527, 35.92233610153198, 36.34700305121285, 35.486051763807026, 34.65267092841012, 34.331066608428955, 41.24562897000994, 44.7420563016619, 46.301093101501465, 43.27086557660784, 38.11717823573521, 36.32039145060948, 35.10499518258231, 34.43799243654524, 37.25433356421334, 37.378629888807026, 37.79985748018537, 36.81393936702183, 38.6864823613848, 38.30662087031773, 37.269713401794434, 37.05400310243879, 40.12502350125994, 44.84846101488386, 47.541572366442, 49.80900580542428, 51.564318793160574, 51.829472473689485, 48.36232137680054, 44.45743376868111, 41.67365189961025, 42.770525796072825, 44.435234274183, 46.74957847595215, 51.393243721553254, 52.32149873461042, 53.634680475507466, 55.119051933288574, 54.081807477133616, 57.05216932296753, 52.73462125233242, 54.10306896482195, 55.60112142562866, 55.53656571252005, 55.35831662586757, 57.19340535572597, 56.016335351126536, 58.02385752541678, 56.70756646565029, 52.55656671524048, 50.3742104939052, 56.63444709777832, 60.95875576564244, 63.54359681265694, 62.69978673117501, 58.13403163637434, 5.569515747683389, 1.1108102457863944, 7.330135856355939, 19.91563551766532, 1.2747179248503275, 0.47572193294763565, 55.80796929768154, 73.8554322378976, 70.84423582894462, 74.34950474330357, 68.170013155256, 59.524522508893696, 30.9559200831822, 41.815190179007395, 55.761746406555176, 77.24079608917236, 42.929715973990305, 0.5020715104682105, 0.19924452076000826, 0.1620406899601221, 0.11777819506824017, 0.18541554281754152], [0.03376379735501749, 0.07546006262834583, 0.029564893737967526, 0.0903159761801362, 0.09470938864563193, 0.09646627187196698, 0.12735278558518204, 14.284821459225245, 62.94009712764195, 43.7297419820513, 27.734361750738962, 19.129759516034806, 31.47871991566249, 41.154746532440186, 54.223682744162424, 57.875940799713135, 55.40960127966744, 56.91375078473772, 39.58712175914219, 0.01754898002504238, 0.1109915692359209, 0.6806953112993921, 1.3010908982583453, 0.2886840807540076, 0.07352906731622559, 26.915837900979177, 49.25132949011666, 38.70125075748989, 59.78969355991909, 52.016910552978516, 51.2975183895656, 43.69082164764404, 49.050547395433696, 47.85773277282715, 49.638024534497944, 51.05246237346104, 53.22185673032488, 45.587815352848594, 48.63451010840279, 50.79940898077828, 50.85094724382673, 48.263121945517405, 45.245693002428325, 39.30660908562796, 39.87205696105957, 37.77102593013218, 37.583702496119905, 37.96967492784773, 41.15724440983364, 43.44491447721209, 48.88524627685547, 45.25096321105957, 50.51201411655971, 46.17505625316075, 40.43328380584717, 45.409444672720774, 49.05925348826817, 43.2823474747794, 37.89657293047224, 36.44607394082205, 34.07303830555507, 32.55553436279297, 33.81513507025582, 33.10509170804705, 34.70757906777518, 32.50975963047573, 34.895079680851524, 32.78652375085013, 32.21099751336234, 31.985497202192033, 33.933417728969026, 35.438421862465994, 40.78330973216465, 40.60624531337193, 41.61992147990635, 38.343765939985005, 38.65625074931553, 36.51232501438686, 35.63526085444859, 35.693903650556294, 36.85505880628313, 39.835419109889436, 45.18987117494856, 44.17499297005789, 46.442798137664795, 37.478701319013325, 38.9665572983878, 37.66520139149257, 44.594768387930735, 39.56427608217512, 38.340455123356406, 34.93259647914341, 34.179137298039024, 35.332819666181294, 36.46587283270699, 35.776687962668284, 37.01269606181553, 36.791587012154714, 36.68009621756417, 35.941606930324006, 34.82680320739746, 32.65269102369036, 35.24781887871878, 33.64453247615269, 38.020327295575825, 40.657154764447895, 39.99982738494873, 36.52127429417202, 34.65559264591762, 32.12992940630232, 33.04089035306658, 33.03052364076887, 34.07864897591727, 32.19752148219517, 33.50249392645699, 34.65086439677647, 34.060528073992046, 33.33774518966675, 34.36587013517107, 34.627132824489046, 37.38621384756905, 39.01246057237898, 45.0277419090271, 45.70391280310494, 48.573793275015696, 45.766505650111604, 47.71768488202776, 47.39662252153669, 44.66439976011004, 39.135513169424875, 40.16120277132307, 36.92482566833496, 40.64852857589722, 42.628056458064485, 43.38831445149013, 45.3586985043117, 47.23738718032837, 45.50568069730486, 42.6095985685076, 44.63825021471296, 41.85626098087856, 41.74400241034371, 41.213768005371094, 42.15809072766985, 41.184391021728516, 44.866165024893625, 44.59934377670288, 47.90945168903896, 47.1266850062779, 52.518521853855674, 52.59806135722569, 60.257140568324495, 56.09485346930367, 51.498633997780935, 1.3202268885714668, 0.09257801515715462, 2.534701760326113, 3.9643268414906094, 0.23542092740535736, 0.6770966872572899, 50.20788104193551, 61.83194977896554, 60.45219734736851, 63.66235542297363, 61.69933646065848, 47.917737415858674, 34.6284738268171, 31.63528367451259, 43.87211751937866, 66.29060186658586, 20.182745116097585, 0.4229458863181727, 0.07459075070385422, 0.07903746888041496, 0.04679057387901204, 0.07044492888131312, 0.08016332811010735, 0.014668383436011416, 0.007869493083230086, 0.10138010034071547, 0.10778572876006365, 0.13148177973926067, 0.22704916234527314, 20.516613006591797, 71.0562184197562, 50.65015125274658, 34.553832803453716, 29.217869894845144, 41.68942778451102, 44.8097699710301, 56.94071674346924, 62.76030554090227, 61.66735390254429, 60.913606371198384, 42.567791257585796, 0.035571139838014326, 0.20209660700389318, 1.7240276379244668, 3.2668799119336263, 0.8494961506554058, 0.0545145415567926, 30.227422305515834, 51.81865412848336, 39.81783669335501, 61.752524920872276, 54.37955168315342, 53.69288900920323, 46.610614504132954, 51.29806382315499, 49.77026612418038, 52.778290680476594, 53.671895027160645, 54.13368967601231, 46.96569177082607, 50.85190609523228, 52.035604681287495, 51.93365376336234, 48.85669265474592, 47.00262492043631, 41.340774127415244, 41.41815274102347, 39.214145932878765, 40.52646262305123, 40.56149544034685, 43.257674421582905, 44.95946543557303, 48.43696934836251, 47.00357682364327, 53.06485176086426, 48.60370179585048, 42.292854513440815, 47.29026297160557, 50.27901322501046, 46.87486491884504, 39.297969000680105, 39.00276436124529, 34.80864061628069, 34.19992978232247, 35.08719389779227, 35.21236916950771, 35.226821422576904, 34.626559598105295, 36.56929676873343, 35.2133002281189, 35.49764483315604, 33.152148383004324, 36.6166661126273, 36.4770107950483, 42.82035827636719, 43.80329213823591, 42.49969891139439, 38.18649346487862, 39.67848709651402, 37.0789749281747, 36.114398206983296, 36.12035281317574, 38.32046863010952, 41.84906612123762, 45.39618056161063, 45.19161517279488, 44.38032266071865, 37.15765632901873, 40.29094648361206, 40.423410415649414, 45.52320752825056, 40.919237341199604, 38.44198567526681, 35.04287133898054, 33.69674471446446, 34.831764221191406, 35.32690674918038, 34.93410423823765, 35.96042265210833, 37.46990837369646, 36.84949677331107, 36.65919256210327, 33.36331108638218, 33.44698824201311, 35.09346464702061, 35.99967997414725, 40.42362233570644, 43.2973312650408, 42.601448331560405, 37.391619546072825, 36.7351085799081, 34.40392541885376, 34.41701235089983, 34.84144653592791, 35.2827787399292, 34.79237488337925, 36.10046706880842, 34.54945543834141, 35.26845155443464, 35.168373176029746, 35.23172337668282, 36.78474651064192, 38.205927576337544, 39.94651733125959, 46.58404459272112, 47.02734661102295, 50.39453744888306, 48.884857177734375, 51.21665178026472, 49.73051200594221, 45.69932004383632, 39.977089405059814, 42.877027784075054, 39.214472498212544, 43.38004262106759, 46.33556311471121, 45.67521326882498, 47.91131728036063, 48.79566315242222, 47.50177655901228, 45.866347789764404, 46.53948926925659, 44.82594885144915, 43.576103414808, 44.3936527797154, 44.84319428035191, 43.37230232783726, 46.86827107838222, 46.51643167223249, 49.48619597298758, 48.932500975472585, 54.80235998971121, 55.19970662253243, 62.709514209202354, 57.52190923690796, 53.042572362082346, 1.679765984416008, 0.14552669466606208, 4.107263880116599, 7.1123945116996765, 0.4062968896968024, 0.7981205188802311, 53.36139045442854, 68.1050613948277, 66.94965239933559, 69.70061792646135, 68.05340153830392, 53.6567097391401, 33.41750703539167, 33.92201573508126, 51.668354170663015, 72.99751731327602, 28.740083966936382, 0.4726302017058645, 0.14416863396763802, 0.0479242803661951, 0.05246305538873587, 0.11853656651718275, 0.22788294617618832, 0.07982649654150009, 0.1517448845718588, 0.25361589821321623, 0.22798285367233412, 0.2345050408371857, 0.3156965327050005, 23.83976095063346, 80.83390413011823, 57.509086336408345, 43.43532943725586, 29.13710924557277, 41.88049282346453, 52.5677706854684, 64.36670821053642, 68.37228911263603, 67.23715496063232, 67.20685386657715, 47.00065858023507, 0.10457379503973893, 0.969313764146396, 3.345516149486814, 6.729545295238495, 1.7498689655746733, 0.230583732681615, 33.61136177607945, 53.806241921016145, 42.348558221544536, 63.316682543073384, 58.27197422300066, 55.31597777775356, 48.43374538421631, 53.71606819970267, 52.32645280020577, 53.96623461587088, 55.51787158421108, 57.03994396754673, 50.598220416477744, 52.28752899169922, 53.27689688546317, 54.59010294505528, 50.07773780822754, 48.85523700714111, 42.85305649893624, 42.83575548444475, 41.34324073791504, 42.488494941166465, 41.121603625161306, 43.738757269723074, 47.471270493098665, 52.35671220506941, 47.559526511601035, 53.95786551066807, 51.282308782849995, 44.091385296412874, 47.86019243512835, 53.50834138052804, 46.422165461948936, 40.71312945229666, 40.47516754695347, 36.032280921936035, 35.86360992704119, 36.897018977573936, 37.02104779652187, 36.24260636738369, 36.38976573944092, 37.62103516714913, 36.289030756269185, 36.01367712020874, 35.47113398143223, 37.576834201812744, 39.44197736467634, 45.491346563611714, 47.23671667916434, 45.872385774339946, 40.89993871961321, 40.65621328353882, 38.21010691779, 36.68162482125418, 36.92851168768746, 39.07097135271345, 42.036490304129465, 48.574168477739605, 46.46303129196167, 47.06382812772478, 37.73912327630179, 42.40018681117466, 41.197338989802766, 47.46358925955636, 42.59858567374093, 38.41610710961478, 35.33577959878104, 34.4257219178336, 36.41754463740757, 35.55465132849557, 35.0905568259103, 37.84775488717215, 38.32442215510777, 37.73189714976719, 37.13353565761021, 33.994746003832134, 33.41074991226196, 38.29214777265276, 35.40757186072213, 41.15790101460048, 44.63321277073452, 44.18183694566999, 39.32067918777466, 39.07237488882882, 36.26925270898001, 36.28342356000628, 37.5691043308803, 37.57197741099766, 37.24073246547154, 37.001971517290386, 37.47983734948294, 38.01606110164097, 35.988170283181326, 37.21312379837036, 38.079331398010254, 40.2350412777492, 42.10467297690255, 49.04965802601406, 49.32861082894461, 53.242902823856895, 51.55448014395577, 53.02184588568551, 52.78194195883614, 47.22616931370327, 43.06476811000279, 44.662718296051025, 41.754101616995676, 45.59863369805472, 47.980903489249094, 47.29776702608381, 50.287927763802664, 51.41551617213658, 50.008335726601736, 46.75385856628418, 49.34452567781721, 48.127538272312705, 45.99184615271432, 45.51784699303763, 45.710683822631836, 45.635024888174875, 51.05484560557774, 48.14297716958182, 52.52195773805891, 51.37404932294573, 57.07216623851231, 55.69589138031006, 66.5472057887486, 59.517977305821006, 58.367967060634065, 2.1880140091691698, 0.2835850257958685, 7.044069400855473, 10.735119683401924, 1.1099955695016044, 0.9967261446373803, 60.61347893306187, 72.21858256203788, 71.13751234327043, 74.97951875414167, 73.54862758091518, 62.85413401467459, 47.07641478947231, 43.5906286239624, 60.33706569671631, 84.90272753579276, 37.833479813167024, 0.5888578221201897, 0.18832150474190712, 0.17777069232293538, 0.20539310654359205, 0.24958111186112675], [0.09846112411469221, 0.021131017278613787, 0.06480173633566924, 0.09557503648102283, 0.03802244258778436, 0.16907160196985516, 0.21593154248382362, 9.935291699000768, 61.4494514465332, 50.27824197496687, 26.98232000214713, 15.196672643933978, 31.282058102743967, 40.72264848436628, 60.50361401694161, 56.22945744650704, 56.255367279052734, 54.56562096732003, 44.57379872458321, 0.3368746962930475, 0.18757194067750657, 1.2424143382481165, 3.0328192029680525, 0.5739889485495431, 0.2464623749256134, 25.22485133579799, 57.145386355263845, 47.15125036239624, 56.799480710710796, 50.221120834350586, 54.623020035879954, 47.996151311056956, 51.70867109298706, 47.22366796221052, 52.260556084769114, 47.0923296383449, 48.454405852726524, 46.028803621019634, 51.183891023908345, 49.52280255726406, 48.639905384608674, 43.30905982426235, 40.30611440113613, 36.496712412152974, 38.28929206303188, 34.27443878991263, 40.24857289450509, 41.074105739593506, 46.756307806287495, 44.29637105124337, 46.28352458136422, 44.174016748155864, 46.174413544791086, 42.25487565994263, 48.85376051494053, 48.399827752794536, 48.35413292476109, 42.60784762246268, 38.457070214407786, 34.296002524239675, 32.02742610658918, 33.25756645202637, 34.18606117793492, 33.64588042667934, 34.350660528455464, 32.67849663325718, 32.172278676714214, 31.72448464802333, 33.91709293637957, 34.47374439239502, 35.208127294267925, 34.13767739704677, 38.52790709904262, 42.38746813365391, 41.09171942302159, 39.30945437295096, 37.008214473724365, 36.184807777404785, 34.31182009833199, 35.920074462890625, 37.36999327795846, 40.62335525240217, 40.512326513017925, 40.94883666719709, 46.40094913755144, 39.84379516329084, 38.700295380183626, 37.92940664291382, 42.652889319828574, 40.0740966796875, 37.15231663840157, 34.81277132034302, 35.72777959278652, 36.33058793204171, 36.99438408442906, 38.72942222867693, 36.35330506733486, 38.69984722137451, 36.63785464423043, 36.81554787499564, 34.3605443409511, 34.052534171513145, 35.88226931435721, 35.16791806902204, 40.05369676862444, 41.75221865517752, 38.91602652413504, 35.08412626811436, 32.96952887943813, 33.29210247312273, 32.90801647731236, 33.50737156186785, 33.326516900743755, 33.06027235303606, 33.95528718403408, 33.66667291096279, 33.77943522589547, 33.35037006650652, 36.119008336748394, 33.47479840687343, 36.509361607687815, 36.41331665856497, 42.434531756809776, 45.98153502600533, 48.064476421901155, 44.899443422045024, 49.422856194632395, 46.68710722242083, 47.55172715868269, 46.20309918267386, 42.97328117915562, 39.295276573726106, 36.73095703125, 37.33305318014962, 42.241712297712056, 41.53500754492623, 42.08633320672171, 40.63919019699097, 37.790769236428396, 37.876461369650706, 38.154469217572895, 41.82873221806118, 42.883632046835764, 44.2904303414481, 44.25768000738961, 48.08283356257847, 49.19426046098982, 53.529967648642405, 53.09213386263166, 55.296369961329866, 55.2267107963562, 58.72682762145996, 58.202311583927695, 47.409709453582764, 0.7831019876258714, 0.25121060013771057, 2.729338607617787, 3.094945869275502, 0.21166290582290717, 1.5757258300270354, 56.69370828356062, 63.085203307015554, 60.89982114519392, 65.13029439108712, 60.6271390914917, 47.784564767565044, 26.76968949181693, 28.222620350973948, 41.01612997055054, 64.15946429116386, 17.04821297100612, 0.3751814179122448, 0.05200414179957338, 0.08031949972999947, 0.03028256326381649, 0.03389998272593532, 0.04447487296004381, 0.06810675827520234, 0.07056846296680824, 0.09014710917004518, 0.04550458038491862, 0.1526128529970135, 0.2979291746658938, 12.285755242620196, 70.22928551265171, 55.68990898132324, 32.45877374921526, 12.39776975767953, 38.927779402051655, 46.245114939553396, 63.497842924935476, 62.66210665021624, 61.183717591421946, 59.3078498840332, 48.93126767022269, 0.3184897628213678, 0.20903954016310827, 1.1908671728202274, 5.55522460596902, 0.4980128939662661, 0.37103752312915667, 27.674296310969762, 58.66835158211844, 48.71650579997471, 58.12158046449934, 52.1903132711138, 57.24718441282, 49.88724946975708, 53.71926784515381, 49.599823338644846, 53.27052191325596, 49.742205824170796, 51.74325227737427, 48.77105610711234, 53.00719908305577, 49.930498531886506, 49.39809628895351, 44.40943908691406, 41.810291699000764, 37.089720317295615, 39.64536503383091, 37.627882616860525, 41.552513531276155, 43.66057961327689, 48.245626381465364, 46.63902916227068, 48.715599060058594, 43.860336848667686, 50.058835233960835, 44.30441359111241, 49.651469298771445, 49.74410268238613, 50.633798667362754, 43.84746878487723, 39.72986207689558, 35.91721527917044, 33.324793747493196, 34.521228381565635, 35.455667291368755, 34.741885798318044, 35.330881118774414, 33.20640339170183, 34.40746552603585, 32.35524559020996, 34.647310393197195, 35.23480837685721, 36.528545583997456, 35.965060574667795, 40.32902261189052, 45.00282914297921, 44.11399820872715, 39.851375647953574, 38.174851758139475, 36.84850318091256, 34.9457494190761, 36.27786152703421, 37.359504972185405, 42.251220907483784, 40.21495403562273, 41.37781844820295, 47.04846913473946, 39.29118061065674, 39.78225496837071, 39.33458253315517, 43.74914482661656, 42.49714544841221, 36.935727391924175, 34.60018423625401, 34.87910577229091, 35.49170412336077, 36.34233038766043, 36.46114458356585, 36.430812222617014, 37.94616569791521, 37.96735422951834, 36.64040810721261, 34.28493751798357, 33.56594140189034, 36.11860534123012, 35.5085882459368, 41.36477320534842, 42.93583038875035, 42.20538364137922, 36.70870542526245, 34.40461676461356, 34.765520095825195, 34.992229393550325, 34.778398581913535, 36.41454301561628, 34.594597884586875, 35.317220960344585, 34.383167675563264, 35.346438135419575, 35.28825044631958, 36.89751577377319, 36.1053968157087, 37.25461149215698, 38.560907568250386, 44.05660956246512, 48.39354658126831, 50.581013202667236, 47.71952615465437, 49.606201784951345, 49.660397733960835, 50.43889822278704, 48.317453384399414, 43.040789876665386, 40.938480377197266, 39.04737179619925, 38.86635732650757, 43.06795385905674, 43.84192412240164, 43.57460955211094, 42.46052496773856, 38.3676746913365, 39.293741021837505, 41.45753860473633, 44.172380447387695, 45.23408603668213, 47.28814377103533, 46.038965361458914, 49.63349430901663, 52.115533283778596, 55.70688343048096, 54.53952005931309, 55.04918432235718, 57.592419556209016, 61.39192731039864, 62.49655887058803, 50.83362538473946, 1.0412811424051012, 0.4059474713035992, 3.3839844167232513, 4.860615798405238, 0.6039066974605832, 2.141165997300829, 59.31536088671003, 66.86320291246686, 65.6041476385934, 70.91816466195243, 67.18055493491036, 53.855626242501394, 30.41846649987357, 34.430443218776155, 47.50057452065604, 74.03500843048096, 23.621769905090332, 0.39487953377621515, 0.11151972053838627, 0.16345745750835963, 0.007404470134393445, 0.03338663705757686, 0.20029188027339323, 0.10103970646326031, 0.19237906272922242, 0.20203087053128652, 0.13749733194708824, 0.3183676265180111, 0.37555757058518274, 13.910284893853323, 82.5895471572876, 63.5027414049421, 41.75126327787127, 23.358631202152797, 47.498490061078755, 52.6281817981175, 68.09427084241594, 67.65179565974644, 66.45473221370152, 65.10693454742432, 54.33251237869263, 0.47201143205165863, 0.8752202274543899, 5.8164112993649075, 11.475608314786639, 2.2203526624611447, 0.5241062566637993, 30.069621767316544, 59.603516578674316, 49.91463232040405, 60.81869397844587, 54.14766250337873, 57.993566853659495, 52.17503070831299, 55.798293931143625, 50.80074650900704, 55.73385633741106, 52.70932286126273, 53.3180684362139, 50.22085680280413, 53.42881577355521, 52.516312326703755, 52.854835510253906, 46.193371704646516, 43.06640093667166, 39.67048624583653, 40.98171901702881, 38.11059134347098, 44.39077622549874, 43.99539245877947, 50.76129463740757, 49.22321360451834, 51.44852706364223, 47.48406907490322, 53.47310011727469, 46.28386156899588, 51.27112913131714, 51.424732957567485, 53.48948049545288, 46.54128885269165, 42.14547627312796, 37.58935138157436, 33.67043536049979, 36.419302531651084, 39.03823144095284, 37.266583238329204, 37.636474064418245, 36.11955377033779, 35.87569284439087, 33.9950065612793, 37.42556497028896, 37.37383563177926, 39.5938024520874, 38.02625410897391, 42.31617961611067, 47.665354524339946, 47.24298048019409, 42.26938349860055, 39.512657914842876, 38.26380259650094, 35.30807018280029, 36.72024290902274, 39.03326347896031, 43.787224428994314, 43.34025028773716, 43.178704670497346, 46.819439138684956, 41.19945819037301, 41.72611774717058, 42.17174046380179, 45.58338240214756, 44.021920680999756, 38.88593735013689, 34.5423126901899, 35.518291405269075, 36.509104524339946, 36.80815846579415, 38.666165828704834, 37.24419961656843, 40.38664402280535, 37.553227697099956, 37.21892901829311, 35.64980690819876, 34.58065285001482, 37.64894955498831, 36.992049489702495, 42.190851484026226, 44.80140781402588, 43.00430835996355, 39.53775828225272, 36.052291733878, 36.2404420035226, 36.21491084780012, 37.01803575243269, 39.00978551592146, 36.61507150105068, 39.13821949277605, 35.99393728801182, 37.346709864480154, 37.04563399723598, 39.339328152792795, 38.05789967945644, 39.809797627585276, 39.92020102909633, 45.026425225394114, 50.13604014260428, 53.31955187661307, 48.43810190473284, 54.649371079036165, 52.00205877849034, 52.298621790749685, 49.47549227305821, 47.51567990439278, 45.08422034127371, 40.72880111421858, 42.505330426352366, 46.13739354269845, 45.44466161727905, 46.14193071637835, 44.726224831172395, 40.716794627053396, 42.64615304129464, 42.13293130057198, 47.037306853703086, 46.626640524183, 48.733282225472585, 48.983188084193635, 52.262803827013286, 53.43542351041521, 59.000517163957866, 56.40645933151245, 59.4971535546439, 60.894311223711284, 63.061801774161204, 62.96358898707798, 53.22866249084473, 1.6274529972246714, 0.32256908821208136, 7.977385742323739, 8.409850307873317, 0.956415627683912, 2.422293369259153, 67.40815012795585, 72.35580253601074, 71.43427685328892, 75.79964242662702, 70.25815527779716, 62.75016117095947, 38.63069180079869, 43.06907599312918, 56.525707789829795, 85.15734427315849, 33.0856853893825, 0.6247616612485477, 0.34475237929395264, 0.3001042322388717, 0.12248334687735353, 0.13131149459098065], [0.06844136424894844, 0.10955009622765438, 0.06361594210777964, 0.06575038935989141, 0.04345626636807408, 0.16082928782062872, 0.06741750240325928, 3.7964813794408525, 57.92280292510986, 51.81051778793335, 38.59887947354998, 35.44291039875576, 26.457249845777238, 36.371540614536826, 62.56665229797363, 55.45971516200474, 59.71545205797468, 53.16943604605538, 49.571300983428955, 1.7654825448989868, 0.25329242699912613, 0.398514418729714, 2.6861549019813538, 0.8347247689962387, 0.24893986912710325, 20.343312774385723, 61.93986919948033, 54.2383781841823, 54.788623401096885, 51.768220629010884, 50.40498406546456, 47.406040804726736, 51.32936198370797, 49.862051827566965, 48.20242248262678, 48.10628373282296, 48.08188165937151, 51.85537188393729, 52.227781432015554, 47.20385864802769, 44.743209702628, 39.10154342651367, 36.96989515849522, 35.876641273498535, 37.57065030506679, 40.0421210697719, 45.936090333121165, 46.22559744971139, 48.80633558545794, 45.22709614889962, 48.23608997889927, 46.14001301356724, 46.82799931934902, 48.23434945515224, 46.85210609436035, 47.34322908946446, 44.035341126578196, 37.028322560446604, 36.84019660949707, 33.908025537218364, 31.78883191517421, 33.17632811410086, 33.95823322023664, 33.339767115456716, 34.44637196404593, 31.894527912139893, 34.83490480695452, 35.703429630824495, 36.09844166891915, 32.955667223249165, 33.778677872249055, 34.17310626166207, 35.7130320412772, 40.02787031446184, 41.164394106183735, 41.1257586479187, 36.59124960218157, 35.50563178743635, 35.36002533776419, 33.88311277117048, 37.02610608509609, 37.74152735301426, 41.614849294934956, 41.49068151201521, 43.23758370535714, 42.463832310267854, 40.80274384362357, 36.983885356358115, 40.86714322226388, 39.236487865448, 37.181766578129356, 34.22651011603219, 34.36972638538906, 35.246939931597026, 35.95280047825405, 37.00239535740444, 36.781418323516846, 36.76579529898507, 34.58805268151419, 33.3918125970023, 34.538939339774, 32.852361406598774, 35.70303358350481, 39.32435131072998, 39.378463881356375, 42.914263180324006, 41.01181861332485, 35.030475752694265, 33.721789496285574, 34.477128165108816, 32.919057164873394, 33.127239091055735, 32.14874512808663, 32.27924271992275, 34.84448289871216, 33.7475152015686, 34.46463877814156, 33.6816462789263, 34.90341404506138, 34.40968894958496, 36.23459162030901, 36.788241454533164, 38.93378264563424, 47.64324535642351, 49.74077796936035, 46.83020884650094, 47.839017799922395, 46.424927370888845, 47.17081996372768, 45.74335772650582, 47.68047727857317, 45.323050771440776, 39.46588611602783, 39.166245051792686, 37.489651679992676, 40.026595320020405, 39.67490530014038, 39.25099570410592, 39.6034118107387, 37.774416651044575, 40.73142753328596, 45.28999471664429, 48.847614833286826, 51.491446086338584, 51.16273375919887, 53.381196294512065, 55.51937239510672, 57.626608167375835, 57.17110858644758, 60.033269609723774, 56.265872955322266, 59.746267318725586, 62.87999520983015, 45.425300461905344, 0.2556091084011963, 0.34324695436017855, 3.895395500319345, 7.0029642922537665, 0.502592028251716, 3.6018508289541518, 59.2123121534075, 59.611771038600374, 63.13710635049002, 63.53090245383126, 62.63555063520159, 46.78250251497541, 30.616215705871582, 25.004244293485367, 44.40328993116106, 63.675424984523225, 13.757426261901855, 0.44185071332114084, 0.1609236720417227, 0.0372821778458144, 0.027158961232219423, 0.041497125423380306, 0.035434272539402754, 0.06453510600009135, 0.05114253803289362, 0.08108318410813808, 0.03335164839934025, 0.1510941016354731, 0.220991527395589, 5.288537110601153, 65.7283466884068, 57.079031058720176, 39.61719356264387, 33.310525621686665, 35.105182783944265, 41.97589159011841, 66.14875439235142, 59.433813776288716, 62.84036268506731, 57.568427426474436, 52.617481572287424, 1.7390939380441393, 0.3133228543613638, 1.4975654355117252, 3.3364157463823045, 0.8542961073773248, 0.33051837022815433, 22.14381684575762, 64.25505760737828, 52.197435174669536, 57.16568204334804, 53.077917848314556, 52.55671262741089, 51.52712508610317, 52.457589626312256, 51.52092381886074, 51.44391693387713, 51.27381113597325, 51.20838689804077, 53.17758975710188, 52.51982116699219, 48.923377990722656, 47.02419212886265, 40.75494023731777, 38.46576588494437, 38.13275957107544, 39.265718936920166, 41.56879663467407, 48.32725729261126, 47.84276635306222, 49.64596285138811, 47.33452647072928, 50.53564146586827, 49.103489194597515, 49.17785229001726, 51.226559911455425, 49.376456124441965, 48.40322542190552, 46.04826899937221, 37.79525429861886, 38.25885895320347, 34.86210700443813, 35.39242131369454, 34.38125344685146, 36.028455938611714, 34.95503568649292, 34.57880462918963, 34.22755581992013, 37.19243206296648, 36.49971750804356, 35.718316146305625, 34.868884972163606, 35.225991112845286, 34.786837169102256, 38.52904312951224, 41.03596360342843, 42.7560909135001, 41.58678204672677, 36.5028407233102, 37.34140144075666, 36.19484097617013, 34.81021785736084, 36.33685868127005, 37.359831537519185, 42.76587050301688, 41.85570512499128, 45.17773267201015, 41.97893142700195, 42.519914695194785, 39.553527218954905, 42.3333694594247, 42.00353847231184, 38.30131244659424, 34.46124110903059, 35.23263359069824, 35.58803742272513, 36.75220809664045, 36.84346226283482, 37.63054725102016, 35.78020027705601, 35.33569622039795, 32.3310033253261, 33.783051763262065, 34.54425818579537, 35.84447111402239, 39.0627064704895, 42.308692932128906, 44.29787533623831, 42.71235547746931, 37.10773352214268, 34.75399998256138, 35.23436369214739, 35.334928444453645, 34.69432537896292, 33.71787418637957, 33.5841908454895, 36.62748793193272, 35.575530665261404, 35.54275948660714, 34.874988964625764, 35.995750767844065, 36.72578757149832, 38.20179687227522, 38.91179854529244, 41.40284238542829, 49.73577526637486, 51.86197962079729, 48.10972656522478, 50.282782622746055, 49.579319204602925, 50.707539899008616, 47.02788509641375, 49.628078188214985, 48.235165868486675, 41.224291052137104, 40.089664118630544, 40.03344624383109, 41.27202517645699, 41.01637315750122, 41.320402009146555, 41.58954048156738, 40.75427668435233, 43.167691775730674, 47.791742256709504, 50.84491620744978, 55.01367902755737, 53.14222342627389, 56.527587277548655, 58.940971102033345, 60.23792879922049, 58.75368240901402, 63.970779010227744, 60.15461989811489, 61.03435216631208, 63.81318691798619, 49.08577128819057, 0.6197337167603629, 0.2589905469545296, 3.6617241076060703, 3.5126911103725433, 0.7745964697429112, 4.337007803576333, 64.12669658660889, 66.0655288696289, 67.1235797064645, 69.72427654266357, 70.20387595040458, 57.67841741016933, 28.682948929922922, 27.278132608958654, 52.62399550846645, 70.5420308794294, 18.76769757270813, 0.6316548170787948, 0.15309126089726174, 0.06172922120562621, 0.07373091112822294, 0.011298623318517846, 0.12105606203632695, 0.22522349602409772, 0.20694156416824885, 0.16408010838287218, 0.2380628984953676, 0.27375416617308346, 0.26536872184702326, 5.957723328045436, 76.69852393014091, 65.01714297703334, 52.122446741376606, 47.00274303981236, 37.13616207667759, 48.872353894369944, 73.33261503492082, 64.59205218723842, 67.76629502432687, 64.03901726858956, 58.24161754335676, 2.4592334670679907, 0.5439769104123116, 3.5008470373494283, 8.202945981706891, 2.70032553587641, 0.5475539298994201, 26.2089455468314, 68.36053276062012, 53.746817452566965, 59.12791933332171, 55.70041465759277, 54.67417614800589, 52.254990577697754, 55.26275110244751, 53.80736058098929, 53.282924447740825, 52.02287905556815, 50.336610317230225, 54.314606870923726, 53.310501847948345, 50.52146366664341, 49.23570646558489, 42.97980901173183, 39.623842988695415, 40.463310446058, 41.05309438705444, 43.78455632073538, 51.73549113954817, 49.5727288382394, 52.16958679471697, 49.73179394858224, 53.68968588965279, 50.607148851667134, 52.01804310934884, 51.778288568769185, 50.95842545373099, 50.459947790418354, 47.952648639678955, 39.911463669368196, 40.52592761175973, 36.58549649374825, 35.184562478746685, 37.40838554927281, 37.26372405460903, 36.05025591169085, 37.17175422395979, 36.4518791607448, 39.86260393687657, 38.92453806740897, 37.13996621540615, 36.48739487784249, 36.97949062074934, 36.552186829703196, 41.36429030554635, 43.46964659009661, 45.53848661695208, 43.96733215876988, 37.437230995723176, 36.820168427058626, 36.59521354947771, 36.134676524571006, 37.51362296513149, 38.125630719321116, 43.99704613004412, 42.83200693130493, 45.37989745821272, 43.27054248537336, 44.575584411621094, 40.69661358424595, 43.07042741775513, 43.583471979413716, 38.106887953622, 34.57256862095424, 34.33685098375593, 35.40013381413051, 36.147454261779785, 36.73388222285679, 39.221702098846436, 35.465373924800325, 35.60398701259068, 32.80009705679757, 34.14838457107544, 35.80375814437866, 36.45328269686018, 40.69558872495379, 43.672551359449116, 47.476836000170024, 45.6885746547154, 38.395265987941194, 36.87584434236799, 38.0616899217878, 37.15384871619088, 36.968415192195344, 35.1329026222229, 36.26542772565569, 39.142492634909495, 37.23612233570644, 38.11894655227661, 36.175083773476736, 37.23242589405605, 38.558291571480886, 40.52016060692923, 40.02891254425049, 43.93268149239676, 51.319026538303916, 55.18814829417637, 50.978290353502544, 51.22844982147217, 52.15190362930298, 52.03241893223354, 49.20217098508562, 54.12880856650216, 50.07205070768084, 43.79955400739397, 43.23573548453194, 42.50906160899571, 44.13007634026663, 42.70793294906616, 44.24384961809431, 45.26181977135794, 43.10584586007254, 44.79318462099348, 50.66808802740914, 53.58058874947684, 57.026370661599294, 56.426692485809326, 59.56698295048305, 60.41898495810372, 62.81173610687256, 61.52445725032261, 66.99026462009975, 60.5407451902117, 64.08645956856864, 64.9012678691319, 51.482107707432334, 1.1169418139117104, 0.412728913128376, 8.47308760029929, 13.615429401397705, 0.7507731595209667, 4.772815755435398, 72.53623335702079, 71.92238780430385, 74.39115224565778, 74.27470738547188, 76.54800510406494, 63.598772457667756, 42.43589012963431, 37.40184729439871, 60.91961656297956, 81.85979175567627, 26.698734487806046, 0.8763514810374805, 0.3576614537409374, 0.3300737126597336, 0.1623707293931927, 0.1335231659135648], [0.06389203800686769, 0.05969029811343976, 0.022140592569485307, 0.0030313007009681314, 0.040018831712326834, 0.03729349241725036, 0.02193395490758121, 0.3784306235611439, 45.24453265326363, 53.271449497767854, 42.9767552784511, 25.01013289179121, 19.757652589253016, 36.438889503479004, 59.15460041591099, 56.64154120853969, 56.19961493355887, 52.35898426600865, 55.77780021939959, 5.242398032120295, 0.45491370665175573, 0.4967521759016173, 3.6581974625587463, 0.5547483009951455, 0.4438299999705383, 18.307023320879253, 53.64138201304844, 46.623486042022705, 56.89142969676426, 53.83297164099557, 57.12372187205723, 53.658182757241384, 52.7948134967259, 49.7038448197501, 52.72621393203735, 49.787556716373985, 50.811676025390625, 49.79960489273071, 47.45867688315255, 43.67250967025757, 41.60369048799787, 36.68250029427664, 36.09687485013689, 38.05970273699079, 41.634568282536094, 46.84449086870466, 47.06360231127058, 47.68939529146467, 46.194212436676025, 48.226650851113455, 45.05239759172712, 43.73862525394985, 49.71941225869315, 45.99924945831299, 44.38141005379813, 42.78404699053083, 37.542944363185335, 36.39205517087664, 38.35412917818342, 32.69828857694353, 33.26164157049996, 33.625789710453574, 34.871500968933105, 34.50067561013358, 33.948408467429026, 32.797203132084434, 36.01684897286551, 34.04473829269409, 34.61880193437849, 35.42750971657889, 34.38705171857561, 34.1136018889291, 36.12602949142456, 41.42967980248587, 40.912025111062185, 38.386205536978586, 40.60088130405971, 38.777361324855256, 35.080040727342876, 34.887662478855674, 37.06963654926845, 35.533101490565706, 42.69081606183733, 39.54624898093087, 41.30419881003243, 39.82546928950718, 40.45607737132481, 40.28297342572893, 38.85984686442784, 41.88774674279349, 38.13434723445347, 38.093755858285085, 36.931054728371755, 35.47160645893642, 35.94155829293387, 37.76704461233956, 39.91983624867031, 38.163144043513704, 35.727157729012625, 33.01588726043701, 35.31001220430647, 36.981005328042166, 37.758011954171316, 38.088120869227815, 40.67017568860735, 39.130771023886545, 40.216955116816926, 35.20823151724679, 36.472838401794434, 34.30164098739624, 34.930060386657715, 34.771297522953574, 37.4419071333749, 35.86561795643398, 33.018951416015625, 34.266236441476, 33.7192325592041, 33.82293789727347, 34.40391847065517, 35.25638253348214, 35.38231863294329, 37.94642972946167, 37.89510686056954, 40.24495983123779, 46.25859791891915, 47.4577944619315, 49.38073968887329, 47.744675159454346, 47.98713949748448, 51.17560182298933, 48.564882210322786, 48.49595260620117, 46.19982310703823, 43.829010895320344, 43.76355191639492, 40.189044203077046, 38.40870727811541, 39.310652937207905, 35.735175950186594, 35.54512882232666, 38.85634497233799, 48.47698054994856, 50.07636553900582, 55.789452348436626, 52.84532690048218, 54.51688977650234, 56.351676259722026, 55.23614297594343, 51.56942571912493, 49.018853187561035, 57.33092410223824, 61.085511752537315, 54.412663323538645, 39.52461576461792, 0.4942428448370525, 0.5920270692024912, 1.4083473086357117, 2.4283938876220157, 1.0220355008329665, 5.955813876220158, 62.36928871699742, 59.34290354592459, 64.09128856658936, 65.64523233686174, 63.08835778917585, 47.708332606724326, 19.728002888815745, 26.998151472636632, 48.68783058438982, 62.33162253243582, 8.363790699413844, 0.5009128983531679, 0.0962524451315403, 0.09474199225327798, 0.07433144854647772, 0.03398841619491577, 0.0663296886320625, 0.030530896902616535, 0.03174400555768183, 0.0467079588478165, 0.058125908486545086, 0.03394861672339695, 0.04525630102892007, 0.7265180296131543, 55.28330039978027, 60.73869241986956, 49.60110528128487, 31.334037576402935, 24.696887254714966, 43.751208441598074, 63.48080594199044, 60.99024500165667, 62.226211411612375, 56.664181913648335, 60.253145354134695, 5.467743745871952, 0.6570558569261006, 0.3256859523909432, 3.9391834821019853, 0.3971472792327404, 0.4218899229807513, 18.961378608431133, 55.87441144670759, 48.267270020076204, 57.747253213609966, 55.584306785038535, 58.50563171931675, 54.86774948665074, 55.12922409602574, 51.214675017765586, 52.496718406677246, 50.47134631020682, 52.6499331338065, 50.735905919756206, 48.36234222139631, 45.156175885881694, 43.487864766802105, 37.72937495367867, 37.10961300986153, 39.031168597085134, 44.07122162410191, 50.54572677612305, 48.233484404427664, 48.89960125514439, 48.648191111428396, 49.538269247327534, 45.60074247632708, 43.9704657963344, 50.72506672995431, 47.53513486044747, 45.68956824711391, 43.64722864968436, 39.49833072934832, 37.73024000440325, 39.52049895695278, 35.1092335837228, 34.93497971126011, 35.69511611121041, 36.38220609937395, 35.52552448000227, 35.40277065549578, 34.994365964617046, 37.02865259987967, 34.01538910184588, 36.173461369105745, 35.54418386731829, 36.90407139914376, 35.644717352730886, 38.07054887499128, 43.7190591267177, 43.32328278677804, 40.79620211465018, 40.479062012263704, 38.74571575437273, 37.30122000830514, 36.2662649835859, 37.20764166968209, 36.24912377766201, 43.16833448410034, 39.99513387680054, 41.34543636866978, 39.843590191432405, 41.03481715066092, 41.69393021719796, 41.25334841864449, 44.14563683101109, 37.334105832236155, 39.55481610979353, 36.652994768960134, 35.92911754335676, 36.28642518179757, 37.02315310069493, 39.91506631033761, 39.454355580466135, 35.42578656332833, 33.53496980667114, 35.624494620731895, 36.63405397960118, 37.747395106724326, 38.91670397349766, 43.37809017726353, 41.40551049368722, 41.82704380580357, 37.217952796391074, 38.33548368726458, 37.615355014801025, 36.81376566205706, 37.15003068106515, 38.69522319521223, 37.79098463058472, 34.67568336214338, 35.763406481061665, 35.613683223724365, 35.86909900392805, 35.95531225204468, 36.897276060921804, 36.45365789958409, 39.83896963936942, 40.16218594142369, 41.37757526125227, 48.3927857535226, 50.97520535332816, 50.1397956439427, 49.734639235905235, 48.959237643650596, 55.40590831211635, 50.93157066617693, 50.95393691744123, 49.640793391636436, 44.47931017194475, 44.6593588420323, 42.00452511651175, 40.40693276269095, 40.64137887954712, 37.53448840550014, 37.71114635467529, 41.327954701014924, 50.626013210841585, 53.38305146353585, 57.86956582750593, 55.42272642680577, 56.157352515629356, 58.2787834576198, 57.080893175942556, 52.162919998168945, 52.071155139378135, 58.32909188951765, 63.875852721078054, 57.71580566678728, 43.46137128557478, 0.5290792669568742, 0.1363571352724518, 3.8033296976770674, 2.673255354166031, 0.60491082072258, 6.337941782815116, 67.60582637786865, 64.00244889940534, 67.77873924800328, 71.11216531481061, 69.21963582720075, 54.51114361626761, 22.68374572481428, 30.4225937298366, 53.39250101361956, 73.06968130384172, 12.00933505807604, 0.4771193893892424, 0.20360566888536724, 0.07038177084177732, 0.07300044782459736, 0.03777977471639003, 0.11593872734478541, 0.17408270521887712, 0.22768348402210645, 0.15581080211060389, 0.13861459413809435, 0.14817739171641214, 0.16479003243148327, 0.8144491112657956, 63.3368809563773, 67.62542029789516, 58.074044363839285, 33.82994862965175, 29.731640543256486, 51.698683057512554, 69.19278103964669, 64.88882364545549, 66.67303766523088, 60.725518635341096, 67.81551606314522, 6.35800644329616, 1.0117553153208323, 2.1821510323456357, 7.65002657685961, 2.0185209555285315, 0.6993253859026092, 21.887886898858206, 58.68922397068569, 50.85259049279349, 58.413401331220356, 58.904903003147666, 60.54638712746756, 57.340926034109934, 55.53081955228533, 52.48735570907593, 54.871074199676514, 52.006832190922324, 56.18669128417969, 52.395347663334434, 52.579064982278005, 48.96110323497227, 44.569334506988525, 39.75579970223563, 38.80549110685076, 41.9808143888201, 46.68329266139439, 52.14980179922921, 50.18691832678658, 53.444292885916575, 51.323365688323975, 52.04870898383004, 48.67789118630545, 44.706432887486045, 52.10019513538906, 50.39575685773577, 48.80938237054007, 46.71762023653303, 42.58437660762242, 39.932961395808626, 41.7352546283177, 38.26097467967442, 36.72809437343052, 37.912122998918804, 38.15928084509713, 37.160380022866384, 37.5160687310355, 36.08971125738961, 38.23444645745413, 36.21975721631731, 38.68843480518886, 38.69453879765102, 39.297215121132986, 37.80255685533796, 39.80056694575718, 46.40289115905762, 44.95648465837751, 43.55584246771676, 42.72008882250105, 41.68911164147513, 38.28853818348476, 37.04435552869524, 38.03288269042969, 38.14895234789167, 44.61559213910784, 39.97238547461373, 42.3156133379255, 41.70924057279314, 42.17152506964547, 44.040972641536165, 42.98051077978951, 45.10895940235683, 38.05688524246216, 40.54535130092076, 38.148782117026194, 36.154819352286204, 36.856733322143555, 38.63963065828596, 41.11642026901245, 40.317464283534456, 37.70752286911011, 35.350106784275596, 37.91539907455444, 38.42430945805141, 39.4176412991115, 41.2375099999564, 45.23670550755092, 44.69767120906285, 44.243460518973215, 38.314566135406494, 40.03907428468977, 40.15468883514404, 40.010499817984446, 39.660981110164094, 40.95990514755249, 38.3033378464835, 37.455640247889924, 38.25724697113037, 37.33062825884138, 37.94085380009243, 38.61070530755179, 40.15904882975987, 38.66423422949654, 42.454994201660156, 42.13481078829084, 43.13037647519793, 51.21362931387765, 52.91114023753575, 53.09768547330584, 51.62638010297503, 51.348010948726106, 57.82021277291434, 53.94258294786726, 52.47260468346732, 51.92482260295323, 46.82926736559187, 49.00117697034563, 45.53926134109497, 43.19066946847098, 42.497319153376985, 39.01080690111433, 40.45076199940273, 44.67760133743286, 54.17570195879255, 55.1486998966762, 61.04872104099819, 56.44671024594988, 58.12416866847447, 61.942440032958984, 59.70091642652239, 53.129806995391846, 53.59798356464931, 61.50452286856515, 66.11033085414341, 59.06419045584542, 47.051713943481445, 1.0905151005302156, 0.6322190868003028, 8.563106724194117, 8.932390451431274, 1.2498505392244883, 8.183435440063477, 71.14692715236119, 71.53358745574951, 72.9690158026559, 76.49373967306954, 72.9384298324585, 63.69055816105434, 29.94471400124686, 40.019330978393555, 64.07498114449638, 84.11778259277344, 16.497776678630284, 1.036981076002121, 0.42774869288717, 0.15872747131756373, 0.13985502400568553, 0.17743890226951667], [0.12562351194875582, 0.06889635590570313, 0.10941397531756333, 0.017313489357807806, 0.034498070632772784, 0.03076976158523134, 0.14021132274397782, 0.044495385073657544, 37.74778767994472, 58.29582391466413, 42.52071721213204, 34.731856073652, 33.954418659210205, 32.786881583077566, 51.641367367335725, 56.6730443409511, 57.80839041301182, 52.11290686471121, 57.88668966293335, 11.448654515402657, 0.6854137352534703, 0.6985934366072927, 2.7435242235660553, 0.36746430343815256, 0.29462614761931555, 18.021914413997106, 61.98380265917097, 48.453113487788606, 56.55340330941336, 53.80401849746704, 53.11524357114519, 50.84548248563494, 50.48551368713379, 49.09353242601667, 50.622462681361604, 48.62179837908064, 51.626720564705984, 47.75094243458339, 43.2379276411874, 41.57209355490548, 39.02637086595808, 37.58861139842442, 36.90009355545044, 39.76017359324864, 44.96028879710606, 47.158671038491384, 44.84451791218349, 46.29676784787859, 49.26652520043509, 47.64898109436035, 49.35525369644165, 48.57302549907139, 47.03231109891619, 48.14108031136649, 42.93058449881417, 37.97343737738473, 37.460090569087434, 38.78099870681763, 38.039174284253804, 34.10757432665144, 34.23687335423061, 32.65473031997681, 33.3681400844029, 32.537944998059956, 33.38555921827044, 35.803726877485005, 33.936565262930735, 33.28553295135498, 33.47285638536726, 33.60683502469744, 33.04507316861834, 34.41829081944057, 36.16441134044102, 38.27492666244507, 40.71886171613421, 37.72640807288033, 38.37295184816633, 38.90820632662092, 36.93996926716396, 35.529345989227295, 35.27116482598441, 36.08270052501133, 41.41470990862165, 38.96111338479178, 41.72754560198103, 40.734088693346294, 40.99630675997053, 38.08881916318621, 35.525416782924104, 38.94351012366158, 36.535122053963796, 35.09712634767805, 36.2322952406747, 36.3752509525844, 36.46413925715855, 38.52291829245431, 40.01810809544155, 35.65180104119437, 34.61643607275826, 34.20114571707589, 33.60944407326834, 35.143557684762136, 38.32190343311855, 40.48007297515869, 41.338623659951345, 38.82760027476719, 37.05842910494123, 32.84045566831316, 33.23851101739066, 32.417126246861045, 33.672731740134104, 34.237912109919954, 32.34028264454433, 34.05327068056379, 33.6440634727478, 32.29258673531668, 32.62279292515346, 35.08372327259609, 33.95497451509748, 34.79415014811924, 34.668207100459504, 37.627361501966206, 39.91160263334002, 36.783648695264546, 38.64102029800415, 46.16773632594517, 46.65511771610805, 50.096796716962544, 46.38033383233206, 45.291047368730815, 50.131516865321565, 50.73202187674386, 49.98636204855782, 49.061230250767295, 45.18295771735055, 49.28452450888497, 47.84603200639997, 44.35912370681763, 41.83049358640398, 40.797640391758506, 37.431519576481406, 40.930187702178955, 49.62002522604806, 53.44593960898263, 55.61719260896955, 53.53660665239607, 53.237754208701, 54.41873604910714, 49.69382899148123, 44.64010190963745, 38.98901040213448, 57.68359381811959, 50.95112289701189, 38.48068714141846, 0.37754505393760546, 0.3027275843279702, 2.163558087178639, 0.7202795786517007, 0.7278714084199497, 7.404167175292969, 63.13813468388149, 58.018767969948904, 59.84852395738874, 65.8661642074585, 63.891013690403526, 52.9442275592259, 24.939077138900757, 32.00278432028634, 55.690433570316856, 55.62486342021397, 4.658321602003915, 0.48328955258641926, 0.17232977785170078, 0.13320289738476276, 0.0662667341530323, 0.06849754016314234, 0.07265915149556738, 0.03533508089770164, 0.1142713903848614, 0.056907330839229484, 0.08252448069729976, 0.0342188331165484, 0.05902479775249958, 0.1179894773023469, 46.54579128537859, 62.97316360473633, 49.90354299545288, 28.493379490716116, 34.36050265175955, 44.116718428475515, 57.41671698434012, 62.31530121394566, 61.042182786124094, 56.52012143816267, 63.42059285300118, 11.74278826372964, 0.8457618738923753, 0.06814191995986871, 5.176818328244345, 0.22089015426380293, 0.4326308880533491, 19.70200620378767, 63.28970268794468, 49.621835231781006, 57.969300270080566, 54.829183510371614, 53.862709930964876, 52.61252403259277, 52.79217318126133, 51.10771097455706, 50.83350379126412, 51.11463138035366, 52.90311506816319, 50.89665944235665, 45.903100286211284, 44.057891505105154, 41.24003914424351, 38.985730852399556, 37.713574750082834, 42.50740793773106, 47.06900800977434, 47.93402051925659, 45.9366010257176, 48.49832889011928, 50.411393778664724, 48.952824456351145, 51.030738830566406, 48.5249057497297, 48.71464020865304, 51.79016651426043, 43.91650261197771, 40.15890986578805, 37.87491886956351, 39.66000836236136, 40.15593603679112, 36.57712738854544, 35.18691444396973, 34.89268602643694, 34.257252420697895, 34.66216564178467, 35.69586999075753, 36.351866790226524, 35.98886857713972, 34.84470176696777, 34.38358804157802, 34.479348114558626, 35.373251233782085, 36.526082447596956, 39.03600106920515, 40.6194885798863, 43.08414316177368, 41.87358283996582, 40.36029645374843, 39.05100917816162, 36.90268523352486, 35.41099384852818, 35.65855121612549, 35.88872071674892, 42.37039988381522, 40.42374045508248, 41.6536271912711, 41.17510822841099, 40.466457980019705, 40.74197837284633, 37.90269776753017, 40.89255278451102, 35.351145539964946, 34.49434927531651, 35.5962884085519, 37.25373254503523, 37.85406037739345, 38.277375902448384, 39.35814387457711, 35.67804091317313, 34.16116925648281, 34.64926283700125, 34.15367215020316, 37.56165586199079, 40.0801659311567, 39.842468057359966, 42.251630851200645, 41.32918105806623, 39.40133040291922, 35.924670696258545, 34.50623764310564, 34.309224946158274, 35.50253289086478, 34.89887687138149, 33.940345082964214, 35.34728928974697, 33.67191185270037, 34.60671206883022, 33.72183813367571, 35.058602060590474, 35.376579420907156, 35.32259886605399, 35.902443408966064, 38.18051453999111, 41.01566791534424, 39.64503846849714, 40.24305602482387, 48.84852852140154, 48.930117743355886, 50.76449080875942, 48.33607108252389, 46.38173042024885, 51.84397336414882, 52.73380831309727, 51.34616272790091, 51.90912314823696, 46.85693161828177, 51.71820402145386, 48.21348054068429, 47.23897136960711, 44.45865317753383, 43.429298400878906, 38.75640903200422, 43.111810888562886, 52.55028554371425, 55.491558756147114, 55.83496652330671, 55.45130089351109, 55.35714585440499, 57.187541076115195, 50.50311694826399, 47.10358224596296, 43.42260033743722, 58.22122458049229, 53.474295207432334, 43.830178192683626, 0.7066098121660096, 0.32720182676400456, 2.856568374804088, 0.6500648834875652, 0.7930283035550798, 7.687658020428248, 69.85655634743827, 62.07362897055489, 65.07691138131278, 69.97522463117326, 68.71878187997001, 59.01719284057617, 20.92777786936079, 35.91885157993862, 61.02784865243094, 65.76709679194859, 6.918068162032536, 0.9075273967214993, 0.17879160254129342, 0.12405205198696681, 0.10804541089705058, 0.03460166257406984, 0.2816847749054432, 0.14051910622843675, 0.2192741281219891, 0.14466780503945692, 0.15673935014222348, 0.07612965455544846, 0.28076728699462755, 0.20374263796423162, 53.52167844772339, 73.94117995670864, 57.051658630371094, 46.967814445495605, 45.27496576309204, 43.83965900966099, 67.77603639875139, 66.09765039171491, 67.84513623373849, 59.921473094395225, 71.00108446393693, 13.461983646665301, 1.035872186933245, 2.729218751192093, 7.992137636457171, 1.6936821405376707, 0.4421642507825579, 22.7112831728799, 64.44215175083706, 53.124078205653596, 59.05105141230992, 56.27836581638881, 54.95130852290562, 54.11623580115182, 53.568769863673616, 51.70470714569092, 52.303002629961284, 52.879744802202495, 53.73274735042027, 52.171254362378804, 49.00707599094936, 46.12391056333269, 44.14935411725725, 41.03762769699097, 41.38259880883353, 43.67923205239432, 49.19132832118443, 50.32764366694859, 49.044193267822266, 49.300203119005474, 53.64851781300136, 50.88300275802612, 50.77497911453247, 48.77655560629708, 52.43689094270979, 52.36023146765572, 46.83524281638009, 42.13469614301409, 41.71183225086757, 41.33979095731463, 41.667103222438264, 38.041651317051475, 37.306389468056814, 37.0054977280753, 36.67014987128121, 36.74871662684849, 37.38814197267805, 38.579007625579834, 37.78587770462036, 37.46718120574951, 35.95577778135027, 36.92564902986799, 36.08621283939907, 37.63019984109061, 41.38038580758231, 42.287580830710276, 46.196046761104036, 45.20980208260672, 42.57302672522408, 41.44228730882917, 38.51882232938494, 35.532740184238975, 36.66172865458897, 36.18127809252058, 42.401656355176655, 42.26384231022426, 41.87545190538679, 41.64283316476004, 42.90835721152169, 42.39355822971889, 38.37423031670706, 41.6412524495806, 35.784723554338726, 34.61201007025582, 37.05298171724592, 37.43002223968506, 37.994771821158274, 40.08037437711443, 39.79362569536482, 34.78260224206107, 35.87402875082833, 35.29209974833897, 33.75811120441982, 39.22176810673305, 40.52785921096802, 42.26449544089181, 45.79576798847744, 43.1881160054888, 41.11056988579886, 37.21500676018851, 36.46878065381731, 36.606827463422505, 37.60400513240269, 38.863953249795095, 35.31444862910679, 37.14284971782139, 36.41968468257359, 36.76215444292341, 35.72327716009957, 38.53615461077009, 37.70070668629238, 37.80016320092337, 38.030350072043284, 39.610526766095845, 43.8140583719526, 40.5685304914202, 41.457569871629985, 50.6044807434082, 51.04084151131766, 54.06478091648647, 50.76895502635411, 48.57369252613613, 55.094434465680806, 55.8766313961574, 54.37280150822231, 52.193248885018484, 50.12823731558663, 54.340982232775005, 50.746908392224995, 48.77388054983956, 46.66384465353829, 45.59287016732352, 42.480521883283345, 44.7259156363351, 54.9362587247576, 57.64534745897566, 59.70432104383196, 57.8294677734375, 58.35066604614258, 58.999898774283274, 51.65110526766096, 46.07404334204537, 44.9439640045166, 62.77620301927839, 54.76278305053711, 49.60515260696411, 1.1247728679861342, 0.941920708332743, 9.795664174216133, 6.371638374669211, 1.322414594037192, 10.209735989570618, 75.89117104666573, 68.1906840460641, 69.6370210647583, 77.78975936344692, 73.86644513266427, 69.87168257577079, 35.80630118506295, 48.213223457336426, 71.3271495274135, 79.78304467882428, 11.80485999584198, 1.0861355641058512, 0.3474643751978874, 0.28917951988322393, 0.19541191070207528, 0.14900049540613378], [0.1234636807015964, 0.06331763097218104, 0.008867342440810586, 0.003989480568894318, 0.04078383584107671, 0.04965012740077717, 0.0835958399942943, 0.03978031986792173, 30.89500870023455, 62.879203115190776, 36.65906402042934, 29.142362083707535, 26.411596706935338, 32.933568477630615, 46.35293708528791, 53.584111486162456, 56.38850518635341, 49.561781951359336, 58.82561016082764, 20.804042611803325, 0.8631248793431691, 0.7217094419257981, 3.541049748659134, 0.05487384959789259, 0.05322647174554212, 28.63426637649536, 65.35187939235142, 55.47280556815011, 52.504872117723735, 55.277279785701204, 55.666663782937185, 53.69979204450335, 52.38798604692732, 51.05301822934832, 51.23944534574236, 52.472722802843364, 48.54575381960188, 43.73264632906233, 41.16444969177246, 38.72404432296753, 38.26119007383074, 38.22126225062779, 38.437559672764365, 42.39750133241926, 45.44345610482352, 45.31256593976702, 47.269018854413716, 51.0486512865339, 46.6111147744315, 46.452925137111116, 44.868760177067344, 51.28940289361136, 53.48365790503365, 44.78703546524048, 45.08403968811035, 45.381551129477366, 39.75925643103463, 37.07170363834926, 39.35094206673758, 36.7859138080052, 35.834854807172505, 32.86407606942313, 34.39749486105782, 33.62766224997384, 33.82600205285208, 32.23744930539812, 32.80834109442574, 34.4988169670105, 37.00929144450596, 35.04927410398211, 37.62599965504238, 34.49224397114345, 35.28243480409895, 37.895575863974436, 41.01307623726981, 38.57479701723371, 36.85067796707153, 37.35236917223249, 34.07379913330078, 34.30746357781546, 35.45926645823887, 35.57923752920968, 37.76777417319161, 39.24561085019793, 40.81206137793404, 40.425932611737935, 38.10445261001587, 41.16821214130947, 37.57441970280239, 39.15502718516758, 34.9282225881304, 33.65451008932931, 32.76301452091762, 36.198725019182476, 36.75912850243704, 39.51969296591622, 37.95604951041085, 36.85003873280117, 35.25949880055019, 33.401456696646555, 35.44812849589756, 38.785970142909456, 38.36045551300049, 38.18285608291626, 39.326404503413606, 41.44666467394148, 37.901756286621094, 34.15027448109218, 33.758913721357075, 33.13734524590628, 34.42131675992693, 32.11866290228707, 33.28514732633318, 31.77114874976022, 30.930788448878697, 32.34861353465489, 32.29632486615862, 34.13477652413504, 33.14082976749965, 34.113077299935476, 35.42191294261387, 38.53787428992135, 38.326468399592805, 38.898055008479524, 36.818181242261616, 42.57131746837071, 47.409914425441194, 48.68761171613421, 47.29297971725464, 45.43818242209298, 46.67478459221976, 47.05551808220999, 44.950380665915354, 47.95542097091675, 48.86094147818429, 49.40812948771885, 50.28890745980399, 51.09903267451695, 49.3822682925633, 49.84574440547398, 43.467405796051025, 37.44424172810146, 40.399244580950054, 46.66406004769461, 51.556755678994314, 55.2074156488691, 52.33176817212786, 55.111190046582905, 54.14114509310041, 60.71363026755196, 56.624691826956614, 60.15585667746407, 58.5710003716605, 59.88097204480852, 1.198965189712388, 0.3070014864206314, 1.2981372624635696, 1.0147182877574648, 0.5770568496414593, 15.710292169025966, 66.74930109296525, 57.129162311553955, 64.67294311523438, 61.70251178741455, 65.08014229365757, 42.433572905404226, 34.71962029593331, 33.37156902040754, 53.44825683321272, 55.08139617102486, 3.401026827948434, 0.33551385360104696, 0.12874000971870764, 0.14397230664534227, 0.024421264118115817, 0.06235069821455649, 0.1409979619617973, 0.11461742967367172, 0.0035008117348687457, 0.021199856352593218, 0.11994212466691222, 0.019052136955516677, 0.24941041959183557, 0.0693470931478909, 38.865589550563264, 68.92187077658517, 45.59533677782331, 32.460774830409456, 31.098347731998988, 40.679156235286165, 52.356229305267334, 62.47574206760952, 59.0795042855399, 55.6705721446446, 63.332941327776226, 21.988165037972585, 0.9101184234023094, 0.6153287759849003, 3.786773443222046, 0.2619008922151157, 0.21447584059621605, 32.124627930777415, 67.34114170074463, 58.38608796255929, 54.82030371257237, 56.706843852996826, 55.00982625143868, 55.06847252164568, 52.43400396619524, 52.3434168270656, 51.80181516919817, 54.325703144073486, 50.04822186061314, 44.318191868918284, 42.61391339983259, 41.31841482434954, 40.80860464913504, 39.84077617100307, 40.3346471786499, 45.32553822653634, 48.14029516492571, 48.0000388281686, 48.24196468080793, 52.27256604603359, 48.40327058519636, 48.9772994858878, 48.4938507761274, 54.584078856876914, 53.21759748458862, 46.0926262991769, 46.178030082157676, 47.55904361179897, 42.11046430042812, 38.92809207098824, 39.80672652380807, 37.50417341504778, 36.312432289123535, 35.18332917349679, 35.07452385766165, 34.09737089702061, 34.49532549721854, 34.37713316508702, 32.97945090702602, 35.53222949164254, 36.81443963732038, 37.12482956477574, 37.07870742252895, 35.92922871453421, 36.67996072769165, 39.042667865753174, 42.47420597076416, 40.068242822374614, 40.008870465414866, 39.53035845075335, 36.601261956351145, 34.922181129455566, 34.35017762865339, 35.014783246176584, 37.623373235974995, 40.10018021719796, 42.63437237058367, 40.59262684413365, 38.88716370718819, 41.59707580293928, 39.642238344464985, 41.31674378258841, 35.21128177642822, 34.673619747161865, 33.53976058959961, 36.95129483086722, 36.61776392800467, 39.47278915132795, 38.47242225919451, 35.67633860451834, 34.9088579586574, 34.750195843832834, 35.939550263541086, 38.803833961486816, 39.904001304081504, 40.832482133592876, 41.286348887852256, 43.42825269699097, 39.70009252003261, 35.32729237420218, 36.1160067149571, 35.856032916477744, 36.40241493497576, 34.266007150922505, 35.742044244493755, 33.270142691476, 33.54741750444685, 34.321571895054404, 33.302514348711284, 35.46385226930891, 33.98928471973964, 35.69188172476632, 37.58841684886387, 38.794888155800955, 40.670787130083355, 39.45661721910749, 39.400236061641145, 43.960647991725374, 50.901491914476665, 49.74547495160784, 49.25880922589983, 47.03062616075788, 47.35806001935686, 49.083415848868235, 48.08795785903931, 48.84497104372297, 51.54978663580758, 51.36896671567644, 50.948270661490305, 53.53252458572388, 51.07058674948556, 52.54889242989676, 45.49652991976057, 39.65238618850708, 41.61583941323416, 51.00642360959734, 51.996819836752756, 57.16951050077166, 55.02846826825823, 60.529120853969026, 55.20343085697719, 61.31123093196324, 59.15414183480399, 63.07817867824009, 60.13417829786028, 63.06328174046108, 1.9907025396823883, 0.3107446927045073, 2.072377745594297, 0.847417987883091, 0.3786580413579941, 16.267487321581157, 74.00563144683838, 61.281791414533345, 71.81172384534563, 67.07647786821637, 71.41380746023995, 47.0645820072719, 34.80329050336565, 38.71083927154541, 59.44935689653669, 67.04603781018938, 6.015134121690478, 0.452652312283005, 0.18827252808426106, 0.10918754818184034, 0.08736166185034172, 0.017668536198990684, 0.2707761031176363, 0.23689082424555505, 0.1170477249792644, 0.09511646894471985, 0.15821323676833085, 0.11949840347681727, 0.2446852374289717, 0.12142051676554338, 45.789368697575156, 80.72185053144182, 51.0106828553336, 41.3592528615679, 36.452678203582764, 45.888919012887136, 60.234545026506694, 62.39810289655413, 65.54261439187187, 60.22064168112618, 70.24531500680106, 23.72827536719186, 1.2104859543698174, 1.1921047121286392, 7.498046892029898, 0.5067356516207967, 0.20642648823559284, 36.158772877284456, 68.41625036512102, 59.62744617462158, 56.55118335996355, 58.21362672533308, 56.387511593954905, 56.56296750477382, 54.446070262363975, 53.800273418426514, 55.336322103227886, 56.67111621584211, 51.69946125575474, 46.863018240247456, 44.28452784674508, 43.37587022781372, 42.566693442208425, 42.18884692873274, 43.02915164402553, 46.49552801677159, 49.45856646129063, 49.421758379255024, 50.36736304419381, 55.20631088529314, 50.38290616444179, 49.68145424979073, 49.45661401748657, 53.2507438659668, 52.496509960719514, 49.04870959690639, 49.268098967415945, 51.217360496520996, 43.14775391987392, 41.91051251547677, 42.351764815194265, 40.334522111075266, 37.752627100263325, 36.71100180489676, 38.80825996398926, 37.35739966801235, 38.770802225385395, 36.03030068533761, 35.550628321511404, 37.58287566048758, 41.27470718111311, 39.686838831220356, 40.8437625340053, 37.508345808301655, 38.72481557301113, 42.196132114955354, 45.2145859173366, 44.177800042288645, 42.03280775887625, 40.58529649462019, 36.065844195229666, 34.531167779650005, 36.01341308866228, 36.08354125704084, 37.777734415871755, 41.52941771915981, 43.00681665965489, 41.967400891440256, 39.49956750869751, 43.76477132524763, 42.32940203802926, 42.36638729912894, 34.51661477770124, 35.911611557006836, 33.060334886823384, 37.27871131896973, 37.42424828665597, 40.582805565425325, 38.678453717912944, 37.23948873792376, 36.17745658329555, 35.20623738425118, 37.28301920209612, 40.24997990471976, 41.56655931472778, 43.7996825490679, 43.73354959487915, 46.946615491594585, 42.820441654750276, 37.99838488442557, 38.300829546792166, 36.300272941589355, 39.72926800591605, 35.05292885644095, 37.77210290091378, 35.83561563491821, 36.13474600655692, 35.51678017207554, 36.54954651423863, 37.7800794328962, 36.590200424194336, 37.00231197902134, 39.77951042992728, 42.17310578482491, 41.6656163079398, 42.47777387074062, 41.346770422799246, 45.99138757160732, 52.78244570323399, 52.98718132291521, 51.847207750592915, 49.33289786747524, 47.89138984680176, 51.48806231362479, 49.95665502548218, 51.74659088679722, 51.35156842640468, 54.830274377550396, 54.16394560677664, 55.720790249960764, 53.3863970211574, 55.733901500701904, 47.60466548374721, 42.206929615565706, 44.52890988758632, 52.89233841214861, 53.51484489440918, 61.14919894082205, 56.18612848009382, 61.43416540963309, 57.05050522940499, 62.865070479256765, 57.46521888460432, 66.36556598118374, 61.19197899954659, 66.08220454624721, 3.0328804339681352, 0.8210437116878373, 5.405039293425424, 3.9443142924989973, 0.7856114272560392, 18.84052859033857, 80.68698447091239, 66.93731934683663, 74.74818543025425, 72.28445148468018, 75.80882099696568, 56.8425213268825, 47.37230035236904, 47.41846765790667, 68.88001482827323, 78.88666452680314, 8.95439887046814, 0.5552884691527912, 0.2817667419356959, 0.26756657819662777, 0.13669686418558868, 0.14167622556643827], [0.03819056320935488, 0.04735242462317858, 0.11979174773607935, 0.05078748779903565, 0.15531585152660096, 0.046005654747464826, 0.1418919861316681, 0.18711273531828607, 22.139962332589285, 64.20788628714425, 39.73797409875052, 31.26016432898385, 16.52238893508911, 31.253365516662598, 44.518643924168174, 51.81940800803048, 56.43513107299805, 50.18225955963135, 58.89349406106131, 25.450763327734812, 0.22271496563085488, 0.48375079355069567, 3.4252102502754758, 0.06553266104310751, 0.33308116985218866, 43.41272347314017, 62.34952804020473, 52.29217733655657, 53.95505843843733, 52.99570676258632, 53.99779680797032, 53.852103505815776, 54.105723176683696, 53.00450665610177, 49.226312501089915, 47.19598633902413, 43.460853644779746, 43.91294166019985, 40.119145325251985, 37.66731364386422, 38.590798718588694, 41.02362012863159, 43.17625890459333, 45.18252692903791, 45.247322354997905, 43.39383132117135, 46.68361575262887, 46.00818484170096, 46.25364037922451, 46.977837221963064, 45.45640059879848, 38.59605155672346, 47.40527650288173, 53.38129356929234, 50.733529635838096, 48.32457876205444, 47.303686891283306, 42.56660311562674, 37.8494849886213, 38.0299505506243, 35.336172172001426, 33.89629002979824, 34.54038456508091, 34.41069991247994, 32.28505488804409, 34.99434164592198, 37.29945863996233, 40.946616717747276, 36.81974458694458, 34.74880967821394, 35.714560644967214, 34.975188936506, 35.18997859954834, 37.09710625239781, 40.31630393436977, 38.285797119140625, 38.40300628117153, 39.82254409790039, 35.73742021833147, 34.608244146619526, 38.701486996241975, 35.13392053331648, 34.447851930345806, 37.814511231013704, 42.314994948250906, 37.54023456573486, 37.36407341275896, 38.65778977530343, 36.40578481129238, 38.22095652988979, 35.1185302734375, 33.73004048211234, 35.4693135534014, 35.34366927828108, 36.218746253422324, 37.75807448795864, 36.89076212474278, 35.041221141815186, 35.248892375401084, 36.231850555964876, 36.65560729163033, 36.16394928523472, 39.96283170155117, 36.220069885253906, 38.32303598948887, 42.51474870954241, 36.3374388558524, 34.91632032394409, 32.65454619271414, 33.33623743057251, 33.722904682159424, 33.380636419568745, 33.322136061532156, 32.56178426742554, 33.09629528863089, 34.38038839612688, 33.916662148066926, 33.78480618340628, 33.22111620221819, 34.169430664607454, 35.250361919403076, 38.33652939115252, 39.67833423614502, 38.93379306793213, 44.135336126599995, 46.23458841868809, 47.22397715704781, 49.18642289297921, 48.49607767377581, 42.74728407178606, 43.168647153036936, 44.146088463919504, 43.7940788269043, 42.23002542768206, 41.74606949942452, 48.06652614048549, 48.25937339237758, 48.48188597815377, 49.3161735534668, 50.30479451588222, 50.24650955200195, 47.99858318056379, 38.6343743460519, 40.24489729745047, 40.391973291124614, 48.98212153570992, 51.85855415889195, 54.89379480906895, 52.03558383669172, 55.37400565828596, 54.37912089484078, 63.74702617100307, 50.42081206185477, 63.91187913077218, 5.049718839781625, 0.6370669209531375, 1.059779744063105, 0.4951706464801516, 0.3289747030607292, 21.038233382361277, 66.26919446672711, 52.75093214852469, 57.318740436008994, 65.13581820896694, 59.061862809317454, 54.80357592446463, 43.53209352493286, 25.703962632587977, 53.85766206468855, 43.348956380571636, 2.6553209679467336, 0.27367678603955675, 0.09920619627726929, 0.12266442073243004, 0.07108163221606187, 0.06388436377580677, 0.06025709877056735, 0.03079391403922013, 0.20487887199435914, 0.10447806053395782, 0.10027078379477773, 0.0387144193851522, 0.1807872825967414, 0.20418804192117282, 27.899909530367168, 70.93702902112688, 45.11757516860962, 36.65191432407924, 21.91857361793518, 40.90438904081072, 54.141892024448936, 60.2340794972011, 60.324517250061035, 54.64779036385672, 63.13714109148298, 27.01669795172555, 0.3209454353366579, 0.3343178406357765, 4.70472297498158, 0.13099708860473974, 0.07728009710886649, 46.155827113560264, 64.58946745736259, 54.71454518181937, 54.91815866742815, 56.26693255560738, 55.227238859449116, 53.370530809674946, 55.23477070672171, 53.64047179903303, 51.98588684626988, 50.03832067762102, 44.31367553983416, 45.98943860190255, 41.51444435119629, 39.660407883780344, 39.80797719955444, 41.919670241219656, 42.93175527027675, 47.17461715425764, 46.68202461515154, 47.03840119498116, 48.689049993242534, 47.49559613636562, 47.498087065560476, 46.92523241043091, 46.13683768681118, 41.91208628245762, 51.324515615190776, 54.12714447293963, 48.4166875566755, 49.2835065977914, 48.3273024559021, 44.42848757335118, 39.964697292872835, 39.69368975503104, 37.85147564751761, 36.39933688299996, 35.19281693867275, 34.26758091790335, 33.77751752308437, 36.61210462025234, 39.51055261066982, 40.81612260001046, 39.9824013028826, 38.04952710015433, 37.584824630192344, 35.64105217797415, 36.82668236323765, 38.009196281433105, 43.22434738704136, 42.97919757025582, 41.966751234872, 41.35499708993094, 35.27606330599104, 34.489895480019705, 38.254780360630576, 35.01881667545864, 35.33954552241734, 37.33830254418509, 40.87265314374651, 38.05505439213344, 38.737245900290354, 41.747507776532856, 39.283193656376426, 39.41062361853463, 34.872862815856934, 34.28555243355887, 36.96840476989746, 36.90985230037144, 36.89676536832537, 38.180716037750244, 37.457957472120015, 35.28660372325352, 34.726297514779226, 36.3708735874721, 37.198779242379324, 37.23306165422712, 40.104929310934885, 38.88443653924124, 42.008902481624055, 44.13310922895159, 38.10195473262242, 35.77790042332241, 34.88543210710798, 35.317828927721294, 35.288160119737896, 34.954045568193706, 35.191097259521484, 33.33817250388009, 35.44208008902413, 35.25605944224766, 35.07375260761806, 35.14572204862322, 34.12507683890206, 36.4391257422311, 37.0248658316476, 38.92471177237374, 41.891279901777, 41.199336596897666, 44.75147111075265, 46.802252769470215, 48.971980639866416, 50.51602322714669, 50.24913944516863, 45.07858187811715, 45.7220128604344, 45.64934165137154, 46.364849771772114, 45.12559338978359, 45.19594390051705, 50.35575607844761, 49.92401933670044, 50.79013313565935, 50.5557530266898, 53.43693821770804, 52.76713187353951, 50.266370977674214, 40.255396025521414, 41.792646748679026, 42.81672436850411, 52.078256198338096, 55.96852479662214, 57.960879053388325, 55.25461476189749, 59.47942175183977, 53.89369542258126, 66.08232266562325, 53.389721734183176, 69.34910855974469, 6.882521612303598, 0.9440351320164544, 1.2658333501645496, 1.0253721560750688, 0.28684742216553005, 23.055031401770457, 73.98100703103202, 57.32618890489851, 63.01356043134417, 68.13240255628313, 65.36495590209961, 53.85029697418213, 41.038218293871196, 30.207623413630895, 59.929331507001606, 54.888628823416575, 4.038933992385864, 0.41408400184341837, 0.19186136765139444, 0.0940748837643436, 0.05653229435639722, 0.040757030315165005, 0.18381190672516823, 0.10890862279172454, 0.25377196126750534, 0.14747797138988972, 0.3132009080478123, 0.11438999830612115, 0.23579786717891693, 0.2716367026524884, 32.09856523786272, 81.27620560782296, 52.231856550489155, 42.19470773424421, 24.616585186549596, 43.0119618007115, 59.20418970925467, 61.84108666011265, 66.32452297210693, 59.4654906136649, 68.41362394605363, 30.274572781154088, 0.31794899755290573, 0.9094921627214977, 8.079488652093069, 0.41389184072613716, 0.32861776649951935, 50.4282466343471, 67.37361063276018, 58.55031558445522, 55.856311389378135, 59.45328957693917, 57.106952394757954, 55.62466887065342, 58.22710623059954, 56.64367430550711, 53.13947193963187, 52.45103400094168, 47.19074044908796, 48.119565214429585, 42.398748534066335, 41.4580215045384, 42.24001693725586, 44.10977022988455, 46.08966984067644, 49.566471985408235, 49.22780636378697, 47.29337229047503, 50.209347111838206, 50.96398401260376, 49.60249492100307, 49.53901965277535, 48.47319378171648, 46.09228931154524, 50.36094290869576, 52.319716521671836, 52.111329623631065, 52.075025285993306, 50.94256271634783, 46.69565698078701, 43.275072710854666, 41.80232211521694, 38.86427286693028, 37.48904371261597, 37.10977976662772, 37.32795320238386, 36.0307696887425, 40.0715571131025, 43.291157790592735, 44.56381068910871, 40.90293686730521, 38.78638703482491, 39.228233405521934, 38.69935737337385, 40.172920908246724, 40.83167266845703, 44.30397238050188, 46.01125594547817, 45.948319162641255, 43.23139980861119, 36.086751324789866, 34.973983424050466, 38.87740496226719, 35.11874566759382, 35.37272664478847, 38.096945081438335, 43.67370476041521, 39.376021589551655, 39.16605050223214, 43.37100996289934, 40.90153680528913, 41.44827318191528, 35.52898120880127, 33.66994203839983, 36.82807200295584, 37.22449452536446, 37.140796525137766, 38.489021505628315, 37.05421502249581, 35.32021215983799, 35.680167061941965, 37.4761061668396, 38.35066897528512, 38.83545868737357, 42.05800887516567, 39.89170299257551, 43.28878150667463, 46.48923642294747, 42.50215857369559, 39.66792583465576, 37.2187032018389, 38.90712240764073, 38.44776310239519, 38.26000540597098, 37.48162998471941, 35.003085953848704, 37.36932972499302, 38.975645542144775, 37.79297181538173, 37.09048114504133, 35.692010266440256, 39.009361675807405, 39.05968400410244, 41.3866218158177, 44.09383801051548, 43.82153810773577, 48.653610706329346, 50.14364842006138, 51.753215994153706, 52.81780161176409, 51.19555010114397, 47.61329514639718, 50.62034695489066, 47.73517002378191, 48.26906960351126, 48.27765410287039, 50.90390641348702, 50.96143749782017, 52.796359470912385, 54.19627904891968, 53.77574280330113, 55.56855174473354, 53.990212849208284, 53.187963417598176, 42.4535732950483, 45.365101269313264, 45.096219880240305, 55.12232453482491, 56.37805162157331, 58.35988630567278, 55.95155382156372, 61.00098691667829, 57.94545405251639, 68.01608276367188, 55.191427843911306, 70.40749985831124, 9.239565968513489, 1.1597858177764075, 4.364924362727574, 2.7959792145660947, 0.5491545668670109, 26.82339906692505, 77.50259031568254, 62.43696417127337, 67.68980925423759, 74.43814291272844, 70.58989007132394, 68.2315741947719, 56.70474549702236, 39.239812578473774, 68.45024790082658, 68.13684245518276, 6.57117543901716, 0.7250104333673204, 0.3415023594030312, 0.2394522667995521, 0.1133963448394622, 0.15848914267761366], [0.08665113390556403, 0.03331308046888028, 0.014162322689246918, 0.03504991977076445, 0.04263556808499353, 0.07388818876019546, 0.10658856907061168, 0.20903689387653554, 14.440866708755493, 59.75210380554199, 47.38586671011788, 26.154879876545497, 22.575906208583287, 32.86913783209664, 40.40286806651524, 48.464501585279194, 55.00810309818813, 53.75088562284197, 55.75914083208357, 31.81029142652239, 0.03377282526344061, 0.5542569873588425, 1.1997187435626984, 0.03340232139453292, 1.2318879259484155, 52.45006125313895, 57.16053690229143, 54.881784847804475, 51.63830321175711, 53.44843053817749, 53.00383268083845, 53.553890296391074, 51.71692902701241, 51.28982673372541, 46.62032808576311, 43.99038628169468, 40.33842352458409, 38.60799551010132, 37.72235032490322, 39.83056231907436, 38.58141170229231, 39.74220902579171, 42.93650436401367, 44.95782218660627, 43.5031612260001, 47.98479448046003, 45.85103048597063, 42.27496985026768, 42.28412757601057, 45.076393195560996, 46.90566280909947, 47.15052080154419, 36.47339425768171, 40.09978764397757, 46.56022269385201, 47.98974854605538, 42.511493478502544, 42.89656611851284, 39.35649020331246, 37.722843647003174, 35.80681882585798, 36.03324324744088, 33.87248202732631, 33.88381801332746, 35.42966365814209, 37.9692337172372, 37.58899007524763, 33.8311367716108, 32.8476505279541, 32.72639751434326, 33.82919822420393, 33.358846868787495, 33.835910184042795, 36.297761167798726, 40.66578790119716, 40.60715552738735, 39.49298409053257, 40.86539575031826, 36.91447285243443, 34.01441287994385, 35.51471308299473, 35.003103324345176, 36.419434547424316, 38.4042534828186, 38.59295266015189, 39.555740220206125, 38.8795519556318, 40.742707933698384, 39.13938679013933, 39.38409539631435, 36.06641742161342, 35.697343008858816, 34.93892976215908, 36.500460965292795, 36.85470444815499, 38.15441363198416, 35.55060052871704, 35.79669877461025, 35.244598388671875, 36.73648084912981, 35.87595687593733, 39.290166173662456, 38.10552263259888, 38.44718292781285, 40.306454862867085, 35.8373908996582, 35.87030104228428, 34.35573271342686, 34.13442216600691, 33.599636690957205, 32.30667768205915, 32.97660561970302, 34.037915161677766, 33.39242056437901, 32.64387028557913, 33.264354842049734, 32.9468013218471, 33.17358704975673, 33.84023196356637, 35.622719355991904, 35.74110276358468, 36.89880813871111, 40.08267075674874, 44.67155987875802, 47.243439061301096, 48.12722212927682, 48.06055416379656, 48.85435806001936, 42.6921501159668, 37.44945982524327, 38.751979555402485, 41.80214841025216, 44.86066205160958, 49.026200907570974, 45.75143848146711, 40.2960638318743, 40.166945457458496, 48.42325013024466, 48.775395257132395, 53.25495447431292, 50.32062251227242, 48.893063000270296, 43.87890938350132, 40.226686068943565, 36.3613406590053, 44.019725050245015, 49.48320477349417, 56.36183452606201, 52.4394200869969, 59.92005566188267, 50.287833963121685, 55.98447438648769, 51.877349036080496, 68.51465770176479, 12.63296627998352, 0.6138592319829124, 0.9012967082006591, 0.1720005390899522, 0.17445805722049304, 22.921394961220876, 66.54311329977853, 54.6073032106672, 62.40856688363211, 63.578275271824424, 58.87628337315151, 49.68364640644619, 35.27307210649763, 26.944898741585867, 54.23049545288086, 45.93565954480852, 1.4675102425473077, 0.09115605681602444, 0.10223440985594477, 0.06326591303305966, 0.0171786983763533, 0.019790294846253734, 0.03971139428072742, 0.08815150375344924, 0.07838346290269069, 0.051797297184488604, 0.05832599489284413, 0.024245603276150565, 0.08488428299980504, 0.1619219056197575, 18.495182275772095, 69.71029676709855, 50.42711755207607, 32.574926785060335, 24.041468892778667, 40.77180698939732, 46.28494896207537, 54.14737415313721, 60.31413664136614, 56.57410546711513, 61.421867098127095, 35.23587492534092, 0.030775953217276504, 0.11185583285987377, 2.7768616804054806, 0.1315398080540555, 1.4725344415221895, 56.34380395071847, 61.18999181474958, 58.05775778634207, 53.75550617490496, 55.01039947782244, 54.10252005713326, 56.16466549464634, 53.886747223990305, 53.86217491967337, 47.412377561841694, 45.966103076934814, 40.86596202850342, 40.88602147783552, 39.49988712583269, 42.62424884523664, 41.086779253823416, 42.02632508959089, 44.18972315107073, 46.091087273189, 46.22679601396833, 48.464209760938374, 47.77561896187918, 45.29147815704346, 43.497133663722444, 47.43024138041905, 48.3405978339059, 49.25005102157593, 39.293358870915, 43.71809680121285, 48.424549443381174, 47.52386488233294, 42.66771330152239, 44.992914063589915, 42.018088000161306, 37.63830838884626, 37.598390987941194, 35.88556276048933, 34.43013749803816, 33.73472704206194, 36.48282296316964, 38.72125114713396, 39.672782625470845, 36.961685861860005, 35.18057073865618, 34.693505491529194, 36.08889831815447, 37.02501521791731, 35.206532682691304, 36.532273292541504, 43.24405942644392, 43.701104981558665, 43.82690559114729, 42.15170880726406, 36.441342217581614, 33.67799152646746, 36.168548992701936, 34.26808813640049, 36.676712444850374, 39.01969017301287, 40.54360382897513, 38.11638266699654, 38.4102532523019, 43.22104351861136, 39.45182991027832, 41.20819902420044, 36.170119285583496, 36.27251488821847, 37.17699663979666, 36.73475769587925, 37.56149952752249, 38.54233503341675, 36.12576198577881, 35.00899887084961, 35.891836983816965, 35.42689480100359, 35.92959349496024, 39.92172963278634, 39.60803236280169, 41.845776149204795, 42.44841078349522, 39.03157159260341, 38.749964577811106, 37.28646898269653, 37.35733018602644, 34.89315502984183, 33.30937916891915, 34.182090282440186, 35.36721324920654, 35.116087981632774, 33.646252155303955, 34.701495919908794, 35.03925480161394, 34.36067983082363, 35.82303939546858, 36.52521044867379, 38.056933879852295, 40.500476360321045, 41.57425791876656, 46.21906961713518, 47.12667458398001, 48.97723695210048, 48.65851960863386, 49.32690852028983, 44.755660874503, 40.14238357543945, 41.374208859034944, 42.946033818381174, 44.01698746000017, 48.381501879010884, 47.49309131077358, 43.00737598964146, 43.82179866518293, 49.27228873116629, 49.08227287020002, 54.72102437700544, 51.8680488722665, 51.83988782337734, 45.85243402208601, 42.33808381216866, 38.05065270832607, 46.49242564610073, 51.03545318331037, 58.25638246536255, 55.137256213596885, 61.907205717904226, 51.924801758357454, 59.58896705082485, 53.23583650588989, 72.13669109344482, 17.051360504967825, 0.5150723499911172, 1.2731101768357413, 0.624415499823434, 0.2255545939717974, 24.125099148069108, 72.88409491947719, 58.352687971932546, 65.91798387254987, 67.72079821995327, 64.76760537283761, 58.30837236131941, 40.07849836349487, 30.919445514678955, 59.947876249040874, 55.793173108782085, 2.9551911056041718, 0.2777302728167602, 0.1511209580515112, 0.020623052392953208, 0.12308469175228051, 0.036714328852083, 0.18698955407100065, 0.23936001317841665, 0.18793106212147645, 0.11704389804175921, 0.2477181532553264, 0.23710969250117028, 0.26632426200168474, 0.34171816068036215, 21.794444050107682, 80.33253601619175, 59.29487064906529, 38.754348891122, 32.00489657265799, 44.98464570726667, 52.56399086543492, 57.88841281618391, 63.92367022378104, 62.52484498705183, 65.6024592263358, 38.660721915108816, 0.18325392023793288, 1.0502356333392007, 6.886140320982252, 0.36673276126384735, 1.6075546592473984, 59.485397202628, 60.821070262363975, 61.127027239118306, 54.846977846963064, 57.56740951538086, 55.00798150471279, 57.86320127759661, 55.764574323381694, 55.47010966709682, 49.19248519624983, 48.65403454644339, 43.910912786211284, 42.67695093154907, 41.594258308410645, 44.97476189477103, 44.567833696092876, 43.71140916006905, 45.997891085488455, 50.323843002319336, 47.15559993471418, 51.50806965146746, 51.640193121773855, 46.73379564285278, 45.38369812284197, 48.895550455365864, 51.17859649658203, 50.25213759286063, 43.50438758305141, 47.433833599090576, 49.67014953068325, 49.591614042009624, 46.52198675700596, 47.37452725001744, 43.75443240574428, 41.720006806509836, 39.09990017754691, 38.78410455158779, 37.72547354016985, 37.32382597242083, 39.02785430635725, 41.138880320957725, 41.39017234529768, 38.02712958199637, 36.54536369868687, 36.840644768306184, 37.06337622233799, 37.986378397260395, 36.4160646711077, 37.11191633769444, 45.22707183020455, 45.491756507328574, 47.05408327920096, 45.25062622342791, 38.34354012353079, 33.956329413822715, 37.45530673435756, 35.8310923576355, 36.53623723983765, 39.6822703906468, 40.275514534541536, 40.8728928565979, 39.96836594172886, 45.880574226379395, 43.12388685771397, 42.38465411322457, 38.77677420207432, 37.32981879370553, 36.4392021724156, 36.38485336303711, 37.075452191489084, 38.627526896340505, 35.43353380475725, 35.11440304347447, 36.77836806433541, 37.374846594674246, 37.368183272225515, 41.468106814793174, 41.10304151262556, 44.31718438012259, 46.27285214832851, 42.65008224759783, 41.06613962990897, 39.58135822841099, 39.18589803150722, 37.11128405162266, 35.20359359468733, 36.681680406842915, 37.68362801415579, 37.521540437425884, 35.93455450875418, 35.73360218320574, 36.77143376214163, 35.75076075962612, 37.45524072647095, 40.19240713119507, 40.56587975365775, 41.50227458136422, 43.58751583099365, 49.40151480266026, 49.53813375745501, 50.85147878101894, 52.65090935570853, 52.90908704485212, 45.85629027230399, 43.04476424625942, 43.674503803253174, 45.47579649516514, 44.15891831261771, 49.71062626157488, 49.274925572531565, 47.617648192814414, 46.26547316142491, 49.53425318854195, 50.26364033562796, 56.017242091042654, 54.00467899867466, 53.45913076400757, 48.236357484545024, 44.93645300183977, 41.41750308445522, 48.39795173917498, 53.831967626299175, 62.10472910744803, 57.96790715626308, 63.57267502376011, 55.11376435416085, 61.14880984170096, 56.4087244442531, 70.96437018258231, 22.524942908968242, 0.6745870304959161, 2.806982555559703, 2.70755643929754, 0.5096224652869361, 27.45693407739912, 79.12074933733258, 65.08554799216134, 73.71842070988247, 71.40127290998186, 69.77968842642647, 63.4537843976702, 49.956985064915244, 42.123999391283306, 68.04044314793178, 70.746182850429, 5.236813417502812, 0.49877453595399857, 0.36739115736314226, 0.1587000856442111, 0.19203153066337109, 0.12476941277938229], [0.06089022622576781, 0.010342273162677884, 0.14558304021401064, 0.021658476475360136, 0.04088105973122375, 0.05991253190274749, 0.12366582985435214, 0.08222304830061537, 7.533706784248352, 60.50384330749512, 44.95704051426479, 25.987926823752268, 19.174368688038417, 38.47422184262957, 42.03602130072457, 48.6772450038365, 51.47334950310843, 55.4714298248291, 50.48952974591936, 45.110686029706685, 0.39218604830758913, 0.117941233462521, 2.2426392265728543, 0.20377589975084576, 2.4643256281103407, 54.163243838718955, 58.30935900551932, 53.064375809260774, 46.21425104141235, 44.55948543548584, 48.400734492710654, 49.526624066489084, 48.11296442576817, 45.6554525920323, 42.03679949896676, 38.88945313862392, 37.322846276419504, 37.805013043539866, 37.18584517070225, 38.02949891771589, 39.38487012045724, 41.53261041641235, 42.003114632197786, 41.51985699789864, 45.377100808279856, 42.98553432737078, 41.94197048459734, 36.4787061555045, 37.93682731900896, 41.26135621752058, 43.45127902712141, 45.591393675122944, 49.19723081588745, 42.90039110183716, 41.671226978302, 41.05001980917794, 41.968238149370464, 41.13253314154488, 38.624344621385845, 35.77425261906215, 35.48601702281407, 34.49142408370972, 35.15114164352417, 35.76040138517107, 33.32969570159912, 32.81149557658604, 33.906698431287495, 32.069643361227854, 33.67564303534371, 35.2434206690107, 34.0528815814427, 34.20553697858538, 34.52467468806675, 36.41882310594831, 41.200271129608154, 40.189864090510774, 43.90535075323922, 39.663451194763184, 37.82068470546177, 34.26144565854754, 35.11515344892229, 35.161883558545796, 34.646410601479666, 34.99177081244332, 37.85483510153634, 37.00869389942714, 37.17336968013218, 41.52640220097133, 39.785246167864116, 41.839029448372976, 34.8766530581883, 35.588582856314524, 36.937071868351524, 37.18564019884382, 35.45084524154663, 35.93927580969674, 36.556122984204976, 34.273483412606375, 36.578673362731934, 35.60051638739449, 34.551164695194785, 36.955734729766846, 39.27659286771502, 38.958744049072266, 35.1362099647522, 39.0857640675136, 38.0476267678397, 34.50468124662127, 33.386851583208355, 34.32093613488333, 31.723814146859304, 32.655713490077424, 31.751360280173166, 34.344761507851736, 33.46055112566267, 32.53403663635254, 32.65725251606533, 33.96845749446324, 36.84667233058384, 35.285794258117676, 38.02647992542812, 36.85605934688023, 41.700152329036165, 45.34765086855207, 45.99195384979248, 47.862290791102815, 46.4238087109157, 44.317823614392964, 43.613408293042866, 47.0473643711635, 46.60559095655169, 45.61768218449184, 42.43393073763166, 43.428440298352925, 49.74335922513689, 51.38941526412964, 47.59156118120466, 48.49527168273926, 50.076490606580464, 52.8617593901498, 49.51663950511387, 46.645959990365164, 43.471786635262625, 40.762541566576274, 39.75292314801897, 41.31871359688895, 47.26640633174351, 54.79490804672241, 48.5999984060015, 52.33912631443569, 45.24113845825195, 55.452843393598286, 49.80680670057024, 65.138229233878, 17.32923981121608, 0.4460310590054308, 0.7699578957898277, 0.7713424872074808, 0.11017611263585941, 25.7607832636152, 64.84646742684501, 52.122168813432964, 65.31795133863176, 62.62564945220947, 58.141504423958914, 32.696523734501426, 25.633433205740793, 31.280328001294816, 56.592886447906494, 44.02521065303257, 0.5089810054217065, 0.05217873225254672, 0.11168488953262568, 0.02247604671200471, 0.03564707808462637, 0.05983925690608365, 0.12121848974909101, 0.011871939608162003, 0.09151440473007304, 0.051919474199946435, 0.08120751886495522, 0.05701248001839433, 0.18253286821501596, 0.1355192938021251, 10.377105065754481, 68.62994221278599, 51.56605931690761, 32.59773077283587, 24.862794603620255, 43.384131635938374, 44.71959624971662, 49.64464964185442, 56.40237031664167, 59.60958930424282, 56.33876998083932, 47.316902365003315, 0.34439728834799355, 0.47361771443060463, 1.525996487055506, 0.31681891105004717, 2.755041948386601, 58.97663620540074, 60.45884677342006, 55.97227334976196, 48.236152512686594, 47.13247285570417, 52.9960298538208, 52.74321617398943, 49.13486725943429, 48.08048159735543, 43.573563848223, 41.63555492673601, 39.6398412159511, 39.940524509974885, 39.591968127659385, 41.59258379255022, 42.13352884565081, 43.69424016135079, 43.33513988767351, 43.945282050541465, 46.46578972680228, 44.38530451910836, 44.31559671674456, 38.32990080969674, 39.68239893232073, 44.36239283425467, 45.11792605263846, 46.98082494735718, 49.64256518227713, 44.98567404065813, 43.640683446611675, 44.90117699759347, 43.65599727630615, 44.09830917630877, 39.81497056143624, 37.42232016154698, 36.299182074410574, 36.92816775185721, 37.02887841633388, 35.80315365110125, 35.02900620869228, 33.68696859904698, 35.638491766793386, 35.05629178455898, 36.34169462748936, 36.09468616758074, 36.24233538763863, 35.168869972229004, 36.239976474217, 38.60605001449585, 42.43459776469639, 43.328615529196604, 45.69411236899239, 42.431266103472026, 38.256673744746614, 36.353944301605225, 35.461601052965435, 34.98838356563023, 33.88280357633318, 35.33853803362165, 37.1775872366769, 38.19364316122872, 38.44996220724923, 42.26015976497105, 42.02587693078177, 43.10463687351772, 33.570659228733604, 35.7855156489781, 37.65734297888619, 37.066885062626426, 35.9491422516959, 34.90625933238438, 38.0678460257394, 35.685885429382324, 36.48999350411551, 35.16488865443638, 37.30914095469883, 38.37972634179251, 40.70314836502075, 39.44731705529349, 38.878332546779085, 40.9631256375994, 38.894928319113596, 35.76418120520455, 34.26467309679304, 36.31528452464512, 32.45768288203648, 33.16378314154488, 34.51586089815412, 36.6530190876552, 35.35197932379586, 35.021248544965474, 35.277630124773296, 36.23782253265381, 39.21217611857823, 37.06288290023804, 39.54756913866316, 39.60595832552229, 42.490819113595144, 48.21865694863455, 47.746474742889404, 49.30867644718715, 48.442232608795166, 46.753552845546174, 45.203673771449495, 48.824505124773296, 48.847118037087576, 49.14652286257063, 44.63408129555838, 45.25422886439732, 47.689767020089285, 52.47704110826765, 49.5346805027553, 49.544074467250276, 50.225063937050955, 55.315630367824006, 51.38634763445173, 49.75921154022217, 44.11543301173619, 42.4119223185948, 42.299833978925435, 43.35193715776716, 48.51842655454363, 56.21333762577602, 52.16763435091291, 55.12781361171177, 47.01745932442801, 57.71657344273159, 54.2389166695731, 68.74542822156633, 23.045706919261388, 0.3448261224797794, 0.9332535905497414, 0.6110574251839093, 0.184283420709627, 28.019062450953893, 72.56866059984479, 56.84439386640276, 70.30219990866524, 65.71533966064453, 65.65165942055839, 40.5768266405378, 26.53502450670515, 37.997575419289724, 62.97593593597412, 53.419220311301096, 1.0872692061322076, 0.10065311792173556, 0.05680275162948029, 0.059921854973903725, 0.08952977801007883, 0.05811178817280701, 0.23622634847249302, 0.18767009755330427, 0.2549966355519635, 0.10172946445111718, 0.16347968631557055, 0.13662028472338403, 0.5216973487819944, 0.23734489988003457, 12.125104205948965, 78.85651629311698, 57.696805817740305, 37.338041986737935, 27.98957255908421, 49.33402694974627, 53.0629757472447, 58.05927249363491, 60.13666575295584, 64.776533808027, 60.533727509634836, 52.04230621882847, 0.7638292589357921, 0.9777764528989792, 6.434442707470485, 0.36229269951581955, 2.940680878502982, 61.72067437853132, 62.56625625065395, 60.55821296146938, 49.221768379211426, 48.55698210852486, 53.218664033072336, 52.9977946962629, 50.83456686564854, 49.72952536174229, 43.90379088265555, 43.54157434191023, 43.097890172685894, 42.016253675733296, 41.3214407648359, 43.3076354435512, 43.37812491825649, 47.329996245247976, 46.91517489297049, 45.893591676439556, 49.14166954585484, 45.29397256033761, 46.48964984076363, 41.913743427821565, 42.685347829546245, 45.69962576457432, 47.54277787889753, 49.08179691859654, 51.50884437561035, 47.77699817929949, 46.61270243780953, 46.85706015995571, 44.811642510550364, 44.59827375411987, 41.076624461582725, 39.832400117601665, 39.246819836752756, 38.38566357748849, 37.816039834703716, 39.81463704790388, 36.96815116064889, 34.606322969709126, 37.17752122879028, 36.10843317849295, 37.21912704195295, 38.00259896687099, 37.79125213623047, 37.38529321125576, 38.88972411836897, 40.35167373929705, 46.07662459782192, 44.7276040485927, 48.97133098329817, 44.49236583709717, 37.79984358378819, 35.78883688790457, 34.57985380717686, 35.33261816842215, 32.48847382409232, 34.68264198303223, 37.92218746457781, 37.17593356541225, 38.93797588348389, 45.75741393225533, 45.38210698536464, 43.006368500845774, 34.11961555480957, 35.704777581351145, 38.12564808981759, 38.42067207608904, 37.64285251072475, 35.4200508253915, 36.82077986853463, 36.121384620666504, 37.873133182525635, 35.39821611131941, 35.45608418328421, 39.540176255362375, 44.08505201339722, 43.69920117514474, 41.758756910051616, 42.7405686378479, 40.667076792035786, 37.701106207711355, 36.8990478515625, 38.630563259124756, 33.24102626528059, 34.66082811355591, 35.941711153302876, 39.016059739249094, 37.05865492139544, 36.05613061359951, 36.918673038482666, 39.368517535073416, 41.966514996119905, 38.690390723092214, 42.121703011649, 41.07252849851336, 46.24763713564192, 50.03553792408535, 49.10561186926705, 50.98800046103341, 50.207339082445415, 47.38483142852783, 46.04876579557146, 50.86026130403791, 49.57970830372402, 49.750957080296104, 46.6298679624285, 46.90989773614066, 49.77415711539132, 52.52776643208095, 54.0203298160008, 53.09367983681815, 54.6465744291033, 58.35908726283482, 53.97594819750105, 50.019696031297954, 46.55728360584804, 44.762987749917166, 44.52009262357439, 44.79250022343227, 52.58677748271397, 58.52977670942034, 53.90895366668701, 56.816364833286826, 50.13389662333897, 59.158255168369834, 57.48892266409737, 70.75723048618862, 29.427924360547745, 0.31795279734901016, 3.1257921797888617, 2.374966148819242, 0.3695558469210352, 31.382473468780518, 76.9813711983817, 61.6312232698713, 76.80702699933732, 70.21318653651646, 72.0221083504813, 46.836038385118755, 38.06908975328718, 47.17169543675014, 71.07465199061802, 65.0240981238229, 2.1478156404835835, 0.3424219372017043, 0.2710416817239353, 0.17949562333524227, 0.13126688769885472, 0.13299773553652422], [0.03844065764652831, 0.041005133252058706, 0.04984236994226064, 0.0035687341504464193, 0.0644054040312767, 0.08281105317707572, 0.009365996129677763, 0.10585883179945604, 4.840231955051422, 59.788053785051616, 49.004077843257356, 36.5823107446943, 30.746720245906285, 34.67248371669224, 42.92106894084385, 55.765373366219656, 47.23453841890608, 56.76765101296561, 47.64562858854021, 53.592292990003315, 2.0778618284634183, 0.35810038447380066, 0.7771147574697221, 0.030641508288681507, 1.5157647218023027, 52.19542714527675, 59.79527991158621, 55.11520957946777, 47.22247634615217, 41.712725094386506, 43.44399731499808, 43.37924010413033, 42.06131969179426, 39.29483536311558, 37.795698983328684, 35.368338857378276, 36.46015793936593, 36.989982400621685, 36.19469158990042, 37.07332604272025, 39.38681909016201, 39.944915771484375, 40.80451910836356, 41.79771893365042, 44.23710986546108, 41.919173445020405, 37.523909773145405, 35.913984366825645, 38.099526337214876, 39.872789996010916, 42.589879580906455, 43.65374953406197, 41.64900663920811, 45.73890740530831, 49.39123146874564, 45.74574095862252, 44.744147709437776, 40.61634452002389, 37.238946778433665, 37.23602853502546, 36.85816812515259, 34.4717606816973, 34.82014683314732, 33.11729621887207, 32.56002984728132, 33.22628218787057, 33.223888533455984, 33.993272985730854, 33.75527286529541, 34.5425454548427, 35.43159178325108, 35.51590469905308, 34.58609676361084, 36.89407294137137, 39.995894704546245, 43.55119412285941, 46.23684310913086, 40.577121938977925, 37.80125059400286, 35.707487378801616, 34.70721081324986, 33.43595102855137, 34.43387562888009, 34.050612994602744, 38.165134702410015, 37.77288109915597, 36.87292957305908, 41.98130771092006, 41.96011570521763, 39.03269025257656, 36.1215409551348, 34.78437055860247, 36.98157508032662, 34.161336013248985, 35.17684997831072, 36.4033842086792, 35.42939962659563, 35.50685467038836, 36.75938905988421, 37.00187424251011, 34.598818915230886, 38.38406549181257, 37.35045494352068, 36.95606476919991, 40.28900793620518, 35.96641199929373, 34.33768129348755, 35.95576041085379, 32.872340951647075, 33.37323311397007, 34.13498844419207, 33.32662459782192, 32.000922203063965, 32.25356912612915, 33.578413418361116, 33.71082871300833, 31.846425533294678, 32.98979677472796, 34.62923812866211, 36.35483367102486, 35.72135945728847, 38.165006160736084, 40.57481166294643, 44.01268999917166, 46.94716092518398, 46.29301234654018, 45.585828168051584, 46.68388673237392, 47.88251352310181, 46.37175280707223, 46.77143056052071, 49.4973269871303, 49.89009823117937, 47.10897752216884, 41.8242541040693, 47.78785126549857, 54.03572702407837, 51.21977152143206, 48.025347641536165, 47.56235095432827, 44.94091721943447, 43.925774982997346, 39.14620992115566, 40.661681515829905, 37.73998137882778, 41.03634575435093, 39.90789229529244, 46.25074992861067, 43.112186091286794, 48.29223837171282, 41.80857201984951, 55.4107859475272, 51.12847219194685, 64.50911154065813, 14.751096827643257, 1.2918927861111504, 0.6370656181659017, 0.46815366191523416, 0.01882976576286767, 31.553353990827286, 64.2481302533831, 54.84026936122349, 62.04653794424874, 63.6583810533796, 57.43009574072701, 37.40684652328491, 30.989142894744873, 33.23985549381801, 59.31936304909842, 38.97273424693516, 0.4061263602759157, 0.10174537609730448, 0.12185355781444482, 0.042149740404316356, 0.07481935593698706, 0.026417178268145238, 0.12373159346835953, 0.030462917871773243, 0.05367637099698186, 0.04721104845936809, 0.08217766787856817, 0.022915825613641312, 0.034292087757161686, 0.1843419104282345, 5.903330223900931, 67.84437888009208, 52.31785787854876, 36.21540764399937, 17.13739309992109, 40.67618588038853, 49.67452342169625, 56.3653781073434, 52.48141152518136, 63.56726237705776, 53.980867522103445, 57.831555707114084, 2.3888998925685883, 0.29675330061997685, 1.5235885019813264, 0.5941154914242881, 2.1552771372454504, 53.977376052311485, 61.75257355826241, 56.87780427932739, 48.47317293712071, 43.60670675550188, 45.32947438103812, 44.71813365391323, 45.4447797366551, 41.08854757036482, 41.12741231918335, 38.38270017078945, 38.675271442958284, 37.66206080572945, 38.12029102870396, 40.75624997275216, 41.39467477798462, 41.645681926182334, 42.822626863207134, 43.64299372264317, 44.60146297727312, 44.131768226623535, 39.123044627053396, 36.78747715268816, 40.39974137714931, 40.424570764814106, 44.78401647295271, 46.14096144267491, 45.45035219192505, 48.558931078229634, 47.70476470674787, 47.84483344214303, 45.06677688871111, 42.986861433301655, 39.857149600982666, 39.10696996961321, 38.46376132965088, 36.865943159375874, 36.71244355610439, 34.915232930864605, 35.044323512486045, 34.519119603293284, 35.55054841722761, 35.32267182213919, 35.842254638671875, 36.92932462692261, 37.774031026022776, 36.1159337588719, 35.95984942572457, 38.79366527284895, 40.51161779676165, 44.058099951062886, 47.22317811420986, 43.17408759253365, 36.66177729197911, 34.332789761679514, 34.990739004952566, 33.87558439799717, 34.86454234804426, 34.59971523284912, 39.0546361378261, 39.54689516339983, 38.17418820517403, 43.389130864824565, 42.81003325326102, 41.80620615822928, 37.03441613061087, 35.0941664150783, 36.16706207820347, 35.30857392719814, 35.0494339125497, 35.69626603807722, 35.29539319447109, 36.04746273585728, 37.310061591012136, 36.61230959211077, 34.27842010770525, 38.8843218939645, 40.4474755014692, 41.05846187046596, 42.03463166100638, 38.18192502430507, 35.902332237788606, 38.37253843035017, 35.70908546447754, 35.476497990744456, 35.22433396748134, 34.32417399542672, 33.33230822426932, 34.55190815244402, 35.329560961042134, 34.97122151511056, 33.09103550229754, 35.96811430794852, 35.178465434483115, 38.28952830178397, 39.535107544490266, 39.586121218545095, 42.38235773359026, 45.32778249468122, 48.37938615253994, 48.81880760192871, 47.743799686431885, 48.69198908124651, 50.14379433223179, 48.66134057726179, 49.19782836096627, 50.88627188546317, 52.28826550074986, 50.538111550467356, 46.92613567624773, 49.07059989656721, 55.56928825378418, 54.76695891789028, 49.23988233293806, 49.51611144202096, 46.83998496191842, 46.5268748147147, 41.829854352133616, 42.11276068006243, 38.98351090294974, 43.24777671269008, 43.689303466251914, 47.89627095631191, 45.251053537641255, 50.957685470581055, 43.089625290461946, 58.01324415206909, 53.777337414877756, 68.02403845105852, 21.500462293624878, 1.0198688570942198, 0.9764140631471361, 1.0820239675896508, 0.09442026487418584, 32.9355799811227, 69.72405420030866, 58.20481293542044, 67.46850218091691, 68.64283112117222, 63.18181800842285, 46.05467871257237, 35.045678411211284, 40.33615493774414, 64.52424471718925, 47.50404861995152, 0.6823622275676046, 0.05187352041580847, 0.0074624009097793275, 0.028632902141128267, 0.0253148625072624, 0.06580689097089426, 0.26896935435278074, 0.1139439158141613, 0.2230744127716337, 0.130441707691976, 0.18050746832575115, 0.16397600754031114, 0.12446321706686701, 0.29261570264186176, 6.9546617184366495, 77.5932365145002, 61.869338035583496, 49.54341786248343, 38.45506565911429, 47.17501320157732, 56.47964123317173, 65.15207699366978, 58.59293583461216, 69.86898667471749, 58.421794755118235, 62.20550577981131, 2.9919965820653096, 0.9154220159564699, 4.591617592743464, 0.5048208257981709, 2.098977403981345, 57.071492263248985, 64.4820066179548, 60.68444783346993, 50.99811356408255, 45.359098025730674, 46.67884928839547, 46.23605796269008, 46.91245814732143, 43.91380671092442, 42.421034881046836, 39.09554018293108, 39.6307703426906, 40.634857995169504, 41.218819345746724, 42.72149583271572, 43.45755672454834, 45.077449321746826, 44.80311359677996, 45.806509903499055, 46.84845134190151, 45.98527315684727, 41.51277330943516, 41.14039502825056, 42.81383044379098, 43.10495301655361, 46.69816180637905, 46.851234095437185, 46.995631558554514, 49.843503611428396, 51.37131520680019, 48.94012662342617, 46.38811928885323, 45.208930083683555, 42.50752258300781, 40.213783264160156, 39.94250474657331, 37.88089779445103, 38.54511431285313, 35.49965633664812, 37.04292072568621, 35.31350367409842, 36.93551547186715, 37.17600999559675, 37.13055488041469, 37.72775254930769, 39.05681439808437, 38.7319062096732, 38.24021346228463, 40.86094890322004, 43.45064326695034, 47.961524963378906, 50.175842898232595, 44.6487524168832, 37.82713263375418, 35.15884372166225, 35.83419820240566, 33.33664042609078, 35.86071252822876, 34.70077330725533, 38.81872395106724, 38.929964610508506, 37.321783202035085, 45.86932856695992, 43.91969183513096, 41.38527733939034, 37.87671150479998, 36.80482333047049, 36.85655961717878, 34.61791951315743, 35.62757962090628, 36.95402547291347, 34.49616275514875, 35.46391132899693, 38.06851305280413, 38.728386947086875, 35.218264716012136, 39.35548618861607, 42.199891090393066, 46.39769390651158, 45.97213063921247, 39.40604822976248, 38.30428280149187, 39.98763677052089, 36.15363121032715, 36.45412342888968, 38.91038458687918, 37.100569929395405, 35.885576656886506, 36.498908042907715, 37.07875605991909, 36.429690088544575, 35.59680952344622, 37.811262948172434, 38.65898139136178, 39.86270815985543, 42.75691080093384, 42.24878556387765, 45.27998236247471, 47.86408690043858, 50.74671384266445, 51.076211316244944, 49.11176797321865, 50.618543897356304, 52.60854966299874, 51.63373129708426, 52.10471493857247, 54.68982696533203, 53.92142220905849, 52.42686816624233, 48.19998713902065, 49.80515997750418, 56.05192402430943, 55.0321820804051, 51.25907053266253, 50.94214235033308, 50.03560740607125, 49.069925921303884, 43.520271165030344, 44.070446899959016, 41.94100815909249, 42.931001390729634, 45.82361289433071, 50.46212257657732, 48.35257305417742, 52.86908973966326, 46.77196904591152, 58.24499784197126, 58.266505990709575, 69.60954788752964, 30.50834492274693, 0.9401959265981401, 1.699532415185656, 2.0913115867546628, 0.187581670869674, 37.84447881153652, 76.75953606196812, 64.06376675197056, 72.42090020860944, 74.95458861759731, 69.95122555324009, 51.40425314222063, 43.0656817981175, 47.92927837371826, 70.87071541377476, 59.93511240822928, 1.6939683194671358, 0.2877550577478749, 0.2626356099333082, 0.14596744387277535, 0.14645164646208286, 0.17103837643350872], [0.044192816130816936, 0.03927770523088319, 0.044354555130537064, 0.0361498453920441, 0.023123255465179682, 0.030247415149850503, 0.042953526202057085, 0.053097455097096305, 1.413113881434713, 47.469512598855154, 52.36282661982945, 44.047792298453196, 42.061469078063965, 38.44207600184849, 42.71660082680838, 61.443913732256206, 45.64701400484358, 58.96795790536063, 44.89953374862671, 59.98322868347168, 6.6000039492334635, 0.2617142679435866, 0.4976838859064238, 0.2207168292786394, 0.4121355206838676, 40.817578247615266, 64.5440262385777, 51.98198195866176, 53.41103533336094, 41.06502096993582, 40.92164141791207, 39.57846777779715, 40.07134171894619, 35.46222291673933, 38.392695154462544, 36.09284836905343, 36.18978268759591, 34.69574975967407, 34.736104897090364, 36.226816586085725, 38.42936774662563, 39.23171097891671, 38.98714828491211, 39.41702290943691, 39.13471065248762, 34.58861895969936, 36.2043912751334, 36.32000929968697, 37.195572648729595, 38.467624528067454, 41.01073816844395, 40.79489585331508, 43.65023027147566, 40.38915579659598, 40.7273211479187, 40.250862325940815, 39.46452079500471, 37.806486061641145, 36.96657739366804, 37.32456248147147, 37.84007017953055, 35.933355944497244, 34.647251333509175, 33.65082406997681, 35.15512990951538, 36.486300536564414, 36.02141393933977, 34.011324405670166, 33.99171658924648, 34.173283440726145, 34.8902576310294, 34.229167801993235, 33.596593379974365, 34.287119252341135, 40.431685720171245, 46.77487339292254, 46.767171314784456, 43.97670875276838, 36.62757478441511, 35.40296867915562, 35.04856538772583, 34.46830742699759, 35.03287982940674, 35.0011682510376, 36.96530934742519, 36.98460449491228, 36.703435216631206, 41.65273434775216, 41.946434702192036, 40.852069105420796, 35.45733833312988, 35.05612850189209, 36.759319577898296, 35.54124477931431, 35.195693492889404, 36.08490310396467, 35.921669074467246, 34.997263363429475, 35.50786215918404, 35.600109917776926, 37.28314079557146, 38.85947166170393, 36.685547079358784, 39.147140979766846, 39.015913827078684, 36.36529418400356, 34.252440793173655, 32.453253405434744, 35.4344197000776, 36.136125223977224, 38.00436380931309, 37.43966286523001, 38.623958996364046, 33.614318234579905, 33.19545650482178, 34.72560269492013, 35.06333725793021, 33.6443761416844, 33.794926234654014, 36.60097360610962, 36.15149463926043, 37.091384410858154, 39.093639850616455, 39.702493122645784, 42.05159568786621, 45.489442757197786, 47.08755275181362, 45.972172328404014, 45.55980716432844, 45.6568318094526, 46.26219361168997, 43.159246240343364, 43.19942767279488, 48.10820490973336, 48.1102511542184, 45.73767410005842, 45.558070114680696, 47.54136044638497, 43.57898691722325, 42.390216146196636, 37.53839329310826, 41.27626010349819, 38.16953638621739, 40.18134559903826, 38.16569403239659, 39.89076498576573, 39.73596259525844, 41.210940088544575, 39.716952323913574, 43.407585280282156, 45.49181209291731, 60.9143567766462, 51.09131669998169, 59.51704624720982, 7.687509502683367, 0.8735877807651247, 0.6395790747233799, 0.784918235880988, 0.11441338062286377, 31.859707014901296, 65.64532961164201, 54.95911482402256, 62.07407365526472, 60.650193214416504, 52.750046253204346, 33.026952266693115, 32.10501316615513, 35.30586412974766, 57.83877488545009, 32.10452331815447, 0.2521591106695788, 0.06705329194664955, 0.015140450426510401, 0.039527362012969594, 0.06890180454190288, 0.014177565978440856, 0.022382673508088504, 0.030675265405859267, 0.020864597288891673, 0.050982675182500055, 0.018560796177812984, 0.0021052683379301535, 0.020230737015871064, 0.08868298666285616, 2.0378981786114827, 57.8469147000994, 57.05502503258841, 47.80784123284476, 31.74481507710048, 37.73077154159546, 49.6667240687779, 63.87171854291643, 50.53491537911551, 63.67141587393624, 50.36234644481114, 64.26138741629464, 6.730963596275874, 0.4368015442575727, 0.10283587008182492, 1.0633679458073206, 0.6023409643343517, 43.799821513039724, 65.69269548143659, 52.392905371529714, 56.46716226850237, 42.697267464229036, 44.20517594473702, 41.14682558604649, 41.62339557920183, 38.47087975910732, 40.3646251814706, 39.01837348937988, 38.947390692574636, 36.138723850250244, 37.83550868715559, 37.97165863854544, 39.913051332746235, 40.45861346381051, 40.98957742963518, 40.53052731922695, 42.0091734613691, 36.1339921270098, 37.03037575313023, 37.71410281317574, 38.792435441698345, 40.29720333644322, 43.20081731251308, 42.49839959825788, 45.46877186638968, 40.29248898369925, 44.39584493637085, 41.69490296500069, 41.08087675912039, 39.6300060408456, 38.48631518227713, 38.98507077353341, 40.28817067827497, 37.798301083701, 36.33448934555054, 34.87956782749721, 36.131966727120535, 39.05985076086861, 39.37427064350673, 35.90313128062657, 35.07735524858747, 35.83882222856794, 36.345464025224956, 34.95047072001866, 36.502767767224995, 36.53901651927403, 42.65144756862095, 48.82259784426008, 48.626460620335166, 47.26674331937517, 37.15923009599958, 35.19852488381522, 35.51744372504098, 35.61355815614973, 33.27402326038906, 34.71103927067348, 36.582661628723145, 35.97562183652605, 37.6225985118321, 42.64038256236485, 43.77754558835711, 40.76714127404349, 35.885576656886506, 36.08746351514544, 36.92503064019339, 36.60778978892735, 34.9492860521589, 36.120828764779226, 34.2922956602914, 34.51832750865391, 34.98258181980678, 33.92421136583601, 37.33164964403425, 39.76260893685477, 39.48764092581612, 42.816248416900635, 40.59921721049717, 37.35259846278599, 35.738778591156006, 34.4021258354187, 37.370601245335166, 37.64837980270386, 39.45758649281093, 39.27631493977138, 40.657074860164094, 37.241733006068635, 35.10257026127407, 35.37551634652274, 36.10764455795288, 34.47928210667202, 35.472071988242014, 38.122670786721365, 38.25592333929879, 39.39730739593506, 40.47186367852347, 42.67219488961356, 45.15021085739136, 47.71106672286987, 47.52492100851876, 47.551390171051025, 47.20057215009417, 46.341097354888916, 48.69502544403076, 45.36802298682076, 46.06327016013009, 48.775617599487305, 48.90440246037075, 50.00614704404558, 48.87417779650007, 48.359566416059224, 45.462112018040244, 43.32489129475185, 39.320213658469065, 43.48178856713431, 39.78701795850481, 41.33337777001517, 40.20211376462664, 40.98797934395926, 40.813805375780376, 44.36148262023926, 41.613886969430105, 46.42190490450178, 47.59430571964809, 63.24449075971331, 53.71438326154436, 64.56945664542062, 12.828819496291024, 0.8557425811886787, 0.9100779827151979, 0.6029591368777412, 0.13964019981878145, 34.169621740068706, 71.75927884238106, 58.57450226375035, 68.32372120448521, 64.50658239637102, 61.42980888911656, 35.88114718028477, 31.823902947562082, 40.10103484562465, 65.32535117013114, 40.90115812846592, 0.41875799532447544, 0.05325555714911648, 0.0794129633743848, 0.07222194424165146, 0.041004162946982045, 0.05844412783959082, 0.12777144169168814, 0.14796980071280683, 0.07835848602865424, 0.1611697766929865, 0.18116538945053304, 0.11353801616600581, 0.15709110269589083, 0.17137030219393118, 2.5706969031265805, 66.15124879564557, 64.12074198041643, 57.26469734736851, 55.03506210872105, 51.46688420431954, 56.32919536318098, 72.26560797010148, 55.67197915485927, 69.88207708086286, 53.02682774407523, 69.67495822906494, 8.526818020003182, 0.8795893958636692, 3.088162907532283, 1.5652044117450714, 1.011269049985068, 45.9051639011928, 68.30077130453927, 56.38594477517264, 59.795933042253765, 44.49693775177002, 44.678365639277864, 43.65037270954677, 43.961645058223176, 40.63413885661534, 43.215620449611116, 40.57182741165161, 41.98622703552246, 38.176627022879465, 39.43482766832624, 40.29712690625872, 41.48804119655064, 43.992290088108604, 42.66360344205584, 44.06812967572893, 43.16861936024257, 37.78359522138323, 39.592492716653005, 39.64714724676949, 41.901163714272634, 43.327781745365684, 45.750034945351736, 44.71927663258144, 47.289238112313406, 43.502640111105784, 47.01173748288836, 44.64558056422642, 41.973178318568635, 42.163374832698274, 40.06208324432373, 41.79373066765921, 41.182108538491384, 39.78857782908848, 37.754110540662495, 36.637576716286794, 37.57380131312779, 41.13927984237671, 40.787812164851594, 37.961500372205464, 36.777360575539724, 37.52813080378941, 38.57932029451643, 38.06593527112688, 38.90291179929461, 39.135648659297395, 45.700212887355256, 49.68077332632882, 51.525158745901926, 50.994962556021555, 38.53909717287336, 34.90800333023071, 35.3238182749067, 34.598902293613975, 34.31501279558454, 35.49192993981497, 37.61818640572684, 37.81704037530081, 37.94206278664725, 44.41590091160366, 47.00902073723929, 42.1108638218471, 36.89972530092512, 35.84883805683681, 37.66675083977835, 37.08403321674892, 34.55783149174282, 36.714795521327424, 36.774918283735005, 36.6369618007115, 35.40397616795131, 35.25901937484741, 37.94197940826416, 41.89215537479946, 42.66856098175049, 45.24291719709124, 43.56322840281895, 39.177838121141704, 37.099107333592, 35.58435140337263, 38.87188809258597, 38.5644337790353, 41.38067415782383, 41.42944703783308, 42.57615688868931, 39.641491413116455, 37.97819341932024, 38.663483824048726, 39.53383602414812, 36.32428591591971, 36.59260450090681, 39.95741558074951, 40.68164021628243, 40.41495793206351, 43.19850703648159, 43.09170627593994, 47.89223405293056, 50.650272846221924, 51.14513397216797, 50.13382019315447, 49.421226842062815, 48.91160774230957, 51.709626470293315, 49.09277159827096, 47.498688084738596, 53.09052882875715, 51.52654838562012, 51.15131786891392, 51.0590249470302, 48.98538718904768, 48.65306874683925, 45.93376268659319, 39.902649879455566, 47.18682166508266, 43.2472243309021, 42.57449974332537, 43.251052788325715, 42.543437821524485, 44.39963517870222, 46.01110308510916, 44.053125040871755, 47.785165786743164, 50.31642232622419, 65.14778300694057, 57.7342392376491, 67.72120121547154, 20.80184003284999, 0.9777823154415403, 1.8224962055683136, 2.026419754539217, 0.2794813545686858, 38.64419909885952, 77.84489331926618, 63.50354739597866, 73.05156735011509, 69.18734060014997, 65.97806494576591, 45.3664561680385, 43.92424290520804, 49.305195399693076, 74.30033234187535, 51.411691188812256, 0.9387292053018297, 0.18865447544625827, 0.12344134332878248, 0.22420014307967254, 0.1510330606251955, 0.14021577393370016], [0.014706914047045367, 0.07901382193501506, 0.03971463767811656, 0.07165453968835728, 0.032993643145476065, 0.008564045769162476, 0.04812117087255631, 0.018410648252548914, 0.547764818583216, 45.87570701326643, 51.260293415614534, 39.80873802730015, 23.476156507219585, 28.15903217451913, 43.803441524505615, 62.9610389981951, 48.61282478060041, 55.4746607371739, 49.09434189115252, 58.28982067108154, 17.14413458960397, 0.42676055591021267, 1.0709800230605262, 0.37621963077357834, 0.04007104837468692, 20.267591306141444, 69.16234792981828, 49.403415134974885, 57.710559776851106, 45.657637800489155, 44.25487640925816, 40.81761646270752, 42.84630979810442, 36.59188188825335, 39.457381520952495, 34.631687368665425, 37.01959214891706, 33.60272863933018, 36.03670692443848, 35.07810912813459, 37.16619219098772, 35.63334315163748, 37.01653841563633, 35.40003653935024, 36.38406821659633, 34.83041974476406, 37.69229589189802, 35.32801498685564, 37.29573440551758, 35.434718472617014, 36.883866037641255, 37.64113630567278, 36.22440556117466, 36.510768617902485, 36.489868436540874, 37.24748611450195, 38.23404346193586, 37.7026104927063, 37.66919660568237, 36.045228890010286, 37.90972587040493, 34.76221970149449, 35.4131304195949, 33.778309617723735, 35.34254019601004, 36.885134083884104, 34.303874833243235, 33.46263558523995, 34.030188764844624, 33.53556040355137, 35.65668909890311, 33.628381388528005, 35.47348942075457, 35.57333503450666, 43.34635080610003, 44.160245418548584, 47.97403866904122, 45.771181787763325, 35.84835863113403, 33.53480999810355, 35.96754802976336, 35.11159249714443, 35.19806282860892, 33.268360478537424, 35.937934807368684, 37.92600549970354, 35.5648512840271, 43.618946007319856, 45.615764481680735, 39.58511025565011, 34.73148087092808, 35.72326326370239, 35.10133000782558, 34.464461599077495, 35.12154231752668, 35.02708155768258, 36.56990473611014, 34.33241803305489, 35.50487790788923, 36.91481678826468, 37.94373035430908, 39.221719469342915, 40.61755003247942, 42.87867798124041, 41.23750305175781, 36.63731268474034, 33.803246702466694, 32.68237372807094, 33.59238971982683, 33.95070137296404, 31.585572787693568, 33.15764788218907, 34.04828882217407, 34.40685061046055, 34.75267635072981, 32.62070846557617, 35.33077342169625, 34.610610008239746, 36.024863719940186, 33.73377513885498, 34.98220314298357, 36.69059147153582, 36.95025954927717, 37.191507952553884, 37.69804205213274, 38.461374623434885, 40.096198899405344, 39.08159514835903, 39.55189439228603, 39.00958054406302, 38.53106852940151, 39.42380435126168, 41.29334919793265, 42.090349265507285, 45.34403085708618, 45.59260960987636, 45.62814964566912, 43.949965136391775, 41.49606984002249, 41.222036361694336, 37.98092753546578, 37.934343338012695, 37.81214884349278, 39.45539433615548, 37.77415609359741, 38.870394229888916, 38.11817182813372, 41.62447254998343, 40.41756003243582, 45.38501828057425, 46.719152314322336, 56.788186413901194, 52.500661509377615, 55.566686153411865, 5.245717099734715, 0.31312127517802374, 0.8929448106459209, 1.1253583622830254, 0.18811964057385921, 32.64855337142944, 65.23205075945172, 49.090318884168354, 61.65988458905901, 55.96065248761858, 55.09387166159493, 34.567312308720176, 39.31121226719448, 39.511799812316895, 53.746268544878276, 19.253037929534912, 0.199755511911852, 0.007258075355951275, 0.02305949692215238, 0.010691675440674382, 0.02697867278142699, 0.02795989379020674, 0.020089394778811505, 0.05978116073778697, 0.04609832227496164, 0.1009629030844995, 0.044512002396264246, 0.030931015432413136, 0.05076800366597516, 0.06336719795529332, 0.9327292186873299, 55.67750644683838, 57.5792944090707, 47.5771610396249, 35.11411469323294, 45.26773268835885, 47.51281377247402, 68.51730496542794, 54.3192378452846, 62.96420042855399, 50.73055928094046, 64.47480133601597, 17.953679629734584, 0.15785468529377664, 0.5522596516779491, 1.2716432384082248, 0.06756379455327988, 21.857865469796316, 72.40423842838833, 51.08918012891497, 60.85670757293701, 44.93265928540911, 45.6928061076573, 42.254451819828574, 44.17790426526751, 39.56087146486555, 41.384964670453755, 36.843149593898225, 38.87514679772513, 36.262766565595356, 36.897328172411235, 35.647923946380615, 38.19754457473755, 35.378729888371055, 38.12363658632551, 37.803011962345664, 37.40563753673008, 36.8240316254752, 39.0059813771929, 37.32041788101196, 38.65148775918143, 37.716618061065674, 39.15532595770699, 39.13643033163888, 39.54863221304757, 38.897370610918315, 39.61328520093645, 39.66549743924822, 40.77984605516706, 39.55470493861607, 39.6075633593968, 38.683918476104736, 38.860472202301025, 37.16760267530169, 36.69580956867763, 34.15703855242048, 37.62225457600185, 37.62657635552542, 36.48418481009347, 34.45300054550171, 34.923386641911094, 35.79086576189314, 36.77877453395298, 35.58792972564697, 35.67088079452515, 37.24078457696097, 43.730739048549104, 45.692667143685476, 49.15029573440552, 47.399169036320274, 37.7382721219744, 33.051399503435405, 36.02859490258353, 33.734619344983784, 34.53688267299107, 33.45847361428397, 35.519691467285156, 38.065157072884695, 35.59480496815273, 44.80155372619629, 47.74145466940743, 40.04724189213344, 35.2751669883728, 35.249569824763704, 35.426401478903635, 35.19048581804548, 34.923018387385774, 35.643789768218994, 36.45684712273734, 34.502930300576345, 34.88000556400844, 36.75841978618077, 37.50141845430647, 40.81631367547171, 44.71323864800589, 44.32350376674107, 43.38391971588135, 37.54261779785156, 36.6271196774074, 34.10005637577602, 35.10596445628575, 35.26835775375366, 33.30528667994908, 35.78838872909546, 35.36258922304426, 35.63758502687727, 36.6527133669172, 33.680423395974294, 36.68160397665841, 36.19904463631766, 38.80662713732038, 34.64378418241228, 35.92047051021031, 38.29140778950283, 40.6805910382952, 39.51513147354126, 39.89314126968384, 39.65872641972133, 42.39148766653878, 40.62004096167428, 41.60563598360334, 41.645709718976704, 39.66992344175066, 40.560880524771555, 43.25128902707781, 44.41467802865164, 47.03538915089199, 48.13293702261788, 48.26574141638619, 46.626505034310476, 44.10799496514456, 43.10617937360491, 40.612356254032676, 41.10052973883492, 40.12103523526873, 41.6057436806815, 40.265241622924805, 39.81456061771938, 40.15265301295689, 43.504019328526084, 43.001737526484895, 46.84675598144531, 48.62964636938912, 60.285259928022114, 54.486401081085205, 59.3189947945731, 11.225735460008893, 0.29332463602934566, 0.6107400336435863, 0.6833468090210641, 0.16246604999261244, 35.42466442925589, 70.82754625592912, 52.87618037632534, 65.64917891366142, 60.02398681640625, 57.10245343617031, 41.38409267153059, 45.02893352508545, 44.991687706538606, 62.02961908067976, 26.47649982997349, 0.24939446044819696, 0.021970896050333977, 0.020621676663202897, 0.02595193394725876, 0.013507696700149348, 0.06186450073229415, 0.1599922063095229, 0.2308799267879554, 0.09168254570769412, 0.16285410416977747, 0.11875421340976443, 0.18706822342106275, 0.22501498221286706, 0.24398588495595114, 1.231791411127363, 65.74528639657157, 63.26036044529506, 54.5588047845023, 35.15775285448347, 40.28412682669503, 55.153268337249756, 72.76454421452114, 59.06503813607352, 66.23591954367501, 57.905328205653596, 70.42572498321533, 21.01625623021807, 0.6402155948536736, 2.7267705968448093, 1.9777910496507372, 0.1679466723331383, 23.47392439842224, 74.83295345306396, 52.488484791346956, 62.31101417541504, 48.38429158074515, 48.60577930722918, 43.97035462515694, 47.59225947516305, 40.52760560171944, 44.312480449676514, 38.79925857271467, 41.20403357914516, 38.49437509264265, 39.855433395930696, 39.391644614083425, 40.765775953020366, 37.925022329602925, 41.542522021702354, 39.897529057094026, 39.733561992645264, 38.25604493277413, 41.353148869105745, 38.62037025179182, 40.29258278438023, 40.76310089656285, 42.42042691367013, 41.685550689697266, 40.16082409449986, 40.386418206351145, 40.19718401772635, 41.53752279281616, 42.956897326878135, 41.150612354278564, 41.193385464804514, 40.73647887366158, 41.27190705708095, 38.56169618879046, 40.081715379442485, 36.27637461253575, 39.58024304253714, 40.12621511731829, 36.9744462285723, 36.15905427932739, 36.93683215550014, 37.52772780827114, 40.3323403767177, 37.11547728947231, 39.25848238808768, 39.74459573200771, 46.87817226137434, 47.525132928575786, 51.45824064527239, 49.795422077178955, 38.43289048331124, 33.06443084989275, 36.21156529017857, 34.72798940113613, 35.181630338941304, 33.359138693128315, 36.10101250239781, 39.64463547297886, 34.23652594430106, 45.443643706185476, 49.82161331176758, 42.004563331604004, 35.24117987496512, 35.49956948416573, 35.355759143829346, 35.287809235709055, 34.77340282712664, 37.03642763410296, 37.75719206673758, 34.63265664236886, 35.58955560411726, 39.847286633082796, 39.07461568287441, 41.71981920514788, 47.87465511049543, 45.81145702089582, 46.77863931655884, 41.40585790361677, 38.68423114504133, 35.0349816594805, 37.13909074238369, 36.68509544645037, 35.05231394086565, 37.03095245361328, 37.57333925792149, 37.781816482543945, 38.50481823512486, 34.883094038282124, 40.73511355263846, 37.673389843532014, 40.74882582255772, 35.32592357907976, 38.99111918040684, 41.90246997560774, 42.1874885559082, 40.74591105324881, 41.436183316367014, 42.5855439049857, 44.189709254673545, 43.250170367104666, 44.35133825029646, 44.04361990519932, 41.72995662689209, 42.971794264657156, 45.97686931065151, 45.239106110164094, 50.313764640263145, 49.34189578465053, 50.46153545379639, 48.1828806740897, 45.10503019605364, 45.438925879342214, 43.51270457676479, 41.81069816861834, 42.355093002319336, 43.610979897635325, 41.76692451749529, 42.21009104592459, 42.7016031401498, 45.063514709472656, 45.31810712814331, 48.69687713895525, 51.51653255735125, 60.584233965192524, 58.48917143685477, 65.17406804221017, 17.745952810559952, 0.2871242101703371, 2.6822163590363095, 2.4084319302013943, 0.3900401405990124, 39.86352457318987, 78.18558434077671, 57.071193490709575, 73.46042714800153, 64.83161912645612, 66.83531979152134, 48.24505662918091, 52.32726226534162, 53.18634796142578, 70.23097392490932, 34.930060386657715, 0.4188985877803394, 0.12051060130553586, 0.15495787002146244, 0.11909491941332817, 0.12340230042380945, 0.12910175030784948], [0.04106558732954519, 0.06940432079136372, 0.03122430880154882, 0.0018791893754886197, 0.039433042252702374, 0.031454610372228284, 0.09759686049073935, 0.04941333903531943, 0.09986681118607521, 36.83936629976545, 55.46055589403425, 40.46249750682286, 14.15876202923911, 20.274508237838745, 43.66346658979143, 60.740901947021484, 48.93801089695522, 47.18838153566633, 52.14328438895089, 54.89755031040737, 27.569328137806483, 0.10521250005279269, 0.2678869552910328, 1.3116029798984528, 0.15118365468723433, 4.429714577538626, 60.63380936213902, 53.672110421316965, 58.242503438677105, 49.011092049734934, 42.928524357931956, 39.544755118233816, 40.64162901469639, 37.93190104620797, 37.26016657693045, 36.45117391858782, 39.418405600956504, 36.993404388427734, 37.1383055959429, 34.914110796792166, 36.035101890563965, 35.70781741823469, 35.82747234616961, 35.214877469199045, 36.796242305210654, 35.86658375603812, 35.298929827553884, 35.65350334984915, 34.44814028058733, 35.898712226322715, 34.90361901691982, 32.88373252323696, 34.60923079081944, 34.189799308776855, 33.375275884355815, 36.13485370363508, 38.4069459097726, 36.86706876754761, 37.419394969940186, 37.12927641187395, 36.074838638305664, 36.075422286987305, 35.26037079947335, 34.323955127171104, 34.46479511260986, 31.992167472839355, 34.58136504037039, 34.29128122329712, 35.704270362854004, 36.28611946105957, 34.917247908455984, 34.19105693272182, 36.90849045344761, 39.437881401606965, 41.51624740873064, 47.227298395974294, 48.2270052092416, 46.096951552799766, 44.68805490221296, 33.96724155970982, 35.23507588250296, 34.648536750248496, 36.72957781382969, 35.040772983006065, 36.198005880628315, 35.059665134974885, 36.093414647238596, 40.17503316061837, 46.66258702959333, 40.87492520468575, 37.13754824229649, 34.19456229891096, 37.09739460263933, 35.22658518382481, 35.7519280569894, 34.52546330860683, 36.60833522251674, 33.56427730832781, 36.13019841057913, 35.57879979269845, 41.93145438602993, 31.29367549078805, 37.81333698545183, 46.28737040928432, 40.54374974114554, 38.39064196177891, 33.88446419579642, 33.47817175728934, 33.07968214579991, 31.48584529331752, 32.461323738098145, 33.831074237823486, 32.85127401351929, 32.571386677878245, 31.72893496922084, 35.89869485582624, 34.26618432998657, 33.843292645045686, 34.64137315750122, 35.96831580570766, 36.17068208966936, 36.42156069619315, 36.04974521909441, 36.7611608505249, 38.203912598746165, 37.7673260143825, 36.90276861190796, 35.91400521142142, 37.099538121904644, 37.79196432658604, 36.842472144535606, 36.67857108797346, 35.17244482040405, 36.9173389843532, 39.65097917829241, 42.40386240822928, 41.6686144556318, 41.391763482775005, 40.58594962528774, 39.02214636121477, 36.11990812846592, 38.413129806518555, 37.991117068699424, 36.66568217958723, 36.82643917628697, 37.591790199279785, 38.902282987322124, 39.6785774230957, 39.12318706512451, 42.20727355139596, 45.77790764399937, 57.90961177008492, 52.28198780332293, 54.545551095690044, 10.36065867968968, 0.28617485825504574, 0.4482306252632822, 0.7360444441437721, 0.2616347707808018, 36.79086787360055, 61.14591244288853, 52.88472318649292, 58.95879323141915, 58.04170397349766, 59.821745600019185, 20.332174812044414, 15.41512748173305, 35.679916926792686, 54.692873750414165, 18.708181040627615, 0.29035607246415956, 0.06668580416589975, 0.05156528909823724, 0.03722641923065696, 0.04009808799518006, 0.04931767238304019, 0.06550832877733878, 0.06853511743247509, 0.09080372750759125, 0.03552864318979638, 0.04961459591452565, 0.054260511616511006, 0.02855841935213123, 0.06272169402135269, 0.1763698160648346, 43.99497209276472, 60.66790417262486, 47.46967240742275, 19.690461771828787, 25.42731315749032, 53.23627771650042, 64.38902582441057, 56.04636199133736, 53.195929527282715, 57.673376492091585, 58.861358642578125, 29.349058832441056, 0.10369497683963605, 0.1924523173698357, 2.18439074073519, 0.15938533815954412, 5.099621670586722, 63.61610126495361, 54.60850177492414, 61.4263208934239, 50.044160638536724, 44.717855725969585, 41.26259994506836, 42.51873697553362, 39.34645700454712, 40.00742176600865, 38.72904355185372, 40.86595855440412, 38.74457277570452, 39.26148400987898, 36.26740796225411, 38.027400561741416, 36.33345058986119, 37.46185193743025, 36.717001574380056, 37.65163155964443, 37.251182556152344, 37.518427644457134, 37.522700786590576, 37.222086974552695, 36.35930831091744, 37.04777751650129, 34.831847599574495, 38.026156834193635, 35.24054411479405, 36.95549849101475, 38.4864958354405, 40.26411601475307, 36.595036370413645, 39.34988594055176, 39.26446826117379, 37.525872639247346, 38.02592406954084, 35.68738276617867, 36.27764960697719, 34.839035511016846, 34.120734214782715, 34.594531876700266, 35.48281042916434, 37.41994040352957, 37.258943693978445, 36.045385224478586, 36.86514411653791, 38.69848190035139, 41.52127095631191, 44.867888178144185, 48.22030019760132, 49.797822679792134, 47.13524171284267, 44.08641038622175, 35.63851955958775, 36.3657979284014, 35.462493896484375, 36.106619698660715, 34.45998348508562, 36.09536361694336, 35.28038508551461, 36.29957117353167, 40.26145485469273, 47.39749104636056, 39.853873525347026, 35.37119804109846, 36.06678567613874, 36.53620597294399, 34.755587645939414, 36.28127656664167, 34.7572899545942, 36.32740913118635, 34.752245562417166, 37.426648889269146, 35.951563698904856, 42.878247192927766, 36.74318586077009, 41.832758699144634, 47.006960596357075, 44.06765372412545, 41.001834051949636, 35.76136371067592, 34.22226129259382, 34.601038864680696, 35.16244288853237, 34.957335540226524, 33.54656982421875, 34.572662421635215, 34.44121640069144, 34.6765901020595, 37.560961042131694, 36.78112302507673, 34.10206093106951, 36.91013370241438, 36.93054403577532, 36.754080636160715, 38.26147147587368, 38.32228905814034, 38.78283650534493, 40.77439866747175, 38.93940026419503, 39.04183060782296, 38.38759865079607, 37.867772647312705, 39.316586698804585, 39.17855378559658, 38.71043627602713, 36.72156654085432, 39.344146728515625, 42.39546551023211, 44.09177439553397, 42.91745935167585, 44.081233978271484, 41.49803965432303, 41.81029864719936, 38.53953490938459, 40.58861773354666, 40.44829886300223, 39.26719890322004, 39.548184054238455, 40.774624483925955, 41.52774320329939, 41.42906836100987, 40.780412333352224, 44.83039222444807, 47.171038831983296, 61.85541384560721, 54.019721848624094, 58.74984005519322, 13.579986640385219, 0.2009033624614988, 1.0202223466975349, 0.4649076046688216, 0.3226230453167643, 40.49985102244786, 68.13840579986572, 56.39222942079817, 63.439325196402415, 62.80159868512835, 65.53279658726284, 29.78609357561384, 21.172773088727677, 40.045706340244834, 62.09908717019217, 25.210235800061906, 0.28322491369077135, 0.05883298268807786, 0.04065966732533915, 0.05805768857577017, 0.022411294115175093, 0.020486066350713372, 0.15439653157123498, 0.1718351258231061, 0.2460433388394969, 0.172900385090283, 0.08032948776547398, 0.310337056006704, 0.23397670633026532, 0.18087866769305297, 0.23011869192123413, 51.96892629350935, 68.11731801714215, 55.70825569970267, 21.33740544319153, 28.933337688446045, 57.001596859523225, 71.20785590580532, 60.455261502947124, 57.43104069573538, 61.952945709228516, 64.23731190817696, 32.03726822989327, 0.2952669560909271, 0.8244908867137772, 4.605026313236781, 0.21534379545067037, 5.466434010437556, 65.91973481859479, 56.6359201158796, 65.71909168788365, 53.17386204855782, 47.150850840977256, 43.08285427093506, 43.815197876521516, 41.88990068435669, 41.46764128548758, 41.585451466696604, 44.23305559158325, 40.798429012298584, 43.34492642538888, 38.52464491980416, 40.726869515010286, 38.435940742492676, 40.34621245520455, 38.205069473811555, 39.945659228733604, 39.74084023066929, 39.19628211430141, 39.08493028368269, 38.04274565832955, 38.56964840207781, 38.473867484501426, 35.611755098615376, 39.257811886923655, 39.06326927457537, 38.95148318154471, 42.07120697838919, 42.94751031058175, 39.92683655875069, 41.56212983812605, 39.9136176109314, 39.38991103853498, 39.877480030059814, 36.4808566229684, 37.41398579733712, 37.043028422764365, 35.89076696123396, 37.167988300323486, 37.37594093595232, 38.9432704108102, 40.30964756011963, 38.934157848358154, 37.44295283726284, 41.24395445414952, 42.00422634397234, 48.81471511295864, 52.159668241228374, 54.1973351751055, 50.11018589564732, 45.45553207397461, 35.569391931806294, 35.605689321245464, 35.41242865153721, 36.804246629987446, 34.00397321156093, 36.126265730176655, 34.63157272338867, 35.81454522269112, 41.751287596566335, 50.26717002051217, 40.94829470770699, 35.280749865940635, 34.820143359048025, 36.57060997826712, 35.40153387614659, 36.299619810921804, 35.74423292704991, 35.60809687205723, 34.16033894675118, 37.68070977074759, 37.21661179406302, 43.8978397505624, 41.06842558724539, 45.871082987104145, 50.12327977589199, 45.40082890646798, 42.535412652151926, 38.39206286839077, 35.48142773764474, 36.537137031555176, 36.33987767355782, 37.11752700805664, 38.42864860807146, 37.12867886679513, 35.98822586877005, 35.48641307013375, 39.1027524130685, 38.76503522055489, 35.10349089758736, 38.20892572402954, 39.87909548623221, 39.489409242357524, 40.04538324901036, 41.05363982064383, 41.28083201817104, 42.970251764569966, 41.313954080854145, 39.76841415677752, 40.00098773411342, 41.533451148441856, 42.011501107897075, 41.67626789637974, 41.40446478979928, 37.42012800489153, 41.18692364011492, 44.19036585944039, 47.52836036682129, 45.74733557019915, 46.68112482343401, 44.827925613948274, 43.82348012924194, 41.19905172075544, 44.24842153276716, 42.36024856567383, 41.36389773232596, 40.505003111703054, 43.25231736046927, 45.03713239942278, 43.967870644160676, 44.58545085362026, 47.658691201891216, 50.56291314533779, 64.98493807656425, 58.90941933223179, 61.02326284136091, 18.084347452436173, 0.21767946226256235, 3.1748799000467574, 1.7787976818425315, 0.46310791266816004, 44.816575731549946, 72.45049258640834, 62.34073856898716, 69.57469572339738, 66.26277433122907, 73.41653537750244, 32.396090575626914, 25.840197699410574, 51.0352794783456, 71.81843580518449, 34.03561183384487, 0.501623405941895, 0.18594897990780218, 0.15170498671276228, 0.14273910996104988, 0.11093611935419695, 0.1535463271928685], [0.044834873106862815, 0.09250771892922265, 0.007269126995067511, 0.05342821716996176, 0.011755323187181992, 0.028124043285580616, 0.036241732604269467, 0.024679329645420824, 0.03263735119253397, 26.21764121736799, 61.90694168635777, 42.417508670261924, 37.087073053632466, 45.939752033778596, 38.40658112934658, 61.7188470023019, 52.25853763307844, 47.4956065586635, 54.60931818825858, 47.76469986779349, 39.460056577410015, 0.1029752411746553, 0.03668011372376766, 1.5412951175655638, 0.04596076287063105, 0.1809900017189128, 35.15545300074986, 61.660634994506836, 51.706444195338655, 52.78011110850743, 42.52767235892159, 38.48963989530291, 38.45907824380057, 37.62224415370396, 37.87588119506836, 37.464071886880056, 37.783675125667024, 38.37172201701573, 38.084209033421104, 37.415768010275706, 34.631395544324604, 34.521016461508616, 37.35110460008894, 36.085344314575195, 34.99101345879691, 36.62599059513637, 35.04667895180838, 36.46959706715175, 37.333556924547466, 38.011485712868826, 37.59729664666312, 35.970914431980674, 36.09991121292114, 35.92189836502075, 36.64686645780291, 35.181887422289165, 36.400243622916086, 37.07857888085501, 34.929528849465505, 33.72267539160592, 34.49416862215315, 33.5004893711635, 33.53875657490322, 34.4618490764073, 35.42445945739746, 34.88317394256592, 33.444212436676025, 33.793727670397075, 34.39596973146711, 36.90190008708409, 34.22852509362357, 36.49513169697353, 39.92411286490304, 42.93406902040754, 45.26384517124721, 46.537724426814485, 46.85112987245832, 47.551449230739046, 42.082160813467844, 35.828170640128, 33.494618143354145, 33.238646507263184, 36.10116883686611, 34.66141871043614, 35.683641161237446, 35.7130320412772, 34.898605891636436, 39.81467873709542, 44.690406867435996, 40.75221306937081, 34.81548111779349, 36.180958475385395, 35.93391180038452, 34.903580801827566, 35.36042138508388, 33.66577659334455, 35.277956690107075, 35.80200719833374, 34.3391022000994, 36.85117128917149, 36.23273297718593, 40.70060185023716, 42.02976444789341, 46.569178921835764, 42.1338449886867, 38.11005980627877, 35.19203526633126, 34.94350167683193, 33.10375765391758, 35.33777720587594, 33.86597503934588, 32.64004877635411, 34.055528845105854, 33.672130720955984, 32.063185010637554, 31.942070960998535, 33.787578514644075, 35.4615524155753, 35.98222262518746, 35.646523884364534, 34.03044237409319, 35.390538351876394, 36.816670009068076, 35.140451839991975, 35.327657154628206, 36.92762926646641, 35.595777715955464, 36.65437398638044, 35.907838685171946, 35.63566037586757, 34.946576254708425, 37.63336474554879, 37.09620993477957, 35.76895809173584, 35.25190094539097, 39.5088746207101, 39.09593275615147, 40.1453400339399, 38.087384360177175, 40.260634967258994, 35.653548513139995, 37.53320298876081, 36.54237944739205, 38.095899377550396, 36.49863706316267, 39.477576460157124, 41.170987946646555, 40.819961479731965, 39.313025747026714, 43.291116101401194, 39.346880844661165, 54.54886886051723, 49.752190385546, 59.60431562151228, 18.043224539075577, 0.4126928964895861, 0.17211423441767693, 0.41835977669273106, 0.6623927248375756, 45.64392900466919, 58.919403893607004, 55.29153748920986, 61.448972020830425, 58.34812995365688, 53.34839732306344, 27.27081789289202, 33.148420674460276, 45.51928527014596, 59.387094088963096, 13.863157868385315, 0.37665682445679394, 0.19214218615421227, 0.03041893183918936, 0.01480881473980844, 0.044480609973626475, 0.01428234450785177, 0.01736352961909558, 0.1257840126220669, 0.06372401916554996, 0.03748671544183578, 0.0676767909899354, 0.0169361916570259, 0.03551727433555892, 0.06258670626474278, 0.03659373621589371, 33.578118119921, 65.49826404026577, 49.58707339423043, 27.554818562098912, 36.69841514314924, 53.82417869567871, 64.03970514025006, 59.894958768572124, 50.39558662687029, 58.80691255841936, 53.200963497161865, 43.725823198046, 0.12339799851179123, 0.356366293238742, 1.7870519246373857, 0.03178004255252225, 0.2294622500027929, 39.46819986615862, 62.82839093889509, 55.30438470840454, 54.29254286629813, 45.071487767355784, 39.15811218534197, 41.53511871610369, 38.10707555498396, 39.46026502336775, 39.04018388475691, 40.2611734526498, 41.299418449401855, 40.55979313169207, 38.280238560267854, 37.141248158046174, 36.153815337589805, 37.92098890032087, 37.76152426855904, 36.30610942840576, 38.15959351403372, 37.821108545575825, 37.380102906908306, 39.92064918790545, 39.37925945009504, 39.229702949523926, 37.687376567295615, 37.719852447509766, 38.76883935928345, 37.68764407294137, 37.16423627308437, 38.71127700805664, 40.835775579724995, 38.2769763810294, 36.77257326671055, 36.839995111737935, 35.840736457279746, 36.03385468891689, 34.829481737954275, 35.35878161021641, 35.24151686259678, 34.124593939099995, 36.27864319937569, 36.11979695728847, 37.23466668810163, 35.70456913539341, 39.371904781886506, 42.95348228727068, 44.529295512608115, 47.405464104243684, 48.96664789744786, 48.06623431614467, 49.84170055389404, 45.497554779052734, 36.856639521462576, 33.103306021009175, 34.79327814919608, 34.69277245657784, 33.69912794658116, 35.51713105610439, 37.52710247039795, 34.79301759174892, 40.26837873458862, 47.134505203792024, 40.24941710063389, 34.69010782241821, 36.39769015993391, 35.02703986849104, 34.27611330577305, 34.94091347285679, 33.652682713099885, 34.58671862738473, 36.649951457977295, 35.02186346054077, 35.43270696912493, 39.404474462781636, 42.14988490513393, 45.43726873397827, 49.01161316462925, 44.111882482256206, 39.8604291507176, 36.13246004922049, 36.691070897238596, 34.463568755558555, 36.34987613133022, 34.56895555768694, 33.76532343455723, 34.97858313151768, 34.11731570107596, 33.8269157409668, 33.76167563029698, 34.8799604007176, 37.17049312591553, 37.44823694229126, 37.77561868940081, 36.82986116409302, 37.40276793071202, 38.22443757738386, 37.19755983352661, 37.920683179582866, 38.81250878742763, 36.71379845482962, 39.96385656084333, 36.67480863843645, 37.30718156269619, 38.03147220611572, 39.76093789509365, 38.1655272756304, 38.05488068716866, 36.93674182891846, 40.55362313134329, 41.2251422064645, 42.20265647343227, 40.674792766571045, 40.52190807887486, 38.761522906167166, 39.440841334206716, 39.55375303540911, 41.20972762789045, 38.883470739637104, 41.19084937231881, 43.04620599746704, 43.81980105808803, 40.4776793207441, 44.841054235185894, 42.181624276297434, 57.74835797718593, 52.57681376593453, 63.18628570011684, 21.125009434563772, 0.3876563385128975, 0.39257973432540894, 0.7006915211677551, 0.7828187399676868, 50.24279573985508, 63.77000386374337, 58.919299670628135, 67.12616443634033, 61.90620517730713, 58.45144966670445, 32.617178780691965, 33.85276998792376, 50.0486352784293, 66.20347840445382, 19.281852109091624, 0.45314620435237885, 0.17201461190623896, 0.04569284671119281, 0.00584367589492883, 0.04999218708170312, 0.0492895538918674, 0.12548677357179777, 0.2096285085592951, 0.23855231223361834, 0.11171880271285772, 0.19656920645918163, 0.13831165539366858, 0.1286393151219402, 0.23727349085467203, 0.06763217052710907, 36.45846952710833, 75.93816866193498, 57.0206800869533, 47.18284034729004, 60.123658725193565, 53.69781180790493, 72.33342933654785, 63.87285109928676, 58.79633045196533, 61.06830106462751, 58.892715862819124, 46.86418553761074, 0.35860478026526316, 1.4306003259760993, 3.7613543272018433, 0.15903505124151707, 0.5924195881400789, 40.69826030731201, 65.87841388157436, 57.213867800576345, 56.26194722311837, 47.08278281348092, 39.78352996281215, 43.912833963121685, 40.89277165276663, 41.865946769714355, 42.30586501530239, 42.55659423555647, 43.64651993342808, 42.722503321511404, 41.20327969959804, 38.62610598972866, 37.49402209690639, 40.552879674094065, 39.89326981135777, 39.411891664777485, 40.60466112409319, 39.2894400869097, 41.2831700869969, 42.23840495518276, 41.059879302978516, 41.467533588409424, 37.6242104939052, 41.0302973474775, 39.903942244393484, 40.25383268083845, 39.67815358298165, 41.65592009680611, 44.11294208254133, 40.413120133536204, 36.759156295231406, 39.62893254416329, 35.423354693821494, 36.765260287693565, 37.22572088241577, 37.820052419389995, 37.10820252554757, 36.395053318568635, 38.19313594273159, 38.67744970321655, 41.4754684312003, 37.672799246651785, 41.1758690561567, 44.63934455599104, 47.09606776918684, 49.75477164132254, 50.989841733660015, 51.125922203063965, 51.87345109667097, 48.87022079740252, 39.555309431893484, 32.959155218941824, 34.71218919754028, 35.74176631655012, 33.81175477164132, 36.003004687173025, 37.76336554118565, 34.51473528998238, 41.684400762830464, 47.91053908211844, 41.329309599740164, 34.227288314274375, 36.242106097085134, 34.97511945452009, 34.76302569253104, 35.559452533721924, 34.14697756086077, 35.14828593390328, 36.842215061187744, 34.99079459054129, 36.810788358960835, 43.241790839603965, 45.94863183157784, 46.72989770344326, 51.08986452647618, 45.91072940826416, 41.80712332044329, 38.48722539629255, 40.387439591544016, 37.35834114892142, 38.66308082853045, 37.27563674109322, 34.90538733346121, 35.724037987845286, 37.13572781426566, 36.03111709867205, 35.21217114584786, 37.099892480032786, 39.39486510413033, 40.8306234904698, 38.82554360798427, 40.467204911368235, 39.8213073185512, 41.75370209557669, 38.20306839261736, 39.79128762653896, 42.39449276242937, 39.34612349101475, 42.827876227242605, 39.78755644389561, 40.0357426234654, 39.73150185176304, 41.671348571777344, 40.80128819601876, 40.70773070199149, 39.928229672568186, 43.18256439481463, 44.18203149523054, 43.69212096078055, 42.89994989122663, 43.01536641802107, 41.45539508547102, 40.80858033043997, 42.704608236040386, 43.56554562704903, 41.440925461905344, 43.694570200783865, 46.28619268962315, 44.973611967904226, 42.94033629553658, 46.63810852595738, 44.620546204703196, 60.705382755824495, 56.37619992664882, 66.57090609414237, 22.77398545401437, 0.5541548814092363, 2.8700268183435713, 1.943972647190094, 1.0561380194766181, 55.194495473589214, 70.41565009525844, 64.26868302481515, 72.02911908285958, 66.73415402003697, 65.54790197099958, 39.61899314607893, 43.393324102674214, 58.38382979801723, 75.18758256094796, 24.641972167151316, 0.6489947523389543, 0.3380500003695488, 0.18805785317506107, 0.20305324638528482, 0.18487912017319882, 0.1841818575880357], [0.027208524822656597, 0.01301954927787717, 0.0288817921786436, 0.07961794201816831, 0.04349920067137905, 0.04765261530077883, 0.1717790924012661, 0.06974905050758805, 0.09785023225205285, 17.550529514040264, 59.89884975978306, 42.0212459564209, 30.96278142929077, 18.05273141179766, 40.3984385899135, 55.30515595844814, 55.65786388942173, 51.432330812726704, 56.62975358963013, 45.701043197086875, 52.61194038391113, 3.2926546888692036, 0.440944353384631, 0.8505413659981319, 0.22386433609894343, 0.03925473342782684, 14.96990602357047, 64.78447559901646, 51.45303644452776, 53.498162269592285, 38.214209829057964, 40.66599634715489, 40.66211230414254, 41.0719587462289, 35.73868479047503, 39.87431165150234, 38.350933006831575, 41.368928228105815, 40.01932750429426, 40.57429749625069, 37.601034777505056, 36.35031386784145, 36.52315378189087, 35.75218514033726, 35.84191765104021, 36.66436202185494, 35.7275572504316, 37.09310061591012, 36.75833640779768, 39.273212569100515, 35.7084253856114, 35.59096261433193, 35.60379941122872, 37.415226050785606, 35.29039396558489, 36.90970638820103, 35.48424523217337, 36.42935310091291, 35.559563704899375, 37.15907028743199, 35.05177545547485, 36.96488203321184, 34.35630246571132, 33.85794292177473, 34.051516260419575, 35.66993236541748, 37.187057631356375, 37.29762431553432, 35.4023711340768, 36.567990507398335, 35.18210629054478, 39.902597767966135, 38.97284541811262, 42.78419290270124, 43.916686739240376, 44.061699117933, 45.20379189082554, 42.129478045872276, 34.96951225825718, 40.7677492414202, 36.9137259210859, 35.27834926332746, 34.03391647338867, 36.10807882036482, 33.817052773066926, 37.1247044972011, 34.01969003677368, 41.7827525138855, 47.74444934300014, 41.80293008259365, 35.62328216007778, 35.36114747183663, 35.21201481137957, 36.77412966319493, 34.12894698551723, 35.51972273417881, 35.23843881062099, 35.546615736825125, 34.90908030101231, 37.419332436152864, 43.403940950121196, 52.25181525094168, 46.467029980250764, 46.24494818278721, 43.28247601645333, 41.10573393957955, 36.41494253703526, 34.08977651596069, 33.92769588742937, 34.03952019555228, 34.446986879621235, 33.3056514603751, 33.27386345182146, 32.692983627319336, 32.704698290143696, 33.29852260862078, 33.76562915529524, 35.5627737726484, 35.28058658327375, 35.10903903416225, 34.05309002740042, 36.49545478820801, 35.720143522535054, 36.01096732275826, 35.48347050803048, 35.91415112359183, 35.24035998753139, 35.55690254483904, 33.71809305463518, 35.52305439540318, 35.12710435049874, 35.97641045706612, 36.288686820438926, 38.132224559783936, 35.39211906705584, 37.3649697303772, 35.90171037401472, 38.13372189658028, 37.37746606554304, 37.1813496862139, 36.444646086011616, 38.433324745723176, 36.438111305236816, 37.32832840510777, 38.31000116893223, 44.500054018838064, 45.759752001081196, 49.46448632649013, 47.15806654521397, 47.11299705505371, 39.1547075680324, 47.79039083208357, 50.58042260578701, 61.42176982334682, 23.744631426674978, 0.606382698885032, 0.4113602265715599, 0.6531869588153703, 2.8576388316495076, 55.12467997414725, 54.72717353275844, 56.31601810455322, 57.74248674937657, 61.779372760227744, 52.95041840417044, 25.38365067754473, 35.215065070560996, 41.588418347494944, 55.743670667920796, 4.382241879190717, 0.31386861364756313, 0.08820008686078445, 0.06896226879741464, 0.05441075623301523, 0.0676297549424427, 0.02953342328380261, 0.025837753466995697, 0.04569825802796653, 0.05318258410053594, 0.04008087016908186, 0.052314578355955224, 0.08391855803451367, 0.06411171371915511, 0.08449716520096574, 0.010253687871487012, 21.10539640699114, 70.15038871765137, 48.33590085165841, 38.14077431815011, 28.519113881247385, 47.604109627859934, 59.27267810276577, 60.729993275233674, 53.71555750710623, 61.610767773219514, 49.39393431799752, 57.90889263153076, 2.8287959907736098, 0.1554226122264351, 1.6948592088052203, 0.5708751784903663, 0.048148437802280696, 17.615404844284058, 66.85251658303397, 53.1562831061227, 53.707344736371724, 39.62706347874233, 43.34656620025635, 40.268243244716096, 43.368463448115754, 37.61615405763899, 42.15798650469099, 40.15383768081665, 45.014231136866975, 42.003962312425884, 43.14982100895473, 37.85952166148594, 37.98024661200387, 38.52217830930437, 37.8316524369376, 37.991401944841655, 38.22296803338187, 38.166559083121165, 38.27100787843977, 39.2660038130624, 41.079917907714844, 36.443186964307515, 38.622937611171174, 38.419285910470144, 37.9286527633667, 37.643762724740164, 37.88910709108625, 37.39763668605259, 38.29532309940883, 37.372942788260325, 38.82926436832973, 36.10905156816755, 37.94409166063581, 37.164660113198416, 36.50781910760062, 34.346408230917795, 36.69764736720494, 37.88502502441406, 38.60051230021885, 36.25328574861799, 38.65980127879551, 37.22259419304984, 40.47520228794643, 39.961132866995676, 44.09800345557076, 45.27981560570853, 46.481642041887554, 46.74919979912894, 44.20311232975551, 40.38048791885376, 40.987030914851594, 36.66971560886928, 35.34005968911307, 33.5669766834804, 36.564492089407786, 32.43889842714582, 37.64568737574986, 33.40039709636143, 41.78515659059797, 47.98067767279488, 40.25684125082833, 35.03495734078543, 36.2225330216544, 34.58357456752232, 36.255158288138254, 34.2308805329459, 34.852893693106516, 34.92742007119315, 35.08379275458199, 34.869270597185405, 35.811255250658306, 42.98662519454956, 54.39953122820173, 48.03155585697719, 48.94113758632115, 46.4412556375776, 41.401918275015696, 38.75332750592913, 34.918415205819265, 35.46453666687012, 35.92638342721121, 36.45736823763166, 34.478618553706575, 34.57235670089722, 34.40816034589495, 34.013217789786204, 35.21288333620344, 35.38271468026297, 37.847699301583425, 36.00873000281197, 37.64715344565255, 35.843661648886545, 38.810511180332725, 38.30878176007952, 38.2191777910505, 36.89252001898629, 39.09262193952288, 37.7284369468689, 40.19907740184239, 36.65678153719221, 38.21385199683053, 38.03032922744751, 37.31717307226998, 38.50326531273978, 39.01800523485456, 37.42570046016148, 39.46349940981184, 36.8834456716265, 41.06635502406529, 39.62589618137905, 40.21582950864519, 38.62781177248274, 40.03862265178135, 38.25857755116054, 39.11666965484619, 41.288374287741526, 46.73260750089373, 47.35946355547224, 50.984647955213276, 49.12599788393293, 49.63974073954991, 42.54021038327898, 50.21221324375698, 53.35085351126534, 62.91232517787388, 25.902199949537003, 0.4353865273296833, 1.9416784388678414, 0.9814072123595646, 3.0590738398688178, 59.54629121507917, 59.98938478742327, 59.33380140577044, 65.11434132712228, 64.71094281332833, 60.844951220921104, 26.407295772007533, 37.39573287963867, 47.68223517281668, 63.97955458504813, 8.673003775732857, 0.46436890214681625, 0.22847319021821022, 0.15845826933426516, 0.06753413578761475, 0.02330106047780386, 0.06616275544677462, 0.0898552644731743, 0.09341971070638724, 0.11778062422360693, 0.14571171759494714, 0.14980369087840828, 0.14270713739097118, 0.24704029677169664, 0.23651510583502905, 0.12691613472998142, 25.146043130329677, 78.36980193001884, 55.80282415662493, 45.32024369921003, 26.710186856133596, 52.90967764173235, 62.65875761849539, 66.91866343361991, 59.22104603903634, 67.31116022382463, 54.10207537242344, 63.213196073259624, 4.15607671226774, 0.9901773588997977, 4.878371051379612, 0.6577030164854867, 0.11536163331142493, 20.89328180040632, 70.24746894836426, 55.50254733221871, 57.135540757860454, 42.064196246010916, 44.40888670512608, 42.5958376611982, 45.32479476928711, 39.380093233925955, 44.01898506709507, 42.802442346300396, 47.48065403529576, 42.98479087012154, 44.75284685407366, 42.27765532902309, 40.450946126665386, 40.80184752600533, 39.53542716162545, 41.03249297823225, 39.584328583308626, 39.183011054992676, 40.77021585191999, 40.82959515707833, 43.42550468444824, 39.12078298841204, 40.19865008762905, 40.37880992889404, 41.38128212520054, 41.209877014160156, 41.498508657727925, 39.49320295878819, 39.00184719903128, 40.209117548806326, 40.74784960065569, 38.809611388615195, 39.57484776633126, 39.018939767565044, 38.185750007629395, 36.34126383917672, 37.152455602373394, 40.37436655589512, 40.72870036533901, 37.93514238085066, 41.07770838056292, 39.110926968710764, 42.69730567932129, 41.69522953033447, 46.382883821214946, 47.90897921153477, 48.99460050037929, 49.99403633390154, 47.64364487784249, 42.33059365408761, 41.462259905678884, 37.804960932050435, 35.021498680114746, 34.23213815689087, 36.39183977672032, 32.61272151129586, 38.11633750370571, 33.6569002696446, 42.110071727207725, 51.41382081168038, 41.92683383396694, 35.37914330618722, 36.014229501996724, 35.81665052686419, 37.627368450164795, 34.946482454027446, 35.24832262311663, 35.181602546146934, 36.018971647535054, 35.403065953935894, 37.77706044060843, 44.519852910723, 54.03149904523577, 50.76071793692452, 50.65005397796631, 48.944274697984966, 43.97818871906826, 39.96481541224888, 37.26162569863455, 36.9636869430542, 37.0283989906311, 39.20003761563982, 36.24468387876238, 37.06154884610857, 36.69332211358206, 36.66221155439104, 37.34158556801932, 38.422812121255056, 40.153181076049805, 38.39874356133597, 39.86781161172049, 37.914912700653076, 41.76660490036011, 40.914915561676025, 40.83358689716884, 39.34775979178292, 40.21636799403599, 39.80632700238909, 42.130773884909495, 37.90549441746303, 39.858254364558626, 40.17873307636806, 39.83518981933594, 41.34629794529506, 41.71117912020002, 39.685584681374685, 41.74305050713675, 40.30147647857666, 43.57152107783726, 41.31662566321236, 41.744273390088765, 41.97939000810896, 43.092849254608154, 40.3306519644601, 41.69948877607073, 43.64406374522618, 49.52857303619385, 50.895961148398264, 53.60128395898001, 53.23031963620867, 51.42025136947632, 46.216908727373394, 53.409246172223774, 57.156447887420654, 66.89342062813895, 27.773742403302872, 0.5544059393661362, 3.4541210532188416, 1.3106481454202106, 3.4721099393708363, 67.26728929792131, 65.43780081612724, 63.563065665108816, 68.81479903629848, 70.92529351370675, 67.97006484440395, 36.325182233537944, 47.20638084411621, 54.42152227674212, 75.59665080479213, 12.4876994235175, 0.8068082641277994, 0.3333740255662373, 0.23848757999283926, 0.14264503786606447, 0.12604518075074467, 0.11437663116625377], [0.01267825803785984, 0.048760791907885244, 0.046375150991869826, 0.02752339051637266, 0.06342302103127752, 0.20754962653986045, 0.08359503253762211, 0.027624532946252396, 0.07637525709079844, 12.929274814469473, 62.41934353964669, 44.141398429870605, 40.297946793692454, 32.67346613747733, 46.9605952671596, 52.78685433523995, 62.9395968573434, 50.33479683739798, 56.620446477617534, 45.19370310647147, 56.59051711218697, 10.139492307390485, 0.2087864601718528, 0.4056461203311171, 1.487674783383097, 0.04668882755296571, 7.545748012406485, 63.76803057534354, 49.46403816768101, 51.63541623524257, 36.790232113429475, 44.77037715911865, 45.11767939158848, 43.30760417665754, 36.71520546504429, 38.01625912530081, 38.52290787015642, 41.893371309552876, 40.0462760925293, 42.031953130449565, 39.94949810845511, 39.36588069370815, 34.31998770577567, 35.72969382149832, 34.2419559614999, 36.795411995479036, 35.81174509865897, 36.1647344316755, 34.83095475605556, 36.096603870391846, 34.279580456869944, 36.98486157826015, 35.29412514822823, 37.06970255715506, 34.45434154782976, 35.686674049922395, 35.33030094419207, 36.39951058796474, 35.36416646412441, 37.51128837040493, 35.8742094039917, 35.966464110783164, 34.876781599862234, 35.589201245989116, 34.42292179380144, 36.43096160888672, 36.553180422101704, 38.11168221064976, 37.07713712964739, 35.788677079336985, 35.82213612965175, 39.72472735813686, 41.05819089072091, 44.92396361487252, 46.26667519978115, 46.43976872307913, 45.784042903355186, 45.20583813531058, 47.54358386993408, 38.1829012462071, 32.814896719796316, 36.46550457818167, 35.58870097569057, 34.40090990066528, 35.11581005368914, 35.42625904083252, 34.07110670634678, 38.63780675615583, 47.58485269546509, 38.950527804238455, 33.24652923856463, 35.656216621398926, 35.15538004466465, 35.326715673719136, 34.93055023465838, 35.620370864868164, 33.47375965118408, 35.743253231048584, 35.284602642059326, 38.393862451825825, 45.48165382657732, 48.48367166519165, 44.888260296412874, 46.758003166743684, 44.56385932649885, 43.175848960876465, 37.354787145342144, 34.92111458097185, 32.76122883387974, 33.64005088806152, 33.73323665346418, 34.177271706717356, 34.668929713112966, 34.94563824789864, 31.773698738643102, 32.93649366923741, 33.3124954359872, 35.235260009765625, 34.80487469264439, 37.49527277265276, 34.444832938058035, 35.53866004943848, 36.84236444745745, 37.63453204291207, 36.23442486354283, 37.896096978868755, 37.335193225315635, 37.972718238830566, 34.95751619338989, 36.14908708844866, 35.63355507169451, 36.289183616638184, 35.67811039515904, 35.833447796957834, 35.73460272380284, 36.284948689596995, 34.87562125069754, 36.34911182948521, 36.951621396201, 37.747207505362375, 36.11931753158569, 37.45808948789324, 36.09411294119698, 39.278889247349326, 38.59003789084298, 46.30243410382952, 49.217255524226594, 53.51841279438564, 51.18251528058733, 56.69370480946132, 47.554673194885254, 48.034911836896626, 47.19663599559239, 60.25042860848563, 22.173695836748394, 0.3739647503410067, 0.4125803953834942, 0.7500921817762511, 7.371607048170907, 59.870855467660085, 50.75195625850132, 57.42150081907, 58.14828586578369, 57.78080606460571, 46.37854814529419, 34.163910320826936, 38.31964874267578, 43.6721761567252, 54.2320761680603, 3.2424365835530415, 0.38803789232458386, 0.08448343843753849, 0.08710530453494617, 0.04541173643831696, 0.046993896897350035, 0.08301340589033705, 0.031123844906687737, 0.02719661144406668, 0.039942791685462, 0.055511146650782654, 0.043603260801838975, 0.08595691794263464, 0.04088713601231575, 0.0865396506020001, 0.10037483035453729, 15.825279644557408, 70.44105965750558, 48.7419570514134, 43.48263277326311, 27.59845151220049, 49.200079577309744, 57.12579938343593, 65.73733070918492, 54.9500161579677, 61.82058252607073, 48.65446533475603, 61.12973703656878, 10.227313194956098, 0.36885340032832964, 0.4871743012751852, 2.3883238434791565, 0.04465447100145476, 9.407317195619855, 66.25922380174909, 50.06159019470215, 53.68078177315848, 38.49762337548392, 47.023250647953574, 47.10532624380929, 44.31574262891497, 37.20498398372105, 40.216937746320454, 40.4324882371085, 44.1028185571943, 43.47819982256208, 44.26361724308559, 42.912446226392476, 40.78226055417742, 36.33668845040457, 37.67281314304897, 36.682656628744944, 37.789601939065115, 36.85727528163365, 38.31027214867728, 36.39668961933681, 36.64448322568621, 36.295367513384136, 38.89244086401803, 37.07939529418945, 39.48636940547398, 37.51949071884155, 37.68707432065691, 36.83549962724958, 38.73652328763689, 36.39914928163801, 38.481705052512034, 36.70410571779524, 36.89750187737601, 34.806045464106965, 35.64990765707833, 36.98809943880354, 39.12431614739554, 39.20659671510969, 40.21672235216413, 38.69447973796299, 36.92538847242083, 39.16864912850516, 39.94457530975342, 42.979194096156526, 48.00148752757481, 48.21206658227103, 48.04582398278372, 47.33949095862252, 48.97342586517334, 47.774618421282085, 39.428508281707764, 31.974856036049978, 36.526450702122276, 35.43273128782, 34.35652480806623, 34.69425242287772, 35.54915182931082, 34.64890153067452, 38.93751382827759, 48.70042766843523, 39.93352419989449, 32.18457351412092, 36.066726616450715, 35.99762330736433, 34.76139633996146, 35.49381637573242, 35.76603290012905, 34.54841668265206, 35.93883112498692, 36.058152539389475, 38.65093885149275, 44.95500469207764, 48.85946151188442, 47.066378116607666, 50.00558771405901, 46.123337336948936, 44.715462071555, 40.48894582475935, 36.860061509268625, 35.162550585610525, 35.87805870601109, 34.62948826381138, 35.92500073569161, 36.74224090576172, 36.81052432741438, 32.42996999195644, 35.53427921022688, 33.91562339237758, 36.845543248312815, 37.82653856277466, 38.94858578273228, 37.29638058798653, 37.265985693250386, 38.11511809485299, 39.579621178763254, 37.783883571624756, 39.268084798540386, 38.33790166037423, 40.725636209760395, 36.252010754176546, 38.86512054715838, 38.17746428080967, 36.769814831869944, 37.901749338422505, 38.118588720049175, 38.35336487633841, 39.65613126754761, 36.47708722523281, 39.326797076633994, 38.25846985408238, 38.32292134421212, 38.623427459171836, 39.607816968645366, 38.29991933277675, 40.855334758758545, 41.483816691807334, 48.81356518609183, 50.74484477724348, 54.64897503171648, 53.216013295309885, 59.023877007620676, 50.24353224890572, 49.87328706468855, 51.02160542351859, 64.05769402640206, 22.470156363078527, 0.20713956068669045, 0.4935912883707455, 1.0539986257042204, 8.708352736064366, 65.79270785195487, 57.3522481237139, 61.723481450762065, 62.28969015393938, 62.58437715257917, 54.163681575230186, 31.862142358507427, 38.575877462114605, 47.532591819763184, 61.98520619528634, 5.496775056634631, 0.6027935200503894, 0.0564200477009373, 0.11910213902592659, 0.025055967470897094, 0.08759902697056532, 0.04838599291230951, 0.1788447725453547, 0.1252391625727926, 0.11548162544412272, 0.2091108270521675, 0.14101664881621087, 0.20407826852585587, 0.28594502487352913, 0.2107331771403551, 0.16076922390077794, 17.416474444525583, 83.1981120790754, 54.63324431010655, 54.84536586488996, 44.214406626565115, 60.09559495108468, 61.46650232587542, 72.86582115718296, 56.74849830354963, 67.74594375065395, 53.45016758782523, 68.3328719820295, 12.342690518924169, 0.5907165738088744, 3.2290630383150916, 5.1061347382409235, 0.12254083236413342, 12.097994072096688, 68.40648814610073, 51.04706709725516, 55.550357886723106, 41.206531456538606, 49.08205400194441, 49.92718424115862, 46.58858176640102, 39.2985873903547, 42.075754574366975, 44.842829499925884, 45.84863335745675, 45.31629017421177, 46.89907244273594, 44.30201298849923, 42.93321091788155, 38.40260328565325, 38.894584383283345, 38.17548751831055, 40.50659077508109, 39.4428528376988, 38.958598136901855, 39.811135155814036, 41.1475829396929, 39.00403240748814, 41.10179778507778, 39.65879590170724, 41.33701515197754, 38.44547367095947, 39.60924482345581, 39.134707178388325, 39.75589350291661, 38.440842696598594, 41.56839363915579, 38.36524977002825, 39.7180084500994, 38.065963063921245, 38.706767627171104, 38.94574049540928, 39.7903287751334, 40.365914072309224, 43.21096863065447, 41.76297446659633, 38.39463717596871, 40.145249707358225, 43.66351522718157, 45.73528739384243, 50.134845052446636, 53.01150001798357, 51.02656296321324, 50.047943932669504, 50.83559519904, 50.30708394731794, 40.907849243709016, 31.58860915047782, 36.500690255846294, 35.953491824013845, 34.36630439758301, 35.016600200108115, 35.39726768221174, 35.695043155125205, 39.76246302468436, 51.732625007629395, 40.05150808606829, 32.58505378450666, 37.23647321973528, 37.290578842163086, 36.94398185185024, 35.30217463629586, 35.299284185682026, 34.14437893458775, 36.298918042864116, 36.68800674165998, 39.460588114602224, 47.0041708946228, 52.037842001233784, 51.212128502982004, 51.813300541469026, 49.88626977375576, 47.83366073880877, 42.85264308112008, 40.08292784009661, 37.70585877554757, 36.370321205684114, 35.466919898986816, 37.705351557050435, 39.476812158312114, 38.93524176733834, 34.86990983145577, 36.21483094351632, 35.77766418457031, 39.45408807482038, 39.97299691608974, 41.549855845315115, 38.942064898354666, 37.63719320297241, 40.82571458816528, 41.82168327059065, 40.315636907305034, 41.586910588400706, 41.73404564176287, 44.716525145939414, 39.39372559956142, 41.218947887420654, 40.088694844927105, 38.98818704060146, 40.592574732644216, 40.05944292885916, 42.49393538066319, 40.83686644690377, 38.398132119859966, 39.73210634504046, 41.563043526240754, 41.63632270268032, 41.419118540627615, 42.550170625959126, 40.981475830078125, 43.02452761786324, 44.16293437140328, 50.2788290977478, 53.038549355098176, 56.68620075498308, 54.665612493242534, 61.955759729657856, 52.307439054761616, 52.0956266948155, 54.14326081957136, 66.4275369644165, 24.845295565468923, 0.29638792308313505, 0.7678639910050801, 1.511862331203052, 10.121356640543256, 72.71776894160679, 61.43083722250802, 64.9111829485212, 69.99524239131382, 66.69264548165458, 60.970484324863975, 47.133984088897705, 49.57214866365705, 55.17248705455235, 75.19485037667411, 9.587006296430316, 0.7679314645273345, 0.2063312762017761, 0.1887433771044016, 0.13292802284870828, 0.20840820404035704, 0.17936767877212592], [0.05349967708545072, 0.02843409138066428, 0.06587458840970482, 0.05187580707882132, 0.013231664413719304, 0.010447524970264306, 0.06447023126695837, 0.033498639440430064, 0.03238544845953584, 4.975149469716208, 55.94781569072178, 43.417163372039795, 41.41930266789028, 19.049669367926462, 29.721114022391184, 53.16286652428763, 59.57921872820173, 51.90637513569423, 55.59370074953352, 46.26656750270298, 54.981387274605886, 20.462220770972117, 0.1896877350019557, 0.2590709669249398, 0.6144651366131646, 0.03997603990137577, 4.618937909603119, 58.655143056597026, 52.546418871198384, 46.52004473549979, 38.10493550981794, 49.59447322572981, 46.77322319575718, 43.113148416791645, 38.428179604666575, 39.074952670506065, 38.720267977033345, 42.27435840879168, 41.8026556287493, 42.89292178835188, 41.96018171310425, 39.933954988207134, 33.8537392616272, 36.42860616956438, 35.163950647626606, 36.34122214998518, 34.41595622471401, 34.38320936475481, 34.23339925493513, 35.62889630453927, 34.63601262228829, 36.744304520743235, 35.11535842078072, 36.77127047947475, 35.41295671463013, 36.438795702798025, 34.267233507973806, 37.54608147484915, 34.952211243765696, 35.25254365376064, 35.93788964407784, 37.45605713980538, 35.90505940573556, 35.99292285101754, 33.716946601867676, 33.672492027282715, 34.024202891758506, 34.775921549115864, 36.69090414047241, 35.99820695604597, 37.90330573490688, 37.98056970323835, 42.443734645843506, 45.465725081307546, 45.66146625791277, 47.06512744086129, 45.580544063023154, 48.028564657483784, 47.0724265234811, 41.69605984006609, 32.60590532847813, 35.54154355185372, 34.34488657542637, 34.2325758934021, 33.365371227264404, 36.447748456682476, 35.69288573946272, 36.799382890973774, 46.386785234723774, 39.65242787769863, 34.400729247501914, 36.41140937805176, 34.41457005909511, 34.82462494713919, 35.88762984957014, 36.78380502973284, 36.89347539629255, 35.80612400599888, 34.71805695125035, 36.97637087958199, 40.69681160790579, 48.234950474330354, 46.73729753494263, 44.79790244783674, 43.368182046072825, 41.83869593484061, 42.60881689616612, 36.77064166750227, 34.24600328717913, 33.994266578129356, 31.59713111604963, 34.63917405264718, 36.522396428244456, 36.64659200395857, 33.85261017935616, 34.635314328329905, 34.910782609667095, 35.07586833408901, 34.13127810614449, 34.18948663984026, 35.50332498550415, 37.05460064751761, 36.39679036821638, 36.06573302405221, 35.37712485449654, 37.41610847200666, 37.01839358466012, 36.41888216563633, 38.11460740225655, 36.730359486171174, 35.97259589603969, 36.6661650793893, 36.79738528387887, 36.76337732587542, 35.381304195949006, 34.64337771279471, 34.41234316144671, 36.996628352573936, 35.92700529098511, 35.23383910315377, 36.14214236395699, 35.85392413820539, 34.4593824659075, 36.1543607711792, 42.155280181339805, 50.1196562903268, 49.211835929325645, 50.221367495400564, 53.55622489111764, 56.232907227107454, 49.809415749141145, 56.57410546711513, 47.118788378579275, 63.19977910178048, 10.3948837688991, 0.2493569238909653, 4.376516129289355, 1.1918216816016605, 13.265851633889334, 56.84214959825788, 51.81407526561192, 58.39029162270682, 56.785132680620464, 59.50935459136963, 42.86049107142857, 24.289872203554424, 36.80141871316092, 47.496836389814106, 44.23133591243199, 1.0392624735832214, 0.08617126715502568, 0.05863925415490355, 0.024468249275482128, 0.02430910736854587, 0.03720183929960642, 0.028088359128949896, 0.022950895696080158, 0.0265566358741905, 0.08183954030807529, 0.03257030514734132, 0.008339353986749691, 0.06950183984424387, 0.06569018294768673, 0.06519466917961836, 0.0954863383833851, 6.575055139405387, 64.91585908617292, 48.70686864852905, 51.02530881336757, 27.16925781113761, 41.574382986341206, 55.64325530188424, 64.85118525368827, 56.42491027287075, 60.974396160670686, 50.51577656609671, 60.94993155343192, 20.968998057501658, 0.17367567920259067, 0.358598809157099, 3.3225408451897755, 0.11365440527775458, 5.268480701105935, 62.3984294618879, 54.12142610549927, 49.59707532610212, 40.2657801083156, 52.63766261509487, 48.02967636925833, 45.43362787791661, 38.50600290298462, 41.58466632025582, 40.756187438964844, 44.12430933543614, 42.30121667044503, 46.426125935145784, 43.940713609967915, 41.04257134028843, 36.06265149797712, 38.083455153873985, 36.58232464109148, 36.526742526463096, 35.9665162222726, 36.332908630371094, 36.25263261795044, 37.182186944144114, 35.87245845794678, 38.57679462432861, 36.74153913770403, 38.9125246320452, 36.311720098767964, 36.9739077431815, 35.938244002205984, 38.71923616954258, 35.0137688091823, 38.34183086667742, 37.154651233128135, 37.47532796859741, 36.63743775231497, 38.00078201293945, 35.699055739811485, 34.82314498083932, 34.7370012147086, 36.76240110397339, 37.93430512292044, 39.21587950842721, 38.307569299425396, 40.08612748554775, 44.25423717498779, 47.085756642477854, 47.401236125401084, 48.68957805633545, 46.89948238645281, 48.8816853250776, 48.571955476488384, 42.25115837369646, 31.9866749218532, 35.33079079219273, 34.48173482077462, 34.28848109926496, 33.21908385413033, 36.07206283296858, 35.82844161987305, 37.86330842971802, 50.00325311933245, 40.09879057747977, 34.01706709180559, 37.68740783418928, 33.895199162619456, 34.98486777714321, 36.043241705213276, 36.72897679465157, 36.08791514805385, 35.0677250453404, 35.98109006881714, 37.50294705799648, 42.32761982509068, 50.704948220934185, 48.098150866372244, 48.714588097163606, 44.056623458862305, 46.96753304345267, 43.76676893234253, 39.179092270987375, 35.579004764556885, 35.5717647416251, 33.82471316201346, 35.85463980266026, 37.43041481290545, 39.16868039539882, 35.81071676526751, 35.11267989022391, 36.18223694392613, 35.50031988961356, 35.491426195417134, 36.96636547361101, 36.57914931433541, 39.06651060921805, 37.91509335381644, 38.568759032658164, 38.42411143439156, 39.08800833565848, 39.7932504926409, 37.73078891209194, 39.98857825142996, 39.006703989846365, 38.9094500541687, 39.37249885286604, 37.375815868377686, 38.09652818952288, 36.24086584363665, 37.323145048958914, 36.789210728236604, 38.88260568891253, 37.71055923189436, 38.71882969992501, 37.58083636420113, 38.621249198913574, 36.58446816035679, 39.47706924165998, 45.103320939200266, 51.5344797543117, 52.493115765707834, 53.72487851551601, 54.75635249274117, 56.87536893572126, 53.378375325884136, 57.956505162375315, 51.39860078266689, 65.37709440503801, 12.081597191946846, 0.5735228221331323, 1.2315254254000527, 1.2181877068110873, 14.803364651543752, 63.314410482134136, 56.520819732121055, 63.71078436715262, 61.35121781485421, 62.73616055079869, 52.5706924029759, 28.746759448732647, 40.74252380643572, 53.20875242778233, 54.68807601928711, 1.8185292184352875, 0.12522878098700727, 0.047080162446945906, 0.03480161666604025, 0.026936715568548868, 0.01176752070231097, 0.07574360205658845, 0.18380768623735222, 0.08586305619350501, 0.1890249012836388, 0.16190351732075214, 0.06609588582068682, 0.12876530550420284, 0.11624257532613617, 0.09515963055725608, 0.15445822397513048, 7.059976867267063, 75.33960219791958, 55.606311729976106, 56.40832839693342, 25.890014546258108, 43.86083364486694, 62.24230343954903, 69.17512566702706, 60.60940728868757, 65.88015093122209, 53.45010505403791, 67.39328793116978, 24.639488186155045, 0.38265816814133097, 2.0364512162549153, 4.2002598728452405, 0.12810226822538034, 7.619656000818525, 66.76107134137834, 56.64057888303484, 52.0669584274292, 40.706521715436665, 53.96379232406616, 50.580162048339844, 47.71817473002842, 41.96131774357387, 43.35074554170881, 43.02930450439453, 46.87925270625523, 44.5522905758449, 49.37833908626011, 46.27096571241106, 44.53840807506016, 37.5913211958749, 41.300165380750386, 38.18153245108468, 38.96398646490914, 37.977491651262554, 37.89857053756714, 39.23129408700125, 40.0152975491115, 38.7644932610648, 41.12047106879098, 39.473671572549, 40.97996807098389, 38.7717923436846, 40.17768389838082, 38.958903857639854, 41.59650257655552, 36.296996865953716, 41.15900577817644, 38.6471277645656, 40.02750900813511, 37.519150257110596, 39.209848472050254, 38.82023865836007, 37.325632504054475, 36.71279444013323, 37.79892642157418, 40.34676831109183, 40.604150431496755, 41.15353059768677, 42.95650822775704, 45.55955702917916, 50.77806411470686, 51.05765267780849, 51.7649758202689, 49.04940441676548, 52.44251203536987, 50.04854842594692, 43.91769422803606, 33.384450980595176, 35.74161345618111, 34.292142799922395, 34.364869594573975, 32.053419317517964, 35.87645714623587, 36.56334563664028, 37.56653697150094, 50.831759793417795, 39.04366493225098, 33.756384577069966, 37.40743017196655, 32.95655311856951, 35.28764247894287, 37.07207884107317, 37.314518860408235, 37.85418544496809, 36.22378717150007, 36.48691545213972, 38.14858061926705, 43.784823826381135, 52.70907620021275, 50.338128498622346, 51.35355561120169, 47.55121646608625, 49.29044437408447, 47.13199690410069, 42.769549574170796, 36.56076438086373, 37.30712250300816, 35.99329457964216, 36.38702120099749, 40.74821090698242, 41.2274420601981, 38.06227357046944, 36.606827463422505, 37.99057510920933, 37.192254883902415, 37.67226423536028, 38.383467946733745, 38.40552152906145, 42.52046707698277, 40.8405316216605, 39.88872568947928, 40.116171496255056, 42.595907143184114, 42.516510077885215, 42.2822585105896, 43.2015711920602, 42.42527675628662, 39.986813408987864, 41.77611698423113, 41.088339124407085, 40.813829694475444, 37.8070627621242, 39.38308443341936, 38.959779330662315, 41.015501158578054, 39.504622323172434, 40.40676253182547, 40.39201845441546, 41.43985891342163, 38.669709409986226, 41.569227422986714, 45.68424245289394, 53.95234169278826, 53.43318619046892, 56.156702859061106, 55.78720113209316, 59.04433945247105, 56.06348235266549, 63.72472940172468, 51.09385279246739, 70.77469825744629, 12.261514714785985, 0.4418809488415718, 11.28282880783081, 1.8441921727997916, 17.232454878943308, 67.75252369471959, 62.4357899257115, 68.45497962406704, 67.49428694588798, 67.22407845088414, 57.99016918454851, 35.13081121444702, 49.11243152618408, 57.83104501451765, 66.81582314627511, 3.042407065629959, 0.3553242262985025, 0.16269766113587789, 0.19553026078002794, 0.15562336359705242, 0.20877979695796967, 0.22046328788357122], [0.007973188501117485, 0.017779600507180606, 0.017296013688402515, 0.03398831102198788, 0.027001228981784413, 0.02106867008842528, 0.07845606614968606, 0.03182119230872818, 0.09429423377982207, 2.3902482773576463, 47.91694532121931, 52.1487352507455, 38.25306068147932, 19.809614692415508, 25.761287008013042, 51.252928325108115, 58.29026535579136, 53.57957778658186, 53.85440335954939, 47.36360815593174, 52.976105894361226, 31.494311673300608, 0.07125208021274634, 0.4138459989002773, 2.5562179429190497, 0.044466201282505474, 1.527506417461804, 51.87340940747942, 52.28022643498012, 45.41835226331438, 43.69616828645979, 53.091407775878906, 49.58799750464303, 44.558144433157786, 36.93568222863333, 36.90068415233067, 38.4564448765346, 41.170334815979004, 40.59194939477103, 42.54016521998814, 42.13178832190377, 43.85395840236119, 33.99022620064871, 35.90634134837559, 36.972361768995015, 35.901508876255576, 35.078195980616975, 33.49903719765799, 35.39394991738455, 33.970667021615164, 34.92820174353463, 36.16654443740845, 34.215240137917654, 34.85663529804775, 35.564469133104595, 34.462985106876914, 36.18669421332223, 35.929704666137695, 34.08344323294503, 34.20942102159773, 32.87610687528338, 34.6653652872358, 35.44070781980242, 34.277687072753906, 34.94385256086077, 34.56012092317854, 36.01804058892386, 35.7629930632455, 34.56784732001168, 35.40232597078596, 36.15040029798235, 39.49195575714111, 43.40105744770595, 44.704073974064414, 43.45982183728899, 44.26177944455828, 46.376307351248606, 46.76922798156738, 45.8065550667899, 43.90160914829799, 33.17584868839809, 34.90354258673531, 33.31464242935181, 34.704386370522634, 34.41893352781023, 35.41269963128226, 35.97857829502651, 37.016291754586355, 47.498910427093506, 38.2860472542899, 35.727602413722444, 36.32391766139439, 34.682513441358296, 35.839371136256624, 37.01952961512974, 37.07184260232108, 34.782498019082205, 36.263603823525564, 35.48848710741316, 36.2056245803833, 44.305653844560894, 48.7365756716047, 45.57558652332851, 45.8334515435355, 42.65789202281407, 42.63115188053676, 41.65335621152605, 41.50602313450405, 36.29614571162632, 34.996756144932334, 32.88349281038557, 33.55000918252127, 32.276442595890586, 34.52616160256522, 32.52237408501761, 35.28364379065377, 36.10719639914376, 34.60622916902815, 35.46044765199934, 34.56248331069946, 33.652588912418906, 34.680137157440186, 34.4513156073434, 35.722408635275706, 34.77928447723389, 37.969605445861816, 37.59723063877651, 38.37264960152762, 36.41155876432146, 37.205435616629465, 34.30388872964041, 35.152388845171245, 36.44226632799421, 35.75207396915981, 35.60205888748169, 35.81687634331839, 36.96464926855904, 34.41622373035976, 35.17415407725743, 34.701026916503906, 37.208617891584126, 36.67444385801043, 36.31981127602713, 36.64419834954398, 42.54666525976998, 48.47369057791573, 48.9960526738848, 51.02931097575596, 47.75377382550921, 57.03031029020037, 53.802093846457346, 54.031116894313264, 55.78338657106672, 52.03072704587664, 1.8740670382976532, 0.28000597070370403, 0.5042547647442136, 0.32396258200917927, 14.766429764883858, 61.60687678200858, 48.4168438911438, 59.65195941925049, 54.45364727292742, 57.33556202479771, 38.58483716419765, 25.4528842653547, 33.133506366184776, 47.45686687741961, 33.0484812600272, 0.564584344625473, 0.07777658118201153, 0.09747190148170505, 0.03145189283947859, 0.03250010052163686, 0.044966183203671656, 0.030491548656885113, 0.010877287846856883, 0.01849222512516592, 0.021033114853448102, 0.01801291138066777, 0.01600156395163919, 0.02608955611607858, 0.06691829740468945, 0.03140506374516657, 0.1045908737661583, 3.583322588886533, 56.39104127883911, 55.387248924800325, 40.1567976134164, 17.12138966151646, 37.29242706298828, 59.194566454206196, 64.96701867239815, 56.38023683003017, 58.92674119131905, 52.94497101647513, 59.614369664873394, 33.89867673601423, 0.015089677347402488, 0.35218640895826475, 2.301410347223282, 0.1539966030312436, 2.1891443942274367, 56.71961464200701, 54.35252666473389, 46.64720024381365, 44.90677029745919, 54.69172729764666, 50.922399044036865, 46.727931363242014, 38.402950695582796, 39.450728620801655, 39.17209890910557, 41.99113246372768, 42.60635723386492, 45.44627359935215, 43.672429765973774, 44.93924617767334, 36.125748089381624, 37.49075991766793, 37.14438526970999, 38.06384038925171, 36.5804694720677, 35.52553142820086, 35.72622667040144, 35.664585726601736, 36.653210163116455, 38.79903623035976, 35.144850049700054, 35.627110617501394, 36.878779956272666, 36.66576208387102, 38.18153592518398, 38.15302399226597, 36.41048526763916, 35.92968034744263, 35.041304520198274, 35.871093136923655, 36.97570385251726, 35.83323587690081, 36.71972874232701, 36.948067392621724, 36.45443262372698, 38.879009996141704, 36.12887477874756, 37.28908845356533, 37.55308525902884, 40.24259744371687, 45.84766755785261, 47.149565424237935, 45.11921494347708, 47.39084162030901, 48.04594210215977, 48.764941692352295, 47.76772233418056, 44.509520939418245, 31.677511351449148, 36.254456520080566, 33.847854137420654, 34.97046763556344, 35.2937673160008, 34.33937317984444, 34.94196612494332, 36.77294152123587, 48.88362734658377, 39.808091844831196, 34.99028737204415, 36.09270245688302, 34.323486123766216, 36.01534816196987, 36.551363468170166, 36.49651091439383, 35.61155707495553, 35.10010017667498, 35.355981486184255, 36.05133635657174, 44.940792151859824, 49.733225277491975, 46.57642241886684, 48.204569475991384, 44.56704160145351, 45.0917626108442, 43.956506865365164, 43.042519978114534, 37.67297642571585, 36.29059757505144, 33.92980119160244, 35.00554214205061, 32.80131646565029, 35.420537199292866, 35.216934135981965, 36.647814886910574, 36.785437856401714, 36.44216905321394, 36.8212627683367, 37.1217862537929, 36.4472690309797, 36.17300626209804, 35.73052413122994, 37.44171953201294, 37.990853037152974, 39.94760125023978, 39.25396605900356, 40.88951294762747, 38.375005040849956, 38.76889494487217, 36.42438513892037, 38.488479546138215, 37.99500805991036, 38.02739708764212, 37.6381242615836, 37.69190331867763, 38.104793071746826, 36.373298508780344, 37.59752941131592, 37.51751395634243, 39.31216764450073, 38.58875594820295, 37.150749819619314, 38.36513859885079, 45.35876103809902, 50.849046911512104, 51.52937977654593, 53.17437621525356, 53.24092606135777, 58.901053701128276, 55.82565246309553, 56.41985198429653, 58.401325362069265, 53.864877768925254, 2.40423652103969, 0.7627259067126683, 0.3369056646312986, 0.6182514705828258, 16.6404127734048, 66.71586636134556, 53.060071400233674, 63.75009727478027, 59.18809073311942, 61.471713474818635, 47.806774684361045, 25.357151985168457, 36.58866834640503, 55.3403103692191, 40.85628318786621, 0.48739197530916756, 0.13226034439035825, 0.046612431295216084, 0.029437308798411062, 0.025711096424077238, 0.06722635230315582, 0.03374167372073446, 0.07190973670887095, 0.08026218387697424, 0.17650180469666207, 0.05479424047682967, 0.10211511661431619, 0.11185754955347095, 0.19170120624559267, 0.14918003577206815, 0.1480625428791557, 3.8501410143715993, 66.21764578138078, 63.11508750915527, 51.752451692308696, 29.060745068958827, 39.751519611903596, 63.5756071635655, 68.32085159846714, 61.77097238813128, 63.00541019439697, 56.08840206691197, 63.78820814405169, 37.78088889803205, 0.10437828195946557, 1.3678466933114188, 6.585725835391453, 0.33640316873788834, 2.76761862209865, 61.56211648668562, 56.58809219087873, 50.931872912815635, 47.14393738337925, 56.67278725760323, 54.04878963742937, 49.20701387950352, 41.347472190856934, 41.117340905325754, 42.727374008723665, 44.50613716670445, 44.450388295309885, 47.73000751222883, 46.48425803865705, 47.79636975697109, 37.980125018528526, 40.282323769160676, 39.191397530691965, 40.083952699388774, 37.78597150530134, 37.06049966812134, 39.42935248783657, 36.70218106678554, 39.45904908861433, 40.898827007838655, 37.93474980763027, 38.99738992963518, 40.03801121030535, 38.29968309402466, 40.796302863529746, 40.94035291671753, 39.704904147556846, 38.86799362727574, 36.64398642948696, 37.13914980207171, 38.017051219940186, 37.47428226470947, 39.04964733123779, 38.130286012377056, 39.62233870370047, 40.06286839076451, 39.38702058792114, 40.43075813565935, 39.703677790505544, 43.421905517578125, 48.96235738481794, 48.59244224003383, 48.04112352643694, 49.808144228799, 50.024636200496126, 51.149493966783794, 48.09413480758667, 46.265070165906636, 32.39820282799857, 36.09681926454817, 32.663029943193706, 33.69132511956351, 34.70566136496407, 35.1050785609654, 35.95281090055193, 36.47285229819161, 51.2252710206168, 39.516986642565044, 37.011320318494526, 36.780372619628906, 34.71499626977103, 37.110860211508616, 37.64970690863473, 38.39529725483486, 34.12152978352138, 36.37309006282261, 35.61498948505947, 36.889309951237266, 46.89183241980416, 52.081327302115305, 49.71517038345337, 51.931680474962505, 45.95856080736433, 47.058891432625906, 45.27100876399449, 46.07980687277657, 39.9735631942749, 39.55231475830078, 35.54705694743565, 36.30965995788574, 35.49415683746338, 38.39008263179234, 37.9311853817531, 37.7015335219247, 40.31503241402762, 38.41471399579729, 38.31759902409145, 37.82648297718593, 38.193382603781565, 39.9703357560294, 39.060118266514365, 40.23574651990618, 39.15762233734131, 42.044532843998496, 40.91618013381958, 43.455260344914024, 40.753220558166504, 41.84528977530343, 39.11696147918701, 39.937112944466726, 39.86460154397147, 38.766966819763184, 39.90230941772461, 40.019150325230186, 41.650194781167166, 38.24659538269043, 38.603027548108784, 38.65423577172415, 40.24390370505196, 40.84181356430054, 39.7206974029541, 39.393333026341026, 46.313690185546875, 53.11630317143032, 54.163254261016846, 55.15977185113089, 55.72507381439209, 61.71427508762905, 57.48961053575788, 61.659829003470286, 61.84783336094448, 56.19373675755092, 3.0192591420241763, 0.6954220182129315, 2.183054949556078, 0.8157903307250568, 19.1866009916578, 73.13737065451485, 56.9462058203561, 70.60728141239711, 65.32056386130196, 66.07394313812256, 51.90510361535208, 35.18651144845145, 46.507513659340994, 62.323951721191406, 51.95645775113787, 1.16204691358975, 0.287778127938509, 0.20818563098353998, 0.15229292373572076, 0.11004424614033528, 0.14243684975164278, 0.12205958818750721], [0.02379424008540809, 0.04467959036784513, 0.04937256247337375, 0.031357501833034415, 0.09012125698583466, 0.02335998445882329, 0.037681241253657, 0.04347370471805334, 0.010187631639252816, 1.190696073429925, 38.91971254348755, 52.14984348842076, 40.439703941345215, 22.374860082353862, 25.254829338618688, 44.52721800122942, 58.39380046299526, 54.71278728757586, 52.753989355904714, 50.978422369275776, 50.13741936002459, 38.30562032972063, 0.22884342606578553, 0.18845235343490327, 1.9777026772499084, 0.1600603312253952, 0.4854675957134792, 39.801442418779644, 53.08463675635201, 44.95804452896118, 48.74706745147705, 52.18066569737026, 49.83820908410208, 42.187558037894114, 36.55424697058541, 37.234263692583355, 39.939433642796104, 41.7015836579459, 41.60157128742763, 45.12195600782122, 43.022404943193706, 43.29253700801304, 36.085121972220286, 36.42780365262713, 37.52900627681187, 34.36548103604998, 33.419765199933735, 33.990570136478965, 34.073587213243755, 33.81497526168823, 33.26266295569283, 34.55757440839495, 34.245089599064414, 32.61188077926636, 33.52099003110613, 34.245829582214355, 34.50014754704067, 34.87690666743687, 34.7246264730181, 34.52057525089809, 36.42179346084595, 36.10084227153233, 35.12384564535958, 34.74154533658709, 34.10172394343785, 33.4737422806876, 33.187153407505576, 34.916956084115164, 33.48101009641375, 34.89918606621878, 34.77706452778408, 41.552086217062815, 43.852360316685264, 47.53014952795846, 45.200227464948384, 45.9536588532584, 45.229083333696636, 47.79329865319388, 46.73078012466431, 45.36640753064837, 35.61291544778006, 33.1699983051845, 34.22264691761562, 34.95595284870693, 35.57056270326887, 34.54035677228655, 36.201486928122385, 37.721009322575156, 48.064511162894114, 38.02231100627354, 35.695883887154714, 35.28322689873831, 35.8443147795541, 36.96040391921997, 35.006969996861045, 35.90405886513846, 36.04423877171108, 35.014105796813965, 33.54466949190412, 37.315627098083496, 46.93474102020264, 47.51585013525826, 47.41624423435756, 44.95540768759591, 43.777681078229634, 44.41980579921177, 40.16601439884731, 38.29685517719814, 40.024219036102295, 37.31706190109253, 36.15873466219221, 36.036807673318044, 34.38491514750889, 32.79772424697876, 32.72451107842581, 33.61676747458321, 35.14876535960606, 35.44698551722935, 35.46496050698416, 35.62608923230852, 34.28403772626604, 35.32310261045183, 35.251741136823384, 34.52815573556082, 35.082931177956716, 37.29208312715803, 36.83570112500872, 38.792442389896934, 36.11612136023385, 35.38326358795166, 35.08234405517578, 34.54935121536255, 34.48312793459211, 36.428025994982036, 33.87775918415615, 34.037272453308105, 34.51521471568516, 37.016420296260286, 36.19761678150722, 35.810164383479524, 35.8081841468811, 35.74061986378261, 36.94946050643921, 36.43922649111067, 44.63340037209647, 48.96956614085606, 52.784603118896484, 51.31248480933053, 49.58116742542812, 44.40430784225464, 57.11992120742798, 48.819290501730784, 59.524522508893696, 30.7407135282244, 0.03282167523034981, 0.532775382910456, 0.6342020918216024, 0.08978896481650216, 23.437590530940465, 62.023185048784526, 47.08021545410156, 60.66924517495291, 55.588989870888845, 60.71604129246303, 35.92714772905622, 32.87895563670567, 35.84898049490792, 51.6938019480024, 28.739891154425486, 0.5291226931980678, 0.06571859999426774, 0.004876006926809038, 0.06719897341515337, 0.03112181947965707, 0.03964977651568396, 0.08312991035303899, 0.06701644070978675, 0.04299527306907943, 0.03374614187383226, 0.06255323413227286, 0.022053524652229886, 0.02283510030247271, 0.035166098536657434, 0.054333447345665524, 0.01549760072625109, 1.6713410764932632, 48.28574180603027, 59.5259816305978, 49.40050383976528, 28.461558478219168, 30.48888996669224, 51.38989468983242, 62.18042973109654, 61.058990478515625, 57.7001131602696, 55.466708523886545, 55.13582488468715, 43.35476507459368, 0.1353925841727427, 0.0017011192041016848, 2.7619992664882114, 0.7991676341210092, 0.5803006270102092, 43.43896681921822, 56.17652259554182, 47.85143423080444, 50.786620821271626, 54.75272900717599, 52.5126610483442, 44.520481722695486, 38.072282450539724, 39.153821672712056, 41.45591967446463, 44.096495696476524, 44.60715355191912, 46.355184827532085, 44.655547755105154, 45.162995542798726, 37.42979294913155, 37.47053371156965, 38.77934503555298, 36.66236441476004, 35.481830733163015, 36.80198151724679, 35.875678947993684, 34.946343490055625, 35.80009991782052, 36.37167263031006, 37.41779688426426, 34.88717263085501, 35.13020672116961, 36.10277387074062, 36.526169300079346, 36.61624574661255, 37.152670996529714, 36.82163102286202, 37.86477449962071, 38.472186020442415, 37.03660828726632, 36.43358107975551, 36.1469852583749, 35.79084491729736, 34.74181979043143, 35.95211608069283, 35.14270305633545, 35.41091741834368, 36.63916785376412, 43.67096717017037, 45.90179749897548, 48.53541142599923, 47.99418149675642, 45.83990642002651, 47.57404129845755, 49.37064395632063, 47.33984184265137, 45.495616231645855, 35.81769275665283, 32.57467664991106, 34.64325959341866, 34.446233000074116, 35.471780163901194, 35.23847007751465, 35.38579968043736, 38.15556008475167, 48.09066070829119, 37.71496786390032, 35.24397652489798, 35.56120695386614, 35.41118144989014, 36.5609450340271, 34.06535359791347, 36.20681619644165, 35.196148599897114, 36.15937737056187, 34.337385995047434, 37.84978723526001, 48.495980398995535, 49.671716349465505, 47.147995131356375, 46.1402006149292, 45.32181051799229, 47.3150680405753, 42.35159458432879, 39.638753822871614, 40.165399483272004, 39.99286528996059, 38.10532113483974, 37.372359139578684, 35.458495208195274, 34.90318475450788, 34.0174492427281, 35.63460424968174, 37.11424398422241, 38.371933937072754, 36.474012647356304, 36.86566175733294, 35.98236158915928, 37.40834386008126, 36.86114542824881, 37.47973312650408, 37.02684954234532, 39.14022057397025, 41.01072774614607, 40.050382477896555, 38.11641045979091, 37.99327448436192, 36.84614079339163, 36.874961921146934, 35.9302396774292, 37.66926261356899, 35.55082287107195, 37.8595564024789, 38.39612409046718, 40.219758714948384, 38.51476458140782, 37.78637102672032, 38.24195398603167, 38.076725823538645, 38.37894466945103, 37.15205260685512, 47.88326045445034, 53.541296686444966, 54.84543187277657, 52.07891975130354, 53.159031118665425, 48.63802589688982, 58.08487313134329, 51.57838889530727, 62.58780261448452, 32.78891740526472, 0.0032128637373846558, 1.1182436240570885, 0.5105136803218296, 0.23444196422185215, 25.934566395623342, 66.84796551295689, 51.63963031768799, 65.80426270621163, 63.03009019579206, 65.59328065599713, 42.250449657440186, 32.41508000237601, 40.278860092163086, 58.528949873788015, 36.507200717926025, 0.7902874020593507, 0.17028752315257276, 0.03185530226411564, 0.026375260071030686, 0.033772370644978116, 0.09663361896361623, 0.04639356303960085, 0.1055496030354074, 0.12775492614933423, 0.14601038156875543, 0.2145345474460295, 0.16432953785572732, 0.1151746426309858, 0.15812616715473787, 0.14716934652200767, 0.08382081506507737, 1.7771291370902742, 53.36429827553885, 67.49965790339878, 55.95042821339199, 31.755581310817174, 38.31903035300118, 56.6171669278826, 67.09309795924595, 65.81668608529228, 62.75393404279436, 59.381931577410015, 59.2164671761649, 47.77927718843733, 0.39186499267816544, 1.1639026254415512, 8.916608486856733, 0.9773305739675249, 1.3659445153815406, 50.79160615376064, 57.670326232910156, 49.56672559465681, 52.91626453399658, 57.02915341513497, 53.45830740247454, 47.04892424174717, 39.49675696236746, 41.901226248059956, 43.44218036106655, 45.94465051378523, 46.93659618922642, 49.25357723236084, 46.662382057734895, 46.612157004220144, 39.40753167016165, 39.7899466242109, 41.0667337008885, 38.23699297223772, 35.752852167402, 38.78469167436872, 37.584963594164165, 37.54907962254116, 38.332186767033164, 39.05239186968122, 40.23005247116089, 36.72202512196132, 37.85093021392822, 38.74385711124965, 38.886409827641074, 38.65473256792341, 39.40913322993687, 38.614141191755024, 41.268787315913606, 40.63842242104666, 38.68686103820801, 37.21286671502249, 38.242416041237966, 37.49028396606445, 35.566775935036794, 37.689770221710205, 36.20250483921596, 39.73150532586234, 38.74399607522147, 45.88555261066982, 48.65949583053589, 52.29560627256121, 50.0068244934082, 49.46294730050223, 48.54076153891427, 52.32565723146711, 50.57923446382795, 46.57899325234549, 36.19113411222185, 32.573787280491416, 34.958068575177876, 35.34738656452724, 36.274046966007774, 34.3966714995248, 35.411744253976, 38.79390845979963, 52.14024107796805, 39.10790797642299, 34.775577613285606, 36.41158308301653, 36.20144871303013, 37.68630307061331, 35.655334200177876, 36.58599328994751, 36.13400254930769, 35.154928411756245, 32.89341483797346, 36.676844460623606, 51.01881572178432, 52.02987241744995, 51.011124065944124, 49.42727872303554, 48.867980003356934, 50.245748724256245, 45.66126128605434, 41.17270415169852, 44.258329663957866, 40.84550653185163, 41.20534331457955, 38.655917235783164, 38.19072144372122, 36.78532668522426, 33.93206977844238, 36.04800469534737, 38.84188577107021, 41.019628388541086, 38.97389112200056, 40.927356311253135, 37.47296558107649, 40.79232154573713, 38.97496461868286, 40.3750752721514, 38.87943383625576, 41.65401629039219, 42.38435534068516, 43.686124665396555, 41.27332101549421, 41.36511714117867, 39.29120492935181, 39.04022557394845, 37.7919191632952, 40.588756697518484, 37.81355932780674, 39.44399929046631, 40.44566202163696, 42.01043455941336, 40.166601521628245, 40.77333211898804, 39.87831728799002, 39.643909386226106, 40.84395360946655, 38.652300698416575, 51.30193049567086, 56.02980095999581, 56.40495157241821, 55.270755427224294, 55.33157300949097, 51.57101338250296, 58.51442813873291, 55.57680967875889, 64.278486933027, 37.129047121320454, 0.10786272891397987, 1.7781049247298921, 2.3858995735645294, 0.390921096184424, 29.09179309436253, 73.58643967764718, 55.9676319531032, 70.58683286394391, 64.11299473898751, 68.7999576841082, 49.825872557503835, 42.96265390941075, 49.68105125427246, 67.07789530072893, 48.44242715835571, 1.2290406844445636, 0.26443855890205925, 0.14197540522686072, 0.1367830652743578, 0.14215129507439478, 0.18236984339143547, 0.24325401708483696], [0.04293237626552582, 0.03326067042403987, 0.06771480252168008, 0.04453201578663928, 0.020081657783261368, 0.030232694332620928, 0.09525668142097336, 0.09821737397994314, 0.06310307141393423, 0.17253572680056095, 31.25180217197963, 62.16852746691023, 31.097986425672257, 27.475072349820817, 30.66625315802438, 35.55243137904576, 58.57122271401541, 54.945371287209646, 50.96976143973214, 52.45599501473563, 45.99663693564278, 49.09479699816023, 2.57407676747867, 0.19776848996324198, 1.6120024834360396, 0.5107981764844486, 0.031352450139820576, 23.537759235927037, 61.50550256456648, 48.14383527210781, 56.852276597704204, 51.597454752240864, 51.31748056411743, 39.49241086414882, 36.01615762710571, 37.779825823647634, 41.97395651681082, 42.57799468721662, 45.03946352005005, 45.883471625191824, 46.46009220395769, 42.129676069532124, 36.57153408867972, 35.48596143722534, 34.29743732724871, 34.72738490785871, 33.97067396981375, 33.93408475603376, 34.815092018672395, 33.83237702505929, 33.215588910239084, 34.597085339682444, 33.622815881456646, 33.86264337812151, 35.487524781908306, 33.50359174183437, 33.26860019138881, 34.22775731767927, 33.42007439477103, 35.42820453643799, 35.633989334106445, 34.38896247318813, 36.721920898982454, 34.5274088042123, 34.70862129756382, 34.21363510404314, 33.90199102674212, 34.13636418751308, 35.347595010484966, 34.44225863048008, 36.10477147783552, 42.015840257917134, 44.55376706804548, 44.53520495550973, 46.070284366607666, 45.81965936933245, 45.81298909868513, 45.34392663410732, 46.55349683761597, 45.63445860998971, 35.18525035040719, 34.37786620003836, 34.42417941774641, 34.907044478825156, 35.740338461739675, 35.7401682308742, 35.457494667598176, 39.00324726104736, 45.8203125, 39.23061663763863, 36.41319159099034, 35.26670755658831, 33.712975706372944, 35.098168577466694, 34.57057448795864, 36.18846947806222, 37.351281779153005, 34.890528610774446, 35.69367436000279, 39.14902394158499, 49.53413506916591, 47.543149607522146, 44.28368016651699, 45.954082693372456, 44.139984471457346, 47.18682166508266, 43.38049077987671, 34.28062268665859, 37.39215455736433, 36.35862738745553, 38.361525535583496, 35.73130580357143, 37.385084765298025, 36.52656534739903, 36.427220003945486, 34.792934213365825, 36.54428325380598, 34.77526494434902, 35.23660796029227, 34.58897679192679, 32.985422883714946, 33.7133925982884, 33.6881810597011, 35.44852106911795, 35.19741317204067, 36.31943607330322, 39.340655258723665, 37.446277550288606, 37.443473952157156, 35.58150611604963, 35.37294551304409, 33.59298379080636, 35.37376192637852, 35.10242782320295, 34.85769142423357, 35.43095602308001, 34.71472181592669, 34.95712014607021, 36.122635296412874, 36.38035440444946, 37.7449562890189, 35.35431391852242, 36.24546207700457, 35.41511413029262, 44.352998869759695, 47.896600995744976, 53.32323094776699, 50.11621693202427, 52.21602160590035, 45.27511862346104, 48.052678380693706, 49.149316038404194, 54.836833477020264, 8.971851876803807, 0.22946102863975934, 0.6175115959984916, 0.7585757694074086, 0.027246846784172312, 28.267312901360647, 60.172129358564106, 45.4416252544948, 62.420455251421245, 41.22540971211025, 52.27079772949219, 34.26922764096941, 36.81961604527065, 36.711005278996055, 58.00198112215315, 14.036758610180446, 0.6428123755114419, 0.017064768954047134, 0.045905207815979204, 0.021820480103737543, 0.02357970766856202, 0.04543700847508652, 0.05304210699562516, 0.018307380311723267, 0.04536175215616822, 0.019429675536230206, 0.03570859067674194, 0.03555734522108521, 0.03667541826143861, 0.02533424486007009, 0.0304032475022333, 0.05738391687295266, 0.35544780109609875, 38.51329156330654, 65.69735772269112, 37.364941937582834, 21.630034037998744, 31.015969889504568, 49.81480407714844, 61.165332657950266, 61.08963898250035, 55.27713387353079, 56.995406014578684, 49.766232694898335, 53.48847648075649, 1.9669527283736636, 0.14353227668574878, 0.9503261830125536, 1.5036000545535768, 0.026015271798574498, 27.429342780794414, 63.611925397600444, 50.316887855529785, 58.765744481767925, 52.87183427810669, 52.95064422062465, 41.21928487505232, 37.24675307955061, 39.42168515069144, 44.34895849227905, 44.95282990591866, 44.97036715916225, 48.34154278891427, 47.98395027433123, 44.298577104296, 38.84092344556536, 35.75703150885445, 36.18591948917934, 37.635789666857036, 36.739982741219656, 36.26473985399519, 37.20319134848458, 35.99909285136631, 36.87173448290144, 36.787661279950825, 35.920390605926514, 36.835457938058035, 36.41146496364048, 34.79926749638149, 36.28638696670532, 35.5959027835301, 34.94410964420864, 38.07332468032837, 36.20759439468384, 35.69709634780884, 38.20937040873936, 35.83046701976231, 35.818929536002024, 35.459888322012766, 37.065874099731445, 34.97632149287632, 36.19129739488874, 35.1542648587908, 39.039892060416086, 42.49977534157889, 45.1510203225272, 45.62381396974836, 47.233378069741384, 48.37705503191267, 47.34394475391933, 47.84526423045567, 47.6562419618879, 46.235595907483784, 35.505190576825825, 33.447752543858115, 35.12704529081072, 34.71169587544033, 35.32771968841553, 35.62065921510969, 35.647923946380615, 38.451084341321675, 46.901108264923096, 39.08765050343105, 35.367557185036794, 34.92290721620832, 35.84112555640084, 34.76695489883423, 34.64080687931606, 36.84226369857788, 36.4554956981114, 35.366136278424946, 34.31455421447754, 39.217088494982036, 49.511772292000906, 48.99694204330444, 46.67833859579903, 47.14773457390921, 45.87304237910679, 48.56819650105068, 44.47975833075387, 38.040477071489605, 39.117288044520784, 37.53002418790545, 38.99241501944405, 37.6656356539045, 37.94803476333618, 38.08856555393764, 37.63388933454241, 36.95043325424194, 37.2810389654977, 36.163240568978445, 36.46516759055001, 35.94070366450718, 35.23045880453927, 35.067752838134766, 36.763710839407786, 37.27082163946969, 38.06008836201259, 38.621909277779714, 41.06150170734951, 40.13921867098127, 40.027467318943565, 37.488612924303325, 37.65707894733974, 36.031836237226216, 37.394708020346506, 36.1142383984157, 37.6062285559518, 36.79233741760254, 36.57023824964251, 36.97074631282261, 39.37841524396624, 37.9169658933367, 40.737493310655864, 38.364447253090994, 38.90554864065987, 37.79899590356009, 45.826079504830496, 51.95179898398263, 54.47005891799927, 53.2604261807033, 53.49281563077654, 46.28622743061611, 53.78896869931902, 50.304797989981516, 59.83881037575858, 11.310697163854327, 0.345172609601702, 2.2565501715455736, 0.756783242736544, 0.016966581544173614, 33.10661336353847, 66.42400727953229, 52.761715752737864, 67.3402384349278, 48.51315982001168, 59.03442437308175, 42.360140868595664, 41.48941693987165, 43.89011335372925, 65.92063808441162, 22.07375294821603, 0.7624653492655072, 0.09857090429535934, 0.017766944132745266, 0.039699584378727844, 0.10996369046292134, 0.0037463351784806165, 0.04627647503678288, 0.16117705058838638, 0.2184673771262169, 0.08640262724033423, 0.15575035821114266, 0.07605192836906229, 0.09066992040191378, 0.2687592256282057, 0.18051628928099359, 0.26898257221494404, 0.5440264163272721, 44.414792673928396, 76.81515639168876, 43.31623036520821, 37.171493666512625, 40.93415512357439, 50.00641107559204, 67.24486746106828, 65.19614941733224, 59.479887281145366, 63.561453683035715, 52.47298683438982, 59.32528291429792, 3.294890488897051, 0.8365016079374722, 3.8352366941315785, 1.722290805407933, 0.08570802451244422, 29.628935745784215, 66.33432688031877, 52.73618459701538, 61.0520909173148, 54.181423800332205, 55.95183869770595, 43.50020129340035, 39.94726773670742, 41.63031251089913, 46.320200647626606, 48.06099190030779, 47.88378504344395, 49.46233933312552, 50.31351450511387, 46.51149150303432, 41.075735092163086, 36.70994220461164, 37.67247615541731, 39.854550974709646, 38.82489742551531, 37.220450673784526, 38.80857958112444, 37.891716139657156, 38.350189549582346, 40.61057751519339, 38.09595496313912, 39.02467897960118, 40.4683062008449, 38.26321547372, 37.85513734817505, 37.40558542524065, 36.64365291595459, 40.13024854660034, 38.15479925700596, 38.026483399527415, 40.651630946568076, 37.030302797045024, 38.812133584703716, 37.184330463409424, 37.982338019779746, 37.392870221819194, 37.89022922515869, 36.915035656520296, 41.565145356314524, 46.28706121444702, 48.59310231889997, 49.06439862932478, 49.58105278015137, 49.74654497419085, 49.756661551339285, 48.924441065107075, 50.20476477486746, 50.055635588509695, 35.62259776251656, 33.58370794568743, 34.92022521155221, 34.4670741217477, 36.157213006700786, 35.6351774760655, 36.38675716945103, 40.097717080797466, 48.91262912750244, 40.14681305204119, 36.628401620047434, 36.17137690952846, 34.3349541255406, 34.6248642376491, 35.020425183432444, 37.43748460497175, 36.89224903924124, 34.921083314078196, 37.03750807898385, 40.06690182004656, 53.59325531550816, 51.850431714739116, 47.24345990589687, 50.41027511869158, 49.03689418520246, 51.19394506726946, 47.49103116989136, 39.668245451790945, 40.47248901639666, 40.05916152681623, 42.16537938799177, 39.91385384968349, 39.84222487040928, 41.487676416124614, 40.29954487936837, 39.89891522271292, 39.165380001068115, 38.42396552222115, 38.18546860558646, 39.101915155138286, 36.51019886561802, 37.21365533556257, 38.00819574083601, 40.240683215005056, 40.9617464201791, 41.720142296382356, 43.70118835994175, 41.922585010528564, 43.181852204459055, 40.86315148217337, 40.068381786346436, 37.87883070537022, 38.98955236162458, 39.537414346422466, 39.729848180498394, 39.16664457321167, 38.45412417820522, 39.78274481637137, 40.094260351998464, 40.95652484893799, 42.329332556043354, 41.436673164367676, 41.0756447655814, 40.03413758959089, 48.231632709503174, 54.63261897223336, 58.129021985190256, 54.94141428811209, 53.62186452320644, 48.01289994376046, 53.701959882463726, 52.67702416011265, 61.151679447719026, 12.532576969691686, 0.28818101489118164, 3.12088696871485, 2.094433064971651, 0.07535725778767041, 36.16475180217198, 72.08970737457275, 55.48201540538243, 71.5278343473162, 50.080607414245605, 64.98890549795968, 48.64546741758074, 48.844158104487825, 49.900374616895405, 75.67078808375767, 29.604783807482036, 1.0035046551908766, 0.2829641391124044, 0.11149682676685707, 0.12141546846500464, 0.18548772537282535, 0.11662665328809194, 0.12922457871692522], [0.035302494253431044, 0.01461998522946877, 0.01659103955275246, 0.021996395396334783, 0.04169262832562838, 0.03458207666075655, 0.013515120721422136, 0.029754863187138523, 0.07177825697830745, 0.10862780428890671, 31.130931309291295, 57.720968178340364, 41.46471956798008, 56.4052677154541, 57.361061913626536, 33.98726626804897, 49.13996376310076, 59.59936850411551, 48.52192497253418, 52.125719342912944, 44.582386698041645, 53.08909402574812, 13.61559007849012, 0.3518785983324051, 0.8584632894822529, 1.4704498733792986, 0.07956481951155833, 4.285357066563197, 60.2777350289481, 48.23065996170044, 55.63124186652047, 49.17994369779314, 50.10485315322876, 36.7109740121024, 40.079648290361675, 37.79184968130929, 44.90140628814697, 44.48987143380301, 48.62679065976824, 48.15523726599557, 48.33495937074934, 40.26140969140189, 37.96357093538557, 34.951985427311485, 35.76029716219221, 33.866367612566265, 34.687398024967735, 35.115771838596885, 35.048631395612446, 33.4809684072222, 34.94692366463797, 34.97749573843819, 35.10072898864746, 32.17785460608346, 32.06531115940639, 33.04374953678676, 36.559009960719514, 32.27583810261318, 33.24282584871565, 33.20736919130598, 35.874556813921245, 35.001946449279785, 37.19972767148699, 35.29426758629935, 35.55737502234322, 33.30514424187796, 34.56915358134678, 33.73962204796927, 34.590387276240754, 33.7787230355399, 37.3835665839059, 42.71479776927403, 42.12659106935774, 43.919566767556326, 46.44896118981497, 46.52670805794852, 45.532886368887766, 45.07058102743966, 48.24433749062674, 42.28494051524571, 35.97684471947806, 34.469863823481965, 35.82672888892037, 35.471675940922324, 37.631982054029194, 36.14256967817034, 37.39199822289603, 38.314402852739605, 46.26852342060634, 38.906563077654155, 33.855556215558735, 36.58941180365426, 34.232495989118306, 35.447805404663086, 35.04588338306972, 33.92237704140799, 35.49554647718157, 35.538177149636404, 35.79914801461356, 40.906324114118306, 47.69155270712716, 44.92893157686506, 46.19761010578701, 44.11644050053188, 44.90759365899222, 43.53802381243025, 45.300847802843364, 40.23287343978882, 34.78388071060181, 33.799678802490234, 33.17008168356759, 35.48537431444441, 34.36954920632498, 33.790083340236116, 34.71019159044538, 34.39913463592529, 36.28289549691336, 35.19904947280884, 34.31941795349121, 32.500004359654014, 33.67922830581665, 33.37608534949166, 34.40985918045044, 35.66195930753435, 36.96256480898176, 36.22733770098005, 34.913895402635845, 35.72165128162929, 35.218056270054404, 35.5811448097229, 34.22356407982962, 33.62272555487496, 33.410555362701416, 35.77695894241333, 35.69073527199881, 35.101941449301584, 35.60213531766619, 35.49681452342442, 35.67240939821516, 35.733365944453645, 36.682260581425254, 36.10050180980137, 35.32851178305489, 36.607015064784456, 41.22946746008736, 47.92235796792166, 50.770101479121614, 51.54899454116821, 51.34672205788748, 50.01249074935913, 46.5103554725647, 47.63198580060686, 41.64899969100952, 1.4857791193893977, 0.1717144822967904, 1.3208034804889133, 0.346390145697764, 0.05835060535797051, 34.204984596797395, 54.68297256742205, 45.46278599330357, 53.95543711526053, 45.23774773733956, 45.16073043005807, 27.15927151271275, 32.859983580453054, 40.68363782337734, 48.92808192116873, 8.671241538865225, 0.46194425225257874, 0.08595431236816303, 0.06786004294242177, 0.014810958910467369, 0.08657872743372406, 0.08861706020044428, 0.018584256526082754, 0.04205757838540843, 0.030085024756512473, 0.01997468334489635, 0.050313371632780345, 0.01593304378911853, 0.05304009174661977, 0.05174283117854169, 0.043448212157402716, 0.08100868096309048, 0.12688952258655004, 36.16507836750576, 66.4149398803711, 44.14964941569737, 50.097422054835725, 47.31848308018276, 39.56980684825352, 54.711995192936485, 65.15178516932896, 51.87747410365513, 57.220110757010325, 48.10053409848894, 59.70717675345284, 13.11260998249054, 0.20056024087326868, 1.507594725915364, 2.2324501276016235, 0.1144774207579238, 4.5684696691376825, 64.89108180999756, 49.18734352929251, 56.156470094408306, 49.657712255205425, 53.75902543749128, 39.13913665499006, 41.70886189596993, 41.37814153943743, 46.504796913691926, 45.63475043433053, 50.28358861378261, 48.18610463823591, 49.447894028254915, 42.63282639639718, 40.08338642120361, 35.730579716818674, 37.80104214804513, 34.94412006650652, 37.34176622118269, 36.983329500470845, 36.35471555164882, 34.82624735151018, 36.17528527123587, 36.99958481107439, 36.91891622543335, 34.99715914045061, 35.572650636945454, 34.3703030858721, 36.79354640415737, 35.3295053754534, 35.919122559683665, 35.1196072442191, 36.306925841740195, 37.16950300761631, 39.17102888652256, 36.62216213771275, 36.302475520542686, 33.564711570739746, 36.63791717801775, 34.0012321472168, 36.528688022068565, 35.10153497968401, 39.89397157941546, 45.25037261417934, 44.8345924104963, 46.20001070840018, 49.0627623285566, 48.35101318359375, 46.565388679504395, 48.658960819244385, 49.77458095550537, 42.60369954790388, 36.0713541167123, 33.20913403374808, 35.97626107079642, 36.152349267687114, 35.497627462659565, 35.25981494358608, 36.674784319741384, 37.83190952028547, 46.87002897262573, 37.398470469883506, 33.6665096282959, 37.1123297555106, 35.163363524845664, 35.225886889866416, 34.7851105417524, 34.29518263680594, 34.91607018879482, 36.04349531446184, 35.98344898223877, 41.59423746381487, 50.359205859048025, 47.29797894614083, 47.64320019313267, 46.62475061416626, 46.69422565187727, 46.82573768070766, 47.84557342529297, 42.152160440172466, 36.2797966003418, 35.22738075256348, 36.45401573181152, 37.33737843377249, 36.021594592503135, 34.851674284253804, 37.101236956460134, 36.16363661629813, 36.9702912058149, 37.244220461164204, 36.54891422816685, 37.07982955660139, 35.56521953855242, 35.56882912772042, 36.433386530194966, 38.06007099151611, 39.757540225982666, 37.338691643306184, 38.187226499829976, 37.67064183098929, 38.74491671153477, 37.69388702937535, 36.99995306559971, 35.96873269762312, 36.640800680433, 36.93437944139753, 37.557830878666465, 36.102356978825156, 37.67421667916434, 36.86320904323033, 38.66339349746704, 36.89640406199864, 38.75283765792847, 37.998683656964985, 36.7419490814209, 37.886313915252686, 42.71593032564436, 49.50619288853237, 51.412153244018555, 53.25810200827462, 52.937001432691304, 49.99624586105347, 51.48601259504046, 49.933646065848215, 46.76289817265102, 1.6978905775717326, 0.4428293508078371, 2.5712297431060245, 0.909539985869612, 0.1176482013293675, 37.813809462956016, 62.63867037636893, 50.5008761542184, 57.41533429282052, 46.566726207733154, 48.39202492577689, 36.74741036551339, 37.96980694362095, 43.78258303233555, 59.48077665056501, 12.680355599948339, 0.5406594712819371, 0.09227274903761488, 0.028922297326581817, 0.05709793471864291, 0.03202190296724439, 0.09915214417768375, 0.05697116402110883, 0.1744803131691047, 0.08623653543846947, 0.09346950839140586, 0.06303485150315932, 0.2522675134241581, 0.17235364871365683, 0.13715049198695592, 0.1137445079428809, 0.20454124653978006, 0.40284640341997147, 41.37398304258074, 74.94120638711112, 50.72470194952828, 66.64710003989083, 64.09533936636788, 49.26161977222988, 56.802121026175364, 71.120940889631, 56.08789137431553, 63.63955838339669, 52.73405844824654, 65.48080321720668, 16.098646095820836, 0.43759714013763834, 4.29328669820513, 4.107778915337153, 0.13752710606370652, 6.451334646769932, 66.01379258292062, 51.32130207334246, 57.80252265930176, 52.549952030181885, 55.37469352994646, 41.4268935748509, 43.55238921301705, 41.43429340635027, 48.112352984292166, 46.94880417415074, 50.64184468133109, 51.75324726104736, 51.119404792785645, 43.05337653841291, 43.554581369672505, 39.43369511195591, 39.490395886557444, 38.69032818930489, 39.14459793908255, 40.50328343255179, 39.356358187539236, 37.00897530147007, 38.02131393977574, 39.282095840999055, 40.21264723369053, 37.97740132468087, 35.824255330221995, 37.495463848114014, 39.948028564453125, 36.771777697971885, 37.114254406520296, 37.34925637926374, 37.948729583195274, 39.38542945044381, 41.32762813568115, 37.58331339699881, 36.7737648827689, 36.0016428402492, 38.82977506092617, 36.1054037639073, 37.78245224271502, 38.11116804395403, 41.53212056841169, 47.84448255811419, 47.37034790856497, 48.152610846928184, 50.55988025665283, 52.265795026506694, 49.38651016780308, 52.40316091264997, 52.357490403311594, 44.618906429835725, 37.006275926317485, 33.751520838056294, 35.080655642918174, 34.908270835876465, 36.71222816194807, 35.47965594700405, 37.225251879010884, 39.628883906773154, 48.24917343684605, 38.28992782320295, 34.12978424344744, 37.53454399108887, 34.54204865864345, 35.1332882472447, 34.30849538530622, 33.20929036821638, 34.38201427459717, 36.06113679068429, 35.57865388052804, 42.32580981935774, 51.35435812813895, 48.31770004544939, 49.947365283966064, 49.21541772569929, 51.16111135482788, 49.933583532060894, 49.624131611415315, 43.43512446539742, 38.68764965874808, 37.02818707057408, 38.983816623687744, 39.30448293685913, 37.263598987034385, 37.78656905038016, 39.98423215321132, 38.207744530269075, 38.065174443381174, 38.29353046417236, 38.00081327983311, 37.70418773378645, 38.153746604919434, 38.301104000636506, 39.30483382088797, 41.70743751525879, 43.11640017373221, 39.759037562779014, 40.9467522076198, 40.67722463607788, 40.50859533037458, 41.4781608581543, 38.92115429469517, 39.28397880281721, 38.326548303876606, 40.561540603637695, 40.68861968176705, 38.90856763294765, 40.30796957015991, 39.465656825474326, 40.78703049251011, 39.86305209568569, 40.88471869059971, 38.88754933220999, 37.1597512108939, 40.57022932597569, 46.07443591526577, 53.588422843388145, 54.222379956926616, 56.575797353472026, 54.51172726494925, 53.273002420152935, 54.10139792306082, 49.65741695676531, 48.36239085878645, 3.3244394404547553, 0.327182230672666, 4.35522598028183, 1.4062651289360864, 0.13435091078281403, 42.80054548808506, 66.95766367231096, 54.986240591321675, 64.24068178449357, 53.84366839272635, 56.45556572505406, 38.36712578364781, 42.3144599369594, 53.5593307358878, 68.01497800009591, 18.357434238706315, 0.6742580224360738, 0.2905293431665216, 0.19731468574276992, 0.18718726560473442, 0.10039712701525007, 0.18180231670183794, 0.16233630052634648], [0.04536758077197841, 0.011749737995809742, 0.06105135115129607, 0.028835139503436427, 0.0436158985165613, 0.04301134756367121, 0.03799599329275744, 0.007437505459945116, 0.15869748006973947, 0.11382699744509799, 19.695393255778722, 59.83186912536621, 42.03868246078491, 51.19608858653477, 87.06133828844342, 53.115785530635286, 41.965427603040425, 62.34964615958077, 48.98993478502546, 51.08963871002197, 46.05879899433681, 51.75003719329834, 30.97195999962943, 0.14327866743717874, 0.1579120350735528, 2.0569649040699005, 0.21399543780301297, 0.10287394268172127, 34.00999729973929, 56.730269704546245, 51.05382422038487, 52.465305600847515, 42.92665876661028, 37.4718017578125, 40.713782582964214, 44.197352273123606, 46.154055322919575, 49.13096932002476, 49.37597669873919, 47.54412235532488, 48.12126404898507, 40.08219133104597, 35.17518935884748, 33.40460770470755, 33.058441502707346, 35.783240113939556, 38.79392235619681, 37.279840401240754, 38.096069608415874, 35.498089517865864, 35.800211088997976, 35.07979754039219, 35.75519718442644, 32.733585425785606, 32.861817904881065, 34.050599098205566, 32.94886493682861, 33.440359660557334, 33.57514081682478, 35.383079460689, 35.028280121939524, 37.75991923468453, 35.85279853003365, 35.76051255634853, 36.86174297332764, 34.47163561412266, 34.016313212258474, 35.31151301520211, 35.57418966293335, 36.16366440909249, 39.14266286577497, 40.90753657477242, 43.6252931867327, 46.395522594451904, 45.85682528359549, 44.79125649588448, 46.11205346243722, 46.37319803237915, 46.593688692365376, 40.61221729006086, 34.76289367675781, 34.96099724088396, 36.00523158482143, 35.51747151783535, 35.744163445064, 35.91877167565482, 37.72060980115618, 36.68223973682949, 43.496612548828125, 38.29017448425293, 34.85605164936611, 36.47164331163679, 35.397656781332834, 36.62992327553885, 33.62260743549892, 37.064817973545615, 36.01322201320103, 35.72696665355137, 35.31311457497733, 39.38159057072231, 46.10414988654, 46.81482206072126, 45.11952066421509, 45.337190355573384, 45.064574309757774, 44.31522846221924, 43.42546994345528, 46.290236541203086, 38.56997149331229, 31.4279876436506, 30.554380212511333, 32.65655769620623, 32.44150052751814, 34.51081998007638, 34.62657696860177, 35.37581859316145, 35.39419310433524, 36.32136419841221, 35.9884204183306, 35.73644052233015, 34.077891622270855, 34.355496474674766, 34.16122831617083, 34.770491531917024, 35.09480217524937, 35.21211903435843, 35.40495586395264, 35.22326047079903, 33.4197860445295, 34.891463143484934, 33.157415117536274, 35.96671077183315, 34.271742888859336, 34.85756288255964, 34.39543472017561, 35.7617632320949, 38.999519552503315, 41.13752889633179, 41.65846313749041, 40.593825408390586, 36.89865527834211, 36.69981867926461, 36.47614574432373, 37.90243721008301, 36.277427264622276, 41.303566523960654, 47.99368470055716, 51.6034962109157, 49.321249212537495, 54.02378307070051, 46.05069044658116, 48.957385948726106, 23.36798174040658, 0.1022378568138395, 0.14531556170965942, 2.843796283006668, 0.2821639020528112, 0.6597400328942707, 47.70430612564087, 52.86053303309849, 51.8416804586138, 55.29392419542585, 57.76858070918492, 38.27856404440743, 25.302301168441772, 42.59647342136928, 55.119402817317415, 47.548815863473074, 4.652616696698325, 0.25337716245225494, 0.09402971368815218, 0.09454728662967682, 0.06298047370676484, 0.030140959790774753, 0.05059074657037854, 0.023963412436257516, 0.04160468679453645, 0.00243165046725023, 0.08113099368555204, 0.023172194803399698, 0.04912238321932299, 0.02582806907594204, 0.10796378991965737, 0.07904374532933746, 0.1138483238007341, 0.08328992248113666, 25.099304335457937, 68.12881033761161, 46.26742907932827, 56.38160909925188, 75.90836783817836, 51.029338768550325, 49.12021350860596, 65.11091586521694, 52.57291235242571, 56.28954546792166, 50.70328065327236, 55.87557874407087, 32.30849116189139, 0.26462909153529574, 0.9571929574012756, 3.2093397080898285, 0.5057483017444611, 0.11324888560920954, 37.26548889705113, 54.43244137082781, 51.428231375558035, 54.5671044077192, 46.433821065085276, 37.757702759334016, 42.67152786254883, 46.381476811000276, 47.93556301934378, 49.771231923784526, 51.61002056939261, 48.82556472505842, 50.785307611737935, 42.75029958997454, 36.52491167613438, 35.90899903433663, 35.52904026848929, 37.22817359651838, 40.5394036429269, 39.52777372087751, 40.49797848292759, 37.26929650987898, 36.61269521713257, 34.87184143066406, 36.953744070870535, 34.13692004340035, 34.51936626434326, 37.49149642671858, 34.394427231379915, 35.765556948525564, 36.69994027273995, 35.49257264818464, 37.550045422145296, 39.60520792007446, 37.92445257731846, 36.91740846633911, 38.08809307643345, 36.6425655228751, 35.38456637518746, 36.55315957750593, 37.09005730492728, 39.055626256125315, 40.60489041464669, 42.875829219818115, 44.92625652040754, 47.57436786379133, 47.02005100250244, 46.39038092749459, 48.23510333469936, 47.69584321975708, 49.59731156485421, 42.01372800554548, 35.9691287449428, 36.03908320835659, 35.48747961861746, 34.89185919080462, 35.797063555036274, 35.39930697849819, 37.724969795772004, 36.95626974105835, 44.599826676504954, 38.81085164206368, 34.17175136293684, 36.463767528533936, 35.31872871943882, 36.2130834715707, 33.79095881325858, 35.182332106998985, 35.003659180232454, 35.66210869380406, 35.794954776763916, 40.16560445513044, 48.58369445800781, 48.177353382110596, 47.61717571531023, 46.62868676866804, 46.91987534931728, 47.36997965403965, 45.14816461290632, 47.553148065294536, 40.226585320064, 35.14469371523176, 33.47363110951015, 33.61872686658587, 34.450579098292756, 36.16170154299055, 35.028898511614116, 36.626421383449006, 37.84167521340506, 38.09158454622541, 37.45834309714181, 37.31736067363194, 34.923011439187185, 35.207561016082764, 35.952015331813264, 37.157096999032156, 38.06554964610508, 36.89576135362898, 37.88041489464896, 36.7455586705889, 35.90117188862392, 37.15729849679129, 34.89983572278704, 36.101439816611155, 35.95597233091082, 37.09872170857021, 36.705682958875386, 37.13929918834141, 42.91575704302107, 42.12106030327933, 43.39873327527727, 41.129680906023296, 39.552026408059255, 37.705031939915244, 39.51500293186733, 38.292915548597065, 38.25872346333095, 44.46167911802019, 51.460766315460205, 54.113748346056255, 52.42853225980486, 56.27302612577166, 48.97195979527065, 49.580767904009136, 27.09323409625462, 0.019677965070254037, 1.430074325629643, 4.01833301782608, 0.948566660284996, 0.8057272221360887, 50.40628685270037, 58.13541432789394, 54.016292912619456, 58.87508828299386, 60.1840455191476, 44.05632816042219, 28.720229489462717, 42.00103712081909, 60.32885292598179, 54.9029038974217, 6.773824862071446, 0.36087420848863466, 0.09422994937215533, 0.06019042591963496, 0.06554423685052566, 0.058533321267792156, 0.06181133072823286, 0.03504713099183781, 0.13054911978542805, 0.12598249768572195, 0.15958765016070434, 0.16118414806468145, 0.13298689254692622, 0.21965769039733068, 0.20825793567512715, 0.1942642501422337, 0.279839105371918, 0.19494848485503877, 27.484620911734446, 79.5765928540911, 50.836946623665945, 63.42439351763044, 88.18926021030971, 62.257561683654785, 53.3601884160723, 70.61335413796562, 57.98251921789986, 61.539159638541086, 54.93416731698172, 62.51202556065151, 38.00524623053414, 0.253128357231617, 2.514510295220784, 7.604959692273821, 0.6738276683858463, 0.20083977015955107, 37.26462732042585, 54.8036801474435, 53.56920065198626, 57.03431592668806, 46.83801167351859, 40.85984761374337, 45.38240575790405, 47.56752388817923, 49.07162822995867, 53.441232204437256, 52.32398966380528, 51.70954309191023, 53.5075249671936, 44.71974911008562, 38.60050882611956, 38.68542970929827, 37.86676863261631, 40.37601327896118, 43.00872394016811, 41.54670483725411, 42.68535130364554, 38.8312862941197, 38.88275160108294, 38.713434423719136, 39.768935271671836, 36.65223741531372, 36.43341779708862, 39.43460185187203, 37.00406639916556, 38.1758314541408, 38.46027333395821, 38.109535217285156, 39.04617670604161, 40.527907848358154, 39.20638132095337, 38.036026750292095, 41.4308123588562, 38.27166795730591, 38.12284449168614, 38.479012625558035, 39.51983192988804, 41.107477937425884, 42.708398478371755, 44.38201454707554, 46.94642789023263, 50.08903905323574, 48.819412095206125, 48.61937345777239, 50.71297686440604, 50.19039590018136, 52.915246622903005, 43.269121578761506, 35.61353383745466, 37.00977781840733, 35.95195974622454, 34.79955584662301, 36.132783140454976, 36.39791945048741, 38.27584382465908, 36.97847270965576, 45.88023723874773, 38.676292828151155, 35.60372992924282, 36.519307953970774, 36.09953948429653, 36.898022992270334, 32.887192726135254, 36.905919619968955, 36.43556131635393, 35.22657128742763, 36.269023418426514, 42.09610932213919, 50.228451183864046, 50.71165670667376, 48.626314708164756, 50.03919267654419, 50.593033586229595, 50.26857008252825, 47.102703298841206, 50.13036346435547, 43.4073942048209, 36.290427344185964, 34.06372077124459, 36.18800047465733, 35.76190219606672, 37.99039445604597, 36.489399433135986, 39.68366697856358, 38.20289121355329, 39.917928968157085, 38.27981472015381, 39.33275515692574, 39.02824687957764, 37.96010031018938, 38.106505802699495, 39.201833724975586, 39.97326442173549, 39.60001066752842, 40.89090953554426, 39.09381355558123, 37.5595714024135, 40.26629774911063, 37.01085826328823, 39.64700828279768, 38.11162315096174, 40.03382839475359, 38.618574142456055, 39.40969950812203, 44.295624119894846, 44.53296763556344, 45.48734787532261, 44.75625147138323, 41.28829090935843, 40.22577585492815, 41.06141138076782, 41.09803533554077, 40.33629390171596, 47.009024211338584, 53.73161826814924, 57.08671229226248, 54.90799692698887, 58.077824183872764, 51.672488348824636, 49.70879193714687, 31.16007205418178, 0.25477407606584684, 1.0314109006098338, 8.946386728967939, 2.2977232422147478, 1.084073577608381, 56.08364602497646, 64.22754274095807, 60.855192865644185, 66.30944538116455, 66.02536133357457, 49.52784694944109, 34.32329157420567, 50.06982728413173, 64.51024409702846, 67.0988302230835, 9.786593300955635, 0.6463754986013684, 0.21751654600458487, 0.23276885971426964, 0.16633299392248901, 0.24681795441678592, 0.21393303972269806, 0.20030220757637704], [0.014935648201831749, 0.03790484907637749, 0.007019556726195982, 0.011836095147633126, 0.03331984207034111, 0.042980053528611145, 0.027212802985949174, 0.05173163874340909, 0.06842615149383034, 0.05099837987550667, 8.071930749075753, 54.41919115611485, 43.332277229854036, 49.1383934702192, 80.04317828587124, 56.135323251996724, 37.15779529299055, 54.99180957249233, 53.62799630846296, 49.43390383039202, 48.00708082744053, 45.00338847296578, 44.25794751303536, 1.0597738815205437, 0.816673783319337, 1.5590981394052505, 0.9892331638506481, 0.27002211500491413, 10.252434406961713, 54.76696934018816, 49.29046521868025, 52.70201335634504, 39.43971572603498, 41.999324389866416, 43.14364406040737, 48.77187599454607, 47.34739106042044, 49.764790943690706, 50.003739493233816, 50.29597725187029, 45.11725207737514, 38.29205744607108, 33.39970575060163, 34.875186988285606, 36.819654260362896, 44.21591438565935, 43.90130342755999, 44.45202112197876, 42.976022243499756, 40.379907744271414, 36.84720039367676, 34.69379384177071, 35.29080390930176, 35.38468449456351, 33.003463881356375, 32.6501271384103, 33.40183537346976, 33.42171764373779, 33.600810936519075, 35.630035809108186, 36.72752809524536, 35.309897559029714, 34.91051510402134, 35.30750043051583, 34.648425579071045, 36.26361424582345, 34.583564145224436, 33.89813825062343, 34.40755237851824, 35.50592361177717, 37.3150087084089, 41.33526073183332, 45.02364247185843, 45.59053904669625, 44.76138966424124, 44.75228752408709, 44.19731753213065, 47.535593441554475, 46.83479118347168, 44.23704038347517, 37.16220045089722, 35.87258005142212, 36.64746052878243, 36.13563537597656, 36.06905426297869, 36.96749802998134, 37.287653650556294, 37.68993697847639, 44.489704677036826, 38.747897488730295, 36.5468784059797, 36.22134140559605, 35.32518707002912, 35.96786764689854, 36.267369747161865, 35.391354765210835, 35.61378397260393, 36.53495877129691, 35.84009027481079, 38.48963989530291, 43.74403442655291, 45.125402314322336, 43.70262663705008, 46.3443386895316, 44.36546046393258, 43.03518615450178, 41.89837053843907, 42.19453402927944, 42.94645765849522, 35.07638250078474, 32.73886258261544, 32.016632080078125, 32.55857072557722, 32.7076130594526, 32.97447599683489, 36.290333543504985, 36.0824990272522, 35.99019568307059, 36.850851672036306, 35.780888148716514, 33.516112395695274, 34.68016842433384, 33.04833534785679, 33.875045912606375, 33.17055763517107, 34.33591992514474, 33.89321197782244, 35.31889200210571, 33.4215578351702, 35.33487285886492, 33.590298312050955, 35.24038083212716, 34.10728597640991, 35.8705963407244, 35.514080796922954, 39.7334542955671, 42.33781978062221, 45.52518081665039, 46.19197164263044, 46.33360372270857, 42.65849651609148, 38.91918100629534, 34.54753426143101, 35.00366612843105, 35.29340948377337, 39.83061443056379, 45.1578642981393, 48.592417921338765, 49.210901396615164, 53.47841548919678, 46.3215868132455, 47.5972934450422, 7.490487251962934, 0.4241434192018849, 1.7227663227490015, 1.7327036580869128, 0.9478273285286767, 1.5062956299100603, 53.525232451302664, 49.01130049569266, 54.136805943080354, 53.000938756125315, 56.53006431034633, 43.08790213721139, 31.156875882829937, 40.50190074103219, 52.09812804630825, 40.382037367139546, 1.7866104968956538, 0.1892995722591877, 0.02767900064853685, 0.09036601813776152, 0.04161388772938933, 0.03470212986160602, 0.03252245146515114, 0.03352215067882623, 0.05981926726443427, 0.028399799917159334, 0.011624794253813369, 0.02153637070607926, 0.060776374834988794, 0.0790351890027523, 0.06388864533177444, 0.07437325987432684, 0.08697339732732091, 0.06149622585092272, 12.000153013638087, 64.62751579284668, 48.15579659598214, 55.96603386742728, 80.516037940979, 57.53886978966849, 44.10418387821743, 62.14888490949358, 57.930873257773264, 54.728212288447786, 52.96105262211391, 48.80963945388794, 49.35231808253697, 1.0094237604311533, 0.49825282394886017, 3.912178005490984, 2.3673044570854733, 0.33140524263892857, 12.48805638722011, 57.011699540274485, 49.96549660818917, 55.18288503374372, 40.25153282710484, 43.96252747944423, 43.72492340632847, 50.481772082192556, 49.18981013979231, 50.51162501743862, 50.36411476135254, 51.26463603973389, 47.88158246449062, 40.532351221357075, 34.6340844971793, 36.77505724770682, 39.16160365513393, 47.36060306004116, 44.93219723020281, 45.516307967049734, 43.149463176727295, 41.634175709315706, 38.77005876813616, 36.08394772665841, 35.15987205505371, 37.475185530526296, 34.86130101340157, 34.642912183489116, 36.448804582868306, 35.48980726514544, 35.04807901382446, 36.34070450919015, 38.04969733101981, 37.03341906411307, 37.636741570064, 37.221291405814036, 36.14626611982073, 37.73291506086077, 35.417945521218435, 36.74099717821394, 36.21122830254691, 38.36495794568743, 38.67968702316284, 43.42672061920166, 46.10285404750279, 48.55643320083618, 47.53973804201399, 48.060342243739534, 46.78693893977574, 48.61838681357247, 50.01748997824532, 44.72872270856585, 35.946005140032085, 34.264867646353586, 35.765001092638286, 36.11602061135428, 35.439887932368684, 36.25185094560896, 36.487193380083355, 36.772903306143625, 46.44178717476981, 38.6573520387922, 37.134174891880576, 36.89008467538016, 35.503714084625244, 37.36921507971627, 35.864103249141145, 35.92597695759365, 35.76347596304757, 36.543584959847585, 35.55760431289673, 39.18582854952131, 46.4920608656747, 46.645087991442, 46.73797845840454, 49.21347223009382, 45.21517651421683, 45.60752739225115, 44.99086087090628, 45.3547762462071, 44.540582861219136, 37.30012566702706, 34.28478118351528, 35.181512219565256, 34.294011865343364, 35.00034836360386, 34.90216684341431, 36.4411164011274, 38.725145612444194, 37.13212169919695, 38.83542742047991, 37.050077370234895, 35.98199680873326, 35.99455220358712, 34.49301174708775, 35.98297650473458, 35.6748343195234, 36.84099217823574, 35.350134577069966, 35.92974288122994, 36.20671544756208, 36.99276862825666, 36.17059523718697, 35.1801746913365, 36.48320163999285, 37.20136397225516, 37.69602360044207, 40.91740301677159, 44.98642444610596, 49.08852277483259, 49.017008440835134, 49.01866906029837, 45.31308358056204, 40.296498094286235, 35.89331695011684, 37.700317587171284, 37.13334458214896, 39.72402906417847, 46.73302091870989, 51.29432916641235, 50.962917464120046, 55.76738486971174, 48.96029724393572, 49.85337700162615, 10.406625355992999, 0.42527803831866806, 2.427811324596405, 3.7133661593709673, 0.8863091724259513, 1.8206129180533546, 56.41668013163975, 54.22167124067034, 57.939131191798616, 60.375357219151084, 59.444632121494834, 48.238792828151155, 38.527486733027864, 42.03835242135184, 56.86444289343697, 49.35022667476109, 3.197845216308321, 0.3716944807342121, 0.04479874450979488, 0.04731710348278284, 0.03599295113235712, 0.07470143333609615, 0.05679085351792829, 0.010512923023530414, 0.1482368585254465, 0.08540118419166122, 0.13459625547485693, 0.11583322872008596, 0.17236894289297716, 0.1214056975607361, 0.19539247745914118, 0.20932027724172386, 0.17844549539898122, 0.22000434036765779, 13.783708691596985, 72.77527223314557, 55.329804692949565, 58.626328877040315, 82.06939111437116, 63.331475257873535, 49.663277762276785, 65.13356004442487, 63.13283320835659, 57.823023319244385, 58.363832882472444, 55.16770669392177, 55.268167223249165, 1.4645506356443678, 2.361666645322527, 6.3479406748499185, 3.531027840716498, 0.27858642116189003, 12.894760506493704, 59.05850682939802, 52.538393701825825, 58.23615278516497, 41.938218457358225, 47.413114070892334, 46.77514437266758, 52.35417263848441, 52.547728606632774, 52.30454513004848, 53.28826066425869, 53.59480823789324, 48.75323050362723, 42.709864548274446, 35.871041025434224, 39.062511920928955, 40.83929136821202, 50.10682644162859, 46.698012420109336, 48.22555650983538, 46.59567935126168, 44.58395004272461, 40.85685294015067, 38.092355796269004, 37.34514651979719, 40.09989881515503, 37.102696078164236, 35.974072388240266, 38.951351165771484, 36.84715870448521, 37.42085061754499, 38.56027528217861, 40.85013403211321, 38.60221113477434, 38.418730054582866, 38.366139139447895, 35.451310770852224, 38.8466591835022, 38.28416429247175, 39.01687615258353, 37.87863962990897, 39.22383519581386, 40.75243888582502, 45.697572571890696, 47.80219234739031, 51.364089080265586, 49.556251185280935, 50.629813875470845, 49.11508226394653, 52.08728538240705, 52.42095177514212, 46.32684312547956, 36.91005032403128, 35.23403017861502, 35.72574029650007, 37.32262045996529, 35.85167987006051, 37.128661496298655, 38.5046306337629, 37.46268572126116, 47.227479049137656, 39.954615456717356, 36.29531192779541, 37.467733587537495, 35.13309022358486, 37.00140871320452, 36.837928022657124, 35.15729079927717, 35.26361908231463, 39.35314117159162, 35.09888424192156, 40.308365617479595, 46.85297809328352, 48.6537253516061, 48.47103636605399, 51.80993413925171, 48.75879601069859, 47.75838048117501, 46.57590477807181, 46.674850600106375, 47.881988934108186, 39.34675577708653, 36.777284145355225, 35.83984708786011, 35.97673354830061, 36.023595673697336, 35.29725183759417, 37.995466641017366, 40.80430371420724, 39.43957676206316, 40.73092378888811, 39.555955614362446, 38.126005922045024, 38.93643685749599, 38.023492200034006, 39.622953619275776, 37.40657206944057, 40.139024121420725, 38.08145407267979, 40.05976602009365, 39.026263168879915, 40.613867487226216, 38.030221530369346, 37.55701099123274, 37.66354424612862, 40.431265354156494, 39.72871562412807, 43.19405671528408, 45.39772653579712, 49.23485878535679, 50.962709018162315, 51.687340123312815, 47.44966506958008, 42.325292178562705, 36.971083300454275, 39.66206850324358, 38.848406655447825, 43.0721366746085, 50.064074175698416, 54.16304928915841, 54.78112629481724, 58.82107298714774, 52.82436071123396, 52.168329170772004, 12.305587138448443, 0.38967858999967575, 4.226857577051435, 7.811743293489728, 2.1670938517366136, 2.004116037062236, 62.83004461015974, 58.54135240827288, 63.76912144252232, 62.55212361471993, 65.9751536505563, 53.581745624542236, 45.40141255514962, 51.34355020523071, 61.109093938555034, 59.191161836896626, 4.9138372625623425, 0.6115636665906224, 0.11908524350396224, 0.13268394023180008, 0.2329361593084676, 0.27878561190196444, 0.10124986232923609, 0.13778725638985634], [0.0041079807727198514, 0.050188969022461345, 0.0638499620503613, 0.016805639823100398, 0.08387922335948263, 0.03290958283469081, 0.03048248342903597, 0.01551016719479646, 0.07110675158245222, 0.09941578217382942, 1.611291378736496, 48.565583978380474, 46.46787071228027, 33.85651854106358, 56.95985903058733, 53.20471205030169, 40.13921867098127, 53.08122519084385, 54.846369879586355, 50.022357191358296, 51.79588835580008, 44.003045899527415, 50.24445983341762, 5.7819095849990845, 0.8864904769829342, 1.001852069582258, 1.4844563560826438, 0.15166936362428324, 0.12827908088053974, 42.155280181339805, 55.6580445425851, 49.33371080671038, 42.999680859701975, 46.10827364240374, 47.63389308112008, 49.44039344787598, 48.43501343045916, 48.98865284238543, 49.329239640917095, 49.24775811604091, 41.54401935849871, 34.880168846675325, 33.65369367599487, 36.37301710673741, 44.0608549118042, 47.97688743046352, 48.6441924231393, 45.812110151563374, 45.95728233882359, 40.67537294115339, 38.10012040819441, 35.64989028658186, 34.586982658931184, 32.8863137790135, 33.562498569488525, 34.2952938079834, 32.4855694770813, 34.24254308428083, 33.65771320887974, 34.747294970921104, 34.68669973100935, 37.33369241441999, 37.018744468688965, 37.09613003049578, 34.5074223109654, 36.114165442330496, 34.784332343510215, 34.54658930642264, 33.184530462537495, 33.80636644363403, 36.86570692062378, 41.95703417914254, 45.699062960488455, 45.25649397713797, 47.44051776613508, 44.950398036411826, 44.77799585887364, 47.497572898864746, 45.62196574892317, 41.72342879431588, 38.00138650621687, 36.92846999849592, 36.592746938977925, 37.05485078266689, 35.59572907856533, 36.04236970629011, 35.1328261920384, 38.880621978214805, 42.89802176611764, 37.25691829408918, 35.4794613974435, 36.09758356639317, 36.05737086704799, 35.712639468056814, 34.980122157505576, 35.52184540884835, 36.110521112169536, 36.87097365515572, 35.639398506709504, 38.88920995167324, 44.977916376931326, 45.74058539526803, 44.454237597329275, 43.866510323115754, 44.634112562452046, 43.59372404643467, 43.12114231927054, 40.001390729631694, 42.42536013466971, 40.08657217025757, 34.12972518375942, 33.34174040385655, 35.33528627668108, 33.62237467084612, 33.340177059173584, 33.12351485661098, 36.116764068603516, 37.03384985242571, 36.12706477301461, 34.613437925066265, 34.165334701538086, 34.22086817877633, 31.53125524520874, 32.38500125067574, 33.70118113926479, 33.39346974236624, 32.78459562574114, 32.83815928867885, 32.4424489566258, 33.398927552359446, 32.938737937382285, 33.859242234911235, 34.82956511633736, 34.72483491897583, 35.047926153455464, 42.40050295421055, 48.225674629211426, 48.50656597954886, 48.80831582205636, 47.84921775545393, 46.1203739302499, 44.96265465872628, 39.36902822766985, 36.273588384900776, 35.21934168679373, 34.61955581392561, 38.932837690625874, 46.19122471128191, 46.27650690078735, 53.7569340297154, 48.010985715048655, 43.08611645017351, 2.0366340407303403, 0.21501226324055875, 2.8110153334481374, 2.136011302471161, 1.0095515421458652, 3.638458933149065, 53.92998933792114, 46.63162933077131, 53.72343676430838, 52.94619389942714, 53.77346379416329, 39.48971496309553, 24.22726719720023, 33.71863848822457, 53.95054905755179, 36.363112449645996, 0.6104387098125049, 0.16561281042439596, 0.013859829233427132, 0.0613104836749179, 0.043206752078341584, 0.028044086415320635, 0.013693320980694677, 0.03819112300074526, 0.02615405256593866, 0.021880024944299033, 0.032755144871771336, 0.021466296698365892, 0.10789548858468022, 0.015006548325930322, 0.03144494803356273, 0.06521650443651847, 0.04718481290287205, 0.08197457556213651, 3.0420553130762915, 58.30887263161795, 49.801689352308, 38.44738442557198, 68.3907504762922, 58.20880814961025, 45.490884508405415, 56.57792002814156, 57.9131622995649, 53.14525631495884, 56.583711351667134, 48.01139218466622, 55.75518383298601, 6.472522744110652, 1.0349960625171661, 2.0462086583886827, 2.967105963400432, 0.6205409020185471, 0.39241870439478327, 48.02687971932547, 55.86677190235683, 53.155060223170686, 44.654724393572124, 47.92070082255772, 48.734397411346436, 49.784617628370015, 51.2461051940918, 50.69024583271572, 50.88299928392683, 51.832064151763916, 44.308752741132466, 36.9788270677839, 35.848171029772075, 38.168626172201975, 46.536320890699116, 51.18786539350237, 49.82728999001639, 47.91559737069266, 46.655513763427734, 43.76406260899135, 40.2412668636867, 37.89139999662127, 36.03665828704834, 36.067713260650635, 35.00880084718977, 35.71888937268938, 35.06309059688023, 35.51056500843593, 36.350428513118196, 37.890764236450195, 37.19440882546561, 37.55152538844517, 38.43227209363665, 38.60594926561628, 35.57904297964913, 38.020514896937776, 36.35684864861624, 36.070833001817974, 35.542686530521934, 34.6077230317252, 37.57861641475132, 43.68766369138445, 48.35450117928641, 46.73062726429531, 47.48258563450405, 47.45062044688633, 45.82177856990269, 46.70773294993809, 48.86368254252842, 43.06090838568551, 37.029034750802175, 35.475827489580425, 36.86995574406215, 36.19857215881348, 36.59809010369437, 36.40204668045044, 35.76751634052822, 37.862818581717356, 44.420813288007466, 38.99961682728359, 36.5152884210859, 35.71033614022391, 35.54383645738874, 35.1485013280596, 34.52915975025722, 34.98552090781075, 36.25954954964774, 35.27085910524641, 34.618155751909526, 38.1489315032959, 46.058816364833284, 46.10833270209176, 47.00753729684012, 46.60020957674299, 46.47499261583601, 45.54321139199393, 45.760957513536724, 42.179084709712434, 45.20211042676653, 41.11587136132376, 34.95754746028355, 35.30013186591012, 35.75016321454729, 35.45779691423689, 35.56974976403372, 36.222255093710764, 37.78652041299002, 38.36377327782767, 38.97100414548601, 34.56316423416138, 35.49701254708426, 34.60721581322806, 33.87822471346174, 34.732821873256135, 35.86491618837629, 34.74659320286342, 34.42074005944388, 35.200248037065776, 35.0741034916469, 35.03877885001046, 34.484312602451865, 36.19930171966553, 35.97595535005842, 36.15748051234654, 35.99289158412388, 43.668775013514924, 50.799891880580354, 50.364538601466585, 49.44526760918753, 49.026423249925884, 48.38753638948713, 46.05254561560494, 42.71184478487287, 37.70718240737915, 37.3672730582101, 38.416072368621826, 40.96247945513044, 49.508624758039204, 49.3366915839059, 55.466475759233745, 50.009843485695974, 44.61169072559902, 3.1415111763136725, 0.3251828322453158, 5.411637910774775, 2.6681408286094666, 0.6808797099760601, 3.836497357913426, 57.804492473602295, 51.77475888388497, 58.992908886500764, 59.21227046421596, 59.78972830091204, 47.97301033564976, 27.672012090682983, 36.04202924455915, 58.37007236480713, 45.749750069209504, 1.5913482031651904, 0.12247732148638793, 0.06073120475879737, 0.07888149403567825, 0.017669092597705976, 0.041031382379255125, 0.04382252260776503, 0.022728249696748595, 0.1491963341832161, 0.1821285699095045, 0.11450842980827604, 0.09897121281496116, 0.14948426373302937, 0.0582430779135653, 0.17863420955836773, 0.19944755200828823, 0.1906742299241679, 0.23079904541373253, 3.074856238705771, 66.28789901733398, 58.30081272125244, 43.71026618140084, 64.79609298706055, 63.11680371420724, 53.25675753184727, 63.35013117109026, 62.38923004695347, 57.52270827974592, 61.475889342171804, 53.152280943734304, 61.9210604258946, 8.341605969837733, 2.6648942828178406, 5.8883377483912875, 4.42440311397825, 0.5119287243911198, 0.7724984937480518, 48.751014028276714, 58.849782943725586, 55.37256390707833, 46.539287771497456, 49.646008014678955, 50.113656520843506, 53.55289322989327, 54.86143357413155, 52.403678553445, 53.70729957308088, 53.36932182312012, 44.51237317493984, 39.97709287915911, 39.81474127088274, 41.466831820351736, 48.764625549316406, 53.49764115469796, 51.004231452941895, 50.404035636356895, 49.06381498064314, 45.14346068246024, 42.77480241230556, 39.035851682935444, 38.5889504977635, 38.19252102715628, 38.32661083766392, 37.98441900525774, 37.688286781311035, 38.36257471357073, 36.94315154211861, 38.632859638759065, 38.782506465911865, 40.92904124941145, 39.747823170253206, 39.66723448889596, 37.5616489137922, 40.44392497198922, 38.29393693378994, 38.32464449746268, 37.42228194645473, 37.3609675679888, 40.06699562072754, 46.27586071831839, 51.332231589726035, 50.42857319968087, 51.48838540485927, 49.8523382459368, 48.559136050088064, 50.88373579297747, 50.34157827922276, 43.83430889674595, 37.89201143809727, 36.962557860783164, 38.18769550323486, 36.955144132886616, 36.95090920584542, 35.78573104313442, 36.67291872841971, 39.5570638520377, 46.61276497159685, 39.22094474520002, 36.44122062410627, 36.35273878914969, 36.20155988420759, 35.71899706976754, 33.63434641701834, 34.922257559640066, 35.948749678475515, 36.409356185368125, 35.48385613305228, 41.56192486626761, 47.64397839137486, 48.00783470698765, 49.872349057878765, 48.275246552058626, 50.405769211905344, 49.34340354374477, 48.84791360582624, 44.333696774074006, 46.657424518040244, 44.99573850631714, 38.842917578560964, 37.614257199423655, 37.403685092926025, 37.979489258357454, 37.124054840632844, 38.458345208849224, 38.665505749838694, 39.72461271286011, 41.43932042803083, 37.81482737404959, 37.411387171064106, 37.26883792877197, 36.05222920009068, 37.94285140718733, 38.571427140917095, 38.13310350690569, 37.351924487522666, 37.280827045440674, 37.60940040860857, 36.335875511169434, 35.89274024963379, 38.7252949987139, 39.39672374725342, 38.162966864449636, 38.38000079563686, 46.38594797679356, 52.6512393951416, 52.06883791514805, 51.74812296458653, 53.118366786411826, 50.45274945667812, 47.91730315344674, 45.35070807593209, 41.88377932139805, 39.91148451396397, 38.699961866651265, 43.54555565970284, 50.915899004255024, 51.266282762799946, 58.46161488124302, 52.45772164208548, 49.05394853864397, 4.122420506817954, 0.3465976688478674, 7.903634088379996, 8.229578426906041, 2.195874593087605, 5.2510906628199985, 64.38606589181083, 54.46225609098162, 65.27879129137311, 63.41192844935826, 63.33801351274763, 52.67872646876744, 34.31137193952288, 43.22924586704799, 64.65817819322858, 55.84316887174334, 2.630492014544351, 0.4041428395680019, 0.1467979843063014, 0.2083996952112232, 0.2309683806129864, 0.08525823043393237, 0.19073027691670827, 0.18317648582160473], [0.022731752633782368, 0.049507750397814174, 0.08938233235052653, 0.026472256651946476, 0.027018282263140594, 0.04809796836759363, 0.007540675861361835, 0.11487200244196824, 0.03524309190522347, 0.03628573560022882, 0.20504402741789818, 36.89046335220337, 54.29957096917288, 37.286882400512695, 34.140911783490864, 32.2932641846793, 43.54837662833077, 49.23094694955008, 56.21988977704729, 48.915394510541645, 53.2225341796875, 42.89645494733538, 50.25386074611119, 14.875801358904157, 0.6598494670220784, 2.4065869663442885, 2.7680598327091763, 0.4783250646931784, 0.09449022183460848, 26.58615630013602, 57.3714668410165, 47.60856342315674, 48.667983055114746, 47.271103313991, 47.921948024204795, 50.34114749091012, 47.595330578940256, 49.858397075108115, 48.09086568014962, 44.22045155933925, 35.80397353853498, 34.73048727852957, 35.177798407418386, 41.9496864591326, 48.62581443786621, 47.482915673937114, 46.333857331957134, 48.20942279270717, 45.73059388569423, 42.07515355518886, 39.28036226545061, 37.94995246614729, 35.44506434031895, 34.01456574031285, 32.353379998888286, 33.089121273585725, 33.9091546194894, 32.77620915004185, 32.11462599890572, 35.768266745976035, 37.15894521985735, 34.30424656186785, 35.903624602726524, 35.9577545438494, 35.43592051097325, 34.31700692858015, 34.46079642432076, 33.77809074946812, 32.99250309807913, 32.71004145486014, 37.534943512507844, 44.28995091574532, 47.53956086294991, 45.78375455311367, 46.42750515256609, 45.61514261790684, 46.12560592378889, 45.700539452689036, 45.57208810533796, 41.7563910484314, 36.22310972213745, 34.47126388549805, 36.22805336543492, 35.90498992374965, 36.620136737823486, 35.621701444898335, 34.29142018726894, 37.42971651894705, 44.83419288907732, 39.174332754952566, 34.97534874507359, 35.20158209119524, 35.27160951069423, 37.72139842169625, 34.52958706447056, 34.41950328009469, 36.22885240827288, 36.12748861312866, 35.7413945879255, 39.0413407598223, 45.52577836172921, 45.01487037113735, 45.63402782167707, 45.37092385973249, 44.75605692182268, 42.62875822612217, 44.81877136230469, 40.51216670445034, 38.15262794494629, 39.55618143081665, 36.710397311619346, 35.75298418317522, 33.84533888953072, 33.14291770117623, 33.58461815970284, 33.383061340876985, 34.03985023498535, 36.12290975025722, 35.00582354409354, 35.20071356637137, 33.264500754220144, 31.579472269330704, 34.232777391161235, 31.992758069719585, 32.43272842679705, 32.71645811625889, 32.85624892371041, 32.4445229939052, 32.235590662275044, 33.35581745420183, 33.23028782435826, 33.66298689161028, 33.93637071337019, 34.83101034164429, 39.2016669682094, 45.32715368270874, 47.85324771063668, 48.65528522218977, 49.48347922733852, 47.71499592917306, 48.84073264258248, 49.43533515930176, 44.04681607655117, 40.90083851133074, 33.708737305232454, 36.62768248149327, 36.336744035993306, 42.723232882363455, 45.992342948913574, 52.07742936270577, 49.025214263371055, 39.514005865369526, 1.59586800634861, 0.12626795736806734, 2.2717515272753577, 1.013521677681378, 0.5813851973840168, 8.054057376725332, 55.54822826385498, 46.094773292541504, 54.974251474652974, 53.15554312297276, 54.91038015910557, 36.98480946677071, 35.33531059537615, 28.084530115127563, 48.57162543705532, 26.64878041403634, 0.17566750517913274, 0.052442054729908705, 0.006862230324519, 0.03257234075239726, 0.028805630015475408, 0.0181945314564343, 0.0485178322664329, 0.013777495794264334, 0.04023459227755666, 0.015275041240134409, 0.016074759220438342, 0.06046019787234919, 0.06868502617414508, 0.008110456983558834, 0.05180261689903481, 0.07950848074895994, 0.05274495615490845, 0.039103057102433274, 0.42714666947722435, 44.37240171432495, 59.48322936466762, 39.6120171546936, 41.18886913572039, 42.02510915483747, 48.62406349182129, 56.663358552115305, 61.11943980625698, 52.4992093358721, 58.72306169782366, 47.679160594940186, 54.44241203580584, 15.450109924588885, 0.7932670393160411, 2.3807364106178284, 5.222450622490474, 1.8789081956659044, 0.056648344200636656, 30.248659474509104, 59.30213846479143, 49.90796552385603, 50.26229933329991, 48.48082637786865, 49.18604074205671, 50.34544147763933, 49.99344573702131, 51.73798554284232, 50.63398626872471, 46.821151869637625, 38.55760369982038, 36.94695568084717, 35.9436149597168, 43.78760657991682, 50.120712416512625, 51.377304553985596, 48.85583802631923, 49.33504833493914, 48.34615639277867, 43.813954148973735, 41.18876838684082, 38.49769285746983, 38.74955463409424, 35.55648217882429, 34.10794258117676, 33.424146039145334, 36.31503438949585, 35.03401238577706, 35.97132090159825, 37.45279843466622, 36.591468470437185, 36.76211622783116, 37.20665502548218, 37.262254510607036, 37.08353294645037, 36.630743162972585, 35.942239216395784, 35.91278232846941, 35.16836275373186, 35.180146898542134, 39.53814390727452, 45.26900768280029, 48.987440381731304, 47.1502046585083, 47.77200937271118, 46.97692353384835, 47.414580140795024, 47.47581808907645, 46.6217941556658, 42.01319646835327, 36.21612678255354, 34.711480481284006, 35.600561550685335, 35.43259579794747, 36.87604931422642, 36.217565059661865, 35.325378145490376, 37.70171070098877, 44.970429692949565, 39.752728598458425, 34.679358959198, 35.65247849055699, 34.2748452595302, 36.97357075554984, 35.91054153442383, 35.55644743783133, 36.465455940791536, 36.104757581438335, 36.93987199238369, 39.86837094170706, 45.89224720001221, 46.604680742536274, 46.6971195765904, 46.61911562510899, 46.950054849897114, 46.82503938674927, 46.05956677028111, 42.87705557686942, 41.435797691345215, 42.98429754802159, 38.64987230300903, 36.48364979880196, 35.27522604806082, 35.139899458204, 36.04947771344866, 36.00506135395595, 36.899634974343435, 37.68655320576259, 38.09693118504116, 35.85779428482056, 36.37984718595232, 34.1029120853969, 37.11672101702009, 34.4407890864781, 34.52076980045864, 35.092019421713694, 35.529252188546316, 35.92694970539638, 34.77400384630476, 36.284639494759695, 34.73747369221279, 35.12204953602382, 36.1894839150565, 37.5488155909947, 41.80890553338187, 46.547535283224924, 49.54818432671683, 50.958936146327424, 51.85012251990182, 50.77336365836007, 51.291192054748535, 51.57656846727644, 45.88466671534947, 42.302258900233674, 35.43512841633388, 38.65555245535714, 37.98211915152413, 44.90359844480242, 47.2886266708374, 54.304445130484446, 50.4546080998012, 43.96352802004133, 2.060687835727419, 0.08420632473592247, 6.593206873961857, 3.869541253362383, 0.5513105711766652, 9.965315733637128, 61.13587229592459, 49.83826814379011, 61.158231598990305, 56.898155553000315, 59.43992124285017, 41.88765294211251, 33.64634943008423, 32.39394358226231, 55.64006607873099, 32.95904752186367, 0.19026181633983338, 0.09320067960236754, 0.04686993194211807, 0.03683530146788273, 0.015472116647288203, 0.04359121001990778, 0.005469743303755032, 0.02485908374988607, 0.13151843420096807, 0.0840336172176259, 0.20311341887073858, 0.11425049150628702, 0.14110559118645533, 0.19396405267928327, 0.12565636661435875, 0.2067370130015271, 0.1537965844784464, 0.1436923159552472, 0.542160553591592, 50.4901898247855, 66.97844573429653, 49.308582646506174, 43.68468986238752, 46.32631853648594, 55.39166103090559, 61.175629888262065, 66.6713423047747, 57.80968625204903, 64.8667631149292, 52.53998483930315, 59.99533939361572, 19.062247344425746, 1.0931556331259864, 8.22515502997807, 7.4415693283081055, 1.3883288971015384, 0.1389686537108251, 32.690683773585725, 61.25496441977364, 53.18366943086897, 52.927200998578755, 51.394796643938335, 50.743184157780235, 53.3981533731733, 51.42822095326015, 51.41805573872158, 51.349056652614046, 48.32863998413086, 39.69298103877476, 40.74690464564732, 39.27149288994925, 44.98025097165789, 53.88768523080008, 51.53645304271153, 47.659521511622835, 51.184808186122346, 49.37273188999721, 45.791571276528494, 43.932111740112305, 42.59608084814889, 41.11647932870047, 38.45015328271048, 36.597909450531006, 36.44044937406267, 38.16621514729091, 37.1584449495588, 36.82815538133894, 40.544055461883545, 40.98389032908848, 38.976965699877056, 40.108486788613455, 39.02816002709525, 38.61014250346592, 38.963586943490164, 38.80516801561628, 38.43052462169102, 37.857030732291086, 37.448316846575054, 42.4319748197283, 48.298238141196116, 53.32217134748186, 51.043231691632954, 50.53789963041033, 48.940588678632466, 49.53476735523769, 49.30889531544277, 48.677258900233674, 43.56814425332205, 37.11298288617815, 34.09674208504813, 37.18782888139997, 36.57496302468436, 37.49572787966047, 36.0522153036935, 35.67485169001988, 38.58515330723354, 47.50621993201119, 39.951158727918354, 35.19105904442923, 37.55500643593924, 35.088048526218955, 38.06573724746704, 37.07749843597412, 34.8100128855024, 36.934921400887625, 35.03700705936977, 36.58726481028965, 40.39684745243618, 47.55019160679409, 49.11368915012905, 50.17289686203003, 51.051566055842805, 50.118544578552246, 47.94166006360735, 48.65105029514858, 46.1406626701355, 43.33887801851545, 44.47034699576241, 40.15936497279576, 40.976657254355295, 39.10384675434658, 37.088202135903494, 36.416585786002024, 36.74676765714373, 38.43632984161377, 39.595185143607004, 39.159661633627756, 39.021427222660606, 38.20796339852469, 35.82339027949742, 39.04080574853079, 36.9852819442749, 37.68301657267979, 38.10328531265259, 38.35031114305769, 37.85631159373692, 37.220030307769775, 37.75048358099801, 37.99546316691807, 37.019199575696675, 38.44185018539429, 40.13171461650303, 43.68061474391392, 48.96519224984305, 52.9283960887364, 54.36737149102347, 53.857067993709016, 52.472441400800435, 53.89792340142386, 53.207272461482454, 47.835852895464214, 45.09087324142456, 37.037480286189485, 40.5629232951573, 41.021719796316965, 46.73720373426165, 48.86857754843575, 57.01596226011004, 52.15963002613613, 46.68380682809012, 3.2001541895525794, 0.14224303300891603, 8.356862476893834, 6.695950755051204, 1.5172612986394336, 11.725334388869149, 64.84175654820034, 54.143486636025564, 65.64231409345354, 61.124657903398784, 64.85278333936418, 49.2925705228533, 46.94572959627424, 39.90929583140782, 61.91052000863211, 42.2255403654916, 0.5844895222357341, 0.18039746422852787, 0.12544447369873524, 0.20308155486626284, 0.0780412166246346, 0.11311959754675627, 0.10277740071926798, 0.15543595222490175], [0.026005855428853204, 0.005761195298483861, 0.05267985411254423, 0.023203127518562332, 0.02632668035637055, 0.07525352335401944, 0.06016743036785296, 0.1402970759996346, 0.07108704692551068, 0.11393470130860806, 0.07876246542270694, 14.267774053982325, 56.239872796194895, 39.236074447631836, 42.04133667264666, 39.1104336466108, 33.63674007143293, 42.06939002445766, 57.61974334716797, 50.375224930899485, 52.37405490875244, 43.492169175829204, 51.39988272530692, 27.94837668963841, 0.31655135112149374, 0.8676898458174297, 2.759289686168943, 2.848905380283083, 0.02373211850811328, 8.437491978917803, 53.88324185780117, 54.2652816091265, 51.22232845851353, 49.001444475991384, 51.10036325454712, 49.33872740609305, 52.30198471886771, 48.35102013179234, 47.45463650567191, 40.03588506153652, 36.163907596043174, 33.26641150883266, 40.380508763449534, 45.453649112156455, 46.70205627168928, 47.96380744661604, 43.25274467468262, 48.86941133226667, 47.32051542827061, 42.908603872571675, 38.84034674508231, 36.935657909938264, 35.64476946422032, 36.68931300299508, 33.730297565460205, 33.43558972222464, 34.24735123770577, 34.90484537397112, 34.57384361539568, 33.960463591984336, 35.79324204581124, 34.89797707966396, 35.679121358054026, 35.70785910742623, 37.43096719469343, 35.038400173187256, 35.90878364018032, 34.84869350705828, 34.29864631380354, 32.84763663155692, 38.59289012636457, 45.05839736121041, 46.79338339396885, 44.28744261605399, 45.86733790806362, 44.64029993329729, 44.536379201071604, 43.93578733716692, 45.05192858832223, 43.45608718054635, 38.396502767290386, 35.999944005693706, 35.776069572993684, 35.519243308476035, 37.2587491444179, 34.383546352386475, 35.218949113573345, 39.42072629928589, 41.79309490748814, 37.31814929417202, 34.83997351782662, 33.542501653943745, 34.87212283270699, 36.37911415100098, 35.78139189311436, 35.687549522944856, 35.235398973737446, 36.01003279004778, 35.40151303155081, 39.453994274139404, 45.83189167295183, 46.804893084934776, 44.69469390596662, 45.74304853166853, 45.126309054238455, 43.106905460357666, 43.51581389563424, 43.69609880447388, 38.58376714161464, 38.93011747087751, 37.72907618113926, 34.823461123875205, 34.25955922263009, 33.763937268938335, 33.18897383553641, 35.06124932425362, 33.4389248575483, 34.78867496762957, 34.37534747804914, 33.65019178390503, 33.618435042245046, 31.854443754468644, 32.74674183981759, 32.87398420061384, 32.537944998059956, 31.639216354915074, 33.13107797077724, 33.16299452100481, 32.486646447862896, 32.73887995311192, 31.743272577013286, 32.56681476320539, 31.806421279907227, 34.91916561126709, 43.224163259778706, 46.98386478424072, 49.67399883270264, 48.03471728733608, 48.021258626665386, 46.945510728018625, 45.42547764096941, 50.614830085209434, 47.59970446995327, 45.9426702771868, 36.99391508102417, 34.39069952283587, 35.127194677080425, 39.75980533872332, 46.41375814165388, 51.047126156943186, 48.77514164788382, 38.44874974659511, 1.0118865711348397, 0.13170361997825758, 5.04984347309385, 1.3520777566092355, 0.5160651824304036, 17.086638246263774, 55.86557681219918, 45.51908377238682, 54.79740939821516, 50.28811189106533, 50.41789729254586, 30.301382405417307, 24.979138714926584, 29.003665617534093, 52.95412526811872, 20.286711011614116, 0.10988457327974693, 0.04095347298841391, 0.0452104015275836, 0.02462285178314362, 0.026433846480878334, 0.02508567034133843, 0.036751889158040285, 0.02127658000348934, 0.007001421181485057, 0.04407633202416556, 0.0696536891960672, 0.029023266730031798, 0.024417211567716937, 0.0528070828212159, 0.05500408760937197, 0.08390375240040676, 0.0664016811975411, 0.145792707534773, 0.003935417443114732, 19.97495228903634, 63.19024617331368, 39.93850258418492, 40.68495103291103, 44.78633369718279, 42.075025013514924, 47.98317902428763, 61.70552730560303, 53.43225860595703, 57.575406891959055, 48.25231402260916, 55.18550797871181, 28.831261702946254, 0.23255427979997226, 1.4318782516888209, 4.025181770324707, 5.184220765318189, 0.05654222810907023, 11.212635500090462, 58.95017051696777, 55.15398052760533, 53.29388175691877, 50.89125026975359, 52.31948375701904, 48.83632401057652, 54.34877463749477, 49.60562855856759, 50.97528525761196, 41.33528505052839, 38.40167570114136, 35.767394747052876, 41.04619482585362, 46.04972117287772, 48.49290929521833, 50.35451929909842, 44.26179681505476, 50.28318561826433, 49.47330011640276, 45.26873670305525, 40.54790823800223, 39.30821759360177, 36.63084391185215, 37.904184682028635, 36.3021593775068, 35.29256527764456, 35.84934180123465, 37.32093552180699, 34.67554439817156, 36.1379109110151, 37.05375991548811, 37.83744376046317, 37.18893711907523, 36.880221707480295, 37.830856868198936, 36.120356287275044, 37.43143619809832, 35.65853384562901, 35.97245693206787, 36.0061730657305, 40.28111825670515, 47.33171592439924, 48.08600194113595, 46.64228786740984, 46.38843543188912, 46.74568748474121, 47.30677536555699, 46.918798378535676, 45.90967328207833, 43.155827726636616, 39.54132618222918, 35.46612433024815, 36.11398826326643, 35.3796192577907, 36.69661208561489, 34.43807928902762, 35.65879092897688, 40.12129579271589, 42.59828690120152, 38.42799200330462, 35.02033485685076, 33.42190177100045, 35.93055582046509, 36.78989512579781, 36.254918575286865, 35.02244710922241, 35.05202211652483, 36.591562271118164, 34.72425127029419, 40.76776313781738, 47.389372076307026, 48.585806710379465, 47.59538616452898, 48.46970926012312, 46.32439388547625, 46.16438382012503, 46.16720478875296, 47.22571768079485, 40.6098757471357, 41.46265942709786, 39.91874190739223, 37.41588265555245, 36.2802551814488, 35.19942467553275, 34.867196559906006, 37.079655851636616, 35.26147903714861, 36.163379532950266, 35.59576729365757, 36.3797151701791, 34.96114662715367, 34.83751732962472, 34.386805057525635, 36.8450151852199, 35.457067353384836, 34.15118816920689, 34.611065115247456, 35.2759382384164, 36.283454826899934, 35.3893050466265, 33.53017554964338, 34.58387681416103, 34.893582344055176, 37.85193770272391, 44.31997755595616, 48.14047581808907, 50.302807331085205, 51.10374355316162, 49.19968005589077, 49.45501593181065, 47.43809284482683, 52.77674470629011, 49.85393980571202, 48.538746561322895, 38.239824363163535, 37.85972663334438, 36.40382194519043, 42.586474963596885, 47.85003069468907, 53.87306274686541, 51.017137731824604, 41.26115819386074, 1.2424035902534212, 0.19250007266444819, 5.842506561960493, 2.2044892736843655, 0.45224212429353167, 18.88793788637434, 62.38524872916085, 49.734934534345356, 59.295350074768066, 56.16326195853097, 55.87203516278948, 41.50756910869053, 30.026063510349818, 31.61647837502616, 59.3697235924857, 24.641225235802786, 0.0966166148760489, 0.05429472674482635, 0.012195446445340557, 0.029654660528259616, 0.07069209204720599, 0.03536192713571446, 0.10164513611899954, 0.026667501710887467, 0.08365029242954083, 0.17362466693988868, 0.15622860326298646, 0.1864172097827707, 0.16708285654229776, 0.12009621996964727, 0.1698386993791376, 0.1945721964750971, 0.1737315362053258, 0.22350483467536314, 0.22067248022982053, 21.136289834976196, 72.95515414646694, 48.57348755427769, 51.34625652858189, 50.46605178288051, 47.13365057536534, 51.41031544549124, 67.65993894849504, 58.44423048836844, 62.96153232029506, 51.38672978537423, 60.9756954738072, 34.42698648997715, 0.46288486463682993, 3.9615779604230608, 9.397096395492554, 9.144057767731802, 0.16740231082907744, 12.560958623886108, 60.404643876211985, 55.83715867996216, 57.84547642299107, 51.53138780593872, 55.10889714104788, 51.38969666617257, 57.14097772325788, 52.656756264822825, 52.20383446557181, 43.181233814784456, 40.32869604655674, 36.96356882367815, 43.22067526408604, 48.33810690471104, 50.134278774261475, 50.63345125743321, 44.2582289150783, 50.81606033870152, 52.14272853306362, 47.55596208572388, 42.96739258084978, 39.189313071114675, 40.09845706394741, 41.600261551993235, 37.284283774239675, 36.716529096875874, 39.4938074520656, 39.95205504553658, 37.48659447261265, 37.033339159829275, 38.54345369338989, 38.61252573558262, 38.221140657152446, 38.83627162660871, 40.86268942696707, 37.72083214351109, 41.67880398886544, 38.2854323387146, 39.02819129398891, 37.128609384809224, 42.172508239746094, 49.72822952270508, 50.98349802834647, 49.305726936885286, 49.73959330150059, 48.13219356536865, 49.793886525290354, 46.51651505061558, 48.69725234167916, 45.41087600163051, 38.559997354234966, 35.82347713197981, 36.41090563365391, 36.17541033881051, 37.626322746276855, 34.43929522378104, 37.561701025281636, 41.35626861027309, 46.01495933532715, 39.13848352432251, 35.961749758039204, 33.912673882075715, 36.325560910361155, 38.52481515066964, 35.44955287660871, 35.36875227519444, 35.57294593538557, 37.62857396262032, 35.11708157403128, 40.814927509852815, 48.803188051496235, 51.0488076210022, 49.86740888868059, 50.932894298008506, 48.995072977883474, 48.6446510042463, 48.34653506960188, 48.70805679048811, 43.28869465419224, 43.767932755606516, 42.8022130557469, 39.276700564793174, 38.80199268886021, 36.86655460085188, 36.69494104385376, 39.2076632635934, 37.369673660823274, 38.32954297746931, 37.35157012939453, 37.94318839481899, 38.44803408214024, 36.08144637516567, 36.76087597438267, 38.32557903017317, 36.68331323351179, 35.03171253204346, 37.65039478029524, 37.684117862156455, 37.74262864249093, 38.078963143484934, 35.56396886280605, 35.54647329875401, 36.466202872140066, 39.4304016658238, 48.43012537275042, 50.625679697309224, 52.582382747105186, 51.83400617327009, 51.62139129638672, 51.729943002973286, 48.061210768563406, 53.6874555179051, 51.8605899810791, 50.790768895830425, 40.28457498550415, 39.99157639912197, 39.119563579559326, 43.97172689437866, 51.47021239144461, 55.29994828360421, 52.80608000074114, 45.303387369428364, 2.573264479637146, 0.36022558329360826, 12.79486972945077, 7.380321826253619, 0.9014098335589681, 21.519194637026104, 67.43430314745221, 53.437372480119976, 64.49839741843087, 60.01392582484654, 60.773120743887766, 42.25242294584002, 35.50738273348127, 39.57921123504639, 64.26094273158482, 32.123238291059224, 0.20137790271214076, 0.08441700307386261, 0.11466637918991701, 0.10880655076886926, 0.12479428787316595, 0.1833017433860472, 0.17326588476342814, 0.1270630918443203], [0.03412662360018917, 0.0188269905546414, 0.04508494718798569, 0.06739751954696008, 0.019271361442016702, 0.07025035896471568, 0.005603698414883443, 0.03399327789832439, 0.051297878447387896, 0.03371355862223676, 0.02859800847779427, 1.9742374803338731, 50.94347987856184, 47.80971724646432, 39.12279796600342, 29.395604814801896, 30.755481924329484, 47.28535059520176, 58.08430337905884, 49.16194438934326, 53.79102884020124, 46.246855463300435, 49.505400793892996, 35.25532988139561, 0.15102922011698994, 1.6344743690320422, 3.123325135026659, 3.1824527851172855, 3.9019559025764465, 0.5142388375742095, 31.979125704084122, 56.73557118007115, 47.29876061848232, 51.44790172576904, 49.354579721178325, 50.929875305720735, 48.59636102403913, 46.07992499215262, 41.4840737751552, 38.38578517096383, 35.52023342677525, 36.152950286865234, 45.76852757590157, 45.82795204435076, 49.07373006003243, 44.739492416381836, 45.74460145405361, 49.86317048754011, 44.95434808731079, 42.67776039668492, 38.08425072261265, 36.45542969022478, 35.04618215560913, 34.6621413230896, 32.90561587469918, 33.90340845925467, 33.39228160040719, 32.834473269326345, 31.43314320700509, 34.54579026358468, 35.694032192230225, 35.065779549734934, 33.978608812604634, 35.174762044634136, 36.336014475141255, 33.92247779028756, 34.4777569770813, 33.15702601841518, 33.12614474977766, 34.296627862112864, 36.002792767116, 44.64942291804722, 44.49603796005249, 47.12599713461739, 46.24192919049944, 44.30080052784511, 45.056893076215474, 43.02409682955061, 44.63862541743687, 43.57109376362392, 38.76174872262137, 38.10239594323294, 36.67586129052298, 35.96514047895159, 34.52266665867397, 33.28264944893973, 35.27754327229091, 39.26034450531006, 38.87499393735613, 37.520050048828125, 34.88512986046927, 34.26292562484741, 34.71094199589321, 35.12281036376953, 33.65185587746756, 36.27221264157976, 35.119864327566965, 36.957569054194856, 35.94400405883789, 39.364762033735005, 45.98751047679356, 45.43616049630301, 45.37170900617327, 44.651451792035786, 44.18886852264404, 44.2919728415353, 43.431903975350515, 45.070167609623496, 41.562074252537315, 36.87271417890276, 33.85648727416992, 32.70586558750698, 32.952314717429026, 32.49321596963065, 34.6228666305542, 35.342012132917134, 34.86010939734322, 36.27808386938912, 35.17953545706612, 32.95627171652657, 33.70711490086147, 33.271240506853374, 32.86469793319702, 32.21461057662964, 32.67485230309622, 32.98867116655622, 33.61838640485491, 32.732042925698416, 33.44492810113089, 33.70313010896955, 34.08002471923828, 33.65073721749442, 33.998897552490234, 38.89312873567854, 43.82549858093262, 45.41331829343523, 48.60517133985247, 47.95481300354004, 49.81886182512556, 47.04271602630615, 47.6880647114345, 50.656748567308696, 49.97326816831316, 45.50210932322911, 44.8876245362418, 34.922872475215364, 34.48321826117379, 37.78170878546578, 44.94431836264474, 48.29101201466152, 53.59264039993286, 42.360964230128694, 7.14978928225381, 0.061633167788386345, 5.543398337704795, 2.736177806343351, 0.11358464509248734, 30.81778642109462, 54.0431581224714, 44.68115186691284, 54.77204499925886, 51.36173711504255, 46.14369903291975, 23.288902555193218, 25.625427143914358, 30.360157217298234, 46.985313483646934, 8.62345096043178, 0.27587694940822466, 0.03673339229343193, 0.06355326582810708, 0.03770864728306021, 0.06094127241522074, 0.05926728581211396, 0.1031692275511367, 0.04247062300731029, 0.04466304089874029, 0.0026411562118612763, 0.016344308952933977, 0.02882186057312148, 0.01912409729058189, 0.1078046327456832, 0.029782469384372234, 0.07739769401294844, 0.041770015244505236, 0.0738122606916087, 0.04260262181716306, 3.1755386761256625, 62.31837231772286, 51.59246594565255, 41.172075339726035, 34.57087326049805, 36.43901457105364, 49.498070444379536, 61.340864998953684, 53.13821431568691, 57.37743534360613, 50.87483862468174, 54.32197890962873, 37.060186999184744, 0.1675974710711411, 2.878050684928894, 3.0996096304484775, 5.601285951478141, 4.685710532324655, 0.8298867057476724, 36.08835635866438, 58.16366917746407, 49.52788863863264, 53.52848073414394, 50.91272367749895, 53.07685477393014, 50.907957213265554, 48.98007876532418, 43.650424821036204, 40.149644442967, 38.15174552372524, 37.0517657824925, 46.80881534303938, 48.60980231421334, 50.91536399296352, 44.038811751774375, 46.75040878568377, 52.55258887154715, 49.44758830751692, 45.25724785668509, 38.97073663984026, 37.6162930216108, 37.82914413724627, 37.00752660206386, 33.926250662122456, 36.48280559267317, 34.35191815240042, 34.342333112444194, 34.47930989946638, 36.161979470934185, 38.48456423623221, 35.87440742765154, 35.24900007247925, 35.509192739214214, 37.22037424360003, 35.669439043317524, 36.34895202091762, 35.58725227628435, 34.78537457329886, 36.0697386605399, 40.08215659005301, 48.94451093673706, 46.44861377988543, 48.76756463732038, 48.85296842030117, 47.344597884586875, 46.75433104378836, 44.85716015951974, 46.14994893755232, 43.10215636662075, 39.26588569368635, 37.85091284343174, 36.560719217572895, 35.8244047164917, 33.85855783735003, 34.57362822123936, 36.28200265339443, 40.917024339948384, 39.9757136617388, 38.22682428359985, 36.87148782185146, 35.42220476695469, 35.14922046661377, 36.069068159375874, 34.74398415429251, 37.291402203696116, 34.91667815617153, 36.388306617736816, 35.95839030402047, 40.76783956800188, 46.99987343379429, 46.354764461517334, 48.412834780556814, 46.642760344914024, 45.206866468702046, 45.95599692208426, 46.528017793382915, 48.06264904567173, 42.266072681971956, 38.059317111968994, 37.11580038070679, 34.673789978027344, 35.44465787070138, 34.69714634759085, 35.627110617501394, 36.19458736692156, 36.771041188921245, 37.904028347560335, 36.641109875270296, 35.528592109680176, 35.227755955287385, 36.116489614759175, 36.13943256650652, 33.766588006700786, 34.21384702410017, 34.91525377546038, 34.522798674447195, 35.169418879917686, 34.99021789005825, 36.93588720049177, 36.13004902430943, 35.854552950177876, 36.20946346010481, 40.710405758449006, 45.8037097794669, 49.06436736243111, 48.727494376046316, 49.159290177481516, 50.81516054698399, 49.25288241250174, 49.209049701690674, 50.95992626462664, 51.4367915562221, 48.47862032481602, 47.10992595127651, 37.58572442190987, 36.95917756216866, 39.24697617122105, 46.99868181773594, 51.96695647920881, 53.713038785117014, 45.280896050589426, 8.926396761621747, 0.09976237786135503, 4.026188824857984, 1.354405403137207, 0.15536105552954332, 34.40468972069876, 60.25998932974679, 51.06134911945888, 59.96832479749407, 57.32736662455967, 51.823340688432964, 32.09221111025129, 26.55819501195635, 33.64861454282488, 56.108225277491975, 12.921129788671221, 0.2451264208980969, 0.08639683255127498, 0.026584973192906806, 0.07648671325296164, 0.06274836723293577, 0.02641914432336177, 0.07271610093968255, 0.05497763492166996, 0.09383312173719917, 0.16698250121303967, 0.09907333233526774, 0.292417081871203, 0.1188111017857279, 0.22907847059624536, 0.11243042309901544, 0.11983631391610418, 0.14438899500029428, 0.14458429094936165, 0.19969057611056737, 3.0349240728787015, 71.81653199877057, 58.946286473955425, 48.6896927016122, 37.85611009597778, 44.72072533198765, 57.47227478027344, 65.57283210754395, 58.850338799612864, 64.88851792471749, 54.11438758032662, 56.601231234414236, 43.19198267800467, 0.26201396329062326, 5.513865453856332, 8.81953867844173, 7.136328450271061, 6.141931363514491, 1.202594212123326, 38.8901549066816, 58.30660057067871, 50.64759431566511, 55.08243145261492, 52.27827399117606, 54.652560302189414, 53.696265833718435, 50.02421236038208, 44.57718249729702, 43.005673680986675, 39.458437647138325, 39.51489870888846, 50.689248766217915, 50.56884690693447, 52.15060779026577, 45.53449140276228, 47.062459332602366, 53.468938146318706, 49.97320910862514, 46.2906881741115, 42.00388240814209, 40.96462992259434, 39.047152927943635, 38.27324172428676, 37.60511337007795, 39.73305130004883, 38.219372340611045, 35.63943672180176, 36.501127992357524, 37.319031715393066, 40.21080248696463, 37.62756994792393, 37.084113121032715, 37.109401089804514, 39.58104903357369, 36.09671156747, 37.67775331224714, 36.4506528036935, 36.97638825007847, 38.205465521131245, 41.60040051596505, 49.072979654584614, 48.44636678695679, 51.022248131888254, 50.101597922188894, 49.3720509665353, 48.35689830780029, 46.77817726135254, 48.24243368421282, 45.49832602909633, 39.39078998565674, 38.2485408782959, 36.474367005484446, 37.091815199170796, 34.238419328417095, 33.99329035622733, 37.88731792994908, 42.044796875544954, 42.41531998770577, 40.278884410858154, 37.2959497996739, 36.836420263562886, 36.34403617041451, 36.62514986310686, 35.0168433870588, 37.582288537706646, 35.79472896030971, 36.439824036189485, 35.32908500943865, 41.68133660725185, 49.70086056845528, 49.99648904800415, 50.064098494393484, 49.28740453720093, 48.35743679319109, 50.217295851026265, 49.2528372492109, 51.93827084132603, 45.376454625810894, 41.321513720921104, 38.03368868146624, 37.593694005693706, 36.79983799798148, 35.19529744556972, 39.02763543810163, 38.1327144077846, 38.92930800574166, 41.01029348373413, 39.37937756947109, 36.73457704271589, 38.37618623461042, 38.48933070046561, 39.27234751837594, 36.14660658155169, 36.69791487285069, 37.91413450241089, 36.701111044202534, 38.531329086848665, 36.91720002038138, 38.54656648635864, 40.27128308159964, 38.20378405707223, 38.88581575666155, 43.4770325251988, 48.81648342950003, 50.32001107079642, 51.39978197642735, 52.303871154785156, 53.69819048472813, 51.09730952126639, 51.46588713782174, 54.11570078986031, 51.83790758677891, 50.919730935777935, 49.29286929539272, 40.073269844055176, 37.598762716565815, 41.70687123707363, 48.619394302368164, 54.12091888700213, 56.58080005645752, 46.19578272955758, 12.641645448548452, 0.13015048046197208, 16.09780362674168, 7.2259528296334405, 0.34955556584256037, 39.33669825962612, 64.01770714351109, 54.7647111756461, 64.72009359087262, 62.07192666190011, 57.166137150355745, 34.46214784894671, 37.30406182152884, 41.97289344242641, 63.76231220790318, 16.771071910858154, 0.5161062202283314, 0.2464977673121861, 0.16768941256616796, 0.1446228860212224, 0.17756281633462223, 0.13176323606499604, 0.1340808267039912, 0.10234799661806651], [0.03065519773268274, 0.04876981981630836, 0.024706954502367547, 0.016232045334098593, 0.09260569938591548, 0.015148268846262778, 0.059157688835901875, 0.02768516174650618, 0.04228925398950066, 0.050711267960390875, 0.08119900325047118, 0.1195783620434148, 22.78827789851597, 52.69227198192051, 35.5959027835301, 43.99499988555908, 28.14231480870928, 41.62590735299246, 55.4624388558524, 49.70145116533552, 48.779699666159495, 49.71664687565395, 47.39079645701817, 46.27759081976754, 2.2511403475488936, 1.7091615327766962, 1.1244545536381858, 4.652411724839892, 8.32261220046452, 0.4864426776766777, 15.777689695358276, 57.16870450973511, 45.763316426958355, 52.35749735151018, 49.014764172690256, 50.09722055707659, 46.158425739833284, 45.53358466284615, 38.57138545172555, 40.41741759436471, 39.60790729522705, 43.2104093006679, 46.68745115825108, 46.71608468464443, 47.183205127716064, 44.339363030024934, 48.822094099862234, 47.55433620725359, 45.7255460194179, 39.491761207580566, 35.30246993473598, 36.66412925720215, 33.65704618181501, 33.42963511603219, 32.54787744794573, 33.63640308380127, 34.51566287449428, 34.54925046648298, 32.79052243913923, 34.172116143362864, 37.82445410319737, 35.95089667184012, 36.2690338407244, 34.54344177246094, 36.00575269971575, 37.118861062186106, 34.64379113061087, 33.27839020320347, 32.278106689453125, 34.59176996776036, 36.241223675864084, 44.83557210649763, 43.44648824419294, 45.84280034473964, 45.00148466655186, 45.675251483917236, 44.11794478552682, 45.86041055406843, 42.878855160304475, 39.52921199798584, 37.04672833851406, 35.896183082035606, 35.276900563921245, 34.564741475241526, 35.16198778152466, 34.86869042260306, 35.939428670065745, 37.024094581604004, 37.20170790808541, 38.08738783427647, 35.33615132740566, 33.120499338422505, 33.74290854590279, 34.89287710189819, 33.28910779953003, 36.121360301971436, 34.65742349624634, 35.81761285236904, 37.07506309236799, 38.672526904514854, 44.04169525418963, 45.94425099236624, 45.92172493253435, 46.34469652175903, 44.304368427821565, 44.323114667619976, 44.73731415612357, 44.32228783198765, 42.95837034497942, 37.21152571269444, 32.56817313602993, 32.96391126087734, 33.86729519707816, 33.06570584433419, 33.63500302178519, 35.48564182009016, 33.661413124629426, 33.80550486700875, 35.267398902348106, 32.90379197256905, 32.243727002825054, 32.96891048976353, 30.739924907684326, 34.01050451823643, 31.6159086227417, 32.14593458175659, 32.96696499415806, 33.04899195262364, 32.854428495679585, 34.905140672411235, 33.5364601952689, 33.32951157433646, 33.89860725402832, 37.0384704044887, 41.72993230819702, 45.52091114861624, 47.88247878210885, 47.61685609817505, 51.13799817221505, 45.47855493000576, 47.06349808829171, 45.30102845600673, 52.901225158146445, 48.70995364870344, 48.88229329245431, 39.921111243111746, 34.921767711639404, 36.13563190187727, 43.36931460244315, 48.88125801086426, 55.00657449449812, 45.938522202628, 24.467301402773174, 0.08148825594357081, 3.6289053772177016, 0.6589651459029743, 0.7972842380404472, 47.832476070949006, 48.67447962079729, 50.02400391442435, 52.36411551066807, 54.538109574999126, 40.34144599097115, 28.09985957826887, 26.571895122528076, 35.56697743279593, 43.47611883708409, 1.7440802476235797, 0.12534817600888865, 0.046224624783332856, 0.02117131886604641, 0.044977616518735886, 0.022292647178151777, 0.06249632540025881, 0.01287717990843313, 0.055214219726622105, 0.07225412037223577, 0.03200708036976201, 0.01797691679426602, 0.00955899354136948, 0.10203181287007672, 0.049383771871881824, 0.10868392592029912, 0.040196499321609735, 0.09434091698910509, 0.05114443453827074, 0.09451350237109832, 0.04570143357185381, 30.41442264829363, 59.70081220354353, 39.38175732748849, 38.96217993327549, 39.630815505981445, 50.09907920019967, 62.07195445469448, 54.66957991463797, 54.04194566181728, 54.11193834032331, 50.470425673893516, 49.540371077401296, 2.6035138964653015, 1.9754243195056915, 1.7226549344403403, 7.021608914647784, 10.813255650656563, 0.6929373858230454, 17.643496411187307, 59.52414035797119, 46.13262707846505, 54.00920575005667, 50.38144356863839, 53.09077896390642, 47.1486691066197, 46.73099899291992, 39.07871512004307, 41.63844885144915, 41.04678542273385, 46.3399543762207, 48.094714982169016, 48.60931594031197, 49.541347299303325, 45.33415399278913, 51.3077391896929, 49.02588129043579, 47.11348342895508, 41.81989410945347, 37.34504577091762, 38.227553844451904, 35.863384110586985, 35.97010496684483, 34.70879847662789, 36.5827762739999, 35.91212919780186, 36.554201807294575, 35.457974093300955, 35.69937883104597, 38.0111209324428, 37.43619224003383, 37.53714609146118, 37.281007698604036, 37.38851022720337, 37.944032600947786, 36.42126887185233, 35.71832309450422, 34.936647278921946, 36.96087639672415, 39.0029102734157, 47.39437825339181, 44.66764456885201, 47.1226932661874, 46.408564363207134, 48.30650302342006, 45.60469600132534, 45.17028420312064, 44.298177582877024, 41.204242025102886, 37.0622228213719, 36.690039089747835, 34.723931653159006, 36.066073485783164, 35.03199740818569, 35.62559591020857, 36.35340929031372, 38.4049448285784, 38.352201053074424, 39.10576793125698, 37.20567185538155, 34.04550954273769, 34.42885902949742, 36.292355469294954, 33.5275421823774, 35.63084180014474, 35.41865423747471, 35.96652317047119, 35.80878169195992, 38.16218866620745, 44.21648761204311, 45.89933436257498, 46.780574389866416, 47.11011355263846, 46.334930828639436, 45.886963094983784, 46.706287724631174, 47.744689055851524, 46.698766299656455, 37.979715074811665, 34.68748140335083, 34.93741505486624, 36.135277543749126, 35.55043724605015, 35.649396964481895, 35.784122535160606, 34.80188349315098, 36.95672484806606, 35.34922088895525, 35.43741437367031, 34.92409535816738, 35.64142043249947, 33.25759424482073, 36.142840657915386, 32.849436214991975, 33.455986159188406, 34.51845257622855, 34.4873628616333, 34.996096066066194, 36.27415813718523, 33.83980464935303, 35.36690405436924, 34.59708186558315, 39.302273409707205, 44.21085262298584, 46.995238985334126, 49.308033738817485, 49.82379504612514, 51.76609100614275, 45.98800032479422, 48.528216566358296, 46.43470696040562, 53.78631796155657, 50.558518409729004, 51.31123760768345, 41.34555101394653, 36.19941289084298, 38.25973095212664, 46.671154158455984, 52.01016385214669, 55.576340675354004, 48.435294832502095, 28.00085469654628, 0.1458426205707448, 2.976216354540416, 1.162307579602514, 1.0862125371183668, 51.49657038279942, 53.776753766196116, 52.84376702989851, 57.874842984335764, 56.814454078674316, 48.43850837435041, 31.475537640707834, 25.824409655162267, 41.85799108232771, 49.836485930851524, 3.2209301718643735, 0.2999866556908403, 0.06101455419723477, 0.04788126463868788, 0.053419861011207104, 0.07980985886284284, 0.06875974645039865, 0.04927471772368465, 0.04522522073239088, 0.1459718950624977, 0.15627724065312318, 0.14578594932598726, 0.1316504364034959, 0.2011229499642338, 0.053070985446018834, 0.17325456679931708, 0.16097872837313584, 0.1548948884010315, 0.21561191177793912, 0.22520016799015657, 0.22293000694896492, 34.787087304251536, 69.04029587336949, 46.41664511816842, 52.114359038216726, 43.15932614462716, 51.452894006456646, 66.81922776358468, 59.23270511627197, 57.84911380495344, 59.80393041883196, 55.148772852761404, 56.35029009410313, 3.498564771243504, 4.502241611480713, 7.073273113795689, 12.928240401404244, 13.44856059551239, 0.840908014348575, 20.987824201583862, 58.87733949933733, 48.09855038779122, 55.45903771264212, 51.24936737333025, 53.19626304081508, 49.3193210874285, 49.432038239070344, 41.40135894502912, 42.665934562683105, 44.02587420599801, 47.64469058173043, 52.04431424822126, 51.29380110331944, 51.44460480553763, 47.86721706390381, 53.055263246808735, 51.21352856499808, 50.85572413035801, 43.19452224458967, 39.665209089006694, 41.19962842123849, 38.03042650222778, 38.19656835283552, 37.61058160236904, 38.80368457521711, 38.886729444776265, 39.30233941759382, 37.12033060618809, 36.71490669250488, 41.7160359110151, 39.058051177433555, 39.5061821937561, 38.94478859220232, 38.8405829838344, 40.64137193134853, 38.70299475533621, 36.43661049434117, 36.25012084415981, 38.43849767957415, 41.51357930047171, 50.24586336953299, 46.96266235624041, 47.92452580588204, 48.48766687938145, 50.538719517844065, 47.5192026410784, 48.970215797424316, 45.7688958304269, 42.4365884235927, 37.07150214059012, 37.35945980889456, 34.3766051019941, 37.08170209612165, 37.36164154325213, 37.51636750357491, 39.17247758592878, 40.778414726257324, 39.412475313459126, 42.15501267569405, 38.11249514988491, 34.84685223443167, 36.30282640457153, 37.65897580555507, 33.57833351407732, 37.32547616958618, 34.97152376174927, 36.00147608348301, 37.20035995755877, 38.53516101837158, 45.747752462114605, 48.31636251722063, 50.398327691214426, 50.92059251240322, 48.923770563943044, 48.10218776975359, 49.38338347843715, 50.04048504148211, 49.0785243170602, 41.5294976234436, 35.593196460178916, 37.28118140356881, 37.79896116256714, 37.46584020342146, 36.915198939187185, 38.28088126863752, 36.68872588021414, 38.694285188402446, 38.27035127367292, 36.93322951453072, 36.66451488222395, 37.476967743464876, 35.095844405038015, 38.45510734830584, 35.51602629252842, 35.247874464307515, 36.33053582055228, 36.811927863529746, 37.50667824063982, 38.38241182054792, 36.46346180779593, 37.83467837742397, 36.99563128607613, 41.125675269535606, 45.80891398021153, 48.738041741507395, 51.46901382718767, 51.08002587727138, 56.16056605747768, 49.60316889626639, 51.614853041512625, 47.98829984664917, 57.51874780654907, 54.84220790863037, 52.311156341007774, 44.70983403069632, 39.43559544427054, 40.458742005484446, 48.279200077056885, 53.99747371673584, 59.94413117000035, 47.72582469667707, 31.941918100629533, 0.40848103963903015, 9.965211510658264, 3.5869721301964352, 1.2268895655870438, 58.12054518290928, 57.030897412981304, 57.6861229624067, 61.32773985181536, 63.18599387577602, 52.11615514755249, 38.24894734791347, 35.345236097063335, 47.54290294647217, 59.22787611825125, 4.916569207395826, 0.3684849558132035, 0.19814104640058108, 0.2072881327143737, 0.19140828267804214, 0.1805620225412505, 0.12112600542604923, 0.12549312465957232, 0.14099743270448276], [0.04954040828826172, 0.03120132003511701, 0.016289205124069537, 0.03287860771108951, 0.05327709385060838, 0.06269029142068964, 0.05468545434996486, 0.03679981069373233, 0.05586871424955981, 0.05530751829168626, 0.08609641117176839, 0.14665763612304414, 5.337727316788264, 52.85606186730521, 41.24543442044939, 45.861021995544434, 28.76909269605364, 35.86545467376709, 54.02429723739624, 53.833649090358186, 47.41918332236153, 50.39105987548828, 44.14574105398995, 48.914956774030415, 8.773147293499537, 2.8093369092260088, 1.0764473868267876, 3.6208315704550063, 6.983151503971644, 1.1529440134763718, 11.156435864312307, 53.0694306237357, 33.784827028002056, 48.17976788112095, 50.712855270930696, 51.45323099408831, 46.997219221932546, 46.9664352280753, 41.736599104745046, 45.32511438642229, 43.73739194869995, 47.58818783078875, 46.77724967684065, 49.098753997257774, 46.817017691476, 48.46874346051897, 45.04398332323347, 47.7074293409075, 41.997573443821494, 37.19524260929653, 35.11492068426949, 35.32440192358834, 35.87496675763811, 34.34526525224958, 33.01224987847464, 34.704970019204275, 33.63628496442522, 33.40586880275181, 34.08288042885916, 34.33480126517159, 36.5695538520813, 37.73500994273594, 36.21499422618321, 36.50990009307861, 35.913230487278526, 34.1539431299482, 34.29466152191162, 32.82760844911848, 33.26066882269723, 35.174230507441926, 38.476782253810335, 42.18844393321446, 45.03672592980521, 43.622093541281565, 43.98670373644148, 45.327740805489675, 45.488275459834504, 46.40347828183855, 43.355327878679546, 38.909950324467246, 37.8312702860151, 36.19713388170515, 34.785728931427, 34.95728342873709, 33.69567469188145, 36.495194230760845, 35.584320136478965, 36.28134257452828, 36.102912834712434, 37.95069244929722, 36.80979824066162, 34.61005762645176, 33.501031330653596, 33.34698281969343, 33.69927038465227, 34.23759249278477, 34.00050606046404, 36.25547443117414, 36.23738827024187, 39.029153619493755, 44.310604436056956, 44.32000534875052, 44.937234674181255, 43.90942587171282, 44.712144306727815, 41.22465583256313, 44.74819156101772, 44.17856781823294, 44.188465527125764, 40.932921818324495, 32.380759375435964, 33.52876159123012, 31.347958292279923, 34.47647156034197, 32.87284469604492, 34.205814906529014, 33.64412600653512, 34.76455429622105, 34.41997923169817, 33.10349014827183, 33.358673163822715, 33.06901318686349, 33.20061206817627, 33.088391712733674, 30.55073240825108, 33.45165395736694, 32.199779646737234, 33.846516609191895, 34.12619897297451, 34.58193826675415, 33.77615567616054, 33.76974943705967, 35.32021910803658, 35.69636678695679, 38.57138545172555, 44.60571527481079, 47.116026469639365, 47.25046369007656, 47.21636887959072, 48.52051796231951, 46.861173493521555, 46.15035193307059, 44.74257046835763, 49.193409306662424, 46.22537163325718, 46.840360164642334, 35.38007436479841, 37.77044228145054, 43.03954267501831, 50.28344964981079, 49.215490681784495, 53.817723819187705, 13.089687875338964, 0.5274431833199092, 7.213853410312107, 1.6598283456904548, 3.8028346385274614, 46.99053158078875, 50.42068004608154, 50.22155509676252, 54.13586793627058, 51.92465584618704, 34.94320985249111, 26.068267107009888, 27.171988453183854, 38.85797779900687, 30.836306844438823, 0.09300066104957036, 0.09933547755437237, 0.03966719111693757, 0.07529578251498086, 0.03367354880486216, 0.04160182337675776, 0.026794104471004436, 0.0032370263693987256, 0.021261482599324415, 0.029082987989698137, 0.04102208644949964, 0.01552256742226226, 0.02179470255837909, 0.06260567810386419, 0.018866452454988445, 0.05722599463271243, 0.11679566279053688, 0.05332209090037005, 0.039642363520605226, 0.024194453610107303, 0.16136575117707253, 8.872084430285863, 61.98998655591692, 46.8464606830052, 50.23952661241804, 36.42650433949062, 43.684828826359336, 57.719536849430625, 59.43618311200823, 51.28727674484253, 55.64875480106899, 49.0241824558803, 53.06813131059919, 7.998180832181658, 1.5470531114510127, 1.210388245327132, 5.648007810115814, 10.354126504489354, 0.9936131345374244, 13.331004892076765, 55.1054230417524, 36.55380228587559, 47.75314153943743, 50.83676249640328, 53.07760170527867, 49.102992398398264, 48.00283547810146, 43.85165507452828, 47.28529848371233, 46.09446062360491, 50.07827629361834, 47.83219466890608, 52.2463504927499, 48.13862064906529, 48.9628507069179, 46.93778780528477, 49.64039734431675, 44.060448442186626, 40.05277613231114, 36.82127319063459, 37.152413913181846, 36.98423276628767, 37.77641773223877, 34.597943442208425, 36.154423304966514, 34.94677427836827, 35.28858395985195, 36.61605814525059, 36.45898716790335, 37.76656518663679, 37.14286708831787, 38.290299551827566, 37.10548577989851, 37.51331377029419, 36.06600400379726, 34.24683012281145, 34.518553325108115, 35.69390712465559, 36.18408516475132, 39.26494073867798, 44.16901751926967, 46.89545937946865, 46.52828529902867, 45.49670362472534, 45.16444424220494, 46.43092714037214, 47.54317045211792, 43.85113048553467, 39.33551011766706, 38.197506359645296, 35.29164464133126, 33.811692237854004, 35.66278266906738, 35.39927223750523, 35.90608079092843, 36.58010816574097, 38.65131752831595, 37.42672184535435, 38.727066789354595, 37.88596650532314, 36.9239501953125, 33.861601148332866, 34.941309520176475, 33.80590786252703, 35.69731521606445, 35.68073681422642, 36.6248893056597, 35.91552686691284, 39.57448993410383, 46.7083409173148, 46.06912054334368, 47.00958701542446, 46.433699471609934, 46.45902565547398, 42.9492369379316, 44.516264166150776, 45.47186034066336, 47.1068548474993, 42.166789872305735, 33.01448719842093, 35.3013790675572, 33.858943462371826, 36.72637469427926, 35.21945980616978, 35.895627226148335, 35.27114050728934, 36.68810054234096, 36.07994556427002, 35.52538899012974, 35.787759917122976, 34.357417651585166, 34.74929257801601, 35.31826319013323, 33.535372802189414, 35.21903249195644, 33.796034472329275, 35.843609537397114, 36.723595414842876, 36.387156690870015, 36.96681015832083, 36.56134455544608, 36.50690541948591, 38.08758585793631, 42.183031286512104, 46.756349495479036, 49.0108836037772, 48.82344205038888, 49.03091526031494, 50.75250864028931, 49.38996342250279, 47.18511240822928, 45.50483649117606, 51.51683480398995, 48.8381791796003, 48.34845972061157, 37.57429116112845, 40.197190965924946, 45.298405511038645, 54.06235946927752, 52.741572925022666, 54.03656080790928, 15.372404745646886, 0.6514198364956039, 7.901626927512033, 1.821710841996329, 5.173342491899218, 52.89453751700265, 54.029136657714844, 53.79953343527657, 58.08946936471121, 57.53119550432478, 42.40911872046334, 31.292657579694474, 27.983046463557653, 44.97367797579084, 37.4146180834089, 0.5281741555247987, 0.033698902265833955, 0.07487165741622448, 0.037161117020462237, 0.027598672280354158, 0.04878817079588771, 0.008621322606424136, 0.02706900954113475, 0.03079772401334984, 0.1998251431754657, 0.12276249618402549, 0.12636227373565945, 0.15710421199245111, 0.15238555733646664, 0.17003979001726421, 0.14856430595474585, 0.23847096945558274, 0.22697640982057365, 0.17481469522629464, 0.22820316042218888, 0.2698724844626018, 10.684309244155884, 74.3524090903146, 52.07714796066284, 56.40717847006661, 41.31173760550362, 47.59193638392857, 63.92249597821917, 62.95508439200265, 59.2520558493478, 58.848831040518625, 54.929386956351145, 57.80554512568882, 13.573649883270264, 6.393803562436785, 6.432739964553288, 9.85538741520473, 13.598507932254247, 1.490005686879158, 16.35333926337106, 59.00060749053955, 35.71517903464181, 50.304857049669536, 51.86262232916695, 55.85979243687221, 50.70010185241699, 50.75211954116821, 46.0003160067967, 51.356216771262034, 47.84541014262608, 52.65842383248465, 50.49427189145769, 54.378902026585166, 48.781832763126914, 52.2886962890625, 47.91089691434588, 52.07549428939819, 46.180069378444124, 42.15652043478829, 38.94161673954555, 39.933562414986746, 39.85146944863455, 38.737169470105854, 37.290304388318745, 38.55850001743862, 37.70613322939192, 38.556283542088096, 38.89067254747663, 38.30959817341396, 39.1750762122018, 38.68705211366926, 39.91885307856968, 40.01079511642456, 39.50337164742606, 37.24088185174124, 37.26638174057007, 36.76255743844168, 38.67813062667847, 40.0006959097726, 42.13658605303083, 46.07057966504778, 50.185532161167686, 47.52651562009539, 48.36955792563302, 49.730567591530935, 50.42838559831892, 50.10681949343, 44.498323917388916, 39.149941103799, 39.93827676773071, 36.83783074787685, 35.77388089043753, 36.651931694575715, 36.63960211617606, 38.98331635338919, 38.0028213092259, 39.57941968100411, 39.9074649810791, 40.850755895887104, 39.77054030554635, 38.352864606039866, 36.43898330415998, 35.70232834134783, 35.31220783506121, 37.56135708945138, 35.70416613987514, 36.9596118245806, 36.85357536588396, 40.740675585610525, 47.43941995075771, 46.399886063167024, 49.46646308898926, 48.144081933157786, 48.65699100494385, 46.17822463171822, 48.371298449380056, 48.194407735552105, 49.733388560158865, 46.549293177468435, 36.57357685906546, 38.21216705867222, 35.42134666442871, 38.28562341417585, 37.21820987973894, 38.09626415797642, 36.08282559258597, 38.5825685773577, 38.20455878121512, 37.851559025900706, 38.071108204977854, 37.23567417689732, 36.509507519858225, 37.68218626294817, 35.758817195892334, 36.809054783412385, 36.05438314165388, 38.841364656175884, 38.83279752731323, 39.57457331248692, 39.4068854876927, 37.32864802224295, 39.42737225123814, 39.74920586177281, 43.56195688247681, 49.731828689575195, 51.680384976523264, 52.093194825308665, 50.935534613473074, 53.16160542624337, 49.6382850919451, 48.338558537619456, 47.33690970284598, 53.39548526491438, 51.31920371736799, 51.13367639269148, 40.42176716668265, 43.423851013183594, 49.362604890550884, 57.11738511494228, 55.59411416734968, 55.453503472464426, 17.951789719717844, 1.0263237335852213, 15.871914216450282, 3.8220242602484564, 5.808401329176767, 55.64513826370239, 59.81102452959333, 58.533493995666504, 61.75756236485073, 60.56322956085205, 47.760906151362825, 36.51349231175014, 36.75219767434256, 50.577323709215435, 45.86745602743966, 1.2019507437944412, 0.2435403045799051, 0.18387097998389176, 0.08384924568235874, 0.11793580518237182, 0.11660818356488432, 0.08890137315860816, 0.09845621830650739, 0.15230950713157654], [0.012830655306710728, 0.013415957917459309, 0.05154508911073208, 0.04690352621089135, 0.016742069573540772, 0.014124000727731203, 0.047381839116236994, 0.053272371246878586, 0.043680898778672726, 0.03363159837733422, 0.06738316174596548, 0.12757945699351175, 0.42027476536376135, 33.04807479040963, 41.10603271211897, 37.08001715796334, 36.16295569283621, 29.278972353254044, 53.6405725479126, 53.40160662787301, 48.51127685819353, 49.83221626281738, 44.80064351218087, 47.67196920939854, 26.04787414414542, 1.0683863908052444, 0.7655150113361222, 4.939431820596967, 5.623943158558436, 0.041395877820572684, 22.454825162887573, 59.03096417018345, 43.15031780515398, 53.57180275235857, 45.25059495653425, 53.26881613050188, 47.04192393166678, 47.976050172533306, 47.95588302612305, 51.94586869648525, 46.755098819732666, 49.08632366997855, 47.39605276925223, 51.76591035297939, 46.98177685056414, 48.80454642432076, 46.314728941236226, 45.657036781311035, 37.091085638318745, 36.1064772605896, 35.117470673152376, 35.66495745522635, 33.44801310130528, 34.308314732142854, 33.31956870215279, 33.864953654153005, 32.84199816840035, 36.18765653882708, 35.68594101497105, 35.55391134534563, 35.48438419614519, 35.674618925367085, 36.45277547836304, 36.456801959446494, 34.92210122517177, 36.861527579171316, 34.237811361040386, 35.028203691755024, 33.25733021327427, 34.28203664507185, 39.579072271074565, 41.23406021935599, 44.19999258858817, 45.31457049506051, 45.340098176683696, 43.415884903499055, 45.24959789003645, 45.40717955998012, 43.59714950834002, 38.51128353391375, 35.54415954862322, 31.58812972477504, 33.65671614238194, 34.48863090787615, 36.22667414801461, 34.09347990580967, 34.52136039733887, 35.976198537009104, 35.123192514692036, 37.37112236022949, 35.515126500810894, 35.66187940325056, 34.80581964765276, 35.57434252330235, 33.94485446384975, 33.51703998020717, 34.824645791734966, 35.45669909885952, 36.40503093174526, 36.526461124420166, 42.33623211724417, 46.23874691554478, 43.303490843091694, 45.42536299569266, 43.6962308202471, 43.90060860770089, 43.75875071116856, 43.54276595796858, 42.85568986620222, 40.07457263129098, 33.64241674968174, 32.4376859664917, 32.539306844983784, 33.24721711022513, 32.924598353249685, 34.4661500113351, 33.228623730795725, 33.44616140638079, 33.23259462629046, 34.586683886391775, 33.918829986027305, 32.35046870367867, 31.940347807747976, 34.14161007744925, 33.60566772733416, 33.78889867237636, 31.512943267822266, 32.40429292406355, 33.31304781777518, 33.136817182813374, 33.78449351446969, 34.07840231486729, 33.2826737676348, 34.947013991219656, 35.42133971623012, 39.503395966121126, 42.050577776772634, 46.06785249710083, 45.77168205806187, 48.350255829947336, 46.62854085649763, 48.63232489994594, 40.690561703273225, 52.252968651907786, 48.678023202078684, 48.87088087626866, 39.768375941685264, 35.36279419490269, 44.11764601298741, 53.73284115110125, 49.39663021905081, 43.90092127663748, 4.292243599891663, 0.17199489367859705, 0.9202058506863457, 0.9364925367491586, 7.86868291241782, 51.78136314664568, 46.083395617348806, 53.32145915712629, 47.09558139528547, 48.44405998502459, 32.28291136877877, 28.8935957295554, 31.010446071624756, 43.23900808606829, 18.79095493044172, 0.16350207797118596, 0.057724758583520136, 0.10731758709464755, 0.02195715910888144, 0.06857519849602665, 0.04962540158469762, 0.08172027420784746, 0.06962343331958566, 0.0351760051479297, 0.06137676297553948, 0.03497628175786563, 0.014695546889145459, 0.04610140960929649, 0.06360779968755585, 0.017245135436366712, 0.03802512280110802, 0.05964502625699554, 0.03740836839590754, 0.1074433196336031, 0.06645025751952614, 0.10607606478567634, 0.7844463012048176, 42.09884343828474, 46.80310392379761, 40.47457695007324, 32.566102572849815, 36.139658382960725, 58.0937042917524, 59.11434255327497, 53.266783782414024, 55.02488647188459, 49.456770351954866, 53.861045837402344, 25.831941502434866, 0.6638036976967538, 0.5172773173877171, 6.113338223525456, 7.101369023323059, 0.23432254205857003, 25.135063239506312, 58.29995114462716, 42.79311786379133, 51.78187731334141, 45.83981956754412, 55.593200479234966, 47.924932275499614, 50.95042807715279, 50.15959800992693, 54.98976680210659, 48.88936308452061, 49.74269219807216, 49.28808198656355, 51.45913348879133, 48.064931528908865, 50.464818477630615, 47.4930739402771, 49.14179808752877, 39.52549818583897, 38.5808766910008, 36.15306840624128, 36.504817485809326, 36.83122648511614, 36.55150590624128, 36.26245389665876, 36.97856651033674, 34.839549677712576, 36.443676812308176, 36.71524020603725, 35.89534929820469, 37.41113356181553, 37.820069789886475, 38.308615003313335, 37.26698623384748, 37.031331130436485, 37.09220429829189, 35.4939866065979, 35.0887120791844, 35.866257190704346, 35.526455538613455, 40.618453298296245, 45.118092809404644, 46.8958033152989, 46.886444091796875, 46.02671568734305, 45.851357051304404, 48.44435180936541, 47.73231084006173, 43.48965392793928, 38.78160320009504, 36.558197021484375, 33.03616557802473, 34.767149448394775, 36.917248657771516, 36.27446385792324, 35.89090592520577, 35.82161848885672, 37.289696420942036, 36.40827921458653, 39.25518546785627, 38.54984603609358, 37.67247268131801, 36.820255279541016, 36.967258317129954, 35.90667486190796, 34.55444424492972, 35.11459411893572, 36.357512201581685, 36.16815989358084, 36.916220324380056, 43.06261069434029, 46.58366591589791, 45.425891058785574, 47.8356340272086, 45.07564973831177, 46.636510440281455, 45.270595346178325, 44.22667019707816, 44.606840882982524, 42.35367209570748, 35.30399853842599, 35.47058159964425, 34.030848843710764, 33.71248238427298, 34.87035799026489, 34.436679227011545, 35.644793782915386, 35.23830679484776, 35.06651953288487, 36.29105963025774, 36.03595304489136, 33.322486945560996, 34.73385715484619, 35.42700597218105, 35.241683619362966, 35.91312279020037, 33.74555580956595, 33.816142559051514, 35.18258919034685, 34.88477202824184, 35.650574684143066, 35.04431309018816, 36.27443606512887, 35.817779609135215, 37.23267602920532, 43.23963689804077, 43.993947233472554, 48.6227468081883, 47.662814957754954, 49.87816817419869, 48.70641354152134, 48.76677254268101, 42.402444975716726, 51.802642004830496, 50.75024700164795, 50.6899470601763, 41.69413866315569, 37.90953826904297, 46.41545350211007, 55.90250301361084, 51.16166721071516, 45.67787790298462, 5.15916382414954, 0.6999561520559447, 3.4635784200259616, 1.2782528208834785, 9.06755896977016, 55.951428753989084, 51.41922303608486, 57.838538646698, 55.722238949366975, 51.93672834123884, 40.015078680855886, 30.610650198800222, 32.02293062210083, 49.77981294904436, 22.556025675364904, 0.1696074546447822, 0.05340200875486646, 0.030898751092276404, 0.013151755040910627, 0.010737528292728322, 0.04919941729999014, 0.037833280595285554, 0.09134269465825387, 0.0076360278430261785, 0.12435735203325748, 0.1605920855488096, 0.1549739513014044, 0.11264317096876246, 0.14421851986220904, 0.1737023727702243, 0.06638008342789752, 0.1758956015110016, 0.12191504665783473, 0.1621408960116761, 0.20733511447906494, 0.21794441661664418, 1.163329073360988, 49.14349692208426, 54.50060319900513, 44.86440713065011, 48.322522095271516, 40.039800371442524, 65.31411593300956, 62.76160485403878, 58.63700131007603, 59.6769312449864, 55.46179962158203, 57.25361844471523, 32.78056567055838, 1.595673022525651, 5.8487091319901605, 15.141561269760132, 10.008496182305471, 1.0725404364722115, 27.008849961417063, 55.572293349674766, 43.13138048989432, 53.26199299948556, 46.911877972739084, 56.96430587768555, 51.94922815050398, 53.416190896715435, 52.59747076034546, 57.434017998831614, 51.589728355407715, 52.54939270019531, 51.55595663615635, 54.69019174575806, 49.26955114092146, 52.508259364536826, 50.06290340423584, 51.66601610183716, 40.54517412185669, 41.33922815322876, 38.706847531454905, 39.27703060422625, 37.974955558776855, 38.29002162388393, 36.89178350993565, 39.24153920582363, 36.518828528267996, 39.9103102684021, 38.89833641052246, 37.1933388028826, 39.15543712888445, 39.25872557503836, 41.38191441127232, 38.84043707166399, 39.60000024523054, 39.41763782501221, 36.65472139630999, 37.99274294716971, 38.477761949811665, 38.223961625780376, 44.041299206869944, 46.08881173815046, 48.046779360089985, 49.903126103537424, 48.822754178728374, 46.66435534613473, 49.67220272336687, 49.21380574362618, 45.83302770342146, 38.41632597787039, 36.726808956691194, 33.19671065466744, 35.242298534938264, 38.143286091940745, 37.74169410978045, 36.87950951712472, 38.46424422945295, 39.38665928159441, 38.94224207741873, 42.10619810649327, 40.18067509787423, 39.277569089617046, 39.266274792807444, 38.68487385341099, 37.18982301439558, 36.36909484863281, 36.72705561774117, 36.77034636906215, 36.635648591177805, 37.721335887908936, 45.124902044023784, 49.392190320151194, 46.61165673392159, 51.48589447566441, 48.569846698216026, 49.14991358348301, 48.17798914228167, 46.894444942474365, 47.28959941864014, 45.46200084686279, 39.4422344480242, 38.959720270974294, 35.93914031982422, 36.78478125163487, 37.039255550929475, 36.47745895385742, 36.40608010973249, 36.80133186067854, 35.768586363111226, 38.599014963422505, 39.099563189915244, 35.79569475991385, 37.011497497558594, 37.56727000645229, 38.17000886372158, 38.040459700993125, 36.29588862827846, 37.0848183631897, 37.365122590746196, 37.320977210998535, 37.82998834337507, 37.27418109348842, 37.33341448647635, 39.01332562310355, 39.76530483790806, 44.71426003319876, 46.061998639787944, 51.047511781964985, 49.55303069523403, 52.917355401175364, 50.09735952104841, 50.95082759857178, 42.4612649508885, 52.94449159077236, 52.526831899370464, 53.19904579435076, 43.66057961327689, 40.056357928684776, 48.47259276253836, 59.21440356118338, 52.27644314084734, 48.01171875, 7.603819319180079, 1.1797514664275306, 3.548916846513748, 3.1816837063857486, 11.75145353589739, 62.57285703931536, 54.98538596289498, 64.30586283547538, 58.58971881866455, 57.92316770553589, 42.05913100923811, 40.13484477996826, 40.35161467960903, 55.93785892214094, 29.32990264892578, 0.23722984748227255, 0.21479574271610805, 0.17064413401697362, 0.0932269524782896, 0.21113869680890016, 0.12772204434233053, 0.19729920157364436, 0.20642743818461895, 0.17588633272264684], [0.05324834771454334, 0.04065403887735946, 0.04305044135877064, 0.00951365298325462, 0.016939119535631368, 0.08706952538341284, 0.10010855285716908, 0.015247709849583251, 0.017065676494634578, 0.0308113489965243, 0.05131529304864151, 0.07283873257360288, 0.024793048721871207, 21.382346391677856, 51.28788818631853, 37.67033611025129, 51.185509954180034, 27.286623307636805, 47.152521882738384, 54.19715799604143, 49.21768283843994, 47.265013217926025, 48.7826908656529, 38.809705189296174, 37.629675252096995, 0.13581418512122972, 1.258376413158008, 3.466842987707683, 5.973848794187818, 0.4890718108841351, 22.51866000039237, 56.16491910389492, 47.12928363255092, 53.013706071036204, 47.361516748155864, 50.94643633706229, 46.81652784347534, 50.19806671142578, 49.992591108594624, 49.39741883959089, 46.72046552385603, 48.02321107046944, 45.22054399762835, 46.89394119807652, 49.490521226610454, 46.5347123827253, 43.92650801794869, 37.719379970005576, 33.2367913382394, 34.434764998299734, 33.4585291998727, 34.96610416684832, 34.45811789376395, 33.77926846912929, 35.07996082305908, 34.77409764698574, 33.28062057495117, 33.32757650102888, 33.56492349079677, 35.28356736046927, 35.43930428368704, 35.08226762499128, 35.81611898967198, 35.64942823137556, 34.265114307403564, 35.205622468675884, 33.81920671463013, 34.61188152858189, 32.587336267743794, 32.99830136980329, 35.56973934173584, 42.59952368055071, 43.12062120437622, 43.95948069436209, 45.33530739375523, 44.195660386766704, 46.01054375512259, 46.42393725258963, 39.714388438633506, 33.7228456224714, 33.527212142944336, 35.4349616595677, 35.540904317583355, 36.286637101854595, 34.45922613143921, 34.775681836264475, 33.67792551858084, 35.01110070092337, 34.36750643593924, 34.08045203345162, 34.95746408190046, 33.56786952699934, 33.284337861197336, 35.40462582451956, 33.584878717150005, 33.4943436895098, 34.01584073475429, 33.86458192552839, 35.253019605364116, 36.90880312238421, 40.33535589490618, 44.64604956763131, 43.6727945463998, 44.12050519670759, 43.43492644173758, 43.69865574155535, 41.41677699770246, 41.890032700129915, 40.408919947487966, 37.2818831716265, 33.09068809236799, 32.39061539513724, 32.01875128064837, 33.202373436519075, 33.43363380432129, 33.682275090898784, 34.696086747305735, 33.18917533329555, 32.63843332018171, 34.053743158067974, 32.789025102342876, 33.00100074495588, 32.144753387996126, 31.346401895795548, 32.53077793121338, 31.86518219539097, 32.21137966428484, 32.491277422223774, 32.13914966583252, 33.12512336458479, 34.34120750427246, 34.68142604827881, 33.63582985741751, 33.7156959261213, 33.183790479387554, 33.86426230839321, 36.06506599698748, 40.85973296846662, 42.35823706218174, 45.76900700160435, 45.76386533464704, 48.710506030491416, 46.26658487319946, 40.32683045523507, 48.978258337293354, 47.73137630735125, 44.21950313023159, 37.624596118927, 46.0018550327846, 49.10144642421177, 53.573845522744314, 35.26003728594099, 1.286164430635316, 0.2550624263073717, 1.637080812028476, 0.22608710825443268, 16.241059848240443, 51.00860186985561, 45.14847380774361, 51.85932888303484, 40.393005098615376, 45.22843367712838, 29.65328570774623, 27.882080452782766, 32.49401501246861, 43.92782817568098, 5.108208775520325, 0.3377628986324583, 0.05358816144455757, 0.04368595725723675, 0.06662850188357489, 0.0362219872352268, 0.057849466534597535, 0.08378283067473344, 0.1188806923372405, 0.03465475793927908, 0.04428408248350024, 0.015059647083814656, 0.018448941376326338, 0.06379554354186569, 0.030449241998472383, 0.0823989992163011, 0.08161296389464821, 0.02528115458387349, 0.029950841063899652, 0.053364112574074946, 0.04197453926982624, 0.08524643070995808, 0.05464096959414227, 27.641759634017944, 54.584294251033235, 41.72198356900896, 49.941302980695454, 32.21865095411028, 54.5251407623291, 57.87739297321865, 54.64649452481951, 52.194509983062744, 54.60344696044922, 44.2179536819458, 41.20022944041661, 0.199614444481475, 0.6187095088618142, 4.933881078447614, 5.857815180506025, 0.5578476318291256, 25.732870612825664, 56.35879816327776, 47.27269445146833, 51.34943880353655, 48.22608804702759, 52.31473813738142, 47.43303108215332, 51.500614234379356, 53.456896918160574, 51.19589751107352, 48.98323324748448, 50.929062366485596, 47.23220035008022, 48.85917663574219, 51.2392577443804, 47.675575324467246, 48.3548902784075, 40.03113596779959, 35.62606143951416, 36.84258678981236, 35.81584106172834, 35.39788259778704, 35.660521030426025, 36.03232608522688, 36.3103026662554, 36.429526805877686, 35.16472537176949, 35.56798492159162, 35.71125330243792, 36.82470212663923, 37.22059311185564, 35.3848443031311, 38.665693351200645, 37.180248396737234, 35.95197016852242, 36.17970779963902, 34.29580797467913, 36.93466084344046, 33.78355203356062, 34.15841082164219, 38.49424307686942, 43.36540624073574, 44.8389767238072, 47.0240010534014, 46.810423851013184, 46.20782743181501, 47.21956157684326, 45.888067858559744, 40.17499841962542, 35.93648263386318, 32.82273776190621, 34.036549840654644, 35.918264457157676, 37.32491683959961, 35.88333933694022, 35.910315717969624, 35.68511070523943, 36.06071989876883, 35.81842231750488, 36.22333206449236, 35.82539136069161, 35.830223832811626, 35.26752049582345, 37.56120770318167, 34.57423618861607, 36.275954246520996, 35.303234236580984, 35.60557467596871, 35.11256524494716, 37.653128896440776, 40.33516134534563, 45.66455125808716, 44.621557167598176, 46.701615061078755, 44.85420022691999, 44.198467458997456, 45.595510482788086, 43.50138248716082, 43.07464150020054, 40.36955145427159, 34.67587791170393, 33.62418467657906, 33.34957102366856, 35.4938337462289, 35.4387206350054, 34.58746555873326, 35.63269002096993, 35.430962971278596, 35.10332761492048, 34.26929712295532, 35.21675000871931, 35.159729616982595, 34.49494334629604, 32.86584438596453, 33.94659498759678, 34.34369843346732, 35.351333141326904, 33.05285167694092, 33.92739711488996, 35.23170600618635, 34.98079265866961, 35.51119382040841, 35.808003493717735, 35.4441054889134, 35.08098568235125, 37.78410938807896, 38.285540035792756, 42.51225083214896, 43.389641557421, 48.01527622767857, 47.707637786865234, 49.83770881380354, 47.012592111315044, 41.45823689869472, 51.62704365594046, 50.24746492930821, 45.71417876652309, 39.49527699606759, 47.419391768319265, 51.99411003930228, 56.40999249049595, 38.725805691310335, 2.150732146842139, 0.6831538879445621, 0.22526960926396505, 0.5502551506672586, 18.23464914730617, 56.5143335887364, 49.79165962764195, 56.99622242791312, 46.33040060315813, 49.49927248273577, 41.493756089891704, 28.350352559770855, 35.12975856236049, 50.7048578943525, 7.986822264535086, 0.3663167107318129, 0.043602141219058206, 0.08270119157220636, 0.03136992580922587, 0.05055649412263717, 0.03770676774105855, 0.031098216639033387, 0.025001879748223082, 0.04462403870586838, 0.14749923667737416, 0.1396189752433981, 0.11538082228175231, 0.18443477473088674, 0.22677358213279927, 0.2090673872402736, 0.20769180676766805, 0.1128504905583603, 0.07145712671003171, 0.12522933738572256, 0.12905818835965224, 0.1997167539915868, 0.14297557941504888, 32.15243114743914, 66.42073467799595, 45.78878157479422, 61.64719023023333, 40.10874387196132, 56.580925124032156, 64.7969754082816, 60.75069890703474, 56.4964975629534, 59.59035669054304, 50.25531986781529, 45.380804198128835, 0.43291565562997547, 2.7699395375592366, 11.995886819703237, 9.853598254067556, 0.9799957509551729, 31.17361409323556, 56.768130438668386, 48.49951703207833, 53.07285261154175, 50.357705048152376, 52.60786526543753, 50.66814708709717, 53.11487184252058, 54.614247935158865, 52.69677788870675, 50.36252014977591, 51.47407558986119, 47.77057456970215, 49.12074851989746, 54.786997522626606, 48.61274835041591, 50.36824199131557, 40.922777448381694, 37.80133049828665, 38.85569184167044, 37.81288535254342, 37.19559696742466, 39.74847977502005, 38.04510457175118, 42.19876548222133, 38.633981772831504, 37.36854805265154, 37.50462852205549, 37.87522111620222, 39.105705397469656, 39.75179753984724, 37.97319419043404, 38.71026257106236, 39.00387259892055, 37.78527668544224, 37.88010917391096, 37.05950607572283, 38.66499505724226, 35.41275174277169, 36.5703181539263, 40.59692430496216, 47.017275197165354, 46.039840834481375, 48.88856751578194, 48.35407386507307, 49.75960063934326, 49.315381458827424, 48.525169781276155, 41.74826513017927, 36.3179908479963, 33.831397329057964, 37.027860505240305, 38.10804830278669, 38.99106012071882, 37.625422954559326, 38.41235508237566, 38.16866438729422, 38.92099796022688, 38.6153119632176, 38.21148266111101, 37.74371256147112, 38.475969314575195, 38.151141030447825, 39.5844258580889, 36.13556589399065, 37.53114979607718, 36.49416937146868, 36.89678273882185, 36.87266901561192, 37.725647245134624, 41.37578957421439, 47.07033164160592, 46.655496392931255, 47.447629247392925, 48.001407623291016, 48.75011076245989, 48.625241211482454, 44.84901687077114, 45.47416366849627, 42.76438358851841, 38.91830553327288, 35.52142851693289, 35.66249779292515, 36.39701618467058, 38.37276424680437, 36.303462164742605, 38.26416390282767, 38.43844209398542, 36.90931728907994, 37.181141240256174, 37.05411774771554, 38.793241432734895, 36.837945393153596, 35.475837911878315, 36.464889662606375, 35.652648721422466, 37.527898039136616, 35.68469728742327, 35.66350180762154, 37.99817991256714, 37.92459501538958, 38.60584156853812, 38.593741280691965, 37.13785743713379, 37.07475389753069, 39.36765248434884, 41.48394175938198, 44.88422686713082, 45.53436633518764, 49.22619438171387, 49.705724307468955, 52.19362408774239, 50.22571011951992, 44.402897357940674, 52.34325701849801, 52.253138882773264, 47.65714522770473, 42.646288531167166, 50.36922863551548, 55.12412411825997, 57.47026675088065, 40.87578330721174, 4.212984195777348, 0.5216827467083931, 5.207591465541294, 1.1024213816438402, 18.999944584710256, 59.83563504900251, 52.712897709437776, 61.64073535374233, 50.093228816986084, 55.31515441622053, 41.49347121374947, 37.0052614893232, 40.82292488643101, 59.30525820595877, 11.0869026354381, 0.5767667623502868, 0.13611162773200444, 0.22511996515095234, 0.22607346970055783, 0.1708910393395594, 0.20578379343662942, 0.22375449485012464, 0.22503555539463246, 0.09982056223920413], [0.02814804476552776, 0.02219409166303064, 0.05098034780738609, 0.035738073023302216, 0.031321715896150897, 0.041598671581596136, 0.015799506401110972, 0.016695545819987143, 0.036978435037391524, 0.050864481167601686, 0.04711988727961268, 0.06063125655055046, 0.02172644532817815, 5.921448085989271, 51.09237630026681, 41.423072065625874, 46.98899602890015, 27.042074510029384, 39.54390048980713, 50.12976939337594, 53.895133699689595, 49.34839235033308, 48.18962737492153, 42.65420947756086, 49.610499245779856, 3.597425477845328, 1.0436052062681742, 2.831998024668012, 2.29080131649971, 0.28551233666283743, 29.1560309273856, 62.526582036699565, 49.0048178264073, 55.9234414100647, 50.60203497750418, 51.851494789123535, 50.009492601667134, 53.408645153045654, 46.94393348693848, 51.96837043762207, 48.6027637890407, 47.618721689496724, 43.90329756055559, 47.60171944754464, 46.165974957602366, 47.17373125893729, 41.05210426875523, 35.715675830841064, 33.573327336992534, 34.1717791557312, 35.24492495400565, 34.49688189370291, 33.60226658412388, 34.243727752140586, 34.715930802481516, 33.306217738560264, 33.19802039010184, 33.99291515350342, 32.65425436837332, 34.47266742161342, 34.828050409044536, 35.998561314174104, 35.50788647787911, 34.858011041368755, 34.097391741616384, 36.35102258409773, 33.847048146384104, 34.19649737221854, 33.47091783796038, 32.77756404876709, 36.30713428769793, 39.87823738370623, 41.32939992632185, 44.89503479003906, 44.10195698056902, 43.947957106998985, 45.76520981107439, 40.91947357995169, 37.67433132444109, 34.7282395362854, 32.458228315625874, 35.77050059182303, 36.807296889168875, 36.335757391793386, 34.64386756079537, 33.331335476466585, 32.95464236395699, 33.920768533434185, 32.99801649366106, 35.0078524180821, 35.93710797173636, 35.79773753029959, 33.277278491428916, 33.396172591618125, 33.18416568211147, 34.115099225725444, 34.803901944841655, 34.408757890973774, 33.693826471056255, 33.71177019391741, 37.01138980048043, 42.76276118414742, 45.20456314086914, 44.68989617483956, 43.71508475712368, 43.636980056762695, 42.49789932795933, 42.26429046903338, 41.804608072553364, 37.140529019492014, 31.98585156032017, 31.608234337397985, 31.91351386478969, 32.94820833206177, 34.04345287595476, 34.020447390420095, 33.26404217311314, 33.77659688677107, 33.21457099914551, 33.305293628147666, 32.43570225579398, 32.20854132516043, 32.664231981549946, 32.821643420628135, 32.328786849975586, 33.44018248149327, 31.5021561895098, 32.43123109000069, 34.26655953271048, 33.90783098765782, 34.43767629350935, 33.29925911767142, 33.164137499673025, 31.626073837280273, 32.3190906388419, 34.28659118924822, 33.1868303162711, 34.746464661189485, 34.90573821749006, 40.118346282414024, 45.805797713143484, 45.23797355379377, 50.32877622331892, 43.71182952608381, 48.20098767961775, 49.30009194782802, 47.299090657915386, 41.41439029148647, 43.95570434842791, 51.00050721849714, 53.23827184949602, 22.589955466134207, 0.865533570093768, 0.11899323415543352, 0.523756838270596, 0.1603147547159876, 18.22049045562744, 48.62614100319998, 44.787153584616526, 52.44890090397426, 48.03013147626604, 37.23789760044643, 26.36981197765895, 23.366543463298253, 38.863661425454275, 33.67205081667219, 0.3055439389177731, 0.1203433017113379, 0.03707472254921283, 0.07461508975497314, 0.020348126966772333, 0.007898036506958306, 0.017944623616390994, 0.04606770338224513, 0.015143249383462327, 0.019467237538525035, 0.01582282256068928, 0.03952878015115857, 0.042630265333822796, 0.07015351166150399, 0.022065494009958844, 0.019841427548921535, 0.05015274203781571, 0.021412336201007878, 0.015159035500671183, 0.018754884334547178, 0.027461584457861524, 0.08259435623352017, 0.05145575997552701, 9.539329494748797, 58.367967060634065, 44.76630204064505, 49.45818083626883, 35.31915603365217, 46.01520947047642, 56.886294978005544, 61.85329464503697, 52.760437284197124, 54.16491140638079, 45.704680579049246, 52.86563648496355, 3.654105842113495, 1.2143378619636809, 3.5474373144762854, 4.630617831434522, 0.19052084029785224, 30.783114910125732, 60.95720631735665, 50.17800726209368, 57.74812173843384, 52.25730780192784, 53.7589351109096, 51.79919569832938, 53.46981709344046, 49.27689191273281, 52.34325354439871, 49.70211819240025, 48.446741989680696, 44.892026220049175, 49.96994692938668, 49.07001624788557, 48.68980387278965, 45.13016530445644, 37.52207892281668, 36.19160311562674, 35.25397150857108, 36.62236710957119, 37.22732939038958, 35.32734101159232, 35.08392824445452, 35.87250362123762, 35.06958368846348, 36.072285175323486, 34.396872997283936, 34.649092606135774, 36.93171828133719, 35.86715350832258, 36.81363712038313, 37.50353070667812, 36.124104840414866, 35.00348547526768, 36.9845940726144, 36.2318331854684, 36.51840468815395, 34.83183717727661, 35.990185260772705, 38.35594265801566, 42.51169845036098, 43.413904666900635, 47.204178265162874, 45.25578873498099, 45.30879654203142, 46.78532000950405, 42.1746552331107, 36.88231658935547, 34.93898187364851, 33.517769541059224, 36.448658670697895, 37.42085061754499, 37.68544149398804, 35.5183504649571, 34.7367719241551, 34.61700929914202, 35.00682061059134, 35.77685471943447, 36.284410204206196, 36.260696002415244, 36.67372819355556, 35.19991452353341, 34.71046257019043, 34.64589990888323, 37.149394920894075, 34.98723363876343, 35.30110461371285, 34.66949599129813, 34.64372859682356, 38.14945261819022, 44.16629729952131, 46.51918315887451, 45.69012062890189, 46.02734102521624, 45.92434787750244, 45.75933510916573, 45.47594935553414, 43.48790298189436, 40.56928784506661, 34.41405241830008, 34.45918444224766, 34.113386494772776, 35.01068033490862, 35.198187896183555, 36.02512080328805, 33.206980092184885, 36.392756938934326, 35.088656493595664, 34.502791336604524, 35.00176232201712, 34.50401074545724, 34.24901533126831, 34.203261443546836, 34.54068333762032, 33.948905263628276, 33.95101751599993, 34.96916137422834, 35.77795253481184, 37.136506012507844, 36.7394894191197, 34.869569369724815, 36.35335023062569, 33.53706816264561, 35.11724485669817, 35.96178797313145, 36.153318541390554, 35.164172989981516, 37.5558888571603, 43.21849352972848, 49.37656034742083, 47.45926053183419, 52.47147560119629, 45.004017284938264, 48.794867583683555, 52.148512908390586, 50.35614170346941, 44.064221314021516, 46.48409128189087, 54.0619113104684, 53.928095953805105, 25.717167684010096, 0.975012155515807, 0.4053970436964716, 1.4233751765319278, 0.16758744232356548, 21.24458966936384, 51.73498739515032, 49.76297051565987, 56.22159555980137, 49.59019660949707, 42.88120712552752, 39.12682097298758, 25.479283945901052, 41.65763282775879, 41.55078342982701, 0.8017876478178161, 0.08040891028940678, 0.08768921105989388, 0.05090966481449349, 0.05504165130800434, 0.036923046223819256, 0.02088901606787528, 0.04767117662621396, 0.019401277149362222, 0.035582888671862226, 0.07458771086697068, 0.16430834042174475, 0.1869846957602671, 0.18418140975492342, 0.15755694412759372, 0.1470319160393306, 0.08637484801667077, 0.13955284522048064, 0.09100099120821271, 0.18930709042719432, 0.07878848724067211, 0.23759096381919725, 0.15704304884587014, 10.831566759518214, 69.51425334385463, 51.22656338555472, 55.49142674037388, 41.56565604891096, 50.2565462248666, 59.162931306021555, 63.249597685677664, 59.07224341801235, 57.66784225191389, 49.90817744391305, 59.49756349836077, 5.262993795531137, 2.519256566252027, 9.897729737418038, 6.984558079923902, 1.0041974123035158, 35.02844687870571, 60.640153067452566, 52.4224282673427, 58.920494760785786, 55.37039606911795, 55.15418202536446, 53.848740577697754, 56.09336655480521, 51.07200418199812, 54.8859919820513, 51.87898881094796, 49.24672630855015, 45.930868761880056, 50.885705607278005, 50.49391753332955, 52.27136400767735, 47.33236905506679, 38.889241218566895, 37.777571133204866, 38.465276036943706, 40.27909285681588, 39.10908569608416, 37.26439108167376, 38.421318258558, 38.847951548440115, 36.9075003351484, 38.411535194941926, 38.12785414287022, 36.243349824632915, 38.06885698863438, 39.350893429347444, 39.46046652112688, 39.54309449877058, 36.39789860589163, 37.26627056939261, 39.04223360334124, 36.56854983738491, 39.41559852872576, 37.466684409550254, 37.93600395747593, 39.460271971566335, 43.67673764910017, 45.80648558480399, 49.85211590358189, 47.40697186333792, 46.64046743937901, 49.12768282209124, 41.478174754551475, 39.290808882032124, 35.978901386260986, 34.67634344100952, 36.86478281021118, 40.09141159057617, 41.32855919429234, 37.714387689317974, 36.898898465292795, 36.010206495012554, 36.937356744493755, 36.683229855128694, 37.87620081220354, 39.228612082345144, 38.566959449223106, 36.436190128326416, 38.04032073702131, 36.979608740125386, 38.68362317766462, 36.427372864314485, 36.81152139391218, 36.65246670586722, 35.51284401757376, 38.182182107652935, 44.61079093388149, 48.72324207850865, 47.60956743785313, 48.12757648740496, 48.3003226007734, 48.117341790880474, 48.000917775290354, 45.865121432713096, 41.69161646706717, 36.076735496520996, 36.33194283076695, 35.967339583805625, 37.68274906703404, 37.599492277417866, 38.08503586905343, 34.83781957626343, 37.902631759643555, 37.29444204057966, 36.92624657494681, 36.441755635397776, 36.13464525767735, 35.76004007884434, 37.308515616825645, 35.88981853212629, 36.22561802182879, 35.50091743469238, 36.08166176932198, 38.229982239859446, 38.61159815107073, 39.674995626722065, 37.201798234667095, 37.652260371616904, 35.08231626238142, 36.389213357652935, 38.27752876281738, 39.00222587585449, 38.47798081806728, 38.49588285173689, 44.362851415361675, 50.44243138177054, 48.96752337047032, 53.65367685045515, 46.80907590048653, 49.3947958946228, 52.70864888599941, 51.643872192927766, 47.04054124014718, 47.150732721601216, 57.474150793892996, 54.56093788146973, 29.117619548525127, 1.8624961163316454, 0.634127561535154, 7.640469329697745, 0.6978272891470364, 23.355283907481603, 56.03398724964687, 54.78451354163033, 62.800910813467844, 57.30546242850167, 46.77657570157732, 36.868739809308735, 32.78120143072945, 48.24136366162981, 49.205568654196604, 1.6758668507848467, 0.28210489664758953, 0.2053148578852415, 0.17843438099537576, 0.07109856845012733, 0.10755768671099629, 0.1311341119664056, 0.11830431755099978, 0.11719122156500816, 0.07201856015516178], [0.060373114688055854, 0.002146015638053151, 0.021149390310581242, 0.03977590599762542, 0.07544062938541174, 0.03728482073971203, 0.06328990603131907, 0.1003156281741602, 0.05371406700994287, 0.001769030699506402, 0.06865836653326239, 0.07528603875211307, 0.10762423742562532, 0.5205056784408433, 36.65313025883266, 44.53104645865304, 33.88435649871826, 33.42447260447911, 29.526991776057653, 50.04894099916731, 43.86177512577602, 43.75324078968593, 50.12164347512381, 45.082945346832275, 47.161860261644634, 10.87264016696385, 1.5104694345167704, 1.1704392518315996, 9.324470349720546, 8.395363313811165, 31.161145550864084, 49.3239312171936, 52.139740807669504, 54.02343566077096, 49.344299861363, 49.20012821469988, 49.67597906930106, 50.86531959261213, 51.510442461286274, 50.42810072217669, 48.60466759545462, 49.796752657209126, 49.67933504922049, 49.14764847074236, 46.58865819658552, 45.64093780517578, 39.26879004069737, 35.42400435038975, 33.99173048564366, 33.923134395054404, 32.84361709867205, 33.73098891122, 32.32444769995553, 34.33932106835501, 32.727137497493196, 34.72322988510132, 33.391149044036865, 34.154571941920686, 32.903392451150076, 34.594118458884104, 35.768610681806294, 34.20333092553275, 35.36290884017944, 35.609566416059224, 35.91735424314226, 34.93020282472883, 33.354302746909006, 35.17270885195051, 32.8345879146031, 33.23924057824271, 36.606216021946494, 39.70889241354806, 40.748155321393696, 42.72802366529192, 42.13326481410435, 45.83690479823521, 42.76400143759591, 37.38244444983346, 35.81142895562308, 34.34656803948538, 35.53607184546334, 37.92126335416521, 35.43774093900408, 33.92368330274309, 33.94505596160889, 34.38876097542899, 34.08423185348511, 33.82940667016165, 33.02555567877633, 33.23466518947056, 33.07601349694388, 33.63071945735386, 32.596837929316926, 33.382185867854524, 31.88595383507865, 32.887442861284526, 34.40054164613996, 34.95879813602993, 34.818281241825645, 34.93024451392037, 36.23363971710205, 39.734281131199424, 42.724956035614014, 42.705970082964214, 43.83942971910749, 44.95925004141671, 41.93510913848877, 39.88536623546055, 40.723635128566194, 35.671763215746196, 32.262904030936106, 31.79046474184309, 32.32312754222325, 33.17810685294015, 33.31125865663801, 33.74779660361153, 32.37108053479876, 35.04629332678658, 33.551437037331716, 32.20203433718, 32.31853478295462, 33.09638214111328, 33.12854882649013, 32.9155205317906, 33.16130610874721, 32.07922492708479, 32.09515714645386, 34.56261532647269, 32.56630754470825, 34.538122926439556, 34.545171873910085, 34.064797742026194, 36.221424783979145, 38.60622719355992, 39.48194340297154, 40.26548828397478, 39.27986894335066, 40.94604001726423, 40.134486947740825, 41.86742673601423, 43.02062620435442, 45.93194573266165, 46.79150390625, 48.59589202063424, 47.10098361968994, 50.51562717982701, 48.006896700177876, 47.251832485198975, 45.94950383050101, 53.2180769102914, 48.437386240277974, 20.263387645993912, 1.6896274323974336, 1.8703773277146476, 0.3979088126548699, 0.2944601779537541, 31.26156439099993, 50.62881333487374, 45.90473658697945, 50.86618116923741, 50.35102435520717, 34.217883927481516, 24.950338431767054, 17.44607550757272, 41.829482623508994, 15.496020146778651, 0.25554095634392326, 0.03152726450935006, 0.07380725988852126, 0.04082551485459719, 0.02713482065259346, 0.007322650685507272, 0.007544093981518277, 0.01917626306281558, 0.03663582235042538, 0.027704622130841017, 0.05818627096180405, 0.027092184904696684, 0.04793086215587599, 0.02020151081628033, 0.012161383987404406, 0.013075356238654681, 0.025472021395606653, 0.06573360240353004, 0.0017149893080516318, 0.07281595415302686, 0.024427435394110422, 0.040137310711933036, 0.02068797292719994, 1.2417622932365961, 46.151369844164165, 48.90387787137713, 38.80062389373779, 35.6233412197658, 38.04948193686349, 52.71175820486886, 50.549155712127686, 52.068806648254395, 53.42345176424299, 49.96369007655552, 52.557504722050254, 11.83239049570901, 1.784532551254545, 2.948128478867667, 10.639585426875524, 7.18955078295299, 35.03251852308001, 50.16638987404959, 54.40529475893293, 55.37418631144932, 52.24613857269287, 51.243221691676546, 52.041427271706716, 51.48633221217564, 52.905008452279226, 51.20503439222063, 49.31658002308437, 50.18689053399222, 51.130681719098774, 51.49328735896519, 50.40924678530012, 47.45719344275338, 42.20051295416695, 36.23447697503226, 35.90414571762085, 35.050045354025706, 35.96635641370501, 37.2634391784668, 36.31523241315569, 35.41632659094674, 35.44050284794399, 36.210137435368125, 37.02196148463658, 36.89354140417916, 35.3036823953901, 37.89112206867763, 37.33481454849243, 36.3351320539202, 38.28509187698364, 36.59912885938372, 35.174331256321494, 34.927367959703716, 35.61520140511649, 35.96507447106497, 34.62613575799124, 35.207251821245464, 37.73399550574166, 41.51734869820731, 42.69591951370239, 44.49959543773106, 42.70009190695626, 46.594303607940674, 43.94212062018258, 37.83736385617937, 36.429533754076274, 34.39771372931344, 35.64625290461949, 39.57986089161464, 36.29244579587664, 35.22745023454939, 36.10384389332363, 37.326678207942415, 34.95717225755964, 35.249410016196116, 34.9888699395316, 35.28286211831229, 34.70270143236433, 34.989092281886506, 35.478443486349924, 34.62215791429792, 34.5839775630406, 34.916983876909526, 37.03525686264038, 37.61273206983294, 35.91493627003261, 36.225291456495015, 37.17083011354719, 42.85531118937901, 43.65718541826521, 45.11641134534563, 45.18393046515328, 45.091845989227295, 43.322157178606304, 40.39595113481794, 41.96502113342285, 38.08456686564854, 32.126976421901155, 33.099276065826416, 34.818746771131245, 35.80411945070539, 34.28996106556484, 34.837861265454976, 34.054747172764365, 36.30227402278355, 36.36210148675101, 33.42344079698835, 33.04707077571324, 34.11748940604073, 35.76550831113543, 34.07481357029506, 34.33723660877773, 33.02254710878645, 34.63907330376761, 37.195933955056326, 35.518232345581055, 34.963707038334434, 34.876003401620046, 36.653585365840364, 37.8796193259103, 38.85520199366978, 40.539903913225444, 41.431493282318115, 41.95692995616368, 41.65581239972796, 42.42028447559902, 42.56014476503645, 45.61100843974522, 48.84413031169346, 48.73361921310425, 48.05312653950283, 48.115403243473594, 53.144564969199045, 51.86933428900582, 49.85178239004952, 48.217948232378276, 55.24163900102888, 48.88960974557059, 22.825914553233556, 2.390029843364443, 1.9511162638664246, 0.6003785867776189, 0.16185816404010567, 32.95859241485596, 55.35512045451573, 49.898495129176546, 55.44786153520857, 54.02700356074742, 43.05581883021763, 29.71854666301182, 19.626409803118023, 49.83267136982509, 19.92332717350551, 0.21483971178531647, 0.06900799527232136, 0.05173337918573192, 0.026717302788581167, 0.03541007258796266, 0.02177890287046986, 0.037885137634085755, 0.040109260074262104, 0.06305303624165909, 0.003592339959660811, 0.16162268524723394, 0.11297229437955789, 0.11897302738257817, 0.09736989731235163, 0.18108454878841126, 0.09581584855914116, 0.20612307451665401, 0.1986020566629512, 0.19385418428906373, 0.16461783381445066, 0.11418012742485319, 0.1532856747508049, 0.1280938679618495, 1.3645968905517032, 53.99351324353899, 55.26707635607038, 43.40712669917515, 46.340718678065706, 40.84710809162685, 60.164152826581685, 55.36549758911133, 54.48827709470476, 58.31224945613316, 56.60778685978481, 56.08539349692208, 14.58735384259905, 3.261664637497493, 7.81425506728036, 15.181046145302908, 11.301905955587115, 39.52414676121303, 49.4226199558803, 56.940918241228374, 58.06370544433594, 54.8025267464774, 53.68385287693569, 54.75295829772949, 55.175374031066895, 55.3904242515564, 53.726330689021516, 51.464323793138774, 52.43697779519217, 54.03043597085135, 54.20607948303223, 51.93853834697178, 49.79624196461269, 44.12191915512085, 38.68993214198521, 38.378777912684846, 36.57501513617379, 38.673482281821116, 39.46558039528983, 36.16276461737496, 37.176948002406526, 37.90617881502424, 40.90093578611101, 38.19207634244646, 38.421585764203755, 38.789263589041575, 38.622954981667654, 38.79652098246983, 37.81416034698486, 39.222087723868235, 38.30184050968715, 37.98095532826015, 36.500235148838584, 37.136585916791645, 37.65813159942627, 37.13217033658709, 36.71882200241089, 39.30989210946219, 43.62587683541434, 45.1420293535505, 45.43120643070766, 44.6085536139352, 49.30922882897513, 44.96587514877319, 38.8988436290196, 37.617651394435335, 36.473095485142295, 36.968957151685444, 41.62954820905413, 39.494144439697266, 36.87533017567226, 38.93841361999512, 38.27532965796334, 37.86876623971121, 37.71911941255842, 36.10828726632254, 37.04304231916155, 36.60262380327497, 37.01994998114449, 36.69342981066023, 37.710211821964805, 36.43738521848406, 36.358137539454866, 39.70643275124686, 39.20779875346592, 37.13281651905605, 38.4695074898856, 38.64142329352242, 43.83439922332764, 46.436127867017476, 46.26895420891898, 47.97972924368722, 48.52418313707624, 46.09405415398734, 42.54570640836443, 46.83028180258614, 39.85278960636684, 34.944422313145225, 35.52056346620832, 36.52281679425921, 38.120148590632844, 36.39643948418753, 36.40621212550572, 34.058384554726736, 38.58501434326172, 37.8780768258231, 36.48241649355207, 35.86404071535383, 36.66615465709141, 38.267651898520334, 36.80552509852818, 36.430127825055806, 35.32830333709717, 36.45913308007376, 39.45347315924508, 37.4072390965053, 37.03723015104021, 37.88480615615845, 38.734536102839876, 40.61157805579049, 41.77801036834717, 43.62514727456229, 44.35492352076939, 43.80471304484776, 45.90886729104178, 44.98838036400931, 44.839633328574045, 46.83750792912075, 51.51697376796177, 50.71619735445295, 50.28921665464129, 48.685867718287874, 55.02803747994559, 53.40611253465925, 52.21086951664516, 49.86668280192784, 58.929659434727256, 50.853684834071565, 28.064397709710256, 3.8744284425462996, 4.566971463816507, 2.792927001203809, 0.4461862806762968, 39.55412128993443, 59.0817346572876, 54.17497934613909, 60.42063862936837, 58.84347397940499, 44.1675375529698, 34.648922375270296, 27.69777774810791, 57.15646873201643, 26.27610683441162, 0.43198641549263683, 0.16233411564358644, 0.15907566834773335, 0.11590807113264288, 0.13879190890916757, 0.13989232986101083, 0.07611397361116749, 0.17921540194324084, 0.17186487279832363, 0.20369959170264856], [0.05520698315064822, 0.051593872385897806, 0.05640606309420296, 0.021050305538145558, 0.04620720000405397, 0.019172369968146086, 0.01825363694557122, 0.026719380802075778, 0.02480993576214782, 0.061487004560019286, 0.04501883752111878, 0.029684356613350765, 0.12415081954428128, 0.07553640460329396, 17.821827139173234, 48.600255489349365, 36.34321975708008, 48.52481542314802, 25.66487554141453, 43.98935794830322, 47.42861550194876, 38.97124038423811, 48.668538911002024, 45.54484074456351, 50.71528714043753, 16.47707278387887, 1.068228427852903, 0.5594576597213745, 6.007930142538888, 21.664938313620432, 25.196448837007793, 45.74362175805228, 54.980734143938335, 49.63402932030814, 47.974865504673545, 44.82307577133179, 46.15029287338257, 47.56969520023891, 47.66734170913696, 47.19533320835659, 47.917164189474924, 49.72703095844814, 48.60753720147269, 47.946225030081614, 45.98495701381138, 42.90165567398071, 36.36057983125959, 35.768937247140066, 35.15155158724104, 33.278779302324565, 34.8519800049918, 34.270954268319265, 34.30613994598389, 34.00227090290615, 34.1747008732387, 33.79551683153425, 33.408641133989605, 32.97460453850882, 34.72914627620152, 34.67393936429705, 35.6098130771092, 35.242215156555176, 35.58350024904524, 35.77091748373849, 35.259047167641775, 35.79624366760254, 33.53541101728167, 36.16330657686506, 33.14845194135393, 33.71494204657418, 36.22884546007429, 37.38259036200387, 38.54025404793875, 41.57674189976284, 41.11577408654349, 45.18751573562622, 38.67401729311262, 34.74357073647635, 34.71973494121006, 35.3726258959089, 35.7741379737854, 35.566150597163606, 34.46214784894671, 33.14358472824097, 34.0059951373509, 33.49805402755737, 33.68509953362601, 33.75122553961617, 33.75344896316528, 33.43180295399257, 33.35356971195766, 33.67275258472988, 31.957971913473948, 32.17160817555019, 32.56484147480556, 32.26101064682007, 33.12959105627877, 34.170677866254536, 33.378541537693565, 35.05931077684675, 36.74405785969326, 37.5119171823774, 41.137389932359966, 44.17561483383179, 43.825144222804475, 43.02067484174456, 40.58012703486851, 41.45894908905029, 37.69336244038173, 33.45821305683681, 31.548584052494594, 32.787430490766255, 34.239687374659944, 33.18919965199062, 32.31569644383022, 34.255543163844514, 33.79979344776699, 33.738367898123606, 32.35351548876081, 35.273134640284944, 32.24649585996355, 31.516080379486084, 34.626104491097585, 33.0344181060791, 31.66875662122454, 32.89939028876168, 34.65582888466971, 34.44189037595476, 32.87905638558524, 34.51561771120344, 38.539177077157156, 41.690643719264436, 44.08154664720808, 45.191695077078684, 46.1438102040972, 46.845282963344026, 45.18377760478428, 44.89235625948225, 45.36406946182251, 43.42017889022827, 44.387882300785606, 45.90987825393677, 47.61332988739014, 42.27702651705061, 40.055312224796836, 49.23161050251552, 47.82007006236485, 51.142000334603445, 47.17590257099697, 55.346688815525596, 35.40463277271816, 2.796238034963608, 0.7896122325743947, 1.1643811826195036, 1.4175222963094711, 0.38654701518160955, 36.51219299861363, 50.7527414049421, 43.27060154506138, 51.91387571607317, 41.958361285073416, 26.996727091925486, 28.039693389620098, 27.0349908215659, 45.96060357775007, 6.073621886117118, 0.3898968611444746, 0.015669168305716345, 0.06662962825170585, 0.026436453751687492, 0.008805441387396837, 0.03501101257279515, 0.02046706058484103, 0.1139175072312355, 0.09738461473690611, 0.04898500023409724, 0.07318739779293537, 0.060205516538449695, 0.04733231284522584, 0.022443046161372746, 0.03786409965583256, 0.04082784901506134, 0.029367898058678423, 0.012140318867750466, 0.008783619701197105, 0.04431045035432492, 0.07702671856220279, 0.07133407438439981, 0.19140959903597832, 0.017466633015179207, 24.738091809409006, 55.173084599631174, 38.723450251988, 48.27789034162249, 33.16010407039097, 49.84854105540684, 48.43850837435041, 41.65501683098929, 53.901710169655935, 49.35197067260742, 53.7878326688494, 19.081387894494192, 1.592259719967842, 2.1136752324444905, 7.968382613999503, 24.36878115790231, 28.19545636858259, 46.36137914657593, 57.04278925486973, 51.675392695835654, 50.853445121220176, 46.99759095055716, 48.452922412327354, 51.37348999295916, 49.93430961881365, 49.199231897081646, 50.68112632206508, 52.120146887642996, 49.98088686806815, 50.154438972473145, 48.760866573878694, 44.72773259026663, 37.34019940240042, 36.643819672720774, 37.20100266592843, 35.62037781306675, 35.92450393949236, 36.55016837801252, 36.020628792899, 35.81347867420742, 35.099995953696116, 34.945176192692344, 35.3597091947283, 35.08858353751046, 36.38700383050101, 36.98033830097744, 36.57904509135655, 37.48661184310913, 37.20610959189278, 38.19259398324149, 37.10360629217965, 36.28939206259591, 36.641419070107595, 37.88228743416922, 35.462938581194194, 36.84313917160034, 38.4094820022583, 39.79032530103411, 40.30209834235055, 43.78407342093331, 41.68203837530953, 45.44865683146885, 40.23293597357613, 35.01520013809204, 35.297651359013145, 35.20473657335554, 36.26141514096941, 37.47997978755406, 36.44993019104004, 35.58906923021589, 35.03795896257673, 35.97238050188337, 35.30888659613473, 34.72946241923741, 35.52743870871407, 35.77045890263149, 34.65310171672276, 35.667681149074006, 34.033739294324604, 33.72255727222988, 35.001182147434776, 34.62712587629046, 34.626309462956016, 35.76812778200422, 35.45238774163382, 37.08147975376674, 37.54604325975691, 38.93966429574149, 43.414616857256206, 45.96600232805525, 46.26584489004952, 44.13308491025652, 42.86291251863752, 42.729896204812185, 41.377074990953716, 37.22366074153355, 34.02338647842407, 34.83030162538801, 36.34515830448696, 35.33521332059588, 34.442817960466655, 35.66369983128139, 34.246121406555176, 34.864552770342144, 33.70622205734253, 37.99561950138637, 33.710008825574604, 34.42328657422747, 35.22010946273804, 35.91268852778843, 33.63334935052054, 33.708799839019775, 36.037624086652485, 35.39002071108137, 35.90566042491368, 36.721219130924766, 39.82330839974539, 43.054415294102256, 46.44141544614519, 46.78095306668963, 48.6866181237357, 47.669613770076204, 48.341917991638184, 47.46263040815081, 48.09164735249111, 46.09956407546997, 47.66918992996216, 47.311395917619976, 49.32644993918282, 43.28574514389038, 40.786537170410156, 51.48763499941145, 50.18720320292881, 53.35830545425415, 49.076134136744905, 56.90841804231916, 37.93846361977713, 3.7919841579028537, 1.3346156307629176, 0.755212841289384, 0.7267816268971988, 0.4287815046097551, 39.34162105832781, 57.2843051637922, 47.84396144321987, 58.376534189496724, 45.74166931424822, 34.85293538229806, 23.974467413766043, 26.0954258782523, 52.836398465292795, 8.437631811414446, 0.3443761451968125, 0.07002768412764583, 0.129882350564003, 0.04073990748396941, 0.011674475739710033, 0.0464166807276862, 0.1041355903393456, 0.021402270134006227, 0.08318918717226811, 0.07215926796197891, 0.2467261350580624, 0.14404159864144667, 0.1456429005733558, 0.1513478330203465, 0.09365996638579027, 0.17553349451294967, 0.10167385850633893, 0.12405609605567795, 0.08878520117806536, 0.1738452993865524, 0.21011192404798099, 0.08680071016507489, 0.23600430467299052, 0.10996153950691223, 26.792578595025198, 65.29199981689453, 43.15540736062186, 56.57702718462263, 39.07526533944266, 52.96706976209368, 56.4400052343096, 50.025932039533345, 58.634631974356516, 54.2964824948992, 59.734809739249094, 22.839562552315847, 2.1329695114067624, 3.8774396181106567, 10.36915111541748, 27.047574009214127, 31.79893807002476, 48.02373913356236, 58.047669001988, 53.97444043840681, 52.594500405447825, 49.94208117893764, 49.14037023271833, 54.65823698043823, 51.77811138970511, 51.02998147691999, 51.90556219645909, 54.86657871518816, 51.94785588128226, 52.43259695598057, 50.201714515686035, 46.28658178874424, 39.77834660666329, 40.20348950794765, 39.130239486694336, 37.29573440551758, 39.20025300979614, 39.248025349208284, 39.46632037843977, 38.53948279789516, 36.591621330806184, 36.86028732572283, 36.864536149161204, 37.931685652051655, 38.98937865665981, 39.48944398335048, 39.22373792103359, 38.88524947847639, 38.70799398422241, 40.29711300986153, 38.23986257825579, 39.08986350468227, 36.59903505870274, 39.22283118111746, 37.690798555101665, 39.0655517578125, 41.73935406548636, 41.14256634031023, 41.57013068880354, 45.03139666148594, 43.47640371322632, 48.223760400499614, 40.221044131687705, 34.92699275697981, 35.34619147436959, 35.93542650767735, 38.751507077898296, 38.835715770721436, 38.80408757073538, 36.89535140991211, 36.76491982596261, 40.011587211063926, 38.05920246669224, 38.41529417037964, 38.982187271118164, 37.25579268591744, 37.73157058443342, 38.63150821413313, 35.93365819113595, 36.31679228373936, 36.68036372320992, 37.37393290655953, 37.066235406058176, 36.86062778745379, 38.0951316016061, 37.53166743687221, 39.31076063428606, 40.72107124328613, 45.25715405600411, 48.54507637023926, 48.46132973262242, 48.13598033360073, 44.82228715079171, 44.52010999407087, 43.44017233167376, 38.89409106118338, 36.243051052093506, 37.40311186654227, 38.76905475343977, 37.87148298536028, 35.601815700531006, 38.119050775255474, 37.6004650252206, 36.89900268827166, 34.71677153451102, 40.110209941864014, 36.766000270843506, 35.89822237832205, 38.606140341077534, 37.794868673597065, 36.39493867329189, 35.48653466360909, 39.33489520209176, 36.82408026286534, 38.2159538269043, 38.51330893380301, 43.22870390755789, 44.49771247591291, 48.9846784727914, 50.02958679199219, 50.9569593838283, 51.80625854219709, 49.835374219076975, 49.28984682900565, 50.40112434114729, 47.43046719687325, 50.525024618421284, 48.624205929892405, 52.735142367226736, 43.64967788968767, 41.04732738222395, 50.66748353413173, 53.73712818963187, 54.24562515531267, 51.18975182941982, 57.809602873665945, 41.62408692496163, 5.466756667409625, 2.3528144231864383, 3.354183158704213, 2.171071478298732, 0.5470508911779949, 46.1368932723999, 60.96327904292515, 53.514153548649375, 62.40390464237758, 50.42028052466256, 38.63015678950718, 39.87598269326346, 35.26675966807774, 60.0240285055978, 12.27099813733782, 0.688785402902535, 0.17036621964403562, 0.21781003954155104, 0.13873633689114026, 0.14940228313207626, 0.16009900772145816, 0.1806432974657842, 0.18969722092151642, 0.20473593180733068, 0.08339305301862103], [0.008880768952492093, 0.03487266267516783, 0.04071633517742157, 0.02127745870633849, 0.02080256731382438, 0.03952636795916727, 0.032990145297454934, 0.0091274130390957, 0.01227759922455464, 0.0504583304614893, 0.030300778536392108, 0.04050843883305788, 0.06404812141720738, 0.0979731013732297, 2.993592062166759, 43.48704835346767, 38.01296220506941, 35.67385809762137, 31.09644739968436, 32.422118527548655, 57.650635038103374, 51.54437051500593, 46.548032079424175, 44.74376903261457, 47.12996803011213, 24.010742221559795, 0.4799501289214407, 1.3937818216426032, 0.7703178450465202, 1.9180502210344588, 25.602642263684952, 58.85727310180664, 53.95316852842058, 52.446423871176584, 47.380999497004915, 40.630768980298726, 40.840079988752095, 42.0230142729623, 42.76490122931344, 44.50954178401402, 46.30208321980068, 47.24488776070731, 47.855088983263286, 44.890257903507774, 40.92117241450718, 34.147568157741, 33.90264068331037, 36.0891067641122, 34.25935425077166, 35.77031993865967, 32.51678425925118, 34.14040109089443, 34.75050503867013, 34.4825963973999, 32.909027440207346, 34.331118719918386, 32.26991476331438, 36.72067369733538, 32.12895665849958, 35.442007132938926, 35.83264875411987, 35.2046115057809, 35.04029703140259, 35.250643321446006, 33.39894492285592, 33.68721178599766, 34.32700538635254, 35.32985973358154, 32.33994913101196, 33.59931359972273, 36.4172945022583, 37.92346245901925, 39.34802382332938, 38.79989780698504, 41.86127063206264, 44.337632928575786, 39.39599766050066, 34.04729870387486, 37.242129053388325, 36.74263347898211, 35.60962200164795, 34.19524322237287, 32.484958035605295, 32.60634306498936, 32.08184092385428, 31.16890321459089, 34.811913217817036, 34.27537679672241, 33.80837794712612, 33.111716815403526, 32.33245202473232, 35.27310337339129, 33.25312655312674, 32.148689542497905, 33.29461077281407, 34.17203276497977, 32.042118072509766, 33.24191216060093, 34.77674838474819, 35.096949168613975, 35.88649034500122, 37.33927876608712, 36.886822496141704, 42.991586208343506, 43.06632103238787, 41.72186197553362, 40.76026255743844, 39.337688377925325, 38.70820590427944, 38.001581055777415, 31.107557569231304, 32.61252696173531, 35.158374718257356, 32.73882784162249, 32.84130334854126, 33.974380833762034, 32.65469557898385, 34.56453997748238, 32.75370740890503, 33.39420277731759, 31.79386588505336, 33.51760278429304, 32.97303424562727, 32.81496620178223, 32.27560533796038, 33.333934102739605, 32.90464660099575, 34.95652954918997, 32.861383642469136, 38.8285938671657, 41.909293106624055, 45.79998901912144, 47.42478357042585, 47.73354761941092, 44.555184500558035, 48.53287533351353, 46.48062413079398, 46.83263029370989, 45.224289076668875, 49.33690697806222, 44.68896859032767, 49.896942206791465, 46.24716465813773, 46.66749940599714, 37.99179451806204, 42.9304872240339, 45.87577996935163, 52.308019229343955, 49.855867930821006, 51.82717956815447, 11.308752536773682, 1.6537865613188063, 3.694175669125148, 0.3222819593335901, 0.2406929816518511, 2.1507555970123837, 44.398721490587505, 48.85008144378662, 43.93446717943464, 54.374410016196116, 34.52006803240095, 28.83081701823643, 23.548197167260305, 34.46926627840315, 31.369171142578125, 0.41343581091080395, 0.028877588654203073, 0.010262291695523475, 0.10662630240299872, 0.04407804532508765, 0.01288413574054305, 0.02116569211440427, 0.020215037411877086, 0.016948171192780137, 0.037569802054869275, 0.0054711792534882465, 0.019856368890032172, 0.021545418970552937, 0.038104816739048274, 0.029102095535823276, 0.14776577880339964, 0.02975186745503119, 0.0355183396355382, 0.05073308625391551, 0.03392551260601197, 0.02653123321942985, 0.05837983664657388, 0.051889734010079076, 0.07590872355337654, 0.12365567897047315, 6.494809091091156, 52.096943378448486, 41.67793893814087, 42.96944924763271, 36.80928407396589, 38.920059953417095, 59.33455181121826, 53.24664095469883, 49.12316301890782, 49.26026487350464, 50.317092827388215, 25.746127775737218, 0.8590798335415977, 2.744900618280683, 1.3878985430513109, 2.79010277560779, 28.911876440048218, 58.67128372192383, 54.74199404035296, 53.80806234904698, 48.02053253991263, 42.6680885042463, 43.7660984311785, 45.295918055943076, 45.498138427734375, 47.41830437523978, 48.39815671103341, 48.70153938020979, 50.229736600603374, 46.73433065414429, 44.452969551086426, 36.42342628751482, 35.61330107280186, 37.80542646135603, 34.605576038360596, 35.016534192221506, 34.71461064474923, 36.596380846840994, 37.44495044435774, 35.158520630427766, 35.09717151096889, 36.17891223090035, 34.750049931662424, 36.931072098868235, 35.15673841748919, 37.37177201679775, 36.15184899738857, 36.602342401232036, 36.22943953105381, 36.200003487723215, 35.72431244168963, 36.86522054672241, 37.23472227369036, 36.6057504926409, 34.544862679072786, 35.12185846056257, 39.03919724055699, 40.40992048808506, 40.631821632385254, 40.497148173195974, 42.70184632710048, 46.18173347200666, 40.65490007400513, 34.534624508449006, 37.29243401118687, 37.727054255349294, 38.12211840493338, 35.225664547511506, 35.16723019736153, 34.72185066768101, 34.92359161376953, 33.603180272238596, 37.04917063031878, 36.1245356287275, 36.40434306008475, 33.20692103249686, 34.85810136795044, 36.65630211148943, 34.40449169703892, 34.27124956675938, 35.60080473763602, 37.179119314466206, 34.63492522920881, 35.76903452192034, 36.68609251294817, 35.11256871904646, 37.3704240662711, 38.37667955671038, 38.16850110462734, 45.26982757023403, 45.85529667990548, 43.22916943686349, 42.6433424949646, 41.33954777036394, 41.36475583485195, 39.019533838544575, 32.77775512422834, 36.007753780909944, 37.153907775878906, 34.878977230616975, 35.37876810346331, 36.24220337186541, 34.14746740886143, 36.34706905909947, 34.788494314466206, 35.474910327366416, 34.56081574303763, 36.80435085296631, 34.29279245649065, 34.8386081968035, 35.24707889556885, 36.95514760698591, 35.34751510620117, 36.43218101773943, 33.98521307536534, 40.216903005327495, 43.89711018971035, 46.733614989689414, 47.634921414511545, 49.150851590292795, 46.65775455747332, 48.27250896181379, 49.42261300768171, 50.47878435679844, 48.69411523001534, 50.66586112976074, 48.18900203704834, 50.33640881947109, 46.474808488573345, 46.14473778860909, 38.132815156664165, 43.61728538785662, 48.752104895455496, 54.40119532176426, 51.35445192881993, 52.47635323660714, 13.552853056362697, 3.0949033115591322, 5.0467471820967535, 0.22023744428796427, 0.2306047129843916, 2.18675942506109, 49.33816807610648, 53.439540318080354, 47.96272005353655, 58.79605252402169, 40.553015163966585, 36.44290556226458, 23.62442237990243, 36.277590547289165, 40.00978415352957, 1.101287848183087, 0.05986100395343133, 0.026304967235773802, 0.02289445515322898, 0.02635322803897517, 0.03508902035121407, 0.02525460520493133, 0.028087100446490303, 0.0506338403294129, 0.028815919999033213, 0.0354907809357558, 0.0926268764638475, 0.07352872126336608, 0.1121610514819622, 0.1010220916941762, 0.15855918106223854, 0.2655199537319796, 0.15248736473066465, 0.13297394609877042, 0.12172177274312292, 0.08733811668519463, 0.1993536427617073, 0.17722097039222717, 0.18888300604053906, 0.2442270363015788, 7.801148159163339, 64.20315456390381, 47.26166418620518, 41.64928804125105, 45.41438136781965, 44.94430446624756, 63.790737288338796, 60.68354456765311, 55.98204599108015, 54.841773646218435, 53.08114528656006, 30.823685441698345, 1.5641337377684457, 5.758053379399436, 1.7124171980789729, 3.093168867485864, 31.577405180249894, 59.297733306884766, 59.299463408333914, 56.53497321265084, 50.31137098584856, 44.25647449493408, 46.67481238501412, 47.018115929194856, 48.37592942374093, 48.05006585802351, 51.0109086717878, 51.76309633255005, 52.77158914293562, 48.00922434670584, 47.042743819100515, 37.76418890271868, 38.207136562892366, 40.32322086606707, 37.51971306119646, 38.83136967250279, 36.379635265895296, 38.30093029567173, 39.49641302653721, 36.87780720846993, 37.066756520952495, 38.42225973946707, 36.88711084638323, 41.28184298106602, 36.94190781457083, 39.57692180361067, 39.66198859895979, 39.7457526070731, 38.48655489512852, 39.28391974312918, 37.18395873478481, 37.18157550266811, 38.13092177254813, 38.450559752328054, 35.491460936410085, 36.35800552368164, 41.3740907396589, 41.043696948460166, 43.617830821446006, 41.72209126608712, 45.3062778200422, 48.31657443727766, 41.243044240134104, 35.38235684803554, 39.52894101824079, 39.228174345833914, 38.819790499550955, 36.85972799573626, 37.71752827508109, 37.591036319732666, 37.10796628679548, 34.93802302224295, 39.83756610325405, 38.79044130870274, 39.04736137390137, 36.35097394670759, 36.642628056662424, 40.438786779131206, 35.689411640167236, 34.92365067345755, 38.00775800432478, 38.81242888314383, 35.933751991816926, 37.175464562007356, 39.20869507108416, 37.50187703541347, 40.48598936625889, 40.925820759364534, 40.28924764905657, 47.31470673424857, 48.723582540239605, 45.1467958177839, 44.41183621542794, 43.70787600108555, 45.09586899621146, 42.92762109211513, 35.886639731270925, 38.49196406773159, 38.88766050338745, 36.729039328438894, 38.05218826021467, 37.92668294906616, 36.026037965502056, 37.62963356290545, 37.02364294869559, 37.611255577632356, 36.35430908203125, 38.06542110443115, 37.29678705760411, 36.60455540248326, 37.71628107343401, 37.85069050107683, 36.05194432394845, 38.22230448041643, 36.511188983917236, 41.491074085235596, 46.83938046864101, 49.44735206876482, 50.49758618218558, 50.87476914269583, 47.524941853114534, 50.0219680922372, 51.71879461833409, 50.976285798209055, 51.48688459396362, 51.922283036368235, 50.447479248046875, 52.799729347229004, 48.98086043766567, 46.971319811684744, 38.23552342823574, 44.269151483263286, 48.46550907407488, 55.72261415209089, 53.69986500058855, 53.7472517149789, 16.301663773400442, 5.139280251094273, 6.686471675123487, 0.5006181427410671, 0.7731097723756517, 2.424305958407266, 56.533562728336875, 55.94585977281843, 54.14421272277832, 63.783198492867605, 44.196313517434255, 40.03632627214704, 35.189870902470176, 44.35277305330549, 48.31026894705636, 1.9218068080289024, 0.25714441601719173, 0.11443195891167436, 0.19158514961600304, 0.11594643550259726, 0.096429413849754, 0.11951179775808539, 0.07773707687322583, 0.15029634801404818, 0.14525058519627365, 0.10906694536762578], [0.04740736560363855, 0.03157584422401019, 0.09569929659898792, 0.02341613662429154, 0.023287913861817548, 0.027552314767880098, 0.0959216050271477, 0.014549305629251259, 0.033343706146946976, 0.10830372917865004, 0.017303260442401682, 0.005584819026158324, 0.035317371133714914, 0.0368917962935354, 0.21860992376293453, 31.12290961401803, 43.34126125063215, 29.190500940595353, 35.97213731493269, 28.830730165754044, 47.59716490336827, 49.78093160901751, 49.60824455533709, 43.69692216600691, 47.12111949920654, 36.033309255327495, 0.10295928881636687, 0.583915535892759, 0.6434821167162487, 0.1224815012621028, 13.746337805475507, 58.98837171282087, 52.47222253254482, 51.53596319471087, 44.80620901925223, 41.72651726858956, 38.15266963413784, 37.930740697043284, 37.779954365321565, 38.45162977491106, 38.02318300519671, 40.181651319776265, 39.17390544073922, 37.12596212114607, 33.65654591151646, 35.425279344831196, 34.88057879039219, 34.57850933074951, 34.36747169494629, 34.27113144738333, 34.58073970249721, 34.476895400456016, 32.69472762516567, 34.92632572991507, 33.51912096568516, 33.93326486860003, 32.399582045418875, 33.49773441042219, 34.153508867536274, 35.450574261801584, 33.29988445554461, 35.58581747327532, 35.96346596309117, 36.4518826348441, 35.43563910893032, 34.60286624091012, 35.07883868898664, 34.8957918712071, 32.60424470901489, 35.30046190534319, 38.547692094530376, 38.336039543151855, 37.853626114981516, 37.80210869652884, 43.91094752720424, 42.572773115975515, 40.9084780556815, 38.254412106105256, 37.596917969839915, 34.27812480926514, 34.41848884310041, 34.738498551504954, 33.500336510794504, 33.09688588551113, 34.13590213230678, 33.353555815560476, 34.8674327986581, 32.04531076976231, 33.89269086292812, 32.1299398286002, 33.53855160304478, 33.33579274586269, 31.905363627842494, 33.5866505077907, 33.28949689865112, 35.0846334866115, 31.676469121660503, 33.703456674303325, 32.571060112544465, 34.569087573460166, 36.00237587520054, 36.753486565181184, 39.35728924615042, 41.08439949580601, 41.42906141281128, 40.97816153935024, 38.60020310538155, 37.37906762531826, 37.2273849759783, 36.87497929164341, 32.465767111097065, 32.855088574545725, 34.31422070094517, 34.62332173756191, 32.07314872741699, 33.98259013039725, 34.063974380493164, 33.34347397940499, 32.90602234431675, 35.24997976848057, 33.62026589257376, 33.588592529296875, 32.714283330099924, 32.80338702883039, 31.598430429186138, 34.49126080104283, 33.29380825587681, 34.95723131724766, 32.98774358204433, 40.026928833552766, 44.77630744661604, 47.16055052621024, 46.44036974225725, 46.999036175864084, 43.79007319041661, 45.15952491760254, 42.35153899874006, 45.60278524671282, 45.71925442559378, 47.5640914780753, 47.51396369934082, 46.523987838200156, 45.88951655796596, 49.65797976085118, 47.981907503945486, 45.26066289629255, 43.63510056904384, 49.13636459623064, 46.39427886690412, 38.196168831416536, 0.46588360943964546, 4.5767093641417365, 11.012532591819763, 0.2561260978026049, 0.17269700100379332, 6.468823262623378, 52.07091542652675, 41.38987009865897, 50.47738429478237, 47.35684755870274, 36.52941410882132, 22.360041311808995, 23.348549365997314, 40.113829953329905, 15.807360240391322, 0.20223694161645003, 0.08018764001982552, 0.01123846270742693, 0.05544021259993315, 0.10234551996524845, 0.017888712330854366, 0.10005886373775345, 0.05197865941694804, 0.024547349495281066, 0.01816658429535372, 0.03840113298169204, 0.06738754508218595, 0.0075259482587820715, 0.03460642249722566, 0.03882858629471489, 0.05944451915898493, 0.040422258100339344, 0.017910676509408013, 0.052580564083265405, 0.05465856400717582, 0.03881054065589394, 0.019081417437908903, 0.05287256145051547, 0.017471825504409413, 0.036645593254693916, 0.611784000481878, 39.64792544501168, 46.902101857321604, 29.754062380109513, 40.30831698008946, 39.22778524671282, 51.884321553366526, 55.24183702468872, 54.27325814110892, 49.10508728027344, 50.76766613551548, 37.52271120888846, 0.07551591963108097, 2.551373745713915, 2.787959907736097, 0.08104043640196323, 16.20958798272269, 60.14119597843715, 54.64063024520874, 55.22722496305193, 46.74410329546247, 43.873336928231375, 40.57523897715977, 40.9070154598781, 40.14566312517439, 40.14751829419817, 39.73025117601667, 42.21779312406267, 42.03201219013759, 39.88852071762085, 35.030166557856965, 37.160765647888184, 36.27285187585013, 38.41606542042324, 37.06616244997297, 35.68603828975132, 36.627508776528494, 36.24778972353254, 34.635467188698904, 36.408584935324534, 35.647767611912315, 35.26811456680298, 35.2479578426906, 35.7948123386928, 36.04008027485439, 37.093878814152305, 34.720756326402935, 36.746705123356406, 38.709289823259624, 37.17041669573103, 36.40290478297642, 35.309015137808665, 37.30785206386021, 38.115031242370605, 35.25448220116751, 35.369394983564106, 39.057700293404714, 40.061186926705496, 38.21898324148995, 39.973799433027, 43.93668712888445, 44.07010643822806, 42.57176562717983, 40.00708130427769, 38.965570654187886, 36.079563413347515, 35.35392829350063, 36.36858763013567, 35.494264534541536, 35.20840869631086, 34.82781764439174, 35.410639490400044, 36.66664797919137, 35.93351227896554, 35.22435481207711, 34.724171366010395, 35.51588385445731, 35.195769923073904, 34.71322100503104, 34.48357261930193, 35.17256988797869, 36.532103061676025, 34.009385858263286, 35.44111776351929, 34.72508158002581, 37.212842396327424, 36.94045911516462, 37.5529636655535, 39.94994626726423, 41.126439571380615, 43.61042056764875, 43.17807238442557, 40.83809280395508, 39.85739973613194, 39.84295790536063, 38.60184635434832, 34.42449903488159, 35.18956518173218, 34.719067914145334, 35.80278192247663, 34.20841700690133, 35.57281391961234, 35.103463104793, 36.069453784397666, 36.77731541224888, 36.35232537133353, 35.94965641839163, 35.36197778156826, 34.191873346056255, 35.215554918561665, 34.78407178606306, 36.57211773736136, 35.56685931341988, 36.06667797906058, 35.078703199114116, 41.12723166601998, 45.6533716065543, 50.399234431130544, 48.807544572012766, 47.973416805267334, 43.75997359412057, 46.70287963322231, 44.065291336604524, 47.55690704073225, 46.99292870930263, 49.39885016850063, 49.43948323386056, 48.98434843335833, 47.912463733128135, 49.20803526469639, 47.967622007642476, 46.004425866263254, 42.925411564963206, 50.974114486149375, 46.71008144106184, 40.920901434762136, 0.9467178966317857, 6.938942287649427, 11.500837223870413, 0.28495126962661743, 0.08507112440254007, 6.211815910679953, 58.9951878956386, 45.457432406289236, 57.06336981909615, 50.844356877463206, 42.803977898189, 32.00783218656267, 23.616739409310476, 45.18535484586443, 20.188925538744243, 0.2036895358136722, 0.09912179330629961, 0.089976199769548, 0.10325973733727421, 0.04047486152766006, 0.08679385017603636, 0.04603525583765336, 0.07133779275630202, 0.015035855949723294, 0.01011063318167414, 0.030428305800471987, 0.15991896523961, 0.1610500288328954, 0.16411501222423144, 0.12073605135083199, 0.12863679097167083, 0.12984330765902996, 0.13644185715488025, 0.1305938759552581, 0.1183463731514556, 0.20073299588901655, 0.16292459038751467, 0.13725034520030022, 0.10442985740623303, 0.14771349089486258, 0.7137318242873464, 44.9236717905317, 57.46980816977364, 35.126096861703054, 47.086906569344656, 40.693271500723704, 54.552745955330984, 61.188484055655344, 58.51205880301339, 55.62856681006295, 55.23367983954293, 44.46476411819458, 0.27473828622273033, 4.930469512939453, 5.53391752072743, 0.1598939544388226, 19.474376269749232, 61.777719088963096, 57.29935496194022, 56.22767175946917, 48.154903752463206, 45.82260887963431, 41.63958488191877, 43.00029577527727, 41.39750964300973, 42.54555354799543, 41.06401348114014, 43.930180140904014, 43.17010627474104, 42.99052660805838, 37.14026846204485, 39.43363605226789, 38.187344619206016, 40.347855704171316, 38.64801365988595, 38.040331159319194, 39.26895679746355, 38.31517062868391, 37.328960691179546, 37.21333919252668, 37.50962775094168, 38.370964663369314, 39.07192325592041, 38.53086008344378, 38.191596916743684, 39.827435629708425, 36.09896278381348, 39.35117483139038, 41.24231467928205, 40.25664670126778, 38.37445265906197, 38.155726841517854, 38.58743231637137, 39.15459292275565, 37.05225910459246, 38.08607809884207, 41.95185777119228, 41.21027653557913, 41.92513152531215, 40.53891379492623, 45.9047018459865, 43.98587690080915, 43.77097259249006, 41.917398180280415, 42.95279441561018, 38.08666522162301, 36.44393736975533, 39.559460980551584, 37.596369062151226, 36.463861329214915, 36.685682569231304, 37.115953241075786, 38.94868653161185, 36.53218991415841, 38.618942396981375, 38.13058825901577, 38.16547169004168, 37.48491300855364, 35.79923834119524, 38.019587312425884, 37.89270625795637, 39.92409896850586, 34.822870526994976, 36.68712779453823, 36.23837491444179, 37.98274448939732, 39.44053561346871, 39.0285769190107, 41.7429323877607, 42.98823370252337, 46.40111936841692, 45.16295037950788, 43.06783921377999, 40.67147500174386, 41.78871406827654, 40.07629925864083, 37.756347860608784, 37.98657642092024, 36.79543284007481, 38.50859458105904, 36.67310632978167, 37.317683764866416, 37.98086847577776, 37.05731391906738, 37.767718587602886, 38.272737979888916, 38.07153899329049, 37.36353145326887, 35.45445483071463, 36.71520893914359, 36.364001819065635, 38.74332904815674, 37.64083405903408, 38.34104224613735, 37.382416657039094, 45.250358717782156, 48.781078883579795, 52.755910532815115, 49.05941677093506, 49.51558337892805, 44.78474950790405, 47.55272422518049, 44.086688314165386, 49.22215747833252, 49.49646888460432, 51.07830619812012, 51.78973225184849, 51.177700178963796, 48.488410336630686, 52.83467183794294, 47.61437906537737, 46.358975069863455, 44.19507673808506, 51.557245526994976, 48.33897195543562, 43.86715650558472, 2.522457948752812, 8.753919890948705, 15.298819848469325, 0.4852979619588171, 0.7162518490638051, 8.049773812294006, 65.94768047332764, 48.172395842415945, 63.13192299434117, 55.37573575973511, 48.176880904606406, 32.69851439339774, 33.54987021854946, 52.057307379586355, 27.72344265665327, 0.28305967684303013, 0.3097843756633145, 0.19386077964944498, 0.15815444849431515, 0.19834798601056847, 0.1749290283769369, 0.22106964034693583, 0.15619356371462345, 0.1971242752458368, 0.08692838331418377, 0.11740156742078917], [0.08353200341973986, 0.04830942362813013, 0.051330074934022765, 0.02337747878794159, 0.013816252018191984, 0.04584543905886156, 0.06947334815881082, 0.03176249224426491, 0.006125837897083589, 0.02938686989779983, 0.08591824823192187, 0.04969978259344186, 0.0759580394785319, 0.10268094018101692, 0.13865800680858748, 10.96554626737322, 46.77367830276489, 39.09472724369594, 28.851802315030778, 24.342565604618617, 43.94272858755929, 54.70060362134661, 48.26947259902954, 49.13059064320156, 44.09643316268921, 45.395423207964214, 1.2153959423303604, 4.980799223695483, 0.5001037046313286, 0.11418175590889794, 8.43754061630794, 57.66272142955235, 53.05349145616804, 51.13618816648211, 47.19730997085571, 44.030623299734934, 42.28345707484654, 39.536684785570415, 39.60447141102382, 37.784842423030305, 37.51142038617815, 35.60580744062151, 35.18945401055472, 35.38943011420113, 36.29861232212612, 35.69114521571568, 34.8995577948434, 33.82534544808524, 34.14998613085066, 33.8387485231672, 33.9931583404541, 34.199634483882356, 34.367707933698384, 33.46202414376395, 34.18371268681118, 32.815205914633616, 34.0199818611145, 32.923945222582134, 32.86037962777274, 34.670722348349436, 34.482245513371055, 35.859739780426025, 36.03779084341866, 34.11530072348458, 35.81765801565987, 35.646516936165945, 35.510342666081016, 36.53621986934117, 32.70037651062012, 36.5806952885219, 39.31763587679182, 38.198631967817036, 38.227314131600515, 40.14287689753941, 41.31292922156197, 41.145793778555735, 39.280174664088655, 37.57061903817313, 35.62254565102713, 33.5861884525844, 33.22877311706543, 34.60844911847796, 33.62788806642805, 31.441039834703716, 33.51741518293108, 35.249305793217246, 34.644704818725586, 34.300751617976594, 34.23604999269758, 31.670719487326487, 35.08607176371983, 35.6920554297311, 32.597550119672505, 33.35409777505057, 31.1738155909947, 33.58475364957537, 32.46648277555193, 31.95821510042463, 32.95176233564104, 34.43857955932617, 35.48669099807739, 35.25344344547817, 37.17448834010533, 39.312966687338694, 40.51406703676496, 40.20248201915196, 38.7068510055542, 37.50743906838553, 35.697283949170796, 36.968349184308735, 33.81540257590157, 31.345714024135045, 34.19583034515381, 34.74987275259835, 32.189541476113455, 32.401082856314524, 33.789534432547434, 34.987977096012656, 33.09126131875174, 32.71238994598389, 34.2079792703901, 33.42580318450928, 32.7513484954834, 32.162134306771414, 32.12203972680228, 32.2385436466762, 32.746328422001426, 34.08851194381714, 33.62959384918213, 35.07853644234793, 39.752384662628174, 43.91391093390328, 43.924232482910156, 46.23256649289812, 46.39177056721279, 46.3531767981393, 44.9677164213998, 44.86499425343105, 46.060285908835276, 45.85163150514875, 46.51759202139718, 46.648395333971294, 46.64327451160976, 45.101107937949045, 49.225454398563926, 48.87635605675833, 44.5949455669948, 45.634079933166504, 52.26180328641619, 11.897099937711443, 0.052304237482271025, 0.44186811095901896, 0.37232774389641626, 0.12415813415178231, 0.2595734085355486, 14.955757754189626, 52.4281188419887, 42.842728001730784, 51.01013394764492, 45.339590958186555, 29.1848555292402, 20.21243303162711, 29.99937547956194, 35.21988364628383, 2.3950358033180237, 0.08806394559464284, 0.013859700311773589, 0.06252137691314731, 0.043641743915421624, 0.018215594879750694, 0.018759347398632338, 0.044994450972548554, 0.11270378450197832, 0.016414016551737274, 0.00941622383626444, 0.038414174424750466, 0.015986607343490635, 0.029059904228363718, 0.0716060855026756, 0.07553172949701548, 0.031753203099859614, 0.009862841522720243, 0.0112086453342012, 0.0413062569153096, 0.043422885837831667, 0.019715170841664076, 0.025218077968539934, 0.0177743316827608, 0.02143616635086281, 0.12349487974175385, 0.12885005452803203, 16.931139298847743, 55.50453799111502, 38.60435465403965, 33.025632108960835, 32.87851790019444, 49.94106674194336, 57.14385775157383, 52.76146214348929, 52.58189984730312, 48.12588112694876, 48.10750314167568, 1.0234207979270389, 4.04995470387595, 2.455157045807157, 0.1835736595094204, 10.822729519435338, 59.77224663325718, 53.957226276397705, 51.891394819532124, 49.42966195515224, 45.33147546223232, 44.74378292901175, 41.471289089747835, 40.692997046879356, 39.76885884148734, 38.213799885341096, 37.56057889120919, 37.95898859841483, 36.27100712912423, 37.666274888174875, 36.90093428747994, 36.42733464922224, 36.489243098667686, 36.61333792550223, 37.03930418831961, 37.11900002615792, 37.483151640210835, 36.2322952406747, 34.38300091879708, 33.53802701405117, 35.92217629296439, 34.502030508858816, 34.15188646316528, 36.97578723090035, 36.6105169568743, 37.099110807691304, 37.41195344924927, 36.195285660879954, 35.57918541772025, 36.628537109919954, 35.685492856161936, 36.99349124091012, 38.48374087469918, 35.40511219842093, 37.58984817777361, 39.696559361049104, 38.94497619356428, 40.01476601191929, 42.85468932560512, 42.300382886614116, 42.45109278815133, 41.016369683401926, 38.89304535729544, 35.81172425406319, 34.88022790636335, 35.907407896859304, 36.22993285315377, 35.253318377903526, 33.75838565826416, 35.48743792942592, 36.035032408578054, 35.982038497924805, 35.18089382989066, 34.98044177464077, 36.16131591796875, 37.10732357842581, 36.991028104509624, 34.63067293167114, 35.54232175009591, 32.94346271242414, 34.37493406023298, 35.312134878976, 34.480352129255024, 35.05572203227452, 35.07355110985892, 36.35018185206822, 37.16002219063895, 38.88053165163313, 40.91581882749285, 42.629480838775635, 42.17483936037336, 40.84841782706124, 39.15720197132656, 38.39453642708914, 39.68440348761422, 35.22361830302647, 33.079560552324565, 36.11955724443708, 36.34447043282645, 34.962081159864155, 33.71400056566511, 34.445784841264995, 35.912879603249685, 35.217312812805176, 33.66311543328421, 35.816021714891704, 35.863752365112305, 34.45077017375401, 33.301690987178254, 34.55764389038086, 34.65064900262015, 35.056072916303364, 35.32886961528233, 35.33178091049194, 36.264274324689595, 41.66709974833897, 46.003901277269634, 44.78206402914864, 46.57264954703194, 47.482238224574495, 46.45275143214634, 46.03749581745693, 46.05254214150565, 48.07304007666451, 48.03998749596732, 49.147592885153635, 48.11382947649275, 48.36163003104073, 47.46053205217634, 49.45961911337716, 49.291594300951274, 45.00945425033569, 45.40279524666922, 52.140324456351145, 14.139955861227852, 0.025285872098590647, 1.2010545347418105, 0.46142899990081787, 0.12470203425203051, 0.20627240650355816, 16.724115984780447, 60.364844594682964, 46.053250857761924, 57.6841253553118, 47.3698684828622, 40.63773454938616, 25.51373311451503, 29.13506473813738, 45.30454077039446, 4.927696747439248, 0.14114432196531976, 0.03284309997356363, 0.050012482064110894, 0.036592277365603616, 0.011803334628764008, 0.018834992178848813, 0.03408513796914901, 0.047368366803441725, 0.016278730239719152, 0.014016837147729737, 0.006101838961642767, 0.1707080520157303, 0.10667389484920672, 0.14336710769150937, 0.1664806974253484, 0.17514257691800594, 0.19078632390924863, 0.15347793086298875, 0.11063389307154076, 0.14920489729515143, 0.07918080261775426, 0.16143207118979522, 0.1125229209927576, 0.1365652283919709, 0.2709622388439519, 0.3646480031311512, 19.067444596971782, 64.69771344321114, 47.40578719547817, 35.778654302869526, 38.878540992736816, 54.02620104381016, 63.57300158909389, 57.162072454180034, 61.19146483285086, 51.20310279301235, 54.79656171798706, 1.1759916224649973, 9.459778700556074, 5.678436143057687, 0.2833568751811981, 13.994653395244054, 60.445693833487375, 57.03586190087454, 53.95908144542149, 52.34451116834368, 47.61614390781948, 47.259447710854666, 43.447992529187886, 44.74692004067557, 42.30549676077706, 41.73353842326573, 39.82242945262364, 40.13444178444998, 39.712356090545654, 40.443160670144216, 38.28397669110979, 37.93638958249773, 38.56835603713989, 38.98747137614659, 39.09286860057286, 38.96482719693865, 38.9088316644941, 39.657354150499614, 36.49657344818115, 36.32017953055245, 36.03790896279471, 36.93050234658377, 36.16367483139038, 36.782926082611084, 38.90255396706717, 39.72030830383301, 39.841603006635395, 39.27583203996931, 36.710501534598215, 39.51650026866368, 38.40960359573364, 37.42541558401925, 40.55332088470459, 37.120549474443706, 39.36548464638846, 42.98407173156738, 40.9890250478472, 41.07783692223685, 44.53637572697231, 44.541857855660574, 44.32213149751936, 43.08185373033796, 41.41276093891689, 39.61099576950073, 37.0598395892552, 36.75872550691877, 38.31446886062622, 37.64534343991961, 34.56146192550659, 38.88710464750017, 38.44170427322388, 38.532718726566856, 37.803442750658306, 37.64297757829939, 36.52955307279314, 38.572549274989534, 39.82614326477051, 36.455672877175466, 38.69400378635952, 35.80367824009487, 36.379558835710796, 37.3728038242885, 36.19948237282889, 37.89457184927804, 38.35067592348371, 38.64215285437447, 37.379512310028076, 40.92992714473179, 42.38524471010481, 44.060167040143696, 44.817301818302695, 43.312297684805735, 42.25142935344151, 40.66413770403181, 43.25934198924473, 38.546594279153005, 35.36942277635847, 38.813050746917725, 38.550520011356895, 35.50996398925781, 35.00600419725691, 36.88856301988874, 37.48627485547747, 36.66328157697405, 35.902992316654746, 38.43005561828613, 38.58394432067871, 38.27486412865775, 35.928863934108186, 36.021452154432026, 36.285598346165244, 36.64671359743391, 36.86549152646746, 37.369527748652864, 37.84903335571289, 42.33068745476859, 48.805543490818565, 46.78650120326451, 50.18752629416329, 49.76408570153372, 48.637602056775776, 48.13839135851179, 48.126398767743794, 48.945226601191926, 50.64555501937866, 50.233526842934744, 50.7705774307251, 50.08506120954241, 49.811600957598, 51.5473895072937, 51.33467040743147, 46.35342345918928, 47.5288085256304, 52.30608068193708, 19.438773700169154, 0.09413780431662287, 2.422693976334163, 1.2541776384626115, 0.12465460465422698, 0.4939061829021999, 18.058897938047135, 65.8337230682373, 50.918900626046316, 61.07586070469448, 54.49418306350708, 40.9741975920541, 29.566464492252894, 40.20754030772618, 52.9997992515564, 10.321891205651418, 0.32841670300279346, 0.08627600582050425, 0.14975056158644812, 0.1792255256857191, 0.14265472734613077, 0.11769896931946278, 0.1292009792689766, 0.24020142374294146, 0.11204329851482596, 0.10402808325099093, 0.08879062945821456], [0.029836531661983048, 0.0142817270409848, 0.012651782449600952, 0.008915005285026771, 0.020859893344874893, 0.0265104479954711, 0.02354306847389255, 0.06523107258336884, 0.022036232187279632, 0.11948750620441777, 0.031076500125761543, 0.07482907934380428, 0.05499673228976982, 0.07376028490918023, 0.12845700633312973, 1.769314584987504, 44.36135407856533, 36.09058673041207, 26.829758405685425, 28.28735671724592, 28.945780175072805, 50.731396538870676, 46.89824908120291, 47.985253061567036, 42.32955142429897, 48.736085823604036, 4.0813761949539185, 3.1003183467047553, 0.7634866258927754, 0.3375634636197771, 2.727628482239587, 51.03196518761771, 55.997127056121826, 47.866209575108115, 58.094051701681956, 48.577719007219585, 45.91773319244385, 45.0541798046657, 43.278519017355784, 38.00648995808193, 39.2296438898359, 36.57572732652937, 36.190338543483186, 35.4905229296003, 35.28013147626604, 34.547030517033164, 35.385195187159944, 34.28644527707781, 35.21678474971226, 33.66897971289498, 34.41916281836373, 33.24711636134556, 35.48176819937569, 32.87525919505528, 33.22823115757534, 34.42539187840053, 34.42359924316406, 33.782940592084614, 35.0323726109096, 35.04364606312343, 35.73256342751639, 35.400821685791016, 36.191658701215474, 36.07871573311942, 33.4452303477696, 36.237193720681326, 37.184476375579834, 35.40718623570034, 34.73355490820748, 39.22561046055385, 39.36251081739153, 38.036165714263916, 37.542131423950195, 39.849833147866384, 40.319180488586426, 39.40369279044015, 38.90525334221976, 35.49415683746338, 35.49229819434029, 34.28641748428345, 33.57516860961914, 34.77030740465437, 34.51712894439697, 33.4791236604963, 32.799152101789204, 34.788490840366904, 33.57197938646589, 34.962737764631, 34.271537917000906, 33.11001450674874, 33.99010460717337, 33.58675125667027, 34.85018736975533, 32.988990783691406, 32.917441708701, 33.73914609636579, 32.75223786490304, 35.04414980752127, 32.428198201315745, 33.049804891858784, 34.66507346289498, 33.51606723240444, 32.44679505484444, 34.63517883845738, 37.96658992767334, 39.016386304582866, 37.245832443237305, 36.264882292066304, 35.36935329437256, 37.25498669488089, 35.53222254344395, 33.26994814191546, 32.58568607057844, 34.013037136622835, 32.41368341445923, 32.52288130351475, 34.5725234576634, 33.2224954196385, 33.316671303340364, 34.02446344920567, 32.38397639138358, 32.733019147600444, 33.33331571306501, 32.27419832774571, 32.982556751796174, 32.36142601285662, 35.01985543114798, 33.78162738255092, 31.034973212650844, 34.02028063365391, 33.75685358047485, 35.283126149858745, 41.824914182935444, 44.45285490580967, 47.43164144243513, 45.82878930228097, 47.78852524076189, 46.79108354023525, 47.9658328465053, 44.53965527670724, 44.293213094983784, 41.573934827532085, 43.267346314021516, 44.33663586207798, 46.924686976841514, 45.53738880157471, 45.80411624908447, 44.41297919409615, 42.742330006190706, 1.2597493337733405, 0.7195367185132844, 3.1696266276495795, 0.08524283447435924, 0.20602324844471046, 0.051114660421652455, 20.751863377434866, 46.90301207133702, 43.80951772417341, 47.960632119859966, 39.31292847224644, 20.196217673165457, 20.32912802696228, 35.27848127910069, 25.983337538582937, 0.54050639378173, 0.08569532912224531, 0.026811890570180755, 0.026130838186613152, 0.018390354966478686, 0.0031103513028938323, 0.028582904288279157, 0.055802367095436366, 0.07776996546557971, 0.07615334899829966, 0.031129358003714254, 0.11000497253345591, 0.060773104296198914, 0.00880204192695341, 0.022554397150608044, 0.047472871374338865, 0.056938573984163146, 0.018512294494679997, 0.04451041462432061, 0.016758483335641877, 0.05995323043316603, 0.04730420792475343, 0.018310165697974817, 0.04049479688650795, 0.0471004981414548, 0.043807716973658116, 0.20383342594972678, 3.4061734889234816, 51.31474297387259, 40.169474601745605, 28.027627842766897, 32.49424777712141, 38.77932071685791, 54.23794044767107, 51.56620175497872, 52.299820355006624, 47.43351398195539, 52.561426980154856, 4.528640857764652, 2.8277392131941657, 0.7572329214641026, 0.20950126967259816, 3.5816521985190253, 53.82388687133789, 57.84967660903931, 49.90548154285976, 59.446049554007395, 50.07959645135062, 47.65702016013009, 46.03416763033186, 44.10868978500366, 39.80115754263741, 40.28380026136126, 39.128710883004324, 37.991495745522634, 36.49548952920096, 37.125437532152446, 36.291372299194336, 37.12577451978411, 36.88299751281738, 38.02315173830305, 35.56697743279593, 35.47540364946638, 35.808229310171946, 35.834528241838726, 34.83558225631714, 37.14476047243391, 36.06277309145246, 36.09499536241804, 36.98149170194353, 36.075311115809846, 36.647568225860596, 37.36134624481201, 36.85420070375715, 38.31275960377285, 36.59338617324829, 35.16640683582851, 38.366198199135916, 38.21253531319754, 37.00954852785383, 36.99121223177229, 39.03717878886631, 41.08327736173357, 39.3944343158177, 39.60729932785034, 42.20090552738735, 42.21555233001709, 41.90696198599679, 39.77762746810913, 38.29126535143171, 36.84037726266043, 35.99601132529122, 35.03857735225132, 36.184651442936485, 36.368042196546284, 34.49468626294817, 35.149963923863, 36.12008878162929, 34.366842882973806, 36.87803649902344, 35.478367056165425, 36.312706742967876, 35.558406829833984, 35.54419081551688, 36.5779299054827, 34.26299510683332, 35.544447898864746, 33.621426241738455, 34.62018115179879, 35.40064450672695, 33.49335357121059, 36.03647763388497, 34.724966934749055, 34.49504062107631, 36.96276978084019, 36.173110485076904, 40.41098356246948, 41.7687588419233, 38.334715911320274, 38.34574965068272, 37.12019164221627, 39.85168136869158, 36.87041432516915, 35.181793621608186, 35.35782970700945, 35.732466152736116, 34.57072734832764, 32.908818994249614, 35.099745818546836, 34.85527345112392, 35.207595757075715, 34.64529888970511, 35.55998407091413, 34.13889333180019, 34.28658424104963, 34.195312704358784, 35.41008016041347, 33.41326516015189, 35.27841179711478, 35.04956245422363, 34.242654255458284, 35.132701124463765, 35.004906381879536, 38.189102513449534, 43.897263050079346, 46.18177168709891, 48.754495075770784, 47.70556722368513, 49.35616391045706, 47.14000122887747, 48.841733183179585, 46.993168422154014, 48.676147188459126, 44.540687084198, 44.98685870851789, 46.21976443699428, 49.29076051712036, 47.216855253492085, 47.70537614822388, 45.29824570247105, 43.79270655768258, 2.3884345803942, 0.9455576560326985, 4.976369312831333, 0.2555368308510099, 0.14191204362681933, 0.1290449976388897, 24.73263226236616, 53.72497231619698, 48.811786447252544, 54.013854094914024, 43.92163038253784, 31.5548026902335, 20.106816938945226, 37.582587310246055, 36.83623961039952, 0.8471425569483212, 0.05336061811872891, 0.029699535441717932, 0.04585695040545293, 0.01323544215743563, 0.02512972762009927, 0.007364263541863433, 0.027759600430727005, 0.057443437964788506, 0.004280519081346158, 0.03902892375897084, 0.021508194539429884, 0.13806355584944996, 0.11929678358137608, 0.21273972732680185, 0.08030792392258133, 0.09688062606645481, 0.08337876985647849, 0.21490352121847017, 0.14562582863228662, 0.14222820023340838, 0.2709172655429159, 0.15965793281793594, 0.1715891161667449, 0.1512474234082869, 0.17326181355331624, 0.36800425446459223, 5.194436354296548, 60.11133262089321, 48.24624477113996, 34.37537179674421, 37.72598423276629, 40.83084583282471, 59.25560637882778, 54.952111039842876, 58.77518708365304, 50.77988454273769, 58.264216559273855, 4.748898318835667, 6.397931660924639, 5.6211369548525125, 0.6560585732970918, 5.540187835693359, 56.20302997316633, 58.84796251569475, 51.43521778924124, 62.547648974827354, 54.445924350193565, 49.95364645549229, 49.170494147709434, 46.34927885872977, 41.82190561294556, 43.92239815848214, 41.125411237989155, 41.38395023345947, 40.21266113008772, 39.62293277468, 37.990998949323384, 39.57387154442923, 40.34437118257795, 39.42738962173462, 37.817016056605745, 38.44718640191214, 38.1617613519941, 39.698497908455984, 35.56207547869001, 38.06128692626953, 39.326508726392476, 38.718673365456716, 39.14181865964617, 38.1975862639291, 39.32222516196114, 41.28123501368931, 38.37268434252058, 40.91755240304129, 40.53381034306118, 36.5966066632952, 40.09175552640642, 39.58772625241961, 38.067866870335166, 39.193996156964985, 43.566431522369385, 42.36998299189976, 41.90051405770438, 40.82195561272757, 42.80496106828962, 43.22864484786987, 42.16357633045742, 41.58381169182913, 38.50659349986485, 39.75053991590227, 39.780451910836355, 36.92613540376936, 38.19856595993042, 39.150267669132774, 36.79317467553275, 37.856224741254536, 38.447961126055034, 36.038034030369346, 37.90084259850638, 38.52267510550362, 37.600096770695274, 38.09512117930821, 37.50740780149187, 38.95908798490252, 36.86039154870169, 37.95365238189697, 37.22220509392874, 37.100465706416536, 37.65124593462263, 35.82880292619978, 38.68653794697353, 37.82417270115444, 34.92901120867048, 36.15603528703962, 37.022955077035085, 42.40708637237549, 43.411177498953684, 41.54784434182303, 40.157912799290244, 39.555670738220215, 42.6833085332598, 40.50436735153198, 38.16595458984375, 35.77151502881731, 37.0788950238909, 36.632063320704866, 35.42941352299282, 37.38112776620047, 36.50961521693638, 36.84890965053013, 36.889455863407676, 37.44196966716221, 36.97994920185634, 37.145632471357075, 36.91368423189436, 37.744240624564036, 34.20621790204729, 38.24364239828927, 38.336783000401084, 36.10432679312569, 38.06309345790318, 36.484063216618125, 39.23861401421683, 45.22329895836966, 48.51842655454363, 51.66592924935477, 48.95210879189627, 52.2382732118879, 50.70744609832764, 51.025173323495046, 49.80892590114048, 49.73745673043387, 46.86674247469221, 47.180384159088135, 47.93477439880371, 52.39339174543108, 49.54109716415405, 48.85992704119001, 44.042740958077566, 45.807034492492676, 4.454026324408395, 1.7459346566881453, 7.7033843994140625, 0.8989170044660568, 0.3211900607815811, 0.3166547869997365, 27.942453350339616, 58.89111777714321, 54.349000453948975, 56.48614822115217, 49.056300503867014, 31.45155245917184, 29.262633664267405, 44.73077242715018, 47.09231226784842, 1.9172025408063615, 0.2379091696015426, 0.11296846065670252, 0.18730470644576208, 0.14421438079859528, 0.10589693832610335, 0.11187954765877553, 0.13444282513644013, 0.09526081369923693, 0.17477331816085748, 0.16290873980947904, 0.23516522826892988], [0.04813260418762054, 0.03456842792885644, 0.01015396018712116, 0.018419711784060513, 0.027929975484896983, 0.012064385710151067, 0.035750568245670626, 0.01745488418133131, 0.028011236838730316, 0.014577178151479788, 0.04588097393778818, 0.004185948687206421, 0.0025511286096713904, 0.08209905281130757, 0.011292840503821415, 0.23650367930531502, 24.756061588014873, 48.164033685411724, 23.181677954537527, 18.764933926718577, 22.178375448499406, 42.25465331758772, 50.93011849267142, 51.120613779340474, 42.73980433600289, 49.244079044886995, 9.179576090403966, 2.7746434680053165, 0.686617619224957, 0.16961954613881453, 1.1697657108306885, 39.12109913144793, 59.28569207872663, 51.14041614532471, 55.186411244528635, 48.75680187770298, 48.996163845062256, 49.24677842003958, 46.34941782270159, 41.807171957833425, 38.759094510759624, 34.562014307294575, 35.83413219451904, 32.986451217106406, 34.763004847935264, 32.78220197132656, 34.49911226545061, 34.89702517645699, 34.852525438581196, 32.86385025296892, 35.20038005283901, 33.76461124420166, 34.26337725775582, 33.03989328656878, 34.04592990875244, 33.86571448189871, 34.67315074375698, 32.81109952926636, 35.32744870867048, 34.75102962766375, 36.104941708701, 33.96019261223929, 34.50860350472586, 34.42620481763567, 34.99043328421456, 35.079568249838694, 36.54271643502371, 34.00823940549578, 34.9532013620649, 38.267255851200645, 39.23766211100987, 37.95565346309117, 37.87278229849679, 40.06597423553467, 38.83716794422695, 38.11384310041155, 36.3499629838126, 34.60359580176217, 34.44841126033238, 34.65132992608206, 35.63933597292219, 34.236824716840474, 33.12919848305838, 31.208275181906565, 33.74296760559082, 33.683734212602886, 36.8256436075483, 36.36729179109846, 35.60738468170166, 35.17935480390276, 35.62702029091971, 35.03723634992327, 33.980547360011506, 34.03288813999721, 34.75394092287336, 33.71417774472918, 32.95390932900565, 32.24165643964495, 33.11324541909354, 32.33005837031773, 32.52413197926113, 32.87765284946987, 33.93116998672485, 34.94291107995169, 38.210051332201274, 36.025489057813374, 36.62900958742414, 36.14401142937796, 34.717497621263774, 37.35744135720389, 36.29204280035836, 32.59950951167515, 32.4426052910941, 36.180930682591026, 32.56384440830776, 32.48460367747715, 32.679090704236714, 33.40642465863909, 34.577414989471436, 34.93435089928763, 33.14743055616106, 32.5761844090053, 31.645893573760986, 32.07296460015433, 32.498548712049214, 33.60900633675711, 33.25491918836321, 32.628129141671316, 34.226920059749055, 33.07656587873186, 31.849256924220494, 31.52800348826817, 33.49131427492414, 34.951120376586914, 36.95779834474836, 40.34565659931728, 43.83354459490095, 43.93948377881731, 42.59208215985979, 40.33940322058541, 40.74482018607003, 40.266554832458496, 42.08531876972744, 44.821821621486116, 46.94904388700213, 45.50384289877755, 48.57699639456612, 46.029540130070274, 38.039730140141074, 0.9142986876623971, 0.3366387018135616, 1.362072957413537, 0.16853653639554977, 0.03668112474094544, 0.2733776606619358, 29.45960467202323, 47.585707323891775, 42.36173895427159, 44.06422826222011, 30.79277638026646, 26.12137392589024, 25.52865263393947, 38.709779671260286, 12.07652153287615, 0.27139270145978245, 0.0532920962598707, 0.0527091871814004, 0.07926663729761328, 0.0030344454987373736, 0.06838988379708358, 0.0037971756870060092, 0.02632092129039977, 0.03913780827341335, 0.04591572850144335, 0.0730903876413192, 0.02690852922387421, 0.03219866473227739, 0.017216343499187912, 0.018416181705625992, 0.038542597355054956, 0.030742810174290622, 0.0335718160495162, 0.09070713804768664, 0.02376303934891309, 0.03448616912854569, 0.0420416803099215, 0.060421921711947234, 0.012307822870622789, 0.01078464915709836, 0.04153894014390452, 0.024369149236008525, 0.4105941876769066, 35.28203875677926, 49.89906488146101, 29.46098041534424, 22.999970402036393, 28.093303952898296, 47.90591505595616, 53.845978668757844, 55.19656603676932, 45.075465611049104, 53.74139090946743, 9.90199419430324, 2.1443708539009094, 0.7646882842694009, 0.26324156884636196, 1.6243941613606043, 43.037704876491, 61.98772839137486, 51.95142725535801, 56.868073327200754, 50.77168914249965, 51.22444765908377, 50.36611584254673, 48.958139828273225, 42.18006093161446, 41.920629092625205, 36.415154457092285, 38.84563432421003, 35.86026784351894, 36.98846769332886, 34.37126541137695, 36.610746247427805, 35.18544142586844, 36.09537056514195, 34.057807854243684, 37.5577301297869, 35.90635177067348, 37.95280122756958, 34.86849934714181, 35.56640420641218, 34.97308363233294, 35.76970502308437, 35.83049133845738, 36.30893734523228, 35.48217119489397, 37.19838319505964, 35.1394374029977, 36.0541330065046, 35.38610887527466, 37.29092625209263, 36.33253690174648, 38.078740801130024, 36.52049957002912, 36.23158652441842, 40.075660024370464, 41.73895801816668, 40.74157885142735, 39.228011063167024, 40.79909951346261, 40.13318068640572, 39.13546800613403, 37.294959681374685, 36.41670043127877, 35.70126526696341, 36.2817907333374, 37.3789564541408, 36.517438888549805, 34.6198719569615, 33.78461510794503, 36.19123486110142, 35.83354507173811, 37.07739421299526, 38.307732582092285, 36.555831159864155, 36.937408855983186, 36.92249802180699, 37.161210332598, 36.251652921949116, 35.44470303399222, 35.325308663504465, 34.31813601085118, 35.17815623964582, 34.133769035339355, 35.19075679779053, 34.096509320395334, 36.486446448734824, 34.49909489495413, 35.85178756713867, 36.9665287562779, 39.30430228369576, 37.87927886417934, 39.03890194211687, 36.61430025100708, 37.01010438374111, 40.506041867392405, 37.92537668773106, 34.3615448815482, 34.859925270080566, 37.54289919989449, 33.51556348800659, 33.80743299211775, 33.650042397635325, 34.58023248400007, 35.72242947987148, 35.118165493011475, 33.56864425114223, 34.7026493208749, 34.46404818126133, 34.03322860172817, 34.56062814167568, 35.436604908534456, 34.844274452754426, 35.03901856286185, 35.170492376599995, 35.69094719205584, 33.863984380449565, 34.477069105420796, 34.70560577937535, 37.009475571768625, 39.52128062929426, 43.26562316077096, 46.02927957262312, 45.77109146118164, 45.52831792831421, 41.64072438648769, 42.89786195755005, 41.101165499006, 45.09173134395054, 47.900304385593955, 50.26219163622175, 47.41284309114729, 50.4838148525783, 46.44767229897635, 39.02862903050014, 1.4392672266278947, 0.9555669703653881, 3.7620265654155185, 0.2843135824160916, 0.0984846285677382, 0.18243663837867125, 33.44105100631714, 51.986407961164204, 47.409532274518696, 46.460873876299175, 40.155668531145366, 33.70333508082798, 21.417167288916453, 46.139519691467285, 17.200321197509766, 0.21942316155348504, 0.02186190805930112, 0.08857168656374727, 0.10596705813493047, 0.04041576112753578, 0.04546885551618678, 0.0811870474634426, 0.018551544352833713, 0.020368544085483466, 0.0511867276259831, 0.007866067329554685, 0.020759465073102286, 0.10609235641147409, 0.11556355176227433, 0.06265550971563373, 0.15060430791761192, 0.10333512257784605, 0.111206284857222, 0.16678911873272487, 0.14982054568827152, 0.10989036796880619, 0.17049789614975452, 0.14117439463734627, 0.13544317574373313, 0.18377926919077123, 0.21027948148548603, 0.1532056619014059, 0.4911072530916759, 40.00172771726336, 62.74230970655169, 31.617294788360596, 26.240332296916417, 34.95832913262503, 51.13254731042044, 59.07718358721052, 59.8449456351144, 50.93821661812918, 58.5344181060791, 11.458384599004473, 6.541314687047686, 4.362867261682238, 0.9066510551742145, 2.8166412029947554, 44.14675201688494, 62.91775866917202, 54.27101387296404, 58.74504579816546, 52.96308844430106, 54.597440242767334, 52.46777221134731, 52.57220711026873, 45.68070581981114, 44.399888787950786, 38.531818934849326, 41.028758321489605, 36.65405436924526, 39.587691511426655, 35.80790621893746, 38.864783559526714, 37.64455829347883, 39.13020821980068, 36.4744781766619, 40.26449816567557, 39.14347580501011, 39.14956590107509, 37.51681218828474, 38.367622579847065, 38.143216609954834, 38.62710305622646, 37.545765331813264, 38.6033228465489, 37.90730094909668, 39.34549467904227, 37.649397713797434, 37.91482932226998, 36.85572235924857, 39.68416377476284, 38.96063048498971, 40.72415624346052, 36.956849915640696, 39.313849108559744, 43.38076523372105, 44.341680254255024, 42.35069826671055, 41.07336228234427, 42.24894537244524, 41.19376066752842, 41.109899384634836, 39.92967142377581, 38.16310930252075, 37.121765409197124, 38.78792258671352, 40.13257966722761, 37.95594181333269, 35.679986408778596, 34.587337017059326, 39.392099721091135, 37.40568617412022, 40.47490698950631, 40.37781981059483, 39.28119952338082, 38.30462326322283, 39.033826283046174, 39.431030477796284, 37.673844950539724, 37.663530349731445, 37.71232754843575, 37.08734750747681, 36.79401193346296, 36.21475798743111, 37.51885148457119, 36.23343127114432, 37.54502534866333, 36.20870958055769, 38.186684540339876, 38.337015765053884, 42.45950705664498, 39.35255404881069, 40.64918518066406, 39.144945349012104, 39.64346122741699, 42.19060829707554, 40.75822673525129, 36.029098646981375, 36.06264802387783, 39.823746136256624, 35.30501297542027, 36.85088988712856, 36.3218332018171, 36.488068853105815, 37.98482894897461, 37.63948263440813, 35.90074110031128, 37.086503301348, 34.864820275987896, 35.13672760554722, 37.107625825064524, 37.21941886629377, 36.56135845184326, 36.758127961839946, 37.89997754778181, 36.78680665152413, 35.67508792877197, 35.33578307288033, 36.31778587613787, 38.81440217154366, 40.48388753618513, 42.34496600287301, 47.33990090233939, 48.70236274174282, 47.01528453826904, 43.03744084494454, 44.65884467533657, 43.50567299979073, 47.30441992623465, 48.79368986402239, 53.070973123822895, 48.10229546683175, 53.46637078693935, 46.33876623426165, 40.73707294464111, 2.8394638640539984, 1.3060020804405212, 5.923053554126194, 0.4922655395099095, 0.1500694594745125, 0.23434042824166162, 38.25027445384434, 57.152786186763215, 50.88567781448364, 53.22955880846296, 42.35075385229928, 36.63086128234863, 35.47526815959385, 52.39686237062727, 25.94139473778861, 0.32122501890574184, 0.17594954504498414, 0.1321564878204039, 0.13831396241273197, 0.13519370555877686, 0.1347567154360669, 0.18045736529997417, 0.09033022541552782, 0.16357526475829737, 0.1272549679768937, 0.14292566637907708, 0.09812697275940861], [0.03887760027178696, 0.013257518294267356, 0.026161077099719217, 0.03345958296475666, 0.05037223793832319, 0.026156931250755276, 0.009651553351432085, 0.04165304259264043, 0.04146257442023073, 0.012936755283070462, 0.035091551286833625, 0.02606109157204628, 0.02257033933087119, 0.02816694705480976, 0.07414485141634941, 0.08085379177438361, 4.831944056919642, 40.47652244567871, 28.044947964804514, 27.28372417177473, 25.609057188034058, 37.64101818629673, 47.33421032769339, 46.299738202776226, 42.59535823549543, 48.41779579435076, 11.617011104311262, 0.9155892069850649, 0.6107159863625253, 0.08058146852999926, 0.11865820070462567, 33.305825165339876, 62.45329243796212, 49.434035846165244, 53.1283791405814, 46.632112230573384, 49.02353279931204, 44.02631541660854, 46.0436623437064, 41.31211628232683, 40.817633833204, 36.509781973702566, 33.32321650641305, 32.896274021693635, 36.34230259486607, 36.91437905175345, 37.808004243033274, 37.22361210414341, 36.64912462234497, 34.976279803684776, 35.47191565377371, 33.969030720846995, 33.88842119489397, 34.82876607349941, 34.72456741333008, 33.83255073002407, 35.580213751111714, 33.79954331261771, 33.80355937140328, 35.272912297930034, 35.750361238207134, 35.09379121235439, 35.368964195251465, 33.73565115247454, 33.26170757838658, 35.82459579195295, 35.94626917157854, 33.70542648860386, 35.71274716513497, 38.850550174713135, 38.11148418698992, 35.35407420567104, 36.20530496324812, 38.96475771495274, 37.35504770278931, 35.811324732644216, 34.47633607046944, 34.07785340717861, 34.3337208202907, 35.15267719541277, 35.1299010004316, 33.19419888087681, 34.6468448638916, 33.06272506713867, 35.66417925698416, 36.77614116668701, 37.83462279183524, 37.3149288041251, 38.96622378485543, 38.000149726867676, 37.2656626020159, 35.93543692997524, 33.99864741734096, 34.31348071779524, 34.0241368838719, 32.77518776484898, 33.90118156160627, 34.39972175870623, 32.433523995535715, 33.849414008004324, 33.09311301367623, 33.36529132298061, 33.436718804495676, 33.65990536553519, 35.817199434552876, 36.478303159986226, 36.95888573782784, 35.610226494925364, 35.690825598580496, 35.859069279261995, 36.70336920874459, 32.30902617318289, 32.18593883514404, 34.34545980181013, 32.86096327645438, 32.68638283865792, 32.647730009896414, 32.373581886291504, 33.527458803994314, 33.78054346357073, 33.26906224659511, 31.851643630436488, 32.95643152509417, 31.85225854601179, 32.3572883605957, 32.28603458404541, 33.16171257836478, 34.19297463553292, 34.32632098879133, 33.0318055834089, 34.047948360443115, 33.34178556714739, 32.997231347220286, 32.803053515298025, 32.62340784072876, 33.12025267737252, 36.209185532161165, 35.97776882989066, 37.33394602366856, 35.907546860831125, 37.16931888035366, 40.667458942958284, 43.00899491991316, 43.88290112359183, 46.01286792755127, 45.33869811466762, 49.95081159046718, 46.654520171029226, 44.97289282935006, 2.3490487166813443, 0.08716341427394322, 0.7315557992884091, 0.15683878266385623, 0.083314349741808, 0.18688784167170525, 34.437064852033345, 43.59413399015154, 46.097733225141255, 47.088629722595215, 31.310090609959193, 24.4059088570731, 28.23246247427804, 43.285741669791086, 2.510388493537903, 0.13472529926470347, 0.027231879997998476, 0.05229537581492748, 0.035139947797038724, 0.03146134143961327, 0.07603552139231137, 0.04418077891958611, 0.04422773015020149, 0.06603266671299934, 0.02062493872030505, 0.0032833622535690665, 0.0612994371248143, 0.02202139432275934, 0.0626908681754555, 0.0760451430188758, 0.023969181680253575, 0.013231655932031572, 0.05925519431808165, 0.02744027167292578, 0.024216224406180636, 0.03022580380950655, 0.02252827355239008, 0.022806688344904354, 0.006437043318458433, 0.05562821429755006, 0.03709031189126628, 0.03143960457029087, 0.18967411001878126, 9.966280664716448, 52.45631810597011, 27.822216510772705, 25.46134196008955, 30.91031210763114, 44.74493980407715, 52.67172963278634, 55.933564935411724, 44.55030339104788, 55.51341431481497, 13.204121232032776, 1.4923675315720695, 0.6174569332173893, 0.10335262878132717, 0.06641111283430032, 36.25468233653477, 64.7884499686105, 53.36939825330462, 54.08595207759312, 49.69897065843855, 52.29181603022984, 47.002430370875764, 48.559358392442974, 42.26618732724871, 43.23673949922834, 39.35922431945801, 35.03873021262032, 35.22668245860508, 38.0671512058803, 39.3161871773856, 39.5028018951416, 40.34453099114554, 39.12062317984444, 37.62268189021519, 37.860383238111226, 36.58065012523106, 35.395787715911865, 35.51772165298462, 35.55304282052176, 35.67075572695051, 37.43328441892351, 36.02742065702166, 34.90339320046561, 36.845386913844514, 36.82394824709211, 38.087693555014475, 37.89542300360543, 35.29437875747681, 35.0595782824925, 38.620648179735454, 38.63054241452898, 34.564758845738, 38.39834751401629, 40.68222039086478, 40.3435651915414, 37.018428325653076, 38.17428200585501, 39.60605560030256, 39.41877038138253, 36.52748250961304, 36.58543048586164, 35.44486631665911, 34.41653639929635, 36.22803599493844, 36.47288703918457, 34.11580446788243, 36.311119079589844, 34.605565616062705, 37.12336002077375, 38.06541415623256, 37.75342614310128, 39.596498353140696, 39.40892825807844, 38.92933579853603, 38.144512448992046, 37.59857511520386, 34.9929381098066, 34.87967899867466, 36.85205718449184, 34.41200964791434, 33.85960006713867, 36.22155679975237, 34.56914663314819, 34.71538536889212, 34.38157653808594, 34.65452609743391, 35.423646518162315, 35.9639002255031, 36.78313800266811, 38.105307238442556, 39.294692925044465, 37.16307244982038, 37.5355931690761, 37.727175848824636, 39.13437713895525, 35.39381790161133, 35.23149061203003, 35.27050127301897, 34.44937705993652, 34.624165943690706, 35.020466872623985, 34.83604778562273, 35.254760129111155, 36.094536781311035, 35.12858084269932, 33.46270159312657, 35.067485332489014, 34.40572847638811, 34.41057137080601, 33.687437602451865, 35.24038430622646, 35.85643243789673, 36.15216514042446, 33.9341333934239, 34.2329545702253, 35.666402680533274, 34.984391825539724, 35.18821723120553, 35.00783504758562, 34.63363981246948, 38.758496965680806, 38.66531120027815, 38.26096773147583, 40.18601826259068, 40.6704466683524, 42.47721454075405, 45.193359170641216, 45.9854016985212, 47.77874565124512, 47.92350789478847, 51.49824142456055, 48.420397894723074, 46.19150611332485, 3.087958804198674, 0.1325495902981077, 1.8859273961612155, 0.09793214499950409, 0.1522128294621195, 0.27777768884386334, 41.75074563707624, 48.741686071668354, 50.68913759504046, 48.673847334725515, 41.913083348955425, 25.756753308432444, 26.90209436416626, 53.081041063581196, 4.8068345699991495, 0.11750788028751101, 0.02213765281651701, 0.07516293214367968, 0.02657781295212252, 0.030025547769452845, 0.03470663533412984, 0.05620642112834113, 0.05804376503718751, 0.05224494709234152, 0.06117379279541118, 0.027906494780576656, 0.04222349716084344, 0.12189687549003533, 0.15482016812477792, 0.15681225194462708, 0.09671534172126225, 0.1244649812579155, 0.2133608582828726, 0.16936761965709074, 0.1306266491966588, 0.23268982395529747, 0.11652124965829508, 0.07694376087082283, 0.15523647650011949, 0.17245749171291078, 0.11440776235290936, 0.1938152906617948, 0.20074073118822916, 11.552847964423043, 63.324374198913574, 36.18002046857561, 35.502060413360596, 38.868910789489746, 48.87028680528913, 55.17043038776943, 58.556124278477256, 49.76199081965855, 61.25650691986084, 15.967394624437604, 3.2991838242326463, 2.871846377849579, 0.23339764454535075, 0.28511292380946024, 39.40567650113787, 66.4475269317627, 54.72478335244315, 56.01004375730242, 52.26084443501064, 55.04146487372262, 49.313366481236045, 51.14270905085972, 45.167657784053254, 45.6218650000436, 41.21608870370047, 38.21764571326119, 37.84945024762835, 41.2807034764971, 41.554650102342876, 43.15225635256086, 43.27033403941563, 41.260418210710796, 40.235013484954834, 40.19529758180891, 37.96165323257446, 37.041718687329976, 38.1825190952846, 37.9089754649571, 37.81598424911499, 41.61008283070156, 37.09108216421944, 39.15936286108834, 38.78765508106777, 39.06133420126778, 39.87869943891253, 39.40850094386509, 37.17707306998116, 36.72829934528896, 40.26519645963396, 39.48508051463536, 37.60509252548218, 40.334237234933035, 42.4077672958374, 42.61718947546822, 38.08047437667847, 38.8461206981114, 41.99560362952096, 41.22399575369698, 38.42444494792393, 38.52656957081386, 35.87682887486049, 36.35858569826399, 38.105984687805176, 38.54315492085048, 35.8598370552063, 38.93178503853934, 36.74541623251778, 40.04772826603481, 40.80688149588448, 40.60332359586443, 42.35465179170881, 43.27992950166975, 41.173214844294954, 41.33652182987758, 39.9423623085022, 36.80354833602905, 38.1680703163147, 39.35175153187343, 37.00644963128226, 36.119147300720215, 38.30555084773472, 35.769381931849885, 37.22778102329799, 35.19921275547573, 37.06609991618565, 36.94952998842512, 37.612457615988596, 37.91652120862688, 40.35310854230608, 42.374798093523296, 38.644299847739084, 40.17846209662301, 40.021672521318706, 40.74254812513079, 36.41370228358677, 38.10779121943882, 38.17785337993077, 36.61872277941023, 35.9272450038365, 35.88999571119036, 36.42844288689749, 36.85747677939278, 38.41813945770264, 37.6104530606951, 35.77223069327218, 36.70593656812395, 36.75843368257795, 35.037618500845774, 35.261329650878906, 36.6302706854684, 37.8380308832441, 38.5143963268825, 36.96181787763323, 38.43175445284162, 37.786774022238596, 36.37603609902518, 37.75992618288313, 37.4850207056318, 35.98992817742484, 40.271105902535574, 40.16920362200056, 40.18407276698521, 41.56515230451311, 41.56078536169869, 44.95305572237287, 48.415040833609446, 47.20118011747088, 51.09096581595284, 48.95576701845442, 55.01845938818795, 49.965159620557515, 48.675546169281006, 4.286182599408286, 0.18160297668405942, 4.01877943958555, 0.6902969075100762, 0.17155533869351658, 1.320719559277807, 45.034641470227925, 53.509581633976524, 55.68116814749581, 55.214777265276226, 41.22028888974871, 31.639237199510845, 37.221385206495015, 59.79839965275356, 8.188300047601972, 0.3010665034609181, 0.11517887668950216, 0.2979190780648163, 0.08584016242197581, 0.1486064429794039, 0.2608526370355061, 0.13082290866545268, 0.21400184317358903, 0.1626630694206272, 0.11504561241183962, 0.10568708780088595, 0.1309235489794186], [0.03904475398095591, 0.013260184088721871, 0.019716716205169047, 0.05561517285449164, 0.019318122682826858, 0.059025177732110023, 0.08251781069806643, 0.03191173941429172, 0.014453845930152705, 0.10716005840471812, 0.0655214652152998, 0.02953258190037949, 0.033914846035518816, 0.02771925813119326, 0.03511853323185018, 0.061747378802725246, 0.22520711618874753, 21.927260603223527, 38.05835131236485, 36.05240985325405, 28.633364847728185, 32.80097252982003, 40.76452875137329, 47.70553248269217, 44.00925758906773, 45.25563587461199, 15.532374858856201, 0.3593738589968, 0.20376327899949892, 0.1616676856896707, 0.08079223507749182, 29.11217737197876, 66.8294346673148, 48.59988376072475, 54.046083314078196, 44.32619966779436, 46.38988413129534, 43.27163682665144, 43.30186496462141, 40.51857989174979, 40.36909287316458, 37.08076408931187, 37.58806249073574, 37.72501843316214, 39.87093482698713, 37.81682498114449, 40.671791144779746, 39.46342992782593, 39.20456089292254, 35.30793121882847, 34.044380460466655, 33.926778725215364, 36.13689647402082, 34.97856228692191, 34.797770159585134, 35.27682065963745, 35.63465288707188, 34.64578178950718, 35.437445640563965, 34.65889998844692, 37.0958069392613, 35.69079433168684, 37.942076683044434, 35.36979103088379, 35.7470052582877, 36.70770835876465, 36.96901968547276, 32.47502905981881, 35.55337980815342, 39.16896179744175, 38.63993290492466, 36.177981172289165, 36.868309020996094, 38.20777232306344, 37.20865958077567, 33.944256918770925, 37.33599574225289, 35.352886063711985, 35.52751166479928, 35.41968257086617, 34.0770891053336, 32.938730989183696, 33.33834620884487, 34.626774992261616, 37.82612861905779, 37.89838988440377, 41.08119290215628, 40.49254151753017, 41.34409884044102, 38.32334518432617, 38.34647226333618, 37.78699289049421, 36.75952802385603, 35.66001728602818, 35.43754291534424, 32.43932574135916, 31.956964424678258, 32.9405757359096, 32.30360310418265, 33.47465249470302, 33.723453589848106, 32.44208417619978, 34.451933997017996, 33.912107603890554, 34.80085515975952, 35.66102824892317, 35.29111657823835, 33.891888345990864, 33.24075181143624, 37.21872404643467, 35.11272157941546, 32.364552702222554, 33.68036086218697, 34.67474882943289, 33.65338795525687, 32.23241880961827, 33.94555623190743, 32.897465637751985, 33.33939191273281, 33.364822319575715, 33.423621450151714, 33.927654198237825, 31.51526744025094, 32.07553890773228, 32.16344404220581, 31.279244082314626, 32.56369502203805, 33.926601546151296, 35.19772236687796, 33.76377051217215, 35.77938386372158, 35.36061593464443, 36.09045124053955, 36.911064761025564, 35.59803588049752, 34.53239413670131, 35.45614324297224, 32.68319361550467, 35.353236947740825, 32.41748407908848, 36.22531924928938, 39.17882476534162, 44.06448881966727, 41.7808278628758, 45.734272956848145, 42.568263735089985, 48.09752900259835, 45.932102067129954, 48.5149142401559, 4.462257768426623, 0.20582194067537785, 0.8044975538338933, 0.1318476458213159, 0.19549465126224927, 0.41223347399915966, 36.01689761025565, 45.20892660958426, 48.38743911470686, 38.5185478755406, 24.61914038658142, 29.588167190551758, 39.77095719746181, 22.720288038253784, 0.18654736637004785, 0.08385672313826424, 0.056460464639323096, 0.058513508045247624, 0.05805078787463052, 0.022582897317728827, 0.01587753962459309, 0.04452411424634712, 0.029993748225803887, 0.04945317582626428, 0.023857942649296353, 0.04278384494994368, 0.042562971623348336, 0.05840288648115737, 0.05105809774249792, 0.03633442048781684, 0.05106760062543409, 0.0444880297540554, 0.018795640540442297, 0.052402017771133354, 0.01958610669576696, 0.021180056700749055, 0.022173733916133642, 0.013988626206160655, 0.047478126628058295, 0.03296475451705711, 0.036564274225384, 0.013156005214633686, 0.06266585058931794, 0.6475977301597595, 36.46665450504848, 42.06184080668858, 37.08549233845302, 32.61919723238264, 41.97160107748849, 45.521136965070454, 51.35928092684065, 48.551986353737966, 52.415938649858745, 17.32259038516453, 0.6570350666131292, 0.7723918280431202, 0.0815578939925347, 0.1416315236794097, 31.192134516579763, 66.17769363948277, 49.80664689200265, 56.94382953643799, 48.051382541656494, 48.08706154142107, 46.38873420442854, 44.92194863728115, 42.68736975533621, 42.14380175726754, 40.2054488999503, 38.24202346801758, 40.01320266723633, 40.154192038944785, 39.615258489336284, 43.26185028893607, 40.35267775399344, 40.99447938374111, 37.2707382610866, 35.97415576662336, 36.63468279157366, 37.6352025440761, 36.65014253343855, 36.04408243724278, 36.57174948283604, 37.688655035836355, 37.18449027197701, 37.577330998011995, 35.52012572969709, 38.76370811462402, 37.53811536516462, 38.721605505262104, 37.25281538282122, 37.26108373914446, 38.54647615977696, 38.69388566698347, 34.126848629542756, 37.575781549726216, 41.98759235654558, 40.086638178144185, 38.45608009610857, 39.144729954855784, 38.40429517201015, 39.016626017434255, 36.21168340955462, 38.00728900091988, 36.47780636378697, 38.265928745269775, 37.235962527138845, 36.76368999481201, 35.35388660430908, 36.381521701812744, 35.46214996065412, 39.80893605095999, 40.27776575088501, 41.55282967431204, 42.46823051997593, 41.90219552176339, 39.894808837345664, 40.911528314862935, 38.9365028653826, 38.48720802579607, 38.276740142277305, 36.30396243504116, 34.74240691321236, 34.47434193747384, 34.128512723105295, 34.30649083001273, 35.340956006731304, 35.78899669647217, 34.4104254586356, 34.85626009532383, 37.54777683530535, 37.726592200142996, 37.92922598975045, 36.39429596492222, 34.990739004952566, 34.71629210880825, 36.88529736655099, 37.01678160258702, 34.04894542694092, 36.73982988085066, 36.53479896272932, 35.67632123402187, 34.11309119633266, 34.95754051208496, 34.71507269995553, 34.47732966286795, 34.7132487978254, 35.652426379067556, 34.90530048097883, 33.67614330564226, 34.11070449011666, 34.930522441864014, 34.29245546885899, 34.171800000326975, 35.60933712550572, 36.848002910614014, 36.96133845193045, 37.59020948410034, 36.591082845415386, 36.793414388384136, 38.521563393729075, 37.41405527932303, 35.03363370895386, 37.03228303364345, 33.570516790662495, 37.61527163641793, 34.40008306503296, 38.02656330381121, 42.196364879608154, 46.02498211179461, 44.20049633298601, 47.51767403738839, 45.14242192677089, 49.879029750823975, 48.99564273016793, 49.864716461726594, 5.281718322208949, 0.20273400922971113, 1.2721638104745319, 0.13157726318708488, 0.06059051052268062, 0.26552967035344666, 39.90033265522548, 49.63343524932861, 53.49664061410086, 46.198155539376394, 37.0779709134783, 21.329547030585154, 42.543361391339985, 30.2427430834089, 0.4069028486098562, 0.12798937356897763, 0.07691252790391445, 0.014972704695537686, 0.06498069994683776, 0.04060892986931971, 0.05582770698570779, 0.044834686509732685, 0.014207025424444249, 0.0411732165542032, 0.020090237858572176, 0.029817044136247466, 0.027406180377251337, 0.08875437533216816, 0.11947683963392462, 0.12223146110773087, 0.25867030556712833, 0.15876249729522637, 0.10827358865312167, 0.18235651696366922, 0.1409690427993025, 0.12088566832244396, 0.1526021050023181, 0.08949564769864082, 0.143097403592297, 0.14455488324165344, 0.1271129505974906, 0.1268040407449007, 0.14904137035565718, 1.0401632423911775, 46.778823443821494, 51.77182674407959, 43.34132725851876, 36.41097164154053, 43.60044642857143, 50.46203919819423, 57.46353742054531, 54.1413848059518, 58.89536312648228, 20.858783994402202, 1.2827163870845522, 1.209360020501273, 0.46009288302489687, 0.27977803722023964, 34.607368673597065, 68.44951139177594, 53.564868450164795, 59.87088326045445, 49.61043323789324, 50.93660463605608, 47.73787634713309, 46.40262017931257, 46.18865040370396, 45.96914986201695, 42.31381375449044, 41.09111840384347, 43.109879289354595, 44.0595451763698, 41.2844694001334, 45.52222783224923, 43.209936823163716, 44.9311306817191, 37.62141384397234, 37.2496018409729, 39.1703062738691, 40.49922568457467, 39.18026999064854, 38.25697946548462, 38.026010922023225, 39.41496624265398, 39.293688910348074, 39.59779071807861, 38.47653559276036, 40.98670782361712, 38.99648666381836, 41.294040543692454, 39.860116481781006, 39.20813226699829, 40.6678341456822, 39.54994542258126, 36.34323017937796, 40.041933468409944, 44.175517559051514, 41.6537765775408, 40.278505734034944, 40.03195238113403, 40.7496839250837, 39.886637755802695, 37.611769744328086, 41.012714930943076, 38.90144920349121, 38.73396635055542, 39.5930346761431, 37.30516311100551, 36.58378376279558, 38.95968552998134, 37.76203843525478, 41.84205191476004, 42.251425879342214, 44.54424803597586, 45.61913783209664, 45.193435600825715, 42.81860038212368, 42.502377441951204, 41.44085945401873, 40.57865054266793, 39.362257208142964, 38.47492708478655, 35.99424300874983, 35.28382444381714, 37.19446441105434, 35.951167651585166, 37.576191493443076, 38.96289907182966, 36.300057547433035, 36.72946316855294, 37.537670680454795, 38.90944658006941, 39.3800550188337, 38.300829546792166, 35.94879136766706, 36.80258253642491, 42.344226019723074, 39.47040244511196, 35.86989457266671, 38.44013398034232, 38.403252942221506, 37.52676895686558, 35.10049622399466, 39.137142521994456, 36.07783331189837, 36.811583927699495, 37.78325475965227, 37.11857966014317, 37.237557138715474, 36.57368108204433, 36.844858850751606, 36.222991602761404, 35.019893646240234, 35.96672119413103, 38.11785568509783, 40.902891704014365, 39.28830753053938, 40.43767506735665, 38.873976026262554, 38.76547295706612, 42.64664288929531, 39.24723325456892, 38.03823280334473, 39.95917347499302, 35.8358588218689, 39.34889234815325, 36.59895168031965, 39.52733251026699, 44.19122396196638, 48.495601722172324, 45.73635394232613, 50.433760029929026, 47.956070627485005, 51.42729336874825, 50.55867821829659, 50.67632164273943, 7.412866319928851, 0.37511945409434183, 4.175006210803986, 0.35156932207090513, 0.3861256720764296, 1.1625795364379883, 46.28222179412842, 54.331650802067344, 56.9497389793396, 47.125896385737825, 34.976821763174875, 38.89140905652727, 49.33206755774361, 37.64705964497158, 0.427175547927618, 0.21652786619961262, 0.15144451068980352, 0.10403389151075057, 0.1837286233369793, 0.10716651805809566, 0.13457497661667212, 0.13955418871981756, 0.1281817246760641, 0.10577062224703175, 0.10803172484572444, 0.07264405409140245, 0.11263558494725398], [0.07778125628829002, 0.012046985527766603, 0.030068719560014348, 0.03474131186625787, 0.021636821030239974, 0.0778918642816799, 0.014746745748977576, 0.05499099188351205, 0.049054709529238086, 0.0567333646384733, 0.056370161806366274, 0.030798589145498614, 0.08332437848938362, 0.020701477470408593, 0.044293778748916726, 0.08064316093389477, 0.08196950012019702, 7.254300177097321, 32.809887068612234, 39.64373568126133, 44.12185662133353, 22.84651075090681, 34.86010592324393, 53.69377837862287, 43.8183627809797, 46.53162043435233, 22.89742020198277, 0.12786083189504488, 0.7286482495920998, 0.26729239576629227, 0.04460861221221941, 19.298289809908184, 66.60652950831822, 46.0256039755685, 52.04380355562483, 39.283433369227815, 42.93869999476841, 39.48558078493391, 41.246261256081716, 36.981922490256174, 39.71712602887835, 36.57448707308088, 41.165953976767405, 38.04014008385794, 40.30078860691616, 40.313778264181956, 42.67542232785906, 40.306444440569194, 40.37328263691494, 36.93528618131365, 36.03844744818551, 35.53769077573504, 37.71430778503418, 34.34461906978062, 36.388629708971294, 34.96776826041085, 35.68400594166347, 34.59549420220511, 37.19896336964199, 37.373345783778596, 35.95046935762678, 35.70472894396101, 38.10267734527588, 35.8462359564645, 35.00464929853167, 35.91226121357509, 36.85638591221401, 34.67285891941616, 36.14099938528878, 35.6842873437064, 37.47551556995937, 35.8918057169233, 35.68383918489729, 34.20214278357369, 38.21518605095999, 35.197854382651194, 34.52300712040493, 33.43345662525722, 36.426730155944824, 36.134864125932964, 35.16266175678798, 34.77570962905884, 33.10019670213972, 35.91409206390381, 40.12267848423549, 41.81985936846052, 42.691608156476704, 41.10179083687918, 41.659995215279714, 42.98430102212088, 38.74035521915981, 36.955741677965435, 39.57219702856881, 39.1642370223999, 38.64745085580008, 35.477029527936665, 32.48521511895316, 32.97435440335955, 33.38723373413086, 33.31582709721157, 31.651865550449916, 32.419957637786865, 32.77605281557356, 33.510901246752056, 36.29573924200875, 34.358619689941406, 36.011787210192, 33.6793429510934, 34.5111083303179, 34.521402086530415, 34.504472800663535, 32.99262121745518, 32.41319356645857, 34.11765268870762, 33.74476024082729, 34.34124571936471, 34.23200266701834, 33.55070400238037, 33.58682073865618, 34.48703977039882, 34.34828424453735, 33.78337138039725, 32.98882055282593, 32.82624660219465, 33.25053487505232, 33.71091556549072, 33.52809109006609, 35.68310962404524, 35.23553098951067, 34.554440770830425, 36.39403540747506, 38.43141399111067, 39.52559546061924, 38.305286816188264, 37.53676741463797, 35.30350521632603, 36.01883268356323, 33.741908005305696, 36.073261397225515, 33.12399775641305, 38.331116744450156, 37.915836811065674, 39.78886270523071, 38.62310436793736, 41.70955671582903, 41.158613204956055, 48.58073105130877, 44.4147891998291, 51.19662012372698, 6.796892881393433, 0.520010022180421, 0.6641078985163144, 0.06540950693722282, 0.18470785793449196, 0.5352531213845525, 37.323891980307444, 46.26219013759068, 43.08102342060634, 31.944040775299072, 23.589895044054302, 28.8129723072052, 44.10133511679513, 6.412861602646964, 0.17110982617097242, 0.10025555068360907, 0.015316486159073455, 0.11202339029737882, 0.01040477811225823, 0.037542843858578374, 0.01035583792586944, 0.025954276589410644, 0.019820240292964236, 0.03199477852987392, 0.04973369577367391, 0.04311822700713362, 0.028791072046650306, 0.06923375744372606, 0.006520632471490119, 0.04399256009076323, 0.022062547471640364, 0.052234233024397066, 0.03635334822216204, 0.031350350073937855, 0.042405429362718544, 0.061422801576554775, 0.042167436597602706, 0.036423831047224145, 0.039814453572034836, 0.01620200489248548, 0.03845339035615325, 0.052073345586125336, 0.13098730412977083, 0.20314380366887363, 13.631280847958156, 41.37854453495571, 38.504154682159424, 42.16556698935372, 32.94938257762364, 39.674172265189036, 56.61078500747681, 47.97748497554234, 52.28911318097796, 25.60486047608512, 0.22177125912691864, 0.37514363708240644, 0.27152211165853907, 0.06095919931041343, 20.88062391962324, 69.06278719220842, 49.08332552228655, 53.6507169178554, 42.92836454936436, 45.11434078216553, 41.878071376255576, 44.512112617492676, 39.74417536599295, 40.526535579136436, 37.535329137529644, 42.95278746741158, 41.928046294621055, 42.20551913125174, 41.87249892098563, 44.40113598959786, 44.02079159872872, 41.54292849131993, 39.99630812236241, 38.48046132496425, 36.99483224323818, 38.94467394692557, 37.08883442197527, 38.00272403444563, 36.50398370197841, 38.91522053309849, 37.39265135356358, 38.63374553407942, 38.176335198538645, 37.885414123535156, 37.65771470751081, 39.913770471300396, 36.62360041482108, 35.99742528370449, 38.23230988638741, 38.43760483605521, 36.061286176954, 37.50630651201521, 38.44888176236834, 38.2692881992885, 38.09185552597046, 39.087584495544434, 35.94548055103847, 39.21935708182198, 36.328750133514404, 36.87269680840628, 36.80917985098702, 36.817271028246196, 36.97218458993094, 35.57943902696882, 35.25568771362305, 33.20124088014875, 36.244471958705354, 41.496097632816856, 42.36493859972273, 44.3930378641401, 43.75597837993077, 44.289002486637656, 43.97326592036656, 41.42667818069458, 38.47881460189819, 41.68257686070034, 40.824859959738596, 41.0738069670541, 36.641342639923096, 35.21610382625035, 35.20343378611973, 35.00255789075579, 33.9650285584586, 34.2084413255964, 34.27640165601458, 34.67369270324707, 35.25759499413626, 36.55970825467791, 35.757993834359304, 37.23170328140259, 36.71745320728847, 36.74665648596627, 36.119814327784944, 35.717485836574006, 34.27796152659825, 36.42780365262713, 36.47465188162667, 34.94289370945522, 34.357511452266145, 36.254539898463655, 35.0633476802281, 36.205395289829795, 36.924606800079346, 35.694622789110454, 35.11022022792271, 36.36347028187343, 34.489784308842246, 35.3024525642395, 34.57302720206124, 35.24176352364676, 35.71922288622175, 36.890220165252686, 38.127934047154014, 40.309567655835835, 39.40239347730364, 40.81231846128191, 39.949956689562114, 40.11197478430611, 37.28513492856707, 37.786377974918906, 36.00858409064156, 37.135543687003, 36.41427550997053, 39.406600611550466, 38.798963274274556, 43.5574231828962, 40.50825834274292, 44.1060459954398, 42.174422468457905, 51.76676150730678, 46.23384148733956, 53.054749080113, 7.495791333062308, 0.4331824284579073, 0.2871663879070963, 0.016486251693485037, 0.3610509804316929, 0.7127052822283336, 41.14846188681466, 51.19894082205636, 48.94677604947771, 39.53367274148123, 29.159056867871964, 24.352459839412145, 51.759174074445454, 8.400511928967067, 0.19296914392283984, 0.01936855649442545, 0.037257686124316285, 0.0711047634748476, 0.023409548049260463, 0.009690210339613259, 0.022432026752669896, 0.05752486216702631, 0.0328937729687563, 0.05890978606683867, 0.055500592038567574, 0.02959331078454852, 0.02101820913542594, 0.17197668179869652, 0.10593480058014393, 0.13334211919988903, 0.125488564904247, 0.10477189333843333, 0.23199722969106265, 0.09106311787452016, 0.1355668862483331, 0.17394006358725683, 0.16385773888656072, 0.15967336270426, 0.11328162492385932, 0.1682350090039628, 0.26821012794971466, 0.13933354270245346, 0.20860962037529263, 0.2723674034433705, 20.06262813295637, 52.46227271216256, 45.810720511845176, 49.203331334250315, 35.04823187419346, 41.87925951821463, 62.47238608769008, 52.82057741710118, 57.57832860946655, 30.427961213248118, 0.7093739467007774, 1.441644161939621, 0.6952791458794049, 0.15370553864964417, 22.583556175231934, 68.82398455483573, 50.21116406576974, 56.238618646349224, 43.19213553837368, 47.31549882888794, 43.32919570377895, 47.04134028298514, 41.838094915662495, 43.13697031566075, 40.02730056217739, 45.922371115003315, 43.82398387363979, 46.19452510561262, 45.06111410685948, 47.320074217660085, 46.32905265263149, 45.128942421504426, 42.73691388538906, 40.52252646854946, 39.56787177494594, 43.038809640066965, 40.067499365125386, 40.08599546977452, 38.538576057979036, 40.2692403112139, 38.20473943437849, 40.868960176195415, 40.89428636005947, 39.78096955163138, 38.62824603489467, 41.497966698237825, 38.08076272691999, 37.10630219323294, 40.837394509996685, 40.526681491306846, 37.90088776179722, 39.08781726019723, 39.83021143504551, 41.57685307094029, 40.73610714503697, 40.781517096928184, 38.627176012311665, 43.15023790087019, 38.02546548843384, 38.35831894193377, 37.433791637420654, 39.81798260552542, 39.621324266706196, 37.500918184007915, 37.55778224127633, 36.53269713265555, 39.58793817247663, 44.41979537691389, 44.05579662322998, 47.05872467585972, 46.458369050707134, 45.54137359346662, 47.07886055537632, 42.62348454339163, 39.7329957144601, 43.69443471091134, 43.60558809552874, 43.491279806409565, 39.32576526914324, 36.38870961325509, 38.43721226283482, 37.784046854291645, 36.40564932141985, 35.28012800216675, 35.54653583254133, 36.129642554691856, 37.72914913722447, 39.84955869402204, 37.405623640332905, 40.364482743399485, 37.48998866762434, 39.028347628457205, 38.86868497303554, 37.598536900111604, 36.83978319168091, 37.52623741967337, 39.47450188228062, 36.98771381378174, 38.86914702824184, 38.99035835266113, 37.95312779290335, 37.160751751491, 39.63416453770229, 37.316509519304546, 37.52941969462803, 37.34353453772408, 37.203111444200786, 37.769382681165425, 36.73281914847237, 37.24983460562569, 40.04167985916138, 39.1432569367545, 39.98120273862566, 39.95749201093401, 41.523025376456125, 43.68219893319266, 41.68351139341082, 41.618781975337434, 38.62439325877598, 39.76051752907889, 38.1465482711792, 39.21054676600865, 37.53446408680507, 42.00318758828299, 40.983035700661794, 44.2688318661281, 41.843003817967, 46.74297768729073, 46.91738789422171, 54.19486856460571, 48.866711957114084, 53.49672051838466, 9.503871968814305, 0.799539634159633, 2.659486413002014, 0.17550015130213328, 0.9291877001523972, 0.9191258400678635, 45.93149757385254, 55.68290172304426, 53.65540000370571, 40.381683009011404, 34.98740039552961, 35.700327260153635, 57.9984062739781, 12.748211707387652, 0.4305660788502012, 0.23269367803420338, 0.1463321835866996, 0.20573253690132073, 0.11896960756608418, 0.10775083848940474, 0.17536700916077408, 0.14925348040248665, 0.11293019128165074, 0.10412066256893532, 0.10727999625461442, 0.1566773456122194, 0.198782994811024], [0.030942245186971765, 0.04917115631646343, 0.06756603371884141, 0.04261934770537274, 0.04299685066299779, 0.014808521273412874, 0.04192578313606126, 0.03404919257653611, 0.03850713711498039, 0.03569585457444191, 0.043397573088960986, 0.023752835878570164, 0.044090598222932646, 0.03928413435018488, 0.014398165346522416, 0.11529263987072877, 0.0544781449383923, 0.6507740882890565, 34.83026341029576, 48.99462481907436, 52.41910008021763, 26.930873802730016, 22.61639509882246, 46.26856510979788, 47.016966002328054, 44.85930020468575, 28.64261290005275, 0.037484442349523306, 1.0058501064777374, 0.18445519863494805, 0.09362916089594364, 8.195953488349915, 65.37159837995256, 49.56659705298287, 55.48884548459734, 44.190362385341096, 39.96524620056152, 37.68058122907366, 39.304854665483745, 36.120707171303884, 39.79574837003435, 37.1182530948094, 38.828090122767854, 40.35139928545271, 42.78827844347273, 41.1414407321385, 41.46978827885219, 40.65610211236136, 39.91069936752319, 36.30120052610125, 35.50763634272984, 35.57436336789812, 35.582461493355886, 34.800368785858154, 35.70785910742623, 35.122306619371685, 37.301570892333984, 34.23704011099679, 35.85237121582031, 35.793881280081614, 37.50040054321289, 35.67874615533011, 35.65108190264021, 35.413401399339946, 34.74489436830793, 34.52595663070679, 38.132617133004324, 34.510500362941194, 36.247133118765696, 36.18372733252389, 35.35895184108189, 35.08896916253226, 35.89873654501778, 34.821018832070486, 34.81653724397932, 35.72421169281006, 35.18465975352696, 35.838575567517964, 36.10435806001936, 36.91120719909668, 35.51730128696987, 33.96030725751604, 33.9648756980896, 34.501721314021516, 43.44060659408569, 43.98477561133248, 44.33993625640869, 44.08139031273978, 46.025152342660085, 43.22227334976196, 41.70026697431292, 41.278358459472656, 41.03426129477364, 42.23459734235491, 41.268888064793174, 38.76339544568743, 34.39930139269148, 33.96071720123291, 32.374130793980186, 33.43722602299282, 33.24989216668265, 33.152877943856375, 34.5883549281529, 32.98224408285958, 33.84760052817208, 33.56889091219221, 34.430307728903635, 33.987168993268696, 34.67440141950335, 33.275527545383994, 34.568410124097554, 32.73920999254499, 32.43590375355312, 32.876346588134766, 32.70032092503139, 32.40892737252371, 35.12657628740583, 33.08421237128121, 35.2319735118321, 34.0266695022583, 33.81298112869263, 33.41260855538504, 31.47769158227103, 32.09479931422642, 33.068679673331125, 33.24520213263375, 36.942227431706016, 35.83871105739048, 36.95333412715367, 37.52005352292742, 36.88669742856707, 37.656102725437705, 38.815691062382285, 38.21981355122158, 38.354354994637625, 37.42518629346575, 37.26175424030849, 34.90283734457833, 34.75800909314837, 34.080260957990376, 35.023718629564556, 33.400410992758616, 38.15413917813982, 35.321164063044954, 39.846188817705425, 41.30703020095825, 49.02874394825527, 46.697077887398855, 48.89644677298409, 5.768759250640869, 0.42995518020221163, 0.18516759255102702, 0.07536210931305375, 0.13981119064348085, 1.4335422366857529, 43.65005309241158, 47.979753562382285, 41.34568302971976, 29.169916902269634, 21.87840781893049, 33.48624208995274, 30.40279483795166, 0.40561053795473917, 0.03611329271058951, 0.04224432140056576, 0.06773324510348694, 0.024492854651595865, 0.022235217670510923, 0.04918348869042737, 0.1031855463183352, 0.045695872977375984, 0.08160391223749944, 0.017027071244748573, 0.02028817161252456, 0.02705787817415382, 0.04526188876479864, 0.009605305252729781, 0.02826712596496301, 0.03709589623446975, 0.012765984134083348, 0.026317119797957794, 0.08670173226190464, 0.03741577799831118, 0.007149814245557147, 0.032468205983085294, 0.028869249458823885, 0.030847124755382538, 0.0763396814997707, 0.09359273035079241, 0.06951647584459611, 0.07173141092061996, 0.039430965935545306, 0.08811268476503235, 2.135762904371534, 41.461301054273335, 51.75353561128889, 49.189403670174734, 33.359076159340994, 30.607259477887833, 49.70229884556362, 51.25848340988159, 49.89770998273577, 33.09301921299526, 0.05206355432580624, 0.7448560084615434, 0.4905106308204787, 0.06604216620326042, 9.546467900276184, 66.08406666346959, 49.019641808101106, 57.406218256269185, 46.60317645754133, 42.768656730651855, 38.99318279538836, 41.60621963228498, 38.30023200171334, 42.68548331941877, 39.57916954585484, 41.524842330387656, 41.51279762813023, 45.94831568854195, 42.99557447433472, 44.254702704293386, 42.88674831390381, 43.099564688546316, 38.46849305289132, 38.60906900678362, 36.30399022783552, 37.29936483928135, 36.1529016494751, 36.95854180199759, 37.202708448682515, 38.13084881646292, 36.591124534606934, 38.54844944817679, 37.65890979766846, 37.780812467847554, 37.22955976213728, 37.71897350038801, 38.2320910181318, 35.770066329411094, 36.97742005756923, 40.04039791652134, 35.769031047821045, 38.214195932660786, 37.271891662052695, 38.854614870888845, 36.42280442374093, 36.853405135018484, 35.72451741354806, 37.71349137169974, 38.70003134863717, 37.4350596836635, 38.13771711077009, 37.93489571980068, 37.12498937334333, 37.36008167266846, 35.66369983128139, 36.233215876988, 35.76210716792515, 44.258791719164165, 44.499598911830354, 45.80495350701468, 46.21903140204293, 47.83300065994263, 45.06951100485665, 43.3870325088501, 41.17393050874983, 42.642960344042095, 43.74072708402361, 43.34871666772025, 39.73126908711025, 35.95042072023664, 35.93610743113926, 35.2683299609593, 35.592501640319824, 35.04534142357962, 35.217611585344585, 35.83756113052368, 35.450240748269216, 35.09149483272007, 36.27682277134487, 36.596585818699424, 35.71238585880825, 36.005071776253835, 34.71016032355172, 36.50524132592337, 34.48860658918108, 34.14551496505737, 35.10682255881173, 35.29340948377337, 34.20284455163138, 37.51747226715088, 35.52516317367554, 36.035084520067485, 36.761206013815745, 35.52006319590977, 35.26080158778599, 34.31676026753017, 34.0946159362793, 35.48675700596401, 34.82172754832676, 37.67784363882882, 37.86759546824864, 39.31441191264561, 39.3099615914481, 41.01138435091291, 40.11205816268921, 40.41666371481759, 39.390529428209575, 40.060398306165425, 38.14328956604004, 39.38294546944754, 36.88812180927822, 38.42466729027884, 36.46388217381069, 36.475308486393516, 36.18036787850516, 39.42905024119786, 37.36441387448992, 41.82389627184187, 42.497388635362896, 49.85030242374965, 47.61544908796038, 49.482968534742085, 5.850077058587756, 0.6597968127046312, 0.2019472885876894, 0.019903795095160604, 0.28386490792036057, 1.4153837710618973, 47.833188261304585, 50.659020628247944, 46.74359260286604, 39.35057381221226, 22.506349529538834, 32.43452453613281, 38.41167415891375, 0.6094789355993271, 0.04773813106917909, 0.021230124103437577, 0.015814992266574075, 0.016666100792852894, 0.03131577532206263, 0.021570953939642225, 0.03986742340826562, 0.041185436969889064, 0.08581015081810099, 0.0828866216221026, 0.039761962102992196, 0.034385786657886844, 0.02490070678426751, 0.13886163516768388, 0.19093912999544824, 0.14248981619519846, 0.16880200643624577, 0.17820693605712482, 0.12160723603197507, 0.12253468483686447, 0.10308673126356942, 0.13429345243743487, 0.11629041204495089, 0.2677374875971249, 0.1319057827017137, 0.153850310881223, 0.13348199240863323, 0.11091919669083186, 0.29044471627899576, 0.15584415889212064, 3.330660249505724, 58.617685317993164, 57.04494667053223, 56.27716725213187, 37.959270000457764, 32.27516412734985, 55.45130436761038, 56.07510321480887, 54.82268347058977, 37.083373137882774, 0.18572342129690306, 1.8498996836798531, 1.0578302315303256, 0.20500136113592557, 10.057741539818899, 67.54873303004673, 52.3011474609375, 60.00399684906006, 49.34133298056466, 44.72009652001517, 41.07133340835571, 43.89941004344395, 39.992945194244385, 45.461368560791016, 40.487365109579905, 42.44362000056675, 44.54918820517403, 48.515616008213584, 45.71655852454049, 45.825864110674175, 45.8222336769104, 44.03708165032523, 40.604897362845286, 40.80159044265747, 39.40133040291922, 38.95326886858259, 38.248221261160715, 38.692082609449116, 39.47558232716152, 42.098589829036165, 37.749736649649485, 40.08789927618844, 38.10612712587629, 40.17166675840105, 39.23550122124808, 40.75500624520438, 37.814504282815115, 38.07377631323678, 38.154469217572895, 42.545563970293315, 39.177077293395996, 41.38460683822632, 38.38229022707258, 39.7472951071603, 38.189720903124126, 39.53221361977713, 38.75569684164864, 39.51019130434309, 40.81790133884975, 39.04599257877895, 39.89259236199515, 39.59130457469395, 39.589081151144846, 39.508318764822825, 37.298305238996235, 38.709925583430696, 37.866650513240266, 46.25276838030134, 46.50257001604353, 46.35326712472098, 46.49557318006243, 49.438513960157124, 47.067722593035015, 46.15036582946777, 43.56301300866263, 43.46879890986851, 45.84422819955008, 46.59060369219099, 42.675196511404856, 38.156216689518516, 37.466437748500276, 36.41196175983974, 38.12409864153181, 38.0561591557094, 37.85120814187186, 38.41465493610927, 36.79623883111136, 37.56613745008196, 36.321263449532644, 38.67421184267317, 39.413364682878765, 37.99736697333199, 37.163902759552, 38.63199806213379, 37.03780337742397, 36.07740599768502, 36.91251693453108, 36.67229686464582, 36.2399069922311, 39.45500176293509, 38.062429904937744, 37.704312801361084, 39.6995609828404, 38.01004048756191, 37.117752824510845, 35.934599672045024, 36.65888336726597, 37.136346203940256, 37.3482905796596, 41.1897098677499, 39.05549771445138, 41.17850242342268, 41.27210508074079, 40.83424350193569, 41.34348045076643, 43.60220432281494, 42.41412142344883, 41.76152924128941, 40.18723767144339, 41.538895062037874, 38.29265151705061, 38.51655721664429, 38.44304180145264, 38.621283939906526, 37.77475711277553, 41.495739800589426, 39.4796643938337, 44.29075690678188, 44.73152978079659, 53.11242607661656, 49.99107640130179, 50.42246225902012, 7.743517194475446, 0.7085455911500114, 1.5849084172930037, 0.25588019671184675, 1.084107124379703, 2.09389197400638, 55.30018104825701, 53.50062540599278, 53.01390756879534, 38.02627495356968, 31.397756031581334, 41.02242851257324, 47.68016113553728, 1.310152109180178, 0.30318567688976017, 0.09333773010543414, 0.10733263700136117, 0.11839439986007554, 0.18902697760079587, 0.15362842993012496, 0.22722999192774296, 0.16525056771934032, 0.304500976311309, 0.1457488877432687, 0.1081421971321106, 0.12608343655509607, 0.12711056215422495], [0.03650183882564306, 0.06039639522454568, 0.024820714290919046, 0.023275584880528704, 0.00695753184014133, 0.02056323953105935, 0.07838516602558748, 0.004758528766355344, 0.03954700899443456, 0.014206240020160164, 0.018539252690970898, 0.01460067751551313, 0.011376752385071345, 0.01991445318396602, 0.05054795815210257, 0.05988997061337743, 0.018327164696529508, 0.10765835416636296, 15.736486877713885, 48.57857016154698, 49.74743434361049, 30.829657418387278, 25.667213610240392, 43.54961340767996, 49.23069681440081, 44.606670652117046, 37.898216179439, 0.16010504668312414, 0.07708938127117497, 0.22364382578858308, 0.02364049931722028, 1.422893579517092, 54.439493792397634, 55.640493392944336, 52.829683031354634, 49.745110171181814, 45.59805352347237, 39.02400847843715, 37.92539405822754, 36.59452567781721, 38.90229688371931, 38.06086308615548, 39.559728486197336, 39.94126796722412, 41.73611967904227, 42.4946996825082, 42.05514621734619, 41.398392064230784, 38.1453983443124, 35.87401832853045, 35.37615558079311, 35.810334614345, 35.867379324776785, 35.1158378464835, 35.73837906973702, 35.740654604775564, 35.665561948503765, 34.91198812212263, 34.715260301317485, 36.62711272920881, 37.00669629233224, 37.11349705287388, 35.527706214359824, 34.84735597882952, 34.17588554109846, 36.62755741391863, 37.55175467899868, 35.75291470118931, 36.006426674979075, 36.55557755061558, 34.72560964311872, 35.8812757219587, 34.715329783303396, 36.427039350782124, 36.90078837530953, 36.31331123624529, 33.29442317145211, 35.92766536985125, 35.888498374394004, 34.761132308415, 36.39414657865252, 33.37305246080671, 34.48829392024449, 36.35434034892491, 41.58759151186262, 46.31573295593262, 44.37840148380825, 46.92610093525478, 49.628505502428325, 49.10115459987095, 43.03364018031529, 41.84455674035208, 44.99025290352957, 41.34452268055507, 42.42562764031546, 37.61908967154366, 33.77235153743199, 31.99441521508353, 34.18871886389596, 33.07033681869507, 34.002284799303325, 33.001191820417134, 32.074976103646414, 34.51067754200527, 35.02717535836356, 34.04813248770577, 35.4517936706543, 34.555795669555664, 34.93350669315883, 33.573917933872764, 34.69044133595058, 33.029825346810476, 32.94420269557408, 33.46891328266689, 33.76303400312151, 33.83415228979928, 33.683244364602224, 33.57455021994454, 34.83325113568987, 34.91240848813738, 33.122708865574424, 33.43282086508614, 32.797797203063965, 33.870797089168, 34.15639584405081, 36.876525265829905, 38.2037284714835, 37.09589031764439, 36.71279444013323, 36.68310131345476, 37.13295895712716, 36.810496534620015, 37.433697836739675, 36.26899562563215, 38.156088147844585, 37.022201197487966, 37.1536819594247, 36.66257980891636, 36.463312421526226, 34.53433615820748, 34.812194619859966, 35.14106675556728, 35.832916259765625, 36.54499544416155, 41.93238891874041, 44.19969034194946, 47.98477710996355, 48.85915926524571, 36.45700345720564, 1.1828363580363137, 0.1323674986405032, 0.08865463068442685, 0.09488268648939473, 0.37121991334216936, 4.567274578980037, 51.333489213671, 46.45664242335728, 39.85086495535714, 24.00894784927368, 20.51102144377572, 39.95168679101126, 10.732101559638977, 0.23890783744198935, 0.04072596358933619, 0.03707183538270848, 0.03603835530312998, 0.030278746504336596, 0.04747851000034383, 0.0220124783726143, 0.04228761872010572, 0.11126695267323937, 0.026127584611198733, 0.045310424374682565, 0.03232426156422921, 0.03174566796847752, 0.006849587096699646, 0.03972898869376097, 0.047025045047381094, 0.025276348859603916, 0.05520923927958522, 0.017708873409511786, 0.018227508258340613, 0.06399184372276068, 0.02727223756457014, 0.042593356421483416, 0.0364811367222241, 0.014523573885006564, 0.06560329653854881, 0.024430213995011787, 0.046875950547733476, 0.049414339874471934, 0.03417744926576104, 0.023422799838174666, 0.05127864537228431, 23.91834681374686, 52.81974710736956, 51.1873824937003, 33.210134574345176, 33.78743955067226, 45.48785161972046, 53.85178736277989, 47.69016654150826, 41.061883858272004, 0.0924107019922563, 0.5841600256306785, 0.11222965815769774, 0.010953030166482287, 1.4809870336736952, 57.66043199811663, 56.55164194107056, 54.30756834575108, 51.47302988597325, 46.314649036952424, 40.23553807394845, 40.736628259931294, 38.054620129721506, 41.57414327348982, 38.97168159484863, 41.60276985168457, 44.54159729821341, 43.96898235593523, 43.226966857910156, 45.20547682898385, 42.94704130717686, 41.01458052226475, 38.013427734375, 37.36907264164516, 36.895021370479036, 37.51565531321934, 37.878174100603374, 37.66068506240845, 36.46958664485386, 37.24802459989275, 36.695931162152974, 37.01647240774972, 38.0201918057033, 38.20613602229527, 37.82944985798427, 38.080790519714355, 37.47445944377354, 37.07243667330061, 37.97190529959542, 38.736234937395366, 36.986098357609336, 38.545788288116455, 39.58870594842093, 37.36848899296352, 37.948406491960796, 34.9419070652553, 37.14178664343697, 37.71978643962315, 38.68990782329014, 35.75031607491629, 37.73803588322231, 38.020917892456055, 36.71053627559117, 36.435835770198274, 35.50448880876814, 36.18596117837088, 38.3276287487575, 42.56488691057478, 47.72877768107823, 46.055835587637766, 48.85718250274658, 48.9896742275783, 49.54465811593192, 45.666597502572195, 44.29138224465506, 44.91748441968645, 45.178952080862864, 43.738680839538574, 41.27112191064017, 35.422972542899, 34.47580105917794, 35.97815098081316, 34.689353942871094, 34.764036655426025, 34.5502336365836, 35.137964384896414, 36.167854172842844, 37.99725580215454, 35.64595413208008, 36.50671434402466, 35.59558316639492, 36.22071259362357, 35.728248596191406, 36.453751700265066, 34.97504997253418, 34.866835253579275, 35.47710943222046, 34.10050800868443, 34.79023136411394, 35.1562694140843, 35.58877740587507, 36.233427797045024, 36.758221762520925, 36.34224353517805, 36.10960047585623, 34.659556593213765, 35.38220051356724, 35.30050706863403, 38.06698792321341, 38.11609779085432, 39.229032448359895, 39.02848311832973, 39.76346009118216, 38.5203891481672, 38.78117935998099, 40.1473445892334, 39.128617082323345, 39.345091683524, 39.385033403124126, 38.35673475265503, 39.03770685195923, 37.51764249801636, 35.98612403869629, 36.76657697132656, 36.6347279548645, 38.88023635319301, 38.86204596928188, 44.015264306749614, 46.50621782030378, 50.38679368155343, 49.40529809679304, 38.2167181287493, 1.5028560544763292, 0.43535390336598667, 0.7616611495614052, 0.12434170501572744, 0.5033785860453333, 4.742773916040148, 56.460922786167686, 48.81854357038225, 45.925199031829834, 31.95953525815691, 16.980532305581228, 46.358426162174766, 15.980035134724208, 0.27352362711514744, 0.11714512189584118, 0.024957020101802688, 0.04055293376690575, 0.030767759906926324, 0.021784453286922405, 0.017446814703622034, 0.07290136814117432, 0.08464579829680068, 0.018101894463013326, 0.01654659890170608, 0.0671748039977891, 0.0490920560966645, 0.060926337859460285, 0.08390783039586884, 0.13119714786963804, 0.1887695278440203, 0.21307879127562046, 0.14957788799490246, 0.1969320869871548, 0.1428415280367647, 0.1094365298215832, 0.0891902730134981, 0.11697795800864697, 0.06492740780647312, 0.12269513122737408, 0.14616322836705617, 0.13422443185533794, 0.3029966370335647, 0.14805347765130655, 0.07739361601748637, 0.11126533775989499, 29.210588182721818, 60.91061864580427, 54.809728554316926, 39.70288569586617, 36.54926858629499, 52.47270890644619, 58.3897705078125, 54.24501371383667, 46.922373226710725, 0.40312533559543745, 1.5295516848564148, 0.5606257713266781, 0.09308610896446876, 1.7730870225599833, 58.95687552860805, 58.34186267852783, 57.58259827750069, 53.93622187205723, 49.67629868643624, 43.24417059762137, 42.76280287333897, 40.86583348682949, 43.981624603271484, 41.988384451184956, 43.691071782793315, 45.6941887991769, 46.20842497689383, 46.92501354217529, 46.41319881166731, 46.550547327314106, 43.5289876801627, 39.71406534739903, 39.600330284663606, 39.48260695593697, 39.34131186349051, 39.67036812646048, 40.02481658118111, 41.28943736212594, 39.75017860957554, 37.57901593617031, 38.7070038659232, 40.266923086983816, 40.38324982779366, 40.050827162606375, 40.307636056627544, 39.97993816648211, 38.73535599027361, 40.26963983263288, 41.37145389829363, 38.66507148742676, 40.1687867300851, 40.661973340170725, 40.07751519339425, 40.24628346306937, 36.345616885593955, 39.89415570667812, 39.61457756587437, 40.786981855119976, 36.455902167728965, 40.40807226725987, 40.01279272351946, 38.93204212188721, 38.717745780944824, 37.7481107711792, 38.39538410731724, 41.536727224077495, 43.87985781260899, 50.432832445417134, 46.8598290170942, 51.00639581680298, 52.485312938690186, 53.38649777003697, 47.83146858215332, 45.80857351848057, 47.92390046800886, 46.75464718682425, 46.28717238562447, 41.87726191111973, 38.47149120058332, 35.32029206412179, 38.856595107487266, 35.70905072348458, 36.41851043701172, 35.99711608886719, 35.30103860582624, 38.23691654205322, 40.42231260027204, 38.04320771353585, 38.98278481619698, 38.52064275741577, 38.79158081327166, 37.96648570469448, 38.858995710100444, 37.453215326581685, 37.05856459481375, 37.199105807713096, 37.18855496815273, 37.246131215776714, 36.80954115731375, 36.40932144437517, 38.58928401129586, 38.525489125932964, 37.03519432885306, 38.91608558382307, 36.689670835222515, 36.95964309147426, 37.63780811854771, 41.07115970339094, 41.393194811684744, 41.817093985421316, 40.81273535319737, 41.075450216020855, 40.41549641745431, 40.62989698137556, 41.78961385999407, 39.827522482190815, 42.513689109257285, 40.46279280526297, 41.35384021486555, 40.37934146608625, 39.279945373535156, 37.6193710735866, 38.317901270730154, 38.78452491760254, 39.46227305276053, 41.087154456547324, 47.43343407767159, 47.51585360935756, 52.904150349753245, 50.103536469595774, 38.92131757736206, 1.9071430691650935, 0.6890558398195675, 1.3957848570176532, 0.36631163528987337, 0.7712598145008087, 5.753352054527827, 62.60831369672503, 53.502313818250386, 50.531747000558035, 34.358487674168174, 26.89404140199934, 52.867008754185264, 22.479503427233013, 0.3090758765382426, 0.2063926700502634, 0.13830305156963213, 0.12835358402558736, 0.14315726395164216, 0.12899040271128925, 0.1002249148275171, 0.1296668207006795, 0.27669189710702213, 0.12094677718622343, 0.10325388836541347, 0.17423023230263165, 0.10135263324316059, 0.16159615452800477], [0.04307418329907315, 0.057979982745434554, 0.011339119984768331, 0.029385227843054702, 0.09059159031936101, 0.058450316078960896, 0.008396670687943697, 0.018753790196829608, 0.02438454349924411, 0.03277443562235151, 0.050644907235567055, 0.07524996783052172, 0.019887610338628292, 0.011944894845198308, 0.04226163422156658, 0.027003486807058965, 0.02876106383545058, 0.05974367167800665, 1.6643279556717192, 38.958004065922324, 51.022883892059326, 34.036681856427876, 23.59347857747759, 35.260909284864155, 50.61054304667881, 43.366955689021516, 40.564660344805034, 0.5796562901565007, 0.177668871358037, 0.21822260240358965, 0.19282068046075956, 0.07258714535938841, 23.50168071474348, 62.93086991991316, 49.81361940928868, 55.67352512904576, 48.81925923483712, 48.12906687600272, 39.77776990618025, 39.47486318860735, 36.563536712101524, 40.083369050707134, 36.817743505750386, 40.28246968133109, 41.40455511638096, 41.92660801751273, 41.38917875289917, 41.511550426483154, 36.591006415230886, 36.25508533205305, 36.6328067779541, 36.53512552806309, 36.6237393787929, 36.28044278281075, 34.27413306917463, 35.991616589682444, 35.08323689869472, 35.175060817173545, 37.4678829738072, 35.536068371364046, 35.665860721043174, 35.89575924192156, 36.304636410304475, 35.996761730739046, 34.66597325461251, 36.94795969554356, 35.370291301182334, 36.95331328255789, 35.09198120662144, 34.88622767584664, 35.666472162519185, 35.96633556910923, 35.46022183554513, 35.66312313079834, 37.8198161806379, 37.069706031254356, 35.95113638469151, 35.261055197034565, 34.93661601202828, 36.0268509047372, 35.04281922749111, 33.29898118972778, 32.447243213653564, 34.748052324567524, 40.49477536337716, 45.66996390478951, 45.27998236247471, 47.680772577013286, 46.24423599243164, 48.485964570726665, 46.1034620148795, 45.019942556108745, 48.16272394997733, 46.14318834032331, 45.65417759759085, 41.73125941412789, 35.707949434007915, 33.69667870657784, 33.2589248248509, 33.57797915594918, 32.02267006465367, 34.149093287331716, 34.60921689442226, 33.05056919370379, 34.1372709274292, 35.06237840652466, 35.17016928536551, 36.25468233653477, 33.24828713280814, 34.98430149895804, 32.9853047643389, 33.759761401585166, 33.720042024339946, 34.105701787131174, 35.379733903067454, 34.58496420724051, 34.993653774261475, 34.23366676058088, 34.899662017822266, 33.10218736103603, 34.63364328656878, 33.30579389844622, 33.37024538857596, 34.72965349469866, 35.02724136625017, 39.623679706028526, 38.77928597586495, 38.775026730128694, 37.47734989438738, 37.3270777293614, 38.411740166800364, 37.86755377905709, 37.2283889906747, 37.1709760257176, 36.024853297642295, 35.9273943901062, 35.49232251303536, 34.87554829461234, 34.90749263763428, 36.38100406101772, 32.693866048540386, 35.512058871132986, 36.30521658488682, 40.68477037974766, 43.785647187914165, 46.29462432861328, 47.85694762638637, 49.64547300338745, 20.889034714017594, 0.1488872886236225, 0.48288384292806896, 0.4557581841945648, 0.16353844744818552, 0.008846140765984143, 8.904984150614057, 52.541798319135395, 45.36948905672346, 33.752076693943565, 26.960504395621165, 34.21394429888044, 35.7169577734811, 3.461745398385184, 0.2592694791299956, 0.044959916932774444, 0.014991484848516328, 0.023662490637174675, 0.03233584415699754, 0.04224006698599883, 0.02872953231313399, 0.037805898314608, 0.026925531615103995, 0.1160228249749967, 0.025698451924004724, 0.044734304039073844, 0.03849309144009437, 0.017570199511413063, 0.0968567416337984, 0.04489425849169493, 0.0367021321851228, 0.031109368362064873, 0.0805686442181468, 0.038374117109924555, 0.008916640554421713, 0.015680754291159765, 0.046337658539414406, 0.07564847144697394, 0.04735265193240983, 0.04688002515052046, 0.02290675020776689, 0.029336614201643636, 0.09644596331885882, 0.028816510324499438, 0.1243084432291133, 0.14264281227120332, 4.435310482978821, 46.68562378202166, 54.04192134312221, 31.96513203212193, 33.63374192374093, 41.24359662192208, 52.75022690636771, 48.397187437329976, 46.31384652001517, 0.4842348332915987, 0.7692793064883777, 0.1660682838410139, 0.20497390760907105, 0.038970423862338066, 27.63719814164298, 64.03434807913644, 51.671519075121196, 57.4982784135001, 49.96388462611607, 50.31081860406058, 41.76320028305054, 40.51135376521519, 39.48521253040859, 41.48467132023403, 39.07252080099923, 43.355953216552734, 44.61771828787667, 43.72732400894165, 43.090309688023154, 44.494856766292024, 39.09349741254534, 37.56609576089041, 37.46658018657139, 38.40735237939017, 38.209571906498496, 38.15040799549648, 36.99757330758231, 38.04380873271397, 38.03737122671944, 37.59171029499599, 38.3688975742885, 39.11130911963326, 37.78426572254726, 37.593728746686665, 37.296905176980154, 37.98959541320801, 36.91736677714756, 39.5530686378479, 38.5014830998012, 38.28034973144531, 38.89717953545706, 37.26075369971139, 36.41016565050398, 38.69397599356515, 37.02032518386841, 37.9079714502607, 39.030327865055625, 39.01708459854126, 36.23674556187221, 36.78377723693848, 37.72833619798933, 37.98968921388899, 36.05116612570626, 36.14068324225289, 35.079387596675325, 35.914491585322786, 43.50506155831473, 48.43199791227068, 47.22293840135847, 47.98044490814209, 48.227095535823274, 51.43814298084804, 46.48159340449742, 47.236053126198904, 49.77406331471035, 47.861863476889475, 45.595593861171174, 42.70325681141445, 35.47094290597098, 35.997001443590435, 34.75102267946516, 35.08728075027466, 34.8620514188494, 35.28427955082485, 35.807197502681184, 35.264063767024446, 35.746796812329976, 36.77858345849173, 35.8809700012207, 36.3687196459089, 34.51192126955305, 36.15577820369175, 35.568242004939485, 34.94325501578194, 35.27421161106655, 35.593985080718994, 37.24303579330444, 36.116173471723286, 35.92226661954607, 35.66011108670916, 36.760973249162944, 35.21388387680054, 35.28605828966413, 35.02004303250994, 35.373261656079976, 35.92968382154192, 38.29546206338065, 40.510012762887136, 40.2280444417681, 40.687990869794575, 40.35502277101789, 38.41176101139614, 41.45569733210972, 39.38533564976284, 37.42857354027884, 38.79373822893415, 36.96623345783779, 38.55615847451346, 36.527180262974326, 36.21894427708217, 36.748796531132285, 37.743055956704275, 35.52476017815726, 38.09760168620518, 38.47549336297171, 41.77699245725359, 47.04677030018398, 47.82446132387434, 50.54374653952462, 50.329578740256174, 22.342545747756958, 0.17330800821738584, 0.14356494136154652, 0.8122593973364148, 0.025299888935738375, 0.36188793980649536, 9.460134795733861, 59.43823977879116, 47.480980600629536, 43.71342761175973, 28.417644126074656, 29.155270099639893, 44.20843812397548, 4.747508244855063, 0.3079006810273443, 0.04875622197453465, 0.07641280043338027, 0.012525749658899648, 0.05580613975014005, 0.020027140887188058, 0.03292654621015702, 0.015474550891667604, 0.035539133341184685, 0.0732546541839838, 0.07305430314902749, 0.06792458519339561, 0.03359302366152406, 0.0345126218162477, 0.20221233793667384, 0.1779513047741992, 0.1329288235200303, 0.1330014131963253, 0.1630571082766567, 0.12381688532020364, 0.10341951876346554, 0.0643545953290803, 0.15943195351532527, 0.1739501601883343, 0.15410377085208893, 0.22861399980528013, 0.13535891526511737, 0.11437588477773325, 0.3303638813751084, 0.150948664439576, 0.23585187856640133, 0.3297344994332109, 5.038440176418849, 58.284762382507324, 55.35557903562273, 42.76859767096383, 32.38501862117222, 45.771324225834434, 57.59726939882551, 51.54052121298653, 50.121303013392854, 0.5075863174029759, 1.2135371906416756, 0.5356101393699646, 0.5088408472282546, 0.15071108218814644, 28.326867648533412, 65.9764529636928, 54.11320986066546, 59.492227281842915, 52.17621537617275, 52.0859409059797, 44.32450083323887, 43.51306240899222, 41.73874262401036, 45.21424198150635, 41.0937100819179, 45.80732979093279, 47.14348227637154, 45.04258326121739, 45.794875144958496, 45.848966870989116, 41.362358706338064, 40.10459232330322, 40.81021663120815, 41.79013497488839, 40.43308925628662, 39.723306451525005, 39.433594363076345, 39.935817105429514, 39.51013919285366, 39.44507278714861, 41.89330530166626, 41.899888719831196, 40.040158203669954, 39.12332950319563, 41.30723864691598, 39.9709506716047, 38.74472911017281, 42.020992347172324, 40.04299654279436, 41.18579108374459, 40.18056740079607, 39.17940146582467, 37.80335937227522, 39.966576780591694, 39.30463579722813, 39.248695850372314, 40.457574708121165, 40.95964459010533, 38.60841587611607, 37.618537289755686, 39.97138840811593, 40.03921324866158, 37.28609377997262, 38.41473831449236, 35.30134432656424, 37.83684621538435, 45.49150289808001, 48.98747512272426, 48.39143085479736, 49.51450293404715, 48.239376476832796, 53.32396050861904, 48.364051478249685, 49.9052209854126, 50.61358635766165, 51.15555279595511, 47.7676146371024, 45.250615801130024, 38.90162985665457, 38.18091753550938, 36.63722235815865, 37.897125312260215, 36.01928431647164, 37.09337159565517, 38.09376628058297, 37.09487935474941, 37.46145936420986, 38.71800633839199, 39.575101375579834, 40.32122673307146, 37.52559123720442, 38.0702223096575, 36.947886739458355, 37.81925685065133, 37.1722023827689, 38.27793870653425, 39.77461889811924, 37.95133515766689, 38.90247058868408, 37.08772965839931, 38.71695021220616, 36.07633944920131, 37.89049673080444, 36.54809086663382, 37.440986497061594, 38.725524289267405, 39.767486572265625, 43.98543569019863, 42.934996604919434, 42.16354506356375, 41.46142264774868, 40.102792739868164, 44.340832574026926, 42.36122131347656, 41.23239612579346, 41.09863288061959, 39.613476276397705, 39.17973150525774, 38.87264544623238, 38.98081152779715, 39.4621445110866, 41.383668831416536, 37.84193924495152, 39.214152881077354, 39.80928693498884, 42.655609539576936, 49.14402845927647, 50.217886447906494, 52.2747026171003, 51.452772412981304, 24.465771062033518, 0.40601706185511177, 0.9713153881686074, 1.3591690446649278, 0.19354090467095375, 0.552968693631036, 11.732098460197449, 64.34168774741036, 51.29929712840489, 44.604388168879915, 36.64343752179827, 42.652222292763845, 51.01087393079485, 7.185706257820129, 0.703848554619721, 0.11436318260218416, 0.16797044820019177, 0.1432330156011241, 0.21018038823136262, 0.11799276141183716, 0.09151371940970421, 0.14473755843937397, 0.11177235269652945, 0.2748435405748231, 0.20964315134499753, 0.15211127991122858, 0.13795184184397968, 0.08852743250983101], [0.07470553168760878, 0.024445206226248826, 0.0057634641499524665, 0.06619983738554375, 0.02678249134416027, 0.07282786922795431, 0.04156236317274826, 0.04268512149740543, 0.07712204594697271, 0.012948670357997929, 0.013985944296499448, 0.032801448101443906, 0.052110909284757714, 0.03453755797818303, 0.02552071985389505, 0.07065994984337262, 0.005049418849271855, 0.028821137933326618, 0.13899274170398712, 16.090645245143346, 53.45453453063965, 36.89309671946934, 27.353696005684988, 31.795877388545446, 43.37836115700858, 46.12527241025652, 45.67163494655064, 3.727788882596152, 0.7774167326944215, 0.10617623012512922, 0.24733070975967816, 0.2400988835309233, 2.888389604432242, 52.97440011160714, 53.817442417144775, 54.089676312037874, 51.64337192262922, 49.73811680930001, 46.08681413105556, 41.613056659698486, 38.174473081316265, 42.07773133686611, 40.1516489982605, 40.873959405081614, 39.40155274527413, 40.663963999067036, 40.59332513809204, 41.75613396508353, 36.86558185304914, 35.59948110580444, 36.91777672086443, 35.86769546781267, 35.497231415339876, 37.846024785723, 35.99463905606951, 36.58076129640852, 34.31718758174351, 36.373076166425435, 35.3751619883946, 36.51867914199829, 35.93484285899571, 37.37199435915266, 35.54745994295393, 36.268637793404714, 35.908411911555696, 36.31815413066319, 36.86982025418963, 36.63592651912144, 35.86692074366978, 35.556888648441856, 36.1960951260158, 35.4200508253915, 36.39270830154419, 37.90258659635271, 37.08697925295149, 35.04132883889334, 33.56627491542271, 35.92869370324271, 35.90635871887207, 36.99301528930664, 34.75374289921352, 33.0567808832441, 33.699836662837434, 35.10571084703718, 39.01481948580061, 45.34708111626761, 44.29983125414167, 46.8334640775408, 48.02828325544085, 49.840210165296284, 48.491874013628276, 47.263974462236675, 47.884459018707275, 47.9875042779105, 42.91959592274257, 40.71134376525879, 34.55617782047817, 34.39780058179583, 33.0528690474374, 33.026531900678364, 34.37117508479527, 34.155565534319194, 35.06677661623274, 35.51737771715437, 33.712332998003276, 35.599508898598806, 34.87895291192191, 34.494484765189036, 33.87578936985561, 34.34331628254482, 33.54313741411482, 35.51605061122349, 33.14760773522513, 36.009428296770366, 33.15297869273594, 32.35987309047154, 33.68182693208967, 35.638946873801096, 35.55566923958914, 35.35252128328596, 34.62788322993687, 33.46960115432739, 32.74747487476894, 34.0460376058306, 39.3763689994812, 42.17304672513689, 43.28155885423933, 44.27117688315255, 44.01199517931257, 40.689884253910606, 43.524335861206055, 41.489736557006836, 40.952053683144705, 39.78751128060477, 39.552196638924734, 38.716383934020996, 37.5805584362575, 37.44751780373709, 34.37198107583182, 35.46084022521973, 37.47596720286778, 36.86793034417288, 37.201593262808665, 42.464204038892476, 43.630771841321675, 48.94887440545218, 48.32548550197056, 42.64268241609846, 7.6349533285413465, 0.19786047217036995, 0.2560350926859038, 0.4773862436413765, 0.1680196419890438, 0.3267793708613941, 15.706024238041469, 56.54160874230521, 39.27370241710118, 30.07226208278111, 21.8958842754364, 37.533418382917134, 26.24008216176714, 0.33945158230406897, 0.12556594503777369, 0.03620156333116548, 0.05296412975128208, 0.03030066318543894, 0.03264109331316181, 0.07133923803589173, 0.02771214029884764, 0.015057535143569112, 0.04590535370100822, 0.005084518617617765, 0.029571109118738344, 0.07668112710650478, 0.01709529454819858, 0.014564640520672714, 0.06994978830750499, 0.041765184075172455, 0.022806101412113224, 0.018963589831920605, 0.0525035537513239, 0.06020930954920394, 0.006202105657264058, 0.007026993470000369, 0.052055500115134885, 0.06840352235095841, 0.030180277502430335, 0.011753693854968463, 0.06770061435444014, 0.023603510677016208, 0.036335326332066736, 0.06567104826016085, 0.019161640633163706, 0.02785254785391901, 0.38835430677448, 24.35176154545375, 62.165942737034385, 33.87166561399187, 26.707219975335256, 39.550192083631245, 47.594660077776226, 50.62937961305891, 46.61794137954712, 3.152291089296341, 0.5455279328993389, 0.5166967628257615, 0.5824974519865853, 0.21537644655576774, 3.874336378914969, 57.66853359767369, 53.979154791150776, 57.673977511269705, 52.207305090767996, 53.637379850660054, 48.23121929168701, 44.37012617928641, 39.163920879364014, 42.87755932126726, 40.374988419669016, 42.74440056937081, 42.589674609048025, 43.36842523302351, 41.76193918500628, 43.98431703022548, 39.35248109272548, 38.05613483701433, 36.98350320543562, 36.42548642839704, 36.26522275379726, 39.45180211748396, 37.39434323992048, 37.30937719345093, 37.55633006777082, 37.239203861781526, 37.68369402204241, 39.17394365583147, 38.807853494371685, 39.50167281287057, 37.17937292371477, 37.9678510257176, 37.53586762292044, 38.26113796234131, 38.18933875220162, 38.12139579227993, 37.19753898893084, 37.60883413042341, 37.36251354217529, 35.74111318588257, 36.411819321768625, 39.670038087027415, 37.751477173396516, 36.82662330354963, 35.427422864096506, 37.90994126456124, 37.76977872848511, 40.135508332933696, 37.459044865199495, 36.08500385284424, 35.574321678706575, 35.92750556128365, 39.68261432647705, 45.46234825679234, 45.658072062901084, 48.82063497815813, 48.38922480174473, 51.82003682000296, 49.07434844970703, 49.130680969783235, 49.049894264766145, 50.30404758453369, 46.17622355052403, 41.73490374428885, 35.26332378387451, 35.577806200299946, 33.753945759364534, 35.49623434884207, 35.39143814359392, 35.96140234810965, 37.00059229987008, 36.65873050689697, 34.92598874228341, 37.37270654950823, 36.63445350102016, 36.80586903435843, 35.575290952410015, 36.67873784473964, 36.06870685304914, 36.429825578417095, 35.37998751231602, 35.62698207582746, 34.221073150634766, 34.89505883625576, 35.19816010338919, 37.51303584235055, 36.506172384534565, 36.908570357731406, 34.7932573046003, 36.16355671201433, 34.58002751214163, 36.569112641470774, 40.13588353565761, 44.18208360671997, 44.99664177213396, 46.71850265775408, 43.59989752088274, 44.04817444937569, 46.737620626177105, 43.56422199521746, 42.724657263074604, 42.01365157536098, 41.38279683249337, 40.165625299726216, 38.61226865223476, 37.724386147090364, 35.53646789278303, 37.1356201171875, 37.77474321637835, 38.13049098423549, 38.88920300347464, 45.309414931706016, 46.46763447352818, 50.357774530138286, 49.656760351998464, 45.14995377404349, 8.528892925807408, 0.33356377109885216, 1.4840957011495317, 1.1877741387912204, 0.0657436175804053, 0.4704364165663719, 16.961650575910294, 60.81872871943882, 41.90957798276629, 41.37556375776018, 24.333925519670757, 38.20936346054077, 33.74903685706002, 0.6224030735237258, 0.13202132364468916, 0.0323857673709946, 0.061725998164287636, 0.014050478065785552, 0.05202952240194593, 0.029906736287687505, 0.04450411442667246, 0.06973629404923745, 0.027379086473956704, 0.05559707632554429, 0.031406424207878966, 0.05980712827295065, 0.06115608981677464, 0.03011574882215687, 0.1781485684748207, 0.2541839677308287, 0.15194061478333815, 0.14967931540949003, 0.127257926389575, 0.1309501068400485, 0.08541483631623642, 0.10047768269266401, 0.11509849743119308, 0.169060243293643, 0.21040347697479383, 0.07158285246363708, 0.17217306340379374, 0.11492215975054673, 0.11579277446227414, 0.10578817594796419, 0.11977703709687505, 0.10863557351487023, 0.41556201396243914, 26.942915030888148, 69.08730738503593, 42.886289732796804, 36.855916908809114, 41.567743982587544, 52.27471303939819, 52.8124132837568, 57.86392389025007, 4.063015145914895, 1.467214184147971, 1.4277392966406686, 1.080773074712072, 0.35297163682324545, 4.076961049011775, 55.61544166292463, 55.05950934546334, 58.86834158216204, 55.06418200901577, 55.416226387023926, 50.10599613189697, 46.25131273269653, 41.76918268203735, 45.90527854646955, 43.8499492917742, 45.01756974628994, 45.1182074546814, 45.74832568849836, 44.61107233592442, 45.89027043751308, 41.343067032950266, 40.050167083740234, 41.49139370237078, 38.47893272127424, 39.226013456072124, 42.00549439021519, 40.07907853807722, 40.301969800676616, 39.43099226270403, 39.00041587012154, 38.56807810919625, 42.12004239218575, 41.45523180280413, 42.5736277444022, 37.99550485610962, 39.97612707955496, 39.49378660746983, 40.6114946774074, 39.40487398420061, 40.69401843207223, 38.862118925367085, 39.452708857400076, 40.32238013403756, 39.18067298616682, 38.47827959060669, 41.550293581826345, 40.83609867095947, 38.68657268796648, 37.102164540972026, 38.661329882485525, 39.20363678250994, 42.380679743630544, 40.19271980013166, 37.96642664500645, 37.123207160404746, 39.67564180919102, 42.09544229507446, 48.40026896340506, 49.19585507256644, 52.24486010415213, 51.86613116945539, 53.23677798679897, 50.649261883326936, 51.56427362986973, 51.59162868772234, 52.905845710209434, 47.58241040366036, 42.72726631164551, 37.63757882799421, 38.469305992126465, 36.838734013693674, 36.76178618839809, 38.59439788545881, 37.88894033432007, 39.604884828839985, 39.285003662109375, 36.718877587999614, 39.014183725629536, 39.772812366485596, 38.39058290209089, 36.58681665148054, 38.265706402914866, 37.31524494716099, 39.44641031537737, 36.521854468754356, 39.351171357291086, 36.72544363566807, 36.164852551051546, 35.71204539707729, 38.42848185130528, 38.70983178274972, 39.45821530478341, 38.40856484004429, 36.51674754279, 36.14402879987444, 38.87836033957345, 43.1621401650565, 45.24636697769165, 47.80794545582363, 48.17370557785034, 47.56389692851475, 45.096727098737446, 48.33410126822335, 45.61098412105015, 45.033064229147776, 42.8840628351484, 44.07735340935843, 42.766082423073904, 42.66848802566528, 39.5443833896092, 37.51624591009957, 39.12681402478899, 41.08484765461513, 39.430849824632915, 40.68098708561489, 47.743115288870676, 49.17092841012137, 51.485213552202495, 52.65554033006941, 44.88137463160923, 10.891920549528939, 0.4108707314091069, 1.4934917283909661, 1.1899179837533405, 0.2715468646160194, 0.6184778298650468, 19.203790834971837, 66.49785968235561, 46.72395351954869, 39.63633932386126, 29.517757620130265, 47.33949443272182, 40.54131439753941, 0.707144986305918, 0.24842570243137224, 0.10620183125138283, 0.22369907210980142, 0.08436725288629532, 0.10815949977508613, 0.1478479222527572, 0.15772310378296034, 0.22175942547619343, 0.15305341221392155, 0.1253512701285737, 0.12154661571340901, 0.15982174474213803, 0.1441091535879033, 0.0799569177574345], [0.03340266066204224, 0.06976479930537087, 0.031935040306832106, 0.04966314509510994, 0.02207092907545822, 0.05465139867737889, 0.046960054963294945, 0.006398745953837144, 0.020271130205531205, 0.048400503383683305, 0.028361910521718006, 0.011072947660328021, 0.031652050491954596, 0.05065335499654923, 0.016567165298121314, 0.04510472648377929, 0.015572979181472744, 0.04364457340644939, 0.06255921202578715, 1.5916203771318709, 34.196083954402376, 46.7287859916687, 29.384574549538748, 30.872652871268137, 40.04388243811471, 43.74143927437918, 52.78291818073818, 13.267493145806448, 1.137665033340454, 0.505965812930039, 0.2519806016768728, 0.023465634057564393, 0.03563853193606649, 20.830596889768326, 63.297199794224326, 51.829705238342285, 55.716461522238596, 50.765446186065674, 52.28464548928397, 43.87683882032122, 38.10363967078072, 39.681075300489155, 40.62547445297241, 40.26712458474295, 39.358432224818635, 38.16203580583845, 38.00565617425101, 37.37625013078962, 36.52506801060268, 36.875417028154644, 37.18335771560669, 37.331559317452566, 35.74974284853254, 35.2851619720459, 35.28710399355207, 36.20182738985334, 35.80447380883353, 36.525748934064595, 36.26747744424002, 36.98498664583479, 37.31335851124355, 36.998292446136475, 35.103956426892964, 35.30676392146519, 36.665960107530864, 36.666981492723735, 36.593740531376426, 37.193043504442485, 36.86406019755772, 35.83848524093628, 36.42796346119472, 36.09615223748343, 36.711839062826975, 35.043448039463584, 36.26852314812796, 37.310179710388184, 35.07852949414934, 35.36852993283953, 35.40795053754534, 36.20088938304356, 34.40845911843436, 34.209205627441406, 34.15552037102835, 34.749518394470215, 35.6987361226763, 41.84166628973824, 43.66163226536342, 45.62171908787319, 47.32923889160156, 49.59226369857788, 49.68965312412807, 49.404752663203645, 48.73887552533831, 46.77753455298287, 43.13030699321202, 39.16144037246704, 35.85439314161028, 35.80434874125889, 34.945537499019075, 35.07962383542742, 34.009563037327354, 34.07148538316999, 34.50887448447091, 34.79988588605608, 34.6732063293457, 34.242133140563965, 33.653926440647666, 34.847428934914724, 33.42594909667969, 33.82947267804827, 34.65993527003697, 35.17805201666695, 34.86484112058367, 34.15235546657017, 33.8156144959586, 34.377664702279226, 33.71795061656407, 34.69210195541382, 33.891818864004954, 32.78706223624093, 33.4839700290135, 34.283568722861155, 33.70288692201887, 34.00111402784075, 38.46368489946638, 43.27970368521554, 45.50275897979736, 44.124298913138254, 47.28979744229998, 46.69855785369873, 44.65377596446446, 44.11059359141758, 43.41238301140921, 44.45943137577602, 43.16473184313093, 43.84955324445452, 40.941370827811106, 40.21960238048008, 37.53922707693917, 36.55981247765677, 34.27785382952009, 38.03889288221087, 38.63826533726284, 42.84787661688668, 44.787212644304546, 46.967428820473806, 46.89302403586251, 33.34693418230329, 1.5562432983091898, 0.35103013100368635, 0.5230341713343347, 0.7179071488124984, 0.03543687132852418, 0.2473635779959815, 34.139608996255056, 51.39217022487095, 37.42090620313372, 25.167773621422903, 23.36757700783866, 40.28442907333374, 6.9519124031066895, 0.382263966436897, 0.08448535190629107, 0.043661295901983976, 0.04136335902980395, 0.010045757600372391, 0.017277876447354044, 0.03489472524129918, 0.07474481886518852, 0.04962122859433293, 0.07066659948655538, 0.032584282968725474, 0.0383937742694148, 0.0127397392477308, 0.04628010519913264, 0.07758876268884965, 0.04799797266189541, 0.016018666426784227, 0.015049984745149101, 0.023195600868867974, 0.01574473675074322, 0.035222749425364394, 0.016916644759476185, 0.017850079939567616, 0.027742877935192416, 0.02575644800838615, 0.01611787672819836, 0.02510305949752884, 0.03249814973345824, 0.024243335272850733, 0.04263980892886009, 0.03767120572073119, 0.02274831397725003, 0.11035657580941916, 0.012638939478035485, 4.247619662966047, 46.219354493277415, 46.02431508472988, 29.72677333014352, 39.518907819475444, 42.670520373753135, 49.22971017020089, 56.75123241969517, 13.43335793699537, 1.4944044394152505, 1.043494577918734, 0.31187059943165096, 0.04304266534745693, 0.03902500521923814, 22.997625385011943, 63.06888198852539, 52.549941607883994, 57.99345220838274, 53.09919670649937, 54.179735388074604, 44.2695266859872, 40.198525020054404, 41.79013844898769, 43.09776857921055, 42.09765182222639, 41.482361044202534, 41.07502637590681, 40.27130740029471, 39.78490570613316, 38.059240681784495, 37.52047388894217, 38.47353744506836, 38.00096614020211, 37.73050403594971, 37.03423547744751, 38.553952421460835, 37.58494274956839, 38.09037208557129, 38.039070061274934, 37.68263789585659, 38.717606816973, 39.50285400663103, 38.61739642279488, 38.22096695218767, 37.91846323013306, 38.21966069085257, 37.10796628679548, 37.74946914400373, 39.71952315739223, 37.885636465890066, 38.389453819819856, 37.65154470716204, 36.84077330998012, 37.64836243220738, 36.47626733779907, 39.07893398829869, 38.18905735015869, 37.43297522408621, 36.94340167726789, 38.01874310629708, 38.36455495016915, 37.29568576812744, 34.85956743785313, 34.63052701950073, 36.198158740997314, 38.61851160866873, 42.750553199223106, 45.405421665736604, 46.13903331756592, 49.9697766985212, 51.00273411614554, 51.41625268118722, 50.57592017310006, 50.55481154578072, 48.63566698346819, 44.70306995936802, 40.98357418605259, 37.986670221601216, 37.27894755772182, 36.51970747538975, 37.514863218579976, 36.81578063964844, 35.917705127171104, 37.04869467871529, 36.24126189095633, 36.61389030729021, 37.63400050571987, 36.441592352730886, 37.022809164864675, 35.255267347608296, 35.6381756237575, 37.16511174610683, 36.306224073682515, 36.4736304964338, 36.61310863494873, 36.10963521684919, 36.46159621647426, 36.19773837498256, 36.023147514888215, 35.904253414699006, 33.70956761496407, 35.29758187702724, 35.88892221450806, 34.24483251571655, 36.48573773247855, 40.91635731288365, 44.78128930500576, 45.015123980385916, 47.90655081612723, 49.0965062550136, 47.90247222355434, 46.97870227268764, 45.8439815385001, 44.73849534988403, 46.323542731148855, 44.14567157200405, 45.75528083528791, 43.664095401763916, 41.49077531269619, 40.02189138957432, 38.537985461098806, 36.470128604343955, 38.44325024741036, 39.20298712594168, 44.879293646131245, 46.94757086890084, 49.41486576625279, 47.878962993621826, 34.1657064301627, 1.8611540283475603, 0.3995996133557388, 1.5378947343145097, 1.4648200954709734, 0.057667646291000504, 0.3989244167293821, 37.19160870143345, 56.522810391017366, 42.66197408948626, 33.429763657706125, 19.101760012762888, 46.81552382877895, 10.732997008732386, 0.40712711800421986, 0.06858934595116548, 0.04345873284286686, 0.02630959145192589, 0.018325252924114466, 0.03356109519622155, 0.005458638230006078, 0.024879373643281202, 0.016998747496732643, 0.030808706102626662, 0.04035198901380811, 0.05967520070927484, 0.030796064995229244, 0.020755037632105604, 0.15169873061989034, 0.1716524777667863, 0.1359047016927174, 0.13309141408119882, 0.07819903029927186, 0.16040297783911228, 0.1465671874050583, 0.1938514837196895, 0.09772826558245079, 0.14076048827597074, 0.10590124702347176, 0.06328521735434021, 0.08006248423563582, 0.12091635167598724, 0.14774247791085923, 0.11480817943811417, 0.14709792392594473, 0.11178664264402219, 0.19883764402142592, 0.20492476810302052, 4.944901789937701, 54.55450732367379, 54.33508668627058, 38.94084201540266, 38.46563386917114, 49.46905129296439, 52.54303857258388, 61.26547704424177, 16.62616375514439, 1.6143140622547694, 2.076125647340502, 0.6646760223167283, 0.10193533876112529, 0.07602341632757868, 24.215510845184326, 64.55122457231793, 53.536870683942524, 59.55501815250942, 55.31024203981672, 57.08500303540911, 47.54350743974958, 41.521660055433, 44.41528947012765, 46.325179031917024, 44.772847243717735, 44.374326365334646, 42.02795444216047, 41.923811367579866, 41.733948366982595, 40.76331629071917, 39.60650028501238, 41.12557104655674, 40.01802471705845, 38.85871083395821, 38.28154134750366, 38.98513330732073, 39.878800187792095, 39.73964514051165, 40.77096625736782, 40.00439235142299, 40.71057946341378, 42.031352111271445, 41.72455440248762, 39.21194682802473, 38.657522269657676, 40.84611797332764, 39.524028641836985, 40.5465463910784, 43.04655340739659, 40.78571033477783, 40.457505226135254, 39.711473669324604, 38.771820136478965, 39.99612399509975, 37.62368590491158, 39.92850760051182, 39.93179757254464, 38.01860761642456, 38.86178193773542, 41.582484585898264, 41.10272536958967, 37.925168241773335, 36.13870995385306, 36.72143799918038, 38.87267323902675, 39.115488461085725, 45.38449716567993, 47.13245548520769, 47.56135736192976, 50.94502932684762, 52.875020027160645, 52.71082019805908, 52.62655591964722, 52.42880323954991, 51.71839509691511, 45.446985789707725, 42.47796147210257, 39.212509632110596, 38.16405425752912, 38.18410675866263, 39.70170797620501, 38.67151246752058, 38.738454886845176, 39.113515172685894, 38.82525525774275, 39.344660895211355, 38.87694638116019, 37.4697277205331, 38.27291168485369, 37.60783358982631, 37.898320402417866, 38.38105344772339, 39.077843121119905, 38.64365713936942, 37.97870758601597, 37.671548570905415, 37.63203763961792, 36.975182737622944, 38.18549639838082, 36.376154218401226, 36.0243148122515, 35.06336852482387, 39.11278908593314, 37.404001235961914, 37.8570168358939, 43.7690965788705, 47.09799242019653, 47.466837542397634, 48.99034125464303, 49.54474149431501, 49.166568415505544, 48.993506159101216, 49.19722039358956, 47.739092281886506, 49.3980268069676, 47.54493529456002, 48.21803855895996, 45.74908651624407, 43.83391979762486, 42.27352809906006, 40.334178175245015, 37.75818565913609, 41.174604484013145, 42.40892417090279, 47.14299242837088, 48.561950070517405, 52.55283900669643, 48.74881839752197, 36.58841821125576, 2.2770981660911014, 0.6258695189441953, 1.3010499690260207, 1.630234882235527, 0.19442191453916685, 0.912716343998909, 43.40997893469674, 60.70497281210763, 46.134503092084614, 36.57401806967599, 31.106768948691233, 53.44872236251831, 15.764215401240758, 0.5926760200943265, 0.18995623130883488, 0.20008622987994126, 0.16857884983931268, 0.10746238646762711, 0.10227341883416687, 0.09938857291958161, 0.24703804403543472, 0.15460534393787384, 0.16205335142357008, 0.0978115489706397, 0.14130863600543567, 0.05122103435652597, 0.10826201284570353, 0.32934065056698664], [0.010265619061621172, 0.04241240470271025, 0.01289441724241312, 0.05298841451959951, 0.04037516437737005, 0.028983175488454953, 0.0468904983385333, 0.027651270618662238, 0.03205458799909268, 0.05731013976037502, 0.03590908759672727, 0.047800440939941576, 0.11039431592715637, 0.01935535729197519, 0.06057850045285054, 0.0060202328272030824, 0.03249885201720255, 0.032215427939913104, 0.07994669902005366, 0.13950154797307082, 12.791244506835938, 49.69569110870361, 25.788848774773733, 34.17619126183646, 41.89667865208217, 37.01253277914864, 50.685698236737935, 26.041467905044556, 0.18426207399794034, 0.7490612428103174, 0.7885437299098287, 0.031502392808241506, 0.014102606518593217, 1.4834900136504854, 42.82371078218733, 53.629361629486084, 51.23888948985508, 53.28189958844866, 51.00841079439436, 46.65388788495745, 42.157725947243826, 38.385868549346924, 38.187368937901084, 40.2247440474374, 37.55809143611363, 38.90198768888201, 36.569157804761616, 38.90505184446062, 38.12520687920706, 38.334111418042866, 37.71180295944214, 35.43418346132551, 36.635554790496826, 36.91392741884504, 35.770007269723074, 35.43801539284842, 35.95073686327253, 36.86547415597098, 35.19087144306728, 36.2336779321943, 37.56425796236311, 36.81727450234549, 35.79098735536848, 37.53348439080374, 37.84538207735334, 35.34561824798584, 37.067288058144705, 37.39284242902483, 37.1782751083374, 35.86700759615217, 37.14137669972011, 36.640192713056294, 36.041317054203574, 36.00973401750837, 36.61476925441197, 35.79346438816616, 35.27042484283447, 36.476097106933594, 35.159514222826274, 35.42303160258702, 36.460946559906006, 35.13530669893537, 36.295367513384136, 35.25118180683681, 35.82510648454939, 38.09519760949271, 42.142109870910645, 45.83770036697388, 49.164122649601524, 52.29720088413784, 49.280994824000764, 50.17348051071167, 50.81874929155622, 45.32295002256121, 41.76091432571411, 39.39913477216448, 36.01937116895403, 35.0242258480617, 36.90338700158255, 36.6859952381679, 34.656589712415425, 33.94204044342041, 35.55821575437273, 35.031264373234336, 35.33883333206177, 34.69216448920113, 35.67864193235125, 34.32801982334682, 34.409324169158936, 34.98369353158133, 35.05158090591431, 34.70931611742292, 35.51034614018032, 34.97438294546944, 34.593055384499685, 32.74625546591622, 34.20048911230904, 35.762822832380024, 34.6611442565918, 33.7135454586574, 34.24673979622977, 33.39384841918945, 32.561575821467805, 31.810256685529435, 38.13346481323242, 46.783061844961985, 44.97239603315081, 47.816293716430664, 45.875654901777, 44.47946650641305, 46.69513586589268, 46.32160765784127, 46.577308314187185, 45.234579358782085, 46.18320649010794, 45.38669279643467, 45.84611463546753, 45.19009004320417, 44.81493943078177, 42.1806515284947, 41.898481709616526, 38.42479930605207, 41.24819285529, 43.5343690599714, 48.51025199890137, 47.925370012010845, 45.42228146961757, 13.802322915622167, 0.0685138792863914, 0.17683702813727514, 2.5281472206115723, 1.4104119007076537, 0.11998438382787363, 4.2213767511504035, 48.99782446452549, 44.29417542048863, 33.630319935934885, 21.506060804639542, 37.99581057684762, 25.285743611199514, 0.8678931891918182, 0.016470996529928277, 0.06650380071784769, 0.08394126860158783, 0.02975625418392675, 0.07801118466470923, 0.042684459925762246, 0.018900525090949874, 0.02930430575673069, 0.05284195952117443, 0.03126736184848206, 0.012644670554436743, 0.08801659742104155, 0.029812182432838848, 0.04787813998492701, 0.09817302493112427, 0.06416400162769215, 0.025890518046383346, 0.02756370567450566, 0.05585535728771772, 0.04490020585113338, 0.07755453059715883, 0.03983135587934937, 0.018352974472301345, 0.008735445411210614, 0.01715194374056799, 0.055611831069524796, 0.05718978800411735, 0.07557755775217499, 0.02469492407648691, 0.044936307306800566, 0.03447295465905752, 0.04933813699920263, 0.026107871472569447, 0.079164456709155, 0.20361448984060967, 19.453439610345022, 56.28795085634504, 24.322700704847062, 41.01173870904105, 51.87739419937134, 42.067124911717, 56.886003153664724, 25.880424295152935, 0.16910764575004578, 1.3151875989777702, 1.391056390745299, 0.07736753313136951, 0.23568726597087725, 2.4778383544513156, 46.54011113303048, 52.071662357875276, 53.636264664786204, 55.75126852308001, 52.7348609651838, 48.3854831968035, 44.39325673239571, 39.762959820883616, 39.73243291037423, 41.56855692182268, 39.3273320879255, 40.80294534138271, 39.387861319950645, 39.064714499882285, 40.07733801433018, 39.333099092756, 39.13205991472517, 37.90092250279018, 37.48199129104614, 38.01697131565639, 37.38101659502302, 37.75877973011562, 37.70556000300816, 38.87073121752058, 36.149535247257774, 39.39952734538487, 40.56194707325527, 39.44074058532715, 38.71818004335676, 38.9456501688276, 39.80740049907139, 39.30377074650356, 39.238662651606965, 38.63448551722935, 39.489846978868755, 37.74066577638899, 37.939710821424214, 37.84985671724592, 37.20463309969221, 37.256286008017405, 37.93840108598982, 38.30316414151873, 37.35639565331595, 39.54124627794538, 37.940482071467805, 37.83038439069475, 38.21759360177176, 36.392927169799805, 38.307131562914165, 36.2671091897147, 36.59026295798165, 41.194764682224815, 43.52064636775425, 47.32680702209473, 50.201645033700125, 53.736422947474885, 52.60091706684658, 51.093526227133616, 51.13130358287266, 46.736230986458914, 42.98458242416382, 40.75492286682129, 39.777321747371126, 37.93553147997175, 37.93632704871041, 39.01310675484793, 36.56391191482544, 36.18114260264805, 37.54445212227957, 37.44254984174456, 38.046247550419395, 36.20651394980294, 37.174804483141216, 36.556487764631, 36.52130208696638, 36.79099988937378, 35.69158295222691, 35.18029975891113, 36.68424081802368, 35.98902838570731, 35.978626932416645, 34.560280731746126, 36.034844807216096, 36.43583229609898, 35.686750480106895, 34.225325448172434, 35.43243598937988, 35.32752513885498, 34.418078899383545, 33.466352871486116, 39.64841876711164, 47.763650689806255, 46.43525586809431, 49.48479243687221, 47.218741689409526, 45.806586333683555, 46.97526638848441, 47.107580934252056, 48.42730440412249, 46.450514112200054, 46.99674327032906, 45.777758257729666, 46.12249313082014, 47.18675218309675, 45.44964000156948, 44.56892456327166, 43.506079469408306, 38.151561396462576, 44.293984345027376, 44.91472251074654, 50.11702639716012, 48.58445528575352, 48.15641498565674, 13.912550006593976, 0.1956556269100734, 1.6738454678228922, 2.984826475381851, 1.100906240088599, 0.1711236818560532, 5.229436601911273, 53.87512288774763, 49.19676528658186, 44.95317036764962, 24.129860401153564, 33.313346590314595, 35.057160309382844, 1.6624807119369507, 0.05350576354456799, 0.008039129382398511, 0.05373160035482474, 0.044973667444927354, 0.04687462740444711, 0.023329446990309016, 0.03285394635583673, 0.016363304540781037, 0.04735822270491293, 0.044995350031448264, 0.029475676561040536, 0.06486985446619135, 0.10268713520573718, 0.08151434561503784, 0.004095958404442561, 0.12301014789513179, 0.14304332435131073, 0.046092327418071885, 0.1757118949400527, 0.16769089177250862, 0.13040840519326075, 0.2006293564502682, 0.1150430611201695, 0.17712248781962053, 0.09902323609484093, 0.13546602880316122, 0.2107789646834135, 0.24520496811185563, 0.15209599930260861, 0.1445140354335308, 0.17616405710577965, 0.11988520914954798, 0.18979849905839988, 0.3759109244814941, 0.2967420912214688, 22.859415292739868, 64.74315466199602, 33.4281655720302, 42.3380560193743, 50.931820801326204, 47.858003752572195, 60.29732894897461, 32.82804618562971, 0.4147229646997792, 2.5608884351594106, 2.2042085230350494, 0.1634403584258897, 0.3037795307380812, 2.470189256327493, 47.07169696262905, 52.72165591376168, 53.7834518296378, 58.93835857936314, 54.68980959483555, 51.635648999895366, 46.15058817182268, 41.381549630846294, 41.4161308152335, 45.17941413606916, 41.086855684007915, 43.99739006587437, 42.2616605758667, 42.990821906498496, 42.62529802322388, 41.96488911764962, 40.796577317374094, 39.11516884395054, 39.92848675591605, 41.12275007792881, 40.388047558920725, 39.674085412706646, 39.43360825947353, 41.37895795277187, 39.060375349862234, 40.148164476667134, 42.86453839710781, 40.1969964163644, 39.315763337271555, 41.04649707249233, 42.451245648520334, 40.085213797433035, 41.04544789450509, 39.58801460266113, 40.41492666516985, 39.5497647694179, 40.16906465802874, 41.496354716164724, 39.36087104252407, 39.007287638528005, 39.60505158560616, 40.02297183445522, 37.796289580208914, 40.294149603162495, 40.51865632193429, 38.72722659792219, 42.13909782682146, 39.32846811839512, 39.70978873116629, 38.7831700188773, 38.22900949205671, 41.83574989863804, 46.09272009985787, 50.536464827401296, 53.45997844423567, 57.51997068950108, 53.860222475869314, 53.01113176345825, 53.34348494665963, 49.294554233551025, 45.584414209638325, 43.10950061253139, 40.992957728249685, 39.9170743397304, 41.75399044581822, 41.6245767729623, 37.919439452035085, 37.53332110813686, 38.80756514413016, 39.80145631517683, 40.6803617477417, 38.51046712057931, 40.52107082094465, 38.10253143310547, 39.55248498916626, 40.26075308663504, 38.08353158405849, 36.21395199639456, 39.595254625592915, 37.50920391082764, 38.167226110185894, 35.5739951133728, 36.24669190815517, 40.777198791503906, 37.512076990945, 37.09246138163975, 38.530839238848, 36.46496956689017, 35.329811096191406, 35.67266648156302, 42.82408251081194, 50.80880989347185, 46.956030300685335, 51.940452575683594, 48.81463173457554, 46.54369640350342, 47.40395981924874, 47.57584088189261, 48.7719315801348, 47.95005348750523, 48.6303585597447, 50.66728898457119, 47.85237571171352, 49.78230735233852, 48.02248150961739, 47.63719694955008, 44.55024780545916, 41.79419272286551, 46.4389523097447, 48.87779780796596, 52.722896167210166, 51.18885203770229, 46.507489340645925, 17.33713470186506, 0.20916098436074598, 1.811571900333677, 4.96827118737357, 5.13220568214144, 0.20342036097177438, 8.074255790029254, 57.515815666743684, 52.977655342647004, 44.55650813238961, 31.821141038622173, 45.47311796460833, 42.41271788733346, 2.1683236828872134, 0.15922704951039382, 0.15799934895975248, 0.2456461787223816, 0.1482165703283889, 0.14241330458649568, 0.1074107838794589, 0.14658225088247231, 0.12927032554788248, 0.12352801939206463, 0.1444176970315831, 0.09678094927221537, 0.17524130376321928, 0.15577051070119652, 0.14598311803170613, 0.08736352782164301], [0.07538513879158668, 0.0725944871082902, 0.027080602311928357, 0.026776498183608055, 0.019620342180132866, 0.009804728391048099, 0.00787629115594817, 0.022883060853928328, 0.013657085514361305, 0.03133010258898139, 0.04190963400261743, 0.015818569842459898, 0.007893291850840407, 0.03023641270452312, 0.015146195921780807, 0.001827908879412072, 0.07946501379566533, 0.032131079251744916, 0.033731078396418264, 0.11560975999704429, 0.7360814107315881, 37.37454434803554, 44.10913446971348, 27.983673538480485, 24.016606501170568, 37.46079581124442, 48.60370874404907, 40.03246654782976, 0.594610333442688, 1.0974140103374208, 0.6125227894101823, 0.005603861263287919, 0.008383180563604193, 0.10596444577510868, 15.334405047552925, 60.64078535352434, 49.699662004198345, 53.883085523332866, 49.021733215876985, 47.29956660951887, 41.23534911019461, 40.06265994480678, 37.307872908455984, 39.1480199268886, 37.059030124119346, 38.08231912340437, 39.266771589006694, 39.882274287087576, 37.160824707576204, 37.15369585582188, 35.3663968358721, 35.72275604520525, 37.442376136779785, 35.82543999808175, 37.53952237537929, 37.440520967756, 36.2875542640686, 36.321239130837576, 35.37712485449654, 35.31180483954293, 37.52248886653355, 38.0626175062997, 35.865819454193115, 36.96926634652274, 37.182548250470845, 37.16661255700247, 36.90746559415545, 37.32618835994175, 37.60140650612967, 37.73902947562081, 36.033309255327495, 35.96065541676113, 37.63471269607544, 36.915720054081504, 36.34803833280291, 36.41233696256365, 36.03086348942348, 36.06762293406895, 35.09966938836234, 35.588933740343364, 35.08405678612845, 36.35825565883091, 35.688612597329275, 34.381788458142964, 37.52633122035435, 40.347529138837544, 46.092174666268484, 47.54583508627755, 49.70576252256121, 50.84309925351824, 49.99082279205322, 50.09979486465454, 47.42135463442121, 44.95653676986694, 40.29643208639962, 40.08740595408848, 39.042212758745464, 40.978269236428396, 40.64288316454206, 39.05344452176775, 35.80558204650879, 34.77026571546282, 34.387326172419954, 33.752900055476594, 34.296884945460725, 34.198922293526785, 34.438968658447266, 34.368711948394775, 35.61882489068167, 34.931106090545654, 36.416853291647776, 35.66177865437099, 34.94725717817034, 35.0420549256461, 34.05961785997663, 33.953018597194124, 32.79213094711304, 33.68858058112008, 33.88611091886248, 33.565972668784006, 33.17641496658325, 33.24159949166434, 32.47835724694388, 33.82988262176514, 33.48607185908726, 40.570802552359446, 44.92294222967965, 43.87273938315255, 45.00990240914481, 41.673842975071494, 42.88053662436349, 43.34064980915615, 45.466562339237754, 45.030503817967, 47.275227069854736, 46.83865785598755, 47.64361708504813, 43.281468527657644, 44.71834557397025, 43.979738167354036, 42.615827628544395, 41.48619644982474, 42.20691224506923, 44.61017254420689, 46.921636717660085, 47.130569049290244, 37.74366739818028, 3.556739649602345, 0.33355538440602167, 1.179882287979126, 3.2036330657345906, 1.6241930978638786, 0.34290196001529694, 23.798221145357402, 53.34752532414028, 41.00788245882307, 26.92976556505476, 24.28338258607047, 41.87665046964373, 16.64833719389779, 0.10868161890123572, 0.010856223575371717, 0.07313219896916832, 0.04029965360781976, 0.0688936146242278, 0.0591720330661961, 0.019680178790752376, 0.01879256677680782, 0.07972439737724406, 0.04374008060299924, 0.07934578840753861, 0.018229706711801033, 0.03803171816148928, 0.08190149055527789, 0.06232530064880848, 0.0681532650653805, 0.03303317120298743, 0.04540200624614954, 0.031022366601973772, 0.019691690137343745, 0.03173668755750571, 0.044591265464467664, 0.043652705648647885, 0.026248114482898797, 0.040016175247728825, 0.01828644411372287, 0.03569268581590482, 0.009693469004040318, 0.08930219057947397, 0.019681118561753204, 0.03640767852110522, 0.009353162487968802, 0.03542567889339157, 0.00857898626210434, 0.032000406977853606, 0.09025897923856974, 2.601605747427259, 47.85619722093855, 40.672357422964915, 29.337271213531494, 41.48129449571882, 42.13730866568429, 51.116146087646484, 42.04484551293509, 0.852113233080932, 1.7575750606400626, 1.3257868587970734, 0.054469395229326825, 0.059554061852395535, 0.17200177402368613, 18.088472945349558, 62.69581930977957, 51.10678686414446, 56.25337314605713, 52.29482460021973, 49.64691128049578, 43.16701085226876, 42.518365246909006, 40.542631081172395, 41.35304117202759, 39.20796203613281, 40.54928050722395, 40.25866515295846, 42.11414337158203, 39.0598646572658, 39.628303732190815, 35.80284793036324, 38.522153990609304, 38.040160928453716, 38.69636269978115, 38.36864396503994, 40.06117650440761, 37.976807253701345, 38.44396938596453, 36.71599408558437, 38.858842849731445, 38.92407948630196, 39.53449957711356, 39.34387922286987, 40.77411379132952, 38.89102690560477, 38.66764579500471, 38.80506031853812, 40.02476794379098, 39.613997391292024, 39.79336861201695, 38.21897281919207, 37.32596254348755, 38.63343981334141, 38.81495107923235, 38.15886047908238, 37.62930004937308, 37.90718630381993, 37.2652804510934, 38.05868482589722, 36.29406125204903, 37.79513965334211, 38.326572622571675, 35.986926555633545, 35.58351067134312, 38.82932342801775, 42.38739170346941, 46.72017022541591, 48.684867177690776, 52.585599763052805, 49.63426555906023, 49.471031529562815, 51.063725403376985, 49.43733624049595, 45.17185797010149, 41.89497634342739, 41.43835115432739, 41.64284358705793, 43.02335684640067, 41.6275749206543, 40.62178495952061, 37.77497945513044, 36.61021818433489, 37.01824072429112, 35.96463326045445, 36.028268337249756, 36.60018151147025, 36.340086119515554, 36.78354099818638, 36.216578415461946, 35.10549545288086, 36.700579507010325, 37.36646359307425, 36.01308652332851, 37.11977127620152, 35.67805828366961, 35.12593705313546, 34.69390501294817, 34.81707225527082, 36.428790296827046, 35.42295517240252, 34.84962803976876, 35.68587153298514, 35.12040976115635, 35.165208271571565, 34.57532358169556, 42.39549330302647, 46.31813703264509, 45.11783572605678, 45.856161730630056, 42.728068828582764, 43.82711751120431, 46.27437032972063, 47.0483649117606, 47.091089384896414, 47.63156543459211, 47.60462032045637, 48.41263328279768, 45.68411391122, 46.335101059504915, 44.971312114170615, 44.19956874847412, 43.595245701926096, 43.57303578513009, 46.166266781943186, 48.11046654837472, 50.75180687223162, 38.82435894012451, 4.330626751695361, 1.0399887774671828, 2.956777031932558, 4.595400452613831, 0.21200304185705526, 0.18790141014116152, 23.544761283057078, 58.97672653198242, 43.779352119990754, 36.155753884996685, 22.019640377589635, 43.65239463533674, 23.385242802756174, 0.13925724822495664, 0.048839685174503496, 0.036763542996985574, 0.02916400507092476, 0.044472114715192995, 0.06404744966753892, 0.04445009964651295, 0.04301894037052989, 0.08779165627700941, 0.020350284708131636, 0.021875661964129125, 0.025096872954496315, 0.06955119648150035, 0.030018932053021023, 0.05085544986650348, 0.08290261469249215, 0.1636066809296608, 0.17785459996334144, 0.10070261026599578, 0.05059686695624675, 0.10571125043290001, 0.19222644663282804, 0.15733317684914383, 0.08532851309116397, 0.10580320549862725, 0.11842120199331216, 0.1221389225018876, 0.07239745410957507, 0.11712112889758178, 0.0940540459539209, 0.0758533211691039, 0.09310632930802447, 0.16730963651623043, 0.09029323847166129, 0.115038894915155, 0.30471732041665484, 3.0695360898971558, 54.42068501881191, 54.08606672286987, 39.06811564309256, 34.17549991607666, 48.69030066898891, 54.96926614216396, 47.98821299416678, 1.757973170706204, 2.988588490656444, 2.5433008074760437, 0.14939712626593454, 0.16156248562037945, 0.14241219178906508, 18.509709221976145, 66.2948889051165, 54.09618330001831, 58.36811992100307, 54.353006090436665, 52.47655473436628, 46.14220864432198, 44.83869184766497, 40.983258043016704, 43.020466395786826, 40.756736346653526, 43.902286597660606, 43.290584564208984, 44.45805563245501, 41.53219699859619, 41.841874735695974, 38.475479466574534, 41.11097288131714, 40.74421916689192, 41.68424790246146, 40.73071186883109, 41.670080525534495, 40.46516214098249, 40.08252484457833, 40.14187288284302, 39.998340470450266, 40.97462838036673, 41.32200704302107, 40.43032039914812, 42.607757295881, 41.00468976157052, 39.79660994665963, 41.615516321999685, 42.53892496653965, 41.75425100326538, 42.036059515816824, 39.74052061353411, 38.15293019158499, 40.64202158791678, 40.50423533575875, 38.286304337637766, 38.285873549325125, 39.61351796558925, 39.818027768816265, 39.82660184587751, 38.78073467527117, 39.2473965372358, 41.91956949234009, 38.60487576893398, 36.808540616716655, 42.002524035317556, 44.505671637398855, 49.30465344020298, 51.760494232177734, 55.14790432793753, 49.02719449996948, 52.072503089904785, 52.33427994591849, 50.642108712877544, 47.32219341823033, 44.41452864238194, 43.61240775244576, 44.1037391935076, 46.38162619726998, 44.92767742701939, 43.70077494212559, 39.701815673283164, 39.244648524693076, 39.37724447250366, 38.385250159672324, 37.96587773731777, 39.000676427568706, 38.63001782553536, 39.06759800229754, 39.50077996935163, 37.45886073793684, 39.78091744014195, 39.94110121045794, 37.95486831665039, 39.76255682536534, 36.86211470195225, 36.584256240299766, 36.431027616773335, 37.96033307484218, 38.268534319741384, 38.15896470206124, 36.48138468606131, 39.026940618242534, 36.925360679626465, 37.46231051853725, 37.03848777498518, 43.80630765642439, 48.04093245097569, 45.83627251216343, 47.63672794614519, 45.59354761668614, 45.8393679346357, 46.49470465523856, 49.7051545551845, 47.910021441323416, 47.66836656842913, 47.83507817132132, 50.38556037630354, 47.88806165967669, 48.981096676417756, 46.96469470432827, 48.0844281741551, 46.3660865511213, 45.96581472669329, 48.16826861245291, 50.330016476767405, 52.32125554765974, 43.29584435054234, 4.425390192440577, 1.107707223721913, 4.717239720480783, 9.930304629462105, 6.342379076140268, 0.6313848687069756, 30.474434239523752, 60.97236033848354, 48.00959954942976, 35.97680650438581, 31.777131148747035, 51.96895408630371, 29.503972394125803, 0.22675693088344165, 0.2591556752366679, 0.17137354559132031, 0.1561804408473628, 0.12074861781937735, 0.15448004566133022, 0.17278559053582804, 0.11920716267611299, 0.13832306835268224, 0.16855713671871594, 0.21854513723935398, 0.10488209421081202, 0.1343491601624659, 0.2310817502439022, 0.17240977713039943, 0.11961523363632814], [0.042086694323058636, 0.03944112021209938, 0.03620464388015015, 0.038969786039420536, 0.054271975465651066, 0.060738661858652315, 0.017014676106295416, 0.07535573108387844, 0.03383538619215999, 0.01329905481543392, 0.018995369019519006, 0.012912541760929992, 0.05358489429844277, 0.06370225176215172, 0.036832719642136774, 0.027236583942015256, 0.02579228313905852, 0.0995203172788024, 0.055749800987541676, 0.13612249786300318, 0.10290663449891976, 16.39564684459141, 44.753374917166575, 27.341102395738872, 21.28252509662083, 34.20680849892752, 42.49183007649013, 50.07135936192104, 6.325773315770285, 0.5341217592358589, 0.3272229427737849, 0.09886734267430645, 0.02606645878404379, 0.10395434006516423, 0.9285863552774701, 35.3044501713344, 58.032626152038574, 54.917748723711284, 52.44840063367571, 45.13193709509713, 43.75130224227905, 40.790257930755615, 40.406790324619834, 38.4129387310573, 42.57967962537493, 39.18786089760916, 41.11104931150164, 37.56058931350708, 38.18637187140328, 35.90485095977783, 37.221298354012625, 35.784209387642996, 36.96202632359096, 36.51663984571184, 37.191052845546174, 35.97387783867972, 38.35987533841814, 36.947098118918284, 36.23683588845389, 35.68966177531651, 36.63597863061087, 36.64124883924212, 38.31957231249128, 36.51197065625872, 37.10375567844936, 35.40904835292271, 36.5678584916251, 36.52110753740583, 37.76867396490914, 35.48592322213309, 37.18689087459019, 37.826879024505615, 36.07047516959054, 34.96451302937099, 37.07911041804722, 36.06900215148926, 36.661878040858674, 34.34556402478899, 36.54793105806623, 36.00308459145682, 35.65244722366333, 35.7784423828125, 37.55195270265852, 37.15804195404053, 40.42092990875244, 42.16615063803536, 51.08080060141427, 47.77539314542498, 58.967012950352256, 89.56678921835763, 46.856525148664204, 49.414598260607036, 49.179836000714985, 44.92268862043108, 44.13641309738159, 43.20718881062099, 44.94694825581142, 45.50931807926723, 46.32181262969971, 43.176356179373606, 38.365298407418386, 36.03168337685721, 35.283126149858745, 33.45735148021153, 35.703276770455496, 36.4763194492885, 34.2805358341762, 33.82123906271798, 36.7962075642177, 35.7317087990897, 35.86574649810791, 33.70568357195173, 34.62237678255354, 33.36485011237008, 33.60812738963536, 34.90227801459176, 33.43409238542829, 33.7047073500497, 34.29016951152256, 33.23467213766915, 33.84592253821236, 32.93738651275635, 32.953221457345144, 32.750726631709504, 34.8529805455889, 32.423671449933735, 39.81499835423061, 44.906398568834575, 45.534178733825684, 44.03283282688686, 44.04277222497122, 43.83494813101632, 44.30147450310843, 43.38475349971226, 41.7582288469587, 39.96023307527815, 46.93872928619385, 46.65079941068377, 47.720954009464805, 44.848447118486675, 46.86515481131417, 43.04706409999302, 44.631288119724815, 45.191823618752615, 50.039755480630056, 42.732724121638704, 18.385610921042307, 0.046593781760228534, 0.48875132522412706, 3.5319070049694608, 2.411833724805287, 0.3918483278581074, 2.1361613401344846, 48.743819168635774, 43.48565871374947, 30.53633921486991, 18.48470960344587, 30.830112525394984, 35.27203335080828, 2.4356545380183627, 0.18806405498513154, 0.056108179435666115, 0.1481571170900549, 0.11379153720502343, 0.05006125516125134, 0.07744774954127413, 0.029949504349912916, 0.03280040315751519, 0.049067540626440725, 0.05795007970716272, 0.023507406369649937, 0.06095193898571389, 0.062068027311137745, 0.017496108576389294, 0.056909502151289156, 0.0674570474241461, 0.023196767949100052, 0.03201446622344, 0.07325150578149728, 0.042922506973679574, 0.05292254573266421, 0.01008186923406486, 0.024276914274586097, 0.11373530700802803, 0.03715090846110668, 0.02981319684269173, 0.03501718045611467, 0.04349973671404379, 0.045561665536037514, 0.05940679261194808, 0.07498130867523806, 0.023517760814034512, 0.04600380573953901, 0.05279378692752548, 0.024135643283703496, 0.07907292233513934, 0.10893165227025747, 22.508133479527064, 53.20075505120413, 26.292469842093332, 24.009903226579937, 45.595447949000764, 45.903100286211284, 54.749866349356516, 5.512597407613482, 0.7513445402894701, 0.3062995012317385, 0.11591713636049203, 0.21896129633699143, 0.05004584223830274, 1.659580490418843, 39.23766905920846, 57.720662457602366, 56.20949527195522, 54.64430584226336, 47.59239149093628, 43.462587220328196, 43.90274517876761, 42.51041998182024, 41.534361362457275, 44.099174227033345, 40.85395206723894, 42.75258207321167, 39.090989112854004, 40.58922570092337, 38.75764233725411, 37.94341768537249, 37.62633664267403, 39.86747809818813, 38.286714281354634, 37.537232943943565, 37.410150391714915, 39.25098180770874, 38.19928509848458, 37.90185703550066, 38.42348262241909, 38.750739301954, 37.27025188718523, 39.925870759146555, 37.312000138419016, 38.79924815041678, 38.305342401777, 39.029865809849326, 38.42249945231846, 38.85992329461234, 37.36556032725743, 36.69983952386038, 38.338113580431255, 38.31129700796944, 36.29242842538016, 38.64876753943307, 38.70324489048549, 37.24704837799072, 37.73870638438633, 36.382893971034456, 37.07918684823172, 35.85330574853079, 37.59731749125889, 39.21966627665928, 39.58467946733747, 39.82416650227138, 43.74993692125593, 51.41323021480015, 50.3811308997018, 51.83577101571219, 62.37726524897984, 50.06025614057268, 50.069295746939524, 49.22024672372, 45.70615707124983, 45.67706148965018, 42.907554694584434, 44.21790157045637, 45.763299056461875, 48.402322156088694, 44.18146869114467, 40.2334258215768, 36.37080063138689, 37.38992418561663, 35.23149756022862, 36.6257369858878, 37.464586053575786, 36.16357060841152, 35.63345084871565, 39.64320761816842, 39.04377262932913, 37.24910504477364, 34.61027649470738, 36.704557350703645, 36.08141163417271, 35.55997017451695, 35.86140039988926, 34.57766512462071, 36.026732785361155, 36.21126651763916, 35.48493310383388, 35.591455936431885, 34.208027907780235, 35.127941608428955, 34.442672048296245, 35.57733372279576, 34.8964832169669, 42.041110856192454, 45.55826813834054, 47.995807375226704, 46.664834771837505, 45.03010777064732, 45.02362857546125, 45.17923695700509, 44.67739289147513, 42.87742383139474, 41.64292696544102, 47.152740750994, 47.32833562578474, 48.647385120391846, 47.60907064165388, 50.02649484361921, 44.99006530216762, 47.71700395856585, 46.701802662440706, 50.90258625575474, 44.385380949292866, 19.30483501298087, 0.32360977094088283, 1.6350857019424438, 5.074327187878745, 3.4047905802726746, 1.4302497676440646, 2.2047159586633955, 52.1170688356672, 50.11110653196062, 36.86255243846348, 22.57206038066319, 29.4111270904541, 45.71145159857613, 5.5228229846273145, 0.23446462729147502, 0.037447692892913303, 0.016898371811423982, 0.016391475618417774, 0.10788651835173368, 0.14612689960215772, 0.022285890665703585, 0.030435416847467422, 0.05151355419574039, 0.04671662713267973, 0.017795524027730738, 0.013272624180120016, 0.0179736123287252, 0.08835196335400854, 0.029640852340630124, 0.039430144908172746, 0.1143610520022256, 0.12158040675733771, 0.14895953903240816, 0.1413304576916354, 0.22370813733765058, 0.15243184699543885, 0.06440739892423153, 0.17958126802529606, 0.13213161272662027, 0.11551289233778204, 0.22898046299815178, 0.14474724791944027, 0.15288274708603108, 0.1882326030837638, 0.18716278406126158, 0.1475565864571503, 0.16177113513861383, 0.18109058775007725, 0.12832302280834743, 0.2679676195340497, 0.20555611779647215, 27.287674222673687, 59.089398520333425, 37.41640029634748, 28.468848875590734, 46.62476451056344, 50.4722078868321, 60.14534405299595, 8.957947662898473, 1.07991757776056, 1.5516894055264336, 0.3101865569395678, 0.23999949172139168, 0.5115058613674981, 1.997664417539324, 37.97554962975638, 60.717097418648855, 58.01145846503121, 58.00196375165667, 47.983665398189, 47.23412847518921, 45.03770215170724, 44.87597935540335, 43.81081008911133, 47.36449057715279, 43.38869660241263, 46.95016949517386, 40.301104749952046, 43.915345736912315, 39.52124241420201, 41.29413781847273, 38.83750145775931, 41.466786657060894, 40.68393659591675, 38.23950822012765, 39.342388834272114, 42.555638858250205, 41.38490908486502, 40.79148081370762, 40.491197041102815, 39.70853458132063, 38.831581592559814, 42.284176213400706, 40.008088793073384, 41.34904248373849, 40.12793479646955, 41.131935596466064, 41.05985498428345, 42.092134952545166, 38.685485294886995, 37.81549440111433, 42.06796564374651, 40.07965176446097, 37.85024234226772, 40.8848090171814, 40.281236376081196, 39.64863068716866, 39.297145639147075, 40.31755461011614, 40.25006675720215, 37.836724621909006, 38.997605323791504, 40.89774308885847, 40.92519889559065, 42.91283532551357, 45.95820297513689, 54.39777333395821, 52.291951520102366, 53.24152708053589, 71.38721670423234, 51.76536839348929, 51.487006187438965, 53.24606772831508, 48.16842842102051, 49.93569231033325, 47.04707949502127, 47.16093267713274, 47.974128995622905, 51.16021851130894, 46.79975836617606, 43.210520471845356, 38.84413698741368, 39.387434005737305, 37.06728458404541, 38.583089692252024, 41.62762703214373, 38.00539909090315, 37.294643538338796, 40.41713619232178, 40.20406968252999, 39.52679055077689, 35.6854372705732, 38.499680042266846, 36.609047412872314, 37.632058484213694, 37.91078199659075, 38.35545628411429, 37.66851915631975, 39.36068344116211, 38.07963711874825, 39.21969059535435, 35.0718731198992, 36.45550959450858, 36.223151411329, 37.767409392765586, 34.81354604448591, 43.12348733629499, 47.65137127467564, 49.20356062480381, 47.68618174961635, 47.3129940032959, 46.62504243850708, 46.24798107147217, 46.16097225461687, 45.34743547439575, 41.47867849894932, 49.381059306008474, 46.959650312151226, 51.08078670501709, 50.81502158301217, 51.75355992998396, 46.13651459557669, 49.97171524592808, 48.396937302180696, 53.49473333358765, 44.6714243888855, 22.29663031441825, 0.21910642140677997, 2.762858888932637, 6.3890379667282104, 5.632843800953456, 3.109418966940471, 2.594914415052959, 56.91654396057129, 52.404585293361116, 40.86857107707432, 29.353113106318883, 38.71696758270264, 53.60345179694039, 7.832282168524606, 0.5531944015196392, 0.1847020768161331, 0.3046874377344336, 0.2124433975134577, 0.19804025680891105, 0.1978856051074607, 0.15606499489928993, 0.1457154088254486, 0.1245616182152714, 0.37449742747204645, 0.1403786494795765, 0.11788366655153887, 0.1734028131301914, 0.16598277485796384, 0.1398832510624613, 0.21949839751635278], [0.055815462821296284, 0.036895562162888904, 0.05420626613444515, 0.06454621361834662, 0.05064093102035778, 0.02393217438033649, 0.025268063947026218, 0.07364899159542151, 0.01950544923810022, 0.026277238902236735, 0.03015726837994797, 0.1137749334531171, 0.0753460144624114, 0.05068962947864618, 0.032938478248459954, 0.04765356185712984, 0.02983828228233116, 0.09042907439704452, 0.03328966761806181, 0.09434530711067574, 0.06595612117754561, 3.1703629195690155, 36.81108365740095, 44.70716939653669, 29.617905480521067, 28.630352803639003, 35.32979372569493, 50.98112521852766, 29.575274808066233, 0.1815802864730358, 0.10727661036487136, 0.04670411155426076, 0.11223714239895344, 0.03025319966088448, 0.10285570366042, 11.23846195425306, 59.41208675929478, 50.69327177320208, 54.40876885822841, 49.72711433683123, 48.4618821144104, 41.60428803307669, 43.352454798562185, 42.04615524836949, 45.439638069697786, 42.40095806121826, 42.025324548993794, 39.61147519520351, 37.8627803666251, 36.317747661045615, 36.820501940590994, 35.68581942149571, 37.30313423701695, 38.77250453404018, 40.47300665719168, 38.84068373271397, 38.95950835091727, 37.932953698294504, 37.88598387581961, 35.36996473584856, 37.37935250146048, 36.95041935784476, 39.41897882734026, 35.65969072069441, 39.00709656306675, 38.716029575892854, 37.43663692474365, 37.02491446903774, 36.68480709620884, 37.392776421138215, 38.21319886616298, 34.88407373428345, 37.456602573394775, 36.873547962733674, 38.33367715563093, 36.86089529309954, 35.8396177973066, 34.05004671641758, 36.54578059060233, 34.33237634386335, 35.62436955315726, 35.11730739048549, 38.27292210715157, 39.26709120614188, 43.931819915771484, 47.35178232192993, 51.311644077301025, 50.04800994055611, 57.91760914666312, 65.26574257441929, 53.198312759399414, 52.35010099411011, 47.14708144324166, 46.272511686597554, 46.44406270980835, 49.639337744031636, 47.05324602127075, 48.59458228519985, 48.148316860198975, 47.85491180419922, 39.341495990753174, 34.36777741568429, 33.4953407560076, 34.20539106641497, 33.77086462293352, 35.956371852329795, 35.39350175857544, 35.13261079788208, 35.372351442064556, 35.91178526197161, 34.89547920227051, 35.29356929234096, 33.99658032826015, 33.96995483125959, 33.132780279432026, 34.160926069532124, 33.168365478515625, 33.60991655077253, 32.058957031794954, 34.27003363200596, 32.41445813860212, 34.68786008017403, 33.21098572867257, 32.678045000348774, 32.47922577176775, 33.99872037342617, 36.04701457704817, 40.00807837077549, 43.18580572945731, 45.2374142238072, 43.29236330304827, 46.13823080062866, 44.9113005229405, 47.448737485068186, 44.59474754333496, 42.69441870280674, 39.9200690133231, 39.82792200360979, 44.83873006275722, 49.665577616010395, 44.5934864452907, 47.80675731386457, 47.56541163580758, 48.34941162381853, 45.33409145900181, 35.0589598928179, 3.9190515109470914, 0.16202439154897416, 0.8223803713917732, 2.2602192546640123, 0.4890017860702106, 0.8944956702845437, 11.58893517085484, 55.343020166669575, 36.8837513923645, 37.78187206813267, 35.966439792088096, 36.16963638578142, 22.878147636141094, 0.6044730842113495, 0.06975822430104017, 0.009407509750287448, 0.023517216289682046, 0.017669866127627235, 0.03872300963848829, 0.028467258172375814, 0.019864965928718448, 0.08654874975660018, 0.006886462506372482, 0.008195597013192517, 0.040897846687585115, 0.028479648221816336, 0.01373704323279006, 0.05427123246980565, 0.16709778431270803, 0.05840317825121539, 0.06702719548983233, 0.021809136694563285, 0.037328121451927085, 0.11344331981880323, 0.031555817262934785, 0.029267318812864165, 0.04416623791413648, 0.019725754291617444, 0.01261391765105405, 0.06096707031662975, 0.0743660538324288, 0.04784215727288808, 0.05525407348094242, 0.03988339612260461, 0.010128054568277938, 0.08336775723312582, 0.05263439905164497, 0.024509665356682878, 0.09990898213748421, 0.023915472240852456, 0.10568651783147029, 6.461367845535278, 44.15812621797834, 43.28299018314907, 25.20346130643572, 38.650660923549104, 41.91855158124651, 56.93824665887015, 27.444828578404017, 0.25806513375469614, 0.09596299566328526, 0.13894158016358102, 0.6473825531346458, 0.844391287437507, 0.1875916589051485, 12.598037685666766, 62.49772616795131, 51.53627238954817, 57.52439669200352, 50.586672510419575, 49.30614035470145, 42.364017963409424, 45.695505482809885, 44.298424243927, 45.72497279303414, 43.466092586517334, 45.07001822335379, 41.25159747259957, 40.959540367126465, 36.92393977301461, 38.09054926463536, 36.79126392092024, 38.89239222662789, 38.15296145847866, 40.64785460063389, 39.365925856998985, 40.07391255242484, 41.38557611192976, 40.431901114327566, 38.73976462227957, 38.74555594580514, 37.71115330287388, 40.400696754455566, 37.277613503592356, 40.07287379673549, 40.090994698660715, 39.33358894075666, 38.83502095086234, 38.09109122412545, 38.396228313446045, 39.998364789145334, 37.036222662244526, 40.16516671861921, 37.12249844414847, 39.938287190028596, 37.8959128516061, 39.08595514297485, 36.396074703761506, 37.52007436752319, 35.45051172801426, 37.06279257365635, 38.45702157701765, 40.44292443139212, 40.81806809561593, 43.2350788797651, 47.11824294498989, 52.44281080790928, 52.3614057132176, 57.777224268232075, 71.11251967293876, 48.21904257365635, 53.592376368386404, 48.72263411113194, 48.863897936684744, 48.316400732312886, 50.838850430079866, 50.0301183291844, 50.82081290653774, 50.59009449822562, 47.67540509360177, 41.62036616461617, 37.041416440691265, 37.114264828818186, 36.2979279245649, 36.855173451559885, 37.54557078225272, 35.73865352358137, 36.261957100459504, 37.048173563820974, 37.052015917641775, 35.904708521706716, 36.10821778433663, 35.80524158477783, 35.380831718444824, 36.06016404288155, 35.90263101032802, 35.87034273147583, 36.204957553318565, 35.60600893838065, 34.72453614643642, 35.249031339372905, 36.6815379687718, 34.43939249856131, 34.51466580799648, 34.25652633394514, 35.68199096407209, 37.62028823580061, 41.648280552455354, 45.77883870261056, 46.60344396318708, 45.90228387287685, 47.801903997148784, 45.313813141414094, 48.30826439176287, 45.23959248406546, 42.62498882838658, 40.19859102794102, 42.588104316166465, 46.93368141991751, 48.47580977848598, 47.309895106724326, 49.389369351523264, 51.44458743504116, 49.543852124895366, 47.62799406051636, 36.32054083687918, 4.875529672418322, 1.0956279976027352, 1.2939625893320357, 4.587996278490339, 4.131338519709451, 0.7161321554865155, 12.23284123625074, 59.850163732256206, 40.98133339200701, 37.67659643718174, 31.017046860286168, 36.60804339817592, 31.16969530923026, 1.01913897054536, 0.09873820388955729, 0.0971125764772296, 0.053580202228788815, 0.06447766122541257, 0.06333952051188264, 0.009569783944503536, 0.03250216666076865, 0.04150908121040889, 0.08183369133621454, 0.043996923070933135, 0.05828028877398797, 0.016530112197090472, 0.04510480112263134, 0.06133643085403102, 0.12357186632496969, 0.1564181859471968, 0.21199996130807058, 0.1020983432286552, 0.1536549606493541, 0.20404415178511823, 0.1404566267239196, 0.13911942419196877, 0.11029482233737196, 0.21025984468204634, 0.09754501362996441, 0.10281473371599402, 0.09179392723100525, 0.21695860022945063, 0.25119179114699364, 0.10244111876402583, 0.13902711628803185, 0.12564465509993689, 0.12974330516798155, 0.16687139788908617, 0.16381007858685084, 0.23248192082558358, 0.2840017277215208, 6.0222443001610895, 52.8186423437936, 54.9058256149292, 37.871538570949006, 38.67046676363264, 47.762990610940115, 56.49190132958548, 38.81225865227835, 0.47306886102472034, 0.4571806107248579, 0.25907688375030247, 0.4464946341301714, 0.3268416060933045, 0.2823997879666941, 13.459563936506, 61.99702508108956, 53.215342794145855, 60.60766329084124, 53.28679459435599, 53.99447209494454, 45.01179231916155, 48.72472551890782, 46.16492577961513, 49.39890922818865, 45.670568398066926, 47.38280255453927, 43.800095966884065, 43.76303774969918, 39.28312764848982, 40.35754149300711, 38.95009701592581, 40.91436317988804, 41.8549234526498, 45.52649402618408, 42.09416035243443, 40.202832903180806, 42.692841461726594, 41.23460217884609, 39.07432733263288, 41.09260531834194, 40.66766044071743, 43.42874254499163, 39.34282309668404, 42.124530928475515, 42.20478957039969, 42.11387586593628, 41.091135774339946, 40.50938395091465, 38.627374035971506, 42.03958920070103, 37.39772701263428, 41.25847271510533, 41.674899101257324, 43.0004277910505, 40.091731207711355, 41.37852716445923, 38.44435848508562, 39.791402271815706, 38.12209756033761, 39.06675379616873, 40.94222893033709, 42.973302023751394, 43.042068345206125, 47.571328026907786, 48.36761243002755, 55.131916522979736, 52.8238639150347, 62.68860707964216, 78.73627076830182, 47.866973876953125, 56.97401251111712, 49.464368207114084, 52.55594832556588, 49.285347870418, 52.29385880061558, 52.001627990177695, 51.543171950748985, 52.44793857846941, 50.45274945667812, 43.234384059906006, 39.09219809940883, 38.95934854234968, 37.77889823913574, 39.27801724842617, 39.68339599881853, 38.033813749040874, 37.93938078199114, 38.340309211185996, 39.307960510253906, 37.16550431932722, 37.84707396371024, 38.68808044706072, 37.29960455213274, 36.80813414709908, 37.24936212812151, 36.66764851978847, 39.06944622312273, 36.07898671286446, 36.10134254183088, 36.56776816504342, 40.00587926592146, 36.63810477937971, 37.091829095567974, 35.720855712890625, 37.82093831471035, 38.84270565850394, 44.138619150434224, 46.61545392445156, 48.00090387889317, 46.49310309546334, 49.38651016780308, 46.374521664210725, 49.95699201311384, 46.702608653477256, 43.278484276362825, 42.19180686133248, 43.455451420375276, 45.74209662846157, 49.07808310644967, 49.77738107953753, 52.214051791599815, 52.543417249407085, 51.36404391697475, 46.78078630992344, 37.26623582839966, 5.7050759707178385, 1.5807879183973585, 2.9177498689719608, 6.110087335109711, 7.994450518063136, 1.5103494695254733, 14.77494478225708, 67.78326252528599, 45.814802578517366, 46.00844539914812, 43.63917916161673, 43.38861322402954, 38.94506999424526, 1.1888030150106974, 0.14403029424803598, 0.2028003428131342, 0.14776210114359856, 0.1021218883938023, 0.1576708565865244, 0.06825024129024573, 0.10463189120803561, 0.1359530540981463, 0.1154465451836586, 0.09534669587654726, 0.19773366754608496, 0.09605684384171452, 0.07607054058462381, 0.1609926519117185, 0.2141183747776917, 0.2742330761892455], [0.042875440392111025, 0.018580855369301777, 0.08480721499238696, 0.09139959660491773, 0.006888770373604659, 0.04412068107298442, 0.06828171852976084, 0.01685113729243832, 0.04960926262927907, 0.0016629687847203708, 0.027169222378038933, 0.017185899329238703, 0.011762499543172973, 0.04820949238325868, 0.03747340597744499, 0.03877140614869339, 0.030191218879606043, 0.01574030252439635, 0.07211411824183804, 0.06987381952681712, 0.010293399981622185, 0.02971447678282857, 18.94601093019758, 46.02868202754429, 28.917919635772705, 29.94327919823783, 37.43297869818551, 41.02049343926566, 53.10447038922991, 6.929444534437997, 0.23102480758513722, 0.12711723893880844, 0.5952670467751366, 0.19109258747526578, 0.3187586526785578, 0.5319800855857986, 36.60625076293945, 58.715800830296104, 53.036336353846956, 52.425593171800884, 48.660082953316824, 45.99290575299944, 44.03665781021118, 43.47904750279018, 45.520699228559224, 46.03018978663853, 43.22440644672939, 39.81694384983608, 34.554301806858604, 38.045948777879985, 35.73794133322579, 38.64251068660191, 44.2172588620867, 47.96003457478115, 48.8948313168117, 48.81150157111031, 43.55988284519741, 40.992648533412385, 38.68044090270996, 37.04665538242885, 35.67114135197231, 37.08983843667166, 37.68690061569214, 37.19077839170183, 38.14363350187029, 38.79150785718645, 37.60908426557268, 36.955828530447825, 35.39478717531477, 37.8826904296875, 36.10274955204555, 35.39864342553275, 37.34685230255127, 36.34615189688546, 34.253479548863, 36.03356981277466, 36.2014730317252, 36.997382232121055, 35.538701738630024, 37.49746492930821, 36.51686913626534, 37.99081482206072, 38.288343633924214, 42.53211225782122, 47.347127028873985, 52.34527547018868, 48.60869060243879, 53.42234352656773, 31.72836869103568, 17.788098846163066, 84.96933991568429, 50.292576108660015, 49.89372171674456, 48.71948310307094, 51.09386668886457, 51.0612587928772, 49.174802030835835, 47.222941875457764, 48.37171881539481, 50.19388736997332, 42.58911180496216, 34.60201161248343, 34.042674677712576, 36.21475798743111, 33.623132024492534, 33.566570213862825, 36.01053653444563, 34.66454539980207, 35.52169949667794, 35.8354731968471, 35.865534578050884, 34.931543827056885, 33.354386125292095, 34.69576713017055, 32.8350499698094, 34.15086507797241, 33.87331233705793, 33.402123723711284, 34.21454184395926, 35.15312188012259, 33.22738695144653, 32.33513750348772, 33.27685465131487, 33.01591157913208, 33.688115051814485, 32.14465958731515, 34.64645229067121, 37.13595015662057, 41.89166900089809, 44.24398858206612, 44.444669927869526, 45.35691976547241, 46.21849291665213, 45.39582967758179, 47.551407541547505, 43.71868044989449, 46.33574376787458, 44.75371537889753, 41.38505847113473, 47.96794857297625, 46.023370129721506, 48.008526052747456, 50.311989375523154, 47.43950680324009, 47.06138236182076, 19.297742639269146, 0.706506783408778, 0.8513895347714424, 1.4187306314706802, 6.237514691693442, 0.48692204909665243, 0.07837027218192816, 27.459946121488297, 53.98354605266026, 35.60921900612967, 32.36018575940813, 31.338640757969447, 38.346371514456614, 13.261053902762276, 0.2080986156527485, 0.014807060726785233, 0.0497709982363241, 0.08062870813799755, 0.11200390955699341, 0.04745247461167829, 0.02267572090827993, 0.03397018735163978, 0.08097316644021443, 0.013444287602656653, 0.04007606614114983, 0.06887498883796589, 0.008516376139596105, 0.02711030518236969, 0.020824120978691747, 0.051359760841088634, 0.01042165158183447, 0.03314304637855717, 0.04825915436127356, 0.03805161280823605, 0.08751063421368599, 0.023367092113143632, 0.06291534791567496, 0.0393204732931086, 0.02891167825353997, 0.003230118458824498, 0.029097104910761118, 0.07106771546282939, 0.03198936042775001, 0.029903116303363016, 0.12010601801531655, 0.03720469253935984, 0.0952815633001072, 0.03050819312089256, 0.006418816595604377, 0.06360673438757658, 0.028344684213932072, 0.03426665626466274, 0.26476794694151196, 26.18828681537083, 52.96448850631714, 27.39943425995963, 35.412904603140696, 44.691188539777485, 45.273416314806255, 56.82550866263253, 5.527266791888645, 0.06570090380098138, 0.024134523700922728, 1.4144409873655863, 3.7320833035877774, 0.9898602387734822, 1.2445303904158729, 41.135503496442524, 59.401344844273154, 53.30929980959211, 54.49412400381905, 51.62369115012032, 48.18744216646467, 46.24344389779227, 45.85018975394112, 47.0210029057094, 47.75701168605259, 45.26077406747, 41.02555520193917, 37.34829405375889, 39.23986121586391, 38.7363634790693, 38.140326159340994, 44.10215153012957, 48.73179183687483, 48.72708790642874, 49.98479870387486, 45.16514253616333, 41.65070199966431, 40.467298712049214, 38.394442626408164, 38.23215702601841, 38.83419411523001, 40.64914001737322, 37.9931320462908, 39.677590778895784, 41.22756712777274, 38.952233586992534, 39.541597161974224, 37.63664776938302, 39.04727799551827, 37.495463848114014, 36.42943300519671, 38.9820100920541, 39.114828382219585, 36.49666724886213, 38.56328732626778, 38.16404383523123, 37.9116644178118, 37.93668835503714, 38.6520540373666, 37.21670906884329, 37.74127721786499, 40.97584431512015, 43.85201290675572, 47.71726451601301, 53.353875977652415, 49.39605699266706, 55.00943367821829, 35.52717120306832, 22.358662094388688, 68.39761529650006, 52.48275252750942, 51.613901138305664, 49.21290595190865, 53.583236013139995, 51.3312623160226, 49.61589799608503, 48.385524885995046, 48.59572526386806, 51.14153480529785, 43.15290600912911, 37.33159405844552, 36.597992828914094, 39.368250029427664, 35.32012183325631, 36.345213890075684, 37.868912151881624, 35.960231576647075, 36.52265698569161, 37.300712789808, 36.653922353472026, 37.0840471131461, 34.96057687486921, 36.361729758126394, 34.1708585194179, 35.71892063958304, 36.66378879547119, 34.964540822165354, 35.62229898997715, 37.202906472342356, 34.15473175048828, 34.60123688834054, 34.86217301232474, 35.11459411893572, 34.979993615831646, 34.165890557425364, 36.15900216783796, 38.11202962057931, 44.90737131663731, 46.94190113885062, 47.679674761635916, 47.29456043243408, 47.36175993510655, 46.096079553876606, 48.47289500917707, 44.572728702000205, 47.00897209984915, 44.49815368652344, 44.060163566044395, 49.37198148454939, 46.76659114020211, 50.0357984815325, 51.68378611973354, 46.69915887287685, 48.38373225075858, 21.205077001026698, 0.5934255570173264, 1.898889694895063, 2.9160616738455634, 7.1425071358680725, 2.448118520634515, 0.12172425618129117, 29.78331777027675, 60.30209541320801, 38.33733538218907, 49.956884316035676, 37.87333468028477, 41.01140866960798, 19.016649791172572, 0.2476102119045598, 0.01298546900839678, 0.03341887764898794, 0.07917032603706632, 0.09471710358879395, 0.06968653029096977, 0.02158292499370873, 0.003026551379921979, 0.02311653796849506, 0.007473317690060607, 0.024458251061982343, 0.022092482740325586, 0.046988960555089374, 0.045317701662757566, 0.04412597364612988, 0.01964336148064051, 0.0811802688986063, 0.2019225356302091, 0.13699950437460626, 0.2518514628921236, 0.14102183282375336, 0.13542404105620726, 0.1452528650739363, 0.31335914241416113, 0.10958949197083712, 0.1466728217367615, 0.0916593126686556, 0.18498015403747559, 0.1313898925270353, 0.0959802440234593, 0.14849958728466714, 0.1419480602656092, 0.13921976595052651, 0.10628705524972507, 0.13049791753292084, 0.32687555998563766, 0.18031580932438374, 0.1183864881417581, 0.20538917104048388, 29.629606246948242, 59.79449476514544, 38.5339937210083, 40.01637799399239, 47.66083819525582, 51.18936620439802, 62.356080191476, 9.368410757609777, 0.3475995122322014, 0.2821738086640835, 2.514125321592603, 4.521894156932831, 0.9218730926513672, 1.4020764508417674, 41.39980254854475, 62.72860091073172, 55.794656549181255, 58.11689737864903, 54.69793551308768, 51.295326232910156, 48.56368712016514, 47.77873870304653, 50.235757214682444, 50.51052720206124, 48.71015862056187, 42.43166215079171, 38.155334268297466, 43.22752618789673, 40.1620261328561, 41.644045625414165, 48.035811628614155, 52.04473461423601, 52.51817791802542, 54.4272267477853, 49.24690348761422, 44.25835050855364, 43.776326179504395, 40.24437965665545, 39.20364373070853, 40.67169039590018, 42.04555422919137, 41.339884757995605, 42.81265272412981, 43.10123225620815, 40.17283752986363, 40.5531576020377, 39.56189285005842, 41.870560373578755, 39.56071860449654, 37.39782428741455, 41.237040996551514, 39.31519705908639, 38.21081910814558, 40.3960588318961, 40.805057593754356, 40.53484909875052, 39.50715146745954, 40.22088084902082, 39.185832023620605, 40.89540154593331, 45.00850582122803, 46.128406047821045, 50.43397889818464, 54.914552552359446, 52.62101125717163, 55.38029030391148, 40.01274061203003, 28.40998200007847, 75.65660681043352, 54.148134980882915, 53.774301052093506, 50.72581018720354, 54.972528321402415, 54.05297940117972, 51.46327461515154, 50.76064150674002, 51.804434640066965, 52.42321341378348, 45.37273039136614, 39.17614623478481, 38.62717948641096, 41.38357155663626, 36.14739867619106, 37.40496008736746, 39.387135233197895, 37.60008634839739, 38.530352864946636, 39.39783893312727, 38.78164141518729, 39.08841480527605, 36.003880160195486, 37.5065462248666, 35.601221629551475, 37.467594623565674, 39.270631313323975, 37.00583471570696, 38.06585536684309, 39.4011949130467, 38.08783251898629, 36.68571731022426, 36.24669885635376, 36.149972983769004, 37.66004235403878, 36.234605516706196, 37.10161215918404, 40.91651712145124, 46.471129417419434, 48.06836741311209, 49.08931139537266, 49.216314043317524, 49.30444152014596, 48.57218129294259, 50.062976360321045, 45.54599414552961, 48.85361112867083, 47.34003291811262, 46.21711369923183, 50.23407575062343, 46.53972550800869, 50.174765927451, 52.27982691356114, 48.38035542624337, 49.57379886082241, 23.1844676562718, 1.2636218688317706, 1.6035937517881393, 4.360795829977308, 14.925328118460518, 5.250726750918797, 0.47214073368481224, 35.121879305158345, 62.96286637442452, 44.40882764543806, 41.52594709396362, 38.69042198998587, 50.22235066550118, 25.10965715135847, 0.4640050988112177, 0.11453844819750104, 0.10986953015838351, 0.20147770164268358, 0.14995653767670902, 0.18540374987891742, 0.08064970201147453, 0.13731815799006394, 0.2082683036902121, 0.08999642689845391, 0.1433826597141368, 0.12977120652794838, 0.08593641939972128, 0.1317937701408352, 0.21685889629381044, 0.20550174000007765, 0.12726805013205322], [0.03695694583335093, 0.05009918526879378, 0.007597722844885928, 0.08075086479740483, 0.05748818734926837, 0.06830448337963649, 0.048398600092956, 0.02294214259433959, 0.022042442479037812, 0.07183224122439112, 0.016848177183419466, 0.008894311663295542, 0.04753509982089911, 0.038068060497088094, 0.034606704089258394, 0.024138138596234576, 0.05947181662278516, 0.05581354256719351, 0.1181161462196282, 0.04415128639500056, 0.01050172295487885, 0.0777926624619535, 2.9104916070188795, 40.46322706767491, 38.29500348227364, 21.337784120014735, 34.33545092173985, 35.23521137237549, 52.10054949351719, 30.262806006840297, 0.16712473572364875, 0.15038280694612435, 1.3344503939151764, 2.724361743245806, 0.6536965114729745, 0.06631315273365804, 12.790264810834612, 57.457162448338096, 52.827574253082275, 54.25564098358154, 51.0876202583313, 50.61315556934902, 47.14387832369123, 48.27462816238403, 47.28661516734532, 45.82962656021118, 41.51860979625157, 38.67878375734602, 35.901970931461875, 37.12068149021694, 40.58725241252354, 47.69441189084734, 48.666308539254324, 52.03655311039516, 51.017412185668945, 49.61174297332764, 49.07566165924072, 47.11001280375889, 43.034651143210276, 42.11314977918352, 38.58438205718994, 36.584718295506065, 37.347352572849815, 38.1520790372576, 37.58892059326172, 39.281272479466026, 37.47727346420288, 38.32532542092459, 36.718860217503135, 36.39112411226545, 37.135616643088206, 36.16054466792515, 35.86251558576311, 36.131615843091694, 36.28052963529314, 37.623439243861604, 36.28843668528965, 37.92346593311855, 38.689946038382395, 39.1645496913365, 36.808231421879356, 36.07582875660488, 37.60709360667637, 41.00336960383824, 46.438914094652446, 51.722602231161936, 48.751872130802695, 48.39251477377755, 40.06826366697039, 31.780177933829172, 39.7159309387207, 47.603105613163535, 49.10539647511074, 49.704233918871196, 49.866053989955354, 50.14328016553606, 49.488739013671875, 50.09826626096453, 47.66658435549055, 45.79945400782994, 37.163708209991455, 34.71091767719814, 33.85515669413975, 34.59348964691162, 34.13710764476231, 35.68770585741316, 34.312671252659385, 35.88045930862427, 34.25561611992972, 36.266306672777446, 34.341148444584434, 34.51867144448416, 34.77105781010219, 35.50512456893921, 34.00701304844448, 34.90288250786917, 33.5088654245649, 33.57565150942121, 35.02834612982613, 33.77363348007202, 33.372847488948274, 34.02456767218453, 33.365214892796104, 31.5155279976981, 33.19873605455671, 31.74880681719099, 34.92696149008614, 32.38897214617048, 36.66690158843994, 40.94444193158831, 44.87180001395089, 45.06307002476284, 45.98665932246617, 45.10032626560756, 45.65711668559483, 43.77066339765276, 45.50662565231323, 48.86947039195469, 45.49545642307827, 39.61372641154698, 41.8658321244376, 47.8728346824646, 46.24855777195522, 45.293652943202424, 36.151751722608296, 5.0405320184571405, 0.16098582584943089, 1.0797679743596484, 1.2521456160715647, 5.986209639481135, 3.136100700923375, 1.3691758619887489, 39.737011773245676, 39.64773784364973, 28.155552864074707, 14.096624289240156, 19.212552513395035, 42.58322320665632, 6.2192674194063455, 0.1363046709448099, 0.11877722931759697, 0.11482480354607105, 0.030687991330134015, 0.09653654774384839, 0.006008860580290535, 0.0324433512453522, 0.013692140329762228, 0.10836406451250825, 0.03163718378969601, 0.06231115997901984, 0.029381204130394117, 0.030021340852337222, 0.04427314789167472, 0.015251032974837082, 0.024069949219535505, 0.024085636949166656, 0.04706586232142789, 0.0397169243411294, 0.033836363282586844, 0.023012250528803894, 0.03845498491344707, 0.035083208698779345, 0.02832482010126114, 0.015563669681016887, 0.028592268071536506, 0.038746022153645754, 0.02853528470067041, 0.01254089964952852, 0.06711768491991929, 0.05313269142061472, 0.02689129613073809, 0.04019961040467024, 0.047083785823945484, 0.009012261405587196, 0.036652141117623875, 0.10061737269695316, 0.06245982021625553, 0.049540805231247625, 5.452257079737527, 51.58216871534075, 37.90560906273978, 23.7238632610866, 44.70503282546997, 40.48237977709089, 57.915969371795654, 29.69170924595424, 0.09883947524109057, 0.10289283988199063, 2.5284735688141415, 4.27864727803639, 2.5457930394581387, 0.16911311474229607, 16.03723965372358, 58.84295981270926, 55.07519837788173, 55.71020814350673, 53.16874122619629, 51.85411773409162, 49.92159788949149, 51.24925620215279, 49.22026409421648, 48.69627264567784, 44.09370946884155, 40.16585806437901, 37.49431392124721, 38.86049999509539, 40.58837454659598, 48.41510336739676, 51.58568102972848, 52.736796038491384, 52.75869676045009, 52.06632614135742, 50.10178204945156, 49.34288590294974, 44.1795197214399, 43.30350821358817, 39.96976252964565, 38.58037294660296, 39.54402208328247, 39.41411508832659, 38.81727177756173, 41.43543291091919, 38.95498507363455, 40.50699029650007, 39.7122414452689, 37.179365975516184, 38.06355898720877, 38.649177483149934, 38.301944732666016, 37.85876778193882, 37.80289731706892, 38.9868460382734, 37.792791162218364, 39.187468324388774, 37.700942925044465, 39.4753669330052, 39.05646351405552, 37.81222874777657, 38.76988158907209, 43.971310002463206, 50.093364306858604, 53.051059586661204, 51.517171791621614, 50.50324896403721, 39.238155433109824, 30.192080293382915, 47.94540861674717, 49.617082663944785, 51.94201592036656, 49.96035841533116, 51.83603852135794, 52.292017527988975, 51.487013135637554, 50.53318527766636, 49.08135223388672, 48.06740856170654, 40.33338608060564, 37.224181856427876, 35.64088542120797, 36.822054862976074, 36.07808344704764, 35.832676546914236, 36.605239800044465, 36.64485148021153, 35.558236598968506, 37.72047431128365, 36.73363208770752, 36.663430963243755, 35.75453363146101, 36.94513872691563, 35.97761249542236, 36.56343248912266, 36.53991631099156, 35.424813815525596, 35.83200951984951, 34.91859585898263, 35.44163540431431, 35.61301967075893, 36.6775358063834, 34.22980008806501, 34.70704058238438, 33.83743878773281, 37.40183687210083, 35.07528121130807, 38.04603215626308, 42.497861112867085, 46.38708748136248, 46.20138645172119, 46.95505060468401, 47.335877895355225, 46.96473639351981, 45.72296476364136, 47.77128676005772, 50.857124192374094, 47.52009548459734, 41.212044852120535, 44.61192349025181, 48.009040219443186, 47.117826053074424, 46.18645477294922, 37.524715764181956, 5.815352567604609, 0.799549893609115, 3.1184066789490834, 5.115626411778586, 5.517503270081111, 2.5832859533173695, 1.7785158455371857, 44.54261173520769, 47.05738367353167, 33.95642668860299, 21.33216997555324, 20.91117341177804, 48.23654508590698, 9.597142849649702, 0.22531701172036783, 0.09775442989276988, 0.08958345013005392, 0.00972237714034106, 0.09620004187205008, 0.05376757288883839, 0.029987719442163194, 0.019396697037986348, 0.02462885172904602, 0.04156793733792646, 0.036479504845504246, 0.0058567567778352115, 0.03623944254858153, 0.03898778757346528, 0.021890024854136363, 0.04297006888581174, 0.0371801634984357, 0.1780463403889111, 0.12355361373296805, 0.08053786586970091, 0.1736912312252181, 0.2030299183513437, 0.12600562215915748, 0.1198710413383586, 0.09652224422565528, 0.15335963506783756, 0.13833988245044435, 0.07835693896881171, 0.08835488783993892, 0.21621278167835303, 0.17787591953362736, 0.09096581595284597, 0.09427275814648185, 0.1922875147845064, 0.14300748413162573, 0.26384679494159563, 0.11302981379308871, 0.08247310881103788, 0.2811255534844739, 5.422754594257899, 56.84817716053554, 46.934525626046316, 30.315546308244976, 42.870638915470664, 47.66125856127058, 59.497035435267854, 37.59694923673357, 0.3978638936366354, 0.24017743074468204, 5.0038720199040005, 8.13392083985465, 2.617081557001386, 0.23658404499292374, 15.930296455110822, 59.70740604400635, 58.62205573490688, 59.00315053122384, 56.64688784735543, 55.36507722309658, 51.956565448216026, 53.40358339037214, 51.55289248057774, 52.07371555055891, 46.952851499829976, 42.339296272822786, 39.443009172167095, 40.85098171234131, 43.23547145298549, 53.75745167051043, 52.85649960381644, 53.94443464279175, 55.898090907505576, 52.89370025907244, 52.21053947721209, 52.71422481536865, 47.39687613078526, 46.69822434016636, 42.37962014334542, 41.14805889129639, 43.481854575020925, 40.90510123116629, 40.621058872767854, 43.58805431638445, 40.48985603877476, 42.387839862278526, 40.48135839189802, 39.379262924194336, 39.82465635027204, 40.45928396497454, 40.37238284519741, 40.13422291619437, 39.327245235443115, 41.9931891305106, 40.062448024749756, 41.08170012065342, 41.19641487939017, 42.997030121939524, 39.74841724123274, 39.107206208365305, 40.970337867736816, 46.01651573181152, 51.7355397769383, 56.972782679966514, 51.68395635059902, 51.205687522888184, 43.04005684171404, 38.45585427965437, 52.85792745862688, 50.16411781311035, 52.01221704483032, 51.12765230451311, 53.22704356057303, 53.76740843909127, 52.782289368765696, 53.43802561078753, 51.75302144459316, 50.60020760127476, 41.51446519579206, 39.1607003893171, 37.28589923041207, 38.5446765763419, 38.00270318984985, 38.330720697130474, 39.16502911703927, 39.45580080577305, 37.179133210863384, 39.99028056008475, 37.32128293173653, 38.36735160010201, 38.42634528023856, 39.107567514692036, 37.52259308951241, 39.401813302721294, 37.58312232153756, 37.649123259953086, 38.537572043282644, 37.579332079206196, 39.11115278516497, 39.10035181045532, 39.94072253363473, 36.065767765045166, 37.15051358086722, 34.73331866945539, 40.29280512673514, 35.87223264149257, 39.83128840582711, 44.51214735848563, 48.76261057172503, 48.39526973451887, 48.25131000791277, 49.840491567339214, 49.741319928850444, 47.79423666000366, 49.3984124319894, 53.55962950842721, 48.455576624189106, 45.81159945896694, 45.82335581098284, 48.06030402864729, 47.39955118724278, 46.161086899893625, 38.98467820031302, 6.617582891668592, 0.9868908609662737, 3.6486971037728444, 7.2702363048280985, 14.354314735957555, 6.945756299155099, 2.057676660163062, 48.06233637673514, 49.98481260027204, 36.71356916427612, 23.134270395551408, 28.409328869410924, 56.62171799795968, 11.908537541116987, 0.38409459963440895, 0.19654381567878382, 0.1817654451089246, 0.09551867736237389, 0.29472955635615755, 0.11772206665149756, 0.0816229587154729, 0.1584038236843688, 0.25749293874417034, 0.1648567867066179, 0.13954354929072516, 0.12537643020706518, 0.16944417197789463, 0.10774059261062316, 0.08394244925252028, 0.15178546096597398, 0.09555555574063744], [0.04918402812576719, 0.04373128678915756, 0.012778424225481493, 0.04732449612181101, 0.026533826919538633, 0.02399659958401961, 0.04752012455303754, 0.03590758803433605, 0.0512848743237555, 0.02569954775805984, 0.03246050800329872, 0.048193580737071376, 0.04903799042637859, 0.029379131205912148, 0.05044072587043047, 0.010675268463923462, 0.046771988804851256, 0.047983455405171425, 0.1050861296909196, 0.09522666303174836, 0.021235859420682703, 0.0403487320457186, 0.045355991393859894, 19.86851109777178, 45.329276357378276, 30.826075622013636, 39.80371447971889, 34.19740063803536, 35.69493545804705, 52.36220128195626, 3.512143288339887, 0.496260156588895, 0.4325958756463868, 6.3192485230309625, 3.0741787893431525, 0.05875729889209781, 1.9089194195611137, 43.891919885362896, 57.769744532448904, 52.523267473493306, 55.33326489584786, 50.57478066853115, 50.731618881225586, 50.15926449639456, 49.149864946092876, 45.435437883649556, 41.56905024392264, 37.22125319072178, 36.67309938158308, 39.86951739447457, 48.55908741269793, 50.22350059236799, 50.123585496629985, 49.942932333265034, 50.42845160620553, 49.07462290355137, 49.12060955592564, 47.045425823756624, 48.53503622327532, 46.92835562569754, 42.75966228757586, 37.299840790884836, 37.469404629298616, 37.75935295649937, 37.056528772626606, 38.59357452392578, 39.29416833605085, 37.61673423222133, 37.75820302963257, 37.15603739874703, 36.68919140951974, 37.71307447978428, 36.10885354450771, 36.89379848752703, 38.13416658129011, 35.74156134469168, 39.21129717145647, 38.71160704748971, 44.90657227379935, 44.00217390060425, 43.80956288746425, 40.35789237703596, 39.62885611397879, 40.399904659816194, 43.8109837940761, 49.93589728219168, 50.934704303741455, 49.39450059618269, 51.371902329581125, 40.41247047696795, 21.489518880844116, 41.50859744208199, 47.5403390611921, 46.65442637034825, 51.8947924886431, 49.61436244419643, 47.434604849134175, 47.721923283168245, 46.636305468423025, 39.233107566833496, 35.63941240310669, 36.07048906598772, 35.75313356944493, 35.83622012819563, 35.73762171609061, 35.394304275512695, 35.149877071380615, 33.91385507583618, 34.86972223009382, 34.45708608627319, 34.35519422803606, 33.410544940403526, 34.375510760716026, 34.99012408937727, 33.58189793995449, 34.611037322453086, 34.4041234425136, 34.75710235323225, 34.38948358808245, 33.610983099256245, 32.71573897770473, 32.86383635657174, 32.423122542245046, 32.621490137917654, 32.03965146200997, 33.78501115526472, 31.987915175301687, 33.4746663911002, 31.330382823944092, 35.484926155635286, 36.675051825387136, 38.777489866529194, 41.48679746900286, 43.29126896177019, 44.11129535947527, 44.586611202784944, 45.433138029915945, 43.96160684313093, 44.93903773171561, 46.676410470690044, 43.50287287575858, 44.21822813579014, 44.22442940303257, 47.25473683220999, 20.906858580453054, 0.5366144254803658, 0.48441315229449955, 3.69930647952216, 3.1704610628741126, 3.6270630189350674, 0.9043147233980042, 4.9888743332454135, 51.46774230684553, 31.054393427712576, 25.25618597439357, 28.16555479594639, 34.44536794934954, 28.252461126872472, 0.2958227576954024, 0.05480710889345833, 0.025265902812991823, 0.008443965426912265, 0.016876324512330548, 0.02308764255472592, 0.08799390721001796, 0.043317163296576054, 0.027975554378437142, 0.013793694121497018, 0.028128770978323052, 0.045741782656737735, 0.016211864006306444, 0.05081911092357976, 0.02237963706388005, 0.04378667899540492, 0.03702400205656886, 0.06965211499482393, 0.017489184126523987, 0.03466807758169515, 0.03411435568705201, 0.050169233831443956, 0.026720193347760608, 0.056599231835986884, 0.07659257150122098, 0.053520565785999806, 0.025395480949165564, 0.04538062221503683, 0.013819221457067345, 0.02839381354195731, 0.07997900407229151, 0.020265596752454127, 0.09093344304710627, 0.017337010774229254, 0.018646050710231066, 0.06564538606575557, 0.02974268687622888, 0.029850604478269815, 0.02856195791225348, 0.05812607133494956, 0.15513218566775322, 28.404423441205704, 52.549882548195974, 25.021253483636038, 41.45695148195539, 39.17193562643868, 43.23940065928868, 56.33058500289917, 3.81401298727308, 0.3774235418864659, 2.421171452317919, 5.483820574624198, 5.22470531293324, 0.7156042009592056, 2.318482288292476, 47.95524379185268, 59.472209521702354, 54.61082247325352, 55.40635994502476, 53.37976149150303, 52.565575054713655, 52.55966213771275, 51.244493212018696, 47.580801895686555, 43.8604792867388, 39.206384795052664, 38.86131640842983, 40.71007571901594, 49.80436440876552, 51.81187268665859, 52.46743522371565, 51.75957359586443, 54.26441308430263, 52.014013154166086, 51.5621474811009, 50.29314586094448, 49.798010281154085, 48.004364081791465, 44.68624489648001, 39.904876777103965, 39.48117562702724, 40.252488204411094, 38.85646309171404, 39.36442504610334, 41.238781520298545, 38.838092054639546, 39.01516342163086, 37.09767600468227, 39.43337549482073, 38.629837172372, 36.69975961957659, 38.02274179458618, 38.56583036695208, 37.89219903945923, 39.40837240219116, 39.638798986162456, 45.93469721930367, 44.44742488861084, 44.018523011888774, 40.957442011152, 40.13257966722761, 41.9696729523795, 46.56636142730713, 51.07248360770089, 51.77342830385481, 50.83824246270316, 51.990215573992046, 40.39037867954799, 21.59446794646127, 44.11422402518136, 48.73219830649239, 49.99763202667236, 52.944314411708284, 52.64541680472237, 49.67830671582903, 49.551053932734895, 48.722046988351, 42.182937485831125, 37.87116684232439, 37.24648904800415, 36.95513718468802, 37.11866998672485, 36.60911342075893, 38.55299704415457, 36.4416583606175, 36.900312423706055, 36.55377449308123, 37.84849834442139, 35.724927357264924, 35.99704660688128, 35.84501307351248, 36.479057039533345, 36.2472060748509, 36.244534492492676, 35.53092670440674, 37.241639205387656, 35.779088565281455, 36.14608546665737, 35.56114442007882, 35.373932157244, 35.3555645942688, 34.97655773162842, 35.12409578050886, 34.47773265838623, 35.114614963531494, 34.03054659707205, 33.791869027274, 38.06236389705113, 37.67572791235787, 42.09757191794259, 43.33012328829084, 44.619069712502615, 45.09535482951573, 46.87692158562796, 45.720637117113384, 47.02870845794678, 47.47361898422241, 48.91939319883074, 45.415774481637136, 47.170316219329834, 45.55042014803205, 46.52989728110177, 22.91832733154297, 0.7324898434536797, 2.001411667891911, 4.171524729047503, 5.3737806507519315, 3.931137902396066, 0.5235988753182548, 4.896767709936414, 54.86143010003226, 32.981966154915945, 32.587885175432476, 25.998755591256277, 34.66051197052002, 37.70985746383667, 0.6999662486570222, 0.042723146599850485, 0.020992723360125507, 0.01628324419393071, 0.016699696757963726, 0.06449245328881911, 0.05112822772935033, 0.021676476313067333, 0.037918416384075365, 0.03568874692012157, 0.021155678633866564, 0.028085899439507296, 0.024166828753160577, 0.04749479823346649, 0.04894995729305914, 0.058129307946988514, 0.022398474892335277, 0.09552629052528314, 0.10601681510784797, 0.09468167727547032, 0.06351853162050247, 0.12150447868875094, 0.2028128278574773, 0.07473375195903437, 0.08338715654930898, 0.14365180741463388, 0.17826374300888606, 0.29347038535135134, 0.09148773151848998, 0.17322140000760555, 0.18240526291940892, 0.19344710398997578, 0.202291373695646, 0.09875267025615488, 0.08745171023266655, 0.10372152112956558, 0.2912554842020784, 0.22523598106844084, 0.07985523249953985, 0.13697450714451925, 0.13295634490038666, 32.071908473968506, 58.66081278664725, 39.53538547243391, 48.87799235752651, 44.480248178754536, 46.30669682366507, 61.77592645372663, 5.511744950498853, 1.10182720209871, 2.889226210968835, 18.775441340037755, 11.204612936292376, 0.34792933453406605, 3.000476207051958, 47.34915590286255, 61.21192727770124, 55.15634291512625, 60.12389496394566, 54.946896416800364, 55.7401305607387, 54.96012231281826, 55.245210375104634, 48.54246037346976, 46.84697484970093, 41.89731093815395, 40.94259371076311, 43.97699015481131, 53.766883850097656, 55.05333239691598, 54.5552716255188, 53.66521780831473, 55.434972626822336, 53.809441566467285, 53.75226484026228, 51.04210955756051, 50.879188196999685, 51.88562086650303, 46.80538640703474, 41.04376643044608, 41.53005000523159, 42.33001000540597, 40.473499979291645, 41.73492806298392, 43.853538036346436, 40.24622787748064, 42.19459656306675, 39.02312953131539, 41.108825887952534, 41.317518506731304, 39.65193108149937, 42.07296139853341, 41.21334416525704, 39.87270661762783, 43.01150669370379, 42.946103300367085, 48.89340693610055, 46.698338985443115, 49.1255601474217, 44.25320536749703, 42.67831972667149, 44.41166251046317, 47.660355295453755, 52.797130720955984, 53.22198527199881, 52.11300413949149, 53.95170940671648, 43.74876267569405, 27.965519632611954, 43.50484616415841, 49.24500315529959, 51.16191387176514, 55.52261025565011, 53.82053089141846, 50.9335161617824, 52.925022738320486, 50.252436365400044, 42.44547864368984, 38.656518254961284, 39.677076612200054, 38.44387558528355, 40.54522623334612, 39.3499311038426, 41.03600181852068, 38.22406932285854, 39.4164149420602, 38.18680613381522, 39.58439459119524, 37.978196893419536, 36.94187307357788, 37.50185966491699, 39.63060358592442, 38.509025369371685, 37.78671496255057, 37.842432567051475, 39.88807255881173, 38.78460482188633, 37.841584886823384, 36.89751577377319, 36.647352831704275, 36.79464769363403, 37.16402087892805, 36.79089566639492, 36.740882532937185, 36.07139580590384, 37.76221214021955, 34.42495066779, 38.93508890696934, 39.39417028427124, 44.37640735081264, 45.06069721494402, 47.454164028167725, 47.44400576182774, 47.719328130994526, 49.440435137067524, 48.34660107748849, 48.32374497822353, 50.30478061948504, 47.5935240473066, 50.89913647515433, 48.90064695903233, 48.213925225394114, 24.026514632361277, 0.9810046511037009, 1.9070234298706055, 7.135198933737619, 9.148693084716797, 10.715662121772766, 3.395836957863399, 6.517769413334983, 62.19676494598389, 38.9095264843532, 36.00876126970564, 37.20328514916556, 42.249417849949424, 43.540834358760286, 0.7883012486355645, 0.22336321084627084, 0.21244114477719578, 0.0757309270224401, 0.10070424553539072, 0.13436319226665155, 0.17933183855244092, 0.14679299028856413, 0.09369817469269037, 0.11604770006878035, 0.11730552757424967, 0.07594344419028078, 0.1266139288033758, 0.1131198350340128, 0.10435556460704122, 0.1145552351538624, 0.08130539075604507, 0.24414240941405296], [0.022089344515864338, 0.005282245842473847, 0.037194867352289815, 0.027891624685642973, 0.04682793740981391, 0.04402838673974786, 0.05421491406325783, 0.062019702047109604, 0.06302662087338311, 0.052674534397998025, 0.03651435440406203, 0.013185376451084656, 0.0020963358484940337, 0.03377312721152391, 0.058145850630743165, 0.022009141676660095, 0.04764817768175687, 0.09033356380781957, 0.05424614024481603, 0.10861586885792868, 0.07070246006229094, 0.022687479920153106, 0.020053116904039468, 2.495151311159134, 31.810298374720983, 40.59553119114467, 27.68130704334804, 42.41729327610561, 27.923731429236277, 46.09029517854963, 15.870644433157784, 1.2851113442863737, 1.4621744602918625, 2.658846527338028, 2.7525006447519575, 0.39846447855234146, 0.32915698470813887, 14.866450820650373, 61.31531647273472, 51.15883929388863, 56.56107759475708, 52.481144019535606, 54.297635895865305, 52.521919522966655, 49.12185328347342, 45.271717480250764, 38.079744815826416, 37.186904770987375, 42.385258606501985, 48.43758773803711, 50.217664105551584, 51.38843904222761, 51.42071342468262, 49.91725526537214, 50.83063071114676, 48.21317481994629, 49.03036287852696, 48.500027724674766, 49.05766235079084, 48.57011072976248, 46.266081128801616, 40.140351227351594, 38.18371071134295, 36.803558758326936, 38.13438892364502, 37.66277994428362, 40.08294521059309, 37.5888580594744, 38.73577288218907, 37.08213635853359, 37.68820340292794, 36.98985733304705, 36.70761455808367, 35.59873070035662, 36.55880846296038, 36.40354054314749, 39.50515386036464, 47.339574337005615, 50.4446930204119, 48.14050708498274, 47.23392350333077, 46.75325059890747, 45.64473499570574, 39.542045320783345, 41.50455706460135, 45.21703168324062, 50.06842027391706, 49.83421386991228, 50.24466480527605, 50.75554500307356, 41.725141525268555, 43.72024032047817, 49.10323558534895, 49.58813646861485, 50.640034675598145, 50.03907108306885, 49.23639781134469, 45.36243316105434, 39.646525382995605, 37.41147402354649, 37.16005345753261, 36.25301824297224, 37.03104625429426, 35.407672609601704, 35.58871487208775, 35.63043533052717, 36.07416813714163, 34.02466147286551, 34.88289948872158, 34.4691481590271, 36.22134835379464, 34.10210609436035, 35.23133427756173, 34.63735362461635, 34.70455312728882, 33.47967256818499, 34.459059374673025, 36.10910715375628, 34.06680924551827, 34.19092491694859, 33.74848447527204, 33.27660799026489, 34.26827226366316, 33.73528289794922, 32.475379943847656, 33.25244215556553, 32.7305143220084, 32.78090960638863, 32.41674757003784, 33.31928382601057, 32.93553134373256, 33.65570517948696, 32.46918562480381, 36.601922035217285, 35.95594106401716, 37.40784011568342, 36.88994918550764, 41.90127141135079, 40.157082489558626, 41.87073755264282, 42.87371349334717, 49.013732365199495, 45.099624497549875, 47.06306035178048, 7.7034721204212735, 0.18435835811708653, 1.6482881477900913, 2.204045674630574, 3.262238949537277, 3.19281667470932, 1.248844570347241, 15.308939899717059, 56.982784611838206, 28.059619086129324, 30.312833036695206, 18.59994547707694, 37.003010272979736, 8.611167413847786, 0.20178236386605672, 0.055896649536277564, 0.05862701338316713, 0.042734871684972725, 0.035154074896126986, 0.03870991051995328, 0.04828651289322546, 0.006060339335817844, 0.07086535596421786, 0.03486367887152093, 0.0398924884918545, 0.018063864271555628, 0.016929296044898883, 0.0595879139644759, 0.044548616145870516, 0.036064828346882544, 0.027917512492941957, 0.010249800713998931, 0.052110800719154735, 0.019132299082619802, 0.026921251755473868, 0.05449516598933509, 0.02126573701389134, 0.058913029464227815, 0.033252331228660684, 0.04493043797888926, 0.11826496251991817, 0.007613308794264282, 0.08045385644904204, 0.038450574435825856, 0.03303775131436331, 0.05343685831342425, 0.028400578536093235, 0.09016488000218358, 0.05876685266516038, 0.023093790081994872, 0.10243336989411286, 0.04164456769025751, 0.06784012115427426, 0.06640622738216605, 0.08388227676706654, 4.603193291596003, 41.782200132097515, 41.5883731842041, 31.812004157475062, 48.03552327837263, 31.50342423575265, 55.141272272382466, 15.886911903108869, 1.2614073476621082, 1.2500749443258559, 3.90699508360454, 3.849843110357012, 2.013355187007359, 0.11465754466397421, 18.505302327019827, 62.28294345310756, 52.951200076511924, 58.72819641658238, 53.07363428388323, 55.88437516348702, 54.64887080873762, 51.429089478084016, 46.55330228805542, 40.888845920562744, 38.68018381936209, 43.680232592991416, 49.568848269326345, 52.638016973223, 52.21963814326695, 53.72086245673043, 50.87142358507429, 53.32902921949114, 49.54834066118513, 50.38590778623308, 48.63497563770839, 50.408093384334016, 51.423558712005615, 48.083274773189, 41.39225333077567, 39.94276530402047, 37.813013894217356, 40.00217587607247, 40.855796813964844, 40.775010108947754, 38.372670446123394, 39.64126559666225, 39.11578723362514, 40.23137262889317, 37.97227702822004, 38.47024399893624, 36.29223387581961, 38.60550110680716, 37.496596404484336, 41.355577264513286, 48.27723026275635, 50.834803104400635, 48.35753754207066, 47.955990723201204, 48.28417151314871, 45.83478559766497, 42.32088007245745, 43.969354084559846, 47.99103396279471, 52.15892825807844, 52.46699401310512, 51.964437757219585, 50.88079670497349, 40.020890848977224, 42.65032543454851, 49.81605127879551, 50.45320456368582, 51.62475075040545, 51.382046699523926, 50.6280003956386, 46.674791540418354, 43.21784039906093, 37.68887390409197, 38.04553536006382, 38.969951493399485, 39.78971038545881, 37.9272700718471, 36.29313019343785, 36.97212553024292, 36.253820759909495, 35.91262946810041, 37.30841486794608, 37.11472340992519, 38.15813091823033, 35.78663083485195, 36.76783806937081, 36.338741643088206, 38.296695368630544, 36.32599169867379, 36.78916209084647, 37.20230197906494, 37.2174768447876, 37.37932818276541, 35.75082676751273, 36.12504284722464, 35.86875854219709, 35.210142271859304, 35.3478798866272, 35.29309334073748, 35.27031714575631, 35.24523762294224, 33.65550020762852, 34.08302286693028, 34.93951688494001, 35.43136944089617, 34.549646513802664, 38.365169865744456, 38.358926909310476, 40.94304186957223, 38.874535356249126, 43.94990260260445, 42.40211146218436, 44.4711251940046, 44.81450169427054, 51.013569831848145, 45.24838890348162, 47.79684223447527, 9.765471645763942, 0.27756647446325844, 4.579143839223044, 5.181223486151014, 7.447013241904123, 1.91057265656335, 0.45196984176124844, 14.226691092763629, 62.35002136230469, 31.247087819235666, 34.973879201071604, 18.277354512895855, 43.09102535247803, 12.593246034213475, 0.19059637481612818, 0.043527685571461916, 0.03239191150558846, 0.038256615200745206, 0.04339879445199456, 0.054951786130134544, 0.05994255707732268, 0.04205101016642792, 0.03298027939828379, 0.035310918265687566, 0.03737749165988394, 0.023597030667588115, 0.0260794815673892, 0.04995869120050754, 0.07937624105917555, 0.029183713120541403, 0.02262911742686161, 0.09355636765914303, 0.17619993803756578, 0.14673759468964168, 0.1488468072244099, 0.11292746357087578, 0.14360046945512295, 0.14691196461873396, 0.1317636567567076, 0.17035184827234062, 0.24474247864314488, 0.19513806753924914, 0.1722482315131596, 0.15370621718466282, 0.0889404635610325, 0.1469801709588085, 0.09868427392627512, 0.3446643054485321, 0.1483754018055541, 0.17052551252501352, 0.2281633982700961, 0.21052137921963418, 0.19502095239503042, 0.11958642303943634, 0.1890528704971075, 4.38191922221865, 46.62968036106655, 50.70973552976336, 36.4627183505467, 53.28130899156843, 38.243941170828684, 56.524516173771445, 20.000606775283813, 2.8107723636286597, 5.216432613985879, 5.465893353734698, 9.588540979794093, 1.5511943463768278, 0.7125104069709778, 19.430856227874756, 65.15140996660504, 54.552805015019004, 59.47671890258789, 55.12296724319458, 57.91663987295968, 57.15892839431763, 53.878360748291016, 49.29073967252459, 43.113669531685964, 41.283552237919395, 46.94594151633126, 53.63566711970738, 54.77675240380423, 55.1217165674482, 55.78713859830584, 52.65425491333008, 55.44771214893886, 51.848913533346995, 53.821600914001465, 52.13886880874634, 53.431678431374685, 52.21482304164341, 50.13670369556972, 43.68044798714774, 42.06638492856707, 40.32448196411133, 43.30689893450056, 41.73429230281285, 42.44133056913103, 40.8720451763698, 42.29137454714094, 40.073037079402376, 43.2253201348441, 40.098359789167134, 39.796530042375835, 38.35108239310128, 39.5791209084647, 39.77945484433855, 42.53654520852225, 51.320544719696045, 54.554170336042134, 51.25410257066999, 51.617382185799734, 51.01822859900338, 49.250759737832205, 43.039494037628174, 47.24636772700718, 47.94974776676723, 53.71726328986031, 54.585280895233154, 52.74484552655901, 53.624800137111116, 43.112248625074116, 43.31899574824742, 51.24467733928135, 53.34808118002755, 53.52162981033325, 53.14692735671997, 53.163658618927, 47.9250226020813, 44.076627322605674, 40.9379106249128, 41.481871196201865, 40.737118107931956, 41.54121923446655, 38.86213976996285, 38.30215665272304, 38.4827299118042, 40.14646564211164, 36.889250891549246, 38.771847929273335, 38.73771490369524, 40.185914039611816, 37.54915605272566, 38.127815927777974, 37.514852796282085, 39.17113658360073, 37.1011848449707, 39.038672651563374, 40.58194746289934, 39.68236419132778, 39.39846427100045, 37.43289531980242, 37.963789803641184, 38.28575890404837, 37.03717803955078, 37.18137053080967, 36.79757635934012, 37.47293084008353, 36.160478660038535, 35.549290793282644, 37.47937182017735, 36.668621267591206, 38.05658299582345, 37.06678083964756, 40.11526823043823, 39.64868974685669, 42.21825517926897, 40.1229008265904, 44.92597164426531, 43.50697578702654, 46.93131903239659, 47.077147824423655, 53.663637093135286, 46.50142356327602, 49.70591190883091, 10.316492455346243, 0.7434318448816026, 4.966152421065739, 6.774774593966348, 14.554408958980016, 8.985656210354396, 2.48630799140249, 18.67626449040004, 68.2894596372332, 36.31693819590977, 43.81491994857788, 27.275396755763463, 51.199281283787315, 17.492364406585693, 0.35964288456099375, 0.1107888026162982, 0.1387895747487034, 0.11775456847889082, 0.14877809876842157, 0.14995063442204679, 0.16665056188191685, 0.14795276948383876, 0.10929753870836326, 0.12480173818767071, 0.16319067110972746, 0.0978973972211991, 0.0985678576731256, 0.1618382286812578, 0.1581649522164038, 0.140811948371785, 0.11133950163743325, 0.19542392077190535], [0.022599536692723632, 0.04516782006248832, 0.03490463524524655, 0.008476822637021542, 0.06264525705150195, 0.02520265317122851, 0.021930518127711754, 0.05812666166041579, 0.020148147429738725, 0.13231261872819491, 0.02602753971171166, 0.04013111229453768, 0.02635957403773708, 0.04074789044846382, 0.011799425418887819, 0.033122354453163486, 0.016867892018386295, 0.05058466011126127, 0.07710253127983638, 0.02528684240366731, 0.034465731653784, 0.02651462607484843, 0.05509240233472415, 0.036286495559449704, 7.943878923143659, 42.24638843536377, 24.467938899993896, 32.05412803377424, 37.27590077263968, 35.184340136391775, 40.27365241731916, 0.14798077940940857, 1.984137577669961, 1.4348559890474593, 2.225371216024671, 3.1871267514569417, 0.09781933855265379, 0.9135811775922775, 33.29015697751726, 58.293002946036204, 52.63179833548409, 55.988997663770405, 51.694072927747456, 49.501996176583425, 48.62945876802717, 42.3363676071167, 36.96049771990095, 40.829609053475515, 48.034908362797324, 52.23462540762765, 51.83923816680908, 51.693041120256694, 50.59412445340838, 51.32190309252058, 49.84093625204903, 50.598435810634065, 47.44233819416591, 50.244015148707796, 49.606219155447825, 50.2105005128043, 47.3720953805106, 38.88584007535662, 36.66815921238491, 37.360328333718435, 37.7390398979187, 37.52002573013306, 38.67839813232422, 38.01945877075195, 39.412919998168945, 37.311621461595806, 36.837980134146555, 36.04425266810826, 37.69290733337402, 36.82082155772618, 34.67960214614868, 37.51079852240426, 43.49375336510794, 50.71524197714669, 50.79602173396519, 52.11285822732108, 50.86469425473894, 48.64021805354527, 45.78313963753836, 45.645502771650044, 41.04160206658499, 40.94342054639544, 43.141041960035054, 48.00855731964111, 48.30673231397356, 49.01300627844674, 47.58900424412319, 46.54229981558663, 51.34396014894758, 50.99766887937273, 47.92510598046439, 45.29614039829799, 44.71761948721749, 41.41252817426409, 36.43627003261021, 37.37788643155779, 36.30337183816092, 37.13205221721104, 36.68947281156267, 34.402712958199636, 35.89185435431344, 34.54111065183367, 34.26633024215698, 34.99620376314436, 34.71530199050903, 35.39542988368443, 35.279638154166086, 34.33963026319231, 34.120570932115825, 34.165744645254954, 35.11780766078404, 33.40068544660296, 33.15820721217564, 34.98724406106131, 34.83358812332153, 34.46850892475673, 33.410864557538716, 32.96669748851231, 32.62219190597534, 34.469794341496055, 34.19663981028965, 33.59322697775704, 34.46586513519287, 34.29009655543736, 34.38008614948818, 32.97167239870344, 33.10764169692993, 32.06392846788679, 31.465987341744558, 33.53788457598005, 34.19655990600586, 32.37000356401716, 34.05161006110055, 35.352559498378206, 36.59913233348301, 42.53369297300066, 44.977350098746165, 45.39643069675991, 50.00947175707136, 35.942319120679585, 0.5265408403107098, 0.29688243940472603, 3.9230284861155917, 3.8642944949013844, 5.409710654190608, 1.3226277083158493, 0.1510632282921246, 32.32777936117989, 43.02668850762503, 27.786832809448242, 31.322017192840576, 24.256345408303396, 35.81199523380825, 2.4805644367422377, 0.2468728343290942, 0.06563311136726822, 0.09118153580597468, 0.0900445282459259, 0.057970781810581684, 0.0045611933954725304, 0.0500667987923537, 0.09764433758599417, 0.006579521677589842, 0.018548216138567244, 0.062335146191929064, 0.053628693733896525, 0.12513090909591743, 0.02778121516374605, 0.05811047860022102, 0.021885195381141136, 0.012822393294689911, 0.041577399508761506, 0.043258707504719496, 0.02260675121630941, 0.04985530621239117, 0.06399223727307149, 0.035584422161004374, 0.028066506908674325, 0.021772519552281926, 0.05826674521501575, 0.006390486486322645, 0.07029375127915825, 0.016044662799686193, 0.04091331050066011, 0.02850386852930699, 0.03577469355825867, 0.036900328871394904, 0.08373824413865805, 0.04219548384259854, 0.045977685533996136, 0.04181826926235642, 0.025585509770150696, 0.04045403389526265, 0.03627533365839294, 0.07444415321307522, 0.04555101592891982, 14.008258836609976, 51.06147766113281, 23.550008910042898, 39.06333180836269, 40.97026143755232, 41.00807006018502, 39.45700284412929, 0.03861571628866451, 0.9129982888698578, 2.013089201280049, 2.9810826991285597, 5.690471725804465, 0.7125798346740859, 0.5261145031877926, 38.233907972063335, 58.66163962227957, 56.38350248336792, 56.07360587801252, 55.201631273542134, 51.35940599441528, 51.83278676441738, 44.11151075363159, 40.571014472416465, 41.93214225769043, 49.22419330051967, 53.79361009597778, 52.86433022362845, 53.158430099487305, 52.997568879808696, 52.35061863490513, 52.860116141183035, 52.96355397360665, 49.88229887826102, 51.22764730453491, 52.41921819959368, 51.1979854447501, 50.035843644823345, 39.8984705380031, 39.418023450034006, 38.63802562441145, 39.10880776814052, 39.91757113592965, 40.07270009177071, 39.45580775397164, 40.908905369894846, 39.388010706220356, 38.73504332133702, 38.19220488412039, 37.92337908063616, 37.628490584237234, 37.599318572453086, 38.93275778634207, 46.020830563136506, 51.50946971348354, 52.859122548784526, 52.87206704275948, 52.78642354692732, 50.54155785696847, 48.43654898234776, 46.74376630783081, 42.02646752766201, 42.119180815560476, 46.270924023219514, 49.84940610613142, 50.87172583171299, 52.58453321456909, 48.47703266143799, 47.32741846357073, 52.50624786104475, 52.86010571888515, 50.38054377692086, 49.17882851191929, 47.02925736563546, 42.73793527058193, 37.64367239815848, 38.219184739249094, 36.947431632450645, 38.64672129494803, 37.6113007409232, 37.213356563023154, 36.59794071742466, 36.816465037209646, 35.734943185533794, 37.025501591818674, 37.326671259743826, 36.81548881530762, 35.908662046704976, 35.95815059116909, 36.55080761228289, 36.35117197036743, 35.811991759708945, 35.52565649577549, 35.43609421593802, 37.37564216341291, 35.27080699375698, 36.2784104347229, 35.17489058630807, 34.4283309664045, 36.00290741239275, 35.73674971716744, 37.39428070613316, 35.841361795152935, 35.12743786403111, 35.81855085917881, 35.47797448294503, 33.87277037756783, 34.9988614491054, 33.691040243421284, 33.51537936074393, 35.707855633326936, 35.97656331743513, 34.83716644559588, 34.7603645324707, 37.80127491269793, 37.58771160670689, 43.49638673237392, 45.69914286477225, 48.93380376270839, 50.81514665058681, 38.00438812800816, 0.38985294635806766, 0.916530362197331, 7.085663054670606, 12.571425216538564, 4.128590941429138, 1.4659799018076487, 0.07740656925099236, 34.558540207999094, 49.63361242839268, 32.56084973471505, 34.76092038835798, 24.169930662427628, 45.159879275730674, 5.119645944663456, 0.3909162650150912, 0.03894650550293071, 0.04631790977769664, 0.020934313369382705, 0.01565170959968652, 0.01548045753900494, 0.05071937984653881, 0.054490701228912385, 0.022684597842661396, 0.03973990632221103, 0.04391043021210602, 0.04428106639534235, 0.04442923469468951, 0.03549043827557138, 0.029030781505363326, 0.03629393230325409, 0.007825869218712407, 0.051038701818989854, 0.10077692342123815, 0.14630243661148207, 0.19257929841322557, 0.11218733114323445, 0.2287030778825283, 0.23178604245185852, 0.12376420386135578, 0.10014551944498505, 0.1045943885775549, 0.23239498691899435, 0.10249151355986084, 0.19174312613904476, 0.19401187582739762, 0.12117393713976655, 0.17541833354958467, 0.1631993292165654, 0.08250202797353268, 0.19740999277148927, 0.15475935781640665, 0.10609323850699834, 0.16456854503069604, 0.14576537614422186, 0.11794351334018366, 0.15499233960040978, 14.576577186584473, 57.87175451006208, 34.43959747041975, 43.08479281834194, 48.50118807383946, 44.79067284720284, 48.548804078783306, 0.20611441640981606, 5.041831765856061, 7.260828009673527, 12.414733784539358, 9.823944211006165, 0.4311970892761435, 2.204618683883122, 35.40122468130929, 59.93913541521345, 57.284795011792866, 59.63123294285366, 55.60049261365618, 56.03071812220982, 54.18545028141567, 46.12220130647932, 42.030049324035645, 46.22761937550136, 51.14794799259731, 57.24399518966675, 55.22023160117013, 55.10075732639858, 53.86712203707014, 55.258759362357004, 54.74057313374111, 56.083024161202566, 51.30938243865967, 55.603935446058, 54.646129744393484, 53.66599253245762, 51.77859428950718, 41.91693959917341, 40.65442064830235, 40.525361333574565, 41.87991612298148, 41.176372800554546, 42.014794554029194, 41.995944091251914, 42.31076349530901, 41.2981538772583, 40.2687782560076, 39.61610616956438, 41.58180366243635, 41.30612693514143, 38.885537828717915, 40.96785388674055, 49.31675720214844, 54.58780656542097, 54.45597839355469, 55.28528411047799, 55.95868962151663, 52.33761855534145, 51.02078553608486, 48.63806758608137, 43.8706306048802, 45.481966495513916, 48.055600098201204, 51.64870466504778, 52.85918855667114, 55.19741371699742, 50.11021716254098, 48.10297291619437, 54.64756454740252, 54.9644649369376, 52.368065561567036, 50.340084416525706, 48.55182307107108, 44.452625615256174, 39.79529326302664, 41.35912779399327, 38.66773959568569, 41.30687734058925, 39.199526923043386, 37.6416574205671, 38.72664989743914, 38.4732734135219, 36.74536759512765, 40.07535777773176, 39.21638672692435, 39.701141698019846, 37.95368364879063, 37.04045411518642, 38.56557675770351, 39.07617902755737, 37.456154414585654, 36.59297622953142, 37.72421939032418, 39.51764324733189, 38.20507642201015, 40.013088021959575, 37.03061894008091, 36.02118117468697, 38.013354778289795, 37.66007709503174, 38.830313546316965, 37.71247346060616, 37.543778147016255, 38.12783677237374, 36.44239834376744, 36.02297033582415, 36.915414333343506, 36.138543197086875, 36.23049565723964, 38.43718794413975, 38.19083261489868, 36.61446005957467, 37.13129138946533, 40.676491601126536, 40.43894311359951, 45.11340972355434, 48.388311113630024, 49.74934162412371, 54.21054022652762, 38.68599598748343, 0.9705625942775181, 1.5331108995846339, 9.389342205865042, 13.131277186529976, 14.445932814053126, 5.654747128486633, 0.2684755437076092, 38.100888184138704, 54.77907657623291, 36.96323183604649, 44.42203269686018, 30.945831298828125, 54.292824268341064, 7.474505526678903, 0.6797248433743204, 0.09554946928152017, 0.14713119928325924, 0.13546615093946457, 0.16572456514196737, 0.13621936552226543, 0.13065877104444162, 0.09440638204770428, 0.15159795459892067, 0.14346483030489512, 0.15627418724553926, 0.11685892939567566, 0.2083158961364201, 0.06194456107914448, 0.17819727371845925, 0.11972744975771223, 0.07491549756377935, 0.13490785232612065], [0.04029543651267886, 0.034606185009969134, 0.04572256315233452, 0.02856773224526218, 0.02238860390415149, 0.014410356924469982, 0.08079724945127964, 0.041346711173121414, 0.037286998837121894, 0.05368740736906018, 0.027171907680375234, 0.05495353675048266, 0.05056371712791068, 0.02141573396511376, 0.024604375274585824, 0.005108006955457053, 0.034167715680918524, 0.0184486343392304, 0.047408912663481066, 0.016215584074546183, 0.05291655087577445, 0.024696874864665524, 0.005042361660993525, 0.06193526514938899, 0.5936150582773345, 23.005063431603567, 43.53251041684832, 20.88129094668797, 44.94365133558001, 25.803452151162283, 50.596754346575054, 11.128642201423645, 1.6046991667577197, 1.6792350986174174, 1.77440587750503, 3.7557275891304016, 0.5387736867581094, 0.2348390429147652, 7.616955757141113, 50.60350104740688, 56.39883368355887, 56.90844236101423, 53.02761289051601, 53.288323198046, 45.191660336085725, 43.69063057218279, 39.369556290762766, 44.93598747253418, 49.654985087258474, 51.092744554792134, 49.914812973567415, 54.1861937386649, 51.012138502938406, 52.88833277566092, 50.32864768164498, 51.94086251940046, 49.06881768362862, 49.176431383405415, 51.228557518550325, 50.557250363486155, 45.33396291732788, 38.61931412560599, 36.11229290281023, 37.14675113133022, 38.30984830856323, 39.15276902062552, 37.42477287564959, 39.78037895475115, 39.69419697352818, 38.49059874670846, 37.6703256879534, 38.17512968608311, 36.229877267565044, 36.94907488141741, 36.77304227011544, 38.97429411751883, 45.82058695384434, 50.272280420575825, 50.18649796077183, 50.51918813160488, 50.07360363006592, 49.67051778520857, 48.20941931860787, 46.71158572605678, 45.17252847126552, 41.33391625540597, 40.616514750889365, 44.39492082595825, 47.825152669634136, 52.03110919679914, 49.3443728174482, 49.63103812081473, 48.69776998247419, 49.19408328192574, 46.3796945980617, 43.17054401125227, 40.256323610033306, 37.211358955928254, 36.091413566044395, 36.32829850060599, 40.655362129211426, 42.54286112104143, 42.208576338631765, 41.19073472704206, 38.33963871002197, 36.16318498338972, 33.86448117664882, 35.05423511777605, 35.80522421428135, 36.57406323296683, 36.768588474818635, 34.63259410858154, 34.921930994306294, 36.15330464499337, 35.83289541516985, 33.315017632075715, 33.25870248249599, 33.91011347089495, 34.702423504420686, 34.12007761001587, 33.98942715781075, 33.30924367904663, 33.67712647574288, 32.762965883527485, 33.682483536856516, 34.43066208703177, 34.7211662701198, 35.679771014622276, 34.892397676195415, 32.42162867954799, 35.65388897487095, 36.40490239007132, 38.14587082181658, 39.610592773982454, 43.17164182662964, 41.434043271201, 43.582363741738455, 43.750815868377686, 43.80331645693098, 41.361611774989534, 46.074227469308035, 45.41167504446847, 51.5613762310573, 17.84125256538391, 0.0755816153915865, 0.183879393818123, 6.9640878183501105, 8.081705127443586, 3.626575993640082, 0.8768432289361954, 0.5152704822165626, 40.83195407049996, 31.2101685660226, 30.668962955474854, 43.580373082842144, 31.52578353881836, 21.837868554251536, 0.20608431659638882, 0.015801777797085897, 0.04969242388116462, 0.12298414643321719, 0.06861751193978957, 0.05885130991893155, 0.044793496041425636, 0.029060101003519127, 0.04727669332974723, 0.0283391728132431, 0.014123150014451571, 0.01682603488942342, 0.024739934696948955, 0.02824075979047588, 0.013114618819339998, 0.0185238143229591, 0.02332832062217806, 0.10595107184989111, 0.00443786329456738, 0.04623119978766356, 0.017186504921742847, 0.056557121952729564, 0.00713480165826955, 0.03052037621715239, 0.012423688662238419, 0.04669290554842778, 0.06486056532178607, 0.02469757036305964, 0.050768509174564054, 0.01182551509035485, 0.05964714328625372, 0.061924198243234835, 0.037159363007439036, 0.03985333362860339, 0.008391367088604187, 0.011309596926106938, 0.013272273038247866, 0.03074578894302249, 0.05550247836591942, 0.05797895137220621, 0.05946101434528828, 0.04704345030976193, 0.057347723815057955, 1.142234668135643, 31.63904959814889, 44.311803000313894, 23.862137624195643, 50.8289110319955, 29.709712028503418, 56.071583952222554, 9.00132439817701, 1.0599831960030963, 0.7283084935375622, 3.2682154859815324, 5.361770689487457, 2.2976444235869815, 0.7426755226084164, 8.911346094948904, 54.043408257620676, 58.14009393964495, 59.77670737675258, 53.892979758126394, 54.68758269718715, 46.25107649394444, 44.41306604657854, 40.77629899978638, 46.26697744641985, 52.00287866592407, 53.73035022190639, 51.42262417929513, 55.29555007389614, 51.21938937050955, 54.81038168498448, 51.7757385798863, 52.5709216935294, 51.60177305766514, 52.11782618931362, 50.811373778751914, 53.56242615836007, 48.41205658231463, 39.42249461582729, 37.386439664023264, 39.12572315761021, 37.90236077989851, 39.90861143384661, 39.160335608891074, 41.023734773908345, 41.32652684620449, 41.48387227739607, 39.37911353792463, 39.83131619862148, 38.93702745437622, 38.13843624932425, 38.60831165313721, 40.27450704574585, 45.88105017798287, 52.322648661477224, 51.75243084771292, 52.19980451038906, 51.99966164997646, 49.831573554447715, 48.71892377308437, 48.48480074746268, 45.20860351834978, 43.03558567592076, 42.022913524082725, 46.6041978427342, 50.77028908048357, 52.52329526628767, 51.77111802782331, 51.17446231842041, 51.20718485968453, 49.13780287333897, 47.598234925951274, 46.37965290887015, 40.77216134752546, 39.47786481039864, 37.52803005490984, 38.74636888504028, 41.3619452885219, 43.923158986227854, 43.65886688232422, 42.98821633202689, 37.85804516928536, 37.47671413421631, 36.4518826348441, 37.96226814814976, 36.337720257895334, 37.08815349851336, 38.042981897081646, 36.598722389766145, 36.33445807865688, 37.83882645198277, 36.87761613300869, 36.2420539855957, 35.86105646405901, 36.052878856658936, 37.00821099962507, 35.81337792532784, 34.97431346348354, 35.846044881003245, 36.08721685409546, 34.687717642102925, 35.51498058864048, 36.5975272996085, 36.638563360486714, 37.09540046964373, 36.578940868377686, 34.75454889025007, 36.579017298562185, 36.2134621483939, 38.827850409916465, 41.008966377803254, 42.99042238507952, 43.65645238331386, 43.676775864192415, 44.016980511801584, 44.207736355917795, 44.396202768598286, 47.84944704600743, 47.73435708454677, 50.63988528932844, 21.026987722941808, 0.10863555994416986, 1.3842457447733199, 6.275116605418069, 15.212709086281912, 3.6451782754489352, 0.45866236835718155, 0.7276505859834808, 45.020328181130544, 35.79534387588501, 38.0034362248012, 44.09483160291399, 35.581287247794016, 33.127016748700825, 0.9428107291460037, 0.19125758005040033, 0.08554307264941079, 0.07820865871118647, 0.020506753187094415, 0.06142054205494268, 0.006584058956442667, 0.04137042257934809, 0.07065475905047995, 0.034769932473344464, 0.028815149861787046, 0.01921547729788082, 0.03164935331525547, 0.031230571679770947, 0.09421973063477448, 0.026689264025273066, 0.008665133068071944, 0.050052535986261706, 0.02717256246666823, 0.18171093160552637, 0.1003026342285531, 0.13948617236954824, 0.09389998457793679, 0.11777147757155554, 0.1025799402434911, 0.15441738973770822, 0.1213908919266292, 0.13216380242790493, 0.12100428981440407, 0.1121786730363965, 0.2086684357907091, 0.14947470995996678, 0.18625438851969583, 0.0968166266434959, 0.087384413129517, 0.0699214187583753, 0.16677953781826155, 0.12609506664531572, 0.14948773783232483, 0.22537106381995337, 0.09406412219894783, 0.1367712723357337, 0.2065075731703213, 1.2307170459202357, 34.65696144104004, 55.55149391719273, 30.83675500324794, 58.21193136487688, 35.422927379608154, 61.67977728162493, 13.15204187801906, 2.6254091901438574, 6.98831444978714, 6.420518517494202, 11.559004936899457, 2.2039520910808017, 0.512143955699035, 9.51939424446651, 54.37184265681675, 59.62049102783203, 60.878003801618306, 56.317675249917166, 57.527162075042725, 48.47915881020682, 47.12646613802229, 44.51477377755301, 48.288642678942, 55.09747082846505, 56.30776364462716, 53.23188298089163, 56.525273527417866, 52.03263085229056, 57.11553342001778, 52.94001347678048, 56.36629179545811, 52.2631755556379, 53.916989258357454, 53.95803574153355, 55.508366448538645, 50.56008522851126, 42.437147753579275, 40.01678793770926, 41.78224876948765, 40.541095529283794, 43.9000631741115, 41.080209732055664, 44.77855518886021, 43.440950529915945, 43.01878145762852, 40.74522318158831, 42.83228485924857, 39.5898871421814, 40.55826105390276, 41.25506809779576, 42.480289118630544, 48.61472511291504, 54.05671405792236, 53.210986273629324, 55.56883314677647, 53.01171888623919, 53.21137189865112, 51.80062355313982, 51.545120920453755, 48.84732648304531, 45.5231727872576, 44.505518777029856, 48.84265729359218, 51.16986608505249, 55.55225127083914, 54.005863666534424, 53.25989811761038, 51.87955161503383, 51.673329080854145, 48.78372267314366, 47.56037071772984, 43.75196232114519, 41.328642572675435, 39.97600548607962, 41.559982844761436, 45.690933568137034, 47.81993109839303, 45.28689929417202, 45.59956475666591, 42.24419627870832, 39.958909443446565, 35.89553689956665, 39.13847310202462, 38.785247530256, 38.83816501072475, 40.84270988191877, 37.79310730525425, 36.82630716051374, 40.05663933072771, 38.36777196611677, 38.09424918038504, 38.398892947605674, 38.6699595451355, 39.298705509730745, 39.21970101765224, 37.68980843680245, 38.78836727142334, 37.16595595223563, 36.501881871904644, 38.491088594709126, 39.06748683112008, 38.237475872039795, 39.21368735177176, 37.94185781478882, 37.20598105021885, 39.57344423021589, 39.527784143175396, 40.939665045057026, 43.379441601889475, 46.49830729620797, 46.35320806503296, 45.24545676367623, 47.32327733721052, 47.19176878247942, 47.20132255554199, 49.851591314588276, 50.09596640723092, 51.848656449999126, 20.74298357963562, 0.16056849967156137, 2.140725003821509, 19.641367537634714, 20.731015307562693, 8.383789352008275, 1.8075025358370371, 1.2467861665146691, 50.106461661202566, 39.49539164134434, 43.22821405955723, 49.54855258124215, 42.59759208134243, 43.17686687197004, 1.3807988954441888, 0.43333040337477413, 0.1672568464917796, 0.261777046003512, 0.10602298977651767, 0.1489329540303775, 0.11912383857582297, 0.12057124876550265, 0.18871491934571946, 0.13057255638497217, 0.11557083922837462, 0.07367850786873273, 0.17406416764216764, 0.09347857361925499, 0.1506313950355564, 0.12463861836918763, 0.11695893188672406, 0.22164340955870493, 0.09522932967437164], [0.06781561925475087, 0.012276935956573911, 0.010166105963954968, 0.026244255314980234, 0.02972542155267937, 0.10302545955138546, 0.02744029033263879, 0.019962929422035813, 0.033659207967243025, 0.0806506248190999, 0.05038389177726848, 0.006435796934446054, 0.02732306153380445, 0.01242698379792273, 0.04403767588415316, 0.00952193365498845, 0.04903713547225509, 0.025871726019041877, 0.05402884619044406, 0.056978641477014334, 0.02425755058149142, 0.03834928612091711, 0.03460362693294883, 0.03964083003146308, 0.014596757279442889, 3.760921367577144, 32.66902623857771, 26.646800177437918, 24.470092841557094, 34.187739167894634, 30.14171280179705, 32.40570688247681, 0.8482134480561528, 0.1524677143565246, 2.156275289399283, 3.2619512506893704, 3.05868604353496, 0.46353050427777426, 0.12079160979815892, 25.345553704670497, 60.12333215985979, 54.5794027192252, 56.61272355488369, 50.63265221459525, 45.615462235042024, 41.543063981192454, 42.110801288059776, 49.6186112676348, 50.34538241795131, 50.50436067581177, 51.1049108505249, 51.04437814440046, 49.830170018332346, 52.237488065447124, 49.53774813243321, 51.867975916181294, 47.28337383270264, 51.97723981312343, 50.51995938164847, 49.94477360589163, 41.1815561567034, 35.77143859863281, 37.42328248705183, 37.842613220214844, 38.48940713065011, 39.04466894694737, 38.6344438280378, 38.60381964274815, 37.68997171946934, 38.581512451171875, 37.446656227111816, 35.994583470480784, 37.14158514567784, 35.92112364087786, 36.88745478221348, 40.202975341251914, 46.442718233381, 49.14845098767962, 50.25109536307198, 52.42032296316964, 50.067725454057964, 51.06845365251814, 49.80232163837978, 50.20159292221069, 48.410913603646414, 45.211890016283306, 42.95961059842791, 42.92213201522827, 47.38002674920218, 49.388393129621235, 49.225464820861816, 50.510916301182334, 51.798876081194194, 48.773182255881174, 42.9051957811628, 39.86230863843645, 39.14474037715367, 36.77210773740496, 41.20003489085606, 45.04869767597744, 46.941949776240754, 48.387616293770925, 48.26002652304513, 46.11759465081351, 40.669724055698936, 35.37269537789481, 35.76882260186331, 34.91686575753348, 36.345582144601, 35.36710902622768, 35.589277676173616, 34.877716132572715, 36.54975496019636, 34.87903281620571, 35.31911087036133, 34.36014134543282, 34.64577831540789, 34.41023785727364, 34.958822454724995, 34.432142053331646, 36.37899603162493, 33.476549352918354, 34.44452026912144, 34.27082920074463, 34.17058753967285, 33.88331774302891, 35.8561475617545, 34.49586745670864, 34.76926170076643, 40.718149525778635, 45.570323262895855, 46.73797151020595, 47.52422618865967, 46.25147601536342, 47.05512203489031, 46.06502110617501, 47.141616685049875, 43.969156060900005, 46.58543423243931, 43.497821535382954, 48.97880377088274, 47.79275321960449, 45.78528315680367, 4.77592898266656, 0.44390317318694933, 0.6927410449300493, 3.053287293229784, 14.153596912111555, 2.5827520276818956, 1.0688194589955466, 4.534487766878946, 44.24898781095232, 25.240872144699097, 33.90775803157261, 42.17845937183925, 37.72730786459786, 10.390304906027657, 0.1534754881369216, 0.02596582525542804, 0.08290891828281538, 0.03690794203430414, 0.054019706323742867, 0.08926358872226306, 0.02726577960753015, 0.05215483424918992, 0.0213176907439317, 0.005661249210658882, 0.030643045170498744, 0.057070128353578706, 0.04322695206584675, 0.056382416148803065, 0.04430366161146334, 0.07672515724386487, 0.044865291831748824, 0.030181271556232656, 0.04338929156905838, 0.061459618886666637, 0.04788856906816363, 0.029749750425773006, 0.04865608038380742, 0.06088154097752912, 0.07389542872884444, 0.03142525694732155, 0.03538222211812224, 0.05862484885645764, 0.007416839827783406, 0.04613669003759112, 0.02334595235463764, 0.01707463994223092, 0.024318679801321456, 0.11115375267607824, 0.015379281182374274, 0.04931278353823083, 0.0025879885402641124, 0.020709343387612274, 0.023644344914438467, 0.014598552004567214, 0.038158509215073924, 0.030899643365825926, 0.05742721419249262, 0.03078712529635855, 7.523770860263279, 43.38650097165789, 27.376063993998937, 38.67530618395124, 39.21639714922224, 37.13076332637242, 34.056522437504356, 0.6062442777412278, 0.09333374710487467, 1.6234603886093413, 3.735064515045711, 4.066944352218083, 2.779851794242859, 0.3785768342869622, 29.033186776297434, 60.30948829650879, 57.42274454661778, 57.47554390771048, 52.954246861594065, 47.10440213339669, 45.37566253117153, 43.16556910106114, 51.18359572546822, 51.137053217206685, 52.382882595062256, 53.27660158702305, 54.335451466696604, 52.333533014569966, 54.899853638240266, 51.42007071631295, 53.486027240753174, 49.49113614218575, 52.2773186138698, 52.38870865958077, 52.74332387106759, 43.152336256844656, 39.77331263678414, 38.06659882409232, 39.88907657350813, 40.23089667728969, 40.18234961373465, 40.41541651317051, 42.06356743403843, 39.24815389088222, 40.593877519880024, 39.756734234946116, 37.48288760866438, 39.43525150844029, 38.40564659663609, 37.48562519890921, 42.59496913637434, 49.55682441166469, 50.401516914367676, 50.94420943941389, 51.404934065682546, 51.605299268450054, 51.97055564607893, 51.551499366760254, 51.45730611256191, 48.480847222464426, 46.82986838476998, 44.25134672437395, 45.73512411117554, 49.449002265930176, 49.98569849559239, 51.52135460717337, 52.54598808288574, 51.27022239140102, 51.57662752696446, 47.203295843941824, 41.829131739480154, 40.80726364680699, 37.779971735818044, 40.04095377240862, 44.569341455187114, 48.452126843588694, 49.46928405761719, 50.28649990899222, 47.83618293489729, 41.219361305236816, 37.7767790385655, 37.173508644104004, 37.48545496804373, 37.20127364567348, 37.2550561768668, 38.022599356515066, 36.79159048625401, 37.98939391544887, 36.735633168901714, 37.284224714551655, 36.2389828818185, 35.40265948431832, 36.27469662257603, 36.18701730455671, 37.50940540858677, 37.75980806350708, 34.979479449135916, 36.757620743342805, 35.78211450576782, 34.89216838564192, 35.15202406474522, 37.38829483304705, 36.31890106201172, 37.615139620644705, 41.32656158719744, 45.67745058877127, 48.074947357177734, 49.13497495651245, 46.71003975187029, 50.206380231039866, 46.82553965704781, 49.73656388691494, 44.41965988704136, 47.57388148988996, 45.95846700668335, 50.98559291022164, 47.37093503134591, 47.8838996887207, 4.9429241589137485, 0.43759271608931677, 3.417730514492307, 6.826307645865849, 8.781401753425598, 0.9191445133515767, 0.5412366603102002, 4.327412341322217, 48.55369561059134, 28.39510416984558, 42.931428704942974, 46.21334777559553, 42.07016474860055, 14.94759362084525, 0.1476225672023637, 0.004373541567474604, 0.051817425925816805, 0.019567083966519152, 0.07074336215321507, 0.020277369335027676, 0.05979788662599666, 0.005593438117232705, 0.01710077711114926, 0.03677704584385667, 0.07176742077405963, 0.07932216181818928, 0.06378728577068873, 0.04669357390542116, 0.048640223020421605, 0.04671105636017663, 0.06148965084659202, 0.018334340204351714, 0.06601370844457831, 0.10368808292384658, 0.10712385177612305, 0.083146174837436, 0.10981171897479466, 0.08518093172460794, 0.20151708381516592, 0.08963197216923748, 0.09735421636807066, 0.08798902854323387, 0.14734021521040372, 0.11373349531952824, 0.15098559031529085, 0.13510119409433433, 0.11033281351306609, 0.19058359121637686, 0.21656300074287824, 0.1623739456491811, 0.10337541398725339, 0.09598901748125042, 0.23225252170647892, 0.0889480427971908, 0.14345089319561208, 0.1801833321473428, 0.09923108494175331, 0.0861150301726801, 7.132381873471396, 48.944969517844065, 37.60728815623692, 35.55334159306118, 44.38111822945731, 38.841507094247, 41.2040822165353, 0.9879503526857921, 1.025371178984642, 4.628433057240077, 14.975994382585798, 8.838331818580627, 2.3300084812300543, 0.5642254267420087, 27.54931037766593, 64.65450259617397, 58.78075953892299, 62.218568393162315, 54.81173658370972, 49.41894088472639, 47.387009688786094, 45.62066643578665, 52.949178150721956, 53.56927360807146, 53.40690115519932, 56.11655616760254, 55.512636116572786, 53.663157667432515, 55.686156954084126, 53.5194411277771, 55.256442138126914, 52.757032666887554, 55.33891725540161, 52.6676093510219, 55.13010304314749, 46.87669229507446, 41.01740149089268, 41.00142758233206, 42.436831610543386, 42.85362277712141, 42.60392883845738, 43.049801690237864, 43.372819968632285, 41.068272726876394, 41.931742736271445, 42.54479619434902, 38.71339968272618, 41.92251900264195, 39.94984899248396, 40.291919231414795, 44.21637296676636, 50.33908040182931, 52.9351601600647, 54.370258467538015, 55.138225487300325, 53.95296008246285, 53.96363251549857, 55.7862457547869, 54.328239236559185, 51.33784573418753, 49.89712633405413, 46.572920526777, 47.355576038360596, 53.22604301997593, 52.41784940447126, 54.59436913899013, 55.41433647700718, 53.90059150968279, 53.91018349783761, 49.0811333656311, 44.74834789548601, 43.55465085165841, 40.28204236711775, 44.278667041233604, 48.6288994380406, 50.03766059875488, 51.16470009940011, 50.847184794289724, 50.62833390917097, 44.10857513972691, 38.467676639556885, 40.116855893816265, 39.54395260129656, 40.23090362548828, 39.87105294636318, 39.14368077686855, 39.0325026512146, 39.0037579536438, 38.46678727013724, 38.74916900907244, 38.03429664884295, 36.951590129307334, 38.67731768744332, 38.57448434829712, 39.47340406690325, 41.42611537660871, 38.37180192129952, 38.13622324807303, 37.33114242553711, 37.20949336460659, 36.9247214453561, 39.9789445740836, 38.48254231044224, 39.3121155330113, 44.9630263873509, 49.104399408612935, 52.100518226623535, 51.000517640795024, 49.42482948303223, 51.964420386723106, 49.075474057878765, 51.170015471322195, 47.07343053817749, 50.373661586216514, 47.96469334193638, 52.305576937539236, 50.059992109026226, 48.49407311848232, 6.622704582554953, 0.7114888046469007, 3.586224764585495, 16.493835312979563, 29.962887014661515, 9.146504402160645, 1.4855352810450961, 6.470884272030421, 55.139743668692454, 34.511959484645296, 47.08614574159895, 46.31831421170916, 52.224943092891145, 18.926099130085536, 0.24730362264173372, 0.1411447019449302, 0.10597509877490145, 0.12257401272654533, 0.14295193925499916, 0.16962920847748006, 0.16875066847673484, 0.13844208339495317, 0.18436697551182338, 0.13316314880337032, 0.13839393455002988, 0.18961468392184802, 0.17884365974792413, 0.1863706215683903, 0.1407457912074668, 0.10644043809069054, 0.10664019201483045, 0.225424355960318, 0.15607168525457382], [0.03759224460061107, 0.07087641608502183, 0.026597429399511645, 0.01495888632988291, 0.02551965625025332, 0.019038257521710227, 0.04023773728736809, 0.06200064199843577, 0.02506910899787077, 0.011277534450138254, 0.062369215435215404, 0.026539926949356283, 0.0699725260159799, 0.02388260909356177, 0.0349830230032759, 0.00843890949285456, 0.020716973513896977, 0.03627323359251022, 0.03322723900367107, 0.024703441387308494, 0.08045036199369601, 0.047329496924898455, 0.02222751290537417, 0.045700866995113235, 0.05838406391974006, 0.04722222053845014, 14.246080040931702, 42.937063694000244, 15.275767462594168, 43.27003526687622, 26.142015286854335, 35.11984348297119, 1.6254617955003465, 0.8485126005751746, 1.1579502991267612, 3.9537842529160634, 1.1648436720882143, 3.954494271959577, 0.032237806024828126, 4.278447517326899, 52.60598577771868, 58.374338558741975, 56.23153148378645, 55.41264806474958, 51.79040275301252, 42.605530398232595, 47.71762582233974, 49.39307621547154, 51.967731203351704, 49.993577752794536, 50.59699405942644, 50.679010595594136, 52.76854583195278, 48.01680483136858, 52.223272051130024, 50.31206233160836, 51.573872566223145, 52.49834081104824, 50.29091201509748, 42.874415261404856, 38.742210388183594, 38.52827535356794, 38.39069059916905, 37.257074628557476, 38.69033513750349, 39.47662108285086, 37.55039283207485, 38.048821857997346, 39.27785743985857, 39.129054818834575, 37.72132893971035, 37.20717961447579, 37.006352356501985, 36.72886562347412, 37.91970695768084, 41.77104827335903, 47.82244982038225, 49.52404628481184, 52.03235987254551, 50.61398240498134, 51.298883710588726, 50.89176443644932, 52.110895361219136, 48.73692308153425, 48.24306944438389, 49.10857875006539, 45.181154659816194, 45.78883021218436, 49.004060472760884, 51.74135889325823, 50.43179368972778, 50.660563128335134, 49.1859712600708, 45.6921842438834, 43.20815461022513, 38.77259138652256, 42.64312710080828, 44.55261019298008, 46.748296533312114, 47.06361968176705, 46.857244287218364, 49.64345107759748, 48.371451309749055, 48.729054246629985, 44.196758202144075, 34.961643423352925, 37.05969367708479, 34.7735070501055, 34.10067823954991, 36.288634708949495, 36.26831470217024, 34.555340562547954, 35.48985937663487, 34.418068477085654, 35.291575159345356, 35.6662289755685, 34.55174486977713, 34.77365296227591, 35.14549970626831, 34.62572928837368, 35.051330770765034, 34.360033648354666, 33.58705350330898, 33.07966477530343, 34.18758978162493, 34.953719002859934, 35.1167619568961, 33.07978636877877, 42.61330543245588, 44.371891021728516, 47.05294724873134, 46.32394920076643, 47.05478504725865, 45.83363914489746, 46.87690074103219, 46.20543030330113, 46.10339948109218, 47.28914083753313, 48.328334263392854, 47.35630212511335, 48.73285491125924, 48.28710017885481, 21.369490487234934, 0.25503607200724737, 0.14928526298276015, 2.709392066512789, 2.7206372916698456, 7.641687870025635, 1.0500891783407755, 0.6707349057708467, 8.560765181268964, 35.311467851911274, 30.60136045728411, 24.713896444865636, 29.210800102778844, 34.42436007090977, 2.6904567054339816, 0.08490852705602135, 0.024158501432144215, 0.03436892506267343, 0.03575020183676055, 0.03366391700027244, 0.05821649969688483, 0.021285899681970477, 0.04871792545808213, 0.0496990090635206, 0.057107108512095044, 0.04418651254049369, 0.03506296121382287, 0.027469394395926168, 0.054520502486931424, 0.08977119398436376, 0.045885737253619094, 0.05864502848791225, 0.09223576209374837, 0.03441237165991749, 0.07087429905576365, 0.07651272150022642, 0.02003783459908196, 0.05809140498084681, 0.05197695968672633, 0.03050023390512381, 0.031873225766633234, 0.04424967736537967, 0.07271185331046581, 0.05237388570926019, 0.060985696102891646, 0.038848691287317445, 0.031186131028724567, 0.01568417071497866, 0.055408419841634374, 0.02190537840527083, 0.03790755982377699, 0.03306659923068114, 0.030349867152316228, 0.017373583811734403, 0.05293275768469487, 0.04383206620280232, 0.029701228386589458, 0.03825343626418284, 0.030797293143612996, 0.10745890558298145, 21.344433546066284, 44.63657569885254, 15.898789848600115, 50.764949389866416, 29.066779579435075, 38.889147417885916, 0.7427428332822663, 0.4034158300076212, 0.33588978914277895, 2.546144140618188, 5.760695431913648, 5.319091379642487, 0.6631118091089385, 5.012627184391022, 54.81924063818795, 58.461017336164204, 58.38679667881557, 55.57037912096296, 52.279875550951274, 44.23274292264666, 48.5265976360866, 50.996428625924246, 54.40692758560181, 52.26990488597325, 52.603203024183, 52.10799101420811, 54.82867281777518, 51.34888294764927, 54.582598890577046, 51.542418071201865, 52.742406708853586, 54.78316559110369, 52.89778927394322, 46.09324468885149, 41.26521941593715, 41.39860051018851, 39.21525764465332, 39.19386414119175, 38.544304847717285, 39.6969484601702, 40.15157951627459, 39.31870589937483, 41.55060625076294, 40.87253849846976, 39.87397813796997, 38.89377839224679, 38.60386480603899, 38.10344859531948, 39.169889381953645, 42.366574900490896, 47.81285088402884, 50.492371559143066, 52.52327789579119, 52.332716601235525, 52.75251286370413, 50.93230717522757, 53.394891193934846, 50.85378558295113, 51.22133139201573, 49.78929376602173, 47.05849191120693, 47.90224640710013, 49.54624925340925, 52.5107398714338, 51.593216351100374, 51.980696541922434, 51.343439034053254, 47.68669939041138, 44.14364964621407, 41.1794056892395, 42.619576181684224, 45.76090540204729, 49.05725588117327, 48.771459102630615, 49.03262799126761, 50.88579593385969, 49.55501440593174, 49.87861633300781, 45.23114000047956, 35.591035570417134, 37.54539360318865, 36.15549332754952, 37.15562745503017, 38.116059575762065, 38.34698295593262, 36.27117735998971, 37.783616065979004, 35.82372031893049, 37.73509679521833, 36.771649156297954, 37.02611303329468, 36.76106357574463, 37.7642479624067, 35.76465368270874, 36.783947467803955, 35.97111592973982, 35.11680712018694, 35.207613127572195, 36.55498347963606, 36.318442480904714, 36.72640943527222, 34.827782903398784, 44.71720954350063, 46.35252366747175, 48.66089589255196, 46.035810879298616, 48.47941241945539, 47.780920437404085, 47.961368628910606, 47.57622650691441, 47.63931615012032, 48.35676976612636, 49.064659186771934, 47.49619715554373, 49.958777700151714, 48.495500973292756, 25.7039452620915, 0.26745551558477537, 1.1765737512281962, 4.617965596062796, 6.147788260664258, 4.851181447505951, 0.14414823720497744, 0.6629792505076954, 10.013665642057147, 42.2930177961077, 36.525283404758994, 29.176910264151438, 29.95040110179356, 42.85452951703753, 4.927577325275966, 0.10469607383544956, 0.035718293727508614, 0.05046463405181255, 0.008590217713000519, 0.01676819656443383, 0.05814792016255004, 0.009612235639776503, 0.04202875082514115, 0.03376799748678293, 0.08344077438648258, 0.04531099095142313, 0.06792480910995177, 0.03799533850646444, 0.04241683553638203, 0.0212125907585557, 0.011598808907105454, 0.029576147241251807, 0.09596346385244812, 0.0077529063481571415, 0.2353154830634594, 0.1196287093417985, 0.06173965707421303, 0.13015030404286726, 0.18883018887468747, 0.1881975635354008, 0.11725182831287384, 0.13782674712794168, 0.19361044093966484, 0.1248418531779732, 0.19828550650605134, 0.11914310897035257, 0.12457292260868208, 0.08825589636606829, 0.12483258438961846, 0.07818147659833942, 0.08769596926867962, 0.1600084097257682, 0.11628502447690282, 0.08485320609595094, 0.15828121240649903, 0.10901338181325368, 0.14844982352639946, 0.138590967548745, 0.11828906408378057, 0.29816994603191105, 23.888905559267315, 57.6075770514352, 22.8036299433027, 54.824708870479036, 34.46685872759138, 45.110446316855295, 1.7871577761002948, 1.7378632383687156, 4.906275451183319, 7.198521341596331, 6.597156056335994, 6.944206416606903, 0.43312852563602583, 4.999730025018964, 57.548677171979634, 60.41290528433663, 61.859422956194194, 57.37336369923183, 55.23765073503767, 46.551447119031636, 51.86231313432966, 54.0312489100865, 56.96977410997663, 54.60848093032837, 54.453480516161235, 54.837107930864605, 57.14992005484444, 51.34037140437535, 56.808527265276226, 53.3382112639291, 54.433122294289724, 56.45869936261858, 54.87812662124634, 46.64622054781233, 43.26680088043213, 43.899465629032676, 42.35160500662667, 41.54912281036377, 41.57390703473772, 42.63457039424351, 42.98854637145996, 41.66891670227051, 42.975584506988525, 43.28284427097866, 40.6785934312003, 40.387953758239746, 40.290279456547324, 40.04010609218052, 41.66065876824515, 45.03540924617222, 50.133740288870676, 54.779879093170166, 56.18239382335118, 55.250588280814036, 55.17148651395525, 53.358899525233674, 55.0771438734872, 53.77132027489798, 53.831668853759766, 53.384086745125906, 49.83790683746338, 49.80301993233817, 51.921904359545024, 56.30960144315447, 53.994072573525564, 54.68537664413452, 52.97057860238211, 50.09272159848894, 46.77212885447911, 42.5594152041844, 45.74008859906878, 48.252807344709126, 51.32996647698538, 50.77588932854788, 50.28479412623814, 52.33065298625401, 52.442032609667095, 54.021608284541536, 48.52094875063215, 38.552475929260254, 39.81716619219099, 38.28456381389073, 38.612949575696675, 40.61012935638428, 40.21629156385149, 37.19243901116507, 37.90968765531267, 37.817085538591655, 40.01840686798096, 39.69111197335379, 38.421165398189, 39.22021171024868, 39.37057072775704, 38.32605498177664, 39.16122497831072, 38.78314570018223, 38.142830984933035, 37.51666975021362, 37.59095641544887, 37.419857025146484, 39.69933516638619, 36.23099592753819, 47.85956709725516, 48.391319683619905, 50.796059949057444, 49.87752546582903, 50.67877088274275, 48.73129504067557, 50.80207708903721, 49.621988092150005, 50.22415372303554, 49.62328393118722, 51.279880387442454, 50.07402399608067, 52.267646721431184, 49.979789052690776, 25.764882700783865, 0.4502908204283033, 0.9661958685943058, 6.321672141551971, 8.786959443773542, 18.33372003691537, 4.21844938823155, 1.105603113770485, 11.992027963910784, 46.896581513541086, 40.80389724458967, 32.85889966147286, 34.557939188820974, 51.63710117340088, 4.83827907698495, 0.1977205311081239, 0.09922467957117728, 0.13686542585492134, 0.1006070589646697, 0.17813628699098313, 0.12835020492119448, 0.11916911043226719, 0.15276036651006766, 0.12806391742612633, 0.13775560951658658, 0.14804665158901895, 0.18086892393018517, 0.19949443877807685, 0.09108873257147414, 0.1949857228568622, 0.14976985912237847, 0.14362808583038195, 0.17258376707988127, 0.10369547217019967], [0.0450604418957872, 0.05841580578791244, 0.028300777909212878, 0.013194012505534505, 0.03995585009189589, 0.02887977353696312, 0.009050394225466465, 0.058117935700075965, 0.006484014056955597, 0.035623393819800446, 0.02669028522047613, 0.03421599684017045, 0.012225236677165543, 0.020478899324578897, 0.009239010845444031, 0.10110957521413054, 0.056578845251351595, 0.05761989778173821, 0.01788901597527521, 0.012055367131584456, 0.08175417381737914, 0.011955825196179961, 0.039193356542715004, 0.016693927513967668, 0.0932497987523675, 0.026860190389145697, 0.2957633451691696, 32.26228216716221, 30.006452219826834, 27.60774646486555, 35.710805143628804, 31.931895324162074, 16.155491045543126, 1.0810490484748567, 0.5746338282312665, 2.5408302886145453, 4.74634268454143, 2.3263804359095435, 0.18666176737419196, 0.07969358510204724, 17.397481543677195, 63.71575232914516, 52.544112069266184, 57.52305916377476, 51.51618167332241, 52.10726145335606, 49.61155884606497, 52.558227334703716, 53.11682081222534, 56.65435021264212, 52.07300336020333, 52.53739663532802, 52.28114012309483, 50.95525360107422, 52.63810729980469, 51.887639318193706, 53.996157033102854, 50.50578505652291, 46.19492810113089, 39.757991858891074, 38.13483360835484, 39.07142298562186, 38.86544711249215, 37.69224378040859, 38.87191241128104, 38.830278805324006, 41.15428795133318, 40.52271406991141, 40.56296845844814, 39.73204033715384, 40.4972836630685, 37.299771308898926, 37.39566339765276, 35.37905992780413, 37.67600931440081, 39.96174430847168, 45.254086426326204, 49.49193865912301, 51.61962645394461, 49.97928878239223, 47.642699922834126, 49.92648942129952, 50.087295055389404, 50.13944475991385, 53.04954487936837, 49.8742459160941, 49.88975429534912, 49.12014750071934, 50.00749499457223, 49.88626977375576, 48.274843556540354, 50.04944474356515, 50.30329023088728, 46.38606262207031, 43.359434264046804, 43.86049665723528, 45.54796743392944, 47.57329784120832, 50.07470839364188, 50.058981146131245, 51.22854709625244, 49.79252815246582, 49.37692860194615, 47.21279750551496, 43.46315349851336, 35.4235075541905, 35.57242482049124, 36.521732875279014, 35.19040591376168, 37.23985351834978, 35.208599771772114, 35.04507391793387, 35.28263630185808, 35.37114245550973, 34.795001302446636, 34.45657886777605, 35.57581206730434, 33.71579320090157, 34.64219651903425, 34.44743503843035, 34.90368849890572, 35.26574870518276, 33.04212365831648, 32.72084937776838, 36.08976336887905, 32.7558057648795, 35.40487595966884, 36.085479804447715, 42.1713478905814, 45.55806316648211, 47.747367586408345, 49.30259329932076, 48.537485463278635, 46.821203981127056, 45.40246868133545, 44.210960320064, 46.86297655105591, 43.71812459400722, 48.66458191190447, 45.096793106624055, 48.4972380229405, 31.929873398372106, 3.2783859116690497, 0.1134315472362297, 0.3655693722622735, 4.611690938472748, 5.154586264065333, 1.2149354070425034, 0.1512213269514697, 0.07242136568363224, 11.482444473675319, 31.5053836277553, 27.34580111503601, 18.56182939665658, 38.401578426361084, 14.23399017538343, 0.43948534024613245, 0.012592274928465486, 0.04678361210972071, 0.010885169031098485, 0.028372195416263173, 0.03255109582096338, 0.013017595945192235, 0.05327584873884916, 0.04632662556001118, 0.0332322906968849, 0.016212249074929526, 0.03710471379703709, 0.019602545902931263, 0.13456490715699537, 0.08231760894081422, 0.03218054445460439, 0.027460444519030194, 0.05945688885237489, 0.020093269213767986, 0.048119708629591126, 0.051462508006287475, 0.02292380348912307, 0.07450702626790319, 0.059771763027778695, 0.029088582510926893, 0.020900289927210127, 0.036777968651482036, 0.030911158105092387, 0.05541767845196383, 0.03374627758083599, 0.053575808714543066, 0.058042150123843124, 0.015235404617020061, 0.07881699249680553, 0.04096262642581548, 0.06902839882033211, 0.008260099400234009, 0.03487858289320554, 0.004334856165639524, 0.038981141322957616, 0.06336812754826886, 0.014458863696615611, 0.0969882213643619, 0.0416541655680963, 0.020744099647604992, 0.03947639046236873, 1.4645484643323081, 45.21185874938965, 26.508180141448975, 36.79172250202724, 45.069000312260215, 39.950488226754324, 15.65792533329555, 1.127458889569555, 0.3320862746664456, 2.9271103952612196, 4.727449664047786, 5.473649280411856, 1.7580677313464028, 0.045582170864301066, 21.183845043182373, 63.070591245378765, 54.20023257391793, 57.244353021894185, 54.64053644452776, 52.352046489715576, 52.69460310254778, 52.72478607722691, 55.327060154506135, 57.92073931012835, 54.88998024804251, 54.8536376953125, 54.949915409088135, 51.87540006637573, 54.383539949144634, 52.92479692186628, 54.7300500869751, 53.11961398805891, 49.55295079095023, 43.603218759809224, 41.41226066861834, 40.52249520165579, 40.04017210006714, 40.14950895309448, 40.57228251865932, 40.421155725206646, 41.57742977142334, 42.99446276256016, 42.239283902304514, 41.358200209481375, 41.57139526094709, 38.49055010931832, 40.32075078146798, 38.032861845833914, 38.80758598872593, 43.356818267277305, 47.35889727728707, 51.8704286302839, 54.30896840776716, 52.19902283804757, 48.27677168164934, 50.27393061774117, 51.01524434770857, 53.75625658035278, 51.69320092882429, 50.60003737040928, 50.911747455596924, 51.47933190209525, 51.807151385716026, 50.597424847739084, 51.37839889526367, 51.737589495522634, 52.143805503845215, 47.03090756280081, 45.68884563446045, 44.607733726501465, 47.425238677433555, 49.23839889253889, 49.84148515973772, 50.936632428850444, 50.5170932497297, 51.34068059921265, 50.809730529785156, 48.875484057835166, 45.35237564359392, 35.65892989294869, 37.76668678011213, 37.88211372920445, 36.33740064076015, 37.91304016113281, 38.25535358701433, 36.78494800840105, 35.934307847704204, 36.63091686793736, 35.50220285143171, 35.71810075214931, 37.29782581329346, 36.401348386492046, 36.50272260393415, 38.25525631223406, 36.95079108646938, 36.53369767325265, 35.64870909282139, 33.745521068573, 37.95066813060215, 34.346321378435405, 37.40071473802839, 37.7654812676566, 44.327453817640034, 48.16377660206386, 50.054437024252756, 51.09708717891148, 49.41624845777239, 48.044093881334575, 47.90285437447684, 46.974477767944336, 46.972709451402935, 46.50393533706665, 49.22476652690342, 46.817490168980186, 49.283009801592144, 34.022615228380474, 4.599130766732352, 0.6505761731948171, 2.57383662036487, 6.008072580610003, 4.914510803563254, 2.181619712284633, 0.08800811573330845, 0.23400259922657693, 13.045679722513471, 34.65810094560896, 37.77890171323504, 18.08301166125706, 41.3163685798645, 23.236389807292394, 0.5935736947825977, 0.07114501417215381, 0.12661965563893318, 0.028475336131772826, 0.09251639739211116, 0.005417452426627278, 0.028573140169360807, 0.03867898289380329, 0.04889967106282711, 0.04459112975746393, 0.050904328136571815, 0.050689639656671455, 0.05380006793088146, 0.02731246960216335, 0.014724661130458117, 0.040015819016844034, 0.00950881587674043, 0.03692941766764436, 0.032225307409784625, 0.0615202324198825, 0.15717522746750287, 0.09972058688955647, 0.10572985586311136, 0.16793269451175416, 0.08894652287874903, 0.1184332799166441, 0.16325374772506102, 0.2206375899591616, 0.07789596263319254, 0.16496258388672555, 0.11179727528776441, 0.11010363831051759, 0.09555602392980031, 0.09860966900097472, 0.12814549090606825, 0.15751640844557965, 0.107992885501257, 0.15269791414695127, 0.14887094950037344, 0.1119500474472131, 0.28557622752019335, 0.10500547901860305, 0.14515491175864423, 0.12726522742637567, 0.16503988259604999, 0.11315030804170029, 2.2285967000893185, 50.49771819795881, 39.38940382003784, 38.273773261478965, 44.996745995112825, 43.87711327416556, 20.616072995322092, 1.2024652361869812, 1.7326312448297227, 7.4060206072671075, 13.971997056688581, 9.305537377085004, 1.4394781695944923, 0.23941589732255253, 20.292549235480173, 64.87323883601597, 56.632237570626394, 61.72380106789725, 56.26566103526524, 56.202654770442415, 54.456225054604666, 57.658653259277344, 57.74140283039638, 61.05678789956229, 57.4572423526219, 57.31476954051426, 55.995212827410015, 53.09252643585205, 56.47277988706316, 56.198034218379426, 57.46896743774414, 55.35173668180193, 50.7193865776062, 45.62606866019112, 42.932536942618235, 42.26838295800345, 42.578390734536306, 41.55449724197388, 42.73311669485909, 43.65920386995588, 45.518514020102366, 45.587061473301475, 45.955882276807515, 43.209641524723594, 43.44171135766165, 40.75656611578805, 42.48568092073713, 41.10687344414847, 41.1039308820452, 45.23405129568917, 48.69828067507063, 53.86810868127005, 55.924580914633616, 54.54391826902117, 50.63156829561506, 51.714024680001394, 52.03407607759748, 56.396016189030235, 56.23960876464844, 53.68231037684849, 53.000542708805625, 55.04635640553066, 53.77507925033569, 54.00477279935564, 50.940252440316335, 55.20017910003662, 53.85498006003243, 50.11955901554653, 48.10820490973336, 48.024909905024934, 48.49991307939802, 51.93685340881348, 53.704617568424766, 55.1470879146031, 53.26113142286028, 53.78149938583374, 52.24930347715105, 50.701019014631, 47.01812982559204, 38.1186443056379, 38.59776081357683, 41.160027163369314, 39.182993684496196, 41.36603430339268, 38.91978897367205, 38.73089872087751, 38.017186709812705, 39.17635815484183, 38.22303751536778, 38.4003381729126, 37.81347942352295, 37.3501353263855, 37.979781082698274, 39.00726331983294, 39.278305598667686, 39.88403218133109, 36.807647773197715, 35.89340032849993, 41.06447901044573, 36.698116370609824, 39.1786128452846, 39.73985358646938, 45.29470212118966, 51.70980017525809, 52.183663845062256, 52.70099197115217, 50.04539046968733, 48.27567039217268, 48.075746400015696, 47.50332253319876, 49.21822827202933, 47.3661789894104, 51.95823648997715, 46.18898391723633, 50.80413375582014, 34.65651328223092, 4.607202402182987, 0.33811986233506885, 3.2046212298529486, 11.898031864847455, 13.943773474012103, 7.4995841809681485, 0.987356498837471, 0.3198555995311056, 15.063244649342128, 43.3228519984654, 37.371535778045654, 27.666455268859863, 50.256945746285574, 27.486741849354335, 0.46361084282398224, 0.08678412676921912, 0.14113189120377811, 0.18817152136138507, 0.1725082461323057, 0.12592248804867268, 0.09295593880649124, 0.13288150248782976, 0.17721368292612688, 0.10493631594415222, 0.10921276254313332, 0.23378462663718633, 0.14133694448641368, 0.2001399834241186, 0.14032786791878088, 0.09958390279539994, 0.13028237409889698, 0.23267413622566632, 0.11880160229546682, 0.18840408245367662], [0.026955080118828585, 0.045757870722029886, 0.02867110027000308, 0.04780290402205927, 0.03976032004824706, 0.08343550895473786, 0.02131132099644414, 0.017137250064739158, 0.048816954251378775, 0.0829628346753972, 0.004272477169122014, 0.016699747648090124, 0.00946986033315105, 0.05508741849501218, 0.06173907353409699, 0.04791459767147899, 0.05561410076916218, 0.02526938878665013, 0.0398704971719001, 0.036349731630512645, 0.018837419637878026, 0.005788508029322007, 0.041626433841884136, 0.020525606282587563, 0.0955682782722371, 0.01598630369906979, 0.03065263626298734, 8.021581496511187, 39.560541425432476, 18.847310032163346, 38.50828538622175, 29.925005435943604, 21.514469861984253, 0.020717194037778035, 0.25662411536489216, 0.2225526464836938, 4.467296080929892, 1.8491108460085732, 3.4295172648770467, 0.6260024032422474, 0.14056663082114287, 36.91871820177351, 65.05141844068254, 57.07947226933071, 56.7972468648638, 54.542010988507954, 52.21197428022112, 52.13819483348301, 53.24916662488665, 54.2385379927499, 52.99346596854073, 50.897170134953086, 49.449481691632954, 48.850196089063374, 52.62796292986189, 51.75161443437849, 51.17971168245588, 47.72831909997122, 41.750043869018555, 38.00383922031948, 38.347854954855784, 38.2682147026062, 40.148928778512136, 38.54485375540597, 38.84244510105678, 40.64291443143572, 41.578145435878206, 44.86038759776524, 46.87298890522548, 45.30670166015625, 42.7379526410784, 38.990163803100586, 36.983850615365164, 36.42526756014143, 38.35167646408081, 37.89079550334385, 44.99313988004412, 49.032127720969065, 49.72820520401001, 49.56404359000069, 51.128656319209504, 48.369300842285156, 45.82870592389788, 32.25518110820225, 47.16291986192976, 50.856147970472065, 50.84070907320295, 50.39332846232823, 51.36603110177176, 51.8207003729684, 49.58540235246931, 49.82064751216343, 48.62786415645054, 47.79750926154, 47.45196492331368, 48.274200848170686, 50.81567471367972, 55.46531193596976, 49.742890221732004, 48.50864349092756, 49.486519064222065, 47.2688764163426, 48.641166482652935, 48.45485053743635, 43.9552457673209, 35.69861452920096, 36.477976594652446, 34.92901120867048, 35.87483821596418, 35.011104175022666, 35.91676017216274, 36.51781061717442, 35.7672175679888, 36.817055634089876, 34.91021285738264, 35.67878784452166, 33.388849190303254, 33.47301966803414, 34.25365325382778, 34.15939399174282, 35.65031065259661, 36.446591581617085, 34.364758423396516, 33.483511447906494, 34.14882230758667, 34.164295945848735, 35.29374647140503, 35.63972854614258, 36.02329690115792, 40.36049100330898, 45.09348576409476, 47.271836348942344, 47.990790775844026, 47.6049781526838, 48.21274055753435, 47.007148197719026, 47.499226570129395, 45.35171556472778, 45.8504398890904, 43.56612580163138, 36.984347411564414, 6.453200238091605, 0.249574462217944, 0.7627429515123367, 3.3190328734261647, 3.2203397921153476, 3.779139978545053, 1.5925975761243274, 0.22177376970648766, 0.09627547461007323, 14.224294832774572, 38.71288204193115, 21.53279399871826, 26.42403745651245, 37.308526039123535, 1.1819374348436082, 0.21029580703803472, 0.052403401982571395, 0.019183630256780555, 0.036760547264878235, 0.027851531747728586, 0.06390406843274832, 0.02369778972518231, 0.046485721665833674, 0.02384433462949736, 0.01714430852527065, 0.043005929461547306, 0.008347350521944463, 0.04371166694909334, 0.012540469627960451, 0.03521617442103369, 0.04441981662863067, 0.022549533750861883, 0.020590613330049173, 0.02264334460986512, 0.0024911340276178506, 0.027888065769470165, 0.03047458188874381, 0.006031820933068437, 0.017956221476197243, 0.07499807527554886, 0.031822793651372194, 0.0033587508868159993, 0.0400177935537483, 0.017288799164816737, 0.006414314515755645, 0.03926872142723628, 0.04182961776054331, 0.009193217365204223, 0.028866898334984268, 0.04079290785427604, 0.048490226069199185, 0.021102478095729436, 0.0112190243754802, 0.05618949167962585, 0.024929605590711747, 0.03878105830933366, 0.04422248846718243, 0.014546113121988518, 0.05860129012061017, 0.024084296842504824, 0.04502537859869855, 0.034509049329374514, 14.854069130761282, 42.7688512802124, 19.820770025253296, 49.253281933920725, 33.907254287174766, 25.539526564734324, 0.0028984168270004113, 0.25602923014334267, 1.4067834211247308, 3.3905367851257324, 2.567119015114648, 3.599976118121828, 1.7852982644523894, 0.3333573064633778, 42.81505332674299, 62.970829010009766, 58.996973582676475, 57.83376176016671, 55.15650619779314, 54.81790658405849, 53.89295196533203, 54.426855019160676, 57.530771664210725, 54.043210233960835, 53.81697688783918, 52.609480721609934, 49.606580461774556, 53.45335333687918, 52.367627825055806, 53.930625098092214, 49.337844984872, 45.23225518635341, 40.51614107404436, 42.155804770333425, 40.52160930633545, 41.76577806472778, 40.952345507485525, 40.519135747637065, 42.63491780417306, 44.2529239654541, 46.63866090774536, 49.09499849591936, 47.05804375239781, 44.21465328761509, 40.755836554935996, 38.335070269448416, 37.64301579339163, 39.07726294653756, 39.13432502746582, 45.3968962260655, 50.480389390672954, 51.55418831961495, 51.97734751020159, 51.23105887004307, 49.96504497528076, 46.99357836587088, 37.08155965805054, 51.01020342963082, 51.48776354108538, 51.339058194841655, 51.39765582765852, 51.83998857225691, 52.73160573414394, 51.738610880715505, 52.36981998171125, 50.21469027655465, 49.40104579925537, 46.60172080993652, 50.13976090294974, 52.75714383806501, 52.86601168768746, 53.0976368359157, 50.24849326269967, 51.071246828351704, 51.21996259689331, 50.48791776384626, 51.10555355889456, 46.54465872900826, 37.12579189028059, 37.785888126918245, 36.350282600947786, 36.48694671903338, 36.998052733285085, 37.54843691417149, 37.3628887448992, 36.43001665387835, 37.700439180646626, 36.1239207131522, 37.49872602735247, 37.16854068211147, 34.895639010838096, 35.81685897282192, 36.4521883555821, 37.09560544150216, 36.64558104106358, 36.454446520124165, 35.18154696055821, 35.6628452028547, 36.49708761487688, 37.36791924067906, 37.57437801361084, 37.90540061678205, 43.789058753422324, 46.24939155578613, 48.02236686434065, 48.86679533549717, 48.024472168513704, 47.496242318834575, 45.93928303037371, 49.47554438454764, 45.991356304713655, 48.50795561926705, 44.268036297389436, 40.33852774756295, 7.9337310791015625, 0.7510604783892632, 1.363751273070063, 3.6647174784115384, 4.965374657085963, 4.626271298953465, 0.4866422755377633, 0.14161669090390205, 0.09054960935775723, 15.834746565137591, 47.21530927930559, 29.120402302060807, 24.58381574494498, 46.37085996355329, 3.3807018271514346, 0.1486094556748867, 0.041373075651271005, 0.10918281879276037, 0.013120218429581394, 0.10352702585182019, 0.05023163869710905, 0.02930501482582518, 0.07547687672610794, 0.05924416133867843, 0.02160456856446607, 0.032149545582277436, 0.06905595412743942, 0.04545999724151833, 0.05546468057270561, 0.035207146512610574, 0.007185182035235422, 0.035075330907212834, 0.03900004191590207, 0.01869313425517508, 0.026413654975060905, 0.14627012477389403, 0.20836347501192773, 0.12145656054573399, 0.12332895078829356, 0.0860335041901895, 0.12630975512521608, 0.12432974922869887, 0.13477821142545768, 0.11809152896915164, 0.10675444374127047, 0.11149570039872612, 0.11037739326379128, 0.05621231759765318, 0.13178319856524467, 0.12966675284717763, 0.12686451178576263, 0.10970932125513043, 0.058555149739342074, 0.22337539733520576, 0.1377535331994295, 0.16997060658676283, 0.08975664619356394, 0.10675800605011837, 0.20631566989634717, 0.17797231221837656, 0.14407513184206827, 0.140041553282312, 18.506297656467982, 54.0230187688555, 26.258614744458878, 48.184221676417756, 41.67604555402483, 29.239353724888392, 0.10117514883833272, 0.9453042639153344, 3.007579437323979, 13.234732389450073, 7.784609709467206, 6.453624512468066, 1.5135081857442856, 0.46231435239315033, 41.74360983712332, 65.29396615709577, 63.87330273219517, 59.21124907902309, 58.52197388240269, 56.821346691676546, 55.692090715680806, 56.86372028078352, 59.15294674464634, 54.59597417286464, 54.246827193668906, 52.15860864094326, 53.00431905473982, 56.093519415174214, 56.726806027548655, 55.83114153998238, 51.81261614390782, 47.07404892785208, 41.148076261792866, 44.09010335377285, 42.03617416109358, 43.02520506722586, 43.33907604217529, 43.984292711530415, 45.17034673690796, 45.95079272133963, 49.39471251623971, 51.52644068854195, 50.08498477935791, 46.84612022127424, 43.89280578068325, 40.72706406457083, 39.9244498525347, 41.3008463042123, 40.73873356410435, 48.4531968661717, 53.21033314296177, 54.20721203940255, 54.75154086521694, 54.81283092498779, 51.728313650403706, 50.10169867106846, 37.740842955453054, 52.72875002452305, 52.550191743033274, 54.34746490206037, 53.71321249008179, 53.58398641858782, 55.483985219682964, 52.923848492758616, 53.35176025118147, 53.247568539210725, 53.12119122913906, 51.281784193856375, 51.28654718399048, 55.08919204984392, 53.90098755700247, 55.10680225917271, 51.158825397491455, 52.88218709400722, 51.68159743717739, 51.91102000645229, 53.32097625732422, 49.3213985988072, 39.27836465835571, 41.50210435049874, 38.91161789212908, 39.51460688454764, 38.306985650743755, 39.20544678824288, 40.12942171096802, 37.92087425504412, 38.68892117909023, 37.903962339673726, 39.325615882873535, 38.78661979947771, 37.81550482341221, 36.92648976189749, 37.81483779634748, 38.7263684953962, 40.32406507219587, 39.17769915716988, 36.69422190529959, 37.40893793106079, 37.98723302568708, 38.25840732029506, 39.40174729483468, 40.20289543696812, 44.16672113963536, 48.32351221357073, 50.38074180058071, 51.230916431971956, 50.04490409578596, 50.275153500693186, 46.77745117459978, 49.94554138183594, 46.8668988091605, 48.48565884998867, 45.07281487328665, 42.20020375932966, 9.03949693271092, 0.5880745212946619, 1.6009668984583445, 9.03605670588357, 9.786615014076233, 12.663819755826678, 4.733796409198216, 0.3890181854367256, 0.18603402748703957, 21.98764739717756, 49.850705419267925, 29.38247271946498, 35.56901325498308, 51.819397585732595, 3.979611575603485, 0.45529015788010185, 0.2168875711836985, 0.20039633395416395, 0.13523025145488127, 0.13679844087788037, 0.1190569485936846, 0.19385242009801523, 0.2653856580810887, 0.17845342068799905, 0.1466831083276442, 0.14466895854898862, 0.16095853517098085, 0.20463617358888897, 0.11719707053686891, 0.15824465293969425, 0.10382234464798655, 0.10321679964129414, 0.14317924848624639, 0.09551248912300382, 0.1402195737298046], [0.023770058793681006, 0.042273603579295535, 0.03228574452389564, 0.049530108126678636, 0.04480895646182554, 0.10206158698669501, 0.037688277661800385, 0.03934851036007915, 0.025963189146880592, 0.02945192444271275, 0.028759411602680172, 0.07694410692368235, 0.022060666233301163, 0.016556678539408103, 0.02325695739792926, 0.034587287809699774, 0.018368338201461092, 0.04346008652022906, 0.013986738182471266, 0.060720646753907204, 0.046020375564694405, 0.07178774289786816, 0.03573779482394457, 0.03972206085122057, 0.05011040484532714, 0.06661530437746219, 0.141272008685129, 1.2428583715643202, 38.21921253204346, 29.1215591771262, 29.678146362304688, 36.58536100387573, 32.571772302900044, 5.530778672013964, 1.0499282841171538, 0.4039660947663443, 2.3573906804834093, 1.2882105665547507, 2.3424870116370062, 0.8564347954733031, 0.02125743853061327, 2.063681206532887, 53.45127929959978, 59.60608046395438, 56.953723771231516, 59.47708020891462, 54.00492218562535, 55.86828660964966, 55.00485828944615, 54.56613513401577, 53.87431342261178, 51.60578216825213, 51.312696729387554, 53.86217144557408, 52.659844739096506, 54.1881149155753, 50.79868636812483, 42.03102207183838, 42.095417976379395, 44.08159875869751, 40.52354090554373, 39.426726068769185, 38.31884969983782, 39.8254588672093, 40.041773659842356, 43.267224720546174, 43.36070925848824, 46.05066612788609, 49.67841093880789, 52.88071060180664, 50.52377046857561, 39.88953168051583, 36.43292447498867, 36.47063929694039, 36.11951208114624, 37.04566873822893, 42.492827142987935, 47.19299166543143, 50.190076283046174, 49.2778959274292, 50.18220397404262, 47.32546601976667, 48.59235886165074, 36.1962479863848, 37.975702490125386, 51.18409946986607, 49.25096123559134, 51.02881070545742, 49.5444461958749, 46.778799125126426, 45.51403590611049, 50.82620818274361, 50.298648834228516, 50.216771262032644, 48.48497097832816, 48.71950394766671, 54.206624916621614, 63.113433837890625, 48.63911328996931, 50.03786209651402, 49.528388908931184, 49.1055771282741, 50.05642768314907, 49.49544055121285, 41.612778731754844, 39.23603623253958, 36.05107579912458, 36.18589169638497, 35.3235125541687, 36.581178188323975, 35.94481004987444, 36.437819480895996, 35.81592444011143, 36.14610978535244, 35.414249079568044, 36.07485600880214, 35.41652461460659, 36.43682588849749, 35.61067465373448, 36.567389488220215, 35.117050307137625, 36.03667218344552, 34.29127080099923, 36.30158962522234, 34.26996415002005, 35.03406797136579, 33.90881763185774, 35.756423541477744, 35.2464987209865, 35.56911052976336, 40.343037128448486, 44.24494743347168, 47.016444887433735, 48.69700915472848, 48.671120166778564, 46.84363276617867, 46.91505677359444, 47.90947600773403, 49.85961995806013, 43.46283735547747, 13.685770358358111, 0.19843585629548344, 0.6896845432264465, 3.778632325785501, 1.8654946982860565, 5.068644429956164, 2.62063512631825, 0.2774951197206974, 0.049158623774669, 0.3391714559069702, 20.788999761853898, 40.37948390415737, 17.506997312818253, 33.96038368770054, 12.565624339239937, 0.10974345156656844, 0.023543148201757243, 0.044486577689115486, 0.06269310734101705, 0.027808225946500897, 0.015371542490486587, 0.04912433061482651, 0.09505435584911279, 0.016659688636926667, 0.10567063332668372, 0.026532692069719945, 0.05410058769796576, 0.04057704211611833, 0.029113542421587875, 0.012259121019659298, 0.044644693311836035, 0.06327102240175009, 0.04117511984493051, 0.04857942628275071, 0.04748471859576447, 0.012738335528410971, 0.01839290795448635, 0.012579479454351323, 0.009093154654172915, 0.040481205830084424, 0.02989311469718814, 0.050644293161375184, 0.02736618073790201, 0.04833245649933815, 0.02701251132280699, 0.05321934034249612, 0.014817562752536364, 0.05622318433597684, 0.017020559004907097, 0.0456324095970818, 0.03591691449816738, 0.020122468271957974, 0.030262556658791642, 0.046327276953629086, 0.04124844233904566, 0.018779847637883255, 0.027185797292206968, 0.09168205037713051, 0.042825775021421056, 0.06745189734335456, 0.1032493014686874, 0.07802618028862135, 0.08726286036627633, 2.1496217378548215, 48.32859134674072, 24.42563131877354, 35.838165623801096, 47.06061111177717, 34.11662782941546, 5.2970282435417175, 1.049432356442724, 0.5045066369431359, 2.388495377131871, 3.3864475531237463, 6.926093765667506, 4.373716005257197, 0.07465209705489022, 3.640372944729669, 58.27031012943813, 59.013232367379324, 59.989586285182405, 60.007165227617534, 55.59496184757778, 56.5762038230896, 55.31686019897461, 56.2177323613848, 54.30873564311436, 52.01546880177089, 52.21757452828543, 54.6888542175293, 54.814133712223594, 55.52752958025251, 52.930379799434114, 43.86500603812081, 44.38844163077218, 44.47547129222325, 42.45837797437395, 41.573326860155376, 39.75091859272548, 40.02197476795742, 41.83137253352574, 44.558967794690815, 45.95345040730068, 46.680683612823486, 49.89031362533569, 54.03674840927124, 51.48517881120954, 41.426956108638215, 39.574868610927034, 40.1569504737854, 38.99088988985334, 40.47689764840262, 44.467133453914094, 50.09919037137713, 51.20147344044277, 52.01947791235787, 52.53699016571045, 49.28426742553711, 49.50925357001168, 38.795318944113596, 41.57294123513358, 53.25964798246111, 50.25570549283709, 53.51552929197039, 51.85364873068673, 49.619021211351665, 46.92386014120919, 52.44742441177368, 51.18282447542463, 51.11309930256435, 50.512187821524485, 49.3658948625837, 52.79363577706473, 60.79896804264614, 50.36841222218105, 50.964862959725515, 50.84171308789934, 52.21046652112688, 49.86971916471209, 50.36963857923235, 43.44351788929531, 39.9056966645377, 38.355563981192454, 37.802928583962576, 36.58860581261771, 38.66103458404541, 38.200344698769705, 37.81692920412336, 37.146445410592214, 38.18029219763619, 36.27797964641026, 37.26029511860439, 38.17068978718349, 38.744482449122835, 37.748312268938335, 37.99227394376482, 37.75719901493618, 38.205618381500244, 37.71016318457467, 37.518643038613455, 36.286706583840505, 35.863811424800325, 36.19002587454659, 37.16937099184309, 37.25449684688023, 37.00439643859863, 42.807955741882324, 46.78741141727993, 48.83331544058663, 50.60869482585362, 49.24808815547398, 48.92547982079642, 46.4541688646589, 48.59666327067784, 49.15095581327166, 46.19428539276123, 15.605742624827794, 0.6137797619615282, 2.785775567804064, 4.641863925116403, 5.113052104200635, 6.382996073790959, 2.2364273199013303, 0.16197821045560495, 0.08051721126373325, 0.5427949566926275, 22.675776141030447, 49.973080566951204, 16.62044017655509, 36.71182516642979, 20.816203696387156, 0.2027210627815553, 0.01911222462409309, 0.06091252967183079, 0.019313220267317126, 0.051126480501677306, 0.06883358463112797, 0.058014934084245136, 0.10537099226244859, 0.03538175392895937, 0.05252231863726463, 0.03756574780813285, 0.05727049295923539, 0.012099343834311833, 0.03039098298177123, 0.07789643082235541, 0.02441018194492374, 0.03255868523514696, 0.027486381520118033, 0.04417376286749329, 0.019975589189146246, 0.03799629524084074, 0.10906298950846706, 0.06676086370966264, 0.13128026840942247, 0.11705231187599045, 0.12300033627876214, 0.16411119885742664, 0.1261953812624727, 0.15603056603244372, 0.10366550806377615, 0.14937601025615418, 0.07211134981896196, 0.3006779471678393, 0.08592795128268854, 0.07344343619687216, 0.08829860336014203, 0.12751532186354908, 0.15075202499117168, 0.11666645615228585, 0.16044368994023117, 0.15193711354264192, 0.08636327899460282, 0.19222206329660757, 0.14575715229979583, 0.16640525790197508, 0.1366886267704623, 0.1786534392407962, 0.1566824753369604, 2.9058293657643453, 54.731703758239746, 38.71517147336687, 39.99132626397269, 44.005026136125835, 43.66890355518886, 7.4634005682809015, 1.4561249677624022, 3.199122382061822, 6.003586649894714, 9.197895015989031, 8.476221237863813, 3.4566382552896227, 0.15751701912709645, 3.004085144826344, 58.67217309134347, 61.13881138392857, 62.90695422036307, 63.77404771532331, 58.83709553309849, 58.23593044281006, 58.47311414991106, 57.18547051293509, 56.558604036058696, 53.68990823200771, 55.07229750497, 57.51207058770316, 57.744140420641216, 58.141900471278596, 55.37068094526018, 44.75680037907192, 46.81580523082188, 47.73481566565377, 46.568904467991416, 43.50301878792899, 41.668795108795166, 43.52206380026681, 44.119813850947786, 47.039485113961355, 48.512711661202566, 50.82018756866455, 54.087782927921836, 58.41953659057617, 55.2213259424482, 44.21488952636719, 41.315368039267405, 41.6331855910165, 41.18102461951119, 41.82693610872541, 46.771861348833355, 53.112561566489084, 53.53353207451956, 55.434138842991416, 54.06176539829799, 49.528913497924805, 50.34316941670009, 36.89583083561489, 43.68860169819423, 57.151841231754844, 51.14842741830008, 56.173955236162456, 52.66416651862008, 50.27510486330305, 47.46401309967041, 55.074270793369834, 53.7121250970023, 53.711555344717844, 52.19579539980207, 51.627356324877056, 52.733297620500835, 61.86767046792166, 52.3518762588501, 53.16708060673305, 52.50218663896833, 53.17846870422363, 53.418789522988455, 52.85152121952602, 45.13047102519444, 42.406936986105784, 41.247699533190044, 40.22853776386806, 38.56849847521101, 40.293041365487234, 39.88576923097883, 40.45155756814139, 38.900115149361746, 39.72552292687552, 38.787703718457905, 39.81844466073172, 39.253583908081055, 40.486239501408164, 39.06917176927839, 40.942347049713135, 39.94265413284302, 40.140274797167095, 38.89877414703369, 39.37580272129604, 38.23742028645107, 37.995758465358186, 38.603764057159424, 39.35106366021292, 38.10502931049892, 38.66178151539394, 45.07113340922764, 47.73931809834072, 51.01961129052298, 53.37798275266375, 52.30271775381905, 49.90826082229614, 48.30718394688198, 48.60444177900042, 50.79642472948347, 45.650116375514436, 16.766381876809255, 0.467550417142255, 2.5084938066346303, 9.149604167257037, 8.34902925150735, 13.884840590613228, 7.145484004701887, 1.7718277701309748, 0.15764087890940054, 1.2036533781460352, 31.87390218462263, 51.29338421140398, 24.948446784700664, 46.09542294910976, 23.67952333177839, 0.2601328199463231, 0.11815980316272803, 0.17068590463272162, 0.1821299134088414, 0.2127399987408093, 0.1833297804530178, 0.16921770413007053, 0.20677203897918972, 0.13005897322935717, 0.128274032580001, 0.19111906391169342, 0.11997483005481106, 0.16097815840372018, 0.10942060460469552, 0.11320695893040725, 0.159686024167708, 0.13097719395799295, 0.1293112819216081, 0.12257793465895311, 0.1962109806814364, 0.09971719421446323], [0.02773911545851401, 0.04403933150959866, 0.006232691471398408, 0.011046021694450505, 0.013828783711817647, 0.03582719859800168, 0.027183941498930966, 0.012408135791442223, 0.056170387526175806, 0.015801582718268037, 0.0519495638353484, 0.04593753322426762, 0.026952349015378525, 0.03660007034029279, 0.04745819805456059, 0.06278572737106256, 0.02464082108677498, 0.02217837848833629, 0.030236931783812385, 0.0741642846592835, 0.031630032030599456, 0.014735275114487325, 0.046932292703006945, 0.04100561501192195, 0.03973724307226283, 0.012586023924606187, 0.0463768710781421, 0.053905678513858996, 8.048524005072457, 36.2959337915693, 21.776654924665177, 35.36155046735491, 30.071949413844518, 9.952478068215505, 0.0687093109424625, 0.8172765395471028, 1.2638282520430428, 2.2685686009270802, 4.040617627756936, 4.877119507108416, 0.1732235306075641, 0.10344749476228442, 6.33565582547869, 62.97265638623919, 55.696607044764924, 57.60524940490723, 56.79445021493094, 55.150214603969026, 53.50968585695539, 53.84412349973406, 48.51894766943795, 52.75357941218785, 53.77693789345877, 54.00545719691685, 53.60583850315639, 48.951563358306885, 45.14696952274868, 46.51878016335623, 46.71643556867327, 45.33964306967599, 44.12038360323225, 39.79521335874285, 38.85420492717198, 37.90184661320278, 40.02541760035923, 42.97184985024588, 45.390066146850586, 50.938991342272075, 51.77979632786342, 54.260435240609304, 52.5892892565046, 45.67048849378313, 37.02070038659232, 37.93920012882778, 37.974816594805034, 38.39085040773664, 38.71297236851284, 46.40176902498518, 50.91400562013899, 49.573590414864675, 51.69885328837803, 49.80441304615566, 52.36811419895717, 43.24058880124773, 37.48167167391096, 47.45190586362566, 44.08558007649013, 50.129512310028076, 46.98174210957119, 48.164249079568044, 46.27309880937849, 49.972139086042134, 50.88514627729143, 48.94379527228219, 52.91624368940081, 51.36624302182879, 58.89830221448626, 53.562339305877686, 48.51325709479195, 51.62059225354876, 50.32488523210798, 50.45166206359863, 49.581205640520366, 46.70636762891497, 43.488149642944336, 37.6136040687561, 34.409570830208914, 34.59910379137312, 34.46086243220738, 36.10411834716797, 37.05303035463606, 35.45517744336809, 36.99678121294294, 36.531279700142996, 34.13010733468192, 34.08318267549787, 36.69454847063337, 39.58322034563337, 39.011453083583284, 37.48362064361572, 36.33247089385986, 38.54434653690883, 36.7323431968689, 38.21389716012137, 37.07632419041225, 38.836608614240376, 37.34765134538923, 38.42963525227138, 35.951570647103445, 34.582379477364675, 32.824165616716655, 35.89639152799334, 39.419746603284565, 45.88221747534615, 44.642419133867534, 45.8891726221357, 47.221871852874756, 47.73359625680106, 46.75673164640154, 26.92749524116516, 0.5971071251801082, 0.33558716252446175, 2.0450268132346014, 1.4082091046231133, 3.5780245874609267, 2.768654989344733, 1.7708076877253396, 0.14021124131977558, 0.040604824732456885, 3.36252338545663, 34.901280948093955, 32.595517771584646, 26.12054361615862, 33.93881300517491, 1.8901710084506442, 0.1482932854975973, 0.0644005321498428, 0.11317343930048601, 0.025907573024077073, 0.10705976414361171, 0.06539338494517974, 0.03943283190684659, 0.012308542965911329, 0.038219350057521036, 0.04289746903149145, 0.030709969079388038, 0.07664538866707257, 0.007281781673165304, 0.06355193589947053, 0.03974011666806681, 0.014557069766202142, 0.008844987256452441, 0.04760787270164915, 0.045486310829541514, 0.021777584816196134, 0.058336722531488965, 0.00920002137510372, 0.04479163007012435, 0.02840943172174905, 0.032389109155961444, 0.036781785410961935, 0.01170726424814867, 0.07459043857774564, 0.05573349579104355, 0.017537260028932775, 0.029414506629109383, 0.042133815187428675, 0.0487639776297978, 0.03030715337289231, 0.02783932999175574, 0.031209241931459734, 0.04483830988673227, 0.03896380814590624, 0.024952638461919766, 0.03149141071896468, 0.024287733515458446, 0.04193826818040439, 0.005071656986339284, 0.016899820483688797, 0.045817880359079154, 0.08775239624083042, 0.055123319782848866, 0.04520626585664494, 0.07796993652092558, 18.429304667881556, 40.1093761580331, 20.724141802106583, 39.71238388334002, 33.973908356257844, 13.558868459292821, 0.04252994393131562, 0.20174874924123287, 0.9852894097566605, 1.646867349743843, 4.681618043354579, 5.315791853836604, 1.51528833593641, 0.332278842904738, 9.590281503541128, 67.40355042048863, 54.08268642425537, 60.48677853175572, 57.650113923209055, 56.71297911235264, 54.20012140274048, 54.401393345424104, 50.03131341934204, 54.669899531773154, 54.47363029207502, 56.74871717180525, 53.17230912617275, 52.49956716809954, 46.721313204084126, 48.09615673337664, 47.258075441632954, 47.44851861681257, 45.12654529299055, 41.376060553959434, 40.31542498724801, 40.28264338629586, 41.79701369149344, 44.25128419058663, 47.68175227301461, 51.364655358450754, 53.36145646231515, 54.71603209631783, 54.11038194383894, 46.354465688977925, 39.44405140195574, 38.02620547158377, 39.826834610530305, 39.433163574763704, 41.32627671105521, 46.763089248112266, 52.259923798697336, 51.58187689099993, 51.71201317650931, 51.09158420562744, 51.541236877441406, 48.02622658865792, 41.91439308438982, 49.30883625575474, 48.20349945340838, 51.09488112585885, 49.621637208121165, 48.26428576878139, 47.29317774091448, 51.83249841417585, 52.837235723223, 50.90005363736834, 52.27861792700631, 52.79775258472988, 57.82966232299805, 58.65681062425886, 49.62274891989571, 52.599680287497385, 52.14577531814575, 53.90090765271868, 50.77600744792393, 49.07670736312866, 44.83200420652117, 39.686939580099924, 36.63990783691406, 36.84674181256975, 35.782673835754395, 37.19482224328177, 36.81205293110439, 36.438128675733296, 38.88663216999599, 37.89478376933506, 36.209675380161826, 37.21837316240583, 38.08930901118687, 41.98011956896101, 40.69102723257882, 39.79780503681728, 38.988020283835276, 39.93342692511422, 40.35961205618722, 39.72763517924717, 37.96865006855556, 40.42910099029541, 37.79593869618007, 40.87300750187465, 37.44879279817854, 36.4863908631461, 34.87392589024135, 37.71863651275635, 42.42704159872872, 47.30124112537929, 47.36037376948765, 48.22257225854056, 48.96095732280186, 47.69999476841518, 49.394094126565115, 29.118045125688823, 1.5068873124463218, 1.291902557015419, 3.3584480498518263, 5.32951454605375, 9.163413711956569, 4.351076168673379, 1.5477014652320316, 0.07094658339130026, 0.040038007111953836, 4.061498267310006, 41.49943276814052, 39.805955273764475, 22.20190726007734, 41.83971732003348, 4.017052377973284, 0.3535883165895939, 0.03717369705970798, 0.05276099333007421, 0.03772766661963292, 0.010079052465568696, 0.03196451586804219, 0.04297019780746528, 0.05334908302341189, 0.009436713897490075, 0.030564759192722182, 0.08552771061658859, 0.05162187213344233, 0.03853171704603093, 0.03122647332825831, 0.03446220666436212, 0.04791157140529581, 0.01976449185583208, 0.03905270641137447, 0.06537338851818017, 0.03694000281393528, 0.0398829991796187, 0.07958587445318699, 0.12130004965833255, 0.07583537391786065, 0.1270536602075611, 0.07570677796112639, 0.08918880059250764, 0.11844761057623795, 0.07742260303348303, 0.11284242956233875, 0.08093881899757044, 0.15997261021818432, 0.1111090440036995, 0.11961598002484866, 0.1969925444573164, 0.12426230284784522, 0.11949878345642771, 0.06476900380636964, 0.1307904746915613, 0.12561555951833725, 0.15422483507011617, 0.07269362785986491, 0.10322071478835174, 0.10932310590786593, 0.12996034137904644, 0.1888709824000086, 0.15405858041984694, 0.15188185365072318, 0.1531902320150818, 21.536302839006694, 50.73730598177229, 30.36182131086077, 43.97050748552595, 42.249101706913535, 16.318619115012034, 0.19759595207870007, 2.835052626473563, 3.9869354111807684, 6.589667635304587, 11.330318876675197, 10.444036194256373, 1.183126988155501, 0.23533798328467778, 8.890820247786385, 64.00868838174003, 55.50374589647566, 62.09876755305699, 58.64216382162911, 55.621823583330425, 55.39551033292498, 55.82193865094866, 52.78011458260672, 57.187343052455354, 57.68831511906215, 57.99852786745344, 56.907348019736155, 53.414109911237446, 50.0685453414917, 51.12105846405029, 52.177070004599436, 51.64949328558785, 47.701342718941824, 43.24043594087873, 41.83360290527344, 42.46367597579956, 43.09646231787545, 46.38232101712908, 49.75852019446236, 54.10020283290318, 56.26572009495327, 58.23018428257534, 55.69116660526821, 51.22117158344814, 41.497369153159006, 40.19917467662266, 42.14050136293684, 40.472006116594585, 43.032146317618235, 48.762249265398296, 55.25509071350098, 53.33710650035313, 53.278182302202495, 54.37631382261004, 53.97271728515625, 45.352438177381245, 40.14743144171578, 52.7764424596514, 49.43274000712803, 52.58652039936611, 51.01808616093227, 49.54234783990042, 46.61228207179478, 53.086603096553254, 54.61937917981829, 52.70179796218872, 53.889901706150596, 55.52507339205061, 56.77392871039254, 58.58979524884905, 52.36514384405953, 54.45639875956944, 54.142142159598215, 55.98491907119751, 52.13996662412371, 51.41509233202253, 47.31057950428554, 41.28792265483311, 36.953212533678325, 38.777712208884104, 36.89063358306885, 39.65251473018101, 39.12832873208182, 38.49753304890224, 41.31684453146798, 39.57634857722691, 36.995238712855745, 37.72477872031075, 39.54712792805263, 43.08283690043858, 42.67524514879499, 42.71392577035086, 41.24169281550816, 42.813083512442454, 41.076909337724956, 41.89748464311872, 40.274889196668354, 43.06166573933193, 39.75684888022286, 43.98733254841396, 39.20861169270107, 38.43189341681344, 36.66769020898001, 39.45332029887608, 42.571150711604524, 48.7395738192967, 48.426828452519004, 50.3729042325701, 50.52189098085676, 49.084075927734375, 48.369050707135884, 30.265950066702707, 1.404603749513626, 1.253619936960084, 5.216738334723881, 5.711182568754468, 8.84277171748025, 10.774673172405787, 7.437558480671473, 0.8471820205450058, 0.21885321927922113, 6.861881119864328, 46.244788374219624, 42.654258114951, 35.190121037619456, 49.514746120997835, 6.538618351731982, 0.7527981251478195, 0.17959744430014066, 0.2929181664117745, 0.15421202432896408, 0.23653888170208248, 0.12095496031854834, 0.2352282234600612, 0.21215043323380606, 0.07429354558033602, 0.16187248112899916, 0.16880533125783714, 0.09466288864080395, 0.13123344949313573, 0.20097964336829527, 0.2271221862839801, 0.09614131466618606, 0.12484372593462467, 0.09863351272153002, 0.24103333481720515, 0.11959757815514292, 0.13518234688256467], [0.04514881090394088, 0.029943288969142095, 0.03367029183677264, 0.04571058700925537, 0.06923671585640737, 0.02297120085651321, 0.03143493964203766, 0.0906997759427343, 0.08049287221261434, 0.030507185496389866, 0.06743141915649176, 0.05112183253679957, 0.030221719028694288, 0.08970944051231657, 0.04539285280874797, 0.09469073571796928, 0.027274602259110128, 0.08078650824193444, 0.05616414161132915, 0.041833149535315375, 0.023945812934211323, 0.0235368955015604, 0.08539969819997038, 0.03834812582603522, 0.08147848503930227, 0.01691921640719686, 0.04088301730475255, 0.0834722855527486, 1.0256410730736596, 27.185898746762955, 34.41454921449934, 58.1046998160226, 49.54760067803519, 18.028699329921178, 0.8958409066711153, 0.06468923522957734, 0.25315411442092484, 1.171992717044694, 6.381611210959298, 7.3640022448131015, 1.725102003131594, 0.30771196686795776, 0.049904354116214175, 11.678011076790945, 63.63875239236014, 53.77980055127825, 55.83324684415545, 55.343826157706125, 54.3013288634164, 50.9494240624564, 52.99608196531023, 53.33089133671352, 54.58020176206316, 53.34228638240269, 50.6645861353193, 48.85012313297817, 50.288837977818076, 47.27352128710066, 48.896554470062256, 49.49549961090088, 46.15929773875645, 40.47213813236782, 38.998789991651265, 39.16748530524117, 41.04396792820522, 41.15482643672398, 49.96729966572353, 52.179769379752024, 52.58097573689052, 54.87464557375227, 51.1894530568804, 46.956005981990266, 38.867733069828574, 38.459665366581504, 38.712986264910015, 38.18123367854527, 39.20454004832676, 39.56332417896816, 50.55126101630074, 51.03011349269322, 52.079868180411204, 51.40938786097935, 53.463723523276194, 46.99394314629691, 41.60502801622663, 53.49903426851545, 46.78079325812203, 47.77835307802473, 44.054608481270925, 45.374047074999126, 44.35383265359061, 49.40470402581351, 50.868512289864675, 55.48498228618077, 50.425099100385395, 53.96689816883632, 56.97416884558541, 40.124203613826204, 50.97803674425398, 48.1585168157305, 50.71806294577462, 49.448564529418945, 48.87087740216936, 46.13164043426514, 41.018777234213694, 33.9883918762207, 35.56813778196062, 34.42990125928606, 35.02321488516671, 36.44299936294556, 36.37372929709298, 35.87152392523629, 37.47400433676583, 37.77436453955514, 35.704923493521555, 37.425398213522776, 40.596990312848774, 42.14377049037388, 39.81095450265067, 40.267444201878135, 38.40446192877633, 37.91157756532942, 38.71725593294416, 39.982404776981895, 40.61033085414341, 40.663019044058665, 43.62302112579346, 45.419109616960796, 45.13537645339966, 41.5348025730678, 38.20822395597185, 38.19279200690133, 37.37276560919625, 39.54495661599295, 45.22831903185163, 45.24141638619559, 47.6648507799421, 48.4467385155814, 42.06907388142177, 10.018710034234182, 0.3609814170215811, 1.9819241421563285, 3.748303438935961, 6.730782074587686, 7.049164601734706, 4.298620309148516, 0.6122822623167719, 0.10064122998820883, 0.1360305156558752, 13.97203700883048, 43.13428136280605, 17.317700590406144, 31.633345127105713, 24.612034116472515, 0.01162773824762553, 0.019378139105226313, 0.12964942306280136, 0.022374263066532354, 0.006347994078948561, 0.025002515874803066, 0.04174598153414471, 0.014671099272423556, 0.00515421391797385, 0.06699133491409676, 0.06691624144358294, 0.037763472912567, 0.0178524480267827, 0.016049460042268038, 0.021885957036699568, 0.06299044817153897, 0.01901482092216611, 0.011757966081079627, 0.10133282002061605, 0.027999374350266795, 0.031118257170809165, 0.03307749989575573, 0.015358758890735251, 0.03414449281990528, 0.014058994528438364, 0.038069726300558875, 0.048437062850488086, 0.03617723785074694, 0.02858700603246689, 0.013855915782707078, 0.05680076012920056, 0.055513877754232714, 0.05737579480877944, 0.04748366008113537, 0.059870069181280475, 0.06004720074789865, 0.06381477322429419, 0.03391601650842598, 0.01117628684733063, 0.05200038271557007, 0.03824128709467394, 0.022530853681798493, 0.0533356717787683, 0.01616107057114797, 0.0570251007697412, 0.004130669287405908, 0.05338194447436503, 0.03578492247366479, 0.052578806677567105, 0.04753664009539144, 1.8096370441573006, 40.51150662558419, 28.438210793903895, 51.48023516791207, 48.10470649174282, 19.022698198046, 1.04680734872818, 0.08991177286952734, 0.44169456884264946, 1.7645553946495056, 2.4743714204856326, 5.339743162904467, 3.9341043489319936, 1.4094206967524119, 0.08970103346343551, 15.447486979620797, 66.9601719720023, 52.40709011895316, 57.19793210710798, 54.7113698550633, 54.04781688962664, 51.847833088466096, 55.32107775551932, 55.459134987422395, 58.08998353140694, 53.25028875895909, 52.86874580383301, 48.558535030909944, 50.57617725644793, 49.24841819490705, 50.460590498788015, 50.52235651016235, 49.331390108381, 42.20719017301287, 41.4521815436227, 42.01044845581055, 43.45242200578962, 42.72316687447684, 50.60101011821202, 55.381016390664236, 54.15526730673653, 56.15222821916853, 53.326048442295615, 48.541411195482524, 40.961958340236116, 40.175682817186626, 40.25846018110003, 41.16886874607631, 40.774753025599885, 43.47309289659773, 51.543609687260215, 53.83810288565499, 55.021881375994, 51.859572069985525, 53.32816416876656, 50.401308468409944, 46.839599336896626, 50.47171803883144, 48.272536754608154, 48.020820890154155, 45.04461560930525, 45.61214099611555, 47.386266231536865, 49.60499974659511, 53.62782607759748, 54.56270967211042, 53.94134964261736, 49.73941959653582, 59.84452179500035, 46.89126961571829, 50.41600390842983, 50.47355931145804, 51.54010432107108, 50.7582756451198, 49.35781063352312, 47.49772923333304, 42.73084115982056, 37.34456981931414, 36.88704831259591, 37.04927485329764, 37.31686387743269, 38.286842823028564, 37.9082042149135, 38.01900366374424, 39.029591356004985, 38.137446131025044, 37.521234716687886, 39.65204572677612, 41.643618311200825, 42.666149956839426, 41.39321913037981, 41.900322982243125, 38.92750147410801, 41.35201631273542, 40.67154795782906, 41.92350217274257, 41.40108101708548, 42.06684003557478, 43.557075772966655, 45.209683963230674, 45.711257049015586, 42.722694396972656, 39.97229514803205, 39.008263860430034, 38.65196371078491, 42.318114689418245, 46.81849765777588, 46.800168309892925, 49.35109519958496, 49.93399000167847, 42.42415462221418, 10.758809566497803, 1.1308894540582384, 3.641780172075544, 4.138903370925358, 3.3603709638118744, 14.963742971420288, 1.7958554008177348, 0.24401470912354334, 0.08196280976491314, 0.15398772779319966, 14.871076583862305, 51.02145603724888, 21.702964067459106, 31.65869562966483, 33.41960539136614, 0.12407080669488225, 0.045626692939549685, 0.09890776300536734, 0.04907323353524719, 0.0198983990454248, 0.02678619953803718, 0.07490571308881044, 0.06353840591119868, 0.02302715115781341, 0.0352991558611393, 0.03747483429365924, 0.008731937385164201, 0.0530459000063794, 0.028588291856327226, 0.029692916332611015, 0.031050926140908684, 0.025763945820342218, 0.04573750449344516, 0.0552993656934372, 0.01596867196661021, 0.029379121027886868, 0.043014533285583766, 0.1313964743167162, 0.12138379445033413, 0.2086174642401082, 0.11283139658293553, 0.15725275687873363, 0.09022554781820093, 0.07047889634434666, 0.15314709075859614, 0.16929953545331955, 0.14067067738090241, 0.15965445871864045, 0.1042285089247993, 0.13586553665144102, 0.1592364540057523, 0.10553603912038462, 0.13043480020548615, 0.1094095716252923, 0.18635938502848148, 0.07769652083516121, 0.10908827850861208, 0.16079162912709372, 0.07308107814086334, 0.28592944570950096, 0.09738859773746558, 0.21061459636049612, 0.1426630461854594, 0.12508542010826723, 0.16128230494047913, 2.8066490420273373, 51.55856221062796, 43.1589162009103, 67.79963942936489, 59.95173249925886, 29.799527917589458, 1.7731185065848487, 0.23593726541314805, 1.9359546431473322, 4.669014879635402, 13.624192816870552, 14.71622555596488, 5.300975688866206, 0.7471801808902195, 0.18834534846246243, 15.735623564038958, 64.44813414982387, 53.812467506953645, 55.2871983391898, 57.27842698778425, 54.47717734745571, 54.08076524734497, 60.11188152858189, 58.61776869637625, 59.0529135295323, 57.918043409075054, 53.836212975638254, 51.52356760842459, 54.53980493545532, 51.10735314232962, 53.06699528012957, 54.17561163221087, 51.103962421417236, 45.83044644764492, 43.896404947553364, 44.57836716515677, 44.93018225261143, 45.98749658039638, 54.34122889382498, 57.246770995003835, 55.16162354605538, 57.66459744317191, 55.59665025983538, 51.52392891475132, 42.93930101394653, 44.04960925238473, 42.38005093165806, 41.842750208718435, 42.87137542452131, 45.19980015073504, 53.27114030293056, 55.284922804151265, 55.40752029418945, 54.085681097848074, 55.02740171977452, 50.10641997201102, 45.34008775438581, 55.14641046524048, 50.42176396506173, 50.44759736742292, 46.11639608655657, 45.21691356386457, 45.29307276862008, 49.63181284495762, 53.45691428865705, 55.84677498681204, 56.235773359026226, 50.34611892700195, 56.59638486589704, 48.71567896434239, 52.381336620875764, 52.19550357546125, 51.535320486341206, 51.21333401543753, 51.00682660511562, 49.82301337378365, 43.42838818686349, 39.620490482875276, 38.34994636263166, 38.590447834559846, 38.44398675646101, 40.034130641392295, 40.492364338466096, 40.735940388270784, 39.65596103668213, 40.04559516906738, 39.75240550722395, 42.63091911588396, 42.86110251290457, 45.285850116184776, 42.000644547598704, 43.671880858285085, 41.54869549615042, 43.50970990317208, 43.94516740526472, 43.811220032828196, 44.16235072272164, 44.304670674460276, 45.87339326313564, 48.65506287983486, 49.38924775804792, 45.10043396268572, 42.99077674320766, 42.48082412992205, 40.01743759427752, 43.2875725201198, 48.65749127524239, 48.60909707205636, 51.26611948013306, 50.725195271628245, 43.67712674822126, 11.968831402914864, 1.1607353325401033, 5.920428437846048, 8.21647846698761, 15.069689103535243, 16.32893545286996, 7.148883845124926, 2.908531129360199, 0.26375820540956085, 0.2610504435641425, 22.560625382832118, 53.851752621786936, 26.703464473996842, 42.65683937072754, 37.797877243586946, 0.40894276914852007, 0.16969873117549078, 0.26033741182514597, 0.14374494313129357, 0.12443135306239128, 0.11681143194437027, 0.15642455060567173, 0.14119331219366618, 0.09607239586434194, 0.09383568659956966, 0.14814626052975655, 0.10135348819728408, 0.14967485064906733, 0.17696992600602762, 0.22042546634163174, 0.14673293993941375, 0.08075809798070363, 0.14835838414728642, 0.17025127581187657, 0.16584431300205843, 0.13074920619172709, 0.12623541482857295], [0.00988987775053829, 0.08033026808074542, 0.051849714014679193, 0.030911439697125127, 0.05613073733236108, 0.025910660358411924, 0.00895042990201286, 0.04174469571028437, 0.070741686171719, 0.055753410793840885, 0.07334209020648684, 0.07235571063522782, 0.030123738572001457, 0.02625213989189693, 0.024380489252507687, 0.03893335210159421, 0.05920218037707465, 0.04387452892426934, 0.058873070536979606, 0.02890242982123579, 0.006359826033336243, 0.003143087012826332, 0.01906081541840519, 0.02705042955598661, 0.027008765809504048, 0.0959604104448642, 0.04357474197500518, 0.10963464847632817, 0.04993805695059044, 12.006370782852173, 37.7483365876334, 26.896323885236466, 37.41956172670637, 41.23100301197597, 5.075296027319772, 0.05237149726599455, 0.23253921632255825, 0.6795091778039932, 0.9649842764650072, 3.131518146821431, 4.2467824050358365, 3.9482148374829973, 0.2255725615790912, 0.08269891847989388, 20.143861259732926, 59.34006173270089, 57.3434864452907, 57.36412954330444, 54.06868927819388, 51.901539189474924, 51.406313283102854, 56.597909995487754, 55.85143722806658, 52.79685626711164, 52.37789726257324, 49.99205609730312, 53.58640786579677, 52.540776933942524, 51.88140330995832, 49.758058139256065, 47.40932035446167, 41.563182490212576, 36.366826261792866, 38.458039488111226, 38.88880695615496, 45.02232231412615, 53.41982133047921, 52.56799302782331, 56.298578126089915, 53.33474063873291, 52.13062824521746, 49.60326617104666, 42.03716427939278, 39.06466933659145, 39.27494267054966, 37.40919501440865, 40.37139620099749, 39.32207924979073, 47.44956432070051, 51.70742736543928, 52.48216540472848, 51.063082695007324, 53.289518288203645, 50.29190213339669, 43.93744795663016, 52.80600357055664, 49.358376911708284, 52.722948278699604, 50.736951623644146, 48.47052567345755, 43.83056729180472, 48.42898934228079, 45.64833068847656, 49.27103458132063, 50.7127024105617, 66.10468891688755, 41.6810691016061, 41.29454428809029, 51.143330914633616, 47.15252535683768, 52.79041876111712, 50.9802497455052, 48.48064572470528, 43.04582037244524, 36.34268821988787, 33.4098744392395, 34.84385756083897, 35.50570126942226, 35.43844270706177, 34.38120133536202, 37.25259304046631, 34.67480788912092, 37.73011841092791, 37.31873294285366, 35.230893066951204, 40.326545579092844, 45.41160556248256, 43.56535802568708, 43.17045368467058, 42.18253449031285, 40.42384467806135, 39.34742627825056, 40.59960630961827, 40.85741227013724, 41.87281158992222, 43.930096762520925, 48.6520299911499, 46.825532708849224, 49.16003710883004, 48.68734073638916, 46.328799043382915, 42.10346051624843, 41.531488282339915, 39.528221879686626, 42.80494369779314, 45.973287514277864, 47.106990337371826, 50.972519874572754, 30.539792469569615, 1.1085204886538642, 0.8692954225199563, 3.346992858818599, 1.7560421143259322, 3.4614364206790924, 18.52984162739345, 1.8784016285623824, 0.36412365841014044, 0.07802433467337064, 0.5139593897121293, 29.846584592546733, 34.79231234959194, 19.23059003693717, 42.55379411152431, 7.657050337110247, 0.4197401340518679, 0.004629505756643734, 0.03627337269218905, 0.0460007455466049, 0.014414977747946978, 0.023488912897716676, 0.05248828671340432, 0.0754788580483624, 0.055188700024570735, 0.04382435804499047, 0.04788303222241146, 0.06718463597020932, 0.016314634920230935, 0.05002734876636948, 0.036436407693794796, 0.03946312849542924, 0.0332918321447713, 0.028121839743107557, 0.09049685326005731, 0.05943687206932476, 0.044766310535903485, 0.08063465889011111, 0.08070616969572646, 0.023796516570395658, 0.03689161648175546, 0.017849057048027004, 0.03945579013920256, 0.024566872644105127, 0.03935473931155034, 0.027589266088658145, 0.021191001470599855, 0.029075463036341325, 0.012628770782612264, 0.014277431914316756, 0.021600176746557866, 0.02172764633516116, 0.02569153086681451, 0.03164971633149045, 0.0774130764018212, 0.03256756386586598, 0.017232326391552175, 0.01496562927163073, 0.0836398226342031, 0.0749762196625982, 0.04608307220041752, 0.04229686036705971, 0.053278301642941575, 0.052828724695635695, 0.056169708991157155, 0.03613305165033255, 0.03853871952742338, 20.25064638682774, 43.9221237046378, 35.505756855010986, 57.06130273001534, 43.46953541891915, 6.148150435515812, 0.025550358263509612, 0.07388765950288091, 1.301114239862987, 1.1962023036820548, 5.237363193716321, 5.331096998282841, 5.380569040775299, 1.6814840350832259, 0.6352945874844278, 24.723389421190532, 60.61936405726841, 54.751064913613455, 57.022889614105225, 56.54447487422398, 53.56837034225464, 54.82090473175049, 56.807446820395334, 57.312577383858816, 55.395635400499614, 54.83663892745972, 51.55618592670986, 53.676480838230674, 55.12792130878994, 53.69755819865635, 52.033117226191926, 49.18300437927246, 43.5693358693804, 39.814762115478516, 41.51463542665754, 41.163800035204204, 47.73583705084664, 54.47502340589251, 55.97649785450527, 56.49300956726074, 55.239474637167795, 54.84803744724819, 52.082577977861675, 43.87924289703369, 41.33231816973005, 41.27260882513863, 38.06170381818499, 40.55910178593227, 40.768906116485596, 47.70698465619768, 53.85463612420218, 52.39690753391811, 55.26885509490967, 52.03999941689627, 53.82900421960013, 50.78521728515625, 54.19507701056344, 51.81867497307913, 53.56994410923549, 50.82984209060669, 48.59363038199288, 44.74947350365775, 50.00793273108346, 47.90717962809971, 52.57418734686715, 46.19091551644461, 63.621548652648926, 51.580011299678254, 41.052812985011506, 53.47761297225952, 48.851644788469585, 54.34807634353638, 51.06845017841884, 49.96641377040318, 44.73211342947823, 39.91650806154524, 35.79819958550589, 37.30577802658081, 36.04104607445853, 38.03846556799752, 36.2937068939209, 38.37596041815621, 37.210775307246614, 40.09416307721819, 38.633151463099885, 37.831843512398855, 41.90474203654698, 46.72539527075631, 45.180505003247944, 46.73719678606306, 43.11863054547991, 41.73411512374878, 41.684960092817036, 42.03918273108346, 42.333095005580354, 43.99090392248971, 45.1706976209368, 49.67298786980765, 48.53446994509016, 50.02906915119716, 49.28930139541626, 47.89305394036429, 44.1798323903765, 42.802810600825715, 41.529181480407715, 46.55352463041033, 47.41708844048636, 48.66226121357509, 51.3348719051906, 33.858728068215505, 1.9478336742946079, 2.692724423749106, 3.2880931964942386, 5.769099712371826, 10.76284212725503, 4.845189929008484, 2.2791357253279005, 0.3508464922862393, 0.03069175380681242, 1.1211827120610645, 34.24611793245588, 45.46526650020054, 17.5376683984484, 46.47153588703701, 11.138031823294503, 0.4503175818494388, 0.028209569232006158, 0.038218111731112, 0.041158064867236784, 0.029862774003829275, 0.027969098117734705, 0.0704174278570073, 0.04929561660225902, 0.05936065901603017, 0.04387102089822292, 0.025093171545969586, 0.04669855095978294, 0.047535856387444904, 0.010815907569069947, 0.040585276138569625, 0.03503914802734341, 0.018310016420270716, 0.03117655689961144, 0.034130935690232685, 0.11062401360166924, 0.02869320354823555, 0.07365613656916789, 0.19254523595528944, 0.09315033908933401, 0.13641496002674103, 0.1198599540761539, 0.10713072533586196, 0.14123629060174736, 0.07286746174629245, 0.15352200849780015, 0.17073121720126697, 0.20161496927695616, 0.19862547969179495, 0.1367858201265335, 0.10156351514160633, 0.19395596454186098, 0.08076112424688679, 0.08166987262666225, 0.15149257811052458, 0.12241368847233908, 0.1343967526086739, 0.10883380073521819, 0.1601019525634391, 0.14947118157786982, 0.11652576870151929, 0.10227550193667412, 0.13381945501480783, 0.1830829158425331, 0.16839221199708326, 0.2564168636287962, 0.22482571165476525, 26.533303090504237, 54.45040593828474, 35.42267377035958, 45.058119433266775, 56.008626324789866, 9.690241762569972, 0.12551121440316948, 1.652491916503225, 3.3130639365741184, 4.861900780882154, 11.781983920506068, 11.664275356701442, 7.620327370507376, 1.0343520513602664, 0.35498029046824997, 24.4577146257673, 61.521448680332725, 58.40190206255232, 58.12699311120169, 57.59202003479004, 57.17044503348214, 56.22514608928135, 59.833071163722444, 60.80583981105259, 56.18555177961077, 58.536933353969026, 52.13268838609968, 58.64567266191755, 57.435254778180806, 56.68132659367153, 54.030970982142854, 52.01644502367292, 45.79047346115112, 41.985639912741526, 42.002899238041465, 42.24953249522618, 49.87230042048863, 57.32576853888375, 58.37378965105329, 61.295382090977256, 55.417119230542866, 57.58576318195888, 53.11874198913574, 45.14977312088013, 43.56237030029297, 44.28815828050886, 39.96029213496617, 44.99184056690761, 43.74637596947806, 49.962258747645784, 56.55413287026541, 55.102956431252615, 56.89153739384243, 55.20326410021101, 53.48326185771397, 49.50153064727783, 57.239732469831196, 55.46668767929077, 55.87859773635864, 52.638440813337056, 49.737745080675396, 44.938436712537495, 50.035913126809255, 47.716951847076416, 52.917039258139475, 47.49995960508074, 61.3994174684797, 52.611169133867534, 43.81762627192906, 53.38400684084211, 52.133122648511616, 56.31184571129935, 55.95546913146973, 53.52268246241978, 47.91037579945156, 40.69322286333357, 37.56841993331909, 38.72504138946533, 38.85850586209978, 39.93030718394688, 37.14288098471505, 40.60446310043335, 37.509742396218435, 42.42151778084891, 41.63711479731968, 38.650455951690674, 44.44396815981184, 49.561121872493196, 47.6680052621024, 47.461435317993164, 45.334497928619385, 43.43181364876883, 44.05828060422625, 43.776711804526194, 44.481891427721294, 46.2119859286717, 47.334762709481375, 51.978966440473286, 51.23573848179409, 53.20154367174421, 52.51811538423811, 50.65766225542341, 46.636322838919504, 45.44834416253226, 44.416422026497976, 47.0394468988691, 49.31496109281267, 48.67219713756016, 54.57877390725272, 33.544051102229524, 2.4408876172133853, 3.3074026746409277, 8.124186413628713, 6.8024774960109164, 13.572512115750994, 33.04160254342215, 8.744090795516968, 0.8835096997874123, 0.17681120309446538, 1.7823231326682227, 41.65245294570923, 46.797639165605815, 29.57558400290353, 55.50707755770002, 12.945153185299464, 0.6661394323621477, 0.1359893964337451, 0.17491328636450426, 0.16185254577015126, 0.11824645208460943, 0.19666768903178827, 0.11554973678929464, 0.1876431054302624, 0.1682588934366192, 0.09326964590166296, 0.11226811752255474, 0.17751434179289, 0.10322197007813624, 0.07659779622086457, 0.1315370396311794, 0.20412347252879823, 0.07250498833933047, 0.10743715853563376, 0.11801163825605597, 0.2561144270002842, 0.06981180142611265, 0.31600331195763176], [0.01856547637310411, 0.047311573422380855, 0.029441651422530413, 0.025031206031729068, 0.027664174658379385, 0.06177827250212431, 0.022745253784315925, 0.052722686635596414, 0.018371213493602614, 0.006913053021500153, 0.022147389794034616, 0.029224591462739875, 0.015346536778711846, 0.014056271058507264, 0.06805082663361516, 0.0312570515088737, 0.04921399223219071, 0.04605398340416806, 0.022055448299007754, 0.08075988931315285, 0.04399227849873049, 0.013066803304744619, 0.028270058932581117, 0.0789761496707797, 0.014099067958470966, 0.051409131049045494, 0.02574686539758529, 0.009451891029519694, 0.07197032988603626, 1.8166829517909457, 37.07337815420968, 34.69876875196184, 15.277728591646467, 43.127235889434814, 26.2787367275783, 0.19258027550365242, 0.16990135530275957, 0.8901813817875726, 0.6188875564507076, 2.3152934994016374, 4.038435459136963, 4.55999720948083, 1.1381037469421114, 1.0159991447414671, 0.4728085207087653, 21.075585160936626, 59.41094030652727, 56.547233309064595, 54.06548963274275, 49.950613566807334, 55.733276162828716, 56.382804189409526, 55.79624421255929, 55.899626459394185, 54.86475133895874, 55.45431988579886, 56.37293427331107, 54.64504929951259, 53.35985837663923, 53.48059722355434, 48.86853238514492, 38.498203550066265, 39.86409085137503, 39.92293861934117, 42.61712694168091, 50.006174836839946, 52.90080826623099, 53.67443111964634, 55.00204426901681, 53.5705555507115, 52.27467482430594, 48.3841769354684, 41.12238877160208, 39.53349208831787, 38.22214467184884, 37.62011800493513, 39.19564635413033, 38.92101880482265, 42.461879866463796, 51.488267285483225, 52.56896230152675, 52.08406489236014, 55.01657295227051, 49.25020735604422, 44.577429158346995, 52.198025771549766, 50.062924248831614, 51.713500091007774, 53.53723199026925, 50.91111169542585, 47.012936047145296, 48.58206163133894, 50.98274414879935, 58.63446521759033, 64.94028200422014, 45.29191241945539, 36.40748017174857, 52.504229409354075, 48.01733636856079, 51.49680314745222, 50.80867092950003, 50.30607993262154, 45.24441105978829, 38.02976294926235, 35.296108858925955, 36.694791657584055, 35.31178399494716, 36.17522621154785, 35.02415984017508, 36.9084279196603, 37.17104550770351, 38.39529725483486, 36.25798620496477, 38.77484955106463, 37.184365204402376, 44.424096311841694, 45.846118109566824, 45.18479898997715, 44.82794645854405, 45.40952110290527, 42.6819987978254, 40.26641934258597, 40.33425807952881, 43.28154843194144, 43.40091153553554, 46.245448453085764, 49.19139780317034, 48.93905312674386, 47.78812919344221, 49.22533975328718, 47.845045362200054, 48.04900973183768, 42.70199571337019, 44.4379232270377, 44.53267928532192, 48.09024729047503, 46.78353432246617, 49.20837920052664, 13.738724316869463, 0.2354803399315902, 3.1171785848481313, 2.3854444665568213, 3.7099241954939703, 3.1402581121240343, 3.888351329735347, 0.2775066005332129, 0.06421830478523459, 0.021756624869470085, 5.3881482226508, 45.99694265638079, 20.255649089813232, 25.939904349190847, 30.51811408996582, 0.4154863708785602, 0.0703308739300285, 0.058085366019180844, 0.01641866790929011, 0.015266116808301635, 0.029072887995945554, 0.05098184058442712, 0.06987048791987555, 0.02847792813554406, 0.047633212591920576, 0.02286749695693808, 0.07835229778928415, 0.035466323141008615, 0.06811482605657407, 0.054437687287905386, 0.012424111050287527, 0.01869876609582986, 0.10597446773733411, 0.05074798349024994, 0.03745443753099867, 0.07693671089197908, 0.037629404570907354, 0.029643254354596138, 0.009017302920775754, 0.0433825571089983, 0.049021871827010594, 0.07933880628219672, 0.013881602574006786, 0.02726128600936915, 0.029285910672375133, 0.05098543682002595, 0.02818343715210046, 0.06990680311407362, 0.04959152911656669, 0.06579297421766178, 0.04058654160637941, 0.012454254968490983, 0.03413375500323517, 0.027576463829193796, 0.08663766498544387, 0.009725046327470668, 0.03433024178126028, 0.02657767554878124, 0.02987882135702031, 0.021424551527681093, 0.04960954422131181, 0.010464028638255383, 0.02553472312034241, 0.05419733322092465, 0.037918589410505125, 0.03888719814962574, 0.030566391069442034, 3.000158109835216, 47.67919186183384, 30.455114773341588, 20.28016233444214, 56.02223784582955, 25.58512932913644, 0.3652849846652576, 0.14855699134724482, 1.2050703763961792, 1.0239086917468478, 1.959188550710678, 3.0448411064488545, 5.399221479892731, 4.3393285019057135, 5.0067655103547235, 1.3454772936446326, 26.302173001425608, 58.6834500176566, 55.00491040093558, 54.58323117664882, 53.72646617889404, 55.57376984187535, 58.94193690163748, 57.78607974733625, 57.62708411897932, 56.53355230603899, 57.955251012529644, 56.89540754045759, 55.52866908482143, 55.23908206394741, 57.18456029891968, 51.13395084653582, 39.56719779968262, 42.46000385284424, 42.417338439396445, 43.87551866258894, 53.61308200018746, 55.544510977608816, 54.52825355529785, 56.80123165675572, 54.705265862601145, 53.7922100339617, 51.17769323076521, 41.89987134933472, 40.07626451764788, 40.91103151866368, 39.89791815621512, 41.909070764269146, 40.751438345227925, 43.92049782616751, 54.46488945824759, 54.26280805042812, 53.240519591740195, 55.24525553839547, 52.470777307237896, 47.993191378457205, 51.52116353171212, 53.736902373177664, 54.898773193359375, 54.54156977789742, 52.22389044080462, 48.18956136703491, 47.584223883492605, 50.40262862614223, 51.38473217827933, 62.12435776846749, 56.61230666296822, 37.25371170043945, 52.10935286113194, 49.289235387529644, 53.34640319006783, 51.62927055358887, 51.18686137880598, 46.150702817099436, 41.20134810038975, 38.46601949419294, 38.31814445768084, 37.591557434626985, 37.331937994275776, 36.966890062604634, 38.851123401096885, 38.52071571350098, 38.91900035313198, 38.1598471232823, 41.45496082305908, 38.53729411533901, 47.001085894448416, 47.152369022369385, 47.11203472954886, 46.34949772698538, 46.437548773629324, 45.19219534737723, 43.039049352918354, 41.03212124960763, 45.28181668690273, 44.90503324781145, 47.9969607761928, 50.16084173747471, 49.37847457613264, 49.50134652001517, 50.326226234436035, 47.8736788885934, 48.87172160829817, 44.66585888181414, 45.31653683526175, 45.41619832175118, 49.87616014480591, 47.576233455113, 49.76954698562622, 14.535620161465236, 0.7431074508598873, 3.571260950395039, 3.2866271265915463, 7.238243758678436, 7.6765435082571845, 1.162521236709186, 0.35525127021329744, 0.19856051674910954, 0.015308009560352989, 5.832389984812055, 52.14752973828997, 26.38243338039943, 25.642366852079117, 41.06393357685634, 0.4797494996871267, 0.08029570350689547, 0.028486898368490592, 0.061725937096135955, 0.04198115159358297, 0.038138567070875845, 0.03357431645105992, 0.03449477973793234, 0.0449846393561789, 0.007483688249651874, 0.05813227314502001, 0.02410639333538711, 0.04229169671556779, 0.018282830914748565, 0.022143288049846888, 0.01992957094418151, 0.016968686699068973, 0.03117876553109714, 0.03191140693213258, 0.015411652391776443, 0.062474781913416724, 0.07429621222295932, 0.051262988176728995, 0.0774522889405489, 0.10033333793814693, 0.12652455217071942, 0.1355743094214371, 0.17915214890880243, 0.11645232407110077, 0.14749573543667793, 0.18365352308111532, 0.1343491737331663, 0.1275251606213195, 0.07857824316514389, 0.24745477310248784, 0.1218588368168899, 0.07787551837308065, 0.15187121422163077, 0.0743107260870082, 0.15839372708329133, 0.08689362875052861, 0.12331312735165868, 0.12776285143835203, 0.1883530430495739, 0.16773610934615135, 0.14421946981123515, 0.1771333036678178, 0.10418243639703308, 0.09329697050686393, 0.1055446904418724, 0.18347858318260737, 0.11633576532559735, 3.5905220082827976, 54.90189640862601, 45.17999431065151, 24.708759989057267, 53.628058842250276, 39.99672154017857, 0.8327711309705461, 0.46255585657698767, 4.013765445777348, 4.021187858922141, 7.892404930932181, 11.499491010393415, 8.842638833182198, 6.042294195720127, 4.1591730032648355, 0.8973868265748024, 24.23788751874651, 58.972543716430664, 56.624855109623496, 56.83088656834194, 54.83490187781197, 59.41398361751011, 61.39838913508824, 60.62179592677525, 59.99311597006661, 60.05440602983747, 59.536945887974326, 60.67035688672747, 58.70124435424805, 56.32513066700527, 58.827194350106375, 54.945465087890625, 42.03534732546125, 45.29684911455427, 44.11631195885794, 47.38058955328805, 56.666478293282644, 59.60947118486677, 57.2776974269322, 56.94304091589791, 57.07662350790841, 55.65111024039132, 53.45190463747297, 44.781397002083914, 43.49331562859671, 44.15138299124581, 43.20045600618635, 43.174820627485005, 43.68697581972395, 44.938565254211426, 56.39171872820173, 56.48091970171247, 56.36657667160034, 58.34250886099679, 54.193600518362864, 47.977002075740266, 57.07344470705305, 54.61431046894619, 56.074147837502615, 56.33934668132237, 53.29175213405064, 49.8555691582816, 48.58625486918858, 52.55073717662266, 52.67789615903582, 59.60255077907017, 56.079018524714876, 42.291068826402935, 52.07738419941494, 51.85439566203526, 54.31115709032331, 53.9970429284232, 51.876549993242534, 49.12776272637503, 41.603363922664094, 40.18706396647862, 41.29076794215611, 39.832348006112234, 40.01095492499215, 39.80018132073538, 41.95631851468767, 40.9776543208531, 42.74680812018258, 40.351670265197754, 43.60683182307652, 40.602211884089876, 49.402018547058105, 49.2892736026219, 49.25404276166643, 48.643980503082275, 49.04594768796648, 47.76451574053083, 44.447636808667866, 43.183405126844136, 47.77178703035627, 48.37392486844744, 50.2498516355242, 53.10230949946812, 51.429499421800884, 51.63386331285749, 52.41591433116368, 51.28138814653669, 51.30012396403721, 46.342167377471924, 49.36287587029593, 49.00414037704468, 52.025363036564414, 50.6368385042463, 50.483787059783936, 15.951827185494558, 0.7343084258692605, 7.803874458585467, 7.024362138339451, 10.667756898062569, 10.836184706006732, 14.985134737832205, 3.031877722058977, 0.39824631597314564, 0.11888963542878628, 9.44009792804718, 59.10396889277867, 29.167950562068395, 36.74470404216221, 45.32112612043108, 1.3253777836050307, 0.24653571099042892, 0.2763841679053647, 0.2790537689413343, 0.13618918428463594, 0.06775597602661167, 0.13597959838807583, 0.1405106923942055, 0.10054130892136268, 0.15802020712622575, 0.09037319025290863, 0.1869255139359406, 0.17397901149732725, 0.16514909959265164, 0.16082390025258064, 0.13744435193283217, 0.051165292704744, 0.16030757581549032, 0.100882618821093, 0.13703003845044545, 0.16718421610338347, 0.28505855958376614, 0.12284121981688909], [0.01417622756811657, 0.048003170240138254, 0.025339405118886913, 0.0244846036657691, 0.025149313533412557, 0.02942875925717609, 0.03138673312163778, 0.014861401203753693, 0.026470601026500975, 0.07560188323259354, 0.019232679856941104, 0.03956075272123728, 0.027389566447319727, 0.027713935023971965, 0.03781854281468051, 0.015120287758431264, 0.04298877270360078, 0.04263157829908388, 0.03099061455577612, 0.042389103810169866, 0.053858971555850337, 0.041278436979545016, 0.01844539094184126, 0.012009557536137956, 0.012350456074013241, 0.047320852388760874, 0.02800592051685921, 0.01152090375710811, 0.017543329524674585, 0.04745269513555935, 6.567973622253962, 43.53741237095424, 37.60878201893398, 32.54157543182373, 47.101956367492676, 6.80579308952604, 0.10153097260211195, 0.6886091466460909, 0.4584876320191792, 1.9166961908340454, 3.030510881117412, 6.845683131899152, 3.3150741372789656, 6.008749161447797, 0.2514599753277642, 0.8661492999110902, 31.672220298222133, 59.94417980739048, 54.369966643197195, 54.319654737200054, 53.15652976717268, 59.0846529006958, 56.39264283861433, 56.30636705671038, 56.82219784600394, 56.81335278919765, 54.67074373790196, 54.12646354947771, 51.61101763589041, 52.57147407531738, 48.931865215301514, 41.62867273603167, 41.08723088673183, 40.902523449489046, 43.74167203903198, 52.54687397820609, 52.43185349873134, 54.37767219543457, 53.26444571358817, 53.4757855960301, 51.86080537523542, 48.85597004209246, 40.94290290560041, 40.375141280038015, 37.02973999295916, 37.84803976331438, 39.279521533421104, 40.111453669411794, 40.312798568180625, 43.758472783224924, 50.69729825428554, 51.53767939976284, 50.903715338025776, 51.64888184411185, 45.39816427230835, 54.64920432226998, 50.41031680788313, 49.03847490038191, 52.94177484512329, 54.993046351841514, 50.000522477286204, 48.89897244317191, 50.15615865162441, 53.354741028376985, 39.199321951184956, 39.96872724805559, 51.11289433070591, 49.53326654434204, 49.14355945587158, 53.4046881539481, 50.52560131890433, 47.55211625780378, 38.01740557806832, 34.91099105562483, 35.08003725324358, 36.09566933768136, 36.24546902520316, 36.81548881530762, 38.0621554510934, 36.24551766259329, 37.9587836265564, 36.94140407017299, 39.996794496263774, 40.91440486907959, 41.41544989177159, 44.68812091009957, 44.742167472839355, 47.3637193271092, 46.18602745873587, 46.355236939021516, 43.070236342293875, 42.44052110399519, 42.13011033194405, 45.440642084394185, 45.47702980041504, 47.625110558101106, 49.512894426073345, 47.84817205156599, 48.67833587101528, 49.62785931995937, 49.75906910215105, 46.92033045632498, 45.586255482264924, 45.05930757522583, 45.28707994733538, 47.956567423684255, 49.18194477898734, 39.02875409807478, 2.082813939877919, 0.6139674176062856, 2.410971279655184, 1.398064843245915, 7.339235390935626, 14.56557992526463, 0.14003733279449598, 0.22967292155538285, 0.17073512556297438, 0.029718982255352393, 18.603006158556255, 44.41084262302944, 15.306294373103551, 37.430223737444194, 14.20385149547032, 0.1599934005311557, 0.036916983513427634, 0.04370970259021435, 0.06442839279770851, 0.02194085730505841, 0.022692926860015308, 0.06399478856474161, 0.04832332681066223, 0.028356458492843167, 0.026462918313752328, 0.012651143778514649, 0.05234263577897634, 0.007099395276912088, 0.03705663959096585, 0.019483990568135465, 0.07441679468112332, 0.024508769690458263, 0.011822904426870602, 0.020811330593590225, 0.0029012045457160896, 0.0407899664049702, 0.041964442668748755, 0.04230355072234358, 0.0182981759841953, 0.043778865664665184, 0.05214972827317459, 0.04660772904753685, 0.0338316678202578, 0.03047344534258757, 0.00895942049100995, 0.004663488062630806, 0.08780482664172139, 0.02088098560592958, 0.00847143930981734, 0.04557273244219167, 0.02290056536107191, 0.024005642759480646, 0.011419150645711591, 0.01227951014880091, 0.022301329033715383, 0.03018828421565039, 0.009184055446114923, 0.02684636863081583, 0.009511825179548135, 0.025084240328786627, 0.02193684546676065, 0.022829008754342794, 0.03985793748870492, 0.07027826032468251, 0.051187412946351936, 0.042989363029067, 0.03038821116622005, 0.17972396393971785, 13.696036321776253, 54.56387002127511, 27.28681090899876, 40.12319265093122, 56.404489517211914, 5.86475556237357, 0.059284167763377936, 0.42758630588650703, 0.8063317154135022, 0.5503069364598819, 2.380403982741492, 3.341109471661704, 6.514944970607758, 6.292356388909476, 1.5437795328242438, 1.350204457129751, 36.49148736681257, 59.701444489615305, 56.329466342926025, 56.5645169530596, 56.14596789223807, 59.93189539228167, 57.43847526822771, 57.155659266880576, 58.9921932220459, 58.399609157017295, 56.24962459291731, 57.370699065072195, 54.26298870359148, 54.765062059674946, 51.276923928942, 42.51487030301775, 43.90700095040457, 42.86265890938895, 46.346308503832134, 53.714188711983816, 55.50802251270839, 56.509664399283274, 55.6731082371303, 55.04519605636597, 54.17402744293213, 51.48685680116926, 43.98454632077898, 40.2120566368103, 38.44732189178467, 38.89843715940203, 41.592319761003765, 40.54125533785139, 40.42107582092285, 46.70021152496338, 52.24562093189785, 53.9596894127982, 53.77291488647461, 52.996418952941895, 49.03221109935215, 55.10537093026297, 52.33026041303362, 50.15806245803833, 54.362608500889365, 55.570691789899556, 49.40181357519967, 48.11291926247733, 51.98642185756138, 56.445820876530235, 49.58675030299595, 38.514444964272634, 50.428528036390034, 50.0071371623448, 51.16591256005423, 53.561661856515066, 53.27661548342024, 48.2658143724714, 41.186225346156526, 36.81390462602888, 36.86225714002337, 37.72216272354126, 37.34830795015608, 38.09626415797642, 39.31259495871407, 37.730097566332134, 39.229563985552105, 37.53181682314192, 41.08083159582955, 41.32900387900216, 42.78500584193638, 49.23353862762451, 47.50408683504377, 48.41614212308611, 48.93345635277884, 48.459304332733154, 44.08482619694301, 43.79412399019514, 43.632091999053955, 46.85166140965053, 46.97556516102382, 49.66308668681553, 49.98432275227138, 49.25398022787911, 49.712543964385986, 51.83063282285418, 51.426001003810335, 47.69244902474539, 46.43892799104963, 47.08775772367205, 46.9758882522583, 51.01167297363281, 51.2070563180106, 41.71066495350429, 2.802581523145948, 1.9558812081813812, 4.73816899742399, 2.9451978589807237, 4.744833188397544, 1.2003858791930335, 0.9778531002146857, 0.35269878432154655, 0.04823111729430301, 0.06860305235854217, 18.278943913323538, 57.015455041612896, 18.350972414016724, 39.18322992324829, 19.824235439300537, 0.28424469754099846, 0.045297179371118546, 0.06703700710620199, 0.01572509485829089, 0.037369084611002884, 0.029061410576105118, 0.05212192190811038, 0.019253329373896122, 0.020970689631732445, 0.04206907616129943, 0.01360344816930592, 0.018094108273674334, 0.014794324624485202, 0.08919020515999623, 0.029308346432766745, 0.01927559550053307, 0.02505237971698599, 0.0473186301865748, 0.049970609668110094, 0.059246699059648175, 0.05354728649503418, 0.059118713784430704, 0.024860834370234182, 0.06804390557642494, 0.17380318950329507, 0.16467677136617048, 0.11791049582617623, 0.08811440145862953, 0.11909386089869908, 0.15329771196203573, 0.09907342733017035, 0.12769365443715028, 0.13358305341431073, 0.04408981451498611, 0.15140905044972897, 0.10826134109603507, 0.18243913538753986, 0.0907522945531777, 0.08843661738293511, 0.1595870666205883, 0.11668882066650049, 0.09610332349049193, 0.09524117011044707, 0.14130662754178047, 0.1709853285657508, 0.10317952771271978, 0.04769802964957697, 0.08319358407918896, 0.16708968260458537, 0.12509278899856976, 0.1200998704880476, 0.16108889531876358, 0.25657154247164726, 16.084365810666764, 59.79473100389753, 51.139488560812815, 42.180047035217285, 60.68134893689837, 12.080928427832466, 0.15616871576224053, 2.4928156307765414, 2.0845998440470015, 5.479971706867218, 10.846547075680324, 16.77352809906006, 10.81130233832768, 13.756589872496468, 1.3022319227457047, 1.4824068546295166, 36.47748327255249, 59.76094191414969, 58.01463379178728, 58.07513175691877, 56.88291815349034, 63.568130901881624, 59.343917982918875, 60.10480826241629, 60.28393977028983, 61.38081019265311, 57.10315520422799, 58.894355637686594, 55.524083273751394, 57.59748131888253, 52.52338906696865, 45.31064476285662, 47.31542239870344, 44.917744977133616, 49.00745119367327, 57.41337490081787, 57.98203979219709, 57.79273612158639, 56.746750831604004, 60.11562660762242, 56.442211287362234, 54.247820786067415, 44.88869455882481, 42.43610552379063, 41.38942888804844, 41.50740582602364, 43.14242465155465, 42.96485301426479, 44.060559613364084, 48.40194347926548, 54.81787531716483, 56.07252890723092, 55.86445467812674, 55.3639794077192, 49.24483639853341, 56.92057391575405, 53.255593708583284, 52.09927797317505, 56.41887576239449, 59.76141439165388, 51.19179459980556, 50.65312508174351, 52.8026510647365, 56.64787449155535, 52.31683996745518, 46.64974675859724, 51.67280101776123, 51.177227701459614, 53.30459240504673, 57.73834909711565, 54.90491887501308, 51.27162592751639, 42.461740902491975, 38.83394398008074, 38.92320053918021, 38.68672207423619, 38.82325765064785, 40.537812505449565, 41.85651111602783, 40.86874825613839, 42.0238550049918, 39.0683970451355, 43.508771896362305, 43.45767136982509, 45.041200569697786, 50.08840676716396, 47.83950069972447, 50.12393985475813, 50.63124867847988, 50.0401793207441, 45.032831464494976, 46.41373034885952, 45.804588726588655, 49.07132945741926, 49.1822053364345, 51.84804848262242, 52.19802229745047, 49.26560109002249, 52.12800530024937, 53.21862929207938, 51.730550970349995, 48.88021230697632, 49.0881267275129, 48.92227670124599, 49.68935782568795, 51.74687576293945, 52.03390237263271, 41.91369826453072, 3.254531225987843, 1.6515147175107683, 6.258613330977304, 7.156486477170672, 18.59940525463649, 28.566719463893346, 4.6379559976713995, 1.073999558176313, 0.5865825042128563, 0.16412208255912575, 27.516127518245153, 57.24974134990147, 22.708097423825944, 50.00902359826224, 24.58078806740897, 0.28368995445115225, 0.19984840335590498, 0.2295479896877493, 0.09065298416784831, 0.16802532811250004, 0.04616415034979582, 0.13915693360779965, 0.18694741704634257, 0.15822070065353597, 0.13163998696420873, 0.10557312105915376, 0.20130373883460248, 0.12855307332107, 0.17689475789666176, 0.08271193956690175, 0.1049888413399458, 0.12289980453039918, 0.216813325881958, 0.12586108062948498, 0.17553331809384481, 0.09783110434987716, 0.18967264438314096, 0.10055292544088193], [0.028070929260658364, 0.054348432791552374, 0.013392774072209639, 0.03765303116025669, 0.10835223086178303, 0.012120442880716707, 0.022586206872282282, 0.026451649543430125, 0.0375997084858162, 0.03687149791845253, 0.05604123856340136, 0.02643132911595915, 0.042476298952741284, 0.06751601211726665, 0.029107018307383572, 0.05950434559157916, 0.04428693572325366, 0.008354311443067022, 0.06051902685846601, 0.043158657516219785, 0.02012004759827895, 0.016660277266055346, 0.06508915698421852, 0.009487103604312454, 0.03176387645570295, 0.025092589702191095, 0.009782589489727147, 0.04454433798257794, 0.04169109483648624, 0.059492532296904495, 0.40640827800546375, 20.98484516143799, 39.23399346215384, 25.366698810032435, 43.36975233895438, 26.275995663234166, 0.10842598083295993, 0.08133586376373257, 0.27301923132368494, 0.17547134070524148, 0.8479569618191037, 2.553379386663437, 4.36997309752873, 2.097466387919017, 1.2543409211294991, 0.013389631606904524, 6.844308257102966, 52.3056047303336, 55.44141360691616, 55.50474296297346, 56.322236742292134, 57.110416071755544, 56.48686735970633, 58.17061390195574, 58.103080885750906, 58.67919077192034, 53.40182202202933, 50.476078033447266, 53.50316149847848, 57.75765119280134, 51.06838764463152, 40.47308308737618, 40.964508329119, 41.42771346228463, 50.24523455756051, 54.93470580237252, 53.90336036682129, 54.70219823292324, 52.101032393319265, 54.23282309940883, 51.55833639417376, 47.49670784814017, 41.394824164254324, 40.52789395196097, 38.1828248160226, 40.05759818213326, 39.35497897011893, 39.43017584936959, 40.592605999537874, 39.96623979296003, 42.1668141910008, 50.35964012145996, 49.79642956597464, 55.48891496658325, 49.586194447108674, 48.12219163349697, 51.49461446489607, 50.258119991847444, 55.10084070478167, 49.402907916477744, 47.66935668672834, 49.41814184188843, 42.56397669655936, 41.14214250019619, 47.890632493155344, 53.50423846926008, 49.52075283867972, 50.74385813304356, 52.25507395608084, 50.609945501599995, 50.16091816765921, 41.201959541865754, 34.99519280024937, 36.114234924316406, 37.71832384381975, 36.942251750401084, 38.44582108088902, 41.17039734976632, 38.0939747265407, 36.90167079653059, 36.594014985220774, 40.6509222303118, 48.826811926705496, 48.16903291429792, 44.02446372168404, 46.9051000050136, 47.730518204825266, 49.14531735011509, 46.3302720614842, 48.18975591659546, 48.162327902657644, 43.34993955067226, 42.89292178835188, 46.83451325552804, 47.02373702185494, 47.25908987862723, 47.48411076409476, 49.969651630946565, 50.71342849731445, 49.693155016217915, 50.450890813555034, 49.09952177320208, 46.93791287285941, 44.085823263440815, 47.79861402511597, 47.922694955553325, 48.4264497756958, 15.107094730649676, 0.25405846589377945, 1.4233597602163042, 2.472632199525833, 1.9935452214309146, 3.7069924899509976, 2.0491282045841217, 0.06122140559766974, 0.27497894902314457, 0.06442825709070478, 0.9247463898999351, 37.386252062661306, 27.91329870905195, 22.1281156539917, 39.93234648023333, 4.636082589626312, 0.258994672447443, 0.08004022828702416, 0.11293677985668182, 0.03925669778670583, 0.010433329169505408, 0.03260289179161191, 0.02576865315703409, 0.034193136995392184, 0.009633701943260218, 0.036109900035496266, 0.03113603139562266, 0.03738480626738497, 0.022991178623799766, 0.02059032834534134, 0.13091911136039666, 0.07949303050658532, 0.03549149339752538, 0.04966367435242448, 0.046990921521293263, 0.020637534026588713, 0.019001850725284646, 0.06438707001507282, 0.029020929176892554, 0.017984029537599002, 0.07341724474515234, 0.016130958883357898, 0.018842827561976652, 0.07452625595033169, 0.053952544927597046, 0.006335733375245971, 0.011940656545838075, 0.04881878290325403, 0.04154384934476443, 0.0003078353552804661, 0.0376223037019372, 0.021034909578572427, 0.043559970267649205, 0.029333903454244137, 0.028694390984518186, 0.0179962295972343, 0.006020196780030216, 0.02370878029614687, 0.07766106738043682, 0.08781638887843915, 0.05952570587396622, 0.05147010420582124, 0.09629448037594557, 0.021770580638466135, 0.021851221132757406, 0.08449472247489861, 0.07429513335227966, 0.03605419909581542, 0.06652607702250991, 0.5559271605951446, 31.44794634410313, 43.47267253058297, 25.941342626299175, 56.79581553595406, 26.2092547416687, 0.07831811998039484, 0.166339032884155, 0.27376681406583103, 0.3615795863526208, 1.636681182043893, 3.8427446569715227, 4.845107853412628, 5.661965872560229, 5.474512594086783, 0.35184573009610176, 8.598200338227407, 56.23898690087454, 57.00040871756417, 58.83273206438337, 58.42090538569859, 58.05374520165579, 57.689027309417725, 59.34079129355294, 59.13183116912842, 60.40606130872454, 53.687768186841694, 53.58962140764509, 55.087778091430664, 58.83098806653704, 52.951554434640066, 43.35780838557652, 43.11544827052525, 43.648691245487754, 51.328844342912944, 56.95687825339181, 55.04962205886841, 54.05006463187081, 53.47050496510097, 55.826531410217285, 53.47462177276611, 49.00930288859776, 43.42429222379412, 40.92007459912981, 40.64044782093593, 41.25636741093227, 41.448558058057515, 42.21946069172451, 41.72432163783482, 42.33276496614729, 45.99671336582729, 51.975294317517964, 53.70614617211478, 57.967250551496235, 51.5464688709804, 49.23973989486694, 52.59718588420323, 51.22097355978829, 55.82655225481306, 52.27093669346401, 48.875216552189414, 49.62888070515224, 43.95444672448294, 43.902870246342246, 46.21655089514596, 54.37840175628662, 51.908268519810264, 50.82188640322004, 54.219232422964915, 52.058415617261616, 52.27322612489973, 44.56529412950788, 36.36463410513741, 37.07935013089861, 38.15121398653303, 38.11781399590628, 39.14540045601981, 42.18890251432146, 40.171103954315186, 39.142492634909495, 37.773662771497456, 42.22137492043631, 49.05268049240112, 49.851907457624165, 45.295035634722026, 47.06459937776838, 47.919154848371235, 49.33102880205427, 48.53675937652588, 49.73828704016549, 49.03999655587332, 45.061249596732004, 44.75908981050764, 48.724294730595176, 48.617799690791536, 49.38239336013794, 50.04607834134783, 51.31214434759957, 51.621832506997244, 50.48398160934448, 51.270816462380544, 50.29902056285313, 47.790696552821565, 46.43463053022112, 50.290415218898225, 49.32988929748535, 50.35870558874947, 17.802205426352366, 0.3946613169142178, 3.793546199798584, 5.185010254383087, 5.190557088170733, 4.653877360480172, 1.3989509556974684, 0.14074294136038848, 0.0784972667960184, 0.07512922930930342, 1.3431468244109834, 44.20577348981585, 37.89321347645351, 19.064446449279785, 49.37670973369053, 6.35852712392807, 0.23119549985442842, 0.04713716956653765, 0.023406158766842315, 0.03606637879940016, 0.04699071796078767, 0.029368162687335695, 0.0608040862051504, 0.013976864649781158, 0.004685762246871101, 0.0259303259995899, 0.030665094165929725, 0.06056856670017753, 0.021800829729597484, 0.034092303298945935, 0.036483097688427994, 0.09220615761088473, 0.013823347798149501, 0.07761386169918946, 0.03991031699946948, 0.0235962842790676, 0.03291785417656813, 0.066812690214387, 0.04307568286146436, 0.22652580828538962, 0.22814705914684705, 0.2420576512813568, 0.09491153779838767, 0.17082276514598302, 0.19271453044244222, 0.11549063638917037, 0.16563607060483523, 0.20819700323045254, 0.16282897123268672, 0.10090046429208346, 0.15972410355295452, 0.11996674191738878, 0.11695343575307302, 0.12563750334084034, 0.14128021895885468, 0.21179137964333805, 0.11398419365286827, 0.2601234833044665, 0.11335920183254139, 0.1629677452147007, 0.13663513106959208, 0.09947043138423137, 0.22552156288708958, 0.10495179332792759, 0.1547765518937792, 0.17760180495679379, 0.10647517908364534, 0.1258154423641307, 0.16281983815133572, 0.8567755286182676, 40.18289852142334, 55.304884978703086, 35.648309571402415, 54.878463608878, 38.61270291464669, 0.20816200439419064, 0.5821433109896523, 0.6845695291246686, 2.9575923596109663, 7.1410949145044595, 9.208573528698512, 11.896731683186122, 8.550394126347133, 6.166726444448743, 0.3368271717003414, 8.299557209014893, 55.51269517626081, 57.39285339627947, 60.72824232918875, 62.17916515895298, 59.99268518175398, 60.07742541176932, 61.40549714224679, 61.958288873944966, 62.873568126133506, 55.68220342908587, 55.23536825180054, 57.58656569889614, 62.025568280901226, 56.52760812214443, 44.799705505371094, 44.409397397722515, 45.81323228563581, 55.08453328268868, 59.50187832968575, 58.33206571851458, 55.070713315691265, 53.83207184927804, 57.18115568161011, 55.3941901751927, 51.9264623778207, 46.06675468172346, 45.50589261736189, 42.89373472758702, 44.10484048298427, 43.13770682471139, 43.14386640276228, 43.96810340881348, 44.28511149542672, 46.47232450757708, 53.76807199205671, 54.24726840427944, 57.90680122375488, 50.971449851989746, 52.105687686375205, 54.52156938825335, 54.16906295503889, 58.75688552856445, 53.27881458827427, 49.26589291436331, 51.20425966807774, 47.26829276766096, 49.733381611960276, 51.227219990321565, 56.31086254119873, 54.01244708469936, 54.1091034752982, 56.024190289633616, 53.597024713243755, 55.12937348229544, 45.04908677509853, 37.53456136158535, 39.30245058877127, 42.224911553519114, 40.82540886742728, 41.81514848981585, 45.331086363111226, 41.91507748195103, 41.490917750767295, 39.651215417044504, 45.31356995446341, 52.77341999326433, 53.095093795231406, 47.70687001092093, 49.774146693093435, 51.37707526343209, 52.12723057610648, 49.99703795569283, 53.45722000939505, 51.521622112819124, 46.56378364562988, 46.061560903276714, 51.17194707053048, 50.72749859946114, 49.94746255874634, 51.205892494746614, 52.47474472863333, 53.018489905766074, 52.48202991485596, 52.16804082053048, 51.68706219536917, 48.93905312674386, 48.681049142565044, 51.57865292685372, 53.409940992082866, 49.94301918574742, 17.317613737923757, 0.615431587610926, 6.3686085258211405, 7.5853553499494275, 7.041409977844783, 11.72949549130031, 8.67381932054247, 2.1443916984966824, 1.037282019853592, 0.26323717193944113, 2.376169489962714, 49.64398261478969, 38.18906429835728, 30.86682333265032, 56.55959415435791, 8.613135491098676, 0.644398138991424, 0.2287499239402158, 0.3046222983726433, 0.16739530834768498, 0.09821394059274878, 0.12563552201858588, 0.08166525858853545, 0.1797056027821132, 0.08604709524661303, 0.17921599905405725, 0.17758139462343284, 0.13132583882127488, 0.1378476188651153, 0.1690827842269625, 0.1687750278839043, 0.16524280527872698, 0.11148932895490102, 0.3172956497541496, 0.10674417072108813, 0.18829569326979773, 0.17488408221730165, 0.12229679045932633, 0.1315911595842668], [0.06524551859391586, 0.03775827194164906, 0.05012413839410458, 0.02158347121439874, 0.018812854973865405, 0.026448334899864027, 0.024979247212676064, 0.025747469293751886, 0.018127488803916743, 0.036260680694665225, 0.03231114208964365, 0.023697173954652886, 0.03173766804060765, 0.05266671088923301, 0.0655585675101195, 0.03100120648741722, 0.02157626686883824, 0.03168472195310252, 0.025239977686266814, 0.07294612431100436, 0.014811606911410178, 0.023478380337889706, 0.03808133942740304, 0.037980994276170216, 0.0376921826308327, 0.053602224082819054, 0.02811591952506985, 0.024335202129025544, 0.03472519326688988, 0.0520784854888916, 0.05748740703399692, 6.619801104068756, 45.66886261531285, 29.280132702418737, 34.301515919821604, 48.25351258686611, 5.002922288009098, 0.18645964536283696, 0.06963274282004152, 0.1816607200141464, 0.9165654288870948, 1.272471268262182, 3.64653708253588, 4.762594955308097, 4.988644174167088, 0.6378872426492828, 0.3108619978385312, 17.167984281267437, 59.53586891719273, 53.32352277210781, 56.190366881234304, 55.6087019102914, 59.58329037257603, 55.02971199580601, 55.017514433179585, 53.57351895741054, 54.45253208705357, 54.0469240461077, 56.587192399161204, 54.555414063589915, 51.16735431126186, 42.22686052322388, 41.97721522194998, 44.94300862721035, 54.5621121270316, 55.46983868735177, 52.13554409572056, 51.7483730997358, 54.93367746898106, 53.603448322841096, 54.284753935677664, 47.894273349217, 40.5459314755031, 40.152923992701936, 39.04706954956055, 38.37699917384556, 39.778221539088655, 40.48518337522234, 39.76198707308088, 39.147748947143555, 41.383627142224995, 45.18841552734375, 49.26717833110264, 50.92640815462385, 56.81584371839251, 51.0132988521031, 49.536320277622764, 50.32856430326189, 54.340666089739116, 51.35725552695138, 49.76685455867222, 52.35283858435494, 52.89107731410435, 54.86598811830793, 53.560254846300396, 49.51684100287301, 53.60796465192522, 51.09758397511074, 50.451860087258474, 50.82354007448469, 43.494889395577566, 37.7794645173209, 38.60935735702515, 37.127598421914236, 36.68310826165335, 39.118979930877686, 42.26124715805054, 43.77026040213448, 41.83881752831595, 37.12217535291399, 37.349419661930625, 46.752833706992014, 51.240331241062705, 49.56814650126866, 49.81303923470633, 47.541266645704, 46.67455530166626, 48.65728630338396, 49.55802992412022, 49.083836214882986, 47.88352448599679, 47.426277433122905, 45.877624716077534, 45.22583852495466, 48.3821758542742, 49.215987477983745, 50.49247925622122, 47.37865447998047, 48.04692874635969, 49.731846060071675, 50.79575770241873, 45.69335501534598, 46.35204076766968, 46.296642780303955, 47.54973302568708, 49.4678179877145, 38.61174406324114, 2.3869609108992984, 0.2826988590615136, 3.7564484647342136, 5.438757164137704, 3.221718575273241, 2.124580647264208, 0.18931262727294648, 0.05963926549468722, 0.17422892951539584, 0.0711543575993606, 11.643352593694415, 41.488878454480854, 18.775964191981725, 32.56915283203125, 22.957424845014298, 0.05087992801730122, 0.027881344880110452, 0.0060560967956137446, 0.06612600599016462, 0.05303348620821323, 0.011048054755000132, 0.034690574410238435, 0.021494854540963258, 0.015047726919874549, 0.06675629038363695, 0.04521579588098185, 0.029669903817453554, 0.01693413399958185, 0.07180279280458178, 0.06041759265852826, 0.025452055502682924, 0.07932182255067996, 0.03304410240213786, 0.01456747849338821, 0.08095722086727619, 0.027455328364989588, 0.04333481877776129, 0.034023425209202936, 0.011619274371436663, 0.018913127182583724, 0.04144656438646572, 0.03282792453787156, 0.028793949035129378, 0.06996238870280129, 0.016852580875690495, 0.02104366268031299, 0.05957238229789904, 0.027892342236425196, 0.041673385072499514, 0.010720824456906744, 0.04823216902358191, 0.0777026480063796, 0.0574235093912908, 0.035493281337299516, 0.038866448548755476, 0.026668483890326958, 0.035929277406207154, 0.04454312001221946, 0.07386579710458006, 0.05048210632854274, 0.016624769528529475, 0.020387926438291157, 0.050227716764701266, 0.054266384337097406, 0.015109022380784154, 0.015578885828810079, 0.102482495829463, 0.024059533706999252, 0.06894660142383405, 0.153177285566926, 10.424578632627215, 54.337442125592915, 26.045298099517822, 41.60566030229841, 55.35556513922555, 3.5387935382979254, 0.05515551966215883, 0.07946985175034829, 0.141862402004855, 0.6269725454705102, 2.0064525859696523, 6.062989839485713, 2.1285580566951205, 3.8675505944660733, 2.432333299091884, 0.1566993301468236, 21.55200229372297, 62.93141882760184, 55.45653288705008, 58.35970565250942, 56.53182567868914, 59.335392543247764, 58.96480342320034, 57.95007807867867, 54.920673915318076, 57.44157416479928, 56.2659250668117, 58.23695877620152, 57.10926614488874, 55.1053535597665, 44.55337102072579, 43.06634882518223, 45.59455163138253, 56.03686727796282, 56.07175765718733, 55.331743240356445, 53.1204651423863, 55.22281633104597, 54.84663043703352, 56.09174067633492, 51.40148775918143, 43.85995469774519, 40.47290938241141, 41.136462347848074, 39.56183379037039, 41.567573751722065, 41.02954346793038, 42.71302250453404, 41.51846735818045, 44.34205198287964, 47.249001094273154, 52.43691873550415, 52.98225505011422, 60.089626448495046, 53.04370839255196, 52.34648445674351, 51.58096667698452, 56.04422542027065, 52.50537933622088, 49.83050353186471, 53.773269244602744, 54.23742628097534, 53.636375835963655, 55.66018806185041, 51.18930714470999, 53.768735545022146, 52.29707581656319, 52.98172698702131, 52.82472896575928, 46.58163356781006, 39.284548555101665, 39.67346007483346, 38.36406510216849, 37.572512422289165, 41.48061009815761, 42.49676677158901, 44.51066044398716, 43.47952345439366, 39.87175471442086, 39.2616924558367, 46.404013293130056, 52.48610850742885, 53.04008143288748, 50.8519686290196, 48.27160917009626, 49.212961537497385, 50.423313413347515, 50.12621538979666, 50.689220973423545, 49.41772147587368, 48.85085964202881, 48.7399594443185, 47.82692098617554, 49.85911968776158, 51.198673316410606, 51.47355447496687, 49.41813489368984, 48.50692728587559, 51.43481479372297, 50.183534554072786, 48.61251558576311, 47.62148707253592, 48.25164352144514, 49.709507601601736, 50.53458186558315, 41.29175458635603, 3.7283291050365994, 0.7239488246185439, 3.9405171019690375, 7.821392604282924, 5.896985215800149, 1.8949444208826338, 0.3872233788881983, 0.11713491672916071, 0.0926295363211206, 0.06997279064463717, 11.856030004365103, 49.797704560416086, 18.819244521004812, 32.31836802618844, 31.315951415470668, 0.07681645413062402, 0.04719148290210536, 0.040494393158171854, 0.06207744537719658, 0.013253264727869203, 0.05048286628776363, 0.05590414395555854, 0.011776124526347433, 0.02184964862785169, 0.09235337935388088, 0.03584787695269499, 0.07419106643646955, 0.04437746247276664, 0.035308841948530505, 0.03425916863073196, 0.03952772842187967, 0.03049233915018184, 0.10696424676903657, 0.039230608115238805, 0.04032763299931373, 0.03321059114698853, 0.028655985902462686, 0.029389794383730208, 0.0209485727827996, 0.22856232257825987, 0.19009211473166943, 0.11096528278929846, 0.10795490789626326, 0.08103316250656332, 0.08385428041219711, 0.16601478814014367, 0.11793534377855913, 0.07147362189633505, 0.15464133343526296, 0.0740635289943644, 0.0687969233840704, 0.10051081555762462, 0.1509879787585565, 0.10563496274075337, 0.15241561643779278, 0.09242314632449831, 0.17694863357714244, 0.16630051923649652, 0.2037689515522548, 0.10290511458047799, 0.08688933362386056, 0.11462348220603806, 0.14134636255247252, 0.16812417709401675, 0.14695422377969536, 0.11152069084346294, 0.1961979256676776, 0.21322383492120675, 0.14980610646307468, 0.2744200532989842, 12.407806430544172, 64.09385245186942, 40.64571108136858, 43.14030197688511, 65.07490335191999, 7.870548503739493, 0.30295041522809435, 1.2788142136165073, 0.6251378953456879, 4.188039294310978, 5.885468142373221, 12.345957040786743, 12.809839623314993, 11.881023543221609, 2.3155673018523624, 0.5454218100224222, 21.05551528930664, 66.24771063668388, 56.061637605939595, 60.0715263911656, 57.55338110242571, 63.0448898587908, 59.42797728947231, 61.702893938337056, 57.77392039980207, 57.667692865644185, 56.43272352218628, 60.59226608276367, 59.59292752402169, 55.83477544784546, 46.75105149405343, 47.39938790457589, 48.14754908425467, 59.61723232269287, 59.50993824005127, 54.72638143811907, 52.44498559406826, 58.517089298793245, 58.788228852408274, 60.39309597015381, 54.83969613483974, 45.544264044080464, 41.99682303837368, 42.49026673180716, 42.47405311039516, 44.364807333265034, 43.35955238342285, 45.82120534351894, 43.858818667275564, 44.79289974485125, 50.14398193359375, 53.68242849622454, 54.27609995433262, 59.467290197099956, 55.01522847584316, 54.76894262858799, 54.310076645442415, 59.321211269923616, 56.04861668178013, 51.656278201511924, 57.454820905412944, 57.10561834062849, 57.28193582807268, 59.043373652866904, 52.28841141292027, 56.07924434116909, 53.733456066676546, 54.76091398511614, 55.30571181433541, 47.073204721723286, 40.83340971810477, 42.73268938064575, 40.16776534489223, 39.66435098648071, 43.48218808855329, 46.42029987062727, 48.085074356624055, 46.35023423603603, 39.51887655258179, 40.98937593187605, 49.20660393578665, 54.811288424900596, 54.14075599397932, 54.323736803872244, 52.049598353249685, 50.79525048392159, 51.356852531433105, 53.55921261651175, 52.22701713017055, 52.456634249006, 52.02889966964722, 49.72872631890433, 49.33987038476126, 51.78045640672956, 53.44475841522217, 54.27395296096802, 50.1330246244158, 49.99058655330113, 54.58636481421334, 52.28330796105521, 49.70102732522147, 49.52849660600935, 50.41630962916783, 50.776021344321116, 51.70516225269863, 42.99671050480434, 3.6617367012160162, 0.5032564497419766, 7.7916456290653775, 10.105765751429967, 8.431437492370605, 7.080286886010851, 3.15092185991151, 0.20927485610757554, 0.5652298214180129, 0.17666941641696862, 18.56678867340088, 51.967825004032676, 26.80640377317156, 43.403537954602925, 35.79114021573748, 0.23333635926246643, 0.14965703231947763, 0.14785991875188692, 0.08095589093863964, 0.1272369867988995, 0.15830931732697145, 0.09970743688089506, 0.19246120617858, 0.10729880524533135, 0.173105601221323, 0.10729300377092191, 0.23163258497204098, 0.15511169391019003, 0.1252843937171357, 0.18197326681443624, 0.1666575236512082, 0.1812528661851372, 0.18145816374037946, 0.14573134082768643, 0.19711457219507011, 0.13836870661803655, 0.1773517240903207, 0.09134500167731728, 0.09449852710323674], [0.041234715575618405, 0.05168352382523673, 0.03261523095092603, 0.02990103998620595, 0.043945432441043, 0.015753815549292734, 0.003725177184345999, 0.0469291035884193, 0.05040038017822163, 0.05942732508161238, 0.07747761186744485, 0.053310854360461235, 0.016758887063977972, 0.021346696419641376, 0.05170305206307343, 0.019471330801025033, 0.022108428313263824, 0.034981869493744204, 0.007762122550047934, 0.02342966152355075, 0.03521883427830679, 0.014753427622573716, 0.04212769819423556, 0.012120528545762812, 0.06896112207323313, 0.035471147524991205, 0.0345953047009451, 0.026947721406551342, 0.04695948160120419, 0.02040101877147598, 0.028168719727545977, 0.21214018735502446, 27.576899937220983, 47.222181047712056, 20.88239049911499, 43.47633075714111, 32.62573896135603, 0.47690470090934206, 0.09699776835207428, 0.08541896859449999, 0.03946201230532356, 1.792673994387899, 2.8253114691802432, 3.4674713654177527, 4.793011997427259, 2.5236775747367313, 0.39046425212706837, 0.8515796874250684, 26.271946600505284, 55.72625848225185, 60.611700194222585, 57.65829542704991, 54.870963028499055, 56.48168747765677, 54.230749062129426, 55.88166536603655, 56.250694615500315, 54.478469712393625, 53.89624193736485, 57.13403647286551, 53.13643210274832, 42.54954876218523, 43.49807167053223, 51.460405009133474, 56.38078921181815, 55.68507998330252, 55.21847023282732, 51.36392232349941, 57.44341891152518, 54.66528245380947, 53.09242568697248, 47.17532239641462, 40.72314528056553, 38.24757855279105, 38.95834800175258, 40.25975949423653, 39.66321843011038, 39.77454594203404, 39.68540750231062, 41.24286011287144, 41.48011677605765, 44.676746709006174, 46.952465874808176, 49.015729972294395, 50.04698855536324, 51.29808119365147, 50.54826634270804, 50.65895462036133, 52.82214076178414, 52.03750153950283, 50.74671384266445, 50.59721640178135, 52.35829986844744, 50.07164771216256, 50.78652702059065, 51.99752507890974, 51.98674494879586, 54.000881808144705, 52.952582768031526, 46.492592402866904, 38.24082142966134, 37.98211220332554, 38.16020842960903, 36.6203556060791, 38.181872912815635, 43.78619262150356, 47.126796177455354, 47.49435240881783, 40.862974303109304, 38.353086948394775, 37.82985632760184, 46.764280864170615, 52.86624097824097, 52.6749918120248, 50.461549350193565, 49.01373931339809, 47.17755971636091, 49.455415453229634, 49.61499473026821, 50.50930779320853, 48.07154621396746, 47.64677504130772, 46.18306752613613, 47.52679007393973, 48.39136484691075, 48.09429809025356, 48.95645489011492, 50.453704833984375, 50.62498835154942, 48.834545271737234, 50.15374067851475, 49.83785472597395, 48.69487605776106, 48.82707595825195, 49.09013475690569, 44.2042692048209, 12.017376729420253, 0.09545065422675439, 1.3827646928174155, 1.2863792819636208, 6.323793947696686, 6.2861486077308655, 1.5990512583936964, 0.43807317316532135, 0.014033146585071725, 0.04390953115320631, 2.3665735934461867, 36.97614506312779, 34.09382731573922, 21.412668330328806, 40.04636641911098, 4.833552999155862, 0.23499510596905435, 0.07291373104921409, 0.055083360855600665, 0.051839610628251515, 0.08147769793868065, 0.037369033720876486, 0.015427333336057407, 0.05405368396480169, 0.040034173389098475, 0.0691965872954045, 0.025449007184111645, 0.051642418173807006, 0.028306954274220125, 0.04477703817454832, 0.04831069927396519, 0.05352320528722235, 0.026298042785908495, 0.10012238140084914, 0.02136708639695176, 0.038637029073600254, 0.022066971519961953, 0.0150815128747906, 0.05904986962143864, 0.021391802035006027, 0.040284573167030296, 0.0037255427450872958, 0.03995705788422908, 0.00947035227103957, 0.020041797243590866, 0.02170418598689139, 0.06764795325164284, 0.01957239519937762, 0.058690144281302176, 0.05877744459680148, 0.027959822544029782, 0.017793415480160286, 0.016568038911957825, 0.02041698639680232, 0.036317613175404925, 0.04382437500836594, 0.008203557077130037, 0.031190348123865466, 0.087692563022886, 0.04509067402354308, 0.01931000910034137, 0.043325787476663075, 0.028955101102058376, 0.064845535771123, 0.04533339278506381, 0.056544962605195384, 0.030489088967442513, 0.010257849835657647, 0.028634754541729177, 0.03416549687140754, 0.0243465200931366, 0.38260415675384657, 37.45479604176113, 47.63728380203247, 21.83164644241333, 61.03890323638916, 31.92737899507795, 0.19687139881508692, 0.14111218654683658, 0.01472742616065911, 0.14886310563555785, 0.39392440074256485, 2.600936983312879, 5.585668572357722, 6.307897772107806, 4.245952529566629, 0.7383737191557884, 1.3082306065729685, 31.882736819131033, 59.2401396887643, 59.15095261165074, 59.162417139325825, 56.51681062153408, 58.451282909938264, 55.58960826056344, 59.52627345493862, 57.71188340868269, 55.790300028664724, 55.733814648219514, 59.907555852617534, 54.017467158181326, 44.47475215366909, 44.30194698061262, 52.403942584991455, 57.954782009124756, 58.46868119921003, 56.29715027127947, 52.68038361413138, 57.774771554129465, 57.61578287397112, 55.30025053024292, 50.24127755846296, 42.95083154950823, 42.57300935472761, 42.27425071171352, 42.552981172289165, 41.72939034870693, 41.73135321480887, 41.51695612498692, 41.607935837336946, 42.75852625710623, 45.47971527917044, 49.17051151820591, 50.54612282344273, 52.620198317936485, 53.1127005304609, 51.483893394470215, 53.406998429979595, 54.637305532182964, 53.82634653363909, 51.90528426851545, 54.59334427969796, 55.51135764803205, 54.75870098386492, 52.56762477329799, 54.837820121220176, 54.62848479407174, 55.41772024972098, 54.36695459910801, 49.093327454158235, 40.594940594264436, 40.40360804966518, 39.005932739802766, 38.73680121558053, 39.68113783427647, 45.09348576409476, 47.61362518583025, 48.37474128178188, 43.55488361631121, 39.09843758174351, 40.191795689719065, 49.23838152204241, 53.96992410932268, 54.13551705224173, 51.599855354854036, 51.18147305079869, 49.87663957050869, 51.35342359542847, 50.47064801624843, 51.655044896262034, 50.52272129058838, 49.72095823287964, 47.588441440037315, 48.06404563358852, 49.20776775905064, 49.83148322786604, 50.626252923692974, 50.992416041237966, 52.013676166534424, 49.6067715372358, 50.45892987932478, 51.77917446408953, 49.02799701690674, 50.384167262486045, 50.51069743292672, 47.021093232291086, 14.35463261604309, 0.16240899876824447, 1.415766247681209, 5.075003334454127, 9.359578728675842, 4.875615222113473, 0.30039434667144504, 0.145541391734566, 0.20958736219576427, 0.059362592840833325, 3.2015479547636847, 39.36327164513724, 43.963298729487825, 19.14370107650757, 46.3668578011649, 7.654437814440046, 0.2460360920854977, 0.04097668227872678, 0.08551378707800593, 0.023499694819163, 0.020015700786773647, 0.05555066792294383, 0.025038607152444974, 0.06213710217603615, 0.06231583508529833, 0.05161819786631635, 0.003100916273459526, 0.017168761231005192, 0.031141174691064016, 0.043307063302823474, 0.03300813326079931, 0.07634884172252246, 0.03462595073506236, 0.004705575045331248, 0.03476399529193129, 0.09359277106289353, 0.044187540521046946, 0.020776309704940234, 0.04475423600524664, 0.041327861470303366, 0.09094337679977928, 0.07466813762273107, 0.15644908643194608, 0.11941695213317871, 0.13413046832595552, 0.0924987011988248, 0.12301713680582387, 0.06577104396585907, 0.22288104386201926, 0.1667741366795131, 0.13218459274087632, 0.09842394718102046, 0.1653514387352126, 0.08312721656901495, 0.11793078402323381, 0.13840318976768426, 0.11014606710523367, 0.14681962957339628, 0.15601890880082334, 0.1263468845614365, 0.10001150877880198, 0.10519343321876866, 0.10682674843285765, 0.10287802067718335, 0.11690342772219862, 0.1340884534376008, 0.15725665166974068, 0.07273650448769331, 0.23279499688318797, 0.12124782960329737, 0.08708248540226902, 0.5987962973969323, 41.36293888092041, 62.892210142953054, 30.377180303846085, 55.811797755105154, 43.7375031198774, 1.25301251241139, 0.2817470372787544, 0.28730328913245884, 1.236714209829058, 7.272306868008204, 9.587223427636282, 8.333256840705872, 12.042501415525164, 8.349203824996948, 0.779574202639716, 1.6939117567879813, 30.71451881953648, 61.3461525780814, 62.486921719142366, 60.403295925685335, 56.751854283469065, 60.79918343680245, 57.19783135822841, 59.68696444375174, 58.80839252471924, 58.264501435416086, 56.77035733631679, 63.11335045950753, 57.35419014522007, 47.10965149743216, 46.77481433323452, 56.416760035923545, 62.05762032100132, 60.98299108232771, 57.17597232546125, 52.13877848216465, 59.364345686776296, 58.665030343191965, 57.297972270420615, 52.76950120925903, 45.77290841511318, 44.173992429460796, 44.37765107836042, 45.01636075973511, 44.36570365088326, 43.64900391442435, 44.05272551945278, 45.47368771689278, 45.237316949026926, 49.33521856580462, 51.486492020743235, 52.6108842577253, 52.66793244225638, 54.143187863486155, 54.53970766067505, 55.21162625721523, 55.17870569229126, 53.63000086375645, 54.18525573185512, 56.620654923575266, 58.08959443228585, 55.98324802943638, 54.55570936203003, 55.62423460824149, 56.47964123317173, 56.59550244467599, 56.18816430228097, 50.88518796648298, 41.54396377290998, 42.73076125553676, 42.08775063923427, 40.06863192149571, 42.21914107458932, 49.193339824676514, 49.47210502624512, 52.6743734223502, 45.01695135661534, 42.126698766435894, 42.877010413578574, 53.22915233884539, 56.561904430389404, 56.188351903642925, 52.8771322795323, 53.63675103868757, 50.726883683885845, 53.02875934328352, 52.53323119027274, 54.80127259663173, 50.849964073726106, 51.13818577357701, 49.21600137438093, 50.7050906590053, 51.592549324035645, 50.747867243630544, 52.22222287314278, 54.04226875305176, 53.73553010395595, 52.20978559766497, 53.82124655587332, 54.70804514203753, 52.320727484566824, 52.0609586579459, 51.77395289284842, 46.45803901127407, 15.080358062471662, 0.33005864918231964, 3.259722398860114, 6.71571056331907, 15.746980394635882, 14.780934129442487, 6.24629591192518, 0.6252646999699729, 0.4959006415946143, 0.21926137166363852, 4.437267269407, 48.13759231567383, 45.08150706972395, 31.373312268938335, 54.03066178730556, 8.850704823221479, 0.49412195703813006, 0.23886717962367193, 0.2388027459383011, 0.08425713343811886, 0.22765889391303062, 0.14492072218230792, 0.12175366388899939, 0.13486709951290063, 0.1713231440101351, 0.1130113440698811, 0.11783175862261228, 0.14529026592416422, 0.12346391140350274, 0.12529092122401508, 0.14362113763179096, 0.10424753504672221, 0.11073013647858586, 0.14853352760629995, 0.09386545393083777, 0.1523914063083274, 0.17498770808534964, 0.11693073197134904, 0.14148151315748692, 0.12779460687722477], [0.04115146611418043, 0.025765111204236746, 0.02021484063672168, 0.08458154103053467, 0.022399183961429765, 0.050273785899792395, 0.024645752340023006, 0.06206004773931844, 0.016659449453332593, 0.02520852249913982, 0.03511252480426005, 0.11667872406542301, 0.07025077965642725, 0.0035801136067935397, 0.05425236241093703, 0.05767945958567517, 0.052574989918087206, 0.010607188500996147, 0.07107175953154053, 0.039728059100785425, 0.03212861616962722, 0.04250427834423525, 0.03089721081778407, 0.01748263117458139, 0.018005615432879755, 0.03424540115520358, 0.08398748362170798, 0.008716825562130128, 0.11621350688593728, 0.062364350339131694, 0.038730588874646595, 0.1699849779584578, 4.612450463431222, 44.84937122889927, 32.14173092160906, 25.21517596926008, 54.972587381090435, 19.319389751979283, 0.09335001837462187, 0.06556252336927823, 0.032878146307276826, 0.30470841803721016, 3.9472685796873908, 1.862077270235334, 0.6417293793388775, 2.2280147884573256, 0.7048747166991234, 0.061913165263831615, 3.1716631012303487, 36.22868912560599, 51.23594692775181, 54.92435993467058, 58.49649483816964, 55.13196168627058, 59.163230078560964, 56.42482689448765, 56.44082164764404, 58.842973709106445, 58.61960996900286, 54.69817175183977, 51.68116317476545, 42.52170385633196, 42.9801355770656, 52.614771774836946, 56.52937991278512, 55.46152169363839, 54.41618258612496, 52.49803509031023, 56.691443170819966, 55.15525899614607, 53.77004875455584, 47.93043177468436, 39.3820561000279, 39.923324244362966, 39.826501096997944, 39.72137137821743, 39.86483778272356, 38.93099294389997, 40.83216251645769, 41.26706068856375, 42.68725511005947, 45.49935783658709, 45.45654303686959, 47.42200081689017, 49.2356230872018, 51.309927872249055, 49.500366824013845, 52.76956026894705, 53.570708411080496, 53.62939289637974, 49.672095026288716, 54.731926100594656, 50.98976182937622, 54.77450813565935, 50.236844607761924, 49.861561979566304, 50.152285030909944, 47.49382781982422, 43.84985549109322, 38.04696321487427, 37.82396078109741, 39.44178628921509, 38.6491253716605, 38.07749707358224, 42.41644906997681, 47.77127981185913, 49.94045182636806, 48.78428200313023, 44.072694642203196, 37.50521217073713, 37.327115944453645, 48.74879060472761, 52.25874955313546, 52.62014273234776, 52.62068469183785, 50.33058622905186, 52.83538750239781, 49.7944632257734, 51.2975183895656, 48.981867926461355, 49.54346302577427, 48.711054938180105, 49.2452324458531, 47.045161792210166, 48.967770031520296, 50.177635533469065, 49.28876291002546, 50.18726921081543, 49.800761767796104, 47.50934314727783, 47.60277557373047, 50.94147184916905, 49.902893338884624, 50.25528860092163, 43.99375268391201, 18.025332927703857, 0.13417996067021573, 0.11400195769965649, 1.0711853206157684, 5.095272098268781, 9.720974513462611, 5.110759632928031, 0.2987649126776627, 0.10001857232834611, 0.09481958273266043, 1.060452633670398, 24.568510600498744, 44.813039098467144, 15.874069895063128, 33.93617268971035, 24.63624858856201, 0.04638452495315245, 0.06477618949221713, 0.011035318652700101, 0.011091158692059773, 0.04346566068540726, 0.022255466851804937, 0.028990008336092745, 0.03442558612940567, 0.06365947012922593, 0.047933881636708975, 0.03142381166773183, 0.024399481447679654, 0.024661731839712177, 0.009571392920666506, 0.014372311465974365, 0.006771413925369936, 0.023200009650151645, 0.03755043327276196, 0.04190308953236256, 0.055925823149404356, 0.01786886857423399, 0.008349984085985591, 0.040524720280830345, 0.04636430460959673, 0.016317983490547965, 0.03648888219946197, 0.02178449569536107, 0.029010947926768234, 0.05435362697712012, 0.006125016021542251, 0.04316219946901713, 0.05925015958824328, 0.049285747310412784, 0.010496142004350466, 0.017953872048695172, 0.045915636899215836, 0.03856315018076982, 0.055193490481802394, 0.050107310725642104, 0.010260599598820721, 0.04371751592095409, 0.026305659341492822, 0.12895581099603856, 0.056868304897631915, 0.010144755011424422, 0.03124820680490562, 0.023616392664345245, 0.07277421746402979, 0.02792561929007726, 0.03212949147980128, 0.013702234386333396, 0.02452587555827839, 0.04488777169691665, 0.01710660063794681, 0.07172881891684872, 0.019470038191814507, 0.09478442104799406, 7.640411138534546, 55.642591748918804, 27.518359627042496, 31.11364766529628, 64.64346190861293, 14.916283300944738, 0.15064359509519168, 0.12060224424515452, 0.053485278572354994, 0.2658970020711422, 0.7991955354809761, 3.362792193889618, 5.671592167445591, 6.083232981818063, 1.8838618269988467, 0.304024834718023, 5.1812742948532104, 42.388156005314414, 55.72355910709926, 55.55666337694441, 58.915012632097515, 60.35692364828927, 58.679385321480886, 58.027515751974924, 57.565081868852886, 60.207516533987864, 59.92023631504604, 58.567845889500205, 54.628252029418945, 45.475980622427805, 44.28004278455462, 55.26588126591274, 57.57978425707136, 57.30964871815273, 56.12666579655239, 53.08174283163888, 56.11229344776699, 57.80909218106951, 53.75510665348598, 50.21030248914446, 41.27119139262608, 42.77806806564331, 39.365283148629324, 42.13056196485247, 42.55103915078299, 42.24055889674595, 43.020723479134695, 41.65995352608817, 44.119900703430176, 49.33173404421125, 48.18614980152675, 50.14558349336897, 52.00205877849034, 53.596194403512136, 52.910563537052695, 55.39490583964756, 56.634176118033274, 53.473464897700715, 51.25556864057268, 56.06390271868025, 53.43957158497402, 54.52733986718314, 54.54667322976248, 51.92613581248692, 52.920013087136404, 50.4541460445949, 46.88859803336007, 40.23428392410278, 39.57799877439226, 40.84031622750418, 39.57112005778721, 39.8618118422372, 43.67401395525251, 48.70977299554007, 51.39891692570278, 50.94034971509661, 46.00888313565935, 39.794737407139365, 39.41396222795759, 49.63188580104283, 54.02276168550764, 53.35769401277815, 52.04261541366577, 51.70526647567749, 52.93255458559309, 51.09382152557373, 52.13450881413051, 50.57987717219761, 51.130740778786794, 50.06449801581246, 51.06492049353463, 49.516153131212505, 51.59260490962437, 51.50279596873692, 52.02111073902675, 50.282518591199604, 50.15914290291922, 50.21461384637015, 50.30745220184326, 50.953294209071565, 49.97665888922555, 52.654981000082834, 46.742817878723145, 21.466397012983048, 0.5273116018090929, 0.8593060842582158, 3.096293385539736, 6.708988615444728, 6.334956228733063, 0.7224735809223992, 0.056127660176051516, 0.04329455790242978, 0.05483296447034393, 1.3570217256035124, 23.676820482526505, 53.966571603502544, 20.11036573137556, 34.85242816380092, 33.9757843698774, 0.04814700609339135, 0.08637088537216187, 0.019425388891249895, 0.047062856411295276, 0.04419720625238759, 0.027153695800474713, 0.0631033428279417, 0.031136502977460623, 0.06320500772978578, 0.04814048197918704, 0.02178247705368059, 0.04368614385436688, 0.043244655044483285, 0.03561771787436945, 0.05391504568979144, 0.04259698319115809, 0.03608661949900644, 0.026123973108561974, 0.04388633204091873, 0.011048798599014325, 0.014198765108760978, 0.01670116408994155, 0.06566355723355498, 0.016378937987610698, 0.019109987154869095, 0.10793535251702581, 0.10349478186773402, 0.06265122137431588, 0.16861941266272748, 0.06057196616062096, 0.15438021958938666, 0.10411840304732323, 0.17456899769604206, 0.08794098826391356, 0.13874943261700018, 0.08697843205715929, 0.30982332357338493, 0.2147266271391085, 0.14446766435035638, 0.15414513434682572, 0.22751219464199884, 0.11639562568494252, 0.2723503586437021, 0.1922702392829316, 0.08067995788795607, 0.08950486898954425, 0.09556272107043437, 0.13604232216519968, 0.13913193637771265, 0.1010755534682955, 0.07351622264832258, 0.1638343972819192, 0.12750424817204475, 0.1861310444240059, 0.17760762678725378, 0.11467756144702435, 0.35441963055304115, 9.223981159073965, 61.08025196620396, 41.933313029153005, 35.251268659319194, 67.97061375209263, 28.649350915636333, 0.26613758344735416, 0.20792113803327084, 0.19316213285284384, 1.3083000885588782, 9.51017051083701, 8.54086206640516, 2.8408604519707814, 4.036314521517072, 2.3995525666645596, 0.639669347022261, 4.660141595772334, 42.13998024804251, 58.49712017604283, 58.13376760482788, 62.056251525878906, 58.678002629961284, 61.64025592803955, 58.74741513388497, 59.4222172328404, 63.08972658429827, 62.27860082898821, 60.14002868107387, 57.20402915137154, 47.51220580509731, 46.78820698601859, 58.08080843516758, 60.01473181588309, 58.44269493647984, 56.12291029521397, 53.47383662632534, 59.38926887512207, 60.56997626168387, 56.05232007162911, 53.16285262789045, 43.07672943387713, 45.408913135528564, 42.30509723935808, 44.11475903647286, 45.46755245753697, 44.01285675593785, 46.38229322433472, 45.14043126787458, 47.45960099356515, 52.10909577778408, 50.583927971976145, 53.32493325642177, 55.2548371042524, 56.768953800201416, 55.44323056084769, 57.875391892024446, 57.56081567491804, 55.30236973081316, 53.09211996623448, 58.85004697527204, 54.98381219591413, 57.169910022190635, 54.980219977242605, 53.548710414341514, 55.58914967945644, 50.885792459760395, 49.29339735848563, 42.00252056121826, 42.09568200792585, 44.16055113928658, 43.35770763669695, 41.76533685411726, 46.30454288210188, 50.038219928741455, 52.88462243761335, 52.23282929829189, 48.41544382912772, 41.687193938664024, 40.68276582445417, 50.93872036252703, 56.772580759865896, 54.46613318579537, 55.34039722170149, 54.05553633826119, 56.89010259083339, 54.77223607472011, 55.36030381066458, 52.503336565835134, 54.108287061963765, 51.60892970221383, 54.54964011056082, 51.0270528112139, 53.31578595297677, 53.984049797058105, 52.857604367392405, 52.14154039110456, 51.93591887610299, 50.663943426949636, 51.26932259968349, 53.633169242313926, 52.599517004830496, 52.328710964747835, 47.46872397831508, 21.11867094039917, 0.32013911860329763, 0.6493792374219213, 3.443363287619182, 11.942850351333618, 19.6677394253867, 10.935857483318873, 0.405201082783086, 0.22225904438112462, 0.17440659712467874, 2.297949058668954, 35.40648794174194, 55.5728040422712, 25.198583671024867, 45.217455523354666, 36.56826148714338, 0.217077303145613, 0.11674276420048305, 0.15633131989410945, 0.1293372426714216, 0.10258806909301452, 0.16350228153169155, 0.11594813184014388, 0.20131781165088924, 0.13475416414439678, 0.1317582284765584, 0.12795521611613886, 0.08892355446836778, 0.10406042222997972, 0.17222935466894082, 0.11083037645689078, 0.08117082369114671, 0.12813645281961986, 0.12421852376844202, 0.08426845818758011, 0.14012170183871472, 0.09396238944360188, 0.10934692248702049, 0.15845843218266964, 0.08679761604538985, 0.06127325924379485], [0.050908012581723075, 0.0578524453033294, 0.03154160873964429, 0.04826683537768466, 0.030543317486132895, 0.10181419311889581, 0.009394372464157641, 0.04461147223732301, 0.07086045015603304, 0.005818580277264118, 0.04618061160934823, 0.03378387859889439, 0.03730133967474103, 0.04108992638066411, 0.05998859567833798, 0.044961039908230305, 0.041202217140900235, 0.029968859561319863, 0.024169159520949637, 0.026540283180241073, 0.04306325549259782, 0.0908016919025353, 0.10562189415629421, 0.028769878005342822, 0.06240924221596547, 0.052489233269755325, 0.0387150232813188, 0.02395439979487232, 0.02334837642099176, 0.07886006589978933, 0.020008238597906063, 0.0530618625426931, 0.04458051407709718, 14.854373114449636, 47.708221435546875, 31.076790945870535, 36.32794066837856, 54.17287751606533, 14.611556155341011, 0.02732340249765132, 0.14964362446750912, 0.03450334284986768, 0.1922009065747261, 3.0989890694618225, 12.321407318115234, 8.246229784829275, 1.285054998738425, 0.23758496556963238, 0.10213395953178406, 8.595295122691564, 43.081127643585205, 56.80387544631958, 56.52775056021554, 59.3242198399135, 58.96717970711844, 60.15234783717564, 61.17212799617222, 58.20350667408535, 57.48265191486904, 57.71845987864903, 48.51868711199079, 40.99426746368408, 45.7038711139134, 56.713350840977256, 56.99255725315639, 56.30728421892439, 53.39371347427368, 54.30380589621407, 54.108474663325715, 57.69676760264805, 54.43384143284389, 47.69731971195766, 40.28455761500767, 40.12433910369873, 38.94255822045462, 42.08047240121024, 41.64869744437081, 40.795222418648855, 39.90142352240426, 40.30729559489659, 43.37896565028599, 46.73732532773699, 48.05637829644339, 49.33340161187308, 48.770840712956016, 51.744638442993164, 51.892919949122835, 55.94631487982613, 56.92599351065499, 53.94787400109427, 51.70888648714338, 54.256106512887136, 49.66829783575875, 47.18828773498535, 43.67622000830514, 41.30575173241751, 39.42026424407959, 39.21326003755842, 37.44265406472342, 38.87056793485369, 37.355346475328716, 37.85566888536726, 36.90547146115984, 40.915686811719624, 45.53467205592564, 55.02353157315935, 55.08424493244716, 53.10429321016584, 47.82906450544085, 38.84993873323713, 38.93879229681832, 47.25122799192156, 54.24043485096523, 53.60953841890608, 54.44920737402779, 52.457666056496755, 51.890863282339915, 49.95104088102068, 49.379329204559326, 51.06135606765747, 51.40403427396502, 47.98994309561593, 48.26817675999233, 48.678665910448345, 51.2334177834647, 49.50010974066598, 50.40330260140555, 51.92733090264456, 51.74828624725342, 48.79960625512259, 47.282925673893516, 55.27480622700283, 51.05496372495379, 44.389219829014365, 18.22933724948338, 1.1284044959715434, 0.22978042864373752, 0.1757512499711343, 1.8980370206492287, 4.881468645163944, 4.0865113479750494, 1.5950335711240768, 0.08537970177297081, 0.009114127323430563, 2.1276765039988925, 21.437094722475322, 47.74173954554966, 21.032217979431152, 28.794147900172643, 33.073129994528635, 1.7048996814659663, 0.04937592461439116, 0.03344566621152418, 0.04750544444790908, 0.02077802300586232, 0.04858100387666907, 0.013137437103848373, 0.018942195622782623, 0.008090348598281187, 0.052960085682570934, 0.03020431799814105, 0.031526524906179736, 0.027999499879245247, 0.06239573936909437, 0.03924681831683431, 0.024179030509133424, 0.030740676181656972, 0.043973449151962996, 0.007224174898250827, 0.009931745905695217, 0.03605172583567245, 0.036788835389805694, 0.030235486504222666, 0.03026210204032915, 0.01366986911411264, 0.019873707156096185, 0.08044834674469062, 0.040991474342133315, 0.031443105810987096, 0.052859363944402764, 0.05862687089081321, 0.03716729168913194, 0.015511222316750457, 0.016249324228348475, 0.0256366899702698, 0.009856934875382908, 0.020800470640616756, 0.03063044138252735, 0.02203682081640831, 0.021378350078261325, 0.013422166512879943, 0.040020236279815435, 0.05492356925138405, 0.035505043741847785, 0.03219020000791975, 0.0446951661391982, 0.0708873269281217, 0.011975014166507338, 0.037496340461075306, 0.07454776551042284, 0.0713552243209311, 0.002028980857825705, 0.05069421298269715, 0.02150074252858758, 0.076541450672916, 0.050247319641390016, 0.05187428716037955, 0.051171681111944575, 0.11636247246393136, 22.808443307876587, 53.84391505377633, 25.052133015223912, 50.41017089571272, 61.48008605412075, 10.044104831559316, 0.055430367056812556, 0.029088962490537336, 0.024507261646379317, 0.0496755656786263, 0.5518974225435938, 6.726959696837834, 8.466432094573975, 3.369677858693259, 1.4722673701388496, 0.07397980455841337, 11.929303101130895, 51.0896178654262, 58.10290370668684, 60.58107948303223, 59.69036211286272, 61.80028683798653, 62.883017676217214, 62.3521614074707, 59.54235853467669, 59.76415198189871, 59.809697423662456, 52.036563532693044, 42.92086049488613, 46.97233077457973, 58.38392012459891, 58.353313309805735, 57.5946603502546, 54.97027710505894, 53.826190199170796, 55.5784911428179, 58.03187574659075, 55.75800827571324, 48.61110510144915, 42.06075688770839, 42.36042921883719, 41.032541615622385, 43.644536222730366, 43.193855217524934, 42.116762842450825, 41.97791351590838, 41.27836193357195, 45.70373909814017, 47.790043422154014, 49.79960836683001, 50.43351336887905, 51.05913264410836, 50.98206669943673, 52.685431480407715, 56.09295661108834, 59.11051409585135, 54.05599839346749, 55.4098653112139, 57.50049488885062, 53.173848152160645, 51.83915131432669, 47.50596979686192, 46.127898829323904, 44.57290588106428, 41.660203661237446, 40.46597508021763, 40.47323247364589, 40.0336651120867, 39.211470876421245, 39.435720511845176, 40.83548028128487, 46.50125333241054, 54.96176208768572, 56.168184757232666, 55.126667158944265, 48.68425226211548, 40.08782632010323, 42.07175588607788, 48.421916076115195, 55.920377254486084, 53.59826149259295, 54.60270350319998, 53.834944929395405, 52.71433251244681, 50.761252948216026, 51.02930055345808, 51.54658351625715, 53.362099170684814, 50.57281085423061, 50.23375265938895, 50.07673726763044, 51.936311449323384, 51.12680809838431, 52.33885186059134, 52.20155198233468, 52.53889397212437, 48.7969902583531, 50.320229939052034, 53.975138732365195, 53.79288400922503, 46.19600159781319, 24.02781741959708, 1.7805015104157584, 0.7464910064424787, 1.5536416321992874, 4.011885958058493, 5.6429556012153625, 0.951118386217526, 0.10063484497368336, 0.14291259779461793, 0.07553584820457868, 2.3112633270876746, 21.69429271561759, 53.78331286566598, 29.693626948765345, 23.389477729797363, 44.182378905160085, 3.9417078495025635, 0.12306736196790423, 0.00868549251130649, 0.02278928392167602, 0.033028200933975835, 0.04086668835952878, 0.023608718433284333, 0.05366168749917831, 0.016159932328654186, 0.038945392705500126, 0.03468976016821606, 0.044194458185562065, 0.0875399469264916, 0.04332260854010071, 0.09449826247457947, 0.06621770321258477, 0.015218461597604411, 0.06396901780473334, 0.02189940051175654, 0.03644110654879894, 0.043235172517597675, 0.057048489871834, 0.02508981110128973, 0.04431273701733776, 0.034852153954229186, 0.030061747612697736, 0.26933858596852844, 0.08331749814429454, 0.09475957309561116, 0.14812070690095425, 0.1471143580440964, 0.23911538773349353, 0.12954334089798586, 0.12224010564386845, 0.14523210190236568, 0.14429854628230843, 0.09490521385201386, 0.07795701042882033, 0.15290983420397553, 0.1426352805324963, 0.06713647355458566, 0.13788279412048204, 0.13828034778790815, 0.15323448606899806, 0.18448039942554065, 0.12165268430752413, 0.12053397005157811, 0.1809538493731192, 0.1261621873293604, 0.20429997305784905, 0.12797093098717077, 0.07482584951711552, 0.20769959634968213, 0.16315713790910585, 0.21403711342385837, 0.12288790302617209, 0.12871094127850874, 0.1347235215029546, 0.17236954000379356, 27.22983741760254, 65.38894803183419, 41.52280650820051, 48.543676308223176, 66.21529729025704, 21.363332646233694, 0.13172405745301927, 0.2567940748163632, 0.17463910393416882, 1.4589394224541528, 8.391143151691981, 31.310080187661306, 18.445627723421367, 5.743917269366128, 0.9403378218412399, 0.12691290490329266, 11.62704517160143, 49.54702050345284, 60.338107926504954, 60.77287755693708, 64.38637856074742, 64.64758219037736, 63.95249135153634, 66.50273731776646, 64.16220188140869, 61.52155985151018, 63.25506591796875, 54.00712129047939, 45.29731464385986, 49.63125351497105, 60.66568769727434, 60.5556629725865, 60.33427946908133, 54.23057883126395, 55.786426407950266, 55.63435813358852, 61.02347823551723, 59.121193477085654, 52.983359813690186, 45.887244497026714, 44.507096018110005, 43.41728149141584, 47.111979143960134, 46.28960772923061, 45.25538573946272, 44.251030581338064, 44.5084787096296, 48.41360255650112, 49.97760731833321, 50.41029248918806, 54.261807509831016, 53.64350816181728, 54.18132305145264, 55.561429841177805, 60.060513496398926, 61.57614489964077, 55.81576517650059, 57.7350869178772, 60.162360191345215, 55.92791952405657, 53.00334630693708, 47.966746534620015, 47.18499428885323, 45.36674451828003, 43.4057822227478, 40.47456305367606, 42.409139565059114, 41.71642848423549, 41.539992877415244, 40.79471172605242, 43.53912162780762, 49.163764817374094, 58.699208532060894, 58.74850600106375, 57.380558558872764, 52.79195083890642, 43.960623673030305, 44.14658873421805, 51.18919249943325, 59.07223646981375, 56.02621568952288, 55.49151011875698, 54.99822275979178, 55.407443864004954, 53.890297753470286, 51.74398183822632, 55.26638848440987, 55.87638473510742, 51.651470048086985, 52.30233907699585, 52.88988222394671, 54.14343105043684, 53.0874160357884, 53.35236474445888, 55.937348229544504, 53.83964538574219, 52.052308150700156, 49.372964654650005, 57.421962874276296, 54.398075580596924, 47.27401808329991, 21.640822853360856, 1.8326362328869956, 1.226761241044317, 0.8022067110453333, 3.6818817002432684, 15.68894556590489, 11.7659535578319, 2.8284366386277333, 0.408346879695143, 0.10007704847625323, 2.8705144950321744, 32.14528145108904, 54.78399590083531, 32.329669271196636, 37.120000566755024, 48.93613140923636, 4.5840922594070435, 0.43786467292479103, 0.14667576657874243, 0.10509556132767882, 0.14219533199710505, 0.11947888880968094, 0.12774919931377682, 0.08585348206439189, 0.10615759755351714, 0.15083127788134984, 0.08258297720125743, 0.13089722182069505, 0.20329545624554157, 0.13404406367668084, 0.17786167029823574, 0.21024020787860664, 0.10734875220805407, 0.12461161267544542, 0.15273717418313026, 0.24977140022175653, 0.07664214526968342, 0.22993570459740503, 0.11260230958993946, 0.13270764824535164, 0.10371922768120255, 0.16740670773599828], [0.01979026261584035, 0.02302731230988034, 0.023672590630927255, 0.017513825125726204, 0.04405327879690698, 0.04729929533121841, 0.08454535475799016, 0.09487464584942375, 0.01816658259901617, 0.052988835211311064, 0.0326188102231494, 0.0761115580265011, 0.04084031370335391, 0.01353353531365948, 0.0221390387242926, 0.04000841619979058, 0.08751994371414185, 0.04617026395031384, 0.026827790342005234, 0.048767617970172844, 0.07940143506441798, 0.01905879338404962, 0.0036985514702142347, 0.03407600149512291, 0.016372206920225705, 0.05419176584109664, 0.039066487457603216, 0.03622501689408507, 0.045303367610488615, 0.055407880406294546, 0.030994892719068697, 0.020816938685519353, 0.04836800494896514, 0.20890455240649836, 28.809110845838273, 43.984490735190256, 24.734777518681117, 31.461877482278005, 52.265788078308105, 13.281208021300179, 0.554874834205423, 0.027261168962078433, 0.0005825711362246823, 0.6701625479119164, 5.641848232064929, 9.104798708643232, 2.1235416744436537, 1.1578484645911624, 0.14743677074355738, 0.07420830122594323, 11.529425586972918, 46.83684090205601, 61.60437543051583, 61.24306215558733, 64.16594696044922, 61.12375463758196, 58.82367161342076, 57.68481322697231, 57.48443760190691, 52.94878557750157, 48.558826855250764, 44.438503401620046, 51.383828912462505, 56.00418642589024, 55.74900688443865, 57.764179025377544, 53.433832372937886, 57.627438477107454, 57.79445232663836, 55.91417946134295, 53.59340122767857, 44.46026863370623, 39.802310943603516, 42.77017491204398, 39.81904220581055, 40.302080971854075, 39.66167593002319, 39.30597332545689, 40.03092404774257, 40.05679219109671, 41.602266107286724, 46.40594836643764, 49.58696569715227, 50.3437044279916, 51.876157420022146, 49.66332639966692, 54.044495650700156, 54.660946777888704, 56.78943708964756, 52.668067932128906, 47.331288610185894, 58.0270745413644, 52.48505585534232, 51.07246971130371, 43.294864654541016, 40.7684440612793, 41.473828656332834, 40.70445810045515, 39.26481219700405, 42.803050313677105, 39.81235456466675, 40.039800371442524, 39.5728188923427, 42.26679529462542, 50.38172844478062, 56.10892357145037, 56.15566062927246, 53.53193746294294, 48.81192888532366, 38.61777857371739, 36.60197067260742, 45.905598163604736, 52.77402796064104, 53.8003637450082, 54.73938151768276, 53.26777042661394, 54.334996359688894, 52.3018388066973, 52.33497129167829, 51.77644729614258, 51.44965614591326, 53.36109168188912, 50.171941484723774, 49.83792768205915, 50.398900917598176, 51.36259174346924, 54.075495038713726, 49.72372709001814, 47.72569268090384, 48.80339649745396, 49.3426079750061, 49.447678634098594, 46.66264956338065, 21.932065282549175, 1.5882232508489063, 0.19199505262076855, 0.9015984120113509, 2.952148880277361, 7.244626547609057, 3.821528332574027, 0.4743463524750301, 0.009554748456659061, 0.041185365723712106, 3.3978853736604964, 27.058199541909353, 45.26688848223005, 23.373587199619838, 22.93403720855713, 35.77691377912249, 6.227389863559178, 0.11475576939327375, 0.03409076980980379, 0.05028055089392832, 0.038074496401739974, 0.037890484490032704, 0.035709404918764315, 0.02460878575220704, 0.07928041834384203, 0.028763299608337026, 0.015049348618569118, 0.061184276161449294, 0.07116104795464448, 0.04581955634057522, 0.06079264610473599, 0.032437997604055066, 0.03845929361081549, 0.040148302979235134, 0.08703435691339628, 0.02834068424999714, 0.00998964105799262, 0.016275062757943357, 0.04098884501893606, 0.040739300195127726, 0.03527225194764989, 0.05945977262620415, 0.05952202142881496, 0.04929681421656694, 0.021119049617222378, 0.036697409581393, 0.004153605467373771, 0.06504714209586382, 0.014134477308419133, 0.07054970825889281, 0.03794401411765388, 0.047319108553762944, 0.014217183941842189, 0.056144046796751876, 0.060048842802643776, 0.06428011932543345, 0.027407822431996465, 0.06946240338896002, 0.04464933788403869, 0.03397249437070318, 0.060900316041495116, 0.008716433708156859, 0.027806570321055393, 0.05097769134278808, 0.020558079272242527, 0.060006597212382724, 0.04128383133294327, 0.005921676887997559, 0.01634081619392548, 0.027763337462342212, 0.00728664846558656, 0.04376694041171244, 0.04159031881551657, 0.016457013619531478, 0.03687954195109861, 0.051964932653520785, 1.685103178024292, 41.19842290878296, 45.874709946768625, 25.714192117963517, 52.472107887268066, 56.090166909354075, 11.395033529826573, 0.20207306183874607, 0.041036467999219894, 0.09126135866556849, 0.37538305137838635, 0.27792604374034063, 3.778841640268053, 5.879603862762451, 2.3094539727483476, 0.8210939775620187, 0.37455711141228676, 16.161063500813075, 50.883013180324006, 63.531319345746724, 61.231958934238975, 67.88023853302002, 60.778832163129536, 62.434038979666575, 59.674541064671104, 59.07524503980364, 53.49181509017944, 50.86190455300467, 46.5181166103908, 53.16240446908133, 58.201720987047466, 60.25539657047817, 57.14264529091971, 54.105816977364675, 58.986384528023855, 59.86180196489607, 59.177988052368164, 56.433595521109446, 47.50743586676461, 41.67170640400478, 44.002212115696494, 40.816195556095664, 42.09708554404122, 42.29545661381313, 41.111827509743826, 41.66289608819144, 42.73879337310791, 43.4684271812439, 48.794200556618826, 51.777465207236155, 51.339145047324045, 55.02139152799334, 53.05632632119315, 55.368367195129395, 55.41638272149222, 57.928993770054404, 55.11721413476126, 52.21945054190499, 58.73646477290562, 56.03184373038155, 50.73512772151402, 46.58064692361014, 41.68587378093174, 42.00090510504586, 42.92935814176287, 41.19709232875279, 42.97713395527431, 40.76210730416434, 41.760841369628906, 41.25041280473982, 43.88100773947579, 51.14329617364066, 58.16031319754464, 57.199710845947266, 54.996374538966585, 49.30730070386614, 41.04982525961739, 38.79268905094692, 48.54651117324829, 54.20900814873831, 55.22477224894932, 54.65399163109915, 54.868989740099224, 54.474867071424214, 53.15465027945382, 53.2669540132795, 53.261367661612375, 52.43245799200875, 53.09570871080671, 51.668044975825715, 51.45012167521885, 52.17023645128523, 51.77874020167759, 54.41666201182774, 50.556631973811555, 49.009935174669536, 50.756802627018516, 51.13185943875994, 51.35789476122175, 47.918262004852295, 25.030663081577845, 2.602655576808112, 0.5715131099734987, 1.9282521307468414, 3.349478793995721, 7.842509916850498, 1.7360002526215144, 0.27852415878857884, 0.0981149287628276, 0.01574236187817795, 3.268037872655051, 25.49305874960763, 46.57278503690447, 34.71364484514509, 18.9865015574864, 42.35073300770351, 13.630501781191144, 0.07750628675733294, 0.01186249524887119, 0.05453619700191276, 0.017235032049939036, 0.046519814657845666, 0.06027845226760421, 0.007700323276886982, 0.12062977919621126, 0.036318943104041476, 0.045833035438720665, 0.08965279640895979, 0.02533817188149052, 0.06636210224990334, 0.07469049535159554, 0.02234953216144017, 0.01944372121111623, 0.07643114802028451, 0.05639740498736501, 0.036956755843545706, 0.031734719805951626, 0.04482109545330916, 0.026827052435172454, 0.12783339193889073, 0.016774369536765983, 0.06675273486013923, 0.03948926566434758, 0.14136868635458605, 0.08607102039137057, 0.11646299064159393, 0.10568217520735093, 0.09358666424772569, 0.13427609551165784, 0.21249663537102087, 0.1392308125006301, 0.08902737032622099, 0.11325434103075947, 0.21194926117147717, 0.15395287823464188, 0.1699893612946783, 0.10116664000919887, 0.19112266014729226, 0.11687553993293218, 0.22336356368448052, 0.12704463569181307, 0.1044413721454995, 0.13823685369321279, 0.27918773889541626, 0.1468432561627456, 0.15762498761926377, 0.09769296140543052, 0.066657760313579, 0.11154504346528224, 0.11544889291482312, 0.13368677427726133, 0.10539032372512988, 0.14485338436705725, 0.14929073197501047, 0.17706388953541005, 0.1300056946596929, 1.773965209722519, 47.56718690054757, 57.286278452192036, 35.95957497188023, 42.44720179694039, 64.62632070268903, 20.509110689163208, 0.876782703612532, 0.09448377575193133, 0.2753896526992321, 1.5342341193131037, 14.912081377846853, 20.034513984407695, 5.201932157788958, 4.902372734887259, 0.8971045017242432, 0.31810356783015387, 13.559869868414742, 49.89773777553013, 66.53861781529018, 61.80339963095528, 69.4935268674578, 64.58140754699707, 63.68991892678397, 61.528619221278596, 61.990007400512695, 56.867454937526155, 52.633396421160015, 49.594428062438965, 55.64849771772112, 59.29979692186628, 61.05784402574812, 61.372361183166504, 54.36352218900408, 60.74884373801095, 60.816922187805176, 62.24218532017299, 59.227500915527344, 49.2132568359375, 44.093223094940186, 47.922788756234304, 42.16297183718, 44.494342599596294, 44.050182478768484, 43.2393798146929, 43.9318060193743, 46.1417361668178, 45.81352410997663, 52.541256359645296, 55.146896839141846, 53.85726601736886, 57.72098554883684, 55.983765670231406, 60.85374764033726, 58.794044494628906, 60.00901344844273, 57.917428493499756, 54.11664921896798, 61.77895586831229, 58.62748227800642, 54.00294542312622, 49.4530600139073, 45.07714360100882, 46.43200411115374, 45.26457473209926, 43.72907495498657, 46.780292987823486, 44.858515058244976, 44.04507555280413, 43.932111740112305, 46.638244015829905, 53.25141784123012, 59.68889604296003, 59.460182189941406, 56.54243557793753, 52.07389620372227, 42.32349954332624, 41.3133739062718, 50.12156009674072, 55.412846088409424, 57.0287504196167, 55.70339543478829, 55.99182210649763, 57.520995548793245, 54.868680545261924, 55.534818240574424, 54.202483790261404, 54.63477986199515, 55.71859809330532, 53.979022775377544, 55.03431865147182, 52.85467570168631, 53.57149355752127, 58.306836809430806, 51.58394398008074, 50.66318954740252, 51.53767939976284, 53.409364291599815, 52.59930508477347, 49.53520161764962, 24.431353160313197, 2.211493274995259, 0.5754216888121196, 2.116451906306403, 7.2609105195317944, 16.69947940962655, 10.289227724075317, 2.8127497775214056, 0.16227721369692258, 0.14237077401152679, 5.134260177612305, 39.05275665010725, 52.842571939740864, 34.23637308393206, 30.92975664138794, 49.58378689629691, 16.440945625305176, 0.2841203627841813, 0.1121829953044653, 0.15925112393285545, 0.07344062706189496, 0.21375607778983458, 0.20892171934247017, 0.11491583580417292, 0.26325663232377594, 0.2128250870321478, 0.0882821013884885, 0.1899836984063898, 0.18427507472889765, 0.15042441471346787, 0.1756189220717975, 0.12156081066599914, 0.15735290864748613, 0.2064034180449588, 0.16361113211938313, 0.14825337406780037, 0.11905287738357272, 0.1138107804581523, 0.17844451830855437, 0.2016853197876896, 0.05231208473976169, 0.12667578405567578, 0.173626607550042], [0.030028173699975014, 0.0239682911030416, 0.05076180524857981, 0.09460766267563615, 0.0716194390718426, 0.01941255440137216, 0.0454547894852502, 0.015419277429048504, 0.05414767124290977, 0.02815287254218544, 0.02973370985793216, 0.007862963031844368, 0.09223023881869656, 0.03270773563001837, 0.04527522876326527, 0.04285633623866098, 0.03056958018402968, 0.08349770347454719, 0.04953388078138232, 0.03979774803987571, 0.08629267064056226, 0.030778005785707916, 0.06624307363693203, 0.011386485121745085, 0.03660611608730895, 0.034811855759471655, 0.029187356853591542, 0.12779825739562511, 0.049881433203284226, 0.012865617671715361, 0.06794962313558374, 0.060327001448188505, 0.03347264815654073, 0.09052514817033495, 4.000760155064719, 43.61919961656843, 38.22436809539795, 24.540118524006434, 34.53106008257185, 55.255097661699565, 18.108457701546804, 1.328815513423511, 0.05393483516361032, 0.13622050546109676, 0.6914046023573194, 1.7354337573051453, 5.2546442321368625, 2.0843447148799896, 1.0102540701627731, 0.07872500350432736, 0.34788072428533007, 12.28690082686288, 49.357994760785786, 61.34948076520647, 63.0018527167184, 58.318412508283345, 60.785363469805034, 55.960346766880576, 54.839407784598215, 52.09245831625802, 48.92178337914603, 48.36477756500244, 53.70047991616385, 57.14489998136248, 60.77644893101284, 57.67607934134347, 56.58074794496809, 54.31870630809239, 59.49804292406355, 54.80661228724888, 52.838343960898264, 43.43847697121756, 42.065620626722065, 42.30830035890852, 40.38993399483817, 41.07392161233084, 42.22525896344866, 41.02686841147286, 41.729720388139995, 39.528968811035156, 41.29475620814732, 43.63378735951015, 51.37114497593471, 47.81901046207973, 50.274903365543906, 48.54480191639492, 57.499285902295796, 53.25576741354806, 59.04987716674805, 41.952573435647146, 29.027320759637014, 62.17262690407889, 50.6770407812936, 54.13212980542864, 50.80549907684326, 51.70398105893816, 47.8893574987139, 48.61218554633004, 41.85322461809431, 40.81662287030901, 38.98379577909197, 40.31846135003226, 39.39096369062151, 46.29774406978062, 52.611992495400564, 57.66591412680489, 56.2744574546814, 56.953088011060444, 50.839784962790354, 41.85027163369315, 40.46921641486031, 44.2652987071446, 52.32231167384556, 53.76333679471697, 56.54267529078892, 55.377611773354666, 55.14743879863194, 53.58394125529698, 53.16655601773943, 53.39035054615566, 53.17698873792376, 50.33542217527117, 50.32552446637835, 50.21771969114031, 51.157838753291536, 51.148086956569124, 50.75706318446568, 49.952388831547324, 51.23195171356201, 48.08754791532244, 50.47587653568813, 46.358811787196565, 21.87463321004595, 1.8644678848130363, 0.06444954273423978, 0.5162397016371999, 1.33421947487763, 7.201006191117423, 3.537246261324201, 0.5623995704310281, 0.10675457266292401, 0.07266474940947124, 2.75778865814209, 28.313815457480295, 45.98154197420393, 33.577906199863975, 27.58735523905073, 38.796312536512104, 18.809904405048915, 0.11448569888515131, 0.10568603607160704, 0.029969534703663418, 0.022522763848038654, 0.059332269110849926, 0.021351530981649245, 0.020204957774175063, 0.04287385940551758, 0.03914921444707683, 0.00435667233874223, 0.10275112784334592, 0.08667330842997346, 0.046894840962652645, 0.011158857827207871, 0.07202640401997737, 0.0370136917169605, 0.04826098979849901, 0.05389540210100157, 0.06813423215810742, 0.030385001695581844, 0.020240216150081584, 0.03080102169354047, 0.023519411350467374, 0.024205512034573724, 0.08297528579298939, 0.04111158521845937, 0.04699914875839438, 0.035520236140915325, 0.07552061509341002, 0.04403431713581085, 0.0217824227708791, 0.07133914304098912, 0.01860320970549115, 0.07121606357395649, 0.020537433147962605, 0.017557823032672917, 0.015278952994516917, 0.03704236660684858, 0.04286400368437171, 0.04545926781637328, 0.07103033496865205, 0.03351569781079888, 0.041880867510501824, 0.011780669862803603, 0.05954662510859115, 0.059837316295930316, 0.026672181906178594, 0.011935436915207123, 0.04957562764840467, 0.054775580763816833, 0.031465015706739256, 0.03846985161570566, 0.04249532168198909, 0.03289391885378531, 0.03751212657828416, 0.08004504588565656, 0.022084160508321862, 0.04508668423763343, 0.054917798311050446, 0.03160136053338647, 0.08479356286781174, 7.674058658736093, 55.06979962757656, 37.24277523585728, 21.483915158680507, 53.066932746342246, 61.49555969238281, 15.80752352305821, 0.7805384823254177, 0.0690388957570706, 0.08547779758061681, 0.1960929020174912, 1.4248020542519433, 4.803160275731768, 5.016245024544852, 3.164093255996704, 0.09246846567839384, 0.6658369143094335, 17.16075815473284, 54.018596240452354, 65.40511648995536, 62.76411315373012, 62.60606248038155, 61.808958189828054, 56.64912864140102, 57.04866395677839, 56.37431001663208, 50.442667620522634, 50.76032883780343, 55.83848231179373, 59.903859410967144, 62.10181781223842, 58.45714718954903, 55.26948390688215, 55.89645113263811, 61.05182688576834, 57.40853548049927, 56.01917716435024, 46.773407323019846, 43.73456403187343, 44.497010707855225, 43.278098651341026, 43.394029344831196, 44.18471697398594, 42.848748615809846, 44.11327559607369, 42.08955022266933, 43.73236492701939, 45.632718086242676, 52.914138385227744, 51.90270301273891, 52.79400403159005, 50.47584179469517, 58.40998976571219, 56.43918187277657, 61.077382360185894, 44.01537547792707, 35.1188394682748, 64.48597403935024, 51.67520162037441, 57.04110084261213, 51.081425939287456, 51.60398953301566, 49.791743006025044, 48.577875341687886, 43.35034602028983, 42.90368454796927, 40.561016014644075, 42.57124103818621, 41.076256207057405, 47.78681598390852, 54.41080468041556, 56.968453952244346, 56.83069201878139, 58.35224328722273, 52.553572041647776, 43.27349894387381, 41.56591313225882, 47.93444783346993, 55.58662053516933, 56.04846729551043, 57.50906549181257, 54.90145172391619, 55.02953829084124, 55.27790859767369, 54.0274795123509, 53.967207363673616, 54.88992466245379, 52.30161993844168, 52.94275801522391, 52.293518338884624, 51.46355601719448, 53.24125262669155, 53.04047748020717, 50.92156178610665, 51.6965777533395, 49.12013360432216, 52.2259019442967, 48.14982461929321, 26.446851866585867, 2.9600107669830322, 0.7006857129079955, 2.122973007815225, 0.8050483071378299, 8.863047429493495, 4.546094298362732, 0.3643595171826226, 0.09595591175769057, 0.018200473726860115, 1.7215661300080163, 28.499638080596924, 52.770359311785015, 43.117220061165945, 23.319825513022288, 39.87273441042219, 27.589571714401245, 0.27195599409086363, 0.09107440191188029, 0.03831053498600211, 0.01487266318872571, 0.09154769365808793, 0.033068024154220305, 0.025752415814037834, 0.0317467807659081, 0.03475376298385007, 0.07430882618895598, 0.050589630380272865, 0.023083422066909925, 0.06950593141040631, 0.015978247792060887, 0.031036588695964644, 0.01573994629351156, 0.012750332027540674, 0.017887139825948646, 0.04205746642713036, 0.020443378016352654, 0.013919475854241421, 0.024090337500508343, 0.04256898683628865, 0.015806948233928, 0.051672083724822314, 0.042568077599363666, 0.050046771831278286, 0.13549562650067465, 0.16849890484341554, 0.12683471052774362, 0.17853126222533838, 0.13242037008915628, 0.08127625446234431, 0.15302034041711263, 0.05917718314698764, 0.1530526386840003, 0.05979532176362617, 0.10833185445517302, 0.16353837959468365, 0.15304487624338695, 0.15243545680173806, 0.218369030260614, 0.1674574621553932, 0.12992916948028974, 0.19376560832772935, 0.16318000453923429, 0.1523318173629897, 0.2541779694812638, 0.15674504983638013, 0.11576646087425095, 0.07284266807671104, 0.11160817436341729, 0.126733717375568, 0.1707623212465218, 0.26871381806475775, 0.22681556987975324, 0.07363510198358979, 0.11001624978546586, 0.12247889568763119, 0.08579131468598332, 0.18538461519139154, 8.277160559381757, 61.697397913251606, 51.71146774291992, 35.76413951601301, 47.08001395634243, 69.83741406032017, 26.987131629671367, 2.437049606016704, 0.10327085174087967, 0.46269769753728596, 1.866593165057046, 11.086028899465289, 17.91943543297904, 7.702246631894793, 4.259002549307687, 0.21266240147607668, 1.0251286434275764, 14.67768042428153, 52.59435101917812, 66.77679511478969, 67.03514303479875, 62.42284543173653, 66.98428222111293, 61.25185857500349, 58.43630954197475, 57.743779114314485, 53.869116170065745, 54.378241947719026, 58.34662914276123, 60.88149874550955, 65.61217280796596, 61.10076304844448, 58.221453871045796, 56.77487366540091, 63.54290894099644, 59.061932291303364, 58.34986005510603, 47.87530476706368, 47.25919757570539, 47.579884733472554, 47.23083850315639, 46.74452018737793, 47.59994418280465, 46.44452476501465, 47.03559064865112, 45.72934668404715, 45.42369890213013, 47.86093241827828, 55.596612044743125, 53.738507407052175, 55.02412564413888, 52.11056879588536, 62.03902694157192, 59.616523606436594, 61.88261604309082, 43.366243498665945, 36.64598751068115, 67.65299769810268, 54.00328935895647, 61.02775832584926, 55.67262533732823, 53.687889780317036, 52.10374219076974, 51.11942563738142, 45.87131575175694, 44.41107538768223, 41.8932775088719, 43.96002612795149, 43.475430965423584, 49.06474951335362, 56.66954592296055, 60.9868403843471, 57.07318762370518, 62.3816773550851, 55.50307192121233, 46.7722157069615, 44.30262442997524, 49.78323841094971, 57.737261704036165, 58.329738071986604, 59.0397675377982, 55.590678283146445, 56.70901863915579, 56.73417806625366, 55.404518672398154, 55.82766049248831, 57.90995223181588, 53.39648233141218, 53.51391383579799, 55.48822709492275, 54.02690281186785, 55.973569188799175, 54.51087958472115, 52.985802105494905, 52.80956104823521, 50.51844467435564, 54.36330679484776, 49.19212736402239, 25.36754822731018, 2.8983120662825446, 0.6371707639523915, 2.478611124413354, 4.95712627683367, 14.81483439036778, 10.387996367045812, 3.0959989556244443, 0.27702807049666134, 0.11661973223090172, 4.117067788328443, 38.68354674748012, 57.24536745888846, 44.875725746154785, 37.15623194830758, 50.30825819287981, 33.31396845408848, 0.2597179636359215, 0.20285533129104547, 0.09335507346051079, 0.08610229407038007, 0.1878542248159647, 0.14734838477202825, 0.10638213157653809, 0.1786355259163039, 0.0805985676124692, 0.1940293006066765, 0.2211192548274994, 0.12784070654639176, 0.18344690916793688, 0.19225850062710897, 0.14110643256987843, 0.10232668383313076, 0.14007875057203428, 0.1440600547939539, 0.10346133687666484, 0.11933759067739759, 0.13279654990349496, 0.13808957088206494, 0.0893131692760757, 0.06418070037450109, 0.12876757181116513, 0.1488050501793623, 0.15367603594703333], [0.05680243611069662, 0.06914043173726116, 0.004091927906431789, 0.052383520906525, 0.03960084057013903, 0.035268564109823534, 0.04290134007377284, 0.04995329684710928, 0.013221250597520598, 0.03712163306772709, 0.019995719626811997, 0.022087263109694635, 0.04496516200846859, 0.02731902594678104, 0.027068173246724263, 0.01495321886613965, 0.0346240745857358, 0.050899798915322335, 0.011994075063349945, 0.06953232642263174, 0.05780542282653706, 0.07764546107500792, 0.04233192027147327, 0.01664792962505349, 0.00870443636085838, 0.030104094983211586, 0.08282969931938819, 0.09543384012899228, 0.029978291198079075, 0.04591189477858799, 0.045846205803432634, 0.04052832330177937, 0.09355490880885295, 0.05229424944679652, 0.08512581432504313, 7.715849467686244, 32.83741583142962, 36.348962443215505, 25.788787978036062, 32.66351631709507, 54.397929668426514, 21.270555087498256, 1.110331580042839, 0.006396356662402728, 0.08087621057139975, 0.3089541473558971, 3.901165544986725, 2.8275796217577795, 1.9339290261268616, 1.2778934687376022, 0.12018257033612047, 2.3249719057764326, 22.88983450617109, 51.845543657030376, 66.00249481201172, 58.58935751233782, 57.319282395499094, 56.71367393221174, 54.31429072788784, 51.437458583286826, 48.55508872440883, 52.9566023009164, 59.690396853855674, 57.73322827475411, 57.93231848308018, 60.739908354622976, 58.66467598506382, 60.26641641344343, 58.54417337690081, 54.52298334666661, 47.76664536339896, 40.882432733263286, 43.08532435553414, 40.896367345537456, 40.92696026393345, 40.64277894156319, 43.3475250516619, 39.54836818150112, 42.53514862060547, 40.756701605660574, 43.98251049859183, 43.598382813589915, 49.321367331913535, 48.92669922964913, 52.59669256210327, 50.62011071613857, 53.92759568350655, 52.83251789637974, 59.19826289585659, 45.905615534101216, 34.67709037235805, 62.63106904711042, 52.74065228870937, 56.68523842947823, 53.45989506585257, 53.423111302512034, 54.791017055511475, 54.749352182660786, 51.74733086994716, 44.37089742933001, 41.220542498997276, 41.645685400281636, 41.158818176814485, 49.05306611742292, 55.75760875429426, 56.58298873901367, 53.83927018301827, 56.12560272216797, 55.2123384475708, 48.040449551173616, 38.953616278512136, 42.47156565529959, 51.03810739517212, 54.674325534275596, 57.111677169799805, 55.62479393822806, 55.14010844911848, 57.030675070626394, 53.96501520701817, 54.776929582868306, 51.93243782860892, 54.41522026062012, 51.35058873040335, 52.88342039925711, 49.89814077104841, 52.78030218396868, 52.80655247824532, 53.66794497626168, 48.81774800164359, 49.10528877803257, 42.15861531666347, 18.068196364811488, 1.2705585594688142, 0.1167375666222402, 0.47106729128531044, 1.732061926807676, 2.820023021527699, 4.016010582447052, 2.986737012863159, 0.032748647898967774, 0.06506243627518415, 3.266915521451405, 32.457842690604075, 41.99354696273804, 29.793357917240687, 23.589078630719865, 34.84247834341866, 28.897703851972306, 0.6481590143271855, 0.13023708867175238, 0.018426722747140696, 0.015173496778256126, 0.0857063281748976, 0.020546576407338892, 0.01933545755621578, 0.042176193092018366, 0.05610169264088784, 0.0490113273928208, 0.0663520802876779, 0.013709932366119964, 0.10345361514815263, 0.004907456600839006, 0.01672329959858741, 0.020448558631220033, 0.011364710932996656, 0.04555957564818008, 0.04691100027412176, 0.03820446299921189, 0.016169577703944275, 0.07559036170797688, 0.03637722586946828, 0.03473789883511407, 0.037572383880615234, 0.04401614936068654, 0.026962447312793562, 0.04977617885119148, 0.09932805438126836, 0.029222036778394665, 0.024912403031651462, 0.021827896491491368, 0.044920687430671284, 0.017331182158419063, 0.07402068629328694, 0.034159427375665734, 0.018804251149828945, 0.017720406808491265, 0.05162914263616715, 0.015104672971314617, 0.13548532633909158, 0.030190740512417893, 0.010346345220958548, 0.03450258967599698, 0.015348645326282297, 0.0291386821440288, 0.04712156665378383, 0.026339635286214094, 0.03212970182565706, 0.03362978668883443, 0.03304447898907321, 0.007847199815192392, 0.032134366753910265, 0.01108368717333568, 0.019765982936535562, 0.03238799975120595, 0.035296645281570296, 0.01604833028146199, 0.025912258308380842, 0.03491346977118935, 0.02093972807883152, 0.046855669136026075, 0.05186283688193985, 14.622331074305944, 43.614596435001914, 32.71723631450108, 24.23615915434701, 51.94024412972586, 63.32152543749128, 19.823201894760132, 0.9566833504608699, 0.029447564855217934, 0.06012663684253182, 0.3348733436848436, 0.12022797789956842, 5.182649169649396, 5.47484176499503, 1.5738144240209033, 0.12045219301113061, 3.5165295558316365, 27.381735461098806, 58.89302853175572, 69.91018254416329, 60.01332827976772, 60.65753746032715, 59.50249671936035, 56.8176189831325, 54.17724445887974, 51.32186835152762, 54.32547385351998, 62.068306650434224, 60.34057453700474, 61.14491190229143, 58.89860793522426, 59.557859965733115, 60.979162624904085, 59.48075580596924, 56.97008677891323, 51.36315107345581, 42.88716173171997, 45.19149357931954, 41.195504665374756, 42.89353322982788, 43.45779643739973, 44.7011661529541, 41.850716318402974, 44.34359448296683, 43.336196013859336, 46.45789309910366, 44.93938514164516, 52.19459336144583, 50.62382105418614, 56.620137282780235, 51.78535141263689, 56.4649110521589, 54.748844964163645, 59.54338686806815, 45.518882274627686, 35.204225880759104, 64.06878335135323, 54.17626823697771, 58.995493616376606, 55.893022196633474, 55.28116035461426, 55.007505553109304, 55.790369510650635, 53.652985504695344, 45.69725295475551, 42.107782295772004, 43.38065753664289, 43.73344537190029, 49.519418784550254, 58.19220542907715, 57.7622196333749, 55.64285578046526, 58.51233673095703, 56.83931820733206, 46.91452176230294, 40.57623256955828, 44.12153353009905, 52.992267404283794, 55.04350764410836, 57.15801470620291, 56.15433004924229, 57.066166469029014, 57.960441316877095, 55.40945884159633, 56.82606104442051, 54.330007553100586, 54.66607454844883, 53.43471132005964, 53.13373620169503, 52.9535242489406, 54.98897818156651, 53.17959083829607, 51.93371629714966, 51.44945464815412, 50.47980226789202, 46.11220632280622, 22.661065067563737, 2.3645703409399306, 0.9132269280297416, 0.7679837931479726, 2.8880361148289273, 1.8594274009977068, 6.115380993911198, 0.2774338887206146, 0.021437248614217554, 0.052973422288362465, 1.9265428738934653, 33.300697394779746, 50.087638991219656, 33.558621474674766, 25.9113872051239, 36.09469311577933, 38.735540117536274, 2.845708340406418, 0.1783735706870045, 0.05293304606207779, 0.01863439178227314, 0.021617381001955698, 0.03681734064593911, 0.011074391243580197, 0.03841198275664023, 0.022815740002053123, 0.032985134316342216, 0.019482178879635673, 0.029035979083606174, 0.038990589923092296, 0.030679641956729547, 0.02517930987024946, 0.0221586432973189, 0.041210858284362724, 0.017564596508496573, 0.029624798202088902, 0.045281973401350636, 0.07112260894583804, 0.06642201689204999, 0.01878460416836398, 0.0798638431089265, 0.05340734204011304, 0.031116431911609004, 0.009980951568910053, 0.08206134662032127, 0.17028733316276753, 0.19254165329039097, 0.13246804395956652, 0.1267335952392646, 0.12697037681937218, 0.14434210823050567, 0.1750542859413794, 0.15476517964686665, 0.18666932625429972, 0.16102604940533638, 0.1992604663329465, 0.05855970270931721, 0.14535605667957238, 0.1743743802819933, 0.0832615325759564, 0.12696213940424578, 0.10212158983839409, 0.1077650198712945, 0.12378804758191109, 0.1302050482481718, 0.18063558930797236, 0.21881659195891448, 0.09103295020759106, 0.11508430247860295, 0.12660969474485942, 0.10975630980517183, 0.13371658910598072, 0.15322143105523928, 0.13924128908131803, 0.15587356659982884, 0.11685921438038349, 0.12382546200283936, 0.19993324737463677, 0.09491108317992517, 0.14496184140443802, 14.64495267186846, 54.303406374795095, 47.616929054260254, 34.78732006890433, 46.298862729753765, 67.2851253237043, 31.101495265960693, 2.091996418578284, 0.15630287570612772, 0.28076742270163124, 2.4368839349065508, 13.150363888059344, 11.313959343092781, 7.859287210873195, 2.584701648780278, 0.25078081605689867, 3.4410753761019026, 26.413816656385148, 58.0091620853969, 71.73737117222377, 63.09040750776018, 63.216378348214285, 61.217485836574006, 59.12222875867571, 56.830181326184956, 51.410687174115864, 57.6413175037929, 67.29798643929618, 62.23996884482247, 60.74352836608887, 60.81998634338379, 60.23371124267578, 65.38389669145856, 62.528603962489534, 61.02993311200823, 52.147203172956196, 44.1813644681658, 47.879418100629536, 43.44386529922485, 45.72214487620762, 45.169957637786865, 48.18087611879621, 43.84719780513218, 47.57084860120501, 45.5540714263916, 50.15104130336216, 48.8118177141462, 54.867884976523264, 54.10682794025966, 58.701800210135325, 55.687320777348106, 58.86273438589913, 58.069722584315706, 63.06251049041748, 49.05821473257882, 41.14800330570766, 64.68699932098389, 57.398620401109966, 60.19935934884207, 58.271720613752095, 57.139014857155935, 60.27975695473807, 59.52486991882324, 56.98096765790667, 49.225631577628, 45.05422149385725, 46.60315213884626, 46.36538478306362, 53.99184914997646, 59.72380379268101, 59.37609509059361, 55.93884904044015, 60.196156229291645, 60.360550607953755, 51.32510968617031, 42.67856638772147, 45.366372789655415, 53.772713388715474, 58.88501031058175, 61.11478451320103, 56.77948032106672, 57.812416894095286, 57.88105467387608, 56.27492298398699, 56.98741906029837, 55.789855343954905, 57.84324952534267, 54.56053836005074, 55.346421309879844, 53.6004501751491, 56.12464039666312, 55.87489782060896, 53.96585941314697, 50.145013741084504, 53.180563586098806, 45.605491570064, 21.116728918892996, 2.3082990518638065, 0.780131958425045, 1.209627743278231, 5.439147566046033, 11.884673953056335, 14.387212719236102, 5.9545710171972, 0.0775845693424344, 0.23739850414650782, 5.307134398392268, 43.28860432761056, 52.02974040167672, 40.10283095496041, 33.03047500337873, 45.02580336162022, 45.11160666601998, 2.982228934764862, 0.2927580592887742, 0.1811011457549674, 0.13277748306947096, 0.08947189897298813, 0.0796054976859263, 0.15529074573091098, 0.11407754650073391, 0.12366479848112379, 0.14572929165193013, 0.14589425708566392, 0.12804476916790009, 0.15594778476016863, 0.09360897447913885, 0.11395353744072573, 0.1165408186082329, 0.09110430495015212, 0.06979572014617068, 0.11447828928274767, 0.10063237510621548, 0.17854248519454682, 0.16950374735253199, 0.10775233126644577, 0.12513236116085732, 0.1546143548829215, 0.12471173730279718, 0.052714958121734004, 0.2114472266818796], [0.044540867275957546, 0.03271015460735985, 0.05917189057384219, 0.032215916485126526, 0.02025468082034162, 0.06435895830925022, 0.02466156559863261, 0.01766849379055202, 0.03763770983953561, 0.06706438599420445, 0.02414033026434481, 0.0427900569380394, 0.03382877726107836, 0.04922212786706431, 0.020863513329199383, 0.031339707252170355, 0.10753818561456033, 0.028984766653073684, 0.042506846599280834, 0.04178269367132868, 0.02263576367736927, 0.0324594189545938, 0.006296808789816818, 0.07030318970126764, 0.005303231234263096, 0.028774892379130636, 0.05599741877189704, 0.06893629447690078, 0.05582476553640195, 0.028970242610999515, 0.05962065327912569, 0.05607553172324385, 0.009928392246365547, 0.0413971738224583, 0.011761660704256167, 0.17498458682426385, 9.836447494370596, 38.66935505185808, 35.70592750821795, 24.80811401775905, 35.11991991315569, 51.55479628699166, 30.151537554604666, 2.607349302087511, 0.03428573666938713, 0.050816176259624105, 0.5460164238299642, 5.380938163825443, 4.168853580951691, 1.1793462995971953, 0.245782021433115, 0.06617142712431294, 6.899942917483194, 35.58296523775373, 55.18741178512573, 63.068937574114116, 59.99596473148891, 58.043920448848176, 57.912780148642405, 58.012372153145925, 53.40755428586687, 55.14867557798113, 59.30042225973946, 60.85975088391985, 57.430074896131245, 58.24586636679513, 61.22988142286028, 60.28000014168875, 57.28193235397339, 51.00172662734985, 44.750244753701345, 43.72956827708653, 45.060638155256, 43.44892011369978, 42.78225088119507, 43.9545578956604, 42.396087374006, 42.798961298806326, 43.53156198774065, 41.46111692701067, 44.02599579947335, 41.338279724121094, 45.9018600327628, 49.83975853238787, 51.43678460802351, 53.36747360229492, 58.44404983520508, 54.88287571498326, 60.19858809879848, 44.57514667510986, 36.22917202540806, 59.7275836127145, 56.04675456455776, 57.5810592515128, 56.32077414648873, 59.09732641492571, 56.93249355043684, 55.447507177080425, 52.61052295139858, 49.36550923756191, 41.454464026859824, 41.247185366494314, 42.45817647661482, 51.494201047079905, 55.596827438899446, 59.09507519858224, 58.84405067988804, 55.35856328691755, 55.76920182364327, 53.15304524557931, 47.19436393465315, 42.77085583550589, 47.10757746015276, 53.131769861493794, 57.78820937020438, 56.450229508536204, 56.885832922799246, 54.36686774662563, 55.32261678150722, 54.96450662612915, 55.69088520322527, 51.95308787482125, 53.7258095741272, 52.22101041248867, 52.87452323096139, 49.849378313337056, 48.88732378823416, 50.89112867627825, 50.79101208278111, 35.7141889163426, 14.526755128587995, 0.6335381588765553, 0.09296813886612654, 0.5050488678472382, 1.78352375967162, 3.5395250533308302, 0.3616624219076974, 0.9645404602800096, 0.13677424431911536, 0.09475360877279725, 2.8829300573893955, 38.01537322998047, 40.88066789082119, 33.988461358206614, 49.2981846673148, 28.321666921888077, 37.448660782405305, 3.5542330869606564, 0.3067423403263092, 0.029371592681854963, 0.029901799945426837, 0.03820252238905855, 0.015509490356115358, 0.019788859744689295, 0.020928023349759833, 0.06877757835068873, 0.03935144502403481, 0.03441809171012469, 0.09836255333253316, 0.06745202626500811, 0.029736803977617195, 0.05678630054795316, 0.0290473106184176, 0.017821455939805934, 0.03301890839689544, 0.015141973737627268, 0.09719919825771026, 0.037858983501791954, 0.06754859536886215, 0.025608403541679894, 0.2350738431726183, 0.015704192587041428, 0.01798388365256999, 0.05160579763885055, 0.033910503411399465, 0.008857219546501125, 0.023884753264220696, 0.07637411715196711, 0.05237232168604221, 0.048679920711687634, 0.030679543569151844, 0.040694550810647864, 0.04173077556437679, 0.022919800132513046, 0.05725705796586616, 0.030087847462190048, 0.05984794215432235, 0.050840179435908794, 0.01434276465858732, 0.021143906051293015, 0.03761757770553231, 0.02356093599727111, 0.017201490367629697, 0.03894203734983291, 0.038095093332231045, 0.0386281199088054, 0.03728650011388319, 0.005344586247312171, 0.04604531851197992, 0.021605479497728602, 0.03912920784205198, 0.065260514217828, 0.025547331997326443, 0.03532837697171739, 0.05167349507766111, 0.036126432541225634, 0.028297505674085448, 0.04473451777760472, 0.021307668781706264, 0.02112307332988296, 0.027561137419460074, 0.3251226326184613, 17.120607989174978, 47.87130607877459, 34.79765204020909, 23.443222045898438, 49.83883442197527, 61.670494488307405, 24.751487936292374, 2.2324080041476657, 0.05912908858486584, 0.04032968896042023, 0.2161501936082329, 0.2529521552579743, 2.77627803172384, 1.9328950473240443, 0.14677908032068185, 0.2591421588190964, 9.022453001567296, 40.02787726266043, 59.82490703037807, 67.72896930149624, 62.56449835641043, 59.98511164528983, 61.16696548461914, 60.19230692727225, 55.996790068490164, 57.86863824299404, 62.422685623168945, 64.47853946685791, 58.81458336966378, 59.09398433140346, 61.69239521026611, 61.60639040810721, 60.64167472294399, 54.01898186547415, 46.943141392299104, 45.768121106284006, 46.61721529279436, 45.854765142713276, 47.51430068697248, 45.81412860325405, 45.94991724831717, 44.724897725241526, 44.89949900763375, 44.01248850141253, 46.18944597244263, 44.48051915849958, 48.67527518953596, 51.3869868687221, 53.88528462818691, 54.61190639223371, 58.45623002733503, 57.06367901393345, 62.19671630859375, 46.508305753980366, 38.465456690107075, 63.15605408804757, 57.70141247340611, 61.489653723580496, 58.32864720480782, 61.41844163622175, 59.44008799961635, 57.384866441999165, 56.728855746132986, 50.85707902908325, 43.05014215196882, 42.98673983982631, 45.0926867212568, 54.079438141414094, 58.41043445042202, 58.74429539271763, 57.0644919531686, 56.92416613442557, 57.66776582172939, 54.724686077662874, 46.93082571029663, 43.323230675288606, 48.9109650339399, 55.82498891013009, 57.68550109863281, 57.8757358278547, 55.825176511492046, 55.374943665095735, 55.32129314967564, 56.761036327907014, 56.588641098567415, 54.131233487810405, 54.73656054905483, 53.34753574643816, 52.90542534419468, 51.99742085593087, 52.18064137867519, 51.48368147441319, 53.45580605098179, 40.47988537379673, 18.29656454495021, 1.2119134834834506, 0.6083642925534929, 0.9971008045332772, 2.725343610559191, 2.0951172454016547, 2.344685899359839, 0.31644582535539356, 0.16103341829563889, 0.06400910565363509, 1.69354567357472, 34.976658480507986, 47.61953810283116, 36.07655484335763, 47.5922212600708, 28.651251247950963, 43.48255634307861, 7.605462568146842, 0.29251381382346153, 0.026076962506132464, 0.02006130342903946, 0.037081928591110876, 0.013694204772556466, 0.018239158704610806, 0.029312427820903913, 0.045434151842658005, 0.023511408029922416, 0.12833408292915138, 0.01640083091998739, 0.022494058424074734, 0.018770290472145592, 0.059880511835217476, 0.03349296349499907, 0.031655833324683566, 0.027451033238321543, 0.02573312506345766, 0.08178424648940563, 0.03497667530817645, 0.04761500410469515, 0.08950636855193547, 0.026192184537649155, 0.02758257742971182, 0.013541379178475057, 0.005741112782353801, 0.049960906617343426, 0.05453260076631393, 0.11618762756032602, 0.15983095924769128, 0.18876964998032364, 0.13020929587738855, 0.08823499070214373, 0.1400382827435221, 0.12191918572144848, 0.06513180291014058, 0.08677838636296135, 0.13913855887949467, 0.11696046537586621, 0.155681419053248, 0.08834836033305951, 0.08546579429613692, 0.12921551348907606, 0.13146180366831167, 0.15420095063745975, 0.13795481382736138, 0.10003621423883097, 0.11071177532098123, 0.16081582568585873, 0.13811318390071392, 0.17221019284001418, 0.12904393912426063, 0.12050548515149526, 0.14691325383526938, 0.1853630377777985, 0.13968245897974285, 0.1273452809878758, 0.15868119522929192, 0.10871518602860825, 0.11551082959132535, 0.1514636589480298, 0.14428047010941164, 0.04531074667881642, 0.43584540699209484, 17.53138027872358, 59.3330648967198, 47.94578729357038, 35.342689582279746, 47.82447869437081, 63.38331576756069, 40.893991061619346, 4.877710538251059, 0.12522887598190988, 0.18984254955181054, 1.5235260767596108, 12.034415449414935, 12.280795097351074, 3.5377130934170316, 0.9116045236587524, 0.4168626841689859, 7.971569231578282, 41.56560393742153, 57.84234625952584, 67.71548284803117, 64.88541207994733, 62.79178088051932, 64.37123843601772, 64.13404083251953, 59.4365166255406, 60.93530559539795, 64.81319250379289, 65.96064581189836, 59.86551925114223, 59.071680613926475, 65.8684640611921, 64.47273772103446, 62.67131996154785, 55.37063578196934, 47.99268415996006, 49.351536410195486, 50.26882369177682, 49.08637925556728, 50.62771551949637, 50.57326596123831, 49.40124729701451, 48.1567519732884, 48.677071298871724, 45.744476386478965, 49.706728322165354, 46.168125425066265, 50.337649072919575, 54.91987834657942, 56.82787799835205, 57.2799243245806, 61.73290320805141, 59.09878553662981, 62.76228577750069, 47.865455695560996, 42.479236466544016, 63.06365694318499, 58.440992627825054, 63.44926806858608, 60.77385030473982, 64.00972366333008, 61.538798332214355, 58.59925174713135, 58.811922209603445, 52.996769836970735, 46.02563871656145, 43.900667667388916, 48.06399352209908, 55.79892274311611, 60.532018252781455, 61.04368359701974, 59.51033428737095, 59.38761520385742, 60.27040467943464, 57.539894648960654, 51.61405052457537, 46.12030097416469, 50.601343631744385, 57.04497446332659, 60.31596401759556, 58.808656556265696, 56.710331848689485, 55.77499314716884, 56.657508168901714, 57.154217515672954, 60.57886300768171, 54.251319204057964, 57.57046324866158, 54.0699052129473, 54.407962867191856, 52.564821175166536, 53.00106382369995, 52.620208740234375, 53.972491468702046, 38.69489662987845, 16.90555429458618, 1.2797068400042397, 0.593117176422051, 0.8850929662585258, 5.701454656464713, 11.502993771008082, 7.28075327192034, 4.4341475282396585, 0.4331681249397141, 0.15258510091475078, 4.710494756698608, 48.54187672478812, 50.93567705154419, 44.295228072575156, 55.66036524091448, 37.63691874912807, 53.49865211759295, 7.45561945438385, 0.5216268354228565, 0.18341359309852123, 0.12479890191129275, 0.13467607833445072, 0.09146044762539011, 0.15052508216883453, 0.1370028563375984, 0.2052366363682917, 0.1468496479626213, 0.23911929609520094, 0.13318060072404997, 0.22052682590271744, 0.11809321173599788, 0.12181365995534829, 0.14328170727406228, 0.18572876815285, 0.1714681876557214, 0.0926433920062014, 0.1427953333726951, 0.16459742348108972, 0.12780591127063545, 0.19099163503519126, 0.2866384062383856, 0.10972350263702017, 0.1097053178985204, 0.15573836171201297, 0.10664718092552253, 0.21622507673289093], [0.05332334619015455, 0.024706638983583877, 0.09969698065625769, 0.02760094028365399, 0.03903338512671845, 0.0386657243195389, 0.02715000287363572, 0.07487966412944452, 0.03164971972416554, 0.02468754331182156, 0.035711518555347405, 0.07005718004490648, 0.03243505276207413, 0.022793102377493466, 0.007809709059074521, 0.0796694021139826, 0.031915864907205105, 0.04526176323582019, 0.043694795175854645, 0.07040232366749219, 0.037882331891783645, 0.040117293928882906, 0.01418243785987475, 0.03257172328553029, 0.07792644921158041, 0.04177095162283097, 0.04283668247184583, 0.014924199619729604, 0.06252111228449003, 0.0676714712753892, 0.006874914264439472, 0.10258048985685621, 0.04130974119263036, 0.03088124149612018, 0.10200589283236436, 0.06541652298931565, 0.15523921778159483, 9.70865969998496, 39.82543107441494, 38.22047363008772, 25.529430832181657, 32.29984065464565, 44.68201691763741, 44.17990187236241, 4.92587023973465, 0.07800601422786713, 0.1230269077100924, 0.3308030292391777, 3.3178851178714206, 1.469450744135039, 0.18943829195840017, 0.0923664750797408, 0.48921490034886767, 13.29890421458653, 40.4556222643171, 59.63130937303816, 62.40958826882498, 61.6471346446446, 61.22799151284354, 57.690941538129536, 58.547842025756836, 63.047189712524414, 62.07943071637835, 59.3518180847168, 57.90483488355364, 61.20358943939209, 60.803442682538716, 62.16732542855399, 56.19330596923828, 48.96747473308018, 46.471011298043386, 46.14917073931013, 45.839746611458914, 43.3252387046814, 43.96645668574742, 43.54383250645229, 44.615727628980366, 42.06995282854353, 45.09743581499372, 46.16613824026925, 47.17869922092983, 45.0280511038644, 48.62777035576956, 49.98364530290876, 58.6449431010655, 54.688499859401155, 56.96476445879255, 57.01792860031128, 59.05647100721087, 46.42744261877877, 30.781631469726562, 52.21816859926496, 54.76305055618286, 59.48679379054478, 56.83339139393398, 58.4427227292742, 54.90133360454014, 57.10148068836757, 56.2749924659729, 55.36677605765206, 44.155784675053184, 42.158549308776855, 46.70431443623134, 52.84346825735909, 58.42952810014997, 60.76084327697754, 57.36146143504551, 58.99112319946289, 57.39642824445452, 56.279369831085205, 52.13186502456665, 48.60488298961094, 42.8723030090332, 48.47632047108242, 53.86762578146798, 56.46815586090088, 59.62911374228341, 57.20902490615845, 56.195751735142295, 52.14206150599888, 53.78469555718558, 53.39343554633004, 52.404661723545615, 53.88825150898525, 52.86071021216256, 48.85612637656075, 48.45145286832537, 49.391710894448416, 26.64697735650199, 5.558365191732134, 0.057559928856790066, 0.15467701080654347, 1.0531167473111833, 2.5504483325140814, 0.5013626313635281, 1.5255028392587389, 1.4341660546404975, 0.07021707682205097, 0.018418756746021763, 2.870691239833832, 36.69370079040527, 43.77315085274832, 42.43311085019793, 54.639237131391255, 35.09761272157942, 32.86722707748413, 7.710684350558689, 0.15740052823509487, 0.01996597265159445, 0.042089727374592, 0.019011312896119695, 0.047950007021427155, 0.007387745094352535, 0.06206683987485511, 0.039967812664274655, 0.024616977366219674, 0.027528430335223675, 0.06277398192988974, 0.03221098014286586, 0.0717921873022403, 0.049594389141670296, 0.06058211025914975, 0.058894301897713115, 0.02222063934563526, 0.017316315456160476, 0.04661899272884641, 0.030042636673897505, 0.045122823012726646, 0.02354445438166814, 0.06277685891836882, 0.015711134000282203, 0.013956847018562257, 0.06362894283873693, 0.1089549803041986, 0.06678301787802152, 0.029682599207652465, 0.009293623584588724, 0.003552353466927473, 0.05883151026708739, 0.0031230939785018563, 0.048995575202362876, 0.02989206975325942, 0.059526615110891204, 0.059252853372267315, 0.009692916846168893, 0.05458105155932052, 0.01927781431004405, 0.024485585845208595, 0.053066775136228116, 0.0182347702793777, 0.02533836187129574, 0.039664697500744035, 0.051656782760151794, 0.007228302087501756, 0.05584044987335801, 0.023285807010584643, 0.040366455380405696, 0.057185377526496134, 0.04151201926703964, 0.034574714555804215, 0.13293738663196564, 0.02053707861341536, 0.07548826932907104, 0.050194203920130215, 0.0232331662638379, 0.024651465604880025, 0.03790235885285905, 0.05437203902485115, 0.030152108121131147, 0.008608381247280963, 0.07923908199050597, 0.06730593089014292, 0.654310829937458, 18.32402729988098, 45.863492080143516, 36.23103414263044, 24.9321254662105, 44.3194078036717, 61.2787481035505, 39.216230392456055, 3.383487186261586, 0.055899329749601226, 0.2809088022581169, 0.07196422307086842, 0.2587062136403152, 1.318495701466288, 0.503343247941562, 0.20360181480646133, 0.7988084448235375, 15.880267688206263, 44.880492210388184, 63.36737659999302, 64.85324886866978, 63.78267042977469, 62.46941225869315, 60.36518505641392, 61.71660968235561, 65.15941429138184, 63.23301233564104, 61.74361038208008, 58.13701936176845, 60.732661383492605, 63.330488613673616, 65.37291853768485, 58.968152454921174, 51.236061573028564, 47.544924872262136, 47.379158224378315, 47.06902190617153, 46.561323983328684, 44.96784496307373, 45.46103852135794, 46.60608427865164, 44.683691433497835, 46.06327363422939, 49.31240068163191, 49.05586624145508, 47.01638582774571, 50.488845348358154, 51.62638010297503, 59.20826135362898, 57.69622564315796, 59.0409973689488, 58.916694096156526, 60.52067184448242, 47.903573513031006, 33.245198658534456, 53.71307005201067, 55.82829972675869, 59.59927817753383, 58.39471762520926, 60.19002791813442, 57.30654982158116, 58.92558084215437, 58.78000913347517, 55.25626148496355, 45.13095392499651, 44.091892514910015, 47.404126576014924, 55.41488191059658, 58.9413115637643, 60.23899187360491, 57.24452672685896, 58.727953229631694, 57.83681549344744, 58.06962878363473, 54.16157974515642, 49.555684907095774, 45.72578573226929, 49.663295132773264, 57.11015204020909, 57.704136167253765, 59.75537640707833, 57.64720262799944, 56.03214250292097, 55.17933450426374, 54.50021757398333, 53.16172007152012, 53.56599753243582, 53.52707372392927, 53.9354818889073, 50.56231560025896, 48.83086272648403, 52.091770444597515, 31.67614255632673, 8.8639281136649, 0.6107784658670425, 0.5425728857517242, 1.5261870196887424, 3.4633860417774747, 0.024148906946980526, 1.953116693667003, 0.3461629721735205, 0.05939107774091618, 0.04724585052047457, 2.172936418226787, 34.96237645830427, 53.92627205167498, 43.40303768430437, 52.50160993848528, 42.14974594116211, 38.19171503611973, 14.66135389464242, 0.23213600367307663, 0.037785182640488656, 0.038288061906184466, 0.033178588042833974, 0.009283109684474766, 0.02790571446530521, 0.04309298211176481, 0.06048718999539103, 0.05551183536382658, 0.042506598933999024, 0.05688591627404094, 0.09450217083628688, 0.052203739660659006, 0.02874752027647836, 0.058850373540605815, 0.03253058370734964, 0.03971029505399721, 0.04899749545646565, 0.07049638897712741, 0.056059881313038726, 0.026223670258851986, 0.02372563849868519, 0.04009272078318255, 0.028360660320946147, 0.030920979899487326, 0.05645159957930446, 0.05312184164566653, 0.06997532836560692, 0.02994812692382506, 0.08848412161959068, 0.08218374755233526, 0.15667094024164335, 0.0666834225079843, 0.17107817929770264, 0.09848861835364785, 0.10845871336225953, 0.16494461627943174, 0.09547856915742159, 0.22765356062778405, 0.12970632500946522, 0.17052682888294968, 0.15379268968743937, 0.08316890576056071, 0.11795941820102078, 0.14141631951289518, 0.1379301558647837, 0.0924546235640134, 0.11068218440881797, 0.0996677086555532, 0.2136534018708127, 0.24979941014732632, 0.1551134716719389, 0.05324125023824828, 0.25161573982664515, 0.10324013446058546, 0.08831245904522282, 0.17658835862364086, 0.14422856218048505, 0.07261274648564202, 0.05788569351924317, 0.16718950867652893, 0.20118301388408455, 0.07762397187096731, 0.2568316656563963, 0.17629120099757398, 0.45079187782747404, 16.510585682732717, 58.92406613486153, 52.914788041796, 36.62766163689749, 43.45265824454171, 56.70636442729405, 58.57427297319685, 7.502760376249041, 0.2473941934960229, 0.5597749426960945, 2.0559228914124623, 11.269476107188634, 9.599368010248456, 1.101635366678238, 0.4621089462723051, 1.3561281221253532, 14.606987714767456, 46.40357208251953, 65.96773297446114, 68.43590681893485, 66.18002128601074, 66.18831743512834, 63.70148072923933, 63.07822731563023, 68.59677151271275, 67.57672732216972, 64.0099321092878, 58.40196459633963, 61.93552657536098, 64.36483914511544, 69.80201298849923, 62.99671104976109, 54.30876343590872, 50.43060554776873, 50.92612675258091, 49.22560378483364, 49.966615268162315, 48.41442939213344, 46.84763492856707, 48.99619163785662, 47.1764132635934, 49.96051474979946, 53.3861677306039, 54.85773018428257, 51.49668502807617, 54.15092815671648, 55.9398078918457, 63.88220337459019, 60.94123240879604, 61.01197896684919, 61.47579901559012, 62.87984929765974, 51.73955236162458, 36.18700688225882, 57.19728939873831, 57.39542422975813, 62.72733633858817, 60.84894643511091, 64.16707951681954, 60.164882387433735, 62.7030245917184, 61.943016733442036, 60.61602892194475, 48.967342717306956, 45.62751041139875, 50.94623483930315, 58.511440413338796, 61.454759870256694, 61.10188170841762, 58.816577502659385, 60.411605971200125, 60.420207841055735, 61.10188865661621, 56.02794231687273, 52.34879125867571, 46.06177977153233, 51.9253819329398, 57.172303676605225, 59.349226406642366, 63.39492620740618, 58.39742047446114, 56.838341985430034, 55.39750446592058, 54.633671624319895, 56.27405445916312, 54.45953239713396, 55.21645872933524, 55.39744540623256, 52.839184692927766, 54.18676349094936, 52.38118723460606, 30.944761276245117, 7.043351999350956, 0.3419618090348584, 0.35103013100368635, 1.7906610795429774, 7.315064345087324, 3.761409044265747, 6.481217111860003, 3.382750677210944, 0.22010422072240285, 0.1889711341687611, 4.947923822062356, 47.9838217326573, 54.135718550000874, 50.60670069285801, 59.20550986698696, 43.71704762322562, 48.96960088184902, 15.235690253121511, 0.35156554941620144, 0.1685689025159393, 0.09490299504250288, 0.12627770113093512, 0.1255343931594065, 0.10662192585212843, 0.1345832683146, 0.11976694049579756, 0.1072963693046144, 0.16385517402419023, 0.182169268439923, 0.1390807476959058, 0.1734982965780156, 0.13019168110830442, 0.1660100926778146, 0.17429830293570245, 0.13228920927005156, 0.1648912291441645, 0.17391062873814786, 0.16929863978709492, 0.08138086420616933, 0.1528523758585964, 0.16055274408842835, 0.11226167143987757, 0.12788603268563747, 0.12411857556019511, 0.22877147421240807, 0.10331598789032016, 0.13409617516611302], [0.029476867389998267, 0.04270706192723342, 0.013514068992143231, 0.04337032651528716, 0.02647722013560789, 0.04294137703254819, 0.08784350992313453, 0.04488224842186485, 0.039381144501801045, 0.03991602687165141, 0.004925377558850284, 0.008928153597350632, 0.04325379830385957, 0.01867068831675819, 0.03976486284019692, 0.043596166718219004, 0.010935871712198215, 0.03591843780928424, 0.020275988516264727, 0.03940523928031325, 0.024627964544509138, 0.016687564551830292, 0.016554352860631685, 0.06056845134922436, 0.05493558949923941, 0.03751091200060078, 0.029826611480010406, 0.027941069532451884, 0.04852222917335374, 0.06624681236488478, 0.06216655738119568, 0.07351162218089614, 0.037269021051802805, 0.031621031263577085, 0.05905042602015393, 0.011362046834879687, 0.04847919987514615, 0.12816434060888632, 10.325015289442879, 45.39100067956107, 43.67916604450771, 27.306668860571726, 27.407521963119507, 47.46247059958321, 49.78826543263027, 9.215609448296682, 0.08283980270581585, 0.10463391324239117, 0.13700061717203685, 1.1262519657611847, 1.5117907864706857, 1.21356900036335, 0.02087623586079904, 0.7083577183740479, 12.40799229485648, 45.371629101889475, 63.38911056518555, 64.04868221282959, 60.07849543435233, 67.70788151877267, 64.03835718972343, 62.02451910291399, 61.25986289978027, 61.295673915318076, 59.331758635384695, 62.66848509652274, 61.03805555616106, 58.18718188149588, 53.29265192576817, 47.44874790736607, 47.17899799346924, 47.280045645577566, 49.63653761999947, 45.77518742425101, 45.497245584215435, 45.50571196419852, 48.992689745766775, 48.77791050502232, 48.94284336907523, 46.746437890189036, 47.631791251046316, 46.462273938315256, 47.98001411982945, 48.179701873234336, 55.43271446228027, 53.21714237758091, 63.267871447971885, 56.767459937504356, 61.806581905909944, 41.12824610301426, 36.00777462550572, 68.23832784380231, 56.715615953717915, 58.90084525517055, 56.38715376172747, 60.95364883967808, 56.01651947838919, 58.5428740637643, 55.81241267068045, 56.512940474918906, 44.54403611591884, 41.170463357652935, 45.71310179574149, 53.44327844892229, 59.02925491333008, 59.621394293648855, 59.40526362827846, 58.83758885519845, 57.706564562661306, 58.78668635232108, 57.0510367665972, 55.91215753555298, 51.19971554619925, 44.832591329302105, 53.16039643968855, 55.296849387032644, 56.78130422319685, 57.399513244628906, 57.68503556932722, 55.988181250435964, 58.244827611105784, 51.74421807697841, 55.66592379978725, 52.57374961035592, 55.58154140199934, 54.9223484311785, 43.93232018607003, 12.889818600245885, 2.3436818846634457, 0.11762338051838533, 0.3281485731048243, 0.7165847112025533, 12.249756625720433, 20.165883575166973, 1.742931297847203, 0.03219236792730434, 0.24270985914128168, 0.18148858925061567, 5.961294702121189, 42.27096421377999, 42.78792061124529, 26.880085945129395, 21.56487556866237, 31.92086853299822, 37.647973333086284, 12.421653321811132, 0.4308705510837691, 0.07115532111908708, 0.020400039984711578, 0.10724866150745324, 0.010484557715244591, 0.056182054935821464, 0.023407125679243888, 0.10875563350106988, 0.008972778301020818, 0.051214408462068865, 0.09516304358839989, 0.029959495778062513, 0.034923033722277196, 0.05640799352633102, 0.009413624198974242, 0.08130423724651337, 0.04116856519665037, 0.056943378012095175, 0.023361207518194402, 0.07333888752119881, 0.07064666412770748, 0.037405532119529586, 0.04943721328995057, 0.07181122699486357, 0.029128527867474725, 0.07845852244645357, 0.07049484870263509, 0.019772800517135432, 0.04095250268333724, 0.0614914150376405, 0.03865512560254761, 0.02396362617478839, 0.011539303930476308, 0.011398981192282267, 0.037755472984697135, 0.08979719544627837, 0.013351365624527847, 0.008699365159762757, 0.04740368115848728, 0.027755161115367497, 0.014887022686057856, 0.04079934375892792, 0.01328295233127262, 0.01576292997093073, 0.06593113751815897, 0.023007198835590055, 0.011289414750146014, 0.029209175147116184, 0.047179425334823985, 0.011820999439805746, 0.01698685617053083, 0.011114587658084929, 0.005458006768354348, 0.010050842372168387, 0.04779297366206135, 0.026947310892865062, 0.027802178503147194, 0.03182001165779574, 0.007044833427893796, 0.03253168971943004, 0.03522486984729767, 0.02959199103393725, 0.07378288012530122, 0.015223006085891808, 0.02131169249436685, 0.04107452363574079, 0.016365394428638474, 0.40169636798756464, 19.436083010264806, 53.12636416299002, 41.66829136439732, 23.800411564963206, 32.75044870376587, 65.49780545915876, 49.551783493586946, 6.10955319234303, 0.08358251356652804, 0.06629124962325607, 0.0790617943608335, 0.5505727593387876, 0.4013894258865288, 0.7697936903153146, 0.0806828552324857, 1.0985167111669267, 15.710064615522112, 51.143098149980815, 67.80275222233364, 65.98986298697335, 63.656241008213584, 69.40610463278634, 65.13790266854423, 63.62461975642613, 63.6171851839338, 62.733784266880576, 58.22834995814732, 65.19782393319267, 62.89626094273159, 61.07060786655971, 54.54947335379464, 50.79133169991629, 49.76657315662929, 48.56534773962838, 49.23943764822823, 46.8901127406529, 46.10923944200788, 47.258770261492046, 49.90991449356079, 49.990996497017996, 50.27909312929426, 49.15700422014509, 49.26741804395403, 47.70493493761335, 50.626742771693635, 52.341231618608745, 57.01930781773159, 55.236876010894775, 62.90195846557617, 59.053656986781526, 63.495355469839915, 44.3367783001491, 38.161438260759624, 66.9639378956386, 56.675809723990305, 60.425745555332725, 56.76972157614571, 62.59558459690639, 57.54519612448556, 62.03767899104527, 57.61514016560146, 59.11621856689453, 44.890483719961985, 43.769072260175435, 47.004122257232666, 54.33901241847447, 61.544878005981445, 61.73193046024868, 57.96871314729963, 60.09818662915911, 59.715987069266184, 58.47462885720389, 58.004645756312776, 58.40709931509835, 52.54404258728027, 47.96165697915213, 55.3762777192252, 57.88056482587542, 59.25603716714041, 59.50071798052107, 57.14346865245274, 56.01048844201224, 58.28407103674752, 53.276243754795615, 55.37544393539429, 53.569895471845356, 54.16635315758841, 56.13706724984305, 47.86915213721139, 19.595525060381206, 3.626902993236269, 0.27501727268099785, 0.6623003897922379, 0.8597152680158615, 10.807337522506714, 21.57582071849278, 1.411130822130612, 0.07536167505064181, 0.2575961303498064, 0.13254368704344544, 3.5166042489664893, 41.05295542308262, 52.249108927590505, 32.34587247031075, 28.32713689122881, 38.67285694394793, 40.680212361471995, 20.576640231268748, 0.47015148614134106, 0.022209994827530215, 0.09135246556252241, 0.06237714072423322, 0.025956359691917896, 0.06345838627644948, 0.013317310800110655, 0.05015908634024007, 0.05307939928025007, 0.01954571689878191, 0.07747296390256711, 0.07467848528176546, 0.04288898395108325, 0.04913559429613607, 0.06041061053318637, 0.051121279530759366, 0.031008636445871422, 0.06075688052390303, 0.0490746347100607, 0.041222630866936276, 0.036182635596820285, 0.038778873426573615, 0.07659678520368678, 0.013774442386680415, 0.02813432987646333, 0.05954267603478261, 0.018282344065872685, 0.016104928583705, 0.04375107965565153, 0.06381444752748523, 0.110120499905731, 0.17004946592663014, 0.03961165641833629, 0.11913027108779975, 0.06669081175433737, 0.1471706221678427, 0.11142445422176804, 0.13486571530146257, 0.13327474067253725, 0.14175622484513692, 0.08937494310417346, 0.08666735767785992, 0.13751330466142722, 0.12038454306977135, 0.24001010400908335, 0.15238403741802486, 0.05873840847717864, 0.1601760485874755, 0.22184234245547227, 0.0839878228892173, 0.10684511637581245, 0.12434702473027365, 0.06064954985465322, 0.10364883645836796, 0.1789734499262912, 0.09099031106701919, 0.0982318539172411, 0.10712153797170945, 0.09739078262022563, 0.16818512310939177, 0.16546806533421787, 0.25020392558404375, 0.15987791387098177, 0.1063136945345572, 0.15865883071507725, 0.21704123222402164, 0.14550777710974216, 0.3072600896869387, 17.175840956824167, 61.760696002415244, 57.20063843045916, 39.051405225481304, 37.46809489386422, 62.44552435193743, 63.8131035396031, 13.25706216267177, 0.2008592848266874, 0.12116419337689877, 0.9026720172592572, 5.161034192357745, 3.1878044179507663, 1.4594755194016864, 0.12580445009682859, 1.3540008877004897, 15.020014694758824, 49.93812070574079, 68.885879107884, 69.25277873447963, 64.15715748923165, 72.546370778765, 69.51494816371373, 67.79145445142473, 65.82666369846889, 63.07972812652588, 59.78662245614188, 67.1929713657924, 67.82673740386963, 63.35287570953369, 56.576019695826936, 51.79781995500837, 53.287836824144634, 52.05273199081421, 53.9140362739563, 51.45803219931466, 49.87891163144793, 51.77631180627005, 55.16901295525687, 54.0848959514073, 54.62264483315604, 52.03611537388393, 51.62790175846645, 49.817718846457346, 51.96287093843733, 54.63571092060634, 59.67110865456717, 58.71197237287249, 65.46917193276542, 62.207249777657644, 65.12456907544816, 45.923336914607454, 42.508870533534456, 67.85306412833077, 58.783768108912874, 61.03909083775112, 60.5820244380406, 63.75475951603481, 60.243515150887625, 62.71742820739746, 61.61597892216274, 60.651582854134695, 47.33696528843471, 45.48009395599365, 48.79796648025513, 56.995218413216726, 63.33944484165737, 64.75268064226422, 60.5362149647304, 61.20577812194824, 62.22525256020682, 61.72817843300955, 61.74711922236851, 62.533023016793386, 57.98881775992257, 51.10833283833095, 57.20780202320644, 59.88079833984375, 61.226052965436665, 59.05028016226632, 58.841841152736116, 56.64024536950247, 59.64745003836495, 50.71810810906546, 57.74161127635411, 52.85601322991507, 55.91607979365757, 55.78853518622262, 46.00963354110718, 14.205050928252083, 3.458913573196956, 0.31790616842252867, 0.9823075469051088, 1.5726537491594041, 21.337700741631643, 36.10868331364223, 3.7923537152154103, 0.13752725534141064, 0.43211419720734867, 0.3074554263481072, 9.294962218829564, 54.121842997414724, 53.090462820870535, 38.172972270420615, 30.614544664110454, 40.79999930518014, 50.41846357073103, 20.476884944098337, 0.36226593809468405, 0.14326912723481655, 0.20423406016613754, 0.19886080920696259, 0.2217212375253439, 0.09329616983554193, 0.10426669687564884, 0.16311496017234667, 0.12860791252127715, 0.09761659228908164, 0.17810164099293097, 0.1628587046372039, 0.12872236780822277, 0.1426943266498191, 0.09926494383918387, 0.19147228210100106, 0.12007703099931989, 0.1834611584033285, 0.15005041978188924, 0.17076275550893374, 0.15511967348200933, 0.12920176636959824, 0.21269841811486653, 0.11556736512907914, 0.1110730002235089, 0.23009703308343887, 0.17035916287984165, 0.11657664525721755, 0.2019551731646061, 0.11071633507630654], [0.06230565706001861, 0.008855563921055623, 0.01659437285603157, 0.014511762286669441, 0.01711239363066852, 0.0021196581572959466, 0.047074713810746155, 0.026746040442958474, 0.0524492845205324, 0.03468772456316011, 0.03418075033862676, 0.00837066413701645, 0.017836344694452624, 0.0333488155156374, 0.028481334381337677, 0.027694366074034145, 0.035801862100405354, 0.07939531467854977, 0.026584713653262173, 0.008279703125091535, 0.03614231026066201, 0.09897666823651109, 0.03543729541291084, 0.020910839450412562, 0.052189673629722426, 0.04722546732851437, 0.011244463501498103, 0.009105198650753923, 0.0582841428528939, 0.05213080393150449, 0.06399932796401636, 0.033138890351567946, 0.041077007073909044, 0.06923710940671818, 0.017893311101943254, 0.0616131577906864, 0.008082039088809063, 0.014177279297395476, 0.13167626144630568, 9.452831370489937, 45.87235798154558, 43.17414665222168, 45.07846375874111, 25.981326035090856, 45.984463691711426, 56.467895303453716, 20.939353568213328, 0.12302569991775922, 0.10689053750996079, 0.2950694481176989, 3.0338067156927924, 8.515669635363988, 0.1571097895503044, 0.3285908150885786, 0.11391564804528441, 9.45196805681501, 36.94503797803606, 67.3722140448434, 66.875855582101, 64.42570536477226, 65.23807484763009, 68.56357301984514, 60.571081025259836, 60.946339334760395, 61.679325648716514, 64.30948979513985, 62.43421268463135, 59.635089193071636, 53.762888635907856, 49.61390038899013, 47.53008699417114, 46.90830659866333, 45.32984610966274, 45.48255361829485, 45.15666920798165, 52.57434368133545, 55.82899802071707, 54.32434824534825, 58.007630007607595, 55.28971011298043, 53.583090100969585, 50.99818999426705, 49.46359348297119, 50.23830720356533, 58.58634199414934, 59.776888029915945, 58.72402054922921, 55.77839429037911, 64.15806075504848, 45.52683796201433, 26.082962547029766, 60.74762780325753, 54.296736104147776, 62.52653339930943, 57.93782145636422, 62.7217777797154, 59.152092116219656, 60.58646433694022, 59.00122588021414, 59.168865067618235, 48.00477055140904, 44.3802809715271, 47.80200127192906, 53.842928409576416, 54.87197399139404, 59.78617777143206, 60.37462765829903, 61.34644440242222, 58.180469921657014, 58.173716272626606, 57.67441872188023, 58.970445360456196, 55.5798008782523, 51.6393906048366, 49.69650404793875, 55.6249989100865, 55.50603185381208, 59.39772483280727, 58.14256749834333, 56.241655009133474, 54.14849281311035, 60.26942498343331, 54.44364186695644, 58.806099619184224, 52.03140449523926, 28.313247442245483, 4.464406064578465, 0.06418227457574435, 0.06647300201335124, 0.12038267031311989, 0.051716459915041924, 9.552171502794538, 24.13266052518572, 0.9684293887444905, 0.37385873602969305, 0.13055538944900036, 0.053014582222593684, 11.297407865524292, 46.07286562238421, 32.58530044555664, 20.175701379776, 26.02346338544573, 32.8849310874939, 37.58979606628418, 10.16729118142809, 0.13763221113809518, 0.10941470135003328, 0.06840399732547146, 0.09896562847175769, 0.043472588527947664, 0.03162657150200435, 0.026073206814804246, 0.00929399423434266, 0.039837873208203485, 0.03788726484136922, 0.03015040499823434, 0.054955362009682825, 0.03850109136796423, 0.042250553744712045, 0.040308186185679266, 0.05210132158494421, 0.002760653862164223, 0.07127383404544421, 0.047949705073343854, 0.042756048762904744, 0.023505991624136056, 0.0521294434687921, 0.035390276328793595, 0.03591038699128798, 0.022608179532523667, 0.02382733902361776, 0.0015225255005394242, 0.04199503442006452, 0.03812018555722066, 0.05964330277804818, 0.025848279241472483, 0.028057188926530734, 0.016112068468438726, 0.006435760887273188, 0.026613325778661028, 0.0553065445939345, 0.027182545413130095, 0.08505115511694125, 0.06480177704777036, 0.03469742422125169, 0.006679494058646793, 0.013052898425874966, 0.027808332815766335, 0.0670809286779591, 0.024035048770851324, 0.059237009579581876, 0.005871669281207557, 0.048444506379642656, 0.05060651233153684, 0.050492928962090185, 0.03477349478219237, 0.014346949523314834, 0.04632548562117985, 0.07155316655657121, 0.05946481414139271, 0.019968405199636306, 0.005159347883558699, 0.01970442454330623, 0.04066751119015472, 0.02737946984624224, 0.053484837524592876, 0.02496328467636236, 0.057763971122247834, 0.02981634863785335, 0.019092618354729245, 0.02517151689556028, 0.023400319973006845, 0.021367722523531744, 0.03520165037895952, 0.32792248523661066, 18.12021231651306, 55.81908988952637, 42.55902263096401, 36.559680461883545, 31.454654829842703, 64.0285393851144, 60.530774525233674, 15.27565802846636, 0.11178658157587051, 0.19343816089843, 0.44254374184778755, 3.777639167649405, 8.629273550851003, 0.35011693143418854, 0.3015585227736405, 0.43210887749280247, 13.081118140901838, 43.73713486535208, 72.61618627820695, 68.18807847159249, 65.7796104976109, 66.78152683803013, 70.56849656786237, 60.88158907209124, 61.13298879350935, 61.8813236781529, 65.62046200888497, 63.496606145586284, 62.94034031459263, 55.74717256001064, 51.44796773365566, 48.50821270261492, 49.41176339558193, 47.664711815970286, 46.98387173243931, 46.66297960281372, 52.63165589741298, 57.82144260406494, 55.58369186946324, 59.70721844264439, 55.32443720953805, 54.34778799329485, 51.53669275556292, 51.56139360155378, 51.04589979989188, 58.13257598876953, 60.72107178824288, 61.37855897630964, 57.0627965927124, 63.70659460340227, 44.927844183785574, 30.39018038340977, 63.09130382537842, 54.04047611781529, 61.72118159702846, 58.66823346274239, 63.62300777435303, 61.2232528414045, 59.932082993643625, 60.366011892046245, 59.332856450762065, 49.062439237322124, 43.73770114353725, 49.730772563389365, 57.20677021571568, 57.1701671055385, 61.075951031276155, 63.051143237522666, 62.78215067727225, 59.12662696838379, 60.7584878376552, 59.47042383466448, 60.98964745657784, 57.58142403193882, 51.31465612139021, 51.1143673488072, 57.75806113651821, 56.97383533205305, 60.05813026428223, 59.4254481451852, 57.7307825088501, 55.25485447474888, 59.251743180411204, 55.38010965074812, 57.63203818457467, 54.520548003060476, 35.95580210004534, 8.118066787719727, 0.8604029768279621, 0.18366432535861218, 2.8574368996279578, 1.679839591894831, 11.561644383839198, 38.68859461375645, 1.7642153671809604, 0.38974701347095625, 0.07827601009713751, 0.12290836764233452, 7.377770100321088, 51.26261411394392, 45.222572871616904, 26.67228443281991, 28.675441401345388, 34.47673559188843, 41.85552099772862, 19.646172216960363, 0.4027854438338961, 0.020888305302443247, 0.08248252009174653, 0.040665309344019206, 0.0503707248052316, 0.056513386978102584, 0.06136687672031777, 0.033662549752209864, 0.06283654285860912, 0.054587999757911475, 0.06335687065230948, 0.03158643615565129, 0.04263391245954803, 0.05021958452250276, 0.06421056270067181, 0.03179737233689853, 0.011081162174897534, 0.03251251771247812, 0.016798808671800152, 0.0370052541340036, 0.018195176064702015, 0.013139147012095367, 0.05229474138468504, 0.019235008928392614, 0.03288610552304557, 0.004550981443441872, 0.04490806667932442, 0.019960432413167188, 0.10095120514077799, 0.04230271612427064, 0.015648142201825976, 0.126400353120906, 0.20183511317840644, 0.07758724955575806, 0.06844940488891942, 0.15423058904707432, 0.14807179809681006, 0.14031014458409377, 0.12113597989082336, 0.1317290650414569, 0.1075404587068728, 0.10822384525090456, 0.1449909641274384, 0.11645176767238549, 0.0947674848139286, 0.18151415645011834, 0.11725234399948802, 0.06762973458639213, 0.14335699751973152, 0.15803394067500318, 0.10823483751820666, 0.1435844288872821, 0.1373225413262844, 0.12301347271672317, 0.15942299685307912, 0.13946368571903023, 0.1723871547728777, 0.11222788718129907, 0.09149860164948873, 0.1074163071545107, 0.1526214839624507, 0.20423608220049314, 0.1889274093721594, 0.24638694897294044, 0.1599248820649726, 0.11471405306032725, 0.1505166683346033, 0.09575058706104755, 0.1312010833727462, 0.23976070167762892, 15.724457808903285, 62.08908871241978, 56.3437796320234, 54.38767065320696, 36.9743697983878, 59.52902494158064, 70.16999653407505, 28.721697296415055, 0.3695456417543547, 0.3767624045056956, 0.4769306480884552, 4.37131757395608, 10.846356868743896, 0.3004494165735585, 0.5603184763874326, 0.3602209421140807, 12.393164839063372, 40.853403159550254, 72.32282638549805, 71.06464658464704, 68.68698692321777, 67.65039907182965, 70.411224092756, 61.24409743717739, 61.33716855730329, 63.23902252742222, 66.61538846152169, 67.44429465702602, 65.56531415666852, 60.398564202444895, 54.6617944581168, 51.90905366625105, 51.519610609327046, 50.67482083184378, 49.20780597414289, 48.79231759480068, 57.30876977103097, 60.916455132620676, 58.75862257821219, 65.57896041870117, 61.41452285221645, 59.441880634852815, 56.92089005878994, 55.526640210832866, 54.41228117261614, 61.70281055995396, 66.53887489863804, 64.83562823704311, 59.28062684195382, 65.36551175798688, 50.29562289374215, 31.615675858088903, 61.686308588300435, 57.48348222460066, 63.25601782117571, 62.60385990142822, 67.27049241747174, 64.04625034332275, 63.435114588056294, 65.18638025011334, 64.07377910614014, 53.573932375226704, 48.83147416796003, 53.58757168906075, 57.92951488494873, 59.47831698826381, 62.54193755558559, 64.44767556871686, 65.09162071772984, 60.450752122061594, 61.43654864174979, 58.87445599692208, 61.60334014892578, 59.32588740757534, 54.836055278778076, 53.698881830487935, 59.52514784676688, 58.48953969138009, 63.2262031010219, 60.2723571232387, 57.68286773136684, 53.50702122279576, 61.90894971575056, 54.523924827575684, 58.12672560555594, 54.30290610449654, 32.41227640424456, 6.190798044204712, 0.5037336498498917, 0.11246306741876261, 1.4732009257589067, 1.5927453339099884, 17.856206825801305, 35.34074061257498, 2.4120723520006453, 1.252691375357764, 0.33601092121430803, 0.23232672629611834, 15.725487879344396, 58.297428948538645, 41.16505765914917, 32.54433734076363, 36.694208008902415, 46.19430276325771, 51.891283648354666, 19.00054212978908, 0.5120111256837845, 0.1824300294475896, 0.268207739506449, 0.18718107736536435, 0.11040413432887622, 0.19406937488487788, 0.1458499894610473, 0.09209082022841487, 0.30327689913766726, 0.15611595287919044, 0.11327361142528908, 0.12874478660523891, 0.13685965830726282, 0.12889292437051023, 0.13992299964385374, 0.17120081771697315, 0.18760788946279458, 0.17569319451493876, 0.12144563613193375, 0.09557244447725159, 0.09608232283166476, 0.19544372042374952, 0.1615047287195921, 0.11894870868750981, 0.08551694226584264, 0.09934050549886056, 0.11234867319996868, 0.1023405734449625, 0.23193301313689776, 0.15380376337894372, 0.1349554719137294], [0.04168086592108011, 0.06185242280896221, 0.020041836259354438, 0.06398507872862474, 0.029703850924436535, 0.03517351492441126, 0.022254688232871037, 0.06658709767673697, 0.05248838170830693, 0.03803680717412915, 0.006816737944193716, 0.011691981943191161, 0.02833038069573896, 0.06513565020369631, 0.05421465961262584, 0.02800901124386915, 0.020850775530561805, 0.12295522727072239, 0.030051162466406822, 0.041539011390081475, 0.042642777519566674, 0.04128359045301165, 0.0504765050219638, 0.009417550372225898, 0.0189950450190476, 0.012703000817314854, 0.03696628586788263, 0.032167855849755664, 0.09812869623835598, 0.050423708212162764, 0.05125566678387778, 0.0509965614016567, 0.026637781877070665, 0.07638016968433346, 0.008635721967688628, 0.05156943155452609, 0.018789703359029124, 0.02633519597085459, 0.12365713103541306, 0.046311467087694576, 4.94623019865581, 33.03514071873256, 51.913569995335166, 35.47460460662842, 23.85976481437683, 32.56821829932076, 56.2130458014352, 31.843875544411794, 1.0151216089725494, 0.02340168382839433, 0.07314446688230548, 0.09891973914844648, 0.15455110184848309, 0.16571528278291225, 0.11936207222087042, 0.14872138681156294, 2.5408103125435963, 21.65655878611973, 55.39300898143223, 74.08688368116105, 66.94278757912772, 60.28845609937395, 59.92967891693115, 65.35629149845668, 63.89440441131592, 64.94897420065743, 61.29711219242641, 58.61689322335379, 56.13078260421753, 50.13666548047747, 50.72705391475132, 51.46663754326956, 50.80227163859776, 51.47407906396048, 55.25461476189749, 59.479741368974956, 60.02051271711077, 59.42295374189104, 59.505560874938965, 57.2216671534947, 59.790582929338726, 55.817818369184224, 55.79240533283779, 50.644700390951975, 55.86481598445347, 56.68992151532854, 64.44852324894497, 58.65161337171282, 66.66647161756242, 34.5882784979684, 17.15218234062195, 62.123489243643625, 55.92202745165144, 58.59302616119385, 59.18650654384068, 65.58512347085136, 57.8930333682469, 60.86633082798549, 56.54252937861851, 58.01864985057286, 46.915668215070454, 42.19610432216099, 45.067655835832866, 51.46145766122, 55.06186825888497, 59.50640855516706, 56.563311440604075, 61.55424417768206, 62.17975575583321, 63.870280265808105, 62.604513032095774, 62.43207958766392, 57.58708333969116, 56.605542591639924, 49.11916780471802, 54.28698778152466, 54.49035460608346, 60.13571384974888, 57.39999614443098, 62.53407914297921, 55.89925125667027, 57.26393304552351, 55.862554345812114, 41.07260145459856, 11.248387455940247, 0.6448696936879839, 0.07342500040041548, 2.05962541273662, 0.7831636528883661, 2.227669115577425, 2.8113347334521155, 7.592611874852862, 2.2206255963870456, 0.2845389646078859, 0.06812305668635027, 0.14415314979851246, 21.026051453181676, 50.93383925301688, 28.618745837892803, 18.864751747676305, 27.37619079862322, 37.42217077527727, 28.503139972686768, 3.9230758207184926, 0.06389417539217643, 0.026046866085380316, 0.03317842858710459, 0.01838206496488835, 0.04872008998479162, 0.022096416547096202, 0.024051677967820848, 0.058326639501111846, 0.02153733592214329, 0.02958365183855806, 0.06839200761169195, 0.04702842075909887, 0.07731574733874627, 0.0355361647504781, 0.04597807569163186, 0.009271078410425355, 0.005606379052291491, 0.01397644735074469, 0.010499115684069693, 0.02074870859671916, 0.03095491004309484, 0.044011820307267566, 0.03825637432081359, 0.08033060734825474, 0.04918666423431464, 0.038000373236302815, 0.015377567881452186, 0.04092071331771357, 0.05541048598076616, 0.06723983479397637, 0.030226265213319232, 0.048671293138925514, 0.047338680896375857, 0.014333799514653427, 0.014289148517751267, 0.024325629696249962, 0.01532755306522761, 0.028324468959388987, 0.047942597419023514, 0.08561630693397351, 0.0227780762195055, 0.048616667677249224, 0.03472346639526742, 0.051726709186498604, 0.041150699369609356, 0.05034633147131119, 0.03929719275661877, 0.01362142595462501, 0.014360700035467744, 0.0420026238342481, 0.04798543333475079, 0.0701902068353125, 0.03939391113817692, 0.032754659719233, 0.004661535154030259, 0.011360395450278052, 0.014410044798361403, 0.017490615835413337, 0.024900844187608788, 0.020826858867491995, 0.016871315227555375, 0.0746415119085993, 0.028236088076872484, 0.003309570244579975, 0.022769774343552332, 0.03282655728980899, 0.021864827456218854, 0.023519319748239856, 0.007053636995676372, 0.011798778266113783, 0.03086004066946251, 0.039248748748962364, 11.596966419901166, 46.02063601357596, 57.58294568743025, 32.844040938786094, 26.46236719403948, 51.755307401929585, 71.9876730782645, 22.944059985024587, 0.17040845166359628, 0.021066524221428802, 0.1921664641371795, 0.9099515037877219, 0.01212772271329803, 0.33342098018952776, 0.26243970330272404, 0.3023391366004944, 4.9938066857201715, 29.243988173348562, 61.850383349827354, 74.7361650466919, 67.23245797838483, 60.61491026197161, 61.54419708251953, 63.773415429251536, 63.64182349613735, 65.36353846958706, 63.231421198163716, 59.05810383387974, 57.783533232552664, 53.1323048727853, 52.00251388549805, 52.167481490543906, 52.46079274586269, 51.982384954180034, 58.39688546316964, 61.89870112282889, 59.1791900907244, 61.4433787209647, 62.10081032344273, 59.36875779288155, 62.387235913957866, 57.195962292807444, 55.366119452885215, 52.282175404684885, 58.209120818546836, 57.92048570087978, 66.89082895006452, 60.88966982705252, 66.38270023890904, 39.793031624385286, 20.600799117769512, 62.72243785858154, 56.27562127794538, 61.172232219151084, 61.7189234324864, 65.93937737601144, 60.33413355691092, 64.18947356087821, 58.19976159504482, 60.52063710348946, 50.391045979091096, 44.72343165533883, 47.53416558674404, 54.573243141174316, 58.8084203175136, 59.44196401323591, 58.525621686662944, 62.76375184740339, 63.462136132376536, 63.53086771283831, 62.9771796635219, 63.231504576546804, 60.05944347381592, 59.11289037976946, 51.02477380207607, 56.36515229088919, 57.47871923446655, 61.0536264692034, 58.460906164986746, 60.302651269095286, 57.40064580099923, 57.42966147831508, 57.91917249134609, 48.50117417744228, 17.79843602861677, 1.3323273935488291, 0.12044623547366687, 2.9800954035350253, 2.80486444064549, 4.4744444744927545, 8.970810515539986, 10.784192204475403, 1.5587228281157357, 0.539989132966314, 0.012574258127382823, 0.16267322030450615, 14.873126302446638, 61.61711842673165, 44.01254061290196, 21.369342838014873, 26.99878896985735, 41.75928497314453, 37.47917379651751, 9.934570823396955, 0.010965320132007557, 0.05164188213114228, 0.05809650756418705, 0.07097780957285847, 0.04500538895704916, 0.019850594557023475, 0.025083342966224467, 0.020994857352759157, 0.037243687946881564, 0.030039013296897923, 0.022266291181689928, 0.027376194218439714, 0.04579755823527064, 0.06314412956791264, 0.026670865548242415, 0.04805930204955595, 0.06421179763440575, 0.0799068147316575, 0.08487584880952324, 0.04369625402614474, 0.016138890957725898, 0.07829211851848022, 0.04725965531542897, 0.0853638919070363, 0.04053755137803299, 0.04137323510700038, 0.029895645632807697, 0.03633701249158808, 0.032854892912187746, 0.009842014738491603, 0.03310947925118463, 0.052166379522532225, 0.1481426235820566, 0.14343820459076337, 0.11503628934068338, 0.1704633180052042, 0.11187629069068603, 0.103007722645998, 0.13339096015053137, 0.1819329618343285, 0.09156706583287035, 0.13405386172235012, 0.12608866127473967, 0.1755231943513666, 0.1358119323849678, 0.16722088413579123, 0.14085821088935646, 0.19852025248110294, 0.07470578953091588, 0.20701233537069388, 0.16082491805510862, 0.11628921782331807, 0.13342325841741903, 0.14786686695047788, 0.10160748421081475, 0.11285054484116179, 0.10491355109427657, 0.06473973180566515, 0.16506736326430524, 0.13432328083685466, 0.1671182217874697, 0.1661005142543997, 0.12302531993814877, 0.12554176204970904, 0.12182742064552647, 0.1441415197082928, 0.055196727093841345, 0.13888447465641157, 0.15609631607575075, 0.15353499565805706, 0.2214356285652944, 0.13854204517390045, 9.04554099696023, 50.050740582602366, 68.30478736332485, 46.77902494158064, 35.393859590802876, 45.77527775083269, 68.4435567855835, 39.7558205468314, 2.068062914269311, 0.12461607743586813, 0.3889501148036548, 0.8242173556770597, 0.3871140261845929, 0.3919889474553721, 0.427518262394837, 0.4165297677474362, 4.043463783604758, 26.467481068202428, 59.37606034960066, 74.87056405203683, 67.97428240094865, 60.294820649283274, 60.57551397596087, 65.25976712363106, 64.43290369851249, 67.56146212986538, 66.34263692583356, 62.14960752214704, 61.4558298928397, 55.63195058277675, 55.3386184828622, 56.84876080921718, 56.907184737069265, 56.96738740376064, 62.02762494768415, 67.06942544664655, 63.6666077205113, 66.39531121935163, 65.43961429595947, 61.66033622196743, 65.57329763684953, 60.00546986716134, 59.842117718287874, 55.386453356061665, 59.9984313419887, 61.41522462027413, 68.42496340615409, 63.712375504629954, 66.50496074131557, 39.97711719785418, 24.4815799508776, 60.594635418483186, 59.27281706673758, 61.469107900347026, 63.70375973837716, 67.87474945613316, 62.55715411049979, 65.17861216408866, 60.040961265563965, 62.28255435398647, 50.52757460730416, 45.150568689618794, 49.47196953637259, 56.84418542044503, 60.93971075330462, 63.85956614358084, 60.10767786843436, 65.50017479487828, 66.46990013122559, 66.57529735565186, 66.40649781908307, 66.60486888885498, 63.131415775844026, 60.58119065420968, 52.85605491910662, 57.88302796227591, 60.08730575016567, 63.47919395991734, 59.907034737723215, 64.19936779567173, 57.90742308752877, 56.530390875680105, 58.27543095179966, 46.33254759652274, 14.902643987110682, 1.0525132311241967, 0.20063388906419277, 3.4461475610733032, 2.451965217079435, 5.6031141962323865, 10.347144433430262, 16.80347309793745, 3.924562300954546, 0.8789202517696789, 0.2874561223600592, 0.43411158717104364, 28.086835180010112, 61.5701208114624, 38.553702286311555, 31.10941273825509, 35.608357429504395, 52.40691988808768, 39.920176710401265, 8.0373261145183, 0.13030959692384514, 0.10055711878729717, 0.11251894477754831, 0.1312572525015899, 0.16422823257744312, 0.08979763649404049, 0.13451109933001654, 0.1840868898268257, 0.11760651213782174, 0.16794033481606416, 0.17893044437680924, 0.16712008097342082, 0.21015404750193867, 0.09675681378160204, 0.10817687705691371, 0.09014349936374597, 0.12431809199707848, 0.12867226478244576, 0.16108931601047516, 0.17074469290673733, 0.20294238733393805, 0.16411533792104038, 0.08466966237340655, 0.1898791225893157, 0.10973497666418552, 0.2436676248908043, 0.06163265210177217, 0.0925673892987626, 0.14625381279204572, 0.24919233843684196, 0.09503227631960597, 0.12475046808166163], [0.057986232052956305, 0.06105260644108057, 0.05760452217821564, 0.009757329327320414, 0.03322436540786709, 0.029760240577161312, 0.05000383074262312, 0.043235823911215575, 0.04465830811698522, 0.029708861905549253, 0.09196778825883355, 0.024326069047674537, 0.03200511261820793, 0.026713759139446274, 0.02451265260710248, 0.05850264469959906, 0.02609901489423854, 0.016077050972463827, 0.07154558053506271, 0.046794553486896415, 0.008587592630647123, 0.0628127127087542, 0.03692877645205174, 0.08177326100745372, 0.026631554621937018, 0.0488682006086622, 0.014556864509359002, 0.015605214683871185, 0.03806242187108312, 0.02943085932305881, 0.04788786339174424, 0.021300725672127943, 0.028624695260077715, 0.08561287354677916, 0.05356296743931515, 0.04675075065876756, 0.07335354387760162, 0.04297106293961406, 0.057211026150201044, 0.04015338181384972, 0.06685477974159376, 2.140363697494779, 23.908574172428676, 48.92782136372158, 41.22408608027867, 27.79220724105835, 29.62857096535819, 52.40663848604475, 46.56340149470738, 5.300978294440678, 0.09083767461457423, 0.06228710591260876, 0.3089488819241524, 0.015581513455669795, 0.1013646297422903, 0.17120839016778128, 0.013354993242371296, 0.22587311188025133, 6.554878439222064, 28.202998638153076, 50.95233883176531, 67.20210824693952, 65.94065584455217, 64.45706953321184, 59.71969740731375, 65.87129892621721, 64.33863748822893, 63.50511768886021, 63.189933504377095, 60.61179052080427, 60.43722397940499, 58.17599180766514, 54.43595368521554, 54.51898813247681, 55.737007345472065, 57.607966150556294, 60.25520202091762, 60.37095206124442, 62.22604465484619, 63.26774638039725, 59.17471545083182, 62.92967482975551, 61.955690247671946, 61.774925913129536, 63.267287799290244, 63.72835636138916, 60.01699692862374, 61.93378952571324, 53.1857921055385, 42.07776607785906, 47.68940918786185, 47.00420216151646, 69.15182835715157, 61.972831453595845, 62.9579678944179, 59.4287485395159, 62.763307162693565, 60.20359080178397, 61.882532664707725, 57.86355216162545, 54.61044379643032, 46.49070596694946, 50.40369170052664, 46.580514907836914, 49.701162815093994, 51.99459988730294, 55.65054396220616, 57.275018896375386, 59.9787540435791, 60.30206067221505, 60.99946526118687, 59.41213539668492, 61.47117151532854, 57.78452335085188, 56.753560066223145, 55.20984751837594, 58.841479846409385, 58.11743933813912, 63.73777117047991, 58.10037803649902, 58.82205268314907, 53.36908905846732, 22.14158821105957, 2.336195852075304, 0.03115040615999273, 0.1028919035036649, 0.5693841384989875, 2.631958301578249, 3.4096121958323886, 6.398427154336657, 3.4981424510478973, 1.087599354130881, 1.4169187801224845, 0.05998971526111875, 1.583596836243357, 31.844559941973003, 45.96548121316092, 19.179459980555944, 19.83670745577131, 29.927135058811732, 41.630659920828684, 17.122254712241038, 0.8584710519228662, 0.10247577833277838, 0.07908478312726532, 0.02943244370232735, 0.009323093208617397, 0.07946223858743906, 0.0464937419497541, 0.02829662527489875, 0.03803309898025223, 0.03722566266411117, 0.05631558044946619, 0.04440757924956935, 0.028202064634699906, 0.029278904798307588, 0.042707241739013364, 0.046471564032669575, 0.03033669000225408, 0.07483751353408609, 0.024603606833677207, 0.026079652897481407, 0.054144631406026225, 0.07166959638042109, 0.04215898544394544, 0.02311901462131313, 0.020094795917559947, 0.03066919251744236, 0.026288986039747084, 0.02989622238757355, 0.01828707006227757, 0.019969811463462453, 0.036862636251108985, 0.004230019960752023, 0.007437251857481897, 0.03051213201667581, 0.012806525753278817, 0.02840214255931122, 0.040268318860658577, 0.02415972788419042, 0.0507215443732483, 0.052513609640300274, 0.033183395463441095, 0.012208694841579666, 0.05486848917124527, 0.0441832453943789, 0.0958321944677404, 0.045139888168445656, 0.05856072051184518, 0.03482461900317243, 0.029208639104451452, 0.007875817877772664, 0.029043734738869325, 0.030205461329647472, 0.012191136051634592, 0.045095603580453565, 0.05975781234779528, 0.04940827037873013, 0.009495779522694647, 0.08414296313588109, 0.0741598198988608, 0.023938868128295456, 0.026277508619906645, 0.04826950202030795, 0.050859076636178155, 0.053411029877939394, 0.06432463122265679, 0.05595594671155725, 0.009382678761280008, 0.023919348372146487, 0.024401550979486535, 0.010717816850436586, 0.05584282474592328, 0.01677639496379665, 0.029438591229596307, 0.02462360156433923, 0.007498504061784063, 6.0254830292293, 36.678994928087505, 53.83998237337385, 36.300033228737966, 23.214320591517858, 41.98282241821289, 74.73044667925153, 41.41346270697457, 1.7391237935849597, 0.04823607059993914, 0.13508994398372515, 0.07716238485383135, 0.06979733505951506, 0.16561290541929857, 0.13167235308459826, 0.10047634597867727, 0.7566885192479406, 11.940173557826451, 37.72903101784842, 57.26334592274257, 69.71491731916154, 66.43679196493966, 63.672235761369976, 61.585420744759695, 67.33859171186174, 66.57793767111642, 65.27028669629777, 64.61037458692277, 60.5539676121303, 59.5176021030971, 59.119067328316824, 56.20928682599749, 55.29670694896153, 56.77004814147949, 60.461487088884624, 62.64265864236014, 62.40182713099888, 64.62763391222272, 62.73628561837332, 61.58034855978829, 64.67067800249372, 62.11101722717285, 61.20827947344099, 62.80725451878139, 65.2392977305821, 62.65496390206473, 60.195246015276226, 55.41019882474627, 38.55684634617397, 38.360452038901194, 51.55611991882324, 67.62803282056535, 63.27331188746861, 63.90131092071533, 62.56469290597098, 63.099224771772114, 61.92822401864188, 61.342483929225374, 60.314518792288645, 53.099047320229666, 46.3545629637582, 50.317495822906494, 49.910442556653706, 53.75317505427769, 56.550842898232595, 59.416019439697266, 59.43073572431292, 62.40025683811733, 63.58816950661795, 62.82714721134731, 61.58111980983189, 62.24644456590925, 59.25140271868025, 57.64668498720442, 57.14028637749808, 58.58667550768171, 59.38550295148577, 64.16546058654785, 59.37681075504848, 58.764723096575054, 55.625794478825156, 29.313602175031388, 4.332810657364981, 0.19878858593957766, 0.9063179216214589, 2.7629552951880862, 5.114408305713108, 6.606292503220694, 5.464280937399183, 2.429339276892798, 0.9442017802170345, 0.3436241926891463, 0.07046333753636905, 0.865543395280838, 26.9014117036547, 63.15542180197579, 33.37885420663016, 16.434280565806798, 28.59721163340977, 47.74696806498936, 26.553294794900076, 2.1237818215574538, 0.046909843371914964, 0.04598077286833099, 0.01080976682715118, 0.03574838675558567, 0.03410219633951783, 0.038283739638115676, 0.07325859647244215, 0.026752888557634184, 0.0013929540436947718, 0.054592590047312636, 0.01473830477334559, 0.022668567452845827, 0.08087404604469027, 0.02050099242478609, 0.07209899369627237, 0.052392216332788975, 0.06713027174451522, 0.03946986974083951, 0.037900441991431374, 0.02476065376374338, 0.05177014560571738, 0.05624163370313389, 0.01814652849654002, 0.017423339088314345, 0.02832059282809496, 0.06724602303334645, 0.016200420513216938, 0.035639257968536446, 0.013415665299232517, 0.05271232540586165, 0.020521095721051097, 0.0462314813796963, 0.03941735113039613, 0.08814798894205264, 0.11904276721179485, 0.11484365324888911, 0.14602954339768204, 0.11761614733508655, 0.18554831854999065, 0.18366836942732334, 0.09129775528396879, 0.09600633369492632, 0.1585892265928643, 0.1980266318257366, 0.12618375117225306, 0.13053431415132113, 0.14387813955545425, 0.07015694504869835, 0.13955839563693317, 0.10548871808818408, 0.1334790882787534, 0.177104384505323, 0.1332720536738634, 0.09257658344826528, 0.2117906603962183, 0.17821165866085462, 0.2903993087155478, 0.1320104535136904, 0.23553413418786867, 0.12524425158543245, 0.13020046135144575, 0.15717017916696413, 0.14726420571761473, 0.1872815684016262, 0.15088519427393163, 0.1469815280288458, 0.12264325043984822, 0.11126134118863515, 0.09644133571003165, 0.19954891156937393, 0.12816621336553777, 0.22456585988402367, 0.09001136823956456, 0.171704534973417, 4.793897892747607, 38.227400984082905, 68.2542531149728, 53.05504090445382, 38.7862480708531, 42.068483284541536, 66.28708607809884, 56.01742969240461, 8.587412391390119, 0.23693072210465158, 0.7160231556211198, 1.4523935679878508, 0.2521922231784889, 0.19307764167232172, 0.37247384605663164, 0.12742358392902783, 0.8127091846295765, 9.530392374311175, 33.77915382385254, 53.62347650527954, 70.77480248042515, 67.71440587724958, 66.50459943498883, 58.47526114327567, 70.2903184890747, 68.45255470275879, 69.99076080322266, 69.53043569837297, 66.0865124293736, 65.63710294451032, 63.571667534964426, 59.00041988917759, 58.971077646527974, 58.15481717245919, 62.38956356048584, 63.820697920663015, 64.01581028529576, 67.74364389692033, 68.97216183798653, 64.97853183746338, 70.40948009490967, 67.04669788905552, 67.28543799264091, 66.82794080461774, 69.43894181932721, 66.14311245509556, 63.21821962084089, 53.329546860286165, 52.33399159567696, 53.16675751549857, 48.05512414659773, 68.89803845541817, 64.8432434626988, 65.71272713797433, 64.22910608564104, 66.38066441672188, 65.8527055467878, 65.76454680306571, 65.48916190011161, 57.79947934831892, 50.79407623835972, 54.691904476710725, 52.912880761282786, 55.402830260140554, 58.7126532963344, 61.01293781825474, 61.52883461543492, 63.41953672681536, 64.87117522103446, 63.53557859148298, 61.931309018816265, 64.95416450500488, 63.87893772125244, 61.06450039999825, 60.73103550502232, 61.90663596561977, 60.60382093702044, 66.72699737548828, 59.78159890856062, 59.357460021972656, 55.581127984183176, 26.66550646509443, 3.051640570163727, 0.17654433527163096, 0.5063061118125916, 1.6824926095349448, 5.124812798840659, 6.80181394304548, 19.727924721581594, 14.25074575628553, 5.402289543833051, 4.132138865334647, 0.14702194157455648, 3.300295970269612, 42.12227276393345, 55.64237982886178, 28.775254011154175, 29.470350061144146, 40.57877908434187, 57.74289321899414, 28.461692231042043, 1.8173680007457733, 0.24989790629063333, 0.2110711011503424, 0.11559681354888848, 0.14987440779805183, 0.22703483168567928, 0.10254212548690182, 0.14891156660658972, 0.11054547317326069, 0.07715093796806675, 0.134604845728193, 0.1558395041418927, 0.1414837794644492, 0.2506826998932021, 0.22195981043790067, 0.12857135305447237, 0.11590117721685342, 0.17477181181311607, 0.10758562878306423, 0.06108628213405609, 0.15852097954068864, 0.16747203708759376, 0.13444651636694158, 0.08757772097097975, 0.13006953123424733, 0.24311421172959463, 0.16190663858183793, 0.09967172558286361, 0.19592181619788918, 0.11037585977464914, 0.09215739129909448, 0.13206116722098418, 0.10534522150244031, 0.1058300890560661], [0.09960491702492748, 0.038509634123849015, 0.022826521923499446, 0.05762528534978628, 0.02087524180699672, 0.002843294126380767, 0.06717054958322219, 0.035148965527436564, 0.011047605225550277, 0.0038107909162395765, 0.020951336116663048, 0.047364797709243636, 0.057407984510064125, 0.08576733525842428, 0.040196628243263276, 0.018846678248207484, 0.02190102729946375, 0.024616012150155644, 0.0032583313087733196, 0.02665252983570099, 0.04082255644191589, 0.06884684320539236, 0.05674761387386492, 0.07705393460180078, 0.009447901243610042, 0.028918673949582235, 0.033614529828940115, 0.02244601984109197, 0.019560313883370588, 0.008006767502852848, 0.02101786986791662, 0.042024974777762375, 0.032839344282235415, 0.0765584208337324, 0.027581464632281234, 0.026484626345336437, 0.053543686866760254, 0.01548389601521194, 0.029578223558408872, 0.07430491104189839, 0.04790207530770983, 0.018767898636204854, 0.4055784839604582, 16.834899800164358, 52.850048201424734, 48.35031488963536, 35.51748888833182, 23.073301689965383, 42.1044019971575, 54.15518045425415, 17.50609925815037, 0.5324486547282764, 0.06557316958372082, 0.43708864599466324, 0.529505658362593, 0.22298366549823964, 0.11366994372968163, 0.04370208942730512, 0.018754015809723308, 0.3783242292702198, 5.584055721759796, 20.40956211090088, 47.37643105643136, 64.39701625279018, 65.89713232857841, 64.97488403320312, 65.00052288600376, 63.85455649239676, 60.33625275748116, 63.49484825134277, 61.965556689671104, 64.05949360983712, 65.80787576947893, 63.174480710710796, 60.15784386226109, 64.56218188149589, 65.17651380811418, 64.11735820770264, 61.297542980739046, 62.50780800410679, 60.19144535064697, 60.84636170523507, 61.1836759022304, 63.6526974269322, 58.46058654785156, 59.81093420301165, 65.41840144566127, 68.85477202279228, 47.432864325387136, 36.4289014680045, 58.88525349753243, 40.04290621621268, 64.6448723929269, 62.907989501953125, 62.850097111293245, 58.24825307301113, 59.57596002306257, 61.465265546526226, 61.43364429473877, 56.90855005809239, 51.47687571389334, 47.95481300354004, 48.202623980385916, 49.26034477778843, 53.99484729766846, 56.04244320733206, 55.84553125926426, 55.14715044839041, 59.27650656018938, 63.23192841666085, 64.5841451372419, 63.84953989301409, 63.43875544411795, 62.06495067051479, 61.28942748478481, 62.192630767822266, 59.613153730119976, 60.46457208905901, 59.20062528337751, 62.45076329367501, 39.00535603931972, 5.192357540130615, 0.04768473036321146, 0.1274063762809549, 0.05746880838913577, 0.3093350769153663, 3.4958011252539496, 6.930203625134059, 6.848323447363717, 3.465172163077763, 3.356553145817348, 0.2325540626687663, 0.44559807223933084, 6.014058453696115, 42.70496606826782, 45.449619156973704, 23.754640306745255, 25.101720571517944, 34.75090108598982, 38.51434074129377, 13.184903383255005, 0.3413887997823102, 0.04693614678191287, 0.028905164317360947, 0.0390946602315775, 0.032335572742990086, 0.054997115662055354, 0.046291938849857876, 0.02627300314738282, 0.008113506998467659, 0.045964067336171865, 0.02543047639275236, 0.028125838010704944, 0.005043647060769477, 0.025261137800823365, 0.04003560849066291, 0.017878571625000665, 0.01688770524093083, 0.06589612511119672, 0.0574326967554433, 0.022570588692490543, 0.05686257806207452, 0.03338031989655324, 0.07160892856440373, 0.02119442298343139, 0.03712238624159779, 0.11703684127756528, 0.04660039747666035, 0.06360914997224297, 0.02928081148170999, 0.011708860501780041, 0.006058357165394617, 0.06734840039696012, 0.04177548762943063, 0.025440910565001622, 0.05401342987482037, 0.020652512687125375, 0.007202265850667442, 0.03644322357805712, 0.043047197961381505, 0.07225623061614377, 0.02681777686146753, 0.022022910848526017, 0.078559217043221, 0.017858269857242703, 0.012893256947531231, 0.050165902224502394, 0.04820853904155748, 0.05402079876512289, 0.055411381646990776, 0.01661124123659517, 0.05575341418651598, 0.05647700732307775, 0.015983197705021927, 0.1126684599689075, 0.11770802097661154, 0.013931300175110144, 0.04662488241280828, 0.1024258720821568, 0.014879061773951565, 0.027014903158747723, 0.03028824260192258, 0.026074261936758245, 0.025990941229143312, 0.024950555359412516, 0.027193741240937794, 0.05032361751156194, 0.03045397138755236, 0.0075818078060235295, 0.10034768895379134, 0.07896202257169144, 0.025780814200905815, 0.021752823377028108, 0.00792343492087509, 0.01865059180584337, 0.004604527186269739, 0.027466178139937774, 0.046714632239724906, 1.7981147595814295, 27.403412103652954, 58.8996501650129, 44.512786592756, 25.99912210873195, 30.502421583448136, 67.64494473593575, 63.331551688058035, 13.098288008144923, 0.2898412543748106, 0.05911066635910954, 0.16024985962680408, 0.50152352558715, 0.6694124681609017, 0.40347570393766674, 0.015888275744925653, 0.09426045630659376, 0.9268102220126561, 9.429666944912501, 28.756283691951207, 55.13513701302664, 67.2031991141183, 64.04801518576485, 65.48012924194336, 67.03175231388637, 64.84401471274239, 61.901758330208914, 65.33257034846714, 65.99675559997559, 66.57606165749687, 67.45457799094063, 64.29626737322126, 61.65372848510742, 66.1164939062936, 65.26477677481515, 65.07626519884381, 63.85133252825056, 64.16540500095913, 61.011972018650596, 64.80224214281354, 63.25268963405064, 65.02220126560756, 62.02342128753662, 63.57787922450474, 65.02983038766044, 71.67503193446568, 50.292079312460764, 45.574176039014546, 59.71199185507638, 43.24718264171055, 68.05663245064872, 64.56110491071428, 67.59108924865723, 60.51422391619001, 62.49580846514021, 62.37884249005999, 65.02166625431606, 60.164041655404226, 56.70177166802542, 49.81042671203613, 51.13357216971261, 49.78851556777954, 53.58533089501517, 57.11377552577427, 57.31028100422451, 56.63084445680891, 62.303927012852256, 63.12776797158377, 66.72815772465297, 65.06357084001813, 66.37894821166992, 64.3903876713344, 63.69128772190639, 62.86915602002825, 61.46095071520124, 61.3812826701573, 60.634149823869976, 63.22306251525879, 46.938479151044575, 9.912522452218191, 0.4552341380289623, 0.7832111503396715, 1.2988478243350983, 2.5491344715867723, 4.6810274464743475, 5.329772932188852, 6.362646537167685, 2.7295338085719516, 1.4133660793304443, 0.42836298421025276, 0.2323096272136484, 3.2149039123739516, 41.50711400168282, 59.32701996394566, 29.278218473706925, 15.916950702667236, 31.901580333709717, 46.62180805206299, 21.65197992324829, 0.6158225866300719, 0.06843311326312167, 0.022153983458078334, 0.010170352745002933, 0.02739828562230936, 0.022351119933383803, 0.032138767053506205, 0.02329244138672948, 0.019830869544031363, 0.03611920275060194, 0.042966398011360846, 0.08718995177852255, 0.02108529250004462, 0.017737777304968665, 0.09048962007675852, 0.024506142063598548, 0.0050111104584565115, 0.07565043241317783, 0.006769116660247424, 0.026383919874206185, 0.029489233690713133, 0.0722429109737277, 0.0541201939673296, 0.05242741872955646, 0.03138053809691753, 0.062391478169177256, 0.020409288417015756, 0.10945347962634903, 0.015476895230157035, 0.02655313124081918, 0.0344325987888234, 0.015404856863564678, 0.05474343177463327, 0.04328598800514426, 0.03192243312618562, 0.20409686038536684, 0.14301177247294358, 0.12180334622306482, 0.06536203662731818, 0.15532795659133367, 0.10832149322543826, 0.13660416273134096, 0.1868976125759738, 0.08573562731700284, 0.0880838945241911, 0.12927108550710337, 0.14452951960265636, 0.16205345998917306, 0.09874792051102434, 0.12371093886239187, 0.20504706725478172, 0.13163371730063642, 0.2362402720110757, 0.3204460064215319, 0.1561396201806409, 0.10964247877044336, 0.12136381837938513, 0.09219494142702647, 0.133767465661679, 0.056881271701838286, 0.12491658702492714, 0.17183589935302734, 0.13268840499222279, 0.21465726728950227, 0.11409947675253664, 0.12141565845480987, 0.1842523438057729, 0.1137377836608461, 0.16656581285808766, 0.19625564185636385, 0.11559970410806791, 0.10417598352900573, 0.11756759136915207, 0.11286295524665288, 0.15413429135722773, 0.06613724931542363, 0.13449793575065477, 1.3819551191159656, 27.647886208125524, 69.82407351902553, 61.835799080984934, 46.745802130017964, 36.842618056706016, 54.83616297585623, 66.8657112121582, 23.4842528956277, 1.330197987811906, 0.18606937916151114, 2.4795630276203156, 1.6104394644498825, 0.7460304168718201, 0.23356144289885247, 0.17769755981862545, 0.23048990485923632, 0.9998591308082853, 7.750532269477844, 24.857583454677037, 50.9261406489781, 67.10427066258022, 67.21781812395368, 65.76036398751395, 70.29618971688407, 68.85634926387242, 63.187230655125205, 67.2769889831543, 67.8585740498134, 71.92001152038574, 73.06372669764927, 69.99791049957275, 64.9915805544172, 71.1346913746425, 69.70371682303292, 69.77352537427629, 66.74545179094586, 65.6367416381836, 63.549301283700125, 64.35049111502511, 65.33436298370361, 67.62019525255475, 64.64703328268868, 64.06040382385254, 66.50637122562954, 71.4097010748727, 53.375210421425955, 46.1319704736982, 58.72166510990688, 47.74165964126587, 64.18470709664481, 65.83960124424526, 66.23970631190709, 61.68859454563686, 61.612553460257395, 65.47031143733433, 66.1703632899693, 60.639347076416016, 57.303555147988455, 52.69872685841152, 53.07306800569807, 54.36633620943342, 57.62727519444057, 60.42102772848946, 60.67934785570417, 61.04534421648298, 65.50337096623012, 68.91540200369698, 69.73423331124442, 69.77539443969727, 68.27051884787423, 68.28095504215786, 64.79778834751674, 65.43261745997837, 62.607403482709614, 62.99596759251186, 60.89217117854527, 65.6433493750436, 43.82964318139212, 6.588349214621952, 0.28996776044368744, 0.30829368851014544, 0.7037955746054649, 2.100673850093569, 10.765044706208364, 16.87906081335885, 20.200685364859446, 8.80815839767456, 11.499021138463702, 0.819943833564009, 0.6733074762991497, 9.750111784253802, 52.6145772252764, 57.63215282985142, 33.91792672021048, 34.4780661719186, 44.934191363198416, 54.31770576749529, 21.95906945637294, 0.5460909541164125, 0.19140514784625598, 0.13590472883411817, 0.0913073361984321, 0.2709336589489664, 0.08069035982979195, 0.11610713973641396, 0.14945189761263983, 0.12347129386450563, 0.11563211094055857, 0.1431373150220939, 0.2374591108943735, 0.10868894707943712, 0.14026418062193052, 0.16594271415046283, 0.09553416153149945, 0.11574611839439188, 0.1547314157443387, 0.17411697123731884, 0.18193796942276613, 0.14155680340315613, 0.16819535541747296, 0.21301173844507762, 0.14774132440132753, 0.10564125954572644, 0.1709837815059083, 0.07338255803499903, 0.13938459567725658, 0.09271199868193694, 0.12048616047416415, 0.1639155229287488, 0.1250823802713837, 0.1630270763167313, 0.09546244038002831, 0.17234952322074346], [0.033082113933882544, 0.08758796006441116, 0.033661881395216496, 0.08256222081503697, 0.016634815239480565, 0.017181175029171363, 0.04940780218956726, 0.027860233959342753, 0.04599365485566003, 0.02194341198940362, 0.032106027738856416, 0.04518844074170504, 0.009159634970793766, 0.03301995673349925, 0.04926719277032784, 0.02176535761516009, 0.04128686099180153, 0.0060762132384947366, 0.05819269668843065, 0.012582062128266054, 0.07083258272281714, 0.053831840333129675, 0.0476623692416719, 0.03706539608538151, 0.09396762094859566, 0.02500103666846241, 0.01798409060575068, 0.04901655211246439, 0.0547813211700746, 0.018809375785557286, 0.04410296791632261, 0.008836613286153545, 0.062425934177424224, 0.049235627321260314, 0.08608607708343438, 0.01444537442044488, 0.06485342034803969, 0.03630778120298471, 0.029545345144080262, 0.042515168831284554, 0.061168432368763855, 0.04152478590341551, 0.014332059072330594, 0.18897276265280588, 11.01980996131897, 47.896465505872456, 48.64040565490723, 40.84970671789986, 25.246204887117656, 31.808168751852854, 56.43558618000576, 41.330476897103445, 7.055164371218, 0.27668831444212366, 0.1878210308828524, 0.21287797205150127, 1.0727882917438234, 0.16343703360429832, 0.18923387649868215, 0.019995375270290033, 0.10260296293667384, 0.19446580218417303, 2.8931076484067098, 19.44507224219186, 49.0163448878697, 65.72768660954067, 66.76244013650077, 69.70806639535087, 69.16360555376325, 70.62882777622768, 66.95840018136161, 65.68970080784389, 63.31032494136265, 59.28867285592215, 58.47976357596261, 63.06324005126953, 60.58262893131801, 61.27298109872, 61.92037255423409, 63.07885960170201, 62.262870107378276, 66.07968929835728, 65.50692844390869, 72.59603650229317, 66.77334880828857, 66.46876757485526, 50.85580056054251, 46.78246429988316, 33.01777022225516, 31.91664055415562, 43.35242005756923, 44.41298614229475, 57.12839106151036, 67.60895306723458, 63.09232521057129, 63.25020912715367, 60.10370349884033, 59.618865149361746, 61.392135756356375, 61.984844888959614, 60.05427401406424, 56.73478255953108, 61.07406112125942, 62.373388154166086, 63.83016831534249, 60.8426513671875, 60.86583055768694, 60.63126632145473, 58.52669170924595, 59.97707257952009, 61.37993471963065, 62.24176842825753, 65.10081318446568, 65.2356082371303, 62.76676736559187, 61.088728768484934, 63.510773522513254, 64.24269676208496, 64.83225836072648, 29.33269235066005, 1.6872194473232542, 0.018002899596467614, 0.4626963404672486, 1.5350469499826431, 3.7579614349773953, 4.361925346510751, 4.955286306994302, 5.430061059338706, 6.956907723631177, 0.6448733849184853, 0.5270406220640454, 0.5431126196469579, 18.701173782348633, 49.28389917101179, 35.0015538760594, 20.149603945868357, 28.735569374901907, 42.396160330091206, 36.5119845526559, 6.8416023680141995, 0.07918688229152135, 0.07840488425322942, 0.013867466993230795, 0.09122270931090627, 0.029770761262625456, 0.034518840589693615, 0.018548144892390286, 0.052198664218719514, 0.05447684893650668, 0.02009413773859186, 0.12221645191311836, 0.06796887317406279, 0.03708283104268568, 0.07030561885663442, 0.02759953571616539, 0.001277880123650123, 0.07086627198649303, 0.032883533875324895, 0.014482123877054878, 0.051499416918626854, 0.017973610632387654, 0.0353909243297364, 0.010359792936859387, 0.06444558687508106, 0.06920029209660632, 0.04798232903704047, 0.01061337928487254, 0.06353421256478343, 0.03215234114655426, 0.027514136995055845, 0.08068973557757479, 0.020720924284043055, 0.04935617585267339, 0.07617833944303648, 0.046353929809161594, 0.0431416296799268, 0.023509119670572023, 0.10420912317931652, 0.044649015579904826, 0.022667293503348316, 0.04308057509894882, 0.055675620146627934, 0.04739490430802107, 0.007924479016635035, 0.016224917323727692, 0.039382494786488156, 0.0607634216014828, 0.025359569483303597, 0.0377918390690216, 0.038395348470658064, 0.02579165549416627, 0.048060567517365725, 0.013849871732028467, 0.0826703996530601, 0.03690313800637211, 0.006821293458675167, 0.011219978565350175, 0.05999169658337321, 0.028776558182601417, 0.04928178805857897, 0.0438127449181463, 0.04690766188183001, 0.015061684385208147, 0.030008553859910796, 0.005102560015594853, 0.04639898453439985, 0.03671779616602829, 0.049935987418783565, 0.05273567718852844, 0.015544136354167546, 0.030058982582496743, 0.053468369479690275, 0.022477083174245696, 0.019374787142234187, 0.02506388258188963, 0.034268959891051054, 0.029945914899664264, 0.031286371007029495, 0.028582605732870952, 0.518941302384649, 19.691521372113908, 61.06443091801235, 51.277702127184185, 33.84690570831299, 22.961618082863943, 49.72234092439924, 72.59584195273263, 34.960364954812185, 1.86699464065688, 0.14915252796241216, 0.5182833948305675, 0.4553201491279261, 0.8651272633246013, 1.0721811928919383, 0.8166096210479736, 0.07896688766777515, 0.12303633934685163, 0.46357979306152886, 6.4384956785610745, 28.191924946648733, 57.82659469332014, 66.61358887808663, 67.3366253716605, 69.97068745749337, 69.07965047018868, 69.64039094107491, 67.06106676374162, 66.75428989955357, 65.13449110303605, 60.740130696977886, 59.8480167388916, 65.69294561658586, 64.96548312050956, 64.14794417790004, 61.6552015032087, 63.27274213518415, 62.46834223611014, 65.52748121534074, 65.2397632598877, 71.02799483707973, 67.09124279022217, 67.73973900931222, 55.76038108553205, 49.7781731741769, 40.61009461539132, 34.07264573233468, 49.98654270172119, 44.0949010848999, 57.03587927137102, 67.60891137804303, 61.61850806644985, 61.936617442539756, 60.63302421569824, 60.529662813459126, 61.57595729827881, 61.18184157780239, 58.51556069510323, 55.27277735301426, 59.203995159694124, 65.07075527736119, 66.5718024117606, 63.96321242196219, 62.19525023869106, 62.35067449297224, 60.99572018214634, 63.65082836151123, 63.436941964285715, 66.16540922437395, 65.42261900220598, 64.68567221505302, 62.99430002485003, 63.56187752314976, 62.89376653943743, 65.11607837677002, 66.40197454180036, 39.66948570523943, 3.399281527314867, 0.39308043888636995, 2.4386337952954427, 3.4256049948079244, 4.521625782762255, 6.122371315956116, 3.0962686325822557, 1.2072384314877647, 2.830736058098929, 0.8955496251583099, 0.09164166397282056, 0.6305016875267029, 15.08633177621024, 57.44143867492676, 52.04312610626221, 27.378204039164952, 25.08646580151149, 42.71928630556379, 44.60056318555559, 13.108474067279271, 0.20368013131831372, 0.04859245415510876, 0.05523518306602325, 0.06149199857775654, 0.017731178551912308, 0.02624702882686896, 0.03981152569342937, 0.10123177937098912, 0.030866910836526325, 0.024962051438965967, 0.018336102699062655, 0.03202511922323278, 0.034780853494469605, 0.04695753759837576, 0.029063615814915726, 0.026624275637524467, 0.05117993209777134, 0.01644086618242519, 0.0035524535508427236, 0.02689210189107273, 0.061940422015530724, 0.02423518437093922, 0.01572108980534332, 0.05900215503892728, 0.045309820478515964, 0.022817546601540277, 0.024148274213075638, 0.08247498156768934, 0.07559089096529142, 0.008016522291914692, 0.021072084815906625, 0.03477606303723795, 0.02262427268682846, 0.035846027944769175, 0.0073800462663971955, 0.04391154979488679, 0.12022227820541177, 0.14709727253232682, 0.09140410886279174, 0.13737397428069795, 0.06533512592847858, 0.12917191082877771, 0.10162686995629754, 0.12323380660797868, 0.16070758577968391, 0.22791641152330808, 0.11312360090336629, 0.13271819267954144, 0.06897317285516433, 0.13442017563751765, 0.2556510961481503, 0.11030785020973001, 0.12867991865745612, 0.15661470325929777, 0.11690361771200385, 0.07000598457774945, 0.12272429466247559, 0.11814620532095432, 0.11665884298937661, 0.1631683065955128, 0.2736580584730421, 0.14986135278429302, 0.10638289153575897, 0.1288628109863826, 0.09721319643514496, 0.11343057014580284, 0.30326463122453007, 0.13518576669905866, 0.1714943383953401, 0.1192516338612352, 0.2364662784550871, 0.12759841526193277, 0.15588485742253916, 0.1724986380764416, 0.15254997994218553, 0.18192632576184614, 0.14862560480833054, 0.1326963302812406, 0.05003791694928493, 0.48426653444767, 17.97262041909354, 67.7512799671718, 66.54430144173759, 52.7871287890843, 36.88265357698713, 44.5711201940264, 68.2999027797154, 51.760622773851665, 9.680728810174124, 0.43327707052230835, 1.553805023431778, 3.896080766405378, 2.5095293053558896, 0.4415324261145932, 0.42002984136343, 0.1543702586953129, 0.2760505186659949, 0.25594055918710573, 5.282168652330126, 23.996519259044103, 53.553438663482666, 67.2391004562378, 69.9933385848999, 73.52635860443115, 72.8445040839059, 74.6104929787772, 71.68557235172817, 68.31472328730992, 67.52077347891671, 63.727091789245605, 62.646368980407715, 66.73379271371024, 66.27367605481828, 63.449330602373394, 63.34128611428397, 63.390611376081196, 66.58750534057617, 69.37364264896938, 70.25661277770996, 73.21439143589565, 71.48216383797782, 68.13854476383754, 61.263698305402485, 51.14270210266113, 43.449472495487754, 40.02978106907436, 50.8729521887643, 50.75840071269444, 56.449833461216514, 70.536500113351, 64.27044786725725, 67.3457692010062, 65.76930631910051, 65.07264518737793, 66.31961754390171, 66.69580691201347, 65.0119457244873, 62.330330167497905, 67.07739503043038, 69.38882446289062, 71.16058036259243, 66.8165249143328, 64.94748033796037, 66.08874974931989, 64.18427630833217, 64.88849013192313, 65.91245310647147, 64.63755593981061, 68.40299320220947, 68.46369961329869, 67.31172997610909, 65.77889483315604, 67.91104684557233, 66.786863054548, 71.34117794036865, 33.166437353406636, 2.5997288652828763, 0.16914056826915058, 1.5290835499763489, 3.9096762197358266, 7.741866997310093, 14.44507818562644, 13.16829024042402, 16.005099024091447, 18.42521217891148, 4.084684406008039, 1.156148870076452, 1.2447503443275179, 24.510831866945537, 62.636440004621235, 45.30002791540963, 31.923699923924037, 39.765120710645405, 53.273089272635325, 51.606157370976035, 12.714869039399282, 0.17833226147506917, 0.1950330710304635, 0.13138348715645926, 0.17498503465737614, 0.0766171548249466, 0.07188183534890413, 0.10981815148677145, 0.3025647630648953, 0.14240187805678162, 0.08706827009362833, 0.22181125198091778, 0.17099298244076117, 0.20844355571482862, 0.27136197739413803, 0.09572737437805959, 0.1384667277868305, 0.14054737399731362, 0.28735713767153875, 0.08528151097042219, 0.11701541314167635, 0.13518219760486058, 0.16022388530629023, 0.08795230622802462, 0.22390078700014523, 0.11197282586778913, 0.17781669699719974, 0.10421478216137205, 0.3104946661208357, 0.19974104554525443, 0.14839130666639122, 0.18895170092582703, 0.05909075814166239, 0.17185006716421672, 0.10532485866653067, 0.1132803832047752, 0.1761368207101311], [0.03245944609599454, 0.047006605858249326, 0.06991143072290079, 0.01780604471319488, 0.02780729635352535, 0.05251696838864258, 0.0823940255546144, 0.03685021906026772, 0.027956652089155147, 0.03468783652143819, 0.10184694600424596, 0.011610896160293902, 0.020689698102484857, 0.00503735661706222, 0.07632963239614453, 0.031496292778423855, 0.01678236946463585, 0.03657925288592066, 0.06418492086231709, 0.027749720960855484, 0.02615961994576667, 0.01703008054755628, 0.017938962937997918, 0.021802446339279413, 0.03617199616772788, 0.0454619683857475, 0.08837888762354851, 0.02346979856624135, 0.050107568568949185, 0.01178907267084079, 0.018110106433076516, 0.07689493349088089, 0.05621264668713723, 0.023978000939158455, 0.026339296018704772, 0.029200740956834385, 0.06262947432696819, 0.06349590926298074, 0.038392936278666766, 0.028792853201074258, 0.03693891376523035, 0.036981824319809675, 0.052576842318688116, 0.028464272618293762, 0.022932860235284482, 5.548510474818094, 36.09366825648716, 49.499321120125906, 47.668561117989675, 42.29291704722813, 23.900225911821636, 36.23731184005737, 52.43943745749337, 24.92587035042899, 1.5105429334299905, 0.2843995120908533, 1.7788569586617606, 1.363851153424808, 0.570251849080835, 0.012586690585262008, 0.2602473295160702, 0.09881828459245817, 0.014872581764523472, 0.254061505730663, 5.362997480801173, 27.372906037739344, 54.377050331660676, 66.07340812683105, 63.63376358577183, 64.46689428601945, 68.25397518702916, 69.640932900565, 67.50857939038957, 69.58900901249477, 69.80397238050188, 65.07010214669364, 63.987989698137554, 64.29121603284563, 60.128557205200195, 60.77544839041573, 61.57830578940255, 60.65281963348389, 61.12467179979597, 65.84194278717041, 59.055227279663086, 53.589239256722585, 63.30788612365723, 62.91046306065151, 38.32855633326939, 38.29812669754028, 34.86684914997646, 50.977262020111084, 51.58312061854771, 66.90874835423061, 66.43643760681152, 63.33204501015799, 60.43495191846575, 59.75442450387137, 60.57328360421317, 59.11666325160435, 58.72327709197998, 57.622227328164236, 59.94271373748779, 63.89420986175537, 66.56015028272355, 69.29390512193952, 65.11671761104039, 66.4680449622018, 63.54187365940639, 64.80897494724819, 66.87671715872628, 70.91989476340157, 69.59274714333671, 65.71700028010777, 65.58152430398124, 66.2357736315046, 62.624864305768696, 56.36025381088257, 15.481105838503156, 0.6588687396475247, 0.09583553286003214, 0.7736167194587844, 2.8612419068813324, 4.227329620293208, 5.518626272678375, 3.991214632987976, 1.014916854245322, 1.1848341822624207, 0.07547109560774905, 0.420063171003546, 4.620810883385794, 34.35659081595284, 44.89397866385323, 23.915838514055523, 18.808511291231426, 30.455962453569683, 43.067099230630056, 26.011599336351665, 2.830529132059642, 0.14143027019287857, 0.052172849353935034, 0.008401060809514352, 0.05269160633906722, 0.016307364417506114, 0.04080722833584462, 0.04720489414674895, 0.02396344636300845, 0.0657308679074049, 0.07280937914869615, 0.0435298026007201, 0.012813564705928522, 0.02910944746275033, 0.02357505800734673, 0.024705972322928052, 0.05774740808244262, 0.06941612730068819, 0.0747663691373808, 0.047193881523396285, 0.05146723061001726, 0.014001400476055486, 0.04219511064833828, 0.03319369901769927, 0.035760664846748114, 0.08783352188766003, 0.01955130972367312, 0.03212271291496498, 0.016570167815578834, 0.07587792484888009, 0.04329395400626319, 0.0050659097947313315, 0.011092408044662858, 0.013145481984663223, 0.025574882215421115, 0.08080381088490997, 0.06518713065556117, 0.04849728961874332, 0.05127091007307172, 0.04509729991800018, 0.051206924220813174, 0.02806244757292526, 0.020961122287969505, 0.03953109734824725, 0.053542509608502896, 0.07787070077444826, 0.03722753881343773, 0.008086246005924684, 0.041432654418583424, 0.046492418806467734, 0.015031835629737802, 0.015705096734953777, 0.003942969961956675, 0.012513178949510413, 0.05905744207224675, 0.04119968959795577, 0.05092941696888634, 0.05357563229543822, 0.024965235464540974, 0.029920666611620357, 0.019519464378910403, 0.05086006729730538, 0.040949177861745865, 0.08453563135117292, 0.040121877432933876, 0.03269201736631138, 0.048254004280482016, 0.008246388752013445, 0.009391257988422044, 0.04790276402075376, 0.07962483593395778, 0.0044952020481494916, 0.05206737447796123, 0.009656919715260821, 0.02442516230179795, 0.11273437964596919, 0.019354392075911164, 0.11509876884520054, 0.04304816826645817, 0.03162527550011873, 0.031402431029294214, 0.1277721609388079, 0.1421514307813985, 11.762925011771065, 48.37722526277815, 55.94059303828648, 40.68132407324654, 29.43614407948085, 32.00007799693516, 62.088518960135325, 70.43298585074288, 13.589093991688319, 0.4554651656321117, 0.243098361151559, 1.0219933773790086, 1.5935774892568588, 1.1893721159015382, 1.277840705854552, 1.2649542944771903, 0.33367171244961874, 0.15492220622088226, 0.6755825227924755, 9.626379132270813, 38.56833866664341, 61.02399240221296, 68.96409497942243, 63.90912764413016, 67.59662001473563, 69.61566925048828, 69.97369602748326, 70.05272483825684, 68.5107319695609, 70.2083158493042, 67.3298647744315, 63.49097810472761, 63.588009698050364, 60.100257192339214, 60.22096824645996, 61.148052488054546, 61.32741328648159, 62.746277127947124, 68.51599870409284, 62.409866196768625, 55.11668954576765, 60.473125321524485, 61.39727047511509, 39.69687897818429, 39.69992923736572, 43.34655230385916, 54.56558622632708, 53.148052964891704, 69.6410162789481, 68.29818657466343, 65.9271832874843, 63.29660224914551, 62.946732657296316, 64.85149097442627, 62.80733094896589, 61.56706360408238, 60.4831793648856, 63.22276374271938, 64.82915946415493, 67.05824579511369, 69.08479908534459, 65.02154118674142, 69.59907695225307, 63.01267801012312, 65.16477830069405, 68.54467391967773, 71.77299458639962, 70.592606816973, 68.53182670048305, 67.10231821877616, 66.1326345716204, 65.49666595458984, 60.6870881489345, 24.886821474347794, 1.9179507749421256, 0.1656178587249347, 3.149951283420835, 4.9195825542722424, 6.507744899817875, 8.377774817602974, 2.8405010998249054, 1.7557336794478553, 1.1747447465147292, 0.5009835202779088, 0.34800902168665615, 1.5308639172996794, 37.398289816720144, 66.07102489471436, 36.977180344717844, 19.461476939065115, 27.693346534456524, 46.436701093401226, 35.18679632459368, 6.363975380148206, 0.1380355187824794, 0.02537244977429509, 0.005339467548765242, 0.021391215102214898, 0.069002451641219, 0.02457544593406575, 0.051366441018347225, 0.012199350566204106, 0.010726413889122861, 0.05215565527656248, 0.055817240583045144, 0.054961044740464, 0.033647248787539344, 0.056748258482132635, 0.018511561676859856, 0.03601185851065176, 0.030884322045104842, 0.03027117744620357, 0.058581565107618055, 0.015785511616351347, 0.06256037910601922, 0.051472723350993226, 0.04780460375228098, 0.06315512183521475, 0.02368400019726583, 0.03274287356595908, 0.018316538838137473, 0.04328585569081562, 0.07504445992942367, 0.06029560563287564, 0.02821634610050491, 0.01991935051046312, 0.09449130749063832, 0.04677578860095569, 0.06490071423883949, 0.04323698759877256, 0.03171949687280825, 0.09955004389796938, 0.1892082957284791, 0.10945229897541658, 0.07011056039482355, 0.12392565448369298, 0.11502605703260217, 0.16689441379691872, 0.18930030507700785, 0.115608294361404, 0.09848654882184096, 0.24343290605715343, 0.10508006358785288, 0.17336252172078404, 0.12097165228000709, 0.17780798460756028, 0.08031861763447523, 0.11703252579484667, 0.2698946589870112, 0.17512977974755423, 0.14558696214641842, 0.09581901731767825, 0.1884702667593956, 0.16685433951871737, 0.12292932080371038, 0.11517671894814287, 0.14937845298222133, 0.20182019897869655, 0.0996865312169705, 0.15733549743890762, 0.14538633291210445, 0.07276715391448565, 0.10849981222833906, 0.09051085822284222, 0.05521276087633201, 0.11181461185749088, 0.21951722007777008, 0.12902971703026975, 0.2828412157084261, 0.16183098192725862, 0.2516948841512203, 0.14984649286738463, 0.10073412821761199, 0.12551194722098963, 0.17817752834941658, 0.15179200204355375, 9.771881358964102, 55.616018363407676, 66.5371378489903, 59.748789514814106, 55.41238055910383, 36.93552589416504, 48.24864884785244, 65.13235800606864, 32.32591724395752, 2.2907368285315375, 0.5257140589611871, 6.713245255606515, 7.165684155055454, 1.3384846917220523, 1.1904389900820596, 0.9105574627007756, 0.2647492193749973, 0.20654510972755297, 0.45629922087703434, 8.000363435064044, 31.903098515101842, 60.19291142054966, 70.14197444915771, 63.97833170209612, 65.42285524095807, 69.69214807237897, 71.18453080313546, 71.03082275390625, 73.25234249659947, 76.59813635689872, 69.89018562861851, 66.09594113486153, 66.97031634194511, 58.95183113643101, 59.790881701878135, 60.47855186462402, 58.71745450156075, 60.945429120744976, 66.51114463806152, 63.93947737557547, 56.46866307939802, 65.82108429500035, 72.43838882446289, 52.20892402103969, 41.51798445837838, 47.300025190625874, 56.479172229766846, 54.97838217871529, 69.00825772966657, 72.17831080300468, 67.60093484606061, 64.43962955474854, 65.0533778326852, 67.33832768031529, 62.78645856039864, 64.04810551234654, 62.970467703683035, 65.8042071206229, 68.90226296016148, 71.05052784511021, 74.701646396092, 68.88661561693463, 73.59937027522496, 69.89052609034947, 71.072970526559, 72.37800203050885, 76.09788690294538, 72.96634769439697, 69.57918425968715, 68.12314755575997, 67.17170292990548, 65.3391363961356, 60.05318314688546, 19.692506279264176, 1.2807691544294357, 0.1398618636386735, 1.9553848462445396, 6.344530412128993, 16.866970947810582, 19.257625477654592, 13.020222391401019, 10.146608131272451, 6.640868476458958, 1.345428221992084, 0.7400362927998815, 7.337310739925929, 43.86246994563511, 56.71675198418753, 33.8436678477696, 28.734709535326274, 39.09392472675869, 56.91915648324149, 39.201180594308035, 5.206531865256173, 0.2587528425667967, 0.1341752109250852, 0.07319534343800374, 0.1616866032459906, 0.12210570142737456, 0.2008043099194765, 0.12587060726114682, 0.09869526619357721, 0.2009132012192692, 0.23024359664746694, 0.13040164698447498, 0.14089471607335977, 0.09821301099977323, 0.11792193592659064, 0.1523455644824675, 0.2691770674926894, 0.12669780930238111, 0.1820377412119082, 0.11690169067255088, 0.08047336433082819, 0.1532703127179827, 0.12959584593772888, 0.1524724912430559, 0.28251033489193234, 0.2385330961218902, 0.10322807689330407, 0.09884018091750996, 0.1290916944188731, 0.23708255110042437, 0.11475230886467866, 0.1596328948757478, 0.11841588227876595, 0.12492262598659311, 0.1370872389525175, 0.14288827909954957, 0.13017846324614116, 0.1030550640342491], [0.06023691913911274, 0.08342858111219746, 0.052146193105727434, 0.026885038341528604, 0.08947122043796948, 0.0368460121431521, 0.04102170986256429, 0.1213361748627254, 0.01917650903175984, 0.05483181096081223, 0.014657806771408235, 0.03683023959664362, 0.10710851688470159, 0.070214057341218, 0.0459349310424711, 0.010256612357417387, 0.03285911340000374, 0.07128079581473555, 0.024021717254072428, 0.026129486205588495, 0.08552292694470712, 0.04508371903960194, 0.07923627285552876, 0.05173280582364116, 0.03524956512930138, 0.1093047990330628, 0.018317193624430468, 0.029705784749239683, 0.11601536108979157, 0.0669670162190284, 0.0474691394317363, 0.03661787849185722, 0.03873009693675807, 0.03276203200221062, 0.01188111340161413, 0.01382532063871622, 0.020667269127443433, 0.042510049284568856, 0.07753697011087622, 0.04453543560313327, 0.0881837952349867, 0.04532556927629879, 0.015032110436420356, 0.0321271199999111, 0.02497600211894938, 0.09456252652619566, 2.0586415912423814, 28.86427433150155, 52.69361993244716, 49.24833134242466, 41.238927432468955, 22.467175585883005, 27.653086934770855, 44.9850869178772, 49.838247299194336, 8.6059684242521, 0.6943173632025719, 1.5724628908293588, 3.8248052767344882, 1.3245025277137756, 1.2232327503817422, 0.5939411350658962, 0.27496521547436714, 0.09065769320087773, 0.10163666800196682, 0.3255379774740764, 9.62964391708374, 36.88297666822161, 64.96715068817139, 71.6559591293335, 69.02846309116909, 64.52936553955078, 63.16293280465262, 62.57763739994594, 61.57424109322684, 62.598245756966726, 59.72898020063128, 61.95065975189209, 65.6744634083339, 67.72669724055699, 64.54781995500836, 71.7514899117606, 67.75963170187813, 71.63729626791817, 74.41943836212158, 70.68019580841064, 48.70016016278948, 22.460249968937465, 36.97417524882725, 58.542533602033345, 31.123270920344762, 41.53291961124965, 43.45276941571917, 67.4038005556379, 72.30376052856445, 68.48231383732387, 70.63813836233956, 65.0487642288208, 68.81052589416504, 70.63509505135673, 72.27335521153041, 68.45790481567383, 70.10191808428083, 67.03801264081682, 66.70455469403947, 63.87700612204415, 67.43174621037075, 64.43983800070626, 62.95265947069441, 62.8873325075422, 66.53135694776262, 64.24116815839494, 65.22127410343715, 66.67783887045724, 61.78387519291469, 54.4332925251552, 24.70405432156154, 3.5837025684969763, 0.1161472818681172, 0.2926164897424834, 1.1880797509636198, 4.317111202648707, 6.05194046667644, 3.4715488723346164, 3.152183609349387, 2.4826614899294714, 0.08199481626174279, 0.7058810112731797, 0.8047951321516718, 19.81625369616917, 47.1121563230242, 30.45405169895717, 15.889347246715001, 23.877913509096416, 39.38694763183594, 40.80267088753836, 14.798045805522374, 0.34410752675362993, 0.13938178654227937, 0.04808659951335617, 0.04668966554371374, 0.03594917205295392, 0.08204809483140707, 0.04015964808474694, 0.03519682938765202, 0.020726286407027925, 0.026323321608028243, 0.05655645698841129, 0.03021208043875439, 0.016737523388915827, 0.03827436567683305, 0.04819609810199056, 0.037962568657738824, 0.053043202829680274, 0.05357851267659238, 0.05366070701607636, 0.05853447477732386, 0.03468643534662468, 0.08668490459344216, 0.057588719097631316, 0.033901712990232875, 0.03352585548002805, 0.005896701710298657, 0.039082443208566735, 0.018668276124766896, 0.02101658913306892, 0.053877129152949364, 0.013966213346325924, 0.0558882458800716, 0.0072069621611652625, 0.04173987811165197, 0.05463337678728359, 0.03465230164251157, 0.03824150422587991, 0.03357331561190741, 0.01601871562057308, 0.01771899715199002, 0.034024785671915324, 0.03305505395733884, 0.031272922442959886, 0.02050458187503474, 0.004372371518651822, 0.02156881825067103, 0.04746333456465176, 0.010442539434214788, 0.028461982562605823, 0.014903212531602808, 0.07238505048943417, 0.054414898689304075, 0.03377182103161301, 0.032000366265752485, 0.033174567722848484, 0.033318261083747656, 0.029086628330073187, 0.02978522762922304, 0.047271071667117734, 0.09634393879345485, 0.07916806651545422, 0.037595281044819524, 0.023881109531170557, 0.05728670994618109, 0.019855583485748087, 0.021252008554126536, 0.059092963380473, 0.03503111417272261, 0.041413855605891774, 0.06636810728481837, 0.01498696071627949, 0.046659898212445636, 0.003568470794042306, 0.030600304249674082, 0.025117030533562814, 0.028247216051178317, 0.08317042567900249, 0.050383416802755425, 0.011742465796747377, 0.022753894927778413, 0.02612452781093972, 0.022307887074670622, 0.06476474260645253, 0.04245733389897006, 0.04884720334251012, 5.587356550352914, 40.74375016348702, 63.10463741847447, 50.23354768753052, 30.54951994759696, 19.185958283288137, 42.986465385981965, 78.70747743334088, 48.909064701625276, 3.3871367275714874, 0.6686277559825352, 1.096317497747285, 1.4053159398691994, 0.9255416329417909, 1.2521993560450417, 1.571712376815932, 1.5562799934829985, 0.49228388709681375, 0.19598658915076936, 1.281047733766692, 16.694382905960083, 45.86430849347796, 68.33568600245884, 70.32402420043945, 66.62021051134381, 63.438553946358816, 62.170556340898784, 64.55915246691022, 63.41198403494698, 62.91493770054409, 61.49676867893764, 62.767767906188965, 62.22245938437325, 66.22171742575509, 61.82765579223633, 66.02012934003557, 66.12324755532401, 67.77507754734584, 70.51992865971157, 70.54571342468262, 62.94495391845703, 36.71846764428275, 45.73513453347342, 57.4918999671936, 37.219877447400776, 46.75328186580113, 47.34225286756243, 65.15391826629639, 71.66267108917236, 67.99666254861015, 65.75559752328056, 63.657144274030415, 65.92807960510254, 67.67177867889404, 69.33131422315324, 68.44079140254429, 70.89135156358991, 71.82969188690186, 70.03720951080322, 65.74763488769531, 66.38181781768799, 66.01252801077706, 67.04076412745884, 66.92531285967145, 68.10965415409633, 65.66613251822335, 67.08153615679059, 66.76428835732597, 64.28534480503627, 61.43453366415841, 32.646951811654226, 8.127492019108363, 0.3044674023985863, 1.1995984528745924, 2.0151541190487996, 5.795558452606201, 7.555431195667811, 3.83586767741612, 0.8910610888685498, 1.309375973684447, 1.744145495550973, 0.27174749385033337, 0.6313159838318825, 15.834211553846087, 60.394242422921316, 48.462847914014546, 20.048908914838517, 19.167529923575266, 33.39963626861572, 47.28613574164254, 22.97477970804487, 1.7113518438168933, 0.1477924452296325, 0.030561956843095164, 0.016626686389957155, 0.07339444596852575, 0.03760182551507439, 0.018787196172135215, 0.03014751783172999, 0.016179638681933284, 0.0806367691340191, 0.015355949755758047, 0.049068236124834845, 0.050470106436737945, 0.051636392782841406, 0.027518822279359614, 0.011130476403715355, 0.06324861039008413, 0.01149124583961176, 0.06392350846103259, 0.06582651420363358, 0.013283489222106124, 0.09196907747536898, 0.07646310023431267, 0.04513331994946514, 0.02907640620001725, 0.07036965899169445, 0.04716647210131798, 0.015797598021371023, 0.03170323917376144, 0.06940363547099487, 0.006922188647357481, 0.06922516040503979, 0.06385230299617563, 0.06177106646022626, 0.07178148680499621, 0.040909758369837484, 0.05226678913459182, 0.04194668201463563, 0.02906786683680756, 0.17694419595812047, 0.12515106158597128, 0.1200761217623949, 0.10055551744465317, 0.14115597919694015, 0.20890802650579385, 0.10516883632434265, 0.15670528768428735, 0.0712454780670149, 0.15787532632904394, 0.12345437120114054, 0.18072195324514592, 0.2511434794536659, 0.15554271292473587, 0.13612614838140352, 0.16290571354329586, 0.1250365927283253, 0.2070955644760813, 0.15824119241109916, 0.16634121776691504, 0.17199232881622656, 0.0952018965035677, 0.12421320405389581, 0.20340767236692564, 0.1545151937752962, 0.20351595298520156, 0.13272391951509885, 0.20623484280492577, 0.2404768546777112, 0.0675452094791191, 0.15558087373418467, 0.14081269476030553, 0.09508125976260219, 0.19587395233767374, 0.09116539345788104, 0.18210073640303953, 0.15762303343841008, 0.13479830963271006, 0.16649599160466874, 0.09960898823503937, 0.13460446574858256, 0.13801375137908117, 0.05093894020787307, 0.21910633998257772, 0.14288237584488733, 0.20423693715461663, 3.7248723762375966, 42.196809564317974, 75.47788524627686, 63.63489614214216, 53.89521360397339, 35.147653647831504, 36.46595273699079, 59.019054957798545, 60.96380015781948, 12.194774661745344, 0.9960570548261914, 3.21618390083313, 12.40572110244206, 7.636441111564636, 3.6939250997134616, 2.9411045014858246, 0.6500369821275983, 0.39092524881873814, 0.19257794134318829, 1.1503737228257316, 13.016215886388506, 40.74383006777082, 68.56784616197858, 72.89167540413993, 69.60102939605713, 65.65325055803571, 61.811667987278526, 64.03323636736188, 61.13714381626674, 65.02848938533238, 61.5578224999564, 61.976243019104004, 64.68005112239292, 70.98099722181047, 65.60743413652692, 74.33011926923479, 71.63586493900844, 71.48122583116803, 75.24992179870605, 73.69431046077183, 55.88882201058524, 28.98814160483224, 46.56904343196324, 71.02910654885429, 45.84510019847325, 53.67294420514788, 55.32191153935024, 65.52627222878593, 73.59178284236363, 72.53457273755754, 73.13945511409214, 71.0606861114502, 74.54187951769147, 75.89788995470319, 76.57118429456438, 73.60943126678467, 75.59410081590924, 73.88813740866524, 71.84788921901158, 64.10130786895752, 68.09464604513985, 66.94836698259626, 68.05753571646554, 65.68359334128243, 68.56766550881522, 63.43381527491978, 67.26061902727399, 72.70356682368687, 66.11660507747105, 60.82522528512137, 30.25670896257673, 4.580556494849069, 0.23453796335629054, 0.6430818353380475, 3.465853303670883, 11.152465837342397, 14.520243797983442, 15.729490041732788, 13.181775825364248, 11.518945097923279, 4.517518528870173, 1.2590688445738383, 1.3088011188166482, 26.322633709226334, 59.745982442583355, 42.56966379710606, 26.034330368041992, 33.20405142647879, 49.6877840587071, 57.08845281600952, 23.34266424179077, 1.0859680473804474, 0.18788154263581547, 0.11248445484255042, 0.17271294657673153, 0.18517264085156576, 0.19939662116978848, 0.13031902856060437, 0.11076039235506739, 0.10901843011379242, 0.1613902055791446, 0.1835784635373524, 0.14084606511252268, 0.156922934576869, 0.1331056361751897, 0.1020568236708641, 0.09313163187886987, 0.13007183825331076, 0.10451651311346463, 0.25225049576589037, 0.1407480575144291, 0.11305942506130252, 0.10650685309831585, 0.16818588306861265, 0.18077760668737547, 0.09168498164841107, 0.12596676924398967, 0.27665015363267487, 0.07828939080770526, 0.10539599627788578, 0.1696716169161456, 0.13068421610764094, 0.21015824084835394, 0.16797678571726593, 0.1556541555161987, 0.154793026724032, 0.1625785103866032, 0.19319338617580278, 0.13503224136573927, 0.08501113512154136], [0.05643340127010431, 0.08890149529491152, 0.03576332131134612, 0.020702578393476348, 0.05795102287083864, 0.1149331655885492, 0.05105189253975238, 0.03477620552959187, 0.004841537347861699, 0.10502953987036433, 0.03478874824941158, 0.03870621250410165, 0.05636510332780225, 0.06387092878243752, 0.06913984819714512, 0.04620175136785422, 0.013648817565159073, 0.01482948291647647, 0.12487432786396571, 0.10678831620940141, 0.11176571662404708, 0.10256320756993123, 0.14150136709213257, 0.03567490141306605, 0.043358696425067525, 0.08065188689423458, 0.045239259621926715, 0.16003389550106867, 0.27314530313014984, 0.1282679529062339, 0.029075585172644684, 0.07837451981114489, 0.061311772891453335, 0.04433954593592456, 0.06899343391082116, 0.026476628113804117, 0.03264626035732882, 0.03342233139223286, 0.028058045576991777, 0.00871515297330916, 0.04271940787189773, 0.06046625040471554, 0.12760335499686853, 0.03754412628976362, 0.007156956674797195, 0.10277830995619297, 0.05405773142618792, 0.4706083301986967, 16.644949947084697, 45.14545481545584, 55.22670037405831, 49.13234158924648, 38.836014543260845, 17.124347857066564, 32.140174525124685, 54.12661293574742, 30.12039920261928, 2.777906732899802, 0.3752464758498328, 1.1321590202195304, 2.263788457427706, 2.465063657079424, 2.1993497780391147, 0.21269883880657808, 0.5857036656567028, 0.04850916398156967, 0.1153797230550221, 0.4276193912540163, 8.688905596733093, 27.814337253570557, 53.179764543260845, 62.99663461957659, 68.02086312430245, 65.97503553118024, 68.9572787966047, 68.92618560791016, 66.11673709324428, 64.33594853537423, 55.85676997048514, 53.51532432011196, 54.252601146698, 47.09898601259504, 46.26557043620518, 37.45944438661848, 26.555971588407242, 8.096797483307974, 0.24438380503228732, 0.1995473780802318, 1.3801451133830207, 29.377011435372488, 20.668716021946498, 41.51662955965315, 55.52286386489868, 63.09283937726702, 60.13681166512625, 69.84486947740827, 68.6654475075858, 70.55473218645368, 66.93083667755127, 63.75204971858433, 63.217253821236746, 64.10970129285539, 62.62689317975725, 71.44436563764299, 73.22027656010219, 76.78393813541958, 74.48309080941337, 78.06911168779645, 74.47908169882638, 71.55877467564174, 72.05235385894775, 64.52933774675641, 47.56436940601894, 39.89663968767439, 15.152928522654943, 3.3833536505699158, 0.23522841344986642, 0.03298994852229953, 0.2278798520565033, 1.8352732913834708, 2.918438174894878, 3.7979174852371216, 4.018382523741041, 3.246757060289383, 2.871202583823885, 0.5879251350249562, 0.34869998746684616, 8.046495999608721, 38.20551415852138, 36.7442558833531, 21.54947488648551, 20.467708110809326, 34.94715642929077, 47.132139342171804, 34.968424865177695, 7.631172639983041, 0.28944287289466175, 0.021111701082970415, 0.054130768935595236, 0.05343350635043212, 0.022375728702172637, 0.0390747791555311, 0.003142429045900436, 0.01312959663170789, 0.032534878834017684, 0.0253180753705757, 0.0336559577845037, 0.03407277845378433, 0.027781398368201086, 0.04934292406375919, 0.05252566381490656, 0.01160588942002505, 0.04971276975369879, 0.01724605994032962, 0.030871579157454625, 0.06345046098743166, 0.03519426791795662, 0.01609256737200277, 0.037315548198031526, 0.08320509881845542, 0.05592294276825019, 0.09349991354559149, 0.02299295299287353, 0.021281009140823568, 0.017358990219820822, 0.05022943685097354, 0.03698957997507282, 0.01856257563589939, 0.053169199997293096, 0.037041399694447, 0.041439226030239036, 0.013065212988294661, 0.013986247940920293, 0.06364193678434406, 0.022267478617972562, 0.1108371007389256, 0.04401231563783117, 0.08978840841778687, 0.01958818979827421, 0.022717388047437583, 0.041416535819215436, 0.032829882111400366, 0.05619942203962377, 0.03889194450208119, 0.027044533086674552, 0.08707758637943439, 0.011668247636407614, 0.04949829161965421, 0.03304165967607072, 0.010952132803920125, 0.049883869144001176, 0.01852374816579478, 0.03400829727096217, 0.023249987146950195, 0.0722563663231475, 0.1545520517975092, 0.01294188924865531, 0.06597802428794758, 0.06459122084613357, 0.046400307677686214, 0.06029185333422252, 0.09873512334057263, 0.06146890124572175, 0.08922973661018269, 0.21017889545432158, 0.021729027153924108, 0.06266935861536435, 0.017852234288251827, 0.06685534971100943, 0.0459660588364516, 0.05515914303915841, 0.0565487725793251, 0.06741360761225224, 0.10617194178381137, 0.016550081482689296, 0.047648628907544274, 0.0864318178168365, 0.01751542986104531, 0.0693674763398511, 0.029974949413112233, 0.14787334017455578, 0.08391335367092065, 0.09597503965986626, 1.9371497333049774, 25.2396787915911, 58.03623921530587, 60.31490789140974, 41.896772452763145, 20.743603706359863, 24.285885674612864, 62.45370932987758, 72.07481043679374, 22.99798842838832, 1.6714575673852647, 0.2274688905371087, 1.3899872366871153, 0.7009543584925788, 2.0617741431508745, 2.56309557386807, 1.9217594734260013, 1.3430470526218414, 0.06358774219240461, 0.09621408076158591, 1.883005244391305, 15.286842891148158, 41.21350744792393, 63.28549902779715, 67.22651032039097, 71.20872443062919, 67.99355670383999, 69.99559674944196, 68.55479049682617, 66.62840243748256, 66.03647845132011, 63.4358024597168, 62.234563146318706, 63.848574093409944, 56.67282894679478, 54.608401026044575, 53.2587377684457, 43.43236255645752, 21.310500281197683, 2.5604326767580847, 0.2441890383405345, 4.727880886622837, 47.99937874930245, 30.59256751196725, 51.427126611982075, 60.53961958203997, 68.20526831490653, 66.14953259059361, 69.14821529388428, 72.52806922367641, 70.8416997364589, 72.89340550558907, 68.8824189049857, 70.23653248378209, 69.99969618661063, 65.52533422197614, 67.6747247150966, 67.68343080793107, 71.62376117706299, 74.44949626922607, 75.99071093967983, 73.04814883640834, 69.90165710449219, 71.85312121255058, 70.40062808990479, 53.27053580965315, 48.77139656884329, 23.43999981880188, 7.353198664528983, 0.8514437090073312, 0.08902025249387537, 0.8476486897894314, 2.0519600297723497, 4.701505959033966, 8.803424937384468, 5.5169934460095, 0.7121748849749565, 1.307192285146032, 0.2790199507560049, 0.2305146578167166, 4.010219693183899, 45.385699204036165, 61.892419951302664, 32.074454988752095, 17.355969531195505, 24.783936023712158, 46.866058077131, 45.28851475034441, 13.490361826760427, 0.17609650215932302, 0.08181522839835711, 0.04018924917493548, 0.24106053050075257, 0.03215612058660813, 0.08612748807562248, 0.07339740438120705, 0.060200108614351065, 0.02597892437396305, 0.028010378491931727, 0.018032015534117818, 0.027594290640471236, 0.09905130708856241, 0.04283034495477166, 0.014205791338879083, 0.06462475404675518, 0.030427824040608745, 0.05394037200936249, 0.022842533653602004, 0.032263753203941245, 0.013566983697403754, 0.022493625858000348, 0.037737166109894, 0.03435025177896023, 0.05201650810028825, 0.006640052938434694, 0.03405175404623151, 0.03662880290565746, 0.021316152165776918, 0.07430529780685902, 0.10194749132330928, 0.06886521793369736, 0.02478877395125372, 0.04590101786223905, 0.043113046392266235, 0.057195596263876984, 0.011539909522980452, 0.07493628109140055, 0.025395708258396814, 0.016902034204187136, 0.14064034686556884, 0.22999191443834985, 0.1433086993971041, 0.10937429458967277, 0.21991355238216265, 0.17881541912044796, 0.11652689506965024, 0.11246681971741573, 0.09697957682822432, 0.17070498503744602, 0.06927759080593075, 0.19514893767024788, 0.12855539391083376, 0.1419666385544198, 0.23711379085268292, 0.11739928754312651, 0.06532500897135053, 0.1971809464905943, 0.22286188203309262, 0.2941957392862865, 0.21372912637889385, 0.2178055476397276, 0.2716168894299439, 0.1629389346178089, 0.2975234378661428, 0.2923729770949909, 0.23965433452810558, 0.28342027749334064, 0.6356843379991395, 0.19667258805462293, 0.13950101871575626, 0.19336156786552497, 0.1243996654770204, 0.18245539308658668, 0.2034669763275555, 0.13360764352338655, 0.1558236399931567, 0.21346733399799891, 0.1902610563806125, 0.11471055181963102, 0.23114672675728798, 0.21763170696794987, 0.38053201937249725, 0.1351195823933397, 0.161761608506952, 0.20384083555213042, 0.09662508977843182, 1.1005576359374183, 22.820126703807286, 67.4779725755964, 73.76003347124372, 61.824807030814036, 56.1783812386649, 26.275941814695084, 46.103997026171, 70.25409058162144, 40.48484986168997, 4.547302416392735, 0.3746982195547649, 4.3465151105608255, 11.196434906550817, 5.756255098751613, 6.025724913392748, 1.6867915902818953, 1.056793321456228, 0.11339930325214352, 0.2416357382067612, 1.0068427217858178, 9.84866155896868, 31.629853657313756, 57.64021621431623, 67.42561789921352, 71.59878240312848, 67.2943594796317, 70.53463104793003, 68.60932690756661, 70.12533351353237, 70.78945623125348, 62.89069543566023, 56.08186033793858, 59.097639083862305, 47.30042123794556, 45.61919341768537, 45.59854337147304, 36.318209716251914, 13.076587046895709, 0.7941516861319542, 0.17457688227295876, 2.038432104246957, 37.52740819113595, 28.37133264541626, 53.025010790143696, 67.50454248700822, 68.46157346452985, 66.89017581939697, 67.47693034580776, 70.92573125021798, 73.55282429286412, 71.02153996058873, 69.89309692382812, 67.61629731314522, 71.58804048810686, 67.84988185337612, 73.22493185315813, 70.91356495448521, 80.17729936327252, 79.69488593510219, 83.43073081970215, 77.82165854317802, 75.99755491529191, 74.85415240696499, 76.2326055254255, 44.65047557013375, 39.60807057789394, 18.31285285949707, 3.8570800934519087, 0.4308191452707563, 0.1652085121188845, 0.5382353642157146, 3.0025148519447873, 7.504906501088824, 14.766664266586304, 15.456035000937325, 14.293951392173767, 9.987957307270594, 1.6004880155835832, 0.3715764156409672, 12.497080360140119, 50.243869236537385, 48.75451244626726, 32.712379523685996, 30.517485277993337, 44.3860445022583, 59.17577157701765, 50.60971621104649, 12.160746727670942, 0.4289841151663235, 0.09474406857043505, 0.1455220670572349, 0.4259701711790902, 0.12155766226351261, 0.23726108723453113, 0.22633752838841506, 0.2611106703323977, 0.1283616314509085, 0.12820418418518134, 0.13434857662234986, 0.09825339061873299, 0.1443304917109864, 0.10014769075704472, 0.1324371299041169, 0.22474770726902144, 0.16541881726256438, 0.1755353808403015, 0.141264585512025, 0.1816612628421613, 0.14508694969117641, 0.1142009584499257, 0.1385975493384259, 0.12998175594423497, 0.2039052149546998, 0.14993656160576002, 0.13271131233445235, 0.1160390419619424, 0.04302500308092151, 0.19436319411865302, 0.22972554873142922, 0.13918148300477437, 0.18272946695131914, 0.14992273306207998, 0.11238458127315555, 0.14302524817841394, 0.07687082514166832, 0.11517997591623239, 0.17617907987109252, 0.19143272350941384], [0.06507526058703661, 0.10947594592081648, 0.054784299938806465, 0.14282351971736976, 0.026033546442964246, 0.11964811544333186, 0.11620198536132063, 0.03086081419938377, 0.04820484781105604, 0.0575417373329401, 0.055465688197208304, 0.02714366535656154, 0.04499571304768324, 0.015029131667688489, 0.026052986471248523, 0.08551950034286294, 0.029002517129161527, 0.07729176112583705, 0.057982452612902434, 0.03936982653768999, 0.10714287111269576, 0.02532335606935833, 0.11835231711821896, 0.031443774167980464, 0.06811354362538882, 0.08762126934847661, 0.028976020336683308, 0.05449626182339021, 0.11845835857093334, 0.088348523181464, 0.07607151088970047, 0.06411418358662299, 0.07401831820607185, 0.010880777213190283, 0.0121187143127567, 0.027917132513331513, 0.02371248509734869, 0.03713074579302754, 0.013923860038630664, 0.03492481826937624, 0.030341283684330325, 0.01636169641278684, 0.05370821464540703, 0.06572900193610362, 0.009265787533617445, 0.028318416427022645, 0.05528189002403191, 0.08704207185655832, 0.07384337830756392, 4.795418245451791, 28.336688927241735, 51.02211611611502, 54.30882249559675, 46.37723840985979, 32.878000259399414, 21.632594449179514, 43.67255483354841, 56.36167819159371, 15.178629909242902, 0.6384554207324982, 1.0742052899939674, 1.625472977757454, 5.049915994916644, 1.1302426201956612, 1.642432770558766, 0.22018686628767423, 0.03858887344332678, 0.12281952026699271, 0.2291857334119933, 0.18606499582529068, 2.1300367202077592, 6.726158048425402, 7.563027313777378, 10.942497355597359, 15.032719475882393, 15.943327801568167, 15.594071388244629, 10.64245069026947, 5.483235188892909, 3.7824230023792813, 2.9906236614499773, 3.257596901484898, 2.141113668680191, 0.15731558922146047, 2.508002438715526, 0.17322294706744806, 0.23908737780792372, 0.059692985112113614, 0.1279693160738264, 0.3116571323147842, 0.221744565559285, 5.284957919801984, 22.11544040271214, 47.412231649671284, 66.50628784724644, 73.0744686126709, 80.29143742152623, 75.99538012913295, 75.99763134547642, 78.27861377171108, 85.14665794372559, 83.05782794952393, 83.87407452719552, 73.13976778302873, 47.603637150355745, 27.428474255970546, 22.03075749533517, 23.365251098360332, 27.256242309297832, 18.971767902374268, 14.510860255786351, 7.991746800286429, 2.558081797191075, 0.09146139757441622, 0.31961623951792717, 1.9877636688096183, 0.3215656706265041, 0.39057623754654613, 0.8568029414330209, 2.0625225944178442, 1.7822163041148866, 6.7651383110455106, 4.128678662436349, 0.6569692215749195, 0.2731271726744515, 4.420165147100176, 28.82776502200535, 40.170047828129356, 25.661090510232107, 17.999607222420828, 32.73366185597011, 45.97259964261736, 44.603043692452566, 18.615575449807302, 0.9834906948464257, 0.21043451316654682, 0.0073592610424384475, 0.03782586420753172, 0.06519091688096523, 0.07599266512053353, 0.037885283519114764, 0.10101587631340538, 0.02352384727315179, 0.16841324658266135, 0.04781651882720845, 0.10084772176508393, 0.048601668660662005, 0.023530072831947888, 0.05749362920011793, 0.1004684003336089, 0.041360855235585144, 0.03151064718674336, 0.03659543255344033, 0.034749036987445185, 0.029377129527607133, 0.07190276136887924, 0.009851225851369756, 0.053272730870438476, 0.021180524889911925, 0.041990084507103474, 0.06434538760887724, 0.10254797445876257, 0.05191969811650259, 0.05749010081802096, 0.016042879948924695, 0.12089913045721394, 0.14878286208425248, 0.10648745378213269, 0.16217140294611454, 0.1583799392517124, 0.021603445589010204, 0.12385535825576101, 0.10075183119624853, 0.07172041865331785, 0.2161288061844451, 0.13078337721526623, 0.06495840328612498, 0.08559190681470291, 0.018127191944846084, 0.05433853296563029, 0.01464283828889685, 0.036828061499233754, 0.08165335029895816, 0.05429347484771695, 0.05646985895665629, 0.026568725671885268, 0.0016678085417619773, 0.01801775272802583, 0.08880014930452619, 0.04256498347967863, 0.0178072389348277, 0.032761448462094576, 0.049745485319622924, 0.1221483541386468, 0.10840805393776723, 0.18609650699155672, 0.04051332428519215, 0.022748410668490187, 0.1273159682750702, 0.06463067765746798, 0.05885897736464228, 0.061671667865344455, 0.033243710441248756, 0.03571456857025623, 0.24062629523021833, 0.1124685499817133, 0.04481175881145256, 0.08379474574966089, 0.0422965618116515, 0.04190640078325357, 0.03199274631749306, 0.03436506759109242, 0.040840412090931616, 0.037472544237971306, 0.03248802599098001, 0.03815311825435076, 0.01848394699793841, 0.03058239771053195, 0.07801403451178755, 0.05837750927145992, 0.05753219034522772, 0.02481644121663911, 0.03101389848494104, 0.007375893632083067, 0.22627293185463973, 10.064952032906668, 41.31411041532244, 64.1721030644008, 51.15782485689436, 23.400565317698888, 18.3619418825422, 37.803699834006174, 70.14138385227749, 59.15254374912807, 7.662823421614511, 0.47665695420333315, 0.35961004346609116, 1.6853852314608437, 1.5292988355670656, 1.6493318974971771, 1.192820485149111, 0.933804343853678, 0.16425051566745552, 0.16239142471126147, 0.14953524885433062, 0.8086017136062894, 6.434144369193485, 15.159630060195923, 16.32401439121791, 19.873004845210485, 25.785918372017996, 26.474232980183192, 26.80909446307591, 21.50623972075326, 13.763518963541303, 10.501808728490557, 11.000734550612313, 11.953014697347369, 8.221024325915746, 0.2689387931355408, 2.915128443922315, 0.4479642595563616, 0.6159624734095165, 0.051587120962462256, 0.13734278881124087, 0.7944794456873621, 2.0397503077983856, 13.549044575010027, 37.004243578229634, 54.863837650844026, 66.41541235787528, 70.64090374537876, 74.89363901955741, 71.4215338570731, 70.5024539402553, 71.5695721762521, 77.30902739933559, 75.94201101575578, 82.32769734518868, 82.52404648917062, 62.87437411717006, 40.31282983507429, 33.9220643724714, 35.47087342398507, 41.95129844120571, 30.290633542197092, 26.09440623010908, 16.63051332746233, 5.482049652508326, 2.1236647878374373, 0.917672689471926, 2.4307543209620883, 1.0543929359742572, 1.9478008874825068, 2.0597285500594547, 2.5135963899748663, 1.3503606830324446, 1.0866944598300117, 2.325037262269429, 0.7258229383400508, 0.2607410858784403, 1.9302510406289781, 29.458948067256383, 58.076649938310894, 42.54622752325875, 16.44067117146083, 23.470083781651088, 45.39056641714913, 52.7775958606175, 28.258314984185354, 2.8494041306631903, 0.1460287562970604, 0.11275962793401309, 0.04390884583283748, 0.019285551305594187, 0.05969654742096152, 0.016620937502011657, 0.08412876139794077, 0.09368960479540483, 0.07818902190774679, 0.039160155824252536, 0.07615495034094368, 0.04377558834052511, 0.023144237464293838, 0.029694687309009687, 0.0667842256703547, 0.06213699361043317, 0.09387409168162517, 0.08624659811279603, 0.03529145788135273, 0.06596744592700686, 0.04308166754032884, 0.07103034175400223, 0.07901040890387126, 0.03199904990781631, 0.026580910464482646, 0.019327028454946618, 0.07378224908773388, 0.03479085849331958, 0.09168698332671608, 0.048209183649825196, 0.06156004885477679, 0.0797313048637339, 0.035204920917749405, 0.05054064693727663, 0.19760505801865033, 0.04231107906837549, 0.09317410138568707, 0.017779671753357564, 0.02907383455229657, 0.11201876268855163, 0.0630000697981034, 0.3281163019793374, 0.1872566118836403, 0.2014282771519252, 0.23655714786478452, 0.16424945715282643, 0.2187938881771905, 0.2717904586877142, 0.18827026177729878, 0.15298870711454324, 0.1566763820924929, 0.21448107888656004, 0.12996715387063368, 0.27959211862512995, 0.13056843089205877, 0.06473390318985496, 0.11489489621349744, 0.25487181224993294, 0.31689471698233057, 0.21334834609712872, 0.20318879054061004, 0.21783690952828952, 0.12615005512322697, 0.22241737374237605, 0.1577240265905857, 0.17398347625774996, 0.10586822950946433, 0.08878978128944125, 0.0940865817080651, 0.23300265574029513, 0.1744919704007251, 0.1061214723491243, 0.18480783328413963, 0.11931305485112326, 0.1020517550142748, 0.12629564159682818, 0.1263150748397623, 0.09498276361929518, 0.1336441622780902, 0.13900308257767133, 0.19398124675665582, 0.0774389828688332, 0.0966220363708479, 0.20837400587541716, 0.15881568086998804, 0.123947340462889, 0.08519623268927846, 0.1585709061473608, 0.14039766203079904, 0.2515332299683775, 7.905178325516837, 45.92331607001168, 75.50092547280448, 67.27473776681083, 62.95326396397182, 49.84577219826834, 36.29599632535662, 59.39266654423305, 73.57828944069999, 20.91375466755458, 0.47801315571580616, 2.1824836773531775, 5.753398954868317, 15.236435447420392, 11.688103335244314, 7.071138279778617, 0.6652838811278343, 0.418104566101517, 0.16112947171287878, 0.38224605311240467, 0.4637064891202109, 3.605808045182909, 9.521951181547982, 10.125760061400277, 13.64211482661111, 17.907265663146973, 18.237650769097463, 18.63711139133998, 13.951432125908987, 8.73407062462398, 6.649873776095254, 7.510059458868844, 10.947081429617745, 6.162254844393049, 0.2531577785100256, 2.373356555189405, 0.3435223852949483, 0.27695242741278236, 0.36952259870512144, 0.21773812840027468, 0.444487988948822, 1.016040182539395, 9.787032774516515, 31.733037880488805, 58.493250029427664, 75.64538546970913, 74.23752062661308, 78.63589014325822, 76.28310503278459, 78.46085112435478, 81.88215105874198, 87.92050388881138, 87.29697949545724, 85.47282028198242, 80.59338528769356, 53.87839548928397, 27.84115035193307, 23.14464579309736, 26.08827097075326, 32.378751346043174, 21.714776005063737, 15.785409143992833, 11.28584953716823, 3.057812741824559, 0.7831854745745659, 0.616479897073337, 5.122102567127772, 2.2709401079586575, 1.5462264929498946, 1.8897048277514321, 8.372429915836879, 9.970354046140399, 18.34148117474147, 13.675031048910958, 1.1326037049293518, 0.4555950643760817, 6.538428579057966, 37.848342009953086, 51.440734658922466, 38.766358852386475, 29.289057663508824, 43.1918054989406, 60.14696993146624, 60.97240897587368, 27.841862542288645, 2.2760439940861295, 0.3209291233548096, 0.2265014760196209, 0.11974830792418548, 0.1851276946919305, 0.18265766437564576, 0.16446930249886854, 0.1927565589014973, 0.23231505549379758, 0.2875875138810703, 0.09121498758239405, 0.16128474766654627, 0.18848568307501928, 0.06215678647692714, 0.0936923867889813, 0.16383732855319977, 0.19185763570879186, 0.2404305243066379, 0.15052227303385735, 0.1071909996015685, 0.1314414476177522, 0.16780407141361917, 0.17949282777096542, 0.2441631183028221, 0.10908316235457148, 0.10967310105583497, 0.23004185461572238, 0.2685827250991549, 0.16746466819729122, 0.13617452792823315, 0.10446946349527154, 0.36703443793313845, 0.36359651812485283, 0.1889450377119439, 0.316161926303591, 0.4299097183559622, 0.11032593995332718, 0.22118488273450307, 0.20701671870691435, 0.16284620602216038, 0.5755239033273288, 0.26305858152253286], [0.03460360657689827, 0.09739636696342911, 0.06809181014874152, 0.09293157939932176, 0.1051068182236382, 0.05398437161264675, 0.0488869247825018, 0.011294740401873631, 0.11572098545730114, 0.03360326614763055, 0.04974023685125368, 0.019658888058204736, 0.019727118147004927, 0.04659914897222604, 0.037192153212215216, 0.17607241416616098, 0.0314371279174728, 0.05725344137421676, 0.017741083466847028, 0.029708203726581166, 0.055413963472736735, 0.053051134904048274, 0.04276823525183967, 0.011325599326352988, 0.04203628256384816, 0.04296666942536831, 0.03587651113048196, 0.00664233196792858, 0.01779954943672887, 0.05910329068345683, 0.09771749044635467, 0.020644884257178222, 0.031583392926092656, 0.015332514852551478, 0.014323758892714977, 0.056852871618632755, 0.023159881089148775, 0.011938478448428214, 0.024369471540142382, 0.03669489221647382, 0.04399261776623981, 0.04491489613428712, 0.036107168932046206, 0.09119813277253083, 0.016387224596525942, 0.009688337582961788, 0.012332215356374425, 0.05993872335446732, 0.128735802801592, 0.062346070605729303, 0.2827758863568306, 11.821068406105042, 44.071562085832866, 61.09653854370117, 45.537576402936665, 41.54792077200753, 24.888805185045513, 26.74954492705209, 53.83739416939871, 37.85389362062727, 11.067617041724068, 0.2407747044094971, 1.292022847703525, 0.7981619909405708, 0.6444811916777066, 3.6729736753872464, 0.2479392471058028, 1.5215843809502465, 0.3477340250142983, 0.04347987599404795, 0.0607486634648272, 0.08309594289000545, 0.07197566995663301, 0.22338282050830977, 0.1544401478022337, 0.12337513188166277, 0.05333037920562284, 0.053656832581119876, 0.16759390197694302, 0.16919210978916713, 1.2397791253668922, 0.6616195748959268, 0.27945177044187275, 0.16825830989650317, 0.2646534102303641, 0.0775945098804576, 0.10686942150018044, 0.14251934603921004, 0.07739240822515317, 0.16730034058647497, 0.1540853961237839, 0.06538891339940683, 0.2621564285031387, 6.9244318434170316, 19.937143666403635, 33.56347826548985, 47.31611027036394, 58.81796714237758, 69.03894792284284, 57.001093115125386, 48.69531379427229, 34.2111302784511, 13.689520648547582, 3.8987823128700256, 0.07844936222370182, 0.07667560383145298, 0.1852743396801608, 0.029826139898172448, 0.18834487348794937, 0.18608026286321028, 0.25301137779440197, 0.14718617419047014, 0.3418770735817296, 0.5381617567368916, 0.6611946491258485, 1.5483636068446296, 1.1711943256003516, 0.08961938534464155, 4.62891161441803, 0.6561491170099804, 3.0848544793469563, 1.0464615672826767, 0.6904963425227574, 2.6395463858331953, 20.01922447340829, 40.66809817722866, 36.2624191556658, 24.210855552128383, 29.16136714390346, 46.85727902821132, 48.40983315876552, 25.60130820955549, 3.811293636049543, 0.03814511154113071, 0.13933796675077506, 0.03230837366676756, 0.1270522895668234, 0.06915067083069257, 0.02717834528136466, 0.023014423537201116, 0.06784516266946282, 0.033254526289446015, 0.012115191867841142, 0.01168288109225354, 0.010257570788131228, 0.03856785921379924, 0.040185683473412476, 0.061375399120152, 0.04462367229695831, 0.032274606371564526, 0.05865068746996777, 0.10852138285658189, 0.01014474144072405, 0.022191497962921858, 0.02460917760618031, 0.010444866809328752, 0.045051227390233956, 0.04282000408108745, 0.018789391232920543, 0.03306023796488132, 0.058854607599122186, 0.008671011725839759, 0.047090075843568356, 0.043850596994161606, 0.09814137127250433, 0.061091452570898194, 0.016421797652063624, 0.07350748311728239, 0.026866572010996084, 0.0991620643596564, 0.065643764367061, 0.0337725809908339, 0.06645182493541922, 0.149066761136055, 0.11350324124630008, 0.07718322266425405, 0.07470551811690841, 0.019441414192052822, 0.022228238937844123, 0.16483461218220846, 0.11017009403024401, 0.09456645524395363, 0.0373366472444364, 0.032983451549495967, 0.05286369978317192, 0.12084130570292473, 0.06715652426438672, 0.11097651932920728, 0.047673751666609726, 0.0477709077032549, 0.010260680174854184, 0.07084373105317354, 0.1257957105657884, 0.07182616833597422, 0.07092689909040928, 0.056991404720715115, 0.023445998950462257, 0.0009575969639367291, 0.03353731593649302, 0.014978322965492095, 0.03012515331751534, 0.07219649239310197, 0.004348918379816625, 0.06579345597752503, 0.05686513274641974, 0.02927400916814804, 0.057768890501133034, 0.04187635185995272, 0.03531264852998512, 0.028534670626478534, 0.04460285823526127, 0.06913746653922967, 0.03134926102523293, 0.04722740115331752, 0.06257557150508676, 0.032643647997507026, 0.05124494593058314, 0.0289585039551769, 0.028139758156612515, 0.07971362224114792, 0.01289059200124549, 0.07324541932237999, 0.06611348701907055, 0.05591348059741514, 0.09151352941989899, 0.04520622853721891, 0.80998766209398, 21.581620727266582, 56.38941887446812, 67.06131689889091, 39.700849873679026, 25.207202911376953, 24.073086670466832, 51.20577090127127, 75.49604088919503, 40.506323269435335, 3.6581205981118337, 0.4060771257749626, 0.3434611814362662, 1.4895604593413216, 0.9664654369865144, 0.38715517254812376, 0.12757377087005548, 0.6790855005383492, 0.209150833476867, 0.16034860004271778, 0.13916180548923357, 0.20126137110803807, 0.05629727357466306, 0.5542566616620336, 0.6454153986913818, 0.5665643640926906, 0.2630102426878044, 0.40522206308586256, 0.27822763898542946, 0.42869576492479866, 1.6736415816204888, 0.40298857007707867, 0.625561464045729, 0.7702189960650035, 2.6866493097373416, 1.8730445674487521, 0.8372775805847985, 0.17194264648216112, 0.684644493673529, 0.20356848516634532, 0.1494283795888935, 0.0566109196016831, 1.475070751139096, 14.621415649141584, 33.16994619369507, 46.880423477717805, 59.87357916150774, 68.85215255192348, 80.423494883946, 70.91484342302594, 65.03048351832798, 54.32702677590506, 28.00967022350856, 10.016019344329834, 0.4187927363174302, 0.5672747631158147, 0.5464942210486957, 0.24780625424214772, 1.170416670186179, 0.2036317517714841, 0.3585801087319851, 0.2964492626488209, 0.5926969732557024, 0.7357900206531797, 0.9141872993537358, 2.576289551598685, 1.9454206952026911, 3.6933605585779463, 1.1131797986371177, 0.6000883366380418, 1.2314375958272388, 1.7407147139310837, 0.5952617813433919, 0.1589883951736348, 13.367409978594099, 49.33821323939732, 53.48375865391323, 27.17548860822405, 18.369192327771867, 39.837281227111816, 56.539232458387104, 36.25013126645769, 7.958611709730966, 0.043076999219400544, 0.17778439873031207, 0.029376997213278497, 0.052221381571143866, 0.02077965997159481, 0.10824076791426965, 0.013603776410621191, 0.07131764026624815, 0.021380051504820585, 0.01977017119393817, 0.060226618977529664, 0.06630114944917814, 0.06984296653951917, 0.03594658344185778, 0.013124566990882158, 0.03199931453647358, 0.04004210885614157, 0.01604689857257264, 0.0587836599775723, 0.04557782484750662, 0.03861843721408929, 0.019981558600972806, 0.014143375447019935, 0.02496781220127429, 0.03144043577568872, 0.06496118527970143, 0.05407063716224261, 0.1516582356499774, 0.06286399638546364, 0.006712762206526739, 0.05155283458796995, 0.04204302720193352, 0.059724380927426476, 0.1321734647665705, 0.019149019881816845, 0.009126371487842073, 0.19393212082130568, 0.01948604144022933, 0.016880514466070702, 0.040717990802867074, 0.09956816756831748, 0.1003754206800035, 0.1473459420459611, 0.16076948174408504, 0.12811201198824815, 0.1322665462004287, 0.19479367030518396, 0.23174386471509933, 0.20448437173451695, 0.1519704974655594, 0.11990423527147089, 0.11123789780374084, 0.16073710205299513, 0.28951482474803925, 0.21679747530392238, 0.09598292423678295, 0.20877983767007077, 0.09583802986890078, 0.18894065437572344, 0.20054151330675396, 0.170599065721035, 0.1373303716203996, 0.18915801628359727, 0.12507928615169867, 0.0994581634710942, 0.10917225400252001, 0.05838170940322535, 0.14309272170066833, 0.11622551695576736, 0.10292366572788783, 0.35213410747902735, 0.19600800371595792, 0.1999607958963939, 0.16028184576758317, 0.07727447883891207, 0.12983478525919573, 0.148881195379155, 0.20718887661184582, 0.20564397451068672, 0.16547626203724317, 0.15117908136120864, 0.08329345086323363, 0.12991755296077045, 0.08037755518619503, 0.14166538257684025, 0.1472883615642786, 0.20499965122767858, 0.06878213810601405, 0.20652598861072743, 0.1890667261821883, 0.2149432019463607, 0.17404869704374246, 0.17377707947577747, 0.5794455643211092, 21.681556667600358, 65.64548942020961, 82.63421712602887, 61.32660034724644, 57.80511086327689, 38.800488403865266, 40.94771800722395, 69.15253012520927, 46.797802448272705, 13.239075882094246, 0.25888236133115633, 1.765594584601266, 4.919480502605438, 7.212555834225245, 13.652128049305507, 1.1684976645878382, 2.5040198181356703, 0.39360293799213, 0.29230295228106634, 0.1789811716548034, 0.188689650701625, 0.2960564451558249, 0.6909974813461304, 0.3683837183884212, 0.4883613575782095, 0.15822758099862508, 0.21269887951867922, 0.344293933893953, 0.6091431964720998, 1.4710197342293603, 0.41431269528610365, 0.3788883904261248, 0.26355163220848354, 0.883141065282481, 0.6927979875888143, 0.2659740565078599, 0.25482092212353435, 0.717165157198906, 0.5044184816735131, 0.2796644775995186, 0.20742774807981082, 0.733526916376182, 9.489819237164088, 24.454158885138376, 40.37548521586827, 48.53699214117867, 59.567163603646414, 73.89733682359967, 57.95756128856114, 51.86984845570156, 42.72303833280291, 17.145890746797832, 4.903094479015895, 0.16591603415352957, 0.24549073992030962, 0.27373071600283894, 0.15724956776414598, 0.7170992035950933, 0.3314043198313032, 1.0020867884159088, 0.2623576819896698, 0.44739458869610516, 1.064275554248265, 1.775260288800512, 2.7113979245935167, 3.070938757487706, 4.830970874854496, 13.82749797616686, 5.6014427202088495, 11.039747817175728, 5.3990799103464395, 0.944424991096769, 2.9630753568240573, 25.1170482976096, 54.38717385700771, 49.12499386923653, 35.99871070044381, 41.17147432054792, 61.77840001242501, 66.14506489889962, 39.84011261803763, 7.822339296340942, 0.20623094801391872, 0.23479211543287548, 0.13604760116764478, 0.33905499215636936, 0.1887222339532205, 0.19538736130510057, 0.12017985619604588, 0.23129307319011005, 0.1340191885828972, 0.0797884375123041, 0.15585464904350893, 0.12683814391493797, 0.09211868766163077, 0.09978541412523814, 0.2348360845020839, 0.09329365925597292, 0.09782588641558375, 0.11659100305821214, 0.16418841614254884, 0.11814388473119054, 0.10876507192317929, 0.15417816543153354, 0.21418160067072936, 0.14113347897572176, 0.0907427543508155, 0.11659754413579192, 0.16420555593711988, 0.19883583911827632, 0.09234409699482576, 0.12030086613127164, 0.20994070252137526, 0.16169915614383562, 0.13101535476744175, 0.1477839092590979, 0.21125982888042927, 0.08208654741091387, 0.2399469731109483, 0.14882209497903073, 0.12455574210200991, 0.18190987807299408, 0.21841800691826002, 0.1887419114687613, 0.17499667831829616], [0.05122975692419069, 0.016904370060988834, 0.036303187520908456, 0.021957934335140244, 0.036510727634387355, 0.04063974214451654, 0.16980242489704064, 0.017807635877813612, 0.029306874011776278, 0.016984876544613923, 0.029237066329057728, 0.014871299333338226, 0.036904993799648116, 0.1620535414133753, 0.03813975450715848, 0.001877774205890351, 0.07832590956240892, 0.0407394630435322, 0.020267170953697393, 0.05965145198362214, 0.038260974788240025, 0.02262322774289974, 0.051831586951656, 0.028883631008544138, 0.02892831593219723, 0.03355703755681004, 0.043756982910313776, 0.04885324230417609, 0.052874237432011535, 0.01844366915923144, 0.011340089441676224, 0.011821296298876405, 0.02437203809885042, 0.04978867746623499, 0.054041629790195396, 0.08113392495683261, 0.011790154086026763, 0.01258340138675911, 0.016841826095644916, 0.0281769656243601, 0.0036339918317805442, 0.02693460532464087, 0.019980505175356354, 0.054595131160957475, 0.06603998132050037, 0.06585728576672928, 0.019951648777350783, 0.07256452300186668, 0.027457713415580134, 0.05053563934883901, 0.10992618783244065, 0.16980657753135475, 1.4230532795190811, 20.193127461842128, 41.45837238856724, 53.33461904525757, 46.67591714859009, 36.81717375346592, 27.321692602975027, 31.60516323362078, 44.3519149507795, 37.42909812927246, 10.511203561510358, 0.3625447345631463, 1.0483857840299606, 1.148038693836757, 0.33723445555993486, 0.29997484918151585, 0.5441218454922948, 0.11182795185595751, 0.11397590195494038, 0.2458846973521369, 0.12955212114112719, 0.05472661428419607, 0.06468278914690018, 0.12338376284709998, 0.1823218438242163, 1.1171553624527795, 0.7672925559537751, 0.13762372945036205, 0.8613477147051266, 1.462357067636081, 1.3015907342944826, 0.8078711756638118, 4.311814504010337, 5.1181116955620904, 1.878116101026535, 0.9727032908371517, 0.09268438909202814, 0.05421017449615257, 0.0337126358146114, 0.01837243146396109, 0.05571341793984175, 0.045825462987912555, 0.06584848516753741, 0.5560417515890939, 1.238845352615629, 2.677581693444933, 3.413511220897947, 1.537873781153134, 0.15132632346025535, 0.3179949208029679, 0.33852614196283476, 0.43250715040734833, 0.6215348743966648, 1.149333881480353, 0.5136128483074052, 0.29298509710601395, 0.31945971505982534, 0.09296108210193259, 0.05841452335672719, 0.05010116659104824, 0.12973926109927042, 0.44729929523808615, 0.5765915917498725, 1.4341046065092087, 2.608566756759371, 5.498184672423771, 1.2914172687700816, 0.5092930229646819, 0.3256506414285728, 2.031752279826573, 19.75223125730242, 41.8312474659511, 40.45271444320679, 26.486015387943812, 30.74712324142456, 45.01277896336147, 49.44067832401821, 31.48462588446481, 10.423466920852661, 0.5055389329791069, 0.2615029992801802, 0.03949901960524065, 0.01705846536372389, 0.08785973369543042, 0.07310843667281525, 0.021381612135363475, 0.12682033915604862, 0.047006867094231505, 0.047094449001763544, 0.057587165252438614, 0.008820173230820468, 0.05350009438448718, 0.03226126976577299, 0.06978601031005383, 0.02713555855942624, 0.037400812908474884, 0.05988106144858258, 0.08012799000633614, 0.034795845725706646, 0.050137597136199474, 0.04236438138676541, 0.011790390725114515, 0.032490750309079885, 0.01978548233663397, 0.030721558457506553, 0.05821284917848451, 0.059618210553058555, 0.049718920673642836, 0.06141577195376158, 0.02975891064852476, 0.06678456493786403, 0.021275565593636463, 0.013801800070463546, 0.018501828092017343, 0.00839281321636268, 0.10803342118327107, 0.047498055201556, 0.07842536922544241, 0.050892002547958066, 0.10208608210086823, 0.063307914350714, 0.061461654491722584, 0.03211537795141339, 0.03193904705611723, 0.01861784909851849, 0.052854950074106455, 0.06986525641488177, 0.04655431477086885, 0.033805388158985546, 0.07970617871199336, 0.024981342189546143, 0.06075236826602902, 0.021265650500676463, 0.07693198828824929, 0.030510405145053352, 0.034029053657182624, 0.012840047079537596, 0.045827478236917935, 0.0695307861481394, 0.026961477007716894, 0.02418521365949086, 0.07075545364724738, 0.017383256328425238, 0.04447360749223402, 0.032071198536349196, 0.022191435198432634, 0.026239961884649735, 0.06487439386546612, 0.07830768411180802, 0.0502584747570966, 0.005719253776728043, 0.012618611417045551, 0.07943621676947389, 0.022517936071380973, 0.024035764625295997, 0.002762609103228897, 0.06761220124151025, 0.09624819750232355, 0.029943685912128006, 0.03439369837620428, 0.02920980957735862, 0.03183158067986369, 0.02099397186455982, 0.025085341251854385, 0.08235595295471804, 0.12552576219396933, 0.03706023243388959, 0.02606941889306264, 0.045424479325967174, 0.0646374901490552, 0.030975439120084047, 0.08993229855384145, 0.06072097245071616, 0.027956141491553614, 0.03137223282828927, 0.04223919506849987, 4.356514871120453, 32.41571576254708, 53.87341710499355, 57.41685594831194, 41.87687976019723, 26.046234369277954, 33.96321160452706, 50.88782133374895, 64.17870385306222, 34.96011481966291, 3.6282839477062225, 0.49072054241384777, 0.45922153549534933, 0.7491786022271428, 0.6721649318933487, 0.748957236962659, 0.8772394391042846, 0.2762921042740345, 0.32218343604888233, 0.5254414507320949, 0.18682789988815784, 0.05876185864742313, 0.1850080011146409, 0.4040996575994151, 0.9095546422260148, 2.5273147395678928, 2.2316428337778365, 2.468345595257623, 3.7688531705311368, 2.4087571927479337, 2.795033173901694, 4.097743110997336, 3.691210091114044, 4.635303522859301, 4.8505178945405145, 3.1991065314837863, 0.3616865777543613, 0.6359446783150945, 0.45037623441645075, 0.21648420925651277, 0.2363081526543413, 0.20429596970123903, 0.2966094783374241, 2.0405230777604237, 4.494571668761117, 7.662604553358896, 9.611976385116577, 6.251497507095337, 3.2795099999223436, 1.1484220389808928, 0.324072640389204, 0.7473580113479069, 1.496604738490922, 3.5317061586039404, 1.9480516740253992, 1.7365077968154634, 0.6475048522864069, 0.30265031276004656, 0.27918790174382074, 0.6807650104165077, 1.155928481902395, 0.9123589460338865, 1.4019583314657211, 1.6647512529577528, 0.5802568750722068, 4.703236060483115, 1.2370317642177855, 0.11683333505477224, 0.129072261175939, 0.4700396092874663, 14.60879077230181, 47.67299059459141, 61.30499144962856, 33.92627845491682, 25.87702488899231, 36.20332472664969, 54.48970494951521, 44.95429597582136, 16.315652234213694, 1.4283684343099594, 0.21351793913968972, 0.021635168797469566, 0.052141307653593164, 0.05358671277229275, 0.00987905087614698, 0.009759312345912414, 0.033631591591984034, 0.016193591058254242, 0.021152028115466237, 0.046722323434161286, 0.019069076582257236, 0.029231465022478784, 0.047812902235559056, 0.05606545547821692, 0.027410653619361774, 0.0740465045507465, 0.04052228094743831, 0.0367743724158832, 0.05891773171190705, 0.10461628490260669, 0.041837756788092, 0.01845246975842331, 0.05663674803716796, 0.030559524295053313, 0.05034012966124075, 0.011538669500233871, 0.08452634220676762, 0.046485185623168945, 0.035092318031404696, 0.029152028927845613, 0.04035944611366306, 0.049973754677921534, 0.05737652762659958, 0.12800769401448114, 0.025521374640188048, 0.0890551766912852, 0.013484791054257324, 0.06727838236838579, 0.08015777769365481, 0.018603959486686757, 0.04442495992407203, 0.03185276793582099, 0.004810900643600949, 0.0546184625875737, 0.12350992964846746, 0.12455837481788226, 0.281146696635655, 0.10914358589798212, 0.15089655295014381, 0.21288976499012538, 0.18502978208873952, 0.15965083534164087, 0.14752894294049057, 0.16364371537097863, 0.11530372713293348, 0.15802115707525186, 0.14064152751650127, 0.3084186746605805, 0.17808471832956585, 0.14316019522292273, 0.18258499327514852, 0.19959825463593006, 0.06428325415721961, 0.15397593485457556, 0.12901238724589348, 0.20216935952859266, 0.10394211286412817, 0.15846657460289343, 0.1373610006911414, 0.14225809648633003, 0.08908461154039417, 0.10546268948486873, 0.15037908857422216, 0.1706786443080221, 0.08493577023702008, 0.10388850859765496, 0.26361587590404917, 0.2730428986251354, 0.17681682136441979, 0.15280376560986042, 0.10590814093926124, 0.10738833794104201, 0.07176695258489676, 0.11694461479783058, 0.1505460353302104, 0.19684670014040812, 0.16811447404325008, 0.12867558960403713, 0.17240295106811182, 0.18983163870871067, 0.1740550345608166, 0.1808259862342051, 0.1601830374981676, 0.08976411686411925, 0.20534585336489336, 0.23129044047423772, 3.377039257969175, 34.008048330034526, 66.96654347011021, 71.50095176696777, 60.082455907549175, 52.84183890478951, 42.47273642676217, 43.20300252096993, 59.889976910182405, 47.250272614615305, 13.683809229305812, 0.4589691747512136, 1.3835337715489524, 3.17363269839968, 0.7646931697215352, 0.8114801134381975, 2.3040702044963837, 1.3361943917615073, 0.4220636822283268, 0.7730493013347898, 0.1625216898641416, 0.2602270820311138, 0.2104412578046322, 0.19345122948288918, 1.05165610568864, 3.0192387316908156, 2.7314712703227997, 1.49190254509449, 0.8897223664181573, 3.368020713329315, 2.8938973546028137, 4.757201416151864, 7.092067556721823, 12.202968324933734, 5.734439492225647, 3.439890491110938, 0.16847801953554153, 0.3913566071007933, 0.38242312361087116, 0.14461318297045572, 0.23402512658919605, 0.16307689435780048, 0.29431692564061707, 1.1624238533633096, 2.630637926714761, 3.8800126229013716, 5.625086137226649, 3.746305397578648, 2.1618368881089345, 0.5577535597341401, 0.6062278843351773, 0.4413633080465453, 0.6954434599195207, 2.4869504826409474, 1.452684523803847, 0.9808943484510694, 0.6116012302892548, 0.1979240101895162, 0.2969161761658532, 0.40215155641947475, 1.055803854550634, 0.9633277824946812, 1.5577954607350486, 5.377841438565936, 4.920996078423091, 14.248071568352835, 4.439077275139945, 2.081748042787824, 0.501767418214253, 3.00099840760231, 24.755886146000453, 51.980224064418245, 53.68327965055193, 39.95233992167881, 41.91650881086077, 54.75805132729666, 65.19758769444057, 52.04345267159598, 17.208731991904124, 1.1210219264030457, 0.4389811615858759, 0.15263973655445234, 0.1669532156416348, 0.21847617094005856, 0.16287562730056898, 0.05243985288377319, 0.14595392745520386, 0.12302249723247119, 0.23238801157900266, 0.1943558252283505, 0.17103697865137032, 0.10090945488108055, 0.15424592393849576, 0.11050413003457443, 0.1437051131256989, 0.144943466676133, 0.09221040524010148, 0.1355519313365221, 0.12299066036939621, 0.15332038860235894, 0.1409972562853779, 0.11150270288011857, 0.2158776396619422, 0.11061737752918686, 0.12087281686919076, 0.12300682307354041, 0.19808068392532213, 0.15805748584015028, 0.22852207188095364, 0.10513789512749229, 0.17757375431912287, 0.10247526264616422, 0.14094891745064939, 0.21766053113554204, 0.11434389863695417, 0.21168380470148154, 0.1773226556501218, 0.17550515889057092, 0.16237003728747368, 0.2661784855382783, 0.23249378161770956, 0.14621348067053727, 0.0889954859656947, 0.2136948603604521], [0.06027261008109365, 0.036635035249803743, 0.07525956231568541, 0.04550210712477565, 0.011867268742727382, 0.04673460152532373, 0.05491042263539774, 0.09141043280916554, 0.01507492090708443, 0.03621875062318785, 0.060847017115780284, 0.06402184854128531, 0.04030432192874806, 0.036351974188749275, 0.011358275028344775, 0.038081583700009754, 0.010160681924649646, 0.06764580908098392, 0.06830429338983127, 0.01696423550934664, 0.043756887915411165, 0.05881832633167505, 0.04573961134467806, 0.03811381072072046, 0.028847203856067996, 0.07938218502593891, 0.05812561671648707, 0.03287186985835433, 0.05377317758809243, 0.028511230634259324, 0.08761741526957069, 0.08041959721595049, 0.04762503285227077, 0.05584947099643094, 0.010072752267920544, 0.034429226469780715, 0.006677338437709425, 0.031706597922103744, 0.005664449351440583, 0.0377850096140589, 0.040433426786746295, 0.04206485228080835, 0.015402963750862649, 0.07100375675197158, 0.0658971361283745, 0.020773127375702773, 0.040033966435917785, 0.04209847369098237, 0.06027003164802279, 0.03420425818434783, 0.11346012034586497, 0.1255386815007244, 0.10291453264653683, 0.02066488577319043, 4.763321910585676, 37.79273905072893, 62.516507148742676, 50.54713726043701, 46.41559246608189, 39.40427296502249, 33.9398204939706, 35.62721136638096, 52.12818247931344, 45.02781139101301, 21.608560630253383, 4.327150046825409, 0.4363424474639552, 0.8270965154681886, 0.6476984790393284, 0.6803085463387626, 0.5732988512941769, 0.39991589209863115, 1.0069039527859007, 0.9165127745696476, 1.6708203958613532, 0.29411518360887257, 1.5637633119310652, 2.573605158499309, 2.1256663032940457, 3.0831788778305054, 12.502611994743347, 3.356225277696337, 2.6134335356099263, 4.89556610584259, 1.9772260742528098, 3.4998015505926947, 3.809997797012329, 2.5968551337718964, 2.692024175609861, 0.8369291935648236, 0.7767437345215252, 0.6916419810482434, 0.658462324312755, 0.5863661872489112, 0.11406894267669745, 0.07790185910250459, 0.07460791763982602, 0.043154501489230564, 0.10728775869522776, 0.023349830182269216, 0.02645331365056336, 0.16442321640040192, 0.1205949160669531, 1.6484334085668837, 0.6505432235343116, 1.8023772622857774, 1.6585827725274223, 3.037551143339702, 0.8992285334638187, 0.9141419189316886, 0.3895989571298872, 1.6289206956114088, 2.590599366596767, 1.3016734612839562, 1.2661414593458176, 2.608654477766582, 0.04833848528297884, 0.008615516891170825, 0.4644080400466919, 3.7015103612627303, 24.239496026720317, 46.175209113529746, 41.772323267800466, 33.19185733795166, 19.747463056019374, 32.22358764920916, 47.460681438446045, 43.23934159960066, 19.547429629734584, 2.562221186501639, 0.20101823844015598, 0.09347624624414103, 0.018348370612199818, 0.031957883188234906, 0.02381488960236311, 0.09469878992864064, 0.06196910369076899, 0.06811040200825248, 0.03578106839475887, 0.03189568866842559, 0.044387525147093196, 0.02359814685769379, 0.03742518588634474, 0.04704745705904705, 0.038952720883701525, 0.08737226056733302, 0.053496148703353744, 0.012291033369755107, 0.04364994401112199, 0.04329361813142896, 0.013837576677490557, 0.04634765675291419, 0.0401986774190196, 0.030083236816738333, 0.022596973526690687, 0.02471654220218105, 0.07870863045432738, 0.041745448884155066, 0.04486262518912554, 0.04895322443917394, 0.03479937071512852, 0.0030582921878833857, 0.06513453062091555, 0.035501213411667516, 0.007724686924900327, 0.015447283961943217, 0.04281966481357813, 0.029041621102286235, 0.013988342069621598, 0.04352976867396917, 0.0391621303611568, 0.024354206198560338, 0.016400637537507073, 0.03057304071262479, 0.012944747577421367, 0.02027277904562652, 0.03237952145614794, 0.061374143830367496, 0.030356998555362225, 0.03425958253709333, 0.05376966616937092, 0.017472444667613933, 0.041420556139200926, 0.05671186864908252, 0.03561383326138769, 0.021631440247542093, 0.04513162700459361, 0.03639579737292869, 0.02014087692701391, 0.08309396835310118, 0.06175708185349192, 0.057466053536960056, 0.02220369123720697, 0.06840143924845116, 0.03179783034803612, 0.06543746257999114, 0.05348581800769482, 0.016015658820314065, 0.05428681502650891, 0.03430027088948658, 0.0022693898437345134, 0.06299155418361936, 0.06934899304594312, 0.040530389440911155, 0.031086213354553496, 0.03826499171555042, 0.06529974032725606, 0.052009030644382746, 0.004845109834734882, 0.09984148825917925, 0.06019557600042649, 0.017548230243846774, 0.06874503581119434, 0.026617458056924597, 0.023354347529155866, 0.04161044077149459, 0.024561322227652584, 0.029405814595520496, 0.012048784493734794, 0.03911422239616513, 0.033290926300521405, 0.025454269223181263, 0.05878264896039452, 0.04913581142734204, 0.01269024605530181, 0.10715259451951299, 0.08284706981586558, 0.12824580552322523, 0.07478838759873595, 0.14095461714480603, 10.422870244298663, 48.01711055210659, 69.14041246686662, 52.02769415719168, 38.649691649845664, 23.689518315451487, 38.46300745010376, 58.96780504499163, 66.24559838431222, 39.473160879952566, 9.420286008289882, 1.264796331524849, 0.5463268128888947, 0.6680308622973306, 0.30514721306306974, 0.46235175324337824, 0.5160562257681574, 0.6905464455485344, 0.4151110595890454, 0.23228924402168818, 0.7339546105691365, 1.014342325074332, 2.9382147022656033, 3.0679809962000166, 3.6028257480689456, 2.2825086414813995, 5.827165807996478, 3.37735236116818, 3.5979016465800147, 3.370096270527158, 3.258617852415357, 4.5297417129789075, 5.484282195568085, 4.094739317893982, 4.104536277907235, 2.4626437297889163, 1.6026829949447086, 2.4070739916392734, 1.340845016496522, 1.8659604447228568, 0.6345205690179552, 0.6126657160265105, 0.12495663416172777, 0.39610800785677774, 0.16152679467839853, 0.1666465720960072, 0.3385809947337423, 0.42433587887457436, 0.6548514323575156, 1.0800021503652846, 1.8618914059230258, 4.492439874580928, 1.8129867272717612, 2.1835986460958208, 2.9050932909761156, 1.2652611008712222, 1.8102307894400187, 2.2750165292194913, 0.38416473301393644, 0.7400633256350244, 1.7335032437528883, 1.6069946778672082, 0.1363909670284816, 0.1373416624431099, 0.212276179343462, 1.374043075101716, 14.584882020950317, 54.92862960270473, 61.53383037022182, 41.59671449661255, 20.724018471581594, 30.464362825666154, 52.78588853563581, 56.528667722429546, 31.3136202948434, 4.573923136506762, 0.20408813442502702, 0.2081259334725993, 0.059841129662735124, 0.015568716285218085, 0.0434972193491246, 0.09658133105507918, 0.025044376396441033, 0.05788046879959958, 0.01921018472473536, 0.04913316174809422, 0.06114159630877631, 0.04761155714680042, 0.024557361279481223, 0.07271765478487525, 0.04397547457899366, 0.019777938723564148, 0.10107581131160259, 0.05263917933085135, 0.03817015626866903, 0.03146091056987643, 0.017224173793303113, 0.04351579763793519, 0.03539607780320304, 0.029477970009403567, 0.04049769423103758, 0.024363176431506872, 0.015432371458570873, 0.027815006207674742, 0.06636450426386935, 0.01629225174630327, 0.0021582918208358543, 0.05623807817963617, 0.08517333891774927, 0.027761174631970267, 0.03044720978609153, 0.049419374604310305, 0.03217311788882528, 0.010585546626576355, 0.03891088241445167, 0.07218596152961254, 0.0181392071036888, 0.04043873632326722, 0.01530205032655171, 0.010537221362548215, 0.0439143046470625, 0.03233089085136141, 0.1121374588193638, 0.1433404276945761, 0.15465328922229155, 0.1273280597691025, 0.0668057148743953, 0.18773241420941694, 0.11173797132713453, 0.29208362262163845, 0.13782581074961595, 0.15724285026746138, 0.10038904566317797, 0.16790790084217275, 0.10985277034342289, 0.16548576152750424, 0.1479517381106104, 0.11816516358937536, 0.11587152523653847, 0.08445282293749706, 0.1425702225949083, 0.10574448507811342, 0.13266578263470105, 0.2101722593818392, 0.09704129637352057, 0.18437526720975125, 0.17816760816744395, 0.1383620976869549, 0.20806939793484552, 0.20593915081449918, 0.11635536141693592, 0.11567305374358382, 0.21971628868154117, 0.19372362058077539, 0.11302743892052344, 0.1757306225065674, 0.15060158020683698, 0.16832430421241693, 0.17362690610545023, 0.147541984383549, 0.10502979771367141, 0.07958112470805645, 0.1966951425586428, 0.09466133479561124, 0.16742817658398831, 0.17264706082642078, 0.14113104982035501, 0.15733319041984423, 0.17752959526010922, 0.06799622492066451, 0.09123498400939362, 0.18602280451783113, 0.16051995727632726, 0.1392380456839289, 0.22175920834498747, 0.29007597320846146, 8.772514138902936, 54.93498373031616, 83.1011221749442, 66.85251658303397, 62.84860324859619, 54.41105828966413, 47.16754388809204, 48.51633514676775, 64.53214481898716, 57.656433309827534, 28.018035854612076, 5.932667689664023, 0.5235402498926435, 1.2131552568503787, 1.402178393942969, 1.9903258170400346, 2.6501734384468625, 1.9181763742651259, 4.159394042832511, 2.1371968388557434, 5.942607956273215, 3.565069019794464, 8.548368726457868, 10.774128607341222, 7.436963541167123, 11.853068334715706, 30.812648228236608, 13.329134089606148, 11.766787341662816, 14.50650634084429, 8.250103405543737, 13.330818159239632, 11.98306131362915, 10.41474085194724, 8.533240761075701, 3.342298699276788, 2.2742268230233873, 3.255153089761734, 2.023495214326041, 2.3087472106729234, 0.28695701914174215, 0.33343205388103214, 0.13779979571700096, 0.20326573641172477, 0.35783572867512703, 0.11238617583044938, 0.23893633591277258, 0.3594300959791456, 0.43716453335114885, 3.4552850936140334, 3.2549420382295335, 9.141002297401428, 6.6209284492901395, 9.701508266585213, 6.690604116235461, 3.2450056799820493, 3.506546731506075, 7.9244430746350965, 9.724564126559667, 7.056779393127986, 7.792580161775861, 6.360747507640293, 1.2675898330552238, 0.1857434787920543, 0.6822676126446042, 5.290872139590127, 31.846164975847515, 56.582717759268625, 54.92776802607945, 45.19727448054722, 32.36885711124965, 44.57239171436855, 63.77801513671875, 61.76986762455532, 34.166689600263325, 5.00045611177172, 0.36573642758386476, 0.2439814337662288, 0.2376660369336605, 0.1067321402952075, 0.09887766997729029, 0.2578574206147875, 0.13054203587983335, 0.14078492910734244, 0.06881056193794523, 0.14374233755682195, 0.18394215830734797, 0.14490337882723126, 0.11071940883994102, 0.1549124624580145, 0.15569954950894627, 0.10968686174601316, 0.15900708202804836, 0.12548468368394033, 0.17432410083711147, 0.11179200307066951, 0.10495768301188946, 0.08460439408996276, 0.16553110123745032, 0.09590476378798485, 0.09932666338448014, 0.1254170880253826, 0.2791069389453956, 0.1101461553147861, 0.10327919093625886, 0.09728413727134466, 0.08230105947170939, 0.0991798826892461, 0.15132189941193375, 0.10588195627289158, 0.08164824093026773, 0.1196427685873849, 0.11956454707043511, 0.13161830098501273, 0.07236778177320957, 0.20095533824392728, 0.10748203005641699, 0.12677850068679877, 0.14783165098301002, 0.08322867791035346, 0.15184593200683594, 0.10987262427806854], [0.033271157182753086, 0.03202299540862441, 0.04130713561815875, 0.029441726061382463, 0.02144861237944237, 0.04592676826619676, 0.018088110024109483, 0.052213670020656924, 0.01740926118301494, 0.03921629781169551, 0.03382193423541529, 0.011649125671413327, 0.0271432090417615, 0.04387524477871401, 0.04874393370534692, 0.022283162954928618, 0.06789257191121578, 0.05532003726278033, 0.0487976601081235, 0.02305042490895305, 0.00815964737973575, 0.02895440560366426, 0.025873205225382532, 0.03303304906668408, 0.034381057268806865, 0.0445174951372402, 0.051479756366461515, 0.06222702842205763, 0.06712805972035442, 0.049016901557998996, 0.019399874278211167, 0.043195271265826056, 0.02402098273991474, 0.031141106837562153, 0.03552192569311176, 0.10260852013847657, 0.07165730811123337, 0.009322919334018869, 0.030208697941686426, 0.024214263439976742, 0.03218749604587044, 0.009124989820910352, 0.03131217908646379, 0.0037578978392827722, 0.044163496632661135, 0.09422010382903473, 0.06614538495029722, 0.01830215219940458, 0.012360195596037167, 0.009931476188025304, 0.01265069340089602, 0.08561456988432578, 0.016383092318262373, 0.18087807058223657, 0.1910647132566997, 1.0280913987330027, 21.22261425427028, 52.648574760981965, 57.70676953451974, 51.06981202534267, 39.0811574118478, 36.82158933367048, 27.349664313452585, 40.24865974698748, 47.18493870326451, 47.98517663138253, 40.00656018938337, 19.14890875135149, 7.340627636228289, 1.8342983722686768, 0.1679082808217832, 0.12335001251527242, 1.4828944227525165, 1.3678020728485925, 1.3277572159256255, 2.664675848824637, 2.051074568714414, 1.2162782549858093, 2.546136975288391, 1.6211021265813281, 2.7199361750057767, 2.229153424501419, 3.040403161730085, 2.0224156379699707, 4.65793467419488, 2.864549900804247, 4.234766798360007, 3.420745381287166, 2.946003850017275, 2.8779874997479573, 1.1145386057240623, 2.1942417664187293, 1.1235010219471795, 0.42085993396384375, 2.31904205254146, 0.36019700339862276, 0.06535465416631528, 0.5404357175741876, 0.5629033691116742, 1.0432322834219252, 0.6367427983454296, 0.3680448037173067, 1.238283525620188, 4.230081106935229, 8.419704590524946, 5.984992836202894, 4.2453784346580505, 1.6618057595832008, 2.2907783005918776, 1.3757973866803306, 1.3099241214139121, 2.6171390967709676, 1.0549708306789398, 0.683224727000509, 0.04999656702524849, 1.2271766130413329, 6.570805881704603, 16.364218405314855, 31.643621512821742, 60.43820367540632, 49.84525455747332, 14.716374942234584, 24.379182611192974, 32.819458212171284, 51.125408036368235, 50.06188201904297, 28.44197150639125, 5.58198298726763, 0.06749269086867571, 0.32740755858165876, 0.06273443012365273, 0.07954528448837143, 0.13311444355973176, 0.004381966851984284, 0.047171656108860455, 0.013718269865161606, 0.0804663822054863, 0.001848870946560055, 0.03304375634927835, 0.04855871739398156, 0.019661201862618327, 0.0036395520021739814, 0.04172560852020979, 0.010576751116397125, 0.044280645703630786, 0.04126416060275265, 0.030509919992515018, 0.035784932651690075, 0.03895155380346945, 0.020447447530127, 0.05572556032400046, 0.009030235798231192, 0.04123838984274438, 0.05082774528169206, 0.030161359946110418, 0.056488539025719674, 0.006271521910093725, 0.024590380489826202, 0.031342706376952786, 0.06822362236146416, 0.05631882045418024, 0.0005542201937974564, 0.03510248587865915, 0.01783853636256286, 0.05924014441136803, 0.03212680448112743, 0.04508911678567529, 0.022731007941599404, 0.03537279048136302, 0.034661000461450646, 0.05478157562070659, 0.14430329602743897, 0.046541273327810426, 0.03528004492233906, 0.020100855235276476, 0.0063406523300467855, 0.03626654323722635, 0.04450503044894763, 0.037098746081548076, 0.014887450163119605, 0.035377163639558215, 0.002427712207593556, 0.009909460271176482, 0.027218385632815104, 0.06169229532991137, 0.017592869366386106, 0.010546268778853118, 0.021309902858255163, 0.030346223419266086, 0.011542770396252828, 0.015300866282944168, 0.05938784791422742, 0.028231855714693666, 0.09288782746131931, 0.07452648665223803, 0.02725056345973696, 0.02983643327440534, 0.06234490352549723, 0.03038180579564401, 0.030642013797270398, 0.02061131882614323, 0.06768998849604811, 0.05668872721227152, 0.014148141307357167, 0.006651325525516378, 0.011841429281048477, 0.05422835584197726, 0.031000090297311544, 0.03111203500468816, 0.057553659193217754, 0.017310337562646185, 0.02562341612896749, 0.005291163064872048, 0.09328514364148889, 0.05516942623736603, 0.016309177802343453, 0.010041125750701343, 0.0439182740769216, 0.05542972244854484, 0.024622929814670767, 0.09303576845143523, 0.09756909483777625, 0.05050085085843291, 0.02488163486123085, 0.025368894250797372, 0.06242401392332145, 0.006431703247861671, 0.04682801204866596, 0.02582870689885957, 0.07245210331997701, 0.2398272252508572, 2.956765958241054, 32.235708781651084, 64.46917329515729, 62.75801263536726, 50.700626441410606, 36.023831912449424, 23.08282940728324, 34.1194418498448, 57.14925650187901, 67.39808218819755, 52.64567041397095, 33.46154471806118, 11.994124582835607, 0.4245564027556351, 1.0608909130096436, 0.25741637285266605, 0.5664331082786832, 0.8745832730616842, 0.354652856609651, 0.21568505785294942, 1.078881861908095, 1.6422230218138014, 1.830349407025746, 2.5241839247090474, 2.1368524687630788, 2.252199730702809, 0.5878491391028676, 1.1825552816901888, 0.7060542276927403, 1.8104249047381538, 2.7822063650403703, 2.706753488097872, 2.430662908724376, 1.9426264337130954, 1.3877017136131014, 1.3171075816665376, 2.281389981508255, 1.942596252475466, 3.5792316198349, 1.754439468894686, 1.481528558901378, 0.9177071047680718, 0.7749427940164293, 0.832084562097277, 1.5413976034947803, 0.5790176529969487, 1.3541156415428435, 1.7328331768512726, 1.2684901676007678, 2.312042610985892, 2.412153776202883, 1.3336337634495325, 1.3283432530505317, 1.0128516107797623, 1.3597975309406007, 0.5017803918038095, 1.220254361629486, 0.10381158308259078, 0.4012245147355965, 0.06965670189154999, 1.2487931102514267, 2.340358691556113, 9.432717204093933, 19.355430058070592, 53.72520160675049, 67.91538946969169, 30.47633457183838, 25.839711325509207, 31.074591841016495, 48.16229316166469, 57.4224214553833, 38.69976731709072, 10.25095009803772, 0.34182783908077646, 0.39170097719345776, 0.04804149389799152, 0.020146532516394342, 0.04528091488672154, 0.008641737180628946, 0.028090279383052672, 0.02648315901335861, 0.06117019655981234, 0.01636298562932227, 0.05606671076800142, 0.03391884260677865, 0.02863983337634376, 0.050460542485650094, 0.04726517180513058, 0.03536349794428263, 0.029081200049923997, 0.04368586904768433, 0.0406125498536442, 0.031205353925802877, 0.040958419508699856, 0.05696804954537323, 0.05510649550706148, 0.05329043045639992, 0.035327114896582704, 0.03521670028567314, 0.01750971489985074, 0.020734228659421206, 0.06102309695311955, 0.0504998975167317, 0.018620071300704564, 0.03996607222195182, 0.03696733420448644, 0.002905778295826167, 0.041192714257964065, 0.07659647986292839, 0.025380885660914437, 0.05246716391827379, 0.038027314469218254, 0.029944795316883495, 0.014001249502013837, 0.04313680190326912, 0.03129513089412025, 0.126033984922937, 0.036740211570369344, 0.06488004606217146, 0.030904654346938645, 0.02622798065255795, 0.15703878764595303, 0.19328796038670198, 0.10401791879641158, 0.05721136541771037, 0.06699541290955884, 0.19544070772826672, 0.058638792751090865, 0.11178164184093475, 0.1208892102752413, 0.11150538309344224, 0.07659407106361218, 0.11858599100794111, 0.11233393541936364, 0.146653700619936, 0.09241623205265828, 0.10788665405873742, 0.14416510558554105, 0.16453797024275574, 0.15451298175113543, 0.1634167589779411, 0.20751994741814478, 0.1032035614230803, 0.10150357335805893, 0.29274383719478336, 0.189251518409167, 0.11099399839128767, 0.2289248774094241, 0.1531948053411075, 0.18109897444290773, 0.06835208939654486, 0.14137685591621058, 0.16364359323467526, 0.08974703135234968, 0.1363158124898161, 0.07359337886529309, 0.17189216347677366, 0.16975301397698267, 0.10986832915140049, 0.14234680815466813, 0.1192016394010612, 0.10027700596089874, 0.1356477133397545, 0.1396371056990964, 0.18469329657299177, 0.14042523769395693, 0.21659115994615213, 0.13534009270370007, 0.09164702439946787, 0.11387352459132671, 0.1349715260522706, 0.19816544651985168, 0.20036510777260574, 0.08694046123751573, 0.24905234309179441, 0.2784802440021719, 2.0597819643361226, 30.874657426561626, 73.77043492453438, 75.38505731310163, 64.71295084272111, 54.92616299220494, 54.7198987688337, 41.26911735534668, 54.73258965356009, 59.81539494650704, 60.00175258091518, 50.492194380079, 26.329488107136317, 8.987896135875157, 2.2994446584156583, 0.2918301762214729, 0.4678452270371573, 1.8115962190287453, 1.7135738560131617, 2.231797431196485, 6.262668039117541, 5.060970144612448, 4.833565592765808, 10.070870161056519, 7.0066346781594415, 12.503596901893616, 9.334619062287466, 12.995196717126028, 11.154035261699132, 19.881957599094935, 15.345270293099539, 15.410421814237322, 12.59727772644588, 10.365765605654035, 8.237245764051165, 7.356532062802996, 11.032393148967198, 5.903687621865954, 7.570102316992624, 4.224503440516336, 2.6902287176677158, 1.9631544521876743, 2.054624446800777, 1.986442642552512, 4.497232394559043, 3.436143675020763, 5.4758614131382535, 7.221836456230708, 17.298756326947892, 23.356861148561748, 20.81955620220729, 14.431883556502205, 9.701225127492632, 9.327017733028956, 8.450584990637642, 7.267707594803401, 3.9596467954771857, 2.24631330370903, 0.7385121945823941, 0.05306021709527288, 1.972348873104368, 9.300440004893712, 21.470319271087646, 43.101013387952534, 69.80691146850586, 64.60337080274309, 25.61006988797869, 41.46430615016392, 44.52748898097447, 66.72063282557896, 66.58673409053257, 45.380161489759175, 10.461604714393616, 0.2734106917466436, 0.6138812165175165, 0.23885955289006233, 0.12652478287262575, 0.17503774325762475, 0.08508576040289231, 0.13952312538666384, 0.09740603608744484, 0.21139833144843578, 0.09477221420300858, 0.1038174999079534, 0.16065683136028902, 0.1773232120488371, 0.14975220364119324, 0.14528893599552767, 0.12645379453897476, 0.17034656926989555, 0.08005867086883102, 0.1065079794664468, 0.20878461455660208, 0.14742613131446497, 0.09208886604756117, 0.15334519584264072, 0.15729194906141075, 0.16210667070533546, 0.13367510347494058, 0.13257309475115367, 0.12152019355978284, 0.08272294540490423, 0.17082898052675383, 0.10576686316302844, 0.2067650772098984, 0.23755966978413717, 0.040758115971194844, 0.1071605740913323, 0.07824294508567878, 0.10784263749207769, 0.14841779667351926, 0.23391805376325334, 0.07322998265070574, 0.16491740702518395, 0.10112750889467341, 0.16083615459501743, 0.26070430928042954, 0.17068994870143278, 0.16167272041950906, 0.1304281505623034, 0.09554476024849073], [0.030923439588929926, 0.04242125619202852, 0.04739871767482587, 0.0237033672830356, 0.014154885945442532, 0.007493301394528576, 0.018448522380952324, 0.04091027744912675, 0.012663549943161862, 0.05127641638474805, 0.04584318971527474, 0.012457521266437002, 0.01736760761455766, 0.057067563491208215, 0.05885240236031158, 0.026249605563602278, 0.009124117055242615, 0.03486646425777248, 0.02586020788710032, 0.03837023249694279, 0.11654339704130377, 0.05389817052387765, 0.014151313458569348, 0.03736199392005801, 0.02289630925016744, 0.021348111165155257, 0.027948806528002024, 0.035851208559636555, 0.032423850148916245, 0.06576414326471941, 0.03347054809065802, 0.0676724212244153, 0.05382832552173308, 0.03473825506599886, 0.012659232764105712, 0.04933748560558472, 0.030946044983076196, 0.026770610195983733, 0.0291235711691635, 0.020522646173568707, 0.015620537700929811, 0.0702895647180932, 0.02370036476557808, 0.013677779984261309, 0.05904619874698775, 0.03406765551439353, 0.04625655664131045, 0.03166614366429193, 0.05715122685900756, 0.012776414913657521, 0.04198957560583949, 0.05586036487615534, 0.046190182345786264, 0.045194995389985185, 0.06138572642313583, 0.14629204145499639, 0.44704707020095413, 2.7218873160226003, 34.3258033479963, 53.7583966255188, 51.45548568453108, 46.76801552091326, 36.06876938683646, 35.99895388739449, 30.206793103899273, 25.597604819706508, 32.569507190159385, 34.68633147648403, 46.19721405846732, 44.90491165433611, 36.302340030670166, 25.84874745777675, 23.6813576562064, 16.49998446873256, 8.190164770398821, 4.7645339369773865, 2.545832557337625, 0.9664566431726728, 0.02528424361454589, 0.2873432684157576, 0.4281969331204891, 1.5385171409164156, 0.9725596585444042, 1.1167131747518266, 2.075472733804158, 1.6784993495259966, 0.6220170685223171, 1.6026762638773238, 1.4633188503129142, 1.3726265111139841, 0.4754737519792148, 1.0664106053965432, 0.7095090565936906, 2.4082434603146146, 2.3850451622690474, 1.361165566103799, 0.5545939207077026, 1.7133945056370325, 1.2540429085493088, 1.2525287440844943, 1.980784637587411, 1.4628875191722597, 1.9612304525715964, 1.4647875257900782, 1.0935641654900141, 1.011489872421537, 1.2469891841922487, 0.3308321791035788, 0.08085837867110968, 0.7200645644749913, 1.8518186892781938, 7.433949760028294, 12.693814260619027, 25.732835871832712, 32.606263160705566, 44.56647879736764, 31.14207969393049, 53.82608945029122, 100.08988462175641, 37.60735069002424, 16.590960706983292, 33.81082371303013, 42.68583420344761, 46.790836879185264, 25.676849024636404, 7.912145631653922, 0.38218807908041136, 0.390052679926157, 0.05504918983206153, 0.023919585859403014, 0.011995827380035604, 0.02622865409856396, 0.04601737643991198, 0.027167885664052198, 0.032725343613752296, 0.06083760583507163, 0.020789091608354023, 0.038630840834230185, 0.033630041139466424, 0.04234670554952962, 0.1108702811013375, 0.029848426380859952, 0.01122850859870336, 0.04061873809301427, 0.007582258183642158, 0.04577366701726403, 0.04917433186035071, 0.03397894723873053, 0.05309109722397157, 0.04786259814032486, 0.07526036298700742, 0.011100643763451703, 0.0526528077067009, 0.02513880472231124, 0.09373474094484534, 0.01979247972901378, 0.07661865438733782, 0.022921262375478233, 0.07603248155542783, 0.042646665525223525, 0.06690552737563848, 0.0724326293649418, 0.06411852621074234, 0.04394013986789754, 0.03736870802406754, 0.008276439371651836, 0.03922283210392509, 0.05312514611120735, 0.020392325041549544, 0.06829058698245458, 0.03354303598670023, 0.05438250203483871, 0.04375046218878456, 0.03548978009660329, 0.0345387284510902, 0.04306761847276773, 0.014474442860643779, 0.050457550146217854, 0.0457344205517854, 0.05051024517576609, 0.054191854050649066, 0.012129603951637234, 0.007958538081896092, 0.02592014967064772, 0.030375047586858273, 0.010648159293590911, 0.017635218433237503, 0.010976123257673212, 0.004851979153629924, 0.04845796512173755, 0.01891405338288418, 0.020450731639617255, 0.01282515493221581, 0.014562957753826464, 0.018848213433687176, 0.019627585541456938, 0.034683863698904, 0.02254461606831423, 0.030149611112262522, 0.014379814366943069, 0.039075932665062804, 0.03767105644302709, 0.018658401743908013, 0.045723879510270696, 0.05274863720738462, 0.05568600512508835, 0.01852835711490895, 0.03247369533138616, 0.07010317793382065, 0.08969312174511807, 0.05069429440689938, 0.028505120426416397, 0.04128293566671865, 0.031510955920176845, 0.046229601837694645, 0.02785803720221988, 0.0276315591763705, 0.03088774186159883, 0.03441336571371981, 0.037372378898518424, 0.04036104406363197, 0.05188936081581882, 0.026679260722760643, 0.011441289547032543, 0.045843064186296294, 0.026188138772600462, 0.07194248959422112, 0.032047717832028866, 0.01724395478543426, 0.10705997448946748, 0.1812827895794596, 0.2467729811157499, 0.14147889401231492, 7.5701883009501865, 47.271468094417024, 66.94790840148926, 51.843646798815044, 49.22996030535017, 33.193799359457834, 33.104341302599224, 31.551102774483816, 40.35587739944458, 56.77960538864136, 52.55313083103725, 60.647698811122346, 46.551693780081614, 29.540294102260045, 19.12698892184666, 9.242118562970843, 2.74627223610878, 1.10272373684815, 1.4196616900818688, 2.0003627070358823, 1.4100090137549808, 0.22897530613201006, 0.5820447334221431, 0.7601951882243156, 0.5392297165734428, 0.5900923215917179, 0.6886114808065551, 0.41641053557395935, 0.8777367238487516, 1.197529735309737, 0.5543744553412709, 1.3693577093737466, 0.35865748886551174, 0.9722444925989423, 1.12564160994121, 0.8751593764339174, 1.73934939290796, 0.7047595828771591, 1.528668286544936, 0.636074631341866, 0.807599598807948, 0.7579359923090253, 0.5111580171755382, 0.37405192852020264, 1.1439804030316216, 0.7799473426171711, 0.3427751825324127, 0.18342561673905167, 0.23160981333681516, 0.6585851120097297, 0.5879549362829753, 0.3040194607206753, 0.8402123802474567, 0.6584454966442925, 1.4068727706159865, 2.7397422322205136, 13.39474766595023, 25.764792374202184, 48.39492927278791, 49.105813367026194, 66.12751374925885, 101.61022690364292, 61.29226234980992, 24.170255490711757, 17.649619511195592, 39.35567031587873, 54.60039322716849, 40.603636264801025, 14.724189928599767, 1.115561076572963, 0.2830698277269091, 0.03306638888482537, 0.054329684868987115, 0.03784199637760009, 0.011952661526655512, 0.06028630291776998, 0.014607366174459457, 0.04616890688027654, 0.04215277684852481, 0.018018210739163414, 0.028845643225525106, 0.026237692185012356, 0.03680023138544389, 0.05423495459503361, 0.060611212626099586, 0.016612708568572998, 0.04025955218821764, 0.0421662864807461, 0.03218949093882527, 0.06337764060923032, 0.06020035967230797, 0.07158097970698561, 0.09030877692358834, 0.007080917920185519, 0.024405532283708453, 0.039062626593347104, 0.0182481492936079, 0.11231896693685225, 0.0410128176611449, 0.021552233158477714, 0.0043317103076593155, 0.010008370320844864, 0.04014888991202627, 0.016879320244437883, 0.01100814332520323, 0.0023592751656126764, 0.0384078776197774, 0.0987514488931213, 0.01879732500362609, 0.0478705132513174, 0.04993410448410681, 0.03480685156370912, 0.01920230354049376, 0.01597492297046951, 0.014740528671869209, 0.02246093743347696, 0.048238662603710375, 0.030781350963349854, 0.017840792491499866, 0.08952181879431009, 0.16894947923719883, 0.10841874764966113, 0.13747745087104185, 0.2419711516371795, 0.12974947983665125, 0.08081934933683702, 0.20039750103439602, 0.08810108181621347, 0.10591726723526206, 0.11413580551743507, 0.15727638346808298, 0.10632138233631849, 0.12321388481983117, 0.15248234357152665, 0.15694646617131575, 0.08291389872985226, 0.09866159050060169, 0.08369733526238374, 0.16330617134060177, 0.17594761800553116, 0.08630702844155685, 0.11812559142708778, 0.10161044940884624, 0.13149631395936012, 0.098252481381808, 0.11480070198220865, 0.17841360425310476, 0.23185555157916887, 0.13383392138140543, 0.14381373301148415, 0.10839269869029522, 0.2536349786179406, 0.1933113019913435, 0.13742071177278245, 0.12462952599993773, 0.06217887279178415, 0.1346659953040736, 0.13919875850634916, 0.112374118263168, 0.16184647966708454, 0.14161568667207444, 0.09430278332105704, 0.11007931961544923, 0.10306442781750645, 0.07260606970105853, 0.1552527749112674, 0.08661107319806303, 0.12628692920718873, 0.10660494212061167, 0.18302852447543824, 0.2105030452034303, 0.1299463635576623, 0.2218652226563011, 0.2410961128771305, 0.21738401454474243, 0.53004951775074, 5.734108584267752, 52.45887156895229, 81.10712119511196, 66.97788293021065, 62.06829275403704, 51.93587718691145, 51.20473561968122, 43.215345995766775, 39.081626415252686, 45.722697257995605, 47.96941464287894, 62.22928251538958, 59.61746161324637, 47.111892291477744, 35.144544328962056, 29.447070121765137, 21.463478769574845, 11.926756586347308, 6.570732491356986, 4.044085213116237, 1.2313200192792075, 0.1103875780744212, 0.3990733687366758, 0.5875152455908912, 1.8350958951881953, 1.9997399747371674, 2.8210270362240926, 3.622957936355046, 4.628466495445796, 5.893894570214408, 6.532592526503971, 6.02667464528765, 6.699653710637774, 6.828400356428964, 6.604096872465951, 8.07081469467708, 9.359107988221304, 8.688835246222359, 8.271868637629918, 9.313685008457728, 8.568849410329547, 5.054421033178057, 6.784229789461408, 6.589717141219547, 5.016069148268018, 3.9396972145353044, 2.5609570486204962, 2.0518664462225775, 1.4235636464187076, 1.6197185665369034, 0.6927110265408243, 0.2527989149093628, 0.9411811594452176, 3.157801445041384, 9.212931786264692, 16.674491950443812, 31.820317677089147, 40.87877450670515, 54.935810565948486, 40.7410056250436, 64.58154651096889, 106.6681819643293, 51.1710090637207, 29.317215238298687, 47.702871322631836, 55.62051384789603, 66.109267779759, 47.469703674316406, 14.876049757003784, 0.7702199731554303, 0.627304484801633, 0.12465537818414824, 0.12300815300217696, 0.15993594218577656, 0.12073017523757049, 0.19813616094844683, 0.1676369753799268, 0.08828318704451833, 0.10248759162745305, 0.15254038545702184, 0.15974417461880616, 0.08800033972199474, 0.18683818647904055, 0.16397781244346074, 0.19769406824239663, 0.0897163479988064, 0.13870572139109882, 0.1386860710169588, 0.11989590286144189, 0.14263111432748182, 0.12102660004581724, 0.16034736510898384, 0.14293517944003853, 0.10280583133654934, 0.13651726953685284, 0.13554308323987893, 0.10207097112600293, 0.16171236043529852, 0.07588057113545281, 0.15603026747703552, 0.07506776760731425, 0.12699118070304394, 0.12215655084167208, 0.2100294820432152, 0.14084928136851105, 0.15392095994736466, 0.08849853370338678, 0.20617962362510817, 0.08255865850618907, 0.2521948558943612, 0.1426277080816882, 0.10833904692637068, 0.20881213593695844, 0.09618026936160666, 0.11425825394690037, 0.12957121511655195, 0.15568572096526623, 0.18395457549818925, 0.1620171040828739], [0.04519945336505771, 0.03127908014825412, 0.0591925655358604, 0.020457929199827567, 0.0067686561046035165, 0.03057468616004501, 0.01311736858250307, 0.04223609755613974, 0.04631786567292043, 0.058675311505794525, 0.006600347189565322, 0.03670320087777717, 0.05526337958872318, 0.06293659963245903, 0.021331556607037783, 0.07450258186353104, 0.054446535384548564, 0.02049789491242596, 0.02469027441527162, 0.04150910495913454, 0.07348235018019166, 0.035512270139796395, 0.020715499396568963, 0.04004452444080796, 0.031379126744078736, 0.02450701398109751, 0.0745188192065273, 0.00764749593301011, 0.06966749059834651, 0.07258497404732875, 0.03771534103101917, 0.06492566397147519, 0.05646500064592276, 0.053794276634497304, 0.026988954283297062, 0.027178974622594457, 0.024118717227663313, 0.0585501150095037, 0.038322090437369685, 0.01671712492991771, 0.037331483592944484, 0.035903218268815956, 0.04049530918044703, 0.09388834770236697, 0.027856435859575868, 0.010452349354246897, 0.05274579753833158, 0.039813143999448845, 0.018085389098684703, 0.06487965929721083, 0.060667741378503184, 0.0724372976858701, 0.017970441873850565, 0.026157351942466836, 0.03267243145299809, 0.010530512347551329, 0.09274436480232648, 0.1795209598328386, 0.06174282583275011, 10.769120693206787, 43.507674080984934, 62.38447747911726, 58.416889326913015, 49.558669158390586, 47.799023968832834, 36.07937581198556, 27.39411541393825, 25.448298454284668, 22.40599148614066, 27.659932647432598, 38.850685664585654, 37.70261396680559, 31.641752447400773, 35.24007511138916, 45.61566720690046, 46.98852702549526, 37.03730310712542, 32.75907489231655, 41.6741486958095, 32.644294125693186, 29.552439553397043, 25.599727494376047, 15.400649172919136, 11.223691821098328, 9.475708314350673, 4.5114345124789645, 1.4052373383726393, 0.7628837068166051, 0.5653279104403087, 0.23472909310034343, 0.15562537206070765, 0.1779595421893256, 0.12727080498422894, 0.1380356816308839, 0.11834718739347798, 0.14743431444678987, 0.10199173859187535, 0.20567821338772774, 0.16001849275614533, 0.712485056902681, 1.4108519170965468, 1.543162228805678, 4.7834113240242, 8.311876365116664, 9.459267139434814, 14.695347956248693, 22.080152239118302, 27.85720590182713, 34.04984174455915, 36.19208948952811, 43.653409072331016, 43.82874338967459, 39.5439977645874, 33.271285670144216, 26.86550341333662, 26.439945357186453, 19.868639639445714, 28.521585702896118, 40.13112054552351, 23.31862347466605, 36.79032244001116, 48.04824195589338, 39.005435943603516, 11.17420848778316, 0.31274946512920515, 0.4677557146974972, 0.055816880959485254, 0.10629655473998614, 0.009988292469643056, 0.011403461219742894, 0.031189401567514454, 0.03234251415623086, 0.00475979084149003, 0.05931286300931658, 0.0760604507688965, 0.03677129525957363, 0.04025659716821142, 0.06384479161351919, 0.043286561367235014, 0.041711959788309674, 0.018790505726688674, 0.1054795239386814, 0.0399222558231226, 0.06505665515682527, 0.029216228518635035, 0.04033788227077041, 0.058112643126930506, 0.019308555339063917, 0.018095092149451375, 0.046282486857048104, 0.023414219762863855, 0.009966538636945188, 0.04103290569037199, 0.013178873541099685, 0.11344221380672284, 0.022638391304228987, 0.03766932278605444, 0.01959145355171391, 0.04020165279507637, 0.04246944574905293, 0.06271816563925572, 0.05764678133917706, 0.061824263605688295, 0.021094071046848382, 0.024983720454786505, 0.04960534408954637, 0.0823973910883069, 0.05959826162351029, 0.02333764199699674, 0.0405943752931697, 0.027285160264000297, 0.031031591285552298, 0.02100162404323263, 0.023000377862315093, 0.021348937281540463, 0.032783368535872014, 0.04931091756692954, 0.019102141593715975, 0.06352778683815684, 0.016867318656295538, 0.010573951311276426, 0.02125580665389342, 0.02585463202558458, 0.06578446538852793, 0.05298323729740722, 0.04197262240839856, 0.028908543421753814, 0.01589849278596895, 0.05510480595486505, 0.0824569868189948, 0.06736438668199948, 0.049105165393224785, 0.016052238643169403, 0.04769007721915841, 0.01302881382538804, 0.03492846878777657, 0.04365610171641622, 0.015300830659855689, 0.08626434180353369, 0.018257272196933627, 0.049373112086738856, 0.027440202123086368, 0.028233674188543643, 0.03903029439970851, 0.019676872628874013, 0.06566000171005726, 0.056957335477428775, 0.07947086276752607, 0.04357934244243162, 0.036578021344861815, 0.032265415614736934, 0.04148355811568243, 0.03189325272770865, 0.06021146050521305, 0.0753543943698917, 0.02720236711736236, 0.015854949497484734, 0.02017314126715064, 0.017449220110263144, 0.06976888408618313, 0.016666336583771875, 0.03867120009713939, 0.014460212284965175, 0.0025885214022959447, 0.023017018933647444, 0.05112087240974818, 0.01838169346696564, 0.06570781128747122, 0.03327391542760389, 0.05554924639207976, 0.05301028031057545, 0.03874688728579453, 0.1797048021107912, 0.2425453822527613, 0.4563639802592141, 20.79599486078535, 60.995386668613975, 69.44857897077287, 62.36372320992606, 53.291964054107666, 39.303079400743755, 27.576800925391062, 20.925505808421544, 25.591803073883057, 32.50151906694685, 43.574147496904644, 55.045296805245535, 55.49995912824358, 61.48251792362758, 63.23515932900565, 60.95442703792027, 55.93128940037319, 52.531549726213726, 43.609041350228445, 37.24851792199271, 29.48266921724592, 23.25920942851475, 11.728937898363386, 6.5967448098318915, 3.364733564002173, 1.6453962858234132, 1.9673029610088892, 1.5762519389390945, 0.5898630853210176, 0.8235329038330487, 0.38648456281849314, 0.15615933840828283, 0.5484220747436795, 0.38194405074630466, 0.17744118214717933, 0.1922143144266946, 0.17954037950507232, 0.171314662322402, 0.4102665366871016, 0.41365598195365494, 0.02997322254148977, 0.588895711515631, 1.2186678924730845, 1.4344063103199005, 0.5890002059085029, 1.2169296486037118, 5.347931180681501, 12.337457656860352, 20.807403802871704, 31.08448260171073, 42.98138277871268, 43.72297443662371, 69.5311096736363, 65.14702565329415, 60.641292572021484, 53.2283741406032, 50.285381249019075, 26.605006762913295, 39.400392396109446, 64.50151715959821, 22.276041064943584, 33.94438198634556, 55.49327496119908, 52.9226256098066, 20.563631466456822, 0.8693112730979919, 0.4287974094705922, 0.06347758203212704, 0.039000686524169784, 0.054623931579824, 0.10166693744914872, 0.02022458439958947, 0.08046236527817589, 0.03334868998665895, 0.019215842010453343, 0.03401966273252453, 0.06089996998863561, 0.0601114308727639, 0.06310649123042822, 0.06037559134087392, 0.1010112487045782, 0.08226714629147734, 0.046491567245019336, 0.04732714580105884, 0.012323501270397432, 0.018874538896073188, 0.09856809516038213, 0.06513436777251107, 0.053045506456068585, 0.026962616946548223, 0.040334706726883135, 0.03264535790575402, 0.006460783138339008, 0.05399185924657753, 0.07351694868079253, 0.051117632405034134, 0.052691986318677664, 0.03069021353232009, 0.02634417129281376, 0.04577836247959307, 0.01753539575396904, 0.054217400894101174, 0.0640245626813599, 0.005582036608497479, 0.01397321922039347, 0.04764307849109173, 0.012625934506234313, 0.040410129286881, 0.029236163877482926, 0.042745741815971475, 0.01198527870500194, 0.011504356832509595, 0.03220219989972455, 0.04256747031052198, 0.03024358142699514, 0.018762714628662382, 0.1070959164894053, 0.13801460633320467, 0.09041118821395294, 0.11129833491785185, 0.12531420854585512, 0.07291228576962437, 0.07586339062878064, 0.12799073063901492, 0.12731419051332132, 0.1477475126406976, 0.12021813914179802, 0.08153740902032171, 0.09732813348195382, 0.20633540169468947, 0.14578972198069096, 0.1334837701703821, 0.18753189354070596, 0.1330633227314268, 0.13441424524145468, 0.09594577444451195, 0.12408823147416115, 0.08579966066671268, 0.13569673070950167, 0.1829867267182895, 0.18076110471572193, 0.07890396711549588, 0.04327658011711069, 0.13523206992873124, 0.07477936308298792, 0.19915154789175304, 0.16970491941486085, 0.20685035549104214, 0.11215714990560498, 0.1510012373328209, 0.16337341416094983, 0.11497934668191842, 0.09080868759857756, 0.10074375662952662, 0.17293997082327092, 0.12869431717055185, 0.1687311673802989, 0.0754372299249683, 0.10372834719185318, 0.08290734408157212, 0.17207616860313074, 0.06395666846739394, 0.23053235401000294, 0.1507805913154568, 0.1484904677740165, 0.0994749775688563, 0.17402732319065503, 0.1101431358339531, 0.18482745651687893, 0.08792506304702588, 0.16020519845187664, 0.13118644058704376, 0.09521077174161162, 0.3336169139615127, 0.2258766945451498, 0.43185597392065184, 18.38872718811035, 67.15535381862095, 86.61559745243618, 78.44677407400948, 64.82827704293388, 61.96219376155308, 50.205866064344136, 41.77358089174543, 38.93105895178658, 36.503615447453086, 43.114048208509175, 51.79414783205305, 50.26864998681204, 44.808529717581614, 48.88375241415841, 59.275867325919016, 59.762748445783345, 51.041001319885254, 46.70247663770403, 54.50236804144723, 43.93212563650948, 39.90752404076712, 35.13356964928763, 21.12546627862113, 15.184737375804357, 12.591889398438589, 5.897033418927874, 2.6257778789315904, 1.6203600806849343, 0.925447397998401, 0.3295249678194523, 0.20573402967836174, 0.32461972960403984, 0.3273831584623882, 0.17006242594548635, 0.1718492257807936, 0.16793159528502397, 0.11448390755270209, 0.3277518743915217, 0.3568501429898398, 1.3140051024300712, 2.165627564702715, 2.6796828721250807, 6.373865706580026, 10.582668389592852, 11.900496738297598, 19.878905602863856, 27.641542502811976, 36.23173243658883, 44.89365209851946, 47.24057640348162, 54.87212337766375, 56.09894943237305, 53.177468163626536, 45.37654495239258, 37.50861331394741, 38.6246850831168, 29.795956543513707, 39.270700795309885, 53.492527280535015, 35.46322693143572, 50.09577533176967, 71.41603783198765, 62.72379970550537, 24.32625297137669, 1.1212569709335054, 0.6606822194797652, 0.27089473818029675, 0.10868647042661905, 0.06847947756094591, 0.14871047596846307, 0.16215415458594049, 0.12288609812302248, 0.14557069087667124, 0.12519098658646854, 0.17015033694250242, 0.09554617160132953, 0.1386392113885709, 0.14400501203324112, 0.1362449870045696, 0.15407764725387096, 0.19065691371049198, 0.1674932480922767, 0.14554500154086522, 0.11916577203997544, 0.15138007700443268, 0.22990631046039717, 0.17855019335235867, 0.12620764917560987, 0.22833808032529695, 0.1326272011335407, 0.1994293536990881, 0.0958547354010599, 0.12370834685862064, 0.34208003697650774, 0.17615516829703534, 0.08749143167265824, 0.09763917393450226, 0.0808282924283828, 0.18175914830395154, 0.07536699476518802, 0.2551690377295017, 0.16638102063110896, 0.22080961215708936, 0.12266737914511136, 0.07085606681981257, 0.12547472278986657, 0.21788703969546727, 0.20020597774003232, 0.09596282602953059, 0.11971301053251539, 0.16040912536638124, 0.1469135388199772, 0.11456856158162866, 0.16897344509405748, 0.06592802304242339, 0.20112738758325577], [0.04734497770134892, 0.030235364367919307, 0.04534150467121175, 0.02449523122049868, 0.05482436403898256, 0.02734157027277563, 0.03687198646366596, 0.043384925196213384, 0.03388643577428801, 0.0063254934336457935, 0.0029391586140263826, 0.062038334618721686, 0.014956245132322823, 0.013221346440591981, 0.009933796777789081, 0.08659069000610284, 0.02392801156799708, 0.037888319963323216, 0.024182789593136737, 0.01780031618129994, 0.02622144127131573, 0.0871228107384273, 0.038051056409520764, 0.009764182531008763, 0.035149471036025455, 0.02337772984589849, 0.07186555050845657, 0.06154081917234829, 0.09741623446877513, 0.03833454834031207, 0.04680588502170784, 0.023332446115091443, 0.06113052261727197, 0.08379871517951999, 0.027160055369936993, 0.015638893769521798, 0.0381236834052418, 0.05869258700736931, 0.013907008621442531, 0.026125991750242453, 0.05259269968207393, 0.046553598916424174, 0.012850848508865705, 0.0395213332293289, 0.14247625906552586, 0.07564469879227025, 0.05083332623222044, 0.014979425584897399, 0.03357551067269274, 0.02539129608443805, 0.020935095380991697, 0.05585264314764312, 0.012028681197469788, 0.024457329950694526, 0.02809257961676589, 0.03013007269640054, 0.08389266513820205, 0.1239173085029636, 0.2166690421955926, 0.4499463417700359, 0.19329801627567836, 10.050149764333453, 30.9544574873788, 47.49693019049508, 57.64732422147478, 61.88192817143032, 53.5930711882455, 43.98889241899763, 37.076411042894634, 36.26310702732631, 42.34795025416783, 41.155184268951416, 31.467491626739502, 30.73606170926775, 34.40246629714966, 37.35044799532209, 20.13885681969779, 25.25552589552743, 23.114573989595684, 32.360230922698975, 28.335474729537964, 28.043078899383545, 47.92366770335606, 48.647461550576345, 23.103792122432164, 33.15111657551357, 45.03499582835606, 33.55334084374564, 34.43112414223807, 31.730630329677037, 28.90877754347665, 24.193974903651647, 23.959124054227555, 28.087187801088604, 30.20455230985369, 31.438687869480678, 31.894236087799072, 33.81266845975603, 30.314326899392263, 32.41629941122872, 37.877805846078054, 50.171048641204834, 42.232373918805806, 41.6306460244315, 57.21160268783569, 43.3383013180324, 31.375900472913468, 30.564625331333705, 23.003491401672363, 25.223732675824845, 35.96910095214844, 17.902759756360734, 21.456355128969463, 30.405782563345774, 33.411076477595735, 36.95050968442644, 41.71509790420532, 36.04102175576346, 44.92292833328247, 49.26102222715105, 42.30783135550362, 24.09308706011091, 2.011873049395425, 0.16851400903293065, 0.0690306651272944, 0.027766061780442084, 0.029650178804461445, 0.07131274124341351, 0.06283338088542223, 0.10554630535521678, 0.005107903478866709, 0.06463498635483639, 0.012340464645863643, 0.03978551405348948, 0.051926025455551486, 0.0254533973056823, 0.06884744710155896, 0.03818757765527282, 0.0025543100907400784, 0.008416881701642913, 0.01579047679635031, 0.04932369777400579, 0.032486187161079476, 0.02966966972287212, 0.04295530735648104, 0.10479882439332348, 0.099205239542893, 0.048905838946146626, 0.029876303992101123, 0.012880926269904842, 0.023392303081761514, 0.020607429124148827, 0.005804597790951708, 0.0472704338442002, 0.019537309849900857, 0.05630730910758887, 0.01888630130062146, 0.039511406262006075, 0.042031020524778535, 0.007576912175863981, 0.024886993591540625, 0.0637188758701086, 0.03377827389964035, 0.05864141868161304, 0.04452297770019088, 0.04134012599076543, 0.023793213801192384, 0.020929109005789672, 0.017358934240681783, 0.02278425936986293, 0.015254904017118471, 0.03782877851543682, 0.022144757078162262, 0.048628643820328374, 0.056373096470321925, 0.03362282831221819, 0.04394464534042137, 0.03057735619534339, 0.09799983565296445, 0.057055628060230186, 0.03875703477699842, 0.0359454163616257, 0.034486192877271345, 0.006775402439026428, 0.0464110556723816, 0.02671832907279687, 0.03258727191548262, 0.04795472962515695, 0.07097612680601222, 0.026004588264705877, 0.07772244087287358, 0.03154357988387346, 0.02441978151910007, 0.022502614750659893, 0.023051203527886952, 0.008407401719263621, 0.033750090947640796, 0.0418687794091446, 0.01084304812164711, 0.017154430571411337, 0.07952950854918786, 0.022570746451882378, 0.034672019870153496, 0.014480754932654756, 0.04293645765366299, 0.007539712341635355, 0.05048299181674208, 0.0532183496813689, 0.06193904458944287, 0.039661912114492485, 0.028530307646308626, 0.030045727400907447, 0.02582963479549757, 0.030508471320250204, 0.005744240404705384, 0.01639473089016974, 0.029385584073939493, 0.027192424883001616, 0.010128783145254212, 0.025388100184500217, 0.04618899490950363, 0.04244553078232067, 0.027697344842766012, 0.023772277603191987, 0.03371626597696117, 0.031348952291799445, 0.021101526450365782, 0.012690906778776219, 0.03977409770180072, 0.029831965121307542, 0.0491723301820457, 0.0449574775993824, 0.0629965549867068, 0.16882766863065107, 0.1473281779991729, 0.28396888662661823, 1.049205671463694, 21.00451898574829, 47.67749302727835, 59.31353351048061, 65.73117460523332, 58.39196613856724, 44.179867131369456, 32.92041553769793, 25.051031725747244, 26.403380462101527, 35.35045766830444, 31.837893145424978, 20.928868736539567, 27.208666256495885, 40.24224655968802, 47.098277296338765, 36.84416403089251, 40.05514546803066, 52.1892397744315, 53.50042738233294, 55.05169609614781, 62.76202869415283, 59.2075526373727, 49.895486559186665, 52.9628278868539, 52.007217815944124, 47.85850749697004, 31.57068279811314, 31.084232466561453, 25.82087128502982, 21.626634631838115, 23.70008131435939, 22.108782291412354, 23.3804190158844, 19.190012557165964, 24.009038175855363, 28.098638432366506, 31.704904624394008, 38.5994735445295, 26.464109454836162, 34.98068148749215, 53.34703547613961, 56.08511209487915, 60.75519439152309, 63.65178721291678, 62.74670096806118, 58.37518623897007, 56.32154539653233, 45.207259041922434, 43.885558809552876, 51.61459248406546, 27.502227646963938, 24.448426621300833, 20.3212730884552, 18.054409401757376, 19.009910038539342, 23.53783914021083, 28.411149297441753, 39.26579189300537, 52.055111748831614, 55.56762763432094, 34.39598362786429, 4.395132524626596, 0.1788148491510323, 0.14210967373635086, 0.019515293084883263, 0.028745213257414953, 0.11562337140951838, 0.09623294403510434, 0.0642503791355661, 0.02710581328054624, 0.05763487983494997, 0.03126057989097067, 0.04027158261409827, 0.005961746077186295, 0.02768536700334932, 0.06223618185945919, 0.029409295480166162, 0.09743962357086794, 0.03093578553359423, 0.02486190984823874, 0.03302046224208815, 0.05214186744498355, 0.03662956286487835, 0.02910486395869936, 0.049285784629838805, 0.0677346700270261, 0.07689755263605288, 0.00683768474430378, 0.04831115049975259, 0.01570424178083028, 0.05049241327547601, 0.017054195682119046, 0.07298547934208598, 0.0654499815510852, 0.05550377776048013, 0.01915544900111854, 0.0062118617185790625, 0.04577879674200501, 0.020464617858773897, 0.015998086459668617, 0.04787537156205092, 0.0211592748694654, 0.032827225646802356, 0.026521228220579878, 0.014934138461415256, 0.03680290820609246, 0.06578510999679565, 0.004097124636505863, 0.015210699156991072, 0.049222548558775864, 0.015438401938549109, 0.05713555948542697, 0.044818265962281396, 0.02945882175117731, 0.04605634809870805, 0.25102012178727556, 0.09773283890847649, 0.1725267565676144, 0.12604435293802194, 0.10654681881091424, 0.1922537237405777, 0.06412434804120234, 0.11302523368171283, 0.12845255514340742, 0.09073362805481468, 0.07498104404658079, 0.12512526368456228, 0.14097270688840322, 0.14327351057103702, 0.17703619173594884, 0.1840732241315501, 0.07820418716541358, 0.16008279073451245, 0.16867170057126454, 0.07283850865704672, 0.11052632491503443, 0.16252604605896132, 0.07206001185945102, 0.08379799593240023, 0.18757795249777182, 0.17806576006114483, 0.13506988648857388, 0.17410194847200597, 0.22642801781850203, 0.10600331904632704, 0.1567086667886802, 0.1419482095433133, 0.14404045870261534, 0.12289561118398394, 0.182026491101299, 0.0865056085001145, 0.14306084412549222, 0.18735316741679395, 0.0956530205107161, 0.15315060556999274, 0.0973852729158742, 0.09832334757915565, 0.07355012225785426, 0.16833935411913054, 0.17832528613507748, 0.09140035656413861, 0.12886821212513105, 0.11941516080072948, 0.16631841899028846, 0.1878845960433994, 0.11551684141159058, 0.13561434298753738, 0.1149690600910357, 0.0860237129298704, 0.07659630344382354, 0.13567926521812165, 0.22352654779595987, 0.19184046877282007, 0.31751299809132305, 0.5148187407425472, 0.587055470262255, 17.19500756263733, 49.2072605405535, 69.56470421382359, 80.33243179321289, 77.5761717387608, 65.58390058789934, 53.345479079655235, 49.218818868909565, 50.166007723127095, 55.3576773915972, 55.09839493887765, 42.19802549907139, 40.99890191214425, 47.111027240753174, 47.44029542378017, 28.561322450637817, 34.685786042894634, 33.83535432815552, 40.23718132291521, 39.0022988319397, 39.47043718610491, 62.854189600263325, 65.41339179447719, 37.24661064147949, 50.017750535692485, 60.54546301705496, 49.283510071890696, 50.27392714364188, 46.6377854347229, 41.93144048963274, 35.8519925389971, 36.15150506155831, 39.32285049983433, 41.57194069453648, 43.49182871409825, 43.530672618321006, 46.271285329546245, 41.94774096352713, 44.38668026242937, 48.926643644060405, 62.276016099112375, 55.48267548424857, 58.34029933384487, 72.27170848846436, 56.8065505027771, 44.178011962345664, 42.97520235606602, 32.63035603931972, 35.529484953199116, 49.92553751809256, 24.70768301827567, 28.70997221129281, 40.841271604810444, 47.032547337668284, 53.5687073298863, 56.10343449456351, 50.71780933652605, 63.47266960144043, 75.18764509473527, 69.7261734008789, 39.52956288201468, 4.614855408668518, 0.4324454037206513, 0.1900032537856272, 0.15414537861943245, 0.24079199348177227, 0.21821261436811515, 0.13860189196254524, 0.2558393489037241, 0.10805058133389268, 0.13460884908480303, 0.11779875467930521, 0.09455127641558647, 0.16928471624851227, 0.09473478621137993, 0.11669779089944703, 0.14779372087546758, 0.15553383768669196, 0.06650270149111748, 0.10873446320848805, 0.10653676970728806, 0.08604592138103076, 0.12834255104618414, 0.1002506245193737, 0.20414769622896398, 0.21724996316645825, 0.1952110914779561, 0.11252742646528141, 0.10014510553862367, 0.07645964649106775, 0.1581699326634407, 0.12141073229057447, 0.16080733042742523, 0.08937845791557006, 0.13755169617278235, 0.09397841644074235, 0.09353576055062668, 0.15872890981180326, 0.18319032793598516, 0.10251638865364449, 0.1318861051861729, 0.12598298623093537, 0.13744040285902365, 0.1323475632816553, 0.1129316704879914, 0.1459472913827215, 0.16162052750587463, 0.11303484173757689, 0.08858174245272364, 0.10485888152782406, 0.137255977040955, 0.060463515908590386, 0.1816553867288998, 0.08103890969817128, 0.1389732134661504], [0.033932769538036416, 0.01922825750495706, 0.013270477464954768, 0.04000141032572303, 0.0425517961515912, 0.010331933985331228, 0.013181655534676142, 0.03324274352884718, 0.01412135104848338, 0.011887987809521812, 0.036871331677372964, 0.03823183510186417, 0.06043760944157839, 0.03347533854788967, 0.03262661337586386, 0.04039746103808284, 0.03614898365257042, 0.039969200268387794, 0.04912315335656915, 0.012665498186834157, 0.05822521208652428, 0.0679041612893343, 0.01013342517295054, 0.010704923836913492, 0.030265257228165865, 0.033971639416579685, 0.05865066711391721, 0.08842797284679753, 0.0706414326227137, 0.06254426389932632, 0.045312626220818074, 0.018985550617799163, 0.023888069604124342, 0.043458536067711453, 0.03394015199903931, 0.12846589514187404, 0.06429141014814377, 0.05336876053895269, 0.044766819437167475, 0.11805317816989762, 0.019835514116234014, 0.016489535802975297, 0.02712266469773437, 0.07457956844674689, 0.032419192006013224, 0.028021352099520818, 0.044046870033655844, 0.06671532043921095, 0.025334789384422556, 0.05697746082608189, 0.06923046654888562, 0.0385186281055212, 0.02861196255045278, 0.042448088859340975, 0.01251989305351994, 0.0212803662288934, 0.09144614410719701, 0.05427716625854373, 0.04428873723372817, 0.17222342427287782, 0.03968234619657908, 0.37470391924892155, 0.10092754462467772, 2.186461955308914, 14.068557041031973, 41.176543031420024, 57.526501996176584, 66.66015570504325, 65.72459466116769, 63.01597840445382, 58.31971876961844, 52.206214223589214, 53.57118088858468, 56.26413590567452, 53.03448813302176, 52.016754218510215, 55.75902271270752, 58.71778106689453, 45.810077803475515, 50.187050342559814, 34.642491817474365, 18.99593026297433, 38.67767551967076, 61.658626965114046, 25.598773854119436, 18.490940400532313, 9.175243888582502, 18.4543650831495, 16.95885566302708, 18.36864515713283, 21.303067445755005, 16.68326231411525, 22.638676234654017, 26.121316603251866, 35.80732604435512, 31.3691120828901, 24.669857025146484, 29.189694949558803, 15.606215102331978, 88.9676877430507, 65.3876348223005, 27.91605714389256, 31.164164543151855, 56.82761744090489, 35.30709048679897, 20.310713563646587, 41.7291784286499, 42.384459563664024, 40.419012205941335, 52.08526693071638, 48.52640308652605, 65.75429821014404, 65.62276186261857, 63.25288418361119, 63.85461902618408, 58.59474931444441, 62.51836926596505, 57.999260902404785, 41.10126624788557, 21.648856707981654, 4.099053280694144, 0.04211272971172418, 0.17915016758654798, 0.04422177939808794, 0.021731115345444, 0.0534784491173923, 0.015543819139046329, 0.12945578273917946, 0.006537388045606869, 0.021669969162238494, 0.01879873126745224, 0.04539555337812219, 0.06547586766204663, 0.0209678754077426, 0.018796885652201514, 0.08648876726095166, 0.0201930426992476, 0.05872740942452635, 0.01359859834026013, 0.039885299413331916, 0.027814717830291817, 0.04921749347288694, 0.020483493006655147, 0.03163149766623974, 0.0863267873812999, 0.04556121431025011, 0.03281988389790058, 0.030684130465877906, 0.06469878221728972, 0.0831285057855504, 0.03510635352826544, 0.012828038706045066, 0.039446134585887194, 0.0516793203007962, 0.020383946830406785, 0.07197878443236862, 0.01590242320006447, 0.012895827747083135, 0.03194388501080019, 0.04892515005277736, 0.04510372564462679, 0.03308500110038689, 0.06406847068241664, 0.07453740428068809, 0.03743874640869243, 0.031525812444410155, 0.052193392001624615, 0.1139109797243561, 0.02436028078331479, 0.052260159847459624, 0.10360184112297637, 0.06213837782187121, 0.033338427144501886, 0.016837554717702524, 0.02293395098032696, 0.06088150705077818, 0.050083290585981946, 0.04755216497661812, 0.024111412798187563, 0.07459034358284303, 0.02232721005566418, 0.06995027006736823, 0.02027388336136937, 0.030555466655641794, 0.010032560942428452, 0.032766109997672696, 0.05176085646131209, 0.09758487756231002, 0.03222138208470174, 0.03742653617103185, 0.02126327732444874, 0.02653673104941845, 0.04556301921339972, 0.028468323472355093, 0.039551314299127886, 0.03308115380683115, 0.01870066769021962, 0.0052176980784029835, 0.028404749830120375, 0.01990124210715294, 0.007851145496325833, 0.012780341086909175, 0.05529761168041399, 0.031022661764706885, 0.018834488366597464, 0.03212286897801927, 0.006330165995417961, 0.011631110566668212, 0.016518850212118456, 0.012973331713250704, 0.013053613432150866, 0.01412662411374705, 0.040801386149334054, 0.019569852389395237, 0.012870705836186451, 0.0818017323368362, 0.04753285047731229, 0.022474000928923488, 0.01372528591725443, 0.07750633425478425, 0.042204196232237985, 0.01148779209636684, 0.030632405741406337, 0.02183463434422655, 0.03970084984653762, 0.017005349642464092, 0.06501869790788208, 0.05425860154043351, 0.048477313547794304, 0.05229269220892872, 0.01404389797244221, 0.023440618167764375, 0.10539826258484807, 0.0361202748359314, 0.07742144952395133, 0.16965005307325295, 0.04570114180179579, 0.45106885582208633, 0.23551752365061215, 7.845845052174159, 28.666090863091604, 58.773908615112305, 70.3737941469465, 73.64347049168178, 67.50259699140275, 60.821396827697754, 57.637714862823486, 51.00951903206961, 41.0319892338344, 40.727119650159565, 40.05522884641375, 37.874230997903005, 24.740971837724956, 30.22617162976946, 21.588893754141672, 34.8048677444458, 21.84241267613002, 14.673673050744192, 48.72153629575457, 72.26618467058454, 25.505108663014003, 30.97242205483573, 36.00505093165806, 45.25684486116682, 42.38035665239607, 51.51594196047102, 52.475675787244526, 44.035407134464805, 46.16093403952462, 55.93032707486834, 65.21614633287702, 60.66934939793178, 53.57698958260672, 57.19355821609497, 35.140615122658865, 84.13924557822091, 68.63160283224923, 48.7260456766401, 39.021823269980295, 54.26368352345058, 43.4871768951416, 25.663638762065343, 25.569685220718384, 24.88521122932434, 18.268332277025493, 24.894718102046422, 35.13077299935477, 23.47566839626857, 35.71177441733224, 50.001252038138254, 53.954276766095845, 60.304374422345845, 65.65261827196393, 67.06397805895124, 59.124222891671316, 32.882742404937744, 8.810269781521388, 0.03071739225249205, 0.3557007046682494, 0.03477052619148578, 0.06738736187773091, 0.10379205484475408, 0.07889699177550417, 0.07696011356477227, 0.04618285756025996, 0.0354458992369473, 0.0313081078763519, 0.036941264889069965, 0.0166428032929876, 0.05324383884934442, 0.10203442522989851, 0.0244117086487157, 0.08166017636124577, 0.01797365812983896, 0.05030148709192872, 0.057515796939177175, 0.0123259652006839, 0.026014705221833925, 0.027770524844527245, 0.06738340601857219, 0.031920166819223335, 0.03666402905115059, 0.03444858507386275, 0.052113983048392196, 0.03274559109870877, 0.026796638799299086, 0.02971412055194378, 0.023680729658475945, 0.018752405985391567, 0.06384827928351504, 0.003706348261662892, 0.022584719184253896, 0.08894718105771712, 0.08362778542297226, 0.011238801974936255, 0.036089452382709296, 0.03067432563485844, 0.013128936756402254, 0.047811962464558225, 0.03516558285004326, 0.02578550796689732, 0.00374422620682578, 0.04860119029347386, 0.09213271298046623, 0.061600835594747744, 0.04738912997501237, 0.10562769563070365, 0.014971149154007435, 0.00900280093108969, 0.017620065049933534, 0.0082180972344109, 0.03525767023009913, 0.09782710099326712, 0.11479424232883112, 0.07546038832515478, 0.15738253348640033, 0.19522581568786077, 0.1885825643049819, 0.05430107443992581, 0.15831869468092918, 0.07535863521375827, 0.14702150731214456, 0.11000108452779905, 0.1490347749952759, 0.14585961108761175, 0.13114428999168531, 0.10034104609595877, 0.1207920169191701, 0.14984075246112688, 0.20095330263887132, 0.10469347504632813, 0.11111359697367464, 0.11168263001101357, 0.09985488254044737, 0.13555651823324816, 0.06673541186111313, 0.11167873522000653, 0.10679259776536908, 0.12331111888800349, 0.13766902844820703, 0.11133487402860608, 0.2162336398448263, 0.21090922983629362, 0.07826055306941271, 0.11081244277634791, 0.08825701594884906, 0.1432877326650279, 0.15027658907430513, 0.22912214111004556, 0.10448017077786581, 0.08261841708528143, 0.1675443553498813, 0.14817408046552114, 0.11815130790429455, 0.08257680931793791, 0.10272499067442757, 0.12562796313847813, 0.1070919470595462, 0.09255831728556327, 0.09136540522532803, 0.14188760279544763, 0.12273124286106654, 0.18616810600672448, 0.1899331882596016, 0.09963213984987565, 0.14404663337128504, 0.07151871733367443, 0.2086761982313224, 0.22109668675277913, 0.12823085061141423, 0.17797613915588173, 0.2961706561701638, 0.05570255459419318, 0.474283655839307, 0.15491645224392414, 5.947695340429034, 27.158297027860367, 60.986298424857004, 79.56320367540631, 90.41710976191929, 83.86827972957066, 78.25048746381486, 73.3989703314645, 68.10449164254325, 65.61922522953579, 70.09913185664585, 65.92500155312675, 66.69473688943046, 71.09977667672294, 74.01310076032365, 60.55059078761509, 65.7745452608381, 47.580596923828125, 27.87255447251456, 47.183194705418174, 76.89214243207658, 32.93751505443028, 25.770147698266165, 19.323070560182842, 32.35745511736189, 26.79994021143232, 31.91601174218314, 34.78825807571411, 27.481264931815012, 37.90035622460501, 41.69642462049212, 52.92919165747506, 45.89314004353115, 36.167235783168245, 43.610542161124094, 24.6264203616551, 101.90770012991769, 79.61072935376848, 42.91854327065604, 43.45742470877511, 67.27479335239956, 44.23615448815482, 31.567344188690186, 54.97648184640067, 56.45730972290039, 52.766124384743826, 64.65651062556675, 60.89235877990723, 78.5562915802002, 78.29002966199602, 81.86574636186872, 80.48723070962089, 79.3096569606236, 84.82817336491176, 83.45890576498849, 69.6279467173985, 37.76227814810616, 8.90347899709429, 0.14984915272465774, 0.4082534589937755, 0.1635799195085253, 0.1536193782729762, 0.34868136846593445, 0.15993856133094855, 0.2947467640042305, 0.05246303164001022, 0.19665285625628062, 0.11532245469944817, 0.1256804953196219, 0.19630875757762364, 0.12573635232235703, 0.18387102069599287, 0.14238175270812853, 0.23153821432164737, 0.13442837234054292, 0.1281093114188739, 0.1318498985575778, 0.09648273991686956, 0.13728431266333374, 0.09379641299269029, 0.09901447620775018, 0.20969876407512597, 0.13510268687137536, 0.15634699405304023, 0.10118865168520383, 0.09820876337055649, 0.1712619537221534, 0.1226991345839841, 0.09630022078220334, 0.14397176381732735, 0.1345271806099585, 0.1327079196593591, 0.17058810059513363, 0.11266109107860497, 0.07715557914759431, 0.19648205542138644, 0.09892399356301342, 0.20251998571412905, 0.11971948375659329, 0.12422596051224641, 0.14728081625487122, 0.15628112187342985, 0.10188910338495459, 0.1956889158380883, 0.20633230757500443, 0.15335542815072195, 0.19031713051455362, 0.16840327211788722, 0.1478842781590564, 0.14696654597563402, 0.08189070863383156, 0.1542193525071655, 0.08582919051072427], [0.022498733530353223, 0.030016886269939796, 0.05346708365582994, 0.007982176545608257, 0.04826477263122797, 0.026908951611923318, 0.007503270770290068, 0.006289127773405718, 0.038602328792746575, 0.00921664633122938, 0.026246584386431744, 0.04107346851378679, 0.055736722225057225, 0.037046434424285374, 0.08679971950394766, 0.023341153415718248, 0.07066218900893416, 0.08214950188994408, 0.03085303140271987, 0.027369707423661436, 0.054550117147820334, 0.018786480317690542, 0.03378842817619443, 0.046343137709689994, 0.012843691660756511, 0.027517200580665042, 0.12205202930739947, 0.012644835099178766, 0.02467594375567777, 0.029423090097095286, 0.005402495394394333, 0.01149371316257332, 0.01835204827200089, 0.022267795833093778, 0.02950866354097213, 0.034921815751918724, 0.009970962685266775, 0.07361615050051894, 0.013316135238190847, 0.004869487477532987, 0.04010315665176936, 0.08341742599649088, 0.06259157814617668, 0.026642570637964776, 0.02207471021184964, 0.029490577190050056, 0.044425305976931534, 0.04867735584931714, 0.07320914484028306, 0.048267435881176164, 0.029579777403601577, 0.07256495047892843, 0.023941592446395328, 0.048492377025208304, 0.03659174471561398, 0.06713971695197479, 0.12689793642078126, 0.054600233744297705, 0.045790287732545815, 0.08276778299893651, 0.10156984587333032, 0.19663794205657073, 0.09706815278955869, 0.0740995252771037, 0.2849249967506954, 0.16085952334105968, 3.9750674537249973, 9.512283631733485, 21.737211738313945, 32.749785150800435, 45.06458820615496, 50.88857173919678, 59.8992805480957, 60.16378457205636, 59.654175894601, 62.209403719220845, 65.17768805367606, 57.47139583315168, 61.08585221426827, 51.02003860473633, 53.59429407119751, 61.50974096570696, 40.06767654418945, 39.158108711242676, 57.35514899662563, 57.59261410576956, 47.926502568381174, 37.71702453068325, 38.14864662715367, 41.86668675286429, 38.47382232121059, 50.49456371579851, 36.031395026615684, 43.046483925410676, 32.310916083199636, 38.68745163508824, 46.52005515779768, 41.65326935904366, 50.539372648511616, 56.84131581442696, 60.85672146933419, 49.967233657836914, 63.51431015559605, 64.12407711574009, 52.141206877572195, 61.379205158778596, 69.68534578595842, 67.31628799438477, 70.55801173618862, 65.0618337903704, 69.83737237112862, 66.47584778921944, 52.81242023195539, 48.33824239458357, 37.89643396650042, 24.67335718018668, 22.060174431119645, 8.716671466827393, 1.6077410663877214, 0.03288698422589472, 0.15114477463066578, 0.07154646941593715, 0.05018097248726657, 0.06820759536432368, 0.023223763464816978, 0.07167429184275013, 0.03728795557149819, 0.06156466967825379, 0.03126139074031796, 0.14204541647008487, 0.0026459171952280614, 0.11346019498471703, 0.07962934819183179, 0.029390988605363027, 0.043544462349797995, 0.05249110941908189, 0.03378477426511901, 0.015567847760394216, 0.03313180644597326, 0.020196126640907357, 0.03406004574415939, 0.07047367841005325, 0.008951808176269489, 0.010159115356925343, 0.10900217920009579, 0.030558462387749126, 0.021588319347106984, 0.09861037467739411, 0.05155103647017053, 0.052714757953903506, 0.025285475155604736, 0.04020159851227488, 0.02889290318957397, 0.04950375382655433, 0.03770729021302291, 0.045159718354365656, 0.018283344905025194, 0.03228744086144226, 0.03018921720130103, 0.022197423269972205, 0.03714445898575442, 0.07684466761669942, 0.016268903356311575, 0.049311674133475335, 0.00654873060661235, 0.03876811864652804, 0.10041912512055465, 0.03421960325379457, 0.02787017958637859, 0.05595803999208978, 0.06873685946421963, 0.021840328949370554, 0.010688148754914957, 0.03433626377955079, 0.02398938506043383, 0.02015791324499462, 0.037066586914339235, 0.012851241211007749, 0.024661806478564228, 0.051881425348775725, 0.0462273660648082, 0.01571386680006981, 0.00455078000335821, 0.03634056122973561, 0.012799915125859635, 0.026727229755903994, 0.05887098064912217, 0.053647818243397136, 0.06448783246534211, 0.07484136761299201, 0.05536740239975708, 0.0242340410394328, 0.05259833152272871, 0.05742735668484654, 0.07340107525565795, 0.027448371684710895, 0.015401365800893732, 0.028111276649204747, 0.02051388967915305, 0.02135951733881874, 0.018326915334910154, 0.005918251134322158, 0.1045515187350767, 0.08929265716246196, 0.06527159469468252, 0.01239713080160852, 0.04538668153275337, 0.0330690826688494, 0.026788426829235892, 0.02230492526931422, 0.0916164903236287, 0.029612207984817878, 0.017320534247638922, 0.014047487422690859, 0.0341305760666728, 0.04502897144162229, 0.0450901142321527, 0.03259513952902385, 0.05492357264405914, 0.014603612179468786, 0.030066073273441622, 0.04055999392377479, 0.048374909042779884, 0.03861674087654267, 0.059095541813543866, 0.027838334241615872, 0.05530450898887856, 0.020915618033281395, 0.026554703745724897, 0.06399782161627497, 0.11387953641159193, 0.020538596835519587, 0.07200802929167237, 0.061786231717893055, 0.04985030201662864, 0.056871036001081975, 0.030581525793032985, 0.23056714928575925, 0.14277899424944604, 0.18613903756652558, 0.31269311958125656, 1.036632580416543, 10.826957498277936, 22.100328070776804, 38.34490891865322, 51.94189085279192, 61.38839067731585, 63.05215767451695, 70.44484642573765, 69.6022800718035, 69.46166937691825, 67.17876924787248, 57.84336417061942, 56.20384291240147, 55.48296730858939, 47.84213406699044, 38.92401000431606, 29.64973517826625, 32.91855689457485, 48.16715342657906, 36.65347766876221, 30.194425310407365, 10.417825852121625, 19.774173668452672, 16.56253215244838, 16.618572848183767, 19.641018390655518, 15.177382707595825, 16.98911680494036, 19.166805573872157, 22.960662705557688, 21.694626229149954, 19.318557705198014, 19.94436284473964, 13.520853127752032, 70.0322276524135, 61.81136226654053, 30.809080328260148, 43.20501749856131, 56.58363492148263, 40.196753229413716, 40.75409950528826, 56.10280220849173, 56.827280453273225, 65.91375936780656, 67.43045384543282, 74.11938040597099, 76.91377217429024, 71.32386302947998, 64.9657541002546, 55.57422494888306, 39.35071625028338, 36.145293372017996, 16.80780529975891, 3.9662931816918507, 0.22631227331502096, 0.18496149432446274, 0.09256713824080569, 0.10455951187759638, 0.04459158776860152, 0.045974353927054575, 0.05970567371696234, 0.07195124269596168, 0.013762977689371576, 0.029496019040899615, 0.08554645853915385, 0.040074990663145266, 0.09001001795487744, 0.044787246733903885, 0.05015371234289237, 0.08702105084168059, 0.02226804180203804, 0.03271061261849744, 0.0852182036531823, 0.04720490432477423, 0.03162940438570721, 0.00823697492679847, 0.034731669883642874, 0.00433772848919034, 0.006939176195633731, 0.047011874682669125, 0.021822953363880515, 0.028824754524976015, 0.06555325458092348, 0.0164299180198993, 0.031762610987893174, 0.014135283068753779, 0.04736968316137791, 0.04445417085662484, 0.07704186346381903, 0.06659818493894168, 0.006768338889482298, 0.02816994787592973, 0.03942476073279977, 0.04881406369219933, 0.03664731334096619, 0.04740545552756105, 0.026702624379790256, 0.03836890256830624, 0.04324137772034321, 0.037389311739908795, 0.02544933627359569, 0.06596595993531601, 0.07002665275441748, 0.05646886829552906, 0.05577832320705056, 0.03759461947317634, 0.045890507354800186, 0.025566191878169775, 0.011068070689881486, 0.05411283186237727, 0.03528620941298349, 0.12630567034440382, 0.09613894657897097, 0.09258473943918943, 0.07750041742942163, 0.13401021834995064, 0.11730807886591979, 0.09002549533865281, 0.12893830479255744, 0.11880629775779587, 0.14511576028806822, 0.16099371042634758, 0.086817524262837, 0.10565652658364602, 0.14228789774434908, 0.204326313787273, 0.09634706005454063, 0.129449689494712, 0.11437445985419409, 0.2164236567914486, 0.12032218570155756, 0.14744335253323826, 0.06882971019617148, 0.10740001552871295, 0.1851871343595641, 0.08946334943175316, 0.09192453843674489, 0.24254720072661126, 0.10416400738592659, 0.10483552635248218, 0.16425453259476594, 0.1223352091120822, 0.10122160134570939, 0.13354494688766344, 0.10963002765285117, 0.2401038504072598, 0.20269884754504475, 0.03868949000856706, 0.1043186726580773, 0.07145691636417593, 0.07704830954649619, 0.08699249130274568, 0.11658940171556813, 0.16070020331868104, 0.12472035469753401, 0.10007841233164072, 0.1423134242317506, 0.12478815391659737, 0.11156987784696476, 0.1511090701179845, 0.11811577981071812, 0.1130681713776929, 0.19625197776726314, 0.08636488033724682, 0.13437195893909248, 0.1860204974987677, 0.18915366008877754, 0.14159104228019714, 0.09098058766020195, 0.22923233519707406, 0.1640255813087736, 0.13008063206715242, 0.39526643444384846, 0.3126056157052517, 0.2356630287000111, 0.3596558581505503, 0.46519459784030914, 7.448951789311, 16.66135811805725, 34.754705224718364, 51.71406636919294, 67.4390765598842, 70.44581917354039, 82.85228633880615, 80.39329801286969, 84.36815398080009, 82.79142706734794, 81.91315392085484, 69.85519450051444, 75.36493532998222, 65.74425111498151, 67.12738731929234, 76.17519950866699, 51.038909912109375, 49.73882205145699, 71.32865033830915, 73.1852228982108, 66.88997432163784, 51.7996369089399, 50.857099873679026, 55.255406856536865, 51.024089404514854, 64.48603657313755, 48.93990775517055, 55.07899556841169, 43.314347403390066, 51.10545628411429, 61.52560370309012, 54.971698011670796, 62.980090958731516, 68.44259793417794, 73.11185686928886, 64.16675295148576, 78.44000652858189, 75.92403602600098, 63.76234000069754, 77.68787792750767, 85.84158897399902, 83.92236450740269, 89.07964406694684, 84.28763130732945, 90.03663335527692, 89.60729721614292, 76.44429629189628, 69.45776448931012, 58.89475168500628, 42.24456453323364, 31.117642879486084, 13.772965039525713, 2.8483688490731374, 0.32782586184995516, 0.33561245830995695, 0.12258609064987727, 0.18156856138791355, 0.24492011911102704, 0.17353230475315026, 0.29951849366937366, 0.12446027222488608, 0.109040027883436, 0.11968451206173215, 0.19184213796896593, 0.09392395043479544, 0.17607382551899978, 0.16322811267205647, 0.10991055438561098, 0.168345447363598, 0.16465902089008264, 0.08494541900498526, 0.1328527054616383, 0.19759013024824007, 0.09559013388518776, 0.14606804347464017, 0.10771991764860493, 0.08394968922116927, 0.1520964607064213, 0.1453059943658965, 0.1282005879495825, 0.059243591369262764, 0.20359146036207676, 0.07813494945211069, 0.168493937967079, 0.058883302845060825, 0.11100108229688235, 0.11368603858032397, 0.13662276816155228, 0.1801040656864643, 0.13304151461592742, 0.07534191611089877, 0.09104333179337637, 0.18862983105438097, 0.11411407882613794, 0.076941765977868, 0.21420150888817652, 0.13407717618559087, 0.11287946400365659, 0.07552733937544481, 0.16915762663951942, 0.2542568695332323, 0.23289712997419493, 0.1085044601932168, 0.1266429972435747, 0.1310465538075992, 0.12836206571332046, 0.12914204171725682, 0.07513638785375015, 0.1332192907908133, 0.062421801899160655], [0.02595385759403663, 0.09058985326971326, 0.0428077836654016, 0.019587636792234013, 0.018026047818628804, 0.013663507848312812, 0.028019265604338477, 0.05387925296755774, 0.06560253657932792, 0.051997936596827846, 0.03721724543720484, 0.04248719961781587, 0.04181637954232948, 0.03224267451358693, 0.017829335427709987, 0.029302466926830154, 0.03125589121399181, 0.061521725196923525, 0.01799555615122829, 0.04652412674788918, 0.0224660366241421, 0.0364022163142051, 0.04724600658352886, 0.03275365888008049, 0.0236967668336417, 0.05128561731960092, 0.03527232997917703, 0.06854167886610542, 0.025298341875895858, 0.04617920025650944, 0.05213462747633457, 0.010419664322398603, 0.06303025782108307, 0.045060821875397644, 0.023295314982533455, 0.025966585214648927, 0.03885672853461333, 0.008426616134654199, 0.06784597012613501, 0.042836048041603396, 0.08219159820250102, 0.010173568152822554, 0.04655752084883196, 0.06157199785645519, 0.022938463238200972, 0.0109036862517574, 0.004928797375344272, 0.005828377898849014, 0.03441050568861621, 0.034075991317097626, 0.030668368097394705, 0.01972307407829378, 0.026283547581572617, 0.01277496708956148, 0.012866048541452204, 0.07132342138460704, 0.10236485142792974, 0.02073417607295726, 0.009555631400352078, 0.11234300743256297, 0.06683220488152333, 0.09099008715046303, 0.0668254466727376, 0.03433605004101992, 0.12306007450180394, 0.03002180904150009, 0.12082519728158202, 0.33220184275082176, 0.31773824457611355, 0.11177449686718838, 0.3144787794777325, 1.951165986912591, 6.394712473664965, 10.7644601890019, 15.650058235440936, 25.647011722837174, 46.30318798337664, 52.781250613076345, 55.27034200940813, 65.54756150926862, 70.03392996106828, 63.4487886428833, 69.8612950188773, 67.75483049665178, 52.23411471503121, 55.44872311183384, 74.3610873903547, 78.1398651940482, 77.16537339346749, 81.99099458966936, 78.73788969857353, 81.84253937857491, 80.3434863771711, 82.8719149998256, 84.87269742148263, 83.32711233411516, 83.28700038364956, 79.34859466552734, 74.39625917162213, 65.78195204053605, 66.91607175554547, 73.26268836430141, 62.79553985595703, 59.08520180838448, 70.15148653302873, 55.87822600773403, 46.968929631369456, 34.70857613427298, 29.526237896510533, 27.91577226775033, 15.545843941824776, 12.668961422783987, 4.368187844753265, 2.249174875872476, 0.859210655093193, 0.05729988031089306, 0.10379539323704583, 0.1536699291318655, 0.11034619422363383, 0.02048903494141996, 0.10385060563151326, 0.0757304181211761, 0.03441103494593075, 0.04422087016116295, 0.09289866366556712, 0.049061203109366555, 0.016744381681616818, 0.05700922305030482, 0.016364239222769226, 0.08762492665222713, 0.02707966593360262, 0.12213622193251338, 0.02890867573608245, 0.011936216382309794, 0.04378396146265524, 0.017238653730601072, 0.04453666035884193, 0.009076560232123094, 0.022601195710844228, 0.08035296507711921, 0.012859635537357202, 0.033219296751277785, 0.03002124585743461, 0.027151868844937, 0.011004912650345691, 0.02238130965270102, 0.007976163029005485, 0.028103605810818926, 0.053716604730912616, 0.046744358858891895, 0.03215525206178427, 0.03301272015752537, 0.06596035523606197, 0.027939629341874803, 0.018122265780610696, 0.04715106935639467, 0.006431854645987707, 0.045760187919118574, 0.0168972335689302, 0.06539166146623236, 0.024792728114074895, 0.018572224403864572, 0.0408626103640667, 0.010394568704733891, 0.052258063174251995, 0.04186875566041895, 0.08536928626043455, 0.023903901522446955, 0.00883147762423115, 0.02229696435720793, 0.05016491834872535, 0.0688175508486373, 0.05467140867507883, 0.04542959208733269, 0.08721353765577078, 0.028308121354452202, 0.01924049827669348, 0.0533343181014061, 0.03313817449712327, 0.049680963424699645, 0.019336650081511055, 0.022106865986383388, 0.010674615373968013, 0.01467154371286077, 0.021686315070837736, 0.033782002449567826, 0.020786463981494308, 0.019710015671859895, 0.024399698578885624, 0.02965050789394549, 0.013439864402503839, 0.036971045791038444, 0.05040003751803722, 0.02797156459252749, 0.0323322004239474, 0.04045698891526886, 0.09224275778979063, 0.043863278813660145, 0.04705268517136574, 0.023984899943960563, 0.010322373426918472, 0.023887180723249912, 0.05839446586157594, 0.04607131997389453, 0.03704962693154812, 0.03352086485496589, 0.09371106685804469, 0.014118879484677953, 0.04509017190762928, 0.03901674744806119, 0.02955565887636372, 0.058339959143527916, 0.05662706194977675, 0.06753425113856792, 0.026046389414529716, 0.025558882359681383, 0.05136368277349642, 0.044749849276351075, 0.024947383208200336, 0.05761022187237229, 0.028451148054695556, 0.019114506198093295, 0.06964408114020314, 0.02624800761363336, 0.02289302005166454, 0.023346822575799057, 0.03651852400175162, 0.008937589474953711, 0.05015566313107099, 0.0370833738707006, 0.022200922814330885, 0.10895756552261965, 0.05784954795879977, 0.047194912896624634, 0.08153139720005648, 0.10487679485231638, 0.08092069532722235, 0.1288290335131543, 0.05605565743254764, 0.05824025520788772, 0.06125292354928596, 0.049319324615810595, 0.19542457216552325, 0.2716242718909468, 0.3911390144910131, 0.7464211444769586, 3.7263710158211842, 7.2846303667340955, 15.965588092803955, 24.813983508518763, 32.395628520420615, 43.79809488568987, 63.54664012363979, 68.76450797489711, 67.84683854239327, 70.86016804831368, 72.34151703970772, 68.34505912235805, 59.105400221688406, 54.56278262819563, 53.680170331682476, 55.763177735464915, 65.512375831604, 66.91714872632707, 62.69845962524414, 60.72774205889021, 62.629526547023225, 67.26628180912563, 65.69746889386857, 69.06996468135289, 66.15444496699742, 67.83028098515102, 73.09830093383789, 73.5771985735212, 73.86867550441197, 69.54474898747036, 72.11196245465959, 80.89611830030168, 73.91261591230119, 71.84538786751884, 78.82663209097726, 73.79117529732841, 63.68660463605608, 53.88892895834786, 46.212736334119526, 43.675740582602366, 30.659110409872874, 23.84109500476292, 12.519271169389997, 7.186985160623278, 2.9951653948851993, 0.2741659826466015, 0.1949363255075046, 0.17558772303164005, 0.04486391440566097, 0.017096232622861862, 0.09845190282378878, 0.07372778986713716, 0.05739108220274959, 0.06816685612180404, 0.03644161545006292, 0.02772883734931903, 0.03683552199176379, 0.012092990202030965, 0.03156463482550212, 0.06007066448884351, 0.03237765548484666, 0.07093989982136659, 0.0333562454740916, 0.04140333492042763, 0.02115312055684626, 0.0707627682547484, 0.06825561528759343, 0.036479803400912454, 0.06539119327706949, 0.038818404876760075, 0.014877699614901627, 0.048291004795048914, 0.03912861073123557, 0.0339572239401085, 0.04668306339798229, 0.08799316082149744, 0.019883661264819757, 0.03531829394134028, 0.03227184473403862, 0.02581197252896215, 0.06408699468842574, 0.023145714974296943, 0.035450218112340996, 0.0123815406113863, 0.006659939103493733, 0.04021383249866111, 0.02836317429319024, 0.02575892805387931, 0.017674626050783054, 0.022475290145458918, 0.04388592152723244, 0.05504376155191234, 0.02762549476964133, 0.03657196881249547, 0.04614032359261598, 0.050883992442062924, 0.03030469368344971, 0.01070796197745949, 0.019549396254920533, 0.013636840573911155, 0.031639775793467245, 0.05881394978080477, 0.02145860211125442, 0.04756295368341463, 0.015172624860757163, 0.0274164652717965, 0.15924129874578544, 0.15522800838308676, 0.1397825836070946, 0.09552306069859437, 0.11608656655464854, 0.061910634328212054, 0.10650451215250151, 0.08953859217997108, 0.13179349872682775, 0.11398339298154626, 0.0943111903699381, 0.12851180482123578, 0.19875716976821423, 0.12270009810371058, 0.09771516985659089, 0.15611327945121697, 0.1550146091197218, 0.11818766381059374, 0.09683179190116269, 0.11147420440933534, 0.14878701471856662, 0.15316535692129815, 0.1740257761308125, 0.13709076733461448, 0.11623642779886723, 0.10280973969825677, 0.15148892759212426, 0.21157389559916087, 0.22774873194949968, 0.14955184582088674, 0.14926000790936605, 0.1607392733650548, 0.1041516987606883, 0.1706735688660826, 0.09337572806647845, 0.08413061379854168, 0.20744464360177517, 0.16617317178419658, 0.12788650766015053, 0.12194857985845634, 0.19647126671458992, 0.12499364146164485, 0.12236620459173407, 0.12298576134656157, 0.14596026497227804, 0.09220252744853497, 0.14567993501467363, 0.14600335194596223, 0.13778754137456417, 0.1655852347612381, 0.12973075227013656, 0.11909837994192328, 0.14653662618781838, 0.12257508481187479, 0.06800081860274076, 0.35718376508780886, 0.33806658376540455, 0.11084861547819205, 0.16106843070260116, 0.1738635112664529, 0.1204961756510394, 0.23132216877170972, 0.22636994879160607, 0.08965649442481143, 0.18681648692914418, 0.1295612949345793, 0.3962517487151282, 0.5720756969281605, 0.525761176432882, 0.3639888199312346, 1.7028708074774062, 3.4873948906149184, 9.292664970670428, 17.61647139276777, 27.01642002378191, 40.66984912327358, 66.09564236232212, 78.11047431400844, 79.87961769104004, 89.82577637263707, 90.52367428370884, 82.72002737862724, 87.66972255706787, 84.73110703059605, 72.91420841217041, 71.71557467324394, 89.69896480015346, 98.021315574646, 96.9155445098877, 96.50163337162563, 95.78318963732038, 101.07995428357805, 96.50683757237026, 104.49963528769356, 101.7594325201852, 103.36989293779645, 103.45328521728516, 99.33534499577114, 92.8189422062465, 86.9757364818028, 86.93874427250454, 96.72371864318848, 85.4434780393328, 84.26083210536412, 89.07051413399833, 78.40404960087368, 66.61078180585588, 54.56982462746756, 44.844590868268696, 41.49357891082764, 25.365161521094187, 19.31398057937622, 9.027595537049429, 3.8689111386026656, 1.2911795100995471, 0.14083412289619446, 0.2965790799685887, 0.41974265820213724, 0.2112619594803878, 0.1412561581070934, 0.33128565762724194, 0.1945845051003354, 0.14523919937866075, 0.2542961431401116, 0.15306797357542173, 0.1402540975915534, 0.22959545999765396, 0.10917699017695018, 0.08396943459021193, 0.24560028261372022, 0.18343683970826014, 0.22652826458215714, 0.11473584760512624, 0.08441212440707854, 0.11697364252592836, 0.22462922148406506, 0.12726494244166783, 0.21992211549409799, 0.16749714288328374, 0.16222835917557987, 0.0656459288937705, 0.12016796826251916, 0.11365972499230079, 0.08753751777112484, 0.11952227433877331, 0.18709581265492098, 0.11632125824689865, 0.13337806798517704, 0.11031917495919125, 0.10778476524033717, 0.1505674227539982, 0.1712139541549342, 0.16422037514192717, 0.12388825363346509, 0.09557311622692005, 0.15139744750091008, 0.13048560890768254, 0.11138442065566778, 0.07090762191052948, 0.19607014395296574, 0.09874797479382583, 0.13229785380618914, 0.1049896420112678, 0.07929937661226306, 0.12080862745642662, 0.1361142061650753, 0.23560413186039242, 0.0953729348257184, 0.07981249157871519, 0.11303305040512766, 0.15292533194380148, 0.20533887802490167, 0.12293382627623421, 0.14407462972615445, 0.27191748044320513, 0.0735320800117084], [0.011290664950917875, 0.041020227263548543, 0.05380313830184085, 0.02963205174143825, 0.06006200638200555, 0.05752724382494177, 0.05871822206037385, 0.0644685145733612, 0.051100964192301035, 0.0972815045554723, 0.024423883263287798, 0.019277062832510898, 0.05053270807755845, 0.04574914815436516, 0.05892229825258255, 0.06879358499177865, 0.05193642061203718, 0.03017766514260854, 0.01700169742772622, 0.03592275329200285, 0.017291209660470486, 0.07809094645615135, 0.03956387398232307, 0.023789926299027035, 0.027936158635254418, 0.02778783766552806, 0.028531257595334734, 0.01865807774343661, 0.010360203450545669, 0.05881694212023701, 0.033699238140668185, 0.06867394569729056, 0.03284033155068755, 0.030616884252854755, 0.06363956869712897, 0.03819428158125707, 0.012814912446109312, 0.023829735948571136, 0.03460194416610258, 0.028423289103167396, 0.03105949264551912, 0.08127404922353369, 0.06410399877599307, 0.02103666019892054, 0.050511208695492575, 0.03799903312964099, 0.014286176534369588, 0.04893470382583993, 0.10030996919210468, 0.030047050544193814, 0.10629187284835748, 0.024930043245798776, 0.019752344382660728, 0.005001121998897621, 0.04559732933661767, 0.012932426229651486, 0.03088548912533692, 0.02305244355063353, 0.01797364286280104, 0.0341029630840889, 0.053586119054151435, 0.07192808429577521, 0.08039824371891362, 0.043669597777937136, 0.05100487684831023, 0.07298183560903583, 0.08553431276232004, 0.08980105631053448, 0.197262329980731, 0.036999279633164406, 0.056271234793322425, 0.03322017884680203, 0.37724337726831436, 0.3751352775309767, 0.12367732423756804, 0.11767538344221455, 0.10598815378866025, 0.45537505618163515, 4.176378914288112, 10.111328652926854, 14.944428716387067, 28.51793442453657, 37.376646178109304, 42.60669422149658, 49.86868735722133, 46.90504094532558, 45.378386225019185, 34.54048531396048, 44.64692851475307, 44.07816634859358, 40.02062681743077, 43.67706421443394, 42.868266105651855, 39.510615144457134, 35.73860836029053, 35.295768397195, 31.41432053702218, 31.012575694492885, 31.24299533026559, 30.744298798697336, 34.057595934186665, 24.989005156925746, 13.524098805018834, 8.443599445479256, 4.6679934944425305, 2.263452555452074, 1.2110167316028049, 0.2345093291785036, 0.055061532384050746, 0.09587089131985392, 0.2238769975623914, 0.37268823598112377, 0.23563295602798462, 0.1722003947943449, 0.05606282276234456, 0.05407823336177638, 0.13465703864182743, 0.11268203066928045, 0.019755184051713774, 0.05206614972225257, 0.009951876343360968, 0.026181485736742616, 0.03191675378807953, 0.01744370022788644, 0.028898026128964763, 0.03304879107911672, 0.020230255256007825, 0.0570678688319666, 0.007763445693334299, 0.05646019661799073, 0.04338891837479813, 0.04143777057262404, 0.016371109389833043, 0.012203945944617902, 0.04845326626673341, 0.04230221740103193, 0.013329381089923638, 0.006627653135053281, 0.02510893900346543, 0.04125261193673525, 0.03718177841178008, 0.03366596617602876, 0.05270199810287782, 0.03017193152170096, 0.027284130587109497, 0.021222332825085947, 0.029110760428011417, 0.10878612007945776, 0.041612381381647925, 0.026794445434851304, 0.0944980928408248, 0.05052981412570391, 0.06349948514252901, 0.0270542751532048, 0.03400876885280013, 0.029169172115091766, 0.04687999800911971, 0.036135585978627205, 0.034380589079643996, 0.03249801741912961, 0.029332298718925034, 0.08027789196265595, 0.07367128147078411, 0.06201124071542706, 0.04458383211333837, 0.07012615312955209, 0.04653739889285394, 0.029679257422685623, 0.103494490097676, 0.0687777411990932, 0.0714456866096173, 0.02788244071416557, 0.018194796085091572, 0.02739040783074285, 0.04456177293988211, 0.023431405358548676, 0.035649975429155996, 0.08139805828354188, 0.02356512425467372, 0.018582097088385905, 0.04039164599297302, 0.03210338484495878, 0.06428146961012057, 0.06545129790902138, 0.06844105890819005, 0.05988294777593442, 0.009973888019365924, 0.030095033148037534, 0.04947730792420251, 0.035983522888273, 0.06179928673165185, 0.04074806686756866, 0.01910755630316479, 0.019869418814778328, 0.04304078580545528, 0.016781036143324206, 0.06054000037589243, 0.06204015987792185, 0.015811428261388625, 0.03772096269364868, 0.0054824293640974376, 0.016277218802965114, 0.01170519895718566, 0.0345503246145589, 0.03168889155079212, 0.055898678355983326, 0.07341002513255392, 0.034186514493610175, 0.030857177251683812, 0.017140685148271065, 0.03034178919291922, 0.0316750935411879, 0.05106039797621114, 0.02874510808448706, 0.06324614730796643, 0.024218757038137743, 0.05876421316393784, 0.05419765552505851, 0.06977784753377948, 0.03371837282819407, 0.07251207224492516, 0.011596840307382601, 0.02339739039806383, 0.020778431823211055, 0.058021705863731246, 0.05156714828418834, 0.013010184646451046, 0.028118723571034412, 0.0413606754238052, 0.02621606727396803, 0.022745611711538265, 0.03366963365780456, 0.023642875886123096, 0.03572675505919116, 0.054280094137149196, 0.020948557515761683, 0.07710153383335897, 0.13230581980730804, 0.06627052037843637, 0.03194417338818312, 0.0664251788652369, 0.10082101462674992, 0.12128676394266741, 0.0899284580456359, 0.059152688032814434, 0.16450213002307074, 0.10457081627100706, 0.07638923491218261, 0.07286368909158877, 0.21265185704188688, 0.5404484197497368, 0.35941676955137936, 2.282311269215175, 6.156962922641209, 13.551323584147863, 24.764130183628627, 32.19927590233939, 45.202996322086875, 56.4382403918675, 64.7730666569301, 65.00799219948905, 61.79340117318289, 61.50029141562325, 54.65977600642613, 63.79024396623884, 62.723716327122276, 60.05309282030378, 60.07668195452009, 62.07322597503662, 59.23255920410156, 55.50122717448643, 53.08812127794538, 50.22065530504499, 49.739666257585796, 46.979518686022075, 49.185554368155344, 49.748580796378, 39.37831449508667, 25.333470787320817, 18.61893490382603, 13.529595698629107, 6.647342460496085, 5.519800083977835, 1.8546709247997828, 0.6599412592394012, 0.5965658170836312, 0.42659040646893637, 0.4157942629286221, 0.09236193568046604, 0.24938403815031052, 0.15672499234122889, 0.12280343898705073, 0.04436431246410523, 0.11329291574656963, 0.06406305597296783, 0.05348458307396088, 0.08623719361743756, 0.10663703004164354, 0.09805309386657816, 0.08402038578476224, 0.02662000765225717, 0.05321585267250027, 0.006073998669827623, 0.030559161278818334, 0.055708793723689656, 0.013047672009893825, 0.06763920014990227, 0.030948511457868984, 0.05402880547834294, 0.03496886197743671, 0.04458568112126418, 0.015812206880322525, 0.0717825521049755, 0.02363121017281498, 0.015587798386280025, 0.04610626452735492, 0.04404335182958415, 0.050486923927175145, 0.017476135898115377, 0.03288177986230169, 0.029754863187138523, 0.028656087682715485, 0.03770110536632793, 0.05785528836505754, 0.03726575729836311, 0.038850597970719845, 0.01103953829234732, 0.011303426498281104, 0.027963478151442747, 0.04354810269017305, 0.050837692605065446, 0.0077143112762964195, 0.05679094512015581, 0.04221941577270627, 0.02051870558144791, 0.026408560873408402, 0.02930327777617744, 0.04550834625427212, 0.01769226456859282, 0.042566805346203704, 0.04335307136976293, 0.041419677436351776, 0.06096460723451205, 0.0582855474203825, 0.021705332711072903, 0.06023807264864445, 0.07999942797635283, 0.04864126117900014, 0.03346316562965512, 0.03782605419733694, 0.0494561274535954, 0.010095860626149391, 0.20009861992938177, 0.19078491255640984, 0.1558748558163643, 0.0763966173731855, 0.2533550964934485, 0.14323913598699228, 0.1251791257943426, 0.18659269250929356, 0.07768810021557979, 0.16757670789957047, 0.1832658081714596, 0.11268113500305585, 0.11607732490769454, 0.17778401875070163, 0.15906439109572343, 0.2036604673734733, 0.09574887036745038, 0.12386127508112363, 0.10250737770859684, 0.12454447842070035, 0.10591942497662135, 0.17141262920839445, 0.15661103917019709, 0.15479720649974688, 0.07060127692031008, 0.14579485170543194, 0.09578738401510886, 0.12195594874875886, 0.04334612995652216, 0.1280759817787579, 0.1407282171504838, 0.08079193652208362, 0.10418971029243299, 0.12167223968676158, 0.13509348593652248, 0.14587817580572196, 0.15569987520575523, 0.13364383658128126, 0.11885831425232546, 0.07292057746755225, 0.13197248269404682, 0.18785631470382214, 0.1296973412058183, 0.13454573175736836, 0.19931362276630743, 0.11301966290920973, 0.11301973754806177, 0.14995423065764563, 0.17647355049848557, 0.16130869995270455, 0.13161960377224854, 0.11612608443413462, 0.1663601624646357, 0.09799974065806184, 0.09203532963458981, 0.09992256640855755, 0.10026129108986684, 0.15908169373869896, 0.15287634171545506, 0.1210728082805872, 0.16742467534329208, 0.31372625700065065, 0.18939943904323236, 0.11102730089000293, 0.24333408421703748, 0.1936413278537137, 0.22025469264813832, 0.15931627686534608, 0.24824838766029902, 0.15617911091872624, 0.09779527770089251, 0.10005454146968466, 0.48371116710560663, 0.5995970772845405, 0.5802555722849709, 0.15809817079986843, 0.7337287941149303, 2.8819827139377594, 7.723277960504804, 16.296862568174088, 24.339008126940044, 41.623294830322266, 52.8184860093253, 62.72893442426409, 71.11475004468645, 68.48111874716622, 63.515651157924104, 54.71016781670706, 61.33586229596819, 59.241126332964214, 58.72876616886684, 59.11860874720982, 58.20404168537685, 54.77686357498169, 49.92350517000471, 49.330372197287424, 46.29137257167271, 47.4332013130188, 46.48784678322928, 45.981041703905376, 46.765319619859966, 33.80388593673706, 21.351956708090647, 12.496431572096688, 8.074072531291417, 3.5473376512527466, 3.044289376054491, 0.7013527399727276, 0.2768124049263341, 0.15898264119667666, 0.38892840168305803, 0.6747420078941754, 0.3342256412974426, 0.29235585087112015, 0.18726841839296476, 0.1347211737717901, 0.3087419830262661, 0.23013215405600412, 0.19115642404982022, 0.268423106521368, 0.2519691751471588, 0.349554643034935, 0.15628984783376965, 0.22172207890876702, 0.1139618834214551, 0.18284796630697592, 0.06852082069963217, 0.06976350330348526, 0.11326228667582784, 0.11566601055009024, 0.10453302187046834, 0.11332376194851738, 0.1884615272283554, 0.12377829024834291, 0.1689810175448656, 0.16261713259986468, 0.16868023654179914, 0.14470528731388704, 0.08909886756113597, 0.1635295043566397, 0.11443863569625787, 0.12462071861539568, 0.09339155828846352, 0.07925878664744751, 0.08396589942276478, 0.06306753653500762, 0.15923901886812278, 0.19217780924269132, 0.1171697662877185, 0.09784008815352406, 0.19128795127783502, 0.08486170135438442, 0.15800337945776327, 0.1325240366693054, 0.18804629093834332, 0.08189382989491735, 0.14536521690232412, 0.1413585761828082, 0.14225405241761888, 0.08398242175046887, 0.10940451653940336, 0.12774501953806194, 0.1251030620187521, 0.13970251647489412, 0.11766551754304341, 0.16662677244416305, 0.1502107304653951, 0.0991142208554915, 0.3111293949186802, 0.1447580773383379, 0.13284644936876638, 0.11849304528108665, 0.06319836487195321, 0.10455645168466227, 0.1667588832122939, 0.09233771198030029], [0.060078847621168406, 0.04065115849620529, 0.028455207390444617, 0.06173343490809202, 0.08314507561070578, 0.07223514174776417, 0.03384283650666475, 0.04049556363107903, 0.06407571743641581, 0.024648758250155618, 0.020161290653049946, 0.007772112281859985, 0.02967070448877556, 0.06629352271556854, 0.04228996305859514, 0.01883136710551168, 0.02138949671228017, 0.04437642092151301, 0.015344379037352545, 0.045850751988057575, 0.06309256090649537, 0.04672089172527194, 0.015210880665108562, 0.02445082619254078, 0.010223535471595824, 0.03681610231953008, 0.043013705472861014, 0.028682866067226444, 0.04713144273098026, 0.01800607344401734, 0.07938681942011629, 0.027867261885798404, 0.03300719688247357, 0.0506046735016363, 0.06188735379172223, 0.026264709753117392, 0.025636432126962712, 0.010553359469797994, 0.02733763476966747, 0.03086527217445629, 0.06532621676368372, 0.01944945483202381, 0.005548994921680007, 0.016247180057689548, 0.07468291611543723, 0.011980267723889222, 0.05052148510835, 0.08302460171814476, 0.0249395698774606, 0.012376713682897389, 0.032024352478661706, 0.03896598285064101, 0.012806687753514519, 0.05578161070921591, 0.015558522992900439, 0.006636165780946612, 0.017032982981098548, 0.036499243429196734, 0.023305847542360425, 0.01719061514761831, 0.03773331881633826, 0.11422731275004999, 0.06720756366848946, 0.06502245699188539, 0.087825698378895, 0.0074269109837976945, 0.04205718483509762, 0.13694720289536885, 0.11643662277076926, 0.04021853135366525, 0.03419010733653392, 0.04737679760104843, 0.2121264130941459, 0.18713253497013024, 0.08923885612083332, 0.10686279221304826, 0.09022417717746326, 0.026618168822356632, 0.19929338885205133, 0.30335045233368874, 0.2031117496745927, 0.49393848116908756, 0.005073968670330942, 0.15178848723215715, 0.24469886241214617, 0.35044773082648006, 0.6074205317667553, 0.2657910963254315, 0.5428101558770452, 0.5123113095760345, 0.5022283334817205, 0.523537101490157, 0.41365421776260647, 0.1184666638395616, 0.11514458352965967, 0.10127373997654233, 0.19318175608558313, 0.05144579568877816, 0.08724295893417937, 0.262055652482169, 0.1714964418538979, 0.25645472588283674, 0.3804425613156387, 0.2441268302500248, 0.13616021083933966, 0.06039653093154941, 0.12511041733835424, 0.02447188113416944, 0.03814855171367526, 0.0611455657386354, 0.06926976051181555, 0.09280276631138154, 0.0508602063969842, 0.14714825765362807, 0.050655631481536796, 0.020310821111447046, 0.012192336210448827, 0.0811386543459126, 0.021475953948018805, 0.04600188548543623, 0.036016713428710184, 0.027895646701966013, 0.025468728804428662, 0.07074763692383255, 0.014815452508628368, 0.06768709793686867, 0.03285950016496437, 0.020986803142087798, 0.028685590385326316, 0.035722202089216025, 0.011682529102212616, 0.049642948500279865, 0.02798240927846304, 0.01657226448878646, 0.033164108105536015, 0.02676254411094955, 0.05251296163935747, 0.02386297398645963, 0.0095126589294523, 0.06351979369563715, 0.013214968211416687, 0.03202523457418595, 0.018405521920483028, 0.03671921430421727, 0.03869933894436274, 0.011114730150438845, 0.009981634344772568, 0.04887768313554781, 0.040228763661746464, 0.015597464117620672, 0.02718639270668583, 0.03518234945035406, 0.04662207667050617, 0.039563826484871764, 0.05161927334432091, 0.04899496452084609, 0.030022796309952225, 0.008763015985355845, 0.04550076362543872, 0.034371869904654365, 0.07783422273184572, 0.05007072411743658, 0.014967931201681495, 0.028071404235171418, 0.033974913348044665, 0.06485228040920836, 0.03528684384322592, 0.022199577618656412, 0.06841232973550047, 0.012738559444967126, 0.021743250944252526, 0.031473619530775716, 0.02640521739210401, 0.04658286413177848, 0.041699912399053574, 0.054784683311092, 0.08205031364091805, 0.02242525327684624, 0.03373480694634574, 0.02679852512665093, 0.07828137730913502, 0.041055192173059495, 0.027510004716792276, 0.01943841845994549, 0.03730798592524869, 0.010864183639309235, 0.028779180720448494, 0.03490866235058222, 0.038459890721631904, 0.055300346176539145, 0.010249283331047212, 0.052306632710886855, 0.036888868414929936, 0.04734021099284291, 0.08736552949994802, 0.0433641823806933, 0.030565179884433746, 0.02166193870029279, 0.008222092109333192, 0.1001313855605466, 0.005937570722640625, 0.011633560078085532, 0.026941991178318858, 0.06752125040761062, 0.07618742502693619, 0.013332388696393796, 0.04075890985716667, 0.02641420967743865, 0.027732007804193666, 0.004839482659008354, 0.040991386132580895, 0.022297268001628772, 0.0416187188987221, 0.03538850874507001, 0.02227673213928938, 0.07920913824013301, 0.04322131343984178, 0.016416745958849788, 0.021822161174246242, 0.024650315488023416, 0.04268439207226038, 0.025317675034914697, 0.031048754828849008, 0.04956597548776439, 0.06037487209375415, 0.07094160294426338, 0.022676445244412338, 0.07832599098661117, 0.03751719184219837, 0.03129199606233409, 0.028949893345790248, 0.02805911426964615, 0.059052081645599434, 0.052447740853364976, 0.11097477549420935, 0.007152522448450327, 0.04633543972990342, 0.09377416382942881, 0.03578701575419732, 0.08866485620715789, 0.03677109848441822, 0.04816981504804321, 0.043081677718354125, 0.0420830505900085, 0.06553784505064998, 0.08621676971337625, 0.06848164887300559, 0.08952685352414846, 0.09759021084755659, 0.038040484833930216, 0.044442201498895884, 0.11781529736305986, 0.13384996194924625, 0.11591672923948083, 0.2784097577844347, 0.14156508153038366, 0.21369053130703314, 0.6755788858447755, 0.13535725963967188, 0.6025350796324866, 1.3474849973406111, 1.7032492671694075, 2.765635128532137, 1.7417637833527155, 2.494775022779192, 2.653147918837411, 2.457294919661113, 2.531604600804193, 1.8198657695736205, 1.2339835677828108, 0.6147430102740015, 0.8152401745319366, 0.5449115516883987, 0.7534647179501397, 0.21547346349273408, 0.3190688517476831, 0.4911658785172871, 0.3358348549476692, 0.2809826268681458, 0.11108778550156526, 0.08047915901988745, 0.1329575391220195, 0.20866296679845878, 0.02645408209147198, 0.02697348198853433, 0.14882987099034445, 0.07230752786355359, 0.10392728687397071, 0.053342470699655156, 0.10308916720428637, 0.06715044459061963, 0.0306756996682712, 0.026500453174646412, 0.13548243577991212, 0.0405085304352854, 0.08310471634779658, 0.032060789809163125, 0.022490031318739057, 0.06683156705860581, 0.02757572931503611, 0.02326251968874463, 0.07596613440130438, 0.014330908955473984, 0.04236007608207209, 0.03457242110744119, 0.019562780358163372, 0.019736035793487514, 0.030699597671628, 0.0440671243039625, 0.014357577078044415, 0.04501962462174041, 0.034355893797640286, 0.0418434802309743, 0.042981777007558515, 0.04097433115488716, 0.025548219181863323, 0.04286692477762699, 0.03463970124721527, 0.04344071095277156, 0.03805089695379138, 0.07368279621005058, 0.05630728875153831, 0.008575695367263896, 0.021131373509498577, 0.05301348978121366, 0.039752642424511056, 0.03494780703580805, 0.04319991923070379, 0.018652868290830935, 0.022197423269972205, 0.03397619577922991, 0.018222870471488153, 0.0640397279390267, 0.0235663133872939, 0.049530308294509134, 0.008882942809058087, 0.03592772695368954, 0.017548778160874332, 0.014585359587467142, 0.014303881209343672, 0.06976454146206379, 0.0011428001286861087, 0.010692152111524982, 0.038301079600517235, 0.01735545844504876, 0.017344062449410558, 0.02132067969068885, 0.022209803141387444, 0.07580002902873925, 0.01617572353487568, 0.01713482939106013, 0.07059250346251897, 0.19505194787468227, 0.1643789623464857, 0.11155052602823291, 0.16815078923744814, 0.23466441514236586, 0.2134580516389438, 0.07938718582902636, 0.14663096969681128, 0.11639762057789735, 0.0901345901989511, 0.06813793695930924, 0.10206150556249277, 0.14627422312540667, 0.18051816203764506, 0.0679536604189447, 0.11556022694068295, 0.10605914212231125, 0.27024595013686586, 0.2501736900636128, 0.15023271499999932, 0.20887016425175325, 0.1342193835547992, 0.0985851806721517, 0.19026666107986653, 0.09586409239896707, 0.12986278161406517, 0.1046391718887857, 0.1457216649183205, 0.16006030408399446, 0.12630277978522436, 0.09715261682868004, 0.06129385956696101, 0.11605449898966722, 0.08974585070141725, 0.10912906524858304, 0.0882976126990148, 0.07070157118141651, 0.12979681443955216, 0.05983676668256521, 0.14889484750373022, 0.14199914038181305, 0.08795491858784642, 0.11519539223185607, 0.10526544614029781, 0.16743771678635053, 0.06400991311030728, 0.1539666796369212, 0.11004949121602944, 0.11098389500485999, 0.11598062009683677, 0.16949662273483618, 0.2465110665985516, 0.11137726211122104, 0.13686497802180903, 0.09662087607596602, 0.11709504601146493, 0.13573520364505903, 0.09208832321954624, 0.32274249462144716, 0.08518334052392415, 0.10039185479815517, 0.2216046652091401, 0.09813152572938375, 0.15526414715817996, 0.17150976828166417, 0.10815880766936711, 0.09902336501649447, 0.1855085699685982, 0.3063424660691193, 0.15291142197591917, 0.16633540950715542, 0.15545909026903765, 0.21080545469054154, 0.4312225750514439, 0.2596860182072435, 0.27012633798377855, 0.15665301334645065, 0.1397012136876583, 0.42401061632803505, 0.4471588656306267, 0.32966214045882225, 0.6121942156127521, 0.10169352923652955, 0.21310910822025367, 0.4778810313769749, 0.553967225764479, 1.028972517166819, 0.7584898940154484, 1.0349569789000919, 1.1311513142926353, 1.1344825412545885, 1.024789267352649, 0.7356622389384678, 0.5318113746387618, 0.2470505562211786, 0.3188120126724243, 0.23833252117037773, 0.3666005826422146, 0.12252825232488768, 0.26937264842646463, 0.30762337733592304, 0.2824931543852602, 0.572716722530978, 0.29736010091645376, 0.2795611231454781, 0.18251784544970306, 0.2148516947137458, 0.11565773242286273, 0.12791792383151396, 0.2034542334399053, 0.2676592660801751, 0.2349176715527262, 0.19281160166221006, 0.26567235269716805, 0.19597892170505865, 0.11496190833193914, 0.17434168846479484, 0.3234043376786368, 0.12524346448481083, 0.2004715699170317, 0.12300417678696768, 0.12961005446101936, 0.15863554339323724, 0.15583479510886328, 0.13048152412687028, 0.12181315783943449, 0.15031812898814678, 0.19176726841500827, 0.18844854006809847, 0.12550114494349274, 0.1174785132919039, 0.1749292319374425, 0.1392280983605555, 0.14203411207667418, 0.12318852118083409, 0.1267373136111668, 0.1325336311544691, 0.11257459143442766, 0.0820415537538273, 0.09586034688566412, 0.07352753382708345, 0.09526029122727257, 0.10261974989303521, 0.10958239449454205, 0.11949083102600914, 0.1381526067852974, 0.1713964393628495, 0.11652689506965024, 0.11926135048270226, 0.1412283517420292, 0.2235817534050771, 0.08368552875305925, 0.11482554993459157, 0.08350880430745226, 0.12293066430304732, 0.11746784672141075, 0.19098106345960073, 0.12297912527407918, 0.10366516879626683, 0.16001493723264762, 0.13505695361111844, 0.1396764200180769, 0.04637587023898959, 0.12383626428033624, 0.20711350494197436, 0.11804036742874555, 0.10313417443207332, 0.10135191399604082, 0.12248211194361959, 0.15293122162776335, 0.09935094815279756, 0.14958502618329866, 0.22987303510308266, 0.14533100516668387, 0.12400403884904725, 0.13691802588956697], [0.04982997650014503, 0.02413019464750375, 0.02531376328053219, 0.037020660271602016, 0.030268324206450155, 0.03225477279296943, 0.027830012009612153, 0.017790348501875997, 0.030780149956366847, 0.024141487166551606, 0.0010479041437585174, 0.06234651165349143, 0.04665834775992802, 0.05004046145560486, 0.03141073629792247, 0.021269016034368957, 0.07059434907776968, 0.09635045951498405, 0.010954126000537403, 0.031754773908427784, 0.02658599608444742, 0.014268056256696582, 0.06640115194022655, 0.01572666736319661, 0.031110447232744524, 0.0053371571370267445, 0.025832700077444315, 0.026649669810597385, 0.10466129891574383, 0.029470913245209625, 0.06098415582839932, 0.06732564233243465, 0.0884191043941038, 0.04115452630711453, 0.012271201487497559, 0.0436884440880801, 0.053128250408917665, 0.026936586646895324, 0.04720378813466855, 0.05721986746149404, 0.04696466221607157, 0.04643980520112174, 0.038732180039265325, 0.04002486728131771, 0.02425746406827654, 0.052730320154556205, 0.058331484241144996, 0.010564374637656977, 0.04948559283678021, 0.04297617570097957, 0.05815221528921809, 0.03399515065497585, 0.04716702510735818, 0.015478121682203241, 0.041015277350587506, 0.02787937712855637, 0.02175864011847547, 0.051056214807821174, 0.07996327563055924, 0.07968054365898881, 0.02971572189458779, 0.08154466255967106, 0.11792901983218533, 0.04985605938626187, 0.04525293210255248, 0.04330561802323375, 0.034997397767645974, 0.05574993669454541, 0.016899233550897667, 0.06585769967309066, 0.0324272835361106, 0.036758735576378446, 0.06592000954385314, 0.15345332718321256, 0.19960585422813892, 0.0390762821105974, 0.12951356678136758, 0.05773384416741984, 0.05038331502250262, 0.11740106530487537, 0.10111023339309863, 0.24232130284820283, 0.05262718961707183, 0.04881455563008785, 0.02466641882035349, 0.03219570292692099, 0.06307960088763918, 0.014856403793341346, 0.0507552336369242, 0.02156473516619631, 0.07311176827975682, 0.11310186742671899, 0.056342871127916236, 0.06648245400616101, 0.047022130739476, 0.017060136256207312, 0.04280780062877706, 0.015723227190652063, 0.05403079358594758, 0.0943003948777914, 0.154671935364604, 0.14702769555151463, 0.1971232710140092, 0.158667190266507, 0.059134788279022486, 0.06866673965539251, 0.07075218989380769, 0.011968577413686683, 0.027748397817569118, 0.06545912820313658, 0.09517932164349727, 0.03776199709890144, 0.10861969579543386, 0.038742453059447665, 0.03385510781247701, 0.017772304559392587, 0.024612147893224443, 0.04778557423768299, 0.019348105448963385, 0.0368360241076776, 0.0417785172882889, 0.045060211193880866, 0.07170224748551846, 0.02402148994484118, 0.03487573643880231, 0.05928324495575257, 0.043814848376704116, 0.004109584235785795, 0.017341914886076535, 0.07267467637679406, 0.08896301127970219, 0.04263134081182735, 0.03278347370879991, 0.011221552766593439, 0.01847856960791562, 0.03622687608003616, 0.029108181994940554, 0.02519301967030125, 0.05161166696676186, 0.0879394615601216, 0.04868006659671664, 0.024844149194125618, 0.026749914877914956, 0.024493297395695533, 0.07964276961450066, 0.017571312308843647, 0.008844884628030871, 0.04876184363716415, 0.05365498696586915, 0.02529948860007737, 0.055746320102896006, 0.023821669863536954, 0.046304488355027776, 0.05035080640975918, 0.06502954089748007, 0.08391446646835123, 0.05104590107553771, 0.031468418559857776, 0.03599333789731775, 0.04582425519557936, 0.06606553494930267, 0.029305679790143455, 0.06854332770620074, 0.05650613683142832, 0.02192535956523248, 0.06706904074443237, 0.01762479274267597, 0.03273111794676099, 0.05785780572997672, 0.020720951425443803, 0.11605261266231537, 0.04640983770202313, 0.014186425949446857, 0.025653108821383545, 0.03723549124385629, 0.04922768846154213, 0.030631588106708865, 0.02817746943661145, 0.04937819431402853, 0.037034410783754926, 0.027086773587922965, 0.07360521930136851, 0.057876607935343466, 0.05139767059258052, 0.019435980822890997, 0.05691488632666213, 0.03603815852797457, 0.024249677878937552, 0.01930277082802994, 0.029536568293614045, 0.05361721970673118, 0.013193373834448201, 0.06513861540172781, 0.016186982127172605, 0.055240465461143425, 0.03882146846236927, 0.032435693977666755, 0.07126757116722209, 0.031012293749621937, 0.04451121868831771, 0.0506676788707929, 0.004403270307063524, 0.026250234904832075, 0.0638115026855043, 0.06647294094519955, 0.033037140632846525, 0.07996500589485679, 0.035393417945929935, 0.052003904312316857, 0.08484185420508895, 0.03200644933219467, 0.062340689823031425, 0.045365497669471164, 0.01591375982388854, 0.03826724784448743, 0.02081161897097315, 0.026098198955878615, 0.040232828086508174, 0.021814965310373476, 0.05381001186157976, 0.008081867758716856, 0.0426605347810047, 0.04293138560439859, 0.04401184405599322, 0.0715583437787635, 0.03433372945125614, 0.020497187539669018, 0.04243158010233726, 0.015130660862528851, 0.027867283938186507, 0.04922158503904939, 0.044548185276133676, 0.02307048749311694, 0.06447153405419417, 0.03030469368344971, 0.037351463056568585, 0.05976735933550766, 0.087561938246446, 0.09569621605000325, 0.013397619660411562, 0.02324305082272206, 0.01575722518776144, 0.020038679375180175, 0.15368174921189034, 0.05169254834098475, 0.13481136464646884, 0.06190146053475993, 0.07164301137839045, 0.07362105630870376, 0.004399328442689563, 0.016091220479990755, 0.05815054609307221, 0.130344120785594, 0.12526071284498486, 0.046940601364310296, 0.07588078826665878, 0.09712609968015126, 0.162541679505791, 0.05098275999937739, 0.08280175724732024, 0.07405289635062218, 0.08904921236847128, 0.018236098511676704, 0.10907333038215127, 0.06492673605680466, 0.13660261567149842, 0.115749470357384, 0.29119753731148584, 0.14807878700750216, 0.18020128618393624, 0.06058719927178962, 0.034088323691061566, 0.13122366501816682, 0.04720529108973486, 0.07329894216465098, 0.10091659306947674, 0.1080964570865035, 0.1142605473952634, 0.0826696464791894, 0.061586979909666946, 0.05044711088495595, 0.09312723497194902, 0.08234836693320956, 0.025536787563136647, 0.015001508507079311, 0.062030755382563384, 0.020085915590503385, 0.05182830284216574, 0.03940322403130787, 0.048348815978637764, 0.044118482619524, 0.02890222965340529, 0.015441321335466844, 0.015758473692195754, 0.11577488827918257, 0.007604760949366859, 0.007985541231131979, 0.019006965182987706, 0.02054694451258651, 0.014267396381390946, 0.04216334503144026, 0.048180223775229285, 0.054424235331160684, 0.0686808531837804, 0.01548128535172769, 0.07746157808495419, 0.04571354202926159, 0.051064594715301476, 0.061941127691950114, 0.021407155586140494, 0.035876131150871515, 0.04547221765720418, 0.047620171148862155, 0.07904722621398312, 0.020331530000216196, 0.026235649794606224, 0.029620757526052848, 0.08945202468229191, 0.04689626588619181, 0.012267816445923277, 0.067884829826653, 0.03913004583280001, 0.014276429378826703, 0.04089270678481885, 0.04132953066644924, 0.08716192828225237, 0.014463708436648761, 0.01888137004737343, 0.024334620285247053, 0.03497288908277239, 0.047119480158601484, 0.05674619573567595, 0.04976105769830091, 0.03653397763680134, 0.006058359709900937, 0.011069046932139566, 0.03942504232483251, 0.06110774419669594, 0.03965440073183604, 0.06314508630228893, 0.07101116635437522, 0.02944424342630165, 0.01856846531986126, 0.061138033999928405, 0.05561308975198439, 0.0035877399163187613, 0.0497479585797659, 0.033881957443164926, 0.022044956451281905, 0.02517901131484125, 0.045982608305556436, 0.027415050526282618, 0.15727315364139421, 0.05676438047417572, 0.18035544934017317, 0.09555917911763702, 0.17541842854448728, 0.15938407608440944, 0.14155676269105502, 0.12478883245161601, 0.07949540537915059, 0.15200640553874628, 0.10670304471360785, 0.12420913284378392, 0.1262156016060284, 0.11344057175197772, 0.21143651939928532, 0.18537378577249392, 0.15674658332552227, 0.17926223443022796, 0.1345927542341607, 0.1042229924350977, 0.07220424804836512, 0.14016738081617014, 0.158135449513793, 0.1465689923082079, 0.09808060167623417, 0.05248191187690411, 0.1678752904491765, 0.1769621092826128, 0.21937964031738894, 0.11693123408726283, 0.18097462611539022, 0.14719555154442787, 0.1826010609843901, 0.16323819570243359, 0.13339363357850484, 0.1639982092061213, 0.17473370528646878, 0.11468562244304589, 0.16200138921184198, 0.08162556428994451, 0.09790726990572043, 0.1545420094792332, 0.16401350338544163, 0.12828845823449747, 0.15363813298089163, 0.09694776710655008, 0.14478403808815138, 0.12932240989591393, 0.1513443317796503, 0.17691105630780968, 0.18550098394708975, 0.08850893564522266, 0.1600092646798917, 0.07694044961993184, 0.19009592809847423, 0.07633505389094353, 0.10140927056116716, 0.14149716017501696, 0.15396343623953207, 0.15831418920840534, 0.13818510861269065, 0.16809118672141007, 0.24194124181355747, 0.10700282148484673, 0.13800320694489138, 0.12413875519164971, 0.16267737293882029, 0.3118345285100596, 0.1595685426145792, 0.23615673077957972, 0.16406243933098658, 0.08657954167574644, 0.22387835463242872, 0.17739135053540978, 0.2520967668720654, 0.12606080062687397, 0.297455475798675, 0.14725584616618498, 0.12698971506740364, 0.18851405940949917, 0.2517037051064627, 0.47136454390627996, 0.2079219658459936, 0.10864514085863318, 0.1676860741738762, 0.16090729220637254, 0.1485618632286787, 0.16660493718726294, 0.09614408987441234, 0.23393387719988823, 0.11727252363094262, 0.22285515096570763, 0.17704487698418753, 0.1760638239128249, 0.14121290828500474, 0.1094588196969458, 0.16017161096845353, 0.08313173561223916, 0.1979711548026119, 0.3098693553890501, 0.27469220012426376, 0.3140554279088974, 0.32190485671162605, 0.2476066563810621, 0.14857396829341138, 0.2676830690886293, 0.13713009522429534, 0.0945632118465645, 0.14785529114305973, 0.17106489358203752, 0.21152987224715097, 0.2085389034556491, 0.32317526425634113, 0.16644554931138242, 0.09138705049242292, 0.15609767314578804, 0.1761713038597788, 0.1846915730940444, 0.16597293610019342, 0.10701067213501249, 0.08644497461084809, 0.10005328617990017, 0.08310213112937552, 0.14240825628595694, 0.10453585136149611, 0.15186547381537302, 0.12927274113254889, 0.15981992626828806, 0.08293924879814897, 0.20541678741574287, 0.15542419999837875, 0.14802352711558342, 0.14225756722901547, 0.073475049143391, 0.09915299913180725, 0.09823569442544665, 0.20923392687525066, 0.21193058788776398, 0.14143069088459015, 0.1374444876398359, 0.09213359507599048, 0.1868307361645358, 0.16922049969434738, 0.15512601099908352, 0.11511782210852418, 0.10139508239392724, 0.11868222084428583, 0.13708269276789256, 0.13183779349284513, 0.11654661329729216, 0.17409356177917548, 0.08426877709903888, 0.1091018288529345, 0.08430156391113997, 0.12213021011224814, 0.17607708248708928, 0.1198644188365766, 0.15202254110148974, 0.14559704517679556, 0.16603548345821245, 0.15585322411996977, 0.14485357435686247, 0.13236306102148124, 0.13796059494572027, 0.13144340179860592, 0.15649662459535257, 0.09524587914347649, 0.1528849591101919, 0.12074251100420952, 0.0661915321169155, 0.16897854767739773, 0.14866584193493637, 0.13631560892931052, 0.13104800587253912, 0.1490394975990057, 0.12201799399086408], [0.009782342672614115, 0.0434819082064288, 0.031012863719037602, 0.03164217441475817, 0.029113121729876314, 0.03102901963783162, 0.021548365508871417, 0.03009706536041839, 0.02761718101932534, 0.0588769381865859, 0.06764823823635067, 0.03899021672883204, 0.0094412829826719, 0.018822274736261795, 0.01526907182830785, 0.042240280724529705, 0.0488136294297874, 0.07682104102735009, 0.019501501860629235, 0.02533469608585749, 0.03427016429070916, 0.04516612372494169, 0.05608899385801383, 0.013028385500157518, 0.024334281017737727, 0.03276514308527112, 0.0257608924127583, 0.015084805465968592, 0.08770044081445251, 0.019369598045679073, 0.07721868290432862, 0.04232722480914422, 0.011389774320247983, 0.04601464533646192, 0.028802600356617143, 0.025609738559329083, 0.06779856088438205, 0.046324505138077905, 0.031030071367110525, 0.02768702941414501, 0.04243385658732482, 0.0436778012663126, 0.05519703921994992, 0.04242243684296097, 0.017467236911345805, 0.015738324594816992, 0.04451663679044161, 0.03437179865847741, 0.07631040271371603, 0.04455767119569438, 0.015068284834602048, 0.06687056246612753, 0.014146086194419434, 0.08737093063869647, 0.019507756257163625, 0.015375876632918204, 0.008914023953756052, 0.023517499578052332, 0.04380097572824784, 0.025705189776739905, 0.03217725355976394, 0.020683111223791326, 0.031922151534152884, 0.020003963827288578, 0.027647401272718395, 0.055651101283729076, 0.03950281261599489, 0.049843513273767064, 0.026386956318414638, 0.007498543077547635, 0.044833824770259004, 0.04093467417572226, 0.04595715306433184, 0.1770823321172169, 0.041647756804845164, 0.09319302572735719, 0.029412481202078716, 0.030878717345850806, 0.07690720818936825, 0.03482469703469958, 0.07864055982125656, 0.12643995242459433, 0.023735105758532882, 0.07802782234336648, 0.19186737947165966, 0.09202751291117497, 0.08818700470562492, 0.04267210380307265, 0.06531095651111432, 0.04632636771670409, 0.049075231820877106, 0.04808428231626749, 0.044190006995839734, 0.014610119330297624, 0.007719658980412143, 0.014435822343719857, 0.022286623483523726, 0.05028384518144386, 0.016887908801436424, 0.028530538348214965, 0.08703992090054921, 0.0927408839176808, 0.10375804666961942, 0.12630082560437067, 0.021076580110405172, 0.02871940517798066, 0.002753138026621725, 0.008862445962482264, 0.018337076396814415, 0.0488302467523941, 0.05693104224545615, 0.07573359366506338, 0.09190872857081038, 0.033304714132100344, 0.03714703402615019, 0.08233877244804587, 0.03227129512067352, 0.019725693223465766, 0.01623271029841687, 0.009737680649517902, 0.06913342247051851, 0.04742981493473053, 0.0613229347925101, 0.03422821725585631, 0.07016848014401537, 0.025933182632018412, 0.016351530261869942, 0.04815555224195123, 0.021499429563326494, 0.006878799725590008, 0.07367244176566601, 0.07564955031765358, 0.03336853713595441, 0.01623537015568997, 0.052357773895242384, 0.02611895534209907, 0.029329638861651932, 0.03616578417963215, 0.018478288015882884, 0.021989623616848673, 0.03590158299942102, 0.11245706238384758, 0.03839661393846784, 0.024149315764329264, 0.02259402529203466, 0.046121171941714625, 0.05620423624558108, 0.00926917087885418, 0.021536133218822733, 0.029284645204565356, 0.014629364279764039, 0.039628019290311, 0.015159340841429574, 0.036342773253896406, 0.02635598967650107, 0.029769516150866236, 0.003252083061462534, 0.027038312616891096, 0.03740612244499581, 0.05593103429834757, 0.02745890085186277, 0.05709587197218623, 0.033289939032069275, 0.060517126960413795, 0.029136286915412972, 0.04153506910162313, 0.06431510459099497, 0.01962523441761732, 0.03379779874480196, 0.04665367943899972, 0.05365841696038842, 0.03781777946278453, 0.06188667525670358, 0.02345550522607352, 0.011702917383185454, 0.029100996309093068, 0.01680493075400591, 0.03775350523314305, 0.03134593620364155, 0.058930087834596634, 0.043474033807537386, 0.01831100368872285, 0.006541331182233989, 0.07972619549504348, 0.03525715793616005, 0.019987648452765176, 0.03139975081597056, 0.06932794488966465, 0.033751661756208966, 0.04911693797579833, 0.0056266909980747315, 0.021229842511404837, 0.03699111685689006, 0.04037114066470947, 0.04631132459534066, 0.052762479321765046, 0.03270273143425584, 0.04732391258169498, 0.007164107585724975, 0.019827836492498006, 0.05292006568717105, 0.028562819651727165, 0.04376298455255372, 0.06685368051486355, 0.05797903958175864, 0.0756761556757348, 0.012553461877230023, 0.06800482195935079, 0.017434784277741398, 0.06729546788015536, 0.028887122071215084, 0.023914795402171354, 0.03858775046787091, 0.01417368306179664, 0.029739782746349062, 0.058116646483540535, 0.0512101235134261, 0.055477545596659184, 0.039685165509581566, 0.0946888222492167, 0.03207498476175325, 0.06803034844675235, 0.02523466814974589, 0.006043641437177679, 0.029724132336143936, 0.01895372223641191, 0.019102117844990323, 0.028110087516584566, 0.03215865491490279, 0.061809505469032695, 0.01921888184733689, 0.03434788369174514, 0.03351554174774459, 0.021058488670470457, 0.013701252206893904, 0.040599569478737454, 0.04766044220221894, 0.009955207102133759, 0.03639663875635181, 0.01897845653417919, 0.052614277095666954, 0.03403849207929202, 0.05305390671959945, 0.08677403695349183, 0.037015530546861034, 0.008197069434182984, 0.06018499763948577, 0.05391984971772347, 0.02365229225584439, 0.027353412405188595, 0.027894455873008286, 0.041843792357082875, 0.03544402987297092, 0.012715343369304069, 0.076232900443886, 0.07529083599469491, 0.11696535082800047, 0.008159335253627172, 0.03661524916865996, 0.09462471426065479, 0.0793028235701578, 0.23648454461778912, 0.11612863572580473, 0.08076383838696138, 0.04872556576239211, 0.04474041424691677, 0.029812942392059734, 0.029346310467060124, 0.04012304451316595, 0.02437398549435394, 0.05551416952429073, 0.02685169343437467, 0.14114042717431272, 0.06416378449648619, 0.05316945444792509, 0.03006215812638402, 0.07771504484117031, 0.015626775134088736, 0.04465446760877967, 0.06917192933282681, 0.011271159613638051, 0.01901777763850987, 0.05705245251634291, 0.04934729043660419, 0.04091706619198833, 0.044988313623304875, 0.04675489650773151, 0.042450256778725555, 0.02683069447188505, 0.05112996817167316, 0.021042923077142665, 0.07684132243905749, 0.05909339085753475, 0.059154506506664414, 0.044704692770860026, 0.00390512085453208, 0.08196831268391438, 0.006824092839711479, 0.09620311563568455, 0.029578003034527813, 0.03186374663242272, 0.05026732963908996, 0.03532644993226443, 0.03207826208589332, 0.05881415334131036, 0.014711241404126798, 0.04291860878999744, 0.052397139104349275, 0.05439509903745992, 0.04123936354049614, 0.019193445265825306, 0.012276029264155244, 0.0650881120402898, 0.023964219892929708, 0.025451633114633814, 0.071571643065129, 0.03210053839055555, 0.010322082505029227, 0.018119585567287037, 0.05516157897987536, 0.053586210656378946, 0.039155250016067705, 0.04061296715268067, 0.007214517648597913, 0.0584094479147877, 0.04122518555128148, 0.016393920040822456, 0.019793253258935044, 0.04992364486679435, 0.03994870172547443, 0.0153850164996194, 0.03229408711194992, 0.03153078949877194, 0.040534670996878824, 0.01692360992144261, 0.020245844598061273, 0.0548950300684997, 0.055892351016934426, 0.03204585186072758, 0.05555702240339347, 0.018548099091276526, 0.0746636050088065, 0.024467021127098372, 0.07747993245720863, 0.02029972706389214, 0.031575250505868874, 0.07489752995648555, 0.07678782673818724, 0.024094868418095366, 0.03336194177557315, 0.03637182812339493, 0.04632163493494902, 0.1316718373979841, 0.1261454682265009, 0.1608890396143709, 0.133645465065326, 0.18434052621679647, 0.13196404171841486, 0.12817314799342835, 0.1712567832853113, 0.08483482458229576, 0.18854945179607185, 0.14635737080659184, 0.11789820077163832, 0.11711817048490047, 0.10719595290720463, 0.15424276196530887, 0.0912339458508151, 0.19600903508918627, 0.16533568315207958, 0.16072480699845723, 0.08981933604393687, 0.08006017043122224, 0.14794982464185782, 0.13587012354816708, 0.13344900203602655, 0.09022157160299164, 0.14022948034107685, 0.12212168771241393, 0.12315160887581961, 0.18995069446308271, 0.16718938654022558, 0.17445447455559457, 0.10660899976002318, 0.13095751644245215, 0.17780945024320058, 0.09946621089641537, 0.12747988876487526, 0.10831079951354436, 0.16254514003438608, 0.19702402848218167, 0.08788701080318008, 0.08710781511451517, 0.16619225218892097, 0.16251297747450216, 0.14618479220994882, 0.09950373388294663, 0.16874984066401208, 0.12786144257656165, 0.1109219922551087, 0.12803600249545916, 0.09076900687068701, 0.07804860587098769, 0.13254208570080145, 0.0960766299228583, 0.1821361423603126, 0.1358195591185774, 0.17422158776649407, 0.23094411620071956, 0.09816381042557103, 0.09563879841672522, 0.14689653473240988, 0.15372335697923387, 0.10469242331704923, 0.1124039330918874, 0.0835927255185587, 0.27477036735841204, 0.17739216477743217, 0.14695239173514502, 0.25111156116638866, 0.3159202592713492, 0.09447257313877344, 0.12917805835604668, 0.13159406371414661, 0.28917824423738886, 0.20820606845830167, 0.2639114728995732, 0.2538158489125115, 0.1671078944844859, 0.08201993562813316, 0.11023035472525017, 0.1718560925551823, 0.13011747651866504, 0.42483720768775257, 0.09296590648591518, 0.1483019571751356, 0.2779611647129059, 0.31722728056567057, 0.2692508649613176, 0.12114127246396882, 0.18582364091915743, 0.15652285675917352, 0.1540910822472402, 0.14138018073780195, 0.1003742196730205, 0.09031838497945241, 0.08392965208206858, 0.13450520964605467, 0.13458575175276824, 0.14406260608562402, 0.17013562630329812, 0.1908274974141802, 0.17465462881539548, 0.40448862101350513, 0.27707659932119505, 0.28622246427195414, 0.13017988816968032, 0.07655639201402664, 0.13375853614083358, 0.13761184151683534, 0.13578367818679127, 0.12172440545899527, 0.15761250257492065, 0.24732826703361102, 0.2019028581146683, 0.17711617744394711, 0.1422049400529691, 0.2934295375432287, 0.24387672224215098, 0.09762364905327559, 0.12975169186081204, 0.07143410401684896, 0.12522628397813865, 0.12614690672074044, 0.20979545531528337, 0.12822470308414527, 0.1702784307833229, 0.10815545570637498, 0.15286465734243393, 0.1974510034280164, 0.13433115184307098, 0.08828879852912255, 0.1526607982814312, 0.17292642726429872, 0.12476179961647306, 0.1192534930471863, 0.10680532708231892, 0.09172470987375293, 0.13465196319988795, 0.18648446617381914, 0.10721161349543504, 0.1215660489563431, 0.20749667366700514, 0.28930027197514263, 0.2201440100158964, 0.11630042722182614, 0.08291502509798322, 0.19738077505358628, 0.14926082215138844, 0.08923634554126433, 0.10728756870542254, 0.10876101428376776, 0.15170775513563836, 0.1273919099143573, 0.12213135005107947, 0.10757042281329632, 0.10314898685153041, 0.16688184732837336, 0.06548975048852818, 0.19925150967070035, 0.1281626442713397, 0.13564669553722652, 0.12479279509612493, 0.13785284358475888, 0.12005837128630706, 0.10986031565283026, 0.1674437421773161, 0.14648574963212013, 0.09597567069743361, 0.10465400466429335, 0.16227838077715465, 0.10345838524933372, 0.23035905616624014, 0.15745551671300614, 0.13271623849868774, 0.13505805283784866, 0.09595209839088575, 0.14104817355317728], [0.038919482845813036, 0.01916132850705513, 0.025489590363577008, 0.018392273524243916, 0.0675275404272335, 0.022271415817418268, 0.07154241856187582, 0.04078865683238421, 0.0849065457337669, 0.045190245644854646, 0.03565617045387626, 0.0839033384940454, 0.05327764007129839, 0.022450236936232874, 0.011352116474881768, 0.038694728298911026, 0.011390034708061388, 0.031735259241291454, 0.028792751420821463, 0.029397163274032728, 0.05510643783158489, 0.03662796152223434, 0.013100232180607106, 0.05480219290724822, 0.08123985105859381, 0.04575429144980652, 0.04727809450456074, 0.028707272971847227, 0.03610943863168359, 0.039355346600392034, 0.03918605211323925, 0.06545212572174412, 0.03133877765919481, 0.0347497324858393, 0.025604320457205176, 0.12056347275418894, 0.042035207085843594, 0.026693150334592377, 0.02724404613088284, 0.016412834204467278, 0.016592357607026185, 0.04184851496081267, 0.06129128113389015, 0.01783547956230385, 0.04643990698137453, 0.016775629915563122, 0.04168005846440792, 0.005544251537815268, 0.04987930599600077, 0.009252527263015509, 0.025455794230635678, 0.03662902003686343, 0.02261588429766042, 0.014015688727210675, 0.04165057611784764, 0.06941679905035666, 0.07929318158754281, 0.07765848894736596, 0.046984716318547726, 0.034032646500106366, 0.014684181427583098, 0.07207867835781404, 0.06300866683678967, 0.07250167708843946, 0.05854208794023309, 0.031460690045995374, 0.04060404780986054, 0.01999760595416384, 0.04066638142934867, 0.04539570604850139, 0.03026927076280117, 0.10531293680625302, 0.06775748915970325, 0.02683074027299881, 0.046354442103100676, 0.08179270103573799, 0.0385084873996675, 0.10996498646480696, 0.04343299600960953, 0.026586956211498806, 0.019692176986219626, 0.07710650749504566, 0.0855865463880556, 0.04086610142673765, 0.11793693155050278, 0.06316124900643315, 0.015594870417511888, 0.07852893402533871, 0.06378982349165849, 0.030396289125617062, 0.04915927177561181, 0.044324716553092, 0.0071495004231110215, 0.045048255406852276, 0.028373208129778504, 0.09188189929617302, 0.03690178093633481, 0.03997874047074999, 0.020836914756468365, 0.02599874438185777, 0.060545788279601505, 0.1112428375386766, 0.10431879479438066, 0.03882899680840118, 0.08576146593051297, 0.06338770328355686, 0.028355842722313743, 0.034123380202800035, 0.047783134904290946, 0.01580249874054321, 0.03708747900756342, 0.018867170005770664, 0.02432627260818013, 0.031073847053838626, 0.05471564576561962, 0.08531982784292527, 0.018598638075803007, 0.06491142830678395, 0.0144037462970508, 0.026872556689860563, 0.0327047093638352, 0.09462689235806465, 0.04908249553825174, 0.040772314316460063, 0.031336080482495685, 0.008626454875671437, 0.016004111850634217, 0.036137774254062345, 0.03247841793511595, 0.03400395803951791, 0.04754707596397825, 0.07415722789508955, 0.06352620585156338, 0.010815569149729396, 0.011026173696986266, 0.04054364801517554, 0.027488383198423044, 0.0853450150628175, 0.041638399806938, 0.05628394036154662, 0.011648090057341116, 0.026464746965627586, 0.042922588397881815, 0.013724802461053644, 0.026256499479391744, 0.03768553298764995, 0.008677189787184554, 0.00912315777636, 0.015497760181980473, 0.07051274167107684, 0.04763028132064002, 0.029039185161569288, 0.023656410963407586, 0.05168408022395202, 0.050428424030542374, 0.03436920326203108, 0.015749313469444002, 0.05264355927439673, 0.03251902486330696, 0.03245051996782422, 0.03148476107578192, 0.026112103834748268, 0.029421760168458735, 0.021004964131861925, 0.03863971267959901, 0.0458884954984699, 0.026222240246300186, 0.028856024811310426, 0.03767719379227076, 0.011899964800769729, 0.03344273154756852, 0.0034639030345715582, 0.022774753094251667, 0.00948760487205748, 0.04031732265970536, 0.021419767855799625, 0.07733841040836913, 0.03636944307280438, 0.04523983976936766, 0.04360487571518336, 0.02714593505619892, 0.021200144729976143, 0.024917451332190206, 0.03464338908504162, 0.10041795125497238, 0.03297522770506995, 0.026771940124620284, 0.019673809043264816, 0.09387749114206859, 0.026992642121123414, 0.04249899934179016, 0.08008565620652267, 0.019197516475937197, 0.06970913229244095, 0.04006181012040802, 0.009728770636554276, 0.014874378185985344, 0.022610452624836137, 0.05772830732166767, 0.04514249713559236, 0.036988535031144104, 0.05569952154265983, 0.03606124228930899, 0.017394582774224024, 0.046422773972153664, 0.0381711231810706, 0.0302526873669454, 0.022682168687294637, 0.01665471158256488, 0.0321563411104892, 0.07286092066871268, 0.03569236011909587, 0.07050584096993719, 0.05172485000054751, 0.030235357582569122, 0.08598460895674569, 0.013754448504187167, 0.01626560906879604, 0.0415314660806741, 0.009399855875277092, 0.05163696953760726, 0.03366519943145769, 0.05047160599912916, 0.030493675864168575, 0.07079868311328547, 0.009480383563121515, 0.028976953322333947, 0.035578620686594925, 0.028051027828561406, 0.03057870308735541, 0.0649949423968792, 0.059322308216776164, 0.0848413792305759, 0.02870414831808635, 0.02804103640041181, 0.06917491488690887, 0.014899022577862655, 0.030715682344245057, 0.07465620897710323, 0.012115684653898435, 0.012914969219959207, 0.03643263164641602, 0.12155934503035885, 0.03124336206487247, 0.053061309536652904, 0.026359107544911758, 0.04650832027462976, 0.04083543164389474, 0.08865743303405386, 0.04095407349190541, 0.02710278531802552, 0.10475094017705747, 0.032183326448180845, 0.053844508581927845, 0.019774298383189098, 0.050607944040426185, 0.059497499173241, 0.1255358045122453, 0.08886214026382991, 0.051493418669062, 0.08998172304459981, 0.07378084452024528, 0.02662778875258352, 0.07191114127635956, 0.05030713589595897, 0.01951410564860063, 0.06223842102502074, 0.07575681313340153, 0.03674988069438508, 0.06520871485450438, 0.07738742777811629, 0.07880526741168328, 0.032166393606790473, 0.034720284066029956, 0.03946208694417562, 0.021516647389424697, 0.0420725570459451, 0.10366689906056438, 0.03990662916164313, 0.018063986407858983, 0.02788233045222504, 0.04776105537478413, 0.09774754954768078, 0.03650591003575495, 0.025048369575025778, 0.02686461783014238, 0.020176486444792578, 0.006213010139098125, 0.025419041381350586, 0.09336362300174576, 0.023935595893168023, 0.06598562388015644, 0.02560878182495279, 0.03519773183922682, 0.09148805721529893, 0.03386539440335972, 0.011450675382677997, 0.06776120753160544, 0.07808686846068927, 0.039313294392611296, 0.06195670685597828, 0.0740715628489852, 0.0055132628435135955, 0.04553564711074744, 0.040189741112823994, 0.020867487848071114, 0.011611014903922166, 0.052923882446650944, 0.08732044763330903, 0.04984746913292578, 0.035923275763967207, 0.06597797679049627, 0.05957827198186091, 0.033932406521801434, 0.00917892572137394, 0.0716565413666623, 0.010794209715511118, 0.03247289126738906, 0.02207131584041885, 0.01943585699025009, 0.02243627268554909, 0.003213585529010743, 0.08227606224162237, 0.05488192416461451, 0.0207695481034794, 0.08386726078710385, 0.07385293208062649, 0.012245792047386723, 0.024860115123114417, 0.07264683608497892, 0.04320529322805149, 0.019108275550284555, 0.0693591439298221, 0.0013138628356890486, 0.04443243398730244, 0.05914830469659396, 0.010989947560509401, 0.014158901176415384, 0.02849031818498458, 0.050508867749678235, 0.017223541059398224, 0.044468152070684094, 0.05626476835459471, 0.04743194214201399, 0.028334721623520766, 0.014675728577588285, 0.006065986019426158, 0.024930380816970552, 0.030790029426238368, 0.027392117738989846, 0.030725633060293536, 0.05461007250206811, 0.14902364702097007, 0.1816957052797079, 0.09715156509940114, 0.054064035016511164, 0.16206907986530236, 0.13880234477775438, 0.16239800650094235, 0.09790456255099603, 0.20601385752005236, 0.14551454888922827, 0.0672141658142209, 0.14597032086125442, 0.15077563800982066, 0.1075513491939221, 0.1492485949503524, 0.1547750048339367, 0.07126443633543593, 0.15045731009117194, 0.1640231657241072, 0.10217956387038742, 0.20648997197193758, 0.13109293846147402, 0.17561153961079462, 0.1664283416633095, 0.2300073036125728, 0.11211058883262531, 0.09614353347569704, 0.1367837166679757, 0.14600555039942265, 0.09616211176450763, 0.140316156404359, 0.12341315698410783, 0.07391449556286846, 0.1753883965845619, 0.1906908540321248, 0.2128009990389858, 0.1479134008820568, 0.13151969627610274, 0.15416215200509342, 0.2506695363138403, 0.14774739050439425, 0.09337479168815271, 0.15309226512908936, 0.09444756912333624, 0.16878486664167472, 0.14168291592172214, 0.18605203580643448, 0.0516373529098928, 0.18302175269595214, 0.08351503325892345, 0.09655965864658356, 0.14026932391737187, 0.09099711677325623, 0.10017904586025647, 0.15552722875561031, 0.23128674924373627, 0.2917130882186549, 0.21291924055133546, 0.07158135968659605, 0.11831783396857125, 0.11769180398966585, 0.14171248647783483, 0.11111742391117982, 0.15963970736733504, 0.11771560699812003, 0.0933966947985547, 0.1749919964266675, 0.12079532817006111, 0.15750582329928875, 0.1335002721420356, 0.10608106558876378, 0.15375504456460476, 0.2761756676648344, 0.2204498800316027, 0.10499500243791512, 0.20810671736087116, 0.13061386559690746, 0.11496603382485253, 0.17042864486575127, 0.1161103288510016, 0.10237395058252982, 0.31881103558199747, 0.35099910838263376, 0.15774580756468431, 0.22871113887854985, 0.1459732385618346, 0.11136452600892101, 0.16790980074022496, 0.144557013841612, 0.1365311930754355, 0.14729963881628855, 0.1434552493904318, 0.08130807775471892, 0.13008768883134636, 0.14405830417360577, 0.16673445595162256, 0.1222679391503334, 0.11391237750649452, 0.15931662970355578, 0.1312964582549674, 0.1494166273623705, 0.19910219125449657, 0.20802494032042368, 0.1065831407904625, 0.22173532391233103, 0.15821850220007555, 0.16766467317938805, 0.19068223663738795, 0.08269694394298963, 0.13230823539197445, 0.1297464942825692, 0.13891059825462954, 0.20935785451105662, 0.2196414598396846, 0.1818164438009262, 0.1794694454542228, 0.22422423107283457, 0.19864686711558274, 0.20128178144139902, 0.102123041903334, 0.1356324055897338, 0.13664457627705165, 0.14450855287058012, 0.1496672781982592, 0.09589522358562265, 0.1830633876046964, 0.06424650470060961, 0.13804675532238825, 0.12112719964768205, 0.06545943354389497, 0.13262778467365674, 0.11570793044354234, 0.14482141179697855, 0.09915628324129752, 0.13724897455956253, 0.17605169170669147, 0.2097476457378694, 0.12225060936595712, 0.1311935516340392, 0.15655572499547685, 0.17503348205770763, 0.09170469309070281, 0.12415384581046444, 0.16469430471105234, 0.09578342815595013, 0.04435523027288062, 0.13700805391584123, 0.17069821325795992, 0.0938173932954669, 0.13491804392210074, 0.1289799939841032, 0.10154032960001912, 0.06712825649550982, 0.1297974522624697, 0.16282335296273232, 0.10821249336004257, 0.09612537587859801, 0.11627340795738356, 0.1273856945335865, 0.22757429416690553, 0.08828864925141845, 0.13032295049301215, 0.0995251823748861, 0.16541786731353827, 0.09323432136859212, 0.11296995343374354, 0.11882460463259902, 0.18016399389931134, 0.1111988074013165, 0.09044432107891355, 0.09904732408800296, 0.10422412558857884, 0.11677746448133673, 0.14245042045201572, 0.08743503184190818, 0.14266365686697619], [0.035520928246634345, 0.026262940473056266, 0.0209375041803079, 0.049807479671601734, 0.043673845407153876, 0.06354047544300556, 0.015665684028395584, 0.035276913483228, 0.06002173532864877, 0.02993139425026519, 0.027849146697138037, 0.010193550160952976, 0.01831229799427092, 0.02840071763577206, 0.0390367269116853, 0.062133356662733216, 0.04381898404764278, 0.0028373105077272548, 0.050183995360774655, 0.050645623090011735, 0.015539091446303895, 0.052910379599779844, 0.01268360234930047, 0.02778913706008877, 0.010233591360572194, 0.06974099629691669, 0.04994010951902185, 0.03656858292275241, 0.016385243274271488, 0.04260921717754432, 0.04685347407524075, 0.03909373063860195, 0.07665703911334276, 0.05470373069069215, 0.036711034564567466, 0.008233189549563187, 0.04280042156044926, 0.07427971025130578, 0.033437968231737614, 0.05000783409923315, 0.037244756639535935, 0.047816376334854534, 0.03181344683149031, 0.014137101542603756, 0.05088688639391746, 0.009058830960254585, 0.03086254446368132, 0.028127016965299845, 0.03311079900179591, 0.01513631984458438, 0.022439792585958327, 0.03790381770314915, 0.021627587864973714, 0.023148128862625787, 0.03985894511320761, 0.05548260407522321, 0.04728960585115211, 0.02688357270588832, 0.04345682615946446, 0.029362429066428115, 0.015580894292465277, 0.0583782217332295, 0.051529031579515765, 0.06339589320123196, 0.038846353734178204, 0.045953142922371626, 0.06513862897242818, 0.020594362236027206, 0.06815500890037843, 0.04523955139198473, 0.019472475828869, 0.034286079329571555, 0.06175857463053294, 0.05757061578333378, 0.07425556118999209, 0.023648005610864078, 0.051485849610928974, 0.002431667854710083, 0.03820182349798935, 0.01411307801026851, 0.047737058983849626, 0.09677087981253862, 0.02439138482856963, 0.07419991453311273, 0.05660461601135986, 0.06863385784838881, 0.032877267604427676, 0.014842329280717033, 0.073830282581704, 0.04671187060219901, 0.06383088843098708, 0.041423904709517956, 0.035252326766827276, 0.0059277752214776614, 0.06468614110989229, 0.06692059085305248, 0.05152531320761357, 0.1256281259868826, 0.035484168611999066, 0.009434023506141134, 0.06723802310547658, 0.06131507057164397, 0.05611931419532214, 0.03923261997156909, 0.06938517931848764, 0.01870769731301282, 0.05426391786230462, 0.06962653422462088, 0.03127823197948081, 0.06049882687096085, 0.03288338799029589, 0.2066064900053399, 0.05064681052629437, 0.008605745138733514, 0.015338993165642023, 0.008996594880175377, 0.04692282374682171, 0.061976771136479716, 0.0032647371034337474, 0.021193688469273702, 0.012631427247210272, 0.0421048858469086, 0.03313195911635246, 0.020737185375764966, 0.07700345838176352, 0.0034873964614234865, 0.04216029162385634, 0.034749769805265326, 0.06020575402570622, 0.004991063141330544, 0.037572031042405536, 0.08406191891325371, 0.06572581282151596, 0.07303000481000968, 0.0006861108621316296, 0.019516010635665486, 0.0972722221964172, 0.052372593100049665, 0.054161655849644115, 0.04600066751507776, 0.04455475688778928, 0.03886010763900621, 0.018539815875036374, 0.008609626359040183, 0.02139138473596956, 0.04199673415028623, 0.005752072395158133, 0.07557399544332709, 0.009009898407384753, 0.017108581960201263, 0.0520276801793703, 0.01301579613105527, 0.020537205838731358, 0.02460422090786908, 0.02696406901148813, 0.03915578266605735, 0.025154697708785534, 0.10652544495782681, 0.020752715346004282, 0.0379442041074591, 0.06998074986040592, 0.05213338236457535, 0.04348340437614492, 0.04450173955410719, 0.03215254809973495, 0.019977322846118892, 0.03475972730666399, 0.04525576837893043, 0.034635606288377724, 0.012075378825621945, 0.029402879931564842, 0.030349775550088713, 0.016091317171230912, 0.04297031315841845, 0.020219547973413552, 0.055227729358843396, 0.0067499408365360326, 0.006174925240754549, 0.034028324232037575, 0.02948664507961699, 0.05736769310065678, 0.043913415766188076, 0.0121632813409503, 0.05955682348992143, 0.07062382463897977, 0.056228639757526774, 0.047661178412714174, 0.024572769113417183, 0.0077736237186140245, 0.015221884806773492, 0.06399646454623767, 0.04196520262796964, 0.06163712364754506, 0.041197335081441064, 0.027215464539559822, 0.044688672559069734, 0.04526981405381646, 0.04571481428242155, 0.05580618046224117, 0.034752663757119856, 0.036263320195887766, 0.05099941464141011, 0.016916349596743072, 0.032184856544647894, 0.04923687582569463, 0.023570976619209563, 0.017390587899301733, 0.014619880056540881, 0.024761345869462405, 0.06819871334092957, 0.041540005443883796, 0.06466512688036476, 0.04110352422243782, 0.0511822594728853, 0.04346666152455977, 0.03412850314219083, 0.01893864349196, 0.06789664312132768, 0.008859030386832143, 0.05329344654455781, 0.01957253599539399, 0.00910939454167549, 0.029890963741179024, 0.017951115500181913, 0.030179615930787156, 0.010198830011566835, 0.06744497628616435, 0.04903909983113408, 0.03137836339218276, 0.025604817484106337, 0.10869682487100363, 0.039191487178738625, 0.012362092101414288, 0.03167327846001301, 0.009031895664520562, 0.06137786898761988, 0.03292421204969287, 0.04537201499832528, 0.032883292995393276, 0.035206135495432785, 0.033609522240502496, 0.03517784058515515, 0.007931311864272823, 0.035229107298489125, 0.0377491660016988, 0.0458809162623116, 0.15179521829954215, 0.03769406217283436, 0.07445296738296747, 0.06094329444957631, 0.0693425808900169, 0.08498043819729771, 0.05225660093128681, 0.015450086311570235, 0.015848985174670815, 0.02322856240373637, 0.06186695024371147, 0.020107910303132873, 0.01529098002772246, 0.05935195341174092, 0.06587357060717684, 0.04132112022489309, 0.02751819972348, 0.04389957704448274, 0.05076109957216041, 0.06159255746752024, 0.037896028121135066, 0.05097467525463019, 0.05275221987228308, 0.038277137492384226, 0.10848371059234653, 0.023580075773809637, 0.04058899790314691, 0.04740658189569201, 0.04777154213349734, 0.07738053386232682, 0.0642785926216415, 0.06966704955058438, 0.06567531624542815, 0.025777623389980624, 0.05593065092606204, 0.029556680071566786, 0.020023922934862118, 0.011871046486443706, 0.0170342874646719, 0.04130825520093952, 0.007002851618121245, 0.09357172290661506, 0.0217035532529865, 0.01572982594370842, 0.029197266857538904, 0.06766469949590308, 0.039671710160161765, 0.03501540269436581, 0.014897134554173266, 0.02450628116327737, 0.06097114831209183, 0.05191247511122908, 0.04139914157401238, 0.05751942710152694, 0.0094435043366892, 0.05173212389594742, 0.018806525938478962, 0.038009937187390666, 0.06935486915920462, 0.04242907291544335, 0.011796150639254068, 0.059630946655358584, 0.08403196159218039, 0.021658077836036682, 0.024846113553004603, 0.04942796825032149, 0.07247741946152278, 0.03101804433390498, 0.043012229659195454, 0.005291615562912608, 0.016864579071157744, 0.056337643015597544, 0.012419585221713143, 0.017720191373622844, 0.037211511816297255, 0.04542222658970526, 0.022661741390558224, 0.047270355812673054, 0.04616847940321479, 0.049376084070120535, 0.03285771222519023, 0.015283751933436309, 0.04627755730013762, 0.0379984733382506, 0.030127022681491714, 0.056270471441426446, 0.028757335285523107, 0.06221876386553049, 0.040057311433234384, 0.02115829099368836, 0.07257105050874607, 0.05931305978447199, 0.04073058780548828, 0.03364301133634789, 0.022023007539766173, 0.047558960504829884, 0.011043534863607159, 0.025428284724642123, 0.04913584874676807, 0.013400945330171712, 0.056594879033842256, 0.029486522943313633, 0.0416839328993644, 0.024570272104548554, 0.03545657598546573, 0.029483910583491837, 0.12390942392604691, 0.10202464754027979, 0.15344363770314626, 0.16924656900976384, 0.10190878090049539, 0.10584860627672502, 0.19684059332524026, 0.1550076473504305, 0.08855648059397936, 0.12318032447780881, 0.08742209896445274, 0.11473497908030238, 0.15768157743981906, 0.11158731619694404, 0.15910890299294675, 0.14202364906668663, 0.1006061090156436, 0.11562665551900864, 0.12206568143197469, 0.09908954932221345, 0.13604731618293694, 0.18718775414994784, 0.1610208246856928, 0.11889315024018288, 0.057635022327303886, 0.15862702099340303, 0.11961307589496885, 0.09634258850876774, 0.1334603607122387, 0.09596249354737145, 0.15544702591640608, 0.09637677988835744, 0.1805185827293566, 0.18137234263122082, 0.12446141216371741, 0.11505819245108537, 0.09700746461749077, 0.15674665117902414, 0.12384998425841331, 0.1662050493593727, 0.09669622738978692, 0.11789563590926783, 0.1245246244860547, 0.12321179493197373, 0.22316973337105342, 0.17671193342123712, 0.10562549717724323, 0.128641527146101, 0.10912885490272727, 0.09624462840812546, 0.111149158994002, 0.15155896597674914, 0.18258628249168396, 0.12409845021154199, 0.19938740666423524, 0.14301726860659464, 0.07346955979509012, 0.1115891889535955, 0.11569418332406453, 0.11961034818419389, 0.10516498903078692, 0.18169687235993998, 0.12180109348680292, 0.09015609975904226, 0.22328964407954896, 0.11376045351581913, 0.12896265062902654, 0.10624069095190082, 0.11877709361059324, 0.11245716416410037, 0.16104664972850255, 0.16598105137901648, 0.24094949503030094, 0.15435322746634483, 0.18144429448459828, 0.2195268552750349, 0.08656435606202909, 0.08281444585216896, 0.09377775327967745, 0.11157512292265892, 0.1276032735726663, 0.1411021306578602, 0.11623648208166872, 0.2217747060848134, 0.20265262573957443, 0.13714772356407984, 0.1224606702370303, 0.12104964309505054, 0.1762882697262934, 0.0995687103963324, 0.19685871021023818, 0.13340542651712894, 0.1033386577452932, 0.10278818942606449, 0.18330353471849645, 0.09646430412041289, 0.10102528080876384, 0.1635213890778167, 0.15295833588710853, 0.11638943744557244, 0.23569000725235256, 0.27078063573156086, 0.30753397356186596, 0.11729192973247596, 0.14918821890439304, 0.0870377631591899, 0.17111727648547717, 0.16897135520620005, 0.05783451162278652, 0.18777415768376418, 0.1335501308952059, 0.305360951593944, 0.17499251211328165, 0.13749661269996846, 0.09894574739571128, 0.11810754239559174, 0.160570888114827, 0.2044685347271817, 0.08498653822711535, 0.09822185231106621, 0.18471082991787366, 0.11245593601571661, 0.19427539168723992, 0.09596611692437104, 0.21464783565274306, 0.13606775365769863, 0.17646458026553902, 0.19186975434422493, 0.1452968477138451, 0.20290869128491196, 0.14283049505736145, 0.2260538600385189, 0.1353619551020009, 0.2812607448015894, 0.09249844335551773, 0.12469083842422281, 0.20711984245904855, 0.11093261132815055, 0.11457894316741399, 0.06072659072067056, 0.1270277944526502, 0.08903692409928356, 0.10501391999423504, 0.12233305137072291, 0.0847802364400455, 0.1809148471802473, 0.10983491130173206, 0.2439145573547908, 0.09509596361645631, 0.12153639697602817, 0.11147469295454876, 0.07807464125965323, 0.08649056537875108, 0.14132204385740416, 0.09217767271080188, 0.13039691081004484, 0.12632774987391063, 0.20663084941250937, 0.10987366243664708, 0.1118450237970267, 0.15078631815101418, 0.10386091257844653, 0.12358591199985572, 0.1636175782020603, 0.0894850150548986, 0.08447666665805237, 0.10537824580179793, 0.11625856161117554, 0.12871400825679302, 0.07430760482592241, 0.15341642844889844, 0.1380495780280658, 0.10157578984009367, 0.08166394901594945, 0.11157417297363281, 0.1538067760744265], [0.05887373550129788, 0.04265171043308718, 0.024121768938909684, 0.06317349656351975, 0.011800447462259658, 0.04680240074438708, 0.017664410706077303, 0.02879095669569714, 0.038914543110877275, 0.02689962005907936, 0.015949255687051585, 0.06847592882279839, 0.041398235729762485, 0.021636824422915066, 0.0673411807843617, 0.03453654017565506, 0.02030075334810785, 0.04524969209783843, 0.008774145655999226, 0.06114038173109293, 0.04095732706731983, 0.039604104323578734, 0.026509759282427173, 0.10016002652368375, 0.028620915820023844, 0.07888165688408272, 0.03359454697264092, 0.02064584268789206, 0.08957249178950276, 0.016194250933559876, 0.0014133618325493963, 0.05435393571055361, 0.04332490538113883, 0.00873036148758339, 0.006193277916671442, 0.011685917536461992, 0.0113226561807096, 0.0572967454791069, 0.0681332889944315, 0.01608908479101956, 0.026965717851583446, 0.03917038134698357, 0.03275565716571041, 0.03264007890330894, 0.02935386256181768, 0.0224418655104403, 0.02635369453180049, 0.006233355587547911, 0.09669550135731697, 0.03960841302094715, 0.024142603356657282, 0.021301042887249162, 0.07018116196351391, 0.014304581796750426, 0.02305172599985131, 0.01924971108590918, 0.05194162158295512, 0.0190652547337647, 0.01458474381693772, 0.023956649138459137, 0.029826452024281025, 0.02810816217346915, 0.053656347428581545, 0.01982288488319942, 0.04999082661899073, 0.06681215417172227, 0.02972824765103204, 0.04654157188321863, 0.05288474115410021, 0.03943705239466258, 0.059706827226494036, 0.050720170339835544, 0.12089018736566816, 0.09249359861548458, 0.06554247944482736, 0.024932017782703042, 0.05234723285372768, 0.05514532467350364, 0.03196595096960664, 0.0347546518647245, 0.08165179645376545, 0.061470258315759044, 0.04008308558591774, 0.04610662415091481, 0.008463771864106613, 0.006846525631512382, 0.07088988500514201, 0.05568501107128603, 0.026055203584421958, 0.01944978052883276, 0.046648817735591104, 0.04668714817879455, 0.031526334916374514, 0.07220424804836512, 0.05153623083606362, 0.03622530527146799, 0.04544850964365261, 0.021621075625132238, 0.05000650756327169, 0.030315835228455917, 0.10709325663213219, 0.03248114903856601, 0.09918090727712427, 0.03438364587990301, 0.08318440350038664, 0.10609156252550227, 0.011820228454390807, 0.006452745042874345, 0.04898191289976239, 0.09255887368427855, 0.07036720269492694, 0.08289603968816144, 0.023114090153415288, 0.027182141684794, 0.07731747760304383, 0.04608813067898154, 0.02888468952317323, 0.033670393617025444, 0.050471039422388585, 0.009520464626673077, 0.027155134294714247, 0.017473565946732248, 0.10077992933137075, 0.02960484248719045, 0.0784668887832335, 0.0035877004764708026, 0.032766551045434814, 0.07767355242477995, 0.02753757529093751, 0.026437819303412522, 0.023072407747219716, 0.037964570336043835, 0.0665872333837407, 0.013638819351659288, 0.1264091469347477, 0.0406883557859276, 0.06930838272507701, 0.07155717669853143, 0.009499029705433973, 0.045623307049806626, 0.021074033907747695, 0.01899350474455527, 0.0483876553231052, 0.007061061441033546, 0.02909982922886099, 0.03346411218600614, 0.0875275975891522, 0.05996911493795259, 0.016497318599639193, 0.021092108384306942, 0.05956720507570675, 0.048026650944458585, 0.04585369683003851, 0.03548316438017147, 0.06840118819049426, 0.02326200739480555, 0.03321223320173366, 0.02094703250830727, 0.014238212590238877, 0.011162823864391871, 0.01599820181062179, 0.06627043216888394, 0.042848804499953985, 0.03321650457967605, 0.041273731339190683, 0.01609693544118532, 0.048542347736656666, 0.035817855170794895, 0.01994940113010151, 0.021410283632576466, 0.06328396884990589, 0.04616478817271335, 0.04189687075891665, 0.05301869414480669, 0.03332786574693663, 0.04230583060000624, 0.012151875167286821, 0.053850717177348476, 0.031078528945467303, 0.05421431016709123, 0.03598031681030989, 0.09155821773622717, 0.013177112742726291, 0.013964845250094575, 0.03717969191659774, 0.08313727245799132, 0.03941442325179066, 0.016660433329109634, 0.02367353379460318, 0.020973410557157228, 0.1176268139055797, 0.01765533021119024, 0.013549526687711477, 0.025876869314483235, 0.004691282977416579, 0.037707880538489134, 0.028326533402183225, 0.02583191467316023, 0.026879535422527363, 0.03701212430106742, 0.059282166085072925, 0.01211672366064574, 0.03200112283229828, 0.040911315607705286, 0.019901489772434746, 0.0023490971403329498, 0.010005596808956137, 0.042526639465774806, 0.05702421867421695, 0.01625462867585676, 0.019971282188115374, 0.027302756373371397, 0.023670202187661613, 0.02856840399493064, 0.0969324390004788, 0.021632442783032144, 0.02608025848998555, 0.02047403931750783, 0.01881566410884261, 0.013664425566925533, 0.0212794128871922, 0.02542525506578386, 0.02555226325057447, 0.007805067031378192, 0.026028009597212076, 0.04180137034771698, 0.056767474593860764, 0.016983577150053213, 0.024275017769208977, 0.049152567849627564, 0.048351401197058816, 0.08054531618420567, 0.0184885203239641, 0.02965269616938063, 0.01274478670010077, 0.030382491116012846, 0.020993215298014026, 0.10300762765109539, 0.03696270998833435, 0.05113415812541332, 0.06284124510628836, 0.028862979795251573, 0.062257087523383756, 0.057194456325045655, 0.04160080896690488, 0.03507186359326754, 0.030940348681594645, 0.0627551729391728, 0.05251295146133218, 0.0630702506750822, 0.02602636075711676, 0.03929066185706428, 0.0243893169931003, 0.023591787288231508, 0.08795204838471753, 0.045305030021284304, 0.0545486311561295, 0.06669191098106758, 0.03418467905638473, 0.0648243451224906, 0.06183155785713877, 0.020256792760587165, 0.08124648034572601, 0.05830230723534312, 0.01745006488636136, 0.05846062981124435, 0.05767964957548039, 0.008289869276008435, 0.03438773744606546, 0.029308190369712453, 0.016985315896038498, 0.03438987822404929, 0.037701298748808246, 0.0413272915008877, 0.01878120131524546, 0.0664743794394391, 0.03849677927792072, 0.060390926232295375, 0.06915751724903073, 0.015696579424132193, 0.10359182594610111, 0.07516637231622424, 0.03985848370939493, 0.053306104615330696, 0.03355540907276528, 0.03225902720753636, 0.053756034400846274, 0.007944568742199667, 0.040600658527442386, 0.05275829276069999, 0.0811216299022947, 0.07642200136823313, 0.05087977195424693, 0.027201362885534763, 0.023655786711190428, 0.0013544039247790352, 0.027748194257063524, 0.01658437124985669, 0.10970556217112712, 0.07718875951000623, 0.01381211549908455, 0.04684648855722376, 0.013195563806220889, 0.06417429500392505, 0.037093134596943855, 0.033087654172309806, 0.01562482095323503, 0.05732166807034186, 0.058575912910912714, 0.01347907948573785, 0.023935394028999975, 0.020930428756400943, 0.03328695008531213, 0.04635439460564937, 0.02044328811046268, 0.0065222138821679565, 0.08556735063237803, 0.02074816746504179, 0.022488991463822976, 0.03213885187038353, 0.01610924067374851, 0.021617150300049355, 0.04889794758387974, 0.013216640800237656, 0.0333346035996718, 0.014074912959975856, 0.049340878280677965, 0.06891870006386723, 0.02650622750765511, 0.03029955378068345, 0.0553590598117028, 0.009387233427592685, 0.023074575666604296, 0.07000148589057581, 0.00560939302002745, 0.033884444274008274, 0.017049808953223482, 0.034008531365543604, 0.047159554436802864, 0.04188612615689635, 0.05053460119026048, 0.08446242420801095, 0.033572949202997346, 0.026283584900998642, 0.04823236919141241, 0.0662725559834923, 0.046026363636233976, 0.039919891128582616, 0.06349419935473374, 0.03526987028973443, 0.03506685939750501, 0.011907030046651406, 0.09674848815692322, 0.18912465950208052, 0.07844934186765126, 0.09299143297331673, 0.11600298461105142, 0.15489908174744674, 0.12472632580569812, 0.0997397012210318, 0.08753243554383516, 0.17611330268638475, 0.12242508786065237, 0.09734358372432844, 0.1067417822778225, 0.09463915348585163, 0.2076989178146635, 0.11692256240972451, 0.09971102633114372, 0.12842662153499468, 0.07101896272173949, 0.15013759796108517, 0.15455473879618303, 0.059946879345391474, 0.09465712787849562, 0.19681650533207826, 0.08313831061656986, 0.24413627545748437, 0.1582468513931547, 0.10926201061478683, 0.08823929261416197, 0.12008152290114335, 0.09381607015218053, 0.18891408294439316, 0.13738381303846836, 0.22101210057735443, 0.061968126600342135, 0.1954933756164142, 0.17858329229056835, 0.11480218118854932, 0.2873303491090025, 0.06669726462236472, 0.07312936947814055, 0.17096573247441224, 0.05853155707674367, 0.087268051159169, 0.13975456011082443, 0.13041030509131296, 0.059745815848665576, 0.06369150376745633, 0.17687205411493778, 0.0966691809839436, 0.12811339619968617, 0.08550030458718538, 0.13224116899073124, 0.11675044521689415, 0.09055361949971744, 0.15406440225030693, 0.08394228640411582, 0.11556967214814254, 0.09643258939364127, 0.07052371358232838, 0.08901791833341122, 0.229586801890816, 0.11970177399260656, 0.12959495027150425, 0.13890084092106136, 0.112507253619177, 0.18030094940747532, 0.0991900267877749, 0.18103250515248093, 0.16806468314358167, 0.11659066379070282, 0.09368920445974384, 0.13098065448658808, 0.1541515261467014, 0.12994151881762914, 0.07764404972216912, 0.12012596694486481, 0.14999826758035592, 0.2673103633735861, 0.1894486735441855, 0.2359740420111588, 0.16859509396765912, 0.07237882832331316, 0.25414914531367166, 0.11600572589252676, 0.18240273876913957, 0.19389638916722365, 0.1411694549024105, 0.11814697885087558, 0.10269408340432815, 0.1760784259864262, 0.09692048999880042, 0.12116937738444124, 0.17042496720595018, 0.19927923461156233, 0.16189943253993988, 0.16162295666124138, 0.11943710462323257, 0.14546739070543221, 0.1595142598130873, 0.22630003254328454, 0.17290703473346575, 0.35513548499771525, 0.14391422404774598, 0.22794694559914724, 0.20115788094699383, 0.14384429422872408, 0.1778017013732876, 0.09254059395087616, 0.11465508836720671, 0.1763240285217762, 0.14986315768744263, 0.20260314696601459, 0.1591548262430089, 0.17820574183549198, 0.13854178733059339, 0.19101167895964213, 0.09873044144894395, 0.09544691549880163, 0.05228493994634066, 0.12915968362774166, 0.1021209384447762, 0.2753420466823237, 0.11325384570019585, 0.23757652459400042, 0.14445360510476998, 0.12340838009757654, 0.15314950634326252, 0.12372164614498615, 0.12666595886860574, 0.12057374577437129, 0.15800750495067664, 0.1294929664582014, 0.11431633654449667, 0.1640634707042149, 0.14339925668069295, 0.20533431826957635, 0.12102797068655491, 0.09777238392936331, 0.08657748571463994, 0.17870172379272325, 0.13474006418670925, 0.09157479434673275, 0.14928906277886458, 0.11316972092858382, 0.09462477532880646, 0.15030776097306184, 0.20313260784106596, 0.08507852721959352, 0.10453923046588898, 0.16112206211047514, 0.1085583290883473, 0.12947981644954, 0.13076794732894215, 0.12395903840661049, 0.09862203869436469, 0.11876504282866206, 0.13921281775193556, 0.09475887420454196, 0.16353255776422365, 0.09569789203149931, 0.17518286832741328, 0.1872563540403332, 0.2134417260863951, 0.1685440545635564, 0.10436318455530064, 0.16555710269936494, 0.14376903112445558, 0.12147194971995694, 0.1010999535875661, 0.24095402764422552, 0.11122457816132478, 0.1346763904605593, 0.1303559680070196, 0.14494064397045545, 0.11392607034317084], [0.052582491122718365, 0.055954253766685724, 0.001814913025425215, 0.03364142017172916, 0.011026115173340907, 0.056509906093456914, 0.023817121982574463, 0.019364568404853344, 0.029971946895654713, 0.0030369683767535855, 0.055387714345540316, 0.03453413476901395, 0.0760050823113748, 0.03573003238333123, 0.02176792247753058, 0.03048902450661574, 0.031464245569493086, 0.03803746535309723, 0.007447134720028511, 0.062285932047026496, 0.043450607386018546, 0.014096481043712368, 0.015070939602862512, 0.020841031767694012, 0.04674780581678663, 0.039742464399231334, 0.014750248686011349, 0.019188520797927464, 0.03682830577184047, 0.045152234113109965, 0.0441632116479533, 0.02857032764170851, 0.03160311793908477, 0.02697669485184763, 0.03311583712430937, 0.020156311902350614, 0.09444127910371337, 0.037376942046518834, 0.020739565337342874, 0.04320906927543027, 0.006282174909886504, 0.045832251730774126, 0.05169651098549366, 0.021424666878634264, 0.03618803334289363, 0.02582129729645593, 0.020937894337943623, 0.023658266756683588, 0.08293215132185391, 0.030647286014365296, 0.011760237477054554, 0.006617850000371358, 0.008282797244776572, 0.0147146289902074, 0.07909612823277712, 0.08571440274161951, 0.022700738494417498, 0.02100646878326578, 0.09035354666411877, 0.0478514837367194, 0.03017759050375649, 0.017083829002720968, 0.08748806613896574, 0.04306688904762268, 0.0541495643556118, 0.05309318371915391, 0.06371771557522671, 0.03600339039361902, 0.02738330017642251, 0.03745420343641724, 0.043069511585469754, 0.047519937955907414, 0.05021822066711528, 0.08571908463324819, 0.052683063583182435, 0.02652671078353056, 0.03055055406210678, 0.018241012801549265, 0.03397174798218267, 0.02293014439887234, 0.020855072353567396, 0.07903923307146345, 0.019524444825947285, 0.1304361844169242, 0.09075655575309481, 0.03359558852389455, 0.005102774178210113, 0.016387745372152755, 0.05996211924191032, 0.013713073135087532, 0.032801275075014145, 0.02838070085272193, 0.022835427695619206, 0.03415389731526375, 0.013142551561551434, 0.019848409674263427, 0.03530345098780734, 0.02719979377330414, 0.07345037761011294, 0.05551570301343288, 0.054921374190598726, 0.011210239891495024, 0.06737493790153946, 0.03003732713737658, 0.04776358291772859, 0.08574529644101858, 0.05983247155589717, 0.04823497137320893, 0.03181508210088525, 0.06488711639706578, 0.03811076070581164, 0.02411159939531769, 0.044040569836007695, 0.010375673200802078, 0.02629612253180572, 0.08323847595602274, 0.055584068809236796, 0.03011926363355347, 0.0069182857987470925, 0.04039685714191624, 0.00960870216866689, 0.02067511808127165, 0.036864227415727716, 0.0583943369399224, 0.04878220986574888, 0.04267279590879168, 0.019518268460940038, 0.02624984983620899, 0.03757608189646687, 0.014058073417150548, 0.006822474957776389, 0.013941725865671677, 0.02756421796844474, 0.02292548116695668, 0.013794336185258414, 0.052864544559270144, 0.041315546059714894, 0.07217154266046626, 0.06088582253349679, 0.023695423334304775, 0.045409483702055047, 0.006191641375023339, 0.02138019060449941, 0.033830212362642796, 0.02451890191462423, 0.044912086999309916, 0.017499331617727876, 0.028512265400162766, 0.038944921123662164, 0.024875472066923976, 0.040498810421143255, 0.03848778868892363, 0.010986298738446618, 0.013634547973716897, 0.007960413383053882, 0.03591011218460543, 0.059362050012818406, 0.04616774319271956, 0.01985131380414324, 0.019942832911120992, 0.022310545235606175, 0.015865492235336984, 0.0542738176882267, 0.013868564523623457, 0.017658280142183815, 0.022572927941967334, 0.04103412026805537, 0.01120688029498394, 0.06109135079064539, 0.039030810086322684, 0.02853661123663187, 0.04382121303517904, 0.005179549567401409, 0.029103510281337158, 0.03479063118408833, 0.0473258599771985, 0.02296790656899767, 0.04396024825317519, 0.01730930958209293, 0.027873906439968517, 0.01241768871633602, 0.040583013224282434, 0.04618677609999265, 0.02499559142493776, 0.017064338084310293, 0.03864450313683067, 0.014016184057774288, 0.04655893898702093, 0.08215545264205762, 0.05604431911238602, 0.0061724473156833225, 0.022164665295609405, 0.02074581294852708, 0.031563728981252225, 0.07178100504513298, 0.024777408489691358, 0.05263924718435321, 0.0020061589686000453, 0.038221409411302636, 0.021368048220340694, 0.017312490214992846, 0.023819364540811096, 0.0586918406188488, 0.04336087791515248, 0.07939921625490699, 0.03196134710950511, 0.06324451882392168, 0.03993127355352044, 0.017265761204596077, 0.010645683488941618, 0.01755190111829766, 0.010720099272605563, 0.037116649228015115, 0.04035378034625735, 0.024937176345182315, 0.07517178024032287, 0.018220670321690183, 0.03406692948192358, 0.016809631305347596, 0.04793583921023777, 0.05647246453112789, 0.024375400239867822, 0.02333959617785045, 0.02868748689070344, 0.09145546039300305, 0.045695706736296415, 0.03381143051332661, 0.02457012961219464, 0.05899057923150914, 0.048251782078295946, 0.006619970846389021, 0.04265975107305816, 0.021228315807612877, 0.01031624455936253, 0.07671806655292, 0.06899595127574035, 0.042494951880403926, 0.053368512873670886, 0.02914697044928159, 0.012734936916136315, 0.010445466464651483, 0.05116984906739422, 0.04301246375377689, 0.05728764632450683, 0.012576332748202341, 0.024823085770809224, 0.03993759749989424, 0.03199493120025311, 0.06931809256119387, 0.062196155078709126, 0.021194043003820946, 0.02662305597082845, 0.06455499386148793, 0.07200367309685264, 0.05378236834492002, 0.0136614807249446, 0.018986422535298125, 0.136813382218991, 0.0105915609913479, 0.03558980294370225, 0.041322324624551196, 0.058785763436130116, 0.07430537244571106, 0.01274680788628757, 0.019893803667011004, 0.024555965193680356, 0.017527439930875386, 0.0552517732472292, 0.04567424128098147, 0.05058563720168812, 0.030529818031936884, 0.017831018194556236, 0.036925550018038066, 0.012297273347420352, 0.05528636835515499, 0.01943417083072875, 0.03665536415896245, 0.013241292825633926, 0.10751740208693913, 0.05529253284579941, 0.04326445469632745, 0.017921736630211984, 0.03368122303592307, 0.04142314814297216, 0.09584515448659658, 0.07390339472996336, 0.05028010306081601, 0.005423281890606242, 0.045147385980401716, 0.08046161210430519, 0.061181880932833464, 0.004324041589695428, 0.032888673778091154, 0.041310501151851246, 0.06309864736561265, 0.03336150072781103, 0.006313553337739515, 0.022829230974561403, 0.083726016937622, 0.05978371881480728, 0.05655561899766326, 0.0218301899398544, 0.03263192630505987, 0.060730024107864926, 0.026601960317098668, 0.03942845196330121, 0.020949068113363216, 0.03098910142268453, 0.01839149829798511, 0.026760751082162772, 0.04812700966639178, 0.03678539860993624, 0.03881519201344677, 0.03169620615829315, 0.02786148076743952, 0.01431730602468763, 0.017354155657812953, 0.022503814061305354, 0.05869481260223048, 0.022392727700727325, 0.005696812079155019, 0.05990373130355563, 0.023988106021923677, 0.01139892521314323, 0.005730795233310866, 0.06469016482255288, 0.0495995052957109, 0.04133178001003606, 0.009325048237639879, 0.016443337746230618, 0.025427375487717133, 0.058173629854406626, 0.041015175570334704, 0.013844747944468898, 0.048313009685703685, 0.03660601769973125, 0.04913190645830972, 0.07234634685197047, 0.006878275133203715, 0.04800470033660531, 0.04049049158181463, 0.056704557434256585, 0.07582793717405625, 0.028331780174214925, 0.040111584056700976, 0.03439339982079608, 0.01995903463102877, 0.01781422445284469, 0.022414389931197678, 0.03629331822906222, 0.027506201528012753, 0.024617211460801106, 0.13657904336495058, 0.1003338061273098, 0.05878076941839286, 0.1642283954258476, 0.16738133052630083, 0.1714083815791777, 0.1085226856438177, 0.046495787732835324, 0.11839391131486211, 0.06888205917286021, 0.10533897219491856, 0.08540912983672959, 0.15621945661093506, 0.13929253204592637, 0.10161474453551428, 0.09961246233433485, 0.17036425189248153, 0.09030605599816356, 0.14770054444670677, 0.0765490841918758, 0.15912209371370928, 0.06508959124663047, 0.09350521290408713, 0.17539523621754988, 0.09786051205758538, 0.13406547824186937, 0.15580613378967556, 0.14479585816817625, 0.19141380595309393, 0.15724841425461428, 0.11170796650860991, 0.15831470489501953, 0.1407834363303014, 0.15494208729692868, 0.09083372554076569, 0.09597164019942284, 0.21063392103782722, 0.16172147994594915, 0.2133667751082352, 0.15631715208292007, 0.07323460347418274, 0.175521172317011, 0.19012397873614514, 0.13160145974584989, 0.1324851837541376, 0.08157803291188818, 0.09503925844494786, 0.12470710969397, 0.21965862677565642, 0.14087912333863123, 0.1056461992806622, 0.14534411446324416, 0.15087459555694036, 0.1463024637528828, 0.14339730249983923, 0.14017582179180213, 0.1398028175213507, 0.1005547032026308, 0.22711985212351593, 0.20612874706940992, 0.2077921756676265, 0.09473199064710311, 0.1358827714409147, 0.17021352212343896, 0.1261757987418345, 0.1260296015867165, 0.0858828422746488, 0.10333462724728243, 0.08217041433921882, 0.1499173454940319, 0.09188459308019706, 0.10015765843646866, 0.24812516570091248, 0.23385543855173246, 0.21980152625058377, 0.19630368213568414, 0.15732700218047413, 0.21022442515407289, 0.18200648788894924, 0.09958294606102364, 0.1080615668158446, 0.20394322648644447, 0.11549089423247746, 0.14729015289672784, 0.1541772833360093, 0.11632245246853147, 0.10182612854987383, 0.10667167603969574, 0.09389851215694632, 0.07373182036514793, 0.15087361846651348, 0.1492333279124328, 0.09029123679335628, 0.08082334590809685, 0.08361399759139333, 0.10555140115320683, 0.09627338472221579, 0.14416169933974743, 0.2577102870813438, 0.2294645027390548, 0.20568911066012724, 0.08597357597734247, 0.2681397231561797, 0.16006308607757092, 0.14495682024530002, 0.1877957893801587, 0.07844710948743991, 0.08732755189495427, 0.12557096619691166, 0.15948031949145453, 0.1638396762843643, 0.1751045382448605, 0.1522310956248215, 0.1676779588950532, 0.1634969211050442, 0.1733247408909457, 0.19580821586506708, 0.1441017304147993, 0.15791119369012968, 0.12778915145567485, 0.20554998383990356, 0.15625521540641785, 0.12011660316160747, 0.14049740667854035, 0.19674692835126603, 0.1315924080887011, 0.15932201727160386, 0.14937360824218818, 0.09297437460294791, 0.1555586584976741, 0.10374265749539648, 0.13130397642297403, 0.12055596815688269, 0.1404522569583995, 0.14693992026150227, 0.14389700282897266, 0.1159160371337618, 0.14453064597078732, 0.08620637455689055, 0.1251664643308946, 0.15765753015875816, 0.12954700498708657, 0.19906132987567357, 0.23176728774394306, 0.17862078813569887, 0.13831784363303865, 0.1230231486260891, 0.07823643114949975, 0.15644950712365763, 0.18826933896967343, 0.1859220556382622, 0.1708024905196258, 0.06006408269916262, 0.06705481186509132, 0.0736150648444891, 0.22737544269434043, 0.11474622919091157, 0.1246449558862618, 0.14676156054650033, 0.1985037097973483, 0.10494783068341867, 0.2270121821867568, 0.19523066042789392, 0.13802335943494523, 0.102641646218087, 0.2490831757230418, 0.18010004875915392, 0.15941418946853705, 0.14693936386278697, 0.13203112169035844, 0.16150630292083534, 0.1380194103611367, 0.11264281134520258, 0.08558471434350524, 0.10694071517458983, 0.12807020066039904], [0.05433119121672852, 0.07958304496215922, 0.03309413078906281, 0.08979266961770398, 0.009814673169915165, 0.022727859539112875, 0.0069236025447025895, 0.03701180538960865, 0.09971920267811843, 0.06585079218660082, 0.0633867329784802, 0.023728566377290657, 0.012549315180097307, 0.022709359281829426, 0.03724121468673859, 0.02251800222854529, 0.05114987299644521, 0.017396635342655436, 0.01840715210086533, 0.05670518507914884, 0.011112572409079542, 0.02034964518887656, 0.042293583042919636, 0.02684405991541488, 0.022355934139341116, 0.02159037021920085, 0.09446660203060933, 0.037533039027558904, 0.050824708837483606, 0.007419434376060963, 0.08337492256292275, 0.036940250479217084, 0.028937995234238248, 0.07843150318201099, 0.024390129538785135, 0.01324675842520914, 0.011674145802057214, 0.05227945399071489, 0.010832301823289266, 0.04177438161735024, 0.02050439188522952, 0.0038511535718238777, 0.05483536309163485, 0.014831598249397107, 0.06365915121776716, 0.06284794224692242, 0.011507406847418418, 0.03349851051877652, 0.013527911106523658, 0.049421037015105994, 0.040965028439781496, 0.049498807306268384, 0.02311268897860178, 0.007625144141327057, 0.021246522598500763, 0.03888083349115082, 0.026765931697030152, 0.05450365785509348, 0.06480277449424778, 0.017346357594111135, 0.0218656586616167, 0.007775001144701881, 0.014123489281960895, 0.041294206133378406, 0.00478729949931481, 0.026240864336224537, 0.03208291005077107, 0.016341923902343427, 0.02045283679451261, 0.01358349245440747, 0.06284252075212342, 0.048488265102995295, 0.11607585927205426, 0.07505649714065449, 0.038550325868917365, 0.04700778650918177, 0.0331374586426786, 0.01840445662050375, 0.05945752667529242, 0.03213147619473083, 0.028134804850976382, 0.03547564960483994, 0.03630801529756614, 0.06266562667276178, 0.018319783931864158, 0.020950633832918744, 0.068644307287676, 0.015334041556343436, 0.027379863396553055, 0.00952618891772415, 0.042180325370281935, 0.03982143569737673, 0.010998736285338444, 0.04027251899242401, 0.036412960916225395, 0.061632122844457626, 0.0247101911144065, 0.025662436981552413, 0.018082205073109696, 0.09954813721456698, 0.025824160714234625, 0.036263133598757644, 0.04813140318063753, 0.018154089072985307, 0.015325381753167935, 0.023834670594494258, 0.06240280970398869, 0.054555413113640885, 0.09658051681305681, 0.05444226061393108, 0.06051861295210464, 0.07272397194589887, 0.14106781035661697, 0.055480412407112975, 0.06597872317901679, 0.005294960740554545, 0.04891205432691744, 0.044309228991291354, 0.03416718981627907, 0.018679460078211765, 0.03749460680410266, 0.03352278510906866, 0.041949416510760784, 0.04957102718097823, 0.022172470144661408, 0.04430270487708705, 0.06024692074528762, 0.009143007470161786, 0.04701613588258624, 0.08148569786655051, 0.04367791661726577, 0.046284135697143416, 0.017311129752280455, 0.052625988610088825, 0.03141235799661704, 0.026618097576179674, 0.04792708271582212, 0.05738192876534803, 0.029369299233491932, 0.0323537405181144, 0.05120436953646796, 0.04264759851087417, 0.014190900887894844, 0.0254086173871266, 0.017343517925058092, 0.033897445004965575, 0.012461187900044024, 0.03814400213637522, 0.016979086944567304, 0.03367027487339718, 0.04534507037273475, 0.1246467607894114, 0.008835659096283572, 0.0176489248406142, 0.024829752377367446, 0.012440063408575952, 0.08802218176424503, 0.005290944237328533, 0.032993381909493885, 0.012300655844488313, 0.019743596369932805, 0.049119994776057344, 0.031480252210583, 0.03760565923792975, 0.041335807115371735, 0.0402567600166159, 0.08048650755413941, 0.03829963771360261, 0.039130279927381446, 0.016917657472991517, 0.013645428282740926, 0.015308800053649714, 0.03996966167220047, 0.042141187470406294, 0.024073382606729865, 0.032530013737933974, 0.0517066313352968, 0.04514190341745104, 0.0589773952960968, 0.01804037847822266, 0.026498443014653664, 0.046352023125759194, 0.0395085326662021, 0.07223187799432448, 0.047654125041195323, 0.015427409671247005, 0.050195795084748945, 0.03534857356654746, 0.04177033754863909, 0.06041235436818429, 0.051687578071973155, 0.040404154786041806, 0.07280723497803722, 0.009320301885184432, 0.03415478958881327, 0.05875311911638294, 0.061339172135506354, 0.02740281993257148, 0.037027900240250995, 0.05515051885907139, 0.027159848416756307, 0.01370871948477413, 0.03981784624712808, 0.045698288562042375, 0.012216488664437617, 0.034118555818817446, 0.049164764516587765, 0.03270305713106479, 0.01861374226531812, 0.04017278791538306, 0.053713849878736904, 0.02154627053200134, 0.025391552231407592, 0.014897472125345042, 0.055800219532102346, 0.047600493633321354, 0.0772679920441338, 0.014667330010394965, 0.03449770422386272, 0.03536295172359262, 0.04003708430432847, 0.07421683719647781, 0.04455609360177602, 0.028442055685445666, 0.028778135776519775, 0.020319150128800954, 0.013498866415050412, 0.0059041032550989515, 0.02928463163386498, 0.04816803050094417, 0.06099350604095629, 0.08688643627933093, 0.05696619714477232, 0.09392929050539221, 0.028739038588745252, 0.016022189719868556, 0.07220076037836926, 0.044055680810872994, 0.02657145507899778, 0.017192652449011803, 0.0077096624632499045, 0.05468012785006847, 0.0005781735401667122, 0.017698883677699735, 0.04838279361969658, 0.014584681052448494, 0.019132504339462945, 0.043731520883738995, 0.012353174454931701, 0.03592726894255195, 0.06741421150841884, 0.011195711608576988, 0.052400562313518355, 0.03443298555378403, 0.02780562885371702, 0.04785109697175877, 0.06265333840357405, 0.030195575074425766, 0.03182889707386494, 0.01205358512899173, 0.05334550714386361, 0.04731703902195607, 0.05753838536994798, 0.03762955045593636, 0.025113374926149845, 0.019130316064027802, 0.032541630257453234, 0.0449493962473103, 0.012138976216582316, 0.01237716236417847, 0.07276910130998918, 0.0357810514313834, 0.023238329915329814, 0.01139457495550492, 0.040937809007508416, 0.04227041107203279, 0.02052895654924214, 0.05782066950840609, 0.0603216817336423, 0.05581199550735099, 0.011187053501739033, 0.015282364329323173, 0.03692865092307329, 0.031679683830589056, 0.06540754597101893, 0.022899191327659146, 0.034859634802809784, 0.04865029587277344, 0.0841138811249818, 0.055926807025181394, 0.02400978691210704, 0.028623565499271666, 0.07921428153557436, 0.030821442204926695, 0.060315371357968876, 0.011256110555093204, 0.019083797399486815, 0.0357647869469864, 0.02188863555368568, 0.07483609539589711, 0.03479800346706595, 0.059393567964434624, 0.01712394568936101, 0.039493560791015625, 0.008357888170784073, 0.0037260028766468167, 0.03182502942425864, 0.029787985874073844, 0.011657497945374675, 0.027614268407757794, 0.05730901339224406, 0.02468969766050577, 0.038290138223341534, 0.029690371826291084, 0.012851681410601097, 0.053152080558772595, 0.051065137543316395, 0.013674345748898174, 0.037351072898932865, 0.027773035424096242, 0.04939598889489259, 0.053799796516874006, 0.04374546817104731, 0.049059235357812474, 0.05461678999875273, 0.04303029904674206, 0.011629555873306734, 0.03371476302189486, 0.028845371811517646, 0.0068188736331649125, 0.08569434524646827, 0.08398054899381739, 0.07311218218611819, 0.05335312709212303, 0.038559228248362026, 0.04269430207620774, 0.07206517551094294, 0.03030144010803529, 0.054712052922695875, 0.011418422916904092, 0.0018854766385629773, 0.024700379498036842, 0.017850090117592896, 0.04921988191615258, 0.047257806307503154, 0.047398208773561885, 0.025059628167322705, 0.04949988956962313, 0.04901644354686141, 0.04317365653280701, 0.03702314031709518, 0.012114513332822492, 0.16348535886832646, 0.22798822766968183, 0.10906493690397058, 0.13786526077560016, 0.08595207998795168, 0.11785480167184557, 0.12012146147234098, 0.20533905444400652, 0.17866044172218867, 0.12312471174768039, 0.1929932590574026, 0.1122541261304702, 0.08934996623013701, 0.14441821271819727, 0.14477980402963503, 0.13573269306549005, 0.1708889901638031, 0.16093674062618188, 0.08065055018024785, 0.15853567660919257, 0.11508888937532902, 0.08032410698277609, 0.10814692652119057, 0.10903182439506054, 0.10863404681107827, 0.11803100364548819, 0.13367134439093725, 0.12900573760271072, 0.136015845728772, 0.1019745377291526, 0.16437246198100702, 0.10193892821137394, 0.14449207804032735, 0.10722110620034592, 0.15412120920206818, 0.13042535499802657, 0.1125140796814646, 0.13651987511132443, 0.16015715817255632, 0.19005047982292517, 0.1152679683374507, 0.11136867185788495, 0.06918210057275635, 0.13169721460768155, 0.11058560173426356, 0.1711262467184237, 0.12102052037205015, 0.11052249797752925, 0.14438136826668466, 0.11162304785102606, 0.1005361724112715, 0.13501740859023162, 0.1169429998844862, 0.09794444683939219, 0.14380902397845471, 0.1578740371125085, 0.14986801599817617, 0.20434571988880634, 0.17780740106744425, 0.08934715709515981, 0.15903667972556182, 0.13274447912616388, 0.1255387222128255, 0.10035341578934874, 0.0787754865097148, 0.1210233566484281, 0.09733937680721283, 0.10393476432987622, 0.0630310449217047, 0.08227654400148562, 0.11692302381353718, 0.1306317246385983, 0.2682215544794287, 0.22594814428261348, 0.1042197761791093, 0.13699596242180892, 0.1411760366920914, 0.08220690595252172, 0.16790973288672312, 0.15280105146978581, 0.14880868712706224, 0.17457061260938644, 0.1537507019404854, 0.142312528565526, 0.12176795383649212, 0.20750051417521068, 0.1265677341393062, 0.1377808374485799, 0.12252142626260008, 0.1414522004446813, 0.07104237217988287, 0.16479570498423918, 0.059121767192014625, 0.12194536360246794, 0.08259730786085129, 0.10454375629446336, 0.0644034973478743, 0.1642496878547328, 0.095603568878557, 0.17491175287536212, 0.1366577534271138, 0.16006163401263102, 0.1770013693187918, 0.18634563790900366, 0.12132438192410128, 0.05148938138570104, 0.15116920189133712, 0.2320079505443573, 0.18209880936358655, 0.11326956735657794, 0.2091393390936511, 0.1752493376178401, 0.22808276116847992, 0.2306218392082623, 0.16359575651586056, 0.09483117889612913, 0.25309367052146364, 0.12344039337975637, 0.13298340487693036, 0.12707143782504968, 0.13652465199785574, 0.09368587963815246, 0.15713250690272876, 0.17863043690366404, 0.1183916042957987, 0.16024714548672947, 0.09586577516581331, 0.11275170943034546, 0.10422264638223819, 0.14146161851074013, 0.1503527478447982, 0.15463636655892643, 0.1100598049483129, 0.12715679753039563, 0.11985767419849123, 0.13484915904700756, 0.18017808028629848, 0.16961139014789037, 0.11364920769951173, 0.10876274454806532, 0.12084924456264291, 0.21194463356265, 0.11469727967466627, 0.11066809123648064, 0.16602844026471886, 0.19332814323050634, 0.08268479816615582, 0.21674387103744916, 0.155773292694773, 0.059829384221562316, 0.14633477559047087, 0.18548220209777355, 0.09906858937548739, 0.15087474483464444, 0.15909715076642378, 0.31437309086322784, 0.18518357883606637, 0.2540374313082014, 0.11503510868975095, 0.09455295239708253, 0.12714018699313911, 0.1348031408020428, 0.16022787509219988, 0.09112899683948074, 0.14124078250357083, 0.22797783251319612, 0.16087066488606588, 0.12287079037300178, 0.13167749638003962, 0.07322411332279444, 0.09872229224336998, 0.11593711243144103, 0.15629135418151105, 0.17192823439836502, 0.1440304842378412, 0.14040846430829593], [0.04213646825935159, 0.06233932596764394, 0.04058951698243618, 0.014765788834275944, 0.008470171297501241, 0.05262726764859898, 0.006500594484220658, 0.01078666016525988, 0.025796278013980815, 0.028000539734161327, 0.03191206171842558, 0.028469867139522518, 0.12010372456695352, 0.009891884517855942, 0.03204749730814781, 0.03182850352355412, 0.03551703006295221, 0.01592327967020018, 0.02274733010147299, 0.059037527069449425, 0.04876856113384877, 0.053827426462833367, 0.04824365322877254, 0.08032767607697419, 0.025069451658055186, 0.008576979494786688, 0.026270972631339515, 0.031107173301279545, 0.01779820933006704, 0.038024617292519124, 0.021006122730406265, 0.056497631394969564, 0.052570986561477184, 0.05025385732629469, 0.01806964199723942, 0.007442036377532142, 0.02757608045690826, 0.029117298112916093, 0.0004797516116273722, 0.057617231139114926, 0.0843393447409783, 0.055576679562883716, 0.0074159068421327645, 0.03641875221260956, 0.040762102364429405, 0.04796219690303717, 0.020702659817678586, 0.031671429452087195, 0.014328447569693838, 0.0788319677646671, 0.020165667203920226, 0.0664621250970023, 0.0474326410330832, 0.020344975171610713, 0.013154240175416427, 0.09614792359726769, 0.022984717274084687, 0.040041152121765275, 0.03629191026889852, 0.03349553175004465, 0.03481300926900335, 0.06634610239416361, 0.05681578628718853, 0.027301957398386936, 0.0526233898209674, 0.029573002231440375, 0.00949927737071578, 0.013711733028425701, 0.08018144499510527, 0.03434189562020557, 0.04033630467685206, 0.0736539177596569, 0.029519689735025167, 0.059023549248065264, 0.057535528737519465, 0.047662830645484586, 0.10733792278915644, 0.04767449466245515, 0.0074291688090722474, 0.025414422254211137, 0.046828147755669694, 0.07778154127299786, 0.024793681455776095, 0.09813583442675215, 0.062210689298808575, 0.036683078921799145, 0.02341218924682055, 0.06802682685000555, 0.015809942269697785, 0.047873627727052996, 0.06261000715728317, 0.02107415095503841, 0.0607461528852582, 0.04144875605457595, 0.04584831265466554, 0.043459228173430474, 0.03436483349651098, 0.0165564783715776, 0.004354549796387021, 0.054451905989221165, 0.021583347381757836, 0.023124902608937452, 0.12156380979078156, 0.02918720757588744, 0.06605845782905817, 0.03757267565067325, 0.055964974619980366, 0.05375118287546294, 0.06233866100332566, 0.023196399843852435, 0.024812439556366632, 0.06927875110081264, 0.00465780999677788, 0.056968931640897474, 0.08030425304813044, 0.04347294815150755, 0.08749329085860934, 0.028509011824748347, 0.016732139213542854, 0.03740767968286361, 0.015911222102918794, 0.02164006612396666, 0.026147976284846663, 0.004164717750557299, 0.048485964869282076, 0.050665097045046945, 0.025095772031428557, 0.07039369948740516, 0.04902897608865585, 0.031537462890680344, 0.02105067194705563, 0.047447165075157366, 0.052018682805023024, 0.009016439484964524, 0.04929388973063656, 0.025368485433448638, 0.022094813508114645, 0.027329095406457782, 0.043978850290711434, 0.009684580195296024, 0.056073475762137344, 0.04374961062733616, 0.015389991857643639, 0.03996952257252165, 0.024319371907040477, 0.05143207571070109, 0.05453381534399731, 0.026839230442419648, 0.002051617210132203, 0.03824994859418698, 0.033831654249557426, 0.034547742788812945, 0.11412428399281842, 0.04622493690944143, 0.01686788523303611, 0.05646582506597042, 0.036041744585548124, 0.025351272696363072, 0.02493425864460213, 0.03245884219982794, 0.029217897714780908, 0.014624828273164374, 0.011626047847260321, 0.028199365761663233, 0.020374387968331575, 0.09318128028618437, 0.014842341155079859, 0.01638045790605247, 0.07895540685525962, 0.041061594150960445, 0.05655663001484104, 0.04140914996553745, 0.08969302675021545, 0.04982534549864275, 0.012510079740812736, 0.03888890127252255, 0.016338380253208534, 0.02623457431660167, 0.010682491469196975, 0.053078578252877505, 0.027922350447624922, 0.07074011875582592, 0.03327273138399635, 0.0604446322790214, 0.01324287974940879, 0.039583483644362004, 0.05059474314163838, 0.021277546915890913, 0.07175616387810026, 0.0338641967890518, 0.017254796078694717, 0.009055886966442423, 0.05284483311697841, 0.03168010452230062, 0.03249639572043504, 0.02588888956233859, 0.020553851999076347, 0.04663709943581905, 0.052699826790818145, 0.06547816111040966, 0.04193792212754488, 0.015432634390890598, 0.023350362832258855, 0.037109711207449436, 0.03314477325017963, 0.03888093866407871, 0.02027947279358549, 0.03089748223179153, 0.07381586371255772, 0.025840264046564698, 0.03217299235984683, 0.05371175320552928, 0.005001439214018839, 0.038165521874491654, 0.022147204893242036, 0.037520879680024724, 0.011549911129155328, 0.02891845003302608, 0.05737140468720879, 0.009795538482389279, 0.01651155256799289, 0.04871502472087741, 0.03805177226396544, 0.04882831632026604, 0.02825692079828254, 0.04128596193290182, 0.06599600546594177, 0.029918854923120568, 0.07060639985970088, 0.05017601239628025, 0.05611917170296822, 0.010478861413763037, 0.0020129413501958227, 0.024444312256361758, 0.028644359204918146, 0.04854830188144531, 0.05669798582260098, 0.03925227713105934, 0.032405105619026084, 0.06964366723384176, 0.02472947847231158, 0.03170554619282484, 0.022856825297432284, 0.037314255588821, 0.11626046150922775, 0.0655806538249765, 0.02079085579940251, 0.03150576512728419, 0.042106219168220244, 0.011508317780680954, 0.024539010299901878, 0.01770510245114565, 0.07050975611699478, 0.023690775369427035, 0.044508860779127905, 0.06340923319969859, 0.010414089309051633, 0.10248923368219819, 0.021587354131042957, 0.04336883034557104, 0.016697834179337536, 0.018834106690649475, 0.007887367391958833, 0.015065826841496995, 0.022888158348255923, 0.1008037526958755, 0.02346961705812386, 0.023999052488112023, 0.07114958071282931, 0.05038640235683747, 0.04001502173819712, 0.033611367855753214, 0.019407841975667646, 0.05879222987485783, 0.06596069450357131, 0.05988773823316608, 0.028235626673059802, 0.02767209825105965, 0.09004977332162005, 0.032718778787446876, 0.03900041511016233, 0.027703963951872926, 0.05089390923136047, 0.0757378955770816, 0.030509319489023516, 0.06392097752541304, 0.020638056498553072, 0.013394002220593393, 0.013956628191018743, 0.014900318579748273, 0.036662465027932606, 0.0792917295226029, 0.039828217654888115, 0.024109536648861, 0.006537885496592415, 0.029427368260387863, 0.03578042039381606, 0.04825103908245053, 0.014693197461643388, 0.002255690433750195, 0.07944974675774574, 0.06419490889779159, 0.046196282375603914, 0.016589485707559755, 0.04763131608654346, 0.014276293671822973, 0.03516343867938433, 0.03601657432903137, 0.024623847533283488, 0.004149901938425111, 0.01581951809514846, 0.016649739617215734, 0.028347188008150885, 0.06290082726627588, 0.04958288458042911, 0.03473389547850404, 0.026471403394160525, 0.022100229913901006, 0.03081311658024788, 0.03708580981141754, 0.05350150913000107, 0.027573939678924422, 0.02884059153231127, 0.04528343564431582, 0.05482477115999375, 0.02436899656562933, 0.06085332749145372, 0.027414645101608973, 0.04472465527110866, 0.019296207698062062, 0.015815365460834334, 0.06284328749669449, 0.011293651353168701, 0.03421870758756995, 0.05003290257549711, 0.015919564690973078, 0.03181161817961505, 0.04063422226213983, 0.035096843859979084, 0.017440930108672807, 0.09777332030768905, 0.023534055832507353, 0.03555955385257091, 0.014392508060804434, 0.07954368314572743, 0.017860407242551446, 0.019613161583298018, 0.019111271282391887, 0.015576794244615095, 0.012435775067258095, 0.026837581602324332, 0.0252712106531752, 0.16471898981503078, 0.19161455732371124, 0.14000256466014044, 0.10361777312521424, 0.09484869867031064, 0.13383907824754715, 0.05804203477288995, 0.11248972027429513, 0.19779103089656147, 0.09956507344863244, 0.17459296355290072, 0.09568413134132113, 0.23687304662806646, 0.12936496761228355, 0.12282047021601881, 0.0654211098860417, 0.0939286933945758, 0.07581982189523322, 0.11402901767620019, 0.09000598067151648, 0.09818970332188265, 0.0924246594575899, 0.11351104439901454, 0.09709092442478452, 0.10693407910210745, 0.0755864872730204, 0.1055043718910643, 0.2174505516886711, 0.16122285170214518, 0.10657216887921095, 0.1560871015701975, 0.1255899787481342, 0.21468102958585533, 0.1362941807934216, 0.08708109440548079, 0.15167568757065705, 0.10610592711184706, 0.09491657931357622, 0.13943161815404892, 0.11965499578842095, 0.2231335403131587, 0.1613420567342213, 0.1439413654484919, 0.07115362478154046, 0.14884905996067183, 0.1550164275935718, 0.1445134383227144, 0.1331929772027901, 0.07926514452057225, 0.1260871956390994, 0.13102987541684083, 0.18476064795894281, 0.11203584141497101, 0.10767428616860084, 0.1692796272358724, 0.1689063651221139, 0.09189515108508722, 0.1141282602080277, 0.11888873976256166, 0.17269039207271167, 0.20027236560625689, 0.1472074937607561, 0.09858752840331622, 0.24112604984215327, 0.1791680809110403, 0.1186577800129141, 0.07206264457532338, 0.11887320131063461, 0.23312335354941233, 0.10767687817237206, 0.08679507832442011, 0.21866299877209322, 0.11964119438614164, 0.17819496669939586, 0.21528061026973383, 0.06393819874418633, 0.2320674987775939, 0.10463828300791127, 0.14083858765661716, 0.15477125932063374, 0.1217645068785974, 0.21753084952277796, 0.10309262773288147, 0.138998522822346, 0.1230825340109212, 0.09348599679235901, 0.10067930937345539, 0.13217809237539768, 0.07819150534591504, 0.17646261251398496, 0.13837112220270292, 0.10839400147753102, 0.17588915542832442, 0.08757098990359477, 0.12857166518058094, 0.15555014966854028, 0.17913431700851234, 0.10785030493778841, 0.0987849888790931, 0.15094022346394403, 0.14944395875292166, 0.17741300937320503, 0.2173960924680744, 0.18303991029305117, 0.20670289626078947, 0.11489326772945267, 0.28619157735790524, 0.1728832045836108, 0.117972961759993, 0.1003377212743674, 0.160236940320049, 0.1096047590087567, 0.12706558885318892, 0.14073331973382405, 0.1657027027436665, 0.1301750705710479, 0.13088944580938133, 0.13403826898762158, 0.07121652497776917, 0.1194699728595359, 0.27820123040250366, 0.08220238012394734, 0.15092684275337628, 0.1758204469723361, 0.16101638706667082, 0.14107488069151128, 0.07862244972160884, 0.11919448764196464, 0.17594100907444954, 0.15158671805901186, 0.0749652273952961, 0.12172045638518673, 0.18141731593225682, 0.13474519391145023, 0.10094483369695288, 0.0839122205174395, 0.11685754518423762, 0.1517961546778679, 0.120974814253194, 0.13105675897427968, 0.1014368733657258, 0.06835384680224316, 0.07667180403534855, 0.18929049346063817, 0.14968055034322397, 0.16730295973164694, 0.12604129953043802, 0.13311368360051087, 0.16855214270097868, 0.17672459488468512, 0.17691244051924773, 0.15721152909100056, 0.1837670827018363, 0.15486553497612476, 0.10885197868836777, 0.1483247559517622, 0.08896892131971461, 0.08825650704758507, 0.17270716545837267, 0.1304465252906084, 0.10069840334888015, 0.10691976201321397, 0.12598242983222008, 0.08930689961250339, 0.19448311839784893, 0.1032666244677135, 0.15887826894010815, 0.1172128396907023, 0.12411738133856229, 0.13126945256122521, 0.11710024358970778, 0.10886185815823929, 0.12263205461204052, 0.14346389392656939, 0.0863067570275494, 0.07567175876881395], [0.048553889617323875, 0.037110698475901566, 0.007600590503508491, 0.013524973898061683, 0.007209730584041348, 0.03650025783904961, 0.035622755996882915, 0.02053410154102104, 0.03801430016756058, 0.05764840982322182, 0.05087786527084453, 0.016088569104405384, 0.05697828185345445, 0.024643173906952143, 0.005695224307211382, 0.040862976772976775, 0.007320309739692935, 0.04319047063056912, 0.01924398255401424, 0.020076838488291417, 0.05123039813978331, 0.013228836619029087, 0.013783256556572658, 0.014617885163586055, 0.024177502109003917, 0.025567318246300732, 0.03276817952947957, 0.0602292109813009, 0.04838425246998668, 0.028571776313973323, 0.06153859357748713, 0.018587723840028048, 0.032303783377366405, 0.03886867753629174, 0.011839046774964248, 0.03771507979503699, 0.03626353393441864, 0.06019909759717328, 0.015408091779266084, 0.027385257749951313, 0.02128142983253513, 0.05514160969427653, 0.007855397366386439, 0.049197802386645756, 0.06892114278993436, 0.016656480862626007, 0.03866599912622145, 0.02419423308622624, 0.02885390438937715, 0.01292092421291662, 0.053562672276582034, 0.09614968100296599, 0.008976217625396592, 0.07337828326438155, 0.01685853162780404, 0.00744530013097184, 0.026161870985691036, 0.13915531869445527, 0.03390754160604306, 0.011832914514733213, 0.035013170314154456, 0.027392160147428513, 0.012238118664494582, 0.006910290959889868, 0.07019288026328598, 0.01769736545559551, 0.02603740052187017, 0.010969326033123901, 0.03650260217753904, 0.017156223600198115, 0.021092247483985763, 0.0019041819406473742, 0.018788502352046113, 0.021677551791071892, 0.05042038678324648, 0.043541005213877985, 0.052886620696101866, 0.023824584171442047, 0.04232483636587858, 0.09491495082953147, 0.038179655758930106, 0.015922480695215718, 0.004663982545025647, 0.08867779586996351, 0.04116372384929231, 0.027123105745496492, 0.016339143605104516, 0.026206527071605836, 0.13337599166801997, 0.07672031250383173, 0.04040890792384744, 0.020316334208473563, 0.022699172774861966, 0.03987930794911725, 0.02612039553267615, 0.026283272774890065, 0.06614443500127111, 0.067393441551498, 0.03031848490770374, 0.027503433105136667, 0.021504942660353014, 0.04462088691070676, 0.04449212810556803, 0.06088086244251047, 0.030765235756656954, 0.013616509968414903, 0.010805419962187963, 0.036632921613220654, 0.015240458006571447, 0.03290546751980271, 0.018159413876544152, 0.0719485217705369, 0.055999922566115856, 0.06677722997431244, 0.03571091126650572, 0.07530755509755441, 0.037866352392094474, 0.03348249030698623, 0.04551805269771388, 0.05160390113347343, 0.03817706036248377, 0.05710887948849371, 0.04700592393055558, 0.004462214644133512, 0.012620837860075491, 0.03574196102895907, 0.007385147153399885, 0.02261995041875967, 0.04096333210223487, 0.03672160614015801, 0.03732121396543724, 0.0252854191764657, 0.050022419209459, 0.02257222056921039, 0.00090735950340916, 0.03478037512728146, 0.02646490981403206, 0.017938031648684825, 0.01908904586785606, 0.041864670879606686, 0.02382651629990765, 0.01950052985921502, 0.047627957338201146, 0.03858407959342003, 0.03248333392132606, 0.07117598929575511, 0.03888378172580685, 0.06744524770017181, 0.03191761213487812, 0.0290375227507736, 0.02467262402309903, 0.07306370085903577, 0.0403818174132279, 0.042360608732061725, 0.011289865975933415, 0.039524074510804245, 0.022122443454074006, 0.01868057796465499, 0.05367021329168763, 0.062091816748891554, 0.06366068470690932, 0.07370222945298467, 0.04156479911346521, 0.0396694370678493, 0.0667079244075077, 0.06459717159824711, 0.10364208503493241, 0.030976009089499712, 0.049620930038924725, 0.038919869610773664, 0.055641333772135634, 0.022695715638941953, 0.04517262748309544, 0.051633478474936316, 0.07693507562258414, 0.04688974177198751, 0.010164698851960046, 0.04565721683736358, 0.012262070102484098, 0.03671406422342573, 0.014570972948734249, 0.054619880725762675, 0.0369036944050874, 0.00837685152821775, 0.020740654386047806, 0.07181930156158549, 0.05864598522228854, 0.03450664392273341, 0.05630076124465891, 0.07607011310756207, 0.01781688431011779, 0.04351396220070975, 0.018902665868933712, 0.044416237356407304, 0.022115678459938084, 0.0032221685729122585, 0.03463789973674076, 0.03014973664124097, 0.0060551158884274104, 0.029759772387998443, 0.08774594337280307, 0.022498414618894458, 0.055269235345934115, 0.06541220750659704, 0.021240302128717303, 0.010383284667373767, 0.0544229189732245, 0.009439180372282863, 0.06473697695348944, 0.12246803912733283, 0.03709202179951327, 0.0029553482475291404, 0.012797768410694386, 0.03688313140134726, 0.018335242655926516, 0.03028373034404857, 0.01660391645106886, 0.05083432028602276, 0.03305387669908149, 0.023893952502736023, 0.068261749244162, 0.012028071364121777, 0.04071100867752518, 0.05046970610107694, 0.018827448565778986, 0.026470970828086138, 0.02266572948013033, 0.010120456672406622, 0.067142125751291, 0.027561936394444535, 0.013891569405261959, 0.05328278675941484, 0.01999484601297549, 0.10916554329118558, 0.03999272507748433, 0.026014345598274043, 0.04502515807481749, 0.03353247119645987, 0.058369814684348445, 0.02492167690901884, 0.0566083140272115, 0.01805322484246322, 0.06321585071938378, 0.033830002016787014, 0.06003805409584727, 0.006112960150598415, 0.009456406680068799, 0.032069902534463575, 0.05653034017554351, 0.01934723522780197, 0.009145530772262385, 0.030931076500564814, 0.028188283588471155, 0.03944540855341724, 0.11507929489016533, 0.037370326330087016, 0.009260594196218466, 0.03603554956082787, 0.04518166556954384, 0.014558118102805955, 0.02283001468250794, 0.10591840717409338, 0.04677039424755743, 0.028897116892039776, 0.011501711394105638, 0.022459729641143764, 0.02494497610522168, 0.03700351029900568, 0.018981150318203226, 0.026144008551325117, 0.05559219426608511, 0.026535056764259934, 0.02032956394499966, 0.03775638222162213, 0.04954386542418173, 0.06034134567848273, 0.05736282800457307, 0.055949351351175985, 0.05525349672617657, 0.01420446649925517, 0.008582808110596878, 0.02121689267057393, 0.025734220897512775, 0.034045596340937276, 0.014376236791057246, 0.05456724676436611, 0.041378907659756284, 0.013551937183365226, 0.018120169107403074, 0.05189787643030286, 0.03450833686760493, 0.03756240263049092, 0.004333454990826015, 0.060653166446302614, 0.03794560528227261, 0.04560554300301841, 0.013686055566982498, 0.018440293447513665, 0.017252141310434257, 0.08581874785678727, 0.01334504337449159, 0.025091580381350856, 0.06247603041785104, 0.01029340167795973, 0.003725318404446755, 0.03672215575352311, 0.039066687625433714, 0.02247001792836402, 0.03043175275836672, 0.018413314895172204, 0.030841045081615448, 0.047029241786471436, 0.006045419198926538, 0.019769097412271158, 0.02336369943805039, 0.01611705570082579, 0.05854980966874531, 0.0541800882534257, 0.01219866015682263, 0.027017015098993267, 0.05352482020056673, 0.0117776096698695, 0.023202384522716914, 0.048818409708993774, 0.029700661809848886, 0.03879936857681189, 0.040864377947790284, 0.047472382829125435, 0.014852970406146986, 0.020624429819041064, 0.013161215515408133, 0.012311539546187435, 0.05273366533219814, 0.07702965661883354, 0.033915409219584296, 0.05290762474760413, 0.05311303086844938, 0.02495631272904575, 0.020018864456298094, 0.03852487741304295, 0.04100571000682456, 0.03425624414480158, 0.06025805550494364, 0.020813886974272982, 0.012222738820128143, 0.03388027806899377, 0.07937041244336537, 0.09926479456147977, 0.01040152199233749, 0.03606162226891943, 0.013035866348738117, 0.04147859123934593, 0.22557362009372028, 0.08586836912270103, 0.12722425748194965, 0.07625760590391499, 0.0819405402456011, 0.143702643258231, 0.12179574663085596, 0.07176037758056607, 0.09974056296050549, 0.13899753216121877, 0.13843902998736926, 0.1048583115584084, 0.19217362946697644, 0.11168429242180926, 0.0647829816277538, 0.15147724321910314, 0.1301061992666551, 0.19308293424546719, 0.12539320359272615, 0.0787986381245511, 0.19478653211678776, 0.1079623649961182, 0.09861945347594363, 0.155868477587189, 0.2139607918049608, 0.11361021907734019, 0.11205446041588273, 0.16065395437180996, 0.13217456399330071, 0.09561387582549027, 0.2376324087381363, 0.08047753732119288, 0.12733476369508676, 0.15223106848342077, 0.11911868170968123, 0.05181556673986571, 0.136273309056248, 0.10407899373344012, 0.09085454299513783, 0.07507259199129683, 0.11888621561229229, 0.14680202837501252, 0.13293417037597724, 0.1517912692257336, 0.159734308719635, 0.11495854279824666, 0.2227127400359937, 0.14862633762615068, 0.16671290567943028, 0.17471172075186456, 0.14620871735470636, 0.23770778040800775, 0.15186760441533156, 0.16766700733985218, 0.09898977753307138, 0.1485316819910492, 0.17601229596350873, 0.3126666567155293, 0.09116919325398547, 0.11502784836505141, 0.08547475774373327, 0.10761951482189552, 0.12635556980967522, 0.10106614218758685, 0.19264104509992258, 0.080000343998628, 0.25473678378122194, 0.09208360740116664, 0.11384159273334912, 0.25365595892071724, 0.14195795330618108, 0.12256034703126975, 0.13326479334916386, 0.181667654642037, 0.13574684730597905, 0.07638415268489293, 0.1325331697506564, 0.10561031156352588, 0.2024057475583894, 0.2290708710040365, 0.05669646590415921, 0.07968742400407791, 0.06259496403591973, 0.16746747733226844, 0.11208282996501241, 0.26292583293148447, 0.11341902147978544, 0.10897296826754298, 0.23517630196043424, 0.16380706589136804, 0.16040293712701115, 0.1053222327360085, 0.13487638187195572, 0.1047376748174429, 0.13914923902068818, 0.07521655676620347, 0.20566880889236927, 0.11116561346820422, 0.11575645926807608, 0.15050746739975043, 0.21709403581917286, 0.11995131203106471, 0.173966485740883, 0.1754456649401358, 0.09031660043235336, 0.09685406142047473, 0.08126893985484328, 0.16653835933123315, 0.0732867828171168, 0.24424975365400314, 0.10767183665718351, 0.10970649176410266, 0.13032683171331882, 0.20160313562623092, 0.11477064288088254, 0.10628449038735457, 0.09184716508856841, 0.11272891065371887, 0.18626837991178036, 0.2167956025472709, 0.10724955038832766, 0.16489576175808907, 0.12566414262567246, 0.16148734465241432, 0.10958490507411105, 0.12289110571146011, 0.08654594062162296, 0.08775996190628835, 0.1251991425773927, 0.19137715149138654, 0.12072166640843664, 0.08783191375966583, 0.1729635838419199, 0.1432599534413644, 0.13118253222533635, 0.12051275904689517, 0.13192080546702656, 0.13664446771144867, 0.20862718086157525, 0.10772528486060244, 0.1300707525972809, 0.1185917178434985, 0.12226408507142748, 0.1918254867196083, 0.11680010040955884, 0.1482983880809375, 0.10509160546852009, 0.15108252582805498, 0.11497683610234942, 0.07906607591680118, 0.2320779753582818, 0.17404278021837982, 0.08146906697324344, 0.06949647263224636, 0.1438993505601372, 0.15458166306572302, 0.09784298549805369, 0.14433779274778707, 0.10689210492585387, 0.13224693653838976, 0.1751068588346243, 0.20602350628801755, 0.07300227308379752, 0.07092550130827086, 0.18584778319512094, 0.12454317563346454, 0.19760679506829806, 0.1339949784534318, 0.09835311491042376, 0.10659736966980354, 0.17767001129686832, 0.1590554072920765, 0.23552232767854417, 0.12202277087739535, 0.18828626163303852, 0.09319090191274881], [0.014065799386506634, 0.010547284036874771, 0.03879265786547746, 0.02313598817480462, 0.016475936264864037, 0.03123421880549618, 0.03822545687268887, 0.04511817165517381, 0.006084310705773532, 0.015315605759886759, 0.022594188140439134, 0.011117666510732045, 0.056014046272529025, 0.11141831347984926, 0.04990967043808528, 0.03211068927443453, 0.047487364882337194, 0.05081037478521466, 0.035678392475736995, 0.01964840978117926, 0.04347709060779639, 0.07843383055712495, 0.01954427331552974, 0.03750848284523402, 0.010371568063939256, 0.008676980289497545, 0.021488912270537446, 0.019857366336509585, 0.03870079440197774, 0.0020756931168892023, 0.019719384544129883, 0.004743110330309719, 0.03376848603199635, 0.036197149460869174, 0.03623075390766774, 0.0432221073258136, 0.01223303982988, 0.034118365829012225, 0.041697222007704635, 0.021081699657120874, 0.03428386391273566, 0.026203439737270986, 0.01217565018617149, 0.08615654294512101, 0.0828797412770135, 0.0251720597235752, 0.04080102313309908, 0.021776690846309066, 0.029975044408014843, 0.01632129813411406, 0.030269277548151355, 0.028498233295977116, 0.033933305580701144, 0.022240868170878718, 0.035303288139402866, 0.0733819202120815, 0.016637429295639907, 0.012108531198464334, 0.023743928410112858, 0.017897884427968944, 0.0032925538585654324, 0.021223808638751507, 0.07713468026901994, 0.047352071784968884, 0.02740332204848528, 0.03228577505797148, 0.037785589761499844, 0.02074712761012571, 0.019752271440146223, 0.04763062058814934, 0.03830597862335188, 0.09183949764285769, 0.07310667248176676, 0.0592612943478993, 0.03520235266270382, 0.04609356913715601, 0.06622864119708538, 0.029379076923110654, 0.05352033508409347, 0.05267147081238883, 0.018732401076704264, 0.050120199498321326, 0.02778701494181795, 0.01294516826913293, 0.08538269411240305, 0.034325532748230865, 0.02012241229281894, 0.015049514859648687, 0.06726101865725857, 0.01930663169228605, 0.017097917086045657, 0.04034957682181682, 0.07419343452368464, 0.031034634515110935, 0.05604034968252693, 0.05721749258892877, 0.052200445373143466, 0.03561209960441504, 0.042451430644307814, 0.01579065660813025, 0.0763029388285109, 0.08345484041741916, 0.04649076657369733, 0.03357591100835374, 0.012950834884707416, 0.03977805016828435, 0.015006280304597957, 0.05388435894357307, 0.030762959271669388, 0.015229345299303532, 0.01664296444505453, 0.037631372322461436, 0.04882693889417818, 0.019625539758375714, 0.04887450419898544, 0.05165970046073198, 0.02397299843973347, 0.04669204720162919, 0.016809456582580293, 0.07065290664987904, 0.0321700950153172, 0.011793143032783908, 0.03960536639871342, 0.008470816753937729, 0.04692188058314579, 0.04544052667915821, 0.020510888858033077, 0.042790101042815616, 0.02153002131464226, 0.0010426125248029295, 0.03701608694557633, 0.007237352896481752, 0.004087155260744372, 0.029649164394608567, 0.010663219378329813, 0.028510192475680794, 0.04615611649517502, 0.010786427767015994, 0.04698567644559911, 0.06469930468925408, 0.0352719432142164, 0.026020464287804704, 0.036719061633838077, 0.03493511503828423, 0.07410021059747253, 0.01776867439704282, 0.008220830882367278, 0.03398085052945784, 0.018338145089468787, 0.028211564124960984, 0.034948828231011114, 0.01049863307603768, 0.03090144826897553, 0.05936839431524277, 0.05722362654549735, 0.050934034399688244, 0.03492036707965391, 0.026270623185804913, 0.02208640137022095, 0.046359093460653505, 0.028996413706668785, 0.015819175434964042, 0.03893030208668538, 0.020882585252236043, 0.017444263411951915, 0.02854849917015859, 0.027297721643533026, 0.035114166859005175, 0.05328296657119479, 0.04479342479524868, 0.09656132105737925, 0.011095871117764285, 0.08231632650962897, 0.021915205288678408, 0.015173026892755712, 0.07740903911846024, 0.030286373237946203, 0.02543670534422355, 0.029539435104067837, 0.06523827862526689, 0.014471233390005571, 0.011468473356217146, 0.07013401056506804, 0.021548438451385925, 0.05016331022073116, 0.013801090153200286, 0.02930674169744764, 0.02590826852247119, 0.00864864805979388, 0.044485922902822495, 0.022339101381865994, 0.0338848310389689, 0.01612453654940639, 0.10044928600213357, 0.07713306535567556, 0.03898978925177029, 0.04846477422064968, 0.019332117467586483, 0.03382710127958229, 0.04181931759896023, 0.050446459491338046, 0.051584233795957904, 0.012119607434474995, 0.01645994828348713, 0.016654876127306904, 0.003178019479881706, 0.012313778711748975, 0.04778831212648323, 0.09713841509073973, 0.05604849210275071, 0.04803822335920163, 0.031177079371575798, 0.025156794381993156, 0.04886467222656522, 0.05850170832127333, 0.03301147843844124, 0.012180764643874551, 0.11877068824001721, 0.011003378313034773, 0.06378698042993035, 0.02276568956274007, 0.04411554456289325, 0.017926774752725447, 0.04712251660280994, 0.03347217318202768, 0.026678244616570215, 0.09185601997056178, 0.0300936455439244, 0.015622273054240006, 0.03769285438050117, 0.05729604658803769, 0.07379881212753908, 0.015476645868537682, 0.04341316243101444, 0.04418809013441205, 0.060140791083020825, 0.07627144123294524, 0.10854506372873272, 0.06304306856223515, 0.052056511132312674, 0.017600285754139935, 0.038681520614773035, 0.05180463554071529, 0.008548474238653268, 0.027103937131219676, 0.07534404671085732, 0.029398130186434304, 0.07269230471657855, 0.06363825233919279, 0.0316354297766728, 0.04131396507312145, 0.026328018766694834, 0.053671068245811124, 0.05493074475920626, 0.07497609752629485, 0.030380024641220058, 0.023470346483268907, 0.010335711729047554, 0.05392366647720337, 0.0023412081105301952, 0.06002961312021528, 0.03832171724310943, 0.06820379556821925, 0.07535146309861115, 0.02763924528179424, 0.04018092355025666, 0.03013495136318462, 0.04456738442448633, 0.06504628714174032, 0.017330539246488894, 0.018949876639193723, 0.017121989812169756, 0.05659087906990733, 0.03609840225960527, 0.028877860068210533, 0.028473093573536192, 0.019238311697595885, 0.05404799784134541, 0.01701950218661555, 0.042208457432155094, 0.025211696346689547, 0.058192988458488665, 0.02522884971196098, 0.03878038316699011, 0.026990228232794573, 0.003921012144668826, 0.06499009765684605, 0.07283709730420794, 0.05149562390787261, 0.023979366490883485, 0.0472576841711998, 0.027505833422765136, 0.02019627422227391, 0.05577342079154082, 0.04651690713529076, 0.027627455735845224, 0.03880103098760758, 0.033250427937933376, 0.02964219923264214, 0.023290568630078008, 0.09049654113394873, 0.015444422240502067, 0.023400074004062583, 0.07151193198348794, 0.04194364557042718, 0.012287738234070795, 0.012622498574533632, 0.06288620483662401, 0.023320003479186977, 0.008116703746574265, 0.0123643957278026, 0.020685591269284487, 0.026016783235328536, 0.11607592712555613, 0.03161215602553316, 0.040712711800421984, 0.021095375530421734, 0.02330561344777899, 0.04500402170898659, 0.11784391797014646, 0.032844789525760074, 0.02718790414343987, 0.04158256655292852, 0.020119319869471446, 0.0361208278419716, 0.02250314740064953, 0.03812900651246309, 0.01983853698974209, 0.020942428648205738, 0.0678805618413857, 0.029502193709569316, 0.0059010434862492335, 0.0163365889207593, 0.07791921602828161, 0.013137459156236478, 0.04747979582420417, 0.021835940524137447, 0.03280194343200751, 0.054118551912584474, 0.023038852494210005, 0.03032947038965566, 0.015825952303462794, 0.05521505093201995, 0.019818513421341777, 0.01923069344567401, 0.0513236322440207, 0.0187396614014038, 0.022022720858720795, 0.03951835446059704, 0.006883769994601607, 0.05593993328511715, 0.07846522637243782, 0.12476973847619124, 0.16539344005286694, 0.1560891100338527, 0.12151078906442438, 0.03847353606085692, 0.08582343653376613, 0.1843844410032034, 0.1420819487954889, 0.12971604163093226, 0.09541798276560647, 0.14805448188313416, 0.07988067077738897, 0.12195073759981565, 0.24900628413472856, 0.1614134521888835, 0.12449634314647742, 0.08308903540351562, 0.17934171802231244, 0.11057059932500124, 0.12589622874345097, 0.18109882516520365, 0.17078601568937302, 0.1603566338973386, 0.1075225860944816, 0.20372562030596392, 0.08669101140861, 0.12729920846010956, 0.07353480093713317, 0.09794348331966571, 0.09874213939266545, 0.1707839665136167, 0.0706632271675127, 0.12930247453706606, 0.11732916773429938, 0.10626431754125015, 0.07777747006288596, 0.10630929762763636, 0.20336166769266129, 0.10942781743194376, 0.08140847379607813, 0.1320926919579506, 0.30518075983439175, 0.08049421571195126, 0.15569750033318996, 0.11965974553355149, 0.261217254613127, 0.13884798304310866, 0.09253965757255044, 0.12501407893640654, 0.10230653812842709, 0.16281142431710446, 0.0719824078093682, 0.09395742256726537, 0.1385041829198599, 0.1812728965388877, 0.10717721855533974, 0.11540282038705689, 0.08663079821105514, 0.15285143948027066, 0.13508296864373343, 0.13691167480179242, 0.1714853953037943, 0.26328238951308386, 0.08894629896219287, 0.14463877731135913, 0.07418166872646127, 0.1007944635514702, 0.07524916037384953, 0.2181498905909913, 0.18568147426205023, 0.06975852964179856, 0.18322870587663992, 0.23809880656855448, 0.09209243514175926, 0.12151076192302362, 0.13661253585347108, 0.21746098755725793, 0.10060092500810112, 0.2087851438139166, 0.11913796567491122, 0.16167132263737066, 0.20439294592610427, 0.13885878532060555, 0.10810064364756856, 0.14028802434248583, 0.1724059366221939, 0.08403922870223011, 0.1307660202894892, 0.10444344846265656, 0.08611355096633945, 0.09225427252905709, 0.12589218467473984, 0.2059608232229948, 0.14410985926432268, 0.15144902973302773, 0.18127582781016827, 0.15549327486327716, 0.13353631592222623, 0.1370381401585681, 0.11489853316119739, 0.11899323415543352, 0.1655511451619012, 0.14954793745917933, 0.1279823982289859, 0.11986273606973034, 0.16983533384544508, 0.05959701990442617, 0.17024043282227858, 0.18501161092094012, 0.0583444849721023, 0.1765705267233508, 0.17040410903947695, 0.15383036195167474, 0.07832124802683081, 0.12606403045356274, 0.18678475863167218, 0.07843885850161314, 0.16798244469932147, 0.09560639836958476, 0.15673210338822433, 0.11858899013272353, 0.21194627561739512, 0.1035468051476138, 0.1162150539457798, 0.16500462591648102, 0.15528121909924916, 0.07885819992848805, 0.20323641012821878, 0.1064807769975492, 0.13280440733901092, 0.11787101865879127, 0.11321100978446857, 0.11161723280591623, 0.09989419007407767, 0.09934674802103213, 0.10154134740254708, 0.0984237775472658, 0.18476390492703232, 0.1290603732424123, 0.12838155323905603, 0.07830103446862527, 0.09370398295245, 0.13298396127564566, 0.1710481337670769, 0.21575399701084408, 0.08410127394433532, 0.11346567076231752, 0.08781478753579514, 0.1388629786670208, 0.1150267491383212, 0.12400683441332408, 0.10941995999642781, 0.18887258374265262, 0.12252149411610194, 0.2753423995205334, 0.1180770897439548, 0.06243911811283656, 0.1615939832159451, 0.08350736581321273, 0.09306394122540951, 0.07174832001328468, 0.09785305495773043, 0.15331823086099966, 0.1313341169485024, 0.10811405149953705, 0.06806323025375605, 0.07317133008369378, 0.0760163799194353, 0.08468095319611685, 0.15491381952805178, 0.18981322326830455, 0.11622086220553943, 0.26689235866069794, 0.07482715908970151, 0.16604480652936868, 0.10718080122023821], [0.026975268231970922, 0.031629431527107954, 0.04227436353851642, 0.04525214500193085, 0.04889570502564311, 0.01803244979652975, 0.10087226437670843, 0.022836270775379877, 0.025777039849864583, 0.042964511684009006, 0.005616897193249315, 0.03068732636581574, 0.10177842075271265, 0.052701472238238366, 0.029729543652917658, 0.06754129433206149, 0.057517405067171366, 0.038682022730686834, 0.025479800799595456, 0.06469644805682556, 0.059235231817833016, 0.009864109535036343, 0.05635744945279189, 0.02285957845327045, 0.030135643468903642, 0.02649343542621604, 0.09355139399745635, 0.029380054013537507, 0.00961766900893833, 0.033843884843268564, 0.06490178632416896, 0.04714091847251568, 0.05168025328644684, 0.030697619742048637, 0.03510346636176109, 0.03011142655408808, 0.06834262383303472, 0.021941132111740962, 0.04726713955668466, 0.034322876283632855, 0.022692353497924547, 0.07462752051651478, 0.026421877123149376, 0.04854742317859616, 0.027190024565373148, 0.059561939643962045, 0.011814426979981363, 0.05420208975140538, 0.007909790429818844, 0.0472402118944696, 0.03199259025443878, 0.038124036243451495, 0.006664856361957001, 0.035272530147007534, 0.021173720880012428, 0.006838042671526117, 0.022792968366827284, 0.030943320664976324, 0.03700745937281421, 0.032388807207878144, 0.041836966294795275, 0.0760836498811841, 0.05253701570576855, 0.005741209049509572, 0.01953282642976514, 0.03899778578696506, 0.027299002378380725, 0.043970246466674974, 0.020034272290234054, 0.007661656110680529, 0.0366407790487366, 0.05976075040442603, 0.021222729768071855, 0.023311764367723038, 0.024951610481366515, 0.019231499206008654, 0.030070643206792216, 0.014936530297355992, 0.03566420430849705, 0.05943064311785357, 0.010120788306396986, 0.064761994539627, 0.08251226028161389, 0.022717610267656188, 0.030291499570012093, 0.020399676968476603, 0.012522833654657006, 0.04502874752506614, 0.019924950120704513, 0.023584404827228615, 0.010933962484289492, 0.05516712261097772, 0.04002918615671141, 0.15883824894470827, 0.045513587937291176, 0.012461924110539258, 0.021818832959979773, 0.06313645533685174, 0.013323457479210836, 0.06967578229627439, 0.015177423799676555, 0.031853792523699145, 0.04317559714296034, 0.03173687415463584, 0.04190892154084785, 0.03906157825674329, 0.050398850081754584, 0.018655584127243077, 0.05697945571903672, 0.06359836126544646, 0.04948142323909061, 0.013650131378588932, 0.043429861177823374, 0.010793939997841204, 0.06964496323572737, 0.044781482578920465, 0.006502925676094102, 0.0320510155122195, 0.012192602535443646, 0.048881961298840385, 0.05680371854188187, 0.04200577902208481, 0.03738271298685244, 0.11634682544640132, 0.02566989917042, 0.023193125912387456, 0.03840394890201943, 0.03307843966675656, 0.016227205683078085, 0.01603910729422101, 0.04403410339727998, 0.0584468012675643, 0.04107375010581953, 0.08143817327384438, 0.025852133320378404, 0.04498852396916066, 0.0152024770089026, 0.031306835623191934, 0.03047736727499536, 0.05615791265985795, 0.014895880960726311, 0.05138215928205422, 0.04835013572924903, 0.008855774266911405, 0.004271623911336064, 0.03610497387126088, 0.031515709057982476, 0.048079240801078935, 0.028168489025639634, 0.0362769112523113, 0.05600389878132513, 0.009504181482563061, 0.04571462089994124, 0.06612572779080697, 0.0296017551528556, 0.027121261826583316, 0.035937809984066656, 0.04758352686518005, 0.038826967988695414, 0.018244883843830655, 0.05793160998395511, 0.0209733732377312, 0.04610051394307187, 0.03380373253354004, 0.023591758450493217, 0.0884919451283557, 0.013492613714853567, 0.022072489706001112, 0.05214725501303162, 0.048567063374710936, 0.039915433153510094, 0.06125913893005677, 0.04935056097539408, 0.047109587118029594, 0.06663598612483058, 0.019506015814840794, 0.019183345272072723, 0.05211897028077926, 0.07057535009724752, 0.026212374347129037, 0.02003491180948913, 0.0391749343169587, 0.08756123935537678, 0.022176593941237246, 0.010258429134929819, 0.10203232177134071, 0.01774965675680765, 0.031779282593301365, 0.016872867376410534, 0.01936884656814592, 0.03909697403599109, 0.024390458628269177, 0.037486851148839505, 0.012384313275106251, 0.024396026008097187, 0.06783968689186232, 0.05708210449665785, 0.016335291222536137, 0.07474629807152919, 0.0300519767084292, 0.022019479157669202, 0.05086449134562697, 0.045075549477977414, 0.005100385310860085, 0.003829763179445373, 0.05905119955007519, 0.04381100108314838, 0.08104264842612402, 0.08423252297299248, 0.03205135138705373, 0.029702660095478808, 0.046319996272878985, 0.008205232210457325, 0.005244431509968958, 0.01712092281585293, 0.05740283442927258, 0.07278537257973637, 0.029537114514304057, 0.03080913357968841, 0.05160455931244152, 0.03715858608484268, 0.047678542123841386, 0.025206039060971568, 0.022772227247644748, 0.019828007822590213, 0.024163310549088886, 0.06572545998330627, 0.06257197526948792, 0.02001063382652189, 0.03427361464127898, 0.008957762321058129, 0.034951640758663416, 0.020098275105868067, 0.05278397531115583, 0.019547939100967984, 0.028926239615040164, 0.009831680650157588, 0.09163061742271696, 0.03871436170967562, 0.04466472366558654, 0.011310784362389572, 0.024936899842162217, 0.038392746288861544, 0.08149859681725502, 0.0497045289458973, 0.041670748963952065, 0.021935707224266868, 0.05983599315264395, 0.009629515382195157, 0.05390153605757015, 0.03324324903743608, 0.06372075541211025, 0.0617582964311753, 0.004124993341974914, 0.06875945468034063, 0.031077487394213676, 0.03646007499524525, 0.03141445466982467, 0.042899579275399446, 0.040538542039160214, 0.08734883753848927, 0.009631818160414696, 0.06744928498353277, 0.06658566596784762, 0.03824355000896113, 0.06173868676913636, 0.019064011318343024, 0.06697443939213242, 0.024735100134941082, 0.0815426812374166, 0.01609940191597811, 0.008966900491421776, 0.04988782839583499, 0.055200693131025345, 0.054459234167422564, 0.01575469594847943, 0.030902133589344363, 0.02051343166801546, 0.07238277061177151, 0.02776336290740541, 0.046112924348562956, 0.08344487273799521, 0.040512170775660446, 0.058760616928339005, 0.042962187701570134, 0.09455275562192712, 0.02543423886943076, 0.034884418294365914, 0.023109674586781433, 0.017825917307553545, 0.037200848638479195, 0.06002419162541628, 0.052411239062036784, 0.02636701756689165, 0.03939217748120427, 0.02181117738863187, 0.018666011514142156, 0.010885679628700018, 0.02758316945151559, 0.02487920400952654, 0.02993074624932238, 0.03425269201397896, 0.01974294158363981, 0.01732898540129619, 0.06665710891996111, 0.014238019207758563, 0.022436109837144613, 0.03651684462758047, 0.03138244138764484, 0.022916010514433895, 0.009274091954076929, 0.07010505069047213, 0.04600428071405206, 0.0026307345501014163, 0.039673433639109135, 0.036475993426782746, 0.004237378673029265, 0.022051780817231963, 0.03380349843895861, 0.01497770719496267, 0.003308933905957799, 0.03786341772813882, 0.05578741557630045, 0.057141327033085484, 0.021425382733078938, 0.02056207075448973, 0.07046607881784439, 0.02959152963012457, 0.005812406032678804, 0.06189057004771062, 0.020680987409182956, 0.0420657275909824, 0.006810940286543752, 0.01158671741307314, 0.013209068349429538, 0.07144409883767366, 0.041071731464139054, 0.06536133773624897, 0.04333505626501782, 0.029362724229161228, 0.10570986622146197, 0.02612762532329985, 0.03429981627102409, 0.03345912156094398, 0.07818854014788355, 0.03587085893377662, 0.05473310786432453, 0.07009752573711531, 0.03892248197059546, 0.012121961102820933, 0.017551147944426963, 0.007221246171476585, 0.12733807494597776, 0.09628280278827463, 0.21445400533931597, 0.09177761524915695, 0.11488127123032298, 0.13999010675719806, 0.24737419028367313, 0.20909682208938257, 0.06882589682936668, 0.15989176955606255, 0.10283398375447307, 0.13140700518020562, 0.3027107838009085, 0.1259469831628459, 0.12659397987382753, 0.22337098685758455, 0.11264799535274506, 0.1483699870961053, 0.1015204553093229, 0.19125843500452383, 0.1708862760237285, 0.12544988840818405, 0.18071462506694452, 0.08423708951366798, 0.14735219813883305, 0.1298984047025442, 0.1922472912286009, 0.13259243299918516, 0.09637662382530314, 0.08374285139143467, 0.13366913236677647, 0.1412383397775037, 0.17830813276980603, 0.25957750688706127, 0.10857191335942064, 0.10942605324089527, 0.12712230081004755, 0.0473511116579175, 0.06815734984619276, 0.10704343180571284, 0.12294751911291055, 0.13200639587427887, 0.17361309113247053, 0.09791268461516925, 0.09178634120949677, 0.11117379660052912, 0.14907776697405747, 0.07530435919761658, 0.13551253559333937, 0.16875319262700422, 0.17172548813479288, 0.14288104591625078, 0.06363274263484137, 0.1512378424938236, 0.10557045441653047, 0.19479057618549891, 0.11145150062761136, 0.11619382937039648, 0.17686473950743675, 0.14287382630365236, 0.1180281402277095, 0.29082914707916124, 0.10875402537307569, 0.2147112786769867, 0.05537849644731198, 0.10663758644035884, 0.11119892953761987, 0.2000883197677987, 0.11695274364735399, 0.09428324151251997, 0.09388538928968565, 0.15383668589804853, 0.09439569512116057, 0.11012404864387852, 0.20412237330206803, 0.09505928201334816, 0.12098447659185954, 0.1134544342224087, 0.1099536685006959, 0.19361205585300922, 0.1059871699128832, 0.1327042012874569, 0.19254162614899023, 0.08412103966942855, 0.2212303038686514, 0.08209705791835274, 0.135675492563418, 0.2381377544786249, 0.1182245354035071, 0.0911277144082955, 0.1327289678156376, 0.19736719078251294, 0.12315521868211882, 0.27933014982513016, 0.12424836573856217, 0.12943370320967265, 0.10573290927069527, 0.12720884116632597, 0.1602148472198418, 0.2595199671174799, 0.12616053170391492, 0.13392470936690057, 0.20672570860811643, 0.07849873243165867, 0.17651245769645485, 0.14010009728372097, 0.2516798478152071, 0.11093796496944767, 0.13800512041364396, 0.18977768160402775, 0.17058472149074078, 0.1754757376121623, 0.13824704528919288, 0.07863762176462583, 0.13748533544795855, 0.1258296508874212, 0.21247638788606438, 0.11688132105129105, 0.09603504251156535, 0.11363077868840524, 0.11309395570840154, 0.14346367679536343, 0.09482604917138815, 0.18126548693648406, 0.15194024837442807, 0.09577698885862317, 0.08713351123567138, 0.17568099445530347, 0.11750716104039124, 0.0818793431722692, 0.19048865059656755, 0.14100431304957184, 0.10811948656503644, 0.11952384854001658, 0.1132051201005067, 0.11945866846612521, 0.10397504895393338, 0.05646208973069276, 0.10112307806100164, 0.10501550098082849, 0.09929431083479098, 0.11926035982157503, 0.12264249048062734, 0.09972547912704093, 0.11040473143969264, 0.15392032212444715, 0.07819537978087153, 0.1293484249285289, 0.0985340259170958, 0.10943827365658113, 0.1454794957701649, 0.11038661455469471, 0.10097814976636853, 0.13677534354584558, 0.13027219607361726, 0.14013048208185605, 0.2257532418838569, 0.09970017655619554, 0.2114290962261813, 0.10458860745919601, 0.11455550656786986, 0.08018297169889722, 0.1439400626612561, 0.1601384984595435, 0.25108395836183, 0.22926371065633638, 0.12332394319985594, 0.1333177869341203, 0.2020798607596329, 0.09538591520062514, 0.15409748761781625, 0.21380841998117311, 0.1385398738618408, 0.1768681728946311, 0.11420246479766709, 0.09052932794604983], [0.057087166367896965, 0.019720912944259386, 0.08300917861717087, 0.010400193760038486, 0.08709869560386453, 0.007488303135947457, 0.01010333129670471, 0.05643313664144703, 0.046076738076018434, 0.014499923546931573, 0.029690049522157227, 0.009359307470731437, 0.018916648779330508, 0.02296193715717111, 0.03889462471540485, 0.014901390665077736, 0.11215757059731654, 0.01037042388426406, 0.017756954400933216, 0.06503515916743449, 0.02338120394519397, 0.033021184881883006, 0.02391744847409427, 0.02883411491555827, 0.03216035125244941, 0.02391038153187505, 0.01236512091210378, 0.01946617054220821, 0.03395377019686358, 0.018498023206900274, 0.0669465312468154, 0.02445352845825255, 0.04879637089158807, 0.02079525949167354, 0.02997575347710933, 0.1023579982242414, 0.0489739231499178, 0.04547969850578478, 0.02456955285742879, 0.0032963364792522043, 0.03310045134276152, 0.0519340016346957, 0.01838456027741943, 0.04985818659354534, 0.029281629116407464, 0.0016412218433937856, 0.024099370497944098, 0.041341683228633234, 0.07485558292163269, 0.010564733413048089, 0.061708763374813964, 0.03091332602447697, 0.03494687405015741, 0.04892834595271519, 0.00598783150780946, 0.01873724072772477, 0.05974395666271448, 0.01655630873782294, 0.037494372709521225, 0.01272894799642797, 0.019254679658583233, 0.013015689261789833, 0.03396281846133726, 0.02792578553115683, 0.05773195105471781, 0.028784140811434815, 0.04421242918553097, 0.03956368738519294, 0.03039809742144176, 0.03369436965190938, 0.03142881586349436, 0.0543966155632266, 0.017563997701342617, 0.05028002502928887, 0.0076822140254080296, 0.031172767281532288, 0.0349172593892685, 0.04478630357022796, 0.08436804677226714, 0.029594230199498788, 0.03304202947765589, 0.10132418905517884, 0.03205746498757175, 0.035202674966837676, 0.01882918900810182, 0.03541533123435719, 0.04620117461308837, 0.026759258305121745, 0.04961631600079792, 0.01695352653041482, 0.047370144565190585, 0.026895976326029216, 0.023696848257843937, 0.03855297554816518, 0.03890180361590215, 0.026040777929925492, 0.02855354407802224, 0.026198043687535182, 0.045435162859835794, 0.014982183829748204, 0.0444310972733157, 0.034259212735508165, 0.018618899131459848, 0.03940618583666427, 0.06948600283690862, 0.036053011659532785, 0.040704162259187014, 0.047018107026815414, 0.03542921066816364, 0.07584515160747937, 0.07886482921562024, 0.07383842500192778, 0.021462965091424327, 0.03238850186711975, 0.031337349342980554, 0.020849861204624176, 0.03205990432096379, 0.021841433265113404, 0.022236652772075365, 0.0506085377585675, 0.016181675983326774, 0.04926444809617741, 0.02274288739343839, 0.04497498719553862, 0.030895266814955642, 0.023333399456792643, 0.05726364654089723, 0.08435242689613785, 0.06983721934791122, 0.040259728607322486, 0.04788852157071233, 0.032752525726599355, 0.04324726401162999, 0.07645937507706028, 0.023488736478611827, 0.01594562891737691, 0.06795076985976525, 0.02212585648521781, 0.017830103868618608, 0.03801275310771806, 0.014682686954204525, 0.02302378901679601, 0.0561076841051025, 0.034152021165937185, 0.02308445344013827, 0.07960053759493999, 0.024339161380859356, 0.02663057074615998, 0.054125228697167974, 0.037417409875031026, 0.07842183405799524, 0.01861483640303569, 0.018127317473824536, 0.05166436538898519, 0.039253132085182836, 0.024911032390913794, 0.025388240980516587, 0.035040199756622314, 0.08054828816758734, 0.016137691647080437, 0.057798976743859906, 0.05820581955569131, 0.0363477978057095, 0.04000110159228955, 0.01862110267393291, 0.05093960517219134, 0.025769648907173957, 0.02287841628172568, 0.09430332614907197, 0.06913130544126034, 0.030090354649083953, 0.036273253948560784, 0.0173967540862837, 0.06637048894273383, 0.004246829393585878, 0.034110002884907384, 0.05456472261409674, 0.011689346682812487, 0.05447314752797995, 0.014165756076441278, 0.07768305191504103, 0.03287465185193079, 0.023068987930725728, 0.020562508409576755, 0.021227679681032896, 0.07516213147235767, 0.08560420186924082, 0.020852940057271292, 0.019852116171802794, 0.018026410834863782, 0.020676605769300034, 0.04225460120609828, 0.029461145733616183, 0.0743254842236638, 0.03408335681472506, 0.04498726189402597, 0.0046850688688989195, 0.01054788114769118, 0.039824706236166615, 0.07689205650240183, 0.013773123484237917, 0.02747530782861369, 0.07448434284222977, 0.012771408173388668, 0.07530614374471561, 0.028349471278488636, 0.06613815176699843, 0.04885430760415537, 0.05493756403614368, 0.013623907696455717, 0.08883244757141386, 0.053240137440817695, 0.028382339514791965, 0.06738041367913995, 0.03292759454676083, 0.06203591224870511, 0.03966700791248253, 0.06685816563133683, 0.03487081366724201, 0.04160666472411581, 0.005972090767629976, 0.010485278658701904, 0.07489071746489831, 0.06653887419296162, 0.05556593156818833, 0.02424291118846408, 0.0808997353804963, 0.05352887783997825, 0.035771273741764684, 0.060615813093526025, 0.03179867512413433, 0.022002911028851355, 0.04237144493630954, 0.04157855301829321, 0.06797396218670265, 0.061918756392385275, 0.030209658068737814, 0.017813262629455755, 0.018166585991691266, 0.01624606047490878, 0.05010146853913154, 0.01859755241977317, 0.03273674300206559, 0.08485791512898036, 0.042410932281719785, 0.05184540192463568, 0.03188715609056609, 0.057195575907826424, 0.02059301364767764, 0.05604457017034292, 0.0380697127298585, 0.043485962453165224, 0.017317913406129395, 0.01542329605269645, 0.12161453706877572, 0.0019459582815345908, 0.010621611610986292, 0.008453949221542903, 0.034752124321780035, 0.0351525617630354, 0.01572223483318729, 0.023911697889811227, 0.04096940838332687, 0.04863667767494917, 0.019258177506604364, 0.03773551726979869, 0.0958089546433517, 0.07295573236686842, 0.010787506637695645, 0.03903485415503383, 0.02608656886565898, 0.036880522434200556, 0.02354892762377858, 0.02286123238237841, 0.06609376879142863, 0.0509225603725229, 0.022812732395582964, 0.029294280401830162, 0.07925129562084164, 0.10391068312206439, 0.09455534084034817, 0.041753774508833885, 0.007471460200447057, 0.04284331515165312, 0.027803737437352538, 0.043621109665504525, 0.13817802470709595, 0.044452216675771136, 0.05116563875760351, 0.057885456031986644, 0.060741918826741834, 0.009770254571256893, 0.07805537086512361, 0.028222286674593176, 0.02047625134166862, 0.028281999452571784, 0.051050118170678616, 0.033863294337477, 0.03555348774950419, 0.005335534590163401, 0.03890280106237956, 0.05707065761089325, 0.07046700162546975, 0.060494002486978254, 0.060599087205316336, 0.03245105601048895, 0.03212079266086221, 0.0435825654837702, 0.007572327823644238, 0.033523497570838244, 0.04882036049717239, 0.01928186177143029, 0.04124088006626282, 0.04313636424818209, 0.06664297503552266, 0.03809029948232429, 0.07021164854190179, 0.0173016200839941, 0.03766038647985884, 0.05663243255444935, 0.034467302462352176, 0.08878871598946196, 0.03753749021728124, 0.008775724098086357, 0.0319160175775843, 0.043051968062562604, 0.02477536440294768, 0.08403505571186543, 0.026114415942824314, 0.037201808765530586, 0.010857644258067012, 0.030156318430921862, 0.04970820999837347, 0.04955493911568608, 0.011474938946776092, 0.046516235385622294, 0.05217704609302538, 0.04963428021541663, 0.02404523018880614, 0.03494215483910271, 0.01861812560153859, 0.05774865658687694, 0.014066511000107442, 0.008114879335542875, 0.010593688198631364, 0.0318410123166229, 0.016678772434326153, 0.012637184616843504, 0.03339173285556691, 0.024601966475269625, 0.03896317371566381, 0.014002238466803516, 0.17619807885161468, 0.10763129418981926, 0.16444222895162447, 0.07654112497610704, 0.1760856048869235, 0.08376465272158384, 0.1309588463710887, 0.19571726503116743, 0.13889795036188193, 0.07318355049937963, 0.22775578871369362, 0.09365838539919683, 0.0875376874048795, 0.12228612388883318, 0.10097865188228232, 0.15334990487567016, 0.30891495517321993, 0.1837735152138131, 0.07708804455718823, 0.10116261629653828, 0.07818233155246292, 0.07204645472977843, 0.11300839922790017, 0.15636838147682802, 0.09366833272257022, 0.13550701231828757, 0.1499678013580186, 0.09087861063224928, 0.26112280253853115, 0.0843943196481892, 0.18705397418567113, 0.1599293468253953, 0.19882321836692946, 0.07795773646129028, 0.15186285467020103, 0.17391119870756352, 0.08925235218235425, 0.17137342345501694, 0.1777460886431592, 0.1106946219557098, 0.1733700263180903, 0.1487531286797353, 0.08119930180587939, 0.156955680676869, 0.11947037998054709, 0.1151520067027637, 0.13194938536201203, 0.20518084721905844, 0.2531044456575598, 0.10091020805495125, 0.22465292949761662, 0.11762821168771811, 0.23230742876018795, 0.15592702158859797, 0.0604022102696555, 0.1043831334848489, 0.12664177588054112, 0.07605203693466527, 0.15258230535047396, 0.21868908165821008, 0.1492895106119769, 0.1118066729977727, 0.15078178553708962, 0.11851592548191547, 0.17658976997647965, 0.13390452973544598, 0.16494503697114332, 0.09647426501448665, 0.14749325199850968, 0.119398333132267, 0.18635568022727966, 0.10794337958629642, 0.10930958270494427, 0.10781785060784646, 0.1343533263674804, 0.17478584391730173, 0.11168610411030905, 0.11833144538104534, 0.27215247069086346, 0.11496688877897603, 0.1000127504978861, 0.20150002544479712, 0.11096874331789357, 0.10692688663090978, 0.1316323330891984, 0.11953851846711976, 0.12231722793408803, 0.1412505805492401, 0.10142269876918622, 0.08189564158341714, 0.2323048503271171, 0.12806165111916407, 0.22315110079944134, 0.18142468482255936, 0.13322245276400022, 0.08931481811617102, 0.09260029824716703, 0.08824000507593155, 0.17840751100863728, 0.19374371878802776, 0.13724650469209465, 0.12721810995468072, 0.11969368585518428, 0.1680136573101793, 0.18579621453370365, 0.1716942890946354, 0.10742971500647919, 0.10755443652825696, 0.1484547225492341, 0.17516682775957243, 0.28070130624941414, 0.15661952085793018, 0.12634395329015596, 0.11000966799578496, 0.15623449294694833, 0.13733094158981526, 0.0933782115046467, 0.1160816132490124, 0.11612999279584203, 0.10525169902082, 0.11755232433123247, 0.17334056432758058, 0.137710215523839, 0.13732418338102953, 0.20670923377786363, 0.11899999236421925, 0.17461863931800636, 0.2995795075382505, 0.14541640558413096, 0.11968300571399075, 0.0995871394074389, 0.1552783828228712, 0.11037788180900471, 0.168154276907444, 0.10846633331051894, 0.12351178883441857, 0.1976203386272703, 0.17275953479111195, 0.1396718466920512, 0.1085860947413104, 0.2863001158194882, 0.09164432383009366, 0.16912783895220074, 0.09221381148589508, 0.1278230103531054, 0.2960062878472464, 0.16426046299082891, 0.06509465990321976, 0.14486679221902574, 0.13023708867175238, 0.13381900718169554, 0.10750164650380611, 0.07584606084440436, 0.1633149515837431, 0.09536337426730565, 0.09703751693346671, 0.08207544657800879, 0.1333021263458899, 0.1310742244656597, 0.14060731578086103, 0.10168677102774382, 0.1508934995425599, 0.14092724504215376, 0.12449493179363863, 0.10056472516485623, 0.12829252944460937, 0.09514396318367549, 0.1918805701924222, 0.11217466289443628, 0.16294295154511929, 0.09721134403454405, 0.1077833471021482, 0.06694365425833634, 0.09927473509950296, 0.10875499567815236, 0.12995461454348906], [0.06158960584018912, 0.03614526188799313, 0.045408021459089856, 0.02566307141179485, 0.02958758394899113, 0.022477028891444206, 0.015134864386969378, 0.03795872814953327, 0.04471545772893088, 0.00926684435190899, 0.023857145370649438, 0.041842123160937, 0.029830679297447205, 0.057883040447320254, 0.07210219638156039, 0.02603263550970171, 0.01273773587308824, 0.04080666515177914, 0.03542343972783003, 0.02425816635202084, 0.006891705885729087, 0.03208953933790326, 0.030962390891675438, 0.042739628215453455, 0.07990781217813492, 0.006278968831923391, 0.015976442888911282, 0.019697483130065457, 0.03956776538065501, 0.07530801650136709, 0.024925098421850374, 0.021219606810648526, 0.06309822667390108, 0.013429681288211473, 0.019303566410339305, 0.08878953701683454, 0.02013056998008064, 0.021488902092512165, 0.035744576781455956, 0.03963253154818501, 0.018703459861821363, 0.021674498383487974, 0.04331878499527063, 0.04993833175727299, 0.0554143298816468, 0.04249386961704918, 0.01797962245265288, 0.02569302703653063, 0.11762553825974464, 0.047932928295007775, 0.0015973383332103758, 0.0054044860465052936, 0.05681370657735637, 0.09227471000381879, 0.01811935656171824, 0.0315003843445863, 0.04674216040543147, 0.060502029556248865, 0.025022561495591487, 0.035493132059595416, 0.025404858303123286, 0.0239878193408783, 0.01807042909786105, 0.0561593952588737, 0.008224388950371316, 0.05055757299331682, 0.029076949028032165, 0.038288211183888574, 0.037701353031609736, 0.07962646441800253, 0.0421217067300209, 0.05315104240019407, 0.04898765330602016, 0.07366573105433158, 0.047517033826027594, 0.039546669726925235, 0.006970036392366248, 0.03134723220552717, 0.05051466922408768, 0.059489560313522816, 0.03708392009139061, 0.031351907311805656, 0.04217941613335695, 0.021810117177665234, 0.023796933869432126, 0.021620234241709113, 0.05403812176414898, 0.0029595842144252466, 0.010787983308546245, 0.028466620349458287, 0.03932958941108414, 0.011258657605919455, 0.02788320915507419, 0.08245999272912741, 0.01758531727162855, 0.02456545959492879, 0.028433792825256075, 0.015866988405053104, 0.0836869061791471, 0.05673442993845258, 0.05349141592159867, 0.002418103515602914, 0.021423289452546408, 0.024716226683397378, 0.055472850134330134, 0.0013768929077611703, 0.05192587957052248, 0.025055363574730496, 0.05769923888146877, 0.04359726933762431, 0.016750135658574954, 0.035581874262009344, 0.008771205903030932, 0.04023774407271828, 0.06652757658490113, 0.031247775935168778, 0.04529351188934275, 0.049714846070855856, 0.00829436457050698, 0.03999524244240352, 0.03473887253286583, 0.03309331315436533, 0.05765465913074357, 0.05947907016213451, 0.02941315634442227, 0.07997828482517175, 0.020682649819978645, 0.04505232661696417, 0.17160476318427495, 0.03515755917344775, 0.009765423401924116, 0.0278737893926778, 0.06517221645585128, 0.01743983257828014, 0.040977187787315676, 0.0824034164792725, 0.032626324998480935, 0.016409789278571094, 0.017214465653523803, 0.04973130393773317, 0.037037101175103865, 0.04424807263006057, 0.025610154162028005, 0.0286151143456144, 0.033792234757649045, 0.016961611275162016, 0.02744363551028073, 0.07028788195124694, 0.04066618126151817, 0.058586993387767246, 0.03277056118739503, 0.039563918087099276, 0.035015765710600784, 0.04499601499576654, 0.06690268431391035, 0.09044075877006565, 0.03422510278012071, 0.05727700689541442, 0.05149514214800937, 0.040230768732726574, 0.12998712994158268, 0.03456077066117099, 0.009320077968628278, 0.049421003088355064, 0.09232270957103797, 0.022602859817977463, 0.010822822689078748, 0.002969938234725435, 0.025281222437375357, 0.007697477670652526, 0.04004001557560904, 0.03514852787234953, 0.02873395975413067, 0.0341859004194183, 0.03066453437453934, 0.04944686205791576, 0.046398082082825046, 0.017369465104171207, 0.03372685790860227, 0.027815952764025757, 0.05296905252284237, 0.04048089370397585, 0.004275606063726757, 0.011231175241326647, 0.037860106477247815, 0.0058133458036796325, 0.015304089324282748, 0.010624491143971682, 0.03445090227095144, 0.02694518707825669, 0.04744131949597171, 0.034408463298210075, 0.013074231566861272, 0.06214595705802951, 0.02646685890587313, 0.011698835995048285, 0.006615859348260398, 0.02195423292661352, 0.032905403058975935, 0.02147595225168126, 0.1130658575732793, 0.04740711793835674, 0.04044957592019013, 0.013708547306513148, 0.031913693595145426, 0.05654612968542746, 0.01261726622137108, 0.034910402792905054, 0.016802969787802016, 0.046736053590263636, 0.02604929354440953, 0.05829494513039078, 0.033329073539269824, 0.04991680523380637, 0.03940474055707455, 0.01895918613964958, 0.020654032605567148, 0.024552553858874098, 0.040596200552369864, 0.10937544131385428, 0.022911030067397014, 0.016672803022499596, 0.0062253811047412455, 0.03036250825971365, 0.09324921521225146, 0.04175544709765485, 0.05007993183763964, 0.021431796585342715, 0.04359558317810297, 0.02266487113333174, 0.04548719971041594, 0.06540654852454152, 0.03601590936471309, 0.04881477276129382, 0.06586633063852787, 0.03859762654506734, 0.014741412463730999, 0.042039383468883376, 0.01831821142695844, 0.053722555483026166, 0.025587011028879454, 0.024928675997736197, 0.011130399220356984, 0.025700066837349107, 0.05956042651087046, 0.03205681359395385, 0.07982576372367994, 0.010429249477705784, 0.05647747890491571, 0.040815190944288454, 0.014807737565466335, 0.032901060434856584, 0.017314398594732796, 0.026442450304914798, 0.006410608442300665, 0.02205496484280697, 0.018954051325895956, 0.01807357241133494, 0.11427348027271883, 0.03214280433686716, 0.04368144499936274, 0.08112145348318986, 0.08454169745423964, 0.04905202592323933, 0.04055647911237819, 0.025791248373155082, 0.02857000194489956, 0.024625306383573582, 0.05158619815483689, 0.008787027643328267, 0.04234382856105055, 0.03899825397612793, 0.0796092635552798, 0.10516651573457889, 0.07428684843970196, 0.03550616671730365, 0.04648605075531772, 0.048923809946115525, 0.03510308298947556, 0.012722505306425904, 0.018624266343457357, 0.013684735816371228, 0.06250038303967033, 0.02653820177407137, 0.10431112056331975, 0.0181648116226175, 0.05381802536015, 0.018105030991137028, 0.06158696633896657, 0.05188763055152126, 0.028552909647779803, 0.015601377568340727, 0.017494985600933433, 0.0367246222283159, 0.05218256597540208, 0.0835894685504692, 0.040188923478126526, 0.0446906979861004, 0.09944379888474941, 0.026380561125863875, 0.03745010169222951, 0.07391936744430236, 0.0070054614334367216, 0.05173225621027606, 0.037144638797534366, 0.03787738197882261, 0.04487656229840858, 0.01664303908390658, 0.03485150256061128, 0.03148030988605959, 0.04687204897137625, 0.0358831675590149, 0.036875453777611256, 0.013991146963754935, 0.024999825483454124, 0.04599453355850918, 0.06055270255144153, 0.029200798632310968, 0.030692449305206537, 0.033339567083333216, 0.07831571796642882, 0.07076968252658844, 0.00480877555673942, 0.04606240402374949, 0.021757803824064986, 0.06855486958686795, 0.052990331381027184, 0.0360270984071706, 0.09468438463019473, 0.0055608493525401825, 0.04283345943050725, 0.010044090948732836, 0.01934098931295531, 0.02479669584759644, 0.0499765332788229, 0.04774839051866105, 0.02614108576173229, 0.016000032158834592, 0.06801508819418293, 0.03638552435274635, 0.03849765119541969, 0.023248981218785048, 0.04508653495992933, 0.043250303848513534, 0.005141971025815499, 0.014557261452344912, 0.015359961594055806, 0.013970789216857935, 0.0039793407112093905, 0.009326885371202869, 0.024432234333029816, 0.009777374948108835, 0.1798320138560874, 0.11288472265005112, 0.12390449776181153, 0.13657995260187558, 0.11146140045353345, 0.13551991805434227, 0.09260310738214425, 0.081468178092369, 0.11187654174864292, 0.05241668430556144, 0.1749169368829046, 0.11254833891455616, 0.15589807528470243, 0.12974243664315768, 0.2893583545727389, 0.16561428963073663, 0.0827159768502627, 0.15928813123277255, 0.09471947167600904, 0.10186395009181329, 0.14774011660899433, 0.11841407737561635, 0.1122424824695502, 0.1892824596060174, 0.14836825004645757, 0.1450450840805258, 0.14505751484206744, 0.11006635281124286, 0.17316462019724504, 0.15879102290741035, 0.10915478851114001, 0.110225218215159, 0.16705017829579966, 0.13947410801691668, 0.08939565199294261, 0.1500610184988805, 0.0941443657502532, 0.1540674827992916, 0.12969852185675076, 0.08437967686248676, 0.1323639295463051, 0.1487565077841282, 0.15107280920658792, 0.20073798990675382, 0.14086343560900005, 0.1277805883437395, 0.0948180899556194, 0.09096787191395249, 0.25547559985092705, 0.07932051976344415, 0.09990598301270179, 0.09561756705599171, 0.12268841373068945, 0.2031359869454588, 0.12392230252070086, 0.09738548326173, 0.13341780299586908, 0.16359681503048965, 0.21909749188593455, 0.10796614443617207, 0.12071542388626508, 0.12729148673159735, 0.16035056779427187, 0.20851757031466278, 0.12136041213359151, 0.08761649924729552, 0.13615267910063267, 0.16820741977010453, 0.27765604108572006, 0.11531002393790654, 0.15295545889862946, 0.16938602152679647, 0.2502109009240355, 0.14256512001156807, 0.11221584318471806, 0.16060571053198405, 0.1026343112545354, 0.11781764509422438, 0.13115377591124602, 0.16371671216828482, 0.09955836273729801, 0.12711122711854322, 0.29353272914886475, 0.07477599754929543, 0.1444470640271902, 0.19142930369291986, 0.2290918513068131, 0.15439535092030252, 0.0869116031431726, 0.09299113441790853, 0.08068886026740074, 0.07538055868021079, 0.18203318145658287, 0.1415174619427749, 0.15834123561424868, 0.08942571109426872, 0.2104857289897544, 0.278663339891604, 0.20299821719527245, 0.11400442756712437, 0.14731623578284467, 0.11680239385792188, 0.07993756593870265, 0.2370578252843448, 0.17941618045525892, 0.13170798974377768, 0.1224546448460647, 0.10086969272898776, 0.16250368154474668, 0.10631093968238149, 0.1287621706724167, 0.09686122675027166, 0.20144045007015976, 0.1525468858225005, 0.1552158218941518, 0.1395701885755573, 0.20703273213335446, 0.17605550507349627, 0.14946651325694152, 0.1657481917313167, 0.10221564836267914, 0.11618404489542757, 0.15041183467422212, 0.18253030335264547, 0.12585358960287912, 0.13801748332168373, 0.06681450868823699, 0.09503499045968056, 0.17065180146268435, 0.11719673126935959, 0.11628118396869727, 0.07446589347507272, 0.23440643612827572, 0.11443178249256951, 0.10489778194044318, 0.1367068522210632, 0.09930969322366373, 0.09081824137164013, 0.08630036522767373, 0.10508202455405678, 0.1532805993088654, 0.07525638677179813, 0.14479740522801876, 0.10709733462759427, 0.19683554502470152, 0.11210305709391832, 0.10584687601242747, 0.18219343785728725, 0.1606684343091079, 0.14789524328495773, 0.11467658435659749, 0.1619383804500103, 0.14126413767891272, 0.16707271922911915, 0.09474837726780347, 0.11916653199919633, 0.12281262635120324, 0.1032970431925995, 0.20552231318184308, 0.09586121541048799, 0.20696679210024221, 0.11957426369190216, 0.17649629499231065, 0.14648900660020964, 0.1636420597455331, 0.05401200155860611, 0.10507520527711936, 0.06744332744606904, 0.12926028322960648, 0.11668295812393938, 0.30018739349075724, 0.11933767210159983, 0.049319029453077486, 0.08680824190378189, 0.09957977730248656, 0.09554317926189729], [0.06528374047151633, 0.06709808882858072, 0.002752595834733386, 0.02537138108164072, 0.03223915630951524, 0.057181828788348606, 0.03795764249350343, 0.0499234650550144, 0.011809757810884287, 0.02325026873898293, 0.031025145202875137, 0.029372308536299636, 0.04053389407428248, 0.038147211607013426, 0.008850996532211346, 0.04014685091429523, 0.0387664290943316, 0.07133838308176824, 0.011611895303108861, 0.05837186386010476, 0.027506673109850714, 0.023968995083123446, 0.05391281330958009, 0.016511791751586964, 0.0270858762253608, 0.013539568338144039, 0.055315704816686254, 0.06813229833330427, 0.04558414540120533, 0.06079814902373722, 0.019436639001859084, 0.03219699214345642, 0.05561971903911658, 0.03887567662500909, 0.025612954815317477, 0.12378054298460484, 0.0350127462297678, 0.012736661243252456, 0.019315625673958232, 0.014033192386185485, 0.006130473987598504, 0.012554514454677701, 0.019314643494518738, 0.004011916753370315, 0.012368481356783636, 0.09384562713759285, 0.08767292621944632, 0.0534837722246136, 0.03923525608011654, 0.05512336049494999, 0.04576158570125699, 0.01822562362732632, 0.011846201926735895, 0.013635394446152662, 0.022657695625509535, 0.016972159102026905, 0.012162013328634202, 0.027380239983488406, 0.0290893322921225, 0.006033867988402822, 0.036286953570587296, 0.0313354189108525, 0.03552860587037035, 0.027201941336638162, 0.029869148840329478, 0.052307701403541226, 0.02702698447475476, 0.02117741889586406, 0.015652469558907405, 0.043011859857610295, 0.042514198526207886, 0.05727910356862204, 0.07124945428222418, 0.04533816288624491, 0.031890104325222116, 0.033560057037643025, 0.06390494374292237, 0.024662982040484036, 0.04699280106329492, 0.08179481127964598, 0.0020501808363146013, 0.008453858467484159, 0.016209402620526295, 0.02369682620545583, 0.03156049915456346, 0.06527751830539533, 0.01532635884359479, 0.04333575515608702, 0.01185252926578479, 0.05907895841768809, 0.05609432714326041, 0.05697610375604459, 0.08111439671899591, 0.03897268677662526, 0.023123314836993814, 0.03529479627364448, 0.06105421456907477, 0.0403172039160771, 0.06869704981467553, 0.028480336934860264, 0.0008265965017406935, 0.05403129570186138, 0.05386703594454697, 0.07971166127494403, 0.017811115066121732, 0.022880429834393517, 0.08842232743544237, 0.05408851316730891, 0.016899786556937864, 0.032714921315865855, 0.042110412514635494, 0.03121295691068683, 0.014840259748910154, 0.020861252111249735, 0.012640865669319672, 0.02067416813224554, 0.04629767925611564, 0.03336137859150767, 0.04490376476730619, 0.019063057976641824, 0.01845552146966968, 0.04873345033930881, 0.06592014525085688, 0.030654417417411293, 0.02169207244047097, 0.04702221555635333, 0.02223288011737168, 0.06524512504360505, 0.02256117232276925, 0.03849826187693647, 0.01904530410787889, 0.028867125644215515, 0.07611313222774438, 0.02704572561196983, 0.05221127818471619, 0.02472877618856728, 0.05037523027775543, 0.06630667950958014, 0.01991392223031393, 0.02458139498984175, 0.007822630062167133, 0.012703497844216014, 0.0238245824751045, 0.03732373472303152, 0.06417546886950731, 0.05475542148841279, 0.014251550892367959, 0.021134715294465423, 0.040198687597044876, 0.03427492082118988, 0.02395527171237128, 0.039892295109374185, 0.043544112904263396, 0.0258230682728546, 0.0459998973778316, 0.03803746196042214, 0.032140996041042466, 0.025025072075160484, 0.032114092127553055, 0.021307310854483928, 0.026111749300201024, 0.01547754492743739, 0.026787607498200874, 0.02294517225319786, 0.01786784059368074, 0.02091743820346892, 0.06762212820883308, 0.0341133582405746, 0.08422604974891458, 0.017694951567266668, 0.036799315363168716, 0.018540550389194062, 0.01800478931649455, 0.032648753973522356, 0.03649767262062856, 0.05156516356925879, 0.05518561608291098, 0.05261783261916467, 0.04382286526794944, 0.00966811045405588, 0.04746066113667829, 0.10256090055086783, 0.026784973085990975, 0.018629348570747033, 0.06488683819770813, 0.0025879753936481264, 0.023920778384698287, 0.0422584586776793, 0.051996345432209115, 0.01787229347974062, 0.02616982680878469, 0.031108974811754057, 0.098588647986097, 0.014199069601350596, 0.030084692274353335, 0.018695743222321783, 0.0608858157481466, 0.07053256167897157, 0.02768395734684808, 0.0957571417093277, 0.01925328526911991, 0.029432145146919147, 0.021563121949189475, 0.031846925749310424, 0.059491412714123726, 0.041898363535957675, 0.03545672187049474, 0.049986609523849826, 0.03805518868778433, 0.013839569025939065, 0.008556501307923878, 0.047711542674473355, 0.0268672675093902, 0.03969370487279125, 0.022274596450318183, 0.014155879999244851, 0.06036436837166548, 0.011350990106750811, 0.019585696182080677, 0.07501100136765412, 0.03398963077259915, 0.03896628479872431, 0.1022258128172585, 0.02750504801848105, 0.02407986091982041, 0.009566957846150866, 0.04273078690416046, 0.0411756796363209, 0.03260205040818878, 0.07975732668169908, 0.026946484776479856, 0.034724284029964886, 0.02494118648714253, 0.03720645673040833, 0.015989297734839574, 0.03622770050008382, 0.043665200871016295, 0.05557001634900059, 0.015536870940455368, 0.032772522153598924, 0.02168530914267259, 0.04513136916128652, 0.01871240634604224, 0.01875340852088162, 0.021605925634503365, 0.0601841766121132, 0.010548022791876324, 0.006435644264066858, 0.05488077744043299, 0.0286948863150818, 0.050202529544809034, 0.02120709971391729, 0.028271125928897942, 0.03986895350473268, 0.05782837766621794, 0.030209658068737814, 0.012961134198121727, 0.05595690683860864, 0.007605230834867273, 0.03020340876121606, 0.026958372710006576, 0.04044062604329415, 0.03730313100719026, 0.03495619712131364, 0.022117912536486983, 0.12555857614747115, 0.030592212719576697, 0.020619103319144676, 0.0955503988744957, 0.07494778904531683, 0.04119713830628565, 0.10342394959713731, 0.06092871951737574, 0.015035060367413929, 0.058667677986834726, 0.07428650238684245, 0.010062419875924076, 0.011829510813445916, 0.06384981955800738, 0.004534816618875733, 0.011495371332525142, 0.02879833576402494, 0.014443347297076668, 0.012276880825603647, 0.02038715630104499, 0.03890289605728217, 0.03698072170040437, 0.0315741818132145, 0.012902736929910523, 0.04097777132743171, 0.054050050409776826, 0.059219550873552046, 0.02846114457185779, 0.021832169565771307, 0.0679435706032174, 0.06434557759868247, 0.04087572644597717, 0.031368032696523836, 0.021364658937922547, 0.024675750373197452, 0.028463763717029775, 0.03064630553126335, 0.021550574140357118, 0.05566095021952476, 0.029360410424747636, 0.014698917511850595, 0.030231690100793327, 0.02790931409357914, 0.04491839058963316, 0.029889979865401983, 0.04924935408468757, 0.011306018502052342, 0.01795474057351904, 0.029354653055114404, 0.04467080673202872, 0.07906110225511448, 0.01933218532108835, 0.04676049442163535, 0.06864679072584425, 0.02575145907966154, 0.024446151086262295, 0.012425168716747845, 0.03307844305943165, 0.02861512791631477, 0.09266496263444424, 0.015343476585777742, 0.02820710275721337, 0.04948407291833844, 0.03060873504728079, 0.04428276273288897, 0.03389173513278365, 0.04673209773110492, 0.025443110714799592, 0.04631404552076544, 0.030229257552751472, 0.034143264671521525, 0.008929500489362648, 0.005972640380995082, 0.037264060960816484, 0.008610437208387469, 0.008067850921569126, 0.019528733167265142, 0.02437922208836036, 0.032844263661120615, 0.010404162341728806, 0.011773884512617119, 0.037888995105666776, 0.0079391811741516, 0.012361786760655897, 0.03349136893770524, 0.01857266036261405, 0.0721006357510175, 0.19820927988205636, 0.1255123679127012, 0.17296065257063933, 0.11900263865079198, 0.2701913687799658, 0.13841454844389642, 0.10590497218072414, 0.1379304544201919, 0.14271424843796662, 0.13631699314074858, 0.18929472751915455, 0.05755420880658286, 0.15039093579564775, 0.11542878113687038, 0.08125016479087727, 0.15400625179920877, 0.156721830368042, 0.1512630432844162, 0.06649660146129982, 0.17928963367428097, 0.0769603985494801, 0.07759972781475101, 0.11510639557881014, 0.15728748430098805, 0.10614372829773597, 0.08481584595782415, 0.15415183827280998, 0.09468554492507662, 0.11467510515025683, 0.10105820332786866, 0.17194369142608984, 0.15756643004715443, 0.208567062658923, 0.09100779691444975, 0.12325956379728657, 0.1546462188873972, 0.21839387821299688, 0.059182848914393356, 0.1659990054156099, 0.07509348408452102, 0.10740873470370259, 0.10371816238122326, 0.09077620612723486, 0.08690031232046229, 0.15496545604297093, 0.29336483244385037, 0.19678869896701404, 0.12592731921800546, 0.1146701518446207, 0.13728083856403828, 0.13548635771231993, 0.09409335348755121, 0.16623143080089772, 0.18981705020580972, 0.08709107565560512, 0.08887797727116517, 0.11406124808958598, 0.049762377448912175, 0.13648457771965436, 0.12184727458017212, 0.1146801941628967, 0.27603222536189215, 0.08420076074876956, 0.16760729625821114, 0.11881684219198567, 0.23816758287804468, 0.1461220412914242, 0.13100889511406422, 0.11833444450582777, 0.14945999932076248, 0.11367630838815655, 0.08428226637520961, 0.2755054921976158, 0.15637811166899546, 0.13175840489566326, 0.09245702557797943, 0.15741039413426602, 0.08260266150214843, 0.14148700929113797, 0.12601421241249355, 0.059020502625831535, 0.0942739387974143, 0.1185807255761964, 0.05743564159742423, 0.17936501891485282, 0.14462737792304584, 0.1671468966773578, 0.07225788624158927, 0.08040735644421407, 0.2623510866292885, 0.16716322222990648, 0.135173553068723, 0.24796386435627937, 0.13918062805065087, 0.1431053831641163, 0.15115267277828284, 0.20045660143452032, 0.0744975810604436, 0.15843267499336175, 0.11376903698380504, 0.10778883645044905, 0.16128048646662915, 0.31239695261631695, 0.09108219149389438, 0.07872803655586072, 0.11798997941826071, 0.08404839571033206, 0.09495999876941953, 0.1514657081237861, 0.09949829203209706, 0.09420146447207246, 0.0865549583520208, 0.12276515604129859, 0.12558332910495146, 0.1458773479929992, 0.13552204865430081, 0.1262234861829451, 0.06514698852385793, 0.1631838721888406, 0.14966756318296703, 0.07683640984552247, 0.14510308525391988, 0.10240120054887873, 0.08687534223177604, 0.08682211115956306, 0.12462891531842095, 0.11607826128602028, 0.13767746942383902, 0.10053542602275099, 0.1380146334746054, 0.06979027829532113, 0.12126974628439971, 0.14957889222673007, 0.04599857423454523, 0.1462435940546649, 0.12848360490586075, 0.1075298192777804, 0.14760241471230984, 0.09433294420263597, 0.17726675793528557, 0.08999080184314932, 0.10222651849367789, 0.13893364130386285, 0.08724677230098418, 0.1252731028944254, 0.2047050991760833, 0.15021419099399022, 0.08510915629033532, 0.15484982010509285, 0.12569870719952242, 0.11094732196735484, 0.1377880706318787, 0.115163297525474, 0.09164080223334686, 0.11528098263910838, 0.11723002019737448, 0.14300966901438578, 0.1343347073665687, 0.15486975546394074, 0.11256760252373559, 0.11305719946644135, 0.10907454495983464, 0.11597923588539873, 0.06950154807418585, 0.12752839044800826, 0.07607624706413064, 0.14793697318860463, 0.13091255671211652, 0.18608784888471874, 0.09574692297194685, 0.09088857831167323, 0.08758494058357817, 0.1108229939958879, 0.08793851839644568, 0.10982421758983817, 0.1930900045803615], [0.035149433716599426, 0.05120133309225951, 0.012524696233283197, 0.06000312989843743, 0.02221509741087045, 0.033520450948604515, 0.03578700896884714, 0.031839852021741014, 0.07947218591081244, 0.08060266596398183, 0.0344650802601661, 0.01970749152159052, 0.033370050269046, 0.0496006621979177, 0.016843032191640565, 0.06566349616540329, 0.01233819664256381, 0.052223023625888994, 0.012872885629933859, 0.02278157915653927, 0.0208201532451702, 0.013316812076871949, 0.05421962309628725, 0.023846148014334694, 0.026357097384919013, 0.04570897888126118, 0.03945886729551213, 0.03984305721574596, 0.029325102855052267, 0.01058753049333713, 0.02539386773215873, 0.0196198231008436, 0.022364539659715126, 0.10036431984709841, 0.04050798421459539, 0.019287798952843462, 0.05280803277024201, 0.034060744635228596, 0.04635881865397096, 0.04463407763146928, 0.036279255590800724, 0.03745540105072515, 0.025635003810748458, 0.06572628779602901, 0.08032843603619508, 0.04454953216814569, 0.030375481849270206, 0.01364003392934267, 0.01475697975339634, 0.019604713822315847, 0.00512595463078469, 0.05506477578143988, 0.04467992963535445, 0.03616087497877223, 0.012644796083415193, 0.0591606879606843, 0.03650591342843004, 0.040852513762989213, 0.06248998109783445, 0.009799231409228273, 0.05192217476932066, 0.0135851090640894, 0.05284012069127389, 0.07931503041514329, 0.03357503230550459, 0.05073969179232206, 0.030048288870602846, 0.054909174130963426, 0.0673345514972295, 0.0405846858131034, 0.022295782009937933, 0.03681376137371574, 0.03965468232386878, 0.03542680526152253, 0.039943497361881394, 0.028832801950297186, 0.020024782977998257, 0.04015080338077886, 0.06059605415378298, 0.023973320743867328, 0.01359073496756277, 0.03511936104457293, 0.06450769997068814, 0.023417866888589094, 0.030533186958304474, 0.025441095465794206, 0.07214884566409246, 0.03240943127976997, 0.03404164726712874, 0.028448026793609773, 0.0491349768292691, 0.024731217218296866, 0.024965240553553616, 0.02148410484993032, 0.028610245856855596, 0.057854888029396534, 0.03586917955960546, 0.02193844680940466, 0.005495436880404928, 0.027263347059488297, 0.012453482286738498, 0.0294978850122009, 0.0314295486813145, 0.014317156746983528, 0.04718669244487371, 0.01577478228136897, 0.012736948772466608, 0.03704956925607153, 0.02906823663839272, 0.025374025671875904, 0.05625667003914714, 0.019387870993731276, 0.013976880764987851, 0.06062732783279248, 0.04224649949797562, 0.018370521387883594, 0.06347072882843868, 0.02139666543475219, 0.03993095803473677, 0.027535836544952223, 0.01994008823697056, 0.06267387087323836, 0.022232815656544905, 0.022399541888652102, 0.02832371917819338, 0.015675117361492345, 0.047810686818723164, 0.057586730990026674, 0.028161116742662022, 0.020061837775366645, 0.05513135363746967, 0.02910342885713492, 0.013009260990656912, 0.02856453295264925, 0.06988630457116024, 0.018433087405615618, 0.04936661172126021, 0.021178808196314743, 0.048390963181321106, 0.03762077360547014, 0.17275205733520643, 0.009183231026067265, 0.06406925778303828, 0.03948969992675951, 0.023203996043386202, 0.03198193046929581, 0.019635895899097835, 0.03877355031935232, 0.023057751390816908, 0.03966455161571503, 0.05742249158876283, 0.019673834488328015, 0.00763755539498691, 0.08017751627734729, 0.04312445595860481, 0.02111284780715193, 0.044283953561846695, 0.08935505524277687, 0.012914942926727235, 0.04692977194541267, 0.027554301179147193, 0.04514913660074983, 0.04543121378602726, 0.009909161715768278, 0.06384233531675168, 0.013227591507269867, 0.04032119709466185, 0.01712470904125699, 0.0707292350541268, 0.08096299520028488, 0.06202753912657499, 0.04387639489557062, 0.026749176971082176, 0.007084831370905573, 0.020363193836861422, 0.05268442065321973, 0.03238910576328635, 0.009403135743923485, 0.06647473227764879, 0.05628395393224699, 0.01153274588952107, 0.0628927866263049, 0.015699500517387475, 0.024872423748352697, 0.002381500580148505, 0.041866594526384554, 0.02791965496726334, 0.03986248367332986, 0.029017685779503415, 0.05946811182158334, 0.03871451098737972, 0.017669082419680696, 0.0233141426329634, 0.09772154808576618, 0.06134390830993652, 0.033863582714859924, 0.024473451942737614, 0.037823815031775405, 0.03242736496031284, 0.04849302163347602, 0.05245086889980095, 0.0462724479314472, 0.06338544376194477, 0.012180050485767424, 0.0386508644026305, 0.07718288339674473, 0.01689995449435498, 0.056377720686474016, 0.040886715320604186, 0.01833310187794268, 0.02816729650034436, 0.009419917611272206, 0.06597447554980006, 0.05147898283654025, 0.042947694193571806, 0.07355559803545475, 0.017348048842645118, 0.04768251833905067, 0.010502032536481107, 0.051190727589918036, 0.05048708338290453, 0.07410714522536312, 0.02581319389199572, 0.01619683106296829, 0.0448198706976005, 0.01456204682056393, 0.021618632899065102, 0.024061453961102024, 0.05092289964003222, 0.06995836499014071, 0.01125748798118106, 0.028646628904555525, 0.018041830543162565, 0.01675391340229128, 0.086983697488904, 0.03780004595007215, 0.094043352242027, 0.03215902132381286, 0.019073877217514173, 0.027449282617973428, 0.005854660952796361, 0.007848088696066822, 0.02218918755118336, 0.04755747790581413, 0.022893834293686917, 0.02784596606423812, 0.027914435336632386, 0.02066583911489163, 0.026259586813726594, 0.034929354275975905, 0.009125880398122328, 0.0751059487728136, 0.007551677458520446, 0.009645082671860499, 0.004930732048316193, 0.022176001919433475, 0.02781578652294619, 0.09442076020474945, 0.13439705116408213, 0.03615141959328737, 0.017126429127529263, 0.07848779444715806, 0.04179483944816249, 0.0321728057627167, 0.09934579807200603, 0.01890394660378141, 0.02180679065973631, 0.05377873478989516, 0.0275492257372077, 0.012092119132700776, 0.03469980587916715, 0.05528389848768711, 0.02402369857632688, 0.04786338524094649, 0.003470403824134597, 0.031925574743321965, 0.06472739603902612, 0.0494174204234566, 0.05483783635177782, 0.02639715130706983, 0.0581651617373739, 0.038396230566182306, 0.030744258846555437, 0.03645761191312756, 0.016605039426524724, 0.02423752870942865, 0.049040494220597405, 0.0349527026659676, 0.018860160739028027, 0.047561538937900744, 0.058494034090212414, 0.014758564132664884, 0.0409009645559958, 0.03468713423769389, 0.026266509567254355, 0.019698005602029816, 0.0270116784210716, 0.06989454877163682, 0.010440397808062179, 0.04983998489167009, 0.04864842650879707, 0.017331014221001948, 0.003948792640585452, 0.10490001432065453, 0.05413806318704571, 0.04895821845691119, 0.042874653291489394, 0.0050236268850442556, 0.03402509440534881, 0.05202710342460445, 0.058274073393217156, 0.026720585201733878, 0.0815464471067701, 0.0362188252620399, 0.02045182917000992, 0.03393324790522456, 0.049128004881952486, 0.04682350318346705, 0.023125513290454234, 0.07587346687380757, 0.012574681363600706, 0.010527855034784546, 0.030135633290878365, 0.04324137432766812, 0.010334534470790198, 0.03261325641402176, 0.024192114360630512, 0.01700698321552149, 0.019531437129314457, 0.019366335988576924, 0.024602765450254083, 0.04820634058809706, 0.027151405744786774, 0.15270967994417461, 0.026592233517606343, 0.02283466773639832, 0.009247897109682006, 0.017745181818359664, 0.0441969518017556, 0.022470849133761864, 0.06955538982791559, 0.04211432087634291, 0.031210235985262052, 0.01681771096108215, 0.02611354402532535, 0.05392774107999035, 0.024352933945400373, 0.06554879660585097, 0.020778162105541145, 0.01645741395519248, 0.01052974390664271, 0.03964455858139055, 0.14168914487319334, 0.10310127905436925, 0.1649786787373679, 0.14963838617716516, 0.11491149318005357, 0.11455367452331952, 0.18608174206955092, 0.09288499797029154, 0.13416104311389582, 0.11541660821863584, 0.06807859228657824, 0.10162043744432074, 0.053621229848691394, 0.17539591475256852, 0.183282486562218, 0.15291102842560836, 0.04674196023760097, 0.14941115837012017, 0.1462160726743085, 0.16678309334175928, 0.12203175468104226, 0.1978002046900136, 0.1872720553406647, 0.13262254638331278, 0.07900482456066779, 0.09715928682791335, 0.11969049674059663, 0.09471802639641932, 0.14475543105176517, 0.12249702614332948, 0.11520966860864844, 0.10665640900177614, 0.11955730031643595, 0.22328615640955313, 0.16804672910698823, 0.1056093005463481, 0.0979407216821398, 0.11259974472756897, 0.12393522182745592, 0.2644089476338455, 0.12699689396790095, 0.11381238858614649, 0.09015337883361749, 0.233723341354302, 0.16677872357623919, 0.18358146266213485, 0.09244728181511164, 0.1081777862938387, 0.1390405377107007, 0.1560955832579306, 0.10465794016740151, 0.10027134697884321, 0.14996827633253165, 0.18221710515873774, 0.061997330747544765, 0.10828981921076775, 0.08498444833925792, 0.09559622712965522, 0.33246421867183273, 0.09777579017515693, 0.2714737728238106, 0.09394343117518084, 0.1100156730307, 0.12395171022840909, 0.21010717430285045, 0.09448159765452147, 0.0856615991464683, 0.08662606882197516, 0.09764825951840196, 0.15318180461015019, 0.1512194134827171, 0.06160418755773987, 0.10321362409740686, 0.12299671290176255, 0.20062485097774438, 0.14100310525723866, 0.09669018164277077, 0.11508635165435926, 0.3358146346041134, 0.08940209807561976, 0.1654867929007326, 0.24944673478603363, 0.1598268337547779, 0.10419978653745991, 0.1527231420789446, 0.1036487143220646, 0.11469485051929951, 0.16133947830115045, 0.16966470942965575, 0.15495736790554865, 0.1213909462094307, 0.13139274237411364, 0.104938127632652, 0.12720467496131146, 0.12007601319679193, 0.11822692384677273, 0.10722922826451914, 0.09682343913508312, 0.07669021947575466, 0.11480302257197243, 0.13882359649453843, 0.10587235500237771, 0.16918603011540004, 0.09960807221276419, 0.22607281830693993, 0.13430310120540007, 0.18349494944725717, 0.1276146186781781, 0.0936960983755333, 0.12782572449318, 0.14636651745864324, 0.10926867382866995, 0.11747035730097975, 0.12323040036218506, 0.12874724290200643, 0.06595820428005286, 0.11133726247187171, 0.19385699342404092, 0.1360463255218097, 0.08435889333486557, 0.11117337590881757, 0.23856403731874057, 0.05035143066197634, 0.1380878338324172, 0.11823961245162146, 0.09153965301811695, 0.10598001815378666, 0.2019225899130106, 0.18908402882516384, 0.1942526471934148, 0.13235746989292757, 0.09004942726876054, 0.09410714131913014, 0.08680662020508732, 0.14514914421098574, 0.1723195862557207, 0.19594950042665005, 0.11781673585729939, 0.08107764047703572, 0.09252938455236809, 0.23775582068732806, 0.11686613543757371, 0.10479690413922071, 0.11322137779955353, 0.05508211913651653, 0.10926025320908853, 0.1591078716197184, 0.06950392294675112, 0.12132845313421317, 0.07618741145623581, 0.12032351563019411, 0.11306546402296849, 0.07567319726305348, 0.11808223303939615, 0.16762952506542206, 0.16561446604984148, 0.11118833760597877, 0.3578967696854046, 0.06697124349219458, 0.17750904921974453, 0.12346169937934194, 0.11626697544540678, 0.15197505722088472, 0.12700131801622255, 0.16453972086310387, 0.10630192873733384, 0.12824405490287713, 0.13208495665873798, 0.13411749473639897, 0.1673334123832839, 0.1514566700373377, 0.15900278011603014, 0.13852324975388391, 0.08882296165185315, 0.16618723102978297, 0.15987275700484002], [0.05629019984709365, 0.027312630754230276, 0.03024988162464329, 0.026900244311296513, 0.027105087248076285, 0.0815944941714406, 0.01517957475568567, 0.025933503239814724, 0.04504111043310591, 0.04195582866668701, 0.02148158409233604, 0.017735025845468044, 0.014018857485747762, 0.03970038165737476, 0.03584273365725364, 0.07297716050275735, 0.05967269691505602, 0.02231387684254774, 0.01043403654226235, 0.011607825789334518, 0.06024615400071655, 0.04115719294973782, 0.01965131051838398, 0.02527192820395742, 0.056544762437364886, 0.012159038800746202, 0.06469139975628682, 0.04714370385876723, 0.05691768528361406, 0.03558740771508642, 0.012560385478926557, 0.04205600079149008, 0.02739777502470783, 0.0037102566233703066, 0.022738936623292308, 0.06493332463183574, 0.01695587086890425, 0.0371349323540926, 0.04628139441566808, 0.012969205372168549, 0.014991074334830046, 0.016844764152275662, 0.004474801044645054, 0.017148466248597418, 0.015395554148459008, 0.020500334245818, 0.0030937344043715192, 0.03199122979172638, 0.014594180542709572, 0.016623056227607385, 0.045104282043342075, 0.034769236974950345, 0.010211657716094382, 0.059843355257596285, 0.016989078372716904, 0.010471769026480615, 0.03292177950165101, 0.05483472187604223, 0.05131909963009613, 0.008832461500008191, 0.057780642727656026, 0.020062480687296817, 0.04953613691031933, 0.032482065060841184, 0.06352301673697573, 0.00935103528068534, 0.015006673854908772, 0.017365426124472703, 0.049778224634272714, 0.02623073889740876, 0.022677300198535835, 0.013796181800509138, 0.02684966122199382, 0.0036514327262661284, 0.027241886693185995, 0.03733831304790718, 0.05231192528403231, 0.04209983415369477, 0.03578108535813434, 0.024381775076368024, 0.06186939975512879, 0.05866400711238384, 0.059024092076080184, 0.025701488368213177, 0.024836108554154634, 0.09022078450237002, 0.1060469624187265, 0.02019856936697449, 0.048654255124607255, 0.037398180192602534, 0.05211770820564457, 0.011851530122969831, 0.03960395843854972, 0.011913353993025209, 0.00799434946384281, 0.010774425330704876, 0.059359485150447915, 0.019551448823351945, 0.02648983070892947, 0.121060757498656, 0.04486354460407581, 0.046749244311026165, 0.10975860325353486, 0.04874633571931294, 0.005964989474575434, 0.025258673022368124, 0.014452741614409854, 0.0682640630485756, 0.06061172831271376, 0.026441357863534774, 0.009097300503136856, 0.049623477937919755, 0.04598753107711673, 0.09465682932308742, 0.01583080891785877, 0.024771583266556263, 0.07845974380948714, 0.022732714457171302, 0.04945820037807737, 0.012689537834376097, 0.015273863981877054, 0.025755476006971936, 0.044595981282847266, 0.019502114238483564, 0.051823824511042664, 0.049353563492851596, 0.05331653369856732, 0.007987477600441446, 0.0263500491024128, 0.054968627369297404, 0.009295073105022311, 0.07820564601570368, 0.045684144499578645, 0.05473580164834857, 0.02973750965403659, 0.0350068701165063, 0.047391939109989574, 0.03479864128998347, 0.0807327072003058, 0.018470284695337926, 0.055885073728859425, 0.019840599736198783, 0.08322512917220592, 0.0572200370952487, 0.0546460755701576, 0.02441448894595461, 0.039050060124801736, 0.04155587977064507, 0.07069180706249815, 0.06315322193716254, 0.07122392779482262, 0.006785906161115105, 0.012575242851328636, 0.01803195446596614, 0.07850321754813194, 0.03597120408500944, 0.014721494068258574, 0.03958028435174908, 0.025934767011286955, 0.03908758989668318, 0.020540403435006738, 0.04816780997706311, 0.022177805126245533, 0.04117940818624837, 0.01527722951556955, 0.01367140090691724, 0.02919546534706439, 0.03688309068924614, 0.03282436901437385, 0.05631111229636839, 0.026370138827977434, 0.029666202408926826, 0.027440909495843307, 0.028933289593883922, 0.034455658801432164, 0.04976824677682348, 0.021627903383757387, 0.034678360779902766, 0.03805979254788586, 0.02792076946103147, 0.03894669549273593, 0.07899740138756377, 0.06260160010840211, 0.0536643507491265, 0.024308773190049187, 0.017613428977451155, 0.028201643942988346, 0.015596714336425066, 0.04969690899763789, 0.03355146339163184, 0.03978718664231045, 0.05726252017276628, 0.03403239544214947, 0.044729438942990134, 0.02105626816462193, 0.03156508944396462, 0.034549065932099304, 0.01672460408216076, 0.017922961385920644, 0.024193559640220234, 0.004639657488691488, 0.015898835446153368, 0.06128591392189264, 0.007133993353428585, 0.009536425466649234, 0.025186544749885798, 0.03592058876529336, 0.04932753488953624, 0.030633932445198298, 0.009993031188579542, 0.0077358106583622945, 0.08361510360347373, 0.010846722388773091, 0.022125724170889174, 0.05268891255504318, 0.060042274583663256, 0.03406509404469814, 0.025788476557603905, 0.02978024718218616, 0.049406859025891335, 0.049324135429092815, 0.059983011335134506, 0.02888337316523705, 0.012623667351103254, 0.04364998472322311, 0.010273522298250879, 0.04827756980167968, 0.009768960265708821, 0.03021549346989819, 0.021843551990709136, 0.013088325587367373, 0.035442224969821315, 0.05720144523573773, 0.0390061996211963, 0.03271270250635488, 0.04337468949545707, 0.06947758221732718, 0.009231308624813599, 0.06799866764673165, 0.06578688775854451, 0.053764960529016595, 0.030621650961360762, 0.022081643143402677, 0.034939050541392395, 0.025161177718213627, 0.018603603255801966, 0.053451928576188426, 0.0578791524416634, 0.010062221404431122, 0.07048818548875195, 0.029601178398089747, 0.029754866579813615, 0.04419567615592054, 0.03515101809586797, 0.01887339386822922, 0.04348580299743584, 0.10655520550374474, 0.04662009874092681, 0.028771218112004653, 0.03709970620859947, 0.018473380511360507, 0.024231957936925546, 0.06394083146005869, 0.022323372940133725, 0.02389946559976254, 0.01963007406863783, 0.02489550072433693, 0.03008903150579759, 0.0484893168322742, 0.012051558853792292, 0.028028424130752683, 0.013033822261994439, 0.06006767214941127, 0.07313744404486247, 0.02409370642687593, 0.0953912620565721, 0.051758162677288055, 0.06517406885645219, 0.05190790857055357, 0.059575035369821956, 0.027889714609565477, 0.014899524693776454, 0.02513703204957502, 0.03784081233399255, 0.07584135181137494, 0.0027226497518963045, 0.015409538755193353, 0.021634622576779554, 0.07683822831937245, 0.09372620497431074, 0.0037291478864582522, 0.040716548915952444, 0.04019321860479457, 0.05788534746638366, 0.07514465241027729, 0.005120682413689792, 0.030511097250772373, 0.015396780600505216, 0.032875822324837954, 0.019942374899983406, 0.030860200125191892, 0.0526851907904659, 0.07841265347919293, 0.018794139281713536, 0.0178152473443853, 0.02835178847557732, 0.031443574000149965, 0.015288578013756444, 0.04352148036871638, 0.05652877275965043, 0.023983023794634, 0.025944322480687072, 0.052497687816087685, 0.030819579626300504, 0.033294166305235455, 0.0085111327602395, 0.03500711438911302, 0.025956519147647277, 0.021618210511015992, 0.027124009893408844, 0.0286975970624813, 0.02021637073318873, 0.04560004686936736, 0.03857787099799939, 0.030874829340193952, 0.06213499193212815, 0.030997413476662974, 0.006086362001951784, 0.007372930978557893, 0.07169588282704353, 0.031589489563235214, 0.05239252845889755, 0.0207648797825511, 0.014854447916150093, 0.008744290115178695, 0.04081935714930296, 0.02061138498330755, 0.07057592685201339, 0.027180745598993132, 0.06772032579673187, 0.003600365332593875, 0.03606025841353195, 0.07288139885557549, 0.028946066408285072, 0.011571930438679243, 0.012853453235168542, 0.05319167986246092, 0.018706038294892226, 0.009639641669179713, 0.022143220196345022, 0.024616168213209937, 0.0416056672776384, 0.17009203721370014, 0.10393795344446387, 0.09272143031869616, 0.1378573626279831, 0.09748735850942986, 0.1718581145895379, 0.1590424065611192, 0.20310932051922592, 0.17017808902476514, 0.12213994030441556, 0.12891109553830965, 0.127138436372791, 0.12953173794916698, 0.09205188588904482, 0.10185724616582904, 0.17705034597643785, 0.10393534786999226, 0.08139096759259701, 0.09652407627020564, 0.15264796039887837, 0.1705146831061159, 0.15390390157699585, 0.06641250383108854, 0.146574379876256, 0.10845227406493255, 0.06225423767630543, 0.12972216201680048, 0.1470144505479506, 0.1377580115305526, 0.11305450568241732, 0.12029774487018585, 0.07860929971294743, 0.19793186762503215, 0.11076541351420538, 0.0971510833395379, 0.1216217295399734, 0.08675215419914041, 0.14859503002039023, 0.23842816746660642, 0.16339914420885698, 0.09996590444019862, 0.11638063006103039, 0.07286223024129868, 0.11250401700713805, 0.09636912601334707, 0.10545869291360889, 0.06203065360231059, 0.13941020358886036, 0.1080092042684555, 0.08962740562856197, 0.15787592343986034, 0.0999263594193118, 0.1025929409744484, 0.13135285808571748, 0.1645582720105137, 0.14384027730141366, 0.14402649445193155, 0.12899333398256982, 0.14654935550476822, 0.1202346682548523, 0.13607941088931902, 0.06266865293894495, 0.15806376907442296, 0.13603416617427552, 0.1421567504959447, 0.12567520274647645, 0.11764607072940894, 0.08236905546592814, 0.10810881999454328, 0.21973657687859877, 0.11253240012696811, 0.11534302788121359, 0.1811400665236371, 0.11575268661337239, 0.25176550607596127, 0.13059998277042592, 0.15235807666821138, 0.1736595436398472, 0.12354966465915952, 0.17575517190354212, 0.24035550547497614, 0.2439510082559926, 0.1236451616776841, 0.09320017748645373, 0.09623185159372431, 0.2871926065002169, 0.2540840059518814, 0.07106345426291227, 0.13531920739582606, 0.12624013743230275, 0.09310700784304313, 0.10338687444371836, 0.10436425664063011, 0.1567816093031849, 0.08408350311219692, 0.09472608739244086, 0.11689748375543527, 0.15863369777798653, 0.1622596803520407, 0.20061387228114264, 0.12876073217817716, 0.138947619125247, 0.2115888369402715, 0.15822614250438555, 0.041424613778612444, 0.10596083596880947, 0.171056724020413, 0.12309664753930909, 0.18158720753022603, 0.13602355388658388, 0.1394113978104932, 0.10967247001826763, 0.11340627859213523, 0.180463363549539, 0.07813921743737799, 0.0850920911346163, 0.26508883972253117, 0.08872082856084619, 0.2418490153338228, 0.05630834387349231, 0.08569994316037212, 0.09072485459702355, 0.14810735333178723, 0.25614406540989876, 0.18960949991430553, 0.08443061448633671, 0.20321598622415746, 0.12136231203164373, 0.13035778648086957, 0.17819622877453054, 0.1687665054840701, 0.2080132830888033, 0.10671756536300693, 0.2118388499532427, 0.11597414687275887, 0.09601893409022264, 0.07175812484430415, 0.19131815965686524, 0.2598624373120921, 0.08064461978418486, 0.1305874027311802, 0.17543339702699864, 0.26409798860549927, 0.10543089333389487, 0.08697135493691478, 0.1256577101136957, 0.11678347630160195, 0.12248842231929302, 0.12136176920362882, 0.15643137666795934, 0.1557501817920378, 0.09415388559656483, 0.11903211421200208, 0.15924930545900548, 0.1935233577553715, 0.09432522925947394, 0.09324488615883247, 0.16529198549687862, 0.13954292503850801, 0.09651709414486374, 0.07609041487532002, 0.20432517384844168, 0.11208806147000619, 0.13660216783838613, 0.07321822363883257, 0.14528225921094418, 0.2214170502764838, 0.13377372175455093, 0.09953087528369256, 0.11472074341561113, 0.12015020421573094, 0.1469992377928325, 0.10628780842359577, 0.14992524364164897, 0.09833134750702552, 0.10933187936565705], [0.08608121877270085, 0.07592203641044241, 0.0634177081020815, 0.03490394313952752, 0.036215283309242556, 0.04403993540576526, 0.03407631701390658, 0.09463803390307085, 0.03374779749927776, 0.07128363887646369, 0.05489284857841475, 0.05314834522349494, 0.05364676990679332, 0.04218881045069013, 0.02645493026024529, 0.06447228722806488, 0.03619209437498024, 0.04243240452238491, 0.055891899791147025, 0.014068152206683797, 0.018972829782537053, 0.05171464144119194, 0.034991935560745854, 0.02121739987550037, 0.03430526490722384, 0.013174017774872482, 0.06326146184333734, 0.04713666405794876, 0.051223327804888995, 0.027846195069806914, 0.010595995217694767, 0.0438247448099511, 0.010982068072605346, 0.041411066826965125, 0.09701278433203697, 0.031998327268021445, 0.019682102437530245, 0.006194480619991997, 0.03945974260568619, 0.0313194529818637, 0.016178025464926447, 0.08659615221300296, 0.02888225018978119, 0.05323631389598761, 0.011875183005551142, 0.051748975313135555, 0.04480367745938046, 0.020906669852722968, 0.053054968626903634, 0.02853492507711053, 0.03239565362621631, 0.014671289262228777, 0.023271092978705252, 0.01134097492987556, 0.045791882289839644, 0.04052856418171099, 0.03796834299074752, 0.024719753369156803, 0.03905963086123977, 0.01775738357433251, 0.008984854528015214, 0.03928137271265898, 0.03842375194653869, 0.02957537371133055, 0.03445196417825563, 0.024487774120643735, 0.012170580681413412, 0.02137179034096854, 0.06966429469840867, 0.058304546400904655, 0.06871095978255783, 0.026488231062623005, 0.01397840746877981, 0.05246107067380633, 0.04039039409586361, 0.05780330579727888, 0.030019098294100592, 0.030934879689344337, 0.01915601727419666, 0.033214190775262456, 0.05810002237558365, 0.05575572459825447, 0.05460658822474735, 0.03100120309474213, 0.046513711235352924, 0.01532931555993855, 0.1419977154582739, 0.05932031332382134, 0.016267100149499517, 0.08334544700171266, 0.029170539363154342, 0.03459939965978265, 0.0010687188415821375, 0.059988283552229404, 0.02827971618223403, 0.05403053913531559, 0.05050235381349921, 0.02118498456132199, 0.031046417275709764, 0.05987916833588055, 0.07085568005485193, 0.01853130534956498, 0.041090777942112515, 0.015264157538435288, 0.05834080731230123, 0.01843606787068503, 0.05239854706451297, 0.017960285900958946, 0.0268320498455848, 0.018114203088251606, 0.027416181983426213, 0.022760089952498674, 0.004973296550036008, 0.027436191981126155, 0.017526113394913927, 0.023333448650581495, 0.018394663663847104, 0.003954600900345082, 0.048582008108496666, 0.025289373339286873, 0.03548142393784864, 0.02477470792031714, 0.03847782779484987, 0.02148198612433459, 0.045623887197247574, 0.012924703652970493, 0.05817918027085917, 0.08514112886041403, 0.007787387801467308, 0.06458486297300883, 0.01458843844011426, 0.009803868347911962, 0.022174319152587225, 0.007399382818091128, 0.034013118262269666, 0.012912687645959002, 0.030812543218157122, 0.0440414213974561, 0.04156254976987839, 0.02046191389672458, 0.031468248926103115, 0.040771564535264454, 0.006337735477635371, 0.04088909358584455, 0.03795612257506166, 0.0529728014288204, 0.023018026558150138, 0.0018837514632780636, 0.10645684506744146, 0.044784457954977236, 0.04467220112149205, 0.011506318646882261, 0.01376089034602046, 0.03771617223641702, 0.03228093371061342, 0.06332763257835593, 0.025439329578408172, 0.06642520600663764, 0.03684098080598882, 0.028309605649805496, 0.042864607580538304, 0.09000565497470753, 0.016346195280285816, 0.06652254864041295, 0.022506132954731584, 0.019717725526009287, 0.021694462580074157, 0.020729601050594022, 0.040809810161590576, 0.024807572763945376, 0.06232980612133231, 0.020935091988316605, 0.0180718862518136, 0.028736656930829798, 0.03022142725863627, 0.04156300438834088, 0.07513404012258564, 0.03745765717966216, 0.025249572171430503, 0.04755051952919789, 0.030282257923058102, 0.03398675039144499, 0.009006729648847665, 0.049686931140188656, 0.027891377020361166, 0.0476098574165787, 0.04544512714658465, 0.07784210052341223, 0.0018917522393167019, 0.08528731244483165, 0.010786917160398193, 0.047852070669510534, 0.024641670951885835, 0.03130716132000089, 0.08011431752571038, 0.007801163758683417, 0.019898684030132632, 0.07941633569342749, 0.02667568314687482, 0.028335881918402653, 0.030729358217545917, 0.0376875177025795, 0.033857920340129306, 0.04387688683345914, 0.018589781497472098, 0.02130160776765219, 0.036308704010610066, 0.030197498721203635, 0.01156570912072701, 0.06711842452308961, 0.00759167964237609, 0.06343451541449342, 0.03638829616829753, 0.04463302929486547, 0.04248962877318263, 0.012026952629509782, 0.010103683286745633, 0.04435189188058887, 0.036866453010588884, 0.013347348697217447, 0.038606389824833186, 0.036403569991567304, 0.03627459066254752, 0.019643429334142377, 0.03568919814590897, 0.052408942220998664, 0.038586183051977835, 0.02313511456096811, 0.01713432388247124, 0.029617585374840667, 0.010067879538317876, 0.02149962803481945, 0.02794881840236485, 0.021771630671407496, 0.06375094343508993, 0.012371099653786846, 0.02127618475684098, 0.01358264683014048, 0.017208480974659324, 0.09065811389258929, 0.15578855973269257, 0.017215603896017586, 0.018830055836588144, 0.03324427701798933, 0.03525162787575807, 0.13424199234162057, 0.03641911183616944, 0.045018226839601994, 0.05873866632048573, 0.07809220853128604, 0.026005653564685156, 0.06505360174924135, 0.07295297751469271, 0.06229150960487979, 0.031655572088701386, 0.02834490134513804, 0.023674319198887264, 0.06164382757352931, 0.03607078588434628, 0.028922300719256912, 0.045574014873376915, 0.06088657570736749, 0.06440532939242465, 0.0357207602023014, 0.08849590098751442, 0.04597470337258918, 0.029072111073349203, 0.02552804463942136, 0.06689219416252204, 0.04830166118751679, 0.012815129577315279, 0.016674058312284093, 0.030165919701435735, 0.0344789834426982, 0.01641656275439475, 0.052016572561115026, 0.01995336207827287, 0.056665236329925914, 0.05915259303791182, 0.03757283171372754, 0.047476240300706456, 0.017172289613102163, 0.03373301222122141, 0.017529115912371447, 0.011124890364174331, 0.016296012526644126, 0.07478371927780764, 0.05155452414016638, 0.03423863276839256, 0.01613906228781811, 0.031565862973885875, 0.02788661709720535, 0.011087509021828217, 0.0462259614973196, 0.053124545607715845, 0.023292812884652188, 0.022320399260414497, 0.01214475987944752, 0.02801505529454776, 0.032175787924123664, 0.03699038064639483, 0.03204741927662066, 0.04843137672703181, 0.03630957253543394, 0.04156259726732969, 0.030571113673171828, 0.07756462719823633, 0.046355354732700756, 0.02845589949616364, 0.06355840912354843, 0.052813081070780754, 0.04470782420997109, 0.07163227695439543, 0.02575786953925022, 0.06704970928175108, 0.048914883817945204, 0.07305805544768061, 0.017904897087386677, 0.01674212555267981, 0.013801520174768354, 0.02708396784562085, 0.01722364453598857, 0.03212639736011624, 0.021805386092247706, 0.06720010656863451, 0.024007245798462203, 0.017027463098721843, 0.02185145183466375, 0.039812601171433926, 0.022631962184927294, 0.04033110709860921, 0.03161680059773581, 0.005131070784825299, 0.04353886782856924, 0.038778578263840506, 0.04821886634454131, 0.044952154492161105, 0.049687063454517295, 0.0640658243958439, 0.00501760234224743, 0.04137611209547945, 0.021642354483317052, 0.007015944799474839, 0.09316692248518978, 0.018413240256320153, 0.05243132369858878, 0.06789228014115777, 0.03338217568982925, 0.030203446080642085, 0.060513761426721296, 0.030099732003041675, 0.03700884358425226, 0.2047197555324861, 0.15476629244429724, 0.16409602681440966, 0.14541194082370826, 0.14712121124778474, 0.12007655602480684, 0.07980808788644415, 0.18332356507224695, 0.1156257191406829, 0.1444896895970617, 0.1371264582765954, 0.16192248915987356, 0.06743729526975326, 0.21569187034453663, 0.14712167265159742, 0.10452138499489852, 0.10689636612577097, 0.10630803555250168, 0.13086725771427155, 0.07619725021400622, 0.07461520510592631, 0.1566132783357586, 0.10464892922235386, 0.1272473819553852, 0.09404323689107384, 0.12427087953048092, 0.13315446355513164, 0.09785905999264546, 0.1832914160830634, 0.1099415702213134, 0.1731735768594912, 0.1145414337515831, 0.13587810311998638, 0.13762856061969483, 0.20671741691018852, 0.12176074779459409, 0.10526256915181875, 0.09729429494057383, 0.1391590234956571, 0.1380468231758901, 0.18489727777029785, 0.17573734000325203, 0.14833698315279825, 0.10838162499879088, 0.07901374051081282, 0.08192701025732926, 0.14243167931480066, 0.09653522460056202, 0.16390264433409485, 0.13079044755016053, 0.13611472185168946, 0.0807639401672142, 0.1168703016425882, 0.09220529587141105, 0.09275887188102518, 0.09953090242509331, 0.14562749782843248, 0.1943842422749315, 0.1949194028441395, 0.12636292512927735, 0.0513779998623899, 0.08532790240964719, 0.08657536868538175, 0.11515430015112672, 0.21024898812174797, 0.1337338646075555, 0.08589513732918672, 0.1778578297900302, 0.12480262028319494, 0.24186459449785097, 0.13830055456076348, 0.12856851677809442, 0.09030961830701147, 0.26520337643367903, 0.10191081650555134, 0.16110759574387754, 0.1383988471435649, 0.09796583426317998, 0.08767495503915207, 0.15776708642286913, 0.12938213454825537, 0.17700360848435334, 0.1232194352362837, 0.18433334731629916, 0.09965590214622871, 0.09053604544273444, 0.22640882884817465, 0.11674114928713866, 0.1385785367872034, 0.10178302122013909, 0.1471236404031515, 0.12972187703209265, 0.21646621450781822, 0.1349540198487895, 0.07272341554718358, 0.18648627107696875, 0.11510574418519225, 0.11131858240280833, 0.12041990831494331, 0.13903539441525936, 0.12657703006906168, 0.1516352468835456, 0.14560346411807196, 0.12473882442074162, 0.20309403991060598, 0.09548953428332295, 0.15498734558267252, 0.1394780706614256, 0.11326132994145155, 0.10527441637324435, 0.2010528165847063, 0.1174372990748712, 0.17930561995932034, 0.0751669897830912, 0.07172453057553087, 0.07502946430551154, 0.08644927652286631, 0.11129359874342169, 0.20457860667790684, 0.09605864874486413, 0.17676393634506635, 0.09892908936100346, 0.10074284739260163, 0.1281933547662837, 0.21112086490861007, 0.10642895049282483, 0.17463518200176104, 0.11929961985775403, 0.07661150941359145, 0.10904536116868258, 0.16567263007164001, 0.13068395826433385, 0.13379992677697114, 0.09366223947810275, 0.1646145632756608, 0.12997141507055077, 0.15219286696187087, 0.14357536365943296, 0.12020884321204253, 0.1772182969642537, 0.15675944834947586, 0.14344694412180356, 0.053336316387036016, 0.072353206841009, 0.1276178349341665, 0.0910995484196714, 0.14919138087757997, 0.12606951301651342, 0.10942264020975147, 0.10653101573032991, 0.15168503778321402, 0.10810267925262451, 0.0768619499036244, 0.12823028064199857, 0.16363697073289327, 0.1188453406627689, 0.09753846576703445, 0.137404467644436, 0.09631637670099735, 0.08265037608465978, 0.1033860534163458, 0.1559212947530406, 0.1054108969068953, 0.15278122467654093, 0.1815395743719169, 0.0894275363534689, 0.12218423507043294, 0.17045369637863977, 0.19726766326597758, 0.09704893667783056, 0.18894809111952782, 0.07277942182762281, 0.06156738381832838, 0.11836341795112405, 0.06289311910846404, 0.1440999662237508], [0.0625571289232799, 0.013641934675563658, 0.030260147859475443, 0.03793022967875004, 0.02230578361611281, 0.05209930972861392, 0.05221601435914636, 0.07296447868325881, 0.028397163808611885, 0.034055730261440785, 0.014673898229375482, 0.015812444367579052, 0.050137542853397984, 0.013960785066176738, 0.050276245589235, 0.021660120226442814, 0.04069645070870008, 0.03343087414811764, 0.02999858957316194, 0.01441829408785062, 0.01858137105591595, 0.04154683829152158, 0.03796684003568121, 0.03781737573444843, 0.049025671623115025, 0.015077675759260143, 0.014292904209079487, 0.0684347553178668, 0.00906179700645485, 0.02430387755988964, 0.03256201684208853, 0.08769229160887854, 0.042816139824156246, 0.005218353712864752, 0.04988856799900532, 0.03310741311205285, 0.009458501656938876, 0.0839749239385128, 0.07318747243178741, 0.03898001495482666, 0.04848623289061444, 0.028198816148298125, 0.022704801222841655, 0.05589896673336625, 0.018834793707355857, 0.07748958122517381, 0.04614999610930681, 0.055030923669359515, 0.011118636815808713, 0.035161012916692665, 0.025972147505464296, 0.019959691113659313, 0.03361568333847182, 0.036929855322731395, 0.02666852799510317, 0.00803029740096203, 0.02658201308388795, 0.02853791741654277, 0.041507137207580466, 0.004457447087458734, 0.04766138197321977, 0.05279441796509283, 0.04862465742709381, 0.0176688788591751, 0.03214153886905738, 0.05731317959725857, 0.037251307895140987, 0.05895211986665215, 0.026774102954992225, 0.028352889398645078, 0.03310258872807026, 0.023345316228057657, 0.017770969541743398, 0.018164287454315593, 0.027140148848827397, 0.029769577219017913, 0.05109439936599561, 0.043941832812769074, 0.002051515217837212, 0.029709961132279465, 0.062496223620006015, 0.05016632970156414, 0.05674589718026774, 0.03744520606206996, 0.011000837199389935, 0.028313856671697328, 0.039680938236415386, 0.019585607972528254, 0.036928633959697824, 0.008844882931693323, 0.04388936509245208, 0.05071765976026654, 0.039238635184509416, 0.023553514520504644, 0.03633275468434606, 0.043666513836277385, 0.029733937167163407, 0.0011977778984666137, 0.01746523692937834, 0.03788024200392621, 0.06236850975879601, 0.006478368645600442, 0.12298151371734482, 0.03804509887205703, 0.022705919109284878, 0.06455138405518872, 0.021993246993848255, 0.012853846785479357, 0.015328536941004651, 0.04609678878581949, 0.05663697534639921, 0.04513182377974902, 0.043445552300129614, 0.025709562934935093, 0.05402015754953027, 0.023907321338940943, 0.1028972775010126, 0.06272203328886203, 0.06586439002837453, 0.027281484300536767, 0.003992620489693114, 0.017780413052865436, 0.030423003049301248, 0.01814343946586762, 0.028945394658616612, 0.011844218908143895, 0.040566175377794673, 0.02059200602317495, 0.005252252050143267, 0.04205012807090368, 0.017409457958170345, 0.011200189939700067, 0.044076939313007255, 0.012087086947368724, 0.033810307537870746, 0.09534007337476526, 0.007616161185848925, 0.0038472074666060507, 0.08498640252011162, 0.06421138372804437, 0.0404971819370985, 0.007566877491106945, 0.045416007816259346, 0.038023911616099734, 0.06642131800098078, 0.0351170167060835, 0.03975159748058234, 0.027133400818066936, 0.016211438225582242, 0.05584647187164851, 0.014561342840482081, 0.06043296826205083, 0.017836931627243757, 0.061856161536914964, 0.06502711174211331, 0.01950851791272206, 0.06129455167268004, 0.03758705720039351, 0.013417013887582081, 0.048321688148592196, 0.04238027946225234, 0.03975284259234156, 0.00420992005716211, 0.01849141936483128, 0.041575285872178416, 0.00915972063583987, 0.02828496295426573, 0.020038750621357133, 0.04035404836758971, 0.04111811951068895, 0.08078555150755815, 0.026006808770554404, 0.032964632380753756, 0.010373663040809333, 0.019203199206718376, 0.062011281427528174, 0.04742593371442386, 0.039581037525619776, 0.04896397582654442, 0.05764039632465158, 0.05600348148228867, 0.019810515189809457, 0.052998626471630166, 0.02788903098553419, 0.03172542726887124, 0.014288838087980236, 0.05428423320076295, 0.060377572663128376, 0.030291262082755566, 0.04722989137683596, 0.028599341799105917, 0.006823367655410298, 0.023853805282020142, 0.059158896628235064, 0.021823983040771315, 0.05858040481273617, 0.02464530281057315, 0.049252353209469996, 0.03398063339825187, 0.0387866121184613, 0.029054336848535707, 0.03270713173385177, 0.04873409494757652, 0.04587186799783792, 0.031182290520519018, 0.03444244433194399, 0.029822180646338632, 0.05443995359486767, 0.054846501243965964, 0.0465818972193769, 0.033537421109420915, 0.02179167459585837, 0.023828833496996334, 0.021972103842667172, 0.04684954535748277, 0.032865610372807295, 0.006313802275274481, 0.039205987472087145, 0.011215188108118517, 0.05918981746903487, 0.04489951713808945, 0.04508535430899688, 0.0051265644641327, 0.05614635381581528, 0.05955037062189408, 0.03760227674086179, 0.027616471950230852, 0.03352165874093771, 0.01824816456064582, 0.010617908506122018, 0.020770396272252713, 0.053245606433068, 0.014848449666585242, 0.08739913055407149, 0.023552832592810904, 0.08286534276391778, 0.0163562952740384, 0.03521110237176929, 0.026138441171497107, 0.02291798165866307, 0.039114805936281166, 0.023792455538309047, 0.01145418595323073, 0.03120908247573035, 0.026497489672952464, 0.0614235411797251, 0.09743395780346223, 0.029161752334662845, 0.04724041884765029, 0.01737758716834443, 0.04669219987200839, 0.07263441210878746, 0.0219150594036494, 0.04400022075112377, 0.024979464343882034, 0.010935246611812284, 0.02358838273877544, 0.0357422460136669, 0.01584696992566543, 0.06142366331602846, 0.09277027805468865, 0.03837667518694486, 0.006122276436404458, 0.025178548214691024, 0.06353058918778386, 0.02067663291070078, 0.030661487752305608, 0.09159076027572155, 0.021640980449904288, 0.019154894298740795, 0.03718858751069222, 0.01620744843967259, 0.013997837319038808, 0.020655013088669096, 0.03276308373148952, 0.02899039849372847, 0.0937283355742693, 0.030445299710014036, 0.04115633121026414, 0.028170443206493343, 0.016276324833078042, 0.06232456783098834, 0.03226789905290518, 0.02858877700886556, 0.019438854418694973, 0.0169252977773015, 0.05164658437882151, 0.046237588194864135, 0.06052661966532469, 0.06704822329006024, 0.05389962258881756, 0.05674909308020558, 0.05243452977655189, 0.03524785182837929, 0.07366504573396274, 0.00826932069113744, 0.025113415638250963, 0.015818103349634578, 0.04928932997531124, 0.036295611677425246, 0.05007868333320532, 0.00927320052869618, 0.021376706327178648, 0.03004836690212999, 0.013283471410561885, 0.03996308666786977, 0.03663115742217217, 0.046031975120838196, 0.030829021441084997, 0.02380889474547335, 0.03300359725419964, 0.02483174218130963, 0.06799849801297699, 0.07954759150743484, 0.014487302795584713, 0.04937772951754076, 0.03434131547276463, 0.0495293719161834, 0.05235795031434723, 0.005484012047028435, 0.010680305738268154, 0.0828151854553393, 0.020949398899184804, 0.016890935067619597, 0.01769761651355241, 0.024114042121384825, 0.028465958777815104, 0.013424913731536694, 0.06746721866407565, 0.024036075055067028, 0.02686781033740512, 0.012181366843703603, 0.0479783969266074, 0.04020490637049079, 0.053133000154048204, 0.014244539929287774, 0.08623002150229045, 0.045815508879188976, 0.0329321780508118, 0.0868531202099153, 0.024194170321737016, 0.033564579473542314, 0.043914481066167355, 0.016806096137900437, 0.08766697546733276, 0.003656278738552438, 0.06380282422261578, 0.01734105314660285, 0.019853994017466903, 0.039700541113104136, 0.024450598883309534, 0.05530090596792953, 0.11333080514201097, 0.10525560738252741, 0.18161772803536483, 0.09844891048435654, 0.12575574485319002, 0.1329837441444397, 0.08368414454162121, 0.15066473824637278, 0.1309356540441513, 0.1410912876682622, 0.11298555295382227, 0.11582315926040922, 0.17020008713006973, 0.19046404691679136, 0.1573619195925338, 0.0685789440093296, 0.094363546131977, 0.10724291431584529, 0.112290577031672, 0.09962938499769994, 0.08095175866037607, 0.14315767107265337, 0.07056445282484804, 0.12493540958634444, 0.11057698433952672, 0.1122669775837234, 0.09779673655118261, 0.1012418284746153, 0.07217380218207836, 0.1465047486126423, 0.07997496000358037, 0.12915224688393728, 0.17828709818422794, 0.11739057515348707, 0.17457011049347265, 0.0783853560153927, 0.10222171446574585, 0.16854416312915937, 0.16086279387984956, 0.08868765498378448, 0.06570172482835394, 0.1098228944465518, 0.09066035984350101, 0.09347170684486628, 0.14749588471438202, 0.18344832052077564, 0.15701174124010972, 0.16731034219264984, 0.18109463181878838, 0.09691588953137398, 0.14483659741069588, 0.11633280691291605, 0.11837915996355669, 0.11416620388627052, 0.07547199805932385, 0.2058590701115983, 0.06222991219588688, 0.1282303484955004, 0.13242928603930132, 0.10186897125095129, 0.1803764160722494, 0.07518551378910031, 0.08973095007240772, 0.09153265053672449, 0.14289923065475055, 0.0941040539847953, 0.1930985405508961, 0.12930001824029855, 0.16701095897172177, 0.18208806136889116, 0.19291963800787926, 0.1098394099889057, 0.12210499575095517, 0.10240206907370261, 0.17630034764962538, 0.14938713823046001, 0.10925867900784526, 0.10580325978142874, 0.07110458705574274, 0.1176573344107185, 0.05832546563552959, 0.11374770384281874, 0.13218187860080174, 0.1407725526286023, 0.14452384704990046, 0.0851443586871028, 0.15396661178341933, 0.1334721672215632, 0.2046694489462035, 0.12054695721183505, 0.09752959731434073, 0.18501657779727662, 0.08921025586979729, 0.10872062109410763, 0.10091668806437935, 0.12206508432115827, 0.12464115609015737, 0.07264035607555083, 0.12633009760507516, 0.06453180831990071, 0.13943980128637382, 0.08929890646998372, 0.14550104604235717, 0.06624732126614877, 0.09082922006824187, 0.20973726415208407, 0.1429972518235445, 0.10187828753675733, 0.07086710658456598, 0.09052395394870213, 0.13330911525658198, 0.21240070409008435, 0.16692444575684412, 0.16785330591457231, 0.17133070289024285, 0.2555341167109353, 0.23713249127779687, 0.1539906726351806, 0.13834430649876595, 0.08424534728484494, 0.11073996845100607, 0.12497179263404437, 0.14285636081227235, 0.17441623232194356, 0.08201164393020527, 0.06326070866946663, 0.09265570063143969, 0.16560412517615727, 0.0903940959168332, 0.13740172636296066, 0.0994091664573976, 0.10692153977496283, 0.08521566593221255, 0.08743163916681494, 0.12851287690656527, 0.134689988302333, 0.13909469837588923, 0.1226335202476808, 0.21523407633815492, 0.1276243081582444, 0.12583114366446221, 0.09399421952132668, 0.1570852401533297, 0.08122573753020593, 0.11786044708320073, 0.22241927364042827, 0.10100187813597065, 0.14233688797269547, 0.06215212494134903, 0.11763608269393444, 0.09010862266378743, 0.06635357306471892, 0.18035918128277573, 0.0985483837180904, 0.11970428457217556, 0.09326634822147233, 0.1620559027152402, 0.14272330009511539, 0.15538187298391545, 0.09693642200103827, 0.24796326724546297, 0.10376470988350255, 0.12566022069326468, 0.23226462677121162, 0.1184686180204153, 0.0869211433455348, 0.1505607459694147, 0.10094991592424256, 0.15240096008138998, 0.09365410384322916, 0.20180187853319304, 0.07526316533663444, 0.07783802252795015, 0.08852158353797027, 0.10442352667450905, 0.14860877713986806], [0.0513966256486518, 0.02758082002401352, 0.04540081541719181, 0.08004061505198479, 0.0471512525608497, 0.0792154146890555, 0.0063827036896587485, 0.024475192385060445, 0.07737981461520706, 0.07411175247813974, 0.02396777202375233, 0.033691628370434046, 0.02264933268140469, 0.011632616066240838, 0.03542454234723534, 0.024171578498291116, 0.050516932138374875, 0.03244272020778485, 0.03334573157397764, 0.013466513865361256, 0.038824409911675115, 0.056060678591685634, 0.03165251528844237, 0.04435538633593491, 0.03190674539655447, 0.04334217749003853, 0.06880338982279811, 0.025163744276921664, 0.020600272276039635, 0.0802387133506792, 0.06031799050314086, 0.014285370774034942, 0.01647915082451488, 0.08964763275746788, 0.034411082443382056, 0.05701750796288252, 0.02191465737165085, 0.0456753812198128, 0.008334714503559684, 0.062135297272886546, 0.02382290649360844, 0.03159962348373873, 0.03461141312228782, 0.048751553653606346, 0.003568334238869803, 0.04718755418434739, 0.026308173313736916, 0.02602681198290416, 0.07491218631288835, 0.0048063387678536984, 0.05303783222500767, 0.020459708657913973, 0.06130954051124198, 0.02243247628211975, 0.03413085426603045, 0.040551943105778525, 0.009520948082873864, 0.06896392442286015, 0.04012532099815352, 0.04264327624280538, 0.030716466052191596, 0.028850664384663105, 0.02705162208128188, 0.06471759799335684, 0.03095288122338908, 0.012562142036456083, 0.03273088724485465, 0.036148759736014266, 0.007740609597281686, 0.03962237048628075, 0.04228972217866352, 0.06071032623627356, 0.023807312062542354, 0.039532844575920274, 0.029574752851788486, 0.0343436903453299, 0.011365577761482979, 0.008545587072148919, 0.03027346750189151, 0.04003317594262106, 0.023246899812615344, 0.06724827576960836, 0.07280071425650801, 0.036923416025404415, 0.027201571535052996, 0.059840797180575986, 0.01625482884368726, 0.06628944472010646, 0.05063485813194087, 0.06277715068842683, 0.007187529766399945, 0.10114038070397717, 0.05624463622059141, 0.06298366282135248, 0.04661127778568438, 0.02256443607620895, 0.05977981723845005, 0.01315215792107795, 0.025315629251833473, 0.026723886274599602, 0.019718524500993744, 0.06921028013208083, 0.05681681766041687, 0.06780813501349517, 0.08016474624829632, 0.05411362914102418, 0.04317871840404613, 0.012189240394426244, 0.02245305116022272, 0.023307569324970245, 0.006316965520714543, 0.03310980834066868, 0.03631112298795155, 0.05189782893285155, 0.014897645151774799, 0.04297557180481298, 0.016166520903685262, 0.04149707453325391, 0.02339835391779031, 0.024351473398772732, 0.0436542052110391, 0.030904790053942373, 0.004819411593156734, 0.013317887554876506, 0.04739717740033354, 0.016468731919303536, 0.027084244348640953, 0.011979813953595502, 0.015690146912155405, 0.02149255939626268, 0.013873839285224676, 0.002171581777344857, 0.03215299254017217, 0.04364989312099559, 0.043650741289768896, 0.042330190007175715, 0.05702952481806278, 0.02576443606189319, 0.026287067481981854, 0.06360402024750199, 0.070930346048304, 0.07979727203824691, 0.029009271945272173, 0.09494573596332755, 0.011779678353507603, 0.021803995095459477, 0.04178829158523253, 0.021333473468465463, 0.06673318626625196, 0.020562393058623587, 0.01456227243345763, 0.03615357054929648, 0.05072238914934652, 0.04032185866630503, 0.012131301985521401, 0.02288602096294718, 0.08316868862935475, 0.04596160086137908, 0.07354643102735281, 0.02156010246835649, 0.032956452641103945, 0.05220352252945304, 0.0327172588690051, 0.04480287678805845, 0.04475310963711568, 0.03846698819792696, 0.009660258955721344, 0.02322319519173886, 0.018036163079419305, 0.04602689289354852, 0.014906684934560741, 0.05061362337853227, 0.026792170646201287, 0.03805675610367741, 0.027744367319558347, 0.03597711751769696, 0.02801994074668203, 0.022107232395293455, 0.028652396452214037, 0.052688692031162124, 0.005073703193504895, 0.027809175895527005, 0.05842052839164223, 0.03746729237692697, 0.08899931290319987, 0.05490766778322203, 0.03994001986991082, 0.02454278465094311, 0.026214871355997663, 0.09241655096411705, 0.04162941939596619, 0.024918101029470563, 0.03475552038954837, 0.019119858143052886, 0.037505636390830786, 0.052733814609902244, 0.024423482927626798, 0.02094848796592227, 0.06423376859830958, 0.027322174349267567, 0.04916106989341123, 0.04135226158957396, 0.036215839707957845, 0.04041215132123657, 0.06856240132557494, 0.03629076015204191, 0.0728066921500223, 0.05758217802005155, 0.03820852742397359, 0.04708924463817051, 0.04375744770680155, 0.020141611441171596, 0.0745029007749898, 0.016095960047096014, 0.026622122985177805, 0.08252194297633, 0.028998724118407284, 0.040511699193822484, 0.059603411704301834, 0.062157017178833485, 0.011153449903109243, 0.09034116340002843, 0.02238227995777769, 0.033581644629261324, 0.08662729697035891, 0.06037204260272639, 0.06471300431128059, 0.017341975954228213, 0.00985276188501822, 0.0474479046783277, 0.06370787681745631, 0.031019835666354214, 0.03162738574402673, 0.026089674859706844, 0.027589522235627686, 0.07033267204782792, 0.02807828288392297, 0.033649009585912736, 0.07957100096557822, 0.06574062524097306, 0.04739353705995849, 0.022015591152012348, 0.024343129114380906, 0.0220217895694077, 0.027367800740259032, 0.027776321229924048, 0.05535346529047404, 0.06607888173311949, 0.03572169318795204, 0.03877120937353798, 0.0487747731219445, 0.052268251377557, 0.024460678521011556, 0.05260219917233501, 0.05794059378760202, 0.028912356788558618, 0.043665207656366486, 0.05692159025264638, 0.005689186617798571, 0.010100884329793709, 0.03479604250086205, 0.024669512940038527, 0.023173026008797542, 0.04592284294111388, 0.019650258789105073, 0.07799708470702171, 0.049762323166110685, 0.023335998245914067, 0.03253008498411093, 0.061568584825311384, 0.06278391568256275, 0.022826292917930653, 0.046011432473148615, 0.020750706882349083, 0.009126763341815343, 0.04076321516185999, 0.006865271433655704, 0.06647542438336781, 0.011223947147040494, 0.029403487220406532, 0.0701043585847531, 0.04736061454085367, 0.008070995083211787, 0.04731425363570452, 0.0689288034502949, 0.04056561219372919, 0.027933795637051975, 0.0276247076690197, 0.037440405426813025, 0.05161067291295954, 0.02583429293840059, 0.017558667808771133, 0.055063849581139426, 0.03545818072078483, 0.04363325883501342, 0.043885297275015285, 0.030988925003579686, 0.07505032925733499, 0.0460154086883579, 0.03541147376277617, 0.04854377266019583, 0.0697589571188603, 0.036631506867706776, 0.035269799043557475, 0.00852061274261879, 0.06295299982385975, 0.01993050053715706, 0.06068637395011527, 0.000642194008313319, 0.012582538799116654, 0.002163244066261021, 0.0576259774555053, 0.0328704788615661, 0.04491766116448811, 0.012054178847133048, 0.038813909582261524, 0.08094766030886344, 0.017061128613672087, 0.02121937271606709, 0.033652785633291514, 0.04426778407235231, 0.03976095787116459, 0.0517398659805102, 0.05887121135102851, 0.04281756814037051, 0.07454217438186918, 0.05169673150937472, 0.01381892544616546, 0.0570067735388875, 0.03734000599277871, 0.03253505864579763, 0.010755718120240738, 0.0388491662618305, 0.03449703586686935, 0.028087332844734192, 0.05167582584545016, 0.04083184897899628, 0.07417468660111938, 0.09387901784586054, 0.05056608860780086, 0.035633565059729984, 0.015309012095843042, 0.028461714541273456, 0.012686386039214475, 0.037910898216068745, 0.0469911047257483, 0.022591762377747467, 0.06560531178755419, 0.03615845260875566, 0.05123183663402285, 0.024527081654274037, 0.008836439411555017, 0.17642761367772306, 0.10586449078151158, 0.12851818305041107, 0.1600443177989551, 0.1292618845722505, 0.27734937039869173, 0.11143735995782272, 0.0797557524804558, 0.25006886997393196, 0.17957134784332343, 0.12235435737030846, 0.11410829770777907, 0.1415044069290161, 0.17010003035621984, 0.19188614775027546, 0.08256901973592383, 0.1730434609843152, 0.17155718430876732, 0.1199527233839035, 0.1575487202831677, 0.10363075350012098, 0.17059749151979173, 0.2278280391224793, 0.1671401248978717, 0.17719841588820728, 0.09750080707349948, 0.15743089946252958, 0.10810042651636259, 0.11240111038620983, 0.11126140225678682, 0.19842122708048138, 0.13105369199599537, 0.07755873751427446, 0.19411543384194374, 0.14871249800281866, 0.0994487793317863, 0.10923957824707031, 0.14175855900560105, 0.13792414404451847, 0.20673271108950886, 0.10051913439695324, 0.10972732278917517, 0.1660101469606161, 0.1356350111642054, 0.12132860241191727, 0.2363903368158, 0.0803182851523161, 0.1157214604318142, 0.31894888675638605, 0.18128878782902444, 0.18622783065906592, 0.16270606139940874, 0.14862101791160448, 0.0969952034897038, 0.17818799135940416, 0.1316485907882452, 0.08281616933111634, 0.21543067507445812, 0.07649455033242702, 0.19203647039830685, 0.07231782802513667, 0.1490976751915046, 0.15573681465217046, 0.16646844308291162, 0.11771456205419131, 0.11165277447019305, 0.1118691728583404, 0.14420361923319952, 0.10804041009396315, 0.13421092900846684, 0.11204209750784294, 0.2074960358440876, 0.11025482269802264, 0.10024155250617436, 0.15448592177459172, 0.18772782731269086, 0.133460225005235, 0.12362750619649887, 0.13416674280805246, 0.11184055903660399, 0.1454643372978483, 0.08505220006086997, 0.16393308341503143, 0.13777254575065204, 0.1212142285491739, 0.20755300564425333, 0.12072581904275076, 0.1642609786774431, 0.15645854521010602, 0.2166467998176813, 0.12491787624146257, 0.20093515861247266, 0.12405205198696681, 0.1531041394919157, 0.13818980407501968, 0.08554936945438385, 0.11866366969687597, 0.10943450778722763, 0.08929893361138445, 0.18477048671671323, 0.12303301452526025, 0.1897683721035719, 0.09190945460328034, 0.13367993464427336, 0.21435735481125967, 0.1775581208722932, 0.14083573780953884, 0.17582894223076956, 0.17268207323338303, 0.1772391279893262, 0.0936577475762793, 0.131749298955713, 0.10565305248435054, 0.09051329416355916, 0.10813869589141437, 0.17053704762033053, 0.14330503530800343, 0.1522730698010751, 0.10041981722627367, 0.12827441255961144, 0.11569898735199656, 0.12355176811771733, 0.13669406862131186, 0.1624918614647218, 0.13302323488252504, 0.15365513706845896, 0.19119173501219067, 0.1339867410383054, 0.07831128034740686, 0.14755387231707573, 0.04809516262529152, 0.13333956790821894, 0.10828901175409555, 0.19833920576742717, 0.09038617062781538, 0.0873695599979588, 0.15368987806141376, 0.07703556665884596, 0.09259330933647496, 0.09871752214218889, 0.15126959793269634, 0.07874681840517692, 0.07270130209092583, 0.28064392932823723, 0.12598389546786035, 0.15025293534355505, 0.13001348424170697, 0.1730812011020524, 0.1528264151087829, 0.1934523694217205, 0.1681143654776471, 0.08518951519259385, 0.079120684415102, 0.09364927267389637, 0.09502264112234116, 0.10114067247403519, 0.12343723140656948, 0.1516573399837528, 0.22173056059650012, 0.08582102094909974, 0.09458919973777873, 0.1690975355782679, 0.1682837549597025, 0.0874743258048381, 0.2064986029373748, 0.0757392051496676, 0.14246642030775547, 0.0999610461294651, 0.13354312841381344, 0.09954496845602989, 0.08889629771666867, 0.08531759546271392, 0.1900666696684701, 0.1833649557083845, 0.09975609462708235, 0.10320815510515656], [0.026701157047812427, 0.039745962247252464, 0.03827894239553383, 0.03797529797468867, 0.03175466873549989, 0.0976537149399519, 0.04649748067770686, 0.054415312595665455, 0.01947781420312822, 0.07375706186784164, 0.007573209919168481, 0.008187290896395487, 0.06335575106952872, 0.018193179475409643, 0.01025431466821049, 0.020436565524765422, 0.0736888080303158, 0.06298067726727043, 0.05773593405527728, 0.030620809577937638, 0.07910779224974768, 0.010612807619119329, 0.020901114347257783, 0.039302607466067584, 0.020728922515575374, 0.025766385153734257, 0.004268626906975571, 0.018182516297591583, 0.0323844611910837, 0.011532232747413218, 0.04215704144111701, 0.026308906131557057, 0.034286343958228827, 0.02216186633865748, 0.05805739002036197, 0.03407548241583364, 0.013822326602946435, 0.04132880463397928, 0.058595393651298115, 0.01936137759392815, 0.017828383782346333, 0.045777361640440564, 0.022110764170065522, 0.04494154898981963, 0.06291521220867123, 0.011861653017279292, 0.011523769719393125, 0.0011646088803120489, 0.04626584917839084, 0.07991235836275987, 0.04850725729816726, 0.04210998843024884, 0.010281098141734089, 0.054036839332963736, 0.06672678089567594, 0.01918670910942767, 0.0850579065403768, 0.07552011297749621, 0.012065855586635215, 0.03973295473094497, 0.07453151459672622, 0.0486482602677175, 0.03534733524013843, 0.058446814838264666, 0.08427510783076286, 0.015572568667786462, 0.002011801623406687, 0.08705213453088488, 0.02227135983827923, 0.09108612699700253, 0.05843101854303053, 0.07016371004283428, 0.025473522654335414, 0.017455584768738066, 0.04720714009766068, 0.056869149673730135, 0.06851440175835576, 0.07611262332648039, 0.04517270551462259, 0.023167156680886234, 0.023791771914277757, 0.034734085468309264, 0.028950381891003678, 0.0014899301625389072, 0.008985451638831623, 0.029094160068780184, 0.036429184688521285, 0.036737782415002584, 0.0217417327221483, 0.04843709338456392, 0.020146320474201014, 0.0291146348629679, 0.057606394934867106, 0.01805098567690168, 0.07514966678406511, 0.04129871839125242, 0.01365837557906551, 0.03730550587975553, 0.042653644257890325, 0.05264554398932627, 0.0125589698852439, 0.009774520860186644, 0.03160004417545029, 0.04835253095786486, 0.07076068515224115, 0.06705802133572952, 0.017526079468162994, 0.031721026969275305, 0.06445292862398283, 0.026126785636214272, 0.04046209489128419, 0.04896512594340103, 0.03426174706380282, 0.02420955610328487, 0.017854826292023063, 0.02869439437719328, 0.02502091265549617, 0.013248164689035287, 0.020861414959654212, 0.03523566194676927, 0.033346545816000016, 0.027767758117988706, 0.05601794784888625, 0.017739052950803722, 0.06092184595763683, 0.02117833661447678, 0.024011369595038037, 0.022183633742055724, 0.04266274680516549, 0.03498671084110226, 0.033090215642005205, 0.017285409882398586, 0.039599782055509944, 0.03227707284635731, 0.03856576593326671, 0.019005253578403165, 0.01875152388986732, 0.04362528604854431, 0.01198522696670677, 0.028583582823297808, 0.037537059347544394, 0.03362178336828947, 0.016408308375892893, 0.01519504196143576, 0.10341945769531385, 0.027475655577810745, 0.01817496759550912, 0.08388531660395009, 0.04759707720950246, 0.025155276159888933, 0.06681051211697714, 0.02698629442602396, 0.05867618681596858, 0.09829214853899819, 0.041012726058917384, 0.036859080727611265, 0.05734063312411308, 0.004672581704133856, 0.08919471741787025, 0.025899043838892664, 0.010490064026920922, 0.015844822362331406, 0.08550022316298314, 0.06592024024575949, 0.11061378129358802, 0.01454542949795723, 0.029386819007673433, 0.03066111116537026, 0.031816038835261545, 0.023963169859988347, 0.03462834596367819, 0.015961072374401346, 0.019500351743772626, 0.04027340787329844, 0.034890352083103995, 0.03521811503118702, 0.018467975979936973, 0.04099558287167123, 0.05675755101921303, 0.04200351271512253, 0.08892379874097449, 0.025646995220865523, 0.04146544462335961, 0.061354595236480236, 0.01624454734181719, 0.028482006131006137, 0.034143152713243446, 0.04010010663686054, 0.06569164858332702, 0.027838444503556405, 0.03309377795085311, 0.016121472963797193, 0.02188712072425655, 0.032689310011586974, 0.005456251483077982, 0.038695586645709615, 0.017066541626783352, 0.03148454733725105, 0.007565292263669627, 0.021891113902841295, 0.04124061883028064, 0.030852325726300478, 0.014102528487066073, 0.027779305087668554, 0.002973125865017729, 0.007833988738379307, 0.014874537641714727, 0.05771275529904025, 0.03130863034831626, 0.11526927112468652, 0.06783640956772224, 0.09543565860284225, 0.03278673067688942, 0.05803771929017135, 0.02818577640157725, 0.03582281865445631, 0.07597260762538229, 0.058494556562176774, 0.02483668191624539, 0.043537690570311885, 0.01624244388325938, 0.02645733905956149, 0.045949733283902915, 0.050750195514410734, 0.04919287622241037, 0.021600146212482026, 0.04916070687717625, 0.045458287333271334, 0.021708560841424123, 0.040011873335710595, 0.07230365342859711, 0.023553450059677874, 0.028842335367309194, 0.013560387488853718, 0.030046667171908275, 0.04499740938522986, 0.022862477494137626, 0.027668306936642954, 0.04328449183542814, 0.05433688751821007, 0.030092050986630575, 0.03519836966214435, 0.04671399102413228, 0.030971439156149114, 0.028441107432757105, 0.026721716658877473, 0.059290600275354724, 0.030533692466893365, 0.05499104955898864, 0.019528249711064354, 0.011402290746835726, 0.014631199716989483, 0.012818342440628579, 0.022459062980487943, 0.015719486766361764, 0.032430862808333974, 0.008019400976731308, 0.030225084562386786, 0.022322799578042965, 0.047418340907565186, 0.009002602459596736, 0.02961425037522401, 0.0560052219246115, 0.06670139690062829, 0.050667787436395884, 0.04210730143157499, 0.06363904622516461, 0.018728748861966387, 0.05158026436609881, 0.00963474010183875, 0.032940364575811794, 0.04018732213548251, 0.01624341418833605, 0.04509860949058618, 0.07209166551807097, 0.010093445041483002, 0.00574201565801299, 0.024282245863495127, 0.04840145333270941, 0.07089800706931523, 0.031812466348388364, 0.03543589423809733, 0.07212618259446961, 0.006539360038004816, 0.04844811957861696, 0.08355966050709997, 0.06492400834602968, 0.011623454147151538, 0.02571536780201963, 0.042264154979160855, 0.03661513042503169, 0.014969675036679422, 0.0413074613149677, 0.016825405548193624, 0.03427179277475391, 0.06725008745810815, 0.017691484253321375, 0.010804880526848137, 0.05219715108562793, 0.03412211812766535, 0.0397084426533963, 0.06734181860727922, 0.009487841511145234, 0.015586655054773604, 0.022707140472318445, 0.013561972716291035, 0.03340764110907912, 0.04130210088832038, 0.012984608965260642, 0.02772113767319492, 0.043338398049984656, 0.008229282036024545, 0.02819264487230352, 0.06757521429764372, 0.03030601343406098, 0.03012138744816184, 0.0409657782209771, 0.0526908124530954, 0.07007405521082026, 0.037281031121632884, 0.03451940716643419, 0.007644199100988252, 0.02204036107286811, 0.029120931667940955, 0.010655502738830234, 0.04572550460164036, 0.07640795569334712, 0.04702096365924392, 0.03795022610574961, 0.012726910695034479, 0.04100121471232601, 0.05274547523419772, 0.05580486749698009, 0.031162711392555918, 0.04220362965549741, 0.010377377171867659, 0.014697065111249685, 0.05877359051789556, 0.057412530694689067, 0.014798521363575543, 0.045319835655391216, 0.04630662913301161, 0.013327040992278074, 0.02512075738715274, 0.041868989755000384, 0.030232904678476707, 0.02606681840760367, 0.03550189533936126, 0.015084410219320228, 0.028930504207632372, 0.0376992122536259, 0.07475128530391625, 0.13268064255160944, 0.13213484255330904, 0.14014576269047602, 0.13451280923826353, 0.17194693482347898, 0.1481634003243276, 0.14320429999913487, 0.1741642379867179, 0.05880375139947448, 0.1496978122740984, 0.0729925428916301, 0.11887349986604281, 0.1740485613367387, 0.145373725731458, 0.12315760712538447, 0.11101640361760344, 0.16800836473703384, 0.17344398663512298, 0.12242807341473443, 0.13079677149653435, 0.12344883435538836, 0.1088869571685791, 0.12629409453698567, 0.14662687134529861, 0.132461475740586, 0.08925403494920049, 0.09866218761141811, 0.10875076840498618, 0.10478537582925387, 0.13399554842284747, 0.08067486208996602, 0.12205230072140694, 0.13686938849943026, 0.18594089177037987, 0.12128570542803832, 0.16448223537632398, 0.11567173738564764, 0.20434155368379184, 0.19816716999879905, 0.10875046306422778, 0.21927667941365922, 0.16362977826169559, 0.12093270436993667, 0.18110214998679502, 0.24037765285798482, 0.11472508603973047, 0.12785876914858818, 0.10164945838706833, 0.11586414277553558, 0.12318998681647436, 0.19421888329088688, 0.19865676015615463, 0.09724666178226471, 0.1143093476338046, 0.20574878102966718, 0.0811146002795015, 0.19967098001922878, 0.12258112377354077, 0.11635530713413443, 0.13912607383515152, 0.118173373863101, 0.17534123840076582, 0.10048933992428438, 0.2017911033970969, 0.174657085112163, 0.09241868156407561, 0.14049300977161952, 0.14015172022793973, 0.09678673039057425, 0.1537405103445053, 0.164042843239648, 0.1487210068319525, 0.15766521117516927, 0.16036525129207543, 0.07914109474846295, 0.11333220292414938, 0.1376582533121109, 0.27644648456147736, 0.11992769901241575, 0.1520943979599646, 0.15155224848006452, 0.13305219475712093, 0.09044808694826705, 0.12854972135807785, 0.052689591090061834, 0.12266919761896133, 0.1081711162946054, 0.2243254684976169, 0.11796988121100835, 0.14790491919432366, 0.17483449487813882, 0.10259794177753584, 0.25553596232618603, 0.08786878535257918, 0.1779838880257947, 0.09952117223292589, 0.11079092643090657, 0.14094528050294944, 0.13080385540212902, 0.20462697265403612, 0.12774624090109551, 0.13172599806317262, 0.12935231971953595, 0.18881645532591002, 0.20602119926895412, 0.0922101406114442, 0.16398432637963975, 0.10986144202096121, 0.14367008714803628, 0.15788249165884086, 0.1312228643468448, 0.1228648056941373, 0.09600632690957614, 0.0818218644708395, 0.06857902543353182, 0.10102813744119235, 0.07481244166514703, 0.14852911712867872, 0.1752446150141103, 0.1629073420273406, 0.14851877625499452, 0.18492569481687887, 0.09615205587553126, 0.08829284938318388, 0.17794080105211052, 0.13504725056035177, 0.05667684606409498, 0.10630062595009804, 0.10160215771091835, 0.09348656676177468, 0.0865488854636039, 0.20255697944334575, 0.07345176182155098, 0.13478057272732258, 0.07861763890832663, 0.07378932620797839, 0.05968131430979286, 0.18403203705591814, 0.09331539273262024, 0.10210709633039576, 0.1557653538350548, 0.20936853465225014, 0.11493936739861965, 0.12956789029496057, 0.17779935364212307, 0.10115363927824156, 0.06053857545235327, 0.12719845958054066, 0.07415883602308375, 0.11907197135899748, 0.21454955664064201, 0.08307013141789607, 0.11671075091830321, 0.12374007515609264, 0.11151947626577956, 0.1753906086087227, 0.12160221487283707, 0.1155236539031778, 0.1599690546946866, 0.08569708652794361, 0.0859398731429662, 0.14889981438006672, 0.19435349106788635, 0.12108084213520799, 0.24661385108317646, 0.2610937069569315, 0.08108059888971703, 0.11665790661105088, 0.09753843862563372, 0.07646696788391896, 0.14107694343796798, 0.09783709581409182, 0.08368637692183256, 0.12413039564021996, 0.06851007270493678, 0.17297815877412046], [0.02487711581800665, 0.07947038100766284, 0.045268650366259475, 0.0385087384576244, 0.015122911992615886, 0.08966284551258598, 0.00839280812735004, 0.04445736336388758, 0.006495666199563337, 0.02704411748397563, 0.038057580523725064, 0.04050759744963475, 0.026892578561923335, 0.03303382938195552, 0.0352191294410399, 0.04255940252915025, 0.050910034616078646, 0.03128800966909953, 0.02639989258854517, 0.009380835690535605, 0.0200744873644518, 0.01638416270725429, 0.037210578830646615, 0.021234081658933843, 0.02912787308118173, 0.009441025139364814, 0.020326556338529502, 0.0654516371765307, 0.03613862242283566, 0.030807325283863714, 0.009110090040069605, 0.030446972298835005, 0.018210100442437187, 0.02981037074433906, 0.030278675258159637, 0.03274765723784055, 0.032738476659038236, 0.16162781497197493, 0.02466220172521259, 0.03865278126405818, 0.013388266903348267, 0.06213300382452352, 0.02388951488371406, 0.03178858870108213, 0.012222910150220352, 0.05521295765148742, 0.05122587909655912, 0.06575805680560214, 0.05025020680789437, 0.025531803723424673, 0.008976866474508174, 0.026747078601537005, 0.020856112208483473, 0.02961893905220287, 0.037816890581910095, 0.032064667636794705, 0.04715335601940751, 0.053163622439439805, 0.01540392218157649, 0.030216494309050695, 0.13095339094953878, 0.07884984716240849, 0.06810671756310122, 0.023684176616370678, 0.025297210418752263, 0.042790328352046866, 0.07027723573680435, 0.0762965605993356, 0.03896139595391495, 0.02473875574235405, 0.031012164827968394, 0.03384846156196935, 0.011763044915694212, 0.016639352942417775, 0.03110670850479177, 0.04265584610402584, 0.022000773643542613, 0.019506355082350116, 0.0261568447375404, 0.1034168249794415, 0.010509394641433443, 0.034482488076069524, 0.03770691701876266, 0.02429990473735545, 0.04738426148625357, 0.016072389436885715, 0.018918396007003527, 0.02205028973652848, 0.0077029619299407515, 0.007684547337703407, 0.012411644665657409, 0.04029510063784463, 0.06567675473966769, 0.03524239640682936, 0.032331752590835094, 0.02932249049523047, 0.027468057681939433, 0.051858226236488135, 0.07134464595999036, 0.04862598396305527, 0.0345861716195941, 0.050341978669166565, 0.017041914198281508, 0.02361795668756323, 0.03539729577356151, 0.04466769225629313, 0.037038431103740416, 0.03610975415046726, 0.02137463340269668, 0.031928641721606255, 0.032327209798885245, 0.01827495312318206, 0.044244340687458, 0.02794303558766842, 0.049235091278595586, 0.016688623066459383, 0.03003550527085151, 0.0316359861753881, 0.01511981278391821, 0.03476043976843357, 0.01383300419963364, 0.04295619623735547, 0.04568935904119696, 0.027012965941269482, 0.018096286371084194, 0.03537224765334811, 0.04218165190624339, 0.03333418630063534, 0.022562805895826647, 0.049375296969498904, 0.03985335398465395, 0.023719611411382045, 0.010646080431927527, 0.02610624298852469, 0.03505438792386225, 0.05710290838032961, 0.045261430753661056, 0.079210447812719, 0.022561540428016866, 0.04959308974710958, 0.0155731776529657, 0.04096802756456392, 0.020126047544181347, 0.015183118404820561, 0.006319262361752668, 0.10161703119852714, 0.00778829534205475, 0.029652563855051994, 0.03550606493705085, 0.020764630420931747, 0.04013755498453975, 0.028767995070666075, 0.03156015310170395, 0.0198253293056041, 0.03775486569585545, 0.04919588891789317, 0.05507457382710917, 0.04554622547168817, 0.04078603768721223, 0.03613842225500515, 0.05084347711609943, 0.032990260648408105, 0.012796902430376835, 0.04263726442254015, 0.04256769083440304, 0.05341357099158423, 0.0167336218125586, 0.016011915003348674, 0.02558634606456118, 0.015222561645454593, 0.007660655271528023, 0.07531853379415614, 0.02378146836001958, 0.08288251648523978, 0.025882457050361803, 0.02088763694544988, 0.0071029915125109255, 0.04248399693252785, 0.013612658434015299, 0.017620059960920895, 0.010525241826793976, 0.0785224133038095, 0.02834233987544264, 0.06414847674646548, 0.056759169325232506, 0.0035165261818162563, 0.04223161243966647, 0.032275444362312555, 0.03861760600869145, 0.045301857870072126, 0.015635818309549774, 0.011924919622418071, 0.028515423980674574, 0.04172476374411157, 0.026421161268704703, 0.06200957830463137, 0.02909825842029282, 0.007902077182994356, 0.0016892657274313802, 0.02243521756359509, 0.06490754708647728, 0.02594372028085802, 0.01134885526594839, 0.028924994503280947, 0.02399084221438638, 0.04702891608966248, 0.045370271163327355, 0.0107348531684173, 0.034459010764424286, 0.05462576701704945, 0.02982414500521762, 0.05258479814178177, 0.016494331349219595, 0.08426022755780391, 0.028581971302628517, 0.06810574047267437, 0.05031970914985452, 0.015422588679939508, 0.01618879720834749, 0.0630044327782733, 0.037852025125175714, 0.03508332744240761, 0.015718577529436777, 0.08950807846018247, 0.015244376546304141, 0.047475005366972516, 0.023384886694007685, 0.01669297756494156, 0.02292747436357396, 0.06071981894118445, 0.03885973444474595, 0.02586559884782348, 0.07077849669648067, 0.0311660837115986, 0.02182664629071951, 0.03782686504668423, 0.028063390736601183, 0.021494228592408553, 0.07118946500122547, 0.0573895215722067, 0.03632942647007959, 0.05712104562137808, 0.043753223826310465, 0.026355234806292822, 0.010748222852790994, 0.00589027174282819, 0.035907727134014876, 0.04988247136186276, 0.04000587169347065, 0.012331763282418251, 0.016375862527638674, 0.019259789027273655, 0.041459914562957625, 0.040162959335637946, 0.0661479023152164, 0.020327462182779397, 0.015477180214864867, 0.05978206318936177, 0.046602388976940086, 0.054118311032652855, 0.08600776057158198, 0.051868407654442956, 0.034450929412352185, 0.053193966525473764, 0.05034355287040983, 0.009144811525142618, 0.027501204117600406, 0.02265456418639847, 0.06764175144157239, 0.052939322511000295, 0.04688442884279149, 0.0040939325533275095, 0.0729684481131179, 0.05146097790982042, 0.028222205250390937, 0.04966293814192925, 0.019583801373041103, 0.07531094777264766, 0.03318567194842866, 0.006436144683643111, 0.01979043733860765, 0.040512187739035914, 0.0397852528175073, 0.019172434428972856, 0.04673481187117951, 0.02512832305261067, 0.03646375944039651, 0.008439381922861295, 0.00434106306472261, 0.049997852849108834, 0.0451913211228592, 0.04054465563967824, 0.027566604715372835, 0.017132074538884417, 0.05112894019111991, 0.02297059865668416, 0.04792344916079726, 0.03499682101288012, 0.06267952985529389, 0.010118857026100159, 0.014279072272724338, 0.09809649296637092, 0.03635606914758682, 0.04274073762020894, 0.07326426223984786, 0.060028133913874626, 0.026316794101148844, 0.00907780704021986, 0.03947558979104672, 0.06321946052568299, 0.01007704739458859, 0.031659700974289856, 0.06540686065065009, 0.015803455474919507, 0.039934164112699885, 0.0666373296241675, 0.017239571449213793, 0.07886738729264055, 0.0579073184302875, 0.03665907235283937, 0.0493709848794554, 0.03131612476759723, 0.020534391614741514, 0.021700440473588448, 0.07129617820360831, 0.03691307854439531, 0.04503556001665337, 0.017328429002580897, 0.029010992031544447, 0.038386761609997065, 0.07739300533596959, 0.029230053669639995, 0.08318822365254164, 0.06062248309275933, 0.06103644373693636, 0.04630755872598716, 0.035414313431829214, 0.03926932532340288, 0.051183165317135196, 0.08786136896482535, 0.01635285170881876, 0.0335550494492054, 0.02125565059083913, 0.036018084069447856, 0.04089191968419722, 0.023153462147872363, 0.013604409144526082, 0.05861889810434409, 0.02046974588717733, 0.02630400371604732, 0.023856739945975796, 0.015285131055861712, 0.03309476861198034, 0.15674633905291557, 0.07877828207399164, 0.13101580260055407, 0.08695873418556792, 0.20621614237981184, 0.16901980260653154, 0.17463671549090318, 0.20084654193903717, 0.07522272464952298, 0.13889246779893125, 0.11960325070789882, 0.08378658297338656, 0.19963892602494784, 0.09928905218839645, 0.18159638132367814, 0.11373932393533842, 0.11168094724416733, 0.1251519029693944, 0.1042450787499547, 0.11679132016641752, 0.20034392390932354, 0.08463327254035644, 0.18728798734290258, 0.19941441235797747, 0.11250878032296896, 0.0934044708098684, 0.2104611253099782, 0.10430507481630359, 0.15718768537044525, 0.13211368583142757, 0.21219356091959135, 0.12256948011262075, 0.10210734738835267, 0.11643233442945139, 0.20534304422991617, 0.09489736998719828, 0.23912781849503517, 0.08105593414178916, 0.121823946546231, 0.17690178751945496, 0.08466414588370494, 0.09132522238152367, 0.13319691270589828, 0.07684475582625185, 0.19193862564861774, 0.15798732531922205, 0.15205325159643376, 0.10266141872853041, 0.06602001203490154, 0.08459343574941158, 0.04016463192445891, 0.10529190900602511, 0.1703466506940978, 0.20087312694106782, 0.13051536945360048, 0.14716344326734543, 0.10671316845608608, 0.08533145114779472, 0.10483990290335246, 0.1683959575103862, 0.27670324221253395, 0.15474858268031053, 0.12426656404776232, 0.09069136889385325, 0.16103373042174748, 0.15566867616559776, 0.11433077576969351, 0.14621171647948877, 0.11644766932087285, 0.13801657408475876, 0.12406282712306295, 0.0807869221482958, 0.10882664897612163, 0.13466196480606282, 0.10078761713313204, 0.09564516986055033, 0.13299340648310526, 0.12414972031755106, 0.23137607159359114, 0.09775580731885773, 0.10241475767855134, 0.15537113855992044, 0.1555906039263521, 0.2089575459914548, 0.10939017909445933, 0.07148387456046683, 0.08727223772023406, 0.1459821816533804, 0.09623474893825394, 0.10880928526499442, 0.07266279522861753, 0.1680990034448249, 0.1351482030004263, 0.08455745982272284, 0.1119382477232388, 0.19296139505292687, 0.1575703519795622, 0.13770406799657003, 0.2741400626088892, 0.1355289425700903, 0.211984585704548, 0.0997113384572523, 0.16684589854308537, 0.21206382502402576, 0.21535357992563928, 0.07916428029005017, 0.13992684015205928, 0.11260234351669039, 0.12445089487092835, 0.11973604001104832, 0.15927252492734364, 0.05482877790927887, 0.15530696271785668, 0.1279249805957079, 0.12273846247366496, 0.10789070491279874, 0.13888040344629968, 0.09191291513187544, 0.10426483090434756, 0.11711252507354532, 0.13291764126292296, 0.1376038348036153, 0.16066677868366241, 0.1259322046701397, 0.22408832050859928, 0.11236927352313485, 0.17201728533421243, 0.14553057588636875, 0.16303653509489127, 0.08336775723312582, 0.0727484534893717, 0.1372989554490362, 0.10846727647419487, 0.08318756547357355, 0.09963624498673848, 0.10057127981313638, 0.13760335982910224, 0.1388918435467141, 0.18289166396217688, 0.102931312817548, 0.21592045522161893, 0.11596718510346753, 0.14206480900091784, 0.10726643912494183, 0.15528860156025204, 0.09505938379360096, 0.09465798283261911, 0.16268779523670673, 0.09130177221127919, 0.14534707287592546, 0.08096256093787295, 0.14944125818354742, 0.04848229738750628, 0.17262042154158863, 0.1678487868713481, 0.16096232139638492, 0.142764256468841, 0.118443064391613, 0.1237710706357445, 0.11059092144880976, 0.14074838321123803, 0.18822219435657772, 0.14087403432599135, 0.16925640776753426, 0.19709482682602747, 0.09502129083765404, 0.12303803568439824, 0.0982426969068391, 0.09085554044161524, 0.11742998446737017, 0.29231695724385126, 0.11288767427738224, 0.1691439338028431, 0.13389840934957775, 0.11670028790831566], [0.03183311077633074, 0.023617690362568413, 0.010222326831093856, 0.04458972179730024, 0.044979166971253495, 0.017821832526741282, 0.06656266363071543, 0.02880036797640579, 0.09623360221407243, 0.0506615516995745, 0.033666145987808704, 0.043917978914188485, 0.005345199897419661, 0.03727165037500007, 0.03812019573524594, 0.03478952517200794, 0.028846155519464185, 0.025719566237447516, 0.027908752605851208, 0.014228508691303432, 0.038610936009458134, 0.0218985150235572, 0.06338806969246694, 0.02176263668973531, 0.02272535744123161, 0.022386481785880666, 0.025350787543824742, 0.04793186638770359, 0.03136937280318566, 0.0641580508755786, 0.04487946642828839, 0.02583835566682475, 0.06123852503619023, 0.02943113073706627, 0.053003318541284115, 0.03832931683531829, 0.04428757693884628, 0.02547961929147797, 0.048244484434170384, 0.08818807679095439, 0.030873166929398264, 0.012198996879825634, 0.009387309762782283, 0.0469418057639684, 0.024485635038997446, 0.016582035393054997, 0.03268639570368188, 0.025476121443456838, 0.04589740466326475, 0.03954132626365338, 0.01448764545576913, 0.04994616883673838, 0.0033193865258778843, 0.010557875968515873, 0.05306355548756463, 0.015174249952126826, 0.0465590068405228, 0.011923918783265566, 0.029853932692536285, 0.06589517516217061, 0.01675876832034971, 0.012287387940367418, 0.020507903303951025, 0.05356369007911001, 0.041888972611299584, 0.02846482562433396, 0.0459477824957243, 0.02069507209983255, 0.02449852381167667, 0.059920009358653, 0.004504757941633995, 0.03989406269309776, 0.027914211420076232, 0.06984527355858258, 0.031073667242058685, 0.04797300257320915, 0.07361513948334114, 0.010121515187035714, 0.10446495123739753, 0.015321200281115515, 0.05396915885752865, 0.024192278905372535, 0.03854185775188463, 0.017075713723897934, 0.04494924018425601, 0.03475856361910701, 0.037546362062650065, 0.03635153992633734, 0.03571276705978172, 0.030707672238349915, 0.01758519683166274, 0.023362964923892702, 0.033939144374536614, 0.045019933355173895, 0.07781797181814909, 0.12848627833383425, 0.017905411077663302, 0.026021358257691776, 0.023866636379222785, 0.036632572167686055, 0.045039366598107984, 0.03196104516142181, 0.021549904087026204, 0.055966789701155255, 0.05079312642504062, 0.013184898083896508, 0.05176723808316248, 0.011836090058620487, 0.02416478975542954, 0.05056576291099191, 0.03505121577265007, 0.05985755021018641, 0.04983441751184208, 0.01868744643538126, 0.06519403814205102, 0.04186448428247656, 0.045220437060509405, 0.027762180560135415, 0.024622291991753236, 0.044400166254490614, 0.03814423283828156, 0.02092639995472772, 0.030006158631294966, 0.0273100845515728, 0.008989595791458018, 0.06665715641741242, 0.04835301950307829, 0.04443860865597214, 0.034724884533456395, 0.05110868592081325, 0.03140360828755157, 0.013017277881902243, 0.06210507532315595, 0.06809308579457657, 0.065066032510783, 0.046982131100126674, 0.026425276583592807, 0.04744019991319094, 0.021467370480032902, 0.020743032651288167, 0.053820410410740545, 0.01774365172189261, 0.022379117984590784, 0.03823024732992053, 0.018225966287510734, 0.02647594448977283, 0.007154815896813358, 0.039101971446403434, 0.055295949269618304, 0.06603379986648049, 0.04299400081591947, 0.026387046224304607, 0.010958280331189079, 0.02286201948300004, 0.008803946914018264, 0.0499738734215498, 0.03267034495781575, 0.0789794677070209, 0.06934224840785776, 0.05173139786347747, 0.027181500469201376, 0.05002738269312041, 0.02379618408823652, 0.019283663281904798, 0.03837951146332281, 0.04657295412783112, 0.06192155195666211, 0.05039399516369615, 0.03619839796530349, 0.03554882960660117, 0.05144244372578604, 0.02413328707085124, 0.01779536796467645, 0.047121352915252955, 0.02905983298218676, 0.021664447583524243, 0.043040985973285775, 0.042531541881284544, 0.0416642044936972, 0.022068399836176207, 0.0472387055467282, 0.04084492774148073, 0.03246297108541642, 0.01852458106753017, 0.05892447634999241, 0.10513200544353042, 0.03275526700807469, 0.060238554408507686, 0.03627987645034279, 0.027542477706447244, 0.03334068327343889, 0.04646018160773175, 0.029316047805228403, 0.015845928374411802, 0.044129169546067715, 0.01861582706416292, 0.019563106054972326, 0.021730754025546566, 0.0523660995199212, 0.03531620744615793, 0.031925143873585124, 0.016603969037532806, 0.027213155824158872, 0.03722297227276223, 0.04662032265748296, 0.1128577712391104, 0.022074871363916566, 0.05776269547641277, 0.04395192602117147, 0.03550647205806204, 0.01488442559327398, 0.00942443750266518, 0.044977368853454075, 0.024056760195110525, 0.030017249286174774, 0.01720714256433504, 0.054705111509455104, 0.04019503368596945, 0.056486876614923985, 0.02575639372558466, 0.036855898398373804, 0.10591052259717669, 0.01586194010451436, 0.014069542355303253, 0.03358505426773003, 0.027922862741564, 0.027376881235146096, 0.027248644901971732, 0.07868097336696726, 0.039393510802515914, 0.05512148095294833, 0.06415222904511861, 0.035317405060465844, 0.04167220442156706, 0.020658018998801708, 0.02705147280357778, 0.0074133776028507525, 0.03472152239243899, 0.025798897159152796, 0.008589994644613137, 0.01967798712264214, 0.03319105612380164, 0.011452046023415667, 0.017593422372426306, 0.022512763938201324, 0.06891248468309641, 0.024076459763039435, 0.042179762186216455, 0.029385085350700786, 0.028498833799468618, 0.030642135933573757, 0.03202740927892072, 0.05956711008080414, 0.026839367845760922, 0.04431800923443266, 0.0312221612382148, 0.08159160361226116, 0.004445003179301108, 0.025000015473259345, 0.08846165532512323, 0.014945620970268334, 0.012827160003195916, 0.037021952880812545, 0.0785937544756702, 0.04486367691840444, 0.055933653443519554, 0.044855548068881035, 0.020378393021279147, 0.030826839951000044, 0.08773727848061494, 0.023371180286630988, 0.1277880250875439, 0.025479224044829607, 0.07402593136898108, 0.030529220921120474, 0.03382096732301371, 0.023097745941153595, 0.021697385369666984, 0.022853463156414882, 0.06483461135732276, 0.021311142881001745, 0.011917649119693254, 0.016162673610129526, 0.029687382879533937, 0.03118514036759734, 0.044593301069523604, 0.04574583690347416, 0.04784072895667382, 0.028408749794055308, 0.05172601368810449, 0.03879366209730506, 0.03023638895579747, 0.05098344871242132, 0.00713936735077628, 0.03174905725089567, 0.03320579729708178, 0.05836905472512756, 0.016840962659833685, 0.02547094931027719, 0.028072043754426495, 0.042270122694649866, 0.019341895157205205, 0.026672110660001636, 0.05784568709454366, 0.005886087726269449, 0.05124519359586494, 0.05422077321314386, 0.056971238659960885, 0.038833631202578545, 0.044937840795942714, 0.03350100752764514, 0.06007958722433873, 0.024990151270425746, 0.03429366874375513, 0.011156419341984605, 0.020122965298859135, 0.01813636743463576, 0.07303054085267441, 0.02242254083310919, 0.02279238821938634, 0.05812109088791268, 0.061452582478523254, 0.06818691361695528, 0.011899726465344429, 0.012386948535484927, 0.05696658390973296, 0.0583901707349079, 0.03273192879610828, 0.01204468953489725, 0.022914483810641935, 0.019218681679506387, 0.040520811919122934, 0.03951809661728995, 0.04707821844411748, 0.031189669588846818, 0.027835306279095154, 0.027172942446278672, 0.012840402462253613, 0.013393351675144263, 0.026481123408302665, 0.12739057998572076, 0.06450985092669725, 0.027481399376743605, 0.06657670252025127, 0.06978167447128467, 0.024727865255304744, 0.050213063800973554, 0.019025662215426564, 0.004392161416555089, 0.007614272313990763, 0.04024087551182934, 0.0576419433844941, 0.09540444599198443, 0.11809471808373928, 0.07813115644135646, 0.09352001853819404, 0.19354029398943695, 0.12402538556073393, 0.14754536348794187, 0.09038024701710258, 0.17533207817801408, 0.2620730772614479, 0.10668705164321832, 0.13807728939822742, 0.16653408456061566, 0.1339524071663618, 0.10999140183308295, 0.07694796100258827, 0.0886754956362503, 0.11917942416455064, 0.1885980756155082, 0.11427810788154602, 0.08558150487286703, 0.05572475286732827, 0.1818518497581993, 0.10846216032015425, 0.0711629410673465, 0.07914025336503983, 0.147408448691879, 0.08172013850084373, 0.12486458410109792, 0.20489709744496004, 0.14835679637534277, 0.12109448068908282, 0.1554671512650592, 0.11679826836500849, 0.11282918455877475, 0.12314938328095845, 0.11645320616662502, 0.15628127115113394, 0.09100091656936066, 0.17563270990337643, 0.15581845598561422, 0.09371174539306334, 0.1654848658612796, 0.11310629147504057, 0.12303270239915166, 0.14627131899552687, 0.11661172551768166, 0.1283703845526491, 0.12744320716176713, 0.124628589621612, 0.13839952567858355, 0.15160317931856426, 0.09487932774105243, 0.08697886631957122, 0.11785055404262883, 0.15356379268424852, 0.16209506775651658, 0.08940748564366784, 0.12190013245812484, 0.11790763240839754, 0.15776266237454756, 0.10486749213721071, 0.10925425495952368, 0.14192674069532327, 0.12331829778850079, 0.0787836696420397, 0.09843383343624217, 0.11979522183537483, 0.06333860448960747, 0.1464403284979718, 0.11619560713214533, 0.14246461540460587, 0.1566216650285891, 0.15630375780165195, 0.07803259244454758, 0.20464639232626983, 0.2199950444379023, 0.12694281472691468, 0.16842702084353992, 0.08553566304700715, 0.11676426018987383, 0.04975552085254874, 0.10434064362198114, 0.16029806275452885, 0.10851699952036142, 0.13509325523461613, 0.12713099962898664, 0.14099176015172685, 0.19322090755615914, 0.11870385254068033, 0.16107911084379467, 0.1622083288218294, 0.09306619396167141, 0.1431297425712858, 0.10923368856310844, 0.22938641692910874, 0.09790516644716263, 0.1395853470478739, 0.05379891102867467, 0.12439672063503947, 0.10837857837655715, 0.07188689722014324, 0.07031574259911265, 0.18538601297352994, 0.15628769009241036, 0.09243983150060688, 0.09476983254509312, 0.17561322237764085, 0.15611279090600355, 0.10231308599135705, 0.08432391485465424, 0.11928682268730231, 0.1999914656792368, 0.1462630680097001, 0.109761446315263, 0.07428590527602605, 0.19221438228019647, 0.09449600295296737, 0.0878833399287292, 0.11043257173150778, 0.15238391528172152, 0.10920331733567373, 0.12649580942732946, 0.09259437463645424, 0.1634503057492631, 0.21704794972070626, 0.1360889510916812, 0.1205591301300696, 0.10809353938592331, 0.10673668647983245, 0.09393136003719908, 0.09168278319495064, 0.13397165041949066, 0.17503110718514236, 0.132428037534867, 0.09113485938204186, 0.1032960389607719, 0.11381495344851698, 0.05999407824128866, 0.1021557269351823, 0.16958985344639846, 0.11612980280603681, 0.07806380505540542, 0.12523042304175241, 0.1151726341673306, 0.11802985013595649, 0.13936798514000007, 0.12093725055456161, 0.12058329954743385, 0.1898944710514375, 0.10658693380121674, 0.10586591570505074, 0.09497750497290067, 0.08505249183092799, 0.05876380604292665, 0.15148937542523655, 0.08070405266646828, 0.1072231282347015, 0.2103820081268038, 0.11411452665925026, 0.11573804382766996, 0.1274378603058202, 0.10136831418744155, 0.07925542111375503, 0.1941279053155865, 0.09890654842768397, 0.1858947513891118, 0.15870085917413235, 0.16631655980433735, 0.19654484705201217, 0.1621639933437109, 0.07690987483199153, 0.10922739854348557, 0.1373269518039056, 0.1319394108972379, 0.16347347093479975], [0.040644994005560875, 0.010635657285872315, 0.005443505202752671, 0.050634155848196576, 0.043510040268301964, 0.03491698118991085, 0.007727971034390586, 0.04357973260006734, 0.010709735498364483, 0.00893880405263709, 0.017490213803414787, 0.04286299605986901, 0.023161110933870077, 0.0450808284804225, 0.05121987406164408, 0.02151653203847153, 0.026766333729028702, 0.052898315247148275, 0.02202829672023654, 0.02883802666994078, 0.054989594101373634, 0.032597063175801716, 0.031170137958335023, 0.026516525972900645, 0.029135194474032948, 0.06958496716937848, 0.046431713671024354, 0.054292894700276, 0.0824281151539513, 0.043850447716457505, 0.10082288059805121, 0.035924100184014866, 0.033408187329769135, 0.050502526839928966, 0.005988328958795006, 0.04862682534647839, 0.028587779562388147, 0.02652821713127196, 0.013537595497577317, 0.030389144151870693, 0.014000629490640546, 0.007326350397696453, 0.09440164587327413, 0.021880399834896837, 0.033571507316082716, 0.00499158985413877, 0.08654401358217001, 0.050953477820647616, 0.030141746891396384, 0.027732403050842028, 0.058615600424153466, 0.01841769483871758, 0.06373853981494904, 0.04885800222733191, 0.05256755995963301, 0.04693692370450922, 0.03710451362920659, 0.029024898606751646, 0.03522050008177757, 0.02817475190386176, 0.0679547121482236, 0.08877889758774213, 0.0028066358479138997, 0.12070061825215816, 0.008433194531659995, 0.046230986049132686, 0.02996563651998128, 0.03499278033684407, 0.01113662138647799, 0.052913409258638106, 0.03766093948589904, 0.022606583278892294, 0.014742289470242602, 0.05084166882027473, 0.04610460211655923, 0.06410455517470837, 0.012110886563147818, 0.023470282022442137, 0.06663406587072782, 0.014171075790987482, 0.057620298117399216, 0.022412708860688975, 0.0761705498610224, 0.024808743236852542, 0.025159912250403847, 0.09683245686548096, 0.010164959239773452, 0.013079301919788122, 0.059881108946033886, 0.03743347419159753, 0.026811334171465466, 0.010692867117800882, 0.021889146151287214, 0.0030645841158859965, 0.057908112316259315, 0.02534224818061505, 0.021043420104043822, 0.08782668225467205, 0.06259343733212777, 0.03622185152822307, 0.006349938505861376, 0.008420071664399334, 0.03257111260401351, 0.02912187483161688, 0.023562681528606584, 0.03895107204360621, 0.036343746951648166, 0.08487213722297124, 0.029605510844183818, 0.04357398540845939, 0.10108991126929011, 0.07749116221176726, 0.07345651835203171, 0.00927010047182973, 0.043877853745860715, 0.030540962969618182, 0.01913801913282701, 0.03612244614799108, 0.03855434958157795, 0.03072170094986047, 0.06521336960473231, 0.040993666010243554, 0.04948781503896628, 0.06717352156660386, 0.00795740238390863, 0.02470975515565702, 0.016573711464713727, 0.04614688163357122, 0.05501033691689372, 0.050211696552910974, 0.035257412386792045, 0.039619164408317635, 0.0426268998001303, 0.0722588769027165, 0.016523640669350113, 0.10266656202397176, 0.015594147777717029, 0.054612433803933005, 0.06662217793720109, 0.017166971594893506, 0.020586684612291198, 0.05334148682387812, 0.08287809243691818, 0.009311100102162786, 0.03764969276796494, 0.04116079257801175, 0.02381464702609394, 0.01634587297615196, 0.01988066722904997, 0.01416350673285446, 0.09620498839233603, 0.02048746752552688, 0.02494975977710315, 0.016574686858803034, 0.07180728470640522, 0.053509152826986144, 0.023110480347116078, 0.033210129743175845, 0.032890532964042256, 0.028691480069288185, 0.040953445847013166, 0.0327271485169019, 0.038023775909096, 0.07877364089446408, 0.07883746389831815, 0.011516926693730056, 0.03253876005432435, 0.05771541515631335, 0.05621525226160884, 0.048838932000632794, 0.05145529178636415, 0.03369739931076765, 0.026571351602407436, 0.04660046533016222, 0.07079764495470695, 0.028230232319661548, 0.012654153081322355, 0.05760349759033748, 0.01912339331050004, 0.02620701052780662, 0.03744406273056354, 0.0369006817096046, 0.011692577357670026, 0.06680110762161867, 0.019082482737888182, 0.008652310452557035, 0.0060667930520139635, 0.031273519553776295, 0.017218862560444644, 0.043343582057527134, 0.04499599124704089, 0.020543994581592933, 0.045405867110405645, 0.022164880730477825, 0.02570695396778839, 0.05777574370482138, 0.02361606527119875, 0.03254676337486931, 0.08164061419665813, 0.0209467169895236, 0.03974162980115839, 0.03951818482684238, 0.02862984873354435, 0.03042647036324654, 0.027035444110099758, 0.08434393163770437, 0.07587907835841179, 0.04611900741500514, 0.043010363687894175, 0.033912807037787776, 0.06579794787934848, 0.010602204661284174, 0.06470923165657691, 0.05581174784206918, 0.048414087654756646, 0.024471426515706947, 0.01401697624740856, 0.03801398125610181, 0.05961997474410704, 0.05836838976080928, 0.005270264610382063, 0.056074805690773895, 0.027354269055649638, 0.04966217139735818, 0.018755057360976934, 0.03406492441094347, 0.022286268948976482, 0.02124938940895455, 0.009907956467941403, 0.013617245330741363, 0.023872775424804007, 0.03908666030370763, 0.005802681353608412, 0.04569813249898808, 0.03671802008258445, 0.07353243963526827, 0.05975262834025281, 0.010724861740267702, 0.03263106456558619, 0.0589683572096484, 0.02604136147004153, 0.030608762188681533, 0.08183196785726718, 0.011649588771563555, 0.06329076098544256, 0.008964820781589618, 0.01370933949614742, 0.019009957522419945, 0.05227519279079778, 0.06547577266714402, 0.02328800716038261, 0.011091566661239734, 0.0419363547116518, 0.030442097024726014, 0.05216492067224213, 0.02649569494782814, 0.03540482072691832, 0.0768521586433053, 0.06887922289648227, 0.014540510119072028, 0.052010469138622284, 0.08903632020311696, 0.02807230838308377, 0.003061542158580518, 0.056646976952574084, 0.023780689741085683, 0.022281880523743372, 0.0616119025009019, 0.03210545776944075, 0.023439976952171752, 0.049843201147658486, 0.053845516206430535, 0.04942742542230657, 0.07314674675996814, 0.031906511301973035, 0.026212576211297085, 0.019905089400708675, 0.00856833326231156, 0.008644158702476748, 0.07269528348531042, 0.020548342294724922, 0.03310900427667158, 0.007877931514355754, 0.05447990573676569, 0.02889585481690509, 0.07709833114807095, 0.012279068252870014, 0.05802078305610588, 0.06678208828504596, 0.05037473155451672, 0.0690538574542318, 0.0342259102367929, 0.08784579658614737, 0.08654534351080656, 0.007717784527423126, 0.0239387714370553, 0.046299382379012446, 0.029528446229440824, 0.009441818177167858, 0.012323950799847288, 0.02622305618466011, 0.03708788612857461, 0.010876655961120767, 0.026903362179707204, 0.01723576826043427, 0.023088046283062016, 0.044871371505515914, 0.0123597019618111, 0.06624269365732159, 0.012856206391006708, 0.012712143228522368, 0.031214883950139796, 0.034183152352592776, 0.06214337862495865, 0.025911795208230615, 0.021386865692745363, 0.05051869972209845, 0.057726610984121046, 0.06075183900871447, 0.013847920943849852, 0.06209591510040419, 0.027445811911353042, 0.057816387952438424, 0.03626331341053758, 0.00633417656146256, 0.0252861469052732, 0.061004389742655415, 0.015304043523168989, 0.07260741320039545, 0.053491741618407626, 0.027482630917802453, 0.02499146762836192, 0.04484139382839203, 0.026584150469196693, 0.01378233714162239, 0.010522015392780304, 0.018232161312230995, 0.024239515120695745, 0.045166876898812394, 0.04433878258402858, 0.05250383534335664, 0.06864290272018739, 0.06239116604306868, 0.01074108127171972, 0.04448321894077318, 0.020619118586182594, 0.018620456369327645, 0.021817860958565558, 0.03047971839883498, 0.012464114930480719, 0.053077194041439464, 0.05048279504158667, 0.17688696831464767, 0.13091700790183886, 0.10625630404267992, 0.10345085351062672, 0.08356283605098724, 0.14975276003990853, 0.11922712517636162, 0.17633800634316035, 0.16555597633123398, 0.112130225636065, 0.0981041332706809, 0.08470771461725235, 0.07348876233611788, 0.15988252790910856, 0.13932246901094913, 0.11078215975846563, 0.1182824687233993, 0.10456563226346459, 0.0691683195265276, 0.16999154617743834, 0.11137228166418416, 0.07949317299893924, 0.20646413335842745, 0.17150461141552242, 0.14309276241276944, 0.1115076561857547, 0.08011604100465775, 0.17728640830942563, 0.15758533403277397, 0.16145932115614414, 0.18302396472011292, 0.1068829514884523, 0.1041475325556738, 0.16979082194822176, 0.12932645396462508, 0.09981206698077065, 0.11102994039122548, 0.19832499724413666, 0.06655899954161473, 0.13386436046234199, 0.09149833702083145, 0.1121122037459697, 0.1235842699451106, 0.11474622919091157, 0.0588326094938176, 0.09223317687532731, 0.21420609578490257, 0.12536298164299556, 0.11755795617188726, 0.14987697266042233, 0.210844986140728, 0.10856130107172898, 0.08855868583278996, 0.16110223531723022, 0.07156578052256789, 0.15609076565929822, 0.13036135557506764, 0.075136564272855, 0.09133803312267576, 0.19555495945470674, 0.14010963748608316, 0.13694831569279942, 0.10191403954688992, 0.30675821804574555, 0.12767730174320086, 0.11003473986472402, 0.12178407582853522, 0.10742351319640875, 0.16101656348577567, 0.08420324418693781, 0.1458570190838405, 0.09228613653353282, 0.18258522397705487, 0.16249730331557138, 0.08490900881588459, 0.13729257721986088, 0.12991202968571866, 0.07930656229811055, 0.20910736652357237, 0.054687469598970244, 0.15683848410844803, 0.1300190482288599, 0.18102471557046684, 0.09490886437041418, 0.1586587085787739, 0.1792717474911894, 0.09477399875010763, 0.1248956745756524, 0.17260686441191606, 0.2113932967185974, 0.1750217162604843, 0.1067779753357172, 0.11761746369302273, 0.08743247376488787, 0.18581975969885076, 0.13357861579528876, 0.16838914501879895, 0.18667316676250525, 0.12482868959861142, 0.1799523045441934, 0.1318887107606445, 0.060687181406787465, 0.10597871536655085, 0.13573139027825423, 0.19555189247642243, 0.11508800727980477, 0.08070781175047159, 0.16748931258916855, 0.10083419856216226, 0.15326567153845513, 0.13504731841385365, 0.24647475140435354, 0.1833997509841408, 0.11917729356459209, 0.1977622067289693, 0.10885652487299272, 0.16950441231685026, 0.18779717359159673, 0.12205000727304391, 0.10600863876087324, 0.16706977438713821, 0.15318804713232176, 0.22975882408874376, 0.07814002489405018, 0.08466755891484873, 0.16641155470694813, 0.11534471064805984, 0.08133207075297832, 0.15375003697616713, 0.1350991042064769, 0.1691759063729218, 0.08392412202166659, 0.23090055425252232, 0.2223323125924383, 0.09140389851693596, 0.16296245264155523, 0.1475986149162054, 0.1291006375104189, 0.1562485657632351, 0.058694018716258664, 0.062433778042239804, 0.15391835437289306, 0.25558383975710186, 0.06758605050189154, 0.2514321282505989, 0.1329633609524795, 0.08920731781316654, 0.09136394637503795, 0.08359001137848411, 0.0868793727297868, 0.14601806258516653, 0.13236858429653303, 0.10259608937693493, 0.14104612437742098, 0.14376137724944524, 0.08735994515674454, 0.09333879540541343, 0.1412599171910967, 0.09756642819515296, 0.12867465322571142, 0.1408363077789545, 0.17013939895800181, 0.183823360396283, 0.14400925966245787, 0.13565878703125886, 0.13688926957547665, 0.1661444968943085, 0.10555374888437134, 0.105240856031222, 0.10622127806501729, 0.07468253613582679, 0.10482084964002882, 0.13967437084232057, 0.0691377515239375, 0.1632169439856495, 0.123904660610216], [0.011949994884032224, 0.048637173005512783, 0.03267321176826954, 0.024962390706475292, 0.060312222955482345, 0.033207262932722054, 0.01654624267082129, 0.05709836898105485, 0.03353103609489543, 0.041615244799426625, 0.028781871111797433, 0.0807253790221044, 0.046163940003940036, 0.07336681602256638, 0.09900167225194828, 0.03080280284796442, 0.04099962354770728, 0.02705897231187139, 0.03921559213527611, 0.04334372115720596, 0.04112786666623183, 0.03733706793614796, 0.02898216786395226, 0.020858064692999636, 0.024757352690877657, 0.04485797043889761, 0.0814862542652658, 0.057494484154241424, 0.02212753246671387, 0.036975968562598736, 0.012544874168400253, 0.022693825918915014, 0.060404306942863126, 0.04843372445819633, 0.03847569380221622, 0.11091696431062051, 0.06289220308618886, 0.02326245522791786, 0.01440409743892295, 0.0317574778704771, 0.08146654960832425, 0.03111621817307813, 0.04584962561992662, 0.07752194056021315, 0.0512472733056971, 0.051282743723796945, 0.07014928438833781, 0.019607321093125, 0.01978294800833932, 0.047632391564548016, 0.02872152899258903, 0.05788228727344956, 0.08975123826946531, 0.04345126895766173, 0.04093850450590253, 0.020084872342912213, 0.011941691311741514, 0.022768910907741104, 0.0623134398566825, 0.07385539516274418, 0.06682711586888347, 0.014126427338591643, 0.032390456047973464, 0.08319089708051511, 0.06883727586162941, 0.017119177284517458, 0.033878568160746775, 0.022072065621614456, 0.05054322197767241, 0.032647088170051575, 0.04736373240926436, 0.03379510156810284, 0.005800013438731964, 0.06504259591123887, 0.047219791383083375, 0.04760447324120572, 0.007929733422185694, 0.020777649811602066, 0.03946003098306911, 0.0332844055789922, 0.030558095978839055, 0.04910485326711621, 0.015849190431513956, 0.0690003956801125, 0.009151226225575166, 0.013249890712488974, 0.046488479910684485, 0.007929432322271168, 0.022065248041014587, 0.08246381966663258, 0.07006047093974692, 0.014030361198820174, 0.03731487305568797, 0.041150227787771394, 0.0685570001868265, 0.03694364654698542, 0.04259728853191648, 0.04219343127416713, 0.023481443923498903, 0.05759585050067731, 0.05411796497979334, 0.011243689971576844, 0.05360487036939178, 0.07792281904923064, 0.01787740284843104, 0.03077670299847211, 0.027081301202997565, 0.016703181035284485, 0.043855119430060895, 0.028955810171152865, 0.043061063824487586, 0.04666285662512694, 0.05703382673008101, 0.017877306157190884, 0.04183272205825363, 0.05068771940256868, 0.062445693117167266, 0.03366887030590858, 0.020623420498200824, 0.08717826740550143, 0.04881827400199004, 0.0055768657475709915, 0.061889199406972954, 0.02043964437741254, 0.01633838194954608, 0.017103962833061814, 0.041453644899385314, 0.07971914551619973, 0.031273950423513136, 0.011799064098990389, 0.03132613655179739, 0.04600119337971721, 0.06600113519068275, 0.01824361498334578, 0.009681790568200606, 0.07484948289181505, 0.07799057077084269, 0.05309690209105611, 0.06107817364058324, 0.033020974536027224, 0.015144835459068418, 0.06724033690989017, 0.06700465455651283, 0.020236019410991242, 0.029386221896857023, 0.0147470850164869, 0.03617405552150948, 0.011807170896125692, 0.05910132971725293, 0.009476641442493668, 0.019970980240032077, 0.006906346975093973, 0.013279736075284225, 0.021113743473376547, 0.06950691528618336, 0.01803526741319469, 0.03416549687140754, 0.09235320972012621, 0.032498285440461974, 0.03175367807437267, 0.051394579865570576, 0.04189360361280186, 0.04880259305770908, 0.07725206004189593, 0.03382744054709162, 0.06932579393365554, 0.02700232820851462, 0.031112625330154384, 0.05838499351271561, 0.04552347419251289, 0.02984401590323874, 0.11215018135096345, 0.028426313673013022, 0.01856089965440333, 0.034586127514817884, 0.030637959550533975, 0.07682288664260081, 0.043722228346658606, 0.03470287964280162, 0.035381706431508064, 0.026419512428609387, 0.025626671400719454, 0.018818921076932123, 0.0199729021904724, 0.043632505661142726, 0.02476815157569945, 0.09307455351310116, 0.009315670035513384, 0.01996871902208243, 0.002444725837059585, 0.015054726008591908, 0.02235515891308231, 0.05882412102073431, 0.04999859245227916, 0.04925062633784754, 0.02137313044763037, 0.03519026795402169, 0.016621329355984926, 0.04939300673348563, 0.007878899274926101, 0.015925120196438262, 0.05963862767176969, 0.02534097932013018, 0.017157455141256963, 0.06476323625871114, 0.0066382531242977294, 0.03637846080320222, 0.012767640607697623, 0.05844942041273628, 0.06600121661488499, 0.08745587643768106, 0.05051473707758954, 0.044737031749848805, 0.05429155798628926, 0.0327762948083026, 0.03385534190705844, 0.06083301893834557, 0.058930352463253906, 0.02160229716849114, 0.03449818937640105, 0.05563026008063129, 0.0402536964310067, 0.04088708512218935, 0.027086978844766105, 0.012765850971585937, 0.038547482807189226, 0.016501705328534757, 0.038900626357644796, 0.09017732433442559, 0.040779316797852516, 0.07912212290934154, 0.047469261568039656, 0.022313788632995317, 0.044846004473843744, 0.019098701421171427, 0.04423117710809622, 0.01228370943239757, 0.050220622681081295, 0.045333511528692076, 0.026436974527314305, 0.023382328616987382, 0.01921075808682612, 0.0867225836430277, 0.004052918080040919, 0.037203002987163405, 0.018260939678709422, 0.07616144392107214, 0.02275411205898438, 0.012958121502638927, 0.025155340620715703, 0.05341764898704631, 0.017269220036853637, 0.022038825887388418, 0.028956461564770768, 0.08130454258727175, 0.017064818147835985, 0.03646508597635797, 0.025946716012965356, 0.023017395520582795, 0.04347772843071392, 0.0694559369502323, 0.024716208023684363, 0.055161690938153436, 0.01800468414356666, 0.011244009731204381, 0.017694264550560286, 0.03720479431961264, 0.027943454583042433, 0.06496480865670101, 0.028579844095345055, 0.06713878735899925, 0.018245630232351165, 0.009735626384748943, 0.01162361360288092, 0.017854173202067614, 0.034468998799898794, 0.04400833263727171, 0.02281776034007115, 0.05000117088535002, 0.06355733703821898, 0.053688221611082554, 0.05450117102425013, 0.05612996380243983, 0.06409780375127282, 0.04205955970766289, 0.03569527442700096, 0.014531787551407303, 0.03431273897045425, 0.020740781611363803, 0.0052426304235788325, 0.05501176184043288, 0.002112151015483375, 0.035015633396272144, 0.07073572184890509, 0.079524019200887, 0.0696639282894986, 0.01828639322359647, 0.058021597298128266, 0.04879997730521219, 0.02534502338884132, 0.059480406876121245, 0.039408007703189335, 0.04047345017482128, 0.04842837420957429, 0.031186273521078483, 0.07493428619844572, 0.013724603989560689, 0.023541456953223263, 0.0521454568952322, 0.05286633589171937, 0.054693383031657765, 0.03784180638779487, 0.024017691845074296, 0.022482803224452903, 0.034460398368537426, 0.009180633085114616, 0.04100624944216438, 0.038563944066741636, 0.07249865082225629, 0.04433357482776046, 0.0697220583845462, 0.005276441399473697, 0.06240992075098412, 0.06166174089802163, 0.039097262413374016, 0.013769116734952798, 0.022090881397681575, 0.04097702833158629, 0.017498106862019216, 0.027066750019522648, 0.05516463917280946, 0.01286504855046847, 0.043961340694555213, 0.02604322913768036, 0.0659341841403927, 0.020925814718274132, 0.03358572941007359, 0.015161552865590368, 0.03392121408666883, 0.0507234544493258, 0.020790862584752694, 0.025417808143954192, 0.009411551274492272, 0.02836008695885539, 0.023737930160548006, 0.04388917849532195, 0.033831654249557426, 0.06998862765197243, 0.05997577815183571, 0.04860603503350701, 0.014149380481934972, 0.03687544699226107, 0.13631760382226535, 0.13458769236292156, 0.12218618925128664, 0.10368186754307576, 0.15411572663911752, 0.0778814759105444, 0.1566358328397785, 0.1739651286708457, 0.2077641657420567, 0.11694956810346671, 0.1921935241137232, 0.2225235237606934, 0.15359951076763018, 0.15447275819522993, 0.18230608824108327, 0.1189679926527398, 0.1444059448050601, 0.1733087274645056, 0.19663031532296113, 0.18340281796242508, 0.1011899137603385, 0.16729928207184586, 0.07265888008155993, 0.12715311987059458, 0.1564331137176071, 0.10698891830231462, 0.13838081168276922, 0.12079991506678717, 0.19966186050857815, 0.10083330968128783, 0.11714778175311429, 0.09135876236749546, 0.15441709118230001, 0.11771404636757714, 0.1935595101011651, 0.20507647496248993, 0.11129877596561398, 0.09397153609565326, 0.09208369561071907, 0.09951699245721102, 0.27522867705140797, 0.16741677719567502, 0.12667112930544785, 0.12763330553259167, 0.12293465408895697, 0.11723200151962893, 0.21581391165299074, 0.08741119490670306, 0.10218214230345828, 0.1380330624857119, 0.1077192323282361, 0.13480924761721066, 0.13167305876101765, 0.13709416000970773, 0.15064208874745028, 0.15977696143090725, 0.09893378482333251, 0.08726840399737869, 0.17986319932554448, 0.12365296483039856, 0.14458988207791532, 0.10429892050368444, 0.18235220148095063, 0.1762339597834008, 0.11872050379003797, 0.0972366194639887, 0.16039676245834145, 0.13485997489520482, 0.16058809576289995, 0.08601205569825002, 0.14346911864621298, 0.1332447358540126, 0.1480339222720691, 0.1548237915017775, 0.1701069242720093, 0.09148625231214932, 0.15268675903124468, 0.09989938765232052, 0.141601152451975, 0.12807214127055236, 0.09106858008142028, 0.16537966579198837, 0.08953329282147543, 0.14343135138707502, 0.12577147329492228, 0.1538878202970539, 0.14704767162246363, 0.09670895670673677, 0.08586480002850294, 0.15426655140306267, 0.14267421487186635, 0.05822848941066435, 0.09240855103624718, 0.11764854059687682, 0.15025091330919946, 0.08785279906753983, 0.12670251833541052, 0.14738873046423706, 0.08812005365533487, 0.17461919571672166, 0.12816451702799114, 0.07381471020302602, 0.16341606687222207, 0.14376593700477056, 0.07466172546680484, 0.15729420179767267, 0.11370696460029908, 0.09630640223622322, 0.09699604487312691, 0.11758337409368583, 0.15272581550691808, 0.11672451160848141, 0.1591146026871034, 0.05991178551422698, 0.16608748638204165, 0.11401938247893538, 0.11744696141353675, 0.19405075588396617, 0.23292503133416176, 0.13988901861011982, 0.1451311766036919, 0.09331993891724519, 0.11218088506055729, 0.1181651364479746, 0.14775366016796657, 0.21892922877201013, 0.18148865710411752, 0.13676512480846473, 0.1348304993339947, 0.15649160343621457, 0.10061729127275092, 0.10399097417082105, 0.16646688245236874, 0.1417261114610093, 0.15022507469568933, 0.17419995607009955, 0.16050485308681214, 0.07056911436042615, 0.10956077636884791, 0.07865910418331623, 0.1035150700647916, 0.11090767516621522, 0.1981313976326159, 0.16590825814221585, 0.24867556616663933, 0.108181653943445, 0.20679091582340853, 0.19522862482283795, 0.14964221311467035, 0.13975194096565247, 0.07506843257163252, 0.11223531713975327, 0.06567917710968427, 0.11312572471797466, 0.18518581800162792, 0.15053117541330202, 0.08500819027956043, 0.1367561545755182, 0.17556503282061645, 0.04995960383010762, 0.08853820764592715, 0.1315316113510302, 0.1413240251796586, 0.13210737545575413, 0.1862971769379718, 0.12894922920635768, 0.16530527121254376, 0.06638522672333888, 0.10682940150478057, 0.10296468316976513, 0.08971395277019058, 0.16634100063570909, 0.16927593600537094, 0.1284679714590311, 0.11632079684308597, 0.09275568276643753], [0.03787358218271818, 0.04709455417469144, 0.033657260571739504, 0.042675930740577836, 0.027500352556152, 0.10504173314464943, 0.01736061361485294, 0.043278381627585204, 0.028909968345292976, 0.031241933748658215, 0.06968197053564446, 0.05449282843619585, 0.024709436244198253, 0.03113252336957625, 0.013493269349315336, 0.016196060925722122, 0.048684989368276935, 0.029298639989324977, 0.05302196807627167, 0.025212539426450218, 0.03400822263211012, 0.07811101073665278, 0.028480852621474435, 0.013651607192254491, 0.05954284566853728, 0.10577776722077813, 0.06864299092973981, 0.01292145686290626, 0.04660371890557664, 0.03139651081125651, 0.01931053496498082, 0.010573439017337347, 0.03015856777450868, 0.04768751574946301, 0.03639866418338247, 0.046689841962818585, 0.05490542522498539, 0.035847001642520936, 0.026644453572641526, 0.04296687977122409, 0.029929989682776586, 0.021615981523479735, 0.0314611785912088, 0.015329542869169797, 0.04408544474946601, 0.02600056624838284, 0.03031796243573938, 0.03291243268176913, 0.07678705999361617, 0.001122132800186851, 0.05180523604420679, 0.041071151316698105, 0.04329204732286079, 0.044579441991767714, 0.022544490539335778, 0.010242085770836898, 0.025396882123979073, 0.014940537046641111, 0.024112505239567587, 0.014706601920936788, 0.06452931809638228, 0.02601915132254362, 0.031352185511163304, 0.02520779985934496, 0.05016498959490231, 0.10590616640235696, 0.026165962551853487, 0.057610432218228064, 0.021049774584493468, 0.10384303318070513, 0.022873201740107367, 0.032451364743922434, 0.021303165005519986, 0.03167731235069888, 0.03169166675901838, 0.012253635064033526, 0.04966307384893298, 0.05545864161103964, 0.030781751299010854, 0.0335439045115241, 0.09349286356674773, 0.09068053268960544, 0.09566724939005715, 0.1317423236157213, 0.026701382660706128, 0.0732045986556581, 0.03590045663129006, 0.06894692033529282, 0.07124037548367466, 0.07135184521653823, 0.03014227614871093, 0.002619788720039651, 0.03757160356534379, 0.03386125194707087, 0.013601047851677452, 0.05094023620975869, 0.01572214492729732, 0.043842403683811426, 0.045859338848718574, 0.062478337436914444, 0.025084477816043154, 0.0038310409457023653, 0.00719365693761834, 0.011619818047620356, 0.064344905849014, 0.022159238711797764, 0.01581588962913624, 0.04233652752424989, 0.04846926951514823, 0.027586792828515172, 0.011195249356595533, 0.01972008852421173, 0.02442353212141565, 0.04986947063090546, 0.03413747676781245, 0.03439343374754701, 0.017840933287516236, 0.023992721756388034, 0.02535563737287053, 0.015791065425478985, 0.041338894449706585, 0.072693485367511, 0.06535275426826306, 0.059965064083891254, 0.008854055028807904, 0.019052610233692185, 0.05254173152414816, 0.03944324063403266, 0.05217471193256123, 0.045197896127189906, 0.034628145795847685, 0.045671126805245876, 0.0232811081555805, 0.03092582124684538, 0.011265354746553515, 0.028381893378017203, 0.021144647350800887, 0.027790611177416782, 0.02833921691801931, 0.052710717277867455, 0.029510213993489742, 0.09264091535338334, 0.0399856140304889, 0.011638591415248811, 0.03889842451150928, 0.04522396204993129, 0.03806447783218963, 0.05441459334854569, 0.02375759240905089, 0.024014489159786274, 0.012679850898816116, 0.010061995791537421, 0.042725521472415755, 0.05297085064064179, 0.011468025523104837, 0.06571336848927395, 0.007811695470341614, 0.03753124090975948, 0.003974310222214886, 0.03533629886806011, 0.07956971174904279, 0.02602396552850093, 0.01627654366062156, 0.019074659229123166, 0.04055174633062311, 0.05827705216194902, 0.03856678034311958, 0.05168485714654837, 0.07722215021827392, 0.026650657079049518, 0.060486077197960446, 0.03162642900965043, 0.021929980388709476, 0.08041037592504706, 0.05944000690111092, 0.034656264287020476, 0.030252670403569937, 0.023695363962490643, 0.036102510789143186, 0.040750407813383, 0.06437369608985526, 0.06374728613133941, 0.037485877451087744, 0.0634862876364163, 0.011324074318898576, 0.009129331596860928, 0.0318945826563452, 0.06145676903958831, 0.0036320033000915176, 0.04957569550190653, 0.03424798637362463, 0.006982802180573344, 0.02246352774091065, 0.03378880815580487, 0.051441215577402284, 0.029754883543189083, 0.019186096731573343, 0.06663245774273362, 0.029156564934445277, 0.011072917126252182, 0.06015212940318244, 0.03055913753009268, 0.08442828032587256, 0.09776571393013, 0.06304196255015475, 0.0025285026474323657, 0.012811081267760267, 0.05237368893410478, 0.01580553688108921, 0.029763673964355673, 0.033075416793248484, 0.020195295435509512, 0.04308944694431765, 0.0011549796202286544, 0.038999251422605345, 0.029364885363195623, 0.047028542895402224, 0.03640554452847157, 0.022630228527954648, 0.04128138521420104, 0.05243592416601522, 0.021478264359757304, 0.018349988918219293, 0.0785607166056122, 0.03604082177792277, 0.03528106951021722, 0.04050073746059622, 0.04928427828209741, 0.10123564702059541, 0.03777849228520479, 0.048170266273830614, 0.06551546018038477, 0.053555473020034175, 0.05179085110181144, 0.012620720812784774, 0.05150986635791404, 0.07019525513585124, 0.04652760423985975, 0.0029375712661671317, 0.0358235752210021, 0.08276453960154738, 0.10374683048576117, 0.024178613210096955, 0.01894763408095709, 0.09291406641049044, 0.06466463833515133, 0.006670199825228857, 0.045444363794688664, 0.00648576086054423, 0.04576300723212106, 0.01122881648396807, 0.024917754976611053, 0.02920943299042327, 0.03558703791350126, 0.011478636114458953, 0.05135833252487438, 0.04095397510432771, 0.08541131471948964, 0.04978367327047246, 0.09771202145410435, 0.04144505464604922, 0.015102827356063893, 0.017605247541463802, 0.010759009863249958, 0.00615987363770338, 0.07760362939110824, 0.038261157992695055, 0.011727784843450146, 0.009237135544286242, 0.034115560086710114, 0.01554253840419863, 0.017756247028176273, 0.059032906245972426, 0.07800352400434868, 0.030236517877451012, 0.06889233897839274, 0.04398150336263435, 0.021287651998656135, 0.08067729803068296, 0.00677135879439967, 0.029685571191034148, 0.055085586450461826, 0.04518728383949824, 0.0064558573981880075, 0.069330177269876, 0.027730355571423258, 0.0064771888428367674, 0.023805765002699833, 0.054527555858450275, 0.05826630416725363, 0.027891181941543306, 0.013190367076146816, 0.04734519822522998, 0.020223057695797513, 0.05061393550464085, 0.030831287748047283, 0.04641309127743755, 0.020566564352650727, 0.0507400208818061, 0.04353809429864798, 0.03462359621854765, 0.0371425115902509, 0.058390096096055846, 0.014069378658730005, 0.051030824027423344, 0.010028873952770872, 0.007094859694396811, 0.01906490868090519, 0.04570746574816959, 0.04305732509653483, 0.05225730660770621, 0.06935579196682998, 0.04416051107857909, 0.019297530841348425, 0.017869910125487616, 0.0382157063244709, 0.039887016106929095, 0.03651902272499033, 0.0924847505188414, 0.05735403419073139, 0.04071558878890105, 0.06681793529008116, 0.024676652824772254, 0.042707377446017096, 0.017830295554761375, 0.03398687592042344, 0.011430013991360153, 0.016567367162289362, 0.017676196859351227, 0.05168337454753263, 0.05235839814745954, 0.04897103598341346, 0.03591376270300575, 0.052127726775194914, 0.040611715255571265, 0.04572645455066647, 0.012681819498538971, 0.037090610446674485, 0.01771423892517175, 0.0449929208760815, 0.033430205791124275, 0.016732168051281145, 0.04628807120025158, 0.04367904977074691, 0.014579061086156538, 0.024212699416758757, 0.04818054947203823, 0.037198022540126524, 0.036192494710641246, 0.07393842749297619, 0.06594974294837032, 0.026994584427614297, 0.11370332765259913, 0.11560957000723907, 0.10862186032214335, 0.09351736546627112, 0.15603060674454483, 0.20304104632564954, 0.11784549217138972, 0.19030444190970489, 0.09932450564312083, 0.08076871705374547, 0.08425163051911763, 0.15008461794682912, 0.08734879682638816, 0.11094048233436686, 0.09559281409851142, 0.13358465475695475, 0.12032525267984186, 0.1317662759018796, 0.123997334923063, 0.10792704724839755, 0.09667230903037957, 0.170585603586265, 0.07070296896355492, 0.10209600228284087, 0.2501258940568992, 0.1539879720658064, 0.1335020770451852, 0.14020024905247347, 0.1563691957188504, 0.1358216625771352, 0.05719055474868842, 0.08464239883635725, 0.14100199245980807, 0.15550950542092323, 0.21764457199190343, 0.15845468666936668, 0.09276945024196591, 0.12085997898663793, 0.21712439347590717, 0.16421813597636564, 0.10371394189340727, 0.07752122809844357, 0.08452341093548707, 0.09097287271703992, 0.13286467481936726, 0.058805983779685836, 0.12530065141618252, 0.10806274068142686, 0.12908473264958176, 0.12499126658907958, 0.11785651158009257, 0.15266895427235536, 0.1409357131591865, 0.15904453716107778, 0.0821388488901513, 0.12834768077092512, 0.14835895411670208, 0.07766855162169252, 0.07009618902312857, 0.10862566690359797, 0.19945447306547845, 0.0951610758368458, 0.10604959513459887, 0.18708617745765618, 0.1549412730549063, 0.20541719453675406, 0.0925260190186756, 0.1324520441038268, 0.14032260248703615, 0.17611365552459443, 0.156824438433562, 0.23307957447000913, 0.14167151653340884, 0.08849498496523925, 0.12728319503366947, 0.10619889998010226, 0.12799834380192415, 0.10812973922916821, 0.07127888234598295, 0.12648618780076504, 0.1883035371346133, 0.2110985139650958, 0.17439198148037705, 0.23804797072495731, 0.10037824338568108, 0.1998335841510977, 0.13021735687341007, 0.09786606247403792, 0.09370281587221793, 0.143256045079657, 0.07575080809848649, 0.08243274276277848, 0.09092331930462803, 0.135627682986004, 0.08023319686097757, 0.22841472764100346, 0.21877498419157096, 0.2167668869452817, 0.1750076027320964, 0.14640093275478908, 0.08627917457904134, 0.11671209441764013, 0.1888485907443932, 0.11628908211631434, 0.23347611033490726, 0.11897869993533407, 0.10804441345057317, 0.14478338669453347, 0.19474206093166554, 0.06127176646675382, 0.19403609952756337, 0.1620251243667943, 0.1487587469496897, 0.12402687833777495, 0.10333667642303876, 0.11169693352920668, 0.11885218029575688, 0.07704337659691061, 0.1664013359695673, 0.17182451353541442, 0.10483615739004952, 0.1474214494228363, 0.2759456442935126, 0.12627312780490943, 0.061532710678875446, 0.18102242212210382, 0.17862274231655256, 0.12174980981009347, 0.17836477687316282, 0.10754066226737839, 0.06302165399704661, 0.07536701512123857, 0.08293062461806194, 0.1853674618261201, 0.08866200636007956, 0.11015849108142511, 0.11810702670897756, 0.09968534378068787, 0.1514375489205122, 0.1110486543870398, 0.20614310487040452, 0.20464394960020268, 0.18292951264551707, 0.11896416571523462, 0.17124664597213268, 0.1350415237247944, 0.09924626377012048, 0.0900582889361041, 0.16032980462270124, 0.10907750337251595, 0.08848171960562468, 0.10970357406352248, 0.10961282679012843, 0.09615848838750805, 0.2362055310181209, 0.0788357879168221, 0.1272867369864668, 0.16722327257905686, 0.12003683458481516, 0.09713630484683172, 0.205198841967753, 0.11120216614965882, 0.07867057142513138, 0.09385028867317097, 0.11827763755406652, 0.12329867455576148, 0.16926879781697476, 0.0954374974327428, 0.1525255526815142, 0.12397779311452593, 0.11293819120952062, 0.08948758670261928, 0.09550136114869799, 0.15925785500024045, 0.20384504246924603, 0.24785722579274858], [0.029401828202285936, 0.07397298528147594, 0.02443732164933213, 0.045510724519512484, 0.034405226686171124, 0.028788344335875342, 0.040226731449365616, 0.026165516415078725, 0.029448318029088632, 0.048794131726026535, 0.019176683754527142, 0.0393692701389747, 0.08547141935144152, 0.02486744330131582, 0.08249791605131966, 0.05401053253029074, 0.007797061166326914, 0.05235291558450886, 0.02506388258188963, 0.05086325641189303, 0.021726257034710476, 0.06110515897827489, 0.03584231296554208, 0.023206058789842894, 0.041346192093832154, 0.02041438251866826, 0.033708035347184966, 0.02565954133336033, 0.015428746385233743, 0.026381003869963542, 0.07400118519685098, 0.029688787447022538, 0.019422311734940325, 0.08529969570892197, 0.0435027426241764, 0.02966988685407809, 0.031445124452667575, 0.02214416505635849, 0.09334388441805329, 0.017169573776690022, 0.041554539663983245, 0.0322939480122711, 0.061128643075270314, 0.05415779159271291, 0.03791143086605838, 0.019935660795973878, 0.03553986276632973, 0.02922738702701671, 0.03110049312402095, 0.1260437558272055, 0.04053120707560863, 0.07108973392418452, 0.04781375718968255, 0.04362118769703167, 0.0341722482948431, 0.015635518057804023, 0.0295328261729862, 0.04877103100131665, 0.03458217504833426, 0.04657476581633091, 0.006755860630489353, 0.050645918252744844, 0.03577706503814884, 0.07401431484946183, 0.04518007440492511, 0.02514316261346851, 0.0246903863735497, 0.021663597718413388, 0.0029091412850123432, 0.047756163137299676, 0.02219065318682364, 0.05403091572225094, 0.04997258420501437, 0.10793761203863791, 0.023270334715821912, 0.06066831134791885, 0.054863586755735536, 0.02270931687339076, 0.06346399097570352, 0.031877453039799414, 0.03510318476972835, 0.06074870417692831, 0.02203336707316339, 0.021364835357027392, 0.024653865922508494, 0.052433243952691555, 0.04296384671969073, 0.0324446065351367, 0.02872914894084845, 0.009991092274763753, 0.010957681524035121, 0.01611679616118116, 0.01958113981943045, 0.02327740505071623, 0.02403356277916048, 0.0343272223004273, 0.04101292283407279, 0.021498501666688492, 0.04033810958000166, 0.012962392032412546, 0.020742023330447928, 0.01626221809004034, 0.024591276156050817, 0.041060016557042084, 0.05329630317698632, 0.028109300415962934, 0.004614892656848366, 0.029504806069391112, 0.07313228717872075, 0.08177051294062819, 0.010668968266275312, 0.021969576299722706, 0.03452799741977027, 0.013957582380888718, 0.04362032935023308, 0.03981012791129095, 0.005609627114608884, 0.039902992213943174, 0.04534001528684582, 0.026557828399485776, 0.018883721171213046, 0.06233351092253413, 0.05880773440003395, 0.008093271387874015, 0.004426376968954823, 0.030239785023565804, 0.04325929104483553, 0.02611622423864901, 0.052482800757778544, 0.06050455370651824, 0.03839389979839325, 0.0469791557240699, 0.017511916745986258, 0.041288703214377165, 0.07718221843242645, 0.011420759621874561, 0.0183299042816673, 0.08342151756265334, 0.010935878497548401, 0.009612395943674659, 0.05752754916570016, 0.034352436661720276, 0.028296386091304675, 0.040015747770667076, 0.0491400488785335, 0.03787594009190798, 0.01592172073599483, 0.03140300778406007, 0.1262447786118303, 0.0714674743690661, 0.044566739816218615, 0.03591598829786692, 0.006459141931762653, 0.03849646375913705, 0.09011977099414382, 0.0489213129372469, 0.041370045992412736, 0.040701638108917644, 0.05391268099525145, 0.07510180970919983, 0.016797422764024565, 0.01005820871796459, 0.057026084645518234, 0.027076882243688618, 0.05915563287479537, 0.024339839915878007, 0.01796578203461, 0.05523678440866726, 0.015327554761565157, 0.009657914617231913, 0.041397336670862775, 0.020132746381152953, 0.026111382891290953, 0.010455038049258292, 0.051692236214876175, 0.030879277137241194, 0.05651300021314195, 0.02516035160182842, 0.07990533552531685, 0.0434086603511657, 0.04224474209227732, 0.029955726516033922, 0.010172869261753346, 0.019594247419653193, 0.012830377107353082, 0.01513545640877315, 0.03233920629801495, 0.015153836226090789, 0.0027725316176656634, 0.012067814008332789, 0.06656051267470632, 0.04534975226436343, 0.03097949336682047, 0.05638063160170402, 0.036391278329704485, 0.06852167565375566, 0.054424499959817955, 0.02147971642469721, 0.024137858700539385, 0.04340415148596678, 0.020439440816906945, 0.01054193209191518, 0.03851986982460533, 0.017152600223198533, 0.033833638964486976, 0.06678210864109652, 0.06551769934594631, 0.022243972468589033, 0.04308844610516514, 0.0839481693027275, 0.03115515590512327, 0.023466553472514664, 0.016277854929545095, 0.02344177506997117, 0.015279606084472366, 0.03378560207784176, 0.024799177589427148, 0.03454146633989044, 0.03493910821686898, 0.039361690902816396, 0.020303240178951194, 0.02071556555373328, 0.01945730548218957, 0.012842963083780237, 0.03076642658561468, 0.06737457827797957, 0.026771802721279006, 0.050887619211737595, 0.036201587079891136, 0.050756478748683415, 0.03365087555721402, 0.006217135632011507, 0.03014840671260442, 0.010824178062778498, 0.034753131946282725, 0.03712922926726086, 0.025142156685303365, 0.04131183786583798, 0.029678276939583675, 0.03841881899695311, 0.03226589058924999, 0.030808885914406607, 0.030131053179502487, 0.08222787946994815, 0.01344938255247793, 0.0670825300206031, 0.05880107797150101, 0.023603361399312104, 0.022646796656772494, 0.059463233154799254, 0.013576776654060398, 0.022534387152908102, 0.039973892338041744, 0.05139454933149474, 0.009638742610280002, 0.028419238249106065, 0.04344848696408527, 0.03011336037889123, 0.05867628181087119, 0.014980266968320523, 0.004528936264770371, 0.08195805323443242, 0.03813071981338518, 0.04717977138768349, 0.05456071925748672, 0.07312683175717082, 0.058778876305690834, 0.010626955074258149, 0.026066160228635584, 0.009024874523415096, 0.05177036952227354, 0.02198544723380889, 0.00845092804437237, 0.061606915268514834, 0.03421935898118785, 0.03884004335850477, 0.05475843757657068, 0.025806890301672474, 0.033523141339953454, 0.022821668701778566, 0.0568827712642295, 0.03458097743402634, 0.03382638203246253, 0.05239787192216941, 0.08887412997760943, 0.06546954371567283, 0.01968084884408329, 0.05373842302443726, 0.03469383477100304, 0.007785560845929597, 0.01775700020204697, 0.01771498192101717, 0.03521374865834202, 0.035594033609543524, 0.020180070806028585, 0.026692392071709037, 0.04992418769480927, 0.05167827196419239, 0.017541904601135423, 0.0472001986844199, 0.06219695575003113, 0.020793552976101637, 0.04351540069494929, 0.027234370221516917, 0.04820042037005935, 0.033519928476640155, 0.06460402480193547, 0.10335967197482075, 0.0714862969304834, 0.027669781053970968, 0.0608390239732606, 0.0237548019337867, 0.027428492305002043, 0.052448531346661706, 0.021059609949588776, 0.07780389900186233, 0.047118923759886196, 0.040369413793087006, 0.05148993439174124, 0.015154869295656681, 0.02836502330111606, 0.027722684733037437, 0.03278040333784052, 0.04047304305381008, 0.004828666810811098, 0.056377344099538665, 0.07436693592795304, 0.021911471649738293, 0.005586603573257369, 0.0016352876305713185, 0.01342875593607979, 0.06557444522955588, 0.032865220215171576, 0.04464487651629107, 0.0372673654263573, 0.05126909159922174, 0.03937401988410524, 0.0016720104758860543, 0.007977130789575832, 0.049350160639733076, 0.1259691169751542, 0.030834208841302564, 0.03800573027027505, 0.027114473083721738, 0.030001751546348845, 0.019844007678329945, 0.06422865922961916, 0.008113033720292151, 0.02148141445858138, 0.07721349889678614, 0.09157314550663744, 0.05533736026180642, 0.13574327821178095, 0.16738914724971565, 0.11102887509124619, 0.15462422078209265, 0.14516328488077435, 0.09823537551398788, 0.11647709059928145, 0.16765020681279047, 0.1500841701137168, 0.10778977961412498, 0.12119813369853155, 0.155743966411267, 0.07191827267940555, 0.12198280516479697, 0.20439836063555308, 0.1001607525561537, 0.07883370481431484, 0.14034620193498476, 0.11743853400860514, 0.17975683217602118, 0.2247159518301487, 0.12926436801041874, 0.16868670976587705, 0.1426505068583148, 0.10926963734839644, 0.06648602988570929, 0.10783121096236364, 0.12395198164241654, 0.08399216551333666, 0.13663863231028828, 0.11504002128328596, 0.1087074303733451, 0.07043466264648096, 0.1534390915185213, 0.11069247099970068, 0.07932440098375082, 0.07799873354711703, 0.12330688482948712, 0.13710061966308526, 0.1108836346705045, 0.13477557870958531, 0.10029128912304129, 0.10652999114245176, 0.22270364766674383, 0.11443909710007054, 0.12952172277229174, 0.1101278755813837, 0.10767734636153493, 0.1310575460749013, 0.18679367458181723, 0.07417702076158353, 0.13823063831244195, 0.1597800012677908, 0.21118181092398508, 0.111604707049472, 0.10674484247075659, 0.11157928234232323, 0.13974185793527535, 0.15874800378722803, 0.15704706577318056, 0.07782620923327548, 0.11568476525800568, 0.11452708952128887, 0.1731692206646715, 0.09968727082014084, 0.17054711708000728, 0.10548487757997853, 0.17867291319583142, 0.09175029742930617, 0.11850930298013346, 0.10629958100616932, 0.11524136976471969, 0.10044913672442947, 0.28602454917771475, 0.1408808468175786, 0.15820755064487457, 0.10682135407945939, 0.0953936165730868, 0.13251913764647075, 0.09604720864444971, 0.13369061478546687, 0.10638099842305694, 0.13772420691592352, 0.10718211079282419, 0.09054878154503447, 0.1925140233444316, 0.14595365604119642, 0.15762315557471343, 0.16194341517984867, 0.13278730825654098, 0.13693991542926856, 0.11212026474199124, 0.07011705397495202, 0.062293138088924546, 0.08296519597726208, 0.18761122785508633, 0.10894777426230055, 0.10024208854883909, 0.0906609705250178, 0.16463717206248216, 0.16777213955564158, 0.11778878021453108, 0.10559199111802237, 0.14571276253887586, 0.1871739663183689, 0.1275443767330476, 0.08088008500635624, 0.09996473057461636, 0.247660722051348, 0.20463709639651434, 0.12557012481348856, 0.18712042990539754, 0.09279232365744454, 0.08050208671816758, 0.11125742604157754, 0.08471716661006212, 0.09846995864063501, 0.1437213843954461, 0.14972750496651444, 0.07824365754744836, 0.11329974859420743, 0.11463665935610022, 0.1544252336025238, 0.15316406770476274, 0.15917552156107767, 0.12360157258808613, 0.1034146129552807, 0.11538804189435073, 0.11083802354655095, 0.14810860183622154, 0.2597505604582173, 0.19905841217509337, 0.12982854273702416, 0.24091754960162298, 0.1630371186350073, 0.08584099023469857, 0.10128650322024312, 0.16526354130889687, 0.13342233560979366, 0.17355123588017055, 0.13538816012442112, 0.18812284325914724, 0.1245062497577497, 0.08456665397222553, 0.14150193706154823, 0.11720431729086808, 0.09957448472934109, 0.15993295663169452, 0.15291588673634188, 0.12329262202339512, 0.1461090405604669, 0.07806035131216049, 0.10438993240573577, 0.1677096871925252, 0.20468950644135475, 0.09723849222064018, 0.13116574526897498, 0.08163445988403899, 0.16341517120599747, 0.12153318072003977, 0.10197884642652102, 0.1073910045836653, 0.12909472068505629, 0.15358671359717846, 0.24134087402905735, 0.06448489440871136, 0.16826067119836807, 0.16038705940757478, 0.09420694703502314, 0.10834065505436488, 0.12648807412811688, 0.16923613314117703, 0.12448699293392045, 0.16156564759356634, 0.16104076004454068, 0.14449020528367587], [0.029280282224395444, 0.06328225215630871, 0.02606534429027566, 0.0469769470925842, 0.06300830042787961, 0.02521208650432527, 0.0329045141781015, 0.03115451129685555, 0.01115336932707578, 0.05142575515700238, 0.014208641185957407, 0.05927327049097844, 0.0416119946166873, 0.035764166087444337, 0.08205490053764411, 0.04302352387458086, 0.04780065128579736, 0.006816218440820063, 0.014867601317486592, 0.03716571409521358, 0.03591837674113257, 0.040678160797272406, 0.04686979962778943, 0.04213889062936817, 0.03058504738977977, 0.04542663706732648, 0.029254005955798284, 0.03259915645633425, 0.017474293675539748, 0.018346107697912624, 0.06735774382416691, 0.015667779005265663, 0.028402139166636125, 0.027666507122505988, 0.056592951994389296, 0.02255350487705852, 0.03709279532943453, 0.028410580142268112, 0.07325114615793739, 0.025003123163644756, 0.08032170496881008, 0.022941479326358864, 0.03240589611232281, 0.04513553536630102, 0.014177509999301816, 0.0046837554795534486, 0.03215259898986135, 0.028326053338657533, 0.07635823264718056, 0.027345403995630995, 0.01498818547198815, 0.024061604935143675, 0.021364494393180524, 0.011299234848203403, 0.05406322416716388, 0.052007049322128296, 0.00935582913059209, 0.026014976635841385, 0.028994741117847816, 0.05617035699209996, 0.061358557880989144, 0.02921561783711825, 0.026463355968839357, 0.016281661510999714, 0.061828904785215855, 0.036299553965883594, 0.04163976026965039, 0.01844904994192932, 0.01976862922310829, 0.03731851000338793, 0.0652853146727596, 0.04112969531810709, 0.041614549301032505, 0.0425028941327972, 0.010193219375131386, 0.08105514704116754, 0.0032532726181671023, 0.047695583530834744, 0.026499778032302856, 0.08720966322081429, 0.03954561460497124, 0.08826253243855067, 0.04036841634660959, 0.11433335420276437, 0.008924274921550282, 0.017360016504036527, 0.01738006721383759, 0.035749072075954506, 0.017022287572867105, 0.04185986006632447, 0.0203148329497448, 0.05663682267602001, 0.0365393211000732, 0.06188167445361614, 0.04538367562262075, 0.028851207212678025, 0.026010469466980015, 0.02622651162424258, 0.03875706870374935, 0.0220560284464487, 0.03248284198343754, 0.05959169340452977, 0.002858577491549243, 0.02492151745328946, 0.018457268697342703, 0.02916677010112575, 0.02866342943161726, 0.04507220769301057, 0.01418981608003378, 0.026281495013141205, 0.027212592640093396, 0.0186896347108164, 0.020557836695973362, 0.033724720523293526, 0.045729026198387146, 0.03388472247336592, 0.016935450357518027, 0.04253341803061111, 0.026238648919388652, 0.044788461311587265, 0.017368971469945142, 0.040302628983876536, 0.03823389106297067, 0.038078048532562594, 0.0381403991154262, 0.04115356957273824, 0.04214356912832175, 0.03556681078459535, 0.007496633849638913, 0.03722010546230844, 0.06217454373836517, 0.04273103117676718, 0.036281596536615064, 0.08739569038152695, 0.014953305379354527, 0.036557458341121674, 0.07134223037532397, 0.019751095878226415, 0.01405697503858911, 0.06114616284945181, 0.01862365735827812, 0.043997184306915314, 0.031525289972445796, 0.0711494857179267, 0.03935185553772109, 0.0382013451308012, 0.024410862176279937, 0.02721898613630661, 0.0579922099464706, 0.016025599358337264, 0.041218980348535945, 0.03793200065514871, 0.017793366286371435, 0.0501437073440424, 0.02075814701882856, 0.06181862497968333, 0.05117013405210205, 0.04525589390790888, 0.01254624650547547, 0.03797678057370441, 0.015470593336171337, 0.02685350173019937, 0.022171644028276205, 0.04099825629964471, 0.04635299343083586, 0.04345660224290831, 0.05305389993424926, 0.06488898236836706, 0.06267043070069381, 0.060833683902663846, 0.005449942379657711, 0.03323630423152021, 0.023293788278741494, 0.04386957222595811, 0.01242055298228349, 0.048146174887993505, 0.016340268276897923, 0.07302953662084681, 0.021381864889657924, 0.03276994711320315, 0.04539938370830246, 0.005375726763824267, 0.020795320559825217, 0.04911675137866821, 0.0688047536781856, 0.034125286886202436, 0.028986727619277577, 0.03661153758210795, 0.006200833404104092, 0.01648999042143779, 0.0328829808692847, 0.04642237024381757, 0.022512049780094197, 0.10013733631266014, 0.019999487192503045, 0.034995653932648044, 0.060187820345163345, 0.0530315422053848, 0.01627941556008799, 0.012871676141263118, 0.02034122626563268, 0.05453593237325549, 0.034463821577706506, 0.008346564269491603, 0.07181556961898293, 0.03878292428063495, 0.01950566467296864, 0.02242495472143803, 0.032287902265254936, 0.04436023107596806, 0.014254936782111014, 0.05254966359851616, 0.012967235924276923, 0.048765765569571934, 0.011813588989233332, 0.04557340758453522, 0.00783910574058869, 0.017487940711102316, 0.025594235730490515, 0.04412577008562429, 0.043055089323648384, 0.03809736303186842, 0.06097332640950169, 0.05211098731628486, 0.06210879369505814, 0.09834399539977312, 0.027806804415636828, 0.03204424373273339, 0.038946010172367096, 0.010379394965379365, 0.03820167761296034, 0.04304126417264342, 0.00719928029658539, 0.0291694570997996, 0.050068094794239314, 0.0873654887878469, 0.02454990757230137, 0.04387621169111558, 0.03490532395829048, 0.02478744402261717, 0.01960503782278725, 0.015234218877074974, 0.08213428913482598, 0.051441761798092296, 0.045988219790160656, 0.025671510691089288, 0.03313571820035577, 0.01289530357878123, 0.0294718801576112, 0.03554105020261236, 0.042252874334475825, 0.06719909555145673, 0.037219189440033267, 0.02458548146699156, 0.03673107170366815, 0.052800178727401156, 0.07391230389475822, 0.0712893521413207, 0.03610258882067033, 0.012167257556159581, 0.01413072585793478, 0.02753165676923735, 0.042745314338909726, 0.04110521377463426, 0.027348158847806708, 0.0273315958080015, 0.06903375924697944, 0.037350845589701615, 0.015835119311564734, 0.004622279782779515, 0.005726724447283361, 0.02805237641691097, 0.07956260748739753, 0.05162821982854179, 0.053978621028363705, 0.05038065855790462, 0.023816594421597462, 0.03665713174268603, 0.019027504438002194, 0.019107603800616095, 0.03899254071127091, 0.027118807226153355, 0.064405051193067, 0.03800868868295636, 0.03114764791514192, 0.029227739865226404, 0.06830033753067255, 0.09730205738118716, 0.015371886847008551, 0.0470923150091299, 0.03146305134786027, 0.026607364848522202, 0.030819990139986788, 0.026862821408680508, 0.028387908590957522, 0.05191439197265676, 0.026673771374459778, 0.047975543686853986, 0.0545927053982658, 0.036053286466215334, 0.03761008667892643, 0.08743922518832342, 0.022708210861310363, 0.03075787704437971, 0.030834263124104058, 0.01573803961010916, 0.02548978035338223, 0.04684890074921506, 0.017572201189718077, 0.008158665200296258, 0.016071468325597898, 0.0452669777774385, 0.09416372435433523, 0.0415404023868697, 0.03831656716231789, 0.030082839873752425, 0.01461443820569132, 0.01503349804053349, 0.042315672750451734, 0.04674339194649032, 0.006865232417892132, 0.0812832365876862, 0.026507774567497627, 0.05471354230706181, 0.03052796223866088, 0.03306822432205081, 0.05197985703125596, 0.02692815245661352, 0.03209918810586844, 0.022451105461056744, 0.05455132833282862, 0.03389979612880519, 0.019187375770083497, 0.060364063030907085, 0.030681494357330457, 0.016272553874711906, 0.022475271485745907, 0.06874445227107831, 0.035270603107554574, 0.02267547833201076, 0.02836709113658539, 0.019103597051330974, 0.03254136562879596, 0.06904501614293881, 0.043046896013298204, 0.049681899803025384, 0.05357389185311539, 0.041244045432124815, 0.056983465860996924, 0.016811753423618417, 0.06962448504886457, 0.04275124134229762, 0.10925852294479098, 0.1963007372937032, 0.13076754020793097, 0.13630381599068642, 0.09693085122853518, 0.056289809689457924, 0.130146110696452, 0.1179986239543983, 0.09453288133123092, 0.09294786423976932, 0.18721898033150605, 0.18149673167083943, 0.09805303279842649, 0.10512120316603354, 0.20254534935312613, 0.10265134248350348, 0.08138754777610302, 0.13818645211202757, 0.11850706381457192, 0.13287961616047791, 0.08551210431115967, 0.11028060702873127, 0.11144343963158981, 0.07849588936993054, 0.0727160263008305, 0.18281109471406254, 0.12373745601092066, 0.0918020900072796, 0.12397031565862042, 0.08836630758430276, 0.2079219115631921, 0.07001624402723142, 0.09585690671311957, 0.14417585358023643, 0.10753456902291093, 0.13900051771530084, 0.17432007033910069, 0.10670866976891245, 0.1103610744965928, 0.09414165161017861, 0.12553043051489762, 0.09896064123937062, 0.13182298785873822, 0.09492183795997075, 0.11340452118643693, 0.184600011578628, 0.1488893920821803, 0.16404778297458375, 0.1997724888580186, 0.12776692264846393, 0.20838745443948678, 0.09787737365279879, 0.1004639355731862, 0.09590566623955965, 0.12954992268766674, 0.10629789823932306, 0.08655887349907841, 0.09415666080479111, 0.09087276844573872, 0.22421971202961036, 0.1983974647841283, 0.09157231769391469, 0.10673420982701437, 0.09265770909509488, 0.18902944746826375, 0.2277155922991889, 0.1285871493497065, 0.16751625042940888, 0.1137415970276509, 0.09973173521991287, 0.18569509924522468, 0.16930675506591797, 0.1799579770969493, 0.08806960457669837, 0.13799254037439823, 0.18504830609474862, 0.10367721279284783, 0.14830973318644933, 0.10860248814736094, 0.11372045387646981, 0.12725272881133215, 0.20147368471537316, 0.14353937416204385, 0.11069697647222451, 0.08328636017228876, 0.09591144057256834, 0.13804945589176246, 0.10455873156232492, 0.11659168159323079, 0.0937573497316667, 0.19981173532349722, 0.19101845073912824, 0.09429090217288051, 0.08899137404348169, 0.08646070305258036, 0.13533518011016504, 0.14243706688284874, 0.16076842322945595, 0.15909423306584358, 0.08738676086068153, 0.0781037232705525, 0.1116797598078847, 0.10529876899506364, 0.12348676446293082, 0.16870466380247048, 0.08834335952997208, 0.09143531468829938, 0.10144070030323096, 0.11168758331664971, 0.14859436505607196, 0.15227038280240127, 0.18451562896370888, 0.09030663275292941, 0.11609698885253497, 0.1616437334035124, 0.11811317423624651, 0.114060338852661, 0.11037631439311163, 0.21092771313020162, 0.13899297240589345, 0.08773347189916031, 0.15977635074939045, 0.1717915367335081, 0.11188104043581656, 0.09395266603678465, 0.16006628876285894, 0.11628062756998198, 0.07195403826023851, 0.10282969541315522, 0.08945081688995872, 0.1734197765056576, 0.12416842074266501, 0.10627451592258044, 0.10871002916246653, 0.12618331690984114, 0.13834180948989733, 0.22730556715812, 0.11194680404982396, 0.10393593819545847, 0.13349161403519766, 0.0667475847793477, 0.20160261993961676, 0.11968231360827174, 0.24492739300642694, 0.0953558628846492, 0.20287997568292276, 0.09920366534164973, 0.11817877500184945, 0.14428849039333208, 0.24138128757476807, 0.16473201768738882, 0.111960340823446, 0.10969165220324482, 0.09001946316233703, 0.11940035516662256, 0.1467993820884398, 0.08052964881062508, 0.13918038377804415, 0.09397104755043983, 0.1036198969398226, 0.07210286813122885, 0.19115083292126656, 0.11434157804719039, 0.10471350540007864, 0.10883472354284354, 0.10989555197634868, 0.1449725893991334, 0.24199066630431584, 0.22054780620549405, 0.20644354660596165, 0.13603588965322289, 0.13721552278314317, 0.10257972311228514, 0.07662495797766106, 0.10261865745165519, 0.11478694129203047], [0.013883674650319984, 0.026749283840347613, 0.024765301728621125, 0.05968271887728146, 0.013964631511563701, 0.06912081528987203, 0.010928872623480856, 0.008066237704562289, 0.021289862326479385, 0.06695834454149008, 0.04875762314934816, 0.09668908241604056, 0.03157763555645943, 0.01879106042906642, 0.04713387527902212, 0.0583876126578876, 0.04799930937588215, 0.06699381835226502, 0.04662574754495706, 0.06895173793392521, 0.07829651542540107, 0.06533834896981716, 0.02523828643773283, 0.027150369282545786, 0.015312282634632928, 0.012352827553903418, 0.02087697376763182, 0.004488133409592722, 0.022303761581757238, 0.07822288080517735, 0.015571301503639137, 0.04565246030688286, 0.08674965719027178, 0.012781666774701859, 0.014810126008731979, 0.05410280990015183, 0.016079532714294534, 0.014896216835560543, 0.037769301528377194, 0.04166737325223429, 0.03251646000093647, 0.03390649326943925, 0.026180552751091973, 0.06888159776904754, 0.05677197667370949, 0.04247875524950879, 0.031801616573440175, 0.08325432653405837, 0.030875551979988813, 0.052666978910565376, 0.05940390883811882, 0.04118629531668765, 0.01523735370886113, 0.01953457705011325, 0.015637163505224243, 0.03874195433620896, 0.051128410933805366, 0.013864417826490743, 0.051900261480893405, 0.06398404057004622, 0.012793379985461277, 0.01122398955547916, 0.020606014378634945, 0.0200869130369808, 0.04983989328944257, 0.023488546488806605, 0.018386728196804012, 0.06700970285705157, 0.04633346858567425, 0.06844632433993475, 0.023288828187755177, 0.04192280776000448, 0.03264840113531266, 0.02041336810881538, 0.033715872426650355, 0.04957439950002091, 0.07680911238172225, 0.07658584721918617, 0.00794645761405783, 0.03824317342202578, 0.03695687797984906, 0.04143558568986399, 0.049658442847430706, 0.032256869466177056, 0.04230393409462912, 0.057568139130515714, 0.031925327078040154, 0.02556282125546464, 0.027442342901070203, 0.0388305404755686, 0.0739396759974105, 0.027293940507141606, 0.03130823340533035, 0.03167345827179296, 0.02447161989818726, 0.057001765950449874, 0.014477808394336274, 0.008173725285035158, 0.043683741840400865, 0.02358069154433906, 0.12297323559011732, 0.027899095356198292, 0.047568694089672396, 0.03746626100369862, 0.04212067874946764, 0.012517795532143541, 0.04478020014773522, 0.058872283436357975, 0.0483458847073572, 0.03564455732703209, 0.0996583177308951, 0.02529037417843938, 0.06319271267524787, 0.006983781815506518, 0.0467545470621969, 0.02778660612446921, 0.04904660103576524, 0.008505081924210702, 0.03135057059781892, 0.02197929292118975, 0.05781660508364439, 0.03799700430993523, 0.10535193899912493, 0.03524906640606267, 0.0639143685943314, 0.033328551067305465, 0.00638869303345148, 0.06049740194742169, 0.039164664689451456, 0.03442615270614624, 0.06273300520011357, 0.044351976697466204, 0.029970430369888033, 0.018950385540457707, 0.006324883600297783, 0.009941438778436609, 0.026016057202858583, 0.06154041883668729, 0.042561658658087254, 0.043740165419876575, 0.03340159196938787, 0.07318097206630877, 0.018615513241716793, 0.017033225557367717, 0.009866476774082651, 0.046018804756126235, 0.018184955630983626, 0.06308573484420776, 0.012804971059917339, 0.06312335282564163, 0.010063547092223806, 0.01434496311204774, 0.05754905194044113, 0.03797167459768908, 0.07789316028356552, 0.026827647849651318, 0.042763553360210996, 0.07911753601261548, 0.03411216401894178, 0.04256604877965791, 0.05894852363105331, 0.03067434938358409, 0.034732925173427374, 0.05564723363412278, 0.01494471512601844, 0.0701765479253871, 0.04008085659838148, 0.03694469149091414, 0.04260726299669061, 0.08724083511957101, 0.04894209985754319, 0.011137627314643135, 0.04403098892154438, 0.01842058539789702, 0.08886929880827665, 0.02448306678395186, 0.02430192337903593, 0.041299474957798205, 0.05409791426999228, 0.04478776242051806, 0.034744958991983106, 0.02631373730088983, 0.03646729800051876, 0.04080880592976298, 0.06002118571528366, 0.05072366140250649, 0.0062031590828805095, 0.025575508163975816, 0.03533885694508042, 0.05704293267003127, 0.04894786061985152, 0.003566401686319815, 0.015701805840113332, 0.03218934844647135, 0.023120312319536294, 0.08581752649375371, 0.027245189462389265, 0.0320139641075262, 0.014297445304691792, 0.059621331814144335, 0.034348056718174896, 0.024546681138287698, 0.04766261012160352, 0.048843179629849534, 0.05896773295743125, 0.0706019758113793, 0.03318429112966571, 0.049154885046716244, 0.045233271550387144, 0.028807563840278556, 0.021252308805872287, 0.043786200628216775, 0.03748829982110432, 0.023079396657911793, 0.03485105812017407, 0.008509544988295861, 0.007779707633224981, 0.028307788872293065, 0.00827184399323804, 0.08511976179267679, 0.004889284160786441, 0.04093328657160912, 0.019913369224273732, 0.0539499563165009, 0.048155436890998056, 0.016628900110455494, 0.04731120362079569, 0.008435851844426776, 0.03753564120935542, 0.033833611823086224, 0.008687587488176567, 0.03417571221611329, 0.019438437119658505, 0.025367057117234384, 0.0166309306264988, 0.02648492150806955, 0.046851536857762506, 0.02544308526973639, 0.04375918475644929, 0.06649863706635577, 0.03119489430849041, 0.011592912437793399, 0.02203829663007387, 0.06635743392897503, 0.024319556807833057, 0.049767914294664345, 0.029519832227379084, 0.03688367762203727, 0.04020523206729974, 0.014454078328396593, 0.05840479994990996, 0.02160204271785915, 0.05262227023818663, 0.006412229716910848, 0.046588482401732884, 0.016556965220453482, 0.025691178028604815, 0.10983571875840425, 0.07489739424948182, 0.052308759918170314, 0.0180148808285594, 0.06665713606136185, 0.04566277064649122, 0.022670979644837122, 0.046079886478504965, 0.08455260151198932, 0.03871510809819613, 0.019572778571663157, 0.017460906179621816, 0.02522659019034888, 0.01378703345212021, 0.010553505354827004, 0.037623548813696416, 0.020565210675288523, 0.054666424835366864, 0.04712102721844401, 0.037717183253594806, 0.03524988743343523, 0.034507783861564736, 0.021222344699448774, 0.07873559543596846, 0.07886049337685108, 0.02210600594324725, 0.05304160148703626, 0.07043747178145818, 0.026554364478215575, 0.04785572458058596, 0.030159208990101303, 0.018952690863183567, 0.02496390723224197, 0.038582478250776014, 0.03323614816846592, 0.04017471834751112, 0.0394853403392647, 0.02438666731385248, 0.05047860508784652, 0.06115748081356287, 0.05996201067630734, 0.03634376730769873, 0.028925388053591763, 0.09987747097121817, 0.06869567917393786, 0.007705265556329063, 0.050263478952859125, 0.04745248139702848, 0.009698896436020732, 0.018320192749212896, 0.053040749925587855, 0.05001018522307277, 0.020482641445206742, 0.031308562494814396, 0.004043156505628888, 0.035945219586470296, 0.030206397707973207, 0.05122011833425079, 0.03260373317503503, 0.09376565500029496, 0.06378523659493242, 0.06774722971022129, 0.02467490390076169, 0.008098716631398668, 0.03737116092815995, 0.08437809587589332, 0.06465986144862004, 0.005056109204555729, 0.031235508022031615, 0.016969036144603575, 0.0399025274174554, 0.10834248031356505, 0.02507243551579969, 0.027082688807110702, 0.05111239072201507, 0.059169339282172065, 0.029512076572115933, 0.06547280746911253, 0.037349746362971406, 0.05719436811549323, 0.007702084923429149, 0.05272041693595903, 0.0386183320411614, 0.01882641719255064, 0.01892394811979362, 0.023974016242261444, 0.026997074651132737, 0.0498369179133858, 0.08195562407906566, 0.04221742766510163, 0.04608640380735908, 0.02050204754674009, 0.023689630341583064, 0.036891504523477385, 0.043707873938339095, 0.12132086711270468, 0.11158072083656277, 0.1737490152674062, 0.13280406807150158, 0.11527579863156591, 0.09109808278403111, 0.11298854529325451, 0.11605513681258474, 0.06725423330707209, 0.10201110398130757, 0.15919800821159566, 0.23152165806719235, 0.054728911125234196, 0.14289115608802863, 0.1267759222537279, 0.09281364322773047, 0.12639655332480157, 0.11999237697039332, 0.10285987665078469, 0.19828557435955318, 0.1289722179727895, 0.16410985535808972, 0.06648885259138686, 0.13180796509342535, 0.13963687499719007, 0.09073194528796844, 0.17688031867146492, 0.08635951312524931, 0.13924465461501054, 0.20126724722129957, 0.09377819432743958, 0.09470092731394938, 0.1983544049518449, 0.10680525244346686, 0.07999480715287582, 0.19238810081567082, 0.19443188900394098, 0.16332727377968176, 0.10842256101646594, 0.10630522641752448, 0.07444856369069644, 0.1776025920574154, 0.08577805611171893, 0.20878280965345247, 0.08844251385224716, 0.16319748360131467, 0.10483528886522565, 0.19473709405532905, 0.20283569448760577, 0.10326177294233016, 0.09111052033092294, 0.07489763852208853, 0.07749358458178383, 0.09850968686597687, 0.13498285758708203, 0.1071800005489162, 0.1531297338328191, 0.11692244027342115, 0.1805520209350756, 0.13418291908289703, 0.17943744574274334, 0.09507377552134649, 0.1002943425306252, 0.13484377147895948, 0.15243211840944632, 0.07250975165516138, 0.11556918360292912, 0.11102909222245216, 0.10509801762444632, 0.1876868437975645, 0.13584770475115093, 0.14325673718537602, 0.14592698961496353, 0.1118566267458456, 0.11838464252650738, 0.13251824198024614, 0.1485316412789481, 0.16926851283226693, 0.09856287722608872, 0.15594269574752875, 0.14858546267662728, 0.15621560253202915, 0.10631273780018091, 0.11209842948509113, 0.17219491223139421, 0.10274809479181256, 0.17353877797722816, 0.05765729184661593, 0.10670095482575041, 0.11495648005178996, 0.15076522928263458, 0.05388907815462776, 0.10506236060921635, 0.14711492801351206, 0.07359305316848413, 0.1688984398330961, 0.1651531843734639, 0.09719113047633852, 0.1016658450077687, 0.09665040591997759, 0.1722449745450701, 0.11652544300471034, 0.2166650252682822, 0.14994549112660543, 0.1534827213202204, 0.16927808017602988, 0.09819928423634597, 0.16059444685067448, 0.13954713195562363, 0.11224992599870477, 0.10183975353304829, 0.10688291756170136, 0.18864431099167892, 0.07039675968033926, 0.12938235167946133, 0.10493840583200965, 0.11612185037561826, 0.12882728289280618, 0.07195741736463138, 0.10416514732475791, 0.10460108571818896, 0.11121011858007737, 0.1708928578134094, 0.06005665274070842, 0.1404346421893154, 0.27292963755982264, 0.10092563794127532, 0.1414490384714944, 0.12467156802969319, 0.11086855762239013, 0.14460604478205952, 0.1359161010810307, 0.11768120527267456, 0.15580970288387366, 0.08911551202514342, 0.07477765996009111, 0.09429785037147147, 0.13744992949068546, 0.15421095224363462, 0.1635246460459062, 0.12571534487817967, 0.16783550115568296, 0.11147606359528643, 0.12707652683768952, 0.07897511829755136, 0.11217026598751545, 0.18514845786350115, 0.15909995990140097, 0.10595361635621105, 0.144128573260137, 0.11473368986376695, 0.10846750717610121, 0.1580092827124255, 0.042585509163992744, 0.11284219207508223, 0.1031915106411491, 0.16716016882232257, 0.17283444505717072, 0.0776475238214646, 0.1496107562312058, 0.1618162848587547, 0.12464663865310804, 0.1605345457792282, 0.10961253502007041, 0.1120923226699233, 0.17525963777942316, 0.0948329973699791, 0.11406390794685908, 0.10821096665625062, 0.2112552419837032, 0.12278640775808267, 0.09040041307785682, 0.13904664452586854, 0.14062930031546525, 0.13811568090958254, 0.08443509960280997]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.0289529297899987, 0.016427767063890184, 0.018629781136821424, 0.028483593902949775, 0.04346182017720171, 0.02556899931680943, 0.023486627931041375, 0.010301066579164138, 0.03188025199675134, 0.03965200550322022, 0.010060859245381184, 0.04909942498696702, 0.030968226292835813, 0.022351959620469382, 0.026571251518492187, 0.03655518864148429, 0.028627144771495035, 0.02138687756710819, 0.03128303261473775, 0.018005379641960775, 0.011642343713901937, 0.05156157411901014, 0.027233864712928022, 0.032466933729925325, 0.0266505400317588, 0.058263406822724004, 0.007069434563163668, 0.015520696361948336, 0.01076907677842038, 0.05469865524875266, 0.024029481391023313, 0.05601876209090863, 0.028201270748728087, 0.018798938220632926, 0.0327405020860689, 0.04337896087339946, 0.012601369842221695, 0.03433152421244553, 0.07641386573335954, 0.10686139443090983, 0.04526244516351393, 0.05848000877137695, 0.02812900168022939, 0.020761451484369378, 0.0613537606384073, 0.050081153200673204, 0.05996305562023606, 0.034346207710249085, 0.04037116441343512, 0.029716003486620526, 0.034107516054064035, 0.05723408955548491, 0.031760365036981444, 0.04808785141046558, 0.023442740286035196, 0.04030288682718362, 0.014412387440513288, 0.008630494703538716, 0.06091637018003634, 0.06979376596531697, 0.028609282337129116, 0.04018078784325293, 0.046692966616579464, 0.008898929094097443, 0.010783182673289307, 0.05250563685383115, 0.0053308628765600065, 0.017063377957258905, 0.03375723931406226, 0.034781511673437696, 0.029552805636610304, 0.019754044112882445, 0.015914258547127247, 0.03496062795498541, 0.04346341134182044, 0.04122210839497192, 0.03884598732526813, 0.04227187331499798, 0.008131377066352537, 0.05486583270664726, 0.023974818609920994, 0.02299730240234307, 0.05684747387255941, 0.04093940356480224, 0.006314742894444082, 0.06458465262715306, 0.03674141597002745, 0.013342326689910675, 0.024351242696866393, 0.03453582771388548, 0.043732362267162116, 0.044438795253102265, 0.020288410796118633, 0.01992392383648881, 0.005643030545408172, 0.10045506033514227, 0.035212310164102485, 0.024468015180900693, 0.055270656876798184, 0.04230016143992543, 0.008562182342367513, 0.034268176183104515, 0.019811887526884675, 0.03672910395211407, 0.01573955443953829, 0.050349272920617034, 0.0515141513065568, 0.0857346434412258, 0.03896359440737537, 0.021150486144636358, 0.030934330075979233, 0.012648183669495796, 0.016871673154777715, 0.023359280478741442, 0.058155085492346964, 0.03162221869985972, 0.018613781281081692, 0.018583447373073016, 0.06121766686971698, 0.07655004771160227, 0.023252139799296856, 0.07975853447403226, 0.06523802078195981, 0.023647242258968096, 0.055398245209029744, 0.030696384808314697, 0.08049469068646431, 0.057536695817751546, 0.026460850478282998, 0.010130354801991155, 0.04229379338877542, 0.028276337077841163, 0.02361997024023107, 0.010597021501910473, 0.04811799532866903, 0.010540704791700202, 0.03306286050272839, 0.029187221146587814, 0.03813408873975277, 0.004532221222429403, 0.04833636486104556, 0.015048000030219555, 0.012293285257848246, 0.023213527764060667, 0.03536277869716287, 0.09361636372549192, 0.028202181681990623, 0.012915258445510907, 0.024406429646270614, 0.032616876398346255, 0.0442613617384008, 0.007926339898923678, 0.05940933711826801, 0.012017146102152765, 0.0338865884446672, 0.017290734685957432, 0.03481376922822424, 0.03311108059382864, 0.07615788839757442, 0.022563085791521838, 0.07299171507890735, 0.04293425580752747, 0.05354113896776523, 0.04057443314897163, 0.016644818541992987, 0.04719946247392467, 0.05509111311818872, 0.11764209451419966, 0.044010171467172246, 0.03288114882473435, 0.05444692214950919, 0.04150212283379265, 0.024390911550394127, 0.035171676094510725, 0.05480881201635514, 0.012788764250996922, 0.04684669890307954, 0.03404246490182621, 0.024038446534957205, 0.02975651202723384, 0.03039750370330044, 0.032542831264436245, 0.04440361660506044, 0.018074362904631665, 0.0318495957846088, 0.07898040408534662, 0.020854232666481818, 0.029736356144504886, 0.021069469063409736, 0.01179394031143082, 0.039739641693553755, 0.0177091176821185, 0.030889543372073343, 0.03185698163828679, 0.012116632906586995, 0.015096113252054368, 0.06948786202285971, 0.036029161153627295, 0.028290487925655076, 0.07357165895934616, 0.008887980083402778, 0.052408602953489335, 0.03582401287608913, 0.031189174258283207, 0.03191007700349603, 0.006548158092690366, 0.04675239949886288, 0.04523352260834404, 0.012806904036551714, 0.051504244695284536, 0.09498282468744687, 0.053273422976157496, 0.00541899524562593, 0.02379641818281795, 0.06118800810405186, 0.008967525591807706, 0.02872307944510664, 0.05037416497777615, 0.02407650386781565, 0.01793313941120037, 0.054765684330569844, 0.036132519000342915, 0.07378027455082961, 0.040919115367744646, 0.021443180706618086, 0.03246378532743879, 0.01661542440498514, 0.05170390362452183, 0.025446215012509907, 0.05552499894318836, 0.009142216976865061, 0.03062615982655968, 0.02722003956192306, 0.059692530493651114, 0.04923857555591634, 0.023784799966961145, 0.020105574446331178, 0.019037884327449968, 0.05692649606083121, 0.009463352334153439, 0.022232308451618468, 0.036136145770017586, 0.03658218754987631, 0.05221401946619153, 0.009034911752678454, 0.05385408949639116, 0.0442135182342359, 0.008971199010764914, 0.05576188230354871, 0.04062805777149541, 0.060612067580223083, 0.018456016800233295, 0.007279874141594129, 0.009649354897971665, 0.004382233176979103, 0.04913578428594129, 0.0924031702535493, 0.06188090092369488, 0.03917794022709131, 0.06679159456065722, 0.04426620647843395, 0.04737137610624943, 0.04034620111009904, 0.1096546109765768, 0.022029865832467164, 0.03828165653560843, 0.016222505131736398, 0.04153515052582536, 0.017782993182273846, 0.04733498627319932, 0.023995939708713974, 0.0574534327856132, 0.014326091356841581, 0.01237277393894536, 0.04283424653112888, 0.03613293969205447, 0.016240331943013837, 0.07341034404401268, 0.06690856042717185, 0.017319872675995742, 0.02063024147147579, 0.031640132024352036, 0.021132801825712835, 0.039452858867922, 0.05410211779443281, 0.01595547785317259, 0.06831966899335384, 0.02262601991450148, 0.027827133324795535, 0.02985459765685456, 0.05730057241661208, 0.0563740633827235, 0.010169169549564165, 0.03972821516383972, 0.0412356214198683, 0.03598516833569322, 0.01472218447764005, 0.028428215267402784, 0.03835413086095026, 0.04882143258250185, 0.029918919383947338, 0.021280318731442094, 0.043220824894628355, 0.06334167825324194, 0.023281420281689082, 0.04974458286804812, 0.029674928369266645, 0.005618556635454297, 0.023442309416298355, 0.009049177951445537, 0.04751764450754438, 0.031279639939644506, 0.07745656371116638, 0.05351447254153235, 0.1007847808567541, 0.022926980729347894, 0.07193111056195838, 0.06140078990054982, 0.04209510137193969, 0.03949958957465632, 0.019609192153438926, 0.027408129469092404, 0.043745793867856264, 0.00997811698886965, 0.02329188838068928, 0.04244760709947773, 0.018042749958112836, 0.01850773473935468, 0.021077796384426098, 0.031548394089830775, 0.0328723889376436, 0.03625492671770709, 0.011069864566837038, 0.11004582034157855, 0.023193533033398644, 0.01221393482826118, 0.08875565776335341, 0.057536207272538116, 0.02988518601549523, 0.02417513571812638, 0.010860705299169889, 0.030762935522943735, 0.027892954614279524, 0.009114594664424658, 0.035438801760652235, 0.08467548420386654, 0.03631420014426112, 0.0012869675099084685, 0.020791580135534917, 0.051210625629339895, 0.058301364071667194, 0.04776583565399051, 0.15680508661483014, 0.09075066606913294, 0.09357782972178288, 0.12161441493247237, 0.13766270450183324, 0.1025402866570013, 0.20536825859120914, 0.09922142260308776, 0.11924650413649422, 0.16778457031718322, 0.09496274683624506, 0.09218323669795479, 0.10430305278194801, 0.07877109638814415, 0.11697692663541862, 0.06733679066279105, 0.1065868523770145, 0.1667501436812537, 0.10553215790007796, 0.12150667714221136, 0.17134424644921506, 0.06970217052314963, 0.13908317685127258, 0.10080607328563929, 0.19013844510274275, 0.1417396143078804, 0.09109604717897517, 0.09973067670528378, 0.07243165227451495, 0.1015487162928496, 0.16522695470069135, 0.1605590951762029, 0.09414854552596807, 0.11178716511598655, 0.15408988802560739, 0.12616803630122117, 0.10218284797987767, 0.11202350564833198, 0.25375320655958994, 0.1810845895005124, 0.1813683799867119, 0.20820974611810275, 0.07561603068773236, 0.14687255530485085, 0.09801767433860473, 0.15477733899440083, 0.09903537508632455, 0.09338707995734044, 0.11155947590512888, 0.1052733917853662, 0.12342269718647003, 0.19097807790551866, 0.11987223555999142, 0.1497642272817237, 0.06704866433782236, 0.16121527925133705, 0.13756129065794603, 0.10390285961329937, 0.14684674383274146, 0.21788836962410382, 0.16717097109981946, 0.08318958072257893, 0.10654006738747869, 0.049422092137059996, 0.08473598238612924, 0.16274361152734074, 0.11860755485083375, 0.09100989358765738, 0.11639369864548955, 0.1838287343936307, 0.20879806312067167, 0.0685683452923383, 0.21825795407806123, 0.18097622745803424, 0.13835103756615094, 0.09651710093021393, 0.07341637622032847, 0.11905811567391668, 0.05397492640518716, 0.1430595006261553, 0.2204570182199989, 0.126423640442746, 0.17823331749864987, 0.15304490338478768, 0.1382278970309666, 0.15133256598242692, 0.11620908283761569, 0.33197469636797905, 0.12383920912231718, 0.18178012860672815, 0.08750980640096323, 0.13059500232338905, 0.14813372120261192, 0.19158243547592843, 0.13689007024679864, 0.18819134815462998, 0.1209714487195015, 0.11789598874747753, 0.13302142997937544, 0.11344036819147212, 0.08254234652434077, 0.20493141774620327, 0.12538804672658443, 0.11173767955707652, 0.10170101347778525, 0.15246432168143137, 0.11368569931281464, 0.2001467959157058, 0.10432631974773747, 0.07999483429427658, 0.19345390291086265, 0.12434380847428526, 0.1434482740504401, 0.09714147528367383, 0.13066335794116768, 0.11103701751146998, 0.1694940578724657, 0.11897175173674311, 0.14597767618085655, 0.1548946848405259, 0.12138418800064496, 0.16095816876207078, 0.13248621512736591, 0.18035730852612428, 0.11098312826028892, 0.1397602462342807, 0.19973480302308286, 0.14895652633692535, 0.07783612262989793, 0.17187484726309776, 0.14212770919714654, 0.05753670260310173, 0.06307661533355713, 0.1558229885995388, 0.14284445930804524, 0.11003838359777417, 0.20083592965134553, 0.13619773382587091, 0.12967804366988794, 0.08944458793848753, 0.13689107447862625, 0.14669438557965414, 0.09948585448520524, 0.08865212010485785, 0.1520189448658909, 0.20356556746576512, 0.15485585906675883, 0.0695113596905555, 0.12883657882256166, 0.12092545761593751, 0.07428851085049765, 0.06991288957319089, 0.176920637222273, 0.0874839202900018, 0.1121358506913696, 0.2152395046183041, 0.12329103425145149, 0.1954892094113997, 0.2411663005394595, 0.09637222013303212, 0.17389914792563232, 0.12946904131344386, 0.1461904647627047, 0.14769085496664047, 0.05831129103899002, 0.06374230568430253, 0.14691647009125777, 0.2047750289951052, 0.1544433640582221, 0.2099884578159877, 0.1272147037088871, 0.11982857861689158, 0.09855257027915545, 0.14783383586577006, 0.12449326259749276, 0.09389860036649875], [0.01050458976533264, 0.025144792793850814, 0.03396009414323738, 0.07441465729581458, 0.02038133447058499, 0.014040501056505101, 0.03383793069847992, 0.016710685632590736, 0.026539691158437302, 0.06586068522717271, 0.009858202039530235, 0.029651532481823648, 0.021244875454742993, 0.0554638799013836, 0.02012960985302925, 0.007901262940971978, 0.05372834338673523, 0.015356875956058502, 0.03821668680757284, 0.010472942043894103, 0.026530739585203782, 0.04379284009337425, 0.055132408759423664, 0.021005447588062713, 0.054071994232279916, 0.02490792978954102, 0.021712515004245297, 0.0410967083381755, 0.04709442864571299, 0.03445675802816238, 0.050815056676843336, 0.03131053363904357, 0.04409878135525754, 0.031553751123803, 0.022926190236051167, 0.03553824106763516, 0.05144114772390042, 0.034203277701245885, 0.05855401658586093, 0.021791253904146806, 0.008573137290243591, 0.021742799718465124, 0.007272150716744363, 0.0402901948296598, 0.042596067168882916, 0.010906386821131622, 0.049472341047866006, 0.03127051364364369, 0.038819527852215936, 0.04014368215575814, 0.04100615105458668, 0.03327077720314264, 0.05510589839624507, 0.02109495483871017, 0.03641639430341976, 0.012039926219066339, 0.031158378946461847, 0.05905432081116097, 0.024880235382754887, 0.0387895264263664, 0.02041520015336573, 0.026808808324858546, 0.014968694553577473, 0.05500038280817015, 0.03605353752417224, 0.02673723136207887, 0.0025289290642831475, 0.0304565125011972, 0.004623705130403063, 0.017031749743702154, 0.026906675126935755, 0.06832379448626723, 0.013956819028992738, 0.037286255841276476, 0.01853929170673447, 0.026738065960151807, 0.03830335269282971, 0.036977410449513366, 0.08538055672709431, 0.08023048950625317, 0.012243339991463082, 0.030136199867618934, 0.02088309245716248, 0.05539606711161988, 0.049615976733288596, 0.041130641874458106, 0.025782595355329768, 0.0350875004327723, 0.0045214024056414405, 0.033415430691093206, 0.04260132581527744, 0.007518832122773996, 0.04146632671888385, 0.008352033261741911, 0.025758459864716445, 0.07411369987364326, 0.05267488045085754, 0.024621694880936826, 0.03704551161666002, 0.00905552988738886, 0.07063086104712316, 0.04113078097413693, 0.04957207212490695, 0.04358981563044446, 0.016969372019437805, 0.02307043829932809, 0.04442299895786813, 0.01305467533945505, 0.013735365554956453, 0.023145957550566112, 0.007022750505711883, 0.04727818949946335, 0.061336953325995376, 0.02429367069687162, 0.037121870554983616, 0.05723571803952966, 0.015201040211000612, 0.055487279181501696, 0.0759254087294851, 0.044102319915379794, 0.024208830070814917, 0.09875106212816068, 0.04456609181527581, 0.024330406582781246, 0.004459039100246238, 0.008748182361679417, 0.02392238990536758, 0.01636084824401353, 0.009556616124297892, 0.03239162991355572, 0.03324075202856745, 0.014609042155955518, 0.04800261044874787, 0.04090838094374963, 0.04448113583826593, 0.021353503822215965, 0.0671165246250374, 0.022018459658803682, 0.012622378982736595, 0.0269008549928133, 0.01952763394053493, 0.01811907157701041, 0.02485841030388006, 0.018957583100668023, 0.036037856579891274, 0.009212871980188149, 0.029302653523960283, 0.03280891877199922, 0.02872941696218082, 0.03904522556279387, 0.038505461133484326, 0.04451931361109018, 0.020220438550625528, 0.020453762994813066, 0.056435935598398955, 0.02153317819881652, 0.03912175074219704, 0.02968282312420862, 0.027125940325536897, 0.028935009680156196, 0.0192571054212749, 0.006421072724541383, 0.04831143548446042, 0.042473757839096446, 0.007171676643857998, 0.012411508958653679, 0.021803720288776925, 0.03455508793038981, 0.03908407169261149, 0.010218069023851837, 0.055024691325213225, 0.03108597586729697, 0.03075370066133993, 0.03460434618006859, 0.018217716998021518, 0.020908893751246587, 0.04185029950791171, 0.10891547599541289, 0.04434898775070906, 0.0968525754287839, 0.09077253525278398, 0.023005307419225574, 0.0411060483727072, 0.0563542331968035, 0.044195727046046934, 0.056051593007785935, 0.027760012640750835, 0.012635263514571955, 0.02974156050809792, 0.031084913959992782, 0.010329002714050668, 0.03264775652704494, 0.10128507829670395, 0.02649796295112797, 0.05533646120290671, 0.01583742463429059, 0.03509896767458745, 0.022005021272759353, 0.05048690696379968, 0.044954980590513775, 0.05806788695710046, 0.03234742674976587, 0.05619186994486621, 0.033096851714487584, 0.014707706236679639, 0.06342035438865423, 0.07654660753905773, 0.03625680286703365, 0.08371685671487025, 0.017022179007264118, 0.02045451956135886, 0.022265649966097305, 0.007446300970124347, 0.04843690000208361, 0.06791863444128207, 0.03757924386965377, 0.025611243210732937, 0.05038765086127179, 0.009463478711300662, 0.02689989995477455, 0.032812009499009163, 0.041740807704627514, 0.013339387785111154, 0.04034985162849937, 0.046571763298873387, 0.08011885692498513, 0.026220459091876234, 0.03563582118866699, 0.013501141203700431, 0.04228718445769378, 0.02306910667435399, 0.015682576157684838, 0.07907776707517249, 0.014169816260359116, 0.027703599239300405, 0.022242550937724963, 0.033786568990243335, 0.029767032712697983, 0.060507193207740784, 0.03312489217413323, 0.025521679980946437, 0.01150551119021007, 0.0432651807287974, 0.016511494892516305, 0.04733861643554909, 0.04397371717329536, 0.034970141015946865, 0.03258459170215896, 0.06649286273334708, 0.011449518480471202, 0.026109089442927922, 0.051454820204526186, 0.05635765640597258, 0.02586396866744118, 0.07424931866782052, 0.019434130118627633, 0.031205798366240094, 0.0642639294798885, 0.030211965087801218, 0.02118953244228448, 0.02034862569001104, 0.028854755950825553, 0.03881814703345299, 0.007651483174413443, 0.033035698745931895, 0.025071936792560985, 0.0249440125854952, 0.0010814118993169228, 0.007755530582341764, 0.03310337922136698, 0.055485009481864314, 0.12177064083516598, 0.06670689303427935, 0.008448129087420446, 0.06110708601772785, 0.017531185444178324, 0.01889895597871925, 0.026534108511571373, 0.018879339531330124, 0.056203347364706654, 0.014631617016025951, 0.04496555216610432, 0.022384544568402425, 0.04911645282326, 0.02257424090722842, 0.02770659836408283, 0.01979232536229704, 0.061751382159335275, 0.025614506964172636, 0.031093117448368242, 0.02763784071430564, 0.06990974795605455, 0.06185020399945123, 0.043844066094607115, 0.0059561367130040056, 0.018721829501113722, 0.03232046176812478, 0.0307786673573511, 0.016951993041272675, 0.05683283108685698, 0.03441375247868044, 0.03734917300088065, 0.05647987752620663, 0.09588772577366658, 0.01513321215419897, 0.047473227605223656, 0.04497335871149387, 0.031339988844203095, 0.018089251659278358, 0.10037051487181868, 0.08183588978967496, 0.008506164187565446, 0.024103655446586863, 0.03487518682543721, 0.04588122499574508, 0.03709004386993391, 0.03672609804198146, 0.008282101746382458, 0.030736374269638742, 0.00723023251962981, 0.05389826212610517, 0.05428445711731911, 0.030667221373213188, 0.02165923304190593, 0.06418082929615464, 0.04668321946103658, 0.01338678939334516, 0.020227700571662614, 0.012611872716141599, 0.038599502694393904, 0.04882772260212472, 0.060058437287807465, 0.005349506898450532, 0.05916049118552889, 0.02417231470878635, 0.030189902521669865, 0.05819357878395489, 0.003279530651135636, 0.03721680438944271, 0.015031879734514015, 0.023350352654233575, 0.04314304781811578, 0.025391150199409043, 0.061381397369716845, 0.07263469030814511, 0.012012787362826722, 0.0813877581219588, 0.0682304280677012, 0.029971227648534944, 0.006330574812766696, 0.02266823497068669, 0.0153584331939263, 0.1319435363901513, 0.24811498767563275, 0.13539447050009454, 0.1488433466958148, 0.19565565405147417, 0.1174976886915309, 0.08303184168679373, 0.10445176730198519, 0.07017069895352636, 0.1370042134076357, 0.11537406407296658, 0.08095125654446227, 0.08882051892578602, 0.09117554434176002, 0.09896053267376763, 0.13648197214518273, 0.1302575668586152, 0.14557444996067456, 0.24863726965018682, 0.1228129927601133, 0.09849458267646176, 0.08950003103486129, 0.14233174467725412, 0.1590012059147869, 0.100891860468047, 0.10079453819032226, 0.1669392106788499, 0.1114417432940432, 0.17510115914046764, 0.17703281263155596, 0.148757810571364, 0.14625872538558074, 0.13930108158716134, 0.1467121767678431, 0.13532568061990397, 0.08472097319151674, 0.18692696600088052, 0.17769249794738634, 0.15261875625167573, 0.3038904033601284, 0.10397081489541701, 0.11098128264503819, 0.05255668982863426, 0.17137205281427928, 0.08257231741611447, 0.05303316390407937, 0.11596609944743769, 0.14280822553804942, 0.0993665408875261, 0.18189105551157678, 0.14586347873721803, 0.15743760338851384, 0.10383001887904746, 0.2290697582066059, 0.18487646031592572, 0.07360844234270708, 0.16707909745829447, 0.19350515944617136, 0.08573417525206294, 0.08693785566304411, 0.12238240800797939, 0.11907564901879855, 0.09065111141119685, 0.17310678187225545, 0.11099361841167722, 0.11830180697143078, 0.14153047624443257, 0.15268264710903168, 0.1153588377471481, 0.10293781996837684, 0.1282716712781361, 0.15648435668221541, 0.10421623422631196, 0.17226936109364033, 0.09932375925460032, 0.14463303690510138, 0.20725236034819058, 0.10211442450859717, 0.20864073799124785, 0.22112598589488439, 0.1387277330671038, 0.15163950808346272, 0.13134768764887536, 0.22784380827631268, 0.12587967248899595, 0.10847826195614678, 0.13445912354758807, 0.12083563315016882, 0.0893598117732576, 0.14007690495678357, 0.19359670739088738, 0.07240791711956263, 0.12819574320954935, 0.09489036072045565, 0.23767119379980223, 0.18525783770850726, 0.18494406954518386, 0.16372292754905565, 0.08351453114300966, 0.1639465048377003, 0.20015215634235314, 0.08062796853482723, 0.17208531525518211, 0.13711590027170523, 0.1431526227721146, 0.07548036439610378, 0.07516530701624495, 0.1410751656762191, 0.12641537588621887, 0.10597675440034696, 0.0796279843364443, 0.16951445463512624, 0.10243744788957493, 0.09220239174153123, 0.16258277158652032, 0.12918666218008312, 0.07853673717805318, 0.16275153681635857, 0.16751135140657425, 0.12169068226856844, 0.08911524739648614, 0.1488493313746793, 0.10597824039203779, 0.2289378781403814, 0.07541131667260613, 0.11081517048712287, 0.12780260001974447, 0.09205412505460636, 0.14174063211040838, 0.14022414705583028, 0.06625262062464442, 0.09897904310907636, 0.1038727665852223, 0.19936459431690828, 0.2509185586656843, 0.1025275301986507, 0.1352658202605588, 0.09995467468564, 0.11417537767972265, 0.10637332419199602, 0.1076493025092142, 0.09153535110609871, 0.10756323034209864, 0.09152051833059106, 0.1311817586954151, 0.07524994068912097, 0.1072326684370637, 0.09950739797204733, 0.11212996100740773, 0.1264453399926424, 0.06832267490348645, 0.09890170368765082, 0.05778689203517778, 0.12974025176039763, 0.13505801212574753, 0.07216620937521968, 0.2245661855808326, 0.09201536034899098, 0.16167965504739965, 0.2622034102678299, 0.09871434659830161, 0.09805793182126113, 0.10011068345712763, 0.09606055542826653, 0.06981573692922081, 0.16332715164337838, 0.13456691562065057, 0.11324556757296834, 0.19874756171235017, 0.10824817751667329, 0.1570987022880997, 0.13440081024808542, 0.13113711109118803, 0.13008907304278441, 0.15638567054910318, 0.09868504067084619], [0.05891754172210183, 0.012701899046078324, 0.039701626769133976, 0.026581658549340706, 0.0698707118364317, 0.030595893772052865, 0.02265955481146063, 0.03454501847071307, 0.044159778260758946, 0.04904583768386926, 0.08005693381918327, 0.05963423755019903, 0.014860117076230901, 0.014910067431628704, 0.08645989559590816, 0.0552595560438931, 0.026169935374387672, 0.0010880430948288578, 0.04382907047069498, 0.0035184292605013718, 0.020538551034405828, 0.06698715513838188, 0.03431849634008748, 0.022643222473561764, 0.011068839130790105, 0.04749035382909434, 0.027860157624153153, 0.046339229347982576, 0.004464524631787623, 0.06263309091861759, 0.0426712284928986, 0.05912968569568225, 0.011365744850731321, 0.013323506672999688, 0.038943815111581764, 0.0623233803947057, 0.02491980924138001, 0.048540590330958366, 0.06629671183015619, 0.0785323063443814, 0.034027370890336375, 0.029129993503115008, 0.06689232308417559, 0.022066126743863736, 0.03149438948769655, 0.026645736003826772, 0.029132575328860964, 0.010960129339114895, 0.023274616271789585, 0.10001344260360513, 0.01000734488479793, 0.03898152469524315, 0.060801127792469094, 0.03726014581375888, 0.028006293711119463, 0.010362663139988269, 0.07710690104535647, 0.012962501446184303, 0.04047411513913955, 0.026431973724226867, 0.07562533340283803, 0.0628266158912863, 0.02400557490597878, 0.0850888341665268, 0.0194601519365928, 0.041019932100815434, 0.057494558793093474, 0.007828918385452457, 0.0772562398176108, 0.02142661597047533, 0.03777165265221681, 0.033724866408322535, 0.06318560841360263, 0.01911866052874497, 0.03810364626614111, 0.02776789043231734, 0.04679291821750147, 0.0525130430635597, 0.07337373029440641, 0.0545901473212455, 0.046632671994822364, 0.05304504165958081, 0.01684728660620749, 0.03949772360335503, 0.02658409109738256, 0.012868734691957278, 0.013407024155770029, 0.01980546010392053, 0.05252654591043081, 0.04242406193433063, 0.032816660856562, 0.019016434139172946, 0.016374899007912194, 0.02929443646488445, 0.07957834949983017, 0.029519574384071996, 0.05476140955995236, 0.052435859705188444, 0.027570675925484726, 0.014271791591974241, 0.04140404738219721, 0.016633850023416535, 0.04221368215179869, 0.04685798633311476, 0.05574633028092129, 0.03229333393807922, 0.010459910778860961, 0.0648772097857935, 0.03344072986926351, 0.004815721634908446, 0.02813625182690365, 0.027753690390714576, 0.01016331124784691, 0.02783356074775968, 0.06115650372313602, 0.0686943560306515, 0.054152804360325844, 0.023611670060615455, 0.05852745193988085, 0.01727827339033995, 0.026632032989125167, 0.025275943434930274, 0.04370163480884262, 0.007285464421979019, 0.08264767551528555, 0.022861198455627476, 0.019433200525652086, 0.022974914139402763, 0.01325887960514852, 0.06132537751857724, 0.016530894208699465, 0.05728098989597388, 0.04618955809356911, 0.08760828897356987, 0.037001654505729675, 0.016381664002048116, 0.08388367454920496, 0.02910396150712456, 0.03529003295781357, 0.013605750099356686, 0.030053761255528246, 0.04684172524139285, 0.0142619477451912, 0.10789180413952895, 0.10169287105756146, 0.02804015769756266, 0.06152969119804246, 0.025838085949154835, 0.05275285430252552, 0.023938393153782402, 0.03390972988147821, 0.01526785216161183, 0.014447901963389345, 0.025686728535220027, 0.06080029319439616, 0.05146088291491781, 0.06637077392744166, 0.07225017129842724, 0.03707632389185684, 0.01462879600668592, 0.016628097742795944, 0.03783721270571862, 0.06170664634555578, 0.05408576510048338, 0.037249211221933365, 0.03582718163462622, 0.03795511155788388, 0.03074297641537019, 0.013000935365978097, 0.015150579258001276, 0.03613402195540922, 0.028647290476198708, 0.02828145832089441, 0.0378314994408616, 0.025402849839468087, 0.07564509912793126, 0.035585433178182156, 0.03279559573690806, 0.07224821711757354, 0.01777314255014062, 0.025314390925424438, 0.02851861309526222, 0.0332524228308882, 0.017422390835625783, 0.05822778373424496, 0.0511605734936893, 0.03423478886751192, 0.04704155380438481, 0.05791929457336664, 0.04796156247279473, 0.013544014438853731, 0.045523915240275006, 0.04750582782019462, 0.06108628213405609, 0.07419902565223829, 0.0642782397834318, 0.04726683760860136, 0.05959909622158323, 0.038841603989047666, 0.024210044648498297, 0.020345031150749752, 0.028580953500100544, 0.030726403197539703, 0.01891369715199939, 0.05165581924042531, 0.01317940788742687, 0.026003772326345955, 0.07527793025864021, 0.00650198378467134, 0.03181292775220104, 0.04080556931772402, 0.045420367403754165, 0.04448253022772925, 0.038606199835027964, 0.03347514516540936, 0.07431160139718226, 0.027165561681613326, 0.02042823311473642, 0.012960654134596033, 0.06983208283782005, 0.002153460227418691, 0.07300067174115352, 0.007967968022317758, 0.006423355146710361, 0.08135178898062025, 0.0452565385161766, 0.04483232520786779, 0.022367776271754077, 0.05340638191306165, 0.10612867160567216, 0.011104061883608145, 0.03131320706701704, 0.10078557474272591, 0.03197288220482213, 0.03705342672765255, 0.02327515570712941, 0.008535291999578476, 0.04433881311810442, 0.027222392382100224, 0.046594697782503705, 0.07805142179131508, 0.058139655606022904, 0.030776971019804478, 0.02509725123776921, 0.04869380353816918, 0.013376059210194009, 0.023810820088588765, 0.024519371800124645, 0.06987655402294227, 0.012510275667799371, 0.01677026609624071, 0.00847364794130304, 0.028538154903799295, 0.016907732202006236, 0.04326303316546338, 0.05014031806162425, 0.034444920984762054, 0.03466951946860977, 0.037643884508205314, 0.016007587646267245, 0.03862753976136446, 0.0340840862398701, 0.04282288106956652, 0.004438206802920571, 0.031295839963214736, 0.022939138380544524, 0.045032744096325975, 0.06587780466569321, 0.01491151949656861, 0.055688196793198586, 0.031462542446596284, 0.017244887771084905, 0.040296810546091626, 0.046743907633104494, 0.02665148998078491, 0.061018265783786774, 0.0480298570224217, 0.02329714533074626, 0.04264003284541624, 0.053539459593594074, 0.036987585082117996, 0.020425714053479687, 0.024100315357957567, 0.05477200488426855, 0.04978208549852882, 0.011632740747050514, 0.08564621675759554, 0.021176161909742013, 0.04654155152716807, 0.02249754609407059, 0.047777764299618344, 0.03492461470887065, 0.027130262593605688, 0.07443948489214693, 0.05402824907962765, 0.06290138366499118, 0.0431006156307246, 0.01287721807602793, 0.07473924809268542, 0.045753619700138054, 0.014052526393373097, 0.01339024059208376, 0.028800384939781258, 0.026756016604070152, 0.0551457419725401, 0.04900536985535707, 0.011926339456944593, 0.061660478822886944, 0.09912186115980148, 0.055845528707972596, 0.0367020270121949, 0.027863535032208477, 0.033283482771366835, 0.03664607162188206, 0.02411100228450128, 0.06461929183985506, 0.026472427982038686, 0.030005500452326875, 0.03668047674000263, 0.039932406707001586, 0.04232070408761501, 0.05079397798648902, 0.043263382610997984, 0.025619129483987178, 0.0932333782049162, 0.058926478028297424, 0.026176277980474488, 0.022990515355819037, 0.0168067933326321, 0.043758177131946595, 0.049665441936148066, 0.053465003945997784, 0.06724257607545171, 0.049639060494623015, 0.0256288817285427, 0.04431812797806092, 0.01735945331997105, 0.053368149857435904, 0.04771701166672366, 0.06467708945274353, 0.047768207133880684, 0.03818359804738845, 0.01589603309652635, 0.061103347289775095, 0.028017516680327908, 0.034883410669863224, 0.015330782891916377, 0.025887452764436603, 0.018139205407351255, 0.07341584696301393, 0.021858325394402658, 0.00217492547069144, 0.31786447923098293, 0.10249250422098807, 0.2849581635424069, 0.1172651004578386, 0.12975847721099854, 0.14003056101500988, 0.11864388361573219, 0.11741436459124088, 0.2051694614014455, 0.18044958928866045, 0.09629578994853155, 0.13183635499860558, 0.1041171613282391, 0.1573591511696577, 0.15606614840882166, 0.09705270254718405, 0.17115363239177636, 0.14128187458430017, 0.3651501461863518, 0.06468620217804398, 0.13191602858049528, 0.12445700168609619, 0.1537592921938215, 0.14763936772942543, 0.09444304329476186, 0.17705143163246767, 0.08287038427910634, 0.19866788813046046, 0.10451459964471203, 0.1915346530399152, 0.1294216795691422, 0.14934899099171162, 0.1067792306255017, 0.1276385166815349, 0.07747369672038726, 0.11416985440467085, 0.13367842829653195, 0.15396840311586857, 0.12857607565820217, 0.18467238412371703, 0.1288873196712562, 0.13203212592218602, 0.1392360372202737, 0.11558606555419308, 0.09382304549217224, 0.11630500054785184, 0.07463740677173648, 0.1425286012568644, 0.20024447781699045, 0.177929428805198, 0.1345194045986448, 0.10583011619746685, 0.16131647596401827, 0.22732191985206945, 0.10944011927183185, 0.11300218384712934, 0.19083384850195476, 0.09916578951690878, 0.10355489328503609, 0.12297231278249196, 0.10133278609386512, 0.11553494472588811, 0.09130089011575494, 0.17137085859264645, 0.17048824738178933, 0.09572613944432565, 0.18370073554771288, 0.10010162501462869, 0.21243879704603127, 0.14867284441632883, 0.13557384801762445, 0.10474938633186476, 0.15125789998897485, 0.09812457753079278, 0.14435406401753426, 0.14155115799180099, 0.11302653646894864, 0.14742090659482138, 0.1224572097084352, 0.14195545629731246, 0.16719306420002664, 0.0983004809490272, 0.12840338849595614, 0.12246474144714219, 0.14231064223817416, 0.1736192386597395, 0.12011265408779893, 0.11933589433985096, 0.18191424783851418, 0.10025708417275123, 0.10011459181883506, 0.18021881952881813, 0.17344195103006704, 0.16736276580819062, 0.1707506233028003, 0.12020010368100234, 0.15603636072150298, 0.18521135805972985, 0.10941777511366776, 0.13443846894162043, 0.15429739760501043, 0.11746047783110823, 0.14479034846382483, 0.1327527572533914, 0.20244054283414567, 0.07248119211622647, 0.08784177965883698, 0.13831389455923013, 0.1886414068617991, 0.09922218256230865, 0.11414754417325769, 0.09582020475396089, 0.150263194793037, 0.10941719157355172, 0.13880917084004196, 0.1731011364609003, 0.12377944375787463, 0.1076183748830642, 0.15458931694073336, 0.17815812224788324, 0.06736055295914412, 0.2375240602663585, 0.12351166669811521, 0.0916467122733593, 0.13131237668650492, 0.106406070291996, 0.12814333316470894, 0.0941841753997973, 0.12618501324738773, 0.16982747640992912, 0.15256812396858419, 0.17453659086355142, 0.18120984706495488, 0.20260677034301416, 0.11168277928871767, 0.10735248415065662, 0.14287735468574933, 0.1382559748100383, 0.07913265377283096, 0.147625525615045, 0.11115574756903307, 0.09721687409494605, 0.11397412419319153, 0.1807358767837286, 0.17404839848833425, 0.12083947365837437, 0.12381708888070923, 0.08426954384360995, 0.14226139416652067, 0.13852353473859175, 0.16745526370193276, 0.08812383988073894, 0.06402321918202297, 0.1666269488632679, 0.13828455470502377, 0.16871831592704567, 0.2710440158843994, 0.13375416637531348, 0.13175528363457747, 0.16035951088581765, 0.13384190095322474, 0.1179559441017253, 0.1444219718022006, 0.12266204585986477, 0.11847476554768425, 0.07811212353408337, 0.07147452434790985, 0.11859801464847156, 0.06812616437673569, 0.08566723777247326, 0.0752434946064438, 0.08571642477597509, 0.118808849049466, 0.18026234076491424, 0.08767225446977786, 0.11908381858042308], [0.04791431947212134, 0.07367696759424039, 0.02946779198412384, 0.030093899994556392, 0.04599694235782538, 0.03708889714575239, 0.013316637354104646, 0.09376399258949927, 0.024539875432050655, 0.07505963875779084, 0.049870715742664676, 0.06870979948767594, 0.02578683789553387, 0.02530625189787575, 0.024039057216473987, 0.028165561147034168, 0.06501123402267694, 0.02524788092289652, 0.03565851139969059, 0.0272381683212838, 0.07493039140743868, 0.05889730780784573, 0.03778914189232247, 0.014285087485664656, 0.03869090136140585, 0.002419032048367496, 0.0381602293013462, 0.025396349473989437, 0.013813549752480217, 0.052225775085389614, 0.012413633621430822, 0.024776260069172298, 0.017864704065557038, 0.008735425903328826, 0.030407400136547427, 0.07191384863108397, 0.020513560589669005, 0.029850750363298824, 0.019424907131386653, 0.05572790805516498, 0.07509332802146673, 0.027393159290243472, 0.02856298250013164, 0.039488302144621096, 0.03880400297098926, 0.040959355887025595, 0.023018750894282545, 0.01264122105203569, 0.02793416883131223, 0.07410110626369715, 0.06623728573322296, 0.03676164649160845, 0.04321652637528522, 0.015314411538253938, 0.042132956840630086, 0.051033222648714266, 0.01172890018538705, 0.015195954591035843, 0.01774202154151031, 0.011972858121485581, 0.03598830316747938, 0.029513060447892973, 0.011284195119515061, 0.017784114461392164, 0.013261374069510825, 0.021586516140294925, 0.027516172600111792, 0.0309221469797194, 0.029622253695768968, 0.005652588135230222, 0.013640497029492897, 0.0324867774865457, 0.02986092838857855, 0.008313972536208374, 0.03953837463632226, 0.056027684826403856, 0.03315363831019827, 0.015196916414424777, 0.03852903683270727, 0.04980720825759428, 0.041825176748846254, 0.047890085593930314, 0.01336692358433668, 0.040439224868480644, 0.0030539669512238887, 0.02116770397073456, 0.017332088002668958, 0.06691763922572136, 0.03128359240612813, 0.01745216834491917, 0.019271700709526027, 0.0868707892618009, 0.03829308645799756, 0.037989957723766565, 0.03029145546523588, 0.07857816852629185, 0.04212706715666822, 0.038292886290167055, 0.06192840516035046, 0.03982147980215294, 0.0233221764875842, 0.027233973278531005, 0.0818207041759576, 0.014362301378111755, 0.021412853583959595, 0.01819752888487918, 0.047089197140719206, 0.02370117900760046, 0.044610532466322184, 0.0176689043042383, 0.029186437438641275, 0.02113842518467988, 0.026718815921672752, 0.045714563224464655, 0.05217097998995866, 0.013923356226379318, 0.01856388520848538, 0.05826234830809491, 0.019479312069181885, 0.046008592804095576, 0.036038212810776064, 0.017329329757818153, 0.028593075528208698, 0.05485471151769161, 0.04336465396253126, 0.024114218540489674, 0.005774617569321501, 0.021586241333612373, 0.035524612691785605, 0.010963477909431925, 0.03771419769951275, 0.026022182677739432, 0.0240462547766843, 0.0663292407989502, 0.047289443002747636, 0.039398077343191416, 0.019813422712364366, 0.02976725323657904, 0.03634627449459263, 0.04186173960832613, 0.04793750501370855, 0.012366889343996133, 0.048802888220442195, 0.03414994484878012, 0.08306295930274896, 0.058588845788368156, 0.044117125549486706, 0.04331617942079902, 0.047233172093651125, 0.011408728347825152, 0.015803677695138112, 0.06689112886254277, 0.02664124240566577, 0.026677939275811826, 0.013395201531238854, 0.046330920686679225, 0.02096585676606212, 0.003329815821156704, 0.028618395062429563, 0.04001110659113952, 0.011751017034319895, 0.018589693287919675, 0.048930513872099776, 0.010749078655083264, 0.06523740331509284, 0.0391277930965381, 0.06430196136768375, 0.01904491564658071, 0.02642675578993346, 0.02792150397518916, 0.05591129571465509, 0.02234047880795385, 0.07338808131005083, 0.04542720703674214, 0.039900542702525854, 0.024174808324979882, 0.0340282122737595, 0.04466244378792388, 0.04574313294142485, 0.03304459434002638, 0.06393076878573213, 0.01710553533796753, 0.022310263643573438, 0.04105472398389663, 0.010686812889096993, 0.011137106539016324, 0.0676413511059114, 0.035782890261283944, 0.013592427064265524, 0.025716253290218965, 0.02894413597615702, 0.051109004832272015, 0.021030468566875373, 0.011083224073185452, 0.06698459027601139, 0.028067672292568853, 0.015910948992573788, 0.028738278629524366, 0.06920738957290139, 0.004678405655015792, 0.033297830394336154, 0.05125634192622133, 0.022367611727012054, 0.03156400039525969, 0.041067097069961686, 0.03874908234657986, 0.039584535373640914, 0.04136247354160462, 0.030307818337210586, 0.056956677298460684, 0.01972586794623307, 0.056871544902345965, 0.031963962862001996, 0.029838085507175753, 0.03839709569833108, 0.028677108697593212, 0.052874909181679995, 0.07244691931243454, 0.025640047022274563, 0.034058016924453635, 0.015317561637078012, 0.064997045855437, 0.05382136035976665, 0.027457162105877484, 0.05566010883610163, 0.030960256899041787, 0.03320946477885757, 0.061920853065592904, 0.07713487025882516, 0.01986371572794659, 0.03685650907989059, 0.004251406112286661, 0.022625339683145285, 0.03599216403173549, 0.012966229996111776, 0.04526287264057568, 0.012131991546734102, 0.029128012180860554, 0.04498576233163476, 0.03598544992772596, 0.018894306317503964, 0.058726513758301735, 0.043646361346223524, 0.0146164059572454, 0.02919599460437894, 0.03356608582128372, 0.11038508785090276, 0.011956356149832053, 0.048734956687050204, 0.03837115191189306, 0.0033306868904868937, 0.03287548305732863, 0.043881928348647695, 0.027841743880084584, 0.07753922284713813, 0.07075834420642682, 0.04998514388820954, 0.05073356462110366, 0.05947537214628287, 0.01880263793282211, 0.028531030286103487, 0.04235853920025485, 0.015948097088507245, 0.04300867413569774, 0.08832295598196131, 0.0202370439988694, 0.02371212208111371, 0.05505367834120989, 0.048162059392780066, 0.028126026304172616, 0.0489193553637181, 0.07350592927208968, 0.04779914833073105, 0.02771786374172994, 0.09814124235085078, 0.03382159496790596, 0.019658894843554924, 0.04044281771140439, 0.05761625404868807, 0.023168752934517603, 0.06959035473742656, 0.01790274104236492, 0.03253846489159124, 0.01776191788459463, 0.03460488561540842, 0.055029763374477625, 0.03510821610689163, 0.046447859411793094, 0.02032657160556742, 0.021322433703712056, 0.010842364497615822, 0.026639712309198718, 0.037005484835909944, 0.005230141986560608, 0.09163348084049565, 0.021877611055970192, 0.01798918131472809, 0.04339662313993488, 0.03426156385934778, 0.04731638762833817, 0.01863936714029738, 0.015435128007084131, 0.08138657747102634, 0.0622972771525383, 0.03134950529783964, 0.01870275757807706, 0.036221020322825224, 0.052573904262057373, 0.05999981864754643, 0.008611600895944451, 0.005525629144228462, 0.023035239295235703, 0.02177886215836874, 0.030229305050202777, 0.008345995148244714, 0.044109190082443614, 0.017173809531543936, 0.02300053901438202, 0.019414320288758193, 0.024352445400186946, 0.017075225178684508, 0.032168585274900706, 0.05084084779290216, 0.035679172791008434, 0.02842672249036176, 0.03190489638862865, 0.02821945887990296, 0.05245497403666377, 0.011703766400127538, 0.04246618538828833, 0.040090705534177165, 0.05999865835266454, 0.025103559917105094, 0.01775524449268622, 0.022443217491464953, 0.018285672280139158, 0.015758543242035166, 0.05214111766378794, 0.018326462412785207, 0.023828718146043162, 0.05680602216827018, 0.036843538883009126, 0.03371655774701919, 0.06749625317752361, 0.00870783327679549, 0.03743120109928506, 0.019492348423227668, 0.040506125028644285, 0.09335303785545485, 0.035452155329819234, 0.03376809587436063, 0.026620572532660196, 0.10822885283934218, 0.17969713466508047, 0.17458783382815973, 0.13003127542989595, 0.20089560002088547, 0.11975285410881042, 0.19197441158550127, 0.1226742323487997, 0.10161119579736676, 0.2019296602479049, 0.1748049378927265, 0.1250487385051591, 0.12323774211108685, 0.1353386134973594, 0.12955585308372974, 0.1501597182026931, 0.14464279423866952, 0.11850326401846749, 0.11827261639492852, 0.09193712526134082, 0.18272766204816954, 0.09899469691195659, 0.12642654457262584, 0.13687476249677794, 0.11952356355530874, 0.12953950038978032, 0.09510724086846624, 0.13108643809599535, 0.09348086028226785, 0.12798143470925943, 0.17475133362625325, 0.11910216616732733, 0.0887355866975018, 0.20907734813434736, 0.15363156476191112, 0.1503653550254447, 0.07668062499059097, 0.10203229462993996, 0.10671726002224854, 0.12774651231510298, 0.17534036987594195, 0.26312049105763435, 0.10993354315204279, 0.0782357593998313, 0.150251551132117, 0.1368173991463014, 0.18823724426329136, 0.12198271016989436, 0.08144069742411375, 0.1024618615795459, 0.13217425186719212, 0.10356271000845091, 0.14236556286258356, 0.08702341892889567, 0.15609681819166454, 0.12220696599355765, 0.11415708437561989, 0.15080283369336808, 0.12766854864146027, 0.1297026609203645, 0.10717271308281592, 0.07735906501433679, 0.1765598872942584, 0.06752387633813278, 0.08102816170347588, 0.09557486684726817, 0.10062244813889265, 0.11353841650166682, 0.11016284727624484, 0.08638400145407234, 0.17909730970859528, 0.08466569972889763, 0.19401848475847924, 0.08890628575214318, 0.11567631071167332, 0.1368935986288956, 0.09280428622982331, 0.11274162639996835, 0.14228403009474277, 0.17804039642214775, 0.12536142101245268, 0.10408970780138459, 0.11870911797242505, 0.13904175907373428, 0.19790037002946648, 0.20366419931607588, 0.06470733854387488, 0.12667586547987802, 0.16350226796099118, 0.08344211110046931, 0.09463078036372151, 0.2076893097587994, 0.18742723629942962, 0.1512085704931191, 0.11701306541051183, 0.12454458698630333, 0.16674372473997728, 0.13603145203420094, 0.18334450466292246, 0.10892572187419448, 0.07582330956522908, 0.13241183411862167, 0.17746174175824436, 0.09818844803209816, 0.11223727810595717, 0.09751758724451065, 0.20246391158018792, 0.16408085477139267, 0.12169309785323483, 0.15657243052763598, 0.16788210294076375, 0.2572723605803081, 0.15145242240812096, 0.10747018962034158, 0.07894998536046062, 0.08723165454076869, 0.11592770793608256, 0.1202117744833231, 0.17966463283768722, 0.06110001568283353, 0.1516167228775365, 0.1533562016806432, 0.055421196656035523, 0.12964199988969735, 0.09409211176846709, 0.18096135397042545, 0.09103757103106805, 0.1347187174750226, 0.12952180419649395, 0.11719545562352453, 0.15221284303281987, 0.09642969204911164, 0.2152210348950965, 0.2310243733227253, 0.08500319626182318, 0.12606131631348813, 0.11052191443741322, 0.1390037475419896, 0.1520837585308722, 0.14435593677418573, 0.16058572089033468, 0.08509012338306222, 0.0880774213001132, 0.06978786271065474, 0.13127732356744154, 0.15583166027707712, 0.11880651488900185, 0.12689200602471828, 0.1944129985890218, 0.18559570743569306, 0.10042194104088203, 0.13720208778977394, 0.10869310649910144, 0.1709595170936414, 0.07205307044621025, 0.136991307671581, 0.06196611813668694, 0.10789917981518166, 0.1886196123170001, 0.10501482923116003, 0.07819812106234686, 0.10921746479081255, 0.18153483819748673, 0.16316306830516883, 0.1179524292903287, 0.15156659271035874, 0.08634218334087304, 0.16576545366219111, 0.08743277910564627, 0.08686624307717596, 0.11645072272845677, 0.2169258812708514, 0.1289258740310158, 0.13832929730415344, 0.1634889008211238, 0.08779739668326718], [0.021607347165367434, 0.03259982481332762, 0.0192838380046721, 0.09437214995601348, 0.03746609815529414, 0.0467798971304936, 0.05336253837283168, 0.013342008626620685, 0.01934327427963061, 0.01051980845763215, 0.03207891687218632, 0.15812752422477516, 0.03516128093802503, 0.016040654354063526, 0.020370382915384004, 0.05562609726829188, 0.040356016119143794, 0.0396069338146065, 0.05316753080114722, 0.016871776631368057, 0.08724604626851422, 0.07470948076141731, 0.06585836463740893, 0.030435064009257724, 0.04960747468950493, 0.039606943992631774, 0.036543745148394785, 0.045614065402852635, 0.024636644703735198, 0.023733216038505946, 0.015544309380597301, 0.020392752518611293, 0.039631493389606476, 0.03273543003680451, 0.024342184254367436, 0.033309412987104485, 0.0528837437076228, 0.03103482789759125, 0.055546895268240144, 0.007819952393349792, 0.03749902067439897, 0.012465726451150008, 0.036733724775591066, 0.05414938793650695, 0.04559541247518999, 0.05160267298508968, 0.05675053157444511, 0.0298786754719913, 0.05351668795836823, 0.0689791100365775, 0.03463049352701221, 0.0242972465764199, 0.032161402981728315, 0.038751782915954075, 0.014352584756644709, 0.04780654436243432, 0.03937894944101572, 0.06521613124225821, 0.05538267283035176, 0.018502988386899233, 0.026719211168321114, 0.06931191110717398, 0.01694041384117944, 0.036299092562070916, 0.03814141691795417, 0.011590663942375352, 0.13873297135744775, 0.010884805166694735, 0.025023767591587136, 0.06460693571716547, 0.005750499890252415, 0.053601104500038285, 0.06908534147909709, 0.008642118008408164, 0.0221824395204229, 0.0047184663625167945, 0.023645988665521145, 0.04334343956517322, 0.054139264194028716, 0.07377597942416157, 0.011346633911931088, 0.059470140641289096, 0.03841227113402315, 0.04660615823896868, 0.029964910487511327, 0.07197419075029236, 0.0065146931696550125, 0.03617384856832879, 0.020284253072791865, 0.060292789712548256, 0.059048227566693506, 0.05675301840528846, 0.05659864151052066, 0.01993892285307603, 0.09396749202694211, 0.011411895410024693, 0.009307167991729719, 0.05951797736010381, 0.052130759826728275, 0.025368139380589128, 0.015704938975561942, 0.046353556614901335, 0.02579700743912586, 0.021221058875588433, 0.010199286326366876, 0.029816786292940378, 0.06119885787900005, 0.038321191378469975, 0.02336616930551827, 0.04465320214096989, 0.028366896057767526, 0.04410235384213073, 0.05244647877823029, 0.019386471515255313, 0.0215594697344516, 0.037548926925020557, 0.09882626416427748, 0.02650518934907658, 0.08569652334387813, 0.0569845311609762, 0.01892010252257543, 0.008361898312744285, 0.03344800376466342, 0.07033598329871893, 0.01478389384491103, 0.024173215464023606, 0.05187290973429169, 0.012669178391141551, 0.06449132692068815, 0.03312122129968234, 0.005866781284566969, 0.05451261791001473, 0.022417707967438867, 0.03930368633674724, 0.025420819143099443, 0.05917606356420687, 0.00853424790381853, 0.011821842519566417, 0.00880460170031126, 0.039173421183867116, 0.06541822611221246, 0.03673743636214307, 0.02101695554197899, 0.08189748719866786, 0.04994516121223569, 0.009783011877776256, 0.06519845540502242, 0.05495528397815568, 0.042248253510998826, 0.0469131885495569, 0.06177944636770657, 0.0438072216430945, 0.01570351914103542, 0.06395717058330774, 0.019197506297911917, 0.011490875189857823, 0.02346133893089635, 0.047781526776296754, 0.03372668827484761, 0.006674290119138147, 0.04959826696930187, 0.02681084392991449, 0.04668084119579621, 0.061073790304362774, 0.04839934648147651, 0.03132200766620891, 0.02056218440910535, 0.023160805593111684, 0.03756295224385602, 0.015578926540911198, 0.022074550756120255, 0.030557047642235245, 0.06060904131403991, 0.03999960542257343, 0.03328899247571826, 0.01853622472845018, 0.010803676127190036, 0.042146537719028335, 0.038922081634934456, 0.009256589143270893, 0.02182005432301334, 0.006972576233757926, 0.06062100388641868, 0.01265480023409639, 0.03983230582837548, 0.026737770797418695, 0.03408040179471884, 0.16826269323272364, 0.05182213835152132, 0.04982887048806463, 0.10009064631802694, 0.01686938649176487, 0.061743707928274355, 0.0498023261981351, 0.050492050259241035, 0.0710088186232107, 0.03882169916427561, 0.02297334502717214, 0.07235256223274128, 0.02613673295958766, 0.015201895165124109, 0.03388723644561001, 0.0819123335448759, 0.06500481508140053, 0.027437737344631126, 0.028008407347702553, 0.05061061746839966, 0.024960741866379976, 0.03573258028232625, 0.07530925143510103, 0.0194394667965493, 0.02264748028080378, 0.020455825741269758, 0.037471248236085684, 0.03673517344785588, 0.013489656998509807, 0.0532394351570734, 0.06556196018521275, 0.0796043441763946, 0.03328551837642278, 0.08032586438847439, 0.026661311775179844, 0.038730364958090444, 0.024443986559552804, 0.021672734192439487, 0.029872436342494826, 0.036621159208672385, 0.06118131774876799, 0.01768882948506091, 0.01055546208018703, 0.024855017628786818, 0.01305004264161523, 0.03366521978750825, 0.01625441663366343, 0.023942472845582024, 0.0867421186662146, 0.022723886716578687, 0.09283011805798326, 0.02024376149555402, 0.054739740544131825, 0.04689455937061991, 0.04320981566395078, 0.09499226310955626, 0.08836687755371843, 0.07814148374434028, 0.0351752553667341, 0.013850557052397301, 0.04645741318485566, 0.009960516638654684, 0.06324982496776752, 0.04598418929214988, 0.02282963809557259, 0.020602206100842783, 0.025122055085375905, 0.04391582117282918, 0.04170851283041494, 0.032135567760893276, 0.03770171944051981, 0.09509516973048449, 0.0068510612140276605, 0.034010980876960924, 0.02314492448100022, 0.05048352446673172, 0.03916412525411163, 0.06452799495309591, 0.029341173956968954, 0.03934690562476005, 0.09302939022225992, 0.054845452907362154, 0.042888295238039324, 0.021382188890129328, 0.025632457608090978, 0.021119249785052877, 0.12499294935592584, 0.05603883315676025, 0.021553408720397522, 0.031386420995529206, 0.08117655052670411, 0.044528986127781015, 0.0297088381568236, 0.03631110602457609, 0.0292835188364344, 0.0636630460087742, 0.019851637804614644, 0.014435978406774146, 0.030329646808760505, 0.06197297812572547, 0.06683696819735424, 0.06805233298135654, 0.07771375562463488, 0.04249916558286973, 0.03396933918286647, 0.062376007570752075, 0.012654055541913425, 0.048333623579570224, 0.037864676410598416, 0.03508984477126172, 0.06340468022972345, 0.05990068468132189, 0.09742251091769763, 0.02024461475333997, 0.1051749431395105, 0.03478809007044349, 0.026458999774019634, 0.06931986353759255, 0.06757745346320526, 0.037362092307635715, 0.03755885049966829, 0.015310311490403754, 0.03617317681866033, 0.011746732933845903, 0.020385868780847107, 0.019165789874802743, 0.03940048614250762, 0.008225005569069513, 0.023593622725456953, 0.01398772036191076, 0.030636001977005174, 0.0208095613135291, 0.043555016962013075, 0.05202314078009554, 0.021920672584591166, 0.047143819209720404, 0.017725039506331086, 0.023992794698902538, 0.06294386674250875, 0.0561587913627071, 0.09672625256436211, 0.02807024902930217, 0.01677913454893444, 0.023934532289526293, 0.029951692625348057, 0.046469959297350476, 0.013784226013480552, 0.04338425683922001, 0.028938168260668005, 0.040919600520282984, 0.05530174056600247, 0.021930048242211342, 0.01935739628970623, 0.0038037082828980473, 0.014264449843072464, 0.047848912088998725, 0.015505593868770769, 0.03255953001124518, 0.05159782145970634, 0.040557700475411754, 0.04168012631790979, 0.07235013307737452, 0.02265137167913573, 0.04185593474124159, 0.006045431921458138, 0.1342751591333321, 0.28140690124460627, 0.11790581393454756, 0.18660392904920237, 0.09489757354770388, 0.17077228214059556, 0.13215926981398038, 0.10912213740604264, 0.16636420653334685, 0.11083720930452858, 0.14470485305147512, 0.301805780934436, 0.1581343909991639, 0.14270523749291897, 0.14982202489461216, 0.099876554948943, 0.1409124122666461, 0.17081589837159428, 0.12214184020246778, 0.13081427770001547, 0.11391492879816464, 0.2686764986387321, 0.10263707967741148, 0.05093066547332065, 0.13513924633818014, 0.09607132377901248, 0.11934596379952771, 0.1602088896823781, 0.08826177247932979, 0.1303589264197009, 0.16282929692949566, 0.11968395566301686, 0.09505502081343106, 0.2374636163668973, 0.10587223286607436, 0.10914979449340276, 0.1592759990266391, 0.10267749322312218, 0.11644794073488031, 0.10814364241170031, 0.11258332418011767, 0.052619084516274076, 0.16500043257006577, 0.1510964222252369, 0.20092321639614447, 0.0921158106731517, 0.12503238581120968, 0.1836203427187034, 0.13051462306507997, 0.15651983049299034, 0.0646190679232989, 0.1614884031670434, 0.06789543532899447, 0.18544690470610345, 0.09842024916516882, 0.15340711894844258, 0.24600178535495484, 0.10986157094261476, 0.18037294197295392, 0.1427048168012074, 0.11640503018030099, 0.13855685080800736, 0.09206059149333409, 0.12772375425057753, 0.16764986754528113, 0.13063124966408524, 0.21740160217242582, 0.12381540611386299, 0.12041335366666317, 0.10925699624099902, 0.12423413007387094, 0.20501707600695745, 0.130561889814479, 0.1604805886745453, 0.1553262738244874, 0.06710286571511201, 0.06640765230570521, 0.08573591230171067, 0.13209877163171768, 0.13700067145483835, 0.13007310032844543, 0.1934968541775431, 0.13318768462964467, 0.10760884825140238, 0.15743853976683958, 0.131590657468353, 0.13236673868128232, 0.1541204492428473, 0.13279846337224754, 0.13507884315082005, 0.13089526763984136, 0.22618773499769823, 0.1542225144803524, 0.10400944389402866, 0.15330403590840952, 0.14933334397418158, 0.06928413188351051, 0.20033880775528295, 0.1375907662191561, 0.09434350899287633, 0.13205442258289882, 0.11619688277798039, 0.08618349435606174, 0.09454786338444267, 0.18683602873768124, 0.12350975322936263, 0.20459244879228727, 0.11240175499447755, 0.1041267490280526, 0.15937677504760878, 0.15953853779605456, 0.16896374204329082, 0.1454048976302147, 0.19744614511728287, 0.1271542598094259, 0.1948933470994234, 0.16047860735229083, 0.09114479992006506, 0.24629787089569227, 0.07897914201021194, 0.11753774939903192, 0.18490828360830033, 0.15156227722764015, 0.2648537409092699, 0.1523446281041418, 0.16028218503509248, 0.14626247089888367, 0.08806112288896527, 0.13119010467614445, 0.1492988879659346, 0.08526287161345993, 0.08778347314468452, 0.11098820370222841, 0.09606755112430879, 0.08441830586109843, 0.0953794623325978, 0.05206686557669725, 0.07602095324546099, 0.12018955924681254, 0.10048693112496819, 0.15472457611135074, 0.10518617289406912, 0.13227300585380622, 0.125698218654309, 0.1702563919659172, 0.11710010788270406, 0.17740925028920174, 0.15008692496589252, 0.13308902563793318, 0.15324123070708343, 0.19108794629573822, 0.28172977534787996, 0.10391310549208096, 0.166829912258046, 0.09183782166136162, 0.07745167825903211, 0.1332157352673156, 0.08561539091169834, 0.07903698033520154, 0.06608937866985798, 0.1885305613811527, 0.13838818057307176, 0.11745219970388071, 0.121306251468403, 0.10473648738116026, 0.08131828970674958, 0.1745395628469331, 0.05658650930438723, 0.1303841272102935, 0.14716037628906115, 0.13432020028787, 0.15735797051872524, 0.15438152237662248, 0.08090597790266786, 0.09293043267514024, 0.1281677604253803], [0.014349611076925482, 0.05025783693417907, 0.016822126527716006, 0.026724044033991437, 0.013074865148934935, 0.025805243157914708, 0.02905356671128954, 0.055302130723638196, 0.016366714179249744, 0.06469524704984256, 0.06057573202997446, 0.027868406913642372, 0.03312149949903999, 0.03800246651683535, 0.06408755787249122, 0.04783681380961623, 0.023352269515661255, 0.021865076817838208, 0.05230275827593037, 0.04732446898041027, 0.03369599135060396, 0.01899276514138494, 0.03641222470573016, 0.028139868418553045, 0.07923808454402856, 0.017578643879720142, 0.07334274160010473, 0.0821076702060444, 0.07719001479979072, 0.010129613502483283, 0.03560176890875612, 0.031220702387924706, 0.06029557170612471, 0.024196394220260636, 0.033694749631519826, 0.06418952811509371, 0.012541210927468325, 0.012654612788797488, 0.019444891684023396, 0.0331609563103744, 0.031107007060199976, 0.02763921983673104, 0.018948543317882077, 0.0535636425816587, 0.03859118385506528, 0.012020499761482435, 0.020530076132022908, 0.040226032558296404, 0.0031733855097887237, 0.0695814455726317, 0.08066945416586739, 0.040649933740496635, 0.011175834773374456, 0.036680534415479214, 0.07688354767326798, 0.0572690341089453, 0.0346213095555348, 0.018504247069358826, 0.03958081021638853, 0.059928721748292446, 0.061616591177880764, 0.052621645985969474, 0.03149838266628129, 0.021373756396185075, 0.024415450769343545, 0.014364981591435415, 0.07265740766056947, 0.019731286048356975, 0.06961450379874025, 0.027061143623931066, 0.041530424529420476, 0.0859487144542592, 0.022106484310435395, 0.037299514415540864, 0.044033119521502934, 0.03330656314002616, 0.021592168337000266, 0.05032562936789223, 0.02963134945769395, 0.02188700876597847, 0.07757808254765612, 0.024840917671099305, 0.001262751019177293, 0.008162863635724145, 0.04248641590986933, 0.02601573320238718, 0.07476498492594276, 0.01789207786454686, 0.025020824445943748, 0.05098265821912459, 0.013437692242275392, 0.03438846008586032, 0.07846821871187006, 0.034878494683653116, 0.056703251254345687, 0.025763611641845534, 0.02973441214167646, 0.030479745540235723, 0.004835682862903923, 0.04600884386205247, 0.019239751888172965, 0.022887729174856628, 0.04336355812847614, 0.019411733373999596, 0.05158125502722604, 0.02810235900272216, 0.03467551093282444, 0.03145383005695684, 0.07176330885184662, 0.014177283538239343, 0.03727576568988817, 0.04916192145485963, 0.06487904183034386, 0.09153427223541907, 0.011631623708776065, 0.010371368744277527, 0.042920566363526244, 0.021652861598080823, 0.08221767430326768, 0.0454507725579398, 0.01681628603754299, 0.01737262198834547, 0.06190802875374045, 0.03848925432456391, 0.01757391109796507, 0.04146995009588344, 0.01816415005097432, 0.022004944937569753, 0.05670572790716376, 0.024974190430449586, 0.019150229370487586, 0.04564471482964499, 0.04598663541089211, 0.020497029780277183, 0.036093940891857655, 0.04298646568453737, 0.03183059001873646, 0.032223281982753954, 0.06000950134226254, 0.043694008075233014, 0.07433076322610889, 0.008783836832403072, 0.007608331739902496, 0.030852844805589745, 0.05035960700895105, 0.010240119715620364, 0.0041821641581399095, 0.016520095323877673, 0.04083922465464898, 0.019012021965214183, 0.037607308078025065, 0.03411617076822689, 0.027884072590885416, 0.04207844672990697, 0.051753518105085404, 0.03503113113609808, 0.02530055390005665, 0.06998108234256506, 0.015258330618962646, 0.03157068396519337, 0.04225534080926861, 0.026197119183572273, 0.03625340001391513, 0.06545877536492688, 0.062433479486831596, 0.04950347901987178, 0.021956132824665735, 0.023669949433367168, 0.06894525113914694, 0.05280332712988768, 0.07815449126064777, 0.06802842819264956, 0.030012289195188453, 0.01598454120435885, 0.03172629240102001, 0.022590289956757, 0.04328007796513183, 0.025394666707143188, 0.03644858400470444, 0.03371391485312155, 0.0038568778628749506, 0.03845761423664434, 0.003019943933135697, 0.0527415702651654, 0.01231905771419406, 0.09274070749857596, 0.10775126596646649, 0.011464296973177364, 0.012194135176417018, 0.02598546545154282, 0.010658629088928657, 0.00874823918898723, 0.04976838587650231, 0.01907478136542652, 0.04437409354639905, 0.025165625515260866, 0.04805875922154103, 0.04681572038680315, 0.06048924595649753, 0.058215963654220104, 0.024823335132428577, 0.028882884620023624, 0.06416501943022013, 0.03574263956397772, 0.024328106349068027, 0.11945885845593043, 0.056008394075823684, 0.0735843407788447, 0.1356755875583206, 0.03943023651040026, 0.028869161249271462, 0.03212658056457128, 0.032692417701972384, 0.04951644243140306, 0.02702220080287329, 0.03177728770034654, 0.05424020306340285, 0.020800898117678504, 0.017250265161107694, 0.02415422666152673, 0.038636438748134036, 0.034716429987124035, 0.030540898508791412, 0.02086307397777481, 0.010303735766293747, 0.02127105333576245, 0.04249483992212585, 0.05771076719143561, 0.03277770955381649, 0.06245934524174247, 0.045261349329458814, 0.045769470278173685, 0.029838529947612966, 0.03564266760700515, 0.04197031199666006, 0.04378580368523087, 0.0866846874622362, 0.030914934152471166, 0.08193849106984478, 0.03325633119259562, 0.03300891357607075, 0.04073817043432167, 0.054533822129347494, 0.0322616667087589, 0.0359421051107347, 0.02140169677191547, 0.022216077893972397, 0.009288497252522834, 0.06431308934198958, 0.02342543425038457, 0.06010582617350987, 0.03012254774304373, 0.10514862276613712, 0.045844336439456256, 0.08165347922061171, 0.024784394007708346, 0.03552224121189543, 0.052950881355042966, 0.009463482103975756, 0.02923539713291185, 0.038740709224449735, 0.05600840764652405, 0.05472880255963121, 0.04965570156595536, 0.05126120023695486, 0.02409373356827668, 0.08265798246221882, 0.033177614345082214, 0.02653137910445886, 0.043057844175824096, 0.008208816571693336, 0.02645967830903828, 0.04043340303802064, 0.10193042616759028, 0.014922104642859526, 0.038729598213519366, 0.009534926752426794, 0.023016219958662987, 0.03958872872005616, 0.059843450252498896, 0.043564204326165576, 0.06678387283214501, 0.026003850357873098, 0.012989601286660348, 0.0701389435146536, 0.007829873423491205, 0.05290435081613915, 0.07077911416334765, 0.023193953725110208, 0.06417840014078788, 0.02884000799219523, 0.06285391335508653, 0.01994889901418771, 0.017838699210967337, 0.035616693286491294, 0.018232799135148525, 0.03678444526823504, 0.015012415957504084, 0.032166281648512395, 0.06508026817547423, 0.09503382337944848, 0.027402112559814538, 0.06721071207097598, 0.022495786992034743, 0.03948111645877361, 0.08027582243084908, 0.06535198073834181, 0.03107201840196337, 0.059462507122329304, 0.03995753964409232, 0.029966576290982108, 0.06541651620396546, 0.06220643488424165, 0.04453894362917968, 0.020076651891161288, 0.018543642812541554, 0.05453239381313324, 0.041445940134248564, 0.02918177590306316, 0.015871833145086254, 0.02338508516550064, 0.10683809353836946, 0.041870004164853265, 0.09256928241146462, 0.03914843073913029, 0.0212242378121508, 0.05039258041818227, 0.012210224938046719, 0.014209468998680157, 0.04313636424818209, 0.06038390339485236, 0.06559563587818827, 0.02400316101764994, 0.03629236828003611, 0.058536890361990244, 0.005923581026893641, 0.04364833588312779, 0.02952267528910722, 0.03817481780424714, 0.020658819670123712, 0.07827202709657805, 0.04257760762370058, 0.017749351416049258, 0.011736127431504428, 0.029888931528798172, 0.006791565991339407, 0.03535043953784874, 0.032153901777097156, 0.02702853492727237, 0.03441779315471649, 0.050360875869435925, 0.007911697961390018, 0.19275558181107044, 0.1436999969716583, 0.08765060920268297, 0.10647923672305686, 0.08933511309857879, 0.09794078275029149, 0.09035469338830028, 0.1359329694615943, 0.09852314221539668, 0.17935216746159963, 0.15961830637284688, 0.09500719087996654, 0.0838133172531213, 0.11093919311783143, 0.12003022565373353, 0.1654760313353368, 0.16770131407039507, 0.08085362892597914, 0.1737534393157278, 0.12238064381693091, 0.14449017814227513, 0.08782660083046981, 0.1385944823601416, 0.0951245299407414, 0.10993320388453347, 0.1278173378003495, 0.149356427735516, 0.13556741550564766, 0.15141764070306504, 0.19639900273510388, 0.1265172782753195, 0.1545267967241151, 0.20930606871843338, 0.11527513366724763, 0.1668348384222814, 0.150821751249688, 0.06063530740461179, 0.08726673480123281, 0.12297475550855909, 0.15149845422378608, 0.15082914728139127, 0.17566704377532005, 0.14315537762429031, 0.0916506749178682, 0.1532929622169052, 0.1269223229693515, 0.10685209171580416, 0.11373466918511049, 0.07221424965453999, 0.2297327954854284, 0.1582842386726822, 0.17192394605704717, 0.1304069666990212, 0.13648802467754909, 0.21079476097864763, 0.08463447354733944, 0.15052467504782335, 0.15002728173775332, 0.12823294049927167, 0.16261102578469686, 0.17991141602396965, 0.09586155467799731, 0.1142380064619439, 0.10807496109711272, 0.10744671909404652, 0.1421303012009178, 0.2059037448572261, 0.07399074254291398, 0.1315854870315109, 0.07336490933916398, 0.1058871199243835, 0.1922381581472499, 0.13646272889205388, 0.09192522375711373, 0.1764256866382701, 0.11483047609882695, 0.17777366430631705, 0.11677519817437444, 0.18678835486727102, 0.18797471906457627, 0.1916967143437692, 0.1549090833536216, 0.09675192154411759, 0.052991138837699375, 0.07763571052678994, 0.09239681916577475, 0.15628211253455707, 0.09521521614598376, 0.1267021247850997, 0.15775958182556288, 0.1350328249058553, 0.17511361704341002, 0.08378783147782087, 0.12218226731887885, 0.11700432587947164, 0.19252090368952068, 0.08861328076039042, 0.16052423204694474, 0.08641862031072378, 0.1352225568677698, 0.12887201192123549, 0.10916818279240813, 0.18088740722409316, 0.17561137676239014, 0.20213772622602327, 0.1402126255312136, 0.10742739441671542, 0.1753581203520298, 0.1777951331543071, 0.0984590749389359, 0.13157506473362446, 0.1992723678371736, 0.15499683150223323, 0.2040741430329425, 0.12380159114088331, 0.13286113286656992, 0.10741571682904448, 0.11463040326322828, 0.19710733901177133, 0.12752970680594444, 0.10006053971924952, 0.09717787190207414, 0.2302701680787972, 0.10631001687475614, 0.15764052607119083, 0.10270842084927218, 0.13958256505429745, 0.15068727917969227, 0.14119633845984936, 0.08460817353001662, 0.13930899330547877, 0.15977597076978, 0.10778437169002635, 0.11744860346828188, 0.0942124906661255, 0.13680030006383145, 0.09336829810802426, 0.08100566826760769, 0.07770765559481722, 0.09864082732903105, 0.15590893184500082, 0.11806733241038662, 0.08666630594858102, 0.09733986535242625, 0.1607736208076988, 0.1721310620861394, 0.09211120342037507, 0.12346169937934194, 0.11424739738660199, 0.06306034406380993, 0.10951802187732287, 0.07194016221910715, 0.1084777055574315, 0.0976550177271877, 0.22054414211639337, 0.15078945298280033, 0.06707027567816631, 0.21409018843301705, 0.07251836904989821, 0.06043957040778228, 0.12640283655907425, 0.12013282014855317, 0.1746466899556773, 0.1453603043087891, 0.2594217152467796, 0.18341971348438943, 0.16244858450123242, 0.1181071081331798, 0.17120517391179288, 0.22983959689736366, 0.2138044573366642, 0.13976373390427657, 0.0910794637831194, 0.08669980522245169, 0.10320772084274463, 0.10431944618799857], [0.021338341957224265, 0.028981021139770746, 0.025918170044730817, 0.06083033193967172, 0.004933352465741336, 0.022237159977001802, 0.035342721202011616, 0.03154308455330985, 0.029330863617360592, 0.024091365481061593, 0.04421192028426698, 0.043401685011173995, 0.04501841343673212, 0.04407067982746022, 0.04048663071755852, 0.033872118685394526, 0.04167313401454261, 0.06717177094625575, 0.04515338083729148, 0.0446413481341941, 0.03859448153525591, 0.01137380754309041, 0.05398934527433344, 0.02788850512089474, 0.019941927066871097, 0.044951855936752896, 0.049290958459356, 0.027959272930664674, 0.04783242708072066, 0.02645368005947343, 0.057741185916321616, 0.09246153105050325, 0.039182320170636685, 0.013439131584683699, 0.0055234866699070805, 0.020365626384903277, 0.044130309484899044, 0.0042143665819561905, 0.02018675607229982, 0.03086615087730544, 0.055961622656988244, 0.029727606435439417, 0.028446734184399247, 0.08867794514766761, 0.03826631146616169, 0.039124627730676105, 0.07338453935725348, 0.027358681229608398, 0.027509863920775906, 0.06074472117636885, 0.03144889710737126, 0.061335379124752114, 0.043141765386930535, 0.0053164232272787815, 0.0739401781133243, 0.040970154771847386, 0.014683365489223173, 0.009056287302103425, 0.024146525289065073, 0.011911925676810955, 0.03525274067318865, 0.040470169458006106, 0.046495173658643446, 0.007626221315669162, 0.03325606995661344, 0.06029135800365891, 0.04987455625087023, 0.030566937290132046, 0.038834248669445515, 0.04120901945446219, 0.053907832862543206, 0.022962848090433648, 0.047604496989931376, 0.05109654014397945, 0.051495433918067386, 0.04987338577796306, 0.040962351619132926, 0.00522453771139096, 0.02000712919315057, 0.01812347866195653, 0.0645889952512724, 0.0303885877531554, 0.04608522315642663, 0.05203891332660403, 0.05954765648181949, 0.019030223667089428, 0.059866269385176044, 0.04376263510701912, 0.015864070704472915, 0.012081094634985285, 0.017640589037910104, 0.01912691829992192, 0.039320327408079586, 0.02677972801029682, 0.0809536517730781, 0.08468779961445502, 0.02448335346499724, 0.043369420671037266, 0.016166498851297156, 0.05105973640456796, 0.026235885585525205, 0.033020960965326855, 0.024233820515551736, 0.052996339808617315, 0.009481643941918654, 0.01847332453222147, 0.08835611598832266, 0.03097480468984161, 0.03961037059447595, 0.06362942459860019, 0.03278077653210078, 0.037124622014484236, 0.019723041847880398, 0.07996519588466201, 0.021094069350510836, 0.055824840175254006, 0.025186556624248624, 0.023121143524934138, 0.033082130897258005, 0.06552771452282156, 0.038835951792342324, 0.04473082993977836, 0.06066000607929059, 0.021237640575106655, 0.026501910328598957, 0.0255198411510459, 0.040669523046485016, 0.011022414612982954, 0.008399202471732028, 0.07501735924077885, 0.07139810094875948, 0.03967740646164332, 0.04647414246574044, 0.00591555014086355, 0.026915375642212372, 0.0476415857140507, 0.07826078377131905, 0.02609230248656656, 0.02369040556784187, 0.032157379269067726, 0.0357542459054717, 0.054255062980311256, 0.008826817784990584, 0.008024998890635158, 0.028686255349644592, 0.016576386589024748, 0.07704239950648376, 0.05296671836237822, 0.07553943765482732, 0.05556950405506151, 0.056467755498098474, 0.06573264566915375, 0.02229740540497005, 0.045748048927634954, 0.017859749063583355, 0.03207776336265462, 0.02763899931284998, 0.03606340003066829, 0.06614242653761591, 0.03831133565732411, 0.05218831316701003, 0.0495630068970578, 0.04708929552829691, 0.05535801147509899, 0.025609085469373634, 0.029273982026747296, 0.03020105085202626, 0.04436663305386901, 0.02906521376488464, 0.02241341453710837, 0.02165082429668733, 0.010948271091495241, 0.018431095905335884, 0.01874460792168975, 0.029536955058574677, 0.03320698134068932, 0.06857054374579873, 0.051587958953210285, 0.026761901199019382, 0.04914671887776681, 0.0197727665903845, 0.04304280783981085, 0.05138455451067005, 0.009860433571572815, 0.01285528443155012, 0.027055557584390044, 0.02374610141851008, 0.02924842161259481, 0.086945238124047, 0.060442298118557246, 0.02589883349303688, 0.03701821415285979, 0.05833474120923451, 0.08144856164497988, 0.014679655599008714, 0.02714821493386158, 0.05997179515127625, 0.02667537271710379, 0.04408048805115478, 0.03364942009959902, 0.029494624651436294, 0.013982515998317726, 0.07335853789533887, 0.021180022773998122, 0.03279262375352638, 0.017484415721680437, 0.04710151255130768, 0.04487207718193531, 0.0525808185338974, 0.02164387100908373, 0.0208301192282566, 0.03755280814532723, 0.03346077040103929, 0.03029201864930136, 0.03948723005929163, 0.005375179694965482, 0.026224581192114522, 0.015729055806462253, 0.03569782571867108, 0.0962715662483658, 0.030623455864510367, 0.03543247102892824, 0.025789701313312565, 0.04546100486602102, 0.011228135404443102, 0.023988740452166115, 0.04220853207100715, 0.04746249318122864, 0.03712086293048092, 0.04686355032026768, 0.07034436320619923, 0.04274279358131545, 0.04023716053260224, 0.03716653512258615, 0.014355443085410764, 0.07795197569898196, 0.0872424907450165, 0.04398325737565756, 0.03257471901763763, 0.033266237803867886, 0.023643162567168474, 0.05472893148128476, 0.05279260966926813, 0.06873359571077994, 0.06499608233571053, 0.0348464203333216, 0.03456375282257795, 0.017987973522394896, 0.010272183039757823, 0.03890069421114666, 0.050058819220534394, 0.06689750709171806, 0.015594140992366841, 0.034021026587912014, 0.021382831802059497, 0.01888122925135706, 0.03235251236973064, 0.015481122503323215, 0.05256738014785307, 0.0860951558819839, 0.041530909681958814, 0.024387839483097196, 0.012428283192483442, 0.024816157928268825, 0.07291760548417058, 0.02426670741156808, 0.022391781144376312, 0.0636437281167933, 0.014556896739772387, 0.013163492848564471, 0.06701272233788456, 0.035237076692283154, 0.015461282139377934, 0.03097684708024774, 0.013411932508461177, 0.059669188889009614, 0.0127627822969641, 0.0480428611460541, 0.041861264633813074, 0.0413850246529494, 0.02799328280213688, 0.025528380514255593, 0.036799987112837176, 0.03198413570810642, 0.011874768251020993, 0.08128607964941434, 0.010757217682631952, 0.029671769788754836, 0.03620292040120278, 0.03448585021708693, 0.09146447812340089, 0.045480546674558094, 0.019056011390473162, 0.06918304373643228, 0.02047227512645934, 0.020842828189155886, 0.049944906761603694, 0.04887264162035925, 0.04109241999685764, 0.026256781071424484, 0.0657508032662528, 0.01291799548614238, 0.053388624651623626, 0.02189800951496831, 0.0024674434015261276, 0.05389617902359792, 0.025526305893436074, 0.038677116922502, 0.011645245299275433, 0.009734407566221697, 0.015896083986652747, 0.008739527647516556, 0.035190250990646224, 0.053511449668024264, 0.038996252297822914, 0.018680885001750927, 0.04883600751470242, 0.01713176241277584, 0.04787645382540567, 0.06339822057634592, 0.07216811605862208, 0.044812915713659356, 0.04330531946782555, 0.06990957832229988, 0.01041567708099527, 0.06349971584443535, 0.03898723456742508, 0.020176922403542057, 0.058629082914974005, 0.054764788664345226, 0.03714071686512657, 0.016221707853089486, 0.02929699793457985, 0.024242139354880368, 0.048219677193888595, 0.04985912297187107, 0.004605205297204, 0.031623782723077705, 0.05801819105233465, 0.032572557883603234, 0.00874534947797656, 0.09698089318616049, 0.05535453398312841, 0.05049765156581998, 0.03364900619323764, 0.006899977227606411, 0.05145288298704794, 0.015967901829364042, 0.04395674361980387, 0.02326995812888656, 0.03408121603674122, 0.03337567871702569, 0.1534274478576013, 0.10800562838890723, 0.08939219824969769, 0.12114668717341763, 0.13670236031923974, 0.08152268481041704, 0.15014213057500975, 0.10444509730275188, 0.10958394833973475, 0.22317934142691748, 0.10295756533741951, 0.14412427134811878, 0.13545126388115541, 0.12023579462298326, 0.09683352895081043, 0.1783522782581193, 0.1279146804341248, 0.23783678348575318, 0.1974227220884391, 0.18001231418124267, 0.18247717406068528, 0.13198361066835268, 0.14227078509117874, 0.06602132839283772, 0.10331931949726172, 0.08280078694224358, 0.24348577750580652, 0.15403939144951956, 0.12948656108762535, 0.101638384695564, 0.12215436595891203, 0.1318107877991029, 0.2177886249763625, 0.12208001209156853, 0.06988129698272262, 0.15249028243124485, 0.17919040471315384, 0.07770825949098382, 0.07058176225317375, 0.12988954303520067, 0.1920971449996744, 0.10799802879669837, 0.12514359770076616, 0.23296989606959478, 0.1469556079911334, 0.1381557687584843, 0.2132366049502577, 0.12909007950552873, 0.05983072772089924, 0.11183428937303168, 0.2138714694551059, 0.19969656078943185, 0.124433198677642, 0.11810134058552128, 0.18809108782027448, 0.12308224902621337, 0.1373266532484974, 0.1656507405319384, 0.05342724686488509, 0.17603330340768608, 0.2089757171592542, 0.10624477573271308, 0.17472116595932416, 0.08844017969178301, 0.06189327061708484, 0.15169096817927702, 0.17627047853810446, 0.18477666138538293, 0.19724437594413757, 0.15535500299717697, 0.10711831493037087, 0.09512077085673809, 0.10135914717933961, 0.16295752647731984, 0.1358424121780055, 0.114608052319714, 0.10829952226153441, 0.08770286318446908, 0.11042892121310745, 0.08681299843426261, 0.12042704650333949, 0.10988970300448792, 0.10972682745861155, 0.20433081925979682, 0.27405934408307076, 0.12608745348240646, 0.21743236695017132, 0.0791219397048865, 0.09968197824699537, 0.11427559730197702, 0.07153627781995706, 0.14710405788251332, 0.12711782247892447, 0.09175494539418391, 0.15541148425212928, 0.11638854177934782, 0.11230788645999772, 0.0706734594755939, 0.08769705492470946, 0.16203148902526923, 0.08834538834967784, 0.15120680630207062, 0.1680839942502124, 0.1521241177937814, 0.07532120722212962, 0.122531210737569, 0.1645780580916575, 0.088316285982728, 0.1664004267326423, 0.31923932688576834, 0.13343764335981437, 0.10443297866731882, 0.14984514936804771, 0.20154489018023014, 0.13575357837336405, 0.09020931047520467, 0.10112942914877619, 0.14695905494902814, 0.07862736910049405, 0.11467445375663893, 0.17709708346852235, 0.13665312581828662, 0.17899362955774578, 0.09721286395298583, 0.1686141879430839, 0.1291943567671946, 0.1587694590645177, 0.1289956545723336, 0.11996736616960593, 0.1449679210782051, 0.14431198127567768, 0.13008269481360912, 0.09770854735480887, 0.050094252319208214, 0.1614747510424682, 0.06944415079695837, 0.18740567245653697, 0.14184657856822014, 0.14932908277426446, 0.06794264101024185, 0.14772881221558365, 0.09499956414635692, 0.07484720301415239, 0.18635213827448233, 0.12939513527921268, 0.06615377164312772, 0.1386502715093749, 0.13888204550104483, 0.1758813387049096, 0.22561486145215376, 0.10957058798521757, 0.15811860827463015, 0.13892285259706633, 0.19711687921413354, 0.17166349717548915, 0.09535422761525426, 0.0748236510636551, 0.12272151266889912, 0.16018021479249, 0.17958141730300017, 0.10586401580699853, 0.1501980825726475, 0.10823448467999697, 0.1836179407047374, 0.10474306917084114, 0.12683316346790108, 0.1713192899312292, 0.15487221176070826, 0.132859097261514, 0.09725430887192488, 0.14304108518574918, 0.15298713291329996, 0.13218311353453568, 0.08041298149951867, 0.08031116053462029, 0.12294692200209413], [0.017111172267634953, 0.10377384975020375, 0.037897955160588026, 0.027277379163673947, 0.06843734732163803, 0.021121461809213673, 0.01450145703607372, 0.058253344148397446, 0.046123960720641274, 0.021672177793724195, 0.021464763209223747, 0.04208292845370514, 0.03924528143501707, 0.06145332208169358, 0.04525627049484423, 0.04457529275012868, 0.008125366942424859, 0.04187526281124779, 0.027674425626173615, 0.013202125239851219, 0.03471043173755918, 0.03698464024013706, 0.04523313584338341, 0.005127498722036502, 0.0323417881237609, 0.018884538805910518, 0.01660013192200235, 0.01034532317758671, 0.016589621414563487, 0.03301266926739897, 0.018658820739282028, 0.03579498514799135, 0.03406969790479966, 0.03312206268310547, 0.09016696989004101, 0.056453984629895, 0.073487893811294, 0.016126215923577547, 0.01249567189786051, 0.03782683790528348, 0.06189264636486769, 0.023024060430803468, 0.03098320834604757, 0.027642419129343967, 0.028717162619744028, 0.04819307183580739, 0.026249249332717488, 0.01969469095846372, 0.005460415143586163, 0.027921726195407764, 0.026496875598760586, 0.04191700289291995, 0.03546158018122826, 0.0428481938184372, 0.027188565715083053, 0.020902339102966443, 0.06699661391654185, 0.055896540970674584, 0.017911373704139675, 0.03006594774446317, 0.006518221127667597, 0.04445838795176574, 0.042251602081315856, 0.04055316446881209, 0.009349935205786355, 0.035516717936843634, 0.0002965682547905349, 0.10995505271213395, 0.027195982102836882, 0.04115400044247508, 0.03171417376558695, 0.039103657605924776, 0.03301088472029992, 0.07121592786695276, 0.03647749977452414, 0.12363098029579435, 0.011782040503541273, 0.017497048347390125, 0.03243832330086401, 0.010140773707202502, 0.045259384970579825, 0.0570220337914569, 0.02843105324011828, 0.03841728211513587, 0.014305708164881383, 0.012502080661111643, 0.07549966871738434, 0.005069378805014172, 0.0341952879514013, 0.024123570449384193, 0.029194169345178773, 0.01587069490259247, 0.03134809733767595, 0.08183203571076904, 0.02949952706694603, 0.049623552576771805, 0.0733142431293215, 0.027174913590507846, 0.04797993380842464, 0.025378532840737274, 0.04349215408521039, 0.051191022752651145, 0.029042082506098917, 0.01907306127915425, 0.06994396647704498, 0.025571428472176194, 0.03560787233124886, 0.008155806023361427, 0.040931790401893, 0.060496662344251356, 0.04863313232947673, 0.01788510591723025, 0.03142461233905383, 0.021205669701365486, 0.04031320395214217, 0.06107357317315681, 0.04716590213190232, 0.1003825520830495, 0.03716821788943239, 0.013789785759789603, 0.026969548181763718, 0.02656740083226136, 0.036415820941329, 0.05090700834989548, 0.046260675348873646, 0.023410883066909652, 0.02533887416523482, 0.04532307905278035, 0.022727684816345572, 0.014219301819269146, 0.03852594949837242, 0.012882132365900491, 0.01918998304089265, 0.0714667211951954, 0.04891892788665635, 0.049431703585599146, 0.011774179675350232, 0.03033062389918736, 0.0295534604229033, 0.07354669565601007, 0.030978567166520015, 0.011229762192150312, 0.040629971240247996, 0.03634583344683051, 0.04037826188973018, 0.01031368478600468, 0.03120372544175812, 0.05503124936616846, 0.028648023294018846, 0.012507789685124797, 0.034865412528493574, 0.022407192370987365, 0.034862046994801076, 0.03595622203179768, 0.015298516855442097, 0.026134480223325745, 0.027623503269361596, 0.044649778931800804, 0.022686536756477187, 0.023730735993012786, 0.06030521368873971, 0.0412143866664597, 0.004307003999461553, 0.025856153640363897, 0.022569723560341766, 0.026099981806640114, 0.05351831304973789, 0.07993217837065458, 0.09167206234165601, 0.03905209572985768, 0.028112017948712622, 0.05227969487064651, 0.027675891261813895, 0.014016249366769833, 0.01633771019987762, 0.03996418250192489, 0.021337941621563265, 0.059976721315511634, 0.03263943429504122, 0.016368486851985966, 0.03601371430392776, 0.028187647461891174, 0.05203786838267531, 0.014092334346579654, 0.02079587017319032, 0.07217365290437426, 0.04500151452209268, 0.036178913832243, 0.01944358380777495, 0.08735372977597372, 0.03482673942510571, 0.003357862854110343, 0.018180609614189183, 0.06797422681535993, 0.03113398900521653, 0.0335632291888552, 0.0642520347610116, 0.08125253287809235, 0.04422522635598268, 0.022265163117221425, 0.03570648043283394, 0.07956258034599678, 0.05386007417525564, 0.03493572911247611, 0.04030234060649361, 0.062276744682873995, 0.08042048609682492, 0.01687231267403279, 0.01010205565086965, 0.056186343277139325, 0.09078574632959706, 0.0213911387670253, 0.04544265727911677, 0.012676476035267115, 0.052879774277763705, 0.0166124320655529, 0.007408156275882253, 0.07794730059270348, 0.019295588534857546, 0.03008584917656013, 0.020312049259830798, 0.03970354363056166, 0.027855538497013704, 0.004916733870881477, 0.025980576606733457, 0.03971497355295079, 0.023746596749073694, 0.022041918310735906, 0.03561645919190986, 0.025073246365146976, 0.05254715980429735, 0.03699240946610059, 0.06260537954845599, 0.031157839511122023, 0.015380809582503778, 0.027857411253665174, 0.040990375115403106, 0.08705053997359105, 0.02555255332429494, 0.0313349676850651, 0.04905004460098488, 0.0309348491552685, 0.038766598728086264, 0.034564319399318526, 0.026934301680220023, 0.040293947128312926, 0.04217724482129727, 0.025035916761096035, 0.05069522739255002, 0.05680966250864523, 0.04192244474376951, 0.053182407681431086, 0.015151537688715118, 0.03101140147607241, 0.028937781495707374, 0.029107377930943455, 0.04502457453470145, 0.04133970529905387, 0.04601974452712706, 0.056047179137489626, 0.026228937386934246, 0.05672222648614219, 0.024503809599471942, 0.010458119446411729, 0.03463687175618751, 0.02691528234364731, 0.01453519718987601, 0.02229028078727424, 0.05604082804971507, 0.036772598046809435, 0.03649035801312753, 0.05167857051960059, 0.041779368849737306, 0.0548930724949709, 0.07039523976189749, 0.045553485796387704, 0.016590162546240857, 0.05399823408307774, 0.006782927392383239, 0.008155388724324959, 0.02072427115802254, 0.04686688192720924, 0.03646861435845494, 0.03404165405247893, 0.03361721343493887, 0.02096276095003954, 0.0274389553149896, 0.012619860769648637, 0.04290244947852833, 0.029767826598669802, 0.004644418260016079, 0.05312503415292927, 0.015464922479752983, 0.012205662638215082, 0.02883553644642234, 0.04364710434206894, 0.027219284691714814, 0.004803700114799929, 0.07591606530227832, 0.03224507652755294, 0.016256513306871057, 0.021458518990714635, 0.08536355263952698, 0.0365678874243583, 0.008517547460672046, 0.05294877789648516, 0.050477902804102213, 0.011366944161376782, 0.06225503156227725, 0.038276933931878636, 0.03663836346407022, 0.03480008996224829, 0.04353141412138939, 0.0016429588930415256, 0.03542668651789427, 0.03649029015962567, 0.026615943227495466, 0.016940062699307288, 0.02903286460787058, 0.0381768941214042, 0.023659377857776623, 0.01444628365736987, 0.01686451630666852, 0.0077147217899827016, 0.022736955301037858, 0.0038219205868829575, 0.04406630666926503, 0.03061173077938812, 0.0231015338628952, 0.03993463569453784, 0.03303723223507404, 0.01891681332407253, 0.021652057534083724, 0.033021256128059964, 0.010537207791847842, 0.011034287279471755, 0.04007888545415231, 0.04671628786517041, 0.017100327581699406, 0.075949856346207, 0.063352996217353, 0.01481193769723177, 0.0040936403591851035, 0.06821602955460548, 0.07686680142900773, 0.0370458712402199, 0.031102891745311872, 0.02430572996049055, 0.009370661057930971, 0.0135097543575934, 0.020475048638348068, 0.05193285151783909, 0.10633090896798031, 0.18995837547949382, 0.16693672724068165, 0.08926970910813127, 0.22536821397287504, 0.08462518440293414, 0.14158545115164348, 0.12653232818203314, 0.19308947532304696, 0.13106787337788514, 0.1302652885871274, 0.1274861448577472, 0.08846441017729895, 0.17856662747051033, 0.0822650564036199, 0.14533101873738424, 0.08495265897363424, 0.1323716105627162, 0.10440160320805651, 0.06456187420657702, 0.13963857133473667, 0.22479911308203424, 0.07879377302846738, 0.07725191076419183, 0.13414360476391657, 0.1337257900408336, 0.19015360357505934, 0.13426470969404491, 0.062374195882252285, 0.16382005305162498, 0.157097548778568, 0.0904183399730495, 0.12375659069844655, 0.20884459705225059, 0.1469244360923767, 0.17090854554304055, 0.17837395066661493, 0.0760482099971601, 0.10918702570987598, 0.13337956076221807, 0.21066794278366224, 0.12292457105857985, 0.07300323660352401, 0.1566114327205079, 0.1365247741341591, 0.16976643539965153, 0.14908481016755104, 0.10556815418281726, 0.11108346323349647, 0.1333503701857158, 0.10608260586325612, 0.1689151589359556, 0.13369273181472505, 0.14397968910634518, 0.14969148832772458, 0.06746411775904042, 0.15738713395382675, 0.1076087803979005, 0.06923039869538375, 0.08132950589060783, 0.1419940377984728, 0.14970370195806026, 0.06918535075549569, 0.13815446597124847, 0.15480628529829638, 0.06896272341587714, 0.18950337703738893, 0.22807570440428598, 0.15661251837653772, 0.10491150870387043, 0.09770068991929293, 0.06755391508340836, 0.15519857353397778, 0.1564582602253982, 0.14817408046552114, 0.18889918231538363, 0.06133102292993239, 0.09169551929725067, 0.07810123304703406, 0.0801131979429296, 0.15814907449696744, 0.1703117468527385, 0.10331598789032016, 0.12267704148377691, 0.12029465075050082, 0.12469724379479885, 0.17584635343934807, 0.13301638167883667, 0.09990468701081616, 0.07871542258986405, 0.0980297861886876, 0.07792560782815729, 0.09675413356827837, 0.08831691023494516, 0.08839870763144322, 0.129493862124426, 0.19142049630837782, 0.1376870639090027, 0.1185869002448661, 0.13084535460386956, 0.06841031448649508, 0.09501557078744684, 0.0759980526885816, 0.07846110766487462, 0.16286167662058557, 0.1886454237891095, 0.11220868464027133, 0.061634423078170845, 0.11663193229053702, 0.1378356223659856, 0.15942287471677574, 0.076972293268357, 0.12527608844850743, 0.12942467869392463, 0.14684814161487988, 0.18168269097805023, 0.12971301536474908, 0.17950772839997495, 0.09465976737971817, 0.06956094702971832, 0.12180074064859323, 0.09241494962147304, 0.07931536968265261, 0.17973696467067513, 0.07888670518462147, 0.09392880874552897, 0.17910671420395374, 0.11616750221167292, 0.06373552033411604, 0.11084762481706482, 0.09346854487167937, 0.079847924677389, 0.13969440119607107, 0.13426134416035243, 0.09090871044567653, 0.14114571974745818, 0.13268604369035789, 0.0897017934226564, 0.1356828207416194, 0.17187294736504555, 0.0896011870354414, 0.15563937702349254, 0.12116746391568865, 0.13390724387552055, 0.07912546130163328, 0.09668486192822456, 0.10100930809442486, 0.15189756852175507, 0.08240112303090946, 0.13221011922827788, 0.15042844521147863, 0.1022248018000807, 0.1668393981776067, 0.10990130595330681, 0.07736189450536456, 0.09631859551050834, 0.09423778645162072, 0.15738732394363197, 0.12210728919931821, 0.14281217461185797, 0.12062407950205462, 0.1006715197914413, 0.07922689550157104, 0.18691122398844787, 0.18036498954253538, 0.059421123271541934, 0.16888014652899333, 0.13874928333929606, 0.14418539378259862, 0.14657817967236042, 0.12662188123379434, 0.11200319709522383, 0.05338505895010062, 0.08757378546787159, 0.07866816941116538, 0.1299740206450224], [0.03701702332390206, 0.05089973106182047, 0.021370945564870323, 0.029977032515619482, 0.02773110195994377, 0.0798760906660131, 0.047965457263801775, 0.026531508026112403, 0.052766370720096996, 0.02488645924521344, 0.04475327587819525, 0.03809512386630688, 0.023022747465542386, 0.028416960067780953, 0.027782031102105975, 0.060132200829684734, 0.09324997517147235, 0.03992283597056355, 0.027490937882768254, 0.019513459343995367, 0.02561274786213679, 0.013673367810302546, 0.059080159424671104, 0.01810266629659704, 0.08892331019576107, 0.08577902641679559, 0.05112815987584846, 0.021561396773904562, 0.038070584647357464, 0.05855810136667319, 0.041116365497665744, 0.08099397710923638, 0.011233830857755882, 0.02145666828645127, 0.03753573281158294, 0.01942574342579714, 0.012327557213471403, 0.0957083414707865, 0.0344170365881707, 0.033862707404685874, 0.011894612007641366, 0.010185176190654082, 0.06756889035126992, 0.03214909774916513, 0.03803686824228082, 0.030703675667090074, 0.022474046730037247, 0.05959010563258614, 0.014498374790751507, 0.03885619927729879, 0.017224199238366315, 0.021590512711554766, 0.04620651468368513, 0.04593446963865842, 0.01917574567986386, 0.018782946846580932, 0.014497402789337295, 0.009995920051421438, 0.01604490537595536, 0.023335492737325172, 0.026077725858028446, 0.04941532714292407, 0.08170090203306504, 0.04624671109818986, 0.06417414572622095, 0.045198493238006315, 0.08071886508592538, 0.05044476993914161, 0.037813806640250344, 0.013698657658616347, 0.0852982232879315, 0.04571510944515467, 0.01521963207051158, 0.026825335741575276, 0.12675817177764007, 0.10280352431748595, 0.023938712065241168, 0.02340919860372586, 0.03574401020471539, 0.013061821161370193, 0.02902389776759914, 0.022058505099266768, 0.041977609640785625, 0.040267351948257, 0.09068102123481886, 0.006868226453661919, 0.020414197617875676, 0.015846723956721168, 0.042405079917183945, 0.11585646175912448, 0.06449562204735619, 0.04798624757677317, 0.050324991544974704, 0.0371941684612206, 0.03028609843126365, 0.021828354502628957, 0.04746555337416274, 0.04495876342324274, 0.021855556971526573, 0.05237495440191456, 0.017493901641241143, 0.016845812488879477, 0.03131511375041945, 0.006021388033072331, 0.01581934337238116, 0.022125357761979103, 0.009507343455749964, 0.02566195182901408, 0.023397088449980532, 0.04158005258068442, 0.029060833821339265, 0.04578919868384089, 0.02081516431644559, 0.018726158554532697, 0.012373181908125324, 0.02267196012793907, 0.03377064038068056, 0.1123464001076562, 0.01484251078883452, 0.017718498428751315, 0.00432186179594802, 0.054012629203498363, 0.06372769682535104, 0.0087042514600658, 0.03698220429942012, 0.03745366060840232, 0.03389369949166264, 0.03588203440553375, 0.003339017816220543, 0.02516426844522357, 0.029196140489407947, 0.04218888169686709, 0.026926361124164293, 0.02671856995272849, 0.0357893872340875, 0.030415797007403204, 0.03846876935235091, 0.016983302343370657, 0.05194994042228375, 0.023530656372063925, 0.02284769730509392, 0.017732323579756275, 0.06849443247275692, 0.009117555621612285, 0.05739526876381465, 0.02995095302217773, 0.017556252224104743, 0.0036993614713927464, 0.0401009819470346, 0.030235123487987688, 0.012617308629809745, 0.013367368872942669, 0.03676302391769631, 0.04052311893818634, 0.010444200996841704, 0.01466540466727955, 0.023462741802047406, 0.014176571076469762, 0.053199116606265306, 0.07146016654691525, 0.057894887668745856, 0.020648768870159984, 0.03557746039171304, 0.008973976763497506, 0.08703042141028813, 0.0406883557859276, 0.016969702805259397, 0.02000499689685447, 0.025196419130744677, 0.05993866228631564, 0.018181367877072523, 0.04827460799632328, 0.02343103725330106, 0.02644953760318458, 0.06220459605434111, 0.03488632158509322, 0.0343547843928848, 0.03819932309644563, 0.012858999410777219, 0.05915193485894373, 0.05830721304352794, 0.04826532563726817, 0.05893369085554566, 0.08583086649222033, 0.03952493625027793, 0.04136159483875547, 0.03496078062536461, 0.03705755900591612, 0.04216722285907183, 0.0052114368965184045, 0.03980106946879199, 0.029228167342288152, 0.047820718958973885, 0.029788487989987646, 0.059231560943382125, 0.021679022515724813, 0.02464481596169727, 0.006776081398129463, 0.026445423984634023, 0.042040425020137, 0.020394750804241215, 0.037715120507138114, 0.03657614519553525, 0.016731553977089267, 0.06281953198569161, 0.02715061864416514, 0.033884668190564425, 0.0745540080325944, 0.022803867335564325, 0.04892862754474793, 0.02533265539178891, 0.05047754657321742, 0.007032317849474826, 0.04594690379287515, 0.025217852355646234, 0.017590160315324153, 0.009958549735269375, 0.04218989949939506, 0.08253220921116215, 0.03906044849593725, 0.04607393233371632, 0.025282107925574695, 0.028101624488564472, 0.026993475022858808, 0.04092050975720797, 0.034414865276111026, 0.05164566157119615, 0.011391548689321747, 0.02021899157469826, 0.05716344727469342, 0.052100232536239285, 0.05028594185465148, 0.029745004073317562, 0.03761298741613116, 0.013273927815524595, 0.003133132480018373, 0.0291366736803736, 0.03331930263500128, 0.00963347208952265, 0.040980980798069916, 0.014147975066277598, 0.0646869892786656, 0.018721914317991053, 0.01413199895926352, 0.05966724149350609, 0.04184078983962536, 0.001528713315825111, 0.05058292306161352, 0.04767159392525043, 0.025032742913546305, 0.025204483519441316, 0.028256751164527874, 0.055120008531957865, 0.03050689711900694, 0.05109669281435864, 0.03579784178041986, 0.05313040815027697, 0.03813661628269723, 0.03353172480793936, 0.06561244997595038, 0.04813424963504076, 0.043821956031024456, 0.011877471364901533, 0.036375152944986305, 0.04781008292255657, 0.04651140082361443, 0.026368059118145278, 0.024673655396327376, 0.038860172099832974, 0.04204580919550998, 0.011379637007069374, 0.029329150316438506, 0.04133618709498218, 0.029729435087314675, 0.010775928285771182, 0.03189382269712431, 0.029316705984196494, 0.01732054103298911, 0.04262984464211123, 0.0355669363135738, 0.02969914528408221, 0.023067508724385073, 0.050654952946518145, 0.01910518143059952, 0.04757582888539348, 0.05003139962043081, 0.017023196809792092, 0.01889462522896273, 0.060875176319054196, 0.07253006699361972, 0.03376780410430261, 0.04441052069887519, 0.008330256528487163, 0.031028924642929008, 0.053087148150163035, 0.019965843729940907, 0.05755339456456048, 0.03346577798947692, 0.04318848930831466, 0.03437094031167882, 0.011946324857750108, 0.09128105653715984, 0.04232702464131372, 0.019764339185452888, 0.024658666557765434, 0.06644569097885064, 0.04887248555730496, 0.06807772376175437, 0.05461215560457536, 0.055943834861474376, 0.05185825677056398, 0.028661977366677353, 0.05550992528774908, 0.04390798409336379, 0.026983332620667558, 0.03365430894440838, 0.028827563659953218, 0.05310891894623637, 0.0168404283135065, 0.005096994756188775, 0.04455196810886264, 0.022402035504845635, 0.0343655764923564, 0.03218613558315805, 0.07788190338760614, 0.020181378682277033, 0.011001431765700025, 0.026934900487373983, 0.06989306277994599, 0.052982236458254714, 0.018131529479952793, 0.025689837921942984, 0.008570948166639676, 0.04752775128664715, 0.07359825074672699, 0.03273159631394914, 0.03985251599390592, 0.00434588490419888, 0.025473376769306402, 0.03758323026288833, 0.017757241081978594, 0.053691624464201074, 0.017671950926472033, 0.07261510100215673, 0.0028337768245754497, 0.043443123144762855, 0.045413785614073277, 0.00640504784782284, 0.028741657733917236, 0.03721446344362838, 0.08284973645848887, 0.023433737822675278, 0.09611166947122131, 0.10577981639653444, 0.12999160827270576, 0.10356186183967761, 0.14431670387940748, 0.15644561233265059, 0.25555672549775665, 0.10714190759296928, 0.08435007237962314, 0.11478975042700768, 0.15350010538739817, 0.16534709611109324, 0.10030026614133801, 0.10807424184999295, 0.08882829493709973, 0.14880381524562836, 0.185298034123012, 0.08482227846980095, 0.10861118018094983, 0.06181636545807123, 0.11838593174304281, 0.14628597535192966, 0.21490270697644778, 0.09114403996084418, 0.1801976899483374, 0.16618250842605317, 0.08552028744348458, 0.0822599877470306, 0.1544350859309946, 0.15527469159236976, 0.08148609141686133, 0.19667094599987778, 0.14196343586913177, 0.18258689317320073, 0.09494403284043074, 0.1272211362208639, 0.10316737515053578, 0.13578766797270092, 0.13712970167398453, 0.11512657521026474, 0.048915145053927384, 0.24336296266743115, 0.17675394830959185, 0.13262151501008443, 0.08807593530842237, 0.12537488314722264, 0.1321041863411665, 0.1810096385223525, 0.08707857025521142, 0.16426386923662253, 0.1661496537604502, 0.11246481125376054, 0.16259579945887837, 0.19223878239946707, 0.12530130280980042, 0.1066387603059411, 0.14079094092760766, 0.10117142368108034, 0.05248628842777439, 0.05830569312508617, 0.20939768451665128, 0.15976032375225, 0.16531937117023127, 0.19218897792909825, 0.13437664083072118, 0.08246447106025048, 0.21484363371772425, 0.13369706086814404, 0.1285313737711736, 0.14224938409669058, 0.12219412811100483, 0.1859208614166294, 0.1129119929724506, 0.09124670230916568, 0.19642329428877148, 0.1195540569190468, 0.1326017967824425, 0.1272258995366948, 0.160502518926348, 0.09112546845738377, 0.09556021049086537, 0.10025918084595885, 0.13540637200432165, 0.13931203314236232, 0.18632600110556397, 0.10710803512483835, 0.12265504337847233, 0.11165569217077323, 0.1641904788890055, 0.15395827937339032, 0.18554135678069933, 0.08453677807535444, 0.1185884065926075, 0.16502941958606243, 0.09435304919523851, 0.08008159856711115, 0.09135425689497165, 0.09673015414071934, 0.059716347072805674, 0.14047162234783173, 0.09294243595962014, 0.1286020771201168, 0.12338212079235486, 0.09324310161173344, 0.11355807366115706, 0.12469866871833801, 0.12043771307383265, 0.07638092964355435, 0.137016304901668, 0.1278414936470134, 0.2206665634044579, 0.11879411126886096, 0.15032089741102286, 0.16089577068175587, 0.12519660485642298, 0.09738973767629691, 0.09869931704763855, 0.25120232201048304, 0.08626149874180555, 0.07630492693611554, 0.1794347180319684, 0.08555768829371248, 0.14202121991131986, 0.09430833373750959, 0.10378388528312955, 0.12789612928671495, 0.08853509995554175, 0.07070001055087362, 0.13936338467257364, 0.19708692867841038, 0.1880537683942488, 0.13475607761314937, 0.15273614280990191, 0.13059622368642262, 0.10699493690793004, 0.14121231117418834, 0.17629358944083962, 0.10448677970894746, 0.0786066602117249, 0.08240499746586595, 0.11568823935730116, 0.15251285050596508, 0.12362833400922162, 0.08038513442235333, 0.1076958364407931, 0.1862714197486639, 0.1557242888957262, 0.1316391455807856, 0.11940446708883558, 0.06695547433836119, 0.11832394078373909, 0.09096633163946015, 0.09496157975601298, 0.15661356332046644, 0.08001861016133002, 0.14793102922184126, 0.09131944804851498, 0.09496334394706146, 0.15154770229543957, 0.17630112117954663, 0.12582370692065784, 0.07860808513526406, 0.14050601050257683, 0.18105557534311498, 0.20341785039220536, 0.1146209037729672, 0.07732711280030863, 0.14262295833655766, 0.17335163801908493, 0.15371544526091643, 0.10925252469522612, 0.14058767897742136, 0.09613184910267591, 0.11365549093378441, 0.19040310090141638, 0.08180429719920669], [0.023999693703704646, 0.07718387405787196, 0.031514453768197975, 0.013876605163594442, 0.04500610141881874, 0.03041793778538704, 0.06493684622858252, 0.0202254732804639, 0.007731793731051896, 0.04709029636744942, 0.05898730869271925, 0.044178258161991835, 0.005912752032080399, 0.025742673747507588, 0.02103512840611594, 0.04494215627866132, 0.04497149274019258, 0.13885155213730677, 0.03328762862033077, 0.038733615140829764, 0.05095247019614492, 0.04210101480462721, 0.04692881181836128, 0.029147811832704713, 0.028072746038170796, 0.0468443104598139, 0.04663727924759899, 0.05720235447266272, 0.01742636365815997, 0.01865291578828224, 0.006449494011966246, 0.048714831338397095, 0.03218767585765038, 0.03541801144768085, 0.03351967063333307, 0.050470065724636824, 0.013989415003119834, 0.008666376483493617, 0.03555814589240721, 0.020977122143709233, 0.04130632816148656, 0.02825664259892489, 0.04058330160166536, 0.0017375134900378595, 0.02338063227944076, 0.05053864525897162, 0.013528537055078362, 0.07944094615855388, 0.031302835659257004, 0.05317041796765157, 0.06460564650063004, 0.055963736293571334, 0.026843766449019313, 0.04214903133522187, 0.04383213744897928, 0.007863225115995322, 0.04647495670776282, 0.07400616564388786, 0.04264706925355962, 0.046183203613119464, 0.028688728609787564, 0.04619130192856703, 0.01806645288265177, 0.012232460530607827, 0.0507630164335881, 0.016218773189133832, 0.03436380212328263, 0.08308379032782146, 0.054209082054772546, 0.09679335967770644, 0.027863670739212205, 0.05601313364292894, 0.058346079529396126, 0.06130489933171442, 0.0032264793907026096, 0.0034733857734993634, 0.0264470677357167, 0.055962128165577135, 0.04746894265658089, 0.019109228891985755, 0.06271209275083882, 0.023842115819986378, 0.03222653216549328, 0.06784006008612257, 0.012424563972412475, 0.01348942714477224, 0.07805106216775519, 0.012867593904957175, 0.04404757571007524, 0.021669784261445914, 0.009037919359148612, 0.029896137570696216, 0.08306289823459727, 0.029518220706709793, 0.08456987022821393, 0.03418893347095166, 0.03191058590476002, 0.011858000802541417, 0.033890914105411084, 0.02961895601557834, 0.05298848915845156, 0.039085377872522385, 0.035133230300354104, 0.056221569422632456, 0.059468179675085206, 0.029769807920924256, 0.033495121236358366, 0.031619443491633446, 0.023506909342748777, 0.027723945111834576, 0.055727965730641565, 0.024081735372809426, 0.018128698292587484, 0.04899627409343209, 0.056607781377221854, 0.043835038186184, 0.044252137054822276, 0.03829905417348657, 0.03900784846129162, 0.03711927515853729, 0.035993721269603283, 0.01889578722018216, 0.03727335010522178, 0.05573994526639581, 0.11825173108705453, 0.08482738105314118, 0.03938481876892703, 0.009902924282609351, 0.024502213345840573, 0.06248914649976151, 0.040771381330809424, 0.03620608576706477, 0.010479065822437406, 0.013070978839615626, 0.01923352972205196, 0.03341617029426353, 0.02956958920029657, 0.04464278323575854, 0.02195995467315827, 0.06444635361965213, 0.018955554280962263, 0.03498510271310806, 0.02637974009849131, 0.05315431972433414, 0.03316450844119702, 0.01793429970608226, 0.08612533033426319, 0.08900223738913025, 0.03430824028328061, 0.044535944504397254, 0.009835074173419603, 0.07608744967728853, 0.042828261852264404, 0.10415784628795725, 0.02837874327919313, 0.0631411847259317, 0.059577281320733685, 0.02559980989566871, 0.02631426146919174, 0.03751982455807073, 0.026491560973227024, 0.024095994786226323, 0.041002890693822076, 0.02134585503621825, 0.01947100510421608, 0.08291881132338728, 0.04808304398985846, 0.08690409176051617, 0.043065118071224005, 0.049123574048280716, 0.013030142057687044, 0.06149692474199193, 0.044291346200874875, 0.041566736330943446, 0.04866933895807181, 0.04142923799476453, 0.032500996187861474, 0.022273415799385736, 0.04566003954304116, 0.008497578175073224, 0.02051616446780307, 0.03971527550103409, 0.07236578688025475, 0.063794681802392, 0.015214268251189163, 0.03660923395571964, 0.04724635602906346, 0.02492447756230831, 0.08243553832705532, 0.020340186410716603, 0.05565971528579082, 0.0444023816713265, 0.04199049502078976, 0.04352597566321492, 0.045409219073397775, 0.02458098447615547, 0.0075851945439353585, 0.04647647662620459, 0.03574805427342653, 0.04442800654630576, 0.014404582591461284, 0.026069459605163763, 0.0693089459091425, 0.05118725349062255, 0.023476305717070187, 0.015102846015776907, 0.046284977080566544, 0.0525583284907043, 0.025413136430350796, 0.014409008336120417, 0.03684288409671613, 0.0584788281204445, 0.018143327507589544, 0.0413199599300112, 0.03160055307671428, 0.025006802519783378, 0.04116079257801175, 0.04663646500557661, 0.004780931448164795, 0.04089437598096473, 0.012478061369620264, 0.028751245433730737, 0.03335370436044676, 0.03864530041547758, 0.008259603221501623, 0.048240759276918004, 0.05282752029597759, 0.01387426336961133, 0.025059762177988887, 0.045633162770952494, 0.044306514851216755, 0.03129532088392547, 0.04655848776123353, 0.08286155653851372, 0.011321998849910284, 0.05973426718264818, 0.026301331984411393, 0.026081965005557452, 0.011804723081045916, 0.026685208082199097, 0.013943088024721613, 0.04408790443890861, 0.038736258034727404, 0.009514517267234623, 0.0952991373570902, 0.03256588109901973, 0.06195288670382329, 0.03378437053678291, 0.04251425959435957, 0.009840154704371733, 0.031008812864976268, 0.012453422914924366, 0.04756611226392644, 0.014506642739953739, 0.03476083671141948, 0.018916850643498555, 0.04110500342877848, 0.033956379164010286, 0.029722527600824833, 0.07465914703373398, 0.036946557462215424, 0.04967509748946343, 0.0811949795378106, 0.0270993315747806, 0.04154616654185312, 0.060473687148519924, 0.06198988721839019, 0.056692795029708316, 0.07795504267726626, 0.025525179525305117, 0.06914531718939543, 0.005683777421446783, 0.0501698139788849, 0.029372149080570256, 0.07797365489282779, 0.03704020547281418, 0.09372364011194025, 0.02206975351353841, 0.02537575932884855, 0.044133291646306, 0.048963287113500495, 0.02789640157217426, 0.07357421703636646, 0.020779868621113043, 0.061526536010205746, 0.021920592856726477, 0.05248035803171141, 0.027884847817144225, 0.059198787701981406, 0.024595182821420685, 0.033295082327510626, 0.03722447183515344, 0.012583511648699641, 0.09385813253798655, 0.05604370843086924, 0.033361307345330715, 0.05098377101655517, 0.05423095802377377, 0.038734724545585256, 0.022230634166459953, 0.04616459818290813, 0.09301237256399222, 0.02971358790195414, 0.040518827204193385, 0.026552001480013132, 0.030704082788101265, 0.015840138774365187, 0.03876483453703778, 0.031684654099600654, 0.044377377655889304, 0.027306780086031983, 0.03742642421275377, 0.039759132611964426, 0.037360406148114374, 0.012555691712935056, 0.09764072099434477, 0.053029394642050774, 0.0047543260900835905, 0.026982280891388655, 0.026473513638068522, 0.009890237374098172, 0.06404997381780829, 0.0056635761616884595, 0.025517537524657588, 0.03235964038010154, 0.03363730824951615, 0.02206693759321102, 0.0506748577712902, 0.043295355181076696, 0.12149105726608209, 0.0798998393916658, 0.021412962149562578, 0.03738200052508286, 0.037165290010826926, 0.039152878536177535, 0.029039765309010233, 0.11761774867773056, 0.05983490749661412, 0.032598464350615225, 0.011610714652176415, 0.011718141164497604, 0.12457254262907164, 0.028238296708358184, 0.027304418784167086, 0.01958364700632436, 0.007173828448035887, 0.011168241118347006, 0.05668372301650899, 0.03672081564686128, 0.03206763283482619, 0.04622004467195698, 0.05450395301782659, 0.08921320749712841, 0.14781254343688488, 0.11309510243258306, 0.14690820553473063, 0.12435599496322018, 0.08749890234321356, 0.13366241487009184, 0.21658547382269586, 0.07596296564276729, 0.12707972952297755, 0.21135020974491323, 0.21527469344437122, 0.0940177036183221, 0.1247610260865518, 0.2039603255689144, 0.07643232188586678, 0.14364713909370558, 0.3014612208519663, 0.11102062410541944, 0.19950764306953975, 0.23856439015695027, 0.1659087873995304, 0.14500722182648523, 0.11122142975883824, 0.08085478922086102, 0.1141015530696937, 0.1753941641322204, 0.15252073508288178, 0.06283598645989384, 0.044404597088162384, 0.1485044320247003, 0.144659730472735, 0.08406501303293876, 0.09814220587057726, 0.1376962512731552, 0.10835547425917216, 0.1272491325757333, 0.17869947105646133, 0.17929422057100705, 0.0873394805405821, 0.17046751135161944, 0.08574206661432981, 0.08777509323720421, 0.11946858864809785, 0.10001278442463704, 0.113272953246321, 0.10499131120741367, 0.2165258713066578, 0.20776365005544253, 0.09488151940916266, 0.12478359416127205, 0.0860287815864597, 0.17675417901149817, 0.15283600959394658, 0.15003189577588014, 0.09084633950676237, 0.11188346959118332, 0.13973887238119329, 0.09500006626227073, 0.16896112289811882, 0.0785301011055708, 0.10362494524036135, 0.08686048231486763, 0.1169033870100975, 0.05449236024703298, 0.12692657059856824, 0.09469852529998336, 0.10613469021128756, 0.17809181580586092, 0.1423733253031969, 0.21802901636276925, 0.09190207892762763, 0.14623427098350866, 0.09805878677538463, 0.17177397624722548, 0.10592696350067854, 0.1234194537890809, 0.13469861926777021, 0.10408911747591836, 0.11667928046413831, 0.15419662158404077, 0.1317184663244656, 0.10018290672451258, 0.1673422876213278, 0.07899800528373037, 0.09945662998195205, 0.1876599466694253, 0.08047761196004492, 0.12934775996421063, 0.14469966904393264, 0.13256674366337912, 0.1204193112041269, 0.2048068522874798, 0.11398268730512687, 0.13624297854091438, 0.1008850344057594, 0.19677075850112097, 0.07796161768159696, 0.20218981057405472, 0.10423094486551625, 0.17047568091324397, 0.14445178663092, 0.07740179236446108, 0.1002433845507247, 0.19086868448981217, 0.07194122073373624, 0.07417845925582306, 0.12928414052086218, 0.09998727150793586, 0.11665572172829083, 0.1995993945747614, 0.1585905293801001, 0.09998396704239504, 0.055643986844058545, 0.12946091246392044, 0.06844932346471719, 0.14096490373568876, 0.18177717019404682, 0.12435447504477841, 0.21682503739637987, 0.12351763780627932, 0.16198449368987763, 0.11871533335319587, 0.10956380263503109, 0.21121193787881307, 0.1221924860562597, 0.10728112262274538, 0.07195973795439516, 0.08401309831866197, 0.16211994285030024, 0.0809586661468659, 0.15483862427728518, 0.11520462030810968, 0.11840517499617167, 0.10101031911160264, 0.1456359252333641, 0.1830822101661137, 0.16664178163877555, 0.09933373371937446, 0.14858935746763433, 0.1726154275238514, 0.07879557793161698, 0.09521192525114332, 0.16210562576140675, 0.13967051676341466, 0.149046785065106, 0.11403706510152135, 0.11701860225626401, 0.0697996285078781, 0.14915815980306693, 0.12918898276984692, 0.0753255837729999, 0.10376467595675162, 0.14157337322831154, 0.1078821960836649, 0.14572968520224094, 0.10372912072177444, 0.11414111166128091, 0.09608600727681603, 0.09467149246484041, 0.13921862601169518, 0.15297523140907288, 0.13233115630490438, 0.116403320272054, 0.09871718287467957, 0.27401184663176537, 0.16838029692215578, 0.21190747698502882, 0.09782904838877064, 0.19560456036456994, 0.09150135650166444, 0.14182863810232707, 0.11284785105713777, 0.10170597356877156, 0.18474884144961834, 0.1328083835542202], [0.018415883150217787, 0.04691674746572971, 0.015060362938259329, 0.023348747918914472, 0.037419207992830446, 0.03546513231205089, 0.026261490104453902, 0.04827395660270538, 0.056567639245518615, 0.00851154072941946, 0.02864517005426543, 0.0068025370544221786, 0.03489870145650847, 0.01196090318262577, 0.08310369175991841, 0.025019709952175617, 0.05480825222496476, 0.014530311737741743, 0.012038447860894459, 0.012057468045635946, 0.03731639636680484, 0.03704938944429159, 0.03783826104232243, 0.03043501990448151, 0.06085366675896304, 0.050257738546601365, 0.027539459921951805, 0.015301711059042385, 0.018245922002409185, 0.034169737715274096, 0.011063392190927905, 0.009547460990558778, 0.030293457143540894, 0.06124516110867262, 0.05296935786360076, 0.056852576455899646, 0.03393422160297632, 0.042505781299301555, 0.010077210242993065, 0.006052578167457665, 0.05774310617042439, 0.059386945462652614, 0.02797385973722807, 0.027734133315139582, 0.004387651703187397, 0.07907895451145512, 0.01081870058884046, 0.07429413590580225, 0.03161967419353979, 0.04126122933147209, 0.017349188781476448, 0.01650280285892742, 0.027822778826313357, 0.015277066667165076, 0.016208690158756714, 0.043127828277647495, 0.03673015568139298, 0.0419024177826941, 0.004286428273189813, 0.05487827364621418, 0.04447759388546858, 0.010623938986100256, 0.06809520282383476, 0.06341189984232187, 0.017811425495892763, 0.03011601684348924, 0.04939857411331364, 0.031111926439085176, 0.07728590536862612, 0.060088462462382655, 0.032339308078267744, 0.03320916961612446, 0.008949413795822432, 0.006141953103776489, 0.04614223027601838, 0.09171480326248066, 0.01896094354534788, 0.050057601250175915, 0.03426932290728603, 0.007633863316316689, 0.02370288721950991, 0.013820804988167115, 0.05340745399839111, 0.00815681873687676, 0.057364619337022305, 0.07460669627679245, 0.04541667956592781, 0.029670008990381445, 0.012807956613999392, 0.04060764065278428, 0.06891643375690494, 0.0511419443147523, 0.03480636980384588, 0.004821196140255779, 0.040978348082197566, 0.0902486519355859, 0.038901298107313256, 0.019492139773709432, 0.06132607640964644, 0.018345369791079844, 0.03392671361299498, 0.014230923427801048, 0.029402527093355144, 0.024938989730019654, 0.0210779711071934, 0.04428026572402034, 0.0064659238892740434, 0.04845202454764928, 0.03622323913233621, 0.017699178840432848, 0.09372855949082545, 0.036230604629963636, 0.003698836454922067, 0.023074550221541097, 0.002742917592903333, 0.057891779978360446, 0.01667131024545857, 0.05138568087880101, 0.035892164933362176, 0.017821103101596236, 0.018636446047042097, 0.05605903314426541, 0.07044211296098572, 0.006202878339016544, 0.05376671114936471, 0.05232009823833193, 0.02298753658708717, 0.018879112222098877, 0.022558585408010652, 0.05865208525210619, 0.020687479292973876, 0.07082387711852789, 0.07155493074761969, 0.0011625625671253406, 0.05067484759326492, 0.06479902219559465, 0.034145022077219825, 0.030672724292214428, 0.03772607884768929, 0.07848585383700472, 0.025952369906008244, 0.04994230457980718, 0.01819246362096497, 0.06959440559148788, 0.050462998782417605, 0.02806309048485543, 0.06448622433734791, 0.03462507203221321, 0.024153471791318486, 0.01961606401684029, 0.016865890340081284, 0.0059005502761075536, 0.037846135441213846, 0.033660724493009705, 0.06254770407187087, 0.04749783467767494, 0.060016435970153124, 0.03073364995153887, 0.027310696929427128, 0.04201778909191489, 0.028375191148370504, 0.01788593203361545, 0.017768148532403365, 0.03551210050604173, 0.045324751641601324, 0.06846354555870805, 0.040005155839025974, 0.020548150608582155, 0.008213874202088585, 0.024436612580237643, 0.023772706776591282, 0.0307429730226951, 0.010957020800560713, 0.0479614301584661, 0.016496078576892614, 0.01589209759341819, 0.014936221563922507, 0.04303932695516518, 0.07209124482635941, 0.10112782780613218, 0.0916714109480381, 0.027179514057934284, 0.03757140339751329, 0.04030196741223335, 0.06857992109975644, 0.045448726774858575, 0.0165712907910347, 0.05441019983429994, 0.02887513575011066, 0.022210361236440282, 0.0436602306020047, 0.06364038972450153, 0.06566177268645593, 0.03976434376090765, 0.04610340450225132, 0.058008257299661636, 0.0299481065677745, 0.09865749893443924, 0.02715559400218938, 0.011142026766070297, 0.066370604293687, 0.03000186350462692, 0.020323733632851924, 0.03783965203911066, 0.04678972910291382, 0.045409202110022306, 0.03984694861407791, 0.04707689190815602, 0.016310310955824595, 0.05650539044290781, 0.024643687897228768, 0.02232686400280467, 0.009612841232280647, 0.08222957580749478, 0.027925090032762716, 0.08014871246580567, 0.032235166523605585, 0.03238957395244922, 0.05499208771756717, 0.0365305849617081, 0.023068192348416363, 0.07208255279277052, 0.03039319161325693, 0.008324937662109733, 0.025096806797332, 0.034326204497899325, 0.05756558105349541, 0.009999484056606889, 0.02843521605245769, 0.03155831427180341, 0.018087823343064104, 0.06411431250827652, 0.009240034585153418, 0.022551942550178086, 0.04002001236325928, 0.030284564942121506, 0.053284717191542895, 0.026942053942808082, 0.029087038843759468, 0.03134379542565771, 0.02557850389608315, 0.08935291785746813, 0.05242971896326967, 0.08298525347241334, 0.0317439207408045, 0.06174598102058683, 0.03108975870002593, 0.04946706883077111, 0.008792556007392704, 0.08343786347125258, 0.013953564605409545, 0.029735945630818605, 0.028468893441770757, 0.010980669442298157, 0.04881871844242726, 0.053804285026022365, 0.00971495481540582, 0.04238121923325317, 0.05530588302229132, 0.03596070036292076, 0.049733495605843406, 0.04782483088118689, 0.016345006147665635, 0.035173396180782995, 0.0480513428337872, 0.0415131931326219, 0.035994399804621935, 0.03366166426401053, 0.11452946439385414, 0.02532049604425473, 0.022198919439688325, 0.04119180841371417, 0.03352160445813622, 0.025379297888970802, 0.04184017915810857, 0.018140665953978896, 0.02973933830591185, 0.05107071849384478, 0.05458695820665785, 0.04463905129315598, 0.03126009813110743, 0.0240425906875836, 0.04601898117523108, 0.015568429604172707, 0.011347253075135606, 0.022176390380731652, 0.039111399690487554, 0.02579135524242052, 0.011045215934115862, 0.05586805607059172, 0.026144437724724412, 0.05023960130555289, 0.043749875255993435, 0.033168990164995193, 0.08250594990594046, 0.05337047044719968, 0.020313726937664405, 0.03224176188398685, 0.04884858076859798, 0.05703296499060733, 0.036507338351969204, 0.009730143821798265, 0.07640812532710177, 0.032288122789136, 0.034162514710000584, 0.03237912112048694, 0.0045908195066398805, 0.04528789361938834, 0.05388564137475831, 0.05142658296972513, 0.010980459096442376, 0.038198094948061874, 0.021561812376603484, 0.08548184843467814, 0.023468232846685817, 0.03730422344857028, 0.03900687815621495, 0.022413326327555945, 0.022584308670567613, 0.04496975229786975, 0.09747870718794209, 0.036178971507719586, 0.04206249437161854, 0.021806371664362292, 0.052235166010047705, 0.043409803682672124, 0.008240411706667925, 0.016295160965195725, 0.029895421716251543, 0.02858686014743788, 0.01593233980903668, 0.05940667047564473, 0.06963714651231255, 0.026260496050651585, 0.0503068169845002, 0.03130342937739832, 0.055310022085905075, 0.04788916278630495, 0.017007592200700725, 0.030314742787075893, 0.02511784477558519, 0.06046101889972176, 0.02501970316682543, 0.03001017216593027, 0.026338922824444513, 0.03861661195488913, 0.0179102320689708, 0.06099023550216641, 0.017977586847596934, 0.011812309950723179, 0.057849710807204247, 0.027327047927039008, 0.12271459161170892, 0.08422067575156689, 0.10141575057059526, 0.15146588454289095, 0.07296428869345359, 0.09290512331894465, 0.09951216807322842, 0.14511410466262273, 0.14195325784385204, 0.1388977603720767, 0.07706613466143608, 0.1546949648431369, 0.13930385001003742, 0.10085132478603295, 0.13379360283059732, 0.2170490896595376, 0.11477117213819708, 0.07732216628002268, 0.11593781810786043, 0.2291455641388893, 0.13260885354663643, 0.21910563430615834, 0.15463941996651037, 0.06754431381289448, 0.14258170340742382, 0.05869021213480404, 0.1000780730641314, 0.1546044075595481, 0.11718968807586602, 0.1406142096966505, 0.09487073748771634, 0.18281522020697594, 0.1338498940957444, 0.16567704054926122, 0.13905143498310021, 0.10265791070248399, 0.09001868963241577, 0.11450556639049735, 0.12298730840640408, 0.18298885731824807, 0.1788415155772652, 0.2002630696765014, 0.17403774548854145, 0.17489803289728506, 0.09898044089121477, 0.19128046025122913, 0.06928498683763401, 0.19288257642516068, 0.07590187034968819, 0.08257925204400506, 0.14751511439681053, 0.1021037647234542, 0.10672487318515778, 0.11568784580699035, 0.07768155235264983, 0.15945591937218392, 0.11445657616215092, 0.1827562012310539, 0.11588790507188865, 0.14981525311512606, 0.1113393320036786, 0.13750957271882466, 0.13502586313656398, 0.12844339492065565, 0.10301431122102908, 0.14115196226962975, 0.1645773524152381, 0.10153002265308585, 0.09436389218483653, 0.18242514399545534, 0.09165954337056194, 0.18656298624617712, 0.09200835786759853, 0.23722892467464718, 0.07588207748319421, 0.21078638785651752, 0.09183612532381501, 0.14639315674347536, 0.11901506941233363, 0.1360892496470894, 0.12695519120565482, 0.12213854252227715, 0.14700615885002272, 0.06964275799691677, 0.20581853442958423, 0.0999880586085575, 0.136157130290355, 0.11539990268647671, 0.14597668551972934, 0.1639882211706468, 0.19417240364210947, 0.1727944929152727, 0.17237769599471772, 0.087160713704569, 0.10617903926010643, 0.23372597407017434, 0.16060807183384895, 0.08239399841321365, 0.1532930436411074, 0.14988443654562744, 0.06895315607211419, 0.12790917072977337, 0.1253703505332981, 0.07900903826313359, 0.11154683479773146, 0.17355890332588128, 0.11411178537777492, 0.10317442512937955, 0.09353564519967351, 0.08595969993621111, 0.1900048279868705, 0.172905297683818, 0.16840631195477077, 0.09110588593674557, 0.057747055244232924, 0.09256878029555082, 0.1493779101542064, 0.16673062901411737, 0.12067188907946859, 0.13898957973080023, 0.11446821982307093, 0.11535229666956834, 0.14269676937588624, 0.13292034183229717, 0.46082108680691036, 0.1423767451196909, 0.14819043315947056, 0.09540623053908348, 0.15088948261524948, 0.08299204560795001, 0.11265037022531033, 0.15636682084628514, 0.1488244291394949, 0.12690816872886249, 0.07259216651852642, 0.10013661706554038, 0.1583254121776138, 0.09900368750095367, 0.10509514063596725, 0.21841025804834707, 0.1543902483369623, 0.1520600098052195, 0.09758149845791714, 0.1393012580062662, 0.19050724245607853, 0.10244609242571251, 0.11481256277433463, 0.06603856996766158, 0.13189165560262545, 0.07177131556506668, 0.09430563316813537, 0.08522848345871482, 0.0932500973077757, 0.11632047114627701, 0.10707672073372773, 0.14386885719639914, 0.18591464603585856, 0.14446123183837958, 0.08293825813702174, 0.15183924165155205, 0.1250057193849768, 0.20326547856841767, 0.10699882491358689, 0.11678543048245565, 0.09970573375799827, 0.21018262739692414, 0.11601731527064528, 0.14276318438351154, 0.0873359725145357, 0.15428701601922512, 0.08495872507670096, 0.2510970133755888, 0.10505833011120558, 0.10390433203428984, 0.12427695920424801, 0.09246136820209877], [0.011699791033087032, 0.053908073742474825, 0.0025220474469408926, 0.024582746970866407, 0.03213734212996704, 0.02731495812934424, 0.04033199258680854, 0.008709502472941364, 0.015730048163927028, 0.07979180983134679, 0.06627780784453664, 0.045376781706831286, 0.041124280608658276, 0.04481805900910071, 0.030261477788111994, 0.024314647606973137, 0.031274564497705014, 0.04162993168990527, 0.04711322067305446, 0.009666892483697405, 0.015427067011062588, 0.06822274026593991, 0.017605946432533007, 0.02893382902922375, 0.04350840499890702, 0.059922587791723866, 0.016060123220086098, 0.06795648312462227, 0.0071569498894470075, 0.07122888110045876, 0.03589552368170448, 0.04384054449786033, 0.03480651568887489, 0.028495651470231156, 0.011560760904103518, 0.07965378902320351, 0.06044301736567702, 0.05906647337334497, 0.08126925876630203, 0.03407134674489498, 0.037211138622037, 0.03607632951544864, 0.03045866684988141, 0.03778915885569794, 0.015727975239445056, 0.03594689896064145, 0.021784738271630237, 0.014991087905530418, 0.01934129126103861, 0.02264947008474597, 0.02037089012031044, 0.02353428823075124, 0.03690761633749519, 0.06221602258405515, 0.07149157593292849, 0.02454255734171186, 0.01632540496731443, 0.04238458815962076, 0.015017381137503045, 0.0007654381791196231, 0.08388461771288089, 0.021807194388072406, 0.051903219893574715, 0.03470539361504572, 0.015133766856576716, 0.05908118401254926, 0.029661530695323433, 0.02278097017136003, 0.03956664240519915, 0.05396201727645738, 0.026865623758307526, 0.07478494742619139, 0.06724516807922296, 0.05112669763288327, 0.05877905272479568, 0.04741944352697049, 0.04527189376364861, 0.030487918494535343, 0.014754859331463064, 0.007540220394730568, 0.023723433259874582, 0.031723025254905224, 0.023450835208807672, 0.04833391874230333, 0.05965928906308753, 0.02516957967808204, 0.02272680780983397, 0.02711928728967905, 0.01578440560427095, 0.052635043659912686, 0.05154080416208931, 0.0557767456131322, 0.051104892910059006, 0.015129291918128729, 0.04417793246518288, 0.006587083102203906, 0.011526205660110074, 0.010532397826734399, 0.020198431963633214, 0.037190989524658234, 0.04195155728874462, 0.042712330751653226, 0.05675258753555162, 0.013937483325467577, 0.0461532123652952, 0.009142773375580353, 0.0322787827546043, 0.058318531007639, 0.06591068647269692, 0.04292113294026681, 0.017668537895328233, 0.010345094172017915, 0.05388914600812963, 0.05449632289154189, 0.025357452454045415, 0.02907790576240846, 0.04717558482661843, 0.025047702914369956, 0.0655626862176827, 0.009437799553519912, 0.022554945067635605, 0.03251050246347274, 0.049906762915530374, 0.0349258462499295, 0.04528179358957069, 0.020927446594993983, 0.032408250628837516, 0.012849790842405387, 0.12342204579285213, 0.058600421595786295, 0.01253813037848366, 0.04951174357639892, 0.023792614994038428, 0.05378627670662744, 0.024015759716608694, 0.04313498682209423, 0.029901094269007444, 0.021657394212005392, 0.027887658648458973, 0.0481831754025604, 0.07002676132002048, 0.05337697420535343, 0.035414160761450014, 0.060926901043525765, 0.05221164120095117, 0.02726135725554611, 0.02492475406532841, 0.06987386702426843, 0.04663859899821026, 0.043484333969120464, 0.047876715061387846, 0.0333982637551214, 0.06181521873388972, 0.06540782417037658, 0.03758726754624929, 0.0203008279869599, 0.03817712821598564, 0.014065248924972755, 0.06276231791291918, 0.022540707706606815, 0.0239139455370605, 0.09493474369602543, 0.03472109830805233, 0.01590106782636472, 0.058212394560022016, 0.05002483479412539, 0.056749588410769186, 0.03159818498949919, 0.03909820557704993, 0.08467338074530874, 0.04408975683950952, 0.015229664210762297, 0.04070726655689733, 0.0049015465608265784, 0.008696558569291872, 0.022114662353747656, 0.031055187340825796, 0.032084141591829915, 0.024312605216567005, 0.03098920320293733, 0.014178247906134596, 0.026223386970481703, 0.023179763861532723, 0.025462085946596096, 0.017440433081771647, 0.044845166483095715, 0.043784765526652336, 0.07554323745093175, 0.011696284703378166, 0.031934137855257304, 0.06540219232972179, 0.047881987278482745, 0.03370868334812777, 0.020317759132012725, 0.028364400745236447, 0.00799656318434115, 0.00970056393582906, 0.07209647633135319, 0.010000762246948267, 0.04381337595571365, 0.02812201276953731, 0.01418868631922773, 0.10119230220360415, 0.04710911214351654, 0.0022302252265425132, 0.05695751189653363, 0.039410687916513, 0.02248279983177781, 0.0606569391010063, 0.04827874027458685, 0.0298099975500788, 0.04094662657007575, 0.025283125728102665, 0.009089053758153958, 0.019603020877444317, 0.018455144882734333, 0.01959676987358502, 0.0028320234476788236, 0.03131335973739624, 0.047944785694458654, 0.04044685838744044, 0.07675696018018893, 0.06392446519540888, 0.014889901370874472, 0.038507486560514996, 0.04417690787730472, 0.059099884437663217, 0.10001359188130923, 0.0036396995835405377, 0.025784866751304696, 0.03133962922064321, 0.022186875443107316, 0.025969699690384523, 0.03133966654006924, 0.055686283324445994, 0.02717439960023122, 0.04972486803308129, 0.013738425747890557, 0.04248288752777236, 0.04283266893721052, 0.03473972748698933, 0.02487287836681519, 0.04680626839399338, 0.05584224799115743, 0.04661908093839884, 0.11380983050912619, 0.03439118440396019, 0.009719983608062779, 0.03853266020970685, 0.05970872033919607, 0.04960872997928943, 0.011003573391852635, 0.01312377564941666, 0.01585670351050794, 0.023909892986661622, 0.004667203041857907, 0.08974560642881052, 0.04098183235951832, 0.037900886431868584, 0.05642350144418223, 0.07500367318945271, 0.021417793318895356, 0.015780546436352388, 0.008599626449202853, 0.03738152215789471, 0.07648158352822065, 0.0494816301922713, 0.07018903975508042, 0.01638002533997808, 0.014271077433867114, 0.02039022327932928, 0.03433366499042936, 0.032331606705806086, 0.05101722618564963, 0.027230438111083846, 0.07682336161711387, 0.01673805434256792, 0.10510160028934479, 0.025163367689986314, 0.02891996655879276, 0.020169460214674473, 0.046640271587031226, 0.04255021855767284, 0.06123461667448282, 0.02189003163948655, 0.0472325817681849, 0.041116708157850165, 0.03901684922831399, 0.07242320451353278, 0.056343749830765386, 0.009188747515768876, 0.03986955740089927, 0.012002407473378947, 0.06515827256121806, 0.06650578204010214, 0.029561772476881742, 0.032419918038483174, 0.017139999827902232, 0.028745715373328755, 0.013870461877169353, 0.016118370362424424, 0.013570770770976586, 0.045088529852884154, 0.029103157443127463, 0.05902545593146767, 0.05375061629872237, 0.019082345334546905, 0.01793776193101491, 0.06100761278399399, 0.025239619759044478, 0.036533960673425875, 0.032892103772610426, 0.005042644525279424, 0.0304377374372312, 0.012305442060876106, 0.018828875185655694, 0.03280605874689562, 0.026143061994974102, 0.020246275467798114, 0.04707723456834044, 0.040157307138932605, 0.010434668427998466, 0.05045734319303717, 0.0612296565834965, 0.05575241334736347, 0.04503645907555308, 0.024752207699098756, 0.009131547861865588, 0.03475252465744104, 0.0378755261855466, 0.044980177988431284, 0.04946128771241222, 0.06565869892282145, 0.049728352310402055, 0.0398413812342499, 0.06200064199843577, 0.027016986261254976, 0.0697393813835723, 0.07734516183180468, 0.03458805116159575, 0.022784973527970057, 0.015402931520449263, 0.03647497562425477, 0.02903342100658587, 0.12641366597797188, 0.03252295697374003, 0.038641517582748613, 0.03153625849102225, 0.05072579539514013, 0.022989029364128197, 0.04989543477339404, 0.05315753258764744, 0.08689962021474328, 0.13819870645446436, 0.1072556572034955, 0.09737790402557168, 0.14203698906515325, 0.08954881091735192, 0.08743842451700143, 0.12356056193155901, 0.11746543113674436, 0.11305047518440656, 0.12782947000648293, 0.18809146779988492, 0.10926376802048512, 0.19059177434870175, 0.1290325125945466, 0.12911376037767955, 0.0887872435684715, 0.10271244456193276, 0.1322522291115352, 0.1031494482553431, 0.12255058969770159, 0.17155962703483446, 0.120067137958748, 0.1308080894606454, 0.04650729229407651, 0.16294471573616776, 0.23228104731866292, 0.11421691759356431, 0.08947555627673864, 0.20808131300977298, 0.06678888042058263, 0.15529488479452475, 0.20600593223103456, 0.11123122101915733, 0.10035982794527497, 0.16654168415282453, 0.16106596083513328, 0.19143348346863473, 0.1673623586871794, 0.17249181201415403, 0.12520127317735127, 0.12373356121991362, 0.07037015432225806, 0.15540662594139576, 0.13652379704373224, 0.10293706679450614, 0.09071458157684122, 0.07505826811705317, 0.21799291829977716, 0.15165003894695214, 0.12990386012409413, 0.1189283254955496, 0.06294260466737406, 0.13574312893407686, 0.14445950835943222, 0.08158867912633078, 0.08885597238051039, 0.15845919214189053, 0.10339333409709589, 0.17476464648331913, 0.22473210096359253, 0.12944027142865316, 0.14441912195512227, 0.12788988676454338, 0.08338746867541756, 0.12850594227867468, 0.17530397325754166, 0.12001646496355534, 0.172984618427498, 0.2341017196221011, 0.08665207706923996, 0.10873261759323732, 0.1487992283489023, 0.1574767277176891, 0.15895488911441394, 0.05856312931116138, 0.12010010118995394, 0.10637924101735864, 0.21721784131867544, 0.10104567078607422, 0.12442923603313309, 0.09938657802662679, 0.09702561542923961, 0.1524060626647302, 0.13899708432810648, 0.088847334629723, 0.10686905509127037, 0.09871748143008777, 0.09199099415647131, 0.2367435550051076, 0.1553848178258964, 0.1475153315280165, 0.08686082836772714, 0.13800797026072228, 0.1530594104634864, 0.0763205603829452, 0.12878695077129773, 0.11312639646764312, 0.07767574409289019, 0.11153356943811689, 0.15666803611176355, 0.26115203382713453, 0.17596927684332642, 0.09273789836359875, 0.17145581117698125, 0.10341103029038225, 0.1196068740848984, 0.11718535902244703, 0.12158192667577948, 0.20210393518209457, 0.14701204853398459, 0.15055496485105582, 0.14126757106610707, 0.1381215298814433, 0.15384972734110697, 0.1372825349015849, 0.10122223238327674, 0.14486326383692877, 0.21178994114909852, 0.06939875001886062, 0.11063710254217897, 0.12659216139997753, 0.10071907831089837, 0.10510779531406504, 0.08725370014352457, 0.20344352615731104, 0.10214308582778488, 0.12505508959293365, 0.1856831434581961, 0.19012053177825042, 0.14134831673332623, 0.1624803670815059, 0.1377823030842202, 0.2098458026136671, 0.1565153385911669, 0.17435388852443012, 0.07570144467587982, 0.09852063842117786, 0.09610236675611564, 0.13724609757108347, 0.11504789228950228, 0.18802258292479174, 0.18552461053643907, 0.18060770151870592, 0.14500116929411888, 0.07798443681427411, 0.1503561676612922, 0.09327809366264514, 0.19380705324666841, 0.20888868825776236, 0.0872593659109303, 0.07460168868835483, 0.14688901656440326, 0.15019303427210876, 0.11399946069078785, 0.1273360936237233, 0.1980726636414017, 0.11593225412070751, 0.16721929636384758, 0.1285025631742818, 0.08276073980544295, 0.14982691034674644, 0.16460979995982988, 0.08866322772311312, 0.23500940948724747, 0.11282155103981495, 0.1626977968428816, 0.16363832780293056, 0.19034029570009026, 0.10717943057950054, 0.10835583388273205, 0.09217859551842723, 0.17263905411320074, 0.1010002496519259, 0.08237788320652076, 0.12291347022567477], [0.020143277244642377, 0.01140244850622756, 0.007168981163496417, 0.03553232763494764, 0.029163068692599024, 0.039578489626624754, 0.03191705234348774, 0.027184937249070833, 0.020454417781106064, 0.03537009669733899, 0.0493619942904583, 0.01157117132762713, 0.046919166443071196, 0.03352768413190331, 0.13524546420999936, 0.027966641820967197, 0.03557625938473003, 0.0586572489035981, 0.04540901551289218, 0.03425203722768596, 0.055563940067908595, 0.031231094151735306, 0.008548106133405651, 0.060072767947401316, 0.12224636173674039, 0.034904214553534985, 0.07863177279276506, 0.02651846149404134, 0.041082282683679035, 0.0314457656682602, 0.04376982079286661, 0.03143514320254326, 0.022764500430119888, 0.014551600773951836, 0.010901553107292523, 0.036731400793152194, 0.003448105467084263, 0.015387951163575053, 0.009311934700235724, 0.043065379307206185, 0.017098278405943086, 0.03906009905040264, 0.013841265363485684, 0.008757494406641593, 0.005792238699671413, 0.043191379867494106, 0.068272700799363, 0.05610177745776517, 0.06122686101921967, 0.032944293293569765, 0.03539131788004722, 0.03822517188798104, 0.028389759295220886, 0.049202558917126486, 0.03434904398662703, 0.01670408687953438, 0.012026778754911252, 0.039482785654919486, 0.028018666797184517, 0.0382027022008385, 0.02416620619728097, 0.056447630149445364, 0.05837167387029954, 0.08034054110092775, 0.02765538593355034, 0.094050083309412, 0.03049005927251918, 0.034030495544097254, 0.04298600767339979, 0.02861846630860652, 0.056497526222041676, 0.0442610089001911, 0.026197801111266017, 0.06806502837155547, 0.054026288113423755, 0.06406686255442244, 0.024720893307988132, 0.03451982446547065, 0.05261037551930972, 0.03768675095800843, 0.002615040247162272, 0.026476712930681448, 0.037763578085494895, 0.042063345933066945, 0.034101114076163085, 0.01843107894196042, 0.016978876598711525, 0.05605038182277765, 0.06146740846868072, 0.03627525901954089, 0.03627492993005684, 0.02500652940943837, 0.016410995374566743, 0.03260607751352446, 0.048590313377124925, 0.07162989529647998, 0.027764234824904373, 0.022810121732098714, 0.05258957502831306, 0.047537413625312705, 0.08339601143130235, 0.008765668209109987, 0.028501279918210845, 0.05154920442562018, 0.02964210763041462, 0.013578953055132712, 0.02788061206229031, 0.029045817841376578, 0.04552689400900688, 0.07477732069258179, 0.013150812725403478, 0.03067061404830643, 0.05887490936688014, 0.017729492392390966, 0.05300738975139601, 0.02286711528099009, 0.055297581146338155, 0.020752491429448128, 0.023385107217888747, 0.00728430412709713, 0.03580325648986867, 0.04125842358916998, 0.028674129928861345, 0.04225993449134486, 0.019740015401371887, 0.03768604188891394, 0.009763034958658474, 0.033119528354810815, 0.02525840839371085, 0.0170154869556427, 0.029091347541127886, 0.03515495699165123, 0.020367553424356238, 0.0600778976721423, 0.037010780801730495, 0.05812007987073489, 0.06504853309265204, 0.04855433066508599, 0.020251776690461805, 0.006001135883187609, 0.07648669968226127, 0.010264921018720737, 0.036543524624513726, 0.050434632625963004, 0.038780162643109045, 0.039709759011332474, 0.041979784345520396, 0.020110787291611944, 0.011034430619994444, 0.011385178941834186, 0.02535554577064301, 0.01878213769357119, 0.05499790615535208, 0.02381380394633327, 0.006019075924996287, 0.01794851671106049, 0.028915189672261477, 0.03936252550088933, 0.041183004421847205, 0.018505441290991645, 0.033126622438430786, 0.09157410902636391, 0.043241547354097874, 0.036339984474969764, 0.04052676945658667, 0.02426794743431466, 0.08023080841771194, 0.0127343050304002, 0.028383745778618113, 0.0064070949031572256, 0.003733456159742283, 0.01143270353454032, 0.04296668299606868, 0.08228220298354115, 0.05188516407672848, 0.05114244643066611, 0.015195418548371111, 0.0756285564441766, 0.022630661094029034, 0.06017039556588445, 0.015959778068853275, 0.02784770311388586, 0.01741209576305534, 0.019711270961644392, 0.01170433297686811, 0.018538111055802022, 0.05848276362355266, 0.04384598974138498, 0.027139670481639247, 0.041073862064097605, 0.03154651794050421, 0.030908518603869846, 0.04325079917907715, 0.03907781559973955, 0.03222329894612942, 0.009749605054301875, 0.004686939505128456, 0.038719871414027045, 0.07011768501251936, 0.04565842802237187, 0.04181249153667262, 0.0409200415680451, 0.07082478635545288, 0.02440953564031848, 0.03006632433139852, 0.02443244807156069, 0.05990913922765425, 0.023816969312195267, 0.05758769450975316, 0.055659067284848006, 0.021230515957410847, 0.04881627571636012, 0.022124222912160412, 0.044698402751237154, 0.01826364024808364, 0.017116473322468143, 0.01716170785948634, 0.03762279903250081, 0.04535331118053623, 0.028463644973401512, 0.011203836217256529, 0.017635077637221133, 0.030213488398918083, 0.04592246974685362, 0.04848092674676861, 0.07868641521781683, 0.02228127493123923, 0.008346836531667836, 0.024597045400046876, 0.07670370875192539, 0.029949996287801435, 0.06752533518842288, 0.044290375895798206, 0.03593056323006749, 0.015436488469796521, 0.03746582334861159, 0.042562801989593675, 0.020086412617404546, 0.06189445126801729, 0.10984109954110213, 0.06908813025802374, 0.04563032649457455, 0.042463986934827905, 0.049577120425445695, 0.02570540690794587, 0.0076102189154231125, 0.05226939470906343, 0.0582708367811782, 0.016547849102477943, 0.025542636534997394, 0.016552010218479803, 0.014188179962470062, 0.0147609661466309, 0.03295122792146035, 0.03978067609880652, 0.04127587890252471, 0.013955904703055109, 0.016314814732010876, 0.09956309891172818, 0.06044237954275949, 0.010822995715508503, 0.052140055756483755, 0.06582677883229085, 0.014186017980266894, 0.03810323914512992, 0.026798772791932737, 0.04003460086616022, 0.08819315223289387, 0.02037694604535188, 0.010951651044056883, 0.04375813302717038, 0.03204420302063227, 0.04171787661367229, 0.03112356670733009, 0.008250884894680763, 0.04265020747802087, 0.042697949201932976, 0.03937208605930209, 0.05894886968391282, 0.07420702558010817, 0.019562493677117994, 0.05210321469764624, 0.070982158982328, 0.01203836643669222, 0.024418351506548266, 0.07505474652030639, 0.059160226556871615, 0.019381265455324734, 0.03531876552317824, 0.03852929128333926, 0.06071978501443352, 0.025229496016566242, 0.03588023968040943, 0.054141079275203605, 0.08084834313818387, 0.03612592703263674, 0.09511927807969706, 0.055691463939313374, 0.029970063960977962, 0.03717096256358283, 0.015296734004680599, 0.03321744095800178, 0.030857774362500225, 0.013024962290988436, 0.08765238017908164, 0.03189513905506049, 0.07231919866587434, 0.010599202143826654, 0.005342294495286686, 0.0758324833586812, 0.02706779326711382, 0.04067993516634617, 0.04008625095177974, 0.055447710411889214, 0.10399368152554546, 0.03274886842284884, 0.0348455721645483, 0.009237384905905595, 0.01251410345347332, 0.021317470220050642, 0.022255784066926156, 0.009879702269764883, 0.0368041906372777, 0.09205072559416294, 0.034691850056073496, 0.10945461956518036, 0.06745717634579965, 0.01660119043663144, 0.04625133531434195, 0.04197734501212835, 0.054443953558802605, 0.018955840962007642, 0.013051989188949977, 0.0632873818810497, 0.03603074214022074, 0.024124289696503962, 0.059935452815677435, 0.030030321263309036, 0.07085767494780676, 0.01838414976373315, 0.034641706318195374, 0.014165828170787011, 0.03664649909894381, 0.08206180123878376, 0.020674437849915454, 0.02493528662515538, 0.018456595251336694, 0.04370566869952849, 0.042625770039324246, 0.03799239705715861, 0.005559164889356387, 0.035615516028233936, 0.06243165422763143, 0.16866859288087913, 0.045545859062778096, 0.19463783795280115, 0.06922245983566556, 0.10763685139162199, 0.1117745375792895, 0.14595464670232364, 0.1441511277641569, 0.10788187038685594, 0.08439633489719459, 0.13622748080108846, 0.11449276922004563, 0.10956795526934521, 0.19392400554248265, 0.0777822673054678, 0.15115176354135784, 0.16674333118966647, 0.0708245285121458, 0.08437053021043539, 0.14703541728002684, 0.1329333289925541, 0.1440092460917575, 0.10655673899288688, 0.18384975540850843, 0.12043688526110989, 0.18076882644423417, 0.0911471408658794, 0.25034400235329357, 0.13620006798633508, 0.11203740883086409, 0.10584729670413903, 0.1353046324636255, 0.09284524938889913, 0.08018278849444219, 0.22109121776052884, 0.06398955027439765, 0.06655252631753683, 0.0969292838126421, 0.08365479111671448, 0.13558147475123405, 0.09427184890955687, 0.1914573543305908, 0.050836308393627405, 0.13933848243738922, 0.09145778098276683, 0.18397039893482411, 0.11511494512004511, 0.13619449042848178, 0.13736461049744061, 0.1450990547559091, 0.11594871538025991, 0.12073446357888834, 0.13662556372582912, 0.0887952231402908, 0.1762289386242628, 0.1069369696612869, 0.10055085590907506, 0.15592782225991997, 0.21064244343766145, 0.09020060487091541, 0.07470368607235806, 0.14301479873912676, 0.17876879019396646, 0.11656133750719683, 0.23175624119383947, 0.05587865478758301, 0.1294439219470535, 0.10078098106064967, 0.11400336905249528, 0.09962823827351842, 0.10258327863578286, 0.091889539600483, 0.1614974005413907, 0.17650223895907402, 0.2096981941057103, 0.10669094643422536, 0.11284289775150162, 0.19308465772441455, 0.1893192090626274, 0.07531380440507617, 0.13610488309391908, 0.1669807777340923, 0.10073000951004879, 0.09979684065495219, 0.13591004854866437, 0.08370426310492413, 0.12665253744593688, 0.17980845512023994, 0.08161637014044182, 0.20715633407235146, 0.16774548670010908, 0.09470944292843342, 0.0833163649908134, 0.1419864110648632, 0.0884251229997192, 0.15616429171391896, 0.07503251092774527, 0.16650312979306492, 0.11107186028467757, 0.2011609479252781, 0.10246483356292758, 0.17900493395115646, 0.15647488433335507, 0.12417216625596796, 0.12840154288070543, 0.14247381633945874, 0.10490310165498938, 0.07208551120545183, 0.14559107406863145, 0.17627722317618982, 0.085695681960455, 0.11920010591191904, 0.15756355305867537, 0.1360835906650339, 0.08951274678111076, 0.13813108365450585, 0.18162566689508303, 0.11796439864805766, 0.11362321302294731, 0.21972572031830037, 0.13621351655040467, 0.11835466484938349, 0.08232912368008069, 0.1259302097771849, 0.10233111466680254, 0.1198755603815828, 0.18710567855409213, 0.10601239784487657, 0.12086521727698189, 0.13141144279922756, 0.1770628717328821, 0.06786060612648726, 0.21152706311217376, 0.09036559066069977, 0.21136397043509142, 0.18246443117303507, 0.11670909529285771, 0.17916174339396612, 0.14439780238483632, 0.10456247029027768, 0.10570353548973799, 0.12820749543607235, 0.1534296598817621, 0.07711685515408005, 0.12372661302132265, 0.08112674605633531, 0.1671535870326417, 0.06480329696621213, 0.12839049633060182, 0.23219305489744457, 0.08582201161022697, 0.14249573302056107, 0.09806303440460137, 0.11114428032721792, 0.11190210894814559, 0.1787705272436142, 0.18083591998687812, 0.1249588733272893, 0.19211773175214017, 0.21031937934458256, 0.15280213712581567, 0.17637293732592038, 0.11990674585103989, 0.12974882844303334, 0.09691727374281202, 0.13567037640937737, 0.14327143425387995, 0.1564709624009473, 0.07472519563244921, 0.04789378021710685, 0.11502577204789434, 0.10593910249216215, 0.15595324018171855, 0.09483649182532515, 0.09396437076585633], [0.019213231346969093, 0.010998631112410553, 0.03149665579465883, 0.009828837588429451, 0.02752571110613644, 0.031840700190514326, 0.023738662978368144, 0.02289870787145836, 0.08222887691642557, 0.024945030388023173, 0.041346304052110226, 0.039388499821403196, 0.03407959433804665, 0.04596847102844289, 0.016119752877524922, 0.02042148508397596, 0.012110275881631034, 0.03140128091243761, 0.04443083943000861, 0.03919106309435197, 0.04038917612550514, 0.05015132389962673, 0.0032873100551244405, 0.07051692144679171, 0.11721944862178393, 0.04182590278131621, 0.01688541009623025, 0.03760823088565043, 0.058046377397009304, 0.02942143107897469, 0.03785302257165313, 0.054935759132994075, 0.018833502794482877, 0.040640278187181265, 0.05023472263876881, 0.06164828554860183, 0.02138393951047744, 0.0450134058482945, 0.03880419974614467, 0.06366813502141408, 0.042892298594649346, 0.039086948681090555, 0.022902628107528602, 0.030927280097135475, 0.04878020140209368, 0.031719008327594826, 0.049558464105107954, 0.04012339056602546, 0.029248007706233432, 0.05100859522021242, 0.02368794078938663, 0.025110039926533188, 0.006871029227373323, 0.02268519495347781, 0.028897998987564018, 0.0662532313061612, 0.010352014381039356, 0.019659763368378793, 0.031601933895477226, 0.053715495326157124, 0.057908485510519574, 0.03159819856019957, 0.035087921124483855, 0.05106194842872875, 0.046905208977737596, 0.02567012987232634, 0.03691938552739365, 0.009504625074831503, 0.02212237729690969, 0.04440935701131821, 0.06075882113405636, 0.058045875281095505, 0.012419698028159993, 0.020256278770310537, 0.11946231898452554, 0.013505907064037663, 0.023490746638604572, 0.030144674770001854, 0.043524818761008124, 0.07857666217855044, 0.08163880250815835, 0.028659744986466, 0.014744313200935721, 0.03266248073694961, 0.07157675921916962, 0.02502121460357947, 0.03385306202939578, 0.038944357939596684, 0.02439370202565832, 0.04716889447133456, 0.051923871106867275, 0.05487343229885612, 0.054410332148628573, 0.03983281812231455, 0.056296415227864466, 0.050838795224470754, 0.014996869023889303, 0.07728482649794646, 0.024691829956801872, 0.07112222218087741, 0.013734638674317725, 0.08430698540593896, 0.046544465835073164, 0.01206533141833331, 0.06621965060808829, 0.013859023473092487, 0.0346516841756446, 0.04378602760178702, 0.027273579367569516, 0.05920490808784962, 0.023127467471307943, 0.0786712703162006, 0.04193933687305876, 0.03930803235354168, 0.06277413120759384, 0.024829849068607603, 0.04091820952349475, 0.03363921493291855, 0.04078372727547373, 0.04438477029491748, 0.007034299595813666, 0.042588206340691874, 0.030477184070540324, 0.015064678420977933, 0.030912369290100675, 0.044028220498668294, 0.020168661239690015, 0.058896154298314025, 0.041185026456202777, 0.006603783121266003, 0.04107822843694261, 0.07543273802314486, 0.03777921831767474, 0.025514171990965093, 0.05151418523330774, 0.05262145599616425, 0.021810140926390886, 0.027478347665497234, 0.05629461711006505, 0.02698737838571625, 0.02483967425567763, 0.06013087090104818, 0.037158813394073925, 0.026921589326645647, 0.012242853990755975, 0.030715383788836852, 0.014711728253002678, 0.021805331809446216, 0.03255204576998949, 0.05227009699280773, 0.05394128803163767, 0.018457813221695166, 0.0212762729663934, 0.038546749989369085, 0.010136246182290571, 0.0327988900244236, 0.03203341431383576, 0.00568128634975957, 0.047261901266340695, 0.057728239468165805, 0.04820198439327734, 0.03440905023100121, 0.012596387698847269, 0.04533858357795647, 0.020406465711338178, 0.043902206367680004, 0.0143521114784692, 0.029489925796432153, 0.013244308065623045, 0.030303513032517264, 0.04506043850311211, 0.027826293637709956, 0.00494819414702111, 0.005644031384560678, 0.012322363876072424, 0.02816622271867735, 0.038588673275496276, 0.019172951811924577, 0.02654360460915736, 0.036615788603999784, 0.0510259758947151, 0.022117003299561993, 0.0339038096634405, 0.0033628547514256623, 0.050070103257894516, 0.03466405386903456, 0.03386727733803647, 0.006609458218528224, 0.0034305653368522015, 0.03672388941049576, 0.05640541170058506, 0.029301595009331192, 0.01325032243039459, 0.03371009470096656, 0.07703316464487996, 0.012218522573156016, 0.07956620372299637, 0.02727476680385215, 0.02051176586454468, 0.00719890370965004, 0.032650416384318044, 0.03288702154532075, 0.04781638651287981, 0.018799640504377227, 0.09566412134362118, 0.03534920121143971, 0.010298163297453096, 0.0807538435661367, 0.039522778508918624, 0.017524700345737592, 0.04348197605993066, 0.027075582849127904, 0.008126244797105235, 0.0250279762050403, 0.0371191157028079, 0.041679485102317164, 0.015206773831908191, 0.03019484904195581, 0.04935616906732321, 0.023408984865194986, 0.04188477587220924, 0.005863553154215748, 0.0622218715559159, 0.07082288645740066, 0.013320334521787507, 0.016195124547396387, 0.012028795700254185, 0.038272604878459654, 0.019629459994445955, 0.028341800440102816, 0.01846046290094299, 0.10891545563936234, 0.024092084728181362, 0.05247374910062977, 0.055173694222633324, 0.0135278525828783, 0.07065094568367515, 0.07508171828729765, 0.03497338102066091, 0.05360107396596244, 0.03793346968346408, 0.04438354553920882, 0.06345945836177894, 0.06678183044173888, 0.024521977374596254, 0.06516001639621598, 0.03200525850323694, 0.03647805617323943, 0.006331247410603932, 0.05480529381228345, 0.04608203743451408, 0.01682378045682396, 0.009491925443788725, 0.015383391408249736, 0.044585542021585364, 0.026947892736643553, 0.014168974876935993, 0.033444183612508435, 0.03938071023938911, 0.07957159807639462, 0.09819239710590669, 0.017897512930046235, 0.017069898678788116, 0.02056353639013001, 0.06816271705819027, 0.0377374680579773, 0.044297069643757174, 0.05440110407237496, 0.026703440318150178, 0.038326429668813944, 0.03432759888736265, 0.029299952954586064, 0.007821934563773019, 0.028615338262170553, 0.04062521131709218, 0.05959976797125169, 0.04265967304153102, 0.003947075946988272, 0.03146493767521211, 0.02067291284246104, 0.04849332697423441, 0.012369982615512396, 0.04297969390505126, 0.06943849181490284, 0.02821047168358096, 0.023160585069230626, 0.04106377903372049, 0.04853539614539061, 0.043960095582796, 0.043977455901248116, 0.050800203545285125, 0.0503564687844898, 0.092571806561734, 0.037620274882231436, 0.048604922236076424, 0.06325084955564567, 0.04010562312656215, 0.04859507330028074, 0.010826409594821078, 0.012147462145159287, 0.028011932337124432, 0.0026033800469511853, 0.07068643306515046, 0.036419040589992485, 0.08848588581063918, 0.020627732588244335, 0.008987845171109905, 0.04252427137855973, 0.07253527814256293, 0.018287882607962404, 0.05415745911055377, 0.018491957103833556, 0.021507728046604564, 0.032763901366186995, 0.010257877825227166, 0.035125990331705124, 0.03723692973809583, 0.049554443785122464, 0.026678029181701795, 0.042293413409164975, 0.014051947094100927, 0.04236376391989844, 0.06376641403351511, 0.05791172890790871, 0.028001851003084863, 0.08500374587518827, 0.03957923262247017, 0.0879449373377221, 0.0403899496554264, 0.013445382588542998, 0.060232176179332395, 0.01114339571047042, 0.009434533255573894, 0.02914143699620451, 0.030024723349405185, 0.020708269605945264, 0.06608139231268849, 0.02358337345400027, 0.006559718633070588, 0.042952216629471095, 0.0701071677197303, 0.01668284534077559, 0.02075461863673159, 0.010554522309186203, 0.011064379459380038, 0.019734302136514868, 0.021101248251008134, 0.021247172295781117, 0.061124734713562896, 0.037529432613934786, 0.024826374969312122, 0.01196586581811841, 0.14342148548790387, 0.04817261400499514, 0.09339688478835992, 0.08465344538646084, 0.14924375021031924, 0.08643244206905365, 0.124185302693929, 0.0886477774807385, 0.17839296321783746, 0.09329019194202763, 0.11783034726977348, 0.07108982213373695, 0.07905899201120649, 0.10612597103629794, 0.12295719502227646, 0.11932992323168687, 0.08250006022197859, 0.13579720817506313, 0.20787182210811547, 0.10331494294639144, 0.19628640663410934, 0.10741537077618496, 0.05773201212286949, 0.13245720096996852, 0.25387238445026533, 0.10703944880515337, 0.17381747945078782, 0.2430452997131007, 0.21955512304391178, 0.10484548046120576, 0.12822397026632512, 0.14863844269088336, 0.1260773025985275, 0.08216160016932658, 0.1221890662397657, 0.0974325193092227, 0.09935472080750124, 0.10974736671362605, 0.11874847300350666, 0.24590179643460683, 0.07038605918309518, 0.19086582107203348, 0.13365132760788712, 0.12951979573283876, 0.1289599093475512, 0.06880573076861245, 0.08540071600249835, 0.15586735121905804, 0.07360168413392135, 0.10561721905001573, 0.1380345688334533, 0.12427257586802755, 0.11716104032737867, 0.13119865421737942, 0.06970012134739331, 0.1179013220327241, 0.06100132954972131, 0.09430572816303798, 0.11756999338311808, 0.09753534450594868, 0.14798871826912674, 0.11517380124756268, 0.13288983489785874, 0.16457998513111047, 0.1278630710606064, 0.07452401678477015, 0.10655654900308166, 0.20707888608532293, 0.1495158156113965, 0.19333180731960706, 0.13127686216362885, 0.12140877810972077, 0.11710542759725026, 0.12480183318257332, 0.1631392924381154, 0.0947000587891255, 0.13025479843573912, 0.09365913178771734, 0.1301991721349103, 0.19359658525458404, 0.09501381338174854, 0.1361516612981047, 0.1020309714866536, 0.19092313013970852, 0.15693866301860127, 0.07468805941087858, 0.22054273076355457, 0.08654178798730884, 0.10941071834947382, 0.11545780886496816, 0.14134292916527816, 0.08509251182632786, 0.19490177450435503, 0.12130611576139927, 0.1091822013258934, 0.13543253631464072, 0.09693449496158532, 0.08568050313208785, 0.12657853641680308, 0.185029252831425, 0.12213106506637164, 0.1882493764694248, 0.11187762740467276, 0.10498072606112276, 0.13558188187224524, 0.08907130546867847, 0.29351419157215525, 0.1516652245606695, 0.11121379623987845, 0.10307564400136471, 0.15814581752887794, 0.17004956092153276, 0.10317999590188265, 0.09833377666239228, 0.11092747481805937, 0.12658286547022207, 0.14145552526627267, 0.13113967595355852, 0.17514560318418912, 0.2277718564229352, 0.13881544050361427, 0.20291734939174993, 0.07595549497221198, 0.10528538828449589, 0.10763369620378528, 0.12383730922426496, 0.1877793145499059, 0.12085977542613234, 0.17858695637966904, 0.050831222773662636, 0.11571901770574705, 0.1582270110292094, 0.08657501584717206, 0.10768332425504923, 0.11225691490939685, 0.13177847596151487, 0.09590992743947677, 0.11948690909360137, 0.1593848496143307, 0.16194861275809153, 0.06469471779252801, 0.15674205071159772, 0.1585831062069961, 0.10256470713232245, 0.12590699030884675, 0.08467271578099046, 0.11802510039082595, 0.10429261691336121, 0.12115546741655894, 0.16139429035995687, 0.08551337317164455, 0.19899236357637815, 0.12128156636442457, 0.10751958018434898, 0.0952276944049767, 0.1551660309944834, 0.08473919185676745, 0.19134610172893318, 0.17971427445965155, 0.23412088145102772, 0.2638657124979155, 0.1219818823571716, 0.07909044210932084, 0.10750507989100047, 0.18334048773561204, 0.17225429761622632, 0.14743808710149356, 0.1437072301549571, 0.11185746134391852, 0.12097177441631045, 0.13645158734704765, 0.17581799067556858, 0.16859396759952816, 0.06193105144692319, 0.11476730448859078, 0.08910160205726113], [0.023585492179595997, 0.04295378065268908, 0.02732811831603093, 0.05464974644460848, 0.04426559579691716, 0.036997111713779826, 0.028662428592464755, 0.016642928821966052, 0.06531232036650181, 0.045676975777106624, 0.030308887029864957, 0.050419592897274663, 0.06598861621958868, 0.036524875089526176, 0.028897897207311223, 0.02366826157750828, 0.03805136514295425, 0.023319984819473963, 0.016969081945717335, 0.0608854154124856, 0.03235576594514506, 0.018308947727616345, 0.019399090570264628, 0.048091301761035404, 0.07629103053893362, 0.025459521084225605, 0.030787698658449308, 0.031600508971938064, 0.03093201627156564, 0.02430800983815321, 0.027321402515683855, 0.030910672952554057, 0.05690817900800279, 0.05176277671541486, 0.03350403718650341, 0.056336825380900075, 0.028212809236720204, 0.03043433797678777, 0.054951321333646774, 0.010434398710328554, 0.038697364407458475, 0.025833361649087498, 0.05703343317977019, 0.05631980432995728, 0.06572843875203814, 0.030816889234951565, 0.023798860908885087, 0.058723562130970616, 0.025311810796016028, 0.013037365062960556, 0.02022696266482983, 0.05500196718743869, 0.038547479414514134, 0.01319845182089401, 0.05204034164281828, 0.03193946774782879, 0.04161778252039637, 0.022419321184445704, 0.03805773997945445, 0.08451127194400344, 0.00776139397307166, 0.04116329297955547, 0.04246535757556558, 0.07074860044355903, 0.015298616939357348, 0.03424424425299678, 0.05306300926687462, 0.03449729710285153, 0.025539182791752473, 0.06757613031991891, 0.06476689356246165, 0.06292469134288174, 0.04486519683684621, 0.01306089326473219, 0.021724223125992075, 0.05294782116210886, 0.034327948332897255, 0.0284599367795246, 0.0721444148304207, 0.03617380107087748, 0.06056710106453725, 0.028688131498971155, 0.028223031366776143, 0.01201184674365712, 0.038341360831899304, 0.02771835567961846, 0.029635050866220678, 0.03097326441534928, 0.026529440190643072, 0.03896294640643256, 0.05195757054856845, 0.052863611573619504, 0.07893962413072586, 0.07490616092192275, 0.03182126694758024, 0.016551618364506533, 0.03881994175857731, 0.026885367431012646, 0.03663026175594755, 0.05665571309093918, 0.05311504611745477, 0.04816069893006768, 0.03566500158714397, 0.03475603946883764, 0.015082583263782518, 0.03231997661558645, 0.06528849700199706, 0.038507520487265925, 0.012752850240628635, 0.014703151570366961, 0.007227218127809465, 0.11041528265923262, 0.05966786574572325, 0.015904178909425224, 0.04698092670046857, 0.06853685448212282, 0.030742579472384284, 0.05270600485216294, 0.023175083666241596, 0.01639214058273605, 0.012873911065980792, 0.005446697285931025, 0.022238269381757294, 0.014550050321434225, 0.05582465697079897, 0.03848526453865426, 0.0598319015864815, 0.023225827907611216, 0.022989263458709632, 0.01729567950990583, 0.05307187432689326, 0.021219440569568957, 0.023091360926628113, 0.04907727421128324, 0.02759758323164923, 0.02754257948670004, 0.10040734575263091, 0.023891721818862215, 0.027833253710663745, 0.06612735627485172, 0.04002963738249881, 0.03018174653074571, 0.050605172224875004, 0.026629814179614186, 0.07446082481848341, 0.06655904025371585, 0.015198916396392243, 0.005214964430446604, 0.03403027841289129, 0.07191650170300688, 0.01925891202076205, 0.05678021748151098, 0.024761769953849058, 0.019815556704998016, 0.022126049867698123, 0.047491578584803004, 0.04618639612038221, 0.05417887706841741, 0.032319572887250354, 0.04981910976182137, 0.01746423609022583, 0.05674469278060964, 0.04258566861972213, 0.009858984051139226, 0.040358570803489, 0.0061643752934677255, 0.0781418772946511, 0.024620420931439315, 0.008606568710612399, 0.015792390265102898, 0.04369465607617583, 0.041065499119992764, 0.07698104637009756, 0.02889836878914918, 0.004802054243295321, 0.007978186759698604, 0.041074482923639674, 0.0464558898737388, 0.021329129148008566, 0.03485121079055326, 0.07576770362045084, 0.029221344672675644, 0.05232666984998754, 0.01606104093869882, 0.009659912902861834, 0.03501957907740559, 0.10017065916742597, 0.04666375907670174, 0.03440480599445956, 0.04129600425117782, 0.048278977761843374, 0.011215118558279105, 0.013185457027118121, 0.046284936368465424, 0.03283461489315544, 0.019970895423154746, 0.05919283016451767, 0.029375521399612938, 0.04350377739007984, 0.07208850354488407, 0.027248953635405217, 0.014693183890943016, 0.014782348481406058, 0.0156960993606065, 0.05816948400544269, 0.013029728999494441, 0.021960975868361335, 0.02401456719131342, 0.05451233631798199, 0.012087612812008177, 0.022316685977524946, 0.0168803397433034, 0.034691324191434045, 0.02925238086442862, 0.012314967844369156, 0.06738224572369031, 0.05819604865142277, 0.02220286342448422, 0.10032564335103546, 0.09444460392530475, 0.13488981686532497, 0.07133018637874297, 0.01797597871960274, 0.017170917276026945, 0.006875884145431752, 0.036886941375476975, 0.029341560721929585, 0.029182970124695982, 0.03449570933090789, 0.03516697723950658, 0.0278421374303954, 0.018412239417167645, 0.005083748904455985, 0.03491505754313298, 0.04972112251977835, 0.006753165574212159, 0.003647484500626368, 0.0720777487648385, 0.07477272701050554, 0.06385168552930866, 0.016442827148629085, 0.06953665547605072, 0.06468605290033988, 0.06192490391965423, 0.05876561773142644, 0.05134720115789345, 0.06191535014659166, 0.03835545061156154, 0.07111465651541948, 0.015369147261870759, 0.03164502765451159, 0.019008902400465946, 0.054746006815029044, 0.08702291681298188, 0.02416449459269643, 0.05164027739582317, 0.014154304101664041, 0.05536334136767047, 0.04069284429507596, 0.030588053299912384, 0.022880847133429985, 0.007768123344119106, 0.010032325999678245, 0.009610279762585248, 0.010594396419557077, 0.0256376178669078, 0.031966653253350935, 0.049720623796539645, 0.06717909233910696, 0.0929296523598688, 0.031694163767887015, 0.02083003950039191, 0.030077794965888773, 0.02027247879388077, 0.0034363229185276267, 0.03150069986336997, 0.05087710191894855, 0.011269738082773983, 0.011721964709327688, 0.08726332177008901, 0.02338671704222049, 0.027063649114487425, 0.03845232844884906, 0.050168205850890706, 0.02840497374667653, 0.06422340058322464, 0.01823490429004388, 0.026907418122781173, 0.015364584113870348, 0.005818948382511735, 0.06466768495738506, 0.02529032159197543, 0.007962577061594596, 0.08033169978963477, 0.01263533391258014, 0.03882926822240863, 0.00984143459105066, 0.04665424940841539, 0.055092059674539735, 0.011186595490601445, 0.0482000980659255, 0.042390209822250266, 0.047717059164174964, 0.05712165630289486, 0.05207765767616885, 0.008963230465139662, 0.12704414714659962, 0.025967584357463887, 0.03197311629940357, 0.04963882300736649, 0.019700066652148962, 0.040954958980104754, 0.02152716807488884, 0.014404424832069447, 0.019180425875154988, 0.005234492244198918, 0.04900652675756386, 0.02651358113091971, 0.010327767780316728, 0.03355100877316935, 0.06270814367703029, 0.035375850674297125, 0.05258303055805819, 0.058828524713005335, 0.03231902327388525, 0.08098586183041334, 0.010907825315371156, 0.06491463777742215, 0.02824798958109958, 0.04863155134288328, 0.01622755852128778, 0.021013873296656778, 0.027073835621454885, 0.019941898229132806, 0.021242341126448343, 0.06728795649749891, 0.03353810982246484, 0.06707865558564663, 0.04484725637095315, 0.058497209634099684, 0.009074813852618848, 0.039014613455427546, 0.08319269519831453, 0.05103421670251659, 0.010656186362861522, 0.02409094139667494, 0.08658390465591635, 0.016327033451359187, 0.09125022390591246, 0.09175005994204964, 0.039976158645004034, 0.04382877530796187, 0.08317706175148487, 0.14388753048011235, 0.1267814455287797, 0.18382403893130167, 0.12675803607063635, 0.07981533464044333, 0.12530987949243613, 0.13412282802164555, 0.11012187733181886, 0.14761420765093394, 0.21311254160744802, 0.1745399156851428, 0.11220280174165964, 0.13718071393668652, 0.12354325928858348, 0.07110650052449533, 0.07940050547144242, 0.13254475912877492, 0.14492351774658474, 0.09907392266073398, 0.1128068675420114, 0.13947348376469954, 0.11296483727970294, 0.20186989488346235, 0.1055810327774712, 0.07348328655851738, 0.12506701823856148, 0.11371425885174956, 0.1256723664700985, 0.16516048541026457, 0.17812695034912654, 0.17124811160777295, 0.13949730034385407, 0.12715408339032105, 0.13034720133457864, 0.10340009909123182, 0.07357942139995949, 0.08662406714367014, 0.12197950748460633, 0.10045718414975063, 0.14309129677712917, 0.08207379095256329, 0.1376162248530558, 0.2319244635956628, 0.21997998096048832, 0.15157605148851871, 0.08767969121358224, 0.1277509227927242, 0.17466202484709875, 0.08655010682663747, 0.13128625308828695, 0.11171824631414243, 0.09800194589687244, 0.10932639680270638, 0.16808942253036158, 0.1234559996851853, 0.1339264599872487, 0.10407089202531747, 0.08040749893656798, 0.09421709113355194, 0.0830607269225376, 0.16108685971370765, 0.14798592270484992, 0.17164508173508303, 0.1407210518206869, 0.11903678253293037, 0.14853439613112382, 0.10625208355486393, 0.11913644575646945, 0.23447404535753386, 0.1949602642229625, 0.1461496576666832, 0.13405338674783707, 0.07740086277148553, 0.12890698361609662, 0.23236903973988124, 0.19615402445197105, 0.13256607869906084, 0.11355937644839287, 0.0955159632222993, 0.11957954269434724, 0.10062100285930292, 0.08285517830933843, 0.13010965979525022, 0.11653967866940157, 0.12113513850740024, 0.11958487597959382, 0.11722160636314324, 0.10829890479466744, 0.14680558389851026, 0.12282680773309299, 0.12742331251502037, 0.16351779284221785, 0.3008634586419378, 0.09515056532940694, 0.14999091226075376, 0.09281002663608108, 0.15629562895212853, 0.12097603561622755, 0.14555839582213334, 0.1367970159543412, 0.17448840130652699, 0.07199412610914026, 0.15143859386444092, 0.09002910514495202, 0.06702684265162263, 0.15044776988880976, 0.08920149598270655, 0.10683739464730024, 0.18850694836250373, 0.12109952898962156, 0.1778411513992718, 0.1634380514068263, 0.06935863502855812, 0.13067011614995344, 0.07557753061077424, 0.2180078596408878, 0.207869040114539, 0.057651293597051075, 0.09350951481610537, 0.08899607629116092, 0.15733181977910654, 0.08413296831505639, 0.08670467031853539, 0.10856278027806963, 0.11154207148190055, 0.116883356656347, 0.1553688993943589, 0.139685593811529, 0.0849361570019807, 0.19592424535325595, 0.2122478030089821, 0.08069023090813841, 0.19041492098144122, 0.123306043446064, 0.09310145742659058, 0.1916649860462972, 0.11133516579866409, 0.1283227378236396, 0.13555342411356314, 0.14893231620746, 0.1633601420159851, 0.07253948505967855, 0.10830861463078431, 0.12470846676400729, 0.11223007206405912, 0.11613343975373677, 0.09746502792196614, 0.1597620743725981, 0.18869362691683428, 0.1260951752109187, 0.15280767397156783, 0.0873707135074905, 0.09863832353481225, 0.12347811992679324, 0.09161831558282886, 0.1753570075545992, 0.11340286556099143, 0.13479380416018621, 0.27856747646416935, 0.20912614837288857, 0.13058711774647236, 0.11963169489588056, 0.13152220685567173, 0.059154601501567025, 0.09009213426283427, 0.21800937955932959, 0.13001443419073308, 0.09995111916214228, 0.0996919527117695, 0.10733502544462681, 0.09559753670224122, 0.20731055151138986, 0.0977470406464168, 0.09163919410535268, 0.11728023178875446], [0.059660266153514385, 0.09205565175839833, 0.05778767235044922, 0.021659806403996687, 0.05137864447065762, 0.03599092909800155, 0.011969914975842195, 0.025925605092197657, 0.03400446015543171, 0.017102005259533013, 0.03689072760088103, 0.020993585099599192, 0.04156872783122318, 0.04198707520429577, 0.05314492540700095, 0.04887767635019762, 0.05297232306163226, 0.010953879183424371, 0.036664822937122414, 0.01973046502098441, 0.03997203654476574, 0.027071969650153602, 0.04332005724843059, 0.01266621149677251, 0.02439146625277187, 0.03383398501734648, 0.04084192183134811, 0.028375900217464993, 0.05109968515379088, 0.018638345945094312, 0.07320503291807004, 0.04022627343822803, 0.028519905704472746, 0.07763032295874187, 0.01963513933255204, 0.01362437249294349, 0.012282154739036091, 0.05907231555985553, 0.041740936626281054, 0.11344776422317539, 0.03679814828293664, 0.008928979713735836, 0.05471852614677378, 0.01976020012183913, 0.09180792540843997, 0.05191239368702684, 0.01632265011513872, 0.06145919819495507, 0.04691288999414869, 0.0360566180731569, 0.04609001361365829, 0.02360493390421782, 0.04202793997579387, 0.03173825158072369, 0.051135420200548, 0.0229492926570986, 0.045083121928785524, 0.06538172092820917, 0.06315380547727857, 0.04188501335946577, 0.028967742209455798, 0.05164321545245392, 0.04256915307736822, 0.010951326195416706, 0.008312315214425325, 0.034618513991257975, 0.09199941477605275, 0.036116261301296096, 0.007985421639334942, 0.010832739478376294, 0.02876520629173943, 0.037642741176698885, 0.024770877590136867, 0.04763672061796699, 0.018233129920970117, 0.03538055631465145, 0.06596905405500106, 0.043602887607578716, 0.02968794945627451, 0.05684614394392286, 0.06217431303645883, 0.020316844806075096, 0.06454381838973079, 0.03447766029941184, 0.0696488715974348, 0.018537839641794562, 0.009555315033399632, 0.05370382113116128, 0.05157975885750992, 0.015434552948655826, 0.011210514698177576, 0.05055590379717095, 0.014522031914176685, 0.024533047673425505, 0.043354710031832965, 0.012466763761559767, 0.05818338040262461, 0.020152149090011204, 0.08191970243517842, 0.05002059055758374, 0.04385270384539451, 0.01673715528366821, 0.029300936830363104, 0.049889925069042614, 0.10226213479680674, 0.04542774647208197, 0.02011847000436059, 0.029223295460854257, 0.03777127606528146, 0.02640502909863634, 0.025356456703905548, 0.03256083279848099, 0.061395185201295784, 0.025265862100890706, 0.02311996287400169, 0.038053278611706834, 0.03413265238382986, 0.025810671438063894, 0.005155709239521197, 0.043681421250637086, 0.045729172083416154, 0.050092868107770167, 0.009294086684738951, 0.014356186081256186, 0.016222522095111862, 0.04977578530088067, 0.05178355345768588, 0.002996047626116446, 0.011298455381100731, 0.03363929296444569, 0.06687135635209934, 0.02258805079119546, 0.021528436935373714, 0.02918453754058906, 0.01169551965514464, 0.07453065285725252, 0.05956226534077099, 0.03832462137298925, 0.020034896542451212, 0.011078185102503215, 0.01884419989905187, 0.022184872068464756, 0.08555692154914141, 0.07590423165155308, 0.031049379081066166, 0.03259026764758995, 0.03728360616202865, 0.022388150982026542, 0.035809007074151716, 0.005770161290586526, 0.026649084574143802, 0.03274778615949409, 0.02406544205067413, 0.04310793363090072, 0.03522935157109584, 0.05995407860193934, 0.0190747915434518, 0.024669456960899488, 0.041005357168614864, 0.01982009780061032, 0.030113787855952978, 0.029994647284703593, 0.015107341310275453, 0.03116888945390071, 0.05520529020577669, 0.03760210371443203, 0.02651750136698995, 0.014971018536016345, 0.02644723736947136, 0.08341226913034916, 0.051676277071237564, 0.02682458426404212, 0.07287771441042423, 0.020657428673335483, 0.022057164992604936, 0.03783641542707171, 0.046463092522961755, 0.045555361945714266, 0.04985111625865102, 0.03501818808061736, 0.02523066140046077, 0.06059186080736773, 0.06831007450819016, 0.02669671773245292, 0.0049284882178264, 0.09314594896776335, 0.07852925293679748, 0.01462275195600731, 0.031458223571202586, 0.003878283522291375, 0.04515202037457909, 0.06126504218471902, 0.0726816381460854, 0.03383252616705639, 0.01503429701551795, 0.03405408820669566, 0.045435929604406865, 0.06684298680296966, 0.0684689466974565, 0.01786018332599529, 0.02669946919195354, 0.038927855967943154, 0.061765672106828005, 0.025108645537069867, 0.05982931636806045, 0.03691660014114209, 0.01804087889779891, 0.01864018986400749, 0.020717731776780317, 0.09238841890224389, 0.061634870911283154, 0.03571957615869386, 0.038149494877351184, 0.054480078763195446, 0.013708211431678916, 0.024499853740313222, 0.0748338426596352, 0.045370942912995815, 0.009958905966154166, 0.09370360975818974, 0.03846502383904798, 0.08867539385599749, 0.004466088655005608, 0.05653296610606568, 0.05833482263343675, 0.0431669322507722, 0.07186335884034634, 0.04879257109548364, 0.014450639852189591, 0.015056575016517724, 0.0753150936216116, 0.05491622071713209, 0.05375709291547537, 0.022732902750638977, 0.02306541205117745, 0.04122170805931091, 0.07874613308480807, 0.06371826518859182, 0.02394285112885492, 0.04873066156038216, 0.08745288409824882, 0.03502765025145241, 0.10777528610612665, 0.026149542004402195, 0.03761904673384769, 0.02514980886397617, 0.008749573358467646, 0.06510793204818453, 0.007425494541946266, 0.031689312242503674, 0.03791312381092991, 0.020480999390461614, 0.02463023254780897, 0.04710744973272085, 0.024317845203248516, 0.05281729816592165, 0.06205440911331347, 0.0469327167873936, 0.039222564082592726, 0.051044184381940534, 0.03988531976938248, 0.021521880590756024, 0.03145675115021212, 0.03128824715635606, 0.020255880130987083, 0.03220131441152521, 0.04371200282392757, 0.03450560576415487, 0.0157496408625905, 0.004216087516397238, 0.00394713447063363, 0.03870863487411823, 0.05885327088513544, 0.054765609691717794, 0.04742886498570442, 0.03351966384798288, 0.05184010595881513, 0.03094039617904595, 0.015150124639538782, 0.05829043287251677, 0.03811560205316969, 0.07606752110379082, 0.0291227671051664, 0.0784278323075601, 0.029617680369743278, 0.09561507683247328, 0.06309110205620527, 0.058671565992491584, 0.04808441463059612, 0.01978200993367604, 0.023126400474991118, 0.031296789912240844, 0.03181098374937262, 0.044885050771491866, 0.02368236323153334, 0.0382196180788534, 0.08962094597518444, 0.010444670882342117, 0.03615001841847386, 0.016080282495490143, 0.03128641511180571, 0.03896793024614453, 0.013032706071888762, 0.04320574784651399, 0.028743014803954532, 0.10265786999038287, 0.06639252097478934, 0.05474869720637798, 0.03059126277055059, 0.07125493684517485, 0.010679196333512664, 0.013146474342127996, 0.034665041137486696, 0.044138017642710886, 0.019644425084282244, 0.029479167623711482, 0.006449497404641339, 0.004364747329548533, 0.09170205358948026, 0.030310719074415307, 0.009771407232619822, 0.041263298863278966, 0.01981626238141741, 0.01558171192716275, 0.020004571116130267, 0.04029376392385789, 0.03152297956070729, 0.05752946263445275, 0.05294225038960576, 0.08532556824918304, 0.05050676768379552, 0.030079094360449483, 0.02787907687681062, 0.02422099281102419, 0.06850765712027039, 0.03190544939466885, 0.029557758942246437, 0.01144910033326596, 0.06098908877798489, 0.048435990765158615, 0.0067158554780430025, 0.026468713002811586, 0.029365316232932464, 0.036271988480751, 0.023250906561900462, 0.003157897523903687, 0.06333543573107038, 0.005046602080775691, 0.06055341501321111, 0.0368718677200377, 0.028718115961445228, 0.030348425265401602, 0.16012502275407314, 0.21064507615353378, 0.09209704239453588, 0.0774488216266036, 0.13321796086217674, 0.13363701051899365, 0.15374785209340708, 0.14189309892909868, 0.07312285554196153, 0.15795935610575335, 0.13193968231124537, 0.10340455706630435, 0.13871550586606773, 0.12992675389562333, 0.14620655961334705, 0.1290590568844761, 0.1320492657167571, 0.1302080609436546, 0.14562466155205453, 0.18940927780100278, 0.1557279529848269, 0.25128863166485516, 0.08870685752481222, 0.1044962452724576, 0.11959616680230413, 0.12008140076483999, 0.14326998218894005, 0.10760952678642102, 0.14104009898645536, 0.12840520696980612, 0.12795634248426982, 0.1382894537278584, 0.11945860061262335, 0.1807769010109561, 0.17291365723524774, 0.07568689688508, 0.19680000336042472, 0.1468805620180709, 0.17634788581303187, 0.20467666855880193, 0.15136888117662498, 0.12750263325870037, 0.13320996771965707, 0.1893752831965685, 0.13955925059105667, 0.3218069848205362, 0.1528311919953142, 0.16694868302771024, 0.21873197864208901, 0.12582614964672498, 0.16447426937520504, 0.17670400813221931, 0.09939536505511828, 0.13662591656403883, 0.1509859295828002, 0.17314825393259525, 0.1110177810436913, 0.1802973396011761, 0.15893000044992991, 0.1948569504810231, 0.1244453444544758, 0.15303951581673964, 0.12677681791995252, 0.13594212968434605, 0.12313912383147649, 0.14549166868839944, 0.18625136225351266, 0.09919759923858301, 0.14305324453328336, 0.1274767675037895, 0.10390392491327864, 0.14677555193858488, 0.11576119544250624, 0.15612940144326004, 0.10986163201076643, 0.14371970162859984, 0.13310997879930905, 0.1173477324524096, 0.13714920277042048, 0.13954471637095722, 0.11555042889501367, 0.1439692803791591, 0.08182782879365341, 0.16491906265062944, 0.13574649446776935, 0.0985303618279951, 0.14073204408798898, 0.09823208461914744, 0.09013054613023996, 0.1208488510123321, 0.14035658352077007, 0.14033225125500134, 0.07221462963415043, 0.13594679800527437, 0.1100482562822955, 0.09056400787085295, 0.22859255809869083, 0.1611397990158626, 0.11202480843556778, 0.06937783756958586, 0.1851379405707121, 0.11342480938349452, 0.08142784597086054, 0.16414807045034, 0.17340362737221376, 0.22463610182915414, 0.10077858583203383, 0.16530741538320268, 0.10155564413539, 0.2758679927459785, 0.13485187318708214, 0.1936040898518903, 0.13864100272102015, 0.16846997211022036, 0.08476859956447567, 0.09883456943290574, 0.19122358544596604, 0.12908492263938698, 0.09181808307766914, 0.12006901071539947, 0.1446002908051014, 0.14860214106738567, 0.07212958884026323, 0.20141037739813328, 0.11229240907622234, 0.1644457166216203, 0.10922643502375909, 0.09590500806059156, 0.08485788120222942, 0.17890208161302976, 0.21756759897938796, 0.1502366912152086, 0.08771217268492494, 0.1443620300186532, 0.09599350938307387, 0.2394121518092496, 0.1263174768537283, 0.1275280240390982, 0.09025898602391992, 0.06984161625483207, 0.11998217180371284, 0.257877668099744, 0.26691971719264984, 0.11226657046271221, 0.13304113463631698, 0.21463828187968048, 0.10577423883868114, 0.14686899978135312, 0.16117057736430848, 0.1566263469202178, 0.14621652050742082, 0.12635673688990728, 0.14752006770244666, 0.1381495398070131, 0.10739006820533957, 0.1256089505872556, 0.1255795428795474, 0.0872139244207314, 0.22488220648041793, 0.12371590573872839, 0.08419717808387109, 0.12952018928314957, 0.06972777843475342, 0.22630873136222363, 0.11796134524047375, 0.1931855965937887, 0.0626409687101841, 0.1284982341208628, 0.1405689242695059, 0.13261201551982335, 0.1283248412821974, 0.08916314518345253, 0.1770193912088871, 0.05197390627914241, 0.11428345473749296, 0.10061810551477329], [0.1087825306292091, 0.032553528369005234, 0.023160659708082676, 0.07241547599967037, 0.01324561339736517, 0.02308103023096919, 0.08394242211111955, 0.048294997973633666, 0.08179475021149431, 0.05242937630308526, 0.018149159516074827, 0.009531675721518695, 0.06164280977100134, 0.0625553240201303, 0.023117761027866175, 0.048019227771354575, 0.020712361172107712, 0.03741953708231449, 0.016072048473038843, 0.03620696446991392, 0.017465666102777635, 0.02504357911779412, 0.06790282457534756, 0.016010237325515066, 0.0656920624896884, 0.013629495432334287, 0.023977003492681042, 0.018596215705786432, 0.03771954116278461, 0.013709345433328832, 0.03685878895755325, 0.06374589513455119, 0.024413457572726265, 0.01948493712448648, 0.023650114158434526, 0.018362382360334908, 0.023363816485341107, 0.006952511529172105, 0.05193459535283702, 0.04415583936497569, 0.07547767061207976, 0.07045811281672545, 0.0311339041883392, 0.04393261491454073, 0.013112471256005977, 0.021656016785917536, 0.036463023229901276, 0.08175658261669533, 0.030178082441645007, 0.06301585252263717, 0.02570632632289614, 0.015970814440931593, 0.04877151954653008, 0.04282368513356362, 0.009849093555073653, 0.07387237889426095, 0.047763552383652756, 0.03267957981941955, 0.03207410266622901, 0.03065539790051324, 0.030639683029481342, 0.01842755395253854, 0.0495627083416496, 0.04207725250827415, 0.022438172583601305, 0.040671148137854676, 0.03529089130461216, 0.027308584989181588, 0.03813931006672127, 0.02060597197019628, 0.05665650358423591, 0.03794231438743217, 0.033170788282794614, 0.03885854022311313, 0.021221248865393654, 0.009263480514554041, 0.01482854484181319, 0.05292829631694725, 0.035706639888563325, 0.03415437907512699, 0.044812986959836314, 0.023245846386998892, 0.05580578012658017, 0.0330088389372187, 0.016515527086864625, 0.02001603157259524, 0.02755728842956679, 0.03728867821129305, 0.013305381306314042, 0.010497858697947646, 0.009193360705726912, 0.05850969467844282, 0.0384959853919489, 0.008422505060609962, 0.027725342893972993, 0.0654838200924652, 0.05630611827863114, 0.04705656299899731, 0.030037527305207083, 0.04239816903801901, 0.013647657270277185, 0.020029985645253743, 0.02860967249476484, 0.05413461283647588, 0.06138159414487226, 0.02818282477424613, 0.03294365207797714, 0.01814265745425863, 0.03933069881583963, 0.06529493629932404, 0.08303972626371042, 0.026431819357510124, 0.01724489964544773, 0.050579394679516554, 0.03270761688639011, 0.01622997919496681, 0.07558988673346383, 0.06423653702118567, 0.026946099707856774, 0.057042701968124936, 0.03737312189436384, 0.028399284230545163, 0.021256707409130673, 0.022215209369148527, 0.05162539712286421, 0.009911188839136489, 0.03512397847537484, 0.045885995096926174, 0.05424741589065109, 0.01612990545774145, 0.058000175947589536, 0.02893724206036755, 0.02078354628091412, 0.059646790448044024, 0.04043547256982752, 0.05545002082362771, 0.06827392216239657, 0.04937922568725688, 0.01347517451670553, 0.019196714108277644, 0.05395180871710181, 0.022675222185041224, 0.0038634236053829746, 0.010076851467601955, 0.05192428840590375, 0.016404094673427086, 0.014577050926163793, 0.0468424003837364, 0.004007104243750551, 0.03906797684196915, 0.07777364991073098, 0.03299405026648726, 0.011312295799143612, 0.06364366026329142, 0.08145128257040467, 0.03500416615445699, 0.046714893475707085, 0.02613476351169603, 0.028670560834663253, 0.016997497295960784, 0.02082162057714803, 0.021760987849639993, 0.012764431137059416, 0.05182523925655654, 0.018374338147363493, 0.017641633981838822, 0.059797411651483605, 0.01955022237130574, 0.05814232224864619, 0.04802109034998076, 0.029815215484372208, 0.0245138722737985, 0.02278577589562961, 0.029817997477948666, 0.03261370085445898, 0.050490157146539004, 0.06068513223103114, 0.028472337006990398, 0.07315011229366064, 0.0030551772880634026, 0.0207381471991539, 0.06139711902609893, 0.04519539911832128, 0.0092384620802477, 0.04346943673278604, 0.0033222278912684745, 0.020922167592548897, 0.04432236882192748, 0.06609545834362507, 0.014951239240222743, 0.12297379198883261, 0.028247268637642264, 0.025670603150501847, 0.07155298335211617, 0.03461648517155221, 0.026882571866735816, 0.017502630994256054, 0.03430739550718239, 0.0716416339523026, 0.02445174051847841, 0.010640556308706956, 0.08757177021886621, 0.019642783029537116, 0.032476307691207955, 0.028227833698370626, 0.034696073936564584, 0.02939834731764027, 0.028504136550639356, 0.008499752879807991, 0.05349936835201723, 0.024455764231138995, 0.0028041413835515933, 0.04310033403869186, 0.027889300703204105, 0.02930697239935398, 0.010250746422181172, 0.03549382755798953, 0.017925214122182558, 0.04688907680766923, 0.04257484259349959, 0.017805595183745027, 0.025934020622766445, 0.028130731944526945, 0.01739881683274039, 0.035829546329166205, 0.029740810726902316, 0.022907912198986326, 0.004576303946253444, 0.03423199669591018, 0.03380068251863122, 0.05917453007506473, 0.059772400850696225, 0.05217253044247627, 0.021024068285311972, 0.08088304341903754, 0.02484661397258086, 0.05684096332905548, 0.07612539335553135, 0.08374051044562034, 0.025923481277589287, 0.026880800890337144, 0.02709959281076278, 0.01665400929882058, 0.03402874831642423, 0.043560492739613564, 0.02904266943889005, 0.019285939766892364, 0.04393104410597256, 0.010413907800934144, 0.082310687883624, 0.054664962592401674, 0.028184317551287155, 0.024978078436106443, 0.027619700080582073, 0.02235840739948409, 0.016033706155472567, 0.02979254562939916, 0.03136858230988894, 0.03756794626159327, 0.03534439379083259, 0.03102781863084861, 0.017270777274721434, 0.05060418156374778, 0.0169625239047621, 0.0450011548985328, 0.05880796510194029, 0.026326797403661267, 0.06354026509714977, 0.055952435292835744, 0.05982460733503103, 0.07248574508620159, 0.029810652336371795, 0.040437318185078244, 0.04078438545444182, 0.029066048362957578, 0.015746394072526267, 0.0290781364643148, 0.04023092140310577, 0.03922831127420068, 0.015682988367708664, 0.08147092615919453, 0.022815522870847156, 0.009177156441312815, 0.023412345309874842, 0.018953464393104826, 0.010540615733979004, 0.04449652501248887, 0.03836439031043223, 0.03428430835317288, 0.018505095238132135, 0.0992220536406551, 0.033856739689196856, 0.03678817042548742, 0.06979298565004553, 0.08257625291922263, 0.06468871275761298, 0.05851534687514816, 0.015026614302769303, 0.012615978701173194, 0.03149455912145121, 0.020822119300386736, 0.07956342172941991, 0.037046777084469795, 0.08270697947591543, 0.06320629016097103, 0.04277526826730796, 0.009637450849238251, 0.045076896369989426, 0.05093690799549222, 0.022806311757969003, 0.05784897120403392, 0.023566196340003183, 0.04377344077719109, 0.007185694329174501, 0.021296133686389242, 0.021941722437207187, 0.08103731514087745, 0.14257744220750673, 0.020621004913534437, 0.04593230511194893, 0.034913344242210896, 0.04777201710801039, 0.020120571766580855, 0.04758257352347885, 0.012889927036927214, 0.029467513784766197, 0.06442442336784941, 0.04749118164181709, 0.01467680066291775, 0.036142245799835236, 0.005809107080235013, 0.08825952652841806, 0.019912850144984465, 0.02444338096704866, 0.051211002216275246, 0.01368524641397276, 0.034480153915605376, 0.030501716504139558, 0.022767950780689716, 0.05204912188595959, 0.06012972417686667, 0.035276007638978105, 0.03504150254385812, 0.01815731550699898, 0.05749679117330483, 0.040963267641408105, 0.008692702794048403, 0.024340484524145722, 0.015396317500354988, 0.021004582455913936, 0.02604075757387493, 0.024433660952906524, 0.1475869169724839, 0.11278489657810756, 0.15851062509630406, 0.11811330994325024, 0.14341079177600996, 0.11314331913100821, 0.12645418808928557, 0.11085607936339718, 0.15380323412162916, 0.23089341606412614, 0.09601035062223673, 0.1036221089639834, 0.10812528803944588, 0.13560036516615323, 0.1339124007416623, 0.1884067558816501, 0.075905283380832, 0.14033374403204235, 0.07800298796168395, 0.10820463592452662, 0.14593838900327682, 0.17244896931307657, 0.14188593359930174, 0.06968596032155411, 0.1090966584160924, 0.21756521053612232, 0.2320552851472582, 0.1151500932340111, 0.113565639326615, 0.07883792530213084, 0.1589988853250231, 0.12715107069483825, 0.12962918914854527, 0.09535031246819667, 0.15690447842436178, 0.10227387345262937, 0.11172965927315609, 0.08978131772684199, 0.15977575363857405, 0.16173749337238924, 0.0965686763769814, 0.0992897307234151, 0.1313918059957879, 0.1601508477968829, 0.10462583867566926, 0.08054244598107678, 0.1853585730173758, 0.16973041876086167, 0.08663346485367843, 0.16554920455174787, 0.13960320608956472, 0.09911152028611728, 0.07883059033857924, 0.15548879653215408, 0.10635855248464005, 0.07843781355768442, 0.1075156107544899, 0.05963701954377549, 0.1783891362803323, 0.11313304611082588, 0.14142774604260921, 0.10691111069172621, 0.272035436970847, 0.17370082571038178, 0.09152121722166028, 0.09684246525700603, 0.07562852251742568, 0.10168674388634306, 0.13486996293067932, 0.08805922977626324, 0.15437210431056364, 0.15248983459813253, 0.14181243468608173, 0.1642118256006922, 0.1480585802346468, 0.07844739447214774, 0.1401252437915121, 0.13169470402811254, 0.10524946664060865, 0.13170539774000645, 0.1405453791043588, 0.12507381715944835, 0.12910229313586438, 0.13299522495695523, 0.09713977216077702, 0.09820097378854241, 0.10958882700651884, 0.1498575529881886, 0.11440632385866982, 0.16852401063910552, 0.10251208674162626, 0.141424936907632, 0.23993448806660517, 0.12974795991820948, 0.20134014902370317, 0.1842346340417862, 0.1436419686568635, 0.15644953426505837, 0.1031913138659937, 0.06481270824692079, 0.09737202112696, 0.12460952278758798, 0.12067125125655107, 0.12402853396322046, 0.15559911275548594, 0.1782452054321766, 0.07789836464715855, 0.08210503070482186, 0.15958458318242005, 0.1704527735710144, 0.18856402672827244, 0.1084195143942322, 0.05930207430252007, 0.1495060718485287, 0.1832084312502827, 0.11331590451300144, 0.20926576373832567, 0.19935582764446735, 0.12216636245804173, 0.14115972471024307, 0.12059909584266798, 0.07403315776692969, 0.14656412042677402, 0.09322106279432774, 0.1086932218500546, 0.12326497850673539, 0.08941474596836738, 0.1645474833037172, 0.1490048516009535, 0.09527144634297915, 0.1545109732874802, 0.1130859897072826, 0.1468779971557004, 0.11312822851219348, 0.1113544904759952, 0.10020229925534554, 0.1790972961378949, 0.10732193650411707, 0.05265308929873364, 0.06485129653343133, 0.11882087268999644, 0.1708266870783908, 0.09590650762298278, 0.09258706002895321, 0.14215261143233093, 0.10381213948130608, 0.09905744783048119, 0.231500542057412, 0.12467611421431814, 0.09797167644969054, 0.1283348836004734, 0.1044362017086574, 0.14482033971164907, 0.14747362876577036, 0.1450928800872394, 0.21465706372899668, 0.12163930359695639, 0.11795033940247127, 0.1143321328397308, 0.11402718563164983, 0.08705039069588695, 0.15781267040542193, 0.08243257991437401, 0.2311030833848885, 0.17397267398025307, 0.09464726197932448, 0.1653123686888388, 0.07772263764802899, 0.08322595019957849, 0.12067813160164015, 0.10188216197171382, 0.11654414342982428, 0.12544565434966767, 0.08010042112852846, 0.11497376912406512, 0.12133184580930642], [0.041721371069018326, 0.01681918677474771, 0.013285840345945741, 0.01961172478539603, 0.04539254746798958, 0.016365674324333668, 0.05060214256601674, 0.033623737549143176, 0.038246118264006715, 0.05322205448257072, 0.04538185375609568, 0.023027856834232807, 0.06703170096235615, 0.0665746262030942, 0.040381437433617454, 0.04725973673963121, 0.041744210557746034, 0.0350526542668896, 0.02069797962238746, 0.07775777897664479, 0.010621832983036126, 0.02796797174960375, 0.052317163574376276, 0.10288028019879546, 0.025533606930236732, 0.02081310496266399, 0.04721198483769383, 0.07730390690267086, 0.026382841003526534, 0.043530375962810855, 0.03825303932119693, 0.06652836368552276, 0.055295185917722325, 0.0277174074269299, 0.06903894325452191, 0.013185322168283165, 0.1042089806869626, 0.0206136682536453, 0.02373502094165555, 0.05219543778470584, 0.03600637594770108, 0.0032245436575197217, 0.012812913312310619, 0.008003003329836895, 0.013851629137726766, 0.031240770061101233, 0.044672438608748574, 0.1098466906696558, 0.005088576681113669, 0.02228595343019281, 0.024505892701979195, 0.06335112346070153, 0.10022674687206745, 0.04388546012341976, 0.10529695730656385, 0.03025771870410868, 0.0164390290488622, 0.04373981936701706, 0.020979787089994976, 0.022993041202425957, 0.06804265707199063, 0.0441915303069566, 0.03864150740472334, 0.04669711246554341, 0.02524017446142222, 0.08880352162356887, 0.062333856975393634, 0.021977588101955395, 0.04231583220618112, 0.020030637038871646, 0.006527620958097811, 0.035351192711719444, 0.017761337737153684, 0.02600134995632938, 0.02013229515536555, 0.04951490215691073, 0.058025858498045375, 0.050415592933339734, 0.01019059429277799, 0.01920713301348899, 0.03388327380110111, 0.03298277301447732, 0.03705922820206199, 0.018862284553636397, 0.030061846000275443, 0.029597195397530283, 0.021465935378468463, 0.012356649402395954, 0.03660568521757211, 0.0140444798162207, 0.02956570458731481, 0.007850932605963732, 0.03278062725439668, 0.056417679613722224, 0.09362172415213925, 0.01687759337281542, 0.05104534128414733, 0.015040883894211479, 0.04601140193907278, 0.035717601621789594, 0.04822884759466563, 0.053592120696391375, 0.036893787793815136, 0.007861871438633119, 0.03443325696779149, 0.01456014352983662, 0.05836864760411637, 0.0214763831214181, 0.009417946467043033, 0.04792172568184989, 0.02174791756884328, 0.0550224962644279, 0.04440829849668911, 0.036359997865344794, 0.03446817098717604, 0.012301708421935993, 0.059033299796283245, 0.02727209676855377, 0.03681508112432701, 0.0330842954239675, 0.046719012183270285, 0.05510088402245726, 0.02075169245446367, 0.03842791475887809, 0.01064884037311588, 0.029133121549550976, 0.07159563606338841, 0.018821519866053547, 0.05329230999840157, 0.013936866706769382, 0.024153010387505804, 0.011600574794491487, 0.014160443147245263, 0.041029675863683224, 0.024969406758568118, 0.03169809587832008, 0.033465750848076174, 0.038774255995771716, 0.017176837494064654, 0.01319479027629963, 0.019648189257298197, 0.02425025124102831, 0.019749791394653063, 0.015831460311476673, 0.028546891042164395, 0.028333893810798014, 0.0445634353506778, 0.026740793670926775, 0.12371365300246648, 0.041320170275866985, 0.013205132846321379, 0.06967001474861588, 0.02697464058707867, 0.012056584253774157, 0.062179483473300934, 0.03222367553306477, 0.011318568007222243, 0.05251995733539973, 0.02382733054193003, 0.025969402831313864, 0.028728338091501167, 0.03054969910798328, 0.026812945692134754, 0.03505718348813908, 0.04976451483422092, 0.04649811510794929, 0.015488739058907543, 0.017399563221260905, 0.10449454893491097, 0.030514401716313193, 0.018120664437966685, 0.03883058797301991, 0.008809483759770436, 0.023951388795727065, 0.025512412888929248, 0.028562629661921943, 0.02185462398587593, 0.026107481314933727, 0.012558939351168062, 0.0030921684727737947, 0.021639450353437235, 0.016866641817614436, 0.04229600202026112, 0.04083277178662164, 0.0328421635952379, 0.054009524905788045, 0.053346589407218356, 0.08133266107844454, 0.04512661602348089, 0.06343993012394224, 0.02412328546467636, 0.010793429400239671, 0.009487936506047845, 0.015984071318858435, 0.04389521745698793, 0.09208484912025076, 0.03546741218971355, 0.002390043336033289, 0.02576819684223405, 0.03307659065883074, 0.013351590389252772, 0.019862099118264656, 0.052818322753799815, 0.0668124391564301, 0.051785809586622884, 0.061140279950840135, 0.0382603844627738, 0.03393459479723658, 0.1219256589455264, 0.026334592074687992, 0.021272371390036175, 0.062086904155356545, 0.019838129868730903, 0.029644814985139028, 0.03923241301838841, 0.06491672766527959, 0.033654773740896156, 0.03515117755159736, 0.0366347570504461, 0.0356308984171067, 0.03227038588374853, 0.059654783590563705, 0.03043890112478818, 0.09443781857511827, 0.04153286725548761, 0.015368816476049168, 0.03619739034080079, 0.0887051069044641, 0.026270506138514196, 0.03873720459107842, 0.04095435169126306, 0.015548002307436295, 0.04980471803407584, 0.01567174673878721, 0.020992151694372296, 0.054142147967857976, 0.03194368823564478, 0.018936058273538947, 0.06359545713556664, 0.04010481906256505, 0.03913654959095376, 0.041316631715744734, 0.024575941264629364, 0.016832950857600996, 0.04128746149529304, 0.004423031367228499, 0.05102780115391527, 0.036526442505419254, 0.024670296647985066, 0.029942311878715242, 0.018485575481983166, 0.020906120239357864, 0.022373671044728587, 0.05437543848529458, 0.034433514811098576, 0.010461970132642558, 0.047444959836346765, 0.016743362182751298, 0.02230968519247004, 0.011830175777764192, 0.035587363610310216, 0.034256071118371825, 0.03688816273851054, 0.04858327018363135, 0.046578253486326764, 0.010588474505181824, 0.0469195667787322, 0.02795954604100968, 0.0433932983183435, 0.0427800214051136, 0.01722019418541874, 0.008287211963241654, 0.06539848074316978, 0.021483875844361525, 0.03185819282329508, 0.04235867829993367, 0.022798182908445597, 0.07575238908507995, 0.05879744780915124, 0.019633018910618763, 0.04601766820997, 0.056077048249010525, 0.1342940902603524, 0.011537405728761638, 0.021724830414833765, 0.03823651020814266, 0.04420174904433744, 0.05261348320969513, 0.01932590887216585, 0.013789278554863163, 0.02171025887530829, 0.020959816108058606, 0.049439672979393175, 0.03281694244859474, 0.0054566344312791315, 0.04768801786537681, 0.04580569047746914, 0.01714048158776547, 0.046380457135715654, 0.020565626277987446, 0.010155814284059619, 0.01717938369672213, 0.03079115240169423, 0.009449980105273426, 0.031040758293654238, 0.01663738688720124, 0.05093737957733018, 0.04893540271690913, 0.031992474903485606, 0.020154286475319947, 0.03699213805209313, 0.02012778289749154, 0.05495745189754026, 0.0026052466543790486, 0.012141196722430843, 0.04994553101382085, 0.03356973294700895, 0.028691948258451054, 0.04941244336909481, 0.026362344156950712, 0.06136319227516651, 0.01714747558747019, 0.0551902267283627, 0.011194860895297356, 0.051187280632023296, 0.053846900417868576, 0.027121177009705986, 0.07506413744496447, 0.06181142572313547, 0.04179198620840907, 0.03686014263491545, 0.031883237550833395, 0.018176416267773936, 0.03730332438967057, 0.02560420340991446, 0.0368295949883759, 0.027959272930664674, 0.04367892084909337, 0.06714399850794248, 0.03563926475388663, 0.029420671119753803, 0.045270034577697515, 0.027308276255748103, 0.036829859617033174, 0.026095573025356446, 0.04042685517509069, 0.08567953282701117, 0.042613441058035405, 0.002601935827572431, 0.04618697966049824, 0.04719283997214266, 0.04765086128775563, 0.15682678616472653, 0.15082970368010656, 0.15686291136911937, 0.0817840632849506, 0.1191653377775635, 0.1150925127523286, 0.1503578775695392, 0.09560271392443351, 0.12722646950611047, 0.15754862528826508, 0.11434450931847095, 0.14622790632503374, 0.21711281766848906, 0.0944031590063657, 0.08957823898111071, 0.0856094808716859, 0.10141319249357496, 0.07772410328366927, 0.11099758784153632, 0.12594141917569296, 0.09915204239743096, 0.08887694589793682, 0.09894598488296781, 0.20833929202386312, 0.13687610599611486, 0.14165627663689, 0.1586127853287118, 0.20337799324520997, 0.11653400611664567, 0.22204390806811197, 0.11392255553177424, 0.16245895251631737, 0.2029541531311614, 0.0624983881467155, 0.13216856574373587, 0.12380343675613403, 0.13249874088381017, 0.12689906278891222, 0.10587861109524965, 0.1245868732886655, 0.1069461095279881, 0.10074999915169817, 0.09815680794417858, 0.0907225204365594, 0.10039893191839967, 0.1995234257940735, 0.12890116178563663, 0.28954519597547396, 0.0817612170108727, 0.09513088781386614, 0.06412377128643648, 0.21080003998109273, 0.1475823979292597, 0.1329673643090895, 0.14852040473903927, 0.09944547486624547, 0.13744098639913968, 0.1017719746700355, 0.13010853342711926, 0.16071458826107637, 0.175553809851408, 0.1450324904705797, 0.10652171301522426, 0.13784024997481278, 0.14168617288981164, 0.1483620482363871, 0.11034016883266823, 0.12049034024987902, 0.10877524316310883, 0.05997927939253194, 0.07416352470006261, 0.13621986763817923, 0.15869368027363503, 0.11585906733359609, 0.07008801267615386, 0.11061526728527886, 0.18499639816582203, 0.1101222505260791, 0.12115191189306122, 0.07289053872227669, 0.12841271156711237, 0.07670143565961293, 0.11946290252464158, 0.13367415352591447, 0.12942526223404066, 0.11194193895374026, 0.08802045149994747, 0.10396732722542115, 0.11452831088432244, 0.0663937016257218, 0.09909239916929177, 0.09824700560420752, 0.08464685002607958, 0.1398979617016656, 0.10177382707063641, 0.09360140881368093, 0.1741921936294862, 0.06429212939526353, 0.12267311955136911, 0.0832974338637931, 0.16046909429132938, 0.2704868572098868, 0.12368458456226758, 0.1495733553809779, 0.13312608722065175, 0.16301098146608897, 0.1344741191715002, 0.10412937495857477, 0.12233849322157246, 0.18906502984464169, 0.12430344921137605, 0.0888341303382601, 0.18764875084161758, 0.09530056228062936, 0.078648871875235, 0.053154173839305124, 0.1175473438841956, 0.15844256803393364, 0.17039315748427594, 0.087178287761552, 0.13812300908778394, 0.18345908208617143, 0.14309401091720375, 0.13408174951161655, 0.29794543236494064, 0.21843727731278964, 0.1944015584886074, 0.08141585625708103, 0.15065496734210423, 0.18169855512678623, 0.10874202887394599, 0.11980245501867362, 0.06595111358910799, 0.16691733470984868, 0.12376129973147597, 0.10771596178944622, 0.16861010316227162, 0.1072864355519414, 0.12153559630470616, 0.13893408913697514, 0.12176571467093059, 0.18712277763656207, 0.1354525259562901, 0.11750589896525655, 0.16761185601353645, 0.10915546704615865, 0.20083787026149885, 0.09686954558960029, 0.14317046824310506, 0.1861209071108273, 0.07374841733170406, 0.23567687081439154, 0.1579680142125913, 0.12536493582384928, 0.13735680734472616, 0.06639691109636, 0.08991036830203873, 0.18473596285496438, 0.06906757743230887, 0.08679856599441596, 0.06796158570796251, 0.08176370723439114, 0.0760373127247606, 0.063635639979371, 0.13305173335330828, 0.12024779112211295, 0.06848443765193224, 0.10578904447278806, 0.14253249604787144, 0.12274971258427415, 0.13696557762367384, 0.15660824360592024, 0.0892032737444554, 0.11431758504893098, 0.09175694028713874, 0.20717238821089268], [0.044950637966394424, 0.040308783296495676, 0.08221403057021753, 0.03425707195752433, 0.027669365451272045, 0.012307428472143198, 0.022883700373183404, 0.028986269608139992, 0.1240933747696025, 0.013847260220375444, 0.04375796339341572, 0.053490822203457355, 0.0345213579546128, 0.030012455436268022, 0.042574900268976174, 0.028120268934539387, 0.02086830378643104, 0.006847557428825114, 0.008702133582638842, 0.03459559307832803, 0.062217067527983866, 0.043010122807962556, 0.02299371804110706, 0.0402166484189885, 0.07995416969060898, 0.018849238021565334, 0.06481584986405713, 0.027425483002194335, 0.05672319000586867, 0.017799965039427792, 0.06742534626807485, 0.02873825827347381, 0.05103156702326877, 0.0246165380147951, 0.03792238920660956, 0.016302755468391945, 0.03871069083522473, 0.025545348978734443, 0.012720457827007132, 0.011836081576932753, 0.0586996234155127, 0.018829889595508575, 0.0683233534385051, 0.02111267308438463, 0.056485417764633894, 0.05708648783287831, 0.012943319261207112, 0.043008192375834496, 0.019474396082971777, 0.06619796462889228, 0.04122168091791017, 0.04214234097993799, 0.02618763326401157, 0.0178990362411631, 0.04696175130084157, 0.05468184454366565, 0.028962090012750456, 0.013150716034163321, 0.008473642004121627, 0.04906893162322896, 0.061180591716298034, 0.04775497909369213, 0.018980297060417275, 0.0064781455772130615, 0.05652787709342582, 0.022059139529509202, 0.046824599017522166, 0.05213851548199143, 0.06939467202339854, 0.029732332431844304, 0.023954550768913965, 0.04898449133283325, 0.04180819641000458, 0.012602518262740756, 0.056502557559204955, 0.024315492383071353, 0.023652560277176753, 0.04448453190603426, 0.051950045595211644, 0.020564331972439374, 0.04358719987794757, 0.010251862612286848, 0.03100194948326264, 0.04998600562768323, 0.04669684444421104, 0.03352396236732602, 0.025394590371953588, 0.038109556306153536, 0.014518757982711707, 0.07331894537700073, 0.020891706459224224, 0.031338920151548724, 0.015366353393931474, 0.011325493305256324, 0.02858113670455558, 0.00905669866395848, 0.057494660573346276, 0.0240261989778706, 0.03815597488677927, 0.04785473731213382, 0.04855298038039889, 0.024720369139686227, 0.03690520753817899, 0.011999739134418113, 0.046414696012756655, 0.05623055322627936, 0.0416057147750897, 0.02945791929960251, 0.03337683222655739, 0.021449270558410456, 0.026456713111006787, 0.013175935484468937, 0.04488676067973886, 0.033390002591269355, 0.07163953727909497, 0.025237406038546135, 0.05326521609510694, 0.03251345069812877, 0.03499826968514493, 0.019820688126076545, 0.0015661142720741086, 0.00946806900070182, 0.02167689530844135, 0.026768040244600604, 0.020402431820652316, 0.031785793136805296, 0.07956859216626201, 0.031110206352812902, 0.023883196026352898, 0.014087003605839397, 0.059450625974152765, 0.037995922046580484, 0.014934693163793002, 0.01793777210904019, 0.03841494456199663, 0.06634087088916983, 0.027134835919631378, 0.04611899723697986, 0.030320601936961924, 0.04542405524158052, 0.004468519506709916, 0.054398830980062485, 0.015178020910492964, 0.02602214026930077, 0.026298132691798464, 0.06204746091472251, 0.08557907571750027, 0.012393996817991138, 0.005944851403390723, 0.030393680158470358, 0.0484441331853824, 0.03395331557840109, 0.0026774996076710522, 0.03896095151347773, 0.04224281505282436, 0.057235439840172014, 0.08054513976510082, 0.028263073414564133, 0.059200022635715346, 0.028346595986347114, 0.02802248694933951, 0.0713475908019713, 0.029572696890681982, 0.027118281361513903, 0.018629418120586445, 0.02077741062800799, 0.04051816223987511, 0.02564174335982118, 0.03737527285037296, 0.03304924230490412, 0.025719588289835622, 0.0363287682911115, 0.024057494709268212, 0.025611212676657096, 0.029756664697613035, 0.0477690010198525, 0.03266995819285512, 0.020017549794699465, 0.08186731953173876, 0.04656015017202922, 0.06623787605868918, 0.07688134921980755, 0.022835354753104702, 0.015257677529007196, 0.03807867957012994, 0.028386317426338792, 0.025574773649818132, 0.023509022979331867, 0.008464335048172091, 0.06008139212748834, 0.046776236434067996, 0.0500943574921361, 0.039102721227599044, 0.017967500424544727, 0.05930542626551219, 0.07685990751321826, 0.023110943447266306, 0.05020640058709042, 0.028176643320226243, 0.043880130230848274, 0.07498641804392848, 0.02744538613062884, 0.016447312265102352, 0.03736724578110235, 0.022549347153731754, 0.03472068779436605, 0.031075485715908662, 0.05612347361498645, 0.05219057608129723, 0.03650449189756598, 0.046158698320920975, 0.02284591954334506, 0.050824875078563175, 0.0276607768942735, 0.051554507176790915, 0.05270738906360098, 0.032643980479666164, 0.07680434228054114, 0.0652914893414293, 0.04657476242365582, 0.04022341341312442, 0.03877820506958025, 0.02488894946873188, 0.03055633178779057, 0.07001031363116843, 0.03061086903991444, 0.01785644799071763, 0.022883311911885227, 0.014445365938757147, 0.037332087489111085, 0.012426357849368026, 0.03200619148888758, 0.013610601624740022, 0.044053869122373204, 0.02953803732192942, 0.028753996893231357, 0.04538302083632775, 0.05286163364404014, 0.027787954712818776, 0.0034552871241300765, 0.03849520168400236, 0.016744161157735755, 0.05241338323269572, 0.07066013304782764, 0.03966355077656252, 0.04471607519579785, 0.025997774076781104, 0.014761522545346191, 0.05209513673824923, 0.04430274898186326, 0.042016130073794296, 0.023665717071188346, 0.05696673318743706, 0.05244170867704919, 0.023511910145836215, 0.013431135049488927, 0.043558606412261724, 0.04414248579580869, 0.04019023644338761, 0.009491497118558203, 0.05571480893662997, 0.019021088889400874, 0.026138853381520936, 0.04265589699415224, 0.01354122905260218, 0.06889900219227586, 0.048019129383776865, 0.008509072558289128, 0.04699705887053694, 0.08689723177147762, 0.021223382858027304, 0.022477456368505955, 0.030799820686557462, 0.03835098585113883, 0.04239462369254657, 0.060385538664247305, 0.014717980953199523, 0.05039881615500365, 0.03570549316438181, 0.019626900221088102, 0.019897002959623933, 0.07429114356637001, 0.03545641992241144, 0.03472584805318287, 0.030122941293354546, 0.04038375802338123, 0.019249436279226626, 0.011941812599876096, 0.10087397428495543, 0.09931129456630775, 0.023214448875348483, 0.025891201670414636, 0.04578622330778411, 0.012746354964162623, 0.01149570890369692, 0.03419791388192347, 0.041285744801695855, 0.02979302399658731, 0.05517589606876884, 0.014896355935239365, 0.033172542295817814, 0.0537191729859582, 0.06150626816919871, 0.035778269437806945, 0.03627878061628767, 0.01918243942782283, 0.0595488099913512, 0.05466837562354548, 0.05943121308726924, 0.02774111713681902, 0.020816431480592916, 0.0635520037529724, 0.03460598144946354, 0.019483217038214207, 0.05780108020241771, 0.0551752616385264, 0.030032445077917407, 0.02833496080711484, 0.08764602909130709, 0.06741244731737034, 0.03553188997986061, 0.057209139822849205, 0.08259827138057776, 0.008187027115906988, 0.045841028581240346, 0.029350666661879847, 0.0346764846305762, 0.025939859416601912, 0.03610794585464256, 0.055496500472405126, 0.04563621278586132, 0.04709296979542289, 0.006970711958794189, 0.024808388702305298, 0.06426833317215953, 0.045318203778671365, 0.03544538015765803, 0.05314910179004073, 0.05576196712042604, 0.012828185439242848, 0.0099423098477668, 0.05086208254631076, 0.009427239004123424, 0.015726499425779496, 0.061969266539173465, 0.032288519732121906, 0.056132409921182055, 0.012367415208635586, 0.03461494828973498, 0.036233776781175814, 0.05006662915859904, 0.08779547642916441, 0.12118726356753282, 0.10627969993012291, 0.23167799253548893, 0.12594268125082764, 0.11462435073086194, 0.10294060874730349, 0.09989857341029815, 0.08370004261710814, 0.1848853219832693, 0.08494788208710295, 0.1405058205127716, 0.1102712025333728, 0.13732482120394707, 0.10107497671352965, 0.14759215526282787, 0.10705949272960424, 0.09667210546987397, 0.0866892540029117, 0.17518706167382853, 0.1501960198261908, 0.18586817995778152, 0.11824539356998034, 0.1394989016864981, 0.21271839418581553, 0.15631522504346712, 0.09326163240309272, 0.09102677553892136, 0.11348874773830175, 0.1683861594647169, 0.13727740517684392, 0.19609151780605316, 0.1284473847065653, 0.14816213824919292, 0.07856829584177051, 0.14336303648139748, 0.11857738718390465, 0.14036503806710243, 0.11609204911759921, 0.1253184697457722, 0.08700029445546013, 0.1396505135510649, 0.12502812461129256, 0.21861037159604685, 0.12145623484892504, 0.13413341316793645, 0.14641624050480978, 0.20040940253862313, 0.09194203106952564, 0.179851501381823, 0.2931406987564904, 0.14352401212922164, 0.15648780364011014, 0.13001368780221256, 0.14317996773336614, 0.05633118336222001, 0.1127007853771959, 0.11175631212868861, 0.11485495764229979, 0.12986175024083682, 0.06716111794646297, 0.11511191885386195, 0.18938286921807698, 0.09687574739967074, 0.13449440736855778, 0.22107022388705186, 0.16257281069244656, 0.11431542730757169, 0.1464283319988421, 0.15206492239875452, 0.11554027801113469, 0.12842407024332456, 0.09940166864544153, 0.12011390259223324, 0.15598050371876784, 0.1845096849969455, 0.09705412747072321, 0.16069157235324383, 0.13847903641206877, 0.12610277480312757, 0.09112328357462372, 0.18736653455666133, 0.16861344155456337, 0.1098099412130458, 0.07192784680851869, 0.16136609044458183, 0.12790704012981483, 0.25531516703111784, 0.10305509796100003, 0.10952592002493994, 0.14589847757347993, 0.100296154219125, 0.07077141279088599, 0.1357739751360246, 0.1637813901262624, 0.07103503721633128, 0.1437251027673483, 0.17928949796727725, 0.1129713308598314, 0.20968885746385368, 0.12956597682620796, 0.13233931229582854, 0.1172372398099729, 0.10752828578863825, 0.08261684288403817, 0.10355783134166684, 0.23152752060975346, 0.10759098920971155, 0.11254251708409616, 0.13660680901791367, 0.0921962306435619, 0.1378294476973159, 0.10561670336340155, 0.18038075869636877, 0.09604403310056243, 0.1092076056769916, 0.14800731012863771, 0.1351661163249186, 0.14561780834836618, 0.17627007141709328, 0.06909234396048955, 0.10245832641209875, 0.14105989863829954, 0.13928745660398686, 0.15828940910952433, 0.08839050414306776, 0.12015526608697005, 0.1899564212986401, 0.1334190515003034, 0.11976251644747597, 0.10034096467175654, 0.3317699687821524, 0.13126918114721775, 0.11692659290773527, 0.09139137276049171, 0.07646399590053729, 0.20601396608565534, 0.14137965148048742, 0.11668825069708483, 0.14941683092287608, 0.173332829028368, 0.12950394515480312, 0.09369793042008366, 0.1434595784438508, 0.20823911311370985, 0.11753979857478823, 0.1441547375704561, 0.14718476283763135, 0.08499231256012406, 0.14459396685872758, 0.17353925295174122, 0.10701791210366146, 0.1969470554696662, 0.12896194495260715, 0.140351195952722, 0.10932366230658122, 0.13184030407241412, 0.16843459329434804, 0.09737668266253811, 0.11236395380858864, 0.1216804092483861, 0.15420792597745145, 0.1910474377551249, 0.1128953756498439, 0.0780625022681696, 0.07825472445360251, 0.13222770685596125, 0.09205451860491719, 0.1172819688384022, 0.1449387983552047, 0.05444533098489046, 0.1434492375701666, 0.08893392248345272, 0.18382543671344007, 0.14773295127919742, 0.09585776845259325, 0.18199735480759824], [0.026928503598485674, 0.035363321525177786, 0.0060932003626865995, 0.028561303125960485, 0.013794901065661438, 0.021739700509767448, 0.01426961858357702, 0.07474891043135098, 0.060902188798146586, 0.04562017221802047, 0.024349866967116083, 0.024662429034443836, 0.0784230147089277, 0.03699097436453615, 0.007671327779202589, 0.006863567462590123, 0.0453908307743924, 0.04891397797369531, 0.06893068299229656, 0.018082366225176623, 0.058998056687414646, 0.047555404981332164, 0.005672665986432028, 0.04942272656730243, 0.023428871030254022, 0.027971194790942327, 0.04799023397000773, 0.02001359054286565, 0.019185820228553245, 0.029948425479233265, 0.03509672511635082, 0.048616820347628424, 0.10701000717069421, 0.03078801417723298, 0.058816589282027314, 0.03183769088770662, 0.051602700126490424, 0.038295977017177005, 0.021989089270521487, 0.0351116935988622, 0.0011193284361589967, 0.02769412349776498, 0.025465358181723526, 0.07519423296408993, 0.07072982537959303, 0.015474700169371707, 0.028491722752473185, 0.020777514104598334, 0.032434438687882254, 0.07290113743926797, 0.02078862002651606, 0.01609240791627339, 0.04835795584533896, 0.03784717020711728, 0.031219402993363992, 0.04866986821538635, 0.03591316559218934, 0.00843647270396884, 0.08025104911731822, 0.024846454516851475, 0.029745166921722035, 0.021856145600655248, 0.019686523093176738, 0.022765952495059798, 0.03716058097779751, 0.040532689674624374, 0.019417738408914635, 0.03249025158584118, 0.016807638108730316, 0.07188489554183823, 0.012503364788634437, 0.041507038820002756, 0.04599179227703384, 0.05359644974981036, 0.007414990819857589, 0.017432772421411107, 0.04398174763524106, 0.021640023715527992, 0.06889533131782498, 0.013393349978806717, 0.03368022898212075, 0.009234304356920933, 0.034262398457420726, 0.008919760967338724, 0.008579216964010681, 0.06145121183778558, 0.019911571106474315, 0.034663785847702196, 0.01718516820775611, 0.06983129573719841, 0.05406154140031763, 0.025029837087328945, 0.044279485408748896, 0.010511702508665621, 0.03173614812216588, 0.04915122774296573, 0.06309405368353639, 0.029320895937936645, 0.015527369753856744, 0.027596212590911558, 0.030944911829595054, 0.021862157420920472, 0.05941091810486146, 0.03811992092856339, 0.061593337782791684, 0.032043670370642624, 0.00868049425272537, 0.05032705768410649, 0.023285262486232177, 0.04457933681883982, 0.03496193413489631, 0.04143255263833063, 0.010137901807736074, 0.024460417285029377, 0.012983349434632276, 0.019457437796518207, 0.021623263900567378, 0.0019747232893548372, 0.026448872638866305, 0.06922887877694198, 0.04125711401658399, 0.028844021526830535, 0.011640984947527093, 0.015063190732949545, 0.010954884263420743, 0.03513010564659323, 0.012817716492073876, 0.04557316331192851, 0.018366239831915925, 0.02363483015713947, 0.001705584070545488, 0.062049245461821556, 0.05497521594432848, 0.021236520992325883, 0.05252635931330068, 0.006603871330818427, 0.017273521948871867, 0.08317045282040324, 0.045644596086016724, 0.031817782670259476, 0.027081262187233994, 0.04172052290024502, 0.05346788093447685, 0.05413774088291185, 0.010321286074551088, 0.051258540379681757, 0.029767999625099555, 0.053827277185129266, 0.0374397167137691, 0.046813990122505596, 0.09174868251596179, 0.009776690475908774, 0.008382227221902992, 0.06492406941418137, 0.03525990939566067, 0.02560401172377169, 0.06636565777340106, 0.02285164298622736, 0.007830493434864496, 0.021313302318698595, 0.03502558750499572, 0.021376555353136997, 0.09170068294874259, 0.03490778025505798, 0.033174849314881225, 0.0076317539205774665, 0.028528736837740456, 0.026587748401133076, 0.03472139686346054, 0.06915179041347333, 0.035715671189661534, 0.05915855057537556, 0.0433081048540771, 0.014903521265036293, 0.07177879302097218, 0.022042939505938972, 0.013519851806839662, 0.04536378436854907, 0.0389485682493874, 0.061912581723715575, 0.047216466561492, 0.007351095721657787, 0.08817371898995978, 0.03596670200516071, 0.02652057513062443, 0.022123149130493402, 0.02726245648227632, 0.028716592650328363, 0.026666456766958748, 0.028503027145883868, 0.03632679714688233, 0.06459324966583933, 0.03405845797221575, 0.02052520594692656, 0.010978279302694967, 0.07437997737101146, 0.02754984320407467, 0.019676989676164727, 0.01899171680478113, 0.03307132861976113, 0.0015875172809631164, 0.037207304899181635, 0.016034997068345547, 0.010084111792301493, 0.04435867044542517, 0.04143804877198168, 0.027535198722034693, 0.04678225503968341, 0.02945607029167669, 0.01997300736340029, 0.04526753756882889, 0.07624054074819599, 0.022730047814548016, 0.0099487101293302, 0.014274590548926165, 0.029366663124944483, 0.03988858352282217, 0.06442248954304627, 0.005420491839426437, 0.06824348986681018, 0.08292265861694302, 0.029991990820105587, 0.018055559002927372, 0.04438311806214707, 0.028860835624592643, 0.08697719712342535, 0.01772855601406523, 0.029771371944142238, 0.04646528758374708, 0.03791546475674425, 0.057453012093901634, 0.051198276292000494, 0.09999134271804776, 0.037137673635567935, 0.009644625508891684, 0.051334678794124296, 0.0318596923856863, 0.022032366234010885, 0.04749607727197664, 0.020877387673993195, 0.026865888386964798, 0.03750098164060286, 0.021198769000225832, 0.0685102559093918, 0.013801174121908844, 0.03313137557623642, 0.018664148935515965, 0.03758148303521531, 0.057802946173719, 0.02032814241413559, 0.008072447996320469, 0.01937876844645611, 0.02814424836209842, 0.030120240723980323, 0.05795412377587386, 0.01837602600322238, 0.007545940444937774, 0.01757738858993564, 0.013623615926397699, 0.038872616432074986, 0.03402116568759084, 0.025813107378780842, 0.05400324845686555, 0.03832709124045713, 0.03433059461946998, 0.07256031608475105, 0.08209348882415465, 0.018691916284816604, 0.05231413391551801, 0.03227876239855375, 0.03561967884057334, 0.0552442923986486, 0.03742718756464975, 0.06943924498877355, 0.015174723230302334, 0.03742505017934101, 0.0992847163496273, 0.0376094013585576, 0.07379976886191539, 0.04091384315064975, 0.05253574005993349, 0.03535148108910237, 0.03261958375307066, 0.013588281215301581, 0.03516115201637149, 0.01353854120575956, 0.01655122820687081, 0.03837869043595024, 0.06068664536412273, 0.04378526424989104, 0.015248883715165513, 0.032432681282183955, 0.016187996537025486, 0.03635982483891504, 0.04246525579531278, 0.009540709567123225, 0.0669651570330773, 0.09520155723605837, 0.03039954270103148, 0.0554083553808076, 0.0320743062267346, 0.011312963307968207, 0.016423668712377548, 0.0070171504713861, 0.010837942993800555, 0.0113080727668213, 0.03886340192652174, 0.10378219573093311, 0.0425786016775029, 0.04172248047377382, 0.014510523960260409, 0.02275369136727282, 0.02891317442325609, 0.04118101631424256, 0.013629724437903081, 0.016769348377627984, 0.0018051308829204313, 0.05408200262380498, 0.03112040812681828, 0.021763225318863988, 0.048846609624368806, 0.028303276614419053, 0.016244291194847653, 0.0383242922835052, 0.028521137245531594, 0.04820921757657613, 0.038568205266658745, 0.019561282492109706, 0.028496336790599992, 0.01679964835888573, 0.07273815332778863, 0.020451006446299807, 0.06418886315077543, 0.03659642321456756, 0.03946421415145908, 0.03645213274285197, 0.027315724873915315, 0.04287529789975711, 0.08639045432209969, 0.04769185498090727, 0.043024056524570496, 0.105897107959858, 0.05251490903486099, 0.0029604521031225367, 0.05083383174080934, 0.037378238048404455, 0.03950348097298827, 0.013636766783227878, 0.04861064228628363, 0.004314964911567846, 0.03518490074202418, 0.04462197935208678, 0.07242342843008892, 0.1563003244144576, 0.12082549583699022, 0.10083546063729695, 0.09989296871104411, 0.1439353400575263, 0.18050611125571386, 0.0987158122339419, 0.10264667416257517, 0.15400390406804426, 0.08821266011468001, 0.11893783855651106, 0.16767434908875398, 0.13661785556801728, 0.13040855447096483, 0.12064301062907491, 0.1155817907835756, 0.13182699121534824, 0.13094822051269667, 0.1169560006154435, 0.13399636266486986, 0.14625811470406397, 0.09329015122992651, 0.13607186557991163, 0.14963246935180255, 0.13407195146594728, 0.0910258459459458, 0.09989561499761683, 0.09558661228844098, 0.12921719625592232, 0.11805677440549646, 0.23103753690208706, 0.20950863856290067, 0.20314218875552925, 0.13792503971074307, 0.17573884635099343, 0.1223522267703499, 0.08880100425864969, 0.06922141489173685, 0.10215568622308117, 0.08342241322887795, 0.1349335280912263, 0.08293088246136904, 0.1716732137969562, 0.2074929824365037, 0.15320719539054803, 0.061869949368493896, 0.11500552456293787, 0.10104296343134982, 0.3157585236643042, 0.11266335060021707, 0.11150511846478496, 0.14209159756345408, 0.2588448519153254, 0.14240303156631334, 0.11996603624096938, 0.19274806364306382, 0.1049242787329214, 0.1425366893942867, 0.16396762084748062, 0.13254910175289425, 0.10335083744887795, 0.10045905012105193, 0.12921114372355597, 0.09652569118355002, 0.20468304678797722, 0.11788798203425747, 0.0746840899810195, 0.060700087142842155, 0.1040823660524828, 0.18892347386905126, 0.0811650086460369, 0.12051920512957232, 0.08316221540527684, 0.09451504264559064, 0.12638729810714722, 0.08628705915595804, 0.12350083727921758, 0.20978883281350136, 0.13105339344058717, 0.06911599769123963, 0.0902551794424653, 0.11167342907616071, 0.15267154627612659, 0.1284622581941741, 0.12496901064046792, 0.13818324942673954, 0.14972873990024838, 0.07968036723988396, 0.17469943926802703, 0.13366618752479553, 0.06468615468059268, 0.1200404851032155, 0.19336961529084615, 0.1674247839088951, 0.20517512038350105, 0.10608594425554786, 0.24025044111268862, 0.08257423767021724, 0.1599842267377036, 0.1492128904376711, 0.06534583999642304, 0.12635099648364953, 0.16002160044653074, 0.18571229332259723, 0.11223168019205332, 0.08338788936712913, 0.17205878453595297, 0.13740471191704273, 0.21071273966559342, 0.083092251659504, 0.15790006571582385, 0.12757710926234722, 0.0763712605195386, 0.05624701448583177, 0.08887318002858333, 0.1073908010231597, 0.11393073866409914, 0.12249021365174226, 0.13396660211895192, 0.16091414541006088, 0.1849896399570363, 0.14469420005168232, 0.20897339656949043, 0.11382607463747263, 0.1449899056128093, 0.06701271555253438, 0.13047235033341817, 0.11269625276327133, 0.08219847176223993, 0.10497585417968885, 0.2901685796678066, 0.17196783370205335, 0.15630031084375723, 0.21613058394619397, 0.1287723079855953, 0.07065095246902534, 0.17577313951083592, 0.09555089420505933, 0.12191936214055334, 0.05464026391772287, 0.270136760281665, 0.17538997078580515, 0.11188980032290731, 0.1461526567914656, 0.1879672416086708, 0.07978914997407369, 0.2352712425802435, 0.11705417106194155, 0.1812009989683117, 0.16243413170533522, 0.09255273972770997, 0.06979122824434723, 0.1476502242897238, 0.14021153987518378, 0.09054607419031006, 0.11686354343380247, 0.19509993387120111, 0.09092203687344279, 0.1925559432378837, 0.19599874849830354, 0.09405804252518074, 0.17899174323039396, 0.2075630479625293, 0.09200605084853512, 0.21967477590910026, 0.08505823223718575, 0.09402917764548745, 0.1394863895007542, 0.13767267896660737, 0.10727770959160157, 0.16150736143546446, 0.2088631617703608, 0.09455213136970997, 0.13923324165599688, 0.07760387366371495], [0.062537193564432, 0.05109876234616552, 0.01125210041313299, 0.014273135091311165, 0.025532760457800965, 0.026512322448460118, 0.031538999772497585, 0.031545737625232766, 0.032107449269720485, 0.028840079238372188, 0.019571686130283133, 0.04659029069755759, 0.014286831320662583, 0.030311322970581905, 0.03995186369866133, 0.05150931335187384, 0.030898690024124723, 0.005322752686749611, 0.007663673056023461, 0.030710657792431966, 0.02047959651931056, 0.008412596753000148, 0.037097942017550976, 0.015147061053929585, 0.036665833954300196, 0.024476010019757917, 0.04666833918807762, 0.04695772419550589, 0.014326125283592513, 0.012969117162616124, 0.05622311648247497, 0.023936628962733915, 0.025309127190017273, 0.028096866261746203, 0.04484285946403231, 0.07235104231429951, 0.020977999150220836, 0.04531871607261045, 0.006590516489398266, 0.009224028792232275, 0.054119488290910206, 0.03617303432630641, 0.019457512435370257, 0.07288612824465547, 0.014620506005095584, 0.010004273665669774, 0.0302303974915828, 0.03189514923308577, 0.017504586871447306, 0.009533482321005846, 0.03950116038322449, 0.02407523331099323, 0.047938916366547346, 0.0866307167868529, 0.004740509844850749, 0.038178285118192434, 0.04652470350265503, 0.03968221048957535, 0.0343672830079283, 0.048291917424649, 0.01838707594600107, 0.02430270708698247, 0.022634340450167656, 0.01100420018857611, 0.032991794137550254, 0.06296865362673998, 0.028811869144971882, 0.05009257633771215, 0.03182508370706013, 0.04439106031454035, 0.03807884241853442, 0.036860688855605464, 0.05587776590670858, 0.05228634451382926, 0.031038549662168537, 0.0248163716667997, 0.048076920211315155, 0.03309745221797909, 0.018394117443157092, 0.028129230685798184, 0.03651373693719506, 0.008247756848244794, 0.009598014393954404, 0.06565428844520024, 0.09767758580190794, 0.02339660160110465, 0.010856221030865396, 0.02094882892976914, 0.023278777387791445, 0.03140070076499667, 0.0307359942900283, 0.04159355882023062, 0.015593708426292454, 0.03691172147435801, 0.0034158108049138847, 0.05568347418946879, 0.036915483951036415, 0.03505698671298368, 0.0766385490340846, 0.04078557289072445, 0.020456232862280946, 0.021081233164295554, 0.009156365280172654, 0.04862728335761598, 0.047467558445142846, 0.035511720526431284, 0.017894881910511425, 0.026819895587063262, 0.041348563573722324, 0.04656384140253067, 0.04943948977493814, 0.016830642142200043, 0.024334515112319162, 0.04958012294290321, 0.10060826675700289, 0.010870004621600466, 0.0984650935445513, 0.008651710797234305, 0.04941922193393111, 0.036575120607657094, 0.020871896629354784, 0.028459622957078472, 0.015959973147671138, 0.0429391107255859, 0.02138962733027126, 0.03976817409108792, 0.062381659767457416, 0.08025152409183127, 0.015443803077297551, 0.027958840364590287, 0.04163808089547923, 0.012930946175142058, 0.016291707221950804, 0.026327718514949083, 0.029486505979938165, 0.02430240174622408, 0.03097297264529126, 0.008156757668725081, 0.020361787573035275, 0.08003546497119324, 0.016422635642811656, 0.02481315371447376, 0.022057777370459268, 0.0612173072461571, 0.014968791244817632, 0.027350535416709523, 0.03801048340808068, 0.06478648965380021, 0.056320927305413146, 0.039774114665176184, 0.023897497848208462, 0.04068732102002416, 0.0124159669337262, 0.03475980533819113, 0.02249792607368103, 0.055597351132226844, 0.07168535874890429, 0.030696537478693893, 0.05860427567469222, 0.023855119943618774, 0.01662682888231107, 0.06378172178353582, 0.02227924780787102, 0.051566798838653734, 0.03100256695012961, 0.08490243381155388, 0.04357919316472752, 0.05260611431939261, 0.06605255457439593, 0.008848089009656437, 0.009182398972500647, 0.07059071213006973, 0.046707785821386745, 0.025684545348797525, 0.013535104425890105, 0.062347739801875184, 0.04962900121297155, 0.08296235291553394, 0.06891950752053942, 0.04727398258234773, 0.0289391249950443, 0.038265571862991364, 0.042776119828756363, 0.03179729769804648, 0.05836638129715409, 0.01027335096815867, 0.013787409190886786, 0.006348156927353037, 0.016399818206472055, 0.02118238407586302, 0.03299481701105833, 0.039810694488031526, 0.015013935875945857, 0.0136783745505714, 0.019097335869446397, 0.054028157477400134, 0.018297887606812373, 0.010769208244580244, 0.011847355436267597, 0.03129682723166687, 0.02123441414109298, 0.05102797418034502, 0.0681726915229644, 0.0509533319356186, 0.029379063352410282, 0.019751606475827948, 0.027252251315595846, 0.05929087168936219, 0.06762220963303532, 0.00983852706849575, 0.05041440888973219, 0.042783118917473724, 0.030239880018468415, 0.03072858468762466, 0.028336022714419023, 0.0364859543208565, 0.05174400504412396, 0.03434541043160217, 0.027208462058167373, 0.056819477517689974, 0.03547906942133393, 0.026898128978375877, 0.06945207608597619, 0.04882310177864773, 0.027014931996486018, 0.019994250598496625, 0.017018866060035567, 0.0052583953365683556, 0.046551749908498356, 0.004206625345562185, 0.021881175061155642, 0.04971829981410077, 0.024797856142478328, 0.04880325462935226, 0.0014450503721101476, 0.006720565783325583, 0.08115655409970454, 0.04081857683403151, 0.023780411541728035, 0.021179700469864265, 0.0456818103391145, 0.008237588152821575, 0.05284981017134019, 0.006627611150699002, 0.0034550152860382305, 0.03353589440562895, 0.010261788731440902, 0.031319917778351476, 0.024552655639126897, 0.07167596103889601, 0.040123780723661184, 0.022909588180482388, 0.04988387932202645, 0.06716413064194576, 0.026924205079142536, 0.04229789174028805, 0.012997535057365894, 0.009952420019544661, 0.0513658540855561, 0.041734317517174144, 0.06772491947880813, 0.047918770661843677, 0.007289836732005435, 0.008586568042768963, 0.011508696063953851, 0.08742481988987752, 0.05756130628287792, 0.010672394019950713, 0.05995344077902181, 0.031301824642079215, 0.022816577992801155, 0.03483412867145879, 0.0250054861618472, 0.03733594835336719, 0.030709002166986465, 0.009676676958666315, 0.027397395045097386, 0.010862325301526912, 0.033102826215326786, 0.031498871211494715, 0.048140522691288164, 0.042316008625285964, 0.009115598896252257, 0.03454773939613785, 0.06936533216919218, 0.06460199598222971, 0.03187295435262578, 0.02958060860899942, 0.04175528764192547, 0.04739555909431406, 0.05201249456565295, 0.035112246604902406, 0.05353569372424057, 0.11175805596368653, 0.03806586543630276, 0.04087871200005923, 0.0031648016177184346, 0.024154791541929756, 0.037728182306247096, 0.017720215122348497, 0.03306587998356138, 0.03276377922988363, 0.03435531025752425, 0.023788784663858156, 0.02637476982947971, 0.03944372917924609, 0.02074605891747134, 0.015495566817532693, 0.03813468245789409, 0.011697316076606512, 0.06031302362680435, 0.024410236227725233, 0.027219303351427828, 0.006711490801535547, 0.03875413403979369, 0.0857960372897131, 0.06056324020028114, 0.024726038299767033, 0.05178345846278327, 0.030966244970581362, 0.03418012947908469, 0.007503984928397196, 0.06472312805375882, 0.032315484713763, 0.06580023454236132, 0.01579965228613998, 0.024899158028087447, 0.04065078190926995, 0.047457136147256405, 0.03724596103919404, 0.04240158206916281, 0.06278597842901945, 0.027192798077261875, 0.03496828522267086, 0.027803096221759915, 0.07634864494736705, 0.04015536652877927, 0.01747010711447469, 0.035309215142790756, 0.03456743387505412, 0.05010634381324053, 0.003302068403822237, 0.02624176848413689, 0.05765542587531464, 0.07158603479287454, 0.018287534858765345, 0.05697596126369067, 0.032231461722403765, 0.007734291588089296, 0.01786315530937697, 0.025449052985225405, 0.06401650168533836, 0.12274281866848469, 0.2387101123375552, 0.13180588877626828, 0.12586276339633123, 0.17254063939409597, 0.14531941578856536, 0.09238706861755677, 0.09205778914370707, 0.11443376381482397, 0.11569934019020625, 0.1160772977662938, 0.12531097871916635, 0.09669624774583749, 0.1427442261150905, 0.10322169866412878, 0.11844746129853384, 0.09314223738121134, 0.0946343494579196, 0.11265832265572888, 0.0904518256762198, 0.12137185223400593, 0.09272461264793362, 0.10927979501762561, 0.11290431195603949, 0.10996675744120564, 0.14230795523950032, 0.15119544762585843, 0.17507631118808473, 0.0700381403522832, 0.1281818603830678, 0.1267926413565874, 0.14883307367563248, 0.10531941681568112, 0.0961374266605292, 0.12030742077955178, 0.10895844083279371, 0.08651675004512072, 0.1493252015539578, 0.10372794685619217, 0.13641006100390637, 0.12664819482181752, 0.1214658971875906, 0.09303937825773444, 0.15408800169825554, 0.12011097132095269, 0.10173519807202475, 0.14626207734857286, 0.09015869176281349, 0.12950378230639867, 0.12451338794614587, 0.27480119998965946, 0.06919204111077956, 0.08301139064133167, 0.220688398661358, 0.1024800395326955, 0.10275823889034134, 0.12296562242720808, 0.10536275484732219, 0.2029100212135485, 0.12227984065456049, 0.16043284695063317, 0.24135916733316012, 0.10918337519147567, 0.1419323453945773, 0.26461883208581377, 0.08989386633038521, 0.13404444365629128, 0.11611950264445373, 0.1169050969183445, 0.13413257178451332, 0.07509845096085753, 0.13053998670407704, 0.1120077839919499, 0.18233717871563776, 0.12483063020876475, 0.13374694676271506, 0.21493370245609963, 0.17194483136492117, 0.16158573223011835, 0.11324779316782951, 0.09016404540411063, 0.13248199463954993, 0.1350639153804098, 0.12596762419811317, 0.24056574276515416, 0.09069770641092743, 0.07132341459925685, 0.0746574235547866, 0.11090213832046304, 0.20536668438996586, 0.11709283398730413, 0.08917464635201863, 0.1006962727489216, 0.10668082269174711, 0.10029196765805994, 0.16850639587002142, 0.10020535944827966, 0.11800801487905638, 0.2212290417935167, 0.13315214296536787, 0.08194345116083111, 0.11047485803386994, 0.10206588211336307, 0.1173495916383607, 0.12812326209885733, 0.15068837840642246, 0.06570450003658022, 0.09213820911411728, 0.2863561899534294, 0.1306937834514039, 0.12373273340719086, 0.1264621540904045, 0.16981656556682928, 0.14617070582296166, 0.2019186815513032, 0.07132950105837413, 0.13302658684551716, 0.17398434478257382, 0.09629372041672468, 0.1982396375387907, 0.09726013748773507, 0.12694889440068177, 0.11796491433467184, 0.15537625471396105, 0.08994853589683771, 0.07825196281607662, 0.08302264753729105, 0.18399612898273127, 0.10339908128870384, 0.13954833974795683, 0.15311591885983944, 0.09084176618073668, 0.07402083557099104, 0.08581956209880964, 0.23125168255397252, 0.12052263851676669, 0.14272830768355302, 0.08972336405089923, 0.12417714670300484, 0.19204481637903623, 0.15061675224985394, 0.11012594175658055, 0.21373319758900575, 0.2186263714517866, 0.0766523504363639, 0.1493197732738086, 0.11945961841515132, 0.09709684803549733, 0.1395738119525569, 0.14314110124749796, 0.07577896051641021, 0.11976000586790697, 0.16812218220106193, 0.16605757655841963, 0.21723141201904841, 0.12880101001688413, 0.10523375176957675, 0.17314313777855464, 0.12703695467540196, 0.13764673178749426, 0.12727081855492933, 0.10715002287179232, 0.08196658241961684, 0.08700295431273324, 0.10003842626299177, 0.15354137388723238, 0.1258295966046197, 0.221874898565667, 0.1347055538956608, 0.14297579654625484, 0.14151150440531118, 0.12219862001282827, 0.05813987273722887, 0.10417839911367212, 0.09646167140454054, 0.11496585740574769], [0.03276613713907344, 0.02795323057632361, 0.014350632272128547, 0.04067248824451651, 0.039464658591896296, 0.030411237252077887, 0.0361428157692509, 0.040741824345397096, 0.06452105353985514, 0.045183076922382624, 0.03866826204050865, 0.058385027439466546, 0.04163579762514148, 0.03123605085004653, 0.049832086744053025, 0.027231676437492882, 0.020042504616347805, 0.043770899663546255, 0.030930357253445045, 0.010301470307500234, 0.04265955090522766, 0.044773363907422335, 0.048839814096157036, 0.03966536246506231, 0.009112652357933777, 0.04946714346962316, 0.023785587067582777, 0.043088900723627636, 0.03735970725704517, 0.015234139149210282, 0.008908950208154107, 0.0641953092334526, 0.03381940669247082, 0.0420037773437798, 0.07287126832774707, 0.024233859531315308, 0.08637675470007317, 0.004421671328600496, 0.03313492092170885, 0.013710362387688031, 0.022666012768500617, 0.03567337810194918, 0.029312295506575277, 0.04602109141913908, 0.02319970091671816, 0.042431084771773646, 0.034079115970858505, 0.0314041477228914, 0.024432967150849954, 0.04876922270549195, 0.04127566855666893, 0.023318644712812135, 0.05740559606679848, 0.03496691797460828, 0.04156453448480793, 0.02619156876711973, 0.03665657873664584, 0.026193343136193495, 0.05693515416766916, 0.04327544357095446, 0.03779632757816996, 0.043930715016488514, 0.016682387329638004, 0.015107588975557258, 0.058871028146573474, 0.004635026063104826, 0.041577063633927276, 0.01826437815491642, 0.029203187075576613, 0.06769214623740741, 0.0030075837816444357, 0.056210550013929605, 0.08179478413824524, 0.032645008460219414, 0.03459956590086222, 0.041802642600876946, 0.04273615072348288, 0.04981759662872978, 0.029685130143272023, 0.019053719638447677, 0.005450824051097567, 0.05296102884624686, 0.09271376287298543, 0.048433001818401475, 0.08825979794242553, 0.04396923205682209, 0.06668057944625616, 0.05166022293269634, 0.07470961646842104, 0.01709385944663414, 0.03201932453417352, 0.09785203715520245, 0.06306850684008428, 0.04011882741802505, 0.02144551825975733, 0.015299300563388636, 0.04413578186982444, 0.03396635362878442, 0.051853981999946494, 0.012936466905687536, 0.03372319381950157, 0.047946641487734656, 0.011893899545871785, 0.020458090351894498, 0.004493302150097276, 0.06777574853705508, 0.011266371700912714, 0.015454975156379598, 0.014477175660431385, 0.04345840036070772, 0.00731541241319584, 0.009014903451316059, 0.011676814989186823, 0.08013664132782392, 0.030214516379471337, 0.02947818035525935, 0.026267920920093144, 0.05355348491242953, 0.05801507657659905, 0.01119688292965293, 0.037876700051128864, 0.027094363002106547, 0.02770853049254843, 0.09281638450920582, 0.06698760975684438, 0.06986961939505168, 0.020863939109923582, 0.04011121764779091, 0.025584885517933538, 0.006860832542380584, 0.019692860610250915, 0.03942548676526972, 0.03206884741250958, 0.009586743079125881, 0.02493652155888932, 0.015277246478945017, 0.00917882818196501, 0.03193061625851052, 0.05310660514182278, 0.023287547452907478, 0.043067961132952144, 0.04033556168100663, 0.10475254830505167, 0.013847370482315975, 0.01903210660176618, 0.02893567125179938, 0.023825495104704584, 0.036942031633641036, 0.0598012793010899, 0.04937899159267545, 0.003704299085906574, 0.015484489733353257, 0.0346539945873831, 0.019196106819435954, 0.07202309276908636, 0.02948936939771686, 0.0641230113272156, 0.021785579655053358, 0.011852639527725322, 0.02378920026655708, 0.024798848499943103, 0.03098223464829581, 0.05866048551563706, 0.028314424944775443, 0.06202631776354142, 0.019627590630469576, 0.03896128399563687, 0.055012365736599476, 0.022113709012046456, 0.03695235215127468, 0.019984768071611012, 0.027180346959669675, 0.0345822055824101, 0.00800438754127494, 0.014087585449617888, 0.015138121355058891, 0.04691638105681964, 0.015625918483627693, 0.02019281030100371, 0.05079832400328346, 0.01821355418568211, 0.012698673460233425, 0.007574384632919515, 0.022761684509792497, 0.033586282416113784, 0.011878084590924638, 0.013634763408585318, 0.1096735896010484, 0.10788246749767236, 0.025678380858153105, 0.06984985366995845, 0.03007181707237448, 0.022516874164076786, 0.031145239115825722, 0.03368677005970052, 0.015477785807369011, 0.03683391047109451, 0.034834624002022405, 0.006898453492405159, 0.06900695032839264, 0.010079551188807403, 0.010638160231922354, 0.05022371680076633, 0.011992120882496238, 0.025663057841094475, 0.014549203848998462, 0.022203599634979452, 0.04933448987347739, 0.048123576279197416, 0.021473948877038698, 0.023565619585237334, 0.029884605868054286, 0.028210453023867946, 0.0199867069854268, 0.03295309389276164, 0.008986991065155183, 0.05866282646145139, 0.08714710229209491, 0.09263812657445669, 0.054177611600607634, 0.013405966489309711, 0.02449307856815202, 0.006685523690456259, 0.03131571425391095, 0.023222304614526883, 0.1869283773537193, 0.05543573766148516, 0.014342164155095816, 0.047125654827271185, 0.027030048060363958, 0.07370710133441857, 0.06967145324285541, 0.016091646260714958, 0.03293974371626973, 0.05021038358764989, 0.02731986902654171, 0.0024694406269450803, 0.043962785974144936, 0.010552222923641759, 0.04825800085174186, 0.015560489048116972, 0.019058555896793093, 0.04572099573644144, 0.013223310799470969, 0.018861241306045225, 0.1034135612260018, 0.008896252273448875, 0.049443398136645555, 0.024098629198436226, 0.022020486782171896, 0.01642430992797017, 0.011941033980942197, 0.021416432856182967, 0.03089571125539286, 0.042778033297508955, 0.02583350074876632, 0.04206995486414858, 0.012702452052118523, 0.08395518535482031, 0.026462777517735958, 0.05743007082492113, 0.04696854004370315, 0.049074074918670316, 0.061762998678854535, 0.042526978733284135, 0.06080368586948939, 0.05568951315113476, 0.03968160320073366, 0.023697080656087825, 0.030085350453321422, 0.018901383437748467, 0.01921062237982239, 0.04228996305859514, 0.04257274592029197, 0.027614517769377147, 0.02061306944649134, 0.0442314383440784, 0.06370469448821885, 0.03353643384096878, 0.05566555068695119, 0.03051181649789214, 0.05599682844643082, 0.045652548516435285, 0.010909509778554951, 0.03595158763762031, 0.014302239154598542, 0.04650523294029491, 0.052024687839938064, 0.03567197692713567, 0.0561195822166545, 0.017058207520416806, 0.014849655762580889, 0.027996538073888848, 0.093449756237013, 0.062385717406868935, 0.02206881034986249, 0.11260897280382258, 0.015218573555882488, 0.0811386543459126, 0.05488834310589092, 0.025025279028341174, 0.03876471918608461, 0.009956174014535333, 0.02232297769348536, 0.032809787296823094, 0.04555763164535165, 0.07031315738069159, 0.031509313865431716, 0.03522501912500177, 0.02180680083776159, 0.02703657895991845, 0.019811985914462378, 0.01676456131307142, 0.05649306485429406, 0.007011893945413509, 0.029586284554430416, 0.03958144125395587, 0.009533432279048222, 0.09840162337890693, 0.02016084621261273, 0.03613385232165456, 0.04702822059126837, 0.040337268196578534, 0.023291203060320446, 0.04216082766652107, 0.0328520532431347, 0.057806786681924544, 0.03980720681803567, 0.061842991172202995, 0.07985742416765008, 0.031334621632205586, 0.02466020004690758, 0.05742922265614782, 0.0621006309187838, 0.028452152286523154, 0.0378650869242847, 0.04786418930494359, 0.007313532023025411, 0.022567920353529707, 0.056639153443809064, 0.028850996866822243, 0.012796251036758934, 0.020301526878029108, 0.0519764711415129, 0.024427454053823437, 0.035854971036314964, 0.03054899682423898, 0.016415823151224425, 0.023573690759284154, 0.02052020175116403, 0.011866975276331817, 0.01304319707144584, 0.17892353689031942, 0.1085621424551521, 0.1341992582061461, 0.12230225945157663, 0.14146361340369495, 0.06835054912205253, 0.09049352843846593, 0.08278167939611844, 0.12491038521485669, 0.09307736264807837, 0.13287401146122388, 0.1934578519846712, 0.10972853058150836, 0.08280874615801231, 0.2158500775694847, 0.18002714695675032, 0.15481720971209662, 0.14316875833485807, 0.1352643681956189, 0.13184565092836106, 0.12444827572575637, 0.1275095543158906, 0.13900025987199374, 0.16783712963972772, 0.09453571760760886, 0.12088517977723054, 0.14194728673568793, 0.12324574882430689, 0.12212425257478442, 0.10248706237013851, 0.06893448278840099, 0.13080807588994503, 0.1019550094913159, 0.07194436235087258, 0.15113887137600354, 0.10894345199423176, 0.10459111125341483, 0.13670862998281205, 0.1238118370196649, 0.10421775414475373, 0.14308234011488302, 0.17084815592638083, 0.13575633322553976, 0.14239509270659514, 0.1632906871714762, 0.14665482698806695, 0.07861212241862502, 0.10518176241644792, 0.1554859331143754, 0.2679741877530302, 0.18209453459296907, 0.09357755830777542, 0.14208342800182955, 0.16905006526836328, 0.28320914453693796, 0.10991126006203038, 0.21236010055456842, 0.11938654019364289, 0.13880233120705399, 0.09940219790275608, 0.11393502700541701, 0.15955612542373793, 0.09565824523035969, 0.16027035138436727, 0.09007707078542028, 0.06907382673983063, 0.28450639492699076, 0.0986100286245346, 0.07522666015263114, 0.24570428846137865, 0.10238862050963299, 0.16390549418117317, 0.15375193687421934, 0.19458564503916673, 0.08589739685079881, 0.07272323234272854, 0.1139788603676217, 0.10028662080211298, 0.13228836788662843, 0.13891153463295527, 0.09276428659047399, 0.17533494159579277, 0.11273674773318426, 0.0870151679430689, 0.16717825856591972, 0.1465498169085809, 0.1311491211610181, 0.11235083772667817, 0.21584421502692358, 0.09969907054411513, 0.16872461273201875, 0.14460973601256097, 0.15483958779701165, 0.11626593050147806, 0.170740133151412, 0.10002976815615382, 0.09949148632586002, 0.15355909722191946, 0.07998054434678384, 0.06116758419999054, 0.14813681532229694, 0.14497463857488974, 0.07514010622565236, 0.11387907500777926, 0.11368730065545865, 0.14140367162014755, 0.16321321204304695, 0.13330615684390068, 0.09810749201902322, 0.11828518286347389, 0.06600448715367488, 0.11486118659377098, 0.10476701467164926, 0.1632638850382396, 0.09739178006670304, 0.08334116544574499, 0.09640196710824966, 0.24879710535917962, 0.16900966529335293, 0.08798629404710871, 0.11697634309530258, 0.1368467797126089, 0.14610553931977066, 0.13310936811779225, 0.1874206137976476, 0.15274846500584058, 0.11344327232135193, 0.13033325065459522, 0.10542245914361306, 0.13650881499052048, 0.1682223475405148, 0.16115092699016842, 0.20001971987741335, 0.13077830177332672, 0.1460410649222987, 0.10675801962081875, 0.10748976535562958, 0.09025057218968868, 0.11599082526351724, 0.14250885588782175, 0.10655063217771904, 0.08782617335340806, 0.16764359788170882, 0.09234324882605247, 0.0788550108139004, 0.15770011501652853, 0.12708295934966632, 0.11110263863312346, 0.16136352558221134, 0.10429675597697496, 0.20164772894765648, 0.06746955960988998, 0.12215557375124522, 0.24088848116142408, 0.15135479478963784, 0.08778092863836459, 0.17623628037316458, 0.11796988121100835, 0.063495373220316, 0.2746100431042058, 0.1670891126351697, 0.12911053055099078, 0.1689612857465233, 0.2104485181293317, 0.11215511430054903, 0.10352807079574891, 0.141400631783264, 0.10535839865250246, 0.06669373624026775, 0.14859793415027006, 0.1303172915109566, 0.14577501134148665, 0.1615575458854437, 0.17683126058961662, 0.09776851627975702, 0.16738202263201984], [0.03273213914196406, 0.03018588898703456, 0.06592755485326052, 0.03520739417789238, 0.02685455515581582, 0.005620486643497965, 0.059641314670443535, 0.09246803141598191, 0.01053550127627594, 0.028732687500970702, 0.017332315311900208, 0.04745518535907779, 0.007938759634271264, 0.04845393801640187, 0.059361093278442106, 0.048188922594168355, 0.020680129062384367, 0.031969784692462, 0.06274959538131952, 0.021668160866413797, 0.016153225009994845, 0.005894848037444587, 0.008573602086731365, 0.026733786100521684, 0.017223296786791513, 0.0306615929252335, 0.08649076893925667, 0.0028674544259307106, 0.02283772623299488, 0.041038656274655035, 0.0444646813640637, 0.043218578943716626, 0.014921342987301094, 0.03239538560488394, 0.0567289982656283, 0.0278502951176571, 0.009953368272233223, 0.023320722726306746, 0.018216156367478625, 0.05933891196868249, 0.03388688700007541, 0.04257763137242623, 0.045928820834628174, 0.049562657451523204, 0.012438035437038966, 0.023545456917158196, 0.007246520752752466, 0.05371928833691137, 0.024520630482584238, 0.04758012740473662, 0.07416875620505639, 0.010517086684038597, 0.011972668979849135, 0.07300624251365662, 0.057073269970715046, 0.03149125126323529, 0.03791314416698047, 0.07627104768263442, 0.02437722380273044, 0.01654102304019034, 0.03421520634687372, 0.018654936126300266, 0.08392097361918006, 0.04309275819520865, 0.04521438452814307, 0.023126631176897457, 0.030655706633946726, 0.03266775295404451, 0.025989633352894868, 0.032809339463710785, 0.05506542717505779, 0.029002584982663393, 0.0572868592238852, 0.017966089071705937, 0.018763491551258733, 0.03181257491399135, 0.03413403320259281, 0.04598983131082995, 0.03634109048705016, 0.01902418300908591, 0.04711483897907393, 0.04018161565597568, 0.03498245303386024, 0.023254387446546128, 0.030692551085459333, 0.054763570693986754, 0.018072910839691758, 0.011988662050238677, 0.016364344395697117, 0.03782049021018403, 0.004234137820146445, 0.025252729055604765, 0.03554513159074953, 0.015759745945355723, 0.0329445782782776, 0.03211960183190448, 0.07439405018729822, 0.004859730143964822, 0.008421032639619495, 0.0492503956359412, 0.01796637405641377, 0.0368957623307194, 0.0834736969055874, 0.05716198842440333, 0.05270172668887036, 0.03709911249045815, 0.0464312929793128, 0.028944878972002437, 0.04373690166643687, 0.04537922443289842, 0.0356138773661639, 0.017916567889707427, 0.017500166215800812, 0.031602249414260895, 0.0657626979851297, 0.04153318616694637, 0.04251850043822612, 0.022244930899302875, 0.07204974562461887, 0.03038955805823207, 0.010229958653716105, 0.06444584471838814, 0.06573071184435061, 0.05408612472404327, 0.04158391683761563, 0.025110180722549558, 0.03600788229544248, 0.04637904917555196, 0.07801461805190359, 0.08190798413540636, 0.06763603139136519, 0.05504555966971176, 0.023285713712019578, 0.027366199397615025, 0.024758138095161746, 0.027645050148878778, 0.02070907536627991, 0.02398253694575812, 0.06792772002518177, 0.02681904741828995, 0.023146586891795908, 0.02009400712060077, 0.05133185608844672, 0.04517880893711533, 0.02205066123445119, 0.05526150004672153, 0.04131773094247494, 0.023326990693541508, 0.10399695884968553, 0.029306880797126462, 0.031687385203050714, 0.05344798628773008, 0.026707833832395927, 0.05299897252448967, 0.023380131859864508, 0.06418735001768384, 0.05283006480229752, 0.04149686758007322, 0.01131008462315159, 0.07218195138765232, 0.013797776357802962, 0.04956970064501677, 0.031033324942524945, 0.04117252105580909, 0.004265649834581251, 0.06130669744951384, 0.0828366678740297, 0.03764952313421028, 0.0022620684508832967, 0.02414744470401534, 0.04614475442628775, 0.03064434795773455, 0.06094870237367494, 0.018416400533169508, 0.017261155648157, 0.03776223458615797, 0.016827678640506098, 0.04436618182808161, 0.015744395786896348, 0.017353058127420287, 0.019818681358758892, 0.00496853281012071, 0.030139297379979064, 0.028750407442982708, 0.05755233604993139, 0.03191893867083958, 0.010966212405557079, 0.02228650134722037, 0.015511364809104373, 0.02868792454579047, 0.03344381381092327, 0.061464104003139904, 0.03476018871047667, 0.016276672582275102, 0.018700855983687297, 0.057997007189052444, 0.02770947026354926, 0.04595867298277361, 0.01857558824121952, 0.005547479244082102, 0.03242930217779108, 0.048103053987558396, 0.04479228485641735, 0.060609808058610985, 0.028785782866179943, 0.02983977845204728, 0.008940737029271466, 0.020816936989181807, 0.005235789518337697, 0.01031078489696873, 0.035771066788583994, 0.04211271274834871, 0.03041071817278862, 0.01570057769172958, 0.09058876082833324, 0.08633954383965049, 0.016782215097919106, 0.019538695757676448, 0.018468026870063374, 0.08986506930419377, 0.0219060722073274, 0.045222649084670205, 0.027912664360233715, 0.04951909211065088, 0.027214202464425137, 0.0456839646877987, 0.04458847329286592, 0.014077804367324072, 0.03688302283574428, 0.038835052733442614, 0.022034917525681, 0.01392178881048624, 0.02709056150966457, 0.07671182403074843, 0.0767249401126589, 0.05171431913705809, 0.03379254009840744, 0.04594566885914121, 0.07052021912698235, 0.04084508041185992, 0.05576719184006963, 0.023835761339536736, 0.01590438586260591, 0.06685396549957139, 0.030794205809278146, 0.016718702523836067, 0.019926017117021338, 0.03220974860180702, 0.09438004810363054, 0.01527624563979251, 0.013272904075815209, 0.025391158681096773, 0.011942501312920024, 0.01832714773315404, 0.03348665990467582, 0.05836427105324609, 0.03318840305187872, 0.08325263019651175, 0.06740638121430363, 0.025924921468166367, 0.028545791815434183, 0.022955287513988357, 0.017021934734657407, 0.001764101778722501, 0.04014123264434082, 0.0642198518450771, 0.015147205242621047, 0.012544544230747436, 0.026947955501132777, 0.025510185597730533, 0.007291173445992172, 0.018759545870125294, 0.0832393987636481, 0.027437023186524, 0.021963993652856777, 0.056294298198606284, 0.02069807461729007, 0.005096538441388735, 0.030583581754139492, 0.06617713360381977, 0.06252452531563384, 0.06963732971676759, 0.07009922886001212, 0.010463783517479897, 0.019190237491524646, 0.031206263162727867, 0.027645492892978445, 0.02864992997742125, 0.027831711739833866, 0.01970838040246495, 0.10626709274947643, 0.03701634818155851, 0.05987689524356808, 0.021848084604633704, 0.08077523777527468, 0.03195869403758219, 0.016586803797898547, 0.03315155181501593, 0.0657790642497795, 0.04013819280745728, 0.023763700920556272, 0.0395131025995527, 0.0708528912759253, 0.05512201360293797, 0.05787110501634223, 0.12356569165629999, 0.03590645148817982, 0.048078080506197045, 0.022213908278250268, 0.009778211242519319, 0.04436192741351468, 0.04297721046688301, 0.021912313033161417, 0.018527776967468004, 0.020251067621367316, 0.02557720959053508, 0.012914771596635026, 0.01950194121205381, 0.02577051064664764, 0.007406970535937164, 0.007518517452159098, 0.025465286935546567, 0.029083015131098882, 0.029735406195478778, 0.055823710414447954, 0.03823838296479412, 0.035366235833082876, 0.045236151931541305, 0.009668112150393426, 0.030946302826383283, 0.032022476329335144, 0.03833017857479198, 0.02239163695568485, 0.048224616928824356, 0.03278313783396568, 0.026731395960918496, 0.02238069218583405, 0.016385962521391254, 0.03704154897215111, 0.028349547613678232, 0.00451746181352064, 0.008064957817883363, 0.11206480128956692, 0.04053028766065836, 0.041239448357373476, 0.020677825435996056, 0.02349624446859317, 0.011243615332724792, 0.014378153652484928, 0.01850779241483126, 0.020145628368481994, 0.0662370618166668, 0.10745186238948788, 0.1899144606930869, 0.22210782606686863, 0.09780086204409599, 0.1825759687594005, 0.0882632245442697, 0.18334681168198586, 0.14744857725288185, 0.08779454005083867, 0.12450572050043515, 0.0880578930622765, 0.11993676424026489, 0.04629159279699836, 0.09108690731227398, 0.14500579690294607, 0.20900204431797775, 0.08967550019068377, 0.12992500327527523, 0.11916514778775827, 0.1683799847960472, 0.09734343444662434, 0.10563915608716862, 0.0820975803903171, 0.06489114689507655, 0.11070231654282127, 0.13821706761206898, 0.14423378690012864, 0.1242368577846459, 0.16001079816903385, 0.2453344597348145, 0.1370243387562888, 0.09415168714310442, 0.09794014492737395, 0.09350137918123178, 0.13102485425770283, 0.10586653317191771, 0.1347077116370201, 0.08420458090092454, 0.18243994962956223, 0.2994144878217152, 0.1089696909434029, 0.0980916346556374, 0.09883161102022443, 0.2341594493814877, 0.0695658324818526, 0.14354447674538406, 0.09594627656042576, 0.09600844393883433, 0.09087367089731352, 0.1399073526263237, 0.19855769404343196, 0.06626903438674552, 0.16707332991063595, 0.151984163160835, 0.09894496029508965, 0.15125568796481403, 0.10677977345351662, 0.20941812199141296, 0.17031398601830006, 0.0958865179813334, 0.1220023605440344, 0.11907164566218853, 0.24316065066627093, 0.13012259267270565, 0.17199399801237242, 0.103654332592019, 0.09589390722768647, 0.09301044552453927, 0.16082892141171864, 0.09731382996376071, 0.18751326096909388, 0.11521528687860284, 0.19578107446432114, 0.09635121268885476, 0.10665755572595767, 0.20213132085544722, 0.09740676211991481, 0.17637672355132444, 0.0824538723432592, 0.11892068519123963, 0.1734700288091387, 0.20423552580177784, 0.13650521875492164, 0.08130445437771933, 0.24375108469809803, 0.0839309480839542, 0.173892186156341, 0.07211012845592839, 0.15979001644466603, 0.129439755742039, 0.15670923675809587, 0.09379824503724064, 0.06881586129644088, 0.1247336675545999, 0.0794171363647495, 0.21405907081706183, 0.17620106440569672, 0.11071536477122988, 0.09487847957227911, 0.10270348789968661, 0.11353203827249152, 0.07503702318561928, 0.15291550675673143, 0.16817303161535943, 0.15234399028122425, 0.12542113209409372, 0.1625407024153641, 0.1333260786320482, 0.17402961663901806, 0.1778637466153928, 0.07266384017254625, 0.09413650831473724, 0.12201542912849359, 0.13346004858613014, 0.1736799268318074, 0.12327841350010463, 0.13722382805177144, 0.0952339233564479, 0.16856169647404126, 0.09605592103408915, 0.04931727544005428, 0.13739954148020062, 0.14493084592478617, 0.0831690686089652, 0.18551755377224513, 0.11099621720079865, 0.11313886794128589, 0.10024738112198454, 0.1854179176901068, 0.2903926319309643, 0.11215822199093443, 0.11824437576745238, 0.0872009236897741, 0.1157827050025974, 0.1766681136297328, 0.1315573142575366, 0.14304910546966962, 0.1358001801584448, 0.2504639673445906, 0.09394951084894793, 0.11180904108498778, 0.07459004502743483, 0.13587842881679535, 0.1315067091158458, 0.1707417480647564, 0.14548906311392784, 0.1989410256168672, 0.15519286026912077, 0.15886965154537133, 0.1422589650111539, 0.09544650837779045, 0.13634185466383184, 0.09073874420885529, 0.09660315274127892, 0.11578875753496375, 0.12668612492936, 0.1430673444909709, 0.13079525157809258, 0.15687241085938045, 0.16988916881382465, 0.09939092743609633, 0.09322298983378069, 0.11364128241049391, 0.08905353463654007, 0.13659117557108402, 0.12111962719687394, 0.20084671835814202, 0.21045903542212077, 0.12373923377266952, 0.13435875464762959, 0.13811451382935047, 0.15801798153136457, 0.1104294979678733, 0.13419916321124348, 0.08331494006727423, 0.09881692752242088], [0.0029691180555216435, 0.04704090241076691, 0.03195308594565306, 0.036990485819322724, 0.044967716692813804, 0.03853413602337241, 0.06633937132677861, 0.05614594669480409, 0.028098006200577532, 0.014029972737521997, 0.020092758616166453, 0.057679486727075915, 0.011274763482755848, 0.021395657810249498, 0.028781368995883634, 0.10271581009562526, 0.04095255018078855, 0.003023523205359067, 0.028693593705871275, 0.05892822186329535, 0.06409738984491144, 0.04817645790587578, 0.04543940370370235, 0.03873759814138923, 0.05772248549120767, 0.011138750290099, 0.0819476241511958, 0.03344553728987064, 0.025270859511303048, 0.03369120767872248, 0.03583731894780483, 0.086359974529062, 0.06759138378713812, 0.08502079746020691, 0.0684501648481403, 0.09095502724604947, 0.027761371407125677, 0.019604510261810253, 0.015643962426111102, 0.006014447892084718, 0.03506659816152283, 0.04380247529063906, 0.04200534815234797, 0.01732154356847916, 0.04066672408953309, 0.026972043494294797, 0.06162662671080657, 0.0532818062763129, 0.04455303340884192, 0.027933147636109164, 0.03562123268576605, 0.0193848481202232, 0.014351599184530122, 0.030476013597633158, 0.10305049749357359, 0.057299907452293804, 0.030846588712717806, 0.032637022103049924, 0.027634936584425823, 0.050933009811810086, 0.10057463856147868, 0.04612621006422809, 0.05449851795232721, 0.06074191204139164, 0.04731326975992747, 0.032095415451164754, 0.010917829466052353, 0.02550348167174629, 0.012963598128408194, 0.011685853923803993, 0.028523430693894625, 0.020250009106738225, 0.08293078068111624, 0.03450389246323279, 0.011846990723695074, 0.04361241084656545, 0.022104954213968346, 0.03521563159301877, 0.016771599417552352, 0.05148948995130403, 0.03674048298437681, 0.012595415697433054, 0.032261246017047336, 0.02168687146955303, 0.04451924575758832, 0.046346258970775774, 0.06172471573310239, 0.020448660411472832, 0.031613964321357865, 0.043389155862054656, 0.05863410407411201, 0.02475209574082068, 0.05926527734845877, 0.041682480834424496, 0.03030584380030632, 0.030668625940701792, 0.06037789157458714, 0.0600095216983131, 0.024131349853373, 0.02210134101499404, 0.040263321450246234, 0.019367151926936846, 0.03793892849768911, 0.08054376233901296, 0.03341227889593158, 0.015144977951422334, 0.019605614577553103, 0.017631315160542727, 0.03469692210533789, 0.04084787258346166, 0.046127007342875004, 0.012900720832736363, 0.016094655563522662, 0.02541408298670181, 0.015022677103323596, 0.02071887850096183, 0.03891228358926518, 0.054118891180093796, 0.008268339359866721, 0.03682804114318319, 0.0072066203491496185, 0.05180803160848362, 0.019614367679293667, 0.016963645183880414, 0.03809480156217303, 0.047331644488232474, 0.1141617934086493, 0.1155784252498831, 0.02529797037797315, 0.042367750313133, 0.01963877458391445, 0.009061139675655534, 0.044386829648699076, 0.015094654401764274, 0.0799108384443181, 0.062014294123010974, 0.03243368212133646, 0.039181159875754795, 0.08915550487914256, 0.07489828313035624, 0.0351456305278199, 0.03915922962395208, 0.11476575742874827, 0.08984545285680465, 0.04189450267170157, 0.03493631604526724, 0.041553755956036706, 0.017650146203647767, 0.043234368453600576, 0.062144070730677674, 0.019094424954216396, 0.03241743799299002, 0.019795938561271344, 0.049864988907107284, 0.04170498444831797, 0.007790525177759784, 0.010508088461522545, 0.0673958503508142, 0.019517757863338505, 0.06085108832589217, 0.03564064217997449, 0.05690921377390623, 0.03178507728236062, 0.03284636711967843, 0.02832352409937552, 0.05801316310784646, 0.03641194989904761, 0.05006260883861354, 0.017351645078243952, 0.011311059169072126, 0.024857609632558057, 0.06429195297615868, 0.007512161275371909, 0.042331316375306675, 0.03883723083085247, 0.013139935809054544, 0.05107162433809467, 0.03290505700611642, 0.006401033889103148, 0.04251508401440723, 0.024932297678398233, 0.009018855917799686, 0.003109398597319211, 0.02224964162866984, 0.04104435596881168, 0.009734881692565978, 0.01589590247853526, 0.03248594967382295, 0.021820659915517484, 0.03889586304181388, 0.017731748521327972, 0.012110307263875646, 0.09555957945329802, 0.006419077831586557, 0.05226436337190015, 0.042394247105611224, 0.00638275797246024, 0.014716634061187506, 0.07430675665714911, 0.024766075258542384, 0.017750903564904417, 0.03778165765106678, 0.030466721060552766, 0.033122089824506214, 0.04873120778107217, 0.06529642907636506, 0.03170582439218249, 0.02023013651237956, 0.06446743570268154, 0.07808084985507385, 0.031093256548047066, 0.011330548391145254, 0.04137855142887149, 0.01997352983536465, 0.030292486838464226, 0.06234117836824485, 0.03159560655642833, 0.04624571365171245, 0.06293459116880383, 0.02652705683639007, 0.012600489443034997, 0.024121858844799653, 0.0857276681012341, 0.08400948172701256, 0.04876409298075097, 0.018507911158459525, 0.004725783090439758, 0.07098008945052113, 0.07919611036777496, 0.011837583683830286, 0.069482996926776, 0.06469085692827191, 0.009785621693091733, 0.041537630571318526, 0.03429888667804854, 0.021757761415626322, 0.02639928869237857, 0.04342085701812591, 0.039429018540041785, 0.06927755009382963, 0.03004894365689584, 0.05441969932456102, 0.016942690326167003, 0.05087073726047363, 0.05222808210445302, 0.009446606089893197, 0.029732498672923872, 0.018207489778952937, 0.10790831289653267, 0.0471886025209512, 0.003192035892945049, 0.024539939892877425, 0.02111858651707215, 0.046720728876867464, 0.008159204635636082, 0.02835996142987694, 0.06812047825327941, 0.05608773517555424, 0.010733839606733193, 0.0273606388031372, 0.023984813430745686, 0.027721387034814273, 0.028878460571702038, 0.02612516054484461, 0.03888381565255778, 0.062496264332107136, 0.07303751619266612, 0.02213569015397557, 0.03760878728436572, 0.016609622930575694, 0.05542248247989586, 0.015093970777732986, 0.07169377258313553, 0.022041280487818376, 0.01830789939101253, 0.042912651252533705, 0.03516779487420406, 0.13332059606909752, 0.03832042124122381, 0.034818573256156275, 0.041945240127721, 0.03222381802541869, 0.01083690398705325, 0.0568264935697828, 0.02583377555544887, 0.01980592659674585, 0.050257436598518064, 0.028590527629213672, 0.028185128400634443, 0.051319557641233714, 0.040712304679410796, 0.06000924349895545, 0.03640235202120883, 0.02327894532520856, 0.03785912599414587, 0.011476306194838668, 0.035168649828327556, 0.018281370368120924, 0.026257417198004465, 0.027885490729074393, 0.04298315443364637, 0.025160767204527344, 0.07392802555114031, 0.020905441704339216, 0.03459278394335082, 0.03281869985429304, 0.035112151609999795, 0.02305742060499532, 0.05045154171862772, 0.02766178791145129, 0.05474329606762954, 0.02971282455005816, 0.0518517665831106, 0.025489259577755417, 0.030364767781325748, 0.008011107582465878, 0.02463138266466558, 0.028017618460580707, 0.006605063856113702, 0.0456667977518269, 0.047888026240148714, 0.04464113778833832, 0.0415149505383202, 0.03712165681645274, 0.029505257295178514, 0.009904059980596815, 0.021261421531172733, 0.023230031432051743, 0.051469201754246435, 0.019191672593089085, 0.006751986619617257, 0.01481021591462195, 0.017858856790033833, 0.011674165309939002, 0.04743642047313707, 0.028263940243050456, 0.011653391112174307, 0.017330751288682222, 0.012025157056216682, 0.01504715355778379, 0.0315339718280094, 0.056762935194586, 0.0014887497236486524, 0.008410176927489894, 0.06897902861237526, 0.013412616980661238, 0.035834411425249915, 0.05979297403246164, 0.06220432464033365, 0.010529683686659803, 0.07583829161844083, 0.02591482486708888, 0.09961107133754663, 0.11384985728987626, 0.15478109807840415, 0.16061225160956383, 0.14850699688707078, 0.08164870233408042, 0.19031358856175626, 0.15331745733107838, 0.11483624364648547, 0.0887063214821475, 0.08873175297464643, 0.20010745445532457, 0.1039479754066893, 0.09554302998419319, 0.09144687013966696, 0.2082836250109332, 0.16894227319530078, 0.07328194486243383, 0.13919892135475362, 0.15316055289336614, 0.18065447972289153, 0.17323167302778789, 0.09422525390982628, 0.22118884537901196, 0.12590000139815466, 0.1539276231612478, 0.1335864868015051, 0.099462886074824, 0.08374935854226351, 0.1487154292740992, 0.10948471937860761, 0.16713331240628446, 0.11902834155729838, 0.20990555440740927, 0.19494248660547392, 0.21649114388440335, 0.06832163674490792, 0.11112816512052502, 0.06823742376374346, 0.16100884175726346, 0.2284242542726653, 0.2064712986882244, 0.25600084023816244, 0.07657762337476015, 0.13018211376454147, 0.08902424227978502, 0.3082683655832495, 0.2374299338885716, 0.15198549308947154, 0.14954223776502268, 0.09423545229115657, 0.20481289124914578, 0.12978884843843325, 0.14145528099366597, 0.16669845288353308, 0.1749670806207827, 0.1014222577214241, 0.20335167965718678, 0.1172133960894176, 0.14227024226316384, 0.1429485058678048, 0.15740786998399667, 0.11320771210427795, 0.19800291024148464, 0.09016393005315747, 0.15329373574682645, 0.07345371600240469, 0.1238027989332165, 0.13352594790714128, 0.1170519861791815, 0.09682580043694802, 0.14360421496842588, 0.13785691479487078, 0.1350629518606833, 0.139009474377547, 0.11516541455473218, 0.1467193149562393, 0.09425947243081671, 0.10564597536410604, 0.17223818919488362, 0.16517625456409796, 0.09434017738593475, 0.09082089444356305, 0.11000759846397809, 0.0900662617225732, 0.06183972063341311, 0.1485651201967682, 0.10162498362894569, 0.1210187426103013, 0.17427422851324081, 0.12826276889869145, 0.11960418708622456, 0.06852930917271546, 0.12157301072563444, 0.13480361577655586, 0.1150081708495106, 0.2339306745146002, 0.13892499676772527, 0.12113327932144914, 0.10425822197326592, 0.1193802569593702, 0.17344659220959457, 0.20550138716186794, 0.1322667904730354, 0.15707412574972424, 0.2232147338134902, 0.13241256693644182, 0.15910690809999192, 0.09105412050017289, 0.10086204563932759, 0.11273991649172135, 0.08955240715295076, 0.1097988403801407, 0.11161844738359962, 0.10216076845037085, 0.09443648864648171, 0.10606960513229881, 0.13939838350883552, 0.1663054996835334, 0.08091684803366661, 0.19003286505384104, 0.11025441557701145, 0.11265687059078898, 0.11266618687659502, 0.13082745485007763, 0.11655269297105925, 0.23842854744621686, 0.15409604912357672, 0.15306044183671474, 0.10451981757900544, 0.15423483667629106, 0.1439139662044389, 0.10354775509663991, 0.12129174438970429, 0.18121292761393956, 0.18389619434518473, 0.1099190835707954, 0.2388137382056032, 0.20134845429233142, 0.09693944826722145, 0.09871507263077156, 0.14966966664152487, 0.13467374417398656, 0.14989358319767884, 0.10479413571634463, 0.10228260619831936, 0.13601438009313174, 0.08163562017892088, 0.10707047821155616, 0.12095966935157776, 0.11818523465522698, 0.1302907879331282, 0.13503173924982548, 0.1287898277597768, 0.1512745783797332, 0.12406236571925026, 0.10077251294361693, 0.14287459983357362, 0.11250128929636308, 0.12063325329550675, 0.10845150732036148, 0.13742284237274102, 0.08022952598652669, 0.1294458761279072, 0.12266310437449388, 0.18462604018194334, 0.11466047593525477, 0.1162209707711424, 0.14700850658118725, 0.09113985339977912, 0.1034392166350569, 0.16128104286534445, 0.0919858847877809, 0.07839723716356925, 0.16131112910807133, 0.09213171553398881], [0.02538924690868173, 0.029924642826829637, 0.013706107973121107, 0.0463887182995677, 0.05633011466956564, 0.0045769888425378925, 0.016586649431181804, 0.002936586330179125, 0.024800432879211645, 0.06547671583081995, 0.026522848222936903, 0.06529944855719805, 0.05258336304021733, 0.03691210823931864, 0.03761867353958743, 0.03425845616896238, 0.038254257291555405, 0.023668772175109813, 0.06274345463940076, 0.03205833690507071, 0.004199152130500546, 0.03631786084068673, 0.038225019217601845, 0.06065519526600838, 0.009977593668736517, 0.027930966146024208, 0.15379781941218035, 0.03780341826911483, 0.07053188314395291, 0.058031802464808734, 0.03346967617315905, 0.023076787690765092, 0.03329114343172737, 0.007284712944445866, 0.05962505018604653, 0.06243460585496255, 0.041414249156202586, 0.011910204742369907, 0.015442157629877329, 0.04888197147686567, 0.03446099208667874, 0.027249722076313834, 0.006708568436027105, 0.04281645195026483, 0.0072192699382347715, 0.030664853285998106, 0.055299504793116024, 0.032831564878246615, 0.025433129464675273, 0.020372920636353747, 0.06166755594313145, 0.07597722166350909, 0.00887749926187098, 0.0463067376986146, 0.05030219616102321, 0.02942285260983876, 0.022229406018076197, 0.017442777420261076, 0.028916475496121814, 0.0385619525664619, 0.031012154649943113, 0.022543638977887373, 0.0450822330479111, 0.08092963163341794, 0.03235621038558228, 0.01107155581537102, 0.07724889806870903, 0.019706039456650615, 0.06225313166422503, 0.059779206556933265, 0.016877937729337385, 0.028040949887196933, 0.04445448637540851, 0.02932432932513101, 0.017362695021022643, 0.041496938826250176, 0.06154985725879669, 0.05905710280473743, 0.040748952355767996, 0.05423041519575885, 0.05001209529915026, 0.024086145850430642, 0.02177487576513418, 0.08428023077015366, 0.04534878195928676, 0.025418700417503715, 0.021685802776898657, 0.01478178020832794, 0.027614745078608394, 0.0844411114230752, 0.03525092898468886, 0.0505320804326662, 0.035570077930710146, 0.02225634046564145, 0.04835473958935056, 0.04036151225279484, 0.07257757123027529, 0.015096040309539862, 0.05893713781344039, 0.011326625610568693, 0.007003246016600835, 0.042917516348617415, 0.032568849689726315, 0.010527173107090806, 0.0233015167926039, 0.044149206685168405, 0.05357057720954929, 0.043279993148254495, 0.027485630042584877, 0.005663242831360549, 0.05080777260341814, 0.03717578016221523, 0.03025658555062754, 0.025612364489851252, 0.008572810745265867, 0.01807110254386706, 0.034278276176857095, 0.01452987577899226, 0.01900000511003392, 0.04183326488626855, 0.010100644298030861, 0.04627903311380318, 0.030843396205455065, 0.03677676085914884, 0.05522659959803734, 0.0514007952463414, 0.05872480385005474, 0.03788085947079318, 0.036932209839246104, 0.01659327362930136, 0.041176605836621354, 0.053526516538113356, 0.013960905506142547, 0.029012199823877642, 0.020257705390187244, 0.05877920200249978, 0.0432197969140751, 0.018025601681854044, 0.048501842588718445, 0.014032948961747544, 0.044050004865442, 0.026496862028060213, 0.03806206903287342, 0.0585444424567478, 0.016006015141361525, 0.02730431530757674, 0.05052438584555473, 0.057314068478132994, 0.005807550690535988, 0.04110902374876397, 0.03370104643649288, 0.04631069016509822, 0.06074684499097722, 0.09558948927692004, 0.027677786070853472, 0.04144240157412631, 0.0402586700926934, 0.02159478408949716, 0.04483600965301905, 0.03326158305363996, 0.04333204696221011, 0.021434290201536248, 0.013120256597176194, 0.07278426656765596, 0.04126560927501746, 0.0497560908219644, 0.03436932200565934, 0.015594624448567629, 0.07283200829156808, 0.021030577132478356, 0.0500283903176231, 0.026343034746657525, 0.018527882140395895, 0.07461638575685875, 0.015234639568786536, 0.07539889948176486, 0.01470726858159261, 0.04498645104467869, 0.057866504548915794, 0.016223468651462878, 0.0711001358660204, 0.01414801662654749, 0.04797976078199489, 0.01839049406615751, 0.04335454718342849, 0.0739037272121225, 0.049783968433205567, 0.06143996172717639, 0.0553907338263733, 0.023130371601187756, 0.03769173819039549, 0.03387361146243555, 0.013934690305697066, 0.019683686816798787, 0.006865787120269877, 0.015634586768490926, 0.037824469818068404, 0.004239373141899705, 0.03586721859340157, 0.03957511730758207, 0.020928956335410476, 0.03457749994205577, 0.06853848975151777, 0.01662744634917804, 0.03562427930799978, 0.0618146216230733, 0.05040027161261865, 0.025879013485142162, 0.046867736881332736, 0.04392351915261575, 0.04474149311759642, 0.06922505862478699, 0.027241041917087774, 0.015839365244443928, 0.03248223130192075, 0.0296332832824971, 0.020658086852303574, 0.07209123125565903, 0.033488573373428414, 0.045016323548874686, 0.006511749175842851, 0.04305636836215854, 0.06851014734378882, 0.03137395630723663, 0.029532883848462785, 0.06415520781385047, 0.0020576203366675016, 0.08439729163157088, 0.044870384237063785, 0.012003203903857087, 0.0152200985633369, 0.02495521180597799, 0.040262344359819374, 0.07436587062797376, 0.02072448828922851, 0.039186381202723296, 0.1040411993329014, 0.06225834281316825, 0.03196228688050594, 0.007815885424081768, 0.04864275734871626, 0.00238330802780443, 0.04904203788776483, 0.03211252471165998, 0.0850464596546122, 0.057193445307867866, 0.012947851875131684, 0.028470196229006563, 0.05102735332080296, 0.08300976215728692, 0.05376038720299091, 0.03897434240207076, 0.014397011836990714, 0.04900040976437075, 0.04330196071948324, 0.0317962323980672, 0.007924346702306398, 0.05576188230354871, 0.027345191953437667, 0.04527788183518818, 0.022467142636222497, 0.026469050573983362, 0.048424618518246074, 0.015030580339953303, 0.024651190798197473, 0.029606627034289495, 0.05460989947563835, 0.014544633915647864, 0.023486558381201963, 0.014781873506893004, 0.08875229222966091, 0.05747964459338358, 0.055187804358346124, 0.02882037797410573, 0.04249228863045573, 0.005705011326686612, 0.022106777776830962, 0.01612280967778393, 0.0723937221669725, 0.028170056441532712, 0.05488299624994397, 0.06100411832864795, 0.04779981329504933, 0.031530545226165226, 0.009753863709712667, 0.025825841784743325, 0.0853140874366675, 0.04881746654531785, 0.027235013133447086, 0.04944924032315612, 0.05866531668496983, 0.019198033858888915, 0.06548073954348053, 0.035673286499721665, 0.008188655599951744, 0.06072480617357152, 0.017666770311604654, 0.06470371516687529, 0.05180450322638665, 0.05537547018112881, 0.008029924206701773, 0.009979678467581314, 0.02911000046879053, 0.037844374642840455, 0.02148904967387872, 0.02131106993848724, 0.00527422089362517, 0.04792185799617853, 0.04094153755743589, 0.021792634722909758, 0.10766856611839362, 0.049725787448031564, 0.015721273009798357, 0.04145291208156517, 0.06449925220970597, 0.033430450063730986, 0.03914723991017256, 0.011444113949047667, 0.0413589180181069, 0.03752312563093645, 0.11582124579165663, 0.09648048718060766, 0.022404810713071908, 0.02189899847975799, 0.010624264682909208, 0.09542708192020655, 0.02679797212061073, 0.03513711491333587, 0.012305338584285761, 0.043568580877035856, 0.0274662917945534, 0.0486243622643607, 0.046084483553256304, 0.005344228320089834, 0.021610213975821222, 0.011029773325260197, 0.03697940534246819, 0.08233824319073133, 0.033935928118548224, 0.045558411960623095, 0.08875425319586482, 0.09581027100128786, 0.011237118359921234, 0.03138594602101615, 0.015524894797376223, 0.03506301549662437, 0.04908193235418626, 0.06878244344677244, 0.026234552264213562, 0.010564404323564043, 0.02762676532646375, 0.007903053425252438, 0.17368551796036108, 0.08786750292139393, 0.09589039241628987, 0.11754305554287774, 0.2034343523638589, 0.08623910030083996, 0.09863275276230914, 0.20423703214951924, 0.08349213270204407, 0.29111744303788456, 0.11912307861660208, 0.1620875767299107, 0.1531425988567727, 0.16564706287213735, 0.16674740239977837, 0.13248806074261665, 0.08292458565639597, 0.07470011697815997, 0.12753361516765185, 0.10962738815162863, 0.06654286397887127, 0.1817516437066453, 0.09275393214608942, 0.1861830609185355, 0.11995135274316583, 0.13982419137443813, 0.2468003939305033, 0.12365766029272761, 0.15606845542788506, 0.10246848408132792, 0.12327875276761395, 0.0912926798420293, 0.09231432966355767, 0.10981724224984646, 0.11741517883326326, 0.17772189208439418, 0.08728086868567125, 0.0808058057778648, 0.1271758915058204, 0.13528130442968436, 0.11937119173152105, 0.14661505126527377, 0.11243190230535609, 0.10259334131010941, 0.08273397838430745, 0.10855619170303855, 0.1569020085568939, 0.10995063544916255, 0.14837618890617574, 0.12278568851096289, 0.14175731050116674, 0.1739309440766062, 0.07704887273056166, 0.12041192874312401, 0.1458590818302972, 0.09210985313568797, 0.13049600406416825, 0.1458525000406163, 0.12222931693707194, 0.19027652697903769, 0.32674392419201986, 0.11182531914008514, 0.0770385589982782, 0.21025360215987476, 0.1284962256572076, 0.09643311186560563, 0.21522471255489758, 0.11951057639505182, 0.16213157294051989, 0.09790534286626748, 0.13428066883768353, 0.11278271169534751, 0.16568052821925708, 0.12153681766773973, 0.12272938367511545, 0.14743587507733277, 0.16061071812042169, 0.1771134225917714, 0.1468400941895587, 0.09990290246371712, 0.1322172438459737, 0.11628294815974576, 0.17961732537618705, 0.14068396309656755, 0.092015652119049, 0.08369628353310482, 0.14323589258960315, 0.10649727218385253, 0.06658152011888367, 0.15512644526149544, 0.1432762789939131, 0.21704997175506183, 0.13542982217456612, 0.097230953696583, 0.10464497336319514, 0.24357482844165393, 0.10909205116331577, 0.11103409981088978, 0.1621634369449956, 0.1586712614766189, 0.07181457217250552, 0.1590698736586741, 0.11506514064967632, 0.11021721828728914, 0.08630548138171434, 0.09380229589130197, 0.14978594040232046, 0.15913791715034417, 0.18183217224265846, 0.08511790939207588, 0.11613732097404343, 0.12217469486807074, 0.07249343967331306, 0.07922633910285574, 0.1277449923966612, 0.09729242218392235, 0.0953773520886898, 0.09376526144998414, 0.15175393622900757, 0.14197605662047863, 0.14445285871624947, 0.1993080587791545, 0.16428752296737262, 0.12571120581456594, 0.129397985126291, 0.16257642049874577, 0.13467406987079553, 0.13155533293528215, 0.0678329218977264, 0.1226084687347923, 0.10689233562776021, 0.16236830023782595, 0.15050194412469864, 0.17131322382816247, 0.18397886705185684, 0.22161754380379403, 0.17553401019956383, 0.16917465786848748, 0.09825071040540934, 0.051215565364275656, 0.1703158180628504, 0.1225237739937646, 0.13140296111149447, 0.10578116668122155, 0.11353160401007958, 0.1793543387736593, 0.17649690567382745, 0.09125463438353368, 0.1263345895068986, 0.2171463780105114, 0.0900190288999251, 0.16160059214702674, 0.12808104364999703, 0.1043320262272443, 0.09641701701496329, 0.12287229672074318, 0.11017468092697007, 0.11419878713786602, 0.08026614652148314, 0.069334397757692, 0.11831034294196538, 0.14563646806137903, 0.10095541205789361, 0.13333131692239217, 0.21607065573334694, 0.17217526185725415, 0.13694564226482595, 0.14944190957716533, 0.10672412679663726, 0.10897402678217206, 0.1196763017880065, 0.17122578780565942, 0.06525911643568959, 0.11551498222563948, 0.13804264340017522, 0.11033503910792725], [0.013616838209730173, 0.05613174156418868, 0.051787363431815586, 0.00930610778076308, 0.04156693649877395, 0.023662604291790297, 0.071771654832576, 0.0010299150141820843, 0.014237861448366727, 0.047277114021458795, 0.05577148696673768, 0.058447554441435, 0.01676015762080039, 0.04024043446406722, 0.03516853787004948, 0.008929129839608712, 0.04232094157487154, 0.01779234509116837, 0.029864751933408634, 0.03958149214408227, 0.0938046911199178, 0.04772139500294413, 0.061645286423819404, 0.03131279655333076, 0.03919269157839673, 0.05315863859972783, 0.03855509597009846, 0.009125318062225623, 0.04574100234146629, 0.03805601989318218, 0.04463689694447177, 0.018037082494369576, 0.026522646358768855, 0.02652442072784262, 0.020612165298578993, 0.0034589327655599584, 0.022886577361662473, 0.04635044553184083, 0.07607147017759935, 0.05702681067798819, 0.03466008783185056, 0.031192122492939234, 0.01345060221917395, 0.04560545818614108, 0.02282924284892423, 0.028702499477991035, 0.0388058926910162, 0.02207286629293646, 0.055100870451756885, 0.024314369407615492, 0.03522158234513231, 0.03705222232799445, 0.044767586181738546, 0.007233137497678399, 0.011619351554795035, 0.014406509630914246, 0.02820526562365038, 0.01710143529011735, 0.037436025483267646, 0.04018606345302292, 0.07592171749898366, 0.011662454643685902, 0.09627459251454898, 0.0028561220429505086, 0.032558580062219074, 0.021978120751945034, 0.01916107744909823, 0.02261803695000708, 0.05184839087139283, 0.03368291937346969, 0.034356792856539996, 0.011017827716256891, 0.05237558204680681, 0.025981260230764747, 0.0321786784833031, 0.01169313714906041, 0.06510882092905895, 0.023780101111957004, 0.07951631104307515, 0.03526116807812026, 0.03085558269438999, 0.042519531811454465, 0.02520498733169266, 0.060725796834698746, 0.03924628227416958, 0.06836993486753531, 0.06783756307725396, 0.01860849549328642, 0.07150762328611952, 0.07596349490008183, 0.04989364344094481, 0.01280627554349069, 0.06077239183442933, 0.053278281286891015, 0.09231846872717142, 0.028474487962999513, 0.0237409462487059, 0.02025114226021937, 0.011499482406569379, 0.02673819488180535, 0.007330017879472247, 0.04244010928752167, 0.01465735215294574, 0.05343441219468202, 0.025274713590208973, 0.050112155465675254, 0.03992747036474092, 0.0641966120206884, 0.043978158184992414, 0.014954542009426015, 0.04491718958265015, 0.06464601254888944, 0.01676829664834908, 0.06052157136478594, 0.022183883103675077, 0.035207183832036595, 0.014347723053236092, 0.06448228204888956, 0.04786236404574343, 0.031051672529429197, 0.027349951876593486, 0.018024717889992253, 0.04207408714241215, 0.04383681255525776, 0.04548398006175246, 0.013817212993412145, 0.02484198466741613, 0.030669793020933867, 0.05951678313847099, 0.028562378603965044, 0.06105187362326043, 0.05986673078898873, 0.04828767997345754, 0.0625538651698402, 0.03294129416878734, 0.05919397688869919, 0.0611576165205666, 0.026588450684877377, 0.04805608918624265, 0.028430790307798555, 0.05447049784873213, 0.02171873038501612, 0.039879779530955214, 0.054815261491707394, 0.03172922706497567, 0.018022324357713972, 0.03612560472850289, 0.004178962321020663, 0.05725655584995236, 0.041528368568313975, 0.06964311762047665, 0.03376588385019984, 0.032925477517502647, 0.03748540926192488, 0.07313403779906885, 0.060569543790604384, 0.05344573015879307, 0.04518890893086791, 0.04804704770711916, 0.0968909262280379, 0.03603868099993893, 0.024831652275419662, 0.012248034605623355, 0.02004899480380118, 0.02337248985921698, 0.013322905321339411, 0.048237281784947426, 0.010711591291640486, 0.0075368234787934595, 0.04526155288996441, 0.04542206034862569, 0.04778956063091755, 0.0360032037964889, 0.04054300679958292, 0.021191082894802094, 0.04248867543148143, 0.01524536042208118, 0.007162507939418512, 0.022572295208062445, 0.05701685656926461, 0.018087090525243963, 0.023211636347696185, 0.022319291551996554, 0.02859381852405412, 0.0067141968840067935, 0.03728489537856408, 0.01090510523811515, 0.053158815018832684, 0.022838572705430642, 0.019294017726289373, 0.015651163378996507, 0.016775623130212938, 0.03266073350927659, 0.012865608341858854, 0.08088608325592109, 0.06370696079518114, 0.05394772054361446, 0.09086549455033881, 0.05025495316034981, 0.021451677661389112, 0.024635372450575233, 0.042353019317878146, 0.0255521478996213, 0.03715458272823265, 0.053036919595407586, 0.02290751355966287, 0.007845970818639865, 0.03638495099065559, 0.020280241234494106, 0.03783452570704477, 0.04173094519813146, 0.06900162382849626, 0.04829099461702364, 0.01794471012960587, 0.08040216565132141, 0.01987206849402615, 0.022958630995292748, 0.04686764867178031, 0.05975976652864899, 0.036340323742479086, 0.059333219059876034, 0.025865159496398907, 0.013556851473237787, 0.08414510052118983, 0.05225285881065896, 0.04274627107328602, 0.04827227383585913, 0.036290563376886506, 0.020957385256354297, 0.016843086474442055, 0.011111694554399167, 0.03011725177722318, 0.03934302440445338, 0.021777881675266793, 0.044490489443497996, 0.042038969562522004, 0.02897491432460291, 0.05967824054615838, 0.045329840654241185, 0.048259429167956114, 0.0342644679892276, 0.03010870223598821, 0.07430898225201027, 0.015100194640191538, 0.056383315207702775, 0.015855224304167286, 0.016634297856528844, 0.0451422257215849, 0.04941047901021583, 0.044565915396170955, 0.0372528074575322, 0.03437902844910111, 0.06395098912928786, 0.018406185188463757, 0.05862444852079664, 0.07008243511830058, 0.05213836620428732, 0.06419656452323709, 0.0410796397897814, 0.048056828789412975, 0.030944345252854482, 0.042646221084786315, 0.024051337003973976, 0.013245799146326525, 0.011418574739114513, 0.01912859088874289, 0.027396450185083916, 0.01613402586164219, 0.0392235276023192, 0.02633730960743768, 0.07704026212117501, 0.02087585927386369, 0.03170647917847548, 0.015576080086507967, 0.008072772844960647, 0.02414859821354704, 0.012798431678675115, 0.04281603804390345, 0.07795310206711292, 0.062040058097669055, 0.030061778146773577, 0.024105986214375923, 0.04720149129363043, 0.022114930375080024, 0.010830789538366454, 0.02819395444488951, 0.04198853744726096, 0.1126853758469224, 0.06951699153121028, 0.055729204057050605, 0.02360045557309474, 0.026829573192766736, 0.022334986066977893, 0.008920785555216883, 0.0671399205124804, 0.039853493084332774, 0.020454025927132795, 0.018126725452020764, 0.01891113568230399, 0.03716380062646099, 0.05565926406000342, 0.0304930108998503, 0.04662271788609879, 0.04656159205894385, 0.02638363149682326, 0.04427392481427107, 0.006987441663763353, 0.03424512295584593, 0.030607696888702254, 0.03950791180666004, 0.061209225894085, 0.061147241720131466, 0.038667939736374786, 0.013101886957883835, 0.04057232629773872, 0.011472114544760968, 0.06530826951244048, 0.008834106947428413, 0.0019474659015291504, 0.021267183989818608, 0.05924173218331166, 0.06737210162516151, 0.012084908849958862, 0.030751732909785848, 0.023338995674358945, 0.032257877090679746, 0.04777914511838129, 0.015489865427038499, 0.026429290118228112, 0.01595794772064047, 0.09014532462294612, 0.0050053501202325735, 0.0305422114740525, 0.01795726302745087, 0.017735443144504513, 0.05566857695313437, 0.03808479317064796, 0.04134058739457812, 0.06102777884474822, 0.0812245975913746, 0.05391191425068038, 0.0653093619538205, 0.04756344222862806, 0.03568857050101672, 0.03182899206876755, 0.037943712169570584, 0.016316505980544856, 0.061165962501295974, 0.05225100301738296, 0.009925419414815093, 0.04654736996495298, 0.012635975976341536, 0.04925116238051227, 0.11090539528855256, 0.13772765387381825, 0.15035870538226195, 0.12055784091353416, 0.11256800964474678, 0.10370287498725311, 0.1337484802518572, 0.12570455617138318, 0.1038987273350358, 0.06602533174944775, 0.16192263843757765, 0.07747662120631763, 0.17504868124212536, 0.06937738295112338, 0.061696434393525124, 0.1939794418535062, 0.07074077014944383, 0.21335566070462975, 0.17494491966707365, 0.1679598901953016, 0.1647968313523701, 0.12773794920316764, 0.1033786234578916, 0.07291162759065628, 0.10384362350617136, 0.08389162697962352, 0.08034390663462025, 0.09892476709293467, 0.11222308315336704, 0.16375149387334073, 0.15584274753928185, 0.09734996195350375, 0.1302148870059422, 0.14252223659838947, 0.145521307098014, 0.1214559091521161, 0.1718887843723808, 0.16248145273753575, 0.12214942622397627, 0.08199372382036277, 0.1553006252007825, 0.18566755072346755, 0.09895775746554136, 0.11550859042576381, 0.08915913504149232, 0.14481785627348082, 0.24298482867223875, 0.12571398780814239, 0.08967450952955655, 0.07877421764922993, 0.15113937349191733, 0.20616685359605721, 0.13978839186685427, 0.054455851670354605, 0.12293223850429058, 0.13271386362612247, 0.14893242477306298, 0.16670664958655834, 0.14995759619133814, 0.15944941900670528, 0.1398279775998422, 0.21390101286981786, 0.14568936665143284, 0.11951126850077085, 0.2238490962024246, 0.1549587928290878, 0.09721367140965802, 0.134502929768392, 0.10855112304644925, 0.09074149227568082, 0.15538219868072442, 0.10930959627564464, 0.13957022928765841, 0.2228005560381072, 0.14118580759635993, 0.19383946007915906, 0.2044580445757934, 0.1603217843387808, 0.13138706982135773, 0.12237518839538097, 0.15329678915441036, 0.10970248162214245, 0.17984561169786112, 0.10422021044152123, 0.18839462367551668, 0.228235730103084, 0.15304402128926345, 0.12779531255364418, 0.18749043505106652, 0.15172332072896616, 0.23303802098546708, 0.16825023532978126, 0.24454980183924946, 0.1491428656237466, 0.09743493489388909, 0.09525073066885982, 0.1051031541345375, 0.06617858566875968, 0.14225759437041624, 0.09143394404756171, 0.10978442151099443, 0.14249038616461412, 0.13197685245956692, 0.09318128028618437, 0.1597946576241936, 0.13608462203826222, 0.11557161275829587, 0.16999420603471144, 0.14569031660045895, 0.13828406615981034, 0.12006895643259798, 0.13457561443958962, 0.1892433895596436, 0.112868817789214, 0.15519649721682072, 0.07922690907227141, 0.16357875242829323, 0.20927664744002478, 0.23785591817327909, 0.14265740077410424, 0.17979571223258972, 0.16092996884669575, 0.14776755656514848, 0.13621116881924017, 0.09829722398093768, 0.1348246910742351, 0.10138129456234829, 0.11412207196865763, 0.11553463259977953, 0.13705533423594066, 0.14895838552287646, 0.11162845577512469, 0.13060873587216648, 0.1282588198248829, 0.15628203111035482, 0.13200285392148153, 0.08920078352093697, 0.15199522328163895, 0.14225265463548048, 0.1142894665577582, 0.12545518098132952, 0.11515516867595059, 0.13253179910991872, 0.1433168011052268, 0.11278664041310549, 0.11757971000458513, 0.08314877362655741, 0.2709248922765255, 0.09366308764687606, 0.1420349534600973, 0.16097331366368703, 0.0747592920171363, 0.16361254347222193, 0.16831089636044844, 0.11490436856235776, 0.0757685721452747, 0.19966559245118073, 0.07477360232067959, 0.17030779777893, 0.11649047130984919, 0.08829265260802847, 0.11009603871830873, 0.13173806241580419, 0.12422906820263181, 0.18747948349586555, 0.08938904984721116, 0.12790485524705478, 0.1376627180725336, 0.13843597657978535, 0.1378849654325417, 0.11611761631710188, 0.11299897437649113, 0.09647678916475602, 0.14913479105702468, 0.13770637501563343], [0.011128636725646044, 0.005718382707397852, 0.027300327218004634, 0.1758148287023817, 0.02643984473044319, 0.056812410575470755, 0.07338639175785439, 0.02904297477964844, 0.03325560516012566, 0.024911512454439486, 0.045763855400894365, 0.04191955079191497, 0.06627258991024323, 0.041224873425172906, 0.03398315754852124, 0.01496551392067756, 0.06653222454977886, 0.026527216292119453, 0.09627715737691947, 0.014589651321460093, 0.015809348551556468, 0.018762826586940458, 0.05942291460399117, 0.03705810522660613, 0.043623409899217744, 0.052561578673443625, 0.06443325789379221, 0.015782369999215007, 0.02340448278534625, 0.05162017918857081, 0.04090145988655942, 0.027246319223195314, 0.06272231827356986, 0.07019898029310362, 0.014957040714632188, 0.03740561015105673, 0.0473578868300787, 0.027438929869926403, 0.03855099083323564, 0.06159952602216175, 0.055257021715598445, 0.0230588353505092, 0.04098343709483743, 0.05792630384010928, 0.017890749632247856, 0.06142003993902888, 0.026072239902402674, 0.010475709618601416, 0.05760389792599848, 0.03450367193935173, 0.04087498684280685, 0.03176413769168513, 0.08144507397498403, 0.06225387126739536, 0.03408756373184068, 0.05461088674409049, 0.048250109489474974, 0.05527881286772234, 0.018012210793261017, 0.01979747205041349, 0.034274479773427756, 0.02785232393736286, 0.006716327059880963, 0.12240912871701376, 0.02706091631469982, 0.009264183646467115, 0.029829620782818114, 0.02796990896708199, 0.027133714640513062, 0.05030996199431164, 0.053499215681638033, 0.02473412643718932, 0.023418282491288016, 0.024105144830952798, 0.01058993165913437, 0.043228756968996356, 0.03257738905293601, 0.02155060806710805, 0.007573723909445107, 0.017192550668759004, 0.003967828516449247, 0.021999967883207967, 0.038930091740829606, 0.017305638707642044, 0.015802578468407904, 0.019512997940182686, 0.030395695407475744, 0.023154349332409244, 0.010682496558209615, 0.03207780746743083, 0.039803284885627885, 0.025875042358945523, 0.05680031229608825, 0.03212773746677807, 0.01647448928893677, 0.04278770920687488, 0.06145469272243125, 0.017604787833988667, 0.013856831804982253, 0.060036194909896166, 0.0020093097035507007, 0.022768156037532856, 0.03241142617272479, 0.03082200199631708, 0.12301333700971943, 0.015571311681664415, 0.045249888872993846, 0.026303454102682214, 0.03171212798250573, 0.08305684570223093, 0.00952835429260241, 0.0543079547850149, 0.026673411750899892, 0.08952476363629103, 0.03451689997954028, 0.04166537835927946, 0.014205820176617374, 0.054001704789698124, 0.0036403187467450543, 0.05676037033221551, 0.016588266040863733, 0.012355191400274634, 0.03994135997657265, 0.03834675518529756, 0.03826280344011528, 0.008968016681527453, 0.02240083789053772, 0.033121065236628056, 0.03916472236492804, 0.023766432024006332, 0.06256565132311412, 0.021466586772086363, 0.04235627628596766, 0.046359955200127194, 0.033039651212415526, 0.015421660783301507, 0.026092755408691506, 0.010059649756710445, 0.030729504102574925, 0.04412191261404327, 0.05166990223473736, 0.030904559352036034, 0.004037482256535441, 0.04323043295049241, 0.0869951918721199, 0.04090943606570363, 0.04582901172606008, 0.04855096173871841, 0.021229596542460576, 0.054258638859859536, 0.004635176613062088, 0.08463679413710322, 0.013576504391884165, 0.03654715817953859, 0.0473959390739245, 0.021966327813320925, 0.02081576481993709, 0.030057350705776895, 0.046456992493144104, 0.038270325000796995, 0.0518083946247186, 0.02350067869494004, 0.040457355324178934, 0.036905255035630295, 0.04985526889296515, 0.051943236496299505, 0.07478527990835053, 0.014061047096869774, 0.03802054947508233, 0.08878147602081299, 0.017612104137827243, 0.05004032574860113, 0.019952435877972415, 0.025665973845337118, 0.0295808698449816, 0.0538834395286228, 0.03506434203258582, 0.01304748117191983, 0.0507096496543714, 0.06066200097224542, 0.015880436969122717, 0.07266005394714219, 0.021336679546428577, 0.02898500414033021, 0.02533081656188837, 0.04863293555432132, 0.05653431639075279, 0.047901403558041365, 0.004644603160808661, 0.06347899338496582, 0.02680448436045221, 0.0063258683242435965, 0.015882584532456737, 0.05903923697769642, 0.034155576689434905, 0.04381184585924659, 0.020429999002122452, 0.00375947670545429, 0.01857856531361384, 0.027850439306348562, 0.02296556392684579, 0.026425407201583897, 0.02886014012619853, 0.030911480409226248, 0.060992562877280374, 0.03414120192506483, 0.057325162525687895, 0.020616628362664154, 0.06800789572298527, 0.0013007899043649168, 0.04339256550052336, 0.03466802669156875, 0.05019432605643358, 0.03746995562687516, 0.10512818529137544, 0.05846420569079263, 0.027967125277167985, 0.037222456586148055, 0.023243573294686418, 0.022420685039833188, 0.029484137892723083, 0.039295109654111524, 0.04594427446967789, 0.01655154542199203, 0.012977827855918025, 0.05393039754458836, 0.04514621890016964, 0.03768170605014477, 0.04916930730853762, 0.03197313326277903, 0.011507657905375319, 0.025413329812831113, 0.03586078268874969, 0.059646980437849245, 0.039138055938695154, 0.06261813600680657, 0.04506367172247597, 0.07894750870764256, 0.010168193307306086, 0.05682791170797177, 0.02947186997958592, 0.026328928003619825, 0.014887351775541902, 0.062372363837701936, 0.062282844712691646, 0.05336324065657599, 0.013853043035071875, 0.03948973046083536, 0.009310614101455679, 0.044133454494710476, 0.010135386987323207, 0.04862324946693011, 0.03350381666262235, 0.025572307175025344, 0.048187087156942914, 0.02412007429770061, 0.07129756241504635, 0.037795472624046464, 0.028800720814615488, 0.0042993119568564, 0.041243149765900204, 0.038233507690685134, 0.0241159114853612, 0.07466055838657276, 0.02321567532739469, 0.023704488562153916, 0.042827698668198924, 0.02111531767461981, 0.09119858060564313, 0.03314206250278013, 0.022222970113424317, 0.06646257293011461, 0.06811481927122388, 0.03310087542714817, 0.004683216892382396, 0.0629431882074901, 0.023529260286263058, 0.024011347542649934, 0.058947275126619, 0.03801521279716066, 0.04065798795116799, 0.029765078531844274, 0.032942763197102716, 0.03973669685157282, 0.005848306472346718, 0.05649789941630193, 0.0014088925132195332, 0.01776463202466922, 0.053192921581545045, 0.02085576785196151, 0.018086120220167295, 0.021172324794211557, 0.07441210600414447, 0.04349413540746484, 0.023416029755026102, 0.050819321269435544, 0.010597976539949221, 0.021244434406980872, 0.013318899420223065, 0.01564591151795217, 0.04184616044429796, 0.04276958553652678, 0.06792942314807858, 0.03941671670015369, 0.04861224702160273, 0.044272058842969794, 0.03526967012190393, 0.02525852544100157, 0.02341996186545917, 0.09043024826262679, 0.0192275857552886, 0.02759666381669896, 0.04380319453775883, 0.036152383113013845, 0.014582954180826033, 0.046230219304561615, 0.06285829669130699, 0.04194598312356642, 0.03401326075462358, 0.06608647453997817, 0.01791561285166868, 0.026134278359157697, 0.01832862863583224, 0.08039508174572672, 0.025098861062100956, 0.03031695481123669, 0.021711264803473438, 0.05001517924081002, 0.023137204448825548, 0.05072966643742152, 0.012769615992770662, 0.004895133556731577, 0.021165095003587858, 0.02189007744060031, 0.058005013902272494, 0.06654266041836568, 0.0352412700386984, 0.027322557721553103, 0.0625380485185555, 0.010939570576218622, 0.010900754132308066, 0.04634497993226562, 0.05442289861717394, 0.048791264915572743, 0.021705446365688528, 0.048755892885050604, 0.02571510147702481, 0.08604557532817125, 0.03537945030257106, 0.07551720206226621, 0.024086049159190485, 0.0092156446439081, 0.06938055849501065, 0.0823998066729733, 0.11858141768191542, 0.2141140050121716, 0.09930463135242462, 0.1221142238272088, 0.14322815729039057, 0.09512575130377497, 0.07462723553180695, 0.11546882827367101, 0.15176059944289072, 0.17957756322409424, 0.13210661549653324, 0.13819980568119458, 0.10068749929113047, 0.0770472442465169, 0.21375655276434763, 0.17295411149305956, 0.1567703727632761, 0.08121478597500495, 0.08514792778130088, 0.09421569335141353, 0.14962031000426837, 0.0809375365663852, 0.1419360637664795, 0.15100545782063687, 0.1767452359199524, 0.16553195619157382, 0.19303730955081327, 0.11680176960570471, 0.15662675404122897, 0.11970188255820956, 0.1700855368482215, 0.13078560281012738, 0.0666897464543581, 0.09235677202897412, 0.23318814007299288, 0.08913958644760506, 0.1299277716981513, 0.13295124231704644, 0.20929796701031073, 0.09725938431386437, 0.1457721750651087, 0.11067547369748354, 0.09470315290881054, 0.18110307279442037, 0.1413070753748928, 0.11685229332319327, 0.18664724672479288, 0.10189187180783067, 0.18903723705027783, 0.09007078076579741, 0.17224758011954172, 0.1034980524065239, 0.1796856674232653, 0.17604869258190903, 0.16168971093637602, 0.1643330662378243, 0.12148602253624372, 0.13713878047253403, 0.1405062276337828, 0.15214042977562972, 0.11162806901016406, 0.22126786756728375, 0.15102128125727177, 0.13543424622288772, 0.11826135271361896, 0.18174679896661214, 0.2097610400191375, 0.15974466316401958, 0.229908997459071, 0.12744977538074764, 0.07824817659067256, 0.08510184846818447, 0.07522851255323205, 0.1776870968086379, 0.11962374246546201, 0.10985385599945273, 0.14943919543709072, 0.205020115843841, 0.19839515776506492, 0.17051084259791033, 0.0899620930265103, 0.09397594657327447, 0.20565835945308208, 0.09969275338309151, 0.06176609279853957, 0.2150057628750801, 0.13716807961463928, 0.10689874099833624, 0.12255064398050308, 0.09460471104830503, 0.22459484690002032, 0.11575552288975034, 0.12366439136011259, 0.08736387387450252, 0.19174360111355782, 0.06556074560752936, 0.13182804972997733, 0.1985384372196027, 0.11491005468581404, 0.06389899977615901, 0.227042607696993, 0.1391956101038626, 0.23302670302135603, 0.14186523828123296, 0.10620345973542758, 0.10616445754255567, 0.17980868582214626, 0.14702517140124524, 0.14473888836801052, 0.14372491277754307, 0.10260517496083464, 0.18311904104692595, 0.1304605302533933, 0.1287566473973649, 0.14273279958537646, 0.11416046348001276, 0.16333309561014175, 0.12335837206670217, 0.09878713304975204, 0.09484978432634047, 0.0953996894615037, 0.10700846689620189, 0.09035075109984193, 0.1299059907240527, 0.16117838051702293, 0.08334265822278601, 0.12041232229343482, 0.18788798871849263, 0.1440961935690471, 0.09437911851065499, 0.08583558909595013, 0.16188834527773516, 0.06941695511341095, 0.08901217792715345, 0.10549429564603738, 0.0824576314272625, 0.12044041364320687, 0.2100270257464477, 0.16444081759878568, 0.0815289748300399, 0.15722640257860931, 0.2534210229558604, 0.1882605587265321, 0.2080406823328563, 0.09567142916577202, 0.1388129706361464, 0.11896510209356036, 0.1756784160222326, 0.09251972221370254, 0.18349123107535498, 0.12267644437296049, 0.12654621100851468, 0.09423374916825976, 0.14685614832809993, 0.08410803893847124, 0.19244485348463058, 0.13828205769615515, 0.18653764974858078, 0.15095616903688225, 0.09942009087119784, 0.18365296668240003, 0.16063977298992022, 0.18384481567357266, 0.12508352021021502, 0.17036985659173556, 0.13924206261123928, 0.06638389679470233, 0.12744596201394284, 0.08196515071072749, 0.09982489807797329, 0.06481722729014498, 0.22461744211614132, 0.15461839895163262, 0.10514635645917483], [0.02534623457384961, 0.012208573553445084, 0.027504980164979185, 0.08144777454435825, 0.061695966204362254, 0.056693429459950755, 0.07884182009313788, 0.009346829211738492, 0.02965741538043533, 0.04056240950844117, 0.03639871846618397, 0.03731529035472444, 0.03269925054961017, 0.04091016549084868, 0.06705207058361598, 0.03251343034207821, 0.033354121659483225, 0.01712974037842027, 0.006879245014195996, 0.03416980556877596, 0.005270126358872014, 0.07440945293222155, 0.02623120030122144, 0.04422886669635773, 0.024258912740541354, 0.042525316322488446, 0.06592092556612832, 0.03747814215187516, 0.026244374058608497, 0.019711315066420605, 0.03594206100595849, 0.022166437968345623, 0.05195080894710762, 0.0226267374652837, 0.007515226557318653, 0.015715880352737646, 0.05616539350843855, 0.022487817598240714, 0.004300980728917888, 0.052162488124200275, 0.0182198085822165, 0.05760700561638389, 0.0029216816723679324, 0.05999618169984647, 0.040385573104556115, 0.061305598222783635, 0.026147187487887483, 0.03463996587587254, 0.03250009373628667, 0.03278742617528353, 0.030618098830538135, 0.012661957082205584, 0.044968971982598305, 0.07486068550497293, 0.03693030994119389, 0.04866518632375768, 0.027408867375925183, 0.03484824559252177, 0.08045641452606235, 0.05104045243933797, 0.014853860983358962, 0.05396783571424229, 0.06942846985267741, 0.02128526525172804, 0.047522818337061574, 0.027874797017180493, 0.010570160845028502, 0.02233241611559476, 0.06848280916788749, 0.024141892591225247, 0.044100528582930565, 0.0413108234559851, 0.01689292147888669, 0.1065913171374372, 0.07554704403238637, 0.04955018937055554, 0.014312939651842629, 0.023125823720225265, 0.05302302998357585, 0.033570062036492994, 0.005796411690036101, 0.04682490096560546, 0.04635199598435845, 0.022728721278586557, 0.05668130064649241, 0.02719427049825234, 0.049738486230905564, 0.018893045938706825, 0.047059399275375266, 0.04269858702485051, 0.02163008996285498, 0.018713100148098807, 0.002263962835838486, 0.015526526674096073, 0.004795871092937887, 0.026927105816347257, 0.04058424137266619, 0.02157050441019237, 0.019368914421647787, 0.06989348347165755, 0.05741370456027133, 0.016805957038221613, 0.03270071618525045, 0.055415982114417214, 0.05461158563515969, 0.07392546068876982, 0.03275865289781775, 0.015588314072894198, 0.04912230858047094, 0.04427848456959639, 0.04080345228846584, 0.04130115093929427, 0.01717993670276233, 0.020247800475252525, 0.02852144597896508, 0.06362056293125663, 0.02540104154364339, 0.02942170249298215, 0.0381161516665348, 0.025035580886261802, 0.04998461802357009, 0.03446647125695433, 0.062346864491701126, 0.042609681974032095, 0.03540040346394692, 0.026946620483483587, 0.03985164746908205, 0.04903895394610507, 0.035358995864433904, 0.09604660474828311, 0.05146107629739812, 0.04922496075076716, 0.01781548822431692, 0.0342875110384609, 0.03466819293264832, 0.013265809144026466, 0.03991659005571689, 0.02686449060482638, 0.061523000842758586, 0.04104451203186597, 0.021450498706794212, 0.03470736475927489, 0.04695434169843793, 0.057403736880847385, 0.018508216499217918, 0.02982117302183594, 0.034042488650551865, 0.008439505755502199, 0.018630332446524074, 0.00955592401857887, 0.08673883455672435, 0.004134264674835971, 0.024033250653051903, 0.09497509617358446, 0.03158026487965669, 0.04224237400506224, 0.01220142433885485, 0.069255477349673, 0.01446213762808059, 0.017788302718794773, 0.056807715113141706, 0.012943387114708977, 0.03587700646104557, 0.044857963653547425, 0.03378124927569713, 0.08793971940342869, 0.049053287998374016, 0.037995399574616125, 0.09223756021154778, 0.02585793818746294, 0.04571729093523962, 0.013502329488151839, 0.041682165315640826, 0.022734331066853235, 0.035762520640024116, 0.006892034551128745, 0.007970844162628055, 0.007206337908948106, 0.034968193620443344, 0.031534188959215365, 0.024748574144073894, 0.018717471609956453, 0.022322685923427343, 0.05257417228338974, 0.07309029943176679, 0.017878033885998384, 0.031144984665193727, 0.006502820503166211, 0.027853609761223197, 0.031779224917824776, 0.06334982745881591, 0.018574500888852135, 0.0217677630218012, 0.005363124672190419, 0.04958348847659571, 0.06832249169903142, 0.04972643884164946, 0.038305608821766715, 0.0540941891127399, 0.03642472332077367, 0.06916893020804439, 0.0600038966430085, 0.06647779925593308, 0.01737219111860863, 0.012629052374645003, 0.023177190517474498, 0.01603983502302851, 0.053714019512491565, 0.058441786893776486, 0.04370075949866857, 0.0433294888851898, 0.05342735203781298, 0.07603160624525376, 0.06576755629586321, 0.03010921792260238, 0.018942679078983407, 0.05483448778146079, 0.045040920443300686, 0.08683628575610262, 0.06123219430446625, 0.03344883836273636, 0.02479771534646196, 0.05575319705531001, 0.0841419996161546, 0.041421970884714804, 0.03940025204792619, 0.04335068631917238, 0.041452114802918265, 0.06436283952955689, 0.048564237276358266, 0.035307454344417365, 0.03966631580676351, 0.07112525523241077, 0.042846504266240766, 0.028614965067910295, 0.022153881677825536, 0.062466571639691076, 0.08992159127124719, 0.08071039696889264, 0.03321900498121977, 0.043676220279719145, 0.08756974139916045, 0.01614036677139146, 0.04344462609982916, 0.009708686848171055, 0.03569071127900055, 0.04732342403648155, 0.050046978784458976, 0.0464015188626945, 0.036417490137474876, 0.04622689448297024, 0.11907649040222168, 0.029308546600597243, 0.038689880166202784, 0.08278055302798748, 0.03115257407937731, 0.025660820371870483, 0.03553800358037863, 0.01266363645637674, 0.04604859583611999, 0.047876022955668826, 0.031288521963038614, 0.03241231844627431, 0.05490449223933475, 0.028479156283927814, 0.096172567989145, 0.0389578573937927, 0.040125521165984016, 0.03112596193594592, 0.03523503090920193, 0.08423757805888142, 0.038591034577361176, 0.033230129562850506, 0.018528048381475464, 0.03557334168414984, 0.0483176712212818, 0.03832084871828556, 0.005685870277894927, 0.0436595249255853, 0.023583744951922978, 0.06080035426254783, 0.005701060132456145, 0.0262391018415136, 0.010831389193689185, 0.01759784642074789, 0.05777482768254621, 0.006798246168598, 0.05165450966783932, 0.023629430714728575, 0.015576146243672286, 0.011090491183235176, 0.06565430201590061, 0.013682310901848333, 0.024773269426077604, 0.018780665272580724, 0.037760524677910974, 0.06318949641925947, 0.025299804118861045, 0.019990963096331273, 0.021342755827520574, 0.02536983911081084, 0.007090765159643654, 0.039199419253106625, 0.014448538089969327, 0.04039230077926602, 0.035968859746520004, 0.033073150486286194, 0.06438094962920461, 0.012005701760894485, 0.03262552771983402, 0.054146704330508194, 0.0046711215815906015, 0.026424743933603168, 0.02753266609007759, 0.07726896234921046, 0.0865487361858998, 0.022931923856958747, 0.023439676700425998, 0.0038778560452296263, 0.03437698605869498, 0.016996778048841015, 0.04882431635633111, 0.04157621207247887, 0.026782567679349865, 0.0540542267928166, 0.02391665967713509, 0.048919287510216236, 0.004755951181453253, 0.016714422664205943, 0.012255561255317713, 0.043260933099580665, 0.021447479225961224, 0.026729742031810538, 0.04061147098296455, 0.030808801097529273, 0.047974922827311924, 0.04298632319218346, 0.08428506193948643, 0.03124284977093339, 0.054143885017505715, 0.022043139673769474, 0.032403738370963504, 0.008737246921685125, 0.0545631857322795, 0.03302165985639606, 0.023650519583108168, 0.009540366906938809, 0.050746232869901826, 0.039023583688374074, 0.07103081672851529, 0.04905898090718048, 0.059814320744148324, 0.07223864977381059, 0.061368552701813836, 0.08110303804278374, 0.12291861352111612, 0.1316711860043662, 0.09693622522588287, 0.11497530261320726, 0.1156876693878855, 0.14816599232809885, 0.14693880746407167, 0.10331686320049421, 0.1507034690252372, 0.17124515319509165, 0.10953479526298386, 0.17546441964805126, 0.09155899126614843, 0.08835968508252076, 0.08613974920340947, 0.10094132567090647, 0.11778006782489163, 0.12684840336441994, 0.14841546251305512, 0.0691391018086246, 0.15714938885399274, 0.131331009258117, 0.14619642230016844, 0.09905949022088732, 0.14833029279751436, 0.14925272044326576, 0.11254203532423292, 0.12369544112256595, 0.10313306841999292, 0.14786864471222672, 0.15369248363588536, 0.12556533435625689, 0.15931649399655207, 0.18323228854153836, 0.11526344929422651, 0.19515828788280487, 0.1457696102027382, 0.11093892848917417, 0.18996661289462022, 0.222360173240304, 0.21335765559758457, 0.08625162605728422, 0.1408915812415736, 0.08084828885538237, 0.11709371608282838, 0.09373453059898955, 0.059519320859440734, 0.21135453879833221, 0.13100213690527848, 0.15644444525241852, 0.15512352756091527, 0.1578319679413523, 0.09315883434776749, 0.10911117228014128, 0.14963506135557378, 0.10722436316843544, 0.09786368760147265, 0.12148455690060343, 0.1035574513620564, 0.14630711850311073, 0.13881326919155462, 0.10613238319222416, 0.11574785544403962, 0.16100251781088964, 0.13949944451451302, 0.09601589425333909, 0.10047199656920773, 0.11208088256950889, 0.10934903273092848, 0.09146687335201673, 0.15595754209373677, 0.11986834076898438, 0.16312364542058536, 0.0875073636748961, 0.11659689274217401, 0.18414821582181112, 0.07810834409402949, 0.17285917087325028, 0.2371113481266158, 0.17120161838829517, 0.07369802253586905, 0.16348244116774627, 0.15747349789100035, 0.13925925668861183, 0.11322085532758917, 0.14073607458599977, 0.21356520588908876, 0.12575955821999482, 0.156284148139613, 0.07492773833551578, 0.03930218338168093, 0.17104117199778557, 0.1739723618541445, 0.13955139315554074, 0.09409296672259058, 0.1132008114031383, 0.16653335174279554, 0.11898255401423999, 0.06465342215129308, 0.09724771351154361, 0.09459846852613346, 0.14575975787426743, 0.1338890591370208, 0.1670306771993637, 0.07836709663804088, 0.21040287986397743, 0.13409313532922948, 0.12801186021949562, 0.08302535489201546, 0.08099485241941043, 0.09099695392485176, 0.07529348906661783, 0.14662512072495051, 0.07459571758019072, 0.11621208196239811, 0.08038814033248595, 0.10663207673600741, 0.15670676689062799, 0.11362912306295973, 0.1720616886658328, 0.13458261692098208, 0.11031236246760402, 0.09252559832696404, 0.10483060018824679, 0.12007804880184786, 0.1742402067674058, 0.1420681338225092, 0.12379001533346516, 0.18411838742239134, 0.13809727903987679, 0.15235980014715875, 0.12218015028962068, 0.06932539359799453, 0.10213944888008492, 0.08122771885246038, 0.10870444481926304, 0.14731824424649986, 0.11329221685550042, 0.20416339752929552, 0.09935282090944902, 0.15454538858362607, 0.11451298956360136, 0.10638202979628529, 0.17666462595973695, 0.0812980897192444, 0.11682855816824095, 0.10528131707438401, 0.26507187634706497, 0.06456718035042286, 0.08399984652974776, 0.12922570508505615, 0.11216679188821997, 0.1400987809257848, 0.09647545923611947, 0.14088502659329347, 0.1063142034358212, 0.10442214924842119, 0.1853704202388014, 0.13577735424041748, 0.10481850869421448, 0.12466206853943211, 0.15266341742660317, 0.12817188591829368, 0.13612081509615692, 0.08931381388434342, 0.13617686208869728, 0.06130620890430041, 0.12953907969806874, 0.12467293867043086, 0.1754213191036667, 0.1354253167020423, 0.09729662910103798, 0.1249637994915247], [0.04446069157815405, 0.019162085073600923, 0.008561321451062602, 0.010010759612279279, 0.05140559927427343, 0.052113358796175034, 0.04319748668266194, 0.07261867688170501, 0.02241345864188458, 0.059624941620443545, 0.0427245409893138, 0.04018685394631965, 0.0436585206937577, 0.038880975983504734, 0.032657228875905275, 0.016110699524038603, 0.016853744563247477, 0.039776323296661885, 0.00864369051331388, 0.028950527776032686, 0.005435377625482423, 0.04535161145031452, 0.0689883448981813, 0.06557606692825045, 0.042687262275389264, 0.045179090529148064, 0.021484182881457464, 0.0762888795829245, 0.03871685193319406, 0.016969975915604403, 0.032819218933582306, 0.0229712805843779, 0.021184170319299613, 0.0541073425140764, 0.02277652407065034, 0.041951604786195924, 0.106263693289033, 0.03557580815894263, 0.03774309989863208, 0.040829745520438464, 0.010377837727511567, 0.031017549003341367, 0.0657027562015823, 0.036425720767251084, 0.006880147889855185, 0.02342756824301822, 0.010560487480168896, 0.015028225823438593, 0.03825168903650982, 0.04918159218505025, 0.0636124951498849, 0.04507556304867778, 0.03575628151052764, 0.020945644904194132, 0.020593103553567613, 0.05445421300828457, 0.04808972416711705, 0.038571740434105904, 0.01765375261727188, 0.020334339135193398, 0.028632260925535644, 0.0208596134491797, 0.028327958325722387, 0.06598590886486427, 0.05647308878334505, 0.025870185744549547, 0.08876078070274421, 0.03390406411407249, 0.09111630144928183, 0.0353729024396411, 0.019225064997694323, 0.04558379595567073, 0.07149800844490528, 0.014545704304639782, 0.04318396347974028, 0.10593279211648873, 0.0588860237704856, 0.030821082581366812, 0.06894122064113617, 0.029892293669815575, 0.07392113842070103, 0.03152050969323941, 0.08611157642943518, 0.0998803683157478, 0.0731736778148583, 0.04364251744534288, 0.023091220130611743, 0.05600492336920329, 0.0667185638366001, 0.10509377678057977, 0.04645033945728626, 0.0007400825447153433, 0.02500800183042884, 0.06186341507626431, 0.06254078301468066, 0.037567576460008106, 0.03523588586332543, 0.025815621351024935, 0.02768008460822914, 0.051844367158732245, 0.08135110366025142, 0.048276867517935376, 0.015581298020801373, 0.015950792568868825, 0.06714924358363662, 0.03367263278258698, 0.04147891015080469, 0.03168129874393344, 0.006536262525644685, 0.020583831372537782, 0.023981561551668813, 0.03854461260406034, 0.02905784487458212, 0.06214810801403863, 0.02514298110535102, 0.020810455283416168, 0.010780561831779778, 0.024564752222171853, 0.027257543888741305, 0.036097367493701835, 0.021843636807586466, 0.026696631219238043, 0.030492196657827923, 0.01276443452973451, 0.03115858250696744, 0.0124268989810454, 0.07585740594991616, 0.020358318562752435, 0.035866889503917525, 0.006388514069840312, 0.07494530560714857, 0.019622471083753874, 0.047902112627135854, 0.006010929263928639, 0.07413834426552057, 0.029350015268261944, 0.025332426386220113, 0.027844069558860998, 0.07341082580387592, 0.023142030529145683, 0.05649850670514362, 0.054396937867360454, 0.04762357060930558, 0.08949348995728151, 0.026029802625998855, 0.039712517256183286, 0.06409694879714932, 0.057045076840690205, 0.088255740303014, 0.04078652283975056, 0.03902145308841552, 0.01697623879382653, 0.014626716296853763, 0.036866656571094475, 0.017312354507989118, 0.01611095227833305, 0.04008736374921032, 0.0583268159202167, 0.05137838323467544, 0.014394450367295315, 0.07909226736852101, 0.031964783889374564, 0.02930140501952597, 0.11447063540773732, 0.01119859198973115, 0.03707249016900148, 0.030452013814023564, 0.032836592822734795, 0.048512956992323907, 0.06191029506070273, 0.026826087219108428, 0.024218790964888673, 0.03820941969752312, 0.02464320613736553, 0.01463967970838504, 0.02249254529098315, 0.04404376234327044, 0.05477598788482802, 0.02003310521000198, 0.02844817776765142, 0.05252196579905493, 0.08330418528722865, 0.00959261749604983, 0.04223799406151686, 0.05188063146280391, 0.04895377405253904, 0.03522611835173198, 0.019837123940565755, 0.13446817520473683, 0.029450550409299985, 0.02827542953725372, 0.03939545480534434, 0.013163464858994951, 0.0212150758930615, 0.1041632474267057, 0.03616297843733004, 0.030754996663225547, 0.007364703741456781, 0.02188708510116807, 0.08372288889118604, 0.019809212402573655, 0.05946479378534215, 0.04392555815034679, 0.020224482619336674, 0.03799000522121787, 0.018398214098332182, 0.020405388536996076, 0.07347722045545067, 0.09941847595785346, 0.01028431354955371, 0.04258037604657667, 0.05612559064424463, 0.03545606029885156, 0.06915497274271079, 0.05738293978252581, 0.015399794992325562, 0.03279373315828187, 0.060888977721333504, 0.034983348700084856, 0.02731018463548805, 0.006289715554365622, 0.005187287411120321, 0.025290124816820025, 0.023142676833750944, 0.041822672954627445, 0.05413027699770672, 0.021732949086331894, 0.026114254790757383, 0.02101124736613461, 0.033753100250448496, 0.06377807126513549, 0.05341626477560826, 0.03005375786285315, 0.028683880477079322, 0.08184294655386891, 0.007289455904226218, 0.03502984870491283, 0.03017223346978426, 0.018929201677175503, 0.04144122092319386, 0.054353596443044286, 0.05936413311532565, 0.04931134843666639, 0.014028688609999205, 0.10261107821549688, 0.025817738380283117, 0.030239533965608904, 0.030108773482165167, 0.030994658624487262, 0.017397746443748474, 0.02507105978604938, 0.06676051765680313, 0.036198574384408336, 0.042984212948275466, 0.05330569749431951, 0.08849906296070133, 0.06254806369543076, 0.07228985881166798, 0.041850886440702846, 0.04533299244940281, 0.018276832665183713, 0.014988188864663243, 0.054101099991904836, 0.034439085583601675, 0.016020182952550904, 0.037016134443027635, 0.024919385156993355, 0.012981178970741374, 0.07956644799560308, 0.03714806879205363, 0.03962751038904701, 0.06473949431840863, 0.08557645657232829, 0.03899076294952205, 0.012064515479973384, 0.021974002044381838, 0.11715173082692282, 0.06255951736654554, 0.07101191274289574, 0.025913347357085774, 0.03043943377477782, 0.013970120011695793, 0.025437234601538097, 0.03954142465123108, 0.07749221394104616, 0.04115356618006315, 0.020322780291150724, 0.045194900395082574, 0.050030310571725876, 0.037149256228336265, 0.03860942966171673, 0.04936848787058677, 0.027363397047988007, 0.03932921282414879, 0.014847243570589592, 0.03208106443552034, 0.03814281130741749, 0.03137995794947658, 0.08412617617951972, 0.03734685919646706, 0.024806483715240444, 0.018741892085277607, 0.0207054655599807, 0.03238554345443845, 0.03706627818090575, 0.04098368476011923, 0.04214529599994421, 0.029550057569784776, 0.029070184033896242, 0.010405459191783198, 0.04542121896520257, 0.03515907230653933, 0.05582321169120925, 0.02691611015637006, 0.0528724494922374, 0.01820599869824946, 0.014516084554738231, 0.02238622903158622, 0.010510795816246952, 0.050485750061592886, 0.021078105117859583, 0.05884352033691747, 0.03327624958806804, 0.02982400929821389, 0.04371725468497191, 0.03517925872334412, 0.01977988611906767, 0.012618620746902056, 0.011384675977751613, 0.026545628339850476, 0.015853573767734424, 0.050515361329806704, 0.0722142428691898, 0.021400117481659566, 0.05040680929752333, 0.0035237016896384633, 0.02739747816563717, 0.0033507030374104424, 0.03563673381826707, 0.04659248575834291, 0.0581621965393424, 0.02579164701247854, 0.03679330354290349, 0.04071596198316131, 0.07297654303589038, 0.0445178479754499, 0.010432665053355907, 0.01075769859432642, 0.04444180116323488, 0.008979269336642963, 0.018493246320368986, 0.01786834610226963, 0.13993243128061295, 0.08723931520112924, 0.07855581079742738, 0.14625652693212032, 0.12002428168697016, 0.14183984750083514, 0.11113617861909525, 0.1491782580103193, 0.1185185174856867, 0.13589722423681191, 0.14329032466879912, 0.06388500838407449, 0.223355502688459, 0.15182449030024664, 0.10031772484736783, 0.12031108486865248, 0.15343883367521421, 0.1121501609949129, 0.23781471752694675, 0.08576840055840355, 0.06731709279119968, 0.11649276475821223, 0.11116298753768206, 0.18661241073693546, 0.13079156034759112, 0.1363999101200274, 0.12164108135870524, 0.19966089698885167, 0.1393420243901866, 0.07154536340385675, 0.1278351561299392, 0.23765998440129416, 0.18686587070780142, 0.12374934394444738, 0.09204884605216128, 0.1427626008433955, 0.12256948011262075, 0.1992022887404476, 0.15182434102254255, 0.14472267138106482, 0.12348741585654871, 0.09091013536921569, 0.17326489410230092, 0.15359985003513948, 0.09957135668290512, 0.09491062177611248, 0.14619791507720947, 0.10832380702985184, 0.20317873465163366, 0.12513511601303304, 0.1981937007180282, 0.16714902727731637, 0.15820730637226785, 0.1852494374449764, 0.17847060119467123, 0.12064366202269282, 0.09943288125629936, 0.1672200427523681, 0.17705268013690198, 0.10801386580403362, 0.15494206015552792, 0.10719378159514495, 0.08853425857211862, 0.1256287366683994, 0.12279886566102505, 0.19065608589776925, 0.2000406730387892, 0.16316305473446846, 0.2087059316358396, 0.10463205405644008, 0.14674121806664125, 0.08315040889595236, 0.1541946945445878, 0.11159708710121256, 0.10863070841878653, 0.16961979041142122, 0.10530226345040969, 0.12402980960905552, 0.12911039484398706, 0.20895078778266907, 0.16513931511768273, 0.11305021055574928, 0.17343762197664805, 0.15185406085635933, 0.24609756735818727, 0.14764322180833134, 0.12294674558298928, 0.22860083622591837, 0.17121787608734199, 0.15985250951988356, 0.1685744665030922, 0.09054257973496403, 0.09521005927984204, 0.17370587401092052, 0.11018483859619924, 0.13715043770415442, 0.183852686679789, 0.09403801895678043, 0.08318532630801201, 0.15265444719365664, 0.2868620242391314, 0.17349164693483285, 0.2197872091616903, 0.20098363315420492, 0.2258882974939687, 0.17514488393706934, 0.143243600747415, 0.1259810727621828, 0.1820801632212741, 0.1096140006557107, 0.13981817955417292, 0.12176437117159367, 0.10200005743120398, 0.18111459431903704, 0.10673583831105914, 0.12566222915691988, 0.11530581702079092, 0.05718662603093045, 0.10572193735944373, 0.11639810912311077, 0.09372214054954903, 0.11083055287599564, 0.1309769225439855, 0.1359472322676863, 0.14712587956871304, 0.10943330678024463, 0.16086796431669168, 0.08645849781376974, 0.1440197362431458, 0.10660484034035887, 0.16784851545734064, 0.10672844906470605, 0.1907720203910555, 0.10071611989821706, 0.13505700789391994, 0.1407517080328294, 0.17313088343611785, 0.11699838191270828, 0.20448689588478633, 0.12270600135837283, 0.19743560068309307, 0.12641654296645097, 0.09947687746690852, 0.18342899584344455, 0.13584676837282522, 0.09174728473382336, 0.14677104646606104, 0.09596396596836192, 0.15019916822867735, 0.1368531986538853, 0.06741630139627627, 0.09886249114892312, 0.11098162191254751, 0.11346529078270708, 0.11722232561026301, 0.21746394596993923, 0.18183285077767714, 0.17962320148944855, 0.10480135532894305, 0.13069723040929862, 0.10338264717055218, 0.09380972584975616, 0.13790591859391757, 0.19179149211517402, 0.10487127836261477, 0.1070192013201969, 0.11764718352683953, 0.11802185699343681, 0.17490266050611222, 0.14302247975553783, 0.16799544543027878, 0.14838019226278576, 0.13038153520652226, 0.1276161250259195, 0.07838340861988918, 0.0843218724642481], [0.037774665347699604, 0.031075655349663327, 0.05557917996442743, 0.02691196939641876, 0.00677819418654378, 0.010455771715247204, 0.018794390339670435, 0.057817697525024414, 0.006621993728913367, 0.06121162112270083, 0.04235850866617901, 0.03534982207098177, 0.03614588953288538, 0.06782136644635882, 0.011373639605673296, 0.02034672918463392, 0.03560298687911459, 0.02241843399990882, 0.04926042099084173, 0.06537375492709023, 0.016203328035771847, 0.023289615288376808, 0.017257980104269724, 0.03419583077941622, 0.03009735034512622, 0.004688540423688079, 0.04106505807223065, 0.009595375740900636, 0.040256902508969815, 0.0553483118170074, 0.057211609690317085, 0.019001453782298734, 0.049044327943452766, 0.05877098494342395, 0.038327250696186504, 0.05233546027115413, 0.01794914435595274, 0.02734105458616146, 0.02140968312908496, 0.024472410391483988, 0.0062418071652895635, 0.09858524174030338, 0.015181084496102162, 0.029909474176487753, 0.0329164122896535, 0.05113138630986214, 0.006627539904522044, 0.031459397436784844, 0.014858256193942257, 0.022918371816298792, 0.017679852466764193, 0.04482084439535226, 0.01424542541748711, 0.037924984603055885, 0.0470856891146728, 0.040200967474707534, 0.047851843360279284, 0.005769071817797209, 0.04415376644049372, 0.06115654443523713, 0.03161092109179922, 0.022606946295127273, 0.054843363019504716, 0.11989274088825498, 0.00788187634732042, 0.018912353652662466, 0.04077297588810325, 0.03995103249326348, 0.035003009252250195, 0.02560203888320497, 0.0820455706811377, 0.03720699616574815, 0.06395897548645735, 0.05143541071031775, 0.04863824509084225, 0.056384886016270945, 0.0614626519382, 0.03983939312664526, 0.07941474792148386, 0.08214733736323458, 0.07988310671810593, 0.05230987610827599, 0.07585379614361695, 0.26975653639861513, 1.3664067877190453, 1.9325489401817322, 0.3873352828834738, 0.09977229125797749, 0.04599806872595634, 0.26378105846898897, 0.12715755748961652, 0.053947717150939364, 0.052790709771215916, 0.04261946305632591, 0.040046051144599915, 0.06466180205877338, 0.08335282267736537, 0.037961947798196755, 0.04309611694355096, 0.039847884992403645, 0.052557371756328006, 0.0818860742396542, 0.03359019756317139, 0.05549683973991445, 0.008000633546284266, 0.029642497788050344, 0.03713723258780582, 0.02509355322191758, 0.020154437449361597, 0.03884471507210817, 0.03285093026767884, 0.010505895945243537, 0.046850749757140875, 0.02370139444246888, 0.031959827191063335, 0.05239679644416485, 0.012510442757047713, 0.005370684400466936, 0.019857055906738554, 0.030849750685904707, 0.04690802150538989, 0.03785411501303315, 0.05429597185658557, 0.018293117505631278, 0.010614129066068147, 0.0585597569921187, 0.015787116351670454, 0.01910218909116728, 0.01032830127847514, 0.07812021167150565, 0.023409500551809157, 0.07360349582242114, 0.03679421617250357, 0.08230475748756103, 0.029187512916645834, 0.015511351238404001, 0.03772712379161801, 0.006991263936340276, 0.03556553853143539, 0.06545260748160736, 0.009848810266703367, 0.0266480803423162, 0.046544540473925214, 0.024377600389665792, 0.06279987482620136, 0.011734518455341458, 0.04096383761082377, 0.06165519982044186, 0.11029258317181043, 0.049078712705522776, 0.0679068686440587, 0.05195415412474956, 0.011117246667189258, 0.007047411012795887, 0.036688707369778834, 0.026870086822392683, 0.03022027714177966, 0.017645924019494226, 0.02972995416660394, 0.019863837864249945, 0.020252112565296035, 0.016250628711921827, 0.021767264298562492, 0.0776968261759196, 0.020583290240860412, 0.08571276747222457, 0.07403485410447631, 0.04766224371269345, 0.031372388891343556, 0.048422878075923236, 0.03388996754906007, 0.014697523122387273, 0.02587985317222774, 0.008532738163402038, 0.06828467015709196, 0.037516262249222825, 0.05805899136300598, 0.045730352734348605, 0.04943731507020337, 0.03647894844678896, 0.02832867587650461, 0.014495358702593615, 0.04555366560816765, 0.04001420749617474, 0.01835189899429679, 0.01279010096498366, 0.012043630172099386, 0.05606297882539885, 0.04259814348603998, 0.033054429705121686, 0.009919260013183313, 0.036371563494737656, 0.051697321834840944, 0.01634996454231441, 0.01103951539179044, 0.05989488320691245, 0.02929550176486373, 0.044487883869026384, 0.0217344011512718, 0.06264646484383515, 0.07688827027699777, 0.04286026156374386, 0.039702451189181635, 0.05522262677550316, 0.029702079948037863, 0.048304497463894744, 0.03191005664744547, 0.07701434208346264, 0.04069462884217501, 0.03085667174309492, 0.05473459724869047, 0.009961972944438457, 0.005619257646945438, 0.03269330658284681, 0.012142006723609353, 0.01739698987720268, 0.03784361807629466, 0.10189001940722976, 0.04944957959066544, 0.08415710380566971, 0.07352616318634578, 0.0547292096806424, 0.04307266677330647, 0.043598304103527746, 0.03178665487627898, 0.04577359237841197, 0.020825549294906, 0.03488141916958349, 0.017690235748887062, 0.03555005096963473, 0.03227428067475557, 0.03224041838464992, 0.022954245962734734, 0.04575868157137718, 0.07863232919148036, 0.04006050394049712, 0.04709382814222148, 0.06379863766155072, 0.05935584141739777, 0.0761723072667207, 0.020450444958571876, 0.019997695860053812, 0.040683941915631294, 0.038914899341762066, 0.019675561359950473, 0.05154773200462971, 0.02109876481283988, 0.03585061823417034, 0.10325208346226386, 0.05455358446176563, 0.08207506659839835, 0.02765923661978117, 0.028485001863113472, 0.07031500299594232, 0.07326154809977327, 0.06461095264447586, 0.10269176281456437, 0.06026328022458723, 0.09104008161063705, 0.1862953720348222, 1.2058824471064975, 1.748528071812221, 0.3541704724941935, 0.01805093139410019, 0.015376874079395617, 0.19518255229507173, 0.09522555701966796, 0.015369898739403911, 0.0344168364203402, 0.04200999950990081, 0.042062097428632636, 0.025767937302589417, 0.04816715519077011, 0.04701968801340886, 0.05519483058846422, 0.030726813711225986, 0.046651850787124464, 0.0771597046405077, 0.0365414788414325, 0.01416113440479551, 0.03371829479666693, 0.07699452207556792, 0.05305848343830023, 0.02850160900769489, 0.01045920595061034, 0.02473936303119574, 0.014347770550687398, 0.020989451124998074, 0.046352077408560684, 0.0436412044800818, 0.020228443567508032, 0.025573660852387547, 0.012716620711476674, 0.016808511722566824, 0.05193713307380676, 0.0420685910087611, 0.04637332912534475, 0.032785095407494476, 0.020907811487891843, 0.03747849838275995, 0.023356905606176172, 0.012039804930931755, 0.03780183388984629, 0.04024697554164699, 0.05910860361265285, 0.1175715404429606, 0.02116867936482387, 0.027836546301841736, 0.0368584598680692, 0.1613131511424269, 0.026257590224434222, 0.02438721353454249, 0.07416188264531748, 0.04375881156218903, 0.023147441845919405, 0.03871282482785838, 0.016212973411061933, 0.012269319400989583, 0.03391504281067422, 0.04641491314396262, 0.040955685012574704, 0.01262207024930311, 0.08651889421577964, 0.015478477913088031, 0.07465578150004148, 0.03392499691939779, 0.05236712750047445, 0.02137074539703982, 0.003668340970762074, 0.005244113870763353, 0.06321060564368963, 0.057859379931219986, 0.03560502248417054, 0.04518734830032502, 0.050650508542146, 0.057754634480391226, 0.022021686092817357, 0.05495912448636123, 0.05171095699604068, 0.022725355744894062, 0.02913847179817302, 0.03704829700291157, 0.02211236042369689, 0.08720889647624322, 0.016382678411900997, 0.036652497348508666, 0.04673211130180529, 0.05512541984873159, 0.04888846844966922, 0.0186315996106714, 0.04310519574210048, 0.015198767118688141, 0.15440831093915872, 0.09812862159950392, 0.1457225741552455, 0.103885271985616, 0.1374655629375151, 0.09389264961438519, 0.10428872212235417, 0.1747766158410481, 0.08452967381370918, 0.11468146980873176, 0.10367129596748523, 0.10911166082535471, 0.09356623355831419, 0.16065478218453272, 0.0824040678728904, 0.09500682447105646, 0.13954114727675915, 0.2131097867552723, 0.09913005786282675, 0.15228756330907345, 0.1205735829259668, 0.18149221262761525, 0.10473726091108151, 0.14494979062250682, 0.19035963394812175, 0.12669082039168902, 0.19418928559337342, 0.13004561966019018, 0.06127588517431702, 0.18386981290365967, 0.08158556465059519, 0.20019251560526236, 0.17712947673031262, 0.16301065576928003, 0.13347185509545462, 0.11733748657362801, 0.10712294932454824, 0.10108603683433362, 0.08905183829899345, 0.1489194511835064, 0.058780484433685026, 0.18943876693291323, 0.08503444958478212, 0.1428843978792429, 0.1922176663896867, 0.14802797830530576, 0.18869327407862457, 0.09506635234824248, 0.1474427825638226, 0.05926883965730667, 0.1023765222302505, 0.10446928029081651, 0.12204159343881266, 0.10402331993516002, 0.1258252268390996, 0.15613526398582117, 0.1253699976950884, 0.072399489714631, 0.1949238268924611, 0.08655451730425869, 0.20609628595411777, 0.11126784833946399, 0.15892223800931657, 0.1423619801976851, 0.11381637158670596, 0.10307012072631291, 0.16450147862945283, 0.1307380646467209, 0.11899938168270247, 0.09346688924623386, 0.1636724988264697, 0.11918676591345242, 0.22538752507950577, 0.14812264751110757, 0.16487091380570615, 0.13442716454820974, 0.14470882926668438, 0.12251987920275756, 0.1962608258639063, 0.15069996778454098, 0.17388393517051423, 0.15976657984512194, 0.14216646711741174, 0.7222843510763985, 3.106827288866043, 3.317849291222436, 0.7685784069555146, 0.19646457635930606, 0.12955769869898046, 0.3646864896374089, 0.27827782343540874, 0.18534957564302854, 0.13655361187245163, 0.18897386187953608, 0.1247099188289472, 0.17482032706694944, 0.13339983538857528, 0.18382566741534642, 0.16306291653641633, 0.1416836894516434, 0.18023638001510076, 0.19015559846801416, 0.1035149207870875, 0.09432746163968529, 0.09740849238421236, 0.12209199501999787, 0.12885582207569055, 0.15426235805664743, 0.08311010391584464, 0.11283028378550496, 0.10460117392774139, 0.11763621840093817, 0.11019916247044291, 0.0916048398773585, 0.08647031110844441, 0.1739560363015958, 0.11282596151743617, 0.07551056598978383, 0.10566878092608281, 0.09222892924611058, 0.1488004768533366, 0.11731858258800847, 0.15351488388010434, 0.07864027483654873, 0.11992189075265612, 0.15458534072552407, 0.11684942990541458, 0.08750171147819076, 0.0909247917256185, 0.24604575442416327, 0.09842521604150534, 0.22063706070184708, 0.10132237058132887, 0.31632857450417107, 0.10701236168720893, 0.0842846276770745, 0.1418330350092479, 0.14093222548919065, 0.10229374774332557, 0.14298080413469247, 0.09794509823301009, 0.0642964109512312, 0.10461819837135927, 0.15084183588624, 0.1855631920375994, 0.06761480681598186, 0.12353590396898133, 0.161304058773177, 0.17189147137105465, 0.15488768235913344, 0.16969904330159935, 0.11753385460802487, 0.08529137008424316, 0.12108204992754118, 0.15800223951893194, 0.09724810027650424, 0.10472970203097377, 0.1040704238361546, 0.11751166651291506, 0.1825011670589447, 0.11644758789667062, 0.09069409660462822, 0.11573170631059579, 0.1412958116935832, 0.11900493209915501, 0.14537262650472776, 0.1788480430841446, 0.24400100271616662, 0.15971877026770795, 0.12648727345679486, 0.08131027620817934, 0.11455942850027766, 0.14065446039395674, 0.06658126906092678, 0.15001240825014456, 0.14686054523502076], [0.07166334028754916, 0.03639668964647821, 0.036477930644260984, 0.011772842961363494, 0.017054365315873708, 0.03722156770527363, 0.055667318270674775, 0.04992742769952331, 0.05330095114186406, 0.03525024027164493, 0.024794755237443105, 0.05453214954052653, 0.05676661624706217, 0.10128062710698162, 0.06551347207278013, 0.07449676681842123, 0.05677042282851679, 0.031056788683469807, 0.021618483621360998, 0.06397115519004208, 0.07413769287190267, 0.09874760159956557, 0.06395514176360198, 0.04583159015913095, 0.03945706578503762, 0.04913797934672662, 0.04061565075867942, 0.018518129895840372, 0.04251314679692898, 0.02228896103666297, 0.11209206482661621, 0.009378443006426096, 0.022512258429612433, 0.03162387093263013, 0.022579603030213287, 0.020236095746180842, 0.040746801399758885, 0.04946641404447811, 0.0933891630598477, 0.06353655351059777, 0.043844496964343956, 0.045060000848025084, 0.05035943737519639, 0.05895856594932931, 0.08703012285487992, 0.03986058038260255, 0.08394325670919248, 0.07532662871692862, 0.020808229688555002, 0.039845581366015334, 0.02338227772686098, 0.07339004227625472, 0.047419253537165265, 0.012213375885039568, 0.08108841561313186, 0.07416541781276464, 0.04444170616833227, 0.06495454920721905, 0.044556246272155216, 0.041470896652234454, 0.0412846693236913, 0.01208648644387722, 0.07606277135866028, 0.1789999535041196, 0.12978541505123886, 0.015825093956664205, 0.030026599498731748, 0.04155221228886928, 0.22210507121469292, 1.1826765494687217, 2.4951880063329424, 3.4768182124410356, 5.007919345583234, 6.2124946628298074, 8.905445337295532, 8.13023395197732, 9.425346033913748, 7.302144169807434, 10.49251811844962, 11.796123504638672, 16.919940539768763, 23.436966930116924, 35.38551133019583, 59.15356513432094, 62.23393086024693, 57.64483329227993, 36.724418776375906, 19.763770478112356, 12.139249001230512, 9.856042282921926, 5.616057387420109, 2.4648087450436185, 1.290961510368756, 1.23912556043693, 0.7724280346717153, 0.3243461714259216, 1.1816097838538033, 1.697253514613424, 0.4547261595726013, 0.44055283867887085, 0.09799742685364825, 0.041702195669391325, 0.02000400623572724, 0.023722171184739897, 0.013544178983595754, 0.10828208391155515, 0.024627055307584148, 0.04631562990003398, 0.007599305527816925, 0.04875322284975222, 0.05595358880236745, 0.04196321791304009, 0.07550105292882238, 0.06917531522256987, 0.03136036525081311, 0.07022039485829216, 0.1127661554408925, 0.056938458633209975, 0.04110114256452237, 0.0879474954147424, 0.022295751475862095, 0.07393462091152157, 0.09159502826098885, 0.05838276791785445, 0.010665905528834887, 0.007913618215492793, 0.07630967668124608, 0.02788470532479031, 0.09638780608241047, 0.08283670858613082, 0.0684148742418204, 0.04331882231469665, 0.017497031384014657, 0.0374368532959904, 0.03294366564867752, 0.06797872550253357, 0.015571737462388617, 0.04902699815907648, 0.010837937056619142, 0.005707709351554513, 0.03985023272356816, 0.052171166587088785, 0.028102521851126636, 0.0654381343296596, 0.046041199804416726, 0.06376711292458431, 0.09723604270922286, 0.053737086310450516, 0.0298806839356465, 0.05108957498201302, 0.07004692059542451, 0.07890332250722817, 0.05307982336463673, 0.07681130404983248, 0.10968675318041018, 0.0691252936209951, 0.07601253262587956, 0.07281887185360704, 0.13185729458928108, 0.12558258271643094, 0.021690985088103583, 0.05307561644752111, 0.01155036998846169, 0.017848714387842586, 0.058394289442471096, 0.04398712841793895, 0.014791021855281932, 0.02959962116022195, 0.10231363560472216, 0.08260551813457694, 0.042266794480383396, 0.03381983756220766, 0.03732702561787196, 0.012505603106027203, 0.02570944419130683, 0.054817639756947756, 0.06007651346070426, 0.01584130585459726, 0.0776947702148131, 0.06783468608877488, 0.0302346145867237, 0.07225196263087647, 0.003432090768391, 0.020800375645714145, 0.04782764680151429, 0.043586477238152704, 0.036429442531828365, 0.08517807509217944, 0.053762565300400765, 0.04426662717014551, 0.09451051681701626, 0.11233089558248009, 0.11103300058415957, 0.08969886215137583, 0.04174358291285379, 0.07099131241972957, 0.06382201319294316, 0.07677637985242264, 0.01613342366181314, 0.02141065343416163, 0.05176335347018071, 0.05207860083984477, 0.04281687603465148, 0.02894194091537169, 0.017589848189215575, 0.08339350763708353, 0.10176917910575867, 0.044934648288679976, 0.0884785915591887, 0.01783899776637554, 0.06940970835941178, 0.03325887909159064, 0.034074834414890835, 0.010028398978257818, 0.0748173746147326, 0.08637271741671221, 0.009464785739380335, 0.08158842806837388, 0.08877987467816897, 0.03108789272872465, 0.06090191059878894, 0.054259605772261105, 0.11254065111279488, 0.1193637414170163, 0.0642862736380526, 0.06486976625663893, 0.02921953298417585, 0.04064541808994753, 0.066998147405684, 0.054974890247519524, 0.09156371386987822, 0.022181413236207197, 0.11128081514367036, 0.07564475307507174, 0.014108434286234635, 0.06860405659036976, 0.06453661234783274, 0.02758671818966312, 0.1201452509100948, 0.10384890929396663, 0.10815098416060209, 0.04459807795605489, 0.03612199492220368, 0.015096742593284165, 0.47067270960126606, 0.8036364114710263, 2.0171953695161, 2.932257056236267, 3.564941780907767, 5.280611821583339, 7.673178843089512, 6.9397600037711005, 7.680357200758798, 6.6106811591557095, 9.88359362738473, 11.091199227741786, 17.432701962334768, 27.21388782773699, 38.68403312138149, 64.9611404963902, 70.06341811588833, 64.5263500213623, 39.0421849659511, 19.95283964702061, 13.584098236901418, 10.31890434878213, 5.343046597072056, 2.53222233908517, 1.0349417797156741, 1.4158044627734592, 1.0635747632810046, 0.46826912143400734, 1.148346368755613, 1.5489825393472398, 0.8718891090580395, 0.5809747651219368, 0.10339666570403747, 0.057818369274692874, 0.0728235605305859, 0.04701273302946772, 0.13484827695148333, 0.07235944257783038, 0.08643966846700225, 0.042187677297208986, 0.0718636709664549, 0.035765679220535924, 0.033972630077706914, 0.04246933039809976, 0.0964386487113578, 0.08714796403156859, 0.053122241981327534, 0.05531518573739699, 0.0423340135520058, 0.0497728099248239, 0.0772209017138396, 0.09582434381757464, 0.06991225853562355, 0.09348083992621728, 0.08326928144586937, 0.030974848794617822, 0.049712617083319595, 0.13639879732259683, 0.04812415981931346, 0.045850246479468684, 0.08558382546263081, 0.08357703100357737, 0.11477436125278473, 0.07999912942094461, 0.08589477092027664, 0.03978671506047249, 0.027336437155359557, 0.05897307302802801, 0.023766703438013792, 0.018698136754600064, 0.042824034579098225, 0.08277709249939237, 0.04834635968187025, 0.060445629725498815, 0.045841140539518425, 0.07246903955404248, 0.05455093138984271, 0.0376544323350702, 0.04779488034546375, 0.05355018383956381, 0.1044748103512185, 0.06834596901067666, 0.030780373872922998, 0.06020653434097767, 0.09515584433185202, 0.04692952428013086, 0.03955179266631603, 0.055804256815463305, 0.1425651471529688, 0.03888941017378654, 0.07889039641512291, 0.048816693015396595, 0.03124867838674358, 0.05856818439705031, 0.04916795702385051, 0.0662306903728417, 0.05757606441953352, 0.0095165867990415, 0.006621576429876898, 0.01233575222015913, 0.10226628064577069, 0.05502049119344779, 0.01722737817492868, 0.020033824457121745, 0.04789983614214829, 0.0259135848443423, 0.0816808445379138, 0.0364177276247314, 0.20460342748888902, 0.07817536978317158, 0.14849915302225522, 0.1310807384018387, 0.11318150029650756, 0.1603867065693651, 0.18255767545529775, 0.10054854210466146, 0.1830207756055253, 0.20605895295739174, 0.10761667854551758, 0.18298264193747724, 0.19688197039067745, 0.1966288768287216, 0.2781201590384756, 0.27335068210959435, 0.1950261364025729, 0.22424180512981756, 0.1319418671940054, 0.1196319798805884, 0.13431209857974732, 0.18235026087079728, 0.194372652896813, 0.2052760999649763, 0.2152454757264682, 0.18640807670141968, 0.1227372953934329, 0.14632368832826614, 0.10185935640973703, 0.1737434919923544, 0.256087421306542, 0.1263136634869235, 0.2165135626814195, 0.13512591991041387, 0.20869435582842144, 0.17177845457834856, 0.158289761947734, 0.1769376684512411, 0.1896778962441853, 0.20840622271810258, 0.21455729193985462, 0.15873116254806519, 0.3021598405071667, 0.16217023586588247, 0.2317611537873745, 0.22778689275894845, 0.22104228181498392, 0.2642630897462368, 0.10461911439363446, 0.13706619079623902, 0.21558559818991593, 0.23404040719781602, 0.09117544934685741, 0.16757863493902342, 0.22653693625969545, 0.11686632542737893, 0.13010344441447938, 0.2791199396763529, 0.2359469277518136, 0.13412577286362648, 0.19517514269266809, 0.0654858760535717, 0.33666139202458517, 0.3145742900669575, 0.29939866438508034, 0.1588180557425533, 0.14058378418641432, 0.24227605813315936, 1.1399215693984712, 2.2871791337217604, 4.421088823250361, 6.859771907329559, 7.943873711994716, 11.115469285420009, 14.223033734730311, 12.793633818626404, 14.839097499847412, 12.07094212940761, 16.46889475413731, 18.157822915485927, 27.82246490887233, 38.77608633041382, 54.567899976457866, 82.88255964006696, 89.49100521632603, 82.17583056858608, 55.73240416390555, 30.586112635476248, 20.16645506450108, 15.374167851039342, 8.263924241065979, 4.66591511453901, 2.474435257060187, 2.776953309774399, 2.0991250532014027, 1.3964199657951082, 2.4073163100651334, 3.756092369556427, 2.0389358486448015, 1.3659025004931857, 0.26803929997341974, 0.1183454232024295, 0.17084715169455322, 0.13812185557825224, 0.1880553425954921, 0.23542369582823344, 0.18416661769151688, 0.1978265725608383, 0.3087942030813013, 0.12473400682210922, 0.17035882361233234, 0.21785381862095424, 0.23473012447357178, 0.23742244286196573, 0.22624475908066544, 0.1836251196052347, 0.25287048678312984, 0.2559297297682081, 0.17679790380809987, 0.19884854129382543, 0.1391083097883633, 0.274139438356672, 0.32862718456557816, 0.20408898937915051, 0.17375243508390018, 0.1832520067691803, 0.16438676549920014, 0.1860181497676032, 0.27296967112592285, 0.22565127164125443, 0.14626294587339672, 0.3085074541824204, 0.20195944793522358, 0.1570262618895088, 0.1236438588904483, 0.2289915366896561, 0.1332509783761842, 0.30832139988030705, 0.15546582133642264, 0.22561395221522876, 0.14421174808272294, 0.15664407025490487, 0.15136167513472693, 0.14990734388785704, 0.2015359199472836, 0.20117016243083136, 0.21315591356584004, 0.2811549747628825, 0.16138230743152754, 0.15511439447956427, 0.185955887394292, 0.2286014604781355, 0.20542900104607853, 0.134139072149992, 0.21566654741764069, 0.16585692018270493, 0.30907413948859486, 0.1587509350585086, 0.2506624795496464, 0.23187094075339182, 0.10218480894608156, 0.2176004129328898, 0.15047563053667545, 0.11612330244055816, 0.20558076218834945, 0.14600990659424237, 0.14597074155296597, 0.06895592449499027, 0.36016082391142845, 0.15448660030961037, 0.10846892531429018, 0.10479955042579345, 0.09827354989413704, 0.06110433116555214, 0.14882955886423588, 0.17669131952737058], [0.023961422632315328, 0.010099637521696942, 0.08610893692821264, 0.006343989874169762, 0.04575760270069752, 0.039517465579722605, 0.025091544758262377, 0.038697500114462206, 0.05194258171000651, 0.048128122463822365, 0.03046122153422662, 0.03961323740492974, 0.014482848213187285, 0.010183205894593681, 0.02870283874550036, 0.0450564758586032, 0.04058064513706735, 0.03616584185510874, 0.029539665805974176, 0.03359951384897743, 0.09976911571409021, 0.00931421881874225, 0.029874370167297975, 0.04621718464685338, 0.041735325141676834, 0.04744769772514701, 0.04014083570135491, 0.040617923850991895, 0.11280740358467613, 0.01782732696405479, 0.032771623094699213, 0.032374707250190635, 0.01870421303569206, 0.036655900201627185, 0.030663961012448584, 0.0449933721018689, 0.02610660600475967, 0.04242328840440937, 0.05562260281294584, 0.021262826098661338, 0.07072385427142892, 0.01959117195968117, 0.023816161855523075, 0.0393477809349341, 0.05299248912238649, 0.06717204236026321, 0.07665568204330546, 0.047049143218568394, 0.03191038912960461, 0.02405999680714948, 0.03515297566939678, 0.052788049913942814, 0.056453896420342584, 0.10528642644307443, 0.044301989022642374, 0.052857304590621164, 0.042103304860315154, 0.015714078842263137, 0.08723731352282421, 0.02106204758664327, 0.08824257672365222, 0.05026962648012808, 0.304217022976705, 0.07591057595397745, 0.7526801143373761, 4.558614952223642, 11.477794391768319, 22.067376238959177, 42.64544432503836, 41.64189168385097, 53.28720106397356, 60.51356383732387, 64.0366131918771, 62.20975807734898, 63.50582640511649, 67.66425377982003, 77.15307508196149, 76.54064001355852, 86.97696631295341, 92.17435782296317, 95.44490964072091, 96.30418641226632, 103.80044501168388, 105.66063758305141, 105.0843539919172, 112.98313563210624, 96.19887256622314, 102.40054280417306, 96.32444735935756, 85.60006264277867, 78.0760807309832, 70.45575509752545, 61.85463564736502, 64.50570692334855, 65.22457449776786, 67.47518634796143, 60.183239528111045, 68.58075591496059, 57.51143135343279, 32.34285000392369, 18.42875749724252, 6.006793243544442, 1.7943436247961861, 1.2112359255552292, 0.12741302592413767, 0.044175245466509035, 0.14889756164380483, 0.06533750758639403, 0.03832879775602903, 0.022627488942816854, 0.059517061337828636, 0.05585599850331034, 0.10340782760509423, 0.18331582977303437, 0.030971116852015257, 0.007096827021866504, 0.02918903962043779, 0.10015554819256067, 0.04969066986814141, 0.0729653879201838, 0.04508865198918751, 0.02864200808107853, 0.04400086196671639, 0.061893670952745845, 0.04341344741572227, 0.03179872262158564, 0.06543814111500978, 0.06642901258809225, 0.042836248209433894, 0.04158180998638272, 0.06093658373824187, 0.02177006664818951, 0.026291572954505682, 0.043261041665183644, 0.0431437399238348, 0.05892001158956971, 0.06456428979124341, 0.030368937379015342, 0.03286652300240738, 0.07878262469811098, 0.07785884676767246, 0.044548629716570885, 0.015922462035502707, 0.05072759012026446, 0.07421592117420264, 0.02669715029852731, 0.04428399766662291, 0.07379438129386731, 0.014321619811068689, 0.05708821809717587, 0.039518853183835745, 0.023310826293059757, 0.11749593807118279, 0.10877445606248719, 0.056837105857474465, 0.08352052260722433, 0.027299161834110106, 0.034155851496117454, 0.017092711026115075, 0.021915934713823453, 0.03020809404551983, 0.03752423503569194, 0.03944348490663937, 0.049643114741359434, 0.04871807473578623, 0.019441560077081834, 0.015903079682695012, 0.08261464443057775, 0.045663656134690554, 0.07526259536721877, 0.06061073086623635, 0.0845624063430088, 0.07088415138423443, 0.06643163173326425, 0.06468556435512644, 0.03822525670485837, 0.06467630913747208, 0.08077123441866466, 0.04097234983263271, 0.007122198718466929, 0.027105996485001276, 0.03901878983846732, 0.017099886533937285, 0.044977691157587936, 0.08907477956797395, 0.08144591535840716, 0.043420337938836644, 0.03138148465326854, 0.034699592140636275, 0.0370475268656654, 0.06949141754635743, 0.05103833541007979, 0.022734271695039103, 0.02923865749367646, 0.009479810201030756, 0.02973507371331964, 0.07027052502546992, 0.02295382018201053, 0.04948103986680508, 0.0711709206391658, 0.08384091327232973, 0.02677172129707677, 0.10330421530774661, 0.07922365888953209, 0.01660684432967433, 0.06729908447180476, 0.011290887171136481, 0.033511056631271324, 0.012446836036230837, 0.035762893834284375, 0.022577606440920914, 0.08671704679727554, 0.029473016703767434, 0.05875262378581932, 0.08138797525316477, 0.05008197083537068, 0.1504741513303348, 0.018147790571674705, 0.07446552706616265, 0.01774098338293178, 0.04969558585435152, 0.015874771201717, 0.006516202910071505, 0.04368938385908093, 0.06616476391042982, 0.015307266564507569, 0.057560261338949203, 0.044871093306158266, 0.07724332729620592, 0.017915665438132625, 0.006584454203091029, 0.062457723543047905, 0.06030546474669661, 0.10614534321108035, 0.09427282599998371, 0.04549750326467412, 0.040495237934270074, 0.033111521641590765, 0.14907843193837575, 0.01961964159272611, 0.5655681118369102, 4.076513758727482, 9.771152666636876, 21.339713982173375, 44.584700448172434, 44.00787142344883, 56.32440458025251, 62.57048075539725, 67.34506743294853, 65.05549008505685, 68.2867567879813, 73.27926676613944, 85.4469243458339, 85.14777660369873, 100.40319974081856, 108.0413544518607, 111.5196782520839, 115.73155117034912, 124.3546894618443, 125.41224697657994, 124.05028888157436, 131.37041064671106, 114.92767238616943, 118.00899696350098, 109.92265565054757, 99.72640350886753, 93.62429400852749, 83.64539541516984, 73.55153192792619, 78.16434369768415, 76.70389488765171, 78.94614110674176, 70.97840554373605, 77.18360546657017, 63.815285273960654, 36.245948450905935, 19.298053571156093, 5.843166640826634, 1.7023754226309913, 0.9367238900491169, 0.253104635647365, 0.04255913450781788, 0.050582108819591146, 0.05269267503172159, 0.04675093047054751, 0.04713898464771254, 0.08540488220751286, 0.03816476870062096, 0.03566410592091935, 0.24616544800145285, 0.05561397863285882, 0.02399263863584825, 0.018598668609878848, 0.08306499490780489, 0.03962006685989244, 0.09142831899225712, 0.028900862405342714, 0.0271650222462735, 0.010684822236986032, 0.039299523524407826, 0.022279581986367702, 0.01283238472283951, 0.05716435651161841, 0.11132641269692353, 0.009160306720462228, 0.030838395402367626, 0.07030385466558592, 0.019207187296290482, 0.009138421421604497, 0.010333557380363345, 0.013218570384196937, 0.0346619266617511, 0.09098852651992015, 0.03924966477123754, 0.04097143381035753, 0.05514053421627198, 0.042554679925420454, 0.007525594572403601, 0.0788506885458316, 0.031143295112997293, 0.060417192322867255, 0.07862774908010449, 0.01003241929824331, 0.02136861310074372, 0.050159293293420754, 0.06610305793583393, 0.018116915531988655, 0.07016482284026486, 0.06590544139700276, 0.05304949963465333, 0.03793960024735757, 0.048435824524079046, 0.030320700324539627, 0.015274048882669635, 0.034328579370464594, 0.031731612115566216, 0.07271093728819064, 0.010323319135100713, 0.0325547531247139, 0.031069127842783928, 0.008100058434398046, 0.12152084495340075, 0.023756276051114713, 0.09098837724221603, 0.038978891979370794, 0.026970411617574946, 0.04319415507572038, 0.05710575822740793, 0.04913045439336981, 0.043413905426859856, 0.03595384376655732, 0.04585351701825857, 0.17730049469641276, 0.1698094680905342, 0.22894754047904695, 0.09372002352029085, 0.14414929571960652, 0.1426361897694213, 0.14041512752217905, 0.12220807879098824, 0.14786648697086743, 0.13040687170411858, 0.11740584219140665, 0.16075808235577174, 0.1151130995047944, 0.16967861939753803, 0.14453317012105668, 0.10319905595055648, 0.1828462156866278, 0.09567959872739655, 0.14803792562867912, 0.15330087393522263, 0.16660188377967902, 0.13503625829304966, 0.1522867897791522, 0.18583847369466508, 0.24083153850265912, 0.17123040184378624, 0.22174565121531487, 0.09589706241552319, 0.2790830002299377, 0.2436200731566974, 0.0967635652050376, 0.14751178957521915, 0.06452414765954018, 0.21374735182949475, 0.12419453077018261, 0.2148354777268001, 0.16029028674321516, 0.1338544131389686, 0.1732458815510784, 0.15836459078959056, 0.32843331354004995, 0.07971929479390383, 0.11947659536131791, 0.20467840560844966, 0.17562828585505486, 0.14770773691790445, 0.21314701118639537, 0.15688522160053253, 0.15263386044119084, 0.19623877347580024, 0.11446480000657694, 0.2879688505615507, 0.26668309846094673, 0.13970048086983816, 0.2440322424684252, 0.11371917823063475, 0.25044746537293705, 0.19252143294683524, 0.18970809105251515, 0.12671821963574204, 0.2174192305122103, 0.20423240454069205, 0.26819818573338644, 0.1814853594239269, 1.9315807521343231, 9.566645468984332, 20.889052084514073, 35.968996729169575, 65.0099515914917, 66.84315735953194, 79.83159174237932, 87.1447444643293, 88.42559623718262, 90.12100533076695, 91.48811898912702, 95.31798689705985, 105.00467205047607, 108.9732746396746, 120.82008525303432, 127.59450939723423, 132.74986430576868, 133.3139190673828, 139.33925792149134, 137.21952928815568, 135.40407616751534, 144.31369563511439, 127.95209148951939, 134.28433227539062, 128.68497358049666, 119.53536333356584, 114.46629810333252, 104.03678798675537, 92.73470919472831, 99.55666596548897, 94.80333382742745, 97.5360186440604, 88.11515072413853, 98.23208223070417, 86.2802426474435, 51.902275698525564, 30.396044663020543, 9.901049239294869, 4.073595515319279, 2.3761312748704637, 0.6077028566173145, 0.21931960353893892, 0.19123038436685288, 0.1623233269367899, 0.1732059565505811, 0.13574819080531597, 0.2535071154790265, 0.24787315779498645, 0.19341247156262398, 0.36420315557292526, 0.1775100263101714, 0.09745740118835654, 0.13332166815442698, 0.20455833205154964, 0.2928274869918823, 0.23968011885881424, 0.15430848486721516, 0.12448239246649401, 0.098845385281103, 0.16547181084752083, 0.1931283146675144, 0.06688956144664969, 0.1540753673762083, 0.14483566103237017, 0.203516332964812, 0.12979134544730186, 0.1991664892328637, 0.06496028961347682, 0.25665660362158504, 0.08905248290726117, 0.1712260456489665, 0.1568955760449171, 0.16743355058133602, 0.14799706424985612, 0.15881551802158356, 0.13666626225624764, 0.2660112945096833, 0.18749713897705078, 0.1904097641152995, 0.14605538201119217, 0.1509417298116854, 0.2001795827278069, 0.23967327922582626, 0.17925239567245754, 0.09646328631788492, 0.10585446203393595, 0.1438083861555372, 0.13325817084738187, 0.21962197231394903, 0.22560914818729672, 0.13345814868807793, 0.19716420024633408, 0.08168304299137422, 0.14818941535694258, 0.12017669422285897, 0.14144665002822876, 0.25971923928175655, 0.14157207044107573, 0.12044073934001581, 0.17162916330354555, 0.21700258286935942, 0.25784889821495327, 0.17306015294577393, 0.12295735787068095, 0.1146972661039659, 0.16723009864134447, 0.08772969924445663, 0.1804955125387226, 0.1550303375614541, 0.14554361732942717, 0.11039039399474859, 0.10261265920209033], [0.032388718998325725, 0.05873158920024123, 0.12045504285820893, 0.08238977114004747, 0.0413857269366937, 0.08628776483237743, 0.01982789416797459, 0.008348373413485075, 0.01775983308574983, 0.04768337668584926, 0.10356432492179529, 0.11265691808824028, 0.011429477100526648, 0.025368948533598865, 0.10682768481118338, 0.046946497833622355, 0.02056401814999325, 0.008298646126474653, 0.08629393950104713, 0.01371785850330655, 0.014877884515694209, 0.058886858368558545, 0.04973252869344183, 0.014736167388036847, 0.06444355127002512, 0.03917838806020362, 0.07054210188133375, 0.07657653771873031, 0.056280289843146286, 0.06651495583355427, 0.08006613475403615, 0.04044219006651214, 0.04593255616990583, 0.0474470463315291, 0.0605124586394855, 0.12073919975331851, 0.06416459195315838, 0.01379277216204043, 0.07359086828572409, 0.009676330057638032, 0.03403141835172262, 0.05622302827292255, 0.08272125585270779, 0.04527759345780526, 0.1283387512500797, 0.06819570743079696, 0.06087125438664641, 0.023723341657647064, 0.02074102758030806, 0.05437536723911762, 0.09501997447971787, 0.06017635988869837, 0.13251240657908575, 0.011248853623068758, 0.030259031669369767, 0.10301406694842236, 0.13656836322375707, 0.04286314194489803, 0.06293980231774704, 0.11783402492957455, 0.010819689553630139, 1.0777840465307236, 7.45309465272086, 24.85547467640468, 55.852764333997456, 63.49094336373465, 75.83954593113491, 84.69316291809082, 74.99604851858956, 86.24835736410958, 84.28585256849016, 80.15440504891532, 82.68709291730607, 91.20661272321428, 88.94671807970319, 89.81772341047014, 77.69201210566929, 85.37003558022636, 82.8501671382359, 80.19416264125279, 83.45541776929582, 81.11309664590019, 75.70074871608189, 70.83539077213833, 66.1406944819859, 89.70140361785889, 85.47800363813127, 90.74022184099469, 94.86821610586983, 97.5879008429391, 102.99366188049316, 108.56973716190883, 106.62180273873466, 89.1788226536342, 85.51976231166294, 90.9593471799578, 96.87317439488002, 95.50104413713727, 101.96946266719273, 91.00020953587124, 82.27037470681327, 78.97275270734514, 65.22723565782819, 56.07186882836478, 42.31304945264544, 29.868419306618826, 8.78760302066803, 2.184266975947789, 0.05322800523468426, 0.04283179362703647, 0.05174314669732537, 0.07239813264459372, 0.027664101715864878, 0.09019921387412719, 0.018140309723094106, 0.07599817482488495, 0.09363129828125238, 0.03841210489294358, 0.057407305975045474, 0.06808032933622599, 0.06653408373572997, 0.04370242530213935, 0.0398987615481019, 0.051824363946382485, 0.04027301093031253, 0.060548800975084305, 0.0445840662079198, 0.02269348156239305, 0.035788725662444315, 0.1110699875280261, 0.05468183775831546, 0.0754196626533355, 0.01376817187493933, 0.03742273976760251, 0.06061684446675437, 0.039603503820087226, 0.036178991863770146, 0.027608132754851664, 0.019193279024745737, 0.03876679211056658, 0.030035878465111767, 0.058164293212550025, 0.06677346410495894, 0.05200607223170144, 0.016371967736631632, 0.039442935293274264, 0.03278919715168221, 0.05740898195654154, 0.12532821350864, 0.0862018351576158, 0.10283956131232636, 0.06099814722048385, 0.0607083991968206, 0.06832765535052333, 0.017732262511604598, 0.04790584117706333, 0.06090316588857344, 0.1217343799237694, 0.0639880167852555, 0.08711188632462706, 0.030857784540525506, 0.03692600802917566, 0.04917710367590189, 0.02048830042726227, 0.05381917208433151, 0.06846412909882409, 0.03130457949425493, 0.015995599628825272, 0.049556669379983626, 0.06937665013330323, 0.07559022600097315, 0.05627500066267593, 0.05645548079961112, 0.030349476994680505, 0.07207536032157284, 0.02363971391293619, 0.005400258773339114, 0.04960354597174695, 0.031430383279387436, 0.07358196590627943, 0.03484753313075219, 0.040733837988227606, 0.03876539772110326, 0.04403653594532183, 0.03909986459517053, 0.08203423914632627, 0.040810373345656056, 0.10230752200420414, 0.01063558688786413, 0.029697591438889503, 0.07430379145911761, 0.041425960670624457, 0.02527048801338034, 0.0237004818128688, 0.14902690398905957, 0.06720450347555534, 0.013727031448589904, 0.03187011807624783, 0.06446571222373418, 0.07781912532768079, 0.07524310784148318, 0.015136036556214094, 0.07872957004500286, 0.1419689455734832, 0.08287224346505744, 0.035363596331860335, 0.08088005786495549, 0.06648081195141588, 0.08524076494255237, 0.10450511372515134, 0.04742930603346654, 0.06386515444942883, 0.02000564998680992, 0.013833238294215074, 0.027678191495527114, 0.06267226274524416, 0.06986542604863644, 0.07485116565866129, 0.08787860375429903, 0.07870724624288933, 0.09830733415271554, 0.05994776822626591, 0.019149513516042913, 0.05670257950467723, 0.07633563064570938, 0.04930015939420887, 0.006960837577935308, 0.08615344204008579, 0.13527879385011538, 0.05685512774756976, 0.034768002041216405, 0.01341255845701588, 0.12354700480188642, 0.09222258494368621, 0.029363399371504784, 0.14718141087463923, 0.023376091183828454, 0.6946212383253234, 6.4576718381472995, 25.0993720803942, 58.38098798479353, 72.21132169451032, 88.09031091417584, 94.83369745526994, 90.74067347390312, 97.1297505242484, 96.59797709328788, 96.08271953037807, 99.13288143702916, 110.82651206425258, 103.57429504394531, 102.75480365753174, 95.84259673527309, 100.15301595415387, 101.73610046931675, 98.46579878670829, 100.83105591365269, 103.40457834516252, 93.79764461517334, 93.55971050262451, 92.2346612385341, 103.40805244445801, 101.97415270124162, 106.44704164777482, 113.72056879316057, 115.74443313053676, 119.56957626342773, 120.06613622392926, 120.86281667436872, 108.2831448146275, 104.49885708945138, 108.86567483629499, 114.56421906607491, 109.29058497292655, 116.84315872192383, 103.743622643607, 94.57423087528774, 91.75782721383231, 73.44935866764614, 60.30127552577427, 45.798526423318044, 30.930388927459717, 9.292830858911787, 2.4083984919956754, 0.08230320364236832, 0.09496059588023595, 0.08052316201584679, 0.034057843898023875, 0.053587462553488355, 0.06475824902632407, 0.08018593011157853, 0.11908736053322043, 0.018902974602367197, 0.050923449253397327, 0.0531787876971066, 0.08060332414294992, 0.04874115510444556, 0.07584967065070357, 0.037945934371756654, 0.11892323648290974, 0.0691971911915711, 0.051005199152444086, 0.06334876215883664, 0.13303472926574095, 0.007458564642417643, 0.04982917582882302, 0.04870270252493875, 0.05960132860179458, 0.0271637160663626, 0.01692087881799255, 0.058242365451795716, 0.04079911305702158, 0.03936511750466057, 0.05876055586018732, 0.03513993422633835, 0.06166330152856452, 0.11405226428593908, 0.03062942697267447, 0.06282332499644586, 0.038125104936105866, 0.052670130705727, 0.07137337513267994, 0.08729949447193316, 0.08830386879188673, 0.11575527861714363, 0.06006231850811413, 0.05661963877667274, 0.05503640962498529, 0.047232327317552905, 0.09562615052397762, 0.12167941858725888, 0.09128510739122118, 0.07595018882836614, 0.06800545978226832, 0.05926582696182387, 0.055686792225709984, 0.03283407206514052, 0.01545872915137027, 0.09805154002138547, 0.053455236434404335, 0.036783542816660235, 0.06055889757616179, 0.03097041796094605, 0.07668654860130378, 0.05485421957980309, 0.05003186102424349, 0.08536816667765379, 0.06518715101161174, 0.05693706763642175, 0.11712445371917315, 0.08813601958432368, 0.03476197325757571, 0.217103101047022, 0.13531770104808466, 0.2801422748182501, 0.16266944764980248, 0.10615090719823327, 0.12246801198593207, 0.2627733254006931, 0.20843017500426086, 0.1487924972815173, 0.1507196317293814, 0.15239777096680232, 0.3382726955626692, 0.12006822361477784, 0.145656552697931, 0.2606096400746277, 0.17310353847486631, 0.105881352376725, 0.11189066206238099, 0.1853174673659461, 0.1297182807964938, 0.14785773386912687, 0.11674086430243083, 0.1763810118926423, 0.25277101354939596, 0.1856264586427382, 0.17433213469173225, 0.12844110147229262, 0.2642942752156939, 0.20908458131764615, 0.14473430147128447, 0.14113946365458624, 0.1513932134423937, 0.14566256451819623, 0.26461438089609146, 0.15955380483397416, 0.23733987872089657, 0.1921144612133503, 0.14084241459412233, 0.14400566342685903, 0.22644105926156044, 0.3063911848834583, 0.13392674497195653, 0.3063989473240716, 0.21610348325754913, 0.16436560877731868, 0.1713050678372383, 0.11452504034553256, 0.16034773151789392, 0.23471508813755854, 0.18858810115073407, 0.24838949580277714, 0.15784373373857566, 0.19159933099789278, 0.14343097140746458, 0.09438437037169933, 0.18225276895931788, 0.2916502830173288, 0.16442526557615825, 0.19671444009457315, 0.2669052236846515, 0.13546335537518772, 2.002153822353908, 12.013207810265676, 38.99865450177874, 77.67570468357631, 90.7196273803711, 106.18306568690709, 112.12945216042655, 101.99741527012416, 112.72804641723633, 110.5886891228812, 104.99418027060372, 109.05742427280971, 117.48827116830009, 116.93463870457241, 116.63790893554688, 106.46596854073661, 117.01095771789551, 112.70581912994385, 108.31994247436523, 110.84522356305803, 105.81706237792969, 102.3690049307687, 94.80220127105713, 93.22103445870536, 115.33671978541783, 112.37270859309605, 115.92844227382115, 122.76748466491699, 124.59422166006905, 131.00978524344308, 137.74914877755302, 134.86443737574984, 119.76803071158272, 114.72098432268415, 119.16073036193848, 126.22918837411063, 120.6815937587193, 127.8333328792027, 119.50048337663922, 108.85867800031389, 108.47695786612374, 90.48347895486015, 79.48786435808454, 63.3461012159075, 44.07703379222325, 16.22316997391837, 4.633041884217944, 0.35300613354359356, 0.18435062281787395, 0.2744348996451923, 0.22011271598083632, 0.11764893414718763, 0.22266676250313008, 0.18115962190287455, 0.2163471316120454, 0.1970189530402422, 0.26924375391432215, 0.14962583327932016, 0.19487297747816357, 0.1811002500887428, 0.2599610148796013, 0.20488142328602926, 0.2487950697541237, 0.1434376346213477, 0.18618310163063662, 0.1551623126225812, 0.151534837271486, 0.09131776528166873, 0.2301069125533104, 0.16613292108689034, 0.25861295578735216, 0.13397101259657315, 0.2495984552162034, 0.21070891272808823, 0.19085336316909107, 0.1688365845807961, 0.16983183260474885, 0.21081745118967124, 0.17313810304871627, 0.1623329214219536, 0.22320674067097052, 0.20260545398507798, 0.11920283362269402, 0.13641436291592463, 0.16663180717400142, 0.2954021745494434, 0.16038076260260173, 0.22001274063118867, 0.30942882331354277, 0.24552496522665024, 0.228199089212077, 0.15876803414097854, 0.277476039315973, 0.2350910236792905, 0.2525551308478628, 0.13163082674145699, 0.2224633377045393, 0.17382877027349813, 0.16324697594557488, 0.1596010308712721, 0.22095305446003163, 0.19769640240286077, 0.1287307409303529, 0.1794353151427848, 0.19233347874666962, 0.18114442271845682, 0.16893746916736874, 0.17949394056839602, 0.09193075381751571, 0.22353428309517248, 0.2631577562008585, 0.15690236139510358, 0.13248721935919353, 0.16943620597677572, 0.15430491577301705], [0.03428247970129762, 0.09604253353817122, 0.036257932627839703, 0.05088542075827718, 0.04922541197655456, 0.05774848695312228, 0.029745899739542177, 0.05172352346458605, 0.12463503570428916, 0.054435329378715584, 0.048826141615531275, 0.006319612655456045, 0.0457400931045413, 0.08083309645631484, 0.04772117108638797, 0.04750243514510138, 0.06134620175829955, 0.027261140124340142, 0.07437607579465423, 0.08978281050388302, 0.10383103668157544, 0.08313024962054831, 0.08995870713676725, 0.09671914830271687, 0.02330975929674293, 0.07200262136757374, 0.08360118006489106, 0.06413827157978501, 0.03985999005713633, 0.029981086762355905, 0.07548923284879752, 0.0979690912312695, 0.1082444591447711, 0.07725870968507868, 0.10841012346957411, 0.12124402980719294, 0.09971713993166174, 0.09173488789903265, 0.10139914003333875, 0.06346253212541342, 0.07764685207179614, 0.08056350092270545, 0.13556380569934845, 0.048768673092126846, 0.08858940311308418, 0.06884409513856683, 0.1363041823995965, 0.06739637960812875, 0.012139750594672347, 0.03563957009464502, 0.1519897814307894, 0.0632425985698189, 0.04771801589855126, 0.10785614712429897, 0.16539227297263487, 0.05572168928171907, 0.03397525940090418, 0.1429378121559109, 0.2942524648138455, 1.5258133368832725, 12.1127998147692, 45.301810128348215, 61.77791363852364, 68.1799977166312, 66.41260528564453, 68.40078367505754, 73.76668984549386, 72.15721607208252, 73.2100418635777, 47.32411806924002, 63.186528887067524, 51.424090249197825, 53.49552195412772, 34.14293370928083, 56.349942684173584, 63.982118470328196, 39.308120318821494, 65.45660264151437, 42.79640436172485, 47.26282453536987, 40.71605464390346, 39.3368684904916, 36.23264265060425, 31.713270255497523, 28.43876838684082, 45.40862478528704, 42.10284212657383, 51.18221650804792, 53.85363905770438, 56.05652720587594, 61.32895578656878, 83.65080111367362, 68.40184674944196, 63.411935397556846, 71.3044011252267, 69.82324668339321, 64.99012838091168, 66.73829514639718, 87.1668814250401, 90.8917828968593, 82.58384963444301, 88.55754252842495, 98.62714985438755, 96.48042052132743, 91.93625000544957, 87.87698037283761, 74.23876435416085, 66.32749680110386, 40.69044705799648, 17.067853791373118, 2.845940670796803, 0.09173232303666216, 0.25465196690389086, 0.045476675632276704, 0.11951673749302115, 0.052088663514171324, 0.018097275335873877, 0.16692865267395973, 0.09958418778010777, 0.03044430904888681, 0.03264087957463094, 0.1109320277880345, 0.04234963342813509, 0.020279433777821914, 0.08979093256805624, 0.014377074781805277, 0.06551860179752111, 0.018542348506993482, 0.043680098107350726, 0.07116432527878455, 0.0575531842187047, 0.04724784880610449, 0.061107486353388855, 0.07060766193483557, 0.012013107970623034, 0.03582313417323998, 0.017223882023245096, 0.031969255435147455, 0.01378731504415295, 0.016638945821406584, 0.004313691810239106, 0.04978709647964154, 0.024431347148492932, 0.0681105445006064, 0.06863380356558732, 0.09036814873772007, 0.09536029371832098, 0.138771403580904, 0.043340833990701606, 0.048379943772618256, 0.05160082058448877, 0.05928437810923372, 0.13890408431845053, 0.14986440619187696, 0.10945672980908837, 0.053504216484725475, 0.014438811290477003, 0.004049913442161466, 0.03927409881725907, 0.05577027578172939, 0.06298294357423272, 0.014855754096060991, 0.07511709710316998, 0.07040865439921618, 0.08242458677185432, 0.032909572656665526, 0.040813287653561146, 0.02888367172064526, 0.025453370164281557, 0.026708583613591533, 0.03471606697088905, 0.052448694195066176, 0.05696065351366997, 0.01582727375041161, 0.06430671789816447, 0.06462125280605895, 0.013887318383370127, 0.05763620297823634, 0.018191366090572307, 0.02994447640542473, 0.035853474866598845, 0.05792084163320916, 0.04521320726988571, 0.030280558192836385, 0.06696020372744117, 0.016550056037626097, 0.03380386145519359, 0.030081211389707666, 0.018268814077600837, 0.05655177170410752, 0.06912071350961924, 0.030270970493022884, 0.07866854939077582, 0.0693832929911358, 0.06717418653092214, 0.06382698006927967, 0.03859354515693017, 0.048236420045473745, 0.058124822830515246, 0.019008568221969262, 0.03804565187809723, 0.07741465738841466, 0.050940076754029305, 0.04112313388447676, 0.039025646434830766, 0.03356000275484153, 0.09576453095568077, 0.02133943948761693, 0.024971379599134837, 0.0487490159326366, 0.07895244165722813, 0.12838858286184923, 0.08995196928403207, 0.13498250474887236, 0.0561458890193275, 0.06077005088861499, 0.07332051957824401, 0.08973987959325314, 0.11413607693144254, 0.05895011818834713, 0.03133678276623998, 0.0599150899797678, 0.07712655820484672, 0.07330825845045702, 0.023948282801679203, 0.13973296912653105, 0.04665481259248086, 0.08596254299793925, 0.01070064736995846, 0.04514124523848295, 0.11762422190180846, 0.057397284012820037, 0.041297809154327424, 0.08375815914145537, 0.09326754244310514, 1.7261941730976105, 12.354054297719683, 50.0362674849374, 70.33501625061035, 81.15708569117955, 81.96170098440987, 82.98609474727085, 85.86686652047294, 88.62964398520333, 80.94923033033098, 70.49456773485456, 86.71507481166294, 67.2620712007795, 71.58321843828473, 58.21178545270647, 76.24830150604248, 85.27016217367989, 71.38913440704346, 89.32504749298096, 72.61783300127301, 83.23777239663261, 72.38285187312535, 70.90761729649135, 65.63394846235002, 61.35315636226109, 57.313390323093955, 84.22089385986328, 73.84162616729736, 83.22688456944057, 91.44296264648438, 91.12760475703648, 95.52248627798897, 114.65635912758964, 100.13718795776367, 95.74415465763637, 98.26059068952287, 91.53110749380929, 85.54605429513114, 94.07522514888218, 100.34722505296979, 99.43000030517578, 97.29341534205845, 104.7649175098964, 112.39264297485352, 109.28459562574113, 105.8941456930978, 104.5488007409232, 86.80604062761579, 74.92562157767159, 45.34956162316458, 20.013063158307755, 3.464890543903623, 0.10370174183377198, 0.23997313742126736, 0.04112724580668977, 0.05631473906604307, 0.06124548680548157, 0.03567473177931138, 0.07692014106682368, 0.14151735337717192, 0.01862322648854128, 0.10844977705606393, 0.07535607035138778, 0.023492149509755627, 0.09155169701469795, 0.14083519498152391, 0.05096249555104545, 0.10561586197997842, 0.049833396316639016, 0.03881165684599962, 0.06183062147881303, 0.039766576141119, 0.01896325226074883, 0.011863670810790998, 0.07189809983330113, 0.009660748349103545, 0.052518067615372796, 0.03184717680726733, 0.04274753314842071, 0.027748407995594398, 0.014104014478756912, 0.036436723212578466, 0.03645062639511057, 0.06537426382835422, 0.10025244977857385, 0.053983319883367846, 0.03922537321756993, 0.03358816195811544, 0.06171041900025947, 0.021263526686068093, 0.08712995571217366, 0.078297458589077, 0.043238164857029915, 0.07683938182890415, 0.08026343916675874, 0.09245266259780952, 0.031006607626165663, 0.018826761549072604, 0.017256209127871052, 0.09541070208485637, 0.04606080607378057, 0.10047359791185174, 0.047076114985559664, 0.028729342323328768, 0.04678947804495692, 0.08307823991136891, 0.03435107280633279, 0.030445306495364224, 0.05266459046729973, 0.030246200572167124, 0.08641471194901637, 0.05728890161429133, 0.017405498706336533, 0.03846378890531404, 0.026488787461338297, 0.048343085750405274, 0.12691000077341283, 0.1185707375407219, 0.2320040421826499, 0.12085104946579252, 0.09587169199117593, 0.09422712666647774, 0.16086377097027643, 0.1526246052235365, 0.18317877926996776, 0.15580555024955953, 0.1428489512098687, 0.20855938164251192, 0.1368181048227208, 0.10861042700707912, 0.20290407724678516, 0.21484234450118883, 0.12974616858576024, 0.15573378838598728, 0.23150043349180902, 0.1730638848883765, 0.24632791642631802, 0.17564729840627738, 0.20198211100484642, 0.16693626583686896, 0.19302124184157166, 0.16160745892141545, 0.1307335863155978, 0.23631100250141962, 0.2072929231716054, 0.14596930305872644, 0.11422306512083326, 0.20879506399588926, 0.19002458692661353, 0.14651882142892905, 0.17052220127412251, 0.18963761840547833, 0.19010172278753348, 0.23278604022094182, 0.22259143154535974, 0.22953938586371286, 0.10102586434887988, 0.15422042459249496, 0.2848942184022495, 0.33727302349039484, 0.20371732860803604, 0.2502350024878979, 0.16251236679298536, 0.17389830654220922, 0.1838303493069751, 0.06195752788335085, 0.3310649166149752, 0.21905052369194372, 0.16289492483649934, 0.21293521326567444, 0.22444109086479458, 0.3310124251459326, 0.16446744331291743, 0.15124700271657535, 0.3485130917813097, 0.5400930302483695, 3.949250553335462, 21.656452826091222, 64.92441231863839, 87.84897218431745, 93.41756425585065, 91.17744418552944, 88.29687391008649, 95.52768353053501, 93.13303552355084, 97.8572130203247, 68.85452883584159, 86.80824320656913, 74.51261370522636, 74.11265454973493, 55.609289033072336, 80.31169836861747, 88.98118114471436, 60.105301584516255, 94.56401702335903, 64.82779066903251, 70.39305455344063, 58.41054562159947, 54.04735483442034, 54.61880942753383, 43.74078614371163, 41.07992485591343, 67.29283087594169, 61.68145874568394, 73.17199352809361, 73.71990067618233, 78.56396239144462, 84.98125607626778, 109.43496853964669, 89.03647490910122, 84.55915301186698, 95.56605843135289, 91.61315182277134, 83.74547726767403, 90.21309675489152, 110.78020232064384, 115.21410492488316, 106.35098975045341, 111.98670142037528, 121.86637278965541, 120.81012153625488, 116.55501692635673, 116.21025426047188, 103.29785401480538, 96.34522247314453, 62.793983459472656, 28.99435329437256, 5.662031880446842, 0.2209142286862646, 0.5236303050603185, 0.0755269933225853, 0.17396803280072554, 0.2092063512120928, 0.21387839051229612, 0.308610591505255, 0.241911169141531, 0.1497028334332364, 0.17021624983421393, 0.36111240142158096, 0.13792470044323377, 0.18645679551575864, 0.24028632204447473, 0.23732144970979008, 0.17087404882269247, 0.2150289144899164, 0.2289130709000996, 0.1371295116841793, 0.11575803346931934, 0.1971038920538766, 0.13508725698505128, 0.1613011953553983, 0.08637321274727583, 0.1775599257754428, 0.15891754254698753, 0.1784380315137761, 0.096500802519066, 0.10841159589056458, 0.10014121753296681, 0.1869728078267404, 0.17137497051485948, 0.1754862277635506, 0.16268102345722063, 0.17941957313035214, 0.22193109483591147, 0.31086069505129543, 0.13425128827137606, 0.1864990953888212, 0.1211335507354566, 0.1391236718211855, 0.21307125953691347, 0.3000225637640272, 0.19632331893912383, 0.13431270926126412, 0.0843575226941279, 0.1218347352530275, 0.28926914078848703, 0.1723735433604036, 0.27739209096346584, 0.18186738821012632, 0.18820295110344887, 0.10787828772195748, 0.20688557145851, 0.09891142709446804, 0.09129543469420501, 0.08677080034145288, 0.1023291265591979, 0.24888110799448832, 0.07398458144494466, 0.12690237403980323, 0.16926716933293, 0.08111418637314013, 0.10781846807471343, 0.23430072037237032], [0.09204153823001043, 0.035552191747618575, 0.011032488313503563, 0.06027434713074139, 0.0619055928130235, 0.06232926329331739, 0.015762848546728492, 0.018032473545255404, 0.015108220013124602, 0.022233365269910012, 0.06359239694263254, 0.028854372578540018, 0.023633004897939305, 0.025644462588908415, 0.06940772025180714, 0.04241711712841477, 0.04005685681477189, 0.019412327092140913, 0.022773472359403968, 0.04888699942135385, 0.08889244363776275, 0.04979920154437423, 0.014582860882260969, 0.05801466267023768, 0.06848725357225963, 0.018687644906874214, 0.06809207477739879, 0.01827228139154613, 0.041982213500887156, 0.07235934758292777, 0.0360202214547566, 0.02296669708032693, 0.062202757224440575, 0.015902943975691284, 0.043578908180019686, 0.07448827834533793, 0.03899487487173506, 0.019672835345513055, 0.06932794488966465, 0.014110162854194641, 0.0302291422017983, 0.027688378002494574, 0.05350887802030359, 0.0307490968012384, 0.03682446526363492, 0.013953583265122558, 0.05655191758913653, 0.019950785341539552, 0.026060645435271517, 0.04720004601404071, 0.04719913338444062, 0.06745036385421242, 0.21654174902609416, 0.03793234331533313, 0.04309595748782158, 0.02989415285576667, 0.4672164150646755, 1.3264266358954566, 14.036675231797354, 45.88726881572178, 55.146973269326345, 47.55041742324829, 57.64650085994175, 71.92492389678955, 66.24500778743199, 43.918486322675435, 44.44595881870815, 41.863115378788535, 32.07670273099627, 26.029261657169886, 23.37449046543666, 23.27499747276306, 27.733626978737966, 33.2106556892395, 32.05018145697457, 30.975830146244594, 25.257181303841726, 33.11453430993216, 24.963658128465923, 21.25294314111982, 22.374229533331736, 43.805602414267405, 33.63149070739746, 34.246044976370676, 27.010144063404628, 21.418047973087855, 25.943918670926774, 25.33842658996582, 19.953037670680455, 27.75759826387678, 22.511008296694072, 25.806210586002894, 20.169022423880442, 29.3321920803615, 26.719924756458827, 25.8339912210192, 41.44137709481375, 20.733181408473424, 42.77059875215803, 59.516004017421174, 43.000330516270225, 54.56306055613926, 56.5853511265346, 60.757125990731375, 77.49510015760148, 81.86418996538434, 88.06018352508545, 82.5103099005563, 85.18855558122907, 80.85926505497524, 60.25123459952218, 26.967973709106445, 5.112592654568808, 0.2817548540021692, 0.0989202344790101, 0.02784873957612685, 0.03230344410985708, 0.0755840309762529, 0.019579421429495727, 0.0145138419965016, 0.04258173650928906, 0.04745823876666171, 0.036954584531486034, 0.023005578833233033, 0.039945909553872685, 0.03305683511176279, 0.032747433321284394, 0.05294064226161156, 0.043203087989240885, 0.04213607131636568, 0.05151286209002137, 0.05025968254942979, 0.05350093576791031, 0.07044384322528328, 0.015828764831115092, 0.045633278121905665, 0.06388925601329122, 0.036020835528948476, 0.019100441863494258, 0.04591815087145992, 0.030234662084175006, 0.04932890213759882, 0.020795938026692187, 0.10913678019174508, 0.0033781919753112432, 0.024010953992339115, 0.04061714692839554, 0.07458087801933289, 0.019957295885043483, 0.04929034099248903, 0.026401894266850183, 0.05296259965481503, 0.01279778961491372, 0.03223716141656041, 0.03198316201035466, 0.012882919466522123, 0.030887904710003307, 0.03830512027655329, 0.041683861653187444, 0.04861509347600596, 0.020942627119698694, 0.02754322070229266, 0.050869400546486886, 0.03699923552838819, 0.0259067333369915, 0.049317115984324894, 0.03342142554798296, 0.06142612639814615, 0.022767735345821296, 0.06741307156958751, 0.033221094869077206, 0.13241495537970746, 0.031350614702595134, 0.047764068070266924, 0.07057471905968019, 0.023552445827850273, 0.05623580847999879, 0.017038977837988308, 0.02577078714966774, 0.021875743388331363, 0.02434670669026673, 0.025890533313421265, 0.05343315011954733, 0.040170508037720404, 0.09943907628101961, 0.03226682696757572, 0.05655070301145315, 0.041666148496525626, 0.030634705975119556, 0.013045218257632638, 0.0679488903177636, 0.10015105629073721, 0.040621140106980286, 0.055787588602730205, 0.027295375608706048, 0.04311589284666947, 0.07166946745876755, 0.0457515399903059, 0.06311757170728274, 0.03401788157810058, 0.024078795619841133, 0.01797766996813672, 0.03724019688421062, 0.0776049050369433, 0.02104144895981465, 0.05865733711315053, 0.06838507976915155, 0.060118209437600205, 0.04173878227759685, 0.21268363962216036, 0.041419877604182274, 0.09560276142188481, 0.028537120137895857, 0.05166431789153388, 0.04028815243925367, 0.023444579115935733, 0.08439494390040636, 0.09499383052544934, 0.06398247993950333, 0.04538509376080973, 0.04640741193933146, 0.025692426533039128, 0.046027031993227344, 0.045120580454490015, 0.03371232708117791, 0.017385442907522832, 0.029986671105559384, 0.030390650499612093, 0.3502687875713621, 0.016294708043070774, 0.03045802902696388, 0.018061104330367277, 0.5011200958064624, 0.6167901775666645, 15.587144034249441, 51.084632532937185, 65.15277181352887, 57.287202562604634, 65.47666903904506, 81.16110174996513, 75.07604312896729, 58.0552008492606, 72.446455683027, 62.55381897517613, 56.09534331730434, 36.25541884558541, 43.98478603363037, 42.47902454648699, 45.80535650253296, 33.20686197280884, 41.676691736493794, 43.05760799135481, 32.35960211072649, 48.6231359073094, 32.20575162342617, 35.56776605333601, 30.53287206377302, 48.39388704299927, 34.967431272779194, 37.95700488771711, 33.871967860630576, 31.907937935420446, 36.92396409170968, 37.71385962622506, 31.679703508104595, 38.14920595714024, 40.060450417654856, 45.17029462541853, 33.41674273354666, 44.97549145562308, 43.888112272535054, 41.02607979093279, 54.0869699886867, 33.268996238708496, 68.90131105695451, 82.76403032030377, 71.11065755571637, 77.45343181065151, 87.43503325326103, 83.51882702963692, 90.82353769029889, 91.98890345437187, 96.88359669276646, 94.72923823765346, 96.60222939082554, 92.61229583195278, 70.64942918504987, 32.38540424619402, 6.646211641175406, 0.10466801641242844, 0.11769024335912295, 0.03034983661824039, 0.053392644971609116, 0.04289760473849518, 0.013249995885416865, 0.009481150307692587, 0.12208226482783045, 0.02216691124652113, 0.02331017829211695, 0.0556573641619512, 0.035222678179187436, 0.022625360039195845, 0.04047352481367333, 0.10385235625186137, 0.03638827920492206, 0.07130965390907866, 0.1105933573895267, 0.031650683243892024, 0.01363850468104439, 0.09304915594735316, 0.02751502417959273, 0.014461582925702845, 0.032104904763400555, 0.028940953646919558, 0.04634262202307582, 0.09032027130680424, 0.03903075919619628, 0.012961419182829559, 0.03340070308851344, 0.09574500271784407, 0.03754583280533552, 0.05839468299278191, 0.08993060900164501, 0.03611545045194881, 0.04851698749033468, 0.03295022029695766, 0.01952506059647671, 0.084181456427489, 0.058549592537539344, 0.026984028119061674, 0.033224026140357764, 0.10430993312703711, 0.004500247804181916, 0.029970186097281318, 0.07971462647297553, 0.05109591928443738, 0.0048507471884866905, 0.049084120629621406, 0.0737471009737679, 0.03922337493194001, 0.0428754539628114, 0.07287218435002224, 0.023687615092577677, 0.0316736855810242, 0.037226141031299315, 0.029674884264490435, 0.03136511838861874, 0.039692439404981475, 0.0031690257102517144, 0.050347383200590096, 0.0073390262800135785, 0.015125805944470423, 0.12696007665778908, 0.08471359751586403, 0.060464133375457356, 0.07375416452331202, 0.10284383608294384, 0.08144200021134955, 0.14706709129469736, 0.18757424769657, 0.2226108240761927, 0.10611940281731741, 0.14591986499726772, 0.13171286162521156, 0.10034146678767034, 0.09243844050381865, 0.2347667110817773, 0.1424282052155052, 0.13963391658450874, 0.1032941322773695, 0.12869655633611338, 0.12989520201725618, 0.19874484757227556, 0.1308927299188716, 0.11326477689934628, 0.16943497104304178, 0.1601084800703185, 0.09721770190766879, 0.2032044239874397, 0.2248248431299414, 0.11902093195489474, 0.1797401944973639, 0.17200748728854315, 0.23241357877850533, 0.1271612758615187, 0.19572212334190095, 0.13901330131505216, 0.25037141516804695, 0.12499335647693702, 0.12195643729397229, 0.14715470373630524, 0.08297124850962843, 0.1992886391069208, 0.24172088078090123, 0.15290033471371445, 0.14444232785276004, 0.140426404774189, 0.06242722339395966, 0.30691609957388466, 0.17734639080507414, 0.15224504630480493, 0.18559497461787292, 0.12364695301013333, 0.13318433266665253, 0.443693071603775, 0.13608964319740022, 0.0856140541977116, 0.061416260498975, 0.5833606028131076, 2.6755347975662778, 28.2524767603193, 69.52241747719901, 79.79429381234306, 69.31197043827602, 79.28089141845703, 94.07981095995221, 90.5785025187901, 62.319893973214285, 64.90267140524728, 57.9695781980242, 50.745713302067344, 39.167318548474995, 36.57745395387922, 39.7030976159232, 43.9417975289481, 50.413530349731445, 47.96923051561628, 49.46221773965018, 36.8608466557094, 50.227214404514854, 37.27174227578299, 28.43671693120684, 32.39586475917271, 58.17123923982893, 48.45242214202881, 49.07410526275635, 37.94583913258144, 32.458356857299805, 36.50243425369263, 34.93278408050537, 28.06503520693098, 39.787347997937886, 31.171995162963867, 39.281883920942036, 27.94030635697501, 38.90068142754691, 39.083693504333496, 41.003849029541016, 54.94112246377127, 29.50282941545759, 59.42846366337368, 79.91396958487374, 60.7532627923148, 70.5610133579799, 70.22008609771729, 79.72196306501115, 98.1560480935233, 102.5258674621582, 109.07040350777763, 102.36357143947056, 109.08274350847516, 109.22557067871094, 88.533216885158, 43.67844343185425, 10.296649268695287, 0.21142069596265042, 0.2279299007994788, 0.1318913706179176, 0.12478340417146683, 0.22723432098116192, 0.1103795917172517, 0.11258561084313051, 0.2256827149540186, 0.12189174576529435, 0.16977254221481936, 0.09684980022055761, 0.08922208273517233, 0.08347122025276933, 0.07188451556222779, 0.15952320290463312, 0.15635806774454458, 0.11092940185751234, 0.13745900828923496, 0.1392975803464651, 0.19349898477750166, 0.20190504299742834, 0.12401853235704557, 0.13130465495799268, 0.1595933905669621, 0.12928746534245356, 0.10667383378105504, 0.10778715368360281, 0.1925174838730267, 0.145085551909038, 0.10447888156133038, 0.21473016909190587, 0.12661358953586646, 0.12794552663607256, 0.15827400636460098, 0.11948396425162043, 0.06830269204718725, 0.13720142282545567, 0.12811112989272389, 0.13720880528645857, 0.12934827565082482, 0.12680687702127866, 0.1321647252355303, 0.1695564016699791, 0.07946468131350619, 0.12170624786189624, 0.20356350471930845, 0.162562347682459, 0.11375245358794928, 0.17042510291295393, 0.15724536084703036, 0.17515378631651402, 0.1560583859682083, 0.16678161413541862, 0.11964190006256104, 0.12143974644797188, 0.14299556905669825, 0.19918155271027768, 0.15671860054135323, 0.22939257802707808, 0.09976963140070438, 0.09592799682702337, 0.1361303281571184, 0.07486474992973463], [0.018128506606444716, 0.060425497591495514, 0.02414494939148426, 0.023935790971985886, 0.07757964317819901, 0.0035067724529653788, 0.05724205555660384, 0.05325114667149527, 0.05139538732224277, 0.023834982720602835, 0.02398811111093632, 0.10005287227353879, 0.06881339821432318, 0.12548507723425115, 0.07378303618835551, 0.051415007162306986, 0.06893436743744782, 0.01677874439129872, 0.014909385503934962, 0.04937553784943052, 0.06624373860125031, 0.05748869625053235, 0.05221387358116252, 0.06556440291127988, 0.04747072041832975, 0.05494628321113331, 0.01989860599860549, 0.08570853341370821, 0.026605385222605298, 0.07614914208118405, 0.07011056039482355, 0.007175052355575774, 0.019194307005298988, 0.08856873493641615, 0.031763618612395864, 0.03826797726963248, 0.04496202378400734, 0.026505148636975458, 0.04983020041670118, 0.06928282231092453, 0.017045318747737577, 0.027133621341947998, 0.016493296583316157, 0.09120149152087313, 0.0721381858789495, 0.04371065593191555, 0.050300669457231245, 0.03213811905256339, 0.023707903289635266, 0.03542930227039116, 0.09864190619971071, 0.04350273244615112, 0.15668433452291147, 0.057180383508758884, 0.1380741409957409, 0.3015892468392849, 9.841555288859777, 51.384558473314556, 67.38567270551408, 71.09215450286865, 55.956452301570344, 37.097377232142854, 32.369089875902446, 28.11266163417271, 28.952203784670147, 28.08383182116917, 20.918408223560878, 27.882167305265153, 22.75277955191476, 40.278404985155376, 40.775729247501914, 39.22154923847744, 50.36102281297956, 64.6842269897461, 70.81380271911621, 61.11064338684082, 101.06802422659737, 67.08362061636788, 85.50192628587995, 110.60924189431327, 95.50389984675816, 107.74039322989327, 99.91019030979702, 110.6952953338623, 120.14848627362932, 108.63561303274972, 88.4704954964774, 93.28864737919399, 110.61419595990861, 92.52983461107526, 88.53706618717739, 73.46222673143659, 73.26948370252336, 94.34878962380546, 69.83421788896833, 61.53632477351597, 76.92252690451485, 88.05705683571952, 56.68648910522461, 43.47457981109619, 37.86587578909737, 41.708170550210134, 31.796023300715856, 39.50808947426932, 42.188106945582796, 43.984994479588096, 57.319643701825825, 68.59353365216936, 80.68949277060372, 73.77620887756348, 79.40656348637172, 81.17824990408761, 60.95193263462612, 23.66470456123352, 1.1738996718611037, 0.1471066770276853, 0.005779299460950175, 0.015154530028147357, 0.024224930010469894, 0.07470243756792375, 0.01267181704419532, 0.02908154610278351, 0.01749105179416282, 0.029188683389553, 0.03749024382393275, 0.03680714226460882, 0.03382644310061421, 0.04051772119211299, 0.019244447350502014, 0.050079942015664916, 0.017639004658641558, 0.08147522128586258, 0.07286641001701355, 0.021887744976473705, 0.03004872313301478, 0.07340078348559992, 0.01826318902229624, 0.029446485984538282, 0.09005722363612481, 0.03060794116130897, 0.025172419347135083, 0.07747783578400101, 0.022013482604441897, 0.07182643974998168, 0.057630564352231364, 0.02868184487202338, 0.053768831571297984, 0.029593398994100944, 0.024538915304999267, 0.08434705289879016, 0.022727067349478602, 0.01312509794453425, 0.020199103713301674, 0.06704220468444483, 0.027343405710001076, 0.05527970853394695, 0.03152990061789751, 0.026717713302267448, 0.027581695334187577, 0.07876297432397093, 0.029183869183595692, 0.05923744384199381, 0.03126162822757449, 0.006187107488845608, 0.07014581707439252, 0.04977099484364901, 0.027092532653893744, 0.0047935220895202035, 0.031235467309930494, 0.037562317813613584, 0.05212072768647756, 0.02888268105951803, 0.013916932196090264, 0.03553754556924105, 0.05229397803278906, 0.027634222426318696, 0.01152444486173668, 0.09564877966684954, 0.02980514263202037, 0.050305273317332776, 0.03495664495442595, 0.042359638426985056, 0.049785708875528405, 0.08631807499166046, 0.05381687185061829, 0.034728623261409144, 0.03968444965513689, 0.030802300732050623, 0.11758957590375628, 0.04863660303609712, 0.07379299029707909, 0.03470395172813109, 0.047650423632668595, 0.06590626920972552, 0.019204033804791312, 0.05755937245807477, 0.021164138269211565, 0.026570053904184272, 0.04340577997001154, 0.031916892887758355, 0.047672258889568705, 0.007641990469502551, 0.040639189138476334, 0.05462362963174071, 0.08877316396683455, 0.013292897958308458, 0.06263138779572078, 0.04952777735888958, 0.0401722688360938, 0.056220948563090394, 0.040872028430125544, 0.020724944604028548, 0.04736514376210315, 0.09054270187126738, 0.057994014849620204, 0.08223657150353704, 0.046332026698759625, 0.06154159948761974, 0.03131061167057071, 0.1359813218670232, 0.04814573723290648, 0.08023649454116821, 0.03759637687887464, 0.01843128419880356, 0.018711034008967023, 0.008136607723177543, 0.03965149999463132, 0.08731558253722531, 0.1521431032036032, 0.05574855248310736, 0.1431831025651523, 0.5778932933296476, 11.768817952701024, 63.85338919503348, 82.73708520616803, 82.66015475136894, 64.67636857713971, 49.26984296526228, 43.46766635349819, 51.416492394038606, 47.52467087336949, 34.78127861022949, 31.08294357572283, 32.58855220249721, 25.900845050811768, 31.79574884687151, 33.49306869506836, 34.135467869894846, 41.38514532361712, 53.687948840005056, 53.56476770128523, 50.46697241919381, 57.49468272072928, 50.04301071166992, 53.97789021900722, 54.86500147410801, 57.455533095768516, 65.15703105926514, 65.95105729784284, 56.85125868661063, 58.35922622680664, 57.695106983184814, 59.13940470559256, 56.12145464760916, 53.04152665819441, 61.4284678867885, 55.84647968837193, 52.768577098846436, 50.32853651046753, 48.243201460157124, 45.28304999215262, 45.05076476505825, 67.99901103973389, 57.11520685468401, 52.58370290483747, 50.222010203770225, 39.77434097017561, 52.66454866954258, 38.23180614198957, 48.14177165712629, 69.70848328726632, 72.346999168396, 75.81007862091064, 87.47891112736293, 90.23528235299247, 81.42256246294293, 89.52173709869385, 95.84337493351528, 71.56004619598389, 31.55212763377598, 2.8548022295747484, 0.0750871194260461, 0.12517476959952287, 0.02885776186095817, 0.08793809770473413, 0.048585913077528985, 0.05761909032506602, 0.022997765502493297, 0.023574969797794307, 0.030992022515939813, 0.048335645613925796, 0.01793638789760215, 0.0814913772046566, 0.010920939700944083, 0.04147582620914493, 0.08453059662133455, 0.0318425186643643, 0.018922624976507256, 0.06841834834111588, 0.016394121904990504, 0.1049704123288393, 0.05076603591442108, 0.02116562595723995, 0.057810104718165736, 0.0538413703574666, 0.053161810750940015, 0.013582215112234865, 0.025267432909458876, 0.07325645908713341, 0.0262977628902133, 0.0786590702565653, 0.059902998485735486, 0.015868498145469596, 0.01802705883580659, 0.03977062699518033, 0.0361864964610764, 0.0565224657766521, 0.008526324311138263, 0.04430776335565107, 0.01684007717163435, 0.060783750510641506, 0.022005701504115547, 0.06330579732145582, 0.04079093671004687, 0.058094322681427, 0.05890576235417809, 0.01583480040010597, 0.05328267480113676, 0.0746179192460009, 0.040945228787937334, 0.055941405706107616, 0.03459581360220909, 0.029984286054968834, 0.043514888401010206, 0.016908390380974327, 0.07888430995600564, 0.052929124129670005, 0.052177490533462594, 0.05774753700409617, 0.04601647738101227, 0.06101022514381579, 0.03537632225613509, 0.08601284958422184, 0.24655742411102566, 0.1387933881155082, 0.10038403128939015, 0.22506589948066644, 0.11636909496571336, 0.09831694899392979, 0.24231495176042828, 0.13676948100328445, 0.10009768272617034, 0.11612141611320631, 0.2445589756327016, 0.17746505300913537, 0.328272745013237, 0.2017539061073746, 0.1761049295642546, 0.2105161002171891, 0.164090327120253, 0.1247964184731245, 0.13635279264833244, 0.19880643141056809, 0.11075256884630237, 0.12248368614486285, 0.18765770750386374, 0.18556463053183897, 0.1635665116565568, 0.21134824199335916, 0.14612544753721782, 0.2254696956702641, 0.16699368347014698, 0.1905762358967747, 0.1156796355332647, 0.1065243457310966, 0.15664214321545192, 0.11969760778759207, 0.1307314692863396, 0.11359246181590216, 0.1606643766696964, 0.29064710970435825, 0.2851140908896923, 0.15076782128640584, 0.11888519780976431, 0.13754811350788387, 0.15030945731060846, 0.11511202741946493, 0.26291581775460926, 0.1887955293059349, 0.25511776762349264, 0.1100162769268666, 0.1779576422912734, 0.1952707211353949, 0.3212835629071508, 0.3883204885891506, 0.13494354326810154, 0.29421025993568556, 1.0137880976711, 17.78647470474243, 82.0556753703526, 98.084794316973, 94.26498045240129, 76.96202741350446, 60.23206451960972, 54.19460800715855, 50.55874422618321, 48.6375013078962, 44.13745185307094, 29.762810162135533, 41.73894412176949, 39.01044906888689, 60.41023717607771, 60.431783539908274, 53.567209993089946, 70.98424203055245, 85.34963566916329, 94.41246291569301, 88.84608731951032, 138.14281981331962, 93.77022702353341, 117.76800564357212, 144.78628431047713, 128.33535412379672, 143.05684988839286, 133.28027588980538, 149.37327657427107, 156.93595995221818, 141.60359246390206, 120.6557742527553, 124.39700399126325, 145.91899354117257, 120.97912951878139, 117.88003839765275, 103.14705726078579, 107.2024359021868, 128.62541362217493, 99.80834361485073, 87.31396784101213, 99.26748194013322, 114.11356585366386, 78.18142236982072, 61.47036552429199, 53.428249495370046, 56.30837856020246, 41.10451800482613, 54.04363407407488, 58.35527965000698, 62.23117937360491, 79.8198492867606, 92.5011385508946, 100.69494765145438, 92.90586417061942, 101.10587106432233, 109.58878776005336, 89.6409890311105, 44.92391497748238, 5.088778138160706, 0.15610379353165627, 0.26096269541553085, 0.12392131185957364, 0.21771656455738203, 0.18631769583693572, 0.19769273831376008, 0.100114917515644, 0.11386547716600554, 0.17833448706993035, 0.1878222929579871, 0.16694128699600697, 0.12678618170320988, 0.22640601971319743, 0.1380543006317956, 0.1575844112251486, 0.10735924235944237, 0.12242107093334198, 0.11042433431638138, 0.11956491347934518, 0.26231064594217707, 0.18630122100668295, 0.13095655292272568, 0.12531840189227036, 0.1137343163469008, 0.1336846843894039, 0.12020832752542836, 0.22133451327681541, 0.09486728374447141, 0.14687281314815792, 0.21074579789170197, 0.14816649444401264, 0.11761392174022538, 0.11595824201192174, 0.202339983944382, 0.2143367544880935, 0.18882970032947405, 0.08300267146634203, 0.1331356002816132, 0.2200744601764849, 0.1370459297405822, 0.10049809981137514, 0.14754613701786312, 0.10878121427127294, 0.21794049468423637, 0.23023119302732603, 0.07749980674790484, 0.18921626172959805, 0.19760781287082604, 0.15797782582896097, 0.09289858224136488, 0.11873004399240017, 0.09003628404544932, 0.09379185323736497, 0.13413755223155022, 0.13093147426843643, 0.14257441594132356, 0.12339461940739836, 0.18785931382860455, 0.1678547036967107, 0.15117860638669559, 0.16656772632684025], [0.06386193140809025, 0.08623544978243963, 0.18695448738123688, 0.1323486217962844, 0.12198512575456075, 0.1421175447425672, 0.04224057249458773, 0.0463139640965632, 0.10019043167786938, 0.07174435736877577, 0.037170623296073506, 0.08124116741653, 0.21399513924760477, 0.19450422083692892, 0.1412380412220955, 0.12319191385592733, 0.10862302061702524, 0.25556684924023493, 0.1745854996676956, 0.19384081714919635, 0.12249680901212351, 0.2525894104370049, 0.19743868123207772, 0.14004554306822165, 0.17133594118058681, 0.1178817937948874, 0.15994056979460375, 0.19147237709590367, 0.10318377534193651, 0.06154393364808389, 0.12390938321394579, 0.12051210765327726, 0.08176034848604884, 0.12433075346052647, 0.19835185366017477, 0.24600772932171822, 0.08367587319974389, 0.21574428038937704, 0.20725088114184992, 0.1917119813816888, 0.06572266441902944, 0.18419550971261092, 0.13470080415053026, 0.10525929182767868, 0.1677359329270465, 0.1386711568172489, 0.047472148734544, 0.12729730856205734, 0.06616868584283761, 0.13190920251820767, 0.13737572490104608, 0.3865043488996369, 1.0966793469020297, 0.6463724587644849, 9.688457812581744, 37.2001827784947, 62.54506424495152, 67.30086994171143, 61.836090905325754, 63.54404149736677, 43.3070205279759, 22.7285772391728, 15.591490132468087, 28.460889714104788, 31.049390724727086, 38.06444140842983, 73.2309489931379, 60.711392947605674, 69.58437456403459, 58.028158460344585, 82.46965599060059, 78.50638266972133, 61.885714939662385, 37.15618678501674, 19.755225930895122, 22.54745854650225, 26.112553187779017, 25.25339800970895, 30.47169664927891, 54.513922895704, 45.554939951215474, 45.57288019997733, 42.00631775174822, 53.43601063319615, 58.681761605399, 48.84173665727888, 59.254307065691265, 55.33256312779018, 52.27398695264544, 52.82474981035505, 66.59347384316581, 51.78264856338501, 60.62491566794259, 64.47877570561, 61.0436349596296, 50.04793003627232, 50.214335918426514, 47.05469124657767, 62.9915554864066, 58.77345698220389, 81.08160046168736, 81.2312160219465, 88.37152535574776, 66.58443423679897, 46.86970935549055, 28.922187566757202, 22.641967943736486, 21.119780915124075, 36.23663091659546, 62.197536196027485, 59.81895242418562, 64.28782531193325, 69.82483087267194, 69.74129268101284, 46.5203469821385, 15.757084812436785, 1.6749805212020874, 0.07352216661508594, 0.07621365040540695, 0.12320696376264095, 0.11026681919715234, 0.05518195199381028, 0.29226644709706306, 0.22183128233466828, 0.08050897384860686, 0.13446274692458765, 0.13857399060257844, 0.09196877213461058, 0.10407214052975178, 0.18026713122214588, 0.14278056845068932, 0.13565837991024765, 0.09408618815775428, 0.1019301140414817, 0.14424946105905942, 0.10973655086542879, 0.13647092559507915, 0.041043463695262156, 0.1306609016444002, 0.10584593963410173, 0.1415224831019129, 0.11673012987843581, 0.04439579988164561, 0.16120345917131218, 0.1438346454607589, 0.08015475142747164, 0.12192286338124957, 0.2533704585262707, 0.18042200005480222, 0.22961402471576417, 0.16065821557172708, 0.22720757313072681, 0.23459238186478615, 0.1619442565632718, 0.33923040702939034, 0.29211868931140217, 0.17314977385103703, 0.169024403073958, 0.16234334371984005, 0.1032443278070007, 0.07312726601958275, 0.11729118334395544, 0.031872896677149196, 0.12167857720383576, 0.1608859726360866, 0.23611322311418398, 0.07497906950967652, 0.15991652251354285, 0.2341304352240903, 0.1389983735446419, 0.15112912761313574, 0.0758719944528171, 0.12253047791974885, 0.11572340104196753, 0.06379204908651964, 0.11206503877682344, 0.06488319446465798, 0.005747860389029873, 0.15891413630119391, 0.03262021139796291, 0.09101822599768639, 0.05946952995977231, 0.041804973368666, 0.020328196696937084, 0.042442029541624446, 0.06711598179702248, 0.02881084455709372, 0.031714760698378086, 0.1359831810529743, 0.024453832102673392, 0.0827583513621773, 0.054082297786538086, 0.05650476958336575, 0.05488352211458342, 0.020376506693927304, 0.008759658933351082, 0.03998574295214244, 0.09501195419579744, 0.14354344537215574, 0.06257402444524424, 0.12857432503785404, 0.06214217761797564, 0.08069670413221632, 0.16208423833761895, 0.06003820337355137, 0.0749044781550765, 0.06709032638796739, 0.05492496024817228, 0.10212367972625153, 0.11623440576451165, 0.05097703316381999, 0.13984342105686665, 0.06324754509010486, 0.13232731579669885, 0.09837771180484976, 0.12545269754316124, 0.08524278697690793, 0.046040677332452366, 0.06855794335050241, 0.11796221376529761, 0.10052845746810947, 0.07854049626205649, 0.11671569065323897, 0.08679973985999823, 0.09954494131462914, 0.2568322627672127, 0.1490212314363037, 0.25711504902158466, 0.5822174070136887, 1.0601821967533656, 13.278109993253436, 47.61952420643398, 75.29334803989956, 80.56042998177665, 74.07582214900425, 76.32116726466587, 62.04644066946847, 42.71895974023001, 27.01851143155779, 25.238021646227153, 30.200734274727957, 29.415441921779088, 36.48146111624581, 37.24591582162039, 51.23358801433018, 45.19364057268415, 56.902296679360525, 52.90426846912929, 42.942448547908235, 30.93772622517177, 24.336980990001134, 22.463361024856567, 26.72690074784415, 24.436533042362758, 28.349115780421666, 41.804135595049175, 36.36608280454363, 36.97074631282261, 34.78547184807913, 37.43177318572998, 39.7844888142177, 37.136120387486045, 38.5152405330113, 38.97034754071917, 43.73588071550642, 39.546624183654785, 45.42223630632673, 39.064002309526714, 44.95821475982666, 54.33324193954468, 53.359191349574495, 42.94429676873343, 40.29979501451765, 44.893356800079346, 45.2334155355181, 44.807921750204905, 63.58261094774519, 60.83628681727818, 57.943668365478516, 56.88406113215855, 42.711949007851736, 30.55771882193429, 37.131815978458945, 45.05185215813773, 63.08434867858887, 82.16779845101493, 77.28931535993303, 76.55578013828823, 81.96139526367188, 85.42786543709892, 59.483917236328125, 24.41315582820347, 2.8954140160764967, 0.10896737035363913, 0.12503451641116822, 0.07112000337136642, 0.10140331980905362, 0.016828180756419897, 0.03495250928348728, 0.0884543000055211, 0.11404826092932906, 0.1356099732220173, 0.06782121716865472, 0.07281002375696387, 0.031124397912727933, 0.22350969298609666, 0.0735542681068182, 0.05228136067411729, 0.02072130935266614, 0.09418145447437253, 0.12708921544253826, 0.05281829221972397, 0.057211725041270256, 0.030875775896544968, 0.08374942639576537, 0.15837391386074678, 0.010657144793575364, 0.018239662516862154, 0.05961133699331965, 0.06638291970427547, 0.05661794583180121, 0.0016008326825353184, 0.07783684866236788, 0.02735440306631582, 0.08638282758849007, 0.06258967146277428, 0.10079835155712706, 0.13477730218853268, 0.10827253692384277, 0.12627918033727578, 0.11719633771904878, 0.11874099554760115, 0.07387009901659829, 0.11905758641660213, 0.08864460872220141, 0.08934646498944078, 0.021577598493812338, 0.07234813139906951, 0.07961294800043106, 0.051971093751490116, 0.07452973004962717, 0.033238210914922614, 0.08151283926729645, 0.09006708953529596, 0.03999251812430365, 0.06664560775139503, 0.09165933302470616, 0.0706263216478484, 0.04160559263878635, 0.11335722729563713, 0.04863064889130848, 0.07532478988702808, 0.3537222865436758, 0.13532623701861926, 0.3955690067793642, 0.35194612613746096, 0.27902679038899286, 0.31177644591246334, 0.20473168417811394, 0.2278007891561304, 0.3316702241344111, 0.2447020108146327, 0.19745932226734503, 0.2833000139466354, 0.4226190224289894, 0.35917165556124275, 0.3040281188275133, 0.2532481865159103, 0.21622423534946783, 0.4520846770278045, 0.32242716582758085, 0.3884655593761376, 0.3057708410280091, 0.3129735716751644, 0.46856876249824253, 0.27109471602099283, 0.39582383739096777, 0.19636730157903262, 0.2882980757525989, 0.42619525481547627, 0.3104251841349261, 0.24776622067604745, 0.34433323464223314, 0.3189569477524076, 0.19726873535130704, 0.379116242485387, 0.23510364443063736, 0.3552253773169858, 0.2563934405999524, 0.5733912406223161, 0.3691659878407206, 0.37583859264850616, 0.22954399990183966, 0.2437092869409493, 0.39025200637323515, 0.23553123005798884, 0.23683002750788415, 0.26429864498121397, 0.3072292570556913, 0.29339159386498587, 0.16238245447831495, 0.4105747272925717, 0.42057231654013905, 0.4896942717688424, 1.055804723075458, 1.912891834974289, 21.99648550578526, 61.07579122270857, 87.52752767290387, 87.88752773829869, 80.0510366984776, 82.88213579995292, 60.96855967385428, 38.973818165915354, 31.774949414389475, 47.50430570329939, 50.515265873500276, 58.06715522493635, 108.50128350939069, 87.40938745226178, 96.76426833016532, 81.80840982709611, 110.77367101396833, 109.0609609058925, 85.22709723881313, 52.66826248168945, 31.597700868334087, 31.736664840153285, 39.41428531919207, 35.386904444013325, 43.35944468634469, 76.94485146658761, 66.56676496778215, 63.15030792781285, 59.22304017203194, 71.75269889831543, 83.65008544921875, 69.26039396013532, 82.6926862171718, 77.7133708681379, 74.70974799564907, 74.62331240517753, 95.32572024209159, 71.54498944963727, 86.80999415261405, 89.58320781162807, 88.73218550000871, 72.24527754102434, 72.01950277600969, 65.54668603624616, 83.92509514944894, 78.9631016595023, 104.01975795200893, 104.58444499969482, 117.78434780665806, 89.60158579690116, 62.46891893659319, 41.37904133115496, 35.92945105688912, 31.36107996531895, 50.28181334904262, 80.90677683694022, 80.69339765821184, 81.59332833971295, 85.41268362317766, 93.78347029004777, 71.99392645699638, 29.95065471104213, 4.179867344243186, 0.2519666781382901, 0.29841096167053494, 0.2130739465355873, 0.301531869918108, 0.3461713045835495, 0.36206050483243807, 0.45207707743559566, 0.26657184585928917, 0.32895779396806446, 0.3123685898525374, 0.4058395028114319, 0.2523446764264788, 0.5008649666394506, 0.42366418348891394, 0.22654563507863454, 0.2746777337576662, 0.26365935642804417, 0.23252542849097932, 0.3433318798031126, 0.2618914470076561, 0.25047818943858147, 0.21292442455887794, 0.2830219231545925, 0.2913559888090406, 0.3369226822895663, 0.39244836994579857, 0.3065951796514647, 0.34184062268052784, 0.30199685639568735, 0.34071007477385656, 0.3387957646378449, 0.2918209210038185, 0.4248895634497915, 0.47045351564884186, 0.366538048854896, 0.33776987397244995, 0.4078053816088608, 0.4172468435551439, 0.39753114006349016, 0.2873603674982275, 0.34831555666668074, 0.2875195246722017, 0.30867016687989235, 0.21190027094313077, 0.28043860463159426, 0.2221474117998566, 0.33521214979035513, 0.30367123654910494, 0.4312875787062304, 0.23125010835272924, 0.20474769760455402, 0.4035017325409821, 0.2750626259616443, 0.24373596693788255, 0.25697993912867134, 0.2788926304451057, 0.2315944784453937, 0.14777564470257076, 0.24340348477874482], [0.04809990219239678, 0.07193458466125385, 0.05435950987573181, 0.0035603385518438047, 0.04717052634805441, 0.06575794145464897, 0.14855370723775455, 0.13906196584658964, 0.026969539700075984, 0.09616437807146992, 0.07133490898247276, 0.08346485559429441, 0.055991427307682376, 0.134626748838595, 0.1273027097008058, 0.11868678059961114, 0.06734181860727922, 0.09455635864287615, 0.0435621856844851, 0.11349845757441861, 0.20025575506900037, 0.20913065384541238, 0.12127745444221155, 0.1835148712354047, 0.05696997658482619, 0.3059920163026878, 0.14499335257070406, 0.08850016897278172, 0.05047013697081378, 0.06627065608544008, 0.05828113694276128, 0.20659599985395158, 0.07210041183446135, 0.07339764865381376, 0.054658319734569104, 0.10673840995877981, 0.12457377756280558, 0.06236753945371934, 0.15979644895664283, 0.11575151953314032, 0.0505592387967876, 0.1482550296932459, 0.02630259405954608, 0.09143054458711829, 0.18317090826375143, 0.10467256259705339, 0.03028001875749656, 0.08975412204329457, 0.2596991817866053, 0.38245194777846336, 0.09022926619010312, 2.487904122897557, 15.64110895565578, 42.40632207053048, 68.430264881679, 74.41286536625454, 66.054689679827, 46.72796263013567, 40.561387743268696, 30.705416679382324, 20.894713129316056, 43.35322257450649, 28.069563695362636, 51.86223323004586, 54.383088316236226, 43.62308365958077, 49.92057303019932, 43.70554835455758, 34.497903278895784, 26.77675233568464, 18.09249768938337, 6.9509513803890774, 2.623869947024754, 1.132361495069095, 0.3168391313936029, 0.3020636242415224, 0.21734651869961194, 0.37635558204991476, 0.24748598571334565, 0.7157112466437476, 0.8833859350000108, 0.4854374144758497, 0.49215344552482876, 0.25511852758271353, 0.28202767936246737, 0.06173293957752841, 0.3161604606679508, 0.6333712935447693, 0.3559640576796872, 1.3916286400386264, 2.1107823933873857, 1.8047094685690743, 2.3433750782694136, 0.5610736587217876, 1.9472217985561915, 0.7649240887590817, 1.6409397763865334, 0.6342833531754357, 1.4834795913525989, 3.1147041576249257, 8.4604184286935, 18.423495973859513, 22.374927827290126, 29.254837785448345, 73.52106407710484, 80.37773404802594, 56.53766563960484, 44.49893535886492, 24.488762651171, 21.166955709457397, 32.21682357788086, 47.40872975758144, 57.43603992462158, 66.22353785378593, 66.60605008261544, 67.77493163517543, 52.13435247966221, 20.96356282915388, 0.500942156783172, 0.19140517498765672, 0.10283867243145194, 0.11973035388759204, 0.0955929769469159, 0.06890451189662729, 0.14499044844082423, 0.11757489240595273, 0.1000138632953167, 0.01102405836406563, 0.18647770796503338, 0.09832985472998448, 0.11194234607475144, 0.18395221419632435, 0.11238839463996035, 0.07479054534009524, 0.03630916202174766, 0.19345631849552902, 0.11449065219078745, 0.11435710292841707, 0.09895285165735654, 0.09273001378668205, 0.1846618125481265, 0.08749057671853475, 0.09973993192293815, 0.12689930706151895, 0.0629642295784184, 0.12665462733379432, 0.09578418132982083, 0.07230500371328422, 0.15087811036833695, 0.13947341591119766, 0.11918721374656473, 0.08394464092063052, 0.070272092441363, 0.11265258903482131, 0.1851761828043631, 0.1618255672178098, 0.18665300070175103, 0.1460541199360575, 0.1276885247124093, 0.10714856402150222, 0.1509819533675909, 0.1092004199911441, 0.10009186768106051, 0.12341143350516047, 0.07855488120445184, 0.05933736490883997, 0.10745838989636727, 0.12212699385625975, 0.09088951468999897, 0.07258890276508671, 0.07630591081189257, 0.01475121729475047, 0.027812096988782287, 0.13952969360564435, 0.16015500043119701, 0.06199781929275819, 0.0803419795951673, 0.05456980484138642, 0.08984805843127625, 0.015374221007472702, 0.05714907590299845, 0.04798039860491242, 0.056697147831852944, 0.049601869990250895, 0.1615189779549837, 0.08232883191002266, 0.07514011301100254, 0.032583143029894145, 0.09701895221535649, 0.12257908816848483, 0.15136087446340493, 0.12360134188617979, 0.12708625702985696, 0.05889458688242095, 0.07250138531838145, 0.15040169736104353, 0.1513202302157879, 0.11769782938063145, 0.12078140463147845, 0.16566194993044647, 0.1873965258044856, 0.256164231470653, 0.130396517259734, 0.06355297405804906, 0.040024969061570506, 0.1202485239399331, 0.023786145162635615, 0.08715584860848528, 0.029505918866821697, 0.13964622520974704, 0.0837367038641657, 0.01215443154796958, 0.04413608042523265, 0.07653359323740005, 0.07511484436690807, 0.08699000786457743, 0.13752748604331697, 0.13302669541112014, 0.10037181765905448, 0.12450462127370493, 0.1042727901201163, 0.1624012634690319, 0.047223838844469616, 0.10907352715730667, 0.21446951664984226, 0.4095943798976285, 0.09435190925640718, 3.563413394348962, 18.862722873687744, 52.6669214793614, 81.24600178854806, 84.93344552176339, 75.64900548117501, 66.34669467381069, 60.442650522504536, 56.65875884464809, 33.53779424939837, 41.09191744668143, 33.45386348451887, 46.321270670209614, 49.70005805151803, 47.56194448471069, 54.75811038698469, 46.905833039964946, 39.25636318751744, 31.854249204908097, 20.958537544522965, 9.530933465276446, 3.631954116480691, 1.4677458299057824, 0.1629647325192179, 0.15611972553389414, 0.13617436507982866, 0.10593153682670423, 0.28944767692259377, 0.490829270865236, 0.6079415923782757, 0.5095884299704007, 0.5870124240006719, 0.3072335996798107, 0.4994179500000817, 0.15938281400927476, 0.6044451828513826, 0.2725354629967894, 0.35629624128341675, 1.3183505492550986, 1.2933612444571085, 0.7854454847318786, 1.296484459723745, 0.6978328802755901, 1.474829518369266, 0.8752398778285299, 1.2678753605910709, 0.6947556425418172, 1.7358843045575278, 3.7510249614715576, 7.601642795971461, 16.2095046043396, 22.772409949983867, 32.386745248522075, 54.240653719220845, 61.44788115365164, 50.969535623277935, 30.231671128954204, 27.293554135731288, 42.433882100241526, 55.3677522795541, 62.39801951817104, 66.05314717973981, 74.34769821166992, 79.676730292184, 79.80506352015904, 67.47239317212785, 29.059348481042043, 1.9514172077178955, 0.12422876964722361, 0.08127110438155276, 0.21209560760429927, 0.07262109925172158, 0.09774631461394684, 0.14379174847687992, 0.1134350620476263, 0.24734069779515266, 0.04225613808791552, 0.3020400112228734, 0.09396010956593923, 0.11538874757077013, 0.15157905061330113, 0.05384174694440194, 0.09739703871309757, 0.062458863481879234, 0.0913936865649053, 0.14797533755855902, 0.06158468646130391, 0.04305266695363181, 0.18864847719669342, 0.0835701303024377, 0.09385955746152572, 0.11109882526631866, 0.1446439070361001, 0.06725128167974097, 0.04816939774900675, 0.08794928674719163, 0.10240419288831097, 0.20045042676585062, 0.17342510979090417, 0.062215567965592654, 0.04056418387751494, 0.04003236509327378, 0.10853192729077168, 0.0666014419070312, 0.11725451531154768, 0.15502889906721457, 0.08911394460925035, 0.09862344326185328, 0.17374171423060553, 0.15091062576643058, 0.0935112518657531, 0.1309347040951252, 0.07862870581448078, 0.12403902411460876, 0.06497979749526296, 0.05582698095323784, 0.03104049705767206, 0.05304627659331475, 0.025002085005066225, 0.13674409022288664, 0.037849874169166596, 0.019885634105386477, 0.09486036947263138, 0.1569432770567281, 0.06569055614194699, 0.15417294071188994, 0.20115779952279159, 0.14214039780199528, 0.10825321903186184, 0.1235317513346672, 0.14730518923274108, 0.22040888294577599, 0.24235995220286505, 0.28665887085454805, 0.20302140952220984, 0.16034055261739663, 0.16085834269012722, 0.18595928006938525, 0.2964749384139265, 0.2457376452428954, 0.20176042004355363, 0.22634035109409265, 0.16058829932340554, 0.27789580821990967, 0.2826726133269923, 0.2831044058714594, 0.2589328714779445, 0.25363090740782873, 0.26648246922663277, 0.43613473432404654, 0.4863057221685137, 0.2787129000893661, 0.39175192160265787, 0.2791837491095066, 0.30522996719394413, 0.18224333732255868, 0.27527213043400217, 0.23230832442641258, 0.2835022716649941, 0.29327925560729845, 0.2950715922883579, 0.19783054877604755, 0.2879304183380944, 0.25389607889311655, 0.21718200109899044, 0.1950142484690462, 0.23742423419441494, 0.183438508904406, 0.24631250011069433, 0.35273528950554983, 0.2829972244799137, 0.14814719690808228, 0.18293507663267, 0.49120376791272846, 0.5405618708048547, 0.24829653650522232, 5.202457181044987, 26.55841909136091, 65.87555122375488, 94.79847008841378, 94.26884365081787, 83.3512156350272, 61.2198760168893, 55.82877220426287, 43.04004989351545, 32.12046595982143, 61.47853660583496, 46.07208047594343, 74.51551805223737, 80.0941572189331, 65.33960887363979, 72.70084312983921, 63.61676829201834, 49.61071463993618, 39.07871164594378, 27.585616452353342, 11.572531342506409, 4.268629712717874, 2.623279784406934, 0.4901798314281872, 0.39296468081218855, 0.2907845266163349, 0.5964047057288033, 0.5342742396252496, 0.8164323877011026, 1.6768036633729935, 1.0720639420407159, 1.2565237411430903, 0.5081974331821714, 0.5019187043820108, 0.3187062426337174, 1.1616708423410143, 1.614662992102759, 0.7232682268534387, 2.769351763384683, 2.822333731821605, 2.9214797488280704, 3.7826349224363054, 0.8745949981468064, 2.621459573507309, 1.2368695672069276, 2.066638533558164, 1.2291733516114098, 2.098695784807205, 4.615839447293963, 11.273999384471349, 24.962549890790665, 28.985393592289515, 40.12180995941162, 94.53730814797538, 104.73526954650879, 76.54626110621861, 58.952949796404155, 36.17247472490583, 31.09246608189174, 44.743515423366, 67.25966712406704, 74.74797003609794, 85.7438417162214, 85.81552628108433, 90.98410361153739, 76.65768241882324, 37.9413297516959, 4.129573677267347, 0.20531495288014412, 0.6170185995953423, 0.2971068173646927, 0.3451288305222988, 0.2878638676234654, 0.24611550782408032, 0.26844557960118565, 0.32884062454104424, 0.22472146153450012, 0.4390326216816902, 0.246897533003773, 0.26686440301792963, 0.334717334913356, 0.18851933841194424, 0.24076802762491362, 0.2698573667023863, 0.2511817216873169, 0.21470541613442556, 0.22248230954366072, 0.18958775965230806, 0.3722950385085174, 0.24842393824032374, 0.23698427208832332, 0.27322306324328693, 0.2322337669985635, 0.1551151815801859, 0.2700131040598665, 0.24527450438056672, 0.2271940160010542, 0.3823498146874564, 0.30158911113228115, 0.3016673597906317, 0.19612716803593294, 0.2075439811285053, 0.3222414915050779, 0.2530147704694952, 0.24209317937493324, 0.3872399351426533, 0.40595960350973265, 0.2912732889609677, 0.27266465606434004, 0.3243892176875046, 0.24916462706668036, 0.3024126626551151, 0.2212309009794678, 0.22893206988062176, 0.19808319450489112, 0.24298295591558727, 0.3687048283006464, 0.1322032795952899, 0.18061785240258488, 0.20284444758934633, 0.21900873950549535, 0.12616515931274208, 0.2707204089633056, 0.3009469455906323, 0.23662752551691874], [0.04791858406471355, 0.063123366396342, 0.07705405673810414, 0.04415228723415306, 0.01047171389551035, 0.03770953616393464, 0.019435169973543713, 0.033917088593755446, 0.09527441832636084, 0.04429075587540865, 0.027994398992242556, 0.042990251909941435, 0.03628613254321473, 0.018430736281776, 0.007430959293352706, 0.012154708899158453, 0.0821526027949793, 0.06164884194731712, 0.023035946667992642, 0.031029236769037585, 0.03763289902625339, 0.024265525064298084, 0.06198785161333425, 0.10192622603582484, 0.09348772027130638, 0.06003138409661395, 0.05464553613481777, 0.040295514544206004, 0.046987824008933136, 0.06375715881586075, 0.010103389820350068, 0.034388707751142125, 0.06246138084679842, 0.0722795043672834, 0.08138211949595384, 0.05008641863241792, 0.048981207223342996, 0.03656764654442668, 0.03765367576852441, 0.07042312755116395, 0.032863177824765444, 0.02979138194184218, 0.09625885728746653, 0.03811767837032676, 0.05459186740751777, 0.02989434963092208, 0.060548895969986916, 0.027043084414409738, 0.07583196767206703, 6.658474343163626, 32.64795930044991, 56.89203419004168, 68.03931753976005, 77.08238410949707, 68.76394517081124, 65.63807569231305, 49.07095078059605, 19.73781200817653, 24.049384628023418, 30.7972058568682, 54.364557470594136, 53.804682050432476, 43.75250080653599, 27.638085774012975, 26.301695312772477, 16.39133722441537, 12.945122786930629, 6.749063219342913, 3.30563804933003, 0.3023872583040169, 0.03403221902304462, 0.012280849407293966, 0.037717838039887805, 0.0778236375855548, 0.22008162550628185, 0.10524392300950629, 0.10315535829535552, 0.07292148670447723, 0.02958566030221326, 0.17683633603155613, 0.06857818405010871, 0.06486790028533765, 0.021745088077815514, 0.14547139406204224, 0.021935537590512207, 0.0854552566472973, 0.04079165256449154, 0.04834065320236342, 0.07737834897956677, 0.030884963260697465, 0.03209025179967284, 0.09223105306071894, 0.05613115802407265, 0.03422205276521189, 0.210074156788843, 0.23252436997635023, 0.0711527494713664, 0.09626149000333888, 0.0859161244173135, 0.10314655769616365, 0.055232719983905554, 0.06953358849776642, 0.8678200159754071, 2.0249486906187872, 4.397179637636457, 17.023968969072612, 55.82366180419922, 94.6320607321603, 88.82863344464982, 60.1607551574707, 30.056566102164133, 20.854701927730016, 44.022546018872944, 46.49024738584246, 60.425370352608816, 66.17367758069719, 73.50677163260323, 68.54511165618896, 46.505481311253135, 17.87677870477949, 0.4292195939591953, 0.27550861345870153, 0.043116849581045766, 0.015458442470324891, 0.10813567641058139, 0.024905839901683584, 0.04542754291157637, 0.028085256527577127, 0.0781502097046801, 0.05237368893410478, 0.036119138289775164, 0.07349631443087544, 0.02625674714467355, 0.03057304410529988, 0.04668790813801544, 0.06985009794256516, 0.022975004045292735, 0.011914589774927922, 0.08896216311092887, 0.0460953299355294, 0.024387160948078548, 0.04677003801667264, 0.052303694654256105, 0.0210490298923105, 0.01581556223598974, 0.050198231025465896, 0.005863504384511283, 0.03724065150267311, 0.03292821540630289, 0.08863211010715791, 0.04566170195383685, 0.04245175634111677, 0.06211631864841495, 0.0762892324211342, 0.0032890006675318417, 0.07729856683207409, 0.05394615652039647, 0.0196924925050033, 0.05494363692456058, 0.009695438451931944, 0.017335368719484125, 0.03919821824612362, 0.027611983441082493, 0.02902438970548766, 0.06345848805670228, 0.03296206073303308, 0.02338272047096065, 0.06278001410620553, 0.05171729451311486, 0.04185279990945544, 0.04379088251984545, 0.014869765844196081, 0.08759085062359061, 0.06942542323044368, 0.042062894707279544, 0.024938285749937807, 0.040313024140362225, 0.022935029851006608, 0.0832791066329394, 0.02892823450799499, 0.03099144236849887, 0.02705392910034529, 0.02445384906604886, 0.054168936530394216, 0.06242492316024644, 0.056890323358987055, 0.03667333855160645, 0.027239747611539702, 0.021040463387700062, 0.0731911500915885, 0.008418297295325568, 0.017662733028243695, 0.07343478487538439, 0.015559274470433593, 0.020566638991502777, 0.050035379228315184, 0.10653018791760717, 0.03154464518385274, 0.02269673683414502, 0.01838972562524889, 0.03429264076320188, 0.005325627554806748, 0.07658565722938095, 0.023873423425746814, 0.03382430910798056, 0.02103520474130554, 0.07234957667865924, 0.008571961728323783, 0.08195324242115021, 0.0695421312536512, 0.03957048969875489, 0.008434778062759765, 0.0237143120528864, 0.0732073127957327, 0.045815210323780775, 0.06850151637835161, 0.08487567917576858, 0.058916150725313594, 0.0535937627511365, 0.0550405181545232, 0.020338856482080052, 0.029244574319039072, 0.09406897372433118, 0.0351196799560317, 0.04378910815077169, 8.518720763070242, 38.87803030014038, 66.95503030504499, 82.50594643184117, 85.5795098713466, 81.90461458478654, 86.04304504394531, 72.62585122244698, 31.468012741633824, 27.48082545825413, 37.33304623195103, 41.618337290627615, 46.46430628640311, 38.876251561301096, 38.8230631010873, 34.37512166159493, 24.715023790087017, 17.36447933741978, 11.681805661746434, 4.863263062068394, 0.8777668508035796, 0.12019839377275535, 0.044713852993611775, 0.05977698774742229, 0.07882267862026181, 0.019245175079309514, 0.12339892131941659, 0.15161247524831975, 0.05985883942672184, 0.06305395226393427, 0.10435109984661851, 0.03870460098343236, 0.10879635238753897, 0.12632328511348792, 0.42859121624912533, 0.45339419533099445, 0.3895521382136004, 0.21973521980856145, 0.106032462125378, 0.1033188309520483, 0.07911845203489065, 0.029255210355456387, 0.11164377031049558, 0.07490242897932019, 0.13001655121999128, 0.3295762650668621, 0.23044390018497193, 0.059877404144832065, 0.1602765531944377, 0.1197578888386488, 0.09198257353688989, 0.06917522022766726, 0.08940150096480336, 0.40828760287591387, 1.467361073408808, 5.890986314841679, 20.62976094654628, 49.29201119286673, 68.68758446829659, 65.63583837236676, 40.67803757531302, 36.03393111910139, 37.121612548828125, 63.67174243927002, 68.57585743495396, 67.99874700818742, 77.54460607256208, 83.62294578552246, 85.17735508510044, 61.63630935123989, 28.90781695502145, 1.8197501472064426, 0.13707319327763148, 0.1363356935658625, 0.011758681935524302, 0.04504527663812041, 0.030501753823565583, 0.0376103547002588, 0.04286789847537875, 0.0776141873959984, 0.027797674726960913, 0.024212170159444213, 0.06657311307000262, 0.023208245368940488, 0.07343177896525178, 0.02778121007473341, 0.04208257561549544, 0.060588013513811996, 0.09867525619587728, 0.059285850530224185, 0.005486876312975905, 0.019471895681428056, 0.021363172946231704, 0.03275298713041203, 0.04413362412846514, 0.012885251082479954, 0.08253174102199928, 0.027841423272288272, 0.02247269814168768, 0.06765144092163869, 0.0293460695871285, 0.047380268307668824, 0.016015679176364626, 0.050398643128573895, 0.025852879708898917, 0.0452666792220303, 0.018598482012748718, 0.03581588741924081, 0.015685529481353502, 0.013260423272315944, 0.028420161056731428, 0.03407623219702925, 0.04335296619683504, 0.08403674526406185, 0.04038649930485657, 0.029518454801291227, 0.03534736916688936, 0.09833970705845527, 0.026895022984328013, 0.044953274074941874, 0.029610864485480955, 0.03498025797307491, 0.06538736633956432, 0.02530985831149987, 0.02876009013769882, 0.007660078516762171, 0.03546173285160746, 0.1710667527679886, 0.15617221700293676, 0.181239322626165, 0.13856170911874088, 0.08350423776677676, 0.0723101334380252, 0.09731880362544741, 0.26461788213678766, 0.14887872551168713, 0.09703247541827814, 0.08709359980587449, 0.17865985818207264, 0.12459173159939901, 0.1847610143678529, 0.11960961536637374, 0.12861909477838449, 0.13893581261592253, 0.17195689571755274, 0.11598516628146172, 0.1597293961261, 0.19164053164422512, 0.17807422817817756, 0.09910707588174514, 0.18154527406607354, 0.17355746483164175, 0.1453075007136379, 0.14047316940767424, 0.15914357613239968, 0.11403893785817282, 0.21201839031917707, 0.18077209698302404, 0.10563197040132113, 0.20872294929410729, 0.15651436150074005, 0.16513878586036818, 0.16862922427909716, 0.11927986091801099, 0.14029418544045516, 0.168525883395757, 0.20994816640658037, 0.14348644843058928, 0.17555465123483113, 0.24703131296804973, 0.08215683685349566, 0.26157839809145245, 0.14566431513854436, 0.2619427442550659, 0.19557205853717669, 0.32783272862434387, 12.608988046646118, 49.69194950376238, 82.34609617505754, 91.41936656406948, 97.35899938855852, 84.68929277147565, 82.240143094744, 65.54956259046281, 29.47335515703474, 34.81337928771973, 41.53669943128313, 75.87054879324776, 78.46444334302629, 65.2017149244036, 45.790588106427876, 41.85331494467599, 27.814846209117345, 20.81456392151969, 12.568771004676819, 5.927748799324036, 0.9887023866176605, 0.26830341294407845, 0.10821948227073465, 0.1957798802426883, 0.2363661266863346, 0.3623526548700673, 0.3084828369319439, 0.3004120428647314, 0.3110794004585062, 0.18411997519433498, 0.4322300909885338, 0.17243260304842675, 0.21883810151900562, 0.30663423612713814, 0.570312862949712, 0.3702613062092236, 0.3821830579212734, 0.2995508462190628, 0.22477605646210058, 0.351655224604266, 0.12999144542430127, 0.15178375105772698, 0.25153542842183796, 0.1754699700645038, 0.46173032373189926, 0.5684474344764436, 0.44554636787090984, 0.18615666590631008, 0.28807806755815235, 0.17554353683122567, 0.20347628582801136, 0.2274130199636732, 0.258533485765968, 2.0842103106634955, 3.1008655173437933, 7.175154983997345, 23.923415524618967, 71.91759354727608, 125.81572886875698, 117.05635724748883, 77.93643583570207, 43.40087332044329, 33.72089317866734, 59.16255610329764, 63.42224652426583, 81.24185371398926, 85.60919952392578, 93.80215399605888, 95.28003583635602, 75.60461344037736, 37.75657715116228, 3.42582169175148, 0.2818174420722893, 0.28242717364004677, 0.08328908109771353, 0.1734168180929763, 0.208480318742139, 0.2202618715486356, 0.10324670946491615, 0.27639605583889143, 0.1686837106410946, 0.11615718847938947, 0.1301479155996016, 0.11449152071561132, 0.1516748597579343, 0.16550598187105997, 0.19040999481720583, 0.13815589089478764, 0.19573648114289555, 0.21824787104768412, 0.09933450724929571, 0.2762193110372339, 0.15250659441309317, 0.12485854513943195, 0.15949709287711553, 0.10046352166682482, 0.1834032250834363, 0.11423336528241634, 0.18305394239723682, 0.15264968387782574, 0.24867353056158337, 0.19813134334981441, 0.08876631754849638, 0.11412348332149641, 0.13949269987642765, 0.08051857511912074, 0.10855587957692997, 0.13292635365256242, 0.11721378963972841, 0.1099541231191584, 0.07152092935783522, 0.14762813118951662, 0.12355041104768004, 0.10518417121576411, 0.13732902812106268, 0.14324125301625046, 0.12602130988878862, 0.11697784944304399, 0.13104256402168954, 0.13478845730423927, 0.12202844343015126, 0.14583612020526612, 0.13067382095115526, 0.2067302819341421, 0.10854042254920516, 0.22872910648584366, 0.09988631228251116], [0.03120987636170217, 0.06328464738492455, 0.015734657113041197, 0.09843253064900637, 0.050659950356930494, 0.0389725646403219, 0.06705853023699351, 0.04125060008040496, 0.0692238983299051, 0.06309454222874981, 0.03880284946145756, 0.0035756840453749256, 0.02147697514322187, 0.026711218025801436, 0.028540007304400206, 0.07228440339011805, 0.08734885789453983, 0.010788835718163421, 0.007428412242526454, 0.04482458312330501, 0.026347830292901823, 0.04595097839566214, 0.018839407745482664, 0.0574842043487089, 0.05202082697568195, 0.02688890090212226, 0.034299158092056, 0.05982275493443012, 0.0589281947218946, 0.04141236961420093, 0.00401507194120703, 0.01855753581704838, 0.04320388526788779, 0.0316794599140329, 0.07600122144711868, 0.033610604503857236, 0.030639357332672392, 0.06373482144304685, 0.03924599728946175, 0.009169216733425856, 0.009846497310458549, 0.0896951641355242, 0.029028661083430052, 0.06778117681720428, 0.10194368474185467, 0.0749160743185452, 0.1738825916711773, 0.46885836124420166, 30.6173552104405, 66.47832829611642, 63.45884268624442, 69.91122477395194, 75.84458337511334, 56.773796694619314, 39.32065486907959, 18.614112854003906, 22.511362654822214, 43.1347781590053, 45.46385254178728, 91.13418470110211, 59.926739828927175, 33.91859027317592, 21.868305138179235, 9.414216756820679, 2.5979310188974654, 0.3542759711188929, 0.2717552291495459, 0.007541723349796874, 0.06533978067870651, 0.017530425484957438, 0.06923591518508536, 0.008422787500811475, 0.05135663618732776, 0.09113696962594986, 0.02414692901740117, 0.12093925901821681, 0.05648084783128329, 0.014195728664552527, 0.09101417514362506, 0.052800266936953576, 0.03102430042677692, 0.07335429705147233, 0.057877503601568084, 0.07373923675290175, 0.029649568122944663, 0.24228403770497867, 0.017632490722462535, 0.07011070288717747, 0.24318901343005045, 0.03461996266352279, 0.14173175687236444, 0.1567033063620329, 0.2643093658345086, 0.12057423431958471, 0.03086273106081145, 0.03963778680190444, 0.075414695776999, 0.10866592438625437, 0.10844865068793297, 0.11781389958092145, 0.05216998593615634, 0.18745278992823192, 0.041238359308668544, 0.10329322304044451, 0.1791553787354912, 1.3477570627416884, 2.7378766408988406, 8.45452288218907, 28.546706914901733, 74.63941138131278, 78.30790737697056, 55.53234468187605, 27.890489510127477, 20.034237793513707, 45.035207748413086, 57.933874879564556, 62.35046604701451, 67.16738809858049, 69.69583756583077, 71.33508437020438, 46.035897731781006, 19.244034801210674, 0.2888000016765935, 0.39556330708520754, 0.09048663452267647, 0.05725097150674888, 0.04427893579538379, 0.05350364651530981, 0.017799271237371222, 0.017131100841132656, 0.05982639866748026, 0.12384570948779583, 0.04907973390072584, 0.030172742371048247, 0.09418845695576497, 0.09064163906233651, 0.0417138054035604, 0.06418612186930009, 0.07035854458808899, 0.031134928776217357, 0.035818357286708694, 0.056458032091281245, 0.0667718763330153, 0.019904838342751776, 0.07666279987565108, 0.012523443488005017, 0.046991688265864334, 0.0452423299928861, 0.15899950957724027, 0.00829823561278837, 0.010206287959590554, 0.03690392171431865, 0.05737102470759835, 0.04818224920225995, 0.03909154236316681, 0.009066092133122896, 0.04096090294686811, 0.016268391062372496, 0.004759961323413465, 0.05192142498812505, 0.08856240420469216, 0.08420522550919227, 0.024282836188961352, 0.0440680810383388, 0.06630545814654656, 0.05409040628001094, 0.042680151228393824, 0.020821907258193408, 0.034935528944645605, 0.013825296041821795, 0.07293930503406695, 0.02874179683359606, 0.04052963287436536, 0.029382686729409864, 0.017596558900550008, 0.03661281322794301, 0.027983250661886165, 0.021364694561011026, 0.03759142018056341, 0.100182994934065, 0.0862370307690331, 0.01937090422558997, 0.07517194987407752, 0.07148888893425465, 0.030547612612800937, 0.01862486175793622, 0.013470328928503607, 0.04403418482148221, 0.03870550682768226, 0.0702551697779979, 0.038731206341513565, 0.022669325715729167, 0.1146842110902071, 0.03142232567604099, 0.02959126839414239, 0.008694573854362326, 0.021045574452728033, 0.04785650150318231, 0.005167717613013727, 0.05604616133496165, 0.07910452849630799, 0.007805710791477135, 0.023329160309263637, 0.06652666734797613, 0.06280262289302689, 0.032317981722631624, 0.015867807736088122, 0.008408088735970003, 0.06418279704770871, 0.02610200723367078, 0.03724326386249491, 0.043353064584412744, 0.028573381049292426, 0.0816901811797704, 0.07078334822186402, 0.041110964358917305, 0.020790399484602467, 0.05100235269804086, 0.01555066046837185, 0.09194771040763174, 0.11249681775059019, 0.08429279045334884, 0.1968334008540426, 0.8193962286625589, 40.15978186471121, 80.79818344116211, 79.05501243046352, 81.67406640733991, 82.66767965044293, 69.30226380484444, 65.72160693577358, 38.68461329596383, 38.65017454964774, 38.492141246795654, 34.26694515773228, 52.6122738974435, 54.528187547411235, 39.87949848175049, 28.12168734414237, 14.301154937062945, 3.7833827223096574, 0.6582086607813835, 0.444818734058312, 0.05381446983665228, 0.026186574749382477, 0.011275969578751495, 0.02510570239142648, 0.12112377983118806, 0.12885540138397897, 0.08892888096826417, 0.03654770100755351, 0.07188767075006451, 0.033395108567284684, 0.03932479216850229, 0.3398660586348602, 0.20952528981225832, 0.1804549497153078, 0.25745914770024164, 0.056096447565193684, 0.37940421274730135, 0.7661953376872199, 1.6842826391969408, 0.3498279297990458, 1.2768453764063972, 0.799703948199749, 0.343888414225408, 0.5410339683294296, 0.5164855484451566, 0.4421821098242487, 0.24916286287563189, 0.13291826551514013, 0.176722043593015, 0.13106054519968374, 0.21845596416720323, 0.18100659868546895, 0.02498665511874216, 0.07505860738456249, 0.12384706655783312, 0.04614753641986421, 0.04212888902319329, 0.19147840248686926, 0.43561389084373203, 2.911831306559699, 9.639239379337855, 27.811531918389456, 57.05362844467163, 52.65649570737566, 43.444518429892405, 38.81787974493844, 32.07717868259975, 59.689069747924805, 72.95799595969063, 75.0990069253104, 74.79482868739537, 78.83296884809221, 85.31663867405483, 62.8875617980957, 28.542068992342266, 2.271730031285967, 0.23331923303859575, 0.031113368325999806, 0.043018370401114225, 0.05302263304058995, 0.03684504183807543, 0.06716187790568386, 0.011385607267064708, 0.07457331913922514, 0.15667400721992764, 0.050734205836696286, 0.08261353841849736, 0.019405061678428735, 0.15641532252941812, 0.07131779632930245, 0.03239898184048278, 0.049027283143784316, 0.05909837808992181, 0.1260760405233928, 0.033864559805286784, 0.07426124731344835, 0.04705102615324514, 0.031859777202563624, 0.023397870461589525, 0.0741222154881273, 0.040246989112347364, 0.04312857127349291, 0.026492212366844927, 0.06792396094117846, 0.029433064561869417, 0.06101395708641835, 0.012209546403028071, 0.03823324306202786, 0.011254929904160755, 0.02848857774266175, 0.067819262987801, 0.01930820589352931, 0.06856491869049412, 0.055718201611723216, 0.029461393398897986, 0.01418975246737578, 0.019747503035302674, 0.08780353742518596, 0.05656396497839263, 0.08259505512458937, 0.042318051015692096, 0.024007844605616162, 0.027102271327748895, 0.03929818681042109, 0.06300331998084273, 0.05681507043274386, 0.021265246772340367, 0.010890165593342056, 0.059820793968226225, 0.11215024920446531, 0.1972001897437232, 0.20593533744769438, 0.2531813643872738, 0.28525647467800547, 0.14092793714787277, 0.18472001728202614, 0.12097200511821679, 0.1773157345929316, 0.09069594900522913, 0.11679978828345026, 0.1285878007433244, 0.1260734756610223, 0.15164725695337566, 0.16574771675680364, 0.1164802797138691, 0.23133275391800062, 0.10223884068961654, 0.09825491053717476, 0.15414394012519292, 0.12499493067818028, 0.09434019095663514, 0.1571429292006152, 0.17638815008103848, 0.20862651589725698, 0.1772024735276188, 0.16303143251155103, 0.2307685384792941, 0.2758348802370684, 0.12061071236218725, 0.10335393835391317, 0.189303439908794, 0.18852978785123142, 0.10868824140301772, 0.1780475481812443, 0.11004138950790678, 0.12752681624676498, 0.18470427526959352, 0.14730282793087618, 0.1782922414796693, 0.08460545260459185, 0.20974973562572682, 0.13955641431467875, 0.28856612422636574, 0.2493867522903851, 0.1839249778006758, 0.25091587166701046, 2.309190158333097, 50.231289522988455, 94.19977160862514, 86.5561625616891, 89.86617319924491, 93.26976217542375, 73.47611618041992, 52.99223613739014, 26.4411004952022, 35.393359320504324, 61.426591873168945, 67.31924792698452, 127.9310245513916, 82.41980961390904, 52.30848823274885, 35.25139372689383, 16.235723631722585, 4.339544330324445, 0.8821405789681843, 0.7337030640670231, 0.16807278485170432, 0.10367833237562861, 0.0770867553406528, 0.24810646527579852, 0.18019960341709002, 0.3617741087717669, 0.4263908357492515, 0.06581413772489343, 0.18592719893370355, 0.2742401329534394, 0.12603965747569287, 0.3101733390774046, 0.1825141135071005, 0.11889978631266526, 0.14809448830783367, 0.18521838768252305, 0.2079445067793131, 0.28269231798393385, 0.48472495270626886, 0.15825252394591058, 0.5007177516818047, 0.4671211487480572, 0.32087874891502516, 0.30704187282494133, 0.36945656367710655, 0.4479377695492336, 0.2631783293826239, 0.2091450523585081, 0.25715386122465134, 0.26952358175601276, 0.30161386408976143, 0.350138888827392, 0.30720168139253345, 0.22137766810400145, 0.5603134823696954, 0.10438578655677182, 0.2048480665045125, 0.43503778747149874, 2.145015516451427, 4.678090964044843, 12.383430412837438, 38.59359884262085, 97.54382147107805, 100.49188654763358, 73.25535801478794, 39.298622131347656, 28.140897376196726, 60.50614316122872, 75.38920538766044, 81.75986276354108, 84.85978766850063, 88.32890510559082, 94.41465854644775, 72.62109865461076, 32.840928145817344, 3.6304669848510196, 0.521335988172463, 0.3669120030743735, 0.10482200314956051, 0.10219818287129913, 0.2503971994987556, 0.19523887070161955, 0.16790282540023327, 0.17688432202807494, 0.2844397627881595, 0.161847660318017, 0.18090363778173923, 0.15560042911342212, 0.386931337416172, 0.1784688505743231, 0.13306580616959504, 0.09523975197225809, 0.29606135774935993, 0.23702232433216913, 0.15756736642548017, 0.12647173500486783, 0.11192139969872576, 0.26716806100947516, 0.13362314126321248, 0.1571558213659695, 0.2025100655321564, 0.26335542702249115, 0.0857310811323779, 0.19386567867227963, 0.11764309874602727, 0.17771859440420354, 0.09369410348257848, 0.12987589091062546, 0.04355563103620495, 0.10882890849773373, 0.09613482108605759, 0.09207264227526528, 0.23775497930390493, 0.24872246650712831, 0.11932169938726084, 0.07087008535329785, 0.15729394395436558, 0.12588915840855666, 0.16605103548083985, 0.2091117227183921, 0.1584936481501375, 0.09452910867652722, 0.169567203947476, 0.15744555581893238, 0.19579734573406832, 0.19403421320021152, 0.1566698138735124, 0.11155308410525322, 0.15107313490339688], [0.02858200522937945, 0.0627332833994712, 0.01465948105656675, 0.019092662459505454, 0.060318153351545334, 0.04519352296899472, 0.057783709705940316, 0.01569062188666846, 0.0665521938353777, 0.07274525080408369, 0.07567720061966351, 0.04938344617507287, 0.05012593311922891, 0.036053815723529885, 0.050897457969508, 0.09529290162026882, 0.09017496303256069, 0.04404639505914279, 0.037435930488365035, 0.022328087062175785, 0.06324226608765976, 0.0306184686321233, 0.05752119129257543, 0.028147876828110645, 0.04200717680422323, 0.02444372701990817, 0.07161064525800091, 0.035734005205865414, 0.07138269141848598, 0.02473658782296947, 0.030637291193540608, 0.04425922774576715, 0.13877920673361846, 0.012109476906646575, 0.02246047942233937, 0.07011524907180242, 0.043098254328859706, 0.08363746811768838, 0.025236830980117832, 0.0561987536826304, 0.08305996017796652, 0.06117873253034694, 0.04188913206702896, 0.07714856988085167, 0.16317726325775894, 0.09900268326912608, 7.981364454541888, 39.57377079554966, 67.72944177900041, 65.44018404824394, 82.90921987806047, 65.22805554526192, 46.10622392381941, 34.56948709487915, 14.628384692328316, 23.560516323362076, 46.64260401044573, 45.97650800432478, 36.92767095565796, 40.62286540440151, 12.794564877237592, 3.011787874358041, 0.02505099041653531, 0.05493842238294227, 0.09007236175239086, 0.06987432164273091, 0.0033430729111257407, 0.06156443219099726, 0.0580614408744233, 0.018059582715587955, 0.05393310150663767, 0.13255622637059006, 0.15367036339427742, 0.040704613484974415, 0.09855398163199425, 0.17792598184730324, 0.1302822112504925, 0.05080799991264939, 0.10798918070005518, 0.20082206039556436, 0.18533016954149517, 0.08598052417593342, 0.06669152421610695, 0.6057298396314893, 2.051492763417108, 2.922642920698438, 1.467066534927913, 0.2834978476166725, 0.183239006038223, 0.29603815185172216, 0.10449578386864491, 0.24578848108649254, 0.14233971067837306, 0.08810015900858811, 0.07988395488687924, 0.043845932065908394, 0.17077419560934815, 0.10160788454647575, 0.054768496858222146, 0.06657823600939342, 0.07071515545248985, 0.09333052406353609, 0.10248067735561303, 0.11613596390400614, 0.029406713654420207, 0.05218922579661012, 0.04908596285219703, 0.06951103399374656, 0.4073992376880986, 4.664175025054386, 33.54617725099836, 67.69667407444545, 74.62649468013218, 49.59007849012102, 23.776900597981044, 27.868946620396205, 38.7920046533857, 66.40919372013637, 66.43354020799909, 62.72036034720284, 72.81120831625802, 69.0582708631243, 54.66853421075003, 15.573430027280535, 1.0142721916948045, 0.10007650564823832, 0.25300195972834316, 0.023519974534532855, 0.14060715293245657, 0.010498619505337306, 0.06656310467847756, 0.060363615197794776, 0.05408895082239594, 0.037180702933775525, 0.07982408774218389, 0.07743633658226047, 0.033399128887270174, 0.042502246131854396, 0.060153099708259106, 0.05142833359007325, 0.017444682407325933, 0.017907087059159364, 0.034241126384586096, 0.004848479609271246, 0.02501184064229684, 0.1074845881334373, 0.017978860797094445, 0.051406494940498045, 0.033359997772744725, 0.05881587003490754, 0.12277401770864214, 0.03551475697063974, 0.02793838083744049, 0.0352444829020117, 0.03899353815774832, 0.007855851984848934, 0.05474871416975345, 0.07044497637876443, 0.06227381341159344, 0.032124829944223166, 0.026450090609224777, 0.04454735746341092, 0.05071315768041781, 0.045169777636017115, 0.07967009421970163, 0.06512152310460806, 0.020542031919051493, 0.007826136391876, 0.05797846282699278, 0.039679252076894045, 0.005001339554187975, 0.03613750962540507, 0.03153747985405581, 0.03670215932652354, 0.07401069825781242, 0.009977699689833181, 0.101939803521548, 0.050646820704319646, 0.05939360189118555, 0.028799838719091246, 0.05452298592509968, 0.07244750963790075, 0.08661124961716787, 0.014061015714625162, 0.03813543902443988, 0.05228136745946748, 0.03616457977997405, 0.0570199778303504, 0.03302436721112047, 0.10812688938208989, 0.0879738022174154, 0.029054231675607816, 0.10314817939485822, 0.057114083852086744, 0.05451591219753027, 0.019124287280387113, 0.07046163441347224, 0.0439750029971557, 0.0240009727422148, 0.017142600313361202, 0.018418868704299842, 0.023863983307299868, 0.02108938915521971, 0.03106819824980838, 0.050650576395647864, 0.02416762094279485, 0.04807611953999315, 0.1044048262493951, 0.026537129688741903, 0.002197428448458335, 0.01659645256586373, 0.038115992210805416, 0.08843450035367693, 0.09124929431293692, 0.06448842957615852, 0.0716750585873212, 0.055301713424601724, 0.09117855025189263, 0.10002773933644805, 0.12209010869264603, 0.18206818029284477, 0.09536300107304539, 12.243067247526985, 52.13265364510672, 79.23923001970563, 77.90195192609514, 88.8109016418457, 73.85341031210763, 72.83299091884068, 53.1389855657305, 21.1603809765407, 19.856061662946427, 38.510783263615195, 37.14758491516113, 41.989343302590505, 45.177597182137625, 18.628308023725236, 5.647112795284816, 0.48352188297680443, 0.045330760069191456, 0.07876846367227179, 0.05742129058177982, 0.07511164846697024, 0.10285190386431557, 0.06374520981418234, 0.09026921154665095, 0.07236388019685235, 0.371369408177478, 0.575846288885389, 0.26462645881942337, 0.35387786105275154, 0.5300656940255846, 0.8114655656473977, 0.8251561767288617, 0.670496441423893, 1.0300923713615961, 1.3514151807342256, 1.4781126507690974, 1.275095733148711, 1.506043432014329, 3.866462332861764, 5.995209727968488, 3.7397632343428473, 1.7069346351282937, 1.2415663323232105, 1.1940117755106516, 1.1512868681124278, 1.4607705984796797, 0.7810187222702163, 0.7352837792464665, 0.5605377246226583, 0.6496951090438026, 0.5161675055112157, 0.6638401757393564, 0.34241086351019995, 0.1772675450359072, 0.13018937408924103, 0.17524127662181854, 0.2096251973084041, 0.12090514227747917, 0.0291974195279181, 0.040063821976738315, 0.08451785373368434, 0.19858205345060143, 0.6374040171504021, 5.561154893466404, 28.112751960754395, 56.37626593453543, 55.9192134312221, 46.498835359300884, 39.26746988296509, 48.4008595602853, 58.20400694438389, 82.28346511295864, 78.35344587053571, 71.38106754847935, 79.64487974984306, 83.2575330734253, 70.93559769221714, 27.439113685062953, 3.9979161705289568, 0.04216622541259442, 0.31493179659758297, 0.007922549432675754, 0.16906381238784107, 0.07469755890113966, 0.032104528176465204, 0.0445322566665709, 0.034755133624587736, 0.09569390224558966, 0.0684916844059314, 0.15234373243791716, 0.040555647906980345, 0.056268147458987575, 0.04603063501417637, 0.05216347539265241, 0.03271629534927862, 0.018033036729320884, 0.0215730998066387, 0.02660368549238358, 0.03570688416117004, 0.061137715088469644, 0.010546479972877672, 0.08383839590741055, 0.08016302955469914, 0.04906803934967943, 0.09558926536036388, 0.01987921346777252, 0.023985893997762884, 0.03997604329405086, 0.10766382994396345, 0.06315876556826489, 0.0203429226031793, 0.017351404198312333, 0.059422772111637254, 0.014930579545242446, 0.022598900566143647, 0.03955699363723397, 0.03914609997134123, 0.046272777020931244, 0.00923314830288291, 0.05199998577258416, 0.054508665443531105, 0.008628339506685734, 0.06757127200918538, 0.09067247847893409, 0.028789324818977287, 0.02636243406284068, 0.017297781272126094, 0.046942436801535745, 0.0438772566350443, 0.06510198129607098, 0.1584838501044682, 0.1729270379458155, 0.12714444819305623, 0.21167060041001864, 0.12784608054373944, 0.15712819142001017, 0.1870354637503624, 0.11194428668490478, 0.10929128261549131, 0.15359881866191114, 0.08794483555746929, 0.19636762727584156, 0.1663501337170601, 0.24103675463369914, 0.15624350389199598, 0.27270316971199854, 0.28521109425595825, 0.19183852816266672, 0.18073157487171038, 0.09410923120698758, 0.24455908419830458, 0.20266364514827728, 0.13671971724501678, 0.10900802817195654, 0.15109904137040886, 0.10424793538238321, 0.18563279615981237, 0.15389421209692955, 0.12877665060971463, 0.11815307209534304, 0.11773130829845156, 0.26225207479936735, 0.2661752828529903, 0.08667389875543968, 0.10274204904479639, 0.22827190959027835, 0.13794171810150146, 0.16964679610516342, 0.1671687319342579, 0.20301174718354428, 0.20524008332618646, 0.3395072764583996, 0.1947472992220095, 0.33233117152537617, 0.36378197531614986, 0.2540581130555698, 15.306558404650007, 65.82738631112235, 92.28741891043526, 82.3146208354405, 99.63128961835588, 80.7071898324149, 60.8162899017334, 46.85728597640991, 21.794487476348877, 38.123056411743164, 66.2432290485927, 65.46714305877686, 54.59943437576294, 59.85556248256138, 21.293366023472377, 5.955634525844029, 0.5064399732010705, 0.20669026193874224, 0.13595924233751638, 0.18055453151464462, 0.10630922298878431, 0.2934893029076712, 0.2516204352889742, 0.12843810234751019, 0.2050699745970113, 0.35121827519365717, 0.3473321965762547, 0.19096217304468155, 0.2565831318497658, 0.3709908127784729, 0.7121988779732159, 0.49591437514339176, 0.5509318943534578, 0.6366077427353177, 0.4925480272088732, 0.7133611270359584, 0.5609389830912862, 1.7776682738746916, 3.395230293273926, 7.565819621086121, 4.134134301117488, 0.8219072424939701, 0.6051823432956422, 0.6423168820994241, 0.6010899086083684, 0.6255388281175068, 0.41957633569836617, 0.48138129498277393, 0.3492696040443012, 0.39393067040613716, 0.4986034908464977, 0.614204959145614, 0.3352503105998039, 0.2861317848520619, 0.22997796375836643, 0.3750648998788425, 0.3693440897124154, 0.33887425756880213, 0.17102285155228206, 0.10979908465274743, 0.23885065051061766, 0.35852365461843355, 0.9481168729918343, 7.241061687469482, 46.97221612930298, 90.7293826511928, 96.1935988834926, 63.4751501083374, 37.361950738089426, 40.668702670506065, 50.42456408909389, 83.44382122584751, 86.66809109279087, 81.5582468850272, 90.3597662789481, 93.54176330566406, 81.28151403154645, 35.06542519160679, 5.739688856261117, 0.21678756869265012, 0.42591542697378565, 0.14992662785308702, 0.4193368942609855, 0.21664758691830294, 0.18721020008836473, 0.1916416444416557, 0.09488781621413571, 0.18937931369457925, 0.31993819081357544, 0.26777738545622143, 0.19031322215284618, 0.12424916640988418, 0.19318630227020808, 0.2899233028292656, 0.13224131826843533, 0.10620713739522866, 0.16252288408577442, 0.1713520088898284, 0.1700382022453206, 0.1393667230648654, 0.10829017204897744, 0.1957837478922946, 0.16582808244441236, 0.27768901788762634, 0.23831268080643245, 0.13596624481890882, 0.10893942149622099, 0.1395225961293493, 0.15064953906195505, 0.08876914703952414, 0.13205040565558843, 0.11847373417445592, 0.17557005397975445, 0.10669778606721333, 0.2250413772250925, 0.1914055413965668, 0.14328128658235073, 0.1119539150968194, 0.166329791237201, 0.14843937408711227, 0.17162510566413403, 0.1516387074121407, 0.17525278457573482, 0.2427380047738552, 0.1405070147344044, 0.18425344303250313, 0.16541003701942308, 0.12887478034411157, 0.1836039357419525, 0.15457257069647312], [0.06267481403691427, 0.08405534390892301, 0.020265708710732203, 0.07311691836054836, 0.0365985097097499, 0.0431021694759173, 0.04124331600697977, 0.022165264102763364, 0.015412358068195837, 0.038837631166513474, 0.01348249675772552, 0.0944282648020557, 0.024762479022943547, 0.051385558742497645, 0.01764796132088772, 0.0038239315950444764, 0.05741755185382707, 0.019857345980459025, 0.036619978557739935, 0.015003126813098788, 0.06740916999323027, 0.04313880358157413, 0.06718131114861794, 0.06484658071505171, 0.04618736303278378, 0.05835486655788762, 0.10565235359328133, 0.04355437235374536, 0.02518701972439885, 0.00643940970933597, 0.05790572387299367, 0.11302762891032866, 0.024901035873751556, 0.04113940176154886, 0.046212743635156324, 0.09711278003773519, 0.012673406512476504, 0.03570786464427199, 0.09185117523052863, 0.05325634085706302, 0.02734368560569627, 0.03192350860419018, 0.4052745545549052, 0.5737704059907368, 5.3838963593755444, 31.003536088126047, 66.09586470467704, 63.2496463230678, 53.05512080873762, 46.94372851508004, 46.92799779347011, 38.92913082667759, 21.51579349381583, 27.26973397391183, 48.413762365068706, 75.22103813716343, 62.55649403163365, 40.698176928928916, 14.69821582521711, 2.091346327747617, 0.05900138150900602, 0.051192892116627524, 0.05675712354215128, 0.28068651418600765, 0.04343638189935258, 0.0919957710430026, 0.04857133135997823, 0.06659831386059523, 0.04759945547474282, 0.07461475048746381, 0.25213302778346197, 0.13244189321994781, 0.32700613726462635, 0.30505067110061646, 0.42124067353350775, 0.9530404316527503, 0.44774031585880686, 0.5442697118435587, 1.5158148791108812, 2.129318884440831, 1.8373712130955286, 1.9388136097363062, 1.323578091604369, 2.356575135673795, 3.912739072527204, 7.806737116404942, 4.547313707215445, 5.533906664167132, 2.7426361569336484, 0.5997994978513036, 1.888435912983758, 1.5080447303397315, 0.40779563784599304, 1.724754918898855, 0.7547975235751697, 0.5668238901666233, 0.28012463290776524, 0.30577621502535685, 0.3198128789663315, 0.11070206548486437, 0.14623010477849416, 0.04259106297312038, 0.08237718431545155, 0.041720173454710414, 0.048069921122597795, 0.1282237802765199, 0.17415057229144232, 0.04685845112960253, 0.023083286359906197, 0.14318695664405823, 0.25518904094185146, 7.764717885426112, 52.92268466949463, 81.89879199436733, 38.24704354149954, 26.44236854144505, 15.328479971204485, 26.90557541166033, 45.00675140108381, 66.49338504246303, 72.3785787309919, 59.38304328918457, 64.00310897827148, 68.86836964743478, 51.37097821916853, 26.328527518681117, 3.0080445323671614, 0.5915767933641161, 0.03792903545711722, 0.13097224065235682, 0.07007521550570216, 0.019594452676496336, 0.03259166542972837, 0.047636316889630895, 0.03203202331704753, 0.06938298086502723, 0.014413271232375076, 0.05954439951372998, 0.04147563621933971, 0.012389481167442032, 0.05703200147088085, 0.048865072562226226, 0.010466801301975335, 0.025447366825704063, 0.010802743141539395, 0.012599646363274326, 0.08090840027268444, 0.025002200356019393, 0.09121267377798047, 0.0056577662055912826, 0.028101205493190458, 0.019637015481878604, 0.025687471531065445, 0.010604607523418963, 0.03528583961139832, 0.04730382455246789, 0.024221159052103758, 0.022217078733124902, 0.033299061935395, 0.03754637563335044, 0.049464537895151546, 0.06536117488784449, 0.014495511372972811, 0.04802379431203008, 0.03066866665280291, 0.05992624509547438, 0.028399257089144418, 0.005162905951562736, 0.04989356880209275, 0.03144244084666882, 0.03814877563023141, 0.04516952657806022, 0.06072656357926982, 0.05078796955889889, 0.0512343709623175, 0.025170378653066497, 0.05055203614756465, 0.06426207707928759, 0.04519530412341867, 0.00908990531960236, 0.06886648679418222, 0.07533205021172762, 0.04858360266579049, 0.06651059963873454, 0.05905362192009177, 0.01552450972875314, 0.047270535624453, 0.13400583501373017, 0.011646330107136496, 0.029653279709496667, 0.024837374021964412, 0.03303305245935917, 0.02150630990841559, 0.022824284454275454, 0.03539570460894278, 0.09373098186084203, 0.027015142342341796, 0.019532517696331655, 0.03787513942058597, 0.06372011758919273, 0.04737817841981139, 0.016720766966630305, 0.033863155237798176, 0.07651821763387748, 0.0694047279123749, 0.0321100548441921, 0.01829943636299244, 0.07268046428050313, 0.06317505040871245, 0.04839675108503018, 0.0721400450649006, 0.02509952093740659, 0.0206426094685282, 0.026703129888379147, 0.01900718401053122, 0.09603378043643065, 0.028756643179804087, 0.022839273292837397, 0.3190936861293656, 1.2742121177060264, 8.701096211160932, 43.026434898376465, 81.83010210309709, 75.09944466182164, 65.842255456107, 64.82520593915666, 73.1918306350708, 59.421008246285574, 21.960712705339702, 36.368882928575786, 34.641883850097656, 46.57334436689104, 46.35092210769653, 39.17705297470093, 19.408281530652726, 3.3406843287604193, 0.08263046786721263, 0.05253388426665749, 0.032279915908085446, 0.2032581368195159, 0.052789756429514716, 0.10701019037514925, 0.3350391505020005, 0.5664007557289941, 0.6114851193768638, 0.710722277207034, 0.6584323602063316, 1.4918346915926253, 1.3848039891038622, 1.4064098468848636, 2.3661814544882094, 3.5079732835292816, 2.6279457168919698, 3.4274488730090003, 4.667125838143485, 3.723942186151232, 4.3279886075428555, 4.620057003838675, 2.788574389048985, 5.78926512173244, 7.2438817875725885, 9.568661315100533, 8.798514298030309, 9.056254250662667, 8.340133820261274, 6.256274393626621, 2.5093922955649237, 3.8786160349845886, 2.885383640016828, 2.363230641399111, 2.2683888162885393, 2.127642414399556, 0.864992153431688, 0.6689007984740394, 1.0715266508715493, 0.7140691376158169, 0.4402632942157132, 0.2313020841351577, 0.11600732723517077, 0.1489760817161628, 0.09455183959965195, 0.04933370955820594, 0.09298893596444811, 0.06332229929310934, 0.06641094320054565, 0.12024958245456219, 0.27176065742969513, 8.850492903164454, 46.20173386165074, 57.91996111188616, 34.856458118983674, 33.2608460017613, 24.247752223696025, 44.26785217012678, 62.32719652993338, 79.1627859388079, 84.27423518044608, 65.29851722717285, 73.31345190320695, 80.813948903765, 69.52307060786656, 41.70729160308838, 6.225611558982304, 0.573722419994218, 0.020598245152671422, 0.09993437970323221, 0.020262460224330425, 0.029807229127202715, 0.05547244979866913, 0.04221110371872783, 0.0324228662731392, 0.0069331359617145994, 0.014406721673107572, 0.014532077625127775, 0.04239599433328424, 0.023439406982756088, 0.03231161367148161, 0.054817483693893464, 0.019073202075170617, 0.04843649627374751, 0.04705078188063843, 0.04661833115720323, 0.057062284488763125, 0.016059500664206486, 0.04216132978243487, 0.054684121028653214, 0.09349148614065987, 0.023539774186377014, 0.0372907104236739, 0.015420410582529647, 0.05066129046359232, 0.026817724275003587, 0.03919074418289321, 0.034303622852478705, 0.06589138215141636, 0.0360781581673239, 0.053858459261911254, 0.05461619967328651, 0.09200094826519489, 0.02002811458493982, 0.012958323366806974, 0.018359585099720528, 0.011882239769745086, 0.043843523266592195, 0.03558683096032057, 0.008756134792097976, 0.022504322962569337, 0.0665328623726964, 0.016963465372100472, 0.026594299656738127, 0.013862773227239293, 0.005663288208389921, 0.1587710604071617, 0.2190282406019313, 0.1630223130009004, 0.2651316417115075, 0.12598070635327271, 0.15059702045151166, 0.180821725034288, 0.16981401427515916, 0.23419155765857014, 0.14379617252520152, 0.10948256163724832, 0.21060509687023504, 0.11040322509195123, 0.20311321531023296, 0.1476167860840048, 0.13979894987174443, 0.13464462145098618, 0.12011770238833767, 0.0998602836791958, 0.21977363846131734, 0.15934229189796106, 0.09254987630993128, 0.13660421701414244, 0.12414216143744332, 0.12545963217105183, 0.12734359822102956, 0.1695832580860172, 0.1302597110292741, 0.11599952408245631, 0.10412213498992579, 0.12680028166089738, 0.17872396617063455, 0.10040771894689117, 0.09562433205012764, 0.13610143613602432, 0.1562990623393229, 0.07300308054046971, 0.1898849444197757, 0.17591643253607409, 0.3016350343823433, 0.12896060145327023, 0.09630559477955103, 0.6003868920462472, 1.4829639047384262, 13.12598352772849, 51.80122457231794, 96.90203721182687, 82.42651462554932, 72.64590372358049, 62.53982530321394, 64.64100224631173, 54.21874257496425, 31.845199176243373, 40.121288844517295, 67.19525732312883, 99.41475595746721, 86.08590153285435, 56.68939692633492, 22.891013962881907, 3.946845608098166, 0.19489760829934052, 0.22097765813980783, 0.19493130434836659, 0.5285016436661992, 0.23315709031053952, 0.23239094285028322, 0.28870655383382526, 0.3917144393282277, 0.3457299311246191, 0.3623692925487246, 0.6391060543911797, 0.8215814371194158, 1.003374376467296, 1.207263510142054, 1.617316226874079, 3.8154343281473433, 1.4259819452251707, 2.479041261332376, 3.898009325776781, 5.023754290172032, 4.490504801273346, 4.7967879090990335, 3.499426999262401, 7.145404100418091, 13.363902006830488, 23.91987715448652, 17.695484570094518, 9.160176719938006, 8.321842687470571, 5.638247762407575, 4.888649174145289, 4.51187355177743, 3.229162484407425, 4.6278133647782465, 2.7073592841625214, 1.7903530789273125, 0.7736930410776819, 0.6690879112907818, 0.7615968787244388, 0.42118584790400093, 0.46836954461676733, 0.3898962368922574, 0.22844699876649038, 0.1639544844095196, 0.20465567468532495, 0.3265535001243864, 0.5628683024219104, 0.22723231251750672, 0.1576564445027283, 0.36507371600185123, 0.33835957518645693, 11.546059574399676, 69.83926228114537, 105.44680677141461, 56.77017668315342, 40.30957807813372, 25.45471337863377, 37.754023688180105, 59.38381453922817, 82.87333243233817, 90.91685894557408, 76.65618160792759, 81.63933931078229, 92.29358891078404, 82.66003663199288, 49.40783766337803, 6.657757375921522, 0.6996450573205948, 0.11987748742103577, 0.25455642917326515, 0.29084380343556404, 0.12484468945435115, 0.16602097637951374, 0.141558581164905, 0.17223421297967434, 0.13770090602338314, 0.13778068817087583, 0.1643302028200456, 0.10836069897881576, 0.12771259913487093, 0.14310284544314655, 0.14297989489776747, 0.21590574458241463, 0.13797210289963655, 0.14911201942179883, 0.22347063651042326, 0.14036839003009455, 0.17637810776276247, 0.22217911295592785, 0.19995489264173166, 0.11670544477445738, 0.13240031259400503, 0.182423094819699, 0.11909614077636174, 0.112860885714846, 0.14570650644600391, 0.13233625888824463, 0.10887222617332425, 0.14285136679453508, 0.1524966742311205, 0.15859462773161276, 0.14374210685491562, 0.13733205438724586, 0.11773951857217721, 0.08895508599068437, 0.11793549305626325, 0.07709884683468513, 0.11451696577881064, 0.1352997605821916, 0.08734281893287386, 0.13518421963921615, 0.18694133737257548, 0.12719645111688546, 0.18230250557618483, 0.12505540171904223, 0.13957462619457925], [0.04558570263907313, 0.04284057726285287, 0.018114197999238968, 0.03011161315121821, 0.01973299086759133, 0.01991980173625052, 0.07776645065418311, 0.050230553041079214, 0.0053435167064890265, 0.03983345255255699, 0.08907634019851685, 0.024119348265230656, 0.04390556172334722, 0.019529299744005715, 0.07777678474251713, 0.05061332821579916, 0.05148507268833263, 0.05360786270882402, 0.06467746264700379, 0.029646670778415034, 0.024913405567141514, 0.04332996725237795, 0.011936224863997527, 0.03860433047105159, 0.015095473732799292, 0.03539889033085533, 0.0470583746874971, 0.07700271199324302, 0.030085896674011434, 0.05471063817718199, 0.08024661828364645, 0.04658640608457582, 0.011879205870042955, 0.02046963053622416, 0.07862842082977295, 0.04281397529744676, 0.023518405422302227, 0.11257153802684375, 0.06669861490705184, 0.04776655150843518, 0.0885473203712276, 0.04358811929289784, 6.08186331817082, 36.423606940678184, 64.45989050183977, 65.03537505013603, 61.01370906829834, 72.1921307700021, 52.455897739955354, 29.103193351200648, 63.019542830330984, 38.13207517351423, 50.47108922685896, 50.67108270100185, 61.08754757472447, 46.66042961393084, 17.65048803601946, 2.5298039317131042, 0.10278945828654937, 0.10210723203739949, 0.015188144652971199, 0.06692600556250129, 0.06916687424693789, 0.04317960389224546, 0.12177114295107977, 0.04809312362756048, 0.1741342195974929, 0.29838078043290545, 0.4322298467159271, 0.6486796949590955, 1.2131166074957167, 0.5696467586926052, 1.063793197274208, 0.91114670251097, 1.7039484296526228, 1.9264019557407923, 2.860972447054727, 4.086087942123413, 1.5718490609100886, 1.6952547132968903, 5.383213264601571, 3.4842797092029025, 5.35118510893413, 2.7534738268171037, 5.521778583526611, 5.045612020151956, 4.9361700756209235, 6.448195363794055, 5.28753787279129, 3.847999232155936, 3.297275458063398, 5.181370266846248, 3.5406851853643144, 1.450313451034682, 2.1999345123767853, 2.719263502529689, 0.5001233550054687, 0.9973201070513044, 0.43936749228409355, 0.3006304497165339, 0.11534969109509673, 0.0919686635690076, 0.15135476764823708, 0.10572577786764928, 0.1067303828895092, 0.017951821176601306, 0.024905012088960836, 0.020558708613472323, 0.011180471712058144, 0.03599923097395471, 0.048896068041878085, 0.06917979355369296, 4.605824053287506, 36.252629143851145, 75.7186472756522, 72.47768088749477, 53.42598785672869, 21.15065697261265, 16.15732363292149, 31.280060495649064, 41.086848735809326, 61.35081481933594, 72.97220502580915, 68.16874858311245, 61.64001274108887, 74.32624912261963, 53.033164501190186, 8.297312940870013, 0.40335164059485706, 0.06943910928176981, 0.0546332716143557, 0.09968818005706583, 0.049836015461811, 0.00959660388928439, 0.04745965690485068, 0.026499577864472355, 0.06276579201221466, 0.055218636989593506, 0.047345564634140046, 0.022582344311688627, 0.047563004573541026, 0.06601650400885514, 0.018940692667716315, 0.04322764077889068, 0.04396210404645119, 0.011494851405067103, 0.04308222393904414, 0.03718533732795289, 0.029711813532880375, 0.06975585621382509, 0.01470868502344404, 0.013049377677296954, 0.07421601616910525, 0.06996366434863635, 0.019663130598408834, 0.03102622407355479, 0.032807375104831796, 0.04510739312640258, 0.0151251138387514, 0.022295485150867274, 0.041283464924033196, 0.02998840476253203, 0.022850716785926904, 0.002126546559988388, 0.07344878305281911, 0.05087105956460748, 0.02199148789181241, 0.02918374365461724, 0.023130780418536494, 0.03197830030694604, 0.04839482743825231, 0.020115823717787862, 0.027001201840383664, 0.05039706214198044, 0.0211834493758423, 0.04536572497870241, 0.04000759856509311, 0.037141470038997274, 0.03573057181867106, 0.025239327988986458, 0.03129539213010243, 0.05344628995018346, 0.007567580623020018, 0.0623344269448093, 0.06298850077603545, 0.0475792860213135, 0.07271403140787568, 0.045144729515803714, 0.017911853767665367, 0.022312592715024948, 0.04012122943199106, 0.03798898063333971, 0.052095723671040366, 0.0656937656125852, 0.049981164280325174, 0.027822865339528238, 0.0628596537613443, 0.039399515837430954, 0.05578481339450393, 0.057156851914312155, 0.03527023330596941, 0.02035434913289334, 0.013074192551097699, 0.014884892086099302, 0.02238750298108373, 0.03131089326260345, 0.12658009704734596, 0.06903133009161268, 0.035397082035030634, 0.02353958589290934, 0.057556576893797944, 0.06768485198595695, 0.024529237699295794, 0.05391551048627921, 0.011962454483312155, 0.03975526156968304, 0.020481343746983578, 0.12265596618609768, 10.958933319364276, 47.69878230776106, 83.28938361576625, 77.25823606763566, 70.53537450517926, 85.14863123212541, 67.05231898171562, 39.88255221503121, 53.66730921609061, 40.83155107498169, 46.50175012860979, 33.29127216339111, 43.37789562770298, 47.29801716123308, 23.76514424596514, 4.7629649468830655, 0.16611515704010213, 0.03823585881452475, 0.07115899877888815, 0.07667707625244345, 0.048294339794665575, 0.10008938424289227, 0.13201338478497096, 0.6699568160942623, 1.0679307409695216, 2.7397439692701613, 3.014298562492643, 3.2933992317744663, 4.7846042428697855, 5.738780379295349, 4.540894440242222, 5.3773528933525085, 8.061639598437718, 9.110791529927935, 5.418203958443232, 7.754610862050738, 7.365389278956822, 10.132683941296168, 10.172347732952662, 10.6584906067167, 8.34040914263044, 6.009205571242741, 12.590259177344185, 8.403209567070007, 9.584622195788793, 12.150482501302447, 13.662827406610761, 9.257355962480817, 6.866785245282309, 7.7794723851340155, 6.315493890217372, 5.064673968723842, 7.7140620435987195, 6.905059397220612, 2.8903318430696214, 2.315681729997907, 2.5306681139128546, 2.57486560514995, 1.9217375431741988, 1.157758897968701, 1.1533343068190982, 0.5833500719496182, 0.5056075464401926, 0.11029050006930317, 0.20141075737774372, 0.08004692542765822, 0.04737558302336505, 0.015829687638740455, 0.19053005480340549, 0.1654634920081922, 3.4516155762331824, 33.32914331981114, 53.04533774512154, 49.767097745622905, 36.35000467300415, 26.188936471939087, 33.489737033843994, 51.30826030458723, 58.321198735918315, 74.70652403150285, 84.23692335401262, 73.81864847455705, 69.88359178815568, 83.9010682787214, 70.902968951634, 17.931721585137502, 0.18165024343345845, 0.11421307708535876, 0.022781813251120702, 0.14769856312445231, 0.07575653493404388, 0.0164442503758307, 0.1006069639697671, 0.029049699061683247, 0.09576438846332685, 0.06210246974868434, 0.07542992888816766, 0.029840185573058467, 0.05108602624386549, 0.07907034390206848, 0.027911400588761483, 0.056318793312779496, 0.021796098644179956, 0.058581917945827754, 0.02631614949288113, 0.03882917322750602, 0.06786257387804133, 0.0164551697006183, 0.029685262457600663, 0.07122518986995731, 0.05437262595764228, 0.042606821948928494, 0.02922702401078173, 0.033859979693910906, 0.03581342433712312, 0.011127428085144078, 0.06459350072379623, 0.07903174883020775, 0.026425985652687292, 0.01152333545698119, 0.046226103989673514, 0.03012368768187506, 0.04994613830266254, 0.015387404942885041, 0.07139179735843625, 0.022338246427742497, 0.023373762112376944, 0.02130786725319922, 0.012444158367413496, 0.02917765380282487, 0.041095039142029624, 0.0009946940637226881, 0.046909432858228683, 0.008619511766093118, 0.15019011657152856, 0.14974453619548253, 0.13229433899479254, 0.06904420190091644, 0.23814516408102854, 0.2160069548657962, 0.19767411931284837, 0.2078529316931963, 0.19121735649449484, 0.10684199511472668, 0.2877815748964037, 0.11318937808807407, 0.10712335644555943, 0.17473234821643147, 0.19483172254902975, 0.19612369393663748, 0.1758260652422905, 0.168285302019545, 0.11413471986140523, 0.12977995962968894, 0.18018112012318202, 0.139001725507634, 0.10454016005886452, 0.11591632211846964, 0.1020343845177974, 0.15057574159332685, 0.15675426434193337, 0.20627533777483872, 0.14653813253555978, 0.18359962025923388, 0.34337058344057625, 0.1437595316341945, 0.11019275031451668, 0.13798257948032447, 0.20070221754057066, 0.2847965093595641, 0.11230813073260443, 0.20117317512631416, 0.19442880845495633, 0.14843672780053957, 0.15395996214023658, 0.34571923741272514, 13.729070663452148, 60.52156121390206, 95.46071679251534, 85.96225139072963, 75.71120575496128, 91.15361881256104, 70.21213735852922, 42.92555400303432, 75.3719391141619, 52.89994668960571, 70.71335261208671, 69.0493563243321, 79.19473375592912, 65.76273332323346, 28.34499897275652, 4.561102841581617, 0.3169291051370757, 0.27251128000872477, 0.25412007687347277, 0.3409185750143868, 0.18499532608049257, 0.16887059275593075, 0.2715441776173455, 0.43794460434998783, 0.411366306245327, 1.3897002977984292, 1.5967172064951487, 1.914347916841507, 2.6639039473874226, 3.1121919495718817, 3.6167736053466797, 4.196222535201481, 8.969210692814418, 11.474837933267866, 8.855804800987244, 14.330735155514308, 11.575355785233633, 13.083206943103246, 20.16084439413888, 16.5697409084865, 18.197424173355103, 12.277357476098196, 18.294886554990494, 16.414875984191895, 17.166462625776017, 16.25076300757272, 14.898617506027222, 11.098358477864947, 10.646305203437805, 13.34294102873121, 9.465293833187648, 8.266150270189558, 9.215308938707624, 8.572354776518685, 2.876026370695659, 3.479342145579202, 2.7660005603517805, 2.0256430762154713, 2.256914517709187, 1.0832001673323768, 0.7570063450506755, 0.552397041448525, 0.4260232597589493, 0.16777190885373525, 0.3027090738926615, 0.2701522037386894, 0.26046836908374515, 0.14774231506245478, 0.45622040224926813, 0.2950522133282253, 6.562093709196363, 49.39350005558559, 98.93239116668701, 94.9409567969186, 73.61405181884766, 30.38732119968959, 27.19642005647932, 43.2682078906468, 54.50202063151768, 78.40486254010881, 89.6266062600272, 87.27637808663505, 77.84475435529436, 95.34410517556327, 79.41007927485875, 20.060224056243896, 0.47956900937216623, 0.23277561792305537, 0.16353414553616727, 0.28137232310005594, 0.13622769793229444, 0.08622167552156107, 0.1910542231053114, 0.1936675871589354, 0.11723690054246358, 0.12410436703690461, 0.18287613908095018, 0.12658587816570485, 0.298848209636552, 0.10931701944874865, 0.09251939651689359, 0.13266716684613908, 0.06794188783637115, 0.11979162559977599, 0.10205244033464364, 0.09533911664038897, 0.2341216956930501, 0.16510067933372088, 0.06962092274001666, 0.16294025097574505, 0.12299384948398386, 0.18749084217207773, 0.1608001108148268, 0.1094712233170867, 0.1150190138391086, 0.18192240382943833, 0.1248944667833192, 0.12027927514697824, 0.1676108246403081, 0.1109075326738613, 0.16138525227350847, 0.13562966430825846, 0.22935021030051367, 0.12634887945439133, 0.11491723358631134, 0.19093926570245198, 0.08517565272216286, 0.14903805910476617, 0.22559261907424244, 0.1287365084780114, 0.16823338051991804, 0.10649626116667475, 0.1080681486055255, 0.1340843957981893], [0.04380042611488274, 0.03001246222161821, 0.041391894820013216, 0.025807965779677033, 0.013202447543985077, 0.024784368562645147, 0.031505344435572624, 0.020880320641611303, 0.06635535761181797, 0.07395369453089577, 0.028364195488393307, 0.028783428349665234, 0.04209949488618544, 0.08198125234672002, 0.03433161581467305, 0.009591679421386548, 0.06128790881484747, 0.0278057408119951, 0.05243908613920212, 0.03662918967061809, 0.04638475565505879, 0.026877325094704117, 0.05178035755774804, 0.0264699360621827, 0.03827505778255207, 0.033435362657266, 0.026644825070564235, 0.019345564335318546, 0.04640999037240233, 0.05403697843264256, 0.05118644264127527, 0.008427755225316753, 0.016934586921706796, 0.09806596567588192, 0.07858585632805314, 0.03999181244788425, 0.028499807497220378, 0.061494712717831135, 0.04366741968052728, 0.08118613144116742, 3.110802961247308, 30.19852474757603, 62.62180709838867, 80.18553297860282, 63.96613761356899, 72.88337925502232, 64.15308584485734, 33.56141812460763, 17.038593190056936, 38.99881431034633, 143.17309325081962, 98.9993509565081, 35.75867823192051, 53.483737809317454, 32.40628010886056, 8.152073008673531, 0.30121054287467686, 0.024283789530662552, 0.02770436937654657, 0.04717743383454425, 0.05980911638055529, 0.10968579644603388, 0.008561529252412063, 0.2591626505766596, 0.14558016322553158, 0.4055512339941093, 1.493465238383838, 3.9620226451328824, 3.2875002111707414, 3.933786468846457, 4.606425940990448, 8.15648945740291, 3.1487049502985816, 3.0747346452304294, 7.585531660488673, 6.801143876143864, 5.408099974904742, 7.404959269932338, 8.755387697901044, 4.491648214203971, 7.158877091748374, 6.3126950689724515, 2.4299370391028265, 5.901773393154144, 6.153028505189078, 4.3561583416802545, 5.990920952388218, 13.74945146696908, 16.31158753803798, 11.90323085444314, 0.8255305652107511, 3.8007562586239407, 3.8294128009251187, 2.649659488882337, 2.794646463223866, 4.09773051738739, 1.4639719809804643, 1.5276827280010497, 2.4219713636807034, 2.697780106748853, 0.750106078173433, 0.9703827010733741, 0.8075043867741312, 0.8774581987942968, 0.12871480892811502, 0.22269458243889467, 0.12521035197590077, 0.01568256937233465, 0.11821401811071805, 0.08840332166957003, 0.021450776906151856, 0.09085529616900853, 0.038340499092425616, 1.1074478604963847, 19.88337676865714, 65.2127069745745, 68.22525828225272, 61.75044046129499, 32.39222737721035, 12.90163140637534, 18.128310441970825, 22.747855016163417, 41.25308438709804, 55.70143951688494, 73.33519281659807, 58.786436217171804, 71.44481727055141, 58.650355747767854, 20.565599543707712, 0.41719304929886547, 0.13471043934779509, 0.07633800551827465, 0.04257790957178388, 0.055558009671845605, 0.04368852211960724, 0.049767537707729, 0.013976767110372228, 0.028631405971412147, 0.029956710391810963, 0.050613521598279476, 0.021050493831613233, 0.026076926883043985, 0.04043612735612052, 0.04322674171999097, 0.029933735196079527, 0.0953749907868249, 0.06968870160302945, 0.045458202516394, 0.015437926964036055, 0.07497539863522563, 0.04544673866725393, 0.06036469406847443, 0.07325283571013383, 0.016394537507689426, 0.04825821119759764, 0.023806945653632283, 0.022550531197339296, 0.045476831695330996, 0.0240836556269122, 0.0587750765095864, 0.012085414358547755, 0.02903487646420087, 0.03529807699045964, 0.020627389928059917, 0.06859769871724503, 0.0827287808060646, 0.05567505017721227, 0.0319747040713472, 0.035517189518681595, 0.02598858162361596, 0.05437537402446781, 0.04137945727312139, 0.009829200604664428, 0.032510875657732995, 0.022188422502949834, 0.04853402550465294, 0.025912904612986103, 0.02770012174732983, 0.012622695349689041, 0.040767191377069266, 0.04136997813891087, 0.03975986882245966, 0.03156205299975617, 0.06708285571741206, 0.019001236651092768, 0.01637818311740245, 0.04219231169138636, 0.014874281494745185, 0.08405998508845057, 0.03325142538441079, 0.011733941700575607, 0.049660573447389264, 0.04609725358230727, 0.05292692228353449, 0.05144096112677029, 0.025350298998611312, 0.006964173425720739, 0.02401234159645225, 0.012623344198800623, 0.062374731924917014, 0.05279213808743017, 0.05681973196832197, 0.06491235789975949, 0.023679087603730813, 0.021326739008405378, 0.04678888093414051, 0.08834331203252077, 0.054463502152689865, 0.07788309760923896, 0.04267941501789859, 0.04703574215195008, 0.04565929315452065, 0.036353453395089934, 0.0917805058083364, 0.06705279661608593, 0.11266732003007617, 4.13155608517783, 40.183228560856406, 79.4136575971331, 91.31435149056571, 72.60663945334298, 84.39887196677071, 75.0290663582938, 52.40598882947649, 29.540940284729004, 43.38909959793091, 129.91795921325684, 76.80046789986747, 30.651060921805247, 43.79286636625017, 32.39415897641863, 11.116912773677281, 0.3861822618969849, 0.07727686049682753, 0.02600117353722453, 0.07552890679133789, 0.08418729861399957, 0.2722577793257577, 0.9082645028829575, 1.9260330498218536, 1.4024289633546556, 2.5392658582755496, 7.137932181358337, 8.161660654204232, 8.153709309441702, 12.272283554077148, 11.735996399606977, 11.324159298624311, 8.57475277355739, 9.493737152644567, 9.786756583622523, 11.438922694751195, 14.190279058047704, 13.920573438916888, 9.478714278766088, 11.215520739555359, 11.650815827505928, 12.072520239012581, 7.1021537355014255, 13.742881076676504, 12.209066237722125, 9.250640528542654, 11.687098452023097, 9.109997698238917, 9.318114485059466, 9.550457903317042, 5.893315698419299, 6.560436129570007, 6.778960449354989, 4.448490347181048, 4.317809930869511, 4.439214502062116, 4.628790020942688, 4.235834215368543, 6.218012835298266, 5.969258640493665, 3.081943618399756, 4.227426026548658, 2.23517165013722, 2.502456473452704, 1.6431379041501453, 1.0155415407248904, 0.6011999398469925, 0.5580522779907499, 0.2650986377682005, 0.07724847059164729, 0.04575767394687448, 0.058682008646428585, 0.06838107641254153, 0.9309689360005515, 18.68971793992179, 51.3308037349156, 57.42788273947579, 38.32692003250122, 25.18740749359131, 20.19241179738726, 32.87610340118408, 44.20886891228812, 57.99203824996948, 69.49399239676339, 87.92818859645298, 69.78010531834194, 78.77691773005894, 76.59867831638881, 37.72329527991158, 1.2200505839926856, 0.36722298924412045, 0.06380211854619638, 0.009724654473497399, 0.007614222272033138, 0.12308177405170032, 0.028365812098075236, 0.04030292075393455, 0.046782614663243294, 0.05072220255221639, 0.038734782221061845, 0.06488855489130531, 0.0051135832410571826, 0.03125372329460723, 0.022230612114071846, 0.02391680047315146, 0.01322875265032053, 0.016452045046857426, 0.021964229443775754, 0.045439505483955145, 0.019774400163441896, 0.06420937526438918, 0.04518836949552808, 0.029593168292194605, 0.08611586477075305, 0.021010606150541986, 0.021458215346293788, 0.040865707876426835, 0.024124147204150046, 0.045701806766114066, 0.03080604624535356, 0.0657249917941434, 0.05917448257761342, 0.010591879902806665, 0.030812336264976432, 0.029206291373286928, 0.08777994476258755, 0.01764382904262415, 0.017086390472416366, 0.054461944914822064, 0.0029801041736001416, 0.060823485521333556, 0.036510578356683254, 0.018503970566338727, 0.04385776571663363, 0.023895292609397854, 0.011803694252323891, 0.1715579849800893, 0.2086543222623212, 0.15592973572867258, 0.1765168003205742, 0.1486679861055953, 0.1414764512862478, 0.1595790327659675, 0.1416566837579012, 0.16650167772812502, 0.10570727421769074, 0.17969980809305394, 0.11612037116927759, 0.2464163973927498, 0.21463189007980482, 0.19069032477481024, 0.23443184047937393, 0.08321100207311766, 0.11442999116012029, 0.14321907849184104, 0.11612000476036753, 0.1334322557917663, 0.14227928034961224, 0.13927254240427697, 0.2307840090777193, 0.19117935853345053, 0.2191995842648404, 0.10413868445903063, 0.1843715352671487, 0.15579149100397313, 0.11472497747412749, 0.1741087202514921, 0.11707117514950888, 0.23223905957170896, 0.18160691218716757, 0.15739111016903604, 0.18640682819698537, 0.2725066659705979, 0.1627019630478961, 0.10910754211779151, 0.17031423029090675, 5.658894334520612, 51.521212169102256, 93.15579087393624, 103.36382716042655, 79.02628857748849, 90.9172272000994, 82.78257506234306, 46.24858903884888, 31.276961599077495, 51.34551307133266, 144.68656376429965, 111.2897206715175, 51.53645304271153, 73.83842304774693, 46.83345365524292, 13.222999487604413, 0.6023006322128432, 0.21649902846132005, 0.185697949092303, 0.22264739711369785, 0.10034380773348467, 0.27070838532277514, 0.32771721482276917, 1.1244366403136934, 0.7151896974870137, 1.5709486177989413, 7.068566143512726, 13.011254004069738, 10.877273746899196, 15.543599673679896, 14.250048330851964, 23.56176699910845, 15.251367126192365, 12.504671267100743, 22.532917703901017, 19.276554107666016, 23.18202189036778, 23.11940472466605, 22.203838859285625, 18.224622896739415, 15.826512949807302, 19.383495569229126, 11.850335087094988, 17.29731978688921, 17.960629565375193, 17.835721799305507, 18.211834737232753, 31.669288158416748, 34.15782717296055, 23.511012145451136, 13.022205233573914, 13.90214421067919, 13.804508124079023, 8.147301333291189, 9.919185774666921, 10.027814779962812, 6.917164896215711, 6.562958759920938, 7.986209954534258, 7.605616297040667, 4.142592864377158, 6.845333984919956, 4.144163591521127, 2.7928186527320316, 1.6901556040559496, 0.7902733428137643, 0.7833648792334965, 0.6389560710106577, 0.3096352608076164, 0.18788756802678108, 0.16449203342199326, 0.24856936186552048, 0.26741496633206097, 1.7834084630012512, 27.969761507851736, 82.65166405269078, 89.39208371298653, 84.22428458077567, 45.74354532786778, 20.49044782774789, 29.640671253204346, 34.627511501312256, 56.0186699458531, 71.1499218259539, 92.66977133069719, 77.48580346788678, 88.5614126750401, 89.08992045266288, 44.49459968294416, 1.1958355690751756, 0.5841874927282333, 0.16193223292274134, 0.11812712491622993, 0.20624553651681968, 0.23625319131783076, 0.19954541032867773, 0.10231518944991486, 0.1646442831094776, 0.23450563794800214, 0.1351045596280268, 0.1336250818733658, 0.1197964431984084, 0.11466589064470359, 0.05913792989615883, 0.13623506682259695, 0.1283756092722927, 0.23667982699615614, 0.12749485724738666, 0.20563728415540286, 0.10919497814029455, 0.14116304953183445, 0.14051103166171483, 0.1440343383167471, 0.1269270862851824, 0.11630198785236903, 0.11165933590382338, 0.16390755692762987, 0.1417452868606363, 0.17263950194631303, 0.10113073193601199, 0.22209299329136098, 0.1244873186307294, 0.10336256931935038, 0.1464006206286805, 0.16318358720413276, 0.18797437979706696, 0.15383427031338215, 0.19521403631993703, 0.1283455230295658, 0.1541495176830462, 0.09599473753145762, 0.18200363804187092, 0.08758348173328809, 0.17187445371278695, 0.11177817452698946, 0.12994040602019855], [0.027155051174174463, 0.02265747679796602, 0.023004688256021057, 0.035621802655181715, 0.04582361397998674, 0.020964662544429302, 0.041076240329337974, 0.06960957763450486, 0.03182422536026154, 0.018379988647731285, 0.03221170278266072, 0.027762938823018755, 0.052787581724779944, 0.03304642638457673, 0.020066801259028058, 0.032324756894792826, 0.04712892197338598, 0.04417181207931467, 0.013393647686046149, 0.04174888227134943, 0.014122644505862678, 0.025825329490804246, 0.0145943925849029, 0.033193627771522315, 0.06532343477010727, 0.042710651377482076, 0.07265851367264986, 0.024217610313956226, 0.04790206852235964, 0.04846749853874956, 0.05606778285333088, 0.016911805108455674, 0.04842800780066422, 0.0499685503143285, 0.06264712980815343, 0.028203087526240518, 0.018364762321912816, 0.1451933846942016, 0.08233330345579556, 6.414527867521558, 41.735747950417654, 17.45013846669878, 56.49676506859915, 65.69985212598527, 59.012898853846956, 39.376827580588206, 26.199806928634644, 23.47673147065299, 21.475787503378733, 29.210351943969727, 30.083615439278738, 42.567610604422434, 47.95690788541521, 15.936341387884957, 2.929517511810575, 0.07752614069197859, 0.1973403072250741, 0.037641825154423714, 0.015416732922728573, 0.0483638591000012, 0.048479488252529075, 0.1565416386084897, 0.3214723584907395, 1.3637413936001914, 0.16234670925353253, 1.9712278246879578, 7.98057062285287, 6.254081802708762, 10.319011177335467, 10.972418904304504, 9.443712728364126, 9.84581366607121, 9.43838780266898, 11.22419990812029, 7.639497450419834, 10.872192876679556, 4.227679635797228, 4.66899186372757, 6.274273702076503, 10.866154023579188, 9.52482339314052, 11.173381652150836, 5.544735865933554, 6.351885948862348, 13.071655562945775, 6.446761863572257, 6.850876476083483, 6.877738211836133, 9.988283004079547, 10.119061129433767, 5.864286993231092, 5.872179278305598, 5.883551742349352, 3.7919381260871887, 6.446274186883654, 4.69771180834089, 6.621122130325862, 2.8649537648473467, 3.338409445115498, 4.52676397562027, 3.6672696386064803, 1.9990814157894679, 2.313841760158539, 0.6115236058831215, 1.9544073215552737, 0.9686731185231889, 0.44571434600012644, 0.17800991662911006, 0.05081254948994943, 0.15548247258578027, 0.02714819966682366, 0.03614113978775484, 0.043284094892442226, 0.2257522919348308, 0.27856799215078354, 10.021951368876866, 37.5537314414978, 85.94632611955915, 83.20499774387905, 63.40081827981131, 38.21355669839041, 9.73710823059082, 35.374665192195344, 43.161014556884766, 26.411843367985316, 68.57238333565849, 68.07703930991036, 60.65485545567104, 64.76281111580985, 39.25138132912772, 1.0062971796308244, 0.6508757599762508, 0.06295467580535583, 0.02278557063878647, 0.04589109768026641, 0.008476480825005897, 0.04671530398939337, 0.06638393750680344, 0.06476386051092829, 0.03737208712846041, 0.030185668463153497, 0.04271263609241162, 0.006940598150582186, 0.013631914409675767, 0.04703355048383985, 0.016066660904990773, 0.05803544619785888, 0.024530674497197782, 0.05584098591602274, 0.05038882472685405, 0.0723187711888126, 0.03815263310181243, 0.057709980090813975, 0.03913961996191314, 0.044238138877387555, 0.055614803052906475, 0.061806173862091134, 0.025336802937090397, 0.0652093051799706, 0.03511709813028574, 0.0928976187216384, 0.01987572410143912, 0.07177359544272933, 0.025169094525543705, 0.004495300011642809, 0.0377700988070241, 0.031973333430609534, 0.12217477629227297, 0.08869578383330788, 0.0456152358757598, 0.033611764798739126, 0.055309082314904244, 0.014583702265684093, 0.09254031575151853, 0.040725529326924255, 0.011215054097452333, 0.008226281214904572, 0.07730055493967873, 0.043973801990172694, 0.03750053041481546, 0.03654453224901642, 0.03139783056186778, 0.04003967970077481, 0.02400826699366527, 0.04006250561880214, 0.022309169505855868, 0.06574167697025196, 0.054707581376922984, 0.029032314994505475, 0.05126957335908498, 0.027646468287067752, 0.011420611192339232, 0.015355556205447232, 0.007932272839492984, 0.02019149055039244, 0.043576848826238086, 0.03181376913562417, 0.02274710957759193, 0.04255901915686471, 0.044010975531169345, 0.019192091588463103, 0.07367293709622962, 0.06807792053690978, 0.0477175409240382, 0.08155133255890437, 0.012088960552188967, 0.07479240452604634, 0.01870340049000723, 0.03724356581057821, 0.02226935137462403, 0.020658270056758608, 0.02781732510110097, 0.039865133352577686, 0.12325610326869146, 0.036975167891276736, 11.448889885629926, 52.773197650909424, 22.21408224105835, 60.29256248474121, 76.89103766850063, 76.5670918055943, 64.34318855830601, 48.74801588058472, 25.33758933203561, 18.061512197766984, 29.733186517442974, 48.41947725840977, 54.57301732472011, 46.64297921316964, 23.249584436416626, 4.38058386530195, 0.15940589777060918, 0.07344018601413284, 0.13435813039541245, 0.07883610682828085, 0.30431266927293366, 1.2330106028488703, 1.869385255234582, 2.274723402091435, 3.675272226333618, 2.399435967206955, 9.36020232949938, 11.870867013931274, 9.065470167568751, 5.1601782611438205, 7.709074974060059, 6.6344804763793945, 11.710501721927098, 10.476162927491323, 6.132915207317897, 7.639942135129656, 9.056022354534694, 11.270579133714948, 14.890729563576834, 12.467829312597003, 13.884527921676636, 11.634175760405403, 11.659554924283709, 8.08948016166687, 10.413729889052254, 9.971356323787145, 4.813293354851859, 5.647761149065835, 5.7172261987413675, 9.815285887037005, 6.2818198800086975, 4.013632995741708, 2.485092273780278, 5.11598858663014, 3.645827497754778, 3.9733286670276096, 3.782563269138336, 2.2964297916207994, 4.150429563862937, 4.166070827416011, 6.943448628698077, 5.637998495783124, 3.7725483093942915, 5.386377734797342, 2.9520661532878876, 2.7477374374866486, 1.435624633516584, 0.8344069974763053, 0.9538360003914151, 0.29837214946746826, 0.7701663417475564, 0.28035465627908707, 0.08814297456826482, 0.07649997182722602, 0.05114487897870796, 0.3557594929422651, 10.448318890162877, 34.214256967817036, 77.01450715746198, 61.1430150440761, 32.40335839135306, 26.307271242141724, 14.375325219971792, 39.06560386930193, 46.29062911442348, 38.084750992911204, 78.72928088051933, 78.70966611589704, 68.90811334337506, 76.92179039546421, 59.83712196350098, 5.665874234267643, 0.6159405431577137, 0.04855084638776524, 0.04720558285979288, 0.031917622312903404, 0.07440053019672632, 0.02183571830391884, 0.13012420758605003, 0.044840545659618716, 0.07572243176400661, 0.05908690406275647, 0.029343687929213047, 0.007818902360408433, 0.009078843502460845, 0.05181641490863902, 0.01843156070182366, 0.030793472991458008, 0.04257279002506818, 0.02856137097946235, 0.006516717324432517, 0.03528195160574146, 0.04902306265596833, 0.04913942123364125, 0.03804716161851372, 0.045358461261327775, 0.046773712283798625, 0.031388012160147936, 0.045571880880743265, 0.03967657864892057, 0.014468989135431392, 0.02147738396057061, 0.08525405744356768, 0.06770431915564196, 0.03820580989122391, 0.06641278881579638, 0.03907150183139103, 0.047730063287807364, 0.019400072749704123, 0.05736272622432027, 0.017284819556932365, 0.038364278352154155, 0.04341324046254158, 0.02136988365756614, 0.0039034291819137123, 0.050113393792084286, 0.051683218484478335, 0.09809623512306384, 0.16965174941079958, 0.15152361430227757, 0.10764587590737001, 0.13339672769818986, 0.0999024071331535, 0.09057179745286703, 0.2227159562919821, 0.17268300961170877, 0.10309083640043225, 0.13364222166793688, 0.1241960914007255, 0.08556213269808463, 0.24371588230133057, 0.09306616682027068, 0.09929794099714075, 0.1548069231212139, 0.1257384286395141, 0.16592260237251008, 0.17266844825020858, 0.12990139025662625, 0.12839638601456368, 0.1253342388996056, 0.13979010177510126, 0.1464079488068819, 0.17576049161808832, 0.1815017664006778, 0.12500001969082014, 0.2590984883052962, 0.14293637366167136, 0.12888221708791597, 0.1579154006072453, 0.09354844237012522, 0.06327746169907705, 0.11622776969202928, 0.12861050452504838, 0.2336857776556696, 0.22111928196890013, 0.21260241898042814, 16.103667906352452, 67.05705765315464, 30.80636010851179, 72.8716367994036, 83.14996106284005, 76.89705480848039, 52.48440967287336, 36.102527209690635, 32.71335574558803, 36.17744616099766, 46.80775921685355, 44.78838341576712, 60.208753313337056, 69.26306206839425, 26.354043040956768, 4.738787821360996, 0.24419072110738071, 0.3785752872271197, 0.20625518528478487, 0.1935110627008336, 0.279405060091189, 0.43666545727423256, 0.797760081078325, 1.5941737315484454, 2.852853694132396, 1.406767787677901, 12.009351560047694, 22.616174493517192, 21.218205622264318, 25.35790412766593, 23.544990573610576, 28.506386518478394, 28.091950791222708, 24.77032276562282, 25.541162865502493, 19.464857237679617, 24.45055624416896, 19.995564120156423, 20.823678221021378, 16.654305696487427, 28.324852670942033, 22.650712251663208, 26.769493205206736, 18.32360519681658, 20.80086554799761, 29.670378276279994, 20.556360176631383, 20.21414749962943, 22.82160840715681, 28.081340891974314, 25.565825496401104, 18.681691033499582, 17.984960419791086, 13.096600464412145, 13.523400511060442, 17.41045904159546, 11.434724245752607, 16.40892137799944, 10.810016921588353, 9.802587185587202, 13.348365834781102, 11.306522165025983, 6.44246700831822, 8.722370726721627, 4.990369064467294, 6.206517909254346, 3.825554813657488, 1.10162744138922, 0.8986240944692067, 0.2930135412939957, 0.7145631653921944, 0.4600514109645571, 0.2320948030267443, 0.1254907769284078, 0.4930816814303398, 0.7215039815221513, 16.1966678074428, 51.00316143035889, 106.45160661424909, 106.61703627450126, 86.85446957179478, 54.03494882583618, 16.107086420059204, 48.26234374727522, 54.57404913221087, 37.74698863710676, 85.59053666251046, 86.27948529379708, 76.8719231741769, 89.72208840506417, 69.58971078055245, 7.2084338154111585, 0.9441219844988414, 0.19629363981740816, 0.11648668508444514, 0.15249149022357805, 0.2901163324713707, 0.12679496194635118, 0.2502073725419385, 0.1551833607788597, 0.1733216739126614, 0.129890574408429, 0.17776227848870413, 0.11288601186658655, 0.08402560371905565, 0.12701511941850185, 0.08886925809617553, 0.07896487241876976, 0.07422514246510607, 0.13227122809205735, 0.14432730259639875, 0.09397947495537144, 0.11639265370156084, 0.15755249293787138, 0.1452869546732732, 0.09578854430999074, 0.10045359469950199, 0.1571313398224967, 0.0873740247583815, 0.13719480032367365, 0.10341094886618, 0.21864861382969789, 0.11551097886902945, 0.19616399891674519, 0.10077717447919504, 0.11107979914439575, 0.12319646004055228, 0.13933712536735193, 0.24848177656531334, 0.17207931700561727, 0.09282171779445239, 0.17449594661593437, 0.15152266435325146, 0.14332178155226366, 0.21577109609331402, 0.18535364685314043, 0.14861044633601392], [0.046443225017615726, 0.01686007359863392, 0.033092604085270844, 0.02373658157219844, 0.0035996219126640683, 0.04930315173364111, 0.04669155187106558, 0.07982803681599242, 0.10683844637657915, 0.04965482625578131, 0.06602567101695708, 0.0450308238422232, 0.05303440562316349, 0.08185178107981171, 0.005020693917426148, 0.044820003011929135, 0.012450725738225239, 0.03810538670846394, 0.024752229751486863, 0.02166217958022441, 0.03428929219288485, 0.022006030593599592, 0.025080189474725297, 0.017663742349083935, 0.051300802933318276, 0.08404300814228398, 0.08037579778049674, 0.05245854313086186, 0.05677956948056817, 0.06774984885539327, 0.0898263453106795, 0.09692879526742867, 0.05035071141485657, 0.011376926259669875, 0.020783805820558752, 0.06143917462655476, 0.011187284203645374, 1.0825038275548389, 18.178990602493286, 66.00118160247803, 67.61419200897217, 19.408694948468888, 41.668649196624756, 56.44135318483625, 23.112970692770823, 16.687493767057145, 18.430944442749023, 41.26570578983852, 32.11465726579939, 53.07594803401402, 41.577193532671245, 28.06798471723284, 7.627949544361659, 2.158594467810222, 0.08317738066294364, 0.09118800903005259, 0.07555296085774899, 0.13481310169611657, 0.08798964601010084, 0.48541027307510376, 0.8950335585645267, 1.7959442074809755, 4.550251492432185, 7.956011346408299, 5.111972962106977, 8.607279028211321, 8.413128120558602, 7.697297777448382, 6.123092191559928, 10.924005593572344, 9.564380356243678, 9.540692210197449, 4.643639189856393, 7.532733167920794, 4.767650638307844, 6.191602298191615, 10.501392705099923, 16.35132254873003, 8.383616515568324, 6.53001344203949, 10.68928849697113, 8.324579409190587, 5.445463044302804, 13.245438694953918, 9.450217979294912, 5.189585208892822, 8.343926668167114, 4.796634614467621, 5.865892895630427, 7.092536125864301, 2.3204842380114963, 3.2606256646769385, 4.313215000288827, 5.184479585715702, 4.134762678827558, 4.380921721458435, 6.142855908189501, 5.49187570810318, 6.316545239516667, 7.251484853880746, 4.0343751055853705, 5.28383925982884, 3.3955195120402744, 3.673711052962712, 1.2231857414756502, 1.4939055804695403, 1.340851638998304, 1.7434943190642764, 1.3773307672568729, 1.1843060106039047, 0.7588148851479802, 0.3173578035618578, 0.14051765416349682, 0.11032440646418504, 0.08815108984708786, 0.16339305096438952, 8.783665129116603, 24.69738926206316, 56.72387736184256, 98.65822914668492, 85.33193860735211, 51.956898961748394, 98.83884756905692, 124.05715370178223, 44.0091290473938, 37.403316838400706, 56.54385648454939, 72.27125685555595, 54.5109212739127, 61.5148617880685, 48.13892984390259, 17.590318373271398, 0.40627506801060265, 0.015943808747189384, 0.056289178651890585, 0.053878007855798514, 0.042675364163837264, 0.034443299286067486, 0.02964450964438064, 0.053799762590123076, 0.04136033615629588, 0.046535244544169733, 0.015631473989092877, 0.02634350972117058, 0.039813571476510594, 0.05987036095133849, 0.04373692202248743, 0.09435207889016185, 0.04137704847380519, 0.05810610204935074, 0.013105709654545146, 0.06515662372112274, 0.02278798961612795, 0.05316135613247752, 0.0716870143743498, 0.009150140569545329, 0.03795312684295433, 0.021444673483659114, 0.07722063029983214, 0.026284772337281277, 0.02098413141045187, 0.04925589855494244, 0.04051378568900483, 0.007717978758072215, 0.016196688570614372, 0.04725094631846462, 0.03059555111186845, 0.056781262425439696, 0.0243829930467265, 0.02930156108258026, 0.03616579435765743, 0.03825834546504276, 0.008380122067007636, 0.017918001294934323, 0.009767749080700534, 0.05577959885288562, 0.08011861265237842, 0.026730885363316963, 0.07461705750652722, 0.0377574509142765, 0.059785679781011174, 0.06398062075355224, 0.05292412332658257, 0.030871772539934943, 0.06579384952783585, 0.07934196825538363, 0.02133164651292775, 0.03433345125189849, 0.039520254358649254, 0.0484618531273944, 0.027582071921122924, 0.04825872349153672, 0.010457060931782638, 0.05527243124587195, 0.02423227684838431, 0.06916176487824746, 0.05652868115742292, 0.0748075358569622, 0.04593971471435257, 0.04233915006209697, 0.05220652843958565, 0.08479110657104424, 0.029939675770167793, 0.05124081025964447, 0.06846292809184108, 0.01925787895119616, 0.024890393051984053, 0.02939710220588105, 0.03157870764178889, 0.04879734458933983, 0.014691660579826151, 0.019507780005889278, 0.0254948150832206, 0.6985209690673011, 27.160167830330984, 78.8445098059518, 78.00766181945801, 23.905761889048986, 61.593334742954795, 75.02694715772355, 36.187250069209504, 23.859460830688477, 20.30676177569798, 41.398958342415945, 32.53207377025059, 43.21018695831299, 40.362193311963765, 32.02100249699184, 12.647777233804975, 2.751674460513251, 0.08102086745202541, 0.1014449004349964, 0.03323219570198229, 0.12049476429820061, 0.7224509449941772, 1.8838518389633723, 2.1013775723321095, 5.731737511498587, 7.794536079679217, 8.685190047536578, 8.467772228377205, 7.6143857921872815, 9.458929283278328, 5.066432731492179, 4.232957661151886, 2.1845620572566986, 2.866554456097739, 0.705916132245745, 4.313035649912698, 1.2937606573104858, 1.8299833238124847, 5.310302342687335, 7.993525539125715, 8.702105437006269, 11.06074787889208, 10.688195892742701, 14.506282261439733, 11.882400155067444, 9.977810331753322, 8.159422465733119, 4.206113730158124, 2.380303668124335, 1.3346850041832243, 1.4729238663400923, 1.4923178085259028, 3.403820655175618, 2.7996183335781097, 2.46624202813421, 1.8193158847945077, 3.6958593044962202, 4.351895187582288, 4.632199849401202, 5.8887494291578015, 5.390927067824772, 4.317206306116922, 4.045839198998042, 5.1702666112354825, 6.350523233413696, 2.948216417006084, 3.2034498069967543, 3.0785168537071774, 2.8725340323788777, 4.002922347613743, 2.0028712238584245, 2.1803190963608876, 2.9581788309982846, 2.292185962200165, 0.5431685852152961, 0.23117674514651299, 0.21784893316881998, 0.11275259152586971, 0.11462068664176123, 7.86209602015359, 27.038471869059972, 54.15323148454939, 83.85231971740723, 67.0743864604405, 34.14668921061924, 102.92570849827358, 128.10582733154297, 35.50419698442732, 51.15656723294939, 69.04044873373849, 84.18799413953508, 62.70531054905483, 72.86004720415387, 67.65316445486886, 35.44390399115426, 0.695933362202985, 0.09463208993630749, 0.16739396484834806, 0.047083880818848095, 0.00843660586646625, 0.059639482625893185, 0.03604647397462811, 0.12706994504800864, 0.029296248153384243, 0.08284408426178352, 0.007096464853800301, 0.03501046635210514, 0.030082904334579195, 0.010616752452083995, 0.04585743895066636, 0.028165700246712992, 0.037515756740633927, 0.03797376109287143, 0.03861270359318171, 0.023931036137842705, 0.013202232109116656, 0.015387367623459016, 0.06376511803162949, 0.0548945754500372, 0.0191096597617226, 0.04803630989044905, 0.04874306857319815, 0.035305717294769626, 0.03396617042432938, 0.04633169421660049, 0.06252240150102548, 0.04071872701336231, 0.07185443610485111, 0.04637461494920509, 0.05293521737413747, 0.029993721084403138, 0.04156226817784565, 0.007229702414146492, 0.04193999844470194, 0.06802666400160108, 0.02367409528233111, 0.011627785745076835, 0.05763464913304363, 0.009289913694374263, 0.13012617533760412, 0.14910372772387095, 0.13126876045550617, 0.10737849239792142, 0.1312479565718344, 0.1599383849118437, 0.09933213916208063, 0.18126806536955492, 0.16774859439049447, 0.1644842302692788, 0.1520309006529195, 0.12790666015020438, 0.12517622166446277, 0.18772307756756032, 0.1831298161830221, 0.16947174764105252, 0.13941840029188565, 0.12976568325289659, 0.15988691124532903, 0.15933470587645257, 0.13036116558526242, 0.19365200799490723, 0.18690260659371102, 0.08785463111209017, 0.24349394706743105, 0.1365999829556261, 0.2743495942226478, 0.1312213172870023, 0.1511149869433471, 0.1734796232943024, 0.16239385386662825, 0.1688573613230671, 0.1583507758166109, 0.13061849320573465, 0.12886354380420276, 0.16568426016185964, 0.13439136504062585, 1.6982984585421426, 35.5671580859593, 93.82940483093262, 86.90493433816093, 32.6925493649074, 61.213462829589844, 72.79783303397042, 31.42205388205392, 23.13811101232256, 28.42454195022583, 59.29051412854876, 49.2827353477478, 73.02703326089042, 59.60797037397112, 45.060791015625, 15.653657402311053, 3.664446064404079, 0.2151759530284575, 0.22555044133748325, 0.3052441621465342, 0.27661568405372755, 0.933670482465199, 2.762381851673126, 2.836068583386285, 7.3945265497480115, 15.705183506011963, 22.022480453763688, 20.274548189980642, 22.411576100758143, 23.368009533200944, 21.716813564300537, 22.484674624034337, 26.253398384366715, 20.258044481277466, 20.375271013804845, 16.659164224352153, 16.566572529929026, 16.076356274741038, 20.031218801225933, 25.900707823889597, 28.714264460972377, 22.76464707510812, 22.82626370021275, 25.578525066375732, 24.082207918167114, 17.155538320541382, 30.763649531773158, 22.74257264818464, 16.88176713671003, 20.793642895562307, 13.9959249155862, 15.405677931649343, 14.15084629399436, 10.485652429716927, 8.93830076285771, 11.408664158412389, 11.389822380883352, 10.67099562713078, 8.898228764533997, 15.686336517333984, 14.54352981703622, 17.074251345225743, 15.504778351102557, 14.12440926688058, 13.859017610549927, 8.984153662409101, 10.67492309638432, 8.412722519465856, 8.172336561339241, 6.174613518374307, 4.69049870967865, 5.391052135399409, 5.474968135356903, 4.517870281423841, 0.6965611428022385, 0.7563795415418488, 0.4191572181880474, 0.5072432500975472, 0.27504237847668783, 13.422776699066162, 35.26696463993618, 78.19164316994804, 120.51364190237862, 106.0427885055542, 72.70187841142926, 107.07624271937779, 135.72479111807687, 58.6583948135376, 53.16902262823922, 72.00215312412807, 91.50256429399762, 73.46319947923932, 82.80259977068219, 79.52848352704729, 34.171654088156565, 0.6478988911424364, 0.14136297308972903, 0.23282954788633756, 0.2751670389303139, 0.16432706798825944, 0.11175965730633054, 0.22079525435609476, 0.2778985766427857, 0.17859469167888165, 0.17074382438191346, 0.13284978776105813, 0.11459748074412346, 0.07566603871860675, 0.11889490086053099, 0.2589573258800166, 0.13456349580415658, 0.16669249534606934, 0.1900183851165431, 0.08925421815365553, 0.15023936464318208, 0.09465638148997511, 0.13431254641285964, 0.14792846435947077, 0.10377737813230072, 0.146514017400997, 0.10929271432438067, 0.13307953971837247, 0.09206289851239749, 0.11111912024872643, 0.12504744928862366, 0.11552704657827105, 0.10483791479574782, 0.16947429893272264, 0.11273619133446898, 0.14135962112673692, 0.14513055235147476, 0.12209171003529004, 0.06292594663266625, 0.1470479837485722, 0.11571116027023111, 0.09040806016751698, 0.08875234651246242, 0.16897272584693773, 0.14434764507625783], [0.005389305097716195, 0.02459104884681957, 0.03736359526270202, 0.10884541046938725, 0.016930625973535434, 0.13558440602251462, 0.06923050726098673, 0.009366221742571464, 0.020541806306157793, 0.03297966193141682, 0.009859411528200974, 0.01652201048896781, 0.03971203210364495, 0.025344083617840494, 0.037756453467799087, 0.10125078513686146, 0.08372143682624612, 0.015486708542864238, 0.03752550728885191, 0.04153380702648844, 0.052615009913487096, 0.07852781444255795, 0.015449718206322618, 0.016357134961123978, 0.09228004328906536, 0.06961772005472865, 0.08710964037371532, 0.0337126358146114, 0.015120414983747261, 0.03618129888283355, 0.031416636159909625, 0.031079872444804226, 0.04652935146753277, 0.04747153466035213, 0.0507240549528173, 0.1706905865243503, 4.223145936216627, 36.897807598114014, 89.0593066896711, 80.92776039668492, 79.25889342171806, 44.120039667402, 21.785955088479177, 9.43608968598502, 28.202682495117188, 63.359643254961284, 55.118951184409006, 33.50439773287092, 43.533604758126394, 41.661746161324636, 21.499090024403163, 5.60838440486363, 1.2454971671104431, 0.08239174567695175, 0.11384350620210171, 0.07566257819001164, 0.25579841967139927, 0.09034488177193062, 1.2701753228902817, 0.9908803211791175, 8.628146205629621, 9.607135227748326, 5.308897938047137, 6.796779104641505, 7.7903463159288675, 8.77359892640795, 6.915067843028477, 4.998776384762355, 1.5036223105021884, 4.255665676934378, 2.334715234381812, 4.058137076241629, 3.5350078557218825, 3.1174156921250478, 3.8740884150777544, 3.9043404374803816, 6.428692638874054, 12.797435351780482, 12.11977059500558, 9.591673748833792, 6.665743461677006, 4.8346238902636935, 5.9141720192773, 3.551088375704629, 3.8800317304474965, 4.945246594292777, 9.417454617364065, 19.898513419287546, 34.15421410969326, 21.134500673839025, 14.380228042602539, 10.230333924293518, 14.35384486402784, 13.504877482141767, 19.411521128245763, 21.507389647620066, 15.260856628417969, 19.27005406788417, 14.25213713305337, 13.301275287355695, 5.561837988240378, 2.161635390349797, 4.09883918932506, 3.6120342825140273, 2.566757491656712, 2.9583796773638045, 4.4962696347917825, 2.954782030412129, 1.7838721466915948, 3.2789270026343207, 1.4498546527964729, 0.8994254714676312, 0.3964705084051405, 0.11271959436791283, 0.025326884451455305, 0.16051846449928625, 0.05736062955111265, 4.654595630509513, 21.054905584880284, 34.57700504575457, 38.11691420418875, 53.47238097872053, 24.57536152430943, 24.733724866594585, 38.93156269618443, 18.946844714028494, 29.864882673536027, 44.19605295998709, 56.03696802684239, 59.00786140986851, 61.96816921234131, 71.53392791748047, 31.182448727743967, 0.6705514841846058, 0.15253322012722492, 0.028187722100743225, 0.08720684051513672, 0.1210742603455271, 0.029016433882394006, 0.27089750660317286, 0.06786056541438613, 0.0483248026243278, 0.021410555046583925, 0.08979705295392446, 0.04763155696647508, 0.03760642258982573, 0.020763897603111606, 0.04198182334325143, 0.010916614888368972, 0.1161676107772759, 0.1513117485280548, 0.147374101249235, 0.11624181536691529, 0.12804580054112844, 0.05928853752889803, 0.10694095944719655, 0.023690488688381653, 0.0503584297506937, 0.03770089502047215, 0.007604628635038222, 0.02785991844055908, 0.08956155380500214, 0.06588636099227838, 0.12620116238083157, 0.1294074167630502, 0.16433268625821384, 0.1354046349546739, 0.0661992606307779, 0.03329321635620935, 0.11854428824569498, 0.17396990555737699, 0.025285877187603285, 0.13001211360096931, 0.02033751637541822, 0.10428431843008314, 0.042227341061724086, 0.025489013608811156, 0.027564502953152572, 0.019738395399014865, 0.08053532814873116, 0.09630525551204171, 0.15260409989527293, 0.03472968177603824, 0.03401205296229039, 0.0467070055061153, 0.055015917867422104, 0.021662708837538958, 0.03424079390242696, 0.02715376704665167, 0.04699467721262148, 0.027424645011446307, 0.09627529819096838, 0.10620356151568038, 0.10187804326415062, 0.02605562936514616, 0.09464312970106091, 0.03346442770478981, 0.09462782195104019, 0.01229426489278142, 0.009933548264338501, 0.05435751837545207, 0.08270726446062326, 0.0791286707722715, 0.06558602103697402, 0.04052908326100026, 0.049931699077465704, 0.043141931628010104, 0.10012632368930749, 0.05779643902289016, 0.09005161215152059, 0.03800723661801644, 0.08402334419744355, 7.0774520209857394, 51.7874984060015, 101.83706474304199, 89.94263812473842, 91.81535134996686, 52.639048780713765, 26.35215139389038, 13.937979544912066, 21.539591073989868, 38.41194861275809, 31.616193498883927, 30.686708654676163, 40.02864851270403, 37.574228627341135, 23.416315146854945, 7.980984040669032, 1.3273901556219374, 0.0917768417192357, 0.014051911471012448, 0.05791383915181671, 0.07061203170035567, 0.2467005949999605, 0.5126608908176422, 0.44369195880634443, 2.130844448293958, 3.9916241424424306, 3.9245879224368503, 7.0986670425959995, 7.609890307698931, 2.5180521394525255, 2.8059322919164384, 0.5680252771292413, 0.7961805601205144, 2.1855565181800296, 1.6545541201319014, 2.512636887175696, 2.818444694791521, 1.889298792396273, 3.541527654443468, 4.058600868497576, 3.0178460521357398, 5.622121862002781, 3.9878686411040167, 5.344454475811549, 7.085985711642674, 6.415472388267517, 4.204552122524806, 0.4732439230595316, 2.6735667203153883, 4.652697469506945, 9.958195567131042, 17.887465034212383, 28.9821001461574, 21.617299727031163, 16.07032697541373, 12.045565571103777, 16.204256977353776, 16.763154438563756, 20.673336574009486, 21.62127583367484, 18.843988793236868, 20.155730519975933, 16.18547773361206, 13.831122330256871, 5.618307735238757, 2.505950548819133, 2.129343420267105, 3.3019557212080275, 1.4331169852188654, 1.4565186266388213, 2.521208792924881, 2.205776644604547, 3.2844590714999606, 3.98230356829507, 2.6760320280279433, 1.2705275097063609, 0.4108847363718918, 0.2655304031712668, 0.13612565983619007, 0.2609732805618218, 0.05876622162759304, 3.8790733133043562, 20.43383390562875, 42.03267226900373, 45.53394249507359, 42.99050923756191, 30.555022920880997, 39.136378220149446, 41.1912384714399, 20.31261042186192, 52.04365416935512, 58.35835770198277, 65.97982978820801, 70.73330089024135, 69.24054990495954, 82.94407899039132, 51.53460482188633, 1.3296604795115334, 0.5503870035920824, 0.03776364254632166, 0.05383196246943303, 0.06382547372153827, 0.07147010708493845, 0.26128250254052027, 0.04120435452620898, 0.07218003791889974, 0.02092788933909365, 0.059012346634907384, 0.05756208659814937, 0.13593290160809243, 0.03288436847339783, 0.06599215138703585, 0.07434651202389173, 0.04696600910808359, 0.051511793397367, 0.07475093246570655, 0.06328901715044465, 0.07661235758236476, 0.06746160039412123, 0.017040686049897755, 0.0077042248532442105, 0.05077076869617615, 0.04414155620283314, 0.03370439500680991, 0.09974996745586395, 0.06122381439698594, 0.09671460211809192, 0.13303585563387188, 0.19888729921409062, 0.09662470301347119, 0.043931505509785244, 0.026083601971289942, 0.03923454361834696, 0.0643695570262415, 0.1153997534087726, 0.010179166914895177, 0.06249509725187506, 0.021636620862409472, 0.04938058275729418, 0.07422172943396227, 0.24036720341869763, 0.20250933271433624, 0.1484683339617082, 0.16347235813736916, 0.2358535070504461, 0.26348869130015373, 0.175764155707189, 0.12688916974834033, 0.09253194941473858, 0.1550485494413546, 0.11475392377802304, 0.07237784444753613, 0.11085310059466533, 0.20859117779348577, 0.12601175611572607, 0.20970515587500163, 0.20800245366990566, 0.1686815528997353, 0.11708653718233109, 0.16857601356293472, 0.17585089962397302, 0.13548999466001987, 0.1944834440946579, 0.09270547117505755, 0.15639894269406796, 0.13640501270336763, 0.1870015234287296, 0.16025200379746302, 0.09604635369032621, 0.13336288237145968, 0.18722419148044928, 0.12133124869849, 0.1594201877181019, 0.19292636907526425, 0.23969729936548642, 0.20475372299551964, 9.56283698763166, 64.73820059640067, 115.55824225289481, 97.49953365325928, 100.11184092930385, 64.21901035308838, 36.5846175466265, 18.44587438447135, 43.174125807625906, 86.990647315979, 80.67945262363979, 48.89177758353097, 59.61379991258894, 60.365428243364605, 35.80648878642491, 10.251112512179784, 3.1908972348485674, 0.25541154614516665, 0.3457614422908851, 0.21398200280964375, 0.7805964563574109, 0.6790617789540971, 3.2343375895704543, 5.820555899824415, 19.071062871388026, 19.673438685280935, 16.66663180078779, 21.389803545815603, 20.010198763438634, 22.325776270457677, 20.57790306636265, 15.473787648337227, 9.172381230763026, 12.334520305906024, 8.201842955180577, 12.237133485930306, 11.088000450815473, 10.117094789232526, 13.439158814293997, 14.285166263580322, 15.320633717945643, 26.637246404375347, 24.868980237415858, 20.508330753871373, 20.002844095230103, 17.02389427593776, 15.847084828785487, 13.63887870311737, 12.36680337360927, 7.445417761802673, 9.71003544330597, 18.321958473750524, 34.270037106105256, 23.746319838932582, 19.97211742401123, 16.476984194346837, 19.840205873761857, 19.471701213291713, 25.55608238492693, 28.465173278536113, 23.36937138012477, 28.396438223975046, 24.746961184910365, 26.7399286202022, 12.058747172355652, 9.890010288783483, 13.4953019959586, 10.74544210093362, 7.018691539764404, 9.626695275306702, 11.234553592545645, 10.17484039919717, 6.655814051628113, 10.629890084266663, 4.695540930543627, 2.367964970214026, 0.8530357692922864, 0.7087573483586311, 0.21929342565791948, 0.42257369628974367, 0.2288480672453131, 8.284981625420706, 30.461965697152273, 48.10086761202131, 54.73140498570034, 71.82732255118233, 36.73648084912981, 34.3808400290353, 49.12895086833409, 29.903243677956716, 45.174915177481516, 58.92300306047712, 76.13464982169015, 80.22976521083287, 79.61931732722691, 93.63887132917131, 55.43580641065325, 1.5689587188618523, 0.7658018959420068, 0.1265436461461442, 0.17547347130520002, 0.15770353483302252, 0.18458851719541208, 0.366132203489542, 0.16636686639061996, 0.15053254605403968, 0.09575650388641016, 0.19548912798719748, 0.1722154039889574, 0.3310807671930109, 0.14518558154148714, 0.10211160180291959, 0.15178717087422097, 0.18640507757663727, 0.19275740028492042, 0.14359715820423194, 0.21718566518809113, 0.20056748762726784, 0.1359035481831857, 0.26676777963127407, 0.1519560989524637, 0.127988477902753, 0.16242185022149766, 0.18538378737866879, 0.27429764558162006, 0.13232154824904033, 0.23908713353531702, 0.21086688925112995, 0.30739129121814457, 0.22534266034407274, 0.2645377335803849, 0.14903028309345245, 0.1532956220741783, 0.15957440515714033, 0.25933616555162836, 0.08923390960054738, 0.26168196967669893, 0.11545182418610368, 0.17175676859915257, 0.21638998788382324], [0.14917354897728988, 0.10277757713837282, 0.07618108072451182, 0.20524000190198421, 0.1858651265501976, 0.08947362923728568, 0.15415878647140094, 0.057420272779251845, 0.032707908656448126, 0.237507341163499, 0.03340436378493905, 0.054518989353839836, 0.052800996362098625, 0.0597587080140199, 0.08411812875419855, 0.15811433350401266, 0.17786665074527264, 0.012278524576686323, 0.010990777069569697, 0.05709287963275399, 0.05176516515868051, 0.0757798697533352, 0.06887163008962359, 0.33842485025525093, 0.03901243535801768, 0.034128801697599034, 0.050082442417208634, 0.10090606220598732, 0.1335876945938383, 0.09357389421867472, 0.05704046958791358, 0.16822449171117373, 0.12385652533599309, 0.02510943094135395, 0.26780409259455545, 9.638808591025215, 72.70813873835972, 84.9705627986363, 73.80095836094448, 69.84209019797188, 84.74966566903251, 64.06953375680106, 49.665035656520296, 50.63146754673549, 46.43942478724888, 50.654184682028635, 50.77708441870553, 58.760693141392295, 30.67637668337141, 12.218507971082415, 2.466174283197948, 0.3030403346887657, 0.2968731570456709, 0.16009896700935705, 0.24857112605656895, 0.13490023916321142, 0.26963288017681664, 0.20252905094197818, 0.8088760046022279, 1.129962520939963, 1.6696679719856806, 3.6716205137116567, 1.7330816835165024, 2.1128219068050385, 3.373818550791059, 4.072079939501626, 5.1085978746414185, 5.957418475832258, 4.482279436928885, 7.381105235644749, 7.799019404820033, 15.376417330333165, 11.58166127545493, 14.612285716193062, 13.953683342252459, 14.077999642917089, 7.289389882768903, 6.964313634804316, 8.024524058614459, 9.015186922890798, 12.441087433270045, 7.227410648550306, 5.804070864404951, 9.14785669531141, 31.872773102351598, 62.57392011369978, 91.82225091116769, 109.09713322775704, 107.51957253047398, 115.34697532653809, 77.82179750714982, 41.15647663388933, 36.5405729157584, 43.4407525062561, 49.29581185749599, 53.94448675428118, 53.383958203451975, 52.45626252038138, 36.81814997536795, 29.143593651907786, 20.248438596725464, 9.955839259283882, 2.621166446379253, 0.6506125426718167, 1.0065305956772395, 0.4883372560143471, 1.1363248995372226, 1.2503233424254825, 1.594584760921342, 2.0828860274383, 1.4366426531757628, 0.8386815509625843, 0.35991633417350904, 0.29116130354149, 0.3676548632127898, 0.10757140668907336, 0.015952176780306866, 0.0881670354200261, 0.7595773956605366, 8.653048549379621, 32.4444465637207, 34.20546749659947, 32.03629895618984, 29.008902822222026, 30.26094388961792, 36.1236184665135, 15.683743102209908, 18.65221503802708, 37.54477521351406, 54.08413512366158, 59.1618960244315, 55.88735941478184, 65.7800760269165, 41.74611813681466, 3.8060273357800076, 0.23022896743246488, 0.04635867955429213, 0.04788902707930122, 0.1232664305716753, 0.185562594926783, 0.11958810580628258, 0.13599394261837006, 0.20264307196651185, 0.11820331082812377, 0.11941608360835484, 0.12311072035559587, 0.031517822694565566, 0.2231765322919403, 0.1258151845208236, 0.1362986048417432, 0.12233079863446099, 0.407715733562197, 0.27309533581137657, 0.41972251928278376, 0.16049236804246902, 0.26134120939033373, 0.07360216589378459, 0.01670266704500786, 0.034385827369987965, 0.05825688610119479, 0.113908319867083, 0.13912789230900152, 0.1787906525922673, 0.3191856140536921, 0.44246367471558706, 0.35798975612436024, 0.08825673096414123, 0.024262120514842014, 0.0572985028848052, 0.06661635610674109, 0.05304867182193058, 0.239608139864036, 0.23584357329777308, 0.17327389147664818, 0.28071642400962965, 0.11380727921745606, 0.04746885444702847, 0.06457602844706603, 0.11060562530266387, 0.1282426164086376, 0.17373175333653176, 0.14497712201305799, 0.1380874809942075, 0.04557513106348259, 0.03911229196403708, 0.09740946268928902, 0.06058067176491022, 0.01355425438045391, 0.048653749616018364, 0.04759372863918543, 0.16670791166169302, 0.18179242366126605, 0.1424122325011662, 0.08587379061750003, 0.05781711398490837, 0.0748539747936385, 0.03197260739813958, 0.06887142652911799, 0.004389669496699103, 0.10474204458296299, 0.012085318515476371, 0.012423078828890408, 0.042799956763961484, 0.08746996282466821, 0.13191307016781398, 0.11706680538398878, 0.018537351096581136, 0.15153523082179682, 0.07516637231622424, 0.019406467942254882, 0.11754353051739079, 20.759089503969463, 91.70125498090471, 97.68168762751988, 82.67545468466622, 75.53784125191825, 91.02059555053711, 87.80746364593506, 60.9631678717477, 28.510343517575944, 35.82741328648159, 44.37057433809553, 51.28781523023333, 52.79892683029175, 33.069030557359966, 15.061599663325719, 3.475511733974729, 0.33875296264886856, 0.1531711516103574, 0.04374616706211652, 0.3821452499500343, 0.16790108835058554, 0.5732552622045789, 0.510307351393359, 0.8824242608887809, 0.5740203240088054, 2.382407018116542, 3.9626058595521108, 0.5031277995024408, 0.20334682134645327, 0.46051732024976183, 4.45514976126807, 5.36365191425596, 8.145804865019661, 6.976621500083378, 9.996425424303327, 11.813636439187185, 18.56485707419259, 15.978655917303902, 19.545319114412578, 17.8512909752982, 17.13141938618251, 10.12801388331822, 7.773130416870117, 6.972684911319187, 5.2029174992016385, 3.5370910125119344, 2.5268218517303467, 3.319899878331593, 8.922134910311017, 31.734663758959087, 63.79888752528599, 92.68870517185756, 113.7784959248134, 114.87890992845807, 120.0413589477539, 80.3310352052961, 46.26297180993216, 45.14570495060512, 52.07939222880772, 56.791778632572715, 61.04257188524519, 59.1794193812779, 54.66723142351423, 42.018824509211946, 32.6403614452907, 23.289580004555837, 10.994314415114266, 4.295124062470027, 1.6110859726156508, 1.4604789912700653, 0.894898068692003, 0.6723655068448612, 1.3110508152416773, 0.275442225592477, 1.8495546621935708, 1.4880832071815218, 0.9916572166340691, 0.6605581289955548, 0.4604914273534502, 0.22526058474821703, 0.2416218960923808, 0.18764500532831463, 0.05503538164443203, 0.8670541942119598, 7.654167703219822, 29.93064389910017, 31.605628762926372, 24.468114342008317, 20.903693675994873, 29.54522384916033, 28.533656460898264, 21.569548232214792, 34.4006667137146, 57.222143105098176, 65.36478914533342, 71.05267483847481, 67.38060052054269, 76.93608283996582, 67.56797259194511, 12.131450516836983, 0.09692394374204533, 0.055810224530952315, 0.056013930921575854, 0.1468509371791567, 0.15256311638014658, 0.21854219239737305, 0.10357317301843848, 0.19118918372052057, 0.029792945965060165, 0.09660423839730875, 0.12286491425974028, 0.218813009294016, 0.1905510758182832, 0.2116368907902922, 0.2724965422281197, 0.2498676979116031, 0.41189219802618027, 0.18518697151115962, 0.39656197492565426, 0.1416722900633301, 0.18703311601919786, 0.08099864543016468, 0.04875350444178496, 0.049728030006268194, 0.022910748475364277, 0.11024233086832932, 0.16032524486737593, 0.1909401613686766, 0.2476949202162879, 0.3521548163677965, 0.31917440465518404, 0.13433020189404488, 0.09068064804055861, 0.012289179272816649, 0.06069721693971327, 0.08561786077916622, 0.13978178293577262, 0.10500245275241987, 0.05970558550740991, 0.17984299255268915, 0.1183051589344229, 0.17172195975269589, 0.1608636352632727, 0.1690230324332203, 0.2761370725929737, 0.40680304967931336, 0.36779624276927536, 0.2959492366228785, 0.1544009284781558, 0.15322592295706272, 0.3841872603765556, 0.149925827181765, 0.15516223119837896, 0.12921068231974328, 0.2591814867087773, 0.2658401408365795, 0.3153392161641802, 0.24357070294874056, 0.22389982348041876, 0.10418977136058466, 0.15779748479170458, 0.11764274590781756, 0.1089639166103942, 0.1206030584871769, 0.3975311672048909, 0.19769936081554207, 0.17639545111783914, 0.11444470179932457, 0.2322029343673161, 0.21516931695597513, 0.36728937711034504, 0.25512490581188885, 0.4217756305422102, 0.23111309856176376, 0.08115282894245215, 0.2411255341555391, 28.23930471284049, 109.19456086839948, 105.30802345275879, 91.316741670881, 87.04470430101667, 102.24227673666817, 83.87726375034877, 74.25508567265102, 71.66851452418736, 72.19319384438651, 80.51024314335415, 68.17053427015031, 82.60383265359062, 47.07315261023385, 21.222720214298793, 5.332446685859135, 0.9112057621989931, 0.39799745646970613, 0.6788072468979018, 0.7593957111239433, 0.5840771357928003, 1.128446836556707, 1.5732666019882475, 2.368366662945066, 4.115867487021855, 7.406452264104571, 11.510151284081594, 9.22089615889958, 11.519249081611633, 11.09897860458919, 14.044799412999835, 11.860873767307826, 11.533016068594796, 5.570192762783595, 9.268532139914376, 10.12238323688507, 21.35818576812744, 16.020980869020732, 18.596328939710343, 18.413365500313894, 20.18356326648167, 12.247574891362872, 13.171833821705409, 15.62685820034572, 23.3711952822549, 23.271299294063024, 20.27581971032279, 16.24232268333435, 14.665434224264962, 31.9641558102199, 56.525777271815706, 87.35831819261823, 105.36938299451555, 107.31365571703229, 112.01971231188092, 84.01057883671352, 51.45658697400774, 45.79255097252982, 53.229492800576345, 57.07037360327584, 62.20905630929129, 61.527743748256135, 59.68331663949149, 43.882605825151714, 36.348979813711985, 27.895186492374965, 18.36404892376491, 10.080313631466456, 5.739978075027466, 4.748379809515817, 5.9038621953555515, 6.154628762177058, 5.870731447424207, 5.348638594150543, 6.110429099627903, 5.215213639395578, 2.0121555370943884, 1.4472403930766242, 0.8869146970765931, 0.6036901090826307, 0.5478663817048073, 0.38113024298633846, 0.1727693464074816, 1.4490184805222919, 15.433171953473773, 47.64933892658779, 51.57901423318045, 46.4279602595738, 39.99371991838728, 42.49120126451765, 54.03606053761074, 23.841647386550903, 28.118452957698278, 51.29417978014265, 65.15072904314313, 77.40887301308769, 73.25858892713273, 90.84784943716866, 74.85178307124546, 11.140902297837393, 0.3534612948341029, 0.1569505373814276, 0.21958221016185625, 0.3703304353569235, 0.2775486154215676, 0.27064161747694016, 0.23314498524580682, 0.31282888086778776, 0.2640602620584624, 0.31167059444955414, 0.2465750388801098, 0.35363030433654785, 0.4192927080605711, 0.49084229873759405, 0.3637073907469, 0.36671292089990204, 0.5110014112932342, 0.5697950050234795, 0.6592535504273006, 0.34443325070398195, 0.4706663585134915, 0.23372686973639897, 0.10166699173195021, 0.1089892191812396, 0.14723375306597777, 0.2634846200900418, 0.24288768959896906, 0.5300457722374371, 0.4918110838958195, 0.6024380762662206, 0.46707023148025784, 0.21998283080756664, 0.15314880066684314, 0.21570804661938123, 0.24097042105027608, 0.19790255491222652, 0.3217752022402627, 0.23459354894501822, 0.14441597355263575, 0.4092932731977531, 0.22306253840880735], [0.1557116410029786, 0.22006345433848246, 0.2172313170241458, 0.19190528243780136, 0.25171719438263346, 0.22236534367714608, 0.0474295299500227, 0.06727011781185865, 0.1400289868137666, 0.109882938010352, 0.278580015791314, 0.01778508646280638, 0.11234225425869226, 0.06843866367957421, 0.06388742396874086, 0.11015434523246118, 0.1907972754644496, 0.11461167569671359, 0.04069883915196572, 0.01822225809363382, 0.0772413799007024, 0.15028038887040956, 0.6025440362947327, 0.4411756252603871, 0.15572385463331426, 0.04627010698563286, 0.1563118595097746, 0.2242012694478035, 0.10284830762871675, 0.04563010936336858, 0.07716450188308954, 0.03563584154471755, 0.028472231834062507, 0.41193147163305965, 24.982496431895665, 87.19372231619698, 76.85886750902448, 80.8726611818586, 84.57944869995117, 79.88118798392159, 41.477139472961426, 23.21925207546779, 23.814808232443674, 26.204764468329294, 37.12757410321917, 43.13072388512747, 38.53530693054199, 22.648976939065115, 5.984570733138493, 1.2533833725111825, 0.19645515829324722, 0.08092074282467365, 3.381046414375305, 0.14714299222188337, 0.11950964001672608, 0.19339655313108647, 0.17303002599094594, 0.3605772815644741, 0.2622897470636027, 0.6043738552502224, 0.32024814561009407, 0.7611403603638921, 1.2299855308873313, 1.7038959924663817, 10.623261502810887, 18.557530198778423, 27.889645303998673, 35.5733767236982, 45.84741742270333, 45.98961230686733, 51.64554670878819, 59.65546825953892, 56.64269808360508, 54.33930424281529, 57.5967378616333, 55.664485522678916, 47.184688568115234, 37.69197627476284, 23.469800642558507, 20.714271886008127, 20.448088135038102, 26.144982167652675, 39.17519780567714, 55.444988455091206, 97.26725537436349, 95.54605456760952, 79.46650559561593, 79.73198236737932, 81.76716532026018, 83.5915538242885, 77.65444319588798, 51.469660009656636, 60.05193247113909, 72.14691189357212, 74.76333250318254, 77.96150493621826, 73.77200521741594, 77.56430421556745, 67.0587043762207, 61.00403717585972, 47.1149251801627, 24.47967267036438, 15.917803594044276, 12.111811433519636, 7.480817965098789, 2.1545629927090237, 0.3204247275633471, 0.8003229349851608, 0.8733805290290287, 1.1151575382266725, 3.584736547299794, 0.653322231556688, 0.18308915836470468, 0.17569124033408506, 0.2239539705749069, 0.47290156143052237, 0.1586008702537843, 0.14020570447402342, 0.05702031709785972, 0.3458846913916724, 3.217164682490485, 21.54013303347996, 47.584755420684814, 59.88282026563372, 75.83721828460693, 51.62373978751046, 45.187571321214946, 25.102413654327393, 12.135566455977303, 28.319043976919993, 54.034573623112266, 51.70258447102138, 54.7434218951634, 60.214075633457725, 62.936588287353516, 14.885249171938215, 0.24547486220087322, 0.0215847468602338, 0.07488932646811008, 0.0952439181772726, 0.18023688213101455, 0.07347139862499066, 0.10063278222722666, 0.0529918309434184, 0.08719857595860958, 0.10860961276505675, 0.13384867273271084, 0.17459130792745522, 0.13347154296934605, 0.15167878169034207, 0.24945609856929096, 0.5086472204753331, 0.3592141589948109, 0.32785001769661903, 0.22423062287271023, 0.1870006684746061, 0.05192524853295513, 0.04224143423406141, 0.06096460723451205, 0.042544356015111716, 0.0245177619757929, 0.12874500373644487, 0.10581269820353814, 0.18724120913871697, 0.20069982909730502, 0.18718073809785502, 0.02066398841062827, 0.10534330124833755, 0.0466727157389479, 0.21894273161888123, 0.14454664582652704, 0.36323461468730656, 0.20828305504151753, 0.24145459649818285, 0.49680070472615107, 0.2946789919265679, 0.19198104765798363, 0.13284921779164247, 0.12264297902584076, 0.2333352193236351, 0.3605738346065794, 0.1925002219421523, 0.11609203554689884, 0.036727214232087135, 0.05926102971924203, 0.13226727901824883, 0.3041202096002442, 0.07951537466474942, 0.01861588134696441, 0.041907571256160736, 0.08716335999114172, 0.052695094009063075, 0.1547431679708617, 0.07068587666643517, 0.04712388724354761, 0.025468745767804127, 0.10021245013922453, 0.13073080432202133, 0.3013545551470348, 0.2605708007301603, 0.09012652920292956, 0.087905019122575, 0.11925193241664342, 0.13185890950262547, 0.10310500421162162, 0.08486370981803962, 0.1176463964262179, 0.046971281325178485, 0.0640820481681398, 0.5420848290835107, 43.17499085835048, 107.5381589617048, 85.58251844133649, 90.65262590135846, 92.65125438145229, 100.94759804861886, 68.82943889072963, 41.8655298777989, 38.1942754473005, 38.72693477358137, 43.091341495513916, 47.46707378114973, 36.89863443374634, 27.792064802987234, 7.384035638400486, 1.1475561197314943, 0.05083628464490175, 0.14666861481964588, 3.163144609757832, 0.15565783317599977, 0.10770195682666131, 0.2626708394714764, 0.23582878123436654, 0.538539456469672, 0.28884570779544966, 0.6431020285402025, 0.47380124458244866, 1.482951202562877, 1.1219771951436996, 3.9210452096802846, 12.168934311185565, 23.03959945269993, 32.47645691462925, 42.39663975579398, 50.56673118046352, 52.23146745136806, 58.55656201498849, 69.63160146985734, 65.22242750440324, 61.816566467285156, 63.692413330078125, 63.74758202689034, 55.57962022508894, 42.05681378500802, 26.544355937412806, 24.18288905279977, 21.276433263506206, 23.51739059175764, 39.924686091286794, 64.74913011278424, 107.68369592939104, 109.46165657043457, 95.53650774274553, 94.0551448549543, 97.21873610360282, 97.85812323434013, 87.28523703983852, 59.55028642926897, 65.76080172402519, 79.36798013959611, 80.32559476579938, 85.22868837629045, 81.63759531293596, 80.79512623378209, 69.8382339477539, 61.960533142089844, 52.82584067753383, 31.892787388392858, 20.70755124092102, 14.902701309749059, 9.93791811806815, 3.9376544441495622, 0.9386564663478306, 0.1513151004910469, 0.6479078478046826, 0.8236657338482993, 3.3969022035598755, 0.7415407406432288, 0.3548790530434677, 0.21766335384121963, 0.21716201145734104, 0.5774647848946708, 0.09713083585458142, 0.21707646176218987, 0.08594978653958865, 0.25141022514019695, 3.2333064334733144, 20.46674578530448, 42.085172857557026, 53.93922001974923, 73.07585825238908, 59.043547357831685, 36.24568094526018, 21.85074356624058, 26.43436595371791, 45.01323059626988, 67.95168685913086, 62.16676957266671, 65.44862610953194, 69.71821076529366, 87.032315662929, 35.35149989809309, 0.5604784478034291, 0.08655233920684882, 0.1597972767693656, 0.15779952039676054, 0.15557526903493063, 0.1117702695940222, 0.08519568307591335, 0.118326994191323, 0.04027300414496234, 0.07277908934546368, 0.11351423351360218, 0.1857364491692611, 0.13941424765757152, 0.1162053644657135, 0.2813617650951658, 0.4395098217896053, 0.23910979660493986, 0.20898090116679668, 0.11125902738422155, 0.13669453002512455, 0.05270686319896153, 0.03164618116404329, 0.012916446729962314, 0.025956754938566258, 0.00506768246746755, 0.055832972417452505, 0.11694693538759436, 0.28696646434920176, 0.13928004700158322, 0.14153499528765678, 0.03521155359755669, 0.03688240197620221, 0.056134879788649936, 0.024538664247042367, 0.09865653541471277, 0.2968426229698317, 0.15566837761018956, 0.1911920742797, 0.26296355947852135, 0.2545394115149975, 0.41068163727011, 0.35032285324164797, 0.39198300348860876, 0.6914348378777504, 0.684831117945058, 0.3581868569765772, 0.20628831136439527, 0.11858452537230083, 0.21906399939741406, 0.36911705189517563, 0.5829918597425733, 0.15076545998454094, 0.21426634969455854, 0.16006780868130072, 0.20392873297844613, 0.22319892394755567, 0.2636181286403111, 0.256309410823243, 0.19393142871558666, 0.17921589048845427, 0.34059048976217, 0.3518192943717752, 0.690675747181688, 0.5388956602130617, 0.2824869932872908, 0.16860341280698776, 0.38314636051654816, 0.3221209836857659, 0.28442193088786943, 0.10649210174701043, 0.20978169462510518, 0.17754289454647473, 0.14945922579084123, 1.1111523360013962, 52.85672194617135, 123.85768481663295, 93.54965645926339, 101.34287411825997, 105.00048228672573, 100.967011315482, 56.3241092818124, 34.281991481781006, 35.383902822222026, 42.58734348842076, 53.75333833694458, 61.72724042619978, 58.05663912636893, 37.01675728389195, 10.279850261551992, 2.4402787813118527, 0.3840805132474218, 0.5644052656633514, 6.4542832885469705, 0.35240128742797033, 0.6881292866809028, 0.5920550248452595, 0.5790200957230159, 1.0319271300520216, 1.0855776454721178, 0.9862281765256609, 0.9265446705477578, 4.05354996238436, 5.188444401536669, 7.122185826301575, 16.954964671816143, 24.62516621180943, 32.76907335008894, 41.2461952481951, 51.35617855616978, 50.67638070242745, 58.01092692783901, 67.44935294560024, 67.75749165671212, 65.09926373617989, 66.42397253853935, 63.820558956691194, 57.49003784997122, 44.81055859157017, 31.890435423169816, 28.885167564664567, 25.587760959352764, 31.421914918082102, 45.22008541652134, 62.783220699855256, 104.81622300829206, 107.08635234832764, 95.99825722830636, 95.82119628361293, 99.03372369493756, 98.99111039297921, 90.12445858546666, 69.22777911594936, 71.48208740779332, 84.05330330984933, 87.66159316471645, 89.20828996385846, 85.38618319375175, 87.4690168925694, 77.81453663962228, 71.8272044318063, 60.941739627293174, 33.00558655602591, 20.4338321685791, 14.797642810004097, 10.808828779629298, 4.277161232062748, 1.3756536458219801, 3.7691102538790022, 5.697054275444575, 5.298316700117929, 9.160306130136762, 2.836402314049857, 0.9313249226127351, 0.6780723663313049, 0.5012099881257329, 0.8226330035499164, 0.2883025812251227, 0.6959837909255708, 0.2629944463925702, 0.5761473955852645, 4.863090659890856, 32.59196029390608, 66.18448202950614, 80.64497566223145, 84.79170227050781, 68.09714739663261, 62.289752687726704, 35.53524153573172, 19.231816393988474, 40.99290909085955, 68.29271834237235, 69.91981969560895, 73.69302504403251, 83.51212201799665, 101.50485052381242, 37.91803591591971, 0.4679093893085207, 0.19466744922101498, 0.33909090022955624, 0.6301174738577434, 0.3620043492742947, 0.23069484957626887, 0.26691523886152674, 0.1716215637113367, 0.148381182923913, 0.22204461374453136, 0.32186593594295637, 0.4396795912512711, 0.48646053671836853, 0.23013576386230333, 0.6947363178644861, 0.7735512001173837, 0.6615538384233202, 0.625220459486757, 0.5070811616522926, 0.30713597206132753, 0.1931883514459644, 0.12405483398054327, 0.15325189727757657, 0.10895886152450528, 0.18074562054659638, 0.3946464162852083, 0.3327694780060223, 0.4375574051269463, 0.44058991383228985, 0.30091187890086857, 0.24061435301389011, 0.2000923366951091, 0.1305378425334181, 0.2601865056369986, 0.3160726310951369, 0.5932091857705797, 0.5320729634591511, 0.4013761808829648, 0.5456286817789078, 0.41384295906339374], [0.05065037962049246, 0.03068023906754596, 0.056971815414726734, 0.16733030469289847, 0.14197651802429131, 0.12433611388717379, 0.032490974225636036, 0.09657218440302781, 0.07375989135886941, 0.11990009620785713, 0.15154444532735006, 0.04824724607169628, 0.05845241275216852, 0.030320720680590187, 0.01745964919349977, 0.06743232160806656, 0.04375321025561009, 0.022475787172360078, 0.026557375477360826, 0.07580394417579685, 0.10968726208167416, 0.37142184536371914, 0.37626452265041216, 0.3117398050214563, 0.1455225556024483, 0.15587938843028887, 0.44450017543775694, 0.10000268103820936, 0.13468715202595505, 0.07256068249366113, 0.1634877880236932, 0.00573672350895192, 0.6023263079779488, 45.147414207458496, 95.58497142791748, 82.70054462977818, 78.30721950531006, 57.70427165712629, 39.83970614842006, 26.472700902393886, 14.347905022757393, 26.293211562292917, 39.98600741795131, 28.40607190132141, 34.43693283626011, 23.939116716384888, 14.823200021471296, 4.455823302268982, 0.8192699125834874, 0.039780143448816876, 0.2418851948210171, 0.4112291064645563, 0.5800623797944614, 0.17208333393292768, 0.258515545300075, 0.07731090259871312, 0.1880093514919281, 0.22944175824522972, 3.0168457286698476, 3.0062256242547716, 0.9486170347247804, 1.5305057593754359, 4.019409554345267, 23.306306055613927, 46.955241680145264, 69.04251234872001, 75.4278095790318, 84.3080312183925, 81.69580732073102, 82.40535736083984, 89.5618143081665, 91.72972175053188, 92.04250880650112, 84.33220400129045, 78.26648221697126, 77.41131183079311, 80.38290350777763, 77.35678931644985, 70.36983367374965, 61.95914350237165, 51.25073616845267, 47.058686460767476, 43.837605816977366, 73.18511172703334, 58.015724658966064, 60.79236725398472, 59.076725006103516, 64.72850091116769, 65.60985905783517, 69.42218971252441, 35.50045885358538, 34.48458705629621, 68.31946890694755, 79.71822493416923, 81.41573238372803, 81.69538348061698, 81.63690744127545, 78.73240756988525, 72.20806298937116, 75.51838629586356, 77.64470182146344, 69.35269383021763, 56.49728965759277, 49.176910809108186, 41.16029814311436, 32.34164449146816, 17.32159505571638, 4.908988288470677, 0.15103787822382791, 0.30935627434934887, 1.395941082920347, 1.5109312725918633, 0.7887231345687593, 0.11270742144967828, 0.20119019278458186, 0.17339248582720757, 0.23798554550324166, 0.02342353095965726, 0.3484473010259015, 0.06885454457785402, 0.3350707159510681, 0.1557774453290871, 10.675055980682373, 24.585467679159983, 32.66073703765869, 33.122736658368794, 52.30490296227591, 65.28830337524414, 30.21883085795811, 16.582228558404104, 15.667001417704991, 34.37643487112862, 58.66044453212193, 58.68340832846505, 54.8231976372855, 61.79891109466553, 32.14467000961304, 1.2083339669874735, 0.21530334119285854, 0.15796091673629625, 0.051056292839348316, 0.09095324948430061, 0.06438859671886478, 0.05872056979153838, 0.07897117600909301, 0.05055974769805159, 0.008076976369401174, 0.044804064224341085, 0.07146081794053316, 0.055597276493374786, 0.02864624553226999, 0.11269528924354485, 0.1054902651480266, 0.09438986650535039, 0.08717143455786364, 0.01240862179214933, 0.014521706217367734, 0.016277317190542817, 0.042303123245281835, 0.015934567100235393, 0.06570387578436307, 0.029068450376923596, 0.03228266058223588, 0.04858588254345315, 0.08792594514255013, 0.01717135832378907, 0.056897207096751244, 0.06061473422284637, 0.03838108227189098, 0.07876333394753081, 0.11357302178761788, 0.09730426940534796, 0.061345482511179786, 0.10875942651182413, 0.09053679861660514, 0.2444674548293863, 0.13174984178372792, 0.06645420659333467, 0.15920590635921272, 0.29511955114347593, 0.2284094893506595, 0.1485295242496899, 0.05731824825384787, 0.17333350756338664, 0.061525219652269564, 0.09784529251711709, 0.14872036900903496, 0.058896025376660485, 0.04430925952536719, 0.021024818066507578, 0.030642834824642966, 0.06809185086084263, 0.0350358367764524, 0.022727121632280092, 0.039538435704473934, 0.14111545708562645, 0.17501159251800605, 0.33959787445408957, 0.4397953764668533, 0.34880212055785315, 0.14140428230166435, 0.24626329275114195, 0.36591716217143194, 0.08384912354605538, 0.11093980379934822, 0.0629374138744814, 0.13203562716288225, 0.055130244232714176, 1.1412949242762156, 67.852584702628, 107.74853651864188, 91.08784021650041, 89.41590213775635, 73.41903672899518, 61.725642340523855, 40.87261492865426, 21.08032556942531, 22.040083714893886, 29.04871600014823, 29.642571585518972, 40.623219762529644, 32.44886909212385, 19.147018841334752, 5.705006054469517, 0.7483087746160371, 0.05923405795225075, 0.18265678228012153, 1.1486755396638597, 1.9078433173043388, 0.4895112301622118, 0.6587105595639774, 0.01109893894421735, 0.14620255625673703, 0.4111960753798485, 3.324396448475974, 4.006469402994428, 1.5713688752480914, 3.1085608644144873, 6.94389157635825, 27.518359627042496, 50.93122673034668, 72.52529689243862, 80.11853149959019, 88.16057109832764, 85.5046499797276, 83.8494153703962, 92.15850898197719, 95.03046349116734, 96.99611582074846, 88.88201645442417, 83.29773535047258, 83.04675946916852, 85.30385398864746, 79.44186033521379, 77.42174802507672, 67.97815254756382, 58.54639680044991, 55.09755073274885, 57.783380372183665, 82.73589706420898, 71.277574130467, 71.6863852909633, 66.62953499385289, 70.85456780024937, 74.44772447858537, 78.65091214861188, 42.138180664607454, 40.82337304524013, 70.24019418443952, 80.30284636361259, 83.36730071476528, 82.30185004643032, 82.17901284354073, 80.85026018960136, 74.73840931483677, 78.97387831551688, 79.95736803327287, 72.21850613185337, 58.778925214494976, 52.14428840364729, 45.472996371132986, 36.39932298660278, 19.575575045176915, 6.336741481508527, 0.7133066271032605, 1.310378577028002, 1.6665946968964167, 2.924836163009916, 1.2819503481898988, 0.4739788579089301, 0.31440395063587595, 0.11373621624495302, 0.43871867709926193, 0.04149545283455934, 0.3811948395201138, 0.12384697156293051, 0.4180881998368672, 0.3199024184473923, 11.322833061218262, 24.72750449180603, 39.356521470206125, 41.63009016854422, 40.709606715611045, 52.823749269757954, 22.059231213160924, 26.171421800340923, 33.47556618281773, 51.141649450574604, 71.9352558680943, 72.19471549987793, 65.45722797938755, 77.43467167445591, 58.95014272417341, 4.973887503147125, 0.4459860042801925, 0.17065328066902502, 0.20472644588776998, 0.020667269127443433, 0.04001630756205746, 0.09577204233833722, 0.11101951130798884, 0.0903738145051258, 0.03612060731809054, 0.10353260340967349, 0.06971419416368008, 0.01035253600483494, 0.03702194270278726, 0.13730669074824878, 0.054851834529212544, 0.1809770959828581, 0.09191675564008099, 0.012968692230060697, 0.04827196170975055, 0.025560086759339486, 0.042140926234424114, 0.036212810049099584, 0.03218204740967069, 0.04604933883196541, 0.02567407046444714, 0.007072151671828968, 0.07876348322523491, 0.023889112851715515, 0.04459492955356836, 0.06085530202835798, 0.00537191382110385, 0.01137718410297696, 0.16784695482679776, 0.10361832952392952, 0.009042736109612244, 0.07368422113358974, 0.11402274801262788, 0.16700194802667412, 0.3156634744788919, 0.1539523218359266, 0.30768116137811113, 0.4058856703341007, 0.40928059816360474, 0.24142170112047875, 0.41617711952754427, 0.2648303450218269, 0.1651503752384867, 0.2869773751923016, 0.27824967780283516, 0.18234188774866716, 0.1714730052543538, 0.11272456124424934, 0.22604586689599923, 0.20932882678295883, 0.0781928827720029, 0.12842124753764697, 0.17574430177254335, 0.21660565345415048, 0.4382599060024534, 0.6392103316528457, 0.8511307686567307, 0.6535827347210476, 0.33371774426528383, 0.3494971575481551, 0.7529675960540771, 0.24021795285599573, 0.3257565200328827, 0.21291621428515228, 0.30189635178872515, 0.1323018300213984, 2.0329727743353163, 84.29824120657784, 122.71235765729631, 97.07214300973075, 98.65517888750348, 76.30880641937256, 56.218889236450195, 39.12166888373238, 18.333417790276663, 39.55176585061209, 58.91037123543875, 42.43055043901716, 51.85845341001238, 40.61818579265049, 23.434693132128032, 8.337259871619088, 1.4478179620844978, 0.2717495837381908, 0.3327846500490393, 1.8496117677007402, 4.508306520325797, 0.9738378013883318, 1.8387334942817688, 0.20773675292730331, 0.6032863536051342, 0.6491958158356803, 5.533378601074219, 5.1697150979723245, 3.5033027912889207, 6.133530122893197, 6.869660930974143, 31.291719572884695, 54.90696859359741, 77.31861591339111, 84.7957044328962, 95.47986602783203, 91.38026210239956, 90.15846306937081, 97.33538246154785, 103.56825011117118, 99.82599898747036, 94.76496587480817, 88.6531150000436, 85.62757056100028, 86.61354773385185, 83.45086669921875, 80.06289727347237, 69.3288128716605, 64.98875263759068, 62.280372619628906, 58.145510060446604, 85.67210156576974, 79.04181085314069, 77.51527077811105, 72.8315179007394, 80.31616606031145, 80.90784685952323, 86.50334235600063, 49.07372311183384, 47.04286541257586, 75.48165116991315, 82.35180064610073, 86.50757380894252, 88.52287796565464, 88.78596455710274, 85.3191886629377, 77.23302800314767, 80.54498413630894, 78.4043275288173, 73.92645672389439, 64.84764167240688, 58.600328717912944, 50.067916529519216, 41.13409996032715, 21.019586154392787, 6.411451986857823, 1.5346022652728217, 2.857356126819338, 5.09041747876576, 5.111954723085676, 2.1184234576565877, 0.8043305799365044, 1.3141582884958811, 0.9252686990158898, 0.9132583034890038, 0.2958702008639063, 0.6951916962862015, 0.4607174609388624, 1.1540552909885133, 0.5392640775867871, 18.834513187408447, 37.69588116237095, 51.93247256960188, 48.776638984680176, 70.39759867531913, 88.2261551448277, 42.06483548028128, 25.89052697590419, 26.758508103234426, 48.84962286267962, 78.82650007520402, 79.73035648890904, 75.39876610892159, 91.7979461124965, 64.18515178135463, 4.4501405443464, 0.64606809509652, 0.2853588249002184, 0.4229422765118735, 0.20134124825043337, 0.22514174612505095, 0.1606655301792281, 0.15337328719241278, 0.2812019836689745, 0.1042548700102738, 0.4259642543537276, 0.2237434075879199, 0.18162816390395164, 0.18194328913731234, 0.42592256516218185, 0.19672127972756112, 0.17492433291460785, 0.3231067865022591, 0.1063161101192236, 0.12511834262737206, 0.15448090061545372, 0.11874437465199403, 0.1830621933830636, 0.13770120457879134, 0.14287172284509453, 0.12834394882832253, 0.1567003886614527, 0.20542422415954725, 0.13590911217033863, 0.1356477133397545, 0.12174640356429986, 0.08748721118484225, 0.12772417494228908, 0.30074745629514965, 0.18789926597050258, 0.22232676217598574, 0.22476870114249842, 0.35390863940119743, 0.385911119303533], [0.1181308568588325, 0.08985713044447557, 0.10397667065262794, 0.055134861663516076, 0.10240248298006398, 0.04589471427191581, 0.016291474823706915, 0.03070789615490607, 0.08690875329609428, 0.08075345680117607, 0.14188563504389354, 0.02733941762042897, 0.06702692407582488, 0.07570139039307833, 0.013001348424170698, 0.034653088743133206, 0.029207828255104165, 0.05841222990836416, 0.07179392435188804, 0.13618287390896253, 0.05648160439782909, 0.11873217459235873, 0.1336310529815299, 0.2693954472030912, 0.11163953625197921, 0.1400283354201487, 0.20213608417127812, 0.2183200264615672, 0.058270924990730624, 0.09992518555372953, 0.06637977808713913, 4.124634376593998, 56.92113324574062, 95.11463396889823, 79.63152531215123, 65.83236122131348, 60.3767329624721, 42.15006903239659, 22.181865181241715, 34.274574279785156, 60.738442284720286, 58.85126291002546, 48.37652696881975, 44.8651888029916, 29.99549491064889, 12.684461985315595, 1.9703929552010127, 0.07155514109347548, 0.030167402300451483, 0.11482917331159115, 0.028603626747748682, 0.35866039299539154, 1.7973545832293374, 0.2405725009739399, 0.16258711421063968, 0.040830383343355994, 0.39566896855831146, 0.33771081428442684, 0.14633985103241035, 2.0968625460352217, 3.914130015032632, 14.414409705570765, 32.81855147225516, 63.305544580732075, 76.94757516043526, 82.96257509504045, 79.46954890659877, 81.32720538548061, 85.00620705740792, 85.56266048976353, 84.07004846845354, 83.73616668156215, 82.50846862792969, 83.02043274470738, 75.30026844569615, 75.12884249005998, 78.11581053052629, 80.53677136557442, 84.606935773577, 83.47529656546456, 64.3844747543335, 52.31899043491909, 31.031349727085658, 43.081263133457725, 61.60008839198521, 64.32020391736711, 62.198717389787944, 62.37067835671561, 68.699875831604, 58.16962030955723, 21.338133266993932, 48.10168055125645, 79.2699966430664, 76.54769243512834, 77.12296853746686, 75.767062323434, 74.94250570024762, 72.70374052865165, 74.76301288604736, 78.80012471335274, 75.9195613861084, 78.6432135445731, 74.65894971575055, 69.37526852743966, 73.66129956926618, 73.34175191606793, 67.88367789132255, 50.817627157483784, 21.729957818984985, 7.494201932634626, 0.9824141583272389, 1.503484540752002, 0.10662290294255529, 0.16084724185722216, 0.052380189299583435, 0.24918452171342714, 0.05321105542991843, 0.28571660284485134, 0.11445747182837554, 0.23539674441729272, 0.042120970519525666, 0.10042424805994545, 0.10754256216543061, 3.9203312822750638, 20.861966269356863, 36.8603116444179, 59.572944504874094, 46.58908551079886, 70.02375779833112, 48.1575961794172, 26.67816260882786, 10.042713454791478, 27.78403615951538, 51.36897018977574, 55.58214242117745, 60.163020270211355, 70.12868254525321, 50.640461989811485, 2.3276754064219336, 0.3680755820657526, 0.10009429683642727, 0.08440986488546644, 0.011596817406825721, 0.09420223121664353, 0.0888381472655705, 0.0020136444821088973, 0.07246680038848094, 0.030033052366759096, 0.06864742854876177, 0.02768248662219516, 0.08745196807597365, 0.07095283269882202, 0.050054517308516164, 0.03884306283933776, 0.014618848683312535, 0.03291678548391376, 0.0061862024927644855, 0.04821789603946464, 0.06380991491356067, 0.07706629750984055, 0.08225104465548481, 0.03533399863434689, 0.0175337825369622, 0.03708770970946976, 0.046524079250437875, 0.02568444865755737, 0.016511639081207768, 0.07299889397940465, 0.044091531208583286, 0.03235870060910072, 0.03263645552630935, 0.011342971519167935, 0.059781581429498534, 0.01401874128662582, 0.06014672147908381, 0.05232054267876914, 0.07140399741807155, 0.03383621400488274, 0.10294096837086336, 0.09067912133676664, 0.06129400884466512, 0.10614323975252253, 0.011492725045952414, 0.11368002676005874, 0.10111729694264275, 0.16273310780525208, 0.06818387378007174, 0.06522498612425157, 0.009350589143910577, 0.0335346187597939, 0.02247842158456998, 0.01656770134078605, 0.01546785544737109, 0.070121383028371, 0.06452417480094091, 0.11383137399596827, 0.027886415233037302, 0.15507623367011547, 0.08461935578712396, 0.32059159289513317, 0.0898879970024739, 0.1689592772828681, 0.16309281278933796, 0.2994269185832569, 0.05413810729182192, 0.10515208329473223, 0.07842331326433591, 7.8720058883939465, 78.34840842655727, 104.13754381452287, 87.1362954548427, 77.15782070159912, 74.27272714887346, 56.235919271196636, 33.119735036577495, 40.883606978825156, 44.30404881068638, 46.40035854067121, 46.6260985646929, 46.47990499223982, 33.47280774797712, 14.987596137183052, 2.3646621874400546, 0.155202984011599, 0.05660764567021813, 0.11654936814946787, 0.03068476150344525, 0.5578902981110981, 2.7241780502455573, 0.46498408913612366, 0.2983258733791964, 0.13782346301845141, 0.6364401174443108, 0.5449029207229614, 0.4791860984904425, 2.4329653680324554, 6.845646219594138, 19.56173770768302, 36.717908314296174, 65.6997617994036, 79.45902933393205, 87.147433417184, 84.06806823185512, 84.98683547973633, 86.36954089573452, 88.49840641021729, 85.4929700578962, 87.6751629965646, 84.27415875026158, 84.79598930903843, 79.1215900693621, 79.42073781149728, 81.91227149963379, 84.17302771977016, 86.65935720716203, 87.10528564453125, 69.35457679203579, 57.112722873687744, 32.55955736977713, 49.5851730619158, 69.20813655853271, 70.22103105272565, 70.63161400386265, 69.66714150565011, 76.6375812802996, 68.14218561989921, 28.19493351663862, 51.497699465070454, 82.48173195975167, 79.52818475450788, 78.59936346326555, 77.33417987823486, 76.21611745016915, 76.49811703818185, 75.11842714037213, 77.15782764979771, 76.53062071119035, 82.56246307918003, 76.57349804469517, 74.01278809138707, 76.20179721287319, 77.83313696725028, 71.00855377742222, 54.75547701971871, 23.831984179360525, 10.189026883670262, 1.331072375178337, 1.4365598176206862, 0.9589016714266368, 0.4030061848461628, 0.6685678277696881, 0.6594776841146606, 0.18175951471286161, 0.30465185535805567, 0.06591623010379927, 0.1328704830791269, 0.12457755021750927, 0.36990670380847795, 0.17101730113582952, 4.353627026081085, 24.924320902143204, 34.81437635421753, 53.227665424346924, 44.4318505014692, 46.4265775680542, 35.23752859660557, 23.51838592120579, 19.829906906400407, 44.43624871117728, 62.60540240151541, 70.73324530465263, 73.10455431256975, 79.6848805291312, 75.28914437975202, 12.159747924123492, 0.6735563629439899, 0.013890577895965959, 0.06981450199548687, 0.05485122384769576, 0.10004004796168633, 0.04479829328400748, 0.02177243473540459, 0.08296316715755633, 0.0426791605672666, 0.05382328739921961, 0.041632618688579114, 0.01852469302580825, 0.022936610837600062, 0.0261305888249938, 0.013758696981572678, 0.033715444949588606, 0.04634759229208742, 0.01585724633852286, 0.04972567209707839, 0.06259560864418745, 0.05769916424261672, 0.02615415773886655, 0.022605809748971036, 0.06964201160839625, 0.08234427536704711, 0.12759112779583248, 0.0938260310462543, 0.027852507141817893, 0.03306862126503672, 0.05046070194137948, 0.04698938803215112, 0.05554735667205282, 0.034167844602572064, 0.05064758744889072, 0.01344043352375073, 0.027651316419775997, 0.06954289799822228, 0.18731256388127804, 0.2109360998230321, 0.3307612043406282, 0.1464252243084567, 0.23998423825417245, 0.2371714391878673, 0.17804993662450994, 0.21937989816069603, 0.17008420691958495, 0.3050552579973425, 0.30295348220637863, 0.1820441058703831, 0.20923870376178197, 0.1677535069840295, 0.08218422252684832, 0.19692618373249257, 0.10369082420532193, 0.20744389721325465, 0.17188380392534391, 0.26400682064039366, 0.2209565014179264, 0.2191293423197099, 0.27063287794589996, 0.5318028522389275, 0.1766228282025882, 0.38814206102064674, 0.4256198842610632, 0.36708785220980644, 0.16802326536604337, 0.19404071356569016, 0.21515953248100622, 8.035334587097168, 92.97579778943742, 115.39008889879499, 96.37403665270124, 90.0013017654419, 77.05912848881313, 56.69420507975987, 31.41028015954154, 47.031251498631065, 81.28191702706474, 79.05246244158063, 65.11154120309013, 64.43375832693917, 47.20443534851074, 20.689407757350377, 4.2326706136975965, 0.5947128193719047, 0.10709911238934312, 0.16538560975875172, 0.14702618920377322, 0.9235659560986927, 5.118177269186292, 1.2641035744122096, 0.3982021840555327, 0.20073253448520387, 1.296878878559385, 0.8933324984141758, 0.9297043638569968, 5.0135990636689325, 8.278318302971975, 22.241572788783483, 39.80537857328142, 69.84850338527134, 85.87455122811454, 92.53969410487584, 88.702607018607, 91.72237055642265, 93.91143526349748, 93.9826751436506, 91.45580986567906, 95.62924534933907, 90.54091971261161, 89.11257852826799, 85.29703085763114, 84.41320610046387, 86.68516281672886, 90.14961106436593, 87.01247160775321, 88.99308340890067, 71.3681161063058, 60.86389201028006, 39.37193257468087, 56.11130332946777, 79.43433543613979, 76.32624639783586, 76.44869450160435, 76.89183671133858, 83.80328627995083, 77.07506070818219, 33.63359253747122, 56.24024452481951, 83.92356654575893, 83.19074698856899, 81.87609222957066, 82.29591628483364, 79.60853372301374, 79.02129977090019, 76.63448933192662, 79.20873437608991, 80.1136816569737, 87.55544553484235, 79.52318205152238, 78.68443720681327, 81.56306893484933, 85.8061740057809, 77.77541828155518, 62.76409230913435, 24.882431949887955, 12.013564773968287, 1.97721044080598, 3.7433658753122603, 1.6712037410054887, 0.9756624634776796, 0.6993353196552822, 0.8279504925012589, 0.4780489280819893, 0.6648237258195877, 0.5847130588122776, 0.5016797514898437, 0.29081527782338007, 0.5983958531703267, 0.4451556131243706, 7.650952424321856, 34.426062379564556, 56.31317976542881, 80.92128467559814, 60.89594405038016, 90.41258648463658, 63.392702783857075, 36.05662740979876, 16.878588335854666, 40.285822187151226, 67.3262586593628, 78.8161403111049, 78.7405091694423, 92.93203108651298, 83.36208956582206, 10.531081489154271, 1.062057450413704, 0.1669181625225714, 0.211124718987516, 0.1269337766404663, 0.2647750037057059, 0.12564608002347605, 0.1156138719192573, 0.18160008612487996, 0.20345169571893557, 0.16991154689873966, 0.16596556720989092, 0.21712887180703028, 0.2924111107630389, 0.229650367051363, 0.12797530075269087, 0.1368010735937527, 0.11680851424379007, 0.08028106750654322, 0.15947475550430162, 0.24815686685698374, 0.1722714781228985, 0.11737738443272454, 0.07015500443854503, 0.18452151864767075, 0.14310505746730737, 0.3023548243301255, 0.2749456193830286, 0.14378394532416547, 0.13737328217497893, 0.17046293802559376, 0.1407784151711634, 0.13955735069300446, 0.14348315075039864, 0.19630582630634308, 0.06905835614140544, 0.148774475391422, 0.23004733717867307], [0.06499300178672586, 0.09208546658711773, 0.15091179284666265, 0.0901325342378446, 0.04974761591958148, 0.009679721036393727, 0.053568361792713404, 0.038413288936551125, 0.11897788569331169, 0.12908482764448437, 0.04744472913444042, 0.17448479150022778, 0.04499654425308108, 0.03996857262349554, 0.027349302179313133, 0.05589826444962195, 0.028653441396142756, 0.10572218163205044, 0.035207221151462624, 0.15014550967940263, 0.16187720373272896, 0.1738692516727107, 0.1388094151126487, 0.15266828930803708, 0.0976806188534413, 0.08635890244373254, 0.18551745877734252, 0.07670294200735432, 0.2270744852721691, 0.1591710839420557, 6.46864651782172, 81.65444469451904, 93.49205589294434, 83.83748531341553, 86.52386038643974, 59.606337547302246, 41.019840308598106, 21.281670468194143, 26.65744481767927, 21.488935232162476, 41.09843485695975, 49.121797697884695, 35.83217280251639, 25.18358598436628, 7.09795354945319, 1.048289269208908, 0.01904604201471167, 0.09103230559932333, 0.0846055815262454, 0.0400144789101822, 0.05914827755519322, 0.06587221353713955, 0.05630261703793492, 0.16174639575183392, 0.06431103338088308, 0.06257878097572497, 0.4041728036744254, 0.21556184946426324, 0.9801450286592756, 8.283437388283865, 26.855353832244873, 41.76067461286272, 62.87483964647566, 78.5891774041312, 81.25682013375419, 76.71129471915108, 68.5973482131958, 71.75282396589006, 72.64817578451974, 72.21590055738176, 70.17438779558454, 70.80742427280971, 73.37420695168632, 73.24574865613664, 69.76048360552106, 70.95813764844621, 69.70100007738385, 71.67469842093331, 74.88293879372733, 78.7238404410226, 78.27455602373395, 80.88859340122768, 72.95544597080776, 37.42693029131208, 61.419782638549805, 61.823563303266255, 65.3928529194423, 68.19248362949916, 69.61541216714042, 37.2777281488691, 34.239364283425466, 72.2865081514631, 76.01746845245361, 74.26714079720634, 71.60787064688546, 73.45263126918248, 74.08691147395542, 70.57089369637626, 73.04585593087333, 78.34237739018032, 76.96127700805664, 74.43027060372489, 74.28887476239885, 74.69651862553188, 71.03105899265834, 70.18057169233049, 69.65988758632115, 74.09340109143938, 65.53802163260323, 46.78248514447893, 29.55048016139439, 11.535996845790319, 2.552440945591245, 0.719158693083695, 0.19794752821326256, 0.006215370168709862, 0.16702523534851416, 0.18521836054112228, 0.2316045750464712, 0.05841294237013374, 0.3483909826193537, 0.05452058051845857, 0.09719667410744087, 0.15642501200948442, 1.946523938860212, 11.964053647858755, 26.07103943824768, 52.00826699393136, 55.23846367427281, 57.848293917519705, 56.0693952696664, 40.79385709762573, 21.40065142086574, 33.696553639003206, 48.60898242677961, 57.800976685115266, 52.57319375446865, 57.99619327272688, 56.48005812508719, 6.351559817790985, 0.352723944400038, 0.059516274237207005, 0.08537208182471138, 0.07453966380230018, 0.02933506714180112, 0.05674649089840906, 0.016096304403617978, 0.03326571872457862, 0.05903274339756795, 0.05893603180135999, 0.017558606740619456, 0.05150651100224682, 0.10229839570820332, 0.011547922173381915, 0.08173327493880476, 0.06909712763237101, 0.036220799798944166, 0.057764717510768344, 0.08211182962570872, 0.06175196569945131, 0.08394981135747262, 0.07174536160060338, 0.0287150693392115, 0.03309246159291693, 0.011088608248558427, 0.027862210192584565, 0.015280445771557944, 0.06387212300407034, 0.06818818247744016, 0.0328286573556917, 0.007823926064052751, 0.022015211172401905, 0.03033800296751516, 0.03133016026445797, 0.0558249419555068, 0.08451655773179871, 0.02781187985757632, 0.05884813437504428, 0.08273916239184992, 0.04384441554014172, 0.01361995777447841, 0.022357124968298843, 0.07161382758723837, 0.04890805097030742, 0.15108819838081086, 0.18957815159644398, 0.06549211857574326, 0.13982690551451274, 0.02675836772790977, 0.02639143125686262, 0.026907128049060702, 0.023038557331476892, 0.0694939891940781, 0.0831331673211285, 0.07433982845395803, 0.06212021343942199, 0.12799891377133982, 0.1752695036785943, 0.15872912694300922, 0.18235705979168415, 0.08539904002100229, 0.09834692667105369, 0.1999641614300864, 0.10083719768694469, 0.11330740246921778, 0.126350250095129, 11.599101253918239, 102.26855482373918, 104.17491122654506, 96.02579988752092, 94.154385975429, 72.64941951206752, 59.90347726004464, 35.49565070016043, 20.91297820636204, 23.28473711013794, 44.80635493142264, 47.36398335865566, 41.68307018280029, 28.67441827910287, 9.863005246434893, 1.356831084404673, 0.10695683038128273, 0.06886400335601398, 0.05576808411361916, 0.09761117079428264, 0.19017675518989563, 0.11768727137574128, 0.1365392269300563, 0.37229943541543825, 0.10847750199692589, 0.14564429835549422, 0.5955539856638227, 0.22124867859695638, 1.1073953147445406, 9.40364420413971, 26.14082714489528, 40.54444803510393, 62.59554985591343, 80.4098903111049, 83.86230427878243, 78.99550805773053, 72.01514625549316, 73.35016618456159, 76.65286036900112, 75.00334412711007, 73.20376764025006, 73.15815271650041, 77.03222506386894, 76.68489156450543, 72.41174248286656, 73.71767725263322, 72.51502745492118, 74.30377864837646, 78.53090981074742, 81.75673607417515, 82.0151673725673, 84.40854385920933, 70.48361042567662, 42.516030652182444, 69.87637260981968, 68.18136651175362, 71.65991960253034, 75.69400201525006, 78.31515434810093, 43.93356391361782, 38.84775352478027, 73.37074674878801, 78.2931910923549, 75.72689478737968, 73.79208551134381, 76.78839193071637, 77.79319872174943, 71.43047618865967, 74.24505942208427, 80.91842201777867, 81.04503904070172, 77.3677396774292, 76.86626734052385, 77.11250455038888, 76.08831923348563, 73.73565224238804, 75.11168043954032, 77.06597941262382, 70.14057091304234, 51.82890966960362, 33.02068499156407, 13.833255427224294, 3.7879689676421027, 1.4317422189882822, 1.0334571450948715, 0.7555216018642698, 0.9272191886390958, 0.5309866017528942, 0.6098290053861481, 0.43969576752611567, 0.11066530924290419, 0.12956567827079976, 0.035030791868588755, 0.09409273602068424, 1.7029232446636473, 12.299739360809326, 25.748787198747905, 44.54936538423811, 50.118113790239605, 56.267071519579204, 57.226301601954866, 43.73972306932722, 32.26688882282802, 55.88102265766689, 68.12179265703473, 70.68069607870919, 66.04621982574463, 64.37592847006661, 77.07148238590786, 22.305362462997437, 0.08410267172647373, 0.026118015571098243, 0.09323496597685985, 0.14340727696461336, 0.029469142268810953, 0.0663027847185731, 0.05135378634024944, 0.09625224835638489, 0.009181231044099798, 0.08224853407591581, 0.05886679408805711, 0.043808768702937026, 0.038881260968212566, 0.0476818465893822, 0.04025296022051147, 0.02871685049363545, 0.010293579793402126, 0.07623734484825816, 0.008419480490764337, 0.07119728850999049, 0.10177991352975368, 0.028388785597469126, 0.06340772685195718, 0.05805292525993926, 0.029801329265215566, 0.020361154839130383, 0.010880450668212558, 0.01062391184469951, 0.08795135627899851, 0.03878493613696524, 0.03328249889558979, 0.04139224087287273, 0.020656896023345844, 0.03702223447284528, 0.09745170149419989, 0.05902298606399979, 0.13519342057406902, 0.16115202621689864, 0.26245487534574097, 0.1759659791631358, 0.16170261667243072, 0.12906801354672226, 0.16959775159401552, 0.2616415561309883, 0.19528438683067048, 0.30854906194976395, 0.10582768704210009, 0.30974678482328144, 0.1275405226541417, 0.13713514352483408, 0.14923431857356004, 0.1195465794631413, 0.20816136657127313, 0.2808173085962023, 0.200871132048113, 0.24906271110687936, 0.22412905975111894, 0.34934166446328163, 0.35873717601810184, 0.32781009269612177, 0.28497993094580515, 0.22453714428203447, 0.2780416932489191, 0.25708427067313877, 0.4292671185519014, 0.23814825820071356, 14.013372710772924, 119.84593391418457, 115.56371743338448, 105.05169745853969, 106.5985610144479, 75.33462033952985, 57.46691077096121, 31.472105230603898, 40.08584260940552, 31.778260231018066, 56.388334955487935, 66.38500704084123, 52.269053731645855, 39.283221449170796, 13.905056374413626, 2.2896107860973904, 0.2394301736993449, 0.28731783692325863, 0.2470388039946556, 0.19659699925354548, 0.20806259901395865, 0.1438793202063867, 0.1956263141972678, 0.5072608377252306, 0.244275727974517, 0.2901504763535091, 0.9839993246964046, 1.3996859448296683, 3.3038323862212042, 13.36821596963065, 34.48792219161987, 49.60690007890974, 68.91971683502197, 86.38297176361084, 87.75952107565743, 84.51234994615827, 75.90163503374372, 79.19658892495292, 80.67787538255963, 79.52448831285749, 79.13021973201207, 76.51307650974819, 81.70513875143868, 81.55644035339355, 76.73220184871128, 76.9548568725586, 76.5353524344308, 78.30464172363281, 80.9319987978254, 86.10434900011334, 84.97152165004185, 86.92793287549699, 80.13573523930141, 49.421150411878315, 75.43008163997105, 75.76080894470215, 79.42720658438546, 84.4393174307687, 86.50855350494385, 49.78464194706508, 44.91089752742222, 77.48545605795724, 80.94729178292411, 81.48598561968122, 76.68489851270402, 80.95965957641602, 78.93987383161272, 72.48045321873256, 77.16450486864362, 86.87810039520264, 84.48451546260289, 82.849791935512, 82.48467104775565, 81.74656391143799, 81.06132561819894, 79.43472453526088, 78.4852601460048, 82.42818914140973, 75.25579302651542, 54.89103290012905, 35.10394600459507, 15.630207232066564, 4.962169800485883, 3.636227910007749, 1.4494970377002443, 0.595117443374225, 0.8099136746355465, 0.3857694954744407, 0.5121232196688652, 0.3892018784369741, 0.776247861129897, 0.21313662960061006, 0.32868779131344383, 0.35703060616339954, 3.195741432053702, 19.38370054108756, 41.12499782017299, 72.98176574707031, 73.71318871634347, 76.95009735652378, 77.49033369336809, 54.378054346357075, 33.25896651404244, 51.177321502140586, 62.47347000667027, 77.44364179883684, 73.5026444026402, 75.50521945953369, 91.23389829908098, 20.59040113857814, 0.4441542311438492, 0.14990920307380812, 0.18380510780428136, 0.2676871402987412, 0.1665928185518299, 0.09612912817725114, 0.12133378641945974, 0.09500556918127195, 0.09274591864751917, 0.14515552244016103, 0.1012943402997085, 0.09609395970723458, 0.1936659858162914, 0.1115793976932764, 0.16005100815423898, 0.14912347309291363, 0.10752888289945466, 0.23586281655090197, 0.20500323389257702, 0.14957825440381253, 0.21011606311159475, 0.20684576859431608, 0.28183022567204064, 0.24399571014302118, 0.1564401297696999, 0.14636036993137427, 0.10036168034587588, 0.14618787275893347, 0.2811309003404209, 0.08710040551211153, 0.08828716325972762, 0.06263422407209873, 0.10534391192985432, 0.09773300854223115, 0.2764018912400518, 0.2507205621472427], [0.07428862620145082, 0.06830922633941684, 0.058880439427282126, 0.1349746473133564, 0.033566377591341734, 0.0485160714680595, 0.04453413960124765, 0.07864524849823543, 0.14745405981583254, 0.07390597994838442, 0.04871715871351106, 0.09694438800215721, 0.07059603184461594, 0.04625029715576342, 0.05502618070957916, 0.06400755859379258, 0.026705687965399454, 0.15906608743327005, 0.12508409017963068, 0.17436484007963113, 0.06699531112930604, 0.13760842170034135, 0.15701521533940518, 0.21727225982717105, 0.1859535803752286, 0.19599406660667487, 0.0644174005304064, 0.31093804804342134, 0.14644479325839452, 3.9848848240716115, 65.20614787510463, 77.86880901881626, 83.15904930659703, 74.97948401314872, 59.24492699759347, 36.63923386165074, 17.299148900168284, 35.106812136513845, 69.55235031672886, 79.66055488586426, 55.208294595990864, 42.41533388410296, 21.550824574061803, 4.835900187492371, 0.2975422739982605, 0.057625984240855486, 0.04638237738981843, 0.05342612049675413, 0.09651107553924833, 0.048536281633589945, 0.15505059861711093, 0.07098067299063716, 0.16427351800458773, 0.05494847148656845, 0.12987500881510122, 0.7266278980033738, 1.197797349521092, 12.004909055573599, 34.31663172585623, 43.73211131777082, 56.78268691471645, 68.28651360103062, 77.27568994249616, 82.42768887111119, 77.38412352970668, 73.75346742357526, 67.80914456503731, 64.49213709150041, 65.10451657431466, 66.35632487705776, 68.59141445159912, 69.91858291625977, 68.11163439069475, 70.38429982321603, 68.16185597011021, 68.71973378317696, 63.89029107775007, 64.7948978969029, 68.93546840122768, 70.56165259225028, 70.70905862535749, 74.59486648014614, 75.55378736768449, 67.36008249010358, 30.517863954816544, 50.836578369140625, 59.645309993198936, 70.44620132446289, 53.583698068346294, 34.51960597719465, 67.45547430855888, 76.47188064030239, 71.21038505009243, 65.27945137023926, 66.86847659519741, 73.20726258414132, 73.4769847052438, 71.13565022604806, 70.71126120431083, 69.25908075060163, 63.58771092551095, 61.673899105616975, 69.17703642163957, 69.55317715236119, 70.57917594909668, 64.42055674961635, 65.76511655535016, 69.00581196376255, 71.1189328602382, 71.78463976723808, 72.47818115779332, 64.09383855547223, 41.15529544012887, 15.550433226994105, 1.9760075339249201, 1.3368948570319583, 0.46773552149534225, 0.3807229862681457, 0.07619391182171446, 0.14152084104716778, 0.09866916973676, 0.2335756921342441, 0.07083384479795184, 0.12962430369641098, 0.17273585391896112, 0.2637414591653006, 4.810478900160108, 15.111800398145403, 33.95256001608712, 46.03516469682966, 30.47774158205305, 38.96989243371146, 39.78943593161446, 15.375316040856497, 17.821033307484218, 40.49103375843593, 60.63908999306815, 61.05227157047817, 65.0695949281965, 68.04839188711983, 20.895777940750122, 0.5085961946419307, 0.15902138554624148, 0.09631151160491364, 0.09054743126034737, 0.01853039950531508, 0.12143207900226116, 0.04118492128327489, 0.03666049727637853, 0.04698969337290951, 0.0554381769948772, 0.08548969229949371, 0.032492500929428, 0.004991715807201607, 0.022942514092262303, 0.04770569030993751, 0.11075222957879305, 0.13961740104215487, 0.12042681580143315, 0.14821338121380123, 0.016383568989112973, 0.058633873372205665, 0.028983446902462413, 0.04715123220479914, 0.03457235325393932, 0.02452922921760806, 0.012460283752131675, 0.04473607162279742, 0.0375477021693119, 0.01459328318014741, 0.04199159085484488, 0.013327079159872872, 0.07955882804734365, 0.07171229658914463, 0.08277929773820297, 0.07349069616092102, 0.11255196907690593, 0.09537673462182283, 0.077839908855302, 0.12939607165753841, 0.041362670316760025, 0.031705607260976515, 0.047548972469355376, 0.06351650280079671, 0.11756152526608535, 0.052871618286839554, 0.11007813896451678, 0.12797285802662373, 0.08702816188867603, 0.018256356174658452, 0.033077961299568415, 0.03970258689618536, 0.04179496158446584, 0.07646759213613612, 0.1606223482106413, 0.03934480216620224, 0.05820856762251683, 0.15728379307048662, 0.1542599696133818, 0.12159023194440774, 0.17008006785597118, 0.15065089613199234, 0.05212517209084971, 0.3724639394453594, 0.11419648011880261, 9.580228328704834, 84.27159486498151, 86.30795206342424, 94.42417063031877, 87.12985447474888, 78.2567686353411, 61.44068281991141, 37.661831515175955, 33.99929707390921, 57.72205209732056, 47.91066762379238, 44.341516971588135, 44.67333166939871, 24.16747100012643, 6.224720886775425, 0.3384852127305099, 0.028513832816055844, 0.03592556581965514, 0.04108153968783362, 0.12491057520466191, 0.3150685621159417, 0.5435801574162075, 0.3979582371456282, 0.6120360898120063, 0.2071537963513817, 0.012682727039126413, 0.2771260238119534, 2.279284025941576, 11.905010461807251, 35.663185664585654, 47.73632342474801, 58.19519662857056, 67.74763911111015, 76.98283726828438, 84.28761741093227, 79.24591418675014, 75.14421885354179, 70.68893664223808, 67.5959529876709, 68.36167921338762, 70.47566863468715, 70.26333168574742, 71.26030090876988, 73.30577414376395, 73.25201593126569, 72.17245347159249, 72.178067616054, 67.9094626562936, 69.10545607975551, 73.06686728341239, 73.56848553248814, 74.1554901940482, 76.78796114240373, 78.00491033281598, 68.58764852796281, 38.64834369931902, 58.879528181893484, 68.52840818677629, 78.03216811588833, 62.72178472791399, 41.875945227486746, 70.65491131373814, 79.85263783591134, 74.52500929151262, 68.68295696803501, 71.29311725071499, 74.66480009896415, 75.93330492292131, 71.47401360103062, 72.8431213923863, 72.07189914158413, 64.77847930363247, 66.39775003705705, 71.56798103877476, 73.0663948059082, 73.55927916935512, 67.8319068636213, 68.90236718314034, 73.7858668736049, 73.79216194152832, 75.43727997371128, 76.08644321986607, 70.67419951302665, 44.207048484257285, 16.714803661618912, 1.4392851399523872, 0.8881859460047313, 1.2068799478667123, 1.8163651802710123, 0.5208939090371132, 0.48849511040108545, 0.48631201897348675, 0.45846391043492724, 0.01677319227850863, 0.23858868171061787, 0.2581075286226613, 0.08793344973985638, 4.913830314363752, 18.104229722704204, 33.93695783615112, 38.344947133745464, 26.37656215259007, 31.801133700779506, 37.14916215624128, 26.089686666216167, 35.7788210596357, 56.712621280125205, 72.1842098236084, 73.23198427472795, 74.27650002070835, 81.87921891893659, 41.29618058885847, 0.6116787461297852, 0.23998779377767018, 0.0600899484540735, 0.07930589733379227, 0.011933039990253747, 0.11666011863521167, 0.014300680220393198, 0.129205213327493, 0.032191143171595674, 0.015243871037715247, 0.06597732539687838, 0.03255541130368199, 0.014813783312482494, 0.03290666174143553, 0.08847844906683479, 0.15381537989846297, 0.17111167178622314, 0.13923368948910916, 0.11857179605535098, 0.019685717332842093, 0.043314795209360976, 0.04236367231767092, 0.0042992496164515615, 0.0456323553142803, 0.022703204969210283, 0.040451479210917435, 0.02216008348789598, 0.026587529573589563, 0.07036331468927008, 0.05513674799086792, 0.01609434174107654, 0.06570046275321927, 0.12112239561975002, 0.048137811943888664, 0.0696127735344427, 0.2088835992451225, 0.21985951385327748, 0.17608118083860191, 0.18932193677340234, 0.0981036311547671, 0.2637259614254747, 0.19831438495644502, 0.21276315035564558, 0.36866275912949015, 0.21091288035469397, 0.21467630698212556, 0.2376051859131881, 0.20528702437877655, 0.16748193012816565, 0.18055421938853605, 0.1684933001441615, 0.15709218835192068, 0.17905674688518047, 0.2618799390537398, 0.2749749592372349, 0.1817723118833133, 0.35698696279100006, 0.3788474883352007, 0.31644254124590326, 0.3759735939758164, 0.28386702494961874, 0.182499104312488, 0.4124710155384881, 0.2364006776894842, 12.372073582240514, 102.96689047132219, 94.65343339102608, 106.61842591421944, 95.55454526628766, 76.86449554988316, 53.34720918110439, 26.147938626153127, 47.23372547967093, 81.34851551055908, 93.6726326261248, 70.11443178994315, 60.784078053065706, 34.1811522756304, 8.411770616258893, 0.5138844794460705, 0.1809894453201975, 0.11724061891436577, 0.16873219875352724, 0.24814259048019136, 0.26112236827611923, 0.45337696054152077, 0.24807025864720345, 0.3450184464454651, 0.08014205603727273, 0.1808999872633389, 2.7882502121584753, 3.861466578074864, 15.24218681880406, 39.88811772210257, 48.70066390718733, 62.60757718767439, 70.62741034371513, 82.55448654719761, 86.66595104762486, 85.7016522543771, 81.45023018973214, 74.88622529166085, 70.3737871987479, 72.8721648624965, 73.67409815107072, 76.51167297363281, 77.197112764631, 76.8840616771153, 77.26467704772949, 76.5184405190604, 76.0900354385376, 72.34090559823173, 73.13471644265312, 77.60697310311454, 78.57336330413818, 74.6902027130127, 78.27712685721261, 78.96245547703334, 71.18722670418876, 45.66723326274327, 65.20353535243443, 76.38449314662388, 86.3647813796997, 70.02161080496651, 46.47704928261893, 76.38991968972343, 81.55558572496686, 79.46392086574009, 71.60721751621791, 74.95273344857353, 78.22107573917934, 77.62942968096051, 73.16128635406494, 76.29765456063407, 75.24768447875977, 70.26187256404332, 69.01364953177315, 76.08645711626325, 78.20393453325543, 80.07983003343854, 70.57435389927456, 74.16742025102887, 78.95568793160575, 78.38216972351074, 77.74572168077741, 80.81524126870292, 72.86851705823625, 49.3515294619969, 20.531982421875, 6.2057362369128635, 3.540258739675794, 1.515155343072755, 2.2529438393456593, 0.47885486483573914, 0.39739925999726566, 0.6885636576584407, 1.0972065414701189, 0.3185223325022629, 0.6227458151323455, 0.5300745421222278, 0.554795364184039, 8.846279689243861, 26.367135184151785, 53.41306420734951, 63.40817642211914, 41.42337083816528, 53.74064745221819, 56.51328093664986, 23.50178493772234, 27.893164566584996, 53.680899892534526, 78.39364119938442, 81.09489236559186, 83.46262305123466, 94.31229768480573, 38.6060847554888, 0.8244540286915643, 0.21954993903636932, 0.1813434777515275, 0.15760005824267864, 0.14751172172171728, 0.1797289443867547, 0.14792455599776336, 0.20667023158499173, 0.22826135158538818, 0.12272795875157629, 0.23181027972272464, 0.14992870417024406, 0.25342913823468344, 0.10706906007336718, 0.16846002478684696, 0.21206729912332126, 0.2633902494396482, 0.3438788061695439, 0.21037200652062893, 0.12793602714581148, 0.21123826503753662, 0.09187555499374866, 0.1398883672165019, 0.19677192558135304, 0.12340808154216834, 0.1264315385903631, 0.12788730833147252, 0.09347761009952851, 0.15054522108818802, 0.15523412876895495, 0.09803381668669836, 0.1485690964119775, 0.2627415156790188, 0.16625085047313146, 0.13707073698086397], [0.031882599727915864, 0.02029685177175062, 0.07971382580165352, 0.06980503643197672, 0.01335265823373837, 0.02715994680433401, 0.00805638452792274, 0.05478885630145669, 0.026928317001355544, 0.06809796446136065, 0.06542922516486474, 0.05020057875663042, 0.048845910733299594, 0.029660160054585764, 0.09560493273394448, 0.08707196810947997, 0.030140288041106293, 0.032958834299019406, 0.007966196197750313, 0.03280208931703653, 0.0777260981766241, 0.08661656254636389, 0.0689569626535688, 0.10631351811545235, 0.08602048988853182, 0.0652084502258471, 0.060265044415635724, 0.04051041676263724, 10.686724611691066, 72.47761835370744, 82.70741639818463, 84.20569814954484, 69.44158908299038, 57.85611411503383, 17.545309679848806, 15.661166667938232, 34.63719729014805, 62.75304467337472, 62.65648555755615, 59.186708041599815, 48.09654235839844, 17.28968719073704, 2.2785479511533464, 0.07953663316688367, 0.03739647028435554, 0.15281927692038672, 1.7083191722631454, 0.11691055233989443, 0.11229555747870888, 0.0923824885061809, 0.155372468488557, 0.6687000606741224, 1.0529137296336037, 0.5676042597208704, 0.37440061409558567, 5.841062639440809, 34.79390696116856, 66.8532600402832, 76.09060519082206, 78.66668455941337, 73.82125404902867, 68.71418217250279, 69.84680107661656, 73.60605444226945, 76.66465841020856, 73.95185933794293, 70.19700418199811, 68.04378523145402, 68.80204909188407, 68.66253621237618, 69.3567932673863, 72.88658237457275, 71.94469152178083, 67.47809069497245, 66.8285800388881, 63.0893930707659, 60.34428487505232, 58.595854078020366, 61.5986362184797, 60.351031575884136, 67.93015439169747, 73.36329133169991, 75.32649789537702, 80.24835164206368, 59.8271860395159, 25.595674957547867, 50.97928394590105, 57.53231416429792, 40.04985441480364, 64.25166688646588, 72.13983862740653, 68.84672600882394, 62.738766125270296, 66.23788588387626, 70.95011942727226, 71.49513612474713, 72.41158962249756, 70.206773349217, 73.03575325012207, 71.17548424857003, 61.36992236546108, 55.84762266704014, 58.891055243355886, 59.01903411320278, 59.1502925327846, 55.41492012568882, 59.26563957759312, 65.41941588265556, 68.66676071711949, 69.07969910757882, 68.08003398350307, 71.7365721293858, 68.39694132123674, 54.14104781832014, 23.551693848201207, 3.177498285259519, 1.0546807433877672, 2.3709385820797513, 1.417876763003213, 1.0855738456760133, 0.07360395722623382, 0.02195013627143843, 0.01938471750223211, 0.08488078175910882, 0.08416464911507708, 0.07508473098278046, 0.08061505601342235, 1.8741968827588218, 14.670139891760689, 40.99860661370413, 70.48945386069161, 64.85846696581159, 54.706884792872835, 52.76996326446533, 27.03469204902649, 12.798980457442147, 32.49980286189488, 46.50854546683175, 60.17713900974819, 71.56704303196499, 79.63012177603585, 28.861932788576397, 0.13595730172736303, 0.12091423464672905, 0.031006353175533668, 0.03676957856597645, 0.009984228044881352, 0.10818745541785445, 0.0493596872713949, 0.10135063835020576, 0.014890993812254496, 0.07071456512702362, 0.0506612531441663, 0.08498588004814726, 0.01607820957100817, 0.06053945754787751, 0.06130100454070738, 0.06694134045392275, 0.07822553387710027, 0.03933554016319769, 0.008522097037972083, 0.06529427133500576, 0.04932452219405344, 0.06715558110071079, 0.03608197831947889, 0.017669900054378167, 0.04791215155273676, 0.05512648175603577, 0.03655611484178475, 0.0895971158253295, 0.08904881881816046, 0.024696021606879573, 0.0449639542161354, 0.013264633582106658, 0.07709861613277878, 0.0743911528427686, 0.010867250617593527, 0.030879636760801077, 0.055488507329885445, 0.07030236867389508, 0.0883078042949949, 0.07726727279701404, 0.021248127333819866, 0.025208719274295226, 0.01875699627479272, 0.0252809255783047, 0.04300346637942961, 0.02484300925529429, 0.07962627442819731, 0.028049753879063895, 0.06810768786817789, 0.03301683886508856, 0.035395216063729355, 0.0392035990288215, 0.013011942052149346, 0.12444290172840868, 0.07774240337312222, 0.06710335426032543, 0.05276780242898634, 0.07590309849807195, 0.06888034926461321, 0.02239672257564962, 0.1659462968153613, 0.07728426331388098, 17.539415870394024, 94.13721697671073, 95.42268235342843, 96.2015962600708, 85.66324956076485, 78.34159224373954, 32.65624850136893, 24.085233858653478, 37.21829673222133, 62.17931801932198, 72.32061685834611, 64.70416137150356, 49.301071643829346, 18.543849195752824, 2.6869092157908847, 0.16874604086790765, 0.05576601458181228, 0.06138352118432522, 2.231044637305396, 0.08191535302570888, 0.30012399117861477, 0.4935723436730248, 1.3289941038404192, 1.240366899541446, 1.2349259172167097, 0.9326809069940022, 1.5512651311499732, 6.068323884691511, 37.26286595208304, 69.92405809674943, 79.61669785635812, 81.13336454119, 77.14918409075055, 69.27967521122524, 73.24480370112828, 74.76270716530937, 79.63768836430141, 77.71127946036202, 71.84048243931362, 71.96886430467877, 71.54268264770508, 70.67833369118827, 73.12987354823521, 75.34162412370954, 76.25378363473075, 71.77080590384347, 70.06902531215123, 67.87304714747837, 63.99631364004952, 61.93509578704834, 64.63975851876395, 63.05324159349714, 70.81749221256801, 76.24435492924282, 77.73060934884208, 81.10750334603446, 61.55068670000349, 32.99409770965576, 57.73580258233206, 63.413220814296174, 47.8667619568961, 67.00809369768415, 76.11776569911412, 71.99533694131034, 65.89240060533795, 66.27610792432512, 73.57504463195801, 73.95382567814418, 74.51368372780937, 70.46795613425118, 75.18145424979073, 75.11767673492432, 65.39591012682233, 58.086179392678396, 62.285430908203125, 61.79688916887556, 61.61641665867397, 59.29398822784424, 62.38301835741316, 69.09023257664272, 72.33030959538051, 72.41021387917655, 71.2453692299979, 75.39079652513776, 73.31480680193219, 59.1149331501552, 27.079502718789236, 4.252122964177813, 0.16887728311121464, 1.3636008011443275, 1.0369759734187807, 1.5012628542525428, 0.41745499095746447, 0.45869314670562744, 0.21508847629385336, 0.05203048592167241, 0.024462266292955195, 0.15672382526099682, 0.04195983541597213, 1.8578254069600786, 17.08413689477103, 37.25669247763497, 48.71149614879063, 40.9627365384783, 36.97574206760952, 35.87342773165022, 17.303957053593226, 24.106309482029506, 51.38303681782314, 55.44504404067993, 70.54440716334751, 79.87314196995327, 91.36289855412075, 52.62938731057303, 1.759896410363061, 0.24704572505184583, 0.052034831938466856, 0.016085441057969416, 0.013217460979441447, 0.08057138549962214, 0.08526536862232856, 0.10539155865886382, 0.040357641210513454, 0.02038359908120973, 0.04453977483457752, 0.10738818866333791, 0.01613206828811339, 0.05103443383372255, 0.02399985824844667, 0.0774648350530437, 0.05661106548671212, 0.10587871287550245, 0.04204503566558872, 0.05892246110098703, 0.061157379033310075, 0.018986841530672142, 0.020333623280748725, 0.023449086284797107, 0.054910144436040094, 0.032651807381106276, 0.028588875396443263, 0.026151613232546618, 0.06986347186778273, 0.027210689349366084, 0.040408826499645195, 0.02364167827181518, 0.023498249539573277, 0.046495397575199604, 0.10603375812726361, 0.23998630100062915, 0.14963998751980917, 0.2343270203896931, 0.15109910922391073, 0.10182226090026752, 0.09794134593435697, 0.09262375520276171, 0.15137364449245588, 0.23540811666420527, 0.15672713651188783, 0.1841633878648281, 0.22954215428658895, 0.12700578277664526, 0.14474735648504325, 0.20669586663799627, 0.1342912404132741, 0.12409033493271895, 0.08935155400208064, 0.19598831262971672, 0.17108211480081081, 0.26079341449907845, 0.18379252776503563, 0.1922780288649457, 0.10960602786924158, 0.1657883067216192, 0.23986261763742991, 0.1166420288916145, 20.8775406564985, 111.07768944331578, 105.6669395991734, 106.75553471701485, 90.84908621651786, 74.85632719312395, 29.440754209245952, 20.8920293876103, 45.94064835139683, 77.95402867453438, 75.9918851852417, 76.04280158451625, 65.86098085130963, 28.14728103365217, 4.687174865177699, 0.2088681422173977, 0.21311263660235064, 0.23909003766519682, 3.1097216478415897, 0.3008875602058002, 0.2804999170558793, 0.3415104475404535, 1.2552819677761622, 1.3809266771589006, 2.263513352189745, 2.9856728528227126, 3.560646491391318, 7.286872029304504, 40.73706947054182, 73.7755765914917, 83.42057255336216, 85.12990583692277, 79.94154003688267, 70.76818084716797, 73.65664427621024, 78.82165023258754, 83.7428091594151, 83.4863372530256, 75.79685619899205, 75.1112288066319, 75.19830363137382, 74.70590564182827, 77.1642964226859, 80.03311034611293, 80.30613980974469, 75.47860091073173, 73.86605603354317, 71.26724910736084, 66.99287019457135, 64.57691206250871, 69.22863374437604, 66.2225651059832, 72.68658542633057, 78.29321193695068, 80.31245572226388, 84.64891678946358, 66.86289719172886, 39.926093101501465, 64.57529313223702, 69.78277342660087, 53.95919261659895, 71.91313975197929, 78.64636107853481, 74.66740567343575, 68.50049727303642, 70.9355560030256, 77.5419727052961, 78.83637346540178, 76.2671172278268, 70.67516531263078, 79.09123338971818, 79.67370782579694, 68.06892381395612, 60.79104709625244, 65.19015312194824, 65.43307604108537, 65.81429590497697, 62.069334983825684, 64.84753050122941, 71.3249261038644, 75.49896608080182, 75.80486747196743, 73.36647360665458, 78.37396390097481, 73.75457913534981, 61.87522315979004, 28.34618364061628, 5.325564929417201, 4.234312559877123, 5.873248432363782, 7.005291938781738, 2.9707105585506985, 0.26227804911988123, 0.38560203303183826, 0.2569768450089863, 0.21882199309766293, 0.3215239000107561, 0.36928076882447514, 0.20725174966667378, 3.8443479537963867, 25.75018204961504, 63.176196915762766, 98.94706576211112, 86.77834510803223, 74.49612562997001, 70.98393630981445, 35.46691295078823, 21.83602728162493, 47.18383046558925, 59.25557858603341, 77.54436983380998, 86.91788578033447, 110.1231598172869, 54.27062477384295, 1.0099437896694456, 0.33979975219283787, 0.2009488378784486, 0.09577885482992445, 0.09442817659250327, 0.16981055374656404, 0.19109637370066984, 0.2603335848876408, 0.10108092068029301, 0.1583896151610783, 0.13962056301534176, 0.16934292098241194, 0.09907247059579406, 0.15207393334380218, 0.14525270222553185, 0.180881870378341, 0.17485586873122624, 0.2835649140179157, 0.16427088528871536, 0.15446853770741395, 0.18466626373784883, 0.12633040973118373, 0.209363689912217, 0.09526630983288799, 0.11530637341950621, 0.18234787242753164, 0.1270049549639225, 0.1475574549819742, 0.20386944258851664, 0.08687725570052862, 0.12734790013304778, 0.06585064969424691, 0.11571109241672925, 0.1308311867926802], [0.06518065064613308, 0.04020139155909419, 0.030171694034444432, 0.026202611924548234, 0.004551255826040038, 0.037435689608433416, 0.06802854354360274, 0.05353153430457626, 0.01884733303450048, 0.007915194113073605, 0.015914289081203084, 0.03659591770597866, 0.016377307807228396, 0.03091430650757892, 0.03613168440226998, 0.011665435956924089, 0.052106739687068124, 0.12434372705008302, 0.11504026555589267, 0.008323029282369783, 0.024872008145653775, 0.06113538771335568, 0.10232248370136533, 0.13803679442831449, 0.03260336337344987, 0.19379336040999207, 0.022725494844572883, 14.6089141028268, 92.98188441140312, 83.99953814915249, 79.34431457519531, 65.11088807242257, 43.30771534783499, 22.422759226390294, 23.87997191292899, 44.848148345947266, 62.98118877410889, 36.56570107596261, 38.12923336029053, 29.629634039742605, 17.225812401090348, 1.4238391859190804, 0.039959978977484364, 0.08300210828227655, 0.16785593863044465, 0.030034389080745832, 0.08740723904754434, 0.09022718308759586, 0.20000112801790237, 0.7059465306145805, 1.0099429211446216, 1.301247124161039, 3.026201043810163, 2.112755898918424, 11.215557217597961, 50.920467444828574, 78.41495132446289, 76.97975226811, 73.7062544141497, 70.76397718702043, 73.93979031699044, 71.42503574916294, 69.6030582700457, 71.72050094604492, 75.01175144740513, 73.23597254071916, 72.62748404911586, 70.77379499162946, 73.19529778616769, 73.27940573011125, 79.06730379377092, 73.29018238612584, 69.34698241097587, 71.55390398842948, 66.84873676300049, 64.02475261688232, 60.21968282972063, 60.33443232945034, 59.101933070591514, 59.44893305642264, 61.24800927298409, 63.97426700592041, 72.54887213025773, 73.87736770084926, 82.15585449763707, 49.63640213012695, 26.750936303819927, 31.118219579969132, 53.58209998267037, 72.62762301308769, 65.761399269104, 62.69078186580113, 59.55354513440813, 71.96314593723842, 71.68563488551548, 78.51654093606132, 69.89907932281494, 67.88604027884347, 68.77016380855015, 71.14366844722203, 63.053672381809776, 53.8530832018171, 51.55564744131905, 53.34797695704869, 51.498272691454204, 52.06337315695626, 51.42468432017735, 52.553346225193565, 53.6827654838562, 61.213608741760254, 63.019827706473215, 67.47255298069545, 70.24187564849854, 69.5377938406808, 58.962468828473774, 50.19888659885952, 29.171278749193462, 10.978258865220205, 0.8543558727417673, 1.5154747430767332, 1.026947985802378, 0.2305657650743212, 0.05116812898112195, 0.060792652890086174, 0.07220958133361169, 0.12473233762596335, 0.19921709437455448, 0.11197839664029223, 2.079533955880574, 8.533582091331482, 23.072992495128087, 47.19741071973528, 54.9666188785008, 76.08298301696777, 78.27146407536098, 40.12503392355782, 13.473855512482778, 24.193799461637223, 59.56243882860456, 56.30508858816964, 65.00713062286377, 75.82166126796177, 49.02952562059675, 1.9997195644038064, 0.17248242108949594, 0.041741279286465476, 0.11322299271289792, 0.05118096347099968, 0.10239474768085138, 0.10949955893946545, 0.15860576927661896, 0.04596661523516689, 0.011992023343087306, 0.08236034986163888, 0.05867933521845511, 0.03808845725974866, 0.06777647456952504, 0.09638550584869725, 0.007893233327195048, 0.09916218649595976, 0.0883185997871416, 0.06464654180620398, 0.06527483130672149, 0.03923490663458194, 0.07016369647213391, 0.010865973275420921, 0.03751581780878561, 0.048369097390345166, 0.05774739451174225, 0.03241218952462077, 0.0200146948586085, 0.09857714681753091, 0.03521656118599432, 0.04013954309214439, 0.01789764015536223, 0.048871559357004504, 0.0296388540550002, 0.06611756501453263, 0.029464290743427615, 0.05349334296105163, 0.008607218407892754, 0.021980862033420374, 0.017682854984221712, 0.045190920787198205, 0.0070592154016984356, 0.0114902975869232, 0.01728399344054716, 0.0068414904775896245, 0.015062384972614902, 0.017894320422783494, 0.1001131601099457, 0.0649906744116119, 0.060528594202228954, 0.029782272609216825, 0.057038467909608564, 0.026744191435032656, 0.03312298549073083, 0.08803589495697192, 0.07166289923978703, 0.06971434344138418, 0.058618680973138125, 0.2145316975989512, 0.03762424770476563, 22.742530958993093, 111.97966984340123, 92.16162872314453, 89.21015902927944, 72.70526913234166, 55.89132683617728, 37.342217854091096, 25.588554791041783, 32.167376722608296, 37.180884156908306, 27.13896713938032, 34.914239338466096, 31.970468248639786, 20.674910340990337, 2.306625838790621, 0.01217017525673977, 0.12499946329210486, 0.11755901468651635, 0.007726023638887065, 0.14892291171210154, 0.32434758277876036, 0.7975899587784494, 1.6676440920148576, 3.795075237751007, 1.9594517137323106, 0.7897519022226334, 0.9126819287027631, 10.027762668473379, 53.36470127105713, 82.39712374550956, 81.361647605896, 77.70091274806431, 73.82048279898507, 77.5258459363665, 73.36418070111955, 69.883195740836, 70.82189042227608, 75.77085603986467, 75.20325074877057, 74.23488725934709, 76.16508293151855, 75.84571593148368, 76.72963101523263, 79.45750073024205, 75.8975772857666, 74.09062876020158, 72.55324949537004, 71.7929915019444, 64.95897265842983, 64.45423466818673, 61.87298583984375, 61.04182147979736, 60.809084619794575, 64.61533560071672, 67.01102583748954, 76.16363075801304, 74.73746435982841, 85.79197188786098, 53.03872306006295, 33.72610780170986, 38.120930262974326, 59.648124013628276, 73.59877273014614, 67.53151539393834, 64.88069425310407, 63.056743485586985, 75.29978901999337, 74.24796376909528, 79.62082508632115, 70.8678388595581, 67.28060204642159, 71.56082439422607, 73.79883221217564, 66.48854214804513, 57.03039714268276, 55.03802898951939, 56.32269879749843, 54.33387769971575, 55.63882235118321, 54.97775336674282, 56.1488652910505, 58.67142963409424, 64.94095597948346, 68.28748634883335, 72.28426388331822, 73.90849563053676, 75.7557715007237, 66.21791676112584, 57.35009070805141, 35.4627058165414, 13.928762759481158, 1.8032317821468626, 1.2423616839306695, 1.7390145765883582, 1.6748179984944207, 0.669504640357835, 0.3251052349805832, 0.15743725055030414, 0.06576746808631079, 0.138227910601667, 0.05936572088726929, 2.0383563254560744, 11.946160299437386, 27.194314752306255, 47.714592933654785, 50.3913516998291, 55.75269637789045, 52.72493198939732, 29.683711869376047, 20.7811951977866, 43.28604391642979, 75.82466983795166, 64.41096128736223, 71.64160415104458, 85.31176103864397, 71.11626475197929, 7.548130375998361, 0.21491934465510504, 0.046153314145548005, 0.15495970206601278, 0.07582589478365012, 0.027509673930970684, 0.07178127645914044, 0.037133429399026294, 0.018795321628983532, 0.04646506705986602, 0.08473595524472849, 0.03629028857020395, 0.032578020090503354, 0.06435406607176576, 0.12197185360959598, 0.08058948881391968, 0.07035341486334801, 0.023589987474094545, 0.07995106878557376, 0.054391200853777785, 0.09656791641776051, 0.03483084456196853, 0.05142268817871809, 0.07117629463651351, 0.057021463822041235, 0.07409056861485754, 0.014550713589414954, 0.05448047570618136, 0.07416818623564073, 0.01366803198054965, 0.04642834135198167, 0.013589470347921764, 0.07200413450066533, 0.12998939624854497, 0.2250372517321791, 0.08550567858453308, 0.06117832540933575, 0.17884775809943676, 0.07998584370527949, 0.14149390320692742, 0.09166400813098464, 0.0591001422809703, 0.1162778048643044, 0.17670616587357862, 0.12865516569997582, 0.230269869523389, 0.23580329545906611, 0.20668251306882926, 0.14065937298749173, 0.14593004302254745, 0.20147817661719664, 0.16020286429141248, 0.18014015017875604, 0.17859835576798233, 0.20198808211301053, 0.17309258691966534, 0.246714002851929, 0.19369095590497765, 0.2729312117610659, 0.11895031003015381, 29.562497070857457, 130.22370774405343, 103.09279182979039, 103.06324114118303, 83.5258377620152, 61.566083908081055, 32.944098472595215, 34.623016016823904, 61.25954328264509, 85.8403730392456, 52.18243401391165, 57.349854469299316, 48.670647689274375, 28.910078593662806, 3.1843227190630774, 0.10948262270539999, 0.30094339006713455, 0.4100477769970894, 0.24366643066917146, 0.5101139417716435, 0.27320848831108635, 0.44842221641114777, 2.0691633352211545, 4.5078288316726685, 4.4421800800732205, 8.26202825137547, 6.603911008153643, 10.811570712498256, 54.505644117082866, 84.66218784877232, 83.26423808506557, 80.16186046600342, 78.379821232387, 80.02771159580776, 74.25284835270473, 70.3668737411499, 72.73486845833915, 77.12760993412563, 78.02245453425816, 78.11994470868791, 79.3564669745309, 79.48026302882603, 80.14060592651367, 84.57855238233293, 80.4972152709961, 77.51171330043248, 76.97354057856968, 76.10020760127476, 71.39727074759347, 67.69107382638114, 67.63487679617745, 64.00699302128383, 65.16780076708112, 68.23175484793526, 71.16975893293107, 78.3827464239938, 81.38762692042759, 86.75337328229631, 58.6583183833531, 41.329809870038716, 44.80314833777291, 64.30422306060791, 77.3853394644601, 74.35771751403809, 68.80704484667096, 66.66574900490897, 80.10913058689663, 77.80837358747209, 81.82286902836391, 72.13784449441093, 70.29458468300956, 73.19553402491978, 78.07505239759172, 70.86488587515694, 60.2255471093314, 57.16543190819876, 59.214716230119976, 55.69937242780413, 56.771191120147705, 58.071310247693745, 58.475879532950266, 61.75378254481724, 67.82914842878068, 70.60808045523507, 75.62536076136998, 77.5049318586077, 77.45224366869245, 65.78594725472587, 56.8876359803336, 33.897565024239675, 13.728680695806231, 2.908007626022611, 7.127359628677368, 3.938505598476955, 1.4686002412012644, 0.5063096401946885, 0.3633962960115501, 0.34725326938288553, 0.2812802866101265, 0.3542250267096928, 0.2595725671521255, 3.969826340675354, 18.060772214617046, 38.03821543284825, 66.508163860866, 77.76053524017334, 103.86115142277309, 109.27622304643903, 53.609406403132844, 20.744915178843907, 37.42547811780657, 76.14877550942558, 76.35686710902623, 79.54086521693638, 96.79384681156704, 73.74542835780552, 5.9704446111406595, 0.3519684906516756, 0.2340192911880357, 0.188966872968844, 0.2810319427933012, 0.2287756268467222, 0.16871216839977674, 0.1836219033492463, 0.18461443723312446, 0.1816472035965749, 0.170924789671387, 0.20274557146642888, 0.19849492955420697, 0.15692270387496265, 0.21885321927922113, 0.1930744389870337, 0.21474950733993733, 0.11752991910491671, 0.27853178552218844, 0.16923447751573154, 0.15875526411192759, 0.157203576660582, 0.13865823751049383, 0.18324937405330793, 0.0927295863096203, 0.13997357764414378, 0.11834559962153435, 0.14579861078943523, 0.16962297952600888, 0.0692099476499217, 0.14957144191222532, 0.08485206615711961, 0.1716948862054518], [0.04665581343163337, 0.020649128493719866, 0.07430147086935383, 0.044361479580402374, 0.04526862661753382, 0.049247114919126034, 0.033388954254665544, 0.0474727526307106, 0.03666771010362676, 0.04091163791183915, 0.037834142334759235, 0.04544352919661573, 0.038720865467829366, 0.06893319357186556, 0.011573585215955973, 0.032528928081904135, 0.09259420500269958, 0.003998666660793657, 0.015842881752178073, 0.03556024935096502, 0.025021810018058335, 0.025060189655050635, 0.03254234950457301, 0.03548337133335216, 0.016409758744495254, 0.006383822000186358, 13.120458841323853, 96.0961503982544, 78.54855823516846, 86.44522067478725, 82.41561985015869, 85.96179975782121, 33.57246923446655, 25.460405690329416, 42.252172810690745, 58.704072271074565, 68.49288204738072, 63.14279692513602, 51.663921219961985, 26.87552966390337, 3.9383609890937805, 0.06512437973703657, 0.06966540071048907, 0.04041047873241561, 0.06632310684238162, 0.03623282004679952, 0.0070578456091295394, 0.020795220475909964, 0.413506948522159, 0.8102930571351732, 2.5511824531214575, 2.081315734556743, 0.361907101635422, 9.900070411818367, 54.87351301738194, 75.73082746778215, 77.97089890071324, 70.41443416050502, 66.7694925580706, 67.79212147848946, 72.18398053305489, 71.43839713505336, 68.87289292471749, 69.13587529318673, 72.23665482657296, 70.3754825592041, 72.43698528834751, 69.46666513170514, 70.79418100629533, 68.7995616367885, 68.16852624075753, 63.752807072230745, 70.79004682813371, 73.33393519265312, 71.74950272696358, 66.77776786259243, 61.46829496111189, 59.9228002003261, 55.16949585505894, 56.00948095321655, 57.834803989955354, 61.05473818097796, 67.43448380061558, 73.06964656284877, 71.8576305934361, 67.815842628479, 33.380174364362446, 25.242638724190847, 63.859767641339985, 69.10693604605538, 63.58169378553118, 53.89200006212507, 62.77430616106306, 70.05764416285923, 72.54015214102608, 70.86621992928642, 68.28973061697823, 72.37529918125698, 72.09376512254987, 69.24405179704938, 64.76542363848004, 53.327257428850444, 51.34844521113804, 52.3314277103969, 54.45080893380301, 58.82417188371931, 60.67638792310442, 60.03937707628523, 57.19208867209298, 56.123129163469585, 59.53909288133894, 65.15618337903703, 67.84185668400356, 70.17133058820451, 66.75506809779576, 67.31888662065778, 76.22279466901506, 76.00289808000836, 56.00792108263288, 9.623240283557347, 1.642746850848198, 1.7114735458578383, 0.2472458385995456, 0.46040397776024683, 0.104491020552814, 0.06943836289324931, 0.016825958554233824, 0.1385578414691346, 0.0648006031821881, 1.3313244645084654, 4.709070375987461, 15.262678793498448, 29.458986282348633, 42.38311161313738, 40.41363082613264, 52.68521956035069, 50.45990610122681, 16.274829830442155, 15.599857500621251, 49.705390793936594, 65.72656794956752, 56.8409857749939, 70.45237827301025, 63.98829541887556, 5.19693249464035, 0.2525806709059647, 0.04082053780023541, 0.053352567300732644, 0.05555788414286716, 0.07714099064469337, 0.009316295135899313, 0.045255551247724464, 0.04945521143132022, 0.05613383145204612, 0.03515738614701799, 0.03847463868026223, 0.07172966708562203, 0.009120117939476455, 0.03735034686646291, 0.0234247658933912, 0.051395665521600416, 0.01802892141443278, 0.11064365719045911, 0.03236461064911314, 0.048755204172006676, 0.05020456854254007, 0.024235908707071627, 0.024201266101694534, 0.024600148001419644, 0.07953097418482814, 0.09905925951898098, 0.05093883842762027, 0.06649733427911997, 0.04509707260876894, 0.06735283801598207, 0.013123276078009179, 0.018499227606558373, 0.01036571230672832, 0.09044722520879336, 0.013838913391477295, 0.014447321815948402, 0.02039716299623251, 0.01884456630796194, 0.0642755799261587, 0.06056277879646846, 0.03944583942315408, 0.0115147960937715, 0.04670700889879039, 0.04366152321121522, 0.04805515280791691, 0.045783688979489465, 0.04128284067181604, 0.025231526532609547, 0.020444560363622646, 0.010665635811164975, 0.024593612012852515, 0.07421581260859966, 0.010174040582829287, 0.027426212427339385, 0.09217704167323452, 0.07173302583396435, 0.008529163980191308, 20.01094048363822, 111.62330368586949, 86.14835888998849, 99.5818531853812, 94.01709651947021, 97.02093478611538, 51.019204820905415, 31.906756741659983, 36.25275421142578, 42.442876543317524, 50.67198249271938, 54.859779902866904, 51.09680577686855, 32.71570771081107, 4.6062639611107965, 0.033377768604883125, 0.05914184504321643, 0.025436250725761056, 0.1533201579004526, 0.0666674565789955, 0.10099880437233619, 0.4836946651339531, 1.5212427249976566, 1.9564722393240248, 3.7103449957711354, 0.575869901904038, 0.4610172105687005, 12.0771564245224, 59.508124760219026, 79.72318594796317, 80.67793096814836, 75.08262307303292, 70.34891264779228, 70.66051156180245, 75.48798097882951, 73.61198125566754, 69.05595711299351, 70.83170822688511, 73.51381710597447, 70.91221700395856, 71.96709251403809, 71.25506196703229, 72.82437515258789, 70.13064888545445, 68.76980250222343, 68.73750727517265, 73.42053059169224, 74.10782555171421, 72.62638623373849, 69.17819677080426, 64.2508192062378, 62.25390693119594, 59.36527674538748, 58.80644008091518, 61.349432127816335, 64.71599415370396, 70.210782459804, 76.15368788582938, 72.4741928918021, 69.00176811218262, 39.20084708077567, 29.859935556139263, 66.3848055430821, 73.39264747074672, 65.32011917659214, 56.004380975450786, 65.31156594412667, 74.3206627709525, 74.78023052215576, 70.39737633296421, 69.87102249690464, 73.34409345899309, 72.5493654523577, 72.3081865310669, 68.04887131282261, 56.2118124961853, 54.91606378555298, 55.640423910958425, 56.91611664635794, 61.1983574458531, 64.96350983210972, 62.143597330365864, 59.92323098863874, 59.81367179325649, 62.670131819588796, 69.40041405814034, 71.71399743216378, 73.41169248308454, 68.0757747377668, 69.57663427080426, 82.18354306902204, 84.12502956390381, 64.5556366784232, 13.432102050100054, 0.2792652818773474, 0.5468369626573154, 0.5238487933363233, 1.2214621539626802, 0.7069163471460342, 0.3858435372156756, 0.12550350624535764, 0.05293104438377278, 0.08420105930417776, 0.8383888580969402, 4.926945907729013, 17.451507261821202, 33.60213804244995, 41.356751510075156, 41.3529543195452, 47.825117928641184, 51.42168617248535, 22.91035427365984, 23.61892809186663, 65.76996639796666, 78.908613886152, 63.901845932006836, 76.86352280208042, 87.08658109392438, 11.208442262240819, 0.3917219846376351, 0.06293406869683947, 0.1045112544670701, 0.049984271970710585, 0.05572676133098347, 0.03762926886390362, 0.005529795349242964, 0.08223421020167214, 0.03479672782123089, 0.08094951270946435, 0.043866776661681275, 0.001745939622716313, 0.07310122384556703, 0.03230924219159143, 0.09676431159355811, 0.0336450130146529, 0.019992925758872713, 0.047407056870205064, 0.046826916214610846, 0.0627327405714563, 0.03788141586950847, 0.05689321731084159, 0.05936381420386689, 0.027091285845796977, 0.06742730044892856, 0.020874293554308157, 0.018907286692410707, 0.11468126624822617, 0.028854820411652327, 0.0440394604312522, 0.03908448899164796, 0.10806495270558766, 0.08783409185707569, 0.15255472968731607, 0.10806901034499918, 0.1658838987350464, 0.10716184295181717, 0.1468155583632844, 0.12626275978982449, 0.17685138593826974, 0.11319550525929246, 0.1331312305160931, 0.1573967555803912, 0.10995873715728521, 0.1806790969733681, 0.16203108190425805, 0.09645287080534867, 0.19898738312934125, 0.07664142602256366, 0.07826174050569534, 0.12816120577710016, 0.1328993615295206, 0.09367545055491583, 0.15117457588868483, 0.27969107617224964, 0.11666697183890001, 0.08448340451078755, 27.855713776179723, 130.75310489109583, 95.16896888187954, 112.20868246895927, 100.75206879207066, 106.0108893258231, 48.374494620731895, 38.45543391363961, 56.375487736293245, 79.21065207890102, 92.23926094600132, 87.0765687397548, 73.29164845602853, 42.52683162689209, 7.396922809737069, 0.19788670433419092, 0.25368331745266914, 0.0797367806413344, 0.30797257859792027, 0.15311275688665255, 0.14891989901661873, 0.1267253171120371, 1.6832548486334937, 7.060260006359645, 7.692035385540553, 7.702565380505153, 3.6825239743505205, 11.191929868289403, 57.55571917125157, 81.10500199454171, 84.00939764295305, 76.9384799684797, 73.50716073172433, 72.67156342097691, 80.32748467581612, 78.07097380501884, 70.26654870169503, 72.714996610369, 76.1031744820731, 71.63411399296352, 74.47054931095668, 72.01980154854911, 74.39947618756975, 70.61068602970668, 71.4943926674979, 71.02416637965611, 75.29817008972168, 77.71357236589704, 79.63411004202706, 73.21759455544608, 65.604001726423, 64.7338718686785, 62.05711310250418, 61.86850425175258, 65.02426488058907, 68.05012893676758, 74.23928546905518, 78.95476382119315, 75.85688863481793, 70.60455077035087, 43.624442032405305, 38.05689219066075, 69.50174658639091, 77.39383016313825, 68.44228526524135, 59.46275302342006, 68.48293917519706, 77.99509947640556, 76.56222806658063, 71.57236535208565, 72.82231153760637, 77.18263966696603, 76.51218019212995, 73.73641654423305, 72.10322162083217, 58.96374034881592, 57.888374601091655, 58.67238848549979, 61.14907387324742, 65.26746572766984, 67.01429843902588, 66.48453998565674, 63.703002384730745, 62.74888270241873, 65.32487869262695, 72.72197954995292, 74.21793365478516, 75.41364915030343, 68.63686261858258, 67.47872298104423, 82.0139444896153, 85.2676191329956, 64.88118062700543, 11.568037595067706, 4.5803589054516385, 5.548080120767866, 3.491030101265226, 1.4248493888548441, 0.3562374258680003, 0.3803137753690992, 0.3516283817589283, 0.34347752055951525, 0.2720739777599062, 2.476004898548126, 10.234653098242623, 27.10152677127293, 46.249589579445974, 58.91463048117501, 56.44535534722464, 74.13507638658795, 66.75825037275041, 23.197783878871373, 27.617486102240427, 65.15945598057338, 87.66838155473981, 75.1425860268729, 90.32550471169608, 95.05596337999616, 11.142575945172991, 0.4679904335311481, 0.16117605992725917, 0.2671215135071959, 0.16499068880719797, 0.14634924195706844, 0.05486817704513669, 0.146340529567429, 0.18217131761567934, 0.111128674021789, 0.1571079303643533, 0.14259573551160948, 0.17949072431240762, 0.14616705530456134, 0.12774317392281123, 0.20697569447968686, 0.1714744980313948, 0.08499692659825087, 0.221655419628535, 0.1107626925887806, 0.15406744208719048, 0.1350754911878279, 0.14435231339718613, 0.1836143173277378, 0.11017302530152456, 0.17552988470665046, 0.15072630851396493, 0.14877147626663956, 0.18342512819383824, 0.18006789976997034, 0.15602322428354196, 0.09882653557828494], [0.03304718295112252, 0.009459897742739745, 0.046708891833467145, 0.018364836960764866, 0.03987219690212181, 0.01275397406425327, 0.02116331554550145, 0.10065176085169826, 0.06619826318430048, 0.035053892593298636, 0.0848435844693865, 0.010404633075397993, 0.008983187876375658, 0.03482094134337135, 0.02249946804451091, 0.004179210834471243, 0.02693421855968024, 0.032697618672890325, 0.03798758624387639, 0.04691668300490294, 0.03685849718749523, 0.06454400837953601, 0.03637312751795564, 0.04238456441089511, 0.08553023476685796, 13.743848613330297, 85.10850538526262, 86.51276411328996, 90.98731367928642, 78.25401020050049, 55.94444234030587, 29.973434380122594, 27.74634391920907, 36.74247714451381, 45.896044390542166, 56.02446474347796, 47.36111027853829, 29.74370609010969, 16.78535393306187, 3.8608473198754445, 0.04588817997968622, 0.05185518639960459, 0.03480096866509744, 0.08190100879541465, 0.047563937559191666, 0.13279762198882444, 0.13076977937349252, 1.2875953252826418, 2.5439339620726447, 2.5493133877004897, 4.287607848644257, 1.4980139200176512, 10.48201939037868, 63.11115482875279, 76.61312362125942, 76.31229441506522, 70.26643058231899, 60.86900588444301, 60.4991671698434, 70.06701728275844, 70.10281440189907, 72.35385009220668, 68.16908209664481, 70.95083509172711, 67.66441358838762, 67.32119342258999, 66.0396259852818, 68.1378082547869, 67.76309885297502, 70.28353009905133, 63.21625328063965, 68.69296932220459, 69.12185382843018, 67.7619662966047, 70.04167720249721, 67.80959619794572, 65.27752671922956, 60.99718625204903, 58.909335953848704, 56.04822063446045, 56.38939108167376, 57.94194868632725, 63.762207984924316, 71.37497397831508, 74.21510573795864, 69.62488951001848, 51.12406355994088, 18.39858841896057, 61.73127038138253, 71.0770491191319, 60.88352761949812, 54.6997663634164, 60.79801613943917, 71.01838547842843, 66.62701974596295, 69.05540125710624, 71.14528737749372, 67.91293675558907, 66.3763426371983, 65.0657456261771, 56.93042993545532, 51.87205798285348, 50.3825170653207, 52.260135718754356, 62.23314571380615, 67.3251816885812, 69.49641036987305, 67.13578769138881, 63.52783135005406, 60.86829716818673, 63.33921555110386, 66.12742342267717, 71.60674503871373, 68.2072902406965, 64.57352134159633, 71.50562790461949, 68.62453651428223, 70.9926562990461, 77.16988277435303, 76.31681769234794, 16.791183471679688, 0.8490457662514278, 0.9955349628414426, 1.0445042380264826, 0.69522475451231, 0.03108113112726382, 0.03960343596658536, 0.027133036105494415, 0.06550222874752112, 0.020423600416896597, 0.028104788158088923, 2.197919100522995, 9.893751893724714, 26.804633719580515, 37.87222644260952, 43.81765406472342, 35.349008968898225, 62.1368784223284, 51.18279668263027, 13.856451119695391, 30.842011315482004, 53.402026993887766, 60.441781997680664, 73.13237489972795, 46.33049440383911, 1.0253596710307258, 0.19301240731562885, 0.06327132774250847, 0.047351790192936144, 0.023858734838930622, 0.032125114928931, 0.08003545140049287, 0.05616947150390063, 0.03553635813295841, 0.05736311977463109, 0.036531419559781036, 0.043631155376455615, 0.03776074520179203, 0.06667200954897062, 0.07000851551336901, 0.04164465929248503, 0.05532827128523162, 0.03282497969589063, 0.054580763181937594, 0.07520157471299171, 0.017574771141101207, 0.024033912224695086, 0.05160755165187376, 0.0443429895011442, 0.02229786171977009, 0.016280419791915586, 0.04896924804363932, 0.04322141522009458, 0.03183698181861213, 0.05243245006671973, 0.026483196332784634, 0.025908412711162652, 0.02786549599841237, 0.014149915676430931, 0.03323310833158238, 0.03945018543994852, 0.021667339839041233, 0.042824353490556986, 0.03924892516806722, 0.02803872768501086, 0.10045010702950613, 0.02437276752399547, 0.05051309841551951, 0.022700512881523797, 0.07695199828594923, 0.030975503580910817, 0.041738079993852546, 0.005855321252186383, 0.03771242333043899, 0.0025703587161842734, 0.08469324825065476, 0.026107159010799866, 0.05888772689338241, 0.010268591893171626, 0.05523705921534981, 0.09272837173193693, 18.48284227507455, 102.40332208360944, 96.5428500856672, 103.62826170240129, 89.50911917005266, 69.26779379163469, 53.71384825025286, 32.48947089059012, 31.525001866476877, 40.805846214294434, 49.26553160803658, 46.92714316504342, 37.21825851712908, 24.8436610017504, 4.609929570129939, 0.009517004946246743, 0.015867593997557248, 0.08147680905780622, 0.06557683367282152, 0.014428672280960848, 0.6667198783585003, 1.0987612009048462, 3.1512588475431715, 1.9182662665843964, 4.234930081026895, 1.2265018778187888, 0.5991855593664306, 11.781877091952733, 68.80753816877092, 82.39251708984375, 79.64040510995048, 75.4206737790789, 64.9733693259103, 61.78320121765137, 70.77580302102226, 73.06025954655239, 74.89778014591762, 66.83693177359444, 69.93083953857422, 68.09496566227504, 67.5811185836792, 66.59011091504777, 68.83188465663365, 69.47550324031285, 70.69633647373745, 66.03200381142753, 70.2298274721418, 70.87411308288574, 71.90087618146623, 72.83571461268834, 70.37487111772809, 67.95767620631626, 63.36411094665527, 61.117480414254324, 58.457063811165945, 58.47678279876709, 59.2130834034511, 66.69598756517682, 73.7338457107544, 76.6327383858817, 70.63380963461739, 52.49356739861624, 21.64485628264291, 63.09297834123884, 74.8884973526001, 62.77157551901681, 58.79532296316964, 62.73495156424386, 74.50009305136544, 69.94394384111676, 71.66162191118512, 72.83653450012207, 70.4657952444894, 69.3494907106672, 66.61551352909633, 58.84658677237374, 54.772399357386995, 52.81024891989571, 56.880781582423616, 65.65949698856899, 72.031710760934, 71.33669635227749, 70.23546246119908, 67.77399362836564, 63.875011989048545, 66.7844798224313, 70.87223706926618, 75.51621845790318, 70.32877676827567, 65.0775853565761, 75.68576145172119, 72.60468700953892, 74.57887867518834, 80.96455805642265, 83.30673326764787, 20.4226907321385, 0.20346255227923393, 1.1448586987597602, 1.8968959961618697, 1.9721966641289848, 1.1827985772064753, 0.36238240184528486, 0.07320418474929673, 0.027427798502945473, 0.1253193382705961, 0.022541087686217258, 2.088181206158229, 9.9652419090271, 29.299671036856516, 36.85516650336129, 39.914969035557334, 31.86543927873884, 35.838763168879915, 40.68379415784563, 21.618029287883214, 44.54992471422468, 63.656741278512136, 71.44056497301374, 76.79094886779785, 69.4613289151873, 2.3871178967612128, 0.31528729466455324, 0.04274942965379783, 0.06360575051179954, 0.07435714466763393, 0.05718035636735814, 0.016558576741122773, 0.050460026799035926, 0.03443832562438079, 0.02572471122922642, 0.056504121582422934, 0.04463585539321814, 0.025425853872937814, 0.012210503985573138, 0.06112672282116754, 0.035348465000944476, 0.0455777841354055, 0.009464846807532012, 0.041292163742972274, 0.06637445158724274, 0.03552930136876447, 0.02029466688899057, 0.11556378246418067, 0.030099111143499613, 0.02023044863848814, 0.059679753679249964, 0.02457121357188693, 0.06248106514768941, 0.07448403750147138, 0.04930106523845877, 0.056360099132039716, 0.10712225721882922, 0.10987347244684185, 0.12718545884958335, 0.09287963075829403, 0.13203021245343344, 0.16913836981569016, 0.1008605800036873, 0.22736530538116181, 0.1433655877730676, 0.16558208635875157, 0.13105743750929832, 0.12472695005791527, 0.05206813443718212, 0.14681939887148993, 0.062425058867250166, 0.08690004090645484, 0.17578897651817116, 0.20821796996252878, 0.0939062542415091, 0.14653745400054113, 0.101106535377247, 0.10943912861070462, 0.24737969998802456, 0.2080108132213354, 0.1688759938946792, 25.676916769572667, 120.14417839050293, 105.77075958251953, 115.92451654161725, 97.80404540470668, 78.12654549734933, 47.46642759868077, 38.95152834483555, 49.81190667833601, 63.079964365277974, 75.18909726824079, 65.50309998648507, 46.98894044331142, 32.08026715687343, 7.125677730355944, 0.18303114362061024, 0.1967333440801927, 0.1514801609196833, 0.3563086449035576, 0.18957983436329023, 0.45822870305606295, 0.43578697155628887, 3.2215917706489563, 9.595296365874153, 10.864664503506251, 14.078433905329023, 5.9201279282569885, 13.65481265953609, 71.38637597220284, 82.5344409942627, 84.59160109928676, 75.92901788439069, 66.13007068634033, 65.01949841635567, 75.51120185852051, 76.0032593863351, 75.16890580313546, 68.45033822740827, 70.84958594185966, 68.87480367933, 67.7302199772426, 68.85262502942766, 71.33584867204938, 70.22085734776088, 73.85130500793457, 69.78491347176688, 73.74712371826172, 73.05607673100063, 74.95995957510812, 75.34215913500104, 71.03235135759626, 74.53841236659459, 67.21464279719761, 65.05931854248047, 61.95578057425362, 60.873285974775044, 62.55641065325056, 69.73100934709821, 78.09622355869838, 79.90932818821499, 73.22839205605644, 59.77677685873849, 28.939264501844132, 65.7207453591483, 77.43840285709926, 66.68389769962856, 60.87056228092739, 67.32126985277448, 78.93195983341762, 70.33844866071428, 75.45066220419747, 77.47450569697789, 73.2214160646711, 72.30647727421352, 69.96273871830532, 62.36517538343157, 57.79359075001308, 56.373069763183594, 59.94023323059082, 67.7499667576381, 75.34468133108956, 75.13057953970772, 74.35152666909354, 69.59148951939174, 67.81568281991142, 69.75102710723877, 75.31695801871163, 77.42618097577775, 73.95978028433663, 65.1519797188895, 78.35247312273297, 76.05417578560966, 76.89746475219727, 86.305832862854, 83.89290414537702, 20.548873492649623, 4.016984633037022, 4.93871876171657, 4.645671537944248, 2.972077399492264, 0.7586856920804296, 0.3168247735926083, 0.2323776978467192, 0.32353961041995455, 0.23624711164406367, 0.24098901290978703, 4.048039606639317, 16.434075593948364, 42.313011237553184, 55.456425189971924, 57.25490733555385, 49.526443413325715, 83.66052859170097, 70.57972485678536, 24.3833133152553, 44.05059937068394, 72.76231384277344, 80.12826592581612, 88.42875071934291, 78.38449042184013, 2.510794746024268, 0.4890604114958218, 0.15867443702050618, 0.1781988207783018, 0.1392856924129384, 0.16767562473458902, 0.21820881457201072, 0.137876280184303, 0.10929941146501473, 0.14960595220327377, 0.14965393819979259, 0.19755637991641248, 0.12910626935107367, 0.09254478051194123, 0.19734950815992697, 0.10056060645729303, 0.2102654358106, 0.1365982187645776, 0.15109791500227793, 0.09840903298131057, 0.13288341595658235, 0.1441106599356447, 0.15764642932585307, 0.19324650189706258, 0.1058716086138572, 0.11936256076608386, 0.16993229649960995, 0.14033785595425538, 0.2025738206825086, 0.10658388717898301, 0.18793848529458046], [0.02504000493458339, 0.03748513784791742, 0.039829639185752184, 0.038525162397750785, 0.01688515394926071, 0.048190384837133546, 0.036056655392582924, 0.03379224832834942, 0.03407030180096626, 0.04326865143541779, 0.028581794883523668, 0.09806336010141031, 0.03355437091418675, 0.03477867878973484, 0.006444976240995207, 0.010142111269358014, 0.05940077400633267, 0.013930580927990377, 0.03376696950622967, 0.02436285582371056, 0.0485070876644126, 0.04828764604670661, 0.02808837269965027, 0.04993363290226885, 6.110782154968806, 91.86437783922467, 91.75103187561035, 84.10219083513532, 69.06706033434186, 48.33481345857893, 33.796027524130686, 37.525976862226216, 47.750539439065115, 54.607994556427, 46.21234028679984, 37.69388702937535, 35.48965093067714, 23.80739450454712, 4.281919011047908, 0.21383641633604253, 0.07922224075134311, 0.053692913680736504, 0.05404725484549999, 0.06054854313177722, 0.07032227010599204, 0.5568303721291679, 1.6190616360732486, 4.267620052610125, 1.5424234398773737, 0.7434550236378397, 1.167457714676857, 7.729422773633685, 68.72910690307617, 76.44806221553257, 74.44189493996757, 71.35669326782227, 59.29626028878348, 57.136708055223735, 68.88842909676688, 70.1405917576381, 74.34093761444092, 67.57307951790946, 68.97983959742955, 63.64033658163888, 71.21128136771065, 66.53847885131836, 70.21065739222935, 70.58518614087785, 70.05531651633126, 63.60567201886858, 66.79424898965019, 63.30455098833357, 69.3391865321568, 66.10432066236223, 67.79378904615129, 66.99381514957973, 68.26967116764614, 57.472924436841694, 60.34142221723284, 53.18772717884609, 58.18652180262974, 57.0196031161717, 63.42170456477574, 66.11750834328788, 74.02827562604631, 59.96749101366316, 46.477337632860454, 18.740731613976614, 52.08846657616751, 73.71387658800397, 66.11781406402588, 57.04127107347761, 54.256252425057546, 67.69843196868896, 66.02784878867013, 73.09090805053711, 67.59657832554409, 61.40527479989188, 58.87405300140381, 55.896315642765586, 49.86556761605399, 51.10543196541922, 54.98671306882586, 61.10453592027937, 66.79652799878801, 66.80992412567139, 67.88911833081926, 67.57694966452462, 66.87828050340924, 65.01132038661412, 64.90750040326799, 67.62344006129673, 68.69452571868896, 60.97104018075125, 67.914076260158, 71.78828062329973, 72.22285570417131, 68.97168936048234, 69.12851020268032, 70.6286540712629, 74.07705198015485, 6.815071105957031, 1.2282159115586961, 0.6971586335982595, 1.390676628266062, 0.22400579707963125, 0.15745626310152666, 0.07160547482115881, 0.05929220840334892, 0.1440796915973936, 0.043405281246772835, 0.10679056216031313, 0.06473435102296726, 2.6308342133249556, 22.66951755114964, 48.41014930180141, 60.33068725040981, 117.26811054774693, 118.19440269470215, 54.38082320349557, 20.082077877862112, 41.18557916368757, 60.06755896977016, 66.11055319649833, 66.64545331682477, 34.630829266139436, 0.6743454720292772, 0.053551995528063605, 0.07810907012649945, 0.0520681955053338, 0.03788112409945045, 0.03634749246495111, 0.04391172282131655, 0.07151864269482237, 0.022739818718816553, 0.04010211510051574, 0.030635045242628882, 0.0531863669332649, 0.08039947186729737, 0.030513594259641, 0.08209218603691884, 0.06206459392394338, 0.019481188218508447, 0.014384253682302577, 0.03377922384866646, 0.04294527521623032, 0.0244146704540721, 0.04824338520744017, 0.07323420313852173, 0.03171761054545641, 0.02377727162092924, 0.04226704893101539, 0.04385674112875547, 0.0552514204090195, 0.031447614676186016, 0.04125030152499676, 0.02379402973955231, 0.028817752043583562, 0.023717913377497877, 0.0413811095058918, 0.0425132383991565, 0.013027652682337378, 0.03357358363323978, 0.011817399811531817, 0.003937679509233151, 0.047594356284077675, 0.021519059581415992, 0.0835740997322968, 0.01805569131725601, 0.05573361792734691, 0.07366197197032825, 0.029140873812139034, 0.027715551633653895, 0.11097225812929017, 0.034055635266538174, 0.00729159583404128, 0.02089948077420039, 0.04397494871435421, 0.021252200240269303, 0.02400898454444749, 9.190855622291565, 107.18518352508545, 100.39942686898368, 96.03841781616211, 74.38695553370884, 76.76201656886509, 54.46302386692592, 36.98004995073591, 48.67751598358154, 40.29024124145508, 53.97525337764195, 40.57913344247, 42.11451162610735, 27.785451854978287, 4.772040597030094, 0.16027824953198433, 0.02289019904232451, 0.1376233494707516, 0.07018730949078288, 0.21433325324739727, 0.6063471979328564, 1.857964153800692, 2.6448958473546162, 3.32282007592065, 3.366826274565288, 1.2406304968254906, 1.0356243316616331, 8.658974494252886, 72.77231924874442, 80.8930333001273, 76.81687259674072, 71.89758273533413, 61.34425571986607, 59.759086745125906, 71.56324931553432, 71.18182795388358, 76.73625264848981, 70.41610172816685, 69.23902130126953, 65.63080092838833, 71.59297370910645, 68.29624802725655, 72.32951055254254, 72.58727482386998, 73.07751887185233, 67.7736462184361, 69.94952324458531, 66.03823634556362, 72.94437054225376, 68.15715203966413, 71.7774692262922, 69.7752902167184, 71.22279453277588, 61.36871337890625, 63.31740515572684, 56.25449180603027, 61.94578906467983, 58.480937821524485, 67.72185434613908, 68.32428400857108, 76.17139884403774, 62.752940450395855, 52.50189134052822, 20.89921382495335, 52.95503200803484, 77.03046716962541, 68.05127538953508, 58.67701598576137, 56.92063644954136, 70.24514130183628, 67.20205960954938, 74.19797842843192, 69.70752443586076, 63.45362458910261, 61.95808737618582, 57.947965826307026, 52.71239396503994, 51.55460173743111, 58.492659432547434, 64.72297709328788, 69.6546208517892, 69.41101700919015, 70.19344670431954, 71.83054651532854, 71.24878079550606, 69.004853112357, 67.09895529065813, 69.14909771510533, 72.58098670414516, 61.17813123975481, 70.0100906917027, 75.04091998508999, 76.31351729801723, 73.43926988329206, 72.76573235648019, 75.4016843523298, 81.26691586630685, 9.007444024085999, 0.6689396106771061, 0.5246944108179638, 1.7077165246009827, 2.43708912389619, 0.9206960243838174, 0.4068968232188906, 0.10520943985985858, 0.09899606755269424, 0.0791564771373357, 0.10289189671831471, 0.05125351922054376, 2.472935748951776, 22.412856306348527, 45.871148994990754, 37.73768499919346, 102.41485609327043, 115.62304810115269, 49.60861280986241, 34.45275388445173, 53.909419195992605, 66.62464346204484, 75.22223322732108, 75.2324470792498, 56.47856426239014, 1.7696410417556763, 0.08038715645670891, 0.05328373331576586, 0.014214267089430774, 0.009994691054868911, 0.03000365144440106, 0.02527726997089173, 0.035157080806259594, 0.020333387489829744, 0.06745531037449837, 0.025068564473518302, 0.022148293941946964, 0.02732011499548597, 0.0202891300432384, 0.03260438796132803, 0.01752724145938243, 0.025194419148777212, 0.053841512849820514, 0.004237248055038175, 0.09059604829443352, 0.010249934724665113, 0.05051397711836866, 0.030446856947881833, 0.05993250118834632, 0.02188354654104582, 0.005287529933931572, 0.03337157018748777, 0.018901162913867404, 0.06119221502116748, 0.03123446986345308, 0.2081661434578044, 0.13852182483034475, 0.114980459479349, 0.1079722580366901, 0.1347345816237586, 0.10817801699574504, 0.10019737309111015, 0.1351390699190753, 0.17479808468903812, 0.10277569759637117, 0.06132718242172684, 0.18128226032214506, 0.10918015215013709, 0.09305929326053176, 0.17059285034026417, 0.09418032810624156, 0.09084870080862727, 0.1847691296466759, 0.16855337763471262, 0.11279465391167573, 0.12054287243102278, 0.08337682924632515, 0.08374435095382587, 0.08529124116258961, 13.20935148852212, 124.10990442548479, 110.06219632284981, 108.69984912872314, 88.57581629071916, 69.6991240637643, 52.51480804170881, 51.693041120256694, 61.60425731113979, 73.54813425881522, 65.44233104160854, 55.15649924959455, 54.14794390542166, 37.951262201581685, 7.717696819986616, 0.44283429054277285, 0.12262130661734513, 0.3523047726069178, 0.3122138838682856, 0.18795303308538028, 0.33574716108185904, 1.5721708493573325, 4.461682370730808, 11.98630438532148, 7.48155186857496, 2.562636124236243, 6.3366676568984985, 9.437506249972753, 78.80703122275216, 83.61949947902134, 80.73453099387032, 74.2523272378104, 64.28722776685441, 62.03792217799595, 75.42459951128278, 73.75063255855015, 81.84207384926933, 71.03745133536202, 69.658616065979, 66.16392230987549, 75.455783026559, 71.56006704057965, 76.66298389434814, 77.89674772535051, 76.12941087995256, 71.7403450012207, 73.95469420296806, 70.51449516841343, 75.9463814326695, 71.60058198656354, 73.77629225594657, 72.55347183772496, 73.34988130841936, 64.0197777066912, 67.01977361951555, 59.5034555707659, 64.80976009368896, 61.78043583461216, 69.72936262403215, 71.80377510615757, 77.94969299861363, 65.0130921772548, 58.89869131360735, 26.24261130605425, 58.84154238019671, 83.11075237819126, 69.83187634604317, 61.86664908272879, 59.58482592446463, 71.26775632585797, 69.65381486075265, 78.67923995426723, 73.7836434500558, 67.27940000806535, 63.93160506657192, 61.90403733934675, 53.70693131855556, 54.30730084010533, 61.51502854483468, 66.81177234649658, 76.02807140350342, 72.5969467163086, 71.42208276476178, 72.57304491315568, 72.52474103655133, 73.69361564091274, 72.58004869733537, 71.65332576206752, 76.60628659384591, 61.21343503679548, 71.89697129385812, 77.94692066737584, 79.46077333177838, 75.15756634303501, 75.2561126436506, 77.06926591055733, 85.53128937312535, 7.050513855048588, 3.7989788225718906, 4.370265790394374, 4.589086277144296, 2.466935328074864, 0.7204502437795911, 0.2958447422300066, 0.28701626881957054, 0.3455056888716561, 0.35199956755552975, 0.22949150843279703, 0.2747797311416694, 4.556101441383362, 35.06816278185163, 70.8169641494751, 73.74648448399135, 119.69984109061105, 126.71107373918805, 67.85938004084996, 33.57386582238333, 56.83309262139456, 78.31143706185478, 85.09535939352853, 85.84328433445522, 61.432303292410715, 1.5496578173977988, 0.221736450280462, 0.1517473544393267, 0.1496525811297553, 0.14423533395997115, 0.1476426382682153, 0.11246526587222304, 0.11587178307984557, 0.24648889207414218, 0.14702823837952955, 0.18846246360668115, 0.09917580469378404, 0.08164144200938088, 0.1343990189156362, 0.15105843783489295, 0.13834908338529722, 0.10154461115598679, 0.11571235449186393, 0.13334857885326656, 0.2068790846637317, 0.08344342067305531, 0.11079613757984978, 0.12199256249836513, 0.20887238984661444, 0.08688972038882119, 0.1893915408956153, 0.11624980850943498, 0.15185890559639248, 0.13990136794745922, 0.16287543731076376], [0.011206454514259738, 0.015321926313585468, 0.05516828290585961, 0.002912581033472504, 0.024468208563381007, 0.03205526314143624, 0.013734061071383101, 0.016294823394023945, 0.013215577196595924, 0.05329692403652838, 0.054056560953280756, 0.056155134058956585, 0.018158494461593882, 0.035366103518754244, 0.07549336512706109, 0.03906871983781457, 0.10884380234139306, 0.0614215327160699, 0.07433064787515573, 0.038719013067228455, 0.10649948420801333, 0.14217132542814526, 0.08655774034559727, 0.38811953365802765, 50.69482816968645, 92.6470159803118, 86.4147389275687, 70.0469856262207, 64.63939026423863, 25.49952925954546, 60.49004418509347, 80.08521488734654, 34.65704829352242, 54.506099224090576, 39.59630727767944, 39.30244364057268, 16.65949078968593, 1.5745887139013834, 0.032023694299693616, 0.012119253748096526, 0.05220887277807508, 0.11340968483792883, 0.054105364584497044, 0.1259988232382706, 0.31361497725759235, 1.9529799010072435, 3.65197491645813, 3.566752220903124, 1.515061216694968, 0.859280951321125, 9.897269419261388, 66.82742663792202, 74.1426499230521, 72.72845527103969, 68.36805071149553, 58.84314741407122, 56.448113782065256, 70.67587402888707, 72.74822289603097, 71.50530133928571, 69.2937661579677, 72.18680150168282, 66.74362441471645, 70.83124964577812, 67.32031100136894, 65.80403341565813, 63.101093837193076, 63.38921478816441, 61.355622972760884, 63.65034893580845, 60.70912783486502, 59.349011012486045, 59.59578323364258, 63.01273359571184, 67.75203732081822, 64.87148094177246, 67.49047933306012, 64.34456430162702, 58.71324389321463, 49.22999504634312, 51.8542914390564, 53.40387521471296, 61.91838536943708, 67.143479347229, 70.3115382875715, 59.71154022216797, 59.552176339285715, 22.68902461869376, 34.539762701307026, 66.17043972015381, 64.83676079341343, 59.300331933157786, 54.55837399618966, 68.73838274819511, 67.31980378287179, 68.45069258553642, 62.41451454162598, 57.471190861293245, 50.03347430910383, 49.30807195390974, 47.392655100141255, 54.38273048400879, 57.88463299615042, 63.38048785073416, 68.4148120880127, 67.34816632952008, 60.64077145712716, 62.74472767966134, 62.242595263889854, 66.23204244886125, 66.39023903438023, 68.52581650870187, 66.06027603149414, 64.12661320822579, 68.69349043709892, 70.17373466491699, 65.40739549909318, 62.58132689339774, 67.35954053061349, 74.03752367837089, 73.09165845598493, 58.337096214294434, 1.7132352398974555, 0.8580946549773216, 1.8016482442617416, 2.481689827782767, 0.38650424033403397, 0.02280432534670191, 0.07253259792923927, 0.08694221864321403, 0.03814929810219577, 0.3388527887208121, 0.08954374904611281, 0.10062248885099377, 0.218500856044037, 13.560245939663478, 50.563079902103965, 68.89739922114781, 107.66583905901227, 71.08757563999721, 15.603696380342756, 31.200965676988872, 54.96765068599156, 57.64196368626186, 61.42344433920724, 74.0462784085955, 23.671472106661113, 0.8826616938625063, 0.011417573051793235, 0.11607344368738787, 0.07479265558400325, 0.0983282398166401, 0.03579481890691178, 0.06377260227288518, 0.08916787457253252, 0.07988823644284691, 0.055639053894472976, 0.0367956580594182, 0.03413247935740011, 0.06928319550518479, 0.030925342879657234, 0.04345250049872058, 0.10471226368099451, 0.013200223645461457, 0.02127643920747297, 0.029100755429161445, 0.021720075580690588, 0.035676709708890746, 0.06841895223728248, 0.05580425003011312, 0.028659765342516557, 0.034799899972443066, 0.036244521383196115, 0.02871755277737975, 0.06269805386130299, 0.025330864059339677, 0.18103530071675777, 0.018017542382170047, 0.04784492908843926, 0.02420068934692868, 0.07382178053792034, 0.04677675212068217, 0.03733603995559471, 0.02168395716164793, 0.03278489184698888, 0.0408180306133415, 0.02378142255890582, 0.037411150389484, 0.03035218095672982, 0.04631904971652797, 0.12398206788514342, 0.025231657150600637, 0.042987877037376165, 0.03586893867967384, 0.1464887216155018, 0.08315524685063533, 0.06407027558556624, 0.09490809762584311, 0.08428162176694189, 0.2947440498641559, 64.566239629473, 105.45553370884487, 96.81209972926548, 79.77370629991803, 79.96214144570487, 32.202659675053184, 54.49999523162842, 63.30073642730713, 27.500252621514456, 51.32819816044399, 38.614936760493684, 43.09767477852957, 21.336708886282786, 2.195567569562367, 0.07983884587883949, 0.06818843353539705, 0.017734593279393654, 0.013254248603646244, 0.15286757504301413, 0.7099691576191357, 1.1526476293802261, 2.911094580377851, 3.384648186819894, 3.972685090133122, 0.6623181945511273, 0.7304621094039508, 10.847085561071124, 71.94554615020752, 78.00167942047119, 75.55254364013672, 70.70281219482422, 61.55855900900704, 59.63075351715088, 74.03614793504987, 75.58057962145124, 74.20148032052177, 70.90886102403913, 71.77747617449079, 68.05738980429513, 71.7339665549142, 69.80100549970354, 69.27745178767613, 66.75151062011719, 65.96896975381034, 65.5756322315761, 68.5311735698155, 63.43411404745919, 62.95805822099958, 63.532674244471956, 65.41450350625175, 70.37365518297467, 66.9234368460519, 70.00137765066964, 66.56242929186139, 61.077896526881624, 52.594430923461914, 56.146617548806326, 54.735337666102815, 63.89819812774658, 68.57653835841587, 71.59075723375592, 61.53824247632708, 66.92506967272077, 25.47269705363682, 40.988062722342356, 71.26298291342599, 65.93720258985246, 61.85936042240688, 57.36799621582031, 70.26412378038678, 67.40241091591972, 74.74605928148542, 62.996182986668174, 61.49571255275181, 52.678253991263254, 52.00795432499477, 49.035230091639924, 56.3198048727853, 61.40292630876814, 66.71722820826939, 71.24428531101772, 69.58588232312883, 61.26595646994454, 63.98760754721505, 65.03664657047817, 68.03593376704625, 68.5123370034354, 70.4951513835362, 67.22030557904924, 64.1189910343715, 70.08160155160087, 74.81490203312465, 66.99658748081752, 65.31854888371059, 68.81730038779122, 77.12968049730573, 74.06829030173165, 66.40051542009626, 2.5989576152392795, 0.038677049069000144, 1.0822201456342424, 2.6261124781199863, 1.0464550533464976, 1.039512065904481, 0.44962154062730925, 0.1921311260334083, 0.12142849633736269, 0.10661272491727557, 0.09425905852445535, 0.10431944618799857, 0.28721355966159273, 14.144255927630834, 48.3393680027553, 65.7749968937465, 114.48840032305036, 73.40966360909599, 20.86671015194484, 44.118639605385916, 62.00024209703718, 63.53065231868199, 67.5869620186942, 83.99907261984688, 39.29171909604754, 0.7652622706123761, 0.011014616549281138, 0.13782890486930097, 0.06153762327241046, 0.033439257448273044, 0.0652398324704596, 0.06500651141894714, 0.047400919520961385, 0.03519416953037892, 0.0800545657319682, 0.028217618353664875, 0.026752416975796223, 0.03143245620386941, 0.04137080255895853, 0.08888771424868278, 0.0363645135158939, 0.05827557295560837, 0.03313587087073496, 0.03341745272544878, 0.062377337499388626, 0.016270891463916217, 0.06475752977920429, 0.02433576700942857, 0.02810757015166538, 0.07880787977150508, 0.059520012965159755, 0.0032570266131577747, 0.01564034413812416, 0.03833631931671074, 0.26731937431863373, 0.10689113462077719, 0.18414247541555337, 0.06090582574584654, 0.1414622834750584, 0.19668960571289062, 0.16103203408420086, 0.11688871708299432, 0.1417110479835953, 0.143566705552595, 0.13656583907348768, 0.1788918628756489, 0.11553613894752093, 0.16445554180869035, 0.22096999069409712, 0.11371194504733596, 0.2539110609463283, 0.14530273739780697, 0.25450627186468666, 0.1342039808098759, 0.18731728648500784, 0.1882835067808628, 0.16440705369625772, 0.8223904137100492, 80.27670724051339, 116.62367902483258, 110.28637300218854, 89.33599785396031, 87.44998577662876, 39.068445682525635, 73.58884375435966, 94.373580796378, 46.60532692500523, 71.72652503422329, 57.71451677594866, 61.10379246303013, 27.01695850917271, 3.0105530491897037, 0.18150959669479302, 0.1822647111756461, 0.09994491735207182, 0.2700015961059502, 0.1541512140205928, 1.031302986400468, 1.556496581860951, 6.064240080969674, 10.921893341200692, 12.90701973438263, 6.108649058001382, 2.8805185982159207, 12.653608509472438, 77.08111953735352, 81.05703163146973, 78.7535787309919, 73.13259724208287, 64.33209923335484, 62.45750304630825, 77.75383717673165, 78.37734767368862, 78.43206473759243, 74.23417159489223, 73.31727341243199, 67.34256608145577, 75.00151675088065, 71.61930043356759, 71.98301083700997, 70.83129828316825, 70.33862931387765, 67.64313125610352, 71.51212447030204, 68.10994597843715, 67.94371727534703, 66.08468505314418, 70.6419459751674, 72.9419525691441, 71.77456487928117, 74.60543469020298, 70.86173834119523, 64.20018768310547, 56.123935154506135, 57.39464603151594, 58.47015421731131, 67.97139889853341, 71.6607255935669, 75.255494253976, 64.32904202597481, 63.96562344687325, 29.751446383340017, 43.33964579445975, 74.37747819083077, 69.69552489689418, 64.17998232160295, 60.353699684143066, 72.74019077845982, 71.90127917698452, 77.31141063145229, 67.98214776175362, 65.3838688986642, 54.32135009765625, 53.55734355109078, 51.27808427810669, 59.89292989458357, 63.71415424346924, 69.40049048832485, 74.00673621041435, 70.78202165876115, 62.66646317073277, 65.09708895002092, 66.21185098375592, 70.98577063424247, 69.30827399662563, 73.9199879510062, 68.55185835702079, 65.37935951777867, 72.46277700151715, 76.9990543637957, 72.78816808973039, 69.66855893816266, 73.17535645621163, 80.34209673745292, 76.85035596575055, 68.10889680044991, 2.03216113788741, 4.7960401092256815, 7.696347611291068, 6.81059125491551, 1.9702385749135698, 1.0369021488087518, 0.5092554049832481, 0.30933456122875214, 0.22334282765431063, 0.6844730685864175, 0.22209671166326317, 0.2438167126051017, 0.7839913027627128, 23.592250483376638, 70.37020192827497, 75.37502411433628, 106.15336213793073, 85.2010553904942, 24.07538652420044, 44.954521792275564, 69.89106110164097, 75.95480959756034, 80.05773476191929, 96.32099410465786, 44.633966650281636, 0.9607594460248947, 0.09383932354726962, 0.1806950561170067, 0.16939577886036464, 0.24059958809188434, 0.10981198360345193, 0.13186911466930593, 0.15708296027566704, 0.0991367075060095, 0.22288864345422812, 0.07513366692832538, 0.16322174801358155, 0.15228332925055707, 0.19153295670236858, 0.17256182325737818, 0.14156562435839856, 0.13807378815753119, 0.099208951129445, 0.17163590794163092, 0.06708023657224008, 0.09601025562733412, 0.21254243648477963, 0.14339914811508997, 0.2043770682066679, 0.16060321352311543, 0.1282712234450238, 0.09051944847617831, 0.19815274434430258, 0.1066605005679386], [0.025482431819130267, 0.03363042790442705, 0.0031895653893505888, 0.020407512351604443, 0.046553242685539384, 0.04893369620133724, 0.1103634290131075, 0.04876230164830174, 0.018183780069063817, 0.05761867641870465, 0.07714523148855992, 0.030906496569514275, 0.03816993235211287, 0.020923385562907373, 0.026565387279593518, 0.023998007544183304, 0.017554197959335785, 0.06687451153993607, 0.03284660121425986, 0.04934833538053291, 0.05715635658374854, 0.1714416162243911, 0.42592503502964973, 13.418490529060364, 88.24309485299247, 89.21935844421387, 79.87842954908098, 71.25396415165493, 32.55230345044817, 65.64428043365479, 169.22386305672782, 76.13729708535331, 59.5135235105242, 45.9636538369315, 47.329791273389546, 17.835568938936504, 0.6837970848594392, 0.08160336262413434, 0.14497419074177742, 0.07318667176046542, 0.16442922822066716, 0.01960718708245882, 0.4419318661093712, 1.2105640130383628, 1.4143859446048737, 2.245518386363983, 0.333579811666693, 0.5018060132861137, 1.7109154100928987, 18.28044993536813, 71.36708777291435, 77.71180752345494, 72.99725328172956, 68.82875796726772, 61.17664432525635, 52.945954186575754, 65.55044501168388, 70.15908091408866, 70.05398941040039, 63.96563734327044, 70.11641202654157, 64.39219420296806, 67.61918081556047, 65.09824929918561, 63.62384850638253, 59.54398441314697, 61.14780930110386, 60.139542307172505, 59.57274300711495, 56.61582939965384, 55.53152826854161, 52.44296019417899, 56.988641943250386, 59.532040459769114, 67.17248112814767, 64.7167306627546, 67.89786611284528, 61.64792673928397, 54.79905612128121, 46.06111969266619, 50.53401558739798, 54.46174192428589, 65.07891941070557, 60.096776144845144, 72.64306885855538, 60.98083714076451, 73.81663349696568, 24.41076043673924, 42.73187296731131, 74.43451595306396, 59.63909830365862, 57.868384633745464, 52.14605672018868, 66.41522475651333, 65.083498273577, 70.79327079227993, 61.15447262355259, 55.48481900351388, 49.37839119774954, 48.77947384970528, 48.92614337376186, 58.88954748426165, 60.74232632773263, 69.15809563228062, 65.45638029915946, 60.23689351763044, 60.105266843523296, 64.22877952030727, 64.4513442175729, 64.94526386260986, 62.14047758919852, 62.013186591012136, 64.82569926125663, 61.50702422005789, 66.8594856262207, 69.77927153451103, 63.961468424115864, 61.470177922930034, 57.191477230616975, 66.96712711879185, 69.59598500388009, 75.60050010681152, 35.020529406411306, 0.48179308431489126, 1.3543276701654707, 2.2969832590648105, 1.7540544952665056, 0.6517471617885998, 0.049814553399171145, 0.05153764218890241, 0.10531346606356756, 0.07391744719019958, 0.07480754942766257, 0.19484689459204674, 0.06185498088598251, 0.7557317848716463, 10.6132595709392, 33.10717616762434, 39.13660751070295, 35.59661497388567, 48.25306790215628, 20.740404060908727, 32.928312165396555, 53.70406518663679, 59.15783132825579, 59.27826445443289, 67.53194618225098, 12.109836408070155, 0.26410482823848724, 0.02946416860712426, 0.05188923867951546, 0.06743583641946316, 0.048639439312475066, 0.012902258562722375, 0.019751949136012366, 0.15275797806680202, 0.03351437806018761, 0.04280257930180856, 0.024072013662329743, 0.014453033384467875, 0.028191778043817197, 0.036561295456652126, 0.0385857996796923, 0.03517966584435531, 0.03622621111571789, 0.015536840406379529, 0.014209323113651147, 0.06341753846832685, 0.04056768511821117, 0.059608894267252514, 0.04755936762584107, 0.04676299821585417, 0.03636349571336593, 0.038334005512297153, 0.0055928969855553335, 0.051113439058618884, 0.04041091978017773, 0.030570262111723423, 0.026663354165585976, 0.024401223586340035, 0.02146633232145437, 0.02537407147298966, 0.050927055667021444, 0.036255744352404556, 0.05227706554744925, 0.07896781047540051, 0.009024557308293879, 0.0185924413547452, 0.02519784914329648, 0.050497702455946376, 0.03281330889356988, 0.05400278026770268, 0.03110749221273831, 0.04412572258817298, 0.04907136077859572, 0.06533538377178566, 0.008066498092375696, 0.14634873984115465, 0.2863271486546312, 19.18972420692444, 108.98144572121757, 95.3659920011248, 92.71212754930768, 80.43268040248326, 43.28274352209908, 70.0364521571568, 152.94470623561313, 73.61147403717041, 49.886464323316304, 42.10450969423567, 50.17440462112427, 21.05975890159607, 0.6329981535673141, 0.07984113932720252, 0.04185878798099501, 0.06475725157984666, 0.033342559422765455, 0.4995739044887679, 0.8161389348762376, 1.8137533089944293, 1.7399962267705371, 3.415896624326706, 0.929329161133085, 0.6936667838266918, 2.829943529197148, 23.851140362875803, 71.7457298551287, 82.46846784864152, 76.32745538439069, 71.99794946398053, 63.70590673174177, 57.092930930001394, 69.2202959060669, 72.89888068607875, 71.47869668688092, 69.58319337027413, 71.82163197653634, 65.1136395590646, 70.33962290627616, 68.58360467638288, 65.19376618521554, 62.56658976418631, 64.66120760781425, 62.61543560028076, 62.86732169560024, 60.06350122179304, 60.328074727739605, 56.7243116242545, 59.82223197392055, 61.055328777858186, 68.56402465275356, 67.7628070286342, 70.41049453190395, 64.8073421205793, 57.31913300922939, 49.09546749932425, 54.08907181876046, 57.59891264779227, 69.27313695635114, 64.28253773280552, 74.57417474474225, 60.856665883745464, 73.7438302721296, 25.574953692299978, 45.035506520952495, 76.8730696269444, 61.95614882877895, 61.57806955065046, 54.552686895642964, 69.33038316454206, 68.00849533081055, 72.64339542388916, 65.81876359667096, 58.39796938214983, 52.13945593152727, 52.01473229272025, 51.24335718154907, 61.00696931566511, 62.705331393650596, 70.37753922598702, 67.30128683362688, 61.62457384381975, 59.62757124219622, 64.72745868137905, 65.00128718784877, 66.58253043038505, 62.57003607068743, 62.77671023777553, 64.26570224761963, 61.92237363542829, 69.15714372907365, 72.88645035879952, 69.26390974862235, 64.06333596365792, 60.047631536211284, 68.7675095966884, 73.2191995893206, 78.08555807386125, 41.02717413221087, 0.266679760068655, 0.6006726367133004, 0.8190534327711377, 3.0314373799732754, 1.3899672606161662, 0.6354543960520199, 0.34052388476473944, 0.4026324206164905, 0.09597031027078629, 0.2169509463544403, 0.05498953303322196, 0.05066429976640003, 0.46550031857831137, 12.841692771230425, 39.2865947995867, 45.97657748631069, 36.98760264260428, 34.72807625361851, 29.728545120784215, 44.894058568137034, 62.76439108167376, 67.2129613331386, 65.28262669699532, 81.94669287545341, 21.64912073952811, 0.1997843360794442, 0.10637234710156918, 0.03059210754664881, 0.05478174186178616, 0.05392768340451377, 0.08038577903062105, 0.08819152374884912, 0.0571200821016516, 0.029504677147737572, 0.047548694269997735, 0.04631834404010858, 0.023285404978586093, 0.03739515392641936, 0.04246763406055314, 0.03797054144420794, 0.020125355438462326, 0.019005429997508014, 0.023938898662371293, 0.046216974300997596, 0.06190492106335504, 0.02914947085082531, 0.05153320456988045, 0.046195196719574075, 0.06234337003635509, 0.006639885849186352, 0.017894817449684654, 0.02809213856900377, 0.016334293776058724, 0.08513658946113926, 0.13987440296581813, 0.13086108304560184, 0.11333603664700474, 0.09565650818071195, 0.14552203991583415, 0.127347398017134, 0.19705734455159732, 0.1628141655985798, 0.1597649920731783, 0.14231104935918534, 0.06142313405871391, 0.17495976601328167, 0.10472797855202641, 0.10724174045026302, 0.12934885919094086, 0.12267531800482954, 0.17667804738240583, 0.21829933114349842, 0.17940248761858257, 0.14049463825566427, 0.3025733126061303, 0.6341267472931317, 26.927950348172867, 122.84305327279228, 108.78107357025146, 102.22280093601772, 92.74477018628801, 46.71682466779436, 80.29512691497803, 169.95856557573592, 80.49332427978516, 76.61188684191022, 62.856100354875835, 72.2936578478132, 27.444130284445627, 1.8046279358012336, 0.1587016327040536, 0.2670642722930227, 0.20546330777662142, 0.41557634462203297, 0.3341367803514004, 1.7241770241941725, 4.815844646521977, 4.138560303619929, 8.103579793657575, 4.901794731616974, 2.9369831340653554, 6.217953775610242, 24.23810464995248, 78.61289855412075, 82.01536192212785, 78.65323284694126, 73.67491109030587, 66.80217688424247, 59.59182276044573, 71.36435713086809, 75.55131380898612, 73.88826247623989, 71.40343379974365, 71.46191678728376, 64.5554004396711, 72.36193084716797, 72.28499344417027, 71.50940077645438, 66.72435011182512, 68.30271680014474, 67.02209431784493, 65.65130506243024, 65.16563987731934, 63.13842650822231, 58.56394100189209, 63.5996618270874, 64.46285043443952, 73.13547379629952, 70.78760801042829, 74.20402336120605, 68.04199259621757, 60.533303669520784, 50.44841725485665, 57.31213617324829, 60.94863224029541, 73.24146161760602, 66.782089642116, 78.01598576136998, 63.435260500226704, 74.62376403808594, 29.88390336717878, 46.60249205998012, 79.4245662689209, 65.30117143903459, 64.63112885611397, 58.12886912482125, 72.8521957397461, 70.22204548971993, 75.22043364388603, 68.5663731438773, 60.15512711661202, 55.550983224596294, 53.862633500780376, 54.05789177758353, 64.09684712546212, 65.90342739650181, 73.90613324301583, 69.39339637756348, 62.911755425589426, 60.317381450108115, 67.65991115570068, 68.43334988185337, 67.9338160923549, 64.7281743458339, 65.37444019317627, 66.35954189300537, 63.36584799630301, 72.07487991877964, 75.49365765707833, 71.7898509161813, 68.03119509560722, 64.0588196345738, 71.13029316493443, 76.89206600189209, 81.0948715209961, 42.94424813134329, 1.0019470644848687, 5.122862960611071, 8.18098098891122, 7.394180876868112, 3.1159843632153104, 0.734876278255667, 0.4110331455511706, 0.6110670875225748, 0.1743024962821177, 0.3698635489812919, 0.34859337604471613, 0.1838277301618031, 1.088294608252389, 19.966303518840245, 51.768102509634836, 48.94004324504307, 47.14912073952811, 65.20953859601701, 29.98058407647269, 49.8601028578622, 71.44229507446289, 78.75723348345075, 75.04565170833042, 93.29103755950928, 23.16034872191293, 0.29212753740804537, 0.13931337664169924, 0.2012908873813493, 0.1413116758423192, 0.23095592271004403, 0.17816448690635817, 0.14331986808351108, 0.29056888818740845, 0.09543563146144152, 0.16916998954755919, 0.1881568514342819, 0.12715640398008482, 0.19479504094592162, 0.12042666652372905, 0.24921584288988793, 0.11106075266642229, 0.07663497315453631, 0.08142825309187174, 0.24903692677617073, 0.13912762089499406, 0.18848260252603463, 0.12100396411759512, 0.13952573096113546, 0.14938621542283467, 0.05613690182300551, 0.10963544914765017, 0.07962227107158729, 0.08171896463526146], [0.06032901669719389, 0.047353215116475306, 0.008872257578851921, 0.11526085729045527, 0.03040024498477578, 0.0675806018656918, 0.018190784246793816, 0.02817564587374883, 0.016069980637569512, 0.01774271364722933, 0.017513163554083024, 0.04140686669519969, 0.02994713626269783, 0.11187654174864292, 0.02452186880899327, 0.034659483935683966, 0.019457559932821562, 0.0409686416387558, 0.027024445057447468, 0.05239936809188553, 0.04998067234243665, 0.09184826431529862, 1.4010042569466998, 70.0416077205113, 96.70293658120292, 84.19813850947789, 63.57056277138846, 43.30305658067976, 38.34959200450352, 48.114572933741975, 68.5527685710362, 63.077991076878135, 54.8652411869594, 48.414978299822124, 14.275616833141871, 0.3139196123395647, 0.04076875540028725, 0.05514588785756912, 0.050732353436095376, 0.1077914759516716, 0.10462957061827183, 0.3790696407003062, 0.7760489146624292, 0.40676868866596905, 0.4964585059455463, 0.33113610850913183, 1.449579438992909, 6.538720403398786, 38.20999574661255, 72.35684476579938, 76.41685785566057, 72.66933304922921, 71.4042467389788, 62.91320759909493, 51.34439441135952, 56.00164685930525, 65.87720489501953, 70.15455763680595, 66.8805456161499, 72.89497579847063, 66.77893515995571, 64.12432725088937, 68.87640871320451, 61.82428591591971, 61.21799305507115, 52.60191065924508, 55.41243267059326, 52.43745027269636, 53.749235425676616, 49.79670401981899, 50.23893254143851, 49.586958748953684, 54.787028789520264, 56.11192519324166, 64.21995530809674, 63.468368666512625, 64.66512639181954, 56.06966972351074, 50.78829533713204, 48.2962509563991, 58.39468288421631, 61.617243494306294, 68.53851781572614, 65.37251554216657, 69.37305205208915, 56.541497571127756, 62.13885865892683, 28.722690888813563, 47.43156501225063, 67.30217620304653, 52.370591231754844, 54.07370935167585, 50.79177638462612, 63.137168884277344, 65.56406348092216, 68.83698463439941, 61.065431458609446, 52.91377360480172, 48.08449418204171, 48.53223957334246, 52.113921301705496, 61.57111440386091, 69.00597177233014, 64.50478281293596, 58.67655740465437, 63.468285288129536, 64.1801768711635, 64.08718218122209, 62.61488669259207, 66.44153758457729, 62.82235990251814, 62.42804963248116, 61.27900518689837, 63.53153473990304, 65.6919172831944, 66.56169973100934, 61.78710610525948, 58.90862028939383, 57.12010186059134, 62.48742198944092, 68.7117086138044, 73.48892865862165, 67.83809076036725, 25.83082457951137, 0.10707925845469747, 0.5315148276942117, 1.2791782340833118, 2.1186277781214033, 0.7728600714887891, 0.1645112902458225, 0.09349683978195701, 0.053842934380684576, 0.1842164493032864, 0.13087393449885504, 0.13567195061062062, 0.033706437397216044, 1.2892664756093706, 20.45021254675729, 33.507333346775596, 66.30908407483781, 57.63738482339041, 25.723134449550084, 23.579439742224558, 44.87353358949934, 54.544713837759836, 65.11881596701485, 67.85271671840123, 57.842290673937114, 1.6103981009551456, 0.2573015647275107, 0.015541274632726396, 0.041411691079182286, 0.03730983493317451, 0.060186734689133506, 0.050326134876481125, 0.005923575089712228, 0.02942762610369495, 0.05038559490016528, 0.03245299322796719, 0.038812861245657714, 0.05403792838166867, 0.033319984562695026, 0.021814161246376376, 0.022641500690951943, 0.027264480212969438, 0.059301097212093215, 0.03131980921274849, 0.04600241474275078, 0.01391348269368921, 0.051868590858897994, 0.029947801227016107, 0.03414204330848796, 0.07429923848914248, 0.0031755390103041592, 0.019511425435276966, 0.006830373105393457, 0.04056507275838937, 0.024856009986251593, 0.02945343418312924, 0.09027158641921622, 0.014497626705893447, 0.014220720805626894, 0.03287319978699088, 0.012077254974948508, 0.05452615807631186, 0.03407883098615067, 0.027527583862787912, 0.12641484662890434, 0.063001474365592, 0.00417398229806817, 0.0379237734180476, 0.031947593204677105, 0.04812401732695954, 0.04999527441603797, 0.02601664243931217, 0.040267677645065954, 0.009360109838390989, 0.0909310138917395, 1.9928725489548273, 86.92240905761719, 107.56443010057721, 94.66055529458183, 74.7149382999965, 60.82852567945208, 54.47619765145438, 55.783695765904014, 96.82213987622941, 87.72076402391706, 56.183293615068706, 51.356140341077534, 19.086956875664846, 0.37586087573851856, 0.07577925228646823, 0.06940318085253239, 0.03734526463917323, 0.17726329740669045, 0.7407969576971871, 1.3769352627652032, 1.8089615489755357, 1.956724111522947, 0.3889410767172064, 0.993395134806633, 0.16847063707453863, 7.454802172524588, 43.170905317579, 73.85231944492885, 77.15094198499406, 75.99569279806954, 74.79891422816685, 65.46873419625419, 55.03803593771798, 58.897503171648296, 69.24077919551304, 71.4906336920602, 69.73383031572614, 72.47699301583427, 66.92937755584717, 65.49519293648856, 70.53188650948661, 65.72454602377755, 63.60574150085449, 56.610430649348665, 57.9724234853472, 54.87197746549334, 56.35862445831299, 52.13491875784737, 52.0940112386431, 51.50676686423165, 57.40759399959019, 60.6568078994751, 67.48298222678048, 66.4984780720302, 67.80202960968018, 57.740023612976074, 53.29467732565743, 49.70362247739519, 61.0395633152553, 66.18600368499756, 70.84045600891113, 67.08530902862549, 69.8501501083374, 58.341737610953196, 63.85019302368164, 30.721817902156285, 49.67019121987479, 68.66906057085309, 55.36261061259678, 56.871623856680735, 54.21477515356881, 65.51993547167096, 67.98464911324638, 71.35026618412563, 63.78204509190151, 55.882116998944966, 50.28854962757656, 50.65578276770455, 54.85568741389683, 63.43413489205496, 68.76714829036167, 66.37243774959019, 60.96468257904053, 63.57869216373989, 66.77434240068708, 67.35888739994594, 65.225998878479, 67.1273386819022, 64.40481907980782, 63.60876396724156, 61.84255273001534, 66.04150199890137, 67.1709177834647, 69.22512490408761, 63.199820790972026, 61.738017082214355, 58.718913623264854, 64.9799770627703, 69.30983039311, 74.7342334474836, 72.60636847359794, 32.993079798562185, 0.4620906529682023, 0.5556946130735534, 1.2112280002662112, 1.3684950470924377, 2.6524561388151984, 0.8750067331961223, 0.8266919457486698, 0.1571125986852816, 0.38876061354364666, 0.49767921758549555, 0.1031590291698064, 0.0739370636375887, 0.7526059097477368, 25.648403099605016, 31.35080357960292, 62.90156241825649, 56.06593854086739, 27.74138637951442, 36.03862462724958, 56.859249114990234, 63.91042695726667, 72.96295002528599, 74.65302985055106, 70.39006682804653, 4.259429863521031, 0.19713370688259602, 0.0421130214817822, 0.04274833042706762, 0.03087289212271571, 0.073603163340262, 0.05825420588787113, 0.019694095543984855, 0.06377496357475008, 0.01727253637675728, 0.05685223040304013, 0.009504619985818863, 0.03675285946311695, 0.04865193792751857, 0.04687642552224653, 0.036117737114961655, 0.0526763019817216, 0.026327866096315638, 0.03377086429723671, 0.01070551501054849, 0.00808940882728036, 0.03223734801369054, 0.075552852292146, 0.023326105205342174, 0.12466905745012419, 0.059523805975914, 0.05709758188043322, 0.012856502401908594, 0.0959246652200818, 0.1757388599216938, 0.08402269958917584, 0.20850204543343612, 0.13298111142856733, 0.11138121797037975, 0.13693857192993164, 0.1174513040376561, 0.10105977074376174, 0.06424029610518898, 0.15182172187737056, 0.17282121362430708, 0.16491820769650595, 0.24032746840800556, 0.0942304175613182, 0.14038060366043023, 0.18509420220341, 0.0681670189702085, 0.13293771232877458, 0.20661631519240992, 0.09775518985199076, 0.2306028673691409, 2.9731682666710446, 101.34464590890067, 118.39424678257534, 106.22926425933838, 84.71810695103237, 63.09130382537842, 54.37880475180489, 58.8032717023577, 75.02569648197719, 77.06764698028564, 70.81945855276925, 69.26245757511684, 24.20691592352731, 0.7029220557638577, 0.17372339378510201, 0.12853705989462988, 0.19413724195744309, 0.3033146799675056, 0.597449541091919, 2.2660368510654996, 4.07456956590925, 4.5435256361961365, 6.145213084561484, 5.76539762531008, 4.208318480423518, 9.310375928878784, 43.84911550794329, 75.5724571772984, 79.2551691872733, 79.08024828774589, 76.41500963483537, 67.27093710218156, 56.61032295227051, 60.948979650224956, 71.51533453805106, 74.2313506262643, 73.18825926099504, 75.17336654663086, 67.7392109462193, 66.70222009931291, 72.37277698516846, 68.51213550567627, 65.65849644797188, 59.09245572771345, 61.40765108380999, 58.95490918840681, 60.121671540396555, 55.571188586098806, 55.26953949247088, 55.65832594462803, 60.89336626870291, 63.38392720903669, 70.99628325871059, 70.39618819100517, 71.93783364977155, 61.50214658464704, 57.13980695179531, 53.03952210290091, 65.00059931618827, 68.34134183611188, 73.55706964220319, 69.74230016980852, 71.99280084882463, 57.73522935594831, 65.61331926073346, 35.82122244153704, 53.84402969905308, 72.77136734553746, 59.217460768563406, 58.4109833581107, 56.55358396257673, 69.52919891902378, 70.23911026545933, 73.71825395311627, 67.57090473175049, 58.961926868983674, 55.002926690237864, 51.59590530395508, 57.976140771593364, 66.83452074868339, 72.86673831939697, 67.77962166922433, 61.26157910483224, 65.96601676940918, 68.67062391553605, 69.77687440599713, 69.18883446284703, 71.90849835532052, 66.97240080152238, 63.4340306690761, 62.13080569675991, 66.82723208836147, 70.26324830736432, 72.42541653769356, 66.62205178397042, 65.62618732452393, 63.18215152195522, 68.58263887677873, 73.50975240979875, 77.37876646859306, 77.71059853690011, 34.01466996329171, 1.3229626332010542, 3.7276725002697537, 5.895371496677399, 6.437025266034262, 3.5477947124413083, 0.9837654743875776, 0.5790016395705087, 0.4053343470607485, 0.6384687743016652, 0.5674791921462331, 0.35647605306335856, 0.1725587427083935, 2.1078187695571353, 33.595700536455425, 54.22428028924124, 81.84714603424072, 73.9830984388079, 39.75121736526489, 33.85299233027867, 62.89022295815604, 71.19937215532575, 82.84134292602539, 82.78846713474819, 83.26322364807129, 4.149705648422241, 0.4394489979105336, 0.129969094480787, 0.1493007064397846, 0.11399620372269835, 0.14177818223834038, 0.20542492983596666, 0.06785522534378938, 0.22539230196603707, 0.1656230834445783, 0.17200337536633015, 0.10368589804108654, 0.17137870245746203, 0.09902600451771702, 0.15057518519461155, 0.08129946714533226, 0.16517173552087375, 0.13599379334066594, 0.11479481229824678, 0.1744045615196228, 0.13585499221725122, 0.10559980105608702, 0.24027242564729281, 0.21205872244068555, 0.2700806590063231, 0.13200768509081431, 0.15138166477637632, 0.06473090406507254], [0.054795787536672184, 0.09936640518052237, 0.018964989310396568, 0.08339494613132306, 0.025225380701678138, 0.025672803300299814, 0.027265750769791857, 0.01806024259089359, 0.0603512047923037, 0.04449214167626841, 0.0006460248685990726, 0.02295778621919453, 0.008732368254901042, 0.06287517864257097, 0.04669535505984511, 0.017433956465018646, 0.11114252292151962, 0.01995928568898567, 0.08936077529298407, 0.18874172147895607, 0.27944721068654743, 0.3372440093329975, 21.150363411222184, 93.90087400163922, 78.49005440303257, 75.12508351462228, 58.459662437438965, 51.46025562286377, 15.067373616354805, 34.6782785143171, 34.455571378980366, 28.565251656941005, 49.408542905535015, 24.323477166039602, 0.8348532021045685, 0.06490572182727711, 0.05443807405286601, 0.14591431458081516, 0.106567222358925, 0.44302856868931223, 1.2578262026820863, 1.1064675131014414, 0.1658931810941015, 0.852664149233273, 0.9763238451310566, 4.459085481507437, 21.893874508993967, 66.75472068786621, 71.47455556052071, 79.57625239236015, 78.32028906685966, 72.0595452444894, 67.11108684539795, 58.37358120509556, 51.905621256147114, 55.340223516736714, 65.00829792022705, 66.71066216060093, 73.5110308783395, 68.54110254560197, 61.053209577287944, 67.07080118996757, 62.879974365234375, 61.127610887799946, 52.42345660073416, 49.34848962511335, 49.06431525094168, 48.817602089473176, 49.58944272994995, 48.838936533246724, 45.97917263848441, 46.250722135816304, 49.625906876155305, 54.39549085072109, 57.21679299218314, 55.6053146634783, 53.69159664426531, 46.677793162209646, 46.24868631362915, 49.62856803621565, 60.87953935350691, 66.38700812203544, 66.27414158412388, 64.74857425689697, 64.89190864562988, 60.91384955814907, 66.9606375013079, 33.12045417513166, 47.30025448117937, 66.24358340672084, 49.76211241313389, 53.01838568278721, 52.60810150418963, 61.731798444475444, 66.30914660862514, 67.28047697884696, 61.8255991254534, 55.542530741010395, 46.31726155962263, 48.270615577697754, 54.365714345659526, 62.287772451128276, 60.44586059025356, 65.6228938783918, 60.88051904950823, 63.49207592010498, 60.38601575578962, 60.94873646327427, 57.23779739652361, 62.05891963413784, 64.44173485892159, 64.35208225250244, 61.77497455051967, 66.22176606314522, 61.39723573412214, 66.37879535130092, 60.568850653512136, 59.14962550571987, 54.72960887636457, 58.8364701952253, 63.23390170506069, 68.14740371704102, 64.8670688356672, 78.865416935512, 36.765715394701274, 0.5464922125850404, 2.2689674709524428, 0.7230375249470983, 2.4684810851301466, 1.0202783665486743, 0.3806580640375614, 0.08477234507777862, 0.3033658415079117, 0.22054007090628147, 0.10431403826389994, 0.1726758171405111, 0.014414497684421284, 4.110740584986551, 38.94780758449009, 28.871920824050903, 23.339422907148087, 43.56139407839094, 16.799524784088135, 26.564938238688878, 40.73257398605347, 56.14864294869559, 62.71772697993687, 69.57101317814418, 26.79522933278765, 0.15868610782282694, 0.026856543263420463, 0.05956058257392474, 0.04836971824988723, 0.06692080798425845, 0.018077467202341983, 0.009319963465843881, 0.05351614173767822, 0.04110246231513364, 0.05374341704217451, 0.05703769437968731, 0.06105525951300349, 0.05882857221045664, 0.05455081264621445, 0.02004844179776098, 0.05166195658966899, 0.0760547850014908, 0.0794260183881436, 0.0081697007242058, 0.00778457781832133, 0.017809345786060606, 0.054246720392256975, 0.013000297543060566, 0.07148987281003169, 0.003039925517181733, 0.010657634186957563, 0.028259855462238193, 0.011910928230333542, 0.07260260917246342, 0.029635759935315167, 0.03529180393421224, 0.024522089332874333, 0.05381448340735265, 0.060889839460807185, 0.05345878856522696, 0.03843715301315699, 0.05166664526664785, 0.038489413780293295, 0.08340832005654063, 0.015958105480032306, 0.03638837080714958, 0.03450330213776656, 0.016847077956689254, 0.06958367116749287, 0.056909593753516674, 0.0801032099074551, 0.10677990916052035, 0.2648954843836171, 0.33453722457800594, 26.84295129776001, 107.64432048797607, 87.18243149348667, 86.69653701782227, 66.99004227774483, 58.3717816216605, 22.250640187944683, 48.82547787257603, 37.28515229906355, 33.23301499230521, 49.25100292478289, 28.90546498979841, 0.8486132408891405, 0.08081217043633972, 0.025644077520285333, 0.040910847418542416, 0.23777476538504871, 0.8701142785804612, 3.1482326899256026, 2.793776418481554, 1.0834153443574905, 0.5334344846861703, 1.6655996931450707, 4.7540174041475565, 27.039797237941197, 70.14261368342808, 72.88352516719273, 79.58517387935093, 83.51015567779541, 73.51475511278424, 70.52300671168736, 61.71009227207729, 54.36386265073504, 57.66885321480887, 67.26075799124581, 71.0718240737915, 74.62476457868303, 69.39986515045166, 61.79950169154576, 67.02788911546979, 65.48564611162458, 63.83697060176304, 57.11798613412039, 52.228896617889404, 51.092435359954834, 51.551954473767964, 52.529173442295615, 53.11727591923305, 49.11069447653634, 47.39068528584072, 53.60832248415266, 56.861462116241455, 59.639334542410715, 59.557602882385254, 57.00275026048933, 48.975805623190745, 49.59998662131173, 52.97154440198626, 64.03516101837158, 68.71354293823242, 69.91960430145264, 66.46102033342633, 67.03500407082694, 63.65027945382254, 67.98537172589982, 36.598861353737966, 49.435005119868684, 68.45171397072929, 52.76419973373413, 55.91730615070888, 53.67996883392334, 65.33463396344865, 66.39789594922746, 68.78607518332345, 62.60370009286063, 58.316731044224326, 48.16335276194981, 50.86684124810355, 55.8486579486302, 65.18446949550084, 64.49655614580426, 65.37005587986538, 61.31143242972237, 65.00731822422573, 62.54087448120117, 64.47705255235944, 59.28076580592564, 64.26254081726074, 65.94958427974156, 65.3230721609933, 61.671661785670686, 68.17562729971749, 65.45613016401018, 67.98502431597028, 62.63983767373221, 62.04868493761335, 57.613437856946675, 59.98739760262625, 65.93836988721574, 71.56531987871442, 66.28088828495571, 82.10846083504813, 41.32752043860299, 1.4235232600143977, 1.3371743048940385, 0.8044942425830024, 2.290781991822379, 2.6116684760366167, 1.514433381812913, 0.6019362860492298, 0.6045273127300399, 0.11502867617777415, 0.2271750441619328, 0.10801961299564157, 0.05946373527071305, 4.094335453850882, 41.408675398145405, 29.48609467915126, 24.79963547842843, 38.550186497824534, 24.328069925308228, 38.59226826259068, 49.64121723175049, 62.331351552690776, 68.83324650355748, 79.44031088692802, 39.04846266337803, 0.3294269602213587, 0.02280786051414907, 0.040148041743252955, 0.05973634349980524, 0.06259596148239714, 0.03638968037973557, 0.03514629549213818, 0.02004448593860226, 0.04279407725802489, 0.028352446654545407, 0.10671785713306495, 0.11140053586236068, 0.02583191976217287, 0.03201993182301521, 0.009963857575452753, 0.0124375163577497, 0.02062871816035892, 0.04223873366468719, 0.05357683669509632, 0.017946034969229783, 0.05138122968907867, 0.005488745676952281, 0.00957735045813024, 0.002050591350000884, 0.051198021841368506, 0.08775344797010932, 0.01307491264638624, 0.1213417931326798, 0.13799711370042392, 0.10298025554844312, 0.17862730207187788, 0.07832964150501148, 0.15273147448897362, 0.14767614432743617, 0.17038188023226603, 0.19876565145594732, 0.1865479363394635, 0.13990496418305806, 0.14535916436995777, 0.1156906820833683, 0.20014452960874352, 0.11480847799352237, 0.08364881322320018, 0.28843804395624567, 0.13527690752276353, 0.17427425565464155, 0.2222514312182154, 0.4557361453771591, 0.45381293286170277, 33.2291066305978, 123.10016441345215, 96.91117409297398, 99.31794670649937, 75.83976132529122, 66.64728764125279, 23.332740477153234, 49.71358272007534, 51.17207908630371, 41.49194261005947, 70.28581605638776, 38.28294140951974, 1.8350240247590202, 0.3371330552867481, 0.14732551814189979, 0.19775490569216864, 0.5417616292834282, 1.212024980357715, 5.441964192049844, 5.238430176462446, 2.3582227272646765, 4.634163584027972, 5.516042845589774, 7.926749876567295, 26.501560245241436, 72.15197713034493, 74.39205551147461, 78.33617959703717, 83.32897445133754, 77.64174188886369, 72.62247439793178, 63.77160194941929, 55.10363735471453, 60.96063872746059, 69.66964285714286, 74.94168581281389, 78.40591866629464, 70.61485494886125, 63.139948163713726, 69.02408572605678, 68.50734819684709, 68.59185913630894, 59.202702794756206, 55.59229026521955, 53.3981533731733, 54.86397661481585, 55.49678380148751, 57.215729917798726, 51.04005289077759, 50.83950008664812, 56.19604703358242, 60.88101931980678, 63.96683243342808, 61.65007373264858, 59.80857181549072, 51.09931060246059, 52.11844457898821, 56.483851841517854, 68.19269902365548, 71.63201563698905, 72.23004708971295, 69.21531404767717, 70.32168960571289, 65.9326445715768, 70.43447971343994, 39.80660145623343, 53.02571603230068, 70.67666612352643, 56.68331377846854, 57.34922218322754, 56.94376700265067, 67.75624792916435, 70.2295286996024, 71.05352946690151, 66.20146342686245, 60.446437290736604, 49.813813958849224, 53.53961869648525, 58.92995820726667, 67.84418433053153, 67.96524279458183, 69.37742941720145, 63.504110200064524, 67.51595142909459, 66.96630723135812, 66.78986467633928, 62.13164642878941, 67.58491230010986, 71.3905587877546, 66.1185644694737, 63.57837949480329, 70.8862168448312, 68.57162598201207, 71.88283170972551, 64.48403549194336, 64.71718924386161, 59.99654838017055, 65.75395774841309, 70.70664065224784, 74.56611483437675, 70.5002305167062, 86.01906681060791, 42.51232031413487, 1.0060627864939826, 5.76521132673536, 5.9459787011146545, 6.2148783292089185, 3.9063723513058255, 1.7784887041364397, 0.5585631877183914, 1.1496734746864863, 0.4482390119561127, 0.3098809447671686, 0.4687809539692742, 0.1287472971848079, 6.864051563399179, 59.53180422101702, 41.35067878450666, 33.0787649835859, 58.549565179007395, 23.84980457169669, 38.05758353642055, 56.20596906117031, 73.55126789637974, 77.99522454398019, 91.48577744620187, 47.499525342668804, 0.5950051322579384, 0.1408570980919259, 0.140512348019651, 0.11645408826214926, 0.16945996827312879, 0.07636094678725515, 0.11679840407201222, 0.12270168587565422, 0.10934899201882736, 0.12413718099040644, 0.11497319915464946, 0.13143053677465233, 0.2789906109017985, 0.10893102801804032, 0.04102138416575534, 0.16345479765108653, 0.1450867054185697, 0.15245612497840608, 0.12188095705849783, 0.14951243650700363, 0.14616884663701057, 0.20593103553567613, 0.0997109856190426, 0.1091474060501371, 0.10511686732726437, 0.16230272661362374, 0.09014320080833775], [0.012441268656402826, 0.045290577225387096, 0.0421754704522235, 0.012404011994866388, 0.06119504451219525, 0.022566936477752667, 0.022348227677866817, 0.02512747318749981, 0.011052301536048097, 0.022523941106296012, 0.03623010251404984, 0.04342981368037207, 0.058964625267045837, 0.038677513865487914, 0.01137943853557642, 0.09774667423750673, 0.02612049052757876, 0.007182397497152644, 0.020027032321585075, 0.07652566794838224, 0.08904235916478292, 0.2529723213187286, 56.00935935974121, 83.82064288003104, 81.35636002676827, 67.40360600607735, 57.49037136350359, 64.95920889718192, 61.48160770961216, 24.41376553262983, 44.70155872617449, 58.19089569364275, 36.470781735011506, 2.5532423768724715, 0.09984150182987962, 0.01185813226870128, 0.0756382459242429, 0.0906784902991993, 0.09539617465010711, 0.7277333672557558, 1.7341031772749764, 0.8006211646965572, 1.305122699056353, 0.7485495188406536, 14.637606688908168, 61.2794429234096, 83.66353716169084, 74.02608694349016, 72.56473486764091, 72.41305569240025, 69.36867468697685, 72.01156098502022, 67.50011648450578, 56.2888263293675, 48.80269820349557, 54.49858474731445, 60.81115518297468, 65.56567546299526, 66.05743421827043, 68.71583584376744, 63.44259779793875, 63.89601639338902, 65.69294561658586, 58.66772624424526, 54.843934535980225, 49.14066205705915, 47.06687143870762, 45.69566876547677, 45.78486973898751, 46.296302318573, 44.86346217564174, 45.15687070574079, 47.45242697851998, 48.94743612834385, 51.60923542295183, 45.73554447719029, 45.606801305498394, 43.80605404717581, 47.05556671960013, 47.16697413580758, 56.16067722865513, 60.77620574406215, 62.96432549612862, 58.809024810791016, 63.582736015319824, 56.8931702205113, 69.2002295085362, 36.399736404418945, 44.12834971291678, 67.20621463230678, 50.85959080287388, 55.046411991119385, 52.64891174861363, 60.9785372870309, 61.59232030596052, 65.41676861899239, 61.163915225437705, 54.395032269614084, 47.050546646118164, 48.14561401094709, 53.28016253880092, 64.00943878718785, 59.61464064461844, 52.907030378069194, 60.54471261160714, 59.750304222106934, 58.50531905038016, 55.079315185546875, 53.26349033628191, 55.456769125802175, 59.300623757498606, 61.09414141518729, 62.99941389901297, 64.0825685773577, 63.71944877079555, 60.19419683728899, 56.37189899172102, 53.259224142347065, 57.176566396440776, 59.76464530399868, 58.14107016154698, 63.6839017868042, 66.61611802237374, 62.673286301749094, 75.15536376408168, 54.193121092660085, 5.98168853351048, 1.656454018184117, 1.188839818750109, 1.2729156272751945, 2.1179468546594893, 0.26215287297964096, 0.29218472433941706, 0.3247779368289879, 0.018992844869249632, 0.07175401970744133, 0.014663715115083116, 0.04594061377325228, 6.9819768241473605, 39.1006749016898, 52.01825850350516, 44.12746034349714, 30.070413861955913, 16.874763352530344, 33.30263941628592, 53.44936159678868, 57.969025816236226, 61.96493829999651, 58.75273745400565, 15.192291804722377, 0.2531163607324873, 0.055151587551725764, 0.07924261037260294, 0.05644340966162937, 0.031563583096223216, 0.009117886407433875, 0.09551645855286292, 0.039745684047894816, 0.12861766985484532, 0.03173248403306518, 0.021511765329965522, 0.044992635891373665, 0.017772650612252097, 0.015454378045563186, 0.029861888515629938, 0.025072388018348386, 0.06326070188411645, 0.015638815737994652, 0.023332610659833466, 0.017865920339577963, 0.03455219058586018, 0.013455364686836089, 0.03385723841243556, 0.010046293643037123, 0.10747894950743232, 0.04481679354129093, 0.0217268982503031, 0.0785231664776802, 0.008754980434397501, 0.009242393342511994, 0.06880980197872434, 0.05254646769857832, 0.01288401784508356, 0.08589859785778181, 0.0020989272161386907, 0.022880060032808354, 0.058692274881260734, 0.010837175401060708, 0.05327616086495774, 0.02301951594251607, 0.018179252544151883, 0.023738125239365866, 0.07507942483893462, 0.0358741328652416, 0.031379164063504765, 0.05483345301555736, 0.005579275395055967, 0.44828618371060913, 69.50538049425397, 93.57034124646867, 89.47282872881208, 76.19084685189384, 69.23169789995465, 78.26899746486119, 44.633553232465474, 25.18709656170436, 44.20742021288191, 46.77588088171822, 41.75526891435896, 3.381119587591716, 0.127513462677598, 0.050101132664297304, 0.1603406611829996, 0.4434006501521383, 1.068276088152613, 1.4554496897118432, 1.6116139271429606, 0.5923507575477872, 0.3399553538433143, 0.5799301468900272, 18.07827298981803, 66.86009011949811, 83.61436476026262, 76.85000160762242, 71.68227890559605, 76.44916697910854, 72.15306799752372, 74.0214455468314, 70.20368140084403, 59.158387184143066, 52.29357739857265, 56.57747534343174, 63.74433721814837, 66.85214138031006, 68.32997458321708, 70.076418195452, 64.54697227478027, 65.23105716705322, 68.70116124834333, 60.40686729976109, 58.09836653300694, 51.35335063934326, 49.268158027103965, 47.637971673692974, 49.82555294036865, 48.507747173309326, 49.470944677080425, 46.92375591823033, 50.70129346847534, 50.81941979272025, 53.46181276866368, 49.069342272622244, 47.47345222745623, 46.52571446555001, 49.269033500126426, 49.3241639818464, 58.7253337587629, 62.832629340035574, 63.6425461087908, 60.76375457218715, 66.2822014944894, 60.170566013881135, 70.44488116673061, 39.781532355717246, 48.39668369293213, 70.27930559430803, 51.96609490258353, 55.21217516490391, 55.64126116888863, 64.90155274527413, 63.72861344473702, 68.64981406075614, 62.89541326250349, 55.477898597717285, 50.086249351501465, 49.97258029665266, 55.65301404680525, 66.97319984436035, 62.23000512804304, 57.031352519989014, 61.5019450868879, 62.1661650793893, 60.69506468091692, 56.96569899150303, 56.332047598702566, 58.08104467391968, 61.953237533569336, 64.80552169254848, 64.45555482591901, 67.0461767741612, 66.57055173601422, 63.17933750152588, 58.352875573294504, 54.83047934940883, 60.67599882398333, 62.39662987845284, 61.889953340802876, 64.9755858012608, 70.04643671853202, 67.04974120003837, 79.23865331922258, 57.730077266693115, 8.453229648726326, 0.29398335782544954, 0.46074845641851425, 0.5163882193820817, 2.1212448605469296, 0.906357656632151, 0.4812341885907309, 0.8469310168709073, 0.06426907956068005, 0.12500424017863615, 0.019298662298492024, 0.08018041362187692, 7.524237258093698, 44.309617791857036, 37.59621272768293, 39.22545065198626, 28.282155990600586, 25.871478489467076, 42.79663365227835, 59.93700926644461, 65.859938621521, 69.07170173100063, 73.35812187194824, 24.253953490938457, 0.13527297201965535, 0.027620773862249086, 0.05818693592612233, 0.03583731894780483, 0.09346625142331634, 0.03139711131474801, 0.10215409845113754, 0.03879362817055412, 0.09456035521413599, 0.018890111274751167, 0.03421714695702706, 0.030879066791385412, 0.010686496522144547, 0.026652590903852667, 0.028832696777369295, 0.009660862003719168, 0.015350918418594768, 0.030320113391748497, 0.0484084863481777, 0.03261641160185848, 0.07295803260058165, 0.0469153496835913, 0.017869791381859353, 0.049800802887018235, 0.10464677826634475, 0.03722521822367396, 0.07925040673996721, 0.1083481732223715, 0.10856381165129797, 0.11455581869397845, 0.24373466415064676, 0.209835393886481, 0.0797667515331081, 0.15503044612705708, 0.08777274550603968, 0.1469027501131807, 0.1054996492873345, 0.14237506235284464, 0.09972207288124732, 0.09552363066801003, 0.09513714390673808, 0.12532119745654718, 0.14253546803125314, 0.16449225055319922, 0.09768134488591126, 0.1765910049102136, 0.1437509006687573, 0.8877305133002145, 85.02838570731026, 102.65939794267926, 102.14654445648193, 88.17982455662319, 78.02774211338588, 75.6564608982631, 73.85446643829346, 35.11163418633597, 67.8678776877267, 81.03069795880998, 54.96663277489798, 4.469281094414847, 0.2236111339713846, 0.1139104776084423, 0.3469618521630764, 0.6541271369372095, 1.3836327833788735, 2.640309384890965, 6.037545536245618, 3.8408095836639404, 6.477961446557726, 4.055646147046771, 17.55077964918954, 66.21557521820068, 90.26686191558838, 76.99339853014264, 73.12284891945976, 76.43300546918596, 74.83610098702567, 77.2370718547276, 72.61571380070278, 60.85045419420515, 53.582225050245015, 60.417685644967214, 66.46124962397984, 71.50526659829276, 70.7459466116769, 72.73911380767822, 66.62236445290702, 68.39901188441685, 70.78906713213239, 63.57916464124407, 60.07852322714669, 54.64921474456787, 52.54543570109776, 49.43594660077776, 52.98383229119437, 50.30234180177961, 51.93785742350987, 50.46837248120989, 53.22872155053275, 54.85097653525216, 57.73492016111101, 52.43673808234078, 50.37648255484444, 48.98108625411987, 52.286608355385916, 52.05614355632237, 60.842727797372, 66.45311328342983, 67.24175466809953, 63.629643304007395, 71.20675809042794, 63.27697358812605, 73.16501058850969, 43.053619725363596, 52.03857503618513, 73.50321415492466, 56.867086683000835, 58.68143504006522, 58.658116885593955, 66.05187565939767, 67.01202637808663, 70.4074512209211, 65.69851807185582, 59.24153627668108, 53.972481046404155, 52.414524691445486, 59.21011652265276, 69.8430768421718, 64.07183361053467, 58.59925869532994, 66.41850430624825, 66.78449371882847, 65.05323886871338, 59.73993056161063, 58.97496863773891, 61.36030605861119, 67.35759503500802, 67.65160805838448, 65.43347903660366, 69.79785796574184, 69.6488538469587, 66.62185723440987, 62.11183711460659, 57.16751636777605, 64.13862664358956, 68.19535323551723, 64.65734440939767, 68.1037620816912, 73.3936688559396, 69.70999104636056, 84.09547887529645, 62.02870886666434, 7.643759301730564, 3.994212346417563, 5.717992671898433, 4.602582718644824, 5.090024471282959, 0.7009243943861553, 1.0656632397856032, 1.6890607199498584, 0.6157982679350036, 0.2614312102752072, 0.10821953655353614, 0.16548622293131693, 11.354110377175466, 61.66652706691197, 66.78533445085797, 60.64999171665737, 41.14310482570103, 24.148330450057983, 47.85981723240444, 69.72383880615234, 75.26422119140625, 77.41468865530831, 83.68326309749058, 26.4670398575919, 0.3498388949249472, 0.15698250995150634, 0.14546208456158638, 0.11877292740557875, 0.355148974273886, 0.18285955568509443, 0.1738534282360758, 0.11147970054298639, 0.17477145897490637, 0.1034691943121808, 0.12719217634626798, 0.10044645651110581, 0.1686538958123752, 0.08859567956200667, 0.10851923868592296, 0.07518803793936968, 0.16034386386828764, 0.10518257665847029, 0.19972030951508454, 0.08505635269518409, 0.22293276180114063, 0.08480669930577278, 0.15121391734906606, 0.1240945282791342, 0.20231031839336666, 0.15323455392249993], [0.025112289270120006, 0.043431581264095645, 0.030809371066944938, 0.05464192632851856, 0.019235580594145825, 0.05737201536872557, 0.0707731159137828, 0.011438139448208469, 0.024481122781123434, 0.027667070306571465, 0.005768120596517942, 0.04170688434637018, 0.038342968959893496, 0.04024283987070833, 0.09161879055734191, 0.047374673786440065, 0.010542101725669844, 0.01669904027533318, 0.1390431432851723, 0.011696104043429452, 0.2746543921530247, 8.92198031289237, 77.27896254403251, 82.94037560054234, 72.21006407056535, 67.90050642830985, 40.38562611171177, 19.849768332072667, 30.41894245147705, 57.046728883470806, 45.84184496743338, 39.17873443875994, 10.85422830922263, 0.10986781346478633, 0.12703576045376913, 0.024857027788779566, 0.03844199436051505, 0.6491958701184818, 1.035516960280282, 1.003494558589799, 0.6293932327202388, 1.3890896162816455, 0.5292392383728708, 36.861458097185405, 84.97637149265834, 74.91394165584019, 71.29031712668282, 76.2156171798706, 72.7796357018607, 68.75931072235107, 77.01654992784772, 68.01388018471854, 64.67595168522426, 52.79613365445818, 49.89843954358782, 49.87010826383318, 54.76712914875576, 58.807565689086914, 64.88423783438546, 62.76067379542759, 61.739490100315635, 61.161941937037874, 63.303682463509695, 58.74858937944685, 56.24396528516497, 48.473933764866416, 47.40058299473354, 45.6426887512207, 45.66495425360543, 47.112541948046, 46.03465747833252, 43.31777286529541, 46.72965104239327, 44.02086802891323, 44.41912834984915, 43.43926559175764, 45.460628577641074, 43.1028789792742, 46.34147603171212, 43.65092509133475, 48.145325660705566, 47.11514752251761, 50.83586965288435, 48.54859215872628, 53.57892465591431, 53.13327414648873, 66.50858770098004, 48.36807448523385, 43.87433052062988, 68.49468163081578, 52.66768230710711, 55.491979122161865, 54.254202706473215, 61.713594164167134, 61.16335242135184, 65.24200057983398, 57.73284959793091, 53.299586227961946, 46.659654889787944, 46.43085765838623, 51.08698797225952, 61.190686634608674, 64.3438972745623, 59.404485430036274, 58.670046942574636, 60.42874717712402, 53.01352194377354, 51.49962759017944, 45.594951152801514, 49.725749015808105, 58.31110300336565, 62.58655888693673, 61.13244683401925, 63.372566904340474, 63.08016586303711, 58.04697070802961, 52.03495502471924, 50.12215416772025, 51.63004527773176, 57.928701945713584, 58.22208963121687, 60.31246907370431, 62.54620374952044, 66.97455474308559, 59.42637920379639, 63.00795323508126, 62.58064596993582, 24.654930557523453, 0.42398388204830034, 1.4052352756261826, 1.6444119215011597, 0.5475112093346459, 0.2653907878058297, 0.0573906275842871, 0.32610298001340454, 0.25333275912063463, 0.1208774173366172, 0.07379445593271937, 0.2624142989516258, 19.013503994260514, 41.1764040674482, 47.844284534454346, 43.71653693062918, 23.0827043397086, 27.888623918805802, 42.03750474112374, 54.24375261579241, 62.989429337637766, 71.52310957227434, 59.016852378845215, 6.609299336160932, 0.10744973857487951, 0.04438864133719887, 0.060390797310641835, 0.08235574260886226, 0.04908423937324967, 0.07903281413018703, 0.03500424079330904, 0.04867808188178709, 0.02515855518036655, 0.03265594644472003, 0.09748379620058195, 0.06305254769644567, 0.05548458879015275, 0.039128037369144816, 0.052509080419050794, 0.05579233495518565, 0.08578251408679144, 0.021716114632519226, 0.08070712643010275, 0.056048505673451085, 0.0718819506998573, 0.024897261522710323, 0.07798208908310958, 0.02367837174928614, 0.01799226864906294, 0.010203324457896608, 0.034833762262548716, 0.06555283388921193, 0.06444223491208893, 0.014911239600873418, 0.0044630492422064495, 0.03543140572894897, 0.052642242916460545, 0.03916386401812945, 0.012768042639696171, 0.05052404997072049, 0.018172412911163907, 0.04527714901736804, 0.01858952535050256, 0.13513330237141677, 0.03214013769424387, 0.00899851174160306, 0.03476356781486954, 0.08198986974145685, 0.05760737881064415, 0.2459828406572342, 13.603981375694275, 94.02068873814174, 93.74566514151437, 83.93332876477922, 73.96334471021379, 48.588249002184185, 29.282991886138916, 41.6871383530753, 39.89416265487671, 37.32938800539289, 44.149937765938894, 13.68215468951634, 0.19287108204194478, 0.17103378953678267, 0.1385085933974811, 0.6839997225574085, 2.0702314036233083, 3.2180071515696387, 2.999571204185486, 0.4545086755284241, 1.0050657199961799, 1.3802112298352378, 40.95846339634487, 89.34818499428886, 79.08676569802421, 73.53935173579625, 76.23655905042375, 73.9804789679391, 70.91272422245571, 77.61965356554303, 70.42261219024658, 66.56200545174735, 53.950434412275044, 53.21189648764474, 53.416989939553396, 57.48560837336949, 61.51575115748814, 67.44718510763985, 65.25316633496965, 64.30412578582764, 63.06730474744524, 65.10961655208042, 61.20447186061314, 58.23410306658064, 52.04276132583618, 49.775630133492605, 47.87566259929112, 47.77740812301636, 49.51518733160836, 47.8985013280596, 46.745166369846885, 48.02776908874512, 47.17924118041992, 47.37556253160749, 46.606876373291016, 48.06222173145839, 45.66857426507132, 47.442682129996165, 47.350764410836355, 50.4052619934082, 50.22091586249215, 52.74697514942714, 51.8772691317967, 54.94684777941023, 56.76718200956072, 69.45474202292306, 52.32116174697876, 45.75610419682094, 71.13222476414272, 54.84824241910662, 58.60829135349819, 55.791759150368826, 64.64426789964948, 63.6876677104405, 66.7585699898856, 59.45208753858294, 54.542577266693115, 48.220279353005544, 48.376287255968364, 52.021489415849956, 64.64197499411446, 65.24982425144741, 62.29035023280552, 62.27618285587856, 62.1338837487357, 55.11853081839425, 53.10361923490252, 47.80195263453892, 51.85587910243443, 61.519899232046946, 64.66637011936733, 61.72872734069824, 66.06642518724713, 64.99322032928467, 60.85296944209507, 55.32867908477783, 53.474854537418906, 54.196240833827424, 60.494074140276226, 61.24525778634207, 64.08043548039028, 63.90138040270124, 71.20135239192417, 63.56140504564558, 66.57608250209263, 67.97947965349469, 30.39675337927682, 0.77240382454225, 0.33657027834228104, 0.7121326529553959, 2.2690282676901137, 1.026452166693551, 0.8844397270253727, 0.8853401701365198, 0.5652350325669561, 0.11101514832781893, 0.057621383773429055, 0.24128254715885433, 21.694384779248917, 42.090213775634766, 42.881078583853586, 40.50001777921404, 22.52342299052647, 37.41662263870239, 51.36752496446882, 61.40010534014021, 71.18207808903286, 79.61774008614677, 73.56256566728864, 11.407185060637337, 0.25695228204131126, 0.010242259645435427, 0.058511336733187945, 0.11386663067553725, 0.10995106971157448, 0.037702499755791256, 0.056913790492607017, 0.0382186138470258, 0.020495111222511957, 0.031244837878538028, 0.03676966677552887, 0.03953811679301517, 0.044669178247983964, 0.042222886479326656, 0.056343186646699905, 0.0654629822820425, 0.06659765568162714, 0.04402394572805081, 0.020530006582183496, 0.04399791373206036, 0.04291749259989176, 0.053740533268345256, 0.01948574627749622, 0.028645519499800036, 0.07203807482229811, 0.09199790164296116, 0.11255623027682304, 0.13532257292951855, 0.09417111360068832, 0.1732438188046217, 0.1297193393111229, 0.10523807403764554, 0.17163256954933914, 0.1314246878027916, 0.14102411270141602, 0.10382009191172463, 0.154835598011102, 0.18069858449910367, 0.191117082589439, 0.2229724425290312, 0.12118469870516232, 0.1682789237903697, 0.23508298982466969, 0.27165396458336283, 0.17991999270660536, 0.4112702528280871, 17.69167000906808, 106.10844898223877, 103.91951629093715, 94.33855492728097, 87.47288703918457, 54.84973280770438, 27.725490638187953, 36.94444043295724, 80.43061678750175, 66.57241385323661, 56.65789726802281, 19.036552906036377, 0.2810177206993103, 0.6944771174873624, 0.26465243313993725, 1.3855187850339072, 3.6385781381811415, 6.52131473166602, 6.073636216776712, 2.853963017463684, 6.959257083279746, 2.3365443476608823, 43.56597294126238, 93.36835016523088, 82.39991692134312, 75.21748065948486, 80.55248819078717, 75.77419812338692, 72.84297548021588, 80.62759821755546, 73.30108410971505, 68.69681862422398, 56.70726421901158, 56.230979101998464, 55.7506605557033, 59.177842140197754, 64.52054132734025, 69.36891092572893, 66.84139251708984, 65.14957564217704, 62.973212242126465, 68.3228040422712, 65.42015933990479, 62.07169737134661, 54.84436879839216, 53.02030685969761, 49.989304610661094, 50.41620193208967, 53.12536014829363, 49.889379092625205, 49.675360679626465, 51.612726892743794, 50.22228465761457, 48.61401987075806, 47.15841048104422, 50.95041765485491, 48.75231334141323, 50.621993677956716, 48.62790584564209, 53.97151524680001, 52.481168338230674, 54.900169781276155, 54.34065914154053, 57.77998270307268, 58.83175236838204, 71.22425365447998, 54.70476906640189, 50.463352407727925, 73.9561185836792, 57.473490715026855, 61.71515056065151, 59.11619772229876, 67.35250200544084, 67.26988097599575, 70.20023509434291, 62.428028787885395, 57.08566311427525, 51.10417781557356, 52.316124303000315, 55.7372088432312, 67.32139492034912, 67.59314591544015, 63.45951666150774, 65.14086260114397, 65.18889549800328, 57.93133878707886, 56.484977449689595, 50.73317180361067, 53.530919551849365, 64.98918342590332, 67.76598235539028, 63.94958005632673, 67.45323004041398, 69.1099168232509, 62.80920696258545, 58.118728228977744, 56.69316979816982, 56.64404256003243, 63.49232605525425, 63.75721917833601, 67.07160718100411, 68.90869004385812, 72.59818349565778, 65.97874586922782, 68.74427482060024, 72.03419126783098, 29.247121810913086, 0.8561579531856945, 4.750107305390494, 5.741191838468824, 4.084702210766928, 1.2601409299033028, 0.9771413441215242, 1.6496822386980057, 1.39579929624285, 0.4693363755941391, 0.22008895368448325, 0.6692345834204129, 30.69684260232108, 60.23963805607387, 61.07757690974644, 60.024813652038574, 32.09648772648403, 38.29851927076067, 58.30081966945103, 70.24161856515067, 80.01059818267822, 86.37037467956543, 83.07705361502511, 11.576222573007856, 0.35848462528416086, 0.28074926510453224, 0.12247403737689767, 0.29274896691952434, 0.17071003333798476, 0.12275413663259574, 0.15474022312888078, 0.12079755376492228, 0.1505390057074172, 0.11818019992538861, 0.1465577964804002, 0.15495428735656397, 0.12538698821195535, 0.16814476384648255, 0.13303101089383873, 0.2626277932098934, 0.19698001870087214, 0.16601134118224892, 0.2243549847709281, 0.14352117585284369, 0.17472544072994164, 0.15268450629498276, 0.1254136546381882, 0.15197053817766054, 0.11583879270723887], [0.044538268486836126, 0.02154981078846114, 0.03975942438202245, 0.07928529701062612, 0.09237280581146479, 0.04024714517540165, 0.025011815197233642, 0.054037623040910275, 0.06094450902725969, 0.04041112334068332, 0.06736543841127839, 0.01867827264192913, 0.021860084496438503, 0.018726440146565437, 0.04475314695654171, 0.016752464730026465, 0.1043272629114134, 0.012936645869298704, 0.10577909036406449, 0.18212490582040378, 0.2905585473137242, 25.070062841687882, 83.54440334865025, 73.82152502877372, 75.2466630935669, 48.519923891339985, 38.0319481577192, 34.47454343523298, 25.19542224066598, 42.97621331896101, 45.465440205165315, 24.226188489368983, 0.7571568712592125, 0.06987641153058835, 0.06775602352406297, 0.26342748744147165, 0.2961820555584771, 1.5044193991592951, 2.1481975742748807, 0.7927426131708282, 0.3862350790628365, 0.6338927341359002, 48.118012292044504, 87.15875898088727, 71.62647792271206, 71.93198326655796, 73.13252776009696, 70.21651472364152, 73.99886390141079, 73.02829088483537, 71.04865877968925, 68.85557801382882, 62.636266299656455, 49.85228960854666, 48.89285455431257, 46.97413035801479, 51.60162714549473, 59.662006514413015, 63.06617913927351, 64.42870698656354, 63.7529946735927, 62.79093320029122, 63.62983785356794, 59.73897171020508, 57.6561484336853, 51.35303797040667, 44.99650280816214, 45.79809216090611, 42.93376677376883, 43.68059737341744, 44.39928429467337, 43.9165859903608, 43.13355875015259, 43.588728291647776, 44.86262839181082, 42.649040017809185, 42.705344745091026, 43.66073942184448, 46.162775312151226, 45.65215914590018, 47.36838156836373, 43.5419773374285, 46.78499344417027, 43.412275314331055, 49.07700613566807, 51.832001617976594, 65.5990685054234, 49.640991415296284, 40.622674328940256, 65.58911173684257, 53.920164585113525, 53.142386708940776, 53.45860270091465, 60.45699160439627, 58.87332344055176, 61.887208802359446, 57.72898639951433, 50.56508098329817, 45.101861817496165, 46.251451696668354, 45.55659362248012, 57.0107615334647, 63.427978788103374, 62.45394556862967, 58.63994039808001, 54.17287056786673, 51.395081520080566, 47.90747492653983, 45.74680403300694, 49.145369461604524, 55.10329341888428, 63.85965647016253, 61.02600737980434, 64.08858571733747, 63.16699055262974, 59.275644983564106, 52.498215743473594, 47.35139322280884, 50.91930709566389, 56.29586138044085, 58.125263009752544, 63.28023229326521, 63.98872620718819, 64.41854177202497, 71.21997356414795, 67.66854081835065, 59.991677692958284, 66.43773691994804, 38.8614901133946, 0.23477490778480256, 1.8752280388559615, 1.2299779312951225, 0.5308070885283607, 0.11161555003906999, 0.08355997941855874, 0.1344423908740282, 0.08355658674346549, 0.08873872831463814, 0.21560741987611565, 4.191424369812012, 33.32519326891218, 31.76702846799578, 50.415229184286936, 40.52679961068289, 17.316427333014353, 31.982290608542307, 44.81408132825579, 55.56553970064436, 60.640076637268066, 68.02312128884452, 44.68884352275303, 0.6376167514494487, 0.042403770344597955, 0.00037539136194806943, 0.03979661488639457, 0.01963267625043435, 0.014498702183898007, 0.010068143318806375, 0.06486689605351005, 0.015143631059410316, 0.039950625372252295, 0.1363031645970685, 0.12301092142505304, 0.11990139899509293, 0.037727018618690114, 0.06085363283221211, 0.05895314445453031, 0.05511711458010333, 0.05610310060105153, 0.03579576885593789, 0.034771822193371396, 0.04419031912194831, 0.015603939038036125, 0.018797986575269272, 0.037952913104423454, 0.010987889054896576, 0.06382291564451796, 0.016785528045147657, 0.04324633441865444, 0.06110106062676225, 0.054635086695530584, 0.02832812287046441, 0.021710935713989393, 0.059840362918164046, 0.03800090588629246, 0.05353961226397327, 0.03454707443181958, 0.03125513804012111, 0.021524988281141435, 0.01720549542057727, 0.04868509793387992, 0.021327166485467126, 0.0772847111469933, 0.072718591163201, 0.056622471660375595, 0.16403783565121038, 0.2734823721860136, 33.223110335213796, 95.73927007402692, 81.07113647460938, 86.2336619240897, 60.128703117370605, 42.9450888633728, 34.85407836096627, 26.519540446145193, 40.04216970716204, 51.23411955152239, 28.29033054624285, 0.7643262722662517, 0.0592271029683096, 0.13197977016014711, 0.7185023597308567, 0.8780774569937161, 3.164796543972833, 3.8255652359553745, 2.108210257121495, 0.40398585370608736, 1.160951812352453, 53.18894311359951, 89.24556704929897, 74.31309618268693, 74.66451522282192, 75.96919931684221, 74.40083108629499, 75.1093805858067, 73.1183534349714, 71.2980296271188, 71.4838730948312, 65.7441816329956, 51.37704399653843, 51.41099289485386, 49.24975572313581, 54.39711672919137, 61.79909174782889, 66.00264767238072, 66.61909879956926, 65.4388986315046, 64.79124314444405, 64.82054369790214, 61.32202843257359, 59.208678245544434, 52.638524191720144, 47.54267018181937, 47.51953615461077, 45.63172101974487, 46.59917776925223, 47.291114125932964, 45.764056410108296, 43.94066844667707, 47.685865606580464, 46.9745819909232, 44.50657837731497, 44.33803939819336, 44.90964685167585, 48.55382415226528, 47.334960733141216, 50.03085831233433, 46.38205698558262, 47.82462808064052, 45.52190126691546, 52.33086838041033, 56.116910525730674, 67.32935060773576, 52.26275518962315, 45.1566344669887, 67.75292669023786, 57.745863573891775, 55.17917122159685, 55.67719725200108, 62.82041440691267, 61.935915674482075, 63.35968494415283, 60.921409198216026, 52.76019409724644, 48.06880514962332, 46.97722578048706, 48.40271125520979, 60.54616478511265, 64.22131715502057, 65.524979863848, 61.04499680655343, 56.431587491716655, 53.08523082733154, 50.882148129599436, 48.16314779009138, 52.614059584481375, 58.82909120832171, 65.91568401881626, 61.606835092817036, 64.60052898951939, 65.90253802708217, 63.196152142116, 54.66707508904593, 50.517590045928955, 53.543301241738455, 58.793314933776855, 59.51027175358364, 66.62733936309814, 67.80696977887834, 66.19551576886857, 70.616591998509, 70.87371008736747, 65.56439004625592, 72.32584190368652, 44.77085658482143, 0.5911157695310456, 0.9015207876052175, 0.9497832464320319, 1.5850582378251212, 1.6309954928500312, 0.49881275104624884, 0.5235720053315163, 0.16195397318473884, 0.2854287140071392, 0.21333818164254936, 3.7055737546512058, 38.59761490140642, 30.50150442123413, 39.65702758516584, 32.31330973761422, 23.796654326575144, 43.91548817498343, 51.87264510563442, 59.88032586233956, 68.85678005218506, 75.90037046160016, 60.48102542332241, 1.5183510801621845, 0.00905212024892015, 0.025617197355521575, 0.06297840417495795, 0.024870556080713868, 0.03061930662287133, 0.0651813902493034, 0.03096064366400242, 0.029852066721235002, 0.011846801582058626, 0.04537420327376042, 0.04609534689890487, 0.0632384323648044, 0.02371660041223679, 0.05800674416657005, 0.026305652556142638, 0.031972848278071196, 0.064637591929308, 0.03941026722480144, 0.01864094303787819, 0.01929122894736273, 0.004975055227987468, 0.005192289486460919, 0.04561117484367319, 0.01606563462077507, 0.12961933682007448, 0.0818811005779675, 0.13868974867675984, 0.29398620767252787, 0.17581102890627726, 0.20456021837890148, 0.06707581252391849, 0.1455713558409895, 0.12486230422343526, 0.12279821426740714, 0.1190873741039208, 0.1569795243974243, 0.1380627416074276, 0.08677405730954238, 0.16244943945535592, 0.17418990018112318, 0.1933484992810658, 0.11582419063363757, 0.1455821038356849, 0.2956803467656885, 0.34601982842598644, 41.08999974387032, 108.2745498929705, 92.08920070103237, 96.67104434967041, 68.53289672306606, 53.126923492976594, 46.909338406154085, 37.42934479032244, 63.769580023629324, 65.82071604047502, 39.14707497188023, 1.199306411402566, 0.12624168449214526, 0.3158729246684483, 0.7627845864210809, 2.3186798776899065, 4.1273159469876965, 5.34681338923318, 3.8662521498543874, 4.459403795855386, 1.6488575743777412, 54.83198363440377, 92.24625778198242, 76.34065001351493, 77.46727957044328, 79.32385907854352, 76.51794719696045, 77.62407956804547, 76.5915425164359, 74.73484488895961, 74.21552957807268, 68.42610985892159, 53.44412612915039, 53.02278389249529, 50.19111851283482, 56.00189004625593, 67.04676737104143, 69.85843236105782, 69.23781926291329, 66.2077307019915, 66.15882233210972, 67.08758108956474, 63.77588203975132, 62.1821528843471, 57.4450169972011, 49.62086248397827, 50.448267868586946, 47.57686921528408, 48.990306513650076, 49.99496391841343, 48.93155949456351, 46.189640522003174, 48.79203619275774, 49.459299496241975, 47.115460191454204, 46.48849643979754, 47.74977513722011, 51.58383628300258, 50.30691371645246, 51.26084927150181, 48.24264907836914, 51.10265963418143, 47.392853123801096, 55.46137925556728, 60.27314921787807, 70.60835838317871, 56.00028501238142, 48.6392696244376, 69.51478140694755, 61.77737167903355, 58.04399340493338, 58.88669177464077, 65.77112674713135, 65.66937037876674, 65.31588077545166, 63.43886661529541, 54.85112592152187, 50.40905570983887, 50.3016539301191, 52.44969299861363, 61.73719719478062, 68.18058831351144, 68.65601185389927, 63.23429775238037, 59.70488384791783, 55.43389218194144, 53.96313919339861, 52.01665346963065, 55.12277964183262, 61.051271029881065, 69.66224302564348, 63.82695129939488, 67.01976667131696, 69.71143627166748, 65.23758152553013, 57.30420133045742, 54.303114550454275, 57.20389018739973, 62.27006149291992, 62.84938839503697, 70.05483709062848, 71.07332488468715, 69.46362182072231, 75.51566260201591, 73.65417071751186, 67.81398051125663, 78.94625922611782, 48.56457301548549, 0.5869449504784175, 6.0417943596839905, 6.699272862502506, 3.5454889961651395, 1.2805917582341602, 0.40646570920944214, 1.44867747596332, 0.5917679773909705, 0.3564995846578053, 0.3549503263618265, 6.188867747783661, 51.20169578279768, 45.32916866030012, 65.23620578220913, 54.02096905027117, 27.225572960717336, 44.664740221840994, 57.60894932065691, 70.66656344277519, 76.60822514125279, 83.85521016802106, 68.574141229902, 1.8396621644496918, 0.12013701349496841, 0.10959960214261498, 0.10814307244228465, 0.08167901927871363, 0.12593466096690722, 0.13270361774734088, 0.11024841054209641, 0.11513611541262694, 0.0885708180389234, 0.24385245782988413, 0.19803629416440213, 0.21293069422245026, 0.09454348683357239, 0.1364696363785437, 0.14919091947376728, 0.08353167093758072, 0.20161365291901998, 0.14434045260506018, 0.1593462409717696, 0.14395189631198133, 0.1162424667605332, 0.1684203576296568, 0.14848803861864976, 0.08498528293733086], [0.05319087240578873, 0.008634373379339064, 0.012791094170617206, 0.024735429224425128, 0.029493664524384906, 0.022019728519288555, 0.07048422284424305, 0.02130447288176843, 0.05779564513691834, 0.0325317100754806, 0.04096401742260371, 0.023605093359947205, 0.07238363913659539, 0.020430706374879395, 0.030541926489344666, 0.07192024043095963, 0.053579065682632585, 0.016869271140811697, 0.11107276273625237, 0.11337670803602252, 1.599767791373389, 65.41801929473877, 84.05580466134208, 84.87594223022461, 60.40519278390067, 51.53704363959176, 68.13264574323381, 34.66925975254604, 44.10397890635899, 48.10296596799578, 35.188797405787874, 8.827819194112505, 0.16682803950139455, 0.016958401804523807, 0.1413527000695467, 0.25404101397309986, 0.6236269335661615, 0.9904036096164158, 0.4825311132839748, 0.6840455372418676, 0.535287048135485, 38.71621370315552, 87.34090600694928, 67.90527289254325, 77.74514498029436, 70.89490904126848, 69.01362868717739, 71.16645159040178, 70.40977191925049, 69.6976649420602, 70.84110219138009, 63.57616301945278, 56.70718431472778, 48.42805828366961, 47.93230084010533, 47.92008243288313, 48.82536322729928, 55.2247896194458, 63.08537701198033, 63.00095639910017, 62.33027458190918, 60.124381337847026, 61.79341506958008, 60.91561440059117, 59.52137497493199, 50.75988415309361, 45.23814378465925, 44.26021262577602, 44.09871564592634, 42.997905594961985, 44.9336702483041, 44.373853887830464, 45.97695616313389, 44.34518214634487, 43.074808256966726, 43.479325430733816, 46.416155270167756, 49.25618628093174, 54.69352340698242, 53.82963650567191, 56.67667824881417, 52.02932003566197, 53.596124921526226, 49.1359407561166, 56.6948755809239, 54.62453474317278, 60.98658330099923, 53.57180275235857, 44.1162667955671, 62.154700551714214, 54.14425441196987, 52.801035608564106, 54.629040649959016, 59.371488434927805, 58.43768528529576, 62.919085775102886, 55.935562542506624, 48.760258606501985, 45.73371710096087, 43.95910896573748, 43.03737831115723, 45.401134627205984, 51.387257848467144, 51.7612098966326, 50.094962392534526, 49.83449527195522, 47.01748711722237, 45.32809863771711, 44.5120188168117, 47.44569764818464, 54.33367272785732, 60.781215395246235, 59.978406633649556, 60.829512323652, 64.10582419804165, 60.54073824201311, 55.55965110233852, 48.58797107424055, 47.74744749069214, 50.569649423871724, 58.641413416181294, 59.91263498578753, 65.67699255262102, 64.9029632295881, 63.28857013157436, 64.36875098092216, 68.52196720668248, 61.64832278660366, 62.813396726335796, 37.845726013183594, 0.10766761616936751, 1.2382087239197321, 1.660248494574002, 1.1549640936510903, 0.39171234944037026, 0.14596904521541937, 0.542236929493291, 0.2513069792517594, 0.2422737782554967, 0.04207886402894344, 11.896968790463038, 34.29200383595058, 52.864865234919954, 47.334821769169395, 26.25710698536464, 13.077045628002711, 36.228550161634175, 54.871796812329976, 55.79706062589373, 61.63113294328962, 71.05931036812919, 15.364237138203212, 0.2802370525896549, 0.07432747233126845, 0.05708952766976186, 0.028787709905632904, 0.07844472782952444, 0.07197742736233131, 0.04404460711936865, 0.0641709566116333, 0.030088831337967088, 0.025944191862695982, 0.04930053937381931, 0.041719837579876184, 0.013333956112286873, 0.014876725917149867, 0.04103578946420124, 0.029418913714055504, 0.05687952108149018, 0.03158117750925677, 0.026744595163368752, 0.05064952127369387, 0.05251129583588668, 0.06058335876358407, 0.056984110469264646, 0.017094743238495927, 0.020317275675811937, 0.02422737273653703, 0.030654044223151038, 0.036705134702580314, 0.016722449733476554, 0.04103148076683283, 0.062264551408588886, 0.03452391263895801, 0.05861232988536358, 0.0678233816953642, 0.04417867206835321, 0.049776467228574414, 0.04293357387983373, 0.04659052139946392, 0.022050552668848207, 0.023066489225519553, 0.07056520599871874, 0.0536012469923922, 0.050001625503812513, 0.13789014944008418, 2.7852917994771684, 80.72785377502441, 93.37882804870605, 92.306227684021, 67.53570515768868, 51.64168698447091, 63.60788154602051, 29.056018556867325, 35.06682177952358, 45.625606604984824, 42.410761969430105, 12.162229299545288, 0.2765445735837732, 0.043937588576227427, 0.5751334471361977, 1.2281483837536402, 1.4039078439985002, 2.7775556317397525, 1.1810200554983956, 0.7477831542491913, 0.3373914957046509, 40.992443561553955, 88.77888434273856, 71.79627105167934, 80.24826826368059, 71.68245955875942, 70.80105972290039, 74.23154517582485, 73.69263594491142, 71.56593132019043, 71.80424758366176, 65.55193192618233, 59.12406308310372, 51.21193742752075, 50.347154208592, 50.35442202431815, 51.64652640478951, 58.29111998421805, 65.99437236785889, 65.70474365779332, 62.77595288412911, 60.878121920994346, 63.65619237082345, 63.463866233825684, 62.31928253173828, 51.90138980320522, 46.760612215314595, 47.024511745997835, 47.02171509606497, 45.30684757232666, 48.8469443321228, 46.6637612751552, 49.26691777365548, 46.90478038787842, 46.07033995219639, 45.18584816796439, 48.681719643729075, 51.46993446350098, 55.5871763910566, 58.03323759351458, 59.45594378880092, 54.430978775024414, 56.80872181483677, 52.471600668770925, 59.39543192727225, 57.957311153411865, 64.80429880959647, 57.48819310324532, 46.81249441419329, 66.0695240838187, 56.33914170946394, 55.414183616638184, 56.09645502907889, 62.55696650913784, 61.0242703301566, 65.33353614807129, 58.35439028058733, 52.16681793757847, 46.83983904974801, 47.65518930980137, 45.422309262411936, 47.61367729731968, 53.307225772312705, 54.656034401484895, 52.710549218314036, 52.16753707613264, 50.44344581876482, 46.87668187277657, 46.10722099031721, 48.36905418123518, 57.13865007672991, 62.32631410871233, 60.79684884207589, 61.630424227033345, 67.20799337114606, 63.38649804251534, 58.401033537728445, 51.73844412394932, 51.17091178894043, 52.77872494288853, 61.896769523620605, 61.65537520817348, 66.50874750954765, 65.42708669389997, 66.5937170301165, 66.63933195386613, 70.47208336421421, 63.820989745003835, 70.47104113442558, 43.261214528764995, 0.3580629293407713, 0.7688886331660407, 0.7567909508943558, 1.299999053989138, 1.652887529560498, 0.44265214460236685, 0.6151215242488044, 0.8659310287662915, 0.07155058133815016, 0.033975622417139154, 12.864145874977112, 37.18752663476126, 44.06245994567871, 44.68628658567156, 29.641956669943674, 22.162462336676462, 48.8591662134443, 66.06691850934709, 62.2401008605957, 67.96360301971436, 81.60418142591203, 26.128950936453684, 0.23311876665268624, 0.1165720990725926, 0.03366643097251654, 0.09877797282700028, 0.08489819296768733, 0.14649629406630993, 0.0868753558024764, 0.0897747902199626, 0.03227173616843564, 0.07767848537436553, 0.05082397262698837, 0.030381527596286366, 0.016468070347660353, 0.03560669507299151, 0.03892026994643467, 0.035437190239982944, 0.012248188972340097, 0.05492752171786768, 0.002455861444884379, 0.023818808142095804, 0.038514309230127504, 0.015362687608493226, 0.0290354125068656, 0.016630162185590183, 0.11523417729352202, 0.09106568273689065, 0.10530524900449173, 0.08601233389760767, 0.05538192304915615, 0.17691695956247194, 0.1614664729152407, 0.12700870047722543, 0.1282091239201171, 0.14158110852752412, 0.18432335928082466, 0.11638228568647589, 0.14073437824845314, 0.10805425899369375, 0.14304647275379725, 0.13551742104547365, 0.1462883095123938, 0.20346799413008348, 0.24782471039465495, 0.37243763942803654, 3.923802775996072, 93.11715194157192, 103.01213714054653, 106.49000235966274, 77.50821140834263, 64.3187586920602, 77.82429885864258, 46.94901262010847, 61.76251643044608, 70.17452675955636, 54.24949530192784, 15.099246740341187, 0.3413993849286011, 0.19984415572668823, 0.7174165408526147, 3.2340922313077107, 2.0982015941824232, 4.914990663528442, 3.246273943356105, 4.671345566000257, 2.72404169184821, 41.727052279881065, 92.01281915392194, 75.11024911063058, 83.61137008666992, 77.68431350163051, 73.27844687870571, 77.58009052276611, 76.11150537218366, 75.94418580191476, 74.86946623665946, 67.0579331261771, 60.50635160718645, 54.437788009643555, 53.78316695349557, 53.000758102961946, 53.75856685638428, 61.440988540649414, 67.27436256408691, 68.84992218017578, 66.01416778564453, 63.05998134613037, 64.64350359780448, 66.87792614528111, 65.34447956085205, 56.35841948645455, 48.42853076117379, 50.198302950177876, 49.03623410633632, 48.5438117980957, 51.11474255153111, 49.05412571770804, 50.932935987200054, 49.41139166695731, 48.09028203146798, 47.47259759902954, 52.39769615445818, 54.40051439830235, 58.469285692487446, 60.69635704585484, 63.22984395708357, 58.043962138039724, 59.6883818762643, 56.14806972231184, 62.39868654523577, 61.46012387956892, 66.68061120169503, 60.39199815477644, 49.60043478012085, 69.12429959433419, 61.15491730826241, 57.37954412187849, 59.448196547372, 64.17281178065709, 63.022905758449006, 66.09612873622349, 60.91837283543178, 53.44862161363874, 50.30645513534546, 48.509098597935264, 47.5334985596793, 50.30874456678118, 56.39857660021101, 57.37495483670916, 54.826852389744346, 56.46885415485927, 52.91213730403355, 51.3328742980957, 50.415382044655935, 52.79171460015433, 59.97938632965088, 65.19252245766776, 63.26408467973982, 63.47578239440918, 70.45653329576764, 66.63181400299072, 62.231783866882324, 53.89861127308437, 54.02989748546055, 55.32867213657924, 64.45105934143066, 64.62478515080043, 70.9990486417498, 69.34218120574951, 68.72997542790004, 70.57342284066337, 72.93614387512207, 68.29405239650181, 74.56189727783203, 48.04499019895281, 0.36128808770860943, 6.052501533712659, 6.255664254937853, 4.651890175683158, 2.249441295862198, 0.5501482135483197, 1.5910098041806902, 1.2082144362585885, 0.439797222082104, 0.11505095926778657, 20.745345967156545, 50.052161489214214, 65.15593324388776, 61.978591510227744, 36.52632563454764, 21.337030240467616, 49.63916056496756, 69.13196345738002, 70.85220541272844, 76.59410640171596, 91.8798028400966, 29.80171660014561, 0.4404839538037777, 0.1797549051365682, 0.13894635705011232, 0.20022086479834147, 0.1669263049427952, 0.2903415789561612, 0.18959288937704905, 0.13992997498384543, 0.13450556248426437, 0.21959943138062954, 0.2191952144993203, 0.18964861067278044, 0.11390541573720318, 0.12069011453006949, 0.12923996789114817, 0.15007927109088215, 0.09864973649382591, 0.14200726923133644, 0.05323216126167348, 0.1267376257372754, 0.10789084061980247, 0.1613843837486846, 0.08936601358332805, 0.1296474010284458], [0.09169081026422125, 0.025249122641980648, 0.01736561781061547, 0.04438859723242266, 0.008061580409828042, 0.021662406889455657, 0.008194013482092746, 0.06198534781911543, 0.015390911272593906, 0.08671493655336754, 0.025921985107873167, 0.06397905333765916, 0.021779578012813414, 0.028914154906358038, 0.007838795310817659, 0.038287240878811905, 0.0851411424311144, 0.024195742826642733, 0.16496822929808072, 0.1667834326092686, 15.647200788770403, 76.75365093776158, 67.88297612326485, 72.8969143458775, 58.554359436035156, 61.12416458129883, 47.426148891448975, 48.442368098667686, 58.696304185049875, 33.387126037052695, 33.107002462659565, 1.0219159701040812, 0.06280508597514459, 0.029433688814086572, 0.3937381021678448, 0.6434402646762984, 0.656234938119139, 1.123865150979587, 1.803896963596344, 2.0966219646590094, 15.933581215994698, 84.67369406563895, 65.67080170767647, 80.09540789467948, 65.43875966753278, 67.02947330474854, 65.42394610813686, 71.54606642041887, 69.04631301334926, 70.23733152662004, 62.44421809060233, 60.68005657196045, 50.95269666399275, 47.43230152130127, 46.188004221235005, 49.14688069479806, 46.20131696973528, 56.864411626543315, 59.99341474260603, 62.305059569222585, 62.406822885785786, 58.42843723297119, 58.370926993233816, 60.291999680655344, 56.927122592926025, 50.762805870601106, 44.393704891204834, 45.88606677736555, 45.190041405814036, 48.1377660206386, 47.56331327983311, 48.7660916192191, 44.495836462293354, 43.821791716984336, 42.739887714385986, 44.57028988429478, 54.05971220561436, 63.177885328020366, 65.10474586486816, 61.18930394308907, 60.439176423209055, 58.658408709934776, 60.04017611912319, 55.89156654902867, 56.95637450899397, 55.727505683898926, 60.613096782139365, 52.905487877982004, 47.36243043627058, 60.61442388807024, 51.26912457602364, 53.47825220652989, 55.18223885127476, 59.10066155024937, 61.08763790130615, 60.91809490748814, 52.23990256445748, 48.35760702405657, 41.45696537835257, 43.42735637937273, 42.9081974029541, 43.465251854487825, 42.04478645324707, 44.66403150558472, 43.058170795440674, 45.900220257895334, 43.04844331741333, 45.39609718322754, 44.11645787102835, 45.797866344451904, 50.56692920412336, 57.85786158697945, 59.91150937761579, 59.13313743046352, 60.8681651524135, 61.30727045876639, 55.60258402143206, 51.25185135432652, 45.72309330531529, 50.468719891139436, 51.70280681337629, 62.383539472307476, 61.56918280465262, 63.84462056841169, 60.393075125558035, 60.915725571768625, 56.70845236097063, 66.85981219155448, 60.44114971160889, 66.15860693795341, 21.59270657811846, 0.2197183378572975, 0.4148961268365383, 2.7646756257329668, 0.5800059799637113, 0.4791751333645412, 0.14585574343800545, 0.8746319647346223, 0.06719008460640907, 0.043536347070974965, 0.42246461500014576, 19.42874918665205, 32.21740027836391, 44.20105218887329, 44.32745729173933, 57.17533309119088, 26.602953570229666, 24.591255528586252, 41.305213247026714, 53.266116755349294, 60.80177511487688, 50.14475318363735, 1.7975169973714011, 0.11622244997748307, 0.07222666006003108, 0.03659969036068235, 0.014113994032543684, 0.06373241264373064, 0.052552767896226475, 0.11245312009538923, 0.016819023926343237, 0.012604798988572188, 0.03706560982391238, 0.05364391327436481, 0.01792031340301037, 0.06599615474364587, 0.07430544029921293, 0.019104716634111743, 0.04420214259464826, 0.011313342439409877, 0.06219361735773938, 0.01600005930023534, 0.07425206673464604, 0.02416073720503066, 0.06562793414507594, 0.05110377332727824, 0.01773195038549602, 0.05225541349500418, 0.044048878497311046, 0.04035148350521922, 0.04874342141140785, 0.047684418237102885, 0.022722270106896758, 0.024910815259707824, 0.03870093350165656, 0.023168079488511597, 0.06419345683285169, 0.04196839174255729, 0.051186639416430674, 0.0060069517764661995, 0.03997880832425185, 0.0218763014833842, 0.04201866779476404, 0.06813137552567891, 0.16137320149157727, 0.15088750129299505, 22.30804967880249, 90.93942669459751, 75.78239004952567, 81.59695529937744, 67.27965014321464, 69.84038094111851, 59.33735193525042, 41.65199783870152, 41.137466362544465, 42.790102345602854, 39.04327930722918, 0.967109990971429, 0.11781293606119496, 0.03256762832669275, 0.9510153574602944, 0.6537557882922036, 1.472724865589823, 1.4430824390479495, 0.5749235355428287, 1.1468515289681298, 16.158450978142874, 88.90723146711076, 69.78114059993199, 82.14443165915353, 67.0067387989589, 69.81372765132359, 67.60729244777134, 73.8958568572998, 70.99195453098842, 71.92015048435756, 66.75878538404191, 62.436012268066406, 53.43925196783883, 50.39109114238194, 50.19803197043282, 51.16176795959473, 50.013154302324565, 58.827861377171104, 61.80856214250837, 65.14026505606515, 63.571681431361604, 59.348121643066406, 60.88393061501639, 62.35487815311977, 59.9789069039481, 51.58466311863491, 44.93000507354736, 47.98378004346575, 47.043706144605366, 50.231529235839844, 50.01545763015747, 52.45688091005598, 46.46520260402134, 45.19964729036604, 45.33990362712315, 47.175040994371685, 56.522820813315256, 66.40652561187744, 66.34136540549142, 63.67144366673061, 63.80725315638951, 61.37699563162667, 63.435260500226704, 58.412053380693706, 59.055706705365864, 57.99031162261963, 62.64909962245396, 55.120500632694785, 51.03607504708426, 64.21421609606061, 53.79873786653791, 54.866005488804404, 57.62388794762747, 60.157454763139995, 60.83616174970354, 62.69574287959507, 55.201982157570974, 49.8365832056318, 44.05013384137835, 45.64455781664167, 43.85847820554461, 45.917267663138254, 43.75569697788784, 46.64669302531651, 44.98880420412336, 47.160498414720806, 44.82061610903059, 47.21790443147932, 45.20465694155012, 48.87633521216256, 53.89872939246041, 63.16468375069754, 61.63034779684884, 61.883039883204866, 63.28245571681431, 64.26761995043073, 57.64306150163923, 53.18604571478707, 48.73316410609654, 51.692947319575715, 53.85236406326294, 64.75129100254604, 65.55466951642717, 65.03380475725446, 63.171152523585725, 63.91659000941685, 58.45056029728481, 70.29541151864188, 62.90203489576067, 71.65832846505302, 28.05931510244097, 0.11961479937391621, 0.7021663848842893, 0.9065958495650972, 2.0565499663352966, 1.5578214079141617, 0.8877947298543793, 0.9565612141575132, 0.4482840938227517, 0.1042641998667802, 0.45033468093190876, 22.688618149076188, 34.05516406467983, 40.25636877332415, 36.85734476361956, 46.17766877583095, 36.37009538922991, 35.521129744393484, 46.08707121440342, 61.210350036621094, 66.84265014103481, 66.5179260798863, 4.266269062246595, 0.30277196051818983, 0.024208528122731617, 0.017476424275498306, 0.03608312165098531, 0.03305625157164676, 0.012328208607089306, 0.10515943861433438, 0.04459970644009965, 0.01610258424521557, 0.09869062501404967, 0.008738011121749878, 0.044638427040938816, 0.039931392297148705, 0.0663111103432519, 0.03032312947990639, 0.0914225514445986, 0.022064014803618193, 0.030364299592162882, 0.029050065470593314, 0.08712914147015129, 0.013222053813348924, 0.08046134747564793, 0.044020800718239377, 0.14804329962602683, 0.15964984468051366, 0.12046667294842855, 0.11624645654644285, 0.10534309768783194, 0.1292314590620143, 0.038926736385162385, 0.13266306849462645, 0.10118827170559339, 0.1639672272971698, 0.12712139157312258, 0.19880926768694604, 0.12098443587975842, 0.1141164672694036, 0.13077296848808015, 0.13379999463047298, 0.19303785237882817, 0.18595561598028454, 0.23089721586023057, 0.3148341689790998, 27.444764307567052, 104.75789288112095, 83.29839542933873, 93.85043007986886, 75.66510445731026, 81.81359318324498, 58.644776344299316, 67.26801885877336, 79.53698812212262, 49.21328810283116, 50.95317608969552, 1.5400290255035674, 0.19471470239971364, 0.19298774935305119, 1.4897281931979316, 1.1040548597063338, 2.453661880322865, 2.774386167526245, 6.536305035863604, 4.976744515555246, 17.147956098828995, 92.41669014522007, 71.42674500601632, 85.09343474251884, 69.88570404052734, 72.90795503343854, 69.98866939544678, 77.66305896214077, 72.69187995365688, 73.83502537863595, 66.28659275599888, 63.56987489972796, 55.40134334564209, 53.29858568736485, 52.818545069013325, 54.78508676801409, 52.501630783081055, 62.08785193307059, 64.97701713017055, 66.26560224805559, 64.7052869796753, 60.16607052939278, 61.976493154253276, 65.12924521309989, 62.81184727805001, 55.8269031388419, 49.12837764195034, 51.574087960379465, 48.924732889447895, 52.408222675323486, 52.23888465336391, 55.69227136884417, 49.213406222207205, 47.72204140254429, 47.38072156906128, 48.79527752740042, 59.20580863952637, 69.09317861284528, 67.46506977081299, 67.4861089161464, 66.49324607849121, 63.33599158695766, 66.59805965423584, 60.619176455906455, 61.83248479025704, 60.50079304831368, 66.06336797986711, 59.9493145261492, 54.7576379094805, 65.95017487662179, 56.69243328911917, 57.29801743371146, 61.326690673828125, 63.742961474827354, 62.56362288338797, 65.76941054207938, 59.62156799861363, 54.16115590504238, 45.76237494604928, 46.79390450886318, 46.772889682224815, 48.83160270963396, 46.65574652808053, 49.462370600019185, 47.62473882947649, 49.91161332811628, 46.392701625823975, 50.873768602098735, 46.94772025517055, 50.55646521704537, 57.06766727992466, 64.93767642974854, 64.53553553989956, 62.556827545166016, 66.42706448691231, 67.80064691816057, 61.54743494306292, 55.121692248753135, 51.733430998665945, 56.4991899899074, 56.6514458656311, 68.71291760035923, 67.61333738054547, 68.99903747013637, 65.28783089773995, 67.1015191759382, 61.706166539873394, 73.14479133061, 66.59023598262242, 75.55972807747978, 31.04282120295933, 0.6189868939774377, 6.179226687976292, 9.601837226322719, 5.028553324086325, 1.8383945524692535, 0.8738812335899898, 3.3057348898478915, 0.6573054492473602, 0.23967284496341432, 0.9165301450661251, 33.45285252162388, 46.47431516647339, 57.25873579297747, 55.12176867893764, 67.09461961473737, 34.119344575064524, 36.260543142046245, 54.727482727595735, 69.98445183890206, 74.62964916229248, 73.4342463357108, 4.867206599031176, 0.5138817653059959, 0.18340907405529702, 0.08936751993106944, 0.0977336870772498, 0.12576727994850703, 0.1675696104232754, 0.28890300329242435, 0.11293870011078459, 0.1069999241403171, 0.16745757072099618, 0.11989257803985051, 0.10671827103942633, 0.13755043409764767, 0.16625010408461094, 0.11761489883065224, 0.14205651730298996, 0.077312171459198, 0.15498024810637745, 0.12831577605434827, 0.15521443768271379, 0.09249362575688533, 0.206235942031656, 0.09515209881854908], [0.021685773939160363, 0.0066505121316627735, 0.11658493695514542, 0.09097342911575522, 0.08135575162512915, 0.012479155507337834, 0.09795887249388865, 0.05836999788880348, 0.0334503752445536, 0.08868077463869538, 0.04168321704491973, 0.00839123731878187, 0.08706865007323877, 0.021304679834949117, 0.11837242889617171, 0.052292454721672196, 0.043972322783832035, 0.047937471086957624, 0.09989977441728115, 0.33383054392678396, 36.90431458609444, 81.2360589163644, 69.60152966635567, 59.850573675973074, 36.83445044926235, 54.04591655731201, 15.790658508028303, 27.49356845446995, 46.720222336905344, 47.28869267872402, 10.223851255008153, 0.1926103617463793, 0.03197526725541268, 0.151745400258473, 0.2600611666483538, 0.5002236696226257, 1.2686764661754881, 0.6304082668253354, 1.333430528640747, 2.8315427005290985, 71.24466051374162, 70.87189660753522, 77.06162289210728, 66.50991480691093, 68.09864820752824, 58.48333495003836, 59.67356136866978, 65.51519680023193, 68.42291368756975, 61.26772131238665, 59.84567519596645, 51.69899225234985, 48.72998530524117, 47.001256125313894, 48.67530645642962, 47.86010558264596, 48.12189980915615, 50.863985538482666, 59.682482855660574, 59.74142442430769, 62.593889236450195, 56.16081619262695, 60.145218985421316, 60.46131338391985, 56.871074948992046, 46.9667444229126, 43.901094981602256, 43.92302349635533, 47.76815659659249, 53.06156178883144, 52.04862560544695, 49.59851360321045, 45.360067299434114, 43.615336418151855, 42.469759123665945, 49.07815606253487, 60.09982640402657, 63.14754254477364, 58.29286398206438, 56.55184691292899, 60.74070739746094, 60.88345118931362, 62.9868654523577, 59.702326910836355, 58.76634897504534, 52.7673785345895, 59.90702778952462, 53.22871460233416, 47.294021947043284, 61.65341581617083, 48.98089517865862, 53.191246441432405, 55.37569407054356, 60.32198115757534, 56.74633393968855, 57.06296682357788, 51.05322320120675, 44.006415775844026, 44.25517518179757, 43.611400263650076, 43.08468859536307, 42.709805488586426, 42.9829044342041, 44.30170031956264, 44.266201972961426, 44.48656409127371, 40.74227714538574, 42.17655903952462, 45.37735789162772, 42.52040801729475, 49.429971149989534, 57.06243528638567, 58.78345543997628, 58.89829526628767, 60.61040782928467, 62.13098634992327, 59.37062685830252, 55.651905809129985, 48.01984466825213, 45.80470337186541, 48.10532488141741, 54.43327168055943, 56.88481501170567, 58.20439951760428, 52.71459306989397, 52.225964478084016, 55.634344237191335, 59.01906190599714, 66.0623049054827, 66.25252573830741, 61.46696785518101, 10.479888898985726, 0.8504298148410661, 0.6629824531929833, 1.9908219618456704, 0.31186321697064806, 0.2877323403954506, 1.0853924325534274, 0.18243408708700112, 0.10742892790585756, 0.06559992421950613, 2.465451887675694, 29.81237166268485, 32.200363295418875, 89.35390336172921, 154.20010675702775, 60.85297639029366, 21.057195016316005, 52.50354848589216, 56.01105472019741, 57.72322981698172, 67.52863883972168, 26.474331992013113, 0.2554667517542839, 0.06421880690114838, 0.0927366227177637, 0.008394975198565848, 0.04456085352493184, 0.030181909379150187, 0.054701779902513535, 0.0076746568416378325, 0.053830215241760015, 0.08095713944307395, 0.029733099176415374, 0.07179002277553082, 0.05599087769431727, 0.026239466554086124, 0.04167075914197734, 0.07629685915474381, 0.026876110517020737, 0.011744629475288093, 0.028787733654358556, 0.027017849697066203, 0.06345981798533883, 0.04883911859776292, 0.0016260279600308941, 0.017663058725052645, 0.05433917757389801, 0.012414178145783288, 0.053742026045386276, 0.022369011205488017, 0.04745098522731236, 0.037520584517291615, 0.009653241207290972, 0.010903996681528432, 0.043174728618136475, 0.016219884290226867, 0.07164033116506678, 0.04907080437988043, 0.04257141938433051, 0.02770422349151756, 0.0881616614226784, 0.07894391247204371, 0.05364073094512735, 0.07111967088920729, 0.35975321435502594, 47.108842032296316, 95.47984518323625, 75.91183498927525, 72.44507299150739, 42.578039850507466, 63.96162823268345, 24.169770853860037, 36.23701654161726, 51.03492859431675, 46.712624481746126, 12.839543172291346, 0.2722822337278298, 0.040038061394755325, 0.6745371446013451, 0.5999417187912124, 1.2714055883032935, 2.044597544840404, 0.8877254107168743, 0.5220792282904897, 3.574567207268306, 75.52061666761125, 71.67653969355992, 78.60268470219204, 68.5975844519479, 71.82241712297711, 61.81282833644322, 62.768976892743794, 65.95678261348179, 68.36882196153913, 65.49481773376465, 60.91018090929304, 52.82159185409546, 52.63123205729893, 49.60372127805437, 51.880093574523926, 49.41965307508196, 50.74341344833374, 52.822300570351736, 63.01369939531599, 62.005647795540945, 65.39666053227016, 58.6763003213065, 63.51292746407645, 63.49996212550572, 60.92716230664934, 49.25679077420916, 46.16906690597534, 47.83531788417271, 50.354866709027974, 55.33790976660592, 54.43495314461844, 52.545612880161826, 47.90339980806623, 45.28858423233032, 45.15879535675049, 50.93607657296317, 62.168937410627095, 64.17050497872489, 60.9351874760219, 60.804325103759766, 62.11823640550886, 62.350215911865234, 65.22905608585903, 59.01862416948591, 59.33907508850098, 55.209305558885845, 61.453001976013184, 56.69697046279907, 49.040479455675396, 61.944121497017996, 52.58608266285488, 54.42913750239781, 57.701641763959614, 60.478510175432476, 59.938162667410715, 59.63563115256173, 52.6858275277274, 45.956490244184224, 45.25558376312256, 45.15405668531145, 45.77236992972237, 44.96628509249006, 44.64103296824864, 45.41058417728969, 45.65065138680594, 46.92296382359096, 43.864943504333496, 44.818726199013845, 47.61906215122768, 44.92378643580845, 51.66534907477242, 57.37879719052996, 62.655700411115376, 61.00203609466553, 61.65937737056187, 65.14970765795026, 63.525274412972585, 56.88981771469116, 51.460696833474294, 48.604250703539165, 50.81187752314976, 57.15767771857125, 59.57308346884591, 60.716367857796804, 56.37707192557198, 55.29456342969622, 58.40566798618862, 61.534184728349956, 69.3797779083252, 69.55120386396135, 67.82836328233991, 14.87982610293797, 0.47373702802828377, 0.6761640001620565, 0.7225327491760254, 1.358193799853325, 1.069665076477187, 2.0074129572936465, 0.6392589147601808, 0.11446290010852472, 0.15053938568702765, 2.0549670798437933, 33.66738510131836, 28.961274657930645, 71.68398121425084, 127.68833787100655, 50.2084264755249, 26.669967208589824, 57.25698137283325, 62.512817655290874, 63.70117500850132, 76.59118121010917, 37.70996516091483, 0.09940348033394132, 0.07239087231989418, 0.08982269479227917, 0.018714497930237224, 0.03527583461254835, 0.03311492110203419, 0.009541108206446682, 0.042047593742609024, 0.058347741940191815, 0.04328860715031624, 0.06660804405276265, 0.02671331469900906, 0.02404486377989607, 0.06140596712274211, 0.04020527277940086, 0.06406556655253683, 0.07230644220752375, 0.01166815179333623, 0.03323522875351565, 0.039402884763798544, 0.00633749968671639, 0.029368583379047256, 0.07147955907774822, 0.10735162241118294, 0.14314804944608892, 0.1540417798927852, 0.1265355580087219, 0.1698619867009776, 0.08387729632002966, 0.1668802188443286, 0.08125673979520798, 0.1313014251313039, 0.20924106506364687, 0.12886965061937058, 0.13153750103499207, 0.22124675155750342, 0.09011173035417284, 0.14246015064418316, 0.1498059978974717, 0.18356937116810254, 0.13979069888591766, 0.21544698705630644, 0.4602689764329365, 56.542018686022075, 107.07929992675781, 86.87199987683977, 82.62503855569022, 51.82409804207938, 71.21524184090751, 24.2818591935294, 40.961916651044575, 63.4949038369315, 68.0764765058245, 17.150968142918178, 0.5082335855279649, 0.07381015723305089, 1.0268499510628837, 0.7179704968418393, 2.3728871175221036, 4.1483346819877625, 4.277765725340162, 3.433045429842813, 3.1861537865230014, 78.8149938583374, 74.5112657546997, 82.29565225328717, 72.5276940209525, 74.41800703321184, 64.91993073054722, 64.12648119245256, 69.85863385881696, 74.92198766980852, 66.80137089320591, 66.28530733925956, 55.196315901620046, 53.242930616651265, 50.36869362422398, 55.43924229485648, 53.31336797986712, 53.338815757206504, 54.7082952771868, 66.03026676177979, 64.94864068712506, 67.39758886609758, 58.38187735421317, 64.61890002659389, 66.21326146806989, 63.76240253448486, 52.12765441622053, 48.97285611288888, 48.957351207733154, 53.200456278664724, 58.91242790222168, 57.07127686909267, 54.814932755061555, 50.062965938023154, 47.492049080984934, 48.403274059295654, 53.30050686427525, 66.40296813419887, 65.28683035714286, 63.830661637442454, 60.78944206237793, 63.34193229675293, 64.7610115323748, 67.74458190373012, 62.051464217049734, 63.322213309151785, 57.67013168334961, 65.00651918138776, 59.077308654785156, 53.00964832305908, 65.22040557861328, 55.28419671739851, 57.74891035897391, 60.44941806793213, 62.0627133505685, 62.28340203421456, 63.15000915527344, 56.38753243855068, 48.34977640424456, 47.715089729854036, 48.58148145675659, 48.08950383322579, 47.208691120147705, 47.62545796803066, 48.35613053185599, 46.98174210957119, 50.40574141911098, 45.80085754394531, 46.722501346043174, 51.08819695881435, 48.10727037702288, 55.143363680158345, 60.82471806662423, 65.21285288674491, 62.20046138763428, 65.80253955296108, 67.9933899470738, 64.92095211574009, 60.798537254333496, 55.49063464573452, 51.61729185921805, 53.29529571533203, 61.81897054399763, 64.37021705082485, 64.95144775935582, 58.36127594539097, 58.016881534031455, 60.74901049477713, 64.21558489118303, 72.49647576468331, 72.07803440093994, 68.02490697588239, 15.558110986437116, 1.8740362056664057, 5.772844357149942, 8.908843874931335, 4.161065084593637, 0.8143147613321031, 2.829308637550899, 1.2934876148189818, 0.7018631611551557, 0.263738962156432, 4.254170077187674, 46.818014757973806, 46.97072226660592, 98.97223213740757, 154.90890639168876, 65.3714246749878, 31.48112746647426, 68.08484213692802, 71.61720207759312, 72.60447161538261, 84.12975433894566, 40.828622409275596, 0.44290537387132645, 0.21067090119634355, 0.3089397895549025, 0.10538946198565619, 0.17259204520710877, 0.11106576025485992, 0.0901340948683875, 0.09669932829482214, 0.18103531428745814, 0.14382704586855002, 0.14763794280588627, 0.11413883178361825, 0.09605641636465277, 0.09642304240592889, 0.09662829246371984, 0.21431723982095718, 0.18170532690627234, 0.18649986891874246, 0.12151833437383175, 0.17923423807535852, 0.13702967204153538, 0.113059587909707, 0.14942577401442186], [0.02880514147026198, 0.04474972374737263, 0.0408755635975727, 0.029122237847851853, 0.03515467539961849, 0.10987514842833791, 0.0373535665151264, 0.04208060786394136, 0.09777971210756473, 0.011549908584649009, 0.0053902987274341285, 0.03374579582097275, 0.04401032753022654, 0.02240761136636138, 0.02503375562706164, 0.021871831633948853, 0.04606950828539474, 0.04124102934396692, 0.04267217844192471, 3.131504250424249, 71.72994354793003, 71.63337053571428, 64.83498900277274, 57.74417863573347, 83.84332874843052, 48.07547194617135, 36.552169459206716, 33.53635597229004, 33.855160168239046, 36.601022243499756, 1.232779358114515, 0.02653519586393876, 0.14977931790053844, 0.13830222375690937, 0.2791809806866305, 0.3328073945428644, 1.0980337027992522, 0.6000897479908807, 0.14886244067123958, 47.510416643960134, 73.61314160483224, 70.666855267116, 71.37358433859688, 68.03316143580845, 61.41222299848284, 54.82717548097883, 54.558516434260774, 52.727971826280864, 56.06491715567452, 53.907386847904746, 50.72438580649239, 50.971654823848176, 52.269929204668315, 50.46299804959978, 49.783252307346885, 47.6155081476484, 48.11340911047799, 50.55401597704206, 57.38293136869158, 60.77168941497803, 61.48451205662319, 58.0133900642395, 60.52739770071847, 60.19576713017055, 56.486210754939485, 44.02982078279768, 44.20524542672293, 41.991271427699495, 54.63488061087472, 58.0378303527832, 57.917855807713096, 52.441758155822754, 48.17257996967861, 44.768535886492046, 46.01569931847708, 47.79149906975882, 57.13123982293265, 57.34919786453247, 55.265061378479004, 59.41577625274658, 59.17912755693708, 57.00310809271676, 58.19465119498116, 53.97873789923531, 53.83898183277675, 48.4704145022801, 61.48417159489223, 51.563769885471885, 43.026896953582764, 59.7731568472726, 50.71107653209141, 53.91703789574759, 53.70707375662667, 57.14080054419381, 57.65859767368862, 58.38625471932547, 44.69091756003243, 41.65306091308594, 44.60643788746425, 44.373972007206504, 43.743405614580425, 43.09947436196463, 43.801450865609304, 42.56722150530134, 43.79711518968855, 41.76320375714983, 42.163228920527864, 43.11792182922363, 43.13080726351057, 43.25050040653774, 44.86063773291451, 52.32824543544224, 59.54606887272426, 58.5912960597447, 59.229981422424316, 59.60163361685616, 57.914760385240825, 56.263152735573904, 53.77257442474365, 47.48098407472883, 45.01539496013096, 49.06691040311541, 49.68467473983765, 50.3821314402989, 53.16228287560599, 54.85908160890852, 54.94823741912842, 61.51053306034633, 64.10718604496547, 61.04981885637556, 66.21928555624825, 61.79930019378662, 10.900062969752721, 0.5298999686326299, 0.9176970081669944, 1.405666281070028, 0.9624060605253492, 0.7409535635794912, 0.20487895341856138, 0.19039855471679143, 0.13283883620585712, 0.03093077115980642, 8.391945668629237, 38.25801822117397, 56.61914369038173, 74.36658341544015, 48.449879101344514, 28.920184748513357, 39.25901045118059, 41.57803079060146, 58.010965142931255, 53.235655852726524, 64.44408335004533, 6.042041889258793, 0.29867037917886463, 0.08670868046049561, 0.056797143537551165, 0.07766428363642522, 0.06520384975842067, 0.06924551645559923, 0.04797094661210265, 0.05628162994980812, 0.02545094270525234, 0.01433832703956536, 0.040920950804970095, 0.05439232722190874, 0.03784248831548861, 0.012799385020376315, 0.06930039636790752, 0.06851776729204825, 0.0318848388934774, 0.015956745017319918, 0.04761769449604409, 0.026033195301092098, 0.02691941462191088, 0.030434185306408575, 0.042258109232144694, 0.05482752261949437, 0.09846505961780037, 0.017073318495282104, 0.04795944883621164, 0.0938482191413641, 0.018927680062396184, 0.041124246681907346, 0.02929957297497562, 0.015253209375909396, 0.03560958563217095, 0.022621317666822245, 0.042616267156388075, 0.04564997008336442, 0.05010514619893261, 0.057850178996367116, 0.018851638339193802, 0.05491199344396591, 0.08987182751297951, 5.192839137145451, 86.85218361445835, 80.89061532701764, 74.27019105638776, 64.25143759591239, 83.6322911126273, 62.73412472861153, 40.04829454421997, 28.274806533540996, 37.22095094408308, 40.656279291425435, 1.6276649172816957, 0.04750037918399487, 0.1296017627630915, 1.4162287371499198, 0.8258511051535606, 1.5792469382286072, 1.3456324338912964, 0.29996608250907486, 0.37571102806500023, 51.88219887869698, 79.34773308890206, 72.78058065686906, 75.17920998164585, 70.71644456045968, 63.16047314235142, 56.289455141339985, 57.841665336063926, 52.666890212467735, 58.32781342097691, 55.94607516697475, 53.21522467476981, 54.01630333491734, 54.22350556509835, 52.855863843645366, 53.129150390625, 49.14413268225533, 51.10593570981707, 52.16755444662911, 61.09603132520403, 62.89127908434187, 64.42252308981759, 57.65130206516811, 62.06344985961914, 62.30665070669991, 59.82419831412179, 46.32038824898856, 45.47474384307861, 44.717539582933696, 56.68471384048462, 61.32411289215088, 60.62877886635916, 55.68941913332258, 51.10289239883423, 45.619339329855784, 47.5886081968035, 51.62898915154593, 61.82032544272286, 61.74138001033238, 58.06460176195417, 61.64033235822405, 60.800989968436106, 58.588315282549175, 60.55155658721924, 57.16882610321045, 56.17363214492798, 51.85464232308524, 61.71389988490513, 53.80028731482369, 46.93272604261126, 61.50691304888044, 54.2515207018171, 57.358532769339426, 56.33873176574707, 59.44167913709368, 60.35083702632359, 60.34024797167097, 47.37088986805507, 42.95971482140677, 46.28708553314209, 46.31956836155483, 45.35163218634469, 44.545321532658164, 44.351227079119, 44.37806102207729, 44.55634484972273, 43.239862714494976, 44.77649852207729, 45.38940259388515, 45.313514368874685, 45.32246364865984, 46.143403734479634, 55.35953950881958, 63.5058958871024, 60.189423424857004, 59.66953141348702, 61.53182234082903, 60.374975068228586, 59.02218164716448, 56.74189404078892, 50.16016428811209, 46.85498264857701, 50.79562568664551, 52.47994892937796, 53.65190505981445, 57.18202420643398, 57.70535557610648, 58.6775301524571, 65.21896035330636, 67.0663126536778, 64.35851628439767, 67.79842349461147, 68.12619086674282, 16.662409033094132, 0.23747805559209414, 0.6497254531298364, 1.9281652782644545, 1.5154924392700195, 2.4953745220388686, 1.658397451043129, 1.4005616349833352, 0.203011299350432, 0.05701941464628492, 10.446267434528895, 39.4473865372794, 51.0672516141619, 74.65209184374127, 40.51981667109898, 34.122526850019185, 45.88145317350115, 48.118227686200825, 64.68592929840088, 58.287361008780344, 77.4154668535505, 10.580864463533674, 0.3524901212326118, 0.10178328584879637, 0.040065372429255924, 0.01311804966202804, 0.007726898949061121, 0.05243604290964348, 0.07400222335542951, 0.09313817295644965, 0.03548157660822783, 0.014201851594927055, 0.01625748021927263, 0.0374491517432034, 0.026515004358121326, 0.016595701088330576, 0.040501541524593315, 0.06554669993264334, 0.013305251536491727, 0.041540466847696474, 0.03586791069912059, 0.04067832025300179, 0.014263030008545943, 0.03116222284734249, 0.16621729013110909, 0.13253710525376455, 0.20757256102349075, 0.07769335207662412, 0.1457688638142177, 0.1776916565639632, 0.10884762927889824, 0.1929117398602622, 0.23530478935156549, 0.08926586859992572, 0.08035279544336454, 0.11434578496430602, 0.14173303251819952, 0.06166546605527401, 0.12452250745679651, 0.1603742486664227, 0.1556633428803512, 0.1282005879495825, 0.18313444379184926, 6.910410812922886, 100.6981507710048, 88.8069064276559, 84.92022309984479, 74.77198995862688, 97.39855548313686, 58.85093634469168, 49.567079952784944, 46.161448206220356, 49.95500135421753, 56.57037775857108, 2.3493335928235735, 0.12654074201626436, 0.3276968044894082, 2.5219574613230566, 0.8528909970607076, 2.7762454620429446, 4.077090893472944, 3.6191327358995165, 0.3420686104467937, 53.72277668544224, 79.36467974526542, 74.63253266470772, 76.84244891575405, 73.08949061802456, 65.34507710593087, 59.8731483731951, 61.37473051888602, 56.305147647857666, 60.932574953351704, 59.704126494271414, 54.34108645575387, 57.05693231310163, 57.47650623321533, 57.426058837345664, 56.30476549693516, 52.687936305999756, 54.35507665361677, 55.81949288504464, 63.40147835867745, 66.40998581477574, 66.0862067086356, 59.65591294424874, 64.27344254084996, 65.94743728637695, 62.19224166870117, 48.259630475725444, 48.054127080099924, 46.56039639881679, 59.841895375932964, 64.34322329929897, 63.12143121446882, 58.54807826450893, 52.0270653452192, 50.14408963067191, 50.13235412325178, 52.49104520252773, 62.730087825230186, 63.112481934683665, 59.763158389500205, 64.91214874812535, 64.34506457192558, 62.45567567007882, 62.90683610098702, 60.63160678318569, 58.061096395765034, 55.21884543555123, 65.37525313241142, 57.65336568014962, 52.30844306945801, 63.740460123334614, 55.49044009617397, 59.20007637568882, 59.377637590680806, 63.24078042166573, 63.9210854939052, 64.23832634517125, 49.12226322719029, 46.58497565133231, 50.34933246885027, 49.07758283615112, 48.01366424560547, 47.66320058277675, 49.14928477151053, 46.662031173706055, 48.12038510186331, 46.257420199257986, 46.920118536267964, 48.31581360953194, 47.528596605573384, 48.11862373352051, 48.607356548309326, 58.26391083853585, 66.31774847848075, 62.21246092660086, 61.63697637830462, 65.24122932979039, 63.44749627794538, 61.403523853846956, 60.250727381025044, 52.003497055598665, 49.272893224443706, 53.67489317485264, 54.89461122240339, 56.87329142434256, 58.66636439732143, 60.90000874655587, 61.43203231266567, 68.45686258588518, 69.97416850498745, 66.68052782331193, 69.7040433883667, 69.56432206290108, 16.893622500555857, 1.2261575077261244, 5.77589852469308, 7.239038458892277, 5.331611164978572, 2.8674729210989813, 1.7820287027529307, 1.4415225684642792, 0.33034917073590414, 0.1447443709309612, 14.19367151600974, 57.03062643323626, 66.88261617933, 78.75785882132394, 58.264876638139995, 40.52593803405762, 51.80987855366298, 56.436353955950054, 73.76249313354492, 66.427001953125, 86.52000413622174, 9.784238730158124, 0.4747480994888714, 0.2152482577200447, 0.16559330932796001, 0.10938354980732713, 0.12000406134341444, 0.1855073214641639, 0.20109149308076926, 0.1944339381796973, 0.11099611542054585, 0.1084580687539918, 0.1335485838353634, 0.10734453172023807, 0.11409851323281016, 0.08968242803322417, 0.17317034703280243, 0.19990620096879347, 0.19155065289565495, 0.09417898460690464, 0.09065556260091917, 0.10843394004872867, 0.0983373796833413, 0.10575192182191781], [0.03630417478936059, 0.021654615611104027, 0.09077799067433391, 0.02226122761411326, 0.0042296505832512465, 0.056924446885074885, 0.019959177123382688, 0.041663960221090486, 0.06564921978861094, 0.01874069616730724, 0.03135591745376587, 0.03917097167244979, 0.024765905624787723, 0.027601891929017644, 0.06787701988858835, 0.06340926712644951, 0.08934230556977646, 0.11342731317771332, 0.4317985698580742, 17.956985235214233, 85.3570077078683, 70.57761260441372, 62.055890219552175, 66.8308937890189, 38.131950105939595, 12.934607556888036, 31.892075198037283, 40.18764066696167, 49.30236748286656, 11.092164158821106, 0.1132684274177466, 0.02620124806916075, 0.11505257418113095, 0.6335508610521043, 0.6237832680344582, 1.1919686794281006, 1.5784880646637507, 0.6567002502935273, 22.726430245808192, 75.54242706298828, 70.01098006112235, 72.93409415653774, 68.48502363477434, 62.94566263471331, 58.54722363608224, 55.78272301810128, 49.881850719451904, 51.23344905035836, 49.006693840026855, 51.30870498929705, 52.817214488983154, 52.09536613736834, 52.78884152003697, 50.354908398219514, 47.6736923626491, 45.46411657333374, 47.555746691567556, 49.693436418260845, 55.72270795277187, 60.3327647617885, 61.98936816624233, 58.70450305938721, 60.08562428610665, 58.69086374555315, 50.963636602674214, 43.72668130057198, 43.94598034449986, 45.563791956220356, 57.71803256443569, 58.4673957824707, 60.40960489000593, 55.64137234006609, 51.71999665669033, 46.41452244349888, 47.21355485916138, 53.8034348487854, 58.64576298849923, 56.26841252190726, 58.88503810337612, 57.1228985105242, 55.242827142987935, 50.885816778455464, 49.5441370010376, 47.52721043995449, 48.55871220997402, 48.650369371686665, 58.8660625730242, 48.41050018583025, 42.08965791974749, 60.67353221348354, 48.85228054864066, 52.61131157193865, 50.736711910792756, 53.939525740487234, 56.13701513835362, 48.31086649213518, 43.6284441947937, 44.63136454990932, 42.834914752415244, 44.46933603286743, 44.34250708988735, 43.62253475189209, 43.35968092509678, 45.548954078129356, 42.35860531670706, 43.19226408004761, 39.95577233178275, 42.530368259974885, 42.27229131971087, 43.02869306291853, 43.904447487422395, 46.729286261967246, 54.89120660509382, 57.73840468270438, 58.88718509674072, 58.58009556361607, 59.30929510934012, 57.15248394012451, 56.44992726189749, 49.856701714651926, 45.63341638020107, 45.03509310313633, 46.27467605045864, 46.95701347078596, 48.73777423586164, 51.49224165507725, 57.270704065050396, 58.78025926862444, 63.75264031546456, 63.05130999428885, 67.20224721091134, 63.94821126120431, 65.74316719600132, 14.618424449648176, 0.3495289129870278, 0.23141306532280786, 2.213615949664797, 1.2947506670440947, 0.29077673703432083, 0.3371351451746055, 0.23961147825632775, 0.042769331085894785, 2.0274661098207747, 22.356852088655742, 28.221432209014893, 29.926693848201207, 26.867063283920288, 18.910305874688284, 21.89493932042803, 48.16345351082938, 57.32150929314749, 60.633455004010884, 62.30533749716622, 38.97666692733765, 0.34175298309751917, 0.010013791815643864, 0.11003106220492295, 0.03228680982387491, 0.018434446171990464, 0.0198600194084325, 0.02227801626681217, 0.044565379353506226, 0.027526973181271126, 0.0417409637676818, 0.03207454371399113, 0.013025716313027909, 0.008045114909431763, 0.00924637379856514, 0.03644612770793693, 0.039233091553407054, 0.037338672671467066, 0.029427883947002034, 0.11794086705361094, 0.047842347262693305, 0.06116717029362917, 0.08569391098405633, 0.060944502241909504, 0.01161545846012554, 0.016626927269888774, 0.02200062945485115, 0.08374500234744378, 0.024141348066872785, 0.03385514173922794, 0.0375647198275796, 0.13817289498235497, 0.051076475863478014, 0.010678374457971325, 0.02473396698145994, 0.009671109578838306, 0.09923839954925434, 0.03091035404109529, 0.042791536144380055, 0.04770653847871082, 0.06276147652949605, 0.5225876410092626, 25.059392145701818, 97.75777040209088, 77.44591385977608, 71.32548195975167, 71.34668786185128, 54.67929349626814, 25.37607192993164, 29.154029846191406, 38.09581599916731, 52.15509632655552, 12.863841891288757, 0.014671082309048091, 0.1040782473449196, 0.1945540253072977, 1.9807603188923426, 2.0400340982845853, 1.3592211561543601, 0.6652138020311082, 0.7286925443581173, 24.65115942273821, 81.72605282919747, 73.8406673158918, 74.80948938642229, 72.15051106044224, 66.44899300166539, 59.52641241891043, 58.22707496370588, 53.30018029894148, 54.303027697971885, 51.68887914930071, 53.9523104258946, 55.12362732206072, 54.613424573625835, 54.57541445323399, 53.12884814398629, 50.59512846810477, 49.068967069898335, 48.69052301134382, 51.382064070020405, 58.40491758074079, 63.74908978598458, 64.83343955448696, 60.327769007001606, 62.92548506600516, 59.89193630218506, 54.049494879586355, 46.535084111349924, 46.170963764190674, 48.68945646286011, 59.65204974583217, 60.399154799325125, 62.482266426086426, 57.234285082135884, 53.302931785583496, 49.51174797330584, 50.405664988926475, 56.36603471211025, 62.31892817361014, 57.07984399795532, 61.7266845703125, 59.313088825770784, 56.95528016771589, 53.833451066698345, 53.306951318468364, 50.42964669636318, 50.35537740162441, 50.27073444638933, 63.05626405988421, 52.07675191334316, 44.517188276563374, 63.39126450674874, 53.219845226832796, 54.406111172267366, 53.97148745400565, 56.88875116620745, 57.658337116241455, 50.92206900460379, 45.32062932423183, 47.14690426417759, 44.45784371239798, 46.77556126458304, 45.281118392944336, 47.177337374006, 46.917186396462576, 47.79402126584734, 45.830905028751914, 45.98041636603219, 42.073756967272075, 43.95351913997105, 43.906233174460276, 45.42611687523978, 45.431022303445, 49.87408263342721, 58.0225373676845, 60.493893487112864, 61.397256578717915, 60.8278169631958, 62.52682522365025, 58.61517007010323, 58.02021319525582, 51.5281742640904, 47.44847345352173, 46.561452525002615, 50.19161530903408, 49.62488896506173, 52.39139413833618, 53.58677612032209, 60.52532713753836, 60.53188623700823, 67.01309640066964, 66.12444959368024, 70.21314484732491, 64.8683056150164, 69.54148333413261, 19.850584745407104, 0.3167404724018914, 0.31736572885087555, 1.8327586948871613, 3.3841637670993805, 1.6594509716544832, 0.40685022143380983, 0.39834809622594286, 0.04335967690816947, 1.4626525832074029, 28.446281126567296, 32.52547298158918, 33.46411902563912, 27.438573462622507, 20.465477739061626, 31.226121629987443, 55.07880449295044, 64.14478274754116, 66.69323607853481, 70.72293417794364, 51.60476425715855, 0.4232459616448198, 0.010935017606243491, 0.08119503382061209, 0.08770532626658678, 0.014232913231743234, 0.029287250779036964, 0.056779688224196434, 0.03644022784594979, 0.021606573635446172, 0.051155494659074714, 0.0787889961419361, 0.01991276872078223, 0.028987260269267217, 0.0188411227427423, 0.02113887980314238, 0.03977203156266894, 0.039901757280209234, 0.04034594326679196, 0.03543371274801237, 0.016891995278586234, 0.05756735881524427, 0.015987872811300412, 0.09928731513874871, 0.09102399354534489, 0.22118433990648814, 0.20490122293787344, 0.1407660251217229, 0.11932753478842122, 0.12858663366309234, 0.1329318769276142, 0.24513122492602893, 0.17474150843918324, 0.1121038238384894, 0.14598490936415537, 0.1004963084789259, 0.356378154030868, 0.11437474483890192, 0.18243396495069775, 0.13874758700174944, 0.2505681360406535, 0.709298656455108, 31.86596039363316, 107.71428884778703, 86.89014857155937, 83.30589948381696, 79.62265941074916, 52.48988485336304, 20.028887680598668, 47.36770411900112, 59.04740360804966, 71.95525278363908, 18.463307414736065, 0.24282032464231762, 0.16212007855730398, 0.5991311679993356, 2.1472543563161577, 2.699999187673841, 3.6078638434410095, 6.1287059017590115, 2.1478872937815527, 27.844728674207413, 83.93441268375942, 77.8216724395752, 77.16130174909318, 76.08699907575334, 67.56191376277378, 63.771004404340474, 61.69083186558315, 55.489509037562776, 56.36112928390503, 53.56830780846732, 56.06600454875401, 57.139014857155935, 56.535949434552876, 56.75055497033255, 55.112604004996165, 52.30256836754935, 51.209915501730784, 50.966217858450754, 53.47399296079363, 59.836725916181294, 66.94659519195557, 67.62847750527519, 60.73446791512625, 66.4327620097569, 63.13619613647461, 56.94394070761544, 48.322546413966585, 47.81050934110369, 51.746816703251426, 62.25978510720389, 62.77048465183803, 64.67144230433873, 60.357813017708914, 57.25910404750279, 51.43429715292794, 52.667491231645855, 59.67044162750244, 63.25288418361119, 60.587895665849956, 63.55151775905064, 62.158869470868794, 60.29040159497942, 56.78190871647426, 54.36724294934954, 53.37572111402239, 53.14361654009138, 52.7468535559518, 64.75625896453857, 55.814062867845806, 49.85417604446411, 66.31387138366699, 56.256235803876606, 58.653829847063335, 57.29033620016915, 58.628184046064106, 61.57997335706438, 54.18747220720564, 48.16615983418056, 49.8451885495867, 47.14235666819981, 49.593458788735525, 47.1833301952907, 48.592536040714805, 48.94062341962542, 49.97501564025879, 46.16533572333199, 47.24499545778547, 44.66520227704729, 46.88831663131714, 46.08589349474226, 47.11943456104824, 48.07210554395403, 52.41433709008353, 60.65545300074986, 62.45790604182652, 63.96116965157645, 62.90944167545864, 64.69441304888043, 61.41470350537981, 62.10468047005789, 54.5170704296657, 50.688776288713726, 49.891908236912315, 52.39917264665876, 50.585925579071045, 54.24885606765747, 56.66650261197771, 63.377986499241416, 63.58032499040876, 69.42590699877057, 69.2616446358817, 73.28258105686733, 66.122788974217, 72.22633675166539, 20.07241119657244, 1.4769705406257083, 3.838534048625401, 7.8739175115312845, 5.936424493789673, 2.5415303196225847, 0.6228144285934312, 0.5563011148146221, 0.15234052975262913, 3.150112611906869, 38.58343710218157, 42.69627734592983, 40.719160488673616, 35.17420618874686, 27.546647480555944, 33.01965665817261, 62.36195141928536, 73.16328048706055, 75.05808203560966, 79.13182476588658, 54.92800079073225, 0.5603614683662141, 0.0846606989258102, 0.32902857874120983, 0.10227072505014283, 0.1761989609471389, 0.1076961892790028, 0.16812581914876187, 0.16104108574134962, 0.13950468280485698, 0.16181730266128266, 0.16919220478406974, 0.1388527870710407, 0.08459365288061754, 0.11456735378929547, 0.10140878201595374, 0.12021053954958916, 0.09260351450315543, 0.12186471293015139, 0.15143275846328053, 0.10099152369158608, 0.12876364987875732, 0.12748462493930543], [0.03681384279791798, 0.028272355773619244, 0.04534151824191213, 0.005964808814626719, 0.05510404260296907, 0.030102337577513287, 0.026437566549118077, 0.02137273520098201, 0.08018189282821757, 0.05487568164244294, 0.025711810582184365, 0.0651652275451592, 0.03719209214406354, 0.05143080685021622, 0.022990515355819037, 0.054773765682641945, 0.03738857552941356, 0.0776309064988579, 0.2625478075018951, 50.76074572971889, 79.20560073852539, 62.14199924468994, 61.70259516579764, 51.74471139907837, 21.35824830191476, 29.457016468048096, 52.35297754832676, 39.585426398685996, 35.64211177825928, 1.8315401545592715, 0.07179844339511224, 0.07448281613843781, 0.13731775086905273, 1.4564600012132098, 1.8309465178421565, 0.5624014160462788, 1.0798775170530592, 2.838317628417696, 61.615381377083914, 71.77077116285051, 73.15514414651054, 68.51600565229143, 66.10333401816231, 61.0410988671439, 57.38874006271362, 53.61814028876168, 53.538989884512766, 53.95788982936314, 56.502434798649375, 55.107406752450125, 56.27190399169922, 55.02591480527605, 55.52783530099051, 51.66886486325945, 47.70944084439959, 49.01056398664202, 46.158863476344514, 51.671560764312744, 57.89283881868635, 60.85846546718052, 58.442159925188335, 58.91053104400635, 59.231642041887554, 56.895855699266704, 47.2452004296439, 42.199891090393066, 42.29979228973389, 46.53407314845494, 59.46890912737165, 56.715751443590435, 58.90696661812918, 56.41784048080444, 54.86458805629185, 52.24556187220982, 53.857332025255474, 54.03347928183419, 58.42753396715437, 54.65536390032087, 60.233113697596956, 53.99861669540405, 51.4842894417899, 46.97500583103725, 48.131252084459575, 44.513613428388325, 46.74263027736119, 46.60945068086897, 61.18847710745675, 44.458010469164165, 39.146873474121094, 61.99585778372628, 47.53842830657959, 46.929550715855186, 46.32349756785801, 48.874928201947895, 45.71428993770054, 44.348701408931184, 42.66241182599749, 41.735963344573975, 40.67941679273333, 43.91330296652657, 45.94663769858224, 49.44231809888567, 46.817233085632324, 49.47861548832485, 49.63319901057652, 51.55164180483137, 44.41407700947353, 42.80226516723633, 42.794347694941926, 43.04361431939261, 40.94475112642561, 44.176153319222585, 50.07624741962978, 56.222891398838584, 56.8779536655971, 60.97797448294503, 55.81079026630947, 59.15045928955078, 57.634299823216026, 55.95328739711216, 44.18786103384835, 46.279373032706125, 44.0386380468096, 46.824462686266216, 50.111433097294395, 51.7191732951573, 55.51129164014544, 61.87926006317139, 57.61761372429984, 63.536989075796946, 60.19845608302525, 63.51590824127197, 64.35585512433732, 70.07340962546212, 15.41166033063616, 0.7127447458250182, 0.9054702956761632, 3.4620628442083086, 2.3394465233598436, 1.4157186959471022, 0.046502223637487204, 0.11232602370104619, 0.06888621859252453, 7.1595189315932135, 20.0482314654759, 30.452008928571427, 21.80613786833627, 33.350262369428364, 21.214342423847743, 29.75653941290719, 44.42401640755789, 48.84678104945591, 53.01238938740322, 56.91877433231899, 12.592255915914263, 0.5180037298372814, 0.0996287539601326, 0.08926761922027383, 0.07762369367160968, 0.01280766908478524, 0.003051042677335707, 0.03240590289767299, 0.03817391874534743, 0.10747118706681899, 0.035598993700529845, 0.02411746363421636, 0.02536627510562539, 0.004762408290324467, 0.1052192650469286, 0.03503521252423525, 0.01893644334216203, 0.024871984396928122, 0.031478141966675005, 0.020280980837664435, 0.07868064767015831, 0.0238995877360659, 0.010018997875574445, 0.033079667815140316, 0.043533945057008944, 0.066106735595635, 0.03763220692053437, 0.06498566682317428, 0.09148580447903701, 0.09031499908970934, 0.03205750909234796, 0.05263071460649371, 0.056079613111381016, 0.0122739300464413, 0.020646638270201426, 0.06237320522112506, 0.038796912280044386, 0.05245966949899282, 0.05795374379626342, 0.08750021870114974, 0.4536968490907124, 62.62904017312186, 89.56958934238979, 71.46543952396938, 69.76197052001953, 60.627340589250835, 34.42209843226841, 29.10328367778233, 37.47059277125767, 37.69956718172346, 40.64270945957729, 2.6672692639487128, 0.12149905040860176, 0.03898658995915737, 1.4567949260984148, 1.7642134130001068, 2.3298740770135606, 1.5040221576179778, 0.7302100200738225, 3.286314891917365, 67.1867596762521, 72.33136572156633, 77.76829637799943, 70.92353561946324, 69.30197198050362, 64.26498658316476, 60.23310674939837, 57.035340785980225, 56.98890944889614, 55.156850133623394, 56.925552300044465, 56.12193407331194, 59.428658212934224, 57.61048139844622, 57.30100515910557, 54.056071349552695, 49.81310871669224, 49.05798544202532, 48.603211947849815, 52.94982085909162, 58.58616828918457, 62.485893385750906, 61.53362192426409, 59.436162267412456, 62.99417495727539, 60.14015374864851, 49.511873040880474, 46.324862888881135, 44.854578903743196, 49.58796623774937, 61.391406195504324, 58.55928570883614, 59.65664945329939, 59.21927424839565, 57.91667808805193, 55.7301355770656, 56.30890662329537, 57.80091067722866, 60.53583281380789, 57.074709279196604, 59.687020029340474, 56.37109994888306, 54.27201788766043, 49.59852402550833, 50.42880596433367, 46.24472236633301, 49.949234349387034, 49.41311829430716, 62.695958273751394, 48.7072924886431, 40.83607087816511, 64.08313138144356, 49.46031045913696, 50.04864222662789, 47.254653453826904, 51.66815267290388, 48.57434218270438, 45.76717962537493, 45.22580030986241, 43.69647053309849, 44.070540700639995, 45.54789447784424, 47.32083851950509, 51.65855026245117, 50.964723995753694, 53.891249656677246, 54.04737915311541, 54.08972494942801, 48.3718056678772, 45.13485186440604, 45.435420513153076, 44.96052850995745, 43.21383823667254, 46.175844873700825, 54.21566104888916, 58.46714564732143, 58.873740332467214, 60.94369207109724, 58.17930609839303, 62.246583529881065, 60.86388506208147, 59.142093658447266, 45.491895471300396, 49.209814003535676, 47.01790400913784, 49.06452022280012, 52.62400593076433, 55.486052308763774, 58.7608460017613, 65.48426342010498, 60.63106482369559, 67.30955518995012, 61.64908708844866, 67.14022759028843, 64.20675373077393, 74.00832734789167, 20.344723258699688, 0.8150013302053724, 0.5065129292862756, 0.7453328285898481, 4.007541162627084, 2.116605635200228, 1.1343720214707511, 0.06911297142505646, 0.08247861173003912, 9.61431532246726, 32.66119909286499, 32.010250159672324, 25.84046346800668, 34.007179805210654, 32.22399411882673, 41.53109918321882, 49.03406626837594, 55.37334210532052, 57.99760028294155, 69.92532961709159, 21.104979515075684, 0.5328278200966972, 0.1289711051753589, 0.09767636443887438, 0.05507897751938019, 0.07670312521180936, 0.045559473867927275, 0.020041556363659244, 0.04155939118936658, 0.09246986346053225, 0.04638263523312552, 0.03448127010571105, 0.023074020964226553, 0.048970428694571765, 0.04237045766785741, 0.040068612433969975, 0.046690089628100395, 0.043941961734422615, 0.022462135047784874, 0.029905674380383322, 0.06732416991144419, 0.01779427213062133, 0.13147671786802156, 0.0922742011025548, 0.13870397077075072, 0.11376238734062229, 0.138936776135649, 0.14456446415611676, 0.18379594758152962, 0.18941128626465797, 0.14812081546655723, 0.1226492351187127, 0.12030473378087793, 0.08832033683678933, 0.0944898622110486, 0.2020314269300018, 0.1033671290746757, 0.13700033218732902, 0.14406131686908857, 0.23479605093598366, 0.8670249900647572, 72.23405620029995, 98.24407482147217, 80.31825051988874, 81.48426941462925, 68.30799048287528, 32.036990301949636, 42.21511459350586, 70.55184868403843, 54.97062451498849, 55.321282727377756, 3.7812834978103638, 0.23208858764597348, 0.5944794033254895, 1.3839405668633324, 3.7564753890037537, 5.057295850345066, 5.7690176367759705, 4.952928262097495, 3.8885089669908797, 68.8157787322998, 75.6086642401559, 80.50972202845982, 74.0436589377267, 71.63991573878697, 67.4460733958653, 63.256907190595356, 58.96808992113386, 61.121211596897666, 59.24175861903599, 59.21762752532959, 61.502688544137136, 61.20033073425293, 60.23266206468855, 61.17576885223389, 57.657583236694336, 51.349091393607004, 53.110237394060405, 50.278558118002756, 56.77213607515608, 62.250453676496235, 66.31802640642438, 61.79905005863735, 60.628980364118306, 64.7872896194458, 61.701330593654085, 51.516282422201975, 48.95471436636788, 47.25270101002285, 52.26247031348092, 66.28172206878662, 60.66001796722412, 62.48291955675398, 62.70026615687779, 61.098984309605186, 57.250860009874614, 59.296927315848215, 60.35722936902727, 63.97746317727225, 59.17921093532017, 63.24412250518799, 58.594679832458496, 56.84591899599348, 51.55327115740095, 52.84139769417899, 48.927022320883616, 51.19415698732649, 52.52346897125244, 64.23178809029716, 51.29695905957903, 45.79042829786028, 68.8408339364188, 52.119101183755056, 51.31874861036028, 50.003576210566926, 53.68405784879412, 51.44933305467878, 49.279375893729075, 47.613208293914795, 45.1364186831883, 46.59979963302612, 48.73398051943098, 50.09315586090088, 54.29048272541591, 51.607880524226594, 57.3056708744594, 56.529136725834434, 56.89353847503662, 50.85324362346104, 47.13623183114188, 48.3572804587228, 47.76951844351632, 46.12607492719378, 49.207927567618235, 56.20522212982178, 61.10808644975935, 61.66036401476179, 63.989045824323384, 59.7073643548148, 64.7635337284633, 62.5679099219186, 62.25749914986746, 48.48696163722447, 51.79404360907418, 49.82333646501814, 52.06859820229666, 55.029673780713765, 58.35763508932931, 61.555279459272114, 70.9329365321568, 61.29690374646868, 70.69097246442522, 63.07610811505999, 70.01498917170933, 67.727614402771, 75.9301643371582, 21.145907878875732, 2.0055358580180576, 5.921693444252014, 8.958477463041033, 7.147932376180377, 4.521324838910784, 1.3078242455210005, 0.3195630152310644, 0.42378485415663036, 13.988850780895778, 35.61510413033621, 44.755973543439595, 30.237260954720632, 45.78656162534441, 31.70953212465559, 42.716475759233745, 58.717183521815706, 65.0871113368443, 66.48267092023576, 78.90454918997628, 21.886943680899485, 0.8175550103187561, 0.25146654354674475, 0.1940202625202281, 0.21955916711262294, 0.2764230343912329, 0.12786683014460973, 0.17298615191664013, 0.09405222069472075, 0.2507814131677151, 0.20151351472096785, 0.08981606550514698, 0.07229496139500823, 0.09495834314397403, 0.19998347253671714, 0.08793946834547178, 0.1512572214539562, 0.14428227501256125, 0.13039051901016915, 0.10420888569206, 0.20991357469132968, 0.18292386723416193], [0.08060075249522924, 0.043193171199943335, 0.057999144574361186, 0.026922624092549086, 0.047192276788077185, 0.05180639633908868, 0.02786873430678887, 0.05939608532935381, 0.06153286674192973, 0.036736320172037394, 0.036872050924492736, 0.03424586595169135, 0.05821786355227232, 0.05210384912788868, 0.0554439988253372, 0.04149249781455312, 0.10211429558694363, 0.0565200535846608, 3.314749526126044, 62.416175161089214, 71.44734641483852, 61.79889025006975, 62.2799904687064, 55.00379868916103, 15.791573933192662, 53.68249103001186, 39.87470769882202, 55.05242913109915, 19.173762457711355, 0.2087395191192627, 0.04766648116388491, 0.06829836977911846, 0.7693583965301514, 1.675291127392224, 2.043521442583629, 0.7118973912937301, 0.5331702902913094, 34.524153573172434, 77.507169178554, 70.04085036686489, 73.83883299146379, 65.29711369105748, 65.17728505815778, 59.94574315207345, 60.98802852630615, 58.7166485105242, 57.79036331176758, 56.16697577067784, 57.50287812096732, 59.866137640816824, 60.51797594342913, 56.228088651384624, 55.48599672317505, 50.36846433367048, 47.070397649492534, 45.13424389702933, 48.49677249363491, 53.477185658046174, 58.50868892669678, 62.862687247140066, 60.73328672136579, 58.137484891074045, 60.55526692526681, 52.90980618340628, 46.08799532481602, 42.55766773223877, 42.979597091674805, 48.02225569316319, 60.516190256391255, 54.15942580359322, 56.31506620134626, 56.61367545809065, 58.534584862845286, 56.85768229620797, 55.21577780587332, 59.38188294001988, 56.25918878827776, 54.01576484952654, 57.98719188145229, 52.62158448355538, 50.04901048115322, 46.53347560337612, 48.26371601649693, 42.586777210235596, 49.48635925565447, 46.07768072400774, 59.40951592581612, 44.077301297869, 33.97782366616385, 61.277907371520996, 46.07498482295445, 47.69486352375576, 42.799485887799946, 44.73011234828404, 41.0061662537711, 40.05041721888951, 40.562433447156636, 43.42194373267037, 40.0687187739781, 43.819304261888774, 47.874602999006, 52.57924216134207, 53.149668421064106, 56.94424295425415, 57.07413257871355, 55.17511347361973, 50.5771222114563, 44.06757729394095, 41.31501368113926, 42.88289553778512, 41.590322153908865, 42.19833469390869, 45.31778403690883, 54.08177273614066, 55.80128860473633, 58.71054104396275, 53.72523634774344, 57.37709140777588, 58.32927254268101, 55.19294949940273, 44.31553418295724, 43.69427490234375, 45.2495562008449, 47.43269409452166, 49.51366220201765, 54.95666905811855, 57.11220523289272, 56.72320338657924, 59.93766239711216, 61.77644062042236, 61.265247753688264, 58.29537922995431, 63.099301201956614, 61.87175600869315, 65.65714849744523, 12.325828977993556, 0.9506859694208417, 3.0820374190807343, 1.8983121258871896, 0.3604490113045488, 0.5588588661381176, 0.07846185405339513, 0.058423446092222414, 1.1575321044240678, 11.316649164472308, 24.635374852589198, 29.796342168535503, 40.04871143613543, 46.99617004394531, 22.070958035332815, 34.49048955099923, 43.11573314666748, 54.11936249051775, 51.318470682416645, 45.33542551313128, 0.4392363993184907, 0.11682500264474324, 0.018562916599746262, 0.056078266219369004, 0.041265022342226336, 0.03079122704054628, 0.02466920590294259, 0.03105908552450793, 0.023224241832005124, 0.06439495459198952, 0.02797160021561597, 0.03411650664306112, 0.08844416947769267, 0.028429572337440083, 0.006135180900205991, 0.06800186354666948, 0.04683590680360794, 0.04478636463837964, 0.04992253885471395, 0.10708487672465188, 0.03826377374519195, 0.04218734820772495, 0.03626939308430467, 0.033923130948096514, 0.02269569019387875, 0.006927840419978435, 0.0629526741270508, 0.050248832774481604, 0.010515000188856252, 0.014709969150966831, 0.07291108476264135, 0.030218713118561676, 0.009305147653711694, 0.039297260610120635, 0.024771065883604542, 0.05928844253399542, 0.002998788059423012, 0.05642771853932312, 0.19439942788864883, 5.6619684781347, 76.4173025403704, 77.05556406293596, 70.5023010798863, 68.95397840227399, 63.22277069091797, 20.935417413711548, 37.454698766980854, 35.66022573198591, 56.42876999718802, 21.06885756765093, 0.23961573945624487, 0.06961361491786582, 0.21004668969128812, 2.368168422154018, 1.02878480723926, 2.956198377268655, 1.134325446827071, 0.2821478343435696, 38.67428479875837, 81.60191631317139, 73.94073527199882, 75.75925949641636, 67.61026627676827, 66.52902930123466, 61.261023248944966, 62.320547103881836, 61.20182459694998, 60.366741452898296, 60.43120683942522, 59.80550765991211, 61.93667997632708, 61.625484057835166, 60.110832350594656, 57.057724407741, 53.221415519714355, 47.66002525602068, 48.19653735842024, 49.48671361378261, 56.573386328560964, 60.315769468035015, 63.95973137446812, 62.19708456311907, 60.56681483132498, 64.06948511941093, 56.715734073093955, 47.38096823011126, 44.579770701272146, 44.18917076928275, 50.440447671072825, 62.69501331874302, 55.9978392464774, 56.78655358723232, 58.98974745614188, 59.8969737461635, 59.03872530800955, 57.951530252184185, 62.06762572697231, 56.6670480455671, 52.730629512241904, 60.18837424686977, 54.9228104863848, 52.42552716391427, 47.91775826045445, 50.59931823185512, 46.23491498402187, 50.814847878047395, 49.515955107552664, 61.40335014888218, 46.12058237620762, 36.84452533721924, 62.88815934317452, 48.872499806540354, 50.33908387592861, 46.337056977408274, 47.58329977308001, 42.6177453313555, 42.54597391401018, 43.020792961120605, 45.02046019690377, 43.479266371045796, 45.81726918901716, 50.12901551382882, 54.32272931507656, 57.19398900440761, 60.79450035095215, 59.801790373665945, 57.513758999960764, 54.30676930291312, 46.924318722316194, 44.20758696964809, 43.24069997242519, 44.3954176221575, 44.619198254176546, 47.203942026410786, 57.63931294849941, 58.871350152151926, 61.92835603441511, 55.353230544498985, 60.88034534454346, 62.24567331586565, 56.95190681729998, 46.13702181407383, 46.47186592647007, 47.49036414282662, 50.16558735711234, 52.84940549305507, 56.55280229023525, 58.589114325387136, 59.68738828386579, 61.3001902444022, 63.32823044913155, 64.93243748801095, 59.54718058449881, 66.41860158102853, 63.2901473726545, 71.45106370108468, 16.968419858387538, 0.8710254696863038, 0.40256975112216814, 2.4562294568334306, 1.9483754166534968, 1.0979420734303338, 0.5323920920491219, 0.07490150617169482, 0.6911400822656495, 16.6501749924251, 31.060594694955007, 27.9046916280474, 32.362589836120605, 40.298665932246614, 27.647781985146658, 48.3007811818804, 49.89618485314505, 60.369159426007954, 56.15187733513968, 61.78334018162319, 2.1420232313019887, 0.24449391769511358, 0.10502402338066272, 0.03568627705265369, 0.068699831808252, 0.09372292765017066, 0.016306797840765545, 0.11442874265568596, 0.020990801409685185, 0.0190880976151675, 0.009188974825000125, 0.04904107436803835, 0.07471047820789473, 0.03469490007098232, 0.04677271144464612, 0.089663937953966, 0.05603247867631061, 0.022139262640848756, 0.048069001707647524, 0.0840017803545509, 0.07043714608464922, 0.19888999978346483, 0.10978123918175697, 0.14013483827667578, 0.07511341944336891, 0.05765947672937598, 0.17607415121580872, 0.13938508422247, 0.13170687694634708, 0.09692529402673244, 0.17986170654850347, 0.16492434165307454, 0.09873447873230491, 0.14093943153108868, 0.1396833953580686, 0.21828338557056018, 0.08501066014702831, 0.26278089785150116, 0.36847521205033573, 7.3644643000194, 88.72008868626186, 85.1925299508231, 81.13646343776158, 75.83175005231584, 72.93946511404855, 25.25643958364214, 70.16569559914726, 51.60573353086199, 76.14597538539341, 30.504356656755718, 0.4757213901196207, 0.1425233901079212, 0.6266562938690186, 2.590618474142892, 6.8850290434701105, 6.32832156760352, 5.933410278388432, 1.4116661591189248, 41.92768151419503, 83.58177770887102, 75.7137279510498, 80.54353196280343, 70.53770909990583, 69.72194194793701, 65.72570637294224, 65.18879127502441, 64.95595714024135, 62.6220919745309, 62.509850774492534, 62.835068157741, 64.39618941715786, 65.18199593680245, 62.70314271109444, 60.20152718680245, 54.66269424983433, 51.278893743242534, 49.874631541115896, 52.62414142063686, 60.05166843959263, 62.16827733176095, 68.15071105957031, 62.86374337332589, 61.416412762233186, 67.02845886775425, 59.14003004346575, 50.39103903089251, 46.92743846348354, 47.93112659454346, 52.98340150288173, 65.38184697287423, 58.471523012433735, 59.423530442374094, 60.908659253801616, 63.540171350751606, 62.96574987683977, 60.75173418862479, 63.8099490574428, 58.78426143101284, 55.34353085926601, 64.37448324475969, 57.801032270704, 54.8637820652553, 51.266942841666086, 54.11743436540876, 48.937104157039094, 53.72489241191319, 51.95373058319092, 66.34632641928536, 50.05485044206892, 41.62171758924212, 65.5657935823713, 50.34138372966221, 53.4253694670541, 48.71062067576817, 49.27030849456787, 45.10871621540615, 44.47418587548392, 45.46643032346453, 47.14452450616019, 44.39812394550869, 48.05979681015015, 52.37705305644444, 56.64607490812029, 60.86726883479527, 62.31310558319092, 60.46928991590227, 61.036547797066824, 55.56591142926897, 49.718338762010845, 45.56774548121861, 46.456638949257986, 46.55275338036673, 46.04937376294817, 50.11628641401018, 60.46333530970982, 61.1733786719186, 64.09438746316093, 56.00420727048601, 61.98264231000628, 63.25020912715367, 60.804804529462544, 48.73295218603951, 49.03705399377005, 50.145076274871826, 52.16142960957119, 55.788003649030415, 59.0107866014753, 61.99852589198521, 61.826384271894185, 64.76013605935233, 66.41287626538957, 67.96603488922119, 60.84817518506731, 69.91419860294887, 67.28591741834367, 74.11808109283447, 17.759456634521484, 2.4891684779099057, 10.206873331751142, 6.792330954756055, 3.8520113825798035, 1.5196116353784288, 1.0512727605445045, 0.27392901107668877, 2.365012202944074, 19.980908632278442, 38.97139324460711, 40.89272648947579, 49.29815687452044, 58.51722131456648, 29.65448774610247, 48.66373423167637, 56.317237513405935, 70.26836218152727, 64.31362397330147, 74.23152433122907, 2.495479396411351, 0.34727821233017103, 0.15755600774926798, 0.12222466218684401, 0.16517640384180204, 0.14830079009490355, 0.12807900804494107, 0.22127795059766087, 0.10384894322071757, 0.12357529971216406, 0.1752632747271231, 0.11551638000777789, 0.22045433122132504, 0.14519034485731805, 0.18182592972048692, 0.17329770805580275, 0.10534356587699481, 0.08460523547338587, 0.11105559580028057, 0.17902463860809803, 0.15495856212718145], [0.03765360452234745, 0.03179324684398515, 0.053380499194775305, 0.019817251346207092, 0.13853768897908075, 0.08666136621364526, 0.08992926550230809, 0.05572838642235313, 0.06390792251165424, 0.029553541847105538, 0.024303869078201906, 0.01970917937744941, 0.032637846523097584, 0.044147126975336244, 0.02213134752985622, 0.04483853041061333, 0.06354002082454306, 0.19156043737062387, 24.513703210013254, 72.01377746037075, 71.38194302150181, 61.78395857129778, 54.22829982212612, 39.42511408669608, 35.31312152317592, 97.99207755497524, 57.87439482552664, 35.94807570321219, 2.6932746342250278, 0.10093476423727614, 0.13002940267324448, 0.09760785954339163, 1.0930533643279756, 0.9247434586286545, 0.7632431675280843, 2.64398997596332, 4.918147317000797, 67.58743449619838, 67.13284860338483, 70.9128840310233, 65.15328598022461, 67.46855081830705, 63.84116036551339, 68.23956462315151, 63.26459189823696, 63.365792410714285, 64.63593006134033, 63.999551500592915, 63.032139914376394, 59.579128401620046, 59.81646496909005, 60.6830165045602, 54.19601501737322, 47.258565289633616, 45.58309405190604, 45.98747226170131, 48.765685149601524, 59.574487004961284, 58.21573550360543, 60.33270222800118, 61.553340911865234, 59.09647873469761, 57.0646413394383, 48.609062331063406, 42.83478273664202, 43.62932661601475, 40.971015317099436, 50.38997943060738, 56.80036660603115, 55.883454527173726, 54.29796246119908, 54.65777839933123, 56.54815394537789, 55.28841427394322, 58.51284394945417, 51.68603386197771, 50.173751490456716, 51.93634271621704, 58.866118158612935, 51.85325615746634, 48.39745494297573, 44.606163433619905, 47.372269085475374, 44.822891644069124, 48.92833205631801, 50.49494586672102, 59.07517555781773, 40.56790515354702, 30.301882675715856, 60.57918957301548, 48.351582935878206, 54.275467668260845, 45.61647319793701, 46.096840381622314, 38.76139783859253, 41.33834225790841, 39.42177547727312, 40.90553549357823, 38.98866299220494, 41.397106647491455, 44.387298652103965, 52.031960351126536, 52.939204011644634, 57.72118704659598, 56.56197738647461, 60.35317162105015, 55.9177508354187, 48.07017394474575, 38.99263736179897, 43.394001552036826, 40.86920683724539, 43.580237592969624, 43.95136867250715, 50.35998405729021, 54.729337896619526, 57.20895195007324, 55.31041921888079, 58.77003846849714, 57.3843731198992, 51.99961648668562, 43.53036689758301, 45.37524216515677, 43.65752240589687, 45.21769176210676, 51.38126155308315, 55.91465193884713, 55.28850112642561, 60.68555954524449, 59.82170391082764, 60.788024629865376, 58.53847585405622, 60.99148872920445, 62.26281452178955, 62.667790276663645, 63.07979760851179, 61.409999574933735, 5.0601072651999335, 0.6177782331194196, 1.5471654768501009, 1.315935724547931, 0.8165697774716786, 0.4444091703210558, 0.01958012201690248, 0.2096187240843262, 12.33579877444676, 19.64256089074271, 43.10121488571167, 57.486379623413086, 88.11680439540318, 36.967901025499614, 18.31436061859131, 45.12450252260481, 45.41417639596121, 52.22691290719168, 51.285181862967356, 23.378732340676443, 0.30211313015648295, 0.06967661010899714, 0.1512239868087428, 0.044534709570663314, 0.03045997302979231, 0.04081157435263906, 0.023754839253212725, 0.062497065003429136, 0.0366499189154378, 0.020712646156815544, 0.07123226699020181, 0.051890195413891754, 0.01598494154001985, 0.015091329580172896, 0.04103904303961566, 0.026950130205867544, 0.08550557680428028, 0.006635704801218318, 0.04771443323365279, 0.04638235364109278, 0.029189338175845996, 0.03254976589232683, 0.061547285611076016, 0.07690762209572963, 0.08757581428757735, 0.042310454816158326, 0.06114985407995326, 0.0363839399734778, 0.0411427944366421, 0.03528526285663247, 0.01616637162598116, 0.026690616006297723, 0.03762514676366534, 0.10342386138758489, 0.017297023009242754, 0.054390990507922, 0.029699739002223526, 0.17600652841585024, 35.76442091805594, 86.14793504987443, 77.24647276742118, 71.77610737936837, 58.72489602225167, 51.44946507045201, 29.07128027507237, 78.28608308519635, 51.87686961037772, 38.06859990528652, 3.5697744701589857, 0.15625877092991555, 0.19003230865512574, 1.3733849504164286, 1.826500105006354, 1.7357809501034873, 2.837156193596976, 1.9578371260847365, 5.489422125475747, 72.14322934831891, 68.76171479906354, 72.81578023093087, 67.96060139792306, 72.14732183728898, 66.02540302276611, 69.55605370657784, 64.20671204158238, 64.76304735456193, 65.13681874956403, 66.43807043348039, 66.73167351314, 63.34529522487095, 62.47892434256417, 64.78678240094865, 57.18210758481707, 51.85115432739258, 47.795740944998606, 48.00381517410278, 51.37229142870222, 62.521343094961985, 61.39089897700718, 62.603310993739534, 60.10904666355678, 60.929135595049175, 60.03238718850272, 51.975996085575645, 44.363084180014475, 45.9015508379255, 42.99075937271118, 52.71397120612008, 59.20598234449114, 58.229836872645784, 55.107347692762104, 56.00345686503819, 58.85001918247768, 57.763710021972656, 59.91706098828997, 56.580435276031494, 52.51805632455008, 55.294997692108154, 60.6342054094587, 53.912479877471924, 52.32475743974958, 47.24052776609148, 48.94733885356358, 47.515005929129465, 52.122839314596995, 54.36148984091622, 61.71790204729353, 40.838030270167756, 33.51597343172346, 62.56315040588379, 50.47955213274275, 56.241637638636995, 48.82023893083845, 47.469342367989675, 40.80466849463326, 43.02964496612549, 41.73802695955549, 43.847705023629324, 40.8538304737636, 43.22064747129168, 46.05031524385725, 54.02116707393101, 55.36418090547834, 60.12462452479771, 59.21351419176374, 60.98324816567557, 58.06979554040091, 51.531099455697195, 41.21992063522339, 45.21003484725952, 43.74205418995449, 45.204111507960725, 45.79393713814871, 54.19862059184483, 58.73504039219448, 60.33779525756836, 56.444698742457796, 61.56900909968785, 59.28926345280239, 54.495524065835134, 46.128913266318186, 47.32279791150774, 45.714001587459016, 48.13391671861921, 53.436111382075715, 57.89605930873326, 57.64238405227661, 63.393071038382395, 62.441140038626536, 62.90844808306013, 60.86968680790493, 63.52299540383475, 62.86332648141043, 66.16273416791643, 65.77620588030133, 64.91813114711216, 7.794786214828491, 0.6549411075455802, 1.1702772719519479, 2.9459163461412703, 3.288037610905511, 0.8135334146874291, 0.046266303796853335, 0.26077826959746225, 8.416481494903564, 29.06688380241394, 36.48352125712803, 51.937992913382395, 65.40346281869071, 37.86487872259957, 29.130204473223003, 56.61217812129429, 52.48758152553013, 59.10365622384207, 60.412814957754954, 40.10827486855643, 0.11997701493757111, 0.011581997353849667, 0.08320423029363155, 0.07591746986976691, 0.0335289937044893, 0.08683914238853113, 0.011218835233843752, 0.02726058372562485, 0.039444472175091505, 0.006255884222420198, 0.010926695374239768, 0.020116098524470414, 0.06486737781337329, 0.03673468490264245, 0.023821805570540682, 0.010364742849820426, 0.06592171266674995, 0.008038686638298844, 0.04245521008436169, 0.024443833889173608, 0.09350927732884884, 0.14692196622490883, 0.1321312870298113, 0.16607523203960486, 0.21742676225091728, 0.15115819605333464, 0.16571972040193422, 0.19344476982951164, 0.14736928365060262, 0.14263089719627584, 0.14261313314948762, 0.0658600949017065, 0.12551563845149108, 0.1872488630137273, 0.1805900867496218, 0.18228023605687277, 0.2303841891033309, 0.24376519822648593, 44.49839339937483, 95.94538143702916, 88.24877153124127, 82.39265605381557, 70.604599407741, 54.06211280822754, 50.539449078696116, 118.05721746172223, 73.33103084564209, 54.67922748838152, 4.688379509108407, 0.18778175727597304, 0.5689415165356227, 1.2674182994025094, 5.1130121520587375, 3.581452872071947, 4.7076616287231445, 6.750120214053562, 5.781009793281555, 76.43647956848145, 71.03509589603969, 74.67420101165771, 68.693573815482, 74.97673947470528, 68.2244314466204, 75.61436871119908, 66.99785900115967, 68.52066094534737, 70.82274505070278, 70.00806181771415, 69.3501785823277, 65.8516355242048, 63.743718828473774, 66.07101794651577, 60.167237826756065, 54.07914284297398, 48.88064309528896, 51.10600866590227, 53.310804094587056, 64.68438679831368, 61.91135379246303, 65.3419017791748, 62.11051000867571, 64.55948598044259, 61.29595184326172, 53.37869494301932, 47.29312562942505, 48.823775563921245, 45.6535244669233, 56.32262584141323, 60.624887875148225, 60.517732756478445, 56.649705341884065, 56.47704955509731, 60.31442846570696, 59.10776260920933, 62.5562230518886, 59.01813084738595, 55.12017059326172, 56.56774091720581, 64.1941705431257, 57.45758976255144, 54.731495312282014, 49.26202276774815, 51.21634258542742, 51.54403700147356, 54.087525844573975, 58.208828994206016, 63.837512561253135, 45.59036186763218, 37.76338985988072, 65.32586533682687, 52.42382485525948, 59.0388434273856, 50.82377283913748, 50.60867745535714, 43.20447553907122, 46.14071478162493, 43.92264134543282, 46.062419005802695, 43.32760804040091, 45.6073328426906, 48.649914264678955, 58.49858624594552, 59.1174692426409, 62.009601320539204, 59.469416345868794, 63.65090479169573, 61.17007827758789, 53.154844829014365, 43.52256754466465, 47.60071890694754, 44.52835750579834, 48.36276606151036, 48.56775181634085, 56.20775474820818, 60.68911007472447, 61.47991929735456, 57.98935971941267, 64.82385104043144, 62.61199624197823, 56.54847008841378, 48.08246183395386, 50.848772457667756, 48.296282223292756, 50.619481904166086, 57.6746688570295, 62.12633105686733, 59.2566625050136, 67.23244408198765, 64.97907379695347, 65.64552416120256, 62.06975187574114, 67.26321765354702, 65.34871796199253, 69.58458300999233, 69.1840124130249, 68.308504649571, 7.040756412914821, 2.8781942086560384, 10.042302642549787, 5.8326731239046365, 4.874793597630092, 0.9157129717724664, 0.14269868284463882, 0.3337847835251263, 18.165749073028564, 32.759936468941824, 59.264083181108745, 67.67936611175537, 96.0417251586914, 46.44108888081142, 28.774309056145803, 59.82792254856655, 60.28141757420131, 66.36307157788957, 69.12215260096959, 47.47716951370239, 0.3368903568812779, 0.11389196717313357, 0.23976336153490202, 0.1581962462514639, 0.18546207674912044, 0.14537349502955163, 0.21624787550951752, 0.20262576932353632, 0.1767383420041629, 0.10290778800845146, 0.2055017128586769, 0.14995447493025235, 0.10883118837539639, 0.09478581883013248, 0.06771608495286532, 0.21047652805490152, 0.20538970029779843, 0.11423963494598866, 0.1376740224659443, 0.07142879108765296], [0.07947264731462512, 0.031951935828796456, 0.0532526360558612, 0.01612336268382413, 0.004833498828312648, 0.03143872586744172, 0.09450842014380864, 0.06166295547570501, 0.010704570998703795, 0.02302525974144893, 0.01212854458883937, 0.044325147422828844, 0.02543591145825173, 0.07372306726340737, 0.02755794151952224, 0.054367906746587584, 0.049623382943017144, 1.5453528655426843, 57.48822089603969, 61.752629143851145, 74.66047137124198, 51.799616064344136, 57.04784754344395, 33.41684348242623, 32.88716493334089, 49.500144481658936, 55.592470918382915, 18.264851229531423, 0.22509621642529964, 0.07282015428479229, 0.12517639808356762, 0.38496822704161915, 1.6703562779085976, 0.5590717632855687, 0.9701134583779744, 0.7386709174939564, 22.152630635670253, 81.12884126390729, 63.409378460475374, 71.44119031088692, 68.52455193655831, 70.3655674798148, 64.81390122004917, 67.07847200121198, 63.59322779519217, 67.20495006016323, 61.872096470424104, 65.91477380480084, 60.30268601008824, 66.60967704227993, 63.38712338038853, 59.0597505569458, 54.00159052440098, 45.53899383544922, 43.61661141259329, 47.51501635142735, 56.26142610822405, 60.8371970312936, 61.13429505484444, 59.95688806261335, 58.66278607504708, 57.03529562268938, 53.69001245498657, 43.4203109060015, 43.92866543361119, 41.38529123578753, 43.187622683388845, 51.553017548152376, 56.346280983516145, 56.583728722163606, 53.486749853406636, 56.366604464394705, 56.26122113636562, 56.51905836377825, 55.025650773729595, 50.402253423418315, 49.889191491263254, 56.63364805494036, 56.19922236033848, 48.92033120564052, 47.94000291824341, 48.10436603001186, 49.978527954646516, 48.04083170209612, 53.43995026179722, 50.78358793258667, 61.672141211373464, 36.9328612600054, 29.05563988004412, 59.434404373168945, 50.638165610177175, 55.290290287562776, 44.30561910356794, 45.56443813868931, 38.95676033837454, 45.229125022888184, 43.57519320079258, 44.27573142732893, 38.431497369493755, 43.655594280787874, 40.313288416181294, 46.483333928244456, 49.51123033251081, 57.36260788781302, 48.76846442903791, 57.48662281036377, 56.545499733516145, 52.81739166804722, 40.45060913903372, 42.03827946526663, 41.57156549181257, 44.22472817557198, 42.06002385275704, 47.99614783695766, 54.514183453151155, 57.98290831702096, 58.113155773707796, 57.45105150767735, 52.517288548605784, 48.965199198041645, 43.830984183720176, 43.45772695541382, 41.68545341491699, 46.315705163138254, 48.78231566292899, 53.990000929151265, 56.149379457746235, 60.17876488821847, 58.01828159604754, 62.229185240609304, 56.17586946487427, 60.04130172729492, 58.50481183188302, 63.689015660967144, 61.354115213666645, 65.72182232992989, 43.357575620923726, 0.5047854876943997, 2.2166002009596144, 1.5867113662617547, 1.257066894854818, 0.7980840408376285, 0.10545459456209626, 0.04825263703241944, 2.144399515220097, 21.386228697640554, 28.38273811340332, 35.22051593235561, 47.684510707855225, 47.83371979849679, 27.576371874128068, 35.56903757367815, 35.94962167739868, 49.34442492893764, 47.49114581516811, 61.20018482208252, 11.720665199416024, 0.5005619057587215, 0.14908831140824727, 0.10165521914937667, 0.07102825865149498, 0.08658790122717619, 0.049923339526035955, 0.04689249662416322, 0.042644331364759376, 0.02878246482993875, 0.022359664385606135, 0.09328890951084239, 0.033525129447558095, 0.04916498504046883, 0.04007361323705741, 0.026350812454308783, 0.06449934720460858, 0.04766143286334617, 0.03398094552436045, 0.024194682615676096, 0.05990263207682541, 0.040558395973805866, 0.012768057906734092, 0.06402214031134333, 0.02117404148780874, 0.013205033610574901, 0.04570342507213354, 0.0872415882934417, 0.016850216181150506, 0.0338805664463767, 0.05220194493553468, 0.015462237177416682, 0.0282184088469616, 0.02740197685281081, 0.04177031719258853, 0.04681697567658765, 0.02969537941472871, 2.5057814036096846, 72.28944723946708, 69.52122238704136, 81.01244504111153, 62.73283931187221, 64.73499052865165, 44.747138908931184, 42.150829860142295, 57.76128510066441, 59.53710569654192, 18.59607011931283, 0.24227426680071013, 0.19387481175363064, 0.45977353730372017, 1.492870950273105, 1.657175219484738, 1.8665768802165985, 2.2135136808667863, 0.6700721670474324, 24.253225667136057, 83.37303992680141, 65.94592952728271, 75.760301726205, 69.7988862991333, 73.29833262307304, 68.26974759783063, 69.60799843924386, 67.50648798261369, 70.37031309945243, 65.48117841993059, 68.67939254215786, 63.49205507550921, 67.37942627498082, 65.767701285226, 61.464452607291086, 55.47234351294381, 48.524707726069856, 44.707718304225374, 48.41480112075806, 58.361526080540244, 63.19560323442732, 64.36804226466587, 60.9526344026838, 60.14494105747768, 59.79020077841622, 55.80602032797677, 45.9643486567906, 45.571969985961914, 44.88436235700335, 45.32423543930054, 53.318273408072336, 58.92246804918562, 57.562493664877756, 54.02800062724522, 57.57522276469639, 57.750452859061106, 57.91180740083967, 56.80376427514212, 51.95327547618321, 52.07844032560076, 56.50545031683785, 58.95949499947684, 50.50665358134678, 49.59718649727957, 50.70412138530186, 51.50170857565743, 50.62721872329712, 54.16159364155361, 53.43093497412545, 62.72648171016148, 40.05693462916783, 31.542028427124023, 62.0637138911656, 53.136546748025076, 59.11368942260742, 47.26096589224679, 47.6587050982884, 40.90392003740583, 47.350489956992014, 47.01393658774239, 46.83623988287789, 41.10663373129708, 46.453182220458984, 42.402153151375906, 48.503724166325156, 51.08614724023001, 58.57063211713518, 53.49191236495972, 58.47259998321533, 58.49043600899832, 56.18246330533709, 42.24112170083182, 44.45621088572911, 42.8022894859314, 45.42085708890642, 43.376182896750315, 49.344289439065115, 57.027690819331575, 60.331618309020996, 59.67197717939104, 59.69692816053118, 56.537724699292866, 50.31104094641549, 45.95664657865252, 46.586337498256135, 43.425539425441194, 49.43044015339443, 51.42448629651751, 57.34303828648159, 58.310032980782644, 63.292037282671245, 59.97982406616211, 64.5427964074271, 59.610256331307546, 60.70009517669678, 61.46103409358433, 66.17099557604108, 64.32437978472028, 69.23332377842495, 48.62952477591378, 1.0240376676831926, 1.0441195900951112, 2.4743616495813643, 3.2122653339590346, 1.9183989337512424, 0.533289223909378, 0.05118695832788944, 0.46551524634872166, 27.86311534472874, 33.09005233219692, 32.948548793792725, 52.72127028873989, 40.663508892059326, 29.588597978864396, 47.46376296452114, 42.220204148973735, 56.679360253470286, 53.73312950134277, 72.88913236345563, 19.59931182861328, 0.708858314369406, 0.1344537902623415, 0.08632113518459456, 0.11919743248394557, 0.11687194369733334, 0.08575594265546117, 0.05855669001383441, 0.033654939981975725, 0.0459528545449887, 0.04699183415089335, 0.06236021127551794, 0.01481860939280263, 0.03328288905322552, 0.037671670517218966, 0.030357741551207643, 0.08064748320196356, 0.01566006745477872, 0.014689806482887693, 0.022810961419184293, 0.12081698700785637, 0.1416147502937487, 0.16622947662004403, 0.12804331710296019, 0.16589623450168542, 0.12721918204001018, 0.1041209746950439, 0.11362847845469203, 0.10491853154131345, 0.1177731603384018, 0.12353622966579028, 0.11653035559824534, 0.09862810479743139, 0.11046841195119278, 0.130482569070799, 0.18281957640179566, 0.2794829559113298, 2.9156328397137776, 87.79863248552594, 78.93109130859375, 94.07418986729213, 68.75432191576276, 75.01658739362443, 44.2563841683524, 46.495854582105366, 59.528267587934224, 70.14338493347168, 30.550100122179302, 0.358007832297257, 0.24911623394915036, 0.5980464347771236, 2.5848360529967715, 4.874070984976632, 3.3366584990705763, 6.407245721135821, 2.4213538425309316, 26.520530564444407, 86.7633717400687, 67.4110336303711, 77.53038311004639, 72.08621937888009, 74.28995868137905, 69.16892787388393, 71.7514204297747, 69.80971854073661, 71.27264785766602, 66.83732087271554, 70.95055716378349, 65.61320114135742, 69.296920640128, 66.887542452131, 64.4812353679112, 58.47275284358433, 52.08431850160871, 46.83560759680611, 52.09351096834455, 60.86161994934082, 64.63784081595284, 64.4699375970023, 62.454438890729634, 63.37925107138497, 62.41873904636928, 58.916034017290386, 46.42539984839303, 49.54952532904488, 45.867824281964985, 47.45331634793963, 55.58814219066075, 61.56539603642055, 60.03476347242083, 53.19134371621268, 59.888941628592356, 60.58103084564209, 60.37928295135498, 58.51231588636126, 54.11904634748186, 53.726751055036274, 58.71639837537493, 61.014792987278526, 54.83504431588309, 52.95500768933977, 52.75749124799456, 55.07333278656006, 53.814406054360525, 57.458166463034495, 57.765870911734446, 65.81787422725132, 43.20500012806484, 36.313467570713584, 65.0808857509068, 54.73409046445574, 60.37936632973807, 49.32074894223894, 49.01831122807094, 42.15775374003819, 50.290192876543315, 49.146529810769216, 49.034622124263215, 43.63325234821865, 49.62728261947632, 45.02590063640049, 50.62349101475307, 55.02791241237095, 62.321686608450754, 55.45646340506417, 57.986576965876985, 61.10688441140311, 57.137093680245535, 43.99941199166434, 45.584532329014365, 45.031674589429585, 48.06442778451102, 46.99918903623308, 52.77392373766218, 59.46411487034389, 62.90423747471401, 61.746479988098145, 62.18964999062674, 57.518028667994905, 54.63706234523228, 48.10078770773751, 49.119817461286274, 46.85305452346802, 51.65015683855329, 53.778595038822715, 61.209141050066265, 61.030065127781455, 65.34414604731968, 63.06162806919643, 66.51003292628697, 61.402710914611816, 64.63985579354423, 64.11989430018834, 69.23638793400356, 67.81680147988456, 71.2953267778669, 49.638924326215474, 0.6920931254114423, 7.853919727461679, 8.024494528770447, 6.294401330607278, 2.2743742551122392, 0.4840376781565802, 0.1046008618016328, 3.201906438384737, 33.14807326453072, 42.344827038901194, 45.00351006644112, 54.52121850422451, 61.43001038687569, 37.03866842814854, 49.096586159297395, 50.23819950648716, 64.75781536102295, 62.25245475769043, 82.48256574358258, 20.866037913731166, 0.745537094771862, 0.3789188430777618, 0.24937551575047628, 0.16303349525800773, 0.19747225514480046, 0.25830832070537973, 0.11567514363144125, 0.10617692901619843, 0.08533163435224976, 0.15331054984458856, 0.14889154982353958, 0.12113979325762816, 0.09189098488007273, 0.0931785593607596, 0.07413834426552057, 0.20169879549315997, 0.0770770183631352, 0.1191516313701868, 0.161411905129041], [0.08028592581727675, 0.05288644088432193, 0.0208745497012777, 0.07012039915259395, 0.03198531975171395, 0.02140989856395338, 0.04086429652358804, 0.011768982945276158, 0.015347636005442058, 0.05601600045338273, 0.057636141910084655, 0.06570205731051308, 0.05903120990842581, 0.06861971039324999, 0.052116561481463056, 0.2746006521795477, 0.4728325679898262, 16.803664173398698, 75.1346025466919, 62.75376728602818, 54.7195200920105, 46.280616760253906, 57.239061968667166, 23.94005298614502, 27.826991660254343, 24.644800083977835, 36.23343127114432, 3.056007512978145, 0.058575668638306, 0.02674343147581177, 0.030518907188837017, 1.512710988521576, 0.9203549112592424, 1.2031752552304948, 2.312558731862477, 0.5021660168256078, 51.858404772622244, 71.94058513641357, 69.4750029700143, 66.62582465580532, 68.74654688153947, 74.30780165536063, 67.87145601000104, 69.78423254830497, 65.55852576664516, 64.54916095733643, 65.45968069349016, 66.87441730499268, 68.90832873753139, 66.06042194366455, 57.50072070530483, 59.86995220184326, 51.14141321182251, 45.34968669073922, 42.24932404926845, 50.46238660812378, 59.46016829354422, 61.060018811907085, 53.88131373269217, 56.52707658495222, 58.58594594682966, 54.6672487940107, 50.73072256360735, 40.660250186920166, 43.13243661608015, 40.438296931130544, 41.75899314880371, 50.04232631410871, 56.76151922770909, 52.80030952181135, 58.580839020865305, 56.769047600882395, 56.277542454855784, 55.439867632729666, 55.59267241614205, 55.24078784670149, 53.97999899727957, 53.93370315006801, 53.94984381539481, 48.039532388959614, 50.85144404002598, 50.66874463217599, 52.77602209363665, 48.21897656576974, 51.83721276691982, 50.89197635650635, 60.69974776676723, 33.645977701459614, 30.05303989137922, 57.75832516806466, 51.4895144871303, 54.755747999463765, 41.72744137900216, 42.41738707678658, 42.163899421691895, 50.73801122392927, 51.43104192188808, 55.29377828325544, 45.51425130026681, 41.117983613695415, 38.24716166087559, 42.438502652304514, 48.24972929273333, 56.869737420763286, 50.634469168526785, 46.19722100666591, 58.8108035496303, 54.14236102785383, 46.37879828044346, 40.2530197416033, 43.30242082050869, 42.38123907361712, 42.65457078388759, 44.67161546434675, 55.20696401596069, 56.57352181843349, 57.84118243626186, 55.38163478033883, 53.450810296194895, 46.829427174159456, 43.087137835366384, 44.321561745234895, 42.76192740031651, 45.34591381890433, 50.44595759255545, 54.194528102874756, 58.05570111955915, 58.52861636025565, 59.17991270337786, 59.44808537619454, 58.265182358878, 56.49434362139021, 63.102483476911274, 58.0756459236145, 62.302030154636924, 57.742879322596956, 69.54354694911412, 21.941226482391357, 0.3069412053695747, 1.2377533997808183, 2.3708137316363196, 1.4304121817861284, 0.32594626556549755, 0.07998356382761683, 0.05023432230310781, 8.692532556397573, 39.605843680245535, 38.946584701538086, 22.823998587472097, 54.53031717027937, 32.51632220404488, 23.06974594933646, 32.40723896026611, 41.21107905251639, 54.278719425201416, 55.58254541669573, 43.23286587851388, 0.563195247735296, 0.08478728641888925, 0.07199578851993595, 0.053350474020200114, 0.030901767180434296, 0.021727963550282375, 0.07459642325661012, 0.12363017962447234, 0.04568194265344313, 0.02601465772438262, 0.018906465665038143, 0.052577609063259194, 0.032274826895445585, 0.014350162386628134, 0.03685368298153792, 0.047475541409637244, 0.012110476897630309, 0.06956921837159566, 0.023912091440122043, 0.03679497952439955, 0.02497188510772373, 0.08476125781557389, 0.09551176309053387, 0.055571889105652056, 0.02718336644050266, 0.04556441021018794, 0.009665833969068314, 0.026331708300858736, 0.016535879744748985, 0.01797578533712242, 0.007473337197942393, 0.023876395409128497, 0.048208040318318775, 0.00658384055298354, 0.15682186000049114, 0.36770979740789955, 23.491100345339092, 87.99605860028947, 68.55039923531669, 67.07535226004464, 52.20577301297869, 67.9683277947562, 28.754423311778478, 25.571920803615026, 27.901816810880387, 41.73383024760655, 4.110001036099025, 0.10223331062921456, 0.039886344357260635, 1.0063954315015247, 0.5344740003347397, 2.6373733367238725, 2.8734505431992665, 1.4410571477242877, 0.90391541911023, 55.009642124176025, 74.31087275913784, 70.26339421953473, 67.78200490134103, 69.56403718675885, 75.51976898738316, 67.85460662841797, 72.8422737121582, 68.193845476423, 68.48107705797467, 67.14684227534703, 67.86247198922294, 67.66826289040702, 67.95798192705426, 60.63241972242083, 64.00011430467877, 52.73652158464704, 46.22902985981533, 44.55121013096401, 52.779346806662424, 61.46254185267857, 62.00079795292446, 54.93027979987008, 55.80041313171387, 60.56481375013079, 58.36883558545794, 51.06993709291731, 42.68083150046212, 44.45181267602103, 42.90822866984776, 43.26430647713797, 51.798858710697715, 60.80687509264265, 55.58870846884591, 58.28126743861607, 59.31710488455636, 59.33617074148995, 56.459637369428364, 56.61959184919085, 58.505847113473074, 55.123724596840994, 56.67495856966291, 55.85538033076695, 50.312204769679475, 53.47167921066284, 51.78664377757481, 53.25998844419207, 53.03562763759068, 53.141511235918315, 53.1485184941973, 61.43217822483608, 35.396232400621685, 34.43449749265398, 59.35982935769217, 52.67215347290039, 56.18667391368321, 44.623290743146626, 44.47161851610456, 43.903221130371094, 52.68533420562744, 54.25689513342721, 57.19974558694022, 47.89677470070975, 42.67487342017037, 40.90319047655378, 44.146199635096956, 51.50074972425188, 57.67635726928711, 53.447027002062114, 50.248250075748985, 60.455219813755576, 57.2351188659668, 48.400050095149446, 42.4417405128479, 45.64078841890608, 43.48027385984148, 43.70926564080374, 46.55450432641165, 57.20656524385725, 58.81306866237095, 59.07630811418806, 58.30341134752546, 57.16988222939627, 48.261235509599956, 45.025449003492085, 45.765984535217285, 45.48254667009626, 47.49624579293387, 52.390091351100374, 56.08904824938093, 59.800727299281526, 61.87090832846505, 61.48223304748535, 60.56122153145926, 59.76028183528355, 59.495715277535574, 66.18645531790597, 60.11320168631417, 65.63591480255127, 60.62062168121338, 72.22126456669399, 26.13232602391924, 0.2618259819490569, 0.6315492913126945, 2.8426157406398227, 2.8266520372458865, 1.1716885162251336, 0.07365498305963618, 0.19457739405333996, 5.024626289095197, 50.091891288757324, 33.8431328364781, 34.88469212395804, 54.58431509562901, 28.88932258742196, 30.999363694872173, 43.781203814915244, 48.6518771307809, 62.6755861554827, 61.69749518803188, 54.018349579402376, 1.4624214470386505, 0.07779528160712548, 0.00646692981743919, 0.049676868465862105, 0.018419223238847086, 0.021936129612315978, 0.03583949365253959, 0.07146376956786428, 0.07217831443995237, 0.013267320580780506, 0.044725791817264896, 0.015509134125230568, 0.041369126577462466, 0.015130455605685711, 0.0070819853405867305, 0.0631433017551899, 0.05390880995297006, 0.05137176073289343, 0.015514891494863799, 0.22210838246558393, 0.08302343463791267, 0.19731217516320093, 0.20238678928996834, 0.20895297266542912, 0.06878827884793282, 0.11592468166989939, 0.05733106578035014, 0.11903200564639908, 0.09871999879500695, 0.1426461370927947, 0.14111830693270477, 0.12727640968348297, 0.2172065233545644, 0.14566838634865625, 0.5177103312952178, 0.6041030383535794, 28.39295891353062, 101.12787600925991, 79.51193291800362, 73.72798837934221, 59.87724781036377, 70.99028696332658, 29.240507125854492, 40.35689183643886, 35.95208828789847, 56.87209286008562, 5.680693004812513, 0.11425279852535043, 0.15480714025241987, 1.8754028294767653, 5.218920503343854, 3.565055991922106, 4.345232733658381, 8.256540043013436, 0.832442122910704, 59.04627105167934, 76.38028253827775, 74.7144102369036, 72.53462832314628, 72.60819584982735, 78.29210022517613, 71.08184337615967, 74.92571885245187, 70.27984060559953, 69.83895656040737, 68.62256322588239, 68.90226296016148, 66.96195071084159, 70.58829198564801, 64.566086769104, 65.48873111179897, 55.92112071173531, 49.76918567929949, 46.21661690303257, 55.2830467905317, 62.83271271841866, 65.1604426247733, 56.49118913922991, 57.90266009739467, 64.32821519034249, 59.862100737435476, 54.915810176304404, 43.541306836264475, 48.34399897711617, 45.06252459117344, 45.49513333184378, 54.32537310464041, 63.376777512686594, 55.640225887298584, 62.75494153159005, 62.361346926007954, 63.23037896837507, 61.341955866132466, 58.99646636417934, 59.608943121773855, 57.01097345352173, 60.021992683410645, 57.0927745955331, 52.36311149597168, 55.58813524246216, 54.64585181644985, 56.731641973767964, 54.64937802723476, 55.365803309849326, 57.580131667000906, 65.36175973074776, 37.56551211220877, 38.371395451681956, 61.15901674543108, 57.04758698599679, 59.33281476157052, 47.75473962511335, 46.23679099764143, 48.71429974692208, 55.91700390407017, 57.192019190107075, 60.05922113146101, 51.24789088112967, 45.08540848323277, 42.86574043546404, 45.527397292000906, 54.44805744716099, 60.726366315569194, 56.57528666087559, 53.258546692984446, 62.842843191964285, 60.2527562550136, 50.53558588027954, 45.29197495324271, 48.37504700251988, 46.44155788421631, 45.17345258167812, 49.15872042519705, 61.70354012080601, 63.25884573800223, 62.02199690682547, 61.36142471858433, 59.11556543622698, 51.61131293433053, 47.36143684387207, 49.14237131391253, 47.11717292240688, 50.738376004355295, 56.68926838466099, 60.31512328556606, 62.819441659109934, 64.67750113351005, 62.48979132516043, 63.64812551225935, 63.40092945098877, 62.80954047611782, 69.95727743421281, 63.97543430328369, 68.42296927315849, 63.289292744227815, 74.04163006373814, 28.50266228403364, 1.3242427302258355, 7.110843760626657, 8.23524989400591, 6.1673257265772135, 0.8450845873781613, 0.21314204431005887, 0.3516801675515515, 10.963982922690255, 55.49830545697893, 55.888641357421875, 32.2934205191476, 64.20077133178711, 43.18356840951102, 32.98594399860927, 47.124482427324565, 54.34096833637783, 71.10354954855782, 70.11149270193917, 62.000075340270996, 1.4229966082743235, 0.2442052417567798, 0.1477806522910084, 0.11831031580056463, 0.1275001633912325, 0.10460641900343554, 0.1595878265798092, 0.21447205437081202, 0.13582616804965905, 0.1538862053837095, 0.10913728230765887, 0.20410870760679245, 0.1179649279053722, 0.16086050043148653, 0.09073288845164434, 0.10824047614421163, 0.2442750765808991, 0.12717783211597375, 0.036702444311231375], [0.04185229100819145, 0.06027585347848279, 0.08916535720761333, 0.022605399235284755, 0.04187999220032777, 0.03828839099566851, 0.04506022137190614, 0.0314006838016212, 0.07548730580934457, 0.016796823956870606, 0.0373406641717468, 0.0172646704595536, 0.03759626831327166, 0.05040639199848686, 0.03426223221634116, 0.02978331416047045, 0.04073879807921393, 45.16081380844116, 74.43940748487199, 62.83353955405099, 53.07116767338344, 65.55832426888603, 36.87721313749041, 28.902319192886353, 43.64657204491751, 37.26452309744698, 26.39952768598284, 0.39271682554057663, 0.1858143721308027, 0.03964514551418168, 0.9897219261952809, 0.5236712885754449, 1.4271642246416636, 0.6200390032359532, 2.18825307062694, 8.299558077539716, 63.67320156097412, 66.98358045305524, 70.30488886151994, 67.92952905382428, 66.59530816759381, 65.81717940739223, 68.10729871477399, 61.20805713108608, 63.627635274614605, 63.053269386291504, 64.95856271471295, 65.8381838117327, 61.80780478886196, 53.44545670918056, 63.12630884987967, 57.48859262466431, 47.19420412608555, 44.15730633054461, 44.87877600533621, 48.30642311913626, 62.56931345803397, 56.16309172766549, 61.35334396362305, 58.007630007607595, 58.18508005142212, 52.24566956928798, 45.00402423313686, 42.01388781411307, 41.66929537909371, 40.57544394901821, 42.99383395058768, 48.276472909109934, 55.0996629851205, 55.99221815381731, 55.94175338745117, 54.04311295918056, 51.951979637145996, 51.230846949986045, 55.92973647798811, 49.226371560777935, 55.75020892279488, 53.373271874019075, 52.71036856515067, 50.16750505992344, 52.84917620250157, 53.42221845899309, 53.976441519601, 51.234817845480784, 55.179053102220806, 51.145627294267925, 61.96340274810791, 38.12801047733852, 32.67048536028181, 58.082319668361116, 50.58351802825928, 50.78150347300938, 41.37568882533482, 43.51694645200457, 47.26604502541678, 52.67953940800258, 54.17025457109724, 54.191800934927805, 49.52848270961216, 42.26784099851336, 40.721835545131135, 38.839968068259104, 44.499967166355674, 49.75920459202358, 57.27296917779105, 45.77429805483137, 52.78825787135533, 56.827794619968955, 49.484278270176475, 43.23701395307268, 40.56889527184622, 42.21507290431431, 40.56491047995431, 43.143512044634136, 51.511161599840435, 57.54456731251308, 55.72293029512678, 57.500408036368235, 53.1809526852199, 46.80826990944998, 41.6389456476484, 43.84861523764474, 42.45150620596749, 45.304450443812776, 47.64804308755057, 51.51676879610334, 54.71755027770996, 59.24216856275286, 54.840290205819265, 60.200964382716585, 56.544325487954275, 56.43951538630894, 58.254819120679585, 57.63159349986485, 59.05765914916992, 61.0670781816755, 60.401607513427734, 60.5734086717878, 3.1052287689277103, 1.8115133834736687, 2.0798987363065993, 2.0379118578774587, 0.21522893304271357, 0.16582778388900415, 0.12066062539815903, 1.1606607479708535, 18.53412171772548, 37.15483883449009, 36.86037070410592, 44.0132771219526, 74.34921986716134, 24.462590524128505, 21.245652743748256, 33.58240863255092, 51.51295076097761, 50.20552907671247, 58.072800636291504, 20.270902122770035, 0.3410147912800312, 0.08334062940308026, 0.07992214962307896, 0.038077563380024264, 0.08366064008857522, 0.02948125751156892, 0.02300946514255234, 0.09567558180008616, 0.03291583553488765, 0.03144607440169368, 0.042808184001062594, 0.0470940690221531, 0.013382924288245184, 0.0987017529883555, 0.03517441737598606, 0.04398064162316067, 0.07332445508135216, 0.01461544752653156, 0.04021080283980284, 0.06078134171132531, 0.004642376293694335, 0.07144820397453648, 0.04334237087251885, 0.05534572320591126, 0.042092383839190006, 0.06939576446477856, 0.028456152250458087, 0.07438804515238319, 0.07150570303201675, 0.047172273575727425, 0.16142778284847736, 0.08653331308492593, 0.019206006645358036, 0.011305660574830003, 0.6400363530431474, 57.28304753984724, 82.53086267198834, 68.94909381866455, 58.433266230991904, 69.08516733986991, 53.62933036259243, 36.468064989362446, 37.26785128457205, 38.79774039132254, 35.03407144546509, 0.8384912354605538, 0.14272777842623846, 0.2900231017598084, 2.7035290896892548, 1.3470536661999566, 3.645382813044957, 2.349065435784204, 0.5703283335481371, 9.830069048064095, 67.97328880855015, 68.76543208530971, 73.28362328665597, 71.80573449816022, 69.2803144454956, 67.3768971306937, 67.12043912070138, 62.02361583709717, 62.872984477451865, 62.97421973092215, 64.65074362073625, 66.53831904275077, 65.39989839281354, 60.28058379037039, 66.66837542397636, 60.456831795828684, 48.79763991492135, 46.117455686841694, 46.15095295224871, 52.09272929600307, 65.18409429277692, 59.0418450491769, 62.12292643955776, 58.52940150669643, 60.411307198660715, 56.27701439176287, 47.73781033924648, 42.95565012523106, 44.85380070550101, 43.681733403887065, 44.66854088647025, 49.60395404270717, 57.23041146142142, 58.032848494393484, 59.01204422542027, 56.21785395486014, 54.08130373273577, 52.223470074789866, 57.54741259983608, 52.47205924987793, 58.13764122554234, 54.574021339416504, 54.19561202185494, 51.689226559230256, 54.509587219783235, 56.041390555245535, 56.598778520311626, 54.24844264984131, 58.04102652413504, 55.175519943237305, 61.97433921269008, 40.7354679107666, 35.10066645486014, 61.28240980420794, 53.28447042192732, 52.36090196881975, 43.01895516259329, 44.90132638386318, 48.563346658434185, 54.62299919128418, 57.3028290612357, 55.603362219674246, 52.8530706678118, 44.98840815680367, 42.34149537767683, 40.87781912939889, 45.74886417388916, 52.6380968775068, 58.754349436078755, 50.268267835889546, 56.03787824085781, 58.45174843924386, 51.779469762529644, 45.04275696618216, 42.18236773354666, 44.616933141435894, 42.31394229616438, 43.99150494166783, 53.58243349620274, 59.02079200744629, 57.7320887701852, 59.23662390027727, 56.94376352855137, 48.900205748421804, 43.41449178968157, 45.361245019095286, 44.07933364595686, 47.72700241633824, 49.16713816779, 53.95307125364031, 57.635484491075786, 61.3510719026838, 57.240486349378315, 61.87661279950823, 59.39671039581299, 58.882599285670686, 59.79048565455845, 60.347043309892925, 61.07190023149763, 64.34490476335797, 63.282810074942454, 64.63327584947858, 4.289042217390878, 1.4250341675111224, 1.4757869584219796, 3.1974967207227434, 1.5066625816481454, 0.884504106427942, 0.05231766908296517, 0.5481442553656442, 19.591300555637904, 43.20215136664254, 29.364292757851736, 52.92626299176897, 64.90216418675014, 25.725069522857666, 29.795094966888428, 40.88591725485665, 56.59570394243513, 56.17773158209664, 67.4654449735369, 28.141479287828716, 0.18708908158753598, 0.017854855129761354, 0.05744050669350794, 0.08674310254199163, 0.10125480884952204, 0.06368987528341157, 0.008113629134771014, 0.03130088826375348, 0.04440121119841933, 0.019812756051708545, 0.03611497547743576, 0.06907352139907223, 0.011259338685444422, 0.06491062763546195, 0.1030149015464953, 0.053048814314284494, 0.04177634597622922, 0.013710073162136334, 0.11801379599741527, 0.14585537702909537, 0.18846656195819378, 0.1456615195742675, 0.1241037156432867, 0.160338164174131, 0.13441548017518862, 0.231846350644316, 0.13882369148944104, 0.23579102754592896, 0.15450809629900114, 0.1158862223050424, 0.23789994152528898, 0.15307585815233843, 0.14066459770713532, 0.10079009378595011, 1.0242910598005568, 69.87614331926618, 90.72173268454415, 78.89363356998989, 68.85644653865269, 79.8425212587629, 48.70031302315848, 41.16671133041382, 61.22772748129708, 53.45864091600691, 42.307001045772004, 1.4576578055109297, 0.521259069442749, 0.6074863768049649, 4.548270387308938, 3.6650496891566684, 3.205582469701767, 5.554125922066825, 4.072090361799512, 10.993729029382978, 70.81223937443325, 70.0596730368478, 75.46528121403286, 73.09388187953404, 71.66706235068185, 67.01791845049176, 69.6972827911377, 64.35429177965436, 63.35454327719552, 63.75418281555176, 64.42262731279645, 67.7421291896275, 69.14899349212646, 63.574571881975444, 69.75221524919782, 62.70498398372105, 50.23588923045567, 48.77642706462315, 48.92953756877354, 53.565604959215435, 69.24501759665353, 61.00913715362549, 63.83931214468819, 60.38740539550781, 63.446217809404644, 57.37066084997994, 50.20286444255284, 45.6288548878261, 47.114793164389475, 43.86720166887556, 46.53730058670044, 52.536590644291465, 59.14197553907122, 60.36620644160679, 60.3585147857666, 58.5198129926409, 56.22122035707746, 55.79457317079817, 61.81863703046526, 54.67903988701956, 60.279291425432476, 58.31308323996407, 56.26263509477888, 56.4274776322501, 57.02199329648699, 58.27197422300066, 57.83789941242763, 57.99227796282087, 58.858475140162874, 57.728086607796804, 62.64350632258824, 42.37777887071882, 39.17219270978655, 63.24783979143415, 56.16034024102347, 54.483434200286865, 45.46676731109619, 47.98323808397566, 50.4071866444179, 57.041788714272634, 60.10000010899135, 58.18984304155622, 55.84385674340384, 47.68037305559431, 45.08566209248134, 42.179616246904644, 49.3854957308088, 55.850419316973, 61.70990467071533, 53.77940797805786, 56.77759735924857, 61.060699735369, 55.89290755135672, 47.87643384933472, 44.56211532865252, 46.60372883932931, 46.32379634039742, 46.40702881131853, 57.1875376020159, 63.386921882629395, 59.562244279044016, 63.46351882389614, 57.70121792384556, 51.54809822354998, 46.762008803231375, 48.40020642961775, 47.881707532065256, 51.094175883701865, 53.29496220179966, 58.27865144184658, 60.115744726998464, 62.81955977848598, 58.474086897713796, 63.74637304033552, 61.91251414162772, 61.07309532165527, 62.66024453299386, 63.5843688419887, 61.60258974347796, 69.30680097852434, 64.37550462995256, 67.5005750656128, 4.3528909512928555, 5.680343423570905, 8.06314127785819, 7.017225035599299, 3.083728436912809, 0.728543972330434, 0.3465945747281824, 2.4627648890018463, 26.904180560793193, 52.08899116516113, 50.11355229786464, 54.44672686713082, 83.52905477796281, 33.33072056089129, 32.05936697551182, 47.25097785677229, 64.34249373844692, 65.08039937700543, 75.13828509194511, 31.184609617505753, 0.44840937852859497, 0.2114637286535331, 0.1577811185270548, 0.1492977887392044, 0.24962103686162404, 0.18918601263846668, 0.07441422303340264, 0.17876014565782888, 0.1650937039937292, 0.1247436555900744, 0.07790322974324226, 0.1913212537765503, 0.05891482758202723, 0.15455906784960202, 0.20905540431184427, 0.1481006901179041, 0.17836711103362696, 0.12453843945903437], [0.05475178114803774, 0.03295815237132566, 0.06456015072762966, 0.021224317540015494, 0.032437359781137536, 0.040107241432581625, 0.08928569539317063, 0.02665691147558391, 0.06412388663738966, 0.019738595566845367, 0.0591813222106014, 0.05112656871122973, 0.09718912879803351, 0.03864957857877016, 0.135831514905606, 0.3533604916717325, 11.734197684696742, 76.0553639275687, 63.2570253099714, 63.396545137677876, 65.94936193738664, 42.20475482940674, 14.396404317447118, 27.59681521143232, 34.6208620752607, 38.449600900922505, 10.788665975843157, 0.047084779877747805, 0.11165409761347941, 0.7679206079670361, 0.4837426511304719, 0.3249568800841059, 3.8233804617609297, 2.36832714506558, 0.08538587644164052, 27.404666253498622, 65.5125981739589, 62.7439147404262, 66.46245166233608, 63.070077078683035, 69.43216037750244, 68.6295531136649, 57.36063459941319, 64.19582421439034, 58.22762039729527, 61.27790042332241, 56.953567436763215, 56.98468494415283, 53.84245245797293, 63.52859565189907, 59.28727626800537, 55.898486954825266, 42.95872817720686, 45.82688896996634, 42.81152711595808, 48.674080099378315, 54.74091706957136, 56.525099822453086, 61.616326332092285, 58.572827747889924, 56.43127482278006, 52.702256543295725, 43.14293187005179, 43.6578802381243, 41.872255734034944, 40.52003901345389, 42.790369851248606, 46.825782843998496, 52.53055265971592, 54.696156774248394, 55.2576858656747, 50.56562989098685, 49.141127586364746, 49.3620559828622, 56.16736486979893, 50.372900758470806, 52.427368436540874, 52.41619920730591, 52.97852039337158, 53.13419130870274, 54.97847250529698, 53.28703083310808, 54.34665891102382, 51.96683488573347, 55.03752177102225, 54.60346780504499, 53.62316036224365, 34.291312490190776, 33.31736612319946, 56.5326247215271, 50.014731543404714, 50.40771818161011, 43.20153645106724, 47.380846636635916, 47.53317199434553, 55.05290160860334, 54.72962972096035, 53.22609165736607, 51.27311979021345, 43.33462224687849, 38.42813096727644, 39.43058579308646, 40.57563502447945, 48.489539418901714, 55.367842606135774, 51.23838227135794, 48.63038982663836, 58.42219080243792, 49.57150942938668, 44.880252497536794, 40.60813522338867, 42.29049907411848, 40.796320234026226, 42.42160810743059, 49.03675869532994, 56.89323970249721, 53.68651056289673, 55.61193282263619, 53.774530342647004, 48.24934366771153, 40.75772646495274, 41.325356074741904, 40.5514691897801, 43.796333517347065, 46.70530455453055, 51.3143504006522, 52.02764204570225, 58.09869657244001, 57.324392795562744, 56.76762669427054, 54.34016581944057, 55.768795354025706, 55.63485145568848, 55.79909644808088, 55.27978808539254, 60.22094740186419, 56.99380098070417, 68.04525824955532, 32.53812565122332, 0.1159503845764058, 0.40378905140927857, 3.222949057817459, 1.4662427391324724, 0.33393452263304163, 0.08846736180463008, 0.11001502842243228, 9.709273747035436, 27.695406675338745, 52.27606793812343, 75.2886996950422, 76.81910991668701, 64.08112335205078, 21.227135794503347, 32.93970373698643, 38.408714226314, 53.64888954162598, 53.883693490709575, 52.728496415274485, 2.62558137519019, 0.0516413189470768, 0.003942212123157722, 0.023968559124373963, 0.034341359577540836, 0.03823101068181651, 0.025310575862282088, 0.0751215075807912, 0.035260706674307585, 0.03617124977920737, 0.02775475399435631, 0.10755404297794614, 0.05424901384062, 0.01359367132785597, 0.051596467782344134, 0.033142761393849335, 0.02290685029168214, 0.007804604779396738, 0.013512794194476945, 0.021935043956286142, 0.044195659192545075, 0.07399351096579007, 0.07767316565981933, 0.02249986498749682, 0.04079243287976299, 0.032202277931251695, 0.0623111328376191, 0.0642847672903112, 0.05299151881730982, 0.05357056024617382, 0.007799183284597737, 0.08487738229866539, 0.19162506104579993, 0.16841203879032815, 15.865113667079381, 88.03612886156354, 68.11490004403251, 72.21386473519462, 73.44170175279889, 51.55432728358677, 21.49236590521676, 27.941310371671403, 27.602882725851877, 42.38647106715611, 13.171257989747183, 0.044246763057474575, 0.12279406163309302, 1.9481040026460374, 2.371859435524259, 1.8709119047437395, 5.228691407612391, 1.0671628564596176, 0.39340100597058025, 31.195011070796422, 69.15079307556152, 66.45148045676095, 69.19658170427594, 65.81732531956264, 69.68717316218785, 67.85805988311768, 60.12133802686419, 65.38960116250175, 60.27516419546944, 62.04769829341343, 60.78887231009347, 60.32610838753836, 58.16285623822893, 64.2960102898734, 61.484525953020366, 57.17968961170742, 45.71005501065935, 48.77706977299282, 45.09827307292393, 52.037987913404194, 58.20712668555123, 58.95766067504883, 62.61272580283028, 58.34413473946707, 59.55360071999686, 53.82351861681257, 45.43078259059361, 44.21169682911464, 45.33259759630476, 42.135873862675254, 43.57909114020211, 48.35338946751186, 55.18540375573294, 56.538304873875205, 57.32314211981637, 51.95202827453613, 50.085564953940256, 52.918581758226665, 56.806460176195415, 53.677794047764365, 54.59010641915457, 54.93008525030953, 55.948375020708355, 55.507824489048545, 57.07057510103498, 55.47110325949532, 57.149169649396626, 54.00581850324358, 58.043336800166536, 55.99763427461897, 54.449784074510845, 35.65165165492466, 36.33423573630196, 59.49396433149065, 52.20597798483712, 51.54156691687447, 47.19235590526036, 49.27258750370571, 48.94601174763271, 57.284492765154155, 56.69012301308768, 55.66017416545323, 53.060151304517476, 46.32300424575806, 41.25936555862427, 41.6030547278268, 43.46753781182425, 50.96606499808175, 57.05536896841866, 53.37788895198277, 51.81104237692696, 60.13518578665597, 52.83115604945591, 47.52299983160836, 42.020231519426616, 44.91783530371529, 42.578647817884175, 44.659914697919575, 50.192942414964946, 58.715793882097515, 56.73401130948748, 58.197381837027415, 57.26683391843523, 51.172211102076936, 43.1167927469526, 43.722825050354004, 43.01030118124825, 45.915930134909495, 49.4085568019322, 55.5449070249285, 55.283491475241526, 59.66433416094099, 59.5114529473441, 59.6728526524135, 57.3561669077192, 57.87722621645246, 58.378549167088096, 60.00937475476946, 57.902396065848215, 62.28181784493582, 59.01782512664795, 71.17578996930803, 37.5358259337289, 0.11082691592829567, 0.11451734575842108, 2.776244593518121, 3.7742501837866644, 1.0531092562845774, 0.32157983843769344, 0.06951866072735616, 5.408562030111041, 34.007051263536724, 48.10375458853585, 72.71058450426374, 75.37876919337681, 53.22162396567208, 24.677387135369436, 45.32208844593593, 43.05443613869803, 58.855140004839214, 57.990645136152, 63.79871382032122, 4.791989309447152, 0.13084163623196737, 0.02966871977384601, 0.04406459676101804, 0.0029509922647516108, 0.025172383724046603, 0.0971852679337774, 0.023784313118085265, 0.024675443336101513, 0.026523078924843242, 0.08419820945709944, 0.09010820875742606, 0.022101157810539007, 0.023134778686133877, 0.03714305441826582, 0.07537321014595882, 0.06510075314768723, 0.03118571712236319, 0.08093195222318172, 0.12905366931642803, 0.12252124984349523, 0.09758060957704272, 0.21047156117856503, 0.13182403280266694, 0.16882396382944925, 0.14601452063236917, 0.2320246153644153, 0.10226735951645033, 0.1527313252112695, 0.15368709606783731, 0.16479992547205516, 0.22229662165045738, 0.2777594769639628, 0.5317008548549244, 19.446350710732595, 98.98202909742082, 75.98052488054547, 83.28684057508195, 83.85725988660539, 57.11082254137312, 21.915340968540736, 36.6684684072222, 48.892847606113975, 55.64447818483625, 16.522560903004237, 0.20983396896294185, 0.19541492339755806, 2.8246092668601444, 3.523360937833786, 1.4070544008697783, 9.838402543749128, 8.295760018484932, 0.44555242040327614, 35.063594341278076, 70.95890195029122, 70.35590948377336, 70.95193985530308, 70.87475231715611, 69.22542367662702, 68.99652917044503, 62.13953958238874, 67.65540872301374, 62.503437587193076, 64.41517189570835, 63.55132320949009, 65.91870648520333, 62.60130296434675, 66.05153519766671, 63.22411169324602, 61.03315012795584, 47.31316076006208, 51.28122138977051, 47.70787749971662, 54.22429071153913, 60.73664270128523, 60.80333151136126, 62.018620082310264, 60.25632068089077, 60.20035294124058, 58.69437953404018, 46.76514591489519, 46.01757533209664, 46.9707396371024, 43.91709668295724, 46.45832388741629, 51.64551196779524, 56.79182032176426, 59.296413149152485, 60.5282175881522, 55.51763881955828, 51.5662955556597, 55.688460281917024, 60.581531115940635, 54.933906759534565, 55.73464495795113, 57.94447783061436, 58.43678896767752, 56.43233094896589, 59.072444915771484, 56.680996554238455, 59.215195655822754, 55.498496532440186, 60.03866836002895, 58.66586412702288, 55.34461825234549, 38.860496520996094, 39.5514531816755, 60.11441762106759, 55.94789212090628, 54.87849834987095, 48.45998873029436, 52.34281233378819, 52.4826899937221, 60.16655690329415, 58.513524872916086, 58.02841206959316, 56.73137446812221, 47.752752440316335, 43.38251270566668, 42.97088752474104, 46.43157679694039, 54.06817511149815, 60.35452651977539, 55.147265093667166, 54.14685998644148, 60.137166023254395, 54.97303901399885, 48.52381140845162, 44.374413217817036, 47.47371973310198, 46.027552945273264, 47.85881321770804, 54.568594796316965, 61.164054189409526, 59.7686196735927, 59.09679140363421, 60.12194946834019, 52.936195441654746, 46.18572521209717, 44.0331072807312, 45.27199540819441, 49.299313749585835, 52.569941997528076, 57.32277386529105, 56.386851515088765, 61.83370072501046, 62.79675579071045, 61.30814593178885, 60.63699858529227, 60.21519429343087, 61.54519067491804, 60.957734380449565, 61.84406048910958, 65.2821125302996, 62.04678807939802, 72.36255618504116, 39.51116752624512, 0.44080367950456484, 5.217364106859479, 7.206380188465118, 5.141736439296177, 1.5143578201532364, 0.4374382272362709, 0.3211462545607771, 12.985608203070504, 43.85543489456177, 67.34235763549805, 78.70434379577637, 80.75832162584577, 73.63013689858573, 33.02638946260725, 47.19629553386143, 50.92051260811942, 69.00382477896554, 66.18549646650041, 73.18972533089774, 6.238973379135132, 0.3169990213853972, 0.0994296446442604, 0.15650286711752415, 0.14324731911931718, 0.164795189297625, 0.1673857681453228, 0.17590789656553948, 0.1494131125509739, 0.14469443075358868, 0.18283476201551302, 0.17300205677747726, 0.12698054127395153, 0.08107503490256411, 0.1442283857613802, 0.10831419897398778, 0.12676988329206193, 0.0671262141051037], [0.025154626462608576, 0.03711477307868855, 0.05174559620874269, 0.01570894063583442, 0.05574284939627562, 0.05423227438170995, 0.021661585862083093, 0.01762997335754335, 0.034032571861254315, 0.004603045859507152, 0.036812465371830125, 0.012567741646697479, 0.12924349627324513, 0.050134173927030394, 0.0683670782351068, 0.05360674651871834, 39.56772238867623, 74.75761413574219, 64.91255869184221, 47.48486116954258, 59.88194479261126, 41.05385521480015, 28.44331771986825, 54.723546573093955, 42.530670506613596, 36.85776512963431, 9.159240450177874, 0.11404357903770038, 0.1719771432025092, 0.8439314035432679, 0.19716667011380196, 1.8194762361901147, 3.90694123506546, 0.9818355036633355, 4.427406907081604, 53.039535999298096, 62.3460122517177, 69.98051915849958, 66.38959980010986, 64.9437005179269, 68.88640717097691, 52.925929478236604, 62.2311863218035, 64.4782406943185, 64.43452262878418, 62.99765600476946, 62.2347993850708, 62.18941375187465, 62.04889338357108, 60.504149028233115, 57.53995023454939, 46.43179913929531, 43.400407791137695, 44.56490503038679, 43.60380588259016, 43.114048208509175, 52.079103878566194, 55.64882428305489, 56.77411978585379, 57.816248825618196, 56.450503962380544, 52.47410202026367, 45.036698137010845, 43.088579586574006, 41.56574290139334, 42.236667905535015, 39.621039390563965, 45.558764934539795, 47.660181590488975, 48.66308804920742, 46.062804630824495, 41.98139803750174, 46.45056274959019, 51.302965777260916, 54.08790452139718, 52.291433879307334, 50.43337093080793, 52.17232438496181, 51.77007232393537, 54.20610727582659, 52.75961739676339, 50.00859975814819, 52.630592823028564, 52.072065353393555, 56.37073169435774, 51.40762301853725, 51.97880663190569, 35.14862639563424, 34.03431946890694, 54.807473863874165, 50.060384682246614, 52.52197858265468, 48.86335597719465, 52.13591929844448, 51.05296611785889, 55.54410103389195, 51.534229619162424, 54.69597612108503, 47.94845887592861, 48.753233977726524, 41.85271045139858, 38.896015712193076, 39.95347942624773, 45.78861134392874, 49.90771538870675, 53.22689764840262, 43.54625742776053, 57.1442676952907, 55.14519453048706, 45.355248723711284, 41.269103458949495, 41.106699739183696, 40.14001076562064, 42.043504510607036, 43.82176392418997, 55.35526984078543, 54.81186165128435, 53.85535178865705, 55.064772605895996, 48.63552107129778, 41.536497933524, 42.40662431716919, 40.75546135221209, 41.866922991616384, 44.718592235020225, 51.28178766795567, 52.40572827202933, 55.616344928741455, 55.105607169015066, 55.62003789629255, 53.64762496948242, 52.577307088034495, 51.10838494982038, 52.92377553667341, 53.25865091596331, 56.01481022153582, 57.73202971049717, 59.986397062029155, 60.99590083530971, 5.1869774631091525, 1.4450058958360126, 2.5748504059655324, 1.5208015143871307, 0.4662762369428362, 0.6013087768639837, 0.25551625766924446, 0.3894470195685114, 27.309911932264054, 29.46974904196603, 40.06531068256923, 48.55950777871268, 59.80226285117013, 22.90914876120431, 17.313055719648087, 28.836549282073975, 38.72519077573504, 54.86139188494001, 60.70470183236258, 32.02273607254028, 0.04836270898314459, 0.09053413875933204, 0.036377924760537486, 0.04071534790896943, 0.02855297750128167, 0.023746727367064784, 0.0667982849159411, 0.018292851180636456, 0.017999069266287342, 0.0704175296372601, 0.0036775503873026794, 0.05656218382396868, 0.0355867156093674, 0.034568207404975376, 0.018179995539997305, 0.08229939027556352, 0.05401129927486181, 0.02480910286041243, 0.002814477380265349, 0.06183858747993197, 0.03871469758450985, 0.07131206949374505, 0.006508526982673044, 0.030463440343737602, 0.04708600802613156, 0.05835740427885737, 0.024018143070861697, 0.03305739829582827, 0.038177158750061474, 0.03217311788882528, 0.07258329128048249, 0.025095923005470207, 0.062612002050238, 49.4007887159075, 85.35297775268555, 70.8370166506086, 56.28831911087036, 64.8986483982631, 52.385265827178955, 30.15529305594308, 28.325297355651855, 40.348616531917024, 45.59764705385481, 7.927285756383624, 0.15558048018387385, 0.18450640088745526, 2.93350773198264, 3.0070429061140334, 3.817259967327118, 2.2523019995008196, 0.7133633526308196, 5.981411474091666, 58.30516229357038, 65.6911460331508, 70.10305064065116, 69.38100773947579, 68.10112176622663, 68.94578647613525, 54.396637303488596, 64.26199190957206, 64.68481758662632, 66.52741037096295, 65.5282107761928, 63.80505057743618, 64.69170325142997, 64.08590371268136, 62.34243392944336, 61.04200908115932, 49.36796889986311, 45.337892123631065, 45.90703296661377, 45.08826766695295, 45.579369817461284, 54.70249700546265, 57.47264650889805, 58.917896134512766, 58.96139880589077, 60.4847149167742, 53.52918597630092, 48.249836989811485, 45.89491530827114, 43.404350893838064, 41.95886155537197, 42.20695740836007, 46.502462318965364, 50.71437692642212, 50.21661145346505, 50.0846061025347, 44.37111282348633, 49.24536446162632, 54.027267592293875, 55.92329897199358, 54.28376381737845, 51.62995842524937, 54.07622807366507, 53.55043704169137, 54.33901589257376, 55.10190725326538, 52.61457027707781, 54.49504811423165, 55.1885860306876, 58.29298210144043, 51.66911847250802, 55.167303698403494, 37.87339721407209, 36.438125201633994, 57.16800274167742, 51.61910533905029, 55.734846455710276, 50.95584419795445, 56.17271498271397, 55.194419043404714, 56.59356042316982, 52.53593403952462, 56.85826594488961, 51.15789086478097, 51.01024511882237, 44.97233697346279, 41.34171213422503, 42.95275967461722, 46.55956261498587, 52.651979378291536, 56.15383325304304, 46.95885474341256, 58.24224982942854, 56.46911471230643, 47.300264903477256, 43.13449675696236, 43.07528073447091, 42.03805364881243, 43.615927015032085, 44.9373527935573, 55.518965925489155, 58.304613385881694, 57.364199025290354, 57.9796530859811, 49.87937021255493, 43.38444777897426, 43.71885415485927, 44.1587724004473, 43.985046591077534, 47.91815083367484, 53.35633911405291, 54.56942858014788, 57.042233398982454, 57.72300400052752, 57.38696479797363, 55.6362167767116, 53.96525839396885, 52.787997313908164, 56.31454161235264, 56.09503064836775, 56.47429459435599, 59.405652727399556, 62.71116093226841, 64.36526298522949, 6.903786139828818, 0.8935467526316643, 0.6160947063139507, 2.3345508660588945, 2.037664545433862, 1.4436305867774146, 0.40024639293551445, 0.43114980895604404, 26.064878123147146, 37.015065397535054, 47.1502810886928, 52.91415922982352, 54.176219599587576, 27.1248779296875, 27.881422110966273, 35.592261927468435, 44.41182926722935, 61.52713230678013, 66.85262080601284, 40.3945198059082, 0.12952894238489016, 0.02419233149183648, 0.04022006484280739, 0.0251845362862306, 0.04148488465164389, 0.016644991568422744, 0.04339677241763898, 0.11913143816803183, 0.0405108883444752, 0.07728000211396388, 0.037842186367405314, 0.01360815720233534, 0.026714824439425553, 0.06521721011293785, 0.03655376032527004, 0.12345141278845922, 0.017871547091220106, 0.1236345629606928, 0.09290573400046144, 0.15657868662050792, 0.1179459560662508, 0.13711717591754027, 0.08024539013526269, 0.13504966614501818, 0.09928367819104876, 0.13692547620407172, 0.12494755536317825, 0.14699399950248854, 0.13024348047162804, 0.1550427276108946, 0.1682827371571745, 0.17739843444100448, 0.2009164174752576, 59.95066247667585, 93.00134631565639, 80.33368246895927, 65.52773829868862, 75.39402743748256, 54.24407570702689, 39.64773089545113, 71.17394174848283, 58.66032641274588, 52.553561619349885, 12.54814006601061, 0.32370864706380026, 1.3017534741333552, 2.5511372898306166, 4.092145034245082, 5.049290657043457, 14.172234586306981, 3.7459684099469865, 6.579130257878985, 63.21623938424246, 66.81922081538609, 74.42689377920968, 72.96599333626884, 69.79605838230678, 70.89874444689069, 59.03457028525216, 66.90157086508614, 67.04173687526158, 69.36369977678571, 67.81377206529889, 66.8547261101859, 67.02898693084717, 66.47363131386894, 65.92687061854771, 63.43267577035086, 51.83716065543038, 47.47925397327968, 49.54934120178223, 47.37512479509626, 48.29987791606358, 55.7216066632952, 60.026856422424316, 60.18886756896973, 60.250692640032085, 62.060177258082796, 57.06583642959595, 50.932334968021934, 47.734572478703086, 45.42293112618582, 45.971925667354036, 43.60042905807495, 50.04318789073399, 53.03113562720162, 52.651326247623985, 51.342101505824495, 45.70363140106201, 52.805194105420796, 57.44974872044155, 59.101856640407014, 57.063519205365864, 52.127324376787456, 56.426939146859304, 55.57296732493809, 56.508326871054514, 56.3015901701791, 53.361334868839805, 55.66396788188389, 57.4008994102478, 60.866810253688264, 54.79387623923165, 55.84032358442034, 38.923207487378804, 39.81544998713902, 57.98121990476336, 56.18100070953369, 57.67701734815325, 52.95457342692784, 57.817826066698345, 57.12437847682408, 59.23890290941511, 54.41606446674892, 57.33149038042341, 53.39276157106672, 53.41307462964739, 46.09184462683541, 41.74582631247384, 45.89069427762713, 49.92464467457363, 54.61019713538033, 56.4497709274292, 48.99448932920183, 59.93665490831648, 59.695149421691895, 48.46546738488333, 45.61119604110718, 45.6429249899728, 44.22254296711513, 47.07214164733887, 48.06418807165963, 60.129078320094514, 60.91938032422747, 58.97423907688686, 62.021510532924104, 54.11395331791469, 46.291532380240305, 47.00973640169416, 46.28317717143467, 45.828368936266216, 51.15964528492519, 57.06466565813337, 57.08376625605992, 59.970464842660085, 60.59810951777867, 60.03945350646973, 58.31653649466378, 56.98274292264666, 55.61121020998274, 60.072019713265554, 59.208129337855745, 60.88045651572091, 63.32775797162737, 65.23920045580182, 65.88296495165143, 7.667923399380275, 3.198768892458507, 9.608167035239083, 6.521560524191175, 3.9795538187026978, 1.6490570093904222, 0.6778430757778031, 0.9492930727345603, 35.96274682453701, 44.12891251700265, 50.9505045073373, 55.10883808135986, 68.21347413744245, 31.167183535439626, 25.077285494123185, 41.39648130961827, 53.013938835689, 68.05053888048444, 73.88113362448556, 47.31160436357771, 0.2602310175342219, 0.10824888319309268, 0.06917909466262374, 0.16215737084192888, 0.11851737754685537, 0.1273567753710917, 0.09690921953214066, 0.12679448697183812, 0.09621337508516652, 0.1896081157028675, 0.1283502456332956, 0.18913117343825953, 0.10580725635268859, 0.2115987299808434, 0.12967665945844992, 0.18961211905947753, 0.11192220715539795], [0.024498645947980027, 0.021707999353696193, 0.050081027671694756, 0.06520520682845797, 0.06307051530373947, 0.029289978489811932, 0.0716658237257174, 0.10258211834090096, 0.008184770986969982, 0.04187858424016407, 0.06225451587566307, 0.025793526554480195, 0.06001315186066287, 0.032670266926288605, 0.029228934086859226, 1.3502181363957269, 68.51032897404262, 65.42655168260846, 60.60338320050921, 51.48493562425886, 56.92872762680054, 16.165420021329606, 27.155111278806412, 58.63125514984131, 31.927729879106792, 36.843055793217246, 0.9631471293313163, 0.04115442791953683, 0.1927132819380079, 1.378144575016839, 1.6266830499683107, 3.75044869525092, 2.2953276336193085, 0.3492319860628673, 17.230789048331125, 65.67736080714634, 63.921842847551616, 70.08030918666294, 62.64489596230643, 69.45581204550606, 48.74763025556292, 58.10379307610648, 67.27111080714634, 64.70146547045026, 61.43474211011614, 59.282391684395925, 60.352532386779785, 58.620353426252095, 59.62434032985142, 54.53543104444231, 46.599473067692344, 42.639573097229004, 44.76852199009487, 41.093758719308035, 46.14436605998448, 45.35117013113839, 49.249922479902, 56.538099902016775, 58.490165029253276, 59.21075575692313, 57.90783303124564, 52.55411400113787, 47.513136863708496, 46.23445987701416, 44.434282370976035, 40.662848813193186, 40.35559599740164, 40.53408827100481, 41.772924286978586, 42.73977654320853, 42.93945734841483, 44.2595351764134, 47.910278524671284, 50.50160224097115, 54.150452205113, 56.0915322303772, 50.68566002164568, 51.13602488381522, 55.117644923073904, 51.381136485508506, 53.01602329526629, 50.513945715767996, 53.415284156799316, 54.41678013120379, 54.553406034197124, 50.41211291721889, 56.57943820953369, 39.85627065386091, 34.31933804920742, 55.13537325177874, 50.885712555476594, 51.57781219482422, 48.83552496773856, 53.90122379575457, 48.97748361315046, 50.139903341020855, 42.82699728012085, 49.38559995378767, 54.11145544052124, 51.15412841524397, 47.03412110464913, 44.55914149965559, 40.52448238645281, 44.96858842032296, 48.38011571339199, 55.707335063389365, 49.59313222340175, 50.24534225463867, 58.57339055197579, 46.55673817225865, 41.88763904571533, 40.26973710741316, 40.14323820386614, 43.26370198386056, 41.83620153154646, 47.852799551827566, 54.67299495424543, 54.132577964237754, 53.9027350289481, 47.19988775253296, 41.81670141220093, 40.59575005940029, 40.221593039376394, 41.92802197592599, 43.648531436920166, 48.853875160217285, 48.246140548161094, 53.03391490663801, 52.54054764338902, 50.40762785502842, 50.21943242209298, 50.92235388074602, 50.54746035167149, 51.36570453643799, 54.14213868549892, 52.17408575330462, 55.93771995816912, 59.031971658979145, 65.69714232853481, 40.62883390699114, 0.180314872946058, 1.304421256695475, 3.8482775943619862, 1.144224675638335, 0.826386279293469, 0.1799993541623865, 0.039521438402256796, 6.7761208074433465, 40.264348779405864, 22.52639855657305, 46.78597314017159, 52.087604999542236, 54.3608957699367, 22.631792306900024, 28.367295742034912, 37.236424582345144, 47.410275731767925, 52.06063209261213, 50.788618428366526, 6.869877627917698, 0.11038382577576808, 0.05671346999172654, 0.02510575667422797, 0.030236962317888225, 0.04793846853343504, 0.03126612352207303, 0.057797117557908805, 0.03551925226513829, 0.02735547175897019, 0.031034865217017274, 0.031099264975637197, 0.03410964665402259, 0.011066007095256021, 0.04078230235193457, 0.021900903466822844, 0.02529118672412421, 0.01289237994101963, 0.028893337451985905, 0.029755724926612208, 0.0776550080627203, 0.04684643427442227, 0.030017602124384472, 0.05764011133994375, 0.03165095805057457, 0.02349887039911534, 0.011197287506157798, 0.048523396253585815, 0.03420257541750159, 0.03755669275830899, 0.04288645640813878, 0.05336286746231573, 3.2156200110912323, 82.51004586900983, 71.97164358411516, 67.79900019509452, 59.473884037562776, 72.82170704432896, 21.1183009488242, 32.48863015856062, 52.50031757354736, 35.9015714100429, 42.88470206941877, 0.40798478626779144, 0.08879663449312959, 0.5561300697071212, 3.3910292387008667, 6.127853010381971, 8.910215275628225, 2.149375293936048, 0.35075958552105085, 20.349845818110875, 67.72185434613908, 68.0237396785191, 71.94466372898647, 66.0247915812901, 69.41142000470842, 50.23718506949288, 59.1844151360648, 69.55314935956682, 67.08246026720319, 62.75273200443813, 61.880295344761436, 61.77070835658482, 62.63148593902588, 60.923861912318635, 57.66015754427229, 49.09301825932094, 46.26346165793282, 46.94866173607962, 43.2218599319458, 47.385064193180625, 46.457667282649446, 51.17828730174473, 58.41008704049246, 60.14111954825265, 62.54666927882603, 59.427372796194895, 54.94126490184239, 49.14278820582798, 48.75764955793108, 45.62497779301235, 44.23542840140206, 42.05305828366961, 42.3454350062779, 43.9045968736921, 44.83816378457205, 44.94626038415091, 46.4629340171814, 49.565273421151296, 52.876923833574565, 55.44524206433977, 56.603607518332346, 51.3039732660566, 53.30676024300711, 56.47444398062569, 52.677722454071045, 53.89426864896502, 52.36221865245274, 54.34463351113455, 55.9830812726702, 56.79138258525303, 53.25576046534947, 57.17652818134853, 41.19780451910836, 36.96977009092058, 55.7777098928179, 51.88553401402065, 54.94710833685738, 50.62203884124756, 55.8917749949864, 51.54152870178223, 49.311514786311555, 45.18302719933646, 50.61786992209298, 54.92375891549246, 54.40132386343819, 48.62268080030169, 48.15021371841431, 43.12144456590925, 48.788051400865825, 50.492343766348704, 57.16239554541451, 52.208263942173545, 53.77629518508911, 59.09010028839111, 49.78332873753139, 43.33168315887451, 41.75794397081648, 42.85365056991577, 43.28368500300816, 44.490347385406494, 50.12786211286272, 57.880238260541645, 55.38072804042271, 57.076029436928884, 49.94516617911202, 45.11278785978045, 42.785832677568706, 42.59750522886004, 45.11476462227957, 47.34329162325178, 51.640123639787944, 50.5863424709865, 55.37612138475691, 54.67773362568447, 53.482296058109824, 51.412264415196006, 54.94522884913853, 52.73630271639143, 53.129282406398225, 55.881293637411936, 54.73079007012503, 58.34301607949393, 60.32384327479771, 65.42372376578194, 45.50267560141427, 0.15957516511636122, 0.320804951446397, 2.176362748656954, 2.5145786915506636, 1.7527790665626526, 0.4303408595068114, 0.11185428580003125, 4.706976796899523, 44.18933057785034, 26.61896221978324, 51.624980040958945, 54.423405238560264, 48.56146022251674, 20.558689560209, 39.730560370853965, 42.63133600779942, 53.26230566842215, 57.64704629353115, 60.61817591530936, 9.43943350655692, 0.14322840156299727, 0.02602775514658008, 0.05708379404885428, 0.06000562012195587, 0.03727644761758191, 0.032836016067968946, 0.03505069330068571, 0.07693400353725467, 0.01581494476912277, 0.023633303453347514, 0.022998423681461384, 0.04275968910327979, 0.016164261382073164, 0.048109045451773066, 0.05847133709383862, 0.024825402967897908, 0.18475641390042646, 0.10905844332384211, 0.14375478188906396, 0.1361809740109103, 0.15687136591545173, 0.06869307359946625, 0.18426880506532534, 0.2587303694869791, 0.10824183321424893, 0.10907999359603439, 0.15647257731429168, 0.09951641570244517, 0.1331326011568308, 0.10452498123049736, 0.1080925894368972, 5.382322592394693, 92.89332962036133, 79.24050848824638, 78.15985516139439, 65.5760908126831, 73.93972778320312, 24.282043320792063, 40.652857303619385, 79.58905792236328, 46.08083520616804, 49.73370122909546, 1.3176759225981576, 0.2868960866970675, 0.35699665227106636, 5.619670016424997, 8.81873529297965, 10.469114848545619, 7.627067123140607, 1.2456760832241602, 23.753156866346085, 73.53786482129777, 70.38615499223981, 75.73092474256242, 68.3926751273019, 71.77711486816406, 55.583955901009695, 61.909005301339285, 70.60368919372559, 68.97108486720494, 65.45922906058175, 63.70815099988665, 64.84377152579171, 64.99464470999581, 62.72214603424072, 59.64096736907959, 50.807833671569824, 48.17952816826956, 49.47497115816389, 44.847717557634624, 50.176433495112825, 49.413722787584575, 52.858024733407156, 61.65297113146101, 62.642630849565776, 62.873456954956055, 63.79353046417236, 57.495426177978516, 53.025677817208425, 50.485141958509175, 47.59980174473354, 46.87457309450422, 44.95289938790457, 45.212560517447336, 45.302494525909424, 46.63872691563198, 46.270104135785786, 50.1796053477696, 53.05601017815726, 54.61949382509504, 57.97019311359951, 58.588231904166086, 52.00968790054321, 56.30651296888079, 57.86900997161865, 54.4961633001055, 56.40559775488717, 54.803975445883616, 56.913042068481445, 59.80625111716134, 60.28974846431187, 54.696125507354736, 59.39096423557827, 43.413605894361226, 40.50522892815726, 57.36746120452881, 56.88018751144409, 54.831542423793245, 53.2145402772086, 57.88806888035366, 53.37732267379761, 51.530053751809255, 47.15766702379499, 52.99281283787319, 59.029081208365305, 56.90451315471104, 51.85703597749983, 50.69600936344692, 46.18205656324114, 50.889339515141074, 52.84450701304844, 60.14261341094971, 54.36852836608887, 55.809553486960276, 62.210439000810894, 51.70050001144409, 45.633068970271516, 44.28942632675171, 45.19987310682024, 47.378025668007986, 46.886871406010215, 53.64466156278338, 59.48039449964251, 58.67808600834438, 60.10122299194336, 52.93405887058803, 47.620625495910645, 45.767193521772114, 44.2089592388698, 46.2305862562997, 49.16077709197998, 54.16470643452236, 53.93780606133597, 60.3897955758231, 58.59763976505825, 56.717217513493125, 54.22215414047241, 58.13069997514997, 55.56939595086234, 56.11511441639492, 60.64291845049177, 57.89195639746529, 60.71604824066162, 63.80603722163609, 67.24914755140031, 47.19264078140259, 0.2663200008017676, 6.385810528482709, 12.061820013182503, 4.6973583187375745, 2.6421206934111456, 0.9096331894397736, 0.1263352409005165, 8.451660224369594, 53.66767399651663, 35.62425490788051, 56.13710199083601, 57.94955696378435, 62.893599782671245, 33.41162885938372, 42.27136026109968, 49.0987366267613, 61.13075147356306, 64.94440228598458, 68.37521430424282, 11.597538777760096, 0.3227174702499594, 0.105164045867111, 0.11203059633927685, 0.08963658620736428, 0.16392981287624153, 0.15091887675225735, 0.14631807005831174, 0.20049865703497613, 0.06525846504207168, 0.14898847176560334, 0.11270072430904422, 0.1038759353437594, 0.07156677118369512, 0.07880735729954072, 0.14708226333771432, 0.0844317204984171], [0.03811143924083028, 0.03507042170635291, 0.051366441018347225, 0.05347943977851953, 0.02318032195658556, 0.022416118499157683, 0.03247512025492532, 0.04928678207631622, 0.03647031069600156, 0.028692755715123246, 0.07359103113412857, 0.030503283920032636, 0.019802177690767815, 0.07799893032227244, 0.10937220470181533, 11.09258713041033, 80.6816690989903, 59.00349794115339, 60.88790498461042, 35.74846090589251, 14.054998500006539, 46.480134282793315, 34.25174249921526, 25.606229271207535, 53.91599914005825, 25.555695022855485, 0.24033121392130852, 0.00979863599474941, 0.36167973812137333, 3.427587402718408, 3.3204298956053595, 5.891298983778272, 0.7031410325850759, 0.8332946343081338, 38.61349500928606, 63.77039991106306, 66.14597511291504, 63.49753720419747, 67.57266957419259, 62.832004002162385, 56.81696237836565, 61.97029536111014, 60.09160668509347, 61.95974104745047, 63.76958697182791, 59.507019996643066, 57.18090902056013, 56.04381200245449, 56.23412316186087, 46.919732911246165, 46.886075837271555, 43.26530006953648, 44.0932891028268, 42.67196559906006, 43.60535533087594, 43.34836230959211, 48.80023506709507, 54.57758576529366, 55.893220220293315, 57.22660732269287, 56.30414710726057, 53.88848427363804, 47.82997819355556, 48.05264016560146, 44.02771200452532, 42.799562317984446, 42.26843854359218, 40.91884476797921, 40.798474175589426, 42.39979076385498, 42.50366633278983, 41.4922205380031, 46.84022467476981, 49.40845605305263, 54.64509793690273, 54.78920010157994, 45.71697541645595, 52.36892713819231, 55.53639895575387, 53.592515332358225, 52.49570049558367, 50.31511606488909, 52.39499677930559, 53.85906907490322, 54.626535824366975, 49.583015646253315, 58.52296052660261, 41.53396184103829, 34.14729717799595, 51.06843280792236, 48.28653737476894, 49.637784821646555, 47.385828495025635, 49.09968158176967, 45.155439376831055, 46.955825328826904, 47.045849663870676, 48.49888474600655, 48.72262021473476, 49.89313111986433, 51.08251680646624, 50.51067311423165, 48.1074093409947, 45.4411631992885, 45.125770568847656, 51.32901457377842, 52.22604785646711, 47.61467088971819, 55.390879358564106, 49.732454027448384, 41.68791307721819, 41.01706450326102, 38.80345181056431, 42.226797989436555, 41.4577887398856, 44.85325179781233, 51.74541664123535, 53.85701240812029, 51.08104031426566, 46.46530335290091, 41.34954622813633, 40.78228834697178, 40.21982819693429, 42.34201649257115, 42.871462277003694, 46.450413363320486, 48.44903836931501, 49.29773998260498, 46.89218330383301, 48.320333412715364, 48.15978486197335, 48.476556709834504, 49.36723933901106, 52.50211368288313, 51.00397089549473, 55.71094465255737, 54.32416411808559, 58.900907788957866, 57.7747472354344, 62.591068267822266, 15.207263435636248, 0.7835326130901064, 1.008103819830077, 1.9972275495529175, 0.8158176892570087, 0.3081080956118447, 0.15720832640571253, 0.1842287579285247, 31.421279157911027, 42.21743529183524, 26.69913748332432, 52.576344762529644, 95.53188024248395, 64.84150641305106, 16.598315375191824, 32.942837374550955, 39.74929966245379, 52.28865112577166, 54.033218724387034, 30.78742626735142, 0.5211830192378589, 0.00742611285698201, 0.014781259432701128, 0.03104111791721412, 0.047527571474867206, 0.05236508171739323, 0.021035696679194058, 0.04737698759085365, 0.01868421830503004, 0.0327814686378198, 0.0361552702795182, 0.019147705220218216, 0.04521448291572077, 0.04613113962113857, 0.07953458399112735, 0.09986183752438851, 0.04437041588659797, 0.010551770849685584, 0.020395890743072544, 0.06360434594431094, 0.03241645072453788, 0.024590811359563043, 0.047645470327032466, 0.04994476766192487, 0.06447331181594304, 0.06250321931604828, 0.04650882239054356, 0.048269529161708694, 0.027145690783592205, 0.11319173938993897, 0.11121639502899987, 16.24951580592564, 90.8408317565918, 64.00581877572196, 70.02926771981376, 42.74354246684483, 24.90824624470302, 42.40240676062447, 29.28802933011736, 27.786690371377126, 59.38242489950997, 28.10564742769514, 0.3185069704694407, 0.07226949597575835, 1.0268479968820299, 1.740551974092211, 6.9414688263620645, 5.579085154192788, 0.6418638921209744, 1.2993581912347247, 43.72491645812988, 67.1275749206543, 67.06645856584821, 66.82925401415143, 69.56211253574916, 65.80153901236397, 58.21739264896938, 62.01117161342076, 62.71798406328474, 63.347039222717285, 65.95543466295514, 62.645271165030344, 59.09494318280901, 58.144797870091026, 57.2795421736581, 49.80301645823887, 49.10235316412789, 45.97237382616316, 47.3120698928833, 44.623641627175466, 44.84663016455514, 45.07180043629238, 50.04888193947928, 58.1665735244751, 58.59688935961042, 57.542031220027376, 58.01524870736258, 56.4683712550572, 51.63855334690639, 50.58264602933611, 46.67960664204189, 44.35550716945103, 43.23866762433733, 42.681804248264854, 42.108668191092356, 44.40458229609898, 43.73989677429199, 43.543165479387554, 48.83387129647391, 51.4112742968968, 55.63070338112967, 55.27656064714704, 46.35390635899135, 55.129394326891216, 56.229804856436594, 56.460280077798025, 55.09170382363455, 49.85867500305176, 54.52318137032645, 55.55798353467669, 56.50767026628767, 51.827926499503, 60.03072656903948, 43.87271853855678, 36.20759439468384, 51.57135384423392, 49.3482985496521, 52.55204691205706, 50.78641932351248, 50.224275316510884, 46.96828344890049, 47.56575557163784, 49.36156266076224, 48.42476136343819, 51.78233936854771, 54.481255940028596, 52.80209173474993, 53.85928446905953, 49.73002563204084, 47.21251262937273, 46.344303948538645, 53.89872939246041, 54.60025078909737, 50.527296679360525, 56.887257303510395, 50.63473667417254, 44.043727602277485, 42.93999930790493, 40.718569891793386, 43.27050427028111, 43.33505303519112, 46.83280052457537, 53.18240833282471, 56.37189204352242, 52.92263603210449, 49.158696106501985, 44.52999380656651, 44.08245686122349, 42.096060684749055, 43.414144379752024, 45.12706640788487, 48.60841267449515, 51.23015560422625, 50.54788071768624, 50.2447829246521, 50.44345971516201, 49.90333802359444, 50.51707935333252, 51.98812416621617, 54.44435405731201, 53.54999583108084, 57.448286124638145, 57.119420937129426, 62.43034948621477, 63.08251435416085, 64.71655000959123, 18.19724178314209, 0.5826508009007999, 0.9496575274637767, 1.920112098966326, 2.5954867729118893, 1.1863858018602644, 0.09274923668376037, 0.2743847423366138, 30.71445628574916, 44.46066468102591, 29.633622305733816, 65.10521834237235, 84.96854782104492, 62.842037200927734, 26.822285618100846, 39.28668860026768, 46.44008486611502, 58.94775949205671, 61.26389980316162, 40.14209175109863, 0.6322386828916413, 0.04159722290933132, 0.016625066387600133, 0.015999033016019633, 0.031428178040576835, 0.0343216481352491, 0.09191857411393098, 0.04506472684442997, 0.04597605365727629, 0.01598376258542495, 0.08268849618200745, 0.07426385288791996, 0.014466303833095091, 0.023264965807486857, 0.10606087917195899, 0.03529883694968053, 0.09611129627696105, 0.12170676354851041, 0.1527601493788617, 0.22845448979309627, 0.11896920044507299, 0.1389317956886121, 0.11794898233243398, 0.12701492942869663, 0.19094003923237324, 0.09803112290267434, 0.14441912195512227, 0.14091957759644302, 0.09028230048716068, 0.24373406703983033, 0.2953611638929163, 20.582174471446447, 103.13903903961182, 72.96786934988839, 78.82934883662632, 50.39401980808803, 23.522879668644496, 57.16345167160034, 45.6459196635655, 37.03065368107387, 73.80299418313163, 30.346319879804337, 0.9306605011224747, 0.10380476380565337, 1.211716654045241, 9.961815578596932, 8.521939516067505, 13.62698859827859, 5.274123506886618, 1.3603007325104304, 50.6481362751552, 71.5170646395002, 72.37076895577567, 71.17483806610107, 71.81942244938442, 67.96454102652413, 61.410888944353374, 62.93381595611572, 62.69565255301339, 64.31431184496198, 69.02900505065918, 65.28357860020229, 63.464818137032644, 60.98448494502476, 61.501958983285085, 52.641946179526194, 51.25690616880144, 47.1040095601763, 48.78597041538784, 46.967248167310444, 46.2445000239781, 46.69167913709368, 53.46907016209194, 60.484596797398154, 61.0447883605957, 58.74246106828962, 60.977543694632395, 58.837338720049175, 51.33597666876656, 52.40079852512905, 48.563468251909526, 46.550252028873985, 46.46474402291434, 44.14621353149414, 45.540817737579346, 46.96356214795794, 46.78629623140608, 45.05698340279715, 50.286479064396445, 54.40274824414934, 59.38202885219029, 57.463415827069966, 48.557131494794575, 55.107938289642334, 60.56268065316336, 58.36769608088902, 56.96759237561907, 52.699664865221294, 56.104820660182405, 60.035652841840474, 60.13388647351946, 53.155984333583284, 62.99735723223005, 45.93673651559012, 40.13095031465803, 54.79471697126116, 52.66317292622158, 54.08662257875715, 51.790833541325156, 51.617281436920166, 48.12956714630127, 50.18464626584734, 52.69666324343, 51.16580833707537, 52.73866510391235, 56.025097029549734, 55.54577554975237, 56.808853830610005, 53.50249794551304, 49.57869039263044, 48.60460158756801, 56.29362406049456, 56.592139516557964, 51.175650460379465, 59.25179876599993, 53.48595775876726, 47.27620676585606, 44.6655010495867, 43.252692563193186, 45.06773921421596, 45.536923272269114, 47.993979998997276, 56.68199362073626, 59.95353208269392, 55.26261561257498, 51.41598170144217, 47.2600348336356, 46.4594703401838, 45.36187730516706, 45.892723151615684, 46.8383903503418, 53.23525980540684, 54.32434477124895, 54.03021362849644, 52.79862458365304, 53.17552614212036, 53.36778974533081, 53.41535711288452, 55.631224496024, 57.18627997807094, 56.69544880730765, 60.22153105054583, 59.34235463823591, 63.45974595206124, 65.36128030504499, 65.93077550615583, 20.284289564405167, 1.094813647014754, 5.678024462291172, 7.095945085797991, 3.216046456779752, 1.7754319310188293, 0.4726322644523212, 0.5676041511552674, 38.676139967782156, 56.44124548775809, 39.196209158216206, 61.41752447400774, 103.85301508222307, 74.80834988185337, 26.894331489290508, 47.70403861999512, 54.855305262974326, 66.15457003457206, 70.05292633601597, 47.081966400146484, 1.0425241099936622, 0.129625104367733, 0.0810609417302268, 0.09972241893410683, 0.1390179017824786, 0.2031186707317829, 0.26145020925572937, 0.12096863958452429, 0.061462943708258014, 0.11396355261760098, 0.1392105243035725, 0.17689715991062777, 0.12254052023802485, 0.20420143620244094, 0.15673555034611905, 0.1907382429178272], [0.061242419827197275, 0.0020989244595901774, 0.042664534744939635, 0.06689189560711384, 0.03119030062641416, 0.0284625457466713, 0.08265655753867966, 0.07766727597585746, 0.02274642256088555, 0.03531642118468881, 0.017216387603964125, 0.09448631347290107, 0.05481983821040817, 0.10896931774914265, 0.04449996518503342, 37.978652000427246, 71.61692414964948, 53.900459493909565, 54.32678358895438, 47.38927132742745, 37.742326395852224, 57.193836144038606, 59.57899638584682, 40.502988134111675, 55.86103963851929, 9.582741839545113, 0.16904695757797786, 0.10544656070747546, 1.2471556152616228, 0.9344199108225959, 6.736859577042716, 9.411625078746251, 0.6641463850225721, 4.5172275730541775, 53.2322929246085, 61.90678187779018, 68.08655834197998, 59.991823605128694, 64.09921646118164, 63.383697918483186, 62.105000087193076, 61.994148526872905, 64.44994068145752, 62.959413119724815, 62.28987775530134, 59.6465676171439, 58.57565566471645, 51.38409294400896, 49.387201513562886, 45.47231197357178, 44.480057103293284, 44.95237479891096, 43.974697249276296, 41.59946945735386, 44.65267467498779, 42.661498137882774, 47.71317550114223, 56.30215297426496, 57.582070214407786, 56.305376938411165, 57.23500769478934, 53.46678767885481, 52.376535415649414, 49.94351945604597, 46.73827028274536, 40.1441901070731, 42.65065894808088, 39.85468299048287, 42.08960928235735, 40.91895941325596, 40.59270327431815, 41.42259611402239, 48.04112005233765, 49.60317931856428, 56.643042019435335, 47.69577373777117, 48.204941204616, 55.000130040305, 52.07581738063267, 51.27765001569475, 52.645076342991416, 52.30450691495623, 53.52371079581124, 50.561478342328755, 53.476087842668804, 50.074621541159495, 56.86513423919678, 44.742751121520996, 32.963855675288606, 46.872655391693115, 43.92369399751936, 47.51672560828072, 45.6822691644941, 47.684423855372835, 45.602191175733296, 51.18422801154, 50.50375270843506, 50.72094644818987, 52.00132574353899, 51.530269145965576, 49.15869958060128, 51.49706023080008, 51.90018776484898, 50.10014574868338, 48.24090160642351, 49.32313564845494, 52.27316011701311, 48.23270273208618, 49.34358072280884, 52.32503189359392, 44.06567348752703, 40.18089049203055, 39.78492655072893, 40.84302602495466, 40.39000347682408, 42.99762071881975, 47.52425398145403, 48.86687176568167, 48.37615524019514, 43.751854624067036, 40.587068285260884, 40.57782718113491, 40.65266622815813, 39.80063990184239, 42.16004317147391, 45.5241733278547, 45.155258723667686, 45.043594224112375, 44.197213309151785, 46.263645785195486, 46.934157371520996, 48.22386809757778, 51.04297113418579, 55.01497834069388, 55.281792640686035, 54.218402113233296, 56.857730933598106, 57.91096666881016, 59.12945488521031, 54.193326064518516, 49.445389202662874, 2.722459239619119, 0.926723803792681, 1.2528080833809716, 0.6452219347868646, 0.6948595941066742, 0.0654936588502356, 0.059421822162611146, 5.225135666983468, 52.899099009377615, 34.32653290884835, 37.36337859289986, 57.13861533573696, 55.96919182368687, 23.681496620178223, 25.56656721660069, 36.72652408054897, 46.007503918239046, 50.459732396262034, 47.37199463163103, 7.031307731355939, 0.11876896476106984, 0.04105276980304292, 0.03884253358202321, 0.03156025827463184, 0.04685863094138248, 0.032304645116840086, 0.02371725350219224, 0.017651376048369066, 0.011487045707846326, 0.004064486678024488, 0.03662379870989493, 0.015350952345345701, 0.02655871049501002, 0.07481708963002477, 0.020691652283338562, 0.006695302652328142, 0.015401722031778522, 0.06315952552748577, 0.035108406096696854, 0.02157179532306535, 0.019770736074341193, 0.05077800527215004, 0.06164633815309831, 0.05259859275871089, 0.07290154456027917, 0.058533653749951293, 0.11963974232120173, 0.013402202316293759, 0.09059127819325243, 0.040608926476644616, 47.475515842437744, 81.28111798422677, 63.13579314095633, 63.18643161228725, 54.90441165651594, 39.00966739654541, 68.57863671439034, 52.47071477345058, 35.61102901186262, 65.43252713339669, 9.003835303442818, 0.24997846196804727, 0.03485671031687941, 2.4888299703598022, 6.1878637330872674, 8.637959667614528, 3.6426382746015276, 0.7271068351609367, 5.741636523178645, 57.7951124055045, 65.14160605839321, 70.66809899466378, 63.17457798549107, 66.34813295091901, 65.47805173056466, 63.75527368273054, 65.22098227909633, 67.53316906520298, 64.79117366245815, 64.27188614436558, 63.419814654758994, 61.076534679957796, 53.852291107177734, 51.424826758248464, 46.464872564588276, 47.42976542881557, 46.39562681743077, 47.715614318847656, 42.147581577301025, 46.02385650362287, 45.07633760997227, 50.256389890398296, 58.30997044699532, 59.38012504577637, 57.58515868868147, 59.31291512080601, 57.15612479618618, 53.936329569135395, 51.1933718408857, 49.4943288394383, 42.5408878326416, 43.243413243974956, 42.232210636138916, 44.39120353971209, 41.14005109242031, 42.93375982557024, 42.565665108816965, 49.48538303375244, 50.92555005209786, 59.16903182438442, 48.288298743111746, 50.004260608128135, 57.431342942374094, 55.48785884039742, 52.927920137132915, 55.30642400469099, 53.508084297180176, 54.055345262799946, 54.15592738560268, 53.85101958683559, 51.74504491261074, 56.728150503976, 48.05435289655413, 34.76715987069266, 48.25480147770473, 46.875914096832275, 49.49654878888811, 47.597182273864746, 47.294588225228445, 47.954733099256245, 52.97070366995675, 52.30226264681135, 53.251977171216694, 53.934092249189106, 54.7866918018886, 52.66377394539969, 54.48852028165545, 55.44138581412179, 52.83777073451451, 51.39123569216047, 52.62381485530308, 53.9338629586356, 50.65548399516514, 52.71946723120553, 54.633164405822754, 45.77185228892735, 42.68012278420584, 41.69261353356497, 42.878994124276296, 43.133075850350515, 44.22818490437099, 49.36262920924595, 51.53343057632446, 49.959514209202354, 45.50862325940813, 42.31474828720093, 44.19814089366368, 43.602148737226216, 42.09682846069336, 44.34702341897147, 47.185699531010215, 47.016340664454866, 47.295849323272705, 45.62850400379726, 49.08477422169277, 49.294255461011616, 51.31185599735805, 54.78627143587385, 56.09801489966256, 55.6646522794451, 56.04144614083426, 59.13279696873256, 61.276997157505576, 62.12625462668282, 58.813492502485005, 53.90100492749895, 5.101430807794843, 0.7176736784832818, 0.8484829078827585, 0.5426614210009575, 1.6176533230713435, 0.4161413743027619, 0.06769458896347455, 4.202619654791696, 59.041907582964214, 32.148098945617676, 41.56606599262783, 67.39508751460484, 52.274386474064414, 28.16942494256156, 34.43091222218105, 41.4207444190979, 51.78753662109375, 56.87782859802246, 58.30484962463379, 9.726118785994393, 0.10435781734330313, 0.0016911382720406565, 0.044529864830630164, 0.038410001434385777, 0.020909484076712812, 0.038905169149594646, 0.04244032981140273, 0.04720636656773942, 0.017438818168427263, 0.037450539347316535, 0.034174636738108735, 0.05067846418491431, 0.02331780332938901, 0.058648556870009215, 0.02408907881804875, 0.09675679342555148, 0.14943254579390797, 0.13383290357887745, 0.08791787057582821, 0.2055026763784034, 0.13602979640875543, 0.2501342807497297, 0.15374261380306312, 0.22465852062617028, 0.11947462760976382, 0.1565286378775324, 0.17604907256151947, 0.15332887029009207, 0.20850997072245392, 0.1618129193250622, 55.59172746113369, 89.50989736829484, 71.50264017922538, 73.32934938158307, 61.829761096409385, 49.47528730119978, 63.16937378474644, 77.07716601235526, 56.83697666440691, 70.13799313136509, 12.05627621923174, 0.3396341896482876, 0.12911608096744331, 3.8084717988967896, 8.197880744934082, 11.585468019757952, 19.58200560297285, 4.685957193374634, 6.592357890946524, 63.02526119777134, 67.222501209804, 74.74580914633614, 65.69864313943046, 68.84950528826032, 68.52875559670585, 66.0255628313337, 66.83937059129987, 68.04344476972307, 65.88069983891079, 66.36644840240479, 67.12106445857457, 63.510849952697754, 56.457688399723594, 53.88765743800572, 48.92266232626778, 48.570208004542756, 48.8328811781747, 49.60476003374372, 45.72083166667393, 47.615865979875835, 47.02038451603481, 52.36683920451573, 61.241366795131135, 61.4924955368042, 60.112916810171946, 61.35893031529018, 59.48966339656285, 55.47228445325579, 53.844880853380474, 50.98715278080532, 43.45254707336426, 47.026804651532856, 44.04652425221035, 47.31579065322876, 44.03561558042254, 45.80162879398891, 45.99773127692086, 52.5776093346732, 54.76307487487793, 61.51362500871931, 51.198843547276084, 51.76161289215088, 59.20527362823486, 58.62297984531948, 56.50860479899815, 59.459007944379536, 56.49525383540562, 57.344219480242046, 55.62240375791277, 56.761672088078086, 55.88527842930385, 60.007241657802034, 51.01731491088867, 36.86362246104649, 49.736004556928364, 48.99899523598807, 50.89003086090088, 48.7476476260594, 48.61310618264334, 49.37370811189924, 55.08730213982718, 55.31234039579119, 55.194050788879395, 56.923947266169954, 56.236089502062114, 53.06856904711042, 54.78007364273071, 56.728126185280935, 54.633859225681846, 55.52159234455654, 55.90179777145386, 56.1790725844247, 53.73493603297642, 54.7675529888698, 55.76200348990304, 49.16202081952776, 44.668283803122385, 44.81718717302595, 44.5484482220241, 44.10972159249442, 46.36759083611624, 51.823719365256174, 53.943430628095356, 53.43168190547398, 48.19361564091274, 45.30652448109218, 46.9327712059021, 47.29290328707014, 44.628932680402485, 46.19706467219761, 50.35780232293265, 50.73158066613333, 50.00263820375715, 49.25163173675537, 52.59993737084525, 52.47697510038103, 53.721692766462056, 57.49124683652605, 57.168461322784424, 59.73959009987967, 58.11971139907837, 61.31924220493862, 63.42023849487305, 63.660402979169575, 60.53696537017822, 57.224484648023335, 5.345821099621909, 2.444250979593822, 8.068731103624616, 2.8610028454235623, 2.278597674199513, 0.5557122549840382, 0.12429772237581865, 6.495998535837446, 64.55937480926514, 47.17473527363369, 44.3335473878043, 64.6551765714373, 64.75699547358921, 32.410706111363, 39.145716599055696, 46.92190769740513, 61.791601589747835, 64.46066175188336, 66.21588093893868, 11.615777799061366, 0.3610148552273001, 0.13084889655666693, 0.20701845575656208, 0.16310049380574906, 0.13724061500813278, 0.12810829361634596, 0.11416438541242055, 0.16318000453923429, 0.1562075958188091, 0.13097979953246458, 0.11635553783604077, 0.056290674821606705, 0.17692291709993566, 0.1471935295100723, 0.08810692400272403], [0.033560637185083966, 0.027991940999137502, 0.06711737957916089, 0.0878255016037396, 0.030883066755320345, 0.037402407465768714, 0.02131613011338881, 0.06229094642081431, 0.020229977056650177, 0.047035409669790945, 0.04430306110797184, 0.01480809718902622, 0.06827420036175422, 0.04393959025453244, 1.5545359956366676, 55.022631781441824, 62.60606248038155, 59.56865746634347, 50.712417534419465, 19.276109422956193, 23.063937255314418, 31.18044764654977, 34.44046252114432, 43.6614933013916, 54.22072281156267, 3.556258703981127, 0.06673730497381516, 0.33955010558877674, 1.2871162252766746, 0.25208002062780516, 9.45771334852491, 1.5762313114745277, 0.18245741512094224, 15.301432371139526, 61.40599741254534, 60.86919348580496, 63.53416115897042, 62.98532295227051, 59.16023540496826, 57.537459305354524, 62.39168276105608, 62.546141215733115, 62.294616426740376, 58.21846614565168, 61.591507366725374, 61.47259589603969, 60.638325691223145, 57.64547600064959, 53.5677102633885, 45.94838864462716, 44.99563775743757, 44.23166247776577, 42.064710412706646, 42.696840150015696, 42.62262644086565, 42.46899482182094, 46.763054507119314, 55.21301589693342, 56.8545868737357, 53.76510163715908, 54.28866924558367, 53.57965421676636, 55.017486640385215, 49.80881472996303, 45.19868496486119, 42.17832040786743, 42.529270444597515, 38.62071418762207, 41.32162836619786, 40.43344014031546, 40.61107431139265, 40.30941826956612, 47.11043316977364, 49.6295234135219, 53.243555954524446, 51.012454645974294, 54.61037431444441, 52.17124046598162, 52.254844665527344, 49.19830083847046, 50.1359498160226, 52.648685932159424, 53.098258699689595, 50.65725925990513, 50.31995895930699, 49.555719648088726, 54.316997051239014, 45.590716225760325, 33.96588666098458, 47.04769441059658, 44.3466169493539, 47.67670093263899, 45.075819969177246, 47.139170919145855, 48.345683915274485, 50.55979687826974, 49.792378766196116, 49.770432880946565, 50.097724301474436, 54.71433673586164, 49.62482295717512, 47.77708503178188, 50.10595791680472, 51.44677264349801, 51.413636684417725, 51.4793701171875, 49.831583976745605, 46.559051922389436, 48.070941720690044, 52.21195690972464, 46.64673124040876, 39.65403985977173, 38.53503942489624, 40.1668655531747, 39.60621888296944, 42.185087953295024, 45.159924439021516, 46.97606543132237, 42.81669657570975, 39.76766375132969, 40.73698956625802, 41.225996834891184, 41.04512480327061, 40.43048715591431, 41.628412178584504, 43.0842022214617, 42.866122586386545, 45.68797710963658, 47.36643607275826, 46.62283985955374, 48.641611167362754, 49.15859188352312, 53.77523558480399, 55.236959389277864, 53.615340164729524, 57.08409629549299, 57.52081489562988, 59.92028495243618, 56.7009448323931, 51.77691977364676, 49.24612876347133, 39.99957724979946, 1.638224984918322, 0.8072972978864397, 2.249806727681841, 0.16023575966911657, 0.22216882636504515, 0.058038669239197455, 0.13371953394796166, 29.7479236466544, 49.38754197529384, 29.526807648794993, 55.15589475631714, 78.01053142547607, 26.32071774346488, 16.506067616598948, 32.328887598855154, 49.30317347390311, 46.07762166431972, 57.62558330808367, 21.267787967409404, 0.16270844984267438, 0.06438071214194808, 0.025897988716938665, 0.04502874073971595, 0.07123356299208743, 0.028511878635202135, 0.01241335118122931, 0.0377660852723888, 0.05757240711578301, 0.0174495933045234, 0.05352339527702757, 0.03447687319879021, 0.029425224089728932, 0.027442130858876874, 0.02558524683783097, 0.01917085174604186, 0.061346323894602914, 0.06244891615850585, 0.010380642621644905, 0.026835427253640125, 0.03937164840421506, 0.060863010186169825, 0.01891121032115604, 0.06700795902205364, 0.02658837943870042, 0.016700239585978643, 0.06647296130125012, 0.07563803557838712, 0.09560443061803069, 2.8768241107463837, 68.60659626552037, 69.89793287004743, 68.48745550428117, 57.05789463860648, 33.23193802152361, 27.443421568189347, 27.557420662471227, 27.703530856541224, 50.68311350686209, 58.803313391549246, 3.518578405891146, 0.1320632163967405, 0.6244641914963722, 1.1935451605490275, 6.279868304729462, 11.489366616521563, 1.558179674404008, 0.28067962027021814, 17.03766734259469, 65.17114979880196, 64.97127791813442, 66.21813215528215, 64.75225680215019, 61.59298733302525, 61.50935186658587, 65.3931655883789, 63.09465980529785, 64.53591074262346, 59.563383783612935, 63.075573103768484, 64.9128088269915, 62.45288249424526, 60.11593927655901, 56.68331030436924, 49.641265869140625, 47.50322873251778, 46.972122328622, 44.42786570957729, 44.21108538763863, 44.48212766647339, 43.46401160103934, 49.22053507396153, 56.75796522412981, 60.10850470406668, 56.11585092544556, 56.41123969214303, 57.3135918208531, 54.62671995162964, 53.13556705202375, 47.47941378184727, 43.91116986955915, 42.948153018951416, 41.554281847817556, 42.749156611306326, 41.98315593174526, 43.980568477085654, 42.76321281705584, 50.57899475097656, 51.755682604653494, 56.37612349646432, 51.95975119726998, 56.55720049994332, 52.221034731183735, 53.734185627528596, 51.92362403869629, 51.73528616768973, 55.014658723558696, 54.75111355100359, 52.46512842178345, 52.50818293435233, 50.38388238634382, 55.46426623208182, 47.646076747349326, 34.64814417702811, 47.560822350638254, 45.959116663251606, 51.826130390167236, 45.564535413469585, 47.4057628767831, 50.660361630576, 53.07271712166922, 50.67402178900582, 52.42876155035836, 52.13256679262434, 56.568543434143066, 51.30458123343331, 49.05578286307198, 50.624154567718506, 53.59210886274065, 53.80405671255929, 52.46104635511126, 50.16780383246285, 49.68766246523176, 51.200764724186485, 54.07513720648629, 46.96523666381836, 40.617431913103374, 39.935198715754915, 42.37021228245327, 41.55340984889439, 43.569999422345845, 46.900566305433, 48.78591135569981, 44.58215045928955, 42.29261827468872, 42.85309818812779, 42.74259056363787, 42.64915466308594, 42.47316026687622, 43.2160199710301, 45.65730081285749, 44.23902062007359, 48.009106227329795, 49.02685751233782, 49.13372080666678, 51.03857292447771, 51.15636226109096, 55.0879031590053, 59.15683078765869, 58.03531510489327, 59.470548902239116, 60.97898197174072, 63.33633899688721, 59.664313316345215, 54.528503690447124, 54.24415561131069, 45.28115660803658, 2.883494815656117, 0.5889017911893981, 0.8683201777083533, 1.638712010213307, 0.6548098517315728, 0.05438654610354986, 0.15327812944139751, 29.792822905949183, 58.00514602661133, 22.355465923036846, 56.41134738922119, 69.99253259386334, 27.36995131628854, 27.405863080705913, 39.56127446038382, 56.527201652526855, 51.23994214194161, 64.15209225245884, 28.473149810518535, 0.24007866318736756, 0.051629861883286915, 0.02751356702564018, 0.006757274951918849, 0.017139921796375086, 0.013461158527726573, 0.04842427246538656, 0.03410855760531766, 0.01723196167897965, 0.017098448039697747, 0.033350851120693345, 0.03730327010686908, 0.04515369974875024, 0.031786858436784575, 0.0551973547387336, 0.12964556898389543, 0.09533039746539933, 0.23474714213183948, 0.12381323480180331, 0.15049073472619057, 0.13732070928173407, 0.15335768088698387, 0.21700336996998104, 0.22688639536499977, 0.10365748099450554, 0.0752519830795271, 0.11487802783293383, 0.23939445561596326, 0.2990102437990052, 3.9770576783588956, 79.3860524041312, 77.50381319863456, 75.84367316109794, 66.43502017429897, 30.88198777607509, 31.64523696899414, 40.96659973689488, 49.024418694632395, 60.77226611546108, 65.41335010528564, 4.9302767004285535, 0.23566688277891704, 1.1342877745628357, 4.049379740442548, 5.416860350540706, 20.69772301401411, 8.059387513569423, 1.1608613772051675, 20.43872891153608, 69.32055146353585, 65.78783021654401, 69.30065877096993, 69.19471958705357, 64.88342489515031, 66.38118553161621, 66.85735252925328, 67.15045533861432, 67.75547667912075, 62.10970401763916, 65.94631862640381, 66.74536146436418, 65.98040648869106, 62.7056371143886, 58.36704989842006, 52.4331945010594, 49.64841556549072, 49.15335988998413, 45.67001601627895, 46.42034503391811, 47.26458590371268, 46.50647142955235, 52.094713006700786, 58.68438802446638, 62.539248602730886, 59.08985710144043, 58.937309401375906, 60.0840539932251, 58.83981227874756, 54.56403677804129, 50.22309064865112, 46.75067629132952, 46.433529240744456, 42.556694984436035, 45.498937470572336, 44.231961250305176, 44.70497376578194, 45.17977196829659, 53.983740602220806, 55.24335868018014, 58.58470916748047, 54.59235416139875, 57.74656881604876, 55.528356415884836, 57.260038580213276, 56.00563165119716, 54.152741636548726, 58.16396100180489, 56.875626019069124, 56.55830178941999, 55.99613693782261, 55.5082448550633, 57.82955115182059, 50.669140679495676, 37.73207780293056, 49.17171703066145, 49.77988937922886, 53.39155258451189, 48.5914660181318, 50.00478172302246, 52.11192716870989, 55.30671582903181, 53.852273736681255, 54.43386227743966, 54.667148045131135, 61.05875423976353, 53.42913539069039, 51.267033168247764, 53.63768557139805, 56.53370516640799, 55.89758368900844, 54.27011060714722, 52.51756995064871, 50.80696167264666, 54.08511829376221, 56.02661173684256, 50.559247970581055, 44.364480767931255, 43.63158130645752, 44.259691510881694, 43.93917805807931, 46.454519748687744, 49.626216070992605, 51.91111728123256, 46.60873849051339, 43.963521071842735, 46.430843761989046, 44.953159945351736, 45.10929638998849, 45.430188519614084, 46.5229560307094, 49.03163092476981, 48.193963050842285, 51.35739796502249, 51.75813184465681, 50.92453214100429, 53.002498626708984, 54.827168532780235, 57.10915844781058, 60.94317790440151, 60.16640404292515, 62.47023214612688, 63.44469615391323, 64.9490784236363, 62.61624159131731, 56.90695892061506, 55.75956467219761, 44.90095812933785, 3.09172168799809, 3.4900860147816792, 8.894466314996992, 3.5467494428157806, 0.6088265648909977, 0.18044922287975038, 0.35930535410131725, 37.01622574669974, 62.81618990216936, 42.094278471810476, 59.633484159197124, 85.77806854248047, 36.3704115322658, 25.68900489807129, 43.45394018718174, 64.77972303118024, 57.98921728134155, 73.63963508605957, 33.00235564368111, 0.3889772833458015, 0.13362069853714534, 0.05863647894667728, 0.08808973671070167, 0.07947688137314149, 0.09767039333071027, 0.15011207147368363, 0.08131518201636416, 0.19646168580012663, 0.14510224387049675, 0.10875368610556636, 0.0798681110941938, 0.1428844928741455, 0.09777325245418719, 0.15244210644492082], [0.023612201014267545, 0.09891289951545851, 0.04584165622613259, 0.045206801899309666, 0.0507386638117688, 0.035406157440905056, 0.005689061936988894, 0.021652162707011615, 0.05979192230318274, 0.01498807012103498, 0.10538988267736775, 0.014347670466772147, 0.18456615268119744, 0.1483019028923341, 11.139449255807058, 73.03603117806571, 57.35094881057739, 58.10526956830706, 43.00656999860491, 20.51478041921343, 48.66454022271292, 84.45334584372384, 37.76689175197056, 58.841507639203755, 42.79976381574358, 0.09550117794424295, 0.040985991779182634, 0.4468810462525913, 1.7710377382380622, 7.895179867744446, 10.704300080026899, 0.602021184350763, 0.5150719157287053, 27.73919074875968, 60.15648896353585, 64.28425393785749, 63.056271008082796, 60.84439536503383, 58.885899680001394, 54.07624544416155, 55.85376140049526, 56.08472299575806, 57.287160873413086, 60.954878670828684, 61.3767454964774, 61.97679887499128, 60.338434491838726, 58.780940192086355, 58.98490456172398, 48.136869703020366, 44.70560952595302, 43.12142719541277, 43.677463735852925, 42.427260466984336, 42.638725417000906, 42.27663046973092, 42.78930677686419, 55.94900730678013, 56.838335037231445, 55.296679156167166, 53.5901529448373, 54.11037846973964, 54.48407343455723, 49.83201823915754, 45.623463085719514, 43.05856336866106, 40.7563750403268, 40.85154104232788, 39.228354998997276, 39.585151944841655, 39.605836732046946, 46.239035265786306, 52.62327636991228, 51.81886257444109, 55.20198563167027, 52.369615009852815, 55.382440771375386, 51.571266991751536, 49.07589094979422, 45.02970824922834, 46.52170188086373, 47.53274815423148, 49.73534100396292, 44.40931749343872, 46.73691885811942, 47.34319087437221, 55.49269131251744, 42.672306060791016, 32.423615864345, 51.29789011819022, 48.82506445475987, 52.80554846354893, 47.42134768622262, 47.477145195007324, 49.12910720280239, 50.7209221294948, 48.446853160858154, 48.57237236840384, 49.149461950574604, 50.15469952992031, 52.20107255663191, 50.79117883954729, 47.239586285182405, 54.94804981776646, 51.20870304107666, 53.90582002912249, 50.20143658774239, 47.17599637167794, 46.10243715558733, 52.86104025159563, 49.223953587668284, 42.708631243024556, 37.52584137235369, 40.11289542061942, 40.764316831316265, 40.69862856183733, 40.6824357850211, 41.8923464502607, 41.37117249625069, 39.69201176507132, 39.4123398235866, 39.501836095537456, 40.320677825382774, 40.28994246891567, 41.6194281578064, 40.47404193878174, 41.25040933064052, 46.224721976688926, 46.45922367913382, 48.24543183190482, 50.6462150982448, 52.22442545209612, 54.96806410380772, 56.195831639426096, 57.19069555827549, 57.383612292153494, 56.48892402648926, 57.965294633592876, 54.41326781681606, 57.71696254185268, 55.22320195606777, 55.05533695220947, 36.94565289361136, 0.9870881246668952, 0.6606929674744606, 1.7926008211714881, 0.11260664542870862, 0.13070428717349256, 0.06781255906181675, 8.709240368434362, 57.118194580078125, 43.709310804094585, 30.390187331608363, 28.624672651290894, 41.49065719332014, 15.178091423852102, 18.97431094305856, 37.49328211375645, 46.05017975398472, 48.31614364896502, 43.78862796510969, 1.822846221072333, 0.04711062527660813, 0.012404153639051532, 0.08519220897661788, 0.054492706299892495, 0.03952448841716562, 0.028936665305601697, 0.054385996490184746, 0.032518040987529924, 0.020187814586928914, 0.007856331200205853, 0.04706116346642375, 0.018678267552916492, 0.04798640703250255, 0.022634099570236037, 0.034724640260849676, 0.0641690974256822, 0.015218649891072085, 0.1051776979916862, 0.06735460220703057, 0.09029384915317808, 0.012580976472236216, 0.032145331879811626, 0.010212892649828323, 0.07109886700553553, 0.033188090925770145, 0.040154314799500365, 0.1758828314819506, 0.3340253649013383, 17.11689591407776, 84.58231830596924, 64.7885958807809, 62.55796010153634, 52.215246881757466, 24.90286660194397, 38.103789057050435, 68.08161122458321, 37.8881447655814, 68.42686026436942, 43.30661405835833, 0.13980713300406933, 0.0494364465453795, 0.656542178775583, 3.170226561171668, 7.806332383837018, 8.24900037901742, 1.1639787299292428, 0.4386012362582343, 32.85658243724278, 64.20878955296108, 65.46767807006836, 66.40516376495361, 62.89713641575405, 62.123093196323936, 55.07638304574149, 57.60660777773176, 59.12374346596854, 59.54947349003383, 62.36514064243862, 63.522745268685476, 64.18816729954311, 62.30837385995047, 60.509089197431294, 59.98825223105294, 50.4093336377825, 46.031068733760286, 46.11727850777762, 45.47976739065987, 44.03566769191197, 44.41810696465628, 43.35408067703247, 45.0573273386274, 57.4872898374285, 59.57102680206299, 58.41902242388044, 56.643927914755686, 57.38224002293178, 57.008003098624094, 52.350500515529085, 47.27276740755354, 44.63105535507202, 42.55151857648577, 41.828662736075266, 41.46077299118042, 40.95343637466431, 42.562868458884104, 47.88755096708025, 55.34327377591814, 53.55342476708548, 55.66717447553362, 54.643010003226145, 56.95329993111746, 54.06842524664742, 52.53369671957833, 46.18663542611258, 50.00739771979195, 49.46387141091483, 52.50838095801217, 46.886451039995464, 48.31927381243025, 49.12838806424822, 57.18501888002668, 45.00303064073835, 34.09659964697701, 52.832444940294536, 49.366283961704795, 54.902247292654856, 48.75704506465367, 48.75991814477103, 50.80798305783953, 53.39839308602469, 51.0122948374067, 49.4589729309082, 50.86552109037127, 51.24845021111624, 53.140997069222585, 52.79981967381069, 49.01077938079834, 54.59292391368321, 52.86254801068987, 55.028388363974436, 51.55287858418056, 48.279029846191406, 46.31604562486921, 54.937016078404014, 51.14891031810215, 43.72991221291678, 40.302730628422324, 42.083626883370535, 41.81200442995344, 42.40012427738735, 42.722694396972656, 44.64349610464913, 42.471996443612234, 42.20796142305647, 41.61120843887329, 41.37302071707589, 41.92695195334298, 43.17647777284895, 43.197621141161235, 43.77222326823643, 43.152628081185476, 47.991475173405235, 47.7732253074646, 51.27664252689907, 53.48370654242379, 55.64372777938843, 56.685585839407786, 57.7148711340768, 58.84725379943848, 60.185977118355886, 58.76548045022147, 60.59404482160296, 57.497441155569895, 59.89868300301688, 57.05060945238386, 57.99561309814453, 42.62416894095284, 1.434883781841823, 0.2567621293876852, 1.318688731108393, 0.9338493985789162, 0.4738303944468498, 0.07927663211843797, 8.371096730232239, 61.66428279876709, 44.87813329696655, 24.710891348975046, 31.077972139630997, 37.09601191111973, 16.485052789960587, 24.044300283704484, 42.21078586578369, 52.88935416085379, 56.920820576804026, 53.724923678806846, 2.7569883125168935, 0.15186901576817036, 0.06614185656820025, 0.04715413972735405, 0.01796869294984, 0.0332358563984079, 0.03515151681910668, 0.007719772635027766, 0.02643822642442371, 0.015950214117765427, 0.051127976671393426, 0.008940650516056588, 0.050478360815239806, 0.08771195555371897, 0.0664738705381751, 0.09689093979873828, 0.18804987360324177, 0.060598320460745266, 0.16272363545639174, 0.16046283819845744, 0.1779195764767272, 0.1174657161214522, 0.11369207754198994, 0.12287446803280286, 0.15513206353144987, 0.34831599092909266, 0.11714233990226473, 0.30868832447699135, 0.45024153164454866, 21.099004064287456, 94.97781699044364, 72.37256159101213, 73.51258032662528, 57.472306047167095, 30.176241874694824, 59.14840957096645, 103.90257658277238, 53.59780291148594, 74.28197520119804, 48.78540413720267, 0.3677349032035896, 0.1039892439065235, 1.1371901673930032, 7.514144999640329, 17.260473489761353, 19.353008610861643, 6.113145845276969, 1.541099482348987, 37.95223494938442, 65.34026895250592, 68.42198957715715, 68.76081848144531, 67.27213219233921, 65.05956172943115, 59.428032875061035, 60.97902366093227, 62.04423809051514, 62.41878073556082, 65.20308371952602, 67.06727845328194, 67.34462274823869, 64.04096971239362, 62.218339102608816, 63.43908895765032, 52.478364740099224, 48.575009209769114, 48.41226155417306, 47.956737654549734, 45.427343232291086, 46.3748517036438, 47.30441297803606, 48.275924001421245, 60.63827705383301, 61.522789682660786, 59.64235700879778, 58.626731872558594, 59.7736154283796, 59.05128070286342, 54.208539145333425, 48.662372384752544, 47.344941820417134, 44.849423340388704, 44.40892144611904, 44.60153245925903, 42.842463970184326, 43.86746917452131, 51.05614839281355, 59.333766664777485, 57.12058823449271, 59.05784675053188, 55.95379114151001, 59.94886289324079, 56.435429845537456, 55.05088663101196, 49.44896405083792, 51.65157427106585, 51.99884871074131, 54.73790849958147, 49.32384783881051, 50.46358517238072, 51.888195174080984, 59.70751026698521, 50.05170290810721, 36.67634766442435, 54.34663806642805, 52.11869124003819, 58.24156195776803, 50.791335174015586, 50.44726037979126, 52.57433325903756, 53.96027306147984, 54.01660210745675, 51.25776774542672, 54.66957296643938, 53.45089020047869, 57.24186209269932, 53.598706177302766, 51.75227451324463, 57.46064002173287, 55.585223947252544, 56.91919469833374, 51.99220623288836, 50.362249170030864, 48.547935553959434, 56.94039017813546, 54.05744709287371, 48.31307601928711, 42.741506644657676, 43.971379484449116, 44.84245082310268, 44.61804485321045, 44.238940715789795, 47.421191351754324, 45.88090079171317, 44.3753616469247, 43.61417259488787, 42.92182976858956, 44.352244990212576, 45.235110895974294, 46.51263100760323, 47.21331167221069, 45.34356880187988, 51.663236822400776, 49.88343143463135, 54.101168632507324, 55.786982263837544, 57.70822518212454, 58.467208181108745, 59.81532546452114, 62.34879847935268, 63.857613699776785, 61.77592645372663, 64.29090336390904, 59.23686708722796, 61.44001579284668, 59.24798420497349, 61.995204653058735, 46.156410762241904, 1.6139054213251387, 2.520266443490982, 7.972675732203892, 1.7175708072526115, 0.5598774829081127, 0.18226167133876256, 11.342254144804818, 68.70489243098667, 58.03505802154541, 37.41916915348598, 35.49207237788609, 56.61993925912039, 21.7817896434239, 28.463118348802837, 48.53248970849173, 61.62542152404785, 61.29605606624058, 62.82235295431954, 3.979363177503858, 0.18779730929860047, 0.2304779083601066, 0.10843305116785423, 0.14104963918881758, 0.12767451974962438, 0.15968887401478632, 0.10248427359121186, 0.10016253031790257, 0.10222268477082253, 0.08201696364475147, 0.1283219371523176, 0.12462476268410683, 0.13059930423540728, 0.1650612157370363], [0.03386173370693411, 0.058831835963896344, 0.022121656353452375, 0.04193480086645909, 0.023399381898343563, 0.03373589938772576, 0.031550785925771506, 0.0283418581155794, 0.0126165410370699, 0.0469098772986659, 0.027601491593356644, 0.04410578722932509, 0.02019390443872128, 0.09277028484003884, 26.568156991686138, 68.66661480494908, 58.24429954801287, 58.830522537231445, 31.556192329951696, 21.320790563310894, 50.48986325945173, 37.213238443647114, 30.965168135506765, 68.8499847139631, 19.54428904397147, 0.11755027515547616, 0.10715796851686069, 0.8840588246073041, 0.5407868730170386, 9.79060241154262, 7.366864034107753, 1.1248703598976135, 1.7720849620444434, 44.180982317243306, 61.78132520403181, 59.06655979156494, 64.28874942234584, 63.03618376595633, 60.328297070094514, 54.97848640169416, 51.38109827041626, 50.601103918892996, 52.93617112295968, 52.766895634787424, 57.07894768033709, 57.3800756590707, 59.470180647713796, 58.77499253409249, 55.070629937308176, 44.931019510541645, 43.71204492024013, 42.539348806653706, 42.790960448128835, 41.41536998748779, 42.24533578327724, 40.733637060437886, 41.335003648485454, 45.67117289134434, 54.27920579910278, 54.06400966644287, 57.16603987557547, 53.45912034170968, 53.89906290599278, 48.70708056858608, 47.01164020810808, 41.81870596749442, 39.45140954426357, 39.66227347510201, 39.036553450993125, 39.72215305055891, 43.6089996610369, 47.75652878625052, 54.823809078761506, 54.653102261679514, 52.10883869443621, 50.98815679550171, 52.92351497922625, 50.54935026168823, 47.285256794520784, 42.03456217902047, 44.509385449545725, 43.91383102961949, 45.11909335000174, 39.14278098515102, 47.03920718601772, 48.71949005126953, 57.10312046323504, 41.11448172160557, 30.86035803386143, 53.70450292314802, 47.91760540008545, 51.24060222080776, 49.99217421667916, 49.448588848114014, 48.606797218322754, 51.75792687279837, 47.18768671580723, 44.59767968314034, 43.869039467402864, 48.488365173339844, 49.12314912251064, 51.18652091707502, 52.536069529397146, 51.10853781018938, 50.39092091151646, 51.7273200580052, 51.2108222416469, 53.221790722438264, 47.89061859675816, 48.528129713875906, 50.72777305330549, 45.41300909859793, 38.020970003945486, 38.809253556387766, 37.67719745635986, 40.64269208908081, 40.60042272295271, 40.21515553338187, 41.10594585963658, 38.320183753967285, 41.25519663946969, 40.287698200770784, 41.699936934879844, 42.09308685575213, 41.43507855279105, 41.46277059827532, 44.50196477345058, 45.98644740240914, 50.965547357286724, 51.92013604300362, 54.57276371547154, 54.69380480902535, 55.270084926060264, 57.38187524250576, 53.35639817374093, 55.08943176269531, 59.154621260506765, 57.199342591421946, 56.04899188450405, 52.183097566877095, 58.81281157902309, 55.412905148097444, 60.82471111842564, 32.25263459341866, 0.06019425285714013, 1.6276060747248786, 1.6126586539404733, 0.3105598326240267, 0.03152228066963809, 0.16397072853786604, 38.45150818143572, 50.28225108555385, 26.056509017944336, 23.399488346917288, 49.98765788759504, 49.464041641780305, 20.62174619947161, 35.154466356549946, 44.320766176496235, 48.35551561628069, 54.441355909620015, 7.576088190078735, 0.273262906819582, 0.07921781670302153, 0.014373229184587086, 0.05283982892121587, 0.09007395630968468, 0.056141834772591076, 0.0290409866720438, 0.04000640434346028, 0.03269171881090317, 0.03235130457739745, 0.07123321693922792, 0.015021386190450617, 0.052369183461580954, 0.034467916536544047, 0.05162794502185924, 0.04505608570096748, 0.05724596391831126, 0.04136275174096227, 0.02242264261336199, 0.06352023474339928, 0.049668675155511925, 0.014180466715645577, 0.04484289678345833, 0.04453639912285975, 0.13170106868658746, 0.04334603835429464, 0.09203520749828645, 0.11011049829955612, 35.56515005656651, 76.96452181679862, 64.04889065878731, 63.666017123631065, 39.9873171533857, 27.10346531867981, 41.44592121669224, 38.786810874938965, 38.22061954225813, 77.85409968239921, 20.607931443623134, 0.07271322395120348, 0.15919408627918788, 1.7044180844511305, 1.9182862426553453, 4.562239306313651, 3.1902458412306647, 0.7536004792366708, 2.424800366163254, 49.28362819126674, 64.17304107121059, 60.417060307094026, 67.8751802444458, 67.28996126992362, 64.12604345594133, 59.41472707475935, 53.90926286152431, 54.92902912412371, 55.03966529028756, 56.1632411139352, 59.555219650268555, 60.59332915714809, 61.07555498395647, 61.139012881687705, 57.66635186331612, 45.98917804445539, 44.062411308288574, 44.36349064963204, 44.268790176936555, 43.61582279205322, 42.73494059698922, 42.73216479165213, 41.889021737234934, 47.3353602545602, 55.80663524355207, 55.654014587402344, 57.776991503579275, 55.38157572065081, 56.3308664049421, 51.108746256147114, 49.417968136923655, 43.691370555332725, 41.26121377944946, 41.5254294531686, 41.13983917236328, 41.115926946912495, 45.67413977214268, 50.96682582582746, 56.7107070514134, 55.70435776029314, 53.44824988501412, 53.87282303401402, 55.166000911167686, 53.05380065100533, 49.78045218331473, 43.352440902165, 46.38292898450579, 46.165922846112935, 45.96113164084298, 41.306894711085725, 48.54452051435198, 49.28472253254482, 59.7549386705671, 44.85951212474278, 32.78581503459385, 55.72858265468052, 50.626770564488, 52.95190879276821, 51.583596570151194, 51.26111677714756, 48.97085155759539, 54.54453318459647, 49.8783974647522, 45.80884797232491, 46.80748128890991, 49.07036713191441, 50.06880937303816, 52.07134621483939, 53.37499155317034, 52.3730092048645, 52.411366735185894, 54.28947523662022, 53.88050774165562, 56.06611919403076, 49.15037216459002, 51.50103112629482, 53.515664781842915, 47.11830200467791, 39.025947025844026, 41.79653426579067, 41.033285072871614, 42.47321932656424, 42.69897672108242, 42.40927505493164, 42.20898280824934, 41.198461123875205, 42.212196350097656, 41.540243012564524, 44.066482952662874, 42.538473333631245, 41.35772773197719, 42.774899687085835, 47.720870631081716, 48.18050439017159, 52.63737773895264, 54.973025117601665, 56.53236416407994, 56.19510555267334, 58.72607026781355, 59.73274612426758, 53.531346866062705, 57.10683080128261, 60.092384883335654, 59.06893607548305, 58.356391361781526, 56.14188582556588, 61.74634797232491, 59.28002234867641, 64.08980860028947, 38.69354867935181, 0.12509656165327343, 0.7586960600955146, 1.0118536757571357, 0.4976746035473687, 0.06845367287418672, 0.10104968771338463, 38.453648226601736, 57.61204126902989, 29.593350546700613, 23.95006012916565, 46.01172494888306, 39.521051338740754, 25.475498914718628, 42.54956265858242, 49.9138263293675, 53.88061196463448, 63.96748556409563, 10.275807278496877, 0.3228078511144434, 0.1513585810150419, 0.01863311613643808, 0.03988027486151882, 0.08229288991008486, 0.0551788782301758, 0.021472149062901735, 0.017851562538583363, 0.0261906798862453, 0.04872649535536766, 0.02948878925027592, 0.06385851837694645, 0.05294656926499946, 0.02327725068399949, 0.12303321808576584, 0.10781783703714609, 0.13608630480510847, 0.07582894819123404, 0.10970704816281796, 0.1374322875802006, 0.1252370998263359, 0.08896088746509381, 0.15015621696199688, 0.19063218789441244, 0.1480483750679663, 0.2083815104727234, 0.14025246910750866, 0.16667190859360353, 41.07419259207589, 87.65661130632672, 71.39634663718087, 76.2750381742205, 42.21762636729649, 32.54403509412493, 61.803684507097515, 51.57342093331473, 45.56941304888044, 82.07864611489433, 24.54424054282052, 0.2557787692972592, 0.2659497378127915, 3.093592707599912, 3.0640871822834015, 22.79260662623814, 16.344431672777446, 4.181992624487195, 3.088251279933112, 55.731733662741526, 63.3642429624285, 63.816744395664756, 69.4546308517456, 71.08712400708879, 65.24673925127301, 61.49726894923619, 55.49263572692871, 57.26094879422869, 57.45548793247768, 58.30382129124233, 63.313396045139854, 63.91167763301304, 63.763861656188965, 64.33533014569963, 59.01644243512835, 49.80931152616228, 47.46634422029768, 47.92113855906895, 47.34231192725045, 45.672830036708284, 45.75013222013201, 46.16152811050415, 44.86958006450108, 48.853798730032786, 58.04852363041469, 59.32532460348946, 60.807437896728516, 57.06968573161534, 58.62842723301479, 54.516552788870676, 52.10736567633492, 45.70054292678833, 42.41812705993652, 44.05168676376343, 43.85022374561855, 44.82527140208653, 47.94414404460362, 52.51646171297346, 60.48606981549944, 59.53575079781668, 54.8962926864624, 55.78022166660854, 56.65948840550014, 55.69697182519095, 53.43099055971418, 46.941866397857666, 49.9381137575422, 49.358960560389924, 48.53329569952828, 44.62051841190883, 52.670527594430105, 53.778303214481895, 61.31760243007115, 48.22709900992257, 35.798005035945344, 56.85237734658377, 52.82980809892927, 55.44784416471209, 53.14504092080252, 52.10960994447981, 51.828305176326204, 56.141420296260286, 50.989567279815674, 48.43673310961042, 48.84968539646694, 52.989644459315706, 52.58772243772234, 56.2872108731951, 55.66955770765032, 56.45989097867693, 56.13881819588797, 57.72316728319441, 56.59319911684309, 57.97002288273403, 50.582889216286794, 54.041073662894114, 56.04076869147164, 49.76827893938337, 42.50508376530239, 43.60407338823591, 42.06364386422293, 44.473289557865684, 46.97550957543509, 44.786569935934885, 44.62896742139544, 42.47454643249512, 44.65392535073416, 43.80112430027553, 45.535276549203054, 44.21313163212368, 44.72193431854248, 46.72092757906233, 48.812019211905344, 50.68444756099156, 56.01437248502459, 56.45040321350098, 59.74076434544155, 59.423051016671316, 62.34229496547154, 60.59366961887905, 56.25189317975725, 61.149046080453054, 63.013893944876536, 63.05815396990095, 60.2403050831386, 59.37429550715855, 66.55365371704102, 59.99802834647042, 64.7094975880214, 38.96409068788801, 0.21231552080384322, 4.680927566119602, 5.011171971048627, 0.4860271971140589, 0.2937765674931662, 0.4829424140708787, 46.27120542526245, 62.48642839704241, 39.54034996032715, 32.39457934243338, 63.727675437927246, 63.11609499795096, 29.5801420211792, 47.28119557244437, 57.659914357321604, 61.38673005785261, 70.09822859082902, 11.612651978220258, 0.45740300736257006, 0.27488161996006966, 0.18933082558214664, 0.16336558386683464, 0.19543394951948098, 0.20615519636443683, 0.14981256611645222, 0.14961340251777852, 0.08940192165651492, 0.09615975724799292, 0.25913502063070026, 0.16218368442995207, 0.14726761196340832, 0.22079173954469816], [0.059687468622412, 0.0631136294188244, 0.06781977867441517, 0.031023001032216207, 0.05693139508366585, 0.07211551602397646, 0.05520706457485046, 0.032508575424019776, 0.054112322961113284, 0.052566046826541424, 0.1075293646593179, 0.030131819924073558, 0.05324941301452262, 0.36284244858792847, 51.71775933674404, 67.31266103472028, 57.37249517440796, 54.09386954988752, 28.194254330226354, 24.222941943577357, 32.31995221546718, 33.220039231436594, 52.65524503162929, 64.759920665196, 4.395884667124067, 0.2093769484864814, 0.058070214332214425, 0.47277790520872387, 1.7843124887772968, 3.1707515844276974, 2.2205513375146047, 1.1613540479115076, 12.378311327525548, 65.39097690582275, 64.26925277709961, 63.34127916608538, 61.81941522870745, 62.42955044337681, 61.64439010620117, 58.94074181147984, 57.32775919778006, 51.980568000248496, 47.79809291022164, 45.97381905147007, 47.822366441999165, 49.282408782414024, 51.71833951132638, 49.55116857801165, 45.750368458884104, 43.121962206704275, 44.52435186931065, 41.10973610196795, 42.16404185976301, 41.92437417166573, 42.78693396704537, 39.911196163722444, 42.27467802592686, 40.27171386991228, 43.81633390699114, 45.97466673169817, 52.08037887300764, 53.128486837659565, 48.92541033881051, 49.43506070545742, 46.559805801936555, 39.57000139781407, 40.72290209361485, 38.163644313812256, 38.62690155846732, 39.04116358075823, 43.85803004673549, 53.16716398511614, 43.710658754621235, 45.61762312480381, 51.55532782418387, 51.040528842381065, 50.966784136635916, 47.95943702970232, 44.6167768069676, 38.20882844924927, 41.91171107973371, 39.04660054615566, 41.44389929090227, 38.71317386627197, 48.15071398871285, 47.558960233415874, 57.17871338980538, 37.359727314540315, 29.039719820022583, 56.01279871804373, 48.122188159397666, 52.63672113418579, 47.631721769060405, 51.86618675504412, 48.52494396482195, 51.59457472392491, 48.75430400030953, 46.106463636670796, 41.41764552252633, 42.82534013475691, 44.07148912974766, 45.94000564302717, 47.25764812741961, 49.39543512889317, 47.157934529440745, 49.79103428976876, 50.68008409227644, 48.72736930847168, 53.73671129771641, 50.298958029065815, 49.685650961739675, 50.601798738752095, 42.56353548594883, 38.81373167037964, 40.000567368098665, 39.64645937510899, 39.63425486428397, 38.847017015729634, 40.69098554338728, 40.718681062970845, 40.19775029591152, 41.53778682436262, 40.93206718989781, 41.59508514404297, 39.41505656923567, 43.78405605043684, 46.534319809504915, 51.19364282063076, 50.43000105449131, 53.84937286376953, 54.30123853683472, 58.00612572261265, 53.76449714388166, 54.93907969338553, 59.54422065189907, 53.80989319937569, 53.08604724066598, 55.950758252825054, 55.58815608705793, 64.75363254547119, 61.54608004433768, 61.88747978210449, 54.296364375523154, 59.85001087188721, 19.90253816332136, 0.3754735950912748, 0.5813125669956207, 0.6420981766922134, 0.17356178031436034, 0.009636645937072379, 13.116375037602015, 60.64574636731829, 42.17823008128575, 39.71852956499372, 56.58674424035208, 60.66251931871687, 20.238883086613246, 19.069075686591013, 39.1331855228969, 40.711930888039724, 55.643915380750386, 16.462142842156545, 0.24467001110315323, 0.10037806696657624, 0.010558398440480232, 0.022367893319044794, 0.055152466254574914, 0.020152093110872165, 0.01301875793641167, 0.021321426079209362, 0.013255632815084286, 0.07225733662822417, 0.03689974193860378, 0.06339723670056888, 0.06429026342396225, 0.01827799804907824, 0.05776585066424949, 0.02166302265998508, 0.09401386311011654, 0.03398317451189671, 0.09139010390000683, 0.01969028726619269, 0.020296592232105986, 0.056022836693695614, 0.0112312117125839, 0.043526504920529466, 0.09883612327809844, 0.04882476758211851, 0.07054902293852397, 1.1438948533364703, 63.61692810058594, 74.65694168635777, 62.11663137163435, 61.458095005580354, 32.23299551010132, 19.866237299782888, 40.00895036969866, 36.82535873140608, 59.43036052158901, 68.55616624014718, 4.9842385819980075, 0.20145035668143205, 0.5415364099400384, 1.9534297968660082, 4.666202161993299, 6.525219185011728, 3.0579423691545213, 0.6531426097665514, 14.67341423034668, 68.92971529279436, 65.88657801491874, 64.5394960130964, 62.64049080439976, 63.28710406167166, 63.33862495422363, 61.160538400922505, 59.706099782671245, 55.43689727783203, 50.25113010406494, 47.527439730507986, 51.24274921417236, 51.66519621440342, 53.07329034805298, 52.29302849088396, 47.67760419845581, 45.80224370956421, 46.75842005865914, 43.6409717968532, 45.153407028743196, 43.58842951910836, 43.15185335704258, 41.372888701302664, 43.51019975117275, 42.742792061397004, 44.16738469260079, 48.481163365500315, 54.47524922234671, 54.40080969674246, 51.92594126292637, 49.988397870744976, 49.73122419629778, 42.02057545525687, 41.61617292676653, 40.33341039930071, 41.36297362191336, 42.27885389328003, 46.641054562159944, 55.28439474105835, 46.975238595690044, 46.678553989955354, 53.96641526903425, 53.42248249053955, 53.86713245936802, 51.17359726769583, 46.69749130521502, 41.10996886662075, 44.271791798727854, 40.91324799401419, 44.192196709769114, 42.410247802734375, 49.15195287976946, 48.24958338056292, 59.80234622955322, 39.555740220206125, 32.011007513318745, 58.08281299046108, 50.11848551886422, 54.64814472198486, 50.2595339502607, 54.23587335859026, 49.19759907041277, 53.63462836401803, 49.65101766586304, 49.35504525048392, 45.23727873393467, 46.63504784447806, 45.273649079459055, 49.67214018957955, 49.76173373631069, 50.92727320534842, 50.19154582704817, 51.850164209093364, 52.13257721492222, 52.184365613119944, 54.41055454526629, 50.82885544640677, 52.26049355098179, 52.55835240227835, 44.783540521349224, 40.52877984728132, 40.92280871527535, 41.462089674813406, 40.96833678654262, 42.06156982694353, 42.15955679757254, 43.19966043744768, 41.074345452444895, 42.42422410420009, 43.203547954559326, 43.162421567099436, 39.89649724960327, 45.39356803894043, 49.80990212304251, 53.80456740515572, 54.44971111842564, 55.509634494781494, 56.357787200382774, 60.45116206577846, 58.66955362047468, 56.910290581839426, 60.56836427961077, 55.88256515775408, 55.404167788369314, 57.41644600459507, 58.05782379422869, 67.58840724400112, 62.24937670571463, 63.212758336748394, 57.13184431621006, 64.15822056361607, 23.819404465811594, 0.29196542182138985, 0.7122943071382386, 2.323004479919161, 0.1853365341999701, 0.021552628405126076, 13.071114471980504, 64.61091654641288, 49.451368127550396, 41.39590808323452, 56.89776645387922, 55.16986410958426, 28.03498251097543, 24.82008750098092, 42.3160719190325, 47.03531966890608, 63.47665091923305, 21.86200312205723, 0.34877028369477814, 0.10838837642222643, 0.042922866597239456, 0.026404574480173842, 0.028100404821868454, 0.019280447025916407, 0.03361137124842831, 0.021414948560829674, 0.00949242162252111, 0.04849771709580507, 0.02565197227522731, 0.08508548898888485, 0.04198218635948641, 0.0162365609846477, 0.08686179188745362, 0.12316067410366875, 0.1620969676545688, 0.2778757507247584, 0.1884465180337429, 0.1388535470302616, 0.24735706405980246, 0.1572009710861104, 0.22446992860308715, 0.1002887717581221, 0.273252538804497, 0.16924100502261094, 0.2041127381048032, 1.7095457464456558, 73.35553019387382, 85.05886050633022, 71.11541707175118, 70.45538684300014, 39.556605270930696, 35.27554219109671, 46.194000516619, 47.12635496684483, 69.08995464869908, 75.29449449266706, 5.98134503194264, 0.3552987405232021, 1.1254400036164691, 4.155608577387674, 7.275701063019889, 16.156795569828578, 10.088156410626002, 2.828675700085504, 18.545933655330114, 73.50148405347551, 66.72750459398542, 67.55033111572266, 63.16007014683315, 65.87566934313092, 67.14093630654472, 64.71472263336182, 62.83813926151821, 57.79198224203927, 53.58707141876221, 49.13327612195696, 53.6983641896929, 55.60124996730259, 55.42926468167986, 54.88500533785139, 50.20040478025164, 47.28203977857317, 49.59566136768886, 46.51489264624459, 48.14774015971592, 46.250107220241, 46.031447410583496, 44.73494829450335, 46.022115979875835, 45.62661756787981, 46.72642707824707, 50.251081466674805, 56.52471767153059, 57.31802477155413, 53.45567403520857, 53.13634525026594, 51.63440874644688, 44.842495986393516, 43.70543370928083, 43.21156964983259, 44.05341339111328, 44.15499605451311, 49.036199365343364, 58.47367695399693, 48.194091592516216, 49.64989900588989, 54.14283697945731, 55.03413105010986, 55.420975480760845, 53.22633137021746, 49.60592038290841, 43.61378002166748, 45.13923617771694, 42.938008649008616, 46.28204461506435, 44.34848254067557, 50.750601359776084, 52.87449196406773, 61.503279141017366, 44.214955534253804, 34.9692690713065, 59.25284794398716, 53.53172206878662, 57.5502370425633, 52.27602277483259, 56.40585136413574, 52.13078457968575, 56.095020226069856, 52.770154339926584, 50.73157024383545, 47.8238742010934, 48.88124411446707, 48.91993168422154, 51.45721231188093, 52.235636370522634, 52.5308062689645, 53.07536091123308, 55.31916005270821, 54.45685734067644, 53.51232269832066, 58.39398111615862, 53.43839039121355, 54.62235648291451, 54.6875444820949, 47.74259417397635, 44.32236426217215, 42.83934422901699, 43.67350326265608, 43.96819373539516, 44.639160428728374, 43.249885490962434, 46.709758349827354, 43.53577954428536, 44.71854707172939, 44.19469806126186, 47.46545832497733, 43.143546785627095, 47.86434398378645, 52.19585445949009, 55.94007887159075, 56.06088720049177, 57.561420168195454, 61.12495667593819, 63.19062832423619, 61.24347904750279, 60.94743020193917, 61.222544125148225, 57.73962409155709, 57.52370534624372, 61.354198592049734, 60.922395842415945, 69.16646821158272, 64.73355225154332, 66.67647702353341, 61.43796607426235, 67.6253855569022, 24.140564101082937, 1.0408859636102403, 4.5286217502185275, 2.9299089993749345, 0.4032162864293371, 0.08324558700301818, 16.0131676197052, 71.09168202536446, 56.058034964970176, 53.58253077098301, 63.84384931836809, 73.2513211114066, 27.690020084381104, 26.822780677250453, 51.143834659031455, 54.24441964285714, 72.38355364118303, 27.238562617983135, 0.3165974643613611, 0.2530764900147915, 0.09640041326305696, 0.08147082437894174, 0.17306411559028284, 0.16071118201528276, 0.12684852550072329, 0.09534797152238232, 0.1355761821780886, 0.1022820905117052, 0.08272934399013009, 0.2151049239827054, 0.1632834811295782, 0.09190835537655012], [0.04610805246712906, 0.06766727114362375, 0.024119112474311675, 0.05544148146041802, 0.05044797940977982, 0.0045748039597778446, 0.06396210353289332, 0.05041386606171727, 0.05427042501313346, 0.06921786615358931, 0.06391263154468366, 0.04568576280559812, 0.07851053894098316, 7.2141517485891065, 65.44586767469133, 54.41795090266636, 62.518119130815776, 38.2373924936567, 30.407453605106898, 48.33322926930019, 37.85449811390468, 28.465114218848093, 62.62169592721121, 39.67828212465559, 0.18768791588289396, 0.06437020163450922, 0.17275753989815712, 1.1157738651548113, 1.9754492895943778, 2.0041416585445404, 0.5113801423992429, 0.05272810813039541, 48.95055934361049, 70.03377710069928, 64.0826450075422, 64.18247672489711, 62.698410987854004, 63.55071871621268, 63.18195697239467, 59.862656593322754, 60.14571925571987, 56.60049819946289, 51.718711239951, 47.15319585800171, 47.49526957103184, 44.0028270312718, 44.24564920152937, 44.400531496320454, 45.980756827763145, 42.53795569283621, 43.107315404074534, 40.779821736471995, 42.03467335019793, 41.354917185647146, 42.70396205357143, 40.86349194390433, 40.56958314350673, 40.35642283303397, 42.83465766906738, 40.04371220724923, 42.17464828491211, 47.73640332903181, 47.28715017863682, 45.85870129721505, 42.90100949151175, 42.05202995027815, 39.38664538519723, 39.78457219260079, 40.19054501397269, 39.61027315684727, 47.62592349733625, 50.687146936144146, 51.62921149390084, 46.75725276129586, 53.38331549508231, 49.86209004265921, 51.89474385125296, 45.38799558367048, 41.24208538872855, 39.641911779131206, 42.27963556562151, 38.17807919638497, 41.383599349430625, 38.24093607493809, 49.064791202545166, 46.56659071786063, 57.55460398537772, 36.91210004261562, 33.93681192398071, 57.68989930834089, 44.38697208677019, 48.28691257749285, 45.57539892196655, 51.37405627114432, 49.476638725825715, 51.28646033150809, 49.58035796029227, 46.17118263244629, 42.54825987134661, 45.53791686466762, 44.151112011500764, 42.89540924344744, 41.84650918415615, 41.26530279432024, 42.60289355686733, 44.329281193869456, 45.48414822987148, 51.380219323294504, 48.91674246106829, 52.08767448152815, 52.513241222926546, 51.58560112544468, 44.57587276186262, 39.57184614453997, 38.80672441210066, 39.082105840955464, 40.250407218933105, 39.031085218702046, 38.651442595890586, 39.73678248269217, 40.698409693581716, 40.29561914716448, 42.88788087027413, 40.2874550138201, 41.80958645684378, 44.04496785572597, 50.386140550885884, 52.374357155391145, 53.39216750008719, 54.8297324180603, 55.76245164871216, 53.37108666556222, 56.38149445397513, 51.8901024545942, 54.53230088097708, 57.932863916669575, 58.69544260842459, 59.833321298871724, 61.443656648908345, 57.560648918151855, 58.727001326424734, 56.78286061968122, 60.753422600882395, 52.44379397800991, 46.95048563820975, 3.336311306272234, 1.0561869825635637, 0.6879451051354408, 0.033529261725821664, 0.04703130792560322, 0.7690217345952988, 42.90816266196114, 52.39269692557198, 31.429992198944092, 63.283393723624094, 73.45517430986676, 24.48372347014291, 15.931298732757568, 33.81593411309378, 45.65462923049927, 50.95339495795113, 23.32232686451503, 0.23652484959789685, 0.036515348457864354, 0.026547562164653624, 0.08575180359184742, 0.08350165254835572, 0.02931693329342774, 0.06069173437676259, 0.03552319794627173, 0.058545032782214027, 0.014927049466807927, 0.016574785246380737, 0.04881607894120472, 0.026476076804101467, 0.03404329949989915, 0.029584116635045836, 0.022094772796013525, 0.01582994717838509, 0.041212921030819416, 0.037530131505004, 0.026533167044233, 0.053126995119133165, 0.05125063205403941, 0.03176248545891472, 0.05181969562545419, 0.05353726114013365, 0.10196298906313521, 0.18738839695496218, 11.768641642161779, 77.24458980560303, 61.48005826132638, 67.95443834577287, 45.06061036246163, 36.41284418106079, 45.798811299460276, 42.72231919424874, 32.35767051151821, 70.93819631849016, 41.931794847760884, 0.2309615681213992, 0.01201222587509879, 0.7647646601711, 2.4862270014626637, 3.7529843534742082, 5.280996578080313, 0.784644541995866, 0.34741492356572834, 52.63429273877825, 71.66573524475098, 66.29297120230538, 66.54039655412946, 65.16011605943952, 63.91285187857491, 65.50679642813546, 63.11085605621338, 61.6256925037929, 58.50033719199044, 53.042065143585205, 49.92779915673392, 48.7609395299639, 45.634191104343955, 47.41062661579677, 46.78636571339199, 46.854954855782644, 44.25773559297834, 44.08123745237078, 42.75815800258091, 45.152403014046804, 43.0488463129316, 44.220170157296316, 43.21503332683018, 42.3621940612793, 42.88948243004935, 45.56359045846121, 41.91278110231672, 45.002912521362305, 49.5172370501927, 49.0440091405596, 47.22671822139195, 45.60139560699463, 43.49042865208217, 41.713941029139924, 41.13967588969639, 42.287132671901155, 41.4486414364406, 50.50956835065569, 53.36883544921875, 54.49957833971296, 47.488397802625386, 54.55417381014143, 53.383204323904856, 53.092700140816824, 47.33738565444946, 41.86278881345476, 42.3171523639134, 44.706314768110005, 40.021561350141255, 43.70393637248448, 41.28684915815081, 51.35197489602225, 47.494706766945974, 60.19310597011021, 39.63299029214041, 36.691515581948416, 59.75090176718575, 46.37096071243286, 48.17410857336861, 48.307058879307334, 53.521734033312114, 52.52928113937378, 53.87104082107544, 51.68638474600655, 48.20542410441807, 45.67908688953945, 47.99440383911133, 45.56725910731724, 45.89045803887503, 43.98980958121163, 44.225374358040945, 45.27848849977766, 46.491984435490195, 46.854808943612234, 52.28279032026018, 54.31107023784092, 54.39337512425014, 55.05568783623831, 53.053630420139854, 47.35452686037336, 39.935129233769004, 40.37937273297991, 42.088865825108115, 41.7881304195949, 40.739688941410606, 40.427819047655376, 42.25315250669207, 42.721989154815674, 40.78126001358032, 44.92428323200771, 40.94875676291329, 44.435699803488596, 45.655254568372456, 51.98532056808472, 53.9496979032244, 56.27167470114571, 57.606996876852854, 58.65180792127337, 55.28767776489258, 57.59862429755074, 55.78473799569266, 58.07255744934082, 60.7890807560512, 61.0527857371739, 61.173580169677734, 63.46399824959891, 57.88564395904541, 61.555717195783345, 57.57812711170742, 61.77295957292829, 54.44285324641636, 55.08487721851894, 3.941122463771275, 0.543272536780153, 1.2519608374152864, 0.5526494021926607, 0.0540453922668738, 0.8091436188135828, 44.40436690194266, 59.06055654798235, 34.143201214926584, 61.81090368543352, 72.0988164629255, 23.766431399754115, 23.113488333565847, 36.7046685218811, 51.09881728036063, 55.773752893720356, 33.54452010563442, 0.44130859098264147, 0.03391070697190506, 0.07890932075679302, 0.05253174009599856, 0.06176877301186323, 0.015470174340797322, 0.04125642530354006, 0.028218799004597322, 0.02798769506625831, 0.04664651410920279, 0.03263272358370679, 0.018733661455501403, 0.019988937669300606, 0.011361090948672166, 0.10701504190053258, 0.17521435235227856, 0.07369830752057688, 0.1865114447261606, 0.12494762321668011, 0.11186229929860149, 0.17086677492729255, 0.14911797695926257, 0.16217054799199104, 0.2441607027181557, 0.28140690124460627, 0.20406340860894748, 0.3666861594787666, 14.681241376059395, 89.21336214882987, 69.11946364811489, 78.45882225036621, 51.72604158946446, 44.2898918560573, 61.9771671295166, 52.36334078652518, 42.28839029584612, 77.9957526070731, 48.48767382758004, 0.5840143848742757, 0.0995573652908206, 1.4023951994521278, 6.480632594653538, 7.548072184835162, 8.503613642283849, 5.322314475263868, 0.5958096576588494, 59.33993666512625, 72.51406165531704, 69.91263525826591, 69.23588071550641, 66.22574738093785, 66.782548223223, 67.3028154373169, 65.72715854644775, 65.81479617527553, 61.31784561702183, 55.9597144808088, 52.45243753705706, 52.88780471256801, 48.93416506903512, 50.10137905393328, 49.61675609861101, 49.93737030029297, 45.69352524621146, 48.14456830705915, 44.00453976222447, 47.76410232271467, 46.02692065920149, 48.2342278616769, 44.701777594430105, 43.589635031563894, 45.35257019315447, 47.25561577933175, 44.25714152199881, 46.10022415433611, 53.06767272949219, 51.24400683811733, 50.80243492126465, 48.199518135615754, 45.97189787455967, 45.47691168103899, 44.409115995679585, 44.92176103591919, 44.92603417805263, 51.80116898672921, 56.967741761888774, 54.257777554648264, 49.29955346243722, 56.561220032828196, 55.87656191417149, 55.49273994990757, 50.099061829703196, 44.42836945397513, 43.51610571997506, 47.015329701559885, 42.02688094547817, 45.609591007232666, 43.438508238111226, 53.82306350980486, 51.06265538079398, 61.40691457475935, 42.66226938792637, 38.46837493351528, 63.27718898228237, 50.09760618209839, 50.60833699362618, 50.149686404636924, 55.883127961839946, 54.42631653376988, 54.858313832964214, 53.3739458492824, 52.51709052494594, 47.422709533146445, 50.342971393040244, 48.76761327471052, 47.2136868749346, 47.03951290675572, 46.73595653261457, 47.24523517063686, 49.31269598007202, 49.60718495505196, 56.37896530968802, 58.171194076538086, 56.80892331259591, 59.173506464277, 55.64817115238735, 49.72605126244681, 43.155560220990864, 42.484656061444966, 43.88893910816738, 44.42676789419991, 42.678590706416536, 42.71288701466152, 43.92716809681484, 45.40397296633039, 43.068992614746094, 46.44187750135149, 43.20354448046003, 46.182497773851665, 48.81980814252581, 53.65109559467861, 56.92686550957816, 57.05062334878104, 60.15182672228132, 62.25680433000837, 58.034074851444785, 60.090731212071006, 60.03053896767752, 62.314627238682334, 64.07846219199044, 62.67293194362095, 64.31592382703508, 65.7367192677089, 59.92944962637765, 63.688383374895366, 60.23562199728829, 65.26768112182617, 58.29148823874337, 57.727607182094026, 4.110288517815726, 2.1854909445558275, 4.154059129101889, 0.574059896171093, 0.10698915578957115, 1.6371190271207263, 49.8419645854405, 62.886491775512695, 43.11728606905256, 67.92840344565255, 80.03309644971574, 31.830072947910853, 25.31671346936907, 46.51652199881417, 57.72094733374459, 65.77721336909703, 38.829566614968435, 0.5368079979504857, 0.08377850840666465, 0.12549240541245255, 0.1556293075638158, 0.191482650116086, 0.12629551946052484, 0.24173369152205332, 0.1347550055278199, 0.15171709177749498, 0.08154151415718452, 0.10564461150871855, 0.09769777900406293, 0.08350159826555423, 0.10224534784044538], [0.0406231926754117, 0.032279892159359794, 0.024139022388096367, 0.028450143822867955, 0.006591541077276426, 0.06292146830154316, 0.0538219880046589, 0.02800501636894686, 0.08216147803302322, 0.06831385394824402, 0.029581731584455286, 0.03706466666023646, 0.11754490115812846, 33.30728428704398, 70.057053565979, 60.07211003984724, 52.73680993488857, 35.57828215190342, 21.811899662017822, 44.032089369637625, 44.31071213313511, 42.212793895176475, 73.50949532645089, 20.541192259107316, 0.09294648002833128, 0.0850135710622583, 0.7706838196941784, 0.6675160442079816, 6.7598238076482495, 6.176113895007542, 1.4527909180947711, 6.503139981201716, 71.70818178994315, 62.401785441807334, 62.43629019601004, 56.90624673025948, 63.46818801334926, 60.49517890385219, 62.92253902980259, 61.04546233585903, 61.002265385219026, 57.889719077519004, 57.73463181086949, 54.84440353938511, 52.46572944096157, 49.881190640585764, 50.41361720221383, 46.803753580365864, 44.53765419551304, 42.09161731175014, 42.05600084577288, 42.08861221585955, 42.73027835573469, 41.394591399601524, 40.84003482546125, 41.38387032917568, 40.39823361805507, 39.46686928612845, 41.79910509926932, 43.39336926596505, 40.78215285709926, 40.59577785219465, 43.44361168997628, 41.95114210673741, 41.21275009427752, 38.60017531258719, 38.71629360743931, 38.57977540152413, 40.110717160361155, 40.267906257084434, 48.29119961602347, 52.538074084690635, 54.1453070640564, 54.25840984072004, 53.45455884933472, 50.063723291669575, 48.79691730226789, 41.91601201466152, 39.949355670383994, 39.11509588786534, 38.63120596749442, 39.38356385912214, 45.14637892586844, 40.43001815250942, 48.464244501931326, 47.7427852494376, 55.337788173130576, 39.247966289520264, 37.129304204668315, 55.33919518334525, 48.52649688720703, 49.488231795174734, 42.7428754397801, 49.5818691934858, 47.87694454193115, 51.40586859839303, 49.83606556483677, 47.970071247645784, 43.277122429439, 48.28101008278983, 49.078201225825715, 48.4445880481175, 46.03005429676601, 46.2960660798209, 41.26016460146223, 42.56304216384888, 41.74008362633841, 47.05933959143502, 48.4402072089059, 51.90807397024972, 52.08538505009243, 50.820208413260325, 45.67095749718802, 39.61639451980591, 36.90952573503767, 38.51449360166277, 39.63284090587071, 41.06475346429007, 39.79598113468715, 40.84372084481375, 38.943933963775635, 42.09117957523891, 42.067368098667686, 40.06713458469936, 41.04498931339809, 46.92396436418806, 50.2631504876273, 54.57253442491804, 56.197176115853445, 55.03347097124372, 54.94893223898751, 56.014129298073904, 56.74787643977574, 57.950494970594136, 54.74173348290579, 55.62846606118338, 55.505906786237446, 57.20969540732247, 54.50021409988403, 55.91476311002459, 55.12418665204729, 57.503958565848215, 58.656935691833496, 59.13446453639439, 57.201500007084434, 24.83677707399641, 0.4219310150614807, 1.246240190097264, 0.6150187669055802, 0.08430940777595554, 0.08916870238525526, 16.842587981905254, 63.36849525996617, 43.36147008623396, 48.36313084193638, 71.79406152452741, 43.918580123356406, 16.754060983657837, 28.915776116507395, 40.90665415355137, 46.16716309956142, 40.5198792048863, 1.3666912295988627, 0.17074975477797644, 0.07126964069902897, 0.09467466800872769, 0.03926572569512895, 0.029221768757062297, 0.03551546943240932, 0.036471053691846986, 0.025014425860717893, 0.0166461688266801, 0.05871056140001331, 0.023813802249995724, 0.03137927602178284, 0.027733777084254792, 0.01726219380673553, 0.06367567354547125, 0.06328302568622998, 0.08392932638525963, 0.03229920326599053, 0.010306297235989144, 0.019829110441995517, 0.03699844842776656, 0.013890740744370435, 0.03999837727418967, 0.030535388804439987, 0.0876865851293717, 0.03997791265802724, 47.10050071988787, 77.65510327475411, 68.25250216892788, 57.847540037972585, 47.31103808539254, 29.523271015712194, 42.126330511910574, 43.77563830784389, 48.08696774074009, 79.11362048557827, 20.472108057567052, 0.04997524406228747, 0.0377346589230001, 1.485924054469381, 1.883760860988072, 4.289565937859671, 4.536715967314584, 1.2680040108306068, 8.655805247170584, 75.78370325905937, 63.941666058131624, 64.28107166290283, 59.803291184561594, 66.62940297807965, 64.50861821855817, 63.79255771636963, 63.384253774370464, 62.001874923706055, 59.57386861528669, 60.171226092747276, 57.0855519430978, 53.39142404283796, 53.10155214582171, 53.48740298407418, 48.60175977434431, 46.89438588278634, 43.290105138506206, 44.36910826819283, 43.41705567496163, 44.75336102076939, 43.58854416438511, 42.835807595934185, 42.57222073418753, 43.60995156424386, 42.10928658076695, 44.17977680478777, 43.88051094327654, 41.46296167373657, 44.085222244262695, 46.657125745500835, 44.860005446842735, 42.88699150085449, 40.43608045578003, 41.31780685697283, 41.05481406620571, 42.07728665215628, 44.235810552324565, 51.026423999241416, 54.19799525397164, 55.256459508623394, 54.81438037327358, 54.303851059504915, 51.981099537440706, 51.321607794080464, 44.762206077575684, 43.0634514263698, 39.52761043821062, 39.7865628514971, 41.460922377450125, 45.66088260923113, 43.982885701315745, 50.2597667149135, 51.50409180777413, 57.38327530452183, 41.73592165538243, 37.88235691615513, 58.34460721697126, 50.55981077466692, 51.35232925415039, 45.05895321709769, 53.06127691268921, 48.27462468828474, 53.630167620522634, 50.47445910317557, 50.64027091435024, 45.68430151258196, 49.65706259863717, 51.06382267815726, 49.9375752721514, 46.44476447786604, 48.15372950690133, 43.56018509183611, 42.500647340502056, 42.82960980279105, 48.310001441410606, 47.802522386823384, 54.72982427052089, 53.26819774082729, 53.2912449155535, 48.716328620910645, 40.767259393419536, 38.30598511014666, 42.24722221919468, 41.00561039788382, 42.72740527561733, 42.50841195242745, 43.655048847198486, 42.03297451564244, 43.804598399571006, 43.06667191641671, 42.071682929992676, 43.48766674314226, 48.64230251312256, 53.508230209350586, 57.02757269995553, 57.763286181858604, 56.81205000196184, 58.43038967677525, 57.98412077767508, 59.297142710004536, 59.03265953063965, 56.622711590358186, 58.469813755580354, 57.13918161392212, 57.70302445547921, 56.865749154772075, 58.75766372680664, 57.75576475688389, 59.003192220415386, 61.78828729901995, 61.19731521606445, 61.715171405247276, 30.338127953665598, 0.11897453373031956, 0.3513441841517176, 0.7743391149810382, 0.24764318870646612, 0.05841268452682665, 15.480739321027484, 69.3484832218715, 47.281674998147146, 48.16026776177542, 70.39158153533936, 36.660328592572895, 18.98697403499058, 30.730068887983048, 46.85494443348476, 51.20668806348528, 53.47226285934448, 2.4239398751940047, 0.19729128985532693, 0.04109706456906029, 0.06293019426188298, 0.02913393239889826, 0.018778748411153044, 0.02069019852206111, 0.028807621515755142, 0.09360265731811523, 0.02948878925027592, 0.03739497072196432, 0.044733126780816486, 0.04182274080812931, 0.013212355003426117, 0.1254149709961244, 0.20401067286729813, 0.16554209350475244, 0.1423934642225504, 0.232295350836856, 0.11196781827935151, 0.1498679888567754, 0.12305156567267009, 0.15783029874520643, 0.20370892834450516, 0.08496283021356378, 0.11683129944971629, 0.204824724899871, 56.70487751279558, 88.97039754050118, 77.1904216493879, 68.24768706730434, 49.291073186056956, 29.251238618578228, 53.26483481270926, 59.55915927886963, 56.80136019842965, 85.26135185786656, 23.480898652757915, 0.2326598869902747, 0.19099842038537773, 2.5461180848734717, 4.408130867140634, 13.623742921011788, 15.305827106748309, 5.753388966832842, 11.43333808013371, 77.68081160954067, 65.95886707305908, 66.5930916922433, 61.17873573303223, 69.69682421003068, 67.1431666782924, 67.4234848022461, 65.74423027038574, 65.17061478751046, 62.55490984235491, 63.60398360661098, 59.4331328528268, 56.62964589255196, 55.08111824308123, 55.201690333230154, 52.43484122412545, 49.54468938282558, 45.676432677677695, 47.50333295549665, 46.753879410879954, 48.107989515577046, 45.60191324778965, 45.354821409497944, 43.324592522212434, 44.177046162741526, 43.057854652404785, 46.06231130872454, 47.08383199146816, 44.0776869228908, 45.031716278621126, 47.95981223242623, 46.93111058643886, 45.19770874295916, 42.247138840811594, 42.58203853879656, 42.99770062310355, 44.94867140906197, 46.97424847739083, 52.92707940510341, 56.766688687460764, 57.30841541290283, 55.70395129067557, 56.50394950594221, 53.07782752173287, 54.19699471337454, 47.732230935777935, 45.06790597098214, 41.89287798745291, 41.33376686913626, 43.17046063286917, 49.94015652792794, 45.49930225099836, 53.781957966940745, 54.78596224103655, 59.611034529549734, 44.84405585697719, 41.95647832325527, 59.218593324933735, 51.9805714743478, 53.937416962214876, 46.73978846413748, 55.35678802217756, 51.50119093486241, 55.030462401253835, 53.61336687632969, 53.68118129457746, 48.56536511012486, 52.28232479095459, 53.40067209516253, 53.07877247674124, 49.79460218974522, 49.739899022238596, 46.186347075871055, 45.86222750799996, 44.54528331756592, 51.91274315970284, 50.952126911708284, 58.105849742889404, 57.009253774370464, 55.649668489183696, 50.15904215403965, 43.49464273452759, 40.46740640912737, 43.272654737745015, 42.98417942864554, 46.471466405051096, 43.83267954417637, 46.212364605494905, 44.55934994561331, 45.3359431539263, 45.99960034234183, 44.39187751497541, 45.17445312227522, 50.941940852573936, 55.326907294137136, 59.629926681518555, 60.84192875453404, 59.61407784053257, 60.8564088003976, 60.85400472368513, 62.066882269723074, 60.8583265032087, 58.53513377053397, 59.58091408865792, 59.00501959664481, 61.390627997262136, 58.39985234396798, 61.19685663495745, 59.803583008902415, 64.15434346880231, 63.949753761291504, 62.80810914720808, 64.89738382611955, 31.834561484200613, 0.7652172701699393, 5.704830178192683, 2.0574606146131242, 0.5787366309336254, 0.1743078295673643, 20.529102393559047, 74.87241922106061, 56.781498772757395, 53.929888589041575, 77.48189163208008, 53.89221545628139, 24.625539677483694, 40.708731242588584, 54.656128202165874, 58.86904335021973, 60.55048656463623, 3.7718144059181213, 0.477486503975732, 0.23408899030515126, 0.15681519678660802, 0.09924942574330739, 0.12411195305841309, 0.2680982510958399, 0.16685093327292375, 0.17187589220702648, 0.09140127258641378, 0.13582790509930678, 0.09912912148450102, 0.14841434971562453, 0.12174814061394759], [0.02851427047114287, 0.03963522872488413, 0.04344244460974421, 0.03859429493812578, 0.04747683062617268, 0.06343800986983947, 0.0411017803874399, 0.018976719484531453, 0.04361344561246889, 0.011613722258646573, 0.08617524337023497, 0.14724060626966612, 2.661372414657048, 60.42967823573521, 58.32901545933315, 52.68461854117257, 38.671258858272004, 22.27926676613944, 18.04335308074951, 52.53659759249006, 37.94086422239031, 47.6523996080671, 61.64432757241385, 5.54527348279953, 0.11800359083073479, 0.23388884961605072, 0.42340145472969326, 1.9724092355796268, 6.285756468772888, 4.013406745025089, 2.387385185275759, 29.699334893907817, 70.24730219159807, 62.41568183898926, 55.70242963518415, 55.87153489249093, 59.53585502079555, 62.51064286913191, 62.287299973624094, 62.64556993756975, 60.527210099356516, 58.58258301871163, 57.764595917293, 58.669164521353586, 54.62538937159947, 55.99207918984549, 55.075240067073274, 54.77900014604841, 48.92433336802891, 48.22109924043928, 43.87890590940203, 40.58122485024588, 40.220846108027864, 41.73614747183663, 40.009992599487305, 41.498439175742014, 42.00487947463989, 43.0669845853533, 40.53661741529192, 40.67571340288435, 39.99529021126883, 39.71126869746617, 40.00901985168457, 39.487633977617534, 38.25959198815482, 39.02187885556902, 38.09288733346121, 38.96480982644217, 40.85146113804409, 43.685693877083914, 49.64246095929827, 51.50681550162179, 53.120836871010916, 52.24995313371931, 53.08560255595616, 47.87813268389021, 43.87751279558454, 40.61655644008091, 40.4044314111982, 39.942977224077495, 42.74861465181623, 49.17787313461304, 49.59997967311314, 48.297122955322266, 52.69224418912615, 49.43904897144863, 56.08601883479527, 39.31605863571167, 39.110746315547395, 55.07154015132359, 49.74823338644845, 49.266744068690706, 40.648636272975374, 46.73848220280239, 49.85496466500418, 51.86753470557076, 48.74779006413051, 48.20457295009068, 42.82036175046648, 48.94177334649222, 48.8550181388855, 50.05551399503435, 50.13972268785749, 47.47802414212908, 50.69859756742205, 45.32915823800223, 43.85048082896641, 44.65373427527291, 43.424135889325825, 48.17544262749808, 49.08683436257498, 49.67292881011963, 44.78269631522042, 40.609062807900564, 38.405420780181885, 40.290453161512104, 39.105618544987266, 40.707240853990825, 37.65533494949341, 39.78671571186611, 40.10302550452096, 43.1024169240679, 40.5151162147522, 42.13242755617414, 42.601312841687886, 48.7782301221575, 53.885923862457275, 55.2553825378418, 54.352849755968364, 56.83656324659075, 54.23488324029105, 54.89761284419468, 55.41423920222691, 56.08838469641549, 55.93410689490182, 55.20225313731602, 54.79910475867135, 55.52671316691807, 52.320960249219624, 49.17339849472046, 47.037622996738975, 52.48155396325247, 55.02739129747663, 59.99875790732247, 54.881399222782676, 49.513776847294395, 2.6776387989521027, 0.4317933315677302, 1.0289218170302254, 0.10007991189403193, 0.04338753416336008, 0.8577163581337247, 46.18765333720616, 50.196447781154085, 38.9338173866272, 59.49561105455671, 30.98206615447998, 24.60975684438433, 33.22160952431815, 44.25777380807059, 47.27953495298113, 47.076289721897666, 5.938504176480429, 0.21604359575680324, 0.03229793779818075, 0.05454274147216763, 0.022716036066412926, 0.04431290665109243, 0.014713863941973873, 0.08468867492462907, 0.015173462851505195, 0.02707746408746711, 0.01750951642835779, 0.03351886996201106, 0.08606441824563912, 0.03362138642530356, 0.030506547673472335, 0.024326571163588336, 0.051176339254847596, 0.023102197130875926, 0.032533267313348394, 0.011089875412705754, 0.03126385721511074, 0.009619621493454491, 0.07199665704475981, 0.010713274058486735, 0.10960200415658099, 0.2238428265388523, 4.948303801672799, 73.3937383379255, 64.6154398236956, 59.04791777474539, 44.41838141850063, 33.776252950940815, 18.962521587099346, 47.51283114297049, 40.84332479749407, 53.20890528815133, 67.02827821459088, 5.67593435730253, 0.07204899245074817, 0.3001781111317021, 1.9576204291411807, 4.289665383952005, 11.054622173309326, 8.13419703074864, 2.496980424438204, 34.243109362465994, 71.50518321990967, 66.49513598850795, 59.80015059879848, 59.06963784354073, 61.86844171796526, 65.88981587546212, 64.4430411202567, 64.57830170222691, 61.607654980250764, 62.00041580200195, 59.59504672459194, 59.6193584714617, 56.270844391414094, 57.30322858265468, 57.76529768535069, 55.981080191476, 51.78132493155343, 49.26933922086443, 44.76331778935024, 44.04885884693691, 42.465968881334575, 43.47915519986834, 41.3439598764692, 42.72636999402727, 43.93197277614048, 43.49575444630214, 43.14587443215506, 42.702103410448345, 40.835973603384836, 44.380635329655235, 41.54789297921317, 42.908878326416016, 40.62040226800101, 43.139815602983745, 41.25273697716849, 41.271497113364084, 41.789832728249685, 46.42156791687012, 51.765663691929404, 53.68689618791853, 55.27963522502354, 55.076348304748535, 55.7744094984872, 51.245469433920725, 45.60013798304966, 41.55108567646572, 43.84786135809762, 42.419871057782856, 45.406238079071045, 51.10662358147757, 53.51401458467756, 49.85515921456473, 54.48014770235334, 50.007290022713796, 58.81992653438023, 40.77063274383545, 40.547168254852295, 58.65676198686872, 51.448822362082346, 52.39059509549822, 42.250209944588796, 48.52874115535191, 51.12800318854195, 52.08084787641253, 51.94832141058785, 49.91422585078648, 44.0130478313991, 50.24098226002285, 50.0985163961138, 51.189637184143066, 51.924023560115266, 50.47811385563442, 52.10397842952183, 48.46369212014334, 44.85916818891253, 47.11534207207816, 46.228949955531526, 51.40203666687012, 50.16920389447893, 50.68890135628836, 46.66193042482649, 41.39175306047712, 40.790883268628804, 43.427418913160054, 41.244638851710725, 42.46745579583304, 39.28895718710763, 41.15159552437918, 41.87270736694336, 44.902410302843364, 41.899218218667166, 42.793190819876536, 44.10324934550694, 50.41852610451834, 53.89773580006191, 57.977693693978445, 55.85702705383301, 59.89099134717669, 55.24923685618809, 57.112799303872244, 57.4449405670166, 58.87037740434919, 57.520696776253835, 58.47526809147426, 54.81241750717163, 57.74545015607561, 53.371871812003, 51.596843310764854, 48.68542650767735, 54.63026353291103, 56.92976638248989, 62.615602357046946, 55.86896058491298, 57.35821315220424, 3.974074729851314, 0.23090014713151114, 1.8328848481178284, 0.664848153080259, 0.016921326651104858, 0.7877578235098294, 47.83432081767491, 56.90794209071568, 41.23368501663208, 61.870734623500276, 26.907130071095057, 18.915647302355083, 40.68067441667829, 49.708024161202566, 52.67514814649309, 54.59204496656145, 12.544392381395612, 0.3335768532540117, 0.030518204905092716, 0.03348020025129829, 0.019590851351884857, 0.009411836259200104, 0.059924860884036334, 0.04549084683614118, 0.011220272879914513, 0.007138076437903302, 0.049937558227351735, 0.011592816594722015, 0.03476068404104028, 0.01902311940544418, 0.11220388739768948, 0.0879571306120072, 0.13004067992525442, 0.13857021794787475, 0.15626444348267146, 0.15473361419779913, 0.14892706434641564, 0.1243791872901576, 0.1766717370067324, 0.10930355731397867, 0.23847742910896028, 0.5732792552028383, 6.049520756517138, 84.26790537152971, 73.30605207170758, 68.2424064363752, 53.515741212027415, 33.09343263081142, 24.666118894304546, 64.50656155177525, 52.77871799468994, 60.4518985748291, 71.91575227464948, 6.882894209453037, 0.17819126189819404, 0.698574926171984, 2.760678240231105, 7.899183767182486, 16.237253972462245, 8.321266855512347, 3.3911160911832536, 42.37854664666312, 71.62654045649937, 70.32078633989606, 59.7765406199864, 62.79920155661446, 62.91562557220459, 68.63577175140381, 65.63893032073975, 68.2455609185355, 64.01990972246442, 63.26474475860596, 60.617633955819265, 64.48593235015869, 58.39388384137835, 60.765401295253206, 60.734822273254395, 59.32868753160749, 53.30993209566389, 52.791721548352925, 47.273364952632356, 46.34050675800869, 45.32694523675101, 45.87529706954956, 44.05349676949637, 44.81079830442156, 46.59484209333147, 46.59772212164742, 45.73904289518084, 44.54854202270508, 42.80391189030239, 44.346019404275076, 43.99830722808838, 43.49323919841221, 42.46539912905012, 45.913605962480815, 42.71730954306466, 43.82985510144915, 45.21309552873884, 47.487668241773335, 54.20649984904698, 56.573299476078574, 58.00599023274013, 56.9525807925633, 58.391403334481375, 53.579883507319856, 47.29648855754307, 44.42989805766514, 45.8780311856951, 44.11830261775425, 47.7799129486084, 55.32849843161446, 54.379958152770996, 53.392556599208284, 59.23538017272949, 52.52438265936715, 61.32820538112095, 43.54507623400007, 42.98256744657244, 60.8536434173584, 55.909162861960276, 54.89378091267177, 45.31349005017962, 50.58299691336495, 54.32770422526768, 55.50675446646554, 55.413850103105815, 52.65389708110264, 47.30402735301426, 53.379139627729145, 52.48051173346383, 52.890326908656526, 54.774636677333284, 52.06394638334002, 53.35218409129551, 50.20286096845354, 47.42348773138863, 48.68930012839181, 48.54810231072562, 53.15678685052054, 52.238561562129426, 53.41357837404524, 50.73655210222517, 44.1884377343314, 41.86710017068045, 45.275570256369456, 42.89745201383318, 44.840567861284526, 41.15207495008196, 44.2837427003043, 44.734663418361116, 47.22481788907732, 43.72425637926374, 45.277592182159424, 47.77601848329817, 52.14754016058785, 57.160067898886545, 61.94198145185198, 58.5780736378261, 62.32787050519671, 58.80271584647042, 59.8354127066476, 59.9696866444179, 61.83285999298096, 59.87742151532854, 60.339205741882324, 58.69343457903181, 61.541188512529644, 56.97974477495466, 53.62543589728219, 50.95677873066494, 58.06778056280953, 59.7396456854684, 66.32258442470005, 59.47173009599958, 59.4115309034075, 4.88517507484981, 1.5169942272560937, 4.687858394214085, 0.43400739133358, 0.15136858262121677, 1.4844921827316284, 56.099595614842, 60.8037622996739, 49.92791380201067, 66.15365982055664, 44.10070630482265, 38.428617341177805, 45.31028345652989, 60.08590221405029, 58.74290575299944, 64.71432658604213, 15.369938135147095, 0.5347848236560822, 0.2504105530679226, 0.09100671804377011, 0.12544994269098553, 0.1521830689162016, 0.15058753453195095, 0.1342898697725364, 0.08016444090753794, 0.11154638017926898, 0.0908796623615282, 0.0924364048987627, 0.12691947312227317, 0.12676421073930605], [0.0023342395558886763, 0.03211775960932885, 0.05685259002660002, 0.029303908813744783, 0.07813245922859226, 0.07848217617720366, 0.045376069245061705, 0.05371657758951187, 0.008942926152875381, 0.07825026647852999, 0.13882162874298437, 0.3211510314473084, 12.822436707360403, 69.98768969944545, 57.75953762871878, 52.59720325469971, 35.89735732759748, 28.9915931224823, 56.834930419921875, 56.021574292864116, 32.54386486325945, 70.15880298614502, 41.2079210962568, 0.6472047769597599, 0.03341966474960957, 0.15789021338735307, 0.4848456233739853, 1.9031465521880557, 1.0976683795452118, 0.3179566514279161, 0.37388319043176516, 53.83434043611799, 66.37346608298165, 59.95122528076172, 57.65820510046822, 49.49241461072649, 53.18611519677298, 58.765674999782014, 59.880888666425435, 60.45011983598982, 57.994980812072754, 60.66053908211844, 59.983464922223774, 59.14280237470354, 58.10878535679409, 57.13534273420061, 56.32753126961844, 55.18994092941284, 53.00197751181466, 51.37608861923218, 45.363610880715505, 42.0620562008449, 41.10887105124337, 40.02738741465977, 40.439703941345215, 41.167798723493306, 41.2835487638201, 38.65760564804077, 41.53622347967965, 39.888169833592, 39.46665736607143, 39.441536154065815, 40.960989066532676, 38.31582375935146, 39.8072441646031, 39.742351463862825, 39.90735033580235, 37.59267609460013, 43.15163796288626, 45.73655196598598, 49.30073813029698, 51.89241967882429, 52.41071360451834, 51.99772310256958, 50.34272125789097, 48.332374640873496, 41.49056339263916, 37.43051208768572, 38.5354528427124, 42.57682391575405, 50.21524960654122, 49.8933812550136, 54.44050822939192, 49.75789485658918, 52.79598426818848, 48.44124596459525, 58.05488123212542, 37.751564025878906, 37.75152233668736, 56.13770995821272, 46.25119113922119, 46.41533538273403, 40.11496945789882, 42.72593225751604, 43.662455626896445, 50.55840029035296, 47.10934230259487, 47.45352826799665, 39.72262552806309, 46.38151502609253, 49.81346654891968, 50.856144496372764, 46.544679573604036, 51.43477657863072, 49.21245779309954, 51.0759333883013, 47.171952520098, 43.12043360301426, 44.01031024115426, 44.81201771327427, 45.63303075517927, 45.43331173488072, 41.108568804604666, 38.0826804297311, 36.888076645987375, 39.46111617769514, 39.71649374280657, 39.72455365317208, 40.640680585588726, 39.815936361040386, 42.048965794699534, 41.77974394389561, 39.26933894838606, 40.77408947263445, 40.768631662641255, 46.74551377977644, 50.94176367350987, 55.56115886143276, 54.89140810285296, 52.20269843510219, 52.36275366374424, 54.33374915804182, 52.019140924726216, 53.5644793510437, 50.567849840436665, 48.33791582924979, 42.36665480477469, 42.45602600915091, 41.57137441635132, 45.73756987707955, 47.76856306621006, 53.32027448926653, 56.71254832404, 59.26279081617083, 58.65645626613072, 52.77892991474697, 23.622928517205374, 0.033824672124215534, 0.31106957527143614, 1.0381947308778763, 0.06788589512663228, 0.02476168004795909, 20.192271096365793, 62.385151454380576, 42.98911959784371, 39.760215282440186, 38.50376558303833, 33.97006252833775, 22.99403316634042, 35.46037817001343, 44.39581366947719, 49.261651039123535, 25.15437228339059, 0.3508780305939061, 0.04856525847156133, 0.025638167480272905, 0.013411869743971952, 0.068480135739914, 0.032089264531220706, 0.09127854595759086, 0.02511044535120683, 0.009981979549463307, 0.06133381849420922, 0.04476503828274352, 0.04298925107078893, 0.022823948579441224, 0.1515965296753815, 0.040609635545739105, 0.04474007837208254, 0.041263895974095376, 0.09238180997116224, 0.036581739716764004, 0.057997237890958786, 0.11895769249115672, 0.10599915962666273, 0.11038257727133376, 0.11738802386181695, 0.3755117016179221, 17.371401480266027, 80.73829691750663, 64.73958328792027, 62.004258155822754, 41.40481914792742, 37.05581658227103, 50.516690254211426, 50.15766641071865, 36.14831236430577, 77.99307755061558, 43.249142033713206, 0.6005457235234124, 0.1293422502598592, 0.7301802188158035, 2.0221698454448154, 4.406514108181, 2.2016018629074097, 0.3188712080674512, 1.3494715307440077, 58.70208508627755, 69.94087273733956, 63.39188289642334, 59.27321311405727, 51.36406128747122, 55.1041202545166, 60.836189542497905, 61.83039338248116, 63.220734868730815, 57.927367891584126, 61.70842470441546, 61.5367625100272, 61.850161007472444, 60.18353830065046, 58.931090763636995, 58.842612402779714, 56.76677206584385, 56.198058537074495, 52.85488414764404, 47.829113142830984, 43.20478820800781, 41.5563246182033, 42.286111286708284, 40.86616005216326, 44.09954595565796, 42.01964092254639, 41.00699656350272, 43.78575488499233, 43.54567377907889, 40.27681384767805, 42.81503248214722, 42.50818266187395, 41.711196490696494, 42.363281454358784, 41.05814920152937, 42.40164245877947, 39.798159394945415, 44.460233892713276, 47.95952388218471, 51.52054861613682, 54.414660930633545, 54.81194155556815, 55.528679507119314, 52.78572872706822, 50.51941047395979, 44.23912136895316, 39.39572320665632, 41.22025762285505, 44.36509568350655, 52.9185574395316, 52.49656902040754, 55.89034366607666, 53.26096814019339, 54.87528133392334, 49.967893736703054, 60.53777830941336, 38.39248323440552, 39.208889620644705, 57.346696513039724, 48.85122789655413, 46.737672737666536, 43.027643884931294, 45.705194745744976, 43.99420084272112, 51.89468479156494, 48.53572756903512, 48.93122945513044, 40.63143253326416, 47.672844682421, 51.943693910326274, 53.16548252105713, 47.891876220703125, 52.86135639463152, 51.345078808920725, 52.771603039332796, 49.79001290457589, 46.3276560647147, 46.43374810900007, 46.829993452344624, 48.49344778060913, 47.268699237278526, 42.98837266649519, 40.17241021565029, 39.60880013874599, 40.97017111097063, 41.804281507219585, 41.167572907039094, 40.839322635105674, 41.225618158067974, 42.378525802067344, 44.94268206187657, 41.657320158822195, 42.40080172674996, 41.739350591387065, 47.85193450110299, 53.71324028287615, 56.96337481907436, 56.550387791224885, 54.399301937648225, 55.63464995792934, 56.92530563899449, 53.886747223990305, 55.17542961665562, 50.66160535812378, 49.461033071790425, 46.992098399571006, 45.366199084690635, 44.325327668871196, 48.07518707002912, 50.96617616925921, 56.11637898853847, 58.35039506639753, 61.51652935573033, 60.09590762002127, 56.69186353683472, 27.926927600588115, 0.05591406074485608, 0.6230056126202855, 1.5621331994022642, 0.14113596241389, 0.036307560679103644, 18.843384299959453, 67.11595753261021, 47.95127637045724, 42.97781835283552, 38.20615686689104, 34.42596163068499, 29.700074877057755, 41.58597258159092, 49.948334557669504, 57.10140078408377, 36.79959828513009, 0.4708874523639679, 0.06123579732541527, 0.06163687937493835, 0.013451339277837957, 0.14803073315748147, 0.03843516151287726, 0.06309247269694294, 0.07353721652179956, 0.011557537014596164, 0.04087259839954121, 0.09501958092940704, 0.017770187530134405, 0.03776270956067102, 0.24105613359383174, 0.11540011981768267, 0.12989799758153303, 0.08954778632947377, 0.18653471847730024, 0.19514363152640207, 0.16795112352286065, 0.24265237365450176, 0.16842809292886937, 0.17912544177046844, 0.28576548450759476, 0.482269144483975, 21.687440054757253, 92.91888509477887, 73.18111651284354, 68.99696690695626, 47.78779220581055, 37.208555357796804, 66.96964236668178, 69.29897730691093, 45.163224833352224, 82.50839914594377, 49.57216950825283, 1.0571634215967995, 0.11089201457798481, 0.9055758757250649, 1.838920227118901, 5.8825008273124695, 2.73646485379764, 1.081500681383269, 3.3944566547870636, 65.02733598436627, 69.84555040087018, 65.77983283996582, 61.79538835797991, 55.92157929284232, 57.364817414964946, 64.44014372144426, 63.31912136077881, 65.27137756347656, 58.16090032032558, 65.79181153433663, 65.14949226379395, 63.33787454877581, 63.25170298985073, 61.54816450391497, 61.30498450142996, 59.71025480542864, 58.37465817587716, 56.62666164125715, 50.11002261298043, 46.20446102959769, 44.04854965209961, 43.81211287634713, 43.53946903773716, 47.194617543901714, 45.10761840002877, 42.38164554323469, 45.140389578683035, 44.05842304229736, 42.70741530827114, 45.006824357169016, 44.820355551583425, 42.38930940628052, 44.51015669958932, 44.239583424159456, 45.01475919995989, 41.78856815610613, 47.34986114501953, 50.73625332968575, 53.91592270987374, 58.49988555908203, 57.21944372994559, 55.71516220910208, 54.76857437406267, 54.26731048311506, 47.71677119391305, 42.547947202410015, 43.81116097314017, 47.781059401375906, 54.59936836787632, 54.79800346919468, 59.75111716134207, 56.18736178534371, 58.096837929316926, 53.56541040965489, 62.417488370622905, 43.42917333330427, 43.20165804454258, 59.68656839643206, 51.252980436597554, 49.76809828622, 44.63001312528338, 47.21154335566929, 46.426640101841514, 54.97248315811157, 51.90812955583845, 52.22102778298514, 43.01677690233503, 50.55119153431484, 53.56529229027884, 54.208118779318674, 49.20336607524327, 53.8995110648019, 53.39052772521973, 56.71667902810233, 50.91905001231602, 49.25832632609776, 47.9468538420541, 48.50022227423531, 50.5663594518389, 50.455994265420095, 44.968001297542024, 42.12433985301426, 41.48478943961007, 43.27475309371948, 44.0280350957598, 43.48981026240757, 44.06603479385376, 43.45403398786272, 45.458245345524375, 46.91838148662022, 43.47646277291434, 45.738862242017476, 42.94933768681118, 49.85345343181065, 55.52185985020229, 59.01054341452462, 58.76044300624302, 56.36052826472691, 56.78965943200247, 59.64367716653006, 57.42021540233067, 58.32502024514334, 54.058902740478516, 51.80082505089896, 48.79194586617606, 46.24123784473964, 46.326655524117605, 50.88656370980399, 51.73296546936035, 58.71137482779366, 61.79845251355852, 64.61764240264893, 62.51670169830322, 56.34817436763218, 32.00161354882376, 0.14025573964629853, 2.8770970446722846, 2.4716323103223528, 0.1654624334935631, 0.17233863951904432, 23.583982127053396, 75.37635816846574, 54.711164883204866, 49.30527530397688, 45.881071022578645, 43.79156010491507, 32.99239540100098, 50.98614876610892, 58.133017199380056, 65.50995091029576, 41.7917434828622, 0.7042976362364632, 0.28854620243821827, 0.15147319915039198, 0.08611294028482266, 0.19612517314297812, 0.09892834975783314, 0.14062236568757466, 0.13715631381741591, 0.06718658336571284, 0.14061781950294971, 0.28771068155765533, 0.11494265150810991, 0.14878279423075064], [0.053109132684767246, 0.030433527127440487, 0.07334023780588593, 0.05653704749420285, 0.05287437653169036, 0.07339093794247933, 0.05696740493710552, 0.0860992678041969, 0.11763612340603556, 0.05939476218606744, 0.12690079983855995, 0.052283060404339006, 29.088353736060007, 72.6804084777832, 54.126192569732666, 47.80411352430071, 33.5460660798209, 24.504253659929546, 25.20318337849208, 36.40763303211757, 43.08269446236746, 65.62686824798584, 19.984389679772512, 0.05941187483923776, 0.07702671856220279, 0.5357645196574075, 2.653051946844373, 2.162925583975656, 2.5899935705321173, 0.9874904687915529, 11.22883869920458, 68.68060847691127, 62.57219001225063, 63.398497581481934, 59.32885428837368, 53.353250639779226, 45.908502510615754, 51.416065079825266, 58.52659443446568, 61.197058132716585, 61.66443565913609, 59.278326988220215, 55.48452023097447, 57.744758810315815, 57.870899881635395, 56.993005411965505, 55.928558758326936, 58.32000364576067, 55.094003677368164, 53.83260338647025, 52.20511293411255, 44.245843751089915, 39.81964669908796, 40.942322731018066, 40.69510929925101, 41.74981457846505, 40.9062511580331, 40.110870020730154, 39.83953244345528, 39.458333424159456, 40.893209389277864, 39.75606025968279, 38.86997038977486, 39.998580183301655, 39.244982038225444, 39.01149129867554, 38.05975137438093, 38.86168466295515, 43.298936298915315, 44.038384437561035, 51.03643635341099, 48.87996564592634, 53.074537549700054, 52.30488211768014, 49.422599111284526, 42.554172788347515, 40.09562567302159, 36.71483721051897, 39.33619451522827, 47.26735823495047, 52.35259887150356, 50.21416221346174, 54.68601587840489, 51.39956658227103, 53.29217597416469, 48.24794013159615, 55.198699133736746, 32.187012331826345, 37.005101680755615, 55.27042886189052, 44.26074416296822, 45.130828857421875, 41.414084570748464, 45.550798824855256, 40.52217558452061, 40.20733186176845, 40.12003469467163, 41.784816128867014, 38.344700472695486, 43.52058383396694, 46.40669182368687, 50.01296670096261, 51.869768551417756, 49.284597464970176, 40.44286189760481, 41.162771701812744, 47.07739795957293, 51.90810176304409, 44.91550070898873, 45.26783343723842, 44.89280789239066, 43.85438919067383, 41.13939101355416, 38.62059954234532, 38.26493862697056, 39.881537778036936, 40.370308807918, 40.41793523515974, 39.41186734608242, 40.824498653411865, 40.60455690111433, 40.64541230882917, 40.46100017002651, 42.19979728971209, 41.1098507472447, 41.54975162233625, 44.07931627546038, 47.10157421657017, 48.44617223739624, 50.42859751837594, 49.143938132694785, 49.16766275678362, 45.955211775643484, 44.620382922036306, 42.69685752051217, 40.63975300107683, 41.049356256212505, 44.152237619672505, 48.98148577553885, 51.08715125492641, 55.603379590170725, 57.09928853171212, 57.33271326337542, 57.39022350311279, 58.40958677019392, 52.67343888963972, 43.96689442225865, 14.883072648729597, 1.295088957462992, 1.5574349143675394, 0.07426497925605093, 0.10773515754512378, 2.715096103293555, 51.14062806538173, 53.67544903073992, 31.19454206739153, 32.94933046613421, 26.700481959751674, 10.7544104882649, 31.655200685773575, 46.62530994415283, 45.342259066445486, 41.49781731196812, 2.1577381023338864, 0.063508326453822, 0.08286748693457671, 0.0621580621227622, 0.07968831288495234, 0.04316655905651195, 0.013075235798688871, 0.05383185390383005, 0.08420825856072561, 0.023201714469385997, 0.012011677958071232, 0.002419269535624023, 0.041324003998722346, 0.0068303421472332305, 0.027945939717548232, 0.013588338890778167, 0.04422312629009996, 0.03238870542762535, 0.036125146717365296, 0.012933363456145992, 0.027708776461492692, 0.0448234363991235, 0.03245566665594067, 0.14436070009001664, 0.15136403643659183, 37.35134778703962, 82.02338709150041, 61.097671100071494, 53.794475146702354, 41.982353414808, 29.97362892968314, 25.435774326324463, 43.57497085843767, 47.72789525985718, 73.38932623182023, 21.015483243124827, 0.04340726596170238, 0.10787543108952896, 1.599334180355072, 4.546613676207406, 2.2517003289290836, 0.18540278635919094, 0.8151026219129562, 14.840096303394862, 72.20939009530204, 67.22580855233329, 66.45890808105469, 60.21670205252511, 57.88817310333252, 47.94663149969918, 53.669383253370015, 60.18817274911063, 62.77405602591378, 63.332503591264995, 59.20384924752371, 56.94242252622332, 60.701526505606516, 59.774219921657014, 58.92098113468715, 57.80623994554792, 57.83214977809361, 58.14566986901419, 56.01075594765799, 55.24351848874773, 46.764899253845215, 41.17754009791783, 42.41693196977888, 43.189853055136545, 44.49375895091465, 42.96296310424805, 42.05184234891619, 42.05716814313616, 42.013071400778635, 42.05023384094238, 41.5429493359157, 42.50979464394705, 42.3820207459586, 41.269610677446636, 41.32361902509417, 40.58738095419747, 41.67395067214966, 44.62763336726597, 48.075350352696006, 52.378275939396445, 51.7808107648577, 54.62586184910366, 54.4764860016959, 51.938705103737966, 43.54779992784773, 42.300629547664094, 38.16882766996111, 41.820224148886545, 49.58735827037266, 53.989167145320344, 53.591896942683626, 56.61282777786255, 51.03530032294137, 54.649673325674875, 50.38316672188895, 58.726181438991, 33.5169392313276, 39.51680598940168, 57.52178764343262, 46.29547200884138, 47.29436935697283, 43.74467713492257, 46.2214389528547, 41.094641140529085, 43.431320326668875, 42.777376719883506, 45.16297122410366, 40.41759477342878, 45.991630758558, 48.8074438231332, 50.86105687277657, 52.26500640596662, 49.910088198525564, 45.83058193751744, 44.35639306477138, 47.03943647657122, 53.40718603134155, 47.73117133549282, 46.710036277770996, 45.54842601503645, 46.46392413548061, 43.162994793483186, 39.295422485896516, 41.40156044278826, 41.2597199167524, 41.15513563156128, 42.50998224530901, 41.376182147434776, 42.42220565250942, 40.88263423102242, 43.23480790002005, 41.781824929373606, 44.206850460597444, 42.89179618018014, 43.42316314152309, 44.64908593041556, 48.354355267116, 50.54754025595528, 52.00887843540737, 50.28587804521833, 49.58501672744751, 47.94998747961861, 46.388011591775076, 44.719641413007466, 42.392884254455566, 42.34617151532854, 45.23048339571272, 51.41447046824864, 53.490220478602815, 57.99400806427002, 58.938011169433594, 60.32271766662598, 59.220351219177246, 59.689146178109304, 53.85142258235386, 50.60351494380406, 19.94110413960048, 1.6517267461333955, 1.0702984482049942, 0.4170917575912816, 0.03548131537224565, 2.721356213092804, 51.66362244742257, 59.52922643933977, 35.9968763760158, 38.04856824874878, 33.59134749003819, 14.461575814655848, 37.643300669533865, 51.747049467904226, 49.904147488730295, 52.71688597542899, 4.482835727078574, 0.1814033245401723, 0.09321300179830619, 0.06151838001928159, 0.07731118079807077, 0.071271425246128, 0.024844915938696692, 0.044616205019078085, 0.05058122333139181, 0.08407389505633286, 0.03471913734184844, 0.0028513784470435765, 0.0220212365633675, 0.1330555331494127, 0.07952250606779541, 0.25779901232038227, 0.13645928193415913, 0.18751839069383486, 0.14950497262179852, 0.1519286454256092, 0.13937433622777462, 0.14374098048678466, 0.1150014940649271, 0.30195039031761034, 0.17217515329165117, 44.580944946834016, 92.08132144383022, 68.62258407047817, 63.380661555698936, 45.761002676827566, 32.242681298937114, 36.55888489314488, 52.297155720846995, 55.90446935381208, 76.68134103502545, 24.92292431422642, 0.14839398009436472, 0.3898577775274004, 1.7045400036232812, 9.3354971408844, 8.44200222832816, 6.989265484469278, 2.51786128112248, 19.23832859311785, 72.63150705610002, 67.99386242457798, 69.82324668339321, 64.13656997680664, 58.97120271410261, 50.43650804247175, 56.50344576154436, 62.51358890533447, 66.22406591687883, 65.73785877227783, 61.89963912963867, 57.281449454171316, 62.27373708997454, 61.38197749001639, 59.146234784807476, 59.88754504067557, 61.469003677368164, 60.125381878444124, 58.091084820883616, 56.927344935280935, 48.36287028448922, 44.00824315207345, 45.5880446434021, 45.74534491130284, 45.629028592790874, 46.15605640411377, 43.55884408950806, 43.699902943202424, 43.27752889905657, 44.370862688337056, 44.608984402247835, 44.31360953194754, 45.27800907407488, 43.899785246167866, 43.06036295209612, 43.0097279548645, 43.490584986550466, 46.8965676171439, 50.444279602595735, 54.37371172223772, 52.40109034946987, 57.37585462842669, 56.44859320776803, 52.91895696095058, 47.1040859903608, 45.24010665076119, 41.22451686859131, 44.00233718327114, 52.34831530707223, 56.53083903448922, 54.84916305541992, 58.00973183768136, 54.74010760443551, 56.40080349785941, 52.04887921469552, 61.768158367701936, 37.64282124383109, 41.042241300855366, 59.16738510131836, 48.45525353295462, 50.31609228679112, 45.85687044688633, 50.007811137608115, 44.84388215201241, 46.06519481113979, 45.63783196040562, 46.42674432482038, 43.271900858197895, 49.02334519795009, 50.82125064304897, 53.303452900477815, 53.99392318725586, 53.96802377700806, 47.70049851281302, 47.41544171742031, 51.01278815950666, 54.99340418406895, 49.85827200753348, 51.48258365903582, 47.18592882156372, 49.194489751543315, 46.23590510232108, 41.646241256168906, 43.05612107685634, 43.11482293265206, 43.56794622966221, 45.02002246039254, 42.938137190682546, 44.57938507625035, 44.41461549486433, 45.57770572389875, 45.02046019690377, 45.84535380772182, 46.026806013924734, 45.99315241404942, 45.7070985521589, 50.695738383701865, 53.31941638674055, 55.35326181139265, 53.90268291745867, 52.50714070456368, 49.897174971444265, 50.376468658447266, 47.35033362252371, 45.250650542122976, 44.673119749341694, 48.524909223829, 53.592807156699045, 55.140740735190256, 61.1241089957101, 61.08526856558663, 61.70368603297642, 62.82871750422886, 60.255340984889436, 54.57384763445173, 52.29709318705967, 23.488517352512904, 3.4215159799371446, 4.594835042953491, 0.5640440136194229, 0.2464822152895587, 3.545283372913088, 59.78404467446463, 64.08216558183942, 43.81815086092268, 42.01590973990304, 33.342379638126914, 21.477882385253906, 44.17973511559622, 59.62760598318917, 57.45198604038784, 62.78397110530308, 4.85326851265771, 0.3112779940877642, 0.25742777224097935, 0.17475233785808086, 0.2729460581072739, 0.1673508643039635, 0.1249644508851426, 0.08902689535170794, 0.15932121660028184, 0.15759895901594842, 0.12362694979778358, 0.09524568915367126, 0.14930034003087453], [0.04292130596669657, 0.03232304698654583, 0.0921049134007522, 0.04224527134959187, 0.04003613096262727, 0.008027951366135051, 0.020187046146020293, 0.0927192522212863, 0.0573037751019001, 0.061752053909003735, 0.040658428998930116, 0.12323258524494511, 43.55387960161482, 69.63498524257115, 53.515862805502756, 49.191925866263254, 18.496443373816355, 24.108133384159633, 34.5226423399789, 30.869877065931046, 54.065006732940674, 66.03077398027692, 8.010772705078125, 0.20355093825076306, 0.024789849429258277, 0.7373260610869953, 3.8484712753977095, 2.4363971267427718, 1.6669180052621024, 1.9439893662929535, 57.015316077641074, 59.90270601000105, 64.88671834128243, 64.09544358934674, 61.08471270969936, 57.38028757912772, 52.089748518807546, 43.02655301775251, 50.5855712209429, 55.83213513238089, 58.93882410866873, 59.314026832580566, 57.59367718015398, 54.93745034081595, 58.227300780160085, 54.49198395865304, 56.536196095602854, 53.99784891945975, 56.21756560461861, 54.5392039162772, 53.64409181049892, 51.03308732169015, 44.18932015555245, 38.5866436958313, 41.91430623190743, 41.037137848990305, 41.839946610586985, 40.19477646691458, 41.95795481545584, 40.225650787353516, 41.705992289951865, 38.62169735772269, 39.74837902614048, 39.18730851582119, 41.21013409750802, 35.86665323802403, 38.329393591199604, 42.771706989833284, 43.63978712899344, 44.75102990014212, 48.03902864456177, 51.36113262176514, 52.135478087833945, 48.29520525251116, 42.859664235796245, 38.2536894934518, 40.79362780707223, 35.69605411802019, 43.467780998774934, 51.123177664620535, 51.42674446105957, 47.49893127168928, 52.31570741108486, 50.76492507117135, 53.102844510759624, 47.235059533800396, 55.55982480730329, 33.06407996586391, 38.71757902417864, 54.42618104389736, 44.64147417885916, 44.49763257162911, 41.0796434538705, 44.87277970995222, 42.082452637808665, 42.5072238104684, 41.57982689993722, 41.984222480228965, 39.53190442493984, 41.86130884715489, 43.87744331359863, 50.53252867289952, 48.12984160014561, 45.29314225060599, 50.684214796338765, 50.659440994262695, 40.73204244886126, 44.43835401535034, 47.968441895076204, 47.73239769254412, 44.72059679031372, 41.46271848678589, 40.72861698695591, 38.51956231253487, 38.211458342415945, 40.034766401563374, 39.39398268290928, 39.60824080875942, 39.361871583121165, 40.09070634841919, 38.96420185906546, 42.336895670209614, 41.697845527103965, 42.07986443383353, 40.962121622903005, 42.81346913746425, 39.857021059308735, 42.754273959568565, 41.96878010886056, 43.03750685283116, 41.69255794797625, 42.0833454813276, 39.77669293539864, 40.04270471845354, 42.24416501181466, 48.32133047921317, 50.41405841282436, 53.22446230479649, 54.569828101566856, 56.31585829598563, 56.810670784541536, 57.37912722996303, 57.141606535230366, 58.482487269810264, 59.102655683244976, 56.07681247166225, 57.923490796770366, 35.577510901859824, 2.581625985247748, 1.3535421980278832, 0.3964471125176975, 0.06236907972821167, 0.0712907567088093, 26.36142029081072, 60.32651138305664, 40.66710458483015, 28.902548483439855, 29.547443798610143, 34.54835067476545, 30.67740501676287, 37.06284121104649, 46.61029141289847, 46.63157374518258, 12.239695634160723, 0.4289080378200327, 0.07012331685317413, 0.02575940133205482, 0.0693108525925449, 0.06663009644086872, 0.0966985004820994, 0.028287074894511273, 0.06455930934420653, 0.017370018110211407, 0.06858701857605151, 0.04586890619248152, 0.017500522446685603, 0.018420593879584755, 0.004220715973393193, 0.01666908634693495, 0.01397025487053075, 0.01802408685242491, 0.022229277096422653, 0.08963544626853295, 0.10205305780151061, 0.02197870598839862, 0.055413620812552314, 0.10379672995103256, 0.5561945576752935, 55.695964336395264, 75.22849355425153, 60.709551674979075, 53.14040994644165, 28.22604581287929, 25.008755411420548, 27.949740273611887, 36.82948248726981, 59.802749225071494, 71.0908899307251, 7.889384201594761, 0.20387812783675535, 0.221091041341424, 1.241195689354624, 2.2662403030054907, 0.4588859592165266, 0.4212586682822023, 4.189555738653455, 61.485964230128694, 63.214210510253906, 66.23774691990444, 64.36590221949986, 63.66229288918631, 60.191403661455425, 54.500763007572715, 44.671240261622835, 52.026488644736155, 58.57272352491106, 60.09191240583147, 60.804915700639995, 58.74569892883301, 55.02977105549404, 56.799376487731934, 55.83330242974417, 57.113049439021516, 56.31863062722342, 57.29939317703247, 56.76625442504883, 56.08487238202776, 54.63192762647356, 47.15944228853498, 41.42875221797398, 43.80533143452236, 43.21337618146624, 43.80672107424055, 42.006991727011545, 43.607179233006065, 42.03405843462263, 42.72756161008562, 40.08534928730556, 42.054058824266704, 41.40504843848092, 43.22346496582031, 38.42494869232178, 40.618547098977224, 43.51720353535244, 46.079792976379395, 47.35632644380842, 51.15651164736067, 52.03503492900303, 54.29468638556344, 50.36093596049717, 44.65550259181431, 39.28032752445766, 40.47135646002633, 37.99338565553938, 45.23085512433733, 52.875964982169016, 52.48819991520473, 49.650732789720806, 53.65445157459804, 52.58865697043282, 54.77077347891671, 49.4190867968968, 56.40280457905361, 33.983701842171804, 40.505715302058626, 56.99478415080479, 47.14465652193342, 46.40240478515625, 41.81204611914498, 47.340303897857666, 45.58724560056414, 46.586056096213206, 42.795539311000276, 43.78920119149344, 41.67936331885201, 43.37774971553257, 45.13139860970633, 53.018927642277305, 50.398685523441856, 47.108720438820974, 51.0656361579895, 52.907263142721995, 44.997579778943745, 45.927505833762034, 49.748959473201204, 49.60074397495815, 48.244598048073904, 44.94036136354719, 43.51571314675467, 40.29002237319946, 40.333337443215505, 40.79356527328491, 40.52422182900565, 42.00723838806152, 40.736979143960134, 42.81737749917166, 39.82040057863508, 44.76448161261422, 42.040099893297466, 42.48252991267613, 44.75792598724365, 45.2633171081543, 41.14453962871006, 44.17717123031616, 43.55675615583147, 45.52494805199759, 42.88817964281355, 44.292226450783865, 42.584692750658306, 42.04447725840977, 45.326573508126394, 50.85270166397095, 51.97499901907784, 55.424466950552805, 57.32585539136614, 59.850024768284385, 58.23960951396397, 59.42703233446394, 59.30072103227888, 58.517193521772114, 60.448445320129395, 58.34951959337507, 60.13483837672642, 41.685849462236675, 3.52727581347738, 0.21198932187897818, 0.9669866604464394, 0.19184402429631778, 0.14203028513916902, 28.116484880447388, 63.386449405125205, 48.17716925484793, 29.744730949401855, 28.648650884628296, 39.891035965510774, 32.35882043838501, 46.69495868682861, 52.60602051871163, 58.04791566303798, 17.295950991766794, 0.38475481420755386, 0.13013140005724771, 0.04610277346468397, 0.08299564862889902, 0.03642007535589593, 0.08604272548109293, 0.008821351337246597, 0.040987362419920306, 0.0348294535651803, 0.05771818357918944, 0.08883306503828083, 0.03166857960500887, 0.0643605732225946, 0.1066861084795424, 0.19149441591330937, 0.1160351743123361, 0.14031673994447502, 0.10157124365546874, 0.08928419583077941, 0.17844607893909725, 0.09802562676902328, 0.1467036000852074, 0.22440236008593015, 1.2876168212720325, 66.05034010750907, 84.64627647399902, 68.45766162872314, 62.548156193324495, 27.796212877546036, 35.19553368432181, 48.606696469443186, 42.36466761997768, 66.34552042824882, 78.21224457877022, 10.754208990505763, 0.3073445808674608, 0.4945210984774998, 2.7957358104842047, 8.408827185630798, 11.48564064502716, 7.752004419054304, 5.553174887384687, 66.56718185969761, 62.8518966947283, 70.25083187648228, 68.20442063467843, 65.28050054822648, 62.26157774244036, 57.46470819200788, 46.398479052952354, 54.15316200256348, 60.226075172424316, 64.84734984806606, 62.455390793936594, 60.998235430036274, 57.414365019117085, 60.358209065028596, 59.72809777941023, 59.508889062064036, 58.09766476494925, 59.96451718466622, 57.80544785090855, 60.03577790941511, 56.49759537833077, 49.721580096653526, 43.99884223937988, 45.5178713117327, 44.97397674833025, 46.15458686011178, 43.66536692210606, 46.82626574380057, 43.24442073277065, 46.81258126667568, 41.21569960457938, 44.55863775525774, 43.11182131086077, 44.65268857138497, 39.19047689437866, 42.895482199532644, 48.00202601296561, 46.93683590207781, 50.68320383344378, 53.597309589385986, 55.994441577366416, 57.15896660940987, 52.11739887510027, 46.81721224103655, 42.379891123090474, 45.00044938496181, 39.6072541645595, 47.40237215587071, 54.372624329158235, 53.45040035247803, 51.36230339322771, 57.00464711870466, 52.8344703401838, 57.66969742093767, 51.513881819588796, 57.46865129470825, 37.0144157409668, 43.66768067223685, 58.04598753792899, 48.37259428841727, 48.613682883126394, 45.63419457844326, 49.12858261380877, 47.99185732432774, 47.01687567574637, 46.191551276615684, 45.94691910062517, 44.71606656483242, 46.56113985606602, 48.70059789930071, 55.84566674913679, 54.2848025730678, 51.07051726749965, 53.04564693995884, 50.69408818653652, 48.62947266442435, 49.71164417266846, 51.185954638889854, 51.51015758514404, 49.57399688448225, 46.54600320543562, 44.74326181411743, 42.02383416039603, 42.17969267708914, 44.13138607570103, 42.80439131600516, 43.66745832988194, 43.75255986622402, 43.78462927682059, 41.77302156175886, 46.53480270930699, 45.43051855904715, 44.867071764809744, 47.03750140326363, 46.12910086768014, 44.02929271970476, 46.883786405835835, 46.229919229234966, 46.952490193503245, 45.58328512736729, 46.893090043749126, 44.50519915989467, 44.220778124673025, 47.63458442687988, 53.822844641549246, 54.97472047805786, 56.96257925033569, 60.371209144592285, 62.7615909576416, 62.555034909929546, 61.743916102818076, 62.64675807952881, 59.969957624162944, 60.70690441131592, 60.775865282331196, 62.42032323564802, 44.486102036067415, 5.29662264244897, 5.944793164730072, 2.0876650852816443, 0.2457482303891863, 0.33321980812719887, 31.656576429094585, 70.8186525617327, 52.3929956981114, 43.42093276977539, 37.794205120631624, 50.64222683225359, 40.71878528594971, 53.36448587690081, 58.71936525617327, 69.47790036882672, 21.598292929785593, 0.6571051999926567, 0.22709842398762703, 0.0816792364099196, 0.1901943971003805, 0.12638716240014347, 0.22342940872269018, 0.1294976890619312, 0.10057964614991631, 0.1359277447419507, 0.14188448153436184, 0.19652909146887915, 0.2580706977418491], [0.03525982457878334, 0.016064119791345935, 0.0329416164729212, 0.0520338039579136, 0.04580853693187237, 0.06387529176260744, 0.026046465749719312, 0.03505566356969731, 0.00845259299967438, 0.09081074355968408, 0.0870517206245235, 3.999285399913788, 62.16301754542759, 57.206245626722065, 51.47601066316877, 39.30703639984131, 21.966074977602275, 29.511139460972377, 36.76737254006522, 37.53404719488961, 63.72850227355957, 44.98761258806501, 0.9155588086162294, 0.05648131602044616, 0.2745995122407164, 2.3340697033064703, 3.7169449159077237, 1.5457266569137573, 3.3548718988895416, 57.46860613141741, 70.47243077414376, 62.07336493900844, 61.13423252105713, 58.999565260750906, 63.268267495291575, 58.009662355695454, 57.3905222756522, 48.020365783146445, 41.48319482803345, 49.10430213383266, 57.97832250595093, 56.58280461175101, 59.15683773585728, 57.60226515361241, 57.74806962694441, 56.861163343702046, 55.850989069257466, 53.909617219652446, 52.492017950330464, 52.647021838596885, 56.50005851473127, 50.10341835021973, 47.333845547267366, 41.50057922090803, 40.25465604237148, 42.592617171151296, 44.46050139835903, 38.74615696498326, 41.426973479134695, 40.98052045277187, 42.18476138796125, 39.59068965911865, 42.78096546445574, 39.07218728746687, 41.34206649235317, 40.04845782688686, 42.00651230130877, 40.48816762651716, 41.64624473026821, 41.02856029782976, 43.96037006378174, 43.715261936187744, 45.13550846917288, 38.967926093510215, 39.401795932224815, 37.93668140683855, 40.372594765254426, 37.544514656066895, 46.96015405654907, 51.073390347617014, 52.84503160204206, 48.74204042979649, 50.34343344824654, 48.377857548849924, 54.0424667767116, 48.62288229806082, 53.42196832384382, 31.51032727105277, 34.97000905445644, 53.845672948019846, 45.01141364233834, 42.57160234451294, 37.563920974731445, 43.63340520858765, 43.90946061270577, 45.97067846570696, 42.46774762017386, 43.120103563581196, 42.318416936056956, 41.394268308367046, 43.783965723855154, 46.591885634831016, 48.56166519437517, 49.826438835689, 49.16434499195644, 54.326526505606516, 56.69684192112514, 47.37807777949742, 48.83664015361241, 49.34057215281895, 46.846029894692556, 45.8555885042463, 41.14768368857247, 40.167327608381, 40.59394005366734, 40.32987724031721, 39.63885457175118, 39.64121348517281, 39.39404174259731, 40.79398216520037, 40.76483447211129, 40.84202895845686, 41.824365275246755, 41.7749079976763, 40.13131856918335, 42.205112661634175, 43.253453390938894, 43.84099653788975, 42.266295024326865, 40.82578754425049, 41.27857037952968, 42.413138253348215, 43.66874722072056, 47.97900315693447, 52.546033246176584, 53.88477046149117, 55.68685872214181, 54.84329182761056, 55.97577524185181, 55.49259403773716, 57.04705197470528, 55.82710116250174, 56.697251864842, 60.05343328203474, 55.975910731724326, 57.818882192884175, 56.94939851760864, 58.610320227486746, 12.811911055019923, 0.5087921012725148, 0.6612081112606185, 0.12588571145066194, 0.1483585469956909, 6.924441831452506, 60.02873938424246, 47.26150437763759, 43.37641218730381, 39.11871589933123, 27.277521167482647, 29.787246976579937, 28.22110911778041, 43.508323737553184, 47.8503155708313, 24.498266049793788, 0.8062025223459516, 0.08117858613176004, 0.04778817302680441, 0.05020879242303116, 0.045334234168486934, 0.034537656365760734, 0.0850639251459922, 0.0417494997382164, 0.049101084005087614, 0.013786899441454028, 0.05388959723391703, 0.06646306826067822, 0.043967067530112605, 0.04737086720498545, 0.008139178522729447, 0.03232739978869047, 0.01638111099600792, 0.06244682627064841, 0.025961504683696797, 0.08242677165461437, 0.02117307118273207, 0.06999743503651448, 0.09068306362522499, 6.381613382271357, 74.17210333687919, 63.8427653993879, 58.46629796709333, 44.11621815817696, 25.99909257888794, 29.414879117693218, 40.75378336225237, 44.2809773172651, 71.14671175820487, 49.742511544908794, 0.7699887827038765, 0.21365646884909698, 0.3664050559912409, 3.323783052819116, 1.4728864112070628, 0.37755876034498215, 5.290859111717769, 62.6278589793614, 70.96464116232735, 65.71647916521344, 63.26243795667376, 62.22644765036446, 64.8038193838937, 60.67647130148751, 58.871357100350515, 49.3636714390346, 44.479303223746165, 51.29756702695574, 59.78724084581648, 58.5205078125, 61.480544635227744, 59.81256702968052, 60.29045023236956, 58.349512645176475, 56.65104634421212, 55.08189296722412, 53.745872497558594, 54.13107715334211, 58.26374755586897, 53.53993831362043, 49.44188036237444, 42.86749138150896, 42.62348454339163, 43.60224601200649, 45.980760301862446, 42.2508213860648, 43.22824880055019, 42.79312481198992, 43.10075283050537, 42.94159739358084, 43.13574048451015, 40.10392182213919, 44.25726311547415, 41.855646065303254, 42.59109551565987, 42.81367063522339, 42.45170770372663, 44.00985166004726, 46.66797535760062, 46.13471848624093, 45.987489632197786, 39.915073258536204, 42.03079278128487, 39.55809565952846, 41.766035148075645, 39.397741658346995, 49.49654878888811, 52.615595136369976, 56.379118170057026, 50.78023542676653, 52.456422328948975, 50.130686555589946, 55.04820115225655, 50.72778000150408, 54.24126516069685, 32.849033219473704, 37.40959800992693, 54.93787070683071, 47.80560391289847, 44.03724840709141, 41.18761498587472, 45.96992111206055, 46.7784378187997, 47.46707378114973, 44.485289096832275, 45.02979162761143, 43.974506173815044, 43.39820173808506, 43.3836487361363, 49.011279651096885, 50.77197054454258, 52.961149896894185, 51.772420815059114, 54.88477604729788, 57.81115927015032, 50.525000299726216, 51.04353046417236, 51.90406138556344, 49.01062652042934, 48.4877849987575, 44.34304557527815, 42.135727950504844, 40.509265831538606, 41.65602779388428, 41.6746107510158, 41.04295001711164, 40.643974031720845, 42.9292573928833, 42.24661772591727, 42.69909484045846, 43.222370624542236, 43.57018007550921, 41.31176192419869, 43.28015879222325, 44.61389330455235, 46.196731158665244, 44.2569956098284, 41.77158328465053, 42.693039485386436, 44.35608039583479, 44.642342703683035, 50.28911590576172, 55.161276136125835, 56.112984793526785, 58.34410694667271, 57.37398208890642, 57.80224125725882, 58.05615970066616, 58.876415388924734, 55.8866993359157, 56.66309799466814, 63.285922867911204, 58.21467590332031, 58.977928570338655, 59.09076036725725, 62.020252908979145, 17.08856463432312, 0.24190052971243858, 0.6668474429420063, 0.39358046491231236, 0.20184776107115404, 6.926869358335223, 63.17740590231759, 53.19180577141898, 46.660453932625906, 33.5389198575701, 38.37034627369472, 33.484439032418386, 34.80097327913557, 48.24330220903669, 55.44471747534615, 34.09809003557478, 1.170743886913572, 0.07281862079565014, 0.03382836674739208, 0.07155026921204158, 0.025482326646202376, 0.054346695741904635, 0.07068079443914549, 0.03230440423690847, 0.029165789618023803, 0.023868889115484695, 0.009317889693193138, 0.02132581959345511, 0.17210463993251324, 0.13719480032367365, 0.14145055838993617, 0.11667994542845658, 0.13127546438149043, 0.13649460646722997, 0.16859478184155055, 0.2520156412252358, 0.19645895808935165, 0.22380104235240392, 0.2135726154914924, 7.698168039321899, 85.50339930398124, 72.2282405580793, 67.3459220613752, 52.73623670850481, 30.908991949898855, 38.82895169939314, 53.51607125146048, 52.449963978358674, 76.88827228546143, 54.98195702689034, 1.5253057926893234, 0.27636837161013056, 0.6923983033214296, 8.758479646274022, 12.558769072805132, 3.9922399265425543, 6.3023518068449835, 66.75439412253243, 74.2555512019566, 66.87991333007812, 65.58220522744315, 63.56077970777239, 66.24090835026333, 63.00680678231375, 60.66658401489258, 53.27674402509417, 46.39201028006417, 54.15980795451573, 62.55405521392822, 61.62777001517159, 63.92788083212716, 62.35890116010393, 61.836090905325754, 60.563035011291504, 57.34020689555577, 57.833674907684326, 54.60076148169381, 57.30684164592198, 61.35194042750767, 54.74936955315726, 51.972525460379465, 45.07379109518868, 44.68152012143816, 47.26777512686593, 48.43780313219343, 43.21191011156355, 45.245488030569895, 45.11490706035069, 45.68080309459141, 44.92150395257132, 45.50349201474871, 41.80559124265398, 46.228005000523154, 43.079213414873394, 46.11078194209507, 45.0101386478969, 44.3026556968689, 45.52062627247402, 48.85287809371948, 48.6259742464338, 49.84184646606445, 43.825592381613596, 43.74669558661324, 42.01029559544155, 43.87737383161272, 41.903814452035085, 51.65428754261562, 55.51845523289272, 58.84794167109898, 52.699661391122, 54.219472135816304, 52.03265169688633, 56.916283403124126, 52.56504699162075, 56.536300318581716, 34.608706201825825, 40.151544775281636, 56.81980766568865, 50.74970851625715, 45.28366143362862, 42.92661360331944, 48.54999222074236, 49.26209919793265, 48.68321003232683, 47.92289992741176, 47.99727691922869, 47.45691204071045, 46.37605026790074, 48.61861957822527, 51.29396786008562, 52.79013041087559, 55.44645799909319, 54.6859255518232, 58.26306315830776, 56.938750403267996, 53.657067571367534, 53.207703249795095, 53.83252348218645, 51.76577138900757, 51.53936433792114, 47.698292459760395, 44.011012009211946, 43.0831287247794, 44.04072598048619, 43.76437527792794, 42.580430030822754, 42.69046170370919, 45.10134070260184, 44.33777189254761, 43.67521251950945, 45.63204411097935, 46.11805670601981, 43.75998054231916, 44.95712736674717, 47.06554433277675, 48.82272638593401, 47.871920994349885, 45.29516765049526, 46.09395687920706, 46.22511454990932, 47.60858079365322, 51.77107286453247, 58.70230048043387, 58.42386531829834, 59.64815180642264, 60.074583598545615, 60.83843381064278, 59.097562653677805, 61.11506938934326, 55.59674058641706, 59.23693656921387, 62.296680041721885, 62.97804124014718, 61.37876047406878, 62.79524803161621, 63.73087855747768, 17.386590242385864, 1.2214002715689796, 3.552475626979555, 0.476801617869309, 0.23583640796797617, 8.47748407295772, 71.79875155857631, 57.4009758404323, 59.40360300881522, 49.771016529628206, 34.268511976514546, 41.1432055745806, 43.544186864580425, 59.75420910971505, 65.97930867331368, 42.15142045702253, 1.558580498610224, 0.16055636746542795, 0.15069500090820448, 0.12492205601717744, 0.15069520446871007, 0.1410809060824769, 0.19793971148984774, 0.12309155852666923, 0.10380055010318756, 0.08286811118679387, 0.10785721920962844, 0.13227445791874612], [0.027219922514632344, 0.028808072741542543, 0.10008219855704478, 0.05177462732951556, 0.012482266590398337, 0.01948765465723617, 0.021388394092874866, 0.08287556150129863, 0.024528477740074908, 0.1693575909095151, 0.249823158872979, 15.883953707558767, 71.9648551940918, 54.842426776885986, 50.400109904153005, 36.6051390511649, 15.691483395440237, 32.26732655933925, 33.770343508039204, 41.116284779139924, 71.2078628540039, 26.116369485855103, 0.03410565686811294, 0.07857858243265323, 0.2676287048629352, 1.1656280585697718, 0.23327151845608438, 5.087010255881718, 56.0620927129473, 69.4818399974278, 61.25129577091762, 63.68317222595215, 61.24717548915318, 58.37015574319022, 60.00043242318289, 62.307811055864605, 58.77162265777588, 52.8647540637425, 45.21103538785662, 41.63101775305611, 47.32987812587193, 53.786766120365684, 52.6024352482387, 55.60346644265311, 55.00716509137835, 57.18062761851719, 56.74178981781006, 53.82739223752703, 54.25755173819405, 51.638932023729595, 52.36703027997698, 52.2121445110866, 47.05764423097883, 41.555765288216726, 40.736138411930625, 41.08151599339077, 43.81340176718575, 43.17417097091675, 39.147620405469624, 39.96306446620396, 40.42124605178833, 43.5904757635934, 41.17622341428484, 39.9318323135376, 40.9060183933803, 39.96792125701904, 38.83992985316685, 38.132985387529644, 41.469232422964915, 39.28993340900966, 40.45916584559849, 37.40613433292934, 37.40365382603237, 38.97303996767317, 40.2911445072719, 38.98499434334891, 39.73755720683506, 39.357900687626426, 44.991798877716064, 49.64288132531302, 51.09335599626814, 51.20615652629307, 53.79526029314314, 51.55468511581421, 52.29669713973999, 50.02595983232771, 48.57466527393886, 30.818151201520646, 40.48804603304182, 53.77369655881609, 44.66787385940552, 41.291500977107454, 37.10298095430647, 41.05487659999302, 41.406146253858296, 42.799020358494346, 40.93955734797886, 44.59883655820574, 41.48417452403477, 42.937577860695974, 42.616077763693674, 43.43264743259975, 43.566956111363, 46.002761772700715, 45.865524428231375, 49.20122255597796, 50.148949895586284, 57.13623557771955, 47.361329146793906, 48.724673407418386, 45.70032058443342, 47.5461095401219, 42.74225010190691, 41.73747457776751, 38.81503793171474, 40.02363886151995, 37.611144406454905, 38.52941485813686, 40.21149730682373, 41.51750503267561, 39.644364493233816, 42.60236201967512, 40.353153705596924, 39.65860482624599, 38.593192373003276, 41.615825516836985, 40.13895116533552, 41.854558672223774, 40.02430588858468, 41.220354897635325, 44.01862028666905, 50.04884025028774, 53.48663173403059, 54.107738154275076, 55.05175862993513, 55.175047465733115, 53.45581994737898, 59.134228297642295, 56.8785651070731, 56.749512740543906, 57.19427388054984, 57.315919467381065, 57.15338373184204, 59.93610600062779, 58.54518781389509, 56.7500581741333, 55.01599277768816, 60.27286434173584, 49.22396748406546, 3.2124459871223996, 0.2977197787591389, 0.8860447066170829, 0.09744373549308095, 0.5623805714505059, 35.47890554155622, 61.94987460545131, 38.1479309626988, 34.08203969682966, 17.219671930585587, 28.35267152105059, 23.292246375765117, 35.9918806212289, 48.19274711608887, 36.34094074794224, 3.194352226597922, 0.21146836983306067, 0.07606106823576347, 0.04460880220202463, 0.026971833148439015, 0.04679065869588937, 0.07051821066332714, 0.017047936196572015, 0.06239469442516565, 0.01423191578526582, 0.009863082402651864, 0.012202191083425922, 0.04516426793166569, 0.05743577730442796, 0.02219262263471527, 0.054511566180735826, 0.01032263127022556, 0.016373184010652558, 0.05307751973824842, 0.0638643673488072, 0.030559307163847343, 0.11644408665597439, 0.25885980682713644, 21.488224778856548, 81.03519344329834, 58.09897797448294, 58.53317437853132, 43.864283425467356, 24.903722967420304, 27.297891548701696, 38.96651908329555, 47.45544944490705, 75.52732862745012, 27.558633123125347, 0.03458232432603836, 0.05609236617705651, 0.972788080573082, 2.2572402145181383, 0.17420077031212194, 6.828372997897012, 63.042061941964285, 72.47767393929618, 64.3598781313215, 63.86899484906878, 64.72539506639752, 60.059235027858186, 59.818528584071565, 64.07120132446289, 59.70830236162458, 55.468869413648335, 47.760923521859304, 44.03509793962751, 49.746214934757774, 56.786230495997835, 55.30153594698225, 57.13853890555245, 57.87991516930716, 57.051161834171836, 59.81902885437012, 56.04342637743269, 57.58947352000645, 51.77871240888323, 53.96663761138916, 52.90151003428868, 48.95621517726353, 43.71431698117937, 41.79372371946062, 43.22103657041277, 46.07366466522217, 44.729268142155235, 40.91108015605381, 41.07091999053955, 42.406773703438894, 45.12225825445992, 42.4699467250279, 40.937372139522004, 42.72008882250105, 42.749740259987966, 40.53283759525844, 39.80723026820591, 42.71137578146798, 40.833270754132954, 41.800105639866416, 39.454070704323904, 40.033411502838135, 42.347984995160786, 40.65828037261963, 40.72061613627842, 40.13393456595284, 41.62664386204311, 45.79294007165091, 52.03860282897949, 52.639469146728516, 54.320168903895784, 54.138650689806255, 55.09545932497297, 54.504938874925884, 50.32929386411394, 49.82396527699062, 33.62983703613281, 42.298392227717805, 54.76675394603184, 46.63683353151594, 44.18752057211739, 39.58374840872628, 43.29766477857317, 43.97975901194981, 46.430697849818635, 43.30531474522182, 46.742268971034456, 44.306230545043945, 46.162424428122385, 43.8873861857823, 43.842271532331196, 45.68345035825457, 48.25483274459839, 48.36033419200352, 51.24530267715454, 51.27282796587263, 55.77666766302926, 51.64744356700352, 51.82413625717163, 48.14151457377842, 48.35751322337559, 45.10273034232003, 43.163905007498606, 41.12077331542969, 42.21835592814854, 39.828165190560476, 40.614972250802175, 41.96545192173549, 42.00101627622332, 42.154227529253276, 44.14595297404698, 41.320933546338765, 42.91010120936802, 42.66546555927822, 43.19363634926932, 41.68666934967041, 42.18064110619681, 41.47960955756051, 43.698353494916645, 48.135556493486675, 52.45021063940865, 55.909298351832796, 57.78292873927525, 57.51975876944405, 57.83905281339373, 57.47190305164882, 58.4673957824707, 58.2495037487575, 56.00350897652762, 58.12070499147688, 59.57314600263323, 60.25674452100481, 60.82478754861014, 60.115369524274556, 58.96625559670584, 57.51974834714617, 61.31616415296282, 53.99262040002005, 5.3986556359699795, 0.6650338002613613, 0.49697717811380115, 0.027050091984814832, 0.37903815667544094, 36.94473573139736, 65.829498563494, 45.09395476749965, 30.353601591927664, 20.851675987243652, 38.49818270547049, 26.711140496390207, 45.723013401031494, 53.13925307137625, 52.79859331675938, 5.096632642405374, 0.17264001763292722, 0.08766577446034976, 0.13106690985815866, 0.018767340541152016, 0.022570627708254114, 0.03887343745944755, 0.007787351330210055, 0.00957153456485165, 0.045272986205028634, 0.013155838125385344, 0.009151141408697834, 0.10853417324168341, 0.09628998168877193, 0.1698604803532362, 0.1443796447877373, 0.2079237164663417, 0.24692307306187494, 0.0910164618066379, 0.2599471727652209, 0.08714565701250519, 0.3579587877861091, 0.3905148979808603, 27.64328302655901, 92.21594973972866, 67.33844579969133, 66.25868879045758, 48.87001929964338, 24.916919333594187, 45.91579117093767, 50.360338415418354, 53.26982361929757, 81.09337071010044, 32.84543057850429, 0.1575224202658449, 0.15558122657239437, 1.4117872097662516, 4.881307968071528, 4.9286742721285135, 7.0464096409933905, 68.13106850215367, 72.79501901354108, 67.39955520629883, 67.98196710859025, 66.42559146881104, 62.87745911734444, 61.78629316602434, 66.72480869293213, 62.82595212118966, 57.85845218385969, 50.5884234564645, 46.02464859826224, 52.73987061636788, 58.8204129082816, 57.666577679770334, 59.56167452675955, 60.445916175842285, 59.49062919616699, 61.96655723026821, 57.82232502528599, 59.46878405979702, 55.33095114571707, 57.20249012538365, 54.579638957977295, 51.176977566310335, 46.66246543611799, 44.05395882470267, 45.14470441000802, 48.08952815192086, 44.97914968218122, 42.20898628234863, 42.72718293326241, 44.279757908412385, 46.404551778520855, 43.643059730529785, 42.17520761489868, 45.917997223990305, 44.61696440832955, 42.40280280794416, 40.652273654937744, 45.027078356061665, 43.28372321810041, 44.04012496130807, 41.551846504211426, 41.917380809783936, 42.76004443849836, 43.33029351915632, 43.89374031339373, 42.41069596154349, 44.86755119051252, 48.89026982443673, 54.12838472638811, 55.898090907505576, 56.74196004867554, 56.819957051958355, 57.16153049468994, 56.43095173154558, 52.933631556374685, 50.90244034358433, 34.7558308328901, 45.135862827301025, 56.85469457081386, 48.45347826821463, 45.79245022365025, 43.201908179691856, 45.308900765010286, 46.533899443490164, 50.78743723460606, 44.67907435553414, 50.573912143707275, 47.30308239800589, 48.9115104675293, 49.297368253980366, 47.740249156951904, 48.93249750137329, 50.501435484204976, 49.20005873271397, 53.20691810335432, 54.263506344386506, 56.46143000466483, 53.91900771004813, 53.79586478642055, 51.0613317489624, 50.85646758760725, 48.3551994732448, 46.58821351187569, 43.44989633560181, 43.52625356401716, 40.96821171896798, 42.76350464139666, 44.55815832955496, 46.25999798093523, 44.560475553785054, 46.999011857169016, 43.37013448987688, 44.23444175720215, 43.601752689906526, 44.784690448216026, 43.64271232060024, 44.96700075694493, 43.21158702032906, 46.051975863320486, 49.80250576564244, 54.15645544869559, 58.66589191981724, 60.404129709516255, 60.02388259342739, 59.535952295575825, 59.58361693790981, 60.05010509490967, 59.66136033194405, 58.99448612758091, 59.54983479636056, 60.61197117396763, 61.140291350228445, 65.11725957053048, 63.5334107535226, 60.3041729245867, 59.82280172620501, 65.14143930162702, 55.30429090772356, 5.29224397454943, 2.4946006664208005, 2.4064545163086484, 0.20565992008362496, 0.9268864350659507, 42.5775534766061, 72.00571060180664, 51.48872586659023, 48.36480188369751, 23.791396277291433, 39.546485219682964, 37.53174039295742, 53.55573851721627, 62.89842183249337, 61.945955821446006, 7.380047372409275, 0.4614707976579666, 0.1436532459088734, 0.19792429517422402, 0.10956482043755905, 0.08601099039827075, 0.15591677570981638, 0.13064891871597084, 0.1392898586179529, 0.1571288699550288, 0.09706060069480113, 0.12462039291858673], [0.01194692196856652, 0.011105152628650623, 0.008856702163549406, 0.035524331099752865, 0.0559596379420587, 0.020832582310374295, 0.08577046330486025, 0.04907636497435825, 0.03486981282808951, 0.019595692699242915, 0.09676307665982417, 28.977693251201085, 71.1203919819423, 51.190175669533865, 41.83735145841326, 20.204491240637644, 19.653601578303746, 38.73453957693917, 37.65866661071777, 55.19678143092564, 66.69171442304338, 8.50233256816864, 0.3215768528836114, 0.2419352707053934, 1.4134988550628935, 0.7255693290914808, 1.2472505015986306, 33.6897999899728, 68.45432649339948, 61.33876664297921, 61.544947487967356, 58.51565102168492, 61.24002579280308, 56.304202692849294, 62.18600913456508, 60.03787626538958, 60.061611311776296, 53.516932828085764, 47.18993098395211, 44.03703996113369, 42.96956041881016, 42.747895513262065, 50.06693683351789, 51.129198278699604, 53.87863867623465, 53.5164395059858, 53.18035166604178, 55.998600074223106, 56.16005189078194, 53.726073605673655, 54.286866188049316, 51.73630060468401, 45.742572580065044, 40.637824875967844, 41.021487031664165, 40.05732372828892, 40.87724242891584, 43.89629030227661, 43.31405210494995, 37.73517322540283, 39.37810952322823, 41.9885060446603, 41.71805436270577, 40.7224052974156, 41.916564396449495, 38.288162980760845, 41.41983420508248, 38.88517999649048, 40.17364352090018, 38.25507913316999, 39.224488326481406, 39.06983879634312, 41.156153542654856, 39.23889194216047, 39.96125793457031, 39.60091045924595, 39.306320735386436, 38.25945997238159, 44.52741602488926, 47.93199511936733, 51.43301868438721, 48.05807018280029, 51.35667535236904, 49.47264003753662, 54.49696234294346, 49.96220316205706, 54.16445629937308, 28.642619848251343, 40.11745343889509, 53.24576548167637, 45.220637798309326, 42.94140631811959, 38.56968661717006, 38.14328956604004, 36.29390491758074, 41.617051873888286, 41.382723876408164, 43.56565679822649, 42.18236425944737, 43.11902659279959, 42.35077469689505, 42.76573501314436, 42.22409514018467, 42.21314477920532, 40.17604759761265, 42.05917617252895, 44.017109053475515, 44.80166837147304, 48.668410369328086, 48.65506287983486, 46.73983710152762, 43.68614898409162, 40.910524300166536, 39.410258838108604, 38.50586741311209, 39.24351249422346, 38.72966194152832, 37.888585976191926, 39.62826551709856, 39.15083047321865, 42.24484593527657, 42.659114905766074, 40.69920178822109, 41.5209687096732, 38.30463021142142, 40.25232492174421, 41.309510707855225, 41.307332447596956, 42.450731481824604, 47.487220082964214, 53.200946126665386, 54.91501113346645, 53.89683600834438, 55.1928904397147, 54.98999956675938, 55.30284915651594, 56.83501032420567, 54.201524938855854, 55.78884438105992, 53.331631319863455, 55.223076888493125, 56.33620262145996, 56.27802882875715, 55.01392221450806, 56.118241105760845, 53.62292064939226, 57.797314984457834, 57.14582061767578, 57.44398866380964, 25.77286618096488, 0.03741411558751549, 0.5732004365750721, 0.1145825529737132, 0.06152557249047926, 9.92107047353472, 66.8361188343593, 44.227319853646414, 50.18196773529053, 33.12622117996216, 23.330180065972463, 39.39734213692801, 28.479128735406057, 45.919254847935264, 45.64373098100935, 11.02283763885498, 0.5383551120758057, 0.0906980728198375, 0.08791417934532676, 0.03576665631096278, 0.005293719869639192, 0.108503557741642, 0.023294460028409958, 0.016939791285299828, 0.007954513521066733, 0.028451814715351378, 0.04984286866549935, 0.03303305585203426, 0.04502693922924144, 0.043688701931387186, 0.0460173662618867, 0.012687637936323881, 0.07963597747896399, 0.01482246007903346, 0.04622233472764492, 0.025771285872906446, 0.07038540778947727, 0.08446260062711579, 38.68043742861067, 79.41344915117536, 57.828210149492534, 49.038634708949495, 29.121272563934326, 19.587221963065012, 26.41309404373169, 45.10268865312849, 59.65052809034075, 72.87000397273472, 8.737109592982701, 0.2777309242103781, 0.07771332814757313, 1.9413529591900962, 0.5763212091156414, 1.6978537738323212, 39.23143652507237, 71.25086525508335, 63.28652041299002, 64.05671433040074, 62.35037572043282, 64.3017703465053, 61.59327915736607, 63.37251131875174, 60.65541131155831, 62.048969813755576, 56.38503803525652, 48.2742703301566, 45.36019236700875, 45.20919758932931, 44.87811940056937, 53.35386208125523, 52.65056194577898, 55.78252499444144, 54.33161606107439, 55.04119389397757, 56.913549286978586, 57.09097501209804, 56.98474052974156, 55.682672432490754, 53.991526058741975, 47.368197441101074, 42.35891451154436, 43.271126134055, 41.63069118772234, 41.04246711730957, 45.165139062064036, 44.902778557368684, 40.445099217551096, 41.33822761263166, 43.67231164659773, 44.017220224652974, 42.249042647225515, 43.304578236171174, 40.844512939453125, 42.07425376347133, 41.07217066628592, 42.80191428320748, 39.017372948782786, 40.47021000725882, 41.249485220227925, 41.076857226235525, 40.99256862912859, 41.122895990099224, 40.826426778520855, 40.25631666183472, 41.19565405164446, 47.243001324789866, 46.81845596858433, 52.97893728528704, 49.641710553850444, 53.58924967902047, 52.387023721422466, 55.922649315425325, 51.58800172805786, 55.57967233657837, 29.434306280953543, 42.82189382825579, 55.37036827632359, 46.83914770398821, 45.958067485264365, 40.59579174859183, 42.821230275290354, 39.296346596309114, 42.79943725040981, 44.326887539454866, 46.78557709285191, 43.91634280341012, 44.63490118299212, 43.98501532418387, 45.51812144688198, 43.93904256820679, 44.35717126301357, 42.98862280164446, 42.92414699281965, 46.872037002018516, 49.18992131096976, 49.08151551655361, 49.68097134998867, 48.57908085414341, 45.52877998352051, 42.91255044937134, 41.77903175354004, 41.52163226263863, 41.08179044723511, 40.34769589560372, 39.30948216574532, 39.526693275996614, 41.711936473846436, 44.33863346917288, 43.5972398349217, 42.37259898866926, 43.078160762786865, 41.00821597235543, 41.97902870178223, 41.68902826309204, 43.136643750326975, 43.33217648097447, 49.500168800354004, 55.90273577826363, 55.79588985443115, 55.74196488516671, 57.38484559740339, 58.11014372961861, 55.84591688428606, 56.61341142654419, 56.014087608882356, 57.17742102486746, 54.4073931149074, 57.2087539264134, 59.81146226610456, 57.11958769389561, 57.58902188709804, 57.94825070244925, 57.12208209718977, 60.63977786472866, 58.41921697344099, 59.892353194100515, 29.92038835797991, 0.0421288856305182, 0.5903905513031142, 0.08093640341290406, 0.15267014849398816, 9.775642939976283, 68.6045673915318, 50.439485345567974, 49.44107437133789, 22.713023696626934, 32.57614619391305, 45.96620729991368, 36.733903067452566, 51.8177786554609, 55.22424071175711, 18.126674141202653, 0.7658300144331796, 0.10742224433592387, 0.05522203645003693, 0.01851121732033789, 0.025653921367068375, 0.05824395322373935, 0.10239687149545976, 0.032218498310872486, 0.005864444579596498, 0.06502569360392434, 0.03749840660020709, 0.13975823777062552, 0.10247594118118286, 0.11320599541068077, 0.13512319219963892, 0.1403378966663565, 0.10547045192548207, 0.12911264758024896, 0.1637048785175596, 0.1032712860032916, 0.13079485802778176, 0.2841535838586943, 47.90183646338326, 87.5974473953247, 66.49578217097691, 55.046477999006, 32.328665256500244, 28.502002205167496, 52.919318267277305, 53.93174375806536, 65.96928937094552, 78.89273725237165, 11.09461339882442, 0.3916736729443073, 0.3346054037766797, 3.8098527533667426, 5.114608934947422, 2.584946789911815, 45.163019861493794, 72.71305111476353, 68.5481549671718, 65.58727046421596, 66.07680579594204, 65.63492815835136, 63.518173354012625, 65.4990769795009, 63.194595745631624, 64.94456209455217, 58.43432930537632, 51.25076743534633, 47.501373563494, 48.21502998897007, 47.330083097730366, 55.86393008913313, 56.079466683524, 59.06810923985073, 57.83615888868059, 56.1950569152832, 58.934279986790244, 59.87186295645577, 58.34562860216413, 58.847559520176475, 56.76529557364327, 50.23443358285086, 43.255075795309885, 45.78051321847098, 44.209594999040874, 43.73608916146414, 46.18778535297939, 47.37512479509626, 42.88193321228027, 42.19974170412336, 46.77041612352644, 44.80815798895699, 44.75895084653582, 44.226173400878906, 43.174417631966726, 44.78799084254673, 42.64900180271694, 43.85255834034511, 40.952637331826345, 42.48606654575893, 42.45205511365618, 44.144962855747764, 42.80926547731672, 44.62631320953369, 43.14029850278582, 42.582111494881765, 42.75895357131958, 48.58202689034598, 51.703056948525564, 54.46486861365182, 52.6844413621085, 56.490310192108154, 53.73275082451956, 57.76900107519967, 55.27123485292707, 56.73479298182896, 32.39168889181954, 45.36505610602242, 57.56917783192226, 49.36722196851458, 46.85310663495745, 43.69468832015991, 43.605379649571006, 40.542853423527305, 46.89934342248099, 46.97117737361363, 49.30422265189034, 46.709073952266145, 47.85482842581612, 47.28405475616455, 48.985581738608225, 46.75244460787092, 46.908817291259766, 44.69668803896223, 45.69293812343052, 48.74312782287598, 52.99995558602469, 52.472562994275776, 53.332565852573936, 51.79336963381086, 48.47491693496704, 45.21004179545811, 44.13528401511056, 43.195717334747314, 44.48714426585606, 43.93489449364798, 40.91404703685215, 42.36074536187308, 44.57349647794451, 45.01211541039603, 45.79816164289202, 44.641519342150005, 45.84430810383388, 42.849290575299946, 44.89182819638933, 43.96519558770316, 45.53833723068237, 46.869257722582134, 51.95536688395909, 58.0998569216047, 59.02004855019705, 59.306599208286826, 59.15301622663225, 61.857553890773225, 59.082443373543875, 56.53893368584769, 58.77741050720215, 56.87299265180315, 56.32752432141985, 60.73660101209368, 62.27919142586844, 60.73721245356968, 59.948967116219656, 60.71693066188267, 59.566253389631, 63.02557386670794, 61.9186007635934, 60.80501297542027, 31.10552522114345, 0.3210878191249711, 2.122621472392763, 0.2544258790356772, 0.17480032385459968, 12.465261953217642, 77.25800677708217, 54.809846673692974, 66.84237916128976, 44.697320325034006, 31.111855030059814, 52.74697862352644, 45.34875215802874, 62.622779846191406, 66.42842633383614, 23.811447041375295, 1.101447656750679, 0.20829548580305918, 0.20894208896372998, 0.13828832735972746, 0.07561282800244433, 0.16068873607686587, 0.14911511354148388, 0.11934755157147135, 0.125862573406526, 0.2220844980329275, 0.07522493667368378], [0.02720249773535345, 0.041031758966190476, 0.07050493851836238, 0.05162273726559111, 0.11925442942551204, 0.06728028905178819, 0.06175225068415914, 0.04818710072764328, 0.15150876795606955, 0.024972008940364634, 0.13711041770875454, 47.329249313899446, 61.55500153132847, 52.02277830668858, 37.9255747113909, 16.07386187144688, 33.733066422598704, 40.18791512080601, 42.52158573695591, 60.40533869607108, 52.572686535971506, 2.4698785415717532, 0.04331756363223706, 0.1479204712169511, 1.3745279290846415, 0.254029994564397, 1.9285113854067666, 52.87073646272932, 70.31075314113072, 62.92367158617292, 56.208376611982075, 57.37062610898699, 59.068053654261995, 59.164043017796104, 58.65690095084054, 61.141979762486045, 56.66108649117606, 56.15659516198294, 47.458537919180735, 42.07239859444754, 43.22135271344866, 43.21547106334141, 39.73744256155831, 44.9953806740897, 48.51212453842163, 50.39310264587402, 50.294212409428184, 52.28665699277605, 51.43549919128418, 51.87014722824097, 49.44159548623221, 44.2558456829616, 41.138942854745046, 41.19040468760899, 42.193158285958425, 39.76941122327532, 40.100169794900076, 40.28188950674874, 42.68378448486328, 42.404630184173584, 40.78005102702549, 42.95634494509016, 41.10986464364188, 41.2916190964835, 42.00236075265067, 39.92680876595633, 39.739395005362375, 39.90359830856323, 40.05492312567574, 38.64674908774239, 40.93550654820034, 40.034210545676096, 39.600792339869905, 38.4782726424081, 40.30588511058262, 37.815678528376985, 38.996695109776084, 39.23711320332119, 42.91180351802281, 44.73363161087036, 48.93142400469099, 46.18833078656878, 47.73980794634138, 48.78548404148647, 49.675127914973665, 47.11245162146432, 55.54322556086949, 30.3671783719744, 38.56945385251726, 52.688492161887034, 45.455493858882356, 47.40201779774257, 44.82785265786307, 44.152571133204866, 38.66139241627285, 36.66234704426357, 34.9694219316755, 39.661967754364014, 41.12351090567452, 43.69336816242763, 42.40923336574009, 41.11402661459786, 40.56677259717669, 39.62564952032906, 38.950760568891255, 39.41190903527396, 37.95212377820696, 39.34530012948172, 39.874547890254426, 40.96113150460379, 39.305070059640066, 38.73901769093105, 37.60529749734061, 37.668348925454275, 39.07555716378348, 39.174478667122976, 39.54650953837803, 40.07112285069057, 40.66622216360909, 40.360383306230815, 40.7596754346575, 40.87677342551095, 40.25054618290493, 40.375731876918245, 40.551833970206125, 40.01713534763881, 39.622137205941335, 40.3456392288208, 43.29367651258196, 53.16644484656197, 53.00423567635672, 56.787210191999165, 54.755345003945486, 50.918831144060405, 49.20400530951363, 54.610457692827495, 57.79356643131801, 48.733247484479634, 49.407403400966096, 56.38479137420654, 53.814680508204866, 55.41633755820138, 56.490678446633474, 57.29458154950823, 56.89728702817644, 58.686277934483115, 56.60314546312605, 60.38717610495431, 59.155503681727815, 52.973215443747385, 4.280894151755741, 0.5608977824449539, 0.05308783007785678, 0.08640914117651326, 0.8085627928376198, 42.020172459738596, 59.39466067722866, 39.26189047949654, 38.81346763883318, 14.532962475504194, 27.66618081501552, 27.579602786472865, 41.17114775521414, 43.392191546303884, 29.088063648768834, 2.1520572985921587, 0.08910177169101578, 0.03752188391185232, 0.016082148466791426, 0.0476298911630043, 0.06431990183357682, 0.05332075757905841, 0.02727041739438261, 0.007843451757383133, 0.06159616048846926, 0.029312607632683854, 0.06175436092806714, 0.0071263920648821765, 0.056241586205682585, 0.02049300097860396, 0.03566537478140422, 0.04200577223673463, 0.13371338642069272, 0.023069568078166673, 0.08139841112175158, 0.16322009238813603, 0.7931646076696259, 60.81818675994873, 67.83870915004185, 59.354215213230674, 43.46847581863403, 21.3992600440979, 29.54166637148176, 38.19208329064505, 46.57376473290579, 65.58274718693325, 57.16480657032558, 2.2506166270801, 0.022398982097261717, 0.5678332788603646, 3.158520583595548, 1.9531790103231157, 2.494303196668625, 57.138875893184114, 70.13340037209647, 65.12702873774937, 59.07739898136684, 59.70511313847133, 60.53689588819231, 62.48831135886056, 59.88391808101109, 61.21824319022042, 58.10114581244332, 57.785687174115864, 49.791656153542654, 44.59224966594151, 44.38783366339547, 45.067965030670166, 42.32996484211513, 45.74188470840454, 49.78305080958775, 53.51263884135655, 51.57025950295584, 55.895690304892405, 53.30355364935738, 53.06009224482945, 50.806193896702354, 46.18679176058088, 43.37026650565011, 43.82139566966465, 41.85416957310268, 41.58951268877302, 42.050345012119834, 42.40544659750802, 44.50541455405099, 43.4713454246521, 43.404781682150706, 43.54755326679775, 42.55405119487217, 44.107970646449495, 42.918918473379954, 41.02336999348232, 41.50407069069998, 41.75562674658639, 42.56680113928658, 40.86949518748692, 42.61389602933611, 41.82549435751778, 40.929065568106516, 39.68177012034825, 42.01005935668945, 41.03218725749424, 41.37682832990374, 41.91057504926409, 45.96035344260079, 47.65431036267962, 50.632488931928364, 50.42151730401175, 50.149672508239746, 51.63468320029122, 52.27782235826765, 48.18499640056065, 57.890028272356304, 33.44622046606881, 40.88462141581944, 53.665301186697825, 46.47112594332014, 49.65676382609776, 47.039544173649375, 44.9744804927281, 39.49270963668823, 39.301397936684744, 37.9023677280971, 42.82167496000017, 43.20609099524361, 44.8099992615836, 45.01764965057373, 41.87691102709089, 42.75751529421125, 42.331983293805806, 40.57804604939052, 40.74663366590227, 37.994129112788606, 41.595654896327424, 42.55714314324515, 43.31764084952218, 40.07396813801357, 39.815592425210134, 41.42363486971174, 39.609025955200195, 40.3407164301191, 41.8732145854405, 39.97268772125244, 41.35919727597918, 42.59666797092983, 42.41198485238211, 41.56775093078613, 42.65163516998291, 41.534840788160054, 42.00937843322754, 41.30005420957293, 42.99032858439854, 41.43740619931902, 42.53645488194057, 45.45298555919102, 55.499010699135916, 55.48668112073626, 58.6177339553833, 56.158394745418, 52.324948515210835, 53.44855560575213, 54.51377350943429, 57.44565970557076, 51.149685042245046, 51.47605930055891, 58.8168762751988, 55.92322601590838, 57.799663475581575, 58.17247254507882, 58.57519013541085, 57.83096511023385, 61.618744305201936, 57.16778039932251, 63.2255082811628, 59.93655068533761, 57.36934764044625, 5.3855904170445035, 0.42945680980171475, 0.3876672764973981, 0.04589420197797673, 0.499786801636219, 45.04271527699062, 65.5192198072161, 45.23359271458217, 30.81342990057809, 21.044488498142787, 38.08956956863403, 36.175184522356304, 49.18593304497855, 50.42128801345825, 42.983286585126606, 3.4309496794428145, 0.0897867324362908, 0.02148995382179107, 0.03499922641952123, 0.06846217491797038, 0.07638611365109682, 0.004135366870156888, 0.02538471599109471, 0.034256091474422386, 0.09152587875723839, 0.0015163974811522557, 0.16752505781395094, 0.14156790423606122, 0.18914733614240373, 0.1372471967978137, 0.21241415265415395, 0.11699876189231873, 0.3521126929138388, 0.10431231478495256, 0.3260334166032927, 0.27330997000847546, 1.7632379510572977, 72.0134231022426, 77.03129400525773, 67.0794655936105, 52.541985920497346, 26.516010761260986, 48.27566344397408, 54.684820788247244, 55.648365701947895, 70.87792069571358, 63.10349791390555, 2.8920751895223344, 0.11871282277362687, 0.8277160993644169, 5.199191961969648, 6.7720053025654385, 4.977705538272858, 62.104965346200125, 70.56253501347133, 69.41191332680839, 60.22250379834856, 62.44764355250767, 62.33273424421038, 65.03764016287667, 61.520642689296174, 65.15395995548793, 58.538510595049175, 61.68182005201067, 51.65320709773472, 46.480888162340435, 46.44468804768154, 48.195008754730225, 44.93551846912929, 48.49489995411464, 53.58570262363979, 54.344251360212056, 52.24584674835205, 58.54826586587088, 57.25218711580549, 57.320397581372944, 52.30347163336617, 48.20931509562901, 45.030764375414165, 45.779154845646445, 44.99959128243582, 43.09401307787214, 44.347468103681294, 43.479342801230295, 46.89392730167934, 46.26471928187779, 46.255721364702495, 47.682572160448345, 43.989976337977815, 46.929988452366416, 45.27122415815081, 43.496987751552034, 43.42526497159685, 44.18411248070853, 44.66451440538679, 41.66181216921125, 44.505887031555176, 43.91607182366507, 42.48704971585955, 41.86954246248518, 44.483899457114084, 42.11461584908621, 42.706571102142334, 43.54635122844151, 49.01897130693708, 50.314376081739155, 54.384870529174805, 52.22626325062343, 51.25968892233712, 53.99044908796038, 53.92082813807896, 50.30559008462088, 59.745503016880576, 35.706500734601704, 45.72637285505022, 56.438469682421, 48.87412221091134, 50.68480886731829, 50.45872490746634, 47.856145109449116, 43.45293617248535, 42.705886704581125, 39.3221105166844, 46.06562907355172, 45.04712390899658, 48.07181371961321, 47.12751531600952, 44.85195595877511, 44.81406395775931, 43.624160630362375, 42.497979232243125, 43.397510392325266, 41.57544953482491, 42.93774461746216, 45.97634472165789, 45.43814073290144, 42.21030296598162, 41.66764170782906, 43.184072153908865, 41.095113618033274, 44.56697906766619, 44.846793447222026, 42.123818738119944, 45.447972433907644, 45.32023327691214, 45.489776270730154, 44.419395855494905, 44.84010233197893, 43.85199901035854, 44.76443992342268, 44.14256225313459, 45.5313195501055, 42.62868179593767, 43.864985193525044, 46.3110602923802, 57.54233694076538, 58.34842872619629, 60.590244156973704, 57.68664060320173, 53.24740525654384, 55.36900642939976, 55.925230571201865, 59.92350891658238, 55.18844706671578, 53.681806632450645, 58.559556688581196, 56.49751894814627, 60.50774819510323, 61.18916497911726, 61.20562526157924, 61.717221123831614, 63.630157470703125, 60.70679324013846, 68.06913920811245, 60.94162845611572, 58.542644773210796, 5.923993297985621, 0.7699671238660812, 0.6103091367653438, 0.15966165118983813, 1.4689476511308124, 51.283618518284385, 70.95360047476632, 53.61414507457188, 53.205028193337576, 19.270076649529592, 37.853469780513215, 43.26210042408535, 56.393806661878315, 61.55133983067104, 52.04572820663452, 4.03971175636564, 0.28918714661683353, 0.15776553936302662, 0.13551580613212927, 0.12118748069873878, 0.09064905545009033, 0.18824031124157564, 0.11377582233399153, 0.10804663904543434, 0.1741610217307295, 0.08238138444721699], [0.022199211209746342, 0.024718688069177524, 0.07300033247364418, 0.05366933458883848, 0.0742298447127853, 0.017347014076741676, 0.034641000641775985, 0.04538187071947115, 0.1690993540521179, 0.031037185806781054, 6.298970639705658, 59.88053430829729, 52.13196924754551, 54.60870674678257, 25.152560540607997, 14.689506258283343, 51.54555170876639, 31.349313191005162, 50.75690337589809, 65.48572254180908, 38.47665023803711, 0.04042270593345165, 0.12023873946496419, 0.658495328256062, 0.8694152246628488, 2.2215942186968665, 8.784552761486598, 83.79642840794155, 59.80262415749686, 63.971070834568565, 50.481779030391145, 56.321927547454834, 56.1035213470459, 60.82349518367222, 54.7931501524789, 59.04720211029053, 58.55402592250279, 57.12144981111799, 48.56128304345267, 45.81633118220738, 44.4911915915353, 40.731569971357075, 42.3556592805045, 40.528790269579204, 41.59708969933646, 43.93547814232962, 42.141887528555735, 41.942814690726145, 42.657735688345774, 41.8405476297651, 40.999440397535054, 38.77246284484863, 39.42887653623308, 40.041867460523335, 40.71675293786185, 39.91932903017317, 39.946201188223704, 39.829269954136436, 39.77469185420445, 40.10154901232038, 40.75986303601946, 41.23431382860456, 40.44358103615897, 42.589365414210725, 39.64597647530692, 39.66554955073765, 40.21583645684378, 38.76902001244681, 39.3856656891959, 41.91403177806309, 41.17625815527779, 40.450223514011924, 40.62827457700457, 40.09832157407488, 39.950411796569824, 37.72872182301113, 40.390875475747244, 40.01857362474714, 43.900681563786094, 41.04791797910418, 45.010142121996196, 43.6860134942191, 47.32890885216849, 44.33456529889788, 51.22592067718506, 47.11559220722744, 54.255460330418174, 37.89161191667829, 32.71333837509155, 54.27214642933437, 47.50723784310477, 50.539240632738384, 46.211645466940745, 50.59576422827584, 42.65569986615862, 40.37701729365757, 36.39304181507656, 37.73571171079363, 37.38669327327183, 38.89386177062988, 37.70895767211914, 39.77337169647217, 36.87753275462559, 39.15666001183646, 36.6599360193525, 39.02985886165074, 39.26072665623256, 37.23665387289864, 36.89369773864746, 37.67407076699393, 38.286808082035606, 37.751640456063406, 37.653101103646414, 38.53388602393014, 39.02644729614258, 39.74976519175938, 39.694864000592915, 38.37409482683454, 38.32234116962978, 40.77410684313093, 39.68390669141497, 38.49036945615496, 39.744891030447825, 38.93907022476196, 38.94980866568429, 40.61498614719936, 41.68268803187779, 40.650779792240684, 46.28330223900931, 50.99357639040266, 52.5833728654044, 42.75744233812605, 51.11468349184309, 54.14942387172154, 51.68879229681832, 56.978403772626606, 50.93393305369786, 53.20542771475655, 51.1654817717416, 53.24641513824463, 55.87114231927054, 55.381419386182515, 57.257908957345144, 56.17927755628313, 56.87045308521816, 59.482638767787385, 55.77367646353585, 59.43933064596993, 55.854984283447266, 61.545871598379954, 18.379845653261455, 0.13460637921733515, 0.07246880885213614, 0.04950686151693974, 0.07006574315684182, 12.30324559552329, 65.13380323137555, 45.637154511043, 39.95724187578474, 17.292603697095597, 20.23131823539734, 25.591019664491924, 37.43394449778965, 45.70057766778128, 42.150934083121165, 9.817526681082589, 0.2707699420196669, 0.07812042201736144, 0.04577276795836432, 0.0689870421109455, 0.027307816548272967, 0.11223448254168034, 0.020027403819507787, 0.056842734305454154, 0.009143645293079317, 0.018661799508013895, 0.003987011549595211, 0.050308191017912965, 0.0366725616290101, 0.03358284902891942, 0.056939076100076945, 0.06684368569403887, 0.10346314856516463, 0.034999494440853596, 0.1622713240129607, 0.03433622646012476, 8.662670067378453, 70.56142330169678, 58.46239307948521, 61.498193059648784, 29.660876614706858, 23.142627341406687, 41.49823420388358, 37.36967713492257, 57.371376514434814, 72.75141211918422, 40.87605428695679, 0.04236446959631784, 0.21538913516061647, 1.3681505684341704, 3.39731279867036, 2.049767004592078, 10.419885993003845, 82.88217748914445, 62.10281835283552, 66.79757022857666, 51.54967546463013, 57.65994215011597, 57.752690179007395, 63.467854499816895, 56.7550504548209, 61.708285740443635, 61.6642758505685, 58.69834000723702, 51.77121877670288, 47.88915252685547, 46.60567086083548, 42.77329117911202, 45.022242409842356, 43.229141644069124, 43.7164500781468, 45.97168595450265, 45.14828273228237, 45.906953062329976, 44.538661684308735, 44.365998949323384, 41.91887814658028, 42.031352111271445, 41.323375838143484, 42.39173780168806, 42.164406640189036, 40.59026793071202, 41.906413078308105, 40.596232959202354, 40.85285077776228, 40.92397601263863, 41.80894374847412, 42.415299143110005, 43.513281277247835, 43.76716150556292, 42.461671420506065, 41.78702565601894, 42.85212196622576, 41.11915438515799, 40.102031912122456, 44.38663509913853, 42.763546330588206, 43.10910109111241, 41.230061531066895, 41.75744717461722, 40.90799862997872, 39.55786289487566, 41.54470375605992, 42.097116810934885, 45.82116365432739, 43.88731670379639, 46.53061294555664, 46.717898164476665, 49.82253394808088, 47.5944516318185, 52.21604939869472, 48.735578605106895, 55.88592461177281, 40.23589938027518, 35.65731791087559, 55.03446456364223, 49.173523562295095, 52.417415142059326, 47.65272617340088, 52.19483307429722, 45.68336697987148, 42.20016554423741, 38.720636231558665, 39.63019016810826, 39.26294660568237, 41.66082205091204, 39.77855505262102, 41.214994362422395, 39.30022021702358, 40.830279554639546, 38.13167565209525, 41.39557456970215, 40.499197891780305, 39.097833088466096, 37.6892352104187, 40.26480736051287, 39.195545605250764, 39.589508465358186, 39.832056181771414, 40.949729510716026, 42.01636484691075, 43.040386881147114, 39.7553619657244, 40.15123210634504, 40.414499350956504, 42.19601399557931, 41.42508009501866, 40.66794531685965, 40.81854404721941, 42.28526708057949, 40.604529108319966, 41.99362339292254, 43.149668148585725, 43.21492215565273, 49.71955122266497, 54.87774447032383, 54.6086859021868, 48.41595452172415, 53.25491278512137, 54.453077520642964, 53.46335874285017, 58.128521714891704, 53.05987337657383, 54.729421275002615, 52.47409507206508, 54.87447534288679, 57.86715132849557, 58.02098791939871, 58.19783694403512, 59.65027795519148, 57.90644686562674, 61.20783478873116, 58.36603546142578, 61.758236340114046, 57.226395402635845, 61.93365750994001, 21.00269855771746, 0.02645597011516137, 0.24861612649900572, 0.19387645380837576, 0.06277573933558804, 14.559015614645821, 69.54360948290143, 51.48360504422869, 38.873840536390034, 16.14714625903538, 28.402401515415736, 29.980709144047328, 47.51123653139387, 50.30987712315151, 53.22293717520577, 13.803916658673968, 0.20679405065519468, 0.08653570831354175, 0.01861114856520934, 0.08279230525451046, 0.04031395034066268, 0.02970448535467897, 0.05940133719039815, 0.020759205533457652, 0.07225429679134063, 0.044528799530650885, 0.06772736899022545, 0.09779359493404627, 0.10283499477165085, 0.16015859666679585, 0.13645138378654206, 0.12256682025534765, 0.1791873648762703, 0.18726508000067302, 0.339933803571122, 0.17534298902111395, 11.684635315622602, 81.57670130048479, 66.64494609832764, 73.26524530138288, 37.272200856889995, 26.746769121715, 62.16914585658482, 46.90623256138393, 63.16498252323696, 78.22489030020577, 45.94551903860909, 0.1930643016738551, 0.25166223304612295, 1.8061866121632713, 6.303718864917755, 7.878602334431239, 12.406702535493032, 86.15494578225272, 65.21468721117292, 69.85907854352678, 53.94890233448574, 60.61498669215611, 60.286323002406526, 66.05981745038713, 60.25673062460763, 66.28869806017194, 62.43945162636893, 62.692220142909456, 52.940756934029714, 50.07359320776803, 49.01310702732631, 44.413177217756, 47.5119035584586, 44.896056175231934, 45.24270527703421, 49.65200431006295, 47.118180411202566, 47.37099061693464, 47.53882782799857, 46.86894505364554, 44.858376094273154, 42.61476108006069, 43.347799505506245, 44.08554880959647, 44.77738094329834, 44.36241715294974, 43.761199951171875, 42.046280315944124, 43.59603084836687, 42.46359607151577, 43.29313802719116, 44.439635957990376, 44.81712463923863, 46.08519172668457, 44.5022565977914, 43.67835657937186, 44.55580983843122, 42.9456273487636, 42.16244029998779, 47.50293343407767, 44.698647430964876, 45.223226002284456, 43.41958829334804, 45.283202852521626, 42.670916421072825, 40.8269305229187, 43.90236302784511, 44.804062025887625, 47.885497774396626, 46.53267656053816, 49.06709453037807, 48.89290319170271, 52.30962078911917, 50.013154302324565, 55.14645562853132, 51.568084716796875, 58.06184680121285, 43.24089452198574, 37.716162954057964, 57.215712547302246, 50.93808807645525, 55.15619352885655, 50.110404763902935, 55.66517686843872, 48.41316481998989, 43.80194418770926, 40.929433822631836, 41.89605678830828, 42.242799690791536, 43.46234403337751, 42.57088320595877, 44.46065773282732, 41.70878546578543, 44.44958577837263, 40.82990435191563, 44.01106759480068, 44.02912596293858, 40.5804431779044, 39.86912134715489, 43.31408337184361, 41.47745214189802, 42.20706510543823, 42.85828154427664, 42.556642872946604, 45.02329853602818, 45.48593044281006, 43.0482348714556, 42.05445139748709, 41.63455786023821, 44.053062507084434, 43.318884577069966, 42.111642020089285, 43.86239351545061, 44.986886501312256, 41.475732462746755, 44.299911158425466, 46.46665825162615, 45.22193363734654, 51.30176026480538, 55.560735021318706, 56.14592272894723, 49.958468505314414, 56.47454820360456, 57.28302322115217, 56.55021408626011, 61.34781319754464, 55.545136315482004, 55.715638160705566, 55.73063932146345, 56.961814948490684, 61.88624995095389, 59.84620325905936, 60.91179983956473, 60.36587987627302, 60.6308285849435, 64.74842139652797, 61.10970538003104, 63.29175935472761, 59.52644715990339, 65.10361330849784, 21.83029328073774, 0.32295685740453856, 1.0470594380583083, 0.1680275672780616, 0.17233846309993947, 16.904783044542583, 75.08511747632707, 58.55137865883963, 54.79091283253261, 25.138207299368723, 27.420450823647634, 35.526431219918386, 55.4918714250837, 59.392590114048545, 64.86623505183628, 17.50720575877598, 0.5539837277361325, 0.2231352502214057, 0.13611899662230695, 0.23613851889967918, 0.08832860139331647, 0.3254932755870478, 0.2147815613342183, 0.11762985374246325, 0.16613366747541086, 0.12534600469682897], [0.02490202314220369, 0.03713787041072335, 0.01834404155878084, 0.032646491059235165, 0.02019024543863322, 0.04315412490229521, 0.09419821428933314, 0.06161527481994458, 0.09814960868763072, 0.1680955293455294, 11.455346499170576, 64.7505475452968, 51.87094974517822, 50.47839873177664, 26.375004019056046, 26.48214524132865, 67.51922403063092, 43.566490582057405, 50.91976567677089, 69.77508871895927, 18.048861265182495, 0.07280069390045744, 0.15934226475656033, 1.547438410776002, 1.745661397065435, 0.9004123327987534, 27.297035183225358, 60.128418241228374, 59.881472315107075, 64.13858495439801, 48.85280166353498, 52.80959926332746, 54.470322949545725, 59.502559253147666, 55.503916127341135, 57.43872192927769, 55.40658228737967, 57.17617729731968, 50.62351185934884, 46.53996522086007, 46.19720711026873, 44.831305912562776, 41.358432974134175, 41.09408875874111, 39.05318743841988, 41.34622498920986, 40.80835451398577, 39.428098337990896, 40.49330234527588, 40.95154993874686, 38.628847054072786, 40.42723887307303, 39.133376598358154, 40.53668689727783, 39.7070963042123, 41.8966578074864, 40.109508173806326, 38.94086980819702, 39.79093326841082, 41.598621777125764, 41.364133971078054, 41.11879655293056, 41.523265089307515, 41.605149609701975, 39.4400839805603, 39.097857407161165, 40.98323719842093, 38.346152646201, 39.03491020202637, 40.24969850267683, 39.35811608178275, 40.019622802734375, 39.47346312659127, 42.744998114449636, 39.64164774758475, 39.11985192980085, 40.90509080886841, 38.16877555847168, 40.807948044368196, 40.200154372623985, 40.96995224271502, 43.08532782963344, 43.65197426932198, 42.82243578774588, 47.998388631003245, 49.589779717581614, 51.62264197213309, 40.83998271397182, 25.967341048376902, 49.14790555409023, 50.19264364242554, 52.92628731046404, 48.09594133922032, 51.30085699898856, 48.718034403664724, 44.31812933513096, 38.49373933247158, 36.34813213348389, 36.10882922581264, 38.328646659851074, 36.37708180291312, 37.6665632384164, 37.610123021262034, 37.53127486365182, 37.925817898341585, 39.28066798618862, 38.64673866544451, 41.34269183022635, 37.27403518131801, 36.21304873057774, 35.846489565713064, 37.40258380344936, 36.998292446136475, 40.1747065952846, 40.16893611635481, 39.082415035792756, 39.62209204265049, 38.330703326633994, 38.613970960889546, 39.28351674761091, 39.20267793110439, 40.21784101213728, 40.19472435542515, 39.57792929240635, 41.63917146410261, 39.88988256454468, 40.68508652278355, 38.94878033229283, 47.53856379645211, 52.40618337903704, 54.931315081460134, 47.7796801839556, 45.402086530412944, 50.84713615689959, 51.447516100747244, 51.03925732203892, 52.93127959115164, 52.276283332279746, 52.973566327776226, 52.23842259815761, 56.84246574129377, 53.937059129987446, 55.192181723458425, 57.659681592668804, 57.65667997087751, 56.08323955535889, 54.43092666353498, 57.86550113133022, 57.91057756968907, 63.54909978594099, 39.2614666393825, 0.27534690499305725, 0.16509090842945234, 0.014378659161073821, 0.06306303784783397, 2.937487312725612, 51.118956633976524, 51.14743382590157, 42.990439755576, 39.162618092128206, 17.17434709412711, 25.297411373683385, 32.291808537074495, 42.61352777481079, 45.54433700016567, 16.87879851886204, 0.7947050450103623, 0.0741181510633656, 0.03860865952447057, 0.045174323820642064, 0.02186857127318425, 0.025637351541912982, 0.07673382892140321, 0.03666355746931263, 0.06122055064354624, 0.08411819660770041, 0.03700694368620004, 0.05787291670484202, 0.03983903011041028, 0.03066495167357581, 0.07530382994030203, 0.05462757870554924, 0.07181542712662901, 0.06042203027755022, 0.07583887515855686, 0.3308779666466372, 17.916001285825455, 75.92101355961391, 56.99712916782924, 58.795983042035786, 37.36028317042759, 27.923783540725708, 60.7673328944615, 48.25358554295131, 55.461313247680664, 76.23163972582135, 19.04471182823181, 0.1334187529448952, 0.12178312587950911, 1.412399954029492, 2.516579338482448, 0.4426333898944514, 29.36218397957938, 62.049080984933035, 63.33772168840681, 66.54255744389125, 51.53822830745152, 54.871796812329976, 56.50563791819981, 62.955709729875835, 57.37389523642403, 58.892271178109304, 57.19212341308594, 60.66006660461426, 52.98091752188546, 49.4827253477914, 46.71542807987758, 46.48966026306152, 42.355666228703086, 43.27251924787249, 41.08876991271973, 42.36658879688808, 42.319830894470215, 41.74089309147426, 41.56261968612671, 42.97988544191633, 40.25341578892299, 42.761229106358115, 40.92241266795567, 41.62785284859793, 41.10883978434971, 42.58705513817923, 41.86953204018729, 42.91250876017979, 43.29188387734549, 42.019321305411204, 43.24797821044922, 43.927070822034565, 45.82608297892979, 42.920669419424875, 41.8618403843471, 41.478716714041575, 42.79893003191267, 40.04202726909092, 40.45310354232788, 41.9760479245867, 41.282746246882844, 41.40724406923567, 42.670232023511616, 42.92954921722412, 41.13403395244053, 40.89607899529593, 43.337627342769075, 41.696532317570274, 43.98872913633074, 42.168658937726704, 43.1835823059082, 44.9074581691197, 47.48064361299787, 43.07110139301845, 49.83387688228062, 50.68638610839844, 53.03063188280378, 44.69508300508772, 27.58852427346366, 50.71268156596592, 51.10128041676113, 52.44021565573556, 49.88598142351423, 51.97978980200631, 50.538941860198975, 47.059492451804026, 40.9594361441476, 40.52052886145455, 37.10076795305525, 39.61828442982265, 38.20909595489502, 39.78762592588152, 38.701657227107454, 40.006553241184776, 40.05924490519932, 41.6945173399789, 40.50383234024048, 42.941104071480886, 38.13819306237357, 37.863742692129954, 38.231542110443115, 38.653322083609446, 40.31774915967669, 40.73546443666731, 41.2252915927342, 41.27227183750698, 42.0861942427499, 40.55393580027989, 40.418848923274446, 41.85382563727242, 40.23230716160366, 41.29547534670149, 40.75679193224226, 41.019284452710835, 42.514050415584016, 41.65381479263306, 42.19470426014492, 39.706054074423655, 47.530646324157715, 55.96536684036255, 56.04319361277989, 53.177773884364534, 48.28138181141445, 53.17275728498186, 53.184979166303364, 53.30232034410749, 54.16420269012451, 54.58895301818848, 55.437216894967214, 53.92738028935024, 57.32083879198347, 55.83713436126709, 56.49395799636841, 56.64303159713745, 59.090829849243164, 58.688285963875906, 57.17617382322039, 58.85485512869698, 61.12777764456612, 64.64591462271554, 42.42218828201294, 0.7160366720386914, 0.6635460715208734, 0.47669972905090874, 0.08080770567591701, 2.79156146304948, 55.1742136819022, 60.21295697348458, 42.8073581968035, 32.33979279654366, 21.592220204217092, 29.897987365722656, 38.10312897818429, 49.07747861317226, 55.70929792949131, 25.248822620936803, 1.1136360998664583, 0.055099208040961196, 0.05268215434625745, 0.029095221976084367, 0.015561398285041963, 0.040388324564056735, 0.09208763111382723, 0.029186522255518606, 0.023366913997701237, 0.06193489195512874, 0.1521921612854515, 0.12406414348099913, 0.18322962868426526, 0.19106733240187168, 0.12727030286831514, 0.18376379859234604, 0.294982052807297, 0.22089122634913239, 0.1919190159865788, 0.5451835085238729, 24.230821200779506, 84.33176626477922, 65.32976327623639, 68.52967275891984, 39.80589968817574, 40.39589902332851, 74.35832895551408, 57.112045424325125, 61.114867891584126, 82.64008835383824, 22.32922257695879, 0.19851121439465455, 0.25380670226046015, 3.425962392772947, 8.537300246102468, 2.8346741667815616, 33.27948107038225, 68.76722472054618, 65.16689055306571, 69.53573717389787, 52.192925793784006, 57.324823583875386, 59.45742375510079, 64.83138288770402, 58.82536697387695, 60.58695765904018, 59.11835861206055, 62.00133991241455, 54.1164789881025, 51.86337620871407, 48.88920327595302, 49.58637510027204, 45.39977625438145, 47.48298863002232, 42.79612643378121, 45.25135578427996, 44.72395624433245, 43.580710070473806, 43.9061393737793, 45.32454463413784, 41.20400926045009, 45.047012737819124, 42.78994253703526, 43.66412319455828, 43.846134730747764, 44.1363331930978, 43.865207535879954, 44.17745610645839, 44.48597696849278, 44.02961581093924, 45.2019818850926, 44.91172783715384, 47.4800043787275, 46.845025879996165, 43.240019048963276, 43.50389426095145, 44.911561080387656, 41.1954699243818, 41.69087995801653, 43.48781960351126, 43.35515069961548, 44.28210987363543, 43.17290987287249, 46.02648639678955, 43.135108198438374, 43.90288066864014, 46.10007129396711, 43.99547931126186, 46.792441913059776, 44.648790631975444, 44.46921443939209, 47.221743311200825, 49.90728807449341, 45.01012127740042, 53.02970082419259, 53.043788296835764, 55.95511824744088, 47.52736677442278, 30.98417145865304, 51.52057293483189, 52.992715563092915, 55.78260142462594, 52.096512590135845, 56.63177898951939, 51.81704909460885, 49.40496458326067, 44.44142859322684, 42.524100984845845, 37.98321001870291, 42.59826258250645, 40.14476680755615, 41.94581283841814, 41.07165649959019, 41.43454354149954, 41.14349045072283, 43.58637980052403, 42.27479267120361, 44.26410709108625, 40.01119463784354, 39.35624006816319, 40.30874082020351, 39.994849000658306, 42.726766041346956, 43.67370476041521, 44.33364118848528, 43.77395336968558, 46.36418274470738, 42.70510155814034, 42.53290435246059, 44.67355401175362, 42.209319795881, 44.389674936022075, 43.22339200973511, 42.49143055507115, 44.52995211737496, 42.91195290429251, 43.83645589011056, 42.04986906051636, 50.6818836757115, 58.013716629573274, 58.821851185389924, 54.921083859034944, 52.53078542436872, 56.820902006966726, 55.04761055537632, 55.44582223892212, 55.98303958347866, 55.23380143301827, 58.84710093906948, 56.4647547176906, 58.42676966530936, 56.740893500191824, 57.975848947252544, 59.642231941223145, 61.460026604788645, 60.953009605407715, 59.190036228724885, 61.811841692243306, 63.80277851649693, 66.06329154968262, 45.48639597211565, 0.6959586579884801, 1.6248151787689753, 0.6557548610227448, 0.21357104129024915, 4.230610038552966, 60.23153645651681, 63.77686173575265, 57.365005016326904, 50.9886223248073, 23.286653075899395, 34.80462803159441, 46.9918725831168, 58.96432399749756, 65.98108046395438, 32.49980981009347, 1.3305168449878693, 0.15693194552191667, 0.13014142880482332, 0.10970619999404464, 0.12915943935513496, 0.12220110345099654, 0.23564345975007328, 0.15414475436721528, 0.13933526618140085, 0.17125136857586248], [0.05735746079257556, 0.08457736804016999, 0.04284175452111023, 0.008796170902704554, 0.02999978040211967, 0.027719814529908553, 0.026775711082986424, 0.037891088386199305, 0.08421462321920054, 0.09171516967139073, 23.416898795536586, 64.10203742980957, 52.243414878845215, 38.21585307802473, 10.040790540831429, 20.679100104740687, 37.833524976457866, 48.50934178488595, 55.48187296731131, 63.93842819758824, 5.991813361644745, 0.17840460687875748, 0.0487304410365011, 0.8428833654948643, 3.104110760348184, 0.8389558419585228, 38.31007065091814, 59.6474917275565, 65.1924946648734, 59.67717443193708, 50.57664278575352, 46.85992629187447, 54.61830915723528, 56.217113971710205, 61.103590965270996, 57.16579321452549, 57.35807071413313, 60.1198719569615, 53.92540005275181, 50.263591698237825, 47.02033587864467, 45.86790418624878, 43.817289284297395, 41.38483960287911, 40.99727603367397, 40.207832132067, 41.054320744105745, 39.09801721572876, 40.30739286967686, 40.476175035749165, 40.937973158700125, 40.31430285317557, 42.18186398914882, 41.83679212842669, 42.886376585279194, 40.69890996388027, 41.5723888533456, 40.33931984220232, 40.85886444364275, 41.95462662833077, 40.74834292275565, 39.11493260519845, 40.673507349831716, 39.07473727634975, 41.834106649671284, 38.929450443812776, 38.83754662105015, 39.60384259905134, 38.13446882792881, 40.35903535570417, 40.104835510253906, 38.85547297341483, 40.11312471117292, 40.430640016283306, 38.60955190658569, 39.59471614020211, 38.37883697237287, 38.07865742274693, 39.82753637858799, 39.74779537745884, 40.175846099853516, 39.95812429700579, 41.488107204437256, 42.85802098682949, 47.96286596570696, 48.63499648230416, 50.60045773642403, 41.266515254974365, 27.236566747937882, 49.61608559744698, 46.14252478735787, 49.47436319078718, 47.47107246943882, 47.88373988015311, 46.54216432571411, 48.5916223526001, 41.00529425484793, 38.57782643181937, 37.85099274771554, 36.60589640481131, 37.52880825315203, 37.81042569024222, 38.76527145930699, 38.27041380746024, 36.68744741167341, 37.45501491001674, 38.83100141797747, 35.86858136313302, 37.36812073843819, 36.36068752833775, 36.11873040880476, 36.89265898295811, 36.314301354544504, 39.20826775687081, 38.47229719161987, 38.65317964553833, 38.29075118473598, 37.64868899754116, 38.733010973249165, 38.80017226082938, 39.56688513074602, 37.84770277568272, 38.91461951392037, 39.141523361206055, 39.528906277247835, 40.07464558737618, 40.65318386895316, 40.891343797956196, 40.29499380929129, 46.73361151559012, 49.205919538225444, 48.86556550434658, 44.24665321622576, 47.3158358165196, 52.0219966343471, 52.322606972285676, 49.10446541649954, 55.13069364002773, 53.86944620949881, 47.76535994665963, 49.71792187009539, 53.230118138449534, 51.94903360094343, 52.30682066508702, 54.52080161230904, 53.43505525588989, 58.86270659310477, 58.34562165396554, 58.2144535609654, 56.98323971884591, 58.21375526700701, 4.937347795282092, 0.7066163803849901, 0.08854664862155914, 0.06965626762913806, 1.5273158848285675, 39.094393730163574, 61.645592144557405, 46.32749973024641, 40.67188841956002, 17.111167124339513, 17.629688603537424, 29.342687334333146, 42.172699315207346, 43.74677201679775, 38.79055595397949, 3.728261794362749, 0.12995893002620765, 0.06123384314456156, 0.030998909646379094, 0.06861401069909334, 0.05335110505776746, 0.013364170428498514, 0.04168184640418206, 0.06795063415276152, 0.06545318423637322, 0.017927889246493578, 0.04133456200361252, 0.06787351864789214, 0.021726752365274087, 0.07258084176906518, 0.05198928866801517, 0.1172494398696082, 0.015629799703934362, 0.09836646847959075, 0.1347986760416201, 33.89753723144531, 69.6688368661063, 59.75445924486433, 47.69758721760341, 23.670226642063685, 29.960878985268728, 39.844184262411936, 54.38383524758475, 58.128222942352295, 70.80384595053536, 5.792202038424356, 0.172570332086512, 0.10227923387927668, 1.5906461094106947, 0.7268158250621387, 1.2235421623502458, 41.39085674285889, 62.36748913356236, 66.24352782113212, 61.5493665422712, 53.11199181420462, 48.907365867069785, 56.618903977530344, 57.767997060503276, 62.2193535396031, 59.06037589481899, 58.74236379350935, 61.638108934674946, 55.21223422459194, 51.43703474317278, 48.62294830594744, 46.85001816068377, 46.94271755218506, 42.960774421691895, 43.60078689030239, 41.86210094179426, 43.12722199303763, 41.02944271905081, 42.79408366339547, 43.04883936473301, 43.76961769376482, 41.29158435549055, 43.86565916878836, 43.9138240814209, 43.87991687229702, 42.141741616385325, 42.77619900022234, 42.88820048740932, 41.96654626301357, 42.39149808883667, 42.43102986471993, 41.308628286634175, 41.98210675375802, 42.91699382237026, 42.44526672363281, 39.323145798274446, 40.203868184770855, 40.643734318869456, 40.14312355858939, 43.04768248966762, 42.49106230054583, 41.735542978559224, 40.40503590447562, 42.06281355449131, 41.16793073926653, 41.34735059738159, 40.29943718229021, 40.493788719177246, 40.84371737071446, 40.51161084856306, 42.10101475034441, 40.51182624271938, 42.903250285557334, 44.67165715353829, 50.8085423878261, 50.4013466835022, 53.73430722100394, 43.342800276620046, 29.048825434276036, 52.435859135219026, 50.1416369165693, 51.60821056365967, 48.18213026864188, 49.43736750738961, 48.397451468876426, 50.65366356713431, 41.99873031888689, 39.55396842956543, 38.918493134634836, 38.89904165267944, 39.96537126813616, 40.12125757762364, 41.065382276262554, 40.07720252445766, 39.450120653424946, 39.50888156890869, 40.196082728249685, 38.09545121874128, 38.894702502659385, 39.37161643164498, 39.24657317570278, 39.51409271785191, 39.11569690704346, 41.580066612788606, 41.464309624263215, 42.13943134035383, 40.72812019075666, 41.41158321925572, 40.29586580821446, 40.7605995450701, 42.27042920248849, 40.24141277585711, 40.65005023138863, 41.009275572640554, 41.91561944144112, 42.72236088344029, 43.85825933728899, 42.69159426007952, 42.38945531845093, 48.13587263652256, 52.0257625579834, 52.00359780447823, 49.82995115007673, 50.74689449582781, 53.86287668773106, 54.499081543513704, 52.160724367414204, 55.037358488355366, 54.839758668627056, 49.10462869916643, 50.95243958064488, 54.23697117396763, 53.86680589403425, 53.5798522404262, 56.477525506700786, 55.2692928314209, 61.19417463030134, 59.518963950020925, 60.89648600987026, 59.924433026994976, 63.92918014526367, 6.878433465957642, 0.7589183481676238, 0.4810215085744858, 0.1595933905669621, 1.2793769091367722, 42.0095590863909, 67.28914138248989, 51.984382561274934, 33.27623626164028, 18.673737083162578, 22.771937472479685, 34.93333298819405, 49.864177976335796, 51.401307106018066, 50.77689334324428, 5.381447987897055, 0.12450786467109408, 0.057345593215099404, 0.05188175443825977, 0.04507116614175694, 0.0784378203430346, 0.025411404469715695, 0.03583117142053587, 0.03590687217989138, 0.04146480340776699, 0.1435395370104483, 0.15222778437393053, 0.18071239947208337, 0.11061966419219971, 0.15967793603028568, 0.10739841418606894, 0.30942733053650173, 0.08570718312902109, 0.1810334279601063, 0.25176727026700974, 43.56645931516375, 80.39413874489921, 66.15790516989571, 55.99681091308594, 20.330724375588552, 29.507060868399485, 48.10301113128662, 62.738981519426616, 64.02126462118966, 76.74227673666817, 7.754150543894086, 0.27271619758435656, 0.19817658806485788, 4.437593400478363, 10.071811641965594, 1.484882150377546, 46.83582993916103, 64.88097218104771, 68.65560191018241, 65.14865847996303, 56.12851054327828, 51.39702354158674, 58.60018975394112, 61.31956877027239, 65.82767118726457, 59.98027569907052, 61.173802512032644, 64.89221436636788, 57.49903924124581, 54.905829089028494, 50.85731874193464, 51.27342551095145, 48.90415232522147, 46.72451284953526, 45.75153923034668, 44.17569126401629, 45.19036102294922, 42.548245974949424, 44.19457299368722, 44.585068702697754, 46.131775924137656, 43.48173298154558, 44.26459346498762, 44.18634632655552, 45.209326131003245, 44.81566204343523, 45.07638624736241, 45.67302458626883, 45.00664370400565, 45.8829470361982, 44.26403413500105, 42.72361503328596, 44.62932177952358, 44.484302452632356, 45.58443505423409, 42.233589853559224, 42.75822401046753, 43.02196025848389, 42.25903068270002, 44.74948045185634, 43.5458196912493, 43.562957423073904, 44.390883922576904, 44.83867447716849, 42.195694378444124, 43.80721092224121, 42.646399702344624, 43.809152943747385, 43.91039514541626, 44.34908355985369, 45.25858538491385, 43.26108251299177, 46.17174891063145, 47.25049843106951, 52.82204348700387, 54.056106090545654, 56.04908568518502, 44.88361889975411, 31.762713636670792, 53.36943646839687, 50.64902217047555, 53.123956612178254, 51.23955304282052, 51.708177770887104, 51.41046135766165, 53.433220931461875, 45.837210518973215, 41.59776020050049, 40.43200533730643, 40.94013057436262, 42.37396778379168, 42.33073956625802, 43.35042939867292, 40.93065670558384, 42.18737391063145, 41.988238539014546, 42.71457542691912, 39.21206842150007, 41.03767286028181, 40.54963486535208, 41.66734640938895, 41.02783421107701, 40.725090776171, 42.89479085377285, 42.726234504154746, 44.17604562214443, 43.3979411806379, 41.93755490439278, 43.11616393498012, 41.880190576825825, 44.10706390653338, 42.14753988810948, 42.591620104653494, 42.65520306995937, 43.35987547465733, 43.93545729773385, 46.00003113065447, 44.00244835444859, 43.865680013384136, 51.47546870367867, 52.82057394300188, 55.71100718634469, 53.76717220033918, 54.48234333310808, 57.943077768598286, 57.10316562652588, 54.00570733206612, 56.448436873299734, 55.220547744206016, 51.38911301749093, 51.804038592747276, 53.175015449523926, 56.352061884743826, 55.53039918627058, 60.48872402736119, 57.74177803312029, 64.0778090613229, 62.83964007241385, 63.67734268733433, 62.11398410797119, 65.74246542794364, 7.141816658633096, 1.9816779153687614, 1.5458641009671348, 0.20201454497873783, 2.1526528894901276, 47.354554653167725, 71.63145978110177, 60.87483542306082, 54.494693756103516, 23.272979021072388, 28.139618907655986, 44.10008444104876, 60.143537521362305, 58.869633947099956, 60.597998346601216, 6.683552997452872, 0.2915344706603459, 0.13652649761310645, 0.14349502511322498, 0.19157060182520322, 0.11406374509845461, 0.13055766932666302, 0.11590777257723467, 0.1437649463436433, 0.11790951873574938], [0.04459430530135121, 0.0331301270718021, 0.06635197172207491, 0.04466655910281198, 0.03491236375910895, 0.04116891464218497, 0.0560472944884428, 0.050626298412680626, 0.07365162431129388, 0.27877497247287203, 43.31864486421858, 62.62998512813023, 46.11821304048811, 37.00508083615984, 18.13582491874695, 23.528516394751414, 34.65535640716553, 52.07451111929757, 60.42751734597342, 49.51543746675764, 0.8887499985950333, 0.05319288426211902, 0.31988708355597084, 0.4917203230517251, 1.8982591458729334, 7.731375217437744, 68.73886217389787, 61.62096078055245, 66.89993109021867, 56.582495416913716, 49.71025105885097, 44.676576478140696, 48.034557478768484, 53.001237528664724, 57.62462098257882, 57.2655485016959, 55.478061880384175, 52.80691725867135, 52.66524696350098, 47.648880345480784, 47.153345244271414, 47.236671515873496, 42.63386515208653, 42.51554080418178, 41.9114852632795, 39.69070897783552, 41.54522139685494, 40.075722558157786, 39.21760960987636, 40.43285649163382, 39.89997482299805, 40.40609203066145, 40.87936510358538, 40.64513438088553, 41.494947705950054, 40.449924741472515, 41.18097250802176, 40.51495293208531, 40.106506552015034, 40.06643976484026, 39.53613587788173, 40.75175101416451, 39.668297563280376, 39.296082564762656, 38.380296094076975, 38.00035122462681, 39.70458800452096, 39.404627323150635, 38.95468282699585, 38.537050928388325, 39.92607920510428, 37.90191262108939, 38.415471349443706, 39.24784122194563, 40.20397935594831, 37.332441738673616, 38.90585783549717, 38.139780725751606, 39.07005419049944, 37.667414392743794, 39.45970916748047, 38.66277163369315, 41.78589309964861, 47.07079369681222, 49.67650713239397, 47.197858878544395, 51.35156495230538, 41.9028764452253, 33.91861111777169, 51.166756766183035, 47.42565556934902, 50.105037280491416, 49.08146340506417, 48.37601975032261, 48.40458032063076, 49.86554677145821, 40.72489970070975, 37.23889119284493, 38.53228793825422, 37.608535357883994, 39.12955508913313, 38.04704311915806, 37.99730096544538, 39.38840675354004, 35.906122480119976, 36.60137660162789, 36.462360518319265, 38.73284074238369, 36.62888451984951, 36.90525606700352, 35.804095132010325, 36.56460326058524, 37.3917168208531, 35.757761069706504, 38.2769763810294, 39.65220900944301, 37.11113466535296, 37.25287444250924, 37.437067713056294, 39.75233602523804, 39.64439576012747, 38.12813207081386, 40.17006172452654, 38.139110224587576, 39.14807898657662, 39.109870842524934, 40.05083063670567, 39.285010610307964, 41.88063873563494, 39.319775921957834, 45.14990861075265, 48.31170722416469, 45.273246083940776, 48.65481621878487, 49.85659054347447, 51.941748414720806, 51.474916321890696, 49.2024940763201, 53.1420636177063, 52.82665709086827, 46.077135290418354, 47.33080571038382, 53.6908358165196, 52.5188866342817, 57.110409123556956, 58.95472853524344, 59.95765931265694, 54.269113540649414, 60.28733743940081, 55.94641562870571, 67.31810842241559, 23.941856043679373, 0.5300471835902759, 1.044736351285662, 0.06463788369936602, 0.034980115480721, 12.107605167797633, 62.714343207223074, 46.705096108572825, 45.79263435091291, 31.856489998953684, 26.93288878032139, 28.67388153076172, 32.55378341674805, 45.08539458683559, 46.55447653361729, 11.722866909844534, 0.20874440457139695, 0.044210542858179123, 0.012767346293133284, 0.0389259255358151, 0.07474077479647738, 0.0052689567341336185, 0.019200613988297324, 0.05393558494480593, 0.030900678131729364, 0.026398113130458763, 0.008361985674127936, 0.06730375279273305, 0.02863269518794758, 0.06882967626942055, 0.0038298340015379445, 0.04080001550859638, 0.027519429568201303, 0.01747466347712491, 0.6011337148291724, 52.7449323790414, 68.96123232160295, 53.21477651596069, 38.177783897944856, 16.344561951501028, 21.203994819096156, 38.84139592306954, 56.12332371303013, 64.77624893188477, 54.20250810895647, 0.934205059494291, 0.049911292136779854, 0.6183458683746201, 0.6802765737686838, 1.0023017483098167, 8.8917704139437, 72.25781903948102, 62.31339045933315, 67.76844201769147, 58.31820406232561, 52.089411531175884, 46.31161962236677, 51.15289510999407, 54.64521605627877, 59.189376149858745, 58.79293278285435, 56.36173030308315, 54.78433983666556, 55.398320879255024, 50.46066345487322, 50.08677394049508, 47.951293740953716, 44.5981000491551, 44.05108227048601, 42.03790078844343, 41.084427288600374, 42.65862853186471, 40.82958820887974, 41.50869124276297, 39.43845462799072, 40.64090640204293, 41.311852250780376, 42.293761253356934, 42.43971858705793, 42.98315804345267, 42.154081617082866, 42.726123332977295, 42.50143943514143, 41.100362982068745, 42.430901323046, 42.051838874816895, 41.95626292909895, 43.10730498177664, 40.70839772905622, 40.45590714045933, 39.627341406685964, 40.1986083984375, 40.64020810808454, 41.26900618416922, 39.205485003335134, 42.00878783634731, 40.34116458892822, 41.67334270477295, 40.97514602116176, 42.76181970323835, 38.12976489748274, 41.334697927747456, 40.55697216306414, 41.153860637119834, 39.0922988482884, 41.41564096723284, 41.60526772907802, 44.17724071230207, 49.17817538125174, 51.65721273422241, 50.89672197614397, 52.90739515849522, 44.463628087724956, 35.587804658072336, 53.113065310886924, 48.767154693603516, 51.782728467668804, 50.03928647722517, 50.48520449229649, 51.38844946452549, 50.3853554044451, 42.640174116407124, 39.41482727868216, 39.69525309971401, 41.2877003124782, 40.33932679040091, 41.15485075541905, 39.56547812053135, 39.79656825746809, 38.03074264526367, 38.89847537449428, 38.334615162440706, 40.62013128825596, 38.60979856763567, 39.20648554393223, 37.54953472954886, 38.46817690985543, 39.79622432163784, 38.330866609300884, 40.59346757616316, 41.563119956425254, 40.0109931400844, 38.87639052527291, 40.21632283074515, 39.837124892643516, 41.66943086896624, 40.76132910592215, 39.511636529650005, 39.96525662285941, 40.08573143822806, 40.07351303100586, 42.311760561806814, 39.82414218357631, 43.7794702393668, 42.92155531474522, 46.837146622794016, 49.300349031175884, 50.328463554382324, 49.94255018234253, 53.10643672943115, 52.92617613928658, 55.01835169110979, 51.25139624731881, 54.92576347078596, 53.44756896155221, 48.85708522796631, 47.9339406149728, 53.758504322596956, 52.33039937700544, 58.524961607796804, 60.642168045043945, 61.43736852918352, 56.97090319224766, 63.37351185934884, 57.52812787464687, 71.3979377746582, 27.990581784929546, 0.3184708452650479, 1.0757288996662413, 0.676885690007891, 0.14353535723473343, 12.018344266074044, 66.79608331407819, 53.60618938718523, 42.18140540804182, 29.289057663508824, 35.42761046545846, 32.171062741960796, 40.772883960178916, 51.81495768683297, 56.80597727639334, 16.111144168036326, 0.11427471520645277, 0.11736576791320529, 0.07291312715304749, 0.019701968246538724, 0.04618250472205026, 0.04671969411096402, 0.012062354345938988, 0.09391130254204784, 0.029023188698504652, 0.12600493005343846, 0.10146928698356662, 0.16858939427350247, 0.06472422049513885, 0.12456890568137169, 0.1396450445588146, 0.11959763243794441, 0.15160070945109638, 0.12045386220727648, 1.5731515224490846, 64.97538430350167, 77.49519048418317, 64.49971757616315, 50.62450197764805, 27.462357146399363, 32.16570915494646, 49.57985421589443, 63.688570976257324, 70.50443417685372, 58.25893592834473, 1.6473655572959354, 0.20678639678018435, 1.1766237999711717, 5.001935209546771, 6.265700059277671, 9.611895612307958, 74.54249790736607, 64.64651216779436, 71.1811956678118, 61.413008144923616, 54.716157163892476, 48.20442008972168, 53.23821973800659, 57.007318701062886, 63.086995942252024, 61.66907010759626, 59.546457971845356, 57.696222169058665, 58.954228264944895, 52.95116533551897, 52.20615863800049, 51.89481680733817, 46.575678961617605, 45.86050435474941, 46.620175225394114, 43.574963910239084, 46.00597184044974, 43.82048545564924, 43.16513136454991, 42.512240409851074, 44.570439270564485, 43.712861333574565, 43.30022518975394, 43.72655275889805, 44.47685398374285, 43.61405100141253, 45.461438042776926, 45.3123505456107, 42.50203003202166, 44.386305059705464, 42.94851779937744, 45.797498089926584, 45.845294748033794, 44.241101605551584, 41.142218930380686, 41.17362478801182, 41.615825516836985, 43.04598018101284, 42.62034395762852, 41.18199389321463, 45.161140373774934, 43.85535151617867, 43.06354175295149, 43.88202217647007, 44.6559750693185, 40.249986852918354, 43.30103118079049, 43.08062737328665, 44.83273376737322, 41.335125241960796, 43.269455092293875, 42.5196749823434, 47.64135544640677, 51.64919103894915, 54.117007051195415, 51.5138783454895, 53.397969245910645, 46.64636993408203, 38.040845326014924, 56.65953356879098, 52.128370080675396, 53.453672954014365, 54.306234291621614, 52.38700635092599, 52.363382475716726, 54.607963289533345, 45.44213942119053, 40.45617812020438, 42.31702382223946, 43.31390619277954, 42.29633903503418, 43.18117128099714, 43.273742130824495, 43.485808100019185, 39.85557235990252, 40.45192582266671, 40.70201233455113, 42.29103755950928, 41.84003346306937, 42.543771335056846, 39.132973602839876, 40.26341424669538, 42.40605109078543, 38.19452558244978, 41.90335587092808, 43.17189196177891, 43.209523405347554, 40.338010106767925, 42.17716005870274, 43.060957023075645, 43.89202410834176, 43.1334718976702, 42.19730288641793, 41.49578148978097, 42.556677613939556, 42.99338926587786, 43.55544989449637, 42.953965187072754, 45.53242778778076, 43.41811180114746, 48.13594559260777, 51.98383365358625, 54.983787877219065, 54.652716636657715, 56.13005651746477, 56.68769461768014, 56.09446437018258, 55.50743538992745, 54.61132969175066, 53.68834836142403, 51.489646502903526, 50.540057046072825, 52.29473079953875, 51.816437653132844, 59.11804594312395, 63.53946263449532, 64.42239107404436, 60.55275862557547, 66.38891887664795, 60.58327511378697, 73.63885688781738, 29.193443502698624, 0.8665376390729631, 3.9767623799187795, 0.6873560824564525, 0.14905206406755106, 17.622962747301372, 74.28849261147636, 59.22759124210903, 59.02229281834194, 41.81547852924892, 38.07062183107649, 40.36656025477818, 50.59983934674944, 61.522942543029785, 67.72176401955741, 20.209183011736187, 0.35419419407844543, 0.21661032177507877, 0.14759306449975285, 0.1669944298586675, 0.142403601535729, 0.1937316001525947, 0.14589439279266767, 0.1889194840831416, 0.15261117023016724], [0.033034202576215775, 0.11521036071436745, 0.026432837160038095, 0.026597617692979317, 0.04388733966542142, 0.021445124709446515, 0.025534383852833083, 0.06126248410769871, 0.05505790561437607, 1.6297432971852166, 44.76297385351998, 55.58961868286133, 45.06559222085135, 36.77266011919294, 26.486835275377544, 41.72265059607369, 32.660215922764365, 52.741041387830464, 66.0953505379813, 35.808031286512104, 0.06283526721277408, 0.0939493208591427, 0.30811838220272747, 0.2995545103081635, 0.4078712266470705, 25.554189000810894, 69.41864613124302, 60.880977630615234, 63.359455653599326, 56.1906031199864, 51.756575448172434, 41.12478590011597, 46.29398162024361, 48.26562329701015, 52.83463362285069, 51.79036801201956, 54.02542979376656, 49.21089097431728, 50.31920855385916, 47.945325238364084, 47.4097580909729, 46.43067353112357, 45.018775258745464, 38.98889575685774, 42.31145484106881, 41.10105085372925, 41.53188780375889, 40.80580105100359, 40.13978147506714, 38.07429395403181, 41.58694532939366, 39.4463095664978, 40.951237269810264, 39.036657673971995, 39.45387268066406, 41.43648208890642, 39.92271975108555, 39.42792463302612, 41.29503413609096, 39.340742111206055, 38.761290141514365, 38.794210706438335, 40.25420093536377, 37.81924295425415, 38.19294834136963, 38.44123179571969, 38.33237089429583, 37.46830333982195, 40.44515480313982, 39.50821801594326, 39.81185776846749, 38.25718443734305, 39.26828629629952, 39.15800101416451, 38.56544821602957, 37.88978106634957, 38.82177768434797, 37.726369857788086, 39.30156816755022, 37.701630796704976, 39.204036303928916, 36.88373054776873, 40.52579212188721, 46.45900133677891, 49.983158929007395, 50.58514043263027, 50.07464238575527, 44.891796929495676, 35.29544530596052, 48.16502380371094, 47.48138012204851, 43.57787867954799, 43.25722278867449, 47.09527914864676, 46.02211250577654, 42.08809804916382, 37.44650684084211, 37.61018902914864, 37.33734369277954, 37.84763329369681, 38.96352093560355, 37.7015335219247, 36.67298126220703, 36.64635229110718, 36.36674288340977, 35.95839030402047, 36.6426454271589, 37.1594489642552, 36.6304235458374, 37.40094402858189, 37.199064118521555, 38.60953106198992, 39.561913694654194, 39.08338778359549, 38.785935401916504, 39.88064840861729, 38.4632054737636, 38.10964638846261, 40.54069948196411, 39.74728468486241, 39.58359554835728, 37.58166319983346, 37.97097076688494, 38.692398752485005, 38.73970903669085, 39.461762360164094, 40.251588412693565, 40.10541568483625, 39.84134939738682, 38.46115575517927, 44.90236166545323, 50.02013029370989, 46.070944445473806, 44.38072565623692, 46.68048211506435, 51.131710052490234, 53.275010449545725, 51.72161558696202, 48.71631472451346, 49.78341211591448, 46.39009257725307, 45.43122032710484, 47.32277011871338, 51.23769787379673, 47.473879541669575, 50.36308642796108, 58.22480290276663, 54.27074984141758, 52.990158626011436, 54.107609612601145, 61.80788121904646, 50.07913787024361, 0.3242625759116241, 0.8614714252097266, 0.5897286811045238, 0.10789190591978175, 3.5389479185853685, 52.493869645254954, 57.779333046504426, 45.78368854522705, 39.26588569368635, 15.394944701875959, 17.02232050895691, 33.474517004830496, 43.81341566358294, 49.55298205784389, 25.4280983039311, 0.2206407112202474, 0.027884255795340453, 0.02560947901968445, 0.03842455940321088, 0.07066982252789394, 0.051459478347429206, 0.047606552951037884, 0.03943911174844418, 0.014020658996222275, 0.019420723962996687, 0.03604113729670644, 0.02172598392436547, 0.005089805677666196, 0.04828082676976919, 0.01717654911668173, 0.07300643928881202, 0.13014718278178147, 0.023312653248597468, 2.8688571325370242, 54.151334626334055, 62.00510583605085, 52.82536472593035, 45.72526809147426, 33.799609320504324, 37.74478258405413, 35.82523155212402, 57.23729017802647, 71.82354273114885, 37.990373611450195, 0.03266997515623059, 0.02276749107321458, 0.945995392543929, 0.743817578469004, 0.0895304429743971, 27.65488304410662, 70.0823450088501, 63.37683309827532, 64.84373678479875, 57.43368795939854, 53.20353433064052, 44.07404259272984, 47.87850441251482, 50.87312936782837, 56.211531094142366, 53.733542919158936, 54.98962088993618, 51.714403356824604, 52.96523196356637, 51.041369574410574, 49.17385707582746, 48.19681876046317, 46.71503550665719, 42.3448200907026, 43.847388880593435, 42.414691175733296, 43.917961733681814, 42.93203319822039, 42.172424861363, 40.457411425454275, 42.867904799325125, 40.18282903943743, 41.82681451525007, 41.77362258093697, 41.568035806928364, 42.45660270963396, 42.5594117300851, 42.47702693939209, 42.2393707547869, 41.65733405521938, 41.073212896074565, 40.22332661492484, 41.31072316850935, 39.56126751218523, 41.632032190050396, 39.21684530803135, 40.087923594883506, 39.51850482395717, 41.72560358047485, 40.84257786614554, 42.52591446467808, 39.776696409497944, 41.33014338357108, 40.36356210708618, 40.728669098445344, 39.48222827911377, 40.6215626171657, 40.216097014290945, 40.86398526600429, 40.223736558641704, 41.2854768889291, 38.79381465911865, 43.157985142299104, 49.208261081150596, 53.30821936471121, 51.43477657863072, 51.68803494317191, 47.49179547173636, 37.24333109174456, 50.327803475516184, 49.751526832580566, 45.031080518450054, 45.47593198503767, 49.30755083901541, 48.48751401901245, 44.71832472937447, 38.52691698074341, 39.66960382461548, 39.320786884852815, 40.73795536586216, 41.32541166033064, 39.49367891039167, 38.60627235685076, 37.0367020879473, 37.25689050129482, 37.85714190346854, 40.49450090953282, 39.82719939095633, 38.08870104381016, 38.8031530380249, 39.61780847821917, 39.864872523716514, 40.47304834638323, 41.3870769228254, 42.066492625645225, 42.64175483158657, 40.9309207371303, 40.304971422467915, 40.42762449809483, 40.81385053907122, 41.636114256722585, 39.987174715314595, 40.95199809755598, 40.99112687792097, 40.82337304524013, 41.3300495828901, 41.91406651905605, 40.71743733542306, 41.751888615744456, 40.286878313337056, 46.12012726919991, 52.908343587602886, 50.02602931431362, 47.6805293900626, 49.30662325450352, 54.62784208570208, 55.07131780896868, 53.85415669849941, 51.4217973436628, 51.1793851171221, 47.90022448131016, 45.73386648723057, 47.745540210178916, 50.84080982208252, 46.94505214691162, 50.598248209272114, 59.407632963997976, 55.98550966807774, 56.76966251645769, 56.36550317491804, 63.68862656184605, 55.06978225708008, 0.5419839173555374, 0.9959992979254041, 1.2873973016227995, 0.1525010032845395, 4.174545458384922, 56.46819060189383, 65.76677022661481, 47.336590085710796, 38.70849078042166, 23.4647718838283, 23.449077640260967, 41.5045952796936, 50.71647875649588, 57.899213790893555, 31.63826792580741, 0.46590325981378555, 0.018484773114323616, 0.018612034053408673, 0.05346624566508191, 0.032677506894937584, 0.01900133164599538, 0.015386176794501287, 0.023632397609097616, 0.05092794115522078, 0.1318359071654933, 0.1788223808897393, 0.09046275687537023, 0.17008506187370845, 0.14759794995188713, 0.25959498594914165, 0.21513154969683715, 0.3455119313938277, 0.30177581682801247, 4.488733444895063, 68.26921258653913, 68.50190775735038, 62.07664448874337, 51.06976686205183, 36.859915597098215, 55.182544572012766, 46.22131388528006, 63.888811111450195, 76.4676352909633, 43.6653391293117, 0.28069454804062843, 0.16787305128361496, 1.7615628923688615, 3.704873723643167, 1.9488059878349304, 29.301884038107737, 72.44110557011196, 65.90834672110421, 67.82681383405412, 60.94834041595459, 55.06843430655343, 46.66393150602068, 51.427682467869346, 53.992658615112305, 57.46802248273577, 56.15163762228829, 57.78688226427351, 54.877702781132285, 55.715068408421104, 55.13550526755196, 51.6553749356951, 51.03154134750366, 50.47884341648647, 44.54831273215157, 46.74071952274868, 44.61404963902065, 46.42884268079485, 45.383076259068076, 44.29145867483956, 43.26481022153582, 45.061548369271414, 43.08469901766096, 42.7998298236302, 43.07234512056623, 43.03490475245884, 43.98025928224836, 43.5867133140564, 42.00090857914516, 44.70731183460781, 43.786248207092285, 43.1900371823992, 43.66876459121704, 43.769972051892964, 42.3824828011649, 42.63567863191877, 41.88378626959664, 42.813430922372, 41.480043819972444, 44.47842427662441, 43.331043924604145, 44.13852882385254, 40.39578090395246, 43.491286754608154, 43.36110877990723, 42.373022828783306, 41.844688756125315, 43.974728516169954, 41.054998193468364, 42.98224435533796, 43.252442428043906, 43.813155106135774, 41.632966722760884, 44.305045877184185, 52.205908502851216, 55.30584383010864, 56.685877663748606, 55.210584027426584, 49.96637902941023, 40.17262213570731, 52.35397808892386, 52.3972931589399, 47.27811752046858, 48.009655135018484, 52.62588194438389, 51.35869032996041, 46.89980200358799, 42.167217186519075, 41.73213488715035, 41.43707963398525, 42.499688489096506, 44.605076040540425, 42.36089127404349, 41.95824316569737, 39.052666323525564, 40.61776542663574, 39.9931640625, 42.11423717226301, 43.148341042654856, 40.68625382014683, 42.14885657174246, 41.53431619916643, 42.13281318119594, 44.07613052640642, 44.31146253858294, 44.27626643862043, 43.47454507010323, 42.37616341454642, 42.14638648714338, 43.32175418308803, 43.92901284354073, 42.734263147626606, 41.955317974090576, 41.50639138902937, 43.427453654153005, 42.005206039973665, 44.04843153272356, 44.22729206085205, 43.36453424181257, 43.30622843333653, 41.83062560217721, 49.093275342668804, 55.649161270686555, 51.6506883757455, 51.90024682453701, 52.877069745744976, 58.183051177433555, 58.0371424811227, 54.75039093835013, 53.81199502944946, 55.031713077000205, 49.001281193324495, 48.29041446958269, 49.02767392567226, 53.62622104372297, 48.86664942332676, 54.558440004076274, 62.873894691467285, 58.22857230050223, 57.57997880663191, 57.093643120356965, 65.8565479006086, 56.95016629355294, 0.47190036943980623, 3.978871592453548, 1.8379850430147988, 0.3423175242330347, 5.576192532266889, 62.26990168435233, 69.58090046473912, 60.45861053466797, 52.61742946079799, 22.780523708888463, 29.546279975346156, 48.60065501076834, 60.429615701947895, 67.4748180934361, 39.49730587005615, 0.8836867702858788, 0.14770186080464295, 0.18218472546764783, 0.16244972444006375, 0.11205607532922711, 0.10004793932395321, 0.22209068627229758, 0.12985108367034368, 0.07748027851006814], [0.05880685230450971, 0.10962807347199746, 0.03513543214648962, 0.038252085979495726, 0.05871330268148865, 0.07257306575775146, 0.037070105118410926, 0.10875087018523898, 0.10835844624255385, 7.707049574170794, 63.429076603480745, 53.10933065414429, 44.77577938352312, 14.773186888013567, 15.144290174756732, 25.552207027162822, 42.88761336462838, 57.36072492599487, 65.62670843941825, 17.264310632433208, 0.16894453950226307, 0.18607699232442038, 0.5664560699037143, 0.31244729991470066, 1.5062351588691985, 48.58475753239223, 64.90379701341901, 62.50353486197335, 61.60876669202532, 57.640525409153526, 50.57876546042306, 46.14285135269165, 43.17114850452968, 43.37436941691807, 44.4987199647086, 45.099047797066824, 44.701478821890696, 45.3895901952471, 44.07409470421927, 44.387538364955354, 42.497645718710764, 41.46144001824515, 40.89765623637608, 40.98133339200701, 39.78855351039341, 40.01357439586094, 38.62134299959455, 38.45348146983555, 39.0520270892552, 39.014395645686555, 40.55879953929356, 40.6031950541905, 40.64978967394148, 39.742438316345215, 38.90996422086443, 40.565542766026084, 38.289569990975515, 38.91377878189087, 38.61638198580061, 39.07709618977138, 38.77504757472447, 39.032686778477256, 37.88726234436035, 40.391365323747905, 37.698809828077046, 40.59820624760219, 38.31539297103882, 38.431427887507844, 38.38166836329869, 37.45772123336792, 37.332535539354595, 37.97185666220528, 39.527030263628276, 37.65076650891985, 38.13300970622471, 37.10968596594674, 38.828760623931885, 39.042591435568674, 37.408281326293945, 38.364329133714946, 36.40647963115147, 37.85092673982893, 38.45888369424002, 45.50287709917341, 50.062531675611226, 46.926979882376536, 50.077949728284565, 46.73632478713989, 35.21517276763916, 48.564882210322786, 47.78910541534424, 41.51645238058907, 37.67706196648734, 38.903835909707205, 39.45637403215681, 36.917557852608816, 36.91647045952933, 37.44465514591762, 37.11376108442034, 37.03257485798427, 37.643533434186665, 37.14198466709682, 36.83719846180507, 36.44569526399885, 36.31749405179705, 36.57289940970284, 37.763577461242676, 37.74960115977696, 36.82585552760533, 36.790096623556956, 37.13409498759678, 37.620430673871724, 38.58458702904837, 38.64612027576992, 37.6098416192191, 38.32598549979073, 38.72184174401419, 39.66655009133475, 37.45359747750418, 40.74887445994786, 39.30577877589634, 38.18393652779715, 38.8558030128479, 38.638279233660015, 39.574020930698936, 40.20678642817906, 38.73584236417498, 39.25412239347185, 39.82426725115095, 40.73182358060564, 44.77773182732718, 49.70749262401036, 49.18634646279471, 43.776326179504395, 47.05791868482317, 50.76650926045009, 52.0567306791033, 56.47723715645926, 52.730417592184885, 51.53894397190639, 50.99372230257307, 51.073355606624055, 46.55999340329851, 47.07660239083426, 49.01429516928536, 51.16010734013149, 54.71007054192679, 54.76443672180176, 51.91680785587856, 57.4663097517831, 59.18006556374686, 67.76783057621547, 9.485475744519915, 1.3932799228600092, 1.5087582234825407, 0.1718762857573373, 0.7122204825282097, 35.67215231486729, 61.95083345685686, 46.35220752443586, 41.69057771137783, 19.023269687380107, 13.566273501941136, 21.33659076690674, 41.413056237357004, 46.970558983939036, 41.71197468893868, 2.8239889230046953, 0.10107382320399795, 0.040703962091356516, 0.023626109285812293, 0.02131795197991388, 0.02037279850005039, 0.038969002331474, 0.01728484669833311, 0.05082192345123206, 0.05965616101665156, 0.036908786810402355, 0.015501453108819467, 0.03483177076226898, 0.042348937929740975, 0.05998255671667201, 0.03948455323864307, 0.0826889236590692, 0.1438186184636184, 11.47954533781324, 72.90542588915143, 59.112765312194824, 53.56354481833321, 20.57176433290754, 16.082545382635935, 26.0902008329119, 46.403050967625205, 62.634293011256624, 71.63158484867641, 19.92618462017604, 0.3039676477866513, 0.10874953347125224, 1.091601842216083, 0.21974693132298334, 2.124759997640337, 48.91828843525478, 69.06655311584473, 65.01475279671806, 63.299506596156526, 60.19181360517229, 51.67611878258841, 47.67068031855992, 45.09134571892874, 44.84920447213309, 46.57705470493862, 47.241576944078716, 47.93699434825352, 46.6653732572283, 47.026432922908235, 47.391470432281494, 45.0718560218811, 44.338112354278564, 42.649418694632395, 43.47294698442732, 41.925586632319856, 42.36947577340262, 39.36287907191685, 40.79430178233555, 41.078847885131836, 41.717029503413606, 41.71754019601004, 42.751032624925884, 43.066147327423096, 42.23551797866821, 42.1993282863072, 41.263975688389365, 40.832791328430176, 40.81044244766235, 42.43950319290161, 42.64441251754761, 41.45914363861084, 39.88670028959002, 40.35266038349697, 40.77980089187622, 40.026741232190815, 40.55462714603969, 40.25226933615548, 39.77579314368111, 40.030065945216585, 39.34209353583199, 41.21086365836007, 39.60739312853132, 40.881025723048616, 39.538074425288606, 40.2779290335519, 39.22931037630354, 41.05368150983538, 40.314685004098074, 40.599185943603516, 41.030978270939414, 37.73627798897879, 40.111394609723774, 39.19128635951451, 48.476515020642964, 53.30145876748221, 49.80152259554182, 52.43416724886213, 49.544494833265034, 36.92483956473214, 50.409413542066304, 49.71572971343994, 44.1089677129473, 39.75570590155465, 40.91803877694266, 42.1891804422651, 38.55325065340315, 38.70859847749983, 40.911792346409385, 39.32800606318882, 39.129440443856375, 40.61946078709194, 38.078157152448384, 37.954117911202566, 39.29654809406826, 38.4917208807809, 37.79869365692139, 39.942101751055034, 39.05882937567574, 38.869285992213655, 39.48145355497088, 38.93485614231655, 38.99742119652884, 41.22424936294556, 41.406076771872385, 40.574582372392925, 41.41698891775948, 39.86222873415266, 40.77417632511684, 40.51084654671805, 42.87262610026768, 41.31177582059588, 40.83104385648455, 40.656331402914866, 40.86266163417271, 39.341308389391216, 42.456776414598735, 40.20586926596505, 40.2617848941258, 41.31453078133719, 40.85476153237479, 45.67508820125035, 54.00538076673235, 51.80120025362287, 47.15903581891741, 50.314803395952495, 52.322770254952566, 52.56598847252982, 57.32134601048061, 55.312312602996826, 53.15412221636091, 52.30958604812622, 50.34314162390572, 47.694491795131135, 49.93212441035679, 52.43740858350481, 54.281832218170166, 57.15762908118111, 57.24078164781843, 54.05205529076712, 60.01059068952288, 58.79479490007673, 70.21641744886125, 11.944339871406555, 1.0837085800511497, 4.024144751685006, 0.09565245054130044, 0.5019412860274315, 39.58362334115164, 66.99551745823452, 50.21349171229771, 40.74353476933071, 20.200277158192225, 19.04915346418108, 26.89668345451355, 49.56909493037632, 52.84851959773472, 49.74572508675711, 3.7790470463888983, 0.16911455323653563, 0.0584988109767437, 0.06806123536080122, 0.04032496635669044, 0.03795863315463066, 0.03353560942092112, 0.04164383147976228, 0.01055564358830452, 0.1633952629885503, 0.11658767823662076, 0.1488856737102781, 0.08356278176818575, 0.1770752074995211, 0.17406381480395794, 0.16618001141718455, 0.2709162341696875, 0.31693388202360695, 16.056196076529368, 85.47946970803397, 66.4737216404506, 62.72532830919538, 24.337001834596904, 22.986970322472708, 36.38288354873657, 56.37220818655831, 68.00539643423897, 77.51121997833252, 22.640481029238018, 0.36464254770960125, 0.32903650403022766, 2.364935338497162, 3.5430836166654314, 2.2404787710734775, 53.12901490075247, 70.44094848632812, 67.63804517473493, 65.32551097869873, 62.16038417816162, 54.52019017083304, 50.02676234926496, 47.47467858450753, 48.25225843702044, 49.37478855678013, 48.72600746154785, 50.38938535962786, 50.19323076520647, 49.89468056815011, 50.24530751364571, 47.99491800580706, 45.951345103127615, 44.67976222719465, 45.8191556249346, 45.251334939684185, 45.1378812789917, 41.944683756147114, 43.07412385940552, 43.8187484060015, 42.18459810529436, 45.05782413482666, 45.04075935908726, 44.67423493521554, 43.76676893234253, 43.17421613420759, 43.11811637878418, 43.539093835013254, 41.6983596937997, 43.938250473567415, 44.48941632679531, 43.83199862071446, 41.628405230385916, 42.458183424813406, 44.02229240962437, 42.65912880216326, 44.142287799290244, 42.43709216799055, 41.96931512015206, 42.58609628677368, 42.03106376102993, 41.71639721734183, 41.762606212071006, 45.34832831791469, 40.31309734072004, 42.790967396327424, 41.13058417184012, 43.803681237357004, 43.041526385716026, 42.35331078938076, 43.77694109507969, 39.59875999178205, 41.19450759887695, 40.89764928817749, 48.9697711127145, 55.691986492701936, 50.61582367760794, 54.17082779748099, 51.345231669289724, 39.36329596383231, 54.534413133348735, 51.16411645071847, 46.271938460213796, 43.34463460104806, 43.32297011784145, 43.58004304340908, 41.94279037203108, 40.460454736437114, 42.075764996664866, 40.66035788399832, 40.88766820090157, 42.46013586861746, 39.88081863948277, 38.90898452486311, 40.563993317740305, 39.990089484623496, 40.0620241846357, 43.41606903076172, 42.08892488479614, 41.61949069159371, 40.70366253171648, 42.12622628893171, 42.036479881831575, 42.87988349369594, 43.92729663848877, 42.4325966835022, 43.47225216456822, 42.2137770652771, 43.902828557150706, 41.666717597416465, 45.72288485935756, 42.47201034000942, 41.470639433179585, 43.18411731719971, 43.51429224014282, 43.16902582986014, 45.111551080431255, 41.40061201368059, 42.19477721623012, 42.95435776029314, 44.80939824240548, 47.80425943647112, 56.77523497172764, 54.098708970206125, 51.64751999718802, 54.85975211007254, 53.250031675611226, 55.43424654006958, 60.22057914733887, 57.728531292506624, 56.898308413369314, 55.02713074002947, 52.30312769753592, 48.44691569464547, 51.27951908111572, 53.92908607210432, 54.920778138296946, 58.9811247416905, 59.683247157505576, 57.67055204936436, 63.44231292179653, 63.11301694597517, 74.25319576263428, 12.16455955164773, 3.2248754458768025, 5.26433436359678, 0.4142678034092699, 1.4623938713754927, 46.053528785705566, 72.17612212044853, 58.563114166259766, 54.898259026663645, 26.5591938155038, 22.07513737678528, 35.28042677470616, 60.280569893973215, 61.16345664433071, 58.79772703988211, 5.688431995255606, 0.37526637049657957, 0.19349114091268607, 0.1161950235920293, 0.16906702864382947, 0.07567912087376628, 0.08993787611169474, 0.07788833589958293, 0.14022395706602506], [0.07198313384183816, 0.07240432088396379, 0.03799559974244662, 0.10021409897931985, 0.05912766366132668, 0.08735502577785935, 0.009624283029032605, 0.1471371025379215, 0.0754960724817855, 17.37698609488351, 59.77610983167376, 50.440009934561594, 31.556206226348877, 37.84998525891985, 50.210615158081055, 38.22982937949044, 46.18336629867554, 56.25341483524868, 59.699512890407014, 4.527835735252925, 0.05061294145083853, 0.054827437802617035, 0.2928662177707468, 0.28580114830817493, 14.162417650222778, 61.03367124285017, 60.55539199284145, 64.38864367348808, 59.12867668696812, 58.82798644474575, 49.97680132729666, 45.96832650048392, 45.17875753130232, 41.314304964882986, 40.15106534957886, 41.79686083112444, 40.088892868586946, 40.66385282788958, 38.16555854252407, 39.488373960767476, 39.17204679761614, 39.69437762669155, 37.31790958132063, 37.32602507727486, 38.657504899161204, 39.75041832242693, 39.474599157060894, 40.06109312602452, 39.38791690553938, 38.34335252216884, 40.20533772877285, 40.19651699066162, 40.206682205200195, 40.17526592527117, 39.586576325552805, 40.06951434271676, 39.00741270610264, 39.84860331671578, 38.77728836877005, 38.56916550227574, 39.760145800454275, 38.482879298073904, 38.68556867327009, 37.943525382450645, 39.8694201196943, 39.10303381511143, 37.61568505423409, 37.95209945951189, 39.06490210124424, 37.73333542687552, 36.659588609422954, 37.28668785095215, 36.65915434701102, 38.29533004760742, 36.367663519723074, 36.33452408654349, 36.23745427812849, 36.4478874206543, 39.04639557429722, 38.88023287909371, 37.312385763440815, 37.12915481839861, 37.596299580165315, 41.13846690314156, 47.84411777768816, 50.3930401120867, 48.4305214200701, 51.0135246685573, 35.57363033294678, 46.361299242292134, 47.49924046652657, 44.894100257328574, 39.17167854309082, 37.73813315800258, 38.79227910723005, 39.26501022066389, 36.80814109529768, 36.25997338976179, 36.877091544015066, 37.64029904774257, 38.13170691898891, 37.642779554639546, 35.56702259608677, 36.51969705309187, 35.85995864868164, 36.11074692862374, 36.384710924965994, 37.632332938058035, 36.06000076021467, 37.722767216818674, 37.28386688232422, 35.93902220044817, 36.50890302658081, 38.12297303336007, 37.848300320761545, 38.79011126926967, 39.002382210322786, 37.008676528930664, 38.14344590050833, 39.61020367486136, 39.732655252729145, 37.95038325445992, 37.746297291346956, 38.22544159208025, 39.18394906180245, 37.928486006600515, 39.75693573270525, 39.472514697483604, 40.752459730420796, 39.83872297831944, 42.49339689527239, 48.34207780020577, 49.94354724884033, 43.34905365535191, 47.45999356678554, 50.71504742758614, 51.71813801356724, 53.149230684552876, 51.54991865158081, 50.7130845614842, 50.40497016906738, 53.31119319370815, 54.70252479825701, 57.03632395608084, 58.04088061196463, 61.18885925837925, 52.72755493436541, 51.40126889092581, 47.59779371534075, 56.372229031154085, 55.77527802331107, 68.30954687935966, 30.146517481122697, 0.43051836426768986, 2.5255344808101654, 0.023647259222343564, 0.19154206264231885, 24.39130026953561, 64.0112383706229, 45.748989241463796, 52.745227677481516, 40.09578548158918, 14.884823594774518, 21.49413422175816, 40.134942054748535, 44.70945882797241, 50.163544586726594, 10.865057945251465, 0.1795903468238456, 0.05481484079999583, 0.05229953523459179, 0.04860249308070966, 0.022235682466998696, 0.04517371992447546, 0.022161679741527354, 0.04202560920800481, 0.04927024617791176, 0.03904516449464219, 0.05893696139433554, 0.05093404797038861, 0.07651521850909505, 0.03474068761404071, 0.020068477240524123, 0.050686345369155915, 0.09396582283079624, 22.78373725073678, 69.13563905443463, 55.20962517602103, 43.884151799338206, 44.06273092542376, 47.41200930731637, 35.500222614833284, 53.62924698420933, 61.125602858407156, 66.02396474565778, 5.923151263168879, 0.10475295542606286, 0.13255087951464312, 1.1966007394450051, 0.5244861277086394, 15.91236662864685, 64.55651215144566, 61.82256276266915, 67.32488291604179, 61.554695810590474, 60.876954623631065, 53.04743610109602, 47.18478584289551, 46.96734544209072, 44.554809297834126, 42.419405528477256, 44.65859801428658, 41.47999518258231, 41.6112779208592, 41.705933230263845, 42.04085029874529, 40.55464799063546, 41.25904941558838, 39.17665345328194, 39.98503814424787, 41.520854064396445, 41.86554724829537, 41.05768714632307, 42.08952590397426, 41.53829404285976, 40.08753449576241, 41.21993800571987, 41.689177649361746, 42.270825249808176, 41.61872638974871, 41.483465807778494, 41.45916100910732, 40.335651193346294, 41.57425791876656, 40.87698187146868, 40.79227985654558, 41.43620763506208, 39.318361963544575, 41.41403245925903, 41.09487043108259, 40.79578522273472, 41.12433426720755, 39.59320143290928, 40.53688144683838, 40.64386633464268, 39.2866781779698, 38.10595342091152, 39.4591463633946, 38.6842554637364, 37.736847741263254, 39.29460954666138, 39.50517817905971, 39.10822411945888, 38.887156758989605, 40.517155511038645, 41.407772132328574, 40.840079988752095, 40.37488072259085, 38.861962590898784, 42.404734407152446, 50.51972314289638, 52.30396148136684, 49.41378879547119, 53.43586124692644, 37.56781196594238, 47.728951386043, 51.02875164576939, 46.250002997262136, 41.005916118621826, 39.796092305864605, 39.800612109048025, 41.420139925820486, 38.67074816567557, 39.1043643951416, 40.89337614604405, 40.245956897735596, 39.20513064520699, 39.16127014160156, 38.27801513671875, 38.54654911586216, 38.2317019190107, 38.06720331736973, 38.84516532080514, 39.15669822692871, 38.72518730163574, 39.88246883664812, 38.85030698776245, 37.72292702538626, 39.44125475202288, 39.006405217306956, 39.69462776184082, 39.76134436471121, 41.01190546580723, 39.9292962210519, 41.317504610334126, 40.55401223046439, 41.14000245503017, 38.931618281773154, 40.508254868643625, 41.068272726876394, 40.70694555555071, 39.87886619567871, 40.88633762087141, 40.87880229949951, 41.47222709655762, 41.04469401495797, 44.04659373419625, 49.64408336366926, 51.55595316205706, 46.93631131308419, 50.7473600251334, 52.27019671031407, 53.627999782562256, 54.15225178854806, 54.34179517201015, 52.18059968948364, 53.19015210015433, 55.17824363708496, 56.2138865334647, 59.442019598824636, 59.720454760960166, 64.56391198294503, 56.79307099751064, 53.42883314405169, 50.59056350163051, 59.11027785709926, 58.44533525194441, 69.0143860408238, 34.291131837027415, 0.3497971514505999, 5.319562554359436, 0.09135285911283322, 0.06227933668664523, 26.749171461377824, 68.67827388218471, 52.28866849626814, 50.02275671277727, 36.97751038415091, 21.658780472619192, 27.675513982772827, 49.50747830527169, 50.815501008714946, 59.58501352582659, 13.399542791502816, 0.18877110204526357, 0.08118818061692373, 0.051880156488290856, 0.08109093976340123, 0.024325271769027625, 0.03295158415234514, 0.08123873826116323, 0.016578473084207093, 0.11660020399306502, 0.14440130362553255, 0.1329713948071003, 0.16933131803359303, 0.19063483418098517, 0.10263553940291915, 0.1864575283335788, 0.38901134580373764, 0.14001103277717317, 30.749697549002512, 78.92972946166992, 65.29073524475098, 48.240001814705984, 49.217634201049805, 60.26901503971645, 51.00441558020455, 61.62718636648995, 66.08165563855852, 73.25828320639474, 6.108107098511287, 0.27844854284610066, 0.28518308433038847, 2.653564376490457, 2.0922819461141313, 16.89014319011143, 67.0301820210048, 64.45030198778424, 69.38203607286725, 65.0239313670567, 64.48516110011509, 55.25684513364519, 50.17894526890346, 50.67844084330967, 47.09570646286011, 43.71893753324236, 46.327006408146445, 44.35743876865932, 45.318395478384836, 41.872710841042654, 44.429634026118684, 43.43015997750418, 44.03952741622925, 41.160523959568565, 41.08843987328665, 43.60751274653843, 44.47072914668492, 43.646488666534424, 45.546449252537315, 44.10388510567801, 41.98852341515677, 42.11655787059239, 44.08953707558768, 43.85313156672886, 43.797076974596294, 43.5785630771092, 42.52141203199114, 42.52479927880423, 43.12050308500017, 42.84193243299212, 42.38706513813564, 43.18311677660261, 42.116599559783936, 43.06841591426304, 41.889157227107454, 42.94896943228585, 43.2623679297311, 41.14678737095424, 42.903281552451, 43.56684146608625, 41.30762774603707, 40.04083217893328, 40.58348648888724, 41.3655618258885, 40.82111835479736, 40.52021271841866, 42.26385620662144, 41.92374883379255, 40.77414853232247, 43.33079726355416, 43.55896915708269, 43.607936586652485, 42.40278196334839, 40.72218642915998, 45.712723118918284, 53.28638117653983, 55.124103273664204, 52.64128957475935, 54.45041288648333, 41.04427017484392, 50.04654039655413, 52.86830459322248, 49.25506067276001, 44.054007462092805, 41.50957713808332, 43.2539884022304, 45.11569915499006, 42.3568891116551, 40.58035979952131, 42.27274642671858, 43.83572285515921, 43.49071700232369, 41.59892054966518, 39.77123512540545, 39.78047622953142, 41.135555607931956, 39.87065689904349, 41.77979258128575, 42.054291588919504, 40.47509459086827, 42.302790437425884, 41.463719027382986, 39.5619866507394, 41.911780561719624, 41.9050303867885, 42.060586656842915, 42.71094151905605, 43.412994452885215, 41.10258640561785, 42.79583460944039, 42.14673737117222, 43.87231206893921, 40.65319429125105, 42.29583876473563, 42.78373779569353, 43.42923934119088, 41.78692838123867, 42.42956032071795, 43.68797288622175, 44.71882152557373, 43.58840520041329, 46.52507870537894, 51.147291387830464, 54.45515155792236, 50.19185849598476, 56.064142431531636, 54.98603214536394, 56.027581010546, 57.41644947869437, 57.23122092655727, 54.80057430267334, 55.16921445301601, 56.80866970334734, 58.90425682067871, 61.51486873626709, 62.24067061288016, 66.76905482155937, 58.3561829158238, 56.880500180380686, 53.77374519620623, 62.185668672834126, 61.27612863268171, 73.11656079973493, 36.19457694462368, 0.7239026299544743, 6.311265042849949, 0.19854322767683438, 0.4200912080705166, 31.94254343850272, 76.04400362287248, 57.81484876360212, 66.95592662266323, 48.899966035570415, 25.52541129929679, 34.13906356266567, 60.70838437761579, 60.224289485386436, 70.1213938849313, 16.884716647011892, 0.2910727954336575, 0.14134937524795532, 0.10957518845264401, 0.15305426716804504, 0.10320008732378483, 0.14205089903303555, 0.1797118724456855, 0.13554362606789383], [0.025080411694943905, 0.053046795672604015, 0.11643460073641368, 0.13944514814232076, 0.043675117660313845, 0.015906636902530278, 0.060020670028669496, 0.07425802427210978, 0.05650220811367035, 29.870917184012278, 58.3690162386213, 41.87100158418928, 28.266923802239553, 21.77720730645316, 27.47148881639753, 31.93635606765747, 51.32954611097063, 62.71047306060791, 49.68218033654349, 2.608988859823772, 0.051437870399760346, 0.14727488585880824, 0.6136689164808818, 7.318878037588937, 39.727534430367605, 62.59643227713448, 61.82655102866036, 60.40538733346121, 58.90745299203055, 57.74770484651838, 49.743112564086914, 45.452544348580496, 43.812838963099885, 42.79981245313372, 39.99689524514334, 40.78674214226859, 39.76490184238979, 39.91041101728167, 40.100298336574006, 40.07641737801688, 40.68582303183419, 40.32420056206839, 39.52049895695278, 39.063696588788716, 38.42978811264038, 38.27193546295166, 39.61503962108067, 39.77115869522095, 39.12974269049508, 38.951118401118684, 38.60398292541504, 41.02769177300589, 40.67925351006644, 39.879974433353965, 38.768099376133506, 38.820315088544575, 38.900785650525776, 39.83910512924194, 39.89482968194144, 40.240613733019146, 39.514947346278596, 37.541478293282644, 38.1382486479623, 37.46904679707119, 38.566334111349924, 39.478604793548584, 38.90751845496041, 38.597660064697266, 37.4686472756522, 39.21077605656215, 36.1328387260437, 37.833128929138184, 37.34161683491298, 37.0137973512922, 36.416985307421, 37.43882213320051, 35.88637569972447, 37.747436795915874, 36.86256980895996, 38.1214895929609, 37.821226664951865, 37.06238610403878, 37.88240902764456, 38.530224323272705, 40.2972971371242, 46.52309152058193, 47.44648279462542, 51.688830511910574, 33.35880517959595, 45.49786744798933, 50.042677198137554, 45.27771724973406, 41.99782705307007, 37.65330260140555, 37.892410959516255, 36.37142596926008, 39.083641392844065, 35.90821736199515, 37.92376470565796, 35.93284525190081, 35.42791618619646, 36.04355437414986, 37.574298109327046, 36.233789103371755, 36.261067731039866, 36.24555587768555, 37.08246292386736, 37.15701362064907, 37.60917459215437, 34.438683782305034, 35.68341187068394, 38.37962211881365, 38.830073833465576, 38.49982942853655, 38.43623604093279, 38.385757378169465, 37.896541663578574, 38.132078647613525, 38.89656114578247, 37.76702029364449, 39.99623169217791, 38.05089242117745, 37.612447193690706, 38.25966494424002, 39.94124712262835, 38.451529026031494, 38.99034445626395, 38.83042124339512, 39.16382360458374, 38.542390619005474, 42.96482522147042, 46.86201769965035, 50.362179688044954, 45.735422883714946, 47.54683215277535, 50.5735821042742, 48.658453600747244, 49.666536467415945, 51.958365031651084, 52.64229358945574, 55.766950607299805, 54.22410658427647, 51.747341292245046, 56.360017572130474, 53.87192324229649, 52.57413523537772, 52.428921358925955, 49.228292737688335, 48.070517880576, 53.90605626787458, 60.34138052804129, 61.67361422947475, 54.357859407152446, 0.5667331836053303, 2.1677812891347066, 0.7372503908617156, 0.42948186131460325, 16.67611609186445, 61.4091032573155, 54.10666118349348, 49.861742632729666, 40.82452644620623, 19.14652030808585, 19.58112665585109, 35.55499873842512, 45.13312176295689, 53.57484606334141, 20.155654089791433, 0.3532991792474474, 0.04722207126074603, 0.020185631400506412, 0.021248537847506146, 0.06922076349811894, 0.04301390224801643, 0.033682179770299366, 0.026981627801433206, 0.024560655566996763, 0.07384673705590622, 0.03492836022217359, 0.07089279592037201, 0.04972480696492961, 0.026387974120942608, 0.05410791587616716, 0.07276809707816158, 0.20359863926257404, 39.281908239637104, 65.73503085545131, 51.96494844981602, 30.103139877319336, 28.149643421173096, 26.400371892111643, 30.733275481632777, 59.5214444569179, 64.64572702135358, 54.707124505724224, 1.998359888792038, 0.06406097287046057, 0.26241136768034523, 1.5239409059286118, 8.53762594291142, 44.22092056274414, 65.38822541918073, 64.06490625653947, 62.39043208530971, 62.28761959075928, 60.26791722433907, 51.14189263752529, 47.96992186137608, 45.424261706215994, 44.80993325369698, 43.27652488436018, 43.43403359821865, 42.75183514186314, 40.53383813585554, 43.38298865727016, 41.20869582039969, 41.97992154530117, 42.28695549283709, 41.88035385949271, 41.06814418520246, 41.47126129695347, 40.43508686338152, 42.71093804495675, 41.05191319329398, 41.3591764313834, 40.38873543058123, 41.16144112178257, 41.36779914583479, 42.619833265032085, 41.71604980741228, 41.679477964128765, 41.17206144332886, 41.46805817740304, 41.060984066554475, 41.75158984320504, 40.80140284129551, 40.08513389314924, 39.197484152657644, 40.181324754442485, 38.814516816820415, 40.574446882520405, 41.88610349382673, 39.48458024433681, 40.00223840985979, 40.00967993055071, 41.107154846191406, 39.94187593460083, 39.526839188167024, 40.404143060956685, 38.456330231257844, 38.392514501299175, 38.24869721276419, 38.14661775316511, 40.214151518685476, 39.98051486696516, 39.96532263074602, 39.642992224012104, 38.52393620354788, 39.65084368841988, 39.71681335994175, 42.22101708820888, 49.077548095158164, 49.70411579949515, 52.29109689167568, 34.92259802137102, 46.14450849805559, 52.78032302856445, 46.42517403193882, 42.187908921922954, 40.35142013004848, 38.62393815176827, 38.892930712018696, 39.03025490897042, 37.53707313537598, 38.93098252160208, 39.46815817696707, 38.26972940989903, 37.986600739615305, 40.46218136378697, 37.558748040880474, 39.150705405644004, 38.9389660017831, 38.46679769243513, 39.17216491699219, 39.33187968390328, 36.79913622992379, 37.69283785138811, 40.18264838627407, 41.502177306583945, 41.10594585963658, 40.062962191445486, 40.31829111916678, 39.74983467374529, 39.33621188572475, 41.094797474997385, 38.95961257389614, 40.96218763078962, 40.55962984902518, 40.707025459834504, 39.439757415226524, 41.85203300203596, 41.03937864303589, 41.59459182194301, 41.48915638242449, 40.414422920772004, 39.94684737069266, 44.392221450805664, 48.88836254392351, 52.87158414295742, 48.657425267355784, 50.4025730405535, 53.950434412275044, 52.28575372695923, 52.28567729677473, 53.51180853162493, 54.42782081876482, 58.633138111659456, 55.905327456338064, 54.4794876234872, 59.6310453414917, 55.29589400972639, 54.79593290601458, 54.392982551029746, 50.34109190532139, 51.32020773206438, 56.721376010349815, 62.76022911071777, 63.013970375061035, 58.05546835490635, 0.9564392949853624, 1.4115453256028039, 0.6714184890900339, 0.5587482920714787, 18.246488877705165, 65.62747274126325, 58.1986985206604, 51.914785930088584, 47.0010198865618, 25.505461284092494, 27.950799873897008, 44.1905951499939, 51.30585275377546, 62.18965693882534, 26.589481013161794, 0.49036129883357454, 0.06560538642640625, 0.03394239116460085, 0.027935215471578494, 0.023482673768220202, 0.053744533232280185, 0.08466365055314132, 0.027595596820382134, 0.12223530161593642, 0.12323368447167532, 0.22540572338870593, 0.3080027055527483, 0.1827281370226826, 0.11328046462897744, 0.16623574628361634, 0.11713817369725023, 0.36918232696396963, 49.85986661911011, 76.75608280726841, 58.58361830030169, 43.05770526613508, 29.868412358420237, 33.28791618347168, 45.554443155016216, 63.731705393110005, 73.86667442321777, 59.12786374773298, 3.7193945901734486, 0.12357082138104097, 1.006707340478897, 4.433727162224906, 8.939359494618007, 45.97467367989676, 67.20808369772774, 66.91995579855782, 64.67564596448625, 63.55652741023472, 61.81307847159249, 54.77591167177473, 50.95346096583775, 47.670284271240234, 47.10736901419503, 44.29892104012625, 46.88817071914673, 45.36245053155081, 43.269079889569966, 45.4023505619594, 45.13038764681135, 44.18227468218122, 44.47273022787911, 43.41580152511597, 42.62069831575666, 42.068038599831716, 42.26672581263951, 45.12751109259469, 43.770760672433035, 42.35990115574428, 41.873277119227815, 42.58312245777675, 44.60202578135899, 45.5696736063276, 43.869709968566895, 43.13064398084368, 42.34787382398333, 42.259023734501426, 45.413776874542236, 43.748234612601145, 43.823362009865896, 42.10583332606724, 41.39239924294608, 41.260348728724885, 40.11986793790545, 42.637978485652376, 43.6431257384164, 41.11459984098162, 43.20755706514631, 42.00491074153355, 43.94398273740496, 41.3761682510376, 40.987409591674805, 42.20914609091622, 39.200075830732075, 40.66194554737636, 39.49704531260899, 41.71859284809658, 42.948924268995015, 40.9191574369158, 42.69687489100865, 41.15019546236311, 39.99548128673008, 41.66622427531651, 41.17551122392927, 45.225987911224365, 50.96890333720616, 52.79040486471993, 57.203584466661724, 37.971457140786306, 50.171330043247764, 54.75774213245937, 50.2081172806876, 45.97217927660261, 42.0545243535723, 41.19812413624355, 41.90207045418875, 42.973336764744346, 40.421920027051655, 42.66491665158953, 40.72510119846889, 41.45241778237479, 40.107802391052246, 43.01583889552525, 40.18862731116158, 40.3129757472447, 41.7213408606393, 42.28045197895595, 41.13555908203125, 41.09914009911673, 37.81795406341553, 40.33953523635864, 39.75784247262137, 43.5149245262146, 42.53427314758301, 43.86428689956665, 42.89314760480608, 41.03215251650129, 42.810484886169434, 42.940023626599995, 40.72429173333304, 44.355691296713694, 42.92740222385952, 42.43546976361956, 42.434705461774556, 45.72744287763323, 41.74965129579817, 43.02503483636038, 43.07486036845616, 43.010124002184185, 41.93708937508719, 47.70725563594273, 52.06883444104876, 55.52914503642491, 50.35517242976597, 53.76722083772932, 57.71699380874634, 54.87775836672102, 54.864223275865825, 56.24160289764404, 56.7441417830331, 61.14341803959438, 59.57395894186837, 57.12927000863211, 62.680825097220286, 58.630567278180806, 57.33735466003418, 58.065161091940745, 53.93817431586129, 54.76312698636736, 59.1269257409232, 66.82634271894182, 65.00809642246791, 62.364570890154155, 0.8947727297033582, 4.298225130353655, 1.4734558377947127, 0.5130557981984956, 21.364852564675466, 72.15187290736607, 63.62970583779471, 62.297228949410574, 52.42628451756069, 26.343917778560094, 31.643305369785853, 54.291323457445415, 59.821731703622, 71.26185730525425, 34.065047877175466, 0.7787029093929699, 0.11041459733886377, 0.14836218394339085, 0.18408273719251156, 0.11311284612332072, 0.16212747458900723, 0.15186661375420435, 0.1541348613266434], [0.010097727445619447, 0.02068232581950724, 0.019957063486799598, 0.010766904618191932, 0.061388230217354636, 0.018318464181252887, 0.19464428403547832, 0.04795708753434675, 1.289136631148202, 42.3064729826791, 57.70342745099749, 42.281660965510774, 43.44904170717512, 14.014524374689374, 23.912562438419886, 45.332114696502686, 49.344383239746094, 61.78844015938895, 42.584779603140696, 3.7148873805999756, 0.2526087079729353, 0.5415798904640334, 0.5153925642371178, 19.953435455049785, 63.978609630039756, 60.92809336526053, 60.63720008305141, 62.79789529527937, 59.7244291305542, 56.37493188040597, 44.53201225825718, 42.01226888384138, 43.29719230106899, 42.932366711752756, 43.67172452381679, 43.144634178706575, 42.23046316419329, 40.81819316319057, 40.27360030582973, 40.37055546896798, 39.89014312199184, 38.19393845966884, 38.96951028278896, 37.36766563143049, 39.215149947575156, 39.73158523014614, 39.8771847316197, 38.69301019396101, 37.72465017863682, 39.7495185307094, 39.603905132838655, 39.26471144812447, 40.53996992111206, 40.16470813751221, 37.706730774470735, 38.22144290379116, 39.46472576686314, 39.42016002110073, 38.2489994594029, 38.68545750209263, 38.40878023420061, 39.2792957169669, 38.58752959115164, 39.927274295261924, 39.71067115238735, 38.2011958530971, 38.40187719890049, 39.26724754061018, 40.4900540624346, 38.22833899089268, 37.898129326956614, 35.69946915762765, 36.70348732812064, 36.346964836120605, 35.40823541368757, 37.22080850601196, 34.13406433377947, 36.97103466306414, 35.47660221372332, 39.11895561218262, 38.44180849620274, 39.11899382727486, 38.89826692853655, 39.04826463971819, 39.02139595576695, 46.689427920750205, 48.72293288367135, 50.554033347538535, 36.37922879627773, 43.15257249559675, 49.28153330939156, 43.95828907830374, 41.181792395455496, 38.55380303519112, 38.44167300633022, 38.08297225407192, 38.32266426086426, 35.832975319453645, 38.68993214198521, 36.08100169045584, 36.50542892728533, 35.476299967084614, 36.60064704077584, 35.64042336600167, 37.59940889903477, 36.94317238671439, 37.43568502153669, 37.40148251397269, 38.56289822714669, 37.49012763159615, 39.073385851723806, 39.36847237178257, 38.98108945574079, 38.25433915002005, 40.32241834912981, 38.90617397853306, 38.574036189488, 37.92591864722115, 37.297155312129426, 37.9688480922154, 40.26494632448469, 37.184003898075645, 39.32169015066964, 38.058622292109895, 39.44641726357596, 36.85593427930559, 38.147736413138254, 38.47723388671875, 38.31642130443028, 38.37434843608311, 40.133319650377544, 44.22032996586391, 49.07301092147827, 46.390686648232595, 46.79431792667934, 48.69031456538609, 49.8677910396031, 51.36499582018171, 55.606690406799316, 53.21267121178763, 52.73104640415737, 50.34543800354004, 49.6106173651559, 47.807573727199006, 49.29754195894514, 47.748670373644146, 45.26790639332363, 45.91389431272234, 47.01161936351231, 48.56095995221819, 61.28293786730085, 60.50500365665981, 66.28571033477783, 5.7549996461187085, 2.3755369867597307, 1.2214826728616441, 0.46133970469236374, 8.545717988695417, 55.554919379098074, 59.04166439601353, 50.832659585135325, 52.553175994328086, 21.720226866858347, 17.344890628542217, 38.570388385227744, 45.62540510722569, 51.470525060381206, 31.430419513157435, 0.7690426334738731, 0.09712722604828221, 0.045814236626029015, 0.020461706943543892, 0.04438481779236879, 0.019058966410479376, 0.014354203062664186, 0.05336079453783376, 0.04082742153799959, 0.052942949280674965, 0.05443597059430821, 0.06841459604246275, 0.046150525366621356, 0.04433724570221134, 0.08604849302875144, 0.035165464106414995, 1.67386066700731, 53.09889793395996, 64.7051271711077, 50.08608259473528, 48.755304540906636, 20.826903922217234, 23.35922179903303, 43.98752014977591, 57.129367283412385, 67.63217394692558, 48.66328607286726, 2.799495220184326, 0.25070435873099733, 0.321453929479633, 0.673699615257127, 22.597311871392385, 64.78616401127407, 62.06107357570103, 62.251857212611604, 65.26739624568394, 62.051234926496235, 59.27163587297712, 46.99304335457938, 44.071742738996235, 43.716307640075684, 44.32986831665039, 46.17399317877633, 45.56472648893084, 44.421042578560964, 43.29211664199829, 42.96696179253714, 42.885219710213796, 41.42306859152657, 40.37845209666661, 41.76222406114851, 40.21833086013794, 41.1973146711077, 41.03822871616909, 41.75388274874006, 40.565765108381, 40.42337914875576, 41.16047184807913, 41.851487568446565, 40.66836568287441, 42.063449314662385, 41.21788828713553, 39.774886403764995, 40.94346570968628, 41.38697617394583, 41.6298782484872, 40.548127106257844, 41.15657390866961, 40.8243979045323, 40.852274077279226, 41.16981022698538, 40.628399644579204, 40.629129205431255, 40.76862818854195, 38.92118903568813, 41.35584477015904, 42.826187814985005, 38.98829821177891, 39.34856925691877, 38.0746830531529, 38.977403436388286, 38.417402948652, 37.15446015766689, 39.35798406600952, 36.432406834193635, 39.29530784061977, 38.00948463167463, 41.76843227658953, 40.265960761478965, 42.877937998090474, 41.15408992767334, 41.24831444876534, 39.742420945848735, 47.95509787968227, 49.97543600627354, 51.61555133547102, 38.00380447932652, 44.04837942123413, 51.893649509974885, 47.79479946408953, 44.65022890908377, 41.78587572915213, 40.41881765638079, 40.47699492318289, 40.11163779667446, 38.94952726364136, 39.282926150730674, 38.14156641278948, 39.18914631434849, 37.596591404506135, 37.78450543539864, 38.84852824892317, 39.331765038626536, 38.260439668382915, 39.10791492462158, 37.90094682148525, 40.05158799035208, 39.13068069730486, 40.56557403291975, 40.84351934705462, 41.327225140162874, 40.55412687574114, 41.6209602355957, 39.52739156995501, 39.65129879542759, 39.02733319146292, 39.950488226754324, 40.08375120162964, 41.43148980821882, 39.2865947995867, 41.23683255059378, 40.52951635633196, 40.91183056150164, 39.5615245955331, 40.67122834069388, 40.7185559953962, 41.09623575210571, 40.23878983088902, 42.55790744509016, 45.660955565316335, 50.09168284279959, 47.92617947714669, 51.10478925704956, 51.86622149603707, 51.06300279072353, 53.74304805483137, 56.50188936505999, 54.54046501432146, 54.96766458238874, 51.24220725468227, 50.840882778167725, 49.79754475184849, 50.1809845651899, 48.4708765574864, 47.161193234579905, 46.12845121111189, 47.22413001741682, 52.24352952412197, 62.62391240256173, 61.29850878034319, 68.63028962271554, 7.799960885729108, 1.7603742075817925, 1.136677303484508, 0.3045785464346409, 8.176843336650304, 61.70438780103411, 62.683937890189036, 56.45195266178676, 49.66833257675171, 21.226397548403057, 20.454183442252024, 45.689081873212544, 51.82476854324341, 58.84629494803292, 39.03851284299578, 1.2118877534355437, 0.03263497292729361, 0.013104802962126476, 0.03931261246491756, 0.03869430760719946, 0.028159191399546604, 0.019879070975418602, 0.03547866230032273, 0.12622854805418424, 0.1664245282965047, 0.12218401793922697, 0.18831416299300535, 0.1483387609145471, 0.14794116653501987, 0.23108324302094324, 0.22728838665144785, 4.021306846823011, 67.79346942901611, 73.73725032806396, 58.52307864597866, 56.645143849509104, 22.563871928623744, 33.448808670043945, 59.56642014639718, 61.48282364436558, 73.93097305297852, 56.24057456425258, 4.8211951936994275, 0.42717212811112404, 1.581125665988241, 1.8808773585728236, 24.327587025506155, 68.69538729531425, 63.330050877162385, 65.95560836791992, 68.0993013381958, 63.13363919939314, 61.92214434487479, 49.23187105996268, 44.42959581102644, 48.00330448150635, 47.10644490378243, 48.69861766270229, 48.54336363928658, 45.12818506785801, 45.66717767715454, 43.98005083629063, 45.63964196613857, 44.48511191776821, 42.39457266671317, 43.34904670715332, 42.22410556248256, 43.924857820783345, 44.334606988089426, 45.226585456303184, 43.99497209276472, 42.492868832179475, 46.390255859919954, 42.625767026628765, 42.23255804606846, 43.27733087539673, 43.71388619286673, 40.5779835156032, 42.59759555544172, 43.91569314684187, 43.407918793814524, 42.32569864818028, 42.844482421875, 42.53257431302752, 43.839155265263145, 42.260944911411826, 42.95332595280239, 42.84419754573277, 43.04697029931204, 41.59329945700509, 42.540745394570486, 44.60620164871216, 40.86054243360247, 41.41623503821236, 40.039268834250315, 40.56503207342965, 39.96401636941092, 40.11537592751639, 41.570238385881694, 38.36272062574114, 41.85529865537371, 39.115926197596956, 43.617024830409456, 42.67582532337734, 44.87313059398106, 43.719781739371165, 43.249020440237864, 42.02564416612898, 51.04139736720494, 53.122671195438926, 54.81254604884556, 41.62881517410278, 46.63738938740322, 52.847432204655235, 49.455818448747905, 45.766668932778494, 44.32415689740862, 42.67460591452462, 43.031100613730295, 42.402444975716726, 39.559811864580425, 43.4070155279977, 39.83622510092599, 41.370557580675396, 39.74956716809954, 40.55678456170218, 39.087567125047954, 43.034863063267295, 41.30578647341047, 41.06218263081142, 40.12961278642927, 43.64506081172398, 41.817427498953684, 44.17304400035313, 43.74246413367135, 44.13390132359096, 42.595462458474294, 43.98859364645821, 41.740028040749685, 43.89618260519845, 41.05660670144217, 41.57272236687796, 41.771704878125874, 44.92431102480207, 41.284306117466514, 44.28388861247471, 42.68895741871425, 43.225035258701865, 40.43545511790684, 41.98544536318098, 42.77637617928641, 42.99830511638096, 42.27631780079433, 45.81335735321045, 48.31288494382586, 54.40727846963065, 50.876304694584434, 54.16042981828962, 54.39277063097273, 53.73299053737095, 55.80662134715489, 59.390248571123394, 56.728966917310444, 58.99376351492745, 53.57169158118111, 53.87656463895525, 52.178845269339426, 54.281932967049734, 50.67375775745937, 51.01495599746704, 50.85493550981794, 51.092393670763286, 54.772597381046836, 67.21499020712716, 64.75735677991594, 73.13768332345145, 7.479186875479562, 6.500347673892975, 2.687498075621469, 0.5128648313028472, 10.521750058446612, 66.69457013266427, 68.49401460375104, 63.57990115029471, 64.06880419594901, 30.426005295344762, 27.276833295822144, 55.24601289204189, 61.02616718837193, 65.37302276066372, 49.6335255759103, 2.482124524457114, 0.13337273469993047, 0.12952390765505178, 0.11775036156177521, 0.12489283829927444, 0.1542093101888895, 0.07196441306067364, 0.09671644773334265], [0.0042319563300614906, 0.03258444581712995, 0.04151577835104295, 0.034613129815885, 0.07301643410963671, 0.06232341432145663, 0.02841008990071714, 0.07089002749749593, 5.558497641767774, 45.909815720149446, 50.98912606920515, 41.91702645165579, 27.772849559783936, 13.90062255518777, 25.826275246483938, 37.194929940359934, 57.14053651264736, 63.92340619223458, 32.92828437260219, 0.5213102038417543, 0.08792257960885763, 0.3548615739813873, 0.5954514454518045, 23.00669625827244, 63.71584265572684, 58.58320140838623, 62.55644539424351, 59.33875547136579, 59.36645793914795, 50.92902067729405, 42.44900485447475, 44.39632783617292, 50.650026185171946, 52.958995955330984, 53.530926500047954, 51.419837951660156, 51.005749634334016, 49.90332065309797, 48.06533105032784, 48.71515090124947, 46.71742568697248, 44.721329825265066, 44.160314900534495, 43.18283537455967, 40.84328658240182, 37.19531556538173, 37.72693266187395, 37.830043928963796, 37.708155155181885, 38.29618467603411, 38.582446983882356, 38.73073891230992, 39.19332912990025, 38.714546135493684, 39.03037650244576, 37.244793687547954, 39.001541478293284, 38.0204245703561, 39.297298499516074, 38.46116617747715, 39.07858657836914, 38.55052695955549, 38.38030999047415, 40.33473750523159, 39.370386600494385, 40.97299207959856, 38.72490242549351, 40.01912253243582, 39.22794158118111, 38.90592384338379, 38.99478782926287, 38.35265963418143, 36.14806570325579, 36.376400879451204, 36.02402993610927, 36.54607588904244, 36.325765882219585, 37.08735792977469, 36.26260675702776, 39.20202827453613, 41.18462378638131, 42.01333890642439, 40.39518335887364, 41.98303781236921, 39.27850709642683, 42.35320309230259, 47.21473257882254, 50.43971116202218, 41.0247665813991, 45.07660511561802, 49.88497046061924, 43.17624848229544, 40.96987581253052, 38.303556714739116, 39.12505265644619, 39.31531865256173, 39.34173570360456, 37.44399159295218, 35.72035544259207, 37.14964158194405, 37.93794597898211, 34.67353636877877, 36.412486348833355, 35.041596344539094, 37.649665219443186, 35.41915798187256, 36.512919085366384, 36.91983338764736, 37.750216075352256, 38.553479943956646, 39.39894369670323, 38.17562300818307, 39.75707122257778, 38.32105575289045, 37.697632108415874, 37.071738379342214, 36.54308468954903, 37.74161420549665, 37.88937112263271, 37.67113167898995, 37.5166141646249, 37.658701351710725, 38.77456814902169, 38.40777621950422, 38.716588905879426, 38.223687171936035, 38.38927664075579, 37.91730635506766, 39.3513103212629, 36.60207142148699, 39.828397955213276, 40.42424767357962, 45.268691539764404, 45.93895646503994, 44.907239300864084, 45.86909927640642, 45.47815888268607, 44.13579470770699, 45.6288548878261, 44.9893148967198, 44.14456680842808, 43.12654801777431, 41.473314489637104, 38.807975087847026, 40.49030419758388, 40.139590399605886, 43.25492640904018, 46.199385370527, 49.3611283983503, 49.62780373437064, 58.905521392822266, 58.81921781812395, 67.8016196659633, 16.095508984157018, 0.2072917696620737, 0.26746743065970285, 0.13030201090233667, 1.7865533913884843, 48.650042806352886, 62.043070793151855, 53.28738866533552, 58.753883906773154, 48.67002929959978, 31.786229814801896, 39.899992193494526, 42.179584980010986, 50.852649552481516, 46.29389476776123, 3.0441013404301236, 0.08071044446634394, 0.10691228455730847, 0.03432213668046253, 0.01901174376585654, 0.060897004790604115, 0.06819903903773852, 0.016061364939170222, 0.022665420746696845, 0.01581668351510806, 0.04686844934310232, 0.12181205861270428, 0.06632916616009814, 0.022990271083212326, 0.05497596233284899, 0.049943057753677876, 7.597202028547015, 58.241843359810964, 58.95018441336495, 49.39137043271746, 34.53110177176339, 18.97296472958156, 27.601904766900198, 42.120903968811035, 63.45956529889788, 67.95876707349504, 39.54913248334612, 0.4988504775932857, 0.09097496939024755, 0.11213480574744088, 0.7505154247794832, 25.211799144744873, 64.80706419263566, 61.59828880855015, 65.21438149043492, 61.07244913918631, 61.293839590890066, 51.93703406197684, 42.53400911603655, 48.11323193141392, 53.64042663574219, 54.91625486101423, 54.538144315992085, 53.404768058231895, 52.18856232506888, 52.62499257496425, 51.046017919267925, 50.28404024669102, 50.12275171279907, 46.378784384046284, 47.71128906522478, 45.849335125514436, 43.24846111025129, 39.27851404462542, 38.07062530517578, 38.714264733450754, 39.84108883993966, 40.11194699151175, 41.626536164964946, 40.04240247181484, 41.848906312670024, 41.06631333487374, 41.25573512486049, 37.95411443710327, 40.88032742909023, 41.488388606480186, 40.2657835824149, 41.123351097106934, 39.87990147726876, 40.903878348214285, 40.47989927019392, 41.30227415902274, 40.93319627216884, 42.45484481539045, 40.466329438345774, 39.70748887743269, 40.3481753213065, 40.083205768040244, 39.98252289635794, 38.30037791388375, 38.47845329557146, 39.65842069898333, 37.22527619770595, 39.49582590375628, 37.80643047605242, 38.72341898509434, 38.79010084697178, 40.457241194588796, 43.7322815486363, 43.36682367324829, 43.849695682525635, 42.48563575744629, 40.893407412937705, 44.66400023869106, 49.2894994190761, 51.609648840767996, 44.7483617918832, 45.49578646251133, 51.480797971997944, 44.77145412990025, 43.18424933297293, 42.05919354302542, 41.5278821672712, 43.192434310913086, 41.44076565333775, 39.07196494511196, 38.15951360974993, 38.756495884486604, 38.12613793781826, 37.63037354605538, 38.88604852131435, 37.48426335198538, 38.60223197937012, 38.09959929330008, 38.21558557237898, 38.81077173777989, 40.26149654388428, 40.422107628413606, 41.654078824179514, 39.48414250782558, 40.59870999200003, 40.799870763506206, 39.73384339468819, 39.58950499125889, 38.352176734379356, 38.974915981292725, 39.439767837524414, 40.083414213997976, 39.78751475470406, 39.81490107945034, 39.96886273792812, 40.57395703451974, 40.67854131971087, 40.25704622268677, 39.660220282418386, 39.82372876576015, 40.11595262799944, 39.808991636548726, 41.338418688092915, 43.827315534864155, 46.56393650599888, 47.54169743401663, 47.362614563533235, 48.20243290492466, 48.21122237614223, 47.15556866782052, 48.97868912560599, 48.09620884486607, 44.95737402779715, 46.495663506644114, 43.252852371760774, 42.55537830080305, 42.75282526016235, 43.27822371891567, 46.11412402561733, 47.38395595550537, 52.120233740125386, 51.19727325439453, 59.72474179949079, 59.95843751089913, 68.91408879416329, 18.523464918136597, 0.9892623679978507, 0.7675924684320177, 0.23893375747970172, 1.9210118906838554, 52.792663029261995, 65.60798304421562, 57.32108197893415, 54.490781920296804, 37.1819611276899, 33.324665205819265, 46.31222758974348, 51.53636966432844, 55.19362694876534, 55.37094497680664, 5.103898286819458, 0.10082120461655514, 0.05636448586093528, 0.10492535760360104, 0.01613995456136763, 0.06572631493742977, 0.048480366955378225, 0.0713766592421702, 0.09383624978363514, 0.11639050953090191, 0.09259263080145631, 0.15902693596269402, 0.20202346092888288, 0.2615521252155304, 0.131379402375647, 0.18811867705413274, 10.719619989395142, 72.72350120544434, 65.88365977151054, 58.49365997314453, 40.864621026175364, 20.657574585505895, 35.356658935546875, 52.23439959117344, 67.65707629067558, 74.63587474822998, 46.388852323804585, 0.9111041447946003, 0.3174364593412195, 1.1337093370301383, 2.211425312927791, 27.64981780733381, 67.85582256317139, 64.04474258422852, 65.60594722202846, 64.98402786254883, 62.683277811322895, 54.93562991278512, 45.548509393419536, 50.12540592466082, 57.371195861271445, 57.617922919137136, 56.612799985068186, 55.7411276272365, 56.37028700964791, 53.68549265180315, 53.86187962123326, 53.05333859579903, 50.704347201756065, 47.753155435834614, 49.163764817374094, 48.51968765258789, 46.1364312171936, 41.84111043385097, 41.03079761777605, 40.27949237823486, 41.51964507784162, 42.08068084716797, 43.44417796816145, 42.6366548538208, 43.69177007675171, 42.5660993712289, 43.131797381809776, 39.748243536267964, 43.38138014929635, 43.11361394609724, 42.34613677433559, 42.14539289474487, 42.26928274972098, 41.64598764692034, 42.777095317840576, 44.70058945247105, 43.181671551295686, 44.9916946547372, 41.58185229982649, 42.366144112178254, 42.72498730250767, 42.82149083273751, 42.07933637074062, 41.578478949410574, 40.932192257472444, 41.14906985419137, 38.88474573407854, 42.10857439041138, 40.45990930284773, 41.37417759214129, 39.79295172010149, 42.819062437329976, 47.052922930036274, 45.52565329415457, 45.84220627376011, 45.546629905700684, 43.86787564413888, 46.57500498635428, 52.23042174748012, 53.62163175855364, 47.53204638617379, 48.1538337298802, 55.98529774802071, 47.31013134547642, 45.62610340118408, 43.7394242967878, 43.83801923479353, 45.71714217322213, 44.986372334616526, 43.03140633446829, 39.90518944604056, 41.22794927869524, 40.57567323957171, 40.53389719554356, 40.80560997554234, 38.87028305871146, 42.06937265396118, 39.853915214538574, 40.48610053743635, 40.89432804925101, 42.66970048631941, 43.68190016065325, 43.09864057813372, 41.67066764831543, 42.73183127811977, 41.84057889665876, 41.26008817127773, 42.78778164727347, 39.668169021606445, 42.06682613917759, 41.63683339527675, 42.7770744732448, 41.99260548182896, 41.983538082667756, 42.53572184698922, 43.116233416966026, 41.4574830191476, 42.67219141551426, 42.17952592032296, 43.12906673976353, 43.76844344820295, 41.355601583208355, 44.97137464795794, 45.2718460219247, 50.7091623033796, 51.74840784072876, 48.77667025157383, 52.110231808253694, 51.01627268110003, 49.955710070473806, 50.183690888541086, 51.00808422906058, 48.218632629939485, 49.95303153991699, 45.97870363507952, 44.95584542410714, 46.82325717381069, 45.07780367987496, 48.52808802468436, 50.55593020575387, 54.32051978792463, 54.66840219497681, 62.71022987365723, 63.9605165209089, 72.16861806597028, 20.786618266786846, 1.7547635372195924, 1.8083612897566386, 0.275898065418005, 2.7239383373941695, 58.015846252441406, 72.679171698434, 66.83434009552002, 71.51754406520298, 61.561650957380024, 47.00946889604841, 54.00544330051967, 59.04273441859654, 62.06408909388951, 66.43243544442313, 7.6709884234837125, 0.2010062419410263, 0.23994564318231174, 0.23711617929594858, 0.08406968813921724, 0.1518590141619955, 0.166857528633305, 0.16602142421262606], [0.05240728659555316, 0.01787835279745715, 0.020817508654935018, 0.03716547321528196, 0.012605869377564107, 0.05075825990310737, 0.04985898047951715, 0.07865637647254126, 6.850441779409136, 53.86475617544991, 45.79443046024868, 38.9402687890189, 33.464535917554585, 25.87651593344552, 38.08553613935198, 44.992375578199116, 56.63478408540998, 61.936061586652485, 33.13874530792236, 0.16324728807168348, 0.06567180143403155, 0.02232699462079576, 1.0149758053677422, 37.45207234791347, 65.77428122929165, 58.10937247957502, 60.010354450770784, 56.06855453763689, 55.17339379446847, 44.9118390083313, 45.03670161111014, 50.70149496623448, 54.426271370479036, 51.84129135949271, 55.30436038970947, 54.38194533756801, 54.616315024239675, 54.87176207133702, 54.965392521449495, 53.09546899795532, 54.462005955832346, 52.92558206830706, 51.981099537440706, 47.97746065684727, 46.27735110691616, 45.14442300796509, 42.72602605819702, 37.889878341129844, 40.08727741241455, 37.91820614678519, 39.8250732421875, 37.63439655303955, 38.30272987910679, 37.945088727133616, 37.408496720450266, 38.7714900970459, 37.816512312207905, 39.186860357012065, 40.0543429510934, 39.38070814950125, 39.38241393225533, 38.08284023829869, 38.18016365596226, 38.608936991010395, 40.174070835113525, 39.764735085623606, 38.133113929203574, 38.5879499571664, 38.45566667829241, 37.11947250366211, 36.332953793661936, 37.1007262638637, 37.411196095602854, 35.923684052058626, 36.680617332458496, 37.67018672398159, 36.82766900743757, 35.58877740587507, 35.21591969898769, 40.44239289419991, 43.76205805369786, 44.38591248648507, 42.24619388580322, 42.120560032980784, 41.220705781664165, 43.53533138547625, 46.89501469475882, 51.99706302370344, 39.90719052723476, 42.55370378494263, 49.26421839850289, 42.73845291137695, 41.98108536856515, 40.60859727859497, 41.43285860334124, 41.08175918034145, 40.35649578911917, 35.71879209790911, 36.29422453471592, 36.891470840999055, 35.235061986105784, 36.581581183842246, 36.3846310206822, 35.20147092001778, 36.086320536477224, 36.5949182510376, 37.264001982552664, 36.75389303479876, 37.70857204709734, 37.58937917436872, 39.702110971723286, 37.08113234383719, 39.42755290440151, 38.67293684823172, 38.86890384129116, 37.1196323122297, 37.22934784208025, 39.180454117911204, 37.4422093800136, 38.98490054266793, 39.601375988551546, 37.65399742126465, 38.117046219961985, 37.85531800133841, 38.99946396691458, 36.87279060908726, 37.75808143615723, 37.6805534362793, 38.90919297082083, 39.62752900804792, 39.206489018031526, 38.09623983928135, 37.61029325212751, 38.24971859795706, 39.61715882165091, 39.840821334293906, 38.75429677963257, 37.67608227048601, 39.980622564043315, 39.08033405031477, 39.7080933707101, 38.43658345086234, 42.59501082556588, 43.945146560668945, 48.42701257978167, 50.9017767906189, 53.97598641259329, 53.922221251896445, 56.199475969587056, 52.98770243780953, 58.954888343811035, 58.13765164784023, 65.19626753670829, 21.306364365986415, 0.38917546985404833, 1.2752397997038705, 0.08818325919232198, 0.2611932616148676, 36.99290411812918, 67.34425449371338, 53.85149206433977, 52.88218361990792, 30.04891266141619, 10.674559184483119, 19.482213837759836, 41.07465117318289, 47.67126049314226, 57.293042523520334, 9.134730679648262, 0.1502708893801485, 0.06968377543879406, 0.04119041741692594, 0.033296072988637855, 0.0966902155695217, 0.01907690518003489, 0.02305840278443481, 0.042244701380176206, 0.04467987874522805, 0.08275301129158054, 0.03691388939374259, 0.04570738093129226, 0.08871500673038618, 0.07202649901487998, 0.041964944784662554, 10.56716695853642, 64.3073844909668, 53.10489075524466, 46.62408011300223, 38.67274577277047, 21.09627342224121, 31.779469217572892, 49.572562081473215, 61.88038567134312, 68.72042165483747, 35.69388280596052, 0.093960319911795, 0.019235918165317605, 0.43605274015239304, 1.4486616253852844, 41.490653719220845, 67.19937760489327, 60.613346917288645, 61.79817458561489, 59.019854000636506, 57.211859771183555, 47.14254774366106, 47.07086665289742, 53.52495104925973, 55.99957629612514, 54.61106218610491, 56.751691000802175, 56.63575683321272, 56.44894061769758, 56.79766723087856, 56.340889181409565, 56.42560856682913, 57.06836209978376, 55.02706820624215, 53.84050696236746, 50.35386616843087, 47.87892825262887, 46.700593675885884, 45.04705442701067, 40.36602176938738, 41.385923521859304, 39.55843959535871, 41.25485617773873, 38.76865870612008, 39.31989056723458, 38.94478511810303, 38.96237448283604, 40.5245657648359, 39.35876226425171, 42.216542448316304, 41.00752462659563, 40.74059220722744, 40.42944492612566, 40.97630637032645, 41.22604547228132, 40.514574255262104, 40.59932838167463, 41.841944217681885, 40.22081136703491, 41.26004648208618, 40.24210064751761, 40.21491582053048, 38.36949859346662, 38.9309720993042, 38.17125606536865, 37.743663924080984, 37.5386712210519, 39.35508666719709, 38.34368256160191, 37.837916237967356, 38.42100558962141, 41.45908457892281, 46.6022766658238, 46.60325288772583, 43.62835386821202, 43.36319671358381, 42.40328918184553, 45.75165387562343, 48.98020383289882, 52.903531960078645, 43.05587788990566, 46.2003824370248, 49.78454119818551, 44.76212269919259, 44.08644165311541, 42.488658223833355, 44.463805266789024, 43.991984367370605, 41.42967285428728, 37.78950119018555, 39.019523416246685, 38.298453262874055, 38.62994834354946, 38.02589627674648, 37.98604835782732, 37.32939495359148, 37.77427421297346, 36.97110414505005, 39.50922897883824, 39.37157474245344, 39.546033586774556, 38.99544095993042, 41.63813965661185, 39.56097221374512, 40.42024898529053, 39.984541348048616, 40.816772256578716, 39.3318692616054, 40.667667388916016, 40.033084937504356, 39.97029406683785, 39.22268526894705, 41.93736035483224, 40.49887132644653, 39.78669139317104, 40.157700879233225, 40.37920250211443, 40.10388708114624, 40.82566595077515, 39.91731752668108, 40.46032272066389, 42.54331622804914, 40.13124213899885, 39.444423130580354, 41.01076596123831, 41.16438020978655, 42.520696367536274, 42.83605078288487, 41.19091190610613, 40.40859685625349, 42.18696049281529, 41.956586020333425, 41.92018788201468, 41.892853668757844, 43.82463353020804, 44.704605511256624, 50.03500986099243, 53.903572286878315, 57.36214235850743, 57.04575266156878, 59.35572992052351, 55.557879311697825, 62.14807891845703, 60.28655924115862, 68.84261962345668, 23.551857130868093, 0.4590439764516694, 1.0198622345924377, 0.18716791378600256, 0.23613854604107992, 40.47656760896955, 71.84161499568394, 59.364429065159385, 57.250672408512656, 39.83988332748413, 19.78805443218776, 25.988010202135357, 47.311618259974885, 51.76072004863194, 65.8843684877668, 12.977219121796743, 0.2412905538720744, 0.11002403936747994, 0.041839456518313715, 0.015158511332369276, 0.1119139968816723, 0.07025680504739285, 0.02777667746080884, 0.1112642724599157, 0.13950384142143385, 0.1283504899059023, 0.14675170821802958, 0.1264875177294016, 0.1774486731737852, 0.2478218334061759, 0.17346272777233804, 16.33289245196751, 78.25628226143974, 60.24180589403425, 56.16429376602173, 46.29828255517142, 36.3377480506897, 49.40326574870518, 58.21633652278355, 65.75322818756104, 71.82971273149762, 40.23807764053345, 0.44356067585093634, 0.10839523641126496, 0.6569047878895486, 2.555944574730737, 44.247216020311626, 71.28666237422398, 61.93759019034249, 63.57311276027134, 60.73016698019845, 60.315984862191335, 50.346549715314595, 51.059438364846365, 55.181068079812185, 59.35989883967808, 56.487798418317524, 59.954748017447336, 59.313151359558105, 59.62295069013323, 59.1098609651838, 58.676932607378276, 59.5647942679269, 60.04350430624825, 56.690182072775706, 56.249200752803254, 53.073432786124094, 50.80950471333095, 49.528639044080464, 46.69975641795567, 41.44145005089896, 43.515195505959646, 42.184257643563406, 44.53888750076294, 40.51970202582223, 42.521116733551025, 40.85181202207293, 41.369331223624094, 42.41255807876587, 41.63416528701782, 43.50422082628523, 44.013179847172324, 43.2282383782523, 43.62943083899361, 42.9493168422154, 42.912616457257954, 42.525928361075266, 42.6111410685948, 43.600286620003835, 41.916206564222065, 43.25387028285435, 41.79802118028913, 40.56260020392281, 41.68620729446411, 40.02878747667585, 39.72287566321236, 39.04428332192557, 39.881405762263704, 41.43820871625628, 40.927064486912315, 40.03480461665562, 39.091770785195486, 43.87006432669503, 48.51433059147426, 49.6512782233102, 46.644108295440674, 46.2155190876552, 44.67744847706386, 47.16979857853481, 51.14992128099714, 56.19758605957031, 46.268797874450684, 47.73091425214495, 52.06136512756348, 47.42491211209978, 47.77735253742763, 45.38603619166783, 45.48572199685233, 46.524012156895225, 43.963204928806846, 39.71644857951573, 41.71912785938808, 42.68398250852312, 40.98131602151053, 41.49847739083426, 40.344999994550435, 39.016386304582866, 40.55275460651943, 40.3418733051845, 41.62558078765869, 42.99482754298619, 42.04190295083182, 41.50890663691929, 43.82729121616909, 41.751812185559956, 43.57140643256051, 42.53375203268868, 43.04832172393799, 40.65881190981184, 42.40823629924229, 42.99654722213745, 42.12381526402065, 42.565758909497944, 43.76965938295637, 42.32908589499337, 40.180233887263704, 41.868628774370464, 43.35181556429182, 41.38176155090332, 41.828103406088694, 41.923974650246755, 42.19066735676357, 45.09968703133719, 42.93961020878383, 43.042255946568076, 42.17555502482823, 43.423500129154746, 44.64034857068743, 46.25613130841936, 41.919823101588655, 42.529332978384836, 44.589932441711426, 45.39637858527047, 44.930547033037456, 43.503953320639475, 47.814949240003315, 47.47534213747297, 52.69808415004185, 56.06059537615095, 59.41392803192139, 58.81040750231062, 61.546163422720774, 58.821413448878694, 64.49766090938023, 62.168791498456685, 70.54914583478654, 27.228866406849452, 0.8726763182452747, 3.799071320465633, 0.14405652641185693, 0.4982021780950682, 45.2330299104963, 79.41213594164167, 65.48936339787075, 67.15620149884904, 42.80233464922224, 21.168036154338292, 32.89640256336757, 59.144921575273784, 60.01275852748326, 75.2317453111921, 16.866428988320486, 0.317598357796669, 0.18779226099806173, 0.17458573036960193, 0.1734414624848536, 0.23163391490067753, 0.21374447484101566, 0.1689092828226941], [0.02817362723206835, 0.01777637068049184, 0.021428571847666587, 0.01625046077450471, 0.02135072013230196, 0.05071056228397148, 0.025782681868544648, 0.03188101874132242, 16.56713707106454, 59.53067166464669, 47.7423996244158, 40.33729791641235, 20.077389580862864, 28.843511377062114, 31.21841607775007, 43.448291301727295, 59.971639088221956, 60.27367033277239, 28.625341415405273, 0.07757084257900715, 0.03597239152129207, 0.7408633455634117, 1.180575696485383, 40.86261299678257, 64.50249685559953, 57.10293286187308, 56.698610237666536, 51.393775258745464, 48.063732964651926, 47.26855679920742, 50.23884221485683, 53.882157938820974, 56.69283628463745, 57.78855678013393, 54.89863770348685, 51.969027042388916, 51.45785502025059, 51.52821595328194, 50.754683426448274, 49.001110962459016, 52.25225993565151, 51.82735327311924, 49.921938351222444, 48.86060101645333, 47.67245210920061, 44.18626989637102, 42.94483872822353, 40.38302748543875, 38.91302490234375, 38.22587932859148, 38.747466700417654, 38.17732531683785, 38.83719226292202, 39.96933174133301, 38.94547298976353, 36.40416240692139, 37.64333541052682, 39.755181312561035, 39.55412476403372, 39.77959380831037, 38.01064498083932, 38.180674348558696, 39.287713459559846, 39.264558587755474, 38.71577944074358, 38.98541818346296, 39.38218116760254, 38.33058868135725, 39.77374689919608, 37.577410902295796, 37.23312766211373, 36.214021478380474, 36.180159432547434, 37.25272853033883, 37.073572703770225, 37.336892059871126, 35.21057653427124, 35.90991619655064, 35.9117922101702, 40.44447387967791, 43.728425298418315, 46.04546887534005, 46.12401131221226, 44.60641704286848, 42.60085078648159, 46.036780153002056, 48.75628423690796, 52.2375818661281, 37.84156404222761, 42.223480224609375, 51.036217485155376, 41.55891282217843, 41.948901312691824, 40.9723458971296, 43.078244141169954, 42.171007428850444, 39.098441055842805, 35.973711081913535, 35.627822807856965, 35.25177240371704, 35.27328750065395, 35.22723831449236, 37.29752009255545, 36.85955081667219, 36.23931639535086, 35.01929610116141, 38.08446611676897, 38.23641627175467, 36.99120528357369, 39.597439834049766, 38.31007065091814, 36.582421915871755, 38.21854550497872, 36.36659697123936, 37.21236297062465, 36.349441868918284, 38.6153883934021, 37.114646979740684, 38.064128739493235, 39.39221436636788, 39.15275512422834, 38.22083493641445, 38.44935771397182, 37.896843910217285, 38.79579836981637, 37.447128704616, 38.05555466243199, 38.42260020119803, 39.7415315764291, 36.68943459647042, 39.05892317635672, 36.380545479910715, 38.155959606170654, 37.39756025586809, 38.359903131212505, 38.139940534319194, 39.83082982472011, 39.61727694102696, 39.66788761956351, 41.51193257740566, 43.70084095001221, 46.79282406398228, 50.82199757439749, 53.31370496749878, 54.60482965196882, 56.120916162218364, 57.64781754357474, 57.008364404950825, 61.695466314043315, 57.98137623923165, 60.48435361044747, 56.41095134190151, 65.78594725472587, 26.051273550306046, 0.10502201491700751, 0.1607338993677071, 0.13396425438778742, 0.13680606761148997, 22.985816921506608, 68.98802457536969, 51.59835106985909, 51.34974799837385, 28.09229646410261, 12.236835581915718, 18.789904015404836, 29.42246307645525, 41.30524451392037, 55.45183937890189, 24.492846454892838, 0.09516622591763735, 0.042031414075089354, 0.008603139564261904, 0.03947314367230449, 0.04465130563559277, 0.05112486219565783, 0.021333765238523483, 0.05964945709066732, 0.03882561091865812, 0.013290022666166936, 0.024724111260314072, 0.012323522474616766, 0.041567689672644646, 0.11565866880118847, 0.013604914653114974, 23.038392203194753, 68.78800678253174, 55.74001938956124, 48.06281927653721, 29.45389325278146, 33.663292612348286, 31.22019134249006, 50.28526312964303, 64.55653299604143, 65.72921521323067, 31.90962634767805, 0.007526103473667587, 0.04353313760033675, 1.2224217653274536, 0.9121318267924445, 44.892995493752615, 65.44145556858608, 59.41336522783552, 57.74913617542812, 54.13339785167149, 50.162696906498496, 50.355922835213796, 52.20218774250576, 55.61355522700718, 58.59792464120047, 60.29082543509347, 55.10201842444283, 53.64045442853655, 52.937206404549734, 53.10021114349365, 51.366420200892854, 52.1220645904541, 53.421825885772705, 54.40133081163679, 52.05271462031773, 50.35500219890049, 48.61951242174421, 45.75656625202724, 45.05171666826521, 43.000848157065256, 40.76449053628104, 39.27837855475289, 40.23878288269043, 38.883668763296946, 41.07197959082467, 40.056760924203054, 39.96132046835763, 38.94831132888794, 40.87508501325335, 41.602266107286724, 40.56165872301374, 41.05156230926514, 39.9976213318961, 40.37901490075247, 40.02587618146624, 41.90778187343052, 41.17144305365426, 42.03391947065081, 41.05939292907715, 39.882944788251606, 40.94325031552996, 40.916253089904785, 40.472134658268516, 38.159089769635884, 37.639458315713064, 40.38889523914882, 38.42830119814192, 37.514863218579976, 37.54460150854928, 39.91702570234026, 38.46106890269688, 42.22867052895682, 45.57904672622681, 48.14080933162144, 48.028762681143625, 47.85905987875802, 45.63983998979841, 47.61746059145246, 49.41338579995291, 54.881836959293906, 40.84663214002337, 44.23538671221052, 53.77887296676636, 45.045616149902344, 44.326963969639365, 43.08356646129063, 45.28640597207205, 43.753661155700684, 41.98183577401297, 38.42565393447876, 37.62459264482771, 36.489680835178916, 37.94352190835135, 38.10905926568167, 38.98547724315098, 38.71221848896572, 37.30879701886858, 37.902666500636506, 39.24037190846035, 39.21560158048357, 39.39316974367414, 41.32900387900216, 39.27415405000959, 38.52232422147478, 40.40816259384155, 38.5599730355399, 38.30481781278338, 37.72515044893537, 40.08409513745989, 38.74294342313494, 38.91682209287371, 40.68489892142159, 40.43553154809134, 39.69286639349801, 40.875692980630056, 40.699712480817524, 41.03588022504534, 39.813139711107524, 39.78457566670009, 40.09849527903965, 40.99399300983974, 39.005161489759175, 38.93855605806623, 39.91387816837856, 39.82089042663574, 39.384963921138215, 40.45251294544765, 42.20175320761544, 41.72624281474522, 41.19451107297625, 41.46856886999947, 44.78661857332502, 45.27174527304513, 48.59382840565273, 53.59653486524309, 56.29449953351702, 58.06370197023664, 58.136362757001606, 59.22809151240757, 59.42989499228341, 63.640816007341655, 61.19976098196847, 63.263723373413086, 59.098820277622764, 68.87431035723004, 27.81327244213649, 0.12885466856615885, 0.7450925186276436, 0.5000224432774952, 0.14799382085246698, 23.74317925316947, 74.23490115574428, 56.45424209322248, 57.84597669328962, 32.57428755078997, 18.26727441379002, 26.35364178248814, 37.12792498724801, 48.51002965654646, 62.98121656690325, 30.10169812611171, 0.16166866278009756, 0.02339966518671385, 0.025090647395700216, 0.00047050863940967247, 0.021195754608405486, 0.05021822066711528, 0.03444266824850014, 0.10210518964699336, 0.1331491574112858, 0.05286598644618477, 0.0949804498148816, 0.1353681976241725, 0.1762919066739934, 0.20353744897459233, 0.08222853086356606, 30.719073363712855, 79.58106749398368, 62.25235053471157, 57.685466357639854, 34.05819000516619, 40.79266895566668, 41.29189355032784, 56.86284133366176, 67.96249825613839, 72.27311897277832, 37.074475969587056, 0.304602566574301, 0.14285679507468427, 2.3533344524247304, 3.1391857010977606, 47.9508455821446, 68.84655230385917, 63.675209590366904, 60.42258412497384, 57.22763218198504, 53.026226724897114, 53.522178718021934, 55.20414999553135, 58.94431318555559, 61.28859370095389, 62.75571278163365, 56.98285756792341, 55.36027601787022, 55.7324458530971, 55.8534209387643, 55.30819926943098, 51.798302854810444, 55.088396481105256, 56.01163142068045, 52.61891290119716, 52.12988131386893, 52.09157936913626, 48.23669447217669, 46.70015593937465, 44.507815156664165, 44.018370151519775, 40.72996841158186, 43.42171444211687, 41.96593829563686, 43.159694399152485, 42.321665218898225, 41.83298104149954, 40.70245007106236, 41.661249365125386, 43.5069306237357, 42.217529092516216, 44.481352942330496, 40.74597011293684, 40.853694983891074, 43.442194257463726, 43.46306317193167, 41.80499022347586, 43.35501520974295, 44.24229669570923, 42.308272566114155, 43.34211240495954, 43.6361289024353, 42.21733801705496, 41.183300154549734, 39.68346895490374, 41.47601733888899, 40.24741949353899, 40.38313518251692, 39.58773667471749, 42.05427074432373, 41.18339048113142, 44.388122013636995, 47.63823223114014, 52.49396344593593, 51.12177760260445, 50.46846628189087, 47.61980560847691, 50.06026656287057, 52.73797723225185, 57.11628382546561, 43.42549426215035, 44.814651080540244, 55.41545513698033, 46.87818268367222, 45.72512565340315, 46.94758129119873, 48.2440630367824, 45.732848576136995, 45.126069341387065, 41.60462154660906, 40.06288923536028, 39.72312232426235, 38.8837799344744, 40.349269662584575, 40.94634573800223, 42.60075351170131, 39.217321259634836, 39.67589889253889, 41.12073857443673, 42.00840221132551, 41.344324656895225, 44.73048407690865, 41.773813656398225, 41.7229563168117, 42.02492502757481, 40.74360077721732, 40.29639039720808, 39.218151569366455, 43.818275928497314, 41.13583353587559, 41.46903787340437, 43.876665115356445, 43.60751969473702, 41.63667358670916, 42.14391987664359, 42.407228810446604, 42.739595890045166, 42.24361957822527, 40.99934312275478, 43.12406056267874, 42.69301169259207, 41.5613238470895, 42.87677764892578, 41.60140105656215, 42.56895160675049, 42.194443702697754, 43.901584829602925, 43.71725606918335, 43.822142601013184, 44.88085699081421, 43.72579540525164, 47.2659546988351, 48.863352503095356, 49.67040661403111, 57.33067396708897, 60.59054292951311, 61.11283901759556, 61.52910559517996, 61.3492306300572, 63.02180099487305, 66.5865673337664, 63.28363691057478, 66.89036342075893, 62.164025034223286, 70.10846328735352, 31.63171230043684, 0.4284754310335432, 2.9122970529964993, 0.8380397111177444, 0.1843930176858391, 27.78060027531215, 80.23695659637451, 63.11560862404959, 63.61406544276646, 41.23041936329433, 22.198712825775146, 31.140009130750382, 45.89328595570156, 54.814109393528526, 71.7715493610927, 37.63888856342861, 0.2657846638134548, 0.0927286363605942, 0.08222018488283668, 0.1299941459936755, 0.12397943516927105, 0.20615834476692335, 0.18676950516445295], [0.06754292281610624, 0.08195828393633876, 0.024737729458138347, 0.04810001754334994, 0.032196157545383484, 0.050580012146383524, 0.03854154562577605, 0.10354391458843436, 27.64771945135934, 60.853247370038716, 43.16484301430838, 38.23244537625994, 10.642007742609296, 34.26603841781616, 38.80311829703194, 47.23733159473964, 59.86139896937779, 58.77795246669224, 26.25328721318926, 0.035312902980617115, 0.027009742899930904, 1.0258282401732035, 1.2338596944298064, 44.21977758407593, 64.74136202675956, 56.82561635971069, 54.21805470330374, 49.51433617728097, 50.04706845964704, 48.633304595947266, 55.97924934114729, 54.47363724027361, 57.607187952314106, 53.67601530892508, 54.37430926731655, 52.320435660226, 55.323589529309956, 53.66756977353777, 53.923669951302664, 53.61891848700387, 53.01549175807408, 50.97944375446865, 50.01818479810442, 47.65571389879499, 47.32656036104475, 47.601563113076345, 45.39706993103027, 43.556040491376606, 40.62874705450875, 38.15258278165545, 37.730948720659526, 37.29332685470581, 38.42575815745762, 38.58747747966221, 37.88962820598057, 36.96438871111189, 36.85740382330758, 38.18034430912563, 39.255188941955566, 36.16446345193045, 39.34988941465105, 38.528320516858784, 39.26177930831909, 37.45153038842337, 39.73184578759329, 40.51783643450056, 39.265350682394846, 39.63502264022827, 39.16321216310774, 36.14090558460781, 38.47756045205252, 37.36453199386597, 36.53255122048514, 37.00550467627389, 36.45921645845686, 37.50778995241438, 36.60010508128575, 36.45819159916469, 37.673177923474995, 40.26963983263288, 43.47076872416905, 46.6405473436628, 46.91897208350045, 46.76619509288243, 45.15523787907192, 47.155620779309956, 46.8487674849374, 51.85471527917044, 36.744742257254465, 39.87117453983852, 49.58689274106707, 43.45530898230416, 43.23183754512242, 42.76307037898472, 42.2648845400129, 39.713606766292024, 41.85751165662493, 34.200252873556956, 35.48251860482352, 36.04523236410958, 38.18263374056135, 36.08494826725551, 37.15257024765015, 36.20386321204049, 36.20374161856515, 37.987500531332834, 37.550868783678325, 34.87129947117397, 39.28784894943237, 34.760913440159385, 37.97662312643868, 38.02792167663574, 37.053586210523335, 37.18178742272513, 38.27307496752058, 38.571951729910715, 37.74391058513096, 36.591392040252686, 38.05554076603481, 37.67987251281738, 38.76870386941092, 38.356328283037456, 38.718148776463096, 38.14725351333618, 39.42969642366682, 37.471426555088584, 39.114442757197786, 36.97972338540213, 37.80843503134591, 38.82972294943673, 39.77348634174892, 36.423283849443706, 37.64062213897705, 36.93502214976719, 39.761928013392854, 39.08433621270316, 41.21813494818551, 42.45894077845982, 47.513588496616904, 50.35077422005789, 54.2764265196664, 54.2246971811567, 58.16300909859793, 54.98223842893328, 57.79823562077114, 56.761713777269634, 59.551849773951936, 53.41689266477312, 58.1701831136431, 57.704890046800884, 68.54763385227749, 65.1078656060355, 68.25411415100098, 23.358820540564402, 0.04302348316247974, 0.45463529016290394, 0.5261138517941747, 0.2178525294044188, 13.119563392230443, 63.358100754874094, 57.830895628247944, 54.21934012004307, 53.642646585192, 24.500089951923915, 9.171041096959796, 28.901580946786062, 39.80745261056082, 54.86714499337332, 32.84324189594814, 0.4299574600798743, 0.0549888612835535, 0.02063496407520558, 0.08631180532808815, 0.03656730727691736, 0.021129763685166836, 0.03607445675879717, 0.022698411119303534, 0.014638373528474143, 0.01558972881840808, 0.02115211632501866, 0.034043123080794296, 0.06722903930182968, 0.06577139680406877, 0.2117682280285018, 34.01617424828665, 68.68571540287563, 50.90375702721732, 44.353513036455425, 20.605685438428605, 36.16038138525826, 36.571384702410015, 54.591628074645996, 64.44970444270542, 66.56635502406529, 28.18005394935608, 0.08673382696828671, 0.07078099370534931, 2.3933011421135495, 2.0493713915348053, 47.010594504220144, 66.92124121529716, 58.20549733298165, 56.0982928276062, 50.87004089355469, 51.892621176583425, 51.130740778786794, 57.009667192186626, 56.48190982001168, 58.02228723253523, 53.834489822387695, 55.72004679271153, 53.96876376015799, 54.8979845728193, 53.577816418239046, 55.15309115818569, 55.437578201293945, 54.548201833452495, 51.95321294239589, 52.24763590948922, 50.78535624912807, 48.201724188668386, 49.226586954934255, 46.98215552738735, 46.755800587790354, 42.87713895525251, 40.63837030955723, 41.12435858590262, 38.51394469397408, 39.537122522081646, 39.410700048719136, 38.704822131565635, 39.70595332554409, 38.13935341153826, 40.27277347019741, 41.55803387505667, 39.24472842897688, 40.99376719338553, 39.76006589617048, 40.28362308229719, 37.30891513824463, 40.74390997205462, 42.074809619358604, 41.189904417310444, 39.56020096370152, 40.54135956083025, 38.93045098440987, 40.73207024165562, 39.12064055034092, 39.12728302819388, 37.95054306302752, 38.047425270080566, 40.01447071347918, 37.86803320475987, 38.70986304964338, 37.97787380218506, 40.24120780399868, 46.40042454855782, 49.87926598957607, 48.26264251981463, 47.977165358407156, 47.311232634953086, 49.12112372262137, 49.89489943640572, 51.495146002088276, 40.39342199053083, 41.90067039217268, 51.58313798904419, 46.80770015716553, 46.358863898685996, 44.38540179388863, 44.744019167763845, 41.3058385848999, 43.19735710961478, 37.14083821432931, 37.42944553920201, 38.92907524108887, 39.252006667000906, 37.81443132672991, 38.63102184023176, 36.8457030568804, 37.73130307878767, 38.822312695639475, 39.252889088221956, 37.65275716781616, 39.392829281943186, 36.06226934705462, 40.16454485484532, 38.843869481767925, 40.02239165987287, 39.38911199569702, 39.28741121292114, 40.00810268947056, 39.88903488431658, 40.002353055136545, 40.27926656178066, 38.88429757526943, 41.12654032026018, 40.107861450740266, 41.720246519361226, 39.67976556505476, 39.870114939553396, 39.13468285969326, 40.74527529307774, 39.03815153666905, 39.70454631532942, 39.47077417373657, 41.06044558116368, 39.43273278645107, 39.24267176219395, 40.47144331250872, 41.601359367370605, 40.327428000313894, 43.99399587086269, 44.361437456948416, 49.61128439222063, 51.743422508239746, 56.22071661267962, 57.26039293834141, 60.021110262189595, 57.01067468098232, 60.24742003849575, 58.84683690752302, 61.05917113167899, 56.38621922901699, 59.41720758165632, 59.37624795096261, 67.89560100010463, 67.30374649592808, 69.34308447156633, 26.141464642116002, 0.05933738526489053, 2.273620592696326, 1.3221118045704705, 0.30699833801814486, 13.815545337540762, 67.83439431871686, 62.7243138722011, 59.33082757677351, 52.7668365750994, 25.304286616189138, 16.491978406906128, 35.27419771466936, 45.57676771708897, 62.69497857775007, 40.51471321923392, 0.861124395259789, 0.08553195824580533, 0.010179111783924912, 0.056737072832350216, 0.04559605708345771, 0.040109673980623484, 0.041332217665123086, 0.1336706251438175, 0.18759942134576185, 0.1306357415659087, 0.17226515417652472, 0.17827590235642024, 0.23616685452205793, 0.12954220095915453, 0.4425753072968551, 44.13904299054827, 77.68826007843018, 59.41167681557791, 55.01374156134469, 20.854441370282853, 40.414054666246685, 50.99288851874215, 60.46685804639544, 69.02869238172258, 72.86946896144322, 32.944921834128245, 0.18249450384506158, 0.1438901631959847, 2.792794334036963, 2.987232506275177, 52.77181495938982, 70.06288310459682, 60.728895459856304, 59.639668055943076, 53.32862274987357, 56.37753398077828, 53.40531349182129, 60.30164378029959, 59.449600083487375, 60.41872092655727, 57.40116344179426, 57.63582147870745, 55.81379883629935, 56.81663581303188, 55.70234278270176, 55.83888530731201, 57.52306958607265, 57.594434533800396, 55.65336840493338, 53.42765195029122, 53.24871151787894, 50.18870748792376, 51.95573513848441, 50.82620470864432, 48.79596539906093, 46.029369899204795, 43.180969783238, 42.978499276297434, 40.824137347085134, 42.48848104476929, 41.33239459991455, 42.00290618624006, 41.64556728090559, 40.55474526541573, 42.41023390633719, 44.17805017743792, 40.891778060368125, 43.53265980311802, 43.30945239748274, 42.85661050251552, 39.77329526628767, 43.456285204206196, 45.70945746558053, 43.416649205344065, 43.49982609067644, 42.538153716496055, 38.92479862485613, 42.51664556775774, 42.451082365853445, 41.96499334062849, 40.51753766196114, 40.064744404384065, 43.24536221367972, 40.304043837956016, 39.9047725541251, 40.86945697239467, 44.127703530447825, 49.173610414777485, 51.12903847013201, 51.121256487710134, 50.914818559374126, 50.21464511326381, 52.72415379115513, 52.613931042807444, 53.65214129856655, 42.617550781794954, 44.88595002038138, 54.66249622617449, 48.366493770054404, 48.02092511313302, 48.682292870112825, 47.159056663513184, 43.74815123421805, 47.44210542951311, 39.24923086166382, 39.219565527779714, 41.301707880837576, 42.64569098608834, 40.82334525244576, 40.550624983651296, 40.826899256025044, 40.53321279798235, 42.584564208984375, 42.04571403775896, 39.124295302799766, 42.56093338557652, 37.04180901391165, 42.985857418605256, 42.014374188014436, 41.18110452379499, 42.04623167855399, 41.73520599092756, 42.822824886866975, 41.867273875645225, 41.21912506648472, 41.306456974574495, 42.36507061549595, 42.832097257886616, 43.14882046835763, 43.67274938310896, 41.752256870269775, 41.90381097793579, 41.28166580200195, 43.508094446999685, 40.34266539982387, 42.47982358932495, 42.93221385138375, 44.132643699645996, 42.34745693206787, 41.616200719560894, 42.03945371082851, 43.992790358407156, 43.736526897975374, 46.75413996832711, 47.37267208099365, 53.01679801940918, 53.6222049849374, 58.30364063807896, 59.68773569379534, 62.95408385140555, 59.36943871634347, 61.938625471932546, 61.76436465127127, 63.924774987357004, 57.60900490624564, 60.820222582135884, 62.17689309801374, 68.69213553837368, 66.18206405639648, 73.13981642041887, 29.001450879233225, 0.14917520460273537, 4.1149294802120755, 3.037221972431455, 0.3507407493889332, 15.746822323117938, 74.48116615840367, 67.51289422171456, 67.94614219665527, 68.15135724203927, 33.7107766015189, 18.70145171029227, 44.07249314444405, 55.0560873576573, 69.63681956699916, 50.661223207201274, 1.4695761374064853, 0.1350483904991831, 0.16056232500289166, 0.26967022674424307, 0.14330065197178296, 0.11995314407561507, 0.11173290267054524], [0.017786820119779025, 0.053138129878789186, 0.08111070548849446, 0.07297253289393016, 0.03693759740729417, 0.026434504659846425, 0.15347447033439363, 0.8809097164443561, 46.413101536887034, 59.34394577571324, 41.13270684650966, 30.26922266823905, 9.885195187159947, 50.680191789354595, 49.374378613063264, 46.540931020464214, 60.47791263035366, 58.88045229230608, 21.633615834372385, 0.22621940901236876, 0.08377426756279809, 0.7602038191897529, 0.9331787888492856, 38.47290863309588, 67.04423822675432, 53.10605457850865, 57.6666019984654, 49.87573283059256, 54.19442387989589, 53.028269495282856, 58.65724836077009, 54.06465237481253, 57.913078921181814, 54.34743710926601, 55.84508657455444, 49.91458020891462, 50.43799148287092, 49.15198762076241, 50.214037145887104, 52.031289849962505, 51.79792765208653, 48.88127538136074, 47.73291533333914, 47.35117088045393, 45.270373003823416, 45.063539028167725, 45.89415100642613, 42.974108014787944, 42.721065044403076, 39.663597106933594, 38.47215127944946, 38.074419021606445, 39.77269424710955, 37.02249302182879, 39.44389854158674, 37.64180333273751, 39.47187198911394, 36.96127244404384, 38.01414687292916, 38.15329844611031, 37.894898414611816, 35.85165902546474, 37.787604331970215, 37.55696930204119, 39.35735525403704, 38.37654406683785, 38.02100474493844, 37.69336938858032, 37.465871470315115, 37.65313931873867, 37.668692861284526, 38.762054443359375, 37.336892059871126, 37.229274885995046, 36.81540196282523, 37.28125088555472, 34.80747331891741, 35.62158332552229, 37.06035028185163, 37.27207578931536, 42.22909436907087, 43.48991101128714, 45.37460987908499, 46.611111300332205, 44.19890866960798, 46.74164710726057, 45.31367417744228, 47.27146462031773, 36.55362510681152, 37.99532420294625, 46.273439271109446, 42.99285772868565, 43.02507305145264, 41.145168440682546, 43.535133361816406, 40.051918029785156, 38.98042242867606, 35.3793899672372, 37.105096680777415, 33.31222445624215, 34.79966006960188, 35.59981461933681, 38.9699375970023, 36.37324639729091, 35.48915066037859, 36.39319467544556, 36.75865602493286, 35.81115102767944, 37.81310422079903, 38.415797914777485, 39.14613349097115, 36.0063294001988, 39.977818965911865, 38.86338002341134, 39.775331088474815, 36.9338652747018, 38.424927847726, 37.96876471383231, 39.47253554207938, 36.935883726392476, 40.34058788844517, 38.558847427368164, 37.92408432279314, 37.61738041469029, 38.68226133074079, 37.018709727696006, 37.87418583461216, 39.35955088479178, 38.34369993209839, 38.60277393886021, 39.34292731966291, 38.6888655935015, 38.54369340624128, 38.25010422297886, 40.597341196877615, 40.705236298697336, 45.576826776777, 48.24211059297834, 52.20174305779593, 53.014109066554475, 53.81005648204258, 55.6883282661438, 55.37628466742379, 54.16832644598824, 55.307671206338064, 55.21378714697701, 58.72881480625698, 57.78653138024466, 55.74169043132237, 50.77838025774275, 52.69296680177961, 57.85227523531233, 71.384096963065, 22.382063627243042, 0.06763167519654546, 0.5476607584527561, 0.0861062431441886, 0.2942495064011642, 5.409912151949746, 62.1197441646031, 54.872842516217915, 57.84298549379621, 35.40420893260411, 48.563527311597554, 19.321528060095652, 21.3190587248121, 40.75752149309431, 52.167516231536865, 40.3916015625, 1.0392835353102003, 0.05697706049042089, 0.03821599130917873, 0.0749434871332986, 0.02521754362221275, 0.01013789332604834, 0.04307631389903171, 0.01850103081337043, 0.03645478242209979, 0.06504192416157041, 0.058859581260808876, 0.04925375099160841, 0.05338122522724526, 0.05831800853567464, 1.2405056463820594, 54.371012347085134, 67.3697543825422, 49.37795346123831, 38.95874752317156, 13.362455912998744, 49.27607549939837, 50.654973302568706, 54.1140957559858, 62.93616444723946, 65.08392906188965, 24.111590112958634, 0.2147417991821255, 0.07602644259376184, 2.167552432843617, 1.2889395845787865, 40.601270403180806, 70.57402733394078, 55.9620977129255, 58.412498065403526, 51.750752857753206, 55.978071621486116, 55.85710000991821, 61.38311004638672, 55.911466189793174, 59.748865944998606, 54.85679565157209, 55.64710807800293, 51.75297975540161, 52.01180362701416, 51.55432380948748, 52.07961457116263, 52.584536688668386, 54.33909232275826, 51.224159308842246, 50.4433867590768, 50.46472815104893, 47.98400238582066, 46.64450781685965, 48.30373069218227, 44.611791474478586, 45.60177428381783, 40.89113187789917, 40.793377671922954, 40.13306951522827, 39.343861852373394, 38.84003407614571, 39.5039518220084, 39.541607584272114, 40.97827271052769, 39.746357100350515, 41.75498056411743, 40.37355709075928, 40.50548601150513, 37.1790428842817, 40.71839618682861, 38.90996422086443, 38.39188568932669, 39.28979097093855, 40.70442335946219, 39.41287136077881, 39.19469097682408, 38.749756131853374, 40.134942054748535, 40.17527634756905, 39.676239354269846, 38.12546048845564, 37.88345125743321, 37.60306017739432, 37.56066574369158, 37.61622701372419, 38.54468352454049, 40.640235900878906, 43.94474009105137, 45.713067054748535, 46.63304328918457, 48.63101169041225, 47.458503178187776, 50.017107827322825, 47.5783109664917, 49.383126395089285, 40.378115109034944, 41.219805989946636, 49.05409097671509, 46.10248926707676, 46.48110703059605, 43.74433319909232, 43.229273659842356, 43.478304045540945, 41.153356892721995, 39.557282720293315, 39.39090115683419, 35.89506094796317, 36.921518325805664, 38.051917280469624, 39.05681439808437, 36.77894476481846, 37.07946825027466, 38.607220785958425, 37.893644264766145, 38.94907910483224, 39.87801851545061, 39.49975511005947, 40.64067711148943, 39.09397683824812, 40.901887689317974, 39.87545463017055, 42.48225893293108, 37.568069049290244, 39.98902293613979, 40.08491849899292, 41.29234170913696, 39.24667045048305, 41.82795054571969, 40.414065088544575, 40.557545389447895, 38.269187450408936, 40.939373220716206, 39.749761717660085, 39.85264369419643, 40.512465476989746, 40.608367988041465, 40.28841039112636, 41.25777094704764, 40.5170339175633, 40.89426898956299, 40.73210498264858, 42.93674060276577, 42.62902920586722, 47.31589835030692, 49.946455069950645, 54.5039244379316, 55.54172474997384, 56.50479718617031, 57.77507380076817, 56.299092292785645, 55.41889796938215, 56.923339298793245, 56.218194416591096, 59.47368253980364, 57.90398372922625, 56.61795902252197, 51.27638891765049, 54.346127373831614, 58.35090923309326, 71.32282079969133, 23.704357930592128, 0.1811239038194929, 1.8566763486180986, 0.18777388626975672, 0.17780685823942932, 6.1498457959720065, 66.07040650503976, 59.72684015546526, 63.51125989641462, 44.05419158935547, 42.48838029588972, 23.026133843830653, 30.08004059110369, 47.22627701078142, 60.63531712123326, 48.86530147280012, 1.975888328892844, 0.06253007573208638, 0.033145309292844365, 0.05481199773826769, 0.008126367781577366, 0.04015076266867774, 0.08767878876200744, 0.11361394423459258, 0.15257219517869608, 0.2704217992722988, 0.14685837392296108, 0.17006714854921612, 0.14968473011893885, 0.29671961814165115, 2.1981824806758334, 66.62577601841518, 73.23468017578125, 58.08389343534197, 48.02923168454851, 17.615529911858694, 61.042842864990234, 60.70517430986677, 58.64718042101179, 68.16266196114677, 70.40877137865338, 26.52446324484689, 0.252450093626976, 0.23447675949760846, 3.2387566438743045, 2.5089263319969177, 42.381350244794575, 73.29710974012102, 59.134263038635254, 61.22363499232701, 54.16788870947701, 59.84172167096819, 56.51389585222517, 63.31290967123849, 57.27276073183332, 61.22127955300467, 56.87875965663365, 58.58798176901681, 52.169051783425466, 55.30331815992083, 53.23468657902309, 53.978859492710654, 54.88057933534895, 55.86480903625488, 53.6979056085859, 53.7812179837908, 51.90423509052822, 50.05173764910017, 49.44917597089495, 51.73730114528111, 45.96881982258388, 49.00511659894671, 44.671462603977744, 41.7643780027117, 40.68276235035488, 42.70746741976057, 38.68924427032471, 41.146273204258506, 41.75707197189331, 44.778784479413716, 40.444060461861746, 43.11281490325928, 41.24892589024135, 42.62570449284145, 39.39891937800816, 41.68664503097534, 41.429478304726736, 42.493931906563894, 40.39303289140974, 41.44499363218035, 41.03041546685355, 42.080058983394075, 42.01122317995344, 42.512205668858115, 42.698400020599365, 42.57922451836722, 39.420653343200684, 40.809945651463096, 39.99494627543858, 39.90358441216605, 38.56571919577462, 41.115607329777305, 42.26360259737287, 45.56946168627058, 46.45830651691982, 48.988169942583355, 51.408595766339985, 50.75707013266427, 53.11842584609985, 49.416543756212505, 51.274745668683735, 43.22081422805786, 43.09738642828805, 51.82839550290789, 48.63360684258597, 48.90009805134365, 46.96340928758894, 47.01899140221732, 45.735061577388215, 43.833360467638286, 40.77540615626744, 40.9570529120309, 39.10954080309187, 39.430429458618164, 40.239422116960796, 43.54777560915266, 40.38155446733747, 38.64985145841326, 41.75718314307076, 40.388259478977744, 42.36797496250698, 42.85282373428345, 43.01356683458601, 43.422127859933035, 40.11053303309849, 43.435694217681885, 42.93981865474156, 44.13601705006191, 39.4307073865618, 42.177507468632285, 42.09698479516165, 44.7880985396249, 40.65367371695382, 45.0016826902117, 41.55434438160488, 42.54736007962908, 41.32124968937465, 43.32166038240705, 41.744092736925396, 42.04633937563215, 43.10192012786865, 42.30134173801967, 42.60795879364014, 43.38123423712594, 43.626474380493164, 42.5989921433585, 43.878610610961914, 46.06098420279366, 44.950158323560444, 50.22566148212978, 53.4521096093314, 56.28614432471139, 56.35262816292899, 57.792958463941304, 60.09979166303362, 57.91837344850813, 58.106141567230225, 59.79535634177071, 56.92943286895752, 60.20790563310896, 59.25399439675467, 57.12276649475098, 53.60124226978847, 57.22301510402134, 59.178606442042756, 67.60157408033098, 27.747653654643468, 0.460389429969447, 4.17003824881145, 0.2197952972991126, 0.2684478594788483, 7.2413999778883795, 74.57817690713065, 64.02504444122314, 70.30673013414655, 48.139562129974365, 59.41551916939871, 29.543472903115408, 36.72771222250802, 58.47725527627127, 66.48583929879325, 60.65677315848214, 2.891109607049397, 0.2037758861801454, 0.12046505803508417, 0.11678293347358704, 0.08497133225734745, 0.13718964345753193, 0.21918158951614583], [0.01109975912342114, 0.09646604117006063, 0.03529688955417701, 0.06438768748193979, 0.016243882377498915, 0.08556714028652225, 0.07963382652295486, 2.1297850651400427, 51.48508153642927, 58.23095900671822, 36.183411189488, 21.190428461347306, 19.50292294366019, 35.1566480909075, 40.00313820157732, 56.07789639064244, 56.105626651218955, 64.04981476919991, 17.478412423815044, 0.038414656184613705, 0.1009859936311841, 2.2955881910664693, 0.09133000605340515, 32.39674718039376, 70.86314187731061, 54.67690679005214, 58.01015567779541, 52.22989368438721, 56.44852025168282, 54.943543910980225, 56.72681644984654, 53.42288548605782, 56.53888504845755, 47.60102810178484, 49.59289945874895, 47.32287434169224, 49.62158509663173, 49.69598640714373, 49.993946007319856, 47.06412690026419, 48.66699293681553, 47.97693954195295, 48.89592565808977, 46.8159441947937, 47.38051312310355, 47.48906135559082, 46.66357714789254, 43.96988214765276, 43.286940234048025, 38.88776820046561, 39.43519592285156, 36.750349453517366, 36.533447538103374, 35.96952479226248, 36.75841631208147, 37.910778522491455, 39.254973547799246, 37.20365687779018, 38.94584124428885, 37.581197670527864, 37.81189523424421, 38.38503476551601, 37.41421161379133, 35.873545851026265, 37.544823850904194, 38.34027099609375, 38.09871687207903, 39.198290143694194, 38.74443728583199, 38.96805116108486, 36.91245092664446, 36.68503986086164, 38.28222574506487, 36.28577552522932, 36.825681822640554, 35.7862799508231, 37.04876068660191, 34.59806156158447, 34.33473873138428, 36.35283258983067, 40.569402490343364, 40.73123645782471, 43.804125922066824, 44.63527985981533, 44.22497831072126, 46.05715921946934, 46.77789238521031, 41.68922281265259, 38.53676952634539, 35.265641008104595, 42.849075181143625, 44.55714389256069, 43.289556230817524, 41.87516702924456, 43.66482148851667, 40.63434730257307, 39.41019977842058, 36.06419052396502, 36.2221473966326, 34.29704475402832, 36.637569768088206, 35.40403522763933, 35.46782316480364, 36.19654328482491, 36.954702922276084, 35.960679735456196, 35.88233184814453, 35.9554442678179, 36.84157582691738, 36.75528614861624, 39.5589850289481, 38.60798856190273, 40.06279196058001, 37.83598811285836, 39.97014468056815, 38.12937579836164, 38.59825413567679, 38.663396971566335, 38.448989459446494, 38.288010120391846, 40.004128319876536, 38.361480372292654, 39.29542595999581, 37.874022551945274, 38.10266692297799, 36.78502096448626, 39.23043251037598, 36.782429286411826, 38.416961738041465, 37.74923985345023, 39.04890039988926, 38.642250129154746, 41.22801876068115, 38.87067910603115, 42.62344285420009, 42.27435493469238, 48.09344693592617, 50.04262161254883, 52.21342297962734, 52.70525469098772, 55.74573080880301, 52.81523077828543, 55.29575157165527, 54.68096453802926, 57.82741110665457, 55.85620716639927, 58.38388538360596, 55.31785726547241, 62.43548420497349, 56.682841300964355, 55.108007771628245, 43.297015122004915, 61.3297826222011, 25.459705659321376, 0.107945401620652, 1.1137948227780206, 0.9764232912233898, 0.14260826126805373, 2.0885003890310014, 54.87326635633196, 61.41644055502755, 57.09482084001814, 47.98545455932617, 61.05340412684849, 17.81701030050005, 20.550614016396658, 38.26640122277396, 46.73084613255092, 52.74420281818935, 3.867296985217503, 0.17143261885004385, 0.0664407376732145, 0.059796366707554886, 0.04361528783504452, 0.07194660151643412, 0.0282949679531157, 0.01286947344695883, 0.041460623632052114, 0.008878738436448787, 0.06287123635411263, 0.02755669640776302, 0.1201248677181346, 0.11458027309605054, 3.7203564814158847, 60.36137744358608, 64.20658002580915, 45.038233688899446, 29.489252635410853, 25.407486472811016, 42.82606969560896, 46.31793206078665, 60.294160570417134, 62.78297751290457, 68.59939793178013, 18.87143417767116, 0.1847775706223079, 0.09113642001258475, 2.6322794386318753, 0.5435452535748482, 33.402252265385215, 73.35220895494733, 56.546399525233674, 58.86408233642578, 54.18465123857771, 58.234947272709434, 56.12825345993042, 59.74730954851423, 56.54125438417707, 56.61079542977469, 47.27476848874773, 50.89437001092093, 48.26314279011318, 50.69016245433262, 49.42635113852364, 50.55491924285889, 48.63084493364607, 50.75077159064156, 49.49373129435948, 50.05195999145508, 48.96887479509626, 49.27519655227661, 51.49748754501343, 47.19260951450893, 46.80280862535749, 44.22088929585048, 40.91876833779471, 41.123104436056956, 39.579544748578755, 38.0319516318185, 38.6903976712908, 38.525558607918875, 37.9781482560294, 39.48884643827166, 39.38230970927647, 41.15233898162842, 38.14207015718733, 39.79413291386196, 40.15123210634504, 39.503180571964805, 37.680192129952566, 39.141954149518696, 39.07773542404175, 40.76716559273856, 40.92734588895525, 39.92130579267229, 40.89899376460484, 39.67641305923462, 39.59494195665632, 39.05997930254255, 36.84599140712193, 37.76141309738159, 36.9141080720084, 37.401093414851594, 35.25793545586722, 36.6596302986145, 38.12130199159895, 42.394544873918804, 43.87697083609444, 45.11221810749599, 45.71051011766706, 45.60888923917498, 49.35890844890049, 47.72819403239659, 47.28306811196463, 41.96960694449288, 38.214407852717805, 45.914537021092, 46.655798639569966, 45.22215250560215, 44.38670110702515, 47.22393199375698, 43.19427905763899, 41.25885486602783, 39.329680579049246, 38.5333822795323, 36.02522155216762, 37.961833885737825, 37.45526157106672, 37.23813731329781, 38.195123127528596, 38.46540457861764, 36.836719036102295, 38.97069842474801, 37.241475922720774, 38.78675528935024, 39.72017281396048, 40.81603922162737, 40.27820348739624, 41.1910856110709, 38.85998582839966, 40.6133394241333, 39.18399422509329, 40.16356863294329, 41.26360048566546, 41.48947947365897, 40.045869622911724, 41.36014917918614, 39.83370985303606, 41.74288375037057, 38.80652986254011, 38.80800288064139, 38.9466472353254, 40.308855465480256, 38.883814675467356, 41.02511746542794, 39.89104986190796, 40.13037708827427, 39.94188635689871, 41.971548965999055, 41.47244943891253, 42.9243345941816, 44.76628119604928, 49.59182596206665, 52.613983154296875, 53.35473755427769, 54.625882693699424, 56.14763198580061, 54.65964051655361, 57.46998882293701, 56.01688773291451, 58.807933943612234, 58.43042441776821, 60.50350979396275, 57.487338474818635, 62.69996043613979, 55.309071268354145, 58.02133880342756, 45.184552328927175, 64.13305418831962, 27.881595815931046, 0.16086210177413054, 2.3472756232534135, 2.5835745206901004, 0.07278565077909402, 2.530987296785627, 59.61558559962681, 63.70121669769287, 64.85826546805245, 48.86259862354824, 63.93973445892334, 30.737718854631694, 28.741932187761577, 45.38264199665615, 51.38692780903408, 61.92563928876604, 5.750175424984523, 0.18320790199296816, 0.06077191007456609, 0.07228956704160996, 0.04837501421570778, 0.05866052622773817, 0.09530153937105622, 0.09431071539542504, 0.2190931492618152, 0.11961615644395351, 0.3932302051356861, 0.11861505944814, 0.2890826522239617, 0.24519286304712296, 5.9746413230896, 69.87704658508301, 73.680191721235, 52.97976412091936, 35.012320109776084, 28.417915105819702, 42.74699224744524, 52.31730202266148, 68.66391195569719, 65.8085150037493, 74.5738342830113, 20.966569662094116, 0.18998749820249422, 0.21463906898030213, 6.056350835732051, 1.3182266759020942, 35.15863527570452, 78.69252490997314, 58.145989486149375, 62.886971201215474, 56.108437197549, 62.51284544808524, 59.05846514020647, 61.65371458871024, 57.685442038944785, 59.02994973318917, 50.92799929210118, 54.079660483769004, 51.68244511740548, 52.740655762808665, 52.63528980527605, 52.30066803523472, 50.19161878313337, 52.85042340414864, 52.33903251375471, 52.032120159694124, 51.86392511640276, 49.99409539358956, 52.54717969894409, 51.001785687037874, 49.07671083722796, 47.81133270263672, 41.593341146196636, 44.242439133780344, 41.25170864377703, 41.567195074898855, 41.04324878965105, 40.90318005425589, 41.93184348515102, 42.473893301827566, 41.338425636291504, 43.29996463230678, 40.240683215005056, 41.913673945835654, 42.88231188910348, 40.605411529541016, 40.97267593656267, 40.72680698122297, 41.93082209995815, 42.26521805354527, 42.915409633091514, 42.22002696990967, 44.25782591956002, 42.08651385988508, 41.460397788456504, 41.09902892793928, 39.72086068562099, 40.63912418910435, 39.522534779139924, 38.50009346008301, 37.93504858016968, 38.22783177239554, 40.65733541761126, 44.56542614528111, 45.84236260822841, 48.17678362982613, 49.55127280099051, 47.35446432658604, 51.77225405829293, 51.39833327702114, 48.94070332390921, 45.24766976492745, 41.84203107016427, 48.948613848005024, 49.39866951533726, 47.573040757860454, 45.13162095206124, 49.611451148986816, 45.5732102394104, 43.599779401506694, 41.52580465589251, 41.05610990524292, 38.272102219717844, 39.79641539709908, 39.6735052381243, 39.18735715321132, 40.66999503544399, 40.24931982585362, 41.52838591166905, 41.235189301627024, 39.55416645322527, 40.841400146484375, 42.13428272519793, 42.890983240945, 41.99636445726667, 43.13765818732125, 40.22832931791033, 42.96122258050101, 41.89269038609096, 43.01959439686367, 43.110327448163716, 42.85443571635655, 41.186180182865684, 42.72584193093436, 42.27599123546055, 42.47174283436367, 40.717909812927246, 39.40627057211739, 41.24774817058018, 42.328001976013184, 40.037260804857524, 41.973633425576345, 42.61616461617606, 43.513343811035156, 41.600852148873464, 45.01368917737688, 43.681973116738455, 45.90781116485596, 48.21356739316668, 51.79674298422677, 53.81021976470947, 55.22063112258911, 56.523265498025076, 59.60224505833217, 57.41720683234078, 58.62854535239083, 59.17925957271031, 62.75939532688686, 59.3416667665754, 64.48345184326172, 61.0993595123291, 64.9509196962629, 57.517500604902, 58.35131917681013, 50.16626133237566, 65.28217506408691, 29.081805058888026, 0.28901737715516773, 10.899626101766314, 4.576932140759059, 0.20498438418975898, 3.0769024831908087, 66.13715090070451, 71.20239462171281, 69.08990601130894, 61.33354159763881, 70.20261137826103, 29.553645065852574, 31.465657302311488, 56.47212675639561, 60.16930144173758, 72.87572928837368, 9.93425554888589, 0.3818909893078463, 0.1763087614838566, 0.200643904241068, 0.13731803585376057, 0.2235797042293208, 0.24307339106287273], [0.023528296766536574, 0.05595673041950379, 0.026802898284846118, 0.04856814563806568, 0.04170370201713272, 0.14975517562457494, 0.05767895068441119, 3.417075429643903, 56.14295584814889, 53.971588202885215, 39.95033884048462, 28.4054274559021, 13.703726240566798, 34.8791127204895, 35.496262141636436, 59.53263800484793, 56.09668779373169, 62.905939783368794, 17.758740970066615, 0.09333678694175822, 0.11728457441287381, 1.2329905182123184, 0.5743281074932644, 16.19562210355486, 71.82770470210484, 52.28152574811663, 63.503491810389924, 52.12180750710623, 58.99676513671875, 55.819645745413645, 59.87958935328892, 50.72026205062866, 46.28014775684902, 48.3117801802499, 53.47166878836495, 55.08816719055176, 55.039654867989675, 52.74179874147688, 53.393296582358225, 51.57234048843384, 52.05440303257534, 48.01158673422677, 49.564113071986604, 49.21253769738333, 47.68556335994175, 45.13825300761631, 48.885388714926584, 48.799557617732454, 49.2805084500994, 44.47409554890224, 40.066332067762104, 40.129446029663086, 39.90776375361851, 37.03264781406948, 37.08441884177071, 37.16823843547276, 37.08743783405849, 38.157342297690256, 38.72936316898891, 37.34441695894514, 38.29991238457816, 37.86591747828892, 37.08207035064697, 38.04853698185512, 37.4960891859872, 37.32644196919033, 36.75437593460083, 36.79139593669346, 41.384526933942524, 40.006897177015034, 38.74213743209839, 36.073647022247314, 35.887306758335654, 33.658050196511404, 35.97139385768345, 37.52904449190412, 34.682725361415315, 35.16972460065569, 37.077585288456504, 34.474383626665386, 39.76767764772688, 41.31489208766392, 43.50548539842878, 43.320392336164204, 45.27481290272304, 44.09302854537964, 47.964439732687815, 39.64519827706473, 37.96261208398001, 38.32425887244088, 38.81559378760201, 46.17476442881993, 41.967810835157124, 43.52118137904576, 41.612952436719624, 42.06017671312605, 37.73938730784825, 35.844964436122346, 35.70384304864066, 37.147536277770996, 34.2908365385873, 34.95563323157174, 36.39835023880005, 35.82685743059431, 35.009648527417866, 36.89832871300833, 37.25899233136858, 35.063764572143555, 36.19423648289272, 37.53853920527867, 39.16802379063198, 37.774322850363596, 37.454219341278076, 36.25642286028181, 39.6553669657026, 37.75125135694231, 38.157939842769075, 39.22471066883632, 37.611992086683, 38.163651262010845, 38.35095732552664, 37.763070242745535, 38.30325446810041, 36.67184523173741, 38.78337846483503, 38.51519884381975, 39.028410162244526, 36.95911850248064, 37.47237498419625, 37.82775102342878, 38.107099873679026, 37.67459883008684, 37.36506005695888, 37.037789481026785, 39.78834159033639, 41.91607802254813, 45.29908990859985, 48.46424102783203, 50.863478319985525, 53.34370034081595, 51.84247950145176, 55.16551453726632, 55.07986061913626, 52.74696125302996, 55.503308159964426, 54.81577001299177, 55.02749899455479, 54.59849289485386, 59.13266495295933, 59.871188981192454, 63.55376202719552, 56.91390017100743, 48.94751950672695, 27.114490372794016, 0.11847619047122342, 1.2190667624984468, 0.6480794900229999, 0.05799421162477561, 0.5330697585429464, 46.38850143977574, 62.77852371760777, 57.04551294871739, 59.67137268611363, 45.335296971457346, 21.07240114893232, 10.682566114834376, 33.36072288240705, 48.02412475858416, 57.15350185121809, 10.505024007388524, 0.332183549446719, 0.14854110005710805, 0.06190535532576697, 0.07780420434262071, 0.029158217167215686, 0.05697948964578765, 0.03041537631569164, 0.0476741689656462, 0.033614366980535645, 0.05064267146268061, 0.06345851519810301, 0.2042158075741359, 0.15655638995979512, 5.7614758014678955, 64.92011833190918, 60.77860287257603, 47.60057299477713, 34.26925195966448, 15.691632781709943, 32.94343491962978, 41.09206683295113, 65.5757920401437, 58.60216304234096, 68.25763688768659, 19.4664466381073, 0.08010314205395323, 0.1148373293025153, 1.9546885064670017, 1.2909218839236667, 18.24914656366621, 74.8519150870187, 54.16759688513619, 66.16351931435722, 54.46005003792899, 61.581133706229075, 57.513724258967805, 60.982601983206614, 50.90019607543945, 50.710221903664724, 50.11155121667044, 56.019215379442485, 55.838270391736714, 55.55116040366036, 53.72475692204067, 54.02914013181414, 51.9783376285008, 52.63631813866751, 49.330587591443745, 50.14364494596209, 50.45802313940865, 49.64270762034825, 48.756315503801616, 52.24435288565499, 49.162402970450266, 50.83845785685948, 45.412849290030344, 41.866255964551655, 42.877184118543354, 40.927213873182026, 37.671659742082866, 37.43308639526367, 38.70420026779175, 39.9163829939706, 38.249798502240864, 40.34129660470145, 39.240215573992046, 39.69145243508475, 39.8235376902989, 39.87120233263288, 38.74776894705636, 38.993815081460134, 38.718475341796875, 38.621891907283235, 39.68521990094866, 42.50716822487967, 42.20002310616629, 40.70898832593645, 38.403044496263774, 37.53393602371216, 37.948441232953755, 36.99709735597883, 38.82921920503889, 37.35050705501011, 36.276235648563926, 38.30743728365217, 37.10480833053589, 42.15037475313459, 41.76436063221523, 44.91034514563424, 43.82310492651803, 47.66034139905657, 46.412191322871614, 48.41027784347534, 42.33600977488926, 40.91964381081717, 40.963552951812744, 43.640030315944124, 47.00506026404244, 45.7900322505406, 46.19219398498535, 44.48292670931135, 43.79067073549543, 39.73874534879412, 37.69756262642996, 37.92469229016985, 38.82850006648472, 36.69860274451119, 36.155357837677, 37.91672618048531, 37.166143553597585, 38.901376247406006, 39.32772466114589, 37.29868738991873, 37.152945450374055, 38.11425651822771, 40.04793323789324, 40.718319756644114, 40.323940004621235, 39.78797333581107, 38.103351320539204, 40.848525524139404, 39.508429936000276, 40.56058522633144, 40.682348932538716, 39.957505907331196, 40.11261749267578, 39.220142228262766, 38.78602572849819, 39.94272708892822, 39.24066373280117, 39.93468107495989, 38.93955659866333, 39.742782252175466, 39.18487664631435, 40.520275252205984, 39.38216379710606, 40.53329617636544, 39.800698961530415, 38.709651129586355, 39.15061855316162, 42.40789236341204, 42.29777383804321, 47.18672786440168, 49.909473282950266, 52.1592687198094, 56.21360513142177, 54.54150724411011, 55.84587172099522, 55.347682407924104, 55.79211350849697, 57.85984182357788, 57.738776411329, 57.390497956957134, 56.52799374716622, 59.98545905521938, 62.63581466674805, 64.69997160775321, 57.46372849600655, 52.519432067871094, 32.18149198804583, 0.059237002794231684, 1.2229178015674864, 1.6255097814968653, 0.07304795206125293, 0.6308970834527696, 49.32616853713989, 69.0661848613194, 61.86006913866316, 63.92410796029227, 44.59435497011457, 17.85615645136152, 16.998781749180385, 42.25493471963065, 53.88612188611712, 65.97786344800676, 15.325681584221975, 0.3873799033463001, 0.18034898968679564, 0.06406028076474156, 0.04150824661233595, 0.10173992746110473, 0.12026981636881828, 0.10312652734241315, 0.17896941942828043, 0.13409099115857057, 0.19744769217712538, 0.1615517104842833, 0.3762165095124926, 0.3331291829901082, 8.958828347069876, 74.73520619528634, 66.89733246394566, 56.77006551197597, 40.77184867858887, 20.080135856355938, 43.777208600725444, 50.642932074410574, 71.16396413530622, 64.47566986083984, 73.23991216932023, 22.968356098447526, 0.15183940449995653, 0.26737685980541365, 5.40232732466289, 1.3854826326881136, 19.072579315730504, 76.91115965162004, 56.69468450546265, 68.01060758318219, 56.9893923486982, 63.69236469268799, 59.84466075897217, 63.06141267504011, 53.70401654924665, 53.7612384387425, 49.45899030140468, 56.6000257219587, 57.669211047036306, 56.79806675229754, 56.95702416556222, 56.24341637747628, 54.555671146937776, 55.62786156790597, 52.31839983803885, 52.191018513270784, 52.37498596736363, 51.71204791750227, 50.61263792855399, 54.519905294690815, 51.955689975193565, 53.5374230657305, 48.402075495038716, 43.438129561288015, 45.25133146558489, 43.85731438228062, 40.133458614349365, 40.3272681917463, 41.93572752816336, 41.354486397334504, 40.78199304853167, 41.53306552342006, 41.30505691255842, 43.35141951697213, 40.18328414644514, 40.69715901783535, 42.66479158401489, 41.93015507289341, 41.308009896959575, 39.77939925874983, 41.323796204158235, 45.385709626334055, 43.45979751859392, 42.680306911468506, 40.51883002689907, 39.93333312443325, 38.041224002838135, 38.178899083818706, 41.91936452048165, 39.134981632232666, 39.3819032396589, 39.732860224587576, 40.9028708594186, 45.044459274836946, 44.488763196127756, 47.08992208753313, 46.42156096867153, 48.8673859323774, 48.54174818311419, 52.948295729500906, 44.32810000010899, 44.60714660372053, 44.141929967062815, 46.550853048052105, 50.6704295703343, 47.94468252999442, 47.768229552677695, 46.57576234000069, 46.87593494142805, 43.25849083491734, 39.60603822980608, 38.96593543461391, 41.692537103380474, 37.96412679127285, 38.985480717250276, 41.499450138636995, 40.11679336002895, 41.39790221623012, 41.93883684703282, 41.5688522202628, 39.810311794281006, 39.02234785897391, 42.07669605527605, 44.592075960976736, 42.09123863492693, 41.863278661455425, 40.1941511290414, 42.882798263004844, 42.715103490012034, 42.91378722872053, 44.33819573266165, 41.722244126456125, 41.672137192317415, 40.823744773864746, 40.381863662174766, 41.633018834250315, 40.83271142414638, 42.71512433460781, 41.63653809683663, 42.82144219534737, 41.12119368144444, 42.92202431815011, 41.702587672642295, 42.67545706885201, 42.866205964769634, 41.38040317807879, 41.09755590983799, 44.43072141919817, 46.15848132542202, 49.88343838282994, 53.43722309385027, 55.24299042565482, 59.09660380227225, 56.057315826416016, 58.66406454358782, 58.96711022513253, 57.9552058492388, 60.083991459437776, 60.152396474565776, 58.132374491010395, 58.21764278411865, 62.94125052860805, 65.81831891196114, 67.25367777688163, 59.68352508544922, 53.41133410590035, 31.526784079415457, 0.8866564195070947, 4.482408847127642, 2.6038098462990353, 0.1781973144305604, 0.9119494365794318, 55.37699685777937, 72.94831017085484, 66.95717729840959, 71.29074096679688, 56.23126745223999, 28.974865334374563, 21.316734552383423, 50.91610745021275, 61.46177755083357, 76.73828847067696, 21.052518878664287, 0.5187946845378194, 0.26927162813288824, 0.27643877640366554, 0.20020596416933195, 0.1475199455661433, 0.15512550888316973], [0.06450463299240385, 0.023200079199991057, 0.042899691233677525, 0.08587783468621117, 0.1330748578267438, 0.18148519657552242, 0.24154695868492126, 7.905941758837018, 60.843033518110005, 48.941634382520405, 39.31689936774117, 27.118624550955637, 18.58950059754508, 44.76581219264439, 43.78939921515328, 56.55888543810163, 55.275122370038716, 59.55496951511928, 18.208183458873204, 0.10310484814856734, 0.05244138976559043, 0.48255396634340286, 0.2836006592426981, 5.814936109951564, 58.49849591936384, 62.85037503923689, 57.60968582970755, 54.60712603160313, 57.17412063053676, 54.39003651482718, 52.91176904950823, 50.16593129294259, 55.78008965083531, 55.63136345999581, 53.22895431518555, 46.37052297592163, 48.38579586574009, 46.8486111504691, 46.875896726335796, 47.11542197636196, 49.49990129470825, 50.870912892477854, 51.85363483428955, 50.59942592893328, 59.41456726619175, 52.54374728884016, 50.816581453595845, 47.37606280190604, 46.590746130262104, 46.01380940846035, 45.09648043768746, 40.91677073069981, 40.32869604655674, 37.058936323438374, 37.38053716932024, 36.328364508492605, 37.47745064326695, 36.611465385981965, 38.14865704945156, 36.9393196105957, 37.90530334200178, 37.123335702078684, 35.824220589229036, 37.27439996174404, 37.2174733706883, 37.38858665738787, 37.78004469190325, 36.73919064658028, 39.73195695877075, 41.51518780844552, 38.686739444732666, 37.79043919699532, 37.17551319939749, 35.35543605259487, 36.89287437711443, 34.116301264081685, 36.152342319488525, 34.51836919784546, 35.49388585771833, 35.00429146630423, 38.293207372937886, 41.127613816942485, 40.41676446369716, 43.18997117451259, 45.18292645045689, 42.287949085235596, 43.484932626996724, 38.53273957116263, 38.411107880728586, 37.60190330232893, 38.24551841190883, 42.80486726760864, 43.6196859904698, 42.62663902555193, 41.410843236105784, 40.51889950888497, 38.33063384464809, 35.56180797304426, 35.133045060294016, 35.26990720203945, 36.301165785108296, 34.42766393933977, 35.431862762996126, 34.844667025974815, 37.55066728591919, 34.370330878666465, 35.705798966544016, 36.72800404684884, 36.76860237121582, 38.62439325877598, 38.53833634512765, 38.580174922943115, 37.183705125536235, 35.08114549091884, 37.357309341430664, 39.524918011256624, 36.503434794289724, 38.27068131310599, 36.01560524531773, 37.3760347366333, 39.180937017713276, 38.961280141557964, 36.753417083195274, 38.07911947795323, 36.59096472603934, 36.86594663347517, 37.59698050362723, 39.11937597819737, 37.59658793040684, 38.92033093316214, 38.0501628603254, 38.734477043151855, 37.195572648729595, 38.413268770490376, 38.99418681008475, 39.63295555114746, 40.9452930859157, 43.08517149516514, 43.00126157488142, 45.79091814586094, 45.040703773498535, 47.062098026275635, 47.758533341544016, 47.778203691755024, 47.383983748299734, 48.82578011921474, 49.82709891455514, 54.703928334372385, 55.269480432782856, 58.2893898827689, 55.24283409118652, 60.66638946533203, 48.3553523336138, 33.892016887664795, 0.3493094476205962, 0.7168814752783094, 2.7696633466652463, 0.1347749273159674, 0.24871329271367618, 35.99100167410714, 64.89684186662946, 59.39144366128104, 52.76626334871565, 44.659039224897114, 41.3799341746739, 17.536695650645665, 30.148838179452078, 46.75133637019566, 56.00444350923811, 11.860123361860003, 0.23909106903842517, 0.030278654902109077, 0.10121185079749141, 0.02322460993725274, 0.013790572860411235, 0.07479611611259834, 0.04983471267457519, 0.03645489777305296, 0.07234840281307697, 0.1064929770571845, 0.0487111129664949, 0.20755554336522306, 0.21849316145692552, 10.291855011667524, 69.54705578940255, 54.33249500819615, 47.15045826775687, 32.25198493685041, 18.648490803582327, 41.35814462389265, 46.36344623565674, 62.06615965706961, 60.253444126674104, 64.29091031210763, 19.933728626796178, 0.14378961787692138, 0.03243494758914624, 2.652799206120627, 1.3082387489931924, 6.763040823595865, 63.756607736860005, 60.85199669429234, 58.68663229261126, 57.338987486703054, 57.86338540485927, 55.1831316947937, 53.24962173189436, 52.738366331372944, 57.534019947052, 56.71564722061157, 54.88980654307774, 49.96552092688424, 52.50180101394653, 51.09957810810634, 50.836852822984966, 51.85549347741263, 51.60059881210327, 53.046362604413716, 52.307814257485525, 54.05449063437325, 57.596029145377024, 54.47354343959263, 53.62063121795654, 50.007161481039866, 48.07987710407802, 48.69550139563424, 47.073503494262695, 42.984690121241975, 42.68949590410505, 38.371763706207275, 38.995969023023335, 38.36380454472133, 39.44937719617571, 39.15752158846174, 40.78052003043038, 39.48332609449114, 38.99637201854161, 39.0886093548366, 38.931326457432334, 36.695066111428396, 38.899152823856895, 39.266344274793354, 38.842688288007466, 39.65879590170724, 40.70286348887852, 42.79650511060442, 40.13850648062569, 38.51257242475237, 37.96213265827724, 37.12950222832816, 37.43240547180176, 36.485779421670095, 37.711945397513254, 37.30856425421578, 36.92750767299107, 37.094712597983225, 40.49538680485317, 42.224456446511404, 43.60754401343209, 45.55798673629761, 47.14804376874651, 46.03700596945626, 45.12663909367153, 41.635169301714214, 41.923151288713726, 39.78953320639474, 43.13523326601301, 45.18584816796439, 45.394280229296, 44.342031138283865, 42.63585581098284, 43.303713185446604, 39.945336137499126, 36.659717151096885, 37.52563292639596, 38.42298582621983, 37.518403325762065, 37.200022969927105, 37.6255966595241, 37.34309680121285, 38.70335258756365, 36.91872862407139, 38.95366144180298, 39.79915993554251, 39.45309795652117, 39.20084708077567, 39.55909967422485, 40.060596329825266, 37.74078042166573, 37.16941615513393, 38.33616461072649, 41.34463037763323, 38.00949157987322, 40.78835065024239, 37.54728698730469, 38.92803301130022, 40.40881225040981, 40.30339765548706, 38.49243654523577, 39.97900710787092, 39.24553789411272, 39.10479170935494, 38.45433957236153, 38.42724854605538, 39.16261114392962, 38.75082268033709, 39.73371485301426, 39.22574247632708, 39.188368116106304, 39.81348017283848, 40.38323940549578, 40.707258224487305, 42.985815729413716, 44.01781776973179, 45.274910177503315, 45.86445787974766, 47.65593276705061, 49.114971092769075, 50.926866735730854, 50.252634389059885, 50.08334500449044, 52.454278809683665, 53.491773400987896, 55.89106627873012, 58.09506961277553, 60.89933477129255, 59.70142364501953, 61.16886929103306, 52.50748464039394, 40.792050565992085, 0.5789766694818224, 1.194403154509408, 4.771942887987409, 0.06479049979576043, 0.08807580638676882, 39.87166091373989, 68.14682701655796, 63.42244802202497, 56.54962696347918, 49.15490239007132, 37.41640377044678, 18.73147313935416, 37.39984968730381, 52.11905254636492, 65.47959423065186, 17.84569420133318, 0.17297520036143915, 0.011658593779429793, 0.10139536737863507, 0.012174405922581042, 0.10048982168414763, 0.025327308535841957, 0.20575125089713506, 0.12315521868211882, 0.1731568713273321, 0.2530117306326117, 0.3218429200351238, 0.46129101301942554, 0.4747684012566294, 14.46973821095058, 80.4582428250994, 61.72419711521694, 55.17547825404576, 39.39861365727016, 26.86215785571507, 56.69805438177926, 56.14953926631382, 66.95127827780587, 62.77229813167027, 69.57077693939209, 22.661304780415126, 0.2642138823866844, 0.12519676770482743, 3.492462081568582, 1.4848781334502357, 8.103096893855504, 64.57258333478654, 60.011660712105886, 64.38503061022077, 56.931374890463694, 62.062706402369905, 55.43488924843924, 57.59486184801374, 53.31014748982021, 57.38013819285801, 56.91372994014195, 57.39372886930193, 50.77266883850098, 55.9913044657026, 51.82388612202236, 52.7506993838719, 51.068116664886475, 52.626451696668354, 56.02539927618844, 55.223396505628315, 55.979735715048655, 57.922014304569785, 54.61583907263619, 56.55095059531075, 52.24520056588309, 50.42844813210623, 48.77164322989327, 50.442000593457905, 44.14803048542568, 45.71676697049822, 40.288497243608745, 39.70779807226998, 39.7900265284947, 39.6851921081543, 38.72219262804304, 41.80470534733364, 43.24786009107317, 41.41601964405605, 40.21194893973214, 40.484141145433696, 39.87046234948294, 42.46685825075422, 41.058489663260325, 41.48877075740269, 41.49517352240426, 43.15361819948469, 44.37375661305019, 41.973890508924214, 40.11381605693272, 41.28297553743635, 39.56917456218174, 41.15424278804234, 38.25887284960066, 42.038025856018066, 39.26947443825858, 38.92737640653338, 40.051935400281636, 42.872230052948, 44.450669697352815, 44.69457231249128, 48.61332852499825, 50.029652799878804, 46.52285875592913, 47.36711352212088, 44.66412878036499, 45.378566878182546, 43.758448464529856, 44.80800860268729, 48.716620445251465, 48.721824645996094, 46.91059603009905, 45.36530276707241, 45.81787715639387, 42.91672631672451, 39.39762701307024, 38.65815455572945, 40.39059407370431, 39.50200980050223, 38.95932422365461, 41.109631878989084, 38.070406436920166, 42.04275410515921, 37.24163225718907, 39.17506578990391, 42.51536015101841, 40.662324224199565, 42.06654126303536, 40.84579140799386, 43.430205140795024, 39.51691368647984, 38.51395859037127, 40.78656496320452, 43.98090546471732, 38.78489664622715, 42.725077629089355, 38.75614152635847, 40.443838119506836, 42.8166618347168, 42.764376640319824, 40.124627453940256, 42.12022999354771, 39.45163883481707, 42.06858055932181, 41.20598602294922, 42.04403952189854, 42.18400403431484, 42.347029617854524, 42.99527570179531, 41.68204184940883, 41.67277295248849, 42.98388760430472, 42.96740647724697, 43.1676744052342, 44.93475416728428, 46.91002975191389, 46.65125104359218, 49.573677267347065, 49.635863644736155, 51.60391657693045, 53.893563406808035, 52.317392349243164, 51.33623375211443, 55.02582795279366, 55.19956418446132, 59.8520953314645, 59.74453721727644, 64.81604126521519, 60.18779059818813, 65.87204238346645, 51.23756585802351, 40.977195739746094, 0.7003871574997902, 4.754096005644117, 10.239821689469473, 0.20565673096903733, 0.5070373011486871, 42.72030769075666, 74.91868727547782, 69.67757075173515, 65.67210796901158, 56.486040524074006, 56.390520163944785, 29.33235536302839, 48.5287481035505, 60.990224157060894, 74.87897832053048, 26.614676918302262, 0.47635356762579506, 0.1261697326387678, 0.31081618315407206, 0.08585247783256428, 0.17280600086918899, 0.24440255974020275], [0.04057154258979218, 0.05090868093871644, 0.0491330701458667, 0.07647986004927329, 0.16903113414134296, 0.1707692015916109, 0.2362673319876194, 12.920202204159327, 63.140462330409456, 47.138132163456504, 43.76377078465053, 27.748209510530742, 17.236191272735596, 33.31684153420584, 39.43651260648455, 61.392274720328196, 55.92161055973598, 62.136524064200266, 17.223641089030675, 0.2442593074270657, 0.044218851519482474, 1.972314132111413, 0.7219595227922712, 3.264584183692932, 29.671906879970006, 53.08625568662371, 62.69212981632778, 51.051659856523784, 56.365652561187744, 47.51980018615723, 50.062837396349224, 54.84469536372593, 52.80064650944301, 53.6926840373448, 53.76243700299944, 52.74643318993704, 54.5837071282523, 51.81278984887259, 51.47343635559082, 50.38866622107369, 49.978930950164795, 48.17275367464338, 51.22670929772513, 46.34530796323504, 50.594593456813264, 41.99539518356323, 44.961529050554546, 49.9006073815482, 48.764632497514995, 47.799527713230674, 47.712432043892996, 45.09175566264561, 40.3604736328125, 37.88833931514195, 39.21266596657889, 36.461227961948936, 37.535391671316965, 36.64109945297241, 37.16603238242013, 38.37247937066214, 37.95351341792515, 37.98651736123221, 36.535094261169434, 37.16143962315151, 36.67755317687988, 36.29680231639317, 34.52329894474575, 36.89363520486014, 37.871503829956055, 38.45801864351545, 41.09416171482631, 38.587960379464285, 36.707086494990754, 32.748729024614605, 33.78380216870989, 35.8413131577628, 35.79584067208426, 35.77654552459717, 34.86222859791347, 35.19163921901158, 35.95213345118931, 39.32077298845564, 39.23452499934605, 42.066228594098774, 40.72998578207833, 43.41304656437465, 44.152612822396414, 39.95263869421822, 38.115673950740266, 36.877758571079795, 39.9887033190046, 43.735335281917024, 42.07406963620867, 40.542433057512554, 40.90235321862357, 38.81901230130877, 36.4026129586356, 36.7327253477914, 35.3987580708095, 34.998097147260395, 36.66984762464251, 35.60684619631086, 36.45894547871181, 35.37203182492937, 35.10102776118687, 35.845607144492014, 37.05418028150286, 37.591025897434776, 39.20488051005772, 39.54067652566092, 38.90915128162929, 37.23804351261684, 38.016981737954275, 36.01888132095337, 35.9547563961574, 37.34385762895857, 37.71408544267927, 37.54075568062918, 36.71580301012312, 37.953235489981516, 36.14402185167585, 38.56494447163173, 36.944183349609375, 36.73425742558071, 36.64719302313668, 37.04012754985264, 36.74083389554705, 38.533027921404155, 37.923743861062185, 40.4978152002607, 41.37542131968907, 43.37440415791103, 40.31194393975394, 41.45265054702759, 38.9150607245309, 39.92724650246756, 37.57255063738142, 40.50502743039812, 37.80068778991699, 40.06669684818813, 38.79503059387207, 40.70590679986136, 38.38846022742135, 41.02874442509243, 38.981620992933, 40.78911147798811, 41.14485229764666, 44.7821752003261, 48.01027699879238, 59.05074569157192, 56.31691094807216, 64.15115424564907, 53.48275463921683, 38.51122447422573, 2.32882359623909, 1.0183682633297784, 1.7909136031355177, 0.12952853526387895, 0.033856963605753014, 29.264440195901052, 66.89594282422746, 56.21527617318289, 58.208554540361675, 38.986828667776926, 26.05955754007612, 14.420008216585432, 29.087513004030498, 47.8633052280971, 57.34782212121146, 25.514705862317765, 0.15167096496692725, 0.035963679131652625, 0.07812572816120726, 0.038090940697916915, 0.09314535185694695, 0.03139481447370989, 0.1052080760044711, 0.055438991236899576, 0.10499764872448784, 0.07187001526887928, 0.07947960908391646, 0.2211831999676568, 0.4135477420474802, 16.44066596031189, 71.42972578321184, 55.58954920087542, 53.53631830215454, 33.11598995753697, 14.807015929903303, 33.68467569351196, 47.12326996667044, 64.26094967978341, 62.474949972970144, 66.99988092694963, 18.796093123299734, 0.23352284782699176, 0.0956856037623116, 1.3560244419745036, 0.9033027834125927, 2.5811020476477484, 35.52223450796944, 57.1968412399292, 64.31986345563615, 51.07095847811018, 58.737951687404085, 48.57821232931954, 53.979880877903526, 55.929458550044465, 54.70810420172555, 53.54770292554583, 55.77768210002354, 55.02836057118007, 55.756927830832346, 52.89482239314488, 53.53433806555611, 52.18037039893014, 51.730550970349995, 50.39695542199271, 52.82050446101597, 48.665940284729004, 49.82409381866455, 38.71913194656372, 46.06778996331351, 49.58750070844378, 49.839685576302664, 48.820645400456016, 49.45349775041853, 46.73558827808925, 42.8418664251055, 38.163112776620046, 40.61783143452236, 36.8570043018886, 39.986608437129426, 38.78669275556292, 39.19593817847115, 39.28056376320975, 39.88143355505807, 39.47341448920113, 37.76723568780081, 38.426616259983604, 37.254708766937256, 38.189592361450195, 37.29692602157593, 39.048209054129465, 38.10881955283028, 39.98851919174194, 43.93224375588553, 40.81053972244263, 38.020660809108186, 34.89769220352173, 35.719587666647776, 37.44601699284145, 36.42792872020176, 37.44014923913138, 38.22239133289882, 37.3423672403608, 38.79188305991036, 42.68929788044521, 41.27358157294137, 42.73611831665039, 42.528523513248985, 44.582504817417686, 45.96856273923601, 41.9352376801627, 41.571120807102744, 39.63072517939976, 43.900254249572754, 46.336515017918174, 44.53535086768014, 40.995837756565635, 43.70008359636579, 39.42734793254307, 38.80609212602888, 37.661591802324565, 38.42945459910801, 37.055625506809776, 39.389963150024414, 37.39789029530117, 38.06163781029837, 37.53209127698626, 37.43379858561924, 38.01352153505598, 39.25598451069423, 39.38856308800833, 42.99184329169137, 40.33753068106515, 39.84708513532366, 38.304994991847444, 38.5973265511649, 37.76845857075283, 39.08402354376656, 40.027203287397114, 38.69071728842599, 39.347422804151265, 38.81741768973214, 38.52062191282, 38.685117040361675, 38.203037125723704, 39.13212939671108, 38.01416424342564, 39.29583590371268, 37.843120438711985, 39.47002376828875, 39.95666170120239, 39.94252559116909, 42.28995016642979, 43.63429805210659, 44.98578521183559, 42.7896785054888, 41.89171763828823, 40.951702799115864, 41.61178513935634, 41.08470174244472, 42.374221393040244, 40.66885553087507, 42.08069821766445, 40.68983909061977, 42.24958460671561, 40.15309769766671, 43.01746129989624, 40.17359140941075, 42.09128727231707, 42.77188069479806, 46.64647763116019, 50.22253131866455, 59.91137736184256, 58.44869123186384, 65.02819061279297, 56.07501983642578, 44.611600399017334, 2.660075055701392, 0.9038429515702384, 4.5538458824157715, 0.19031373783946037, 0.11016408220997878, 31.26408311298915, 73.63872487204415, 61.223746163504465, 64.91606753213065, 45.7853422164917, 29.719522884913854, 22.202336311340332, 40.173160621098106, 54.2755823135376, 66.47415937696184, 33.86444990975516, 0.08998244229171957, 0.08762344744588647, 0.015599119743066174, 0.003124205079594893, 0.03581982970769916, 0.05284471098067505, 0.24957679637840816, 0.13730943202972412, 0.1946461567921298, 0.3532221790935312, 0.2789519615471363, 0.29300640310559956, 0.5868697687983513, 21.598074061529978, 81.7169576372419, 61.83285304478237, 58.97137641906738, 40.87505374635969, 25.93570590019226, 40.80459901264736, 51.93532827922276, 70.66494451250348, 67.51787608010429, 72.68711348942348, 22.56332302093506, 0.4645226853234427, 0.5051549907241548, 3.864179415362222, 1.5963272388492311, 3.644519065107618, 38.9711709022522, 55.705208914620535, 62.803036962236675, 54.319057192121235, 60.37489863804409, 51.640759399959016, 53.726570401872905, 56.71353496823992, 56.16926867621285, 57.03610856192452, 55.18971511295864, 57.129659107753206, 58.09327697753906, 55.205018520355225, 54.47359207698277, 53.819200311388286, 52.973274503435405, 50.640607901981895, 54.145762171064106, 50.040422507694785, 54.099678243909565, 40.10532883235386, 47.93051862716675, 52.76379326411656, 52.41931894847325, 51.28543894631522, 52.1920051574707, 49.08524669919695, 46.597392082214355, 40.92020661490304, 43.32973766326904, 38.19141278948103, 41.9382323537554, 41.50956671578543, 40.19855976104736, 42.1548250743321, 41.46110650471279, 41.42130027498518, 40.08962590353829, 40.7429962839399, 39.182100840977256, 39.83490146909441, 38.124008314950125, 40.24013083321707, 41.484282221112935, 41.348802770887104, 44.82506990432739, 43.22789791652134, 39.93365968976702, 36.90001712526594, 37.39924866812569, 39.677799224853516, 39.29452964237758, 39.073385851723806, 40.252936363220215, 39.63221556799752, 41.52071510042463, 44.716886452266145, 43.56653921944754, 45.60431732450213, 45.64597177505493, 47.60434934071132, 47.777970927102224, 44.546558312007356, 45.60038117000035, 44.96137271608625, 45.336700507572715, 49.15327998570034, 47.66757794788906, 44.4419983455113, 46.090444564819336, 42.097929750170024, 42.185098375592915, 40.1440372467041, 39.96495090212141, 38.780439376831055, 41.43240349633353, 40.52682392937796, 39.688106877463206, 41.12712049484253, 39.50167281287057, 38.84329972948347, 40.56106117793492, 40.54603917258126, 43.75952196121216, 42.15315750667027, 41.774192333221436, 41.62316976274763, 41.544821875435964, 39.799573353358674, 40.56182547977993, 43.43557609830584, 40.60220146179199, 41.682660239083425, 40.47359377997262, 40.47546284539359, 40.56367717470442, 40.654861858912874, 39.712630544389995, 40.36888442720686, 40.50621557235718, 40.523183073316304, 42.300115380968364, 42.7929858480181, 42.52757855824062, 44.716313225882395, 46.3546393939427, 47.78101771218436, 43.92472927910941, 44.82247127805437, 42.529280866895405, 44.50882611955915, 42.92133297239031, 45.84519747325352, 41.67402362823486, 43.644782883780344, 42.59381226130894, 44.39766189030239, 41.25320250647408, 46.3403434753418, 42.676454135349815, 46.26081439426967, 44.866522857121055, 50.77483320236206, 51.62798513684954, 64.05253151484898, 60.975827489580425, 69.30595329829625, 56.1278053011213, 44.4497594833374, 3.070187266383852, 2.254396447113582, 6.531634543623243, 0.20137787557074002, 0.22036376036703587, 35.14497511727469, 80.02249349866594, 66.04353087288993, 71.77722603934151, 52.08372095652989, 38.836528709956575, 26.2207088470459, 47.04317808151245, 65.84133829389299, 74.56039646693638, 46.88111482347761, 0.33096606763345854, 0.16763081428195747, 0.12449410398091589, 0.12343063604618822, 0.19287120417824813, 0.05845484190753528], [0.02590885545526232, 0.014750465817217315, 0.08145331817546062, 0.11673240975609847, 0.10890788318855421, 0.16503665276936122, 0.03328952851838299, 14.205367939812795, 66.21695790972028, 43.074301038469585, 40.40147842679705, 27.211956228528702, 44.54727397646223, 62.96114322117397, 36.27202156611851, 65.95230102539062, 50.16970763887678, 61.827989305768696, 13.7831198317664, 0.12828640905874117, 0.1776383915649993, 2.7143787017890384, 0.5487292611173221, 0.8912978161658559, 26.484703915459768, 42.49775341578892, 47.695384638650076, 59.38358524867466, 48.28563410895211, 48.97702155794416, 54.57696042742048, 54.79297992161342, 54.40282814843314, 56.89921167918614, 54.45803158623831, 52.73000764846802, 53.2591928754534, 51.248880999428884, 50.650727953229634, 49.49962336676461, 48.91305296761649, 51.16381420407976, 50.095511300223215, 50.08632230758667, 37.29358046395438, 28.612796442849294, 42.22151041030884, 44.321262972695486, 49.378658703395296, 49.012832573481965, 49.45307043620518, 45.91366849626814, 38.07942867279053, 36.322875431605745, 36.15054621015276, 36.153603417532786, 37.56554685320173, 34.53081342152187, 36.289527552468435, 37.30460378101894, 36.93301064627511, 37.394430092402864, 35.576176847730366, 36.90560695103237, 35.794902665274485, 35.90937076296125, 35.39367198944092, 36.445879391261506, 36.330501079559326, 37.73071943010603, 36.849076407296316, 38.871300969805034, 40.52305800574166, 36.618093967437744, 33.512822423662456, 32.57058416094099, 34.4028970854623, 34.416362694331575, 35.518221923283164, 34.19768898827689, 35.903892108372276, 39.051082134246826, 40.097140380314414, 41.47705609457833, 40.81428827558245, 43.51566798346383, 43.69694995880127, 41.340631689344136, 38.63837998253958, 36.53740106310163, 41.91262476784842, 41.906260217939106, 41.185203960963655, 40.75870268685477, 41.0015526499067, 38.305151326315745, 36.098945413317, 34.34487962722778, 37.8867620740618, 38.19963250841413, 35.793641567230225, 33.66563415527344, 37.11934396198818, 38.95370660509382, 39.91041101728167, 37.73330068588257, 38.610840797424316, 40.48240409578596, 39.763720648629324, 38.472623756953645, 36.920316287449424, 37.85995939799717, 35.6254117829459, 35.995938369206016, 35.916506562914165, 35.85526514053345, 33.61713225500924, 35.860924448285786, 37.466833795819966, 36.90153530665806, 37.1392297063555, 36.95106554031372, 36.49519770486014, 38.034887245723176, 37.517246450696675, 37.818037441798616, 35.89421674183437, 37.431689807346885, 41.86597456250872, 49.20769132886614, 47.40614850180489, 51.82994147709438, 46.56629889351981, 47.138132163456504, 46.12808643068586, 46.604114464351106, 43.167702198028564, 44.146456718444824, 39.94483586720058, 39.6607483455113, 38.73255239214216, 41.19980560030256, 44.08831071853638, 46.1949975831168, 44.98834214891706, 49.17159196308681, 49.50338234220232, 47.93548311505999, 41.821843079158235, 53.35641554423741, 52.86052261080061, 63.63292285374233, 53.91819477081299, 39.476888588496614, 5.059838022504534, 0.5991207457014492, 6.098636269569397, 0.4242343971771853, 0.2511738235396998, 20.380734034946986, 67.7442067010062, 60.22964654650007, 54.36729506083897, 53.72987079620361, 38.02145985194615, 7.803066730499268, 22.832098449979508, 44.1174201965332, 56.84458841596331, 35.581971645355225, 0.07919342336910111, 0.02767816774680146, 0.08747416295643363, 0.01683614675753883, 0.05925254124615874, 0.06761596032551356, 0.09266227563577038, 0.045410610070186, 0.02313146404256778, 0.10087493101933173, 0.0227033983516906, 0.13418651531849587, 0.20258109457790852, 17.93399885722569, 73.82260199955532, 47.37645190102713, 45.748610564640586, 31.72432483945574, 35.422166551862446, 49.00390066419329, 42.66733462469918, 70.32093225206647, 55.970550196511404, 66.62207957676479, 14.592394760676793, 0.22712119562285288, 0.24988324993423053, 4.772190851824624, 2.3552981870515004, 0.9282918167965752, 28.437073026384624, 46.12910086768014, 53.47804376057216, 58.8791321345738, 48.07824427740914, 50.014047145843506, 54.69802236557007, 55.28026751109532, 55.87736095700945, 57.73377023424421, 57.08590282712664, 53.38387482506888, 54.2261597769601, 54.665174756731304, 52.19076837812151, 51.136236803872244, 52.52946179253714, 50.863752773829866, 51.593869481767925, 50.51397698266165, 38.194796562194824, 30.927092007228307, 43.62036343983242, 47.26217835290091, 51.66925743647984, 51.430305412837434, 50.71035739353725, 47.342162540980745, 39.51128217152187, 38.088113921029226, 39.53324542726789, 38.08388941628592, 38.64416088376726, 37.22191326958792, 38.336716992514475, 38.423058782305034, 38.50683321271624, 40.897138595581055, 38.06631394795009, 38.547580923352925, 37.232033320835654, 37.383361612047466, 37.372213227408274, 36.83090339388166, 40.309856006077354, 38.72697646277291, 38.43210881096976, 40.89911535808018, 41.4464180128915, 38.068912574223106, 36.148096970149446, 33.53481694630214, 36.57824257441929, 34.65460252761841, 36.44073077610561, 37.44347742625645, 38.755373750414165, 40.50661161967686, 42.764668464660645, 43.732010568891255, 41.91227388381958, 44.55081408364432, 44.81418207713536, 43.09852940695626, 41.50379276275635, 40.369961397988455, 45.038268429892405, 43.33295120511736, 43.93546077183315, 42.58362967627389, 42.14332927976336, 40.46337645394461, 37.52895416532244, 36.72383165359497, 39.665049280439106, 38.06279468536377, 36.966837951115195, 36.95037072045462, 38.91884054456438, 39.50490025111607, 41.054397174290244, 40.135970388139995, 40.6017359324864, 40.70102916445051, 40.63440636226109, 41.34989711216518, 37.966815744127544, 39.01625081471035, 37.584835052490234, 38.08739478247506, 37.81154087611607, 37.413846833365305, 36.57753733226231, 36.81278249195644, 38.310383319854736, 38.72741767338344, 39.31462035860334, 39.11319555555071, 37.797602789742605, 38.72277627672468, 38.365340096609934, 38.72925894601004, 37.869290828704834, 38.56325258527483, 44.84626538412911, 50.59177943638393, 49.41205521992275, 53.898597376687185, 48.85805797576904, 49.30459090641567, 47.47499472754342, 48.40113748822893, 45.37339047023228, 43.77797637666975, 42.31148610796247, 41.40833146231515, 40.97196027210781, 42.925161429813926, 45.81279107502529, 47.819809504917686, 47.242709500449045, 51.971399852207725, 50.36263826915196, 50.22869437081473, 43.76975318363735, 54.341444287981304, 55.07627534866333, 65.2903391974313, 56.70251512527466, 46.64996215275356, 6.180235045296805, 0.7199431338480541, 1.9838123151234217, 0.30073665401765276, 0.24805058113166265, 20.628406047821045, 74.40457616533551, 63.54244341169085, 62.72615514482771, 55.41940171377999, 41.32379273005894, 14.813385690961566, 28.394124473844254, 52.21977015904018, 63.28560325077602, 48.01314313071114, 0.3646305783518723, 0.08249918491180454, 0.06132997798600367, 0.04640231274866632, 0.02559676836244762, 0.06677855311759881, 0.17694050472761902, 0.1087806782286082, 0.19356333703867026, 0.2575889378786087, 0.21948767666305813, 0.46549722445862635, 0.4173368987228189, 22.7398750100817, 84.50221252441406, 55.355839593069895, 55.10515901020595, 39.40083360671997, 57.73307541438511, 72.2152543749128, 49.64398956298828, 77.59555721282959, 59.86901419503348, 71.40592125483921, 17.122991221291677, 0.45535383160625187, 1.0270916180951255, 9.91988320010049, 4.379722722939082, 1.2737166242940086, 30.123838560921804, 48.54076501301357, 54.573052065713064, 57.075275557381765, 51.17592144012451, 51.410951205662315, 55.13707903453282, 56.83304745810372, 59.11706624712263, 61.17828410012381, 59.10153007507324, 55.751515184129985, 56.09693792888096, 56.682247229984824, 54.426872389657156, 52.46487133843558, 52.96327951976231, 51.84809364591326, 52.62796292986189, 51.297646931239534, 41.00124345506941, 32.44832713263375, 41.84388623918806, 48.14404719216483, 52.643318448747905, 52.98177215031215, 53.68484646933419, 49.00669731412615, 42.087959085192, 39.745662280491416, 40.91594042096819, 39.746364048549104, 42.36385815484183, 39.19149480547224, 40.2730062348502, 40.71905626569475, 40.288677896772114, 41.99138259887695, 39.876277991703574, 41.209515707833425, 38.14046859741211, 40.4314911706107, 38.84039190837315, 40.04729747772217, 41.93432746614729, 40.05532264709473, 41.22310985837664, 41.60962424959455, 43.86852182660784, 40.74009888512747, 37.039797510419575, 35.58418812070574, 38.17806877408709, 38.39923688343593, 39.44942235946655, 39.90134014402117, 40.4703802381243, 43.49812378202166, 45.00248173304966, 45.80195188522339, 43.87406996318272, 48.17687048230852, 47.60460294995989, 44.94440174102783, 45.18089062826974, 41.96765450068882, 45.926005022866384, 45.39877571378435, 46.83842856543404, 44.58663204738072, 45.23093155452183, 43.25703518731253, 39.95223569869995, 38.985230582101, 41.84579004560198, 41.90742056710379, 39.714628151484895, 39.00364678246634, 41.54508590698242, 41.87509059906006, 44.13638530458723, 41.902063505990164, 40.97938094820295, 42.004976749420166, 41.34653070994786, 41.43439415522984, 38.994628020695274, 42.02003696986607, 38.31435768944876, 38.828253405434744, 38.76399646486555, 40.61743886130196, 38.00686863490513, 38.21655832018171, 40.975917271205354, 40.80800015585763, 41.29242161342076, 41.58155700138637, 39.1227319581168, 41.23546722957066, 41.133762972695486, 42.031953130449565, 39.405381202697754, 40.717041288103374, 45.46704871313912, 53.85693597793579, 51.76283924920218, 57.87479087284633, 50.54711988994053, 51.1653983933585, 49.79333414350237, 50.643182209559846, 46.420400619506836, 47.990575381687705, 44.11001341683524, 44.120970726013184, 43.995312554495676, 46.27310228347778, 48.34490919113159, 49.93248224258423, 48.91174670628139, 53.97815077645438, 54.06539235796247, 53.190562043871196, 45.74968753542219, 59.11618382590157, 56.29615320478167, 69.433577810015, 56.14074632099697, 45.59128597804478, 8.044910073280334, 1.5040490818875176, 15.321189573832921, 0.8298861629196576, 0.43834149305309567, 24.034699610301427, 80.05622005462646, 71.79536083766392, 69.38601044246128, 68.83756828308105, 49.47106974465506, 16.92923722948347, 36.15873466219221, 63.01139259338379, 72.01071330479213, 60.33014529091971, 1.1430455446243286, 0.2852733294878687, 0.18508665689400264, 0.20208231705640042, 0.13555119851870195, 0.15806911593036993], [0.044776960143021176, 0.020941295494724597, 0.016393884417733977, 0.08386761362531356, 0.03647887380793691, 0.058119903451630046, 0.2333298996090889, 11.89603773185185, 65.96430056435722, 52.30823114940098, 42.204733984810964, 18.077237708227976, 23.762029715946742, 64.62756443023682, 45.13753386906215, 61.72966534750802, 52.473726817539756, 64.37023094722203, 15.106085504804339, 0.2352923857314246, 0.15883489698171616, 0.9938354768923351, 0.973709259714399, 0.17140941295240605, 17.686762843813213, 46.30300038201468, 39.773104190826416, 39.72441121510097, 56.21062782832554, 54.07452923910958, 56.57467174530029, 53.59118127822876, 55.72069992337908, 53.098814555576865, 56.121680464063374, 54.47904988697597, 54.493394442967, 51.836212226322715, 52.240225655691965, 49.54663487843105, 48.555818285260884, 48.51339258466448, 48.147990294865195, 46.72751447132656, 47.95998593739101, 53.18947465079171, 50.59917231968471, 48.63170651027134, 47.310450962611604, 49.436856814793174, 50.77753257751465, 44.56820889881679, 36.900510447365896, 36.50817346572876, 35.52759851728167, 36.134120668683735, 36.86098909378052, 36.31274495806013, 36.461606638772146, 37.713050161089214, 35.40128721509661, 37.11904518944876, 37.103012221200125, 35.6149651663644, 35.20948566709246, 37.151941435677664, 35.4917562348502, 35.76076963969639, 38.43539183480399, 39.29104164668492, 37.80777495247977, 37.02333722795759, 37.66739354814802, 38.0239577293396, 36.62505953652518, 34.458965573992046, 34.93396527426583, 34.85709735325405, 33.55303512300764, 33.29846007483346, 33.707375458308626, 37.32422201974051, 37.88450738361904, 39.278562682015554, 40.28560331889561, 41.33011211667742, 42.609963348933626, 42.02556078774588, 38.72656304495675, 37.38378892626081, 38.81158815111433, 41.23270879473005, 40.835695675441194, 40.644967624119346, 38.318106242588584, 35.368818283081055, 34.20236165182931, 32.94403593880789, 34.2760785647801, 35.76787069865635, 36.10381957462856, 36.15798078264509, 37.22715221132551, 38.020025048937114, 37.44131653649466, 36.38751104899815, 35.96724230902535, 35.87079436438424, 36.868069308144705, 40.430740765162874, 39.918213844299316, 33.991403920309885, 35.5182740347726, 36.571478503090994, 36.82601881027222, 35.928064891270225, 35.21918535232544, 36.71661942345755, 36.10906546456473, 37.63113784790039, 36.54448822566441, 35.47378819329398, 37.34092548915318, 35.663453170231406, 36.729838371276855, 37.48005621773856, 35.807465008326936, 38.18272059304373, 45.4384777205331, 48.8745391028268, 45.92212792805263, 47.90313230242048, 50.52513231549944, 50.608514172690256, 50.826586859566824, 49.93701246806553, 49.80947480882917, 48.127170017787385, 44.06329720360892, 47.226964882441926, 45.73787212371826, 49.30526488167899, 49.91391665594918, 54.44539628710066, 52.36881249291556, 54.62852995736258, 50.634820052555625, 56.83074760437012, 51.140266759055, 55.74848576954433, 53.54066440037319, 64.30671746390206, 49.66175958088466, 43.115024430411204, 8.015800595283508, 0.6601158870118005, 2.2329119656767165, 0.3540946665619101, 0.28685977150286945, 13.544297218322754, 65.72247546059745, 56.15866919926235, 57.86049148014614, 51.99935245513916, 42.8494747025626, 20.414483172552927, 30.879611492156982, 43.32051740373884, 54.23531750270298, 48.871711186000276, 2.3586975932121277, 0.09881369091038193, 0.06423600097852093, 0.09612369989710194, 0.03311822556757501, 0.05484499828889966, 0.043220879177429845, 0.04862986518336194, 0.0875871322516884, 0.09454017558268138, 0.05840207223913499, 0.15004788206091949, 0.18565053306519985, 17.38480281829834, 75.16462571280343, 57.57162012372698, 45.448194776262554, 23.459508623395646, 31.903449399130686, 68.03967189788818, 46.638448987688335, 68.848067011152, 57.27047824859619, 70.29534203665597, 15.829450300761632, 0.4175372022603239, 0.13182958321911947, 3.353921732732228, 2.525823265314102, 0.47700582976852146, 18.302263804844447, 47.44872011457171, 42.187901973724365, 45.19349813461304, 55.97014372689383, 53.593859808785574, 58.205580711364746, 54.85181726728167, 57.74530076980591, 54.85314089911324, 57.62992593220302, 55.152695110866, 55.571376187460764, 54.98937422888619, 54.11397416251046, 52.820771966661724, 50.09454550061907, 50.80753837312971, 48.79173742021833, 47.73704603740147, 48.48759044919695, 54.8752326965332, 52.56353228432791, 50.558824130467, 50.61729669570923, 50.93046590260097, 51.27636112485613, 46.787803990500315, 39.475551060267854, 37.41772045407976, 37.179563999176025, 38.11979423250471, 38.411062717437744, 37.67891713551113, 38.021800313677105, 39.232822690691265, 37.75675433022635, 38.213080746786936, 39.32921504974365, 37.71952935627529, 37.98705237252371, 38.448913029261995, 36.801648003714426, 35.63615369796753, 39.19677196230207, 40.11653627668108, 37.590761865888325, 38.509633336748394, 38.872332777295796, 40.77739681516375, 38.25143480300903, 38.260491779872346, 36.192739146096365, 36.38488115583147, 35.2596412386213, 35.59175818307059, 36.65643065316336, 37.57796328408377, 38.74894666671753, 42.25775568825858, 42.31255613054548, 44.31452669416155, 44.14564725330898, 43.028741700308665, 41.19844375337873, 38.56629589625767, 42.067326409476145, 43.28394208635603, 42.70180811200823, 39.975157805851524, 39.0298102242606, 38.45703894751412, 37.09493841443743, 35.7754407610212, 36.84444890703474, 38.44924654279436, 37.590588160923545, 37.998082637786865, 38.89767633165632, 38.4565178326198, 39.02022171020508, 37.77475363867623, 37.57213027136666, 35.31584869112287, 38.02125488008772, 41.93186085564749, 42.095407554081504, 37.370771476200645, 36.20729909624372, 37.152834279196604, 38.92090763364519, 37.000675678253174, 35.73183734076363, 38.44422994341169, 37.813878944941926, 38.171954359327046, 37.42544337681362, 37.261757714407786, 38.038396086011616, 38.28492512021746, 37.65259388514927, 38.71359075818743, 37.98374850409371, 40.26310852595738, 47.23089061464582, 51.88280684607369, 49.38090991973877, 48.95923069545201, 52.49816710608346, 51.55559532982962, 52.06320292609078, 53.4327449798584, 51.33538607188633, 50.396413462502615, 46.616753237588064, 50.02143655504499, 48.253550801958355, 51.419108390808105, 51.99211590630667, 57.99331324441092, 56.68946988242013, 56.181191784994944, 53.547640391758506, 58.12188965933663, 53.51546675818307, 56.83303703580584, 55.74562658582415, 66.36296040671212, 53.770097391945974, 48.300235748291016, 9.334619930812291, 0.4500053200338568, 4.983538116727557, 0.613791324198246, 0.16706301617835248, 13.98398791040693, 71.65774481637138, 62.07670702253069, 65.095032283238, 55.32363469260079, 37.38166625159127, 17.154120888028825, 35.260659149714876, 50.93414149965559, 60.74989986419678, 58.75693416595459, 3.52497661113739, 0.3098256034510476, 0.07146502485764877, 0.062351729587784836, 0.030289450394255773, 0.01886433712206781, 0.1450576369783708, 0.12379323158945356, 0.19646742620638438, 0.2659866229764053, 0.18002071444477352, 0.22822872762169155, 0.41583752632141113, 23.440427133015223, 84.46978528159005, 65.65957341875348, 56.520691190447124, 30.21632603236607, 33.746247155325754, 71.55353573390416, 57.63340697969709, 70.33266081128801, 62.902931213378906, 75.16060965401786, 18.46487944466727, 0.6610840750592095, 0.6684096476861409, 5.914056505475726, 3.738190335886819, 0.6541001041020665, 22.74616834095546, 48.09794936861311, 47.689989362444194, 45.0459566116333, 55.13392802647182, 52.15776443481445, 60.70839827401297, 54.35705689021519, 60.410473414829795, 55.963348388671875, 59.97239644186837, 57.56525557381766, 60.1795083454677, 55.030702114105225, 55.68416976928711, 52.681349413735525, 50.64212955747332, 52.22158711297171, 51.13929401125227, 47.89413438524519, 51.30961867741176, 56.28436211177281, 54.36535998753139, 51.70970637457711, 52.21777950014387, 52.74339682715279, 54.61152424131121, 48.49089084352766, 40.76229837962559, 38.32321664265224, 39.859147208077566, 40.235590185437886, 41.0007119178772, 38.60102299281529, 39.43327822004046, 41.69948877607073, 39.33157048906599, 40.00707088197981, 41.25370625087193, 40.13058206013271, 39.88175664629255, 40.24161774771554, 38.79397446768624, 38.39627695083618, 42.078044005802695, 41.15225212914603, 39.98728936059134, 39.16690860475813, 39.76997402736119, 42.10424566268921, 41.699784074510845, 40.57756314958845, 38.78420182636806, 39.27235099247524, 37.49959455217634, 37.24290030343192, 39.053833620888845, 40.23617730821882, 41.79328598294939, 44.617579323904856, 44.040382044655935, 46.3301157270159, 46.609791142599924, 46.71486527579171, 45.43613617760794, 42.71827186856951, 45.43667466299874, 45.70681715011597, 45.1590941292899, 44.744172028132844, 43.24858617782593, 40.30417585372925, 38.489285537174766, 36.787643909454346, 38.41677761077881, 40.00059863499233, 39.11940377099173, 41.27281379699707, 40.68447160720825, 40.72736631120954, 41.46887459073748, 39.440858704703196, 37.357635906764436, 37.224119322640554, 38.155935287475586, 44.052388531821116, 43.54131725856236, 37.817377362932476, 37.98234149387905, 39.932662623269216, 41.79038511003767, 38.47444765908377, 38.13292285374233, 39.515788078308105, 39.13154227393014, 41.7613068989345, 40.35120473589216, 38.78123147147042, 41.37525108882359, 39.15479442051479, 40.05251210076468, 41.12633187430245, 40.103821073259624, 42.62377289363316, 49.3177091053554, 52.55073370252337, 51.54566635404314, 52.76571791512625, 54.773788997105186, 54.016952991485596, 54.93652275630406, 54.424426623753135, 54.67354733603341, 52.898293018341064, 48.30804899760655, 53.18681696483067, 51.48741265705654, 54.63260507583618, 54.79549864360264, 60.27865219116211, 57.815303870609824, 58.60096100398472, 55.69788203920637, 62.49631568363735, 56.87761320386614, 62.02740955352783, 58.985731397356304, 69.54586069924491, 54.86507790429251, 48.5828572000776, 10.852952446256365, 0.8566816736544881, 11.876383015087672, 1.9891187846660614, 0.38666345179080963, 16.654566253934586, 76.39158725738525, 66.91452230725969, 71.15879467555455, 65.95803328922817, 54.97187519073486, 30.76675190244402, 44.86890261513846, 61.79037175859724, 70.15513433728898, 70.71385983058384, 5.91442345721381, 0.5368372563804898, 0.2359647053693022, 0.21236946433782578, 0.20455993339419365, 0.1836631039955786], [0.05683204737891044, 0.03171285062230059, 0.08132410475185939, 0.04753138484167201, 0.04412878617378218, 0.1345099593911852, 0.3034939760608332, 17.581289189202444, 60.494296482631135, 52.129186494009836, 32.03682354518345, 12.890945945467267, 18.172334228243145, 31.850156715938024, 50.94419206891741, 61.1440155846732, 50.36151960917881, 61.81857449667794, 14.004898514066424, 0.4924550950527191, 0.2561749523239476, 4.028040085520063, 1.771612484540258, 0.08235380878405911, 11.003310595239912, 42.622793197631836, 49.12965611049107, 39.640581199101035, 45.01085431235177, 52.492386204855784, 57.86554282052176, 55.559140409742085, 53.33403539657593, 51.24114070619856, 52.563132762908936, 50.02951383590698, 50.01841408865792, 51.360180718558176, 52.145441804613384, 51.511581965855186, 48.87487261635916, 48.41617686407906, 51.09595462254116, 50.06352874210903, 46.684557233537944, 48.33335781097412, 49.65503372464861, 48.472398212977815, 49.53960330145699, 47.874981675829204, 47.810762950352256, 38.75778130122593, 34.768556458609446, 36.195535796029226, 36.68323332922799, 38.145068304879324, 38.8782456942967, 36.34751374380929, 37.17316818237305, 36.04761559622628, 36.36747939246041, 37.33067342213222, 38.02971083777291, 34.96645505087716, 35.379546301705496, 36.12919092178345, 34.87561777659825, 34.35040691920689, 39.58176122392927, 40.272797788892476, 40.445936475481304, 36.85025412695748, 37.722124508449006, 37.42392519542149, 35.90378441129412, 35.31696040289742, 33.900993960244314, 35.082062653132844, 34.53880384990147, 34.38218797956194, 32.982105118887766, 33.6673503603254, 37.036306040627615, 40.80654450825283, 41.31270687920706, 40.585473673684255, 41.568619455610005, 39.14689431871687, 38.16064269202096, 38.37252105985369, 41.33598334448678, 40.53384855815342, 38.90118864604405, 38.50351544788906, 38.24728672845023, 35.600339208330425, 35.68185200010027, 34.14612988063267, 37.66598653793335, 35.51206929343087, 35.19501951762608, 36.939656598227366, 38.201890672956196, 37.51721518380301, 37.09386491775513, 35.63647678920201, 36.99641643251692, 37.1841150692531, 36.92576367514474, 39.304048674447195, 38.46661009107317, 35.69133629117693, 33.90752179282052, 34.89362750734602, 35.44044031415667, 36.567219257354736, 35.856918811798096, 36.617715290614534, 37.12260961532593, 36.1029441016061, 36.09987299782889, 35.691954680851524, 37.27240930284773, 34.34171124867031, 35.68086188180106, 36.59719378607613, 38.06422601427351, 36.84426825387137, 44.01989180701119, 50.00374296733311, 46.22226578848702, 48.5832428250994, 49.9032963344029, 51.92236641475132, 50.095004081726074, 52.583935669490266, 50.836953571864534, 50.10325854165213, 50.14897074018206, 49.147599833352224, 51.362039361681255, 52.78254297801426, 55.106736251286094, 58.54349940163748, 56.31371825081961, 58.04450062343052, 61.36245305197579, 61.66095461164202, 54.69041061401367, 55.17274761199951, 53.00856440407889, 63.34714344569615, 49.4091717175075, 48.176443168095176, 7.793821283749171, 0.19132113164024694, 0.7151267837200845, 0.32295832304017885, 0.24627428501844406, 9.761824710028511, 66.60103348323277, 60.01407173701695, 59.302089827401296, 54.546426568712505, 55.673636300223215, 22.988787276404246, 19.826243468693324, 33.89138807569231, 53.064976828438894, 53.84305000305176, 3.7701911330223083, 0.18043086172214576, 0.10941162080104862, 0.06515792650835854, 0.09289995966745274, 0.08328498953155108, 0.06764904569302287, 0.03436273682330336, 0.1557248860065426, 0.07734900234001023, 0.026835640992171, 0.2162030107740845, 0.2142172644713095, 21.291314567838395, 68.93057686941964, 58.75192451477051, 37.00133228302002, 18.761414664132253, 22.273359060287476, 40.03436688014439, 54.58634049551827, 66.7961597442627, 53.85710620880127, 67.93408707209996, 15.998644147600446, 0.5794753655791283, 0.48328634990113123, 4.347955124718802, 4.413431908403124, 0.8501895048788616, 12.073226349694387, 43.91137831551688, 50.88333627155849, 41.15105356488909, 48.39987291608538, 51.5979654448373, 58.101124967847554, 55.86190121514456, 54.35890858513968, 52.093674251011436, 53.555314677102224, 51.343835081372944, 51.95229925428118, 52.37398542676653, 53.72764042445591, 51.618396622794016, 51.02357176371983, 49.094741412571494, 51.60096011843, 50.77497911453247, 48.308604853493826, 49.57781144550869, 52.91936690466744, 50.7143143926348, 52.18492841720581, 50.1801438331604, 49.10514981406075, 40.81307928902762, 36.2349077633449, 38.549998896462576, 39.952110631125315, 39.66999987193516, 40.21652085440499, 37.29908343723842, 38.823136057172505, 38.33926698139736, 38.0866756439209, 37.32789414269583, 39.978239331926616, 37.096616404397146, 37.42502301079886, 38.04337794440133, 35.79562875202724, 37.0037259374346, 42.27793673106602, 42.1397613797869, 41.24332216807774, 38.336355686187744, 38.45626769747053, 39.52345194135393, 38.59967851638794, 35.580050468444824, 36.33570875440325, 37.08978632518223, 35.87762096949986, 35.65706777572632, 34.8921023777553, 36.224415983472554, 38.75014870507376, 40.44495677947998, 43.052313464028494, 43.15486192703247, 43.43606942040579, 41.977621691567556, 41.6756842476981, 41.22208152498518, 44.01752594539097, 42.38433102199009, 39.96841805321829, 40.46109744480678, 39.64864458356585, 35.949958665030344, 36.770148345402305, 36.566823210035054, 40.32921716145107, 37.39402709688459, 37.41667822429112, 37.016350814274375, 40.503314699445454, 37.224702971322195, 38.14636066981724, 35.81491347721645, 38.935127122061594, 37.20557805470058, 37.91721602848598, 39.48184265409197, 40.70834561756679, 37.81848560060774, 35.550020354134695, 37.24056918280465, 36.80315228870937, 37.025928906032014, 37.97495903287615, 37.50830411911011, 39.10052898951939, 37.578463554382324, 38.08376782281058, 37.71679176603045, 37.68118224825178, 37.51748268944876, 38.81294304983956, 36.97739226477486, 39.977065086364746, 39.188489709581646, 45.993593624659944, 51.4493156841823, 49.62604236602783, 50.510704381125315, 52.358640330178396, 52.11126708984375, 50.985391412462505, 54.81227854319981, 53.63358266013009, 52.80559015274048, 53.46676336015974, 52.63216659000942, 52.41249234335763, 56.23915365764073, 57.13755920955113, 59.51615687779018, 58.222815717969624, 61.053049768720356, 63.17302853720528, 63.291606494358604, 56.22389888763428, 59.09857014247349, 55.06993511744908, 65.24421705518449, 55.00472974777222, 51.58377374921526, 9.186969842229571, 0.3233240262738296, 1.9201203499521529, 1.091787923659597, 0.19764444019113267, 10.926299367632184, 72.50860731942313, 63.791723932538716, 67.92041996547154, 56.92704268864223, 62.63170828138079, 25.988626854760305, 27.234393698828562, 42.91027838843209, 61.25291470118931, 62.3795234135219, 6.143880767481668, 0.3244131292615618, 0.14165835295404705, 0.08543753331261021, 0.061737628254507265, 0.08299274449901921, 0.19355020060070924, 0.12828991029943737, 0.3094446196087769, 0.16303916781076364, 0.21115737009261334, 0.40477477280156954, 0.5704903677105904, 27.04243929045541, 76.99913774217877, 64.53845378330776, 46.44342694963728, 23.911327396120342, 28.442999839782715, 42.69962290355137, 63.35510608128139, 72.03422600882394, 59.65566280909947, 72.25121825081962, 18.006749970572336, 0.795742823609284, 1.3106130787304469, 9.445815426962715, 4.670752797807966, 1.0964552674974715, 13.700020245143346, 46.827516419546946, 54.597259589603965, 45.27004643848964, 52.563893590654644, 54.82446568352835, 59.17810617174421, 57.18822199957711, 57.55391958781651, 54.41987555367606, 55.92873593739101, 54.09021479742867, 53.96343796593802, 54.51995045798165, 54.73162385395595, 55.225564343588694, 52.989352634974885, 50.115421363285606, 54.06483997617449, 53.340962750571116, 51.070114271981375, 52.08971725191389, 54.77076653071812, 53.48076398032052, 52.71958187648228, 52.47394221169608, 53.44653715406145, 43.354084151131765, 38.61431837081909, 40.820621558598106, 40.51638078689575, 41.552308559417725, 43.64336197716849, 39.698327677590505, 40.76454264777047, 40.95261301313128, 39.39325312205723, 39.629641260419575, 42.79287815093994, 38.53490393502371, 38.90421806062971, 39.8760278565543, 38.773835114070344, 36.68488005229405, 44.10654279163906, 42.970831939152305, 43.34336308070591, 39.39384719303676, 39.69903639384678, 40.423445156642366, 38.53536599023001, 38.75320938655308, 37.676356724330354, 40.036687578473774, 38.66865675789969, 37.93118190765381, 35.68072639192854, 37.35825777053833, 41.757332529340474, 43.84490489959717, 45.1694712638855, 45.70907531465803, 46.11185196467808, 42.47846869059971, 44.10816172191075, 45.096202509743826, 46.02280037743704, 45.288337571280344, 40.507216112954275, 42.128560883658274, 42.42411988122122, 39.31600999832153, 39.985013825552805, 37.545414447784424, 42.45433759689331, 38.64829853602818, 38.87460136413574, 39.85753870010376, 42.682638032095774, 38.76126234872, 39.88437264306204, 35.97542381286621, 40.03042030334473, 37.24393905912127, 40.74545594624111, 41.74798025403704, 42.22170148577009, 39.33810874394008, 37.880526065826416, 40.68774420874459, 39.86615099225725, 39.96942206791469, 39.082765919821604, 39.31285899026053, 40.2398042678833, 40.83480978012085, 40.60625226157052, 39.270356859479634, 39.840331486293245, 39.20037807737078, 40.597573961530415, 37.86759894234793, 41.71390628814697, 40.41686173847744, 48.49065807887486, 53.742082255227224, 50.67899669919695, 51.24035208565848, 52.85366473879133, 54.812129156930105, 51.71649476460048, 57.529819761003765, 55.69326148714338, 54.92459617342268, 54.50457756859915, 54.89458342960903, 56.02163335255214, 58.23303304399763, 59.57082530430385, 64.491379737854, 60.80554798671177, 62.52074554988316, 65.25541060311454, 66.07221998487199, 57.87414469037737, 60.51734365735735, 58.47883946555001, 68.05282483782086, 54.374031339372905, 55.78238255637032, 11.192918249538966, 0.4419950512903077, 5.53665120261056, 2.1186188757419586, 0.37630363340888706, 11.686534779412405, 79.28834683554513, 71.00692095075334, 72.38046864100865, 68.65298243931362, 70.08382497514997, 33.483587878090994, 34.4091226713998, 52.58637796129499, 67.86235386984688, 75.57834924970354, 8.514372927801949, 0.5863626588668142, 0.2745845844703061, 0.179098354652524, 0.23708550951310567, 0.26706383803061073], [0.058404650672205856, 0.005292851768899709, 0.03738707257434726, 0.08513117475169045, 0.059029106449867995, 0.09049949954663004, 0.05952447772558246, 14.293619615691048, 68.63343020847866, 45.84785515921456, 35.0325984273638, 19.335450513022288, 21.529464074543544, 37.96324437005179, 45.35935510907854, 62.3102707181658, 49.00384160450527, 60.5363678250994, 12.497531124523707, 0.3347680893327509, 0.29087365897638456, 1.670320559825216, 3.0184976628848483, 0.9543865365641457, 6.5223000730787, 43.15597711290632, 45.28732313428606, 53.86694138390677, 54.83700370788574, 48.151856967381065, 48.78728015082223, 50.13050242832729, 50.5337724004473, 50.36861024584089, 50.83339262008667, 53.54648699079241, 51.17549760001046, 50.50962046214512, 50.20874261856079, 50.65507752554757, 52.03891202381679, 49.330594539642334, 52.30442006247384, 52.90234381811959, 51.538131032671245, 51.1547155380249, 47.96409927095686, 45.926658153533936, 44.09221560614449, 42.0984091758728, 38.273808002471924, 34.745231355939595, 37.236768518175396, 36.0367659841265, 39.31632266725813, 38.947904859270366, 38.261940479278564, 37.877069337027415, 37.32604592187064, 36.3419760295323, 37.49851063319615, 35.39650338036673, 34.76201472963606, 35.640291350228445, 35.35044724600655, 35.63489259992327, 35.26931313105992, 35.978248255593435, 40.482244287218364, 41.058934347970144, 37.893859658922466, 36.81141717093331, 38.05960546221052, 37.309870515550884, 38.04838759558541, 36.82643570218767, 34.94527346747262, 34.470669814518516, 34.15041691916329, 34.7615943636213, 33.90768507548741, 33.433741501399446, 37.094024726322715, 36.83075748171125, 37.2713531766619, 38.285487924303325, 42.41133172171456, 39.66282933098929, 38.844008445739746, 39.62190791538784, 37.82958534785679, 38.76878029959542, 36.688034534454346, 35.60444211959839, 32.82693099975586, 33.963687556130544, 34.73621954236712, 36.00176790782383, 35.417577266693115, 37.609077317374094, 35.46448802947998, 38.07593720299857, 34.48092188153948, 34.738988399505615, 35.59926918574742, 35.116612570626394, 33.41982078552246, 37.301348549979075, 36.515208516802105, 36.90102808816092, 38.22877672740391, 34.425263336726594, 33.82111399514334, 34.456349577222554, 34.76325150898525, 34.59101261411394, 34.82574013301304, 36.59417479378836, 35.59995010920933, 36.25615882873535, 34.78724363871983, 35.54869672230312, 36.40214395523071, 36.172947202410015, 38.07210179737636, 36.671292849949424, 38.595867429460796, 37.4785658291408, 40.488317012786865, 48.516946588243755, 49.23789167404175, 52.214190755571636, 52.553349699292866, 50.53433173043387, 50.15379279000418, 51.953400543757844, 50.39598267418997, 51.59601994923183, 51.527343954358784, 51.643073150089805, 54.30277408872332, 54.85358558382307, 50.64756652287075, 52.76409203665597, 51.05455378123692, 56.666023186274934, 37.361672810145784, 54.61289998463222, 60.67772197723389, 59.82274614061628, 60.165611948285786, 63.20298222133091, 48.818828446524485, 53.34636844907488, 6.433470393930163, 0.3213133913065706, 2.5403167733124326, 0.5067789150135857, 0.1262029130011797, 7.191343418189457, 64.10168307168144, 55.71810824530465, 64.47744859967912, 47.887186186654226, 41.341521058763774, 12.736808844975062, 12.667620420455933, 33.419987542288645, 47.03419058663504, 42.03989839553833, 2.173011762755258, 0.1194685615066971, 0.04608838852228863, 0.044491425821823735, 0.029761746924902712, 0.08114636928907462, 0.10636150411197118, 0.06781842838972807, 0.06492405584348099, 0.1180647404066154, 0.06618256188396897, 0.08550971586789403, 0.12049495428800583, 20.518650565828594, 75.5344157900129, 50.908679825919016, 42.766683442252024, 24.38415925843375, 26.158690963472637, 43.022873946598594, 51.65475654602051, 66.27729606628418, 54.92831345966884, 68.96920885358537, 14.133483614240374, 0.4174742070691926, 0.25402407773903435, 5.816749155521393, 6.277472913265228, 1.326264656015805, 8.042660593986511, 44.85463101523263, 48.492343017033164, 53.6806879724775, 56.70627410071236, 50.57247039249965, 51.059070110321045, 52.47642271859305, 53.88623653139387, 50.373810972486226, 54.623596736363, 54.865560804094585, 54.387142590114046, 51.41040924617222, 51.53565052577427, 50.77476372037615, 54.13831717627389, 50.41720942088536, 53.73732621329171, 54.357206276484895, 54.45841373716082, 51.37219762802124, 51.532555103302, 45.96264634813581, 47.307546615600586, 43.686586720602854, 40.47029685974121, 35.60030794143677, 40.24638073784964, 36.44755390712193, 40.05588892527989, 39.95737041745867, 39.98808145523071, 40.17380332946777, 37.7757020677839, 38.47676488331386, 38.80677304949079, 37.9567825453622, 38.503022125789094, 35.9520639692034, 38.38909598759243, 37.35902554648263, 36.93945162636893, 37.02315310069493, 42.23210293906075, 42.44453021458217, 38.521386214665, 38.21683277402605, 38.98657505852835, 38.788422857012065, 37.52376733507429, 37.10696922029768, 37.90018946783883, 36.0475252696446, 35.35613087245396, 36.10545934949602, 35.7712926864624, 35.44298335484096, 39.17008740561349, 38.20635141645159, 39.4263265473502, 39.36530746732439, 44.0296505519322, 41.05347653797695, 42.29336173193795, 41.202998297555105, 39.65502650397164, 40.30212613514492, 39.40553058896746, 38.51675524030413, 34.96001059668404, 37.30440923145839, 36.710192339760916, 37.051140444619314, 36.757766655513215, 39.700342655181885, 38.236499650137766, 37.641869340624126, 35.34759848458426, 35.49174233845302, 37.519921507154194, 35.12924786976406, 35.593366691044395, 36.29109437125069, 36.42711578096662, 38.24567127227783, 40.344228744506836, 36.33373546600342, 36.466595445360454, 36.44532700947353, 38.38271754128592, 37.80164664132254, 37.625214508601594, 38.08779777799334, 37.31694030761719, 36.45213276999337, 36.15888752256121, 37.58221558162144, 37.321206501552034, 37.56748192650931, 38.59522124699184, 39.92978606905256, 41.326721395765034, 38.9843099457877, 40.59924152919224, 48.68571138381958, 50.86523274012974, 53.44075972693307, 52.091040883745464, 50.89050333840506, 51.80252388545445, 53.45039340427944, 53.592435428074424, 53.637251308986116, 54.07607173919678, 54.263634886060444, 56.68963663918631, 56.806460176195415, 50.95496872493199, 54.094418457576204, 51.24187026705061, 56.71947915213448, 37.864138739449636, 57.63165603365217, 62.60985619681222, 62.51586791447231, 61.21204539707729, 67.3000431060791, 51.31374590737479, 56.40969719205584, 7.505598715373448, 0.09681811263518673, 1.9869185941559928, 1.3365355048860823, 0.1266501082905701, 7.442633271217346, 69.38076455252511, 61.63628155844552, 71.93865353720528, 53.64017302649361, 44.54792710712978, 19.983620166778564, 22.07901620864868, 40.94502905436924, 55.09164128984724, 53.41439478737967, 4.018155404499598, 0.19345220657331602, 0.07646062358149461, 0.006557163100556603, 0.02057221146034343, 0.04843962771285858, 0.1652870729033436, 0.11796537573848452, 0.166356606941138, 0.20984185353985854, 0.15972001877214226, 0.21650456530707224, 0.17960067412682942, 25.997067178998673, 85.72097519465855, 58.83521951947893, 51.367914063589915, 31.978170326777867, 31.777391706194194, 49.68283346721104, 58.73094095502581, 70.38204860687256, 58.08762114388602, 73.52289840153286, 16.267513377325876, 0.5722118381943021, 0.7680252109255109, 7.877590503011431, 6.354369061333792, 2.9200790354183743, 8.517312015805926, 51.94840826307024, 53.32038218634469, 53.40533781051636, 59.26844664982387, 54.32649871281215, 54.926934242248535, 53.92821407318115, 55.31399754115513, 53.225789410727366, 57.976509026118684, 57.74447740827288, 55.87146193640572, 52.61023112705776, 53.64559262139456, 52.72104099818638, 56.61084754126412, 52.83430358341762, 55.648483821323936, 58.02260684967041, 57.15084069115775, 54.3002484185355, 53.147903578622, 49.16689498083932, 48.69557087762015, 45.75905023302351, 42.41356904166085, 36.1788774899074, 42.104679925101145, 39.87505858285086, 43.00794226782662, 41.55471611022949, 42.33853544507708, 41.469076088496614, 39.46093552453177, 41.62431621551514, 41.56109455653599, 38.864689758845735, 39.98902293613979, 38.45056670052664, 41.215088163103374, 40.14599663870675, 39.78562137058803, 38.83293301718575, 44.40339762823922, 43.795791557856965, 39.44076837812151, 38.21163204738072, 39.15067761284964, 39.57421200616019, 38.50647190638951, 38.936885016305105, 39.79838521139962, 38.556161948612754, 37.223466191973, 39.075022152491975, 37.070897647312705, 38.36904696055821, 41.69975280761719, 40.7207099369594, 41.70568656921387, 40.702609879629954, 47.345414297921316, 43.15425048555647, 45.177812576293945, 43.267766680036274, 42.09174237932478, 42.160022326878135, 41.711199964795796, 40.63710921151297, 37.357448305402485, 39.14993762969971, 39.64796018600464, 40.106694153376985, 38.73472370420183, 42.01070553915841, 39.08863367353167, 39.54732595171247, 37.25982958929879, 35.501546246664866, 38.569582394191194, 34.8482140813555, 35.458060945783345, 36.54730919429234, 37.74271549497332, 38.19180883680071, 41.808825629098074, 38.26500810895647, 38.917377948760986, 38.82380655833653, 40.319496631622314, 40.148164476667134, 39.84937456675938, 39.96115371159145, 39.45145123345511, 39.53524303436279, 37.17777483803885, 37.86012615476336, 40.19521420342581, 39.71637562343052, 40.75419678006853, 39.816843100956504, 44.53706359863281, 42.26632629122053, 43.84247650418963, 51.41798278263637, 55.68011896950858, 55.56525135040283, 54.93650885990688, 52.85807684489659, 53.671742166791645, 56.12832294191633, 56.068283557891846, 55.49839578356062, 56.97422095707485, 55.77459709984915, 60.02652290889195, 58.925261225019185, 52.714391572134836, 54.50789533342634, 52.94474867412022, 58.38306549617222, 39.99521030698504, 58.16091769082205, 66.24279131208147, 65.37807410103935, 65.9018987928118, 66.99146665845598, 53.66426937920706, 59.68204511914934, 8.70006787776947, 0.3729385882616043, 7.032686948776245, 3.462843430893762, 0.27901802371655193, 8.582659823553902, 73.4456900187901, 65.83045741489956, 77.58096599578857, 63.30333505358015, 51.35054704121181, 20.451343366077968, 24.682837997164043, 50.16229738507952, 63.46322005135672, 66.32614190237862, 7.1500550508499146, 0.5394714378884861, 0.16290115378797054, 0.21865991822310857, 0.09751748546425786, 0.27302379107901026], [0.07238673325628042, 0.03580235743096896, 0.04264274698549083, 0.06508967945618288, 0.016121001381959234, 0.1869568893952029, 0.11397978317524705, 11.272923282214574, 62.412437030247276, 46.795992442539756, 37.087687969207764, 17.193487644195557, 19.187622376850673, 37.05511828831264, 49.1355481828962, 60.53178201402937, 49.894277572631836, 60.27521283285958, 15.79660964012146, 0.28279059699603487, 0.35055290375437054, 2.6227465101650784, 7.112282906259809, 0.525540462562016, 5.439287398542676, 40.58796460287911, 51.80092927387783, 57.262609413691926, 55.16880103519985, 56.81286988939558, 53.591493947165354, 49.459976945604595, 49.290746620723176, 51.50315727506365, 52.1641845703125, 51.71307972499302, 50.35566922596523, 49.470051833561485, 51.60746710641043, 49.82917990003313, 50.45335742405483, 50.01075717381069, 50.77976989746094, 50.12327282769339, 47.90913554600307, 44.5851103918893, 46.528917585100444, 42.941618238176616, 40.12824051720755, 38.11150850568499, 36.762150968824116, 37.829484598977224, 37.54271854673113, 36.69374247959682, 36.788988385881694, 36.80747059413365, 38.189206736428396, 38.129848275865825, 36.93187461580549, 36.1739616394043, 36.014556067330496, 36.20678492954799, 37.01353679384504, 34.56848308018276, 35.54445137296404, 34.5642967905317, 36.4269038609096, 35.26397344044277, 38.63633026395525, 43.232796396527974, 37.49414021628243, 36.761883463178364, 35.24892364229475, 36.099706241062705, 34.68580341339111, 35.445029599326, 35.577229499816895, 35.121167114802766, 34.06289740971157, 33.43099348885672, 33.19732209614345, 32.974788665771484, 34.559380940028596, 36.098688329969136, 37.773430006844656, 39.2038209097726, 40.661723205021445, 39.13824381147112, 36.183494567871094, 38.82478278023856, 37.36511564254761, 36.89368731634957, 35.04749883924212, 35.139534677777974, 34.59205831800188, 33.693541594914024, 33.02612543106079, 34.86413587842669, 36.85196338381086, 36.38932800292969, 38.129486969539094, 36.54385593959263, 36.148576395852224, 35.10114588056292, 35.941297735486714, 35.49210711887905, 35.633836473737446, 37.19431849888393, 35.299728870391846, 37.785238470349995, 38.47086933680943, 35.940533433641704, 35.13442080361502, 34.004831314086914, 34.04430750438145, 35.79077543531145, 34.61057179314749, 37.23639678955078, 34.637662819453645, 35.71200023378645, 35.923770904541016, 35.54208551134382, 36.5644781930106, 38.69639049257551, 36.282951082502095, 41.04678542273385, 39.86980921881539, 38.35070024217878, 37.67859057017735, 38.53816958836147, 46.0984662600926, 47.169708251953125, 49.40226173400879, 49.7398955481393, 49.76321370261056, 51.66033942358834, 50.93348142078945, 52.5179659979684, 52.03043869563511, 53.4704771723066, 51.82933003561837, 50.81355551310948, 53.427735328674316, 53.69946895326887, 53.65877682822091, 57.367964948926655, 39.57609496797834, 44.50689104625157, 56.79254988261631, 57.52976417541504, 64.93817670004708, 54.531779766082764, 53.31001547404698, 50.88671657017299, 5.592899910041264, 0.018456432402932217, 1.2656959061111723, 0.8262257107666561, 0.12591768402074063, 5.665850784097399, 66.4530576978411, 56.48048543930054, 64.83453736986432, 48.950833797454834, 53.573313985552105, 27.12068121773856, 12.758402977670942, 31.059364863804408, 46.39764526912144, 55.73365136555263, 6.894010892936161, 0.2609955093690327, 0.05900862826300519, 0.054101062672478814, 0.01817432977259159, 0.07586263745490994, 0.06505364246134247, 0.09335897503686802, 0.08734105474182538, 0.13345889507659844, 0.0262599362592612, 0.12933238436068806, 0.18512641904609545, 16.819377524512156, 71.46154853275844, 53.03764608928135, 45.31049190248762, 20.85093252999442, 19.26330736705235, 39.88420588629586, 54.237891810280935, 65.09198897225517, 54.93145751953125, 66.28714861188615, 16.124232837132045, 0.21714580804109573, 1.2056159185511726, 6.447327707495008, 6.906387805938721, 2.5386463829449246, 6.423250462327685, 43.169296809605186, 53.98060696465628, 55.94420610155378, 59.06765760694231, 56.8160035269601, 55.17965759549822, 50.75833470480782, 50.88374621527535, 50.016010011945454, 53.03355360031128, 51.68997349057879, 52.99062762941633, 51.71944080080305, 52.858941895621165, 51.102082933698384, 51.57999392918178, 52.01366227013724, 53.87634924479893, 50.922072478703086, 49.039510181971956, 47.31234087262835, 48.39839989798409, 45.0284332547869, 43.012774739946636, 38.98656463623047, 39.21219001497541, 39.9922434261867, 40.20328801018851, 38.24410097939627, 39.6579794883728, 38.10313245228359, 38.461381571633474, 40.846458435058594, 38.28194086892264, 37.64461040496826, 37.39557307107108, 37.193918977464946, 37.34076220648629, 36.83572544370379, 37.741127831595286, 36.48857607160296, 37.3205429485866, 36.62766163689749, 39.57117911747524, 43.4908698626927, 38.9000734601702, 36.33035864148821, 36.96320056915283, 36.25866365432739, 36.0037898336138, 37.61774866921561, 38.49014711380005, 35.41917187826974, 35.456035545894075, 35.10982418060303, 35.91587427684239, 34.793003695351736, 35.89522075653076, 36.9643748147147, 39.22942154748099, 40.70299203055245, 41.377453667776926, 40.89861856188093, 38.82486615862165, 41.03534868785313, 39.196525301252095, 38.27735505785261, 36.684466634477886, 36.7311863218035, 35.48548548562186, 36.18067707334246, 35.70274175916399, 34.495134421757285, 38.812390668051584, 38.53627967834473, 38.87301370075771, 36.5555601801191, 36.934045927865164, 36.660026345934185, 36.55905859810965, 35.14300182887486, 36.33226939610073, 37.26728848048619, 35.62151731763567, 39.98868247440883, 39.705908162253245, 35.5732273374285, 35.77742447171892, 36.76183829988752, 35.94902760641915, 37.66165433611189, 36.22715009961809, 38.82771839414324, 36.932753562927246, 37.72129072461809, 37.98730945587158, 38.0614641053336, 39.53365189688546, 38.69421223231724, 39.6452225957598, 41.63171257291521, 42.088754653930664, 40.77534709657942, 39.48190518787929, 40.426960945129395, 47.10688958849226, 48.79179647990635, 51.577798298427034, 51.518273081098286, 51.35105078560965, 52.75141504832676, 53.40963179724557, 54.30628987721035, 55.48495101928711, 52.90670728683472, 51.73683909007481, 52.4909131867545, 55.97956201008388, 55.450105803353445, 55.40152399880545, 58.47015421731131, 41.657841273716514, 44.12521954945156, 58.340466090611045, 59.21227046421596, 66.27578830718994, 58.281031199863975, 54.41746800286429, 53.1958635193961, 6.273700909955161, 0.10902882527027812, 2.48237943649292, 1.556022367307118, 0.13145484189902032, 5.970811128616333, 72.00329262869698, 61.38984979901995, 70.56133297511509, 53.69210038866316, 52.573464734213694, 28.325007268360682, 14.52500331401825, 38.42568867547171, 55.15912219456264, 63.66724695478167, 10.207688008035932, 0.2806722920920168, 0.11901254526206426, 0.043786858807184866, 0.0394754981888192, 0.05205547636640923, 0.1376126150467566, 0.21297543682157993, 0.14235793612897396, 0.19892031672809804, 0.1527976045118911, 0.3194103719932692, 0.2848549990781716, 23.099468605858938, 82.20772280011857, 60.110769816807334, 52.6799875668117, 28.446597269603185, 27.572531257356914, 47.79193333217076, 60.84220668247768, 69.60232176099504, 59.390380586896626, 69.23109340667725, 18.287905352456228, 0.4427821790533406, 1.7185784046139037, 6.901096318449293, 15.910111938204084, 3.9928813321249823, 6.4679668971470425, 48.489094734191895, 54.947917801993235, 59.895910671779085, 61.324231011526926, 59.75566823141915, 57.473515033721924, 53.154330662318635, 54.14546339852469, 52.16729736328125, 56.31426021030971, 56.68900782721383, 54.981762477329795, 52.167068072727744, 56.442503111703054, 52.162680285317556, 53.207925592150005, 53.62188884190151, 55.298951217106406, 53.23797655105591, 51.819765840257915, 48.983198506491526, 51.80098138536726, 47.333699635096956, 45.25004257474627, 42.697729519435335, 40.383225509098594, 42.16024119513375, 42.40445300510952, 41.14176034927368, 42.527126925332205, 40.53262914930071, 42.03194965635027, 43.62797866548811, 41.641071796417236, 39.54144082750593, 39.80419043132237, 38.72803258895874, 39.39914519446236, 38.13983978543963, 39.5999550819397, 39.02230964388166, 40.046738147735596, 39.895548820495605, 40.93331439154488, 44.43009260722569, 38.51713391712734, 37.03590651920864, 37.20759303229195, 36.61634649549212, 35.324870926993235, 39.4456216948373, 39.42823730196272, 38.150237764631, 38.5167795589992, 36.43438707079206, 36.332213810511995, 36.269454206739155, 39.85349484852382, 38.24747780391148, 42.54277426855904, 43.78656087602888, 44.04836205073765, 42.190559659685405, 40.79652520588466, 43.790622098105295, 41.13783114297049, 41.080261843545095, 37.48704957962036, 40.49971553257534, 38.547914436885286, 38.28387246813093, 37.16565023149763, 37.70395149503435, 41.90006242479597, 41.31656660352434, 41.00299787521362, 38.8050742149353, 38.21516868046352, 35.920348916734966, 37.11353179386684, 36.08502122334072, 36.78720269884382, 36.97237913949149, 35.631619998386924, 40.41372462681362, 41.78570549828665, 39.537859031132285, 39.011282852717805, 37.83405303955078, 37.83642932346889, 39.593899726867676, 39.05616821561541, 42.50362811769758, 37.152792590005056, 39.64572286605835, 40.170117310115266, 40.40215240206037, 41.2066912651062, 41.64305203301566, 41.64936447143555, 44.32190220696585, 43.705398968287874, 42.54060295649937, 41.97312273297991, 41.676125458308626, 49.663340296064106, 51.04461785725185, 55.00431980405535, 53.86551005499703, 53.41405779974801, 55.17186171667916, 56.69547312600272, 56.30149984359741, 57.167870725904194, 55.5189277103969, 52.956911495753694, 54.42728580747332, 58.174682072230745, 56.34676388331822, 57.92236518859863, 59.67404774257115, 41.677497727530344, 45.31761728014265, 60.10313374655587, 63.48705237252371, 63.40085302080427, 61.65749440874372, 58.55973734174456, 56.354789052690776, 7.842222435133798, 0.23126837451543125, 4.315398471696036, 2.84184535912105, 0.30153295557413784, 7.281406836850302, 77.19529233660016, 68.3969065802438, 77.34070423671177, 64.54997389657157, 68.84685107639858, 37.30872058868408, 23.32656352860587, 49.767834254673545, 63.46702071598598, 76.47172777993339, 15.496688910893031, 0.6018567074622426, 0.2804330406444413, 0.19401446783116885, 0.12637640083474772, 0.18805546473179544], [0.023100667034408877, 0.0498488669150642, 0.02583723608404398, 0.052797142283192704, 0.07460996681558234, 0.14885180124214717, 0.06813109732632126, 11.109554631369454, 61.52776459285191, 42.60742378234863, 33.632189001355854, 22.78213742801121, 30.489084516252788, 45.690950938633506, 46.00135823658535, 62.878841808864046, 47.53940452848162, 63.58126299721854, 14.03333054270063, 0.10826060827821493, 0.3644256607762405, 8.236471039908272, 6.516288578510284, 2.084627636841365, 7.358114515032087, 44.27818066733224, 53.5012264251709, 58.62215995788574, 54.93767615727016, 50.63054691042219, 48.445077896118164, 48.643970080784385, 47.3729430607387, 48.22622701099941, 50.319271087646484, 52.8218663079398, 53.623796122414724, 51.22233540671212, 51.39663444246565, 49.339238098689485, 52.84855086462838, 49.808370045253206, 48.51839876174927, 46.28024155752999, 46.47966180528913, 43.52719504492623, 39.091923645564485, 37.70470190048218, 37.08527347019741, 36.43662439073835, 37.34501450402396, 35.25081007821219, 34.67217452185494, 33.980804443359375, 35.367539814540315, 36.89362825666155, 36.29080254690987, 35.69863537379673, 38.73700966153826, 36.45853206089565, 36.19528913497925, 35.48855658939907, 34.49168464115688, 33.97215741021292, 33.468145506722585, 36.435092312949045, 36.18661430903843, 34.321127210344585, 36.60906825746809, 42.474501269204275, 38.80959054401943, 37.54021372113909, 37.33928918838501, 35.95344318662371, 34.6899653843471, 34.704216139657156, 36.603832789829795, 36.280276026044575, 35.018239974975586, 36.57802023206438, 34.75015762874058, 32.03659078053066, 33.743992464882986, 34.70662369046892, 34.49323408944266, 36.94391931806292, 38.08187096459525, 38.4927978515625, 36.613772187914165, 36.103496483394075, 38.83728606360299, 36.130406856536865, 34.318837778908865, 34.290374483381, 33.499349866594585, 34.6024945122855, 34.290273734501426, 34.64439214978899, 36.286553723471506, 34.45525871004377, 38.15349299567086, 37.61313853945051, 36.650757449013845, 36.48902423041207, 37.43299606868199, 35.53280619212559, 35.680594376155305, 36.3130715233939, 35.0548882484436, 37.74434832164219, 41.34986237117222, 34.31464801515852, 34.78821638652256, 33.44533109664917, 35.24351099559239, 35.0671101297651, 34.391641003744944, 37.098982266017366, 36.53546251569475, 36.72225441251482, 35.87701300212315, 35.84532226834978, 37.13344185692923, 35.445943287440706, 39.5106429372515, 40.09264142172677, 40.316623551504954, 40.15935802459717, 39.18460219247, 36.0172450201852, 38.35098859242031, 42.16016476494925, 43.65506969179426, 47.09637001582554, 48.539712360927034, 49.789394514901296, 50.89574228014265, 51.72637162889753, 50.21146978650774, 52.94125025612967, 51.43004485539028, 53.97518042155674, 54.8935273034232, 53.70921032769339, 54.48421934672764, 56.737523623875205, 60.24264662606375, 59.84400762830462, 52.912974561963765, 65.22201756068638, 56.11552783421108, 53.546354975019185, 64.49987043653215, 51.57245165961129, 4.792599013873509, 0.20234556150223526, 0.5325096143143517, 0.9932167615209306, 0.10746464598923922, 3.5461069515773227, 60.358354977199006, 58.86596529824393, 64.40021937234062, 57.665375641414094, 42.0775854246957, 19.277778727667673, 15.10437103680202, 32.40139205115182, 50.412276199885774, 61.85221767425537, 10.217088052204677, 0.5244335819567952, 0.08748475488807474, 0.09137128133858953, 0.04571771841230137, 0.04509369350437607, 0.11790936945804528, 0.07176088648183004, 0.041396739560046365, 0.06245947416339602, 0.04384899565151759, 0.27400462701916695, 0.15299767734748976, 17.196893998554774, 67.7178452355521, 48.712913581303184, 35.63009139469692, 24.063456467219762, 24.06182885169983, 44.05715152195522, 52.82264798028128, 64.26761995043073, 53.80928175789969, 67.13211209433419, 16.40328117779323, 0.34024329696382793, 1.623180940747261, 8.231017572539193, 13.195994445255824, 2.4674514489514485, 8.22378362928118, 47.71102850777762, 54.12876687731062, 58.27868618283953, 56.529678685324534, 53.347282137189595, 50.426870891026084, 49.9474903515407, 49.32966695513044, 50.47063411985125, 52.622369629996165, 53.536846365247456, 54.65371022905622, 53.58287123271397, 52.15163264955793, 52.26321724482945, 53.442430768694194, 52.62972777230399, 50.605022702898296, 49.1959627696446, 49.237332344055176, 44.21197475705828, 41.394660881587434, 40.056795665196006, 38.47823442731585, 37.56588731493269, 39.54204879488264, 37.39925561632429, 37.626194204602925, 36.381195136478965, 36.5955296925136, 38.65670585632324, 38.32331044333321, 38.92080341066633, 39.88020372390747, 38.93216371536255, 37.50695616858346, 36.33870690209525, 36.70805924279349, 36.18853896004813, 35.92410789217268, 37.87183386938912, 39.01554209845406, 36.478782585689, 37.4432863507952, 43.739556312561035, 38.22195359638759, 36.541569982256206, 37.45264210019793, 34.989734990256174, 35.29098456246512, 35.46763903754098, 38.1967316355024, 38.462823322841096, 37.36566455023629, 37.6659448487418, 36.7868344443185, 33.390541076660156, 35.58536236626761, 35.905521460941856, 37.60093402862549, 39.32200629370553, 40.878614698137554, 39.79539401190621, 40.16067818232945, 40.334435258592876, 41.33918298993792, 37.675543785095215, 36.99483224323818, 35.74905150277274, 36.57995877947126, 35.81991965430123, 38.261829308101106, 35.134236676352366, 37.814417430332725, 37.55677475248064, 39.85820572716849, 38.89281259264265, 38.03066274097988, 36.774386746542795, 36.682698317936485, 34.667831897735596, 35.777487005506245, 37.435559953962056, 36.659032753535676, 38.45597587312971, 42.59578554970877, 35.60161072867257, 36.74500976290022, 36.199419839041575, 36.269746031079976, 36.96017810276577, 35.415207930973594, 38.2557635307312, 37.461351667131694, 37.512247221810476, 38.263750485011506, 38.10789196831839, 37.45004347392491, 38.04927001680647, 40.970292704445974, 40.74386133466448, 42.32785606384277, 41.06167541231428, 41.793536118098665, 38.697509152548655, 40.04277767453875, 44.296530859810964, 47.588913917541504, 48.6939172063555, 49.46226985113961, 50.779929706028526, 53.94881895610264, 52.83333430971418, 51.06581333705357, 53.59557253973824, 51.77339356286185, 55.12967225483486, 56.14128133228847, 55.56648118155343, 57.705859320504324, 59.86636693137032, 62.227614947727744, 57.9983263696943, 52.77422251020159, 61.824883460998535, 56.67155047825405, 57.36933721814837, 63.206824575151714, 54.360576152801514, 5.637910340513502, 0.2335584302033697, 2.3208974386964525, 1.1954900047608783, 0.13393712655774184, 4.038759853158679, 66.47766821725028, 64.0930256162371, 70.77733857291085, 61.92406899588448, 45.484658922467915, 24.29663974898202, 20.83474496432713, 44.55760942186628, 56.116090638296946, 71.5119994027274, 14.041242803846087, 0.5087750021900449, 0.16120093502104282, 0.07913204987666436, 0.06801661489797489, 0.03810780907848051, 0.16379065891461714, 0.1623694130352565, 0.13138715124555997, 0.13650527303772314, 0.12030348527644362, 0.4232620564954621, 0.2684739152235644, 22.40267893246242, 78.29075922284807, 55.1685265813555, 48.8689284324646, 33.02972459793091, 42.67782987867083, 56.43291112354824, 58.038518224443706, 72.1912761415754, 56.88687515258789, 73.19581195286342, 17.981929268155778, 0.30419186289821354, 1.2475492741380418, 19.733227934156144, 15.17295149394444, 4.683352487427848, 9.595609034810748, 48.196346282958984, 56.148639474596294, 59.72999463762556, 60.666014262608115, 56.02452032906668, 52.94358137675694, 52.64112629209246, 51.06212036950247, 51.5905065536499, 54.29915407725743, 57.42269243512835, 56.55707890646798, 55.25500038691929, 55.06812858581543, 51.91784313746861, 55.56451484135219, 54.776790618896484, 52.60485669544765, 51.22300590787615, 50.189402307782856, 45.59347813470023, 44.06604869025094, 43.43390505654471, 42.331955501011436, 39.743987764631, 41.24624388558524, 39.627126012529644, 39.5074120249067, 38.57749291828701, 40.38774183818272, 41.86416803087507, 42.57612214769636, 41.93544612612043, 43.27692093167986, 41.98697396687099, 39.948344707489014, 39.088890756879536, 38.45761564799717, 38.551423277173726, 37.144062178475515, 40.64653096880232, 41.80396883828299, 38.427279812949045, 38.796448026384624, 45.756482873644146, 39.30239847728184, 38.06117228099278, 37.63295827593122, 35.87409128461565, 36.4160611970084, 35.25893947056362, 39.85899087360927, 40.411094733646934, 39.534034047807964, 41.58582666942051, 39.60046924863543, 34.88658550807408, 37.81617185047695, 37.77029289518084, 39.67034033366612, 41.763016155787874, 43.73095791680472, 42.75291211264474, 43.43273775918143, 41.85686894825527, 44.63677372251238, 40.719632966177805, 38.84910842350551, 37.88951703480312, 38.208567891802105, 39.66985048566546, 40.58656454086304, 37.24266753877912, 41.65627792903355, 37.94596420015608, 41.61881671633039, 40.41831043788365, 38.732427324567524, 36.92366879326956, 37.398487840379985, 35.44375113078526, 35.92742565699986, 37.10261269978115, 36.84953498840332, 40.21161890029907, 44.977537700108115, 38.4044827733721, 38.987255981990266, 38.3396942956107, 38.693812710898264, 38.04912410463606, 36.687655857631135, 40.04930203301566, 39.01126548222133, 38.80121796471732, 40.39027793066842, 39.29573515483311, 41.021625995635986, 40.2458769934518, 43.6210686819894, 43.62812805175781, 42.91828271320888, 43.14053126743862, 43.56940882546561, 39.72041947501046, 41.67096989495413, 45.69396298272269, 48.72937733786446, 51.0033073425293, 52.60079894747053, 54.20908457892281, 55.70769984381539, 56.80142273221697, 51.635999883924214, 56.820773465292795, 55.10949468612671, 58.048697335379465, 58.07651097433907, 58.61514227730887, 58.77659061976841, 62.9577386038644, 66.07602064950126, 60.758001463753835, 53.97843565259661, 62.88025229317801, 59.35067858014788, 60.81049510410854, 64.67181055886405, 57.75063698632376, 6.255002873284476, 0.22602540227983678, 4.137003907135554, 3.5095820086342946, 0.32380236632057596, 4.632569406713758, 72.323625428336, 70.42996338435582, 76.45512158530099, 70.58272647857666, 54.10024799619402, 29.03358629771641, 27.291603428976877, 51.245184557778494, 66.41566249302456, 82.62484400612968, 21.103209461484635, 0.7187026089855603, 0.30488660133310724, 0.2397613259298461, 0.12919666378625802, 0.17931760288774967], [0.02891729652349438, 0.04978045701448407, 0.040910362266004086, 0.0929809088951775, 0.01981144308644746, 0.19284115864762238, 0.024018931867820874, 8.693929144314357, 60.0733676637922, 48.290688923427034, 49.96423898424421, 24.638736043657573, 27.764987673078263, 47.11194092886788, 44.86476843697684, 62.33028847830636, 48.35306985037667, 65.80269936152867, 14.143044335501534, 0.26800214339579853, 2.135510815041406, 9.782387035233633, 3.8515792914799283, 2.345498187201364, 8.471459984779358, 49.81971297945295, 52.08564908163888, 52.640375886644634, 55.21950898851667, 49.58375562940325, 47.69937290464129, 45.14684445517403, 47.7846794128418, 49.27908754348755, 53.59321015221732, 53.583347184317454, 54.569390365055625, 49.48569917678833, 51.51854406084333, 50.41384996686663, 49.9436479977199, 50.491058349609375, 49.67447131020682, 43.77593013218471, 39.84577192578997, 35.56994431359427, 36.78908218656267, 36.95427213396345, 36.10118620736258, 34.915027959006174, 33.973095417022705, 34.42593731198992, 35.33332341057913, 35.04913166591099, 35.373713288988384, 33.92980119160244, 34.15367215020316, 33.79273407799857, 35.638863495418, 34.21727248600551, 35.23330061776297, 35.13795048849923, 36.51223121370588, 34.77985422951834, 36.03740521839687, 34.93844338825771, 35.6183419908796, 35.66491576603481, 35.35739197049822, 45.17868457521711, 41.6575459752764, 36.084520953042166, 37.88782862254551, 34.32302754265921, 35.599224022456575, 34.830124446323936, 34.599298340933665, 34.70330592564174, 35.641166823250906, 33.78196437018258, 33.09995698928833, 34.14645297186715, 34.14418091092791, 33.58481270926339, 35.011653082711355, 34.901385171072825, 36.90011092594692, 37.29231936591012, 37.545004504067556, 34.01711572919573, 36.15291207177298, 35.318534169878276, 32.81399692807879, 33.28995895385742, 33.069270270211355, 33.235224519457134, 35.79103946685791, 36.10261058807373, 35.57114635195051, 36.58480167388916, 35.46043375560215, 35.21228926522391, 35.728401456560405, 35.10342141560146, 35.005444867270334, 34.32517801012312, 36.16826064246041, 36.88892085211617, 34.23430946895054, 40.16254724775042, 40.98340048108782, 32.58386564254761, 35.905445030757356, 34.388281549726216, 34.85471064703805, 36.089502811431885, 34.68256207874843, 35.34032719475882, 35.45246417181832, 36.014934744153706, 35.501904078892295, 36.88210814339774, 39.65530095781599, 41.76497902188982, 42.279656410217285, 43.826002325330464, 44.15897042410714, 43.34009395326887, 40.664168970925466, 37.39073017665318, 38.89898954119001, 36.960063457489014, 41.29851170948574, 41.168559551239014, 45.103164604731965, 45.15158312661307, 46.819213322230745, 49.98494461604527, 52.34979179927281, 52.01479830060686, 54.27505077634539, 51.595696857997346, 51.260946546282085, 50.85257312229702, 54.153554575783865, 54.07752043860299, 53.34478425979614, 55.76192705971854, 62.15479782649449, 48.34759814398629, 35.33590119225638, 61.84974411555699, 67.10171372549874, 53.494010720934185, 3.3678591677120755, 0.25670342253787176, 1.2044207198279244, 0.9049978724547795, 0.13164344749280385, 2.8911200293472836, 58.635952132088796, 60.83078384399414, 61.26155826023647, 61.416600363595144, 53.152711732046946, 25.481357983180455, 8.619315913745336, 14.35011281285967, 44.9121482031686, 58.371225765773225, 14.129931347710745, 0.25303083817873684, 0.019967590957613926, 0.060708059929311275, 0.10279462193804127, 0.06039394571312836, 0.02292153887849833, 0.02056598590154733, 0.1011212867285524, 0.08503713658345596, 0.052916065723236115, 0.16293630190193653, 0.15776070819369384, 13.793301548276629, 71.02643844059536, 52.38240316935948, 55.29870455605643, 29.375347341809952, 31.789512838636124, 49.03920793533325, 48.59173352377755, 67.05416025434221, 53.29321820395333, 69.86056545802525, 15.724548135484968, 0.15861796933625424, 2.596777183668954, 19.654417991638184, 9.93808400630951, 3.889642826148442, 9.647505130086627, 49.75100919178554, 53.905413559504915, 54.34024919782366, 57.3646992955889, 52.14954471588135, 49.4402232170105, 47.18513672692435, 51.104990754808696, 50.96980312892369, 55.067326068878174, 54.152654784066335, 54.515607833862305, 51.69214480263846, 51.999272550855366, 52.097697257995605, 52.57623706545149, 51.17309004919869, 51.75270182745797, 46.395067487444194, 41.01625156402588, 37.29758957454136, 38.560768604278564, 39.47925097601754, 38.69090836388724, 37.83085339409964, 36.212221894945415, 36.98038346426827, 36.903664929526194, 36.65334217888968, 38.01899324144636, 35.89491850989205, 37.64413792746407, 37.82809495925903, 37.33388696398054, 37.06396334511893, 36.031113624572754, 36.97327545710972, 37.847786154065815, 36.62070649010794, 37.56008209500994, 37.33932045527867, 37.09007467542376, 37.950042792728965, 37.03671945844378, 46.1418890271868, 41.56094864436558, 37.223073618752615, 38.314851011548726, 35.79711219242641, 36.271872179848806, 35.87230212347848, 37.04799291065761, 35.87700605392456, 36.20327261516026, 35.773832253047395, 34.98615319388253, 35.051820618765696, 35.696696826389854, 36.29155642645699, 36.43185445240566, 36.78873130253383, 39.206197193690706, 39.810266630990164, 39.643179825374055, 36.91014412471226, 38.90581267220633, 37.397911139896934, 35.88857133047921, 36.25407089505877, 35.533195291246685, 36.27094112123762, 38.0726889201573, 37.378911290849956, 36.55838114874703, 37.064237798963276, 37.5485063961574, 36.35743229729788, 34.420017446790425, 34.87215757369995, 35.56489644731794, 34.95870086124965, 35.935381344386506, 36.591607434409006, 35.06853451047625, 40.75616659436907, 41.654919556209016, 35.69929892676217, 36.09816026687622, 35.05691017423357, 37.098707812173025, 37.09274973188128, 36.95410885129656, 37.15811838422503, 38.75717680794852, 38.44920832770211, 37.88363538469587, 38.005201067243306, 43.06127316611153, 42.199349130902974, 44.11787877764021, 45.23632335662842, 45.84104939869472, 45.401554993220735, 41.790416376931326, 39.583154337746755, 40.25074768066406, 39.09082930428641, 42.97969436645508, 44.163042068481445, 47.39470829282488, 47.14009850365775, 48.68182734080723, 52.60125058037894, 55.41275576182774, 53.98317779813494, 56.03601959773472, 52.268386704581125, 51.96125895636422, 52.67611394609724, 55.67279209409441, 56.30008241108486, 56.64604711532593, 57.94432149614607, 62.91449301583426, 50.42051676341465, 36.7943628174918, 63.591671398707796, 66.53840242113385, 56.97094488143921, 3.976411061627524, 0.24043576259698185, 1.2833284799541747, 1.3257256277969904, 0.20608780426638468, 3.2952561378479004, 63.942868096487864, 66.11534745352608, 66.6450503213065, 67.31746918814522, 49.74269567217146, 29.201121262141637, 15.972042969294957, 24.008701188223704, 52.833431584494456, 67.68722452436174, 16.9160703931536, 0.2563321010342666, 0.05033566490081804, 0.10440059219087873, 0.0479774435849062, 0.03729245086599674, 0.08104513186429228, 0.1485614153955664, 0.20888805043484482, 0.21885304286011628, 0.16968487549040998, 0.40909733942576815, 0.26771455311349457, 18.450859716960363, 80.70120048522949, 59.56569753374372, 66.63745594024658, 35.61312389373779, 36.08166176932198, 58.5803040095738, 56.229186466761995, 72.3686636516026, 57.83014522280012, 76.59898403712681, 17.909110409872874, 0.4355076594012124, 6.144387551716395, 17.380661691938126, 7.884841816765921, 4.5217591013227185, 11.384419287954058, 51.91019664491926, 54.70726694379534, 57.22378635406494, 59.46200956617083, 53.21967152186802, 52.808887072971885, 49.76491253716605, 54.34510598863874, 51.83808476584298, 57.47119433539254, 55.76581457683018, 57.53833130427769, 53.75892121451241, 54.874600410461426, 53.79118864876883, 53.53529691696167, 54.00449487141201, 54.384099279131206, 47.72909035001482, 43.973238127572195, 40.306076186043875, 41.822537899017334, 41.55754402705601, 41.16515145983015, 40.60273994718279, 37.42738192422049, 39.051099504743306, 39.16511944362095, 37.63161032540457, 41.61163227898734, 38.403576033455984, 39.42295667103359, 39.305917739868164, 38.71584892272949, 38.558246408190044, 37.63053682872227, 38.49455574580601, 40.824345793042866, 38.8102263041905, 39.91864810671125, 38.485092299325125, 39.29845190048218, 39.55037273679461, 39.46059158870152, 48.57303592136928, 42.727304526737754, 36.80875948497227, 37.757890360695974, 36.07853855405535, 36.82394824709211, 36.394247327532085, 36.281286988939556, 38.10052340371268, 41.19338199070522, 38.02250208173479, 38.40324599402291, 36.95508854729788, 38.14312628337315, 37.61619227273123, 39.384390694754465, 38.49996839250837, 40.92189155306135, 42.09107535226004, 42.781639439719065, 39.77078696659633, 40.80283069610596, 39.84719978060041, 38.80703360693795, 37.61104713167463, 37.14185959952218, 38.13339533124651, 39.50250312260219, 38.111480712890625, 38.33173860822405, 38.90727874210903, 37.91844933373587, 36.420487199510845, 35.350631373269216, 34.40483910696847, 35.50064992904663, 33.994422912597656, 36.24890143530709, 37.21882479531424, 35.18756410053798, 42.102390493665425, 43.470588071005686, 36.58686181477138, 38.943864481789724, 36.35938474110195, 38.30451556614467, 40.53109359741211, 38.56493752343314, 38.065070220402305, 39.77493504115513, 40.011451721191406, 41.292901039123535, 40.78715903418404, 44.476114000592915, 45.23459325517927, 47.34849582399641, 48.30075338908604, 48.036641938345774, 47.465798786708284, 44.371168409075054, 41.18838276181902, 43.63175848552159, 41.02270296641758, 46.42115797315325, 46.420091424669536, 50.36540017809187, 49.53644534519741, 50.79266227994646, 54.15901238577706, 58.11333295277187, 55.8045368875776, 58.627454485212056, 55.2968042237418, 56.52146938868931, 54.33692448479788, 59.23424761635916, 58.628635678972515, 58.54300607953753, 61.136039052690776, 66.26342746189663, 54.9812969480242, 41.628113406045095, 63.690912519182476, 66.80361516135079, 57.52277428763253, 5.268893684659686, 0.533887040402208, 4.281040932450976, 3.8050254923956732, 0.33604389801621437, 4.017579138278961, 69.26249926430839, 70.08320658547538, 71.10960142953056, 72.7081526347569, 66.29135922023228, 34.86000517436436, 17.464316265923635, 27.699292455400737, 63.393140520368306, 79.12288243430001, 25.838766370500835, 0.5264815092086792, 0.17987033751394066, 0.21165561835680688, 0.13914294221571513, 0.15495100324707373], [0.027772194040673118, 0.07009730860590935, 0.04252997785806656, 0.15286378881761006, 0.012017161369190683, 0.2678861953318119, 0.24161763489246368, 10.124670931271144, 65.13590853554862, 50.57232448032924, 35.648841108594624, 15.283334050859724, 17.83481158529009, 42.78202159064156, 46.74866131373814, 61.45934568132673, 52.596928800855366, 60.28459290095738, 13.977352380752563, 0.6250358436788831, 2.452793572630201, 6.788968460900443, 12.994442837578909, 2.0995104610919952, 4.942775206906455, 56.65391247613089, 60.07493100847517, 57.40473134177071, 53.61549997329712, 47.97879818507603, 44.62681347983224, 44.68963214329311, 46.54930359976632, 48.828302315303254, 51.67741114752633, 51.414828300476074, 53.66874401909964, 52.63432053157261, 52.06942503792899, 51.80301373345511, 48.82630818230765, 43.47515998567854, 40.80084351130894, 36.65331786019461, 36.21689108439854, 35.60701642717634, 35.927561146872385, 35.76418120520455, 36.272685119083945, 36.936585494450156, 37.226099559238975, 37.65193033218384, 37.65902444294521, 37.778318064553396, 37.20789875302996, 35.85474402563912, 34.85078838893345, 34.904574394226074, 35.42693649019514, 34.496138436453684, 36.175066402980256, 34.10605614525931, 35.99822780064174, 33.633147852761404, 34.23068945748465, 34.15353666033064, 34.964224679129465, 35.78646060398647, 35.0766395841326, 42.35015630722046, 46.96819312231881, 37.703378268650596, 36.011957441057476, 35.56991304670061, 35.58791582924979, 34.50285734449114, 32.13648503167288, 33.856344836098806, 34.46502092906407, 33.1646203994751, 33.38923828942435, 33.69990961892264, 33.348966530391145, 32.728270053863525, 33.89197519847325, 34.558453355516704, 34.913374287741526, 36.24668148585728, 36.559485912323, 33.378690923963276, 34.63474805014474, 34.68993411745344, 32.767336300441194, 33.78458731515067, 32.687126295907156, 33.75592252186367, 34.42683015550886, 34.325202328818186, 36.5354277747018, 35.8357754434858, 34.18003361565726, 34.489930221012656, 35.924629007067, 36.39247553689139, 35.561946937016074, 35.25308561325073, 35.21704183306013, 34.23460824148995, 35.299666336604524, 45.66354724339077, 40.00748429979597, 35.27279765265328, 35.36081395830427, 34.77424355915615, 36.50772530691964, 35.33087764467512, 35.44286176136562, 35.74278770174299, 36.45698956080845, 36.10183238983154, 37.06027732576643, 39.92787878853934, 39.6394555909293, 41.763464314596995, 45.49171829223633, 45.36898531232561, 46.73500115530831, 45.24728413990566, 44.49805293764387, 40.49642556054251, 39.617308207920615, 38.73216676712036, 37.04702711105347, 37.23106404713222, 38.08581059319632, 41.16778482709612, 44.27822583062308, 47.56599528448922, 48.584184306008474, 49.723449162074495, 50.15510252543858, 48.06956250326974, 46.28976058959961, 45.61213057381766, 48.18815088272095, 51.58124460492815, 58.14932114737374, 53.716742174965994, 56.34552362986973, 48.15799570083618, 49.943738324301584, 54.06087950297764, 61.10556425367083, 52.31778839656285, 2.532134835209165, 0.11969900556973048, 0.9191460332700184, 0.9345132772411618, 0.04572568780609539, 1.555553363902228, 55.76099600110735, 61.98999350411551, 64.65015302385602, 57.3902200290135, 50.9897791998727, 32.78122227532523, 11.87473542349679, 29.53357172012329, 42.916302476610454, 58.63609109606062, 16.362833976745605, 0.368804111544575, 0.023230443642075573, 0.07571107987314463, 0.027677993024034158, 0.06776145858956234, 0.051080475827412944, 0.07199760020843574, 0.08752265106886625, 0.1291250376296895, 0.013083016899015223, 0.19438284449279308, 0.1695738128785576, 13.515393580709185, 73.55015618460519, 56.296879291534424, 45.86226919719151, 19.50472947529384, 23.481522253581456, 47.4431928225926, 52.06857735770089, 65.14115442548479, 57.46122019631522, 65.33926841190883, 15.901025431496755, 0.6337506217615945, 0.8822368766580309, 6.616343506744929, 6.874339239937918, 1.267394632101059, 5.540817950453077, 55.88438905988421, 61.06620270865304, 59.60433646610805, 54.40656280517578, 49.1738258089338, 46.648086139133994, 46.40152931213379, 49.680161884852815, 50.8469694001334, 52.733891691480366, 52.65442861829485, 54.00514800207955, 54.76030254364014, 52.79138803482056, 52.5212733404977, 49.96342257090977, 46.704418659210205, 42.68389565604073, 39.445232595716206, 37.79854774475098, 36.38109786169869, 38.490650858197895, 36.57706138065883, 38.72547565187727, 39.36509902136666, 38.35773529325213, 39.71415219988142, 39.37247453417097, 39.31831680025373, 38.21451554979597, 37.159341267177034, 37.72807216644287, 37.76352187565395, 37.01612499782017, 35.804161139896934, 37.31133311135428, 35.57718781062535, 36.39075238364083, 35.19673572267805, 34.4553872517177, 36.30200999123709, 37.596223149980815, 37.76487677437918, 35.953484875815256, 44.08651113510132, 47.661890847342356, 38.24460472379412, 36.977169922419954, 35.59063604899815, 37.23172412599836, 35.20117562157767, 33.2760660307748, 35.445943287440706, 36.56959554127285, 33.87395851952689, 35.046178681509836, 35.88632358823504, 34.76424857548305, 35.657039982931956, 36.49159506389073, 37.06934472492763, 37.609153747558594, 37.59589658464704, 38.85668543406895, 36.572875091007774, 36.55498000553676, 35.80764218739101, 34.74547454289028, 36.053208896092, 36.212875025612966, 36.71056406838553, 36.141451018197195, 35.407269614083425, 37.70307602201189, 37.69538089207241, 34.610710757119314, 34.02497066770281, 36.158112798418315, 36.8082765851702, 35.60048164640154, 35.05798714501517, 35.51799610682896, 34.260740416390554, 34.55926629475185, 44.32552569253104, 41.957478863852366, 36.25124297823225, 36.59158658981323, 35.80396659033639, 37.59703608921596, 36.99216760907854, 37.071505614689414, 37.43484776360648, 36.930412020002095, 36.967508452279226, 39.74023921149117, 43.06815883091518, 40.79829352242606, 43.78887115206037, 48.2595088822501, 46.532502855573384, 46.74409287316458, 47.361370835985454, 46.16127797535488, 43.280943938664024, 41.61096177782331, 40.32400948660714, 38.442916733878, 39.27520670209612, 40.26605108806065, 42.138312680380686, 45.46734748567854, 49.78126164845058, 50.812867641448975, 51.95555101122175, 52.27435868127005, 49.88151373182024, 49.22289398738316, 48.97312709263393, 50.488984312329976, 51.774272509983604, 60.67205919538225, 56.53468486240932, 59.55201653071812, 49.36977890559605, 52.16583824157715, 58.78653349195208, 60.11991364615304, 57.015764236450195, 3.491323011262076, 0.15696497660662445, 3.0292400121688843, 1.1053626409598758, 0.08171963638492993, 1.8851665684155055, 59.8713071005685, 66.87784276689801, 68.20512240273612, 66.02535438537598, 50.036274433135986, 20.1600627217974, 12.583220652171544, 29.15352610179356, 51.45655223301479, 68.27843979426792, 22.403934819357737, 0.2842678762972355, 0.07498770726046391, 0.014922842549692308, 0.03367328417620488, 0.07036022056958505, 0.0924030684732965, 0.2699943222105503, 0.2104588182909148, 0.2896367982029915, 0.18751840426453523, 0.3950770417494433, 0.3979805202356407, 18.08641106741769, 83.71077796391079, 63.05440889086042, 53.46039881025042, 24.800363302230835, 28.015609196254186, 54.33608375276838, 56.88766377312796, 69.87738704681396, 61.7126978465489, 70.7082804271153, 18.515109709330968, 0.9567447985921587, 7.687644124031067, 16.436886140278407, 27.803550175258092, 3.734207715306963, 6.131637607301984, 56.33587953022548, 60.76428958347866, 60.675060817173545, 56.45942892347063, 52.54570320674351, 48.48559284210205, 48.346945013318745, 52.4660108430045, 53.38070297241211, 55.37357486997332, 54.3136237008231, 57.06003815787179, 58.219838414873394, 54.76615292685372, 55.32150854383196, 53.10682930265154, 47.91051476342337, 45.32542358125959, 41.26937791279384, 40.0231351171221, 37.672858306339805, 40.8550637790135, 38.03557511738369, 41.69677203042166, 41.323427949632915, 40.91236557279314, 41.44152300698416, 41.30935089928763, 42.55513163975307, 41.4550963129316, 40.02419124330793, 38.757833412715364, 39.36441462380545, 40.386779512677876, 38.94686262948172, 40.664690085819785, 38.169001374925884, 39.56633274895804, 35.95865086146763, 36.284114905766074, 37.93392644609724, 39.36681522641863, 39.11646120888846, 38.006983280181885, 46.71506329945156, 48.379108224596294, 38.192114557538716, 35.86466605322701, 36.71578911372593, 36.999619552067344, 36.17076546805245, 33.673982415880474, 37.11412239074707, 37.69188942228045, 35.805397919246126, 37.20833648954119, 37.34317323139736, 36.28820044653756, 37.32597296578543, 39.21175575256348, 38.82258367538452, 39.17209196090698, 40.37317493983677, 42.35357482092721, 37.569656712668284, 39.52594287054879, 38.109465735299246, 37.10358544758388, 37.7814621244158, 38.154691559927805, 38.657960006168906, 38.76677574430193, 38.52272721699306, 39.03102963311331, 38.81374209267752, 34.9875602040972, 34.397918701171875, 37.35811185836792, 37.061600957598, 36.21665137154715, 36.168111256190706, 35.17292077200753, 33.42880480630057, 34.54493563515799, 46.66162122998919, 44.1303334236145, 38.76440988268171, 39.34498051234654, 37.46548237119402, 40.4096668788365, 38.55116271972656, 38.415728432791575, 39.680748735155376, 39.798485960279194, 39.71950578689575, 41.55725915091378, 44.19208901269095, 42.76879916872297, 47.02416433606829, 49.979212352207725, 47.870079721723286, 49.56286934443882, 49.33890111105782, 49.473842075892854, 45.365601539611816, 44.72351155962263, 42.42051724025181, 41.20060811723982, 41.63028471810477, 41.300370352608816, 45.575374603271484, 48.93180268151419, 53.06018257141113, 52.2104491506304, 54.30731473650251, 54.8485620362418, 51.37882968357631, 51.83686883108956, 51.57046447481428, 53.215353216443745, 55.876190185546875, 63.21722602844238, 58.80546038491385, 62.18313952854702, 53.69072117124285, 53.65416669845581, 59.4474252973284, 61.771972928728374, 60.05079296657017, 4.053613364696503, 0.1880460059536355, 4.967136459691184, 3.047337463923863, 0.186265638630305, 2.1918648311070035, 65.40608228955949, 71.10363292694092, 74.3873654774257, 69.61605834960938, 61.33912100110735, 43.9142826625279, 20.986267805099487, 44.93590062005179, 59.95472717285156, 79.00651400429862, 30.05332476752145, 0.464540815779141, 0.20434048159846238, 0.26420069166592186, 0.07509604216154132, 0.17451223145638192], [0.020145792913224016, 0.10472845352653946, 0.15491970921201365, 0.047327583456145864, 0.03618988235081945, 0.17631151633603231, 0.20633688090103014, 10.728467651775905, 61.98238522665841, 45.56666851043701, 35.96599858147757, 18.659376893724712, 23.814386129379272, 28.023801122392925, 47.873765741075786, 61.536415100097656, 52.25872870853969, 62.63106904711042, 12.963881186076573, 0.38464502724153654, 0.5848700989569936, 12.105291417666844, 10.822868483407156, 1.326209396123886, 5.616903764860971, 53.84473146711077, 57.54705476760864, 56.837160791669575, 53.69250338418143, 49.256342615400044, 42.80894238608224, 41.737662179129465, 42.884653432028635, 45.18316616330828, 47.66736255373274, 49.71912738255092, 50.980006558554514, 50.01344265256609, 46.69464601789202, 45.36020278930664, 42.252721718379426, 37.0935765675136, 36.5042199407305, 36.36442218508039, 35.55885846274239, 36.03280898502895, 37.26034723009382, 38.21216011047363, 39.78823389325823, 40.065216881888254, 41.18338353293282, 41.76726497922625, 43.43441227504185, 41.564690249306814, 38.06283984865461, 36.58520119530814, 34.59332289014544, 33.70106996808733, 35.030201298849924, 34.937547070639475, 35.35391787120274, 34.366429465157644, 33.64892373766218, 33.75299038205828, 33.85260323115757, 33.73246887751988, 34.334922858646934, 35.75797993796212, 35.3108286176409, 39.31205994742257, 46.45490537370954, 38.831571170261924, 34.96918569292341, 35.90823473249163, 34.092625277382986, 34.00716938291277, 34.97491448266165, 34.19515289579119, 36.03383731842041, 35.89598853247506, 32.70167929785592, 34.98066759109497, 32.931560448237825, 32.84376995904105, 32.75830364227295, 34.043949672154014, 33.8284478187561, 33.85460083825247, 33.18840060915266, 32.43834604535784, 35.094145570482524, 33.13504539217268, 33.02395759310041, 31.66967030933925, 32.96503339494978, 31.46551833833967, 34.53890112468174, 35.19258417401995, 35.91926152365548, 34.0776275907244, 35.61973857879639, 33.77913645335606, 34.49424505233765, 35.19943857192993, 34.881370885031565, 34.724751540592735, 34.19849845341274, 34.20510619027274, 35.153205258505686, 47.61749185834612, 36.80435085296631, 33.94848837171282, 36.18909134183611, 35.4620144707816, 35.661438192640034, 34.6541474206107, 38.935168811253135, 34.76575633457729, 36.993953296116416, 34.98227609906878, 36.551464217049734, 38.577652726854595, 42.44390140260969, 43.7540328843253, 43.931819915771484, 45.468021460941856, 44.983179637363975, 48.815507207598, 46.60654980795724, 45.9124664579119, 42.45061683654785, 39.530028411320274, 37.31575216565813, 38.23963328770229, 36.193923813956125, 36.90325845990862, 38.00900520597185, 40.242972646440776, 41.56257452283587, 41.6567816734314, 44.73009845188686, 41.02216795512608, 40.52288777487618, 43.0718309538705, 42.296377250126426, 47.23611913408552, 49.55653606142317, 52.546161787850515, 54.603478227342876, 58.7662239074707, 55.13034275599888, 49.76152529035296, 44.78409290313721, 45.692608083997456, 2.304669269493648, 0.12516873063785688, 1.5198803352458137, 0.8301917208092553, 0.1259276991976159, 1.8085166471345084, 53.509112630571636, 63.53960854666573, 59.77460207257952, 63.22262477874756, 58.01174681527274, 108.36204855782645, 31.58996752330235, 31.00962965829032, 45.941190310886924, 55.22373696735927, 14.311266303062439, 0.2994115294090339, 0.14659840001591615, 0.10350129580391304, 0.023951558429481726, 0.06017173227987119, 0.06447785121521779, 0.15258569802556718, 0.08447098731994629, 0.08144018852284976, 0.07733952320579972, 0.20606159924396447, 0.3191255229924406, 14.14270213672093, 73.01907757350376, 50.15907342093331, 44.72990042822701, 21.830774443490164, 28.5379695551736, 34.10340888159615, 51.90453038896833, 66.59068761553083, 53.957535471235005, 67.86921174185616, 14.338466763496399, 0.37311001334871563, 0.7382883323090417, 4.655944015298571, 8.380435109138489, 2.3772729507514407, 6.123271541936057, 54.58798027038574, 57.61607122421265, 58.61776869637625, 54.67299495424543, 51.222863469805034, 46.306728090558735, 43.85567808151245, 44.79433454786028, 46.23682573863438, 50.101049014500205, 50.33228506360735, 52.82220676967076, 50.45198515483311, 49.503788811819895, 47.87315082550049, 43.94561903817313, 39.22981759480068, 37.91454097202846, 37.81517825807844, 36.86302144186837, 38.621224880218506, 38.44235045569283, 40.19025318963187, 40.84795924595424, 41.527903011866975, 44.14498717444283, 43.92375653130667, 44.29352923801967, 42.541200501578196, 40.808788776397705, 38.23625993728638, 37.938654695238384, 36.643031052180696, 37.10099376950945, 35.582461493355886, 35.781798362731934, 36.818702357155935, 36.31688608442034, 34.75327736990792, 35.763535022735596, 35.52946410860334, 36.2559677532741, 35.819367272513254, 37.74181570325579, 41.52306011744908, 48.657692773001536, 38.27045897075108, 35.40582438877651, 35.88365200587681, 36.24917241505214, 32.910535199301584, 35.459662505558555, 34.54653719493321, 37.36275672912598, 36.115117345537456, 35.25966555731637, 36.91709579740252, 34.75141872678484, 35.70724419185093, 34.12469468797956, 35.09703254699707, 34.42463452475411, 36.0072465624128, 35.62475865227835, 34.897758211408345, 37.313261236463276, 35.81789425441197, 34.82327699661255, 34.24354362487793, 35.35447025299072, 34.11707946232387, 35.59391559873308, 35.60721097673689, 37.282105513981406, 35.205605098179404, 36.2487416267395, 33.86456455503191, 36.03051607949393, 35.21818481172834, 35.549207414899556, 34.43739489146641, 33.49382952281407, 34.45390033721924, 36.40447507585798, 48.95576701845442, 39.12815155301775, 35.329449789864675, 37.54198898587908, 38.06895078931536, 36.11398131506783, 36.29966150011335, 39.966934612819124, 37.356690951756065, 38.90734822409493, 35.58035618918282, 37.93222066334316, 41.00190005983625, 44.47820193426949, 45.44884443283081, 44.4246313231332, 48.60016516276768, 47.090088844299316, 49.85596520560128, 48.68013892854963, 46.23886156082153, 43.852415902274, 41.020621980939595, 40.154956340789795, 40.01999453135899, 37.39611503056118, 39.250033378601074, 38.90188694000244, 42.87027413504464, 44.512248107365195, 43.77659715924944, 46.03652654375349, 43.9190491267613, 42.20457417624337, 45.14569452830723, 44.67835521697998, 47.662609985896516, 50.62863615580967, 54.09998743874686, 57.419388566698345, 60.07140827178955, 57.035118443625315, 54.00529044015067, 45.42136083330427, 49.973132678440635, 2.186193581138338, 0.23038584472877638, 4.096134168761117, 1.2802001621041978, 0.16669398812311037, 1.6495611880506789, 59.3151524407523, 67.45474474770683, 65.28050054822648, 69.05979946681431, 59.63220569065639, 71.01550197601318, 23.6158378805433, 37.40223639351981, 52.99540451594761, 65.01929691859654, 20.66948206084115, 0.2914090231060982, 0.1054697869611638, 0.047354341484606266, 0.061983895754175525, 0.041375735508544106, 0.19968408931578907, 0.2831210164087159, 0.23573739613805497, 0.35333755718810217, 0.10547545951391969, 0.7219894868986947, 0.41489596398813383, 20.10359123774937, 82.80270399366105, 56.13982221058437, 51.12269476481846, 31.399302005767822, 34.1021443094526, 40.92742926733834, 58.66512066977364, 70.18983364105225, 60.39550004686628, 72.05210372379848, 16.273285593305314, 0.8137248158454895, 2.9712523009095873, 31.400045463017054, 23.152109895433696, 3.0678661337920596, 7.094422127519335, 58.77711173466274, 60.406915937151226, 62.10611179896763, 57.72787121364048, 53.23062188284737, 47.29886136736189, 46.00043760027204, 45.9749550819397, 48.263326917375835, 51.9093211718968, 53.162564277648926, 55.12832430430821, 53.29769284384591, 51.25326878683907, 50.74896158490862, 46.38131005423409, 40.61765078135899, 41.450701577322825, 39.28599725450788, 39.422994886125835, 40.54520886284964, 40.57745892660958, 40.83571999413626, 43.975218364170615, 45.63467747824532, 46.255860328674316, 45.74558809825352, 47.234406403132844, 46.65820966448103, 42.73424230303083, 40.845301559993196, 39.971718447549, 37.038484300885884, 39.47416489464896, 38.14604452678135, 37.074458599090576, 40.56275306429182, 37.437703473227366, 35.644835472106934, 36.90456124714443, 37.57086917332241, 37.39690017700195, 37.9258839062282, 39.5481493132455, 41.725940568106516, 50.9431984765189, 38.62711695262364, 36.121589592524934, 37.187057631356375, 36.30371229989188, 33.53544923237392, 35.594440187726704, 35.790983881269185, 39.26901238305228, 39.50092935562134, 36.49911648886544, 39.44429458890642, 36.820960521698, 36.84728724615914, 36.984854630061555, 38.13583762305123, 36.97533907209124, 37.28608683177403, 38.61658695765904, 36.71579953602382, 40.05072641372681, 36.77416787828718, 37.70190872464861, 35.72693886075701, 37.29666199002947, 36.80929102216448, 38.519187109810964, 38.2779769216265, 40.36214814867292, 37.38401474271502, 37.49329253605434, 34.580767495291575, 36.575758593423025, 34.880683013371055, 35.751528535570415, 34.4639196395874, 34.09504325049264, 33.44389629364014, 37.58752400534493, 50.85276072365897, 41.021282059805735, 36.5487995828901, 39.88723182678223, 38.90900189535958, 40.084150723048616, 38.35104765210833, 43.523359639304026, 38.288156032562256, 41.487370695386616, 37.54804086685181, 39.998475960322786, 42.01487445831299, 47.581489767347065, 47.4278164591108, 46.620800563267295, 49.32490743909563, 48.12160103661673, 53.46419947487967, 52.74227816717965, 49.66963883808681, 45.59498241969517, 44.023772375924246, 41.243686948503765, 43.64301109313965, 39.563233852386475, 40.62945924486433, 41.34648207255772, 45.365393093654085, 45.16215133666992, 46.219945090157644, 49.02991819381714, 46.17667865753174, 45.22120755059378, 48.752483572278706, 48.046932220458984, 52.46346432822091, 53.1847950390407, 58.89723914010184, 59.35136645180838, 63.86235237121582, 58.89348016466413, 57.788046087537495, 50.1373290334429, 54.03642879213606, 3.236747745956693, 0.2970918081700802, 5.122985422611237, 2.0895552124295915, 0.19419451031301702, 2.115871297461646, 64.22350583757672, 73.91710444859096, 70.56214591435024, 75.60999134608677, 72.65652751922607, 117.0086648123605, 44.26625061035156, 47.63197190420968, 62.50707844325474, 75.55803966522217, 28.09898063114711, 0.5025970765522548, 0.22056836581655911, 0.28209865412541796, 0.13167571861829075, 0.17499913461506367], [0.052125653850712945, 0.04986775732998337, 0.10502655431628227, 0.07495546327637774, 0.09456700485731874, 0.13061854748853616, 0.1900219406400408, 14.843294211796351, 59.417450768607004, 47.94072553089687, 33.973849296569824, 20.817636762346538, 17.769024303981237, 24.458173206874303, 51.45534324645996, 62.33486039297921, 53.09983941486904, 62.97150298527309, 14.447392804282051, 0.4171061968164784, 0.22057867954884255, 2.176128246954509, 1.3518963434866496, 0.7958214251058442, 3.8513361045292447, 58.15017924989973, 55.93914086478097, 55.35046516145979, 52.879668372017996, 47.428198610033306, 42.35029179709298, 39.614212785448345, 39.227326665605815, 37.8042939049857, 37.397476877485005, 38.07908126286098, 39.972399371010916, 38.24906199319022, 39.32461534227644, 38.11108813967024, 36.090454714638845, 36.91986118044172, 36.64939907618931, 34.406510148729595, 36.9636105128697, 40.80355330875942, 42.10359948022025, 44.806368827819824, 44.54441826684134, 44.099358354296, 46.91569600786482, 47.076769147600444, 45.28547838756016, 43.77158055986677, 39.93210676738194, 37.0592976297651, 35.75811890193394, 34.74901465007237, 36.470284938812256, 35.7025055204119, 33.49131774902344, 33.81421095984322, 33.413907868521555, 33.476549352918354, 33.83833163125174, 32.89827510288784, 33.74366937364851, 33.767359256744385, 34.530799525124685, 38.579188278743196, 46.22137294496809, 45.26958090918404, 35.41134820665632, 35.06459140777588, 36.597555092402864, 34.7197071484157, 34.44741766793387, 32.69488743373326, 33.68238973617554, 34.31669078554426, 33.19236108234951, 32.712379523685996, 33.97604145322527, 32.28140708378383, 32.72549424852644, 32.75807435171944, 34.13805954796927, 33.48207664489746, 33.84271594456264, 33.48946952819824, 34.160092285701204, 32.50633069447109, 33.49450349807739, 34.23513977868216, 31.779028006962367, 31.334155695778982, 33.627412114824565, 33.89885738917759, 35.42225340434483, 34.659240450177876, 35.16970028196062, 34.68091882978167, 35.84416886738369, 33.65079975128174, 32.92581081390381, 33.25814662660871, 35.424831186022075, 32.50845684323992, 37.65503965105329, 46.90611444200788, 38.03286531993321, 35.57340451649257, 35.59247037342617, 34.06481858662197, 34.04437003816877, 33.53841611317226, 33.98522349766323, 36.371394702366416, 36.04867172241211, 36.220392976488384, 35.847674233572825, 36.54672901970999, 40.77066053662981, 44.149586881910054, 45.73487050192696, 45.640878745487754, 47.8051939691816, 49.23993444442749, 48.84339032854353, 46.95532505852835, 44.997107301439556, 42.560176031930105, 39.88295521054949, 39.179158278873985, 38.112415245601106, 37.965103013174875, 38.52006605693272, 37.68302352087838, 38.787241663251606, 39.48181138719831, 38.66755894252232, 39.940430709293906, 40.02956567491804, 40.933290072849815, 41.075075013296946, 49.78852946417672, 53.942555155072895, 55.882217747824534, 55.53870923178536, 59.04262324741909, 56.15489285332816, 48.124880586351665, 39.78577075685774, 37.58280965260097, 1.4485919262681688, 0.57244644846235, 3.63344298516001, 0.7086468285747937, 0.12443752773106098, 1.9991728280271803, 51.63517999649048, 65.45990998404366, 59.52087470463344, 65.78250789642334, 45.37857730048043, 54.866804531642366, 27.999159336090088, 20.302985429763794, 46.04654584612165, 59.44285338265555, 13.34262922831944, 0.41695469351751463, 0.15370784566870757, 0.03144699381664395, 0.05618478264659643, 0.03849898112405624, 0.05088125794593777, 0.014729553367942572, 0.01746075350924262, 0.12031241479728903, 0.10272890582148518, 0.10378534413341965, 0.2740066083414214, 19.79561059815543, 67.35018130711147, 53.681664194379536, 41.61356040409633, 30.884867804391043, 16.50885558128357, 27.07777782848903, 57.045853410448345, 65.3051666532244, 57.60352972575596, 66.19188186100551, 16.659970215388707, 0.5827935646687235, 0.2691855898925236, 2.678811307464327, 4.380917378834315, 1.2438906133174896, 5.212575060980661, 60.01388413565499, 57.222785813467844, 57.45176369803292, 55.63801288604736, 48.647461550576345, 44.9343581199646, 43.149748052869526, 40.091602666037424, 39.058516706739155, 40.961426803043906, 40.71160084860665, 41.21229498726981, 40.54757125037057, 39.904432092394146, 37.829793793814524, 38.530679430280415, 37.066318784441265, 37.80722257069179, 37.797911984579905, 39.70500489643642, 41.43129873275757, 43.777517795562744, 46.37066541399275, 46.69171040398734, 46.10057156426566, 48.52477720805577, 47.12805380140032, 47.18091222218105, 45.59361015047346, 42.03599350793021, 38.11911678314209, 37.272381510053364, 35.892736775534495, 37.363020760672434, 37.592683042798726, 36.19625840868269, 35.17879547391619, 35.07392978668213, 35.09389196123396, 34.43713780811855, 34.775997979300364, 35.65491036006382, 35.39509984425136, 34.45971597943987, 39.94125059672764, 49.10115112577166, 46.62234653745379, 36.06984635761806, 34.81372322354998, 35.92625141143799, 33.454217842647004, 35.46773978642055, 34.84603929519653, 35.06705454417637, 36.08844321114676, 36.27727093015398, 34.51453726632254, 35.39576687131609, 34.2685467175075, 34.91853332519531, 34.21226283482143, 36.2215324810573, 35.748801367623464, 37.34629644666399, 36.352203777858186, 36.879176003592356, 34.30767202377319, 35.84088584354946, 35.80458150591169, 34.44071613039289, 33.033778871808735, 35.28259113856724, 35.958011627197266, 37.308953353336875, 35.017062255314414, 35.947961057935444, 34.794254371098106, 36.092546122414724, 33.44491767883301, 32.77722358703613, 33.927216461726594, 35.27904755728585, 32.70468091964722, 38.99777208055769, 48.25262321744646, 38.634249278477256, 37.928614548274446, 36.125817571367534, 37.011858803885325, 36.788182394845144, 37.385324478149414, 35.310679231371196, 38.151328631809776, 36.601484298706055, 36.25629084450858, 37.89269583565848, 39.11787516730172, 41.66920852661133, 44.897230420793804, 46.96980857849121, 46.68662084851946, 48.99645219530378, 50.22271197182791, 50.96453292029244, 47.66960334777832, 46.508277961185996, 44.60485369818551, 39.89299188341413, 40.86783456802368, 39.815189429691856, 40.02013349533081, 40.66281407220023, 40.64018031529018, 40.27481624058315, 42.24108001164028, 39.50388928822109, 41.945611340659006, 43.0118019921439, 44.08884572982788, 43.648521014622276, 51.228053774152485, 56.51620612825666, 58.328014918736045, 56.81167827333723, 61.29686205727713, 57.17143515178135, 52.43791580200195, 41.15299211229597, 41.13644845145089, 1.3603605521576745, 0.6872623903410775, 5.470973355429513, 1.3040842690638133, 0.17936412324862822, 2.1445901564189365, 56.93947301592146, 71.97060135432652, 65.93184552873883, 71.53737422398159, 55.68045595714024, 80.95132868630546, 34.501585824149, 23.036583934511455, 54.049897875104634, 68.1657052721296, 19.426228727613175, 0.4963728476847921, 0.138432326061385, 0.09377520198800735, 0.0942982914192336, 0.06845449390155928, 0.1896559659923826, 0.26841607689857483, 0.23035072375621113, 0.2558274609701974, 0.19376043789088726, 0.29489772447517937, 0.506964562194688, 25.371317625045776, 79.09001050676618, 61.84180927276611, 47.31918832233974, 31.06280074800764, 25.527540922164917, 35.45235994883946, 63.31284713745117, 70.45198917388916, 61.75353935786656, 74.03688444410051, 18.75711372920445, 0.641612128487655, 0.7315536822591509, 6.130805126258305, 7.498969265392848, 2.0335212477615903, 6.212291862283434, 64.19994449615479, 58.11534445626395, 59.86666570390974, 58.08568607057844, 52.06000328063965, 46.16911901746477, 45.61088337217058, 41.876904078892295, 42.420152459825786, 40.8692033631461, 41.09422772271292, 43.75512375150408, 41.83214030947004, 41.95050287246704, 39.55635513578142, 39.94899436405727, 41.74932473046439, 40.18685899462019, 38.18007680347988, 42.063668182918, 44.36952863420759, 45.31783962249756, 49.49550308500017, 49.46376371383667, 47.76002720424107, 51.17798852920532, 50.140632901872905, 48.19932011195591, 47.842064585004536, 43.664866651807515, 40.28986603873116, 39.89392989022391, 38.47810588564192, 40.57722616195679, 40.709926332746235, 36.69548995154244, 36.214605127062114, 37.944869858878, 36.23663091659546, 36.16475180217198, 37.02944122041975, 38.33757509504046, 36.66704402651106, 36.796245779309956, 41.33347157069615, 51.97953271865845, 46.85388135910034, 34.76940761293684, 35.3741579736982, 36.35942990439278, 33.85861342293875, 35.73223686218262, 35.14260230745588, 36.32551227297102, 38.77238988876343, 36.85884557451521, 35.60605410167149, 37.39720242364066, 36.65760489872524, 36.34346294403076, 36.858793463025776, 38.15218326023647, 38.257583958762034, 39.51605905805315, 38.72043820789882, 39.88818372998919, 36.80200236184256, 38.40955148424421, 40.123088427952354, 36.02087892804827, 34.188041414533345, 36.14735003880092, 37.183448042188374, 37.06300449371338, 35.79564612252371, 37.08589880807059, 34.69181707927159, 36.930557932172505, 33.57570014681135, 34.386488914489746, 33.52749701908657, 36.14042615890503, 33.28586646488735, 39.4973475592477, 50.32267223085676, 41.73918036052159, 39.19568804332188, 39.04014914376395, 37.925150871276855, 38.61068793705532, 38.026448658534456, 35.71141658510481, 41.03663410459246, 38.589092935834614, 39.58857045854841, 40.4111260005406, 40.89798627580915, 46.275916303907124, 48.16223062787737, 48.95377288545881, 49.27255276271275, 51.55735322407314, 53.500667095184326, 54.224832671029226, 50.16441658564976, 48.89442832129342, 44.88564429964338, 42.03998524802071, 42.634052753448486, 42.10219941820417, 42.60912261690412, 43.04217256818499, 41.299220425742014, 41.21498394012451, 43.158662591661724, 42.23279081072126, 43.60856192452567, 45.180994851248606, 46.22078234808785, 45.72386802945818, 53.168994835444856, 58.450178146362305, 61.75180230821882, 60.702186584472656, 64.42508697509766, 61.916551045009065, 58.95396423339844, 45.36245747974941, 49.85028852735247, 1.810362262385232, 0.802786722779274, 10.389902779034205, 3.8387702873774936, 0.2413369928087507, 2.5510754074369157, 61.00227233341762, 77.60206767490932, 71.8980552128383, 77.56873021806989, 59.525995526994976, 68.47446237291608, 40.092811652592246, 35.125336033957346, 64.32101685660226, 81.23126465933663, 27.383390869413102, 0.5973849988409451, 0.27065792945878847, 0.2053666708192655, 0.18080668869827474, 0.11830340831407479], [0.09349954713668142, 0.058997174591890404, 0.03232515723045383, 0.04820125496813229, 0.017282773773851137, 0.10780232572661978, 0.14148512296378613, 24.20729981149946, 62.28029618944441, 43.71551554543631, 28.725539650235856, 13.702111652919225, 62.40338352748326, 41.4619402885437, 47.88769340515137, 63.79245349339077, 52.752422537122456, 60.97130421229771, 24.94116680962699, 0.016739743894764354, 0.15606088297707693, 0.6321312029446874, 6.08024308511189, 2.0719882122107913, 6.000238486698695, 49.41302101952689, 55.40675599234444, 54.27555104664394, 52.81867013658796, 49.10696676799229, 45.4817476272583, 45.83684573854719, 46.880371366228374, 43.797226360866, 42.95245395387922, 37.86292627879551, 35.41777181625366, 36.21043620790754, 36.43677725110735, 36.97228881290981, 37.06316777638027, 37.790588583265034, 40.084185464041575, 42.636957100459504, 42.812843799591064, 44.6301520892552, 49.13134799684797, 45.60478285380772, 47.37808125359671, 44.955796786717, 46.75916351590838, 47.28091764450073, 46.80883618763515, 43.07134805406843, 40.46848685400826, 35.20481995173863, 36.15188026428223, 35.52947800500052, 34.956685883658274, 35.7848972593035, 33.82770088740757, 34.69431843076433, 33.61521455219814, 32.136617047446116, 33.9798629624503, 34.051832403455464, 31.972111497606548, 34.45176724025181, 33.71949659075056, 35.49412209647042, 45.01619052886963, 45.96182993480137, 39.58683688299996, 34.1169821875436, 34.105444703783306, 32.63478899002075, 35.35763168334961, 33.98218713487898, 32.665892601013184, 33.69508409500122, 35.850477831704275, 33.631647041865754, 31.28596646445138, 32.1665220941816, 33.6275371823992, 33.92276266642979, 34.987195423671174, 34.559071745191304, 34.55958243778774, 34.06318228585379, 34.29617622920445, 30.963510990142822, 34.03747395106724, 32.34688343320574, 34.25853088923863, 32.67216682434082, 36.5405763898577, 34.257235050201416, 33.23859092167446, 33.81247043609619, 36.48868376868111, 34.33006954193115, 35.06327472414289, 35.103991167885916, 34.94332797186715, 33.706809180123464, 34.22478001458304, 33.369720799582346, 43.11153643471854, 46.345057828085764, 34.023789473942344, 35.556520393916536, 34.014583110809326, 35.279662472861155, 35.55299765723092, 35.73742021833147, 36.082804747990195, 35.44708626610892, 34.10284260341099, 35.52226230076381, 34.98504148210798, 35.97422524860927, 36.6387231690543, 38.32227863584246, 41.971086910792756, 44.51584380013602, 45.22467122759138, 48.20995085580008, 47.99321222305298, 47.99898617608206, 46.69940900802612, 46.33365930829729, 42.50807843889509, 42.801198618752615, 40.64406783240182, 42.03159529822213, 41.85035501207624, 42.022684233529226, 41.01608828135899, 41.67644507544381, 42.87422071184431, 39.74429695946829, 40.08272634233747, 41.48887498038155, 44.54133326666695, 53.57228912625994, 54.8867632320949, 57.43562650680542, 53.552424226488384, 52.14121729987008, 43.490188939230784, 47.21628202710833, 47.465562547956196, 35.30551324571882, 0.45005564019083977, 0.2786973480667387, 3.131428905895778, 0.7613901698163578, 0.08519319285239492, 1.9643339088984897, 58.694768633161274, 61.538589886256624, 58.434433528355186, 62.3955112184797, 52.07719659805298, 16.712531600679668, 11.26587780884334, 35.14367927823748, 47.30013288770403, 62.12425354548863, 13.221793975148882, 0.36959550050752504, 0.06734284319515739, 0.18765105786068098, 0.022601127857342362, 0.03291993388640029, 0.06080179275678737, 0.030942085731242384, 0.025944963696279695, 0.04897390279386725, 0.06834839138069324, 0.08782609871455602, 0.2647618129849434, 27.569479261125835, 70.27913188934326, 49.372724941798616, 37.01839705875942, 16.727643932615006, 30.913042749677384, 38.44307654244559, 52.380721705300466, 68.25004250662667, 57.25255537033081, 64.67117132459367, 26.853875602994645, 0.07263677341065236, 0.3048104154212134, 1.5463277846574783, 2.9355687413896834, 1.5234488866158893, 6.330700891358512, 54.42049394335066, 55.984811374119346, 57.074907302856445, 54.81008291244507, 52.31879588535854, 46.737690108163015, 46.84658922467913, 48.32263674054827, 45.59323842184884, 42.89622218268258, 40.64746897561209, 37.36275325502668, 36.79967818941389, 38.62425429480416, 38.64068678447178, 38.18608699526106, 39.24895988191877, 38.932809897831504, 44.20431784221104, 44.94612489427839, 47.13582188742501, 50.51258386884417, 48.5953118460519, 49.84363215310233, 48.547998087746755, 49.481637954711914, 50.55030563899449, 48.19312926701137, 45.59991911479405, 42.02450466156006, 37.13343143463135, 38.39856290817261, 38.472873892102925, 37.61608804975237, 36.39800977706909, 35.62282010487148, 36.01858949661255, 34.94765669958932, 34.28990200587681, 35.01509244101388, 36.18542616707938, 33.37245144162859, 36.90776784079415, 35.36918306350708, 37.77407966341291, 47.905960219247, 47.696138518197195, 39.17790412902832, 34.43352127075195, 35.277630124773296, 32.14233194078718, 35.1424320765904, 34.001263414110454, 32.96836505617414, 36.08746004104614, 36.98157160622733, 35.144686767033164, 33.24511528015137, 33.43629843848092, 35.369752815791536, 35.4474093573434, 36.02236931664603, 34.767604555402485, 37.89758389336722, 34.90025608880179, 35.6154202733721, 33.35367740903582, 35.626589502607075, 33.22198125294277, 35.61122703552246, 36.017592430114746, 38.45053890773228, 34.246058872767854, 36.10732841491699, 33.907855306352886, 36.102030413491384, 35.51438651766096, 35.511645453316824, 34.44767822538103, 35.01575599397932, 33.973679065704346, 34.62203632082258, 34.08092451095581, 43.79510021209717, 48.29583059038435, 35.567436013902935, 37.0350102015904, 36.38121945517403, 37.05769606998989, 36.59269830158779, 36.96263081686837, 36.896247727530344, 36.34612757819039, 37.19996738433838, 36.54100717817034, 36.245107718876426, 38.127273968287874, 38.2771292413984, 41.47444357190813, 42.47328186035156, 45.567408493586946, 47.123804977961946, 49.26004253114973, 49.77730464935303, 49.4013341494969, 49.89101539339338, 49.26494795935494, 45.65847853251866, 44.40454408100673, 43.03160088402884, 43.54139368874686, 42.87256704057966, 43.71695729664394, 43.419949599674766, 42.74608898162842, 44.93209648132324, 41.076454230717246, 42.15244879041399, 43.90501723970686, 46.53946147646223, 56.17478207179478, 57.60243191037859, 59.7214344569615, 54.91787379128592, 54.402671813964844, 47.19518729618618, 49.767518111637656, 47.11163868222918, 36.65403699874878, 0.5577091021197182, 0.8331675039870399, 10.837736759866987, 1.7712405387844359, 0.2586399071982929, 2.443141004868916, 61.2776711327689, 68.2860689163208, 64.60803304399762, 69.87342657361711, 55.28432525907244, 21.24302806173052, 15.59460118838719, 40.99593850544521, 55.03837292534964, 70.86574745178223, 17.561750854764664, 0.47539607329027994, 0.12827377473669394, 0.07813893245267016, 0.05038118102986898, 0.08334422563867909, 0.12133244292012282, 0.1853393026228462, 0.12301267204540116, 0.2545645444520882, 0.17556423214929445, 0.2833905305181231, 0.4166961445340088, 34.00588744027274, 79.5125652040754, 55.6825647354126, 41.87152964728219, 21.519434349877493, 74.97161865234375, 53.17990698133196, 59.06214073726109, 74.89208957127163, 61.15217971801758, 70.36420563289097, 31.209758622305735, 0.1251292670411723, 0.9678928575345448, 3.7566143529755727, 12.855724658284869, 3.642969182559422, 8.432301674570356, 57.67635726928711, 60.07833562578474, 58.993492535182405, 58.20708499635969, 53.72602844238281, 48.22018902642386, 51.273772920881, 51.56486422674996, 46.83906085150582, 48.12712138039725, 41.652595383780344, 39.37416989462716, 38.72700078146798, 40.22597387858799, 39.40425559452602, 39.90025969914028, 41.82179791586739, 42.747836453574045, 46.6853597504752, 47.008357184273855, 50.50726849692208, 54.2338410105024, 51.42106430871146, 52.6887457711356, 50.45736653464181, 52.19586835588728, 51.91001599175589, 50.88208906991141, 46.1222951071603, 43.51848895209176, 39.72983775820051, 40.94947590146746, 40.47363199506487, 41.12713786533901, 38.30844477244786, 37.91883495875767, 37.3559752873012, 36.63921301705496, 35.79822390420096, 37.48838015965053, 37.941708428519114, 36.9015839440482, 36.975182737622944, 36.93536261149815, 39.48064061573574, 49.827005113874165, 51.90437058040074, 39.63403947012765, 35.03182717732021, 35.401651995522634, 31.97907359259469, 35.78023154394967, 35.01467554909842, 34.62108094351632, 36.250183377947124, 39.89183153424944, 35.97733804157802, 35.280923570905415, 36.229071276528494, 38.12966067450387, 37.378338064466206, 39.6494471005031, 38.85502481460571, 39.65303931917463, 37.64253636768886, 39.01298516137259, 33.93953561782837, 38.60830470493862, 34.87599297932216, 37.996178831372944, 37.6076876776559, 39.88853113991873, 35.84579821995327, 35.16530902045113, 34.9555915423802, 37.46820259094238, 34.31209455217634, 35.49519559315273, 35.52392986842564, 35.70676129204886, 34.55013288770403, 35.178868430001394, 35.018187863486155, 47.0197730745588, 50.54932246889387, 37.40220512662615, 37.91404070172991, 37.77827984946114, 38.392524923597065, 39.20476586478097, 37.64769540514265, 39.25652299608503, 38.2928078515189, 38.6047055380685, 39.76388393129621, 39.17243242263794, 40.01550946916853, 39.58276176452637, 41.60821376528059, 46.22019175120762, 48.34524965286255, 49.65346343176705, 51.69491365977696, 52.03481606074742, 51.578520911080496, 52.644287722451345, 50.58829491479056, 47.32716832842146, 47.51231697627476, 45.041593142918174, 46.49246038709368, 44.33997099740164, 45.592029435294016, 45.47787400654384, 45.15510586329869, 47.4820054599217, 43.17327117919922, 45.796004227229524, 45.98185464314052, 49.98618139539446, 58.323206765311106, 58.698430333818706, 61.67086969103132, 57.243505341666086, 57.6128055708749, 49.44800519943237, 52.92352540152413, 50.573234694344656, 43.13206141335623, 0.6958188797746385, 1.0249629723174232, 13.282637613160269, 3.7491619757243564, 0.3549957067838737, 2.736135248626981, 68.5384830747332, 71.77619770595005, 72.34437274932861, 75.37696960994175, 64.0169984272548, 25.625178745814733, 22.35360380581447, 52.153640678950715, 65.23777607509068, 82.65465177808488, 24.440602949687413, 0.594753911452634, 0.2937066512448447, 0.3632508995277541, 0.15183249701346668, 0.19344683257596834], [0.06192018131592444, 0.08495415853602545, 0.026102317663441812, 0.009714946333718086, 0.0658739912988884, 0.07539395296147891, 0.07979689884398665, 22.505875314985, 62.8587406703404, 40.46898365020752, 25.768219573157175, 48.30813237598964, 98.70921502794538, 55.74350391115461, 49.218235220227925, 57.70702314376831, 56.48691947119576, 58.81281852722168, 32.722774028778076, 0.045899955954934867, 0.09620719363114663, 1.9150876828602381, 2.2093037239142825, 0.6094419147287096, 6.069478154182434, 44.64052922385079, 48.58863810130528, 57.52189881461007, 53.00913068226406, 50.50612204415457, 51.62806851523263, 52.19629567010062, 52.3715500831604, 52.794122150966096, 48.46657909665789, 39.962991510118755, 36.2133127621242, 36.219399384089876, 36.56814684186663, 38.2607592855181, 41.50703757149832, 43.57443584714617, 44.110732555389404, 47.244946820395334, 47.4884603364127, 48.06301382609776, 47.746672766549246, 45.36541393824986, 45.119176728384836, 49.84462227140154, 47.43461527143206, 47.32556676864624, 46.05506781169346, 38.80106163024902, 36.12901026862008, 36.35617814745222, 39.87000724247524, 37.049142837524414, 36.125723770686555, 35.21128872462681, 35.33467830930437, 33.040303230285645, 35.370447635650635, 33.21825354439871, 34.628779547555105, 33.62860025678362, 33.52192803791591, 33.40916224888393, 33.037190437316895, 33.538916383470806, 45.74074867793492, 46.645129680633545, 45.64037847518921, 34.66371161597115, 34.15213312421526, 34.54473066329956, 32.98931734902518, 33.37980610983712, 31.891227517809185, 33.1630813734872, 34.43661321912493, 34.8738112449646, 32.397105012621196, 33.59808029447283, 33.84261172158377, 33.263309138161794, 33.577058519635884, 34.62543051583426, 34.48917286736624, 34.891240801130024, 32.65248605183193, 32.001273087092805, 32.45945814677647, 34.781768458230154, 32.96311569213867, 34.88623462404524, 34.14252723966326, 34.08475991657802, 33.45006281988961, 34.691268171582905, 34.47222968510219, 35.03331756591797, 34.5962724004473, 33.11267219270979, 33.8426707812718, 35.42734643391201, 34.56750338418143, 39.048997674669536, 46.40948499952044, 40.652478626796174, 34.54359463282994, 35.12052093233381, 34.74548496518816, 35.76635251726423, 34.094209466661724, 34.47784382956368, 34.9652738571167, 34.98224483217512, 35.168536458696636, 34.03423956462315, 34.72913237980434, 35.34125477927071, 37.20040512084961, 36.14831236430577, 37.127476828438894, 38.1489315032959, 40.058098452431814, 46.82084962299892, 46.50938967296055, 48.28783321380615, 48.02342299052647, 47.61152335575649, 45.68008395603725, 43.99198089327131, 45.895915848868235, 46.45457533427647, 45.82815701620919, 45.60600226266043, 44.940639291490825, 45.92445904867989, 45.61393015725272, 44.08208165849958, 43.466676235198975, 41.6988981791905, 47.318538665771484, 52.14651182719639, 56.60324968610491, 56.35416371481759, 54.15669863564627, 52.8287068094526, 54.10111652101789, 51.630767890385215, 41.105396951947895, 33.41991458620344, 0.2670495616538184, 0.8295961299112865, 5.7442073566573, 0.6932863156710352, 0.1937551453177418, 2.3275444763047353, 57.84363515036446, 59.92994294847761, 59.65154947553362, 58.1629569871085, 51.84122882570539, 54.244186878204346, 19.517535005296978, 22.744620629719325, 47.47218418121338, 62.540603501456125, 10.198877692222595, 0.30777604771511896, 0.14121179548757418, 0.06560843304863997, 0.08863813549812351, 0.07176505947219473, 0.08981877964522157, 0.03310552339202591, 0.04372988222166896, 0.039149363724780936, 0.0735921710729599, 0.15566095443708555, 0.09787227785480873, 28.027259588241577, 71.25494384765625, 44.92483908789498, 29.90262876238142, 37.59566381999424, 88.1452225276402, 54.531838825770784, 55.84263733455113, 64.12361158643449, 61.05488409314837, 63.83757509504046, 35.08492531095232, 0.10235953171338354, 0.0658129502886108, 1.0198220653193337, 1.2671232180935996, 0.9282564244100026, 7.178957385676248, 47.86086988449097, 50.34138372966221, 60.45223903656006, 54.30293042319161, 51.673791136060444, 52.27710321971348, 54.08749805177961, 54.985528400966096, 54.67626060758318, 50.24227115086147, 41.63270616531372, 37.39575719833374, 38.70784459795271, 38.57118395396641, 40.25888402121407, 41.900124958583284, 46.84481743403843, 46.719287804194856, 49.07566860743931, 50.835369382585796, 49.9199789592198, 49.34981673104422, 47.890392780303955, 47.95637287412371, 50.983650888715474, 49.71533714021955, 49.97756562914167, 47.27247558321272, 41.31646932874407, 37.56360483169556, 38.82259062358311, 40.259453773498535, 38.7737169946943, 37.64761897495815, 38.58214821134295, 36.60333251953125, 34.7243971824646, 36.123906816755024, 35.22990642275129, 35.81590012141636, 35.94026245389666, 35.09932892663138, 34.28486456189837, 33.6057893208095, 35.72060557774135, 47.30449983051845, 48.76804058892386, 45.76828786305019, 34.85601690837315, 35.06814888545445, 33.479644775390625, 33.18263360432216, 33.14525229590279, 33.76230444226946, 33.3643012046814, 33.87208945410592, 36.282867704119, 34.75280836650303, 35.19284125736782, 35.87339299065726, 36.50144066129412, 36.38110133579799, 36.043342454092844, 36.105049405779155, 37.31927490234375, 34.97491795676095, 33.829066208430696, 34.63348695210048, 36.51818929399763, 34.441258089882986, 36.857615743364605, 35.75637490408761, 36.02887283052717, 34.33074351719448, 35.14002799987793, 35.93522848401751, 34.816283634730745, 35.14370707103184, 33.949290888650076, 33.94042498724801, 35.073634488242014, 33.9086925642831, 37.479858194078716, 48.19162498201643, 41.94229357583182, 35.9818891116551, 34.79962532860892, 36.76337385177612, 37.94822236469814, 36.39766584123884, 35.797011443546836, 36.54872662680489, 36.79057604925973, 36.6645496232169, 36.88913972037179, 36.524908202035085, 37.48819950648716, 36.96889809199742, 38.286901882716585, 39.78030252456665, 39.40984542029244, 43.21172251020159, 47.07158579145159, 49.60847731998989, 49.58944272994995, 50.769580364227295, 50.25760929925101, 48.23125403267996, 46.84274687085833, 46.86846910204206, 47.15499196733747, 47.562726157052175, 46.67186287471226, 47.263331753867014, 48.01228155408587, 47.834883621760774, 45.59959602355957, 46.3412641116551, 43.32253932952881, 49.70895174571446, 53.79398877280099, 58.91078117915562, 58.64743055616106, 56.865158557891846, 54.54114941188267, 57.49155603136335, 52.54292392730713, 46.65986680984497, 35.547414779663086, 0.3089746119720595, 0.7249717840126583, 9.424714616366796, 2.7399901960577284, 0.6031078174710274, 3.266180749450411, 61.88800089699881, 66.29619516645158, 63.36251286097935, 65.91428743089948, 57.230974265507285, 53.543745926448274, 20.00423894609724, 29.116214275360107, 53.883769920894075, 73.44482149396623, 14.58127416883196, 0.29389297696096556, 0.09568390742476497, 0.03343249923948731, 0.05968254245817661, 0.07651838048228196, 0.21701662854424544, 0.18545017524489335, 0.17135712504386902, 0.22302954803620065, 0.21202299078660353, 0.25930655428341454, 0.2515156694820949, 33.3456244468689, 82.2362312589373, 53.95621183940342, 36.13724388395037, 60.741339683532715, 101.52373572758266, 61.67630318232945, 61.14498833247593, 65.6232829775129, 66.87626552581787, 69.03393132346017, 39.03020279748099, 0.1576711144298315, 0.2431846708059311, 4.52042852129255, 8.183023759296962, 1.3307552550520216, 8.234667113849095, 52.9632100377764, 52.88199601854597, 60.88190868922642, 58.31221471514021, 54.853512627737864, 54.81694425855364, 55.94702359608242, 56.89410127912249, 56.17786359786987, 52.79627261843, 44.34310116086687, 39.28054986681257, 40.91136850629534, 39.58954668045044, 42.46067435400826, 45.11768633978707, 48.53806216376168, 47.617693356105256, 51.93427562713623, 53.0355338369097, 51.269496304648264, 51.390207358769004, 49.331539494650706, 48.781311648232595, 53.60912847518921, 50.909767218998496, 52.0900160244533, 50.33411591393607, 41.41458484104702, 39.672334466661724, 40.716940539223806, 44.73526791163853, 40.22283329282488, 39.7472152028765, 40.56817960739136, 39.84079354149954, 36.32225009373256, 38.507312638419016, 36.05003009523664, 38.3485358783177, 37.65177052361624, 36.20011465890067, 35.94082178388323, 36.426361901419504, 37.893859658922466, 50.00927025931222, 51.272814069475444, 48.43777881349836, 33.91236468723842, 35.58824586868286, 34.089161600385395, 32.565084661756245, 34.04105574744088, 34.239534514290945, 34.620049136025564, 36.86606822695051, 37.79312120165144, 36.48585932595389, 36.360420022692, 38.72959245954241, 38.77065978731428, 39.6698192187718, 39.14347580501011, 39.26157086236136, 39.193092891148154, 37.28094516481672, 35.92192268371582, 35.93728862489973, 41.11964075905936, 37.20614780698504, 37.99844741821289, 37.65852069854736, 37.260736329214915, 34.861561570848735, 35.43448223386492, 36.11450590406145, 34.54261841092791, 34.23125573566982, 32.195708002362935, 34.36658927372524, 34.56799670628139, 35.19598879132952, 39.077923025403706, 50.880654266902376, 44.5598224231175, 37.34334693636213, 37.17992877960205, 38.7791748046875, 40.64048603602818, 37.970487867082866, 38.11584070750645, 38.081561769757954, 38.97174760273525, 38.17830153873989, 37.94186476298741, 37.419318539755686, 38.27347796303885, 39.73808526992798, 39.45381709507534, 42.52876670019967, 41.57365689958845, 45.790456090654644, 49.92217458997454, 52.46951273509434, 53.39532893044608, 52.822265829358784, 53.246960571834016, 50.7352180480957, 49.24652133669172, 49.43058953966413, 49.88942425591605, 49.50872203281948, 49.11846603666033, 48.85044622421265, 51.578965595790315, 48.78631782531738, 47.19561808449881, 48.44576229367937, 46.00810146331787, 53.34722655160086, 56.45080620901925, 60.7774772644043, 61.79873044150216, 58.64633274078369, 56.37686000551496, 57.85842439106533, 54.976353304726736, 49.985361507960725, 40.495956557137625, 0.4072801683630262, 1.4656951342310225, 11.876517636435372, 3.0967712913240706, 0.6319747599107879, 3.7115939344678606, 68.86918258666992, 70.9904398236956, 72.95696762629917, 71.23554447719029, 66.21561690739223, 69.81032303401402, 30.618689264569962, 39.40118449074881, 62.804753167288645, 85.64357226235526, 20.03083665030343, 0.5240238010883331, 0.3748335465788841, 0.1672984678298235, 0.19453058870775358, 0.15956654772162437], [0.1032092339758362, 0.0993778384955866, 0.07456138370824711, 0.04836502618023327, 0.07397967563675982, 0.028649926584746157, 0.13959043606051377, 11.208542142595563, 62.38746520451137, 43.5865604536874, 33.207167693546836, 40.36503512518746, 88.52363531930106, 56.15533406393868, 43.54586138044085, 58.85265254974365, 55.97946473530361, 60.592147963387625, 36.24579906463623, 0.0229311180966241, 0.21736216571714195, 0.8200196123548916, 1.641110441514424, 0.7406830180968557, 6.3293412157467435, 34.90303884233747, 37.97582408360073, 56.02599334716797, 51.674055167606895, 56.24084554399763, 50.23999908992222, 52.39288452693394, 50.35686084202358, 52.148710932050435, 48.6049142565046, 41.10495574133736, 38.31792906352452, 37.6989209992545, 40.32321391786848, 43.27823066711426, 45.105419295174734, 47.34853056498936, 47.81712055206299, 47.92334461212158, 46.898620809827534, 45.783605166843955, 45.0375770841326, 46.71789469037737, 46.89090483529227, 47.194162436894004, 45.77448913029262, 44.58027791976929, 39.1762296131679, 35.428697858537944, 37.03153610229492, 39.77478218078613, 38.98076636450631, 39.651052134377615, 35.37032604217529, 35.84285913194929, 33.16395337241036, 36.27161162240164, 33.717693533216206, 34.4046619279044, 34.09481395993914, 32.24449825286865, 33.54411016191755, 34.05734232493809, 35.56005702699934, 41.18756634848458, 47.8350955418178, 47.08874784197126, 45.59482261112758, 34.81246907370431, 33.18431159428188, 36.108641624450684, 33.559316294533865, 34.45842708860125, 32.81666503633772, 32.99067572184971, 33.45508636747088, 33.97060101372855, 35.274149077279226, 34.054764543260845, 32.878257342747276, 33.08275324957711, 34.543243748801096, 34.70276396615164, 32.84224830354963, 34.162531103406636, 33.627686568668906, 33.31934288569859, 33.00422818320138, 33.9451254435948, 34.329419885362896, 34.11535630907331, 33.732149260384695, 31.92800780705043, 32.47105121612549, 34.19626808166504, 35.47762359891619, 32.00255502973284, 33.94103642872402, 34.24502011707851, 35.30953277860369, 34.85430070332119, 35.6662289755685, 40.490040166037424, 44.987261704036165, 39.38379314967564, 34.35932493209839, 34.59663370677403, 34.8123231615339, 34.241730145045686, 34.93073088782174, 34.77868693215506, 35.31069312776838, 36.60170316696167, 34.83249378204346, 33.32045807157244, 35.88128614425659, 35.13884680611746, 35.51305941173008, 36.817674023764475, 37.75645555768694, 36.16114221300398, 35.28641612189156, 40.07384654453823, 46.34605142048427, 48.61792475836617, 47.19397136143276, 48.62664474759783, 45.38049152919224, 46.69571256637573, 47.17457546506609, 48.11195346287319, 48.63193580082485, 48.71007524217878, 51.466752188546316, 50.29855850764683, 50.20759269169399, 45.57182059969221, 45.12153216770717, 41.493141174316406, 45.12964071546282, 49.82884986060006, 54.76992579868862, 53.462875843048096, 57.20724964141846, 59.44407626560756, 60.28575325012207, 54.38466903141567, 54.897658007485525, 34.24469355174473, 0.1235128744904484, 1.6116367259195872, 10.732343878064837, 1.2036166829722268, 0.5428555362990924, 2.659447112253734, 52.27160372052874, 61.8653358731951, 60.64325196402413, 56.81341879708426, 48.99457270758492, 27.585937806538173, 11.765626123973302, 32.72836038044521, 45.95992612838745, 58.302591460091726, 8.017967564719063, 0.34402678108641077, 0.08251605329236814, 0.10763045959174633, 0.061485674631382735, 0.06689021284026758, 0.06487864149468285, 0.05581719647826893, 0.05897899663874081, 0.11690041502671582, 0.08373504145337002, 0.23970446469528334, 0.16148336843720504, 16.18552984510149, 70.50405202593122, 49.3987945829119, 34.15459973471505, 44.2357862336295, 93.02069010053361, 62.885685784476145, 50.48175818579537, 63.40840571267264, 60.928468567984446, 64.86421312604631, 39.23079381670271, 0.033788940470133505, 0.1523298496114356, 0.7418187228696687, 2.0941581768648962, 1.0203199471746172, 7.250140377453395, 38.18172352654593, 39.92163930620466, 58.13952418736049, 54.12168318884713, 58.27608060836792, 52.64211641039167, 53.402700969151084, 50.90170383453369, 52.980024678366526, 49.63908413478306, 41.050384589603965, 40.24953869410923, 38.45511082240513, 42.03378050667899, 44.9953806740897, 47.184441907065256, 48.743812220437185, 49.193888732365195, 49.8158324105399, 50.06842027391706, 46.188810212271555, 46.610235827309744, 48.77217129298619, 48.839322158268516, 49.94781344277518, 47.23089408874512, 45.69585289273943, 40.228541237967356, 38.222992352076936, 38.18995714187622, 40.99848502022879, 42.24237585067749, 41.490876061575754, 38.10432406834194, 37.47937529427664, 35.12591273444039, 36.46867643083845, 34.91251618521554, 36.223446709769114, 35.20694957460676, 34.12038680485317, 34.9761130469186, 36.60248136520386, 37.75477409362793, 43.76310723168509, 47.839069911411826, 49.1315529687064, 46.50860800061907, 35.90277344839913, 33.16360943658011, 35.65322542190552, 34.34599481310163, 33.954102516174316, 33.41184425354004, 33.46323660441807, 35.238647256578716, 34.422459738595144, 36.25131246021816, 36.277729511260986, 34.78716026033674, 34.34399720600673, 35.95509338378906, 36.030651569366455, 36.552700996398926, 38.0561591557094, 35.44773244857788, 35.694615840911865, 34.0747058732169, 35.44089194706508, 35.91772249766758, 35.39374147142683, 34.28328732081822, 33.729130268096924, 32.77538578850882, 34.547718388693674, 33.674190861838206, 32.661793163844514, 33.723755836486816, 34.43650552204677, 34.64572967801775, 34.32753692354475, 35.240009103502544, 42.86198146002633, 46.25309494563511, 41.78515659059797, 37.83112437384469, 35.95539910452706, 36.03749901907784, 35.78023154394967, 36.9963504246303, 34.975275788988384, 35.584174224308555, 38.14976528712681, 36.30875669206892, 35.552316733769004, 38.177346161433626, 37.83556774684361, 38.39376517704555, 38.535619599478586, 40.4677677154541, 37.26283121109009, 36.925204345158164, 42.209389277866904, 49.10686601911272, 49.69030972889492, 48.36801889964512, 49.84005730492728, 48.68913337162563, 48.92113024847848, 49.674794401441304, 50.058293274470735, 51.35365636008126, 51.48465422221592, 53.795076165880474, 51.9781882422311, 52.60630886895316, 48.651894501277376, 46.34100355420794, 43.40089416503906, 47.400972093854634, 51.614905153002056, 57.23160655157906, 57.32057128633772, 59.083402224949424, 62.07121794564383, 61.43543692997524, 56.04913084847586, 56.04617091587612, 38.21237897872925, 0.05233670538291335, 0.8734028392604419, 8.686998316219874, 2.456013628414699, 0.5137452440602439, 2.893787920475006, 59.065482820783345, 66.0410851069859, 65.97236047472272, 61.801120621817454, 54.90703112738473, 34.90146854945591, 10.340187549591064, 39.0484869820731, 53.73562043053763, 69.97118077959333, 11.23384313923972, 0.33776973826544626, 0.07459804495530468, 0.0744424636608788, 0.11483335308730602, 0.016960817389190197, 0.21071763868842805, 0.17106283083558083, 0.34951257386377876, 0.14997776225209236, 0.136951138398477, 0.3248352051845619, 0.22773700686437742, 20.56151921408517, 83.23629937853131, 55.3693607875279, 46.73041187013899, 52.92961549758911, 90.23836735316685, 64.27997384752545, 55.61891228812081, 68.1477163859776, 64.90682642800468, 69.40552793230329, 44.97594656263079, 0.1306703332811594, 0.42378053867391174, 2.5091890607561385, 5.337704735142844, 1.2780352554150989, 9.701248577662877, 46.21285445349557, 42.63899987084525, 61.752156666346956, 56.08375024795532, 59.96752575465611, 53.04331929343087, 56.54724373136248, 54.50156552450997, 55.97929450443813, 52.17661837169102, 43.19182981763567, 43.728202956063406, 41.409470966884065, 44.997854232788086, 46.47091402326311, 50.205271993364605, 52.213898931230815, 52.10968637466431, 52.75590705871582, 50.58893067496163, 48.692694323403494, 49.99499865940639, 51.1970648084368, 49.46398605619158, 51.91504996163504, 49.926353931427, 48.06526156834194, 42.69155951908657, 39.18507466997419, 41.98428501401629, 43.77815008163452, 44.040698187691824, 44.19301659720284, 40.095007283346995, 39.78732367924282, 37.338813236781526, 39.58756991795131, 37.15704836164202, 37.77016087940761, 38.357134274074006, 35.420544147491455, 36.618625504629954, 38.977712631225586, 38.47402729306902, 46.20516627175467, 51.271195139203755, 52.72014815466744, 49.57990632738386, 34.73683793204171, 33.09451307569231, 36.27378988265991, 35.13190902982439, 34.8333796773638, 34.095779759543284, 34.50600487845284, 35.22284010478428, 36.261422089168, 39.27434859957014, 37.87366819381714, 38.28559562138149, 35.46563795634678, 39.68367740086147, 39.182410035814556, 38.028765882764546, 39.28530938284737, 38.48743731634957, 37.95543459483555, 37.201207637786865, 36.787803718021934, 39.302874428885325, 38.24178375516619, 36.32780517850603, 34.20682239532471, 33.6318485396249, 35.389579500470845, 35.280339922223774, 31.938489164624894, 33.12066609518868, 34.435880184173584, 35.11118255342756, 35.52923134395054, 36.43287236349923, 45.242441245487754, 49.61005456107003, 42.93791484832764, 38.06711646488735, 38.06632089614868, 38.369790417807444, 36.62610871451241, 39.38724987847464, 36.3445850781032, 36.654471261160715, 40.544347286224365, 37.96637453351702, 37.148425647190635, 39.30160985674177, 39.34838512965611, 39.87919623511178, 39.27332026617867, 43.28904206412179, 40.02047743116106, 37.19748340334211, 44.11988680703299, 50.95546899523054, 52.18652650288173, 49.57193674360003, 53.65946817398071, 49.851136207580566, 52.87032651901245, 52.30012607574463, 51.661982672555105, 53.22318383625576, 54.91208246776036, 57.48599399839129, 53.33999695096697, 54.486553941454204, 51.15066473824637, 49.86076293672834, 46.514614718300955, 50.6771901675633, 54.842148848942344, 59.61602333613804, 57.168951170785085, 61.09320340837751, 63.662237303597585, 66.54708766937256, 58.38596984318325, 57.47856289999825, 38.3157890183585, 0.5198446224842752, 2.9762738943099976, 19.05960008076259, 6.297202323164258, 0.8122687339782715, 3.5560159512928555, 64.4139907019479, 73.14182444981166, 71.84140654972622, 67.65981388092041, 64.16128471919468, 37.53065994807652, 22.572270563670568, 52.916163785117014, 60.69950457981655, 82.07439381735665, 16.379688569477626, 0.5207325805510793, 0.21149122289248876, 0.22632528761667864, 0.13529099390975066, 0.12908094642417772], [0.008119327132590115, 0.0413693097819175, 0.05195738055876323, 0.02765921287105552, 0.09057322916175638, 0.12679359130561352, 0.09661118659589972, 11.152181829724993, 63.64862578255789, 47.60571118763515, 42.65787812641689, 35.617619378226145, 51.068870544433594, 34.7805038860866, 51.11211265836443, 57.42640972137451, 59.212666511535645, 57.077366965157644, 41.36342872892107, 0.1295248440333775, 0.0854970340483955, 0.2603592877941472, 0.2330541701189109, 0.5716324235711778, 3.0548838589872633, 38.56214434759957, 39.50398308890206, 55.82031624657767, 53.600352900368826, 50.152423994881765, 53.324075153895784, 55.950966698782786, 52.24239696775164, 50.95994016102382, 45.85654388155256, 38.92803648539952, 37.65130499431065, 40.9438339642116, 43.238344533102854, 44.35650423594883, 44.838945456913535, 49.45313991819109, 47.09229837145124, 46.447172028677805, 44.50957999910627, 45.90880823135376, 46.34606531688145, 47.919804504939485, 46.40214770180838, 43.46717650549752, 38.958580766405376, 36.9945821080889, 35.526146343776155, 36.08217246191842, 36.83213322503226, 39.06918913977486, 38.48278897149222, 37.435017994471956, 35.40931585856846, 33.97689955575125, 32.73865761075701, 33.29526390348162, 34.050098827907014, 32.493344511304585, 33.774151120867046, 33.88878944941929, 32.47953496660505, 35.58208629063198, 36.8532383782523, 40.25991235460554, 46.82798889705113, 46.8557573727199, 45.90736648014614, 38.754783153533936, 35.1462779045105, 33.70261594227382, 33.94196401323591, 33.64824628829956, 34.26713623319353, 34.53921031951904, 32.036611625126426, 33.79165015901838, 33.85200221197945, 35.660649572099956, 34.32820395060948, 31.94930750983102, 33.63014970506941, 34.01396472113473, 33.51955870219639, 33.826345988682334, 32.303745542253765, 33.944718973977224, 32.50909260341099, 35.11534105028425, 33.99933181490217, 31.617503234318324, 31.521197727748326, 35.165302072252544, 35.46657248905727, 34.38155916758946, 35.24070044926235, 34.4488594191415, 34.25846488135201, 33.169025557381765, 33.979842117854524, 32.007165159497944, 38.517929485866, 42.86589329583304, 45.967253003801616, 38.820158754076274, 34.76418604169573, 33.27127872194563, 33.728487559727256, 32.52378109523228, 33.15748807362148, 33.99601752417428, 35.214224338531494, 35.73832695824759, 34.73912736347744, 34.35173055103847, 35.60116604396275, 33.21333769389561, 35.93968227931431, 34.282359736306326, 35.58009215763637, 34.20058986118862, 37.65623474121094, 34.70964963095528, 38.0476267678397, 45.32659087862287, 47.44307122911726, 48.44962549209595, 48.91817726407732, 47.72574479239327, 50.433971949986045, 52.99609586170742, 50.24523455756051, 51.30487305777413, 51.16046864645821, 48.991345269339426, 50.930330412728445, 50.22277797971453, 48.61762945992606, 45.91831684112549, 45.414829526628765, 47.71377304622105, 52.81057895932879, 53.09519454411098, 54.85646561213902, 53.65604618617466, 56.286324977874756, 55.080635343279155, 69.58096299852643, 36.269735608782085, 0.05488538130053452, 0.45553622181926456, 8.280131782804217, 4.424701886517661, 0.603735055242266, 3.614334353378841, 55.98840011869158, 59.920007024492534, 60.91413443429129, 63.427165848868235, 51.788054261888774, 40.037413665226524, 21.476961748940603, 34.06620822634016, 50.40800653185163, 49.70240306854248, 5.501327429498945, 0.1871000195720366, 0.060752673606787405, 0.07490257825702429, 0.04289805257160749, 0.06585904995777778, 0.018845195649191737, 0.050883900839835405, 0.021282893771837865, 0.034000317699142864, 0.06679234094917774, 0.15155203134885856, 0.04127153967108045, 13.623570953096662, 73.02631759643555, 51.225951944078716, 48.040414810180664, 35.97390563147408, 65.28385652814592, 45.395777566092356, 54.09676347460066, 62.00925391060965, 63.57015977587019, 60.520921979631694, 45.464189529418945, 0.12178852701825754, 0.11183918161051613, 0.6785914184791701, 1.5763713611023766, 0.4733601968203272, 4.374443394797189, 43.267801421029226, 39.2636900629316, 56.997594697134836, 53.31397247314453, 54.645660740988596, 53.548488071986604, 57.819747243608745, 53.24960783549717, 52.63766608919416, 46.59385544913155, 41.41009630475725, 39.52457754952567, 42.550684792654856, 45.09825570242745, 47.904935359954834, 48.50468649183001, 49.72111109324864, 49.438916955675396, 48.30068390710013, 47.50740459987095, 48.18436064038958, 48.63883536202567, 51.09260559082031, 49.72665228162493, 46.118998186928884, 41.273922034672324, 39.927962166922434, 37.75655630656651, 36.82568529673985, 38.36980431420462, 39.821279525756836, 40.24096114294869, 40.21024315697806, 38.1641515323094, 37.328755719321116, 36.045006547655376, 35.30618722098214, 35.91074650628226, 33.967613288334434, 33.83048364094326, 35.238536085401265, 34.40597513743809, 37.34445169993809, 37.77965211868286, 42.679302896772114, 48.82621438162667, 46.89851311274937, 48.06021022796631, 38.53386170523507, 34.90719386509487, 33.89580018179757, 32.89544371196202, 34.252697876521516, 33.793230874197825, 35.0244516645159, 35.26442507335118, 34.64082424981253, 33.80032498495919, 37.18387883050101, 35.37560667310442, 34.63069030216762, 35.81978069032942, 36.93326078142439, 35.99755729947771, 37.53478022984096, 35.34577805655343, 33.520420278821675, 35.47619921820504, 37.3666546685355, 35.17918109893799, 33.960790157318115, 32.68464231491089, 35.54588965007237, 36.46746744428362, 34.11009304864066, 35.961405822208945, 35.68226889201573, 33.86212921142578, 32.90705762590681, 34.27435193743025, 32.19333866664341, 38.69614383152553, 44.92734391348702, 46.53936767578125, 42.43198871612549, 36.51856797082083, 35.9391542162214, 35.21855306625366, 33.717811652592246, 34.71493721008301, 35.07289103099278, 36.27265732628958, 37.26712172372, 37.19714641571045, 35.146437713078086, 36.817809513636995, 37.10284546443394, 37.823790550231934, 36.342007296425955, 37.53031948634556, 36.884963853018625, 38.24550798961094, 36.06769241605486, 40.820194244384766, 46.0997690473284, 50.029996735709055, 51.518432889665874, 50.1688460622515, 49.79942076546805, 52.58231673921858, 54.60042449406215, 53.03090633664812, 51.876859188079834, 54.59524808611189, 51.65683058329991, 55.6020107950483, 53.62233700071062, 51.62619597571236, 47.82819945471627, 47.49411269596645, 50.4138742855617, 55.61149161202567, 55.97330168315342, 57.28244652066912, 57.008638858795166, 58.24835729598999, 58.44227804456438, 68.42291368756975, 40.158670152936665, 0.03885546985215374, 0.25188468396663666, 7.578959533146449, 2.0691620324339186, 0.48875800200871056, 4.210255290780749, 60.31666578565325, 65.76928547450474, 66.5750263759068, 67.99435574667794, 55.98172984804426, 39.37774474280221, 26.016765322004044, 42.407802036830354, 57.26806027548653, 60.8964512688773, 7.70227529321398, 0.23027380502649716, 0.11198342458478042, 0.12209109935377326, 0.02129380631127528, 0.0662818451278976, 0.1283588901694332, 0.13077712112239429, 0.11422096166227545, 0.09567663352936506, 0.1747544684580394, 0.28776699996420313, 0.2449269044612135, 17.048584699630737, 82.53672695159912, 59.81408173697335, 57.51894235610962, 49.23067944390433, 60.745925494602744, 44.30810308456421, 62.99243790762765, 65.83921909332275, 69.69325978415353, 65.10953317369733, 50.4528363091605, 0.28685898440224783, 0.44155289073075565, 2.540073586361749, 2.6185569635459354, 0.8499305216329438, 5.854608586856297, 48.697874205453054, 43.99288763318743, 58.98906653267996, 56.198576177869526, 56.6002584866115, 57.070540360042024, 61.151318141392295, 55.290331976754324, 55.36616461617606, 50.278068270002095, 43.12806967326573, 42.74944148744856, 45.43966933659145, 46.99947738647461, 49.79679782049996, 49.67042398452759, 52.04638133730207, 51.98039429528372, 50.53312621797834, 47.36043282917568, 49.25679077420916, 49.3259322983878, 52.20096138545445, 50.85700259889875, 46.83058057512556, 43.71247918265206, 41.194792475019185, 40.15828105381557, 39.31727457046509, 41.188181264059885, 41.70211519513811, 42.51960897445679, 42.63551882335118, 40.1208997453962, 38.2789739881243, 37.4829466683524, 37.19398845945086, 38.47206442696707, 35.72453825814383, 37.09190552575247, 37.171125411987305, 34.98650755201067, 39.32495927810669, 38.69803721564156, 44.955244404929026, 51.37059259414673, 48.44415031160627, 51.04043504170009, 39.14828743253435, 36.56705597468785, 32.8949225970677, 33.62636988503592, 33.93829536437988, 33.845126969473704, 36.36248363767351, 35.74821424484253, 35.54748773574829, 35.7856685093471, 37.97656059265137, 38.961127281188965, 36.199986117226736, 39.13077449798584, 39.387031010219026, 37.9938303402492, 40.4246506690979, 36.074008328574045, 37.681477546691895, 37.32248844419207, 38.56494099753243, 37.29728732790266, 35.118620600019185, 33.3321657861982, 36.675051825387136, 37.48710516520909, 34.14002241407122, 36.24354090009417, 34.43372971670968, 34.517611844199045, 32.44772263935634, 35.105995723179404, 33.176675524030415, 40.178948470524375, 47.380846636635916, 49.03459433146885, 44.178612981523784, 37.83932672228132, 36.50726672581264, 37.47285788399832, 35.69003002984183, 37.26802846363613, 37.34109572001866, 39.32038041523525, 38.9461921283177, 39.66109575544085, 37.70462547029768, 38.887139388493125, 38.01022114072527, 40.42246893474034, 38.34526675088065, 39.681589467184885, 38.939681666237966, 40.48138271059309, 37.16986083984375, 42.472580092293875, 49.44118206841605, 51.15898520605904, 51.39897945949009, 52.44003847667149, 50.34626831327166, 56.56046267918178, 57.10600743974958, 53.878913130079, 57.04823316846575, 57.84549726758684, 53.40317344665527, 57.78919948850359, 55.25734887804304, 54.9235018321446, 51.553264209202354, 49.56468629837036, 53.2886323928833, 58.49661990574428, 56.59270926884243, 60.183232579912456, 60.33373056139265, 62.43014798845564, 60.240763664245605, 71.82025623321533, 41.932659898485454, 0.1602946293673345, 0.5920307061501912, 19.70477158682687, 11.210668291364398, 0.9009518495627812, 5.2741230726242065, 66.40844331468854, 71.32256371634347, 73.75359943934849, 72.87853636060441, 66.27361352103097, 56.848854609898154, 36.119644096919465, 52.770633765629356, 65.64421789986747, 75.46625396183559, 11.219211970056806, 0.5609914202775274, 0.2285888668681894, 0.23510407869304928, 0.19608480030936853, 0.2190537399479321], [0.042685783069048605, 0.04256563826597162, 0.05136833752372435, 0.07788588638816561, 0.06544763381992068, 0.05308347049036196, 0.08517888254885163, 5.819078539099012, 59.398843492780415, 48.890405314309255, 40.816772256578716, 22.255948611668178, 15.994166033608572, 32.88701554707119, 52.756511551993235, 55.39212308611189, 58.13781493050711, 55.5361453465053, 47.498986857278005, 0.3980186539036887, 0.07802939654460975, 0.4859663460935865, 1.5199558969054903, 0.7361815082175391, 2.46024095586368, 36.54290403638567, 44.63761098044259, 51.00489500590733, 42.734346526009695, 49.542882851191926, 53.99459021432059, 53.5446457181658, 49.91390970775059, 48.36069549833025, 39.740131514413015, 37.92048168182373, 40.23000035967146, 44.115405218941824, 46.506408895765034, 49.12113414491926, 46.470351219177246, 46.45174394335066, 45.66030590874808, 48.09010137830462, 46.69690070833479, 47.70166233607701, 46.8595232963562, 43.53466783251081, 38.36683395930699, 37.44795554024832, 36.45778512954712, 37.84020219530378, 35.85050562449864, 38.50445345469883, 38.271869455065044, 40.51648153577532, 38.293857029506135, 36.821144648960654, 35.98486294065203, 34.27140242712838, 35.479388441358296, 35.42134319032942, 34.33869573048183, 33.76099123273577, 33.083771160670686, 35.68016011374337, 34.264488969530376, 32.59445817129952, 33.294746262686594, 32.88028621673584, 38.314395904541016, 46.02919966833932, 47.35509661265782, 42.10977642876761, 34.00559909003121, 35.09770999635969, 35.59868901116507, 34.85077101843697, 33.78523349761963, 35.61690371377127, 34.22690616335188, 33.518481731414795, 33.2364057132176, 34.03426735741751, 34.49392543520246, 34.80231775556292, 33.17124203273228, 35.52555227279663, 35.2460366657802, 35.804609298706055, 34.20246934890747, 35.032188483646934, 34.94525957107544, 33.66007907049996, 31.00377232687814, 31.900329657963344, 32.13608203615461, 34.2397255897522, 35.32473543712071, 35.37350484303066, 34.23593187332153, 33.47338097436087, 34.03340230669294, 34.85456126076834, 33.89058903285435, 34.59736326762608, 39.21743243081229, 45.754509585244314, 42.30447537558419, 34.15180308478219, 34.23145375932966, 33.36693457194737, 33.34297023500715, 33.25286946977888, 32.854907921382356, 33.07207039424351, 33.12202794211251, 34.4786011832101, 34.15326220648629, 35.39695501327515, 35.690912451062886, 34.932210854121614, 35.68277958461216, 34.910431725638254, 36.28696714128767, 36.96578182492937, 36.583467619759695, 37.03174802235195, 34.67039925711495, 38.49092878614153, 47.9297126361302, 48.856112480163574, 49.08248826435634, 49.59439679554531, 48.994826316833496, 48.135858740125386, 49.21280867712838, 50.6067111151559, 50.243216105869834, 50.83063071114676, 51.00934880120413, 49.204418727329795, 47.10144567489624, 45.80559968948364, 44.32382685797555, 42.82076127188546, 44.51366206577846, 47.27409103938511, 52.21277679715838, 51.842927660260884, 55.46490546635219, 57.03060906273978, 64.62502833775112, 37.39559391566685, 0.08520497900566884, 0.19030212131994112, 4.49178283555167, 0.38966045954397743, 0.5378723751221384, 5.426603027752467, 60.395673751831055, 56.77321304593767, 64.63637474605015, 60.937438692365376, 56.405563013894216, 30.46395288194929, 15.133268594741821, 42.76311206817627, 48.53807258605957, 52.58854232515608, 2.4119705174650465, 0.23693530900137766, 0.04047154009874378, 0.049499814930771074, 0.06792818142899446, 0.01135789420056556, 0.09610145751919065, 0.04131012795759099, 0.0277571186888963, 0.1017518900334835, 0.033732991865170855, 0.16192523044134888, 0.10355404511626277, 7.70534987109048, 68.50061539241246, 57.26521151406424, 47.35800443376814, 32.817408493586946, 27.87157825061253, 34.710115160260884, 59.2190796988351, 60.432700702122276, 63.47644942147391, 59.22506209782192, 52.72876392092024, 0.4037371841924531, 0.05214414053729602, 0.8945215631808553, 2.4317548615591864, 0.6438083563532148, 2.3548637075083594, 41.99951893942696, 44.21335050037929, 50.8580448286874, 43.678439957754954, 51.360548973083496, 54.44567768914359, 55.5332236289978, 52.7099620955331, 50.84382881437029, 41.706040927342, 39.555354595184326, 40.81365598951067, 45.22039461135864, 47.960065841674805, 49.6541165624346, 49.13981785093035, 46.92824445452009, 48.52672617776053, 50.08985199247088, 47.732206617082866, 49.52305269241333, 49.23143679755074, 45.611689363207134, 41.27166039603097, 38.52407169342041, 37.27490370614188, 39.291750362941194, 38.15662663323538, 39.205175808497835, 39.81790270124163, 42.17164666312081, 39.96331112725394, 37.53986978530884, 37.06699275970459, 35.51446294784546, 35.52736922672817, 37.20298637662615, 35.94305910382952, 34.826890059879844, 34.494620255061555, 36.818035330091206, 34.486303261348176, 35.51293087005615, 34.59890924181257, 35.21147632598877, 39.49190017155239, 47.4434985433306, 49.9227408681597, 42.88703319004604, 33.50279269899641, 34.416296686444966, 34.833570752825054, 34.3354891368321, 34.25541114807129, 36.634463923318044, 33.735185623168945, 35.56991652079991, 35.09096676962716, 34.8226203918457, 36.060441970825195, 36.88984843662807, 35.92949274608067, 38.008098466055735, 36.37874242237636, 36.75068644114903, 35.61477061680385, 35.13191597802298, 36.779257433755056, 35.391789027622764, 33.6812676021031, 32.85583550589425, 33.852217606135774, 34.804965019226074, 34.622098854609895, 35.64569704873221, 34.32032469340733, 34.13224737984793, 33.562634059361045, 34.284072467258994, 34.242098399571006, 34.266212122780935, 39.947333744594026, 47.46664299283709, 44.285375526973176, 36.573458739689414, 35.83538287026541, 36.4601787839617, 34.79266670772007, 34.524796281542095, 35.45753983088902, 34.96853256225586, 35.08834729875837, 34.923070498875205, 36.87862014770508, 37.72361489704677, 37.88979148864746, 37.07650831767491, 36.89942305428641, 38.425556659698486, 37.93620892933437, 38.26155138015747, 37.29895142146519, 38.741595472608296, 37.2829601424081, 40.14084454945156, 49.43626969201224, 51.461433342524934, 52.254021303994314, 51.00720528193882, 50.215228761945454, 50.42253521510533, 52.239683696201865, 54.03331599916731, 53.87020008904593, 51.96603236879621, 52.89497525351388, 52.4754638671875, 49.97134004320417, 48.49365970066616, 46.31690720149449, 45.28027071271624, 45.30203594480242, 49.92753165108817, 54.15115744726998, 53.080961159297395, 57.60217482703072, 58.269017764500205, 66.98327473231724, 39.56120497839791, 0.052981876834694824, 0.5176372123616082, 5.700350761413574, 0.9801350406238011, 0.6177067969526563, 6.045487761497498, 66.201657976423, 62.31646851130894, 69.30257647378104, 67.76338372911725, 58.561870438711985, 39.30347544806344, 24.464110442570277, 49.20862586157662, 57.45715550013951, 61.09357861110142, 4.194914971079145, 0.22873534900801523, 0.09119119814464025, 0.048273403596665175, 0.07584353669413499, 0.04075932376352804, 0.20056709407695703, 0.1393930230821882, 0.12474187782832555, 0.13450617316578115, 0.13687883370688983, 0.22197777804519447, 0.18391602113842964, 9.134744576045446, 78.02958338601249, 62.92597838810512, 57.38009302956717, 36.28564698355538, 26.708498443875992, 45.91775403703962, 64.93465396336147, 66.58300985608781, 68.15788854871477, 64.4953749520438, 57.378956999097554, 0.5836258828639984, 0.472199304827622, 2.1732136947768073, 6.253202855587006, 1.0683976816279548, 3.485280466931207, 47.108491148267476, 47.58156967163086, 51.442680154527935, 45.85426139831543, 52.28340523583548, 58.092172213963096, 56.10387570517403, 53.99913433619908, 52.74519988468715, 44.34547744478498, 39.797124113355366, 44.757446561540874, 47.18647425515311, 50.73777151107788, 51.891874245234895, 51.34497806004116, 48.133406026022776, 51.608113288879395, 51.13829347065517, 51.62425742830549, 52.397407804216655, 52.37425293241228, 46.729918548039024, 42.96909836360386, 41.13415207181658, 39.41836391176496, 42.68019226619175, 40.703461033957346, 41.16413007463728, 42.907582487378804, 44.7566579410008, 42.60759053911482, 38.89763811656407, 39.52398695264544, 37.53193841661726, 39.58904988425118, 38.28790589741298, 40.361314364842, 36.2198405947004, 36.675076144082205, 39.929264954158235, 36.153902190072195, 37.02648476191929, 36.18354320526123, 35.98068707329886, 42.975275312151226, 48.8477121080671, 53.017600536346436, 44.82432644707816, 32.4883383342198, 36.070377894810264, 36.47994640895298, 34.20185790743147, 34.67064591816494, 36.62824875967843, 34.942622729710166, 36.89270414624895, 36.530251366751536, 35.521268708365305, 38.818077768598286, 39.61402518408639, 37.48456907272339, 39.84488255637032, 42.30140079770769, 39.15860898154122, 38.88482216426304, 38.340104239327566, 39.936459813799175, 36.148757049015586, 33.79534312656948, 33.0772294316973, 33.907855306352886, 35.351986271994456, 35.32434981209891, 37.01140022277832, 34.739742279052734, 34.99588067190987, 34.598388126918245, 36.168479510716026, 35.0465087209429, 35.82825749261038, 40.913011755262104, 51.54087209701538, 47.57553168705532, 37.569552489689414, 37.56338248934065, 37.16327394757952, 36.41296924863543, 36.64241961070469, 38.06009531021118, 36.72284500939505, 36.12201690673828, 36.70151056562151, 37.609000887189595, 39.3889730317252, 40.779505593436106, 38.73921571459089, 40.56772450038365, 40.514539514269146, 40.720772470746724, 39.84375, 40.01188598360334, 39.85362686429705, 39.953559330531526, 40.85708570480347, 52.032808031354634, 54.56294938496181, 53.681900433131624, 53.472512994493755, 52.93545198440552, 52.67151771272932, 55.582309177943635, 56.531471320560996, 55.9511855670384, 54.66245106288365, 56.78236729758126, 54.53580624716622, 52.0166152545384, 51.75858695166451, 49.20745161601475, 46.9458338192531, 48.33661304201399, 52.354950836726594, 56.95777109691075, 56.37308018548148, 59.063988958086284, 61.607863426208496, 69.89231872558594, 42.941420214516775, 0.18593156869922364, 1.8135608221803392, 11.448950682367597, 3.9438240102359226, 0.926489844918251, 6.927842540400369, 72.82351357596261, 65.88163784572056, 77.70758996691022, 70.5096800667899, 71.63683768681118, 43.46700280053275, 28.023196629115514, 61.6132413319179, 63.54316602434431, 74.96862397875104, 7.068664286817823, 0.4889809414744377, 0.1504366554852043, 0.1867889655487878, 0.1679495493216174, 0.13234830967017583], [0.045791600697806904, 0.058084300719201565, 0.11771513202360698, 0.05323391527469669, 0.06878344089324985, 0.055571234319359064, 0.07292337981717927, 3.2099878447396413, 62.94903251102993, 50.14483656202044, 41.95184734889439, 20.164844819477626, 18.098318542752946, 36.65710810252598, 51.53452839170183, 58.14818859100342, 56.51190519332886, 54.963985511234824, 50.518378666469026, 0.6581916702645165, 0.10128606895783118, 0.6613239507590021, 1.7160473061459405, 0.10878629649856261, 0.7311798908880779, 36.08160618373326, 41.36958483287266, 46.45783403941563, 50.712803159441265, 59.30748857770647, 52.90815946034023, 53.815719263894216, 47.79675538199288, 44.06171996252877, 36.22841119766235, 41.75432743344988, 42.502113410404746, 44.62332548413958, 45.732608863285606, 46.205273968832834, 45.374217305864605, 47.4028376851763, 47.947777952466694, 48.743134771074565, 48.188911710466655, 42.700244767325266, 39.13800409861973, 35.92637300491333, 35.903308459690635, 34.985857895442415, 36.50279903411865, 35.93552030835833, 37.52953781400408, 40.07441629682268, 40.08626644951956, 40.53577668326241, 38.3892696925572, 36.05573109218052, 35.871975558144705, 33.70794521059309, 34.15401956013271, 33.83455875941685, 34.74118750435965, 33.48408120019095, 32.426568848746165, 32.86340209415981, 32.27604307447161, 31.95680114201137, 33.865228107997346, 34.23300668171474, 35.73811156409127, 44.48497295379639, 45.715432916368755, 43.87112740107945, 36.01429203578404, 34.569174425942556, 33.502702372414724, 34.87338393075125, 34.41693939481463, 35.20625475474766, 34.79668276650565, 33.73830883843558, 32.73439489092146, 35.19510637010847, 34.92652375357491, 37.326403754098074, 36.37375361578805, 36.97321292332241, 36.62529230117798, 35.85953133446829, 35.928495679582866, 34.30965573447091, 32.8883878162929, 33.188140051705496, 31.827995436532156, 34.83354296003069, 34.24915429524013, 35.281145913260325, 32.79042516435896, 33.80077314376831, 34.176024505070274, 33.787870338984895, 34.836523737226216, 33.95870917184012, 32.63328470502581, 35.50596530096871, 42.17816754749843, 43.02567407063076, 39.10809905188424, 31.683639662606375, 32.96605478014265, 31.981171948569163, 33.85725852421352, 33.57003736495972, 33.650132724217, 33.90791436604091, 34.002441133771626, 34.84707110268729, 35.082312788282124, 35.8176406451634, 34.96038579940796, 36.1637338910784, 36.782679421561106, 36.930933134896414, 37.154296875, 37.81431320735386, 37.148599352155415, 37.468897410801475, 37.64890439169747, 36.61462334224156, 39.55427415030343, 45.055684089660645, 47.098249503544395, 49.442877428872244, 49.7542644228254, 48.624334471566335, 49.117580141339985, 48.826603480747764, 48.30576304027012, 49.40413427352905, 47.71025030953543, 46.74126148223877, 44.5802709715707, 43.381661551339285, 41.82898235321045, 39.53925214494978, 41.88967834200178, 42.43925653185163, 46.206576756068635, 46.84684978212629, 54.74588850566319, 57.760322775159565, 67.57299613952637, 39.95657137462071, 0.20175826230219432, 0.4597438988941056, 3.6125108855111256, 0.23759375938347407, 0.518473601766995, 8.054758276258196, 62.18855217524937, 58.354188782828196, 61.93902151925223, 64.29833098820278, 53.42744697843279, 28.430684157780238, 21.588238886424474, 37.95365933009556, 51.133322034563335, 50.60559940338135, 3.2051015240805487, 0.21565692579107626, 0.08554913196712732, 0.059085621631571224, 0.06330829433032445, 0.03506411811602967, 0.04246317947815571, 0.03570933367258736, 0.07173828448035888, 0.04045968609196799, 0.04320973763242364, 0.00907728202374918, 0.10762599483132362, 3.882012835570744, 68.78677000318254, 55.12286996841431, 51.332405294690815, 24.705339738300868, 22.047850063868932, 43.15282263074602, 55.665479115077424, 63.53507137298584, 59.4159916469029, 59.20438425881522, 53.00726161684309, 0.8463193039808954, 0.3017735912331513, 0.5921900804553712, 4.553118927138192, 0.13903703647000448, 0.8104660564235279, 40.78172206878662, 45.88393020629883, 48.02374955586025, 52.74795484542847, 60.007373673575266, 54.4555858203343, 54.97360181808472, 48.881855555943076, 45.74494538988386, 37.16926676886422, 44.00210789271763, 44.60411718913487, 46.80707481929234, 47.1135424886431, 49.551654951913015, 47.26677458626883, 50.15513031823294, 48.764326776777, 49.77882283074515, 47.96386998040335, 45.11567831039429, 41.2944643838065, 38.465884004320415, 36.54735435758318, 38.26472323281424, 38.17138460704258, 37.95153318132673, 39.614282267434255, 42.268490655081614, 41.693978854588096, 41.49433626447405, 39.5290070261274, 38.144606249673025, 37.297850131988525, 36.534323011125835, 36.11959893362862, 34.510778290884836, 35.16467326028006, 34.39602879115513, 35.49757187707083, 34.83009317943028, 34.64619868142264, 33.79059403283255, 35.88027170726231, 35.851120540073936, 37.23036575317383, 48.0527582849775, 47.7836788722447, 45.129216875348774, 36.54384899139404, 35.095639433179585, 33.95014551707676, 33.92551415307181, 34.25643253326416, 35.24240623201643, 34.22251490184239, 34.61711004802159, 33.23596797670637, 35.826906067984446, 36.731245381491526, 39.51103898457119, 38.202720982687815, 39.35743863242013, 37.82848405838013, 38.0246490750994, 37.14961378914969, 37.27115167890276, 34.70627628053938, 32.78397028786795, 33.326819147382466, 35.178844111306326, 35.067912646702354, 35.83208247593471, 33.74709830965315, 33.47824471337454, 34.90534217017037, 34.00580406188965, 33.67986059188843, 34.08511080060686, 32.99411508015224, 35.360706261226106, 43.80904524666922, 46.55884000233242, 41.5049079486302, 32.90367037909371, 33.88971355983189, 32.83280222756522, 35.385848317827495, 35.678339685712544, 35.22483423777989, 36.49320009776524, 34.35134840011597, 36.01398284094674, 37.027926513126914, 36.09618697847639, 37.528693607875276, 38.42699841090611, 36.970020226069856, 38.36385318211147, 39.85945292881557, 38.572455474308555, 40.26579053061349, 39.011953353881836, 39.05326386860439, 38.70856373650687, 41.709921496255056, 47.99637712751116, 49.75317702974592, 50.75301238468715, 51.57435894012451, 50.201123918805806, 52.99205201012747, 50.93053191048758, 51.56792490822928, 51.70843138013567, 49.498900754111155, 49.87153264454433, 48.0320074898856, 46.387632914951865, 44.469287395477295, 42.78566939490182, 44.36749281202044, 44.979570048195974, 47.35086515971592, 50.07553175517491, 57.960879053388325, 61.66178839547293, 66.92691094534737, 42.14673389707293, 0.2396517832364355, 0.1430171328995909, 3.840837810720716, 0.9872434820447649, 0.4400334879755974, 8.871964573860168, 69.97045816693986, 62.251627922058105, 68.72176960536412, 68.01641627720424, 62.67978981563023, 32.362572465624126, 23.081003768103464, 48.70046935762678, 55.88012981414795, 63.566588401794434, 4.175799173968179, 0.11571517719754151, 0.052593398573143144, 0.027105368840109025, 0.018705149414017797, 0.02471940222728465, 0.11315307646457638, 0.15540357253381185, 0.26254123928291456, 0.11592270034764494, 0.12064824891941887, 0.13404042672898087, 0.280276570469141, 4.6644147379057745, 80.08097648620605, 62.567409651620046, 58.96753406524658, 31.02463776724679, 28.12778786250523, 47.74982724870954, 62.95317363739014, 67.1161937713623, 65.83359105246407, 64.7325656073434, 59.75313908713204, 0.830020295722144, 0.37411942918385777, 2.226121404341289, 8.268702864646912, 0.166104381904006, 0.8518828568714005, 45.951508385794504, 47.84363487788609, 50.06414713178362, 55.255945341927664, 61.37356322152274, 57.234173910958425, 57.564241136823384, 52.115533283778596, 47.99129799434117, 40.09014007023403, 46.1165246282305, 47.11355985913958, 48.67218671526228, 51.030523436410085, 51.69692168916975, 49.550866331372944, 52.081257820129395, 50.814135687691824, 52.59622703279768, 51.49150514602661, 46.586278438568115, 43.45628867830549, 39.59004347664969, 40.02170378821236, 38.033653940473286, 40.23274489811489, 39.727687290736604, 41.574834619249614, 43.749255997794016, 45.48334223883492, 44.151612281799316, 44.22736849103655, 39.431871209825786, 39.86099542890276, 37.73076111929757, 38.20937735693795, 37.37370014190674, 37.770838328770225, 36.92616319656372, 36.31565277917044, 35.7864328111921, 35.42937878199986, 33.86610358101981, 38.53703703199114, 38.846322195870535, 39.37733479908535, 50.2703731400626, 49.71932888031006, 46.165742192949565, 35.64027050563267, 34.59821094785418, 34.26914426258632, 34.45534903662545, 34.81657893317086, 34.93336772918701, 34.68937131336757, 35.02856847218105, 34.25846140725272, 37.06296280452183, 37.998871258326936, 42.058637687138145, 42.155075209481375, 43.99404798235212, 40.31998995372227, 40.91041660308838, 39.312282289777485, 38.116532053266255, 36.954689025878906, 34.653174672807964, 34.12227324077061, 36.46294069290161, 36.1585123198373, 36.04232801709856, 34.1952988079616, 33.798118931906565, 34.97694335665022, 33.286120074135916, 35.66656248910086, 35.06237840652466, 32.35946314675467, 36.72915397371565, 46.62819692066738, 48.12986939293997, 43.165902614593506, 35.573140484946116, 35.273926734924316, 34.83316775730678, 36.208886759621755, 38.361515113285606, 37.19262661252703, 38.59422765459333, 37.88582059315273, 38.15892996106829, 39.00953190667288, 39.08839743477957, 39.53755331039429, 41.0764924458095, 40.94799246106829, 39.954921177455354, 42.47475835255214, 41.125949723379954, 41.411357402801514, 41.41026653562273, 42.42970275878906, 41.59476900100708, 43.33811719076974, 49.300491469247, 51.101877961839946, 53.32358877999442, 53.04031767163958, 52.07652262278965, 54.6590256009783, 54.198384353092735, 53.93013525009155, 54.88648877825056, 52.23046343667166, 52.11969525473458, 51.14702040808541, 49.742143290383474, 45.85739850997925, 44.92752456665039, 48.07611118044172, 48.394665241241455, 49.08233540398734, 52.05977399008614, 59.81629821232387, 65.88567474910191, 69.89996174403599, 45.96415410723005, 0.24633635740195, 1.5370863548346927, 10.937264493533544, 3.5896738937922885, 0.5954328807336944, 10.890198264803205, 74.91874980926514, 68.20396205357143, 74.01684583936418, 74.4859117780413, 66.79125431605748, 40.11626877103533, 31.67665672302246, 56.14489439555577, 65.01136902400425, 75.93693883078438, 7.552141223634992, 0.4251459411212376, 0.17708599620631763, 0.12112489262861864, 0.16392849651830538, 0.08711765387228557], [0.053821363752441745, 0.07172924639391047, 0.03541767896552171, 0.029971091941531216, 0.05120281229860016, 0.02745772698628051, 0.08492528008563177, 0.672480369252818, 46.922758851732524, 55.67256280354091, 41.506783962249756, 24.606416497911724, 25.73182143483843, 34.14955186843872, 54.39519902638027, 56.18482569285801, 56.74092476708548, 54.201274803706575, 50.921207427978516, 1.8898648534502303, 0.22889969018953188, 0.2718056578721319, 2.2972101611750464, 0.16482136717864446, 0.0750883747158306, 36.07264995574951, 50.305680411202566, 54.05191632679531, 56.63996049336025, 52.753096512385774, 51.83905751364571, 47.99400084359305, 43.51516771316528, 40.21752486910139, 41.489281449999126, 42.35517985480172, 44.75413574491228, 45.87905951908657, 46.48454291479928, 46.71499034336635, 47.91583013534546, 47.254497119358604, 47.08436352866036, 41.969474928719656, 36.901118414742605, 34.91128287996565, 34.94265399660383, 33.63620506014143, 34.009531770433696, 35.16084132875715, 39.2250337600708, 38.970681054251536, 41.98887777328491, 42.308845792497905, 40.07408973148891, 40.39857407978603, 37.90027632032122, 35.89567238943917, 36.193989821842735, 33.639495032174246, 34.22197641645159, 33.478168283190044, 32.44955696378435, 32.30250876290457, 34.09009265899658, 33.50312968662807, 34.19958584649222, 33.28508479254586, 34.27159002849034, 34.3138941356114, 37.49577651705061, 44.94694825581142, 46.13404451097761, 45.874845436641145, 40.638252190181184, 34.01342970984322, 35.60713454655239, 34.775233677455354, 35.830602509634836, 35.69539751325335, 36.14851038796561, 34.345369475228445, 32.8746269089835, 33.71581751959664, 34.630117075783865, 34.273483412606375, 38.26837798527309, 38.137859548841206, 38.321048804691856, 37.102567536490305, 37.68521915163313, 33.92458309446062, 32.52378804343087, 32.48923465183803, 33.26483079365322, 33.59861530576433, 34.812382221221924, 33.96714775902884, 32.99512256894793, 34.37229374476841, 35.28011410576956, 32.866560050419395, 33.03044373648507, 32.46755279813494, 33.03896917615618, 35.739539418901714, 41.25921964645386, 41.63713564191546, 33.62101977212088, 32.57548611504691, 33.57497753415789, 32.390681403023855, 33.79958152770996, 33.26319101878575, 32.83532789775303, 32.56931264059884, 32.14664677211216, 33.009842327662874, 35.11577531269619, 34.20353937149048, 32.91323457445417, 34.87833104814802, 35.907237665993826, 37.514939648764475, 40.32507950919015, 40.77778591428484, 41.46700552531651, 41.93625211715698, 38.548147201538086, 37.92224652426583, 35.37024961199079, 35.4226633480617, 39.565505913325715, 41.77802079064505, 41.91360098975045, 42.813333647591726, 42.024706159319194, 43.234529972076416, 41.133050782339915, 39.93550443649292, 39.78107724870954, 39.093031883239746, 39.566190310886924, 40.22687367030552, 40.556489263262065, 40.29398284639631, 38.84163563592093, 42.18527902875628, 45.3766839163644, 47.249362400599885, 52.90928854261126, 57.58071878978184, 62.992479596819194, 43.75921971457345, 0.07908265931265694, 0.24035029432603291, 3.258126050233841, 0.6613444153751645, 0.3808842333299773, 9.805768592017037, 63.55103138514927, 57.44373158046177, 63.06569971357073, 64.42168930598667, 51.525551319122314, 38.52378681727818, 24.61350539752415, 33.880465507507324, 56.14549541473389, 51.4304895401001, 2.1169502224240984, 0.09719411603042058, 0.05932038796267339, 0.0944210384041071, 0.04379082823704396, 0.025762592142980014, 0.06947560768042292, 0.034613648895174265, 0.037520000977175574, 0.010380186306844865, 0.07557163414146219, 0.007658981834538281, 0.023160364545349563, 1.1452113198382514, 55.21361344201224, 61.40491349356515, 48.91724273136684, 31.76361690248762, 32.298833165849956, 43.783416816166465, 59.59987572261265, 59.756265776497976, 62.07912499564034, 57.393447467258994, 56.40882519313267, 1.6995365406785692, 0.26422788734946934, 0.25254454570157187, 2.991186465535845, 0.16896283280636581, 0.08018975704908371, 38.48350463594709, 50.93879679271153, 54.65118455886841, 57.700939995901926, 54.89446531023298, 54.761209283556255, 49.39583465031215, 45.24819435392107, 40.843199729919434, 43.58995117459978, 44.45949738366263, 46.272271973746165, 46.0542687688555, 48.35626254762922, 49.981581687927246, 49.59416403089251, 49.0520030430385, 48.558691365378245, 44.06287683759417, 39.574604579380576, 36.746910095214844, 36.58235590798514, 35.554463727133616, 36.66193362644741, 37.403761523110525, 39.6041830607823, 40.96179158346993, 45.86459336962019, 44.95140552520752, 42.129342555999756, 42.195062092372346, 39.29175383704049, 37.875936780657085, 36.55580684116909, 36.249585832868306, 35.076643058231895, 35.56787027631487, 32.75052860804966, 34.32060956954956, 34.377466678619385, 35.32387733459473, 36.26476069859096, 35.670672348567415, 36.56878955023629, 35.904569557734895, 37.958505698612754, 47.54972260338919, 47.214548451559885, 48.56876277923584, 40.113836901528494, 34.11196558816092, 35.10462692805699, 34.40337651116507, 36.21529994692121, 35.37440463474819, 35.19414751870291, 34.03655678885323, 32.91287326812744, 35.539361817496165, 35.89760398864746, 34.38211154937744, 39.81781932285854, 39.82725845064436, 39.79501533508301, 38.46065895898001, 39.78450965881348, 35.860983507973806, 32.36326033728463, 32.897080012730186, 34.67416865485055, 34.688488892146516, 36.267394065856934, 33.48960154397147, 33.18668787819998, 33.19730819974627, 34.91298866271973, 34.21101563317435, 34.307046685900005, 32.87594011851719, 32.481886931828086, 37.32947833197457, 44.792434215545654, 44.55721337454659, 35.4334990637643, 34.210310391017366, 35.61092478888375, 35.233620234898154, 35.586234365190776, 34.95263160978045, 34.3045140675136, 34.55010162081037, 34.028319699423655, 35.03969253812517, 36.637343951633994, 35.85436187471662, 35.78807953425816, 37.80801119123186, 37.55691371645246, 37.77967643737793, 41.315520899636404, 42.19651773997715, 43.44207613808768, 43.315160342625205, 41.75608532769339, 39.02650982992989, 37.288004534585134, 37.32567766734532, 42.54393114362444, 44.1129664012364, 44.53066430773054, 43.672627789633616, 44.002514362335205, 46.637438024793354, 43.52225487572806, 42.32047012874058, 42.20408085414341, 41.64342028754098, 42.40525899614607, 41.75852414539882, 41.92637872695923, 41.72560358047485, 40.388638155800955, 43.07948439461844, 47.71743822097778, 49.84089456285749, 55.40061378479004, 60.236191749572754, 67.24087919507707, 46.6630734034947, 0.08124333194323949, 0.39249733303274426, 2.6054520096097673, 0.2785412578710488, 0.6117445368851934, 10.766844289643423, 70.53314413343156, 60.7338147844587, 71.44189207894462, 68.86641025543213, 57.05085958753313, 36.854655810764854, 24.847140312194824, 39.76426260811942, 62.43603311266218, 60.023639406476704, 2.9243065799985613, 0.14634784417493002, 0.060173231842262406, 0.01875240937806666, 0.07736969087272882, 0.036055009945162704, 0.14022055082023144, 0.11831051936107022, 0.1413951763617141, 0.0777701283139842, 0.08665515761822462, 0.14479033489312443, 0.16603015017296585, 1.192386439868382, 61.79999501364571, 69.62006746019635, 56.46031829289028, 36.89027575084141, 36.11730602809361, 45.23224823815482, 67.17627484457833, 65.33434213910783, 66.70171288081578, 63.940630776541575, 62.936115809849326, 2.0339511675494055, 0.6679089974079813, 1.1839870448623384, 6.0062291366713385, 0.47671047704560415, 0.31259760899203165, 41.09098291397095, 52.43762745176043, 57.732957295009065, 58.50450611114502, 56.54414136069161, 57.03239474977766, 53.400918756212505, 46.82608161653791, 43.78549780164446, 44.74523510251726, 46.936196667807444, 49.154186725616455, 48.393689019339426, 51.64779445103237, 51.70445006234305, 51.92420768737793, 50.78628035954067, 50.91296339035034, 46.24317291804722, 42.60313674381801, 39.987886905670166, 38.562245096479145, 36.40139354978289, 38.193365233285085, 40.44027369362967, 42.607802459171836, 42.52035590580532, 47.43610913412911, 46.32952165603638, 45.41384983062744, 44.4816551889692, 42.49473442350115, 39.56560318810599, 39.756744657244, 37.369923795972554, 37.482404708862305, 38.1114216532026, 35.330512864249094, 35.153497082846506, 35.758636542728965, 37.67794438770839, 39.45604746682303, 37.118499755859375, 39.525699683598106, 38.49168266568865, 39.818208421979634, 46.686203956604004, 49.25941719327654, 50.666705335889546, 41.50504343850272, 33.699975626809255, 36.33624376569475, 34.30817576817104, 37.66548974173409, 36.839324610573904, 36.63706949778965, 36.032572746276855, 33.492241859436035, 36.3153783253261, 37.853254386356895, 36.97574206760952, 43.68146937234061, 42.515189920152935, 42.684764180864605, 40.96222931998116, 41.602266107286724, 38.349501677921836, 34.057279791150776, 35.544069222041536, 35.79252985545567, 35.199355193546836, 36.74743121010916, 33.24681411470686, 33.098824432918, 34.709489822387695, 35.691999844142366, 33.954804284232004, 33.82092291968209, 32.49000242778233, 33.78074148723057, 38.531509740012034, 47.58846575873238, 47.12002168382917, 36.7767630304609, 37.23575060708182, 38.27417973109654, 36.870358739580425, 36.638768332345144, 35.964365754808696, 35.50580201830183, 36.156191621507915, 36.39201348168509, 36.474940231868196, 39.73223141261509, 37.20037385395595, 37.020193168095176, 39.16368811471121, 38.83398566927229, 41.17815153939383, 44.712137358529226, 45.65354878561837, 46.330292906079976, 46.61507872172764, 42.38989652906145, 41.44064405986241, 39.58243172509329, 39.53021253858294, 44.41050216129848, 46.21785715648106, 45.797935826437815, 47.40277167728969, 45.86539936065674, 48.98386900765555, 44.916414397103445, 45.29413931710379, 44.62479502814156, 44.344122546059744, 43.65229388645717, 45.32416595731463, 44.71371807370867, 44.05569934844971, 42.30307183946882, 45.9719534601484, 50.41499989373343, 51.443625109536306, 57.17546163286482, 63.94968427930559, 68.38579641069684, 50.454278060368125, 0.18373878779155867, 3.1109165208680287, 10.22437150137765, 2.4824061436312537, 0.9524536345686231, 12.688940967832293, 76.31813785008022, 67.69985634940011, 75.4631689616612, 74.51944378444126, 65.8338759286063, 54.941323961530415, 35.28605828966413, 49.13748325620379, 69.24998555864606, 71.26943778991699, 4.104049035481044, 0.2858865080135209, 0.11981825131390776, 0.17663500112082275, 0.11530778477234499, 0.12261663829641682], [0.042634601172591956, 0.04246334571923528, 0.045644087184752734, 0.08159244499568429, 0.07576862642807619, 0.032293778378516436, 0.06053725230906691, 0.040979447308927774, 32.59673718043736, 55.18665443147932, 45.21328660420009, 23.765286684036255, 21.808053834097727, 37.83346244267055, 46.72513818740845, 56.991358688899446, 57.61998306001936, 54.66807562964303, 52.478083338056294, 4.332373355116163, 0.4796894629086767, 0.40417920904500143, 2.110987365245819, 0.4115312988204615, 0.08437457427914653, 31.08070625577654, 61.32828875950405, 53.68467971256801, 53.97876221793038, 50.56858287538801, 48.907091413225444, 43.57780572346279, 39.402723516736714, 39.175969055720735, 40.67123876299177, 44.86755813871111, 45.08746862411499, 45.13089486530849, 47.46068491254534, 48.62075614929199, 48.65226970400129, 46.287005628858296, 44.278899805886404, 36.98638323375157, 34.353540556771414, 36.716126101357595, 34.67098985399519, 37.32221746444702, 38.74638625553676, 40.138919898441856, 42.41764416013445, 42.53584691456386, 43.13416324343, 43.493784632001606, 40.93165029798235, 38.636170455387656, 36.56663908277239, 35.95674010685512, 35.34866850716727, 34.48624072756086, 33.27117449896676, 31.771037578582764, 32.64032323019845, 31.924888065883092, 32.62424509865897, 35.62165628160749, 33.54244954245431, 32.847747802734375, 33.6324599811009, 33.54178598948887, 38.86552701677595, 46.09517976215908, 44.409414768218994, 46.15713684899466, 41.80544533048357, 35.29543488366263, 33.71230867930821, 36.25531114850725, 33.80656099319458, 35.26750659942627, 36.2776391846793, 35.371913705553325, 31.91236046382359, 32.63371549333845, 31.90277542386736, 34.15879644666399, 36.97629444939749, 36.7866016796657, 36.76268598011562, 38.71513325827462, 36.33242225646973, 33.35613359723772, 31.52542918069022, 33.017672947474885, 32.20042930330549, 35.398230007716585, 34.99582161222185, 35.34964125497, 34.13368913105556, 34.47924389157976, 33.74532651901245, 32.98815699986049, 34.513606207711355, 33.49042837960379, 34.467873164585654, 39.30223519461495, 43.77212946755545, 42.46082026617867, 32.814021246773855, 32.152076789310996, 32.21481902258736, 31.93842315673828, 33.310959884098594, 33.777878829411094, 33.311414991106304, 33.594269207545686, 33.84986216681344, 34.67926863261631, 34.33965458188738, 34.820459502083914, 35.90213768822806, 33.91375085285732, 36.9616893359593, 37.10080616814749, 39.89537858963013, 42.17789656775338, 45.21577058519636, 46.80636262893677, 43.72988094602312, 43.09253658567156, 39.4334762437003, 36.569602489471436, 33.79579128537859, 34.072096824645996, 35.910204546792166, 35.85570635114397, 36.47084426879883, 38.42817613056728, 38.67849540710449, 37.331430775778635, 38.08554308755057, 37.94173274721418, 37.012244428907124, 36.00423451832363, 40.24435881205967, 40.613652093069895, 46.816152640751426, 49.14214897155762, 49.817381858825684, 51.583864075796946, 54.52246570587158, 58.087016650608604, 60.798023087637766, 43.310713495527, 0.017349687504715154, 0.2502330211656434, 2.1426027544907162, 0.547390701515334, 0.3702623647238527, 13.59787825175694, 66.42219379970005, 57.48909636906215, 61.874979972839355, 62.71177932194301, 57.488394601004465, 31.675030844552175, 17.929852519716533, 35.78936842509678, 58.73298372541155, 49.18723930631365, 0.9717422681195396, 0.052874929537730556, 0.04401214261140142, 0.04969195229932666, 0.04180830158293247, 0.04324102827480861, 0.03251133027619549, 0.04947191696347935, 0.05442896132756557, 0.07178709150425025, 0.12498125141220433, 0.046874037078980885, 0.05210166424512863, 0.05951478824551616, 39.41726609638759, 62.653470039367676, 49.35737984521048, 25.932712963649205, 24.366001878465923, 42.60834094456264, 54.63457836423601, 60.75693838936942, 61.421610014779226, 58.358267375401084, 56.864067690713064, 4.622917490346091, 0.5215831377676555, 0.0878686767869762, 5.208898161138807, 0.2069463681961809, 0.05441243560718639, 34.33207062312535, 63.28014196668352, 56.0010666847229, 55.00510842459542, 52.77411481312343, 50.344670227595735, 46.72393614905221, 40.81574739728655, 41.95604058674404, 43.56006697246006, 47.463707378932405, 46.47366203580584, 47.36993101664952, 48.31818641935076, 49.21837765829903, 49.485188484191895, 49.43493216378348, 46.070739473615376, 39.08666385923113, 36.633623191288535, 38.87508078983852, 37.95068550109863, 38.084803104400635, 40.79937049320766, 42.23912409373692, 44.23281240463257, 45.367324692862375, 45.62821217945644, 45.467823437282014, 43.09216833114624, 41.1330577305385, 39.133598940713064, 38.30852467673165, 37.680397101810996, 35.315744468144004, 35.165243012564524, 32.89604125704084, 33.35887813568115, 33.26624127796718, 34.08885587964739, 36.602675914764404, 34.518278871263774, 33.964441435677664, 34.61043977737427, 35.90000111716134, 40.94477891921997, 47.319560050964355, 46.41746153150286, 47.90900353022984, 42.16494859967913, 35.03259495326451, 33.670268603733604, 36.065020833696636, 34.30650472640991, 35.310060841696604, 36.404117243630544, 35.7858178956168, 32.809063707079204, 34.88898958478655, 33.269604206085205, 35.70255068370274, 37.802251134599956, 38.67904084069388, 38.15908282143729, 40.43069907597133, 37.570386273520334, 36.40935271126883, 32.918285914829795, 32.55442265101841, 33.79407855442592, 35.875449657440186, 35.491718019757954, 35.66336284364973, 35.590125356401714, 34.08602796282087, 34.60488469260079, 33.43774018968855, 33.70569746834891, 33.68819843019758, 33.298904759543284, 40.22421598434448, 46.89316299983433, 45.10073273522513, 35.79917580740792, 33.28032527651106, 33.78344086238316, 35.02525765555245, 36.403808048793245, 34.690434387751985, 35.20761660167149, 34.80426672526768, 35.42107915878296, 35.3328891481672, 35.8356990133013, 37.02608871459961, 36.794168267931255, 35.691638537815635, 38.26553269795009, 38.78535175323486, 41.056679657527376, 43.65760925837925, 46.42256498336792, 48.49875967843192, 47.052380970546174, 43.75827128546578, 41.112956592014854, 38.803747109004426, 36.02757004329136, 36.367580141339985, 38.49149506432669, 38.14457498277937, 41.14847230911255, 40.51504673276629, 40.23721258980887, 39.03106090000698, 40.24982009615217, 41.207903725760325, 38.57600947788784, 37.45854459490095, 43.10391078676496, 43.367966651916504, 49.80526072638375, 52.38658945901053, 52.186776638031006, 52.53754254749843, 56.880215304238455, 61.53365666525704, 63.097397395542686, 48.846586499895366, 0.04449437066380467, 0.2085918698992048, 2.0532109226499284, 0.7306416769112859, 0.4124370887875557, 15.760927166257586, 71.61064992632184, 60.539077622549875, 67.63782283238002, 68.22509847368512, 63.698868206569124, 42.54861422947475, 26.54692155974252, 41.32069730758667, 65.6196768624442, 58.02380888802664, 1.8079353868961334, 0.10680710484406777, 0.04378175961651972, 0.04546298958095057, 0.04263861809990235, 0.05518310211066689, 0.1259725775037493, 0.10013744487826313, 0.1557716234986271, 0.1273825325603996, 0.14806205433394226, 0.12224902159401349, 0.13176643875028404, 0.1676275030310665, 44.350862298692974, 70.49511664254325, 58.67278453281948, 34.70921189444405, 31.07330642427717, 47.49586364201137, 59.42597620827811, 66.04567091805595, 68.4976554598127, 61.51425034659249, 62.88724912915911, 5.434115767478943, 0.9308140128850937, 2.441183784178325, 6.325003802776337, 0.8317387806517738, 0.13998273786689552, 37.10701090948922, 65.9689211164202, 58.31904479435512, 56.348879609789165, 55.62704515457153, 52.290537561689106, 48.53127377373831, 43.202665533338276, 43.202533517565044, 46.3795382635934, 49.27224356787545, 47.987111704690115, 49.29100022997175, 49.21510853086199, 51.584392138889854, 52.441313471112935, 51.329129219055176, 49.48563664300101, 41.438319887433735, 38.43020153045654, 40.99937438964844, 39.5308517728533, 40.92696721213204, 41.765917028699604, 44.271569456372944, 46.51249899183001, 47.66478477205549, 46.771329811641145, 48.880243573869976, 45.77599341528756, 43.067759309496196, 40.89374440056937, 40.17181614467076, 39.61985124860491, 37.87251826695034, 36.97481100899832, 34.61624847139631, 35.352792263031006, 34.096867152622764, 36.41278164727347, 38.198114327022004, 36.60138007572719, 35.59207432610648, 36.20589556012835, 36.64059223447527, 42.42368561880929, 51.58808510644095, 48.049958160945344, 49.983054706028526, 45.35444968087332, 35.57432515280587, 34.55728605815342, 36.522601400102886, 33.775644983564106, 35.39389085769653, 37.505927835192, 36.88913972037179, 34.46132448741368, 36.39763110024588, 34.49460983276367, 36.423874446323936, 38.685332434517996, 41.25362287248884, 41.83324159894671, 43.55623851503645, 39.131722927093506, 38.04752949305943, 33.51905843189785, 34.57799168995449, 33.095854078020366, 36.57202046258109, 36.60230071204049, 36.5032993044172, 35.1724865095956, 34.98380470275879, 34.53605931145804, 33.530752250126426, 34.3191157068525, 34.98742471422468, 34.06042732511248, 41.04092461722237, 50.29265948704311, 47.02119745526995, 38.02850185121809, 35.071893964494976, 35.67981617791312, 35.9437643459865, 38.82643297740391, 37.438533782958984, 38.30878523417881, 36.963683468954905, 37.53801114218575, 37.51019402912685, 37.64840759549822, 39.494349411555696, 39.6389205796378, 36.544425691877095, 40.496745177677695, 40.03194195883614, 42.612527234213694, 46.064614636557444, 47.56196532930647, 51.685780252729145, 49.10813406535557, 46.01110655920846, 44.35779660088675, 41.34602001735142, 37.04512677873884, 38.99274158477783, 39.743706362588064, 39.20522097178868, 42.40886163711548, 42.78443261555263, 43.30753469467163, 40.65812751225063, 42.394246101379395, 43.020414284297395, 41.12497002737862, 38.611747537340435, 45.69286169324602, 44.774042333875386, 52.61986827850342, 53.940032958984375, 54.12557070595877, 55.977950028010774, 60.612075396946494, 64.3349688393729, 65.28838675362724, 53.62236131940569, 0.17364772355982236, 0.7373927203672273, 5.643604823521205, 1.836313784122467, 0.6348195586885724, 17.896996225629533, 77.3021000453404, 66.58193288530622, 73.15765939440045, 73.1225084577288, 72.44400296892438, 44.06770583561489, 28.433529445103236, 49.64086634772164, 72.41840580531529, 70.99414321354458, 2.920847897018705, 0.2865670786372253, 0.14595041264380726, 0.11649561460529055, 0.12869103306106158, 0.17022152883665903], [0.052323484128074985, 0.03509831967364464, 0.036555120787982426, 0.02400107791514269, 0.07209391825433288, 0.07457793317735195, 0.1334194993334157, 0.01732059701212815, 20.622564349855693, 66.71823569706508, 47.12888758523123, 40.865350587027415, 40.22953135626656, 41.580754484449116, 46.78925616400582, 54.80876970291138, 56.63754252025059, 54.564460618155344, 56.770746435437886, 8.022689734186445, 0.6484785771795681, 0.6506657941000802, 3.3030843692166463, 0.35760171551789555, 0.18354370897369726, 23.346419743129186, 61.70574269975935, 53.38951676232474, 52.84971121379307, 46.68593297685896, 44.43242372785296, 41.306835651397705, 40.343429701668875, 41.81284516198294, 42.70755079814366, 47.03270019803728, 46.96929441179548, 47.36644649505615, 49.114835602896555, 47.317298412323, 49.12878063746861, 45.69892052241734, 36.82696723937988, 34.986966133117676, 35.790959562574116, 35.01074981689453, 39.18493570600237, 40.82260874339512, 44.70580407551357, 43.41998086656843, 43.25169202259609, 45.404678208487375, 42.88259676524571, 43.50300489153181, 43.22250264031546, 38.84413698741368, 36.00482858930315, 34.975578035627095, 34.429637227739605, 33.61920281818935, 34.17517682484218, 33.05508552278791, 34.37846374511719, 33.76005322592599, 32.72276013238089, 33.951305866241455, 32.81537961959839, 32.84206765038626, 33.52658680507115, 32.39423540660313, 34.072920186179026, 43.08335106713431, 43.69113779067993, 46.976416315351216, 46.19384070805141, 36.40100792476109, 34.15796613693237, 36.08313478742327, 36.0529796055385, 35.02063362939017, 33.78863116673061, 35.50166089194161, 32.93971068518502, 33.68816368920462, 33.71859679903303, 33.74019874845232, 36.39463642665318, 37.21827936172485, 37.42626673834664, 37.88380561556135, 36.04034778050014, 32.29171821049282, 31.56846284866333, 33.62081132616316, 33.57496016366141, 34.98895331791469, 34.96201515197754, 34.86043248857771, 34.78675379071917, 35.37751047951834, 34.88706840787615, 35.11610882622855, 34.69277593067714, 34.20322322845459, 35.71044036320278, 42.66669539042881, 44.43357712881905, 43.33204446520124, 38.35635607583182, 32.577980518341064, 32.97794662203108, 33.379708835056846, 32.82630566188267, 32.95744596208845, 35.391636167253765, 33.97061838422503, 33.20144932610648, 34.79365335191999, 35.26112815311977, 35.34630264554705, 34.22681583677019, 34.43325029100691, 34.85320288794381, 37.03847387858799, 40.52661200932094, 45.060179574149, 47.53725406101772, 47.44186224256243, 46.82525478090559, 46.908963203430176, 46.345203740256174, 43.403322560446604, 41.32570348467146, 36.73105083193098, 37.04385873249599, 37.50872795922415, 36.79719073431832, 36.383408137730186, 38.649246965135845, 38.419699328286306, 38.35230527605329, 38.29264456885201, 38.08810002463204, 40.95268596921648, 44.36965022768293, 50.407766819000244, 51.3694600377764, 54.69029944283621, 52.53037200655256, 54.58151844569615, 53.582412651606965, 60.10221658434187, 61.67098781040737, 39.80709477833339, 0.5547112258417266, 0.3641858665006501, 1.0260172528879983, 0.4883895846349852, 0.451643846396889, 20.275562626974924, 66.98651259286063, 56.2698403767177, 67.04108374459403, 60.20474420275007, 53.38406590053013, 23.86050479752677, 14.382858804294042, 35.422020639692036, 56.8611216545105, 41.628738743918284, 0.45293102732726503, 0.09998867607542447, 0.015399007891703929, 0.03313845608915601, 0.05270883773586579, 0.025796337385794947, 0.07534879645598785, 0.028452165857223526, 0.07352729633982692, 0.04456164401822856, 0.05412964935281447, 0.08417402646903481, 0.1382012441754341, 0.017459501612133214, 26.439358234405518, 73.52238423483712, 54.1305456161499, 42.675120081220356, 28.92555570602417, 39.40614203044346, 52.21676158905029, 60.020123617989675, 60.906394141060964, 58.29547650473458, 60.679896763392854, 8.713454450879778, 0.853242098220757, 0.07167176769248076, 5.5834408061844965, 0.2928713746368885, 0.2548408167702811, 26.806007725851877, 63.434496198381694, 53.94807549885341, 56.87963512965611, 49.379499435424805, 44.862082958221436, 43.10619674410139, 43.2711296081543, 45.05280753544399, 44.255077907017295, 47.3963063785008, 48.14065647125244, 49.09613105228969, 49.80267252240862, 48.414884499141145, 50.28623587744576, 47.1370656149728, 38.66143410546439, 35.90000111716134, 36.280206544058665, 37.24293851852417, 39.97163159506661, 42.34454911095755, 45.803980759211946, 45.018611976078574, 45.68508318492344, 46.86766658510481, 44.591714654650005, 45.90863105228969, 44.00232328687395, 39.6160887990679, 38.687441212790354, 36.65237637928554, 36.27552693230765, 35.517770290374756, 36.3488130569458, 34.1295827456883, 34.28549337387085, 34.29958084651402, 35.17748921258109, 35.49250316619873, 34.824131625039236, 35.045157296316965, 34.143732752118794, 35.09510094778878, 36.63061809539795, 45.04177379608154, 46.1481146131243, 48.96451827457973, 47.12477077756609, 36.37296152114868, 34.248726981026785, 35.74221100125994, 35.32227577481951, 35.40782894407, 34.198904923030305, 36.60925585883004, 33.515900475638254, 33.41838250841413, 34.56300095149449, 34.383897236415315, 38.47122369493757, 38.713271141052246, 38.069232191358296, 39.992497035435264, 37.54377467291695, 34.29758671351841, 32.89898729324341, 34.25000197546822, 34.196480001722065, 35.67813471385411, 34.184987681252615, 34.717476776668, 34.70920147214617, 34.84479556764875, 34.58253581183297, 34.796484742845806, 34.8094813483102, 34.97597408294678, 36.271827016557964, 44.590179102761404, 45.40197535923549, 44.7339824948992, 38.28092990602766, 33.48768731525966, 33.70326212474278, 33.20513881955828, 34.61124576841082, 35.45172071456909, 37.65839563097273, 34.52646384920393, 34.42551694597517, 35.342741693769185, 36.89596632548741, 36.41670390537807, 36.09282752445766, 37.26142767497471, 36.69578872408186, 39.61798913138253, 42.44679880142212, 46.27418620245797, 48.50159106935774, 49.69901582172939, 48.894838265010286, 48.28298337118966, 48.15618569510323, 44.53149809156145, 42.591012137276785, 39.28464582988194, 38.26585578918457, 38.42849574770246, 37.40743712016514, 38.28969158445086, 39.87588889258248, 41.092059884752544, 39.68297215870449, 39.11908762795584, 39.964568751198904, 43.631953035082134, 46.764152322496685, 53.5764684677124, 53.01367827824184, 57.12984323501587, 54.51824467522757, 58.60793004717146, 55.13145446777344, 61.92424270084926, 65.37762941632951, 47.30770295006888, 0.8168331033417157, 0.16293577264462197, 3.3475571828229085, 0.7654038944414684, 0.3345672972500324, 21.82535137448992, 72.56827844892229, 60.63715839385986, 71.26467827388218, 64.17545904432023, 61.777135440281455, 30.278012139456614, 18.088082109178814, 41.42789758954729, 64.99060085841587, 51.213542461395264, 1.0591324759381158, 0.0646628470027021, 0.030986509418913295, 0.015824927715584636, 0.041682850636009655, 0.04401355057156511, 0.14081535461757863, 0.09445024255130972, 0.16372277827135154, 0.16160165066165583, 0.17377760873309203, 0.1798414454928466, 0.3930183936442648, 0.18449591073606694, 30.55100338799613, 82.49330765860421, 60.33467551640102, 55.25403458731515, 53.07338762283325, 52.93791512080601, 57.37372153145926, 65.40968840462821, 66.54239068712506, 63.27827984946114, 66.86697578430176, 10.084413937159947, 1.313871675304004, 1.1114368864468165, 11.973951356751577, 1.104599967598915, 0.6074379022632326, 30.4198283467974, 65.44162927355084, 56.68293857574463, 57.626736709049766, 51.74801179340908, 47.06053468159267, 43.73777757372175, 43.61584711074829, 46.41595377240862, 45.76503610610962, 48.597458839416504, 50.944282395499094, 52.31054489953177, 51.93326813834054, 51.40709842954363, 54.63706234523228, 50.38433401925223, 40.897284507751465, 38.51552888325283, 39.03163760049002, 39.55680676868984, 42.695276805332725, 45.437279156276155, 49.01448971884591, 48.25967911311558, 47.41707801818848, 50.34123434339251, 46.77983440671648, 48.85897166388375, 47.058874062129426, 42.636505467551096, 39.72190291540963, 38.68381772722517, 38.49899217060634, 37.18799563816616, 38.0787581716265, 36.038068771362305, 36.636847155434744, 36.50954226085118, 36.52582883834839, 38.01532459259033, 35.55989374433245, 37.42702061789376, 37.066301413944785, 36.47307116644723, 37.695464270455496, 47.57029969351632, 48.92916931424822, 50.20164155960083, 49.793723242623464, 37.59673384257725, 34.129773821149556, 37.12708078111921, 36.167329583849224, 35.72311387743269, 33.85156447546822, 37.20243052073887, 33.25067731312343, 35.38286059243338, 37.08511018753052, 36.164373125348774, 40.05551719665527, 41.87235300881522, 41.3828524180821, 42.09469883782523, 40.24511269160679, 35.861369132995605, 34.06326219013759, 37.097960880824495, 34.41914892196655, 38.00716045924595, 34.91692134312221, 34.90149981634957, 36.03577586582729, 36.24495833260672, 35.634211676461355, 36.57322597503662, 35.34697662081037, 35.70700100490025, 36.84636313574654, 46.3866879599435, 50.031195299965994, 47.46251923697335, 41.62074136734009, 35.40595293045044, 35.75366163253784, 35.180848666599815, 36.27345289502825, 36.85986695970808, 39.70306634902954, 36.87411771501814, 35.938160623822895, 37.77651848111834, 38.89155844279698, 38.39217403956822, 38.525405747549875, 38.33604996544974, 38.88151134763445, 41.78664697919573, 44.60792132786342, 49.00802789415632, 51.186315945216585, 51.326933588300435, 49.703580788203645, 50.35198320661272, 49.45999084200178, 47.157917158944265, 45.277943066188264, 41.840717860630576, 40.9699626650129, 40.03436688014439, 40.92190197535923, 39.213624817984446, 43.41806663785662, 43.11896753311157, 41.031589712415425, 41.59463003703526, 41.14768716267177, 45.7349226134164, 48.830876622881206, 55.446530955178396, 55.236111709049766, 60.37392589024135, 57.278499943869456, 60.85528319222586, 57.3164336340768, 65.30212334224156, 67.90434878213065, 53.73199347087315, 1.028571910091809, 0.6255810601370675, 5.803022120680128, 1.7284722051450183, 0.559674573796136, 24.85666629246303, 79.78378813607353, 64.88063171931675, 77.84158597673688, 69.31346430097307, 67.76314054216657, 34.070457049778526, 23.655477353504725, 52.545407908303396, 72.32177025931222, 61.9803910936628, 1.5026651961462838, 0.25183648083891186, 0.060847654938697815, 0.15506247297993728, 0.10951960286391632, 0.09308775780456406], [0.0325591703876853, 0.06523570697754622, 0.02123871605311121, 0.01910506947232144, 0.11121126530425889, 0.05466035533962505, 0.09251529816538095, 0.08376109041273594, 11.851123707635061, 59.07272284371512, 47.880231039864675, 32.15962600708008, 23.28786379950387, 33.70514508656093, 40.86122335706438, 50.73395695005144, 58.14782728467669, 52.51861912863595, 58.40632806505476, 15.231019326618739, 0.5061003257121358, 0.5220298309411321, 4.183758335454123, 0.29240817949175835, 0.057353525289467404, 24.89231923648289, 60.317013195582796, 56.23238263811384, 57.15611089978899, 52.501210417066304, 51.28403193610055, 45.163954394204275, 45.74449028287615, 44.37765107836042, 46.52522461754935, 46.16883066722325, 45.76779106685093, 48.017134870801655, 46.15713684899466, 47.885341439928325, 46.01403522491455, 39.53949185780117, 35.449827330453054, 36.46099519729614, 35.818561281476704, 37.99068628038679, 40.802490234375, 41.88555458613804, 40.62343863078526, 43.3523644719805, 42.45031458990914, 42.478513853890554, 43.691012723105295, 44.600014277866904, 38.73824296678816, 36.496232986450195, 34.50349310466221, 35.04557418823242, 33.17166239874703, 32.97461148670742, 34.29470321110317, 33.734233719961985, 32.11374357768467, 33.26132542746407, 33.18411357062203, 32.305736201150076, 33.098244258335654, 33.31009135927473, 35.15584904806954, 33.31872797012329, 33.64717973981585, 39.8824063028608, 44.48546627589634, 43.455552169254844, 44.3996490750994, 37.388576235089985, 34.47734355926514, 36.47456155504499, 34.26377330507551, 35.76593215124947, 34.53625386101859, 35.39736148289272, 33.90762601579939, 31.72195897783552, 33.343967301504954, 32.78848661695208, 34.93787016187395, 38.632380213056294, 35.71431050981794, 38.6034757069179, 37.26695496695382, 32.75751502173287, 31.830416883741105, 32.45042201450893, 33.857637201036724, 34.805986404418945, 35.056621823992046, 35.40017897742135, 35.73384189605713, 34.270815304347444, 33.848455156598774, 34.584324972970144, 35.01794120243618, 34.50948592594692, 36.64445890699114, 42.92939288275582, 42.181975160326274, 45.7113265310015, 44.53919669560024, 39.179741927555625, 34.312021596091135, 33.512683459690635, 33.4164092200143, 32.83713790348598, 31.8712340763637, 33.128472396305625, 34.00057206835066, 33.540424142565044, 34.91122382027762, 35.073832511901855, 35.780735288347515, 34.998361178806846, 36.23976108006069, 36.9586112839835, 37.192452907562256, 42.49208715983799, 44.97365018299648, 46.40910284859793, 47.08012860161917, 47.04753460202898, 49.17481245313372, 47.181419440678184, 46.56880719321114, 45.543920108250205, 43.725441047123496, 42.33978264672415, 40.008655071258545, 37.05412817001343, 35.56337479182652, 37.82498564038958, 39.79711021695818, 38.849351610456196, 42.84366600854056, 44.322899273463655, 46.67163011005947, 48.061294146946494, 54.208264691489084, 53.07102176121303, 51.10054043361119, 54.744804586683, 57.42327260971069, 60.451926367623464, 59.55200958251953, 38.71136038643973, 3.669635934489114, 0.21656152153653757, 1.8846256945814406, 0.11775014443056923, 0.24674749534044946, 23.294447217668804, 65.57631315503801, 56.902126448495046, 64.43993527548653, 63.567019190107075, 50.5216269493103, 38.97303301947457, 39.23389618737357, 39.727843625204905, 53.69613034384591, 35.14211940765381, 0.05478793349383133, 0.08369461433695895, 0.0433379773582731, 0.035661853184657435, 0.015570889293615307, 0.049492259443338425, 0.04206069286114403, 0.09328886201339108, 0.010591054634590234, 0.010167075420862861, 0.1265851046357836, 0.05936514413250344, 0.11813372027661119, 0.09979297979069607, 15.63024718420846, 68.61629595075334, 53.34671933310372, 37.55810880661011, 33.42018209184919, 46.19068969999041, 47.07306228365217, 57.54975414276123, 60.83180522918701, 56.79918193817139, 63.354293142046245, 16.889919110706874, 0.8284512513450214, 0.2840254764471735, 6.439432382583618, 0.3296896889805794, 0.02966782750029649, 28.424462045942033, 62.149385179792134, 57.72943455832345, 57.8021057673863, 55.157350403921946, 51.555195808410645, 47.88494191850935, 47.70380585534232, 48.05443627493722, 46.79329654148647, 49.671622548784526, 47.74584245681763, 49.461623668670654, 47.99910429545811, 50.324072292872835, 47.51147971834455, 41.847117151532856, 37.05121340070452, 39.986403465270996, 36.733576502118794, 39.60277257646833, 42.91979742050171, 43.53869431359427, 42.766134534563335, 46.555157457079204, 43.81557307924543, 45.65222862788609, 45.18993370873587, 46.30580745424543, 40.743472235543386, 39.357765197753906, 37.03141450881958, 37.306511061532156, 34.33558293751308, 35.12041323525565, 36.11653825214931, 36.5152119909014, 34.67445700509207, 35.23530169895717, 34.54794767924717, 33.10215262004307, 33.996111324855256, 35.66713571548462, 36.52352551051548, 35.896064962659565, 35.54954092843192, 41.35055719103132, 45.907328265053884, 44.92268514633179, 46.12095410483224, 38.16318573270525, 35.05426638466971, 36.47943224225725, 34.046996457236155, 35.7606862613133, 33.78377090181623, 34.57249566486904, 33.74727201461792, 33.36857782091413, 33.217947823660715, 34.17923109872, 37.14674070903233, 42.863378047943115, 37.730219159807476, 41.06439215796334, 38.1989620072501, 33.33995124271938, 33.16388389042446, 33.19138486044747, 34.94426250457764, 36.143973214285715, 35.09703949519566, 34.77444505691528, 35.354859352111816, 33.59659685407366, 33.42051213128226, 36.002688544137136, 34.389702456338064, 34.963349206107004, 37.95460081100464, 45.80820526395525, 45.019643783569336, 47.205508845193044, 45.554700238364084, 40.62002011707851, 36.685897963387625, 34.92602000917707, 35.872034617832725, 34.190980502537315, 33.874521323612754, 34.593621662684846, 35.03661796024868, 34.82235288619995, 35.950010776519775, 35.98868792397635, 36.67562505177089, 36.90359197344099, 38.27389138085501, 38.243916852133616, 38.06175940377371, 43.94665779386248, 46.21024887902396, 48.10300418308803, 49.332533087049214, 49.273921557835166, 49.6727203641619, 51.211725507463726, 48.104300022125244, 49.13981090273176, 46.1345135143825, 42.918456418173655, 42.01755993706839, 39.515058517456055, 37.5262964793614, 39.358974184308735, 40.53661046709333, 40.82028109686715, 43.359048639025005, 47.40097556795393, 51.19343784877232, 50.79750517436436, 55.90630367824009, 55.82465192249843, 54.08058112008231, 58.704475266592844, 60.34691824231829, 64.41701316833496, 60.878448486328125, 47.95337472643171, 3.79727303981781, 0.04405273596889206, 1.888697556086949, 0.7207587329404694, 0.19537279994360038, 24.380386386598857, 72.82586206708635, 59.96894318716866, 69.72115680149624, 65.59996482304165, 63.314229828970774, 33.94395467213222, 26.906687123434885, 44.69839382171631, 60.86664349692208, 43.34094858169556, 0.18348622348691734, 0.019594902205946188, 0.05878032158528056, 0.029887418395706584, 0.05771038721182516, 0.035276686173996756, 0.13202990032732487, 0.1254352049103805, 0.17126514283674105, 0.09064956435135432, 0.27567984855600763, 0.21290508631084645, 0.313714151935918, 0.19398233241268567, 17.87044194766453, 77.78666741507394, 59.87292603084019, 46.86815643310547, 33.36732367106846, 43.460269996098106, 55.45956230163574, 61.28393840789795, 67.46648025512695, 61.89635957990374, 68.21107006072998, 18.548836265291484, 1.1181686052254267, 0.793041005730629, 9.621760317257472, 1.368573431457792, 0.13934882331107343, 33.2898199898856, 63.44942787715367, 58.60615825653076, 61.48244844164167, 57.8245484488351, 54.95556082044329, 50.684127943856375, 48.788419655391145, 48.21904952185494, 50.12405102593558, 51.202790124075754, 49.831257411411826, 51.58770990371704, 48.65946456364223, 52.471110820770264, 50.724441392081125, 43.61918919427054, 38.30609975542341, 40.83327422823225, 39.86395883560181, 41.95248310906546, 46.2109089578901, 47.48813724517822, 44.56217438834054, 48.92053617749895, 46.270548820495605, 49.12600135803223, 47.6832218170166, 49.005561283656526, 42.72043623243059, 41.482541697365896, 37.318104130881174, 39.9801744052342, 36.211655616760254, 36.58105659484863, 38.46437971932547, 38.56257513591221, 35.233158179691856, 37.50157478877476, 36.510237080710276, 35.47558082853045, 35.50233834130423, 36.1326823915754, 37.57187666211809, 36.92228610174996, 37.20569964817592, 43.18828623635428, 47.99951423917498, 48.18830721718924, 47.059002603803364, 39.01070267813546, 35.75399167197091, 37.026324953351704, 34.98885604313442, 36.144511699676514, 34.28206096376692, 35.90419088091169, 34.38917786734444, 33.6918740272522, 34.88194758551461, 33.65715387889317, 38.91088138307844, 45.015870911734446, 38.85236365454537, 43.42255170004708, 41.92245299475533, 34.01612213679722, 34.87790720803397, 33.954710483551025, 36.21199607849121, 36.1824905531747, 35.99103988919939, 36.06077548435756, 36.24588591711861, 34.20164251327515, 32.67484882899693, 36.72114964893886, 35.09887381962368, 34.991072518484934, 38.211896078927175, 49.284409863608225, 47.42418949944632, 50.34611545290266, 48.73315715789795, 42.58547094890049, 37.77715424128941, 38.47690732138497, 37.519688742501394, 36.70970596585955, 34.751668861934114, 37.016284806387766, 37.475519044058665, 37.22348008837019, 38.525301524571006, 38.66071496691023, 39.223578112465994, 38.36368295124599, 39.950179031917024, 41.571270193372456, 40.436872550419395, 48.25566305433001, 48.50569398062569, 49.86400774547032, 50.46022571836199, 50.39694847379412, 52.497041497911724, 54.781550134931294, 50.29404565266201, 50.98081949778965, 46.75464718682425, 46.013062477111816, 44.584512846810476, 42.40333087103707, 39.061636447906494, 41.721952302115305, 43.65037618364607, 43.23736136300223, 45.061319078717915, 49.8452719279698, 53.451470375061035, 52.48317984172276, 57.99976464680263, 59.25391796657017, 56.39217036111014, 61.52094146183559, 61.59777464185442, 67.01394408089774, 63.10415799277169, 54.05102348327637, 4.142083040305546, 0.28468672239354675, 4.223927174295698, 1.8823816435677665, 0.40739978051611353, 28.038691111973353, 77.89818600245884, 65.54776300702775, 76.72015367235456, 72.73996148790631, 65.56259741101945, 52.586284160614014, 53.45020580291748, 56.95715618133545, 67.6399142401559, 54.99061448233468, 0.6721364334225655, 0.15033963854823792, 0.1459085334624563, 0.08909037230270249, 0.13495874245251926, 0.18133095199508326], [0.005216868993427072, 0.015457762238968695, 0.10249436340693917, 0.05879715603909322, 0.0787109306880406, 0.08872976486704179, 0.08138641462262187, 0.3344660598252501, 6.564437857695988, 53.280482155936106, 48.83842584065029, 36.52640553883144, 16.577694858823502, 19.679535729544504, 38.54800476346697, 47.89368970053536, 57.00416769300188, 50.97718211582729, 61.760035923549104, 22.588164567947388, 0.32123831819210735, 0.3071651762085301, 2.3416517078876495, 0.6959113233855793, 0.785038092306682, 43.83140802383423, 53.87561273574829, 56.3809802872794, 58.05641678401402, 55.72754042489188, 50.97315216064453, 50.60138184683663, 48.030742917742046, 49.80716453279768, 48.31975323813302, 45.9800237928118, 49.98522254398891, 51.34076745169503, 48.5357449395316, 47.25289208548409, 42.77333286830357, 36.965448311397004, 34.98914091927664, 34.63899687358311, 34.90482452937535, 36.790826184409006, 39.78775446755545, 40.53345945903233, 43.562874044690815, 43.71318095070975, 44.165331499917166, 43.95207044056484, 44.63524511882237, 41.646713733673096, 38.497018882206504, 35.4893730027335, 35.94984401975359, 36.290409973689485, 34.22447081974575, 34.152953011649, 33.39664159502302, 32.09093958990914, 34.174773829323904, 35.20896107809884, 33.16018050057547, 35.74386814662388, 33.792980739048545, 35.10390778950283, 33.47984627314976, 33.860426902770996, 33.4700597354344, 39.2597782271249, 44.54317453929356, 45.94561978748867, 47.30239452634539, 38.90628514971052, 33.084233215876985, 36.15038292748587, 35.14464855194092, 34.75133882250105, 35.154094627925325, 35.013001033238, 35.1854692186628, 34.14949975694929, 32.23589290891375, 32.49529348100935, 34.1318860735212, 37.88683155604771, 38.705124378204346, 39.38649252482823, 34.56842054639544, 31.85788311277117, 31.84998995917184, 33.32923364639282, 32.79494496754238, 34.30221421377999, 33.79605531692505, 34.92101730619158, 35.003089427948, 33.55678020204817, 33.596586431775776, 32.185476779937744, 33.46354579925537, 32.90653998511178, 38.19068670272827, 44.800400325230186, 41.45760113852364, 41.2275983946664, 36.90253932135445, 33.64755841663906, 33.98277078356062, 33.536633900233674, 33.256878580365864, 32.722996371132986, 31.45993546077183, 32.60563087463379, 32.410702637263704, 33.169393811907085, 35.51474434988839, 34.27966036115374, 34.078836577279226, 34.6936479296003, 35.78306640897478, 37.950772353581016, 37.720449992588584, 40.693247182028635, 43.87833268301827, 44.18875387736729, 46.3956754548209, 46.09204612459455, 47.64430495670864, 46.92002820968628, 47.98977633884975, 48.80361189161028, 49.19938128335135, 49.33808469772339, 44.78513860702515, 43.64749615533011, 40.791157722473145, 37.78118419647217, 38.022599356515066, 39.29531478881836, 40.167133058820454, 44.42290122168404, 46.97775731767927, 50.31841993331909, 50.67966720036098, 51.917599950517925, 52.39080354145595, 58.51007856641497, 51.120631149836946, 54.55272511073521, 59.52348027910505, 35.9569068636213, 3.8026166387966702, 0.2439758697790759, 2.7074441824640547, 0.36040886917284554, 0.14112598794911588, 29.67925807407924, 64.00497804369245, 55.1556203024728, 66.60149206433977, 62.43213517325265, 52.090561458042686, 33.018478938511436, 26.3373030935015, 43.20919336591448, 59.062661852155415, 28.579293966293335, 0.12841737988804067, 0.010496393062307366, 0.014399430814332195, 0.019342222550351704, 0.00858272414188832, 0.03712015046871134, 0.024479898025414774, 0.07155968049275023, 0.021901215592931424, 0.07889982805188213, 0.026399975709084953, 0.057207497768104076, 0.13718648148434504, 0.10555072940353837, 8.74179094178336, 62.10811982836042, 56.88142776489258, 41.39938565662929, 17.243186371667043, 26.710265023367747, 44.13944946016584, 55.718236786978586, 62.190400396074565, 55.049517835889546, 66.23168114253453, 24.22503161430359, 0.32428483186023577, 0.29885219942246166, 2.7043250926903317, 0.2065761187779052, 0.7389344604951995, 47.28154993057251, 54.35822071347918, 58.891284533909385, 59.26992661612374, 56.415596212659565, 52.4183600970677, 51.72664955684117, 50.5127853666033, 50.587356907980784, 50.431974342891145, 48.28396306719099, 50.001679352351594, 51.78882898603167, 49.514885084969656, 48.91017641339983, 46.035022258758545, 39.221709047045024, 37.48517009190151, 36.892183031354634, 37.752085140773225, 39.04855298995972, 43.01297971180507, 43.74522604261126, 45.75223752430507, 46.22997828892299, 46.44550098691668, 44.930265630994526, 46.14821883610317, 44.928556374141145, 40.02795021874564, 38.76629631859915, 38.20528139386858, 37.483731814793174, 35.569659437452046, 36.960122517177034, 35.563440799713135, 33.43709748131888, 34.985642501286094, 34.70243740081787, 34.93540702547346, 36.507440430777415, 35.37351873942784, 36.34372002737862, 35.986273424965994, 36.57927785600935, 35.495320660727366, 40.87643643787929, 46.15236343656267, 46.563279901232036, 48.87821817398071, 39.397303921835764, 33.77258777618408, 36.88765975407192, 36.036130223955425, 34.69309207371303, 35.91150385992867, 35.58050904955183, 35.569864409310476, 34.66215174538748, 33.840429987226216, 34.74848311288016, 36.40885591506958, 39.206565448216026, 40.127986907958984, 40.135362420763286, 37.11206572396414, 34.07436888558524, 32.27214860916138, 33.03405679975237, 32.883068970271516, 34.74362284796578, 33.56128263473511, 34.563195501055034, 34.14214856284005, 33.50046157836914, 35.08455358232771, 33.940320764269146, 33.74278347832816, 35.31815896715437, 39.32905871527535, 46.85896396636963, 44.0757622718811, 42.36138459614345, 38.737228529793875, 35.1758668082101, 34.24943222318377, 35.14721243722098, 34.60299130848476, 34.52483797073364, 32.56829820360456, 33.53294093268258, 34.00897591454642, 36.35460785457066, 35.75560017994472, 36.16635683604649, 35.57747963496617, 36.9501553262983, 37.089317321777344, 38.348105090005056, 39.361555440085276, 41.600612436022075, 45.46733358928135, 48.33643238885062, 48.161858899252756, 49.395431654793875, 49.40664952141898, 49.167468207223074, 50.18138061250959, 50.566432407924104, 50.215200969151084, 50.6489839553833, 47.06384549822126, 45.291818618774414, 41.40140758241926, 39.99075303758894, 39.95747116633824, 42.577018465314595, 41.51982225690569, 46.37901367459978, 50.26636055537632, 51.7270108631679, 52.5682327406747, 54.178971086229595, 54.91160304205758, 60.52541051592146, 51.40423229762486, 58.45250579289028, 60.076160839625764, 44.279827390398296, 5.687619490282876, 0.14141250614609036, 3.8445837582860674, 0.8116641864180565, 0.059528060390480926, 32.581298283168245, 71.39043372017997, 61.54789352416992, 72.20761135646275, 65.40728432791573, 58.03312642233712, 35.50654200145176, 32.0605342728751, 49.46187727791922, 67.95705086844308, 34.99492529460362, 0.03737687419301697, 0.08912241272628307, 0.02051315177232027, 0.032855825897838385, 0.008943444383995873, 0.04188283186938081, 0.12847557105123997, 0.22397026898605482, 0.18398403748869896, 0.18612695964319365, 0.21065994964114257, 0.18763264242027486, 0.21897032085273946, 0.5085127619760377, 10.542829155921936, 72.18440437316895, 63.24835395812988, 49.07520307813372, 25.159341982432775, 30.80921581813267, 52.867978027888704, 59.144733973911826, 67.51501342228481, 59.25790623256138, 72.90774658748082, 26.93512957436698, 0.5187052264809608, 1.2570256399256843, 8.884539076260157, 1.3471137029784066, 1.1963159718683787, 50.74562644958496, 54.892307894570486, 61.292081696646555, 59.834092548915315, 59.83115346091134, 54.15409306117466, 54.78798764092581, 51.42891924721854, 53.328827721732004, 52.11690207890102, 51.20423534938267, 53.08035666601998, 55.15679454803467, 52.30315549033028, 51.04746661867414, 47.081837858472554, 41.761140142168315, 38.68827152252197, 38.344057764325825, 38.97953305925642, 42.10179989678519, 46.15415954589844, 44.99239294869559, 48.51220096860613, 47.893967628479004, 48.89429630552019, 47.32774155480521, 48.561658246176584, 48.72056007385254, 43.94948918478829, 39.312400409153526, 40.78681509835379, 40.10376896177019, 37.47136402130127, 38.37174980981009, 37.374030181339805, 35.335185527801514, 37.577330998011995, 36.90201473236084, 36.35910333905901, 39.16257987703596, 36.87535102026803, 38.4728912625994, 37.326740741729736, 38.47651127406529, 38.123417718069895, 42.43783909933907, 49.3653633253915, 50.47731828689575, 52.89907816478184, 40.641882623944966, 35.36977366038731, 37.493372440338135, 36.43519306182861, 34.96143845149449, 36.26740101405552, 35.39915411812918, 36.248970917293, 35.1200658253261, 34.06330387932913, 35.016377857753206, 37.20699896131243, 43.09026105063302, 42.859466212136404, 42.9759909766061, 38.461364201136995, 33.397965226854595, 33.33006395612444, 35.764358384268625, 34.56648199898856, 34.97487626756941, 35.444852420261924, 35.5048257963998, 35.2247439111982, 33.55148914882115, 34.32946852275303, 33.148333821977886, 34.71842520577567, 34.46377372741699, 42.24425881249564, 50.42544651031494, 46.71020998273577, 44.663145610264365, 40.20987490245274, 37.044032437460764, 36.72794498716082, 37.40284783499581, 36.85774775913784, 36.05077355248587, 33.843247481754844, 34.97413281032017, 35.101503712790354, 36.29166759763445, 37.09723479407174, 37.71366855076381, 36.813581534794395, 38.674861499241416, 39.64303738730294, 40.35221569878714, 41.83951929637364, 43.694007396698, 47.024160861968994, 47.95400701250349, 50.02023104258946, 50.100253445761545, 52.16704722813198, 50.14814043045044, 52.20827089037214, 52.495971475328716, 53.35376828057425, 53.502723761967246, 48.70201185771397, 47.44635425295149, 45.273211342947825, 41.70121540342058, 43.442562511989046, 44.11339718954903, 44.8982309613909, 50.0449457849775, 52.5597038269043, 54.63403640474592, 55.64522164208548, 56.28930228097098, 56.55235413142613, 62.6692077091762, 53.26597779137747, 60.82195268358503, 61.78318037305559, 51.487315382276265, 8.884604215621948, 0.4350188427737781, 13.973268577030726, 3.9911586131368364, 0.26938339642116, 35.74612978526524, 78.26475211552211, 66.01223618643624, 79.03256280081612, 70.76524175916398, 67.06622232709611, 43.09206410816738, 40.17195510864258, 58.55072552817208, 77.21733202253068, 44.8691006387983, 0.20457016570227488, 0.14702624348657473, 0.1389148865959474, 0.06608241690056664, 0.1413715633430651, 0.20349523052573204], [0.034763835836201906, 0.02823666313530079, 0.022148516162165573, 0.034228441172412465, 0.060229909872370105, 0.032782757854355235, 0.029988737244691168, 0.01698838796333543, 2.6060185049261366, 49.288040297372, 49.506679262433735, 41.45568690981184, 42.60371344430106, 33.01728384835379, 36.6082900592259, 45.828084060123985, 57.693244865962434, 50.774468421936035, 58.659388405936106, 32.15371309007917, 0.07331693012799535, 0.2148537981723036, 3.4372414903981343, 0.1146928963384458, 5.228780431406839, 60.85539436340332, 55.32726165226528, 57.40579094205584, 51.89084938594273, 54.75383377075195, 52.103707449776785, 51.9557386125837, 50.78843082700457, 49.45870542526245, 47.3104544367109, 50.492215224674766, 52.19036538260323, 46.75526557649885, 45.22944811412266, 39.60415874208723, 36.3581132207598, 35.20455592019217, 33.85683121000017, 35.41524962016514, 35.08550895963396, 37.54293046678816, 37.73398855754307, 38.69491400037493, 39.148607049669536, 42.439729009355815, 41.88694075175694, 43.72550705501011, 42.94589138031006, 45.8100882257734, 40.740401131766184, 38.46779128483364, 35.58689444405692, 34.423248359135215, 34.41598401750837, 35.22424711499895, 34.56700311388288, 33.79608310971941, 32.572793688092915, 33.45425953183855, 33.705360480717246, 32.07456963402884, 33.861555985042024, 31.796784128461564, 34.90748916353498, 32.08404002870832, 34.81154496329171, 42.70535864148821, 43.08062389918736, 46.52521766935076, 45.63494150979178, 42.27529294150216, 33.53356974465506, 36.7235745702471, 35.26776368277413, 35.72655323573521, 34.62244626453945, 36.859092235565186, 34.29240683146885, 33.3576100894383, 33.943134784698486, 32.23456927708217, 35.85567855834961, 38.56376327787127, 38.463219370160786, 39.528631823403494, 34.35353708267212, 32.17135109220232, 32.53907755443028, 32.57076481410435, 36.59677342006138, 35.89615876334054, 34.98301955631801, 34.88089493342808, 33.7976256098066, 31.909998076302664, 35.93687173298427, 33.564211300441194, 34.5345515523638, 32.506000655038015, 41.71289879935128, 43.30550234658377, 40.77277626310076, 39.824315888541086, 33.106915610177175, 31.560931001390728, 31.80558054787772, 32.034124170030864, 33.212979861668174, 33.48546389171055, 32.06767702102661, 32.58060346330915, 33.844723973955425, 34.32510505403791, 36.05276421138218, 36.18730565479824, 35.66375889096941, 35.96737085069929, 34.79381316048758, 35.807652609688894, 35.58643238885062, 39.21462535858154, 41.63373449870518, 44.31536742619106, 45.8555919783456, 44.265858037131174, 45.62439761843, 47.40455389022827, 48.996695382254465, 48.70316178458077, 49.0000444139753, 48.168629918779644, 46.280185971941265, 47.19203281402588, 45.88540322440011, 41.168010643550325, 37.353185585566926, 38.29361036845616, 38.217322622026714, 39.87143162318638, 43.2383063180106, 45.39729574748448, 50.356162548065186, 54.30569928033011, 55.82111528941563, 55.934200695582796, 50.7620450428554, 40.353872844151084, 46.26681068965367, 46.04982886995588, 3.9484662754195075, 0.4139135538467339, 0.5050643927284649, 1.0975056397063392, 0.12950801636491502, 34.89351633616856, 63.62545354025704, 53.1905585697719, 63.03526660374233, 62.518813950674875, 53.72955812726702, 32.171010630471365, 22.8949362209865, 38.755981717790874, 59.066941942487446, 21.510108130318777, 0.19418049177953176, 0.07248398768050329, 0.024374107630657296, 0.030292985561702932, 0.08104399871081114, 0.053247302770614624, 0.04388041521555611, 0.12009673565626144, 0.022173750879509107, 0.017393502207206826, 0.05131992405014379, 0.01868432687063302, 0.06423940722431455, 0.1410877321447645, 3.9074727722576688, 57.72659274509975, 57.33639580862862, 47.62477009637015, 36.15905775342669, 31.971392359052384, 44.686008657727925, 49.67166771207537, 62.20237909044538, 54.606240136282786, 63.70230756487165, 32.940384660448345, 0.10065188298800162, 0.1467215676925012, 2.0601085296698978, 0.4300334560019629, 5.7337824531963895, 62.58724675859724, 57.02224690573556, 59.625458989824565, 52.27160372052874, 56.27581582750593, 53.404118401663645, 54.77495629446847, 52.83929239000593, 51.36662517275129, 49.326720918927876, 50.983452865055625, 53.171190466199604, 50.087048394339426, 46.19227736336844, 41.99723298209054, 36.95119060788836, 37.91759817940848, 36.24361038208008, 36.966855321611675, 37.08921309879848, 39.106372424534385, 40.140490191323416, 42.05803319386074, 41.337268761226106, 43.60190207617623, 43.85360404423305, 45.98476593835013, 44.9624879019601, 45.65045683724539, 42.30151891708374, 39.40225451333182, 38.671043464115684, 37.24942466190883, 37.510454586574006, 36.80833911895752, 34.74746172768729, 35.51864923749651, 34.589966910226, 34.97235754558018, 35.03934512819563, 34.68151984895979, 35.33466788700649, 33.72831385476248, 36.282933712005615, 34.384213379451204, 37.88295446123396, 44.328183378492085, 46.00032990319388, 47.45616510936192, 46.977666991097585, 44.11890711103167, 33.848753929138184, 36.48611640930176, 35.804591928209575, 34.42342553819929, 34.21132482801165, 36.277677399771555, 35.529550961085725, 33.79703153882708, 33.92992278507778, 33.649740150996614, 37.08079883030483, 39.4970383644104, 41.684074197496685, 39.564324719565256, 34.035514559064595, 33.83354432242257, 32.70519161224365, 32.734064851488384, 36.25360883985247, 36.25147574288504, 34.18213197163173, 35.413700171879356, 33.078462736947195, 32.510503087724956, 34.807327406747, 34.47382429667881, 34.571112973349436, 34.31170892715454, 43.26112767628261, 47.009291716984336, 43.97721249716622, 42.31958770751953, 35.89790276118687, 32.98984541211809, 33.43920278549194, 33.58479186466762, 33.73878131593977, 33.983024392809185, 34.75585862568447, 34.18122175761631, 34.75142567498343, 36.341399329049246, 37.8920635495867, 36.876945631844656, 37.25964546203613, 37.039342403411865, 37.30957521711077, 37.551924909864155, 37.97708865574428, 41.33352368218558, 44.72903190340315, 44.468634264809744, 47.3788594518389, 46.78867251532418, 47.740652152470176, 49.90390430177961, 51.5948873928615, 50.72552183696202, 49.852195807865684, 49.43731539590018, 48.79020186832973, 49.638444900512695, 47.20542894090925, 43.980439935411724, 39.823680128370015, 38.947355951581685, 40.555811813899446, 42.24123287200928, 46.11750085013253, 47.70401777539934, 52.67471735818045, 57.56514440264021, 56.6253136907305, 58.534188815525596, 52.627719742911204, 42.892018522535054, 46.773667880467, 53.03931018284389, 5.1521018488066535, 0.3999065825981753, 1.4887623935937881, 1.044935786298343, 0.045433446166238615, 37.326636518750874, 70.91931111471993, 56.843521867479595, 69.6855889729091, 64.32082230704171, 66.03244154793876, 36.16373041697911, 27.75755136353629, 45.057219641549246, 66.80688081468854, 29.06269403866359, 0.19203105568885803, 0.0514654562409435, 0.0530528787390462, 0.04317870144067066, 0.03489485755562782, 0.022367822072867836, 0.11664113322538988, 0.2103117254695722, 0.09785454773477145, 0.1096013527629631, 0.21726700796612672, 0.10591278890413897, 0.15986445173621178, 0.2519065056528364, 4.227621878896441, 68.9964041028704, 63.831425939287456, 54.82793978282383, 54.70863226481846, 45.7688888822283, 51.7558319909232, 55.673771790095735, 66.80959061213902, 59.05440044403076, 68.99119295392717, 37.115102086748394, 0.22159874838377747, 0.6308372638055256, 9.682598744119916, 0.6958404300468308, 6.535597622394562, 64.87753977094377, 59.063988958086284, 61.120475087847026, 55.22308036259243, 58.66373103005545, 54.64135980606079, 55.32867908477783, 54.381431170872276, 53.066074643816265, 51.15284299850464, 53.16414499282837, 54.377880641392295, 51.54333175931658, 47.72785357066563, 44.719922815050396, 39.336121559143066, 39.882875306265696, 38.664904730660574, 39.23338549477713, 39.443738733019146, 42.96923385347639, 42.48405851636614, 43.641131605420796, 43.88757726124355, 46.080074378422324, 46.043092591421946, 47.92303194318499, 47.369680881500244, 49.770940099443706, 45.80821221215384, 42.727898597717285, 41.953497546059744, 41.32490791593279, 40.06839568274361, 39.21078647886004, 38.211527824401855, 36.340892110552105, 36.38145221982683, 36.86067642484392, 37.1141745022365, 35.66884497233799, 38.37600558144705, 35.58888857705252, 39.87222719192505, 36.035709857940674, 39.063258852277485, 46.72397436414446, 47.20378221784319, 50.34616756439209, 49.77046414784023, 43.850876876286094, 34.93298210416521, 35.188328402382986, 35.33140570776803, 34.567475591387065, 33.36479105268206, 37.13766288757324, 36.214813573019846, 34.40910530090332, 34.65371663229806, 34.482179505484446, 39.924019064222065, 43.5640413420541, 42.92271218981062, 41.99560710362026, 36.33896745954241, 34.77710621697562, 33.186621870313374, 33.56831073760986, 37.3559752873012, 38.12208366394043, 35.65121391841343, 35.509922300066265, 33.44453205381121, 32.47359773090908, 37.04477936880929, 35.635170527866904, 35.219543184552876, 34.22907747541155, 45.28463418143136, 49.51150131225586, 46.8128730910165, 45.24146849768502, 37.36399698257446, 35.755482060568674, 35.275194781167166, 35.26922280447823, 35.76548746653965, 36.76359619413103, 35.9076441356114, 36.43314681734358, 37.06710393088204, 38.46584231512887, 39.49901165281023, 39.43037039893014, 39.643026965005056, 39.0357300894601, 39.08759839194161, 38.906743730817524, 39.72307021277291, 42.63509150913784, 46.47429779597691, 46.82687718527657, 48.96580369131905, 48.34481886454991, 48.225236892700195, 50.59276260648455, 53.21681581224714, 51.957972458430696, 51.60367686407906, 53.035565103803364, 49.89125510624477, 50.28486360822405, 49.462061405181885, 46.282287802015034, 42.10604177202497, 41.66276059831892, 42.465753487178254, 45.08417170388358, 49.34567560468401, 49.70388650894165, 54.635874203273225, 60.54185690198626, 59.48591136932373, 61.58239133017403, 52.29974739892142, 44.099063055855886, 48.710412229810444, 58.37154538290841, 10.675606625420706, 0.6274105533957481, 6.8207069635391235, 2.7907891273498535, 0.364935077726841, 42.633406570979524, 76.50878947121757, 62.98329407828194, 75.0591937473842, 71.47229044778007, 68.89426558358329, 41.012954643794465, 35.414916106632774, 51.71639401572091, 78.27361106872559, 36.79250764846802, 0.3093896039894649, 0.17640945608062403, 0.1676671023347548, 0.1587095579930714, 0.1959161436451333, 0.08993647832955633], [0.011735363231439675, 0.06634512530373675, 0.07747334388217755, 0.0430505601023989, 0.05278276412614754, 0.026166656353910054, 0.02742050594783255, 0.07544812041201762, 0.6442794767873627, 45.30783074242728, 51.01893731525966, 36.46957969665527, 20.528803621019634, 13.710571953228541, 37.32056726728167, 47.130252906254356, 55.433648994990754, 53.27430868148804, 56.67506626674107, 39.28945050920759, 0.1644930647952216, 0.05439384374767542, 0.7019515335559845, 0.19520940871110984, 15.901367630277361, 68.5205636705671, 53.3963121005467, 61.49886703491211, 53.81131410598755, 54.04626396724156, 49.69732393537249, 52.83090591430664, 50.08659676143101, 51.37339966637747, 50.64399862289429, 52.20044721875872, 47.725341796875, 48.15669638769967, 41.32578338895525, 35.27721323285784, 33.90420055389404, 34.569122314453125, 34.65711430140904, 33.93883037567139, 35.565507888793945, 34.375535079411094, 34.96062551225935, 35.82875081471035, 35.53437648500715, 37.547867161887034, 38.007858753204346, 40.498162610190256, 42.05743564878191, 41.64104052952358, 39.03592116492135, 40.71418905258179, 35.767314842769075, 34.314036573682515, 34.10557671955654, 33.51776259286063, 32.88183913912092, 32.44225788116455, 33.62775257655552, 32.14093535287039, 33.68844509124756, 33.41884456362043, 33.65829685756138, 35.6175742149353, 35.3962984085083, 36.024561473301475, 38.501993792397634, 42.66885280609131, 43.408339159829275, 46.04403754643032, 44.199818883623394, 45.874348640441895, 35.469963209969656, 34.11933762686593, 35.95071949277605, 35.67055422919137, 35.8812062399728, 36.61247982297625, 34.61060306004116, 34.855447156088694, 33.50331728799002, 32.21099403926304, 35.944942065647666, 41.14440066473824, 41.13249840055193, 38.9140636580331, 31.854940550667898, 33.550492082323345, 34.73488201413836, 33.97321353639875, 34.150163309914724, 33.30724259785244, 33.04371132169451, 33.58134208406721, 34.369167055402485, 33.3508494922093, 32.70111301967076, 33.46655436924526, 32.671638761247905, 36.84224285398211, 42.1280779838562, 45.74580349240984, 44.001451287950786, 41.49365881511143, 34.45806578227452, 32.79361091341291, 34.73681708744594, 31.786608491625103, 32.291888441358296, 34.077954156058176, 32.8855425289699, 33.60023423603603, 33.122410093035015, 34.14145374298096, 34.50416360582624, 36.29017720903669, 35.54660184042794, 37.068754128047395, 36.37625496728079, 37.139326981135774, 36.50635303769793, 40.90977042061942, 43.52020515714373, 44.189942019326345, 42.34913492202759, 42.97538995742798, 44.115318366459434, 42.59429168701172, 45.44056218011038, 45.93832070486886, 45.33178118297032, 48.20485782623291, 45.42213903154646, 48.21481806891305, 46.88989734649658, 44.15656634739467, 39.2612304006304, 37.784321308135986, 36.49963065556118, 38.86028460093907, 40.73589175088065, 44.588146754673545, 50.81978109904698, 53.154691968645366, 53.70417635781424, 56.88806676864624, 57.26692077091762, 56.59110076086861, 44.301915713718955, 51.31932531084333, 3.544148428099496, 0.5821902113301414, 0.9102634127650941, 0.8834579139947891, 0.06854863385004656, 37.291280610220774, 61.58763722011021, 52.98977647508894, 60.89410277775356, 58.84895610809326, 48.42270469665527, 40.804262025015696, 19.21097353526524, 34.719710622514995, 55.50291211264474, 17.93848739351545, 0.19116753845342568, 0.04381584582318153, 0.03384937419156943, 0.024126501720664755, 0.014591717460591878, 0.02359651498097394, 0.05191253957205585, 0.010219225926058633, 0.04784649989700743, 0.09060101517077003, 0.08148889376648835, 0.017487660815407122, 0.04196728912315198, 0.08406933530100755, 1.2862260958978107, 55.29032155445644, 54.615509033203125, 44.973473003932405, 29.13046850476946, 26.57860013416835, 47.301935945238384, 49.252396038600374, 60.98166397639683, 56.130768707820344, 61.39408125196184, 41.66873604910714, 0.11914038125957761, 0.3442147352865764, 0.34438263199159075, 0.33015983232430046, 17.01076912879944, 70.3648796081543, 54.12896490097046, 62.36241694859096, 54.570172037397114, 55.66672631672451, 51.01016868863787, 53.56533397947039, 51.896668502262656, 52.91327680860247, 50.52331188746861, 53.05067048754011, 48.316518851688926, 49.88233709335327, 41.77964666911534, 37.253385135105674, 36.338800702776226, 36.82546990258353, 38.05645792824881, 36.98750189372471, 38.0929776600429, 36.99501289640154, 38.031378405434744, 37.46368626185826, 36.693992614746094, 40.495431968144004, 40.45837722505842, 43.253300530569895, 43.86783742904663, 44.04374497277396, 41.05449792316982, 41.47374875204903, 37.778550829206196, 36.15426697049822, 35.82998064586094, 34.687186104910715, 34.927228995731895, 33.802558830806184, 33.831303528376985, 33.672071661267964, 36.1067864554269, 35.25132771900722, 34.86621338980538, 37.30452387673514, 35.330109868730815, 38.707723004477366, 39.93131467274257, 44.375389439719065, 45.439450468335835, 48.392264638628276, 46.60641431808472, 46.57127727781023, 35.85686322620937, 34.05512237548828, 35.83099160875593, 35.421357086726594, 34.29931334086827, 35.463317258017405, 35.5690028326852, 35.43189055579049, 34.55652870450701, 32.71462031773159, 38.445056779044016, 42.357337270464214, 42.374516691480366, 40.56915930339268, 32.4890262058803, 33.352037634168354, 34.14486878258841, 34.374044690813335, 35.327667576926096, 33.65665013449532, 32.9619379724775, 34.67988702229091, 34.07021386282784, 34.19332204546247, 34.1162109375, 34.7260855947222, 32.87320947647095, 35.900008065359934, 44.9660210609436, 46.770756585257395, 44.82940558024815, 42.497937543051584, 35.38081782204764, 34.50021702902657, 35.00572974341256, 33.033744130815776, 33.637153489249094, 36.054747922079905, 33.301899433135986, 36.061435563223704, 34.013474873134065, 35.33653000422886, 36.705450194222585, 36.93629019601004, 37.29491451808384, 38.24602910450527, 39.74788222994123, 38.422245843069895, 38.496848651341026, 42.2390650340489, 44.923908029283794, 44.95660972595215, 44.599722453526084, 46.30862842287336, 45.761412620544434, 45.503033433641704, 46.6669157573155, 49.41228798457554, 48.992964199611116, 49.080730370112825, 47.51085785457066, 50.111794403621126, 48.89854860305786, 45.647312777382986, 42.22229903084891, 39.80026469911848, 38.37911490031651, 40.74351045063564, 41.72676740373884, 46.32572793960571, 53.01056548527309, 56.319603375026155, 56.14240346636091, 57.73918635504586, 57.06452669416155, 60.129516056605745, 46.8425418989999, 56.59473466873169, 8.49121458189828, 0.4751220537083489, 0.52452944538423, 0.8825024824057306, 0.12969415209123067, 41.00577368055071, 68.00571605137416, 57.85035753250122, 65.76951476505825, 64.69646971566337, 51.852828843253, 35.37053448813302, 23.0559172970908, 41.444861616407124, 67.50107533591134, 22.164128167288645, 0.2398683444729873, 0.024235920581434454, 0.035891506754394085, 0.05153368632974369, 0.08959537199033157, 0.055131608088101657, 0.21087362031851495, 0.19255519684936317, 0.20072622410953045, 0.32316549335207256, 0.1380638951169593, 0.2353029708777155, 0.13374568468758039, 0.2285223975777626, 1.7774733986173357, 63.91982092176165, 65.6951551437378, 51.41935852595738, 32.55775431224278, 24.14187731061663, 50.975830691201345, 57.93445158004761, 65.28916495186942, 61.646571840558735, 65.30909933362688, 47.6427172933306, 0.3461688889988831, 0.7662903325898307, 3.637833595275879, 0.44751582933323725, 19.46693822315761, 70.77515683855329, 55.71770872388567, 67.64240169525146, 57.363941941942485, 57.4880576133728, 52.735837187085835, 56.884940079280305, 54.536897114345, 55.66845989227295, 51.15335716520037, 54.88947302954537, 51.793682302747456, 52.519331318991526, 45.50417988640921, 39.22434936250959, 36.67074394226074, 39.269894804273335, 40.04091555731637, 40.052678857530864, 40.75425583975655, 37.83179487500872, 40.063486780439106, 39.0826130594526, 39.50153732299805, 42.3975499698094, 42.34552880695888, 44.70366055624825, 46.15467371259417, 45.86253670283726, 42.321133681706016, 44.158358982631135, 39.355114459991455, 38.71818699155535, 36.62633105686733, 36.97614853722708, 36.12717941829136, 35.73183386666434, 35.82568318503243, 34.533387729099815, 37.865639550345286, 36.00223691122872, 35.663067545209614, 39.842252663203645, 38.4207033429827, 39.96371412277222, 41.703942571367534, 47.13192394801548, 47.001763343811035, 50.26003074645996, 49.90919882910592, 48.78374004364014, 36.04228980200631, 34.02142013822283, 37.01861940111433, 36.53759561266218, 35.483835288456504, 37.491503374917166, 35.4218156678336, 35.721602644239155, 34.612986292157856, 33.14398077556065, 39.261223452431814, 44.08159875869751, 44.97250025612967, 43.36288751874651, 33.77177136284964, 34.89460025514875, 35.79602827344622, 34.466553006853374, 34.74943849018642, 33.76148802893502, 32.89371361051287, 35.17777061462402, 35.0455116544451, 34.06124026434762, 34.48199190412249, 34.78645501817976, 34.34213508878435, 38.61836222239903, 47.365077699933735, 50.03794200079781, 47.54112420763288, 46.01565415518624, 38.032538754599436, 37.17293541772025, 38.06613676888602, 35.60868399483817, 36.729768889290945, 37.721044063568115, 36.23657185690743, 38.231840882982524, 35.87888554164341, 37.366408007485525, 38.72422497613089, 38.89002636500767, 39.41860709871565, 39.57655354908535, 40.428958552224294, 40.00682074683053, 40.6743654523577, 44.91154718399048, 48.53155517578125, 47.76280300957816, 47.03439903259277, 48.13065453938076, 47.64168201174055, 46.35483741760254, 49.431009905678884, 51.69602189745222, 51.32943146569388, 51.77375486918858, 50.045414788382395, 53.45324911390032, 52.584543636866975, 48.08281619208199, 44.070481640951975, 41.52090270178658, 41.19360433306013, 42.79088749204363, 47.20114190237862, 48.53403220857893, 55.51703780038016, 59.05988952091762, 57.22559983389718, 59.0631343296596, 59.6589423588344, 57.80823755264282, 46.83941868373326, 61.17292703901018, 14.555842893464224, 0.42167800292372704, 2.4560503235885074, 1.3792514013392585, 0.2275473020438637, 45.80946288790022, 73.80925451006208, 63.7640631539481, 73.54394449506486, 67.65330341884068, 62.55775165557861, 53.18083803994315, 32.57073354721069, 51.1418822152274, 74.86811828613281, 32.503238746098106, 0.36017838439771105, 0.21254671125539712, 0.11953626573085785, 0.09675504959055356, 0.14999148223016942, 0.12954403300370487], [0.03710427614195006, 0.018246329123420373, 0.091526774423463, 0.09177601390651294, 0.020093954534136822, 0.01834157508398805, 0.01978823379613459, 0.0465835562374975, 0.19968471356800624, 35.263935225350515, 58.859058788844514, 37.7169064113072, 28.887067896979197, 19.037845270974294, 34.498271533421104, 44.755494117736816, 53.31631054197039, 53.31951713562012, 52.749316692352295, 47.87310913630894, 1.3515359056847436, 0.324323372649295, 0.37600667934332577, 0.16039434687367507, 23.276923860822404, 67.24156706673759, 51.428172315870015, 55.66915818623134, 50.096334661756245, 54.72350140980312, 53.38279438018799, 53.320903301239014, 51.26099170957293, 50.02585560934884, 49.72758681433541, 48.564291613442556, 44.231078829084126, 39.453521796635215, 34.90419919150216, 35.42028706414359, 34.348979064396445, 35.638550826481406, 37.694957051958355, 34.80075093678066, 34.205363273620605, 34.87840747833252, 34.59659549168178, 34.13732303891863, 33.403360503060476, 33.46127026421683, 36.31046942302159, 37.08644771575928, 37.265110220227925, 40.91344601767403, 37.0117997441973, 34.85454041617257, 35.082809584481375, 34.52312176568167, 33.61327600479126, 34.24646186828613, 34.80439179284232, 34.453545979091096, 32.4803409576416, 32.825805391584126, 33.30400126320975, 33.57016243253435, 33.240876879010884, 35.956833907536094, 34.8543632371085, 33.918642384665354, 32.93457249232701, 38.03722184044974, 43.13958631243025, 43.994607312338694, 45.966926438467844, 46.005068574632915, 39.253309454236714, 34.66402428490775, 34.60685798100063, 34.874999386923655, 35.52520138876778, 36.67836611611502, 35.45617798396519, 36.650868620191304, 33.98905542918614, 32.43658120291573, 33.70318916865757, 40.09806101662772, 38.20042807715279, 37.58350447246006, 32.198212827954976, 32.10946348735264, 34.27796500069754, 34.50664758682251, 33.17344461168562, 34.574291774204795, 33.31294012069702, 33.67363848005022, 33.63252598898751, 33.31749813897269, 33.79129580089024, 34.602814129420686, 33.76758507319859, 39.190522057669504, 41.91910743713379, 44.60372461591448, 41.71051556723458, 45.69516849517822, 41.2824752671378, 35.21917840412685, 31.746520859854563, 33.50047894886562, 32.653500488826204, 32.47421612058367, 33.63939775739397, 32.78980677468436, 33.2232597214835, 33.957701683044434, 35.73973396846226, 36.59420953478132, 35.68537821088518, 35.041012695857454, 34.5115703855242, 35.71743719918387, 38.24741874422346, 41.53782156535557, 41.33557340076992, 43.14064243861607, 42.48284605571202, 41.077079568590435, 41.44062668936593, 42.983310903821675, 41.84709283283779, 43.411142757960725, 44.45754146575928, 44.662332671029226, 42.97237096514021, 45.825780732291086, 43.84364032745361, 43.67923552649361, 38.81901230130877, 39.92720481327602, 38.28322281156267, 37.213210650852744, 39.52851022992815, 45.2879067829677, 52.229935373578755, 55.367175579071045, 52.969508579799104, 60.19417599269322, 51.644282136644634, 62.052923338753835, 59.4532687323434, 59.75470243181501, 8.218173827443804, 0.5512673620666776, 0.13937840743788651, 0.8068073413201741, 0.15057713937546524, 36.789624146052766, 64.01971517290387, 51.05514785221645, 67.54308414459229, 54.28286402566092, 59.545443534851074, 53.81642798015049, 24.773954936436244, 40.63465649741036, 57.29203156062535, 18.03180864879063, 0.2634986793356282, 0.09951281268149614, 0.04232326555731041, 0.033209681910063536, 0.01754518022893795, 0.06930109525897674, 0.023910905700176954, 0.02483956908274974, 0.0510843638330698, 0.050303251282977204, 0.02135869291877108, 0.015393642376043966, 0.01625000954871731, 0.03484443561839206, 0.52690361227308, 44.9169876234872, 64.55519199371338, 43.2844249861581, 31.79888595853533, 23.235505649021693, 45.783125741141184, 46.65592023304531, 58.59660448346819, 58.36805043901716, 58.11700854982649, 51.66880580357143, 1.4073554532868522, 0.4084912176643099, 0.4821530335715839, 0.13532683412943566, 24.182678869792394, 68.48851857866559, 53.444918223789756, 58.89347321646554, 52.09423358099801, 58.21367883682251, 55.06592600686209, 54.9585485458374, 51.953334535871235, 51.58380849020821, 51.213834285736084, 51.36963374274117, 47.14388179779053, 40.17560986110142, 35.87631123406546, 36.28948586327689, 37.16176618848528, 36.59396287373134, 39.79345546449934, 37.921892166137695, 35.95524277005877, 37.59559781210763, 36.97409534454346, 36.195285660879954, 35.728571687425884, 36.38614920207432, 39.00301797049386, 38.865575654166086, 40.36932911191668, 41.66463313783918, 39.37404135295323, 37.38724218096052, 37.519911084856304, 36.3020829473223, 35.34597955431257, 35.58356973103115, 35.72613286972046, 34.08128581728254, 34.14916624341692, 34.22784764426095, 33.58236346926008, 36.36274072102138, 34.70751305988857, 38.3303941317967, 36.99732664653233, 36.08144637516567, 34.620573725019185, 40.165555817740305, 43.74509055273873, 45.84774398803711, 47.05167920248849, 46.39877782549177, 40.470908301217214, 34.97491100856236, 35.7954272542681, 34.57599755695888, 35.28539473669869, 35.510499000549316, 35.52913754326956, 35.03553056716919, 35.21228926522391, 32.973527567727224, 35.21228926522391, 43.26698153359549, 41.243044240134104, 40.40427507672991, 33.88656949996948, 32.806253160749165, 33.830035482134136, 33.96987840107509, 34.2023686000279, 34.23013360159737, 34.83213594981602, 34.209591252463206, 34.07780129568917, 33.96719292231968, 33.39992461885725, 34.43028341020857, 33.998133250645225, 39.95479958398001, 44.19184235164097, 47.541006088256836, 45.215979031154085, 48.33524077279227, 41.93409122739519, 37.400322164808, 35.151728766305105, 34.1879232951573, 34.90426867348807, 34.77630370003836, 35.73088543755667, 34.73190818514143, 34.57002905436924, 35.83148145675659, 37.42855616978237, 37.201714856284006, 36.679467405591694, 37.212182317461284, 36.34603030341012, 36.92606939588274, 39.83540521349226, 44.30035236903599, 44.66283988952637, 44.9998379434858, 45.206425258091514, 41.47479445593697, 43.15052277701241, 43.62323651994978, 45.433996132441926, 46.10519906452724, 47.04030500139509, 48.51156868253435, 47.07840544836861, 47.55276938847133, 46.8751254762922, 46.188268252781455, 41.23481409890311, 41.52856656483242, 39.90050288609096, 39.30429533549717, 41.49600730623518, 47.71453039986746, 53.99253702163696, 57.3923704964774, 54.87011534827096, 60.44410269601004, 54.56835855756487, 64.2837050301688, 61.23104177202497, 62.71482263292585, 11.467159305300031, 0.4362981526979378, 0.36127261711018427, 0.6831023735659463, 0.31000017694064547, 40.19203192847115, 70.45773533412388, 56.478244645254954, 73.17145156860352, 59.43754495893206, 62.696389062064036, 48.28849676677159, 25.702533040727886, 48.01804508481707, 66.3485220500401, 24.124986239842006, 0.3091288836938994, 0.03472967499068805, 0.0737409738025495, 0.0030027918401174247, 0.03775727788784674, 0.013185300115895058, 0.09185501573873417, 0.11722999305597373, 0.17545037397316524, 0.25443109018462046, 0.0886426545413477, 0.14757732248732022, 0.130333277795996, 0.13719614382301057, 0.7052668013742992, 50.8474314553397, 73.92426109313965, 50.216875485011506, 40.94879845210484, 28.427512305123464, 49.411502838134766, 53.104122979300364, 64.20268208639962, 62.90489755358015, 62.73346464974539, 56.43927219935826, 1.9732200035027094, 1.0043447358267648, 2.1071022365774428, 0.2747756599315575, 26.768108776637487, 69.40502766200474, 54.59767300742013, 59.768355642046245, 54.306963852473665, 59.17221409933907, 58.29649094172886, 57.344108309064595, 54.094786712101524, 52.31153154373169, 53.8699951171875, 52.11565835135323, 50.93086889811924, 43.01447010040283, 39.933440821511404, 38.3567590713501, 39.75721018654959, 39.56162881851196, 43.958410671779085, 40.20174898420061, 40.269007546561106, 40.789733341761995, 40.80741303307669, 38.735804149082725, 38.05819845199585, 37.77758502960205, 42.41271788733346, 40.931876114436555, 41.199353967394146, 44.81427935191563, 40.70554896763393, 40.254864488329204, 41.004766191755024, 39.31867463248116, 38.44990314756121, 37.2548303604126, 38.12024586541312, 36.51532316207886, 36.14691230228969, 35.688320772988455, 35.71576268332345, 37.80265065601894, 36.13809156417847, 40.27685553686959, 39.31889350073678, 38.58792911257063, 36.09226124627249, 41.88126059940883, 46.22303009033203, 47.36175298690796, 49.151271956307546, 47.90584904806954, 40.53651666641235, 35.323463916778564, 34.87117092950003, 34.439045088631765, 35.73065962110247, 35.12216418130057, 35.243712493351524, 35.37197971343994, 35.209617682865684, 33.812637192862375, 37.05343682425362, 45.90990604673113, 44.30465677806309, 41.08091150011335, 33.98127692086356, 32.736149311065674, 35.20879432133266, 35.10567610604422, 34.56807313646589, 36.01041841506958, 34.309329169137136, 34.564439228602815, 34.63964653015137, 33.84994554519653, 33.96200609207153, 34.826275144304546, 35.0817152432033, 42.47627305984497, 45.61659479141235, 48.98080137797764, 47.57833875928606, 49.86557109015328, 43.96994120734078, 40.054728576115195, 36.48161397661482, 36.475704533713206, 35.947641440800254, 35.8229421206883, 38.1962765284947, 36.05232994897025, 36.05192000525338, 37.51118762152535, 38.55106544494629, 39.68376425334385, 39.61928844451904, 39.029153619493755, 37.93640347889492, 39.70497015544346, 42.76289667401995, 45.98591586521694, 45.343603542872835, 46.929112979343955, 49.69687230246407, 44.367378166743684, 46.32640886306763, 47.88513994216919, 47.297777448381694, 46.928032534463064, 49.54968861171177, 48.85153709139143, 49.01437507356916, 50.05929381506783, 49.125296115875244, 48.89592218399048, 42.735454763684956, 43.846881662096294, 41.68299722671509, 40.598008223942344, 43.25868191037859, 49.46338503701346, 55.88496576036726, 59.904880796160015, 56.718075616019114, 63.06307329450335, 56.1316476549421, 66.22443417140416, 61.67782483782087, 66.80178083692277, 17.745843376432145, 0.42167884430715014, 1.8889993684632438, 1.842598864010402, 0.47289434181792395, 43.36248452322823, 76.81890147072929, 60.74678012302944, 79.24949250902448, 63.88725471496582, 74.3816054207938, 65.96337645394462, 37.33570739201137, 56.01430300303868, 78.46968228476388, 32.28771604810442, 0.3716740704008511, 0.21718220465949603, 0.1647575848868915, 0.07762501002954585, 0.08311532185013805, 0.13350704392152174], [0.03314972994849086, 0.013304470373051507, 0.026537645375356078, 0.0419334912938731, 0.07332651104245867, 0.08196945262274571, 0.058595542929002216, 0.09462591526763779, 0.014957854956654566, 31.025263105119976, 56.382081576756065, 42.8421756199428, 28.023611783981323, 26.745183195386613, 35.02989905221121, 52.809814657483784, 55.20475101470947, 55.16962787083217, 50.95756040300642, 55.84856414794922, 5.417768393244062, 0.6598910476480211, 0.5082044899463654, 0.07503955412123885, 25.27986022404262, 64.75890622820172, 51.48665182931082, 51.819817951747346, 44.669395514896934, 49.29599598475865, 51.90488822119576, 52.7845127923148, 51.59723935808454, 48.313697883060996, 46.25065960202898, 42.06516899381365, 36.32586315699986, 35.76280893598284, 35.40145397186279, 36.28435114451817, 33.490577765873496, 35.09687968662807, 34.24173361914498, 34.1960631098066, 33.77461665017264, 33.156859261649, 33.854576519557405, 35.090004444122314, 33.23326512745449, 32.438248770577566, 34.517493724823, 35.74018212727138, 34.94114623750959, 37.22990369796753, 36.30799239022391, 34.46183170591082, 34.95351750510079, 33.5996401650565, 34.14151627676827, 34.384147371564595, 35.67010259628296, 33.444896834237234, 34.59040812083653, 34.32404545375279, 35.62122549329485, 34.76163952691214, 34.804954596928184, 33.50033303669521, 33.59758349827358, 33.342525550297324, 33.930381366184776, 37.35472461155483, 42.54623099735805, 44.436377252851216, 46.089791434151785, 46.73655407769339, 42.14164434160505, 34.03721686771938, 33.58520180838448, 35.94225311279297, 35.652433327266145, 34.22294569015503, 34.269248485565186, 33.61405767713274, 34.757571356637136, 33.1487090247018, 34.198109354291645, 39.01363829204014, 39.65019403185163, 37.770404066358296, 33.13965899603707, 34.04639196395874, 35.13196461541312, 33.94979463304792, 34.9742648260934, 33.75001655306135, 33.61458921432495, 34.35961675643921, 34.67881005150931, 33.32395648956299, 34.35289090020316, 33.360090596335276, 32.660413946424214, 39.684608459472656, 45.61199508394514, 43.622100489480154, 44.563914912087576, 43.87670333044869, 36.602359771728516, 34.74710042136056, 33.906688008989605, 33.736540521894185, 34.315853527614046, 33.281162534441265, 33.331054074423655, 33.39557157244001, 33.50905302592686, 32.97302034923008, 33.41168791907174, 36.35456269127982, 34.71465580804007, 34.52435507093157, 35.771181515284944, 36.082144669124055, 37.29790224347796, 39.90929930550711, 39.92871604646955, 40.41277967180525, 40.37963329042707, 39.920468534742085, 40.011364868709016, 41.19592503138951, 42.278523853846956, 42.58738170351301, 42.49943835394723, 41.43666621616909, 39.7020206451416, 41.532732009887695, 40.29589360100882, 41.765368121010916, 38.42414270128523, 39.81517205919538, 38.57888950620379, 41.97575262614659, 40.842299938201904, 46.8008005959647, 53.4229862349374, 56.35743979045323, 52.584998743874685, 55.55300862448556, 51.89485502243042, 55.60258402143206, 52.58205965587071, 62.61435168130057, 15.116019691739764, 0.5379490767206464, 0.31349509369049755, 0.7974057229501861, 0.3945024311542511, 42.40972668784005, 62.49626704624721, 53.132120745522634, 61.82588400159563, 57.56467539923531, 50.07949570247105, 28.159103393554688, 26.36187366076878, 41.11721931185041, 57.287306785583496, 13.568502136639186, 0.20071903163833277, 0.036133831965604, 0.05696557967790535, 0.025428861479407976, 0.09733217755066496, 0.003853744303341955, 0.025736622911478792, 0.007305993498968226, 0.05246498242818883, 0.10496079748762505, 0.09115975483187608, 0.05220362091703074, 0.019934186678645865, 0.0868344401408519, 0.09336557718259947, 35.84183079855782, 65.19844927106584, 50.318173272269114, 30.777872494288854, 27.303750617163523, 43.47469098227364, 55.142693178994314, 60.47846153804234, 59.12095029013497, 55.04557820728847, 59.56800433567592, 6.1466934851237705, 0.6144820728472301, 0.20919263123401574, 0.1466544470084565, 27.69698565346854, 66.17212813241142, 53.70788322176252, 53.46127775737217, 46.30869790485927, 51.512189933231895, 53.665850094386506, 53.75705214909145, 54.06453078133719, 50.70077582768032, 47.93052904946463, 43.121069363185335, 39.60662535258702, 36.94038268498012, 37.440976074763704, 36.41638776234218, 36.08976336887905, 35.52563565117972, 35.59453746250698, 36.67747327259609, 34.8808845111302, 34.93655695234026, 35.84287650244576, 36.31519419806344, 35.893098081861226, 35.526740414755686, 36.71799169267927, 38.38740757533482, 37.73639610835484, 39.21848855699812, 37.42079850605556, 37.37024688720703, 36.41622795377459, 35.845589773995535, 34.52143682752337, 34.473970208849224, 36.09703813280378, 34.20764923095703, 35.2921518598284, 35.55060052871704, 35.82834781919207, 35.816587993076865, 36.422853061131065, 35.61775834219796, 34.31251491819109, 35.4848427772522, 34.75388881138393, 38.69136347089495, 44.41907623835972, 46.965379101889475, 47.917577607291086, 47.948875767844065, 43.1326276915414, 34.12334673745291, 34.200930322919575, 35.03717381613595, 35.00250230516706, 34.95352792739868, 35.34571552276611, 34.22046170915876, 34.87591307503836, 34.513057300022666, 34.91767522266933, 40.24421984808785, 42.088351658412385, 38.671053886413574, 33.22932202475411, 35.06557805197579, 34.90323339189802, 34.704448904309956, 34.79616859980992, 34.73241540363857, 33.77036782673427, 34.240812982831685, 34.41197143282209, 33.802930559430806, 33.20156397138323, 33.66405691419329, 34.735420499529155, 42.09484822409493, 48.20110232489449, 45.294375555855886, 45.64065987723214, 44.82862043380737, 38.50776774542672, 36.2974728175572, 35.12587799344744, 34.15228598458426, 35.410761083875386, 34.44956118719918, 34.8890312739781, 35.22186388288225, 34.349003383091514, 34.6893435205732, 36.666234561375205, 36.92322758265904, 35.70220674787249, 37.2587491444179, 36.59084660666329, 36.99172987256731, 39.71935987472534, 41.36986970901489, 41.60582358496529, 41.93788146972656, 41.572434016636436, 42.025307178497314, 41.87062985556466, 44.16785022190639, 43.85195732116699, 44.91853012357439, 44.330917494637625, 43.55444587979998, 42.018463202885215, 42.449459961482454, 42.0834253856114, 42.81707525253296, 39.83858054024832, 42.299635955265586, 39.97255570547921, 44.32213497161865, 41.57731860024588, 49.70927136284964, 56.24411467143467, 57.143406118665425, 54.24382209777832, 58.433106422424316, 56.33245406832014, 59.001211983816965, 54.46270077569144, 66.73211124965123, 18.219378743852886, 0.5331009711538042, 0.4291225363101278, 0.7146471408861024, 0.44800855432237896, 45.26775005885533, 68.90210315159389, 56.93301466533116, 69.44838442121232, 62.5461551121303, 57.33242491313389, 36.21847527367728, 29.73652512686593, 46.08019944599697, 65.57815442766461, 18.62282763208662, 0.19251831168574945, 0.0667647992127708, 0.05677431761952383, 0.03052590967022947, 0.04835865812908326, 0.056864064053765366, 0.1302364237074341, 0.13642802861120018, 0.14055755202259335, 0.22918364352413587, 0.3049424854772431, 0.23818565905094147, 0.10377038243625845, 0.2084405565900462, 0.1692929808050394, 40.03426265716553, 74.58855056762695, 56.04009471620832, 38.39129856654576, 36.65017032623291, 49.25613764354161, 61.62251022883824, 65.87655871255058, 63.019167627607075, 60.53123310634068, 65.31312928880963, 6.986600416047232, 1.1492056655032294, 0.8263158202171326, 0.17938572780362197, 30.617410796029226, 67.22186892373222, 55.07084880556379, 56.38310991014753, 48.397743293217246, 53.964188371385845, 56.118626730782644, 56.4893478666033, 58.25905057362148, 52.31925446646554, 49.59300715582711, 44.81636381149292, 40.23448889596121, 38.629163197108674, 39.516823359898154, 38.92799827030727, 36.71831130981445, 37.76944521495274, 36.911426067352295, 39.33853605815342, 37.52874224526541, 36.69927671977452, 38.76055710656302, 39.48336430958339, 36.951437268938335, 37.09303460802351, 40.03184468405587, 39.35042095184326, 39.64778995513916, 42.88397250856672, 39.82629265104021, 39.264996324266704, 41.196223803928916, 38.54102182388306, 37.723555837358745, 36.255741936819895, 38.92667463847569, 37.78564146586827, 37.33470337731497, 37.29268067223685, 38.03760746547154, 37.797964096069336, 39.2975104195731, 36.88521746226719, 36.08073418481009, 36.25264304024832, 38.66171203340803, 40.37524202891758, 46.16815669195992, 48.8958283833095, 49.87460374832153, 50.83468845912388, 43.49954121453421, 34.93009512765067, 33.46890980856759, 35.01298018864223, 34.46340894699097, 34.961007663181846, 36.42850889478411, 33.61795909064156, 35.55538783754621, 35.73729167665754, 36.15660156522478, 42.181916100638254, 45.92554644175938, 40.851415974753245, 34.225179536002024, 35.72623014450073, 36.78381545203072, 34.30355174200875, 34.87559693200247, 35.66487060274397, 34.47792373384748, 34.99704449517386, 35.8294734273638, 33.80274643216814, 32.99911083493914, 34.62078217097691, 34.75581693649292, 44.59428548812866, 51.60123109817505, 46.50036743709019, 48.56767538615635, 49.02320623397827, 41.83551018578665, 37.39132077353341, 37.46197700500488, 35.670602866581504, 38.726389339991975, 36.517584800720215, 36.39443492889404, 36.95345572062901, 36.3164518220084, 37.0018117087228, 36.97023562022618, 40.68683399472918, 38.851578508104595, 39.798743043627056, 40.593088899339946, 39.13412005560738, 42.541808468954905, 43.11895016261509, 43.18543400083269, 45.53277172361101, 44.5980236189706, 43.417298861912315, 44.3240943636213, 45.059227670942036, 45.7638966015407, 47.38750648498535, 45.39200816835676, 45.33769409997122, 43.65175192696707, 45.69771153586251, 44.87767818995884, 47.03211307525635, 42.12760203225272, 44.25810384750366, 42.36285414014544, 46.893920353480745, 45.0550274848938, 51.33354479925973, 58.69471999577114, 61.54548944745745, 57.20848989486694, 59.32656833103725, 58.96278844560896, 60.469505310058594, 60.230952807835166, 70.42399488176618, 23.534087112971715, 0.5410258259092058, 2.476648041180202, 1.7442831567355563, 0.5068682102220399, 51.947828088487896, 72.98098754882812, 62.18641907828194, 72.87994684491838, 68.37797273908342, 64.86839594159807, 39.85736152103969, 40.510704108646934, 55.38520962851388, 76.37129851749965, 26.844330515180314, 0.37514795256512506, 0.1687753400100129, 0.13217018065708025, 0.1496691373842103, 0.15177708784384386, 0.1141965344016041], [0.07428185442196471, 0.05376086896285415, 0.05258191776062761, 0.021547337528318167, 0.03655401138322694, 0.0165985763804721, 0.0296708334104291, 0.07721620625151054, 0.058146481668310504, 21.489327805382864, 60.74887153080532, 39.47940731048584, 32.975612027304514, 22.83223741395133, 30.976069859095983, 52.27674191338675, 55.11758238928658, 54.453053201947895, 50.27449689592634, 56.50413015910557, 11.752550482749939, 0.7754852420517376, 0.504706723349435, 0.27010324065174374, 17.149672303880962, 68.06198951176235, 53.803525175367085, 53.353910718645366, 41.26954466956002, 41.880121094839915, 41.77766990661621, 45.87437990733555, 43.78589037486485, 41.19486543110439, 38.02422523498535, 37.00239188330514, 35.75760473523821, 35.865690912519185, 32.790181977408274, 34.85696881158011, 33.80521304266793, 34.49137544631958, 34.50241960797991, 33.52095529011318, 33.123150076184956, 34.38363320486886, 32.70318010875157, 33.19386536734444, 33.78198174067906, 33.86205972943987, 34.49422073364258, 33.597045012882774, 34.027548449380056, 33.39606836863926, 33.47061906542097, 34.24424191883632, 33.96913841792515, 33.41965750285557, 33.87753684180123, 35.14347430637905, 35.35955286026001, 34.66750880650112, 33.16340446472168, 33.78280857631138, 34.60956083025251, 34.02809040887015, 33.194289207458496, 34.36021430151803, 35.0492011478969, 34.20020423616682, 34.77482373373849, 36.04250519616263, 43.920226846422466, 43.55422353744507, 44.49274451392037, 46.01014770780291, 42.23162351335798, 36.33546209335327, 35.501261370522634, 34.605944292885916, 34.68080071040562, 36.32299355098179, 36.186489241463796, 34.79566832951137, 34.96669823782784, 33.60783209119524, 34.37825182506016, 39.36733981541225, 40.258859702519004, 38.62294108527047, 32.08602026530674, 33.87862076078142, 33.833019733428955, 33.85645948137556, 33.79006596973964, 34.198133672986714, 34.86050544466291, 35.17136090142386, 32.24170160293579, 34.063505377088276, 32.33387640544346, 35.01716995239258, 37.27269765308925, 42.6314263343811, 44.3913459777832, 43.00026103428432, 41.30154112407139, 43.71594980784825, 38.708108629499165, 30.672582966940745, 32.09590407780239, 32.109981128147666, 32.96847970145089, 33.92244304929461, 32.92507430485317, 32.90040125165667, 33.67430203301566, 34.50459092003958, 33.27432550702776, 34.36387252807617, 34.08653170721871, 35.17621421813965, 35.5832188470023, 33.05300453730992, 37.366331577301025, 37.54348284857613, 37.77689715794155, 39.113911220005576, 39.09565135410854, 36.414563860212056, 37.47660296303885, 38.94113731384277, 39.66457680293492, 40.09663316181728, 39.82717159816197, 37.95603561401367, 38.3279379435948, 38.32883773531233, 36.09355361121041, 37.82958534785679, 33.99120242255074, 38.99927289145333, 37.03435012272426, 39.272166865212576, 37.7346625328064, 42.84668847492763, 49.9777740750994, 55.58527953284127, 51.66189234597342, 54.670125348227366, 46.3633246421814, 55.145198004586355, 51.49760913848877, 64.85579885755266, 17.802940198353358, 0.47950642130204607, 0.19035571201571397, 0.761471865432603, 0.6624220918331827, 45.440444060734336, 60.535756383623394, 52.183431080409456, 64.82749884469169, 57.084672995976035, 45.938817501068115, 18.157155888421194, 34.499351978302, 46.42155054637364, 51.73593929835728, 7.6654941354479105, 0.33205503491418703, 0.039765941710876565, 0.06859674876821892, 0.04764500892321978, 0.040691035999251265, 0.03884140382121716, 0.03979939687997103, 0.07868355858538832, 0.040203905531338284, 0.02059090679644474, 0.04101887697886143, 0.07811876639191594, 0.06804220923887831, 0.10207867249846458, 0.12801693566143513, 26.110142162867955, 67.33333192552838, 43.28916365759713, 31.532457283564977, 22.856629065104894, 40.37659345354353, 57.46159539903913, 60.58187852587019, 59.228369440351216, 54.6563401222229, 61.11413138253348, 12.901794689042227, 1.0200656865324293, 0.09611658885010652, 0.38119994210345404, 18.927322013037546, 68.93549619402204, 55.68807118279593, 55.89154570443289, 43.31857190813337, 43.30454349517822, 43.589318888528005, 46.55696051461356, 44.977485588618684, 42.70686987468174, 40.529992307935444, 38.94640404837472, 37.11784315109253, 37.380196707589285, 35.7452369417463, 35.969285079411094, 36.78938095910208, 35.70255068370274, 36.38583305903843, 36.13859530857631, 35.841688360486714, 35.91293518883841, 34.96079921722412, 35.84947381700788, 36.82030739103045, 36.357665061950684, 36.88054132461548, 34.74631527491978, 35.8131034714835, 34.9918646131243, 35.10798290797642, 36.14552961077009, 36.69602148873465, 35.929920060294016, 35.43089001519339, 36.29045166288103, 35.870269775390625, 34.217237745012554, 35.67894070489066, 34.583880288260325, 35.27588612692696, 36.333176136016846, 33.28822190420968, 35.023134980882915, 35.81734882082258, 35.284901414598735, 35.81478146144322, 39.171897411346436, 45.080621174403596, 47.31935855320522, 46.266320841653005, 47.73279026576451, 42.62943567548479, 35.54708126613072, 35.855887004307334, 34.63124615805489, 35.32396418707711, 35.48270968028477, 35.7545405796596, 35.60376814433506, 33.706440925598145, 35.131037030901226, 35.07815081732613, 40.914703641619, 44.24376971381051, 40.49473714828491, 33.85700144086565, 34.1019150188991, 34.6460770879473, 34.94473498208182, 34.10693161828177, 34.287692478724885, 34.90383441107613, 35.36787680217198, 33.57188211168562, 34.576848711286274, 32.83410154070173, 34.600215503147666, 37.33638136727469, 45.001522881644114, 47.39803300585066, 46.17276682172503, 44.08157096590315, 45.96998017174857, 39.879984855651855, 31.042049952915736, 33.10515424183437, 33.632539885384695, 34.78836577279227, 34.27418518066406, 33.585351194654194, 34.37800516401018, 35.30266101019723, 36.078389167785645, 34.75532014029366, 36.19650854383196, 35.72073064531599, 35.71345935549055, 36.2895553452628, 35.59757382529122, 38.91154146194458, 39.96736192703247, 39.53480877195086, 40.925730432782856, 40.4429418018886, 39.08672986711775, 38.94929102488926, 40.10316446849278, 41.00266783578055, 42.1960244178772, 41.03465039389474, 39.35490253993443, 40.551455293382915, 39.05828741618565, 37.65383413859776, 38.73185409818377, 36.62684522356306, 41.17961413519723, 40.101472582135884, 41.73354884556362, 40.47889872959682, 43.959577969142366, 52.70922211238316, 57.800504207611084, 53.157537255968364, 55.04095070702689, 49.14115537915911, 56.93351493562971, 54.439417362213135, 69.19296864100865, 18.999637126922607, 0.5293653916035379, 0.8036142098052161, 0.9348813146352768, 0.7427325195499829, 48.66255651201521, 67.0982118334089, 55.65463992527553, 71.17715876443046, 59.83969974517822, 55.95152602876936, 21.746697766440256, 38.10994168690273, 53.09190804617745, 61.456913811819895, 11.399400472640991, 0.47359089872666765, 0.08457010093012027, 0.05588854104280472, 0.042943575486008606, 0.05114007834345102, 0.026067254366353154, 0.21206575206347875, 0.13882977116320813, 0.144551083445549, 0.12771379335650376, 0.0922669136364545, 0.1357611643948725, 0.13904885655002935, 0.33978634434086935, 0.21677018462547235, 28.607790265764507, 78.07781778063092, 52.056046281542095, 44.28802279063633, 33.52171264375959, 41.88837555476597, 62.61903476715088, 64.26962797982353, 63.42854854038784, 58.76710632869175, 66.20762647901262, 15.3457236630576, 1.4149960832936423, 0.44523277612669127, 0.4424566179513931, 19.737153666360037, 71.61555535452706, 57.213284151894705, 57.91079643794468, 45.78520325251988, 45.95901591437203, 46.063096455165315, 49.225040980747764, 45.792936597551616, 45.13991362707955, 42.993351050785606, 40.4017459324428, 39.88244799205235, 40.44227477482387, 37.03515263966152, 37.879720074789866, 38.191461426871165, 39.813414164951865, 38.16324826649257, 37.85077040536063, 37.67728778294155, 39.25235060283116, 36.60566364015852, 37.219721112932476, 39.956053733825684, 39.12657083783831, 40.04167291096279, 37.0202522277832, 38.85239144733974, 37.551167556217735, 38.389849867139546, 38.221105916159495, 40.08714887074062, 38.0067400932312, 37.394808769226074, 37.96833739961897, 37.73713609150478, 36.60748059409005, 36.22509690693447, 37.64331109183175, 37.202684129987446, 37.35762201036726, 35.83451434544155, 36.67688267571585, 37.72394493647984, 37.34439264025007, 38.76782839638846, 40.75150782721383, 48.06435830252511, 49.05910062789917, 47.868596281324116, 49.923473903111045, 44.17217894962856, 37.40398039136614, 36.768185479300364, 33.96569905962263, 34.589289460863384, 35.971723897116526, 36.37387868336269, 36.53038338252476, 34.72219460351126, 36.0886447089059, 35.86428737640381, 42.72822168895176, 45.72429186957223, 40.95976965767996, 34.19690384183611, 34.90659284591675, 36.38865750176566, 36.30001238414219, 33.853701046534944, 34.126369203839985, 37.39452389308384, 35.797577721732004, 33.46715191432408, 34.87495769773211, 33.52978645052229, 35.5040545463562, 39.75812040056501, 48.7279668535505, 49.312570912497385, 48.44834354945591, 46.35660573414394, 47.38733278002058, 44.05784286771502, 33.690946442740305, 34.42449903488159, 35.71021454674857, 36.8180388041905, 36.117226123809814, 35.6554662159511, 36.84918410437447, 37.04056528636387, 38.988103662218364, 36.33980471747262, 38.161525113242014, 37.22318826402937, 38.71841280800955, 39.36640528270176, 36.25414037704468, 41.49075794219971, 41.38901547023228, 43.245358739580425, 42.36484479904175, 43.83767877306257, 41.37400736127581, 41.66050590787615, 42.46700068882534, 43.73947293417794, 44.90741647992815, 43.08457395008632, 41.44994422367641, 42.409278529030935, 42.47142669132778, 40.98619018282209, 39.992858341761995, 36.798653330121724, 43.721623011997764, 42.413308484213694, 45.35234785079956, 41.975321837833945, 45.9382130077907, 54.071190629686626, 60.62925829206194, 56.13923161370413, 59.562028884887695, 50.23782777786255, 60.41801221030099, 55.60006182534354, 71.40576839447021, 21.58703511101859, 0.5261079349688121, 1.7744906672409602, 1.477916038462094, 0.7677670419216156, 53.84365102222988, 71.34115014757428, 60.528606687273296, 76.2270817075457, 66.20377717699323, 60.106441089085166, 27.391271863664898, 49.5718811580113, 61.260008811950684, 74.76809896741594, 17.343332495008195, 0.5703777851802962, 0.14427293837070465, 0.14190220486904892, 0.16872879250773362, 0.12954984126346453, 0.0912022582654442], [0.07745864681367363, 0.056247927115431855, 0.031516027969441245, 0.03273213914196406, 0.038201799749263694, 0.1047519308381847, 0.028903939561652284, 0.08488507010042667, 0.1465651789414031, 11.419353093419756, 61.10600893838065, 50.34313120160784, 36.19444840294974, 28.874802589416504, 34.51996380942208, 49.95405292510986, 58.73041984013149, 52.908486025674, 48.5119959967477, 55.467583996909006, 20.677324840000697, 0.4159928022750786, 0.2962724364229611, 0.18824990572673933, 5.358023004872458, 61.63293252672468, 53.700400011880056, 57.300734179360525, 51.854882035936626, 41.46298599243164, 40.3526360648019, 40.51207290376936, 38.20090750285557, 37.5445876121521, 37.328463894980295, 35.31561592647007, 35.693347794669016, 35.421787875039236, 35.051132747105186, 35.320778438023154, 34.391102518354145, 34.195208481379915, 32.777772494724815, 32.555676800864084, 33.96252373286656, 34.51437398365566, 33.28983041218349, 32.59525374003819, 32.869443552834646, 33.30673885345459, 32.43532705307007, 32.32958241871425, 33.186448165348594, 32.51564128058297, 33.5743521962847, 33.67495516368321, 34.98729269845145, 33.918934209006174, 34.49638162340437, 33.73765570776803, 36.43603031975882, 33.20914445604597, 34.19779321125576, 33.823441641671316, 32.613395486559185, 35.07500328336443, 34.048188073294504, 35.85579320362636, 34.076116357530864, 34.798850604466026, 33.862525258745464, 37.69625636509487, 41.90023612976074, 43.11954075949532, 45.58539737973894, 47.03262724195208, 43.01360852377755, 37.27342026574271, 36.03375046593802, 37.606701033455984, 35.49661302566528, 35.50917189461844, 35.49633509772164, 35.21723985671997, 33.54756341661726, 34.2698529788426, 34.42159816196987, 39.55075488771711, 41.11852209908621, 38.94121374402727, 32.82185186658587, 34.01563228879656, 33.84088509423392, 35.81278385434832, 34.51621873038155, 34.71217877524239, 33.15920775277274, 32.69235134124756, 33.07544027056013, 33.93032578059605, 34.434163979121614, 33.79408202852522, 35.71901444026402, 44.32190568106515, 43.69383716583252, 43.550832816532676, 40.873695373535156, 40.807680538722444, 41.22789021900722, 37.158649921417236, 36.79020084653582, 35.212876388004844, 32.92307669775826, 31.663892882210867, 33.62435143334525, 33.19602278300694, 34.209059715270996, 33.87957613808768, 35.87012733731951, 36.05579015186855, 34.342635359082905, 34.392422676086426, 34.26387752805437, 34.20295224870954, 33.91627652304513, 35.04303114754813, 35.521765504564556, 36.200680937085835, 36.446188586098806, 37.48215804781233, 35.60734299251011, 36.889275210244314, 37.93210254396711, 37.86288111550467, 36.55885362625122, 34.195740018572124, 36.055022375924246, 36.86128439222063, 37.466847692217144, 37.29446983337402, 37.964526312691824, 37.24356385639736, 36.547882420676096, 38.25469698224749, 38.93990053449358, 39.57814816066197, 39.61819757734026, 45.648761476789204, 41.646293367658345, 45.438231059483115, 42.092364243098665, 54.555650302342, 52.737584659031455, 68.67202745165143, 14.700776236397878, 0.4946325953517641, 0.048609427708600245, 0.44834649190306664, 0.8895389448319162, 47.78182370322091, 59.55187061854771, 54.386715275900706, 58.97754641941616, 57.11474132537842, 39.05126626150948, 24.25451282092503, 37.36391013009207, 43.35693291255406, 45.74282271521432, 4.4373940740312845, 0.24125217593141965, 0.061273849569261074, 0.06749772559851408, 0.05914871860295534, 0.06287197595728294, 0.025002012062551718, 0.039447216849241934, 0.049366655826036415, 0.026461642667917267, 0.022557202892910157, 0.02039177542818444, 0.11368671711534262, 0.061195784115365574, 0.1073491389730147, 0.1172818195606981, 14.218927349363055, 68.79591383252824, 54.640616348811555, 42.09661306653704, 24.049266508647374, 38.77558953421456, 54.02414437702724, 61.73423726218087, 59.12136023385184, 53.8434738431658, 60.928482464381624, 22.45300473485674, 0.5349137995924268, 0.3194521426090172, 0.20745894711996826, 6.891701919691903, 63.473023959568565, 55.668147223336355, 59.382084437779014, 53.58182552882603, 43.33782884052822, 41.93671417236328, 41.07442535672869, 39.58900819505964, 39.51230355671474, 38.35163477488926, 36.515962396349224, 37.084106172834126, 37.30922433308193, 36.84720039367676, 36.251479216984336, 36.77979939324515, 35.98429318836757, 35.64696856907436, 34.049998079027446, 36.178943497794016, 35.26426873888288, 35.040602752140586, 35.107781410217285, 34.21554238455636, 34.081664494105745, 34.08057362692696, 34.65227835518973, 35.407766410282676, 35.40164157322475, 34.420239789145334, 36.47361660003662, 35.989594663892476, 36.80465309960501, 35.91175399507795, 37.30526385988508, 37.66231788907732, 34.96214369365147, 34.899067946842735, 34.95808594567435, 34.474237714494976, 35.368224212101524, 35.296341623578755, 35.23424557277134, 36.166697297777446, 34.81734323501587, 35.653600624629426, 40.16848448344639, 42.06273365020752, 45.042923722948345, 46.234164578574045, 47.4955336025783, 42.41721337182181, 36.20818499156407, 35.44014501571655, 36.18500232696533, 35.77342230933053, 36.458056109292166, 35.4865311895098, 35.96414341245379, 33.43715654100691, 33.78772790091378, 34.242338112422395, 40.66788625717163, 42.707967690059114, 38.824473585401265, 33.82334784099034, 34.17338766370501, 33.848403045109336, 35.51967757088797, 34.654710224696565, 34.64021280833653, 33.155295916966026, 34.05493477412632, 33.9806307383946, 34.00847217014858, 34.315665926252095, 33.924902711595806, 37.90683889389038, 47.515030247824534, 46.86927161897932, 46.01657479149954, 42.62117426736014, 43.572563307625906, 42.666945525578086, 38.75684329441616, 38.03130892344883, 35.82529408591134, 33.23004116330828, 34.32478543690273, 34.27898638589041, 34.125406878335134, 35.31918382644653, 34.96637167249407, 36.775585310799734, 36.78240844181606, 36.6637853213719, 35.36031368800572, 37.23605980191912, 36.25771869931902, 35.67741904939924, 38.99988433292934, 38.10106188910348, 38.364575794764924, 37.173637185777935, 38.44547367095947, 36.37600135803223, 38.915147577013286, 39.46411085128784, 39.471496786390034, 38.321941648210796, 37.407312052590505, 38.77869190488543, 38.1677611214774, 38.57190656661987, 39.114828382219585, 40.24754456111363, 40.3457920891898, 39.204018933432444, 39.555635997227256, 41.05917406082153, 40.84251880645752, 42.92816999980381, 48.4236044883728, 44.43632861546108, 47.83099263054984, 44.13296331678118, 57.37065390178135, 54.23287868499756, 71.9947463444301, 16.105073179517472, 0.44689114285366877, 0.6467580837862832, 0.8190404048987797, 1.0839967131614685, 50.24611003058297, 65.35986287253243, 58.2621876852853, 65.21037932804653, 63.24286488124302, 43.39576639447893, 23.843426125390188, 45.65649134772164, 49.53196375710623, 59.315465109688894, 7.817230633326939, 0.24094463671956742, 0.023008845979347825, 0.06572254228272609, 0.04046045283653906, 0.022634211528514112, 0.045657484858695946, 0.11431925424507686, 0.1460835819265672, 0.09513658750802279, 0.10274218475180012, 0.08577032759785652, 0.27781218556421144, 0.17121683114341327, 0.24317940537418636, 0.2505847194365093, 16.3870849268777, 76.41721221378872, 62.13947010040283, 50.226172174726216, 39.916059902736116, 46.290048939841135, 59.446341378348215, 67.92290047236851, 60.90702642713274, 58.04615429469517, 65.6418763569423, 27.87652015686035, 0.9593371280602047, 0.5182699326957975, 0.2670898666339261, 7.96604107107435, 64.30132566179547, 56.938020842415945, 62.97393485477993, 56.26916292735508, 45.36171749659947, 43.39592620304653, 44.40430784225464, 42.73929711750576, 41.70379318509783, 41.69785942350115, 37.79951701845442, 39.81443555014474, 38.32284491402762, 38.5610465322222, 38.36621904373169, 39.55261353084019, 39.53548969541277, 38.56455189841134, 37.31486974443708, 39.13561739240374, 39.441063676561626, 38.05702420643398, 36.76691048485892, 37.20201710292271, 38.05583259037563, 36.31780324663435, 37.09030744007656, 36.72202859606062, 38.15728323800223, 36.728268078395296, 37.82930047171456, 39.2530871118818, 39.986935002463206, 38.61391884940011, 37.00875643321446, 39.901062216077534, 35.61201565606253, 36.423290797642295, 36.5318147114345, 36.12733227866036, 38.289972986493794, 38.00249474389212, 39.23583820887974, 38.66786118916103, 37.05963461739676, 38.137275900159565, 40.704711709703716, 43.54947096960885, 47.06145531790597, 49.21097435270037, 50.70650461741856, 43.36022635868618, 36.98529584067208, 36.796527181352886, 37.53349828720093, 35.630883489336284, 37.41279418127877, 35.21398115158081, 35.3127497945513, 34.08122328349522, 36.31992244720459, 35.472843238285606, 43.03067677361624, 46.44097423553467, 41.2824717930385, 34.4692245892116, 35.81813049316406, 35.18651492255074, 35.53115599496024, 35.27835621152605, 35.72568471091134, 33.90751831872122, 33.78201648167202, 35.130383900233674, 35.716874395098, 35.00808865683419, 34.676802022116526, 40.07200179781233, 50.0003661428179, 49.57876334871565, 48.62541491644723, 44.90588092803955, 44.22492272513253, 45.818155084337505, 39.717209407261436, 42.10438115256173, 37.901433195386616, 35.50799070085798, 36.04519762311663, 36.07629081181118, 35.75629847390311, 37.79236037390572, 36.05833666665213, 39.08448559897286, 40.35160773141043, 37.88970463616507, 38.77988699504307, 39.7867226600647, 38.586494309561594, 36.9347893851144, 40.32507256099156, 39.66852685383388, 40.14294637952532, 40.045338085719514, 41.007878984723774, 38.57850388118199, 39.92386620385306, 42.92222581590925, 40.688821179526194, 39.745849881853374, 37.76787492207119, 40.102407114846365, 40.80336570739746, 41.96201951163155, 40.87039845330374, 44.01045962742397, 42.60532195227486, 41.257836954934255, 40.879337310791016, 43.78006431034633, 43.662775244031636, 44.69766078676496, 49.64894710268293, 46.76892573492867, 50.30491263525826, 48.5396602494376, 60.27729034423828, 57.49175752912249, 74.05120468139648, 17.93405965396336, 0.5106043326003211, 2.227423540183476, 1.414764187165669, 1.2429019063711166, 54.193086351667134, 70.90783963884626, 63.70712961469378, 71.94439969744, 66.79098333631242, 54.09401546205793, 36.571815490722656, 51.50199692589896, 56.31508009774344, 70.05368368966239, 11.641936898231506, 0.559287537421499, 0.09758705565971987, 0.1101183353790215, 0.14769493974745274, 0.07732961659452744, 0.12000502486314092], [0.05895107492272343, 0.013474012525486094, 0.022730137720437985, 0.048581746872514486, 0.08332306891679764, 0.05361595084624631, 0.0867392552484359, 0.08354962497417416, 0.09159692137369088, 5.94545932326998, 50.85190609523228, 45.75096600396292, 31.990552016666957, 26.00051348549979, 30.927512373243058, 51.31718873977661, 57.63467155184065, 53.30897324425833, 51.13125841958182, 54.668141637529644, 30.39279638017927, 0.00276336058076205, 0.38723920232483316, 0.13732843101024628, 0.31037695386580055, 37.96398087910244, 62.5094894681658, 52.08275168282645, 54.177258355276926, 43.63360670634678, 41.89461503710066, 39.94813278743199, 41.24814421789986, 36.31841468811035, 35.56903062547956, 35.69111394882202, 36.13061877659389, 35.20062671388899, 35.34675080435616, 33.236384868621826, 33.652863366263254, 33.2520877974374, 32.26556519099644, 33.183988503047395, 33.855340821402415, 33.19332340785435, 33.64328180040632, 33.47871371677944, 33.20320374625069, 34.72237525667463, 34.24322400774275, 35.13716881615775, 35.09781769343785, 33.21475165230887, 33.39660685403006, 32.426190171922954, 33.7853307723999, 32.45602573667254, 32.92909731183733, 35.488434995923726, 35.360199042728965, 33.121982778821675, 33.6633551461356, 34.78821986062186, 33.43212604522705, 33.953501496996196, 33.97761869430542, 35.58959034511021, 34.937745094299316, 32.557743889944895, 35.54241207667759, 38.77188614436558, 40.398775577545166, 44.494901929582866, 45.19219534737723, 45.353469984872, 44.432218755994526, 37.45359747750418, 36.78923504693167, 36.26905121122088, 34.7027987071446, 35.071386745997835, 36.32988268988473, 35.13960763386318, 34.70775624683925, 33.84957034247262, 32.8504193850926, 39.914361068180625, 42.21092135565621, 38.42209298270089, 33.498474393572124, 34.866981165749685, 34.40479394367763, 34.0288963999067, 35.36345427376883, 33.012440953935894, 34.25262144633702, 33.63290466581072, 33.67269352504185, 33.90647956303188, 33.401446274348665, 34.53654221126011, 42.594416754586355, 44.58594070162092, 43.64729813167027, 42.20990344456264, 40.126024041857036, 40.38267660140991, 39.35365881238665, 35.91645792552403, 37.318979603903635, 33.629520893096924, 35.400606291634695, 33.66134711674282, 33.622371196746826, 34.38287237712315, 33.15790843963623, 33.91023506437029, 34.74859080995832, 34.450391496930806, 34.370942320142476, 34.54889958245413, 33.63247735159737, 34.441935539245605, 36.11119508743286, 33.829726287296836, 34.66363518578665, 34.9157714162554, 34.79255901064192, 35.28648212977818, 35.237042222704204, 35.08784702845982, 35.066130433763774, 35.52923134395054, 36.05567898069109, 34.4630754334586, 34.52161748068673, 36.79080186571394, 35.422916957310264, 36.447765827178955, 36.722000803266255, 37.67573833465576, 36.26451751164028, 37.887043476104736, 35.137116704668315, 36.40598283495222, 37.65464012963431, 37.29034260341099, 38.661774567195344, 43.0111141204834, 43.85155432564871, 54.72419275556292, 52.48214108603341, 67.09247956957135, 8.431416647774832, 0.5643425690276282, 0.16814650089613029, 0.6353698234472955, 1.7227278905255454, 47.76783003125872, 59.752868107386995, 55.382524149758474, 58.815187862941194, 50.89249052320208, 42.16061987195696, 22.46862428528922, 22.905883107866558, 45.10210847854614, 41.388657638004844, 1.0739986896514893, 0.11119746390197958, 0.03032195222164903, 0.04647793547649469, 0.052686113598091264, 0.01756138534152082, 0.030633382831833193, 0.08523019336696182, 0.0414971288160554, 0.012818857279073979, 0.026542015140876174, 0.05403566886005657, 0.020850638127220527, 0.06660055302615676, 0.10671532619744539, 0.12696375431759016, 7.7590637888227185, 62.689329692295615, 51.217068672180176, 38.64062425068447, 29.158146653856548, 38.22382961000715, 56.122451714106965, 61.607793944222585, 57.969925607953755, 54.929522446223665, 58.45392322540283, 32.44695486341204, 0.027197305246123245, 0.21500581715788158, 0.2030755973287991, 0.3681604803672859, 43.18122686658587, 64.06204359872001, 53.93960911887032, 55.52896785736084, 45.795166969299316, 42.77070644923619, 42.04585647583008, 43.01944153649466, 39.102533544812886, 37.10880354472569, 37.38399389811924, 40.00818954195295, 36.78090068272182, 36.09983825683594, 34.78351245607649, 36.2506628036499, 34.56049960000174, 33.925493308476035, 36.10795375279018, 36.90516921452114, 34.8781920841762, 36.239570004599436, 34.615873268672395, 35.15027659279959, 36.10699837548392, 35.4221248626709, 36.438333647591726, 36.348840849740164, 35.49135671343122, 34.871372427259175, 35.78785719190325, 35.33059276853289, 34.29405355453491, 35.54613283702305, 37.31040205274309, 36.30249636513846, 35.058567319597515, 33.5314679145813, 35.926901068006245, 34.193495750427246, 35.44874688557216, 36.583898408072336, 35.735537256513325, 37.02900695800781, 34.105309213910786, 37.17255674089704, 39.658007281167166, 42.372637203761506, 45.45167234965733, 46.97697564533779, 46.89603955405099, 44.180106844220845, 37.985832963671, 35.79770278930664, 37.16084902627127, 35.34262704849243, 34.308109760284424, 35.41484662464687, 34.67663179125105, 34.36738831656319, 33.22870363507952, 33.18203258514404, 40.32022966657366, 44.789286681583945, 38.967464038303916, 34.4085807119097, 35.774648666381836, 34.113546303340364, 34.659622601100374, 35.88293981552124, 34.47453301293509, 34.613490036555696, 34.25644295556204, 33.16091006142752, 35.47380556379046, 34.53956467764718, 34.54567214420864, 41.400931630815776, 46.51299231392996, 46.11600351333618, 44.562730244227815, 42.79612295968192, 43.50682987485613, 40.7490690095084, 37.79087693350655, 39.59276369639805, 35.73654127120972, 36.48194401604788, 34.925293922424316, 34.05043928963797, 35.25314119883946, 35.70525353295462, 35.48704535620553, 36.4243677684239, 35.61485052108765, 36.19926003047398, 35.75812585013253, 36.03526864733015, 36.508246421813965, 37.30697659083775, 36.79333101000105, 36.593459129333496, 36.216519355773926, 36.08106769834246, 36.800341742379324, 36.28954839706421, 36.49534361703055, 37.16123465129307, 37.80103519984654, 38.78474725995745, 37.17215027127947, 36.25789935248238, 39.43651260648455, 38.048050607953755, 39.23343760626656, 38.38404812131609, 40.78509889330183, 39.00876760482788, 40.08611706324986, 38.56831782204764, 38.42649119240897, 38.85384362084525, 41.02649668284825, 41.00820207595825, 44.59362193516323, 45.41463150296892, 56.62938533510481, 53.79243585041591, 68.95816816602434, 9.101685047149658, 0.594299238707338, 0.08699407228933913, 1.0057111425059182, 2.017156503030232, 52.53445407322475, 65.01956789834159, 59.78471864972796, 65.26046194349016, 57.062893867492676, 47.96830987930298, 25.07181552478245, 28.124030624117168, 50.65218012673514, 50.84446804864066, 2.262865649802344, 0.1872171347162553, 0.049883102399430106, 0.026154919394424984, 0.0477863206262035, 0.015958348056301475, 0.04694208735600114, 0.12969485776765005, 0.18966260206486496, 0.09700141208512442, 0.3020516006009919, 0.15292322848524365, 0.20779665399874958, 0.2168933523020574, 0.3521305519555296, 0.1936079982135977, 8.206184710775103, 70.0163996560233, 57.70934731619698, 45.37248373031616, 36.064326013837544, 41.447647844042095, 60.8363493510655, 66.15705054146903, 62.023442132132395, 60.690548351832796, 63.12340450286865, 35.83792591094971, 0.19976754912308284, 0.9790415678705487, 0.4611087313720158, 0.8945799171924591, 44.73318345206124, 66.80474771772111, 56.30345923560006, 58.455160004752024, 47.638631752559114, 44.040990012032644, 43.645519392830984, 45.835237230573384, 41.49611152921404, 38.93805578776768, 39.607233319963726, 42.82232461656843, 38.716915471213206, 41.19933312279837, 36.62421533039638, 38.79418291364397, 36.20453371320452, 35.881612709590364, 38.91630792617798, 38.43759093965803, 37.43197120938982, 39.32236760003226, 38.23415810721261, 37.25277369362967, 38.96974652154105, 37.095070430210654, 39.800844873700825, 38.97408219746181, 38.257893153599326, 37.972339562007356, 37.898042474474224, 38.33433028629848, 36.58979742867606, 36.88609988348824, 39.81868437358311, 38.930221693856375, 35.50016008104597, 36.90112883704049, 37.64321034295218, 34.63142333711897, 37.381447383335654, 38.57360887527466, 38.02733107975551, 38.61543008259365, 35.71431050981794, 39.60795593261719, 41.885488578251426, 44.0198883329119, 48.793787138802664, 50.618380614689414, 49.822982106889995, 47.35948440006801, 38.2527619089399, 36.19085618427822, 37.16571623938424, 35.87315327780587, 34.585440158843994, 35.40145397186279, 35.23416566848755, 34.96662528174264, 34.273466042109895, 34.35928324290684, 42.849349634987966, 45.73373099735805, 40.54830428532192, 35.05757025309971, 36.233935015542166, 35.10286555971418, 35.47633818217686, 36.371651785714285, 34.031046867370605, 34.72721120289394, 35.2139116695949, 33.51949616840908, 35.72905111312866, 33.7793414252145, 35.59949500220162, 43.805946350097656, 48.969055448259624, 48.89915657043457, 46.677379744393484, 44.059951645987375, 44.501752853393555, 43.92938109806606, 38.39330312183925, 41.59342105048043, 37.601812975747244, 38.169209820883616, 35.64974090031215, 35.59652812140328, 36.42726516723633, 36.33946772984096, 36.79109369005476, 37.90035969870431, 37.674119404384065, 37.82824087142944, 38.35987533841814, 38.57005139759609, 38.59283801487514, 40.282716342381065, 38.735488006046836, 38.35869761875698, 38.88399532863072, 38.91130869729178, 39.65464087894985, 39.349041734422954, 38.967345918927876, 39.79791620799473, 39.16364989961897, 42.063088008335654, 38.67901304789952, 37.41915873118809, 41.555035727364675, 39.36849669047764, 41.007031304495676, 41.06807470321655, 43.45973151070731, 40.0571847643171, 42.38629388809204, 39.50142962591988, 40.3112803867885, 41.55618565423148, 43.01786082131522, 43.37956666946411, 46.47649690083095, 49.07081529072353, 59.881076267787385, 56.080811159951345, 71.92823123931885, 10.885345816612244, 0.4866521550076348, 4.2355011360985895, 1.747178275670324, 2.2664368067468916, 56.8219963482448, 70.91412081037248, 64.22251919337681, 68.90607057298932, 61.38372148786272, 58.33419186728341, 32.94035686765398, 37.07985387529646, 57.82576090948922, 64.16612066541398, 4.456265815666743, 0.4863691787634577, 0.2428945835147585, 0.15664681153638021, 0.17544965472604546, 0.19098782166838646, 0.15874752881271498], [0.07644316487546478, 0.0073726264859682745, 0.043468154301600795, 0.039380415076656, 0.042635130429906506, 0.03658657767144697, 0.014455369241269571, 0.048411634750664234, 0.0716001551066126, 2.4030852913856506, 44.93085275377546, 54.89349256243025, 29.083311080932617, 20.616891145706177, 31.92859492983137, 49.977746282305034, 57.408104692186626, 50.96547787530081, 55.29479619434902, 52.269192695617676, 42.80049685069493, 0.3386159799993038, 0.08876460764024939, 0.21688442278121198, 0.052140941244683096, 8.116894279207502, 59.07987254006522, 51.951705183301655, 56.246973855154856, 47.485924243927, 41.44500405447823, 38.26038408279419, 38.35075235366821, 37.10530512673514, 38.040202617645264, 40.560804094587056, 39.674248695373535, 37.29960107803345, 35.99160616738455, 34.18447004045759, 34.463134493146626, 32.69217068808419, 34.46470826012747, 32.467257499694824, 32.963119166237966, 32.180991717747276, 34.21488230569022, 34.599718706948416, 35.0763338633946, 35.10166699545724, 34.35687916619437, 33.34498521259853, 34.132737227848594, 31.192540986197336, 35.183902399880544, 32.828685419900076, 33.85428816931588, 34.586298261369976, 34.68167618342808, 34.69602073941912, 35.29455941064017, 33.91525861195156, 34.86671366010393, 34.355128220149446, 34.49095508030483, 33.63909898485456, 33.78699139186314, 33.10821144921439, 33.334833894457134, 33.88269240515572, 33.57278537750244, 34.58186183656965, 39.862781115940635, 45.872858251844136, 44.48139463152204, 47.158876010349815, 46.17177670342581, 36.183418137686594, 34.029278550829204, 35.348710196358816, 34.46533359800066, 36.22995717184884, 34.373745918273926, 36.2373674256461, 33.25793123245239, 33.6715019089835, 34.65705524172102, 38.74107435771397, 41.74166781561715, 37.60624940054757, 36.47576011930193, 34.47494643075125, 32.56048148018973, 34.120049817221506, 34.43921184539795, 35.681271825517925, 34.38918481554304, 35.550544943128315, 34.55205406461443, 34.348635128566194, 35.19049276624407, 39.517691884722026, 42.88389607838222, 44.496461800166536, 41.90858786446707, 43.381112643650596, 39.96576731545584, 36.089964866638184, 36.832035950251985, 33.30854191098894, 32.17704514094761, 31.925454344068253, 32.428479603358674, 33.53522341591971, 34.4668413570949, 35.03630529131208, 33.108784675598145, 34.185501847948345, 33.37898622240339, 35.31197507040841, 35.4022147996085, 34.32998616354806, 34.91296781812395, 34.99852793557303, 32.539949553353445, 33.959299768720356, 34.872185366494314, 34.73169279098511, 34.38658618927002, 34.433959007263184, 34.259197916303364, 35.3517986706325, 34.24945306777954, 36.212607519967214, 35.016909394945415, 33.873270647866384, 34.996988909585134, 35.534373010907856, 36.53222812925066, 36.89079686573574, 34.9774158341544, 36.77548108782087, 36.62193284715925, 37.505830560411724, 39.131354672568186, 43.0304787499564, 40.48989772796631, 39.025467600141255, 36.76045560836792, 41.686148234776084, 42.54561608178275, 53.89060000010899, 52.05929109028408, 63.77387401035854, 6.037017038890293, 0.5174130243914468, 0.5366318502596447, 0.7650675582034248, 1.6520666650363376, 51.98657819202968, 54.83182035173689, 57.04926150185721, 58.6527806690761, 54.45390088217599, 35.30313001360212, 18.167823110307964, 33.06801264626639, 47.650554861341206, 45.41811255046299, 1.8820396619183677, 0.15186536524977, 0.08923548380179064, 0.0768399110862187, 0.04611496673896909, 0.020358949600319778, 0.11430641636252403, 0.05439064445506249, 0.03824713606653469, 0.03895036975986191, 0.01596975083728986, 0.01909392962365278, 0.03556294652766415, 0.04561063201565828, 0.007663449987636081, 0.027672040575583066, 3.2958017885684967, 52.78957455498831, 60.003058842250276, 35.79075806481497, 21.629525082451956, 32.11633178165981, 54.21667548588344, 60.282258306230815, 55.974514143807546, 56.636027812957764, 57.013172558375764, 45.78771502631051, 0.3694264367222786, 0.2429625184408256, 0.3460781824375902, 0.06192731271897044, 10.836344514574323, 62.969738142830984, 54.363279002053396, 58.26277133396694, 48.61339453288487, 42.16928080150059, 39.67607954570225, 40.32667064666748, 39.18181596483503, 41.31444045475551, 40.82067019598824, 42.24043730327061, 38.91245167595999, 37.78659684317452, 36.828349930899485, 36.02648612431118, 34.52039459773472, 36.120321546282085, 34.29088865007673, 34.51973451886858, 33.623399530138286, 36.75682864870344, 36.34573500497, 36.63871622085571, 36.85424934114729, 35.9415339742388, 35.861820765904014, 35.858548164367676, 35.04864181791033, 35.44564798900059, 33.24818638392857, 35.278786999838694, 35.97480542319161, 36.097451550619944, 36.57014444896153, 37.2587456703186, 35.13039084843227, 35.54205771854946, 35.78441088540213, 35.27092163903372, 34.47331012998308, 34.91227994646345, 35.251414571489605, 34.98291533333914, 36.77879537854876, 34.852918011801584, 35.33870826448713, 41.59384489059448, 48.40536546707153, 47.83669710159302, 46.95748594829014, 47.80655929020473, 37.630488191332134, 34.37620905467442, 35.86423179081508, 34.694526876722065, 36.981074810028076, 35.03865030833653, 35.49787064961025, 34.2550185748509, 34.660602297101704, 35.14611462184361, 42.55471127373831, 44.58229289736067, 40.31563343320574, 35.78003352028983, 34.75526455470494, 33.84965719495501, 33.873322759355815, 34.05799198150635, 35.15393829345703, 33.82850340434483, 36.38367216927664, 34.258426666259766, 34.14544548307146, 35.77770239966256, 39.620063168661936, 44.06468684332711, 46.66832276753017, 45.17029809951782, 46.9951034954616, 42.906595843178884, 38.51025172642299, 37.99426112856184, 35.297067710331504, 34.346828596932546, 33.97113602502005, 34.431961400168284, 34.15017025811331, 36.23590135574341, 35.151454312460764, 35.7624545778547, 35.41823039736067, 34.49268170765468, 36.51349231175014, 37.51034688949585, 36.26291247776577, 36.3408191544669, 36.11536053248814, 35.43381173270089, 35.534609249659944, 36.955870219639365, 36.09460278919765, 36.399392468588694, 36.608463764190674, 36.7364877973284, 37.79948227746146, 36.67486769812447, 36.84128400257656, 36.95116976329258, 35.030562605176655, 36.67008038929531, 37.74921900885445, 38.01382725579398, 37.98349836894444, 36.40305069514683, 38.85425703866141, 38.04644209997994, 40.63355868203299, 40.69280249731881, 44.10903024673462, 43.715862955365864, 40.96445274353027, 39.8079320362636, 44.529913902282715, 44.56694432667324, 57.07794713973999, 53.66671167101179, 64.80983652387346, 6.8500761304582864, 0.36535137253148214, 0.6954161013875688, 0.6839413685458047, 1.9756095324243819, 55.98591613769531, 61.60759244646345, 61.377308300563264, 63.90843282427107, 58.5032901763916, 42.95084892000471, 20.70913369315011, 36.47299126216343, 54.765892369406565, 53.18876246043614, 2.5671161924089705, 0.15906914084085397, 0.01576681967292513, 0.10862425555075918, 0.02583809951985521, 0.04096682995025601, 0.03291242928909404, 0.1825651257698025, 0.094409937571202, 0.14842767614339078, 0.08578275157404797, 0.19080586571778568, 0.13489187961178167, 0.15557830887181417, 0.14925262544836315, 0.13731954220150197, 3.552109978028706, 60.96433516911098, 70.0655859538487, 43.214008467538015, 28.75648171561105, 42.53275844029018, 62.06950174059187, 65.7763031550816, 61.14038862500872, 63.20592825753348, 61.11809185573033, 50.30130999428885, 0.6954834663442203, 0.5322289179478372, 0.9951493378196443, 0.10892639362386294, 13.526449901717049, 65.16593864985875, 56.44473000935146, 60.99920122964041, 51.31806768689837, 45.13643257958548, 41.2049993787493, 42.49426542009626, 41.988374028887065, 43.24559497833252, 44.99265003204346, 44.3874271937779, 41.04445430210659, 41.025586468832834, 39.345855985369, 39.63472734178816, 37.90369830812727, 40.35136801855904, 36.727323123386924, 36.773657185690745, 35.22457020623343, 39.38630839756557, 39.27047150475638, 40.287107603890554, 39.01318665913173, 38.93351166588919, 38.168754713875906, 37.479257174900596, 35.236871991838726, 39.97394534519741, 37.64264753886631, 38.99494068963187, 38.318116664886475, 37.85465097427368, 37.78127452305385, 38.105908257620676, 36.81157350540161, 37.91798380443028, 36.48157228742327, 37.3866411617824, 36.09992510931832, 36.35773801803589, 36.51225553240095, 35.95736197062901, 39.15183796201433, 36.593261105673655, 36.97424125671387, 43.98972272872925, 49.995095934186665, 49.979976654052734, 50.32015698296683, 48.605598654065815, 38.4784255027771, 34.3268004144941, 35.712236472538535, 33.95740638460432, 37.117523533957346, 34.21222809382847, 37.102987902505056, 34.13306379318237, 35.48547853742327, 36.3906238419669, 44.61056511742728, 46.30605411529541, 41.055814606802805, 37.70141192844936, 34.97663763591221, 33.939229897090364, 34.91871050425938, 35.08949375152588, 36.86996964045933, 34.71820286342076, 36.695229394095286, 35.51695735113961, 35.34231090545654, 36.00523853302002, 42.949771949223106, 49.29315069743565, 50.0511018889291, 48.71039138521467, 49.45194482803345, 45.12981442042759, 39.989148003714426, 40.87235089710781, 36.13275882175991, 34.085927213941304, 34.439816338675364, 35.681511538369314, 36.415599141802105, 36.08327375139509, 36.9258713722229, 37.29104437146868, 37.62680912017822, 35.24766949244908, 38.384951387132915, 39.21431268964495, 37.50732789720808, 39.59237459727696, 38.367518356868196, 35.47174194880894, 38.5476712499346, 39.824416637420654, 38.94269371032715, 39.32923936843872, 38.647388322012766, 37.45034919466291, 39.93014737537929, 38.59004831314087, 39.1540196963719, 38.5867965562003, 38.04458693095616, 39.130468777247835, 41.23377186911446, 40.5854424067906, 42.364000592912944, 39.126671586717876, 41.67542716435024, 39.98099776676723, 42.33312279837472, 42.41947848456246, 47.686438832964214, 45.18206139973232, 43.114346981048584, 41.33887379510062, 46.93495988845825, 46.90457541601998, 60.14828314099993, 57.008423464638845, 69.46157210213798, 7.94832055909293, 0.6255535387567112, 2.3268305488995145, 1.2915946649653571, 2.096999990088599, 60.68111269814627, 66.02736241476876, 67.30121735164097, 68.36306885310582, 65.52245766775948, 48.4655716078622, 28.508778435843332, 46.90139661516462, 61.11397157396589, 64.55981949397496, 4.644391332353864, 0.3386466497821467, 0.16944812105170318, 0.2014651351741382, 0.18294121058923857, 0.11333438102155924, 0.2367569628570761], [0.03101238195917436, 0.06403817409383399, 0.08367197840873684, 0.07186240889132023, 0.0200261162993099, 0.029743283987045288, 0.017804982805890695, 0.05563731345215014, 0.05663468868338636, 0.7763748828853879, 40.026491097041536, 52.23072746821812, 40.13446610314505, 33.05606869288853, 28.00754233769008, 46.611771379198345, 56.16015611376081, 48.443372113364084, 56.11745595932007, 47.740429810115266, 51.32205595288958, 2.799055746623448, 0.4686584919691086, 0.3220397223319326, 0.05862927290477923, 0.5704249569347927, 33.721765177590505, 58.04057836532593, 49.87581273487636, 51.00413417816162, 38.19841309956142, 37.78792742320469, 40.67899990081787, 46.66952133178711, 44.4662822995867, 44.30468804495675, 40.64794840131487, 39.513043539864675, 35.42653349467686, 36.65727138519287, 35.17140259061541, 33.97624295098441, 32.90845421382359, 34.11415427071707, 33.11016389301845, 33.137518950871055, 35.26956326620919, 34.44304377692086, 35.41471460887364, 34.656957966940745, 32.47335801805769, 34.38688496180943, 32.45753002166748, 34.5667599269322, 32.50174140930176, 32.66228996004377, 33.53775603430611, 35.61290849958147, 32.91211938858032, 35.44429656437465, 34.301627090999055, 32.62386294773647, 33.3854341506958, 35.87164899281093, 33.280564989362446, 33.95261212757656, 33.37653350830078, 33.81287343161446, 33.188817501068115, 33.43943902424404, 34.32724857330322, 32.98870938164847, 42.2651937348502, 46.216147899627686, 43.98055458068848, 45.39110837663923, 42.54308693749564, 41.93275022506714, 37.950918265751426, 36.197429180145264, 35.26241356985909, 37.963643891470774, 35.01625973837716, 36.07356711796352, 34.81180204663958, 34.67356416157314, 33.23331723894392, 38.67829738344465, 41.55772120612008, 38.30576276779175, 32.94911159787859, 34.83294194085257, 33.99445070539202, 35.2502681187221, 33.752080168042866, 34.10954761505127, 33.859627859933035, 35.933863162994385, 33.08999327250889, 36.77575901576451, 35.24231243133545, 40.965877124241416, 35.084515367235454, 41.78526081357683, 43.17698499134609, 42.55727168491909, 41.045138699667795, 33.768342426845, 33.611316612788606, 32.0025063923427, 33.449923855917795, 34.39064393724714, 32.65664107458932, 31.520610604967388, 34.911442688533235, 34.00977495738438, 34.77163103648594, 34.19984640393938, 34.04532194137573, 35.56496245520455, 33.6040974344526, 34.31984874180385, 34.440031732831685, 33.62026241847447, 32.435650144304546, 33.8276800428118, 33.088322230747764, 34.42305380957467, 33.5971805027553, 35.5984388760158, 34.896042006356375, 36.66282646996634, 35.50426646641323, 37.379057203020366, 35.791352135794504, 35.67927769252232, 35.113913195473806, 34.84219346727644, 34.54931994846889, 35.12384564535958, 36.20727130344936, 38.359621729169575, 38.132954120635986, 41.9290120942252, 43.98335470472063, 51.29320355824062, 50.4723607472011, 49.937210491725374, 38.8550317628043, 39.28362444468907, 41.30896527426583, 52.45088114057268, 54.30437912259783, 60.85342107500349, 5.635796785354614, 0.6022002090300832, 0.6020367635147912, 0.7092497476509639, 4.873261954103198, 57.52755812236241, 52.192873682294575, 58.390562602451865, 53.68886252811977, 51.78177656446184, 38.50431101662772, 27.329672609056743, 27.9401604448046, 49.191119875226704, 32.35278592790876, 0.48119792767933434, 0.07835940883627959, 0.03187386019687567, 0.025017009382801395, 0.0217404774323638, 0.04179532460070082, 0.07433606936995472, 0.0480108783979501, 0.0684621681326202, 0.022519276178042804, 0.0440590429518904, 0.04060448207227247, 0.04909690762204783, 0.016660231464941586, 0.0709325580724648, 0.04996285401284695, 1.1755959008421217, 49.17895705359322, 59.52152783530099, 43.52080965042114, 33.91678374154227, 37.41114051001412, 52.07872520174299, 59.12427152906145, 52.00112077168056, 60.1509234564645, 51.40959978103638, 56.88644783837454, 2.6544667737824574, 0.2729611215846879, 0.4175897480121681, 0.040624244404690604, 0.9366545166288103, 38.66745124544416, 61.12530408586775, 52.31498827253069, 52.97690493719918, 39.68041522162301, 40.001262187957764, 42.74796846934727, 46.256405762263704, 46.378329277038574, 46.083624907902305, 42.56862851551601, 41.38931771687099, 37.48831067766462, 39.572332518441335, 36.72714247022356, 37.33095482417515, 34.745224407741, 34.9559702192034, 36.70258406230381, 36.80172095979963, 37.72411516734532, 36.63456814629691, 38.23557901382446, 36.121342931474956, 35.584931577954976, 35.25507627214704, 34.53486769539969, 37.195871421269004, 35.438182149614605, 36.24792173930577, 34.751130376543315, 36.579333441598074, 35.00010517665318, 37.619933877672466, 34.58815343039376, 34.86500787734985, 34.580663272312705, 36.554775033678325, 34.11663825171334, 36.7502452305385, 35.43406186785017, 34.847526209695, 35.66757345199585, 34.08496141433716, 34.61459480013166, 36.44999967302595, 42.6322740146092, 49.92167431967599, 44.71455533163888, 47.7715334211077, 44.65423801967076, 41.01257944107056, 36.33115768432617, 37.85449116570609, 36.390971251896445, 36.13731336593628, 35.177506583077566, 36.62456621442522, 34.50682129178728, 34.47465113231114, 32.623428685324534, 39.21174185616629, 43.78218003681728, 39.705821309770855, 32.00355904442923, 34.49183055332729, 33.73041568483625, 34.30484063284737, 34.32340621948242, 33.864206722804475, 34.326254980904714, 36.208063398088726, 34.538953236171174, 37.35586759022304, 34.77638707842146, 41.17376027788435, 41.379173346928184, 45.03791059766497, 45.52323532104492, 45.32859543391636, 42.159723554338726, 36.585044860839844, 35.97600746154785, 33.38815089634487, 34.764971188136506, 35.60555035727364, 34.60701084136963, 33.704658712659565, 36.051325934273855, 35.0576571055821, 36.029519012996126, 35.074579443250386, 36.0648193359375, 37.283040046691895, 37.07388884680611, 36.670754364558626, 36.53026873724801, 35.527150358472554, 35.05668783187866, 36.997819968632285, 34.390056814466206, 36.27278239386422, 35.517853668757844, 36.51910993031093, 36.2667235646929, 38.4831085886274, 37.75649029867989, 39.4789765221732, 37.37445054735456, 37.63944789341518, 37.94111783163888, 38.354879583631245, 36.66338927405221, 37.82641002110073, 38.30213928222656, 39.90818411963326, 40.38169690540859, 45.10172285352434, 46.004186153411865, 52.36710671016148, 52.35797330311367, 52.07157897949219, 41.36331408364432, 41.37944780077253, 43.68058000292097, 55.069264616285054, 56.054150921957834, 62.69333185468401, 7.150214425155094, 0.6442731256995882, 0.5634531453251839, 0.7285691595503262, 4.976863503456116, 63.35099274771554, 57.8585216658456, 63.54067856924874, 59.308579444885254, 57.17334590639387, 47.351570401872905, 25.4017333643777, 35.794610840933665, 55.60799319403512, 41.13906792231968, 0.6546430406825883, 0.05980538443795272, 0.008121113376026707, 0.022718880824478607, 0.06694354569273335, 0.07829931777502809, 0.12411350011825562, 0.0847255125907915, 0.24409928172826767, 0.17040913019861492, 0.12230220516877514, 0.09713876792894942, 0.1649478461061205, 0.14222687030477182, 0.11397055509899344, 0.16291540302336216, 1.1436022690364291, 54.46133198056902, 66.47415242876325, 54.65237270082746, 45.253408976963584, 39.63432782036917, 58.00868960789272, 65.3011783872332, 59.04656982421875, 63.36530603681292, 56.480947494506836, 61.13924217224121, 4.14693375144686, 1.0760479739734103, 1.3453490776675088, 0.16216372192970344, 2.185131158147539, 43.55134350912911, 60.378094809395925, 54.43646090371268, 54.601685592106406, 41.63595444815499, 40.24436228615897, 47.04684673036848, 50.817189420972554, 48.552979946136475, 48.38677903584072, 45.52613271985735, 45.40269449778965, 41.69027893883841, 41.48329210281372, 39.235292775290354, 40.24308729171753, 37.36313888004848, 37.7820075580052, 38.59776428767613, 38.44139855248587, 40.75188997813633, 39.80042450768607, 40.25965527125767, 37.52471923828125, 37.091829095567974, 38.630431243351524, 37.67087459564209, 40.67723158427647, 36.77122531618391, 38.90746634347098, 38.84257016863142, 39.06199080603463, 38.030478613717214, 40.0690974508013, 36.89731775011335, 35.372462613242014, 35.845280579158235, 39.23403862544468, 37.764630113329204, 39.115651743752615, 35.768009662628174, 36.42757436207363, 36.06188372203282, 36.62974609647478, 37.544420855385916, 39.25651257378714, 45.89156627655029, 52.74460928780692, 48.263980048043386, 48.97997454234532, 45.75392593656267, 41.43323728016445, 37.33033643450056, 37.68536158970424, 35.982028075626914, 37.62648255484444, 34.62254353931972, 36.04839379446847, 35.55380712236677, 35.74197823660714, 34.10080330712454, 41.64481340135847, 45.72748109272548, 41.12162446975708, 32.53245939527239, 36.35034166063581, 35.52832807813372, 35.70215116228376, 36.19344438825335, 33.95446034840175, 34.68575130190168, 36.99269914627075, 34.04041651317051, 38.50127117974417, 35.482938970838276, 40.8550637790135, 42.941917010716026, 46.89492436817714, 48.58665091650826, 47.82217189243862, 45.70131417683193, 37.261903626578196, 38.51309353964669, 34.67178194863455, 37.44114283152989, 37.31630802154541, 35.528831822531565, 34.37155723571777, 39.864782197134836, 37.546220438820974, 37.85004431860787, 36.93182945251465, 37.288219928741455, 39.60721942356655, 38.54688262939453, 38.4302327973502, 38.94908257893154, 37.918557030814036, 37.823457036699565, 39.18791995729719, 37.067427022116526, 39.206575870513916, 38.025152819497244, 39.32500444139753, 39.15495075498308, 40.28628076825823, 40.70934615816389, 42.215538433619905, 38.83071306773594, 39.88629729407174, 39.06879309245518, 39.45360517501831, 38.322969981602256, 39.88704422542027, 40.770010880061555, 42.19017056056431, 42.57650777271816, 46.61575617109026, 48.68003470557076, 56.15660558428083, 55.62589175360543, 56.742001737867085, 44.23643936429705, 44.21313163212368, 44.988283089229036, 57.58195904323033, 59.57391725267683, 65.26714611053467, 7.567754694393702, 0.642072989472321, 2.466914700610297, 1.3779817266123635, 6.875159561634064, 68.18900258200509, 61.85305840628487, 67.81894152505058, 62.66530976976667, 63.43040370941162, 52.87154940196446, 37.831027099064414, 45.08229916436331, 63.55290739876883, 52.15502684456961, 1.1779618710279465, 0.20241804261292728, 0.141310685181192, 0.1482695232012442, 0.22004984292600835, 0.25084166707737104, 0.2446871373270239], [0.060390627676887174, 0.04587725556588598, 0.025732714549771378, 0.06532791310123034, 0.03078673853139792, 0.0529819412955216, 0.056746931946171184, 0.09110887149082762, 0.03317562623747757, 0.04315382634688701, 32.58612380708967, 56.08980907712664, 39.193676539829795, 23.986472163881572, 17.970374413899012, 44.066965852464946, 58.62283393314907, 52.841870171683176, 51.74666731698172, 48.74397897720337, 56.45894602366856, 11.109425221170698, 0.4305108460996832, 0.3458641996341092, 0.3619651028088161, 0.06119628623127937, 17.438095501491002, 65.74259049551827, 49.22064971923828, 52.69574955531529, 35.58993080684117, 42.72068289348057, 46.496966293879915, 50.78988994870867, 44.8622601372855, 45.22765547888619, 40.69372313363211, 40.756642545972554, 35.86038943699428, 37.440343788691926, 35.01615898949759, 34.77646003450666, 31.194316250937327, 34.50416013172695, 33.64671073641096, 35.38671336855207, 33.59373072215489, 35.00487164088658, 33.49792201178414, 35.42741938999721, 32.631172452654155, 32.14874165398734, 31.529521669660294, 32.99304505756923, 32.09290940420968, 33.97911255700247, 31.968540123530797, 33.63436031341553, 33.863539695739746, 33.87659536089216, 35.58488294056484, 34.30523320606777, 33.9757148878915, 33.85234614780971, 34.02192735671997, 33.103372028895784, 31.96929052897862, 34.10193933759417, 34.326967171260286, 33.71643590927124, 34.52091571262905, 35.04825619288853, 42.92489045006888, 45.856092248644146, 43.791375977652415, 45.695984908512656, 46.469614710126606, 44.20051370348249, 36.28905160086495, 36.34077399117606, 36.99077449526106, 37.08494343076433, 35.38129377365112, 36.945364543369834, 33.976645946502686, 34.72122185570853, 33.291383334568565, 37.80832733426775, 42.32939856392996, 40.22628307342529, 33.65968302318028, 33.67785256249564, 32.33091647284371, 35.47014386313302, 33.715317249298096, 35.806151798793245, 34.22740295955113, 36.092469692230225, 33.01910775048392, 35.904201303209575, 31.801849365234375, 40.446214403424946, 45.780888421194895, 42.08998448508126, 45.53033290590559, 43.3811161177499, 41.552864415305, 35.15960454940796, 33.52488102231707, 33.54670531409127, 30.81536497388567, 32.160696029663086, 33.057711941855295, 33.05727073124477, 33.702581201280864, 34.98466280528477, 34.324462345668245, 34.07907281603132, 35.118825571877615, 35.10566568374634, 33.8448942048209, 35.020699637276785, 34.51676068987165, 33.68798998423985, 32.3258547101702, 33.84788193021502, 33.54286643436977, 34.38161127907889, 34.23241261073521, 35.13175964355469, 35.05497162682669, 35.791112422943115, 33.853471755981445, 35.24451501028878, 36.06324904305594, 35.39780616760254, 34.59657464708601, 36.27857371738979, 36.07774298531668, 37.26142767497471, 37.196962288447786, 39.67088576725551, 41.94836630140032, 43.439474037715364, 48.31138413293021, 53.466426372528076, 55.99694292885916, 55.552622999463765, 46.45773676463536, 39.62232828140259, 39.24064983640398, 53.016322067805696, 52.63914605549404, 60.750087465558735, 9.841970443725586, 0.661765378500734, 0.2126701232045889, 0.8600615380065781, 9.20230712209429, 58.759081159319194, 49.94471107210432, 58.357822690691265, 53.618154185158865, 50.40327828271048, 30.307736533028738, 25.09662233080183, 33.61352266584124, 53.799040113176616, 24.34418453489031, 0.17145556690437452, 0.06603808820779834, 0.008300244924612343, 0.017080699259947454, 0.10324504026877028, 0.06816776535872902, 0.020996112642543655, 0.031765525295798264, 0.018473602731579115, 0.07082357177776949, 0.006398334167897701, 0.016952936204948595, 0.04409120551177433, 0.05396078912807362, 0.03484700387343764, 0.11711860474731241, 0.04733106434079153, 41.814887932368684, 61.11607687813895, 47.68608100073678, 25.340382507869176, 24.98405977657863, 54.99800736563546, 62.36609254564558, 57.41902378627232, 57.9037127494812, 53.654076371874126, 60.172143254961284, 10.669885652405874, 0.37571550639612333, 0.2835177422634193, 0.44035826197692324, 0.015650869912600944, 20.54391769000462, 66.62543555668422, 51.08089787619454, 54.91539328438895, 38.33655023574829, 43.934262207576204, 48.64116300855364, 52.11072513035366, 45.14940486635481, 48.30281005586897, 42.71654176712036, 44.502037729535786, 39.16513334001814, 39.520203658512656, 35.99375663484846, 38.04242604119437, 33.996667180742534, 36.3671041897365, 35.56409045628139, 36.74746247700283, 34.83464077540806, 36.74207067489624, 35.13568884985787, 36.54652752195086, 34.84789793831961, 34.57760606493269, 33.92049060549055, 35.86339453288487, 34.900023324149, 34.45699575969151, 34.001864433288574, 34.68164144243513, 35.86539213997977, 35.67617184775216, 35.54021644592285, 35.82999106815883, 34.6582989692688, 36.5295843396868, 34.86947904314314, 35.7469288281032, 35.282407011304585, 35.07357542855399, 34.93770687920706, 35.470477376665386, 36.42682048252651, 36.360666683741975, 44.06304359436035, 46.81274454934256, 46.628457478114534, 49.79647125516619, 46.33912059238979, 45.7534430367606, 37.60872990744454, 35.6647629056658, 37.410939012254985, 36.80204405103411, 35.617000988551546, 37.732595443725586, 34.44259909221104, 35.231487137930735, 33.409749371664866, 39.03867612566267, 44.74742031097412, 42.13321965081351, 35.49988215310233, 33.95193815231323, 31.814828600202286, 35.986478396824424, 34.4239501271929, 35.99622671944754, 34.20517219815935, 35.53550556727818, 33.42282935551235, 35.866858209882466, 32.21150125776018, 40.76606430326189, 47.03750140326363, 44.927680901118684, 45.619648524693076, 46.809371198926655, 42.09052644457136, 36.976023469652446, 34.73819630486624, 35.053456919533865, 32.866285596575054, 34.887235164642334, 35.46825395311628, 33.66639150891985, 35.43810224533081, 36.07486295700073, 34.98496157782418, 36.07070098604475, 36.12034933907645, 36.27215010779244, 34.15355403082711, 37.377737045288086, 35.79417657852173, 35.40072788511004, 34.772242477961946, 35.20610189437866, 35.983952726636616, 36.713312080928254, 36.09756966999599, 36.09507179260254, 37.25112002236502, 36.49917207445417, 35.28992148808071, 37.76622472490583, 37.42866734095982, 37.62895958764212, 37.03706339427403, 38.49757473809378, 38.6252235685076, 38.38478463036673, 40.183263301849365, 42.556385789598735, 42.097835949489046, 46.05559587478638, 50.98231683458601, 54.34192718778338, 56.00911964688982, 55.399338790348594, 48.16993965421404, 42.025050095149446, 41.01651212147304, 54.90518638065883, 53.716742174965994, 62.67425210135323, 11.851896694728307, 0.8678416748132024, 0.7397782866443906, 0.885956442781857, 9.951184834752764, 65.82248783111572, 56.10583857127598, 64.33180046081543, 58.01360198429653, 54.0466183253697, 38.682038988385884, 29.26464864185878, 38.78913852146694, 61.33716855730329, 31.75435495376587, 0.02582851012370416, 0.053873017230736356, 0.04965129108833415, 0.05275500865120973, 0.03277309890836477, 0.011080095178580709, 0.03101812575810722, 0.13139498153967516, 0.049885456915944815, 0.17374738678336143, 0.09304938664925949, 0.19259333051741123, 0.09096208401024342, 0.25068291702440804, 0.17146148372973713, 0.23948073812893458, 0.1290556506386825, 48.370714800698416, 71.62153775351388, 53.444035802568706, 31.46709210532052, 26.000718457358225, 58.75676046098982, 68.29811709267753, 62.27354254041399, 62.89234215872628, 59.39926733289446, 66.0440867287772, 13.418637309755598, 0.7982997064079557, 1.5884626380034854, 0.7948970975620406, 0.10205272531935147, 24.50514476639884, 69.83289078303746, 53.71454307011196, 58.49156161717006, 40.64758709498814, 47.238773345947266, 50.64438077381679, 53.83889845439366, 47.25637660707746, 50.264758995601106, 45.07717834200178, 47.574447768075125, 40.95342247826712, 42.72277430125645, 40.078310762132915, 39.77865580150059, 36.05668646948678, 40.04644979749407, 38.017898900168284, 39.55986745016915, 37.286899771009175, 39.78907462528774, 37.896260261535645, 39.83215693065098, 37.864302022116526, 36.808113302503315, 35.1564952305385, 37.14214447566441, 37.305566106523784, 37.36124202183315, 36.53137697492327, 37.06504378999983, 38.420623438698904, 36.964402607509065, 38.712121214185444, 37.68486826760428, 36.93298632758004, 37.65085336140224, 38.21547787530081, 36.609613691057476, 36.04545818056379, 36.79315383093697, 38.10491813932146, 35.41889047622681, 38.632560866219656, 37.96970966884068, 46.38717780794416, 48.982604435511995, 48.16808101109096, 49.708124910082134, 48.31145361491612, 47.65503644943237, 37.707314423152376, 36.986664635794504, 37.00619602203369, 37.194690227508545, 34.95773506164551, 39.58791732788086, 34.89350938796997, 35.04385798318045, 33.63946723937988, 39.597544057028635, 46.89739097867693, 44.95763805934361, 36.25629084450858, 36.61321980612618, 32.02384778431484, 36.584933689662385, 34.942803382873535, 36.25187179020473, 34.663534436907085, 36.36070489883423, 33.52953978947231, 36.94675418308803, 31.27340064729963, 40.75031968525478, 48.59956761768886, 47.692792960575645, 49.854992457798545, 49.239552293504985, 45.074704783303396, 39.05449022565569, 37.7400404385158, 36.74240418842861, 33.67056737627302, 35.981420108250205, 37.57555225917271, 35.53590161459786, 38.097031933920725, 38.27393307004656, 37.4668025289263, 37.43082128252302, 38.16285569327218, 38.76743234906878, 35.899896894182476, 39.61926759992327, 38.346698079790386, 38.18925884791783, 35.67543881280081, 38.53257628849575, 37.953541210719514, 39.54025615964617, 37.37712212971279, 39.059072562626426, 38.95508234841483, 39.60927261625017, 36.49827575683594, 40.37716320582798, 39.18615511485508, 41.109923703329905, 38.234508991241455, 40.692733015332905, 39.40894562857491, 41.337953158787315, 41.79061092649187, 45.4815218108041, 45.584970065525596, 48.46998371396746, 53.24993092673165, 56.75069740840367, 58.315883363996235, 57.97762073789324, 52.904949392591206, 45.707706519535606, 44.27873999731881, 57.627525329589844, 57.247173990522114, 64.24585124424526, 13.395006486347743, 0.8801483458706311, 2.2588949714388167, 1.444971046277455, 11.099200078419276, 69.80843312399728, 59.811205182756694, 68.86507620130266, 64.12382698059082, 60.85353224618094, 41.7321765763419, 35.49129070554461, 46.76759515489851, 67.26649025508335, 40.159104415348594, 0.36373925475137575, 0.22588174284568854, 0.09652522299438715, 0.11645574388759476, 0.20524097899241106, 0.13303277508488723, 0.09409383524741445], [0.07626394342098917, 0.017581264721229672, 0.009634427127561398, 0.02362340532376298, 0.09196537945951734, 0.08443625311234168, 0.03411040661324348, 0.030128362788153545, 0.15919245779514313, 0.04974493570625782, 22.709434952054703, 55.52086625780378, 42.32719598497663, 31.57245806285313, 34.308085441589355, 39.86654356547764, 57.023497581481934, 47.35554129736764, 52.6179575238909, 50.09442738124302, 55.735315459115164, 21.46289685794285, 0.19046501043651784, 0.2397058489067214, 0.23171088791319303, 0.03054370085841843, 14.86257198878697, 64.48247909545898, 45.64395332336426, 48.381682532174246, 36.225916794368196, 49.0712947164263, 47.16041851043701, 53.55305651256016, 44.349893024989534, 45.90527507237026, 41.33229385103498, 40.655129364558626, 34.52902773448399, 36.20978307723999, 34.5541524205889, 33.07447099685669, 33.49847786767142, 34.91873482295445, 33.844268866947715, 35.9386157308306, 32.68074437550136, 33.92794254847935, 30.87755135127476, 32.84095941271101, 32.15619012287685, 33.85377400262015, 32.25771720068795, 32.70156117847988, 31.84696749278477, 34.10004595347813, 33.71196821757725, 34.52824258804321, 34.97704063143049, 36.10160657337734, 35.07836273738316, 37.07051202229091, 33.44017900739397, 33.48916728155953, 33.5798100062779, 35.53643315179007, 33.67744609287807, 34.921399457114084, 34.52401808329991, 35.01168434960501, 33.5424599647522, 37.46659408296858, 44.07525157928467, 45.72130067007882, 45.148998396737234, 46.88840348379952, 40.713191986083984, 35.55969224657331, 36.778406279427664, 35.2792455809457, 35.917691230773926, 36.693881443568635, 35.98202460152762, 35.149060658046174, 34.808970655713765, 35.34632349014282, 33.24399662017822, 38.2387751851763, 40.56308657782418, 37.856196948460166, 34.16175985336304, 32.10989080156599, 34.00444916316441, 34.62125812258039, 32.769257477351594, 34.72108636583601, 34.15154947553362, 33.391569410051616, 34.991732597351074, 34.440247126988, 36.15778623308454, 42.29480695724487, 42.741996492658345, 44.03332962308611, 41.50357389450073, 42.93284266335623, 43.317255224500386, 37.376243182591026, 32.07469470160348, 32.773933615003315, 33.426254817417686, 32.67657893044608, 33.6980996131897, 33.27228968484061, 34.16828073774065, 36.48386866705758, 32.887665203639436, 34.26647962842669, 34.0544171333313, 33.72662196840559, 34.0658677646092, 33.88188294001988, 33.05832685743059, 32.39097670146397, 33.26626559666225, 33.52273055485317, 32.146698883601594, 34.5038092476981, 34.96136896950858, 34.622414997645784, 34.13495717729841, 35.92181846073696, 35.55061789921352, 34.3176565851484, 34.636773450034006, 37.178542613983154, 36.00202151707241, 35.28754867826189, 35.2484963280814, 36.03177717753819, 35.872868401663645, 39.89067118508475, 42.24909128461565, 47.21447549547468, 47.44439138684954, 51.592806407383506, 49.287272521427695, 55.63361120223999, 52.66693884985787, 44.87442295891898, 39.84117916652134, 48.933101994650706, 53.944406849997385, 57.19866861615862, 5.7410589541707715, 0.45896483212709427, 0.7872503335986818, 0.7278441584536007, 10.997623494693212, 59.57280554090227, 48.78335094451904, 58.16132068634033, 53.30438048498971, 50.234471797943115, 35.30527005876814, 41.538724831172395, 45.71035030909947, 52.24837589263916, 15.333376714161464, 0.2669332336102213, 0.056387274459536584, 0.035248170739838054, 0.05458680892895375, 0.09451885601239544, 0.05223438908745136, 0.059339990839362144, 0.07885883775140558, 0.0472289685692106, 0.027076459855639508, 0.05266573379880615, 0.06704661516206604, 0.035948883675570996, 0.060202673476721556, 0.05519678816199303, 0.19242128117808274, 0.016088614905519143, 28.298204592296056, 63.05709784371512, 45.95735876900809, 31.61219481059483, 32.11611986160278, 46.380174023764475, 64.00260870797294, 53.68077482495989, 57.25359065192086, 53.38050494875227, 61.76238441467285, 22.637571471078054, 0.1897908451833895, 0.21909245715609618, 0.7535714379378727, 0.03686883466850434, 17.107097217014857, 68.02535166059221, 46.47393996374947, 51.48003714425223, 37.74531412124634, 51.46650900159563, 49.53315537316458, 54.71014697211129, 46.3016037940979, 46.83309234891619, 41.7616160937718, 43.88916492462158, 38.03208712169102, 39.4539977482387, 36.07532501220703, 36.928320612226216, 35.60901403427124, 37.22198275157383, 35.31046036311558, 38.28463329587664, 34.559259346553254, 36.46340274810791, 32.682571751730784, 35.566998277391704, 34.4764472416469, 35.049819537571494, 33.987895080021445, 34.96440533229283, 34.12522969927107, 34.65741307394845, 36.52612066268921, 36.37666143689837, 37.457081999097554, 36.56744507380894, 35.95666020257132, 38.453887939453125, 34.27725281034197, 36.24981164932251, 34.775612354278564, 37.516954626355854, 34.590171882084434, 36.816256591251914, 35.61945022855486, 36.15326642990112, 35.134552819388254, 38.070274421146934, 46.60928739820208, 46.15856122970581, 46.65979732785906, 47.712122849055696, 43.18692091533116, 40.330189909253804, 36.90283809389387, 34.29456424713135, 35.45447220121111, 35.703054428100586, 35.19364724840437, 35.737816265651155, 34.64034135001046, 36.46321514674595, 35.33399738584246, 39.39538969312395, 43.44018970217024, 39.301912103380474, 35.39427995681763, 34.65732274736677, 34.674443108694895, 35.33211442402431, 34.99292768750872, 34.697570187704905, 34.03796032496861, 34.34432029724121, 35.00422545841762, 34.69204984392439, 36.40251915795462, 41.0380619594029, 45.688790048871724, 45.593227999550955, 44.16594988959176, 46.392152718135286, 44.848363740103586, 37.58894838605608, 34.14102642876761, 33.64046083177839, 35.27421855926514, 34.322558539254324, 34.73938792092459, 33.99818883623396, 35.959974493299214, 37.78490495681763, 34.59129054205758, 35.38624436514718, 35.80095107214791, 34.739297594342915, 36.465713024139404, 36.054695810590474, 35.619161878313335, 36.591621330806184, 35.552730151585166, 35.291957310267854, 35.317384243011475, 36.00018719264439, 36.440709931509836, 36.04190417698452, 36.744415691920686, 37.84796333312988, 36.7677720614842, 36.95686033793858, 35.98760053089687, 37.694057260240825, 37.412446771349224, 38.48241376876831, 38.03444256101336, 39.35664653778076, 38.58465303693499, 41.230884892599924, 43.89005776814052, 49.15332167489188, 50.70498296192714, 54.05498743057251, 50.36177669252668, 57.95712007795061, 53.350592953818186, 47.703986508505686, 41.986435481480186, 52.54181916373116, 53.433068071092876, 61.18801852634975, 6.488911807537079, 0.2671214592243944, 0.8469232001474926, 1.208364908184324, 13.668346013341631, 64.91148172106061, 53.94457013266427, 62.91766139439174, 57.649676186697825, 56.618261269160676, 41.703789710998535, 41.31690011705671, 48.632686206272666, 59.868736267089844, 21.851724999291555, 0.25062301595296177, 0.05273053389308708, 0.05544882660199489, 0.00554358445307506, 0.04506098472380212, 0.047259377116071324, 0.032948205047952275, 0.21173389415655816, 0.17123958920793875, 0.1350108810833522, 0.1478786463184016, 0.15182824938424996, 0.14666602281587465, 0.26260827854275703, 0.09861749250973974, 0.3049529620579311, 0.17209990375808307, 30.691475118909562, 71.21881321498326, 55.83952801568167, 40.06775297437395, 45.973777362278526, 52.16997936793736, 66.88895988464355, 57.14973940168108, 63.66819190979004, 58.211392879486084, 66.16167804173061, 25.92582729884556, 0.30313872226646965, 1.0025818475655146, 1.3546490243503024, 0.08003473893872329, 20.25219930921282, 67.82195704323905, 49.56183058874947, 52.96584687914167, 39.60076107297625, 55.14160926001412, 51.08194358008248, 56.75631502696446, 47.80707345690046, 50.67924683434622, 44.46361419132778, 46.614363057272776, 39.815154688698904, 43.38260303224836, 38.623076575142996, 37.89687170301165, 39.177984033312114, 40.115820612226216, 39.372933115277974, 41.32455355780465, 37.10497161320278, 38.2536894934518, 35.08579730987549, 37.842133794512065, 36.583846296582905, 37.80359213692801, 35.65261745452881, 37.043337617601665, 36.65689270836966, 38.35353510720389, 38.87941299165998, 39.56031213487898, 39.191713673727854, 39.886502265930176, 37.948809487479075, 41.560017585754395, 35.335032667432515, 38.27230371747698, 36.57014792306082, 37.992138453892295, 36.95521361487252, 37.54188128880092, 37.399832316807334, 39.865285941532676, 35.860570090157644, 40.61957195826939, 48.74777269363403, 48.920779364449636, 47.790363039289204, 47.77311066218785, 43.02973529270717, 41.2546512058803, 37.72062717165266, 34.962824617113384, 34.63838543210711, 35.7337064061846, 35.6176506451198, 35.65879440307617, 34.91459369659424, 36.85520471845354, 35.195728233882356, 39.658677782331196, 44.77428552082607, 38.50692701339722, 35.64851801736014, 35.178482804979595, 35.30856697899954, 35.40360443932669, 34.7625914301191, 36.0715834072658, 33.831373010362896, 33.42228739602225, 35.87381335667202, 34.6915773664202, 36.45466191428048, 42.36494902202061, 47.11933381216866, 48.42274638584682, 46.46791240147182, 50.158451557159424, 48.293124267033164, 42.00477525166103, 36.83484649658203, 36.43905278614589, 37.12909575871059, 35.32922397341047, 35.84554808480399, 36.78387451171875, 37.70273208618164, 38.89066907337734, 35.32927261080061, 37.27631071635655, 37.2157814843314, 37.00071389334542, 38.40944726126534, 38.507250104631694, 36.04536785398211, 36.9633777482169, 37.235319818769185, 36.75329548971993, 38.20313092640468, 38.51684556688581, 37.947402477264404, 37.735544954027446, 38.884644985198975, 41.207841191973, 37.840382848467144, 38.55979585647583, 38.705047948019846, 39.699804169791086, 40.50112254279, 40.14547552381243, 39.060729707990376, 40.39246661322457, 40.475480215890066, 43.33477858134678, 47.28649704796927, 53.260728427342, 53.20517757960728, 56.367813450949534, 54.15103932789394, 58.9641363961356, 55.7145333971296, 49.639834540230886, 46.03743328366961, 54.758568968091694, 56.799154145377024, 62.993758065359934, 7.765752298491342, 0.529615255338805, 1.6072236427239008, 1.5100599250623157, 15.144472564969744, 72.3754242488316, 59.41081523895264, 68.64474882398332, 64.01152324676514, 62.206693921770366, 50.358229637145996, 51.08878060749599, 58.096066679273335, 68.22224971226284, 31.407855238233292, 0.37233803048729897, 0.10057550708630256, 0.1528868047254426, 0.11435774075133459, 0.23527151399425097, 0.22322097633566174, 0.2500268008027758], [0.050590003574533124, 0.020653060604152933, 0.031060252604740005, 0.006823357477385018, 0.030453085899353027, 0.11314574828637497, 0.051073161219911914, 0.007664405873843602, 0.12376405458365168, 0.04881034871297223, 9.88828192438398, 54.23081854411534, 44.04213299070086, 23.13346787861415, 22.78323871748788, 42.290676253182546, 56.552611214774, 50.80286570957729, 54.423981939043315, 50.207929679325645, 53.285884380340576, 34.84757137298584, 0.149049879184791, 0.19408707107816422, 0.7332924146737371, 0.1975136593516384, 15.676537820271083, 67.03539316994804, 48.120173181806294, 43.65927335194179, 38.332172870635986, 52.37059817995344, 49.007729121616904, 48.034463678087505, 44.47424840927124, 45.94881248474121, 38.06540025983538, 38.20062610081264, 34.73211315699986, 35.545194830213276, 32.78857694353376, 34.97863524300711, 32.25447586604527, 35.36588614327567, 32.88926676341465, 33.055721282958984, 34.08559022630964, 33.133207593645366, 32.70014374596732, 34.24990470068795, 34.24344287599836, 33.463643074035645, 31.465445382254465, 31.89409712382725, 30.930357660566056, 33.73218052727835, 33.22658790860857, 34.17410332815987, 33.55605411529541, 34.741722515651155, 34.48609481539045, 34.96890081678118, 34.51044825145176, 36.31279706954956, 34.86057145254952, 35.945730686187744, 32.69334493364607, 34.38594348090035, 33.37341376713344, 35.38617140906197, 35.36300611495972, 37.798770087105886, 43.58353451320103, 45.219845703669954, 44.37961394446236, 41.89454208101545, 40.28337294714791, 43.96060977663313, 39.14815541676113, 35.389100074768066, 35.614204338618684, 36.53007418768746, 34.833056586129324, 36.42391613551548, 32.492889404296875, 35.397486550467356, 35.73371682848249, 40.31460509981428, 39.8769519669669, 40.16303709575108, 36.14746468407767, 33.2932002885001, 34.45710693086897, 34.40700347082955, 34.2257353918893, 34.854331970214844, 35.059519222804475, 34.514856883457725, 34.3520119530814, 35.452735151563374, 35.82086113521031, 44.04850101470947, 46.87225587027413, 43.547247546059744, 43.66793080738613, 42.96673250198364, 44.53704970223563, 37.731049469539094, 32.45992367608206, 32.98110457829067, 31.86965683528355, 33.44404220581055, 33.83732066835676, 33.22136981146676, 32.17160470145089, 34.412975447518484, 33.97798694883074, 33.70428350993565, 33.950482504708425, 35.1576521056039, 34.10556282315935, 34.94443620954241, 32.00113064902169, 33.57716621671404, 33.49949925286429, 33.42160299846104, 34.14163787024361, 34.72687421526228, 34.53118862424578, 34.777241706848145, 34.36112451553345, 33.919834000723704, 34.12453140531267, 35.07993997846331, 35.775770800454275, 34.95015457698277, 34.85539504459926, 35.209697587149485, 34.672497613089426, 34.94935553414481, 35.17399079459054, 37.45674501146589, 38.71910067967006, 42.829592432294575, 50.35638836451939, 51.23128121239798, 46.907135827200754, 42.62647574288504, 53.97886644090925, 52.89759125028338, 41.67817865099226, 47.776848793029785, 52.51570783342634, 53.75871276855469, 2.482118010520935, 0.21959128896040575, 0.2669059565024716, 0.5736679743443216, 16.229473727090017, 61.62462248120989, 50.30686855316162, 60.4057069505964, 53.339427198682515, 46.631434781210764, 23.245071581431798, 40.60295186723982, 49.30937474114554, 49.56517614637102, 10.787727100508553, 0.18510602228343487, 0.0709849681173052, 0.12132100281970841, 0.10456073324062995, 0.03762733503910048, 0.014584133135420936, 0.052542474519993575, 0.06234953113432441, 0.013328339538670011, 0.048461249231227806, 0.10523966859493937, 0.012737172689022762, 0.06334218715450593, 0.08060973629887615, 0.01192387891933322, 0.2794114111789635, 0.06309578394783394, 13.572844760758535, 64.58292920248849, 51.315201554979595, 28.171003920691355, 29.543198449271067, 49.271194389888215, 61.18309225354876, 53.158173016139436, 58.72598688943045, 54.415407861982075, 57.458524295261924, 36.345710686274934, 0.23252987968070166, 0.4764598533511162, 0.7046150820595878, 0.042730030337614675, 16.480489560535975, 70.18975026266915, 50.02675887516567, 45.78988981246948, 39.84821074349539, 55.188829217638286, 50.099763597760884, 50.20397615432739, 46.53130776541573, 48.95358180999756, 41.33948523657662, 39.62125131062099, 37.388326099940706, 36.833290100097656, 34.95867306845528, 37.06820869445801, 34.15821279798235, 35.71009990147182, 35.137297357831685, 36.22373506001064, 35.81027208055769, 35.6408611025129, 34.19874164036342, 36.23096466064453, 34.26157420022147, 36.357116154261995, 34.7623656136649, 34.72641563415527, 34.21524361201695, 34.590491499219624, 33.23203182220459, 35.06053018569946, 35.21234137671334, 37.405613218035015, 36.46554626737322, 36.05847910472325, 34.602032457079204, 36.80961063929966, 37.42088883263724, 37.07317665645054, 35.906852040972026, 37.31435557774135, 35.02020978927612, 36.48996571132115, 36.615915707179475, 39.20757641111101, 46.392545291355674, 46.88061455317906, 45.566748414720806, 43.582731996263774, 41.41860784803118, 43.09535755429949, 39.115026405879426, 34.85701397487095, 34.48512206758772, 36.95114891869681, 34.536382402692524, 36.308812277657644, 33.35005739756993, 35.53262553896223, 36.22775459289551, 42.320911339351106, 42.45703002384731, 41.97109733309065, 36.962679454258506, 33.86870568139212, 34.46347148077828, 35.609677587236675, 36.02267156328474, 35.27608067648751, 35.013358865465435, 35.7998879977635, 34.53667075293404, 35.306948048727854, 37.32151222229004, 45.36595242364066, 48.532340322222026, 46.55663742337908, 45.66272388185774, 44.63533197130476, 47.00175986971174, 39.52511256081717, 34.39783879688808, 35.377236025674, 33.84123250416347, 34.56156962258475, 33.661121300288606, 35.48096568243844, 33.77315058026995, 34.57474340711321, 34.97653341293335, 36.142677375248496, 35.75875466210501, 36.36137539999825, 36.14625917162214, 36.28316647665841, 35.15087761197771, 36.848722049168174, 36.19935730525425, 35.59869595936367, 36.205388341631206, 36.00875084740775, 36.62578909737723, 37.96920592444283, 36.185777051108225, 36.000868116106304, 35.416840757642476, 36.51474298749651, 36.76494761875698, 36.58706331253052, 36.93081154142107, 37.40699243545532, 36.90422078541347, 38.21579054423741, 37.05935321535383, 38.65365212304251, 41.92542682375227, 46.448603357587544, 52.615431853703086, 53.692399161202566, 48.51261786052159, 45.51938601902553, 55.4596699987139, 54.53635515485491, 43.55295549120222, 48.707480090005056, 53.64596782411848, 56.28452886853899, 2.913921411548342, 0.4725767874291965, 0.39656327771289007, 0.8945730775594711, 17.38837592942374, 67.23668248312813, 53.192010743277415, 64.49925899505615, 57.24927929469517, 52.21778992244175, 31.53429160799299, 42.417880398886545, 54.70078427450997, 57.80170624596732, 14.820141077041626, 0.2057624738663435, 0.021204156568273902, 0.14295310633523123, 0.08515628054738045, 0.02745468884573451, 0.01446421055256256, 0.059086992272308896, 0.2027274410107306, 0.1189467002238546, 0.18789054001016275, 0.15843578268374714, 0.12020568123885564, 0.2153863124549389, 0.2604414719556059, 0.10707256131406341, 0.34312413952180315, 0.1602294221520424, 16.05760482379368, 73.18857887813023, 58.92706080845424, 35.54513577052525, 34.42312329156058, 53.76160669326782, 67.07224641527448, 61.14945602416992, 64.01726940699986, 59.53714738573347, 62.40708691733224, 40.92729377746582, 0.4975854169045176, 0.8445901253393718, 2.006228072302682, 0.25034473517111366, 19.11245502744402, 72.62124456678117, 51.59814262390137, 48.28886502129691, 42.94033282143729, 58.546313422066824, 50.428003447396414, 50.474320139203755, 49.68008892876761, 50.586818422589985, 44.06783785138811, 42.413635049547466, 39.79023150035313, 40.13065849031721, 36.63322366986956, 40.20887783595494, 36.724488258361816, 39.71536466053554, 37.363673891339985, 37.66341570445469, 38.78350005831037, 37.70923907416207, 37.25683144160679, 37.10788985661098, 37.89486019951956, 37.844808850969585, 36.47527721949986, 36.39027295793806, 36.204967975616455, 37.780930587223594, 36.345755849565776, 38.30673551559448, 38.03260823658535, 39.719165325164795, 37.133004120418, 38.01390021187918, 36.95164224079677, 39.587003639766145, 39.51903288705008, 38.90909569604056, 36.224176270621165, 38.16781323296683, 36.27261216299874, 39.00119406836373, 38.71608863558088, 41.37108564376831, 48.41388395854405, 47.435108593532014, 49.13004173551287, 45.57032673699515, 44.673633916037424, 45.64371708461216, 39.23631763458252, 34.4440929549081, 34.572749274117605, 37.18162761415754, 35.50025388172695, 38.24960742677961, 33.455659593854634, 37.94719055720738, 38.186771392822266, 43.82608917781285, 44.00480031967163, 43.57673570087978, 38.63720573697771, 33.49940545218331, 35.373800141470774, 36.64398642948696, 36.03008876528059, 34.10324559892927, 36.122517177036826, 36.25679458890642, 36.1030205317906, 36.766205242701936, 36.87436785016741, 46.7683698790414, 51.258486883980886, 49.791847229003906, 48.784455708095, 48.43595143726894, 51.582359790802, 41.23721470151629, 37.31754132679531, 37.14265864236014, 35.495998110089985, 36.77739879063198, 36.316889558519634, 36.7010554586138, 35.318593229566304, 37.308449608939036, 36.96758140836443, 37.41905450820923, 37.59759194510323, 38.543884481702534, 37.0038058417184, 38.87895788465227, 36.36722925731114, 39.162857804979595, 37.939384256090435, 37.434510775974815, 39.82777956553868, 38.00001771109444, 38.341810022081646, 39.1454873085022, 38.594880785260884, 36.65229647500174, 38.628051485334126, 37.790418352399556, 39.74189635685512, 37.784046854291645, 39.50254828589303, 38.86073275974819, 38.572472844805034, 39.2649233681815, 38.96037687574114, 41.23713479723249, 43.525819301605225, 48.946960176740376, 55.3237111227853, 55.87251458849226, 49.49351242610386, 47.73114006859915, 57.611283915383474, 58.46447059086391, 45.695581912994385, 52.44675043651036, 56.44224950245449, 60.03329740251814, 3.632687802825655, 0.3580959604254791, 2.185580402612686, 1.1573699074132102, 21.12211898394993, 72.96111570085797, 59.573347500392366, 70.81369154793876, 63.015839440482004, 59.557714053562705, 33.88942868368966, 49.74001019341605, 58.743593624659944, 65.8196599142892, 21.06297070639474, 0.35353083110281397, 0.13272239959665708, 0.35735149894441876, 0.3024358685527529, 0.10138014783816678, 0.13938816477145466, 0.2782892499651228], [0.10593767756862299, 0.055691565719566176, 0.06170677526720932, 0.03967959134440337, 0.043895007111132145, 0.040185425630105395, 0.06284390496356146, 0.01377628036841218, 0.05254177223624928, 0.07031671290418931, 3.3516933151653836, 46.193920612335205, 47.88264553887503, 33.20202950068882, 19.443845885140554, 36.0368458884103, 52.863169874463765, 57.21677214758736, 54.968060629708425, 50.484092780521934, 51.06403112411499, 43.078108651297434, 0.9367110793079648, 0.30823419455971035, 0.43565102027995245, 0.26892006556902615, 13.07232345853533, 67.52622781481061, 44.96109478814261, 45.00695637294224, 42.76440443311419, 54.94726814542498, 46.33485787255423, 47.21416630063738, 46.869052750723704, 41.61133003234863, 37.603383268628804, 38.131752082279746, 34.83912583759853, 35.371673992701936, 32.37701777049473, 33.986720834459575, 33.286418846675325, 34.417700222560335, 32.81724868501936, 35.81661925997053, 35.07429109300886, 34.678163869040354, 32.823213713509695, 32.87218114307949, 32.695373807634624, 33.53772129331316, 33.19944824491228, 32.60989359446934, 31.70704119546073, 31.39834315436227, 32.1479287147522, 33.08710977009365, 33.12452581950596, 35.08693334034511, 34.20783335821969, 33.108628341129844, 35.62320225579398, 35.170850208827424, 34.21880456379482, 35.21808058874947, 34.14961787632534, 34.1358882359096, 35.036812509809224, 32.15943840571812, 34.077120372227256, 40.11563648496355, 44.7917081287929, 45.512312752859934, 40.86386367252895, 43.51560892377581, 46.79805953162057, 44.46425689969744, 39.089325019291465, 34.16805492128645, 37.15312957763672, 36.348753997257774, 36.14040184020996, 33.48397350311279, 33.44832924434117, 33.81996406827654, 35.111099175044465, 38.85125889096941, 39.40938336508614, 37.498097215379985, 36.213569845472065, 33.5849620955331, 34.52075242996216, 34.70375061035156, 34.13122599465506, 33.59137180873326, 35.22309718813215, 34.17805685315813, 34.20009306498936, 34.52559185028076, 36.88452959060669, 43.00962025778634, 44.77766581944057, 43.30721160343715, 42.164198194231304, 42.26722608293806, 42.716013704027446, 40.116067273276194, 33.72129964828491, 32.10948085784912, 32.70035219192505, 33.231451647622244, 33.14442546027047, 32.47671399797712, 32.57128592899868, 32.73301567350115, 34.02475527354649, 34.38753809247698, 33.87031418936593, 34.43054049355643, 34.898248059409006, 34.71272768293108, 33.153847217559814, 32.50225905009678, 35.778362478528706, 34.04917124339512, 32.66586480821882, 34.69569417408535, 35.17926795142037, 37.384775570460725, 36.99580846514021, 35.182540552956716, 36.040271350315635, 37.131694384983604, 36.035532678876606, 34.60852207456316, 35.76966680799212, 35.22194378716605, 35.04956245422363, 35.36148793356759, 35.352740151541575, 38.10387590953282, 38.20682041985648, 40.713904176439556, 46.27246652330671, 51.17878409794399, 53.38961403710501, 48.776208196367534, 44.86566822869437, 51.26653984614781, 49.83451611655099, 47.13533551352364, 59.15206432342529, 39.03162717819214, 0.07029962739241974, 0.0984970254025289, 0.5007286625249046, 0.3189144443188395, 19.658288138253347, 59.90837574005127, 47.51097597394671, 60.373335293361116, 51.64161055428641, 49.35381889343262, 23.180375167301722, 45.38249955858503, 41.22506577627999, 44.29494667053223, 3.8435927714620317, 0.21691563539206982, 0.07400714273431472, 0.10058060966964279, 0.07076240184583835, 0.06294554950935499, 0.04117725044488907, 0.0002623582419931024, 0.079035942176623, 0.06170305689530713, 0.058619936262922626, 0.038552025599139075, 0.011176799989438482, 0.037981180873300345, 0.05202512888770018, 0.012172460223415067, 0.04388532780909112, 0.07036523494337286, 5.203757796968732, 55.916270869118826, 51.83694526127407, 36.30673476627895, 25.164900541305542, 47.11949362073626, 59.743668692452566, 60.67813886914934, 57.602008070264546, 55.21303326742989, 56.79865040097918, 46.47018446241106, 1.0599346671785628, 0.5681456221001489, 0.5814786180853844, 0.3858041007603918, 13.9518073286329, 69.31084483010429, 46.84539066042219, 47.19421454838344, 44.85965803691319, 56.339489119393484, 47.89210203715733, 48.71687058040074, 48.31069278717041, 45.14959246771676, 39.79299340929304, 39.656377928597585, 36.77295541763306, 35.79498604365757, 33.96136685780117, 36.34364012309483, 36.45555823189871, 36.55659546170916, 34.296509742736816, 37.866247517721995, 36.32888214928763, 35.46059356416975, 34.62452377591814, 35.21570430483137, 35.37663153239659, 35.0899384362357, 35.455590861184255, 35.09997163500105, 35.09609106608799, 34.162451199122835, 34.813823972429546, 34.57643529347011, 35.29748807634626, 37.41757106781006, 35.60271201814924, 35.81116839817592, 36.827912194388254, 37.41267258780343, 35.387050356183735, 36.702139377593994, 34.30584117344448, 36.160985878535676, 36.91515030179705, 34.87675033296858, 36.27328266416277, 40.57248401641846, 44.971339906964985, 45.88116829735892, 43.053633621760774, 46.47128575188773, 49.18782990319388, 43.910752977643696, 38.62602261134556, 34.727308477674214, 36.902431624276296, 34.96466588973999, 34.56733315331595, 34.26529148646763, 34.24546480178833, 35.18380512510027, 37.14647667748587, 39.4627594266619, 41.73206193106515, 40.20820038659232, 36.13120242527553, 34.196650232587544, 34.7067939213344, 34.88211434228079, 34.97506039483206, 34.61963224411011, 34.130510330200195, 34.38710730416434, 33.92380142211914, 34.49406092507498, 36.35056052889143, 45.016444138118196, 47.86043562207903, 47.43298591886248, 44.92999465124947, 45.318197454724995, 45.30995341709682, 42.176927294049946, 34.91753625869751, 33.86350842884609, 34.90207651683262, 34.616415228162495, 33.919837474823, 33.66852807998657, 34.313890661512104, 35.351246288844514, 35.32695191247122, 35.61506591524397, 36.26500735964094, 35.58038050787789, 36.16532850265503, 35.48961271558489, 35.15629025868007, 35.71845163617815, 36.29704202924456, 36.96681015832083, 35.52205038070679, 35.8209445135934, 37.137013231004985, 38.86343560900007, 39.420285088675364, 36.26012972423008, 36.76197031566075, 38.218291895730154, 37.16479560307094, 36.482725688389365, 37.134081091199604, 37.0089544568743, 36.376772608075825, 37.85849332809448, 37.73903642381941, 39.65981381280081, 39.983040537152974, 43.75420658929007, 50.27149180003575, 53.153681005750386, 54.5853225844247, 48.965352058410645, 47.80203948702131, 54.3916346005031, 52.01388808659145, 50.95655986240932, 59.41354588099888, 41.64402478081839, 0.023926600215158293, 1.1228804609605243, 0.7074600436857769, 0.2590399443038872, 21.544354064123972, 67.66874926430839, 50.914175851004465, 68.0489616394043, 57.15750053950718, 56.21233013698033, 24.770553793225968, 44.91781793321882, 47.965461117880686, 52.08215413774763, 6.329409394945417, 0.3530783568109785, 0.09439868746059281, 0.08354884465890271, 0.0850867171372686, 0.029862658652876104, 0.046552360590015135, 0.02977443892242653, 0.2920747202421938, 0.1262400560081005, 0.1264139645333801, 0.17371932257499012, 0.11676085394408021, 0.1304863417255027, 0.16043306408183916, 0.12311774997838906, 0.16196314697819097, 0.1882320466850485, 5.938101615224566, 64.60095977783203, 62.600920813424246, 45.18149512154715, 27.879044089998516, 48.00175503322056, 63.651940073285786, 66.23175757271903, 63.78811781747, 60.9889873777117, 62.40599605015346, 51.41984837395804, 1.5889876612595148, 1.1835788381951196, 2.0997938173157826, 0.44523247757128304, 14.909342050552368, 71.69920471736363, 49.355257170540945, 50.6366856438773, 47.15693746294294, 58.54469449179513, 47.19354404721941, 51.6210230418614, 50.73846633093697, 45.733442647116526, 40.97374595914568, 42.16982970918928, 38.77444308144705, 39.83924756731306, 35.706122057778494, 38.655764375414165, 38.08716549192156, 38.58681045259748, 36.26924228668213, 41.047733851841514, 39.71519442967006, 38.76925277709961, 36.37513630730765, 37.96929972512381, 37.9893661226545, 38.92204713821411, 39.2728408404759, 37.72887815747942, 37.685781955718994, 36.34825720105852, 37.41334656306675, 36.549810545785085, 35.86110162734985, 40.37820543561663, 38.99888031823294, 37.689589568546836, 38.884575503213064, 39.43820449284145, 37.513317244393484, 37.68604251316616, 33.72506557192121, 38.32845558438982, 39.34671408789498, 37.363149302346365, 38.08291319438389, 42.6982228415353, 48.279783725738525, 49.36052737917219, 44.20470346723284, 47.71689278738839, 49.76337003707886, 46.46494204657418, 39.65517936434065, 35.078796999795095, 37.31223290307181, 35.57492617198399, 36.52165991919381, 35.13791922160557, 34.49270602634975, 36.0396077973502, 38.75321633475167, 40.60857990809849, 43.269052096775596, 40.90189116341727, 38.677046707698274, 36.13277619225638, 35.6015169279916, 37.56608533859253, 35.80694041933332, 34.14006757736206, 34.98299176352364, 35.19603048052107, 34.598165784563335, 35.41676432745797, 37.33828169958932, 47.01483290536063, 50.46499913079398, 49.979976654052734, 47.2103864806039, 48.83626842498779, 46.35450042997088, 45.06967428752354, 38.10246889931815, 36.30856214250837, 36.14168725694929, 35.66823353086199, 35.92314209256853, 35.9053373336792, 35.37115635190691, 36.90367535182408, 36.94738299506051, 38.05688871656145, 38.359302112034385, 38.168223176683696, 38.93196569170271, 39.03087329864502, 38.27059098652431, 36.990361077444895, 39.224592549460276, 39.78744527271816, 37.05865839549473, 38.31451749801636, 38.45393310274397, 41.70782314028059, 40.52654947553362, 38.805949687957764, 39.152543204171316, 40.75377641405378, 38.21668338775635, 38.49059527260916, 38.81356838771275, 39.34518895830427, 38.899847643715994, 40.419602802821565, 39.38550935472761, 41.898193359375, 41.74288027627127, 46.50841345105852, 52.11063480377197, 56.47419037137713, 57.81644684927804, 49.94109800883702, 50.20403868811471, 57.58020462308611, 55.08284487043108, 53.83278751373291, 62.20078795296805, 45.298541000911165, 0.19417487350957735, 0.9623429839100156, 2.528254266296114, 0.5274632136736597, 25.169501985822404, 73.22860050201416, 55.95973185130528, 71.88990497589111, 61.312148094177246, 63.06300381251744, 35.62237542016165, 54.9208094051906, 52.08321373803275, 63.94459124973842, 9.670528854642596, 0.5340037484254155, 0.1076632056917463, 0.18035620929939405, 0.1477255281060934, 0.15566102229058743, 0.32147425838879173, 0.14669625833630562], [0.05702327551054103, 0.02112758219508188, 0.09367666513259922, 0.055050041393509934, 0.04976120697600501, 0.009538936894387007, 0.018859862183619822, 0.07289362605661154, 0.047605711567614756, 0.04424099550981607, 1.8414749928883143, 47.89926562990461, 52.87329339981079, 32.715586117335725, 25.63188202040536, 36.62831824166434, 47.73603507450649, 55.56167997632708, 51.38993985312325, 51.44688034057617, 47.23029654366629, 49.92780957903181, 4.925240993499756, 0.6846922082560403, 0.4477402887174061, 0.2516788164419787, 6.033150366374424, 63.73197637285505, 50.94709989002773, 47.127028942108154, 51.01833977018084, 50.82809809276036, 44.5290801184518, 51.078493799482075, 43.235523564474924, 40.64180619376046, 37.0997257232666, 36.12987184524536, 33.91303171430315, 32.99387884140015, 32.836641107286724, 33.87096732003348, 32.28226171221052, 34.76715987069266, 34.317406449999126, 33.92095613479614, 34.4755266053336, 35.00249188286917, 33.045552594321116, 32.80399152210781, 32.01945652280535, 32.80470718656267, 31.868402685437882, 32.501487800053184, 32.18647384643555, 31.937752655574254, 33.94386087145124, 32.43011590412685, 33.478401047842844, 34.642999035971506, 32.895700795309885, 36.199343408857075, 35.341411113739014, 33.9038531439645, 33.0091336114066, 34.290162563323975, 33.91380296434675, 34.59987851551601, 32.97951691491263, 31.82303442273821, 31.19511181967599, 38.03616224016462, 46.07308101654053, 42.223789419446675, 43.921967370169504, 47.86389235087803, 44.22199753352574, 43.21542937414986, 39.518247740609304, 34.08414500100272, 36.4541130065918, 36.43863589423043, 35.78419549124581, 34.056018693106516, 33.94568477358137, 34.89790759767805, 34.73213400159563, 38.391392367226736, 39.8790260042463, 39.497024468013215, 36.42284958703177, 33.39198282786778, 33.13670948573521, 34.31054857798985, 34.40130247388567, 35.01512023380825, 35.77785873413086, 35.460812432425364, 36.08332586288452, 35.5115099634443, 38.944430759974885, 44.73972865513393, 45.06536293029785, 45.015662465776714, 43.52408572605678, 42.237630231039866, 41.582397733415874, 42.51359530857631, 35.549645151410786, 31.3206136567252, 31.008469309125626, 32.92905909674508, 34.672125884464805, 33.53881216049194, 32.69601651600429, 33.926935059683665, 34.02042654582432, 32.81161369596209, 34.03224195752825, 34.67565904344831, 33.7889473097665, 33.97357484272548, 32.44384901864188, 33.36056654793875, 34.39952720914568, 34.37416975838797, 33.286849634987966, 34.74629095622471, 33.76877668925694, 34.51217835290091, 35.637453011104036, 35.31629337583269, 37.534898349217, 35.10571779523577, 37.93704271316528, 35.75785139628819, 35.64773634501866, 35.089479855128694, 36.05131203787667, 33.24173150743757, 35.65446220125471, 35.06253474099295, 37.82838678359985, 37.26535340717861, 45.62556144169399, 47.420600754874094, 51.06860303878784, 51.52723625728062, 50.49879516874041, 43.602079255240305, 57.01507289069039, 43.99193920407976, 65.36043957301548, 12.213979482650757, 0.07884952825094972, 1.601664649588721, 0.35363627544471193, 0.09758526432727065, 22.842939376831055, 61.00187628609793, 48.67647722789219, 58.79885264805385, 46.892429964882986, 47.09036677224295, 21.41277081625802, 43.48739576339722, 47.58470678329468, 41.60104669843401, 1.7680431732109614, 0.19506969835077012, 0.018978164764121175, 0.03782694307821138, 0.015162828511425426, 0.05536770434784038, 0.02127933146298996, 0.019650194328278303, 0.026566990318575075, 0.015088593387710196, 0.05351751916376608, 0.06948757703815188, 0.019937358829858046, 0.012542608709606742, 0.03426277504435607, 0.04633889686582344, 0.0728339081896203, 0.03996947846774544, 2.629528820514679, 55.45798853465489, 59.52175712585449, 37.73806367601667, 19.740219558988297, 41.63669443130493, 54.657010623386924, 60.69193799155099, 55.27781132289341, 56.75414718900408, 50.64694465909685, 54.409481048583984, 5.121365623814719, 0.6232704584087644, 0.7352044720734868, 0.5493470536811011, 7.66605954510825, 64.44210311344692, 52.05184262139456, 50.68917233603341, 52.39358976909092, 52.75294712611607, 46.78115456444876, 54.24422856739589, 45.29051235743931, 43.67870398930141, 39.625798906598774, 38.38200535093035, 36.74816424506051, 34.97165925162179, 34.915986810411724, 36.05580404826573, 34.01641743523734, 37.24858045578003, 35.34008748190743, 36.36675330570766, 35.940901688167024, 36.96726873942784, 34.375323159354075, 35.23679208755493, 34.53268248694283, 34.87593739373343, 32.90376417977469, 34.38103805269514, 35.21746219907488, 33.5055650302342, 35.203986167907715, 34.87845958982195, 35.216958454677034, 35.847135748182026, 35.85026591164725, 37.02144384384155, 36.49280057634626, 36.068606104169575, 35.815851484026226, 35.580932889665874, 35.18937758037022, 34.697559765407014, 34.93525416510445, 34.35464532034737, 34.354853766305105, 40.56077282769339, 47.49213940756661, 45.09689038140433, 45.3965870312282, 48.10059315817696, 46.870862756456646, 43.39419262749808, 39.57332958493914, 35.41403021131243, 36.02720178876604, 36.18313326154436, 36.6136714390346, 33.95845208849226, 33.92184550421578, 36.037631034851074, 36.24259941918509, 39.773927552359446, 42.81430639539446, 40.299183573041645, 36.443812302180696, 34.35005603517805, 33.7957079069955, 35.02819674355643, 34.64892932346889, 34.44719532557896, 35.88659804207938, 36.08590711866106, 35.318857261112754, 34.649961130959646, 37.98183427538191, 46.479199750082834, 46.830472878047395, 47.582809925079346, 45.82136862618582, 44.80845676149641, 44.28148453576224, 43.79794202532087, 36.83980751037598, 33.70565577915737, 34.159630230494905, 33.83701842171805, 35.28568308694022, 35.1958463532584, 34.97844764164516, 35.170808519635884, 35.872788497379844, 34.98478439876011, 35.72314861842564, 34.464822905404226, 35.621093477521626, 34.55028574807303, 34.85637821469988, 35.66449192592076, 35.6465516771589, 36.36594384057181, 34.60521125793457, 36.943231446402415, 35.368338857378276, 36.46623066493443, 36.865453311375205, 37.0127203805106, 38.793335233415874, 37.38082204546247, 39.558043548039024, 36.83338737487793, 38.09366205760411, 36.91653994151524, 37.55528783798218, 36.3740245955331, 38.45700420652117, 38.15579284940447, 39.86964593614851, 38.97688579559326, 48.03567613874163, 50.14953701836722, 53.899351256234304, 52.886272634778706, 50.84615298679897, 45.81968368802752, 60.7632543018886, 47.68653610774449, 67.09496702466691, 14.325218285833087, 0.15852479290749344, 1.425191587635449, 0.9858585106475013, 0.2425551260156291, 25.07540774345398, 67.50207587650844, 52.27788489205496, 66.00876903533936, 50.456636973789756, 56.3510856628418, 26.21670494760786, 49.23440367834908, 53.214133807591026, 49.34342091424124, 3.6577766622815813, 0.1881723627448082, 0.04186187192265477, 0.040536228234746625, 0.024041957953678708, 0.0463722536473402, 0.019433755228029828, 0.025610676633992364, 0.11491257883608341, 0.08746053797325917, 0.21841146584068025, 0.14398305464003766, 0.06225110284451928, 0.13061936173055852, 0.2099772755588804, 0.14822231073464665, 0.19805237544434412, 0.1704407227890832, 3.1084281972476413, 65.49730518886021, 67.53645556313651, 44.86909021650042, 35.40710285731724, 49.5894809450422, 59.60080678122384, 64.92162609100342, 59.91816575186593, 61.14015933445522, 56.00327621187483, 59.16086769104004, 7.070834296090262, 1.5405361354351044, 2.941159869943346, 0.4616331575172288, 8.43514609336853, 68.21293912615094, 54.08186306272234, 53.092898164476665, 55.018678256443565, 52.64318643297468, 49.92767408915928, 56.36590617043631, 46.77516869136265, 45.33206605911255, 41.77922977719988, 40.98000628607613, 40.22160693577358, 36.691598960331504, 36.468235220227925, 38.78407675879342, 35.12458562850952, 40.455868925367085, 38.124463421957834, 37.81541797092983, 37.6276706968035, 40.194366523197715, 36.87093544006348, 36.96739728110177, 35.25496162687029, 36.21290976660592, 34.83454350062779, 38.23963328770229, 36.67424236025129, 35.19713871819632, 39.03090803963797, 36.334305218287874, 37.92092636653355, 38.15672043391636, 36.16936540603638, 39.254105022975374, 38.01041569028582, 36.87528501238142, 35.16804313659668, 37.11414670944214, 36.26147420065743, 38.55042621067592, 36.83364445822579, 36.04149770736694, 36.23524475097656, 42.20615141732352, 50.04974699020386, 46.503706046513145, 47.92193065370832, 50.673750809260774, 48.590621812003, 45.47515378679548, 39.71069547108242, 33.380024978092735, 36.370588711329866, 35.487757546561106, 37.19193179266793, 34.79023831231253, 34.37454843521118, 36.60988119670323, 37.15680864879063, 41.46759612219674, 44.92522471291678, 43.48912933894566, 38.68092032841274, 36.416936670030864, 34.83974770137242, 36.045385224478586, 36.00476605551583, 35.4089788709368, 36.948522499629426, 35.56248542240688, 36.77434505735125, 36.74174410956246, 39.80482619149344, 48.53693308149065, 47.04324408939907, 52.00338241032192, 48.24718277794974, 45.600207465035574, 46.020684650966096, 47.24486344201224, 39.44980798448835, 34.73587908063616, 34.521812030247276, 35.21261583055769, 38.28441442762102, 36.783207484654014, 36.31089326313564, 37.71782009942191, 38.1238728250776, 36.51606314522879, 37.07320097514561, 37.33771889550345, 38.18739325659615, 37.84626797267369, 36.568341391427175, 37.693536145346506, 38.806859901973176, 39.54996974127633, 36.94063976832798, 39.7296119417463, 37.892108712877544, 37.62407847813198, 38.780578340802876, 39.716413838522776, 41.88682958057949, 38.134805815560476, 41.75653001240322, 37.89932441711426, 39.158810479300364, 38.377190249306814, 39.82719939095633, 37.53915064675467, 39.400632108960835, 39.63209050042288, 40.790942328316824, 41.63249771935599, 50.32097339630127, 52.9468400818961, 56.981815338134766, 56.078657218388145, 51.902508463178364, 48.74024779456002, 62.58740656716483, 49.4299954686846, 69.22399929591587, 15.73517540522984, 0.21673836133309773, 4.233243405818939, 2.4718275112765173, 0.3609494444515024, 28.412933247429983, 74.15915189470563, 57.26905039378575, 71.05069460187639, 57.20710372924805, 60.63840906960623, 32.050716468266074, 56.49174152101789, 57.82862704140799, 62.67680903843471, 5.511632476534162, 0.35647648732577053, 0.17508442646690778, 0.14073331973382405, 0.12186441437474319, 0.16991066480321543, 0.10326319108051912, 0.1201818510890007], [0.07158564802791391, 0.04307246321280088, 0.0417056222712355, 0.013260497062999223, 0.0577425022742578, 0.010218474448525479, 0.04887373745441437, 0.04049129564581173, 0.038159784860908985, 0.11616112398249762, 1.3283154602561678, 34.56142371041434, 48.50849757875715, 43.71772159848894, 28.571730852127075, 22.428918804441178, 42.62176833833967, 57.14273909160069, 52.39413520268032, 53.82951143809727, 45.66524607794625, 52.23129374640328, 12.565377678189959, 0.5781995026128632, 0.649735224034105, 0.038660550490021706, 0.6675397115094321, 45.229024274008616, 54.8097493989127, 48.82833705629621, 55.16850921085903, 43.84911550794329, 51.419553075517925, 47.0442133631025, 42.11352845600673, 37.04510246004377, 35.2712482043675, 34.4364012990679, 33.932927880968364, 34.73275933946882, 35.50309222085135, 33.426692553928916, 33.35889550617763, 32.17410952704293, 32.836172103881836, 32.74345186778477, 33.35727310180664, 32.2511476789202, 33.91716589246477, 32.483106340680806, 33.767348834446494, 34.99397339139666, 31.951461451394216, 31.762567724500382, 33.77813243865967, 32.82783079147339, 33.54320689610073, 32.15118394579206, 34.26338768005371, 33.89591135297503, 35.420432976314, 35.461302280426025, 34.40402964183262, 34.85582930701119, 33.72317566190447, 33.89783252988543, 34.31761142185756, 35.2124525478908, 35.01605824061802, 31.790575913020543, 31.45894534247262, 40.07045929772513, 42.01133435113089, 42.52596310206822, 44.55171387536185, 44.11193459374564, 43.96847513743809, 42.402177470070974, 38.99534368515015, 38.43148694719587, 36.43431064060756, 36.801001821245464, 32.994778633117676, 34.05624450956072, 33.49892602648054, 34.40146228245327, 37.26010056904384, 36.44238792146955, 40.63998229163033, 38.11216163635254, 35.83328798839024, 33.83210604531424, 34.19596583502633, 34.74564824785505, 33.35613012313843, 34.76996694292341, 35.261927195957725, 34.368079662323, 34.98293270383562, 34.61473723820278, 39.04143108640398, 43.85662998471941, 45.2434070450919, 43.704287256513325, 43.1656767981393, 41.66535575049264, 43.15397603171212, 42.41618503843035, 36.91004684993199, 31.228855746132986, 32.818454197474885, 33.4677529335022, 34.76630176816668, 33.2613844871521, 34.462095737457275, 34.434869221278596, 34.16748864310128, 35.0941664150783, 34.22862236840384, 33.94196401323591, 34.88288559232439, 33.16234139033726, 32.607187271118164, 31.989739077431814, 33.09415176936558, 32.69451917920794, 33.37353883470808, 34.506918566567556, 33.21886498587472, 34.221646377018516, 35.17213215146746, 35.27485431943621, 35.59894609451294, 35.86459309714181, 35.622566495622905, 35.792046955653596, 37.62917150769915, 35.386619567871094, 34.9349102292742, 34.069248063223704, 34.98589263643537, 34.65321636199951, 35.61759505953108, 37.026651518685476, 39.62005969456264, 47.418568406786235, 49.11666297912598, 49.80077913829258, 51.640964371817454, 49.101217133658274, 50.95838376453945, 54.962957177843364, 43.96033532278878, 0.5147777029446193, 0.22200411877461843, 1.0299713207142693, 0.4357430567698819, 0.0533528929975416, 29.317701612200054, 57.31242104939052, 43.22804730279105, 51.936884675707134, 44.814824785505024, 36.75300713947841, 21.38161161967686, 36.377953801836284, 48.758622305733816, 32.45226328713553, 0.49570392072200775, 0.11065341452402727, 0.07068684697151184, 0.0075356937179874095, 0.019413887722683803, 0.039535711386374066, 0.0527329834045044, 0.026457378075325062, 0.04621788693059768, 0.025764809256153445, 0.0382982874289155, 0.01250790333974042, 0.015088308403002364, 0.028310709965548346, 0.07027375485215868, 0.0393591769305723, 0.0416938768300627, 0.022746688885880367, 1.5120920560189655, 42.390532289232524, 53.65116160256522, 44.76559679848807, 33.65301275253296, 38.58084889820644, 48.04035575049264, 61.17970848083496, 56.61521448407854, 58.85350022997175, 48.55905614580427, 57.81354597636631, 12.390370794704982, 0.6661704821246011, 0.991725395832743, 0.38595628259437426, 0.8548607570784432, 49.993970326014924, 57.366901874542236, 51.25638852800642, 57.341732025146484, 46.652008397238596, 53.19547094617571, 49.189139638628276, 44.61712769099644, 39.04459946496146, 38.206632818494526, 36.84963573728289, 36.768981048039024, 36.79256323405674, 38.35215588978359, 35.927484716687886, 35.25300570896694, 36.21946539197649, 33.58791855403355, 36.30067246300833, 36.1569732938494, 34.344195229666575, 35.924740178244456, 33.16488095692226, 34.75843988146101, 35.5642363684518, 34.653612409319194, 34.258572578430176, 35.55830260685512, 35.628826822553364, 35.77995361600603, 34.74054479598999, 35.66925491605486, 35.12418610709054, 36.27393926892962, 37.43953432355608, 35.1063848223005, 35.63262401308332, 34.32546636036464, 35.22677278518677, 36.46684210641043, 36.33708797182356, 36.62562928880964, 34.1855400630406, 33.370790822165354, 41.49070235661098, 44.71050453186035, 44.73621981484549, 45.31617900303432, 44.445284843444824, 44.13815014702933, 42.44439819880894, 39.872585024152485, 38.23666640690395, 37.03691053390503, 37.127598421914236, 33.907264709472656, 34.31287622451782, 34.57225942611694, 35.126920223236084, 38.05287265777588, 38.49440288543701, 41.77472039631435, 39.65689556939261, 36.20529454095023, 34.27826377323696, 34.692244393484934, 36.15778623308454, 34.83803497041975, 36.147735663822715, 35.959845951625276, 35.35611350195748, 35.19435943875994, 35.32231051581246, 39.445760658809114, 46.12104095731463, 47.25632796968733, 45.69329942975725, 45.03608669553484, 43.14840357644217, 43.65406220299857, 43.29324919836861, 39.70516470500401, 32.1041168485369, 33.26095717293875, 35.316922187805176, 34.96567685263497, 35.73919895717076, 35.23761544908796, 35.90147760936192, 35.81524699074881, 35.74150228500366, 34.61676958629063, 35.46904952185494, 35.97726855959211, 33.43330723898751, 34.05540725163051, 34.83716297149658, 34.462335450308665, 34.93970101220267, 35.970744201115195, 36.775276115962434, 35.532767977033345, 35.97842196055821, 37.13165269579206, 35.81948191779, 37.15557534354073, 37.7717033794948, 36.97835806437901, 37.5219920703343, 39.47776058741978, 36.27140665054321, 36.26724467958723, 36.586580412728445, 36.88084704535348, 36.91346883773804, 38.03019026347569, 39.54847935267857, 42.52310391834804, 49.84772464207241, 52.417654854910715, 52.414448261260986, 55.01374503544399, 50.427325998033794, 54.32366384778704, 58.087541239602224, 48.84630509785244, 0.8489627678479467, 0.09002675062843732, 3.129430430276053, 0.4503170390214239, 0.05978424807212182, 32.52233934402466, 65.50278731754848, 49.22830663408552, 56.36753552300589, 49.03178378513881, 45.607513495853965, 23.510704687663488, 40.149151120867046, 55.07052918842861, 41.64408384050642, 1.0566166852201735, 0.06633648076759917, 0.01767214939796499, 0.042786260534610064, 0.06836784497967788, 0.013936230580189397, 0.12014530519289629, 0.06594935618340969, 0.14558713856552327, 0.17314848463450158, 0.09910275361367635, 0.08618693452860628, 0.2089299296161958, 0.1280636324414185, 0.3544817843607494, 0.1884579581341573, 0.1277729480394295, 0.16969137585588864, 2.0660019048622678, 50.50805016926357, 61.24183232443673, 57.164000579289024, 39.617669514247346, 32.641129221235005, 55.098342827388215, 65.406005859375, 61.684147698538645, 64.01034205300468, 53.877596446446006, 62.89038971492222, 16.795374972479685, 1.0844086110591888, 3.4155848239149367, 0.21243598791105406, 1.149082443543843, 49.24387754712786, 59.817799023219514, 52.62160185405186, 57.69491590772356, 45.84125437055315, 55.32611172539847, 51.052497114454, 44.9355914252145, 41.368619033268516, 40.11808225086757, 38.75029114314488, 38.807502610342844, 39.463718278067454, 40.346080439431326, 38.87588678087507, 37.553081784929546, 36.99347734451294, 36.331202847617014, 37.660264696393696, 38.80055093765259, 36.269652230399, 38.30537714276995, 35.01757642201015, 37.320369243621826, 38.55260794503348, 37.13701670510428, 37.085134506225586, 38.56835603713989, 36.70757286889212, 38.647763524736675, 36.31321048736572, 38.75802796227591, 37.077293464115684, 38.32737166540963, 40.474097524370464, 35.75742060797555, 36.499106066567556, 35.7789808682033, 38.15183585030692, 38.74526064736502, 37.51637445177351, 38.92936359133039, 36.82531704221453, 35.23523916516985, 43.63662222453526, 46.318543502262656, 46.51384694235665, 48.25911978312901, 45.98126752035958, 46.41452939169747, 43.204472064971924, 39.60218892778669, 37.72400747026716, 37.68143238340105, 37.644467966897146, 33.987773486546104, 35.58740861075265, 35.67593560900007, 36.296857901981895, 39.36187505722046, 39.48538276127407, 43.782089710235596, 41.97923714773995, 37.62080240249634, 36.190296854291645, 36.871345383780344, 38.52733734675816, 36.13237319673811, 37.37007318224226, 36.42587552751814, 36.16913611548287, 35.842056615012034, 34.49457161767142, 40.55757665634155, 48.17467137745449, 49.3322343145098, 48.88538524082729, 48.088121141706196, 46.1615628514971, 46.033556188855854, 44.97699921471732, 42.26894923618862, 34.918793882642476, 35.760738372802734, 36.64584854670933, 36.82880156380789, 36.441137245723176, 37.3254587990897, 38.31830426624843, 37.44419309071132, 37.86536857060024, 37.415997300829204, 37.014019693647114, 38.942141328539165, 36.14962904793875, 35.999075480869834, 38.03171191896711, 36.95228494916643, 37.96937962940761, 38.66555438722883, 39.10115780149187, 36.961102213178364, 38.91488354546683, 39.12771381650652, 38.4655122756958, 40.62485258919852, 39.42795589991978, 39.32012333188738, 39.934806142534526, 41.22796664919172, 37.69589158466884, 38.419244221278596, 38.44533123288836, 40.37289701189314, 37.639527797698975, 41.326697077069966, 41.920219148908345, 44.23379904883248, 51.706333024161204, 54.34077378681728, 54.32943780081612, 56.36961998258318, 52.43252747399466, 57.04898009981428, 59.10403837476458, 50.275890009743826, 1.2609674398388182, 0.37591849693230217, 6.146504580974579, 1.3886624106339045, 0.13408632283764227, 36.59553664071219, 69.57980959756034, 54.38400200435093, 62.38323375156948, 54.32004731042044, 48.69085305077689, 31.568751198904856, 48.401318141392295, 60.95090430123465, 52.46535076413836, 1.7856775926692146, 0.2800853321594851, 0.19065938357795986, 0.0980098033323884, 0.1837867602173771, 0.17458095348307065, 0.20495135310505116, 0.1633507918034281], [0.1079010661425335, 0.032141236920974085, 0.02432645920531026, 0.049730218281703334, 0.008344209752976894, 0.0036219100916891223, 0.030902703558760028, 0.1257055468325104, 0.023632231368018047, 0.031341261097363064, 0.5609349661639759, 35.017364501953125, 56.16313689095633, 37.506122384752544, 11.998124139649526, 23.59335698400225, 40.725403445107595, 58.387991768973215, 50.82163974217006, 52.31020791190011, 47.60128518513271, 53.05976220539638, 21.670112984521047, 0.12075965079878058, 0.9329539494855064, 0.43394130202276365, 0.1293968723288604, 11.88296295915331, 66.47194290161133, 51.26842975616455, 52.067305837358745, 48.376005853925435, 53.45460401262556, 42.22303901399885, 40.37014552525112, 32.44962991986956, 34.9001727104187, 33.330453055245535, 39.5439977645874, 36.142729486737935, 37.82584374291556, 34.26367603029524, 34.08206748962402, 32.287187985011506, 33.260317938668386, 32.890923908778596, 36.77796506881714, 35.70009102140154, 36.50815609523228, 34.02978924342564, 33.4006541797093, 33.57935837336949, 34.50393084117344, 32.45802681786673, 33.1554730960301, 32.12659774507795, 34.312751156943186, 32.5735718863351, 34.02975450243269, 33.394477231161936, 34.96913358143398, 35.55008288792202, 35.57787915638515, 35.70341920852661, 36.55304840632847, 35.95995364870344, 34.684156690325054, 33.98162085669381, 34.20096853801182, 31.653932639530726, 34.00803443363735, 37.553818293980186, 41.0775659424918, 43.28130177089146, 42.821925095149446, 45.32415553501674, 44.150170530591694, 41.38511405672346, 38.44536944798061, 37.19882787976946, 37.10485349382673, 35.67986134120396, 34.62720578057425, 32.81358003616333, 34.238839694431846, 36.375699111393516, 39.07553284508841, 36.610454423086985, 38.261794567108154, 36.16101367133004, 37.21229348863874, 34.87941149302891, 33.81725427082607, 33.39154856545584, 33.96183238710676, 34.65147931235177, 35.34381866455078, 34.74256672177996, 34.805017130715505, 33.99165058135986, 37.75612899235317, 42.86290904453823, 43.71629721777779, 44.37951666968209, 44.217012201036724, 42.43851654870169, 42.84760216304234, 42.23107460566929, 36.71415628705706, 32.1706736428397, 32.715690340314595, 32.95802961077009, 32.41895709718977, 33.628159046173096, 34.94438409805298, 34.33491243634905, 33.65950237001692, 34.57687997817993, 34.460535866873606, 32.637519632067, 33.479328632354736, 32.44815690176827, 33.679822376796174, 33.28869785581316, 33.706948144095286, 32.924744265420095, 33.00476666859218, 33.78875276020595, 33.82788501467024, 35.93265765053885, 33.78885350908552, 35.00650099345616, 35.42577266693115, 37.911052976335796, 39.837072781154085, 43.10444579805647, 44.29170880998884, 45.532379150390625, 43.63744558606829, 38.41667686189924, 33.89508104324341, 34.706359658922466, 35.83009876523699, 36.699141229902, 35.50619111742292, 42.53339767456055, 45.72488246645246, 50.50881099700928, 51.619980812072754, 53.58505991527012, 49.22996030535017, 55.54228755405971, 16.297685929707118, 0.08788957566555057, 0.8779381673250879, 1.4177409474338805, 0.32051722545708927, 0.11564201755183083, 34.33827536446707, 55.22358063289097, 46.205916677202495, 58.356203760419575, 49.2217127936227, 29.91114377975464, 26.798983097076416, 33.61710793631417, 52.69063915525164, 21.336424010140554, 0.14295098930597305, 0.05126772095848407, 0.048640314622649124, 0.0395135538253401, 0.02445979472914977, 0.024914433547694768, 0.04129487449037177, 0.012480416734303747, 0.04508132041831102, 0.0809222763138158, 0.051295771596155, 0.023982640422348465, 0.024113860613267337, 0.028791122936776707, 0.057274808441954, 0.0575326992464917, 0.01460518638071205, 0.042061646202845235, 0.7877225939716611, 41.88006203515189, 61.908894130161826, 49.06401995250157, 17.295417717524938, 26.945769003459386, 47.50687653677804, 60.27575479234968, 55.64772299357823, 57.29831968035017, 51.60939175742013, 58.49516078404018, 22.792771645954677, 0.007189282083085605, 0.4510722484971796, 1.2672987686736243, 0.33659969962068964, 13.641353130340576, 68.8675150190081, 51.29902614865984, 53.71171167918614, 49.01134218488421, 54.59674889700753, 43.857550621032715, 43.122750827244346, 33.606001240866526, 37.97835322788784, 35.098828656332834, 41.509542397090364, 36.718648297446116, 39.17547920772007, 34.70637355531965, 37.43949958256313, 33.11666393280029, 35.263730253492085, 34.88012020928519, 38.01338604518345, 37.085151876722065, 38.78187765393938, 35.935697487422395, 36.20130280085972, 35.93025704792568, 35.426641191755024, 33.81553111757551, 35.733598709106445, 35.00141838618687, 35.64203187397548, 34.67610372815813, 35.24187816892351, 34.81210429327828, 38.019264221191406, 35.02378116335188, 36.70894513811384, 37.06503684180123, 38.109629017966135, 37.191483633858816, 37.11234712600708, 36.06182813644409, 35.27189438683646, 33.75154863085066, 37.4936260495867, 39.572124072483604, 43.20663642883301, 44.56186866760254, 44.87834521702358, 45.76053367342268, 45.193855966840474, 41.09899418694632, 38.69365637642996, 37.62073639460972, 37.19096599306379, 35.96077701023647, 35.147337504795615, 33.68192768096924, 34.654925618852886, 36.11227553231375, 38.89985111781529, 39.640452657427105, 39.47314698355538, 38.034380027226035, 38.63275194168091, 35.00228691101074, 34.27644681930542, 34.10012238366263, 33.53882605688912, 34.01685517174857, 34.872546672821045, 34.7024895123073, 35.570156233651296, 34.68007114955357, 37.95248508453369, 45.09449325289045, 46.26617840358189, 47.07447624206543, 44.66069984436035, 43.6656448500497, 45.10477311270577, 42.81900337764195, 39.42791421072823, 34.64831440789359, 34.60971369062151, 35.10888964789254, 34.108995233263286, 35.82623904091971, 35.810595171792166, 35.959717409951345, 34.968202522822786, 36.47639240537371, 36.650337082999094, 34.27870845794678, 35.75108732495989, 34.1435729435512, 35.81389904022217, 34.695041043417795, 36.2784868649074, 35.583444663456504, 35.9152489389692, 35.737910066332134, 35.56072057996477, 35.936211654118125, 35.240575381687705, 37.22652687345232, 36.339547634124756, 40.10477992466518, 41.50389698573521, 45.263761792864116, 46.327537945338655, 47.05752611160278, 45.844592979976106, 40.3217339515686, 36.79829549789429, 36.89392008100237, 37.9221179825919, 38.6512063571385, 39.04236561911446, 44.70141976220267, 47.73637901033674, 53.24740525654384, 54.31925521578108, 55.03876549857003, 49.77761384419033, 54.95477567400251, 19.233398846217565, 0.1910367983260325, 1.6475698777607508, 4.258313374859946, 0.7377895819289344, 0.08694934326090983, 37.157979420253206, 61.53544235229492, 51.884019306727815, 61.677088328770225, 53.47728293282645, 36.60196719850813, 28.83054256439209, 37.726661682128906, 57.875176497868125, 30.90594516481672, 0.07616848032921553, 0.08358461702508585, 0.12163805509252207, 0.04634236078709364, 0.06251928023993969, 0.022542117363108054, 0.022874657197722366, 0.010659430608419436, 0.1668350284120866, 0.1517414783260652, 0.11875035933085851, 0.09823797430310931, 0.17955709860793181, 0.2009954803756305, 0.13254441986126558, 0.2603671859417643, 0.1665799535278763, 0.12161710193114621, 0.8489385034356798, 49.38600294930594, 69.51632390703473, 52.046270166124614, 20.16153573989868, 30.448274271828787, 51.405979769570486, 69.79500225612095, 60.16349274771554, 63.862331526620046, 56.53934710366385, 63.803445543561665, 27.05517360142299, 0.13738839993519442, 3.091189933674676, 1.2013162864106042, 0.2000797837972641, 14.38085859162467, 70.82893589564732, 52.15196616309029, 55.074420179639546, 51.63484648295811, 55.921766894204275, 45.7224714415414, 43.83699784960066, 36.38628469194685, 39.09249339784895, 38.00234883172171, 42.89072963169643, 39.72909082685198, 41.708583968026296, 38.17714466367449, 38.19853121893746, 35.10583244051252, 37.749802657536094, 36.85858154296875, 39.74136481966291, 40.10096188953945, 41.129121576036724, 37.344705309186665, 38.14550256729126, 37.859618936266216, 37.89868170874459, 36.81206682750157, 38.374129567827495, 37.734009402138845, 37.64606605257307, 36.987745080675396, 38.55865287780762, 37.23548657553536, 40.06528288977486, 38.06063379560198, 38.545197691236226, 39.601532323019846, 39.815960679735454, 39.15148707798549, 37.58566883632115, 38.764514105660574, 36.534107616969514, 35.89014509746006, 38.77396365574428, 41.98583098820278, 44.7668787411281, 47.840501240321565, 46.82579674039568, 47.37001092093331, 47.87196615764073, 41.804444789886475, 37.96989379610334, 37.95304788861956, 39.23870434079851, 36.76390538896833, 35.200143814086914, 33.6270021711077, 35.87000921794346, 39.45608915601458, 41.99191761016846, 39.117555550166536, 41.89288493565151, 39.36880241121565, 41.93848943710327, 37.23772736958095, 36.795905317579, 35.40026930400303, 35.79476717540196, 36.48420565468924, 36.25036403111049, 34.530792576926096, 36.01079709189278, 35.86992583956037, 38.67974608285086, 46.166120869772776, 47.4947623525347, 50.08604090554373, 49.563439096723286, 47.16025870186942, 49.05742263793945, 44.38222994123186, 41.3156008039202, 37.0051920073373, 37.40348359516689, 37.46256065368652, 35.80865315028599, 37.372025626046316, 37.69410589763096, 38.83632721219744, 36.41135031836373, 38.88194908414568, 39.594483375549316, 36.60588250841413, 38.08950703484671, 34.63259063448225, 38.63274151938302, 36.341322898864746, 38.816823618752615, 37.077012062072754, 37.52076571328299, 37.75263057436262, 38.45596545083182, 39.849464893341064, 37.94473784310477, 38.673482281821116, 39.14378152574812, 41.701611450740266, 43.87345504760742, 48.08387926646641, 47.663148471287315, 49.12515715190342, 47.80052130562918, 42.48157106127058, 39.2845971924918, 39.85307100840977, 40.17265340260097, 40.559171267918174, 41.45964738300869, 46.84816993985857, 50.99956226348877, 57.24032654081072, 56.908077580588206, 58.431494440351216, 51.310733863285606, 55.72887100492205, 22.969228097370692, 0.23165712079831532, 2.4029059410095215, 8.17412919657571, 0.9339630667652402, 0.19802805674927576, 42.06834084647042, 66.3267047064645, 57.283617292131694, 68.89254243033272, 57.303193841661724, 42.496857098170686, 37.24712480817522, 44.803023270198274, 64.53821059635708, 39.84300306865147, 0.33408040766205105, 0.20134985207446984, 0.2337994458419936, 0.14427855664065906, 0.17979811424655573, 0.09753714940909829, 0.10624711667852742, 0.0754728801548481], [0.011569902467142259, 0.024608149625627056, 0.02234243298880756, 0.0260189358876752, 0.006020974126710955, 0.03069571984399642, 0.06244027162236827, 0.08419109162475381, 0.08976793023092405, 0.07493918522128037, 0.05843181921435254, 25.246915340423584, 57.19077198845999, 35.75572524751936, 45.739161014556885, 46.187257289886475, 29.706456797463552, 54.64562252589634, 53.44288240160261, 49.46428482873099, 50.327424798692974, 46.751016753060476, 37.79098463058472, 0.14372134368334497, 0.6711660740630967, 1.4716410551752364, 0.1160652469843626, 0.06624885475529091, 34.73305811200823, 51.73374366760254, 45.0291246005467, 55.783928530556814, 44.601706164223806, 41.004859992435996, 34.90107250213623, 36.022101811000276, 36.02711146218436, 40.20562260491507, 41.5187418120248, 42.1622804914202, 38.6781792640686, 33.12637751443045, 31.4809433392116, 33.029825346810476, 35.823053291865754, 43.0493882724217, 43.842271532331196, 45.35653414045061, 44.62998185838972, 42.40350110190255, 36.0996367590768, 33.809976032802034, 34.783613204956055, 35.65655360903059, 32.80749341419765, 34.50485495158604, 33.42904451915196, 33.253345421382356, 33.057420117514475, 35.53682919910976, 34.63225017275129, 34.935146468026296, 35.0454352242606, 35.77329724175589, 37.001043932778494, 35.52817521776472, 33.9119999068124, 36.3522732598441, 34.35932493209839, 31.921938555581228, 32.64199079786028, 38.54841470718384, 42.725942679813926, 43.47056375231062, 43.00171320778983, 45.13921185902187, 45.20945119857788, 42.331038338797434, 38.53512627737862, 37.499872480119976, 34.664152826581685, 34.5580746786935, 32.7700982093811, 34.0385092326573, 35.00679976599557, 35.88728938783918, 36.2887840952192, 37.189930711473735, 36.88182326725551, 37.764612742832725, 34.24012858527047, 36.11280359540667, 34.479594775608604, 33.94674089976719, 34.436849457877024, 36.02004861831665, 34.5870486668178, 35.4708525793893, 35.036204542432515, 35.94515398570469, 37.71908467156546, 45.36826964787075, 44.30754028047834, 44.13819183622088, 41.78061246871948, 43.001730578286306, 43.95356777736119, 42.350409916469026, 39.41053329195295, 30.58342715672084, 31.599180834633962, 32.571883474077495, 32.09330197743007, 32.638596602848594, 32.251686164310996, 34.084648745400564, 33.01632847104754, 33.77642665590559, 34.705122879573274, 33.75850030354091, 33.535226890019004, 34.26160546711513, 32.601785046713694, 30.6291914667402, 33.200316769736155, 32.882735456739155, 34.64459712164742, 34.13607236317226, 32.695863655635286, 35.02367694037301, 34.83179896218436, 36.193545137132915, 37.46974161693028, 40.75947393689837, 42.481977530888145, 48.022613525390625, 48.22324275970459, 50.65666171482631, 50.3012752532959, 51.237989698137554, 43.536700180598665, 37.19219582421439, 33.39981344767979, 36.85703904288155, 34.35989121028355, 36.48895822252546, 42.34113754544939, 48.399254526410786, 47.26721927097866, 52.752558026994976, 52.132931573050364, 48.452779974256245, 2.991348445415497, 0.3968929100249495, 0.6957469550626618, 2.991467433316367, 0.3693430854805878, 0.21523802541196346, 41.14540467943464, 54.49421433040074, 49.52257326671055, 58.66728155953543, 46.0610328401838, 26.128513199942454, 18.43983813694545, 27.301994459969656, 53.981843744005474, 13.28038465976715, 0.14999758904533728, 0.01750921448027449, 0.06220830764089312, 0.023895282431372573, 0.04909668370549168, 0.023482868847038065, 0.014820008871278592, 0.027675463784752146, 0.031078355919037546, 0.031502538693270514, 0.0633380888029933, 0.019348161428102424, 0.02845060861935573, 0.052856581950826306, 0.06169236996876342, 0.04143958226112383, 0.054320243054202626, 0.04999465016382081, 0.22391960956156254, 33.73818377086094, 62.75918688092913, 39.68525116784232, 31.059674058641704, 33.551614216395784, 40.958588463919504, 60.404650824410574, 58.68417263031006, 55.038411140441895, 54.840512548174175, 52.12168591363089, 40.306812695094514, 0.13580499775707722, 0.91775324514934, 1.6344417993511473, 0.7442083060741425, 0.14742173440754414, 38.46264961787632, 51.88784429005214, 47.2784823008946, 56.600724015917095, 46.18025697980608, 42.76642983300345, 37.45841605322701, 37.848446232931956, 36.25191695349557, 41.969242164066856, 42.15508215767996, 43.14399494443621, 39.866366386413574, 34.45583888462612, 34.19293989453997, 34.505244050707134, 36.25847952706473, 44.79061378751482, 45.988479750497, 47.169767311641145, 46.54433911187308, 42.6594796861921, 37.442369188581196, 36.207702091761995, 36.94789021355765, 36.88808706828526, 34.589779308864046, 34.96159478596279, 36.078757422310964, 35.809723172869, 34.952860900333945, 37.543708665030344, 35.92054694039481, 36.297698634011404, 35.51664468220302, 36.80388184956142, 38.96093273162842, 37.82625716073172, 35.09589304242815, 37.0107992036002, 36.20436348233904, 33.86638845716204, 35.57688208988735, 40.14363077708653, 45.19257402420044, 45.20868689673287, 45.15059648241316, 46.558478696005686, 45.08889995302473, 41.95424795150757, 38.21156256539481, 37.130735533578054, 34.809012344905305, 35.0058582850865, 34.752158709934776, 35.27228001185826, 34.66346148082188, 36.174739837646484, 37.57957526615688, 38.67352049691336, 39.59834657396589, 38.476792676108225, 35.6605418750218, 37.592165402003694, 35.863279887608115, 34.761375495365684, 35.07109144755772, 36.28281211853027, 35.22542483466012, 35.21411664145333, 35.477001735142295, 34.29539803096226, 38.776332991463796, 46.148437704358784, 46.18480804988316, 45.80175386156355, 44.19414567947388, 44.9112206186567, 46.80229793276106, 45.295970167432515, 40.59225164140974, 31.973761694771902, 34.111079692840576, 34.072301796504426, 33.676539352961946, 33.67150885718209, 33.69319071088518, 36.23603337151663, 35.08126361029488, 35.992439951215474, 35.833378314971924, 34.90955625261579, 36.56780638013567, 36.30296884264265, 33.49168600354876, 33.32060398374285, 35.20452117919922, 34.77472645895821, 36.01140505926949, 35.61793899536133, 34.908691201891216, 36.75343792779105, 36.25080524172102, 38.15798848015921, 39.5237090247018, 42.641407421657014, 44.88388640539986, 49.86323649542672, 50.4706688608442, 53.01044041769845, 52.49125712258475, 52.441740785326274, 45.14766434260777, 38.624997752053396, 35.84409243719918, 38.425838061741416, 37.219505718776155, 38.373007433755056, 43.85280500139509, 51.18983520780291, 49.15932491847447, 56.23605823516846, 52.44703183855329, 51.059209074292866, 4.882823978151594, 0.32693600388509886, 2.252557780061449, 2.9271240745271956, 0.1919960839939969, 0.40758412490998, 44.78142826897757, 59.24300234658377, 54.68543570382254, 63.62352194104876, 51.004884583609446, 33.65189756665911, 22.665953125272477, 30.904729230063303, 60.195760181971956, 21.37830948829651, 0.008235192924205745, 0.005020793577257011, 0.033437296482069154, 0.010256980462665004, 0.015095175177391087, 0.012211950961500406, 0.008950516415227736, 0.04862700515825834, 0.083941092182483, 0.07803460769355297, 0.09256569296121597, 0.0857266570840563, 0.09497585613280535, 0.17509748148066656, 0.2161815690674952, 0.2136790504945176, 0.17612761977527822, 0.3278371798140662, 0.4365435109606811, 38.193743910108296, 71.59932436261857, 46.57174628121512, 56.76643507821219, 58.462768282209126, 42.52129391261509, 64.26035213470459, 62.76708698272705, 57.25154788153512, 60.380040305001394, 56.81256069455828, 46.58407933371407, 0.20566841534205846, 2.8561512657574246, 4.353337373052325, 0.48544859673295704, 0.3171009916279997, 38.33345481327602, 54.23195457458496, 50.55105604444231, 59.22143513815743, 48.79961667742048, 44.72864280428205, 39.598117283412385, 40.50667415346418, 39.440480027879985, 44.58282790865217, 45.92096757888794, 45.280663285936626, 43.46628018787929, 35.60440043040684, 34.846143518175396, 37.423612526484895, 40.520198822021484, 47.718073981148855, 49.37477813448225, 49.361107553754536, 49.31320667266846, 45.30079916545323, 40.34450667245047, 37.93220329284668, 38.199538707733154, 40.72983986990792, 36.74596166610718, 38.55926431928362, 39.505049637385774, 38.27141087395804, 37.176305294036865, 39.20409188951765, 39.08926943370274, 38.452626841408865, 38.00254685538155, 37.774791853768484, 41.537380354745046, 39.45641572134835, 36.84523752757481, 40.169175829206196, 38.425066811697825, 34.62576402936663, 37.039488315582275, 44.099677971431184, 46.45784098761422, 48.657460008348735, 46.02921009063721, 47.897483416966026, 46.840481758117676, 43.7350469316755, 38.555870124271934, 36.211252621241975, 34.9213091305324, 35.30496433803013, 34.70212473188128, 36.38997418539864, 37.17063208988735, 38.14142744881766, 39.61306980678013, 40.48382500239781, 41.83655936377389, 40.797004631587434, 37.790407930101665, 39.91195004326956, 37.87702417373657, 37.49139567783901, 36.68963609422956, 38.37363624572754, 35.74477488654, 36.63501283100673, 35.42270851135254, 35.0074667930603, 39.14792960030692, 47.77377074105399, 47.52375718525478, 49.83059385844639, 45.40109988621303, 48.79002816336495, 49.3913391658238, 46.14555420194353, 43.95926182610648, 34.97906603131975, 35.220373494284495, 36.672477517809185, 35.28171566554478, 35.44411938531058, 34.459608282361714, 38.25024666104998, 35.98816680908203, 36.54114614214216, 37.662647928510395, 37.80287299837385, 38.60920797075544, 39.37028585161482, 36.465257917131694, 34.116429805755615, 38.7789420400347, 36.595936162131174, 38.6351386478969, 37.16642842973982, 35.922089440482004, 37.67564453397478, 39.24479443686349, 39.309252875191824, 40.0853145463126, 45.35210813794817, 46.605090686253135, 54.2835727419172, 51.539649214063374, 54.69606644766671, 53.5757736478533, 53.793790749141145, 48.437584263937815, 40.6173346383231, 37.396865436008994, 40.378330503191265, 39.436217308044434, 40.12034041540963, 46.99036829812186, 54.63769810540335, 52.72705118996756, 58.534112385341096, 54.10970796857561, 53.7440972328186, 7.101927484784808, 0.4654276339071137, 2.574286081961223, 9.573934997831072, 1.1326208582946231, 0.5413270411746842, 51.36134801592146, 66.39070456368583, 59.42066083635603, 66.90446826389858, 55.620468684605186, 36.56160511289324, 29.37395075389317, 39.74432822636196, 65.7336481639317, 32.08799702780587, 0.27858880960515564, 0.10940245379294668, 0.12126785995704786, 0.07547851199550287, 0.10661008541605302, 0.09331930109432765, 0.10632354007767779, 0.15177156456879207], [0.01227156280739499, 0.056852145586162806, 0.06747811593647514, 0.042484943488878865, 0.057075814477034977, 0.026842248226915087, 0.06418335344642401, 0.07313507595764739, 0.029228306441966976, 0.09801722650549241, 0.04023041928719197, 21.654291936329432, 56.70998443875994, 46.10125943592617, 43.838693210056846, 66.21777779715401, 42.5060704095023, 39.85350527082171, 61.361820765904014, 46.16496399470738, 52.23798486164638, 42.95281873430525, 48.36571557181222, 1.7022604516574313, 0.28908039948769976, 1.1892176270484924, 3.1349522939750125, 0.07685897792024271, 8.2072434425354, 51.0230575970241, 51.244774614061626, 52.686921869005474, 40.3756137575422, 38.405497210366384, 34.34353167670113, 38.49713700158255, 39.632118293217246, 44.87406512669155, 45.63178355353219, 46.824497427259175, 40.07082755225045, 34.038762841905864, 33.146704469408306, 35.45614671707153, 43.437007427215576, 47.18370539801461, 48.1027957371303, 45.83491761343819, 45.20278787612915, 46.835159437997, 43.831439290727886, 40.58262491226196, 33.70308494567871, 33.13562209265572, 32.64055252075195, 35.3275077683585, 31.982804775238037, 33.3090352330889, 33.782554967062815, 33.96378135681152, 33.5227826663426, 34.94545064653669, 34.47123261860439, 34.69692053113665, 33.26150260652815, 33.775641509464805, 34.374267033168245, 35.46719087873186, 35.34238733564104, 31.2419878414699, 33.51426764896938, 36.69336380277361, 41.739784853799, 41.22847734178816, 43.71011332103184, 44.3341657774789, 43.69853067398071, 42.247628688812256, 37.8844587462289, 35.32890783037458, 35.24874298913138, 33.459654808044434, 34.387458188193186, 34.55266898018973, 35.92506326947893, 35.999884946005686, 35.237987177712576, 36.845362595149446, 36.58508655003139, 36.18832009179251, 35.08172219140189, 34.056154182979036, 36.016723905290874, 33.66838216781616, 31.917418752397808, 34.60500281197684, 35.014053685324534, 33.955440044403076, 35.75571482522147, 33.43959188461304, 37.07322876793997, 41.89889512743269, 44.67223385402134, 44.423839228493826, 43.326881953648154, 42.0067172731672, 41.02085821969168, 41.2396639415196, 38.02174820218767, 31.473970821925572, 30.757149491991314, 32.456487791878835, 32.50707762581961, 32.31583193370274, 33.45321382795061, 34.69521474838257, 35.07144580568586, 34.315957750592915, 34.2314259665353, 34.13306031908308, 32.72305890492031, 33.31815821783883, 33.68614176341465, 31.694753306252615, 31.432712418692454, 32.77014684677124, 32.293385778154644, 34.93589339937483, 35.276379449026926, 37.17502335139683, 37.80355739593506, 37.35721206665039, 37.92154475620815, 42.6250444139753, 43.6053066934858, 47.01358570371355, 46.83380453927176, 48.04833228247506, 45.50382900238037, 50.37494352885655, 52.5368720463344, 47.09447315761021, 37.5157595361982, 32.21290479387556, 35.58734607696533, 35.44899007252285, 35.03050354548863, 43.142542770930696, 45.77222054345267, 48.52551024300711, 53.50818157196045, 39.61395222800118, 0.18132228031754494, 0.08514694390552384, 1.4032645928008216, 1.0924815492970603, 0.7111070879868099, 0.3735911489597389, 44.746669905526296, 51.46378878184727, 51.854016985212056, 54.252948556627544, 51.966751507350374, 26.048907688685826, 14.774032831192017, 32.380922658102854, 47.544428076062886, 13.190176197460719, 0.20969153089182718, 0.044462703434484344, 0.12525360179798944, 0.017880400276875923, 0.06711445509323052, 0.1514948308467865, 0.07572341563978366, 0.06450513510831765, 0.0925781780055591, 0.05359693490234869, 0.02623744960874319, 0.08249515441379376, 0.04112509145800557, 0.06548688707074948, 0.06606990471482277, 0.044943974752511294, 0.11670065431722573, 0.10037435538002423, 0.05899529504988875, 25.698209524154663, 65.3727239881243, 49.90039546149117, 46.4935964175633, 54.71897118432181, 40.51761409214565, 47.11513015202114, 64.34833717346191, 51.506026881081716, 57.49893849236624, 47.032745361328125, 51.54053510938372, 1.805011498076575, 0.6221983730792999, 1.780844577721187, 2.9283858239650726, 0.029042822109269242, 9.431838256972176, 54.24043137686593, 51.48777048928397, 53.680625438690186, 42.96021856580462, 39.78330762045724, 36.764370918273926, 40.061280727386475, 40.37660040174212, 47.51687152045113, 45.760255745479036, 49.24649006979806, 41.1475864137922, 35.91636412484305, 34.690941606249126, 37.726599148341585, 45.31203440257481, 49.43159702845982, 49.076641355242046, 47.89995697566441, 45.829939229147776, 49.80535452706473, 44.641303947993684, 43.30336577551705, 34.606003352573936, 35.948756626674104, 35.246380601610454, 36.4386636870248, 34.68196105957031, 36.00934144428798, 34.83640561785017, 36.49647617340088, 35.41540942873274, 35.95451668330601, 36.50782952989851, 35.66303627831595, 34.817760126931326, 36.416929721832275, 35.668692111968994, 38.028018951416016, 35.50499950136457, 33.15748459952218, 35.41035461425781, 38.832627296447754, 44.70455687386649, 44.53989151545933, 45.752418177468435, 47.79260035923549, 46.30794055121285, 43.243944781167166, 39.189236640930176, 36.30414308820452, 35.677439893995015, 35.40909699031285, 33.33808217729841, 35.84878247124808, 35.409197739192415, 37.467122146061485, 37.14714023045131, 37.61702953066145, 38.07166406086513, 36.42512859616961, 37.44586760657174, 35.83088043757847, 37.13086754935128, 36.725926535470144, 34.59737021582467, 35.09794276101248, 34.65470675059727, 34.741055488586426, 35.750611373356406, 35.06357002258301, 36.920309339250835, 42.62863663264683, 46.38880021231515, 46.0687210219247, 44.95488657270159, 45.42759336744036, 43.41170556204659, 43.84643350328718, 40.0237535067967, 34.05988189152309, 31.68647105353219, 34.70859350476946, 34.2253532409668, 34.2148197719029, 36.00698600496565, 36.987085001809255, 36.174190929957796, 35.83240556716919, 35.73875774656023, 35.64606877735683, 35.80590166364397, 34.78028154373169, 34.29776736668178, 34.97819750649588, 32.74516807283674, 33.933066844940186, 34.841238089970176, 36.21709953035627, 36.42477771214077, 37.3834866796221, 39.030967099326, 39.16818012510027, 39.15903629575457, 45.02681432451521, 46.51478842326573, 49.387191091264995, 49.02206672940935, 50.70035546166556, 46.34934139251709, 52.48981189727783, 52.060145718710764, 48.016773564474924, 39.14834649222237, 34.157667364392964, 37.24761118207659, 36.57948630196707, 37.94312933513096, 45.32244627816336, 49.28547293799264, 50.538931437901084, 55.39845984322684, 42.639607838221956, 0.7221766539982387, 0.2559462860226631, 4.94995790719986, 4.725234057222094, 0.8640092004622731, 0.6268582258905683, 49.397293772016255, 55.472975799015586, 56.245625904628206, 58.42155851636614, 56.98856551306588, 31.98986761910575, 16.4037275995527, 36.002841404506135, 55.91526338032314, 17.210281440189906, 0.16009503150624887, 0.08216240762599877, 0.10273307202649967, 0.05100406939163804, 0.0538023104891181, 0.06068704569978373, 0.07770614246172564, 0.026909580953153114, 0.12074295883732182, 0.11411665725920882, 0.2133573977542775, 0.21858411229082517, 0.19562213442155293, 0.22367334206189426, 0.17488873696752957, 0.16748723627201148, 0.22111066457416328, 0.22311907394656114, 0.11155995766499213, 30.835424423217773, 75.29555061885289, 56.19928142002651, 52.40597145898001, 71.05908802577427, 53.45083808898926, 50.1469383920942, 72.47823674338204, 53.481851373400005, 63.98601640973772, 51.56396443503243, 58.18558726991926, 2.49723425081798, 1.1436752251216342, 5.1915254933493475, 5.497257087911878, 0.10646607992904526, 11.670184799603053, 56.4112605367388, 53.6983711378915, 56.32415444510323, 44.0990561076573, 41.07699966430664, 38.85504913330078, 43.187271799360005, 43.32666655949184, 50.04312188284737, 48.84649964741298, 51.36746937888009, 44.30183580943516, 37.28001410620553, 37.526574407305034, 40.08686399459839, 48.15325355529785, 52.11490099770682, 51.45429406847273, 51.92526381356375, 50.29345505578177, 51.39695405960083, 47.66606324059622, 46.39986521857125, 37.143565382276265, 37.74712412697928, 38.24092217854091, 39.91042143957955, 37.68322154453823, 37.446843828473774, 36.90088217599051, 38.75238255092076, 37.538855348314556, 38.09244612285069, 38.71087401253836, 38.34647921153477, 35.46651342936924, 36.312011923108784, 37.74317755017962, 39.85497828892299, 38.300110408238, 34.86552204404558, 38.42040457044329, 40.69848264966692, 46.366006646837505, 45.97173459189278, 47.072954586574006, 49.74674994604928, 47.37823411396572, 42.93946777071272, 38.7560407774789, 35.52863032477242, 35.66670145307268, 36.31314447947911, 36.0622832434518, 37.09560891560146, 37.93261323656355, 39.78018093109131, 38.573956285204204, 39.0031395639692, 41.03093658174787, 39.45364339011056, 39.23328474589756, 38.2316324370248, 39.8814891406468, 37.09871823447091, 34.62716061728341, 36.816319125039236, 37.37892518724714, 35.50467988422939, 36.6657794543675, 34.13054159709385, 38.90560075214931, 43.5840208871024, 48.815413406917024, 49.013398851667134, 48.134802613939556, 48.28855235236031, 45.97565337589809, 44.74170194353376, 41.31157432283674, 35.32138293130057, 34.44161244801113, 36.5117517880031, 35.98217051369803, 35.18696308135986, 38.72282838821411, 39.009969643184114, 38.46395935331072, 37.08363369532994, 38.854111126491, 36.78025450025286, 38.117320673806326, 37.14025803974697, 37.36711324964251, 36.30616153989519, 33.94984674453735, 35.39413751874651, 35.14455475125994, 38.51718602861677, 39.67455094201224, 40.064744404384065, 40.914863450186594, 41.18489824022566, 39.89354426520211, 46.00472811290196, 49.59210041591099, 52.01902975354876, 50.48901905332293, 52.73245688847133, 48.77914728437151, 54.53445134844099, 53.97517694745745, 51.253400802612305, 41.61748613630022, 35.50678171430315, 39.58075373513358, 39.32743631090437, 38.42866250446865, 48.540084089551655, 50.47879130499703, 53.93107673100063, 56.8877853666033, 45.60594320297241, 1.287808548126902, 0.25360970997384613, 8.22793778351375, 8.297738518033709, 1.995480511869703, 0.6377633150134767, 54.26290879930769, 61.934567723955425, 62.92909118107387, 62.831191062927246, 64.30908679962158, 34.96743474687849, 23.084338903427124, 42.73934922899519, 63.15387235369001, 25.05858268056597, 0.24983439541288785, 0.1379114825810705, 0.25014193462474005, 0.07621071913412639, 0.16962862493736403, 0.15325390574123177, 0.12880748324096203, 0.1173314204705613], [0.018658481471772705, 0.06803908797779254, 0.03375138355685132, 0.08014725361551557, 0.012749179366177745, 0.04730812307181103, 0.03194246347993612, 0.08315359122518982, 0.022549749185730304, 0.09958983997681312, 0.02859501274568694, 17.94725775718689, 59.5796981539045, 37.487421308244976, 52.17223058428083, 80.99937547956193, 63.338326181684224, 36.470000062670024, 57.45718329293387, 49.70746830531529, 52.116012709481375, 42.53436000006539, 51.51827655519758, 5.959323150771005, 1.2342473821980613, 0.4893093524234635, 2.0862973758152554, 0.2164862041494676, 0.3947522948895182, 48.53103058678763, 52.27914251599993, 48.0632917540414, 41.744110107421875, 39.428852217538015, 37.16183567047119, 41.83863687515259, 43.69302075249808, 48.27440929412842, 46.87004634312221, 48.36156402315412, 38.81693131583077, 33.66260821478707, 32.01040302004133, 40.87636695589338, 45.88166161945888, 49.22594077246529, 43.28684295926775, 42.5295136315482, 42.178768566676546, 44.398877825055806, 45.99257571356637, 46.08857897349766, 40.31303480693272, 34.911390577043804, 33.47661188670567, 33.117522035326274, 33.684950147356304, 31.944839818137034, 32.69688504082816, 33.95682273592268, 35.075041498456685, 34.6899619102478, 34.067816734313965, 35.28385918481009, 35.760755743299214, 35.744257245744976, 34.29956347601754, 35.3501102583749, 34.10575042452131, 31.615672383989605, 32.7119139943804, 36.46096740450178, 41.4143659727914, 42.80668422154018, 42.43670654296875, 44.61132247107369, 44.42727858679635, 42.53125415529524, 38.54745585577828, 36.51314490182059, 34.26030615397862, 33.548862729753765, 34.07674516950335, 34.30102954592024, 35.541873591286794, 36.4980707849775, 34.96172332763672, 37.32739734649658, 35.00410039084298, 35.87006827763149, 33.84077044895717, 33.41944905689785, 33.846773692539756, 35.36169637952532, 33.92976297651018, 34.12621634347098, 33.30728776114327, 35.22937488555908, 34.9610458782741, 34.606552260262625, 36.43572807312012, 38.0098146711077, 40.80815996442522, 44.230811323438374, 42.92285810198103, 42.0081763948713, 41.47288370132446, 41.70662110192435, 38.463233266557964, 31.820005008152553, 31.72823667526245, 32.74749571936471, 32.49905245644705, 33.881125586373464, 33.28632852009365, 33.116785526275635, 34.981640338897705, 34.68515723092215, 34.457009656088694, 33.55048166002546, 32.71505110604422, 32.24899026325771, 32.62323413576399, 32.127594811575754, 34.833553382328574, 33.4575321333749, 34.414733341761995, 34.90925748007638, 35.85409436907087, 33.364547865731375, 34.93180438450405, 37.787955215999055, 41.33201592309134, 40.64296306882586, 42.67655488422939, 46.13104288918631, 47.52021707807268, 47.6405668258667, 45.80877849033901, 42.580468245915, 49.131539072309224, 52.058036940438406, 45.14281102589199, 37.024695600782124, 33.190144606998985, 34.59730768203735, 35.12861558369228, 38.17172506877354, 44.65044777733939, 48.83420828410557, 53.489980765751426, 38.12434877668108, 0.1921069159039429, 0.10020534587757927, 1.8789062414850508, 0.8241603587354932, 0.47426226841551916, 2.157726811511176, 48.6873129435948, 50.73205314363752, 50.37570088250296, 53.46343169893537, 44.51351615360805, 29.607597827911377, 25.327125344957622, 31.596033300672257, 48.24342032841274, 7.8157645634242465, 0.17466183485729353, 0.025093568488955498, 0.05481042014434934, 0.07541146595031023, 0.06714496202766895, 0.02292474834913654, 0.036904281337878535, 0.05476119242874639, 0.045678570334400447, 0.04531189001032284, 0.04363006293507559, 0.07716623893273727, 0.0469508438504168, 0.04324501466804317, 0.07907335659755127, 0.05599706593368735, 0.04962047542046223, 0.07474728194730622, 0.059030958850468905, 22.737351076943533, 64.64494882311139, 41.845355783190044, 52.47210441316877, 72.15559714181083, 60.00474030630929, 40.362690108163015, 62.98187664576939, 54.300859860011506, 57.93690429415022, 45.67054407937186, 54.929480757032124, 6.77740752696991, 0.7216815948486328, 0.609152153134346, 4.213651657104492, 0.7545321892414774, 0.8442972696253231, 52.523781640189036, 52.728239331926616, 50.129057203020366, 42.52661970683506, 40.759213379451204, 37.6710205078125, 42.771244934626985, 45.86503805433001, 50.844450678144185, 48.61197362627302, 49.78276940754482, 41.40922777993338, 35.032945837293354, 34.61599138804844, 43.20843253816877, 48.0086406980242, 49.6666476385934, 44.57187407357352, 44.275008814675466, 44.204467228480745, 47.25036294119698, 47.52444505691528, 45.70916216714041, 42.774211815425325, 36.80600799833025, 34.76184797286987, 34.80105665751866, 35.3654761995588, 34.94144153594971, 34.45013788768223, 36.31872040884835, 36.31192854472569, 35.6351774760655, 35.886862073625835, 36.896060126168386, 38.35658884048462, 36.18190690449306, 34.6720529283796, 37.32917261123657, 35.91186169215611, 34.339348861149375, 34.804204191480366, 37.73658718381609, 43.66037116731916, 43.40907914297921, 45.44428294045584, 46.750742299216135, 45.23219265256609, 42.38723189490182, 38.86509622846331, 36.90647547585623, 35.59365504128592, 36.06631319863455, 36.176859038216726, 36.84611994879586, 38.061015946524485, 37.36921855381557, 37.39914444514683, 38.35159655979702, 37.649620056152344, 37.32698392868042, 35.93215043204171, 35.057976722717285, 34.09123911176409, 35.69813162939889, 35.79737274987357, 35.233467374529155, 34.78765705653599, 36.0619010925293, 35.343033518110005, 34.312167508261545, 35.670905113220215, 37.99249281202044, 42.766888414110454, 45.24695062637329, 45.30027110236031, 44.076995577131, 43.493492807660786, 44.076123578207834, 41.000169958387104, 34.560596874782014, 33.70311621257237, 34.78240769250052, 34.47102764674595, 36.21957308905465, 34.83693020684378, 36.05143710545131, 35.64446026938302, 35.9530679838998, 35.51131888798305, 35.99073764256069, 34.84825577054705, 33.823684828622, 34.59902736118862, 34.43284382138933, 34.92335537501744, 34.911272457667756, 35.114604541233604, 36.63478006635393, 36.318091596875874, 35.60061018807547, 36.180451256888254, 40.84185177939278, 43.29750149590628, 43.22752618789673, 44.71867561340332, 46.54242140906197, 48.672871112823486, 48.88874469484602, 49.04556553704398, 44.16943441118513, 51.71177346365792, 53.31209645952497, 47.644843442099436, 38.410816056387766, 36.154718603406636, 37.55592359815325, 38.42140163694109, 40.83028302873884, 46.646140643528526, 50.36377429962158, 57.51590599332537, 40.842053277151926, 0.19667793491056987, 0.2911874678518091, 6.598463186195918, 3.6568638426916937, 0.4214725968028818, 2.190235261406217, 54.82392372403826, 53.46828154155186, 59.189702715192524, 58.19336230414254, 53.39360230309622, 29.54095765522548, 19.66826401438032, 38.053494521549766, 53.83958980015346, 11.196795344352722, 0.19633926451206207, 0.04581390414386988, 0.14504291276846612, 0.10229758825153112, 0.01864576063651059, 0.04572812035413725, 0.004128302048359598, 0.05297886074653693, 0.17129775322973728, 0.12221843323537282, 0.14838872823332036, 0.2023653747247798, 0.15611751350973332, 0.12641604085053715, 0.3075928975428854, 0.19317817342068466, 0.14553360215255193, 0.22774794484887803, 0.22264244380806172, 23.876478706087383, 74.12495980943952, 47.302210399082725, 62.56472764696394, 80.89605576651437, 66.53082193647111, 46.55763101577759, 67.05794702257428, 59.17000457218715, 61.89693628038679, 49.59686688014439, 59.945965494428364, 7.954903108733041, 2.510827098573957, 3.705212882586888, 7.608098540987287, 0.7779552723680223, 1.315789595246315, 54.82725191116333, 54.404137883867534, 53.89931998934065, 45.44083663395473, 42.7999027797154, 40.512156282152446, 46.23736422402518, 48.41711139678955, 52.135478087833945, 50.966398511614116, 51.406785760607036, 44.39459426062447, 38.73903853552682, 36.455200399671284, 47.444380964551655, 50.16247803824288, 52.412318638392854, 47.40125349589756, 46.26139456885201, 46.74985987799508, 51.712138244083945, 50.4550701550075, 50.73923410688128, 44.80349574770246, 38.69056790215628, 38.032194818769185, 36.86686379568917, 37.504329749516074, 37.56201022011893, 37.253430298396516, 37.93666056224278, 38.169063908713206, 37.86550406047276, 37.870534556252615, 39.910442284175325, 40.017392430986675, 37.95980501174927, 36.78739377430507, 38.05290739876883, 38.2015814781189, 36.02514859608242, 36.252997398376465, 39.926589897700715, 45.098148005349294, 47.03641401018415, 47.5402626310076, 47.361878054482595, 46.68465450831822, 43.65497589111328, 39.22268874304635, 36.976655755724224, 36.06863737106323, 35.47562946592058, 37.04191671098982, 38.18592371259417, 39.88714497429984, 39.62796327045986, 38.6532803944179, 40.88181781768799, 38.94303069795881, 39.713238511766704, 38.0364853313991, 37.92182615825108, 37.3047844341823, 38.06025511877877, 36.99678121294294, 36.851084436689106, 34.96693795067923, 37.41404485702515, 34.29507841382708, 34.870986802237375, 36.817826884133474, 38.574119567871094, 44.51082720075335, 47.83198969704764, 48.250274726322715, 46.55086694444929, 47.31543976919991, 46.772903578622, 41.473811285836355, 36.51181779588972, 36.75696413857596, 36.27498149871826, 36.18157686505999, 38.04834590639387, 37.02699545451573, 36.871380124773296, 38.572455474308555, 37.538264751434326, 36.92099721091134, 36.662746565682546, 36.507971967969624, 36.096218245370046, 37.401635374341694, 37.02300024032593, 37.51308100564139, 37.90035622460501, 38.222495555877686, 38.5098556791033, 39.00622803824288, 37.44343226296561, 37.26098993846348, 42.93723739896502, 46.014990602220806, 44.68714468819754, 45.7575945854187, 48.32970305851528, 50.17865344456264, 50.34100157873971, 48.898937702178955, 47.51052434103829, 53.8803687776838, 57.722993578229634, 49.909059865134104, 41.01519543784005, 37.77909973689488, 39.36328206743513, 39.2882901600429, 43.743878092084614, 48.733737332480295, 53.629121916634695, 59.02412714276995, 44.45625604901995, 0.6052804323179382, 1.0555566506726402, 10.183107018470764, 8.369496038981847, 0.9603626387459892, 3.0670067284788405, 61.173323086329866, 58.811255182538716, 61.25640269688198, 62.270158767700195, 55.000755378178184, 39.21424668175833, 36.08115802492414, 44.67284182139805, 64.05212851933071, 13.68111332825252, 0.175898600635784, 0.13113217135625227, 0.22898784545915468, 0.17154389859310218, 0.12477007774370057, 0.14276998330439838, 0.08869984147271939, 0.12707054215882504], [0.01766788650171033, 0.05754345402653728, 0.0492144468506532, 0.03725792361157281, 0.05666566041431256, 0.1053323225517358, 0.029469179588236978, 0.018010373659698025, 0.02993059018626809, 0.06714124365576676, 0.023865498136729002, 7.846084765025547, 57.37510074887957, 39.925346170152935, 42.868255683353965, 68.54478509085519, 67.08469758714948, 39.5107228415353, 49.188941614968435, 50.88033812386649, 52.78269236428397, 43.65144273212978, 52.01104279926845, 15.41718588556562, 0.8454449166144643, 0.4186785253030913, 0.5265185843620981, 1.1232847592660358, 0.03459515881591609, 36.595620019095286, 54.73622703552246, 49.04864011492048, 42.61815874917166, 38.26787076677595, 43.16336652210781, 47.608559949057444, 47.3252124105181, 48.673100403376985, 48.36940506526402, 45.420961311885286, 36.91590765544346, 32.347119671957834, 38.007386275700156, 43.85397924695696, 46.148274421691895, 46.34078121185303, 39.4696763583592, 43.36210584640503, 44.17430509839739, 42.944387095315115, 43.68015616280692, 46.162903853825156, 43.33600493839809, 41.74280384608677, 35.37094095775059, 34.53763655253819, 32.501463481358115, 34.22918864658901, 33.19289609364101, 34.909128938402446, 34.32089444569179, 33.68816021510533, 33.76837369373867, 33.610510621752056, 34.61248254776001, 35.36010524204799, 34.547933782849995, 35.743444306509836, 34.10350268227713, 31.198377473013743, 31.788415023258754, 37.89945295878819, 41.72885186331612, 41.79069777897426, 42.240082945142476, 43.63562863213675, 43.83893987110683, 38.566976819719585, 39.34014456612723, 36.60273150035313, 33.503338132585796, 34.65889304024832, 33.70207745688302, 36.88435588564192, 36.17308269228254, 34.319567339760916, 35.62958070210048, 37.61075530733381, 35.64835473469326, 34.552682876586914, 34.67514140265328, 33.43973084858486, 32.60102421896798, 34.39162710734776, 34.629345825740266, 32.99320139203753, 34.94261578151158, 34.062852246420725, 35.34462118148804, 36.5786247253418, 35.3604074886867, 38.42491742542812, 42.13953903743199, 43.981617655072895, 43.09606974465506, 42.38487992967878, 40.83106817517962, 42.401138714381624, 38.028001580919536, 32.38607474735805, 30.887042590550013, 33.21827786309378, 34.36333751678467, 32.47724553516933, 33.46085337230137, 33.69377783366612, 33.692961420331685, 34.4354841368539, 34.75177308491298, 32.46867493220738, 32.47563702719552, 30.901550429207937, 32.145371777670725, 31.510059765407018, 33.90549986703055, 32.73655578068325, 31.820296832493373, 33.188303334372385, 34.15003476824079, 34.772721903664724, 38.285658155168804, 41.47350556509835, 40.95964459010533, 41.082773617335725, 41.792629378182546, 43.5908579145159, 47.77902357918875, 47.68231507710048, 47.43194368907383, 45.62785087312971, 40.930462156023296, 50.9627229145595, 48.538124697549, 43.68435982295445, 34.80551740101406, 35.074878215789795, 35.04244402476719, 36.983458042144775, 44.39306565693447, 48.56901638848441, 53.703967911856516, 38.0238013948713, 0.1954397577792406, 0.0166109002727483, 5.3495948399816236, 4.034860176699502, 0.7807481225047792, 5.9675363557679315, 55.33525555474417, 49.36218105043684, 54.30211053575788, 53.288483006613596, 43.068659101213726, 28.794095788683208, 30.242882047380718, 35.80714886529105, 41.758242743355886, 1.5094306788274219, 0.14685594476759434, 0.0834806247481278, 0.07689722015389375, 0.04570753360167146, 0.04417908597471459, 0.010171326442754694, 0.027627906961632625, 0.02199297388350325, 0.029436379205435514, 0.018742083771420375, 0.07991968654096127, 0.0692637147647994, 0.035108053258487155, 0.0273231870627829, 0.04251810349524021, 0.011987634917854198, 0.035010883651141605, 0.05079699746732201, 0.14434645085462502, 9.761708327702113, 66.04318346296037, 44.283238955906455, 53.38740798405239, 75.09398337772915, 67.71652507781982, 44.762911319732666, 56.5205591746739, 55.46422801698957, 56.33139794213431, 48.693628856113975, 57.62950209208897, 15.132780483790807, 0.6368891447782516, 1.283278648342405, 3.2974639279501776, 1.293385997414589, 0.13173818455210753, 40.51377868652344, 57.67111485345023, 50.11093282699585, 44.90392848423549, 40.78237519945417, 43.35083586829049, 48.532194410051616, 50.02830137525286, 52.05262776783535, 49.34105157852173, 48.20999601909092, 39.51523569652012, 33.683845383780344, 39.03018890108381, 46.244614669254844, 46.566340582711355, 47.72648824964251, 41.01517111914498, 43.877349512917654, 44.78227594920567, 45.39366183962141, 45.986238956451416, 47.80853952680315, 46.40449966703142, 42.978252615247456, 36.58330086299351, 37.45021023069109, 36.144914695194785, 36.21149928229195, 35.649904182979036, 35.690533774239675, 36.295308453696116, 35.793196882520405, 35.0916303225926, 34.897869382585796, 35.74340956551688, 36.940872532980784, 36.53567443575178, 38.23470006670271, 34.792357512882774, 32.640371867588584, 34.276759488242014, 39.0850692476545, 44.4275495665414, 45.44313996178763, 43.73560626166207, 45.08385556084769, 45.94786752973284, 40.630914892469136, 38.62479625429426, 36.72033323560442, 33.03389351708548, 33.88191073281424, 34.072697843824116, 38.00198057719639, 37.01093816757202, 37.57468373434884, 36.64568526404244, 37.94460235323225, 37.38467829568045, 35.19356039592198, 36.38799394880022, 34.76311254501343, 34.88530356543404, 35.34058427810669, 35.40830489567348, 34.19926275525774, 34.33164330891201, 35.60438305991036, 35.73806292670113, 36.54518304552351, 36.817715712956016, 38.938754081726074, 42.1232385635376, 45.73718772615705, 45.22492831093924, 43.47215141568865, 44.37673739024571, 45.294458934238975, 40.63107817513602, 34.17926583971296, 32.696471623011995, 32.85970217841012, 36.235505308423726, 34.810957840510774, 35.44870867047991, 35.491606848580496, 34.453149931771414, 35.17877810341971, 37.733425753457205, 34.28403772626604, 35.19148983274187, 33.099289962223594, 34.741448061806814, 33.84156601769583, 35.541581766945974, 35.37076030458723, 34.4563113621303, 36.04786920547485, 36.097350801740376, 37.20562669209072, 38.91935471126011, 42.590282576424734, 43.01883009501866, 43.64215299061367, 43.62190593991961, 44.91915546144758, 48.459759439740864, 48.326989786965505, 50.07004267828805, 47.73345034463065, 43.01902117047991, 53.0157801083156, 49.35788706370762, 46.154635497501914, 35.22697080884661, 37.08989749635969, 37.537087031773154, 39.591248989105225, 46.884832109723774, 51.341580390930176, 53.677356311253135, 41.171057428632466, 0.2778845988214016, 0.12547118083706923, 8.919225352151052, 4.211087337562016, 0.9436319193669728, 6.317394656794412, 60.559553963797434, 51.69170011792864, 58.11008466993059, 55.96323374339512, 48.065890380314414, 32.64463111332485, 33.24696002687727, 41.79595409120832, 50.040929726191926, 2.84016324366842, 0.2120685883398567, 0.034098817235124965, 0.019639565077211176, 0.06808148284575768, 0.07448358288300888, 0.046175654911037, 0.025488743891141245, 0.08151488844305277, 0.12174252234399319, 0.1968799483563219, 0.17173846172434942, 0.18346263760966913, 0.17809606343507767, 0.19004506511347635, 0.10672777731503759, 0.21708877038742813, 0.18046446277626924, 0.2017401047050953, 0.37585235333868433, 11.713971478598458, 74.26711300441197, 51.13494096483503, 53.91655847004482, 75.03071308135986, 70.5857628413609, 50.41529866627285, 59.33548286982945, 59.42592062268938, 63.48207746233259, 51.833564962659565, 61.91225011008126, 19.167003597532, 1.2685874423810413, 4.517693102359772, 6.692772822720664, 3.6166546174458096, 0.37750599746193203, 43.948568548474995, 58.009464332035606, 53.39945616040911, 46.27599273409162, 41.7217994417463, 45.310453687395366, 52.66724109649658, 50.97076545442854, 52.559418950762065, 51.61213629586356, 50.053947176252095, 40.87957007544381, 36.21945149557931, 41.12855182375227, 48.982243129185264, 49.3132518359593, 51.28039802823748, 42.89902925491333, 44.52112790516445, 46.91452176230294, 48.02407264709473, 49.17477771214077, 50.07996123177664, 47.59031745365688, 46.101495674678254, 38.80395555496216, 38.31115804399763, 37.70003965922764, 39.27223287309919, 37.676186493464876, 37.444603034428184, 38.824841839926584, 37.09901353291103, 36.13906083788191, 36.710584912981304, 36.77222238268171, 39.00845493589129, 38.27457577841622, 39.559203897203716, 37.917080538613455, 34.660164560590474, 37.09986468723842, 41.83218199866158, 48.753671714237754, 46.92219257354736, 46.48324360166277, 47.031484263283865, 46.52769122804914, 40.07088313783918, 39.43748188018799, 36.66705444880894, 33.75683968407767, 35.45176935195923, 34.99278177533831, 39.89275564466204, 39.8233049256461, 38.67604269300188, 38.984032017844065, 40.65944072178432, 39.03794656481062, 37.3673494883946, 38.98411192212786, 36.64369807924543, 36.05737434114729, 36.71482331412179, 38.77490513665335, 34.79361513682774, 36.934699058532715, 36.46858263015747, 36.52355677740914, 37.20901393890381, 36.65285233088902, 39.71607337679182, 44.8629584312439, 47.15157692773001, 47.646702085222515, 45.13628666741507, 46.50016941343035, 47.81714139665876, 43.04117897578648, 37.478107248033794, 35.46087844031197, 37.230327538081575, 38.45145954404558, 36.334881918770925, 37.04019008363996, 36.5525655065264, 35.95660809108189, 36.654391356876914, 39.14570965085711, 36.32138156890869, 36.087640694209504, 33.86574574879238, 37.10134812763759, 34.5818201473781, 39.16068301882063, 38.172124590192524, 36.24718175615583, 37.54119689123971, 37.43349633898054, 38.4439172744751, 40.991474287850515, 45.03809472492763, 46.09891094480242, 44.68806879861014, 45.006970269339426, 46.49753257206508, 50.934412479400635, 50.32715034484863, 51.26296847207205, 49.83604819434029, 44.506838934762136, 54.16432428359985, 51.18212618146624, 49.05267701830183, 38.03328568594796, 39.21585518973214, 39.35418340138027, 41.14480018615723, 49.35149819510323, 54.43057230540684, 55.18790858132498, 44.57433373587472, 0.7327074632048607, 0.9716647522790092, 15.321102721350533, 13.539117336273193, 1.395846847976957, 7.371056403432574, 65.74483476366315, 57.42017718723842, 63.57788617270333, 61.9175237928118, 56.31505577904837, 39.925141198294504, 41.876845019204275, 46.8722037587847, 59.35893998827253, 4.638826259544917, 0.3840261218803269, 0.1367359749440636, 0.3241090912904058, 0.10857224584157978, 0.11291757731565408, 0.1871929924402918, 0.08736578055790492, 0.12693726431046212], [0.05606169639421361, 0.03126604549054589, 0.06786798858749014, 0.018981431910235966, 0.01347046293916979, 0.04683777956025941, 0.034103845179613144, 0.0007007614403846674, 0.01774761436640152, 0.06978309260947363, 0.010335882210970988, 1.0747954526117869, 45.18340935025896, 48.309153761182515, 31.711446353367396, 39.46796710150582, 47.20839582170759, 37.871201583317344, 42.856721673692974, 50.25716461454119, 50.7769524029323, 45.626416070120676, 48.411333969661165, 29.370643411363872, 0.14847145522279398, 0.43076847227556364, 3.055160701274872, 1.361753991671971, 0.2072989349918706, 27.81212772641863, 57.854304109300884, 46.34168100357056, 51.86452266148159, 44.978354113442556, 48.04010214124407, 47.39659472874233, 50.93680265971592, 49.82242625100272, 48.180490493774414, 42.51046861921038, 34.15564543860299, 33.7237662587847, 43.89093324116298, 45.677144868033274, 47.873129980904714, 43.38738686697823, 42.16244377408709, 44.852761949811665, 43.59197310038975, 46.492019176483154, 43.96112741742815, 46.495861530303955, 43.21382781437465, 44.53919669560024, 40.12332814080374, 34.635828495025635, 33.23941428320748, 33.74012231826782, 33.806797231946675, 33.00466244561331, 33.92983940669468, 33.77220909936087, 36.02420711517334, 35.2356664793832, 34.313803809029714, 36.964694431849885, 34.978749888283865, 36.60840470450265, 34.260507651737754, 32.64659397942679, 31.791406222752162, 37.912546839032856, 41.17424317768642, 39.863819871629985, 41.46812765938895, 43.452157974243164, 44.21316984721592, 38.714341163635254, 36.662145546504426, 32.973982674734934, 33.09924479893276, 32.75760882241385, 36.277538435799734, 36.45077439716884, 34.270533902304514, 36.012412548065186, 33.55691916601998, 35.21800068446568, 34.91808864048549, 34.20047174181257, 34.1607905796596, 33.21570702961513, 33.007545948028564, 32.70720311573574, 32.899317332676475, 35.221144744328086, 34.17120245524815, 35.88674048015049, 34.51148700714111, 34.95363909857613, 36.4601058278765, 40.021835803985596, 41.70459917613438, 42.88239874158587, 41.37005731037685, 41.191009180886404, 40.63041114807129, 40.89491517203194, 38.54984603609358, 33.449913433619905, 31.16722869873047, 33.80349336351667, 33.50576305389404, 33.99555546896798, 32.75544098445347, 33.81352308818272, 32.31247247968401, 34.568093981061665, 35.26930965696062, 33.65865816388811, 33.08778027125767, 31.186037472316197, 30.899789060865128, 31.65619080407279, 33.20452390398298, 32.49217026574271, 31.535146236419678, 33.21843072346279, 32.49843406677246, 34.893068177359446, 38.43858800615583, 40.15134327752249, 42.47551570619856, 41.722542898995535, 40.01385579790388, 41.47435671942574, 42.66625417981829, 45.989650521959575, 47.51177501678467, 49.3001058442252, 44.46534081867763, 47.05011933190482, 50.35385922023228, 47.25438594818115, 40.423691817692344, 33.35712024143764, 36.99664224897112, 37.67415067127773, 44.65377943856375, 50.66263369151524, 52.94826446260725, 40.34871728079659, 0.08162991369941405, 0.27026283208812985, 6.449558513505118, 1.705583427633558, 0.2366010355097907, 12.818206991468157, 58.218681539808, 46.081939969744, 56.01499087469918, 49.984607628413606, 36.46922186442784, 21.36596601349967, 26.688682181494578, 36.992487226213726, 37.94882685797555, 0.2960607334971428, 0.022709686674975922, 0.014043274568393826, 0.06514636427164078, 0.029868656902440956, 0.05434918935809817, 0.0029629677717041758, 0.05368523266432541, 0.034732904817376814, 0.026026274243901883, 0.06114857164876802, 0.1410435595150505, 0.0639326415423836, 0.017572362341785004, 0.05101936696363347, 0.02590983933103936, 0.1083739846944809, 0.016708957064630728, 0.029211801077638353, 0.01874482335655817, 2.1896264255046844, 53.21554429190499, 53.530207361493794, 33.533274446214946, 53.08622094563076, 60.36738763536726, 42.6003748348781, 48.426022461482454, 55.16862038203648, 56.19853796277727, 49.978399412972585, 53.548463753291536, 31.580396379743302, 0.08127263787069491, 0.8610899799636432, 3.09243192417281, 3.8912343978881836, 0.08847164336059775, 32.480146408081055, 58.98670414515904, 48.34062910079956, 50.806478772844585, 45.06497730527605, 48.65562915802002, 49.04294606617519, 51.14996991838728, 49.88674572535923, 49.065982818603516, 44.48018217086792, 36.81005532400948, 36.37633834566389, 45.659267153058735, 46.92482246671404, 49.23226015908377, 46.37888165882656, 42.15658296857561, 46.1302855355399, 44.186530453818186, 46.80565391268049, 46.52004473549979, 47.38732235772269, 44.756247997283936, 47.641966887882774, 41.70418575831822, 36.584436893463135, 36.12349687303816, 35.046442713056294, 34.94158397402082, 36.1569732938494, 35.42346586499895, 36.894104208265034, 37.45491763523647, 36.443888732365195, 36.80165147781372, 37.02249302182879, 36.260699476514546, 38.036412375313894, 37.150742871420725, 34.09919479915074, 34.26699379512242, 40.33770786012922, 44.09341069630214, 40.890072277614046, 43.602131366729736, 45.01257051740374, 46.623399189540315, 39.37374258041382, 35.995424202510286, 31.904835564749582, 32.59829705102103, 34.19812672478812, 35.279516560690745, 36.621779986790244, 36.51427398409162, 37.72347593307495, 35.657314436776296, 37.23703602382115, 35.96818378993443, 34.823864119393484, 35.48227194377354, 35.50630923679897, 34.58671167918614, 34.77336113793509, 35.25221708842686, 37.261465890066965, 35.56317676816668, 36.6753123828343, 35.480885778154644, 37.262407370976035, 37.19738960266113, 38.69137041909354, 42.13324396950858, 46.24276992252895, 44.05421938214983, 44.2745988709586, 43.46868426459176, 42.56447001865932, 41.211075578417095, 35.1291366985866, 31.323514529636928, 35.04245792116438, 35.10764592034476, 35.0014774458749, 35.16791806902204, 34.890691893441335, 35.62949384961809, 36.372242382594514, 36.16957037789481, 34.65446356364659, 35.73864310128348, 34.5752923148019, 32.791856493268696, 34.62405129841396, 34.42655917576381, 35.39584330150059, 34.2316517829895, 34.64290870938982, 34.711341517312185, 37.02045719964163, 40.744757652282715, 42.066270283290315, 45.63397571018764, 42.37147685459682, 44.06142813818795, 43.24493489946638, 44.2666779245649, 48.55271591459002, 49.116781098502024, 51.87730387278965, 45.93300880704607, 48.31406266348702, 52.42985241753714, 50.240478515625, 42.69962290355137, 35.525778089250835, 38.20293985094343, 40.54978772572109, 46.77376168114798, 54.186054774693076, 53.971511772700715, 41.82569238117763, 0.28616758435964584, 0.30597380442278727, 11.146931597164699, 2.9194639027118683, 0.40884386588420185, 14.433167236191885, 63.689411708286826, 51.00797305788313, 61.383381026131765, 55.4477573122297, 44.6956319127764, 27.47301742008754, 30.479322297232493, 41.84902443204607, 45.39323452540806, 0.7878440788814, 0.08048123533704452, 0.013497411805604185, 0.03993210136624319, 0.046952316271407266, 0.04711188056639262, 0.03282770062131541, 0.025270871385665875, 0.04416650254279375, 0.1503411584666797, 0.19753031060099602, 0.24380935728549957, 0.11532341821917466, 0.11623025313019753, 0.1518429328820535, 0.18441640000258172, 0.125197188396539, 0.06827652095151798, 0.1333203110843897, 0.12588121954883846, 2.263280587536948, 59.46644251687186, 60.6979203905378, 42.840320450919016, 51.17528567995344, 56.364450522831504, 47.30451372691563, 52.322857107434956, 58.64568655831473, 61.1965856552124, 55.29360457829067, 56.71053334644863, 36.298136370522634, 0.18908051401376724, 3.130615098135812, 6.157906574862344, 4.08448247398649, 0.3069683467703206, 33.391208103724885, 61.91762801579067, 51.767011642456055, 55.618627411978586, 48.143487862178254, 51.435401916503906, 50.3327089037214, 53.99010167803083, 52.525786195482524, 52.38069043840681, 47.27942378180367, 38.0803666796003, 37.701415402548655, 46.76923492976597, 48.635764258248464, 52.78993238721575, 48.092217104775564, 43.640238761901855, 48.755370548793245, 46.888226304735454, 48.7173604284014, 50.5023387500218, 50.25467021124703, 46.51637608664376, 50.636473723820274, 43.65316241128104, 38.103987080710276, 37.79393066678728, 38.69414969852993, 37.62496437345232, 37.62673268999372, 37.07332604272025, 38.0530081476484, 39.88367782320295, 38.24187408174787, 37.079815660204204, 38.90563896724156, 38.90725094931466, 38.577010018484934, 38.580185345241, 36.68712084633963, 36.82469865253994, 41.635961396353586, 44.41180147443499, 41.94504158837454, 44.25162117821829, 48.24015814917428, 46.667794704437256, 39.32674843924386, 35.91714927128383, 31.91131475993565, 33.542793478284565, 35.341609137398855, 35.98848295211792, 38.83102921077183, 38.791681562151226, 41.01455967766898, 36.26720993859427, 39.493345396859304, 38.65477773121425, 37.196010385240825, 39.25486237662179, 37.658194133213584, 37.27445902143206, 36.27220916748047, 37.12164728982108, 38.79042741230556, 37.190917355673655, 38.38678571156093, 35.98695434842791, 36.966580867767334, 37.028520584106445, 40.314007554735454, 43.19530044283186, 47.68557725633894, 44.82161317552839, 45.08352204731533, 45.56608486175537, 45.72352409362793, 43.43600688661848, 37.769733565194265, 35.475622517721995, 38.09180688858032, 37.02039813995361, 37.04270533152989, 35.697384698050364, 38.53684595652989, 36.5420355115618, 38.496153831481934, 38.42502164840698, 37.23247453144619, 38.132137707301546, 36.779007298605784, 34.28113685335432, 37.40389353888375, 37.047916480473106, 37.47340331758772, 35.72171381541661, 37.15517234802246, 36.82809632165091, 39.07507773808071, 42.624773434230256, 45.1987509727478, 48.35157946177891, 44.53760208402361, 45.05952991758074, 45.60843413216727, 46.30238199234009, 50.514477252960205, 53.52542005266462, 52.719800744737896, 47.84776905604771, 50.032268796648296, 53.85811717169625, 53.77765008381435, 44.887009620666504, 38.71538686752319, 40.25203309740339, 44.279372283390586, 47.784832273210796, 56.69571283885411, 54.10204063143049, 46.45980037961687, 0.7126866632274219, 1.0898239719016212, 17.44157828603472, 6.384446510246821, 0.5973100885748863, 16.314227853502544, 69.86809035709926, 55.29619625636509, 67.0793822152274, 59.66740526471819, 48.53354236057827, 29.470614092690603, 37.36469875063215, 49.55578565597534, 54.01193291800362, 1.4056289345026016, 0.1500750777444669, 0.1273673198052815, 0.15183473617902823, 0.2075212366346802, 0.13669035024940968, 0.18295634192015442, 0.14706924903605664, 0.21153762111706392], [0.02837477045665894, 0.04959152911656669, 0.02314555042955492, 0.08598017812307392, 0.07942970283329487, 0.06722591804074389, 0.060803224465676715, 0.021286332248044864, 0.05055428888382656, 0.04771300831011363, 0.10960358514317445, 0.038394846354744265, 26.087682110922678, 55.9478052684239, 40.91619403021676, 26.41881935937064, 18.323627778462, 36.90480443409511, 50.21360288347517, 53.367640359061106, 47.92666585104806, 49.107039724077495, 45.045953137534006, 37.23385374886649, 0.1977207346686295, 1.2992719901459557, 2.3271753532545905, 4.383878179958888, 13.991657853126526, 7.885666915348597, 55.940005915505544, 50.178715978349956, 47.83497742244175, 44.28706046513149, 49.79362596784319, 48.585007667541504, 52.749598094395225, 46.500673157828196, 46.63954332896641, 36.792823791503906, 32.70006384168352, 37.81223917007446, 46.98747784750802, 45.94262858799526, 46.27693421500069, 43.98354925428118, 44.27525200162615, 48.056013516017366, 46.59150695800781, 46.29192495346069, 45.103928906576975, 44.16345201219831, 48.00725105830601, 43.36111225400652, 41.898641518184114, 38.924663134983604, 33.764732837677, 33.800863470349995, 34.479785851069856, 33.17941311427525, 34.83243819645473, 34.84620952606201, 34.30325296946934, 34.43737752096993, 34.465489932468955, 36.3249842098781, 35.23990488052368, 36.597926821027485, 33.77961935315813, 30.59243549619402, 33.33967678887503, 37.77151925223214, 39.573086397988455, 40.16020223072597, 42.516579559871126, 43.68082666397095, 42.19391911370413, 38.488788740975515, 34.85374484743391, 34.55235283715384, 35.134132453373496, 36.256179673331125, 35.400373526981895, 33.569022927965435, 34.64493063517979, 32.67996965135847, 34.45899336678641, 34.92896604537964, 35.28543642589024, 34.03393036978585, 34.08356830051967, 34.2700058392116, 34.122825622558594, 31.950321946825298, 33.362095151628765, 33.29133469717843, 35.05694144112723, 34.75935009547642, 36.09475564956665, 33.87608119419643, 36.14952482495989, 37.071679319654194, 40.68743848800659, 44.980615752083914, 42.417578152247835, 41.56541633605957, 41.57762084688459, 40.3101304599217, 37.40506431034633, 32.26910182407924, 31.44671998705183, 32.527276039123535, 33.84221567426409, 32.498642512730186, 33.44036660875593, 33.807672704969136, 32.48998505728585, 31.66315984725952, 32.23153638839722, 32.20507764816284, 32.43907560620989, 30.450119018554688, 32.603525570460725, 33.01391397203718, 31.728031703404017, 33.82527249200003, 34.04922682898385, 34.40883084705898, 34.53608363015311, 34.85018389565604, 38.15410096304757, 41.01554979596819, 40.72262416567121, 39.311337334769114, 41.021143095833914, 40.193348612104145, 41.80996513366699, 44.13899087905884, 47.32984685897827, 48.53537668500628, 47.36042240687779, 45.27908951895577, 50.71595764160156, 48.23936258043562, 44.92458200454712, 35.65767226900373, 33.79945993423462, 38.584402901785715, 45.49703366415841, 50.41970729827881, 49.79047843388149, 41.731332370213096, 2.0927806964942386, 0.18818909541836806, 6.087057530879974, 0.46234507645879475, 0.26842489785381723, 28.542418139321462, 54.70995937074934, 46.61770861489432, 54.04628133773804, 48.684575353349956, 29.70530687059675, 23.973532881055558, 35.09995079040527, 42.177757603781565, 22.624383790152415, 0.05601573582472546, 0.006090723709868533, 0.14407826667385443, 0.051625753353749, 0.030987418655838286, 0.02147384879312345, 0.04833434961204018, 0.03374997220401253, 0.05958035508436816, 0.05456386087462306, 0.11801333459360258, 0.048047753383538554, 0.034808938058891466, 0.021429185921858464, 0.09428894120667662, 0.028875132357435565, 0.02504840010910162, 0.020496220627267445, 0.012708194154713835, 0.09102788833635193, 0.0179260962177068, 33.31032064982823, 59.92698301587786, 42.689120701381135, 31.555737222943986, 33.75395965576172, 47.4609489440918, 50.89807340076992, 57.62378372464861, 50.84482588086809, 54.54663848876953, 49.20284843444824, 41.14615855898176, 0.21601903278912815, 0.8646236817751611, 3.1744649623121535, 8.745986785207476, 15.834103856767927, 9.17094555922917, 59.96371119362967, 52.56565843309675, 51.05827801568167, 46.705429622105186, 51.36746937888009, 49.17999928338187, 53.37175021852766, 49.747194630759104, 48.23083714076451, 39.253000259399414, 34.09365708487374, 39.27830212456839, 47.84649406160627, 47.841769286564414, 48.28233371462141, 43.87899623598371, 46.82676601409912, 51.358214378356934, 48.945709500994, 47.83461264201573, 47.54002986635481, 47.18989624295916, 49.86602619716099, 45.73964391435896, 43.64117676871163, 39.818260533469065, 36.06693506240845, 35.241082600184846, 36.634380544934956, 34.517267908368794, 37.488665035792756, 35.817223753247944, 36.29068790163313, 36.07820504052298, 35.857165472848074, 37.52757147380284, 36.936766147613525, 37.05617788859776, 36.4539601462228, 32.27311093466622, 35.19773278917585, 39.39748110089983, 40.93779597963606, 41.45214332853045, 44.01475708825247, 44.26404455729893, 42.89352280752999, 37.56120075498308, 35.424754755837576, 34.85456126076834, 35.0740305355617, 36.070902483803884, 37.07881511960711, 34.67662831715175, 34.32691853387015, 35.12819521767752, 35.39621850422451, 36.31194938932146, 36.603971753801616, 35.75911944253104, 35.83658490862165, 34.776710169655935, 35.46110773086548, 34.126393522535054, 34.17025402614048, 35.19736800874983, 36.458664076668875, 36.027024609701975, 36.794692856924875, 35.67716891424996, 36.13298463821411, 36.905165740421836, 42.46054233823504, 46.859002181461875, 43.5109293120248, 43.779515402657644, 42.32978071485247, 42.46801512581961, 39.029754638671875, 34.16309043339321, 33.183189460209434, 33.972331115177695, 34.936251231602256, 34.8547488621303, 35.6591591835022, 35.47812039511544, 33.696654387882774, 33.45326246534075, 34.79863521030971, 34.18502937044416, 34.44530194146292, 33.11614976610456, 34.4493909563337, 34.69300522123064, 34.874141284397666, 33.891134466443745, 35.08880935396467, 37.426718371255056, 35.963764735630576, 36.187020778656006, 39.38057960782732, 41.74434287207467, 42.33615568705967, 42.2402913911002, 41.98285368510655, 41.15196030480521, 43.46954236711775, 47.238703863961355, 48.579417841775076, 50.49200330461775, 48.72937733786446, 45.9854051726205, 53.40149545669556, 51.815537861415315, 47.326994623456685, 37.19781344277518, 35.333445004054475, 41.500471523829866, 47.35606936046055, 54.25797210420881, 51.50755895887102, 43.907303197043284, 2.7995199731418063, 0.31432719475456644, 5.607364756720407, 2.3800009872232164, 0.14700831659138203, 29.080615179879324, 62.45477935246059, 50.15922280720302, 60.410869462149485, 51.23512009211949, 37.64659064156668, 24.604649918419973, 37.165618964603965, 47.32750184195382, 30.007987771715435, 0.08824327561472144, 0.012928567061732923, 0.1222239157983235, 0.06776455949459757, 0.020241720801485435, 0.02335385898394244, 0.012552487331309488, 0.03573190853265779, 0.03494422097823449, 0.13032721169292927, 0.23124527718339646, 0.15041423668818815, 0.18190778818513664, 0.2106652015021869, 0.167908782937697, 0.136037748839174, 0.12478328203516346, 0.14018215930887631, 0.15223102777131967, 0.2533000808741365, 0.09466337718601738, 35.915151664188926, 72.46329116821289, 51.527899810246055, 39.943029335566926, 30.981364386422293, 50.082990646362305, 58.260127544403076, 64.07562732696533, 56.308670384543284, 58.503894669669016, 53.668525150844026, 45.52719579424177, 0.41600238318954197, 5.156648141997201, 6.087125275816236, 12.394154957362584, 19.919073138918193, 11.136579649788992, 60.82675388881138, 56.428071703229634, 53.251511641911094, 49.45659664699009, 53.09253338405064, 51.4433992930821, 56.357978275844026, 51.45629514966692, 51.54045867919922, 42.02222565242222, 36.038711479731965, 42.469502040318076, 49.33410685403006, 49.32719687053135, 50.78268119267055, 45.46727105549404, 46.716630118233816, 51.81552396501814, 50.84649344852993, 49.75095360619681, 48.243604455675396, 49.06384972163609, 51.77871240888323, 48.28535965510777, 47.539675508226665, 43.7022271156311, 38.175963469914024, 37.36913170133318, 39.97953864506313, 35.469251019614084, 38.63553816931588, 38.43048988069807, 37.761149065835134, 38.338190010615754, 38.73341396876744, 39.659970147269114, 39.10781070164272, 39.73290886197771, 37.81944097791399, 33.74612903594971, 37.71322386605399, 41.80314547674996, 44.05841956819807, 44.11879593985421, 45.30625697544643, 48.03656898226057, 43.355918475559776, 39.15018081665039, 35.99181808744158, 36.99198695591518, 36.618608134133474, 37.61047043119158, 39.56842763083321, 36.80614001410348, 37.072005884987966, 35.830411434173584, 38.29413843154907, 38.02760205950056, 39.666762011391775, 39.02141680036272, 38.86089604241507, 36.73436859675816, 38.869748047419954, 34.81748219898769, 38.08811044692993, 35.977435316358296, 38.3001833643232, 37.93492003849575, 38.62549107415335, 36.34809739249093, 37.233812059674946, 37.57131038393293, 42.41989885057722, 50.097036429813926, 46.230141571589876, 45.61719928468977, 46.53397239957537, 45.376277446746826, 40.696221011025564, 36.56846645900181, 36.47574969700405, 36.17284992762974, 36.74160167149135, 37.01285587038313, 37.93399592808315, 36.25456769125802, 35.13650873729161, 33.99827568871634, 35.53967796053205, 35.94315637860979, 36.02404383250645, 35.14011485236031, 37.80576344898769, 37.20623465946743, 37.33746876035418, 37.66696623393467, 38.29285996300833, 39.56361252920968, 39.05224943161011, 37.6228278023856, 41.18908452987671, 44.28930820737566, 44.327366965157644, 44.08654587609427, 44.91385398592268, 44.029115540640696, 46.06709166935512, 48.508799825395855, 50.15157631465367, 52.42234836305891, 50.4028058052063, 49.015834195273264, 54.29959528786795, 52.214225496564595, 49.97853142874581, 39.133539881025044, 37.10171638216291, 44.24306794575283, 49.85547535760062, 56.4454665184021, 52.698775495801655, 45.39615624291556, 4.4550846219062805, 0.5802405902317592, 17.346806594303676, 7.50063249043056, 0.4253343567252159, 35.224111625126426, 65.27868012019566, 56.017002378191265, 63.76701613834926, 56.18564905439104, 40.69342088699341, 34.24916124343872, 44.10512883322579, 55.183364459446494, 36.7896727834429, 0.29975465099726406, 0.13015031761356763, 0.21645461155899934, 0.2614845974104745, 0.11700136746679034, 0.12565013766288757, 0.1803311306451048, 0.15362423658370972, 0.15420618892780372], [0.0285989991389215, 0.006665533624722489, 0.052972224674054554, 0.023800377434651767, 0.06845409356589828, 0.07486675160803966, 0.042431753128767014, 0.009605829421031688, 0.031035889804895436, 0.052167071628251245, 0.04364742325352771, 0.05887889915278979, 5.287819274834224, 59.638570240565706, 40.680306162152974, 43.11866876057216, 18.847313506262644, 23.638775621141704, 49.797332831791465, 52.512740952628, 47.10906090055193, 51.3136625289917, 44.357219900403706, 48.52085147585188, 2.400844497340066, 0.9809098733322961, 2.4852590305464606, 5.733725564820426, 4.601114911692483, 1.9838941735880715, 40.12178911481585, 54.52451889855521, 50.75955063956124, 51.076572622571675, 48.86696556636265, 48.5957704271589, 46.929842540196006, 49.175145966666086, 40.1327360016959, 34.56863246645246, 37.414944648742676, 42.871823583330425, 45.77720240184239, 45.978005341121126, 47.76615898949759, 49.40438788277762, 47.618242263793945, 44.78921372549874, 47.12200539452689, 45.99710593904768, 47.51607942581177, 44.90132290976388, 43.279290267399375, 46.84568248476301, 41.63355731964111, 40.25962747846331, 37.46664272035871, 35.871305056980674, 34.64580263410296, 33.94855090550014, 36.04393999917166, 34.133174964359824, 34.426045009068076, 34.55403082711356, 34.73218611308506, 36.42123760495867, 35.54119266782488, 36.086699213300435, 35.42476517813546, 31.902622563498362, 34.24982132230486, 39.0179739679609, 39.1443304334368, 39.67092745644705, 40.63305493763515, 42.011535848890034, 42.06017671312605, 37.02086019515991, 34.848321778433665, 35.23160525730678, 36.70883049283709, 34.554847240448, 34.52941335950579, 32.71363714763096, 33.94196401323591, 33.14131614140102, 33.53074182782854, 35.39999485015869, 35.92251328059605, 32.480420861925396, 33.70789657320295, 34.15689958844866, 32.85257332665579, 33.61301892144339, 32.90768643787929, 31.85218906402588, 35.52570513316563, 34.47138547897339, 35.36304433005196, 35.046546936035156, 37.16045297895159, 34.874474797930034, 41.33344725200108, 40.5668420791626, 40.712205341884065, 41.866426195417134, 41.07451568331037, 38.056513513837544, 37.24917452675955, 30.691242354256765, 30.78100265775408, 33.50427613939558, 34.858448777879985, 33.840058258601594, 31.63245575768607, 34.08067784990583, 33.907212597983225, 32.26284844534737, 33.67324243273054, 32.91692406790597, 34.31917824063982, 31.45109040396554, 31.529539040156774, 31.73346519470215, 32.54135308946882, 32.86739730834961, 33.754161153520855, 32.998791217803955, 35.20816550936018, 36.75188500540597, 37.582014083862305, 38.17046397072928, 38.64916706085205, 39.1977481842041, 37.519869395664756, 39.33554138456072, 41.12509509495327, 43.47974579674857, 43.99696969985962, 45.625248772757395, 49.784308433532715, 43.964869022369385, 45.619964667728965, 49.18002012797764, 46.96739060538155, 41.13458980832781, 34.24267162595476, 37.82442283630371, 45.30906752177647, 52.30276986530849, 50.39962700435093, 43.29689005443028, 11.455068571226937, 0.24602599548442022, 8.126025080680847, 0.6785181909799576, 0.20144184785229818, 44.20191376549857, 50.40945175715855, 48.60844394138881, 51.94646971566336, 48.00663961683001, 26.644785199846538, 28.620260545185634, 35.09972149985177, 43.32096903664725, 11.791718346732003, 0.15245900196688517, 0.029381862309362208, 0.04950485644595964, 0.08695051712649209, 0.07259773050567933, 0.01781777828000486, 0.045842595997133424, 0.023386788288397447, 0.012649185356817074, 0.05158874944650701, 0.059482693539134095, 0.07584705150553159, 0.012782433519272931, 0.034005413497132916, 0.007716217111530048, 0.05575276618557317, 0.033895426363285096, 0.09392690884747676, 0.12034426523106438, 0.05544633637847645, 0.0373841921931931, 9.222070404461451, 64.83528082711356, 46.39280932290213, 40.783045700618196, 26.10075167247227, 36.94842522484915, 52.72599506378174, 59.047361918858115, 51.190116609845845, 56.92332887649536, 49.48228413718087, 51.84002331324986, 2.219352338995252, 0.5535640131149973, 0.9083235082881791, 6.1139818004199435, 8.749438302857534, 2.775174788066319, 45.45956202915737, 56.68738194874355, 52.091846874782014, 52.129613808223176, 51.22630630220686, 50.17115633828299, 50.09299952643258, 50.39310264587402, 42.15744454520089, 36.226972920554026, 39.32062012808663, 44.039569105420796, 47.060621534075054, 48.11572980880737, 48.95543697902134, 48.60525124413626, 50.72260011945452, 46.38811928885323, 48.810893603733604, 48.559129101889475, 48.25166436604091, 46.9965626171657, 45.88258225577218, 46.39972278050014, 44.1938191141401, 42.90178074155535, 38.726691586630686, 37.08992876325335, 36.30058561052595, 36.456878389631, 36.6524076461792, 36.44700847353254, 36.19552189963204, 35.92685243061611, 35.999249185834614, 37.63757882799421, 35.75788961138044, 37.891431263514924, 37.338253906794954, 33.60759585244315, 36.111455644880024, 41.42945398603167, 42.48138345990862, 41.93392447062901, 43.839526993887766, 44.157837867736816, 42.312344210488455, 37.310624395098, 35.05905021939959, 35.9710499218532, 37.68550402777535, 35.82265724454607, 35.809264591761995, 34.66819667816162, 34.25879144668579, 33.51607418060303, 35.76208632332938, 36.6479469026838, 37.32728270121983, 33.570290974208284, 35.890489033290315, 34.74528694152832, 34.90963615689959, 33.810757705143516, 34.57824182510376, 33.614703859601704, 35.879608154296875, 35.83289194107056, 36.74468667166573, 36.47272375651768, 37.7381192616054, 35.81275953565325, 41.30526883261544, 43.81530557359968, 42.60971668788365, 42.47639117922102, 42.69670466014317, 42.7600096975054, 39.92493275233677, 32.48960638046265, 33.57157291684832, 35.69838176454817, 36.076467990875244, 35.21416180474417, 34.61455658503941, 34.673327922821045, 36.09922334126064, 34.21702929905483, 36.171171937670024, 34.61285080228533, 35.62342459814889, 34.132671219961985, 32.840209007263184, 33.84177098955427, 34.1327337537493, 34.12847798211234, 35.42805862426758, 36.134711265563965, 35.95641701562064, 38.65581996100289, 40.308966636657715, 39.92351879392351, 41.461290631975444, 40.03596843991961, 40.757868903023855, 41.172478335244314, 44.33647952760969, 44.41107191358294, 46.25829219818115, 47.56656503677368, 51.59625966208321, 45.588770730154856, 47.421278204236714, 51.09607969011579, 49.53099448340279, 43.57339014325823, 36.15219293321882, 40.951678480420796, 48.18318639482771, 55.05824824741909, 52.26892171587263, 45.46341480527605, 14.172585470335823, 0.30832870091710773, 11.104599697249276, 2.882518159491675, 0.3604472471135003, 47.98366887228829, 55.92611646652222, 52.076505252293174, 57.69006953920637, 52.287723541259766, 37.21373871394566, 31.157254559653147, 36.432914052690776, 51.1108307157244, 15.02730335508074, 0.17708758397826127, 0.04586887565840568, 0.05608972328315888, 0.039059915845947604, 0.03646967965843422, 0.011567696380162877, 0.09193764773330518, 0.023473354089739065, 0.011667161980377776, 0.18418272611285957, 0.10571292641439609, 0.24907576612063817, 0.07822260939116989, 0.15688220890504972, 0.25118218309112955, 0.0989688311570457, 0.11590047154043402, 0.22082714550197124, 0.21353393899542944, 0.14013926232499735, 0.1679474458630596, 9.142490080424718, 77.77091584886823, 53.294517517089844, 56.393976892743794, 27.847770248140606, 35.740647656576975, 57.75561884471348, 61.245535714285715, 56.22623348236084, 62.33342906406948, 53.16499267305647, 59.7726982661656, 3.283427481140409, 2.4330993379865373, 7.876761061804635, 9.811755333627973, 8.000605753489904, 3.3911097943782806, 47.877760955265586, 57.574566159929546, 54.7773881639753, 53.68328659875052, 52.70176669529506, 50.648521900177, 51.398649420057026, 54.596884386880056, 45.07910994121006, 38.207615988595144, 43.9600122315543, 45.831050940922324, 50.028356960841585, 49.31594773701259, 49.93931579589844, 50.488890511649, 52.87335940769741, 49.215455940791536, 52.57823119844709, 50.463831833430696, 49.391109875270296, 48.32984202248709, 48.5432003566197, 49.920910017830984, 46.8344715663365, 46.68867056710379, 42.448629651750835, 39.56316784449986, 38.765535490853445, 37.56640495572771, 40.62037794930594, 36.9716808455331, 37.75695582798549, 37.85213920048305, 38.09479113987514, 40.20499726704189, 39.33727843420846, 40.04114137377058, 39.764012472970144, 36.44303410393851, 37.75185237612043, 44.283787863595144, 44.8600367137364, 42.44830656051636, 44.96914775030953, 45.96373374121529, 43.87880516052246, 37.69464438302176, 35.8618346623012, 37.387975215911865, 40.10799694061279, 36.710157598767964, 37.24011754989624, 36.36517259052822, 36.85063280378069, 35.12066684450422, 36.39589752469744, 38.71218374797276, 39.74210827691214, 34.93510477883475, 37.59119265420096, 38.078560147966655, 37.27047075544085, 37.32479872022356, 36.87349932534354, 34.19265501839774, 37.8706248828343, 37.15815312521798, 37.039033208574565, 38.67793607711792, 39.959149156297954, 36.33246741976057, 42.950383390699116, 44.74432488850185, 46.039583751133506, 44.332418305533274, 46.470368589673726, 44.262470790318076, 42.72460167748587, 36.14874315261841, 36.44801248822893, 38.56540652683803, 38.0652300289699, 38.593810762677876, 35.23669481277466, 37.903034755161826, 37.280208655766074, 35.074885163988384, 37.5914740562439, 36.964180265154155, 39.680568081992014, 35.276765074048726, 35.34989833831787, 37.17063208988735, 37.16725526537214, 35.27914483206612, 38.47359650475638, 38.03880602972848, 38.45387404305594, 41.23402895246233, 42.00211409160069, 41.70847627094814, 43.09658738545009, 43.03581496647426, 42.50626495906285, 43.708848748888286, 46.67432253701346, 47.54174607140677, 48.025503976004465, 49.40746246065412, 54.276857307979036, 46.81761871065412, 49.95405987330845, 53.96613386699131, 51.78074475697109, 47.2196831703186, 38.58116504124233, 43.02208185195923, 49.0111927986145, 58.65740122113909, 52.180328709738596, 46.80421216147286, 17.22555705479213, 0.6090895107814244, 26.850012404578074, 5.467089746679578, 0.3448087248419012, 54.804041453770225, 59.288255964006694, 56.68338673455374, 61.03840296609061, 58.33576910836356, 38.09222725459507, 39.560711656297954, 45.57518005371094, 58.56075177873884, 19.863280841282435, 0.2971548033612115, 0.09134912038488047, 0.16774237900972366, 0.13895509658115252, 0.14258447183029993, 0.09905961235719067, 0.2127839270979166, 0.08525853577469077, 0.099921636815582], [0.03441530632387314, 0.0867561304143497, 0.02995683252811432, 0.07005582297486918, 0.06856905096875769, 0.02446487865277699, 0.01726445841736027, 0.009388643084093928, 0.07170644761728388, 0.12780992819794587, 0.011914018957343484, 0.05673496598111732, 0.18072033833180154, 33.07818133490426, 53.54469435555594, 41.70419618061611, 21.747434275490896, 22.66677474975586, 39.751391070229666, 55.39611830030169, 47.38680819102696, 52.91813012531826, 42.371692248753135, 51.888177803584504, 8.31638400895255, 0.8306327142885753, 0.25545554235577583, 4.1543344514710565, 0.24545076063701085, 0.461541690996715, 40.260940687997, 55.034071990421836, 43.149848801749094, 41.13954039982387, 48.64305639266968, 50.088615213121685, 49.165609564099995, 43.92005314145769, 39.258027281079976, 33.700191020965576, 39.869169984545024, 44.579579625810894, 46.22323506219046, 46.83429438727242, 48.443809849875315, 46.794380460466655, 45.487608432769775, 44.29446724482945, 44.94750411169869, 43.343647956848145, 43.20473262241909, 44.86983019965035, 45.84556572777884, 44.96974182128906, 42.54891995021275, 39.10258218220302, 38.94328778130667, 36.885255677359446, 35.48563487189156, 33.092842033931184, 35.014071055821006, 35.26425831658499, 33.57407774244036, 32.18932955605643, 34.95977783203125, 33.909852913447786, 35.859319414411274, 35.49197162900652, 33.75427232469831, 31.610676629202707, 34.94752468381609, 39.15577411651611, 38.16890410014561, 39.46685191563198, 40.126204695020405, 41.87769964763096, 42.47467844826834, 39.733315331595286, 37.2709640775408, 37.117916107177734, 36.20765692847115, 35.87698173522949, 31.84852041516985, 33.29245335715157, 33.04774822507586, 34.50720344270979, 33.69096033913748, 33.88748318808419, 33.43154239654541, 33.47262709481375, 35.644449847085134, 33.97420712879726, 31.324678352900914, 33.17421586172921, 35.911618505205425, 32.490151814052034, 34.396855626787456, 32.89532559258597, 35.43069893973214, 34.54758984701974, 35.901397705078125, 35.24654041017805, 37.02594975062779, 42.578911849430625, 42.21900905881609, 40.004427092415945, 40.24010304042271, 39.08743510927473, 37.294667857033865, 32.027412210192, 29.25894069671631, 32.23330470493862, 34.462043625967844, 34.02844476699829, 34.438152245112825, 32.24900068555559, 32.36462218420846, 33.74159186226981, 33.05779184613909, 32.825391973767964, 33.13045610700335, 32.591307163238525, 32.122751917157856, 31.698043278285436, 32.25175564629691, 32.84110879898071, 33.30589117322649, 34.01427044187273, 34.94653803961617, 34.90270185470581, 35.33249657494681, 36.98491021565029, 36.885693413870676, 36.3802501814706, 37.82588543210711, 35.70399243491036, 38.098814146859304, 39.651104245867046, 42.146167618887766, 45.948225361960276, 47.80829633985247, 45.7483673776899, 40.35904925210135, 50.10844537190029, 47.88164847237723, 45.58180863516671, 34.68695681435721, 37.4725695337568, 46.19921513966152, 51.48941026415144, 52.036469732012065, 40.44604417255947, 12.91342510495867, 0.08084412943571806, 2.900354619537081, 2.064868914229529, 1.3619753569364548, 43.90762281417847, 48.440551144736155, 50.144037519182476, 52.1228323663984, 42.79126616886684, 23.409577131271362, 22.67927282197135, 40.461090496608186, 39.80763326372419, 3.766699663230351, 0.20499966479837894, 0.032062883089695654, 0.11545339838734694, 0.03779220887060676, 0.06548821699938603, 0.042693263917629204, 0.06581463305545704, 0.043016894587448666, 0.030669667491955415, 0.06651640789849417, 0.08460401411035232, 0.04583579029089638, 0.021305911376007965, 0.09260480371969086, 0.024982375259112035, 0.07636330808912005, 0.01866925321519375, 0.025701239006593823, 0.04475488739886454, 0.06064064068985837, 0.03883358031245215, 0.39521318301558495, 45.85445594787598, 55.44412687846592, 45.060735430036274, 19.605290753500803, 31.30854116167341, 45.095163754054475, 59.447300229753765, 51.74897064481463, 57.34484134401594, 47.45930222102574, 57.3586300441197, 6.534032540661948, 0.46138432515519007, 1.0568304508924484, 6.580283658845084, 0.7832944201571601, 0.6676448572959218, 42.660685198647634, 56.589964730399, 45.77867889404297, 42.64944996152605, 50.94379602159773, 49.73038693836757, 52.14846774509975, 45.4963492665972, 41.931648935590474, 36.14113140106201, 42.30073724474226, 48.091838427952354, 49.3807292665754, 47.332362106868196, 50.84971393857683, 48.604844774518696, 45.75399889264788, 46.246007783072336, 46.43846593584333, 45.125245979854036, 46.373149394989014, 46.37917695726667, 47.87739964893886, 46.37434101104736, 43.3412959916251, 41.02752501623971, 41.52000291006905, 38.88374866758074, 36.71929447991507, 35.578824111393516, 36.39281252452305, 35.77142817633492, 36.41968468257359, 34.33376598358154, 35.76154783793858, 35.24003342219761, 36.56151131221226, 37.079652377537315, 36.44599403653826, 34.44047294344221, 36.80135270527431, 40.00172771726336, 41.896268708365305, 39.84398971285139, 42.84630979810442, 42.979322637830464, 45.04866293498448, 41.263402462005615, 37.12285280227661, 37.219172205243794, 37.060454504830496, 35.646509987967356, 34.51625347137451, 34.37901612690517, 35.44904913221087, 35.95534004483904, 35.332364559173584, 35.70556967599051, 34.34161744798933, 34.19274187088013, 35.027963978903635, 35.70309264319283, 33.65591015134539, 33.84330654144287, 36.34298351832798, 34.499001094273154, 34.35148388998849, 35.8141804422651, 36.47690657206944, 36.31401647840227, 37.3606653213501, 34.866741452898296, 38.626568044934956, 43.82883719035557, 42.936685017177034, 42.35573918478829, 42.48104647227696, 41.978674343654085, 38.72918946402413, 33.80605724879673, 31.758523872920446, 34.40080220358712, 34.661759172167095, 34.43983718327114, 34.868843282972065, 34.59628629684448, 34.97277443749564, 36.19263144901821, 35.29565027781895, 35.7636079788208, 34.24752146857125, 34.57069608143398, 33.78206859316145, 34.60758406775338, 33.11318635940552, 35.23342568533761, 35.18044567108154, 36.807442801339285, 35.90167563302176, 36.6180488041469, 39.163132258823936, 38.11725466591971, 38.83702550615583, 38.96684217453003, 39.64387811933245, 39.001593589782715, 39.35420772007534, 41.15721314293997, 44.59338222231184, 47.159056663513184, 49.87431539808001, 47.77066489628383, 42.55507605416434, 52.37052869796753, 49.84866264888218, 47.69367190769741, 36.8558474268232, 39.576362473624094, 48.35017939976284, 54.54648910249983, 52.2667886189052, 43.28702361243111, 16.4585280418396, 0.05013157853058406, 5.268975760255541, 1.6718165938343321, 1.3325205317565372, 48.94146415165493, 51.26548719406128, 55.3589871270316, 55.70176260811942, 48.288993562970845, 29.313581330435618, 24.158129147120885, 45.717816148485454, 45.256705897195, 5.7377142650740485, 0.39787019044160843, 0.03860055781634791, 0.04011184190000806, 0.052094895858317614, 0.030225345798368965, 0.04472515060167227, 0.05105159737701927, 0.06753758274550949, 0.010889673655453538, 0.11782760598829814, 0.12134859205356666, 0.16363937274685927, 0.17395682340221746, 0.11458005596484457, 0.12064396057810102, 0.16160425623612745, 0.10558170452713966, 0.19600925222039223, 0.27438843356711523, 0.1674726749105113, 0.21328282675572804, 0.295907303158726, 48.778653962271555, 68.59998158046177, 53.25383928843907, 28.710540226527623, 31.768185343061173, 51.47911998203823, 65.86649772099086, 57.67109400885445, 60.37854644230434, 54.06680284227644, 61.305185999189106, 10.869266816547938, 1.9224380084446497, 4.561805912426539, 11.519370675086975, 1.351673892566136, 1.03983331152371, 45.640718936920166, 56.54132734026228, 48.172979491097585, 43.16146271569388, 52.019071442740305, 53.630195413317, 54.58482926232474, 46.85304062707083, 44.46514974321638, 37.97954831804548, 44.94162246159145, 50.27549048832485, 52.0983886037554, 48.06570277895246, 53.1389925139291, 51.06189455304827, 48.83447926385062, 48.43133435930525, 48.886837414332796, 46.67668839863369, 48.08014113562447, 49.517765113285606, 51.239414078848704, 49.552572114127024, 46.759479658944265, 43.681302615574424, 44.91585854121617, 42.01864733014788, 40.78281988416399, 37.725133078438894, 38.070361273629324, 37.11437252589634, 38.03332737513951, 34.385338987622944, 38.40409367425101, 36.81965773446219, 39.01332562310355, 38.74262033190046, 37.75563219615391, 36.52925777435303, 38.55546712875366, 43.432049887520925, 42.49840654645647, 42.10313742501395, 42.9492404120309, 45.01200423921858, 45.30621181215559, 43.86766372408186, 38.808583055223735, 39.730442251477925, 40.2627854347229, 37.766989026750835, 35.51745414733887, 36.278285367148264, 37.055694988795686, 37.8021434375218, 35.660802432468955, 37.217223235539024, 37.09161370141165, 37.08687850407192, 38.45333555766514, 38.20677178246634, 36.40413808822632, 35.5609325000218, 40.25949893678938, 36.137685094560894, 37.587246077401296, 36.44432299477713, 38.32956382206508, 36.96336037772042, 38.826085567474365, 36.47974143709455, 38.95378303527832, 46.284688404628206, 45.82338012967791, 44.13824047361101, 44.22291816983904, 45.64581196648734, 40.553539752960205, 35.99588973181588, 33.6877954346793, 35.751153332846506, 37.11161756515503, 37.75436067581177, 36.68742309297834, 34.16213853018624, 36.374816690172466, 38.297417981284006, 36.771426813943044, 37.81181532996041, 36.794324602399556, 36.95823608125959, 37.00177696772984, 36.64115851266043, 35.66044807434082, 38.26603991644723, 36.978569984436035, 38.42659541538784, 39.248695850372314, 37.52681064605713, 40.99685566765921, 39.692418234688894, 40.178246702466694, 40.8447630746024, 42.37232106072562, 40.637626852308, 42.493171078818186, 43.71907997131348, 46.795460905347554, 48.94034549168178, 51.91925014768328, 49.52985150473458, 45.950889996119905, 54.39141225814819, 52.899905000414165, 48.920960017613, 37.87760782241821, 42.10293592725481, 51.51712315423148, 58.313472339085166, 53.9319417817252, 46.61179917199271, 19.69564860207694, 0.14971356785723142, 9.333658473832266, 5.383059535707746, 1.854922579867499, 55.08063186917986, 56.435902323041645, 59.33441284724644, 60.335502352033345, 53.96997969491141, 32.712268352508545, 32.638360364096506, 53.41556208474295, 54.8189696584429, 8.770450523921422, 0.6570108022008623, 0.1493862425642354, 0.22156060114502907, 0.09546592126467399, 0.09933263449264423, 0.1443207479481186, 0.08475795335003308, 0.14411403904003756, 0.18008869008294173], [0.024733556467773657, 0.06576309153544051, 0.028684443661144803, 0.04210604953446558, 0.07592582263584648, 0.03115148503067238, 0.023453596846333573, 0.06280911647315536, 0.022418674879840443, 0.07483615646404879, 0.021312343887984753, 0.07138792970882994, 0.20486364566854068, 9.777340906006948, 49.69007696424212, 44.98591375350952, 39.37824501310076, 24.798841646739415, 41.155132157461985, 57.79875326156616, 45.36338159016201, 52.66821037020002, 43.18072312218802, 47.69108370372227, 21.084647348948888, 0.39187356936080114, 0.27621103291000637, 6.109675654343196, 0.8339891284704208, 1.2222910523414612, 37.42356388909476, 48.60824244362967, 46.57621397290911, 35.060419014522004, 51.52535676956177, 49.2556026322501, 49.71726526532854, 44.81694746017456, 41.32171174458095, 42.527050495147705, 45.67352138246809, 46.128899369921, 48.342348779950825, 46.99719490323748, 46.15513924189976, 43.27110528945923, 45.06842361177717, 42.06919894899641, 42.41797767366682, 40.45414924621582, 41.194552762167795, 39.747128350394114, 41.891953877040315, 41.49666738510132, 41.53565372739519, 38.68685061591012, 39.98453439985003, 35.53893102918352, 35.18168592453003, 34.795532839638845, 34.63435895102364, 34.848227977752686, 35.99199874060494, 33.51100894383022, 35.29033143179757, 35.09125859396798, 34.858921255384175, 36.65770564760481, 34.7338502066476, 31.21183613368443, 37.114400318690706, 39.524980545043945, 38.6524327141898, 39.16204833984375, 39.69554839815412, 40.972137451171875, 41.75407035010201, 39.09050273895264, 37.542336395808626, 37.02402857371739, 34.58741692134312, 32.926974637167795, 33.38049398149763, 32.50133841378348, 33.94399288722447, 33.017999512808665, 33.023033482687815, 33.62087038585118, 35.124099254608154, 32.22504677091326, 33.05338321413313, 33.14905296053205, 33.4738187108721, 30.97710861478533, 32.44266782488142, 34.185362883976524, 33.52401944569179, 34.8894168989999, 33.59129190444946, 33.857689312526155, 35.975642681121826, 34.427330425807405, 36.829371316092356, 41.252212388174875, 40.403757435934885, 39.310333320072715, 39.50552558898926, 35.76947920663016, 35.72987447466169, 30.658221040453228, 30.890784195491246, 32.33346993582589, 33.218159743717735, 33.301253250667024, 32.71462379183088, 32.82801839283535, 32.56135695321219, 33.793282985687256, 33.468138558524, 33.02093512671334, 33.436958517347065, 32.548329080854145, 32.2442307472229, 32.109654562813894, 33.07682296207973, 32.876405647822786, 34.64297819137573, 33.81481892721993, 34.05458736419678, 34.03297846657889, 35.41519056047712, 34.72497388294765, 35.2179867880685, 34.03213426045009, 35.44190638405936, 34.75115122113909, 34.01046282904488, 36.26424305779593, 40.31760672160557, 46.92280401502337, 45.651763098580496, 50.09893676212856, 43.273221015930176, 47.568222182137625, 50.138583183288574, 47.44895287922451, 39.18525879723685, 36.031620843069895, 45.74138791220528, 50.31760004588536, 50.28008672169277, 28.987945318222046, 3.376317079578127, 1.0828030343566621, 4.3292609964098245, 2.005078796829496, 4.274078837462834, 47.56506422587803, 48.86488805498396, 45.638057776859824, 44.04960230418614, 37.132159914289204, 26.073855195726665, 26.73461151123047, 34.48409373419625, 31.27697549547468, 0.15568760729261807, 0.021717376707653915, 0.007347960889871631, 0.021974651741662195, 0.05635202795799289, 0.07759711545492921, 0.04409642683874283, 0.03516807985891189, 0.04201294095920665, 0.038986152304070334, 0.03879078510882599, 0.047750772176576514, 0.05040493654087186, 0.037961089451398165, 0.04005079749705536, 0.024023491623146192, 0.05337655690631696, 0.04979452304542065, 0.05550569462190781, 0.09781478558267866, 0.06204188335686922, 0.1462690391178642, 0.14135283577655042, 15.303982360022408, 56.630299023219514, 49.65317855562483, 28.913608278547013, 28.74588050161089, 49.92068420137678, 60.75958565303257, 52.041357789720806, 57.236463342394146, 48.266224316188264, 53.905903407505576, 21.874412604740687, 0.34716907675777164, 0.4998785938535418, 4.345544968332563, 2.005879576717104, 0.9483458378485271, 40.75234508514404, 47.928017275674, 49.323194708142964, 37.56582130704607, 52.32332958493914, 50.541686398642405, 51.40519462312971, 45.794805662972585, 43.50126436778477, 43.1307829448155, 49.29335914339338, 47.55831752504621, 50.70517751148769, 48.96450090408325, 50.14499984468733, 45.20765508924212, 48.05366849899292, 43.7713999067034, 44.478007384708945, 43.16348116738455, 43.93353264672415, 42.275411060878206, 44.21406269073486, 42.912751947130474, 43.45907490594046, 40.98727410180228, 42.23623364312308, 38.039757932935444, 37.014610290527344, 37.11617905752999, 36.782557828085764, 37.307171140398296, 37.8489534514291, 34.481345721653526, 37.744487285614014, 36.131195477076936, 37.08417565482003, 36.441265787397114, 36.43668692452567, 33.23339714322771, 39.23107174464634, 41.91816248212542, 41.47741392680577, 39.35782773154122, 41.60814775739397, 42.71165023531233, 43.27030277252197, 39.90639843259539, 39.116905893598286, 38.21165984017508, 35.49384764262608, 34.319035802568706, 34.750908034188406, 33.12429305485317, 35.662963322230745, 36.07794795717512, 34.46886328288487, 35.74144669941494, 36.213861669812886, 35.04599455424717, 34.78135504041399, 34.441334520067485, 34.99107599258423, 33.13578537532261, 33.85886008398873, 37.05766132899693, 35.60845817838396, 36.040358202798025, 36.44970090048653, 36.07721144812447, 37.61294398988996, 36.73675877707345, 37.34435095105852, 42.73262684685843, 41.81253249304635, 41.083940914699006, 40.85996920721871, 38.95042705535889, 37.72297913687569, 33.96501118796212, 31.714951719556534, 35.39608301435198, 36.31686871392386, 35.791386876787456, 34.964155197143555, 34.41574430465698, 33.50463397162301, 34.68010241644723, 34.76585013525826, 34.0240604536874, 35.09513568878174, 34.01103605542864, 33.7894857951573, 35.26614475250244, 34.81068686076573, 35.16039316994803, 36.751266615731375, 34.764609881809776, 35.56499024799892, 36.18774339130947, 36.83444350106375, 36.47541618347168, 36.95694024222237, 36.982672895704, 36.84225675037929, 35.922089440482004, 35.86210911614554, 37.385154247283936, 43.29489592143467, 48.650796685900005, 47.041284697396414, 52.14118255887713, 43.74778297969273, 47.417901379721506, 52.09307670593262, 49.80781071526663, 42.14079666137695, 38.716251918247764, 47.72162103652954, 52.62592363357544, 50.53652736118862, 33.191978931427, 4.437262058258057, 1.4925750004393714, 6.876271707671029, 1.2314663657120295, 4.054303407669067, 53.29256854738508, 52.09627635138375, 53.493326323372976, 49.890365736825125, 45.955788476126536, 29.79093647003174, 23.896904672895158, 42.8619293485369, 38.18793174198696, 0.7202328954424176, 0.06139551089810474, 0.023232826996328573, 0.08147321282220737, 0.013038728070179266, 0.06864767960671868, 0.01198185040682022, 0.037010709555553536, 0.05649884257997785, 0.04208442462342126, 0.08322426064738206, 0.14518840424716473, 0.12202457578054496, 0.16135718806513719, 0.1827552512820278, 0.09600988243307386, 0.10003645851143769, 0.21167598797806672, 0.12884235994092055, 0.19435810510601315, 0.13699373682694777, 0.21460797850574764, 0.26539675891399384, 15.823957749775477, 66.93329633985246, 54.63555458613804, 51.02277272088187, 33.56611510685512, 54.05625547681536, 64.89719622475761, 54.74914026260376, 63.03229277474539, 53.51561267035348, 57.39294719696045, 26.82538798877171, 0.6213637750063623, 2.7237110010215213, 17.14268241609846, 3.4546434709003995, 2.2306646576949527, 42.39217553819929, 48.85583455221993, 47.9381616456168, 37.90091208049229, 54.219145570482524, 53.664477825164795, 55.246530532836914, 48.287774154118125, 45.391059739249094, 45.00290904726301, 50.52428463527134, 51.42164100919451, 52.84609120232718, 49.03638349260603, 50.76609584263393, 48.5106897354126, 50.16460418701172, 46.22383260726929, 45.909318923950195, 44.2052766936166, 47.64332178660801, 45.45643881389073, 46.796308585575645, 44.59503241947719, 46.292029176439556, 43.231622150966096, 44.74400874546596, 38.88289056505476, 38.51019614083426, 39.12644577026367, 40.56312826701573, 39.04670476913452, 40.07375969205584, 35.83361802782331, 40.14538172313145, 38.60866253716605, 38.52748325892857, 39.62020213263375, 38.26918397630964, 35.26537002835955, 41.99503040313721, 43.51316315787179, 42.97523014886038, 40.900157587868826, 42.56576238359724, 44.111813000270296, 44.902094159807476, 40.6308627809797, 41.39257642201015, 40.56315605981009, 38.29237706320626, 36.1114695412772, 36.29768821171352, 35.28867776053292, 37.19429765428816, 37.48379782267979, 35.74767575945173, 38.30660349982125, 38.287666184561594, 36.639122690473286, 37.53460652487618, 36.005071776253835, 37.338399818965364, 33.617274693080354, 35.40644972664969, 38.8278990473066, 37.385883808135986, 38.14767387935093, 37.32818944113595, 37.45779766355242, 39.045318603515625, 38.16227899278913, 38.54315144675118, 45.40801681791033, 44.10562562942505, 43.879562514168875, 42.850110462733674, 39.49994618552071, 39.72433131081717, 35.189221245901926, 34.47888953345162, 37.124322346278596, 37.24451923370361, 38.27379410607474, 37.31924016135079, 37.60652385439192, 35.76518521990095, 37.63868359157017, 37.0758239201137, 35.73449502672468, 37.606694085257395, 36.34351852961949, 36.47538491657802, 36.97223670142037, 36.569157804761616, 37.70982272284371, 38.3216289792742, 36.62086977277483, 38.76330859320504, 38.46356330599104, 39.78931433813912, 37.518927914755686, 39.19609451293945, 37.577914646693635, 39.73924214499337, 38.01766960961478, 37.617265769413535, 39.04254974637713, 45.666281359536306, 51.52653448922293, 49.08225549970354, 54.49771622249058, 45.48862981796265, 50.263112272535054, 53.41640976497105, 52.51949807575771, 44.59443140029907, 41.833265917641775, 49.41494219643729, 55.38754769733974, 52.850538049425396, 36.60928017752511, 6.332308965069907, 2.114900069577353, 12.937451107161385, 4.978920604501452, 5.15096321276256, 59.39765535082136, 56.118241105760845, 55.91387721470424, 55.23704971585955, 47.98900856290545, 35.30582244055611, 35.67409781047276, 47.215938091278076, 46.6369412285941, 1.7954769411257334, 0.1955950337329081, 0.11759671409215246, 0.11966689729264804, 0.15497568835105213, 0.13085883030933992, 0.060934514206434996, 0.15452039135353907, 0.1592610441148281, 0.1083588737196156], [0.08024723575051342, 0.07703258110476391, 0.0996851334348321, 0.07372344724301781, 0.021519288586984788, 0.042167884430715015, 0.08097745478153229, 0.045087091358644624, 0.03803312951432807, 0.027561929609094347, 0.06471452422972236, 0.04123985208570957, 0.005661730546437736, 1.0084731600114276, 41.59831953048706, 46.29751477922712, 36.47328308650425, 26.76035806110927, 27.85832977294922, 48.53840957369123, 50.19447449275425, 50.139972823006765, 48.880174091884065, 42.50234964915684, 32.14007377624512, 0.07524337247014046, 1.0063324634517943, 2.45437776190894, 0.8812261851770538, 0.3692355512508324, 32.91026421955654, 53.635587215423584, 48.44033922467913, 49.756199496132986, 43.47476393835885, 49.93856886454991, 47.59995807920183, 49.557144028799875, 46.248981612069265, 44.04723991666521, 47.23964881896973, 47.27599137169974, 47.42538806370327, 47.34662675857544, 45.34539270401001, 43.225712708064485, 39.81925065176827, 40.38889871324812, 38.923172746385845, 39.66923557009016, 39.407583781651084, 39.92688519614083, 40.831898484911235, 39.809505803244456, 39.27429648808071, 41.45286594118391, 39.252239431653706, 37.86635521480015, 33.74944680077689, 35.79758814402989, 35.17172915594918, 33.96638345718384, 35.073255811418804, 35.49354887008667, 32.61996153422764, 32.760537488119944, 34.486525603703086, 35.49416378566197, 33.54687554495675, 32.68631335667202, 36.69211312702724, 39.50500099999564, 36.306359563555034, 38.28700957979475, 38.471432140895296, 40.41003860746111, 40.09357248033796, 37.319921084812705, 36.051840100969585, 35.795726026807515, 34.66025141307286, 33.60066155024937, 34.32001897266933, 33.490765367235454, 31.37673078264509, 34.43872894559588, 32.893967219761436, 33.82779816218785, 33.18447140284947, 33.573706013815745, 30.98905256816319, 32.82339436667306, 32.72355917521885, 32.154091766902376, 33.42956910814558, 33.129598004477366, 32.777046407972065, 32.82832063947405, 30.585567201886857, 32.88010903767177, 34.96515573774065, 35.83626529148647, 36.262318406786235, 40.80578368050711, 40.1124507359096, 38.012472357068745, 38.70849772862026, 37.040499278477256, 37.01047958646502, 32.38206563677107, 29.802619865962438, 32.259627955300466, 33.90854665211269, 32.823231084006174, 32.335002013615195, 33.66817372185843, 33.44387892314366, 33.67667831693377, 32.71683331898281, 33.38169949395316, 32.32100139345442, 31.628293786730083, 31.531359468187603, 32.2760465485709, 32.46344641276768, 32.82507930483137, 32.95276287623814, 32.99318402154105, 32.46660436902727, 34.44052505493164, 32.955597741263254, 33.40813391549246, 32.48216485977173, 32.42364018304007, 33.684557574135916, 33.50013501303536, 33.84677021844046, 35.16393675122942, 37.83364656993321, 43.37065213067191, 44.65564850398472, 48.006792477199006, 47.42606898716518, 44.32109274183001, 48.82666254043579, 47.564379828316824, 43.573456151144846, 36.48513323920113, 45.57225833620344, 49.45573507036482, 49.0230255808149, 18.885464327675955, 0.4098684809037617, 6.106021770409175, 5.658835274832589, 1.6624897228819984, 4.36720597743988, 44.662871156420024, 48.53061716897147, 45.602413518088206, 43.23311948776245, 31.446407318115234, 24.161365270614624, 30.79687581743513, 40.37970277241298, 18.702415772846766, 0.0706905856994646, 0.04642033124608653, 0.03389414393209985, 0.0761776337666171, 0.03943584120965429, 0.1278363639222724, 0.04059878237811582, 0.04123496324090021, 0.021891047745676975, 0.017878103435837796, 0.04322621585535152, 0.054886120903704844, 0.08322535987411227, 0.10012426094285079, 0.04993126481505377, 0.010278417080241655, 0.07330038065889052, 0.02389973701377, 0.013285109224463148, 0.06665643717029265, 0.03178100607224873, 0.01989919293139662, 0.10228150018623897, 2.2320343213421956, 47.82314116614205, 50.57126488004412, 37.353494780404226, 29.919961043766566, 39.64884955542428, 53.123150621141704, 56.50884451184954, 53.526458808353965, 53.01892416817801, 47.76396335874285, 34.76104893003191, 0.07232471515557595, 0.36530574783682823, 4.4549009289060315, 1.7740613988467624, 0.24039163067936897, 36.02430786405291, 52.42500952311924, 48.70566661017281, 49.84172487258911, 43.637431689671104, 51.24136304855347, 49.41057525362287, 51.12037754058838, 48.38483006613595, 46.71712344033377, 49.99279260635376, 48.53634943280901, 48.62711375100272, 49.24448551450457, 48.95521811076573, 45.57984924316406, 42.753478390829905, 42.04774291174752, 41.79830258233206, 42.69307770047869, 42.406808444431846, 42.13783325467791, 43.007775511060444, 41.70901475633894, 42.86216558728899, 41.71649101802281, 42.28294290815081, 39.40058694566999, 36.57101992198399, 36.20309543609619, 37.6655661719186, 35.543648856026785, 36.99068764277867, 36.84799943651472, 34.359158175332205, 35.19264670780727, 36.74577406474522, 37.45355231421334, 34.99653032847813, 33.18487092426845, 37.729583399636404, 41.295944350106375, 38.79596512658255, 40.275625705718994, 41.40648324148995, 41.60465976170131, 41.38181366239275, 38.25149733679635, 36.72084740230015, 36.51754658562796, 34.38979625701904, 34.12687989643642, 35.484950474330354, 35.08669362749372, 33.92272792543684, 35.51996939522879, 34.88807937077114, 36.3315988949367, 35.14792810167585, 36.40036869049072, 33.115371567862375, 35.691954680851524, 33.18886613845825, 33.643577098846436, 34.68127318790981, 33.87647376741682, 32.86625780378069, 34.04032618658883, 31.921841280800955, 35.434444018772666, 35.87287187576294, 36.245135511670796, 37.82868208203997, 41.712071963718955, 42.542392117636545, 40.588756697518484, 39.97907311575753, 39.39368738446917, 40.67970861707415, 35.34934595652989, 32.79085942677089, 36.05071101869856, 37.12625741958618, 34.15077475139073, 34.644711766924175, 34.632972785404746, 35.19476590837751, 34.59463609967913, 34.569407190595356, 35.51464360100882, 34.57047026497977, 35.61046620777675, 33.6811876978193, 33.88149731499808, 34.30878026144845, 35.025681495666504, 34.60366528374808, 35.48595101492745, 34.56589835030692, 35.34971073695591, 35.28940037318638, 34.732616901397705, 33.56114714486258, 34.765235219682964, 35.35969182423183, 35.18378775460379, 35.49124901635306, 37.125694615500315, 40.577035086495535, 45.19973414284842, 46.845925671713694, 49.199669633592876, 49.04860189982823, 44.58968230656215, 49.67307472229004, 49.14355250767299, 46.03440734318325, 39.0447974886213, 47.505691868918284, 52.440041950770784, 50.47217314583914, 22.75554493495396, 0.8615897617169789, 10.414404732840401, 5.017952978610992, 1.1728634131806237, 5.298226807798658, 49.573229108537944, 52.86141545431954, 48.85920442853655, 44.29708671569824, 42.25583798544747, 27.359119074685232, 31.218082564217703, 45.886344705309185, 23.982023579733713, 0.04567689774557948, 0.011453129134939184, 0.08401146304926702, 0.05516811327210494, 0.016015351783218126, 0.03174159675836563, 0.03743982867204717, 0.04351963475346565, 0.03287476381020887, 0.01908542588353157, 0.13583303482404777, 0.22556773040975842, 0.21516188021217073, 0.23190893871443613, 0.13551474761750015, 0.13896952223564896, 0.22569619065948895, 0.15776221454143524, 0.1492056708250727, 0.197686658639993, 0.22556861250528268, 0.10181195395333426, 0.17131364451987402, 2.244639439242227, 56.62950692858015, 58.42292036328997, 48.065807001931326, 37.54652268545968, 38.36216824395316, 58.879750524248394, 59.48662008558001, 59.92330741882324, 57.05101244790213, 54.068456513541086, 39.82004969460623, 0.4429993102593081, 2.8469716097627367, 11.251326543944222, 3.826027725424085, 0.7106016608221191, 40.31025900159563, 51.275534289223806, 49.11225782121931, 47.00941331045968, 44.33503777640206, 52.57808528627668, 52.306560107639854, 53.38684170586722, 52.41170024871826, 48.81199141911098, 52.26590272358486, 51.652415003095356, 49.480703422001426, 49.53954076766968, 50.757650307246614, 46.74290473120553, 43.39964001519339, 45.7030998638698, 44.71232148579189, 45.02322905404227, 44.79103067943028, 43.02186645780291, 46.83152553013393, 43.57475546428135, 45.82458911623274, 44.64761986051287, 44.84890569959368, 42.02146829877581, 38.88998120171683, 40.53998381750924, 39.686783245631624, 37.376253604888916, 38.94072389602661, 40.01743064607893, 36.32983405249459, 36.19642863954817, 37.75692456109183, 39.5040352003915, 37.317048004695344, 36.13708060128348, 40.13051952634539, 43.660030705588206, 39.66664736611502, 42.257043497903005, 42.63044663837978, 43.38435050419399, 43.55356693267822, 40.28825405665806, 38.75932032721383, 38.75607551847185, 37.08406448364258, 36.86609254564558, 38.81651789801461, 37.4353723526001, 36.04397126606533, 38.508598055158345, 37.60986941201346, 38.9810060773577, 38.70852552141462, 37.262664454323904, 34.36531775338309, 36.876198700496126, 34.35068832124983, 36.805608476911274, 37.30599342073713, 36.4127573285784, 36.761918204171316, 37.07176617213658, 34.866835253579275, 37.371382917676655, 38.02488531385149, 37.58365733282906, 40.700431619371685, 45.5038081577846, 44.93445539474487, 41.74058042253767, 41.513197149549214, 41.758697850363596, 43.730131081172395, 38.71502556119646, 35.393359320504324, 38.048342432294575, 39.10283579145159, 35.59087923594883, 36.42181083134243, 37.61716502053397, 37.352671418871196, 36.236533641815186, 36.34345946993147, 37.178987298692974, 35.392692293439595, 36.78530584062849, 35.43894992555891, 35.306305340358186, 36.60210616247994, 36.976495947156636, 37.101591314588276, 36.97720813751221, 37.11154113497053, 37.65838173457554, 37.5560417175293, 36.20503050940377, 34.995950153895784, 36.17609126227242, 38.248433181217735, 36.51621947969709, 37.880147389003206, 39.097419670649934, 42.69888292040144, 47.46272073473249, 48.80485561915806, 51.067696298871724, 50.49919121606009, 43.87468487875802, 51.65938752038138, 51.43605504717146, 47.948945249829976, 41.09927906308855, 49.596578529902864, 56.1843011038644, 52.963043281010215, 27.42276109967913, 2.064436823129654, 12.590735128947667, 13.926290937832423, 3.4335189930030277, 6.595019051006862, 53.4063835144043, 55.9359655380249, 52.867154666355674, 52.614584173474995, 41.18553747449602, 32.588277748652864, 40.06835051945278, 53.36532660893032, 28.613355772835867, 0.1649308284478528, 0.11995750027043478, 0.20333315565117768, 0.2313358751790864, 0.12798598089388438, 0.1469461220715727, 0.1968355043126004, 0.17419669910201005, 0.11119568614023072, 0.09669791015663318], [0.06888761637466294, 0.01856206843097295, 0.02114775843386139, 0.09177365938999824, 0.02997597400099039, 0.043312298200492344, 0.05110892001539469, 0.1740523747035435, 0.0022911803597318275, 0.05270522453689149, 0.05016394465097359, 0.11336891166865826, 0.08536296231406075, 0.11588331817516259, 23.46487784385681, 51.57273653575352, 33.73364659718105, 24.977016040257045, 31.087258407047816, 46.56910596575056, 48.86993244716099, 46.8898070199149, 50.26901824133736, 44.209581102643696, 47.82503802435738, 3.2917679250240326, 1.0219801323754447, 0.9187132907765252, 9.484316263880048, 0.479901057268892, 27.928588220051356, 48.82792363848005, 47.361440317971365, 50.69453634534563, 47.08047948564802, 46.15569509778704, 48.229173047201975, 47.859785965510774, 49.27099984032767, 48.99281133924212, 50.47546311787197, 45.66643074580601, 47.68374988010952, 47.74836465290615, 45.12871660505022, 43.88969646181379, 39.16765553610665, 38.474187101636616, 35.22861058371407, 37.53885187421526, 38.99339124134609, 37.85989339011056, 41.63736145836966, 40.02721718379429, 39.78944982801165, 39.15287324360439, 38.184933594294954, 36.032958371298655, 33.421898296901155, 34.46816151482718, 33.832599367414204, 34.55062273570469, 34.35151515688215, 34.2559426852635, 35.027592250279014, 34.14321511132376, 34.36658232552664, 35.37321996688843, 33.15149872643607, 33.417739800044465, 38.54928323200771, 38.2700629234314, 38.12921946389334, 39.02921267918178, 40.44634641919817, 41.78867585318429, 38.81182091576712, 37.98804249082293, 34.32984719957624, 35.32133429391043, 33.07951538903372, 34.36234392438616, 32.62272344316755, 32.40502595901489, 32.9799233845302, 34.24293565750122, 33.37271547317505, 35.0340575490679, 33.28401824406215, 33.92450666427612, 33.17913171223232, 34.08888714654105, 34.38927861622402, 31.883779048919678, 32.25220727920532, 33.0836843081883, 33.26605020250593, 33.28664813722883, 32.869992460523335, 31.180788108280726, 31.7051408631461, 33.97653130122593, 34.449634143284385, 37.08992181505476, 38.72029576982771, 37.929910387311665, 36.73570612498692, 36.54264347893851, 35.37671838487898, 35.09331178665161, 30.64731236866542, 33.934789998190745, 33.97862270900181, 32.92948293685913, 32.45559842245919, 32.78226797921317, 31.9935918535505, 33.56545155388968, 34.09910099846976, 34.414372035435264, 32.251283168792725, 32.907405035836355, 31.227493899209158, 34.6603730065482, 32.21668808800833, 32.78947673525129, 33.69800928660801, 32.85500519616263, 33.65680646896362, 33.78182888031006, 33.26082168306623, 32.172049386160715, 33.50959498541695, 33.56514583315168, 33.42266607284546, 33.40098769324166, 33.82483128138951, 33.0879921913147, 35.37743752343314, 39.507325172424316, 43.98395572389875, 46.79633985246931, 49.273303168160574, 46.32810769762312, 49.42068140847342, 46.93093340737479, 45.54979133605957, 41.74629878997803, 43.89104093824114, 49.397644656045095, 47.15714590890067, 14.233040877750941, 1.297860528741564, 6.605889941964831, 4.4270356127194, 0.363109357122864, 7.966016752379281, 46.532888480595176, 45.285276889801025, 51.820898396628245, 44.278378690992085, 23.883456434522355, 21.953926052365983, 25.374836887632096, 40.16796336855207, 6.227965261254992, 0.266920124313661, 0.05309278677616801, 0.06503582413175277, 0.020833717160192982, 0.06698351819068193, 0.028128633574981774, 0.03842009464278817, 0.05600494372525385, 0.05268279216917498, 0.03846384658079062, 0.05116446828469634, 0.04991145498518433, 0.03391251187505467, 0.03143049863034061, 0.03681998693251184, 0.042319828777440956, 0.07541927588837487, 0.04487757670826145, 0.028715140585388457, 0.04542945298765387, 0.030421228680227484, 0.061113579597856314, 0.09440611741904702, 0.09250584617257118, 30.81039353779384, 56.24266597202846, 37.308105673108784, 25.886726311274938, 38.52572536468506, 53.81128283909389, 55.617904799325125, 51.383537088121685, 53.865478788103374, 47.67146546500069, 50.181776659829275, 3.2946147322654724, 1.3998933051313673, 3.4037952508245195, 9.272786174501691, 0.7511189409664699, 31.278052466256277, 50.38647753851754, 45.59383944102696, 50.48478760038103, 47.453031471797395, 47.91583013534546, 50.617918559483115, 50.916225569588796, 51.980964047568186, 50.103512150900706, 52.63389321735927, 47.23123802457537, 47.91967943736485, 49.08105346134731, 46.97716672079903, 46.042592321123394, 40.978071212768555, 39.79168367385864, 38.32961940765381, 40.59925195149013, 40.716072014399934, 39.16807590212141, 43.95520060403006, 41.74775096348354, 42.354603154318674, 41.53829056876046, 40.53235469545637, 39.07030432564871, 35.00427409580776, 35.58974667957851, 36.036748613630024, 36.589606353214805, 37.203135762895855, 34.843176637377056, 35.53249699728829, 36.32374048233032, 35.15166623251778, 36.93976082120623, 34.62113305500576, 34.50949287414551, 39.333786964416504, 41.60199165344238, 39.155329431806294, 41.38412046432495, 41.516205719539094, 42.82183824266706, 41.28591809953962, 39.011883871895925, 35.61998176574707, 35.961829662323, 34.73953035899571, 35.9466096333095, 34.73198808942522, 36.356320585523335, 36.540968963078086, 35.574922697884695, 35.053293636866975, 35.5895208631243, 33.99550335747855, 34.77026571546282, 34.421139580862864, 35.44737114225115, 34.510733127593994, 35.26391090665545, 34.36534207207816, 34.15521812438965, 35.89394576208932, 34.557383332933696, 34.79366724831717, 33.65197399684361, 34.59362513678414, 35.22048119136265, 36.11960588182722, 39.536264419555664, 40.14700412750244, 40.264967169080464, 39.369966234479634, 38.42696019581386, 38.252741064344136, 35.743597166878835, 32.92989635467529, 36.02550990240914, 36.212951455797466, 34.57592460087368, 34.677187647138325, 35.19206305912563, 34.1049930708749, 34.61522708620344, 34.750470297677175, 36.29627077920096, 34.61093657357352, 34.44139705385481, 34.33940444673811, 34.037803990500315, 33.796489579336985, 34.14729717799595, 35.39343227658953, 35.21194532939366, 34.42239025660923, 36.191804613385884, 34.26680619376046, 34.26938050133841, 34.6527612549918, 34.38712467466082, 34.40847996303013, 35.68325901031494, 35.5623916217259, 35.27554913929531, 36.79898336955479, 41.33286707741873, 47.691747256687705, 48.13371869495937, 50.32735184260777, 46.93835408346993, 50.11097799028669, 48.63677522114345, 48.05302579062325, 43.765083994184224, 46.55204813820975, 51.55529655729021, 48.3511278288705, 17.38911591257368, 1.7532642462423869, 8.336408717291695, 0.4131087841732161, 0.3148971370288304, 8.07851677281516, 49.72126047951834, 50.22719703401838, 57.328287260872976, 47.70131145204817, 33.197502749306814, 22.367041621889385, 28.733474493026733, 47.41303069250924, 9.229532769748143, 0.21368944565100328, 0.07218287419527769, 0.05283284679587398, 0.06032107783747571, 0.06294658766793353, 0.029054961100752865, 0.06744414168809142, 0.05369588566411819, 0.038676428209458075, 0.026821306939902048, 0.1412084570952824, 0.11717467888125352, 0.08912322018295527, 0.15092182159423828, 0.14937553528164113, 0.16508663365883486, 0.1207359970680305, 0.14807931626481668, 0.08034731288041387, 0.14821720815130643, 0.1795781331935099, 0.23838362842798233, 0.20649221113749913, 0.249030168567385, 32.77380159923008, 65.58871568952287, 45.22648818152291, 35.23728540965489, 41.79255294799805, 57.028712204524446, 57.93482330867222, 56.19316700526646, 59.424482345581055, 51.73074204581124, 56.15791531971523, 4.551301538944244, 3.5089903260980333, 6.717907496861049, 15.293026787894112, 1.173442067844527, 34.98122692108154, 50.307688440595356, 47.249285970415386, 50.60260820388794, 47.772252559661865, 46.685123511723106, 51.955898421151296, 52.71622242246355, 55.613822732652935, 53.29672704424177, 54.78775487627302, 47.74608564376831, 48.61938040597098, 51.9482866695949, 48.37014157431466, 49.220302309308735, 44.06649684906006, 42.693202768053325, 39.44358587265015, 42.40034661974226, 43.77030903952462, 42.81212813513619, 47.48259605680193, 43.89632504326956, 45.52433313642229, 43.28616550990513, 42.49036748068673, 40.88501051494053, 36.92774738584246, 39.098948274339946, 37.890385559626985, 39.3877466746739, 38.25733034951346, 36.407000746045796, 37.46849094118391, 37.95448963982718, 36.471552985055105, 38.06651544570923, 36.93946552276611, 36.7385687828064, 42.60096195765904, 43.78361483982631, 40.737434250967844, 42.3190735408238, 44.734020709991455, 45.24944850376674, 41.94134514672415, 41.10602923801967, 37.152132511138916, 38.912823404584614, 35.63234608513968, 37.60234451293945, 36.10544545309884, 36.23971939086914, 37.4145416532244, 38.93995612008231, 36.757620743342805, 38.089381967272075, 35.72323547090803, 37.301167896815706, 36.69323526109968, 36.91669627598354, 37.99077660696847, 36.028421197618755, 36.01104375294277, 35.73836169924055, 37.388868059430806, 37.438464300973074, 36.916519096919465, 35.04915598460606, 36.963367325919016, 37.58789573396955, 37.76457452774048, 40.59062228884016, 41.79315396717617, 42.223615714481895, 40.89308432170323, 41.21371241978237, 40.75708723068237, 38.270080293927876, 34.63747869219099, 38.46748556409563, 37.81120041438511, 36.17994751249041, 36.21281944002424, 36.727170263017925, 34.752186502729145, 36.11306415285383, 37.34372908728463, 37.706765515463694, 36.95173256737845, 36.02282442365374, 36.495204653058735, 37.1613701411656, 35.78891331808907, 36.472299916403635, 37.44404370444161, 37.12519087110247, 36.985695362091064, 37.08979327338082, 36.025093010493684, 36.09334863935198, 37.590032305036274, 36.30141939435686, 36.905002457754954, 37.756160259246826, 37.25226994923183, 36.05631474086216, 38.3677476474217, 42.064411640167236, 50.10747957229614, 50.66716391699654, 52.529051848820274, 48.075023787362234, 51.740000520433696, 50.253568921770366, 50.58307681764875, 46.74159846987043, 48.24314587456839, 53.54784883771624, 49.49463108607701, 22.629402126584733, 3.0228854502950395, 13.013612917491368, 14.030006698199681, 1.9826715077672685, 10.697767036301748, 56.20581272670201, 55.47479622704642, 60.73818520137242, 54.599350997379844, 34.61589758736746, 28.223603521074565, 35.76734263556344, 54.85144206455776, 12.78520565373557, 0.42406153359583443, 0.164880440437368, 0.2731485872396401, 0.14118967524596623, 0.17416171383644852, 0.13023699367684977, 0.23354306817054749, 0.16628580859729222, 0.10404129432780401, 0.19995572045445442], [0.09368804416486196, 0.03215500439650246, 0.04334009099485619, 0.026123023159535866, 0.01813967020383903, 0.015731167746707797, 0.006568953070590007, 0.09620135144463607, 0.04626079409250191, 0.04365354703207101, 0.023242506298369596, 0.003537611657520756, 0.012524717437502528, 0.03162306686863303, 5.130048700741359, 45.82479061399187, 39.417147977011545, 25.260059595108032, 20.33675193786621, 38.53012704849243, 48.514931610652376, 46.726722376687185, 47.144489765167236, 46.39195816857474, 47.98469720567976, 7.618657197271075, 1.499411593590464, 2.7366624431950703, 12.18757632800511, 3.2005042050565993, 31.238135065351212, 48.393643856048584, 51.98234673908779, 51.81124040058681, 50.853994028908865, 49.14735664640154, 49.030856200626914, 48.514528615134104, 48.19821882247925, 47.95293698992048, 46.706940855298726, 44.96176528930664, 47.93665041242327, 47.85374450683594, 45.69389002663748, 40.3880614553179, 35.96154131208147, 37.18442078999111, 37.03612538746425, 37.615723269326345, 38.97844566617693, 37.87321308680943, 38.759771960122244, 39.49638523374285, 38.00514895575387, 38.96880504063198, 36.332807881491526, 34.57213088444301, 33.09000022070748, 32.199831758226665, 34.43953146253313, 34.36996609824044, 33.88191768101284, 33.90428393227713, 32.07909638541085, 33.955224650246755, 36.18959856033325, 35.244709559849326, 32.62057644980294, 34.840296609061106, 40.184840542929514, 37.20095750263759, 37.63075222287859, 38.64498771939959, 39.689958572387695, 40.14595147541591, 39.45229196548462, 35.49426106044224, 33.87614720208304, 33.78116185324532, 33.69012655530657, 32.83940996442522, 33.570207595825195, 33.79565232140677, 34.634654249463765, 34.26296383993966, 35.77264758518764, 36.925471850803916, 36.88456085750035, 36.41143022264753, 34.27913577216012, 35.25473928451538, 34.398057665143696, 33.73009606770107, 32.94417142868042, 33.42303780147007, 33.37803084509713, 33.92918280192784, 31.276117392948695, 32.02171816144671, 32.51228182656424, 34.91917950766427, 35.39387696129935, 36.02110474450247, 36.78722701753889, 37.573634556361604, 37.57743174689156, 36.06391954421997, 37.86094604219709, 34.901666573115754, 30.409906319209508, 33.89956610543387, 33.494246414729524, 32.378744397844585, 32.939648151397705, 31.86791283743722, 32.62469673156738, 33.425087520054404, 30.932542869022914, 33.02559041976929, 31.970822606767925, 32.2066444669451, 31.72227164677211, 32.13221883773804, 32.24347686767578, 32.82882785797119, 33.99315486635481, 33.494402749197825, 32.83250345502581, 32.9019124848502, 32.30845294679914, 34.21511854444231, 34.88865607125418, 35.598188740866526, 34.822672503335134, 35.365712438310894, 35.10262584686279, 34.85176461083548, 34.58079528808594, 38.47761256354195, 40.693761348724365, 44.58813633237566, 46.40175512858799, 48.67810658046177, 44.18679448536464, 50.615121909550254, 47.77118253707886, 47.553679602486746, 47.35206024987357, 49.67027112415859, 40.09008795874459, 3.3644258890833174, 0.29988327409539905, 0.4210014763687338, 0.6338034389274461, 0.16847639105149678, 16.635613305228098, 53.10887902123587, 45.21667037691389, 51.97144501549857, 36.77356685910906, 25.996787514005387, 24.91446488244193, 30.4411176272801, 32.399804387773784, 1.1530910113028117, 0.14682570924716337, 0.029709937383553812, 0.04444881042997752, 0.060739116477114816, 0.0646049611802612, 0.061101440606372695, 0.04925146093592048, 0.020669759350961874, 0.021655475654240166, 0.021214602614885995, 0.036151409415262084, 0.10864545298474175, 0.055600231513381004, 0.058565225984369, 0.01650417858867773, 0.022424181191516773, 0.054852360393851995, 0.038051653520337174, 0.013118615390599837, 0.04835163868431534, 0.06662283611616918, 0.05302916394014444, 0.02848793991974422, 0.07736215234867164, 8.017941508974348, 52.664249897003174, 43.33178390775408, 23.105666399002075, 30.18382235935756, 46.05540827342442, 49.15776852199009, 52.8294016293117, 50.6852570261274, 50.76314980643136, 52.37466982432774, 8.063173413276672, 1.9878704973629542, 4.145879796573094, 13.351835591452462, 2.401511524404798, 33.45370020185198, 49.55589682715279, 51.828753335135325, 52.74370949608939, 51.5315580368042, 49.82469483784267, 49.840182372501914, 49.672994818006245, 49.835485390254426, 50.24655818939209, 48.172482694898335, 44.82422569819859, 48.486701079777305, 49.406024183545796, 47.42727449962071, 43.37896565028599, 37.79267651694161, 39.41064098903111, 39.43475123814174, 39.32458060128348, 42.25994437081473, 41.14498431341988, 39.97758967535836, 42.05536508560181, 41.700531005859375, 40.84039265768868, 39.48795706885201, 37.139841147831504, 33.57553686414446, 34.883712427956716, 36.680342878614155, 35.901765959603445, 35.79898820604597, 36.03357676097325, 34.6997241292681, 35.953637736184255, 37.583316871098106, 34.993070125579834, 33.72972086497715, 35.84981427873884, 42.17631932667324, 40.12777846200125, 40.824634143284385, 39.396272114345, 40.95557641983032, 39.689941201891216, 40.04558474676949, 38.19771480560303, 36.42801209858486, 34.90527963638306, 34.505150250026155, 34.158678327287944, 33.43358169283186, 34.994390283312114, 36.09321314947945, 36.11537095478603, 36.56944268090384, 37.94598504475185, 37.764015197753906, 37.06505421229771, 36.51199844905308, 36.212461607796804, 36.56999853679112, 36.65237290518624, 34.3792975289481, 35.46934829439436, 33.32630498068673, 36.15202617645264, 35.0319835117885, 34.789828368595664, 33.98342391422817, 35.766717297690256, 35.98357057571411, 36.74542318071638, 38.24030378886631, 39.69976248059954, 37.90287842069353, 38.862469809395925, 38.9896947996957, 37.647441795894075, 32.66444737570626, 36.20875474384853, 35.44576610837664, 34.79479285648891, 34.76020124980381, 34.087824072156636, 34.20724276133946, 35.77699368340628, 33.13971110752651, 34.36639819826399, 32.68293653215681, 33.295673847198486, 33.182147230420796, 34.565168789454866, 34.08399214063372, 34.20837184361049, 35.819728578839985, 35.40355232783726, 35.43581976209368, 34.237877368927, 34.044887678963796, 35.45399972370693, 36.83401966094971, 37.788125446864534, 35.79635483877999, 36.218499592372346, 36.926423754010884, 35.79834202357701, 37.221076011657715, 39.83326169422695, 43.11168234688895, 46.67716087613787, 48.82022156034197, 49.60206413269043, 44.50985097885132, 52.05701208114624, 49.612726143428254, 49.27116659709385, 50.73278965268816, 52.077912262507844, 42.11468880517142, 5.78057335955756, 0.055177982563951185, 0.5935019872018269, 0.41937548933284624, 0.19845873649631227, 18.36580855505807, 56.179253237588064, 49.094956806727815, 55.59768901552473, 43.37207303728376, 31.513481753213064, 16.572582721710205, 33.83862345559256, 40.46487726484026, 2.2542451066630225, 0.1305622969354902, 0.03678462847269007, 0.06966587568500213, 0.036032000822680335, 0.05210667183356626, 0.05995804124644824, 0.059486920812300274, 0.05083491739683917, 0.02134702381278787, 0.03338422147291047, 0.14027198377464498, 0.1966360014464174, 0.12776631196694715, 0.09009222925773688, 0.11431538659547057, 0.13761595343904837, 0.07101430118616138, 0.15229839272797108, 0.10139035300484725, 0.1436432578733989, 0.17692502055849346, 0.10499985396329846, 0.147742287921054, 0.15734412840434484, 8.46967429774148, 63.21250125340053, 50.66684429986136, 36.188003948756624, 27.32197747911726, 48.138155119759695, 57.41669266564505, 57.19072682516915, 53.00034121104649, 57.58621481486729, 56.05078451974051, 10.017768553325109, 4.1882034455026895, 8.519073384148733, 15.728909867150442, 5.43091264792851, 37.314133235386436, 47.17530155181885, 52.3307328905378, 52.59669256210327, 52.33838633128575, 51.04933220999581, 52.04662105015346, 50.59774793897356, 50.61246074948992, 50.36280502591814, 49.344838346753804, 45.29956586020333, 51.156424794878276, 50.239068031311035, 50.20141921724592, 45.646138531821116, 39.94709403174264, 40.87184020451137, 41.902560302189414, 42.687515667506624, 44.50896160943167, 43.247787134987966, 43.34308862686157, 44.821898051670615, 44.12698439189366, 44.05194384711129, 41.32754475729806, 39.04739958899361, 35.46705191476004, 36.99454041889736, 37.908263274601524, 37.633215359279085, 37.613743032727925, 37.45119687489101, 36.30775267737252, 37.79520566122872, 39.73723758969988, 37.88444832393101, 35.41705962589809, 38.5883321080889, 44.260070187704905, 41.492891039167134, 43.771438121795654, 41.26242971420288, 42.39595535823277, 41.85173075539725, 41.132522719247, 38.43310587746756, 38.717874322618755, 36.54646151406424, 37.16584130695888, 35.87414687020438, 35.74165514537266, 37.50064720426287, 38.50520386014666, 38.278894083840505, 39.17044176374163, 40.156585693359375, 40.30980389458792, 39.220948219299316, 38.5724242074149, 39.89275564466204, 39.95065150942121, 38.020334243774414, 36.18318884713309, 38.189498560769216, 36.24762296676636, 38.322636468069895, 36.98990944453648, 35.365695067814414, 36.597110407693044, 38.362731048039024, 38.424045426504954, 39.48440306527274, 39.247521604810444, 41.20433235168457, 41.52367850712368, 40.401183128356934, 42.43431288855416, 40.285909039633616, 34.277700969151084, 38.97560385295323, 37.12325232369559, 35.63062988008772, 36.1427572795323, 36.293154512132915, 35.75199406487601, 36.874680519104004, 34.32545941216605, 35.90071330751692, 36.0419145992824, 35.45066111428397, 35.35151726858956, 36.794098785945344, 35.640291350228445, 37.339636598314556, 37.81385810034615, 37.255007539476665, 36.18855633054461, 35.123988083430696, 34.94481141226632, 37.43462889535086, 39.26527425221035, 39.0298102242606, 38.30820853369576, 38.75566904885428, 38.454554966517854, 38.10978882653372, 38.48876094818115, 42.50016791479928, 46.86344902856009, 48.7143622807094, 51.28465032577515, 50.31073522567749, 44.91874551773071, 55.43437508174351, 52.60763250078474, 50.3519241469247, 54.61293472562517, 55.61007765361241, 46.87196404593331, 7.989384412765503, 0.7074870222381183, 2.8250691507543837, 4.271214008331299, 0.801216647028923, 22.934438467025757, 63.16828291756766, 52.344274929591585, 62.158535957336426, 48.41063220160348, 37.13375799996512, 31.45246614728655, 41.589575222560335, 48.42701605388096, 3.68908611365727, 0.44405752633299145, 0.13417720581804002, 0.20631860116762774, 0.1511024340455021, 0.16235776937433652, 0.24862986004778317, 0.12278937974146434, 0.14438465237617493, 0.1304232786808695, 0.09284926631620952], [0.02252827864140272, 0.0058762773821529534, 0.019663361300315176, 0.03162975383124181, 0.007724721699820033, 0.054896824793624024, 0.018596595685396875, 0.027565720923511044, 0.10134362229811293, 0.068605847922819, 0.05727092722164733, 0.08638501247125012, 0.09059052501938172, 0.04823203670925327, 1.4982770830392838, 33.21109342575073, 46.84232997894287, 33.59437690462385, 29.49968535559518, 33.31353071757725, 50.28786175591605, 48.84941789082119, 46.50847251074654, 45.586179052080425, 51.29081685202462, 16.262184109006608, 1.2662872629506248, 2.403168018375124, 2.623762684209006, 25.63836816379002, 30.373501232692174, 56.07557916641235, 48.05146939413888, 52.558606011526926, 48.627360412052695, 48.892385550907676, 49.19074467250279, 49.59726292746407, 48.972734519413535, 47.95789452961513, 46.884505544389995, 49.547204630715505, 47.06578057152884, 46.618014335632324, 41.99940429415022, 37.2435291154044, 35.64650303976876, 36.94013602393014, 36.490896769932334, 35.73120158059256, 36.85541663851057, 39.43779802322388, 39.29012795857021, 39.96675395965576, 36.0349247114999, 39.99810075759888, 35.67122820445469, 34.03898171016148, 34.24492631639753, 34.59723472595215, 33.21367468152727, 36.350306919642854, 34.85607596806118, 34.367252826690674, 35.22961459841047, 34.80466277258736, 33.20805011476789, 34.871115343911306, 32.449515274592805, 35.26237882886614, 39.14301374980381, 36.40155335835048, 38.185510294778005, 37.829915387289866, 38.769898959568565, 38.81473568507603, 36.075561250959126, 34.52239220482962, 35.07110186985561, 34.180846554892405, 33.776690687452046, 33.2990471976144, 34.45265660967146, 35.46812193734305, 34.950957093920024, 35.42954901286534, 36.980268818991526, 36.638261113848, 37.35993228639875, 35.85667562484741, 35.84902218409947, 35.63896771839687, 35.24332686832973, 34.51538494655064, 34.724675110408235, 32.97927720206124, 33.48436260223389, 32.88889503479004, 31.607758385794504, 31.806122507367814, 33.05433859143938, 33.83406891141619, 33.1376405443464, 35.27535111563546, 37.183937890189036, 38.447096075330464, 36.143896784101216, 36.010731084006174, 36.760167258126394, 37.97430937630789, 33.24607413155692, 33.8121577671596, 34.318195070539204, 34.65570729119437, 34.266118322099956, 32.96968521390642, 33.16249425070626, 34.58891078404018, 34.20369223185948, 33.64972278050014, 33.01890625272478, 32.832552092415945, 31.85818883350917, 32.684784752982004, 32.43926320757185, 32.182117325919016, 31.759673799787247, 33.98742955071585, 33.626811095646445, 37.58054106576102, 41.865071296691895, 42.438547815595356, 43.00111566271101, 42.94045441491263, 43.056458064488, 40.20530646187918, 40.104422092437744, 39.62166125433785, 38.1779819216047, 38.04384694780622, 40.22668259484427, 44.433511120932444, 45.344221932547434, 49.91595595223563, 45.13237830570766, 47.29737792696272, 48.24569933755057, 48.80285453796387, 46.036394527980256, 50.91034044538225, 21.847927808761597, 0.037689285286303074, 0.48528694255011423, 0.5706408939191273, 0.41853760715041843, 0.2585065886378288, 25.839120728628977, 52.99486950465611, 42.31042650767735, 54.091677393232075, 30.805915423801967, 22.714673893792288, 27.257494722093853, 40.038865838732036, 17.761155469076975, 0.020339628315663764, 0.05992581083306244, 0.024063116371897713, 0.03271322837099433, 0.022329476362626468, 0.01511915460495012, 0.02673326193221978, 0.0503095311245748, 0.05301395797037652, 0.021264307001339536, 0.010180832718365958, 0.052469776278095584, 0.027826846643750156, 0.03197505012420671, 0.025738763689462627, 0.01462834986991116, 0.027887315988274555, 0.02832135957266603, 0.006778538118981357, 0.0882214539285217, 0.032034941017627716, 0.015717152605897615, 0.04921069455200008, 0.05523145790877087, 0.013920080598576792, 2.4160517156124115, 42.348856994083945, 50.92309733799526, 33.34947027478899, 28.870380061013357, 43.82476207188198, 54.616377558027, 53.466509750911165, 48.67130776814052, 51.12225008010864, 52.603289876665386, 16.536575419562205, 1.9846193918160029, 8.37776960645403, 6.553342018808637, 25.58632789339338, 34.15961285999843, 55.0390225819179, 48.66368212018694, 53.60781873975481, 51.957996777125764, 50.31422322137015, 51.79141024180821, 50.618012360164094, 50.15010677065168, 48.53276416233608, 47.08029188428606, 50.25823811122349, 50.511562483651296, 47.30214786529541, 44.2275630405971, 39.06241464614868, 37.91037205287388, 38.081985609872, 37.96097230911255, 39.04893166678292, 40.64828886304583, 42.19101129259382, 40.239495073046, 40.62642288208008, 40.46476261956351, 42.813392707279746, 37.260152680533274, 36.53200578689575, 35.43412787573678, 35.428760392325266, 35.8519161088126, 38.014751366206575, 38.98312875202724, 36.38910913467407, 36.19391686575753, 35.622111388615195, 34.86588682447161, 36.70283767155239, 33.8229934828622, 36.93311139515468, 40.65618201664516, 39.512598855154856, 39.12099838256836, 38.2005739893232, 40.457779679979595, 40.078480992998394, 36.644823687417166, 36.22183125359671, 35.96909052985055, 35.34870324816023, 35.354504993983674, 36.33901262283325, 36.92620488575527, 37.338153157915386, 36.97476584570748, 37.68138722011021, 37.82207087108067, 38.81258174351284, 38.75247982570103, 38.3634432383946, 36.883230277470176, 38.261169229234966, 37.9227363722665, 35.9813506262643, 35.92637995311192, 34.280216217041016, 35.32557616915022, 33.8760985646929, 33.663584436689106, 33.838654722486226, 33.98721415655953, 35.60062061037336, 35.46922322681972, 36.579830237797324, 37.27349669592721, 38.8540346963065, 38.46570335115705, 40.16724075589861, 38.377690519605366, 38.75911882945469, 34.94879273005894, 36.020128522600444, 35.67684929711478, 35.522005217415945, 34.654119627816335, 34.930626664842876, 35.957275118146626, 35.08169787270682, 35.07793542316982, 34.18050261906215, 34.54712431771414, 34.903751032693044, 33.84233031954084, 34.11008262634277, 33.12832301003592, 34.57640055247715, 33.380987303597585, 34.757296902792795, 34.64994028636387, 37.185789585113525, 42.12733105250767, 44.33976255144392, 45.43212011882237, 44.68859338760376, 44.3412355695452, 41.63077804020473, 41.229613372257774, 40.824960708618164, 40.58102682658604, 40.828004019601, 42.81567866461617, 46.147072383335654, 47.054149287087576, 50.622730187007356, 44.635088784354075, 48.641989844185964, 49.99496391841343, 50.67084993634905, 49.008340563092915, 53.73114231654576, 26.008066177368164, 0.22505798776234898, 0.61904155675854, 0.9049325159617833, 0.2681484898286206, 0.4749310868127005, 27.283665112086705, 57.657583236694336, 46.106022426060264, 56.56768185751778, 38.34738942555019, 32.04171507699149, 24.9681327683585, 46.60025474003383, 24.066503252301896, 0.08477964611457926, 0.08710816116737467, 0.02074821835516819, 0.021986661811492274, 0.013510907018956329, 0.015325558172272784, 0.051149828891669, 0.057792903855443, 0.022707199844132577, 0.016797422764024565, 0.011568479239940643, 0.13721369073859283, 0.14713594902838978, 0.08961447275110654, 0.1005727725901774, 0.12457304474498544, 0.09249265545180865, 0.08903317858598062, 0.15001505453671726, 0.27811730919139727, 0.23054196206586702, 0.26474737375974655, 0.18990489334932395, 0.2346653922327927, 0.10437426503215518, 2.1532397951398576, 47.55690009253365, 57.89143875667027, 43.24657467433384, 39.7342985016959, 44.489214829036165, 59.78631673540388, 58.1744875226702, 55.25070987428938, 54.443336146218435, 59.83873394557408, 20.173601286751882, 2.7982582237039293, 8.059219888278417, 7.318137185914176, 30.237111568450928, 36.19441366195679, 53.16633020128523, 49.16875014986311, 54.24185923167637, 54.213013785226, 52.838489873068674, 53.40266622815813, 51.836583954947336, 51.337435790470664, 49.621748379298616, 48.809969493321006, 53.08864934103829, 50.96700995309012, 49.70237527574812, 46.27631235122681, 41.10338544845581, 40.24735695975167, 41.53512219020298, 41.98211717605591, 41.18876838684082, 41.24624388558524, 45.21709769112723, 43.88246686117989, 43.67193296977452, 41.547566413879395, 46.50272635051182, 39.018015657152446, 39.419899463653564, 36.78856801986694, 37.658048221043174, 38.58724818910871, 40.88239451817104, 39.37579229899815, 38.075558526175364, 39.30989210946219, 37.54952778135027, 36.26259633472988, 36.84992756162371, 38.11553846086775, 37.6517288344247, 43.97072287968227, 41.12465041024344, 41.74806710651943, 40.22922910962786, 42.0293093408857, 41.281512941632954, 38.6469783782959, 38.14080558504377, 37.86607033865792, 36.961074420383994, 36.99218150547573, 37.09535183225359, 38.0345641544887, 39.664611543927876, 38.22127614702497, 38.9454973084586, 40.88003213065011, 41.960206031799316, 40.271210125514436, 40.074596949986045, 39.613014221191406, 40.03318568638393, 39.30423974990845, 37.269636971609934, 38.802367891584126, 36.29932451248169, 37.910872323172434, 36.61507497514997, 35.00424630301339, 36.148611136845176, 35.380060468401226, 37.26508937563215, 35.93418625422886, 38.694139276232036, 39.70991379874093, 40.68326609475272, 40.92453186852591, 41.63924094608852, 42.6469520841326, 40.61413846697126, 38.22070639474051, 39.53019864218575, 37.48670564379011, 36.6461056300572, 37.756184577941895, 35.90579244068691, 37.21554177148001, 37.18885721479143, 38.10008566720145, 36.68367106573922, 36.49260255268642, 36.39145415169852, 36.72825765609741, 36.86417484283447, 36.002799715314595, 36.38517298017229, 35.54768923350743, 36.70611374718802, 36.86633573259626, 40.70961018971035, 45.60680825369698, 45.09460094996861, 47.167926039014546, 47.46953691755022, 47.47486965996878, 44.545186042785645, 44.49394655227661, 43.51433045523507, 43.174862316676546, 42.56812824521746, 44.43690879004342, 46.63420016424996, 49.61405324935913, 52.40849712916783, 45.48052821840559, 48.57873691831316, 51.92098024913243, 52.799420152391704, 51.19919095720564, 53.69678347451346, 29.26452010018485, 0.8067124549831662, 0.9071122418556894, 2.6544283415590013, 0.8129586683852332, 0.6336892821959087, 31.19499717439924, 64.03441756112235, 50.33152423586164, 62.99436255863735, 40.507275172642295, 33.083590507507324, 36.20922374725342, 51.78938831601824, 31.79030840737479, 0.2159036954066583, 0.26382820308208466, 0.11245458573102951, 0.07424382931951966, 0.05849560829145568, 0.08503208828291722, 0.18013884739152022, 0.11528239399194717, 0.1330255011894873, 0.09603314261351313, 0.06533564161509275], [0.0077001612766512805, 0.05078215112111398, 0.03328106040135026, 0.07215935617153134, 0.03949003919426884, 0.010589912999421358, 0.03335292065250022, 0.06706564128398895, 0.05522239946627191, 0.05243033303746155, 0.03206067445820995, 0.05907015781849623, 0.02002620790153742, 0.09592307066278798, 0.03067968606150576, 10.833800605365209, 47.99908345086234, 38.996035030909944, 31.052242960248673, 24.86360580580575, 44.101453236171174, 51.53350005831037, 49.31738601412092, 45.41066060747419, 45.383753708430696, 28.58741119929722, 0.34956650382706095, 4.5430409993444165, 1.6241385979311806, 3.9231079561369757, 18.09195225579398, 50.475855691092356, 55.403646673474995, 51.157015391758506, 51.27154949733189, 46.68888248716082, 48.25572211401803, 48.419105529785156, 48.34304707390921, 47.83765247889927, 49.78088991982596, 48.03478329522269, 47.36774928229195, 44.86486223765782, 37.79659182684762, 34.81942422049386, 34.651006834847585, 35.23310259410313, 36.0925669670105, 36.691755294799805, 37.80838639395577, 36.858414786202566, 36.58014638083321, 37.872448784964426, 37.174839224134175, 34.648255348205566, 35.04072434561593, 36.3227538381304, 35.177600383758545, 34.06238671711513, 35.52453783580235, 34.615744726998464, 34.74862902505057, 33.428999355861116, 33.27086183003017, 35.25266177313668, 34.71872745241438, 34.98122692108154, 33.06924595151629, 37.654567173549104, 38.81634766714913, 37.47566148212978, 37.18625511441912, 37.636269092559814, 37.10459641047886, 35.38293007441929, 34.593725885663716, 36.398544788360596, 35.24879857472011, 33.673596790858674, 33.218152795519146, 33.54887662615095, 33.28395571027483, 37.67203494480678, 37.57331146512713, 37.164451667240684, 36.88564477648054, 40.54003592899868, 39.39209277289254, 38.862580980573384, 39.8335257257734, 37.19778217588152, 37.950129645211355, 37.6750921521868, 37.21777214322771, 33.762453828539165, 32.18421915599278, 31.849531378064835, 31.76330075945173, 33.41045461382185, 33.15850598471505, 33.2014284815107, 33.55412599018642, 34.42120211465018, 34.46828310830252, 37.02558497020176, 35.221922942570274, 35.10530437741961, 34.56901461737496, 37.62043762207031, 34.03640740258353, 32.65130485807146, 33.62079395566668, 34.12484407424927, 31.729775701250347, 33.58467027119228, 31.67102173396519, 32.7043126651219, 33.42104714257376, 34.85279294422695, 34.11708293642317, 32.65884712764195, 31.93529646737235, 33.91533851623535, 32.792652062007356, 34.53735167639596, 35.02403824669974, 32.902603830610005, 36.63220575877598, 47.15785462515694, 43.598956039973665, 45.879667486463276, 42.30757427215576, 45.199824469430105, 45.41858155386788, 45.70828669411795, 45.74518162863595, 43.919532026563374, 43.01511628287179, 44.636770248413086, 42.66728598730904, 43.9015257699149, 44.804447650909424, 48.00085524150303, 43.13398606436593, 48.286968163081575, 45.756243160792756, 50.557747159685405, 48.38980497632708, 41.667412417275564, 4.41561928817204, 0.2525319792330265, 1.3474820660693305, 0.1852740275540522, 0.11046822874673776, 0.1810825674661568, 38.62336492538452, 49.10984679630825, 44.13705580575125, 47.82404443195888, 26.48755267688206, 23.646823372159684, 19.941378593444824, 39.86646018709455, 6.211342998913356, 0.34648991748690605, 0.02004400417873902, 0.05891238485596009, 0.08816600404679775, 0.03589811907815082, 0.02852930680715612, 0.09140030906668731, 0.10095710161009006, 0.046919838192739656, 0.11730441477681909, 0.03287441097199917, 0.03570221244756665, 0.1126021874536361, 0.05851242917456797, 0.047362738355462036, 0.023562779916184287, 0.03134164107697351, 0.037047615075217824, 0.08688767121306487, 0.016907964600250125, 0.021183079574257135, 0.061117983290127346, 0.02325525427503245, 0.016203495973188962, 0.0806877746113709, 0.11235380292470966, 17.40297930581229, 56.20482260840279, 39.41503919873919, 31.208803244999476, 33.96596656526838, 46.55281938825335, 56.53084945678711, 53.734863076891216, 51.110702174050466, 50.54718589782715, 32.3015638078962, 0.6180255455630166, 4.63437420129776, 3.828681068761008, 6.28379533972059, 21.50649506705148, 50.488956519535606, 55.89246981484549, 52.722475801195415, 52.624659061431885, 47.66265514918736, 50.777119159698486, 49.413715839385986, 52.262084688459126, 49.84767253058297, 50.71557549067906, 50.18494503838675, 49.386461530412944, 46.14809029442923, 41.35259996141706, 35.84701068060738, 37.62033339909145, 36.30789858954293, 37.966621194567, 38.119797706604004, 39.67201484952654, 39.80090045928955, 39.05537264687674, 39.64601469039917, 39.75542797361101, 37.39961692265102, 36.621773038591655, 37.491117749895366, 36.728723185403005, 35.43593788146973, 38.03438697542463, 35.89885466439383, 37.230258056095664, 34.95102310180664, 35.32993616376604, 36.613952841077534, 36.6762295450483, 36.904015813555034, 35.05867501667568, 38.96860701697213, 40.71961212158203, 38.774126938411165, 37.765436104365754, 39.31028815678188, 37.97901678085327, 38.41625302178519, 37.29905564444405, 37.34116520200457, 36.808109828404014, 36.39618240083967, 35.55123976298741, 34.20932027271816, 34.995814664023264, 38.94715097972325, 38.56333943775722, 38.87458746773856, 38.986595903124126, 41.395466872623985, 40.80532857349941, 39.5217843736921, 41.964156082698274, 39.16469560350691, 37.8258124760219, 39.0339617729187, 38.78684909003121, 35.48342881883894, 33.197853633335654, 33.926274980817524, 32.75031321389334, 34.526196343558176, 34.002944878169465, 35.080408981868196, 33.875997815813335, 35.95264414378575, 37.619145257132395, 38.344391277858186, 37.21600035258702, 37.59453821182251, 37.387888363429475, 40.3655458177839, 35.32306439535958, 34.97762080601284, 36.664862292153494, 35.97052880695888, 33.7966285433088, 34.59729378564017, 33.23729855673653, 34.8472969191415, 35.263719831194194, 34.67941801888602, 34.8472135407584, 33.90603835242135, 34.42998811176845, 35.746143681662424, 34.119403634752544, 35.32896341596331, 35.43684114728655, 34.606031145368306, 36.964350496019634, 48.046553543635774, 45.86578498567854, 47.45242697851998, 44.70575891222273, 47.365206241607666, 46.954230717250276, 46.75106886454991, 47.41710581098284, 47.239527225494385, 44.73133870533535, 46.07887928826468, 44.032398564474924, 46.07841723305838, 46.94726514816284, 49.053531646728516, 43.435986042022705, 48.6275132724217, 46.72150427954537, 52.6552346093314, 49.57685259410313, 46.45080246244158, 6.656858018466404, 0.4640979766845703, 2.859426255737032, 0.1257342624344996, 0.11662649043968745, 0.09366053635520594, 40.803351811000276, 52.64127220426287, 49.70867381777082, 50.97980506079537, 35.40947914123535, 23.719664812088013, 23.107987097331456, 49.36164256504604, 9.847913759095327, 0.21412212029099464, 0.05518265767022967, 0.012042966055949884, 0.10013716667890549, 0.022202644596940706, 0.04119811200403741, 0.0833020004044686, 0.07921483793428966, 0.06946608104876109, 0.05518379082371082, 0.04125193340171661, 0.14516430268330233, 0.17601920344999858, 0.15527568225349697, 0.11069025897553988, 0.15717634026493343, 0.09566946819956813, 0.13020717884813035, 0.1359981766768864, 0.17883023832525524, 0.1353049310190337, 0.147439376318029, 0.1257231751722949, 0.13233202482972825, 0.20553587031151566, 0.2099148774785655, 19.668484619685582, 65.70903069632394, 49.17987421580723, 42.51127808434622, 34.88698155539376, 52.59571981430054, 59.82864516122, 58.890728678022114, 54.50221518107823, 54.148899282727925, 36.894986629486084, 0.8676749180470194, 12.59636664390564, 3.846308648586273, 5.479393703596933, 24.197956221444265, 49.60310983657837, 57.88358381816319, 53.64511319569179, 53.59549263545445, 49.43419565473284, 54.48980222429548, 50.65690837587629, 53.91665574482509, 51.385545117514475, 53.43361003058297, 52.38613782610212, 51.67315190179007, 47.61248220716204, 41.069902079445974, 37.92609930038452, 40.24479307447161, 39.09696456364223, 41.26731777191162, 42.07478182656424, 43.06069993972778, 41.96059513092041, 41.2803247996739, 41.48535919189453, 42.397633348192485, 39.76549938746861, 39.37697696685791, 40.48167453493391, 39.32757180077689, 37.7630216053554, 40.27211686543056, 37.8390348979405, 38.05186169488089, 37.50940888268607, 37.54092591149466, 38.02632359095982, 37.870687416621614, 38.28406006949288, 36.495169912065776, 42.284937041146414, 44.27364696775164, 41.86020408357893, 38.71560573577881, 39.78161226000105, 39.70003693444388, 38.649917466299875, 39.16321563720703, 40.08195161819458, 39.5338568687439, 37.47684267589024, 37.31872599465506, 35.73520721708025, 36.210335459027974, 41.66706500734602, 41.53299604143415, 41.08883592060634, 41.100422041756765, 43.32670477458409, 42.80680928911482, 41.51975972311837, 43.85208238874163, 42.21616724559239, 40.88871737888881, 41.437736238752095, 41.655339922223774, 36.79489088058472, 36.1426808493478, 36.33637578146798, 34.682631560734336, 37.46487787791661, 36.235529627118794, 37.14913088934762, 36.41522741317749, 38.63602106911795, 39.53455516270229, 41.515990325382774, 37.83678020749773, 39.09588064466204, 39.7867956161499, 43.36475658416748, 36.652925286974224, 37.20192330224173, 38.41995988573347, 37.5738707951137, 35.527588094983784, 36.99078491755894, 35.04800258363996, 35.82619387762887, 37.648386750902446, 36.86777400970459, 36.99441882542202, 35.478255884987966, 36.80138397216797, 37.458829471043174, 36.646453039986746, 38.286912305014475, 38.44695363725935, 36.81309863499233, 39.098757198878694, 50.69612053462437, 48.097233704158235, 49.14717946733747, 44.79646764482771, 48.82483516420637, 49.485428197043284, 49.22536407198225, 50.256167548043386, 48.53671421323504, 46.635423047201975, 49.001513957977295, 47.4775516646249, 50.330162388937815, 49.97956323623657, 50.282730511256624, 43.6977733203343, 47.99485894611904, 47.21393353598458, 54.22074365615845, 52.058620589120046, 47.96861212594168, 8.070023468562535, 0.6471674303923334, 4.072815580027444, 0.34954327078802244, 0.2564639539590904, 0.29115440962570055, 46.88326529094151, 55.86339855194092, 54.5037750516619, 56.46917029789516, 37.13670751026699, 32.035916805267334, 30.267902510506765, 56.45642730167934, 14.435048460960388, 0.4386539177170822, 0.1429231557995081, 0.2995151009942804, 0.1497646208320345, 0.11901017038949899, 0.12161206720130784, 0.18760991149715014, 0.1965197819684233, 0.1369726208171674, 0.20697185397148132, 0.15511837069477352], [0.010765235422046056, 0.034822532507990084, 0.06032652647367545, 0.012997272973214942, 0.014976289056773697, 0.07290811277925968, 0.03359884209930897, 0.06158762451793466, 0.034850824025592635, 0.05317152737240706, 0.031065911586795534, 0.10084470228425094, 0.09759893002254622, 0.012568660213478973, 0.02902759239077568, 2.875051668712071, 28.553147894995554, 46.80125222887312, 27.868536676679337, 26.140392882483347, 37.53610733577183, 51.26279476710728, 48.0844281741551, 47.212988580976216, 42.66074078423636, 41.16048921857561, 0.031958103712115965, 5.106028343949999, 2.1912963816097806, 0.21062185668519565, 13.03934817654746, 57.4656913621085, 51.71676574434553, 51.54330396652222, 47.923202174050466, 45.77490602220808, 45.761026995522634, 44.82040766307286, 44.87791790281023, 45.31973648071289, 46.46805831364223, 45.42989322117397, 41.58065720966884, 37.54551519666399, 35.3099809374128, 34.57686260768345, 35.90135948998587, 35.4763069152832, 35.27991260801043, 37.07485812050955, 35.82751056126186, 37.284249033246724, 37.38447332382202, 35.26391090665545, 36.27622870036534, 35.06429263523647, 35.4035245350429, 35.30474199567522, 33.802972248622346, 35.4215863772801, 35.90340920857021, 35.67510182516915, 33.1705367905753, 34.02893114089966, 33.70023965835571, 35.274833474840435, 34.28023011343819, 33.06832878930228, 32.80526999064854, 36.145230838230674, 39.30511522293091, 37.29404599325997, 36.740052223205566, 36.122767312186106, 37.666198457990376, 36.46366677965437, 34.60398490088326, 35.42997980117798, 35.86127185821533, 35.105311325618196, 33.11547926494053, 33.94546937942505, 34.04222651890346, 36.61068718773978, 39.52640839985439, 40.0689480645316, 43.567588397434776, 40.12802512305123, 42.76594693320138, 40.11776263373238, 38.919750758579795, 38.5903297151838, 41.13907139641898, 39.84845393044608, 39.69177900041853, 34.79645695005144, 33.10939959117344, 32.761454650333945, 32.26184095655169, 32.79004301343645, 33.12873990195138, 32.2282429422651, 34.63304574148995, 33.69285372325352, 33.77689218521118, 35.417379243033274, 34.87901891980852, 32.88861015864781, 34.43581417628697, 36.05754804611206, 34.910921573638916, 32.155439717429026, 33.64661693572998, 34.226517064230784, 33.304814202444895, 32.74199969427926, 33.43975864137922, 33.74325942993164, 32.506163937704905, 32.856408732278005, 33.1732292175293, 32.42565516063145, 32.56084973471505, 33.82102714266096, 33.59645789010184, 34.38049956730434, 35.622351101466585, 35.11809948512486, 40.2096734046936, 46.29436724526541, 45.9790232522147, 46.27829258782523, 42.79440328053066, 44.51349183491298, 44.52690533229283, 46.225861481257844, 45.73942852020264, 45.0093708719526, 44.00237887246268, 44.53912026541573, 45.347008160182405, 45.73055567060198, 44.36633593695504, 46.98683861323765, 42.137788091387065, 37.50299916948591, 42.94517224175589, 47.906120027814595, 45.49985810688564, 22.92574974468776, 0.36972273939422196, 2.3006571190697804, 4.688822891030993, 0.04828137977580939, 0.13469598655189785, 2.5867650466305867, 49.77330943516323, 43.20973185130528, 48.618779386792866, 38.562252044677734, 26.01344929422651, 26.045581238610403, 31.069057600838796, 27.635600055967057, 0.8444013840385846, 0.09917754174343177, 0.04789793285142098, 0.06202621598328863, 0.029555696195789745, 0.028001990102763687, 0.047808803884046416, 0.04374103733737554, 0.08362454881093331, 0.037115281979952536, 0.008916551496700516, 0.04496507379891617, 0.05230680573731661, 0.08664445033563034, 0.04989516335938658, 0.016539162157901695, 0.037129822985402176, 0.011783194861241748, 0.039723570591637065, 0.12614440971187182, 0.022996559406497648, 0.02604862179474107, 0.030421103151249032, 0.08572302692170654, 0.0441002571689231, 0.0454411814654512, 0.03469830292410084, 5.233138688973018, 40.83387872150966, 51.833606651851106, 24.507057258061, 32.10668420791626, 50.065616675785606, 54.059792109898154, 53.01407085146223, 49.93815892083304, 47.895273889814106, 39.887349946158274, 0.1666918575231518, 3.9003873467445374, 4.853167763778141, 0.1581545299185174, 14.340457422392708, 61.11748736245291, 54.102499212537495, 52.963498388017925, 52.73282166889736, 48.546368735177175, 46.74166100365775, 47.38026646205357, 47.60100030899048, 48.87465027400425, 49.127328463963096, 49.1084224155971, 44.624857561928884, 39.19306509835379, 36.92841788700649, 36.595018999917166, 37.33263628823416, 37.52752978461129, 38.60518843787057, 38.25766038894653, 37.257015568869456, 38.81109830311367, 38.90480865750994, 37.99494205202375, 37.604540143694194, 34.402369022369385, 36.87012597492763, 36.38873045785086, 34.732015882219585, 37.23547615323748, 37.39321068355015, 36.262610231127056, 36.677494117191856, 35.66935566493443, 34.631805488041465, 36.04297767366682, 37.087080001831055, 35.33684614726475, 35.382349899836946, 37.98004164014544, 40.742683615003315, 38.68784073420933, 39.07643263680594, 37.82543727329799, 38.352760383060996, 37.883920260838096, 34.697500705718994, 37.04013449805123, 36.67187302453177, 35.651398045676096, 34.53489201409476, 34.6863557951791, 35.518010003226145, 37.5514246395656, 41.472421646118164, 38.83437476839338, 44.167124135153635, 41.11379732404436, 42.69086817332676, 42.60482863017491, 39.045377663203645, 40.91259486334664, 41.93541485922677, 41.12210736955915, 41.76695231028965, 36.12475797108242, 34.05530997685024, 34.809613364083425, 34.67932421820504, 36.42600754329136, 34.31572151184082, 34.39453840255737, 35.512437547956196, 35.94850301742554, 35.51019327981131, 37.28898423058646, 38.57773610523769, 36.05225004468645, 37.72380249840872, 38.555032866341726, 37.17269223076956, 33.477039200919016, 35.873365197862896, 35.69465058190482, 34.608525548662456, 34.378067697797505, 35.68319647652762, 34.78890078408377, 34.70026956285749, 34.07007142475673, 34.293018272944856, 33.39053412846157, 34.04299776894705, 36.167340006147114, 36.395286083221436, 36.063718046460835, 36.77269833428519, 35.54437494277954, 42.118305342538015, 48.1947968346732, 47.38072851725987, 47.1702641078404, 44.79042966025216, 45.87053407941546, 45.4729894229344, 48.726618903023855, 46.908945832933696, 46.74657685416085, 46.28820766721453, 47.01972096306937, 47.86440999167306, 47.44593388693673, 47.761937958853586, 47.84707423618862, 42.66075815473284, 38.803583826337544, 43.231576987675254, 48.14465863364083, 46.941821234566824, 27.70078805514744, 0.3800921386906079, 4.334619360310691, 5.083608678409031, 0.141173621107425, 0.07292076745735747, 2.117051839828491, 53.19197252818516, 46.390255859919954, 52.53585066114153, 45.022162505558555, 38.49975299835205, 25.122424466269358, 31.749310561588832, 35.39570781162807, 2.3519548007420132, 0.15328887743609293, 0.025024720933288336, 0.09462001879832574, 0.02637171811823334, 0.05672484223863908, 0.021019176047827517, 0.031744914794606824, 0.05296160560101271, 0.012668038452310222, 0.022344348153897693, 0.014519611240497656, 0.14529466283108505, 0.2383980947945799, 0.13261738951717103, 0.1232473501669509, 0.1264468870524849, 0.2619093060493469, 0.19697142844753607, 0.1701540553144046, 0.17330716683396272, 0.3554806693324021, 0.15150441176124982, 0.12858116467084202, 0.19741462038031646, 0.1906217248844249, 0.16792156653744833, 5.5156424556459696, 50.37376928329468, 56.629392283303396, 36.413799558367046, 37.202774456569124, 48.0886561529977, 59.711366517203196, 57.68971170697893, 56.054209981645855, 51.48518228530884, 49.01010887963431, 0.2117574800338064, 16.0408388205937, 7.991897055080958, 0.179277664316552, 18.487252644130162, 61.56838376181466, 57.06508602414812, 56.590656076158794, 53.85721737997872, 50.51871912819998, 49.82555988856724, 49.788442611694336, 50.39532606942313, 49.58244589396885, 51.55783959797451, 51.44731460298811, 45.231174741472515, 40.37191384179251, 39.51546846117292, 38.7281402860369, 40.01034000941685, 40.15079089573452, 40.154046126774375, 41.22314807346889, 40.13818686349051, 41.603322233472554, 40.94978509630476, 39.4119541985648, 40.4583911214556, 37.8453369140625, 39.39932932172503, 39.64930466243199, 37.04680129459926, 38.87038033349173, 39.07847888129098, 37.96468959535871, 36.687013149261475, 37.38400084631783, 35.73896966661726, 37.388722147260395, 39.31844186782837, 35.43913057872227, 36.656767640795024, 40.36359337397984, 44.584624017987935, 41.396366664341514, 41.019652707236155, 38.69792257036482, 40.35925769805908, 40.23544774736677, 35.89389712469918, 38.83584083829607, 38.21239982332502, 37.999788420540945, 36.39257628577096, 36.24694204330444, 37.98056622913906, 39.120796884809224, 44.11426224027361, 41.60825892857143, 47.12383624485561, 42.761625153677805, 45.75510365622384, 44.560739585331504, 42.11042955943516, 41.619212763650076, 44.98693861280169, 43.27907487324306, 44.53816488810948, 38.760869775499614, 37.75407927376883, 37.18100575038365, 35.72645248685564, 37.96880987712315, 35.47107492174421, 35.61374575751168, 36.921004159109934, 36.509497097560335, 35.953182629176546, 39.889330182756694, 40.179309776851106, 36.46355560847691, 38.484338419778005, 39.73217582702637, 40.11860683986119, 35.349026339394705, 37.54342726298741, 38.07608658926827, 37.22665888922555, 35.779741695949006, 36.35986416680472, 36.728361879076274, 36.783106735774446, 35.917861461639404, 37.32832840510777, 34.6257084437779, 36.002858775002615, 39.822238377162385, 37.42593322481428, 37.514185769217356, 38.899934496198384, 38.8874694279262, 43.0364785194397, 50.2172645841326, 49.811944893428254, 47.98752512250628, 45.85101311547415, 46.79758358001709, 46.73452867780413, 49.32872894832066, 48.35801696777344, 48.49733182362148, 48.707872663225444, 48.32486016409737, 49.52467509678432, 49.848211015973774, 47.30827617645264, 50.87299387795584, 43.055822304316926, 39.13906717300415, 42.971742153167725, 50.94475139890398, 45.81391668319702, 31.39114134652274, 0.8553373600755418, 4.998944010053362, 7.884624685559954, 0.1340857935803277, 0.463111223919051, 2.6272589308874945, 60.19837965284075, 50.60350799560547, 57.47097199303763, 46.50188214438302, 37.52127987997872, 35.07424940381731, 40.4335652078901, 43.73383099692208, 3.867946207523346, 0.3130759761801788, 0.09815889104668583, 0.15625206700393132, 0.12386170934353556, 0.10098271630704403, 0.13101230135985784, 0.10701333877763577, 0.15634422563016415, 0.1995858374450888, 0.19455014408699103, 0.1095107819086739], [0.021856759674847126, 0.008518713692735349, 0.03173045182068433, 0.08606563960867268, 0.051257305445947816, 0.04444464083228793, 0.08729832739170108, 0.002240674665829699, 0.01652430902634348, 0.0795759339151638, 0.06631320701645953, 0.07026065912629877, 0.03738100647128054, 0.016549307952768037, 0.04471954590241824, 0.07657003056790147, 15.145775352205549, 44.18046120234898, 40.249642917088096, 22.098929745810374, 25.24366010938372, 49.46237407411848, 48.68698637826102, 48.76543501445225, 43.190134457179475, 46.57443870816912, 1.9008905589580536, 3.801708596093314, 4.5762976833752225, 0.17793029733002186, 7.221234134265354, 57.681172370910645, 52.67844506672451, 51.837198870522634, 44.34307336807251, 43.064080238342285, 42.97211735589163, 40.903794969831196, 40.95208495003836, 41.4172807421003, 37.71062176568167, 38.03084339414324, 34.84080730165754, 33.491074562072754, 34.366634437016074, 33.032705375126426, 33.884151526859824, 36.41434151785714, 34.51975883756365, 34.308950492313926, 33.76176943097796, 34.25831549508231, 34.36122873851231, 35.054203850882395, 33.84614140646798, 35.52721636635916, 34.12402071271624, 36.24215126037598, 36.05349377223423, 36.9294045312064, 34.82058456965855, 34.62041391645159, 35.106357029506135, 33.364547865731375, 33.19343457903181, 33.91579362324306, 36.02143825803484, 34.245742729731965, 35.114100796835764, 36.629172870091026, 37.43013341086251, 37.57943630218506, 35.93812588282994, 36.484605176108225, 37.79640769958496, 37.18642881938389, 36.47146960667202, 33.9451219694955, 33.66399438040597, 36.70924391065325, 32.59997851508004, 33.92588588169643, 32.48273113795689, 35.18065411703927, 40.83278438023159, 42.75336027145386, 43.27691050938198, 44.87994677679879, 43.364999771118164, 44.47715623038155, 39.66470881870815, 40.65345137459891, 42.575587136404856, 41.15855761936733, 40.874765396118164, 36.33701501573835, 32.39320707321167, 32.48805693217686, 32.91108758108956, 32.852549007960725, 33.53367396763393, 32.78878886359078, 32.9234345299857, 34.65578024727957, 34.84833567483084, 34.97983380726406, 35.154848507472444, 36.33231455939156, 36.406107902526855, 36.21703699656895, 34.37571920667376, 32.13486957550049, 33.38807446616036, 34.58309514181954, 33.23651688439505, 33.424677576337544, 32.404522214617046, 33.81030259813581, 33.688108103615896, 33.83911330359322, 33.15626171657017, 31.78749438694545, 32.75012213843209, 30.656595161982946, 32.53241423198155, 32.331409794943674, 32.445537430899485, 31.78412798472813, 37.517013686043875, 42.99157231194632, 43.02254738126482, 44.89191157477242, 44.76067052568708, 46.35552876336234, 45.4562268938337, 44.49615955352783, 46.97664213180542, 47.44623613357544, 47.00139856338501, 47.14811325073242, 45.96459879193987, 46.48268774577549, 44.72080176217215, 44.183799811771934, 44.82050493785313, 43.94162034988403, 44.140925952366416, 45.61215141841343, 44.52232299532209, 5.001068421772548, 0.025657249581334845, 1.4535956063440867, 0.6109707898327282, 0.02524976894658591, 0.2320058877979006, 5.358986633164542, 53.65496574129377, 42.00304167611258, 51.55186414718628, 30.789812973567418, 26.653227261134557, 15.91279741695949, 38.757965428488596, 17.733018738882883, 0.25696745408432825, 0.0546216245607606, 0.005026484365641538, 0.0290819532237947, 0.013605901921567107, 0.021511517664683715, 0.04583188871453915, 0.09969582036137581, 0.05585238530433603, 0.06639292131045035, 0.0430020143144897, 0.07399503766958203, 0.025422596904848303, 0.05607277687106814, 0.03542015901101487, 0.04745293940816607, 0.0444577569141984, 0.009032355371995695, 0.08120400405355863, 0.020242876007354686, 0.052665628625878265, 0.022823024075478315, 0.031548746928040466, 0.0563423859753779, 0.020621844600620012, 0.04171372737203326, 0.008795710347060646, 0.3070717826485634, 22.34976840019226, 52.036831038338796, 40.08316060474941, 29.067163467407227, 34.61134999138968, 53.708723953792024, 53.04024471555437, 53.33744348798479, 46.49732412610735, 50.48173039300101, 1.7786013952323367, 2.332503101655415, 2.825496030705316, 0.6557327679225377, 9.685790572847639, 59.669364656720845, 55.19868523733956, 53.99910306930542, 46.688451698848176, 44.23783595221383, 44.899690083095, 42.24643012455532, 43.54680980954851, 44.73448623929705, 42.848095485142295, 41.69909272875105, 39.24005576542446, 34.75310019084385, 36.01080404009138, 34.49857030596052, 35.912177835192, 38.51594924926758, 36.421671867370605, 36.84446975163051, 36.32108974456787, 36.19705745152065, 36.64868688583374, 37.271318435668945, 35.64978953770229, 36.157400608062744, 35.81203692299979, 38.000629152570454, 35.91842079162598, 38.64318813596453, 36.691282817295615, 37.05521208899361, 37.71811539786202, 35.80492891584124, 34.51451989582607, 35.1974652835301, 37.18382324491228, 35.38416337966919, 35.55448109763009, 38.64444923400879, 38.4608986718314, 38.80040155138288, 38.16393961225237, 39.76201139177595, 39.80880750928606, 38.27508994511196, 38.26749903815133, 36.554722922188894, 35.24427877153669, 37.20659943989345, 33.22994041442871, 35.46805245535714, 34.606698172433035, 36.61713164193289, 41.94847052437918, 42.734270095825195, 45.442073413303916, 45.43272461209978, 45.94629028865269, 45.70583745411464, 42.15369599206107, 41.656066008976524, 43.1341667175293, 42.28653860092163, 42.03287376676287, 39.11431768962315, 34.75741849626814, 34.337653500693186, 34.59257248469761, 34.67778866631644, 34.93869699750628, 34.90116630281721, 33.67645597457886, 34.85881355830601, 35.658401829855784, 36.10503550938198, 37.17040627343314, 38.09899827412197, 37.42977557863508, 37.754683767046245, 35.723068714141846, 34.561319487435476, 35.31952428817749, 35.144954272678916, 34.40924079077584, 35.39095524379185, 34.72130523409162, 36.19062341962542, 34.84656041009085, 36.14088126591274, 34.9881785937718, 33.67057432447161, 33.51615408488682, 33.11442313875471, 32.61931882585798, 34.79001596995762, 34.01077897208077, 35.092088903699604, 39.93738739831107, 45.272843088422505, 44.86037022726876, 46.58653204781668, 46.683313505990164, 47.33144147055489, 46.97625650678362, 46.227174690791536, 48.62350068773542, 48.54639652797154, 48.4114625113351, 48.26976442337036, 49.594563552311485, 47.62683023725237, 47.4443427494594, 44.62402377809797, 47.324885845184326, 43.93508209500994, 45.18692166464669, 45.13922575541905, 45.7259281703404, 7.2675681965691705, 0.028909988701343536, 3.457216041428702, 0.9413221861634935, 0.01551300856018705, 0.2764848625021321, 6.077761709690094, 59.35546588897705, 47.113677978515625, 56.24019936152867, 37.41003574643816, 31.49775103160313, 16.907308714730398, 44.825698716299875, 24.798862491335186, 0.3075365519949368, 0.012938115745782852, 0.009613486688717135, 0.030453058757952282, 0.052220238239637444, 0.01634500954034073, 0.02922798413783312, 0.0372982896598322, 0.06452627147414855, 0.03631751139515212, 0.016318668810916797, 0.015739512031099627, 0.10309224096792084, 0.12707058287092618, 0.22826517852289335, 0.1585585568100214, 0.13470423753772462, 0.11121483439845697, 0.2668502894895417, 0.14610450794654234, 0.14774367213249207, 0.13944140262901783, 0.06811843586287328, 0.12666927011949675, 0.2088170349597931, 0.14299369630004677, 0.09226031149072306, 0.29087089055350845, 28.755993604660034, 57.80151169640677, 49.451771123068674, 33.74418354034424, 34.04134062358311, 59.87571920667376, 56.474968569619314, 57.830638544900076, 51.477907521384104, 57.065002645765034, 2.177706790821893, 6.757306822708674, 11.732509272439138, 0.5034062702740941, 10.71174681186676, 60.96380015781948, 56.68645436423165, 56.14052745274135, 49.26992286954607, 46.080213342394146, 47.89528431211199, 44.64776577268328, 44.135256222316194, 46.92973484311785, 41.977336815425325, 42.592203753335134, 39.955866132463726, 37.26549931934902, 38.662375586373464, 35.73961237498692, 38.995566027505056, 42.198501450674875, 38.38341236114502, 38.6278395652771, 38.27414846420288, 39.43407378877912, 38.24098123822893, 39.523934841156006, 36.64548029218401, 39.72697857448033, 38.142445359911235, 39.22708347865513, 38.076527799878804, 41.13403742653983, 38.30745118004935, 38.166086605616975, 38.75441142490932, 37.471798283713206, 36.42034476143973, 37.59868976048061, 39.70177398409162, 36.64742578778948, 37.83087076459612, 40.41453061785017, 40.78971597126552, 41.077235903058735, 39.44920001711164, 39.761080333164756, 41.685251917157856, 39.64928034373692, 40.08552994046892, 36.90805966513497, 36.37808581760952, 39.15730619430542, 35.53789227349417, 38.90950563975743, 36.761702810014995, 37.72628647940499, 44.5372268812997, 46.60666445323399, 48.00411742074149, 47.85293851579939, 47.91168206078665, 48.98455340521676, 43.889724254608154, 43.630264622824534, 44.77221148354666, 45.69696113041469, 43.949298109327046, 40.30762563432966, 36.11301898956299, 37.3471337045942, 37.02113117490496, 37.78152118410383, 37.91066040311541, 38.31950977870396, 35.303588594709126, 37.73495783124651, 38.64275387355259, 37.12867191859654, 38.70529113497053, 39.848367077963694, 39.93638685771397, 39.813879694257466, 37.148641041346956, 35.96177407673427, 37.120334080287385, 37.657433305467876, 37.57335662841797, 38.067995412009104, 35.40147134235927, 37.90417078563145, 36.29988384246826, 37.692952496664866, 37.098047733306885, 37.450984954833984, 36.969815254211426, 33.72021572930472, 35.060471126011436, 36.637851170131135, 36.3335930279323, 35.0986966405596, 41.498866489955354, 48.166736534663606, 45.365573746817454, 47.8085047858102, 49.43024212973458, 49.37492752075195, 48.44955601011004, 48.37529713766915, 50.96611710957119, 49.47568334851946, 50.47598770686558, 50.379015173230854, 50.59908546720232, 50.07543100629534, 48.973919187273296, 45.87279224395752, 48.948426246643066, 45.58710316249302, 45.534369809286936, 46.34872300284249, 46.433074133736746, 9.897271156311035, 0.1363136140363557, 6.162937939167023, 2.1474219816071645, 0.14277490946863378, 0.5930960604122707, 6.650051389421735, 65.06050668443952, 50.52495166233608, 59.704154287065776, 40.45404849733625, 37.52958297729492, 23.694102389471873, 50.974948269980295, 33.147864818573, 0.35038753119962557, 0.1608127179954733, 0.2178341546761138, 0.1494369019887277, 0.14611555449664593, 0.22050655127636024, 0.18973331898450851, 0.1718471630343369, 0.10129497133727584, 0.17647170488323483, 0.14756457959967, 0.15315728235457624], [0.018751345774424926, 0.023919797901596342, 0.05273470349077668, 0.022752246087683097, 0.04842419443385942, 0.026950170917968665, 0.05180798411103232, 0.049055808755968294, 0.04350221336686185, 0.04129810092438545, 0.03795497924355524, 0.020418477477505803, 0.06999096181243658, 0.022320119364719306, 0.06391310651919671, 0.060971087243940146, 10.30563850062234, 47.511667319706504, 38.32912955965315, 40.794989653996055, 26.138956342424663, 36.02390486853463, 47.5154401915414, 48.604389667510986, 41.94683769771031, 49.36949750355312, 5.247430264949799, 0.8870407960244587, 1.1283860398190362, 1.4516020161764962, 4.398985735007694, 55.0597699029105, 53.65787703650338, 48.57263987404959, 47.47197920935494, 39.78212642669678, 38.00075422014509, 38.59441525595528, 36.96194641930716, 36.35594538279942, 35.987225328172954, 33.967582021440776, 33.11975935527256, 34.96802534375872, 35.39656591415405, 36.780094691685264, 37.61899239676339, 39.71120268957955, 38.29134178161621, 37.673021589006694, 35.356665883745464, 35.39279651641846, 35.3752384185791, 35.915384428841726, 35.32290458679199, 35.57777145930699, 36.52534246444702, 33.37345893042428, 34.14029686791556, 34.78607981545584, 34.80906793049404, 34.90532827377319, 34.24519034794399, 33.983976296016145, 34.59598057610648, 34.749681677137104, 35.631870133536204, 33.9285192489624, 34.49127469744001, 34.986160142081125, 37.187186173030305, 36.795085430145264, 35.79459694453648, 36.426987239292686, 36.77728067125593, 36.41883700234549, 34.876552309308735, 35.053140776497976, 35.36774478639875, 35.71094410760062, 34.36519615990775, 33.0950585092817, 32.99210705075945, 35.57487406049456, 42.733662128448486, 42.542895862034385, 44.92349113736834, 45.85444205147879, 46.29080976758684, 44.01331186294556, 40.68252958570208, 43.7245968409947, 44.637291363307405, 42.743299279894146, 42.01022611345564, 37.2382241657802, 32.994434697287424, 32.808181285858154, 32.12920331954956, 32.3728905405317, 33.9113050869533, 34.95932272502354, 33.13983270100185, 35.305680002485005, 34.54468897410801, 36.39558832986014, 35.978230885096956, 35.505770751408164, 35.826551709856304, 35.62386928285871, 36.29236241749355, 34.3743782043457, 34.051568371909006, 34.72118016651699, 33.31374611173357, 34.51721232278006, 33.410701274871826, 34.22767741339547, 33.830497537340435, 34.21164444514683, 35.28235837391445, 33.63926921572004, 31.93889910834176, 34.386360372815815, 33.293297563280376, 33.7093174798148, 33.33156476702009, 35.376690592084614, 33.51214844839913, 37.14965200424194, 38.281482287815635, 39.32768644605364, 41.23363290514265, 43.62815931865147, 43.34182752881731, 44.27172926494053, 44.53136954988752, 46.7914274760655, 44.60562147412981, 45.79098415374756, 45.64063903263637, 46.542185170309885, 44.268807547433035, 44.18403952462332, 45.82759768622262, 49.03748478208269, 47.79208271844046, 46.50713150841849, 27.85472365788051, 0.20948406202452524, 0.5877765087144715, 1.1971386820077896, 0.30950297362038065, 0.1728386248328856, 0.18335248423474176, 6.551661423274449, 54.489823068891255, 42.821265016283306, 43.11005646841866, 34.49885170800345, 27.905825921467372, 22.38526153564453, 42.41305487496512, 5.202683866024017, 0.06095438849713121, 0.03615033393725753, 0.04762923976938639, 0.007027677518116044, 0.021588775661907027, 0.07433929919664349, 0.03444641036912799, 0.016288362044308866, 0.019423972449398468, 0.001620707185273724, 0.026731735228427818, 0.03293035279161163, 0.03752836052860532, 0.04318136129794376, 0.05637548152091248, 0.004194960056338459, 0.06687111886484282, 0.059919310467583795, 0.02291732856870762, 0.0626589906002794, 0.00441508148131626, 0.0180155576672405, 0.08848802319594792, 0.041064698448670764, 0.11106802656182221, 0.012042155206602598, 0.05162005365959235, 0.07730551503066506, 14.820589235850743, 52.77938502175467, 42.90305226189749, 32.89336620058332, 33.030707768031526, 43.50761502129691, 51.634106499808176, 52.83500187737601, 45.563291685921804, 53.36789396830967, 5.656196262155261, 1.8276771732739039, 3.086420863866806, 1.4410506337881088, 5.201221704483032, 57.7297020639692, 53.545163358960835, 50.62264333452497, 48.93581526620047, 41.931836536952424, 39.96159839630127, 41.53965588978359, 38.13208906991141, 38.504995414188926, 36.904470920562744, 35.006018093654085, 34.6680577141898, 37.29684959139143, 37.7943788255964, 38.429920128413606, 39.53694534301758, 40.34262718473162, 40.960294246673584, 39.54687431880406, 37.59223140989031, 36.68515450613839, 37.640573501586914, 36.40637540817261, 36.739774295261924, 37.947537967136924, 38.96613693237305, 36.1303061076573, 35.57783399309431, 36.46442065920149, 36.37954841341291, 36.22841814586094, 36.57937513078962, 36.06463868277413, 35.77773019245693, 36.581237248011995, 37.12008047103882, 35.06916332244873, 36.823941298893516, 36.386830125536235, 38.83798435756138, 38.77966117858887, 37.69582557678223, 38.06373964037214, 37.46048314230782, 38.06195395333426, 36.233094283512656, 36.21459470476423, 36.90783732278006, 37.02973651885986, 35.29435443878174, 34.97313574382237, 34.23862430027553, 38.25270632335118, 44.71658420562744, 44.544824736458914, 46.368674755096436, 48.02303041730608, 48.33822849818638, 44.88688802719116, 42.581166539873394, 44.81090600149972, 46.35055385317121, 43.317991733551025, 43.09310286385672, 39.14582429613386, 35.32594442367554, 34.20164598737444, 36.00783715929304, 34.32190540858677, 34.93184607369559, 34.48175913946969, 34.53723355701992, 35.29963854381016, 35.64938306808472, 37.62347398485456, 37.240722043173655, 37.211744580950054, 38.52106659752982, 38.17687020983015, 37.030629362378804, 34.91109875270298, 35.625026157924104, 37.11376803261893, 36.156518186841694, 36.06865474155971, 35.787690435137065, 36.17611558096749, 36.29810162952968, 36.27478347505842, 36.82351745877947, 34.77578605924334, 33.866360664367676, 34.73058107921055, 34.88122844696045, 35.381766251155305, 35.84683697564261, 35.83420862470354, 34.39402770996094, 38.745590686798096, 41.27564171382359, 42.397428376334055, 41.762647901262554, 45.482341698237825, 47.29899338313511, 46.62447268622262, 45.40870468957083, 47.45169046946934, 45.87527622495379, 47.24094813210623, 46.73952095849173, 47.674939564296174, 45.32997465133667, 46.52163587297712, 45.89052752086094, 50.87440436226981, 47.74205568858555, 46.93084308079311, 31.027809619903564, 0.34553057753614014, 0.542063984487738, 1.3968798496893473, 0.43790028244256973, 0.10546863345163209, 0.4762239402958325, 7.499313201223101, 59.722247396196636, 48.87485177176339, 47.933079038347515, 44.09902484076363, 30.390510422842844, 18.352308205195836, 50.85748897280012, 8.438561132975988, 0.09137072493987423, 0.09282381446766001, 0.016785246453114917, 0.013338962852555727, 0.027051912155002356, 0.06926408795905964, 0.025780156021937728, 0.06740032868193728, 0.039787383417465856, 0.04758205783686467, 0.015899435949644873, 0.038248459209821055, 0.1328810139426163, 0.09412893586392913, 0.2096665065203394, 0.050890146754682064, 0.2664642573467323, 0.18473232590726443, 0.08509829294468675, 0.16600398586264678, 0.11042586102017335, 0.09447361129735198, 0.16222283590052808, 0.12091381395501749, 0.23643362734998974, 0.09315460028925113, 0.23160905337759427, 0.15353289219949925, 17.048798356737407, 65.09875651768276, 45.548464230128694, 50.46619769505092, 36.51867914199829, 44.91436815261841, 56.06543479646955, 58.63857160295759, 50.01007972444807, 60.49472032274519, 6.8524011714117865, 3.864251502922603, 7.6174985851560315, 2.6434050244944434, 6.328405380249023, 58.74903406415667, 56.39486278806414, 53.718458380017964, 49.808679240090505, 44.422147342136924, 41.785674231392996, 43.09842865807669, 41.36535337993077, 40.56833594185965, 38.40494135447911, 36.96658434186663, 37.640712465558735, 39.890830993652344, 38.747834954942974, 42.3706430707659, 42.538025174822124, 43.52319983073643, 44.86960438319615, 42.223403794424875, 41.3518773487636, 39.427309717450825, 39.74510989870344, 39.55302694865635, 38.54388795580183, 39.66829061508179, 40.18220370156424, 37.586738858904155, 38.00206742967878, 38.93591226850237, 39.12286049979073, 37.815904344831196, 37.38873256955828, 37.60726383754185, 37.66038628986904, 38.475882462092805, 38.41189650126866, 37.49219124657767, 38.98224980490548, 38.24399675641741, 41.34603043964931, 41.466772760663716, 38.225170612335205, 41.08291605540684, 38.704241956983296, 40.033821446555, 37.42681564603533, 37.51525231770107, 38.56829350335257, 39.42112234660557, 37.24220895767212, 37.16985389164516, 35.79641737256731, 40.31676598957607, 47.45201356070382, 47.43234668459211, 49.09119783129011, 50.37995318004063, 49.64226293563843, 48.79983901977539, 45.49605049405779, 46.64004012516567, 48.576749733516145, 45.35529736110142, 45.72563287190029, 40.921954086848665, 37.919387340545654, 36.22916507720947, 36.84087405885969, 36.829816000802175, 36.90854951313564, 36.79153837476458, 36.05668994358608, 38.555588722229004, 37.82779966081892, 39.46634817123413, 39.535381998334614, 38.02162313461304, 40.50754962648664, 39.44668476922171, 39.27538735525948, 38.33258628845215, 37.14987087249756, 39.34173570360456, 36.98176962988717, 38.70199768883841, 37.20898267201015, 37.15850053514753, 37.63226693017142, 37.49848631450108, 38.502028533390586, 37.459190777369905, 35.13564716066633, 38.44393464497158, 36.23374046598162, 37.05840826034546, 36.58670548030308, 38.24977765764509, 36.53547988619123, 39.71782432283674, 44.0698493548802, 43.77450922557286, 45.13740880148751, 47.76886878694807, 47.15462023871285, 49.10662630626133, 47.94374104908535, 50.54964208602905, 46.81066356386457, 47.573857171194895, 48.64404303686959, 50.4691333089556, 47.547763211386545, 48.023068632398335, 47.90350750514439, 51.87590381077358, 50.396361351013184, 45.361988476344514, 33.716515813555034, 1.0631827328886305, 0.8878696401204381, 4.329375641686576, 1.2547382712364197, 0.26751104689070154, 0.5173765463488442, 8.349396637507848, 66.78840555463518, 52.43185349873134, 52.35064990179879, 46.53893688746861, 37.27782889774868, 28.903906856264385, 57.221132142203196, 11.705237592969622, 0.20525805093348026, 0.2091814489769084, 0.20895742385515145, 0.08118104242852756, 0.15652961496795925, 0.23200634920171329, 0.13398868164845876, 0.14418069832026958, 0.09471644540982586, 0.10763686496232237, 0.10225752075867993, 0.0464161786117724], [0.008409951314596193, 0.002186556197037654, 0.04556947208142706, 0.0194955952132919, 0.024008309402103935, 0.06451857688703708, 0.041854435178850374, 0.03819679894617625, 0.05492032246131982, 0.044025153520384004, 0.03627238542373691, 0.07500214648566075, 0.01383311191706785, 0.028882840515247414, 0.015283522927867514, 0.010953466973400541, 1.4799026804310935, 39.3953514780317, 50.56393105643136, 32.76082236426217, 20.650407518659318, 37.40644005366734, 45.82114975793021, 51.564381326947895, 41.40444047110421, 48.88372809546334, 5.9272832700184415, 1.6709196248224802, 0.8594019476856504, 0.7129042286958013, 1.516258261033467, 43.33417408806937, 58.09891544069563, 48.33248928615025, 46.950690610068186, 38.64912189756121, 40.855848925454275, 36.47118125643049, 37.602764878954204, 34.94352946962629, 37.30176196779524, 36.0633602142334, 37.202784878867014, 38.36570487703596, 40.20708520071847, 42.10980422156197, 43.84254598617554, 44.35181072780064, 42.55560064315796, 41.81816748210362, 39.68189518792288, 36.08027212960379, 36.32354245867048, 36.552030495234895, 37.54570279802595, 34.09137807573591, 34.92427601133074, 33.96584497179304, 34.52293069022042, 35.15178435189383, 36.77955968039376, 36.594067096710205, 35.60601588657924, 35.32101815087454, 35.74414260046822, 34.187937191554475, 34.78592695508684, 35.57638529368809, 35.185239928109304, 37.11688429968697, 36.69794961384365, 34.30932222093855, 35.669491154806956, 35.032046045575825, 36.5390373638698, 36.01998608452933, 35.55041292735508, 33.920983927590505, 34.322902475084575, 37.11041900089809, 33.9426623071943, 32.85828474589756, 33.125654901777, 36.82867997033255, 42.85373394829886, 43.86659370149885, 45.293791907174246, 47.490770612444194, 47.99200323649815, 46.32587385177612, 41.840384347098215, 45.354769298008506, 47.00153405325753, 43.61373485837664, 43.00754622050694, 37.573756149836946, 32.62364755358015, 32.4555914742606, 31.24927302769252, 33.29751511982509, 33.94141163144793, 33.29438495635986, 33.01164885929653, 32.826823302677695, 33.6287704876491, 34.423633984157014, 34.74289676121303, 34.078044482639854, 34.753152302333284, 35.641104289463584, 35.64110081536429, 33.94401373182024, 32.890673773629324, 34.750623158046174, 33.36623280388968, 32.10820238930838, 33.577933992658345, 33.628318854740684, 34.3549336705889, 34.94306741441999, 34.0433486529759, 33.426570960453574, 34.571918964385986, 34.74487352371216, 34.80016033990042, 34.79699196134295, 32.739005020686555, 33.88310929707119, 34.1969872202192, 35.528651169368196, 37.350388935634065, 38.014966760362896, 40.47145026070731, 39.882882254464285, 39.18272270475115, 40.13231216158186, 40.96447011402675, 43.44139868872506, 43.83332920074463, 44.97371619088309, 44.42221335002354, 43.344050952366416, 43.82026311329433, 45.7976370538984, 42.602778911590576, 45.65054021562849, 45.550104004996165, 48.83784219196865, 19.911786215645925, 0.20933418720960617, 2.8873710419450487, 2.5134350614888326, 0.3257325270346233, 0.05026798103270786, 0.2049003272716488, 10.995452182633535, 52.81213188171387, 42.75371462958199, 35.44998019082205, 27.874548605510167, 16.634360892432078, 30.61192866734096, 31.00422395978655, 0.34910257586411064, 0.09962542235319104, 0.0069998698807986716, 0.01926425378769636, 0.04912414401769638, 0.06707835703023843, 0.034171685110777617, 0.02691117551044694, 0.015732669005436555, 0.0579538048644151, 0.04757410540644612, 0.1251794243497508, 0.03777148641113724, 0.01253198115487716, 0.04036998376250267, 0.05534969263577035, 0.04760161321610212, 0.027688908956146667, 0.06967177893966436, 0.09077729856861488, 0.028077036075826203, 0.038565229890601974, 0.0402842237214957, 0.04194575581433518, 0.047267363473240814, 0.01694897864945233, 0.03361964937565582, 0.07730528432875872, 0.004776047692368073, 4.350969340120043, 48.97469391141619, 53.14898749760219, 38.85953419549124, 27.556569508143834, 42.74468891961234, 48.94513974870954, 56.13339860098702, 45.4435464314052, 53.729683194841655, 6.363716994013105, 1.22649319257055, 1.335842204945428, 1.2352528082472938, 2.1699458701269965, 45.77074752535139, 58.87343461172921, 49.78314461026873, 49.19679307937622, 41.00700351170131, 42.42762524741036, 39.38658285140991, 39.06237643105643, 35.90182154519217, 39.081358909606934, 36.76622608729771, 38.52408211571829, 39.87171649932861, 42.17343235015869, 44.0971349307469, 44.41170072555542, 46.7191036769322, 44.221730027879985, 43.97473199026925, 40.52089711597988, 37.465211391448975, 38.16502353123256, 38.199736731392996, 38.7526535306658, 36.72082308360508, 36.1252304485866, 36.81214325768607, 35.887376240321565, 36.46295806339809, 37.93775142942156, 37.66967603138515, 36.76946742194039, 37.037574086870464, 36.93300717217581, 35.79797376905169, 36.86573123931885, 36.87003564834595, 36.10735968181065, 36.1638137953622, 36.749262060437886, 35.74205814089094, 37.156221526009695, 35.8732088633946, 37.314157554081504, 37.541891711098806, 36.875417028154644, 35.419891016823904, 36.46351391928536, 38.36727169581822, 35.03650678907122, 34.534280572618755, 34.211811201913015, 37.36146436418806, 44.30886738640921, 45.20602226257324, 48.00090735299246, 47.04465804781233, 49.18648542676653, 48.93586390359061, 45.44530779974801, 45.37869194575718, 47.55653531210763, 46.15348557063511, 44.19306870869228, 38.392900126320974, 34.67117050715855, 33.19066572189331, 33.05237919943673, 35.952171666281565, 34.621327604566304, 35.2652519089835, 33.91028370176043, 34.326633657727925, 35.72313124792916, 35.934154987335205, 35.62573487418038, 36.39329195022583, 37.157764026096885, 38.6027808870588, 38.47924191611153, 36.2969308580671, 34.34518534796578, 35.48359557560512, 35.36210284914289, 33.90645177023751, 35.94182232448033, 36.173857416425435, 36.108891759599956, 37.01941844395229, 35.11396183286394, 35.63331535884312, 36.487519945417134, 36.64669622693743, 35.78425455093384, 36.786382811410085, 35.45920392445156, 35.0365206854684, 35.7059622492109, 37.55929694856916, 38.47156068256923, 40.401690346854075, 40.65870073863438, 41.83315474646432, 41.0884815624782, 43.13741152627127, 42.332334177834646, 45.810574599674766, 44.50815909249442, 46.2596366746085, 46.881323269435335, 46.40473937988281, 45.32345029285976, 47.00327457700457, 44.54178837367466, 48.04119995662144, 46.78071682793753, 48.10552290507725, 22.605788673673356, 0.11860691702791623, 4.503736342702593, 3.748528386865343, 0.5127018743327686, 0.1315836278455598, 0.5489379784890583, 11.421433210372925, 59.315541539873394, 46.22172382899693, 39.63031523568289, 38.552760805402485, 18.490299429212296, 31.95484869820731, 39.70108263833182, 1.236674040555954, 0.16222054245216505, 0.003729299284584288, 0.038640102837234735, 0.023952264105901122, 0.05286006962082215, 0.0485533739307097, 0.031460612014468224, 0.0242681018010314, 0.02411637288917388, 0.025862050109675953, 0.10589363386056252, 0.10932770637529236, 0.11515227811677115, 0.09219726880214044, 0.14937724518988812, 0.11842497464801584, 0.08524489043546574, 0.14240117238036223, 0.18317491162036145, 0.2248285072190421, 0.09221846623612301, 0.09444785410804407, 0.0968800832384399, 0.12901035164083752, 0.16524463732327732, 0.11824166162737779, 0.10824189428240061, 0.08567650656082801, 4.971427406583514, 58.66389083862305, 59.45052419389997, 43.23264701025826, 30.407040187290736, 46.71730061939785, 52.46096645082746, 61.595711026872905, 49.37720305579049, 58.94205502101353, 7.092721121651786, 2.75228459920202, 5.820697469370706, 2.158186044011797, 3.2761561913149695, 45.87777757644653, 61.88459627968924, 52.85332427706037, 50.97458348955427, 42.460927963256836, 46.3239735194615, 41.23237180709839, 42.64573267527989, 38.95031588418143, 41.01747792107718, 39.656982421875, 40.958970614842, 42.68691117422921, 44.53069904872349, 45.765244552067344, 47.87058694022042, 50.42906999588013, 46.244291578020366, 47.07109246935163, 44.12367010116577, 39.231339250292095, 40.37663514273507, 40.79183864593506, 40.92365639550345, 38.640207358769004, 38.40301322937012, 38.309563432421, 37.75976290021624, 38.004169259752544, 40.14644479751587, 39.47888272149222, 38.9780843598502, 38.41543313435146, 39.3216484614781, 36.38757010868618, 37.991419315338135, 39.6207058770316, 38.92368343898228, 40.07991232190813, 39.15227917262486, 36.82068954195295, 39.09650250843593, 37.49250391551426, 39.42428725106375, 40.04791586739676, 39.28546919141497, 37.03885950360979, 38.250965799604145, 41.58420426504952, 37.4705719266619, 37.85257693699428, 36.570269516536165, 39.31550625392369, 47.35447127478463, 48.52886969702584, 49.442186083112446, 51.05865321840559, 52.10685845783779, 50.26819140570504, 45.970320633479524, 46.83711188180106, 51.069384711129324, 47.59488589423043, 47.94286905016218, 39.77251359394619, 37.571560519082205, 35.91139268875122, 35.68938384737287, 38.309146540505544, 38.572243554251536, 36.725033691951204, 36.39517143794468, 35.28148290089199, 36.26106425694057, 37.64924137932913, 38.40377753121512, 38.67553547450474, 39.378078256334575, 40.209656034197124, 40.31730100086757, 38.623239857809885, 35.6896721976144, 37.83255917685372, 37.089654309409006, 35.26778105327061, 37.713060583387104, 37.9132034437997, 38.15816913332258, 38.36203622817993, 36.61279944011143, 38.05813939230782, 39.1316499710083, 38.49470860617501, 38.484793526785715, 38.55693319865635, 35.80676671436855, 37.11371939522879, 37.436303411211284, 38.02129656927926, 40.548377241407124, 42.15687131881714, 43.67711632592337, 44.67915078571865, 42.805280685424805, 45.008401598249165, 45.007414954049246, 45.840785367148264, 47.01688609804426, 48.196707589285715, 48.12878894805908, 47.83086061477661, 47.71234866550991, 48.48745148522513, 47.1660361289978, 49.0426299231393, 48.72481237139021, 48.31608806337629, 25.72714182308742, 0.49477606479610714, 6.502503786768232, 7.865932294300624, 0.9679282499211175, 0.39118841184037073, 0.6954118673290525, 13.357051951544625, 63.69483825138637, 48.50158412115914, 46.28454596655709, 37.57411398206438, 24.32249399593898, 41.18607248578753, 47.11334793908255, 2.7409970334597995, 0.3256383463740349, 0.07424791410033192, 0.1140091773122549, 0.20272916448967798, 0.29829574642436846, 0.15932629204222135, 0.12490981524544102, 0.18851260734455927, 0.1977891717106104, 0.11366514648709979, 0.2813493071922234, 0.15822908734636648], [0.08430984882371766, 0.004133756621740758, 0.06821718306413718, 0.03357598564720579, 0.026515229971015027, 0.018285080258335386, 0.018534145018618022, 0.0397144171542355, 0.057953268821750364, 0.06038365912224565, 0.06908993516117334, 0.060667198550488265, 0.09443603402801923, 0.046788663802934546, 0.038645222383950434, 0.05498629302850791, 0.17661970694150242, 25.37305814879281, 46.59387976782662, 41.82228428976876, 35.89123249053955, 31.944308280944824, 40.214012554713655, 43.96089812687465, 40.87434503010341, 51.5695264680045, 6.889323464461735, 0.6346749493053981, 0.2809266341584069, 0.3184971995651722, 0.18397715714360985, 35.30704879760742, 63.226300375802175, 46.82123524802071, 49.313974448612754, 40.8507524217878, 39.321558134896414, 36.77160051890782, 37.68201603208269, 37.58611004693167, 42.39836638314383, 42.31305292674473, 45.53805930273873, 44.34813860484532, 46.33498641422817, 44.321870940072195, 47.40752077102661, 46.9565965788705, 48.35955946786063, 44.05641501290457, 42.3497428894043, 38.34734773635864, 35.77092790603638, 35.24828093392508, 35.46297679628645, 35.029051371983115, 35.50003501347133, 34.793750626700266, 35.43756028584072, 34.79578297478812, 36.173009736197336, 36.04003511156355, 35.60805170876639, 34.42039264951433, 33.86796222414289, 35.269097736903596, 35.71279927662441, 35.37928227015904, 37.16472612108503, 34.595431668417795, 36.392155919756206, 35.750798974718364, 34.84159939629691, 34.15722615378243, 37.131173270089285, 35.828243596213206, 35.10745831898281, 35.63184234074184, 37.193950244358604, 37.00740500858852, 34.606587001255576, 32.4542852129255, 33.718815667288645, 35.56829759052822, 42.45191962378365, 43.79426295416695, 44.78789356776646, 46.44624097006661, 49.354795115334646, 48.287259987422395, 44.49039602279663, 46.08034535816738, 49.4344596862793, 44.73864126205444, 41.97955329077584, 37.28877231052944, 32.07835292816162, 33.30263246808733, 32.54100567953927, 33.32062135423933, 33.083795479365754, 34.80521862847464, 34.552794047764365, 33.696254866463796, 33.47041061946324, 34.79852403913225, 35.144808360508506, 34.31815685544695, 34.682228565216064, 34.17113644736153, 34.85595784868513, 34.354037352970664, 34.67408875056675, 34.97430304118565, 33.431452069963726, 33.473179476601736, 34.598527090890066, 33.54592711584908, 34.71589258738926, 35.080572264535085, 34.4470146724156, 32.915398938315256, 32.243188517434255, 32.5655015536717, 33.28968102591378, 32.85236488069807, 34.322020053863525, 33.86735078266689, 32.52781799861363, 33.03973347800118, 38.55491822106497, 41.08559111186436, 41.7491579736982, 40.45774493898664, 39.44100114277431, 39.445812770298545, 37.799291202000205, 39.66413559232439, 40.32059097290039, 41.53544875553676, 42.16741868427822, 44.256127085004536, 40.14778927394322, 42.76921953473772, 41.47638211931501, 46.399500438145225, 47.17732695170811, 49.66189854485648, 19.771601097924368, 0.10483684949576855, 0.3295254563646657, 0.2670469017965453, 0.12402777400399957, 0.2600884437561035, 0.23333405224340303, 16.62141466140747, 52.94078820092337, 43.91650608607701, 38.60058873040335, 22.128985915865215, 25.20953229495457, 38.28795106070382, 21.599743366241455, 0.2519815244844982, 0.052353807858058383, 0.04149287440148847, 0.04063637321814895, 0.20591099161122525, 0.032965846958437135, 0.015324579385508384, 0.06645105140549795, 0.02918375043996743, 0.024527468419234668, 0.022011043271049857, 0.046002564020454884, 0.015353615595293897, 0.10378134756215981, 0.03864216897636652, 0.16078014831457818, 0.023393197051648582, 0.02755707299469837, 0.01801866535762591, 0.051094304371093, 0.009366693324409425, 0.062342128317270956, 0.07815745645867926, 0.0388191953700568, 0.050220843204962354, 0.0922565795481205, 0.07640818639525346, 0.02565302400450621, 0.01963784159826381, 0.5585544481873512, 34.572902134486604, 51.544742243630544, 40.54472596304757, 34.00778777258736, 43.91692992619106, 43.5110057422093, 50.38777337755476, 44.94845601490566, 56.0732376234872, 7.165172593934195, 1.028270966240338, 0.21044318484408514, 1.0244989629302705, 0.39873893239668434, 38.60948589869908, 64.17939867292131, 48.628124713897705, 51.32736437661307, 41.53371517998831, 41.27665615081787, 38.85780756814139, 39.89813355037144, 39.841627325330464, 43.24596323285784, 43.491304125104634, 46.4196571622576, 46.149365288870676, 47.13182667323521, 45.878038133893696, 50.05861636570522, 48.909151554107666, 50.001397950308665, 46.02633006232125, 45.67692599977766, 40.104602745601106, 37.991822310856406, 36.74528421674456, 35.8496926852635, 37.67220170157296, 36.78962067195347, 36.51389530726841, 37.44929306847708, 37.089918340955464, 37.48428072248186, 37.691614968436106, 37.440979548863, 35.92159264428275, 35.63055344990322, 36.5640925679888, 37.76183346339634, 37.488637242998394, 37.420440673828125, 36.69764736720494, 39.875843729291645, 37.98721218109131, 36.98161676951817, 36.23017604010445, 38.285342012132915, 36.80171748570034, 36.29666335242135, 36.1628167288644, 37.98603793552944, 37.857708181653706, 36.34860461098807, 34.492483683994834, 34.337490218026296, 38.059730529785156, 44.30298226220267, 43.60606404713222, 45.944237095969065, 46.95119782856533, 50.82070173536028, 49.33543395996094, 45.871357440948486, 47.865789209093364, 50.13160719190325, 46.389116355351035, 44.39756808962141, 38.77856683731079, 33.90394694464547, 34.419451168605256, 33.695841448647634, 35.06067957196917, 35.43244988577706, 36.513443674360005, 34.96467283793858, 35.491905621119905, 35.08526924678257, 36.628443309238975, 36.20375204086304, 35.727682318006245, 36.686342648097444, 35.700865745544434, 36.419097559792654, 37.35645471300398, 35.59842150551932, 36.29103878566197, 34.99146161760603, 34.382302624838694, 35.78369869504656, 35.26237188066755, 36.626351901463096, 35.91405037471226, 35.93003470557076, 33.64104448046003, 33.178749561309814, 34.71607324055263, 34.87464502879551, 34.883736746651785, 35.15754788262503, 36.15447194235665, 34.630478382110596, 34.76585013525826, 40.246102809906006, 42.877809456416536, 42.802741118839805, 43.34223052433559, 40.581940514700754, 41.37388229370117, 39.57814468656267, 41.20681633268084, 41.935609408787315, 45.62966782706124, 44.29908432279314, 45.2095172064645, 43.38471875871931, 44.31316484723772, 43.313968726566856, 48.45906114578247, 47.80056994301932, 50.84923103877476, 22.325755425861903, 0.06419044413736888, 1.3632378663335527, 0.9829335361719131, 0.20548438307430061, 0.14986821955868176, 0.28818359332425253, 17.58770932470049, 58.13550118037632, 46.6744441304888, 47.469582080841064, 30.02916588102068, 18.81499743461609, 42.052561487470356, 26.46156815120152, 0.30118076875805855, 0.0023236853677579866, 0.03469648105757577, 0.04324122844263911, 0.06651266917054142, 0.018191661253305416, 0.02032946216474686, 0.03966673989115017, 0.06665545329451561, 0.055488846597394774, 0.06385851837694645, 0.03244103744093861, 0.013304666300038142, 0.1636781578085252, 0.11820453219115734, 0.234805523284844, 0.11488465033471584, 0.13857038079627923, 0.10687522975994007, 0.10135570700679507, 0.15924429787056787, 0.16137972899845668, 0.1700077224522829, 0.0904815455100366, 0.12328667805663177, 0.10584074884120907, 0.15642562269100121, 0.12190775919173445, 0.13382378406822681, 0.6626667444195066, 41.016605922154014, 58.97545501164028, 47.78057302747454, 43.53910425731114, 43.60269069671631, 47.80540241513933, 55.0102014541626, 49.90441152027675, 60.49204526628767, 8.860636404582433, 2.1259737610816956, 3.2840119983468736, 2.451296018702643, 1.5525774721588408, 39.65011065346854, 67.317948613848, 50.50174815314156, 52.83295215879168, 43.265133312770296, 43.12060383387974, 40.73092031478882, 42.01240784781319, 41.73035962241036, 48.38818604605538, 46.25605835233416, 49.28777279172625, 47.72186074938093, 50.193439211164204, 48.04226303100586, 52.65728432791573, 50.512695040021626, 53.92257561002459, 47.40812179020473, 47.59675843375069, 42.32133517946516, 39.95075225830078, 38.62766586031233, 39.02599566323416, 39.41315276282174, 38.49487883704049, 39.66175236020769, 39.53967945916312, 37.96594374520438, 38.631282397678916, 39.64192567552839, 38.59728486197335, 37.65116603033883, 36.851237297058105, 38.59721885408674, 40.32209178379604, 39.668836048671174, 39.89570862906319, 38.120228494916645, 41.075304303850444, 39.03956549508231, 38.08480657849993, 36.715886388506206, 39.9305990082877, 38.89642218181065, 38.34939398084368, 38.8443489074707, 40.06546701703753, 40.57431139264788, 38.51232576370239, 36.09729174205235, 36.472873142787385, 40.2916065624782, 45.40115894590105, 45.116303648267476, 48.63629926953997, 48.263309546879356, 52.41095331736973, 50.27741861343384, 49.56176110676357, 49.576873438698904, 53.760529722486226, 46.85785920279366, 45.615594250815256, 40.25653553009033, 36.38810511997768, 38.01408781324114, 35.629160336085725, 36.91493838174002, 37.466934544699534, 38.894952637808665, 36.977367946079795, 37.527811186654226, 37.77682072775704, 39.085218633924214, 39.187075751168386, 38.58591760907854, 38.812939575740266, 37.621886321476524, 37.52766874858311, 39.83030523572649, 37.42440462112427, 37.68587575639997, 36.39760678155081, 36.54304994855608, 38.53160006659371, 36.581212929316926, 39.6127918788365, 38.01605415344238, 37.754607336861746, 35.89078780582973, 35.10490485600063, 36.29580872399466, 36.06486102512905, 36.873231819697786, 37.78125715255737, 38.39389371871948, 35.210322925022666, 36.72400883265904, 40.72480590002877, 45.50786590576172, 44.67100402287075, 44.83960206168038, 41.973289489746094, 44.12158216748919, 41.68828133174351, 44.016063349587576, 44.6104713167463, 46.93464027132307, 46.255346161978586, 48.29382256099156, 44.98145301001412, 45.988347734723774, 45.9786411012922, 50.95475333077567, 50.809994561331614, 51.342754636492046, 25.72428958756583, 0.2592712976038456, 0.9601554955754961, 1.4198245384863444, 0.571998615350042, 0.48058903749500004, 0.4368241530443941, 21.24947599002293, 64.85279028756278, 52.168579305921284, 51.290684836251394, 31.531449794769287, 33.821023668561665, 49.945624760219026, 32.85009281975882, 0.4119801090231964, 0.20242037677339145, 0.12843283691576549, 0.14264332795781748, 0.3402592289660658, 0.22724857021655354, 0.11494147085717746, 0.14272453502884933, 0.17087925997163567, 0.1972528983439718, 0.09642287277217422, 0.12774170828717096, 0.09208930709532329], [0.07373268210462161, 0.03192079785679068, 0.02909076400101185, 0.045271798768746, 0.013375771680979856, 0.044920280309660096, 0.12576571931796415, 0.030578489348824536, 0.039604796429297755, 0.02019758040218481, 0.07950248928474528, 0.010878670361957379, 0.0212431401014328, 0.11146454207066979, 0.042288080123918395, 0.1144133127693619, 0.059938221238553524, 9.263961962291173, 45.75981453486851, 46.16031217575073, 30.01441832951137, 29.360714435577393, 33.2625344140189, 49.355396134512766, 43.35611997331892, 48.87749556132725, 16.53110545022147, 0.35083555430173874, 0.7065162286162376, 0.41135015711188316, 0.18568460909383638, 23.809027331215994, 64.8552360534668, 47.98699011121477, 51.34385245186942, 40.83319779804775, 40.467941420418875, 37.532362256731304, 41.709105082920615, 42.24562760761806, 45.977473803928916, 45.12752151489258, 49.81279952185494, 48.942231927599224, 49.21165527616228, 47.82246719087873, 50.737424101148335, 48.933855874197825, 48.25564220973423, 44.66654675347464, 43.43343257904053, 37.4683450290135, 35.601325852530344, 34.94825077056885, 36.686043875558035, 35.388137749263215, 36.02603449140276, 35.138669627053396, 34.18244464056832, 34.3895218031747, 35.44675275257656, 36.50375093732561, 36.578878334590364, 34.711890425000874, 37.42753825868879, 36.88858733858381, 36.95656851359776, 35.839235646384104, 35.969722815922324, 36.09729174205235, 35.17372676304409, 34.7521448135376, 35.822747571127756, 35.60915299824306, 36.31697293690273, 36.07871573311942, 36.39837455749512, 34.5384008543832, 35.162328243255615, 36.24352352959769, 36.557741914476665, 31.92266811643328, 32.8418105670384, 34.29523822239467, 39.20844146183559, 42.09918737411499, 43.70609378814697, 44.65638848713466, 49.737050260816304, 49.40143142427717, 46.521003586905344, 44.70664480754307, 48.008234228406636, 43.502185004098074, 40.544399397713796, 36.778680733272004, 32.482734612056184, 33.92410019465855, 32.413131032671245, 33.52128185544695, 32.56889574868338, 35.00049080167498, 33.89721066611153, 34.38445656640189, 34.55298859732491, 33.71098157337734, 34.64920030321394, 33.78903068814959, 33.98161390849522, 33.46783283778599, 34.194301741463796, 32.52667154584612, 34.17560761315482, 33.69608810969761, 32.607677119118826, 33.18164348602295, 33.13638292040144, 33.72910247530256, 32.941638810294016, 34.160609926496235, 34.95616476876395, 34.49065630776541, 34.15776811327253, 34.18635300227574, 33.307763712746755, 33.854944774082725, 34.43359770093645, 35.49891635349819, 37.36623082842146, 38.28240292412894, 41.438764572143555, 41.62367698124477, 43.75010020392281, 44.88521351133074, 42.379248414720806, 41.61160101209368, 40.02699484143938, 39.08134848730904, 38.36039645331246, 37.32049778529576, 36.78496537889753, 38.72889763968331, 39.737539836338584, 41.94196701049805, 41.41057573046003, 44.954264708927695, 45.9399813243321, 47.90465743201119, 19.564152206693375, 0.0858591003343463, 1.2140841441495078, 0.18626230023801327, 0.17409633020205156, 0.1813724104847227, 0.16584732569754124, 17.38162922859192, 51.97708347865513, 42.520988191877095, 26.238428490502493, 18.818417685372488, 29.70124912261963, 40.38014398302351, 5.728113157408578, 0.2478538602590561, 0.13811117543705873, 0.0382115876169077, 0.04052074406562107, 0.03863712067582777, 0.04296453882540975, 0.04190967471471854, 0.06679339946380683, 0.010300591604651084, 0.023689599807507226, 0.081353017129004, 0.0719566506200603, 0.011993060653497065, 0.01604046606059585, 0.013405388886375087, 0.07330693530717067, 0.03891149309596845, 0.024797937566680566, 0.08017416431435517, 0.07571333939475672, 0.031574789102056196, 0.0442427868422653, 0.030647713491427045, 0.037642551186893664, 0.04353553282895258, 0.05260079460484641, 0.19566017309469835, 0.07800345615084682, 0.2222988201039178, 0.07384633672024522, 16.139603989464895, 52.48420122691563, 49.34425817217146, 32.46925163269043, 39.77578966958182, 39.61572401864188, 52.05278410230364, 45.170728887830464, 55.13805873053414, 17.1927615574428, 0.6145944382463182, 0.17808857240847178, 0.17045531129198416, 0.1104684051658426, 26.844516379492624, 66.46088136945451, 49.81358814239502, 54.15008395058768, 43.27602113996233, 42.71265772410801, 39.52627985818045, 42.34992354256766, 42.27276727131435, 47.20598827089582, 46.29403025763375, 52.200881481170654, 50.070410932813374, 50.650780064719065, 48.87311472211565, 52.27056496483939, 51.290247099740164, 51.67716448647635, 46.51191881724766, 45.55519356046404, 38.9001498903547, 37.569854736328125, 35.33490412575858, 37.11178779602051, 36.92864717755999, 37.683912890298025, 37.53344964981079, 36.08504901613508, 36.43876443590437, 36.89241579600743, 37.768326554979595, 38.44543545586722, 36.470010484967915, 38.63135187966483, 36.1864128112793, 37.31122541427612, 37.33925792149135, 36.88841363361904, 38.515098094940186, 37.622866017477854, 36.320221219744, 37.09114122390747, 36.838476930345806, 38.46689149311611, 35.6516238621303, 37.17199393681118, 37.062024797712056, 37.2585129056658, 37.57580934252058, 38.473593030657085, 33.084695271083284, 35.15053020204817, 35.82464442934309, 42.51546089989798, 44.44957535607474, 45.002440043858115, 45.88384682791573, 49.94059426443917, 49.185922622680664, 48.20135246004377, 45.85777023860386, 49.76790721075875, 45.49215950284685, 42.300546169281006, 38.30983788626534, 35.29783548627581, 35.15338591166905, 33.50521762030465, 33.59897313799177, 35.04278448649815, 36.361128738948274, 36.56431143624442, 36.197995458330425, 36.522900172642295, 35.911764417375835, 37.6872376033238, 36.90118094852993, 36.108599935259136, 35.85505322047642, 35.21983848299299, 34.751019205365864, 35.8177170753479, 36.11939743586949, 34.559836047036306, 35.039230482918875, 34.60552740097046, 35.898806027003694, 35.88661193847656, 35.75637490408761, 36.62752614702497, 34.32078674861363, 34.63916015625, 36.170358998434885, 36.607529231480186, 35.72415610722133, 36.75329201562064, 37.32884604590279, 39.00404977798462, 39.54583556311471, 42.55104609898159, 43.89442123685564, 46.91125610896519, 48.09520135607038, 43.98320879255022, 41.36544023241316, 43.1938864844186, 40.3992862701416, 40.73087862559727, 39.97655439376831, 38.78076246806553, 41.017165252140586, 41.679547446114675, 42.90363938467843, 43.20268637793404, 46.93823248999459, 47.12090757914952, 48.59672580446516, 21.744755744934082, 0.03561491213206734, 1.8378984076636178, 0.21121496414499624, 0.18456030370933668, 0.27286436249102863, 0.27835105093462126, 18.849992036819458, 58.03634691238403, 45.90980877195086, 36.11333860669817, 23.074144159044536, 27.616263219288417, 50.09208236421858, 8.257088950702123, 0.3304568406726633, 0.07287138367870025, 0.04202478139528206, 0.03792343075786318, 0.012450222774142665, 0.02503261568823031, 0.040467326396277974, 0.06956173413033996, 0.06258919648826122, 0.03080749831029347, 0.02924493733527405, 0.057145649301154275, 0.0550245522255344, 0.13328011466988496, 0.18888578803411551, 0.17151947133243084, 0.11942091477768761, 0.09304472511368138, 0.17113471483545645, 0.1672205991510834, 0.08156334262873445, 0.16412918003542082, 0.0979582414563213, 0.2153156633887972, 0.08798383775034122, 0.16349580830761365, 0.41906702731336865, 0.15531304239162377, 0.2822161221078464, 0.27987949177622795, 15.727957963943481, 61.90398175375802, 53.14772292545864, 36.45299434661865, 40.971852575029644, 42.28664282390049, 58.907869883946006, 51.27304336002895, 58.981555530003135, 20.684896639415197, 0.6699645242520741, 0.6636193533028875, 1.4639015219041278, 0.4170646976147379, 27.8800185748509, 69.24061243874687, 52.05402435575213, 55.84528112411499, 44.791961738041465, 44.03813430241176, 40.33071449824742, 46.21177748271397, 45.96629762649536, 50.81633826664516, 47.376927852630615, 55.548978669302805, 53.460190364292686, 52.5870623588562, 50.39720555714199, 53.72198806490217, 52.12562206813267, 53.77755280903408, 47.555684157780235, 47.9046539579119, 41.97678790773664, 39.84416341781616, 38.071931566510884, 40.100426878247944, 38.91796159744263, 39.75848865509033, 40.103949614933555, 38.608763286045615, 38.70355755942208, 38.52198028564453, 39.99156945092337, 41.00033671515328, 38.47042465209961, 41.78767531258719, 39.209980487823486, 39.78282124655587, 39.12943002155849, 37.88940586362566, 40.35061066491263, 40.182585852486746, 37.78214999607631, 38.42329849515642, 38.42282254355294, 40.87902116775513, 39.12117903573172, 39.94114637374878, 38.29585116250174, 37.98153550284249, 39.67415836879185, 41.54529087884085, 35.90277692249843, 36.09203542981829, 38.20512505940029, 44.276137896946494, 45.986992835998535, 48.837658064705984, 47.333195890699116, 54.15997471128191, 51.87166540963309, 49.00771869931902, 47.78488091060093, 51.827509607587544, 47.12328386306763, 43.82886845724923, 40.47530651092529, 37.41543102264404, 38.457900524139404, 35.845350061144146, 35.95869949885777, 37.053481987544465, 39.122467926570344, 39.84816558020455, 37.02633190155029, 38.70767784118652, 37.27683530535017, 38.49901301520211, 38.234140736716135, 36.97489786148071, 37.702728612082346, 37.84907851900373, 37.09347929273333, 38.1961201940264, 37.553578581128804, 36.658303192683626, 36.993713583265034, 35.979088987622944, 38.207539558410645, 36.47983176367623, 37.38829483304705, 38.32989386149815, 36.55895437513079, 36.934751170022146, 39.35935980933053, 38.38310316630772, 38.26930904388428, 38.13317993709019, 39.58072246823992, 41.952514375959126, 41.79718739645821, 45.129498277391704, 44.69173397336687, 48.26514734540667, 50.4391587802342, 44.853790283203125, 43.8508734021868, 43.88094520568848, 43.99915490831648, 43.513677324567524, 42.72222539356777, 40.105794361659456, 42.27561950683594, 44.31862613133022, 45.76772158486502, 44.82626152038574, 49.538911955697195, 49.68327120372227, 49.49728877203805, 23.782023157392228, 0.2676843990172659, 3.403496261153902, 1.627136311360768, 0.48203806259802406, 0.4666195213794708, 0.3954027385583946, 22.213248457227433, 61.77161857060024, 49.82479558672224, 35.61157097135271, 25.806745597294398, 37.69660724912371, 55.62235859462193, 11.393284320831299, 0.46047774808747427, 0.21094068671975816, 0.14225555876536028, 0.18241649945931776, 0.14913168336663926, 0.116090949890869, 0.31407011140670094, 0.14506192531968864, 0.18360109946557454, 0.09374817593821458, 0.11697508102016789, 0.13405388886375086, 0.13525794925434248], [0.03754754610625761, 0.006542442283327026, 0.05471859060760055, 0.04908627497830561, 0.039734345727733204, 0.014460733060591986, 0.04486842327085989, 0.09212465876979486, 0.02521128244032817, 0.0619455042428204, 0.03733707472149815, 0.02507205044717661, 0.05713678763381072, 0.02829686615483037, 0.06904469044612986, 0.053552104093666585, 0.09388779808900186, 0.8433789131896836, 23.13901080404009, 49.850688048771445, 33.80667563847133, 26.159210341317312, 28.306945426123484, 37.75003889628819, 48.26568930489676, 46.142107895442415, 27.577782358442033, 0.18558481016329356, 0.32930395539317814, 0.1389442671622549, 0.13735439176005976, 13.255259105137416, 63.43502426147461, 49.9198191506522, 54.451330048697336, 43.97551713671003, 42.16182191031319, 38.47482981000628, 43.79498209272112, 43.46263933181763, 49.039235728127615, 46.5035080228533, 51.22359650475638, 48.54606301443917, 46.91891997201102, 47.69957787649972, 48.97257818494524, 46.50855588912964, 48.0439236504691, 44.527836390904014, 40.17300081253052, 36.16299043382917, 35.756176880427766, 34.69136892046247, 36.08422565460205, 33.41454362869263, 35.61802584784371, 35.00028582981655, 36.326571873256135, 35.56099850790841, 37.36134277071272, 35.50242519378662, 34.67579800742013, 34.21257897785732, 35.470400946480886, 36.043599537440706, 37.23325967788696, 35.83401754924229, 35.49455288478306, 35.75959192003523, 34.68069301332746, 33.79500961303711, 36.29245621817452, 33.941435950142996, 35.83219712121146, 34.49616622924805, 35.25976978029524, 34.80946397781372, 36.275308064052034, 34.708940914699006, 36.96855763026646, 33.088169370378765, 33.66344894681658, 33.02902282987322, 37.49110385349819, 39.606795583452495, 43.462114742824006, 43.24219036102295, 47.19348151343209, 48.51658180781773, 45.699552808489116, 47.582097734723774, 48.330418722970144, 44.40885543823242, 44.31463439123971, 37.9244247845241, 33.748460156576975, 34.467755045209614, 34.6714380128043, 34.45127739225115, 34.30109207970755, 33.24156127657209, 34.50028303691319, 35.04494537625994, 33.255283968789236, 34.94565909249442, 35.87077351978847, 35.00424630301339, 35.16171680177961, 34.82444429397583, 35.17684303011213, 34.469874245779856, 35.01806627001081, 34.36096818106515, 34.352991649082725, 34.0161395072937, 34.278569493974956, 34.53228643962315, 34.65993527003697, 34.161620889391216, 34.013568673815044, 32.54895441872733, 32.507928780147004, 33.05383137294224, 32.871534960610525, 33.15857546670096, 37.38484852654593, 41.27613156182425, 44.540127754211426, 44.209963253566194, 43.94299956730434, 43.61017043249947, 45.72126245498657, 44.734458446502686, 44.59000539779663, 43.278046539851594, 42.47449084690639, 41.47061858858381, 39.1825316292899, 37.71086147853306, 38.424173968178884, 38.686753341129844, 37.07021672385079, 39.44648674556187, 41.24430186407906, 44.112268107278005, 44.536045687539236, 44.384477683476035, 12.801513944353376, 0.30552882115755764, 1.2010643056460788, 0.1081569009859647, 0.06253278308681079, 0.5096008607319423, 0.4975954592227936, 21.86700061389378, 52.61438614981515, 31.738669395446777, 24.898742846080236, 26.63007238933018, 42.06716660090855, 24.761931078774587, 0.3248566468911511, 0.014813567877614071, 0.029619885608553886, 0.0328147541731596, 0.01143853469485683, 0.07250455407691853, 0.007923722450089241, 0.02920609459813152, 0.060107203599597724, 0.051843878613518815, 0.008936860897977437, 0.06005446785794837, 0.02162148104980588, 0.04079618178574102, 0.07654623434479747, 0.020900783561436192, 0.05998099608612912, 0.0062418393957029495, 0.028967952555311576, 0.10354478989860841, 0.011091573446589922, 0.011186488621336008, 0.003473599724072431, 0.11712890490889549, 0.027498182940429876, 0.04626635129430464, 0.011681088063466762, 0.06245146066482578, 0.006574850388070834, 0.05000854656100273, 0.09395297137754303, 2.16185708131109, 33.13122040884835, 51.84366416931152, 29.00960806437901, 32.854949610573904, 35.64098269598824, 43.17871161869594, 51.697331632886616, 50.90864161082676, 27.753198317119054, 0.1937310573245798, 0.3098839031798499, 0.766451606793063, 0.06108470114746264, 14.406729340553284, 65.5846232005528, 50.79117883954729, 57.09619658333914, 45.052991662706646, 44.41482741492135, 41.12343794958932, 46.25382798058646, 44.65837219783238, 50.25987788609096, 47.831319195883616, 51.51244701657976, 49.43151365007673, 50.21392250061035, 49.34951795850481, 50.74447304861886, 48.08779805047171, 51.3707662991115, 46.64624834060669, 42.8336432320731, 38.1314046723502, 38.290375982012065, 35.950618743896484, 38.49483019965035, 36.247011525290354, 37.58084678649902, 36.95427908216204, 37.78268848146711, 37.023983410426546, 38.47050108228411, 37.270939758845735, 37.73318256650652, 37.3760347366333, 38.28751679829189, 37.79505280085972, 39.76837246758597, 36.68378571101597, 35.109574045453755, 37.527904987335205, 37.4189259665353, 34.80284581865583, 37.068163531167166, 36.61787509918213, 37.05915171759469, 36.866061278751914, 37.59810263769967, 36.2015494619097, 37.662064279828755, 36.726440702165874, 39.12412507193429, 36.243957792009624, 35.00421156202044, 35.83826984677996, 39.31743785313198, 41.54536036082676, 44.6752667427063, 45.985287053244456, 48.95607968739101, 50.404139859335764, 48.49521957124983, 48.567171641758506, 51.46601220539638, 47.046971797943115, 44.80660159247262, 39.4193297113691, 36.339853354862754, 35.69825669697353, 35.83722414289202, 35.31947565078735, 36.4870856830052, 34.854161739349365, 36.500888279506135, 36.83144187927246, 37.42449494770595, 36.9723721912929, 36.70176764896938, 35.828021253858296, 36.11122635432652, 37.15010016305106, 36.029998438698904, 36.11793484006609, 36.77311175210135, 35.97567047391619, 36.04999188014439, 34.67115313666207, 35.2910019329616, 33.81012889317104, 36.50590140478951, 36.01360763822283, 34.56833021981375, 33.697317940848215, 35.336054052625386, 34.746165888650076, 33.93678413118635, 35.06888192040579, 38.76642486027309, 44.024269172123496, 46.69363852909633, 45.27447591509138, 47.46480172021048, 45.43331868307931, 45.67734636579241, 46.14992461885725, 46.32807295663016, 45.730712005070274, 43.67354842594692, 43.18929025105068, 40.3580139705113, 40.100666591099326, 40.9069390296936, 40.598887171064106, 38.84056213923863, 43.10117667061942, 43.73460224696568, 45.78694377626692, 47.14082111631121, 46.3012945992606, 14.205528616905212, 0.4190926216542721, 2.0790000302450995, 0.12568778278572218, 0.14568419621459075, 0.8700242234127862, 0.5877277084759304, 23.126003776277813, 59.9086606161935, 37.159685203007285, 31.77844783238002, 19.92344876698085, 42.44203928538731, 32.8642532484872, 0.8104395121335983, 0.08319768921605178, 0.037250279914587736, 0.06967219963137593, 0.032989066426775286, 0.027596114203333855, 0.03758309794855969, 0.05406618597252028, 0.012169586627611091, 0.00832668149710766, 0.061167122796177864, 0.04301035350986889, 0.013755227971289839, 0.02517714025452733, 0.19055421065006936, 0.05694558325090578, 0.15906758021031106, 0.14549317503614084, 0.1320545854313033, 0.14365323233817304, 0.15272122861019202, 0.2049107359988349, 0.11564987498734679, 0.30161733818905695, 0.2027689537831715, 0.1028367793187499, 0.14187946037522384, 0.1259489237729992, 0.19783577349569115, 0.164379301613995, 0.21081489989800112, 1.7560987855706895, 37.03629214423043, 61.90776852199009, 40.629532200949534, 37.10667739595686, 37.57671955653599, 45.798373562949045, 56.179767404283794, 56.002991335732595, 32.30979742322649, 0.20479504577815533, 1.3583095307861055, 2.25859381045614, 0.21009512352091925, 15.463568585259573, 67.09805202484131, 53.10202809742519, 59.96191161019461, 47.1198410306658, 46.47726815087454, 42.52054350716727, 49.11421026502337, 47.159237316676546, 53.68301909310477, 50.87803827013288, 53.46436275754656, 49.331390108381, 49.94137593678066, 50.6092472076416, 54.01943349838257, 49.70242043903896, 54.076050894601, 48.815048626491, 45.00879417146955, 40.51099245888846, 41.16736446108137, 37.318455014910015, 40.97620562144688, 37.514776366097585, 39.23099184036255, 39.289599895477295, 39.74972002846854, 39.5602912902832, 41.28223555428641, 38.31213773999895, 39.83578041621617, 38.50039570672171, 38.48115267072405, 39.22993918827602, 42.68662282398769, 38.717523438589915, 36.97595746176583, 38.681705474853516, 38.920428207942415, 35.75931746619088, 39.80118186133248, 37.21691056660244, 39.93706430707659, 38.78620638166155, 39.34058230263846, 37.732755252293174, 40.953012534550254, 38.57955305916922, 41.86337941033499, 37.72806521824428, 37.831843512398855, 38.1972006389073, 39.904442514692036, 42.29905578068325, 45.97125169209072, 46.75908708572388, 51.67764391217913, 52.02335500717163, 49.39635576520647, 50.88798461641584, 53.21359879629952, 48.31891598020281, 47.92913940974644, 41.184536933898926, 38.12172583171299, 38.967651639665874, 40.37334517070225, 37.55446100234985, 36.995276927948, 36.15103258405413, 38.034619740077424, 38.93560307366507, 37.83312545503889, 38.734237330300466, 39.96686513083321, 37.678399494716096, 38.34400565283639, 39.17444740022932, 38.83324916022164, 37.97079011372158, 38.58153329576765, 36.89348234449114, 38.772455896650044, 36.11524588721139, 37.30750117983137, 36.966709409441265, 38.41906009401594, 38.067161628178184, 37.126201833997456, 36.026698044368196, 36.90920959200178, 36.4295129094805, 35.57083020891462, 36.41400800432478, 40.20287111827305, 45.56149557658604, 47.72674880708967, 48.48296642303467, 50.01816047940935, 48.08135707037789, 49.41225324358259, 47.014582770211355, 48.68553767885481, 47.62552397591727, 45.47668933868408, 45.62859433037894, 42.2311440876552, 41.408227239336284, 43.69365998676845, 42.705226625714985, 39.5136376108442, 44.91185985292707, 46.01921510696411, 47.43376064300537, 47.49220194135393, 46.24458687646048, 16.551986524036952, 0.9339411365134376, 4.512655224118914, 1.6048819912331445, 0.3522796668112278, 2.8977729294981276, 0.8615629460130418, 27.517803771155222, 63.28613131386893, 41.16529042380196, 34.28284958430699, 35.78211797986712, 51.59298358644758, 39.02714559010097, 1.394911881004061, 0.1870718060859612, 0.17370637612683432, 0.18469420580991677, 0.11860519354896885, 0.24861254383410725, 0.12405885090785367, 0.16034846433571406, 0.20038057837103093, 0.08509978572172777, 0.12983678015215055, 0.13710307595985277, 0.07131743670574256, 0.17821620484547956], [0.11022610709603343, 0.10900953451969794, 0.13180571235716343, 0.06077956394957645, 0.03526937835184591, 0.03051215237272637, 0.047689164589558325, 0.0496923322789371, 0.024480127030983567, 0.017202806725565876, 0.025327797081055384, 0.03553698238517557, 0.059766321176929135, 0.04636490172041314, 0.07230518691773925, 0.01625777198933065, 0.07169785057859761, 0.0831296050122806, 8.559997405324664, 51.92334611075265, 36.417357036045615, 29.87853240966797, 28.440408161708287, 32.237862723214285, 46.086154052189414, 45.027662004743306, 35.02403129850115, 0.026657807141808525, 0.2967515364289284, 0.1157307427908693, 0.007391006303285914, 2.3215792306831906, 54.019867760794504, 52.76518637793404, 52.98057358605521, 49.63743393761771, 43.378378527505056, 42.186564445495605, 42.84013979775565, 44.644333362579346, 49.16705478940691, 50.17803158078875, 47.12489237104143, 47.8902017048427, 46.70613486426217, 47.22518266950335, 47.67128481183733, 46.337074347904746, 43.65728964124407, 39.68480995723179, 36.30399022783552, 35.61321769441877, 35.198104517800466, 35.06935787200928, 35.26807982581002, 34.72269139971052, 36.71675491333008, 35.5489364351545, 35.588419573647634, 35.172719274248394, 37.09264898300171, 35.88895000730242, 35.31676932743618, 36.361712387629915, 35.06875685283116, 35.62940352303641, 38.366934708186555, 36.37114109311785, 35.185660294124055, 35.79385001318795, 33.43266453061785, 34.429612909044536, 35.198514461517334, 35.42495277949742, 36.057037353515625, 35.175404753003804, 35.48903948920113, 35.4507931300572, 35.39169522694179, 34.68855490003313, 35.13767950875418, 32.977977888924734, 32.962646688733784, 34.30294377463204, 36.85337386812483, 39.12733513968331, 40.31594957624163, 43.64692987714495, 46.08069624219622, 48.89838532039097, 49.36937591007778, 46.38470424924578, 47.20925392423357, 46.17427805491856, 40.30677795410156, 37.83498409816197, 35.31422628675188, 37.3063964162554, 36.1183135168893, 36.470875535692485, 36.225128173828125, 34.19817883627755, 33.217708110809326, 36.250193800245015, 34.99111073357718, 35.69294132505144, 34.7674377986363, 34.04676021848406, 35.7335570199149, 33.707160064152305, 34.3845260483878, 34.254883084978374, 34.459719453539165, 34.630870955330984, 32.82368966511318, 34.72392817905971, 34.08714314869472, 34.816971506391255, 34.95661987577166, 34.82502099445888, 33.404781409672324, 32.16693203789847, 31.743995189666748, 34.350806440625874, 32.988115310668945, 37.346650804792134, 41.06376682009016, 42.733231340135845, 44.198620319366455, 44.737786633627756, 43.91449110848563, 43.120162623269216, 41.911839621407644, 45.23431185313633, 43.57230275017874, 45.25419759750366, 43.478912012917654, 44.1007445199149, 41.22218574796404, 40.276261465890066, 40.51565817424229, 38.96628284454346, 39.13849742071969, 40.843019076756065, 42.00191606794085, 45.70380858012608, 46.63723305293492, 40.6585305077689, 5.750379962580545, 0.1484472993761301, 0.6227147653698921, 0.1526122558861971, 0.0422305471396872, 0.09330877023083822, 0.3116138960633959, 30.9187958581107, 50.652982643672395, 32.236903871808735, 21.802443163735525, 29.07244757243565, 42.307807036808555, 9.010865143367223, 0.09854397324046918, 0.09316599967756442, 0.03416706767997571, 0.0957934840449265, 0.03673820989206433, 0.02398574641639633, 0.05586246494203806, 0.04902312372412, 0.04048004214252744, 0.06797894941908972, 0.0474300795633878, 0.022329551001478518, 0.032657059242150614, 0.09205212337630135, 0.05034832975694111, 0.10961579877351012, 0.04672803669901831, 0.03309945050360901, 0.04345732827537826, 0.04317711366872702, 0.043200054937707524, 0.07297038193792105, 0.0061109796765127355, 0.04808797693944403, 0.022278844079534923, 0.05775357596576214, 0.03156470607167908, 0.05589350113379104, 0.107975820345538, 0.07045526296964713, 0.021039801816056882, 0.059184585964041095, 13.32376834324428, 57.653945854731965, 36.94145965576172, 29.597585473741802, 37.58849327904837, 36.856938294001985, 50.56742252622332, 50.276883602142334, 38.047835213797434, 0.017823308340406845, 0.3405975193849632, 0.18670117668807507, 0.13406348334891455, 2.5699612626007626, 56.928915228162495, 52.81642934254238, 55.656665325164795, 50.59091438565935, 45.68387072426932, 43.19670397894723, 45.2381785256522, 46.20290463311331, 52.22041981560843, 53.286294324057444, 48.37815632138933, 50.42728778294155, 48.53787803649902, 47.816130433763774, 50.40271200452532, 49.082807881491526, 46.650403363364084, 41.356779302869526, 38.012816292899, 37.509304659707205, 37.56947258540562, 36.34860808508736, 37.881450176239014, 35.46441159929548, 38.003818375723704, 38.308538573128835, 37.35135473523821, 36.87774814878191, 39.45628717967442, 38.195824895586284, 36.04908514022827, 36.58854675292969, 37.851548603602815, 37.476092270442415, 38.25552729197911, 38.16727474757603, 36.700621196201865, 37.72270120893206, 35.54160955974034, 36.45134762355259, 36.77725287846157, 36.25594343457903, 38.728334835597444, 36.250023569379536, 35.98922988346645, 37.49294512612479, 37.092193875994, 36.63545404161726, 36.38929673603603, 34.718974113464355, 33.79920285088675, 35.36396844046456, 38.28299699510847, 40.05746616636004, 41.306620257241384, 44.45473786762783, 48.38409355708531, 50.13554334640503, 52.299684865134104, 47.418696948460166, 48.44314282281058, 46.673005853380474, 42.62908479145595, 39.767212118421284, 37.625523703438894, 39.595904282161165, 37.78665937696184, 38.1118072782244, 37.34140144075666, 36.11690650667463, 36.695152963910786, 37.28479446683611, 34.910181590488975, 37.209215436662944, 37.6600284576416, 36.08516018731253, 37.534345967429026, 35.40737731116158, 35.87580748966762, 35.98391798564366, 35.73208400181362, 36.12765884399414, 34.635151045663015, 37.344847747257774, 35.364215101514546, 36.84003332683018, 36.99314383098057, 35.98840652193342, 36.24933917181832, 34.63030815124512, 34.001555238451274, 35.86858136313302, 35.04041167667934, 38.73776701518467, 42.47618620736258, 44.66899946757725, 46.13780696051461, 46.580737250191824, 46.16609307697841, 46.21113477434431, 44.24445063727242, 45.87674576895577, 45.776969637189595, 46.3560985156468, 46.329855169568745, 46.63086155482701, 42.922545433044434, 43.90091780253819, 42.55206053597586, 40.786783831460134, 39.096384389059885, 43.32999127251761, 43.228818552834646, 47.76225062779018, 45.92585563659668, 42.05239473070417, 6.235495371477945, 0.40861278399825096, 2.3837525801999226, 0.2545908987522125, 0.08455197725977216, 0.8507583343556949, 0.5421392747334072, 34.028757435934885, 54.646473680223735, 39.1257301058088, 32.57519429070609, 24.726344142641338, 48.85813788005284, 12.173483644212995, 0.11550681266401495, 0.06556715776345559, 0.018018100477222885, 0.05608573349724923, 0.02591678752963032, 0.024197064273591553, 0.04679364085729633, 0.024084493617660234, 0.048560732642986944, 0.04250496366460409, 0.01840643963909575, 0.04076396833573069, 0.0055488973822710765, 0.030963347626051733, 0.15899233067674295, 0.21797320007213525, 0.28441549837589264, 0.13487235137394496, 0.09645553744797196, 0.16398359356181963, 0.20396415250641958, 0.11480963150305407, 0.15783190008785042, 0.09820924513041973, 0.13146629557013512, 0.08506476652941533, 0.20535428076982498, 0.11689261187400136, 0.22333537733980588, 0.16449444900665963, 0.15683486073144845, 0.22342288121581078, 14.445079922676086, 66.41927555629185, 43.98765563964844, 40.065637247903005, 38.411938190460205, 42.32649074281965, 53.40481322152274, 55.18685940333775, 40.317078658512656, 0.27435741094606264, 0.9385510491473334, 0.5211399186934743, 0.41173480504325455, 2.9017410022871832, 58.121757643563406, 53.97562510626656, 57.26475988115583, 53.969316141945974, 48.430528368268696, 44.27446338108608, 47.3947708266122, 49.419142382485525, 53.52573619570051, 55.043591022491455, 49.49828583853585, 51.32916396004813, 49.86372981752668, 49.116680349622456, 50.83394500187465, 50.74903106689453, 47.67979635511126, 42.70295109067644, 41.2999221937997, 39.97555385317121, 39.58753865105765, 39.78423867906843, 40.8684355872018, 39.359693322862896, 41.53322533198765, 41.034848417554585, 40.598883696964805, 37.67036042894636, 40.98715598242623, 39.21303769520351, 38.546507426670615, 40.26905270985195, 39.34061704363142, 38.802076067243306, 41.838358947208945, 40.195551191057476, 38.860249859946116, 40.020008427756174, 36.81654494149344, 38.222776957920615, 38.45237670625959, 38.23574229649135, 39.91931165967669, 36.93046760559082, 38.923593112400596, 40.179327147347585, 39.174099990299766, 39.141968045915874, 37.92854159218924, 37.46366889136178, 36.43194825308663, 37.06116669518607, 40.9130916595459, 42.76466499056135, 42.75278009687151, 46.511098929813926, 50.27856854030064, 52.19954742704119, 53.07946729660034, 49.378505843026296, 49.54361241204398, 48.94389254706246, 44.69746276310512, 42.21493394034249, 38.63215439660208, 41.65999868937901, 40.61323172705514, 38.65541001728603, 39.63444593974522, 38.10638420922415, 37.908617632729666, 38.999912125723704, 37.48424598148891, 39.15237297330584, 37.63073485238211, 38.21918821334839, 39.16075944900513, 36.20030920846121, 38.95498159953526, 37.91469035829817, 37.591609546116416, 38.41543313435146, 36.0855701310294, 38.789562361580984, 37.97234998430525, 38.43926892961775, 39.28143923623221, 38.83493757247925, 38.83226599012102, 37.17949799128941, 35.71826750891549, 37.90002965927124, 36.66143683024815, 41.51439571380615, 44.36669724328177, 46.24651847566877, 48.90660503932408, 48.2433716910226, 47.805016790117534, 46.617371627262656, 44.208156721932546, 46.93942410605294, 46.673513071877615, 46.29770238058907, 47.76913629259382, 48.0760486466544, 44.82130398069109, 46.27392911911011, 44.611506598336355, 42.670186860220774, 42.84290518079485, 45.13109636306763, 46.151258672986714, 49.80508007322039, 48.46053416388375, 43.89121811730521, 7.911542875426156, 1.0048129792724336, 4.132189674036844, 0.40549868824226515, 0.3012653685041836, 2.1509507979665483, 1.351653156535966, 38.88427325657436, 59.3717941556658, 43.73768029894148, 32.08402265821184, 37.6375857761928, 54.92653819492885, 16.815602915627615, 0.22978287136980466, 0.18332893906959466, 0.153072058356234, 0.20604272239974566, 0.17920480322624954, 0.129859755347882, 0.21557809359260968, 0.21505909572754586, 0.15742442623845168, 0.12325632039989744, 0.14438253534691675, 0.15209232164280756, 0.12570239843002387, 0.13187809847295284], [0.06429208189781223, 0.050412247755697796, 0.06562934549791472, 0.03167892387136817, 0.046194799776588163, 0.0508865640897836, 0.02016845259017178, 0.03420259577355214, 0.04084929072165063, 0.04228702839463949, 0.022899218469059894, 0.01063552581971245, 0.029946929309517145, 0.027023732595677887, 0.053959259031606574, 0.06159250318471875, 0.10920903738588095, 0.06374567800334521, 1.2624814957380295, 29.580284459250315, 45.517131328582764, 27.404381377356394, 26.627206257411412, 29.088134867804392, 44.09096493039812, 45.74166931424822, 40.52478115899222, 0.7713461784379823, 0.4398166281836373, 0.1215495876967907, 0.10074396697538239, 0.05899718816259077, 29.454428264072963, 60.80035768236433, 49.1672945022583, 53.180587904793875, 45.477217401777, 43.13796738215855, 40.514615944453645, 44.92687143598284, 46.59817028045654, 51.58953727994646, 47.10427706582205, 47.44922733306885, 47.24539497920445, 48.04618876320975, 49.31308160509382, 45.91471767425537, 43.177207333701, 38.30316761561802, 34.86887107576643, 36.43565859113421, 34.87708732060024, 35.89800351006644, 35.55579778126308, 35.67501149858747, 35.55108690261841, 36.71473298754011, 33.59524890354702, 35.47920083999634, 34.958221435546875, 35.99169649396624, 35.249194622039795, 36.98718227658953, 35.393043177468435, 36.60744932719639, 35.815792424338206, 36.84449407032558, 36.40405123574393, 37.13061741420201, 33.401060649326865, 35.05049351283482, 35.088427203042166, 34.85775048392159, 35.37895917892456, 34.80841479982649, 34.17922067642212, 33.95433528082711, 34.24368953704834, 35.78527593612671, 33.855184486934114, 32.90555681501116, 33.372934341430664, 33.07002762385777, 34.57754700524466, 36.608894552503315, 38.32696866989136, 44.40188292094639, 48.850300312042236, 47.02011701038906, 46.911019870213096, 50.07962424414498, 49.453966753823416, 45.41161251068115, 39.13218150820051, 40.56661626270839, 39.56279958997454, 38.971792766026084, 37.55557271412441, 38.88060113361904, 36.94544792175293, 35.89609622955322, 34.810019833701, 35.006070205143516, 33.15571280888149, 35.740863050733296, 34.125347818647114, 34.82330478940691, 35.02570928846087, 35.10381398882185, 35.582110609327046, 33.15570586068289, 34.3309519631522, 33.80249629701887, 34.03054312297276, 33.688698700496126, 32.765904971531455, 35.12026037488665, 35.24323306764875, 34.47842747824532, 33.95990078789847, 34.661543778010774, 33.4049516405378, 32.98300838470459, 35.73712144579206, 39.47795513698033, 42.66543776648385, 43.151957580021445, 45.171739850725444, 44.39870759419033, 44.14129073279244, 44.65890373502459, 42.77404505865914, 44.94295998982021, 43.20108829225813, 42.992492948259624, 43.74914135251726, 42.93284266335623, 44.75425386428833, 42.7624763080052, 40.41899830954415, 41.0110821042742, 39.44155699866158, 41.51848125457764, 43.5209972517831, 46.70474522454398, 44.107439109257285, 26.40173373903547, 0.7458650171756744, 0.08088533686740057, 1.0577229687145777, 0.17553073966077395, 0.030080963724425862, 0.20195323255445274, 0.7183248549699783, 37.780683926173616, 46.437583514622276, 29.07611448424203, 20.34458950587681, 30.84314387185233, 36.19826296397618, 0.44977505238992826, 0.09155015674020563, 0.033936226673956425, 0.08557890608374562, 0.03383791373510446, 0.024757897215230123, 0.0047503252779798845, 0.06516755492027317, 0.028940451531005756, 0.06422968381749732, 0.032193504473460574, 0.035465128919375796, 0.056188847071358135, 0.019775952312297056, 0.0744392949023417, 0.053996093305093903, 0.04800748572285686, 0.07154420310897486, 0.03211875705580626, 0.05983236977564437, 0.029586304910480976, 0.033147945401391814, 0.03972482927409666, 0.15582250005432538, 0.04403694306633302, 0.029241697330560004, 0.049988668877631426, 0.025040585082024336, 0.021919030529846038, 0.05970701721629926, 0.03564759377124054, 0.1417371580111129, 0.08628982079348393, 2.7042365031582967, 38.687312671116416, 48.920324257441926, 28.85390067100525, 33.60349294117519, 35.53897966657366, 48.38237040383475, 50.096487522125244, 43.619950022016255, 0.6859430468508175, 0.48742036521434784, 0.05345011688768864, 0.11370842345058918, 0.05022121639922261, 31.341916833605083, 62.973358154296875, 51.42777974264962, 55.779314926692415, 45.812290804726736, 43.71386187417166, 43.32911579949515, 46.27177517754691, 49.00488036019461, 52.47830220631191, 48.716620445251465, 51.15772410801479, 48.18870326450893, 49.547135148729595, 50.90581716809954, 49.26495838165283, 43.83075141906738, 39.576105390276226, 36.779504094805034, 39.03559807368687, 36.8151935168675, 37.68745994567871, 36.6488710130964, 37.96804557527815, 36.44522278649466, 38.338843141283306, 35.88084493364607, 38.414606298719136, 36.76502404894148, 37.6916948727199, 37.40649216515677, 38.30976145608084, 37.789198943546836, 37.10689973831177, 37.62119844981602, 38.49341971533639, 37.826073033469065, 38.469889640808105, 36.194239956992014, 36.75435161590576, 37.4066276550293, 37.00855493545532, 36.85957513536726, 36.76273809160505, 36.45374475206648, 37.03600031988961, 36.003963538578574, 36.88158355440412, 35.86807761873518, 34.86019624982561, 35.30913325718471, 35.936805725097656, 36.29735469818115, 37.50180407932827, 41.52115283693586, 46.245191369737896, 48.26670026779175, 49.15735510417393, 47.594375201633994, 50.02863488878523, 50.406884397779194, 46.744593143463135, 40.967704500470845, 40.88271760940552, 40.883916173662456, 39.50239542552403, 39.46791499001639, 38.75539459500994, 39.22831678390503, 37.22928530829293, 35.11393404006958, 36.85861280986241, 35.22056456974575, 38.0491623197283, 34.51055942262922, 36.20566626957485, 36.908021450042725, 36.33948162623814, 36.75473724092756, 35.38042524882725, 35.428551946367534, 35.8028826713562, 36.164494718824116, 35.26981340135847, 35.09168938228062, 36.31651088169643, 35.40427841459002, 36.45022201538086, 35.515112604413716, 36.47445733206612, 34.795953205653596, 35.64264678955078, 36.16918475287301, 41.082294191632954, 44.70382036481585, 46.60686247689383, 45.48454775129046, 45.9594258580889, 44.652907439640586, 45.42926788330078, 43.7186005456107, 45.329318046569824, 44.62001814161028, 45.242948463984895, 45.13746786117554, 45.73311260768345, 46.1952338218689, 43.284557001931326, 41.597739355904714, 43.13402427945818, 40.19636413029262, 44.51444026402065, 45.60182639530727, 47.76597138813564, 45.549666268484934, 28.50173122542245, 1.744125953742436, 1.16225394819464, 3.204807311296463, 0.5771480990307671, 0.04278600269130298, 0.47808730602264404, 0.6110164416687829, 43.642201628003804, 50.47995512826102, 38.82988623210362, 20.596456493650162, 28.89959028788975, 43.929384572165354, 1.4889210079397475, 0.16294501429157598, 0.02994722786492535, 0.03954244923910924, 0.05757434094058616, 0.02378622319416276, 0.05001395448510136, 0.02414152448597763, 0.02074186726739364, 0.012840863017897521, 0.04557064255433423, 0.054745799861848354, 0.016643668425136378, 0.012954936628895146, 0.0682833402284554, 0.10427346865513495, 0.13376115528600557, 0.21722466738096305, 0.13998001015612058, 0.23400015650050981, 0.09914626806442227, 0.1931114462869508, 0.19151591190270015, 0.27991257714373724, 0.1905159412750176, 0.06735780489231859, 0.1803954421941723, 0.13865768111177854, 0.058839455912155766, 0.2217448776853936, 0.12056700113628592, 0.2584548571280071, 0.19143067433365754, 2.3696942031383514, 43.358371189662385, 56.598375524793354, 37.10927602222988, 36.00516210283552, 39.6969484601702, 52.45233678817749, 54.37430231911795, 49.14671393803188, 1.1745860236031669, 1.060740549649511, 0.6106156717453683, 0.23651279881596565, 0.2048189980643136, 32.495745113917756, 64.72383172171456, 53.334306376320974, 59.07190295628139, 48.66990423202515, 45.79619182859148, 44.691410882132395, 47.49133341653006, 50.89014203207833, 54.61672496795654, 50.211414200919016, 53.46924386705671, 50.24482461384365, 51.530293464660645, 52.67625985826765, 50.31830528804234, 47.00062036514282, 43.01253155299595, 38.72382892881121, 41.58247068950108, 39.796384130205425, 40.49814523969378, 40.505492959703716, 40.71773958206177, 39.11140292031424, 40.954172883714946, 37.579637799944194, 40.74729027066912, 38.77220923560006, 38.41438743046352, 38.787755829947336, 40.943719318934846, 39.49128525597708, 39.90851068496704, 39.24197694233486, 39.84977756227766, 39.60344655173165, 41.160096645355225, 36.364463874271934, 39.22184106281826, 40.47548368998936, 38.57205247879028, 38.62925699778965, 38.40684516089303, 38.23329305648804, 37.82017748696463, 37.67334468024117, 39.938089166368755, 37.77846050262451, 36.43936892918178, 37.663082190922324, 37.15410927363804, 37.712803500039236, 39.84881523677281, 43.631647314344136, 48.09055648531233, 52.158108370644705, 48.85257237298148, 48.08059624263218, 50.71808726446969, 51.57300056729998, 48.01697506223406, 41.67649718693325, 43.68344266074044, 44.0551678112575, 41.97286217553275, 40.14700412750244, 41.369810649326865, 41.45906720842634, 38.93439756120954, 36.83984225136893, 38.71715865816389, 36.476020676749094, 40.570225851876394, 36.8643867628915, 38.68047216960362, 38.87429564339774, 38.701334135872976, 39.88133628027779, 35.612112930842805, 36.64375713893345, 38.17638036182949, 37.90754413604736, 37.78703110558646, 35.734404700142996, 38.185294900621685, 36.99122265407017, 38.3613657270159, 37.81953477859497, 38.92297124862671, 37.81741905212402, 36.77690894263131, 38.988610880715505, 43.194654260362896, 46.01504271371024, 48.50216776984078, 48.26713800430298, 47.2013190814427, 47.743928228105815, 47.43173524311611, 45.71679823739188, 47.35630907331194, 45.50935629435948, 46.57423026221139, 45.94265290669033, 47.46930067879813, 48.5221403666905, 45.076889991760254, 44.73395470210484, 45.662234033857075, 43.14547143663679, 47.269480909620015, 48.593289920261924, 51.10802016939436, 46.524613176073345, 30.978428772517614, 1.9276079024587358, 1.9772404049124037, 6.982037620885031, 0.5016566812992096, 0.11012936835842473, 0.8328762767570359, 2.186369674546378, 47.406871114458355, 56.48876421792166, 37.5870167868478, 29.72442136492048, 38.26340307508196, 51.56604889460972, 2.8321109328951155, 0.30949081427284647, 0.11201584498797144, 0.17000143921801023, 0.20964172642145837, 0.15033440025789396, 0.1748309936374426, 0.14036497021360056, 0.101989397646061, 0.13184024978961262, 0.2017398061496871, 0.09610645832227808, 0.20983709022402763, 0.15241556215499127, 0.1567443034478596], [0.029160130635968277, 0.053968744951167276, 0.06348197893904788, 0.044256625563970635, 0.045529248525521586, 0.058829033614269326, 0.011462159587868621, 0.04954647778400353, 0.026399875625169704, 0.0249328167576875, 0.09587836877575942, 0.05648453566910965, 0.061599512451461384, 0.03503741776304586, 0.05740889374698911, 0.024110206702191914, 0.054247202152120214, 0.03706256320167865, 0.13252702222338744, 7.608028190476554, 45.2468707220895, 33.55641542162214, 30.46968514578683, 32.16713353565761, 36.119164671216694, 43.676536151341026, 41.7598477772304, 1.1329732622419084, 0.15592694016439573, 0.17673604855579989, 0.2250505510185446, 0.1757160068622657, 5.910450390407017, 53.51303488867623, 52.52810689381191, 52.09963927950178, 48.07318251473563, 47.67942462648664, 41.68249348231724, 45.40578644616263, 46.18913330350603, 47.21019540514265, 49.97949028015137, 47.86280148369925, 45.48498548780169, 47.68231507710048, 48.462410177503315, 48.759754862104145, 44.647616386413574, 38.78786352702549, 35.115549496241975, 37.39746298108782, 36.51497575214931, 35.561425822121755, 34.05482360294887, 35.75844546726772, 34.304312569754465, 35.48336975915091, 35.69610275541033, 35.20630686623709, 35.08068690981184, 35.738709109170095, 36.46353823798043, 36.974203041621614, 33.61551679883684, 37.17622191565377, 36.93910074234009, 37.49598148890904, 34.59807893208095, 35.18861327852522, 35.59596184321812, 36.02253607341221, 36.29660776683262, 37.53022568566458, 35.214797564915244, 36.333328996385845, 34.70047800881522, 35.33757223401751, 34.98271036148071, 33.31314161845616, 35.690481662750244, 34.7682785306658, 32.98533255713326, 34.92322335924421, 34.99356344767979, 35.889745576041086, 39.66011953353882, 44.193516867501394, 46.51349605832781, 52.08155311856951, 50.155898094177246, 47.21158504486084, 49.05257626942226, 46.088144711085725, 40.90362821306501, 40.03085456575666, 39.08217184884207, 41.47979368482317, 38.84060730252947, 39.93163081577846, 39.4584550176348, 36.66241652624947, 34.43326766150338, 35.20964894975935, 35.14562129974365, 34.453650202069966, 36.30092259815761, 34.86151988165719, 35.271491391318186, 35.5195802961077, 35.472141470227925, 33.89768314361572, 34.4201842035566, 33.97879293986729, 33.604799202510286, 35.18222093582153, 34.060708727155415, 34.12157147271292, 33.48813894816807, 32.58697148731777, 34.21749830245972, 33.024506500789094, 33.77086809703282, 33.48420279366629, 37.64768845694405, 41.89233602796282, 43.40841906411307, 44.44338798522949, 42.59684862409319, 43.90463161468506, 43.469410351344514, 42.6688597542899, 42.60857718331473, 45.390639373234336, 44.604919706072124, 45.77307169778006, 44.02645090648106, 43.42183950969151, 42.868891443525044, 42.75251953942435, 40.59301246915545, 38.80281605039324, 40.95434658867972, 41.43456438609532, 43.83985355922154, 46.674697739737375, 41.0049398967198, 12.307468363216945, 0.0462322854436934, 0.7415313497185707, 1.2851177496569497, 0.48490072041749954, 0.04442193026521376, 0.3843536914459297, 3.2400794071810584, 50.86078936713082, 38.57393544060843, 25.742768321718486, 29.67068747111729, 41.7208058493478, 19.378847224371775, 0.037662065854029994, 0.08285054391516106, 0.07624001827623163, 0.03318969905376434, 0.03300516806276781, 0.03591191030240484, 0.0417705852139209, 0.05072161901210036, 0.0415414100113724, 0.029639220463910272, 0.0071271740764911684, 0.03561451179640634, 0.020710291640300835, 0.04638136297996555, 0.013096958249142128, 0.05226380018783467, 0.02424986956508032, 0.025114543702719466, 0.01953486373115863, 0.06295259270284857, 0.049740006149347336, 0.07962481557790722, 0.058407005188720565, 0.035073088348976204, 0.021635916882327626, 0.03240668660561953, 0.03981846371399505, 0.026706831296905875, 0.026957592394735132, 0.018541883710505705, 0.09412350758377995, 0.04770910334108131, 0.019438908701496463, 0.09722063317894936, 12.404561621802193, 55.64179270608084, 32.938147340502056, 30.889168739318848, 40.481816973005024, 42.24658645902361, 47.97300338745117, 46.12191295623779, 0.9646078795194626, 0.3391513984118189, 0.4919741494315011, 0.33117581637842314, 0.2691107881920678, 6.717706433364323, 57.09079088483538, 52.28734139033726, 54.5282153402056, 49.85182407924107, 48.134896414620535, 42.17963014330183, 47.75075135912214, 46.37903799329485, 51.47049726758684, 51.46812793186733, 50.08590888977051, 46.66072838647025, 49.748351505824495, 49.878275871276855, 51.24964182717459, 45.59206765038626, 38.34356444222586, 37.0114175932748, 38.57138892582485, 37.12690707615444, 36.08497258595058, 37.02477897916521, 37.53486360822405, 34.76893860953194, 38.907111985342844, 37.27973617826189, 37.59664699009487, 38.14440475191389, 37.8049122946603, 37.11033909661429, 38.42203739711216, 35.72634826387678, 39.38739579064505, 38.39762142726353, 38.72717101233346, 36.31144911902291, 36.63683673313686, 37.198556900024414, 37.48673691068377, 38.71602610179356, 37.526567459106445, 36.77682556424822, 37.81657484599522, 37.115918500082834, 36.1787246295384, 35.68472508021763, 36.810017108917236, 36.690709590911865, 36.43541193008423, 35.58544921875, 36.2817942074367, 35.20786673682076, 37.94320229121617, 41.31855378832136, 45.243205547332764, 50.37980031967163, 51.6889660017831, 54.20725720269339, 49.97465433393206, 51.075242042541504, 47.3129106249128, 42.65563038417271, 40.99131795338222, 40.7752046585083, 43.2685136113848, 40.574651854378835, 41.431191035679404, 40.106687205178396, 39.00391428811209, 35.25301265716553, 37.65681838989258, 36.650663648332866, 36.79855258124215, 37.31456749779837, 36.72692012786865, 36.55148506164551, 38.21946961539132, 36.26426042829241, 36.23461593900408, 35.90874889918736, 35.850717544555664, 35.976851667676655, 35.5307217325483, 35.9242399079459, 35.02950995309012, 35.86732373918806, 33.75856978552682, 34.76585013525826, 36.20768819536482, 34.65700313023159, 34.360700675419395, 38.33643559047154, 43.08391039712088, 44.575584411621094, 45.54713017599923, 43.60273586000715, 45.59222051075527, 45.295188495091026, 44.13866778782436, 45.15595701762608, 45.99513265064785, 45.91147633961269, 47.47376489639282, 46.28011301585606, 44.29441860743931, 44.68863507679531, 43.26592888150896, 42.430553913116455, 40.83965962273734, 42.98251186098371, 42.0944903918675, 45.50058419363839, 47.770776067461284, 42.84023012433733, 13.529840622629438, 0.41247125981109484, 1.9539031428950173, 3.1883237957954407, 1.3740808559315545, 0.0587725659300174, 0.6112129996929849, 3.4759829086916785, 55.76536989212036, 44.88617236273629, 33.619505064828054, 23.57297965458461, 44.43560252870832, 26.580587318965367, 0.10140044282057456, 0.026593756828723208, 0.04234946718705552, 0.027772472240030766, 0.014918942669672626, 0.01775144978559443, 0.05741839323725019, 0.030790372086422782, 0.0028124222673276173, 0.05752726418099233, 0.02345736271568707, 0.03407210670411587, 0.029552941343614032, 0.06624531280249357, 0.04050834383815527, 0.1538399700075388, 0.15980639628001622, 0.15141295881143638, 0.13881990526403698, 0.12709707287805422, 0.16883860661515168, 0.14548702750887188, 0.13311364288840974, 0.06666468815611941, 0.09534027014992066, 0.2665149032005242, 0.1923128105700016, 0.1321028292711292, 0.18177365538265022, 0.21869537846318313, 0.18223490991762706, 0.11035796680620738, 0.12380620517901011, 0.14077990794820444, 13.33300163064684, 62.70740195683071, 42.96493986674717, 41.364297253744944, 42.11747850690569, 46.31011186327253, 50.38245105743408, 53.13007797513689, 1.4894826178039824, 0.4975772202014923, 1.2323686544384276, 1.0644177751881736, 0.33135204549346653, 6.728187790938786, 56.560396671295166, 55.07679646355765, 54.585152353559224, 51.94438178198678, 51.34813254220145, 44.335875034332275, 50.66755649021694, 49.253702299935476, 51.43508924756731, 52.49166359220232, 52.32545573370797, 49.460053375789094, 51.007549217769075, 52.59340606416975, 52.85236889975411, 46.732795102255686, 42.78284495217459, 39.75059897559029, 42.358744280678884, 39.93684196472168, 39.353391306740896, 39.13577025277274, 39.954097815922324, 36.250773974827354, 40.086836201804026, 39.16607829502651, 39.71013961519514, 40.09351689474923, 38.63580914906093, 40.09514972141811, 40.60796846662249, 36.89654302597046, 40.77446467535836, 40.68568059376308, 41.47835888181414, 37.9389499936785, 39.466806752341135, 40.111231327056885, 37.941604205540244, 39.41091891697475, 41.45742048536028, 38.611000605991904, 39.3522379057748, 38.63451678412301, 39.77824585778372, 38.37018993922642, 38.17311470849173, 39.194364411490305, 38.76673058101109, 37.56742286682129, 38.64251068660191, 38.453373772757395, 39.88437959126064, 44.17728934969221, 47.27312871388027, 51.10371923446655, 55.30046592439924, 53.618136814662385, 50.27279806137085, 53.64037105015346, 50.72775568280901, 44.58683007104056, 42.06534269877842, 43.005468709128245, 44.52480002811977, 42.69651358468192, 43.5802514893668, 42.765467507498606, 40.82909836087908, 37.18790878568377, 40.05888359887259, 38.283969742911204, 38.263938086373464, 40.14800466809954, 38.10936498641968, 39.425364221845356, 40.30778891699654, 37.98943907873971, 38.354945591517854, 37.8231269972665, 38.163797174181255, 36.525363309042795, 38.76430218560355, 36.88109023230416, 36.73874943596976, 37.28974158423287, 35.82024621963501, 37.85350104740688, 38.288326263427734, 36.955442905426025, 36.144657611846924, 40.22072798865182, 44.27493585859026, 48.59251172201974, 47.66401699611119, 47.39964846202305, 47.373266151973176, 47.57119253703526, 45.89455052784511, 46.35288149969918, 47.4232862336295, 48.68848718915667, 48.91831622804914, 47.869496073041645, 45.03178923470633, 46.73398324421474, 44.46506983893258, 44.21661267961775, 42.3080015863691, 45.692976338522776, 44.64838068825858, 48.33918040139334, 49.65669781821114, 43.70377656391689, 14.603228739329747, 0.4151564400110926, 2.8581612493310655, 4.069308042526245, 1.8324052052838462, 0.15052607282996178, 1.2611767543213708, 5.239845437662942, 59.63795185089111, 46.10189867019653, 36.54853902544294, 39.069404533931184, 51.39514057976859, 31.434341771262034, 0.14483833446034364, 0.13651204481720924, 0.23298623519284384, 0.13204522164804594, 0.10839826946279832, 0.13695702808243887, 0.09268720501235553, 0.08553716939474855, 0.042684660093592744, 0.10598934122494288, 0.10099477387432541, 0.12373977660068444, 0.13599269411393575, 0.1317992527037859, 0.1474677390818085], [0.03682528968368258, 0.0364332932180592, 0.12781785348696367, 0.04101398813405207, 0.054769636797053475, 0.03601343949724521, 0.029195774080497876, 0.03092883394232818, 0.008643975498021712, 0.0045428564106779435, 0.03913739775972707, 0.013570322937864279, 0.04059471456067903, 0.012574763635971715, 0.07410348113626242, 0.08922416583767959, 0.009346059074492326, 0.04130154109692999, 0.031123444571026733, 0.15760714214827332, 28.526532820292882, 40.571702344076975, 26.199518578393118, 25.549163716179983, 29.22612088067191, 41.091316427503315, 51.01855863843645, 6.916202570710864, 0.5491838795798165, 0.22199506711746964, 0.1653989768986191, 0.04179903957992792, 0.038485990571124215, 23.868861743382045, 57.90944848741804, 51.94854375294277, 50.26579080309187, 45.824526582445415, 45.167084557669504, 41.14000245503017, 46.10348285947527, 47.59090110233852, 50.7833308492388, 49.856055532182964, 45.94885417393276, 47.493369238717214, 48.79158108575003, 48.03220203944615, 44.49805988584246, 38.4190114566258, 35.312607356480186, 36.34417860848563, 35.15133966718401, 35.94938543864659, 33.88881376811436, 36.25752762385777, 35.06813151495797, 35.40397616795131, 37.11821140561785, 35.244838101523264, 35.426682880946565, 36.42521892275129, 37.078693526131765, 36.57855176925659, 36.56176144736153, 38.112648010253906, 36.00843817847115, 38.11255420957293, 36.88876799174717, 35.179393018995015, 35.24349362509591, 37.79063374655587, 36.1073214667184, 35.94566467830113, 34.41366679327828, 35.02303075790405, 35.014456680842805, 36.07499844687325, 36.89367341995239, 34.77968747275216, 36.05903843470982, 35.05538157054356, 34.84300293241228, 36.043095793042866, 34.42545441218785, 36.32432065691267, 40.692045143672395, 44.92018379483904, 49.359620639256065, 46.153513363429475, 48.88834864752633, 50.98809078761509, 48.771528584616526, 45.56428875241961, 41.34404672895159, 40.95753581183297, 41.10060269492013, 43.998981203351704, 44.420399870191304, 40.650557449885774, 41.91006783076695, 37.31552634920393, 35.954759870256694, 33.71179451261248, 35.06970875603812, 35.73938308443342, 33.90568399429321, 35.00178664071219, 34.98269993918282, 35.560699735369, 34.261324065072195, 34.296509742736816, 34.130433900015696, 32.977602686200825, 34.36465072631836, 34.13371344975063, 33.76806102480207, 32.872049127306255, 32.937855516161235, 34.18896552494594, 32.769945349012104, 33.50079509190151, 32.51120138168335, 33.882317202431814, 38.929228101457866, 41.712089334215435, 43.74674422400338, 45.22824954986572, 45.096786158425466, 42.031567505427766, 43.89392096655709, 43.26754781178066, 42.62640973499843, 43.43181364876883, 42.735461711883545, 43.58852331978934, 40.42110013961792, 42.31484208788191, 41.37876687731062, 41.375178132738384, 39.32749537059239, 39.25390699931553, 40.92723471777779, 43.29186303274972, 43.73358086177281, 43.029839515686035, 30.066804272787913, 3.087321306977953, 0.4481773195522172, 1.0798707859856742, 1.447863125375339, 0.8830837426441056, 0.1116404454889042, 0.5911547445825168, 16.183714628219604, 54.78928347996303, 30.179062843322754, 27.596771785191127, 24.504123381205968, 39.87589236668178, 5.048742183617183, 0.24267346252288136, 0.12448806501924992, 0.058811988814600875, 0.02208527669842754, 0.05920852467949901, 0.08722771225231034, 0.013938613086273628, 0.017356669630057046, 0.008551994139062507, 0.041534387173929384, 0.05074405137981687, 0.03144721434052501, 0.06746569196028368, 0.043363317248544524, 0.022700448420697024, 0.041519276199064085, 0.04054280663175242, 0.09349982533603907, 0.07557761203497648, 0.03457589859941176, 0.022179029881954193, 0.052023697178810835, 0.05617450284106391, 0.035901891732854505, 0.07257518278700964, 0.05887960482920919, 0.04195906527872596, 0.042631323848451884, 0.009696440987421997, 0.026555753778666258, 0.09562565519341401, 0.04229873312371118, 0.027440882354442562, 0.0048178255175506425, 0.8025473356246948, 37.538494041987825, 44.534433705466135, 25.931526558739797, 34.43543202536446, 36.08298887525286, 45.37310559409005, 54.428216866084504, 5.431966602802277, 0.6964168048330716, 0.4295752005917685, 0.6118724271655083, 0.05115863966888615, 0.04664612395156707, 27.35580825805664, 58.62267412458147, 53.536245346069336, 52.94771555491856, 49.96077878134591, 46.5187280518668, 44.46475716999599, 48.3757974079677, 48.74573687144688, 51.499276706150596, 52.39799492699759, 47.08168499810355, 48.529345648629324, 50.43355853216988, 49.82628597532, 46.93065200533186, 40.12925842830113, 37.76449809755598, 37.63132197516305, 37.481418064662385, 36.26923186438424, 34.4330210004534, 37.20684610094343, 36.6489509173802, 36.33629240308489, 38.08749205725533, 36.789210728236604, 37.28184495653425, 38.15895080566406, 38.40018878664289, 40.338458265577046, 37.30222749710083, 38.61755623136248, 38.08876357759748, 39.40576335362026, 38.300468240465435, 37.902315616607666, 35.473923683166504, 38.059977190835134, 38.16353661673409, 38.31529917035784, 37.341721057891846, 38.0606233733041, 35.843144008091514, 36.976933683667866, 38.516710077013286, 37.928656237465994, 36.48936469214303, 37.500240734645296, 34.89684452329363, 36.74619443075997, 36.50804492405483, 38.364843300410676, 41.86799301419939, 45.841066769191194, 49.711890833718435, 49.45147582462856, 50.03436367852347, 52.335829394204275, 49.99632576533726, 47.962494237082346, 42.31373037610735, 42.12382221221924, 42.94093384061541, 44.597974981580464, 44.56391143798828, 42.66502087456839, 43.157224314553396, 38.233709948403494, 37.223931721278596, 36.22205012185233, 36.0345321382795, 37.87389748437064, 35.17467171805245, 36.73391348975045, 36.366416318076, 36.90884828567505, 36.41100638253348, 34.93922506059919, 36.555049487522666, 34.50355216435024, 35.208658831460134, 35.18066801343645, 35.584862095969065, 33.87360416139875, 33.88992895398821, 34.90495654514858, 34.7859651701791, 34.451280866350444, 35.52125481196812, 36.09874391555786, 40.83326033183506, 43.19510241917202, 44.26164048058646, 45.00949246542794, 46.778441292899, 45.04675565447126, 46.62390988213675, 44.857184478214805, 45.22909723009382, 44.14737388065883, 44.86679383686611, 44.89516680581229, 42.803779874529155, 44.702472414289204, 42.61680037634713, 43.26194756371634, 41.00127819606236, 41.695479665483745, 44.46356555393764, 45.06120790754046, 46.516535895211355, 44.620091097695486, 31.99018723624093, 3.75424154315676, 0.8782526818769318, 4.533036461898258, 6.654041826725006, 4.332684287003108, 0.14333826995321683, 0.7779864306960786, 17.93285240445818, 59.44252681732178, 36.07368523733956, 32.90812070029122, 22.947315216064453, 46.481482233319966, 6.529745936393738, 0.3590845316648483, 0.07685916112469775, 0.01583546875709934, 0.012897942231834998, 0.018124274244265895, 0.04578474410144346, 0.030165488831698895, 0.02948266886440771, 0.05314710011173572, 0.06068829420421805, 0.013246588791454477, 0.026481796854308674, 0.009546550905465015, 0.016627263144723008, 0.07387505910758461, 0.05966124324394124, 0.13628987888140337, 0.1640578524342605, 0.19586198297994478, 0.1264541745185852, 0.05823748678501163, 0.1276900717722518, 0.13765927111463888, 0.10369918375675168, 0.1266309871737446, 0.09709578952086823, 0.15807662052767618, 0.20821441443903105, 0.09409199641751391, 0.15939624900264399, 0.2679784489529473, 0.13357953860291413, 0.13561651429959706, 0.08417840980525527, 0.8616277596780232, 44.75564002990723, 52.27702678952898, 36.400361742292134, 34.230786732264924, 39.35428762435913, 50.24443204062325, 60.78863607134138, 8.845018591199603, 0.7398019539458411, 1.6678322362048286, 1.507099449634552, 0.20879130491188594, 0.12864901817270688, 28.279807499476842, 58.682435580662315, 57.382198333740234, 55.2548371042524, 52.23294046946934, 49.335458278656006, 46.875323499952046, 49.52285466875349, 51.49183518545968, 53.14777851104736, 53.513569899967735, 49.469145093645366, 52.81427887507847, 52.4594760622297, 53.08390024730137, 48.73569325038365, 43.17084278379168, 40.134358406066895, 39.99497406823294, 40.48285572869437, 38.846607072012766, 36.62264156341553, 40.58220107214791, 38.738746711185996, 37.90485518319266, 41.24788366045271, 39.00415400096348, 40.11894382749285, 40.43793909890311, 39.509937695094514, 41.095235211508616, 39.961518492017476, 42.49864278520857, 39.1743084362575, 41.197286878313335, 40.14934914452689, 40.45821394239153, 38.016106264931814, 41.98285368510655, 40.340737274714876, 40.12711143493652, 38.99083777836391, 38.974314962114605, 38.77526644298008, 39.709090437207905, 41.321079458509175, 40.4619277545384, 39.042049476078574, 39.725835595812114, 36.52134377615792, 38.368049894060405, 38.017659187316895, 39.105576855795725, 43.359573228018625, 46.74257469177246, 53.12430402210781, 49.99156972340175, 52.672361918858115, 53.21190343584333, 51.15944378716605, 50.163238865988596, 43.84267800194876, 43.711624554225374, 43.68772969927107, 46.07603400094168, 47.394482476370676, 43.80722481863839, 44.99241031919207, 41.19376066752842, 39.24365840639387, 37.07496234348842, 38.599313735961914, 39.43221167155674, 35.86026436941964, 37.830068247658865, 38.520139013017925, 38.00449929918562, 37.31503650120327, 37.27683877944946, 38.05433872767857, 35.1275247165135, 37.496467862810405, 37.65460191454206, 37.11527579171317, 35.092380728040425, 36.120158263615195, 37.42713526317051, 36.419674260275706, 36.461561475481304, 36.86786086218697, 38.03535277502877, 42.35490887505667, 45.73431117194039, 46.78355516706194, 47.996939931597026, 49.175667081560405, 46.9775766645159, 47.62412738800049, 47.80835887363979, 47.38065556117466, 46.25961583001273, 46.577839851379395, 47.67801414217268, 43.8051438331604, 46.24256147657122, 44.8666409764971, 44.68307651792254, 44.11551986421858, 44.20186512810843, 44.88520656313215, 47.47435549327305, 47.99078035354614, 46.175858770098, 32.61493451254708, 4.833243804318564, 1.1401245870760508, 3.796068395887102, 7.420829824038914, 5.789540009839194, 0.2484964057803154, 1.190809958747455, 20.8406092439379, 64.07593304770333, 39.240625517708914, 37.79123476573399, 30.380102021353586, 53.528227124895366, 10.415679727281843, 0.38048631325364113, 0.3152281806937286, 0.16292308403977326, 0.16391023035560334, 0.1453702516321625, 0.14510917849838734, 0.076776902324387, 0.14936181530356407, 0.1352334405694689, 0.1316749450883695, 0.14896697577621254, 0.12220475396939687, 0.15020101384392806, 0.13118403857307775, 0.17470422972525868], [0.017988852225244045, 0.047220561520329545, 0.04278686782345176, 0.010417420915993196, 0.05539729865267873, 0.0025004085411118077, 0.01820784092082509, 0.04912864270487002, 0.001732818769856489, 0.053850642538496425, 0.04569212067872286, 0.052070539843823226, 0.024607508410034434, 0.04127396882644721, 0.02267527307516762, 0.05668548720755747, 0.014980823367035814, 0.03189580062670367, 0.02604714428473796, 0.07576026009129626, 5.754217539514814, 41.66974701200213, 29.601594584328787, 27.837589400155203, 38.518200465611045, 31.181250163487025, 51.310674803597585, 18.537759099687847, 0.3515401179237025, 0.07187970474894557, 0.13452879552330288, 0.1932792208556618, 0.006813102692831308, 1.1993381125586373, 36.465174538748606, 56.710495131356375, 51.5924312046596, 51.377398354666575, 48.967342717306956, 42.87479393822806, 44.5951053755624, 48.24364614486694, 49.16653367451259, 49.57107516697475, 49.33908176422119, 47.11393506186349, 48.6726279258728, 49.641463892800466, 46.7363942691258, 41.183755261557444, 35.396850790296284, 36.73898220062256, 36.26235662187849, 35.07916178022112, 34.85297359739031, 34.45652675628662, 34.55440255573818, 34.77122456686837, 35.48594059262957, 35.44363301140921, 36.55615077699934, 36.861913204193115, 37.06302881240845, 37.400058133261545, 34.84613656997681, 35.98889984403338, 36.5492581639971, 36.44260678972517, 35.79019178662981, 36.45599944250924, 35.66634014674595, 36.97823647090367, 35.931181158338276, 35.41294281823294, 36.752371379307334, 35.505652632032124, 34.588903835841585, 36.79640906197684, 39.262793745313374, 37.475876876286094, 37.478100299835205, 35.812262739454, 35.239289964948384, 34.27655104228428, 35.54730013438633, 39.43699550628662, 44.29918507167271, 47.65613079071045, 49.59786394664219, 52.67248351233346, 50.080968720572336, 49.428411279405864, 46.84279898234776, 46.263291427067344, 44.234542506081716, 42.8759195463998, 43.89744370324271, 43.01647465569632, 44.037637506212505, 45.2863712310791, 43.202311175210134, 37.62498869214739, 33.67045620509556, 33.62967722756522, 34.06147302900042, 35.53582171031407, 34.79845455714634, 35.207922322409495, 34.424148150852744, 34.41941295351301, 34.17468350274222, 33.888355187007356, 33.810938358306885, 34.464041233062744, 34.77682828903198, 34.30049453462873, 32.77013989857265, 33.696063791002544, 32.70281880242484, 32.96328592300415, 33.843129362378804, 33.61623246329171, 34.22080217088972, 33.05013493129185, 38.893906933920725, 44.00714186259678, 42.51259476797921, 43.66103819438389, 37.63463626589094, 44.18341418675014, 43.87803391047886, 45.43797745023455, 42.08306407928467, 43.46745095934187, 43.70162609645298, 44.08310651779175, 40.12814671652657, 40.61271408626011, 39.18704795837402, 40.44498109817505, 39.0136695589338, 39.913735730307444, 41.349171025412424, 42.356367996760774, 44.968439034053254, 41.8532280921936, 15.102104187011719, 0.521703048476151, 0.6798868775367737, 2.4160241399492537, 4.085640217576708, 1.8981568770749229, 0.008233042816365404, 1.5632318833044596, 39.366818700517925, 43.217687538691926, 29.28351300103324, 23.41481259890965, 34.11433144978115, 22.933450085776194, 0.26816355330603464, 0.05540692027924316, 0.058067988737353256, 0.06473529418664319, 0.03917365867112364, 0.028925988557083265, 0.035101712348737886, 0.02552971213922969, 0.04740802378260663, 0.06401315650769643, 0.07055094319262675, 0.005671017994505486, 0.04429042339324951, 0.062232741686914644, 0.06011507460581405, 0.029469501892370836, 0.062420906232936044, 0.055041675056729994, 0.05403721591989909, 0.04494456507797752, 0.006066954204080892, 0.06615962740033865, 0.07683632842132024, 0.04022251096154962, 0.021593198013891066, 0.10202301905623504, 0.042120353052658696, 0.01852346827009959, 0.06668950218175139, 0.02258171157778374, 0.0036927627183363904, 0.04176814927320395, 0.029686772198017155, 0.040978789129959683, 0.04559561264302049, 0.0742424518934318, 10.474828004837036, 50.7401373726981, 29.195618288857595, 28.701915775026592, 46.269124439784456, 37.77728278296334, 59.13703536987305, 19.995063849857875, 0.31317170390060967, 0.41266974487474983, 0.5697266086935997, 0.20730688742228917, 0.024034470319747925, 1.9861747026443481, 39.20210123062134, 57.99667617252895, 53.68748678479876, 54.000822748456685, 51.21138504573277, 44.640765462602886, 47.658555712018696, 50.25019557135445, 52.30140801838466, 52.69737195968628, 50.35268497467041, 50.12888349805559, 51.56381157466343, 51.455721923283164, 47.9626019341605, 43.17552586964199, 37.053558417728965, 39.266257422310964, 37.15432466779436, 37.06950453349522, 37.36775595801217, 36.64277744293213, 36.11814676012312, 35.845134666987825, 36.269957951136995, 37.508206844329834, 39.1013627733503, 39.57216228757586, 39.222153731754844, 39.51282467160906, 37.27687699454171, 37.66570166179112, 37.90482044219971, 38.496515137808665, 37.05990212304251, 37.64002111979893, 36.041053022657124, 38.51640088217599, 37.56678015845162, 36.01311084202358, 38.22450358527047, 36.1235350881304, 36.013833454677034, 39.32060970578875, 41.10965272358486, 39.281418391636436, 38.90644148417881, 38.1075758252825, 37.30463852201189, 36.353061880384175, 37.01115008762905, 40.612005370003835, 44.766468797411235, 48.2947154045105, 51.68738876070295, 52.69720867701939, 51.70796932492937, 50.41706003461565, 50.110877241407124, 47.08466924939837, 44.19695969990322, 43.73421662194388, 46.08487558364868, 43.992703505924766, 45.9337557383946, 44.53904730933053, 45.15511628559658, 38.817490645817344, 35.20447949000767, 34.29837185995919, 35.31626558303833, 37.9623932157244, 36.95756210599627, 36.243794509342735, 36.0742688860212, 35.96996947697231, 34.6053397996085, 35.323679310934885, 35.87558167321341, 36.664907455444336, 37.082389967782156, 35.93431479590279, 34.268671785082134, 35.83540024076189, 34.43545286996024, 34.09765577316284, 35.966929640088765, 34.92770494733538, 35.50200482777187, 34.04785108566284, 41.24265514101301, 44.75947196143014, 45.28086478369576, 45.06814220973423, 40.577180998665945, 45.88909271785191, 45.26516880307879, 46.462273938315256, 44.8504273550851, 45.82174382890974, 45.238345282418386, 45.385469913482666, 42.324194363185335, 41.704362937382285, 42.57148422513689, 42.6544839314052, 41.55336815970284, 41.851574420928955, 44.657597473689485, 44.314728191920686, 46.984045437404085, 43.00132410866873, 16.672237260001047, 0.6033834112542016, 2.3905142630849565, 4.709755207811083, 6.96241113117763, 1.741400414279529, 0.08546860343111412, 2.7689596244267056, 45.13347264698574, 48.027817726135254, 39.168732506888254, 22.500730173928396, 32.975799628666465, 31.525165149143763, 0.44484739537749973, 0.08517559165401117, 0.013532502244093587, 0.03688953337924821, 0.01524438163531678, 0.055882661536868126, 0.03078596500147666, 0.05797406592007194, 0.04864986839571169, 0.011451422619367284, 0.07054102301065411, 0.01081916199265314, 0.004570645388282303, 0.05038288415276578, 0.10857119411230087, 0.08782003939683948, 0.09869951382279396, 0.09872254330132689, 0.1507043239793607, 0.11857589440686361, 0.11371368209698371, 0.1416586922215564, 0.20479010604321957, 0.19602556420224054, 0.10215937745358263, 0.2524673826992512, 0.244260664497103, 0.16712568567267486, 0.1559392080775329, 0.0698476687871984, 0.04921475558408669, 0.1092854675703815, 0.14553704911044665, 0.11243754771671124, 0.1527186366064208, 0.23608988150954247, 12.991938011986868, 59.37798500061035, 37.96725695473807, 37.05898496082851, 50.51965018681118, 41.60229390008109, 59.93145070757185, 24.27505690710885, 0.3331109439688069, 1.2821087454046523, 1.2969283844743456, 0.47857308281319483, 0.1440493067992585, 1.9545341261795588, 40.88093539646694, 59.23663084847586, 55.40962559836251, 56.08460487638201, 54.10429184777396, 46.759100982121055, 50.01150410515921, 53.76091882160732, 54.32507085800171, 53.635785239083425, 52.85089240755354, 50.86397164208548, 54.10224560328892, 53.28097547803606, 51.52382121767317, 45.93960264750889, 38.49288122994559, 40.74695675713675, 40.13193695885794, 40.10513775689261, 39.278246538979666, 38.80181898389544, 38.86538110460554, 37.56185735974993, 38.695931911468506, 38.96056795120239, 39.951749324798584, 41.930884633745464, 40.1870778628758, 41.712989125932964, 37.86573682512556, 39.63774285997663, 40.82989392961775, 39.931915691920686, 37.76943826675415, 40.17332737786429, 37.852236475263325, 40.10754183360508, 39.86830840791975, 37.757872990199495, 41.04284232003348, 37.93603869846889, 37.37102508544922, 41.70061091014317, 44.211818422589985, 40.83963530404227, 42.11242369243077, 39.73451042175293, 38.89681475503104, 38.562842641557964, 39.623999323163716, 43.223294734954834, 46.57938582556588, 50.69547087805611, 51.94842215946743, 55.189301695142476, 52.44414486203875, 52.98318958282471, 50.97122403553554, 48.90807110922677, 47.653820514678955, 45.945762225559776, 48.40237079347883, 47.10764346803938, 47.700887611934114, 48.935252462114605, 47.46529851640974, 42.048218863351, 37.035253388541086, 36.023602621895925, 36.970704623631065, 40.329710483551025, 37.45348283222744, 38.03266382217407, 38.668886048453196, 38.12209061213902, 36.72524561200823, 37.9710749898638, 37.32603202547346, 38.37979929787772, 39.6979524748666, 36.89731775011335, 36.15371806280953, 36.806087902614046, 35.640489373888286, 35.84374850136893, 38.253057207380024, 37.50330489022391, 38.16660424641201, 35.15512296131679, 43.52599648066929, 47.21722003391811, 46.13943631308419, 46.415682792663574, 41.09720155170986, 47.053506578717915, 47.65948677062988, 48.2149327141898, 45.97404139382498, 47.1921683038984, 46.9559052331107, 48.23923403876168, 44.06303317206246, 44.467571190425325, 44.38578741891043, 44.78587164197649, 43.27543749128069, 43.47308247429984, 45.15038456235613, 47.04461635862078, 48.02640724182129, 44.94846991130284, 17.31319120952061, 0.9332242778369358, 2.76532050541469, 5.174039048807962, 11.639938422611781, 3.8415699771472385, 0.16135067412895815, 4.799385666847229, 47.76863602229527, 51.052646500723704, 40.239877223968506, 31.911519731794083, 42.98687880379813, 38.84191356386457, 0.863960400223732, 0.1574409824929067, 0.17445903431091989, 0.12704922258853912, 0.16656839129115852, 0.14904158748686314, 0.11606838181614876, 0.11124207757945571, 0.13342473762375967, 0.17255734492625507, 0.2242615640695606, 0.09379757328757218, 0.09576579303081546, 0.13362235416259083, 0.200087166258267, 0.1521088643265622], [0.05219765320154173, 0.03230807511135936, 0.05407494246693594, 0.025078343859474574, 0.11770044852580343, 0.018050926305087547, 0.05128320852028472, 0.02940503428024905, 0.023647837673446963, 0.021090713994843618, 0.04666882434061595, 0.06909869504826409, 0.04100714850106409, 0.03809854029012578, 0.1018295076542667, 0.020552323598946844, 0.07037432052727256, 0.08449254437748875, 0.03341992937826684, 0.046832490379789045, 0.50274244589465, 24.27350745882307, 41.695566517966135, 23.42527311188834, 32.0169586454119, 33.35837091718401, 40.374324866703574, 37.4057799748012, 0.13974978322429316, 0.20144313706883363, 0.286298215921436, 0.027895385465983833, 0.043788690851735215, 0.12570428475737572, 5.548984255109515, 46.410468169621055, 53.07317222867693, 51.21363973617554, 50.067402362823486, 45.267843859536306, 42.81853437423706, 46.28757538114275, 47.8167279788426, 50.43732098170689, 50.246116978781565, 47.77862753186907, 46.55463981628418, 46.82207598005022, 46.090753759656636, 40.25527443204607, 35.750639166150776, 36.192360469273154, 36.17613295146397, 37.01991524015154, 35.639631271362305, 35.852861063820974, 35.9099509375436, 38.52928631646292, 35.87473051888602, 37.12545837674822, 35.57352263586861, 33.96934686388288, 35.93865394592285, 37.13965007237026, 35.61728586469378, 36.64775235312325, 35.089097704206196, 35.93501656396048, 34.932665961129324, 35.79762288502285, 35.42254522868565, 35.47510487692696, 36.65151480266026, 36.17377403804234, 35.62058973312378, 37.901353291102815, 34.81418527875628, 38.505964687892366, 38.343307358878, 38.472109590257915, 39.238079002925325, 36.71364906855992, 37.044529233660015, 35.1920074735369, 37.4140795980181, 41.74531214577811, 45.14671243940081, 48.003353118896484, 48.17721094403948, 45.92564371653965, 48.966005189078196, 47.852233273642405, 48.93808732713972, 45.687779085976736, 45.38754047666277, 44.26328372955322, 44.401302746364046, 45.41590649741036, 47.684878962380544, 46.945132051195415, 45.623369285038535, 37.272207805088584, 35.22105441774641, 34.58272688729422, 33.66761091777256, 36.12745039803641, 34.041868686676025, 33.83542728424072, 32.9570950780596, 34.39011240005493, 35.571434702192036, 34.662933417728965, 33.04686232975551, 33.02937718800136, 35.511259828295024, 33.90604182652065, 33.57471350261143, 34.33514520100185, 33.21049240657261, 33.60525778361729, 33.36629186357771, 34.328638213021414, 32.928524085453574, 33.288656166621614, 35.27103975840977, 41.815009525844026, 43.24584511348179, 46.609937054770334, 39.015889508383616, 40.328664779663086, 44.2742896761213, 45.070945807865684, 43.986186095646445, 42.72926391874041, 43.41867807933262, 43.3857992036002, 43.5916291645595, 43.70658016204834, 41.7936681338719, 41.179047857012065, 40.88943999154227, 41.03680086135864, 41.1467422076634, 45.88327707563128, 44.28422907420567, 30.138756343296595, 4.61909988948277, 0.33296313190034454, 2.0588359236717224, 6.949882226330893, 8.497242144175939, 2.1989986768790653, 0.05709346317287002, 7.3780810322080335, 50.31446988242013, 34.83597482953753, 24.459092106137955, 27.324497938156128, 40.34815795081002, 9.28674944809505, 0.1875323142324175, 0.0750381699098008, 0.04684816114604473, 0.023445722447442155, 0.029135180903332572, 0.02222802011030061, 0.03710584016516805, 0.09189728168504578, 0.02306333403768284, 0.042412411488060436, 0.03600266096847398, 0.008586050659817244, 0.04781476142151015, 0.04612859511481864, 0.03588371717238, 0.023586677919541086, 0.04732750881729381, 0.05817761964031628, 0.011016147493916963, 0.021224673770900284, 0.03055483561807445, 0.05233519903517195, 0.038155985064804554, 0.04573626955971122, 0.08813874050974846, 0.012447435691553568, 0.046028327995112965, 0.06240200903266668, 0.03814297076314688, 0.04542665063802685, 0.06395598993237529, 0.020427586810131158, 0.02073525494363691, 0.01522803572671754, 0.0139761292874547, 0.03581447606640203, 0.9895268338067191, 32.64239379337856, 45.43339511326381, 24.274139744894846, 44.49774374280657, 38.328570229666575, 44.90437664304461, 37.62662499291556, 0.157398058367627, 0.17546788017664636, 0.48702138662338257, 0.07748656852969102, 0.05147349688091448, 0.1585817084248577, 7.544892515454974, 51.3882931300572, 54.210519381931846, 52.99695743833269, 49.921615259987966, 47.502037116459434, 45.01294572012765, 47.781042030879426, 48.3194648878915, 52.089147499629426, 50.09262432370867, 49.551304067884175, 49.75600494657244, 49.44403082983834, 48.03287254061018, 41.64272199358259, 36.693332535879954, 38.85754701069423, 37.81000532422747, 38.044996874673025, 36.74727487564087, 36.72384902409145, 38.10269471577236, 39.268692765917095, 37.62554107393537, 40.15917042323521, 38.423472200121196, 36.695142541612896, 38.55129126140049, 38.585688318525044, 37.57486091341291, 37.55975900377546, 37.08104201725551, 37.94993509565081, 37.21314116886684, 38.139565331595286, 37.90772131511143, 36.804819856371196, 38.16479771477835, 37.63984741483416, 37.51763554981777, 37.69408852713448, 37.3332199369158, 39.97222914014544, 41.307332447596956, 40.160709449223106, 41.318043095724924, 38.81633724485125, 37.366032804761616, 36.64800248827253, 38.89174257005964, 43.70044837679182, 47.118079662323, 50.021895136152, 50.84918934958321, 48.20956523077828, 44.13610390254429, 48.32865735462734, 51.79793112618582, 47.325365270887104, 45.72050857543945, 47.75508008684431, 46.147913115365164, 47.01306111471993, 47.713991914476665, 48.06446252550398, 45.68168898991176, 39.06459985460554, 36.437902859279085, 36.83817120960781, 35.660958766937256, 37.460913930620464, 35.25639295578003, 36.69341938836234, 34.977190017700195, 36.044148445129395, 36.910696506500244, 36.284382411411826, 33.52899782998221, 35.58219051361084, 35.66940777642386, 34.4905937739781, 35.77222721917288, 34.70462608337402, 34.82541356767927, 35.54884263447353, 35.51269810540335, 34.97022097451346, 35.51329912458147, 34.62948131561279, 36.24955109187535, 42.49983440126692, 46.10465710503714, 47.250786781311035, 39.933353969029014, 41.25262580599104, 44.462099484034944, 44.60871689660208, 46.48680802753994, 44.316590309143066, 46.19516086578369, 44.26046276092529, 45.073968274252756, 45.33526223046439, 43.24532747268677, 43.677376883370535, 42.25841229302542, 41.73036309650966, 43.90641382762364, 47.80549968991961, 46.485348905835835, 31.415102209363663, 5.700623043945857, 0.5850994980760983, 4.5222059573446, 6.668472366673606, 6.674292351518359, 1.2295100135462624, 0.1421708504536322, 7.49818411895207, 54.55689055579049, 40.19562414714268, 35.48871292386736, 26.321879829679215, 44.23984398160662, 13.733966537884303, 0.2976273080067975, 0.02442992731396641, 0.03683034137689641, 0.02040316124579736, 0.021930760703980923, 0.0261938418594322, 0.03838501438232405, 0.007793309715842562, 0.03799046662503055, 0.04953396899093475, 0.03200692430670772, 0.023949415955160345, 0.008573022787459195, 0.05901910484369312, 0.08701554113732916, 0.047585508187434504, 0.13908916153013706, 0.18242431618273258, 0.12321460406695094, 0.092013942210802, 0.21432317021702016, 0.17677381581493787, 0.06972403292145048, 0.09367557269121919, 0.16495426504739694, 0.07516167685389519, 0.12426295424146311, 0.18226462975144386, 0.14827563001641206, 0.1298461982182094, 0.13588586556059973, 0.12668780769620622, 0.15036333299108914, 0.11650702756430421, 0.0912098442869527, 0.13698034254567965, 1.3174714935677392, 39.270999567849294, 52.62913022722517, 32.175203868321006, 41.38466937201363, 43.85412515912737, 49.975818157196045, 45.46574592590332, 0.6485188550182751, 0.5300035402178764, 0.9366196670702526, 0.36258151116115706, 0.22203584707209043, 0.21641354661967072, 7.581551211220877, 50.13798911230904, 55.74878454208374, 57.016132490975515, 52.74232333047049, 48.75861188343593, 48.00596216746739, 50.97611556734358, 51.149118764059885, 53.15040145601545, 54.90251132420131, 51.44130093710763, 52.29360171726772, 51.05740949085781, 49.36565514973232, 44.67315101623535, 39.39545917510986, 40.576288155147004, 40.915804931095664, 41.425267696380615, 39.48353454044887, 40.02420513970511, 39.835933276585166, 43.62118680136544, 39.24516269138881, 41.72457177298409, 40.43584769112723, 37.619624682835166, 39.244134357997346, 40.542297567640034, 38.81273807798113, 40.318013191223145, 38.77903931481497, 40.45544161115374, 39.59032140459333, 40.13157565253121, 38.395957333701, 38.46844441550118, 40.87847573416573, 38.77973066057478, 38.883178915296284, 40.57476997375488, 37.911455971854075, 42.62979350771223, 41.92208474023001, 43.1168726512364, 44.730616092681885, 39.86778729302542, 40.54623372214181, 38.81382894515991, 40.11612285886492, 47.34466389247349, 47.99218388966152, 52.007561751774375, 52.236511843545095, 47.910928181239534, 43.85309682573591, 49.713176250457764, 52.94967147282192, 47.84395449502127, 47.68158204214913, 49.059739862169536, 48.65689025606428, 48.0899589402335, 50.009819167000906, 49.55925280707223, 47.96676043101719, 42.0443765095302, 38.73184020178658, 38.147256987435476, 36.60969359534127, 39.92005164282662, 38.04288114820208, 39.25667585645403, 35.877471583230154, 38.75651672908238, 39.0765438079834, 38.4887991632734, 34.55685179574149, 37.23489597865513, 38.9871552331107, 35.55681569235665, 37.734464509146555, 37.51921626499721, 37.24372713906424, 38.123949255262104, 36.69451025554112, 37.78903218678066, 36.62047719955444, 37.02388960974557, 37.39800494057791, 45.147369044167654, 45.71430035999843, 50.577761445726665, 41.365780694144114, 44.38460275105068, 46.67194972719465, 47.48170321328299, 47.89006274087088, 45.24800327845982, 46.1991491317749, 48.18086222239903, 47.06603765487671, 48.21430737631661, 46.06938457489014, 43.93132659367153, 44.83473137446812, 44.307415212903706, 44.85053505216326, 51.912711892809185, 46.62936074393136, 33.14750003814697, 6.119409212044307, 0.668736321585519, 4.988915153912135, 13.193986415863037, 13.859324199812752, 4.905730451856341, 0.21912206842431, 10.423268028667994, 61.34975869315011, 44.22415842328753, 37.226617200034006, 34.91070965358189, 51.86967822483608, 20.52382697377886, 0.3264635263809136, 0.14106315560638905, 0.11052907976721014, 0.1696022299251386, 0.11178394207464797, 0.11123622860759497, 0.11403858501996313, 0.16377252845891885, 0.10910752854709115, 0.1317741469080959, 0.1481532087283475, 0.08246550243347883, 0.07636841745781046, 0.24478576917733463, 0.1652694988463606, 0.11557748887155737], [0.04976923065260053, 0.05611860851890274, 0.006777861280300255, 0.05043612540300403, 0.050679427704640796, 0.05309622694871255, 0.04361384594812989, 0.05409244527774198, 0.014536349003070166, 0.018229701622788395, 0.03724440380132624, 0.14952562722776616, 0.0762275332318885, 0.10013352973120553, 0.017687328226332153, 0.005303973381939743, 0.05087840809885945, 0.03099140165639775, 0.04038179027182715, 0.08929465205541678, 0.07652011074657951, 7.003993059907641, 35.904381956372944, 30.531183651515416, 23.18570269857134, 35.534011704581125, 36.30184323447091, 51.503977162497385, 5.047056811196463, 0.5142411717346737, 0.17525612296802656, 0.03573094162025622, 0.07283888185130698, 0.11769838577934674, 0.06488158633666379, 12.15023410320282, 52.57327365875244, 50.969167368752615, 53.05357830865042, 47.45927790233067, 43.73593282699585, 44.16114521026611, 47.0693484715053, 46.91420909336635, 51.46125268936157, 47.3944651058742, 47.04983792986189, 47.6455591065543, 45.80092355183193, 38.35803059169224, 36.5737019266401, 34.82129676001412, 35.76178755078997, 36.59551927021572, 37.319792543138774, 38.95346341814314, 38.29905080795288, 39.078350339617046, 37.11037383760725, 35.55501610892159, 37.13765593937465, 37.36002261298043, 37.85247618811471, 36.39680426461356, 37.316964626312256, 34.79078027180263, 35.26445286614554, 36.13156025750296, 36.06410367148263, 35.19028084618704, 35.98493242263794, 36.86057915006365, 35.03289719990322, 34.016459124428884, 34.99503646578108, 36.38130630765642, 36.83054903575352, 36.797076089041575, 41.1004706791469, 40.62411955424717, 38.25529452732631, 39.40185499191284, 38.38075120108468, 38.32822629383632, 38.72527068001883, 43.236569268362864, 46.784691197531565, 49.756432260785786, 48.3746474811009, 79.11769907815116, 68.35113184792655, 44.10647678375244, 50.95694201333182, 45.682682582310264, 46.38527052743094, 43.69840213230678, 46.81823362622942, 45.1018340247018, 48.25170258113316, 48.75072915213448, 46.44113751820156, 35.85863849094936, 33.63936301640102, 34.156447955540244, 34.8376910345895, 35.46133007322039, 35.246373653411865, 33.78311082295009, 34.121342182159424, 33.249503067561555, 33.10590117318289, 33.742300578526084, 34.32861736842564, 35.763149397713796, 33.03685344968523, 33.621502671922954, 32.575444425855366, 32.844548157283235, 34.392429624285015, 35.57540212358747, 32.5783348764692, 33.03591891697475, 34.71118170874459, 32.970501627240864, 33.723745414188926, 34.781021526881624, 42.90427514484951, 45.80968870435442, 48.262246472494944, 46.636684145246235, 45.257268701280864, 45.466847215379985, 46.78547634397234, 44.730821064540315, 45.66200474330357, 44.64880452837263, 44.78814022881644, 43.280919619968955, 46.21632160459246, 43.823566981724326, 44.89000082015991, 41.88473817280361, 46.447342259543284, 44.62610476357596, 44.32762404850551, 15.38286178452628, 0.6235182051147733, 1.0189184738057, 2.743598699569702, 3.126513489655086, 6.027782882962908, 1.530257252710206, 0.1158199565751212, 32.572408063071116, 51.719204562050955, 30.334754603249685, 24.57958255495344, 28.053214584078106, 36.19759941101074, 2.155762642621994, 0.10790513056729521, 0.058524527453950474, 0.05072177168247955, 0.09033473088805165, 0.0440346937227462, 0.03295058670586773, 0.048479715561760325, 0.04376941706453051, 0.06896642143172876, 0.07102788545723472, 0.031853809487074614, 0.050244473186986785, 0.04029956879094243, 0.023406615081642355, 0.1039827638970954, 0.013714574393816292, 0.03379588866872447, 0.04503852521468486, 0.048475240623312335, 0.06179936815585409, 0.11063733324408531, 0.0826799330700721, 0.01856754590491099, 0.025347662890063863, 0.006733349807161305, 0.02308527616384838, 0.055711650356118164, 0.1548634043761662, 0.04385191674477287, 0.04440672768812094, 0.026207692455500364, 0.05799811998648303, 0.04585958990667548, 0.03220851706074817, 0.052856239290641885, 0.0024911469621916433, 0.018772356611277376, 10.738077878952026, 44.94359574999128, 28.931176798684255, 30.070834227970668, 47.74745096479143, 39.09334455217634, 55.98866067613874, 4.640670572008405, 0.4614844226411411, 0.18185593453901155, 0.0828783909923264, 0.19199761748313904, 0.18105269835463592, 0.13641603211207048, 14.367288759776525, 54.544720785958425, 52.31739582334246, 53.56750529153006, 48.28365387235369, 45.719070298331125, 48.00726842880249, 50.33218431472778, 48.69492816925049, 53.26599168777466, 49.360138280051096, 49.446487018040244, 50.37777491978237, 47.64367961883545, 40.449351515088765, 37.87739937646048, 37.851496492113384, 37.15751736504691, 38.50419289725167, 37.400040762765066, 38.80625888279506, 41.37296513148716, 41.270048413957866, 37.54958684103829, 36.83419336591448, 37.873348576681956, 38.4034092766898, 38.8441925730024, 38.458939279828755, 38.96776975904192, 36.966573919568745, 37.07273891993931, 37.8597856930324, 36.98345109394619, 37.78427267074585, 38.793088572365896, 38.30966765539986, 38.25449895858765, 35.5048952783857, 37.42603049959455, 38.262086391448975, 38.23055894034249, 39.16719348090035, 42.29198598861694, 40.35138886315482, 40.329408236912315, 39.877764906202046, 41.47140720912388, 41.12430647441319, 40.399904659816194, 42.46978691646031, 49.18778126580374, 51.46286467143467, 50.29585913249424, 56.94785254342215, 60.01552391052246, 48.17400435038975, 51.69620949881417, 48.57038518360683, 47.18329545429775, 46.22231789997646, 48.41670492717198, 47.84864452907017, 48.94635568346296, 50.02410813740322, 46.97708681651524, 37.34538275854928, 34.46889107567923, 35.95491273062569, 37.9687751361302, 37.16895062582833, 37.32828671591622, 36.35643523080008, 36.19839497974941, 35.570541858673096, 36.318657875061035, 35.008008752550396, 36.30158615112305, 38.00404419217791, 33.87399673461914, 35.1913925579616, 35.2471935408456, 35.70382220404488, 37.25777987071446, 37.67589814322335, 33.861041818346294, 35.805568150111604, 35.495626381465364, 34.988543374197825, 34.07330928530012, 36.58594117845808, 43.88447489057268, 47.156517096928184, 50.33510603223528, 47.266625199999126, 46.10597726276943, 46.46481350490025, 47.79604319163731, 46.26688711983817, 46.794349193573, 47.059405599321636, 45.82749693734305, 44.89458315713065, 46.897925989968435, 45.45867613383702, 45.164923667907715, 43.56059850965227, 47.84837702342442, 46.801995686122346, 45.451439585004536, 17.52481770515442, 1.222518714410918, 3.4383364830698286, 5.21141254050391, 5.780197288308825, 5.436636660780225, 0.4073346411543233, 0.13182320498994418, 33.502618994031636, 55.767527307782856, 40.59726129259382, 29.991235664912633, 27.44209619930812, 44.5949455669948, 3.2805913133280615, 0.2430070846208504, 0.028466722129711082, 0.028390624427369664, 0.0520451999535518, 0.02871834666335157, 0.11174565234354564, 0.045168898933167966, 0.026046830462291837, 0.07572602799960546, 0.03344058059155941, 0.02144602207200868, 0.056754606177232096, 0.06503830756992102, 0.024537222360127738, 0.04005171012665544, 0.028874365612864494, 0.15586910183940614, 0.16148317844739982, 0.13966218435338565, 0.16766912436911038, 0.14817763598901884, 0.20006432676953928, 0.1415378451347351, 0.10974003175007445, 0.07259173225611448, 0.11637753594134535, 0.10511196830442973, 0.255814894501652, 0.1524389987545354, 0.2101574537477323, 0.14274228550493717, 0.1281613279134035, 0.13230442202516965, 0.16651257500052452, 0.20021078176796436, 0.16496157965489797, 0.2406529752271516, 13.312979527882167, 50.23977327346802, 38.244712420872276, 31.799789224352153, 45.99231168201992, 44.4785041809082, 60.4141629082816, 6.9533602339880805, 0.5582167005964688, 0.7077380259122167, 0.4074550132666315, 0.12783222485865864, 0.14932760356792382, 0.26376515360815184, 14.908162593841553, 55.46180656978062, 54.60046965735299, 57.347829069410054, 50.86943292617798, 49.07171508244106, 48.60518176215035, 52.368593624659944, 50.544868673597065, 55.304044246673584, 50.77821697507586, 51.734125818525044, 53.45638622556414, 50.42064183098929, 43.48004456928798, 41.441293716430664, 40.06101322174072, 39.62353726795742, 41.73780114310128, 41.2120726449149, 41.12362207685198, 43.68400893892561, 43.26487275532314, 41.0116240637643, 37.694863251277376, 41.40094552721296, 40.42722497667585, 41.414890561785015, 40.478388037000386, 41.698293685913086, 39.1540162222726, 38.18653515407017, 39.98489570617676, 40.091637407030376, 37.00699506487165, 40.83015101296561, 40.29285723822457, 41.606820651463096, 36.890157631465364, 39.35980796813965, 39.091555391039165, 41.113568033490864, 40.28943525041853, 45.289810589381624, 44.5699667930603, 42.37116071156093, 40.94668272563389, 43.942822388240266, 42.841150760650635, 43.671220779418945, 45.2399468421936, 49.6100823538644, 51.980456829071045, 52.293966497693745, 64.66917719159807, 64.11049338749477, 48.822274753025596, 54.84298958097185, 49.240983622414724, 49.79568610872541, 49.41281257356916, 49.89993340628487, 49.1010399545942, 51.18128544943673, 52.64365891047886, 48.845196860177175, 38.010061332157676, 37.07911041804722, 37.2280033656529, 39.954459122249055, 39.7100145476205, 39.73638643537249, 37.509502683367046, 36.84966353007725, 36.18412685394287, 37.804634366716655, 37.5932354245867, 38.9923802784511, 39.721875122615266, 35.20142575672695, 38.978004455566406, 35.19476938247681, 36.74952261788504, 39.817496231624055, 38.549199853624614, 35.709363392421174, 36.8436324937003, 38.018750054495676, 36.08601828983852, 37.453326497759136, 38.43099362509591, 45.77176891054426, 49.75301374707903, 51.965045724596294, 48.37001998083932, 49.98736258915493, 46.11968258449009, 48.908960478646414, 47.608705861227854, 48.576450960976736, 46.462075914655415, 49.212273665836875, 46.25792046955654, 49.59261458260672, 47.98005928312029, 48.75544350487845, 45.639336245400564, 51.10712037767683, 45.96470648901803, 47.32266589573452, 18.051630122320994, 1.5243047092642104, 3.3430354254586354, 8.78425225189754, 11.648626276424952, 15.797302722930908, 4.043247086661203, 0.14765425478773458, 40.6775928906032, 60.58197580065046, 40.258536611284526, 37.92355278560093, 36.8727593421936, 52.72484861101423, 6.012720925467355, 0.5052816867828369, 0.16398433995034012, 0.17883607372641563, 0.19056339801422187, 0.16578342126948492, 0.20458160580268928, 0.15090574031429632, 0.13186456848468098, 0.1974401604384184, 0.09567353262432984, 0.12863262476665632, 0.15643425365643843, 0.12289486479546342, 0.07358748239598104, 0.15352457336017064, 0.10874621543501105], [0.0765989361596959, 0.0330773166913007, 0.032307939404355626, 0.022439884188185846, 0.13000103990946496, 0.08138824666717223, 0.016129152283870747, 0.028536950504141192, 0.03645808010229042, 0.05609294293182237, 0.02684782917744347, 0.08793165162205696, 0.06799389754555055, 0.006634784114014889, 0.0616035225934216, 0.07042412499764136, 0.004975433087175978, 0.03211987324591194, 0.018181758034708242, 0.024404950439929962, 0.05796521103807858, 0.8116281426378659, 24.024624722344534, 44.47633286884853, 23.65461230278015, 35.53004428318569, 31.668593338557653, 48.05132000786917, 17.329331874847412, 0.8004299263869012, 0.2431290309344019, 0.07424784624683005, 0.08013902298573937, 0.1819145463939224, 0.05667031516454049, 1.0217606127262115, 30.09343671798706, 52.884205545697895, 50.42073563167027, 48.75210836955479, 46.51437153135027, 46.84126690455845, 47.119750704084126, 51.11792830058506, 49.80011905942644, 48.55900056021554, 48.80993822642735, 49.43736055919102, 44.53485059738159, 35.872274330684114, 37.91195624215262, 36.866790839603965, 37.19325542449951, 38.110726833343506, 41.20186921528408, 40.61361387797764, 41.81575298309326, 42.221843923841206, 40.946436064583914, 38.6409786088126, 36.770148345402305, 35.33870826448713, 37.68522957393101, 37.07411813735962, 37.149867398398264, 36.73227718898228, 35.73406423841204, 35.45470149176461, 35.94474751608712, 36.79865680422102, 38.14294215611049, 36.20774378095354, 35.86880023138863, 35.462337562016074, 36.62690428325108, 36.667787483760286, 35.67811386925833, 36.04293598447527, 39.70992422103882, 37.845211846487864, 39.96014622279576, 38.5964788709368, 40.02402796064104, 38.47795302527291, 40.20096731185913, 42.62056629998343, 50.15056535175869, 48.07290806089129, 51.18267508915493, 46.74909210205078, 40.78850698471069, 58.42152377537319, 50.43409354346139, 47.79934706006731, 45.82429034369332, 47.30389186314174, 47.36060653414045, 46.0376695224217, 48.798230511801584, 47.98478058406285, 45.07430873598371, 35.12739964893886, 33.34220245906285, 35.52385343824114, 34.13693741389683, 33.94600786481585, 32.67551238196236, 35.21784087589809, 35.36185271399361, 33.290476594652446, 32.97244364874703, 32.56747484207153, 34.76407834461757, 35.00510093144008, 32.477318491254536, 36.05165597370693, 35.25277294431414, 36.47535712378365, 38.40590715408325, 37.635067054203574, 35.31272200175694, 33.69816562107631, 32.98142419542585, 32.18855830601284, 33.638414587293354, 34.0035320009504, 33.54092788696289, 41.680937085832866, 42.31793751035418, 44.90505756650652, 45.15500511441912, 44.72928203855242, 45.83464663369315, 42.66377019882202, 45.61896760123116, 44.70191308430263, 45.265707288469585, 46.19395882742745, 44.250370502471924, 43.32962996619088, 45.68819597789219, 43.628617899758474, 47.701710973467144, 45.638137681143625, 33.25439807346889, 4.094701102801731, 0.3396658908043589, 1.954331977026803, 3.8160609688077654, 4.5190054433686395, 1.8206357168299812, 1.8307797610759735, 4.12498265504837, 47.62486389705113, 34.97033909388951, 26.353982244219097, 22.97335706438337, 37.565258502960205, 23.444731542042323, 0.20524781862539904, 0.02796632460584598, 0.0899764033300536, 0.06302715013069765, 0.04254636447876692, 0.05195668845304421, 0.043388572321938615, 0.0713472922465631, 0.022445982521665946, 0.11071313239101853, 0.03212555258401802, 0.005229615273752383, 0.011422236283708895, 0.0013463564994578648, 0.024568647013178894, 0.05891449509986809, 0.07053164565669638, 0.00544142464475174, 0.030054249800741673, 0.02229955466464162, 0.05541756310101066, 0.14060063899627753, 0.10430934280157089, 0.031463835055806806, 0.041125179667557986, 0.009815429736460959, 0.09180322994611093, 0.051609264952795844, 0.12259597011974879, 0.06850583186107022, 0.09289880615792104, 0.01039325404313526, 0.14482872640447958, 0.012627599461536323, 0.01025080240132021, 0.029606026530797993, 0.053603177424520254, 0.0749079929664731, 1.6390994808503558, 33.444417408534456, 48.29446874346052, 19.819043397903442, 41.81277567999703, 38.40377058301653, 52.861283438546316, 18.17748805454799, 0.8154250074710164, 0.38875599950551987, 0.08216427359730005, 0.15973202884197235, 1.541320196219853, 0.15762806816824845, 1.5263357545648302, 33.88914728164673, 52.081000736781526, 51.42950636999947, 51.64275353295462, 48.05932085854666, 48.09982885633196, 49.239809376852854, 51.70188617706299, 52.25884682791573, 50.56292356763567, 50.31730127334595, 50.3308676310948, 46.53361456734793, 38.59715632029942, 38.11463172095162, 39.25280570983887, 38.74240493774414, 40.12771940231323, 41.354135513305664, 42.476043769291465, 43.68538120814732, 42.79659196308681, 43.87967715944563, 40.61413846697126, 37.962942123413086, 38.37744038445609, 38.959119251796174, 38.62749910354614, 39.68615790775844, 37.34049122674124, 37.048833642687114, 37.84961700439453, 38.42618547167097, 37.89567313875471, 39.87503773825509, 38.04502119336809, 37.491006578717915, 36.83880002158028, 36.15117154802595, 38.91168737411499, 37.07878385271345, 38.579198701041086, 42.02703727994646, 39.656756605420796, 41.22268601826259, 41.45300490515572, 40.61795997619629, 41.029348918369834, 42.60584306716919, 44.576518944331575, 51.42000470842634, 51.08255502155849, 49.6352139881679, 55.279836722782676, 41.72909157616751, 52.039238589150564, 52.777974537440706, 47.98704917090279, 47.97380590438843, 48.53774949482509, 50.418143953595845, 46.512610163007466, 50.7441325868879, 48.6375013078962, 46.71743958336966, 37.493448870522634, 36.07622480392456, 36.80562237330845, 36.40369687761579, 36.81440837042672, 36.21823903492519, 38.35479620524815, 37.904611996241975, 35.382016386304585, 35.47037315368652, 34.53727524621146, 35.90972164699009, 35.48043761934553, 34.49024288994925, 36.35541384560721, 36.94318628311157, 36.6926064491272, 40.1195205279759, 38.32349109649658, 38.008543150765554, 34.90262542452131, 35.51557118552071, 33.47403063092913, 34.721082891736714, 34.46321439743042, 35.62727737426758, 43.49144308907645, 44.19209943498884, 46.67957884924752, 46.85287734440395, 46.88729872022356, 47.56334802082607, 45.60818747111729, 47.87372405188424, 46.13946410587856, 46.95949050358364, 46.0784068107605, 44.14887816565377, 45.09300633839199, 45.05207450049264, 44.534423283168245, 47.94278219767979, 47.38397332600185, 35.44324738638741, 5.384795716830662, 1.217328084366662, 4.257882586547306, 5.898227206298283, 6.780739188194275, 1.9724876199449812, 0.8127908259630203, 3.012937149831227, 55.70860310963222, 41.41689164297921, 31.51287031173706, 24.586648872920446, 40.04091208321707, 30.394950321742467, 0.175664166786841, 0.14869313261338643, 0.05121025922042983, 0.015082798698650939, 0.07107329302068267, 0.028450581477954984, 0.06008330559624093, 0.07720901378031288, 0.09132121223956347, 0.16502760111221246, 0.024368436774238944, 0.0341484995691904, 0.07629117303128753, 0.018496223392763307, 0.027502953041610972, 0.04038124744381223, 0.10171403456479311, 0.11709934792348317, 0.1637705878487655, 0.07655606631721769, 0.25714506741080967, 0.25424509016530855, 0.16309943529111998, 0.16312637313136033, 0.12865139304527215, 0.1326078086027077, 0.17887240249131406, 0.11596635729074478, 0.25893379428556984, 0.13950966325189385, 0.19867581341947826, 0.26429082825779915, 0.23723766420568737, 0.08601987242166485, 0.10525653019015278, 0.10730542774711337, 0.07739969569125346, 0.13494160265794822, 1.6963903095041002, 39.47808367865426, 54.49029554639544, 32.62581191744123, 44.09401866367885, 42.25066157749721, 55.01308148247855, 24.540917566844396, 0.9002298883029393, 0.6237660061035837, 0.19915688117699964, 0.3894331231713295, 0.7763094721095902, 0.1700423141675336, 2.2293510138988495, 33.8847143309457, 53.96589068004063, 54.114092281886506, 52.431537355695454, 50.66060829162598, 49.78825153623308, 51.150456292288645, 54.32262509209769, 55.14509725570679, 51.820874077933176, 51.232184478214805, 53.453613894326345, 49.619861943381174, 41.21738454273769, 40.103762013571604, 41.73984738758632, 40.77285269328526, 42.432825974055696, 44.39850957053048, 46.2841533933367, 44.875732694353374, 47.27732195172991, 46.57230908530099, 43.06845760345459, 39.578471251896445, 38.74669197627476, 41.48382364000593, 39.67563486099243, 41.58672298703875, 40.43830387932913, 38.441402026585166, 40.23584032058716, 39.510872227805, 40.338826520102366, 42.058776651109966, 40.56194012505667, 38.529185567583355, 38.87255164555141, 38.26482745579311, 40.41759477342878, 40.04485866001674, 40.43001467841012, 44.72201769692557, 41.35826621736799, 43.02120637893677, 43.878895487104145, 43.71525846208845, 43.52157047816685, 44.681926591055735, 45.210201604025706, 53.915346009390696, 52.06142766135079, 51.9055552482605, 59.6722412109375, 45.696558134896414, 51.50733661651611, 54.83271319525582, 49.45764582497733, 50.436716488429475, 47.59994418280465, 51.11727516991751, 48.894056592668804, 53.939577851976665, 50.74210371289934, 47.72708232062203, 38.22225931712559, 38.43517991474697, 38.29732765470232, 38.53774922234671, 38.903596196855815, 36.767466340746196, 40.10660382679531, 40.03671189716884, 37.736597606113975, 37.409274918692454, 36.705158369881765, 38.206191607883994, 38.11423914773123, 35.971706526620046, 38.47107778276716, 39.581028188977925, 37.84898819242205, 42.82672282627651, 39.605930532727925, 39.804979051862446, 35.80212184361049, 37.30824811117989, 35.67934022630964, 36.2958538872855, 36.74899802889143, 37.7906893321446, 43.60816240310669, 45.789764744894846, 48.532812799726216, 48.75621822902134, 48.43516976492745, 50.166073731013704, 46.868281500680105, 49.216150760650635, 48.088478973933626, 48.53993470328194, 47.649971212659565, 46.78451749256679, 44.35554885864258, 48.178749970027376, 45.871690954480854, 48.51327793938773, 48.66341461454119, 37.90709597723824, 5.392894276550837, 1.6305163928440638, 4.738275825977325, 11.4320969581604, 13.417745334761483, 11.339946474347796, 5.055951373917716, 4.9399659633636475, 57.784099510737825, 43.96460499082293, 37.951442854745046, 34.5719814981733, 46.88840000970023, 37.746161801474436, 0.3920791654714516, 0.2340211910860879, 0.18550725361066206, 0.15059023510132516, 0.16493526606687478, 0.17818744853138924, 0.20617119622017654, 0.19802638755312987, 0.22959806557212556, 0.41429757752588814, 0.14449845626950264, 0.07853170923356499, 0.18167885046984467, 0.07554553089929478, 0.13287794696433203, 0.20700236090591975, 0.1382901594042778], [0.09132252181214945, 0.032295837732298036, 0.02143724013252982, 0.040269906632602215, 0.1521891350192683, 0.06068768352270126, 0.09034585886235748, 0.04460461564095957, 0.03627438031669174, 0.03162141124318753, 0.06433326897344419, 0.0415554658642837, 0.07099311053752899, 0.01900908221224589, 0.1454925914960248, 0.09418125769921712, 0.043087794711547237, 0.04965876175888947, 0.02258252751614366, 0.05037038893039737, 0.06650649450187172, 0.09687311468379838, 6.699721455574036, 38.45607314790998, 33.24738386699131, 30.17997305733817, 38.150018896375386, 34.54266357421875, 46.21671417781285, 1.752422537122454, 0.16814730156745228, 0.08765274658799171, 0.15046075704906667, 1.2192185372114182, 0.04629229847341776, 0.07156352100095578, 11.62293096951076, 48.207366125924246, 51.69984688077654, 50.244247913360596, 48.985908303942, 47.89436020169939, 48.199726581573486, 50.18833228519985, 50.95093182155064, 47.557476793016704, 49.601699352264404, 50.95940514973232, 40.82311248779297, 34.96933160509382, 36.78176573344639, 36.978285108293804, 40.69911840983799, 43.16586439950125, 45.34613616125924, 46.46527903420584, 46.80064426149641, 46.061998639787944, 44.33797686440604, 42.32467031478882, 37.60480417524065, 38.287426471710205, 36.2660356930324, 39.18802765437535, 36.440803732190815, 37.27111693790981, 38.244431018829346, 35.55486324855259, 34.87915440968105, 36.61339351109096, 36.13164016178676, 33.94472244807652, 37.46628488813128, 35.98987259183611, 34.10681349890572, 33.829563004629954, 36.4159118107387, 37.818732261657715, 39.495961393628804, 37.86429854801723, 37.64536428451538, 36.56331784384591, 38.06339570454189, 39.498372418539866, 41.96130732127598, 45.15141984394619, 47.70001213891165, 48.78621012823922, 42.617818287440706, 13.649030889783587, 56.700857979910715, 64.70544678824288, 43.76015772138323, 51.41814953940255, 45.45865876334054, 47.957373414720806, 44.58990464891706, 46.62139116014753, 46.11262321472168, 50.42933750152588, 42.380311489105225, 34.12736279623849, 32.23734508241926, 34.998969146183555, 35.78047820499965, 34.448494638715474, 33.3659131867545, 35.072116306849885, 33.16762202126639, 33.78519180842808, 32.71450914655413, 33.81921018872942, 32.65805155890328, 34.39453840255737, 32.191323689052034, 34.64690044948033, 35.33958373750959, 40.20376743589129, 40.73745856966291, 39.56717348098755, 37.55216114861624, 36.783794607434956, 32.59303726468767, 33.52021530696324, 33.43258810043335, 32.01463099888393, 31.8444105557033, 32.624648094177246, 37.36228772572109, 39.82290193012783, 40.57666335787092, 41.51002182279314, 41.54929651532854, 41.773309912000386, 40.97378764833723, 44.91155065808977, 43.82616213389805, 45.32918950489589, 44.87630244663784, 46.933556352342876, 43.7536472593035, 43.76742206301008, 44.70872231892177, 43.29531281335013, 20.68502344403948, 0.681618010359151, 1.0378097572496958, 6.460931411811283, 5.992859934057508, 4.019639279161181, 1.7685655908925193, 0.19606611345495495, 16.542877435684204, 50.65250669206892, 26.856583663395472, 49.74702092579433, 30.034335340772355, 33.90031998498099, 10.845133985791888, 0.4556079294000353, 0.05896849970200232, 0.08288524419601474, 0.0812804206673588, 0.030970373856169835, 0.05446563953799861, 0.05309843558019825, 0.038545063829847744, 0.024583656207791398, 0.05399502461243953, 0.04967133501278503, 0.046631386170962026, 0.03634450351819396, 0.048244070527809005, 0.022766632726415992, 0.038188537782324214, 0.02814678269039307, 0.02099380223080516, 0.012395937428144472, 0.062324561045638154, 0.037740246658878665, 0.05136836127245, 0.024755356101585285, 0.11841552944055625, 0.018287545036790625, 0.05917844522212233, 0.07832744983690125, 0.0335064493784947, 0.04987409823973264, 0.13004457471626146, 0.03756457394255059, 0.16136381056691917, 0.008638426777906716, 0.03577165032870003, 0.017158910598871962, 0.12397890591195651, 0.0430115545168519, 0.1064504464822156, 0.0503644517489842, 10.969954899379186, 46.96214124134609, 29.46204001562936, 35.94412912641253, 46.487096377781455, 40.921089036124094, 49.33326612200056, 1.1732292792626788, 0.4574614699397768, 0.15301750414073467, 0.8755332220877919, 4.527391050543104, 0.5177648855107171, 0.1898413553301777, 13.569190876824514, 50.71004125050136, 52.0890919140407, 50.869189739227295, 52.81021417890276, 49.8266681262425, 50.919362681252615, 50.21596874509539, 52.38606834411621, 49.951874664851594, 50.286069120679585, 52.337014062064036, 42.926895005362375, 37.38056148801531, 38.964584009987966, 37.69119112832205, 41.97422054835728, 43.96766914640154, 46.241564410073416, 46.35360063825335, 49.41763809749058, 47.67933777400425, 47.19135536466326, 43.500847475869314, 40.320903641836985, 39.091795103890554, 38.42696019581386, 39.49654851640974, 38.0533173424857, 38.37276077270508, 40.515432357788086, 36.67221001216343, 36.187559264046804, 37.553887775966096, 38.444403648376465, 35.79675088609968, 38.375835350581575, 35.94389636175973, 35.411118916102815, 35.52844967160906, 38.34870263508388, 39.82768923895699, 39.87311656134469, 40.03700719560896, 40.752088001796174, 38.942064898354666, 39.63253171103341, 41.70279959269932, 42.937320777348106, 48.354789529527935, 47.21854019165039, 51.97636434010097, 44.65094804763794, 15.36891848700387, 45.08244507653372, 63.07803276606968, 46.97155952453613, 51.9406783921378, 47.47521359579903, 50.32529170172555, 45.93253632954189, 47.6885267666408, 46.2401191847665, 49.76817124230521, 46.44068241119385, 37.01179279599871, 33.80748857770647, 35.84748663221087, 37.997026511601035, 35.27327707835606, 35.591431617736816, 36.54719107491629, 35.808931078229634, 36.306644439697266, 34.9616573197501, 34.8150121143886, 35.040234497615266, 35.29145703996931, 35.30877195085798, 35.82490151269095, 36.59454304831368, 42.45284720829555, 41.58933203560965, 42.37350920268467, 41.08224555424282, 38.54784842899868, 35.48921666826521, 35.527577672685894, 36.95353215081351, 34.21393387658255, 33.80833625793457, 34.99010671888079, 39.472646713256836, 41.25660712378365, 42.83778435843331, 42.81008536475045, 43.60964584350586, 42.52902030944824, 44.56316103254046, 45.02023785454886, 44.44109855379377, 45.98756258828299, 45.683346135275706, 48.39462007795061, 45.42661714553833, 44.47511345999581, 45.086065087999614, 43.50939376013619, 22.851548194885254, 1.004944126520838, 2.336378676550729, 7.223671214921134, 5.330806042466845, 5.1627877439771375, 0.16053331084549427, 0.4292452154414994, 17.460929019110544, 54.499349049159456, 32.22431026186262, 47.481303691864014, 28.635656016213552, 41.217096192496165, 14.75985676901681, 0.4799841099551746, 0.060616613764848025, 0.059312435532254834, 0.050721123681536744, 0.03371066127770713, 0.047944134300840754, 0.04653210971238358, 0.0651242168886321, 0.09274481263543878, 0.030235191341489553, 0.04516921445195164, 0.027597920802821006, 0.029867659455963542, 0.08437150051551205, 0.0744025454457317, 0.05143933264272554, 0.02046200380261455, 0.12312388393495764, 0.10384183217372213, 0.11853269886757646, 0.1331427791821105, 0.23522534647158214, 0.2483785306768758, 0.17270865823541368, 0.07415904636893954, 0.14797176846436091, 0.17918436575148786, 0.18841983803680964, 0.08549919178975479, 0.16278747203094618, 0.1896401425557477, 0.2328139687223094, 0.19491712296647684, 0.10752333248300211, 0.1214124286281211, 0.20899585607860768, 0.15087331991110528, 0.267785229321037, 0.22774577353681835, 12.070557372910635, 54.63272666931152, 40.84337343488421, 38.89010974339077, 48.133037771497456, 42.40125335965838, 55.160049779074534, 3.860069121633257, 0.45437975387488094, 0.2552852843488966, 1.2843980682747704, 3.2845339817660193, 0.14774338714778423, 0.3410865531436035, 13.317436797278267, 53.521306719098774, 54.699999128069194, 54.38121230261666, 54.0954189981733, 53.99579225267683, 53.47802291597639, 53.896651881081716, 55.1890480858939, 51.96842949731009, 51.17228405816214, 55.35001352855137, 44.936060428619385, 38.87629325049264, 40.311617374420166, 41.48744017737252, 45.847268036433626, 47.729125091007774, 49.77227415357317, 50.41185930797032, 51.475857802799766, 51.57033245904105, 49.0951999936785, 47.77957943507603, 41.89859288079398, 42.91209881646292, 40.57971361705235, 42.978575706481934, 40.011764390128, 40.08537360600063, 41.56088958467756, 37.840014593941824, 38.30316414151873, 40.12849065235683, 40.16738666806902, 38.28153439930507, 39.842346463884624, 38.28908361707415, 36.86232662200928, 37.25364569255284, 38.56795998982021, 40.88250568934849, 43.011392048427034, 41.93495280402047, 42.51181656973702, 41.07250417981829, 40.83505296707153, 43.41153533118111, 44.74620090212141, 50.22227423531668, 49.0505439213344, 52.71221678597586, 45.906060218811035, 22.07632725579398, 50.258661951337544, 66.74876608167375, 49.03207908357893, 53.41089636938912, 49.18714203153338, 51.43673597063337, 48.199809959956575, 49.87338433946882, 48.39180953162057, 53.74324260439192, 48.07667745862688, 37.87755571092878, 36.92170940126692, 37.304530824933735, 39.76574257441929, 37.9256546156747, 36.532909052712576, 38.93468243735177, 37.51982423237392, 37.8045266696385, 35.91427966526577, 37.66776875087193, 36.63434927804129, 37.597105571201865, 36.349441868918284, 38.49574736186436, 39.0724652154105, 44.039947782244, 43.8192903654916, 43.78426797049386, 43.279026235852925, 41.15292610440935, 35.34704262869698, 37.6286747114999, 38.21462672097342, 35.72667482921055, 35.924816608428955, 36.48315647670201, 41.17258603232247, 42.969810553959434, 44.9474971635001, 44.917359352111816, 45.62520360946655, 45.103703090122764, 46.27051407950265, 48.14124359403338, 46.23122896466936, 48.978293078286306, 46.13770273753575, 49.901409898485454, 45.44273349217006, 43.61968946456909, 45.583434513636995, 45.64483574458531, 22.784510237830027, 2.2055697185652594, 3.7864394954272678, 13.664653045790535, 12.3058694090162, 10.251221077782766, 2.7330954117434363, 0.6468483018023627, 20.075652531215123, 62.11803490774972, 36.81002058301653, 58.165816170828684, 37.55896690913609, 47.90960454940796, 20.91791316441127, 0.5978869519063404, 0.16087208980960505, 0.2577143854328564, 0.23210747806089266, 0.14554462156125478, 0.16584894061088562, 0.22648331842252187, 0.1342513154127768, 0.19358433091214725, 0.16549854512725556, 0.09724239379699741, 0.13943617790937424, 0.10152143918509994, 0.17365706020167895, 0.2133878639766148, 0.17230589341904434, 0.14274858230991022], [0.05148924228602222, 0.019385336665436625, 0.01687853823282889, 0.03461141312228782, 0.048772469495556185, 0.06157740578055382, 0.013956530651609813, 0.0207334534331624, 0.10604705062827893, 0.031029474256294112, 0.058541212630059035, 0.04530491806300623, 0.06342406597520624, 0.011235028472063797, 0.08373393544128963, 0.037691887468099594, 0.05632912740111351, 0.0769443376255887, 0.022359579568728805, 0.014926016397242035, 0.05245314199211342, 0.0357605223543942, 0.19283594749867916, 23.38660291263035, 43.48642648969378, 20.19889620372227, 34.79973302568708, 29.604578835623606, 46.664699281964985, 22.205475160053798, 0.27145661945853916, 0.151138233553086, 0.7986978707568986, 10.007122176034109, 3.6886097277913774, 0.06658362357744149, 1.4891887307167053, 30.835664136069163, 51.47731345040457, 52.97622748783657, 48.31839486530849, 49.6423602104187, 50.29557425635201, 52.71323469706944, 48.61963401521955, 48.5584169115339, 49.53970405033657, 49.40859154292515, 37.74114867619106, 35.71628032411848, 37.201231956481934, 41.01040465491158, 44.88252803257534, 46.551155294690815, 47.54290294647217, 49.223456791469026, 50.1729211807251, 49.57386139460972, 45.70808172225952, 41.3338954108102, 36.60497924259731, 37.47299337387085, 36.20125068937029, 37.0012662751334, 37.156162466321675, 38.26204470225743, 36.9849762235369, 37.40944167545864, 37.488682406289236, 38.30301475524902, 38.184051173073904, 36.09550952911377, 36.04668801171439, 37.12407915932791, 36.28378139223371, 35.215982232775005, 36.03000538689749, 37.93747697557722, 37.861616543361116, 38.75780214582171, 38.38469082968575, 40.50148384911673, 39.40306397846767, 39.98230055400303, 40.1380409513201, 47.73498937061855, 47.628404004233225, 51.15780748639788, 46.56406504767281, 46.21543223517281, 31.141075679234095, 33.16196271351406, 47.87767062868391, 44.82367679050991, 47.94245910644531, 46.277802739824565, 47.96904986245291, 47.98706654139927, 48.361814158303396, 43.37463344846453, 37.196694782802034, 34.05546978541783, 35.82851457595825, 32.971529960632324, 35.174494538988384, 34.99891356059483, 34.141537121364046, 33.84177098955427, 33.747456141880576, 33.632189001355854, 35.63396848951067, 32.94156585420881, 33.05798292160034, 34.63589102881295, 34.17213003976004, 32.891028131757466, 38.24594225202288, 42.1294606753758, 41.94903332846505, 42.75414889199393, 41.11672598975045, 40.1584095954895, 37.33025653021676, 35.53296252659389, 33.52892139979771, 32.22842706952776, 33.1043586730957, 33.459852831704275, 31.073692049298966, 33.99066046306065, 34.22849382672991, 35.70050096511841, 37.53835507801601, 38.05981043406895, 40.05248430797032, 42.62179265703474, 42.94625268663679, 44.08689328602382, 43.73753091267177, 45.218202454703196, 44.26170996257237, 46.911405495234895, 44.97707564490182, 40.385810238974436, 6.389574715069362, 0.2776835081832749, 1.7306757611887795, 3.1135709498609816, 5.099315515586308, 4.190492876938411, 0.5731125527194568, 0.08782333029167992, 33.60158566066197, 45.54234981536865, 27.225550379071915, 26.446469715663365, 28.39652681350708, 40.32863698686872, 2.763834676572255, 0.2311184454177107, 0.10511025161083255, 0.07251893223396369, 0.09457847209913389, 0.012051462162552136, 0.0646944735199213, 0.05275730549224785, 0.05603734377239432, 0.010879394698089786, 0.04759948600881866, 0.019237142921026264, 0.027201510466901318, 0.018338667561433146, 0.02540191346114235, 0.05478823883458972, 0.019989019093502845, 0.05513005085023386, 0.0701045146478074, 0.025720429673258747, 0.08814239781349897, 0.034385399892926216, 0.04815030377358198, 0.08043257759085723, 0.019756281582106437, 0.0317395543679595, 0.04078284178727439, 0.010624479269608855, 0.03520320761682732, 0.03331389810357775, 0.07586616583700691, 0.014526922455323594, 0.08480901311018638, 0.006519314417216394, 0.07290531042963266, 0.05119718045794538, 0.011752084878805493, 0.025271152977698615, 0.01618608137193535, 0.015648425490196263, 0.7368828420128141, 30.196902343205043, 47.73543405532837, 20.51864014353071, 43.744684083121165, 32.76944160461426, 54.022730418613975, 19.733088970184326, 0.286871469446591, 0.018337849926735674, 0.5757677959544318, 5.389273830822535, 4.900748593466623, 0.2395137692136424, 1.8911602582250322, 34.31042351041521, 51.265636580330984, 56.1577033996582, 49.848193645477295, 51.284622532980784, 50.93165751865932, 55.32888753073556, 51.22089712960379, 50.36809260504586, 50.91227899278913, 51.166381563459126, 40.43384313583374, 37.19312340872628, 36.850420883723665, 43.028098991939, 46.32353230885097, 48.39677054541451, 49.04317883082798, 50.31045729773385, 50.77385698046003, 51.27245971134731, 48.43724727630615, 43.7614083971296, 39.88220133100237, 39.77861063820975, 37.26940768105643, 38.813394682747976, 37.361433097294395, 39.75537586212158, 38.545409611293245, 38.952233586992534, 38.59469665799822, 40.082632541656494, 40.01094797679356, 38.30002702985491, 38.21474484034947, 38.11202267238072, 35.82321310043335, 36.92672600064959, 38.28023508616856, 39.537285804748535, 39.8316844531468, 40.72440985270909, 39.96457569939749, 40.82558257239205, 40.996987683432444, 43.689623083387104, 42.1781119619097, 49.62525027138846, 49.07059989656721, 52.24128873007638, 45.77725451333182, 42.71461711611067, 38.35303136280605, 37.1309300831386, 47.07235704149519, 46.30166980198452, 48.82625259671892, 47.97938183375767, 49.15834174837385, 47.27890961510794, 49.46615736825125, 45.98908771787371, 39.25559193747384, 34.95742586680821, 37.175815446036204, 35.53955289295742, 37.077234404427664, 36.909112317221506, 35.15232283728463, 35.76352112633841, 34.7083329473223, 35.00028582981655, 36.052312578473774, 34.36482443128313, 34.45931993212019, 35.49368783405849, 35.30688898903983, 34.37917940957205, 39.507273060934885, 44.51643092291695, 41.87100158418928, 44.27634981700352, 42.387412548065186, 41.303045409066335, 38.785747800554546, 37.37986666815621, 35.367154189518516, 33.44537625994001, 34.110794816698345, 34.87057338442121, 32.85516153063093, 35.920647689274375, 36.639327662331716, 38.81448554992676, 40.69301094327654, 39.73387118748256, 41.22999899727957, 44.758023262023926, 45.078022548130576, 46.42701530456543, 45.58805853979928, 46.36530835287911, 45.68120609010969, 47.51951878411429, 46.22455869402204, 39.69545807157244, 8.099466460091726, 1.0738341041973658, 3.162327762160982, 6.654449164867401, 7.667703662599836, 4.152923967157092, 1.3913289989743913, 0.2662326054913657, 34.688822405678884, 49.99084711074829, 34.28151205607823, 40.47559833526611, 31.56667368752616, 47.052485193525044, 4.641419240406581, 0.3412256528224264, 0.06946567392774991, 0.038036725749926906, 0.034867997746914625, 0.06196411645838192, 0.0556233763428671, 0.0593913695109742, 0.0782596506178379, 0.05506013799458742, 0.0367677974115525, 0.03316430148801633, 0.01347296079620719, 0.06047236400523356, 0.033932599904281754, 0.06499160400458745, 0.04112998030281492, 0.018828242451750805, 0.13961600326001644, 0.13791068190974848, 0.18916455736117704, 0.17944566958716937, 0.13520070804016932, 0.23740531663809503, 0.1264447293111256, 0.12276174979550497, 0.17753334077341215, 0.12110589364809649, 0.17498417970325264, 0.14242691599896976, 0.17212764226964541, 0.11387956355299268, 0.11935300699302129, 0.1483157178653138, 0.13660873605736665, 0.1390363715056862, 0.052969401968376975, 0.09657180442341737, 0.15848697136555398, 0.12528100104204246, 0.7361754828265735, 35.431067194257466, 54.679550579616, 29.211025919233048, 45.2710018157959, 39.06534331185477, 57.040656157902305, 27.868163211005076, 0.4389804559094565, 0.24829911493829318, 2.4772169249398366, 20.51879300389971, 6.528270746980395, 0.2199923438685281, 2.310125993830817, 35.00905098233904, 54.41547039576939, 57.99216679164341, 52.13410929271153, 53.75211892809187, 53.381651401519775, 55.41049064908709, 51.873600482940674, 52.805989674159456, 53.000261306762695, 53.3933869089399, 41.759621960776194, 38.91888223375593, 39.08700084686279, 45.68915135519845, 49.32586976460048, 49.68434817450387, 51.691283226013184, 52.540460790906636, 53.96744360242571, 53.76533440181187, 49.78912353515625, 44.994526045663015, 41.544710704258506, 41.46978480475289, 38.392590931483674, 40.24181924547468, 39.16002641405378, 42.38565812792097, 40.435399532318115, 41.582519326891216, 40.12280355181013, 41.983802114214214, 43.06293378557478, 39.586058684757774, 40.369575772966655, 40.405480589185444, 39.00416442326137, 37.44039242608206, 41.335458755493164, 40.90457664217268, 42.238606452941895, 42.45935419627598, 41.391694000789094, 43.25373479298183, 43.657730851854595, 45.960409028189524, 43.70786905288696, 52.25052636010306, 51.789881638118196, 55.16885314668928, 49.67300524030413, 45.588246141161235, 40.70277663639614, 40.71830933434622, 47.11340005057198, 47.325664043426514, 51.52413041251046, 49.6748708316258, 49.59771108627319, 49.82955162865775, 51.36503750937325, 47.49412311826433, 41.85048702784947, 37.94822931289673, 38.88420377458845, 38.02883883884975, 39.42674691336495, 38.25005211148943, 37.57651111057827, 38.790062631879536, 37.67628724234444, 36.4844696862357, 38.02731718335833, 36.05246891294207, 35.30168826239449, 37.68192570550101, 36.40471478870937, 35.62522070748465, 41.311661175319124, 45.7177814074925, 44.06317213603428, 45.5562288420541, 44.291712284088135, 43.14993565423148, 40.485110419137136, 40.05447496686663, 36.024571895599365, 35.068121092660085, 35.666076115199495, 38.16062879562378, 35.19601658412388, 38.075009618486675, 38.549363136291504, 39.88779463086809, 43.20183522360665, 42.60640934535435, 43.1829708644322, 47.00497341156006, 46.55526515415737, 48.274655955178396, 46.985212734767366, 50.21654544557844, 47.091356890542166, 49.619535378047395, 46.407879965645925, 41.99091706957136, 8.549133896827698, 1.9500449384961809, 5.154742164271219, 10.964819312095642, 11.271626574652535, 10.980847069195338, 2.9213379621505737, 0.43940505598272595, 41.018117155347554, 55.09310041155134, 36.876438413347515, 37.93762288774763, 34.465267590114046, 56.863546575818745, 7.099704929760524, 0.5197906110967908, 0.18911169948322432, 0.1958330909588507, 0.15126171335577965, 0.14456827752292156, 0.21691567610417092, 0.14648106774049147, 0.17281687100018772, 0.14281440020671912, 0.17321107270462172, 0.1678149958274194, 0.10792628050382648, 0.10470948847276823, 0.12555466778576374, 0.18772972721074307, 0.24942637873547419, 0.1653599204229457], [0.07039571473641054, 0.011010591988451779, 0.032996191044471095, 0.030294895637780428, 0.019246016462732638, 0.02712399632270847, 0.08850903742547546, 0.053263726710741005, 0.05448669787230236, 0.01027830088111971, 0.04681263644514339, 0.03365694505295583, 0.028315022055591856, 0.06450349305357252, 0.011735288592587625, 0.024809920495109897, 0.041546441348535676, 0.058109990055007596, 0.03855084155553153, 0.08737496792205743, 0.07348530180752277, 0.051168502175382206, 0.09385541839791195, 7.698799456868853, 41.09460639953613, 34.259034633636475, 33.572813170296804, 35.39125401633126, 33.285091740744456, 42.43799890790667, 1.1453297649111067, 0.0590173067258937, 0.4833507293037006, 4.172313349587577, 2.3793706553322926, 0.1580076813697815, 0.13871538372976439, 11.02882524899074, 46.11502729143415, 50.560884271349224, 53.16340500967843, 49.36412307194301, 54.30600847516741, 47.53652450016567, 50.6430640901838, 47.661904743739534, 48.93116692134312, 42.77256161825997, 36.9573849269322, 36.423308168138774, 41.17672715868269, 45.87102740151541, 47.64220312663487, 48.400550365448, 48.249281133924214, 48.32125752312796, 50.38330915996006, 49.62777941567557, 47.762542452131, 38.62233659199306, 37.22328206471035, 37.85003737040928, 36.077864578792024, 36.26854746682303, 35.8579888343811, 37.3493640763419, 38.4253899029323, 37.92737429482596, 37.83371952601841, 35.75794172286987, 37.86131082262312, 36.73255164282662, 36.44705711092268, 36.22911991391863, 36.49062926428658, 38.085060187748496, 39.236821378980366, 37.23043870925903, 37.2547539302281, 37.93532998221261, 37.93659455435616, 36.4871586390904, 37.304805278778076, 38.33048445837838, 39.318000657217844, 44.46564653941563, 46.326672894614084, 46.52013853618077, 50.43336050851004, 43.80728040422712, 26.518246344157628, 41.16267442703247, 45.90690442493984, 46.364370346069336, 48.611462933676584, 49.619622230529785, 48.04331568309239, 45.817324774605886, 43.86430079596383, 37.425398213522776, 35.149046761649, 34.31175061634609, 32.83726991925921, 33.946768692561555, 34.16381999424526, 34.11453989573887, 32.92375067302159, 33.99694510868618, 34.26951946531023, 33.01105826241629, 33.26557077680315, 33.3774402482169, 33.594501972198486, 32.96437679018293, 33.66364349637713, 33.39866352081299, 38.74038996015276, 42.02780505589077, 44.02039902550833, 44.486428601401194, 42.872441973005024, 41.67726843697684, 38.69787393297468, 37.62753868103027, 37.29802731105259, 36.04112597874233, 33.50301851545061, 33.042971338544575, 34.11645065035139, 32.74193716049194, 32.58784001214163, 32.53842442376273, 33.568508761269705, 36.17710222516741, 36.76614965711321, 36.31775113514492, 40.02062334333147, 40.50721958705357, 42.06469999040876, 41.385256494794575, 45.552546296800884, 43.960863385881694, 49.778006417410715, 26.90676007952009, 1.2828370034694672, 0.7233474254608154, 2.1434569486549924, 4.144730303968702, 2.458785091127668, 1.751720769064767, 1.1909543509994234, 1.9203255389417921, 45.45117555345808, 32.96879237038748, 25.739183051245554, 16.983940396990093, 28.238269431250437, 23.427583387919835, 0.13502366468310356, 0.03435842473325985, 0.02854233467951417, 0.05655775299029691, 0.03878092938768012, 0.06543540661888463, 0.04489384458533355, 0.010622860115420605, 0.023118139311139072, 0.04556836946202176, 0.08395255942429815, 0.015893751522526145, 0.057140316015907695, 0.0092362025586356, 0.017027904146483967, 0.06486484687775373, 0.04625810370115297, 0.03804200475237199, 0.03999800747260451, 0.049349393895162005, 0.041419596012149534, 0.015669229373868023, 0.07137051850025143, 0.03144896496087313, 0.031045901589095592, 0.04439353696735842, 0.009569877243068601, 0.03141184231000287, 0.04521427256986499, 0.032172944862395525, 0.0186732938912298, 0.02376004192046821, 0.039468024125588794, 0.006724598825842674, 0.031878894926714044, 0.029414625372737646, 0.0271674564906529, 0.005923497906353856, 0.03151036898738571, 0.025916276932028786, 0.1599634364247322, 11.68863660948617, 49.68205526896885, 28.51876994541713, 36.69155727113996, 44.54941054752895, 38.83268983023507, 47.90214218412127, 1.0077513073171889, 0.1954102007938283, 1.2277735067265374, 3.4537612668105533, 3.911117536681039, 1.0246736449854714, 0.18119388792131627, 13.210744602339608, 48.01723909378052, 52.15302228927612, 53.879851136888774, 51.55988584245954, 54.53031369618007, 49.35254042489188, 52.4033658845084, 49.993466581617085, 50.6563594681876, 45.332354409354075, 38.71300710950579, 39.46543100902012, 41.654638154166086, 47.47967781339373, 51.01382344109671, 50.312427112034385, 49.60430492673601, 49.77484846115112, 52.34275327410017, 51.87673759460449, 48.56891911370413, 41.852929319654194, 38.23560333251953, 39.64562906537737, 37.62607955932617, 37.51205267224993, 37.304169518607004, 38.74602494921003, 39.61275366374424, 40.19010727746146, 37.96828876222883, 38.25966494424002, 39.146102224077495, 38.321889536721365, 38.107777323041645, 38.742905208042686, 38.8008462360927, 39.00309787477766, 39.57584135872977, 39.46622657775879, 38.29010500226702, 40.270546572549, 39.62350252696446, 38.13003935132708, 38.12077740260533, 39.3560802595956, 40.41990852355957, 46.259733949388774, 46.793282645089285, 50.533581324986045, 50.688199588230674, 46.565312249319895, 24.965018238340104, 40.08706201825823, 46.258028166634695, 47.97120380401611, 51.131452969142366, 49.91529587336949, 49.994074548993794, 48.92033120564052, 46.41277844565255, 40.29903071267264, 36.45855637959072, 36.01998955862862, 35.05591310773577, 35.43884917667934, 35.83306564603533, 35.769621644701274, 35.728703703199116, 35.49099888120379, 36.98780761446272, 34.83907720020839, 35.341539655412944, 35.608906337193076, 35.08291033336094, 34.349451541900635, 35.089326994759695, 33.810406821114675, 40.75421067646572, 45.1281989642552, 46.10523727961949, 46.95294877461025, 45.15963608877999, 43.08077328545706, 40.505861214229036, 40.54320430755615, 39.99362959180559, 37.42512028557913, 34.91087988444737, 34.18058252334595, 34.1400328363691, 35.2052264213562, 33.79506172452654, 34.57240533828735, 34.93104008265904, 38.67750876290457, 39.7299211365836, 39.27545683724539, 41.69271428244454, 42.35001386914934, 43.4878682409014, 44.243536949157715, 45.82849400384085, 47.60638516289847, 48.24580703462873, 29.873102392469132, 1.2038861427988325, 1.2120000102690287, 4.850107950823648, 4.584881314209529, 6.155865975788661, 4.32557931968144, 0.2917805074581078, 1.8514936438628604, 51.80845417295183, 38.15420518602644, 29.83345249720982, 16.85103178024292, 31.123229231153214, 30.38130405970982, 0.09991884803665535, 0.04409922579569476, 0.0200420822282987, 0.06247172850583281, 0.018635289144835303, 0.044530892811183415, 0.035031388979405165, 0.059896762748914104, 0.02906914587531771, 0.04027459191690598, 0.08040620293468237, 0.027858790376090577, 0.061594891627984386, 0.022270226684798087, 0.03495959997443216, 0.09606050114546504, 0.045678868889808655, 0.023528281499498656, 0.13248389453760215, 0.16021146811544895, 0.15749012199895723, 0.06272516812064818, 0.13793042727879115, 0.131538043863007, 0.16555494495800563, 0.11888270080089569, 0.1935843037707465, 0.09298487832503659, 0.10050185211002827, 0.12530932309372084, 0.06623117213270494, 0.15203959947185858, 0.17268596802439007, 0.05640500118689878, 0.12268698880715029, 0.14101725949772767, 0.13974472135305405, 0.111804209915655, 0.14824148613427365, 0.17151343237076486, 0.3441229702106544, 13.279336350304739, 55.07435417175293, 42.29636335372925, 42.04446683611189, 47.12141132354736, 43.440547534397666, 53.50964069366455, 2.032654242856162, 0.31940730501498493, 2.1324868287358965, 11.530876891953604, 9.61144311087472, 0.41289314574428965, 0.5281210669449398, 11.949267881257192, 48.29618147441319, 53.07914073126656, 56.391413007463726, 50.41240126746041, 57.71175834110805, 50.406960827963694, 56.50456442151751, 51.25812905175345, 53.36260291508266, 46.67893961497715, 41.566587107522146, 40.87132951191494, 45.68122346060616, 51.14491857801165, 52.63839565004621, 53.190370968409944, 51.820665631975444, 51.123195035117014, 55.32351657322475, 53.83143261500767, 50.95066084180559, 42.08474554334368, 41.375317096710205, 40.34124796731131, 38.96954502378191, 39.13567992619106, 39.73430544989449, 40.0810101372855, 41.97373070035662, 42.39935302734375, 41.95876080649239, 39.505925110408235, 42.289432525634766, 40.944104943956646, 40.4692268371582, 39.989967891148154, 41.228362696511404, 42.65717288425991, 42.56763144901821, 41.31205374853951, 40.250688620976035, 42.63996914454869, 42.445363998413086, 40.314351490565706, 39.87667056492397, 40.84726095199585, 43.11870002746582, 49.183761732918875, 48.37021105630057, 50.21422127314976, 53.80238567079817, 47.654755047389436, 30.93672568457467, 42.00420897347586, 46.353110790252686, 49.73009858812605, 52.23157862254551, 54.079723017556326, 50.97936037608555, 51.18078865323748, 48.31534808022635, 41.907799243927, 38.494809355054585, 37.99322237287249, 36.05808653150286, 37.61681761060442, 36.73829780306135, 38.712850775037495, 35.73383147375924, 37.81454944610596, 37.97807877404349, 36.4843168258667, 36.757690225328716, 37.9078984941755, 36.7392566544669, 36.31853975568499, 36.74062197549002, 35.70835590362549, 42.239488874162944, 46.161086899893625, 48.00523608071463, 49.74287632533482, 47.216219493321006, 44.363890171051025, 41.12419877733503, 42.01646906988961, 41.74644470214844, 38.924878529139924, 36.731818607875276, 36.51910645621163, 37.108654158455984, 37.10171638216291, 35.718479428972515, 36.16045086724417, 36.33856098992484, 39.98431205749512, 42.64893926892962, 41.26092542920794, 43.70179632731846, 45.11803374971662, 44.92900800704956, 46.860589844839915, 47.2590342930385, 48.27091087613787, 51.15191541399275, 30.770371913909912, 2.35588943532535, 1.550691144806998, 7.176725276878901, 9.904155084065028, 6.737793241228376, 11.272167665617806, 2.718162213053022, 2.719818272760936, 56.482285022735596, 42.70825604030064, 36.80786664145333, 25.885426998138428, 39.712929316929404, 38.45627811976841, 0.3429025299847126, 0.17255799631987298, 0.10605724222425904, 0.15501397129680428, 0.11557258984872273, 0.21153287137193338, 0.17186705768108368, 0.12183081332061972, 0.13518947150026048, 0.16900460342211382, 0.14229298675698893, 0.09701057230787617, 0.15084577138934815, 0.0942962286727769, 0.08590657742960112, 0.2175595379833664, 0.11478607276720659, 0.18294769738401684], [0.046796012337186506, 0.02536492990995092, 0.008781947112376136, 0.033670186663844755, 0.035431751781808477, 0.04104378939207111, 0.0324647352764649, 0.008841155229934623, 0.03793588526813047, 0.06321682102446045, 0.018991872867835418, 0.03220176902998771, 0.0729052357907806, 0.03504823021856802, 0.03868427885962384, 0.027190519895936762, 0.04969613886039172, 0.09227698988148145, 0.016258272408906902, 0.06103561592421361, 0.043312193027564456, 0.06564195267856121, 0.04854966912950788, 0.8464550652674266, 24.907389879226685, 45.904378754752024, 24.830461161477224, 33.311769349234446, 28.72615282876151, 39.78908852168492, 16.449130603245326, 1.50112085044384, 0.5153448496546064, 3.100381749016898, 3.398161347423281, 6.548777920859201, 0.11480908867503915, 1.739343096102987, 25.866963897432598, 48.27367625917707, 51.128194264003206, 50.43649762017386, 48.459071568080354, 49.965656416756765, 51.9957081249782, 48.61336326599121, 46.504136834825786, 36.970662934439524, 36.28504596437727, 43.045129026685444, 48.356137480054585, 48.86188643319266, 49.69768524169922, 48.664654867989675, 50.29107182366507, 50.90902723584856, 50.80444642475673, 46.69492047173636, 44.49643053327288, 36.53007418768746, 37.531146321977886, 36.44024787630354, 37.44153193065098, 37.002357142312185, 38.973647935049875, 37.0906548500061, 39.312563691820415, 37.38923283985683, 37.30766098839896, 36.85579531533377, 38.23984520775931, 35.98951128550938, 36.194945199149, 35.878416538238525, 35.9146340233939, 38.601519789014546, 37.039265973227366, 40.504412514822825, 43.17663063321795, 42.31354624884469, 42.52354860305786, 39.41594246455601, 37.98107344763619, 37.36967018672398, 38.19340692247663, 42.34548364366804, 44.909681592668804, 48.144140992845806, 48.631699562072754, 50.961079665592735, 46.82548059735979, 43.83843960080828, 48.2420654296875, 48.62127726418631, 45.421621390751426, 47.86433008738926, 47.58069767270769, 42.01128918784005, 38.60403503690447, 35.456841536930625, 34.51536757605416, 34.83902856281826, 35.91170883178711, 35.54404490334647, 35.85034581593105, 33.621162210192, 33.438646929604666, 34.71977663040161, 33.74342966079712, 32.60728107179914, 33.89358718054635, 34.97321217400687, 34.959472111293245, 35.14010443006243, 33.56722681862967, 33.23324080875942, 39.258249623434885, 43.63916179112026, 42.29400444030762, 43.6348226411002, 44.30055734089443, 42.64478424617222, 39.774295806884766, 39.76152154377529, 39.42911972318377, 38.6218432698931, 36.17796727589199, 34.45266008377075, 32.531837531498496, 33.26283666065761, 33.63664627075195, 32.67774622780936, 31.969439915248326, 33.848291873931885, 35.800534180232454, 35.93286262239729, 38.12529373168945, 36.26800203323364, 39.94541951588222, 42.477096421378, 45.74607447215489, 43.98985821860177, 47.88772119794573, 18.231579780578613, 0.2500044091471604, 1.2466722811971391, 2.976904877594539, 3.720242270401546, 7.200872872556959, 1.2008919034685408, 0.8939265693937029, 11.859285235404968, 36.909188747406006, 20.661085162843975, 34.27589096341814, 27.22939794404166, 39.93956913266863, 10.989776372909546, 0.17653642355331353, 0.02687677039232637, 0.012630114281949188, 0.02554395967828376, 0.04493862111121416, 0.04799156389864428, 0.015263031170304333, 0.11492791372750487, 0.04406118033719914, 0.044030541088432074, 0.037084958249969144, 0.032229025781686814, 0.07942565876458373, 0.04831489262038043, 0.07466308253684215, 0.04832938612837877, 0.01616052774313305, 0.05671850132888981, 0.0553773802572063, 0.023588491304378425, 0.006464697861312223, 0.015079087112098932, 0.01723014999047986, 0.01891354957063283, 0.012767542220119919, 0.010177051581974541, 0.023091946163081696, 0.06728375636573349, 0.012966477661393583, 0.05507987318560481, 0.09247419929930142, 0.029193931857922246, 0.06300391030630895, 0.006768263402461473, 0.04011827101930976, 0.07309482526034117, 0.027522009697609713, 0.06410939312939133, 0.0470577741840056, 0.03899970604106784, 0.08852500335446425, 1.8473664138998305, 34.2570161819458, 51.269909722464426, 25.608614240373882, 41.88170181001936, 32.68689005715506, 48.92021656036377, 14.71573223386492, 0.8607567921280861, 0.7014100626111031, 1.4890105745622089, 4.592796615191868, 6.019400315625327, 0.22549934765057905, 2.707515618630818, 30.589433874402726, 49.69842869894845, 53.30922685350691, 51.05676678248814, 50.343839917864116, 49.73916251318795, 55.202694347926546, 50.72359023775373, 48.93439435958862, 38.992331641060964, 39.14485502243042, 43.225806508745464, 51.30510234832764, 50.42736768722534, 52.101289476667134, 50.43479878561837, 53.76449019568307, 52.823603357587544, 52.38516507829939, 47.79246834346226, 46.847134658268516, 38.565048694610596, 39.97727353232247, 38.45649003982544, 39.538751874651226, 37.01860897881644, 40.3166617665972, 38.33008146286011, 40.581005981990266, 38.235975061144146, 39.19234248570034, 37.91360296521868, 39.48462193352835, 38.18671233313424, 38.40993363516671, 36.981682777404785, 37.33604785374233, 40.309119497026714, 39.2901349067688, 39.61944825308663, 44.64840153285435, 44.30210678918021, 42.67353589194161, 41.387028285435264, 40.611560685294016, 37.82585416521345, 40.787280627659385, 43.242624623434885, 47.472069535936626, 48.50579472950527, 50.69692652566092, 50.65271513802664, 47.15567289079939, 43.131849493299214, 49.77000209263393, 50.364472593579976, 46.911773749760215, 49.37683827536446, 48.06566456386021, 43.946397236415315, 39.82103981290545, 37.618895121983115, 37.776612281799316, 36.246556418282644, 37.57323156084333, 36.26368720190865, 36.84414318629673, 35.0718731198992, 36.06892572130476, 36.00563110624041, 35.734515871320454, 33.722741399492534, 35.980186803000315, 35.45780038833618, 36.06136608123779, 35.08177430289132, 35.11626516069685, 33.75331694739205, 40.0784010887146, 45.282841546194895, 43.813738754817415, 46.374882970537456, 46.02031987054007, 43.31426749910627, 42.9630742754255, 40.7643654687064, 42.38989305496216, 40.607287543160574, 38.65032393591744, 35.988830362047466, 34.08982515335083, 34.89408261435372, 34.9134715625218, 34.64742851257324, 34.694311482565745, 35.636535848890034, 37.09695339202881, 38.417510645730154, 38.096729687282014, 39.63076686859131, 41.06653567722866, 44.13342537198748, 46.6644560950143, 45.99295091629028, 49.824635778154644, 18.644747461591447, 0.2629017856504236, 2.885699565921511, 5.586791574954987, 7.987312112535749, 8.70552395071302, 0.716720418206283, 0.880011933190482, 12.408211163112096, 43.56550393785749, 26.425341980797903, 39.39549739020211, 26.596246821539744, 46.461791038513184, 14.394567387444631, 0.2696164867707661, 0.030335204010563235, 0.03486642354567136, 0.05932247106518064, 0.02462548789169107, 0.012490269910943295, 0.02761042450687715, 0.08125061940933977, 0.06967674581600086, 0.017729241334434067, 0.07606746682098933, 0.02570967998222581, 0.049595451048974476, 0.04113589712817754, 0.05697798329804625, 0.03474279446527362, 0.030250315887055228, 0.03222128030444894, 0.2413562632032803, 0.09421527944505215, 0.09389356563666038, 0.1341337931475469, 0.09257349611393043, 0.09317237790673971, 0.17810514223362717, 0.10769233520009688, 0.17045622052890913, 0.18633510704551423, 0.1015198581985065, 0.17964359825210913, 0.21800566118742737, 0.18809825315007142, 0.0912511127867869, 0.13351054516221794, 0.10475013950573546, 0.15987997661743844, 0.1079235595784017, 0.1729570156229394, 0.1313486240272011, 0.1759825489882912, 0.14421113740120614, 1.6267466694116592, 35.274663243974956, 57.91538919721331, 32.11050919124058, 44.6947147505624, 40.696530205862864, 50.0691567829677, 21.41327108655657, 1.778834268450737, 1.881275360073362, 5.1246234604290555, 16.756577968597412, 13.530433825084142, 0.1868720589471715, 2.650483501808984, 28.986128364290508, 50.762333393096924, 53.315150192805696, 51.71349661690848, 49.86676618031093, 54.04859161376953, 57.09679412841797, 53.685614245278494, 51.029286657060894, 41.294377531324116, 41.013204778943745, 46.92985643659319, 53.75950138909476, 54.35668863568987, 54.10853372301374, 51.33202314376831, 54.34546034676688, 55.698142596653526, 54.34579733439854, 49.129951408931184, 49.186961378370015, 40.58655759266445, 41.80246455328805, 40.34082760129656, 41.523768833705354, 39.48006738935198, 43.29171712057931, 41.00713900157383, 43.77413749694824, 40.259109837668284, 42.06040252958025, 39.59618221010481, 42.078947271619526, 39.66345814296177, 39.72972311292376, 39.121953759874614, 40.16946765354702, 42.81462948662894, 41.48305933816092, 44.78672974450247, 46.99744503838675, 47.06794146129063, 45.31345878328596, 44.517806666237966, 41.646995135716026, 40.40153748648507, 41.948946475982666, 45.95175157274519, 48.9962020601545, 49.94784123556954, 51.550738539014546, 54.10312107631138, 48.08399043764387, 43.723106452396934, 49.07771485192435, 51.25483560562134, 48.011784757886616, 51.29212311335972, 50.19261932373047, 44.61841658183506, 42.45416041782924, 39.581069878169465, 39.392235210963655, 38.51744311196463, 40.70602491923741, 38.12776729038784, 39.456523418426514, 36.30053697313581, 37.88714075088501, 37.66038281576974, 37.18946170806885, 35.68546506336757, 37.490860666547505, 38.416593483516145, 38.32512392316546, 36.289610930851524, 35.89534929820469, 35.830960341862266, 42.48398903438023, 47.22485957826887, 44.52721105303083, 47.304346970149446, 48.59245613643101, 45.562141759055, 43.78314931052071, 43.31596980776106, 44.15960618427822, 42.450498717171804, 41.18919570105416, 37.62269926071167, 35.28401551927839, 37.50286020551409, 38.111487661089214, 36.57000201089041, 36.56398834500994, 38.097073623112266, 39.574990204402376, 39.989985261644634, 41.493592807224815, 40.01203536987305, 43.60988555635725, 46.901209013802664, 48.87144020625523, 48.04010214124407, 50.89028099605015, 20.711826120104107, 0.7376157683985574, 4.113461238997323, 9.415524755205427, 11.039779952594213, 15.536917243685041, 5.830411919525691, 1.646152553813798, 16.065880128315516, 47.114115715026855, 28.997928142547607, 46.92584037780762, 32.218647480010986, 52.096005371638704, 20.462498698915752, 0.34970837192876, 0.10658158694526979, 0.16754134265439852, 0.12241096076156412, 0.17304162893976482, 0.1503446325659752, 0.1364483032375574, 0.24264325414385113, 0.10404374383922134, 0.18655553593167237, 0.1891548271690096, 0.07730752349432025, 0.17217778600752354, 0.13000573537179402, 0.14871420791106565, 0.13897796321128095, 0.17286009368087563, 0.09421200212091208], [0.04012623702042869, 0.062397503560142856, 0.06163119325148208, 0.037052931397088935, 0.02962950723511832, 0.037959423647927384, 0.024858369591778944, 0.02197771702360894, 0.03087704475702984, 0.02580275971974645, 0.057341664497341426, 0.0733354269926037, 0.016877937729337385, 0.027834091701411774, 0.054592620581388474, 0.03652482419939978, 0.07762492860534362, 0.04305822415543454, 0.03064567449369601, 0.015473948691838553, 0.01415666625169771, 0.06033650093844958, 0.030409099866769145, 0.03125631869105356, 3.6722779870033264, 37.63100930622646, 30.531777722494944, 35.6337947845459, 37.37028510229928, 25.768256051199778, 34.580802236284526, 0.15193715425474302, 1.3010713564498084, 1.1100152198757445, 1.2998125382832117, 4.028963761670249, 1.297252669930458, 0.25583174931151526, 8.253913623946053, 32.47055789402553, 49.34075975418091, 50.35747923169817, 50.33228506360735, 52.271113872528076, 52.74788188934326, 48.56580284663609, 41.50772196905953, 37.573978492191856, 41.84653697695051, 48.44513348170689, 47.682725020817344, 50.924233368464876, 50.61955486025129, 49.138306617736816, 51.731124196733745, 49.26009464263916, 46.15467023849487, 46.2800053187779, 39.842339515686035, 36.30958352770124, 35.651043687547954, 36.32320894513811, 37.41908924920218, 37.92337213243757, 37.084224292210166, 36.560410022735596, 38.32631206512451, 37.32207155227661, 37.488922119140625, 35.952901227133616, 37.79058163506644, 36.60300595419747, 36.29217481613159, 35.32141419819423, 35.56709207807268, 36.782686369759695, 40.88596589224679, 48.618167945316856, 48.5318991116115, 47.336030755724224, 46.9023346219744, 47.21305111476353, 46.244076183864046, 42.91502053397042, 40.475772040230886, 38.46576241084507, 42.94673906053816, 46.748873233795166, 48.610337325504844, 48.64797919137137, 46.14404991694859, 48.39713879993984, 50.06228501456124, 48.53623478753226, 48.275409834725515, 45.968309129987446, 41.62854072025844, 35.14068113054548, 34.48406246730259, 35.61289112908499, 36.585628509521484, 38.1148818561009, 39.3327898979187, 36.54360580444336, 36.1321508543832, 35.64685392379761, 35.3789244379316, 34.73351321901594, 33.73120430537632, 35.000546387263704, 35.50640651157924, 34.08437776565552, 33.842135769980295, 33.988357135227744, 34.93646315165928, 34.53379767281668, 39.97237505231585, 44.569181646619526, 44.683031354631694, 46.0999253817967, 43.36662564958845, 42.15304980959211, 42.47003705160958, 41.2026161466326, 40.989132744925364, 39.37958601542881, 38.219295910426546, 38.568915367126465, 36.070655822753906, 35.002255644117085, 34.05140856334141, 33.23747226170131, 32.93266521181379, 32.686921324048726, 34.0821647644043, 34.45906284877232, 34.928858348301475, 36.63925470624651, 39.278100626809255, 40.74437550136021, 44.042327540261404, 45.70426716123308, 43.88636132649013, 7.521236504827227, 0.543366554592337, 2.3624185706887926, 4.006877175399235, 3.7712255460875372, 5.522048694746835, 1.37774472790105, 0.20569300545113428, 26.054000718253, 43.0629928452628, 22.801472527640207, 39.67467253548758, 36.46936430249895, 35.283136572156636, 4.373288256781442, 0.2550815338534968, 0.04621836869046092, 0.00910692976322025, 0.04663150491459029, 0.059575333925230164, 0.07956740472997938, 0.031690194338027916, 0.017357256562848176, 0.03196520458108612, 0.03449325303414038, 0.01347963249177805, 0.048214455866920095, 0.04679010908252426, 0.02959524460935167, 0.03143430521179523, 0.04550442432186433, 0.015158762390326177, 0.023779819519924264, 0.019085208752325604, 0.0809825234381216, 0.08558879233896732, 0.06195642865662064, 0.028275066521018744, 0.04809221439063549, 0.03289543537955199, 0.06314061475651604, 0.047649154772183726, 0.026132704157914435, 0.046842926248375855, 0.09526145830750465, 0.05170953207250152, 0.030861960923565284, 0.02923726649688823, 0.022925974801182747, 0.04092919161277158, 0.018765462695487907, 0.030598920038236038, 0.04877768742984959, 0.04860905451433999, 0.0533891369455627, 0.062157614289649894, 0.0652614641668541, 7.099796559129443, 46.92056669507708, 29.445333072117396, 37.47435522079468, 42.15649264199393, 31.841162272862025, 36.53089754922049, 0.07687848580202886, 0.06142101024410554, 1.8025156834295817, 4.015538104942866, 7.472769345555987, 3.2735056706837247, 0.8005338779517582, 10.253974301474434, 37.053732122693745, 51.86103466578892, 50.03348125730242, 51.54412037985665, 54.302881785801475, 53.60353864942278, 49.59926748275757, 41.931621142796104, 39.8510525567191, 43.04667500087193, 50.650394439697266, 49.7664098739624, 52.3992977142334, 52.33409234455654, 50.97134215491158, 52.093264307294575, 51.39557136808123, 50.235576561519075, 48.82285840170724, 42.24909823281424, 38.41331045968192, 39.183379309517996, 37.77089738845825, 40.05957841873169, 38.64150319780622, 38.508511202675955, 38.29080677032471, 39.960469314030235, 39.125830854688374, 38.8918502671378, 37.81355932780674, 37.90087733949934, 38.471525941576274, 38.802725723811555, 38.08971200670515, 36.8947434425354, 39.486682074410574, 43.02938788277762, 49.375417368752615, 50.38422979627337, 49.25295884268624, 49.01448971884591, 47.476339203970774, 45.7051808493478, 43.42809288842337, 40.10544695172991, 40.46283796855381, 43.54188701084682, 48.80415037700108, 50.31865964617048, 52.455050059727256, 46.798455578940256, 48.35695736748831, 54.0144863809858, 50.0419476372855, 50.426856994628906, 47.19651092801775, 44.556306634630474, 37.273041588919504, 35.89735385349819, 36.32842704227993, 37.196972710745676, 39.033322538648335, 40.22146797180176, 37.7819241796221, 37.02127013887678, 36.778218678065706, 36.384669235774446, 35.89678062711443, 35.99290548052107, 35.93136528560093, 36.855378423418315, 36.40425968170166, 36.60942261559622, 34.995557580675396, 35.78463670185634, 35.442788805280415, 41.20863676071167, 46.68963984080723, 46.53952401024954, 47.6706177847726, 45.54486853735787, 44.387684277125764, 43.386834485190256, 42.694154671260286, 43.890763010297505, 41.843872342790874, 39.57340948922293, 40.00476408004761, 37.24103123801095, 37.08161176953997, 35.36661223002842, 35.15881940296718, 33.772848333631245, 34.71103579657418, 36.017383984157014, 35.99319730486189, 36.66080107007708, 38.02709831510271, 40.7076473236084, 42.428101199013845, 45.28648935045515, 47.145618847438264, 43.62134313583374, 8.68138417175838, 0.5870872257011277, 3.8160466381481717, 6.512471846171787, 11.012603810855321, 8.62640220778329, 0.5866297302501542, 0.14584134492490972, 27.07860119002206, 41.83426993233817, 28.461558478219168, 43.849181515829905, 36.8510114806039, 41.84698860985892, 7.284214777605874, 0.1907398985432727, 0.021477979375049472, 0.13018547929823399, 0.054004025379461904, 0.034198863830949576, 0.04361797822639346, 0.024090174652103866, 0.04950893444142171, 0.045730803960136006, 0.032421940072838745, 0.1358722812895264, 0.012907471408003142, 0.05039700446650386, 0.03361006506851741, 0.03859816598040717, 0.01798228400626353, 0.03235406960759844, 0.07143280801496335, 0.10654459321605307, 0.13862272298761777, 0.2076115496456623, 0.12537011983139174, 0.08641586545854807, 0.12529926720474446, 0.08830948706184115, 0.1461559273302555, 0.12724804691970348, 0.1623273031519992, 0.16260817593761853, 0.207168506990586, 0.20376399824661867, 0.09137061637427125, 0.14326224688972744, 0.14437607569353922, 0.1383935817118202, 0.21037837117910385, 0.1109610962282334, 0.09191046562045813, 0.10651118893708501, 0.11880753269152981, 0.1926336490682193, 0.15217048887695583, 6.971868063722338, 52.72413642065865, 39.09546375274658, 46.20165048326765, 47.60684721810477, 35.71122203554426, 41.675979546138215, 0.29820354708603447, 3.24990285720144, 3.6720213379178728, 7.745407973017011, 14.684651204517909, 3.9449795825140814, 0.6713605693408421, 10.70532146521977, 36.02147994722639, 50.79799502236502, 52.023351533072336, 52.94188254220145, 56.364700657980784, 58.038705825805664, 51.69647353036063, 44.16279888153076, 42.85264655521938, 45.467809540884836, 53.57052080971854, 51.30707911082676, 56.07089955466134, 53.23181002480643, 51.52221270969936, 55.447507177080425, 54.53537893295288, 51.45110484531948, 50.258172103336875, 44.81131941931588, 40.248333181653706, 40.633742809295654, 39.568788937159944, 42.13627338409424, 41.44658824375698, 39.860449995313374, 39.98789037976946, 41.16059691565377, 42.29097849982125, 40.94757556915283, 40.87130171912057, 40.60909060069493, 41.092713015420095, 40.41875164849417, 38.97929334640503, 38.5528233391898, 40.44756235395159, 45.36728300367083, 52.08516270773751, 51.73281260899135, 50.72524390901838, 50.290818214416504, 49.50730460030692, 48.34300538471767, 47.642262186322895, 43.104219981602256, 42.200728348323274, 47.43397603716169, 50.164781366075786, 51.18532582691738, 53.61264773777553, 48.409037590026855, 51.825477259499685, 56.80582441602434, 52.06621497017996, 52.994633265904014, 49.461366585322786, 46.08595602852957, 39.48271465301514, 38.320499897003174, 39.943421908787315, 40.24994516372681, 42.36038058144705, 43.910527161189485, 38.83552469526018, 38.416447571345735, 39.70949343272618, 38.24996178490775, 39.01730694089617, 37.70534808295113, 38.9115240914481, 39.42541980743408, 37.84932170595442, 37.71408544267927, 37.22506775174822, 37.90158952985491, 37.392005171094624, 43.694716112954275, 48.628107343401226, 47.87761156899588, 48.67944758278983, 47.022076402391704, 46.19860717228481, 45.741374015808105, 44.43050602504185, 46.01338904244559, 42.916587352752686, 41.60632038116455, 42.0702793938773, 38.71747132710048, 39.59618221010481, 39.192151410239084, 36.54860503332955, 36.17489617211478, 36.55320821489607, 38.83724437441145, 38.192128453935894, 38.959049769810264, 40.19642666407994, 43.48570040294102, 43.82884413855416, 47.79253435134888, 48.206268310546875, 45.504433495657786, 8.810717940330505, 0.9003537616559437, 5.585730671882629, 8.648903948920113, 9.442187598773412, 12.36549016407558, 4.622873195580073, 0.5463426634669304, 32.5542037827628, 52.32554953438895, 32.71939720426287, 47.56202786309378, 42.127136502947124, 50.648834569113596, 8.888193828719002, 0.30561988055706024, 0.18979099446109363, 0.21867770941129752, 0.12796124150710447, 0.11819659333143916, 0.2499458651457514, 0.09762740135192871, 0.1565696213926588, 0.14172502580497945, 0.13447785111410276, 0.21666385818805012, 0.15127510763704777, 0.17382243275642395, 0.08665310165711812, 0.22065839384283337, 0.13964754156768322, 0.13154754335326807, 0.13510568599615777], [0.03047613234126142, 0.009085448192698615, 0.09537550647343908, 0.04088565002062491, 0.02292675681279174, 0.028633048026157275, 0.014380620127277715, 0.007237786310724914, 0.03232073996748243, 0.06470129279685871, 0.06458018786673035, 0.05891692425523486, 0.008843245965960835, 0.016395024356565306, 0.01239475847354957, 0.0323801457083651, 0.033484420739114285, 0.04550921817177108, 0.061529820119696, 0.003958251418745411, 0.04701642086729407, 0.02925718149968556, 0.034937774895557334, 0.021981102913351994, 0.09930826830012457, 11.555112208638873, 40.780370644160676, 22.30844225202288, 43.16892508098057, 28.562166656766617, 39.81965364728655, 4.581538796424866, 1.4199843470539366, 0.2885655542569501, 4.683740283761706, 3.9749410833631242, 1.8107601553201675, 0.4344054199755192, 0.5161595259393964, 11.375835657119751, 39.8801064491272, 51.60930143083845, 52.23263127463204, 53.68364443097796, 50.551969732557026, 47.35928290230887, 37.882756437574116, 41.93317753928048, 48.71101324898856, 49.82273197174072, 50.88072027478899, 51.40997150966099, 50.30994660513741, 50.887925556727815, 48.05557925360543, 48.36053916386196, 43.79847008841378, 41.32850360870361, 40.49788120814732, 40.65201309749058, 35.797355379377095, 37.23501409803118, 35.96960817064558, 37.68453475407192, 36.81271300997053, 36.4713271686009, 35.06170095716204, 37.519664423806326, 37.2436854498727, 37.39777217592512, 35.84843158721924, 37.425405161721365, 35.084876673562185, 36.377064432416645, 35.30008322851998, 36.19590752465384, 45.82917145320347, 48.79804291043963, 48.31464631216866, 51.08655718394688, 48.78232955932617, 47.76852832521711, 48.5026194027492, 46.73206901550293, 46.25667674200875, 43.5358281816755, 42.747468199048726, 44.31722606931414, 47.06004135949271, 50.38027974537441, 49.206881863730295, 49.10944380078997, 47.79443120956421, 47.881655420575825, 42.35583298546927, 39.8096204485212, 36.702038628714426, 35.716943877083914, 37.14849860327584, 38.039431367601665, 41.710004874638145, 44.72450515202114, 43.92144625527518, 43.26395559310913, 37.808653899601524, 33.83044195175171, 35.11908612932478, 33.4134875025068, 34.07049873897007, 34.56400496619088, 34.5908910206386, 35.128754547664094, 34.85516922814505, 36.30567169189453, 33.3119604246957, 34.2539450781686, 39.95038400377546, 44.21283285958426, 45.423945563180105, 44.4519099508013, 43.58373948505947, 41.71033838817051, 40.16575036730085, 39.88197898864746, 39.089550835745676, 40.593696866716655, 39.96102864401681, 39.51818520682198, 37.044709886823384, 37.250418254307334, 34.87681286675589, 33.926865577697754, 33.5327707018171, 33.60854080745152, 33.54191105706351, 34.627990927015034, 36.85857112067086, 38.31836332593645, 40.39396047592163, 42.03045926775251, 46.264330182756694, 47.65974037987845, 33.061422279902864, 1.6799219931874956, 0.4274704392467226, 2.9211104086467197, 6.030285537242889, 16.88479655129569, 8.986000146184649, 0.2460831824157919, 0.16073440148362092, 34.49520737784249, 35.73038169315883, 27.284971373421804, 36.292202608925955, 42.110905511038645, 16.042714834213257, 0.2950632598783289, 0.06932238768786192, 0.048694828126047335, 0.06218456570059061, 0.04677206344370331, 0.08282247970678977, 0.048464112649006505, 0.05229579311396394, 0.005489246944697308, 0.024577934461246644, 0.031407557361360104, 0.034157330702458105, 0.036273080922131024, 0.027197590230831077, 0.06794980634003878, 0.004555938141753099, 0.027733549775023545, 0.055955939926207066, 0.07362815378499882, 0.03726665974993791, 0.13349093550017901, 0.038252089372170825, 0.04824736142264945, 0.07136829290539026, 0.053418588758047135, 0.01958835095034114, 0.07874181081673928, 0.034693716027374776, 0.05882638054234641, 0.02365829050540924, 0.026584857841953635, 0.045354118637208424, 0.03139261602024947, 0.012406967863041376, 0.09145645783948046, 0.013596313373584832, 0.008127853773268206, 0.04088397403912885, 0.027792694279924035, 0.048943640132035525, 0.010558142293510693, 0.0675636792023267, 0.02381601257781897, 0.2503790690430573, 19.5946078981672, 44.75275305339268, 25.61806379045759, 50.0607077734811, 31.491306577410015, 43.6917770249503, 4.743294596672058, 1.0121486485004425, 1.3635056976761137, 2.705122181347438, 4.448592833110264, 6.80138315473284, 1.5540549414498466, 1.2309140924896513, 15.772174562726702, 40.792342390332905, 53.109209060668945, 52.62674004690987, 56.90732022694179, 53.009314809526714, 49.51335300718035, 39.76454748426165, 43.68406105041504, 51.018902574266704, 52.675776958465576, 51.03303173610142, 52.59252711704799, 50.25378431592669, 52.239315441676546, 49.92605863298689, 51.181035314287456, 46.0850180217198, 42.29026630946568, 43.124105725969585, 41.47929341452462, 37.37352296284267, 39.4413138117109, 38.178840024130686, 39.67094482694353, 37.93129307883126, 37.40922280720302, 36.850514684404644, 40.7541446685791, 38.85475383486067, 39.95162078312465, 38.599716731480186, 38.839856897081646, 38.1986597606114, 36.602960790906636, 37.1772016116551, 37.28628485543387, 45.974197728293284, 49.524807112557546, 49.80962072099958, 51.37274653570992, 49.18156610216413, 50.95977340425764, 49.950460706438335, 49.05268049240112, 47.51836885724749, 45.32223088400704, 43.46320561000279, 45.98711790357317, 48.792991570064, 52.44148717607771, 50.6255407333374, 50.53661073957171, 50.02877732685634, 49.89105013438633, 45.72024801799229, 41.581358977726524, 38.19954218183245, 38.00287689481463, 38.354587759290425, 40.71313987459455, 43.49199199676514, 45.937479972839355, 45.6276250566755, 44.73724120003836, 38.83702898025513, 35.14798368726458, 36.26231145858765, 36.03657143456595, 34.89314113344465, 35.67416729245867, 36.81484958103725, 35.759616238730295, 36.49780675343105, 36.95309094020298, 34.71694523947579, 35.78442825589861, 41.942734786442344, 45.426328795296804, 47.411898136138916, 47.068101269858225, 43.34477009092058, 44.26978376933506, 42.4202948978969, 42.05811309814453, 42.366616589682444, 43.08067601067679, 40.95148393086025, 41.0020876611982, 39.395719732557026, 40.24351808003017, 36.44025135040283, 36.253973620278494, 35.71852459226336, 34.751491682870046, 33.8672639301845, 35.148890427180696, 37.29155158996582, 38.87414973122733, 42.32635177884783, 44.119094712393625, 47.705852099827354, 47.51631913866316, 36.37541423525129, 1.667135353599276, 1.0406827288014548, 3.8643366183553423, 8.611177836145673, 18.405791963849747, 3.2637838380677358, 0.4878240664090429, 0.1185246514422553, 37.65286486489432, 41.780348437173025, 35.66766725267683, 37.49518939426967, 45.97673382077898, 25.53884216717311, 0.8275864177516529, 0.09585877946977105, 0.04887221075062241, 0.06481931717800242, 0.08994341295744691, 0.06570864588554416, 0.024648525851911733, 0.029933670735252754, 0.024697477064494575, 0.03326370347557323, 0.031081850374383584, 0.048060380920235596, 0.08240313827991486, 0.06622449534812144, 0.04159205586516431, 0.043378513040287156, 0.03257787420547434, 0.03708087346915688, 0.021119880822620223, 0.07318004247333322, 0.193052508735231, 0.17322859247880323, 0.125947023874947, 0.1951372940093279, 0.12705034895667008, 0.07452141799564872, 0.13635786809027195, 0.14731380662747792, 0.13010756990739278, 0.12878650293818542, 0.14116024039685726, 0.14183079584368638, 0.13775566379938806, 0.09302795851337058, 0.1978874642934118, 0.07409523015043565, 0.11389284926865782, 0.139669037557074, 0.0908891414957387, 0.1868929849671466, 0.08669266703405551, 0.14207574698541844, 0.23226772089089665, 0.288267297404153, 21.046863045011246, 54.184689453669954, 32.50690739495413, 55.076296193259104, 37.48366928100586, 50.11631768090384, 5.901953612055097, 2.0816813835075925, 2.484489300421306, 9.584696888923645, 11.499193974903651, 6.230170011520386, 2.1285767299788336, 0.8952374990497316, 14.175919737134661, 41.21815231868199, 53.33976766041347, 54.28973231996809, 59.61111790793282, 55.528679507119314, 51.45121949059622, 42.02751670564924, 46.44039406095232, 53.79816811425345, 56.08677618844168, 53.31541075025286, 53.174584661211284, 51.28210381099156, 53.13871806008475, 52.71954018729073, 53.16609396253313, 47.59832525253296, 45.73854957308088, 45.13262496675764, 45.43525723048619, 39.87045192718506, 42.12313781465803, 40.70137310028076, 41.52052402496338, 40.22364623206002, 39.41265596662249, 37.81385115214756, 40.88833522796631, 40.90214477266584, 41.62090812410627, 40.65829426901681, 41.053987230573384, 39.22942502158028, 40.10872302736555, 40.25063303538731, 39.63802078792027, 47.48463882718767, 51.58438866479056, 51.90242508479527, 53.58586938040597, 50.75346401759556, 52.68420164925711, 51.785389627729145, 50.7718836920602, 50.13813502447945, 47.53529814311436, 46.93951095853533, 47.43552548544747, 50.54283632550921, 55.188374110630576, 51.518933159964426, 51.40987423488072, 50.68919318062918, 50.956208978380474, 46.88314022336687, 43.383033820560996, 40.027279717581614, 39.258770738329204, 41.556595597948345, 42.44336986541748, 45.26694059371948, 49.468047278267996, 48.29584101268223, 47.133230209350586, 41.730887685503276, 36.60905088697161, 38.557357038770405, 37.914544446127756, 36.88756595339094, 36.546902724674766, 38.42711305618286, 37.57995394298008, 38.69182552610125, 38.96528230394636, 36.469871520996094, 37.25650487627302, 44.17090742928641, 46.02492652620588, 48.54076153891427, 48.30827481406075, 46.86878524507795, 45.21271685191563, 45.13382700511387, 44.074570655822754, 43.74347857066563, 44.98013980048043, 43.48046840940203, 42.750518458230154, 40.40092951910836, 43.12197262900216, 39.22299793788365, 38.901299817221506, 39.135950905936106, 36.85916519165039, 36.53320435115269, 36.283395767211914, 40.4607743535723, 43.04099484852382, 45.19573892865862, 45.38383708681379, 49.841519900730674, 48.89179147992815, 37.50175196783883, 2.1940665415355136, 1.5538533351251056, 6.922531511102404, 14.969848700932094, 26.053926025118145, 17.50677670751299, 2.271496832370758, 0.25068115283335957, 44.74480431420462, 45.74210010256086, 37.41309642791748, 41.4787722996303, 51.21672821044922, 31.534507002149308, 0.945774244410651, 0.17999780710254396, 0.15038869663008622, 0.12496191316417285, 0.13168293823088917, 0.20189358932631357, 0.16147864583347524, 0.19651116457368645, 0.1316174596015896, 0.1368480282170432, 0.11181869663830314, 0.11127968199018921, 0.21939528733491898, 0.170479684269854, 0.3314349353313446, 0.09896517385329519, 0.09292571007141046, 0.32027273571916987, 0.1793264645550932], [0.016067811021847383, 0.00924824401071029, 0.017630517881895815, 0.05636289808899164, 0.03860548737325838, 0.033759142604789565, 0.05812305863946676, 0.047543096356093884, 0.07449539617768355, 0.05481301893347076, 0.04191294864618352, 0.06425198047821011, 0.059831121271210055, 0.05101979783337031, 0.1216705704906157, 0.08552893197962216, 0.03508019261062145, 0.014660602335685065, 0.02226661518216133, 0.015667517769283483, 0.06520073528268508, 0.02609435166232288, 0.11454493499227933, 0.048965960541473966, 0.027561615786648223, 0.4957908274871962, 24.179081439971924, 30.77966512952532, 24.94017321722848, 37.93201569148472, 32.352977003370015, 22.001073053904943, 0.4096087919814246, 1.4490954535348075, 1.6495404520205088, 3.9390766535486494, 5.668834166867392, 1.2970115457262312, 0.727217354944774, 2.220855321202959, 22.7928307056427, 51.17026908057076, 52.8557630947658, 55.04438659123012, 48.97308192934309, 44.211679458618164, 41.00687149592808, 49.98190130506243, 50.255729811532156, 52.18028007234846, 50.16653231212071, 50.89330346243722, 49.99697194780622, 48.80114875520979, 48.09777218954903, 46.659981455121724, 41.57201017652239, 41.84984431947981, 39.90167018345424, 39.95157214573452, 36.56306423459734, 37.47601931435721, 36.15593801225935, 37.00668239593506, 37.34445864813668, 38.39151743480137, 35.902874197278706, 37.527904987335205, 35.965341976710725, 36.49952295848301, 36.46889182499477, 35.02970797674996, 35.35183688572475, 36.31114687238421, 34.535173416137695, 35.916523933410645, 42.448122433253694, 47.96662494114467, 49.27378954206194, 51.058330127171104, 49.502083029065815, 49.265423910958425, 47.96635743549892, 48.87671736308506, 47.69935553414481, 48.42509140287127, 45.75131688799177, 45.321094853537424, 46.93026638031006, 47.66125856127058, 47.600156102861675, 49.79092311859131, 47.568420205797466, 46.31734146390642, 40.464092118399485, 37.972374303000315, 35.90653242383684, 37.72864886692592, 40.59176179340908, 44.75910370690482, 44.62920018604824, 47.271676540374756, 47.70188467843192, 48.76710605621338, 42.37344666889736, 35.357551779065815, 35.38124166216169, 32.91409962517874, 34.65878186907087, 36.33149814605713, 35.838019711630686, 35.74683502742222, 34.25643253326416, 33.932028089250835, 33.37293086733137, 33.6567439351763, 37.080406257084434, 44.1881285394941, 43.530245304107666, 45.461830615997314, 43.31326001031058, 41.52872289930071, 39.332348687308176, 38.20609433310372, 37.3325320652553, 38.33156837735857, 37.902124541146414, 39.60595137732369, 38.515490668160574, 34.93659169333321, 34.456787313733784, 35.44880941935948, 32.966839926583425, 35.93120200293404, 35.2237503187997, 36.59588405064174, 39.721385274614605, 42.30025781903948, 41.9659035546439, 44.77200998578753, 43.589523860386436, 45.7283148765564, 16.981221914291382, 0.05740091417516981, 0.5952498391270638, 3.336619415453502, 10.283240113939558, 15.884410551616124, 4.195813894271851, 0.979988151362964, 2.472727954387665, 34.54986538205828, 30.272582122257777, 29.4184296471732, 28.09375558580671, 33.3935809135437, 5.829172100339617, 0.05169404451070087, 0.0739920928276011, 0.03554433770477772, 0.010271026137551027, 0.054806023237428496, 0.051613661859716685, 0.043876001345259805, 0.041611729988030026, 0.05496639159641095, 0.03899437614849635, 0.039398956046040566, 0.06618518102914095, 0.06418979274375097, 0.06258864008954593, 0.054889455903321505, 0.01982970246379929, 0.028318657306954265, 0.021990632937688912, 0.022576191695407033, 0.018223917111754417, 0.028811641835740635, 0.036302078116152964, 0.03389674950657146, 0.042960057101611576, 0.02681828067371888, 0.01628477089772267, 0.03452730531405125, 0.04372792125546506, 0.08129490739000694, 0.05568924852247749, 0.05298212789265173, 0.060976956571851454, 0.013493933465464838, 0.04887835827789136, 0.060376873772059164, 0.034810505474784544, 0.025602559658831785, 0.04822115979290434, 0.029437990726104805, 0.028125179831736853, 0.050387209813509665, 0.07995801019881453, 0.07277539132961205, 0.020450134528800845, 1.203690073319844, 34.24128198623657, 30.974961621420725, 33.10127714702061, 46.044266836983816, 37.95297840663365, 19.73745938709804, 0.5078267902135849, 0.6617055045706886, 1.9798114555222648, 3.118158280849457, 7.483269810676575, 5.397647712911878, 1.1280721766608102, 3.5790279507637024, 24.18998490061079, 56.089402607509065, 54.51986707959856, 57.77722774233137, 51.82359777178083, 45.95634433201381, 42.16799885886056, 51.327885491507395, 53.23481164659773, 53.875609261649, 52.43927417482649, 50.85056856700352, 53.0430656841823, 51.075877802712576, 49.24010814939226, 46.60568128313337, 43.961318492889404, 43.211715562003, 41.175344467163086, 41.70138216018677, 38.842952319553916, 37.99975715364729, 37.58213220323835, 38.97629519871303, 39.186130796160015, 39.707589626312256, 38.72012553896223, 39.47756951195853, 37.1108706338065, 38.71836764471871, 37.53429733003889, 37.765557697841096, 38.42983675003052, 37.44515889031546, 37.53325162615095, 37.89261940547398, 45.08713163648333, 50.46705232347761, 50.8764089175633, 51.51398604256766, 50.963462897709434, 50.949608189719065, 49.601598603384836, 49.887742791857036, 48.821187359946116, 49.664736883980886, 45.070254462105886, 45.87161105019705, 49.33683054787772, 50.690242358616416, 50.99174901417324, 50.56487601143973, 49.32910762514387, 47.57694911956787, 43.4995551109314, 39.4132639339992, 38.21466841016497, 39.42584712164742, 41.56152881894793, 45.84465898786272, 46.4756110055106, 48.402812004089355, 48.49630696432931, 49.23966693878174, 42.68337106704712, 37.15699277605329, 35.71331344332014, 35.37626327787127, 36.28688723700387, 37.7916898727417, 36.37952756881714, 37.378629888807026, 35.70167868477957, 35.84020839418684, 36.63777821404593, 34.51415164130074, 39.29286902291434, 46.73061684199742, 46.65094879695347, 47.54144035066877, 44.69010462079729, 42.61686291013445, 39.68589735031128, 40.20535509926932, 39.445444515773225, 40.503290380750386, 40.334949425288606, 41.857251099177766, 40.79291214261736, 38.775832721165244, 36.37953104291643, 37.22155196326119, 35.0790228162493, 37.09644617353167, 36.943856784275596, 37.564598424094065, 40.11445181710379, 44.77795764378139, 44.08943632670811, 47.10907827104841, 44.72344207763672, 46.875090735299246, 18.193677357264928, 0.17082611710897513, 1.3519983951534544, 3.323673184428896, 5.686418754713876, 7.664568287985666, 1.4619332275220325, 0.5504092595406941, 2.4798435611384253, 37.358751092638286, 36.96330826623099, 36.458879470825195, 28.243305138179235, 42.87812907355172, 9.320003526551382, 0.10792539840830223, 0.08260954184723751, 0.038230009842664, 0.017100000188552907, 0.040767418686300516, 0.04699149827605911, 0.02085056179203093, 0.06321236983473812, 0.04404932972309845, 0.006368676674485738, 0.008949069439300468, 0.043352321588567326, 0.05224834316010986, 0.07348697778901883, 0.03868972410314849, 0.054233889295054336, 0.025848070591954247, 0.05825288952993495, 0.05950425059667655, 0.09142063119049583, 0.09556175755070788, 0.16094708149986608, 0.1170829138053315, 0.12534593684332712, 0.1460961348244122, 0.2516857646405697, 0.14339374697634152, 0.13207454793155193, 0.2762769050896168, 0.21504666496600422, 0.12060071075601236, 0.11734056712261268, 0.11108222829976253, 0.15731318720749446, 0.16476783076567308, 0.12874999775418214, 0.08360210965786662, 0.185628670666899, 0.15624328676079, 0.17222129367291927, 0.12094508084867682, 0.3251182628529412, 0.11842722738427774, 0.123500525153109, 1.1721880265644617, 37.36840908867972, 41.637826987675254, 33.79882764816284, 47.911084515707834, 42.39398554393223, 27.345163617815288, 0.5892332419753075, 5.609485694340297, 5.334717009748731, 10.968322941235133, 13.71678364276886, 6.591195370469775, 1.5058877489396503, 2.897209256887436, 25.43070387840271, 54.909337929316926, 55.69531467982701, 58.852249554225374, 53.3834753036499, 49.1230275290353, 45.58855881009783, 53.323647839682444, 55.750855105263845, 57.042657239096506, 53.99786976405552, 51.11724042892456, 54.778624943324495, 53.39695828301566, 53.26695053918021, 50.476616518838064, 46.64570985521589, 46.38976601191929, 43.98236806052071, 44.18663467679705, 41.81699323654175, 40.3123573575701, 39.668676240103586, 40.794614451272146, 42.50288118634905, 42.037939003535676, 40.58100250789097, 41.29596866880144, 39.8817184312003, 41.519544328962056, 40.11384037562779, 39.35568421227591, 40.29373618534633, 40.097348826272146, 38.37491818836757, 40.08646099908011, 46.71184975760323, 53.47629281452724, 53.51027645383562, 54.61566536767142, 51.57082578114101, 52.59053298405239, 51.12286499568394, 50.753714152744834, 50.75630235671997, 51.33155414036342, 48.52724034445626, 49.208955901009695, 51.50399453299386, 51.75566176005772, 52.344670976911274, 52.81900017602103, 51.187875815800254, 49.614581312452046, 45.217111587524414, 41.96952704020909, 38.32282754353115, 40.48038216999599, 45.75777523858206, 49.67031281335013, 48.77949469430106, 50.15798602785383, 51.16245583125523, 51.4790609223502, 45.81558772495815, 39.279695238385884, 38.33551148005894, 36.89050504139492, 37.675432613917756, 39.60802888870239, 38.31941597802298, 39.78288378034319, 37.002409253801616, 39.557574544634136, 37.501088414873394, 37.12930767876761, 40.430184909275596, 49.27588789803641, 47.81632150922503, 47.87382132666451, 46.248828751700266, 44.5898733820234, 41.67471497399466, 41.50528315135411, 41.19108213697161, 42.685417311532156, 42.71287311826433, 44.63268123354231, 43.74852991104126, 40.69022471564156, 38.584531443459646, 39.004379817417686, 36.11978306089129, 40.442636081150596, 39.520168917519705, 39.44426679611206, 43.883721011025564, 45.88790804999215, 45.57421772820609, 49.98771347318377, 46.431941577366416, 48.61874117170061, 19.704092400414602, 0.24939009068267687, 2.3946883933884755, 9.203367590904236, 18.490982089723857, 24.87111333438328, 11.757573161806379, 1.3797452662672316, 3.4239830246993472, 44.42189720698765, 39.24946015221732, 40.49352816173008, 35.48656245640346, 49.22119515282767, 11.048291495868138, 0.18081929587892123, 0.1265257192509515, 0.21480220236948558, 0.16587685554155282, 0.1079968549311161, 0.11482978399310793, 0.08092632038252694, 0.10734913218766451, 0.1025129756225007, 0.12389365477221352, 0.1450425192181553, 0.2272935706589903, 0.15339375180857523, 0.2736480975789683, 0.11249318758824042, 0.11175492113190037, 0.13160204328596592, 0.08761757811797516, 0.1465104211653982], [0.012340517232327588, 0.004228432612892772, 0.0981147794851235, 0.08505988107728106, 0.06636639737657138, 0.05258584647838559, 0.058214803359338214, 0.006866501702461392, 0.01405103107182575, 0.01980661361345223, 0.061191665407802374, 0.04094822112736957, 0.059566872593547614, 0.019721767898382883, 0.0814276695517557, 0.021549133949780037, 0.06537345637168203, 0.03412848278614027, 0.017229008355310986, 0.07384174982351915, 0.03889771544241479, 0.044399833772331476, 0.04744648314746363, 0.05602447535576565, 0.010720986457142447, 0.08015005596514259, 3.3339849625314986, 40.82632255554199, 18.913041727883474, 32.71038539069039, 27.860332591193064, 32.29345873423985, 2.553490774972098, 1.3034364581108093, 0.39939323014446665, 3.065895450966699, 6.811263493129185, 2.933765466724123, 0.8053596190043858, 0.9533639571496418, 8.072979927062988, 47.65011017663138, 56.115746702466694, 53.90870353153774, 52.21947833469936, 44.572162423815044, 48.10599538258144, 51.62265934262957, 53.439901624407085, 52.539276123046875, 50.84342929295131, 52.811562129429404, 51.605146408081055, 49.07958739144461, 47.37603153501238, 41.993140493120464, 42.548315456935335, 42.657023497990195, 40.970945835113525, 38.791681562151226, 37.04836811338152, 35.28688859939575, 36.53515679495675, 37.06438371113369, 36.69177961349487, 37.540373529706685, 36.61616236822945, 36.689577034541536, 36.05979926245553, 37.48391594205584, 36.40657343183245, 36.40570143290928, 35.23529127665928, 35.7589179447719, 34.593656403677805, 33.95587430681501, 37.98493317195347, 45.691208021981375, 47.61605358123779, 48.0551449911935, 47.26055942262922, 49.35678230013166, 44.28179720469883, 44.21343387876238, 49.07328884942191, 48.75085769380842, 49.11092029299055, 47.519369397844585, 49.46204056058611, 50.22835043498448, 52.01360668454851, 48.91644368852888, 47.91450650351388, 43.86252205712454, 39.94256380626133, 39.97511959075928, 40.494507857731406, 45.15857301439558, 45.916590213775635, 46.93078402110508, 48.06578615733555, 49.79149634497506, 50.17351177760533, 49.38541235242571, 43.78597027914864, 33.604740142822266, 33.89855514253889, 35.10018355505807, 34.6222482408796, 35.00109529495239, 35.276007720402305, 33.935140882219585, 35.77133437565395, 34.32728678839547, 34.4467054775783, 35.05903284890311, 37.61420856203352, 43.62738459450858, 45.0056084224156, 43.468322958265034, 43.14260877881731, 40.61805377687727, 38.16541263035366, 36.02621167046683, 35.33431005477905, 34.36889954975673, 36.692331995282856, 33.90705278941563, 35.043844086783274, 38.62913193021502, 38.58403812135969, 36.91541085924421, 38.854323046548025, 39.22055912017822, 39.32124546595982, 39.61654390607561, 41.62010908126831, 42.739748750414165, 42.44713231495449, 44.92778164999825, 48.09055301121303, 35.65022380011422, 2.787820509501866, 0.2939333905066763, 0.573889719588416, 1.814664717231478, 3.567882171698979, 9.214419569287982, 0.24054772087505885, 0.22712446616164275, 6.8565878953252515, 34.4649201801845, 33.32099308286394, 25.351025411060878, 29.257318292345317, 19.932891368865967, 0.4524365924298763, 0.053214488817112784, 0.05409626203722187, 0.05253128208486097, 0.06262357107230596, 0.0719609728881291, 0.017806343268603086, 0.060172105474131446, 0.02396725464080061, 0.02430179276104484, 0.03856082619833095, 0.05025853243257318, 0.01191440487413534, 0.0753546522131988, 0.025398625958977, 0.08756247428911072, 0.0539639137818345, 0.031216841523668597, 0.04557244745748384, 0.010196403400706393, 0.009801028678858919, 0.0399720569008163, 0.05383406253531575, 0.060016422399452755, 0.031226140846099173, 0.029523557384631464, 0.06080577575734683, 0.06676859900887523, 0.008875035331584513, 0.05249656144795673, 0.021080060995050838, 0.048764815620545826, 0.03379231618185129, 0.02399060472712985, 0.028070111625960896, 0.07674852598990713, 0.02338381460867822, 0.050409625217850716, 0.06991072504648141, 0.12604218162596226, 0.028112547206027166, 0.04168647062033415, 0.043792677244969776, 0.0767386465200356, 0.015290998687435473, 0.130531762859651, 7.076008532728467, 47.265930380140034, 20.154922791889735, 41.39540433883667, 34.122578961508616, 37.28786904471261, 1.7235904442412513, 0.8076521988425935, 0.2934117599257401, 2.440543029989515, 7.112227754933493, 6.4834557345935275, 2.744936444929668, 1.6003716332571847, 9.950450931276594, 47.81648479189192, 59.87126541137695, 54.478108406066895, 53.60048839024135, 45.486055510384695, 47.87509632110596, 52.974664143153596, 54.8435697555542, 52.480424880981445, 51.13962752478463, 53.335894039699006, 53.58832209450858, 50.81427812576294, 49.077343123299734, 45.28754200254168, 43.40820714405605, 44.90281677246094, 42.49342121396746, 40.95441607066563, 39.65219511304583, 38.666888441358296, 38.07188292912075, 38.83829007829939, 39.66678633008684, 38.34728520257132, 37.68791505268642, 37.65073871612549, 38.51246820177351, 38.647680146353586, 37.591137068612234, 36.45351198741368, 36.98483031136649, 38.543860163007466, 36.02687522343227, 36.99039581843785, 40.88276972089495, 48.27914101736886, 48.520941802433555, 50.50235612051827, 50.44343887056623, 51.30048527036394, 46.191697188786094, 48.147698470524375, 49.62756402151925, 50.37332807268415, 51.48585626057216, 48.25371755872454, 50.03334576742989, 51.42861352648054, 52.09736374446324, 50.884976046425955, 48.43723685400826, 45.59072664805821, 40.472099917275564, 40.663085051945274, 40.89227138246809, 44.296899114336284, 46.96177298682076, 48.65873500279018, 51.63256399972098, 51.42071689878191, 51.63297046933855, 52.29011024747576, 45.74228422982352, 35.73310191290719, 35.41378007616316, 36.66674525397164, 36.05936847414289, 36.494013037000386, 36.40474605560303, 35.469636644635884, 37.274337427956716, 35.667629037584575, 36.25388329369681, 35.22539356776646, 38.512586321149556, 45.395562171936035, 47.11227444240025, 45.49712746483939, 45.45497621808733, 43.123153822762625, 40.450894015175955, 37.65205887385777, 37.58666590281895, 36.762842314583914, 38.041362966809956, 36.01038019997733, 36.93613386154175, 38.6047020639692, 40.88217217581612, 38.18776845932007, 39.577057293483186, 40.12267501013619, 41.3697898047311, 41.51794624328613, 44.35505553654262, 45.47027267728533, 44.529243401118684, 45.5851993560791, 49.01409714562552, 36.39214549745832, 4.592782284532275, 1.1388659860406602, 3.1293146993432726, 4.988302409648895, 6.718305281230381, 5.483383272375379, 0.4693290474159377, 0.4914004345025335, 7.223500115530832, 39.25275707244873, 42.03555577141898, 26.40250846317836, 31.496601104736328, 27.709440299442836, 1.2838486177580697, 0.020813959916787486, 0.024921201934505786, 0.05517607927322388, 0.01667818719787257, 0.05804320185312203, 0.03459296714780586, 0.056551272980868816, 0.034737624028431516, 0.04269220879567521, 0.009783561491141362, 0.09315008803137712, 0.04622051286111985, 0.1001854512308325, 0.013537765979500753, 0.07162861286529473, 0.04553743844319667, 0.05617873689958027, 0.027750307893646613, 0.05374962903027024, 0.13421817576246603, 0.3063956360731806, 0.12890371307730675, 0.15972987110061304, 0.17215597789202416, 0.16459329798817635, 0.16613573022186756, 0.20997899903782777, 0.12464195676147938, 0.13690885209611484, 0.1679225843399763, 0.11428185339484896, 0.18264699780515262, 0.07628543262502976, 0.11931574184979711, 0.15062072846506322, 0.11189170700630971, 0.1882774813898972, 0.12498502406690802, 0.2834533357194492, 0.14235287425773485, 0.09927734067397458, 0.15744531154632568, 0.11963962018489838, 0.18654177524149418, 0.2443618747804846, 7.731682675225394, 55.413832732609336, 27.77196887561253, 42.20329223360334, 37.75404800687517, 42.53851849692208, 3.1696667969226837, 2.450387541736875, 3.022970131465367, 7.531986236572266, 18.142020974840435, 7.235357650688716, 3.40735815678324, 3.0538796271596635, 9.562979425702776, 50.65600858415876, 60.9647034236363, 57.22215005329677, 56.95815324783325, 47.91434669494629, 51.743557998112266, 55.411397389003206, 56.57508863721575, 54.74442938395909, 51.41128471919468, 55.53278241838728, 55.54786695752825, 52.18198585510254, 50.25379821232387, 46.366600717817036, 46.25773286819458, 48.24639068331037, 44.97613763809204, 43.838634150368826, 43.884391512189595, 41.56653847013201, 40.932560511997764, 41.29432889393398, 40.22236428941999, 41.63430772508894, 39.04120874404907, 39.745148113795686, 41.66335119519915, 41.08809246335711, 39.780597823006765, 38.56956154959542, 37.29181214741298, 40.03679527555193, 39.13822296687535, 39.266174043927876, 41.4239718573434, 49.76774740219116, 50.71259123938424, 52.93481969833374, 51.603055000305176, 54.12396567208426, 47.90735680716378, 49.683292048318044, 51.165495668138774, 51.60501091820853, 53.25367947987148, 51.42368377958025, 52.79261439187186, 52.54826361792428, 53.379490511757986, 51.930249146052766, 50.420054708208355, 47.186001777648926, 43.038156509399414, 42.72727673394339, 43.30413007736206, 47.70519202096121, 49.38410609109061, 49.983579295022146, 52.181176389966694, 53.33060993467058, 53.79525681904384, 54.58122662135533, 46.27322735105242, 37.05398920604161, 35.89778811591012, 38.26379564830235, 36.98430224827358, 38.97078875132969, 38.87075901031494, 36.17947850908552, 39.05521283830915, 37.78049979891096, 38.367827551705496, 38.43930714470999, 40.52140086037772, 47.02341045652117, 48.855230058942524, 47.59420149666922, 46.8506886618478, 44.35880061558315, 42.138232776096885, 39.61432048252651, 39.63027354649135, 39.06497853142874, 40.218525409698486, 37.628191811697825, 39.005623544965474, 42.152698925563264, 43.71900354112898, 40.67570645468575, 43.463584286826, 43.3164735521589, 44.03385421207973, 43.709112780434744, 46.32321616581508, 49.491817065647666, 45.62964003426688, 48.353538853781565, 50.886014802115305, 40.33427197592599, 3.715231316430228, 0.6595039027077811, 4.106310674122401, 6.072838042463575, 13.271384137017385, 20.431825876235962, 3.798888061727796, 0.5479898750782013, 8.908020513398306, 46.16507863998413, 41.68003382001604, 33.951417037418906, 41.44929804120745, 32.66916520254952, 0.8416013142892292, 0.0674404843843409, 0.17589621219251836, 0.1495756081172398, 0.1249526986586196, 0.2708874100020954, 0.14457755988197668, 0.166525073615568, 0.0840020856953093, 0.09930661267467908, 0.08405613100954465, 0.18015837562935694, 0.09310069068201951, 0.14210565680904047, 0.09311565916453089, 0.2024983133056334, 0.07068871294281312, 0.10481432891849961, 0.12640133021133287, 0.09494543062256915], [0.028409329941496253, 0.03813326431970511, 0.030443206429481506, 0.07555234339088202, 0.09044238046876021, 0.029131320039076463, 0.02263430313074163, 0.042927039587604146, 0.0418729998969606, 0.020971698952572684, 0.05384334150169577, 0.009632047165983489, 0.02798597837266113, 0.023376481341464177, 0.04765397237081613, 0.02497907418624631, 0.055261754497353516, 0.03916900731357081, 0.03172674023413232, 0.036753928155771325, 0.0344737146182784, 0.07850399786340338, 0.07843944204172917, 0.0484676783505295, 0.06320889573544264, 0.06840264025543417, 0.13218254356512002, 20.16457905088152, 32.4246963092259, 25.231657096317836, 34.002284799303325, 24.520840747015818, 10.5016975573131, 0.4394444924380098, 0.4732818124549729, 2.187338513987405, 4.732306020600455, 8.501880066735403, 1.9320462814399173, 0.36070623035941807, 2.334935405424663, 32.46915088381086, 62.5762825012207, 54.40231398173741, 53.426276206970215, 51.237176758902415, 51.542213099343435, 52.20083631787981, 51.70352595193045, 49.06362043108259, 51.397628034864155, 52.07214525767735, 50.52002886363438, 48.101736136845176, 46.68035704748971, 44.70491818019322, 43.09177575792585, 42.44266809735979, 42.204358782087056, 38.49684517724173, 36.52917092187064, 35.329578331538606, 35.9788874898638, 37.431262493133545, 38.14681577682495, 40.68935966491699, 43.769277232033865, 39.87814358302525, 36.985712732587544, 36.16542230333601, 36.757467882973806, 34.63743005480085, 34.795762130192344, 35.360939025878906, 34.602709906441824, 34.984864303043906, 37.38132578986031, 40.18660191127232, 45.31067255565098, 47.00362546103341, 48.66730907985142, 49.350970132010325, 47.57707071304321, 45.07074083600725, 45.14357532773699, 49.63366106578282, 49.42818546295166, 48.63031339645386, 50.80496059145246, 48.684161935533794, 50.88560485839844, 50.531951972416465, 48.14931392669678, 44.486473764692036, 43.22973918914795, 45.741964612688335, 47.264335768563406, 46.18731982367379, 47.812100478581016, 49.64746366228376, 48.45086227144514, 50.00640065329415, 46.71558094024658, 47.910400118146626, 42.791544096810476, 32.773325647626606, 35.35860095705305, 34.82847772325788, 35.93717745372227, 35.884489263807026, 35.13198546000889, 35.94135332107544, 36.32691580908639, 33.792028835841585, 34.51045519965035, 34.27340350832258, 36.85933542251587, 40.716217926570344, 46.387625966753276, 44.23275334494454, 43.79171643938337, 40.659527574266704, 40.51046092169625, 35.90587581907, 34.23799548830305, 33.755404881068635, 33.62812430518014, 33.92588240759713, 40.115605218069895, 41.42826236997332, 41.68707234518868, 41.31437792096819, 41.77830566678728, 40.33194432939802, 42.94692318780081, 39.833744594029014, 43.88229315621512, 42.81716905321394, 46.518818378448486, 45.7403005191258, 44.00195850644793, 9.148690479142324, 0.07726113205509526, 1.8651681329522813, 1.5008673497608729, 4.966102480888367, 2.8682472109794617, 0.9564278955970491, 0.22491310696516717, 0.11417913676372596, 12.433048367500305, 37.70679330825806, 27.32266013962882, 27.984118223190308, 32.67409494944981, 7.053300082683563, 0.10869997327349015, 0.03299283229612878, 0.011831453119936799, 0.12823830092591898, 0.0038677725907681243, 0.030836325870560746, 0.0638457415625453, 0.07417328203363077, 0.042855932510324886, 0.04004123015329242, 0.04770739343283432, 0.07096940252397742, 0.04927970156339662, 0.04048104637435504, 0.008073556552907186, 0.05567623422081981, 0.013743563954319273, 0.035510302388242314, 0.03411367375935827, 0.048142510798892806, 0.04211107747895377, 0.011709985173573452, 0.005065455600353224, 0.06641079392284155, 0.058255732591663084, 0.05382764020136424, 0.01802625646814704, 0.021375644419874464, 0.035801434623343606, 0.09016532783529588, 0.05289355193131736, 0.009851229244044848, 0.030256968922913074, 0.04811995290219784, 0.02002827912968184, 0.11542152081217084, 0.021123760346589342, 0.0351200294015663, 0.028748113994619677, 0.022109748063875095, 0.05221635701933077, 0.008563044930009969, 0.05655446209545646, 0.040861120979700766, 0.03630729265777128, 0.12568314160619462, 0.2679054657263415, 28.74220837865557, 33.19071435928345, 26.983355283737183, 40.48983519417899, 29.533283369881765, 12.239688685962133, 0.5710344985127449, 0.38637713715434074, 2.541608921119145, 2.2971643464905873, 8.460878746850149, 4.234824120998383, 1.3876781548772539, 2.546298303774425, 35.118453843253, 63.24508135659354, 56.893472467150005, 57.20443214688982, 49.935282366616384, 53.81965889249529, 54.0300920350211, 53.74677923747471, 48.51136371067592, 53.46892424992153, 54.63055188315255, 53.218146392277305, 51.102263586861746, 48.62342425755092, 45.36157853262765, 45.477839265550884, 43.80271543775286, 43.44433430262974, 39.406308787209646, 39.32355574199131, 36.8826014654977, 38.082110677446636, 38.157727922712056, 39.700043882642476, 40.92434079306466, 43.2891080720084, 40.056031363351, 38.91745090484619, 38.316171169281006, 38.3365398134504, 36.2138477734157, 37.169193812779014, 37.69901827403477, 37.06619371686663, 36.957680225372314, 40.65460824966431, 42.20743683406285, 48.22748116084507, 48.53461585726057, 49.67047957011631, 48.877585887908936, 47.68943350655692, 45.77954394476754, 46.84354591369629, 49.64855105536324, 50.84635101045881, 49.145782879420686, 52.260299001421245, 50.087510449545725, 51.81915439878191, 51.386701992579866, 49.449231556483674, 44.6007890020098, 44.248268672398154, 47.43156501225063, 47.98099728993007, 49.57002598898751, 48.49582406452724, 51.148003578186035, 50.30172341210501, 51.29403386797224, 48.34674004146031, 49.25694016047886, 44.275231157030376, 34.412499495915, 37.34031752177647, 35.74038709912981, 36.68649550846645, 37.28651067188808, 37.23089729036604, 36.74522863115583, 37.211900915418354, 35.88177599225725, 36.34744773592268, 37.008297852107454, 37.27893713542393, 42.90624148505074, 47.66605976649693, 45.5383928162711, 45.36820363998413, 42.47485910143171, 41.57458448410034, 37.48792157854353, 36.4980013029916, 35.35616213934762, 35.315824372427805, 35.1554217338562, 40.35590519223894, 43.18077175957816, 41.703737599509104, 42.11954212188721, 43.37691593170166, 41.69539628710066, 43.964705739702495, 41.91011299405779, 45.8498249735151, 44.22207396371024, 47.935239928109304, 47.350413526807515, 45.05812985556466, 10.826708231653486, 0.4737943506666592, 3.356630878789084, 2.8058428338595798, 7.549309832709176, 6.252459832600184, 1.7196470158440726, 0.19852869345673493, 0.03770688309201172, 13.8540427003588, 43.410639013562886, 34.265475613730295, 24.90873956680298, 39.660845620291575, 11.04906187738691, 0.16393663893852914, 0.020800616525645767, 0.049028402726565085, 0.0674701024379049, 0.014280045970476099, 0.04467944448281612, 0.042988026315080266, 0.019736163018803512, 0.032979186956903765, 0.015059869304033262, 0.08522304839321546, 0.020108251266979744, 0.027088503852220516, 0.018075397670535103, 0.02535021418173398, 0.057131800401423655, 0.00993819029203483, 0.02243514122840549, 0.05353234515392354, 0.01033538518406983, 0.11834260049675192, 0.11959358836923327, 0.07691511990768568, 0.11163404690367834, 0.23158316048128263, 0.1799756461488349, 0.08564597248498883, 0.11434678919613361, 0.09373623372188636, 0.2283463313111237, 0.23000325954386167, 0.11143926664122514, 0.12032023152070385, 0.1062757440709642, 0.10578291730156966, 0.225349147138851, 0.16832287928887776, 0.1134051318679537, 0.12020752685410635, 0.14249912569565432, 0.14218258910945483, 0.13699030343975338, 0.16674468825970376, 0.17229951518986905, 0.18368388073784964, 0.27685203137142317, 0.3642004685742514, 32.17229952130999, 45.123891081128804, 34.47294882365635, 43.6829389163426, 35.94900328772408, 14.065767339297704, 0.7021497200642313, 1.9994062440735954, 6.413849115371704, 13.123687148094177, 16.894838435309275, 7.247256875038147, 1.7747687037502016, 3.4928431468350545, 36.30367061070034, 66.37129824502128, 59.692696707589285, 58.308969906398225, 54.911662101745605, 55.60138545717512, 56.581474031720845, 54.09956707273211, 48.90908554622105, 55.38116577693394, 55.23394387108939, 55.58836800711495, 53.95350899015154, 51.22324909482683, 48.534817355019705, 46.948383808135986, 45.55500248500279, 46.804524830409456, 44.128662381853374, 41.96515314919608, 38.83209923335484, 39.48775209699358, 41.70777450289045, 43.241578919546946, 42.71542658124651, 45.98952545438494, 44.00485937935965, 40.390406472342356, 40.82519694737026, 40.987795216696604, 37.93654244286673, 38.62195096697126, 38.79430798121861, 39.30961070741926, 38.81960984638759, 42.542322635650635, 43.9441807610648, 50.614805766514365, 49.352564743586946, 52.12440265927996, 51.51787008558001, 51.06874200275966, 47.85505076817104, 47.70738765171596, 51.68699618748256, 51.48508153642927, 50.25207158497402, 55.25973558425903, 52.43694305419922, 53.38263457162039, 54.06983225686209, 50.873615741729736, 48.9402516910008, 47.10150473458426, 50.05131033488682, 50.09568847928728, 51.41344560895647, 50.170183590480256, 53.349495138440815, 51.79104893548148, 54.59973314830235, 49.75686999729702, 52.326233931950156, 45.85280227661133, 35.59171649387905, 38.76695639746529, 37.099221978868755, 40.23715353012085, 38.918447971343994, 38.017127650124685, 38.976451533181326, 40.379789624895366, 38.05172620500837, 38.81497539792742, 38.524665764399934, 40.35570022038051, 44.45720795222691, 50.304290771484375, 47.22562735421317, 48.68125064032418, 43.070149489811485, 43.621645382472444, 39.98995052065168, 38.40204395566668, 37.64430121013096, 37.225369998386924, 37.90223918642317, 42.762858458927695, 47.019102573394775, 45.27093233380999, 44.131149836948936, 45.949020930698936, 43.61274126597813, 47.44940103803362, 43.17150633675711, 48.16815744127546, 46.30664471217564, 50.487146513802664, 48.05505813871111, 46.078806332179475, 11.51404401234218, 0.2206376442419631, 3.385095477104187, 4.147188663482666, 13.90754382950919, 11.234614389283315, 5.838231248514993, 1.5212590098381042, 0.22063744068145752, 18.307487113135203, 49.056053842817036, 36.34423071997506, 35.851190022059846, 47.28014986855643, 13.006028958729335, 0.4731969141534397, 0.06478114958320345, 0.13774514650659903, 0.20103670816336358, 0.05440136191568204, 0.12626136200768606, 0.20908574839787825, 0.19818897811429842, 0.1638661798621927, 0.12971955644232885, 0.12493752661560263, 0.14323703252843448, 0.15808099029319628, 0.21926015030060494, 0.1303824173020465, 0.13001039012202195, 0.1345019798193659, 0.20001681574753352, 0.11556428458009448, 0.2859104467289788], [0.03744179303092616, 0.018538450323311344, 0.030783926003745625, 0.03820828654404197, 0.052347823179193904, 0.03911185770162514, 0.007254346806023802, 0.00459629061931212, 0.029281618938382183, 0.04549521320898618, 0.05646363679053528, 0.0722356845757791, 0.06337248374308858, 0.05035248578393033, 0.03359846890504871, 0.05617534422448703, 0.023438801390251944, 0.06467791726546628, 0.009292080765590072, 0.025198931406651224, 0.004628711446587528, 0.09173233660736255, 0.051909822039306164, 0.06280062121472188, 0.03597876635779228, 0.015807623376271555, 0.02656651534406202, 3.8518950002534047, 37.71955714906965, 21.769663299833024, 31.873613834381104, 34.85464811325073, 16.04308656283787, 0.39142967175160137, 0.2753659853977816, 0.9217770120927266, 2.95807569367545, 5.404238513537815, 2.452571664537702, 0.7232678468738283, 0.17054521718195506, 16.0016770362854, 58.4807710647583, 55.69810438156128, 55.80349118368966, 52.71187285014561, 53.412546566554475, 52.90802049636841, 52.7003562109811, 53.014616285051616, 53.865770612444194, 51.936405250004356, 49.23609903880528, 48.110741002219065, 48.07048313958304, 45.91370323726109, 44.95258671896798, 43.20821366991316, 39.28032752445766, 35.306037834712434, 35.58797141483852, 37.219609941755024, 36.558335985456196, 38.85314532688686, 46.50967107500349, 48.58248199735369, 49.56081962585449, 48.159128257206504, 43.79596873692104, 38.86780602591378, 37.215750217437744, 34.55831439154488, 36.20615611757551, 35.73351533072335, 36.183605739048545, 34.52467816216605, 35.888790198734824, 36.72925819669451, 39.99934448514666, 44.51809501647949, 46.159672941480366, 48.9011298588344, 48.0770457131522, 48.72326292310442, 47.89665310723441, 49.06327649525234, 48.70760863167899, 49.481182847704204, 47.988080978393555, 46.338060992104666, 50.13910777228219, 50.15733289718628, 48.641861302512034, 46.829864910670686, 46.582342284066335, 49.38738564082554, 48.06199938910348, 59.09044769832066, 50.12725414548601, 48.68211569104876, 48.404979842049734, 48.4146135193961, 48.425716740744456, 46.9195487839835, 37.22531788689749, 32.93841137204851, 36.02959196908133, 33.92740753718785, 35.28510638645717, 37.05840826034546, 35.39025000163487, 35.6267979485648, 35.482952867235454, 34.41840546471732, 35.02335384913853, 35.23626402446202, 34.00708600452968, 39.583744934626985, 44.55927004132952, 44.39766189030239, 46.26538978304182, 41.98725536891392, 40.29413570676531, 37.32293660300118, 34.03022697993687, 35.03463772365025, 34.818197863442556, 40.60161086491176, 44.86108936582293, 46.37472316196987, 45.78031866891043, 41.94371100834438, 45.071213313511436, 44.22212954929897, 44.2089627129691, 43.43141065325056, 43.85373606000628, 44.43079784938267, 45.407978602818076, 44.43576233727591, 15.9133654321943, 0.0803766188078693, 1.0963730833360126, 2.8822169985089983, 1.6154625777687346, 4.223475107124873, 6.059092768601008, 1.8152948319911957, 0.02869645712364997, 0.02250928644623075, 11.81214952468872, 38.97538845879691, 27.766538858413696, 29.173429216657365, 26.208273308617727, 0.7470145097800663, 0.038063605914690664, 0.148390316005264, 0.05326697350080524, 0.024369953300005624, 0.07564693795783178, 0.04181830997445753, 0.05228543188422918, 0.04270532148491059, 0.04022078748260226, 0.016550960185538446, 0.034491339565387795, 0.05572737879785044, 0.10728770441242627, 0.08269876920218978, 0.06172785735023873, 0.0831459712769304, 0.08900973520108632, 0.057661919455443106, 0.04393824336252042, 0.0014551125163312203, 0.03411774157679506, 0.005533955617076052, 0.01573025681344526, 0.025668099356283034, 0.027396294122029628, 0.02019510544570429, 0.02904413846720542, 0.045368924271315336, 0.006200146811482097, 0.030334145495934144, 0.03965529300538557, 0.043676651149455986, 0.027994631390486444, 0.035274402903659005, 0.029288916582507745, 0.03966934207294669, 0.014446741668507457, 0.049289455504289696, 0.05504565805728946, 0.0196993949024805, 0.0349992399902216, 0.05147304565512708, 0.04170379701203533, 0.049809600093535016, 0.06611920028392758, 0.02510124272001641, 0.05185208210189428, 6.6260362437793185, 45.015954290117534, 19.858568225588115, 40.52209220613752, 39.91297837666103, 19.37353358949934, 0.3007726977978434, 0.2815462180546352, 0.8364624700375966, 2.34174268586295, 6.091229924133845, 5.360971212387085, 3.626371673175267, 0.6529845925314086, 16.4069150856563, 60.26555483681815, 56.941210065569194, 55.981844493321006, 53.9289436340332, 56.34265054975237, 54.268505573272705, 53.150721073150635, 53.87407718385969, 55.206706932612825, 53.11006368909563, 51.07361616407122, 50.4599860055106, 47.99797868728638, 46.78814445223127, 46.43549905504499, 46.71737010138375, 40.7350093296596, 38.656219482421875, 37.18866613933018, 38.93876450402396, 39.166502135140554, 39.011189052036826, 46.86640548706055, 49.134902000427246, 50.566939626421245, 49.01105383464268, 43.83037621634347, 40.8938764163426, 37.738744599478586, 36.15649734224592, 37.01891122545515, 38.24288157054356, 37.22013105664934, 36.02987337112427, 36.95508854729788, 39.368295192718506, 42.98665993554251, 46.815767015729634, 48.88907126017979, 49.77662719999041, 49.9841525214059, 51.50739567620413, 49.04290090288435, 48.85249594279698, 49.20634685243879, 51.17999308449881, 50.67497021811349, 47.14817231042044, 48.48778847285679, 51.142788955143516, 49.07764884403774, 48.10535614831107, 48.11128296170916, 51.261144569941926, 50.38533803394863, 54.39879124505179, 50.46573216574532, 50.812283992767334, 49.68675919941494, 50.79994746616909, 50.88351692472185, 49.94851173673357, 39.85588502883911, 34.026106698172434, 37.41395453044346, 35.037868635995046, 36.04417276382446, 38.35416739327567, 34.99573475973946, 36.738231795174734, 35.89293827329363, 35.027269159044536, 36.550599166325156, 36.0827248437064, 36.57173558643886, 41.725012983594624, 46.68486295427595, 45.816070624760215, 47.085593359810964, 43.67779377528599, 41.91197163718087, 38.96694639750889, 36.066667556762695, 37.255170822143555, 36.13846329280308, 40.16556971413748, 46.788533551352366, 48.075694288526265, 46.84199299131121, 44.57949277332851, 46.26955870219639, 45.78774976730347, 45.151416369846885, 44.9020802634103, 46.30675935745239, 46.84571027755737, 46.076833043779644, 46.13518054144723, 19.099724190575735, 0.34443012944289614, 2.258094842944826, 4.1036733984947205, 4.8181531855038235, 6.952708840370178, 2.870603301695415, 1.0089581225599562, 0.10765967730964933, 0.03956041684640305, 13.411472848483495, 46.69692155293056, 28.55655424935477, 30.157950741904124, 34.38895899908883, 1.584269942981856, 0.04167956991919449, 0.024405786734340445, 0.04949067845674498, 0.016268945764750242, 0.054561136556523185, 0.034044938161969185, 0.0824253603017756, 0.005938912949724389, 0.04424794710108212, 0.023850867225389396, 0.034428595432213376, 0.0650060839418854, 0.06964201160839625, 0.011147660303062626, 0.031128384305962493, 0.02811636226916952, 0.045831013404365094, 0.05786419752985239, 0.01151929478094514, 0.03756833641922899, 0.1178066935390234, 0.17519855605704443, 0.14998544326850347, 0.10403200518339872, 0.1265730131417513, 0.09317913611552545, 0.08265843708068132, 0.11458310937242848, 0.06873057622994695, 0.158547917380929, 0.14779042319527694, 0.1673133141760315, 0.16000813831176075, 0.10246541710304362, 0.2356249764561653, 0.1659824355904545, 0.08746370673179626, 0.2897812175963606, 0.11172844469547272, 0.12740633556885378, 0.20649215685469763, 0.15477169358304568, 0.12952702891613754, 0.11025876498648099, 0.15170595023248876, 0.10844976348536355, 0.2017331157944032, 7.222209053380149, 53.43524980545044, 30.80756562096732, 41.291056292397634, 44.75115149361746, 24.717010974884033, 0.6729093662330082, 0.6065985273037637, 3.4957705097539082, 9.450761675834656, 14.892880031040736, 8.225589292390005, 3.1254801622458865, 0.6431188019258636, 19.067244836262294, 62.16658891950335, 59.91863128117153, 59.84013748168945, 55.98168121065412, 59.17602171216692, 56.89907618931362, 55.30597237178257, 55.3319343158177, 57.27243764059884, 55.00426769256592, 53.095667021615164, 52.277106693812776, 51.301423277173726, 49.29556172234671, 49.00963640213013, 49.254112243652344, 44.376188482557026, 40.058536188943044, 39.87982504708426, 42.11052336011614, 40.97485419682094, 41.85547236033848, 49.4333028112139, 53.91561698913574, 54.52363995143345, 52.43787063871111, 47.07486186708723, 42.43585886274065, 39.2533164024353, 38.01576232910156, 39.132914543151855, 40.25909941537039, 41.28833954674857, 38.99464886529105, 39.09470639910017, 40.556145327431814, 43.42317703792027, 49.52041585104806, 51.07680538722447, 52.17249114172799, 51.761275904519216, 52.872841766902376, 51.82722473144531, 51.24475376946585, 50.10913324356079, 52.64470114026751, 52.703132016318186, 46.751701150621685, 50.140924726213726, 51.97387341090611, 51.8513697215489, 50.326302664620535, 51.12987920216152, 52.40697199957711, 52.457426343645366, 55.7940867968968, 52.0097712789263, 52.02150331224714, 52.08408921105521, 51.624389444078716, 53.86612149647304, 51.494399070739746, 41.88526276179722, 35.71190643310547, 39.44217538833618, 37.21535417011806, 37.28723675864083, 40.961485862731934, 36.98107828412737, 38.47730336870466, 38.041720799037385, 36.55975341796875, 37.41422551018851, 38.388870171138215, 37.34909309659685, 43.39429337637765, 48.500792026519775, 46.82197870526995, 51.570672920772004, 45.30511399677822, 45.39470754350935, 40.00915534155709, 37.5930096081325, 39.28671291896275, 38.67223160607474, 42.617210320064, 49.37947164263044, 50.10014574868338, 48.95176485606602, 45.4490841456822, 47.897775241306846, 47.80107716151646, 47.85647167478289, 47.336916651044575, 47.77896799360003, 46.694694655282156, 47.072103432246614, 46.768613065992085, 19.56587188584464, 0.447367257305554, 3.635281869343349, 8.522399834224156, 9.479456867490496, 11.71287018912179, 13.800727435520717, 5.976683224950518, 0.15459511162979261, 0.15893225318619184, 18.84479304722377, 49.66894401822771, 36.10402454648699, 38.72766433443342, 39.624221665518625, 1.6540659006152834, 0.28995815238782335, 0.1685748736241034, 0.19381693271653994, 0.1767273633075612, 0.14454895284559044, 0.14992902986705303, 0.1504699715546199, 0.1775492456342493, 0.10702781871493373, 0.10183280533445732, 0.08782065686370645, 0.16007551683911256, 0.15956349431404046, 0.17250942678323813, 0.10340611769684724, 0.14834089151450566, 0.11535263593707766, 0.11618624334888798, 0.1125812546483108, 0.19042082423610346], [0.061933684162795544, 0.015119865370382155, 0.07002362648823432, 0.033456431169595034, 0.06599776287164007, 0.02171395519482238, 0.09523770279650177, 0.0505906685388514, 0.0701259970664978, 0.08627235530210392, 0.06352376991084643, 0.015830691870568053, 0.11979010568133422, 0.028151359409093857, 0.040539892323847325, 0.012449355945656342, 0.0626079783375774, 0.009963438580078738, 0.021244025589632134, 0.08201822571988616, 0.10572494326957635, 0.09650633936481816, 0.011122603701161487, 0.049355307327849526, 0.028203825433073298, 0.014160856205437864, 0.029480623081326485, 0.02766484810438539, 19.44928285053798, 36.42729296003069, 18.603513377053396, 36.40148735046387, 26.259450265339442, 2.6423104660851613, 0.29971559452159063, 0.15991901952241147, 1.067961573600769, 5.166263146059854, 2.916158948625837, 3.184887911592211, 0.13628016225993633, 1.7859922157866615, 44.92187915529524, 58.86774403708321, 56.04262733459473, 56.17874949319022, 54.87931823730469, 54.5329053742545, 49.59590802873884, 56.724728516169954, 50.29782199859619, 52.568406445639475, 49.739093031202046, 48.920744623456685, 49.13123335157122, 48.18315512793404, 43.56468057632446, 40.377732958112446, 36.97636045728411, 36.82314225605556, 36.509403296879356, 36.46442413330078, 40.29421213694981, 45.47526148387364, 48.46027708053589, 51.218267236437114, 51.43495723179409, 49.94386339187622, 49.40768480300903, 47.360335554395405, 41.333332606724326, 35.578994342258994, 35.35953548976353, 35.65462895802089, 35.66993236541748, 35.9607526915414, 35.687935147966655, 37.70380558286394, 36.55443804604666, 40.07325594765799, 44.246889454977854, 45.64631571088518, 46.96139778409685, 49.38623571395874, 49.30491052355085, 51.22266892024449, 50.36662653514317, 46.98304142270769, 44.97922611236572, 45.00279092788696, 47.36358731133597, 50.196149008614675, 51.66305616923741, 48.534515108381, 48.95164326259068, 48.08424752099173, 52.452263832092285, 66.90269647325788, 49.05314949580601, 51.25245584760393, 50.074673652648926, 47.743028436388286, 46.93969508579799, 39.026648793901714, 34.64122724533081, 34.35584735870361, 35.154532364436555, 33.345002583095, 35.181234291621614, 35.56453514099121, 35.850331919533865, 35.00669206891741, 36.176153796059744, 34.36286503928048, 35.312718527657644, 33.97303288323538, 34.815786838531494, 37.677016803196494, 42.65930250712803, 44.85382155009678, 43.60371903010777, 41.80235685620989, 41.90868861334664, 39.01116473334176, 36.78573315484183, 34.733061586107524, 35.18176235471453, 42.28572218758719, 46.399142605917795, 46.75056512015206, 46.165151596069336, 45.831050940922324, 45.67462267194475, 45.09312793186733, 45.60009976795742, 42.59948546545846, 47.617950439453125, 41.3418858391898, 46.58136606216431, 23.192166260310582, 0.271620933498655, 0.5213501559836524, 2.1623195707798004, 2.944091792617525, 2.3370780561651503, 4.877885111740657, 2.668819146496909, 0.8351578371865409, 0.04197386073480759, 0.20705627729850157, 22.53031039237976, 34.58820901598249, 19.752064500536235, 34.35405124936785, 8.849402904510498, 0.06752616300114564, 0.055158583247768025, 0.03637673053890467, 0.0007843048453131424, 0.08733409297253404, 0.07682176027446985, 0.02677487987758858, 0.03789083054289222, 0.013111824103231941, 0.02799392062505441, 0.0705504207206624, 0.014244836788358433, 0.043582979390131574, 0.04124910730336394, 0.02442578655401511, 0.03319156502506562, 0.03692750759156687, 0.03828618236418281, 0.04959117627835699, 0.06475508026778698, 0.039049161065902026, 0.10108329555285828, 0.0282496350285198, 0.03940274227144463, 0.07197128662041255, 0.0256313414179853, 0.04857793011303459, 0.03884562770170825, 0.06326191646179982, 0.03544996026903391, 0.019745046738535166, 0.037956020794808865, 0.051879946142435074, 0.15575845991926535, 0.0376521219233317, 0.08532681675361735, 0.006628486036788672, 0.053340407953198464, 0.07456623523363046, 0.08950355941695826, 0.05049325805157423, 0.012208111301463629, 0.04087297498647656, 0.010399273496919444, 0.039002148767134974, 0.023268316074141433, 0.01458839772801314, 0.010011343152395316, 0.2615034878253937, 27.88993886538914, 35.18995080675398, 20.62027665546962, 48.27423906326294, 28.457688331604004, 3.4920747194971358, 0.3096854995403971, 0.3889707422682217, 2.1772089089666093, 2.9755860226494923, 4.859742930957249, 5.32775491476059, 0.9021574705839157, 2.629922479391098, 49.37418406350272, 58.894577980041504, 58.069072927747456, 56.403805119650706, 56.650872639247346, 56.30512680326189, 51.57232311793736, 56.526961939675466, 53.09184898648943, 52.95003277914864, 50.49094370433262, 50.75613559995379, 50.30989449364798, 51.60401037761143, 46.1970716203962, 44.2288693019322, 38.94484070369175, 38.7804775919233, 37.90669298171997, 38.63207449231829, 40.53679806845528, 47.1883224759783, 50.15602663585118, 52.63467141560146, 53.6411839893886, 52.276001930236816, 50.181853090013774, 47.5474123273577, 42.734422956194194, 36.58942570005144, 38.08360801424299, 36.34767007827759, 36.27071877888271, 35.977605547223774, 39.007666315351216, 39.48133543559483, 39.172633920397075, 43.59317513874599, 45.868484360831125, 48.442291668483186, 48.394724300929475, 50.69776725769043, 52.20526579448155, 51.46424388885498, 51.399632590157644, 48.50537436349051, 45.55240385872977, 47.14990241186959, 49.77541126523699, 52.48670605250767, 53.34464529582432, 50.691621576036724, 51.28767279216221, 51.073973996298655, 52.0476632799421, 65.64025742667062, 49.99931001663208, 51.061161518096924, 50.30335276467459, 48.75973054340908, 49.165213516780305, 41.21489013944353, 36.127499035426546, 35.74201645169939, 36.87017461231777, 35.02787365232195, 36.66873243876866, 37.117787565503804, 37.87502656664167, 36.711297103336875, 39.01563242503575, 36.40577786309378, 37.30700090953282, 36.21330581392561, 36.33035169328962, 39.99534232275826, 44.897953033447266, 47.36021396092006, 46.03400434766497, 42.77789088657924, 42.803171907152446, 40.45279087339129, 38.79403005327497, 35.53428268432617, 36.381049224308555, 42.7167397907802, 47.62067413330078, 49.08772720609392, 47.119003772735596, 47.290144852229524, 46.99874782562256, 45.54070656640189, 46.689608573913574, 46.34211526598249, 47.32224900381905, 44.211637769426616, 47.76451226643154, 28.469300508499146, 0.7458125257066318, 1.1039166556937354, 5.094318458012172, 4.314425723893302, 3.863329129559653, 4.164276020867484, 2.4317570328712463, 0.21585496302161897, 0.12883851943271502, 0.47731811872550417, 24.03534405572074, 43.185340200151714, 19.772495678492955, 38.68682629721505, 14.161075779369899, 0.17524058451609953, 0.021339783844138895, 0.016788622164832692, 0.026389422793207423, 0.09606165465499673, 0.07610833498516253, 0.02780365092413766, 0.04372020631230303, 0.04720334030155625, 0.05000255848946316, 0.03612236472378884, 0.02016416933786656, 0.06351725597466741, 0.0433327051411782, 0.02189948023962123, 0.04834219686953085, 0.04637153100754533, 0.08027998185051338, 0.042262638453394175, 0.05028139567002654, 0.05399241564529283, 0.28676613367029596, 0.130807492349829, 0.1928125244698354, 0.16445634248001234, 0.11016801771308694, 0.15031793899834156, 0.13521184958517551, 0.17193374410271645, 0.16081445504512104, 0.17010427798543656, 0.11659069093210356, 0.13125019573739596, 0.21555540338158607, 0.1683370199586664, 0.12078458017536572, 0.11014255229383707, 0.11234782503119536, 0.16385353196944508, 0.21234804977263722, 0.18725905460970743, 0.18826910826776708, 0.25434117072394913, 0.06460899167827197, 0.2043974378279277, 0.21260767084147247, 0.0909451749175787, 0.10581090008573872, 0.3190758813704763, 31.445076738085064, 48.02443742752075, 26.013313804353984, 46.161906787327354, 37.06404324940273, 4.841364511421748, 0.6679991611412593, 1.164211928844452, 3.968010255268642, 15.300631591251918, 9.086171456745692, 8.090352160590035, 0.8692729494401387, 2.520994484424591, 49.61609601974487, 61.43287304469517, 59.7547858101981, 59.83209841591971, 58.96519252232143, 57.40423801967076, 51.28486571993147, 59.48536940983364, 55.36953796659197, 56.99724381310599, 54.720544951302664, 53.41735471997942, 52.637975284031455, 52.797217573438374, 47.305257184164866, 46.30119385038103, 42.537879262651714, 41.1458980015346, 39.589689118521555, 39.44525344031197, 43.66643694468907, 50.39909546715872, 52.066440786634175, 53.45313794272286, 55.96613114220755, 54.50348322732108, 53.057208742414204, 51.989048276628765, 45.77526038033621, 39.20197268894741, 38.5486717905317, 39.304861613682334, 39.049761976514546, 38.07227202824184, 40.6868131501334, 42.05332926341465, 40.86684792382376, 44.11134052276611, 47.62285934175764, 50.872438022068565, 50.666479519435335, 52.52056809834072, 54.62791851588658, 54.32395567212786, 53.79116780417306, 49.66461876460484, 46.2991441317967, 47.823547635759624, 49.936619894845144, 54.777982234954834, 55.85735361916678, 53.516700063432964, 52.909080096653526, 53.220394134521484, 52.523128509521484, 65.57979420253209, 51.444594383239746, 54.277604239327566, 53.02881145477295, 52.06050355093819, 52.41435098648071, 43.46364334651402, 37.832083225250244, 37.91453054973057, 38.44830853598458, 35.406883989061626, 38.29699066707066, 39.292987142290386, 40.37121902193342, 39.865313734327046, 40.30394656317574, 37.35225452695574, 40.82158041000366, 37.4300674029759, 38.112311022622244, 41.36558614458357, 46.04351643153599, 48.932570457458496, 47.50115122113909, 45.51020050048828, 45.80434206553868, 42.36354201180594, 40.90508038657052, 38.23634678976876, 37.306681292397634, 44.44274180276053, 50.89770514624459, 51.963940961020334, 49.3512932232448, 46.842100688389365, 48.02143580572945, 47.72725602558681, 49.05790901184082, 45.78069734573364, 49.5482816014971, 44.861662592206685, 47.796032769339426, 27.688903161457606, 0.8325568224702562, 0.7415543113436017, 5.053434823240552, 8.838131189346313, 7.559469836098807, 11.034243106842041, 11.217034578323364, 1.9642151381288255, 0.1358344733182873, 1.1313901586191994, 32.31533861160278, 44.79621750967843, 26.872805970055715, 47.856221539633616, 17.61694039617266, 0.21606719520475182, 0.10995341065738883, 0.10176738098795925, 0.0766352852806449, 0.20614606328308582, 0.1583692862519196, 0.05758699561868395, 0.12266507212604795, 0.11080886689679963, 0.15913273314280169, 0.11576689513666288, 0.139038474964244, 0.23890783744198935, 0.09833070968410798, 0.1424058542719909, 0.0870283247370805, 0.19584383895354612, 0.15990006125399045, 0.15006716602614947, 0.18175593204796314, 0.19127423129975796], [0.007815150061755307, 0.05975522034402404, 0.03414612469662513, 0.02951866514714701, 0.06376815786851303, 0.045104041163410456, 0.022295558093381778, 0.03586083697155118, 0.046913269973759136, 0.030847603122570684, 0.06954842127327408, 0.006544052955827543, 0.03037087798916868, 0.13557776995003223, 0.013602387110170509, 0.031778851723564525, 0.09231813624501228, 0.013177147517645997, 0.09500495849975518, 0.05768353758113725, 0.1078053248514022, 0.09236286527344159, 0.03155910815777523, 0.03998520690947771, 0.04320454005418079, 0.04310207448101469, 0.08051810014460768, 0.08904942271432706, 2.5444381407329013, 31.752982684544154, 27.83000370434352, 27.008040496281215, 40.09457302093506, 12.448944977351598, 0.047718260171157975, 0.3457997388073376, 0.9560262028660093, 1.0796265133789607, 4.195054369313376, 4.8599691816738675, 0.59894866922072, 0.09201251050191266, 9.273277759552002, 54.91545581817627, 56.63603476115635, 55.89932768685477, 55.22473750795637, 52.008687359946116, 55.47926044464111, 53.166302408490864, 51.63141407285418, 50.28953627177647, 51.049578871045796, 50.40416417803083, 49.04715667452131, 44.31966836111886, 41.87765448434012, 37.46377311434065, 36.91515377589634, 38.72867182322911, 38.26508106504168, 38.56732422964913, 44.306015150887625, 48.50233800070626, 52.1630311693464, 49.61531434740339, 50.09406607491629, 51.84178120749337, 50.424953188214985, 49.5831754548209, 46.80220760617937, 38.07717398234776, 36.39324678693499, 36.098848138536724, 36.74946355819702, 37.32660525185721, 36.116017137254985, 37.25684186390468, 39.42657320840018, 39.780768053872244, 40.11541761670794, 42.93145649773734, 47.458753313337056, 47.181120668138774, 48.641173430851524, 46.74871342522757, 51.744047846112935, 48.728564398629324, 50.32844270978655, 41.38965123040335, 43.00994334902082, 47.103575297764365, 50.90474019731794, 49.086212498801096, 50.01085097449166, 49.081751755305696, 49.59225327627999, 37.046613693237305, 46.99817112513951, 48.58447960444859, 47.572894845690044, 46.78152976717268, 41.89324276787894, 35.48951891490391, 33.967658451625276, 34.54636001586914, 34.065423079899375, 34.74652719497681, 34.94224057878767, 34.87022944859096, 35.51331649507795, 36.36570412772042, 34.6879643031529, 35.15695381164551, 34.388649804251536, 33.294961656842915, 33.47729628426688, 36.989298003060476, 43.13759217943464, 43.164846488407676, 44.81557171685355, 41.92922054018293, 41.362831183842246, 39.716514587402344, 37.78917115075247, 33.94549369812012, 35.59695890971592, 37.92247928891863, 43.724728856767925, 46.18663542611258, 48.352208273751394, 46.05795478820801, 46.21932670048305, 44.55760942186628, 46.78646298817226, 45.45132841382708, 45.64719465800694, 43.672481877463206, 38.03526244844709, 2.225392060620444, 0.563786441726344, 1.9010792459760393, 3.69386864559991, 1.7797477394342422, 3.134962716272899, 4.221725029604776, 1.2116404409919466, 0.08215389879686491, 0.04894193022378853, 3.3703976486410414, 37.45154775891985, 24.466399874005997, 24.176010336194718, 33.45988757269723, 1.3283837480204446, 0.21231672859617642, 0.04525566999135273, 0.04173674327986581, 0.03714636566915682, 0.027088877046480775, 0.07930666407836334, 0.034793671020971875, 0.027352136759353534, 0.022536037689340965, 0.01323678226409746, 0.023847505084371994, 0.017244672336216484, 0.017943951866722534, 0.021137363277375698, 0.02203372839306082, 0.044469515926071575, 0.07460012805781194, 0.04819308201383267, 0.0322364659181663, 0.004423885473183223, 0.01828316000423261, 0.023648830030911734, 0.026745475562555448, 0.03756901156157255, 0.03350739932752081, 0.01383038844713675, 0.009796477405221334, 0.02947925583326391, 0.03746553497122867, 0.04531327761443598, 0.03768090198614767, 0.08276751837027924, 0.04538642368944628, 0.02709499912868653, 0.05883062817156315, 0.04020670109561511, 0.03206070838496089, 0.028066493337973952, 0.06712472811341286, 0.14954704179295472, 0.012489386967250278, 0.05998661435608353, 0.08750350959599018, 0.05199932759361608, 0.028562212362885475, 0.029890118965080807, 0.06086737995168992, 0.10470520013145038, 0.09248940526906933, 6.453218477112906, 42.85159042903355, 22.09325306756156, 33.600536482674734, 45.62761810847691, 11.767316273280553, 0.0555936565090503, 0.22352325011576923, 1.3795656987598963, 1.8487740755081177, 3.915251280580248, 4.822347291878291, 3.014853766986302, 0.417736962969814, 12.620244996888296, 56.01510551997593, 56.32505423682076, 59.714229175022666, 56.30474812643868, 52.11862523215157, 54.71972506386893, 54.07139560154506, 53.542314597538535, 52.245704310280935, 52.08763974053519, 51.208209718976704, 51.26360770634243, 46.74998147147042, 44.49059404645647, 39.4723653112139, 38.794349670410156, 39.863100733075825, 39.969491549900596, 40.31705086571829, 45.41923815863473, 50.22803776604788, 53.0528244291033, 52.94931016649519, 52.350167001996724, 54.13218191691807, 52.41227000100272, 51.537787096840994, 48.980829170772004, 38.93285853522164, 38.315201895577566, 36.19367715290615, 36.614946433476035, 38.251976762499126, 38.545034408569336, 38.856612477983745, 40.77657692773001, 40.95512478692191, 43.957236426217214, 46.16235147203718, 49.294922488076345, 50.493733406066895, 50.858291489737375, 50.46173347745623, 52.62461737224034, 49.56385598863874, 47.85473115103585, 43.57890701293945, 44.87873779024397, 49.90276479721069, 51.95928219386509, 52.14239501953125, 50.95586851664952, 50.39271354675293, 49.023063795907156, 44.736841678619385, 49.3520644732884, 50.56247888292585, 49.470131737845286, 48.816737038748606, 44.53611169542585, 37.836345945085796, 35.82167754854475, 35.86438812528338, 35.33833653586251, 36.84123536518642, 35.95259550639561, 35.91030182157244, 37.82320690155029, 37.213512897491455, 35.23972422736031, 36.18802826745169, 34.69824416296822, 33.80925342014858, 34.95440687452044, 37.90030063901629, 44.0703079359872, 44.66821084703718, 46.327471937452046, 44.232920101710725, 43.520924295697895, 41.62914868763515, 37.895370892116, 35.87687751225063, 36.67501361029488, 41.3327385357448, 45.77463504246303, 47.557699135371614, 50.09368739809309, 47.702871322631836, 47.634483678000315, 46.325317995888845, 47.942247186388286, 46.927733761923655, 45.82503032684326, 46.86272989000593, 40.78717987877982, 3.3163647651672363, 1.145582071372441, 2.6848816445895602, 6.547119472708021, 6.592000927243914, 6.3393774543489725, 4.860728706632342, 0.9344634456293923, 0.20678242056497506, 0.04739978976015534, 3.404106834105083, 43.89254174913679, 29.64816835948399, 24.40106075150626, 40.69039147240775, 2.413034677505493, 0.2273251632494586, 0.025684243400714228, 0.02455314588067787, 0.007392259896732867, 0.028418430792433873, 0.014175262352052544, 0.022619085286610892, 0.06335985620639153, 0.06670147153948035, 0.07374219516558306, 0.03925137467948454, 0.04173748627571123, 0.1026608148323638, 0.0236634812983019, 0.025468421767332723, 0.015503247833943792, 0.005028904191151793, 0.03417945094406605, 0.03542085450940898, 0.026682792497532706, 0.027894786658829877, 0.14008754438587598, 0.12995002764676297, 0.11567956767976284, 0.0912877604631441, 0.2121443399893386, 0.1124541921807187, 0.10494703001209668, 0.10931302287748881, 0.14693142500306877, 0.08654250044907842, 0.1638274219419275, 0.1414267010986805, 0.22357667796313763, 0.23519255965948105, 0.1047159820528967, 0.08719609930579152, 0.20370250940322876, 0.17893667332828045, 0.25012950386319843, 0.11818765023989336, 0.18235172650643758, 0.21162777127964155, 0.18319157644041947, 0.12326803191431931, 0.13517172102417263, 0.15439583946551594, 0.20813826923923834, 0.183900971231716, 7.945132204464503, 49.82790837969099, 39.31400544302804, 34.6533761705671, 51.03087779453823, 20.128272976194108, 0.17778213242334978, 0.7142781264015606, 3.0978784433432986, 6.59757034267698, 10.64027156148638, 12.829889518874031, 3.4438546555382863, 0.24991315975785255, 11.24097112246922, 55.68751532690865, 58.093853678022114, 58.18944352013724, 59.08026163918631, 52.771825381687705, 59.94333907536098, 56.48698547908238, 55.859743799482075, 53.753849029541016, 55.49575546809605, 54.45045110157558, 53.804536138262065, 48.79496833256313, 45.2610832623073, 42.09705775124686, 41.81075028010777, 43.133332933698384, 42.66528490611485, 43.93460266930716, 47.15470709119524, 52.2443459374564, 55.084425585610525, 53.331547941480366, 54.91623749051775, 55.56351777485439, 53.9387857573373, 51.670428207942415, 51.94440957478115, 41.015855516706196, 40.789667333875386, 39.30754361833845, 40.79023708615984, 41.45301880155291, 39.30149868556431, 40.89169815608433, 42.99325030190604, 44.931370394570486, 45.03529460089547, 46.84674555914742, 51.08560528073992, 50.83765533992222, 51.692888259887695, 51.24677569525582, 54.056140831538606, 53.140979698726106, 50.8306793485369, 44.06275871821812, 45.48415865216936, 48.2337658064706, 53.708717005593435, 52.34358705793108, 51.6277072089059, 51.82530008043562, 47.909437792641775, 45.030479499271934, 50.88064384460449, 51.45484297616141, 51.70517267499651, 51.02358218601772, 45.77605594907488, 39.53793546131679, 36.97436285018921, 38.16656255722046, 37.28210203988211, 38.20728594916207, 37.72737039838518, 36.99441882542202, 39.128651823316304, 39.22202171598162, 37.27060277121407, 38.794203758239746, 36.61336919239589, 34.4968923160008, 36.054678440093994, 40.83798163277762, 45.37684025083269, 47.4900028364999, 47.83190631866455, 45.845065457480295, 45.18432651247297, 42.947183745247976, 40.13733223506382, 37.98448848724365, 38.54611485345023, 41.79807676587786, 47.514988558632986, 49.7942339352199, 51.37104075295584, 49.53717490604946, 51.52619055339268, 47.14203010286604, 51.25082996913365, 47.890615122658865, 46.82697098595755, 44.98641402380807, 42.92616197041103, 3.631360479763576, 0.8717712068131992, 3.5577243396214078, 10.149978007589068, 9.112157719475881, 8.589202421052114, 14.847279003688268, 3.6121541389397214, 0.48727201031787054, 0.138746406350817, 6.615892308098929, 49.91815505708967, 32.61541741234915, 32.80208076749529, 46.976121016911094, 2.9784445549760545, 0.35627745943410055, 0.1509939091546195, 0.13558698445558548, 0.1689593315656696, 0.15157496583248886, 0.1954462310033185, 0.09185181305344615, 0.3148266779524939, 0.20962487161159515, 0.17829742548721178, 0.1652897327606167, 0.08855004129665238, 0.17949133499392442, 0.18524916603096894, 0.1321915273687669, 0.1447610900338207, 0.12642995081841946, 0.16986110460545334, 0.09855964739939996, 0.12827693670988083, 0.07321451205228056], [0.04232040213953171, 0.0545166009105742, 0.059105285576411655, 0.055128130596131086, 0.01514659625744181, 0.01493634539656341, 0.11807406347777162, 0.045283802053225894, 0.021266973643962826, 0.02631754388234445, 0.10404033759342772, 0.08616664633154869, 0.015606320695951581, 0.03347190176802022, 0.018446637749938027, 0.03711504449269601, 0.03053565343309726, 0.024683338091043488, 0.04488621445904885, 0.04461676820314356, 0.08783044812402555, 0.01933204791774707, 0.04264344248388495, 0.04323424970997231, 0.07801725076777594, 0.0556046521690275, 0.06756361134882484, 0.025754558288359215, 0.24368580962930406, 16.260789258139475, 38.69535868508475, 21.546351671218872, 34.87261962890625, 26.40363233430045, 1.799507113439696, 0.24110534095338412, 0.8565381499273437, 1.4240566428218568, 2.438618596111025, 2.907047037567411, 1.3861790810312544, 0.5461373659116882, 0.33272602462342804, 12.931948133877345, 59.809996196201865, 51.48987231935774, 54.78585106985909, 53.48225089481899, 58.01817042487008, 55.09714426313128, 52.05200590406145, 48.22303083964756, 48.62012733731951, 44.889778477805, 43.7546512739999, 40.79912035805838, 40.36623368944441, 38.23270245960781, 38.98343447276524, 37.2106363432748, 38.11615685054234, 41.53431967326573, 48.33307293483189, 49.41523402077811, 50.268438066755024, 54.01555987766811, 54.49845620564052, 48.30034344536917, 49.17106737409319, 49.342343943459646, 50.90114450454712, 43.1944180216108, 36.42380843843733, 35.79831770488194, 36.76797355924334, 35.492791516440256, 37.39060858317784, 36.84777362006051, 38.37619318280901, 40.38316992350987, 41.97122240066528, 43.29460757119315, 44.91320085525513, 45.30037185123989, 46.77749981198992, 50.03832762581961, 45.826517241341726, 49.60714326586042, 48.893441677093506, 45.22147158214024, 43.753292901175364, 47.65826736177717, 46.26395150593349, 49.67538499832153, 48.40054341724941, 47.92651993887765, 44.67825099400112, 37.66974203927176, 51.693555286952424, 48.27574334825788, 46.481027126312256, 41.8420102255685, 37.97433369500296, 35.620516777038574, 35.30232402256557, 35.07165077754429, 35.1266770362854, 35.43878664289202, 36.372638429914204, 36.01528910228184, 35.76206200463431, 35.49963549205235, 35.6982810156686, 36.976923261369976, 33.565972668784006, 35.18581315449306, 35.26232671737671, 37.2124011857169, 39.180342946733745, 43.85948569434029, 41.00742735181536, 41.825178214481895, 39.31560352870396, 40.07117148808071, 38.37138155528477, 35.42076301574707, 33.823611872536794, 36.82469170434134, 40.660694871629985, 40.96653372900826, 39.51398849487305, 43.56096676417759, 42.58015557697841, 45.23811946596418, 42.76414734976632, 46.584708145686555, 46.14915336881365, 48.91855246680123, 14.714130674089704, 0.1606753689369985, 1.259311380130904, 2.1410984694957733, 6.35000342130661, 4.103992147105081, 4.92771498646055, 1.7373803385666438, 0.5374473407864571, 0.04607401375791856, 0.014701446751132607, 15.435523918696813, 44.18456758771624, 20.024378299713135, 33.025170053754536, 20.10520669392177, 0.1031682233193091, 0.01691716892777809, 0.05796618812850543, 0.0995676993791546, 0.01810874597036413, 0.05267199328435319, 0.011548828865800585, 0.03353130750890289, 0.07641964006636824, 0.09787939568715436, 0.030321280471980572, 0.04344462949250426, 0.022927711850830486, 0.04147947333487017, 0.05772766949875014, 0.0750515777617693, 0.02550061995030514, 0.012643982689561588, 0.010557282250374556, 0.07379992492496967, 0.08651620721710579, 0.04393847067175167, 0.022316339924665432, 0.018301799361194884, 0.03562423859589866, 0.0450036145879754, 0.016987320967018604, 0.02679694414005748, 0.04021867384601917, 0.030360662644462924, 0.06479326143328633, 0.06641919418637242, 0.06548675136374575, 0.061632753882024965, 0.06497061691646065, 0.09436769198094096, 0.03565376165456005, 0.05480188078113964, 0.0324933524908764, 0.06019275329474892, 0.022325793613812754, 0.021270788707105175, 0.06857793977750198, 0.015512409753033092, 0.10581552090921573, 0.021664573112502694, 0.016545238438993692, 0.06271372802023377, 0.03354493588475244, 0.017991062553067292, 0.622788589979921, 25.800240346363612, 41.470295497349326, 19.578302213123866, 47.612325872693745, 30.8995041847229, 2.051838653428214, 0.14020577232752526, 0.8853473897491182, 0.7859069971101624, 2.39687425323895, 5.77280136517116, 4.973856670515878, 1.6968615927866526, 0.7681527212262154, 17.92015109743391, 64.32320553915841, 49.72223322732108, 57.08852229799543, 54.215285846165244, 61.60089438302176, 55.64172669819423, 54.72443246841431, 51.062054361615864, 50.80130583899361, 47.797394616263254, 48.00381170000349, 42.40889637810843, 42.54018259048462, 40.384778431483674, 40.772703307015554, 39.650065490177695, 40.03913681847708, 42.87160471507481, 48.589972155434744, 52.12227651051113, 54.95036704199654, 54.08287402561733, 54.13709429332188, 49.57023096084595, 50.702745641980854, 50.982990809849326, 53.149126461574006, 44.73992320469448, 37.39937720979963, 36.5487961087908, 38.75174331665039, 37.92184352874756, 39.905932903289795, 38.25979348591396, 40.30350535256522, 40.798550605773926, 43.679742744990754, 44.74308116095406, 47.80817822047642, 47.858750683920725, 48.086078371320454, 51.447912148066926, 47.91683415004185, 50.59627144677298, 52.88705083302089, 46.95750331878662, 45.71090963908604, 46.48424761635916, 49.16913577488491, 50.4942684173584, 51.06610516139439, 48.070076669965474, 45.853066308157786, 39.05512251172747, 52.40529400961739, 49.85043443952288, 49.01073769160679, 44.25623478208269, 38.99375254767281, 37.499872480119976, 36.31060143879482, 34.91612924848284, 36.088766302381245, 36.11331081390381, 38.19383423668997, 37.7781617300851, 38.32954297746931, 37.03580229622977, 37.13824306215559, 37.0436954498291, 35.97020918982369, 37.30990525654384, 36.735334396362305, 39.80671957560948, 41.462190423692974, 44.991051946367534, 43.165770598820274, 43.643282072884695, 41.504946163722444, 42.69988693509783, 40.919126170022146, 36.58979048047747, 36.04454796654837, 38.70635073525565, 41.80233253751482, 43.98010294778006, 42.850582940237864, 45.229375158037456, 45.342721121651785, 47.05711269378662, 45.56702981676374, 47.37385674885341, 47.04980318886893, 48.919990743909565, 17.916649205344065, 0.12684951616185053, 2.7708443232945035, 4.45426082611084, 8.398025342396327, 8.17610682759966, 6.071251247610364, 2.2587078043392728, 0.4231756382754871, 0.08959951105394534, 0.08318607948188271, 15.57321810722351, 52.35669483457293, 21.64586898258754, 33.76568126678467, 27.0422134740012, 0.25513508383716854, 0.06113415277962174, 0.03715862001159361, 0.05487597680517605, 0.031227212931428636, 0.008896116566445147, 0.062498109947357855, 0.035533576139381955, 0.048523959437651296, 0.017406877828761935, 0.026939865667372942, 0.04831545241177082, 0.01380158293925758, 0.060798868270856996, 0.013085506274364889, 0.03191989879789097, 0.019643676999424185, 0.04496229180533971, 0.009568867074059588, 0.051207840243088346, 0.04929097542273147, 0.0704666759286608, 0.13742293736764363, 0.10000012974653925, 0.13436969263213022, 0.0937773800854172, 0.09458712342062167, 0.09308494188423667, 0.14428171861384595, 0.18140043398099287, 0.11975046566554479, 0.18958444840141706, 0.19453920610249043, 0.16745265812746116, 0.15680011973849364, 0.15744208171963692, 0.05907874807183232, 0.28124215294207844, 0.12530143851680414, 0.13860814805541719, 0.08974176592060498, 0.09481225455445902, 0.206085415823119, 0.1450495488409485, 0.13461149537137576, 0.13912223332694598, 0.11419527232646942, 0.22183390147984028, 0.13027762435376644, 0.10559904788221632, 1.1123735904693604, 33.91290317262922, 51.0539527620588, 29.38277496610369, 44.9587984085083, 39.57355192729405, 3.2690755426883698, 0.36716007547719137, 2.9088427126407623, 3.077802274908338, 9.439139076641627, 11.84132935319628, 5.6594263059752326, 1.9910414814949036, 0.8781336396932602, 15.432656049728394, 63.44593293326241, 51.95391123635428, 56.43847663061959, 55.86836651393345, 61.22721331460135, 58.35785048348563, 55.84372125353132, 52.78793478012085, 52.904963288988384, 49.333742073604036, 48.35534538541521, 43.85548005785261, 46.3017566544669, 42.475331578935894, 42.619458062308176, 41.99237619127546, 41.76769576753889, 44.19686589922224, 51.21068327767508, 52.71414143698556, 55.86990206582205, 57.64363125392369, 55.5095511163984, 50.42010334559849, 50.692069734845845, 54.31129952839443, 56.2244999068124, 47.66576794215611, 41.23781572069441, 38.35494211741856, 42.06254604884556, 39.25120415006365, 41.086202553340364, 41.22095939091274, 42.527102606637136, 43.95569045203072, 45.57331098828997, 47.83999054772513, 48.93347372327532, 49.79835769108364, 50.689874104091096, 52.923358644757954, 50.7324526650565, 53.23999847684588, 54.674214363098145, 48.76817260469709, 46.98932606833321, 47.658555712018696, 49.967664446149556, 51.309010710035054, 51.06862040928432, 48.10966750553676, 46.22452742712838, 43.90748732430594, 54.09827470779419, 51.209974561418804, 50.03606946127755, 44.896261147090364, 42.200259344918386, 40.35177101407732, 38.469295569828574, 37.92422328676496, 38.52967194148472, 38.488344056265696, 39.26641028267996, 39.999479975019185, 40.01741327558245, 38.72312716075352, 39.68222522735596, 40.03248739242554, 36.49600369589669, 38.22966262272426, 39.54240662711007, 41.449732303619385, 42.183826855250764, 47.17636810030256, 44.88339308329991, 45.74748495646885, 42.4206040927342, 44.20899050576346, 43.26893745149885, 38.540153299059185, 37.4304495538984, 40.54385049002511, 44.83632598604475, 45.83219739368984, 43.21634653636387, 46.79318537030901, 45.5976505279541, 50.42925064904349, 46.07114246913365, 49.744123526981895, 48.41698980331421, 51.00320659364973, 16.809867177690776, 0.28248970742736546, 2.340798165116991, 6.8590592827115735, 12.536138789994375, 10.377969247954232, 9.835167288780212, 6.270692339965275, 2.7061778732708524, 0.22449489869177341, 0.3143948311252253, 23.013159820011683, 54.89341960634504, 27.554115056991577, 44.62098046711513, 31.54537398474557, 0.21862356231680938, 0.16805800635899815, 0.1118435717320868, 0.1916223197643246, 0.08982361759990454, 0.18411004144166196, 0.1674876298223223, 0.10463631525635719, 0.20834214187094144, 0.13164495384054525, 0.09838090091943741, 0.11182083402361188, 0.11824304583881583, 0.1523890450064625, 0.18866700120270252, 0.15543843566307, 0.09600251354277134, 0.11287842584507805, 0.06637194779302392, 0.11642310635319778, 0.23841834227953637, 0.21108312479087285], [0.02778724394738674, 0.03138865337574056, 0.03750028953488384, 0.03092513931915164, 0.07603744843176433, 0.03225668626172202, 0.07918162364512682, 0.05992462339677981, 0.029961327822612863, 0.023886824492365122, 0.039735000514026196, 0.03735485573166183, 0.0367761807117079, 0.018333351239562035, 0.05969430147004979, 0.09113703069410153, 0.00905242474150977, 0.030507151569638933, 0.03044480437945042, 0.06134943158498832, 0.04352684418803879, 0.03667106206661888, 0.012522608041763306, 0.0490581191677068, 0.018573327023269873, 0.033945956866123846, 0.017809627378093343, 0.01227923110127449, 0.10345381870865822, 4.435876761163984, 29.533606461116246, 30.58381278174264, 27.823190995625087, 43.88012184415545, 10.81072129522051, 0.06568809984517948, 0.7959584348968097, 0.8103272010173116, 1.4365381045000893, 3.069459442581449, 5.366949703012194, 1.6387072333267756, 0.1413814156715359, 0.12158232022609029, 16.198026180267334, 56.6909533228193, 56.834853989737375, 58.23386335372925, 55.888881070273264, 53.69831902640206, 53.9722899709429, 49.06757048198155, 47.28139359610421, 43.90842185701643, 42.69381768362862, 40.4781413759504, 39.79091589791434, 39.752805028642925, 40.11193656921387, 38.2240241595677, 40.61094229561942, 46.429395062582834, 47.518143040793284, 50.46820225034441, 54.07944161551339, 52.05555990764073, 49.72411271503994, 47.864013944353374, 48.24969802583967, 51.25942836488996, 51.094356536865234, 44.762028898511616, 36.85551738739014, 35.756896018981934, 36.65404394694737, 36.78372859954834, 36.556946345738, 38.50228214263916, 37.72704383305141, 40.90806116376604, 43.84288992200579, 46.167260374341694, 48.89922257832119, 48.40983663286482, 45.77150140489851, 49.29563467843192, 48.684353010995046, 45.24885095868792, 47.03370768683297, 44.949720587049214, 43.01904548917498, 49.49418987546648, 48.33703688212803, 50.94533504758562, 48.35264948436192, 50.07432624271938, 45.811175618852886, 42.2389851297651, 51.18675020762852, 46.951673780168804, 44.18614482879639, 37.641817229134695, 38.32609667096819, 34.929476737976074, 35.0474328313555, 34.164011069706504, 35.08358083452497, 36.12213850021362, 36.34119783129011, 39.66114786693028, 38.443295410701204, 35.22603627613613, 35.56052950450352, 35.994850976126536, 36.93971913201468, 34.91492026192801, 35.30971343176705, 36.98538964135306, 40.18471894945417, 42.220006125313894, 42.28573955808367, 42.06166015352522, 39.58618375233242, 38.950545174734934, 37.47168711253575, 35.34015696389334, 34.68318394252232, 36.926027706691194, 36.794821398598806, 38.995215143476216, 39.349250180380686, 40.749920163835796, 39.44573981421334, 43.42773505619594, 42.590473651885986, 47.04299395424979, 46.001827239990234, 37.52251318522862, 1.7632186263799667, 0.1650197843887976, 2.0715880393981934, 3.3252732242856706, 5.888932687895639, 9.360873699188232, 4.688597074576786, 1.8370044784886497, 0.3457462973892689, 0.05994547477790287, 0.6736674798386437, 30.52254009246826, 32.24865674972534, 18.127334220068796, 39.518393652779714, 5.049434397901807, 0.04247435155723776, 0.0641688531530755, 0.05743831502539771, 0.06892788742801972, 0.009994466290143984, 0.006372891649204705, 0.06792254280298948, 0.0428867006807455, 0.03984116410304393, 0.055231091499860795, 0.049966725055128336, 0.00906380292560373, 0.05135657511917608, 0.10443859015192304, 0.010582864716915148, 0.04423001002786415, 0.03858911093058331, 0.0341219892060118, 0.035437285234885554, 0.03110772291464465, 0.055987627511577945, 0.014721714592139636, 0.014330442462648665, 0.031906867532857826, 0.04506976496694343, 0.046461369044014385, 0.07673833439392702, 0.033074633085301945, 0.09966588339635304, 0.0497840023599565, 0.003806042019277811, 0.02844168758019805, 0.023375585675239563, 0.014241764721061503, 0.010975490523768323, 0.03637208257402692, 0.0461008532105812, 0.05283998837694526, 0.02053950267976948, 0.042132766850824864, 0.045956230256706476, 0.06094245985150337, 0.014544805245740073, 0.05625977772953255, 0.029646107594349554, 0.031115777125316005, 0.034717586889330826, 0.05416016307260309, 0.042936874952699454, 0.10324210221213953, 0.07427997487996306, 9.006792630468096, 42.337917055402485, 26.936547006879533, 29.244599614824565, 45.04435157775879, 11.495567883763995, 0.048598669535879574, 0.18775986773627146, 1.4511550515890121, 1.0322292681251253, 3.570601088660104, 4.740034588745662, 3.8315589257649014, 1.1599682079894202, 0.2274982032499143, 20.001673323767527, 61.29575034550258, 54.10121379579817, 57.98453766959054, 56.39050279344831, 57.28320040021624, 54.421616077423096, 51.386340686253135, 48.1105568749564, 46.765628814697266, 44.305921350206646, 42.02219091142927, 42.02621391841343, 41.04264777047293, 41.41745444706508, 39.90001303809029, 41.368337631225586, 47.65699584143502, 50.01690632956368, 53.273019790649414, 55.66909217834473, 54.15479482923235, 52.63988256454468, 51.55598790305001, 49.525911876133506, 53.74122762680054, 52.15541246959141, 46.93058599744524, 38.0699964932033, 38.02323859078543, 38.45310626711164, 38.51690810067313, 38.798893792288645, 39.765350001198904, 39.475773402622764, 42.65781559262957, 45.38611609595162, 47.215413502284456, 51.02727515356881, 50.21809489386422, 47.4132148197719, 52.298475878579275, 51.22365209034511, 48.63117497307913, 49.73342677525112, 48.66312626429966, 43.31952381134033, 48.37064184461321, 50.589920793260845, 51.51663678033011, 49.28184945242745, 51.370186124529155, 47.16540731702532, 43.21575941358294, 52.742583887917654, 49.11766699382237, 46.805931840624126, 41.16218457903181, 39.803408758980886, 37.6946895463126, 36.26554931913103, 36.635714599064414, 35.66666323798043, 37.05250576564244, 37.908926827566965, 41.18397412981306, 38.8786278452192, 37.3150851385934, 36.061393874032156, 37.1708961214338, 37.91191455296108, 35.968857765197754, 36.39990316118513, 38.3520690373012, 42.20586306708199, 43.4778003011431, 42.38900021144322, 43.97650030681065, 41.839998722076416, 40.77715710231236, 39.80179330280849, 36.96484729221889, 35.784869466509136, 37.46249464579991, 37.79527166911534, 39.954990659441265, 40.290786675044465, 42.79610211508614, 41.5304981640407, 45.1279627255031, 44.484302452632356, 48.701021739414756, 47.192852701459614, 41.038861002240864, 2.2924356630870273, 0.4986935460141727, 2.753566324710846, 5.555433051926749, 8.356151155063085, 9.719419854027883, 6.205446583884103, 1.4622023616518294, 0.17380445157842977, 0.102120531323765, 1.1556699872016907, 34.15544741494315, 43.29945741380964, 18.727160045078822, 43.6671004976545, 8.5077816929136, 0.22538828503872665, 0.07159402115004403, 0.04611077678522893, 0.08399312903306314, 0.05031798227823206, 0.09719279288713421, 0.014142588346398302, 0.02049729780160955, 0.028872798196971416, 0.05336029242191996, 0.04005232759352241, 0.023090500883491974, 0.024110863184822456, 0.015123003594843405, 0.04293449668745909, 0.04948985742937241, 0.006477707498041647, 0.03902132755943707, 0.014444614461223994, 0.07067599719656364, 0.09350576251745224, 0.023866610934159586, 0.0928505351766944, 0.13460270155753407, 0.16084304851080689, 0.1480212336672204, 0.13713248366756098, 0.13628241499619825, 0.19685440829821996, 0.2990707148398672, 0.0956660755244749, 0.08969586302659341, 0.147236345069749, 0.1470549726592643, 0.09972577768244914, 0.08444087393581867, 0.17221978732517787, 0.1431930906006268, 0.06961134861090354, 0.12766810080834798, 0.1379550445292677, 0.12186237876968724, 0.21320311246173723, 0.205627974654947, 0.11013058293610811, 0.13657698061849388, 0.17829355783760548, 0.14669490126626833, 0.18083153665065765, 0.13407763758940355, 0.1877600305846759, 11.373151046889168, 50.93192155020577, 39.694718088422505, 37.82577426092965, 54.568980421338765, 18.04749768120902, 0.13128922507166862, 2.603990065199988, 3.9227097375052313, 6.46832994052342, 11.738873822348458, 13.13484161240714, 4.552465796470642, 0.4127225348992007, 0.3578232436307839, 19.609694174357823, 58.754057611737935, 56.5229424067906, 58.4187444959368, 59.682698249816895, 58.016471590314595, 59.21589742388044, 53.32035786764962, 52.49777453286307, 48.66842426572527, 48.316984380994526, 44.61992086683001, 44.764530250004356, 45.13692937578474, 44.40055234091622, 43.271539551871165, 45.24095433098929, 51.69395480837141, 53.13143982206072, 55.282313755580354, 56.04762656348092, 55.24433490208217, 53.74376024518694, 51.93355301448277, 50.40009948185512, 54.147276878356934, 54.17477090018136, 47.38775314603533, 41.067425046648296, 40.83276700973511, 40.44938278198242, 39.1926725251334, 41.16647161756243, 41.965702056884766, 42.17054189954485, 46.00728504998343, 47.39170319693429, 50.08371325901577, 52.35547195162092, 52.27374723979405, 49.038419314793174, 55.125294889722554, 53.1757241657802, 49.621703216007774, 50.93314095905849, 48.76747778483799, 44.520936829703196, 48.74209254128592, 52.00327818734305, 54.718231201171875, 50.3003511428833, 52.043595109667095, 48.90744229725429, 45.38275664193289, 54.19293349129813, 51.02800818852016, 48.69123867579869, 42.32205431801932, 43.4692679132734, 37.438877718789236, 38.29185594831194, 38.297553471156526, 38.70635073525565, 39.96274137496948, 40.84463105882917, 42.781166962214876, 40.719417572021484, 38.51501819065639, 39.11441843850272, 39.98373188291277, 40.321633202689036, 37.82268578665597, 37.75107070377895, 40.90174872534615, 44.4423040662493, 44.763658251081196, 46.079313550676616, 46.64176327841622, 43.57951845441546, 41.49590655735561, 40.94504642486572, 39.11108330317906, 37.84104640143258, 39.78398159572056, 39.04689237049648, 42.1273831639971, 43.34976584570748, 45.54398264203753, 44.45166328975132, 47.92889622279576, 46.53198521477835, 51.93401506968907, 48.050757203783306, 39.826191902160645, 2.493967511824199, 0.25384100899100304, 4.742349207401276, 10.684765219688416, 12.578357781682696, 17.325649329594203, 11.318022302218846, 4.078255585261753, 1.5772989456142699, 0.20772182515689305, 1.8074545498405183, 41.76364149366106, 39.668175969805034, 25.019551174981252, 52.79960427965437, 9.530951704297747, 0.510116764477321, 0.12370564628924642, 0.12433862446674279, 0.1329496952572039, 0.16007477045059204, 0.17317316973848002, 0.11691348361117498, 0.1442883682570287, 0.10416710150561162, 0.13750657359404223, 0.12844902676131043, 0.13710066037518637, 0.10937863042844193, 0.1818090206278222, 0.15632859218333447, 0.09102387140904154, 0.1349528663392578, 0.18720812377120766, 0.09025889102901731, 0.12344035266765527, 0.1339593825063535, 0.10826297636543002], [0.07312732030238424, 0.01735060691966542, 0.0365526780619153, 0.02254629204981029, 0.03747612351019468, 0.017340432287060788, 0.035439286913190565, 0.019724826394979442, 0.13802216521331243, 0.010948212567849882, 0.04673437082341739, 0.07592950708099774, 0.035711576230823994, 0.07369975958551679, 0.07134850003889628, 0.005633998396141189, 0.021556348473365818, 0.029479734200452055, 0.019657057709991932, 0.05550221712993724, 0.0773621727047222, 0.03558168427220412, 0.004958019758175526, 0.08232971400554691, 0.06347210625452654, 0.10096018215907471, 0.06283080923770155, 0.019944542819367986, 0.06683203524776868, 0.9187588883297784, 9.682153190885272, 34.368916920253206, 41.7793687411717, 52.987080574035645, 26.72608780860901, 0.8857324176601001, 0.27072760143450325, 0.5130738743713924, 0.17731297974075588, 2.5336011222430637, 2.7627937495708466, 3.3446589154856543, 2.512631676026753, 0.02448243065737188, 0.17382103497428553, 14.490297930581228, 56.88364424024309, 60.09161363329206, 57.900481837136404, 54.78717817578997, 52.80091054098946, 49.19913809640067, 46.58462129320417, 44.13291467939104, 43.31399999346052, 40.474083627973286, 41.674812248774934, 39.185032980782644, 41.391464710235596, 39.93930857522147, 41.25237567084176, 46.344811167035786, 48.73878867285592, 51.00644098009382, 51.546576568058555, 49.63222973687308, 52.97723497663225, 50.35510989597866, 50.005678040640696, 51.27309199741909, 52.60311269760132, 47.76265362330845, 40.41324520111084, 36.45061111450195, 36.40963063921247, 35.01039545876639, 37.50687279020037, 38.025211879185264, 38.13994748251778, 40.746310574667795, 49.44082771028791, 49.46366991315569, 50.92755113329206, 47.30728605815342, 47.213200501033235, 48.39422403063093, 42.909795488630024, 45.009568895612446, 50.18065105165754, 45.77188008172171, 43.59875454221453, 51.01684243338448, 48.531412737710134, 50.2044347354344, 49.75363908495222, 51.49542045593262, 46.38196665900094, 48.781422819410054, 49.96024029595511, 46.082099778311594, 42.88573040281023, 37.435556479862754, 37.27231897626604, 35.23493691853115, 33.77532884052822, 35.147570269448416, 34.941344261169434, 37.9145896094186, 43.897492340632844, 42.91143873759678, 41.36942849840437, 37.170215197971885, 34.92771884373256, 36.75326769692557, 37.05428103038243, 35.441885539463584, 34.79574475969587, 35.37241744995117, 39.06663220269339, 39.98022999082293, 41.6829103742327, 40.09509066173008, 39.82033109664917, 39.30224561691284, 42.26001385280064, 38.39828845432827, 36.2382880619594, 40.426658698490684, 40.65394817079817, 41.5692343711853, 42.624120303562705, 42.5806245803833, 42.55436386380877, 43.53668281010219, 45.43721662248884, 43.686656202588765, 48.10320220674787, 23.039630719593593, 0.20370301151914255, 0.3951417197074209, 4.939656334263938, 3.933381302016122, 9.450412528855459, 15.136556829724993, 7.059052322592054, 1.3452255300113132, 0.15549313915627344, 0.03243590432352253, 4.409029356070927, 39.88123900549752, 24.506009817123413, 25.342399222510203, 29.04419445991516, 0.21373720094561577, 0.12626715669674532, 0.01344404333004994, 0.12967146188020706, 0.035998291202953885, 0.06517739367804357, 0.09133104421198368, 0.02053820158887122, 0.04224904739697065, 0.028524163511714766, 0.012948534650994199, 0.023850365109475594, 0.052649408246257474, 0.07147738776568856, 0.0207039846573025, 0.044333530722984245, 0.020060735155961344, 0.014720108160482985, 0.021680842685912336, 0.03623424157766359, 0.03628776441993458, 0.030496685166976283, 0.020749850231888037, 0.011062312472079481, 0.03760963545313903, 0.013766405987553298, 0.03223216061347297, 0.042903725124363384, 0.025316009231443917, 0.0030002278259157068, 0.009165844414383173, 0.07350262480654887, 0.02244665427133441, 0.016458014458683983, 0.010874874806696815, 0.05480011319741607, 0.03932869713753462, 0.10763043245034558, 0.04062266002542206, 0.06789956082190786, 0.06506622250058822, 0.03241807920858264, 0.06532816415918724, 0.07233249795223985, 0.052910640835762024, 0.04906176968610712, 0.03233800529103194, 0.016137231939605305, 0.019342097021373253, 0.05134613925058927, 0.03099786809512547, 0.07498273359877722, 1.391798762338502, 19.118638924189977, 38.39709683826992, 38.25906045096261, 63.030340330941335, 30.76221125466483, 0.7412256289805684, 0.09880454425833055, 1.1480023243597575, 0.4393542472805296, 3.291182105030332, 4.25999961580549, 7.011317329747336, 4.79029221194131, 0.9990935261760439, 0.6747850541557584, 19.183444772447857, 58.54768221718924, 59.32119737352644, 58.69440037863595, 57.837378297533306, 55.04072489057268, 51.68960176195417, 48.02715417316982, 47.16072770527431, 45.36618866239275, 43.7329728943961, 43.11035524095808, 42.41167218344552, 42.68217250279018, 42.743323598589214, 42.399495465414866, 47.48788711002895, 48.77385623114449, 52.49357434681484, 54.551547391074045, 51.15779359000069, 51.28240258353097, 51.12419557571411, 51.75626277923584, 51.177415302821565, 54.71395458493914, 50.685750348227366, 41.53129025868007, 38.4875693321228, 39.66125556400844, 37.52297524043492, 39.427677971976145, 39.59186737877982, 40.22234344482422, 43.05725015912737, 49.05083227157593, 51.67268984658377, 51.05614144461495, 49.364175183432444, 48.55514430999756, 50.300945213862825, 46.34635714122227, 50.23922783987862, 50.88570213317871, 45.95580932072231, 43.631748063223704, 52.64931127003261, 50.2613821710859, 51.95870201928275, 52.02917412349156, 52.09993805204119, 48.433595997946604, 51.039587361471995, 52.60739278793335, 48.7891457421439, 44.91442026410784, 39.24473190307617, 38.39772565024239, 37.15066991533552, 35.999342986515586, 36.875041825430735, 37.07171753474644, 39.04017693655831, 44.55418743406023, 44.883382661002024, 41.86183343614851, 38.905465262276785, 36.86114195414952, 38.74179697036743, 38.50507879257202, 35.96842350278582, 36.19509111131941, 38.353986740112305, 40.404143060956685, 42.19403723308018, 43.34855685915266, 41.2185275214059, 40.923618180411204, 40.49666179929461, 44.37815134865897, 39.01929759979248, 37.545758383614675, 40.926491260528564, 41.1829423223223, 43.519558974674766, 43.67966284070696, 43.8393428666251, 43.7569511277335, 45.0772374016898, 46.90897362572806, 45.03442260197231, 47.22746862683977, 25.4691413130079, 0.4090170551623617, 2.918696561029979, 4.279097608157566, 3.498191522700446, 9.861183949879237, 15.567643914903913, 2.9461862402302876, 0.259707432772432, 0.1900665339614664, 0.03161062592906611, 4.305561125278473, 49.24930756432669, 27.39837292262486, 24.30766827719552, 38.30465105601719, 0.5848078365836824, 0.19005664092089447, 0.041811521231595955, 0.0894473631467138, 0.05781435913273266, 0.032257069634007554, 0.049469830468297005, 0.06889550095157963, 0.050950183533132076, 0.02349522496972765, 0.0266245097321059, 0.018178570616458143, 0.07882743515074253, 0.11142329392688614, 0.033647174148687294, 0.02885052189230919, 0.017960472498089075, 0.036064031068235636, 0.04867186989369137, 0.02407421381212771, 0.0808237733851586, 0.0017101826295921846, 0.01899636985867151, 0.13840225338935852, 0.12640021741390228, 0.07759683725557157, 0.159735109390957, 0.14128600007721356, 0.16884995172066347, 0.08514095244130918, 0.14374860722039426, 0.19832845777273178, 0.12597025691398553, 0.10236379291330065, 0.1491211253617491, 0.25297492689320017, 0.19747963760580334, 0.21572240442037582, 0.15574183581130846, 0.1571285578289202, 0.14360834046133927, 0.1277754314775978, 0.15467264104102338, 0.18542511016130447, 0.13815198253308023, 0.123172399188791, 0.17541420805667127, 0.12816523627511092, 0.13937124210808957, 0.1135071496080075, 0.09535987302660942, 0.192642442882061, 1.4357581692082542, 28.182664734976633, 47.228403159550254, 47.238988740103586, 60.93017087663923, 39.74318177359444, 2.1531803011894226, 0.41766862092273577, 3.2079505026340485, 1.995434697185244, 10.674187455858503, 7.527539389474051, 11.448542475700378, 8.195969990321569, 0.24101677856275014, 0.48097981938294, 17.819152082715714, 57.47843435832432, 61.31890174320766, 62.474394117082866, 58.49985776628767, 58.626467841012136, 53.55522435052054, 49.88529702595302, 49.223043373652864, 46.41095106942313, 44.87236629213606, 45.937632833208355, 42.90189191273281, 45.24284771510533, 45.44907372338431, 45.29015799931118, 50.253096444266184, 52.22788218089512, 56.31521906171526, 56.211454663957866, 53.39905663899013, 53.83201278959002, 54.041330746241975, 53.33491086959839, 53.4780124936785, 56.761845793042866, 53.63005297524588, 45.880497796194895, 40.67377485547747, 41.215974058423726, 38.1716764313834, 41.97797952379499, 41.552252973829, 41.43630838394165, 44.98811633246285, 52.82107768739973, 52.68491036551339, 54.47883449281965, 51.258434772491455, 49.926072529384065, 53.72634111131941, 47.19415896279471, 50.20501143591744, 53.69761378424508, 48.936152253832134, 45.5426207951137, 53.93046876362392, 53.35905933380127, 54.03412546430315, 54.83628109523228, 54.922939028058735, 51.60556329999651, 52.4637769971575, 53.08287538800921, 50.62007597514561, 47.04736089706421, 41.79224375316075, 40.88498272214617, 38.40742186137608, 36.97838585717337, 39.061080592019216, 37.798123904636924, 40.60372311728341, 47.32656036104475, 48.21343885149275, 44.26087270464216, 41.16033288410732, 39.04328278132847, 41.73764133453369, 39.90447378158569, 38.50227172034127, 38.13256502151489, 39.97529329572405, 44.15374885286604, 44.361729281289236, 45.517562116895405, 44.6425268309457, 43.33573395865304, 42.513536248888286, 48.799689633505686, 41.48756524494716, 39.48280150549752, 43.44646739959717, 44.52546010698591, 44.227861813136506, 47.34167616707938, 46.27991499219622, 45.870610509599956, 47.54822874069214, 49.637774399348665, 45.576833724975586, 50.63887780053275, 25.174515111105784, 0.49779342859983444, 3.0455891234534125, 8.663676687649318, 13.242018444197518, 14.193184273583547, 27.683797972542898, 16.640027148383005, 2.488349676132202, 0.3482843983386244, 0.28439278102346827, 7.957316739218576, 55.193046774183, 33.47662230900356, 35.999162333352224, 41.716755049569265, 0.8836683684161731, 0.4248521083167621, 0.13535974307784013, 0.24181137021098817, 0.14643730223178864, 0.1196222904005221, 0.2019327272261892, 0.162348690575787, 0.11024085844733886, 0.07003289527658906, 0.2118888444134167, 0.08484848349222116, 0.17223339873765195, 0.15318518371454307, 0.16290435647325857, 0.1394116556538003, 0.13124407535152777, 0.134531563946179, 0.13118337360875948, 0.1625273624168975, 0.2015920483640262, 0.10544977017811366, 0.14207690049495014], [0.04941951709666422, 0.04741177947393485, 0.09065063643668379, 0.06376614940485784, 0.007258985441045037, 0.0348198658653668, 0.021366166982001493, 0.03547969367355108, 0.03621607719521437, 0.016611614430855428, 0.07274733390659094, 0.054971260085169754, 0.022184403879301887, 0.007925798767246306, 0.022342122559036528, 0.05035026018906917, 0.04391097643279603, 0.041588059293904474, 0.02929082326591015, 0.019212527366887246, 0.005853551548040871, 0.037488499988934824, 0.008149839156041188, 0.0544865282385477, 0.008245453221856483, 0.04115714545228651, 0.07044977362134627, 0.032134071591177156, 0.038004064466804266, 0.08466661575117282, 3.3181658685207367, 33.232420921325684, 27.29132550103324, 20.948478290012904, 45.540824685777935, 8.124329720224653, 0.19306242891720363, 0.2623254108641829, 0.11870815445269857, 1.7588245421648026, 3.276007239307676, 3.6351630985736847, 5.605185193674905, 6.915773519447871, 0.7019460509930338, 0.3956541493535042, 15.76736467225211, 67.05120726994106, 55.20790549686977, 62.08593423025948, 51.128958565848215, 55.11663743427822, 49.04036481039864, 48.36566693442208, 42.84106043406895, 45.206178597041536, 42.48684821810041, 43.94837052481515, 42.40886163711548, 41.567247186388286, 42.87160471507481, 46.91623101915632, 46.85665021623884, 50.33828830718994, 48.979106017521445, 54.15916524614607, 51.19240256718227, 51.36719492503575, 49.455724648066926, 52.453403336661204, 51.754695960453574, 49.77736023494175, 40.25075462886265, 37.264790603092735, 36.258083479745046, 38.810604981013704, 35.07738651548113, 37.95689719063895, 39.74575955527169, 43.57466513769967, 51.493575709206716, 52.58740976878575, 52.173835618155344, 47.962303161621094, 44.62389523642403, 43.08417790276663, 46.57802745274135, 49.065638882773264, 48.72716433661324, 46.395737988608225, 47.54336152757917, 50.34597301483154, 49.467779772622244, 46.180517537253245, 44.425982747759136, 49.215112004961284, 47.55942923682076, 48.26114865711757, 46.928737776620046, 43.493593556540354, 40.060766560690745, 38.38944687162127, 36.24934959411621, 35.03490175519671, 34.55240842274257, 34.465010506766184, 38.31745311192104, 43.28363289151873, 44.839261599949424, 45.62809753417969, 41.593382835388184, 38.276535170418875, 37.62858438491821, 37.4561995778765, 35.627239159175325, 35.30196966443743, 35.33201367514474, 36.49635110582624, 37.25192253930228, 40.15321929114205, 39.528454644339426, 38.99441957473755, 39.66224568230765, 38.5193886075701, 37.21992261069161, 36.17834595271519, 38.652866976601736, 39.84168985911778, 42.89473179408482, 44.751780305589946, 44.68574810028076, 46.4280366897583, 46.3065960747855, 45.72264167240688, 45.29286779676165, 46.75374392100743, 40.79259599958147, 8.970644627298627, 0.39368107808487757, 3.4172539114952087, 1.1043019550187247, 1.9722381361893244, 8.618371827261788, 7.019043726580484, 1.6262031900031226, 0.48642622998782564, 0.1332923961537225, 0.08433178586087056, 16.275502068655832, 42.1885655266898, 21.585497822080338, 35.410597801208496, 13.09136152267456, 0.09950633267206804, 0.021126840895574008, 0.05687736673280597, 0.038340672118855376, 0.04747524285422904, 0.08224234583654574, 0.06695225129702262, 0.022442072463620986, 0.019221964092659097, 0.058049709003950865, 0.010830825161454933, 0.03569484355726412, 0.0563908299830343, 0.017105869516464214, 0.019662725173735192, 0.05447130869807942, 0.03947401558980346, 0.10030357060687882, 0.02801139290178461, 0.017525597708299756, 0.00904874877804624, 0.010492820575434183, 0.02003410435281694, 0.016674619800012027, 0.026280365252335156, 0.02561878173479012, 0.03560601653797286, 0.07728339478905712, 0.04507926106452942, 0.046324766374060085, 0.0551959467785699, 0.06720699369907379, 0.06634212617895432, 0.041035697861973724, 0.046421952944781096, 0.0334527840438698, 0.05806880976472582, 0.05310253732438598, 0.013843378151900001, 0.027035688382706473, 0.05743866107825722, 0.048214381228068044, 0.05678310464801533, 0.02896465826779604, 0.018223058764955828, 0.012742174340278974, 0.029544245917350054, 0.00672601823628481, 0.040990320832601616, 0.06315461971930095, 0.04618859118116753, 0.06386860140732356, 0.1210055790309395, 5.639401163373675, 43.03083658218384, 30.76468481336321, 34.53306463786534, 51.87259646824428, 8.650288377489362, 0.08735629463834421, 0.6022953667810985, 0.37155361686434063, 0.5413317637784141, 2.0436775599207198, 4.608572934355054, 12.327152609825134, 11.241361090115138, 2.2616746851376126, 0.45763376355171204, 21.431055000850133, 65.71006597791398, 57.97454616001674, 62.568702016557964, 53.1047865322658, 54.49695192064558, 49.619236605507986, 49.81885140282767, 45.45656040736607, 47.78480448041643, 45.44711085728237, 44.63392496109009, 43.867764472961426, 43.283879552568706, 45.61112308502197, 48.671908787318635, 48.51540756225586, 51.6460747718811, 50.744816984449116, 53.638835498264854, 53.0111699785505, 54.34094401768276, 50.609337534223286, 51.62647042955671, 54.04351248059954, 50.9081517628261, 41.561699049813406, 38.472272872924805, 37.61362143925258, 38.626522881644114, 37.68625095912388, 39.000033719199045, 41.54855653217861, 44.41684934071132, 51.19104766845703, 53.50784111022949, 54.02848700114659, 50.03967905044556, 47.062751156943186, 45.76848241261074, 50.12224449430193, 50.6322283744812, 51.060296467372346, 46.69848142351423, 48.69219752720424, 52.15889004298619, 50.337364196777344, 48.85622017724173, 47.557025160108296, 52.08342565808977, 47.38353211539132, 50.217354910714285, 49.31037180764334, 46.287759508405415, 42.72405276979719, 40.93442610331944, 38.985953194754465, 37.909739766802105, 36.80767209189278, 37.187571798052105, 39.83579778671265, 45.16334295272827, 47.60049309049334, 46.05624900545393, 44.07575879778181, 39.0179774420602, 38.26533120019095, 38.19916697910854, 37.301880087171284, 37.29906259264265, 36.99615240097046, 38.59998771122524, 39.48445865086147, 41.33859934125628, 41.81837592806135, 39.798538071768625, 42.35815020969936, 39.621185302734375, 40.05054228646414, 39.13779565266201, 40.32125799996512, 42.43859297888619, 43.65018163408552, 45.373032638004844, 47.57257522855486, 47.15351547513689, 48.71183313642229, 46.086525780814036, 47.4873833656311, 47.23981557573591, 44.490253584725515, 10.228801846504211, 0.43354625893490656, 4.2430994255202155, 2.0653450829642157, 4.260611491543906, 7.593456949506487, 6.43189445563725, 0.4485296149338995, 0.2456027524811881, 0.0979092987254262, 0.03131053024636848, 16.80269316264561, 50.693261350904194, 20.708011559077672, 38.595787525177, 18.183116095406668, 0.13284326025417872, 0.02135493722744286, 0.049716752754258256, 0.05143536999821663, 0.05658405300761972, 0.03769883905936565, 0.04201249312609434, 0.012248748763730484, 0.05403087840282491, 0.04768861158351813, 0.03917368581252439, 0.03038712211751512, 0.031135583562510352, 0.02776265553464847, 0.049647725386811156, 0.054515247233211994, 0.059678613740418635, 0.05013726465404034, 0.006060663760373635, 0.042782314853476625, 0.0942463292075055, 0.01879391536515738, 0.07367607871336596, 0.17827077263167926, 0.12615774971033844, 0.20490393707794802, 0.13033460772463254, 0.22012684307992458, 0.25568922981619835, 0.14682657777198724, 0.13946226079549107, 0.16392570095402853, 0.12499119873557772, 0.24526429921388626, 0.10285664003874574, 0.07070462458900043, 0.09152161755732127, 0.18468321354261466, 0.1315343662032059, 0.13299597134547575, 0.17505816716168607, 0.10739378657724176, 0.09241463749536447, 0.08549837754773242, 0.09119082495037999, 0.11419544874557427, 0.13180367675210747, 0.16805175026612623, 0.12436358098472867, 0.17607981019786426, 0.1148723688508783, 0.22461684500532492, 0.2633856354015214, 8.057976160730634, 52.69683000019619, 37.730966091156006, 29.882562364850724, 59.38466221945626, 13.576853002820696, 0.24231706878968648, 2.494082808494568, 2.0029430942875996, 4.383218101092747, 12.875278626169477, 8.30205421788352, 16.544911520821707, 14.260349903787885, 1.2572883686849048, 0.900471663900784, 18.59669198308672, 69.56803934914726, 58.0356798853193, 66.01762798854283, 54.173714773995535, 58.643692425319124, 52.317503520420615, 52.369924204690115, 46.55239207404, 51.45473527908325, 47.71951225825718, 47.697135584695, 46.10208279745919, 45.57969290869576, 46.485974243709016, 51.8012558392116, 50.96209062848772, 54.20570428030831, 51.35342706952776, 58.02937092099871, 54.80133513041905, 55.77534750529698, 51.24572651726859, 53.93490171432495, 55.033342429569785, 54.16254554476057, 43.44439683641706, 39.79234027862549, 38.78645651681082, 42.91106700897217, 39.173919337136404, 41.32495307922363, 43.83829716273716, 47.627716132572715, 53.78420918328421, 56.363088675907676, 55.946102959769114, 50.753116607666016, 47.7926698412214, 50.42120810917446, 50.20223215648106, 52.687995365687776, 51.4678395816258, 48.38927691323416, 50.429375716618125, 53.09943641935076, 53.00216858727591, 49.71235983712332, 48.609910011291504, 54.42478098188128, 50.44755915233067, 51.14900411878313, 50.78864969526018, 47.98993614741734, 43.55908032826015, 43.50925479616438, 40.34377711159842, 40.205421107155935, 38.209922790527344, 39.64981188092913, 43.05794497898647, 46.82874625069754, 49.62007386343819, 49.417641571589876, 46.45994976588658, 40.60323674338204, 40.35045780454363, 40.416361468178884, 38.301354135785786, 39.95962163380214, 39.084155559539795, 40.66333171299526, 40.00080360685076, 44.92869881221226, 42.78010041373116, 42.58519302095686, 44.76095540182931, 41.21021400179182, 40.67745392663138, 40.459624426705496, 42.553735051836284, 44.43390369415283, 44.92970282690865, 48.640669686453684, 49.56894901820591, 50.045380047389436, 52.321054049900596, 48.53964287894112, 48.93860149383545, 48.9417907169887, 44.58855322429112, 10.733671852520533, 0.5448355014835085, 7.013214187962668, 4.875747237886701, 10.829978227615356, 19.68598713193621, 16.579037598201207, 6.467464889798846, 1.1313315331935883, 0.670265576669148, 0.20444834152502672, 23.174156529562815, 54.809600012642996, 29.95639739717756, 49.18199341637747, 21.23767794881548, 0.321390472884689, 0.10725373694939272, 0.1969145807836737, 0.14569889328309468, 0.2018269029046808, 0.20018522813916206, 0.1845446295504059, 0.15546769409307412, 0.1317774174468858, 0.15904202658150876, 0.20201759838632175, 0.11864932546658175, 0.1821422084633793, 0.11225011598851, 0.1731617839208671, 0.20563633420637675, 0.17976733589810984, 0.23733681174261229, 0.11405400133558682, 0.1326060172702585, 0.09970424098095723, 0.11313996038266591, 0.20171835087239742], [0.04240443191624113, 0.02837826660834253, 0.07759793648230177, 0.02435262012295425, 0.006498091114086232, 0.04963282475780163, 0.01644438099382179, 0.07422479641224657, 0.023460958951285908, 0.042403973905103545, 0.03286499629861542, 0.01502002403140068, 0.022839733000312532, 0.020307397902277962, 0.011030797064969582, 0.017795088068981255, 0.021026105586705462, 0.025296226542975222, 0.051525571050920656, 0.07228656113147736, 0.06438806067620005, 0.033870452881923745, 0.055098777171224356, 0.016147442195298414, 0.036046440047877173, 0.09489422837006194, 0.00840126521818872, 0.015227360584373986, 0.04953361276004996, 0.040296213435275216, 0.06994725058653525, 23.650835956845963, 40.56211730412075, 28.400704417909893, 49.732926504952566, 30.06407710484096, 0.3646852411329746, 0.27324363642505234, 0.3813912889787129, 0.5007040724158287, 2.1055312923022678, 6.257654913834163, 6.9703312090465, 22.02983512197222, 3.2645746299198697, 0.15018956017281326, 0.33624205738306046, 33.87022386278425, 65.71741022382463, 56.018923555101665, 58.74013342176165, 55.01147992270333, 51.54471445083618, 46.95971632003784, 47.01748364312308, 46.951812744140625, 49.815495422908235, 45.914488383701865, 44.21117571422032, 43.73011023657662, 42.53634371076311, 44.30869715554373, 48.29835278647286, 46.736144133976524, 50.48226887839181, 52.21099805831909, 52.37478794370379, 53.75140673773629, 53.933147294180735, 50.02379199436733, 53.81823798588344, 49.59731156485421, 41.96686240604946, 37.30941193444388, 36.84334761755807, 37.52161339351109, 37.46703181947981, 38.714462757110596, 37.852524825504844, 41.651549679892405, 51.79023599624634, 52.58177825382778, 51.080414976392476, 47.09833983012608, 39.12701204844883, 47.428497382572715, 48.167869091033936, 50.77524314607893, 49.28127275194441, 45.50012561253139, 49.15618780681065, 52.56498098373413, 49.13037177494594, 47.38711738586426, 44.5781170300075, 46.37665476117815, 47.6557868548802, 47.74894482748849, 46.44492776053292, 45.08055864061628, 38.76947859355381, 37.78258425848824, 35.14503070286342, 36.25893463407244, 36.39373663493565, 36.163310050964355, 44.705175263541086, 49.1393210547311, 47.55697304861886, 46.12537315913609, 40.05590629577637, 36.60225554874965, 36.519710949489046, 37.31582512174334, 35.276695592062815, 34.23101602281843, 36.84272575378418, 37.165198598589214, 39.12784930637905, 39.42581932885306, 38.28467151096889, 40.24659613200596, 37.41986744744437, 38.297588212149485, 37.15082624980381, 36.451392786843435, 38.735300404684885, 41.94066769736153, 46.84037058694022, 46.373708724975586, 48.46616915294102, 48.37390054975237, 46.51369060788836, 46.93912533351353, 48.82586349759783, 45.454507214682444, 30.021338735307964, 1.024904346891812, 0.5734950293387685, 3.588768890925816, 3.0540392185960497, 2.428092292376927, 4.936805401529584, 3.9508985791887556, 0.2166122623852321, 0.035977148051772795, 0.07761291853551354, 1.0646315408604485, 33.37334081104824, 27.39249300956726, 18.747956003461564, 35.1299079486302, 2.0072025571550642, 0.22707029192575387, 0.046366150224847455, 0.010851605296401041, 0.039888237469962666, 0.033375749963202646, 0.01100435370712408, 0.013843222937014486, 0.03646664321422577, 0.01598939442607973, 0.01605599433449762, 0.02203440523174192, 0.07558900463793959, 0.011749661660620143, 0.03170746983960271, 0.005423448555770197, 0.011079654130818588, 0.05865915558700051, 0.012216689680436892, 0.019122487466250147, 0.046163509134203196, 0.009913413585828883, 0.05255759906555925, 0.013689357488016998, 0.018306559284350703, 0.024318574628393565, 0.07412887870201043, 0.00699127114577485, 0.01660460007510015, 0.037567240585173876, 0.026335932181349823, 0.020618906543989266, 0.08816453841115747, 0.05545349492292319, 0.017656806024855802, 0.013785919806520854, 0.018883229233324528, 0.0660242528787681, 0.030245868090007986, 0.015347381554810064, 0.041094367392361164, 0.0871496671544654, 0.0348993867768773, 0.03660641125004206, 0.02357055083848536, 0.03985284847606506, 0.021063374122604728, 0.026162198378837535, 0.0742541498371533, 0.06395223084837198, 0.011698640916230423, 0.0453825492544898, 0.03874090939228024, 0.06259651109576225, 0.11900670986090388, 33.00894948414394, 41.16156618935721, 22.95464209147862, 61.379747118268696, 30.920859473092214, 0.1503439133188554, 0.2809460402599403, 0.2073085837598358, 0.26470373038734707, 1.4114087500742503, 2.2287319728306363, 9.889271174158369, 11.660629289490835, 5.740962547915323, 0.5534677154251507, 0.42749728209206034, 41.02070188522339, 64.74204295022147, 59.81363705226353, 60.107274872916086, 56.57244832175118, 53.85147816794259, 48.55886507034302, 48.61442634037563, 49.19503518513271, 50.45396539143154, 47.4517946924482, 46.88467924935477, 45.025952747889924, 45.4314044543675, 47.76337276186262, 49.933927467891145, 48.62112440381731, 52.26596178327288, 52.4178910936628, 55.18407317570278, 53.98910461153303, 53.890467984335764, 51.288079261779785, 54.194072995867046, 53.20970433098929, 43.17544943945748, 38.50800745827811, 39.19870356151036, 39.43495968409947, 38.95152834483555, 39.13753856931414, 39.54694727488926, 43.972397395542686, 53.10757623400007, 53.26186098371233, 54.99280316489083, 47.97860016141619, 44.078868116651265, 48.51507404872349, 50.30790730885097, 51.012961864471436, 52.19516658782959, 46.721337522779194, 49.74344260351998, 54.65044804981777, 50.28028474535261, 49.596185956682476, 46.51241213934762, 48.84476954596383, 50.83409786224365, 50.090220246996196, 48.60344818660191, 45.52706725256783, 42.8357172693525, 39.253747190747944, 36.79708998543875, 37.696965081351145, 37.03658396857125, 37.196774687085835, 44.79954917090279, 50.12186929157802, 48.78298616409302, 47.76227842058454, 43.46215295791626, 37.652183941432405, 38.13906506129673, 38.1853609085083, 37.12488515036446, 36.25410911015102, 37.2646655355181, 38.19096463067191, 40.02484437397548, 40.14477375575474, 40.65443801879883, 42.08447456359863, 39.81862531389509, 40.308664390019004, 38.072258131844656, 39.40345655168806, 42.08418273925781, 41.54160138538906, 47.8051210130964, 47.553773403167725, 47.9742088999067, 49.331153869628906, 47.656186376299175, 47.749973160879954, 49.392971992492676, 45.0192095211574, 32.88180439812796, 1.6296152983392989, 0.6366197392344475, 5.037518671580723, 2.9433893731662204, 4.745432470526014, 3.3247801193169186, 0.9400256957326616, 0.2055623603186437, 0.07861471442239625, 0.1196753518389804, 1.27149569775377, 37.51926490238735, 36.513374192374094, 20.252115930829728, 43.245949336460654, 3.9137192027909413, 0.2574911745531218, 0.05599591242415564, 0.03893188646595393, 0.02834947806383882, 0.05892790973718677, 0.03573744198573487, 0.016894047847017646, 0.027338060550391674, 0.04314542608335614, 0.04823473049327731, 0.030845214679305042, 0.08143061439373664, 0.008657770114950836, 0.047435514628887177, 0.021780164945604544, 0.05353716614523104, 0.08493421639182738, 0.015859382027494054, 0.0263171672954091, 0.029391154846442596, 0.032991366660488505, 0.07023544476500579, 0.01673355226271919, 0.17332733289471694, 0.209622428885528, 0.1644424189414297, 0.044947425103081126, 0.1562550796994141, 0.15375404033277715, 0.10044589332704033, 0.12079310257519994, 0.20700868485229357, 0.10753908128078495, 0.06690096762031317, 0.09828172624111176, 0.13178851827979088, 0.19626697339117527, 0.13134533991771086, 0.06024237456066268, 0.13240150681563786, 0.1183444189706019, 0.14243812539747783, 0.12444571086338588, 0.11368105813328709, 0.16672965192369052, 0.1215617334736245, 0.0879488524847797, 0.1950624787381717, 0.24782321761761392, 0.15012222235756262, 0.15446376082088265, 0.08413796233279364, 0.20933102523641928, 0.14579900433974607, 38.03132281984602, 52.30745642525809, 37.18783235549927, 58.8739070892334, 41.42370087759835, 0.9181643830878394, 0.9259783923625946, 1.331012338399887, 1.1491779812744685, 8.899325711386544, 15.279707091195242, 20.559092555727275, 36.442707538604736, 8.966530425207955, 0.23647898063063622, 0.525597079523972, 36.37987845284598, 68.2857562473842, 61.69994790213448, 63.3430301121303, 59.62149156842913, 55.9501085962568, 50.56652968270438, 51.4595364843096, 51.053959710257395, 54.58928305762154, 49.94032675879342, 48.749832834516255, 48.58645984104702, 47.46083082471575, 49.44724089758736, 52.78646871021816, 51.439483983176096, 54.331626483372276, 54.62512534005301, 57.767722606658936, 56.3062732560294, 54.44924906321934, 53.83482681001936, 57.43247202464512, 55.70399645396641, 46.65747315543038, 40.66301556995937, 42.02196856907436, 41.44367347444807, 41.185798031943186, 41.40266868046352, 42.144527844020296, 45.879757813044954, 56.63550669806344, 56.14820173808506, 56.66457448686872, 47.83080850328718, 46.92568751743862, 51.722668239048545, 50.71794135229928, 54.53641421454293, 53.27513551712036, 48.40861027581351, 52.190591199057444, 56.98698827198574, 53.827878611428396, 52.59406614303589, 50.345184394291465, 51.2890659059797, 52.17713948658535, 51.26045322418213, 51.28805146898542, 48.52960620607649, 44.27134711401803, 41.25876106534685, 38.16671541758946, 39.85572174617222, 39.36554023197719, 39.81426531927926, 48.07782391139439, 53.26675598961966, 50.45893682752337, 50.754478454589844, 43.36502756391253, 40.85242346354893, 39.39022370747158, 40.45406239373343, 38.502501010894775, 37.67810419627598, 40.870238644736155, 41.69265174865723, 42.318663597106934, 42.62048292160034, 41.83450617109026, 44.10419430051531, 41.76375266483852, 43.51789140701294, 41.3860798563276, 40.270265170506065, 43.0048121043614, 44.53573301860264, 49.308940478733604, 51.13617427008492, 51.04908207484654, 51.80421577181135, 47.57682057789394, 50.944608960832866, 51.29192508969988, 47.40572466169085, 33.7271535055978, 1.753985230411802, 1.4942953309842517, 10.040659393583026, 6.2019403491701395, 6.5422357576234, 15.083620241710118, 11.233296837125506, 1.220648997596332, 0.2668680671070303, 0.24379494520170347, 2.8689680865832736, 44.143927574157715, 38.748102460588726, 27.701594046183995, 49.74792071751186, 4.561706466334207, 0.44169611590249197, 0.14078331419399806, 0.12264964223972388, 0.13827763364783355, 0.13447064507220471, 0.08375047133969409, 0.08385367651603051, 0.1488940061203071, 0.15633851236530713, 0.09444619169724838, 0.13171647143151077, 0.2116936163178512, 0.09738543576427869, 0.12362734334809439, 0.09285985146250043, 0.11412475896733147, 0.16197441065950052, 0.12972825526126794, 0.057226707094482014, 0.11780609642820698, 0.1063352312360491, 0.17354826389678887, 0.0766455786568778], [0.03246030444279313, 0.04424220669482436, 0.07338350798402514, 0.028918097194816385, 0.02248977686810706, 0.02362028236633965, 0.08942951089037315, 0.07054075838199683, 0.004543742747046053, 0.09308129136583634, 0.057565764257950444, 0.016240533807181885, 0.04451249772682786, 0.08102005321000304, 0.06602336399789367, 0.05550706186997039, 0.03185440320521593, 0.03019407211935946, 0.07288793993315526, 0.02446915172705693, 0.024049657629802823, 0.07741145470312663, 0.05012595347527947, 0.023114069797364727, 0.06824404626552548, 0.024098739460376755, 0.04893987087000694, 0.04071398066090686, 0.009072960603849163, 0.05516849664439048, 0.0747834342930998, 2.6761425478117804, 40.88760219301496, 36.622683252607075, 34.87806701660156, 51.463430949619834, 9.05543783732823, 0.07288804849875824, 0.038049556847129545, 0.04419482798714723, 0.31951166370085304, 0.24199232192976133, 7.803772841181074, 4.9908380678721835, 5.8977807845388135, 0.798510975071362, 0.09459008183330297, 4.554816893168858, 55.178264481680735, 59.93807928902762, 59.3936253956386, 56.81762940543038, 54.66063410895211, 48.74523312704903, 50.60946954999651, 49.97394214357649, 48.998838901519775, 49.79272617612566, 46.58383614676339, 45.296338421957834, 45.548825536455425, 44.882962294987266, 43.83283935274397, 46.84206942149571, 48.22965594700405, 52.084523473467144, 51.83258179255894, 53.30786848068237, 51.13876942225865, 53.329248087746755, 53.240536962236675, 50.967753410339355, 41.09865025111607, 37.341856547764365, 36.87677887507847, 36.50094386509487, 37.89852884837559, 38.55999388013567, 38.99287707465035, 41.15571928024292, 49.49414471217564, 51.16525942938668, 52.54940659659249, 47.934100423540386, 37.66550711223057, 41.75243752343314, 54.70675277709961, 46.908834661756245, 50.87227126530239, 46.70927892412458, 48.06819370814732, 49.81564480917794, 51.794109616960796, 48.85279124123709, 45.64422082901001, 44.28287417548043, 46.17543145588466, 46.17290925979614, 43.532499994550435, 42.35675709588187, 39.569056442805696, 36.25029107502529, 36.774247782570974, 37.35361289978027, 36.81257404599871, 43.25719499588013, 50.07427065713065, 51.56687920434134, 49.26345409665789, 44.85932452338082, 38.37598473685128, 35.97900560923985, 37.339205810001914, 41.54605518068586, 37.57936682019915, 35.05643074853079, 34.26751143591744, 37.23848124912807, 39.91180065699986, 39.03660903658186, 38.73639127186367, 37.69631542478289, 37.29682527269636, 37.56748192650931, 36.64501476287842, 37.46249464579991, 40.346372263772146, 41.501301833561485, 43.98766606194632, 47.03700460706438, 46.26690101623535, 47.54454966953823, 48.3651180267334, 47.3559581892831, 47.283401625497, 43.881261348724365, 8.935002974101476, 0.1994089705071279, 0.9050187713333538, 2.302516847848892, 0.7756209490554673, 2.7252580608640398, 2.1173699370452335, 0.43118083157709663, 0.05586732325277158, 0.038291373157075474, 0.029248136627886976, 12.089566775730678, 42.492948736463276, 17.505388804844447, 31.65624291556222, 16.461229154041835, 0.02560626615637115, 0.05033580739317196, 0.045432414793010266, 0.03281069653374808, 0.018493353189634423, 0.056402561853506734, 0.07833426911383867, 0.023981846536376646, 0.03353659329669816, 0.046438434560384066, 0.02031140634790063, 0.04850812243031604, 0.03939559729769826, 0.0842962238405432, 0.0164842381408172, 0.04977060807868838, 0.011795733340217598, 0.07385565300605126, 0.012679722825331348, 0.016855632586936866, 0.0642897884494492, 0.02132747521890061, 0.03694786024945123, 0.06725381940071072, 0.025980914177905236, 0.06480816884764604, 0.013869621341915002, 0.06003636454365083, 0.036154968331434896, 0.035327114896582704, 0.07893607539257833, 0.06177858462823289, 0.03804610649655972, 0.00817041318597538, 0.04707734313394342, 0.02695131764215018, 0.048113025059657435, 0.0077898305275344425, 0.03418116085231304, 0.11563536790864808, 0.10318700516862528, 0.033143378860716305, 0.05086815543472767, 0.01289443759846368, 0.07085367837654692, 0.017324939636247497, 0.0024062804669873522, 0.06259020072008882, 0.039493051889751635, 0.029035320904638087, 0.024481999787635038, 0.05102683763418879, 0.07523929447467838, 0.07508786581456661, 0.15163121638553484, 5.340320731912341, 52.19114358084542, 33.812123026166645, 41.52247994286673, 59.91628973824637, 7.60122503553118, 0.07042848797781126, 0.04626233097431915, 0.10843818767794541, 0.22900182328053884, 1.1747210792132785, 6.352995923587254, 6.911591138158526, 5.623580115182059, 3.1330560871532986, 0.16563590775643075, 6.701293051242828, 60.43349279676165, 60.92948995317732, 60.366164752415244, 57.29457460130964, 55.41262027195522, 49.77487277984619, 52.675182887486045, 52.12716456821987, 50.40699904305594, 51.31202622822353, 48.551110880715505, 46.81752838407244, 46.503563608442036, 46.56767463684082, 46.76707056590489, 48.52195971352713, 50.11534145900181, 55.666663782937185, 53.475712639944895, 56.21292420795986, 51.344331877572195, 53.23466226032802, 55.286618164607454, 51.10293756212507, 42.74143368857247, 39.031811305454795, 39.104239327566965, 38.63548258372715, 40.236566407339915, 39.92872994286673, 40.38027599879673, 42.99469552721296, 51.67180742536272, 54.57074178968157, 53.80340358189174, 50.176683630262104, 41.862309387751985, 45.897037982940674, 55.51786463601248, 47.274890082223074, 49.82886723109654, 48.01196541104998, 49.43193401609148, 51.567389896937776, 52.80796991075788, 50.181571687970845, 46.602426052093506, 46.30918427876064, 48.52207088470459, 48.44364309310913, 45.54089764186314, 44.329211711883545, 42.37474250793457, 38.58653947285244, 38.59888642174857, 38.26095730917794, 38.852026666913716, 44.877952643803184, 50.71826096943447, 50.83184664590018, 51.418000153132844, 46.05200365611485, 39.085031032562256, 37.44360249383109, 38.79298087528774, 42.40525899614607, 38.33525092261178, 37.14593471799578, 36.39051267078945, 38.52239370346069, 40.425776277269634, 40.95267902101789, 41.312453269958496, 39.830676964351106, 39.31162568501064, 39.034059047698975, 37.90988220487322, 39.180179664066856, 42.32954100200108, 43.93873337336949, 45.497537408556255, 47.598502431597026, 49.286647183554514, 49.49189002173287, 49.139275891440256, 47.19212314060756, 46.3187380518232, 44.603248664310996, 11.54444932937622, 0.31449973263910835, 2.7299745849200656, 5.16901376417705, 5.126001809324537, 4.212469594819205, 1.7762745086635863, 0.3631389412496771, 0.03377635364553758, 0.04594298525314246, 0.06014206672885588, 11.904729928289141, 49.20173672267369, 21.086756127221243, 31.776960917881556, 24.221972669873917, 0.138674508780241, 0.034026007034948895, 0.04159623224820409, 0.025752034138089845, 0.0593884585957442, 0.021846127031104903, 0.0777404559776187, 0.09677676271115031, 0.054913292838526626, 0.07387037721595593, 0.060055573870028765, 0.025345254090747664, 0.018093478932444538, 0.05494702281430364, 0.01522998312222106, 0.02281300550592797, 0.03595439337992242, 0.03719057222562177, 0.038107629266700575, 0.03055050317198038, 0.04590978792735508, 0.04003820049443415, 0.054985634849539826, 0.009813133743591607, 0.1389880326709577, 0.14444266712026937, 0.23499934002757072, 0.1876503521842616, 0.14070421058152402, 0.13641619496047497, 0.1970003747514316, 0.15324573617960724, 0.07643247794892107, 0.2336829820913928, 0.11305445818496601, 0.10964682139456272, 0.14446857358728135, 0.13574718657348836, 0.14786526560783386, 0.22257806440549238, 0.3756973487990243, 0.12726540384548052, 0.13694238529673644, 0.08492084246660982, 0.18790132871695928, 0.1638545904840742, 0.13527070571269306, 0.16367172529654844, 0.18479219983730996, 0.13330492191016674, 0.11034215694027287, 0.12873847622956547, 0.1148241792938539, 0.15368952522320406, 0.26446352899074554, 6.652204462460109, 60.03859192984444, 45.6499148777553, 45.134080614362446, 62.59221472058977, 14.456538370677404, 0.1678870426756995, 0.2946814075112343, 0.6439231101955686, 1.83670831152371, 3.793352953025273, 23.1490318434579, 11.251343045915876, 14.927348307200841, 4.114529524530683, 0.22783099753516062, 6.486106472355979, 59.52554389408657, 62.881989342825754, 65.10963739667619, 60.07500049046108, 59.68879181998116, 51.87165151323591, 55.84894282477242, 55.15126378195626, 52.120730536324636, 54.85954366411482, 51.83006307056972, 48.97501700265067, 50.004878997802734, 47.5889173916408, 48.09883873803275, 50.08478675569807, 51.26889181137085, 56.916814940316335, 55.60582535607474, 55.05906466075352, 52.18731164932251, 55.05397857938494, 58.532799175807405, 55.012907777513774, 44.41092600141253, 41.52093744277954, 39.75544534410749, 40.53803137370518, 42.840772083827424, 43.17119714191982, 43.05339738300869, 45.591685499463765, 53.676619802202495, 55.13905232293265, 56.362171513693674, 50.91480118887765, 44.21086304528372, 45.984453269413535, 58.23763969966343, 48.323060580662315, 51.58917249952044, 48.412303243364605, 49.23799589702061, 52.302405084882466, 55.55708026885986, 51.08540725708008, 49.41971213476998, 47.611269746507915, 50.14086219242641, 49.257447378976, 47.03535788399832, 45.000751631600515, 44.150976521628245, 40.10444641113281, 41.478032316480366, 41.589123589651926, 40.67545631953648, 46.993838923318044, 53.071615832192556, 53.48518303462437, 53.03601673671177, 47.35298783438546, 40.35276460647583, 38.56173440388271, 40.9560523714338, 43.55714872905186, 41.370171955653596, 38.725798743111746, 38.24145718983242, 40.12770203181675, 43.175685678209575, 42.170090266636436, 44.487147739955354, 42.2515092577253, 41.86038473674229, 41.75042601994106, 38.81517342158726, 42.028617995125906, 44.674439907073975, 45.56825269971575, 48.04387501307896, 49.939475604466026, 50.71250091280256, 52.079774379730225, 50.885181018284385, 47.53856379645211, 48.881178106580464, 45.515640939985005, 10.925601073673793, 0.4899822420307568, 3.818990068776267, 5.811432480812073, 8.96134967463357, 10.762257610048566, 7.880824889455523, 2.908370018005371, 0.10773675210241761, 0.3015341226543699, 0.2474275774189404, 18.037775414330618, 53.19202463967459, 25.307107584817068, 43.45351982116699, 27.67946924482073, 0.28004266587751253, 0.1823264035795416, 0.08121033478528261, 0.1428438757679292, 0.11294454908264534, 0.14360032017741883, 0.20250146170811995, 0.13661268513117517, 0.1256706565618515, 0.1171111815742084, 0.13238709473184176, 0.150422745517322, 0.13990105582135065, 0.230936055204698, 0.11133557970502547, 0.11847956957561628, 0.1042350907144802, 0.19023749764476502, 0.11141616252384015, 0.18497479361082825, 0.14014000871351787, 0.12519002306674207, 0.17762026110930101, 0.13752177277845995], [0.07261769979127816, 0.01913537793526692, 0.0479530977484371, 0.010358127981557377, 0.05695184612912791, 0.019877035370362655, 0.11231520106749875, 0.04887591555182423, 0.05371399237109082, 0.034723408719790835, 0.029756474707807814, 0.04508159861766866, 0.04075679961325867, 0.04341482823448522, 0.030225115096462623, 0.04996542566056762, 0.038291583502931256, 0.026302994395207082, 0.02137362238551889, 0.06154938906963382, 0.035365716753793616, 0.04313342958422644, 0.013464949842143272, 0.05215557385236025, 0.07274339840348278, 0.012522262837072569, 0.019849006785079837, 0.0683902705620442, 0.05149773075910551, 0.04507199734715479, 0.09775263177497046, 0.049829165650797744, 17.98697018623352, 46.55313205718994, 34.94169861929757, 44.81119087764195, 36.80279098238264, 2.685143504823957, 0.03860765189996787, 0.05216173155765448, 0.10646280260490519, 0.6358582600951195, 3.985102823802403, 4.53396361214774, 2.27197647520474, 4.0885041781834195, 0.04468943591096571, 0.057096333375998905, 11.490978598594666, 62.22097246987479, 58.19953577859061, 60.29396602085659, 56.67560127803257, 55.35748979023525, 51.487648895808626, 53.09684821537563, 53.291286604745046, 52.18475471224104, 49.61151020867484, 47.635564122881206, 46.66620356695992, 43.646481718335835, 44.061949253082275, 48.306304999760215, 52.23416682652065, 52.059468269348145, 54.784242561885286, 53.92042166846139, 50.23643466404506, 55.6372138432094, 51.819123131888254, 51.93190629141671, 40.468525069100515, 39.303878443581716, 37.28040320532662, 38.87959711892264, 39.56579078946795, 38.40651164736067, 38.88972411836897, 42.501349108559744, 51.259987694876536, 51.19572033200945, 53.83275972093855, 49.13028492246355, 46.08512224469866, 36.624131952013286, 42.84511818204607, 50.31805862699236, 50.19055223464966, 48.964358466012136, 52.16213485172817, 50.661310059683665, 49.89862367085048, 50.470425673893516, 46.70080212184361, 42.86760255268642, 44.43622439248221, 45.00356217793056, 41.527962071555, 39.382090841020855, 38.155344690595356, 36.222974232264924, 36.67149782180786, 35.6032018661499, 41.70173304421561, 49.117062500544954, 52.509767123631065, 52.51498522077288, 49.713287421635215, 43.45109837395804, 35.46681915010725, 38.068509578704834, 46.850153650556294, 46.87699801581246, 44.40950162070138, 36.96592426300049, 34.317201478140696, 36.77679082325527, 38.729595933641704, 38.514830589294434, 40.8896484375, 38.20110900061471, 38.094381196158274, 37.39000061580113, 37.716225487845286, 37.156006131853374, 40.10103484562465, 42.082348414829795, 45.3521602494376, 46.08528552736555, 47.237442765917095, 46.34198325020926, 47.184295994894846, 48.94345828465053, 48.28496708188738, 22.9110004561288, 0.8199545272759029, 0.27086892670818735, 1.3408409995692117, 4.647106340953282, 3.1614442552839006, 3.1463295349052975, 0.6482839190534183, 0.0978951919823885, 0.0882047348256622, 0.07330539503267833, 2.9883715765816823, 34.55712972368513, 25.40032982826233, 18.229642970221384, 36.34480742045811, 3.5136230375085558, 0.199690453974264, 0.03876831542168345, 0.10382185610277311, 0.0564580049498805, 0.01368527440354228, 0.08696376891540629, 0.029262033025068895, 0.022042410248624425, 0.04672446760482021, 0.008097970242878156, 0.05248374052877937, 0.04449887613632849, 0.023421006809387888, 0.10573292962674584, 0.011402636799695236, 0.09052350611558982, 0.04319919998358403, 0.06133167432355029, 0.03511182252051575, 0.03050237468310765, 0.05085845238396099, 0.07086184793817145, 0.06550059347812619, 0.034551929349878004, 0.024629989971539805, 0.030877563836319104, 0.017691872714619552, 0.02200831556027489, 0.032604455814829895, 0.04520318191498518, 0.012501390251730169, 0.01835285742501063, 0.015805358765646815, 0.057324022586856566, 0.012074003095871635, 0.07775559409388474, 0.03305398526468447, 0.01170200136091028, 0.05672724085993, 0.03286755098296063, 0.10278187226504087, 0.038376977135028155, 0.049258283605532985, 0.0637287689106805, 0.03593528244112219, 0.01771890215708741, 0.041471341092671664, 0.03481018317065068, 0.017981091480968252, 0.06103233181472335, 0.09258546547165938, 0.03383695700072816, 0.07119653533611979, 0.08107593056878873, 0.09592941496521235, 0.03605463335822735, 23.95461467334202, 49.06248787471226, 31.304386138916016, 55.81584160668509, 38.58922495160784, 1.6249746616397585, 0.04271320266915219, 0.054922103615743775, 0.03883878467604518, 0.3009050392678806, 2.2623881782804216, 5.234292524201529, 6.138750825609479, 4.41260290145874, 0.2044726466493947, 0.008991330296599438, 16.669484036309377, 65.72128731863839, 58.334782464163645, 60.07462528773716, 59.65372426169259, 57.71987383706229, 53.56123454230172, 55.04989651271275, 53.50249099731445, 54.3090900012425, 50.251654693058555, 48.47257539204189, 47.97277062279837, 44.836586543491904, 46.43889325005667, 50.398994718279155, 53.033987862723215, 55.71185834067208, 55.82499238422939, 54.21997588021414, 50.865236214229036, 57.28638614927019, 53.712799072265625, 53.70544440405709, 42.86768593106951, 40.58337879180908, 39.015823500497, 39.96436725343977, 41.509090764181956, 41.53634507315499, 41.53444821493966, 44.591131005968364, 51.82552589688982, 53.0144807951791, 54.871657848358154, 51.08206169945853, 48.4871700831822, 39.34054408754621, 45.73917143685477, 52.82039328983852, 51.230805260794504, 50.09986087254116, 52.9250088419233, 53.490821497780935, 53.272849559783936, 50.53418581826346, 49.35968664714268, 45.127431188310894, 45.83013377870832, 46.99121250425066, 44.684052739824565, 41.98731095450265, 39.717442171914236, 38.71088443483625, 38.52136537006923, 37.79710251944405, 42.10893569673811, 49.709000383104595, 54.47635398592268, 55.13445608956473, 51.39585624422346, 44.18806253160749, 37.042538574763704, 40.38549409593855, 47.95119994027274, 48.84214660099575, 44.88106196267264, 37.66142504555838, 36.27131632396153, 37.85254219600132, 40.74379880087716, 41.739333220890586, 43.002331597464426, 39.77996901103428, 40.55422762462071, 39.53391592843192, 39.456995895930696, 39.33843183517456, 42.053193773542134, 43.42019626072475, 46.87598705291748, 46.62421907697405, 48.57667677743094, 47.73554522650582, 48.74962091445923, 49.29181316920689, 50.31112779889788, 26.900114127567836, 1.085115373134613, 1.1408272236585617, 2.3480729290417264, 3.8474633523396085, 4.46791056224278, 2.093592115810939, 0.5611167592661721, 0.033380628629986725, 0.06549781826989991, 0.12853974689330372, 2.7124666443892886, 38.401029518672395, 35.23669828687395, 17.655794722693308, 43.625418254307334, 6.235597857407161, 0.2665839780654226, 0.021782268404162357, 0.046796460170298815, 0.035103340832782645, 0.0342158204210656, 0.06465568845825535, 0.0267202476305621, 0.012310799943017108, 0.013582322829669076, 0.035445800849369595, 0.1095926132319229, 0.04434725070106132, 0.054869981948286295, 0.08528977552694933, 0.03586022968270949, 0.011456888218942498, 0.045052279119512866, 0.033901472110301256, 0.03468915627204946, 0.031015934089996984, 0.020166798661063825, 0.03237106690981558, 0.016743840549939444, 0.07859104712094579, 0.23877614736557007, 0.0935826948178666, 0.10952997766435146, 0.13905682255114826, 0.16603929682501725, 0.12037830054759979, 0.23701396478073938, 0.18238266770328793, 0.23810735610978945, 0.1171506858829941, 0.07956218679568597, 0.1720181131469352, 0.11468655882137162, 0.1065212380407112, 0.1695641776812928, 0.13179580574589117, 0.14383475402636187, 0.11663516211722579, 0.1110403151916606, 0.18099639351878846, 0.13305930580411637, 0.09724788993064847, 0.12125023161726338, 0.1507466917059251, 0.1347335638212306, 0.1481099317648581, 0.13598202754344257, 0.14119082875549793, 0.20424355965639862, 0.18513817127261842, 0.2575001854981695, 0.2933220033134733, 29.836513178689138, 61.21568625313895, 43.62045724051339, 56.64954900741577, 46.26197126933506, 5.208469109875815, 0.2760758144514901, 0.11815531126090459, 0.3298153265246323, 2.3041707362447466, 12.491231713976179, 14.292173521859304, 8.577341846057347, 9.183635575430733, 0.15087174570986203, 0.15176849759050778, 14.370769807270594, 63.701133319309776, 61.78664057595389, 64.05977848597935, 61.265789713178364, 60.237178393772666, 55.6134683745248, 57.20564808164324, 56.85785600117275, 57.23966646194458, 53.327549253191265, 50.29580007280622, 52.212561403002056, 45.908186367579866, 47.54581424168178, 52.4449508530753, 55.31089169638497, 58.12662833077567, 58.47795009613037, 56.393744128090994, 51.656142711639404, 60.151451519557405, 56.36266483579363, 57.22726740155901, 45.21282802309309, 43.03031199319022, 43.1572208404541, 42.16590397698538, 44.48196785790579, 43.50205993652344, 43.35627283368792, 46.6984293120248, 55.50675446646554, 55.50298159463065, 58.00599718093872, 54.27429689679827, 49.18677030290876, 41.676955768040244, 46.845077991485596, 53.65698766708374, 52.440781933920725, 49.59889922823225, 56.035293510981965, 55.71598904473441, 55.33887209211077, 52.92990384783064, 52.14374644415719, 47.6670811516898, 49.0285632950919, 48.951622417994905, 46.64452518735613, 43.23258100237165, 41.55618912833077, 38.49013669150216, 40.2094441141401, 37.937473501477925, 45.36763736179897, 51.106679167066304, 54.51675428662981, 57.48850924628121, 52.61913524355207, 46.46129076821463, 37.9789924621582, 41.78699786322457, 51.89192288262503, 50.13704763139997, 47.78022909164429, 39.98360334123884, 38.6405200277056, 39.53718158176967, 43.15023790087019, 42.50393383843558, 46.85078593662807, 41.9899616922651, 43.90978022984096, 41.16923005240304, 41.50011369160244, 40.27866554260254, 42.976261956351145, 44.81512008394514, 49.27296270642962, 48.797851834978374, 51.03085000174386, 49.66969442367554, 48.69950703212193, 50.480827127184185, 50.957001073019846, 26.56851134981428, 1.8589154056140353, 1.8440034857818057, 4.855575748852321, 10.28801439489637, 7.018430548054831, 10.790403894015721, 4.487387231418064, 0.46892936314855305, 0.26606194036347525, 0.20057761136974606, 4.844639718532562, 45.53322335651943, 35.233637605394634, 25.644609383174352, 50.595708642687114, 6.87154997246606, 0.3469414146883147, 0.11149038068417992, 0.18633955823523657, 0.12146056390234403, 0.1532630388225828, 0.1924596591187375, 0.11466636561921664, 0.11849242102886949, 0.06688516453972884, 0.13831293103950365, 0.27013472467660904, 0.14523250902337687, 0.08400245888956956, 0.23845273043428147, 0.16082293673285417, 0.12734262113060268, 0.12285101786255836, 0.10240032523870468, 0.14971727265843324, 0.0864470780694059, 0.14290640955524786, 0.17849719976740225, 0.10785216412373952, 0.19736185749726637], [0.033867026280079565, 0.02045397842968149, 0.04775521658094866, 0.022557209678260342, 0.009458540672702449, 0.062221620497959, 0.0324201555257397, 0.06341892267976489, 0.06888736531670604, 0.04168520175984927, 0.009741533032086278, 0.05597049110968198, 0.02111847116611898, 0.06495522095688752, 0.00978336895682982, 0.08213547657110862, 0.04939587693661451, 0.05710698637579169, 0.02367181540466845, 0.027094045786985328, 0.029718018735625913, 0.03341522373791252, 0.054745779505797794, 0.024914635411862816, 0.05508542360205736, 0.010562127838576478, 0.05295506791610803, 0.06699929412986551, 0.02710586247433509, 0.0012012428799477804, 0.024063425105331198, 0.02100657904520631, 1.5908958102975572, 38.36177914483206, 38.31119973318917, 31.672407899584087, 47.187714508601594, 28.007945333208355, 1.1919141794954027, 0.009050571492740085, 0.036756170714007955, 0.09094319359532424, 1.4917282973017012, 4.280303120613098, 3.5156618995325903, 2.246120056935719, 1.0289082463298524, 0.06558992939868144, 0.14736800800476754, 19.77297510419573, 66.95823342459542, 57.69736167362758, 60.593752997262136, 57.113417693546836, 56.80630036762783, 54.25840636662075, 55.24406392233712, 53.60661322729928, 52.73920011520386, 50.02336468015398, 48.50544037137713, 43.757638999394004, 44.14681455067226, 47.74774973733084, 52.80514546803066, 53.55697182246617, 54.84399012156895, 51.599563530513215, 54.53629609516689, 52.990158626011436, 52.69184466770717, 46.72068786621094, 40.543860912323, 38.715035983494346, 38.22157839366368, 36.5430360521589, 37.07862057004656, 39.34442465645926, 39.524105072021484, 45.82869202750069, 51.19716208321707, 51.45249448503767, 53.55655493055071, 51.27301904133388, 51.507010051182334, 46.33082791737148, 41.78060552052089, 41.52941077096121, 47.11556441443307, 49.87240464346749, 51.26212774004255, 49.82386800221035, 49.59150634493147, 49.096596581595286, 47.2475836617606, 47.239516803196494, 42.267726353236604, 40.1565648487636, 40.1377352305821, 36.95229189736502, 36.72343560627529, 38.932872431618826, 36.9793655531747, 37.7185183933803, 47.77206148420061, 50.561162199292866, 54.12074865613665, 51.55582809448242, 50.552060059138704, 40.225942611694336, 35.863752365112305, 40.94805152075631, 48.45517710277012, 49.65183755329677, 50.80046510696411, 44.71986722946167, 36.33928707667759, 37.23233904157366, 39.1746141569955, 40.823004790714805, 41.970228808266775, 40.834153175354004, 39.38221590859549, 38.68833753040859, 39.041097572871614, 38.093311173575266, 42.53377982548305, 43.34025376183646, 45.45916598183768, 47.17270639964512, 48.510755743299214, 49.84113080160958, 50.42067657198225, 46.642378193991526, 24.77170545714242, 2.02454634649413, 0.06561498769692012, 0.8745562945093427, 1.7854171437876565, 4.136783301830292, 2.3395665969167436, 1.7883022746869495, 0.20398210654301302, 0.07863865992320435, 0.055704790367079635, 1.6435324315513884, 24.51628793988909, 38.12117692402431, 17.66874269076756, 31.701308931623185, 17.643869876861572, 0.10734919325581618, 0.04280552414378949, 0.05252533811809761, 0.038074062139328034, 0.01018201930647982, 0.027004436756085073, 0.03869779866987041, 0.027159261483965174, 0.02116149028630129, 0.06391932189996753, 0.08244707342237234, 0.023818470570924025, 0.031609862577170134, 0.01048757549974003, 0.042584148701280355, 0.028342579059036713, 0.04155450573723231, 0.050137447858495374, 0.0313984751701355, 0.003374411687088598, 0.04080098920634814, 0.022798829213050858, 0.030415953070457493, 0.019259834828387414, 0.023505665927327106, 0.043599969906998534, 0.03764091252482363, 0.09786530251481704, 0.05128720509154456, 0.021805413233648454, 0.040457375680229495, 0.04771383612283638, 0.002512890616864232, 0.07888439816555806, 0.030276018793561628, 0.09731449492807899, 0.006602212736782218, 0.03801796764933637, 0.05012544796669057, 0.050144053396901915, 0.03281152434647083, 0.11761926859617233, 0.04358256209109511, 0.03563228941389492, 0.0191986445404057, 0.024234921438619494, 0.04791458410077861, 0.02457508461416832, 0.0952057098703725, 0.03583328505711896, 0.0331545271910727, 0.027917027340403626, 0.06394718933318343, 0.024668373001207198, 0.07308825704136065, 0.03693603338407619, 0.14200918270008905, 2.8269479870796204, 47.776386737823486, 39.5646756035941, 34.572978564671104, 58.085158007485525, 28.261945417949132, 0.5823470343436513, 0.02933991188183427, 0.08506206596004111, 0.20099219626614026, 0.2607266737946442, 3.20849854179791, 3.560117994035993, 5.231929702418191, 2.1819723333631242, 0.0574666845745274, 0.2248767374881676, 25.47466513088771, 66.16781330108643, 58.09507656097412, 60.488619804382324, 59.26146371023995, 59.1708869934082, 55.226189681461875, 55.22044352122715, 54.31709432601929, 54.78466640199934, 51.48996959413801, 49.11614881243025, 45.19982099533081, 46.38732024601528, 48.76898206983294, 54.25762816837856, 54.902709347861155, 58.002321583884104, 52.270630972726, 54.9424843106951, 55.04318107877459, 53.35051999773298, 47.993490150996614, 43.258754866463796, 40.16027866091047, 38.19213192803519, 39.19873135430472, 38.85924237115042, 41.1548090662275, 41.35604279381888, 45.66060120718819, 52.54990686689104, 52.45556770052229, 54.54372719355992, 52.08726453781128, 54.41297251837594, 48.97364125932966, 44.737904753003804, 43.249534606933594, 48.30865349088396, 49.40641328266689, 52.41882562637329, 52.40269538334438, 52.00440379551479, 51.181215967450825, 47.79188469478062, 48.08951078142439, 45.132458209991455, 41.37036997931344, 43.23652410507202, 39.008531366075786, 38.82893085479736, 40.460809094565256, 39.017602239336284, 39.34193025316511, 50.20367390768868, 53.71621758597237, 54.44798101697649, 51.777430466243196, 51.66631487437657, 42.176711899893625, 37.838208062308176, 41.68189941133772, 50.03947755268642, 51.33417361123221, 52.32355887549264, 46.13018478666033, 37.881571769714355, 39.018700054713655, 39.89986712591988, 42.25330189296177, 43.784455571855815, 42.192925521305625, 40.86268595286778, 40.42120783669608, 40.40014784676688, 40.66420718601772, 43.91081551143101, 45.64336272648403, 46.11767455509731, 49.14534861700875, 50.25083480562483, 50.48348133904593, 49.382028579711914, 47.69408185141427, 28.152309792382376, 3.4551237651279996, 0.7191966910447393, 1.0527507726635252, 1.702450550028256, 7.476160934993199, 3.643175022942679, 0.8324265437466758, 0.1155051298971687, 0.04995063020448599, 0.03216624093641128, 1.5816221364906855, 25.057663781302317, 46.61904614312308, 20.67938150678362, 31.313241618020193, 26.425131797790527, 0.10267727609191622, 0.011108176350327474, 0.04188282847670572, 0.06174701917916536, 0.014678330759384801, 0.08788096505616393, 0.017446463561749885, 0.014235359350485461, 0.027804802737331817, 0.04374570905097893, 0.034912407863885164, 0.02475623819710953, 0.05763809609093836, 0.05558965654511537, 0.04954135484461274, 0.03092687636879938, 0.02528831482465778, 0.01477712715443756, 0.041645568529410024, 0.04208807174914649, 0.05629262900246041, 0.03449157026729413, 0.026953753582867127, 0.04835892954309072, 0.03231798850798181, 0.13769155581082615, 0.07933563073830945, 0.20094374886580876, 0.14161477743514947, 0.11008571820067507, 0.1508620698004961, 0.24326354371649878, 0.11272215923028332, 0.1783392368150609, 0.12851043418049812, 0.15465850037123474, 0.11702384054660797, 0.0787169017962047, 0.10524212489170687, 0.0907360232834305, 0.3298538401722908, 0.19708147325686046, 0.1599813633199249, 0.143995037568467, 0.13962040016693728, 0.07269635557063989, 0.1168489142188004, 0.118059013571058, 0.22737483201282366, 0.11865503873143878, 0.11464486962982587, 0.17198106513491698, 0.17892391686992987, 0.07853636398379292, 0.14033610533390725, 0.12827372045389243, 0.2921280530946595, 3.095203821148191, 54.234785965510774, 49.46811328615461, 43.96446255275181, 58.80996976579939, 38.75580106462751, 2.3579363312040056, 0.10667377271290336, 0.18871745706668921, 0.6290786096027919, 4.499555264200483, 13.154736910547529, 11.78996045248849, 9.707937955856323, 4.726264127663203, 0.2145283320652587, 0.43592148433838573, 22.88413350922721, 67.75858252389091, 60.858597482953755, 64.03942721230644, 63.28001689910889, 61.22191183907645, 58.50754247392927, 58.31689780099051, 57.69169889177595, 57.171935422079905, 55.10216086251395, 51.674965381622314, 47.7246539252145, 49.768879958561485, 50.57982506070818, 56.32495696204049, 57.06731292179653, 58.1688733782087, 53.331245694841655, 58.77349172319685, 56.375418254307334, 54.792038440704346, 48.21779884610857, 45.18921457018171, 41.15454503468105, 40.84686490467617, 41.64707156590053, 41.124348163604736, 44.275109563555034, 43.361056668417795, 49.54179893221174, 55.806131499154226, 54.52789224897112, 57.15351922171456, 55.17057977403913, 54.857323714665, 49.92314733777727, 47.0245430128915, 44.97447007043021, 49.067320346832275, 49.86070040294102, 53.10623870577131, 53.94819014413016, 53.506298610142295, 53.97163684027535, 49.68646042687552, 51.614338874816895, 47.1947808265686, 43.45498589106968, 44.4855774470738, 40.19763912473406, 40.37318536213466, 42.80878952571324, 41.83956445966448, 43.09918253762381, 54.161572796957834, 54.358331884656636, 56.40422548566546, 53.86981793812343, 54.1573726109096, 43.69033179964338, 40.17711067199707, 44.0882933480399, 50.94500848225185, 53.3474245752607, 54.579510416303364, 48.67824901853289, 39.63625247137887, 40.456657545907156, 42.31778464998518, 45.41473920004708, 45.88047347749983, 46.25942128045218, 44.33471815926688, 43.72317940848214, 42.812732628413606, 41.258719376155305, 47.505340984889436, 47.783588545663015, 48.687841006687705, 52.045731680733816, 52.305653367723735, 52.075786113739014, 51.27703857421875, 48.00963429042271, 26.79752050127302, 2.8551029562950134, 0.5379244323287691, 2.115437686443329, 6.615286077771868, 8.33965960570744, 11.653034908430916, 6.811324724129268, 0.37902141043118065, 0.2264164148696831, 0.2034981617970126, 3.082567653485707, 34.973031520843506, 46.72301551273891, 26.49448871612549, 42.012849058423726, 27.80658480099269, 0.25421732451234547, 0.19136298368019716, 0.11000195983797312, 0.17987766569214209, 0.06732227001339197, 0.21141956959451946, 0.10608636494725943, 0.09218472268964563, 0.10537924324827534, 0.16829458437860012, 0.11439970135688782, 0.08940848987549543, 0.16423993052116462, 0.10126267985573836, 0.17378501833549567, 0.14965028768139227, 0.13223051599093846, 0.07933077921292611, 0.1684798380093915, 0.1188064877476011, 0.21647979877889156, 0.12587082439235278, 0.09621585173798458, 0.1421165812228407, 0.1172504441014358], [0.006302651400411767, 0.021471234736964107, 0.028854325081088712, 0.041730541469795365, 0.056902503062571795, 0.013047843339986034, 0.0314136336424521, 0.04572774037452681, 0.007455752114765346, 0.05788504212562527, 0.08935510952557836, 0.039266804565808604, 0.0382417077863855, 0.04978767323440739, 0.01528669338274215, 0.0507145147504551, 0.02685586133572672, 0.039468570346278806, 0.047397686301597526, 0.023738247375669222, 0.030542526992836168, 0.05724725992019687, 0.0057118098234890825, 0.026965207253981913, 0.0779934274032712, 0.06514564502452101, 0.020466409191223126, 0.04556520748883486, 0.02703666716947087, 0.03698074205645493, 0.07126236680362906, 0.08167512448770659, 0.06345057633838483, 10.736083745956421, 46.60172080993652, 31.795585564204625, 39.353210653577534, 47.64667081832886, 26.08914644377572, 1.7346235322100776, 0.09397843679679291, 0.027860298420169523, 0.24283617522035325, 1.6235863247088023, 3.923113167285919, 3.3750592385019575, 0.7331984511443547, 0.28567605359213694, 0.024968986066856554, 0.3575797309832913, 29.529441016060964, 67.45877470288957, 59.7586281640189, 60.570066588265554, 57.94960560117449, 55.38562652042934, 55.279492786952424, 56.05846575328282, 54.697331019810264, 54.60724762507847, 50.34566729409354, 43.43634387425014, 44.13370329993111, 53.28970241546631, 53.34709106172834, 54.66498020717076, 53.30056939806257, 53.15680769511631, 56.032069546835764, 50.997258935655864, 51.46141249792916, 46.387924739292686, 40.66651398794991, 38.08692230497088, 38.18442637579781, 39.33351945877075, 39.34711708341326, 39.3771402495248, 40.22733225141253, 40.08719750813076, 53.24950361251831, 54.78587886265346, 53.11340229851859, 51.33029999051775, 53.40888833999634, 47.44623613357544, 45.477634293692454, 48.28151035308838, 47.07433727809361, 52.062417779650005, 53.04939896719796, 52.97945840018136, 50.90697404316494, 48.258800165993826, 45.41938407080514, 44.85735470908028, 41.69991956438337, 39.864643233163015, 38.22026865822928, 38.40412841524397, 38.88743468693325, 37.998589856284006, 38.39004094260079, 42.36660964148385, 51.32988657270159, 52.46213722229004, 54.36651686259678, 53.64508540289742, 49.18884434018816, 38.76282221930367, 38.0436350277492, 49.89397185189383, 52.01635122299194, 52.376149790627615, 50.75656986236572, 48.3508221081325, 43.68276868547712, 38.240366322653635, 40.18685204642159, 41.557325158800396, 43.32507542201451, 44.94430446624756, 42.36858292988369, 40.84330742699759, 41.886047908238, 43.88263709204537, 42.46936307634626, 44.52535588400704, 47.72297593525478, 46.753365244184224, 45.55761153357369, 48.36611161913191, 44.500912121364046, 20.021394048418315, 1.9853700143950326, 0.14994068709867342, 1.0002035009009498, 1.0032936036586761, 0.18331057791199, 4.722331012998309, 3.5147334464958737, 0.22835887063826832, 0.04337001099650349, 0.01387798089334475, 2.742944483246122, 22.98164800235203, 40.4689211164202, 21.12167603628976, 22.636343376977102, 33.0588618687221, 2.2239835304873328, 0.20231253041752748, 0.07164994600628104, 0.009941516809963753, 0.053532426578125784, 0.04185976507142186, 0.03577268848727856, 0.01880300773440727, 0.03362162730523518, 0.049600394176585336, 0.020591120534975613, 0.02140222942190511, 0.026739216077008417, 0.0791309235085334, 0.03927661618217826, 0.03793700145823615, 0.02264848960164402, 0.01753135507793299, 0.02052388958899038, 0.00913701091693448, 0.07551543108586754, 0.02896341654871191, 0.04914704457457576, 0.006828095348152731, 0.036795454498912604, 0.038247224276087115, 0.02579454266067062, 0.041992238855787685, 0.0677856280069266, 0.012602976273878344, 0.14584172490452016, 0.09715070335992745, 0.02647285715543798, 0.035265456419438124, 0.06064735818654299, 0.10502869170159101, 0.0350993951516492, 0.044495931294347556, 0.049475815147161484, 0.017312585209895457, 0.03917926676305277, 0.02813879124421094, 0.013324817093754453, 0.05544167484289833, 0.011821198759467473, 0.08801035489886999, 0.023111871343904307, 0.02304173626803926, 0.0168143980138536, 0.024834797285231094, 0.018203379553077475, 0.046620421045060666, 0.023209699130217944, 0.08843137909259115, 0.03387435785095606, 0.051781897832240374, 0.051598737481981516, 0.08058317843824625, 0.06322297533707959, 16.443719693592616, 51.497011593409944, 31.600785868508474, 42.89668771198818, 57.35980428968157, 24.68056419917515, 1.23260489319052, 0.06972192267754249, 0.009195496394698108, 0.16859660031540052, 0.6190885113818305, 3.370425875697817, 8.012949228286743, 6.2425234743527005, 1.4807169224534715, 0.12691823818853923, 0.6357754245400429, 37.456456661224365, 66.92427062988281, 62.26034096309117, 60.272767066955566, 58.7969696862357, 55.31014129093715, 57.231599603380474, 55.81079721450806, 56.9414358820234, 56.90850142070225, 51.35666145597185, 45.466496331351145, 46.40711218970162, 54.64591435023716, 56.118977614811485, 57.57213429042271, 54.405315603528706, 51.43546792439052, 58.630129541669575, 53.561172008514404, 55.56192316327776, 49.11197989327567, 42.40240328652518, 39.490611280713765, 40.754763058253694, 41.19001906258719, 42.38662045342581, 41.21301065172468, 42.24937268665859, 42.888210909707205, 54.164821079799104, 56.38584055219378, 54.67687552315848, 52.50781467982701, 54.01532711301531, 51.18756314686367, 50.42826747894287, 50.587332589285715, 50.15140608378819, 51.56998157501221, 55.098961217062815, 56.2440173966544, 53.092033113752095, 51.94868271691458, 48.15964937210083, 46.33201258523123, 42.59763724463326, 42.291009766714915, 40.90037298202515, 39.82118919917515, 38.57638815471104, 39.73596259525844, 38.06944758551461, 41.86999409539359, 51.948418685368125, 54.135256494794575, 55.56294454847063, 54.98921094621931, 50.686281885419575, 41.34328590120588, 38.599949496132986, 51.973133427756174, 53.65887757710048, 52.51062175205776, 52.2681747845241, 50.03305394308907, 43.17523404530117, 39.86623437064034, 42.400197233472554, 43.2259315763201, 44.695406096322195, 44.898345606667654, 43.75655855451311, 43.02636194229126, 42.82881770815168, 43.91203839438302, 43.58269725527082, 45.07960673740932, 49.533937045506065, 47.38021435056414, 47.53658703395298, 50.30555534362793, 46.37967027936663, 25.92864305632455, 3.891659540789468, 0.44721466835056034, 1.221764617732593, 1.5429798385926654, 3.228683275835855, 4.551018399851663, 1.0992816644055503, 0.22404185443052224, 0.05163362775264042, 0.03375483051474605, 2.298437169619969, 21.727930682046072, 43.97802891050066, 28.23711255618504, 20.661460365567887, 41.40485388892037, 4.27069810458592, 0.2840205638536385, 0.031677960351641686, 0.029944530688226223, 0.020840975788554976, 0.02112577898826982, 0.0414229785092175, 0.035571143230689425, 0.037501500719892125, 0.002270196664280125, 0.03647734371146985, 0.02342333079182676, 0.003372066924514781, 0.06974523714078323, 0.020968116287674223, 0.03325846179255417, 0.022624437231570482, 0.03451304590063436, 0.01139564364815929, 0.05632244043850473, 0.0024929306611219154, 0.0692332349717617, 0.0522005301900208, 0.030514812229999473, 0.04408571955614856, 0.013965361784877521, 0.11475244457168238, 0.09840316365339927, 0.12047800448323999, 0.13981937377580575, 0.2173819382275854, 0.14812171113278183, 0.11807985816683088, 0.17615994518356665, 0.19590772981090204, 0.31088650652340477, 0.2501492356615407, 0.1063156012179596, 0.15617836453020573, 0.12206323870590755, 0.15240622551313468, 0.150889428332448, 0.12035156626786504, 0.16065562356795582, 0.16224011140210287, 0.13201559680913175, 0.10661601581211601, 0.13481777001704487, 0.11761673087520258, 0.08211589405047041, 0.1998096318649394, 0.21285309695771762, 0.09550614482057945, 0.20351983420550823, 0.21631541688527378, 0.1577859225549868, 0.18030122082148278, 0.150995456214462, 0.13760365838451044, 16.917043140956334, 62.96976593562535, 40.57971361705235, 50.60761090687343, 58.87485204424177, 36.665112427302766, 2.9724330604076385, 0.19304528912263258, 0.13842364081314631, 0.675486333668232, 5.3930089218275885, 10.37269035407475, 7.143907632146563, 5.528201758861542, 1.2662527390888758, 0.19312109505491598, 0.5880363062024117, 34.20509576797485, 72.28378445761544, 62.17917210715157, 64.62953077043805, 59.89680698939732, 56.8192309652056, 60.5912446975708, 61.31996481759207, 59.100175176348, 60.22850704193115, 54.962238039289204, 47.506199087415425, 47.61388226917812, 58.19378614425659, 59.42487839290074, 58.689133644104004, 55.64292526245117, 53.091595377240864, 61.33853735242571, 56.46589422225952, 57.87200117111206, 51.696532590048655, 44.51487800053188, 42.346070766448975, 43.45680284500122, 44.35271051951817, 43.365281173161094, 43.852183137621196, 44.23821810313633, 43.5253780909947, 56.15146739142281, 59.10751247406006, 56.31831101008824, 54.98495864868164, 57.47121865408761, 51.63497849873134, 51.62328815460205, 54.25631843294416, 52.648335048130576, 52.168468134743826, 57.850531237465994, 58.02349969318935, 54.7353515625, 53.355616501399446, 50.036462034497944, 49.774007729121614, 45.91076067515782, 44.39207206453596, 41.36377266475132, 41.68622119086129, 41.78687626974923, 41.39140565054757, 41.085962840488975, 45.35186842509678, 54.45125361851284, 54.682437556130544, 58.661042077200754, 56.664379937308176, 53.330644675663535, 42.86267280578613, 41.0103942326137, 55.56107895714896, 56.61246299743652, 55.410007749285015, 55.28533622196743, 52.53108767100743, 47.57744591576712, 42.97823871885027, 46.575154372623985, 45.920432567596436, 47.434038570949006, 48.35179138183594, 45.805790764944895, 45.30642720631191, 45.67070041384016, 47.063890661512104, 45.914061069488525, 47.65095438276018, 52.71315131868635, 49.37432302747454, 49.49266127177647, 48.88627461024693, 46.27454056058611, 22.66217851638794, 3.3497671442372456, 0.3191518230097634, 2.44789856672287, 2.8309186654431477, 3.3489535536084856, 14.985780920301165, 11.011464306286403, 1.0607307787452425, 0.19788207672536373, 0.2039081733673811, 4.530380078724452, 31.757273197174072, 48.795836857386995, 32.303505829402376, 30.826391765049525, 46.584708145686555, 4.214749472481864, 0.39081383336867603, 0.14923496996717794, 0.13253481180540153, 0.09491035036210503, 0.18608582685036318, 0.09193317618753229, 0.08254433463194541, 0.19541425843323978, 0.10182296657668692, 0.2161914078252656, 0.06561324386192219, 0.1129456754507763, 0.13315495210034506, 0.1316169032028743, 0.17066947051456996, 0.11840976189289774, 0.14502288241471561, 0.09968973390225853, 0.08044354271675859, 0.2085318331207548, 0.1956867988088301, 0.2506779230066708, 0.0970130693167448, 0.13918103517166205, 0.11323899256863765], [0.01795451156795025, 0.057723523649786196, 0.0060102490325724435, 0.0038585436663457324, 0.021453874418511987, 0.01016069549535002, 0.021811431839263866, 0.04419252096808382, 0.0501390899132405, 0.03246421280450054, 0.02962159551680088, 0.07296936413539307, 0.06812254099973611, 0.028192500683612058, 0.024674198224342296, 0.027607942765046443, 0.06971120860959802, 0.0934048236480781, 0.041172843359942944, 0.047765920470867834, 0.015022453186767442, 0.03532544570043683, 0.027685887778976133, 0.04560122752029981, 0.0478431513266904, 0.00609381146828777, 0.027182173915207386, 0.04170641954988241, 0.05273666445698057, 0.058232092431613376, 0.07620959276599543, 0.06854636754308428, 0.08526625750320298, 0.14268110878765583, 18.632271971021378, 43.46130180358887, 35.84291819163731, 41.12678350721087, 43.73223638534546, 31.774754864828928, 3.46877458691597, 0.07215983114604439, 0.022511062511642064, 0.3755364545754024, 1.2725834165300642, 10.760655181748525, 8.991663796561104, 1.2321680252041136, 0.38482942591820446, 0.04348879533686808, 1.6597117462328501, 31.20239700589861, 65.4558800288609, 61.47060176304409, 61.51757158551897, 59.21190915788923, 56.955721378326416, 55.87406751087734, 59.91209997449602, 55.02384424209595, 53.806405203683035, 46.214827741895405, 47.47509895052229, 53.46469627107893, 56.368730613163535, 55.521776471819194, 53.66963338851929, 54.45433861868722, 55.838013308388845, 53.918472698756624, 51.183529717581614, 41.661926814488, 39.28774472645351, 40.68816804885864, 38.560966627938406, 38.246102060590474, 39.0807648386274, 39.53291538783482, 39.64019904817854, 40.179566860198975, 47.61918374470302, 54.57620654787336, 53.55658967154366, 55.23253686087472, 53.471408230917795, 54.917526381356375, 50.19532217298235, 47.501720973423545, 50.12508978162493, 48.02374955586025, 49.18183708190918, 54.96049056734358, 51.32956000736782, 50.830995491572786, 47.15498154503958, 45.4556953566415, 41.34261540004185, 39.09527962548392, 37.41413170950753, 38.807151726314, 38.661201340811594, 39.05181169509888, 39.10600069590977, 48.44504662922451, 53.499808992658345, 53.82497426441738, 53.754432678222656, 51.15312440054757, 48.448979309626985, 38.76239490509033, 43.670362676892964, 51.30406011853899, 50.293844154902864, 51.71991327830723, 50.26144470487322, 51.00366170065743, 48.111015456063406, 39.59008169174194, 39.702614716121126, 42.69302906308855, 44.90525211606707, 42.772773538317, 43.014720235552105, 43.57076372419085, 42.5302848815918, 44.41403879438128, 47.193040302821565, 46.19752672740391, 45.40114157540457, 50.518472467150005, 50.69735383987427, 47.274275166647776, 21.76325532368251, 1.3960812411137988, 0.08760216180235147, 0.5934294653790337, 1.7799942919186182, 0.7682355024984905, 1.6368462017604282, 3.4607192363057817, 0.4397824028772967, 0.05948348742510591, 0.0792723505624703, 4.149680895464761, 26.069837399891444, 35.79472896030971, 28.39053225517273, 21.35458833830697, 37.060367652348106, 8.835279822349548, 0.12344476314527647, 0.011612913105636835, 0.04848526258553777, 0.049094067952994785, 0.04680862630318318, 0.030740550652678524, 0.011474020379994596, 0.047612669944230995, 0.02123987295531801, 0.04806214511128409, 0.027121127815917134, 0.046855709848127196, 0.045798206236213446, 0.051924451254308224, 0.0819582703656384, 0.037397002934345176, 0.08587324100413493, 0.027793432186756815, 0.10221620476139442, 0.09473882349474089, 0.03427284111135772, 0.0015678134721903397, 0.035013295843132904, 0.03104737401008606, 0.08471585025212594, 0.024157252927709903, 0.01631832615073238, 0.03649960305275662, 0.04679422779008746, 0.030454263157610382, 0.05078265323702778, 0.038215289025434425, 0.046728630417159626, 0.0726455943658948, 0.06566764879971743, 0.01360606646630913, 0.056788577032940726, 0.039261210044579845, 0.06060611004275935, 0.014157159885923778, 0.03711407079494425, 0.03939441664676581, 0.03461094493312495, 0.010895186752480055, 0.10071365003074918, 0.012917828396894038, 0.05492607983095305, 0.023633970114003335, 0.015082861463140165, 0.0225079056274678, 0.020248763994979005, 0.037089826738727946, 0.03948913674269404, 0.032558172941207886, 0.06300452098782573, 0.007299560986991439, 0.009335277153046002, 0.0696275316710983, 0.07140022476336785, 0.4217412695288658, 29.485208783830913, 47.59376376015799, 38.19753415243966, 47.65208693913051, 54.07688815253121, 30.69712053026472, 2.3853124507835934, 0.06824888422020844, 0.023090083584455506, 0.2579468515302454, 0.4317661630255835, 4.693362670285361, 9.346822704587664, 4.299605650561197, 0.7902388189520154, 0.11020901479891368, 2.9869550125939504, 40.41013240814209, 64.3223717553275, 62.13460636138916, 64.6569344656808, 61.14808028084891, 57.10821349280221, 57.46693161555699, 60.91050747462681, 57.50375011989048, 55.499834060668945, 47.278569153376985, 48.88831390653338, 54.9218863759722, 58.15004028592791, 57.59369107655117, 54.7717080116272, 56.04274892807007, 57.17990500586373, 56.08548034940447, 51.37996571404593, 44.379151889256065, 41.735952922276084, 41.518564632960725, 41.289333139147075, 40.854136194501606, 42.35488108226231, 41.599934986659456, 42.268389906202046, 41.743502140045166, 51.638039180210654, 56.67629957199097, 55.609966482434956, 56.94146367481777, 54.23659249714443, 55.36228404726301, 51.305581774030415, 50.24906996318272, 53.22321162905012, 50.91951206752232, 51.93886491230556, 55.60794455664498, 52.21397883551461, 52.05616787501744, 48.85314907346453, 48.312332562037874, 44.271896021706716, 41.06971100398472, 40.14273445946829, 40.15353543417794, 39.32675886154175, 40.62484564099993, 40.01304633276803, 49.146203245435444, 55.4788852419172, 55.28169536590576, 53.9831326348441, 53.44944497517177, 49.12456655502319, 39.80412094933646, 42.827501024518696, 51.17889526912144, 52.009868553706575, 52.4671642439706, 51.894215788160054, 52.230783053806846, 48.848608425685335, 41.49646936144148, 41.46495580673218, 44.34443868909563, 44.25950043542044, 46.639967169080464, 44.721260343279155, 44.21797800064087, 44.50859682900565, 46.784965651375906, 47.41775894165039, 48.63269662857056, 47.2013156073434, 50.94582142148699, 51.90201166697911, 47.78645120348249, 26.005029814583914, 1.9666891310896193, 0.4332181193998882, 1.4713179639407565, 2.6812360116413663, 3.3280194997787476, 4.291947432926722, 1.2816787170512336, 0.21936292121452944, 0.034178789372422864, 0.10490888277334826, 3.1731936591012135, 27.055845839636667, 41.609127453395296, 36.61487347739083, 19.4564916065761, 39.019499097551616, 15.214977673121862, 0.04041495706353869, 0.06126152737332242, 0.04866975964978337, 0.0768978444061109, 0.04941482502701027, 0.053021744159715514, 0.02487680029922298, 0.05001014790364674, 0.03683680442294904, 0.06232857797294855, 0.015800254485969032, 0.01200864660287542, 0.03128584174971495, 0.030940413142421415, 0.08519716228225402, 0.05723643050129924, 0.04168238244684679, 0.021904879682032124, 0.013721060340425797, 0.06716845291001455, 0.017206684553197453, 0.04359400558418461, 0.014425637533089944, 0.050260130382542095, 0.06448827351310424, 0.013293507791656469, 0.08629529657108442, 0.10017967689782381, 0.23110262198107584, 0.1367761306464672, 0.12441601817096982, 0.13186023943126202, 0.10654886120132037, 0.2791444483612265, 0.12477005060229983, 0.07797349882977349, 0.15431354673845427, 0.11763372139206954, 0.16866871501718247, 0.1336635005261217, 0.12340053623276097, 0.13542493672243186, 0.11465196710612093, 0.2708103284239769, 0.16558279203517096, 0.19367289330278123, 0.2014641309423106, 0.12067898655576365, 0.08668477567178862, 0.1365969566894429, 0.12367032175617558, 0.09130163650427546, 0.09503092603491885, 0.12209607980081014, 0.09815636689641646, 0.13970178365707397, 0.19622271933725902, 0.3172896515045847, 0.18939890978591783, 0.46901046165398186, 30.060891355787003, 58.75803892953055, 46.515052454812185, 52.28701829910278, 56.38961342402867, 43.385837418692454, 5.9644717659269055, 0.2206226350473506, 0.19830958092851297, 1.164859196969441, 5.111984687192099, 21.8353203024183, 21.696936505181448, 5.754772092614855, 0.8539609110781125, 0.13978894826556953, 2.0404720519270216, 35.03960221154349, 67.5519847869873, 63.94928823198591, 67.42227581569126, 64.88386263166154, 60.07486847468785, 61.67699105398995, 65.85998725891113, 59.655190331595286, 58.31785665239607, 50.29292699268886, 53.280704498291016, 56.68790306363787, 61.84859071459089, 58.72574370247977, 55.77267592293875, 58.73467908586775, 60.794250215802876, 58.896627698625835, 54.48853417805263, 45.79097720554897, 43.30064902986799, 44.731123311179026, 42.664597034454346, 43.41958481924874, 44.63129506792341, 43.99972813470023, 44.7053142275129, 43.781412260872976, 53.01217746734619, 58.46631186349051, 58.04220771789551, 59.40613910130092, 56.32320949009487, 57.81873975481306, 53.604605197906494, 52.88659920011248, 54.01585170200893, 51.9613527570452, 50.2892027582441, 56.60759578432356, 54.20007276535034, 53.21197986602783, 50.51745455605643, 50.33035346439907, 46.44923564365932, 43.06676919119698, 41.7912849017552, 42.14428465706961, 41.328204836164204, 43.881355149405344, 41.61294201442173, 53.10987956183297, 56.96016475132534, 57.939961501530235, 56.48615516935076, 53.335105419158936, 50.78459194728306, 42.48422874723162, 46.54664591380528, 53.89860085078648, 53.37595387867519, 53.367862701416016, 53.23411335263933, 54.529139450618196, 51.24000120162964, 42.71631942476545, 42.9870594569615, 46.62783561434065, 47.50478860310146, 47.990130696977886, 47.33789982114519, 48.749516691480366, 45.87887191772461, 48.93718753542219, 51.634714467184885, 50.32616717474801, 48.84220566068377, 54.98665400913784, 51.6395434652056, 49.459848403930664, 23.907811607633317, 2.2085487587111334, 0.351256327437503, 2.5830138879162923, 5.706287997109549, 3.9482109291212897, 6.5571266157286505, 14.493109345436096, 1.6557766773871012, 0.14021125489047595, 0.14091033594948904, 6.558501056262425, 37.32159212657383, 46.17571285792759, 38.389926297324045, 30.684384482247488, 50.291975089481895, 15.567864520209175, 0.2537949228925364, 0.14064990063863142, 0.18230212559657438, 0.07620415091514587, 0.11795788471187864, 0.0906698050509606, 0.1826411352625915, 0.19810455478727818, 0.08185885820005621, 0.09284318664244243, 0.10384818326149668, 0.113605191132852, 0.19965023041835853, 0.10490789889757123, 0.24088975680725916, 0.12380290749881949, 0.18014346142964704, 0.10810987172382218, 0.1497754638216325, 0.12583349139562675, 0.09437768001641546, 0.19399640522897243, 0.0982968100745763, 0.09198641404509544, 0.1659747138619423, 0.10229754753943], [0.0452708963171712, 0.022859546222857068, 0.02340373470048819, 0.042169529878135235, 0.06094376263873918, 0.03871270269155502, 0.027833257103338838, 0.01758825872093439, 0.08781116415879556, 0.07606946849929434, 0.07089622252221618, 0.05988020649445908, 0.025834891745554547, 0.08395055774599314, 0.03600671182253531, 0.049088059525404654, 0.07421497801052672, 0.03391811318163361, 0.033974899777344296, 0.003957212411998106, 0.053133356384932995, 0.029452334956399033, 0.022836177476814816, 0.04597500871334757, 0.04296618766550507, 0.02472604169244213, 0.026405997707375457, 0.048678909694509845, 0.03538205926971776, 0.0229656334766852, 0.07283724658191204, 0.03583391270201121, 0.044387969587530406, 0.04463991642530475, 0.94845983173166, 27.16655843598502, 43.4287668636867, 29.301470620291575, 35.25265482493809, 45.57129601069859, 35.92251328059605, 5.188979412828173, 0.10011072416922875, 0.13096575385757855, 0.39524103009275025, 2.8891096115112305, 5.598122349807194, 5.058738470077515, 1.3392789576734816, 0.061651440736438544, 0.10742973536252975, 1.0674969128199985, 28.188636711665563, 58.44514070238386, 59.620331219264436, 58.73649256569998, 60.33091654096331, 58.867111751011436, 59.0748906816755, 57.78649663925171, 54.62179715292794, 44.882336957114084, 51.749081815992085, 57.0703319140843, 56.277980191367014, 52.584939684186665, 52.83557162966047, 53.96784659794399, 52.830169405256, 49.320321628025596, 46.50811815261841, 41.03611298969814, 39.52866309029715, 41.78615018299648, 43.42452498844692, 43.279752322605674, 42.351215907505576, 41.17045293535505, 38.835483006068635, 38.56583731515067, 42.00532415934971, 49.17627852303641, 54.33478096553257, 53.8737610408238, 54.84154782976423, 51.357477869306294, 57.85038879939488, 49.244183267865864, 48.925907135009766, 44.57694278444563, 38.945434774671284, 60.85091972351074, 52.435515199388774, 53.45742845535278, 49.43111065455845, 46.37472663606916, 44.2219488961356, 40.71364361899239, 39.468196392059326, 40.21922022955758, 39.29388345990862, 38.42713737487793, 40.82766008377075, 51.85973187855312, 52.10260616030012, 54.21381630216326, 53.94453191757202, 54.73545578547886, 47.22013480322701, 41.283562660217285, 44.45679106031145, 51.00352968488421, 52.298930985586985, 54.06730311257498, 51.511505535670686, 53.245880126953125, 50.463060583387104, 46.51709522519793, 41.04637547901699, 42.32861341748919, 43.51429918834141, 44.697678157261436, 44.27786799839565, 44.20676360811506, 46.454050745282856, 47.281786169324604, 46.09581899642944, 49.41487966264997, 48.74224887575422, 49.569518770490376, 47.40864985329764, 21.4982545035226, 1.3383222775799888, 0.04686686496383377, 0.4636841246059963, 0.9702313606228147, 1.4580355052437102, 2.787592955998012, 6.159425624779292, 0.41772056956376347, 0.09567555465868541, 0.055925802793353796, 3.76669488634382, 30.91589151109968, 35.182693413325715, 30.65508392878941, 19.691813196454728, 33.751065731048584, 19.22122039113726, 0.13324654075716222, 0.03979335791830506, 0.050560388913644214, 0.05878365319222212, 0.02399775818256395, 0.02457143409576799, 0.03781351147751723, 0.03436255022617323, 0.08338475453534297, 0.04081333515101245, 0.04872705514675804, 0.04523502556341035, 0.06298080618892397, 0.07437623185770852, 0.03123860214171665, 0.015371939433472497, 0.02380050465996776, 0.047967408051980395, 0.028275371861777136, 0.03151670650445989, 0.0417391079744058, 0.023526203486004045, 0.03561105466048632, 0.06465447388057198, 0.03320765309035778, 0.049858352834624906, 0.019015865866094828, 0.054466718408678255, 0.07416682916560344, 0.0075604407382862905, 0.0889725446967142, 0.07783477234521083, 0.06397490070334502, 0.016131725627928972, 0.045928413713616986, 0.08957582339644432, 0.04307384403156383, 0.04137644457763859, 0.015570673858746886, 0.018151018702025925, 0.006217248862542744, 0.020839528812627708, 0.030641789880714247, 0.0905183899615492, 0.015411465794646313, 0.0871669901534915, 0.06169610869671617, 0.021613245331017033, 0.015084308439067431, 0.02249619411304593, 0.10926317090966872, 0.015542646969801613, 0.02129926173282521, 0.04259754637522357, 0.03777768822120769, 0.012061453590701734, 0.08080978199307408, 0.03507326816075614, 0.032896381935903, 0.03785591313083257, 0.03763553513480084, 1.826219571488244, 37.50348206928798, 45.32245322636196, 33.73820114135742, 41.58123391015189, 59.40696593693325, 34.409657682691304, 4.10388879265104, 0.07313747797161341, 0.1332736143044063, 0.38231273953403744, 0.7919294025216783, 3.6535221934318542, 5.989006289413997, 3.291793329375131, 0.4358416886201927, 0.08176511858722993, 2.0994472759110585, 38.806696619306294, 60.238387380327495, 61.45717784336635, 60.95913096836635, 62.80921391078404, 59.96235629490444, 60.55561433519636, 60.39600031716483, 55.69305998938424, 46.70506484167916, 53.65583426611764, 57.84042855671474, 58.483140400477815, 53.687055996486116, 53.87717955453055, 54.61204188210623, 54.98827641350882, 53.038351331438335, 48.89428588322231, 42.44651045118059, 42.13237197058541, 43.145106656210764, 44.420236587524414, 43.49668550491333, 43.73692294529506, 42.66927317210606, 41.88211522783552, 39.81162847791399, 45.192928382328574, 51.804236616407124, 56.638008049556184, 56.46750620433262, 56.0963716506958, 55.32983248574393, 57.04403298241751, 50.896982533591135, 51.84509202412197, 47.3650255884443, 41.90350178309849, 61.37245845794678, 55.03354740142822, 55.783775670187815, 51.301687308720176, 48.32203572137015, 45.126010281699045, 41.591367857796804, 42.29695047651018, 41.34217071533203, 40.634232657296316, 40.02840185165405, 43.52763625553676, 52.91575384140015, 53.46889645712716, 56.0789281981332, 55.48582649230957, 55.67005450384957, 49.2988030569894, 40.95584045137678, 46.457399777003694, 53.1351432119097, 54.30592162268502, 54.837253843035015, 52.32838787351336, 54.65892137799944, 51.7986398424421, 47.455039501190186, 43.58268683297293, 43.567623138427734, 44.710438523973735, 45.540671825408936, 45.49097830908639, 45.87304237910679, 47.968563488551546, 50.55170917510986, 48.791859013693674, 49.584495612553184, 51.21368489946638, 51.493693828582764, 50.04066569464547, 25.933772563934326, 2.6908388563564847, 0.3221275247633457, 1.9755291938781738, 4.44162335566112, 5.156258608613696, 4.76758028779711, 2.28629714676312, 0.08982746489346027, 0.05278615340856569, 0.04320612782612443, 3.0690243116446903, 33.32591240746634, 41.13331481388637, 34.881044319697786, 21.26165097100394, 33.93556472233364, 29.37055308478219, 0.19468373406146253, 0.04707244750378387, 0.05933919695339032, 0.11587216305945601, 0.06465524062514305, 0.03239110404891627, 0.04360543889924884, 0.028427316208503077, 0.06137054759476866, 0.025634349024455463, 0.034997065285486836, 0.040083821796412976, 0.05525391063253794, 0.04430282022804022, 0.0706709013985736, 0.040627538692206144, 0.04065252235159278, 0.03252271270113332, 0.03615884276639138, 0.021607834014243314, 0.11368730065545865, 0.07118552271276712, 0.05971612315624952, 0.08422921850745167, 0.041938169792826684, 0.07514680336628642, 0.024221813838396753, 0.09900534312639918, 0.09606786325041737, 0.15885390953293868, 0.14478435021425995, 0.12995396314987115, 0.19544308260083199, 0.05917589393045221, 0.1702674656574215, 0.2377866261771747, 0.1256553488118308, 0.11669766876314368, 0.1902623591678483, 0.08147846468325172, 0.1499700676649809, 0.09582338708319835, 0.06371189374476671, 0.15191438261951717, 0.09557888377457857, 0.23809972937617982, 0.08451214046882731, 0.11219227087817021, 0.09171029100460665, 0.04379177479339497, 0.17652636766433716, 0.19903873465955257, 0.1208731968488012, 0.13195840987776006, 0.1299250168459756, 0.08865414892456361, 0.17201708177370684, 0.15826054422983102, 0.0969325950635331, 0.20535136306924479, 0.20829336877380097, 1.6316819531576974, 40.85341705594744, 57.01837675912039, 40.30730949129377, 45.92434440340315, 56.85918310710362, 45.84863335745675, 8.526353359222412, 0.2740214004048279, 0.25953828756298336, 1.2378643538270677, 9.457537037985665, 18.904095922197612, 9.578431350844246, 4.605349838733673, 0.3867244656596865, 0.20741647082780088, 1.7134434687239783, 33.12961190087454, 61.231806073869976, 60.00000858306885, 61.37140927995954, 65.23507322583879, 63.36413179125105, 64.7510825565883, 62.89796325138637, 59.539030347551616, 48.41975171225411, 56.125960554395405, 60.330235617501394, 61.30412292480469, 54.57536234174456, 53.65246786390032, 56.597896099090576, 58.293808937072754, 54.47127137865339, 50.7532833644322, 45.72828013556344, 43.959320885794504, 47.249678543635774, 48.75798307146345, 47.59051547731672, 46.49008757727486, 46.3877614566258, 43.820547989436555, 42.07387856074742, 45.71213252203805, 53.424921308244976, 59.44536863054548, 58.427040645054404, 58.9573757989066, 57.37365552357265, 60.173456464494976, 53.36594499860491, 52.86632088252476, 50.108337674822124, 44.89471517290388, 64.30143683297294, 57.234559535980225, 57.89680971418108, 53.56258249282837, 50.364469119480674, 46.725169454302105, 43.88180330821446, 43.672652108328684, 43.37323338644845, 43.221641063690186, 40.89465808868408, 45.00053971154349, 53.84378998620169, 54.45098958696638, 56.81575686591012, 56.60298218045916, 58.28136471339634, 51.343209743499756, 44.88159697396414, 47.98384952545166, 54.566277572086875, 56.40570892606463, 57.46420444761004, 53.06816257749285, 57.76909834997994, 54.686735016959055, 51.587362493787495, 46.45120198386056, 46.43995632444109, 47.36937863486153, 48.32178906032017, 47.97646011625017, 48.62109661102295, 51.95916060038975, 52.28309951509748, 50.265804699489046, 52.69852883475167, 54.204439708164756, 52.55414874213082, 49.70258372170584, 24.60456654003688, 2.0868779846600125, 0.20948545980666364, 2.8391501094613756, 3.6548901200294495, 3.0226040482521057, 6.898317039012909, 14.970930882862636, 2.2385408750602176, 0.33233125294957844, 0.23385967261024884, 6.300414562225342, 41.0412129674639, 45.61991603033883, 41.486338887895855, 27.441140822001866, 44.07140227726528, 30.8649959564209, 0.20606124640575477, 0.19088509146656307, 0.1325495902981077, 0.22796051629952022, 0.1506270659821374, 0.1486963081572737, 0.12636227373565945, 0.13195611642939703, 0.2195324735449893, 0.11996784114411899, 0.17252522307847226, 0.1199362078415496, 0.18772427178919315, 0.14052441237228258, 0.14686530855085167, 0.09602852857538632, 0.13409798006926263, 0.10973072224961859, 0.08308980893343687, 0.13052561533238205, 0.15360333770513535, 0.12586084992757865, 0.13202398350196226, 0.20299900429589407, 0.11817805575472967, 0.22463812386350973, 0.14113962650299072], [0.07442161906510592, 0.040204506034829786, 0.06782226889793362, 0.05710199914340462, 0.03712876107809799, 0.0645057593605348, 0.05844127120716231, 0.034472683245050054, 0.03794615150296262, 0.02638249664700457, 0.008790951272073601, 0.01244497939478606, 0.03093378385528922, 0.02852073690987059, 0.05278964447123664, 0.008855044841766357, 0.027591958176344633, 0.031791404621409516, 0.042885883046048026, 0.02565634373708495, 0.013170396942379219, 0.051705179270356894, 0.07360827270895243, 0.0841406968289188, 0.024209372898829833, 0.05307042904730354, 0.022444854457197443, 0.023749794345349073, 0.08332902645426137, 0.04239618432308946, 0.018742480714406286, 0.015378292217584593, 0.03609984075384481, 0.008908219934840287, 0.035794995326016626, 2.982984117099217, 26.515920434679302, 44.82556322642735, 28.727707488196238, 30.75743784223284, 47.080003534044536, 36.82634884970528, 5.183500323976789, 0.5140885284968785, 0.04517438488879374, 0.2923214355749743, 3.4770153675760542, 3.3541664396013533, 0.343322543161256, 0.6557898191469056, 0.37546789539711817, 0.07779934603188719, 1.159286958830697, 19.954581907817296, 56.02786936078753, 59.134513173784526, 59.24257850646973, 57.394111020224436, 59.51494094303676, 57.21388169697353, 53.03032268796648, 48.763096945626394, 55.80819164003645, 54.98328413282122, 55.47245121002197, 52.16023799351284, 56.53886072976248, 55.149332182747976, 52.36713102885655, 48.7408036504473, 40.575468267713276, 40.45336757387434, 42.73196676799229, 47.907276902879985, 50.151465143476216, 49.50516108104161, 48.34224803107125, 45.53051355906895, 43.051552636282786, 40.673549039023264, 39.56911550249372, 44.77667917524065, 49.79295546667916, 53.255381788526265, 54.27411624363491, 54.00574554715838, 52.714485372815815, 55.120674337659565, 51.130587918417795, 38.81293262754168, 34.24939053399222, 59.98991979871477, 52.93133865083967, 53.30432142530169, 49.7629531451634, 47.82290840148926, 42.51816374914986, 41.049297196524485, 38.56024054118565, 38.326847076416016, 39.0697797366551, 42.39606652941023, 47.57367999213082, 54.416505677359446, 55.1108843258449, 55.065578596932546, 54.35464586530413, 52.727141516549246, 48.44425106048584, 40.865180356161936, 47.815668378557476, 51.26379530770438, 52.961115155901226, 52.5062826020377, 53.042058195386616, 53.66705560684204, 53.395353249141145, 49.36700657435826, 44.95704051426479, 42.098694052015034, 44.69527060644967, 46.65900870731899, 47.00084965569632, 45.40983029774257, 47.41757481438773, 49.08809546061924, 50.54194695608956, 49.87036534718105, 51.586976868765696, 48.68364429473877, 19.86547647203718, 1.026158713868686, 0.1782881702695574, 0.9811723849603108, 0.7944300483380045, 3.0921566018036435, 3.9658819351877486, 7.360701850482395, 1.6991118320396967, 0.04217698697799018, 0.1193295568227768, 3.1070698244231085, 32.98513453347342, 32.53890037536621, 38.65464571544102, 30.728255408150808, 28.572962420327322, 26.35454331125532, 0.4355581695480006, 0.11161717173776456, 0.06032211599605424, 0.013934988012936498, 0.056058324075170925, 0.12693225672202452, 0.044946780494813404, 0.01866948900611273, 0.030541169922798872, 0.023188581424100057, 0.06011030450463295, 0.051644586093191586, 0.03196337592921086, 0.03588270615520222, 0.0046368856731403086, 0.0619960076042584, 0.027656189997547438, 0.02908283192664385, 0.09343260965709176, 0.03521681224395122, 0.053428936417081525, 0.03383907742266144, 0.03554966081199901, 0.06441993146602597, 0.06499058620205947, 0.056535595429262946, 0.02881635765412024, 0.050391759390809705, 0.05736717741404261, 0.03333791485056281, 0.0878550653745021, 0.04486697459859507, 0.04642945075673716, 0.03408612523760114, 0.033961067840989144, 0.04546179196664265, 0.010841613868251443, 0.011749543765160655, 0.025911510223522782, 0.03285892680287361, 0.07169237480099712, 0.020283991836809685, 0.04517470380025251, 0.016688787611201406, 0.003715638254236962, 0.009061339843486036, 0.07798297796398401, 0.05259744603452938, 0.046355992555618286, 0.025955190915348272, 0.02730159438215196, 0.01627459965779313, 0.07243866154125758, 0.04519547714984842, 0.11683858691581658, 0.01476526296963649, 0.052711595980716605, 0.015541946382394858, 0.037789409913654835, 0.02892827522009611, 0.0652524328657559, 0.06726523235972438, 0.054606391449591944, 6.17755651473999, 39.31746564592634, 45.44897992270333, 30.9717515536717, 35.51691566194807, 58.47799178532192, 38.17576544625418, 4.938471666404179, 0.4810680832181658, 0.044399867699082406, 0.1933644177126033, 0.29581355676054955, 2.6281276728425707, 4.626235255173274, 3.7550219127110074, 0.517351793391364, 0.07611474714108876, 1.8965040743350983, 28.54040837287903, 60.15357766832624, 59.36352579934256, 59.351130213056294, 60.37124388558524, 61.318526540483745, 59.89735589708601, 55.528123651232036, 49.62958942140852, 56.95585339409964, 57.287028857639854, 55.89272689819336, 53.201564516339985, 56.234401089804514, 58.29783194405692, 55.16637263979231, 50.114257540021626, 43.3270765032087, 42.00227042606899, 43.31261382784162, 48.27748734610421, 51.47023671013968, 51.70488779885428, 50.17919887815203, 47.63371590205601, 44.011088439396445, 42.909333433423726, 41.28981256484985, 47.33808742250715, 52.54204150608608, 55.1565374646868, 55.87253543308803, 55.252815178462434, 55.01746579578945, 55.29376786095755, 53.30589519228254, 41.55485160010201, 35.1651040485927, 61.04244681767055, 54.471934931618826, 56.12048537390572, 50.141755035945344, 49.747236319950645, 45.37302221570696, 41.736348969595774, 39.71465594427926, 39.12745673315865, 40.442809786115376, 43.426508699144634, 49.23130478177752, 55.29708562578474, 56.24122074672154, 56.73680795942034, 55.69544669560024, 56.52785478319441, 49.565068449292866, 43.300471850803916, 48.790632656642366, 52.51803895405361, 53.19201421737671, 53.691214493342805, 52.73994009835379, 54.06419726780483, 53.78532089505877, 50.155759130205425, 46.21946219035557, 44.326477595738, 47.13942452839443, 47.574868134089876, 48.053088324410574, 47.101303236825125, 49.28165142876761, 50.659371512276785, 52.15661450794765, 52.70861414500645, 49.655044146946494, 52.12983962467739, 25.116845062800817, 2.508124900715692, 0.47376172670296257, 1.9793654680252075, 3.6380424754960194, 6.294620198862893, 7.145891777106693, 0.3952650230910097, 0.06021830692355122, 0.06597325418676649, 0.0852851207767214, 2.677509823015758, 31.3857148034232, 45.8302275793893, 40.25244304112026, 34.18333053588867, 28.23039538519723, 34.75339548928397, 2.313086360692978, 0.22217907224382671, 0.04712559375911951, 0.0368400376423129, 0.04812448551612241, 0.07065991591662169, 0.05741616085703884, 0.02873859414830804, 0.0051027809635603005, 0.03899768739938736, 0.031095485535583327, 0.026774584714855467, 0.05345970119482704, 0.05686818615400365, 0.025301166277910982, 0.05148612781028662, 0.03726065132234778, 0.039665033375578265, 0.1060400345761861, 0.040190063416957855, 0.024047426945929016, 0.02855379174330405, 0.026762169220351746, 0.050745486481381316, 0.013860949664376676, 0.1066686362028122, 0.026758830828059996, 0.08905491206262793, 0.11573809811047145, 0.1659935364233596, 0.1892783883959055, 0.14954124710389546, 0.08470643897141729, 0.11906183404581887, 0.1480857352060931, 0.12264639884233475, 0.09333513131631271, 0.14254925586283207, 0.13672659759010586, 0.06830212207777159, 0.13190566056541034, 0.13135140602077755, 0.14156851491757802, 0.11590135363595826, 0.0998342347198299, 0.08286002983472177, 0.16118691648755754, 0.09052130087677922, 0.16608131171337195, 0.10529008374682494, 0.16333195567131042, 0.17126187229795115, 0.12157374354345457, 0.18246520470295632, 0.15644262677856854, 0.15001079333680017, 0.22293692800615514, 0.11275314113923482, 0.11389934963413648, 0.08716165686824492, 0.12954757495650224, 0.12690814158746175, 0.32569439336657524, 4.502322818551745, 41.437333243233816, 59.2479008265904, 40.83089099611555, 41.69545882088797, 58.07964808600289, 48.743298053741455, 8.36751059123448, 0.9295671369348253, 0.2568819315305778, 0.7428878226450512, 6.413801346506391, 10.67847102028983, 6.644242261137281, 3.502819891486849, 0.535550482571125, 0.15950727090239525, 1.6940959926162447, 23.948194537843975, 62.12068911961147, 61.35909012385777, 60.45966666085379, 62.53986699240548, 64.86119065965924, 61.5638187953404, 57.010438442230225, 53.422142028808594, 61.0560861315046, 58.27810253415789, 57.88499430247715, 53.49475417818342, 59.44877324785505, 61.339072363717214, 57.439729418073384, 52.0759528705052, 44.99693707057408, 45.06764193943569, 47.271544524601524, 50.325256960732595, 53.77516957691738, 54.46061979021345, 51.78401041030884, 50.947502885546, 48.15848554883684, 46.094516209193635, 42.517368180411204, 48.065275464739116, 54.56159796033587, 58.01833718163626, 58.23342561721802, 56.28739152635847, 56.680395535060335, 57.01044539042881, 52.68103674479893, 43.69318403516497, 38.767685958317344, 62.894767080034526, 57.51549257550921, 56.937565735408235, 53.3893152645656, 50.27670642307827, 45.3663067817688, 43.65897805350167, 42.895826135362896, 40.69781909670149, 41.383231094905305, 46.81050722939627, 52.21262741088867, 58.41112232208252, 59.60393347058977, 58.40684917994908, 57.86012669972011, 58.019351618630544, 52.1123058455331, 44.84372929164341, 51.33853013174874, 54.2733519417899, 55.515853132520405, 54.71922131947109, 53.67158235822405, 56.55109303338187, 58.77952970777239, 53.21170541218349, 48.283719880240305, 46.7862788609096, 49.995085511888774, 50.407905782972065, 50.872302532196045, 48.22908966881888, 49.503736700330464, 53.904155935559956, 55.23630625861031, 54.24564599990845, 52.56977871486119, 52.294633524758474, 22.879898582186016, 1.7436003876583916, 0.495054047022547, 2.410163768700191, 3.8624024135725836, 8.794592908450536, 9.980480177061898, 15.913528714861188, 3.4879685512610843, 0.4357067958584854, 0.18330208265355655, 5.47741129568645, 44.96160200663975, 43.16776473181588, 48.21533918380737, 39.817520550319124, 38.76263461794172, 40.2146761076791, 2.187624041523252, 0.1937147724841322, 0.10583642657314028, 0.2231060325035027, 0.18049178059612, 0.24914226255246572, 0.1431180853396654, 0.09195127950182982, 0.10824910032429866, 0.10021867909069572, 0.1835209916212729, 0.16517744878573076, 0.06753005779215268, 0.14102893030004843, 0.1409128193876573, 0.21187086323542254, 0.12093041092157364, 0.16650592535734177, 0.17138677702418395, 0.14753065284873756, 0.10192169342190027, 0.10455792410565273, 0.10779801024390118, 0.15873078256845474, 0.09575313835271768, 0.21257324197462626, 0.12626981655401842, 0.19393737268235], [0.008720691515398877, 0.042804764184568606, 0.02963967847504786, 0.021464663125308495, 0.013718116346613636, 0.04102630015196545, 0.05886596627533436, 0.04586769161479814, 0.030559731248234, 0.042255361165319166, 0.05446131726992982, 0.11027209819959742, 0.06972479288067136, 0.019636481135551418, 0.011875687665971262, 0.04785192139180643, 0.05658033124304243, 0.04841835903269904, 0.08879662092242922, 0.006171531717492533, 0.03203150763043335, 0.009444969124160707, 0.0959657776568617, 0.03880134989906635, 0.0708872794306704, 0.036110086632626395, 0.017478834771152054, 0.03444716015032359, 0.022096883039921522, 0.028332307735191922, 0.0390765365612294, 0.07534259464591742, 0.0035514783687956098, 0.05595188907214573, 0.038572975367839844, 0.049161938418235095, 0.4228323809802532, 21.910491125924246, 47.016736711774556, 31.278177533830913, 37.52548006602696, 47.60333490371704, 43.7671719278608, 10.861623798097883, 0.22793902031012944, 0.07370891302291836, 0.4551178371267659, 1.9357587907995497, 4.779881639139993, 2.2180208904402594, 0.7949239132659776, 0.02932326402515173, 0.09936295822262764, 1.1571184694766998, 19.511469227927073, 49.42103924070086, 59.478435107639854, 60.04526220049177, 61.331304277692524, 57.805965491703574, 53.102330344063894, 50.86994014467512, 56.7340738432748, 57.73549338749477, 55.02350378036499, 55.03567702429635, 57.293077264513286, 52.511997495378765, 52.91529526029314, 42.66705322265625, 45.255212034497944, 47.40444271905081, 52.40485279900687, 55.11161388669695, 55.526383127485005, 52.50068582807268, 50.490321840558735, 48.39879594530378, 45.48554481778826, 41.86584602083479, 39.36771501813616, 40.64739254542759, 49.62602499553135, 52.44299146107265, 53.0702018737793, 53.794621058872764, 55.40399408340454, 52.09625550678798, 54.13871322359358, 42.879292896815706, 39.02700662612915, 59.97726018088204, 54.78645208903721, 58.374296869550435, 53.63289826256888, 48.70309925079346, 44.36362613950457, 43.50158745901925, 40.48464488983154, 42.907318455832346, 42.54174246106829, 44.061382974897114, 48.555262429373606, 53.53401150022234, 55.22484867913382, 56.610732895987375, 55.256160736083984, 52.69757693154471, 48.48906346729824, 44.99556827545166, 45.50312723432268, 52.19491992677961, 53.51790904998779, 55.856036935533794, 52.09132923398699, 54.14658553259713, 53.68378686904907, 50.47075571332659, 48.63698366710118, 46.04616716929844, 44.121776717049734, 47.312330450330464, 47.85029125213623, 47.848064354487825, 49.34690890993391, 50.96209757668631, 46.50965370450701, 50.83699526105608, 47.72223595210484, 14.352522100721087, 0.6975832879543304, 0.34925801466618267, 0.6057124148522104, 1.9886052693639482, 3.0461260889257704, 7.571417263575962, 13.531988484518868, 1.2680119361196245, 0.016258085811776773, 0.05501623338620577, 3.714044911520822, 35.31216614586966, 38.71435506003243, 24.712836844580515, 47.36910418101719, 31.522135734558105, 29.54387937273298, 3.079105713537761, 0.15190742085022585, 0.010435306250915995, 0.006141763113971267, 0.06647395196237735, 0.0607279749321086, 0.024179876981569186, 0.03929420380986162, 0.06504685711115599, 0.08576774916478566, 0.049572329968214035, 0.049772199243307114, 0.03248635679483414, 0.047233976157648225, 0.0372661101365728, 0.12915846226470812, 0.06651034179542746, 0.09978445060551167, 0.05440766550600529, 0.02678072715311178, 0.030258990957268646, 0.08983024688703672, 0.03995013343436377, 0.009267846887399043, 0.08718195863600288, 0.01520881791865187, 0.0369842229411006, 0.027117848795439516, 0.0998032120987773, 0.05491346247228129, 0.004060921824670264, 0.06391771377197333, 0.056095185490059, 0.03582590938146625, 0.04801798265959535, 0.047003949393651316, 0.034749125196997604, 0.03579455427825451, 0.0415094272632684, 0.03249077745048063, 0.057797741810125966, 0.02471987550546016, 0.07363975673381772, 0.008427432921182896, 0.005920911415679646, 0.05799915814506156, 0.02440757297777704, 0.024847775963800292, 0.049308325563158305, 0.025681951648688743, 0.04478747404313513, 0.012981301107044731, 0.028337026946246624, 0.025170904517705952, 0.06576453681503024, 0.05637595649542553, 0.0846789243764111, 0.045060862587498765, 0.05934244713612965, 0.05997366112257753, 0.018464488309941123, 0.042478521154927354, 0.008773970933231925, 0.022622516977467706, 0.03130845392921141, 2.836021248783384, 34.35659776415144, 48.035929747990195, 30.942065375191824, 40.91340780258179, 57.60968582970755, 40.925066879817415, 8.172921078545706, 0.26839753932186533, 0.056673528027853796, 0.10872421054435627, 0.2501563738499369, 1.7731215464217323, 3.7335102898733954, 2.8064138889312744, 0.18304717061775072, 0.14903531782329082, 2.4377748242446353, 27.266410997935704, 55.635542801448274, 59.60259246826172, 58.904722349984304, 63.59379059927804, 60.971318108694895, 55.346407413482666, 52.48912749971662, 59.929567745753694, 59.23208672659737, 56.213737147195, 54.33525344303676, 58.27058458328247, 55.604647636413574, 55.34883580889021, 44.85879993438721, 45.9781026159014, 48.25238003049578, 54.04834842681885, 56.40615708487374, 57.00397661754063, 55.13294833047049, 53.430493763514924, 50.430129596165244, 46.808426243918284, 44.24953324454171, 42.13688135147095, 42.33015939167568, 51.93595709119524, 53.241523606436594, 55.13410867963518, 55.96501248223441, 57.4314923286438, 52.68301003319876, 54.9038210596357, 44.37347521100725, 40.086464473179404, 60.90875652858189, 56.07322720118931, 58.54514612470354, 56.047762053353445, 50.50537511280605, 45.894140584128245, 44.981466906411306, 40.66121251242501, 43.156803948538645, 42.86282219205584, 46.21359096254621, 50.25510099955967, 53.91533211299351, 55.4114807673863, 56.325453758239746, 56.27184840611049, 55.412613323756624, 49.95323303767613, 46.1504214150565, 48.09897770200457, 54.38595444815499, 53.557878562382285, 56.69867624555315, 52.84562914712088, 54.251833370753694, 54.5100770677839, 51.785139492579866, 50.83417429242815, 46.956537519182476, 46.385103770664756, 48.3083929334368, 49.94466938291277, 51.21369879586356, 50.76147876467024, 51.85213054929461, 50.043260846819194, 50.617470400674, 50.854132992880686, 19.566101176398142, 1.6905580567462104, 1.2404504950557436, 1.6976777889898844, 2.2551019064017703, 4.228997622217451, 4.311383281435285, 1.394765317440033, 0.2994630980704512, 0.0318336875310966, 0.08217707755310194, 3.2740730345249176, 36.070287568228586, 51.73665148871285, 26.47915404183524, 49.58801487513951, 36.72123302732195, 36.02925498144967, 6.53336203949792, 0.18471771026296274, 0.040149619337171316, 0.016960827567215477, 0.05868536739477089, 0.05050670661564384, 0.01974182708987168, 0.04597079161820667, 0.0524818677721279, 0.026511557400226593, 0.014758772782183118, 0.01764554064720869, 0.08493891185415642, 0.03124301940468805, 0.038819914617176564, 0.021919274802452753, 0.032580283004790545, 0.03615839832595416, 0.06910007925970213, 0.0033904846973850256, 0.023711533451985036, 0.13379855613623345, 0.04654415710163968, 0.03861953304814441, 0.07157855055161885, 0.025736326052408134, 0.049496619030833244, 0.007021540168872369, 0.03319818074149745, 0.14244231874389307, 0.12190253447209086, 0.14730676343398436, 0.1346492219184126, 0.10358403636408703, 0.19671643498752797, 0.173533132565873, 0.11939253844320774, 0.0976067263899105, 0.1209582444280386, 0.14316364218081745, 0.17311983688601426, 0.10413344616868667, 0.10884269632931266, 0.08522981338735137, 0.21476416369634016, 0.1531325972505978, 0.13771392032504082, 0.21288524594690117, 0.11076195977096047, 0.17062505361224922, 0.09357352102441446, 0.12783590251845972, 0.09385028188782078, 0.1278572492301464, 0.11447349882551602, 0.3062430199767862, 0.14581541131649697, 0.140993402206472, 0.1450527650969369, 0.23484886810183525, 0.17944047200892652, 0.09793445880391768, 0.07637307220803839, 0.11728456084217344, 0.11011919711849519, 2.321375127349581, 37.28485700062343, 59.79619707380022, 41.65366193226406, 46.95389025551932, 58.98591899871826, 51.67677191325596, 14.99670696258545, 0.6017860312547002, 0.2644791081547737, 1.5409509646041053, 7.326052921158927, 14.15827304976327, 8.11019708429064, 4.31486519745418, 0.086302339764578, 0.14609932393899985, 1.8893035692828042, 24.015623331069946, 54.79926109313965, 62.47822257450649, 62.988769258771626, 66.32314722878593, 63.43327331542969, 59.51609434400286, 55.51277160644531, 61.35032149723598, 63.1306653703962, 57.35234539849417, 56.644852025168284, 61.20657021658761, 56.55338246481759, 58.61745602743966, 45.99743250438145, 49.45882701873779, 52.25071396146502, 58.66498865400042, 60.12704249790737, 62.77649484361921, 59.265257426670615, 56.80413600376674, 54.13492298126221, 50.11462232044765, 46.90826838357108, 44.69199105671474, 43.47677891595023, 55.22088473183768, 55.45557403564453, 57.000783920288086, 58.415610858372276, 59.91404547010149, 55.80532203401838, 56.673058237348286, 48.02329444885254, 43.48693370819092, 62.42672947474888, 59.41227436065674, 64.23057215554374, 58.74330874851772, 54.102797985076904, 49.63246250152588, 47.83567919049944, 43.39630487986973, 45.70693874359131, 45.24838890348162, 48.295278208596365, 53.370461327689036, 56.94460078648159, 57.45926775251116, 56.419369084494456, 58.59196308680943, 57.89859192711966, 52.46337052753994, 47.80844920022147, 49.94629178728376, 56.826603003910606, 56.38480527060372, 59.58629894256592, 54.23618255342756, 55.929382119859966, 57.51396744591849, 54.68652309690203, 53.21598202841622, 50.06104128701346, 48.27507284709385, 50.044883251190186, 52.898258277348106, 52.658375195094514, 54.18326159885952, 54.02869892120361, 51.27908134460449, 52.747068950108115, 50.07355499267578, 17.949215412139893, 1.7073690061058318, 1.5093389408929008, 1.4817847737244196, 4.6495026009423395, 11.1170699766704, 15.691969769341604, 21.813678400857107, 3.9675785984311784, 0.14364519848355226, 0.4001655929854938, 5.868584019797189, 46.76263066700527, 48.36840452466692, 33.14135435649327, 53.383819239480154, 42.913637842450825, 43.563103335244314, 5.9698700819696695, 0.3210417058851038, 0.0711618893380676, 0.17641803276325974, 0.09868605168802397, 0.12439119735998766, 0.16527089662849903, 0.1720534919628075, 0.11461326346865722, 0.23826559047613824, 0.1323576598827328, 0.13923504655914648, 0.1179950005773987, 0.1265122164040804, 0.1286049269671951, 0.17035491525062493, 0.1413754988461733, 0.13844907230564527, 0.11655979044735432, 0.12555320215012344, 0.06598683845783983, 0.18522591942123004, 0.10675082036427089, 0.17612409139318125, 0.1590026579797268, 0.19374286383390427, 0.14499776304832526, 0.07348235018019166, 0.12928234918841294], [0.02308932362523462, 0.017279654209102904, 0.024013381451368332, 0.028512431641242335, 0.07964536840362207, 0.06634168513119221, 0.016251249571463892, 0.044487534423491785, 0.05044450191780925, 0.027394618140533566, 0.018552397610619664, 0.02884048975205847, 0.06656928613249745, 0.06415083126298018, 0.06303845452410833, 0.036325976119509766, 0.010351135678190206, 0.01974549117897238, 0.04136714186253292, 0.017765375020514642, 0.09149052708276681, 0.027946319697158675, 0.00883150306929435, 0.02957929903641343, 0.021777927476380552, 0.02060808560677937, 0.0641333996983511, 0.028872377505259852, 0.0056260213688282025, 0.04784719878807664, 0.06907526523407016, 0.052607474782105, 0.027152784867212176, 0.017959698968167816, 0.009802513822380985, 0.040970595819609504, 0.029577701086444513, 0.7299713385956628, 24.816196509769984, 43.86040980475289, 31.918026719774517, 29.4633150100708, 42.60251488004412, 49.33527067729405, 14.539657933371407, 0.600030851151262, 0.017843301374731318, 0.13345673733523913, 0.7737874388694763, 3.9162027495247975, 1.0633453641619002, 0.36987983382173945, 0.1433773807116917, 0.28863465626324925, 1.9372352830001285, 20.48105386325291, 52.00681482042585, 62.53602463858468, 61.204193932669504, 58.546348163059776, 55.99527188709804, 57.32995482853481, 58.22475773947579, 57.754534925733296, 55.837954248700825, 59.734184401375906, 57.118913718632285, 54.248772689274375, 46.956916196005686, 45.48630911963326, 51.264934812273296, 54.50762782778059, 53.99956512451172, 53.99247448784964, 55.98977933611189, 54.37600462777274, 50.609122140066965, 48.33009215763637, 48.15681798117501, 46.140145029340474, 43.832040309906006, 41.67499985013689, 44.449950558798655, 53.04459081377302, 53.60755818230765, 54.71471888678414, 57.660317352839876, 56.645366191864014, 51.74823413576399, 41.931753158569336, 35.36619881221226, 60.90228080749512, 54.56293896266392, 58.132603781563894, 50.77110896791731, 53.89022479738508, 46.38954019546509, 45.13443149839129, 41.928734166281565, 41.15601805278233, 41.76843575068882, 47.12509734289986, 52.85244185583932, 55.939088753291536, 55.44450208118984, 56.710401330675396, 57.125747271946494, 54.663538455963135, 50.83884000778198, 45.52144615990775, 46.837754590170725, 51.39431721823556, 53.389787742069785, 54.964784554072786, 56.19089494432722, 54.65477677753994, 53.39920949935913, 54.02743434906006, 52.077151434762136, 50.34738349914551, 49.17892926079886, 49.962696484157014, 48.642959117889404, 51.32299395969936, 49.35449634279524, 51.2066706929888, 51.62717914581299, 37.67983429772513, 10.658178806304932, 0.5697149378912789, 0.26019133680633133, 1.337725492460387, 2.594580032995769, 0.872908105807645, 3.6590890032904486, 3.8300859076636176, 2.3269163157258714, 0.10369910233254943, 0.05757126039160149, 5.51026976108551, 34.755445207868306, 42.08677094323294, 21.700315066746303, 24.581231015069143, 31.312199388231548, 25.02993699482509, 3.851333498954773, 0.06802191425647054, 0.03536774218082428, 0.06593282028500523, 0.01969775963308556, 0.028613686029400145, 0.04629958254684295, 0.03743925530995641, 0.018851434778688208, 0.014370508259162307, 0.10921310181064264, 0.049410808099699874, 0.09007709114147083, 0.04092332228486027, 0.03346248370196138, 0.026743563790140406, 0.059390779185507975, 0.03488858789205551, 0.020320832895647203, 0.06398341631782906, 0.029777919807072197, 0.015279151466009873, 0.028422266211626784, 0.05384188943675586, 0.07907917842801128, 0.051355648918875625, 0.022486728549535786, 0.03945447038859129, 0.059690664522349834, 0.03629320287810905, 0.010855300767746354, 0.04797998469855104, 0.019764680149299756, 0.05715078581124544, 0.018031569397343055, 0.051968267653137445, 0.03268343050565038, 0.04142810823395848, 0.0572789746469685, 0.0342149654669421, 0.00811728898302785, 0.04331077488937548, 0.023888826170670133, 0.046682357721562893, 0.07974479413990464, 0.020781946634607654, 0.037188597688717503, 0.016085361330104724, 0.05324166075193456, 0.026518142582582574, 0.052471669390797615, 0.04472052299284509, 0.06596454858247723, 0.005637699804667915, 0.011261959526953953, 0.03247165633365512, 0.052380036629204235, 0.05531669208513839, 0.032830329944512675, 0.011853261235436159, 0.05256101209670305, 0.06846524189625468, 0.03642238237495933, 0.026653605313705545, 0.05432048054145915, 0.011591958247923424, 0.05253402336633631, 2.63045705642019, 37.214079175676616, 46.62824903215681, 34.051137583596365, 34.08134487697056, 52.41044609887259, 54.67697279793875, 10.012302926608495, 0.5032348451869828, 0.07980401667633227, 0.1342040350926774, 0.45647455432585304, 0.9562089187758309, 2.56653254372733, 1.5162001784358705, 0.3790952078998089, 0.4299554516162191, 3.5515936400209154, 26.632391350609915, 56.632015228271484, 62.69758415222168, 62.403682300022666, 59.32630429949079, 57.546137605394634, 58.999210902622764, 60.46318244934082, 60.3602101462228, 56.348931721278596, 60.58790956224714, 58.75897693634033, 57.046009744916645, 50.54607418605259, 48.23797294071743, 53.76412888935634, 55.94050965990339, 56.99675743920462, 56.02333913530622, 56.667569160461426, 57.33492973872593, 52.51567309243338, 51.06369066238403, 50.86800159726824, 48.21155936377389, 46.034970147269114, 42.865743909563335, 45.961128166743684, 54.665011474064414, 54.182830810546875, 56.22636202403477, 58.79387078966413, 55.93654571260725, 54.56454747063773, 44.633494172777446, 37.7973769732884, 61.31635870252337, 54.234462874276296, 58.62089538574219, 53.30869879041399, 55.406544072287424, 47.29181241989136, 45.73487745012556, 44.06099040167672, 42.98545789718628, 43.051927839006694, 47.29735708236694, 55.11006791251046, 56.66465439115252, 55.71247673034668, 57.02040910720825, 56.341094153267996, 55.92231232779366, 50.50306831087385, 46.671970571790425, 48.218247004917686, 52.174460956028526, 54.83978646142142, 55.88967316491263, 56.130633217947825, 54.232232502528596, 54.63623203550066, 53.97784505571638, 53.459763050079346, 51.903613226754324, 49.80274200439453, 52.40666627883911, 49.95042596544538, 52.67939002173287, 51.59812525340489, 52.2766307422093, 52.80138301849365, 44.0989727292742, 16.278750351497106, 1.000207734959466, 0.5673188407506261, 3.308350452354976, 3.628976813384465, 1.7062950751611163, 2.4013219688619887, 0.44448090504322735, 0.2835729478725365, 0.05574862372928432, 0.05104290195075529, 3.0550584324768613, 33.624264580862864, 48.59896659851074, 26.442212206976755, 25.30828877857753, 37.877507073538645, 32.700529370989116, 8.751349925994873, 0.0655855799892119, 0.009908325421357793, 0.04654501884111336, 0.032593378730650456, 0.009676214706684862, 0.03926065703853965, 0.00891497390278216, 0.03783113981730171, 0.04206238241334047, 0.04069459491542407, 0.031358919971223385, 0.06235411124570029, 0.09657504103545632, 0.058603413935218535, 0.024016541728217686, 0.022486923628353646, 0.028037178928830793, 0.07394256655658994, 0.1071598209174616, 0.028660484589636326, 0.027483694521444182, 0.030575089888381105, 0.01966120864796851, 0.03822733980736562, 0.02291750838048756, 0.021919603891936795, 0.008414848641093289, 0.0616827890543001, 0.03094992959605796, 0.12952039284365519, 0.10798243606196982, 0.08164038349475179, 0.1411763895303011, 0.11978713369795255, 0.11603852627532822, 0.19279474685234682, 0.18088469308401856, 0.14378870863999638, 0.1750910896807909, 0.1014875735023192, 0.18584413267672062, 0.16217255645564624, 0.1953084748238325, 0.21295483649841376, 0.13416765204497746, 0.13544044803295816, 0.0943200248958809, 0.17577126675418445, 0.12741598433681897, 0.2075595874339342, 0.13930226223809378, 0.15415166185370513, 0.16350359788962773, 0.13269593673092978, 0.12480073395584311, 0.12206650924469743, 0.13084095769694873, 0.12999230037842477, 0.09780031921608107, 0.18239802973611013, 0.11717009198452745, 0.08763476540999753, 0.07174594514071941, 0.2694531226796763, 0.27284764338816914, 0.2485933005809784, 2.976143181324005, 38.31313133239746, 57.972069127219065, 43.3736572265625, 40.683401584625244, 53.18054968970162, 60.90762397221157, 18.646995203835623, 1.1157802705253874, 0.12152218845273767, 0.3844571273241724, 6.136974258082254, 12.242640801838466, 8.42086146559034, 1.9388246834278107, 0.5025716722011566, 0.8182054811290332, 3.0908390496458327, 24.099977936063492, 55.03169918060303, 64.7469344820295, 65.85754149300712, 60.076702799115864, 60.82664271763393, 62.758068220955984, 62.9258394241333, 61.594613211495535, 57.66759559086391, 63.01763902391706, 62.294185638427734, 60.460674149649485, 52.01367964063372, 52.920964990343364, 56.667200905936106, 58.599376814705984, 59.73091179983956, 59.55000850132534, 58.29404517582485, 59.205780846732004, 54.764930043901714, 53.25808116367885, 54.85574647358486, 51.84876414707729, 50.35195541381836, 47.10876907621111, 48.84760788508824, 57.75839465005057, 56.9428984778268, 59.24791472298758, 60.652715410505024, 58.39058344704764, 55.94002676010132, 46.79832008906773, 40.61623682294573, 61.184308188302175, 56.00263697760445, 61.99289090292794, 54.8007619040353, 56.98644978659493, 50.65128033501761, 47.5844601222447, 45.606492110661094, 44.623975140707834, 45.524805613926475, 49.241060052599224, 58.948961530412944, 59.70633602142334, 57.33938353402274, 58.25378383908953, 60.15018694741385, 58.995583942958284, 53.3069999558585, 48.390430314200266, 50.69729478018624, 55.3408453805106, 56.14288636616298, 58.014376708439414, 57.52429941722325, 54.51772356033325, 55.29146453312465, 55.835859366825645, 56.914000919886995, 53.946633747645784, 53.58618899754116, 55.19985253470284, 52.74426187787737, 54.97826753343855, 52.02935825075422, 54.0499986239842, 58.35488360268729, 43.532180377415244, 14.336886048316956, 0.8091430217027664, 0.49085440380232676, 5.117608819689069, 5.62950302021844, 4.6697587711470465, 9.567514862333026, 10.205036401748657, 7.37578204699925, 0.36472554611308233, 0.16420672301735195, 8.487851653780256, 45.34277670724051, 52.72098888669695, 31.414973667689733, 36.08264146532331, 40.5058890070234, 38.808881827763145, 7.927765182086399, 0.13304903278393404, 0.14235729830605642, 0.22261712088116578, 0.15066315047442913, 0.10512296057173184, 0.1559157579072884, 0.13066867765571388, 0.11138388461300305, 0.11689206904598645, 0.26098921256405966, 0.15160495708031313, 0.202535157757146, 0.21692841899182114, 0.1474561361329896, 0.1308892693902765, 0.08626244869083166, 0.057360914535820484, 0.15897700935602188, 0.21623982808419637, 0.13287473070834363, 0.1155258659273386, 0.11885029396840505, 0.1711831215236868, 0.20336917228996754, 0.1588508425546544, 0.13920447177120618, 0.1593502986111811, 0.125632251479796, 0.12889897690287658], [0.04244259272568992, 0.04888282982366426, 0.02869072350274239, 0.03682674514129758, 0.034346563941133876, 0.04626384410741074, 0.03416312878419246, 0.024715003624026264, 0.06695803920073168, 0.01485503145626613, 0.0527083322272769, 0.04397897921236498, 0.02142271609045565, 0.03763184729697449, 0.04925714027402656, 0.030557363161018918, 0.03194726750786815, 0.03974737020741616, 0.0444023816713265, 0.047923438982771974, 0.015822554539356912, 0.030979384801217487, 0.034626405353524854, 0.005619491741526872, 0.028923006395676305, 0.014076867140829563, 0.024912623555532525, 0.027808064794433967, 0.004456206640627767, 0.020315158646553755, 0.026464801248429076, 0.06404536656503167, 0.019364486980651106, 0.02812055391924722, 0.04294835915789008, 0.04926772881299257, 0.04460533828075443, 0.05513857325006809, 0.6956113023417336, 26.757608311516897, 48.21506472996303, 33.36937338965279, 27.520551783697947, 37.797981466565815, 47.340404646737234, 20.199054275240215, 0.9404457360506058, 0.18136664293706417, 0.32838367191808565, 0.8350000913654054, 1.1429455557039805, 2.1641291422503333, 3.5642298076834, 0.16441302480442183, 0.16680990904569626, 4.360695949622563, 28.137430225099834, 54.376536164964946, 65.37157753535679, 60.55478055136544, 58.845426423209055, 58.81285326821463, 61.150616373334614, 59.107554163251606, 59.05362919398716, 60.190264156886506, 57.33632285254342, 52.09412240982056, 49.48607785361153, 53.862435477120535, 56.078247274671284, 56.13077218191964, 59.16188907623291, 58.667413575308665, 57.590755462646484, 52.64098385402134, 52.74951124191284, 49.30223894119263, 45.816449301583425, 47.57741812297276, 44.87134143284389, 41.448394775390625, 43.50020824159895, 51.227605615343364, 53.898072787693565, 55.807118143354145, 55.05198444638933, 53.90786974770682, 52.455282824380056, 46.542331082480295, 37.52707120350429, 63.337151936122346, 58.28847272055489, 58.016145024980815, 56.48877464021955, 52.463985443115234, 50.75752176557268, 50.332965987069265, 46.19781507764544, 42.58631168093, 42.99075589861189, 45.68828630447388, 52.14316974367414, 54.97513736997332, 57.25284024647304, 57.44590984072004, 56.17832217897688, 56.131300245012554, 52.78556544440133, 52.096297195979524, 48.448260171072825, 50.84618425369263, 54.38119145802089, 55.492131982530864, 56.52744831357683, 56.24130759920393, 55.15613794326782, 56.05219152995518, 53.985679149627686, 53.4866977419172, 51.80110992704119, 54.424506528036936, 52.44045884268624, 52.39238773073469, 53.29717172895159, 55.68564278738839, 29.691038744790212, 4.834037636007581, 0.05215094285085797, 0.05434684841228383, 0.2992810064128467, 2.9660960861614774, 3.3401986062526703, 1.090071175779615, 0.9703907349279949, 0.3723589022244726, 0.16604484724146978, 0.0877431138817753, 6.40332476581846, 39.22794158118111, 36.393826961517334, 45.67523063932146, 43.599411146981375, 26.363079173224314, 23.496865613119944, 4.0163315023694715, 0.06915174291602202, 0.08916746066617114, 0.021062761744750396, 0.06548973013247762, 0.05165722720058901, 0.006246480151146118, 0.021949062489771416, 0.043227522035262415, 0.0499313496319311, 0.034438936305897574, 0.03972268510343773, 0.03734989564067551, 0.05990102394883122, 0.01402602536005101, 0.0956357992919428, 0.03151943760790995, 0.010948338944997107, 0.08724089618772268, 0.029202813881316354, 0.0547600830239909, 0.028515464692775692, 0.04100181860849261, 0.012615523234541928, 0.04720243445730635, 0.020922535697796514, 0.03161592189488666, 0.06069994465048824, 0.023970747399809103, 0.04864959019635405, 0.061885345328067026, 0.009666187655446785, 0.01496698464533048, 0.025611887819000652, 0.02341113073219146, 0.04568972545010703, 0.004687581568889852, 0.023965139307879975, 0.014096782143626894, 0.03950784056048308, 0.015917622384482195, 0.027069618526313986, 0.007606400459605668, 0.050089651851781776, 0.09237269046051161, 0.013418105480793332, 0.017803350929170847, 0.04462443564885429, 0.009507966859798347, 0.04702737242249506, 0.004746402073318937, 0.0561938851938716, 0.06997878889420203, 0.06650076766631433, 0.02516458905301988, 0.04849274004144328, 0.020044348535260985, 0.024549093330278993, 0.02914020884782076, 0.007160059276169964, 0.07843745393412453, 0.03517488217247384, 0.019860920163669755, 0.01631086565820234, 0.03603876581681626, 0.042223470019442697, 0.0549002005053418, 0.04130003474918859, 0.05369629617780447, 3.009769856929779, 37.996873651232036, 49.224717889513286, 31.073629515511648, 31.34133665902274, 52.09277098519461, 59.9018930707659, 16.510043723242624, 0.5803492101175445, 0.1867476427661521, 0.04426762800929802, 0.20158491017563002, 0.5044029025094849, 1.5410409654889787, 4.212150411946433, 0.47236747294664383, 0.04797858013106244, 6.2824026601655145, 33.3592985016959, 58.313069343566895, 66.8811640058245, 63.18001842498779, 60.099736077444895, 60.267903327941895, 62.395108222961426, 59.8062024797712, 58.12431805474417, 62.41400037493025, 58.70534379141671, 55.19288001741682, 51.2478735106332, 54.88887201036726, 58.79111235482352, 59.74654524666922, 59.84814875466483, 59.42563574654715, 59.24281474522182, 55.022374698093955, 54.70055150985718, 51.34865018299648, 49.15940829685756, 49.86276401792254, 46.287811619894846, 43.4216171673366, 46.22048704964774, 53.50777162824358, 55.56698840005057, 58.1493558883667, 57.69564199447632, 55.849932943071636, 54.64418077468872, 50.5818852015904, 38.54017414365496, 61.17674160003662, 58.818842615400044, 59.84483446393694, 58.48318903786795, 54.37213100705828, 51.76627860750471, 52.08429070881435, 47.15944923673357, 44.15425607136318, 45.215371063777376, 48.3011668069022, 53.639644963400706, 58.0147762298584, 56.58971806934902, 56.10766247340611, 57.03138378688267, 57.94880655833653, 53.29453141348702, 53.693323271615164, 49.64953769956316, 51.678574970790315, 56.098588126046316, 55.68987076623099, 58.161209515162874, 57.817225047520225, 56.514260632651194, 55.92960098811558, 55.097759178706575, 55.171823501586914, 53.17245503834316, 53.76665803364345, 52.862346512930735, 53.061408928462434, 52.794139521462576, 56.28780494417463, 36.75849274226597, 7.862552864210946, 0.3346390319722039, 0.18726733273693494, 0.7475495210715702, 5.698527727808271, 3.355397573539189, 1.3841873364789146, 0.40877424819128855, 0.09866465747888599, 0.0647834837436676, 0.06805827016276972, 3.8620988641466414, 39.943637302943635, 47.29695756094796, 45.10849387305123, 39.40994616917202, 29.962233883993967, 30.49667889731271, 8.657867125102452, 0.10003329653825078, 0.04538000814084496, 0.01930126956930118, 0.08734722262514488, 0.012431222097282963, 0.03421923005953431, 0.021362962600375925, 0.05381974883909736, 0.07577860089285032, 0.03831850437979613, 0.03587287079010691, 0.0177851746723588, 0.06131715367415121, 0.01267773047688284, 0.06381171981671027, 0.011435295538311558, 0.030032842020903314, 0.10516225453466177, 0.025287612540913478, 0.019192200154066086, 0.035495500146810494, 0.0519491601070123, 0.024734180719990815, 0.01931547130724149, 0.025014520855620503, 0.08283037106905665, 0.03851871631507363, 0.02089294817830835, 0.010013613700201469, 0.04974630634699549, 0.1737587454595736, 0.07721640981201615, 0.11695728983197894, 0.08627726789563894, 0.21718631658170903, 0.10733771922865085, 0.1287000575768096, 0.20102148183754512, 0.14669935245599064, 0.08286691017981086, 0.11482742269124303, 0.10685175923364502, 0.13963538222014904, 0.16084333349551472, 0.16738621597843512, 0.08579590836805956, 0.12434136574821812, 0.14077704453042575, 0.08363170735538006, 0.12012167860354696, 0.1992718657212598, 0.1153207855033023, 0.15512899655316556, 0.13302026289914334, 0.09372336869793278, 0.2065053340047598, 0.11281413465206112, 0.09079789210643087, 0.10572330121483121, 0.2268296969788415, 0.09419322705694608, 0.10192904874150242, 0.08456575830600091, 0.09942064726991312, 0.13548714481294155, 0.13137552115534032, 0.16207697801291943, 0.14879009526755127, 2.716286199433463, 40.68217175347464, 62.864924567086355, 43.03583928516933, 37.45595639092581, 49.92900119509016, 58.54091467176165, 26.60445785522461, 1.0435114055871964, 0.3786008544266224, 0.6032830423542431, 5.009390192372458, 7.145599518503461, 6.0925913367952615, 5.760616396154676, 0.7791707185762269, 0.2358151019683906, 5.475950002670288, 31.951854024614605, 59.5876191002982, 69.16468252454484, 66.12405354636056, 63.80113179343087, 62.928431102207725, 65.17824390956334, 61.149928501674104, 61.74507645198277, 64.85202598571777, 62.253316334315706, 57.23697403499058, 54.967073985508506, 57.84396866389683, 60.039787020002095, 63.55269200461251, 63.588704517909456, 63.3198161806379, 63.2948374067034, 58.719643184116904, 57.96629170009068, 54.38242823737008, 51.50322675704956, 53.85085283006941, 49.33532278878348, 46.60833549499512, 48.152596950531006, 55.08960894175938, 58.02736289160592, 58.231744153159006, 59.92537103380476, 57.96815381731306, 57.6280186516898, 53.26902110236031, 43.491186005728586, 62.60873058864048, 61.47203309195382, 62.840022223336355, 60.95646980830601, 58.245539801461355, 54.8122854913984, 55.69558565957205, 50.1474803515843, 45.980200971875874, 47.255838121686665, 49.83416175842285, 55.73934194019863, 59.136715752737864, 57.730059896196636, 57.02783325740269, 59.77239949362618, 60.5564272744315, 56.05313648496355, 56.382307393210276, 52.401045186179026, 55.44962985174996, 58.27197422300066, 59.73622022356306, 59.481971740722656, 60.303894996643066, 56.932688099997385, 59.30261789049421, 57.14759588241577, 58.58905873979841, 55.66929367610386, 58.82328251429966, 54.4046242577689, 56.89535195486886, 57.43205165863037, 58.22004338673183, 32.78743396486555, 7.140418767929077, 0.18549033094729694, 0.1986236340765442, 0.4261439304266657, 4.555873453617096, 7.789926818438938, 7.476195675986154, 8.040918333189827, 1.9258243867329188, 0.32207318767905235, 0.24440367253763334, 9.239087411335536, 48.916704245976035, 46.48884732382638, 53.316522462027415, 49.746114185878206, 40.64959512438093, 38.27832433155605, 7.868587374687195, 0.13444766987647327, 0.13789331141327107, 0.11478889547288418, 0.18126502553267138, 0.14173899005566323, 0.15288577335221426, 0.11024938763252326, 0.18157061056366988, 0.10768719190465552, 0.11946607806852885, 0.19558781412030968, 0.10586862305977515, 0.17496988975575992, 0.13513802497514657, 0.1967552336198943, 0.08654921794576304, 0.0993727630536471, 0.16039316622274263, 0.27648008561560083, 0.1308549219476325, 0.1588324135435479, 0.09209835875247206, 0.09531973089490618, 0.11337514062012945, 0.1630194495831217, 0.20695091438080582, 0.25086620290364536, 0.10180455113628081, 0.24254505655595235, 0.13174415566027164], [0.038359168983463726, 0.026081647790436233, 0.05320631247013807, 0.09330648356782538, 0.07758530894560473, 0.02845965518749186, 0.00044301015961017195, 0.035017261880316904, 0.034008795994200876, 0.03442566076825772, 0.03952244941943458, 0.024943286553025246, 0.01416677811981312, 0.13063017757875578, 0.022536373564175198, 0.02219842071644962, 0.022798715558435236, 0.02355049843234675, 0.04895622356395636, 0.056995028097714694, 0.03586975631437131, 0.02328404281953616, 0.024112630768546035, 0.058011975671563826, 0.052101033207561286, 0.055063398355352025, 0.0053747407676252934, 0.017547527960102473, 0.02695738204887935, 0.01582187770067581, 0.0170449302864394, 0.05042169635583248, 0.03442974215639489, 0.044635061507246325, 0.002386309697093176, 0.03939103414969785, 0.04501990621377315, 0.023619023683880056, 0.03869453491643071, 2.036782341344016, 24.720281839370728, 46.357707023620605, 41.36342872892107, 35.377607754298616, 33.98939936501639, 53.97333567483084, 25.016321999686106, 1.7896596704210554, 0.05894869326480797, 0.025181294585179006, 0.5319642350077629, 3.9900290966033936, 3.3564039766788483, 0.5687639574919428, 0.08859478389578206, 0.17979169530527933, 5.718340950352805, 31.514280796051025, 55.81464304242815, 61.29628535679409, 61.55259050641741, 63.05226884569441, 60.56086022513253, 57.93777976717268, 59.11373805999756, 59.05011340550014, 56.92157098225185, 53.731705120631624, 53.3109986441476, 57.14315945761544, 58.07083082199097, 57.6371659551348, 58.39796243395124, 56.37950726917812, 55.13958386012486, 50.221864291599815, 51.263920375279014, 50.126569747924805, 48.66270589828491, 47.088911124638145, 47.6627003124782, 43.12894514628819, 44.82151937484741, 51.16345984595162, 56.72420392717634, 54.69572598593575, 60.83144392286028, 54.84152351106916, 50.00744983128139, 39.57897499629429, 26.22541277749198, 60.48332527705601, 55.37983867100307, 57.89421803610665, 54.63457836423601, 57.92777436120169, 51.77371317999703, 51.72865411213466, 46.81738247190203, 44.59090518951416, 41.25085401535034, 46.07264675412859, 54.37615401404244, 58.91920934404646, 58.610535621643066, 60.50471183231899, 56.74907847813198, 57.835748944963726, 54.97498450960432, 53.90495845249721, 52.25161722728184, 50.691666739327566, 49.570932728903635, 55.240760053907124, 56.65359285899571, 57.91168928146362, 55.054979119982036, 58.49454934256417, 55.327452727726524, 55.34186676570347, 56.309441634586875, 53.392834527151926, 52.74947650091988, 55.634945256369456, 49.7601877621242, 19.042596101760864, 1.4629300768886293, 0.07991788842316185, 0.019953619921579957, 0.9698895961046219, 4.052359649113246, 10.694390211786542, 5.78200729404177, 2.664804824760982, 0.5551483109593391, 0.0226381080158587, 0.2802837629403387, 9.643729652677264, 44.08074413027082, 35.36553873334612, 19.460868971688406, 25.03234280858721, 29.938686438969203, 22.644271271569387, 4.906869956425258, 0.04956476091008101, 0.04387277491124613, 0.14656817806618555, 0.07334344727652413, 0.022382120502048304, 0.031762814548398764, 0.050872660907251496, 0.018892401330439106, 0.002040519769902208, 0.02361104071938566, 0.01456137337455792, 0.0045022070740482634, 0.047157376339393, 0.03340963939470904, 0.03345406986773014, 0.04671947358708296, 0.030929407304418937, 0.02647026175899165, 0.04713239607268146, 0.019875479828832403, 0.0556590197873967, 0.010395050464597131, 0.0289432912000588, 0.03036291877339993, 0.08144531146224056, 0.02928290136956743, 0.021055457315274646, 0.04472095046990684, 0.01886952791496047, 0.02676623364511345, 0.02395441336557269, 0.04832884330036385, 0.013777762967427927, 0.04112251641760979, 0.0904712046363524, 0.04339575461511101, 0.03912386777145522, 0.03519780308540378, 0.014715585724583693, 0.015702659097899283, 0.024280481672446643, 0.03228409229112523, 0.013896859433901097, 0.037986795750579665, 0.02560806936318321, 0.021478630768667375, 0.014163517759048512, 0.0018203078029078565, 0.08085092157125473, 0.01601894123346678, 0.07218180210994822, 0.06831132301262446, 0.06573027079658848, 0.026554929358618598, 0.02840391523204744, 0.025022843087624227, 0.01813424362002739, 0.0066750025809077275, 0.0856385018144335, 0.03571256349927612, 0.03776615312589066, 0.060504954042179246, 0.023965515894815326, 0.021542056829535534, 0.046410132864756246, 0.028508214546101432, 0.03215323342010379, 0.0377571998563196, 0.031791350338608027, 0.07026764125164066, 4.02555045911244, 36.961949893406455, 51.73963574000767, 40.97347150530134, 32.256744452885215, 40.55824368340628, 62.94418961661202, 19.932877472468785, 1.2115330696105957, 0.06206535388316427, 0.11712305593703475, 0.05710313908223595, 6.337177915232522, 4.396269423621042, 1.0600676600422179, 0.15065124897020205, 0.3139549233019352, 8.354293380464826, 37.664277281079976, 59.18872996738979, 62.277523858206614, 62.991750035967144, 64.9237869807652, 61.76124491010393, 59.26599393572126, 59.81242111751011, 62.00042969839913, 59.84673827035086, 55.64129590988159, 56.57500178473336, 57.221483026232036, 57.76750373840332, 59.84955923897879, 60.39165769304548, 59.122548375810894, 58.60408769335066, 53.68570457186018, 54.52854190553938, 53.82640906742641, 49.690299306597026, 50.689033372061594, 49.49997425079346, 44.511080810001914, 47.02752726418631, 51.79126780373709, 57.46314137322562, 56.42739772796631, 61.62689454214913, 56.47255754470825, 53.9967372076852, 45.69337933404105, 31.734545639583043, 60.206238065447124, 56.48153114318848, 59.82449013846261, 56.35403517314366, 59.357619830540244, 52.758946895599365, 52.476735387529644, 48.021790163857595, 45.04427514757429, 41.4406544821603, 46.87502472741263, 55.44221264975411, 59.08893299102783, 61.11444405147007, 59.928386551993235, 55.59959282193865, 59.84483446393694, 56.24922159739903, 55.968371936253135, 54.2788861819676, 51.20153944832938, 52.302634375435964, 57.220624923706055, 57.41912453515189, 58.44241006033761, 55.76950754438128, 58.960314886910574, 57.112344196864534, 56.95053802217756, 56.28761734281267, 55.29523393086025, 53.39118432998657, 55.86092846734183, 54.979629380362375, 27.49935977799552, 3.400961471455438, 0.26312255380409105, 0.6328097922461373, 4.36722378219877, 4.4422339286123, 5.856309592723846, 6.98817765712738, 4.943539943013873, 0.49154770374298096, 0.015058686956763268, 0.06973025508757148, 6.703628080231803, 46.589745589665, 46.690998213631765, 23.56413459777832, 32.61624424798148, 38.34842470714024, 31.228504862104142, 9.674121941838946, 0.04901467596313783, 0.029255312135709182, 0.054670648715857945, 0.029028661083430052, 0.05830740981868335, 0.04649550274812749, 0.046145772228815725, 0.015060851483472755, 0.022944634514195577, 0.0349781036243907, 0.04850740657587137, 0.017847615161112378, 0.0436783033822264, 0.06257774281714644, 0.02528020124217229, 0.028103526082954237, 0.059992544752146514, 0.017015388568064997, 0.046577150866921456, 0.04791983935449805, 0.016872475522437265, 0.011282682834592248, 0.027205503645486066, 0.020652770530432463, 0.020380245421880057, 0.051844869274646044, 0.031786590415452204, 0.02196484012529254, 0.024219052200870853, 0.07155375009668724, 0.11682539619505405, 0.1091457097125905, 0.1245575062930584, 0.17000213132372924, 0.17794582221124852, 0.20068997676883424, 0.08372152503579855, 0.15765200688370637, 0.09590004796960525, 0.11807995316173349, 0.10515031910368375, 0.23098803098712647, 0.08459485388760056, 0.10254617634096316, 0.1633130381149905, 0.145884472610695, 0.14468489055122646, 0.08564829307475261, 0.2591858836156981, 0.12810348958841392, 0.14576833455690316, 0.126282790143575, 0.1504213884472847, 0.1031817261661802, 0.15023601268018993, 0.11860674060881138, 0.17860226412968977, 0.05049299342291696, 0.21851572953164577, 0.09407964029482432, 0.11679601562874657, 0.16403042604880674, 0.12888825604958193, 0.09240827283688954, 0.11658675542899541, 0.16997371427714825, 0.11006264801004104, 0.10945402245436396, 0.1283027617526906, 0.16612617644880498, 3.0455363605703627, 36.092358521052766, 61.981586183820454, 52.46113320759365, 46.734646797180176, 44.1730683190482, 66.75513757978166, 32.08355018070766, 2.8112224766186307, 0.17413739514138016, 0.46519188370023457, 1.7876387217215128, 7.492807950292315, 6.6495411310877115, 2.894923733813422, 0.3024323673120567, 0.55101093011243, 6.8511748143604825, 35.40256915773664, 59.107929365975515, 63.9539852142334, 65.6096784046718, 68.60902118682861, 62.623085566929404, 58.1482754434858, 59.92646190098354, 63.35433483123779, 61.7299085344587, 57.0729409626552, 59.01013347080776, 60.842484610421316, 61.86478001730782, 62.21517767224993, 62.184466634477886, 60.86403097425188, 61.34481157575335, 55.82668774468558, 57.23218672616141, 56.91916343144008, 53.04050874710083, 53.68041351863316, 52.83466141564505, 47.33877182006836, 49.412103857312886, 55.38009228025164, 61.22819301060268, 59.32130854470389, 66.13314873831612, 57.586913108825684, 55.50508689880371, 46.83810200010027, 33.303862299237935, 60.94504002162388, 56.541521889822825, 59.38404382978167, 58.126319135938374, 61.777684347970144, 56.44195767811367, 55.55130631583077, 51.20441252844674, 49.00778123310634, 43.886826855795725, 47.96957792554583, 57.706887653895784, 62.25878456660679, 62.08458627973284, 59.900628498622346, 57.03168255942208, 60.57944665636335, 58.795197895595, 58.00291565486363, 56.65469414847237, 52.513842242104666, 53.22634526661464, 59.456124441964285, 59.58639621734619, 60.3732727595738, 56.505050795418875, 58.885093688964844, 56.44395875930786, 58.37454005650112, 58.2397415297372, 56.24707112993513, 57.20797920227051, 57.28544119426182, 52.20697505133492, 23.691515922546387, 2.6414695169244493, 0.12275170747722898, 0.35684984443443163, 2.981059466089521, 9.204505358423505, 20.497217110225133, 13.567976679120745, 7.809542451586042, 2.1838650660855428, 0.13888015917369298, 0.5128334015607834, 14.147287079266139, 53.97141102382115, 44.24575342450823, 28.493442024503434, 35.46680177961077, 41.94906112125942, 37.38408769880022, 8.947146688188825, 0.19231338053941727, 0.22220055466251715, 0.18088253534265927, 0.08396976028702088, 0.17363031235124382, 0.08963151076542479, 0.1511602723704917, 0.14451351974691662, 0.10709061034555946, 0.14469048167978013, 0.1307607955698456, 0.06682851365102188, 0.1865724857364382, 0.16669850716633455, 0.11352371943316289, 0.12353738317532198, 0.18350431323051453, 0.08855928294360638, 0.11937390587159566, 0.1316970381885767, 0.20710768311151437, 0.11378373405230896, 0.08908851990210158, 0.1640106128262622, 0.14782185293734074, 0.09399758505501918, 0.09217947761395148, 0.1306802670338324, 0.08794113075626747, 0.14143956612263406, 0.3025063547704901], [0.0439032105995076, 0.020395668522853936, 0.06603917386382818, 0.0865092318771141, 0.040955237179462395, 0.004410993307828903, 0.027134164169962918, 0.05792628348405872, 0.017461508379450867, 0.061024460808507035, 0.05131687403523496, 0.01035415007001055, 0.029474363595779454, 0.018729803983920386, 0.04271846131554671, 0.019422634039074183, 0.006499074989863272, 0.015346704716128963, 0.04290394564824445, 0.04236324144793408, 0.023819189818043793, 0.07809560120637928, 0.02692691921921713, 0.005250980221067688, 0.004293503697096769, 0.0295485410440181, 0.02206290200618761, 0.09304363267230135, 0.048143389501741955, 0.03320821627442326, 0.00968352337700448, 0.011189525065544461, 0.047308520014796934, 0.10411275763596807, 0.05639384946386729, 0.03092469827138952, 0.07170481234788895, 0.09286849599863801, 0.022670570827488388, 0.061235573408859115, 1.0202501394918986, 17.792604752949305, 44.82201617104666, 40.144151891980854, 34.55846030371529, 33.55112089429583, 59.95628356933594, 36.15386050088065, 4.9493043422698975, 0.08009274011211735, 0.16451602642025265, 0.13686227745243482, 1.0505586160080773, 0.17855981497892312, 0.1620814563440425, 0.06167120646153178, 0.2425594957811492, 3.6046976361955916, 24.284645421164377, 48.75418240683419, 59.60332202911377, 58.91995974949428, 62.25492136819022, 58.82980687277657, 62.304468972342356, 60.939418928963796, 61.754387038094656, 54.87847750527518, 55.27734579358782, 56.8293788092477, 58.77298450469971, 57.36207635062081, 56.88017361504691, 54.79243796212332, 51.697758947099956, 50.17446715491158, 54.10779026576451, 52.28602818080357, 52.07737725121634, 50.32531949451992, 49.07986879348755, 45.07701505933489, 45.3334070614406, 49.239416803632466, 59.99054513658796, 56.71983698436192, 57.900818824768066, 50.92161737169538, 57.58132675715855, 38.20455878121512, 16.330490112304688, 58.06467471803938, 52.04911197934832, 62.19030312129429, 60.727790696280344, 57.73175178255354, 56.154455116816926, 58.03456122534615, 51.16699995313372, 48.31169332776751, 44.102234908512656, 44.98521545955113, 51.981578963143484, 59.97688497815813, 58.13780798230852, 56.73616177695138, 56.59833383560181, 58.48894214630127, 56.43076760428292, 57.022219112941194, 55.897576740809846, 56.17816237040928, 55.76559918267386, 54.97071484157017, 57.329812390463694, 58.60260772705078, 58.48963696616036, 58.534807205200195, 57.47669383457729, 55.73618745803833, 54.854909215654644, 57.20354972566877, 57.02269853864397, 36.27251836231777, 9.864865626607623, 0.06192084628024271, 0.07245719233261687, 0.1774735211261681, 1.9658529588154383, 6.017372744424002, 9.807608996118818, 23.47656123978751, 7.968763896397181, 1.0030715870005744, 0.06761183483260018, 0.46341303629534586, 13.856322578021459, 49.212301458631245, 28.304385014942714, 20.43505678858076, 28.242836134774343, 34.183188097817556, 18.363315888813563, 3.354595490864345, 0.08843746555170842, 0.010996373287136001, 0.06597814642425094, 0.05511102133563586, 0.04711307818070054, 0.13942867331206799, 0.017980628380818025, 0.030746443729315485, 0.067182987130114, 0.023777666867577603, 0.023135360529912368, 0.020564396433266144, 0.05945709241288049, 0.05462637430589114, 0.09829247423580714, 0.014857294370553322, 0.05934155146990504, 0.01708404952660203, 0.05708055065146514, 0.056085886167628426, 0.045708951739860434, 0.08254404286188738, 0.037814071268907616, 0.014102978016515928, 0.02588585820714278, 0.028965045032756667, 0.022214291650535803, 0.036874646320939064, 0.07795749218868357, 0.02086295184147145, 0.01676843235535281, 0.029127907007932663, 0.025020824445943748, 0.051755967616502724, 0.02984819228627852, 0.05908963855888162, 0.025329771617959653, 0.01251227140892297, 0.0377921376244298, 0.04960534408954637, 0.03339637064241937, 0.03566082859677928, 0.009595575908731137, 0.0062665359499598184, 0.05859893560409546, 0.051795393893761296, 0.027938781173101494, 0.026028325115995746, 0.009602290012740662, 0.028810858127794096, 0.01197912948139544, 0.06599873317671673, 0.05703439669949668, 0.025927674624004533, 0.011269770313187369, 0.08738679478743247, 0.04032295789303524, 0.02682172423893852, 0.0661484112164804, 0.025422013364732265, 0.03227921701701624, 0.02421870275533625, 0.008803292975894042, 0.029972024927181855, 0.03178104678434985, 0.02728784895901169, 0.006793632130471191, 0.018547571530299525, 0.011408140566865248, 0.06578285047518355, 0.02714630655412163, 0.0903343509084412, 2.4483584506171088, 28.92303350993565, 50.46604830878121, 41.19623422622681, 30.86135162625994, 44.038624150412424, 72.40216786520821, 30.943882329123362, 3.128557562828064, 0.10573346566941057, 0.11645275833351271, 0.40281060391238754, 0.22480037515716894, 0.6921835062759263, 0.5153397470712662, 0.0994705128084336, 0.3007309543234961, 6.380124730723245, 31.56017017364502, 55.201777185712544, 62.6844242640904, 63.79278005872454, 62.68176310403006, 59.804465430123464, 61.998685700552805, 63.28532532283238, 61.7079313823155, 55.176093169621055, 56.707441398075645, 59.68652670724051, 60.81771428244454, 59.99934850420271, 59.30972589765276, 57.308728081839426, 52.91752215794155, 52.229549748556956, 54.80239820480347, 54.527902671269004, 54.251885482243125, 50.416497230529785, 50.182815415518625, 47.41117899758475, 48.223187174115864, 51.29485375540597, 61.26324667249407, 58.02982950210571, 60.78110422406878, 52.515624455043245, 59.90877873556954, 43.09131717681885, 19.031086410794938, 59.53823825291225, 55.12866129193987, 64.69234248570034, 61.07287992749895, 61.00400243486677, 56.73898274557931, 58.19313996178763, 53.1658090863909, 50.616907596588135, 45.36579956327166, 47.262543133326936, 53.35176025118147, 60.30608367919922, 59.7687725339617, 58.21503720964704, 57.23568514415196, 58.794558661324636, 56.95410244805472, 58.483070918491904, 56.26955202647618, 58.038021428244456, 55.57686873844692, 57.615793296269004, 58.980165890284944, 58.74437182290213, 57.97663409369332, 59.702583994184224, 56.77743060248238, 56.69692529950823, 55.4532151222229, 57.080986976623535, 59.43596771785191, 45.40205178941999, 14.814585992268153, 0.4376544899174145, 0.1433500357504402, 1.4130166066544396, 2.9907018286841254, 6.377856578145709, 12.92473156111581, 20.59225630760193, 8.298112852232796, 0.8512030733483178, 0.018781499870653664, 0.17098747273640974, 11.349906717027936, 54.43993500300816, 42.57052189963204, 23.464705875941686, 28.564400502613612, 35.31063754217965, 28.03593441418239, 6.718057317393167, 0.0031129575134920223, 0.03356057272425719, 0.07072234113833734, 0.042222174017557075, 0.03302899142727256, 0.04791561886668205, 0.05404173835579838, 0.12882835497813566, 0.06179197212415082, 0.05818806229425328, 0.02949369166578565, 0.0029292356755052295, 0.05591157391401274, 0.1265073309519461, 0.034094888517366986, 0.016409935163600103, 0.011891234599586045, 0.07848385215869971, 0.03753114930753197, 0.035763338274721584, 0.049412850490106006, 0.09904406033456326, 0.027200297585555484, 0.05259673696543489, 0.010136213103708411, 0.013679081075159567, 0.027249381112466966, 0.03651330267478313, 0.04092275910079479, 0.0464550858097417, 0.04644500617203968, 0.016669215268588493, 0.07198198033230645, 0.15840790846518107, 0.1841989295291049, 0.1527421274887664, 0.13505641078310354, 0.09457296239478247, 0.16243854218295642, 0.10495399856673819, 0.07117755671164819, 0.12124169564672879, 0.10780225787311792, 0.05779607939933028, 0.2316986471414566, 0.09201407791780573, 0.13663902586059912, 0.145482155627438, 0.10448669828474522, 0.0943303657695651, 0.10171637551060744, 0.19548226121280873, 0.10920136994017021, 0.14099942759743758, 0.11676141034279551, 0.21898796276322433, 0.1033283711544105, 0.08382741042545863, 0.12191664800047874, 0.14930791248168263, 0.11238598584064416, 0.13795538379677705, 0.11237330402114562, 0.097696835840387, 0.20778277117226804, 0.26757811329194475, 0.061878553192530356, 0.16438725404441357, 0.12299370020627975, 0.15115557690816267, 0.14402105260108197, 0.24252315344555037, 1.8474497922829218, 29.681623935699463, 61.53954873766218, 52.21409348079136, 45.05760874067034, 45.06261491775513, 72.4138686316354, 44.50550488063267, 7.49887980733599, 0.21521281105067047, 0.29899295472673004, 0.6381481800760541, 4.1642933913639615, 1.7560568792479379, 1.1771869297538484, 0.2657607522393976, 0.5737506470509938, 5.191841636385236, 29.098216703959874, 53.5786953653608, 63.415117672511506, 60.46564211164202, 63.309678758893696, 59.80269363948277, 63.90644563947405, 65.16215188162667, 67.31539167676652, 57.79686682564871, 59.32398360116141, 60.1117217200143, 63.63454178401402, 62.88059970310756, 62.35411385127476, 61.192771094185964, 56.17017541612898, 55.70717525482178, 59.476850918361116, 56.4859745161874, 58.64189979008266, 54.159109660557334, 53.77373129980904, 50.59468378339495, 49.962981360299246, 53.51827383041382, 64.908417565482, 60.87129878997803, 60.91794899531773, 55.47948626109532, 63.78851386478969, 45.230969769614084, 23.10382338932582, 60.84803622109549, 56.97651038851057, 64.17037991115025, 65.46981811523438, 61.612699372427805, 60.74003342219761, 60.64176504952567, 56.48557846886771, 51.573518208095, 47.491055488586426, 48.56999955858503, 55.69541890280587, 61.370339257376536, 62.58230658939907, 57.52761370795113, 56.81064646584647, 61.19577966417585, 60.94344193594796, 60.43272154671805, 60.59892245701381, 59.912280627659385, 58.90149143763951, 61.114840098789756, 61.740177971976145, 61.089861324855256, 59.542768478393555, 58.88049398149763, 58.624925340924946, 57.131166866847444, 57.43769359588623, 58.05483954293387, 60.11038071768624, 40.03047588893345, 14.229008316993713, 0.3559415303170681, 0.21861027660114424, 1.1395406126976013, 5.398796771253858, 15.598563398633685, 15.39449828011649, 35.39048624038696, 16.003273384911672, 2.581540435552597, 0.09625679454100983, 0.9428258197648185, 20.11184917177473, 59.13021223885672, 39.784832750047954, 32.24479702540806, 39.277895654950825, 46.927803243909565, 33.58499683652605, 6.032627080168043, 0.1441582523818527, 0.07155678993357079, 0.15916698559054307, 0.21928294907723153, 0.18887760490179062, 0.18861991087240831, 0.1266138338084732, 0.1973190147961889, 0.19884328943278107, 0.12236108843769346, 0.10185269319585391, 0.08828117858086314, 0.1534211239112275, 0.18097792379558086, 0.17142345862729208, 0.14450176752039365, 0.1724419668316841, 0.1482489500194788, 0.16965485710118497, 0.1741681463484253, 0.144121950758355, 0.22869957664183208, 0.1446549535862037, 0.16316469678921358, 0.09198741149157286, 0.14418835219527992, 0.11775281785854272, 0.1091713583362954, 0.22615610169512884, 0.1074850359665496, 0.09851208209459271, 0.1558227307562317], [0.03943403969917979, 0.07717249502560922, 0.006019332496050213, 0.01330871376142438, 0.04799004058752741, 0.04184867102386696, 0.04524005011522344, 0.06585239352924482, 0.01768864458426833, 0.07677486671933106, 0.06527292462331907, 0.02101249247789383, 0.03228119833927069, 0.011379510629922152, 0.01072748173360846, 0.01929230272902974, 0.03691964676337583, 0.029379548504948616, 0.05802325292357376, 0.01456416554615966, 0.018988899188116193, 0.02751974169430988, 0.003677246318797448, 0.0490049016661942, 0.0569468317553401, 0.11726853384503297, 0.023528563091531396, 0.022366427683404515, 0.02228546827765448, 0.02141203934193722, 0.017283323387216245, 0.030541451514831612, 0.043389098186578066, 0.05427639612129756, 0.04457628001858081, 0.03632886328601411, 0.0897339695532407, 0.05708334621574197, 0.03428848134353757, 0.050877203699201345, 0.014165998652710446, 0.6237065664359501, 13.531196389879499, 42.92651980263846, 41.68495314461844, 27.1330246925354, 24.23530626296997, 40.76945502417428, 46.52228900364467, 11.600271156855992, 0.08467604060258184, 0.02693651370438082, 0.2688530534505844, 0.2692457895193781, 0.17902218231133052, 0.15386384086949484, 0.046229842717626264, 0.02376011316664517, 1.325669607945851, 11.979687094688416, 27.522879430225917, 42.8454065322876, 59.137556484767366, 58.409864698137554, 60.914634704589844, 60.67065565926688, 60.08885519845145, 57.73901612418038, 61.49102251870291, 54.964708123888286, 57.150514125823975, 51.67739725112915, 52.54684271131243, 53.013011251177105, 54.30962153843471, 56.49890511376517, 57.94221271787371, 58.585119111197336, 55.58280944824219, 55.844909395490376, 55.17771904809134, 50.497711249760215, 52.38165623801095, 57.211175373622346, 61.15855121612549, 59.96634456089565, 61.88199765341622, 55.93748719351632, 54.60683420726231, 32.28704902103969, 31.967956474849156, 50.12498208454677, 51.903974533081055, 50.37487752096993, 58.333906991141184, 62.69827202388218, 59.59139197213309, 56.01946551459176, 53.43230029514858, 53.37400490897042, 45.48980753762381, 45.553060463496614, 52.511757782527376, 61.3663718359811, 59.22514547620501, 59.92744854518345, 59.06024387904576, 60.766895157950266, 57.66439247131348, 57.26612172807966, 57.81044707979475, 56.19960798536028, 55.129727840423584, 55.04953520638602, 57.49094458988735, 59.31299155099051, 57.76102801731655, 57.218575205121724, 58.0851024218968, 56.19377844674246, 56.858957290649414, 47.57653570175171, 18.37124378340585, 1.4143196110214507, 0.28034521107162746, 0.06333179878337042, 0.3837630402828966, 2.4705451343740736, 1.5798001885414124, 7.631078839302063, 4.324478464467185, 0.45449475198984146, 0.00833529295466308, 0.23374462021248682, 1.6560236641338892, 23.6025390284402, 47.77695996420724, 23.360284873417445, 18.27537601334708, 26.386081184659684, 31.711661747523717, 15.017893757138934, 0.37682781528149334, 0.019671966820689182, 0.016730636258476546, 0.030554978110428368, 0.07398723451686756, 0.022681703890806863, 0.012812888715416193, 0.04396314899037991, 0.06454684465591397, 0.03768918689872537, 0.04574662400409579, 0.05244603094511798, 0.01966599910520017, 0.006909460602660796, 0.010659489132064794, 0.03624969521271331, 0.0763293474114367, 0.03644750852669988, 0.011827366642786987, 0.036992521424378665, 0.03577083269400256, 0.030421425455382893, 0.06256130191364459, 0.07047117461583444, 0.029939282219856977, 0.010963717093026, 0.015407309767657092, 0.047683909335838895, 0.03527354794953551, 0.021731251052447727, 0.03133373614400625, 0.02718205008256648, 0.03742563371945705, 0.04000796497400318, 0.007662681546727461, 0.05968873069754668, 0.02441104198805988, 0.032978603416787725, 0.08323848952672311, 0.03457591217011213, 0.03217949951067567, 0.07358477504125663, 0.04137038865259715, 0.02662223155078079, 0.039890815903033526, 0.014228048135659524, 0.03805310897795217, 0.06978482965912138, 0.04092336638963648, 0.029287254171712056, 0.0037091264384798706, 0.020660113975671784, 0.042620138198669465, 0.016779163386672735, 0.00797238782979548, 0.06070263843451228, 0.05090635356360248, 0.01931932708248496, 0.015820454473474195, 0.004298689825061176, 0.033311709828142605, 0.04866536952821272, 0.04686436116961496, 0.023243410446281944, 0.036720065865665674, 0.04229052284998553, 0.040852910705975125, 0.007262937907528664, 0.023199005418324044, 0.012279531353020241, 0.0018227554059454373, 0.00917923275846988, 0.024751444347202778, 0.07833943955068078, 0.047951448908341784, 1.53794022330216, 21.364600692476543, 51.1321199962071, 42.818023681640625, 29.49468265260969, 36.882212366376606, 61.67471204485212, 48.490268979753765, 8.475410035678319, 0.12907490746251174, 0.027561500435695052, 0.16145244081105503, 0.20186781856630528, 0.5637013805764062, 0.3651855657143252, 0.08001687311168228, 0.048460743722638915, 3.0067185120923177, 17.593186242239817, 35.84022576468331, 50.23284591947283, 59.75082533700125, 58.273058141980854, 62.38634654453823, 63.83653286525181, 63.146097319466726, 59.96231460571289, 62.629637718200684, 57.89919989449637, 59.087571144104004, 55.079631328582764, 55.965853214263916, 54.589130197252544, 55.04438311713082, 58.12572506495884, 59.51632363455636, 60.24427250453404, 55.708981786455425, 57.73202623639788, 54.50088112694876, 51.52743428094046, 51.69099487577166, 54.341454710279194, 60.250393867492676, 59.765242849077495, 60.798030035836355, 57.41497993469238, 57.97504990441458, 35.26275403159005, 27.38107364518302, 54.35851601191929, 50.907939842769075, 55.09253065926688, 61.15302045004708, 64.17846761431012, 60.16146387372698, 59.593080384390696, 54.413896628788535, 53.55682591029576, 45.83766562598092, 45.39242853437151, 53.39546094621931, 63.33217007773263, 61.44436536516462, 59.982992444719585, 59.7657014301845, 61.02228314535958, 59.469784600394114, 59.33202266693115, 58.55406066349575, 56.83764716557094, 55.94462299346924, 56.260092054094585, 58.958292961120605, 60.16560500008719, 60.060666356767925, 58.865715163094656, 58.79653889792306, 56.51153346470424, 57.77052967888968, 54.61850370679583, 27.39672793660845, 3.559739751475198, 0.3209921456873417, 0.5858036002942494, 2.2684272485119954, 5.3052449226379395, 4.013705517564501, 4.374035622392382, 2.073693126440048, 0.2882504425942898, 0.2275138231260436, 0.07057429158261844, 0.3259317991988999, 20.601268121174403, 53.72941221509661, 36.03764145714896, 18.062286921909877, 27.70299063410078, 38.29449626377651, 25.60716380391802, 1.6578793759856905, 0.05848541669547558, 0.0612696697935462, 0.03852227523124643, 0.021529668476432562, 0.09949698924486126, 0.02628935923400734, 0.071220229778971, 0.0190384458151779, 0.004861629193848265, 0.005729446644961301, 0.04680647534717407, 0.0221013613710446, 0.01967608043923974, 0.01441799892511751, 0.031929520424455404, 0.023750250660149113, 0.04839559079014829, 0.011355817883408495, 0.13534853367933206, 0.01683389232493937, 0.06502694210835866, 0.05963127235216754, 0.03218484636662262, 0.011582544422708452, 0.012557014008052647, 0.030608385601746183, 0.032414591538586786, 0.06333007530442306, 0.033943843229540756, 0.05532365046175463, 0.04381753198270287, 0.017689818449850594, 0.022394018613600304, 0.22983566139425549, 0.22365293172853334, 0.09816242621413299, 0.14273164607584476, 0.16057658780898365, 0.1275227586073535, 0.11963045996214662, 0.11442338222903864, 0.12108929668154035, 0.0978959926537105, 0.16471634352845804, 0.09153280659977879, 0.16053909196385316, 0.10812697080629212, 0.12917169369757175, 0.10994110203215054, 0.1133707912106599, 0.12159319035708904, 0.13158750906586647, 0.10994174664041825, 0.10705020358519894, 0.10108987734253917, 0.08186550784323897, 0.0881767181147422, 0.1003614632146699, 0.23262734445078032, 0.10615439486822911, 0.08867325647068874, 0.1924640695963587, 0.12028315636728491, 0.07189383184803383, 0.0902103011363319, 0.11865127964743546, 0.0879220367808427, 0.09012697025069169, 0.12845995117511066, 0.19638620556465217, 0.12000321995999132, 0.09185302084577934, 0.2880759505288941, 0.13432112309549535, 0.9640342188732964, 20.109827245984757, 60.689672878810335, 52.636200019291465, 38.50512048176357, 36.03757892336164, 50.85100282941546, 57.81391075679234, 15.856746298926216, 0.3391891249588558, 0.10732319857925177, 0.9434956695352281, 1.3226487700428282, 0.7473930780376706, 0.4765692874789238, 0.33601643091865946, 0.1538693370031459, 2.215024479797908, 14.422489592007228, 30.966734954289027, 48.557944434029714, 61.96127659933907, 57.6104153905596, 63.634187425885884, 65.80103179386684, 65.64036859784807, 64.05692277635846, 66.70647239685059, 61.81892885480608, 62.03903388977051, 56.45494038718087, 56.36928299495152, 57.36436925615583, 58.77454784938267, 60.76651995522635, 62.163163457598, 64.77819442749023, 59.29434258597237, 60.80310222080776, 58.56474699292864, 57.415153639657156, 56.45870631081717, 61.44401100703648, 65.68100166320801, 64.93813501085553, 63.92161355699812, 61.425855364118306, 59.07562024252755, 37.98426614488874, 40.30526672090803, 51.50778477532523, 55.34203004837036, 53.608249528067454, 59.93097128186907, 65.68104335239956, 61.65600749424526, 60.8093694959368, 58.211889675685335, 57.8343071937561, 48.07846661976406, 49.74971335274832, 57.403293064662385, 67.37143584660122, 63.19094099317278, 61.22468417031424, 62.24069145747593, 61.184092794145855, 59.49625028882708, 61.0806827545166, 58.892417090279714, 58.019344670431956, 56.51987130301339, 57.61609901700701, 60.107135908944265, 61.587248120989116, 59.35937772478376, 58.01335532324654, 58.99360370635986, 57.281373023986816, 57.77917323793684, 51.29271718433925, 22.748831238065446, 2.6461456545761655, 0.34381087124347687, 0.38204580385770115, 1.6491665520838328, 7.556587202208383, 5.202367722988129, 19.049459184919083, 11.939534323556082, 0.5491231371249471, 0.880202628672123, 0.2473147777574403, 2.3297008063111986, 32.43920414788382, 58.5695412499564, 33.62491423743111, 26.85094346318926, 38.558694566999165, 47.72846153804234, 26.22309034211295, 1.1337956466845103, 0.1224332574222769, 0.29934017466647284, 0.14259569479950837, 0.13912285757916315, 0.30062939120190485, 0.0998865904818688, 0.16898284958941595, 0.10594536537038428, 0.1422443493668522, 0.12976298268352235, 0.24732012461338723, 0.11052168373550687, 0.18366626596876554, 0.07165059061454875, 0.14478034685764993, 0.19993532369179384, 0.17143656792385237, 0.06381709381405797, 0.18394237543855393, 0.07580063292490584, 0.12433513679674693, 0.09646102679627282, 0.17401662947876112, 0.14871802127787045, 0.12635751041982854, 0.16483657993376255, 0.052505097418491326, 0.1202821114233562, 0.16299276958618844, 0.12455969117581844, 0.09943507292440959, 0.09842571815741913, 0.20069635499800953], [0.021678645928789462, 0.019458923788209046, 0.011830366615738188, 0.04216813209599682, 0.05879323410668543, 0.09522270717258964, 0.020594553922169974, 0.0213046136777848, 0.0653412938117981, 0.08012507909110614, 0.09902314788528851, 0.0647904658690095, 0.08930523041635752, 0.047300608296479495, 0.005738379982566195, 0.025785796344280243, 0.08134494934763227, 0.04198300738685897, 0.0548234887288085, 0.05467978858255914, 0.03542915977803724, 0.04935920211885657, 0.10752576163836888, 0.07203742342868022, 0.04250237505350794, 0.049231715566877804, 0.021334689742486392, 0.04080527415499091, 0.0265418014023453, 0.034805253613740206, 0.038336906249501874, 0.04204984647887094, 0.01922149590349623, 0.03642466225262199, 0.01814499161472278, 0.019861442635634115, 0.025206447878320302, 0.08069753194493906, 0.05102789614881788, 0.06178404004978282, 0.08601926852549825, 0.01727239558074091, 0.1602021993270942, 7.8304426329476495, 41.443802016122, 48.11809914452689, 31.599531718662806, 30.832485335213796, 37.33229235240391, 52.11332723072597, 30.225383009229386, 1.7855526336601801, 0.03176527423784137, 0.36291114347321646, 0.36971538407461985, 0.2541939557663032, 0.06171678365873439, 0.08474951915975128, 0.04092958516308239, 0.3817410059273243, 0.7518635381545339, 5.87208982024874, 20.927131686891826, 40.427388259342735, 56.9634234564645, 64.74560737609863, 62.41999667031424, 61.38452747889927, 63.17795481000628, 60.35836887359619, 59.443381445748464, 59.90677070617676, 58.44928182874407, 57.97001593453543, 59.540968894958496, 59.476816177368164, 60.81651224408831, 57.68147461754935, 57.605120863233296, 55.52363164084298, 55.31267043522426, 56.688302585056846, 55.60014172962734, 58.74356583186558, 59.418180329459055, 61.34023271288191, 54.53446871893746, 51.97352252687727, 56.19211087908064, 36.98201976503645, 50.112378052302766, 40.02108192443848, 67.69429779052734, 55.62356410707746, 54.91384383610317, 50.57480846132551, 64.1906408582415, 61.71002973828997, 61.90055629185268, 57.59803022657122, 52.60824046816145, 46.165450368608745, 50.26520020621163, 52.90612016405378, 58.47755404881069, 63.53154863630022, 64.19074508122036, 60.62098298754011, 63.90835639408657, 63.390257017953054, 60.55469022478376, 62.99978910173689, 62.827869824000764, 60.518392835344585, 62.898803983415874, 60.189715249197825, 60.53873021262032, 59.41462285178048, 59.05025931767055, 50.524312428065706, 25.78826686314174, 3.4527470469474792, 0.1189785370869296, 0.056869519475315294, 0.9858437457254955, 0.5334021321364811, 1.9195746992315565, 3.402100758893149, 3.1494199633598328, 1.2708381158964974, 2.524887429816382, 0.7770799621939659, 0.09537630714476109, 5.018220918519156, 31.34128107343401, 45.203340257917134, 24.016168764659337, 17.095271383013042, 30.46621104649135, 27.54077798979623, 9.53900032384055, 0.11126923933625221, 0.0763146367722324, 0.019805621255987456, 0.06200375647417136, 0.0173236589013998, 0.07902024087629148, 0.06148351010467325, 0.02446993882767856, 0.04865511007873075, 0.04710464059774365, 0.07930088974535465, 0.025698221222098385, 0.05632593150117567, 0.01675636800272124, 0.01352600272678371, 0.09320100529917649, 0.04694217895822866, 0.06364585193140165, 0.035235634805368524, 0.07241684664040804, 0.08435147694711174, 0.02500012912787497, 0.08209709863045386, 0.02985961203064237, 0.028474270831793547, 0.08883672912738153, 0.040526067172842364, 0.06048006537769522, 0.07503907914672579, 0.031733179531459293, 0.08423927439642803, 0.04163145500102213, 0.025727269306246723, 0.018888301282588924, 0.017600752246965255, 0.05343942317579474, 0.058364338906747956, 0.022975456967417682, 0.035276913483228, 0.04383100090282304, 0.0866292172244617, 0.054525401509766064, 0.011700999673588999, 0.02415708329395524, 0.0369387373461255, 0.03366703147600804, 0.04549685526373131, 0.04576280027894037, 0.054630316594349485, 0.044275013862976005, 0.01959514308587781, 0.14272935262748174, 0.04482441348955035, 0.08960571286401578, 0.04462204042023846, 0.04474262287840247, 0.024280573274674158, 0.03319120879418083, 0.01895809030559446, 0.035171041664268286, 0.06449701304414443, 0.048958401661366224, 0.10688217795853104, 0.07367753077830587, 0.024334153792421733, 0.012663719576916524, 0.02265624695324472, 0.015639614712979113, 0.023032801658181206, 0.016436189379809157, 0.046916991738336425, 0.028543681571526185, 0.02745473464684827, 0.029834204286869084, 0.027775515469589403, 0.056330389476248195, 0.07364810271454708, 0.6090446731873921, 14.543266654014587, 50.218341554914204, 47.64237683159964, 25.23787225995745, 28.967917135783605, 56.546872002737864, 68.77643803187779, 21.80157811301095, 0.5147032269409725, 0.058703708196324964, 0.26196551589029177, 0.14032843788819654, 0.3999275086181504, 0.24017813642110142, 0.28584224038890427, 0.030341073338474547, 0.8580028627599988, 2.532723912170955, 10.237715516771589, 29.83061763218471, 47.763966832842144, 59.940149852207725, 65.46512808118547, 64.64820752825055, 61.15943363734654, 64.62620258331299, 63.038212639944895, 62.41636971064976, 61.65487493787493, 58.981256757463726, 57.66238096782139, 60.91359942299979, 60.99654006958008, 60.960624831063406, 59.26647336142403, 59.30266652788435, 58.796212332589285, 57.87320668356759, 57.54361193520682, 58.33881936754499, 61.144390787397114, 63.85304178510393, 63.07082053593227, 59.357689312526155, 54.11260536738804, 57.65643678392683, 40.32928316933768, 47.72804812022618, 45.60205568586077, 68.3052876336234, 54.73970808301653, 53.9704521724156, 53.81217220851353, 64.80587605067662, 61.616548674447195, 63.611710003444124, 60.14956855773926, 54.23961843763079, 47.13647154399327, 51.27968583788191, 57.266708850860596, 60.69859436580113, 65.16923904418945, 66.49250956944057, 61.52051762172154, 64.63200432913644, 63.00374262673514, 60.98194885253906, 63.520910944257466, 63.099370683942524, 60.45396218981062, 62.82948875427246, 61.389314787728445, 60.25806467873709, 58.281719071524485, 58.50834846496582, 54.363338061741416, 34.06525979723249, 6.488565266132355, 0.21795245047126496, 0.10712691875440733, 2.722617094005857, 1.805420573268618, 3.6871940323284695, 4.5190810050283154, 1.9850649450506483, 0.44450628225292477, 0.8287337933267865, 0.08946655890239136, 0.046460887284151146, 1.055917305605752, 33.16470725195748, 51.62626198359898, 33.34466906956264, 16.83844859259469, 29.707815170288086, 35.86815752301897, 16.398605040141515, 0.299893750676087, 0.036484084956880124, 0.0038767122896388173, 0.030822731421462128, 0.016709913799007024, 0.09813027043959924, 0.046076459876660786, 0.02230097958818078, 0.02448779617303184, 0.043838454610002894, 0.02540024426499648, 0.017838178435340524, 0.034913866714175255, 0.011503521386267883, 0.037404575385153294, 0.0903546323201486, 0.04905536092285599, 0.008784877535487925, 0.00783914645268981, 0.05741684617740767, 0.053086605322148116, 0.05777200497686863, 0.04674455224137221, 0.02727640207324709, 0.03918862376095993, 0.05613464908674359, 0.02012038686578827, 0.003337805995085676, 0.07077492760228259, 0.05065068156857576, 0.05277707461001618, 0.04064450206767235, 0.033101363972361596, 0.01840988320431539, 0.04020436693515096, 0.0983703632705978, 0.09035101572849921, 0.10905579703726939, 0.11277711378144366, 0.13619602391762392, 0.1853538639843464, 0.14189653231629304, 0.1728805447263377, 0.18046298356992857, 0.10874221886375121, 0.1687092642698969, 0.17256038476313862, 0.24383877856390818, 0.17719095200300217, 0.11189656531704323, 0.0840149371485625, 0.25031767519457, 0.18264794775417872, 0.17450805168066705, 0.13122629773403915, 0.14000156042831285, 0.09081735249076571, 0.14045759024364607, 0.25369555822440554, 0.15926313400268555, 0.1345964726060629, 0.17259709350764751, 0.1642561610788107, 0.19560772233775683, 0.12386092224291392, 0.10500753497970955, 0.17267405294946261, 0.10908259238515582, 0.10307401551731996, 0.20079624892345496, 0.09095001287226166, 0.1844666794474636, 0.09091616754553147, 0.13574629090726376, 0.09218588298452751, 0.2000770289450884, 0.09759006835520267, 0.5135029256343842, 14.529179181371417, 57.266632420676096, 62.60507583618164, 40.930684498378206, 39.219232014247346, 46.653703757694785, 64.88973385947091, 36.799897057669504, 2.6883025467395782, 0.11060762019561869, 1.3081551534788949, 1.628564600433622, 0.5534529505031449, 0.1764917080955846, 0.42304457245128496, 0.1471260559878179, 0.8227657792823655, 2.310167900153569, 7.716592056410653, 25.153008699417114, 44.94164678028652, 60.649046761649, 69.7346363067627, 67.96987724304199, 63.01310185023716, 66.91955280303955, 65.02228464399064, 65.27888856615338, 65.98390143258231, 63.3859143938337, 62.11463029044015, 65.42918504987443, 63.71261174338204, 64.94857120513916, 60.669523102896555, 60.265374183654785, 60.781548908778596, 59.980025563921245, 61.39963286263602, 61.16401250021798, 60.908221517290386, 64.56020164489746, 65.1936480658395, 57.78334910529, 53.72522245134626, 60.95985358101981, 47.757418155670166, 51.96175575256348, 48.43135520390102, 68.7447681427002, 62.06579140254429, 55.3436906678336, 55.41288777760097, 67.10216535840715, 68.4534718649728, 66.03038488115583, 62.26382201058524, 57.716236455099924, 49.11881692068917, 52.3942984853472, 56.901421206338064, 62.62643459865025, 66.92515305110386, 70.17486027308873, 62.87103203364781, 64.04780673980713, 64.20314066750663, 63.626530511038645, 64.5432619367327, 65.23627526419503, 64.60795661381313, 65.27789497375488, 63.38020992279053, 61.36755997794015, 61.23408508300781, 61.51281206948416, 52.74410554340908, 31.019815717424663, 4.6581287894930155, 0.18180949560233525, 0.1559001516018595, 2.7761412390640805, 2.005676341908319, 6.2609956945691785, 9.718109250068665, 11.051071643829346, 6.828472878251757, 9.3747136422566, 1.9113984065396445, 0.35478462811027256, 7.678705266543797, 41.25091307503836, 56.181320326668875, 34.648571491241455, 26.04099542754037, 40.22524779183524, 43.01977852412632, 15.49802643912179, 0.2786819860339165, 0.2874209742460932, 0.07582645118236542, 0.16895013063081674, 0.1268633854176317, 0.23230159335902759, 0.11498819477856159, 0.1353974560541766, 0.07870880008808204, 0.16418971892978462, 0.13109057715960912, 0.09787055437586137, 0.15348386125905172, 0.10270751839769737, 0.08717433868774346, 0.1977710412549121, 0.14175766333937645, 0.08964716456830502, 0.06189572012850216, 0.14023740563009465, 0.1281036931489195, 0.1306758158441101, 0.12130570864038807, 0.08274925220757723, 0.08258715019162212, 0.19556156838578836, 0.12156090566090175, 0.15362844350082533, 0.1546144498778241, 0.1023002616795046, 0.12154987268149853, 0.07737408099429947, 0.13532410641866072, 0.0850467582100204, 0.10805062883134399], [0.050923992081412246, 0.04905754919829113, 0.04061866345416222, 0.012066659650632312, 0.027594935248738954, 0.04360203265345522, 0.02385254999223564, 0.0204573846754751, 0.057226741021232944, 0.03913864287148629, 0.06172515678086451, 0.021381552763549343, 0.06044037786445447, 0.06139916820185525, 0.03767653561330267, 0.03826591113050069, 0.008169586221421403, 0.06933971068688802, 0.05214503620352064, 0.03365864139050245, 0.08641094607966286, 0.05630600292767797, 0.025036362897870795, 0.038990644205893786, 0.06676661090127059, 0.019489710618342673, 0.023621666577777693, 0.029669849534652064, 0.09875848530126469, 0.059694328611450534, 0.08329179523778812, 0.03977333434990474, 0.021937396776463305, 0.002093566153364788, 0.020996989649055258, 0.0754715705822621, 0.05157970796738352, 0.09321527489061866, 0.08151986889008965, 0.03546008401151214, 0.03184120909177831, 0.049220869184604714, 0.012156998106677617, 0.08860598650893994, 4.2456042511122565, 37.954340253557476, 45.12944616590227, 43.437837736947195, 25.43204661778041, 25.113254581178936, 40.167105266026084, 44.10925258908953, 9.264547348022461, 0.057598293226744444, 0.0870068898158414, 0.2621018742876393, 0.1976272596844605, 0.14044468450759137, 0.0417099886440805, 0.16733922064304352, 0.07115139918667929, 0.2647987524313586, 0.7701204184974942, 5.474203833511897, 21.88406538963318, 47.00898947034563, 64.08374282291958, 64.32135037013462, 63.865409578595845, 63.82376902444022, 61.456552505493164, 60.52311066218785, 60.11406326293945, 60.19259180341448, 60.149763107299805, 60.6129925591605, 56.311150891440256, 60.390761375427246, 62.972885676792686, 61.32730211530413, 59.385113852364675, 59.42155020577567, 59.80456965310233, 63.38619926997593, 63.73268508911133, 62.235855511256624, 63.11223874773298, 65.38078389848981, 40.023319244384766, 28.34175590106419, 44.26189408983503, 31.836051872798375, 57.83687802723476, 59.114293915884836, 62.93901320866176, 59.98008809770857, 54.26148789269583, 63.58249977656773, 59.961056981767925, 62.29460253034319, 58.482480321611675, 55.176548276628765, 58.061353479112896, 60.36075210571289, 57.85431105749947, 59.10289887019566, 60.92039476122175, 61.84567941938128, 60.3167074748448, 60.993621826171875, 63.31543186732701, 61.82969856262207, 62.30680356706892, 60.75923824310303, 61.768707275390625, 63.451630456107004, 59.58476339067732, 53.1691928591047, 35.76001923424857, 11.684716088431221, 0.15977048820682935, 0.05163085932976433, 0.3083761440856116, 0.24076696911028453, 0.6721431102071489, 2.330238857439586, 4.815046472208841, 3.8499486361231123, 1.8369964446340288, 0.29728985897132326, 0.15818661105419907, 0.6887571215629578, 11.654078875269208, 39.325845173427034, 31.48822157723563, 23.606258051736013, 23.54528934614999, 35.226873534066335, 30.32620484488351, 5.370307419981275, 0.02937951118552259, 0.045499426911451986, 0.051678601053676436, 0.07326643355190754, 0.04857933468052319, 0.029824229822094952, 0.018817519902118614, 0.012526935398844736, 0.007176385676887418, 0.040148330120635886, 0.040813491214066744, 0.026075888724465455, 0.0401651883231742, 0.018603786460257003, 0.04145920888653823, 0.026046192639374306, 0.013351832117353166, 0.02853660105860659, 0.07890506634222609, 0.035860155043857436, 0.025126869291333214, 0.011122161805230592, 0.062309599348476956, 0.0040274420586813775, 0.029798526915588548, 0.04008774372882076, 0.03033013196129884, 0.0873384288113032, 0.016431551592956697, 0.026355489256924818, 0.05389806195827467, 0.04546626690509064, 0.05254499867026295, 0.04139741470238992, 0.0522279905022255, 0.07006817231220858, 0.02514559855418546, 0.04908292640798858, 0.023410993328850185, 0.053492464258202484, 0.07889368052461318, 0.01723143072532756, 0.044784719190959416, 0.023045117068769674, 0.03993692235755069, 0.04915882733517459, 0.027658094984612296, 0.08432339238268988, 0.05556651510830436, 0.11669445250715528, 0.020468533005831496, 0.07263383535402161, 0.040919040728892596, 0.059610936657658646, 0.01313774922995695, 0.027093319754515375, 0.03643335089353578, 0.006958660752778607, 0.01644326141104102, 0.0701329791918397, 0.037243467423000505, 0.02639389264264277, 0.022421974256368618, 0.012714216153004339, 0.019474051726449813, 0.039967368223837445, 0.03253550647890993, 0.03759326918848923, 0.02509140226590846, 0.033870897322360954, 0.04904992585735662, 0.06343306334955351, 0.014427600195631385, 0.062369330786168575, 0.12175350104059492, 0.0747966928673642, 0.023842733286853348, 0.03661866559247885, 0.06158046597348792, 0.1602761053613254, 9.606434328215462, 48.457487378801616, 47.743507862091064, 35.29524033410208, 22.63318542071751, 35.449681418282644, 67.58416189466203, 43.72382211685181, 3.5940158665180206, 0.10860814034406628, 0.15234860431935104, 0.09718980733305216, 0.4051830880343914, 0.26614059614283697, 0.38540376509938923, 0.4131773704929011, 0.0782231047217335, 0.45692331024578636, 1.6746838114091327, 8.522321666990008, 29.33391523361206, 53.820047991616384, 66.2752880368914, 64.47903278895787, 65.30083097730363, 64.73052978515625, 62.874547822134836, 61.41316795349121, 62.587955474853516, 61.79696559906006, 62.578262737819124, 62.21628243582589, 59.46962479182652, 60.56209005628313, 63.48302241734096, 60.49894482748849, 59.47108391353062, 59.69227286747524, 61.05184078216553, 62.125809941973, 65.8998282296317, 62.571001870291575, 59.8930549621582, 63.61354432787214, 48.37576961517334, 31.64719636099679, 46.41061755589077, 35.46909815924508, 61.27383572714669, 61.152339526585166, 62.54161099025181, 57.19644866670881, 56.28563015801566, 63.552990777151926, 62.59377806527274, 63.56860337938581, 60.88074139186314, 55.50939130783081, 57.06589896338326, 60.589174134390696, 60.48880740574428, 61.17588002341134, 62.95968409946987, 62.6529141834804, 60.849773270743235, 61.72569792611258, 62.299938746861045, 61.116778646196636, 63.564385822841096, 59.96136270250593, 62.852174622671946, 61.80460861751011, 59.4402756009783, 55.81861046382359, 43.59870590482439, 17.470804146357946, 1.1352576996598924, 0.0972701119525092, 0.8195536487868854, 1.6870622443301337, 4.318896455424173, 3.4040777385234833, 4.594904959201813, 1.2128312970910753, 0.7335077545472554, 0.3333127945661545, 0.10355765492256198, 0.23163597764713423, 6.280662136418479, 49.123659815107075, 46.867989676339285, 31.862222262791224, 23.22475504875183, 34.423651354653494, 37.61730745860508, 10.955282909529549, 0.03244473545679024, 0.07732127739914826, 0.07075828992362533, 0.052687406207301786, 0.03916070883029273, 0.04404027806594968, 0.026696514171947325, 0.02503966397073652, 0.03973592671432665, 0.030629525360252177, 0.01505817296648664, 0.007367178697937301, 0.03907895893124597, 0.021114174343113388, 0.05391684041491576, 0.020112639692212855, 0.033087725418486764, 0.05949738382228783, 0.04698666371405125, 0.01328452568434711, 0.04757619868697865, 0.05201330202232514, 0.006464145703440798, 0.011063947741474425, 0.04431640110643847, 0.025453728091503893, 0.009921003000012465, 0.03318502055481076, 0.061914753035775254, 0.050722548605075905, 0.03588986469964896, 0.10796153718339545, 0.06340243427881173, 0.04290980140545538, 0.02827281887376947, 0.036503243393131664, 0.10114728140511683, 0.11472933366894722, 0.1267164418739932, 0.13906349933573178, 0.12505711162728922, 0.110173405281135, 0.16236809667732033, 0.07478768870766674, 0.08562527038156986, 0.13063575513660908, 0.2144004282142435, 0.10071979077266795, 0.13847853429615498, 0.1547809216592993, 0.12612997048667499, 0.15997057461312839, 0.17118797983442033, 0.21636775907661232, 0.08139249429638896, 0.17598136833735875, 0.14469198802752153, 0.14758995680936746, 0.15821821721536772, 0.16045876698834555, 0.1834638046899012, 0.09564398242426769, 0.12593684584966727, 0.10466188245585986, 0.16996905952692032, 0.15272141859999724, 0.20948761754802295, 0.11369979927050215, 0.14762153582913534, 0.09257230867764779, 0.13465124395276817, 0.2478428137089525, 0.17639788027320588, 0.12724289005356176, 0.16455736277358873, 0.179044031138931, 0.08750915500734534, 0.12530405766197614, 0.11669289187661239, 0.1898746985409941, 7.830242003713336, 53.14902918679373, 60.51134736197335, 53.3893916947501, 35.35119417735508, 31.43362958090646, 51.112870012010845, 53.88461760112217, 11.55999505519867, 0.36275071065340725, 0.7226489686540195, 1.5189197467906135, 0.8077561504074505, 0.30114423643265453, 0.6156818313258035, 0.6877453444259507, 0.20112641049282892, 0.6138833335467747, 1.2873289052929198, 6.754088503973825, 24.860411371503556, 50.16709164210728, 68.06696442195347, 68.08691270010812, 67.21192605154855, 68.11751951490129, 67.72614138466972, 64.4451116834368, 63.87194783346993, 64.32819434574672, 64.31985650743756, 63.36280468532017, 59.77264962877546, 62.58694103785923, 67.57534463065011, 64.055741582598, 64.32296930040631, 63.012872559683665, 65.76637417929513, 66.88879312787736, 68.89120142800468, 63.10950810568673, 65.30328369140625, 64.8631500516619, 49.65887260437012, 34.55743197032383, 47.458958285195486, 41.69979797090803, 56.52959530694144, 60.71704183306013, 64.74883134024483, 60.90395532335554, 59.76397132873535, 66.55555057525635, 63.91228212629046, 66.52103192465646, 65.79284681592668, 61.48033618927002, 62.50684220450265, 67.65237236022949, 63.89765616825649, 62.705505098615376, 64.7543204171317, 64.89295782361711, 61.67646299089704, 60.62216418130057, 62.108953612191335, 60.719765526907786, 61.538179942539756, 59.715549332754954, 63.00516700744629, 62.47841017586844, 60.52566759926932, 54.52120113372803, 38.100384439740864, 14.862888131822858, 0.5574552757399422, 0.22170183142381056, 0.5589554895247731, 0.7448386922478676, 6.127282823835101, 8.300755773271833, 14.707799128123693, 9.763989073889595, 7.632456319672721, 2.5192346360002245, 0.3873663055045264, 1.1395932670150484, 15.644209589276995, 49.35874169213431, 39.90195505959647, 35.367404324667795, 33.29253673553467, 45.703179768153596, 42.66084153311593, 10.01999545097351, 0.10528439762336866, 0.11333473385976893, 0.15857660584151745, 0.15961713929261478, 0.15023086938474858, 0.10930714676422731, 0.12875028273888997, 0.1188835014722177, 0.18662581858890398, 0.15133857780269214, 0.10819293119545494, 0.2110550877239023, 0.1147117731826646, 0.2332728212433202, 0.10484795711402382, 0.08044761392687048, 0.10373951587826014, 0.14573664697153227, 0.0980372161471418, 0.1556404083967209, 0.20964019293231623, 0.1530892252922058, 0.16063697742564337, 0.061246477466608794, 0.1741478717220681, 0.12587786758584635, 0.10098300129175186, 0.1455743821071727, 0.13155774851994856, 0.1253642165767295, 0.12973061656313284, 0.1491827770535435, 0.2017095706292561, 0.06581573228218726, 0.1015119736215898, 0.1422034879880292], [0.10917799440877778, 0.048452122935226986, 0.04234865973038333, 0.06283586432359048, 0.026399286996041025, 0.09291656341935907, 0.050256412010639906, 0.036755085057978115, 0.03650957751753075, 0.0135248653324587, 0.022410540941304395, 0.022102543718314598, 0.029582549219152758, 0.027564971142315438, 0.0491054096658315, 0.06566756737551518, 0.044939133405153237, 0.02452784839884511, 0.05125548018674765, 0.026540893861757855, 0.032901470948542864, 0.016028681603659476, 0.05327305317457233, 0.017381785603772317, 0.10781590999769312, 0.049523349917892895, 0.024530404779527868, 0.02479831754629101, 0.035716777201741934, 0.03250899611573134, 0.028283409109073024, 0.043334503258977614, 0.020454002178407142, 0.07955592391746384, 0.03289928945845791, 0.07676462084054947, 0.04968619153701833, 0.03304347136457052, 0.0236364213217582, 0.02097595506347716, 0.054882195578621965, 0.03423708910122514, 0.029737088962325027, 0.07899429369717836, 0.01896642441196101, 2.404846008334841, 26.157240527016775, 45.96675968170166, 45.36141177586147, 37.70351723262242, 30.163981778281077, 35.79148415156773, 55.57169580459595, 25.497361421585083, 1.2455480843782425, 0.23510098457336426, 0.568117612174579, 0.45051012294633047, 0.2740850198481764, 0.08679104104105916, 0.14278557603912695, 0.1086567302367517, 0.15280888176390103, 0.095914629687156, 1.0433225014380045, 9.35142936025347, 31.27331379481724, 52.941555976867676, 62.1650116784232, 69.06247452327183, 66.16296345846993, 66.93837547302246, 64.74188314165387, 65.28270312717983, 63.22375038691929, 62.889757428850444, 58.799033301217214, 60.63666507175991, 60.53781999860491, 60.21461064474923, 58.0098534311567, 61.35180146353585, 65.66538211277553, 64.12163134983608, 62.2334931237357, 61.01136752537319, 57.820424692971365, 47.88885028021676, 33.63329029083252, 27.18653276988438, 41.934066908700125, 31.918096201760427, 54.37896456037249, 71.68512071881975, 54.585041182381765, 68.77306120736259, 57.165341581617085, 59.009598459516255, 68.18566744668144, 64.85352679661342, 64.69781071799142, 63.2030725479126, 59.696837833949495, 60.82555185045515, 61.43691689627511, 65.33824702671596, 64.55714443751744, 64.64469868796212, 63.70423221588135, 61.55165249960763, 64.04820278712681, 69.22784164973667, 67.94545432499477, 64.80836350577218, 65.27931240626744, 57.65646457672119, 47.63446978160313, 26.25434681347438, 4.878160434109824, 0.2089452373662165, 0.1571379080414772, 0.20810635095196112, 0.28119131709848133, 2.516271663563592, 3.7423879163605824, 1.4136061178786414, 3.1387112694127217, 0.7653002142906189, 0.07487058533089501, 0.3694314850228173, 1.985788209097726, 26.243170636040823, 40.62397364207676, 22.44537387575422, 21.76304166657584, 27.127387966428483, 38.29124450683594, 23.668889113834926, 2.962583554642541, 0.014396579270916325, 0.038573463913053274, 0.0427672140566366, 0.013595432974398136, 0.048546066108558855, 0.12025406078568526, 0.043112917470612695, 0.07636817318520375, 0.03522219981199928, 0.017113255370142202, 0.12666798090296133, 0.04725856287404895, 0.06269128886716706, 0.00399797285873709, 0.05222190065043313, 0.044947757585240264, 0.04978839587420225, 0.03811764444357582, 0.03069358245868768, 0.06135304817663772, 0.03352568923894848, 0.047268805360155444, 0.061858203927321095, 0.07249742267387253, 0.040047269114958386, 0.029892046004533768, 0.029241517518780062, 0.03580781624519399, 0.061060429949845584, 0.04770886246114969, 0.0975679616842951, 0.023727328050881624, 0.02079177860702787, 0.018538297652932148, 0.07373925710895232, 0.03892702476254531, 0.04214089230767318, 0.09876811371317931, 0.04763624903612903, 0.06980599995170321, 0.06212258831198726, 0.03564046236819454, 0.06911434885114431, 0.03266850273524012, 0.028556332856948887, 0.04899878128032599, 0.041219282296619246, 0.028646364275898253, 0.031368388927408626, 0.04058469259845359, 0.04018167672412736, 0.018694557482376695, 0.0230715884161847, 0.021597204763176184, 0.04193165585664766, 0.06589755682008606, 0.0267929679248482, 0.042603792290070226, 0.042541906503694396, 0.01320086486105408, 0.05503033673656838, 0.03978297972519483, 0.06493806759161608, 0.06815825229776756, 0.020587827943797623, 0.08963819433535848, 0.04655866418033838, 0.014573760031323348, 0.04979247726233942, 0.008505146385037472, 0.051989705967051644, 0.041165959622178755, 0.025555018102750182, 0.05337122701374548, 0.042314336036465, 0.0458172052167356, 0.029466445092111826, 0.008445739795986031, 0.06128453649580479, 0.007377062408652688, 0.030325735054377998, 0.015133685432374477, 5.712955662182399, 37.11458444595337, 54.181277888161794, 36.75778750010899, 24.106488398143224, 26.992407049451554, 56.3926602091108, 66.4989366531372, 16.167005947657994, 0.3164446311337607, 0.13078131446880953, 0.15780409372278623, 0.2428325382726533, 0.5255683639219829, 0.8732729947992733, 0.6370374996747289, 0.3798819014004299, 0.23831949329801969, 0.27156456080930574, 2.6757113252367293, 14.069737366267614, 39.55333266939436, 57.78256743294852, 64.3911519731794, 70.0794267654419, 66.82143034253801, 66.18125111716134, 65.2661247253418, 63.95102528163365, 63.56396893092564, 62.661710602896555, 57.76004137311663, 59.051676750183105, 61.402717862810405, 60.61823150089809, 59.554705483572825, 63.38943713051932, 68.94300719669887, 67.21052251543317, 67.20053100585938, 65.14233561924526, 65.62549945286342, 53.36492708751133, 39.24983882904053, 31.662819385528564, 49.62297126225063, 39.37780727658953, 52.18572746004377, 71.63424600873674, 56.247967447553364, 69.63454750605992, 55.64407866341727, 65.40552643367222, 69.00688893454415, 66.74191515786308, 66.82555757250104, 65.22781235831124, 60.725782666887554, 63.358031272888184, 61.86559990474156, 67.055098261152, 66.91164575304303, 65.92006138392857, 64.00883429391044, 64.03177029745919, 63.39739281790597, 68.39812251499721, 66.84714562552315, 63.72914150782994, 64.32847227369035, 60.679340907505576, 50.52966601508004, 32.05232497623989, 8.125943439347402, 0.7112898038966315, 0.2932381363851683, 1.1818283264126097, 2.2481068074703217, 6.045119072709765, 4.621219524315425, 3.013410495860236, 0.605638644524983, 0.684803976544312, 0.44608607462474276, 0.19427141547203064, 0.4392978203083788, 22.014849594661168, 58.096066679273335, 33.715848786490305, 19.332834516252788, 27.02033359663827, 40.768975598471506, 32.59047685350691, 6.262652839933123, 0.07115471722292048, 0.07597063308847801, 0.05557494929858616, 0.013849061730849956, 0.006368041820158916, 0.07574143752987895, 0.03425370303115674, 0.07722329694245543, 0.055162959798638306, 0.03171178871499641, 0.03395019092464021, 0.029580737530652965, 0.020677341979795268, 0.042495548991220336, 0.09430882228272301, 0.025642993560593044, 0.02958853050534214, 0.060167050388242514, 0.021846081229991147, 0.0657469288312963, 0.05295847076922655, 0.04634779245991792, 0.03723376437223383, 0.02613640047742852, 0.10233596619218588, 0.029032365884631872, 0.04832209526960339, 0.03482780133240989, 0.016419147972815802, 0.09891906061342784, 0.03200739249587059, 0.027297302648159008, 0.06938718099679266, 0.042604972941002676, 0.037809840603066344, 0.016432716976851225, 0.05164430450115885, 0.25122954483543125, 0.15309142374566623, 0.10607750327991587, 0.16111408253865583, 0.14611816007111753, 0.20235226542821952, 0.15840817987918854, 0.11952166365725653, 0.16754597026322568, 0.08461011414016996, 0.10632603030119624, 0.13144508456545217, 0.11893665790557861, 0.12327986556504454, 0.1671193345849003, 0.12422282568046025, 0.16255434096923896, 0.15875546767243318, 0.27110709249973297, 0.09726524685642549, 0.127303917493139, 0.09337549736457211, 0.07129229019795146, 0.15966386321399892, 0.20915892161428928, 0.20338716703866208, 0.24280165135860443, 0.08409519427056823, 0.10628941655158997, 0.10349892093134777, 0.13660100075815404, 0.10406714651201453, 0.08445477033300058, 0.22852182760834694, 0.18100564873644284, 0.19377738769565309, 0.10808275746447699, 0.16649949284536497, 0.18697537268911088, 0.07408883835055999, 0.1778893545269966, 0.22639054911477224, 0.20821457728743553, 0.08636108054114239, 0.11595658638647624, 4.04693831716265, 39.64777953284127, 65.17959880828857, 56.177992139543804, 49.23197875704084, 37.726609570639475, 46.06213065556118, 67.84245422908238, 30.292367117745535, 2.087783856051309, 0.3692864142358303, 2.050062737294606, 1.5005415443863188, 0.5865425520709583, 0.5072130145771163, 0.27701710537075996, 0.2316935716995171, 0.28587755135127474, 0.22938500557626995, 2.224918063197817, 11.528215731893267, 36.288488796779085, 54.347214766911094, 64.2495893750872, 71.37105519430978, 70.76365062168666, 69.16058308737618, 68.77635465349469, 66.64362594059536, 67.32589735303605, 64.35563278198242, 58.20568493434361, 60.21895326886858, 62.38930647713797, 60.62933472224644, 60.38361167907715, 65.79969773973737, 70.20212500435966, 68.5404772077288, 65.7475654057094, 63.453172956194194, 64.7686823436192, 54.47963700975691, 48.451518876211985, 35.2334361076355, 53.24902418681553, 46.262777260371614, 56.58421162196568, 72.99302877698625, 58.40467439379011, 68.86483301435197, 59.050398281642366, 67.02121189662388, 70.90435859135219, 70.53532586778913, 68.86395059313092, 67.27603707994733, 63.69972283499581, 64.03436197553361, 65.20630073547363, 70.14703273773193, 70.22107969011579, 69.62193652561733, 64.76757063184465, 65.11290305001395, 64.76746640886579, 69.93420941489083, 70.59913117544991, 65.8765378679548, 67.12300995418003, 60.813156264168875, 50.507205963134766, 31.160506316593715, 6.568780047552926, 0.47161201919828144, 0.19092421579573834, 0.5371254980564117, 1.7215102187224796, 10.465339371136256, 8.995180453572955, 10.318063616752625, 6.575941468988146, 7.322086368288312, 0.9386180341243744, 0.5573115348815918, 2.5765937524182454, 33.188748019082205, 51.804090704236714, 31.543779373168945, 30.06184673309326, 36.64053317478725, 51.4654598236084, 34.96346385138375, 4.91754195519856, 0.14823065671537602, 0.16490991599857807, 0.18484873537506374, 0.14273906924894877, 0.09434952759849173, 0.17671533966703074, 0.12448362740022795, 0.1398929405425276, 0.1374108051615102, 0.2181616292468139, 0.16205283573695592, 0.15037239821893827, 0.14066927959876402, 0.13781936466693878, 0.18013801957879746, 0.1955684758722782, 0.2363774717918464, 0.21146014598863466, 0.14214684388467244, 0.18728546319263323, 0.10785107846770968, 0.09729637125773088, 0.19577519835105964, 0.1353770321501153, 0.20010564955217497, 0.15605660820645945, 0.10833963046648673, 0.15277585067919322, 0.1180916918175561, 0.17360330665750162, 0.18523817376366683, 0.12710552742438658, 0.11547429726592132, 0.08366167146180357, 0.22302870665277752, 0.1632429590182645, 0.19439708015748433], [0.04914587749434369, 0.019921901802133237, 0.038769764093948264, 0.06139599944331816, 0.04593208798074296, 0.01947266242599913, 0.04312237624877265, 0.05641510796600154, 0.14266291047845567, 0.049299854053450484, 0.00032848752276290076, 0.07336727742637907, 0.02201581676490605, 0.03715519680242453, 0.1239098853298596, 0.07404507962720734, 0.03115639083885721, 0.019145516944783073, 0.02239159624358373, 0.07026863191276789, 0.0522387351042458, 0.040084269629525285, 0.0728655754189406, 0.050043063637401373, 0.0284873970917293, 0.04675295250490308, 0.060406939658735476, 0.06119496308799301, 0.03103899410260575, 0.039385901032281775, 0.042911938790764124, 0.04734618549368211, 0.0032906575652305037, 0.047620564699172974, 0.042746885147477896, 0.013970061488050436, 0.041764193414045234, 0.04415886563115886, 0.06626053912831203, 0.09078921364354235, 0.012928045437937337, 0.039195008775485415, 0.03599525136607034, 0.21672774904540607, 0.022281293590952243, 0.045541085568921905, 0.3337594334568296, 18.288586275918142, 45.466093335832866, 47.83236142567226, 47.400044509342735, 26.881663186209543, 21.57758034978594, 50.08473811830793, 42.63898597444807, 6.3938304867063245, 0.20745440093534334, 0.3839504245136465, 1.0040723447288786, 0.5377388394304684, 2.396850151675088, 0.574186592229775, 0.21164288903985704, 0.05585565584312592, 0.03332330259893622, 0.02903957192652992, 1.7788253660712923, 12.914233701569692, 30.006250722067698, 51.87924936839512, 58.59210205078125, 62.7890293938773, 63.27135249546596, 64.18520736694336, 61.8428167615618, 63.44387626647949, 60.77154350280762, 60.35977240971157, 64.00978619711739, 68.20972211020333, 61.774717467171804, 65.04265676225934, 67.26450307028634, 71.44011334010533, 70.48403426579067, 67.48306560516357, 63.20632430485317, 54.562205927712576, 47.41574048995972, 30.751747267586843, 28.741315535136632, 32.67065559114729, 43.73480027062552, 67.6370654787336, 65.28485012054443, 63.83916623251778, 67.35128607068742, 56.37963581085205, 60.928176743643625, 73.14595862797329, 63.39405768258231, 67.61850684029716, 66.17260060991559, 69.58705656869071, 61.913507734026226, 64.02718448638916, 62.745429447719026, 64.15487848009381, 59.486814635140554, 55.74792296545846, 55.75631638935634, 51.319120338984895, 46.57530723299299, 40.38043928146362, 35.77231407165527, 25.953792061124528, 9.114292553492955, 0.9533476723091943, 0.0030355483301848707, 0.0702250971059714, 0.6899426579475403, 2.814926952123642, 3.9030050805636813, 7.01954790524074, 3.8887291380337308, 1.783943799989564, 0.9262359099728721, 0.5734556200248855, 0.18771175960344927, 11.178778665406362, 36.361045360565186, 30.951080662863596, 17.4096200466156, 26.92449188232422, 31.351025921957834, 38.170331954956055, 17.101364953177317, 0.7806883571403367, 0.15953905348266872, 0.03462908895952361, 0.10677074215241841, 0.026452633419207165, 0.11518517349447523, 0.10469464212656021, 0.030792841953890662, 0.014575442798169596, 0.06412238707499844, 0.0746459359569209, 0.028062495070376565, 0.008873517109480287, 0.03318987547286919, 0.03458308767793434, 0.05411876904379044, 0.10188263016087667, 0.09619530569761992, 0.013085189907412444, 0.08910278270819358, 0.09427806429032769, 0.04701844968699983, 0.104949079187853, 0.07356473111680575, 0.08637127213712249, 0.050664588143782954, 0.060437134467065334, 0.047587455582938025, 0.04035223667908992, 0.07167719597262995, 0.037771866390747685, 0.010161618302975382, 0.05052637056048427, 0.03267826685415847, 0.02400234168661492, 0.024788268442664827, 0.11665748591933932, 0.10145478669021811, 0.04107847270954933, 0.07536015513220004, 0.028852781413921287, 0.03782773017883301, 0.059219795146158764, 0.007947015709110668, 0.07456763301576887, 0.039286000321486166, 0.03576807784182685, 0.060576247716588635, 0.04111622979066201, 0.032044871377625635, 0.016353570955938528, 0.05244053481146693, 0.04290931286024196, 0.04198702431416937, 0.039231727698019574, 0.008450251205691268, 0.011621811244237636, 0.030094266403466463, 0.03861164507855262, 0.04353859302188669, 0.04073379388345139, 0.05422024056315422, 0.056254454622311253, 0.056000855551766496, 0.033965600454913716, 0.07353568981800761, 0.014950218045019677, 0.059328130047236166, 0.013822656540599252, 0.037696565967053175, 0.10303884026195322, 0.0389654875200774, 0.05446269130334258, 0.04551346919366291, 0.02023044863848814, 0.061429349439484734, 0.05075837525406054, 0.041216283171836815, 0.07916387316903897, 0.044735447370580265, 0.05168816500476428, 0.013302219333127141, 0.13050076737999916, 0.01303723529313824, 0.020412603060581853, 1.7655490956136157, 29.2969160761152, 54.79957028797695, 48.030392033713206, 36.722421169281006, 20.599166291100637, 38.95022555759975, 71.2618989944458, 38.08237470899309, 1.4058554023504257, 0.12114326735692364, 0.5013026488678796, 0.21938730776309967, 1.1406935794012887, 1.6492906425680434, 1.894034423998424, 1.58698408305645, 0.26070270793778555, 0.09998852679772036, 0.11218830823366131, 4.189878829887935, 19.730405228478567, 37.81855855669294, 56.942505904606406, 61.08185700007847, 62.923782757350374, 64.93748188018799, 64.5371961593628, 63.924594334193635, 63.681212833949495, 61.96610559735979, 60.92211096627371, 64.96622657775879, 64.54176807403564, 60.115411213466096, 62.47030162811279, 64.88062477111816, 69.1070055280413, 65.1731230872018, 63.863172258649556, 60.02651596069336, 55.284099442618235, 49.865088190351216, 31.099487236567906, 34.3923670904977, 37.16376379558018, 45.400398118155344, 68.95569460732597, 63.43142509460449, 63.37235151018415, 64.90761157444545, 57.040433815547395, 62.94049317496163, 71.81076499394008, 63.9632819039481, 67.00023528507778, 66.20368685041154, 68.44628742762974, 64.75883674621582, 65.15532875061035, 64.14399065290178, 66.58391312190464, 62.16287858145577, 59.83098670414516, 58.29378114427839, 55.57025752748762, 53.90612922395979, 48.03403288977486, 44.20218474524361, 32.33288628714425, 14.837264912469045, 3.038720177752631, 0.13553985341319016, 0.8135790665234838, 3.119838224990027, 3.012496156351907, 5.206464988844735, 7.024405564580645, 3.0589279276984076, 1.6486142788614546, 0.7760982034461839, 0.32891732613955227, 0.29486409627965515, 6.02957421541214, 44.44870335715157, 52.452708516802105, 22.166144881929668, 19.4209463596344, 28.743589333125524, 43.94402095249721, 25.220718894686016, 2.462672391108104, 0.0889090881017702, 0.027475089001070176, 0.03221452209566321, 0.020482675371957675, 0.04808851976745895, 0.08682933077216148, 0.02717364812269807, 0.02130222523451916, 0.05858537847442286, 0.07171927871448652, 0.01656553172506392, 0.07155803165265492, 0.014217201753386428, 0.03407039001051869, 0.04523687457133617, 0.1248114819505385, 0.10844519015933786, 0.027783140506861464, 0.07019099393593413, 0.09577392866568905, 0.05178424895607999, 0.05999460071325302, 0.0720844187640718, 0.07080671696790627, 0.07746030243911914, 0.03249247718070235, 0.013045568551336015, 0.07432410679757595, 0.06764798717839376, 0.04165678132059319, 0.08889197544859988, 0.055413960080061636, 0.01773866618584309, 0.010490935944419886, 0.07121193129569292, 0.052343765539782386, 0.06852369768811123, 0.030109255242028406, 0.14264560783548014, 0.10206303905163493, 0.11982429027557373, 0.2086078833256449, 0.10841635920639549, 0.14373848347791604, 0.10707136030708041, 0.2237234857997724, 0.16927512176334858, 0.12433386115091187, 0.12374733548079218, 0.1586575957813433, 0.10454581225556986, 0.1409946914230074, 0.1702784307833229, 0.18202596184398445, 0.10110931058547326, 0.13052091987005301, 0.10917213865156684, 0.22218623757362366, 0.13199268946690218, 0.14378066121467523, 0.10483773159129278, 0.17666221037507057, 0.07975069739456687, 0.1808850323515279, 0.24992113932967186, 0.11634569907827036, 0.15105195104011468, 0.1184419651648828, 0.15765924006700516, 0.14849164842494897, 0.12329165850366865, 0.19458678497799806, 0.1336318129407508, 0.14210537182433264, 0.18671112401144846, 0.11832140306276934, 0.16029012389481068, 0.20772413217595645, 0.11702746392360755, 0.1635344848036766, 0.06547592873019831, 0.2825791926256248, 0.1252740528434515, 0.09917978769434349, 1.1979128633226668, 28.618598188672745, 63.95320701599121, 62.92675658634731, 58.95840413229806, 36.00473478862217, 28.185744524002075, 61.50228554861886, 54.40150451660156, 9.895199724606105, 0.20398727697985514, 1.6509545189993722, 5.39427957364491, 4.041416236332484, 5.097581505775452, 2.071448641163962, 0.9958969205617905, 0.2008261994591781, 0.10359130347413675, 0.17469641300184385, 3.1561742637838637, 16.599335023335048, 33.84871571404593, 55.89390809195382, 60.6940849849156, 63.13519559587751, 65.03873103005546, 65.69816371372768, 63.31755106789725, 64.01161357334682, 62.881141662597656, 63.15248271397182, 65.53119155338833, 68.0750104359218, 61.3430814743042, 66.01666218893868, 69.28570624760219, 73.83691528865269, 71.33710629599435, 69.3229763848441, 70.44573579515729, 66.78759261540004, 57.54918786457607, 36.90114968163626, 38.85771376746041, 45.90199204853603, 46.15044573375157, 67.00864260537284, 67.27995586395264, 64.53748103550502, 63.92644950321743, 59.74222346714565, 65.89326913016183, 74.47634410858154, 68.47901344299316, 73.23754283360073, 70.55635806492397, 74.79793453216553, 67.9843225479126, 67.63796874455043, 64.89643887111119, 67.14764826638358, 62.63149288722447, 59.297809737069265, 56.84832654680525, 51.599264757973806, 48.58833932876587, 41.96302005222866, 38.631615911211284, 28.85467365809849, 11.150216358048574, 1.5625772327184677, 0.1563708513442959, 0.6951652605618749, 4.300760788576944, 6.558160594531468, 13.652280041149684, 20.493322644914898, 13.602659480912344, 9.57862068925585, 5.234290352889469, 1.2229240983724594, 0.34319231872047695, 15.28332883971078, 47.88724177224295, 41.84369168962751, 26.40211067880903, 36.73188461576189, 41.52054139545986, 52.9532220023019, 25.324132408414567, 1.7835868362869536, 0.2465842126735619, 0.08868454050804887, 0.1792650164238044, 0.12396813077586037, 0.19418469869664737, 0.25096586612718447, 0.09934609662741423, 0.12177691049873829, 0.16272442255701336, 0.23856023752263614, 0.08882840350270271, 0.14466211891600064, 0.10271864637200322, 0.17907282816512243, 0.20593180906559738, 0.23965164752943174, 0.3589905138526644, 0.13444230944982596, 0.1195650084742478, 0.13333754587386334, 0.14025402973805154, 0.2839960551687649, 0.12410310496176992, 0.14613179862499237, 0.2762989439070225, 0.18647663587970392, 0.07937977622662272, 0.15126262259270462, 0.228062242269516, 0.05621818692556449, 0.16850596160760947, 0.18120082254920686, 0.12227233605725424, 0.06610180943139962, 0.2933026786361422, 0.20015601042125905, 0.21920790310416902, 0.22077070495912007], [0.011577784499552633, 0.026961176755971143, 0.0153621481731534, 0.010503481208745922, 0.10692152620426246, 0.04866600735113025, 0.07750038350267069, 0.03310300263443163, 0.126772868846144, 0.10318157010312591, 0.09502891757126365, 0.061935611202248504, 0.2476972815181528, 0.06051456888339349, 0.06640098230647189, 0.07374552677252463, 0.05818628453250442, 0.02530764289466398, 0.04607729108205863, 0.05877744459680148, 0.022756953424374973, 0.011730177527559655, 0.010520246112719178, 0.037915237447513, 0.0193751077500305, 0.036233159314308844, 0.09774253517389297, 0.06609446089714766, 0.22082934395543166, 0.04180320239226733, 0.08032213244587183, 0.10593855287879705, 0.0794469579788191, 0.09670908562839031, 0.11105039822203772, 0.03498076008898871, 0.05948265961238316, 0.07098132438425507, 0.02905147003808192, 0.013902825453052563, 0.02444297045336238, 0.0454355631954968, 0.028577211379472698, 0.011844000080600381, 0.05550563355375614, 0.07581560819276742, 0.044026544517172236, 0.11465624187673841, 8.761498638561793, 38.466123717171804, 43.97555535180228, 35.65618188040597, 29.315825598580496, 24.344787291118077, 32.50669894899641, 51.98350708825247, 23.89179253578186, 1.631837853363582, 0.1621869278273412, 1.1430599838495255, 2.233782661812646, 1.6506563978535789, 1.9582086375781467, 0.5751233505351203, 0.07552761078945228, 0.018544686060132723, 0.1403018528861659, 0.041236883495002985, 1.1976663108382906, 10.189828532082693, 26.402480670383998, 37.88363538469587, 43.758893149239675, 42.09515047073364, 39.240302426474436, 43.60339593887329, 42.95662634713309, 43.47908224378313, 46.07219164712088, 47.815213271549766, 52.85227162497384, 54.398120743887766, 58.327313150678364, 56.76231827054705, 49.50291681289673, 41.881792136601035, 26.843670436314174, 16.73363675389971, 29.500390597752162, 60.382645879473, 47.346425260816304, 50.94821160180228, 48.98304912022182, 73.33060005732945, 57.67140667779105, 64.23904200962612, 67.71239784785679, 73.51653385162354, 63.222374643598286, 67.19329793112618, 70.58031545366559, 68.9920128413609, 63.66740676334926, 66.27217524392265, 68.13171468462262, 72.10529218401227, 68.9669645854405, 59.22070557730538, 49.7433557510376, 38.772309984479634, 33.161848068237305, 26.56285204206194, 16.06803059577942, 8.942839673587255, 4.1544577819960455, 0.9206134059599468, 0.08546164844717298, 0.1555232253990003, 0.12438085648630347, 1.4091484142201287, 2.746986380645207, 1.677775108388492, 2.8550636555467332, 2.4189174132687703, 1.6286269170897347, 0.6978616501603807, 0.1458484966840063, 2.954859111990247, 22.874180214745657, 38.010985442570274, 21.884767157690867, 20.93458362988063, 29.79407705579485, 41.34973382949829, 30.238244124821254, 7.508703691618783, 0.09311317572636263, 0.11147802456149034, 0.11859563977590629, 0.08017892763018608, 0.05335109827241727, 0.022274591361305544, 0.09284377696790866, 0.11697556956538133, 0.0476344068135534, 0.03467456776914852, 0.07125048565545253, 0.06221672147512436, 0.16310985758900642, 0.039923762170864005, 0.022907620428928306, 0.021917451239590133, 0.03932433415736471, 0.10889493674039841, 0.004384151310659945, 0.06892645571913038, 0.025099768602688397, 0.09402981546840497, 0.055787347722798586, 0.07103980053216219, 0.05710353941789695, 0.0564064464664885, 0.10723647501851831, 0.10184940908636365, 0.050853519434375424, 0.09005917781697852, 0.10754758332456861, 0.031079285512013093, 0.07236298453062773, 0.09791543268199478, 0.011375374110814716, 0.04744964512065053, 0.05583083163946867, 0.017882702206926684, 0.11374808382242918, 0.14363637752830982, 0.014796845382079482, 0.05861809743302209, 0.015756441479814903, 0.036508033850363324, 0.03150196872385485, 0.038243780710867474, 0.04748016901846443, 0.03723210196143814, 0.12220505252480507, 0.04093367333656975, 0.0635274543559977, 0.164800902562482, 0.11323165081973587, 0.07888191472738981, 0.02395967031562967, 0.04378202763785209, 0.010440709934170758, 0.03219261559258614, 0.058243688595082076, 0.055200241905237944, 0.06519448597516332, 0.010850881808437407, 0.09194555266627244, 0.028561167418956757, 0.029249476734548807, 0.04768555139058402, 0.007818564789236655, 0.04999230921800647, 0.10009112129254, 0.04595786891877651, 0.0738263199371951, 0.14085298616971287, 0.04294956695022328, 0.06508993729948997, 0.08005800590451274, 0.0319970957269626, 0.06525568304849522, 0.055695586039551666, 0.034758197210196934, 0.09114541738693203, 0.06963466985949449, 0.046312325434493165, 0.008444844129761415, 0.07382086451564517, 0.03715111541428736, 0.11463368737271853, 0.012293038440735211, 0.5960019816245351, 16.946503502982004, 51.50267437526158, 51.922814573560444, 31.8668532371521, 17.371893065316335, 30.7773756980896, 64.94743170057023, 59.44098431723458, 14.043516601834979, 0.13837990244584425, 0.26226401701569557, 1.4253421681267875, 0.7599230142576354, 1.7660912722349167, 1.7927188319819314, 0.9628090560436249, 0.6905753782817295, 0.0861033322289586, 0.03617044910788536, 0.13369966644261563, 2.8666775694915225, 16.47287780897958, 33.92570522853306, 45.47044290815081, 51.00895970208304, 49.61980288369315, 45.50415209361485, 49.586409841264995, 50.174359457833425, 49.99955667768206, 53.41739640917097, 58.17117670604161, 59.545005798339844, 62.82850905827114, 65.63424028669084, 66.83736256190709, 63.132881845746724, 55.76443188531058, 43.46851403372628, 31.16148601259504, 41.258795806339805, 63.077727045331685, 51.64765201296125, 56.28131185259138, 51.538141454969136, 70.47045053754533, 62.4413971219744, 66.38355486733573, 66.89439337594169, 71.91514083317348, 63.57653822217669, 72.33144909994942, 73.10302570887974, 71.54309953962053, 66.91357040405273, 69.37191254752022, 67.69923795972551, 73.50649370465959, 70.0717351096017, 61.39046818869454, 52.62076112202236, 43.71054758344378, 37.886407715933665, 31.00211865561349, 20.386544466018677, 14.411899668829781, 6.992709185395922, 2.47318479844502, 0.4132454954087734, 1.0128837461982454, 1.7143981946366174, 3.080848842859268, 4.435615769454411, 3.3092226684093475, 1.8612534744398934, 0.8742182755044529, 1.3503569918019431, 0.5830830005662782, 0.1187787763774395, 0.208652313798666, 21.63380864688328, 55.74778052738735, 35.27616058077131, 15.779624768665858, 21.903075660978043, 40.49887480054583, 39.15051780428205, 13.721616114888873, 0.3163202420941421, 0.08076281379908323, 0.06376002901898963, 0.09720579361809151, 0.03964280456836734, 0.061158274699534686, 0.08729559968092612, 0.12473673453288418, 0.0663836525220956, 0.03396263186420713, 0.0416898056199508, 0.026200693366783004, 0.07675248863441603, 0.04843048445348229, 0.015267273710508431, 0.03799002557726843, 0.030400655498462062, 0.10091978896941457, 0.03391665433134351, 0.06112674996256828, 0.10982695208596331, 0.10350133651601416, 0.04229933023452759, 0.05991935117968491, 0.08577509769903761, 0.10943996320877757, 0.06787999187197004, 0.05037109799949186, 0.08122394619775669, 0.05406214190380914, 0.07623176050505467, 0.07833436410874128, 0.01788626451577459, 0.021710002728338753, 0.05573504624356117, 0.03972927028579371, 0.09818479751369782, 0.0013555801228254236, 0.08295925879584891, 0.037009454265769036, 0.10320018910403762, 0.28430763844932827, 0.08450365199574403, 0.12891589956624167, 0.22136445024183818, 0.1624166662139552, 0.14452999457716942, 0.10016752433563982, 0.24615529711757386, 0.1954558254884822, 0.16296076987470898, 0.22632013075053692, 0.32095230211104664, 0.22821336558886937, 0.1729609646967479, 0.16128526335316046, 0.2635114900767803, 0.10794149325894457, 0.14154411479830742, 0.12226930979107108, 0.18282063491642475, 0.23522309373532022, 0.22416864548410687, 0.1268842164427042, 0.09316129742988519, 0.11995589892779078, 0.13463413129959786, 0.19378097036055156, 0.20602322130330972, 0.15293764056903975, 0.13400594357933315, 0.3109901595328535, 0.1365141754171678, 0.17430124777768338, 0.17041462633226598, 0.16461853949087007, 0.17875573518020765, 0.13522136264613696, 0.11217462896768536, 0.13468796626797744, 0.12071674024420125, 0.13482893870345183, 0.052475859344537766, 0.18986282417816774, 0.1140422083969627, 0.166923387242215, 0.1895760888499873, 0.32507301813789774, 15.816914013453893, 62.62195301055908, 64.03386865343366, 46.61811508451189, 39.78446796962193, 34.351456097194124, 42.57238054275513, 62.278434072222026, 30.702366420200892, 1.859712928533554, 0.49170539528131485, 4.310795724391937, 9.13382567678179, 8.308867795126778, 5.236789098807743, 2.3288188193525587, 0.39295070299080437, 0.1431410876767976, 0.2521001866885594, 0.16667695689414228, 1.6529028373105186, 11.654568723269872, 30.892052241734095, 42.067479269845144, 48.22952045713152, 47.18561962672642, 44.32902758462088, 47.3301352092198, 45.11227369308472, 46.55344125202724, 51.584979261670796, 53.685426643916536, 56.995878492082866, 59.07323006221226, 61.47908551352364, 59.71724469321114, 53.6827654838562, 47.01136575426374, 33.622944423130576, 23.613421644483292, 40.91045829227993, 73.26633616856166, 61.037562234061106, 65.82149423871721, 60.70454897199358, 73.57798371996198, 62.30858925410679, 66.40777628762382, 66.47235284532819, 72.98513562338692, 66.31312792641776, 70.79809979030064, 74.7440720966884, 70.28368295942033, 66.30482482910156, 69.4202720097133, 68.63396521977016, 77.335909979684, 73.1417132786342, 63.01967484610421, 53.05370685032436, 43.351888520377024, 36.66352128982544, 28.98522857257298, 19.320515360151017, 12.289280584880284, 5.340388476848602, 1.524073030267443, 0.4081835698868547, 0.8616599493793079, 1.5172274261713028, 4.921527615615299, 7.9988009589059015, 9.703378200531006, 9.852006248065404, 12.050755875451223, 6.059124035494668, 1.5274845957756042, 0.3203024555529867, 4.034626543521881, 30.283574172428676, 51.14517566135952, 31.131855419703893, 30.164068630763463, 40.41609396253313, 53.06272908619472, 44.27403606687273, 13.321356449808393, 0.27270582956927164, 0.15595459725175584, 0.22777856034891947, 0.18445586359926633, 0.25625833070703913, 0.14165335893630981, 0.19478806560592993, 0.17919572442770004, 0.26075889063732965, 0.2832120486668178, 0.1230441832116672, 0.09858773196382181, 0.26100899864520344, 0.16285349348826067, 0.14671352026718004, 0.09406699240207672, 0.09740028211048671, 0.21081749190177235, 0.07366984976189477, 0.12122562793748719, 0.3648388886025974, 0.1719899403729609, 0.16375937845025743, 0.21106804774275847, 0.18473478220403194, 0.2604512428598744, 0.2058800504143749, 0.11864609563989298, 0.20807344200355665, 0.15496206336787768, 0.18351177711571964, 0.15857397312564508, 0.11350351944565773, 0.2111839143825429, 0.09342832131577389, 0.05788945260324648, 0.19986995362809726, 0.13771035123084271, 0.21414984523185662, 0.23522179094808443], [0.020971914387441108, 0.04571144874872906, 0.09943818740014519, 0.021455982966082435, 0.07317281607538462, 0.05316190913851772, 0.011994689137541821, 0.05907091099236693, 0.052769230745200596, 0.13417206252259867, 0.008637866986516331, 0.053601925527410846, 0.033451477863958905, 0.14567547025425093, 0.08480222775999989, 0.1511112685714449, 0.040887387070272646, 0.03144657651760748, 0.019264196112219776, 0.044514207635074854, 0.04071197558992675, 0.00870979085032429, 0.07957506539033991, 0.050396383606961796, 0.021845786067258035, 0.062358684571725984, 0.029237663439874138, 0.10170685566429581, 0.03797649558899658, 0.014960908364238483, 0.05081968767834561, 0.0672136636983071, 0.09117215166666678, 0.06310179576809917, 0.06310593483171292, 0.06619118606405598, 0.06350127647497825, 0.0677374859473535, 0.021797635525997196, 0.04220660163887909, 0.050016376855117936, 0.0757366470726473, 0.16140972024628095, 0.05004916027454393, 0.03092573642996805, 0.042893513172332726, 0.04834203062845128, 0.07757324459297316, 0.05396164068952203, 3.6639657701764787, 32.19735819952828, 51.828899247305735, 48.289928095681326, 35.500983442579, 27.47194218635559, 22.353815725871495, 45.89581509998867, 39.68623086384365, 10.755914773259844, 0.20450632912772043, 0.06829317220087562, 0.6537581767354692, 1.1608094828469413, 0.8520447824682508, 1.1261335206883294, 0.18251536201153482, 0.38858557865023613, 0.20125610567629337, 0.17796951665409974, 0.21046249595071587, 0.6865111706512315, 2.0888121894427707, 2.704005692686353, 2.489158055612019, 3.5252521506377628, 4.404618552752903, 4.398707372801645, 5.503083152430398, 3.008175245353154, 3.995462587901524, 3.624694986002786, 3.7762999023709978, 3.1502897909709384, 1.968394696712494, 0.4113829167825835, 0.10994448113654341, 0.3262782320380211, 0.17640398708837374, 0.757320045360497, 15.341533899307251, 12.537650891712733, 10.047471233776637, 11.09480447428567, 40.36117540087019, 64.69978400639125, 57.353394576481406, 72.81860814775739, 69.8347806930542, 71.82310499463762, 62.94486359187535, 67.491500718253, 70.58244855063302, 79.33314882005963, 75.18349702017647, 50.32339136941092, 27.65962518964495, 17.50121467454093, 12.883692026138306, 9.842542801584516, 6.082899468285697, 4.733432497297015, 1.0867500454187393, 0.6355795721922601, 0.09836274332233838, 0.2365372803594385, 0.28127276844211985, 0.5396771154233387, 1.3963229081460407, 2.418553067105157, 2.0392103024891446, 3.462319927556174, 1.1551640714917863, 2.119498474257333, 1.2789942153862544, 0.11234690222357001, 1.2534072569438388, 16.59517478942871, 35.58969109398978, 31.392242635999406, 18.822048119136266, 31.830232756478445, 40.8234737941197, 38.78422267096383, 22.173958131245204, 2.1380167262894765, 0.17274639835315092, 0.01486834600966956, 0.07798063023281948, 0.01314631149372352, 0.053905173005270104, 0.05529444970722709, 0.055028080607631376, 0.09739744583410875, 0.029778893504823958, 0.0875869829739843, 0.10103848510022674, 0.04841793494831238, 0.053646206722727845, 0.022309406993112395, 0.028068739288885678, 0.04221476780782853, 0.027320006429882984, 0.012627434068625527, 0.02414832340686449, 0.11119525866316897, 0.06008690183183976, 0.01141055191068777, 0.021977459180301855, 0.019641749959971224, 0.045993532719356675, 0.047315933009875674, 0.055245571437158754, 0.029215380349861722, 0.007392952850620661, 0.1180845129170588, 0.025058676521959047, 0.10500334841864449, 0.07627315792654242, 0.0170540922055287, 0.055313876164810996, 0.07554980566991226, 0.018438335873984864, 0.015400193631649017, 0.04409075089331184, 0.025493385070668798, 0.0395175198625241, 0.016501947904803922, 0.09262246598622628, 0.019778471373553787, 0.01897474834030228, 0.024507955448435884, 0.05915865235562835, 0.014894618885591626, 0.021006495924666524, 0.04741212891946946, 0.08810773145939622, 0.10511481815150805, 0.07143069777105536, 0.07840210225965295, 0.025286214758775065, 0.06480202132037707, 0.03273765563166567, 0.0732740331441164, 0.03135217872581311, 0.008936184059296335, 0.024216787590246116, 0.0339723858051002, 0.035438669446323595, 0.025679364733930145, 0.020070373745901243, 0.05988503766379186, 0.03316019295847841, 0.04305659567138978, 0.07447441587490694, 0.03627273486927152, 0.02980435892407383, 0.06993836177779095, 0.06403056771627494, 0.13612096437386104, 0.023207724593313675, 0.08804155393902745, 0.09902353465024914, 0.05453397479972669, 0.034776914598686356, 0.07233899153236832, 0.0410231619275042, 0.05562986992299557, 0.05572464769440038, 0.1044479471498302, 0.04751650117603796, 0.12305974880499498, 0.10223844035395555, 0.06215371271329267, 0.08788528053888253, 0.15112816409340926, 9.267330970082964, 45.84378351484026, 58.43551049913679, 40.92220074789864, 25.184457983289445, 20.713854994092667, 40.71558564049857, 69.23545687539237, 38.744124616895405, 2.878677325589316, 0.2797324125255857, 0.060961058496364524, 1.1249823995998927, 1.7192949375935962, 1.392887783902032, 1.7493848715509688, 0.8870708686964852, 0.3714739568531513, 0.10853582886712891, 0.3979062613631998, 0.8440796498741422, 2.9483406160558974, 4.107430636882782, 6.645655785288129, 6.226670290742602, 7.850155540875026, 9.364933184215001, 9.791728019714355, 11.259287442479815, 8.900151678494044, 8.603843144008092, 9.462831565311976, 8.810554657663618, 7.696401459830148, 6.14069675547736, 2.041362941265106, 0.15812026390007564, 0.32078277692198753, 0.13448759487697057, 3.2069130497319356, 31.241261754717144, 25.6259708404541, 19.264342648642405, 21.43753593308585, 53.503943170819966, 68.22750949859619, 59.38752487727574, 68.99755750383649, 67.98187678200858, 67.75801971980503, 60.53712517874581, 67.3515431540353, 68.92344106946672, 74.43792751857212, 75.21611186436245, 58.96076651981899, 39.11379657472883, 26.277534689222062, 20.389163936887467, 15.041580166135516, 9.095136369977679, 7.60991028376988, 3.7094634430749074, 2.1086262805121283, 0.5446653249008315, 0.6706538615482194, 1.7325339700494493, 1.7705611352409636, 3.5593410985810414, 2.6245146095752716, 2.409068124634879, 3.1389950598989214, 0.8518330795424325, 0.497088403574058, 1.2069230484110969, 0.08126338265304055, 0.6689509014998163, 12.231953603880745, 46.43634326117379, 48.74517406736101, 22.50496162687029, 19.8985082081386, 34.231054237910676, 43.299853461129324, 30.399501391819545, 5.448468574455806, 0.10608185268938541, 0.035721235176814456, 0.05690061334254486, 0.08516172239823, 0.06315155274101666, 0.12002369814685412, 0.12448668080781188, 0.017808373784646392, 0.039567493966647556, 0.10326267539390496, 0.1291606742888689, 0.06772455306989805, 0.07793018793953316, 0.045975290305380306, 0.028376860344516378, 0.06819361075758934, 0.0104500389425084, 0.046189883790378056, 0.04994164979351418, 0.16887285906289304, 0.047619930268930535, 0.040867132799966, 0.039659662770905664, 0.0713560249922531, 0.015308496409228869, 0.05779001329626356, 0.11736959485071045, 0.024158423400617073, 0.022443499083497694, 0.07182369846850634, 0.05307269196159073, 0.05282592913135886, 0.06981100754014083, 0.024727349568690573, 0.017908048882548298, 0.01585874081190143, 0.017641416850632856, 0.021729437667610388, 0.07992356776126794, 0.0447104263917676, 0.06723318515079361, 0.10403903480619192, 0.18968872566308292, 0.13898949830659799, 0.11457675828465394, 0.10684391536882945, 0.14894864176000866, 0.14964848277824266, 0.17438017497105257, 0.13354137779346534, 0.1952516543013709, 0.10770953606281962, 0.10582536645233631, 0.1663403356713908, 0.17466773811195577, 0.24486103228160314, 0.29045844982777325, 0.15165040535586222, 0.0982158879882523, 0.14856179537517683, 0.11427979064839226, 0.09316460868077618, 0.0882334029302001, 0.10169170397732939, 0.13132858010275023, 0.16327635651188238, 0.19289337870265755, 0.13162003803466046, 0.19204762551401341, 0.14596790527658804, 0.10641771395291601, 0.09839890923883234, 0.15091209140207085, 0.19745400255279882, 0.16121511640293257, 0.14644130558839866, 0.18021499259131296, 0.10631471912243537, 0.14715395734778472, 0.1338512918778828, 0.15987446691308702, 0.23089360605393136, 0.149266956107957, 0.27140871488622254, 0.14255201071500778, 0.18628037641091005, 0.11821958209787096, 0.11156742833554745, 0.19816826922552927, 0.254153596503394, 7.544707519667489, 49.842628138405935, 73.79966599600655, 63.474483081272666, 46.13112279347011, 41.08705718176705, 32.326024941035676, 57.61988925933838, 47.854675565447124, 13.915092178753444, 0.30070237442851067, 0.19788160175085068, 3.790393888950348, 8.105469703674316, 5.383732208183833, 7.423022849219186, 0.7040232909577233, 0.8383876095925058, 0.4210687870425837, 0.4006096805844988, 0.44789048922913416, 1.3535298215491431, 2.7548510900565555, 3.960792813982282, 3.641840317419597, 4.686494810240609, 5.652383438178471, 6.02943525144032, 7.6803059577941895, 5.711036656584058, 5.471469717366355, 5.785192174570901, 4.987586310931614, 4.481971979141235, 3.2244592053549628, 0.8652133015649659, 0.1571947964174407, 0.3618208191224507, 0.3781183074627604, 2.0534903705120087, 23.55281945637294, 20.26810199873788, 14.43558520930154, 16.962110894066946, 48.317411695207866, 80.38659994942802, 64.60370431627545, 71.64359133584159, 70.72105816432408, 69.9188538960048, 64.45419297899518, 71.08936827523368, 73.43038313729423, 81.03042003086635, 80.47785064152309, 52.789414746420725, 31.210550716945104, 18.386894600731985, 14.332354954310826, 11.215641464505877, 5.972074397972651, 4.868343063763209, 1.587543521608625, 1.0603149724858147, 0.22338140915547097, 0.46825707065207617, 1.2029011270829608, 1.0346198827028275, 3.0999759307929446, 5.335828287260873, 6.698884631906237, 10.41655433177948, 7.518841113362994, 8.04167308126177, 5.027092899594988, 0.30320855709058897, 1.5304766637938363, 22.659453085490636, 46.29062564032418, 42.35795913423811, 27.817465679986135, 43.013684953962056, 51.70940065383911, 53.276424407958984, 32.85793733596802, 4.105536384241922, 0.23633268848061562, 0.08414524301354374, 0.16878277675381728, 0.272673205605575, 0.14091381004878453, 0.19571142963000707, 0.17801138226475033, 0.16409081566546643, 0.12109802264188017, 0.17951646793101514, 0.18672662175127439, 0.2565894829375403, 0.23542448292885507, 0.06159113932933126, 0.07833881529846362, 0.11485866244350161, 0.10861551601971899, 0.12101156370980398, 0.1303338749068124, 0.18985260544078691, 0.10821486823260784, 0.07563992190573897, 0.1157363203487226, 0.10632103628345899, 0.13707026200635092, 0.16572491798017705, 0.16761682288987295, 0.14440882179353917, 0.1100752619760377, 0.25445782446435516, 0.13094925188592502, 0.2015117233885186, 0.23241260168807848, 0.13073049219591276, 0.13029283710888453, 0.22721323211278233, 0.1634791163461549, 0.07263331966740744, 0.17255275802952902, 0.09181876839803797, 0.21018060536256858], [0.03993020146819098, 0.12109168512480599, 0.033015176454292874, 0.03898838468428169, 0.04959037560703499, 0.0017856931871002807, 0.09309488920761005, 0.03273626463487744, 0.10628932834203754, 0.06490263449294226, 0.026099008108888353, 0.045856814698449204, 0.09368140130702939, 0.1991309339978865, 0.07652405982038804, 0.028342682535627058, 0.007025349294833306, 0.07335452775337867, 0.013446435165990676, 0.07170260710907833, 0.13645484431513719, 0.10784211502011333, 0.06438037965978895, 0.12334052659571171, 0.02060221797520561, 0.06388152071407863, 0.06436331450406994, 0.0326535512161042, 0.06345670350960322, 0.033172172494232655, 0.02518466690422169, 0.05975357150392873, 0.05337920319288969, 0.09099237381347589, 0.08699747853513275, 0.05424922079380069, 0.08112319053283759, 0.1454422984804426, 0.07140278962573834, 0.1687898470887116, 0.08813578888241734, 0.023063491797074676, 0.06249937202249255, 0.0545050047471055, 0.1273780677999769, 0.04972166195511818, 0.05507457382710917, 0.043432626208024364, 0.08796349527048213, 0.04662065853231719, 0.6686616284506661, 15.65489591870989, 52.11187853131975, 51.61286238261631, 47.35055249077933, 34.572019713265554, 23.306048972266062, 43.488021101270405, 42.731292792728965, 31.027663707733154, 5.084965314183917, 0.07857559687857117, 0.6598751970699855, 0.9593483103173119, 2.2549014942986623, 2.340639659336635, 0.20791549262191567, 2.4792223487581526, 1.6090908625296183, 2.038396711860384, 0.7520817550165313, 0.09340747672000102, 0.09302149885999304, 0.14614169166556426, 0.1823850561465536, 0.07059904454009873, 0.40694592201283997, 0.37949459361178534, 0.40505880756037577, 0.3075183943978378, 0.08236060770494597, 0.016294653760269284, 0.11538722765232835, 0.06478606217673846, 0.14272914906697615, 0.116002496065838, 0.14406137115189008, 0.17398897239140101, 0.008527503265733165, 0.11734875025493757, 0.07039303452308689, 0.01641771287125136, 0.11057203781924077, 2.888686639922006, 19.882612466812134, 38.538068839481895, 55.77559764044625, 65.24145862034389, 74.08721719469342, 72.03637995038713, 61.4377715247018, 48.4285238129752, 31.735803263528005, 12.57323261669704, 1.4812081818069731, 0.14274840589080537, 0.2569842274699892, 0.2788527325860092, 0.043278401983635764, 1.7380166415657317, 0.13333431604717458, 0.6035822491560663, 0.8416973405650684, 1.5600605734757014, 1.9255742515836443, 5.1653425097465515, 2.4209810282502855, 3.302524822098868, 1.7412498337881905, 2.007315465382167, 1.9948371521064212, 1.2191596946546008, 0.08610988687723875, 0.565251805952617, 10.144808547837393, 35.63080358505249, 36.881489753723145, 20.570925337927683, 24.54861617088318, 33.17485162190029, 45.36343022755214, 30.135730402810232, 11.640093888555255, 0.3375038339623383, 0.18279771400349482, 0.05824229081294366, 0.09571580535599164, 0.06480730710817234, 0.026540122028174143, 0.05751657046909843, 0.07915771885641984, 0.024729441152885556, 0.029955567060304538, 0.011955147509330084, 0.05257157349426832, 0.005560332817757236, 0.06226301791944674, 0.05900216182427747, 0.0299205953654434, 0.09320462867617607, 0.03517551660271628, 0.11767028085887432, 0.028730709571391344, 0.019642045122704337, 0.042226007740412436, 0.0911771117576531, 0.036260124295949936, 0.03543875087052584, 0.08766298568142311, 0.06304303463548422, 0.08181452272193772, 0.02638370274300022, 0.0719465133068817, 0.08296913148037025, 0.019557928832780038, 0.02908035527382578, 0.12373461973454271, 0.039095199666917324, 0.04744484448539359, 0.05922868395490306, 0.11031339384083237, 0.053277911485305855, 0.07838576992175408, 0.07948846396590982, 0.09363147470035724, 0.040910402978105206, 0.01600994894813214, 0.06936960015445948, 0.04089094937912055, 0.04844639949234469, 0.0305767997966281, 0.0303085647257311, 0.0461457857995161, 0.02478689780192716, 0.051595314272812436, 0.028689000023795024, 0.07526218146085739, 0.04141998956246035, 0.04007562170071261, 0.11572144686111382, 0.045377914860312424, 0.2627504180584635, 0.07028776660029377, 0.018924224622813717, 0.04340776807761618, 0.05767596513032913, 0.08790463235761438, 0.02180061599106661, 0.0732868913827198, 0.03446495133851256, 0.020719207590445876, 0.06714971855814968, 0.07272986162986074, 0.05444582970812917, 0.11366816596793276, 0.02626767155847379, 0.019294701350320662, 0.03937969922221132, 0.06756034759538514, 0.06379668348069702, 0.1117023957361068, 0.10117385962179729, 0.05952709008540426, 0.034731055809451, 0.028107079910114408, 0.06709234842232295, 0.06940635639641966, 0.0503666603804699, 0.01591642477017428, 0.05502921036843743, 0.07960186073822634, 0.09958631838006632, 0.05339057204712715, 0.039568053758037944, 0.08880558437002556, 0.05113995959982276, 2.506599119731358, 28.572785241263254, 62.18539074489048, 52.21128988265991, 33.31155048097883, 17.133040053503855, 25.69469026156834, 57.431857109069824, 67.09914984021867, 29.25305904660906, 0.18203666912657873, 0.025950595536934476, 0.5406601226755551, 1.3991361686161585, 0.06921165755816869, 1.8104861357382365, 0.7577509422387395, 2.883654624223709, 1.0769372348274504, 0.17769089660474233, 1.7556627861091068, 0.6164715375219072, 1.3433815432446343, 0.3609603281532015, 0.5121626289827483, 0.6534665695258549, 1.0415647157600947, 0.9098301817263875, 0.6489752105304173, 0.9183367852653775, 0.11931727533893925, 0.014331529815016049, 0.46276848231043133, 0.5750663535935538, 0.6944324970245361, 0.38991132751107216, 0.9223920362336295, 0.3570851060960974, 0.16745507371212753, 0.2383591468845095, 0.5970262438058853, 0.05997223619903837, 0.33031502685376574, 5.811516727719988, 31.888778277805873, 49.04135492869786, 66.15483406611851, 69.00014918191093, 75.21935667310441, 76.40251677376884, 68.27931526729039, 59.98409720829555, 45.94632155554635, 23.795146567480906, 5.041317164897919, 0.9881098355565752, 0.8943411271486963, 1.322229489684105, 0.8756511243326324, 2.695778591292245, 2.143711860690798, 1.7799392491579056, 3.110004786934171, 4.855347326823643, 4.813179578099932, 7.465710844312396, 2.5605898797512054, 4.0691360746111185, 1.9685822980744498, 1.0388350508042743, 1.271675482392311, 1.2117403213466917, 0.1214241265718426, 0.030557176563888788, 6.030537843704224, 40.28459930419922, 53.90003912789481, 29.69617693764823, 18.755274193627493, 23.974964209965297, 48.117831638881135, 40.320003850119456, 18.70433521270752, 1.4147653813873018, 0.13987299161297934, 0.03087585392807211, 0.0974410552797573, 0.04494077206722327, 0.04176192371440785, 0.04885883343272975, 0.0931684695450323, 0.04975415699716125, 0.08048462801213775, 0.039392309795532904, 0.036992674094757864, 0.025614786859867827, 0.0671089386035289, 0.04813620042321937, 0.011092536118147629, 0.09712413871394736, 0.04539232015875833, 0.07184203248471022, 0.046181015337684324, 0.024664093141577074, 0.056615231691726615, 0.05525285890325904, 0.07091874309948512, 0.03695296622546656, 0.05515773168631962, 0.018487572071275542, 0.0791136072948575, 0.020484558306634426, 0.037342482645596774, 0.03649686177128127, 0.008826542130139257, 0.033479670993983746, 0.0997004411848528, 0.05551778272326503, 0.07171530249927725, 0.013770378810087485, 0.06555624013500554, 0.06915875218276467, 0.07800062665981905, 0.10850351702954088, 0.07888536847063474, 0.05712365798119988, 0.12131159832434994, 0.1574013289064169, 0.10689541617674486, 0.11144307322267975, 0.13437126683337347, 0.12137189294610705, 0.2076143723513399, 0.15657804879759038, 0.2017404439726046, 0.13868323474058084, 0.23176644636051996, 0.16766818799078465, 0.19296463845031603, 0.4297167429966586, 0.16583547847611563, 0.38666679018310135, 0.16734231476272854, 0.09271506566022124, 0.10490970380072083, 0.11741710587271623, 0.19654294715395995, 0.18305699580482074, 0.20739349563206944, 0.2241078351757356, 0.10745557397603989, 0.14023473220212118, 0.1240188173417534, 0.11566606483289174, 0.14601804901446613, 0.09199809841811657, 0.1270377960588251, 0.10949303821793624, 0.12976991731141294, 0.2326318227819034, 0.21367063666028635, 0.19460697818015302, 0.1709253324994019, 0.2013631785022361, 0.16350362503102847, 0.14584101922810078, 0.16163065124835285, 0.22748436113553389, 0.1788105743804148, 0.20522742186273846, 0.26965149917772835, 0.12491206798170294, 0.10528179883424725, 0.1258631840880428, 0.12059118412435055, 0.14861159984554562, 1.5975074555192674, 25.70015675680978, 70.63635962350028, 68.12002781459263, 58.91358825138637, 46.64528948920113, 32.737299237932476, 53.20440980366298, 55.92513677052089, 37.10054908479963, 6.595392950943538, 0.14535209403506347, 1.1635200402566364, 5.145755972181048, 8.71797685963767, 8.793726120676313, 2.185375213623047, 7.843334146908351, 3.7300092663083757, 2.696486656154905, 2.6657845207623074, 0.360080431082419, 0.7437103699360574, 0.3474343568086624, 0.4811958649328777, 0.40129266679286957, 0.7882988601922989, 0.4873880669474602, 0.9800544849463871, 0.42101385284747395, 0.09843633723046098, 0.10562910019819226, 0.25539664551615715, 0.3129173346928188, 0.41315153187939097, 0.35323257425001686, 0.8984233023864883, 0.5542325600981712, 0.24336752242275647, 0.25311923772096634, 0.7021357151014465, 0.18719999492168427, 0.23239938382591518, 4.367549044745309, 23.697310720171245, 44.50385815756661, 60.65691212245396, 67.76146602630615, 73.65192644936698, 74.95218454088483, 64.20095893314907, 51.18841430119106, 34.10047326769148, 14.075992482049124, 2.5491336030619483, 0.5153289990765708, 0.33967528172901695, 0.7183083529983247, 0.6395448765584401, 2.4831103001322066, 0.8131081632205418, 2.262697155986513, 2.768584204571588, 4.785567436899457, 6.300226960863386, 13.969154374940054, 11.85189756325313, 9.546609469822474, 6.084091518606458, 10.577136754989624, 6.8020679865564615, 2.936905401093619, 0.16454721188970975, 0.934131343449865, 13.237996305738177, 46.241296904427664, 47.025790214538574, 30.143880639757427, 34.00067629132952, 43.66569696153913, 59.56648962838309, 47.71092428479876, 18.88336249760219, 1.2981703749724796, 0.27216050454548424, 0.14717573832188333, 0.1323231631623847, 0.10942466224410705, 0.1940342267709119, 0.2603193627936499, 0.19483951213104383, 0.11414647208792822, 0.13110056519508362, 0.12069569208792277, 0.12656784270490917, 0.07575913372316531, 0.12583198504788534, 0.19967843033373356, 0.11696767141776425, 0.278726796486548, 0.18158542976847716, 0.2164681686886719, 0.108499737589487, 0.3072463289967605, 0.17622760869562626, 0.3581140637397766, 0.22464292789144175, 0.17035768367350101, 0.1925095585840089, 0.13994864826755865, 0.14670456360493386, 0.10319534436400447, 0.17122999472277506, 0.1544659999864442, 0.14503331828330243, 0.0738641754058855, 0.1874210073479584, 0.20009050465055875, 0.242301951029471, 0.11498185726148741, 0.2727571539580822, 0.3004094644316605, 0.37774546604071346, 0.30736287417156355, 0.19382088179034845, 0.1494285152958972], [0.021043771245915974, 0.029440158645489385, 0.038381842231111865, 0.05527009030005761, 0.038408071002257724, 0.06338716045554195, 0.042075264400669506, 0.06180665562195437, 0.0424585179425776, 0.07324176201862947, 0.10969461740127631, 0.0407285691638078, 0.02660222664209349, 0.02148075627961329, 0.008965968353939908, 0.03691572143829294, 0.022647929810253636, 0.010900694760493934, 0.05957514393542494, 0.03547252495107906, 0.07387683686933347, 0.05839803495577403, 0.04011336860380002, 0.02242474946459489, 0.020826697715425065, 0.05655565631708928, 0.01570554626440363, 0.02120536775328219, 0.10986900768641915, 0.021226812852546573, 0.007591844187118113, 0.07912140366222177, 0.050941647562597475, 0.10022783252809729, 0.02631544551279928, 0.03134060970374516, 0.08330091474843876, 0.09265481175056525, 0.038842550545398674, 0.0429796769416758, 0.019895805345316018, 0.02863766545695918, 0.024300109994198595, 0.06936894197549139, 0.015820079582876394, 0.03121128092919077, 0.05100244090759328, 0.06088953412004879, 0.014067403273656964, 0.022418252491791333, 0.09592699259519577, 0.1042989951425365, 4.537938850266593, 29.0868216582707, 44.81742688587734, 46.7844306400844, 38.90907832554409, 44.58980042593819, 28.51717185974121, 23.485578264508927, 48.48281703676496, 29.383014678955078, 6.327792201723371, 0.3212129681238106, 0.334962394620691, 0.2708350270986557, 0.724595441349915, 0.8576348796486855, 1.0441423888717378, 0.7076048702001572, 1.8294387587479182, 1.7666530992303575, 2.41241455078125, 0.34718072041869164, 0.370358798120703, 0.9718400857278279, 1.192184942109244, 0.5584773123264313, 0.9664390555449894, 3.7818662779671803, 0.3673882803746632, 1.1853343439953667, 0.1992338541895151, 0.7049168944358826, 0.3716126222695623, 0.5544807953493935, 0.31918650971991674, 0.19397838333887713, 0.05292844559465136, 0.09753346496394702, 0.17350690040205205, 0.11884178513927118, 0.05735210715127843, 0.08645361914698567, 0.21163649723998137, 0.4629503296954291, 1.6970573365688324, 4.7810233150209696, 8.227589505059377, 7.961676733834403, 5.807040350777762, 1.685603339757238, 0.07555488111185175, 0.06042956201625722, 0.282394142555339, 0.7579024998205048, 2.4189441204071045, 4.113441697188786, 1.3535457806927818, 3.752123211111341, 3.461171520607812, 1.43344789317676, 3.830534500735147, 4.177975262914385, 1.6688264799969537, 4.2617279802049906, 4.5795837470463345, 5.846485708441053, 1.270646063344819, 0.24023100786975451, 0.03498193056189588, 0.7876746622579438, 11.442851901054382, 34.17127888543265, 45.323589256831575, 26.39478554044451, 21.86535041672843, 32.03292213167463, 39.00615160805838, 43.75961923599243, 21.64904257229396, 2.663627973624638, 0.23143027297088078, 0.09247464034706354, 0.02239773528916495, 0.05621650755139334, 0.0736108443566731, 0.033665898322526894, 0.1412592657974788, 0.03215235810992973, 0.005319423200229981, 0.0965075268011008, 0.08908749531422343, 0.018918426541079367, 0.05301145078348262, 0.04149786163387554, 0.01989160690988813, 0.07770030027521507, 0.012622330637116517, 0.05329303603087153, 0.1367716658860445, 0.027906408267361776, 0.03474531861554299, 0.04327064632837262, 0.036276565199451785, 0.07820578172270741, 0.061661788395472934, 0.048107841052114964, 0.042522656465215344, 0.02145228155755571, 0.028241857320868542, 0.040232675416128974, 0.009760483666988356, 0.013592641650965171, 0.019748675204547386, 0.04135737774361457, 0.08971492986061744, 0.02032889049899365, 0.14391389835093701, 0.036101852610175095, 0.11906731660876956, 0.04148241478417601, 0.006302225195603179, 0.021223423570128422, 0.09024740343115159, 0.08107013587972947, 0.03599915633510266, 0.06397263439638273, 0.04085937375202775, 0.05053687428257295, 0.017962067055382898, 0.0895298458635807, 0.040179339170988114, 0.013058202025214476, 0.05910253072423594, 0.036143853927829435, 0.04833592381328344, 0.018123605887272527, 0.029592119955590794, 0.08771163664226021, 0.03954527194478682, 0.035263604018837214, 0.043869714718312025, 0.03413515957072377, 0.023854697555569664, 0.12478744824017797, 0.06641291773744992, 0.0609509279685361, 0.03413706286145108, 0.0021764347870235463, 0.07209302937345845, 0.06007191299327782, 0.018508272478356957, 0.03736071827422295, 0.05460182151624134, 0.03979128499382308, 0.03898047975131443, 0.07389359668429409, 0.13273580744862556, 0.13552940397390298, 0.07179327295827014, 0.05335667583027056, 0.01986553250545902, 0.05525205144658685, 0.05590877156438572, 0.09773796184786729, 0.06063181973461594, 0.03641662161265101, 0.03758445841127208, 0.06036497226783207, 0.0842770009434649, 0.06699273948158536, 0.029139587988278697, 0.06175941601395607, 0.057116465510002205, 0.014123830245807767, 0.03427276307983058, 0.3464161471596786, 11.758355702672686, 44.492852210998535, 56.93974052156721, 48.205983434404644, 29.428455897739955, 38.79943922587803, 30.536533764430455, 47.43733549118042, 62.253719329833984, 17.96926096507481, 1.2641131281852722, 0.18001688750726835, 0.13434994726308755, 0.8608157432505062, 1.1802467427083423, 1.1212820495877946, 0.3657291265470641, 0.9775808176824025, 1.0702698954514094, 1.7558223775454929, 1.0725855997630527, 1.2380477211305072, 1.0965817464249474, 2.0502390478338515, 1.479151080761637, 3.9631295800209045, 1.3793030785662788, 5.011001740183149, 4.305611499718257, 3.1167521391596114, 3.0762065776756833, 3.4187527682100023, 3.1702953917639594, 1.860407531261444, 2.0007216249193465, 0.7900760248303413, 0.3576561611677919, 0.15331794587629183, 0.3675534357982022, 0.23030846459524973, 0.25289252560053554, 0.17899315458323273, 0.3746105528303555, 2.208193749189377, 4.9682129962103705, 11.98482963017055, 17.186833006995066, 15.877154895237513, 11.956099697521754, 4.534753101212638, 0.9606874670301164, 0.030591025283294063, 0.7808861636689731, 2.3384301321847096, 3.6492303780147006, 2.924703061580658, 2.9232758581638336, 4.022449825491224, 2.005213635308402, 2.3939727289336066, 3.1265847086906433, 1.3819562047719955, 2.0937182690416063, 0.7225358975785119, 2.9397671903882707, 0.6022052030478204, 0.5861251173274857, 0.43353936501911705, 0.0486869130150548, 0.5258965577398027, 3.7978054455348422, 30.11966269356864, 57.35908167702811, 42.14648723602295, 18.642588308879308, 19.24477825845991, 36.502673966544016, 51.560455594744, 31.522142682756694, 5.906138164656503, 0.07515763957053423, 0.05008754839322396, 0.0763017310361777, 0.037033308164349625, 0.13332208884613855, 0.041484219687325616, 0.0805142257096512, 0.0031511153543501026, 0.048033595750374455, 0.03219562828806894, 0.07392154554171221, 0.0609501272972141, 0.013891984159792108, 0.03714106970333627, 0.07447284167366368, 0.10185789755944695, 0.0679347292919244, 0.04034517312954579, 0.0232110002211162, 0.05653812975755759, 0.02999526135889547, 0.032145311523761065, 0.06376969814300537, 0.0951263891266925, 0.08188141270407609, 0.1361300703138113, 0.05015388876199722, 0.028773162114833082, 0.021214412625080774, 0.07244894134679011, 0.02408109076454171, 0.05084269680082798, 0.020067561218248944, 0.011934823689184018, 0.0779984960598605, 0.014807561146361488, 0.04786857942651425, 0.031015764456242323, 0.1326483307140214, 0.030421683298689977, 0.06165908782609871, 0.06351830770394631, 0.07094725514096872, 0.0400030320244176, 0.06987069826573133, 0.07489648501255683, 0.09653204227132456, 0.13530630165977137, 0.16096465555684908, 0.22314572680209363, 0.2605409451893398, 0.11836187089128153, 0.13623100918318543, 0.15469649833227905, 0.2033982135887657, 0.1797089140330042, 0.10087958576955966, 0.21461571380496025, 0.11436582888875689, 0.20982155177210057, 0.2505297580999987, 0.14470242389610835, 0.15530350218926156, 0.2227200682141951, 0.15158766800803797, 0.13070092163980007, 0.13746104389429092, 0.21384911851159163, 0.20080242359212466, 0.1930642473910536, 0.08836015327168362, 0.13974179008177348, 0.2016491810125964, 0.12103048126612391, 0.11907258204051427, 0.23841057983892305, 0.18978023289569787, 0.28751637626971516, 0.12376075690346104, 0.11374534932630402, 0.18820531240531377, 0.21373908727296762, 0.12151753370250974, 0.13556075229176454, 0.19161389235939297, 0.12677300455314772, 0.1897569184324571, 0.17332463232534273, 0.15882801663662705, 0.09394191125673906, 0.13066700845956802, 0.15790402836033277, 0.08192756665604455, 0.15398460653211388, 0.17604953396533216, 0.29371530935168266, 8.432364208357674, 46.608377184186665, 69.39502920423234, 62.792809213910786, 52.84099817276001, 57.407298701150076, 32.991870812007356, 31.502062388828822, 59.50301783425467, 34.34823213304792, 8.995850086212158, 0.6104507063116346, 0.49709589460066383, 2.563295985971178, 1.4814563627753938, 1.5579838220562254, 4.687454530170985, 2.004464532647814, 6.254542989390237, 2.719817187104906, 5.487345482621874, 1.8880455110754286, 1.8188561094658715, 3.3782308740275244, 2.3783305968557085, 3.2669947743415833, 2.754237477268491, 7.390345471245902, 1.394964101059096, 3.8053737708500455, 2.105463764497212, 1.8844380932194846, 2.547707051038742, 1.4274266277040755, 1.6001656843083245, 0.5045791587659291, 0.3104771599173546, 0.28242201677390505, 0.24701293823974474, 0.20792324149182864, 0.20118602657956736, 0.19200248936457293, 0.32768393946545465, 0.9586899685008186, 2.378420054912567, 6.257257129464831, 10.01568409374782, 9.577526347977773, 8.060388922691345, 2.3657443693705966, 0.5179639405437878, 0.21035778442663805, 0.5280170610972813, 1.7533888795546122, 2.995135647909982, 7.2198401519230435, 4.0529098595891675, 7.293287822178431, 8.011728950909205, 4.658856613295419, 6.732146527085986, 7.567267451967512, 7.972379565238953, 12.418227859905787, 18.01915945325579, 15.703574998038155, 5.193472726004464, 1.1838196367025375, 0.2978310042193958, 1.4419125361101968, 14.511476039886475, 43.2735857963562, 55.10681962966919, 37.62125750950405, 29.991166182926722, 42.65929555892944, 50.04505000795637, 59.856173924037385, 34.60214015415737, 4.7139080592564175, 0.525830821267196, 0.1936714548085417, 0.16398637555539608, 0.25404462377939907, 0.27423606174332754, 0.13541816494294576, 0.2337039623941694, 0.1393549708383424, 0.16363606149596827, 0.1412288402872426, 0.16232696388448986, 0.16529197192617825, 0.07183206480528627, 0.12653049613748277, 0.1345419862440654, 0.22681286931037903, 0.2036417398069586, 0.2829485328069755, 0.3045466552887644, 0.11097918597183057, 0.1769552425082241, 0.22587285403694424, 0.09849829426301376, 0.2102994304150343, 0.24764036600078854, 0.17590073123574257, 0.09330608323216438, 0.052237917469548326, 0.07934139828596797, 0.39713284000754356, 0.10445556031273943, 0.16195807153625147, 0.1829941498913935, 0.15476488109145844, 0.19401539063879422, 0.12071688952190535, 0.21030703000724316, 0.17552947758563928, 0.22154996171593666, 0.10948119099651064, 0.10400170180946589, 0.14676335187894957, 0.2057780394596713, 0.22876444458961487], [0.07039824567203011, 0.03731011652520724, 0.046047988547278304, 0.05894055084458419, 0.019290056778118014, 0.06893973464944533, 0.054650394445551295, 0.01834819419309497, 0.0987414608576468, 0.06492745530392442, 0.0846223888386573, 0.10455909118588481, 0.09389285996024098, 0.07395244602646146, 0.10617375347231116, 0.06570117521498885, 0.06477557881070034, 0.05655956128612161, 0.016138918099126646, 0.031674591425274096, 0.05857181455940008, 0.04433127798672233, 0.02718471672518977, 0.015926061663776636, 0.02736101539007255, 0.03533107754109161, 0.03493999709774341, 0.033470429347029755, 0.10067541458244834, 0.057137846148439815, 0.09491208062640258, 0.03408362822873252, 0.022192963598562137, 0.010115709471782404, 0.047725513710507324, 0.010885099481259073, 0.022956664940076213, 0.0090914676464828, 0.04139625780018313, 0.08550856914371252, 0.011054835016173976, 0.018663923322622265, 0.05268265646217125, 0.05976436699607542, 0.08814688292997223, 0.04086365870067051, 0.06598257047257253, 0.03461420190121446, 0.04964118091655629, 0.016607158152120452, 0.09142312819936446, 0.026002330439431325, 0.06134762668183871, 0.4191514370696885, 7.094974509307316, 28.67949046407427, 52.7961996623448, 35.05360630580357, 49.76896333694458, 37.973350524902344, 24.13072371482849, 36.1193904876709, 44.553443976810996, 35.78758273805891, 13.569488780839102, 3.2746553804193224, 0.03910765078450952, 0.3282873199454376, 0.905472032725811, 0.46207013406923836, 0.34260028334600584, 3.659836368901389, 2.1448120645114352, 1.2322839732681001, 0.20407353235142572, 2.0433822614806036, 0.7874138876795769, 4.356597815241132, 1.1323732201542174, 4.535127869674137, 8.340495995112828, 3.0012500626700263, 4.8522414820534845, 6.096418057169233, 5.842328080109187, 3.3785302979605536, 3.311730968100684, 1.5072574125868934, 1.0131704679557254, 0.09559256304055452, 0.958352329475539, 0.2019211242773703, 0.30743170476385523, 0.29952723320041386, 0.4993775635957718, 0.22595312472965035, 0.06344047973730735, 0.02368310622737876, 0.1248269389782633, 0.07523158631686654, 0.2435147373804024, 0.1596621261643512, 0.10603510162660054, 0.14614868057625635, 0.7945982164570263, 1.333624318242073, 2.5178428249699727, 2.0454606413841248, 1.9708706438541412, 0.41344951731818064, 1.7765489625079292, 1.9554569338049208, 3.126333487885339, 2.5825933047703336, 1.4479744051183974, 0.7889185526541301, 0.17169015003102167, 0.1866419677223478, 0.29219148254820276, 3.8992122326578413, 14.98065836088998, 37.84220675059727, 42.82901225771223, 30.476237297058105, 20.192625454493932, 27.024502515792847, 43.45225524902344, 49.267643860408235, 33.77717706135341, 8.771382451057434, 0.11371318676642009, 0.24836585564272745, 0.010316439638180392, 0.07402098484869514, 0.033279479414756806, 0.04201666611645903, 0.05296172773731606, 0.026877791587529436, 0.04278376013306635, 0.06279708604727473, 0.013227616104164293, 0.06748733722737857, 0.056806439467306645, 0.0034285922842432876, 0.052069457580468485, 0.024409617064520717, 0.07363766684596028, 0.0880155253357121, 0.031319351201610904, 0.0273697752771633, 0.04486301873943635, 0.047125586973769326, 0.02880079545346754, 0.0714035699410098, 0.04871331141995532, 0.058754557610622475, 0.077067077825112, 0.06967430987528392, 0.05637594971007534, 0.0887063621942486, 0.03387205083189266, 0.052514284782643826, 0.026785929820367267, 0.022840599828798856, 0.03874026478401252, 0.03754796679796917, 0.07631752733141184, 0.0657643061131239, 0.048470918355243545, 0.09562961105257273, 0.01159216944194798, 0.033759030646511486, 0.03207829940531935, 0.05680267699062824, 0.04598393484151789, 0.024339073171306933, 0.0896563587178077, 0.0314008330793253, 0.06139145325869322, 0.051504013993378193, 0.006839278029344443, 0.12175413886351244, 0.09067861922085285, 0.0454617173277906, 0.0715243491743292, 0.06122320371546915, 0.06448465013610465, 0.11400100775063038, 0.07533945981413126, 0.02317350946499833, 0.07673451424177204, 0.05549841394115772, 0.06548559785421405, 0.13787318606461796, 0.022777463841651167, 0.05443577721182789, 0.017114237549581697, 0.016597227792122533, 0.02460851433819958, 0.017621620591463785, 0.025120206077450087, 0.023376097969178642, 0.02411521937964218, 0.026795179949008992, 0.03732190267848117, 0.07013639900833368, 0.041025747145925245, 0.0975269985252193, 0.034620027124349556, 0.057912882417440414, 0.07029417875622, 0.04973167713199343, 0.14614079599933966, 0.05094671282651169, 0.032813346212995906, 0.02994585722418768, 0.03919168734656913, 0.029046761005052497, 0.06528088383908782, 0.06275232987744467, 0.09230426698923111, 0.02617678518540093, 0.014536450783322965, 0.029732003342360258, 0.026769700959058743, 0.055198786447622945, 0.14151602344853537, 0.0934967447870544, 0.022275605771158422, 1.9604010113648005, 16.393484217779978, 42.894283635275706, 57.01438154493059, 39.299580982753206, 31.828721523284912, 15.976986612592425, 39.701388359069824, 61.86459241594587, 56.344721112932476, 27.547552483422415, 5.977708952767508, 0.350107051964317, 0.10511833974825484, 0.18032559379935265, 0.5526485879506383, 0.5063126257487706, 0.6024551753486905, 0.907923335475581, 0.6148361595613616, 1.5279095215456826, 1.531453319958278, 1.5002559082848685, 1.9660201498440333, 3.26833729658808, 3.7090682642800465, 4.086587343897138, 6.538329567228045, 2.677756918328149, 4.473642826080322, 3.377072479043688, 3.3661866060325076, 5.02804263148989, 3.8776033350399564, 1.4651846587657928, 1.9996457397937775, 0.9218463855130332, 2.659780408654894, 2.122407381023679, 2.231325605085918, 1.5938263216188975, 1.0007845440081187, 1.7158506938389368, 0.42418714399848667, 0.34184447675943375, 0.052731076721102, 0.10932935521538768, 0.0469665044386472, 0.306731890887022, 0.036044869239309, 0.4223543666303158, 2.3305912613868713, 2.6677339247294833, 3.4299417563847134, 2.567807538168771, 2.449656678097589, 2.055104958159583, 1.2654554333005632, 1.3539067613227027, 0.8692309888345855, 0.706493646970817, 1.639513441494533, 0.9779143312147686, 0.32639697566628456, 0.044766592127936225, 0.06876199918666057, 1.0858135585274016, 11.227473378181458, 32.91799061638968, 63.061801774161204, 48.82941402707781, 28.975032091140747, 20.605424880981445, 34.772225107465474, 53.520740440913606, 43.90449265071324, 17.12322919709342, 0.5838668442198208, 0.12194047815033368, 0.04329809306987694, 0.05554802842172129, 0.03732004009985498, 0.039666566864720414, 0.015155313736093896, 0.03530615494985666, 0.015418198558368852, 0.038894821490560255, 0.028752266628933803, 0.048518924707812924, 0.07166303494679076, 0.023037797372256006, 0.06483143581343548, 0.039546819004629336, 0.041599923478705544, 0.11068867798894644, 0.04800076483349715, 0.023214352184108326, 0.01853865897282958, 0.05017374948199306, 0.08197688936655011, 0.0341727470180818, 0.07263189474386827, 0.013442735453801495, 0.007053394419407206, 0.034429938931550295, 0.012800798917721425, 0.004285001653313104, 0.04927954550034233, 0.03040598878370864, 0.026337752351537347, 0.09163012887750353, 0.046384894754737616, 0.035601636594427485, 0.05687774671241641, 0.046141324431768486, 0.05731316602655819, 0.035550712541277917, 0.04428913417671408, 0.03954242549038359, 0.10064579652888433, 0.04807092535442539, 0.017879994852202277, 0.052474251216543574, 0.17306908246661934, 0.11591101597462382, 0.1339896994509867, 0.14016371672706945, 0.10071542779249804, 0.20655766262539796, 0.18939041452748434, 0.16334700557802403, 0.141912613596235, 0.14891501356448444, 0.12194796917693955, 0.23717426189354487, 0.2915679088660649, 0.11821405882281916, 0.1290028334728309, 0.10953160614839622, 0.11021872463503055, 0.22940234893134662, 0.1361094428492444, 0.09819037507155112, 0.0662768239687596, 0.153089523847614, 0.12186331514801298, 0.09472772266183581, 0.07891257093953234, 0.11373272857495717, 0.16150620792593273, 0.132830463083727, 0.23289088745202335, 0.19116824412984507, 0.23532313693846973, 0.15587378373103483, 0.10643429056342159, 0.07352814450860023, 0.15271656028926373, 0.12133616129202501, 0.2114731738609927, 0.11757118760475091, 0.1202343696994441, 0.10260086626346622, 0.1636986902781895, 0.16273993386753968, 0.09430131090006658, 0.13892615027725697, 0.1923385677593095, 0.12079830015344278, 0.12588459865323134, 0.2247692575412137, 0.20588861352631024, 0.10159007300223623, 0.19120449147054128, 0.1830832143979413, 0.13781169722122805, 1.2501090339251926, 17.075064284460886, 54.8863011768886, 75.63385146004813, 49.93684571129935, 65.62250477927071, 48.845488684517996, 34.17853627886091, 46.271500723702566, 55.6651143346514, 43.1053421156747, 16.773385660988943, 4.014018186501094, 0.14801212772727013, 0.4639971735221999, 1.4027858184916633, 1.566448682120868, 2.542837015220097, 9.926865271159581, 7.972890257835388, 8.926824075835091, 7.641115512166705, 7.189720579556056, 7.733722840036664, 15.781228065490723, 8.216028571128845, 13.208928516932897, 18.1563047340938, 9.653322509356908, 13.909024664333888, 13.831215262413025, 12.995377370289393, 10.013401610510689, 6.590829721518925, 2.894142278603145, 2.698198301451547, 0.5730742290616035, 2.9676290324756076, 2.0614738506930212, 1.366481480853898, 1.36448615363666, 1.2228504908936364, 0.7733741839017186, 0.16441367619803973, 0.24463027609246119, 0.17350430839828082, 0.24603763914534024, 0.23016247100063733, 0.3716497788471835, 0.18504089649234498, 0.14213372101741178, 2.961457295077188, 5.5024808304650445, 7.284880067620959, 7.373719300542559, 6.631462352616446, 6.227080234459468, 6.601141282490321, 9.823524713516235, 9.989790763173785, 8.115938901901245, 6.792907655239105, 2.6074107502188, 0.6361081238303865, 0.3088523399616991, 0.3526835579957281, 5.2795800140925815, 19.69566944667271, 46.40380137307303, 55.63050535746983, 44.16803434916905, 32.2131792477199, 39.49135821206229, 54.55700520106724, 66.0557666506086, 49.143208571842735, 16.775982550212316, 0.502849165882383, 0.28040636064750807, 0.12832326708095415, 0.32426987694842474, 0.1812163745718343, 0.14715664434645856, 0.15995559255991662, 0.16758951864072255, 0.10319916451615946, 0.14170640680406774, 0.16229919823152678, 0.1330486120922225, 0.2098173312842846, 0.11648397094437055, 0.20409610042614595, 0.0773089077057583, 0.16580509367798055, 0.20360060701412813, 0.07939564037535872, 0.0949890807803188, 0.09102215471544436, 0.11939830599086625, 0.22330150487167494, 0.166353187124644, 0.0800219349829214, 0.15393963323107787, 0.16493111343256064, 0.16081897408834525, 0.10163119900971651, 0.1715154815465212, 0.14240442934845174, 0.250299191900662, 0.13076094484754971, 0.2595517768391541, 0.13352547293262823, 0.21358169429004192, 0.19862447545996734, 0.16685283317097596, 0.11841331741639546, 0.225176351411002, 0.12575647767101014, 0.1094113765284419, 0.2379268386534282, 0.1791515246565853, 0.07798816197152648, 0.06504849916590111], [0.054858640235449584, 0.057814067362674644, 0.020840890971677642, 0.07268425729125738, 0.021976017293387225, 0.011764876960244561, 0.06815067984695945, 0.06362782325595617, 0.009766805917024612, 0.05134703491681388, 0.010214632243982382, 0.043539322447031736, 0.053029584631855996, 0.0657563197559544, 0.039119952624397616, 0.051663703817342005, 0.16283201106957026, 0.020634212597672428, 0.040256698948464224, 0.04648401854293687, 0.09011424093374185, 0.05463401800287621, 0.0386568355107946, 0.07334312836506537, 0.07084377855062485, 0.036137553730181286, 0.047412427474877665, 0.01151786561656211, 0.022097052673676183, 0.037887607501553636, 0.03668690246662923, 0.024978030938655138, 0.03536714167733278, 0.06555015367588826, 0.05167479786489691, 0.06337944551237992, 0.03979317132117493, 0.011136405103440796, 0.04630781996196934, 0.02260618972858148, 0.007849191315472126, 0.05678501133141773, 0.0229524546302855, 0.02401193617177861, 0.03939054221180933, 0.038013584313115904, 0.06153417631451573, 0.05810178656663213, 0.06625707859971694, 0.04069828275325043, 0.061148958413728645, 0.010890559991821647, 0.11954998570893492, 0.055392464090670855, 0.34591571401272503, 0.5453753439443452, 25.924298695155553, 55.395756993974956, 41.48334074020386, 44.59520265034267, 50.853403432028635, 24.199073144367762, 19.378100293023245, 34.856784684317454, 41.97898006439209, 34.85858774185181, 26.577577011925833, 15.029168946402413, 4.1707591244152615, 0.19179951239909443, 0.10711000287639243, 0.3365183839840548, 0.7937329486012459, 0.8615815107311521, 1.086258351802826, 0.495966269501618, 0.8587711815323148, 0.8890119131122316, 2.2397780886718204, 1.5316111743450165, 12.218856249536787, 1.376174435019493, 2.938019718442644, 3.3851115448134284, 1.8525382620947701, 2.028599100453513, 1.6547902503183909, 1.2207344387258803, 2.289052107504436, 1.0739858789103371, 2.2443652025290897, 1.3152114834104265, 4.873760921614511, 2.4564871915749142, 0.5950444872890199, 5.113268801144191, 1.5037232765129633, 0.19257362586046967, 0.2239133127565895, 0.26226366417748587, 0.22962512554866926, 0.20184359486613954, 0.2380549189235483, 1.2367963939905167, 2.0126058672155653, 4.451781622001103, 2.4117221193654195, 1.3977865896054675, 3.6486649683543613, 1.985087309564863, 0.8317030625683921, 0.8103843065244811, 0.5801461924399648, 0.32196464921746937, 0.07573391936187233, 0.4627028544034277, 6.301362122808184, 12.849812609808785, 30.60049888065883, 42.2787218775068, 52.088879993983674, 43.90332882744925, 15.902085031781878, 21.62753094945635, 34.18724584579468, 47.855266162327354, 42.02850682394845, 18.52699112892151, 1.9484353448663438, 0.18811141672943318, 0.05243817350960203, 0.046058220855359516, 0.18883672995226725, 0.02811929184411253, 0.07295381889811584, 0.03008245989414198, 0.016044868056529334, 0.04280224681964942, 0.062028902981962473, 0.02783647335932723, 0.08192690847707645, 0.0336666006062712, 0.005128755708158548, 0.024523836560547352, 0.01991676359570452, 0.09222818285759006, 0.05066838454721229, 0.03982231779290097, 0.08945414849690028, 0.06870498867439372, 0.12395085527428559, 0.04200299024315817, 0.051984613561736684, 0.09355809113809041, 0.04337543249130249, 0.06600272974797658, 0.04070814525974648, 0.037385155712919574, 0.029905375824975114, 0.05030894419178367, 0.05471476027742028, 0.028282811998256614, 0.016698628065309355, 0.07371938960360629, 0.03271511809102126, 0.06919710298201867, 0.07069096567907504, 0.03412206045218876, 0.03964846694309797, 0.051938259441937716, 0.05548934532063348, 0.06575992956225361, 0.014762014483234711, 0.02393031689072294, 0.04828175297006965, 0.023163009135584747, 0.0332652267866901, 0.030459131646369184, 0.01709806127473712, 0.07028906260217939, 0.05485010426491499, 0.05541937139683536, 0.059039399826100895, 0.03738785967496889, 0.10490747820585966, 0.07058155869266816, 0.04053781261401517, 0.006322434937049235, 0.019218142244166563, 0.0738416819700173, 0.09046257367091519, 0.020133477502635548, 0.0751897885597178, 0.03780311632103153, 0.05496908877311008, 0.01941843899632139, 0.09431670007428952, 0.01321388509989317, 0.09305925254843064, 0.0790134012433035, 0.012325490226170846, 0.025113079763416733, 0.006332149014009961, 0.09433888138404914, 0.021676897004778897, 0.05041678036962237, 0.05038104871554034, 0.04332810128107667, 0.04892435616680554, 0.03616140762876187, 0.07132302783429623, 0.056238064608935795, 0.03244859292837126, 0.021175337489694357, 0.042840913137687106, 0.053842466191521714, 0.01453250679852707, 0.04427226579615048, 0.07113187094884259, 0.035969965758600404, 0.06284619162657432, 0.02604983976509954, 0.020398579438083937, 0.04906283837876149, 0.032485851286245246, 0.03221558400296739, 0.11073088286710636, 0.05716535395809582, 0.12434944031494004, 0.047049346779073985, 0.5179529754178864, 3.849689381463187, 43.57270574569702, 58.3585661479405, 47.31607205527169, 42.27440357208252, 29.0319048336574, 17.37192780630929, 31.06426681791033, 55.82055595942906, 56.26987164361136, 46.33223492758614, 27.15998717716762, 7.764797789709909, 1.0694009363651276, 0.3277817299323422, 0.22092291393450328, 0.307790568364518, 0.18446197041443416, 0.5036090708204678, 1.1104561047894614, 1.0534708883081163, 1.3298426525933402, 1.2963487527200153, 1.5104207971266337, 0.8596465459891728, 2.9467349307877675, 0.9962508444275174, 0.5775950636182512, 1.574477651289531, 1.8090649034295763, 1.8095865611519133, 1.808391579559871, 1.363863855600357, 2.2582961235727583, 1.8427497701985496, 2.527212470769882, 2.8887539505958557, 2.3991167843341827, 2.0946171922343115, 1.5900876479489463, 1.813448891043663, 1.4696981651442391, 0.7746032550930977, 0.5497398983154977, 0.325947921190943, 0.31743089535406654, 0.29485367398176876, 1.0770544856786728, 1.0755973181554248, 0.9497857434409005, 1.026079678109714, 2.0761095796312605, 0.872273322726999, 1.413207573550088, 1.3290810648884093, 0.7469998534236635, 0.3628600090742111, 0.06866460905543395, 0.3826132762644972, 0.15805135188358171, 0.413590598319258, 2.2092505267688205, 7.358908346721104, 19.43201310294015, 46.580789361681255, 56.68904256820679, 56.54758071899414, 24.198340109416417, 20.259619985307964, 25.522960322243826, 46.76024396078927, 53.69440024239676, 28.838225534984044, 4.604384907654353, 0.2876898912446839, 0.11570456490984984, 0.07368686063481228, 0.034196539848510704, 0.016808630466195087, 0.032021075154521635, 0.024591975047120025, 0.04273106171084302, 0.02885176021871822, 0.03731533106682556, 0.056800193552459986, 0.035120232962071896, 0.030137590864407163, 0.049619963126523156, 0.07656941988638469, 0.030027800505714755, 0.06644201331904956, 0.08383263514510222, 0.03963243994595749, 0.06469711980649404, 0.01626006204501859, 0.025897671501817446, 0.07467940130404063, 0.040194592638207335, 0.07983083916561944, 0.026295109818290387, 0.01657743492562856, 0.0432914875314704, 0.05453325555260692, 0.026107732372890626, 0.05372574459761381, 0.08806390488254172, 0.03875550128785627, 0.020996185585058162, 0.02192503895743617, 0.02537215461156198, 0.04252103476652077, 0.07574311351137501, 0.021810325827183466, 0.0924228477690901, 0.04937161930969783, 0.0662361118676407, 0.04407549403341753, 0.05278572253882885, 0.0285928244702518, 0.04836437139394028, 0.007960353163070977, 0.1557212354881423, 0.1630143877118826, 0.06581995277000324, 0.16196922665195806, 0.15356049500405788, 0.16378094229315007, 0.15012490935623646, 0.20821374947471277, 0.2074893047767026, 0.18541934261364595, 0.1054104422884328, 0.1315158014850957, 0.18446032835968904, 0.1657873567725931, 0.276180091713156, 0.16328278902385915, 0.22151224873960018, 0.11608443595468998, 0.20046667089419706, 0.08960719207035643, 0.1507354551660163, 0.09463874636484043, 0.12008357207689967, 0.1975909173488617, 0.09609592067343847, 0.14739752427807876, 0.14427027851343155, 0.15473366848060063, 0.1356746240385941, 0.22788503606404575, 0.14810866968972342, 0.09197606638606105, 0.20978883281350136, 0.1634641614343439, 0.14913907939834253, 0.15807396067040308, 0.2322901396879128, 0.1361491507185357, 0.17307429361556256, 0.15821745725614683, 0.10330420852239643, 0.1303304008075169, 0.12257327990872519, 0.15645021280007704, 0.13758738711476326, 0.13134634414953844, 0.22202257492712565, 0.18643806794924395, 0.08069591703159468, 0.13913079643888132, 0.2944684017981802, 0.1754313071391412, 0.21779836873923028, 0.09334709388869149, 0.4860292598605156, 3.233191571065358, 50.504221711839946, 77.92261586870465, 58.5195072719029, 59.21183967590332, 64.74309907640729, 34.38668693814959, 28.605523415974208, 46.56356825147356, 57.68173517499651, 48.57503700256348, 36.789794376918245, 19.431379079818726, 5.674001021044595, 0.41703549346753527, 0.1903730553707906, 0.741158046892711, 0.9259639531373978, 2.3424066730907986, 4.052532051290784, 3.7377282806805203, 4.628810865538461, 5.824492488588605, 6.819688618183136, 9.18570874418531, 27.159137759889873, 10.298578262329102, 10.645856176103864, 15.449482849666051, 8.193314041410174, 10.121385301862444, 7.870717866080148, 4.587260637964521, 6.055682505880084, 3.367065987416676, 4.935744932719639, 6.772106485707419, 9.185740879603795, 7.488321151052203, 1.6049208577190126, 8.9203987291881, 2.435679942369461, 0.8674328710351671, 0.7522621910486902, 0.482148853795869, 0.5220394932797977, 0.8955553791352681, 1.765961970601763, 5.186831985201154, 9.41059066568102, 15.942219563892909, 13.274397049631391, 6.988795612539564, 10.292008740561348, 6.314692676067352, 2.906345920903342, 2.223621355635779, 1.6173655156578337, 0.5453939629452569, 0.33879657887986725, 1.0120835091386522, 8.819472670555115, 17.868235894611903, 39.17740733282906, 54.99183736528669, 62.0272011075701, 56.050034114292686, 25.792708499091013, 34.86721740450178, 46.923213958740234, 62.10848808288574, 60.71591622488839, 31.620470115116664, 3.41901940533093, 0.3293876594730786, 0.17227937627051557, 0.20250560077173368, 0.31522077109132496, 0.10487642165805612, 0.1439355979008334, 0.15310491302183696, 0.1265490065727915, 0.0825340480410627, 0.18955813481339387, 0.11553482258958475, 0.2389809563755989, 0.11806927302053996, 0.14959164868508065, 0.1808471700974873, 0.14018770972532885, 0.20753653081400053, 0.13557599218828337, 0.16429057637495653, 0.34633830562233925, 0.14042389419461998, 0.14367677750332014, 0.1782187425664493, 0.10079211582030569, 0.2051497431738036, 0.23233277882848466, 0.15954602882266045, 0.12800352780946664, 0.12536057962902955, 0.08416682042713676, 0.18836778083017894, 0.24791568836995534, 0.13925115498048918, 0.10060357808002404, 0.06693076209298202, 0.11259204335510731, 0.15096290010426724, 0.2770575189164707, 0.10274456640971558, 0.20963745165084088, 0.21361844374665193, 0.1528910252132586, 0.11240146322441952, 0.14086772395031794, 0.12476977918829237, 0.12120422694299902, 0.09395100362598896], [0.04369671542995742, 0.035629917934004746, 0.02188867117677416, 0.03404397803491779, 0.08545556877340589, 0.10138235307697739, 0.023591498910848583, 0.03345595619508198, 0.07035175245255232, 0.043778865664665184, 0.07331121686313834, 0.05786146981907742, 0.07358211518398353, 0.08851960900106601, 0.050826859793492725, 0.05048603504630072, 0.05494276161438652, 0.030804753636143038, 0.07423597866935389, 0.06228431713368211, 0.08384952388171639, 0.04481579948748861, 0.03269048048449414, 0.01959518888699157, 0.017394101014360785, 0.02525513106957078, 0.01885044072488589, 0.03280369405235563, 0.06105517130345106, 0.0281754338315555, 0.01161186900987689, 0.08418946314070906, 0.03802332129063351, 0.049166433712733645, 0.04962791216426662, 0.01543400842430336, 0.009661643167159386, 0.07901752673621688, 0.026857586511011635, 0.024168045027181506, 0.019689632479899695, 0.04336441308259964, 0.021489695978483984, 0.002693920155122344, 0.06448907418442623, 0.03617304789700678, 0.07222044467926025, 0.007114011345298162, 0.03424470904948456, 0.03983438214553254, 0.04985523496621421, 0.013867290574125946, 0.05953703062342746, 0.0876500935160688, 0.05923795274325779, 0.05436898561726723, 0.29265693042959484, 11.821338517325264, 49.219916684286936, 54.99554075513567, 47.296380860464915, 51.99341869354248, 40.783268042973106, 31.007128306797572, 27.172412293297903, 22.895594562802994, 24.884024824414933, 31.975057533809117, 44.37269006456648, 39.85922016416277, 26.95464185306004, 18.622099808284215, 11.925372157778058, 5.493687450885773, 2.8918882395539964, 0.6162914814693587, 0.08145893644541502, 0.024871492459039603, 0.6900989381330354, 0.8290549303804124, 1.6405318954161234, 0.964043989777565, 1.1334003593240465, 1.219126039317676, 0.8868636712431908, 2.3579174407890866, 2.222793868609837, 1.184891504900796, 1.3911165360893523, 2.6449125664574757, 1.9748953878879547, 2.453200910772596, 2.3568543664046695, 1.6477656215429306, 2.356591203383037, 3.643703954560416, 3.2779490436826433, 2.693721707378115, 0.7369728428976876, 0.5870751749191965, 1.2156655107225691, 0.6725072935223579, 1.1234528188194548, 1.6046482494899204, 0.49314877497298376, 1.2321802931172507, 0.49523833713361193, 0.48753484764269417, 0.04700423777103424, 0.12497409965310778, 0.8276398320283208, 3.3472640556948523, 8.080247742789131, 15.60023444039481, 26.359033584594727, 40.04810694285801, 38.2905010495867, 66.90846347808838, 84.59831305912563, 31.269537448883057, 55.28183432987758, 33.80181189945766, 40.20537941796439, 44.89767510550362, 49.16688108444214, 31.662027290889196, 5.613190821238926, 0.1957783331828458, 0.26955913699098993, 0.1425409098821027, 0.04063806277034538, 0.018702475986044322, 0.10481851547956467, 0.017880093239779984, 0.04635690179254327, 0.057239687469388754, 0.06885626805680138, 0.03958373470231891, 0.017881840467453003, 0.013178857425892991, 0.03924984119034239, 0.014475920370646884, 0.03976952098309994, 0.015437404492071696, 0.028185298034389104, 0.02361029602720269, 0.03342925584209817, 0.04984121643272894, 0.045014878269284964, 0.06718809649880443, 0.017930209836257354, 0.09009860070156199, 0.031518066967172284, 0.03856810009373086, 0.01716733630746603, 0.05213435606232711, 0.05920812434383801, 0.018712123057671955, 0.01871254374938352, 0.021274520649707744, 0.030019800577844893, 0.04705418812643204, 0.017209488599162017, 0.052702422187264474, 0.05201996862888336, 0.011789391582299556, 0.049994914792478085, 0.026150295178272893, 0.05888454456414495, 0.01721694739535451, 0.03158368808882577, 0.02832509490794369, 0.02455987355538777, 0.0499757292148258, 0.02001448281641517, 0.03636246094746249, 0.03671225253492594, 0.0236282381894333, 0.03975721575053675, 0.027361011997397457, 0.01839061450612332, 0.027132783351199966, 0.0371903042042894, 0.030704116714852195, 0.004394420089998415, 0.020218441961333156, 0.02559224423021078, 0.08282828118119921, 0.03796206993450012, 0.09706032249544348, 0.03921085935352104, 0.013896887423470616, 0.03979992613728557, 0.07334757276943751, 0.005564427352510393, 0.007527171318153185, 0.03997373627498746, 0.03251176453860743, 0.03950764039265258, 0.007568615388923458, 0.06014885886439255, 0.05418488210333245, 0.019263811043596694, 0.023136529306481992, 0.013038336216205997, 0.023546825861558318, 0.02768624570619847, 0.021779754431918263, 0.04816001021702375, 0.002577624553980838, 0.021009471300723295, 0.005070815178831773, 0.018146523407527378, 0.07086179365536996, 0.06831802693860871, 0.0510747252431299, 0.014111936375099634, 0.019767513033002615, 0.02872854165200676, 0.04323287906923464, 0.023269023446898376, 0.04324708080717495, 0.03895668352821043, 0.043518162332475185, 0.04309056652709842, 0.04935261354382549, 0.021922022869278277, 0.013048361571106528, 0.03321317297273448, 0.026361745349796753, 0.05807224315192018, 0.05349646761481251, 1.103203596813338, 25.008612973349436, 58.46598529815674, 56.0457957131522, 51.74876914705549, 39.293605531964985, 22.329361540930613, 24.059579372406006, 30.582965101514542, 33.03312226704189, 43.23391158240182, 56.279043265751426, 53.60885054724557, 37.68567773274013, 22.72736998966762, 10.811927676200867, 3.8516891598701477, 1.4982060811349323, 1.1955160605055946, 0.5810892475502831, 0.19877401100737707, 0.204514865098255, 0.6926724314689636, 0.8208110556006432, 0.1447684589241232, 0.3671903381390231, 0.06954761381660189, 0.43421811716897146, 0.8437096582991737, 0.39980366240654674, 0.5991107576659748, 0.6024530040366309, 0.7405365630984306, 0.5373462662100792, 0.46667803823947906, 0.37386671560151236, 1.2825258544513156, 0.6042680580701146, 0.5039893761277199, 0.4377875913466726, 0.5800766561712537, 0.31799190810748507, 0.976281178849084, 0.3549851487789835, 0.47868577390909195, 0.5689800030418805, 1.1769152986151832, 0.631786832852023, 0.40178873017430305, 0.20683825042630943, 0.5415847759161676, 0.588391261441367, 0.08383157663047314, 0.23816611724240438, 0.7047016088451658, 0.875242754817009, 3.1985502413340976, 8.523207562310354, 23.220362050192698, 35.329682554517476, 49.33272763660976, 61.144140652247835, 80.40626335144043, 49.78249495370047, 58.40287481035505, 34.80795621871948, 24.64465069770813, 43.439046723502024, 54.93165554319109, 44.58611440658569, 10.458581379481725, 0.39075067532914026, 0.24943411403468677, 0.10378138148891074, 0.04647603557844247, 0.08031525888613292, 0.04491343389132193, 0.04044720444029995, 0.02983874368614384, 0.031356636700885634, 0.05270306679553219, 0.031904211068259816, 0.03544620457770569, 0.03849362409008401, 0.045527752355805466, 0.040600376935409646, 0.0560925256327859, 0.03733603656291962, 0.026074256847745607, 0.008073485306730228, 0.055138732705797465, 0.05591265617736748, 0.04725152985858066, 0.0649329853643264, 0.020091133524796793, 0.01927673035035176, 0.0652760255283543, 0.015622915966170174, 0.04016995503168021, 0.03080218538109745, 0.0262795662773507, 0.023534900608605573, 0.07746596142117466, 0.011504288979007729, 0.013757854749980782, 0.057444652542471886, 0.02389035457079964, 0.05503983622682946, 0.041635095341397185, 0.029299905457134758, 0.05247096710705331, 0.05401920420782907, 0.050867432794932804, 0.070738775256489, 0.034427374069179804, 0.03956879336120827, 0.09125405084341764, 0.09870234331382172, 0.03744286511625562, 0.04941136110574007, 0.08569209251020636, 0.09824426432273217, 0.10522024213735547, 0.10093903222254344, 0.18479807595057146, 0.14465133020920412, 0.11048147375030176, 0.11095186815197979, 0.11504679306277207, 0.2311407827905246, 0.14693362345652922, 0.20635339644338402, 0.14852705438222202, 0.19697659888437816, 0.08127290249935218, 0.10273459873029164, 0.22277250540043625, 0.16543214369033063, 0.16192630252667836, 0.10949830364968095, 0.14222796953150205, 0.19735547926809105, 0.12991985997983388, 0.11883654684892722, 0.17991434729525022, 0.12602597820971692, 0.14230571607393877, 0.12519972611750874, 0.17149897957486765, 0.1563560999929905, 0.07559549821806805, 0.1429458460105317, 0.09665645845234394, 0.12857469144676412, 0.2154328463865178, 0.12320921649890286, 0.08338178255196128, 0.14277572371065617, 0.08815019418086324, 0.16307878068515233, 0.12546867025750025, 0.10275852387504918, 0.07778064560677324, 0.15358961772705826, 0.09571776632219553, 0.1043559785134026, 0.11030157376080751, 0.11843598048601832, 0.13951708642499788, 0.11497995736343519, 0.16927335757230008, 0.1152699768011059, 0.17924565103437218, 0.1293053650962455, 0.15886999081288064, 0.16409187418009552, 0.6615023240447044, 21.376768725258962, 69.04563208988735, 75.07338891710553, 62.41981601715088, 65.19178594861711, 56.02065018245152, 43.83872447695051, 41.65091739382063, 33.665880816323416, 34.35487461090088, 44.98056016649519, 57.03868286950247, 50.87036745888846, 34.80206067221505, 24.63165930339268, 16.074765137263707, 7.41607551915305, 4.538759171962738, 1.2416666469403674, 0.190110000914761, 0.24212686185325893, 0.9904778684888567, 1.562314503959247, 1.6675860094172614, 2.220918506383896, 1.883586721760886, 3.091830253601074, 5.325480682509286, 7.0204355376107355, 9.107773406164986, 10.427185075623647, 5.637407898902893, 12.65426685128893, 9.722041061946324, 12.786120210375104, 12.170200620378766, 12.395694851875305, 10.655026929719106, 14.482297948428563, 10.767769268580846, 6.843505305903299, 3.1162008430276598, 1.3876925941024507, 2.546338907309941, 2.6301411305155074, 3.059508753674371, 5.983675718307495, 2.459928286927087, 1.8274103190217699, 1.3809939878327506, 0.9170452888522829, 0.1576863271849496, 0.2809569239616394, 1.4999810201781136, 4.942866836275373, 10.798452513558523, 20.272211858204432, 33.170585427965435, 50.033762659345356, 47.103078501565115, 75.64722674233573, 92.72427300044468, 40.78516490118844, 67.26220321655273, 43.62308713368007, 53.247294085366384, 55.071623529706685, 65.70948232923234, 49.136545249394004, 10.034313951219831, 0.3376674423260348, 0.38061235791870524, 0.2620100277875151, 0.09800436148153883, 0.14849326333829335, 0.2111355076943125, 0.11372069136372634, 0.10648464464715549, 0.1251039576849767, 0.12802330031991005, 0.1500289916460003, 0.14376221863286837, 0.11669727521283285, 0.12776863255671092, 0.1073718291840383, 0.12379184737801552, 0.08651203422674111, 0.0964209253766707, 0.06438690716666834, 0.1184920139078583, 0.2075245478855712, 0.16099618029381546, 0.14271572764430726, 0.08351447686020817, 0.1555848228079932, 0.15191579397235597, 0.08149612016443696, 0.20255000410335405, 0.12832633405923843, 0.12122014537453651, 0.14142922524894985, 0.1779233491314309, 0.12239764790449824, 0.07217758162213223, 0.1159528408731733, 0.14975590844239506, 0.17780719750693866, 0.20233389069991453, 0.22342453684125627, 0.21188642882875033, 0.14017138417278016, 0.09699297789484262, 0.07776653207838535, 0.10125170794448682, 0.18527306403432572, 0.17064208484121732, 0.1705710015126637, 0.11889077536761761, 0.18059900269976684], [0.03161213566948261, 0.054329033475369215, 0.02730603369751147, 0.03967093323756542, 0.01560736055086766, 0.003694918763358146, 0.05415482300200632, 0.03994311738227095, 0.05469380033069423, 0.026950094582779065, 0.06863995787820645, 0.040000171999314, 0.028352087030985525, 0.05426027073657938, 0.050468555984220335, 0.014677260370392884, 0.0542094586417079, 0.025408761575818062, 0.012763144465030303, 0.046091370683695586, 0.05915665067732334, 0.013467030400144202, 0.008320994525482612, 0.06577232639704432, 0.04433672323024698, 0.020216494565829635, 0.03982112357126815, 0.11342636322868721, 0.09914736050580229, 0.05368641331525786, 0.0665705685636827, 0.10212763558541026, 0.06597300312880959, 0.015242726009871279, 0.06538147665560246, 0.023688805921535407, 0.044213745543467145, 0.07213334792426654, 0.005809372557061059, 0.02549158695286938, 0.0266780766791531, 0.0801659676113299, 0.02768883601363216, 0.022993519569614103, 0.04249149135180882, 0.07134475452559334, 0.06462191098502704, 0.0697328606620431, 0.0864097789994308, 0.029995020478963852, 0.01975481933914125, 0.004496578201984188, 0.024860013342861618, 0.0208323787498687, 0.18767382949590683, 0.08366678083049399, 0.002824726651722033, 0.1941233862723623, 1.2383733093738556, 22.001312766756328, 50.92794023241316, 51.563849789755686, 48.24635941641671, 46.76894310542515, 35.23411008289882, 33.70833778381348, 29.610797473362513, 24.28649537903922, 26.242102350507462, 23.609167609895977, 33.20330102103097, 28.15548685618809, 38.577187197549, 40.32721260615757, 38.46760368347168, 38.04182849611555, 34.33339078085763, 25.81186294555664, 22.755359070641653, 18.612262896129064, 16.888534682137625, 7.668841430119105, 4.186937570571899, 2.253234143768038, 0.3196855586554323, 0.19483412456299576, 0.2949580598090376, 0.05223928132493581, 0.15216196647712163, 0.3932435044220516, 0.602339010153498, 1.1108097029583794, 0.5243340815816606, 0.8539216103298324, 0.9054429371442113, 0.5441283594284738, 0.3200596757233143, 0.36289466864296366, 0.20574659614690713, 0.18186783604323864, 0.16201467492750712, 0.4460051389677184, 0.6962547163878168, 2.5131028507437025, 5.368120474474771, 9.60047103677477, 11.448650172778539, 17.721573318753922, 22.33641048840114, 31.54689564023699, 36.890810762132915, 36.49153600420271, 39.74679831096104, 32.722721917288645, 29.62350572858538, 29.954493590763636, 29.989158153533936, 48.070649896349224, 57.21176249640328, 36.4932278905596, 32.057536125183105, 37.09423664637974, 50.29928112030029, 36.68535252979824, 11.516637427466256, 0.3869135597986834, 0.3445541113615036, 0.07625123446008988, 0.02942335811842765, 0.021158012794330716, 0.05181099680651512, 0.17717651277780533, 0.04047598111044083, 0.039018291115228615, 0.011428991099819541, 0.027041589941031167, 0.036539575550705194, 0.05033517635560461, 0.016342302185616324, 0.07736723457596131, 0.00994789503913905, 0.02283317326301975, 0.047994003232036314, 0.030754922024373497, 0.02949525908167873, 0.05758913978934288, 0.14444945247045585, 0.027194382456530417, 0.01685071999340185, 0.009598642038846654, 0.01807546891671206, 0.08191491876329694, 0.020065873362390057, 0.0428695303520986, 0.02165356557816267, 0.10367016281400408, 0.07727580876754862, 0.03950043095807944, 0.041469794032829146, 0.037804018772606335, 0.033971510494926145, 0.09786564856767654, 0.02717673545703292, 0.05985864943691662, 0.04239838616922498, 0.052651952752577405, 0.05406515120661684, 0.02572727609159691, 0.021664919165362204, 0.03861030497189079, 0.08233305239783865, 0.06338925034339939, 0.0646210288895028, 0.06478507830096142, 0.030672001652419567, 0.07125271803566388, 0.04441699392295309, 0.025408252674554075, 0.022888879291713238, 0.008548046761591519, 0.021076368068211844, 0.05958162394485303, 0.09298109209963254, 0.07679381141705172, 0.05778119234102113, 0.019646197757018462, 0.07066866223301206, 0.06952934086854969, 0.046393685175904205, 0.029961056408605406, 0.03211219562217593, 0.027285548725298474, 0.03022774781233498, 0.03556519587125097, 0.00547688064398244, 0.01395008372076388, 0.07866752480289765, 0.03853317589632102, 0.08971371528293405, 0.03339893550478986, 0.004531560498954994, 0.012277533067390323, 0.006447867224259036, 0.03484870021098426, 0.06505888075168643, 0.03240702587312885, 0.033365273382514715, 0.07139291694121701, 0.08224882584597383, 0.04265824472531676, 0.04595854066844497, 0.02312398997933737, 0.06023435427674225, 0.027067861120615686, 0.039142585159944634, 0.029578654428145716, 0.020620935363695025, 0.04748367025916066, 0.08918109243469578, 0.03374833693461759, 0.03283329174986907, 0.008895231926414584, 0.03531400899269751, 0.03491079295054078, 0.02261786561991487, 0.08862205421818153, 0.014994594235239285, 0.056930024442928176, 0.039280405800257406, 0.09108790475875139, 0.1567888017743826, 0.09113758030746665, 0.04791774268129042, 0.0663413322929825, 5.660238376685551, 38.34683704376221, 58.615517480032786, 57.70021390914917, 51.766942160470144, 43.52532250540597, 34.39477464130947, 24.12035526548113, 16.918966054916382, 23.040705953325542, 39.89026471546718, 45.6107166154044, 52.557883398873464, 53.804028919764924, 60.422479901994976, 56.280082021440776, 49.165522711617605, 40.213696411677766, 30.526649951934814, 24.05872126988002, 16.726992538997106, 10.776286023003713, 3.293452646051134, 1.527466139623097, 0.261608036501067, 0.38669656429971966, 0.46703114786318367, 0.15673732810786792, 0.22293240896293096, 0.11962503168199744, 0.18307022723768437, 0.08679513939257179, 0.5855682843497821, 0.03510465719071882, 0.6452775203755924, 0.19248836115002632, 0.12928992163922104, 0.11237410469246761, 0.2225107265902417, 0.1998961857919182, 0.4639223718217441, 0.12970799420561108, 0.18139588779636792, 0.5910777172871998, 0.6402114150779588, 1.2277700326272418, 0.19820425872291836, 3.1564309128693173, 8.147198847361974, 12.93460408278874, 19.353442873273575, 29.215966088431223, 36.82036645071847, 53.784077167510986, 55.82143490655081, 60.93420778002058, 54.5785550389971, 54.13951226643154, 38.88843870162964, 66.53223936898368, 79.41300446646554, 30.760901519230433, 37.3685028893607, 37.79554264886038, 54.764339447021484, 50.08536345618111, 20.04779199191502, 0.9982084993805204, 0.1376495137810707, 0.15098153267587933, 0.05650939040684274, 0.03887075724612389, 0.028949252130197625, 0.08083799547914948, 0.049639806883143525, 0.036571809356766086, 0.0391215166476156, 0.029671739254679, 0.024870299933744327, 0.04780744681400912, 0.059569885289030414, 0.04719677208257573, 0.024697607682485665, 0.029862556872623305, 0.036410267132201364, 0.02121182910299727, 0.04516754186313067, 0.029181551986507008, 0.02024112199433148, 0.04472939144553883, 0.054028903865920644, 0.027203289924987724, 0.04373277956619859, 0.11955871166927473, 0.05165362078696489, 0.04388016076492412, 0.01562698378360697, 0.04294426080637744, 0.042205526160874536, 0.019684809792254652, 0.014833374314808419, 0.026516334286757877, 0.049645737279206514, 0.02599891571194998, 0.08942782133817673, 0.028505965202514614, 0.04547334063266005, 0.02006827198368098, 0.018815114495477507, 0.022569408041558096, 0.05379715023030128, 0.04776705362434898, 0.022595777608720318, 0.05888102975274835, 0.015220290249479669, 0.015065572390865003, 0.06927902930017028, 0.09815824643841811, 0.0901667731148856, 0.09837883138763052, 0.0786141376676304, 0.11627306868987423, 0.16791436049555028, 0.1257652307727507, 0.15681162769240992, 0.1363218921635832, 0.23067044945699827, 0.11449483196650233, 0.15492368542722293, 0.21435404356036866, 0.14055729417928628, 0.11679872976882116, 0.10882021646414484, 0.06658726052514144, 0.123737686712827, 0.0801811735810978, 0.08002155500331096, 0.15526025236717292, 0.17851009193275655, 0.10423317046037742, 0.1456855668553284, 0.1967011136668069, 0.15640821148242268, 0.07142939498381955, 0.1276670287230185, 0.22470111905464105, 0.20286301230745657, 0.08801452788923468, 0.15657350261296543, 0.12982607286955627, 0.2229708954691887, 0.15250382599021706, 0.1572260090282985, 0.10554602715585913, 0.1375821488244193, 0.15905482375196048, 0.09627664847565548, 0.09727213398686477, 0.14413009317857878, 0.09958584340555326, 0.1571476925164461, 0.09313486170555864, 0.1536138549979244, 0.19138105985309395, 0.13908328541687556, 0.16694113771830285, 0.15817628375121526, 0.17640077083238534, 0.09977041850132601, 0.15057134468640598, 0.07379887998104095, 0.13094455642359598, 0.3406665399670601, 0.16022361389228276, 0.163747354809727, 0.2450619057885238, 3.3499514886311124, 34.695124421800884, 70.44891807011196, 73.43588611057827, 63.33478260040283, 61.26811735970633, 47.82742820467268, 47.165942328316824, 41.68110384259905, 35.77020876748221, 36.56014946528843, 35.3869982446943, 47.22028071539742, 41.02177538190569, 53.407290254320415, 53.88037919998169, 50.88715778078352, 49.95608179909842, 46.13336706161499, 36.00445686067854, 30.173059599740164, 27.435783760888235, 21.09295913151332, 11.704394255365644, 6.4105769480977735, 3.1890190499169484, 0.7262251738991056, 0.3849355216537203, 0.37480751797556877, 0.21933653977300438, 0.40662394357579096, 0.8485856652259827, 1.6644587772233146, 2.0430426682744707, 1.5630807599851062, 1.4170570927006858, 2.273279913834163, 0.6496425090091569, 0.7381457313895226, 0.8268627737249646, 0.572256078677518, 0.3226866104773113, 0.38856218276279314, 0.7459465499435152, 1.0519113434212548, 3.1564430722168515, 7.937400596482413, 11.71788591997964, 15.615973847252981, 22.968705245426722, 29.072623014450073, 40.62116656984602, 46.25269195011684, 48.207425185612266, 52.24092742374965, 43.273227964128765, 40.45910331181118, 39.594035216740195, 36.93639094488961, 57.56106928416661, 65.49624211447579, 47.574148995535715, 43.91171530314854, 49.19360385622297, 66.46459865570068, 55.404306752341135, 19.90336847305298, 0.5735115855932236, 0.46529415249824524, 0.2308985729302679, 0.10550094528922013, 0.15910359684910091, 0.13655932513730867, 0.24924510131989205, 0.15484044275113515, 0.10973164505724396, 0.09820916370621749, 0.12425160913595132, 0.23636867797800473, 0.1373850479722023, 0.28479504372392384, 0.2618862901415144, 0.11877637436347348, 0.12786414314593586, 0.270824306245361, 0.12029469146260194, 0.1626523078552314, 0.10940428583749703, 0.24707012517111643, 0.1407782794641597, 0.07966176859502282, 0.15225118026137352, 0.1254797846611057, 0.19329404006046907, 0.1417419756097453, 0.13499600759574346, 0.14523423250232423, 0.15625514755291597, 0.1575179555054222, 0.10484390625996248, 0.14977230184844562, 0.20235274040273257, 0.17382150994879858, 0.13826565071940422, 0.23291061925036566, 0.14859516572739395, 0.22085485687213285, 0.07846147407378469, 0.11346338409930468, 0.08727461259279932, 0.12197409277515751, 0.11076525066580091, 0.1761259777205331, 0.14607225039175578, 0.09224049826817853, 0.12228513322770596, 0.22585006883101805, 0.19189179316163063], [0.07821619723524366, 0.02373269695921668, 0.036614909901150634, 0.037748762273362706, 0.05342745381806578, 0.026955319302422658, 0.038715192915073464, 0.010353349398688545, 0.10693764819630555, 0.0198506318764495, 0.03472770045378378, 0.013024522091395088, 0.021571138840434805, 0.04809806336249624, 0.004536238997908575, 0.048191782619271956, 0.04137078220290797, 0.04169588529371789, 0.030354318342038562, 0.024863801264603223, 0.027763474865683486, 0.03443187275635345, 0.013968614512123168, 0.031153571525854722, 0.022755681171215007, 0.03207801442061152, 0.026428686222061515, 0.03834596808467593, 0.008579219508517002, 0.03281752938138587, 0.03125210159591266, 0.024097959145105312, 0.0037793124044713166, 0.02929213623117123, 0.03257490561476775, 0.009260607766918838, 0.02827966698844518, 0.025711535775501813, 0.019411582399957945, 0.027995705172153454, 0.01624905111800347, 0.01683434015805168, 0.03144913459462779, 0.03817168975781117, 0.02770906314253807, 0.07327683549374342, 0.01664892367885581, 0.046007954981178045, 0.022739581231560026, 0.02649700960942677, 0.030810164952916757, 0.07447575258889369, 0.09930799010076694, 0.03168348362669349, 0.09015128216040985, 0.03902404848486185, 0.04317392794681447, 0.11507455871573516, 0.11201062026832785, 0.0800250426733068, 3.377468092100961, 20.13452809197562, 40.417897020067485, 51.81753199441092, 53.571747166769846, 45.24799633026123, 46.31274175643921, 43.287079198019846, 36.02475254876273, 40.83923578262329, 41.219514165605815, 23.236144883292063, 18.71172114780971, 17.857983827590942, 19.46022800036839, 21.91174701281956, 32.2440778868539, 30.105061054229736, 32.36538996015276, 32.93973500388009, 31.85077163151332, 39.04690279279436, 44.19150536400931, 36.88729497364589, 38.51300321306501, 31.28517436981201, 28.640026433127268, 20.731506892613, 17.88805215699332, 14.749102694647652, 13.77865821974618, 11.781045045171465, 11.96714472770691, 12.999168481145587, 13.44855625288827, 14.761807475771223, 15.755563156945364, 18.35516217776707, 17.594339643205913, 19.65651113646371, 26.969794137137278, 36.332293714795796, 43.766977378300254, 45.74631071090698, 39.02864987509591, 37.500480447496685, 39.70015157972063, 42.6917610168457, 34.6653722354344, 33.497772625514436, 32.877239431653706, 21.817670140947612, 19.04389020374843, 18.961748600006104, 27.187092099870952, 28.075198684419902, 36.98966973168509, 27.497586250305176, 33.193198340279714, 45.969438212258474, 52.09538698196411, 48.76579284667969, 19.963935920170375, 1.3575136363506317, 0.5608794348580497, 0.09709954181952135, 0.0319736998395196, 0.1563344140137945, 0.0347542006389371, 0.07274765281804971, 0.08511687123349734, 0.03221061712663088, 0.10440854462129728, 0.008649822773544915, 0.04448079317808151, 0.02762570681183466, 0.028815295746816055, 0.03651693622980799, 0.012411123041861823, 0.024969040349658047, 0.02112015223662768, 0.05595142088298287, 0.03578673416216459, 0.03886091848835349, 0.03719677064301712, 0.062486289867333004, 0.04896560770326427, 0.03925808539081897, 0.053215367519961934, 0.05673670981611524, 0.010910507225032364, 0.06968488823622465, 0.026000338939151595, 0.0156031485447394, 0.022292075512398566, 0.01611313546475555, 0.03922236052208713, 0.050926797823714356, 0.03759164070444448, 0.0688343174489481, 0.019559184122564535, 0.1211067893143211, 0.05045114477564182, 0.028792819274323325, 0.037084171149347506, 0.03174973917858941, 0.003678116964043251, 0.0290727149695158, 0.07678976734834057, 0.03217525527413402, 0.06241760176739522, 0.028169871540740132, 0.053094520433140655, 0.028979321409549032, 0.021350402917180742, 0.057890863956085274, 0.08037426429135458, 0.010360842969800745, 0.0363131552003324, 0.03469937500943031, 0.08462729464684214, 0.022954793879762292, 0.06195912244064467, 0.0352202863432467, 0.03912027492853148, 0.05691220272066338, 0.04537972994148731, 0.030679075379988978, 0.031285753540162525, 0.04158102288576109, 0.059617613442242146, 0.16889523714780807, 0.05010636756196618, 0.03338128002360463, 0.023307157114946415, 0.01873564956310604, 0.028195070634995188, 0.04664235808221357, 0.004830493766348809, 0.06461172617439713, 0.030361436174384186, 0.09086167439818382, 0.0460306689409273, 0.025032176336805736, 0.007134517521730491, 0.025618925923481584, 0.064843934428479, 0.026585085151184882, 0.0320589475865875, 0.01657836282226656, 0.06535014190844127, 0.014359899364145738, 0.058719144867999215, 0.06529765722474881, 0.05286517559683748, 0.038266060408204794, 0.02372339424411101, 0.03518214588984847, 0.00943890047658767, 0.037673366854765584, 0.036576766055077314, 0.04675742744335106, 0.035794248937496116, 0.030254784040153027, 0.0195533029202904, 0.08381426041679722, 0.020111433596217206, 0.0953694200143218, 0.07500848400273494, 0.01847045772176768, 0.0450734460194196, 0.03744274637262736, 0.12161423851336751, 0.10884802961455924, 0.18594581793461526, 0.16409576897110256, 10.46318803514753, 33.11222055980137, 51.803326402391704, 61.512575830732075, 56.62926721572876, 44.797725268772666, 36.97958442143032, 28.725195714405604, 21.20888982500349, 23.176923649651663, 28.330399070467266, 17.988856622150966, 23.717894758496964, 28.277504171643937, 32.10716363361904, 41.64550822121756, 52.681589126586914, 51.1943793296814, 55.52685213088989, 60.51741313934326, 66.35552583421979, 53.71332366125924, 39.13801799501692, 38.625400747571675, 31.339919226510183, 23.119437728609356, 17.996412788118633, 12.759474737303597, 12.458391053336006, 6.23487481049129, 7.005829121385302, 4.159596843378885, 7.52955436706543, 5.952961206436157, 6.5037140761102945, 6.616219741957528, 10.195175170898438, 11.53372391632625, 19.775882925306046, 17.521515573774064, 21.543883323669434, 36.53676182883126, 43.01040540422712, 55.96449136734009, 53.46899373190743, 52.88361842291695, 52.751529693603516, 58.57197311946324, 51.58199153627668, 49.75417409624372, 50.64834819521223, 32.901992389133994, 28.7759644644601, 17.846776383263723, 20.520768029349192, 20.938941887446813, 25.572652101516724, 28.95490837097168, 33.9080741746085, 39.84042876107352, 51.09685788835798, 54.439476421901155, 32.42387294769287, 4.103365072182246, 0.14178485902292387, 0.3206823265978268, 0.01854013987550778, 0.05783996704433646, 0.09652577939310245, 0.07968515091176544, 0.036201359770659886, 0.10394342922206436, 0.05983313652021544, 0.07019758251096521, 0.030396818382931606, 0.030654766862945895, 0.03923590747373445, 0.027038458501920104, 0.044098991701113324, 0.06140197055148227, 0.03077647229656577, 0.06368686937327896, 0.06931414348738534, 0.059148630393402915, 0.033844712655991316, 0.11850166267582349, 0.035757876067821465, 0.040689719641315084, 0.07497224344738893, 0.031197588092514446, 0.11559023175920759, 0.06042440515011549, 0.04338292691058346, 0.05748227730925594, 0.02225016918964684, 0.04086678674710648, 0.04962161875196865, 0.06324717868119478, 0.06893308500626258, 0.09115174133330584, 0.0349345823882946, 0.09298054927161761, 0.1148702653923205, 0.056180881070239205, 0.13212930570755685, 0.09305094727980238, 0.067572968346732, 0.017619488295167685, 0.022553498091708337, 0.02298517867789737, 0.050138068718037436, 0.022138965781778097, 0.06705384834536485, 0.03212975271578346, 0.015031145220356328, 0.04640504724479147, 0.12655549336756977, 0.08522139955312014, 0.0549666697957686, 0.14613345425043786, 0.20548075969730104, 0.15604051335581712, 0.08277616969176702, 0.1406386505280222, 0.22870736622384616, 0.11455294170549937, 0.11573965874101434, 0.09252430911042861, 0.07795561943203211, 0.09153012638645512, 0.13200224323996476, 0.429485416838101, 0.10363369834210191, 0.16789491368191584, 0.1204468732965844, 0.08986759345446314, 0.13194732261555536, 0.122753308819873, 0.06734177110982792, 0.19435957074165344, 0.10170171236885445, 0.14105257046009811, 0.09288028215191194, 0.15309596993029118, 0.06025502245341029, 0.14714124160153524, 0.16737469445381845, 0.13963223381766252, 0.12887806445360184, 0.06576751558376209, 0.18133173909570488, 0.11714844671743256, 0.0959914873487183, 0.14491317687290056, 0.2018021499472005, 0.1168051894221987, 0.1505402677825519, 0.10723813064396381, 0.13050854339131288, 0.08288341893681458, 0.08906285092234612, 0.2087527234107256, 0.14723937133593218, 0.07513366692832538, 0.07856902865959065, 0.12279066895799977, 0.1802389041653701, 0.14019274445516722, 0.22892086048211369, 0.12242199374096734, 0.20880058727094106, 0.22644864528306893, 0.1923039760440588, 0.20571535639464855, 0.18236408941447735, 0.15409237146377563, 6.146994428975241, 32.01555858339582, 57.94302218300955, 74.0989179611206, 73.0935970033918, 59.48802362169538, 58.262208529881065, 54.08383635112217, 48.887129238673616, 53.49767242159162, 53.918319838387625, 33.934977599552695, 27.568850449153356, 25.895675591060094, 28.22129324504307, 31.102363790784562, 42.22702727999006, 41.07156269890921, 44.35520839691162, 44.208782059805735, 46.222074713025776, 50.564848218645366, 60.898521832057405, 52.131208419799805, 53.71638434273856, 44.71950939723423, 40.27105726514544, 31.5564181464059, 27.167748314993723, 22.61343342917306, 20.567016976220266, 17.459504638399395, 17.96103082384382, 19.668656587600708, 19.934690952301025, 21.358343839645386, 22.360652753285, 26.215138128825597, 27.12327289581299, 29.22453669139317, 37.84662927900042, 46.231222016470774, 55.08532885142735, 56.820241928100586, 51.05650969914028, 50.30813659940447, 50.225946358272004, 54.25873293195452, 45.188651766095845, 43.23244898659842, 45.01849038260323, 29.01333577292306, 30.24119016102382, 29.04077247210911, 37.34356580461775, 38.23374816349575, 47.899585247039795, 38.30515480041504, 45.431022303445, 57.34241989680699, 69.36394296373639, 70.50470515659877, 32.25835296085903, 2.874717503786087, 0.5761418044567108, 0.32685075274535585, 0.08385222445109061, 0.21524787774043425, 0.17167946988982813, 0.10609979994062867, 0.21547895962638514, 0.11933923273214272, 0.1790290626564196, 0.11013883392193488, 0.14514531727348054, 0.09279710732932601, 0.12066827927316938, 0.17147335809256348, 0.09635710915816681, 0.1109384603000113, 0.12152324696736676, 0.13101299346557685, 0.09408092951135975, 0.13931638933718204, 0.09934891254774161, 0.22563362973076956, 0.09112901041018111, 0.20860022945063456, 0.20443928986787796, 0.15901628296290124, 0.13106153586081096, 0.166611342557839, 0.13423831468181951, 0.14490043398525032, 0.0835938315306391, 0.12371860630810261, 0.09592673475188868, 0.12257139358137335, 0.20583560637065343, 0.18520804680883884, 0.14656562677451543, 0.2621381351990359, 0.13541078248194285, 0.12276265903242997, 0.14898870246750967, 0.17681789344974927, 0.17074377009911196, 0.18228065674858435, 0.1099478534555861, 0.1289477092879159, 0.12543439066835813, 0.14182512329093047, 0.13368513222251618, 0.09989877018545355, 0.09070049518985407, 0.17135228030383587], [0.03367539781278797, 0.03327376614989979, 0.11320546615336623, 0.02199903829023242, 0.03429761781756367, 0.04790146801886814, 0.028945357339190583, 0.0503676137221711, 0.021380775840952992, 0.04685775563120842, 0.026618994938741838, 0.02824653242714703, 0.06529119757137128, 0.013134591497613915, 0.046133056482566256, 0.0418321860155889, 0.04786290687375835, 0.034856133562113555, 0.026377092115581036, 0.035845390121851645, 0.031082036971513714, 0.02837097235689206, 0.01429638170105006, 0.09648962026195866, 0.03567398199811578, 0.013781693381523448, 0.08354627301118203, 0.07171562141073601, 0.009575268203791763, 0.01962465257383883, 0.0299217488749751, 0.012035425835555153, 0.03685147435005222, 0.0105308787564614, 0.05313818755426577, 0.07427607330360583, 0.01664678629354707, 0.05543251122747149, 0.03302985655942133, 0.01686752730581377, 0.05639128799417189, 0.03942831964897258, 0.028166994552261064, 0.024666958255693316, 0.0614507029365216, 0.013900154569585408, 0.020354581531137228, 0.06633885564016444, 0.02277984210689153, 0.03694840647014124, 0.04515710599454386, 0.036837907042354345, 0.06522188521921635, 0.011792839388363063, 0.09848444536328316, 0.025103269843384624, 0.10584501682647637, 0.06985689007810184, 0.02169795025007001, 0.09938972642911331, 0.1285704845296485, 0.05651319359562226, 0.7726236156054905, 5.449686680521284, 26.72711440495082, 48.68226507731846, 56.24931192398071, 54.42172030040196, 59.63661084856306, 59.33310658591134, 58.02751922607422, 53.15152359008789, 48.9362530027117, 47.19700077601841, 43.57995966502598, 38.329761845724924, 35.17198971339634, 28.154495000839233, 29.737153938838414, 32.139531816755024, 20.7964152268001, 16.503630535943167, 67.69099739619664, 51.5170293535505, 20.398220913750784, 34.59615428107125, 24.660509960991995, 28.116618633270264, 27.217443568365915, 30.298901898520334, 29.51504782267979, 30.095969336373464, 22.37592315673828, 31.442485060010636, 33.4304723739624, 36.63048607962472, 33.677327973502024, 35.1242938041687, 30.353219441005162, 67.0340382712228, 58.65551825932094, 28.575064250401088, 31.618931089128765, 23.507970571517944, 39.00308745247977, 62.05873203277588, 52.160828590393066, 36.96311371667044, 32.57480519158499, 31.264597279684885, 47.667814186641145, 51.512936864580425, 42.56251410075596, 57.64766468320574, 58.1032406943185, 60.036500522068565, 60.41038308824812, 62.172203063964844, 70.24848338535854, 50.09885685784476, 19.969485793794902, 3.8752431188310896, 0.27583773008414675, 0.12010657441403184, 0.14815650640853814, 0.03422389838046261, 0.08707460082535233, 0.019267339425693666, 0.04832508421636053, 0.031607168793146095, 0.0515164108281689, 0.03422082122415304, 0.1275403733764376, 0.019022055801802447, 0.03252832757841263, 0.03566740020843489, 0.1001893731632403, 0.01309671567287296, 0.02336554166062602, 0.05860683375171252, 0.016245841647365263, 0.028326623308073198, 0.026425944940586175, 0.02734011990417327, 0.026165163576869026, 0.01980172307230532, 0.04206111355285559, 0.00946403426184718, 0.023113935786698545, 0.046218260124857934, 0.019026886971135224, 0.03515391204772251, 0.04492526754204716, 0.07171946870429174, 0.05239272862672806, 0.024565547804481218, 0.03304997512272426, 0.020615096569859555, 0.03396705251985362, 0.040351921160306246, 0.04957740880282862, 0.012814681744202971, 0.04073438420891762, 0.06546776595392398, 0.061697051860392094, 0.006138269506794001, 0.014004823685224568, 0.0693182282681976, 0.011432065711622792, 0.03704111470973917, 0.03615946023325835, 0.07843067536928824, 0.02956658329016396, 0.07192775859896626, 0.014339536528236099, 0.0466375744103321, 0.05065264253477965, 0.030434897768178155, 0.11107382803623166, 0.06168750487267971, 0.01750259367483003, 0.06386415021760122, 0.030793164258024523, 0.036714644370866675, 0.027058644918724895, 0.08326451134468828, 0.01910571238425161, 0.041826679703912566, 0.036694454561386786, 0.06543634299721036, 0.06234434712678194, 0.08142628534031765, 0.026627108521227325, 0.09102209364729268, 0.07128826648529087, 0.027330304895128523, 0.027941505491201366, 0.03480735367962292, 0.020917955586420636, 0.07786955405026674, 0.03468637767114809, 0.03415961397279586, 0.061848494091204236, 0.016200132135834013, 0.06443712554339852, 0.037975399754941463, 0.03911076865292021, 0.0439355427931462, 0.008910921352383281, 0.028978276465620314, 0.06226060912013054, 0.054745331672685485, 0.06571895283247743, 0.05917510682983058, 0.019689025191058005, 0.03010868187993765, 0.050364655309489796, 0.008722245360591581, 0.023658487280564647, 0.015585469314828515, 0.03358917297529323, 0.051741698025060553, 0.04603411929149713, 0.051651245914399624, 0.05260255879589489, 0.06737360118755273, 0.06068756817174809, 0.04603465533416186, 0.020693655657981123, 0.07791735684233052, 0.047810971803430996, 0.03973983846870916, 0.023767485449622785, 0.09397864035729851, 0.05261729657649994, 0.09201430183436189, 0.08466034608760051, 0.23648660736424582, 5.0800855074610025, 16.606361389160156, 42.78792755944388, 60.84130341666085, 63.510189873831614, 59.825011253356934, 56.31893287386213, 56.71867316109793, 54.17767872129168, 38.05864313670567, 27.884967429297312, 21.513785464423044, 20.707177775246755, 21.17287036350795, 26.83677782331194, 21.439597811017716, 24.610304015023367, 30.613200187683105, 21.560522522245133, 27.449424811771937, 72.96476350511823, 54.83226503644671, 40.32919979095459, 53.96558148520333, 48.42927769252232, 45.2935973576137, 51.73580033438546, 54.64180449077061, 57.04612439019339, 54.838789394923616, 49.57898221697126, 59.25648185185024, 61.34307452610561, 62.68721743992397, 58.21074669701712, 60.950702803475515, 45.9178443636213, 60.161074774605886, 61.57383809770857, 50.12222364970616, 51.746180943080354, 39.843239307403564, 46.339089325496126, 49.85139676502773, 42.64694513593401, 33.420057024274556, 25.066701650619507, 23.326038939612253, 34.49530117852347, 19.39419753210885, 23.25058671406337, 31.836326326642716, 39.33149405888149, 47.91996431350708, 53.01379639761788, 57.21038327898298, 66.45415551321847, 62.92957060677664, 38.83482640130179, 10.160111955233983, 0.2253120041319302, 0.20707375636058195, 0.039044187404215336, 0.056838469712861946, 0.18548982883138315, 0.02582760088677917, 0.028622510377317667, 0.08694029838911124, 0.046454149431415966, 0.040484992055488486, 0.061499258902456076, 0.050238841346332004, 0.031240515610469238, 0.017356272687071135, 0.10206633673182555, 0.06915801936494452, 0.07305505632289819, 0.05969445074775389, 0.02100959004435156, 0.047239251767418215, 0.04449387194056596, 0.012755333678796887, 0.049394625039505105, 0.06093830043183906, 0.07574561052024364, 0.07154427774782691, 0.012641104852913745, 0.02608817020830299, 0.009203090049725558, 0.02087455987930298, 0.06536637925143753, 0.04173971526324749, 0.06665216239967517, 0.059260955080389977, 0.0690908104713474, 0.056321802615587196, 0.05099599821759122, 0.05052036552556923, 0.05026386911049485, 0.022958320565521717, 0.026624328223988414, 0.12437788450292178, 0.045968308180038414, 0.052547997795045376, 0.021609440445899963, 0.010780667004707669, 0.048436570912599564, 0.09441786286021982, 0.013329939184976476, 0.06576198552336011, 0.028223564016765783, 0.03387394733726978, 0.06631311202155692, 0.016545883047261407, 0.09493246381836278, 0.05794632740850959, 0.1693313451749938, 0.12841131378497395, 0.10969250037201814, 0.1443432074572359, 0.08697465261710541, 0.1129420113616756, 0.11604692653885909, 0.2078374068119696, 0.20678176917135715, 0.11529994090752942, 0.14092435448297433, 0.10901689662465028, 0.12828769827527658, 0.12682043415095123, 0.21927933927093232, 0.23530212949429238, 0.19405452853866986, 0.10630434432200023, 0.09735883040619747, 0.22420239581593446, 0.11798996584756033, 0.15751049162021705, 0.10044640901365451, 0.05671742245821016, 0.14881491607853345, 0.15464589319058827, 0.11050273903778621, 0.12096931811954294, 0.12717016467026301, 0.12599891823317322, 0.20004653558135033, 0.2629272442843233, 0.12325716178332057, 0.104168316083295, 0.1446369859789099, 0.11448686596538339, 0.15962163119443826, 0.07975449040532112, 0.12919183261692524, 0.13266637974551745, 0.0877165560211454, 0.06320576768900667, 0.1235793980636767, 0.1644449159502983, 0.1409352110432727, 0.1402447066668953, 0.18993530528885977, 0.12394630908966064, 0.19781027414969035, 0.20763661472925118, 0.2755999171308109, 0.1684433463960886, 0.17842736494328293, 0.1146150276597057, 0.10234332829713821, 0.21760430772389683, 0.1627131045929023, 0.22741980531385966, 0.14879105878727777, 0.12318198010325432, 2.771434920174735, 13.33734599181584, 41.30302456447056, 68.48619788033622, 76.95716367449079, 74.396974836077, 78.14449269430978, 73.24913937704903, 72.93321868351528, 66.31322520119804, 59.240751130240305, 59.82419831412179, 55.703058447156636, 50.45423289707729, 45.75913708550589, 37.693817547389436, 40.67883661815098, 41.63700362614223, 26.631180627005442, 23.24093566622053, 80.55496869768415, 63.763020924159456, 34.55665724618094, 48.56620236805507, 40.397240025656565, 42.915559019361226, 43.89665855680193, 46.82740177427019, 44.31757695334298, 45.30941145760672, 35.82977219990322, 44.6637396812439, 48.42256920678275, 52.03439222063337, 47.92444242749895, 49.618659905024934, 41.810267380305696, 79.9827220099313, 72.06890446799142, 39.36081893103463, 43.82837166104998, 32.079308305467876, 52.17780303955078, 73.22787094116211, 60.90930543627058, 48.577590465545654, 43.99377005440848, 42.813496930258616, 59.119435582842144, 62.28324917384556, 53.886163575308665, 69.98067896706718, 70.21636186327252, 73.25989518846784, 75.75985704149518, 79.2061357498169, 87.9148758479527, 73.14967591421944, 35.42436218261719, 5.798161855765751, 0.28960175865462845, 0.25561282677309854, 0.25210564211010933, 0.09672465122171811, 0.25645602867007256, 0.08323793312800781, 0.11073890993637697, 0.13768850240324224, 0.1188086997717619, 0.1159486203853573, 0.21205611686621392, 0.13793942465313844, 0.12547006803963864, 0.14827747563166277, 0.31373920344880646, 0.08216983758445297, 0.17863144113549165, 0.16068409489733831, 0.07708204630762339, 0.15404601395130157, 0.10602805843310696, 0.1268007702061108, 0.15983516616480692, 0.15940905974379607, 0.13616836683026382, 0.10180816772793021, 0.14364719337650708, 0.10394201786922556, 0.1601681232984577, 0.11861930707735674, 0.3468096431876932, 0.15550710340695723, 0.12987955499972614, 0.14819272660783359, 0.1229164150676557, 0.15789412174906048, 0.10175380350223609, 0.13224115542003087, 0.08181642940534012, 0.12656071808721336, 0.14176739353154386, 0.2096557313842433, 0.36419191903301645, 0.060545733996800015, 0.06974763236939907, 0.11537808100027697, 0.18018209721360887, 0.09792399579393012, 0.17309102628912243, 0.13799043691584043, 0.23190090485981532, 0.24665548599192075, 0.1821891495159694, 0.1626427812235696], [0.0967711376558457, 0.06493593020630734, 0.05429089302197099, 0.02161015969301973, 0.08779323726360287, 0.018818284950352142, 0.04356928316078015, 0.048273369669914246, 0.032634179041321786, 0.04085639498329588, 0.011025993885206324, 0.08141969676528658, 0.04987403377890587, 0.17793701482670649, 0.019862833632422344, 0.013874494919686444, 0.005602287062044654, 0.10666529102517025, 0.03746116181303348, 0.050337564798870256, 0.05652822314628533, 0.05132223106920719, 0.01448616964210357, 0.019337829036105956, 0.04435894525210772, 0.032486801235271354, 0.10872989666781255, 0.040410421056939025, 0.04618469639016049, 0.07902629340865783, 0.02084333878675742, 0.028305709162460904, 0.02980725626860346, 0.02014709739679737, 0.01517236532111253, 0.02427358097130699, 0.029294914832072597, 0.047674501447805336, 0.0514859378204814, 0.03147426413904343, 0.09662785141595773, 0.040343293587544134, 0.05486495400379811, 0.0195246127633644, 0.08217167641435351, 0.07132723475141184, 0.02656598269407238, 0.013237619406676717, 0.011140674785045641, 0.05642852260332022, 0.04366792179644108, 0.013947382303220885, 0.03230676553877337, 0.13531589614493506, 0.03382793248498014, 0.004986299401415246, 0.0365923859312066, 0.058013604155608585, 0.07495002821087837, 0.24725503953439848, 0.009293949281397675, 0.017888825985469987, 0.12001704850367137, 0.33327946492603844, 0.12482611116554056, 2.249660815511431, 8.881358538355146, 24.711831092834473, 35.508011545453755, 43.502247537885395, 49.721399443490164, 49.25626965931484, 56.28645351954869, 60.62426948547363, 64.49554865700858, 67.16155855996269, 55.78233739307949, 53.31842279434204, 50.1067465373448, 57.73275579724993, 55.3520701953343, 43.526024273463655, 50.47494200297764, 45.71755559103829, 25.177481991904124, 25.657248156411306, 25.482824053083146, 23.05676324026925, 23.75612895829337, 18.00686287879944, 31.800272124154226, 23.18113773209708, 32.33785424913679, 30.763045038495743, 28.555315732955933, 28.486179419926234, 31.708330086299352, 28.723258904048375, 33.30938611711775, 82.15030983516148, 57.59318733215332, 41.54260540008545, 45.088562965393066, 52.901190417153494, 58.39797633034842, 50.2678405216762, 42.88054009846279, 47.713922432490754, 58.47030707768032, 61.10713454655239, 61.74948855808803, 65.17346354893276, 62.83879934038435, 54.62785598209926, 54.39551516941616, 37.91848407472883, 34.73024409157889, 18.147550003869192, 11.183149082320076, 2.1106041286672865, 0.03180627810901829, 0.10288485352482114, 0.09449842532298394, 0.014516198209353855, 0.05260174794654761, 0.027537141028525572, 0.11143288162669965, 0.03756146625216518, 0.024982449897964085, 0.021892308124474118, 0.03916936693713069, 0.0538405662934695, 0.04229162546939083, 0.04474833614325949, 0.06895244361034461, 0.06368629261851311, 0.014022975345142186, 0.05510213252689157, 0.001630448827719582, 0.06918429902621678, 0.033536186175686974, 0.03755454858765006, 0.04945801038827215, 0.045011814683675766, 0.028513099998235703, 0.026394411721932035, 0.030419478059879372, 0.054354984047157426, 0.05103385368628161, 0.02462440393199878, 0.05392837890290788, 0.021098330550427948, 0.029476110823452473, 0.016115656222349832, 0.05295262858271599, 0.08203210854636771, 0.04231514688581228, 0.025952281696455817, 0.06144937979323523, 0.06681758923722164, 0.03948885854333639, 0.08885799441486597, 0.022073887488139526, 0.02915713151118585, 0.04806292542655553, 0.0807984775996634, 0.020071181202573434, 0.039588969599987776, 0.06884197132395846, 0.06613733073962585, 0.029299057288361446, 0.08029644989541598, 0.06102319194802216, 0.03339224514950599, 0.007342832013299423, 0.06810818998409168, 0.010436699792210544, 0.040780080149748495, 0.022397779393941164, 0.03601857600733638, 0.01577285524191601, 0.01692675662759159, 0.032714544728930504, 0.0570779111502426, 0.043892666165317805, 0.018584186976243342, 0.015692201176924363, 0.09358812309801579, 0.03475583590833204, 0.07018378789403609, 0.03611903311684728, 0.059537159545081, 0.043388731777668, 0.02322574987608407, 0.023597860176648413, 0.014971865008452108, 0.041564955176519494, 0.07942318889711585, 0.028320876116465245, 0.08714176900684834, 0.024619978187339644, 0.07425277241106544, 0.08910530007311276, 0.04146378899791411, 0.03495171879019056, 0.05069062353244849, 0.048894120646374564, 0.06551039830914565, 0.04714685904660395, 0.03684977122715541, 0.04128002475148865, 0.09495229061160769, 0.020864751655608416, 0.08782056186880384, 0.03252607484215072, 0.022634323486792188, 0.04259911718379174, 0.06456684786826372, 0.04607191708471094, 0.038891740941575596, 0.025031058450362513, 0.006605114322155714, 0.019104538518669348, 0.039178113253521066, 0.0101091599125149, 0.005967311760676759, 0.047990790368723016, 0.08733082243374415, 0.018228329285713177, 0.007915283170794802, 0.021646144101396203, 0.03983739484101534, 0.030579954984464815, 0.037392399074243646, 0.13843091470854624, 0.1556240828441722, 0.030086527711578777, 0.11509443979178156, 0.15857519448867866, 0.2720647496836526, 0.4171282084924834, 7.6271982703890115, 21.89316405568804, 39.48108182634626, 51.648322514125276, 57.64726168768746, 61.992529596601216, 63.9311534336635, 64.4338139125279, 63.9506014415196, 64.01505987984794, 55.756934779030935, 44.198613371167866, 38.24365629468645, 35.50195619038173, 35.19640220914568, 23.466053826468332, 21.135115589414323, 61.21193422589983, 51.81694139753069, 20.233265468052455, 29.32182536806379, 22.66280038016183, 25.749285731996807, 22.587822369166783, 21.469058173043386, 27.74035804612296, 24.856386627469742, 21.14276381901332, 24.499014718191965, 26.723216465541295, 26.174180235181534, 26.067622661590576, 23.581763914653234, 20.951354844229563, 85.80052512032645, 63.203781264168875, 22.10833065850394, 28.312217371804373, 23.41321972438267, 40.83241612570626, 52.49309492111206, 42.9244909286499, 41.45506157193865, 51.16227865219116, 51.68036413192749, 61.862890107291086, 65.54959038325718, 66.20106043134416, 66.30697182246617, 66.05047212328229, 54.58241128921509, 52.310326031276155, 36.24361385617937, 26.87668306486947, 8.38318051610674, 0.11909870563873223, 0.18533179802553995, 0.06262936576136521, 0.03173722360017044, 0.04861175847638931, 0.030008095848773206, 0.09467145175273929, 0.02937756379001907, 0.03312455290662391, 0.02231058764404484, 0.08257955738476344, 0.014741183458162206, 0.0393737857895238, 0.03667078047458615, 0.017667282605543733, 0.02459025156817266, 0.03500967585880842, 0.032385014197123904, 0.07919914341930832, 0.05889865130718265, 0.01956155729879226, 0.033472559946988306, 0.03633041034585663, 0.018804290165592517, 0.0810253389977983, 0.019532261549362114, 0.04700378315257175, 0.0425653498885887, 0.05127020100397723, 0.044197433561618836, 0.0893474081531167, 0.02754773974551686, 0.05169230406837804, 0.0476672377304307, 0.04343974404036999, 0.04033388230683548, 0.05909045958625419, 0.024841903243213892, 0.023797802394255996, 0.02907656565574663, 0.06666154653898307, 0.019893818934048926, 0.026505513349547982, 0.029209931713661978, 0.022445456657026495, 0.03516518251438226, 0.04080872789823583, 0.04143488001344459, 0.02945130697584578, 0.08570351903992039, 0.08691432406859738, 0.015062113558607442, 0.03873561681913478, 0.031982093317700286, 0.06644873081573419, 0.03657980249928577, 0.13934760194803986, 0.10092527831771544, 0.13539487762110575, 0.12254585352327142, 0.18353146820196084, 0.10436620403613363, 0.11251134518533945, 0.1523684582539967, 0.17458263624991688, 0.15351955220103264, 0.0943714374942439, 0.19067104080958025, 0.22015684789844922, 0.2843318757201944, 0.10201438809079783, 0.10524398407765798, 0.10205342421042067, 0.23600112912910326, 0.12150888916637216, 0.07336452257420335, 0.20743888962481702, 0.13971082174352237, 0.08803101629018784, 0.17496508572782787, 0.1720772542591606, 0.15813414672655718, 0.17061935391809258, 0.14892327812101158, 0.18616476761443274, 0.12336152046918869, 0.16568791068025998, 0.10014582478574344, 0.10163715654718024, 0.13232902570494584, 0.07184284672673259, 0.24165720705475124, 0.08101528310882193, 0.13227329083851405, 0.14004554306822165, 0.1116287475451827, 0.3044615127146244, 0.12997456347303732, 0.1461444329470396, 0.13429588159280165, 0.2168352154216596, 0.1690091767481395, 0.08294463636619703, 0.09531687426247767, 0.13032137629176888, 0.10562015032129628, 0.1720265405518668, 0.17963745072484016, 0.11354328159775053, 0.2579052709043026, 0.13113067857921124, 0.1276549915117877, 0.08058036930326905, 0.1621350198984146, 0.280497175774404, 0.3864078883613859, 0.09421553050300904, 0.22405333524303778, 0.2172871468854802, 0.5855005394135202, 0.18174548260867596, 4.455495868410383, 15.244735070637294, 36.26643521445138, 50.65978145599365, 59.81126076834542, 68.29986803872245, 72.34131554194859, 75.85146903991699, 81.29648739950997, 83.87189279283795, 82.41181918552944, 69.42830412728446, 65.40072522844586, 62.75767912183489, 72.30512932368687, 69.63345663888114, 55.229302474430625, 63.110251562935964, 57.722357818058555, 37.80597536904471, 39.67582246235439, 38.68758017676217, 36.63849040440151, 34.87123346328735, 26.36844665663583, 42.084432874407085, 34.18050261906215, 43.27332871300833, 38.67368030548096, 39.55854729243687, 37.52689402444022, 41.2285155568804, 37.49407768249512, 46.23079817635672, 91.15388284410749, 67.47749314989362, 56.577280793871196, 58.069878918784006, 65.94041265760148, 68.35122217450822, 63.33506747654506, 53.53039843695504, 60.90376772199358, 73.48540592193604, 76.60713427407401, 80.55013969966343, 83.5408319745745, 83.17985221317836, 75.84594522203717, 74.29031998770577, 56.837331022535054, 51.321513993399485, 32.0239520072937, 19.638115780694143, 4.55475913626807, 0.1098161158817155, 0.2472606035215514, 0.16642390404428753, 0.15321787553174154, 0.12490271776914597, 0.11898567527532578, 0.20896747974412783, 0.0941441079069461, 0.12857176017548355, 0.07867114139454705, 0.1936053926391261, 0.17498712454523357, 0.16168268131358282, 0.13430103845894337, 0.1507154248122658, 0.14031177306813852, 0.07372591711048569, 0.12046759575605392, 0.16780000020350727, 0.24956322567803518, 0.17076427542737552, 0.1541144645639828, 0.1279260798224381, 0.13852384686470032, 0.13698288026664937, 0.07284907344728708, 0.11439455806144647, 0.1707317057464804, 0.16246366154934677, 0.16905058095497744, 0.20412884652614594, 0.12930673573698315, 0.12336925576840128, 0.10558036781315293, 0.10102996270039252, 0.1338036587195737, 0.20363631152680942, 0.12986493935542448, 0.09884172797735248, 0.12217051509235587, 0.15233766633485044, 0.24619063522134507, 0.20021340091313633, 0.12739705320979866, 0.1456142256834677, 0.16191104905945913, 0.1331245537315096, 0.09659271008734192, 0.13635936086731298, 0.19541481483195508, 0.1148882329996143, 0.2590648872511727, 0.09622888639569283, 0.08967685726072107, 0.17574460032795156, 0.1587480716407299], [0.07297448028943368, 0.07353080436587334, 0.004857776387195502, 0.04283797847373145, 0.04001125926151872, 0.0743798009519066, 0.052941419184207916, 0.05176288867369294, 0.03171828568779996, 0.03380356629246047, 0.030412241483905485, 0.08541682442384106, 0.026789490432877625, 0.051798199636063406, 0.057360317425004075, 0.030773924397570745, 0.019285217127097503, 0.01923238469420799, 0.03798261597486479, 0.03329448860936931, 0.026226557425356338, 0.11973156167992524, 0.03974466285269175, 0.061834441630968025, 0.0797945171860712, 0.023961680475622416, 0.08415703595216785, 0.0836935354662793, 0.03955124644562602, 0.03380316934947457, 0.07661308361483471, 0.0627271697989532, 0.0906750772680555, 0.024348494630040865, 0.06623923312872648, 0.05201394323791776, 0.046149907899754386, 0.030537838315857307, 0.06087728656296219, 0.02286110515706241, 0.04681470936962536, 0.019380817622212426, 0.166293150346194, 0.02054315319816981, 0.06629713252186775, 0.10838625939296824, 0.031006767081895044, 0.04704324335658124, 0.09585440970425095, 0.09631451072969607, 0.08734046441635915, 0.027021327189036777, 0.05297204825494971, 0.019565139963690723, 0.034549181283052476, 0.034804595434772115, 0.009730081905477812, 0.0687400417934571, 0.032332760215337784, 0.08369113345231328, 0.015211291178794844, 0.1896161495574883, 0.04317619764645185, 0.07950169539877347, 0.021335339439766746, 0.022320373815351298, 0.21521082972841604, 0.08691941986658744, 0.37105782489691463, 1.1692540411438261, 4.826103661741529, 5.682023584842682, 13.097220591136388, 17.41065011705671, 28.956509930746897, 43.49938835416521, 55.50161974770682, 62.947281564985005, 66.22802639007568, 62.75733866010393, 61.61524936131069, 60.51896258762905, 54.609797613961355, 43.12123611995152, 55.30970355442592, 54.83063915797642, 59.18755572182791, 51.49816499437605, 62.60734094892229, 61.06438228062221, 69.85921055930001, 67.30187048230852, 75.69184807368687, 73.89992850167411, 67.01255444117955, 65.55330072130475, 67.80440589359829, 68.33622796194894, 59.663653237479075, 50.38467100688389, 52.615140029362266, 58.723152024405344, 62.24799401419503, 55.73468664714268, 53.203423159463064, 54.27680172239031, 63.60585962023054, 56.04848466600691, 39.997395515441895, 32.01537445613316, 29.607979978833878, 19.619392122541154, 9.290844542639595, 7.320499573435102, 4.087365107876914, 0.5850591659545898, 0.0140796720349629, 0.07090724871626922, 0.19063441348927362, 0.13312790569450172, 0.06752916212592806, 0.053002497513911555, 0.05865130493683474, 0.04081991354801825, 0.12561264181775705, 0.028548336321754113, 0.046194691210985184, 0.06046796709831272, 0.013063638787051397, 0.02060199066597436, 0.04754443307008062, 0.04410871850060565, 0.038579658937773535, 0.07559559321297066, 0.03894910768472722, 0.03097692850444998, 0.02963816873463137, 0.04412730357476643, 0.04166889317067606, 0.051497262569942644, 0.06600281117217881, 0.028547484760305712, 0.01228976366110146, 0.016995809440101897, 0.03484127025253006, 0.013024786720052361, 0.08429079556039401, 0.03698822629771062, 0.04677099135837384, 0.03579210815951228, 0.04377893691084214, 0.05060973198020032, 0.019837195186742713, 0.02684606159371989, 0.048026094545743296, 0.04600087786093354, 0.16163916007748672, 0.05382665293291211, 0.05839784496596881, 0.05262958823836275, 0.08994443754532508, 0.044024203571357896, 0.0374934804359717, 0.017188372589381676, 0.008212721540725656, 0.13233471182840212, 0.03407596078302179, 0.056467083748430014, 0.06317795453859226, 0.13804522183324608, 0.06620785088411399, 0.004895235336984375, 0.08963768543409449, 0.06409987328307969, 0.08831917654190745, 0.04895542628530945, 0.054982486447053294, 0.057189177322600565, 0.08297031891665288, 0.0364968990907073, 0.04568687221035361, 0.07732612213918141, 0.05710338335484266, 0.10841320401855878, 0.06013498282326119, 0.0668057623718466, 0.02627673339364784, 0.004098157706071756, 0.031199291215411255, 0.016627824632450938, 0.028459480464724556, 0.03079496237582394, 0.0206412303461028, 0.014284590458763497, 0.07009876067084925, 0.03433708819959845, 0.05994299133973462, 0.07743934249239308, 0.06721233376967055, 0.025262813782319427, 0.10903374464916331, 0.027307796192222407, 0.00952877922515784, 0.09114547166973352, 0.0275452597000237, 0.017792238221902932, 0.05264706051509295, 0.01875426517134266, 0.04293933464214206, 0.06691009391631399, 0.006808779576593744, 0.06879719479807786, 0.039330539360110245, 0.055889959180993695, 0.07542429704751287, 0.008199961689699973, 0.03563315115336861, 0.043021528981626034, 0.09717719336705548, 0.038181409771953306, 0.011996233652878021, 0.0271344983484596, 0.02619936683082155, 0.05571297689207962, 0.07284834741481713, 0.029551709802555184, 0.0452268152896847, 0.03964351363746183, 0.03585308470896312, 0.048311323526182344, 0.026896821102127433, 0.041964306961745024, 0.0764922026012625, 0.09087015608591692, 0.04271642571049077, 0.010101700268153633, 0.10978552752307483, 0.052100917856608114, 0.04033078479447535, 0.052126084720449786, 0.08980455755123071, 0.20295118114777974, 0.10334854400051491, 0.12893620133399963, 1.5955477378198077, 5.309048627104078, 12.455649988991873, 14.980741739273071, 25.509850808552333, 31.052027566092356, 44.65071528298514, 58.766765866960796, 66.19194439479283, 71.37706538609096, 71.1931882585798, 65.86351694379533, 63.07618454524449, 56.94540330341884, 52.5906788962228, 46.22567735399519, 51.09141397476196, 41.534350940159385, 48.453130858285085, 43.60183259419033, 42.15147604261126, 33.83524315697806, 43.03637777056013, 40.75459630148751, 49.969884395599365, 45.83187082835606, 41.52202483585903, 43.58083861214774, 46.49026823043823, 48.7794634274074, 51.58774811880929, 63.44646099635533, 60.1501522064209, 58.4370391028268, 64.5484869820731, 65.27363572801862, 66.50511360168457, 63.38693577902657, 67.40637833731515, 66.8102228982108, 55.491301672799246, 50.12001064845494, 45.22427865437099, 34.62508658000401, 22.508647646222794, 17.429160118103027, 11.190736515181404, 3.2296907646315436, 0.7889331004449299, 0.15551322379282542, 0.19924863268222126, 0.10427126341632434, 0.08684811940682785, 0.08540966587939433, 0.08242438999669892, 0.07749155576207808, 0.05461121583357453, 0.05383821177695479, 0.03166857621233378, 0.030390735316489424, 0.03660289304597037, 0.0184893243879612, 0.024816534515204172, 0.04849390372900026, 0.06338333351803677, 0.03550818196630903, 0.018991609935515692, 0.0024120743078778362, 0.04204947328461068, 0.04603673165131893, 0.03183199119354997, 0.05706293588238103, 0.08616619849843637, 0.0967772648270641, 0.022144414417977844, 0.02890576821352754, 0.04621537974370377, 0.014054933496351753, 0.08339937696499483, 0.038891459349542856, 0.026329845722232546, 0.019532677152061036, 0.031221285928040743, 0.03258079190605453, 0.031186388872031654, 0.026289785014731542, 0.04138689062425068, 0.0113811679517052, 0.04996335273608565, 0.07313024478831462, 0.05707808756934745, 0.04232235632038542, 0.03758425824344158, 0.047546743481819115, 0.019035823277330825, 0.03371045093185135, 0.02651545388757118, 0.08382309494274003, 0.08724438385771853, 0.047697357899908505, 0.12681966062102998, 0.024174597979124104, 0.04215424248416509, 0.017736481303083043, 0.04288525540115578, 0.08361496789647, 0.0813130514164056, 0.04576939903199673, 0.11424931085535459, 0.13518690663789, 0.13944966718554497, 0.1361419175352369, 0.09934350462364298, 0.16625473169343813, 0.1187872037823711, 0.21039313610110963, 0.21289570895688875, 0.20393485336431436, 0.12944019000445092, 0.18516666974340165, 0.08556633282985006, 0.13853798753448895, 0.14022113436034747, 0.14642887482685701, 0.08792333278272833, 0.12239497447652475, 0.07257603774113314, 0.101259646804205, 0.07603215585861887, 0.20842178831143038, 0.2117094804665872, 0.11097905705017702, 0.22759869428617613, 0.1032789738050529, 0.1731149921459811, 0.13476597065372126, 0.06941908571336951, 0.11550225290868964, 0.17085373348423413, 0.10779813238020454, 0.12961584915007862, 0.15366231596895627, 0.17292691580951214, 0.08109494990536145, 0.08255569330815758, 0.09633815767509596, 0.28426535214696613, 0.14751781496618474, 0.14632147630410536, 0.1443409411502736, 0.30023936927318573, 0.1275931769715888, 0.07700921914407186, 0.14913461463791983, 0.09356596214430672, 0.1761614786727088, 0.21011253472949776, 0.1953987471227135, 0.12759768244411263, 0.21685835346579552, 0.20158052683940955, 0.12368845221187387, 0.1335489231028727, 0.09161953694586243, 0.12483669631183147, 0.22234205635530607, 0.08500358981213399, 0.15115647257438727, 0.17426844739488193, 0.3492972068488598, 0.12783830453242573, 0.34505717722432955, 0.17964880940105232, 0.19813398963638715, 0.39116906002163887, 0.1329912216003452, 0.61464980670384, 2.3973410853317807, 7.215385488101414, 10.853132230894905, 19.395095586776733, 25.86660953930446, 38.9418112891061, 58.79989487784249, 74.24809578486851, 82.81094455718994, 83.90282617296491, 81.10978930337089, 78.70927006857735, 78.63755771092006, 69.87156445639474, 57.83859075818743, 69.68383802686418, 66.63584395817348, 73.06492178780692, 66.4296214239938, 74.25536360059465, 73.40084634508405, 84.09968253544399, 79.17243698665074, 90.96086188725063, 88.41301999773297, 81.67633846827916, 78.97276660374233, 83.43726907457624, 83.0715992791312, 75.66996819632394, 66.7501140322004, 70.04688140324184, 78.72582762581962, 84.50574220929826, 78.33728436061314, 76.31018216269356, 75.87585721697126, 83.32896750313895, 74.33824866158622, 59.170880045209614, 50.14572940553938, 42.5338909966605, 29.205932889665874, 16.66565384183611, 12.296760320663452, 6.416712641716003, 1.4661208199603217, 0.1904513311705419, 0.21471889183989593, 0.30394066923430985, 0.2362029254436493, 0.2068873220788581, 0.14393567932503565, 0.2083917020687035, 0.09604792789156948, 0.26474205404520035, 0.1563252673617431, 0.1469985863992146, 0.1293948231531041, 0.10631725684340511, 0.1263284148382289, 0.07544236643505947, 0.12023548249687467, 0.11945077031850815, 0.17653706137623104, 0.07972700295171567, 0.14684784305947168, 0.1323221725012575, 0.29017102239387377, 0.14274979010224342, 0.21173350060624735, 0.16211953572928905, 0.1586828101426363, 0.1598399430513382, 0.07967225874641112, 0.12699639185198716, 0.05273693587098803, 0.19035738121185983, 0.16724396789712564, 0.14682986188147748, 0.08694078693432467, 0.09964669442602567, 0.10824054399771349, 0.10464289704603807, 0.11003374241824661, 0.13960461744240352, 0.08015842230192252, 0.23369093452181133, 0.1709597749369485, 0.14146544544824532, 0.21996624741171086, 0.16751949382679804, 0.15348318272403308, 0.15873405310724462, 0.17244496595646652, 0.09519705854888473, 0.2598051689565182, 0.15164395927318505, 0.17822440154850483, 0.22773722399558338, 0.211456156202725, 0.18519743452114718, 0.12489739805459976, 0.2056983115949801, 0.1614872496575117, 0.17824859810726984, 0.1111320870529328], [0.0669646617025137, 0.05037253988640649, 0.04265202934454594, 0.05921113703932081, 0.034816551221800704, 0.047213375834482055, 0.1193228257553918, 0.061513060304735384, 0.023236523315842663, 0.027571003318631222, 0.0325054032728076, 0.03248031444049307, 0.04294491219999535, 0.06104162095912865, 0.016643017031518475, 0.051759506176624975, 0.028768727888486216, 0.024145746670131172, 0.018923076202294657, 0.03507041831367782, 0.026346849809799875, 0.04371650490377631, 0.07648827388350453, 0.0282080679732774, 0.011580193298868835, 0.02231037220917642, 0.0910694282501936, 0.05017594115010329, 0.04593540262430906, 0.0460695252487702, 0.05891296839607613, 0.03063069244048425, 0.03837267183033483, 0.04709498165175319, 0.05629305308684707, 0.07203442430389778, 0.03735807538032532, 0.021180178837052414, 0.06524884341550724, 0.022102676032643234, 0.048588420264422894, 0.05797419484172549, 0.06931424526763813, 0.025937723727630715, 0.015810144133865833, 0.037196807962443144, 0.020065501864467348, 0.010132534595738565, 0.041843958598162444, 0.014890841141875302, 0.02108106861955353, 0.06613422983459064, 0.055306225682475736, 0.03955961956775614, 0.10053209441580943, 0.022609592581700002, 0.03551358649773257, 0.01204125105869025, 0.07844980327146393, 0.05310613355998482, 0.04182170943490096, 0.053903079724737575, 0.046531397250614, 0.058980279069926055, 0.05950680867369686, 0.037424178261842043, 0.02388506199765418, 0.07409993918346507, 0.017356145461755138, 0.020171392343140075, 0.24598571764571325, 0.2255073543637991, 0.32985275451626095, 0.07326440473220178, 0.06966543463724, 0.9435877331665584, 3.5182605258056094, 7.264087149075099, 10.00446275302342, 18.321386984416417, 32.61795350483486, 45.9554306438991, 55.14406197411673, 63.809017998831614, 57.3935238974435, 62.23740495954241, 63.59707709721157, 57.35229328700474, 60.03483990260533, 58.88586493900844, 56.36667742047991, 58.54489598955427, 55.3118713923863, 57.526415143694194, 56.63708046504429, 55.657728399549214, 51.499749183654785, 47.20620366505214, 44.03231518609183, 49.566840239933555, 46.34789269311087, 36.86977161679949, 26.540706396102905, 15.973368338176183, 14.443010228020803, 9.535761594772339, 4.93152346781322, 2.1925652963774542, 0.3813561408647469, 0.14042704259710653, 0.04260466420756919, 0.24401128930704935, 0.17944618527378353, 0.24921644000070436, 0.1783327093081815, 0.08722659266952958, 0.03037369730217116, 0.017364099588511244, 0.027740776172972152, 0.07295739477766411, 0.04689443723431655, 0.043979674710759094, 0.1390899486307587, 0.042107576238257546, 0.04237536347604223, 0.05705199111253023, 0.08019254582801036, 0.06518588893647705, 0.03015080194122025, 0.07407284528017044, 0.03376287794006722, 0.019957385790933455, 0.04279019943039332, 0.0859419833868742, 0.05058662447014025, 0.03942235532615866, 0.018795565901590244, 0.008306826714293232, 0.03575676327039089, 0.018585642433858345, 0.053055833759052415, 0.04548436343403799, 0.0394188201587115, 0.06279644822435719, 0.08565714117139578, 0.02821512982648398, 0.041295305360108614, 0.03220496492992554, 0.04492781204836709, 0.044146227916436534, 0.014916913849966866, 0.05700430367141962, 0.04133445343800953, 0.05841655896178313, 0.022806762983756404, 0.041145182879907746, 0.060174426063895226, 0.027105828547584157, 0.043700355770332475, 0.08313448367906467, 0.012196599106703485, 0.03587392591206091, 0.011633232684939035, 0.022547891696116755, 0.017430679140878574, 0.043177398653434854, 0.02537935895712248, 0.013317147103537406, 0.02944701524185283, 0.034439163615128825, 0.08317725174129009, 0.04763654759153724, 0.031257224535303454, 0.05189978650638035, 0.012872050183692148, 0.032242274177925925, 0.03307920641132763, 0.05733958139483418, 0.036004560866526196, 0.08097640983760357, 0.03102407990289586, 0.01821898076949375, 0.06789364399654524, 0.058412372400718074, 0.039824499282985926, 0.053989915243749104, 0.042416017901684554, 0.018515950102092962, 0.028918351645448377, 0.03238469867834023, 0.024823185854724476, 0.014700076110394937, 0.06146898266992398, 0.03015444567427039, 0.045847671439072916, 0.051197550259530544, 0.028254668062020625, 0.036558225085692744, 0.03747512945639236, 0.04764565692416259, 0.042298573667981794, 0.021790295473432968, 0.05629996735868709, 0.03965154749208263, 0.12142901202397686, 0.053560283833316395, 0.07052895865802254, 0.06456346876387085, 0.031999711479459486, 0.004436842523448701, 0.04190853138321212, 0.0313376784324646, 0.07352895875062261, 0.029033699205943515, 0.04746132610099656, 0.026418453913980296, 0.01887457282282412, 0.02883834218872445, 0.11001244320401124, 0.03430761263838836, 0.008281920238264968, 0.017906890284003954, 0.03243272199428507, 0.015591313197676624, 0.009662111356322254, 0.007829248323105276, 0.01845270554934229, 0.03452329517209104, 0.0748548229624118, 0.08107004767017705, 0.03191982415903892, 0.014050558641819018, 0.017209320661744902, 0.0417139546812645, 0.02466687004614089, 0.06993945421917097, 0.04540547016741974, 0.080105170873659, 0.06939106900244951, 0.09270650933363608, 0.015370265148313982, 0.048873211589774916, 0.0735672213403242, 0.11176055297255516, 0.017732333757781556, 0.09824607601123196, 0.21881238504179887, 0.1289112583867141, 0.29639932247144835, 0.332163790506976, 0.9028296545147896, 4.246025051389422, 10.402109895433698, 19.579408713749476, 25.60732708658491, 37.10132728304182, 50.6402987071446, 62.06399876730782, 70.55958202907017, 71.63567733764648, 69.7307939529419, 74.14340032849992, 72.72540501185826, 70.64791447775704, 72.93464306422642, 74.36610398973737, 74.95715250287736, 75.43532752990723, 73.45379856654576, 74.64103031158447, 72.88468551635742, 71.22605323791504, 69.67285987309047, 65.75689683641706, 62.33591651916504, 61.4105623790196, 59.021584102085654, 50.539765221732004, 40.543454442705425, 28.56905232157026, 26.185137544359478, 20.557431936264038, 15.322084154401507, 8.266416038785662, 3.2235872064317976, 1.5637543009860175, 0.4307812830167157, 0.3772201713706766, 0.22818559993590626, 0.09974151969488178, 0.15539594580020222, 0.1693531804318939, 0.1099266085241522, 0.07761213822024209, 0.04110921713124428, 0.07441266240285975, 0.020310826200459684, 0.02788635586122317, 0.10714026553822414, 0.0670529662498406, 0.059968212486377785, 0.04735453825976167, 0.06441003842545406, 0.042073357717267106, 0.03683806989075882, 0.0287348995251315, 0.06246489565819502, 0.05422168584274394, 0.008310970866919627, 0.004102883278392255, 0.0416552172973752, 0.011722578783519566, 0.13484972901642323, 0.015868608407410126, 0.035119707097432444, 0.017788185671504055, 0.0313162401185504, 0.044041353543954234, 0.08448263776621648, 0.07877110995884452, 0.046220543395195685, 0.046113894653639624, 0.03490467595734766, 0.049121735218380175, 0.006271790355510477, 0.019627280200698545, 0.022544034224535738, 0.0005176874443090387, 0.02352546388283372, 0.08910351552601371, 0.045366864917533736, 0.0397614057042769, 0.032648357030536444, 0.05918436883283513, 0.01545264438859054, 0.005030360072851181, 0.05296326122645821, 0.09311707730271987, 0.04144310046519552, 0.005005644858881299, 0.018999017841581787, 0.010702713509090245, 0.05024595239332744, 0.03397460800728627, 0.008951941338766898, 0.017898054061723605, 0.07962463237345219, 0.0913124591378229, 0.040927963464387825, 0.057057460104780536, 0.015818155936098525, 0.08569883036294154, 0.14263652903693064, 0.16557968434478554, 0.08788298709051949, 0.18289070044245037, 0.15780914202332497, 0.10542097315192223, 0.28231673528041157, 0.1292077646191631, 0.104290208114045, 0.10992980442409005, 0.102250463994486, 0.14858401061168738, 0.11701610524739538, 0.1602951314832483, 0.14833695601139749, 0.12102921919098922, 0.12821486432637486, 0.10849484535200254, 0.1585415391517537, 0.13680624403059483, 0.16604806349745818, 0.10133683694792645, 0.21932400044585976, 0.09221358756933894, 0.1896075185920511, 0.10706736373582057, 0.21870703569480351, 0.10337878630629607, 0.17729187730167592, 0.08355138916522264, 0.1317489461175033, 0.1093949627663408, 0.1648263204842806, 0.11544399389198848, 0.12994107098451682, 0.16566303558647633, 0.23893354034849576, 0.1287280810730798, 0.1542836097734315, 0.09650645471577134, 0.1306241521877902, 0.09581424043114696, 0.20425558329692908, 0.1536341703363827, 0.13712406983332975, 0.10908567971949067, 0.08924055924373013, 0.1379243747464248, 0.1790860460272857, 0.07737551270318882, 0.13690487588090555, 0.18029204702803067, 0.18707951424377306, 0.27828751291547504, 0.22074080870619842, 0.10593990994883434, 0.08339861022042376, 0.09556403742837054, 0.19838071853986808, 0.16387861062373432, 0.1508218055324895, 0.17607117923242704, 0.15699245727487973, 0.1310308796486684, 0.21180523532841886, 0.1100949394915785, 0.2151493408850261, 0.19073501309113844, 0.07039082249892609, 0.17117556264357908, 0.43023175107581274, 0.33371863993150847, 0.4586547144821712, 0.18627223399068626, 0.2681526696043355, 1.682705072419984, 5.205249054091317, 12.530509880610875, 18.785776785441808, 32.40930257524763, 49.266691957201274, 63.81857872009277, 75.29559230804443, 82.80833898271833, 78.98763574872697, 84.156247820173, 82.74144867488316, 80.69593375069755, 80.20379979269845, 79.22378417423793, 80.56434876578194, 81.91729504721505, 77.14299324580601, 77.59558500562395, 75.72159331185478, 76.02341611044747, 71.7648651940482, 68.5464735031128, 65.40674236842564, 71.25783429827008, 66.08787427629743, 53.44769055502755, 39.87097304207938, 28.14995435306004, 22.28263316835676, 13.571412563323975, 8.633130669593811, 3.943782755306789, 1.1933651587792804, 0.4918874597975186, 0.16260178413774284, 0.3014963146831308, 0.2577014389847006, 0.3050374260970524, 0.2534529412431376, 0.24336833666477883, 0.11965042246239525, 0.11422149091959, 0.11514086515775748, 0.11774800025991031, 0.1214305048010179, 0.0779233890186463, 0.2703835027558463, 0.1560897614274706, 0.1869909789945398, 0.12777916342020035, 0.16374139727226325, 0.19593047430472715, 0.06568706847195115, 0.15774776174553803, 0.17686853930354118, 0.15755045733281545, 0.12879160552152566, 0.14079873050962174, 0.1341092844626733, 0.1015270845964551, 0.1746217334376914, 0.05254913434120161, 0.146625975679074, 0.11692086607217789, 0.10116679607225315, 0.11328612361103296, 0.16906811429985932, 0.14468508054103169, 0.22070228148783955, 0.13203903340867587, 0.18368837263967308, 0.15563454585415976, 0.11730969377926417, 0.09676458300756556, 0.06792955885508231, 0.12066479160317353, 0.11589318407433373, 0.14439297121550354, 0.14065705239772797, 0.12956311340842927, 0.2403936662844249, 0.1144045325262206, 0.0838974623807839, 0.12836923104311737, 0.12085533780711037, 0.18674028744654997, 0.0722600304122482, 0.09782524859266621, 0.09465083107352257, 0.1438036092690059, 0.16210255878312246, 0.14540200707103523, 0.06686907647443668, 0.13794578931161336, 0.22396318508046015, 0.16659163790089743, 0.07621767411806754, 0.1929643534656082, 0.08781182912311383, 0.2130717480821269], [0.02341654204896518, 0.0367515804246068, 0.02247930028741913, 0.0704012583675129, 0.025461814532588636, 0.04908489755221775, 0.012996443464154643, 0.04250859721962895, 0.019852923628474985, 0.03983440589425819, 0.04145118520994272, 0.028812931052276065, 0.0428285671930228, 0.026729190722107887, 0.04978339507111481, 0.02102179010398686, 0.04648594558238983, 0.027358185899044787, 0.02126722639825727, 0.06611404341778584, 0.04502035404688545, 0.04242436388241393, 0.04058917771492686, 0.012920903856866062, 0.014289240119978786, 0.040402974135109355, 0.052911689172365835, 0.048853120167872736, 0.04293227109259792, 0.04657393121825797, 0.04741242408220257, 0.02162901618118797, 0.030053710365401845, 0.0909363403916359, 0.04624181886070541, 0.012306418303134186, 0.06153567587690694, 0.04198886314406991, 0.02482936730874436, 0.04076231271028519, 0.03230318965922509, 0.0353333404553788, 0.00999235943891108, 0.07876940683594771, 0.05383844587153622, 0.03206073891903673, 0.027197339172874178, 0.01823703828267753, 0.02248932733865721, 0.010373000620997377, 0.06449353894484894, 0.015620741261435407, 0.02105889918415674, 0.039596006008131165, 0.04351469501852989, 0.002350700815441087, 0.017002947628498077, 0.015639777561383586, 0.05638522528378027, 0.09496090122099433, 0.03135228389874101, 0.06071564595081976, 0.037190562047596486, 0.011774145748599299, 0.0443285333125719, 0.022119931178167462, 0.04943091987765261, 0.07319432563547577, 0.04171973919229848, 0.03303045367023774, 0.08910702355206013, 0.12509937078825065, 0.1120128526485392, 0.030711010630641664, 0.07132623730493443, 0.09811488126537629, 0.051267758277910094, 0.1116284422044243, 0.1724745500832796, 0.08608056059373276, 0.21317605248519353, 0.4405951521226338, 1.3381695257765907, 2.5026961863040924, 3.662339891706194, 4.494569931711469, 6.1503243531499585, 4.901825564248221, 5.722665769713266, 5.424509014402117, 4.054393299988337, 4.853726659502302, 3.7005801711763655, 3.584910035133362, 3.3483149707317352, 2.967647271496909, 2.195482454129628, 2.66779710991042, 1.5021733939647675, 0.5369996162397521, 0.721346452832222, 0.26423741398113115, 0.021675344855923737, 0.15975461048739298, 0.3371404106063502, 0.29978086959038464, 0.1271862323795046, 0.08129941286253077, 0.04969842213072947, 0.059927819296717644, 0.023362486556704556, 0.08836753573268652, 0.1025851581777845, 0.1417601060654436, 0.018080403562635183, 0.0744887465345008, 0.030751067945467572, 0.08996106843863215, 0.06735802880887475, 0.0731078599180494, 0.045949115817035945, 0.007375114164980394, 0.022370293636673262, 0.0762321472700153, 0.027964051513533508, 0.023287628877109716, 0.051877164148858616, 0.009752976525175785, 0.0311737647280097, 0.02914723168526377, 0.015170577381338392, 0.009975581812406225, 0.05346578765394432, 0.055012603223856, 0.024447930544348698, 0.05208919955683606, 0.025482818584090898, 0.05577867943793535, 0.03380783088505268, 0.03479544199737055, 0.040489344857633114, 0.020043079674776112, 0.035526370097483904, 0.02490081704620804, 0.060709776622908454, 0.0699454185419849, 0.03928158645118986, 0.0815906265218343, 0.008184397792709725, 0.08836241279329572, 0.0781302811311824, 0.027958996427644576, 0.02010559819505683, 0.047358884276556115, 0.03659271162801555, 0.04072609929633992, 0.05495663426284279, 0.015265244890802672, 0.032964988611638546, 0.011918450639184033, 0.012269024238256472, 0.023657586525327394, 0.027424721346635903, 0.047615048209471364, 0.03826412658340164, 0.011064594046079686, 0.02687028529388564, 0.02856446849182248, 0.043393417061971765, 0.01119619167210268, 0.024734226521104574, 0.011406906481300081, 0.10456408520362206, 0.04933872053931866, 0.005628886058860059, 0.032165104390255043, 0.007246713287064007, 0.05059867525207145, 0.02359895092169089, 0.05782412325165101, 0.04000164781297956, 0.027160728815943003, 0.0377611150033772, 0.051373742055147886, 0.010005638369226029, 0.014577576790803244, 0.047509128893060346, 0.03870550004233207, 0.04914200305938721, 0.03025949646585754, 0.061178718959646564, 0.07812911405095033, 0.04137968797502773, 0.02332655812746712, 0.0157962545220341, 0.08348004120801177, 0.03699936105736664, 0.08524771314114332, 0.009230937126890888, 0.02256893476338259, 0.02610688081144222, 0.053566377077783854, 0.006849031970237515, 0.007858763748247708, 0.0030233743517393513, 0.054827834745602946, 0.013961654439169382, 0.011303941336726504, 0.016175419890454838, 0.010003801235663039, 0.07605388254991599, 0.03598533796944788, 0.05388883727469614, 0.04454755423856633, 0.05083041870966554, 0.07482702338269778, 0.006130136840511113, 0.020696057671947137, 0.04441660715799246, 0.033416665624827147, 0.06093515881470271, 0.01912473511349942, 0.019947285797180872, 0.013734805763566067, 0.042106134351342916, 0.021861763870609657, 0.02761477222000914, 0.033599697053432465, 0.0325212674215436, 0.004764947283547372, 0.035363501336957724, 0.02644372425441231, 0.012271190461303507, 0.02701641459550176, 0.008447582866730434, 0.06485796653266464, 0.03404815781063267, 0.020723540036539947, 0.0338757963451956, 0.04659873167318957, 0.08326155971735716, 0.021113709546625614, 0.049612526382718763, 0.09083740998591695, 0.06052609719336033, 0.12286887690424919, 0.1690435649028846, 0.039731892823640785, 0.02954453768740807, 0.07738483577434506, 0.11037788180900471, 0.11052234191447496, 0.028067485695438724, 0.035351664293557405, 0.0906771400145122, 0.18186084713254655, 0.6180433503219059, 2.9437231038297926, 5.725718200206757, 8.974921243531362, 11.682510035378591, 12.900814993040902, 14.842305830546788, 12.40950265952519, 13.531943321228027, 12.867520093917847, 10.628994635173253, 11.478772350719996, 11.050256967544556, 9.376118046896798, 8.796388149261475, 8.432434558868408, 6.822848745754786, 6.162911449159894, 5.207322222845895, 4.156500118119376, 3.239936969109944, 1.4695624581405093, 0.10407777915575675, 0.3091490497546536, 0.3360607256846768, 0.22144599658037933, 0.11278727145067283, 0.09563678995307003, 0.09766886662691832, 0.015346631773614457, 0.0859031779691577, 0.11399027332663536, 0.06857986003160477, 0.05266130296513438, 0.08588075917214155, 0.04299886591200318, 0.011150069950547601, 0.028009532019495964, 0.006013046717271209, 0.0221240295296801, 0.03053991463301437, 0.07683103584817477, 0.036778867710381746, 0.04499300230028374, 0.03334756701120308, 0.04788353433832526, 0.06826694003705468, 0.037370099020855765, 0.02806388776350234, 0.044156575575470924, 0.019855086458846927, 0.017758214779730355, 0.047327939687030654, 0.02154234690325601, 0.04734101505684001, 0.06360472592392138, 0.02406963370075183, 0.025924726389348507, 0.08492244380925383, 0.07203306723386049, 0.026225872104987502, 0.02650733182339796, 0.033841231771345646, 0.02375672388422702, 0.008774481530833458, 0.032670382277241776, 0.03785525834453957, 0.03513551017801676, 0.03482909733429551, 0.011663069566046553, 0.05201704414295299, 0.043771557842514346, 0.017512069416365454, 0.04696309480017849, 0.05503314247887049, 0.02363728136489434, 0.03640845205102648, 0.06124208734503814, 0.024110844525109445, 0.05244087068630116, 0.022926629587475742, 0.07710641928549324, 0.06749767131571259, 0.061761967305626185, 0.042417724417256455, 0.07782789200012173, 0.04696856718510389, 0.035402530671230385, 0.03703461434426052, 0.0067901720259604705, 0.05085153132677078, 0.026671423643295254, 0.06044413694845779, 0.016814264003187418, 0.010378142220101185, 0.023493123207507387, 0.10201177573097603, 0.1228519542408841, 0.1121790258746062, 0.21937594908688748, 0.11250902459557567, 0.09478258900344372, 0.19063642195292882, 0.13511105999350548, 0.10125911076154027, 0.15712648151176317, 0.19423831653382095, 0.1556667491261448, 0.0925918844129358, 0.12222916765936784, 0.09626224996255976, 0.17941935599914619, 0.10787088490490403, 0.08682725445500442, 0.061689384414681366, 0.17540844050901278, 0.11256723611482553, 0.19690981746784278, 0.10379708957459245, 0.1202519301857267, 0.08749319586370673, 0.08081651306045906, 0.08408550479050193, 0.21048488760633127, 0.09692924988589116, 0.12210867341075625, 0.1002048776884164, 0.15339688664036139, 0.08078935808901276, 0.16890650082911762, 0.1371009046477931, 0.07619156409054995, 0.2177083000008549, 0.14589151580418858, 0.13840736954339913, 0.16055381617375783, 0.179194231650659, 0.10651869353439126, 0.12396317747022424, 0.12740571131663664, 0.09725415280887059, 0.15859561839273997, 0.18636652321687766, 0.15357341431081295, 0.09831962242190327, 0.10817584568368536, 0.13600796115185532, 0.06525104186896767, 0.10486947345946517, 0.18518133967050485, 0.11944413424602576, 0.1750114160989012, 0.08639761965189661, 0.11360172381890671, 0.08930548147431441, 0.16975844225713185, 0.130439997783729, 0.13072959652968816, 0.09543092921376228, 0.1560752543487719, 0.23332571983337402, 0.0999757092712181, 0.2587864707623209, 0.1809933129698038, 0.10857708379626274, 0.15405898754085812, 0.2803695026252951, 0.2840435526200703, 0.24588700437120029, 0.13399500559483254, 0.17469786506678375, 0.12146239594689437, 0.1676840249981199, 0.1834368939910616, 0.2519654296338558, 0.21628819406032562, 0.2897698182080473, 1.1319558939763477, 2.6363730132579803, 4.481136892523084, 6.982898763247898, 7.891897712435041, 9.07230111530849, 7.924195545060294, 8.707059502601624, 8.58387315273285, 6.8245362894875665, 7.480635574885777, 7.204561931746347, 5.398430253778185, 5.056000445570264, 4.815262734889984, 3.7140601107052396, 3.466336203472955, 2.968627618891852, 1.9468211914811815, 1.5221036502293177, 0.6434475385716983, 0.15627559859837803, 0.30201875950608936, 0.36732248961925507, 0.4449798454131399, 0.25044532120227814, 0.1782812356416668, 0.18951185872512205, 0.1390184446104935, 0.19057943858206272, 0.18278490326234273, 0.1527900184903826, 0.3036595657467842, 0.19058682104306562, 0.13817350566387177, 0.08764359315059014, 0.20994637507413114, 0.17622094548174314, 0.14024472023759568, 0.13147481796996935, 0.11083136033266783, 0.10984987978424345, 0.1527317866150822, 0.18304753702666077, 0.10839359435651984, 0.16311189319406236, 0.12542474190039293, 0.10979032476565667, 0.11460320757968084, 0.07611928654036351, 0.15686076719846043, 0.11946117904569421, 0.07442068947213036, 0.10359808882432324, 0.25181721044438227, 0.15232315925615175, 0.1711372389857258, 0.20647690338747843, 0.159048038401774, 0.14037451041596277, 0.08262937542583261, 0.11519651859998703, 0.10588335405503001, 0.13602706869798048, 0.14265027615640843, 0.15029975425984177, 0.15457738829510553, 0.15940318363053457, 0.14230867448662007, 0.17040158488920756, 0.1327448726764747, 0.09632293813462768, 0.15734515977757318, 0.11535940771656376, 0.15147469192743301, 0.14722361575279916, 0.15603982125009808, 0.12065932261092321, 0.1306568304342883, 0.09116902362023081, 0.18739994562097959, 0.1101941955941064, 0.2549055761524609, 0.23957212322524615, 0.1618502251803875, 0.08308530346091304, 0.11728236238871302, 0.13848905158894403, 0.09231003453688962, 0.21250765477972372, 0.09629585101668324, 0.22246143780648708, 0.061268611278917105, 0.09879996414695467, 0.06459956682686295], [0.04846773263333099, 0.041228724111403735, 0.022811187032077993, 0.048193170223385096, 0.037363758111106496, 0.03565848086561475, 0.0730050482920238, 0.040660746196018796, 0.00773066736292094, 0.03151042327018721, 0.013241113013853984, 0.030243103059806993, 0.018726523267105222, 0.01527763663658074, 0.013539806673569339, 0.026562109955453446, 0.024754713189655116, 0.05276260824341859, 0.051120292262307236, 0.03496150326515947, 0.043521470190691094, 0.03756478428840637, 0.014816336300490158, 0.04253071406856179, 0.03461683461708682, 0.039883667536612065, 0.05777047827307667, 0.05104850325733423, 0.02786220340723438, 0.019723769576687897, 0.018497680546715856, 0.02112522428589208, 0.022935477684118917, 0.019824677911986197, 0.02079750374624772, 0.03556832391768694, 0.08432374522089958, 0.05508856861186879, 0.016611940127664378, 0.05185193282419017, 0.010594706849328108, 0.04261694569140673, 0.0026965679259904262, 0.010751210951379367, 0.0693029205181769, 0.021151497161814144, 0.05952894248600517, 0.04896189611671226, 0.029640523251146078, 0.012220845707426113, 0.010592234437353909, 0.02545898673789842, 0.03022052819973656, 0.06505482311227492, 0.02632001374981233, 0.02788675280420908, 0.05618672664942486, 0.023563142932419266, 0.08352901108030762, 0.08580586926213332, 0.07560868893883058, 0.05331100024549024, 0.03072328193645392, 0.03716323744239552, 0.04838026607675212, 0.04702564894354769, 0.0034336007208496866, 0.02919006420831595, 0.07007336989045143, 0.04529236177248614, 0.08396370096930436, 0.09793215857020446, 0.0902171271986195, 0.037079686032874246, 0.0656168604535716, 0.055416372272052934, 0.03744153179494398, 0.06248930934816599, 0.0861975671723485, 0.09283866081386805, 0.09939118527940341, 0.04335896444639989, 0.019492870895192027, 0.03291172021999955, 0.1041202690186245, 0.25673737643020494, 0.20635113013642176, 0.1505165190568992, 0.1754509032304798, 0.2989148146339825, 0.2557479366660118, 0.26101176706807955, 0.2589599857372897, 0.2606926927609103, 0.18448364282292978, 0.16381955093571118, 0.048275032080709934, 0.26527972519397736, 0.10480052073087011, 0.047933172567614486, 0.03027755567537887, 0.03673574002459645, 0.013538901677488216, 0.12905134872666427, 0.09255326898502451, 0.18676403617220266, 0.04109461505764297, 0.031586778815835714, 0.05054273343245898, 0.053723861662937064, 0.02656762644515506, 0.08512388728559017, 0.08973558446658508, 0.11391572946948664, 0.06335543215806995, 0.005374234410867627, 0.02294431729907436, 0.005359528860675969, 0.01994836127518543, 0.02435665570997766, 0.10408817431224243, 0.03339498643098133, 0.02911224981237735, 0.07951801416597196, 0.03489605177726064, 0.0458540530609233, 0.05647647128041301, 0.04977168694936803, 0.02159819203162832, 0.02084006485529244, 0.037902457240436754, 0.042405880588505945, 0.04887192915858967, 0.027771788615999476, 0.015119578689336777, 0.03023110656067729, 0.0299791325815022, 0.028896604598100697, 0.009967837183337127, 0.036217135709843466, 0.020247199971761023, 0.0074108118923114875, 0.025166639925113747, 0.009542107349261642, 0.0025407684401475956, 0.0045510450560998705, 0.006262377802548664, 0.037087258483682356, 0.02697927667759359, 0.029970192882631506, 0.04543737827667168, 0.02530177865576531, 0.02656790125183761, 0.009877990665180343, 0.10879443891878639, 0.02075642523621874, 0.02236216139447476, 0.09374227268355233, 0.0644191647214549, 0.04562070486801011, 0.07958529769842114, 0.05301771366170474, 0.039376282798392434, 0.051169319810079675, 0.03479635462697063, 0.03609600363831435, 0.0296550710419459, 0.010802033224276133, 0.010437062808445521, 0.013065795680241925, 0.034366818211440525, 0.011384635265650494, 0.04222252346309168, 0.06124002459858145, 0.025003771164587567, 0.00863551247000162, 0.023856912972405553, 0.020320588623040488, 0.061175916610019546, 0.025944030710629055, 0.03018766674878342, 0.015566673894811953, 0.06506511648850781, 0.011096208688936062, 0.03365672792174986, 0.016011923485036408, 0.064857980103365, 0.0272106825640159, 0.02666504880679505, 0.021133461701018468, 0.025487941523481692, 0.026476168406328986, 0.029594664461910725, 0.07322903270167963, 0.03370493444214974, 0.02374007772388203, 0.0697784921420472, 0.016149620292708278, 0.04655147170914071, 0.032114448358437846, 0.04953245925051825, 0.018989540403708816, 0.04540993492784245, 0.02221007116271981, 0.059740204364061356, 0.02679969899223319, 0.04218731428097401, 0.003407793489584167, 0.0374570838175714, 0.04422050714492798, 0.04267303339604821, 0.03868164614375148, 0.024999654153361917, 0.04176358951787863, 0.039021565046693595, 0.05750375294259616, 0.009801317056241845, 0.0547468312350767, 0.011082453087770512, 0.03591565242303269, 0.03787064751876252, 0.03310549285795007, 0.010660719824954867, 0.033993844475064955, 0.03221247631258198, 0.02866842344935451, 0.030820387082972696, 0.030380061960646083, 0.0394875998608768, 0.08331964910030365, 0.022811144623639326, 0.012486460784982358, 0.05533500574529171, 0.059271241671272686, 0.013673892826773226, 0.06903396959283523, 0.0240187944644796, 0.038343209839825115, 0.04114618032638516, 0.05903334729373455, 0.03848172597853201, 0.03500303639365094, 0.0624588770525796, 0.06180979045374053, 0.039978387632540295, 0.003448171624248581, 0.13188641731228146, 0.04900076938793063, 0.032509963028132915, 0.024272196759868945, 0.04205809407202261, 0.10609541660440819, 0.032301313509898524, 0.07021314810429301, 0.0369451630727521, 0.10930159634777478, 0.1299145674066884, 0.08466405088880233, 0.10979650621967656, 0.08318122117114918, 0.17363576777279377, 0.16960315273276397, 0.16272268550736563, 0.0039822227887011, 0.05377069414992418, 0.1392260491847992, 0.14215129507439478, 0.10060694361371653, 0.19913636227803572, 0.1191869287618569, 0.11555011676890509, 0.19778405555656978, 0.1302238708095891, 0.16572045321975434, 0.19988523423671722, 0.09563364833593369, 0.08545828969883067, 0.019191689556464553, 0.056633996577667337, 0.06562863303614513, 0.07290155134562935, 0.09068789479455777, 0.027196933748200536, 0.03265536629727908, 0.020106088436607803, 0.04135918264676418, 0.035490434882896285, 0.07597619029028074, 0.055253710464707444, 0.10396236034908465, 0.049368084142250676, 0.08204036631754466, 0.0248108738368111, 0.036829523742198944, 0.05006796587258577, 0.007224505684072418, 0.05121608105088983, 0.02899663083787475, 0.03942010598257184, 0.004804783226323447, 0.04947782021814159, 0.03497643103556974, 0.03827260148578456, 0.08154892375958817, 0.04422259024743523, 0.022588841284492185, 0.03477571698437844, 0.00755710743500718, 0.00612481076469911, 0.022415324613185864, 0.07847491585250412, 0.04424761801159807, 0.02447292777443571, 0.04094377672299743, 0.006036606301287455, 0.04680554236152342, 0.03397191761593733, 0.012706551251799932, 0.03065028174647263, 0.016150393822629536, 0.03066169809816139, 0.05939320155552455, 0.043886681486453326, 0.02474623150192201, 0.09006544748055083, 0.02630405460617372, 0.04658066228564296, 0.031965886508779864, 0.03612596435206277, 0.028261124322723066, 0.05136729936514582, 0.031295348025326214, 0.04661380532862885, 0.05820132086851767, 0.042616324831864665, 0.040803299618086646, 0.04928215107481394, 0.0017376744300625952, 0.030295221334589378, 0.035949762378420146, 0.03000743766980512, 0.04487746474998338, 0.03356013846184526, 0.02033783189420189, 0.06870085639613015, 0.008043212466873229, 0.023460548437599624, 0.03690348405923162, 0.03639627234744174, 0.0282575671028878, 0.07614665864301579, 0.0030206008398506257, 0.13716639684779303, 0.10215214427028384, 0.10781894983457667, 0.16337345487305097, 0.08565811826182262, 0.08232379718018429, 0.2171475722321442, 0.10429385184709515, 0.06830902956426144, 0.13382078494344438, 0.13834398080195698, 0.23919379924024853, 0.11551731638610363, 0.07839910992022071, 0.09194701830191271, 0.14460016866879805, 0.14196224164749893, 0.1702380579497133, 0.22076147688286646, 0.09503428478326116, 0.12843128985592298, 0.06528427651418106, 0.15163516545934336, 0.12373111849384648, 0.1500473799450057, 0.12164364622107574, 0.10918122423546654, 0.10327739281845943, 0.3014008583767073, 0.09026062129331486, 0.09526471527559416, 0.23028306024415152, 0.12669778216098035, 0.084156459197402, 0.1915825440415314, 0.12740514134722097, 0.12833921265389236, 0.11504756659269333, 0.12050434521266393, 0.17291642565812382, 0.07593628564583403, 0.12217103077897004, 0.09674531261303596, 0.14163532347551414, 0.12401379618261542, 0.1523640884884766, 0.09135489471788917, 0.09272817495678153, 0.09632546228489705, 0.10556433403066226, 0.10462561475911311, 0.10063650059912886, 0.08152204020214932, 0.23022381056632313, 0.1871083112699645, 0.10826844535768032, 0.14305172461484159, 0.14714775553771428, 0.19395657522337778, 0.18205659091472626, 0.11398409865796566, 0.1369949717606817, 0.11437549122742244, 0.11559822490172726, 0.13075600511261395, 0.0946385156629341, 0.21774404522563728, 0.23591237674866403, 0.17529771716466971, 0.10298009948538882, 0.3245317371828215, 0.20346300011234625, 0.17665324014212402, 0.12319316236036164, 0.17695639601775578, 0.17049784186695302, 0.1167848062302385, 0.15494587352233274, 0.0832234328346593, 0.17819169616060598, 0.21239577792584896, 0.11769979713218552, 0.13700122785355362, 0.16913310438394547, 0.21128186769783497, 0.31432790043098585, 0.41134961428386824, 0.3651040058050837, 0.31760473602584427, 0.4608429084931101, 0.32117081752845217, 0.38188203264560017, 0.3990810497530869, 0.4202538122023855, 0.38471540489367073, 0.24419403235827172, 0.13499862674091542, 0.3838681046451841, 0.29604493720190866, 0.11177222377487592, 0.13692931671227726, 0.18077667030904973, 0.08547297319663422, 0.34202705696225166, 0.28290190388049397, 0.19378425447004183, 0.11520360250558172, 0.13399967391576084, 0.1265849417873791, 0.09959739207157067, 0.12932896454419407, 0.1122321348105158, 0.17725244084639208, 0.22451251346085752, 0.08659429981240205, 0.15413296142859118, 0.09995737525501422, 0.08674305504454033, 0.12092708609998226, 0.06794340775481292, 0.2457076268536704, 0.13426399044692516, 0.07013384093131338, 0.14730983041226864, 0.15763360501400062, 0.11715502850711346, 0.08657348914338009, 0.16193908612642968, 0.17682090614523205, 0.14021194699619496, 0.10446977562138013, 0.13255277941269533, 0.13821758329868317, 0.10536289055432592, 0.13516861333378724, 0.10605509805360011, 0.16047178129000322, 0.09799172037414142, 0.12093459069728851, 0.1590358383421387, 0.12170319445431232, 0.08961841503956489, 0.1969355610864503, 0.10975989247007029, 0.07536282177482333, 0.12656630921576703, 0.08499337786010333, 0.1051277442436133, 0.17841220647096634, 0.09557783883064985, 0.18397684501750128, 0.13138515635260514, 0.05081087690112846, 0.0910926680745823, 0.20158675579088076, 0.13768223273966992, 0.1257570476404258, 0.1827951627118247, 0.13890924118459225, 0.15177924558520317, 0.1493889024215085, 0.10862781785960708, 0.15288342562104973, 0.2455225225005831, 0.11879734109554972, 0.11555669855858598, 0.12836745328136853, 0.1346051035715001, 0.12844802252948284, 0.08763103346739497, 0.11104194367570536, 0.1763822603970766, 0.13148538954555988, 0.1634634421872241, 0.17480153164693288, 0.12543956110520021], [0.011434618699630457, 0.021430785568164926, 0.052450566951717646, 0.030032017600855658, 0.040248614203717024, 0.06498795348618712, 0.050786205367850404, 0.03546191605606249, 0.04504006888185229, 0.015246427418398005, 0.030741568455206494, 0.09903827243085418, 0.03009020197870476, 0.0182628819852003, 0.04778645972588232, 0.06747217196971178, 0.012301434463422214, 0.04584762054894652, 0.0416219317620354, 0.020014180868331875, 0.028400200252820338, 0.017967424089355127, 0.005716032007642622, 0.011910312459804118, 0.0352805300748774, 0.08899712802043983, 0.014893604475738747, 0.02656465955078602, 0.0056009342328512245, 0.016360603971406817, 0.008750155202246137, 0.049151689146778414, 0.04477673961914011, 0.020231444388628006, 0.018422144332102368, 0.02771426072078092, 0.029626396152057817, 0.06523347459733486, 0.08884846099785396, 0.024002862462241734, 0.035437566826918294, 0.03064689246405448, 0.018098250729963183, 0.026057103482474173, 0.06216091196984053, 0.06212299543299845, 0.014673060238627451, 0.028681665060243437, 0.012831676501913794, 0.03176251260031547, 0.02427517213592572, 0.003985042101703584, 0.01361161857909922, 0.03662263162966285, 0.059005968405732086, 0.03506524787683572, 0.10345176274755172, 0.05687721745510187, 0.00967616805740233, 0.07333634301487889, 0.04290612374565431, 0.06210439000278711, 0.04008931793006403, 0.06555638262735945, 0.0660481983795762, 0.05911093098776681, 0.015937785052561333, 0.014855117969481009, 0.04218499369121023, 0.1174604914018086, 0.01797258774084704, 0.06165117610778127, 0.025148540003491298, 0.06672580380524908, 0.0736693883580821, 0.03390101749183876, 0.06427047055746828, 0.0218111383728683, 0.015071326367823141, 0.042642862336444, 0.13459915960473673, 0.034541605439569266, 0.03183693771383592, 0.022890450100281408, 0.04201194690540433, 0.07288582290389709, 0.07237583598388092, 0.031673098648233075, 0.08659168745258025, 0.045998452098241875, 0.0968662750508104, 0.054183114519608874, 0.061179322855813165, 0.1452625545540026, 0.1103002709735717, 0.038413723198963065, 0.045500767018113814, 0.10121660054262195, 0.03235771334064858, 0.01796853688678571, 0.09873622935265303, 0.061496171568121226, 0.10088650682674986, 0.058331762440502644, 0.11553755030035973, 0.03729479520448616, 0.013298379673090364, 0.030994332927678312, 0.038340556767902205, 0.02695923105680517, 0.02725285860443754, 0.08599537730749164, 0.022931889930207814, 0.13590311392077378, 0.034644366175468476, 0.02725015294605068, 0.05387260332437498, 0.009064572214681123, 0.028131961789248244, 0.04300122042851789, 0.03519170305558613, 0.063671188428998, 0.07189381827733346, 0.059599225143236775, 0.09798287906284843, 0.05936228750007493, 0.014560348786679762, 0.08178187840219055, 0.0971379808283278, 0.10056897279407297, 0.018834703801465884, 0.026901523349806666, 0.06820225529372692, 0.020076673943549395, 0.08947399564619575, 0.041476487780788114, 0.017716289797265614, 0.06129516913954701, 0.03789993987551757, 0.034176621453038285, 0.030898533961070434, 0.04751297279394098, 0.0264201095394258, 0.0701919167435595, 0.04455073656780379, 0.04203799586477024, 0.010688181833497115, 0.030679010919162204, 0.03608963219448924, 0.02634175231547228, 0.05366366882143276, 0.04717903517718826, 0.020069147293855037, 0.01890719000117055, 0.026489952845232825, 0.016317033541521857, 0.03241358730675919, 0.03341979027858802, 0.037439991520451646, 0.05059483813654099, 0.035696970764547586, 0.06915764617068426, 0.02250855532474816, 0.014802896218108279, 0.013939453621527978, 0.019068611785769463, 0.03868190737973366, 0.09066904509173972, 0.02348299098334142, 0.036259863059967756, 0.018642571521922946, 0.029137901828757355, 0.07787714685712542, 0.009112411478002156, 0.0566001783923379, 0.08118216201130833, 0.06446398195943662, 0.053036688893501244, 0.09263161263827767, 0.028552271824862276, 0.06974502000957727, 0.04706737206184438, 0.026298254828101823, 0.023863282719893113, 0.04331227784444179, 0.01727757789194584, 0.027941736193107705, 0.06346350243049008, 0.037618575152009726, 0.03820208812664662, 0.04791995809812631, 0.04715241964108177, 0.037205693378512344, 0.07912417887044804, 0.010886463336646557, 0.002514092472016013, 0.01965012986745153, 0.02000496975545372, 0.06178880336561373, 0.02838614609624658, 0.023753178538754582, 0.029332166404596398, 0.038826693182012866, 0.013277978669585926, 0.016573306040040085, 0.03910883143544197, 0.024994027401719774, 0.01878209358879498, 0.020925473754427264, 0.015908002454255308, 0.019400322111323476, 0.05146248425756182, 0.03405274131468364, 0.014515244867652655, 0.035779819890324555, 0.032016902164156945, 0.03552086039313248, 0.015695008615564023, 0.01734803187926965, 0.048622543790510724, 0.03456659588430609, 0.08322837935494524, 0.07349294889718294, 0.021532682868252908, 0.019924994225480726, 0.0651354059310896, 0.0269785930535623, 0.017172820566754256, 0.1195221793438707, 0.027431382864181484, 0.0033259318443015218, 0.02387082633296294, 0.05350763290854437, 0.0444121695389705, 0.04771490142281566, 0.0027902591931966265, 0.06764392953898225, 0.10501322788851601, 0.08162564571414675, 0.08615253958851099, 0.012179615375186716, 0.021445065337632383, 0.013335781371487039, 0.024742915162018368, 0.01569110873554434, 0.03213989342163716, 0.033319085503795316, 0.012945344688237777, 0.04500519557456885, 0.0982747305450695, 0.050437794599149904, 0.06065284753484385, 0.014885480715227979, 0.06334349672709193, 0.03792389555435095, 0.08047740161418915, 0.06590572638171059, 0.0409063894434699, 0.06037481102560248, 0.039952291175723076, 0.1230512128344604, 0.09455794641481978, 0.0629009697586298, 0.03580907492765358, 0.05726519360073975, 0.03448896130014743, 0.03157445661989706, 0.1373033659266574, 0.0453293826431036, 0.06055591202207974, 0.04036274379385369, 0.025397604763773934, 0.0037780465125771506, 0.06989562764231648, 0.11114808690867253, 0.07014754733869008, 0.059346952608653476, 0.07300868523972374, 0.12134381516703538, 0.04989958740770817, 0.01132069351816816, 0.05773683650685208, 0.04653970591191735, 0.01627779725406851, 0.051555742110524855, 0.03396689984947443, 0.04680157632433942, 0.018962536406304156, 0.02788735500403813, 0.02119303877199335, 0.07948261499404907, 0.05764071523611035, 0.045551473940057416, 0.020351453484701257, 0.07349237214241709, 0.0329362424755735, 0.03576572671798723, 0.01900871580333582, 0.04626089248007961, 0.029091693593987396, 0.023105326873649443, 0.03410481548468981, 0.05378169998792665, 0.046928648969956806, 0.022961764130741358, 0.024008117715961168, 0.014949563258726681, 0.05751346956406321, 0.03992515316765223, 0.061819025315344334, 0.04311813201223101, 0.021481889433094432, 0.06327812666339533, 0.00481483232994963, 0.05253850169745939, 0.01299075988520469, 0.039317745582333634, 0.03372512085895453, 0.03765735003565039, 0.021610789034249525, 0.07136329210230283, 0.02827484599713768, 0.07158376848591225, 0.07378076988139323, 0.07932788186839648, 0.02059389913587698, 0.0485335946349161, 0.04772503873599427, 0.016090518196246455, 0.039925258340580125, 0.03223842688437019, 0.06796847962375198, 0.02002791441710932, 0.021713149434487735, 0.016756379877084067, 0.030885316098907163, 0.02619973323973162, 0.06867580488324165, 0.05423569759087903, 0.07173601817339659, 0.01450757572560438, 0.014801571378484368, 0.0467312020648803, 0.04140589978279812, 0.015248435882053204, 0.04915385028081281, 0.020982462214305997, 0.038669697142073085, 0.09057310024010283, 0.00958303318891142, 0.03495413098218186, 0.013324210653081536, 0.15143627327467712, 0.09013881747211729, 0.22638160602322646, 0.1341944406075137, 0.176275920388954, 0.09971404581197671, 0.13237650958555086, 0.12340975073831421, 0.1166413232151951, 0.1535200271755457, 0.08130147560898747, 0.17783637451274054, 0.15871251640575273, 0.08699654894215719, 0.08452433374311243, 0.14648880303970405, 0.09946436528116465, 0.09586687439254352, 0.11745141260325909, 0.10041853479508843, 0.15040027243750437, 0.08718107654047863, 0.12601658728505882, 0.10007688562784876, 0.09396225373659815, 0.131793471585427, 0.1429714403514351, 0.0960275379142591, 0.12800244215343679, 0.09332427475601435, 0.1299426858978612, 0.12086107821336814, 0.0852770394246493, 0.09687745052256755, 0.1030110881796905, 0.28102882153221537, 0.10259811141129051, 0.14735256454774312, 0.1328109484165907, 0.10724294145724603, 0.08402116610003368, 0.11980769330901758, 0.09184151967721325, 0.1257609152900321, 0.2387144278202738, 0.16325469767408712, 0.17978588704551968, 0.06051678090755429, 0.06637636505599533, 0.11244185641407967, 0.051095556268202405, 0.0721747317750539, 0.17265570536255836, 0.10413426719605923, 0.11557736673525401, 0.14549401641956397, 0.20593769874955925, 0.2037537387971367, 0.14689619546490057, 0.1123213010973164, 0.20386542566120625, 0.20299802720546722, 0.28853108467800276, 0.20172438983406338, 0.15234769508242607, 0.10449245904705354, 0.11081240206424679, 0.329403537192515, 0.16281690688005515, 0.24294224381446838, 0.11970113616968904, 0.11953120385961873, 0.16066985923264707, 0.22651590167411736, 0.13125789032450744, 0.1108935277110764, 0.16153543921453611, 0.15226855075785092, 0.20014903508126736, 0.18663404243332998, 0.2765666666839804, 0.16290040739945003, 0.08909711015543767, 0.04621237383357116, 0.23092329874634743, 0.11344232915767602, 0.1508991585246154, 0.075952767261437, 0.22096571592347963, 0.1464232565569026, 0.16513632956360066, 0.313852708786726, 0.11616649797984532, 0.2500417014317853, 0.18410025696669305, 0.12670747164104665, 0.2131961371217455, 0.14721691182681493, 0.14776390604674816, 0.08690127584018878, 0.2257454523018428, 0.18488741187112673, 0.2534044938428061, 0.17042447866073676, 0.2837562880345753, 0.14039631853146212, 0.08014736896646873, 0.06802611438823597, 0.1297672303127391, 0.09906392105455909, 0.12475137731858663, 0.12239698294017996, 0.13264383881219796, 0.24095234487737927, 0.20664912914591177, 0.11871628330222198, 0.11807018225746495, 0.1633594770516668, 0.22540167931999477, 0.10354937679533448, 0.1612229874091489, 0.11759812544499125, 0.18561761054609502, 0.0878915705585054, 0.24164977031094687, 0.08959841182721512, 0.1480594351887703, 0.19210203045180865, 0.2370610008282321, 0.19343543318765505, 0.19616165118558065, 0.20244701605822357, 0.15206435242933886, 0.19309674921844686, 0.19095472273017677, 0.06315167487732001, 0.09191799057381493, 0.11998293176293373, 0.13275860622525215, 0.1674744798136609, 0.1325601347322975, 0.09306535936359848, 0.08352424097912652, 0.12360848007457596, 0.1011280652933887, 0.06726693548262119, 0.22354854590126447, 0.15193271663572105, 0.11888213083148003, 0.13390887235956533, 0.1863587200641632, 0.13017817826143332, 0.05862455030104943, 0.22604898815708502, 0.17615723104349204, 0.09715606378657476, 0.17600818404129573, 0.14342185189681395, 0.11112471816263028, 0.09027449054909603, 0.06034581043890544, 0.14694754699511187, 0.11722426622041635, 0.13120056768613203, 0.09629764913448266, 0.1283007940011365, 0.23560519037502153, 0.15321620633559568, 0.14898373559117317, 0.1772286378379379, 0.09691785049757787, 0.08859188655125243, 0.27707763069442337, 0.12388551235198975, 0.18651660159230232, 0.22580162143068655], [0.08301818277686834, 0.02767969445059342, 0.02194233820773661, 0.050003352375434976, 0.01902530768087932, 0.01700093916484288, 0.0821511439446892, 0.018346379111920084, 0.029559346714190075, 0.020158137161550776, 0.0376496147364378, 0.0506236487334328, 0.01785108756407031, 0.05309042547430311, 0.0013827118756515639, 0.038384457983608754, 0.03862824204510876, 0.035805997771344016, 0.017438931823042885, 0.038118496005024226, 0.046486060933343, 0.1265730538538524, 0.030252100434154272, 0.022061076746987443, 0.024199174517499547, 0.012234257800238473, 0.03572288401690977, 0.06308836756008011, 0.07564986244376216, 0.007920823409222066, 0.02642165490293077, 0.07645934115030936, 0.018390254882563437, 0.020188998630536453, 0.050595805048942566, 0.047759355644562414, 0.05571853070120726, 0.06285840525690999, 0.015157754765823483, 0.0837388208934239, 0.04024262613217745, 0.010571480595639773, 0.03227067765380655, 0.02881376225767391, 0.040845426464719434, 0.06134736205318144, 0.011106459656730294, 0.013799166506422418, 0.009989514680845397, 0.012591936509124935, 0.023976023009579097, 0.030205586858625923, 0.023183997920049087, 0.0469099281887923, 0.04321142039926989, 0.048463753025446615, 0.03931754541450313, 0.030840563321752206, 0.037832398499761305, 0.0015788347892729299, 0.04886620232303228, 0.021597820533705608, 0.020052204274439385, 0.02741119814371424, 0.03264517130862389, 0.007764608532722507, 0.05307847307994962, 0.05834303290716239, 0.07385226711630821, 0.05067896630082812, 0.11517445264118058, 0.16433761242244924, 0.03859119403309055, 0.019781148194202354, 0.03921269479074648, 0.05899619750146355, 0.023474670447675244, 0.048067637852260044, 0.02142040228604206, 0.04860763976882611, 0.017946014613179222, 0.03744475822895765, 0.020170523818316202, 0.047274196320878606, 0.16029906698635646, 0.11029426593865667, 0.03607117264930691, 0.02174274543566363, 0.04620852654001542, 0.11567880772054195, 0.06420364842883178, 0.05449757818132639, 0.07214512729219028, 0.16247712368411676, 0.037370339900787385, 0.027077616757846305, 0.03503042206700359, 0.030028194056025574, 0.024273033054279428, 0.03358369719769273, 0.04118027671107224, 0.047516161908528635, 0.026155441866389344, 0.08939259858535868, 0.11834078202290194, 0.06319689923631293, 0.01305118088410901, 0.032245487041239224, 0.050857675461364646, 0.04055726960567491, 0.07613779019032206, 0.04667245111029063, 0.02781736750953964, 0.039084933432085175, 0.0412394890694746, 0.07194559728460652, 0.08203914495451109, 0.01397954995211746, 0.06008433696946927, 0.035541827125208716, 0.031843967336629114, 0.04419997128258858, 0.033660049350666146, 0.05569125698613269, 0.05041732659031238, 0.022883490027327622, 0.020049788689772998, 0.040297889416771274, 0.08624332757400614, 0.02749559941834637, 0.05176097181226526, 0.05361289743866239, 0.02719964279926249, 0.09573031243469034, 0.0174607382422047, 0.04742763005197048, 0.03385937240506921, 0.025688285773087825, 0.030659570890877928, 0.02007231435605458, 0.0820854821109346, 0.02688183226356549, 0.04287057190335222, 0.018101902944701057, 0.0637033102767808, 0.01584787237724023, 0.02984382930610861, 0.06967123611164944, 0.01940049513775323, 0.006442344797376011, 0.03182446284751807, 0.036432621468390734, 0.0654538966981428, 0.02755242333348308, 0.033750348790947876, 0.05871672249798264, 0.06863265005605561, 0.028932024126074145, 0.024405746022239327, 0.06214331077145679, 0.018396602577662895, 0.031377365945705345, 0.014836553251370788, 0.02132972965150007, 0.005524565964671118, 0.12356060264366013, 0.0427165614174945, 0.05436635629406997, 0.03773277938099844, 0.003140497553561415, 0.03438919290368046, 0.04724604729562998, 0.03619100532627531, 0.05142992475469198, 0.028425850572862794, 0.014163432094002408, 0.03707846806251577, 0.046176944127572436, 0.030831155433718647, 0.020164510301713432, 0.038549050223082304, 0.036927907927227874, 0.05031287969489183, 0.031528336594679525, 0.01902064275262611, 0.0240437696421785, 0.06848308736724512, 0.056819966062903404, 0.04670736852235027, 0.04300611945135253, 0.014952893169330699, 0.017593632718282085, 0.02859895842682038, 0.015497775449018394, 0.018882236875859753, 0.021694206433104615, 0.043463458839271746, 0.07158313066299472, 0.060703065911574025, 0.02305608049833349, 0.0501015906754349, 0.02570567323294069, 0.059041754342615604, 0.01178088953851589, 0.147791590275509, 0.03753447073644825, 0.02670460400570716, 0.07566947889115129, 0.02067159648452486, 0.048867674744022746, 0.042505465780517886, 0.053102265910378525, 0.035792040306010416, 0.04520435917324253, 0.044530536580298624, 0.019632258951397877, 0.05599143748570766, 0.08868218599153416, 0.005600032629445195, 0.03185722591089351, 0.017240234717194523, 0.046164255522723706, 0.023911114349695187, 0.02001363634397941, 0.03475770866498351, 0.036905160040727684, 0.02957215066999197, 0.03680746117606759, 0.05350850143336824, 0.05595954633983118, 0.06658038696540253, 0.0353815367977534, 0.07042251008429698, 0.030535785747425895, 0.043855811535779915, 0.05188670435122081, 0.0494612978904375, 0.009464490576647222, 0.023099873148437058, 0.032774150637643676, 0.02707565579164241, 0.03841890720650554, 0.04822928524975266, 0.03603719840092318, 0.06594153267464467, 0.04362725719277348, 0.05092585466003843, 0.07382234372198582, 0.052172438840248754, 0.009214480956351119, 0.014260438004774707, 0.09993159092430558, 0.05889432903911386, 0.057038488265659125, 0.04116787648360644, 0.03134100325405598, 0.030272341133760552, 0.03733255907094904, 0.04319051134267023, 0.028267158195376396, 0.015671105523194586, 0.07603320080254759, 0.0476158319174179, 0.038033604488841126, 0.03242668642529419, 0.025901593434225236, 0.03041582754147904, 0.02564480185641774, 0.06473975894706589, 0.09313406781958682, 0.007760968192347458, 0.04256322268130524, 0.05386112251185945, 0.029852141360087053, 0.022276694819863354, 0.05739231713648353, 0.046418584018413506, 0.04749454378283449, 0.08878454978444747, 0.07715338747948408, 0.052120469843170474, 0.03880322604839291, 0.049804958914007456, 0.026300833261172687, 0.030244796004678522, 0.010667072609066963, 0.02833439253403672, 0.14865934156945773, 0.03483113293935146, 0.030509014148265123, 0.014968870972682322, 0.0944067213152136, 0.058739120938948224, 0.04989725663991911, 0.05757921960737024, 0.07581834947424275, 0.01226918284581708, 0.018516138395560638, 0.06893524953297206, 0.04837735176884702, 0.059079677664807866, 0.02051994390785694, 0.007122214833673621, 0.03272595429526908, 0.05840985503579889, 0.0627265659027866, 0.03415497957861849, 0.0504533126950264, 0.01048257724115891, 0.11256888495492083, 0.05256873043254018, 0.0152862659056804, 0.015407414940584983, 0.017442792687298994, 0.10663613437541894, 0.015105517747412835, 0.046591389924287796, 0.01921681740454265, 0.03440097566427929, 0.008940414725137609, 0.04601211779351745, 0.0427888525383813, 0.04028484797371285, 0.0694681845073189, 0.018603428533034663, 0.03267525415867567, 0.019918171555868218, 0.03586340183392167, 0.019673788687214255, 0.023654071713930795, 0.025057589169591665, 0.10155756438949279, 0.04821329217936311, 0.05277402798778244, 0.010830606333911419, 0.021771754504048398, 0.05318905393193875, 0.0389466581733099, 0.06100181130958455, 0.06539240785475288, 0.06519758688019854, 0.03717642477048295, 0.04445130065349596, 0.07203981865729604, 0.03625867223101003, 0.044434754577066214, 0.03010977092864258, 0.020701111061498523, 0.046813240341309986, 0.056274132137852054, 0.05447757836165173, 0.021718450489320924, 0.17575089713292463, 0.09620924959225313, 0.16449288837611675, 0.16645860432514123, 0.1566581159297909, 0.1284601954477174, 0.17543711539890083, 0.09454056913299219, 0.07858520493443523, 0.09931153205356427, 0.16791851312986442, 0.14347422122955322, 0.1492831323828016, 0.11503163459045546, 0.10975801971341882, 0.2008538158344371, 0.1444878304111106, 0.07672734212662492, 0.06493530595409018, 0.1487200568829264, 0.1755936805691038, 0.27417952620557373, 0.11130546632089786, 0.047376957056777816, 0.14844727223472937, 0.09290006144770555, 0.14005778383995804, 0.17105673759111337, 0.2351741577897753, 0.12185464347047464, 0.0966363466743912, 0.20258399870778832, 0.08009043309305396, 0.1918897982686758, 0.15225226591740335, 0.10218309903783457, 0.1732378476964576, 0.08779917444501605, 0.13601891270705632, 0.1320980523845979, 0.09380861983767577, 0.17791694376085485, 0.0739190417474934, 0.10932610503264836, 0.11711426212319306, 0.11619281156786851, 0.08612313866615295, 0.051293335655438047, 0.12237346491643361, 0.16344081982970238, 0.11741065979003906, 0.0780523174575397, 0.1323651373386383, 0.08075041696429253, 0.21462574255253586, 0.10687324843768563, 0.1853516926722867, 0.15430952981114388, 0.08613008686474391, 0.18697389348277024, 0.10612425434270076, 0.1119119409205658, 0.13997697031923703, 0.22014155371912889, 0.10225258102374417, 0.15795805331851753, 0.12344103120267391, 0.12589622874345097, 0.14610950196427958, 0.10994706635496446, 0.2605023229760783, 0.2328245538686003, 0.16485846947346414, 0.08483350143900939, 0.13713576777705125, 0.20112516198839459, 0.10877433392618384, 0.11658372916281223, 0.1591824290475675, 0.21578273975423404, 0.11658887245825358, 0.15823866826082977, 0.12330552775944982, 0.08562607783824205, 0.25813969118254526, 0.16997546489749635, 0.09219133840607745, 0.24716327445847647, 0.1804431974887848, 0.34932529819863184, 0.2353609177683081, 0.28582630838666645, 0.176354549026915, 0.22706346586346626, 0.11674287276608603, 0.1919055131397077, 0.18319173928882393, 0.16015386049236568, 0.1597628207611186, 0.16131463034876756, 0.11528934219053813, 0.16277634405664035, 0.2170561192823308, 0.25850384735635346, 0.22159242443740368, 0.16024231431739672, 0.14248946335698875, 0.09511517972818442, 0.11217026598751545, 0.08301631002021687, 0.2648187827851091, 0.2658307227705206, 0.21937337065381662, 0.10622937298778977, 0.11588037333318166, 0.1691005075616496, 0.1635869084192174, 0.1800152590232236, 0.19523299458835805, 0.17346001363226346, 0.102770160750619, 0.11466825194656849, 0.11551111457603318, 0.20462910325399467, 0.22409511942948612, 0.11620995136243956, 0.10447359577353511, 0.10250826658947126, 0.09740254163209881, 0.11458066664636135, 0.12114801710205418, 0.1260419102119548, 0.1302384321710893, 0.13654438379619802, 0.1429850517639092, 0.08678988074617726, 0.19344248995184898, 0.15795700837458881, 0.1745411099067756, 0.10968725529632398, 0.16871191055646964, 0.1020486948213407, 0.16500145037259373, 0.0921828295769436, 0.1431540884077549, 0.10798843431153468, 0.203923087567091, 0.21739535965025425, 0.12425254551427704, 0.14478436378496035, 0.12191899573164326, 0.0905147258724485, 0.11727046088448592, 0.08460281988871948, 0.09850790231887784, 0.20281693977969034, 0.21216006843107088, 0.09354963659175805, 0.07604100395526205, 0.16776460781693459, 0.19229881917791708, 0.1350069320095437, 0.16154677074934753, 0.12927797942289285, 0.11012647779924528, 0.1998573328767504, 0.16377742748175347, 0.11346643750688859, 0.11148812116256782, 0.17401767442268984, 0.14064544944890908, 0.1122002097378884, 0.12004268355667591, 0.1626480059432132, 0.14677381488893712, 0.06338215286710433], [0.007112830270281327, 0.016682521340304186, 0.025601618191493408, 0.01845567244371133, 0.029927954077720642, 0.05025303290624704, 0.020709684351459146, 0.01224932212582124, 0.031925574743321965, 0.02406730462930032, 0.0412012807625745, 0.006141439537584249, 0.0017181934776350058, 0.010059314730044986, 0.052016134906027994, 0.035211713053286076, 0.06346989423036575, 0.06808028862412487, 0.023879557382315397, 0.04524701527718987, 0.030221094776477133, 0.029144914488175085, 0.03951957243095551, 0.04387617776436465, 0.04878940572962165, 0.04047747728015695, 0.023176020044567328, 0.06582633778452873, 0.04203357860179884, 0.05737202215407576, 0.04870409691440208, 0.01950936608149537, 0.06048709500048842, 0.04259214523647513, 0.03767485284645643, 0.02726322322684739, 0.031244990548917224, 0.051219141243823936, 0.03735099486740572, 0.011396323031346713, 0.07669951540551015, 0.03138083665232573, 0.05444868294788258, 0.0008024923403614334, 0.03855358962235706, 0.015281848642709, 0.04845997697806784, 0.0404402528490339, 0.01774994683052812, 0.008764038028727685, 0.023675649127523814, 0.018914516483034407, 0.04836354358121753, 0.01201276870311371, 0.07416951616427728, 0.022314022727576748, 0.044884189032018185, 0.02299235248938203, 0.037225116443421156, 0.01676160459672766, 0.027369563234969974, 0.0511211132896798, 0.038678789511322975, 0.04582658935604351, 0.03858481580391526, 0.0286654684293483, 0.011256806901656091, 0.01935516730216997, 0.03897303282948477, 0.06384954135864973, 0.012536133789191288, 0.06441598917756762, 0.046555017054613144, 0.02385342869508479, 0.05847317592373916, 0.08262801835579531, 0.039392391219735146, 0.02203216097716774, 0.021763639225225364, 0.019532697508111596, 0.027407914034223983, 0.03292466666815536, 0.02123091120405921, 0.017441623910729374, 0.03113991261592933, 0.04132797342858144, 0.02437455376743206, 0.05481130902522376, 0.07785226497799158, 0.037372043023684194, 0.11809948139957019, 0.10433406183230025, 0.04804323773298945, 0.08570550036217485, 0.06889257646564927, 0.053337883802929094, 0.024408629796068584, 0.024896160599642565, 0.023852879081719687, 0.04451174794563225, 0.019543545586722236, 0.005292939554367746, 0.07483935236398663, 0.06074654643556901, 0.02956073431830321, 0.03280576019148741, 0.060337830867086134, 0.021929907446194972, 0.050942173427236934, 0.03693529038823076, 0.013599885860458016, 0.06129464666758265, 0.021322654227593114, 0.05519588231774313, 0.05040391534566879, 0.03580340576757278, 0.03593445462839944, 0.02888964961415955, 0.0047962574338141295, 0.030800682426031147, 0.028062586672604084, 0.02571398698325668, 0.03144566049533231, 0.06043385035757508, 0.05907707887568644, 0.06324685298438583, 0.016423590680850402, 0.02036565013362893, 0.01565622864291072, 0.025093782227486372, 0.042745405941137245, 0.07007640972733498, 0.03489359887316823, 0.041350833273359706, 0.0027083653175005956, 0.04777994239702821, 0.033374420034566095, 0.01930870970578066, 0.07171516000692334, 0.05135954710255776, 0.02204358920321933, 0.013327084248885512, 0.044844416701900106, 0.021930190734565258, 0.057425585708447864, 0.0570915157773665, 0.028215460612305572, 0.03327654135812606, 0.0736414191446134, 0.09357903072876589, 0.03888187164972935, 0.035786276151026995, 0.033987971754478555, 0.0815728556896959, 0.07388412433543376, 0.07961697171309165, 0.023487886613500968, 0.012082693433122975, 0.03983200388029218, 0.07563217982117619, 0.09724433440715075, 0.03988693807540195, 0.02267977176234126, 0.015187639144382306, 0.03163806588522025, 0.0515623985390578, 0.04130186000838876, 0.02528034882353885, 0.008818337793595024, 0.026139369068135108, 0.02639883746659117, 0.03650097030081919, 0.03214449728173869, 0.06022173352539539, 0.03572902475882854, 0.04527228731395943, 0.019244947770078267, 0.010852427171942378, 0.07927273732743093, 0.03977162783433284, 0.04552027489989996, 0.013199636712670326, 0.02833635519657816, 0.05732103703277452, 0.05224966969607132, 0.016182975377887487, 0.043325773905962706, 0.01758230457614575, 0.032607461724962504, 0.02644206862896681, 0.05841345805674791, 0.027333631413057446, 0.10847411610718284, 0.018287631550005505, 0.018653731726642166, 0.016796389694458673, 0.011766622491580035, 0.06526696030050516, 0.05174458858423999, 0.011705537376526211, 0.014258188661187887, 0.018096584926492403, 0.02752961098615612, 0.0016680926783010364, 0.0395270566722112, 0.01833781260730965, 0.011905114033392497, 0.03838295502854245, 0.03557955027957048, 0.021732290907363807, 0.01497616692047034, 0.06072810385376215, 0.0736153633998973, 0.07654096212770257, 0.02098446898162365, 0.031649841860468896, 0.0303970219434372, 0.042592582891562154, 0.009678480165478374, 0.01016206613608769, 0.012240602102662836, 0.021744606317952275, 0.020364878300045217, 0.02896823754001941, 0.029271020221390893, 0.004396454846885587, 0.01443152382437672, 0.04374960044931088, 0.056646732679967365, 0.03683621070480772, 0.03744306189141103, 0.03029085835441947, 0.006693719969397145, 0.02600137540139258, 0.018642663124150465, 0.04305864145447101, 0.03685198325131621, 0.024817365720602017, 0.01328020596078464, 0.033657616802624295, 0.04962180195642369, 0.04367002186232379, 0.042323194311133454, 0.05020243454990642, 0.04230386284845216, 0.01088756341154554, 0.025791677546554377, 0.040168957585202794, 0.04102794899206076, 0.11805361243230955, 0.04400297221062439, 0.04444906488060951, 0.024929966910609176, 0.030922611776207174, 0.043428493929760795, 0.02789516494210277, 0.027769098224650537, 0.038662494492850134, 0.03613083962617176, 0.0401447576337627, 0.0502765475373183, 0.03362897923216224, 0.06756935854043279, 0.04600899313975658, 0.08244189620018005, 0.046396297535726, 0.061192771419882774, 0.04399414786270686, 0.09511892524148736, 0.08732825078602348, 0.036357382112847905, 0.11126340393509183, 0.05269878184688943, 0.019750875354345356, 0.02015525338772152, 0.048816526774317026, 0.00963167057904814, 0.052432382213217874, 0.07589587888547353, 0.019935209570186477, 0.04714961389877966, 0.021257609860705476, 0.08982346832220044, 0.03153197014970439, 0.06305926519313029, 0.10488203992801053, 0.03306296906833138, 0.02563195040316454, 0.015954889224043915, 0.03517422399350575, 0.02711320761591196, 0.053633806495262046, 0.07809256136949573, 0.04513673637328403, 0.06245018501899072, 0.03071054583415389, 0.04291787936485239, 0.0315912537542837, 0.08894554578832217, 0.056107466973896535, 0.1314015904707568, 0.04513493147013443, 0.042397263193769116, 0.040508445618408065, 0.05063377586858613, 0.029497080948203802, 0.036643028392323425, 0.04535359277256897, 0.07723373959639243, 0.04013905115425587, 0.03888765276808824, 0.06590493928108897, 0.009597616602799721, 0.03561036594744239, 0.057670923615140576, 0.016085281602240036, 0.01544732806671943, 0.052394669236881394, 0.02158851103324975, 0.03408018805618797, 0.021708506558622633, 0.03523041347840002, 0.03523420309647918, 0.0514819717832974, 0.06052356625774077, 0.042346227182341475, 0.07187074130134923, 0.024360479254807745, 0.051732982242746015, 0.020321983012503812, 0.020529046455132108, 0.02006477413565985, 0.001888043833397595, 0.017734879960439036, 0.028767825436911414, 0.03177423768543771, 0.06651587864117962, 0.04970649330477629, 0.006428300394743148, 0.05517221501629267, 0.03383686200582555, 0.01828078513166734, 0.014943273239103811, 0.032373394284929545, 0.029135401427213634, 0.014601471401484949, 0.052584625115352016, 0.02059697120317391, 0.028612250927835703, 0.09929691640926258, 0.015658372813569646, 0.01217091825258519, 0.08394399631236281, 0.08637396592114653, 0.09553595964929887, 0.15601813527090208, 0.1379629833889859, 0.16191585308739118, 0.1276828928717545, 0.12445252335497312, 0.13661145019744123, 0.10067392859075751, 0.20557289118213312, 0.12373330337660653, 0.08569057259176459, 0.08103325750146594, 0.23014105643544877, 0.12359052603798253, 0.13854193660829747, 0.17793436854013375, 0.1100974025736962, 0.10377948159085852, 0.11529988662472793, 0.2161734809300729, 0.0852572601288557, 0.11651046095149857, 0.1773695967027119, 0.08853155121739421, 0.11388109704213482, 0.14985821795250687, 0.11883251635091645, 0.1247837705803769, 0.07665974646806717, 0.14957585238984653, 0.13490249189947331, 0.10353797740702118, 0.10866585653275251, 0.1471164615026542, 0.14356730266341142, 0.12272447108158044, 0.19253040317978176, 0.13074620706694468, 0.15299550603543008, 0.09002014848270587, 0.08173085935413837, 0.14502062967845372, 0.0743331720254251, 0.1152217872440815, 0.0896975254373891, 0.1545299044145005, 0.10796055330761842, 0.11889460230512278, 0.11327655626727001, 0.1804847509733268, 0.13920216475214275, 0.07805942850453512, 0.21468651214880602, 0.11997157308672156, 0.08702474885753222, 0.15318588939096245, 0.11082125016088996, 0.10322401246854238, 0.09873873993222203, 0.13981100065367563, 0.08875032447810684, 0.12699793891182967, 0.15271848732871668, 0.10546555968799762, 0.12528682287250245, 0.10686473960855178, 0.13762576505541801, 0.11899669468402863, 0.12769488937088422, 0.17847822792828083, 0.13422083561973913, 0.2688208637492997, 0.12900573760271072, 0.15003957679229124, 0.10676262008824519, 0.10645567798720938, 0.1797913017549685, 0.10762292785303933, 0.17791372750486645, 0.14055604567485197, 0.12099474961204187, 0.07107649570597069, 0.11205670636679445, 0.09974873252213001, 0.22192790572132381, 0.12912183494440146, 0.3675069697201252, 0.11974388387586389, 0.19547054969838687, 0.26053950669510023, 0.2621078996786049, 0.19181232314024652, 0.20989530852862767, 0.2470190721963133, 0.12286898546985217, 0.13898367647613796, 0.1164181259061609, 0.2482311257294246, 0.08599856642207929, 0.20469817811889307, 0.17959720002753393, 0.27351483330130577, 0.17554865298526628, 0.1255854054221085, 0.1851567631321294, 0.15415532594280584, 0.11447291528539998, 0.18575766017394407, 0.11858808089579854, 0.11122572488550629, 0.12335187170122351, 0.13033694188509667, 0.08302604699773447, 0.1264384596475533, 0.14553414498056683, 0.1511542605502265, 0.128041091508099, 0.0893853654020599, 0.09874625131487846, 0.09946275715317045, 0.2167858723551035, 0.21782017685472965, 0.1990393181996686, 0.12756292788045748, 0.1434869369758027, 0.06815800123981067, 0.142608016995447, 0.1092332610860467, 0.15076018098209584, 0.15602991463882582, 0.16867494396865368, 0.12548290592219147, 0.07886516169777938, 0.1569873546915395, 0.0777572700753808, 0.1448745410889387, 0.1529553910451276, 0.07002657133021525, 0.16752269651208604, 0.08296484992440258, 0.10763328908277409, 0.14895278082362243, 0.13464006169566087, 0.09634442733866827, 0.10817019348698002, 0.15014569966920785, 0.13394932661737713, 0.17133537121117115, 0.12915310183806078, 0.06008609437516757, 0.10413193982094526, 0.10545597198818411, 0.13670340526316846, 0.12496172317436763, 0.1501915686364685, 0.17728013864585332, 0.11775276357574121, 0.21973405272832938, 0.20072114866759094, 0.13801938321973595, 0.13542904864464486, 0.1575137214469058, 0.09560857646699462, 0.1388482273157154, 0.10733963948275362, 0.11160962642835719, 0.15429001514400753, 0.07883139779525143, 0.1296837433640446, 0.16965663486293384, 0.09646682827068226, 0.18500858465475695, 0.1281854837600674, 0.09753997211477586], [0.02166074956767261, 0.04332048811816743, 0.015397817062746202, 0.014474166357623679, 0.07213528174906969, 0.044383552324559004, 0.05075054156727024, 0.010789320022532982, 0.016569923542972122, 0.031441535002418926, 0.03156965259196503, 0.03330547748399632, 0.01117515708652458, 0.012531211865799767, 0.026988964461322342, 0.008553165460138448, 0.05368354989747916, 0.03785801998206547, 0.01977382680135114, 0.03500838324959789, 0.026859377843460867, 0.015505566727370024, 0.02881665960220354, 0.01106780775756176, 0.01722612458148173, 0.04921498628599303, 0.06053763907402754, 0.03399580544126885, 0.010695842493857657, 0.03523082059941121, 0.03674006229266524, 0.02511841813767595, 0.013456255264048065, 0.007916308606841733, 0.017916618779833828, 0.028500930472676243, 0.019175989952470576, 0.06467562381710325, 0.04676033157323088, 0.031633285606013875, 0.030636890857879604, 0.09491226383085762, 0.05504099312903626, 0.01997884446089821, 0.06113221895481859, 0.01274187832937709, 0.03145490553496139, 0.0403490339938019, 0.026099096318440776, 0.027281055127137473, 0.0569905090544905, 0.05404953811583774, 0.04232438853276627, 0.052433335554919074, 0.014614758813487632, 0.06487213434385401, 0.03817432247368353, 0.024133887574342743, 0.115927287244371, 0.029576917378497974, 0.02136808045075408, 0.0450339349252837, 0.03502823718424354, 0.010721572541764804, 0.06421544136745588, 0.03813512011298111, 0.025174795916037898, 0.023745472077280283, 0.027301462067823325, 0.09627049416303635, 0.07379982993006706, 0.051789670450879, 0.035489668138325214, 0.03859777243009635, 0.03323031276730554, 0.0944017069414258, 0.024827190907672048, 0.03810770729822772, 0.031627205932246785, 0.10024969492639814, 0.056122282786028724, 0.03709604551217385, 0.04097221751830407, 0.027884469533871328, 0.10230522855584111, 0.023926065868831108, 0.061215366636003764, 0.051876183665756664, 0.05010207582797323, 0.0883997797167727, 0.06890130921133927, 0.09001589406813894, 0.0484156143585486, 0.03292310603761247, 0.05208512156137398, 0.032365557205464156, 0.06714389672768967, 0.056587689955319674, 0.05142406899748104, 0.018877051171979735, 0.032432979837592156, 0.07764803272272859, 0.01903689875533538, 0.012580615152338786, 0.04839304967650345, 0.012269286322407424, 0.017856551467307975, 0.02759466553106904, 0.03629878043596234, 0.047246739401349, 0.021100975140663128, 0.02861840184777975, 0.04834265488066843, 0.035420114906238656, 0.055774957673358064, 0.054854226365153275, 0.05765951744147709, 0.031688769414488754, 0.04091686602415783, 0.018841380586049387, 0.04440343000793031, 0.055230585991271904, 0.039562364241906574, 0.02787069188031767, 0.021565274601536136, 0.0525016470679215, 0.032638162041881254, 0.06886973697692156, 0.03232133707829884, 0.015049938944035342, 0.03717401597116675, 0.02715005206742457, 0.01448145552006151, 0.0421385751105845, 0.027240824785881808, 0.024413640777181302, 0.04739054132785116, 0.038258243684789965, 0.06610687130263873, 0.09936567236270223, 0.008742138311000807, 0.02668142524947013, 0.05095227342098951, 0.050670555859271965, 0.04322094363825662, 0.041731247146214755, 0.031942351521658044, 0.04728284424969128, 0.07250099176807062, 0.009995773318223655, 0.05859149886029107, 0.021172618260607123, 0.0632005836814642, 0.03404739785141178, 0.04068329730736358, 0.022226666432938406, 0.02780267213737326, 0.013962279539555311, 0.013701331934758594, 0.01902365544810891, 0.04244714230298996, 0.01883949595503509, 0.024946896359324455, 0.043956390781594176, 0.010189578186587563, 0.03067627303036196, 0.023959375152896558, 0.03850210238514202, 0.0165921727062336, 0.027193617408296893, 0.012504151041087295, 0.053829801335398636, 0.06123718153685331, 0.00545755002946992, 0.02865360424454723, 0.01974791015631386, 0.02655034076555499, 0.02806167913201664, 0.027190233214891384, 0.016110268654301763, 0.010315526160411537, 0.045819766686431, 0.04683949625385659, 0.021097853879577348, 0.0334365195594728, 0.023775819555989335, 0.020546880051759735, 0.013809495505743792, 0.025113917754164765, 0.04453630412795714, 0.03219180474323886, 0.013167111136551415, 0.011695372921946858, 0.04872284144429224, 0.02570942722793136, 0.03619323092113648, 0.036632270219602754, 0.04228228882753423, 0.03271886021164911, 0.018010857115898813, 0.05107100347855261, 0.012815032037906349, 0.03360015506457005, 0.034421019588730166, 0.045185604465327094, 0.021991228352167776, 0.056571791879832745, 0.03609576275838273, 0.027262293633871844, 0.041297832903053076, 0.02311562024988234, 0.002361434179225138, 0.012162394156413419, 0.016146139408062612, 0.01323220130455281, 0.015484533838129469, 0.03462179131539805, 0.016618628786610704, 0.02023540872947446, 0.009149032012958611, 0.0036087091929013176, 0.07089447190186807, 0.03138906728210194, 0.01334872018612389, 0.03441725032670157, 0.014052820707937437, 0.047783267218619585, 0.04155024114464011, 0.09124054121119635, 0.03068682085722685, 0.05196732109678643, 0.0383217817039362, 0.033385700679251125, 0.030702647686536823, 0.03804251704631107, 0.03784150104703648, 0.016450557358829037, 0.026221393773864423, 0.051067156184996874, 0.02835486054287425, 0.030422263446130922, 0.03315664082765579, 0.010695369215682149, 0.056823894780661376, 0.03312930604442954, 0.018541681846337657, 0.03961784805038145, 0.03703725045280797, 0.024566721670063477, 0.05267271253147295, 0.0067519429389254326, 0.049872459577662606, 0.046231494950396676, 0.0829955129218953, 0.03921969048678875, 0.0954591359144875, 0.06878886917339903, 0.012178030995918172, 0.024196406094623462, 0.04354704078286886, 0.08132504791553531, 0.022941681190526912, 0.03747778252831527, 0.05289390816220215, 0.08092314483863966, 0.08525200148246118, 0.07568034902215004, 0.03426427121407219, 0.07829321774521045, 0.017303599709911004, 0.0610182522130864, 0.06312550378165074, 0.060002688850675306, 0.12719518904175076, 0.022443974058010747, 0.05879512721938746, 0.04975511373153754, 0.024472929470773255, 0.02911899784313781, 0.08842080073165041, 0.01947170908429793, 0.04395003969381962, 0.02858462098187634, 0.0037101569635394427, 0.018248145900932804, 0.010045850898937454, 0.034394733142107725, 0.0291887342796794, 0.024184584318261062, 0.03548922709056309, 0.020894651301205158, 0.03682496398687363, 0.033871236589870284, 0.00850973667443863, 0.016360695573634336, 0.05869415442326239, 0.047018425938274176, 0.06199944777680295, 0.04670872219971248, 0.012674659257754683, 0.02877840379785214, 0.05361885158345103, 0.032389336465192695, 0.06444726285657712, 0.08015279046126775, 0.01894315574983401, 0.02302961254359356, 0.014543509243854454, 0.02483231384706284, 0.018180024377735596, 0.07605515141040087, 0.02128776565327176, 0.03799230884760618, 0.02627821938533868, 0.0463084442141865, 0.05963562854698726, 0.03313729579427412, 0.03468904092109629, 0.004818997686795358, 0.017629959786842977, 0.07944708011512246, 0.03552404611504503, 0.008535422617569566, 0.022884005713941794, 0.04781244083174637, 0.02054802168692861, 0.02941365846033607, 0.04895172826945782, 0.10197286174765655, 0.0179257942696235, 0.029538637825420926, 0.05059420709897365, 0.0579448210607682, 0.01687480289755123, 0.035459717602602074, 0.012904592723186527, 0.023276702766971927, 0.02400931533026908, 0.023634004040754268, 0.02259067672171763, 0.047834578036729775, 0.0660723474408899, 0.029561792832932303, 0.005781600542832166, 0.013887967232481709, 0.04490506076919181, 0.03822611505165696, 0.03595334504331861, 0.04204013664275408, 0.03208961397675531, 0.032900107093155384, 0.038309554502900155, 0.08635363701198782, 0.15506319222705706, 0.08888575328247887, 0.11259965651801654, 0.15702286921441555, 0.11749808224184172, 0.10894079892230885, 0.06582558461065803, 0.09374589606055192, 0.1137531389083181, 0.0914406276174954, 0.0762371684291533, 0.12047014704772405, 0.13956575095653534, 0.056709629483520985, 0.10145376888769013, 0.1086097823988114, 0.18558115964489325, 0.04833956754633358, 0.0926238094855632, 0.11656300670334271, 0.2593361926930291, 0.1630477580640997, 0.10207491341446127, 0.1346923088920968, 0.14922941955072538, 0.2391746916941234, 0.09742767456918955, 0.10629669723234006, 0.15953593222158297, 0.16171454531805857, 0.1012236505214657, 0.12007746526173182, 0.08027087591056313, 0.1335766887558358, 0.1285219828465155, 0.07026312220841646, 0.08097088656255177, 0.13888013203229221, 0.09645287080534867, 0.08273025322705507, 0.22107206950230257, 0.0918939568634544, 0.1321304863584893, 0.13288471874381813, 0.16955980791577271, 0.1305551723177944, 0.11259599921426602, 0.08908759709447622, 0.0934589910986168, 0.21795768876160893, 0.13914486925516809, 0.2342463561466762, 0.12568201523806366, 0.1377863200115306, 0.14132475799747876, 0.11239775163786751, 0.09199942834675312, 0.19796308023589, 0.12719574544046605, 0.11107378053878035, 0.11771906752671514, 0.08426671435258218, 0.11198917856173855, 0.13352885203702108, 0.1354541815817356, 0.13577584789267608, 0.12189306212323052, 0.1030108303363834, 0.13181439760540212, 0.1984756998717785, 0.19076184236577579, 0.09213166125118732, 0.08742883681718792, 0.06492474116384983, 0.24223550888044493, 0.1573478603469474, 0.13041889534464904, 0.19538665562868118, 0.23543221822806767, 0.16912037506699562, 0.09745869719024215, 0.06321894483906881, 0.12213101078357015, 0.24045307881065778, 0.14242228839014257, 0.11568889075091907, 0.1766425600009305, 0.21541733507599148, 0.20990331524184772, 0.1827390342950821, 0.20138457949672425, 0.14518442803195544, 0.10620139020362071, 0.26797910034656525, 0.1232835975076471, 0.23173927781837328, 0.19872967552925858, 0.1392963318420308, 0.12480206388447966, 0.1983377265610865, 0.07985270834927048, 0.15682517125138215, 0.22901713103055954, 0.126759406711374, 0.14295614617211477, 0.09474627380924565, 0.07538108793752533, 0.207304553261825, 0.10155096224376134, 0.10178965729262147, 0.19368069645549568, 0.17947746573814324, 0.18299138146851743, 0.12980073637195996, 0.12226645994399275, 0.10453656382326569, 0.08408907388470002, 0.08065337967127562, 0.13529331449951443, 0.13937771533216747, 0.20752172517989362, 0.14091812553150312, 0.13589499864195073, 0.13991561718285084, 0.12558440119028091, 0.12321217491158418, 0.12019463468875204, 0.14008286249424728, 0.1442363653331995, 0.1316443703004292, 0.12708475068211555, 0.13856534606644086, 0.12679945384817465, 0.15119182424885885, 0.15716328525117465, 0.12761584004121168, 0.1308873694922243, 0.21221009003264563, 0.20295137113758496, 0.09883859314556633, 0.12514556545232022, 0.13456905979130948, 0.18835350445338658, 0.21401569885866983, 0.13565137742885522, 0.052230134672884426, 0.10154084528663329, 0.16457378332104, 0.13175232522189617, 0.16086620012564318, 0.13013399206101894, 0.22487168918762887, 0.09698799744780574, 0.14682982116937637, 0.11842877444412027, 0.16570563401494706, 0.06933286426854984, 0.1600620411336422, 0.17489586158522538, 0.08953551163098641, 0.09541055959250246, 0.12597269964005264, 0.14356610844177858, 0.09590469593448298, 0.11406454576977662, 0.12435976761792387, 0.08279608469456434, 0.15433644050998346, 0.13407780043780804, 0.09582356350230319, 0.15876631066203117, 0.09965096919664315, 0.10369152988174132, 0.15206454241914408, 0.11938886078340666], [0.027352114706965427, 0.015632551163434982, 0.046233211643993855, 0.04894812524850879, 0.034628217042024644, 0.002330549173556002, 0.009799056686460972, 0.07523928090397801, 0.009797422265234803, 0.061546118530843935, 0.00033475880315693624, 0.026660363522491286, 0.010747985365534467, 0.011417257533009564, 0.015576029196381569, 0.036358671329383335, 0.03214032768404909, 0.01609132904559374, 0.027024959047724093, 0.015351719089916773, 0.017567174941567437, 0.021642970253846476, 0.049898698526833735, 0.02389469210590635, 0.06135783184851919, 0.03445046800853951, 0.007473014045639762, 0.03784298025337713, 0.01098288401096527, 0.007569035232466246, 0.011916032510011323, 0.06160098487245185, 0.08734673407993146, 0.09775406348385982, 0.021361089843724455, 0.018460669854123677, 0.03299788738201771, 0.04990520907033767, 0.011356064700521529, 0.03013984699334417, 0.027169717708602548, 0.022486207773908973, 0.04167898637907846, 0.013505700110856975, 0.041896813083440065, 0.018168131355196238, 0.03330476162955165, 0.03702735062688589, 0.014089304687721389, 0.014216867574889745, 0.03535507053935102, 0.006524035324608641, 0.05894351604261568, 0.0250176098862929, 0.013099064252206256, 0.011451880630504872, 0.1001272668529834, 0.048853113382522545, 0.059010344956602366, 0.07029016861425978, 0.010861340577581098, 0.016630842416946377, 0.0347785973655326, 0.019689527306971804, 0.03584934937368546, 0.04764167731627822, 0.06998469214886427, 0.013871558559393244, 0.014168532981005098, 0.03436142046536718, 0.0401908437322293, 0.022521684977359006, 0.007949701859615743, 0.044241317813949924, 0.12400949427059718, 0.01907270335193191, 0.012458863069436379, 0.024987040187365243, 0.09091831850154058, 0.06040453085941928, 0.033468274998345544, 0.015968700804348503, 0.07494879327714443, 0.022453548187123876, 0.014515794481017759, 0.10473627024995429, 0.031371415193591795, 0.036926415150186846, 0.05266612734911697, 0.054382291688982926, 0.043671898011650355, 0.0501964227296412, 0.061576652606683116, 0.04879979070808206, 0.08152182307094336, 0.023845971595229845, 0.05610240849533251, 0.055235003254243305, 0.026023324312908307, 0.040853059983679225, 0.04071476776152849, 0.03857213398441672, 0.06894449796527624, 0.03978692879900336, 0.0327640981413424, 0.029096707967775207, 0.04182773143319147, 0.012107119845625545, 0.027353978981929164, 0.05822469639991011, 0.016777957290677086, 0.043033817250813754, 0.02075438793482525, 0.036308856680989265, 0.010786365002526768, 0.04096721671521664, 0.03393509012780019, 0.09926783439836331, 0.053274484883461676, 0.034820574934461286, 0.038167547301522324, 0.030433320174259797, 0.015371216793677636, 0.03656577039510012, 0.04498092776962689, 0.05237629450857639, 0.023249147459864616, 0.05343337403610349, 0.031765399766819816, 0.06467364928019897, 0.018098586604797413, 0.07246492763182946, 0.02765186264046601, 0.017464911232569387, 0.02054531093952911, 0.016615154687315226, 0.04737501644662448, 0.131962956062385, 0.07129241911960499, 0.04939775647861617, 0.03127663742218699, 0.04233490243288023, 0.010940441645548811, 0.03974693933767932, 0.09634576405265502, 0.06643966558788504, 0.06921409349888563, 0.05598724413929241, 0.02151752100326121, 0.04265572736039758, 0.03451657767540642, 0.051782030146569014, 0.03497076526816402, 0.028921109890299182, 0.09610472805798054, 0.06715523504785129, 0.06722418099109616, 0.03819608648440667, 0.00755811930035374, 0.06411056699497358, 0.004088062801331813, 0.06332968175411224, 0.06655505725315639, 0.03335394184770329, 0.014648558339104056, 0.047168443245547156, 0.034743567995194874, 0.07277381712836878, 0.07034127587186438, 0.008924354649414974, 0.05009156871320946, 0.03001020270000611, 0.031218042530651604, 0.005000554149903889, 0.04237150939713631, 0.013834262882093233, 0.040621740610471795, 0.021517772061218108, 0.01728534372523427, 0.057227514551154206, 0.04215948077450905, 0.03596570795135839, 0.019259892503864, 0.015936558600515127, 0.02545560254449291, 0.051371736984167776, 0.02048405279804553, 0.034079075258757384, 0.026584854449278543, 0.03082836326211691, 0.03897622533674751, 0.019719744167689766, 0.06940438864486558, 0.048483959798301966, 0.06760654225945473, 0.028515583436403955, 0.09121729460145746, 0.02296945871785283, 0.01374832896648773, 0.03010717553219625, 0.025686051696538925, 0.030449448951653073, 0.010712646413594484, 0.013773443243865455, 0.0621141337656549, 0.03568617527240089, 0.029000386529202973, 0.05882777153913464, 0.030217773347560848, 0.08822847676596471, 0.039630350058100054, 0.0303926555705922, 0.006438009382691234, 0.04055252664589456, 0.03476150846108794, 0.05036700304065432, 0.034404928130762916, 0.021528486129162566, 0.03504395205527544, 0.021225944327722703, 0.040993835643998215, 0.039185224300516505, 0.07901080923953227, 0.06299139133521489, 0.019185864333329455, 0.04651787404769233, 0.013104808051139116, 0.03435942217973726, 0.04816193386380162, 0.06843543385288545, 0.07046506780066661, 0.06450852778341089, 0.044946373373802216, 0.019876012478822043, 0.07837630435824394, 0.056305266717182736, 0.031124594687883343, 0.010560511228894549, 0.06811243761330843, 0.0143362473297332, 0.04430053695770247, 0.036478829703160694, 0.03288560340713177, 0.07209332792886666, 0.06292949537081377, 0.03423436478312526, 0.09309553381587778, 0.041820800197975974, 0.058331409602292945, 0.044664696524185796, 0.03251169329243047, 0.03658883040770888, 0.015998720889911056, 0.04420586435922554, 0.048085432433124096, 0.02936909906566143, 0.072966887482575, 0.029678042845002243, 0.010001730855687388, 0.01631108787842095, 0.030230105721524785, 0.00811925164556929, 0.0355206500472767, 0.029902305454015732, 0.023493988339656165, 0.029871523712894747, 0.07368046204958643, 0.008229643355921974, 0.07426186478031532, 0.04220992646047047, 0.06979913996266467, 0.03182145693738546, 0.021472822508907745, 0.01650117098220757, 0.08726912324449845, 0.060881235636770725, 0.05959872302732297, 0.12825354082243784, 0.03950539444174085, 0.050431379050548585, 0.05121437114264284, 0.034090491610446146, 0.08637984881975821, 0.042239924493644915, 0.06673503188150269, 0.023373049650607363, 0.04367278689252479, 0.05321837343009455, 0.05972889318530049, 0.020188596598537903, 0.032097440878195424, 0.00794486899394542, 0.011296212822864098, 0.02794489816629461, 0.03802241883905871, 0.020742878284571425, 0.09670345378773552, 0.019765363773331046, 0.028812065920127288, 0.02712590979146106, 0.05184080824255943, 0.061028613442821164, 0.036408116176192246, 0.020903205931452767, 0.0467543977844928, 0.04398971702903509, 0.015548490852649723, 0.054973227836723836, 0.03793818889451878, 0.05233964683221919, 0.027066902689901844, 0.047026510683021376, 0.055862868670374155, 0.06458087997244936, 0.037825684395751784, 0.022911004622333815, 0.028143919272614375, 0.036500827808465273, 0.025992301691855704, 0.022973190660455396, 0.06348833002682243, 0.004294691981548178, 0.07138307139809642, 0.048560023573892455, 0.009150651167146862, 0.030378433476601328, 0.032740515656769276, 0.0237887388627444, 0.023187860480642745, 0.019505206661831056, 0.03792843495362571, 0.03929899087441819, 0.013062400460642363, 0.04634896971817527, 0.03362878245700683, 0.031756941827812364, 0.005745720883299197, 0.021372682614518062, 0.0883331543632916, 0.025235989596694708, 0.032741879512156756, 0.03473172077376928, 0.018178858993841068, 0.023653052215065275, 0.02687702314662082, 0.012253312759899666, 0.010308233605298613, 0.014776336661140834, 0.04032561096495815, 0.028320937184616923, 0.012725325467597162, 0.008646653166839054, 0.14665064721235208, 0.10794145933219365, 0.1000666736758181, 0.13337574739541325, 0.05860066586839301, 0.12323016966027872, 0.09867077107940402, 0.11779234930872917, 0.09795195143669844, 0.1340008952787944, 0.17843158543109894, 0.09304427728056908, 0.11319163760968617, 0.1254488163228546, 0.09896061409796987, 0.10177050224904503, 0.15650335566273757, 0.06650112728987422, 0.1578644969101463, 0.1424241340053933, 0.11214269032435757, 0.09198243782988616, 0.10286444997681038, 0.16849087098879473, 0.18396189010569028, 0.12543283003781522, 0.06889968751264469, 0.0842181108891964, 0.11499626934528351, 0.10686853261930601, 0.1430484540760517, 0.14237827860883304, 0.23598541425807135, 0.18657894538981573, 0.20299323674823555, 0.12784548343292304, 0.07260232418775558, 0.17993899168712751, 0.08844260206179959, 0.10333497330014195, 0.08943814185581037, 0.06747074026082243, 0.07256744748779706, 0.13385794152106556, 0.1863287016749382, 0.08809646099273648, 0.11256986204534769, 0.10622063345674958, 0.10065467855227844, 0.13728663325309753, 0.110214375225561, 0.10310568274664027, 0.12733766782496656, 0.1477971135505608, 0.15254282818308898, 0.22245493744100842, 0.20257007516920567, 0.23866826029760496, 0.12336986644991807, 0.14889644884637424, 0.2798010802694729, 0.1603141983172723, 0.1513490408126797, 0.11629060203475611, 0.14649822110576288, 0.1783357220036643, 0.09371967068208115, 0.12737672430063995, 0.257069288619927, 0.13766878417560033, 0.16621419601142406, 0.15940825907247408, 0.16595766906227383, 0.14245583516146454, 0.21509712082999094, 0.16787879168987274, 0.11176696512848139, 0.17788571757929666, 0.1591932856078659, 0.19911303424409457, 0.2277452035674027, 0.19724780933133193, 0.09318702069244214, 0.10887313541024923, 0.14518191745238646, 0.15640217252075672, 0.13542971360896314, 0.11355432814785413, 0.1986249504344804, 0.15043670976800577, 0.22745265997946262, 0.09582035403166499, 0.21585127179111752, 0.2555758330438818, 0.23078075210962976, 0.12141023017466068, 0.09931870416871139, 0.16480011546186038, 0.21512955480388232, 0.10843310545065574, 0.08035867834197623, 0.1239173085029636, 0.16239499380545958, 0.2483915314078331, 0.1489245809082474, 0.2461293770798615, 0.2862712102276938, 0.13894596349980148, 0.11468338327748434, 0.1469140002237899, 0.16220173346144812, 0.12636946620685713, 0.20037706355963433, 0.16634011854018482, 0.1124662361772997, 0.11732485225158078, 0.06796009293092148, 0.2111935360091073, 0.11385206931403705, 0.12319089605339936, 0.17621645357991966, 0.10170041636696883, 0.058031693899205754, 0.11534401854234082, 0.2403277669634138, 0.1038926544466189, 0.16012823901006154, 0.12295343593827315, 0.2009682168385812, 0.17248016835323401, 0.07235891332051583, 0.09958635230681726, 0.07701248968286173, 0.13524507065968855, 0.14108161175889627, 0.16523877478071622, 0.14249000618500368, 0.2937409036925861, 0.1506368504571063, 0.22714235234473432, 0.07943677995353937, 0.19968592136033944, 0.06807437858411244, 0.19141392808939728, 0.20660917700401374, 0.08867111230002982, 0.2512454225548676, 0.14892611439738954, 0.16654523967632226, 0.07363807396697146, 0.10622020597968783, 0.10671008112175123, 0.09766967408359051, 0.11224257067910262, 0.2259997400854315, 0.1923045324427741, 0.13771058193274907, 0.09711805225483008, 0.10661833640187979, 0.15311606813754353, 0.11737673303910665, 0.1139089712607009, 0.23926363406436785, 0.08332965070647852, 0.08021992471601282, 0.11885349665369306, 0.10209693187581641, 0.22750983334013394, 0.18084689868347986, 0.11588434954839093, 0.09843213709869555, 0.07300808134355716, 0.13277225834982737, 0.11032294082854475, 0.15439009905925818, 0.11155524184661252], [0.07427538798323699, 0.02579966390372387, 0.025546215807220767, 0.03342961885833314, 0.04215096516002502, 0.011367315659299493, 0.02520047846649374, 0.036248694373560805, 0.06301830881940466, 0.095149330395673, 0.04143801823790584, 0.036271140311977694, 0.06439053732901812, 0.114259841718844, 0.030695577351642505, 0.03209622630051204, 0.05185471481776663, 0.022167148733777658, 0.02218153028349791, 0.027370084010596787, 0.043808151236070056, 0.0331760163951133, 0.0350349343248776, 0.039571839983442, 0.08534580216343914, 0.041857376628156216, 0.03141892282292247, 0.043157517577388456, 0.033645566020693095, 0.055099615161972385, 0.07498025694595915, 0.021809202851727605, 0.020504821058628813, 0.029717655719390938, 0.011774528272716063, 0.02771834041258054, 0.024278707303372875, 0.036190883189971955, 0.04122976566265736, 0.026235890674537847, 0.03286928463993328, 0.04067009640857577, 0.11304817495069333, 0.015018241180639182, 0.032364749748791964, 0.02311954727130277, 0.026702147708939653, 0.047627933589475493, 0.06338854466697999, 0.029689516872167587, 0.033012034837156534, 0.024287558792691146, 0.016807361605710218, 0.04088507665853415, 0.04186473194775837, 0.043870518782309124, 0.08851307470883642, 0.07366010599902698, 0.012651400773652961, 0.048879291263542006, 0.017725058166044097, 0.0452786282237087, 0.0388561958846237, 0.04518667994333165, 0.02334385228875492, 0.017688437631087642, 0.026534517328920107, 0.027668276402567114, 0.017087486306471483, 0.018369732590924417, 0.009306017026704336, 0.028063395825613822, 0.039007631330085654, 0.04887112509459257, 0.06350568695259945, 0.02418281843087503, 0.012895541066037757, 0.05586307901622994, 0.03100249231127756, 0.006114277356703366, 0.0017853954798608485, 0.01837241110791053, 0.0765231777248638, 0.053735647816210985, 0.009462154719845524, 0.01447760992284332, 0.1131014603057078, 0.04179531442267554, 0.04503893233569605, 0.01488192010271762, 0.053031362393604856, 0.08199877890625171, 0.0688273896064077, 0.08916649714644466, 0.043401986959257295, 0.02675422527162092, 0.03263182791748217, 0.025558446400931904, 0.08715905129377331, 0.06380503624677658, 0.027725161385855505, 0.04105421168995755, 0.05845419729926756, 0.03472527808376721, 0.04924139486891883, 0.037292522112173696, 0.010280668968334794, 0.061066550335713794, 0.11174349460218634, 0.03894918232357927, 0.013290806374113475, 0.0025803961574898233, 0.04388796052496348, 0.03682167309203318, 0.05135025117280228, 0.07206029005880867, 0.027221082809514234, 0.06765057918216501, 0.029229079971888235, 0.05127817379044635, 0.03947516231398497, 0.019806569508676018, 0.004147642416813011, 0.010429214702786078, 0.040038437981690676, 0.06197189925504582, 0.02786408125289849, 0.05131170359839286, 0.040973832431648455, 0.0044800762303306586, 0.018783060501196554, 0.0736399602943233, 0.03175030914800508, 0.031984614075294564, 0.022695793670469096, 0.01212899072561413, 0.02208879659883678, 0.06611953276608672, 0.03350688024823155, 0.018627280735277703, 0.05630398767867258, 0.04799738233642919, 0.010358061824393059, 0.006390680292887347, 0.029585229432476417, 0.03983645507001451, 0.07344165164977312, 0.01415383251982608, 0.03730151270117078, 0.06425741554370948, 0.029099330505622283, 0.04465781957177179, 0.058914766513875554, 0.006003146467264742, 0.04749822144263557, 0.015221184219366737, 0.024184682705838765, 0.08541783544101886, 0.04244531025843961, 0.06048363447189331, 0.10112762424562659, 0.03797313005530408, 0.03730932603191052, 0.0487038356784199, 0.03737608030704515, 0.0374871055994715, 0.07030819728970528, 0.11001481807657651, 0.02718972261728985, 0.03453660124380674, 0.007875538830246245, 0.04163745325058699, 0.03913414757698774, 0.037508554091410976, 0.032239970551537614, 0.023274243077529327, 0.0689357312928353, 0.03164785036018916, 0.027451696506302272, 0.03686683977554951, 0.0239039795539741, 0.02448628982529044, 0.09193559855754886, 0.015072013384529521, 0.0541827481106988, 0.037227046875549216, 0.0730736685384597, 0.05667989268632872, 0.019098095828667283, 0.03281441151297518, 0.028695832871432816, 0.0287375593824046, 0.02254660756859396, 0.00883749283717147, 0.013157949217462113, 0.03905244856806738, 0.012679688898580415, 0.01263551033168499, 0.011726152966730297, 0.019036299948181425, 0.0950581149331161, 0.008784799503960779, 0.044363311624952724, 0.05231281755758183, 0.015726294168936353, 0.01019925664045981, 0.029606952731098448, 0.020676968785535012, 0.04511203430593014, 0.02594864644509341, 0.010293150620002831, 0.06511485989072494, 0.013368656393140554, 0.024118566253621663, 0.12356653303972312, 0.011596039636060596, 0.03416572757331388, 0.027908481191843748, 0.05433450586029461, 0.03198310772755316, 0.06333613462213959, 0.056680781567203145, 0.060415265283414295, 0.050584222456174235, 0.016102290778820003, 0.03105987941047975, 0.0365506187081337, 0.014469745701977184, 0.06643970629998616, 0.034060069492885044, 0.018978955257417898, 0.0241632528736123, 0.05223382929606097, 0.036876607287142954, 0.00797537508021508, 0.04065730941614934, 0.02474962078434016, 0.04288140471492495, 0.07676363017942224, 0.07117229127990347, 0.08543525343494755, 0.04056605663416641, 0.04585613616343055, 0.04901724421818342, 0.0332136174131717, 0.08715904450842313, 0.02746169132712696, 0.05261695391631552, 0.054860143190515895, 0.04012977558055094, 0.09808061524693455, 0.048764985254300494, 0.035523174197546074, 0.03352645259084446, 0.067347959349198, 0.034067441775862656, 0.01814205864710467, 0.0178826954215765, 0.030176677874156406, 0.02481348450029535, 0.029918264597654343, 0.014548230151246701, 0.029365736924644028, 0.005391966227242457, 0.024090391783309833, 0.05910160791661058, 0.02416459976562432, 0.03253853953044329, 0.03192285381789718, 0.033333036183778725, 0.06684139224567584, 0.009363198020894612, 0.043472289972539456, 0.017329529925648655, 0.05284648874242391, 0.10145134651767355, 0.034061192468340905, 0.04304283498121159, 0.06213369593024254, 0.015016085135617425, 0.04149159197030323, 0.0538314773168947, 0.06830803211778402, 0.0267137710138091, 0.04756275351558413, 0.0536876957464431, 0.0329378506035677, 0.055607787000813653, 0.04700234126565712, 0.010015263388465558, 0.00179513606209574, 0.03708137897774577, 0.043168984819203615, 0.027772212700386132, 0.04575346363708377, 0.00632931528213833, 0.05636345448770693, 0.027979038655757904, 0.03496598159628255, 0.050590006967208216, 0.0519816449710301, 0.06906047317066363, 0.035519191196986606, 0.0628618590001549, 0.038770982064306736, 0.0505855455994606, 0.016762961666764956, 0.0311916373404009, 0.010805423354863055, 0.06611161426241909, 0.058066000629748614, 0.07047660968133382, 0.03580981453082391, 0.028676409806524004, 0.06071325750755412, 0.051546578495098014, 0.014983081192310368, 0.04601196512313826, 0.02317692249614213, 0.06021454105419772, 0.02689835798394467, 0.026682056287037473, 0.026473890225003873, 0.005082489373827619, 0.033337042933063846, 0.0493202745648367, 0.04457381015111293, 0.01356257576428886, 0.027816917980089784, 0.02941866944144879, 0.05903855165732758, 0.027106926077976823, 0.02367858379147947, 0.044372176684971364, 0.028856808519256965, 0.04392670148185321, 0.02759229574751641, 0.050102917211396356, 0.03700580035469361, 0.028361576343221322, 0.07742944945182119, 0.04324743703805974, 0.031792229041457176, 0.032585599326661656, 0.02060848254976528, 0.04176719932417784, 0.03246074549055525, 0.032222650945186615, 0.03936577568362866, 0.02456027389104877, 0.019883812238861407, 0.020550925816808428, 0.2068338535193886, 0.16475871125502245, 0.11343223934194871, 0.0885861257889441, 0.13319719769060612, 0.13573107815214566, 0.09962030619915042, 0.07517929840832949, 0.2366060566689287, 0.14064462163618632, 0.1649845955627305, 0.12020547767835003, 0.1957252581736871, 0.21236460602709226, 0.08647943740444523, 0.14085200907928602, 0.11585110133247715, 0.08512510864862374, 0.09260146532739912, 0.13563084495919092, 0.11648089039538588, 0.16735059288995607, 0.13510169621024812, 0.10305733712656157, 0.2373305692204407, 0.1484329415751355, 0.14118534619254725, 0.12210724848721709, 0.1143117496477706, 0.2593965823096888, 0.16828797544751847, 0.12601117257561, 0.11778774884130273, 0.12931500029351028, 0.13276985633586133, 0.12547398997204645, 0.07765156110482556, 0.08102631608822516, 0.2587315094258104, 0.10153498274407216, 0.08248628596110003, 0.09047628686364208, 0.16293107718229294, 0.1139103826135397, 0.19452030211687088, 0.13088603956358774, 0.13620434275695256, 0.16415011962609632, 0.20754955868635858, 0.07394040881523065, 0.11055763252079487, 0.060369599876659255, 0.13623696672064917, 0.13400238805583545, 0.3047124892473221, 0.1776921179677759, 0.13764627038368157, 0.1712624422673668, 0.11524972931614944, 0.10894033073314599, 0.09695314788924796, 0.12527397141924926, 0.15169593505561352, 0.1134866646357945, 0.11358699960900204, 0.0835000037082604, 0.10462744001831327, 0.1561157764600856, 0.1192599255591631, 0.15035546198487282, 0.15243419472660336, 0.18600064356412205, 0.10382505878806114, 0.10529836187405245, 0.13371776975691319, 0.13480730700705731, 0.11350767886532204, 0.13682198604302748, 0.19495357386767864, 0.20034120976924896, 0.0828884808080537, 0.06466365445937429, 0.1081163924453514, 0.140145871256079, 0.11455249387238707, 0.07361082400062255, 0.1955739041524274, 0.11264245850699288, 0.12747561399425777, 0.11405105649360589, 0.2584935879068715, 0.19770704183195317, 0.1609706130943128, 0.17006212739007814, 0.23505438278828347, 0.07656872778066567, 0.13309954293072224, 0.058441298348563056, 0.1294190739946706, 0.2249329880412136, 0.10658430108534438, 0.15215868236763136, 0.11431588871138436, 0.126556484028697, 0.20276417689664022, 0.11062180836285863, 0.09670534011508737, 0.18805796174066408, 0.1326667054423264, 0.10116246023348399, 0.09097752068191767, 0.1412945089063474, 0.1502098755112716, 0.18403583685202257, 0.11676310668034212, 0.23759449220129422, 0.1515002998390368, 0.09402554069778749, 0.17323936761489936, 0.1080401318946055, 0.2033416237682104, 0.062275475822389126, 0.09412301225321633, 0.11687237795974527, 0.21072546898254327, 0.18988748214074544, 0.12180825881659985, 0.14121148336146558, 0.12543638556131295, 0.10325844133538858, 0.17272783363504068, 0.16708016954362392, 0.07283124833234719, 0.16379606005336556, 0.14902736539287226, 0.19272945821285248, 0.0907208105283124, 0.1324105313313859, 0.07685078800256763, 0.09094085943486009, 0.09105140636009829, 0.0982556976377964, 0.09574583053056683, 0.19604682948972496, 0.15092245941715582, 0.10531390032597951, 0.13318217492529325, 0.06876697284834725, 0.11813814432493278, 0.16935313971979277, 0.14941244758665562, 0.11170406493225268, 0.1380511386586087, 0.12270491570234299, 0.14601971821061202, 0.15017028977828367, 0.11240626725235156, 0.15306463518313, 0.04957768360951117, 0.13982006588152476, 0.23917024050440105, 0.14391081780195236, 0.14611190397824558, 0.12375184095331601, 0.16298970260790416, 0.11511634290218353, 0.12179379245000226, 0.17803480529359408, 0.11029216926544905, 0.11035411272730146, 0.11033789574035577, 0.15010193416050502, 0.08303503080138139, 0.10923550025160823, 0.22632948096309388, 0.05841944952096258], [0.05180313937099917, 0.07623047128851924, 0.06714352353342942, 0.046705248100417, 0.03857821026550872, 0.04661153902166656, 0.05322879912065608, 0.032779684090720754, 0.031021426830972944, 0.018429202792633857, 0.02355096662150962, 0.03527347331068345, 0.008682583292414035, 0.03038034016000373, 0.042957590626818795, 0.0029435075994115323, 0.014353660234649266, 0.043922453852636476, 0.03472039941698313, 0.058369122578629425, 0.08390633761882782, 0.02680280159360596, 0.0418080878444016, 0.034941313455679586, 0.01731290072867913, 0.02463770661103938, 0.006825296815285193, 0.03499532823583909, 0.013205416134691663, 0.1284300142100879, 0.02329284341872803, 0.01424941181072167, 0.04217459853472454, 0.07158566838396446, 0.04176732485315629, 0.031036164611577988, 0.029343111174447194, 0.030985535721161535, 0.0328309711601053, 0.04367071057536772, 0.013179361238144338, 0.05402484961918422, 0.04728260336975966, 0.025659417500719428, 0.03748125323493566, 0.004251087624912283, 0.007729728440088885, 0.036747512607170005, 0.024443625239655375, 0.010490446551037686, 0.010164050851017237, 0.04673658624025328, 0.03382924884291632, 0.048067176448447366, 0.03552422592682498, 0.024874547562961067, 0.0368994807026216, 0.04227028215037925, 0.02452379754478378, 0.038858811637120586, 0.021551809074091058, 0.03909215643735869, 0.057176712634308, 0.02051748421841434, 0.009244784330283957, 0.009169047947839966, 0.04458999660398279, 0.017561397215883647, 0.06022106856107712, 0.029261086468717883, 0.01490615906992129, 0.0812646040160741, 0.03599838959053159, 0.01115496049169451, 0.01396913274324366, 0.03657935466617346, 0.024745020316913724, 0.014285516659063953, 0.03497452774484243, 0.06544491967984609, 0.06060385052114725, 0.02871207699977926, 0.036214866010206084, 0.026739236433058977, 0.03921419774581279, 0.025231633401874985, 0.024616368381040435, 0.030435976638857807, 0.016319596707554798, 0.05054079960765583, 0.0570448257827333, 0.01735625572369567, 0.014393456313492996, 0.053244782013020346, 0.008903589781506785, 0.03757183087457504, 0.050843080173113515, 0.027771539254380122, 0.03862494436491813, 0.03486318354095731, 0.0348288496690137, 0.031391306447663476, 0.07247446783419166, 0.01727339981256851, 0.05154536391741463, 0.017555493961221406, 0.02787329236577664, 0.02971632239807929, 0.06801779554890734, 0.023189936797799807, 0.05222605328474726, 0.031626513826527765, 0.04756309278309345, 0.0448810711636075, 0.024399919102766683, 0.04290252751005547, 0.053758921567350626, 0.03551335918850132, 0.030926326755434275, 0.03559985544000353, 0.07406922868852105, 0.029276078699954917, 0.041952639552099366, 0.05543509305321744, 0.057462267311556, 0.009685793076641858, 0.011255577905103564, 0.023309895003746663, 0.014422278784747635, 0.019447241111525466, 0.03159435126664383, 0.06806846854410001, 0.07731999496796302, 0.04360632099477308, 0.05846738802003009, 0.03496864145355565, 0.0716712452205164, 0.043344311482672176, 0.01416681204656405, 0.058294090176267285, 0.05078218165518982, 0.1337920014879533, 0.032335888261773756, 0.011696130336661423, 0.03234728765008705, 0.06594320865614073, 0.040892737318894694, 0.009894147432143134, 0.012539126128623528, 0.05075812419610364, 0.01490585203282535, 0.03424738247745803, 0.015130905135135566, 0.03719925068851028, 0.026802411435970237, 0.0260358551583652, 0.0141917761980689, 0.04221124621108174, 0.010296294781645494, 0.013731810879627509, 0.026922417139368396, 0.009390230007868792, 0.03192255865516407, 0.04857468332297035, 0.029064463983689035, 0.07228063073541437, 0.05348381293671472, 0.019657166275594915, 0.014290168016616787, 0.03945299457492573, 0.01974819683735924, 0.05272284948400088, 0.043337410781532526, 0.03740585442366345, 0.016835727762164812, 0.02244674417722438, 0.059771349121417315, 0.06857861152717046, 0.013192621508746274, 0.014227529056370258, 0.019855176364736896, 0.02014822037225323, 0.05288925001929913, 0.08993592871619122, 0.026986026404691593, 0.02086870581842959, 0.045606360637715886, 0.026149290946445296, 0.01928813652401524, 0.009481494664214551, 0.019224881793239286, 0.03924775808783514, 0.06905691086181573, 0.05342875660530158, 0.03636996215209365, 0.050985962684665403, 0.05344605924827712, 0.0320222965175552, 0.028384151203291755, 0.060271198728254864, 0.00318467230369736, 0.050966156247471056, 0.03686113329604268, 0.08611861283757857, 0.06297249413494553, 0.04589975578710437, 0.021367286564782262, 0.025478386054081575, 0.04469237396759646, 0.03875261072867683, 0.05521245214289852, 0.05797732967351164, 0.025803024348403727, 0.06332771400255816, 0.056045401375740767, 0.07529165702206747, 0.024172674332346235, 0.04248401389590331, 0.04431525438225695, 0.026395570320476378, 0.038192968615995984, 0.033467586285301616, 0.04501286980562976, 0.012015012109519115, 0.077731370393719, 0.006257411774380931, 0.06406483373471669, 0.002696940272081909, 0.09001565658088241, 0.018324917049280236, 0.010711421657885824, 0.01567860842416329, 0.04145382471116526, 0.054732649853186946, 0.051673172773527246, 0.0033358019843165365, 0.0052684139061187, 0.030210662300565412, 0.026225066344652857, 0.051429466743554385, 0.016460864305762306, 0.03608927257092936, 0.0439311255301748, 0.03989689896947571, 0.05474285162719233, 0.010493399874706353, 0.06052104889282158, 0.03901022333385689, 0.011713399052886026, 0.04693780919270856, 0.017666911107621024, 0.02982684557459184, 0.007099818513129971, 0.030653155342276608, 0.04044176598212548, 0.021527293603867292, 0.0989496557574187, 0.04506717974852238, 0.02199968459483768, 0.00805244393580194, 0.041711905505508184, 0.09440552709358078, 0.026360651212079183, 0.037368562139038525, 0.02175469443734203, 0.030628992710262537, 0.0589682079319443, 0.014171950252992766, 0.014508347559188093, 0.06292847078293562, 0.03577254260224955, 0.04412910169256585, 0.02811356500855514, 0.05631244222500494, 0.010925877739542296, 0.00815961939016623, 0.026083834369533827, 0.00957954382257802, 0.023276253237522075, 0.03874552682308214, 0.038613107321517806, 0.05707490524010999, 0.01755693245546094, 0.08306692194725786, 0.0344529819807836, 0.051273709030023644, 0.03821670037827321, 0.048075464753700156, 0.0178971550028239, 0.041494017732994895, 0.0330578868410417, 0.05603250581771135, 0.037918959212090285, 0.016222354157694747, 0.07326122240296432, 0.015678605031488196, 0.023254875991759554, 0.022929576125794222, 0.0274928971526346, 0.020143136448626007, 0.054208946347768815, 0.01495868107303977, 0.16706339615796292, 0.006861925407844994, 0.0066434176239584175, 0.015110893441098077, 0.028256418682368736, 0.10151733404823712, 0.034179030252354484, 0.04000612275142755, 0.005227119537136916, 0.03774646543232458, 0.021246286807581782, 0.0041654624427402654, 0.013909111231831568, 0.040258419034736495, 0.0770668742646064, 0.052834522777370045, 0.030394440117691244, 0.03959419092695628, 0.049345407501927445, 0.06294915253030402, 0.056395773110645156, 0.017417432440977012, 0.023344167807538594, 0.014087714371271431, 0.038265276700258255, 0.022165067327607955, 0.018358976114541292, 0.03897151630371809, 0.02297584542871586, 0.05119451381532209, 0.018157766732786382, 0.009991827637090214, 0.018682364208091582, 0.020736847804593186, 0.026333123046372617, 0.05271811670224581, 0.0035811581266378717, 0.026408771219264184, 0.021624510708664144, 0.04034549204100456, 0.011409959040715225, 0.01873437052459589, 0.03051083940746529, 0.027429844286026697, 0.04852355910199029, 0.020221157797745297, 0.06489824437137161, 0.016427454937781607, 0.02596136219134288, 0.028053650366408483, 0.12431817342128072, 0.14081029274633952, 0.12375692996595587, 0.17951692933482782, 0.11879250992621694, 0.07722673711499997, 0.13611876592040062, 0.2207719941756555, 0.12944188634199755, 0.10760911288005964, 0.18917412470493997, 0.09642441983201674, 0.1086215821227857, 0.11174384744039603, 0.0991821964936597, 0.06731934552746159, 0.18273888501737798, 0.11238412665469305, 0.11113793602479355, 0.14685617546950067, 0.2040754458201783, 0.09496189866747175, 0.08112680712448699, 0.202639692862119, 0.07745242464755263, 0.17585651789392742, 0.08537199361515896, 0.1264580421681915, 0.14112625936312334, 0.2512890930686678, 0.07439339879368033, 0.08468140102922916, 0.10576961122985397, 0.22404988828514302, 0.13210285641252995, 0.11156833757247243, 0.16036256429340157, 0.20559948975486414, 0.08584187233022281, 0.1682182899011033, 0.09667492817555155, 0.14471975368048462, 0.09352383869034903, 0.08174854197672435, 0.15931258563484463, 0.10043574244316135, 0.09156192932277918, 0.1710651514253446, 0.17856123990246228, 0.06783520856073924, 0.11000067062143769, 0.0837775788136891, 0.18358736591679709, 0.13284883781203202, 0.1057975058044706, 0.1437401119619608, 0.09993617782103163, 0.12402689190847532, 0.11103914132607834, 0.052086780579494577, 0.08883841189422778, 0.12718722304063185, 0.18381832566644463, 0.13948702732367174, 0.06614756983305727, 0.10303985806448118, 0.07585538391556058, 0.13541958986648492, 0.17759219690092973, 0.09378977013485772, 0.1591109928808042, 0.1531758335019861, 0.15693817447338784, 0.13571144134870597, 0.11048647455338921, 0.14763254166713782, 0.12048774824610778, 0.07960376063627855, 0.08724275537367378, 0.10978181593652282, 0.17927128608737672, 0.14425640925765038, 0.0925021752981203, 0.059978533004011424, 0.15407368460936205, 0.1507917464311634, 0.07789811358920165, 0.09176107935075249, 0.12951454387179442, 0.11066187585570983, 0.08186430005090577, 0.07999303617647716, 0.12455614922302109, 0.23450707644224167, 0.08287315270198242, 0.10313051034297262, 0.16797928272613458, 0.11273519388799157, 0.135140915534326, 0.08272286398070199, 0.11535535007715225, 0.1159089667988675, 0.1475609155105693, 0.19714549982122012, 0.13055663795343467, 0.14032481451119694, 0.09686731320938893, 0.2046943511813879, 0.13677147589623928, 0.10921901863600526, 0.10590943694114685, 0.14232381938823632, 0.1989661314125572, 0.1269526941967862, 0.12161693908274174, 0.246783973383052, 0.11888721984411989, 0.12570447474718094, 0.15212077940148966, 0.10832461448652403, 0.16254808487636702, 0.06347202483032431, 0.12120443050350461, 0.13747077408645833, 0.13206643265272888, 0.07706395656402622, 0.3654348594801766, 0.07351369849805321, 0.1420062514288085, 0.1277745222406728, 0.0675924490871174, 0.12495451713246958, 0.17600836046040058, 0.1028575696317213, 0.1651311862681593, 0.18287548768733228, 0.13374504686466285, 0.10359225342316286, 0.10481832548975945, 0.17137564904987812, 0.20266642714185373, 0.21260506526700088, 0.15464906873447554, 0.14533065232847417, 0.09071767569652625, 0.11522904756878104, 0.18987169941621168, 0.11673815016235624, 0.09906757157295942, 0.15989931486546993, 0.11943120136857033, 0.1336481792054006, 0.0962828638564263, 0.13245311618915626, 0.08391805591859988, 0.07360239659569093, 0.12434938603213855, 0.16322675560201916, 0.08741403118308101, 0.13618680941207068, 0.1317335705139807, 0.14728106052747794, 0.09341012300657374, 0.08936348943305866, 0.09908435852932078, 0.2548628555876868, 0.18132830570851052, 0.07332260268075125, 0.08901947896395411, 0.07265766550387655, 0.11917390088949885, 0.09503651037812233, 0.13070666204605783, 0.07560950318085295, 0.09832942725292274, 0.08312920467661959], [0.02872303534033043, 0.007087865270607705, 0.049223091386790783, 0.024093694552513104, 0.0515300154552928, 0.028045562228986194, 0.048679286281445196, 0.04394343415541308, 0.049692657975746055, 0.0193526431519006, 0.0031878940727827804, 0.059221925746117315, 0.015381016535684466, 0.06520914911691632, 0.010561501890021776, 0.020336841233074665, 0.04777868032189352, 0.006274271673256797, 0.043544448779097626, 0.04173695362572159, 0.016922748181968927, 0.05471336928063205, 0.03974377057914223, 0.047868501394987106, 0.031362957254584344, 0.051886158130530796, 0.033455481220568926, 0.020102972264534662, 0.05521336477249861, 0.026567646801205616, 0.025306268861251216, 0.006142593895284725, 0.05116060742044023, 0.015115059646112579, 0.027042617921584418, 0.043840469859008274, 0.01106119797831135, 0.02386253124235996, 0.023417147641469325, 0.08479172403791121, 0.020862127421423793, 0.027137343106525283, 0.03360910154879093, 0.06424486943121467, 0.038499890360981226, 0.06217806533511196, 0.00657823373330757, 0.012261515400106353, 0.058090943577034135, 0.012405223179874676, 0.006287768582946488, 0.04942413452746613, 0.06569514982402325, 0.06157674081623554, 0.06021440534719399, 0.0032138675451278687, 0.009622155821749141, 0.029342242649623325, 0.016348074822287475, 0.07163498430911984, 0.008799473671907825, 0.04948968779561775, 0.015352599489103471, 0.01177141718965556, 0.042414786360625706, 0.04281866058175053, 0.04296577715181878, 0.03675821649708918, 0.021404144586995244, 0.03739598173914211, 0.06620215118995734, 0.04781285134543266, 0.11298470478504896, 0.01710099763503032, 0.05623001379093953, 0.013524699939547904, 0.012888328238789524, 0.04254857311025262, 0.06136205912168537, 0.029437207018158267, 0.04799693789599197, 0.07994098575519663, 0.043653570780796666, 0.04524224517600877, 0.03940786521083542, 0.03448725139190044, 0.02684968666705702, 0.0405646045692265, 0.056338077278009484, 0.02413680188224784, 0.041971998156181405, 0.07988282851874828, 0.06879784619169575, 0.032352797354438474, 0.07095173347209181, 0.01235116514310773, 0.03580176032015255, 0.03907094882535083, 0.052461321731763225, 0.02186989950548325, 0.026134288537182977, 0.024888499939282025, 0.03954007775921907, 0.01854166657929974, 0.042827518856418986, 0.02269803622870573, 0.03594974880771978, 0.052201592097324986, 0.04576762127024787, 0.030021910821752887, 0.011462534478466426, 0.10288294005606856, 0.045151969484452686, 0.01224896080592381, 0.10659971740096807, 0.07660879527351686, 0.03034582986895527, 0.04562640116949167, 0.059488345735839436, 0.012775778787077537, 0.014415812346019914, 0.020813795372045467, 0.050535900584821186, 0.012998995603993535, 0.06507329962083272, 0.04384132820580687, 0.11321176974368946, 0.06085819258753743, 0.02135637402534485, 0.03688356905643429, 0.015713161123650413, 0.023337755651612366, 0.02446207121413733, 0.04976070486009121, 0.0034216873422597666, 0.007878580363467336, 0.037042023946664164, 0.04083195754459926, 0.08064251632562705, 0.04223105264827609, 0.035087079741060734, 0.02952249887000237, 0.01424318625192557, 0.02408165903761983, 0.012875261350667902, 0.02121007169729897, 0.01579995932323592, 0.026164707262068987, 0.061853990224855285, 0.03629661930192794, 0.02534608359980796, 0.015133721055462956, 0.03090110221611602, 0.02109160626839314, 0.05823144782334566, 0.029484351631253958, 0.04662269413737314, 0.02711001850132431, 0.03017238274748836, 0.01450665800699166, 0.05953612817185266, 0.09730667820466415, 0.002946042139748377, 0.02098903552229915, 0.021280639339238405, 0.05067192650000964, 0.06618707414184298, 0.01253566560002842, 0.04774283331685832, 0.05980733861880643, 0.06693916235651289, 0.01206368427457554, 0.08508552291563579, 0.029337896632828882, 0.02919543142031346, 0.0685314465580242, 0.011486109329520591, 0.009881728544964321, 0.05981970831219639, 0.0232272172080619, 0.027704452497086356, 0.020715306014088646, 0.03639018249564937, 0.03820445282118661, 0.014236302514161383, 0.032758527368839295, 0.020916647710172192, 0.0738759683445096, 0.052242626502577744, 0.04048219309853656, 0.011867546093916255, 0.05413661790745599, 0.05337751364069326, 0.014696481571133648, 0.023600058630108833, 0.03606628041182246, 0.0668736837272133, 0.023827435714857917, 0.02212737131464694, 0.055592842267027924, 0.019954630938757743, 0.05159661366737314, 0.05202829086088708, 0.06171529766704355, 0.015906704756032144, 0.03339360221954329, 0.028764062960233008, 0.02157605143396982, 0.04129428416490555, 0.02790741080285183, 0.012418458853582186, 0.008124681622056025, 0.028001638960891535, 0.061520659896944246, 0.008866789434770388, 0.04661043640226126, 0.03296550090557762, 0.06198367862296956, 0.037238327520234246, 0.01625341409817338, 0.01852682532210435, 0.0777125410469515, 0.02948795465220298, 0.04604867047497204, 0.010802488690907401, 0.03608549991622567, 0.07123390225959675, 0.03638110708977495, 0.04200403857976198, 0.04063431725704244, 0.07190309385103838, 0.0003786080685261238, 0.006361714905194406, 0.016676290692495446, 0.03813079445223723, 0.06783007205064807, 0.033091637172869275, 0.03549970027857593, 0.0524189641832241, 0.037934090543006144, 0.01917639368080667, 0.07516841470663037, 0.021974807804716483, 0.053288401636694155, 0.06759844733668224, 0.03512051116142954, 0.02911313869325178, 0.07200099288352899, 0.019599112515736903, 0.05572008793907506, 0.03418873330312116, 0.04355868783646396, 0.05947411685649838, 0.04349113289000733, 0.018537787055330615, 0.05806081662220614, 0.024127356674788252, 0.035673825935061486, 0.0695544330935393, 0.09948810043611697, 0.059346721906747134, 0.055182043596037796, 0.11481416411697865, 0.022472867775442343, 0.006240738896719579, 0.06304601340421609, 0.02670210530050099, 0.02214229738871966, 0.05721308211130755, 0.021208015736192465, 0.025753174076921174, 0.04846935433202556, 0.03994419286027551, 0.011747214693709143, 0.015826681728607843, 0.03029529597344143, 0.043184869323990176, 0.0064774628013505465, 0.09107592183032207, 0.0147101353920464, 0.04278963963900294, 0.05571177249242153, 0.03364421912868108, 0.03846253700820463, 0.04508367493482573, 0.043092639451580386, 0.03431227417396648, 0.06884357266660247, 0.045829819182732275, 0.048493011455450735, 0.018524452145876627, 0.054917869557227404, 0.045230207964777946, 0.03362953902355262, 0.018354406181190695, 0.04619315432916794, 0.05487021943554282, 0.027016687705846767, 0.04011798603460193, 0.01496831457396703, 0.009431759743685169, 0.012868749958995198, 0.027789723992879902, 0.03910268730084811, 0.027997298033109734, 0.04213191868205156, 0.030881309349622046, 0.06313562073877879, 0.016767998092940876, 0.06178421646888767, 0.007374497546282197, 0.028646035186414207, 0.031194351480475495, 0.027324243881074444, 0.014024621640731181, 0.03754109663090535, 0.03583895082452467, 0.024187951548291103, 0.07520897074469499, 0.02114485260764403, 0.02789659665099212, 0.04629185403298054, 0.08098443690687418, 0.030312388270561184, 0.041798988689801524, 0.031170904702906097, 0.02633223755817328, 0.029327630397996733, 0.046955661449049196, 0.00753532476457102, 0.0447700662272317, 0.09076028769569737, 0.05439313128590584, 0.029453217051923275, 0.04216970629724009, 0.05995704379997083, 0.049933982347803454, 0.0670468390786222, 0.024952960766053627, 0.028115792299753854, 0.010091534965405506, 0.05749352063451495, 0.07364853019160883, 0.037469884380698204, 0.037277719870741875, 0.06580893336130039, 0.019080784704004015, 0.0008541560496918724, 0.04490392083036048, 0.0545212183413761, 0.037002757125134976, 0.07551690350685801, 0.08519556093961, 0.09220360631921462, 0.1768700456512826, 0.04546865874103137, 0.09929918950157506, 0.11519617933247771, 0.12913651844220503, 0.1685811432876757, 0.13827908571277345, 0.13316038038049424, 0.18977139836975507, 0.14345815352031163, 0.12326588774366037, 0.1386597031461341, 0.11897051680300917, 0.15299797590289796, 0.13823521163846764, 0.1056177279512797, 0.08837807338152613, 0.13584470562636852, 0.11002391044582639, 0.1323325540870428, 0.20738284263227666, 0.143424837450896, 0.08289857740913119, 0.12615947318928583, 0.10205128003976174, 0.12891576385923795, 0.18937393969723157, 0.17814466011311325, 0.1256331064339195, 0.09555850058261837, 0.11803932248481683, 0.15818936590637478, 0.14307520192648682, 0.15584390104881354, 0.09320787885891539, 0.1897689692143883, 0.11887956596910954, 0.1562807418938194, 0.16281538696161338, 0.12847175768443517, 0.13650557159313134, 0.0927935993032796, 0.15399829936879023, 0.20074382530791418, 0.1614146599812167, 0.11129769030958414, 0.10848301170127732, 0.08689601719379425, 0.18920938138450893, 0.13595070636698178, 0.22321659299944127, 0.14162984091256345, 0.13855258960809025, 0.060972138973219056, 0.07544364886624472, 0.1030850349260228, 0.1445566610034023, 0.14651466879461492, 0.09882227437836782, 0.09594516376299517, 0.11545314054403986, 0.1066671230697206, 0.1070354183071426, 0.22026179012443337, 0.137320125741618, 0.13601174737725938, 0.14538755427513803, 0.11365421528794936, 0.1778245544327157, 0.11645577102899551, 0.17426206916570663, 0.1702495523329292, 0.1929511356034449, 0.13994350497211727, 0.09222224567617689, 0.1888538697468383, 0.14577915040510042, 0.13695212905960424, 0.14500168498073304, 0.15354388446680137, 0.1820985922323806, 0.20940863607185228, 0.16056620622319834, 0.13251851339425358, 0.15648590374205792, 0.1518161850316184, 0.14560973378164427, 0.12314856903893606, 0.09810709168336221, 0.1678195827241455, 0.18370844370552472, 0.14484155071633203, 0.06897250110549585, 0.08394467484738145, 0.147531942065273, 0.1294729361044509, 0.17303820912327084, 0.18156539941472666, 0.09924587700515985, 0.11208014296633856, 0.24124468490481377, 0.12437717882650239, 0.16851166130176612, 0.183807496247547, 0.1188754676175969, 0.1345466681356941, 0.2938870329942022, 0.0932814252695867, 0.12086470159036772, 0.1279398269419159, 0.19613847242934362, 0.18532980313258512, 0.18373987344758852, 0.1662831623107195, 0.17014747352472373, 0.11804837414196559, 0.2008385080844164, 0.08913227862545423, 0.18969514460435935, 0.1415820720472506, 0.21405962721577712, 0.09131934626826219, 0.19817752444318362, 0.07638301953141179, 0.1797327577535595, 0.1456609224634511, 0.14410231395491532, 0.24619180230157717, 0.06567879034472363, 0.24236793177468435, 0.09494349001241581, 0.1712568647095135, 0.09735032157706362, 0.10020309992666755, 0.1423350694988455, 0.1011485502656017, 0.3050209512667996, 0.11137222059603248, 0.11112891150904552, 0.11966649017163686, 0.10780321460749422, 0.0940388874816043, 0.13708305917680264, 0.19339495178844246, 0.18925746237593039, 0.16766722447105817, 0.1340265574731997, 0.1500539888760873, 0.07322351621197802, 0.10277752285557133, 0.17106607423296996, 0.15113177389970847, 0.12134825278605733, 0.12845199874469213, 0.08575918605285031, 0.1290822492114135, 0.0821323213832719, 0.15353947398918016, 0.17362238706222602, 0.1782501723085131, 0.09677185011761529, 0.08582965869988714, 0.12388605518000466, 0.23606553567307337, 0.25468336950455395, 0.0963697706216148, 0.17605602076011045, 0.13770751495446476, 0.1496508169387068, 0.10133628054921116, 0.14829238983137266, 0.09439420234411955, 0.11115464834230286, 0.21815196690814836], [0.05117024940305522, 0.05092403618618846, 0.01672669736269329, 0.013514378573745489, 0.06452529438372169, 0.022668764228001237, 0.013474335677788725, 0.034096947871148586, 0.03156173748097249, 0.07033182387905461, 0.07654776783393961, 0.02675044922424214, 0.0525842824551676, 0.03163285134360194, 0.06631134783050843, 0.013285780125962836, 0.030144596738474708, 0.04418245829375727, 0.05340362706088594, 0.029696512568209852, 0.035461590359253545, 0.05734199697950056, 0.033528288028069904, 0.04472342712272491, 0.001468705799197778, 0.019642214756458998, 0.012448153242335787, 0.011397589347325265, 0.04079416314406054, 0.058436338257576735, 0.016651189985818098, 0.05879740709705012, 0.02371067171251135, 0.015018963820434042, 0.008965194824018648, 0.023597380113122717, 0.01019998182476099, 0.01713019160420767, 0.03341052827558347, 0.04630741962630834, 0.033460475238306184, 0.05396723521075078, 0.013670517963224223, 0.02944188212443675, 0.06179194498275008, 0.02800039554546986, 0.003364702911182706, 0.11599290158067431, 0.04351001651957631, 0.031107688987893716, 0.05088757849963648, 0.0199687105403947, 0.03343116591817566, 0.042500654967235665, 0.015319970436394215, 0.04894407778712256, 0.02200667011285467, 0.030081506552440778, 0.050830188007759194, 0.05611631167786462, 0.016605721354218464, 0.02902152289503387, 0.027860564745164344, 0.021075294286544834, 0.022061198883290802, 0.027586333121040037, 0.03547654866373964, 0.0396063774158912, 0.04225920506619981, 0.014134947193919547, 0.03469359389107142, 0.031212342836494957, 0.03829345965225782, 0.03760329454338976, 0.04199355860639896, 0.05413813104054757, 0.06283756744648729, 0.09897607112569468, 0.04116107417004449, 0.05376737950635808, 0.02191582614822047, 0.003063031330904258, 0.03548201087063976, 0.013743827734807772, 0.036950900086334774, 0.03131072362884879, 0.02462966088205576, 0.04136930299656732, 0.01054647149118994, 0.045698733002479584, 0.02347184774199767, 0.027600748597511222, 0.03375792124175599, 0.0063304285036533, 0.06280908933175461, 0.025095451423632245, 0.025316472331594144, 0.026919784423496042, 0.045202371065637896, 0.026698860206774304, 0.035418598380471976, 0.05034288112074137, 0.03085047671837466, 0.009314281583231474, 0.07402667097215142, 0.05011240991630724, 0.041240683291107416, 0.039080424566886256, 0.031227552198937962, 0.02778883680834302, 0.028973146740879332, 0.02768255617203457, 0.024305241415277123, 0.033003783851329765, 0.006916684032018695, 0.04314030992931553, 0.0321905765948551, 0.030849601408200603, 0.044796447668756754, 0.03059552057779261, 0.05659027856641582, 0.08131040512983288, 0.08515206005956445, 0.040577479771205356, 0.02206233882212213, 0.01918177107082946, 0.03196359306041684, 0.02470338371183191, 0.023648000521851436, 0.039328357870025296, 0.04359376809692808, 0.05324862252122589, 0.016546220618433187, 0.030248829895364385, 0.04587014451889055, 0.03820279719574111, 0.023958683047177534, 0.03822701071788158, 0.0176906920636871, 0.01061711207564388, 0.11026216444692441, 0.07695234433880874, 0.04428366518446377, 0.0215029664271112, 0.02981348182739956, 0.0196948249691299, 0.04375470642532621, 0.005410239599379045, 0.014170476135664752, 0.014958950790709682, 0.08856156960661922, 0.04892361317096012, 0.027436125823961835, 0.024820515819426094, 0.030658627727202008, 0.05442138548408236, 0.018498733972332308, 0.02545836248568126, 0.021873407531529665, 0.015345232295138496, 0.058833294814186435, 0.04916904607255544, 0.016254204591470103, 0.008998127521148749, 0.031162141423140253, 0.03552906048883285, 0.05632205028086901, 0.05411414143496326, 0.029833837877959013, 0.023236270561548214, 0.031803394335189035, 0.09192563087812491, 0.035737509839236736, 0.022080947645008564, 0.01120440533850342, 0.021065382586259927, 0.031309661721544604, 0.008110873434426529, 0.004177229936301176, 0.012640616307700319, 0.016686266853607128, 0.030972718194659268, 0.03437246023012059, 0.044409988048885546, 0.04271366407296487, 0.03772109840065241, 0.06000536906399897, 0.022846257114516835, 0.04046176580180015, 0.016767063410952687, 0.04555579281545111, 0.052880201754825454, 0.028402293533352867, 0.029662053167287792, 0.031231711618602276, 0.014488206943497062, 0.05718180164694786, 0.11997837200760841, 0.05311685102060437, 0.06602588814816304, 0.036033476636345894, 0.03368733663644109, 0.03832587666277375, 0.02868958356391106, 0.06529905500688724, 0.0564782829689128, 0.03783168264531663, 0.006801788121395345, 0.06948419793375901, 0.07749976603580372, 0.028869341061051403, 0.018824707284303646, 0.02018455252982676, 0.03150857765493648, 0.01816803975296872, 0.03623814993937101, 0.058444385682897906, 0.046337960487497706, 0.037400687379496436, 0.05218724108168057, 0.017831072477357726, 0.02441309455649129, 0.03877182344772986, 0.029434923747820512, 0.03158218852643456, 0.015815665712580085, 0.022749665958274688, 0.015637209306338003, 0.07676476333290339, 0.04491655175973262, 0.03259080369025469, 0.028857487054275613, 0.059261321489300044, 0.03029999482844557, 0.017724796930061917, 0.017829074191727808, 0.007341111927027149, 0.020375151320227554, 0.03388274454378656, 0.033666987371231825, 0.023512396994712095, 0.042945953751248975, 0.021598466838310872, 0.027275838889181614, 0.04046367248520255, 0.058778855949640274, 0.02032421708905271, 0.06517517486853258, 0.022980893729254603, 0.022549029938610535, 0.05943686528397458, 0.01897329288268728, 0.012707419776623803, 0.05171132001227566, 0.048699805180409124, 0.07947812309222561, 0.044738270076257844, 0.04076710656019194, 0.05152473645284772, 0.058319005982152054, 0.036493326603834114, 0.03585112713543432, 0.04723417293280363, 0.02966829908213445, 0.018276447596560632, 0.04779019506115999, 0.056808437752936564, 0.08758715260773897, 0.0427192246674427, 0.023144749758232917, 0.07271146654550519, 0.019463968696072698, 0.022112433366211395, 0.01764128283996667, 0.052371042647532055, 0.04317722223433001, 0.02116322055059884, 0.04480298535366144, 0.04227228722135935, 0.07665999074067388, 0.04072443688554423, 0.015530723413186414, 0.023099337105772326, 0.08984664029308728, 0.038514180308473964, 0.06409752555191517, 0.04207818888659988, 0.029936194885522127, 0.02095057106842952, 0.03302931712408151, 0.015200952001448189, 0.012487411582177239, 0.08167652226984501, 0.034105677224163494, 0.03395605007452624, 0.027990032619397556, 0.01834229942012046, 0.053523632764284096, 0.10497948434203863, 0.014655420024480139, 0.02240846462414733, 0.007215471838467887, 0.009723936922715178, 0.05202355807913201, 0.06698873612497534, 0.040588699347738705, 0.007348447738747511, 0.03842263575643301, 0.08704604128641741, 0.04259978214811001, 0.05409668612160853, 0.0497401791757771, 0.060024442683373175, 0.02083443301463766, 0.01614684678081955, 0.054305688478052616, 0.10943641447063003, 0.031181907148233483, 0.04370528532724295, 0.03441054979339242, 0.045508081625614843, 0.03344848213185157, 0.0444594634297703, 0.037151033990085125, 0.010709168073455138, 0.035329455842397044, 0.020970945778701986, 0.021010801229359846, 0.047704316276524744, 0.011453939136117697, 0.03940458110134516, 0.032071588693984916, 0.0050075383956677145, 0.016842971123488884, 0.019306100738633956, 0.01230527157895267, 0.024526255537888834, 0.03832408533032451, 0.052284855129463334, 0.033495630137622356, 0.11418043955096177, 0.017983841244131327, 0.03329978796786495, 0.009832112368063202, 0.05321598159415381, 0.010596917177151357, 0.07012786982314927, 0.05612267294366445, 0.043859272064375024, 0.02271900974613215, 0.014522903831675649, 0.0007099542116130968, 0.1635411615882601, 0.1646609479295356, 0.10387366225144692, 0.12009509360151631, 0.11604694010955946, 0.1317430700042418, 0.08977291746331112, 0.11286503156380993, 0.11836572497018746, 0.2183021402784756, 0.19107495913548128, 0.08785889231200729, 0.15920096662427696, 0.07750932659421648, 0.11243420253906931, 0.11596673727035522, 0.11544047908059188, 0.12387964980942862, 0.11993890841092382, 0.11446094592767102, 0.11721115692385606, 0.21286218932696752, 0.12405126488634519, 0.3589731976389885, 0.11615771773670401, 0.060824605104114325, 0.10549263323524169, 0.20638793387583323, 0.1920061127415725, 0.20455405728093215, 0.07335519271769694, 0.14273327455988952, 0.13541971200278827, 0.21376730075904302, 0.07129062778715577, 0.14136108676237719, 0.09926405495830945, 0.07672044142548527, 0.15494434003319058, 0.12220942229032516, 0.13692791893013886, 0.16558569616505078, 0.1243660237107958, 0.10501990467309952, 0.1362123901822737, 0.10665288061967917, 0.09432095448885645, 0.2575950175523758, 0.08268478459545545, 0.06363450004053967, 0.08853944257966109, 0.1271013476486717, 0.12913942257208483, 0.09956465954227106, 0.15311294687645777, 0.08727495864565883, 0.11768212808029992, 0.1369951753211873, 0.10383045992680959, 0.09507619789136307, 0.09773984138986894, 0.09735543094575405, 0.1598256802452462, 0.13938747266573565, 0.09964287427387067, 0.16163500744317258, 0.12719273274498327, 0.11442673419203077, 0.09353194718382188, 0.11884611419269017, 0.10743674462927238, 0.20938984065183572, 0.07505209344838347, 0.09768114132540566, 0.12024191500885145, 0.08280595737908568, 0.11802554822393826, 0.23483603021928243, 0.09637317686740841, 0.1580876942191805, 0.12721979272152695, 0.12259090824850968, 0.1527916198330266, 0.2519296572676727, 0.06987716470445905, 0.1620540570999895, 0.1678863912820816, 0.10326608163969857, 0.10599981102028064, 0.17848159346197331, 0.1444716134241649, 0.1560335380158254, 0.14607657944517477, 0.13046917478953088, 0.22533419222704001, 0.17067092257950986, 0.11291362145649535, 0.11248670079346214, 0.1467168586594718, 0.1199532254998173, 0.07019824747528348, 0.16218278876372746, 0.10847733914852142, 0.12462959385343961, 0.12735643610358238, 0.11581345620964255, 0.17631163847233566, 0.12495504638978414, 0.13842601568571158, 0.2076453271188906, 0.17657264375260898, 0.13119790782885893, 0.16690769951258386, 0.11254147892551762, 0.09666895706738744, 0.1537169244672571, 0.15903149571801933, 0.1304421555250883, 0.14093559102288314, 0.07993848196097783, 0.15292472126228468, 0.22385945064680918, 0.1351313210491623, 0.11830038204789162, 0.09753410278686456, 0.06177194855575051, 0.04637961575229253, 0.26688918311681065, 0.0999716380611062, 0.3121136506753308, 0.14310873512710842, 0.10431527319763388, 0.1810271040137325, 0.10905164440295526, 0.10276650344686848, 0.16055978728192194, 0.14638335869780608, 0.11924255506268569, 0.08437518496066332, 0.09939807240984269, 0.21310700476169586, 0.16513299117130892, 0.14307871673788342, 0.12678744377834456, 0.10354880682591881, 0.12813767418265343, 0.20245312287339143, 0.11248068218784672, 0.10830296243407897, 0.08722019408430372, 0.273710305669478, 0.07787422915654522, 0.07976295173700367, 0.12617266391004833, 0.16651644265013082, 0.09667986112513713, 0.06039055982338531, 0.22053487332803862, 0.0771267685507025, 0.10017755308321544, 0.16920810964490685, 0.136894412870918, 0.11089188565633126, 0.12242601066827774, 0.2578704484871456, 0.10320227899189506, 0.1922493946871587, 0.12230976404888289, 0.13666943780013494, 0.11870667524635792, 0.14542990843100206, 0.16379269451967307, 0.17483753471502236, 0.057171949318477085, 0.08400677437228815, 0.090810777486435], [0.006040951469913125, 0.041066554241946766, 0.013590925805536764, 0.047641969086336236, 0.02455308990153883, 0.017312625921996574, 0.018105872374560152, 0.020794809962223684, 0.02801547259358423, 0.04081247001886368, 0.022895096368821602, 0.09358707815408707, 0.025721245611618673, 0.04231153029416289, 0.020260643446817994, 0.06682404210524899, 0.0177124068806214, 0.059987890001918585, 0.0408627596417708, 0.05662915183763419, 0.014933570188337138, 0.04108133952000311, 0.03073716476293547, 0.02733357373758086, 0.0355518253387085, 0.00035457070043776184, 0.007343048296336616, 0.0331139134775315, 0.0322814426118774, 0.06444883705782038, 0.03532260263870869, 0.04028505153421845, 0.04331216588616371, 0.03784739751634853, 0.01292810311341392, 0.02384374091135604, 0.08809746522456408, 0.061601453061614714, 0.03583309167463865, 0.04262861649372748, 0.01321338807299201, 0.01757064225551273, 0.03688593375097428, 0.05717454132224832, 0.02390352663184915, 0.031653753614851406, 0.02433731237293354, 0.029506220814904997, 0.019127978510888557, 0.021987557477716888, 0.020774864425350512, 0.020668261484908204, 0.06346170431269066, 0.03640189740274634, 0.029983912860708575, 0.059311309164123874, 0.05132516234048775, 0.030977793636598756, 0.014024687797895499, 0.054535508288868835, 0.08576415292918682, 0.0679999025804656, 0.05188639561778732, 0.02548384147563151, 0.01956880744546652, 0.0059858586672427395, 0.040825111126261096, 0.03707475647596376, 0.07959459362817661, 0.02902310388162732, 0.03564652847126126, 0.019789760499926548, 0.04676205165950315, 0.08739212128732886, 0.025861084893611924, 0.06444619755659785, 0.027317411033436656, 0.027012185625998036, 0.03299641835370234, 0.03297689690121582, 0.05602568654077394, 0.034009264183363745, 0.0073903057158791596, 0.03926295727225287, 0.016361474192568233, 0.0456524399508323, 0.03575522638857365, 0.02502216285626803, 0.037406838299440484, 0.04842069997851338, 0.06696181864078556, 0.10987598981176104, 0.10291160816060645, 0.030110205191054513, 0.010726405407435127, 0.09664044502590384, 0.06924655461417777, 0.021692518577245728, 0.007545529083082718, 0.04239625896194151, 0.016466636942433457, 0.04286224288599832, 0.04779407628146665, 0.014172463395100619, 0.04937095434537955, 0.017157068376296332, 0.04693054208265884, 0.03205913418371763, 0.026044462375076752, 0.0025310766276171698, 0.022742105381829397, 0.020671800045030456, 0.044856837285416465, 0.04791680630296469, 0.004163877639387335, 0.04665501615298646, 0.048282736845846684, 0.05986630331192698, 0.051105381455272436, 0.03303864019523774, 0.027565775206312537, 0.02241730423910277, 0.0512926096229681, 0.02360529183144016, 0.018731702185635055, 0.01971264838773225, 0.10394527483731508, 0.020007032501910414, 0.036994540066059144, 0.0217494391836226, 0.039442076946475675, 0.07241233438253403, 0.04646582701908691, 0.07174177893570491, 0.06098963839134999, 0.048493896943650076, 0.024511254824964062, 0.010160423233173788, 0.014928119855799844, 0.03850258414500526, 0.010940998044264103, 0.0472638588398695, 0.042659703575606854, 0.06998311116227082, 0.06374940994594779, 0.04809462658262678, 0.031195243754025017, 0.023744018316002827, 0.026015066541731358, 0.04578814356188689, 0.028666744075183357, 0.0399831034509199, 0.07060363822217498, 0.0405049172363111, 0.05827859922179154, 0.03513404793505158, 0.03842622520668166, 0.05328747204371861, 0.026602705009281635, 0.0776570640238268, 0.029472066754741327, 0.03553396968969277, 0.03702403598331979, 0.024585172733558074, 0.08638936188071966, 0.07418921403586864, 0.017341431429875747, 0.06053214294037648, 0.06041322289300816, 0.059744411281176975, 0.016180074640682766, 0.01068287993049515, 0.04964411218783685, 0.005591731601660805, 0.029951346572488546, 0.040250809264502356, 0.022629158138962727, 0.00918356774907027, 0.017305569157802632, 0.030137909775865928, 0.07094959608678307, 0.03244105440431407, 0.04149414665464844, 0.03695740045181342, 0.03408369268955929, 0.01279038340518517, 0.019759446947968433, 0.039707570735897334, 0.02564856772577124, 0.02137793617189995, 0.03535526392183133, 0.05190705022375498, 0.014015283302537032, 0.045054857552583726, 0.031919400074652264, 0.09231747128069401, 0.0458015921259565, 0.044810646014021974, 0.09639581279563052, 0.026317372552252243, 0.0503089272284082, 0.03866796348510044, 0.023580382810905576, 0.014695680899811643, 0.030230176967701743, 0.06867111620626279, 0.013712332683748432, 0.020375845122284124, 0.04535373526492289, 0.006214761607615011, 0.05414983916229435, 0.06692934395479304, 0.022514886056472148, 0.012429244167703603, 0.055773105272757154, 0.04154219711199403, 0.012382844246790876, 0.03182091071669545, 0.08769391330757312, 0.008649179861614746, 0.026713674322568944, 0.06688616877155644, 0.02736235210405929, 0.027454251190647483, 0.0005434474961865427, 0.004866684279737196, 0.11036676740539925, 0.025985753828925744, 0.01934193417296878, 0.014888435735234191, 0.008787818984793765, 0.026164462989462272, 0.03547346472207989, 0.02521050551773182, 0.05887126563383, 0.029599339568189213, 0.010713905096054077, 0.025715705373191407, 0.059673511157078404, 0.046652692170547586, 0.03885742064033236, 0.03737084201670118, 0.01280528657870101, 0.03907340851479343, 0.026225885675687875, 0.015099984294335757, 0.037235989967095, 0.03535474144986697, 0.07238827353077275, 0.07514025550335646, 0.0281016618079905, 0.053981433556016, 0.02532478268923504, 0.022018125480307, 0.022305639427421347, 0.031015591429812566, 0.019726653350517154, 0.06553798075765371, 0.023407617617132406, 0.03618269327229687, 0.05492605947490249, 0.024413700148995434, 0.055601541085966995, 0.01555778508606766, 0.01489085131990058, 0.023379178518163304, 0.08422495052218437, 0.04385860710005675, 0.006925230604662959, 0.02211537990452988, 0.04817797103896737, 0.15860826628548758, 0.05382241548172065, 0.015246193323816572, 0.02827074086027486, 0.020612811603184258, 0.04542866588703223, 0.05850620022309678, 0.025272835744544864, 0.033616368658840656, 0.028639880873795067, 0.022721072492588843, 0.04758843606603997, 0.010938099003396928, 0.02019477805255779, 0.02418564792190279, 0.040175091541771374, 0.03624432121536561, 0.016969327914661596, 0.02101343564156975, 0.03016959396856172, 0.03428017607490931, 0.05285762010940483, 0.04460944002494216, 0.028286542244521633, 0.0070445802495149625, 0.029452558872955184, 0.050854696692632775, 0.01680413686803409, 0.016886994475498796, 0.053068233986518214, 0.017730505105906298, 0.05043118227539318, 0.059566485828586986, 0.03140524694962161, 0.028961353802255223, 0.007768011385841029, 0.021505568608907715, 0.02341538175408329, 0.03012881740661604, 0.032626749082867584, 0.006308357031749827, 0.02229375658290727, 0.02687126916966268, 0.02476380386256746, 0.02799806647401835, 0.03292576589488557, 0.04611227974029524, 0.019425955467990468, 0.05683361818747861, 0.09219977259635925, 0.01948701513798109, 0.06325690208801202, 0.0523411497872855, 0.02802448353863188, 0.03965413949585386, 0.014280554871740085, 0.04391366682414498, 0.10856170140738998, 0.03383015129449112, 0.021256149314077835, 0.04836208812360253, 0.010364654640268003, 0.03085789649880358, 0.04949640868497746, 0.04910986764090402, 0.06657062284648418, 0.05635537313563483, 0.07989884194518838, 0.02363103036103504, 0.1134959537801998, 0.03547343758067914, 0.04009357234463096, 0.019870460366031954, 0.03648386104032397, 0.035657232361180444, 0.026735981161307012, 0.061731419659086635, 0.05491841917059251, 0.017677557322063615, 0.01843071762206299, 0.020532970083877444, 0.15992139439497674, 0.16519039523388657, 0.10857176408171654, 0.1687956146363701, 0.21248073051018374, 0.15754607399659498, 0.1555810637239899, 0.08164536394178867, 0.060641529570732794, 0.12879616527685098, 0.11622314208320209, 0.17778802210731165, 0.12565762868949346, 0.08099709837032215, 0.08809337365840163, 0.1419143642165831, 0.06840903205530983, 0.2025979765291725, 0.07452005414026124, 0.21250145296965325, 0.12439524142869882, 0.16301727827106202, 0.17091024188058718, 0.10052510550511734, 0.13061051363391535, 0.07570958031075341, 0.06707581930926867, 0.12398122650172029, 0.13230341779334204, 0.18951090877609594, 0.11752744923744883, 0.10541150080306189, 0.1019365872655596, 0.08121065369674138, 0.09630644973367453, 0.14963706981922897, 0.17422400335116045, 0.06808585939662797, 0.11544305751366274, 0.1532632423830884, 0.09934102797082492, 0.09131994337907859, 0.19201565294393472, 0.10261168211166348, 0.11798512110752718, 0.12749150528439454, 0.14508817105420999, 0.10377208555915526, 0.09827701720808234, 0.09988055830555302, 0.20387873851827212, 0.15190381104392664, 0.1290566005877086, 0.1426529631550823, 0.08482563721814326, 0.1487585705305849, 0.16296269691416196, 0.15679995689008916, 0.11378039566001721, 0.13924229331314564, 0.19180793980402605, 0.185423237404653, 0.10271180673901524, 0.12330202651875359, 0.09213344579828636, 0.08597518410533667, 0.11079240563724722, 0.09418206515588931, 0.12713441944548062, 0.1969419935984271, 0.09765947570226022, 0.13029217214456626, 0.12480935135057994, 0.31856008619070053, 0.19591273739933968, 0.17469953426292964, 0.153279201526727, 0.09160650907350437, 0.12127254184867654, 0.14688288260783466, 0.16518879389124258, 0.1360242459923029, 0.07947806202407394, 0.1470147626740592, 0.13310733251273632, 0.10915304467614208, 0.17546009059463227, 0.08764045831880399, 0.09885101712175778, 0.1152777121003185, 0.18100245962185518, 0.2217671200633049, 0.2502764202654362, 0.08196952726159777, 0.10879658308944531, 0.25904358125158716, 0.14560669394476072, 0.10774324568254606, 0.1597503221460751, 0.09396939192499433, 0.2242341105427061, 0.16313159785100392, 0.11553300411573478, 0.06676038873514958, 0.22555657529405185, 0.12802715439881596, 0.06571148216192212, 0.12975771725177765, 0.09394413685160023, 0.11019205820879766, 0.07068072658564363, 0.16763232062969888, 0.09875922490443502, 0.12670338686023438, 0.07972143896456275, 0.08402440271207265, 0.08486092103911297, 0.10158191022596189, 0.15618126866008553, 0.08862866993461337, 0.14016330960605825, 0.1573455940399851, 0.19311464897223882, 0.16200436119522366, 0.09476059089813914, 0.21474080852099828, 0.2188238115715129, 0.12741337876234735, 0.1273417118936777, 0.10487634701920406, 0.08472619791116033, 0.12962979983006204, 0.12539582273789815, 0.12707563117146492, 0.15347130836120673, 0.1390257320765938, 0.12414623264755521, 0.09153888627354588, 0.11962949644242014, 0.24995742738246918, 0.22967338295919554, 0.1220680834459407, 0.10718495385455233, 0.14675245460655006, 0.1925927876893963, 0.0969420809830938, 0.09794363259736981, 0.16932689398527145, 0.12497389609260218, 0.12044103789542403, 0.08301309376422848, 0.10815287727330412, 0.29324003628322054, 0.16063205126140798, 0.20850690374416964, 0.08408380845295531, 0.13318769820034504, 0.1365762749420745, 0.14485708916825907, 0.241640569376094, 0.1526664708341871, 0.12615107292575495, 0.1373439830328737, 0.09837465161191565, 0.16816282644867897, 0.14643981281135762, 0.14937101623841695, 0.08849039806851319, 0.2357076220214367, 0.1375545324491603, 0.07587426754512958, 0.12834196750606808, 0.10138874487685305, 0.10859242547303438, 0.06514257804623672, 0.09536977963788168], [0.007450967594715101, 0.016157854315159575, 0.03091463220438787, 0.14901265475366796, 0.002278979876012142, 0.05794802374605622, 0.026831963332369924, 0.059662471392324994, 0.016645680281466672, 0.02020610449835658, 0.05388311383181384, 0.013887012194442962, 0.03513091988861561, 0.07867150780345712, 0.012051186507700809, 0.01401349960360676, 0.06344935497535126, 0.01239075681327709, 0.04177254618012479, 0.043949839525989125, 0.015450846270791121, 0.02578823228499719, 0.04646031731473548, 0.0014849660427509142, 0.08370995601373059, 0.05259507116196411, 0.05998817498662642, 0.01781288773885795, 0.026569416081266742, 0.054560037329792976, 0.04483211146933692, 0.021865304127069454, 0.006874746751106743, 0.13009280498538697, 0.026723735300557952, 0.06041881402156182, 0.03764422716838973, 0.04337341045694692, 0.01078790273251278, 0.05225210224411317, 0.03679797525650688, 0.006221378172215606, 0.03476255679769175, 0.03800055304808276, 0.01512572112759309, 0.015464630709694964, 0.027644227425168668, 0.0061786478535006085, 0.027046024167378033, 0.05504993961325713, 0.08617037148880106, 0.03232353213908417, 0.024479475637365664, 0.10825515964201518, 0.035173715092241764, 0.021904728707990477, 0.00972746530481215, 0.016203412852649177, 0.04353291029110551, 0.021706016335104193, 0.017324379844857112, 0.04350619636742132, 0.027776075260979787, 0.021051723676334535, 0.07668037393263408, 0.020429400194968497, 0.025177549071876065, 0.028437144788248197, 0.013672673160077205, 0.043484951435987435, 0.031724931938307624, 0.05627012538856693, 0.02724543203865843, 0.026808241748117974, 0.053932728312377415, 0.08117123081215791, 0.02287724071980587, 0.07778016384691, 0.018188719803999578, 0.06775822197752339, 0.022594091449198977, 0.049506875087640116, 0.023961363260501196, 0.017761269883651818, 0.03452196863612958, 0.010689550777897239, 0.058995607175997326, 0.06728446204215288, 0.004049476211158825, 0.06615782928253923, 0.05665447137185505, 0.04535577765532902, 0.04487129008131368, 0.11639451288751193, 0.005080419842020741, 0.027592896251007915, 0.036308910963790755, 0.038822835710431845, 0.02313546909551535, 0.02949695541922535, 0.02321134288130062, 0.06325876127396311, 0.05040731819878731, 0.05155158269086054, 0.024086481725264872, 0.03763090752597366, 0.02275823924823531, 0.026370145613327622, 0.0161829431474741, 0.022529929177835584, 0.053918513003736734, 0.04673780421061175, 0.05992593975471599, 0.0579500389950616, 0.0331526205076703, 0.05693806508289916, 0.03583731894780483, 0.021016334682436924, 0.02879912286464657, 0.03050819312089256, 0.07217144766556365, 0.02485210501721927, 0.03741841749953372, 0.020232027928744043, 0.05938508627670152, 0.08361152772392545, 0.05433394267622914, 0.09957436937838793, 0.04077245680881398, 0.038104708173445294, 0.08382703044584819, 0.021919754865978445, 0.07457069999405316, 0.08527662551828794, 0.013021315165263201, 0.06707174809915678, 0.021294720637212907, 0.060003699867853096, 0.03222542615341289, 0.017022659070789814, 0.0464704478425639, 0.09112327000392334, 0.032880226017108986, 0.0031841689155304004, 0.008397842009019638, 0.04191982899127262, 0.0918094724682825, 0.09372388438454696, 0.055320983819131336, 0.011110765809592391, 0.05600993095764092, 0.007860589007447873, 0.03542450163513422, 0.023724130454606245, 0.012243786128237844, 0.03882891877687403, 0.01411958600926612, 0.061201884145183225, 0.05081426618354661, 0.015820910788274238, 0.000991427871797766, 0.0626177763832467, 0.025505030427926352, 0.032643105169492106, 0.04965127073228359, 0.06052607683730977, 0.06391964759677649, 0.04789366825882878, 0.058993021957576275, 0.03023379695202623, 0.024659267061256936, 0.018421270718265857, 0.0721175041315811, 0.045260792930743525, 0.037934433203190565, 0.03986503157232489, 0.022063799368749772, 0.027884635774950896, 0.08878651075065136, 0.09949722673211779, 0.02291130317774202, 0.038932948373258114, 0.02083239740958171, 0.07154832860188824, 0.0428511081263423, 0.05691752243520958, 0.029942583292722702, 0.019314872500087534, 0.025877434194886258, 0.09411190463496105, 0.041307186508285146, 0.024049013021535108, 0.04788783625034349, 0.009871289283702416, 0.03368447661133749, 0.03765091073832341, 0.01760468096472323, 0.030950574204325676, 0.005951244051435164, 0.05199465588001268, 0.13145640252956323, 0.0683550885213273, 0.04771652990686042, 0.04621783943314638, 0.0438054642373962, 0.03218389641759651, 0.0158577280983861, 0.07459172779428107, 0.02989577116178615, 0.05693453670080219, 0.013689394807443023, 0.02611429719919605, 0.013645291727568423, 0.06443223330591406, 0.01136520117454763, 0.02959565512303795, 0.07676939772708075, 0.021686630589621406, 0.03410634558115687, 0.005232169958097594, 0.04065135187868561, 0.020177773964990462, 0.03737553747903023, 0.030054276942142417, 0.017574296166588153, 0.10514964056866509, 0.07013565940516335, 0.02719015857603933, 0.01796184992417693, 0.075357861683837, 0.022411774178700786, 0.06602397467941046, 0.03134364275527852, 0.027354004426992366, 0.045712201922599754, 0.04233683625768338, 0.023082796118355224, 0.029944469620074545, 0.03324935585260391, 0.02551252654354487, 0.04083704994991422, 0.026133531970637183, 0.0019233159920466797, 0.029893613420426846, 0.03927996475249529, 0.08577225463730948, 0.07705113903752395, 0.035296173699732335, 0.028701576670365672, 0.06686690516237702, 0.040894257237336466, 0.003461677227668198, 0.049334761287484846, 0.02040730370208621, 0.0415205722009497, 0.048809062889111896, 0.06934680137783289, 0.017795518938718096, 0.1661126600312335, 0.027787450900567428, 0.06690188364258834, 0.055712590127118995, 0.06329122238925525, 0.06676973894770656, 0.021549865071262633, 0.04569833605949368, 0.06904195595000472, 0.06708187184163503, 0.0534298015492303, 0.0033028974887981477, 0.016273508912750652, 0.07718911234821592, 0.02846452367625066, 0.02452722075395286, 0.056110313428299766, 0.033964009290294986, 0.04539162466036422, 0.05743785362158503, 0.07963443041912147, 0.0377078975018646, 0.04467430458004985, 0.030366572684475353, 0.018788046037246073, 0.05615438088508589, 0.03167631151154637, 0.04088410296078239, 0.02189596033921199, 0.03568345095430102, 0.03674572127472077, 0.020783302008307407, 0.06838306452014617, 0.05025261560721057, 0.062442646494933536, 0.07791976564164672, 0.02791248115577868, 0.051750023649739366, 0.024513268377631903, 0.05345292262999075, 0.050881054385432174, 0.01927232156906809, 0.007628891350967544, 0.032623702460633855, 0.09748133990381445, 0.05893694103828498, 0.03740593245519059, 0.029257212033761398, 0.058819079505545754, 0.014397001658965434, 0.04058141188163843, 0.07419667792107378, 0.018737912477393235, 0.08250981755554676, 0.0332098515438182, 0.02621858294254967, 0.03139402737308826, 0.0190032790414989, 0.03248001927775996, 0.03651538916996547, 0.032748837888772996, 0.02337800634891859, 0.05351292548168983, 0.03984194102564028, 0.09645253153783934, 0.0478107716356005, 0.03870668747861471, 0.020502235840207765, 0.11365641374140978, 0.02062132552133075, 0.05007662737209882, 0.03691738724176373, 0.04571888209985835, 0.027902433748490045, 0.03828639949538878, 0.04020495726061719, 0.04883366996156318, 0.08458394304450069, 0.015347337450033851, 0.08350357958780867, 0.032078849018684456, 0.015012767099376236, 0.05930497843239989, 0.08834276920450584, 0.03485305640580399, 0.024634678648518663, 0.032940985435353856, 0.025507585112271563, 0.01513545640877315, 0.023978026384221654, 0.08006874711385795, 0.04558219122035163, 0.016579786049468175, 0.016105788626841137, 0.13730248383113317, 0.10350843399230923, 0.15107876674405166, 0.21152143127151898, 0.12074115393417222, 0.2178009200309004, 0.10532284341752529, 0.19789277043725761, 0.14241425453552178, 0.08389031740703753, 0.10026357775287968, 0.10287337949765579, 0.1218523093100105, 0.2493760585784912, 0.19115596264600754, 0.10796313174068928, 0.18118510767817497, 0.08398056256451777, 0.10284714054848466, 0.1364386137574911, 0.07937740813940763, 0.1269066488104207, 0.18084445595741272, 0.10813554070357766, 0.22254474833607674, 0.1356474690671478, 0.11209309619984456, 0.08766616122531039, 0.1745581275650433, 0.11227778664657048, 0.14185363533241407, 0.1149016408515828, 0.10186745133250952, 0.21757905265050276, 0.0584399209224752, 0.11617459968796798, 0.1297948466879981, 0.10820531445954527, 0.0913728012570313, 0.1371947731822729, 0.16362466210765497, 0.10662824979850224, 0.1203736322266715, 0.13282276849661553, 0.11559985338577203, 0.08001064416021109, 0.10493375108178173, 0.10325641251568284, 0.08251773605921439, 0.18744288331695966, 0.13740526831575803, 0.13920748446668896, 0.07746486219444446, 0.14011942196105207, 0.1020106425774949, 0.20581656667803014, 0.14363542757928371, 0.06945489879165377, 0.18222926450627192, 0.07458627237273113, 0.06707378370421273, 0.0906680476452623, 0.09062627024416413, 0.16908271637346062, 0.11860166516687189, 0.16047442757657596, 0.10227132216095924, 0.19876025031719888, 0.07072778977453709, 0.1982498291347708, 0.17588067374059133, 0.17654835219894136, 0.07061592649136271, 0.15278165893895285, 0.11124551775200026, 0.13158389925956726, 0.12466299134705748, 0.17901861321713242, 0.11413281996335302, 0.1838468105665275, 0.13147449227316038, 0.13591983302363328, 0.17828844168356486, 0.16944616687084946, 0.17000141207660946, 0.13844136414783342, 0.16995286968137535, 0.15946856726493153, 0.10105390141585044, 0.13646750577858516, 0.1403827749724899, 0.17679953229214462, 0.11422778772456305, 0.20966433520827973, 0.19355918440435613, 0.11920398713222571, 0.15901880711317062, 0.13357911791120256, 0.1134209553045886, 0.10101774907005684, 0.07948903393532548, 0.1128645498039467, 0.21709157952240535, 0.21705231948622636, 0.09205016919544765, 0.137573151450072, 0.09839594404080085, 0.14543587953916617, 0.13246929246400083, 0.12857302225061826, 0.11452764592000417, 0.1641103167619024, 0.15767465638262884, 0.15543475800326892, 0.1303061499659504, 0.12284202048821108, 0.10777057028774704, 0.15800970340413706, 0.13544390856155328, 0.11002871447375842, 0.23900014534592628, 0.21485478883343084, 0.1419354530849627, 0.061811337513583045, 0.13850245944091252, 0.1765344693724598, 0.14074337562280043, 0.23350192180701665, 0.10844253030206476, 0.11182854218142373, 0.11236134823411703, 0.158316469086068, 0.18636055210871355, 0.12286107375153474, 0.10572111633207117, 0.16955706663429737, 0.0998502956437213, 0.15276046150497027, 0.09044183085539512, 0.09285784299884524, 0.13589248806238174, 0.12549251397805555, 0.0795161889067718, 0.08878082462719508, 0.11923001573554107, 0.1538084995533739, 0.18374216689595155, 0.22971314511128835, 0.1895792915352753, 0.08718554130090134, 0.2685777582228184, 0.12535691553992884, 0.19151299420211995, 0.1391537580639124, 0.06818718503096274, 0.2034792306699923, 0.11675800409700189, 0.22593000025621482, 0.11493714180375848, 0.18618569363440785, 0.11618521197565965, 0.12281185282128197, 0.10295094962098769, 0.07675248184906584, 0.13816054564501556, 0.175191445010049, 0.08996473931308303, 0.08945100687976394, 0.14257034473121166, 0.17237452045083046, 0.06128319978181805, 0.07376904479627099, 0.27292434498667717, 0.09713559917041234, 0.10582743598414318, 0.11355489811726979], [0.019468431760157858, 0.02943156160680311, 0.01821417674156172, 0.01663952596884753, 0.052238494224314175, 0.03901411473218884, 0.06955603443618331, 0.054729935713112354, 0.0248113250625985, 0.02243259672208556, 0.022368515874924402, 0.008873102354950138, 0.031197910396648303, 0.007750046323053539, 0.03827823332643934, 0.04926482807578785, 0.07103725602584225, 0.06796413021428244, 0.022153971583715508, 0.02003122227532523, 0.032943546905049255, 0.020878899110747234, 0.05912094616464206, 0.01858221922468926, 0.020997890404292514, 0.015485538069957068, 0.062067294493317604, 0.005225731933023781, 0.04458749620243907, 0.020491474274812, 0.04977674203525696, 0.028926928328084092, 0.0355338034486132, 0.02168301060529692, 0.052310768381825516, 0.014709704522309559, 0.030279788055590222, 0.07482993429792778, 0.08324455562978983, 0.08256122336855956, 0.013103037074740444, 0.02408894311104502, 0.001437735976651311, 0.04041540828932609, 0.039255279648516855, 0.0431087478729231, 0.06089057906397751, 0.05039370000096304, 0.047945365841899595, 0.052346286297376664, 0.014949244347267916, 0.03567549852388246, 0.019601351681298444, 0.03008285683712789, 0.06884955056011677, 0.01911919317873461, 0.04443231185099908, 0.07945818773337773, 0.025464895081573298, 0.02813284727744758, 0.042598194376166375, 0.020870714282084788, 0.033661060367843935, 0.03777357629899468, 0.023602949189288274, 0.008514454189155782, 0.05047413014939853, 0.03245594146262322, 0.019499959889799356, 0.025022374898461357, 0.0357605223543942, 0.02056473061176283, 0.027650775288098624, 0.0800809200320925, 0.028750275128654072, 0.05506077581750495, 0.018259446901668395, 0.0743423526042274, 0.008539485345993723, 0.01867472560011915, 0.0646745924438749, 0.008436617740829076, 0.015961683055918132, 0.049140880083931346, 0.024184826894530227, 0.04728568052606923, 0.0352937309736652, 0.07530074939131737, 0.04410491531182613, 0.02854189702442714, 0.01847179443575442, 0.012221709991406118, 0.026689711858385375, 0.03821302271847214, 0.07071423943021468, 0.03492126274587853, 0.013527537064094628, 0.05270336874361549, 0.03545389577214207, 0.035923479324472804, 0.03216690929340465, 0.021642459656244943, 0.0208135273507131, 0.07527410332113504, 0.021633487726960863, 0.05206009379721113, 0.04201232349233968, 0.05101991657699857, 0.029826116149446795, 0.01695748238957354, 0.013286517184626843, 0.010129686444997787, 0.02198117415952895, 0.023383395613304207, 0.015904258637289916, 0.02393950934388808, 0.09966843468802315, 0.06607802677899599, 0.035987458391381164, 0.047869956852602105, 0.029038906962211643, 0.045786871308726926, 0.020774155356256024, 0.03554892460150378, 0.0005371573175320268, 0.017756377646167363, 0.06801894227308886, 0.02469965346556689, 0.034957384557596276, 0.04410168548513736, 0.04350387238498245, 0.0299445917563779, 0.03393608078892742, 0.03806922757732017, 0.018147816016737903, 0.037912764187370024, 0.05227238026314548, 0.07342900375702552, 0.02433905960060656, 0.0058598373268198755, 0.01210320893941181, 0.03008688733513866, 0.04673660998897893, 0.035551235013242276, 0.03413177368098071, 0.013589721405878663, 0.0796281403994986, 0.021799532031374316, 0.033053903840482235, 0.0073248330237609995, 0.03254711621307901, 0.024172367295250297, 0.0205497349878507, 0.03833364249606218, 0.06237262846635921, 0.053785133375121016, 0.024439903475078087, 0.017376628737630587, 0.013759517160776471, 0.010367412885118808, 0.023760408329378282, 0.08078807565782752, 0.06762695259281568, 0.02141262966740344, 0.018700681260919998, 0.026589794184214303, 0.06890223880431481, 0.055252645164728165, 0.03655268145459039, 0.08208943118474313, 0.049245713744312525, 0.02267163443113012, 0.05306811524288995, 0.029673364346048663, 0.02994091748925192, 0.010370475622559232, 0.02833678776265255, 0.037117643281817436, 0.029860992849405323, 0.02637530587214444, 0.014730197976210287, 0.03388828817488892, 0.053548667313797135, 0.04698922857642174, 0.03376941901764699, 0.02476248411195619, 0.028524299218718494, 0.006741457028380994, 0.026646272046491504, 0.01926591619849205, 0.07982836929815156, 0.024674810602196624, 0.03774752394695367, 0.0034988499204960783, 0.01649907770167504, 0.009073691725331758, 0.0361873446298497, 0.02191337663680315, 0.043686472943850925, 0.03388941454301987, 0.024509005481377244, 0.04459438333287835, 0.07295656017959118, 0.0053688430260600785, 0.041082001091646295, 0.0529348984626787, 0.0228191666038973, 0.026825206819921732, 0.07777987886220217, 0.017648780651922737, 0.06986913084983826, 0.0030875209319804397, 0.03147087485662528, 0.04855101941419499, 0.03454550023057631, 0.10756833971078907, 0.08089198651058332, 0.012516456273650485, 0.03169269473957164, 0.013199638409007872, 0.030796285519110303, 0.04095717100426555, 0.034830023534595966, 0.041961518182818375, 0.02887006030817117, 0.033552403162632666, 0.007474106487019786, 0.042156512183802466, 0.03194024806310024, 0.03898938552343419, 0.03266056387552193, 0.007434638649491327, 0.0084210674145392, 0.14158802958471434, 0.016730013702596937, 0.0022899360961413807, 0.005599513550155929, 0.009780825298678662, 0.07299959287047386, 0.031437358619379144, 0.04900228252102222, 0.04771290992253593, 0.03482409653120807, 0.04765334472592388, 0.021528345333146195, 0.03758432948961854, 0.05167297260569675, 0.08013681774692875, 0.02145520265081099, 0.0166545775718987, 0.009384061276380504, 0.021485187113285065, 0.02853484365290829, 0.049402743711003234, 0.026585200502138053, 0.04150051809847355, 0.05649406908612166, 0.05962582371596779, 0.05352164465667946, 0.01251545119365411, 0.10358004657817738, 0.06419342969145093, 0.03430840991703527, 0.025780598766037395, 0.0034449017215852757, 0.0422950079664588, 0.0789719834657652, 0.02408685322318758, 0.020896064350381494, 0.022343535608212863, 0.026597051116238748, 0.12487036521945681, 0.04370162123814225, 0.044763301233095784, 0.01997823717205652, 0.011518997073705708, 0.03610857349953481, 0.05257546149992517, 0.027001352814425315, 0.04417997485558901, 0.09167463398937668, 0.05522377349968467, 0.007603621858704303, 0.03377372771501541, 0.014737398929095693, 0.03177061430843813, 0.05044981484700527, 0.07327707298099995, 0.00984983824725662, 0.03238457314936178, 0.006386771083011159, 0.01932757637197418, 0.05841453692742756, 0.08791804020958287, 0.045471851248294115, 0.0050968526879192465, 0.02060533414727875, 0.09713331929274968, 0.05616598044122968, 0.02941217246864523, 0.01999345501618726, 0.16105207800865173, 0.07457737677863666, 0.01260574215224811, 0.03051728888281754, 0.022023755624624233, 0.05423445247911981, 0.03250097243913582, 0.006976474417440061, 0.047253243159502745, 0.056088389961847236, 0.0420939410770578, 0.05325707367488316, 0.0434461629816464, 0.03783329077331083, 0.02458437206223607, 0.10323212096201521, 0.005554667474435908, 0.026379405919994627, 0.045140295289456844, 0.04618342752967562, 0.07697240183395998, 0.03318539374907102, 0.03037033516115376, 0.029902583653373376, 0.023140619176306894, 0.04007274471223354, 0.016071654922728027, 0.03818100265094212, 0.017455691638003503, 0.022868019428902438, 0.018895237606817057, 0.05381598975509405, 0.0069317729544958896, 0.048865856270172765, 0.019839071336069276, 0.031015106277274232, 0.04523788558851395, 0.014113063591399362, 0.024138740796063627, 0.0385189266609294, 0.04354922227295382, 0.03597173673499908, 0.02471343960080828, 0.014802570521299328, 0.011632113102158266, 0.012974123054716204, 0.02857581359733428, 0.044824773113110235, 0.06292740548295633, 0.07997261905776602, 0.03271435134645019, 0.10356843684400831, 0.08222511104707207, 0.09807803681386368, 0.09440750841583524, 0.12599407349314007, 0.09314599646521465, 0.16026782723409788, 0.1390281883733613, 0.13102000951766968, 0.14900402378823074, 0.1602833249739238, 0.09957782990698304, 0.10073639452457428, 0.0772713575778263, 0.10023482143878937, 0.07606659829616547, 0.13814514290009225, 0.19677558967045375, 0.05074826168960758, 0.07719630481941359, 0.13188472097473486, 0.06193914636969566, 0.11182625551841088, 0.1094501887315086, 0.12986097671091557, 0.2898088204009192, 0.17780425266495772, 0.0821916592706527, 0.1226374828921897, 0.09640543442219496, 0.18260435866458075, 0.12947422532098635, 0.11278989059584481, 0.05963608995079994, 0.13996422743158682, 0.09740913020712988, 0.20113341297422135, 0.1338439636996814, 0.15157122031918593, 0.10700610559433699, 0.11784318515232631, 0.09310538614434855, 0.06480428084198918, 0.11955480330756732, 0.2163677862180131, 0.15674533482108796, 0.13212002334850176, 0.09192450450999395, 0.12883102840610913, 0.17012894951871463, 0.08257969309176717, 0.1325152021433626, 0.15644809577081883, 0.12464463018945285, 0.20098702582929814, 0.0935157166261758, 0.09973827629749264, 0.20420588739216328, 0.12704709198858055, 0.07959721277334861, 0.12338625985596861, 0.12581913359463215, 0.10260969400405884, 0.14856775291264057, 0.2763243753995214, 0.0714606483067785, 0.12868605261402472, 0.1209042194698538, 0.1252046658524445, 0.10313129744359426, 0.06920802061046873, 0.1879731991461345, 0.12181979391191687, 0.1857623556362731, 0.09538812043943576, 0.13419697832848343, 0.07949269802442618, 0.14025458613676683, 0.11813913498606, 0.11234503625226872, 0.2022018749266863, 0.10542182810604572, 0.10676213832838194, 0.11954246754092829, 0.1638929277126278, 0.11167480650224856, 0.10994203841047627, 0.14203181862831116, 0.09519420870180641, 0.10916580791984286, 0.1882019333009209, 0.1374600396624633, 0.12888860888779163, 0.1845668312162161, 0.18436336570552417, 0.1550444918019431, 0.10495845654181071, 0.18494151825351374, 0.10963933036795684, 0.1854588333517313, 0.26702337020209854, 0.09082233293780259, 0.10300048267734901, 0.3067744757447924, 0.2494638610099043, 0.24418944546154567, 0.12368606376860823, 0.09519226809165307, 0.08797567497406687, 0.20934208535722323, 0.11884277580039841, 0.0936622666195035, 0.07869448299918856, 0.10967714512454611, 0.11941134743392467, 0.0845347899677498, 0.22141722669558866, 0.17004409192928246, 0.07989792592291321, 0.1373189722320863, 0.12230605924768106, 0.2089031817657607, 0.11542883541967187, 0.08115829114935227, 0.10330802188920123, 0.3751888817974499, 0.08861561492085457, 0.0980870681149619, 0.1088672796530383, 0.06366408416735274, 0.17066743490951403, 0.24858268829328672, 0.1128814181845103, 0.13591095778558934, 0.11296728679112025, 0.26074266007968355, 0.30492606492979185, 0.2200826025967087, 0.12734019197523594, 0.075861402521176, 0.14721423839884146, 0.1400327594684703, 0.14446028188935348, 0.14561947754451207, 0.10417449753731489, 0.12517668306827545, 0.20015957951545715, 0.10914231025214706, 0.15325400073613438, 0.13157220131584577, 0.21045784120048794, 0.22923768205302103, 0.12345082924834319, 0.07494196721485682, 0.07748069241642952, 0.10846607546721186, 0.15141494013369083, 0.12640633779977048, 0.09806496822940451, 0.1250343807041645, 0.25379839699183193, 0.24295646590845926, 0.09564054903707334, 0.09316804206797055, 0.1169890859829528, 0.09403890105230467, 0.12649502232670784, 0.11502919186438833, 0.15497467054852418, 0.16203565523028374, 0.23091369069048337, 0.09041029933307852, 0.13613294730229036, 0.14273315242358617, 0.268854057682412, 0.11509057214217526], [0.013447575952990778, 0.021847872562440376, 0.013980860372872224, 0.029012172682476894, 0.047042839628245146, 0.005852999390169446, 0.06967245747468301, 0.044190417509526014, 0.010752291518396564, 0.025355510147554532, 0.058786767667957714, 0.006410227190437061, 0.02736709845651473, 0.01792014037658061, 0.0542930473706552, 0.05994715754474912, 0.08771909374211516, 0.004001055952228073, 0.022499442599447708, 0.04206169709297163, 0.09991657494434289, 0.020099345494859984, 0.008846763321863753, 0.01316093307520662, 0.014654755060161864, 0.01109330540722502, 0.024107229629797593, 0.03239205739061747, 0.04964724023427282, 0.039141519859965355, 0.03742544372965183, 0.05477112278874431, 0.020893457079572336, 0.03840820670926145, 0.017785541081268872, 0.050528847213302336, 0.010675700181829078, 0.0036979344274316516, 0.037149035704455206, 0.008599232050723262, 0.061236869410744736, 0.0314999840089253, 0.00640358221218256, 0.012442217757260161, 0.007405902691451567, 0.031378170009702444, 0.02233079611323774, 0.058808657207659314, 0.016594455976571356, 0.03540077665820718, 0.023826377200228826, 0.02480083830388529, 0.03872005122580698, 0.02064421590018485, 0.009437397521521364, 0.021257538614528518, 0.014762058588010924, 0.023213700790490423, 0.025683956719668846, 0.0740975643108998, 0.037844751229775805, 0.0410769799325083, 0.0853054564712303, 0.0522839662485889, 0.007557327958888241, 0.03965941849829895, 0.03630520955526403, 0.0059482020941296855, 0.03990511942122664, 0.0045468589191191965, 0.037810980541897674, 0.05250815761142543, 0.09550049262387411, 0.06882079424602644, 0.01368428289424628, 0.045676097074257474, 0.034476730706436295, 0.017874247660594325, 0.014520746090316346, 0.06413958115237099, 0.010862755323094981, 0.04270321802635278, 0.03943827375769615, 0.020394643934975778, 0.03088237464960132, 0.015292333705084664, 0.02506477485543915, 0.023781461574669396, 0.04306373046711087, 0.03859140777162143, 0.016459278230156218, 0.050309819501957724, 0.054685074370354414, 0.053105875716677735, 0.010150888967993004, 0.02598955192869263, 0.019595119337152158, 0.022351635619997978, 0.048925475749586306, 0.02749060370427157, 0.04938053186716778, 0.03963056718930602, 0.01809883427007922, 0.020184097911364267, 0.017063420365697572, 0.04494553538305419, 0.0424139890819788, 0.02800797308529062, 0.018956492355625545, 0.028293622757441232, 0.05360424272449953, 0.03738670955811228, 0.04757670758824263, 0.01719326482686613, 0.05500254733487964, 0.03601086445684944, 0.07201079771454845, 0.03152801089787057, 0.02869912376627326, 0.02826562979524689, 0.02206514117174915, 0.02229439779849989, 0.04629427979567221, 0.051215059855686765, 0.02735489670054189, 0.0483539151693029, 0.011683445972656565, 0.016124645115009377, 0.03388064447790384, 0.012922025984153152, 0.0670989980655057, 0.035927577675985437, 0.09489975843046393, 0.00977854966185987, 0.03250989517463105, 0.05456537740038974, 0.04641908274165221, 0.008256946756903614, 0.04503496629851205, 0.014006263027632875, 0.0038356876383269472, 0.017158308399042914, 0.03981528477743268, 0.05839632504752704, 0.017302973761356304, 0.04048446619084903, 0.023396333579772284, 0.03769185354134866, 0.03303391419883285, 0.02427204917850239, 0.010125554166734219, 0.06243680430842297, 0.04714238750083106, 0.059313337983829637, 0.004489951459358313, 0.033285094292036126, 0.027646568370983005, 0.012322533509827085, 0.02606085069211466, 0.02652220191833164, 0.05084305642438786, 0.01479195653727012, 0.00814369841412242, 0.05748362759394305, 0.04358716595119663, 0.03821752479832087, 0.0393837772176734, 0.036016513260879686, 0.06500194487827164, 0.034168930258601904, 0.0065481593649435255, 0.0636013061074274, 0.028067190532705615, 0.05964747576841286, 0.0478340657427907, 0.06522995978593826, 0.01600194562758718, 0.07517277768680028, 0.03208957665732928, 0.018541232316887805, 0.022604866585295116, 0.06768387489553009, 0.028039567372096435, 0.008534539673876549, 0.02181852253020874, 0.03662581395890031, 0.012416587793268263, 0.00990534241178206, 0.04088208431910191, 0.03994760589141931, 0.038709879985877445, 0.04417647700756788, 0.019975909796942557, 0.012940007162147334, 0.06326535663434438, 0.010810388534862016, 0.020882965231846486, 0.021640137370143617, 0.015377192990854383, 0.09179051419986145, 0.06140393151768616, 0.042921166867017746, 0.047316343523561954, 0.04742953334269779, 0.02645331365056336, 0.02879190325204815, 0.029880185212407793, 0.07488855972353901, 0.022695296643567935, 0.04481437795662454, 0.030171310662158897, 0.06286770797201566, 0.011739436137889112, 0.027327180241367648, 0.005854004470165819, 0.02683794292222176, 0.034467112472546954, 0.03528183964746339, 0.02838027846467282, 0.04461344677422728, 0.001186106141955991, 0.062467677651771476, 0.02353284804017416, 0.02800724026747048, 0.020092492291171635, 0.03628989841256823, 0.03269884342859898, 0.03667603572830558, 0.028189927339553833, 0.024580740203548754, 0.028943131744329418, 0.04295451007783413, 0.03145326687289136, 0.0424060570076108, 0.03517000011301466, 0.06975420058837958, 0.04544743416564805, 0.037559230479278734, 0.06276726443320513, 0.02232913879145469, 0.06443250471992151, 0.019696083651589494, 0.022035197421376194, 0.004188902434959475, 0.024061364055212055, 0.004526085145438888, 0.09493884204753808, 0.04521139218871083, 0.04204347842772092, 0.04064717888832092, 0.027614068239927292, 0.016750571617324437, 0.011444694944657385, 0.01231991097198001, 0.013722437766513653, 0.062108786909707954, 0.03444158937782049, 0.05333126808649727, 0.0877892542630434, 0.04888653801754117, 0.012512646299520773, 0.01657155541969197, 0.02504975039378873, 0.03607039572671056, 0.021681852006752576, 0.05275184667802282, 0.037299388886562417, 0.034751113304602246, 0.0733477831152933, 0.0396495525991278, 0.02886706796873893, 0.061641079506703784, 0.026658792713923112, 0.04923540001202907, 0.02559193888945239, 0.02255492640792259, 0.058536164329520295, 0.012002357431421322, 0.03221322609377759, 0.07466939969786576, 0.04592322292072432, 0.034295619531933746, 0.040904411513890536, 0.05082099046558142, 0.007441345119981894, 0.055006720325244327, 0.08489132619329862, 0.03557628991880587, 0.07307705442820277, 0.02344162918494216, 0.03622461995109916, 0.053796481873307905, 0.06407078448683023, 0.05791857532624688, 0.02198055838899953, 0.041845529406730614, 0.04108981781506112, 0.08126433260206666, 0.005852062587759325, 0.022460437013900707, 0.008062293719766396, 0.038225579008992226, 0.0363332364442093, 0.06112082635185548, 0.031698299438825676, 0.03336713256846581, 0.02019501893248941, 0.01912705909593829, 0.05420428141951561, 0.0376130654476583, 0.0657287644488471, 0.06421506138784544, 0.0717663351180298, 0.036191280132957866, 0.06127956283411809, 0.007722194156875568, 0.02077364475865449, 0.041795975994318724, 0.03524186036416462, 0.027207983690979223, 0.05638023126604302, 0.01587153798235314, 0.039475281057613235, 0.017173682306227938, 0.07295329642615148, 0.0459187140555254, 0.02631706721149385, 0.036709195734666925, 0.020756292921890105, 0.056763003048087866, 0.020542062453127334, 0.019590880189623152, 0.04215605756533997, 0.045256202641342363, 0.03523806056806019, 0.022110631855736886, 0.029107364360243082, 0.049249472828315835, 0.017271128416593586, 0.04127911212188857, 0.02208520714858813, 0.036666451421167166, 0.020946647439684187, 0.025051665558878864, 0.032886210695973465, 0.09247554279863834, 0.008327494890961264, 0.036689762491732836, 0.017746281045089875, 0.10318295431456395, 0.033955870262746296, 0.027494206725220596, 0.12027060346943991, 0.18409352589930805, 0.1992933074278491, 0.0805582490616611, 0.13658553015972885, 0.16586342054818357, 0.11522513920707361, 0.13327030305351528, 0.09911993412034852, 0.08817308116704226, 0.09136315927441631, 0.1404452680477074, 0.11993012816778251, 0.14003744136009896, 0.11903192422219686, 0.139481178351811, 0.21289348336202757, 0.09063166459756238, 0.1986051643533366, 0.13704523763486318, 0.23448886456234114, 0.13769015802868775, 0.0962790979870728, 0.18923748630498136, 0.10086601506918669, 0.1398133755262409, 0.1411596161446401, 0.15113204531371593, 0.12652343937328883, 0.11020952370017767, 0.09000626565622431, 0.19693309121898242, 0.10406168430511441, 0.18523780735475676, 0.05396871441709144, 0.18608204062495912, 0.09837817999401263, 0.07469120781336512, 0.11486791766115598, 0.10012818966060877, 0.13309194333851337, 0.22576470912567206, 0.08213333918579988, 0.10636489678706441, 0.07636012575988259, 0.1374565927045686, 0.0830660466370838, 0.12946532294154167, 0.11588168969111783, 0.06355443969368935, 0.07685113405542714, 0.11433975957334042, 0.08486223061169897, 0.09417495410889387, 0.1010602457182748, 0.10858646115022046, 0.17299790414316313, 0.10010728399668421, 0.177764748356172, 0.1538435255310365, 0.11482470855116844, 0.1135276345802205, 0.16955184191465378, 0.1626887180443321, 0.14646114595234394, 0.1063121406893645, 0.1272551715373993, 0.12342458351382188, 0.12020215285675866, 0.06198295937584979, 0.19867969463978494, 0.13153828813561372, 0.1922157664916345, 0.13326659825231346, 0.17346549619521412, 0.17048448829778604, 0.09095643859888826, 0.08172266943646328, 0.079740295452731, 0.12466597690113954, 0.17974955828062125, 0.17285191054855073, 0.1545215312923704, 0.19310749721314224, 0.17314775181668146, 0.21708281284996442, 0.12430771041129317, 0.12735137423234327, 0.1353790813258716, 0.1861200657274042, 0.0954468883574009, 0.1398939990571567, 0.15943873886551174, 0.18117212051791803, 0.17129225709608623, 0.11427839286625385, 0.1290012185594865, 0.2005575538745948, 0.09189666421817881, 0.129070659833295, 0.16423960482435568, 0.11570544700537409, 0.10431190766394138, 0.11127639109534876, 0.14484963885375432, 0.21867454743811063, 0.13591117491679533, 0.11635879480413028, 0.07882590844695057, 0.18083028814622334, 0.18915376865438052, 0.10453616348760468, 0.09831424163920538, 0.06630838263247694, 0.07340399974158832, 0.16770136835319654, 0.12625744007527828, 0.100879015800144, 0.1071226711251906, 0.0952713242066758, 0.08991720793502671, 0.23823131088699612, 0.17043809007321084, 0.09587343582617384, 0.09364146952118192, 0.22207653203180858, 0.12166189881307737, 0.11825793289712497, 0.11195565893181733, 0.11423327028751373, 0.1838818501148905, 0.13597791562122957, 0.17827294394373894, 0.07889635395258665, 0.1238786591483014, 0.21816207707992621, 0.10926456869180713, 0.17303751701755182, 0.10554916198764529, 0.06307224556803703, 0.1252978965640068, 0.101118579373828, 0.1164095899356263, 0.16970573365688324, 0.1683214000825371, 0.10961813293397427, 0.12956225845430577, 0.12149603771311895, 0.1958332538072552, 0.1742684609655823, 0.1301011781075171, 0.11493520119360515, 0.1372038112687213, 0.14012210895972593, 0.08816149857427392, 0.08892726605491978, 0.1420809445636613, 0.10076135104256016, 0.1138450668326446, 0.15025107615760394, 0.13160132403884614, 0.12117548419960908, 0.10791120345571212, 0.12833113808717045, 0.15700689650007657, 0.06598764591451202, 0.13571233701493057, 0.10214507393538952, 0.11238241674644606, 0.18103752631161893, 0.18623484671115875, 0.17283411936036178, 0.07578587478825025, 0.13762666072164262, 0.11023359812263932, 0.25214624564562527], [0.061380555986293724, 0.03817707393318415, 0.07089504187128373, 0.05778439502630915, 0.024503751923995357, 0.014141582418233156, 0.02264855575880834, 0.04182577046698757, 0.02886083223191755, 0.004518249762311045, 0.008884244748125119, 0.04746144823729992, 0.03133559532995735, 0.05187262135690876, 0.037070681873176775, 0.035799426159688404, 0.042728724157703776, 0.034058315479861836, 0.03792456730401941, 0.0019007235324742006, 0.042230757485542975, 0.02470131078734994, 0.022754517483658025, 0.0636662622647626, 0.06003702272261892, 0.03955710559551205, 0.021296321979856918, 0.04160532122477889, 0.020961090057556118, 0.0305145476013422, 0.06556381937116385, 0.03238563844934106, 0.034872499826763353, 0.028976030514708588, 0.0449860948137939, 0.021739420614072254, 0.015591818706265517, 0.007956220884807408, 0.016606566130316684, 0.03648927914244788, 0.0530032269390566, 0.016090974511046494, 0.018719441057848077, 0.04692541575059295, 0.024126306641846895, 0.04009186922173415, 0.05486344087070652, 0.019003487691017132, 0.020466022426262498, 0.0871614600930895, 0.04097606820453491, 0.04404916687469397, 0.019441889166565876, 0.013704726306189383, 0.014032291630948228, 0.05996427698326962, 0.04352677294186183, 0.009998832662988986, 0.01172328445993896, 0.0375682821364275, 0.026953821436368992, 0.014308753090777566, 0.049086118915251324, 0.0196617938844221, 0.022790116823411415, 0.04082246144701328, 0.04495912304680262, 0.0940524378259267, 0.05283510971016117, 0.03652155366060989, 0.024760477344638536, 0.05477796242173229, 0.004587850067764521, 0.07297734370721237, 0.0435705689846405, 0.03327147948688694, 0.03819697197260601, 0.043223220123244185, 0.06387466751039028, 0.020459186185949614, 0.008981102229362088, 0.03976654221436807, 0.01131285134969013, 0.00989184295758605, 0.04696254179413829, 0.012296439597516187, 0.010956293071753212, 0.03469913412949868, 0.05687064923612135, 0.015933895350566933, 0.02567432152240404, 0.06547941640019417, 0.012574942599582885, 0.040647182280996015, 0.024863735107438903, 0.09900716838559934, 0.02532266396363931, 0.031612899021378586, 0.02283931230860097, 0.014429583214223385, 0.029641334100493362, 0.05255434549014483, 0.05107141738491399, 0.059229145358715735, 0.004412145121023059, 0.0744028507864901, 0.045572718871491294, 0.02302646923011967, 0.03568418377212115, 0.046442119005535326, 0.03567772072606853, 0.045308008790016174, 0.07905587753547089, 0.060067583939858844, 0.06592897977679968, 0.03626936933557902, 0.0460923172400466, 0.06222179691706385, 0.023909061781263778, 0.012812885322741099, 0.0479755877916302, 0.03562380772616182, 0.05513269713680659, 0.012575606715732386, 0.03397210082039237, 0.04932129915271487, 0.07307635553713356, 0.012555763807280787, 0.022828135140506283, 0.014502413770450013, 0.07165137771517038, 0.03525912568771413, 0.04716057223933084, 0.06512987587068762, 0.027036962332203984, 0.04593133819954736, 0.07532831826912505, 0.03268225664006812, 0.06501528487673827, 0.07937534539295094, 0.016460718420733298, 0.009599380793848207, 0.02847383656938161, 0.046157219114580324, 0.0389874245572303, 0.05282943376473018, 0.05446651145549757, 0.04885632963851094, 0.06662188616714307, 0.013774310072351779, 0.019878019246139696, 0.03790477443752544, 0.031139067839831114, 0.05249470565468073, 0.01990405124213014, 0.014262071577832103, 0.06624020343380314, 0.01755486461999161, 0.04005204260881458, 0.015052022046542593, 0.035552395308124166, 0.028302552278286645, 0.056603482857878716, 0.024451448748420392, 0.028091361646407416, 0.031044554697083573, 0.05244320145409022, 0.04184178728610277, 0.049850454687007835, 0.08696112941418375, 0.04673436064539211, 0.009359611963321055, 0.03221362642943859, 0.05084061369832073, 0.048911969510040114, 0.025846747448667884, 0.02566341237564172, 0.02816994278691709, 0.03004858742601105, 0.011771151712829513, 0.008895549141535801, 0.018787051983443753, 0.008708683141906346, 0.04223375321765031, 0.03861713781952858, 0.02589977326403771, 0.017659481149166822, 0.038164670313043256, 0.02750961795183165, 0.042306044338537116, 0.032652699654655795, 0.03989295328834227, 0.03372994524293712, 0.04478358603747828, 0.045419844931789806, 0.027898503334394524, 0.07739510879452739, 0.05193232226052454, 0.002864069808440815, 0.04801127873361111, 0.03682706405275634, 0.032951177031333954, 0.013506168300019843, 0.011917518501702164, 0.011151429565091218, 0.009591278237556773, 0.09781358457569565, 0.04906343209690281, 0.018995733732091527, 0.01941028470173478, 0.03432464047468134, 0.010571891109326055, 0.01642638454878969, 0.03689281748873847, 0.013076896513147014, 0.033389927952417305, 0.006943897103025977, 0.01632543889406536, 0.05337493520762239, 0.02280434231007738, 0.042827624029346874, 0.008274404614764665, 0.07355620193162135, 0.03321150038391352, 0.025273112247564962, 0.08657552474843604, 0.051209638360887766, 0.04798876154901726, 0.03438001571755324, 0.008906853534946484, 0.07069591898471117, 0.021774326151769077, 0.03987582706447158, 0.02468432535949562, 0.010522695624136498, 0.06244289076754025, 0.012922961514310112, 0.0183337939836617, 0.04195727055360164, 0.03512298781424761, 0.08095331250556878, 0.02285593980923295, 0.019791204083178724, 0.05558904247092349, 0.017714566318318248, 0.0245302130933851, 0.00855801104834037, 0.08901034588260309, 0.03380760018314634, 0.049889626513634405, 0.029441933014563153, 0.027355585413585817, 0.03952361649966665, 0.05319348137293543, 0.0885090170694249, 0.028317929578146765, 0.01907082211359271, 0.020676931466108987, 0.029391663747706583, 0.02499106729270092, 0.002479548254216622, 0.05647832368101392, 0.013221795970041837, 0.027808950282633305, 0.030167656751083474, 0.028309254507933344, 0.0200997390451708, 0.03438072478664773, 0.04725607265053051, 0.04898000282368489, 0.009019964474386402, 0.029710191834185804, 0.015340881189331412, 0.02419059444218874, 0.03760954045823642, 0.0365927353767412, 0.06927140935191087, 0.023195785769660558, 0.06055093836039305, 0.07413803213941199, 0.03423668537288904, 0.07069781888276339, 0.04479482936273728, 0.009850595661971186, 0.021811039985290596, 0.08109315857291222, 0.022117037226312926, 0.06080631858536175, 0.0466763289379222, 0.03351779109133141, 0.029749957378953695, 0.03558044255312, 0.011432058926272606, 0.0217970316298306, 0.12454956743334021, 0.054713206432227574, 0.04257986375263759, 0.04411488299125007, 0.034038522613367865, 0.05053669107811792, 0.14026371921811784, 0.05147605495793479, 0.020849837455898523, 0.06034508440643549, 0.05817744322121143, 0.0680532150768808, 0.04385249010686364, 0.027289268793538213, 0.08000826928764582, 0.04369042880300965, 0.036221301914857965, 0.038970888658825836, 0.028519803924219947, 0.01998526170583708, 0.03794488603515284, 0.07237892331821577, 0.06120810631130423, 0.0162166544635381, 0.03746560621740563, 0.05219321218984468, 0.04853291270722236, 0.0685525829238551, 0.02724960333268557, 0.034568712913564274, 0.02120605985900121, 0.007684939191676676, 0.03270840398701174, 0.02887352422944137, 0.015336650523490139, 0.010395458433777094, 0.055268356643084965, 0.006385671432196561, 0.011133344062337918, 0.03600225045478769, 0.020106388688353554, 0.01795915444381535, 0.05599483694615109, 0.058896717482379506, 0.047518536781093905, 0.04349489536668573, 0.05364290225718703, 0.03777997149154544, 0.03893982532567211, 0.03211146619703088, 0.029029848519712687, 0.04195363699857678, 0.059768092153327804, 0.02490838271166597, 0.021428227491144623, 0.07670509974871363, 0.06659625789948873, 0.021357081398101788, 0.1504227998001235, 0.13042938549603733, 0.136763387758817, 0.11021389346569777, 0.05327151968543019, 0.10952093279255287, 0.09763988639627184, 0.13064986866499695, 0.19183535261877946, 0.1250575187483004, 0.07529670532260622, 0.07441138675702469, 0.12993838398584298, 0.12127233828817095, 0.2597731963864395, 0.22635043412446976, 0.11504517814942769, 0.09815652974482093, 0.10339737816580705, 0.07714946554707629, 0.11284525905336652, 0.18040716727929457, 0.08888364982392107, 0.1495927750532116, 0.10267441945948771, 0.154237564387066, 0.1582133181925331, 0.15761080623737403, 0.05540384312293359, 0.06963896498616252, 0.1507270141903843, 0.08521462777363402, 0.10967844791178193, 0.05706980944211994, 0.16784400998481683, 0.10737170704773494, 0.10377553251704999, 0.07098253217658826, 0.17846882343292236, 0.157223552731531, 0.1367578644837652, 0.06497823686472007, 0.09309994429349899, 0.10288285863186632, 0.15820504006530556, 0.11188597338540213, 0.1730290489005191, 0.12143544453595366, 0.10283911347921405, 0.20181053664003099, 0.08839584421366453, 0.13622351815657957, 0.10611222391682011, 0.07960475129740578, 0.1657122429460287, 0.10821426433644124, 0.12928629826222146, 0.08268152084201574, 0.08141623623669147, 0.16269413275378092, 0.1252283060124942, 0.09010304510593414, 0.14453089024339402, 0.15070710597293718, 0.2480908046875681, 0.09353273428444352, 0.13254961743950844, 0.15688896711383546, 0.13902793053005422, 0.1172577722796372, 0.0684314440669758, 0.1245316541088479, 0.16539729413177284, 0.17645533861858503, 0.1035504217392632, 0.152730470257146, 0.13180955286536897, 0.202931761475546, 0.10270173049398831, 0.11653658454971653, 0.08685478262071099, 0.2317640579172543, 0.11511947773396969, 0.10643314383924007, 0.16311964206397533, 0.18920320671583923, 0.09785792005381413, 0.11448724594499383, 0.15579790994524956, 0.1113891296886972, 0.12296151050499507, 0.19258878433278628, 0.13115252740681171, 0.14563580309706076, 0.13685693059648785, 0.10720563560192074, 0.09373248820858342, 0.08833480320338692, 0.09152925107628107, 0.14039435077990803, 0.10295418623302664, 0.15461838538093226, 0.15236662620944635, 0.16789146672402108, 0.15187177062034607, 0.2921918625278132, 0.12840052507817745, 0.1429877251918827, 0.06805291652147259, 0.14313194102474622, 0.13837237070713723, 0.1249617910278695, 0.15992850544197218, 0.21163189677255495, 0.10107425746640988, 0.11240245388554675, 0.10006039044154541, 0.12635939674718039, 0.20077387083853993, 0.10570901805268866, 0.12024396418460778, 0.16111447608896665, 0.25013767342482296, 0.07924438813435179, 0.2912554570606777, 0.1391344198158809, 0.22318470185356482, 0.16737261813666138, 0.10758675515119519, 0.15587416371064527, 0.17945108429661819, 0.1357791998556682, 0.17939160391688347, 0.10536278198872294, 0.22266039784465516, 0.14940881063895567, 0.15468941442668438, 0.1242552325129509, 0.16406531631946564, 0.10684646666049957, 0.16013307017939432, 0.19920094524111065, 0.13951273023017816, 0.1389446607125657, 0.12980183559869016, 0.143039877393416, 0.17813552703176225, 0.08218415467334644, 0.17753505068165915, 0.10854737074779612, 0.10476138283099447, 0.1017777965004955, 0.1203638341810022, 0.1070076594395297, 0.15760768497628824, 0.07215428072959185, 0.1576767869825874, 0.10417388007044792, 0.08301213702985219, 0.1561598948069981, 0.14178538828023843, 0.08861296863428184, 0.15356547545109475, 0.1434544487191098, 0.18062087866876805, 0.14426787649946554, 0.15053084971649305, 0.30156517241682324, 0.12334866901593548, 0.1831592238907303, 0.1875784003308841, 0.12428020260163716, 0.1620867217757872, 0.16931153195244925, 0.16410475277474948, 0.10166374154921089], [0.052782570743667226, 0.06968446754451309, 0.021176401093336086, 0.004881045897491276, 0.01636354542071266, 0.05620434481118407, 0.026850772323086858, 0.05685399120141353, 0.04674481347735439, 0.02807214723101684, 0.009890569008088537, 0.10359286410467965, 0.03577018130038466, 0.04378033469298056, 0.03858896843822939, 0.016661028743588498, 0.029394618767712797, 0.02453836060262152, 0.05373803286680153, 0.04392727145126887, 0.03257285304633634, 0.02071399474516511, 0.04141116860721793, 0.02141698246954807, 0.0470221782369273, 0.009019647259265184, 0.03882177719580276, 0.047524334862828255, 0.027244531283421174, 0.08377747024808611, 0.06599176462207522, 0.03104228839012129, 0.062316201494208405, 0.045761819795838425, 0.026617765094020536, 0.02010215971884983, 0.02667596304257001, 0.05133483146450349, 0.02795785988148834, 0.05730850449098008, 0.019288816755371432, 0.07003563655806438, 0.05997446857924972, 0.06819656238492046, 0.01979996057759438, 0.05786462500691414, 0.0615700843877026, 0.026826375596491352, 0.03275638998353055, 0.04980237030291131, 0.06395048022802387, 0.016165640504498566, 0.03829385320256863, 0.010701576114765235, 0.03843625395425728, 0.02077880671380886, 0.01362043190082269, 0.018573135337127105, 0.059873156515615325, 0.022828048627291406, 0.011425276968761213, 0.006637448212131858, 0.06059324501880577, 0.057533866326723776, 0.00973381130357406, 0.026864387128236036, 0.03168397217190691, 0.041492562275379896, 0.09463459373052631, 0.036649128422141075, 0.06535698832677943, 0.07635332005364553, 0.04090801453483956, 0.031161035411059856, 0.048524756716298204, 0.042466701074902496, 0.03569314382704241, 0.013965564497214342, 0.01808421184042735, 0.02386664316457297, 0.02692757739818522, 0.057421392362032614, 0.035914651583880186, 0.07919170667550393, 0.03338454716971942, 0.04258362962199109, 0.04335853357666305, 0.033771488549453874, 0.016671447648799846, 0.008600695141857224, 0.007587035918342215, 0.031085857123668705, 0.03413891865472708, 0.03467075100966862, 0.061428731972617764, 0.03299226911206331, 0.042921557024653466, 0.008611752718154873, 0.017509436700493097, 0.009856969650302614, 0.021629089123702476, 0.037585571208702664, 0.011279470819447721, 0.009763931473051863, 0.030276259673493247, 0.02106698732157903, 0.08139538485556841, 0.020283116526635628, 0.040388867392071655, 0.0664932494983077, 0.05374632117205432, 0.06417717199240412, 0.023218168943588222, 0.030885550193488598, 0.05067533953115344, 0.039035770177309, 0.02769688343895333, 0.017967530958620564, 0.02931736077048949, 0.023806718344401036, 0.03470728672774775, 0.03126771129401667, 0.044000125756221156, 0.01657529075496963, 0.03268765099346638, 0.06563401381884303, 0.02702821771215115, 0.024476751319265792, 0.014504600349547607, 0.03497553197667003, 0.03013288861672793, 0.05470682820305228, 0.09633460893694844, 0.026311839099175165, 0.08974253945052624, 0.05097930286345737, 0.05824757660073893, 0.02303988895645099, 0.017411866757486547, 0.023292972340381572, 0.020461384639410034, 0.04239202829610024, 0.0225790941289493, 0.019168629543855786, 0.07744272159678595, 0.026104507635214498, 0.02605540375225246, 0.03389009307803852, 0.017311119574255178, 0.02305766148492694, 0.0395500522239932, 0.06028059643826314, 0.03230695552857859, 0.07785104361495801, 0.05176405914660011, 0.03940675241340484, 0.032487154073481045, 0.019230430513354282, 0.03965529300538557, 0.028869534443531717, 0.06643292094979968, 0.0391538997313806, 0.06136790130819593, 0.022286092529871633, 0.011952067808514195, 0.06510514326925788, 0.062163768602269034, 0.041182085006896935, 0.016040096259010688, 0.03832068247720599, 0.029321282702897276, 0.02499078570066818, 0.016625275037118366, 0.0685539399938924, 0.037947993725538254, 0.04871503829157778, 0.07127895019948483, 0.04253986072061317, 0.04006943006866744, 0.04277763296184795, 0.00671941990731284, 0.02378121730206268, 0.03704183395685894, 0.022366076541532363, 0.009308891470677086, 0.040146532002836466, 0.048746390002114434, 0.04133972565510443, 0.019682952302641103, 0.0355345566224839, 0.03375757518889649, 0.05525640764140657, 0.04436603933572769, 0.060948878792779784, 0.008833522559143603, 0.05652157350310257, 0.05120123131200671, 0.07057240525526659, 0.04942237712176783, 0.036450412656579695, 0.037134101148694754, 0.023345618176140955, 0.029202176058398824, 0.02540645286041711, 0.0943768589890429, 0.06847104337066412, 0.010567154086727117, 0.02745556245957102, 0.021501259911539297, 0.02066367119550705, 0.05147340867136206, 0.008535563413585936, 0.04311230678909591, 0.041360984157238684, 0.047615421403731616, 0.06825431928570781, 0.02750187417093132, 0.047185929092977724, 0.08003481357757534, 0.028479763572769504, 0.0293482782186142, 0.028618985387895788, 0.06570401827671699, 0.014634220894160015, 0.034033918753266335, 0.042323733746473274, 0.17539136856794357, 0.014863845626158374, 0.05233295986961041, 0.0311546877159604, 0.032028745992907455, 0.01367038395255804, 0.035537915370826206, 0.06224701806370701, 0.04411725786381534, 0.047966973789568455, 0.021760090487077832, 0.05832638165780476, 0.030962367142949785, 0.02280159085057676, 0.022093783831223845, 0.02533427200147084, 0.033922516873904636, 0.05677444314850228, 0.03835220042882221, 0.04979387504447784, 0.04399455837639315, 0.046306001488119364, 0.0689385879252638, 0.07042841333895922, 0.06182435181524072, 0.00791165216027626, 0.027147424440564852, 0.0028736382124147242, 0.03341823982607041, 0.06769945405955825, 0.05496783348332558, 0.030610088724642992, 0.024733100152973617, 0.044610817451030016, 0.041120280644723346, 0.04177260724827647, 0.034870559216610024, 0.09434654882975987, 0.046010160219988654, 0.014246505984504308, 0.04061748958857996, 0.04122361474271331, 0.04890224949589797, 0.045211382010685544, 0.026338435975568633, 0.04609555724476065, 0.06420240670974765, 0.0123133139152612, 0.03985381538846663, 0.02596927560599787, 0.050770924759230444, 0.05295336479321122, 0.03976249475298183, 0.004006530881659793, 0.028921415231057575, 0.079604140615889, 0.026833191480753676, 0.055419849764023504, 0.03997947328857013, 0.03818049035700304, 0.0025819881702773273, 0.02655461723251002, 0.017165341414511204, 0.015150019466610891, 0.05284006301579731, 0.06768524553626776, 0.06504990373338972, 0.010469981086706477, 0.02555324203733887, 0.004494298748405916, 0.037091207557490895, 0.06120134810251849, 0.0675978162991149, 0.055326001585594246, 0.07829969096928835, 0.008596654465821172, 0.03460572699883154, 0.06504980195313692, 0.01359567470249853, 0.0599478225090674, 0.07719853719962494, 0.09878963005862065, 0.047262423738305054, 0.044943978145186386, 0.05131656190912638, 0.023116314051938907, 0.019338451591985564, 0.03193768320072975, 0.02766598804321672, 0.02067718591674098, 0.07179406005889177, 0.0533916984152581, 0.049633465973394256, 0.06088867238057511, 0.05622800871995943, 0.04891411368069904, 0.034214877257389684, 0.025456391341452087, 0.029419134237936566, 0.028788697174085037, 0.03056304928447519, 0.027548844061259712, 0.03500887179481132, 0.020688824488648346, 0.030728265776165893, 0.03600041841023734, 0.03246492865894522, 0.05493270233273506, 0.04974771769983428, 0.005749118647405079, 0.07454598774867398, 0.03475436348734157, 0.031622863308127434, 0.041547353978135755, 0.006756674448427345, 0.036851375962474515, 0.06144193626408066, 0.05853466476712908, 0.06338719438229289, 0.04253294984144824, 0.011542178374449057, 0.06918625320707049, 0.03963420752968107, 0.07317284321678535, 0.021404916420578957, 0.04337909658040319, 0.17497553516711506, 0.2202570132379021, 0.12130486725696496, 0.17443470204515116, 0.10285322022225175, 0.1551897254373346, 0.17600977181323937, 0.06603546227727618, 0.11401186431092875, 0.17588496208190918, 0.17699660600296088, 0.1861901312534298, 0.14230108846511158, 0.09061728644051723, 0.09344451794666903, 0.0911166135753904, 0.182510856539011, 0.12617725080677442, 0.17265832450773033, 0.18369346165231296, 0.1837115513959101, 0.20444612950086594, 0.17508704561207974, 0.07398742450667278, 0.09983683350895133, 0.10789882697697196, 0.1247811107231038, 0.1717599712844406, 0.10858281063182013, 0.19250901575599397, 0.10410112076039825, 0.09072592668235302, 0.20399493085486547, 0.13463320849197252, 0.13950092372085365, 0.11921299807727337, 0.1395168692937919, 0.15496621600219182, 0.13254462342177117, 0.13356889917382173, 0.1370434055903128, 0.09894648021353142, 0.14345382446689264, 0.13696958098028386, 0.1312799427126135, 0.0900807280891708, 0.19875229788678034, 0.2594758894826685, 0.14635430382830755, 0.15795376497719968, 0.20757015900952475, 0.08202267012425832, 0.12286629847117833, 0.07115578252289977, 0.17434201416160378, 0.11595702064888817, 0.0929283427872828, 0.09950023942760058, 0.18788713376436914, 0.15622213003890856, 0.13363448636872427, 0.1552635771887643, 0.1323478211249624, 0.19214133120008878, 0.053765710310212204, 0.17513690436525003, 0.1327798172299351, 0.17626486026815005, 0.1280100146042449, 0.15236197145921843, 0.12628565356135368, 0.19569365201251848, 0.1616916786879301, 0.09080178011208773, 0.19166407680937222, 0.08826169784047774, 0.07256820066166775, 0.21040252702576773, 0.0883121197777135, 0.22324893197843007, 0.1553948058613709, 0.12274684916649546, 0.08147003727832011, 0.1472278633820159, 0.09635134839585849, 0.20594989880919456, 0.16929234298212187, 0.21237585613770144, 0.10747927520424128, 0.14437163807451725, 0.12177768402865954, 0.17521397237266811, 0.13609002317701066, 0.12612059313271726, 0.19710527626531466, 0.09425643937928335, 0.1520344561764172, 0.06344081900481667, 0.17538523461137498, 0.07252978200891189, 0.07803160856877055, 0.12209867180458137, 0.14843451577637876, 0.12247049542410032, 0.09116372426173516, 0.14429758276258195, 0.11750941377665315, 0.0660436861217022, 0.10981332710278885, 0.12426627906305449, 0.14906046433108194, 0.14529924972781114, 0.0959816418055977, 0.08959753651704107, 0.11657800232725483, 0.08778151217848063, 0.0846221920635019, 0.10370739403047732, 0.11662130643214498, 0.13975221237965993, 0.13988924931202615, 0.17760890243308886, 0.12176457473209926, 0.12418788112699986, 0.15394002678138868, 0.15594995607222828, 0.1142676720129592, 0.19963659186448368, 0.05382178105147822, 0.12804683191435678, 0.17176029698124953, 0.14722535280244692, 0.13534568383225373, 0.19932134449481964, 0.1668581800269229, 0.15183875310633863, 0.13711241260170937, 0.140972516898598, 0.10721403586545161, 0.08193712721445731, 0.16281130218080112, 0.12122045750064508, 0.1432057927761759, 0.15739879118544714, 0.18675474024244718, 0.16623404994606972, 0.1081734165283186, 0.06332358850964478, 0.11231998473938022, 0.14761732891201973, 0.14387469259755953, 0.13785637196685585, 0.14348247221538, 0.17833308928779193, 0.19737911942814076, 0.11930685304105282, 0.08131856112075703, 0.10189462666000638, 0.23117384101663316, 0.08257655825998102, 0.19207847171596118, 0.09417592441397053, 0.15846850164234638, 0.09602157359144517, 0.12032441129641873, 0.11303000378289393, 0.1289171344999756, 0.18782161442296846, 0.14533047590936932, 0.07950377171593052, 0.07432710592235837, 0.2486303485929966, 0.1163400129548141, 0.1354693943368537, 0.1388166347252471, 0.13011966140142509], [0.05818108695426157, 0.03241556862901364, 0.009669575241527386, 0.021785255654581955, 0.07317044120281935, 0.007992528445486511, 0.06017296042825494, 0.016461040724867156, 0.035622267451669486, 0.06089409387537411, 0.043512846010604074, 0.013939462951384485, 0.012432469753548503, 0.026436472411400506, 0.0202490438906742, 0.015336011004235064, 0.03147447448489921, 0.0062408461900694025, 0.1499595639428922, 0.01998656788574798, 0.012428887088650038, 0.05129232803093536, 0.01730320955227528, 0.036780679398881536, 0.054361338527607064, 0.015413379263398903, 0.003964866711092847, 0.01996909052000514, 0.03779686701350978, 0.03090493593897138, 0.06068203811134611, 0.08024509157985449, 0.030583965126425028, 0.03699490986764431, 0.06268566381186247, 0.06716066332800047, 0.04028551633070622, 0.02786283614113927, 0.06987810786813498, 0.04066178096192224, 0.024772665529911007, 0.02162476346295859, 0.045857696793973446, 0.1507002663399492, 0.019366079841607382, 0.025201745630641068, 0.05063136028391974, 0.022400088109342114, 0.04428076105458396, 0.04591475480369159, 0.03865537326782942, 0.06876739354005881, 0.022263446423624243, 0.024542721886453883, 0.02415864392449813, 0.04590921117258923, 0.05915638604866607, 0.03623479458370379, 0.016718146125120775, 0.037229604952569516, 0.04577353809561048, 0.03362295384119664, 0.050579435391617675, 0.017823856257434403, 0.006969155145010778, 0.020381290365808775, 0.012071461134058024, 0.04521562624722719, 0.030822514290256158, 0.008224339756582464, 0.027412982690813284, 0.016334188603130833, 0.008997777227445372, 0.09707267183278288, 0.04121554356866649, 0.012984500399657657, 0.016507640813610384, 0.02917530946433544, 0.05661997804418206, 0.06821782088705472, 0.019195226420249258, 0.02192448595139597, 0.047228588589600155, 0.021323924784415534, 0.05256178901929941, 0.05938824824988842, 0.031882419916135926, 0.006244007315087531, 0.052553551604173014, 0.04115157467978341, 0.05798735163573708, 0.06882862454014164, 0.030848600569048097, 0.06305824739060231, 0.017934637277254036, 0.011499948899394699, 0.04381132338728223, 0.11005796611841236, 0.033111657348594496, 0.05820707484547581, 0.028044503714357103, 0.013947043035711561, 0.03191621435273971, 0.02867214860660689, 0.03769741413582649, 0.06365604352738176, 0.06478661857545376, 0.0712968295972262, 0.025253940240613053, 0.052371789036052566, 0.03627773906503405, 0.01576434980545725, 0.09020274225622416, 0.02799328280213688, 0.051855610483991246, 0.08244623203894921, 0.037855051391358883, 0.0382005919569305, 0.032751830228205235, 0.04073371245924916, 0.02540764368937484, 0.034380962273904254, 0.04563349525311163, 0.06383962117667709, 0.06361552820141826, 0.03848377515428832, 0.02818705713642495, 0.01284535916056484, 0.040195674901562076, 0.04600315434592111, 0.0234185403345951, 0.05721996245639665, 0.08002051005938224, 0.051939063505934815, 0.04563950028802667, 0.04565290813999517, 0.03260320391772049, 0.03150283385600362, 0.043751517310738564, 0.04718358136181321, 0.004167563356791756, 0.03154969009171639, 0.02241852899481143, 0.07601968438497611, 0.04105125327727624, 0.009846432001463004, 0.02288951032928058, 0.06514115312269755, 0.023198508391422883, 0.013686192122155001, 0.016191755621028796, 0.03853381032656346, 0.03741494679291334, 0.048014922466661246, 0.047762979021562, 0.029200439008751085, 0.05930185038596392, 0.015047959318118436, 0.07536592267985855, 0.011158131794737918, 0.03787609276228717, 0.026771039369383028, 0.07720094599894115, 0.03947224461340478, 0.02228917138251875, 0.05505319658134665, 0.029914773534983397, 0.005220091610681266, 0.0514273497142962, 0.01937947073020041, 0.03556177605475698, 0.02117077094901885, 0.04541635726179395, 0.057039573921688964, 0.012123983137176504, 0.04888563556596637, 0.0461686761783702, 0.028035664099401662, 0.03625954754118409, 0.0010635953720858587, 0.061535703018307686, 0.0555023392662406, 0.03835409014884915, 0.03377089143863746, 0.05085455080760377, 0.0393832276043083, 0.0055486128216476315, 0.038067894256008525, 0.01865772999423955, 0.04068479686975479, 0.01635685676176633, 0.0231353944566633, 0.017885172074394565, 0.009548008059417563, 0.065510120109788, 0.060746838205627034, 0.0357220663822123, 0.08322613340403352, 0.0779089362227491, 0.05017059090148125, 0.015954631380736828, 0.0421298864696707, 0.013168710782857878, 0.0391648411085563, 0.03509410597117884, 0.050071599427610636, 0.010194203250908425, 0.07803557799862963, 0.029540734498628547, 0.008396250844400908, 0.056163218803703785, 0.10141670051962137, 0.018853921609531556, 0.019317668064364364, 0.013195002318492957, 0.019841887256396667, 0.036485940750156126, 0.0157186657389892, 0.011913016421853431, 0.01759764625291739, 0.016801728068717887, 0.03840557399338909, 0.041019915137439966, 0.05414797319099307, 0.07963455255542483, 0.039434823407126326, 0.0626019529466118, 0.025547194593985165, 0.03637437602238996, 0.020372074163917984, 0.03860078851825424, 0.01654025968829436, 0.01931659258635981, 0.025331903914255754, 0.027766161864357333, 0.02049844791846616, 0.031124075608594075, 0.04013365340818252, 0.06937003441687141, 0.02938560103731496, 0.05694357478725059, 0.010182336521601039, 0.03166645239772541, 0.04461913289768355, 0.01078928100676941, 0.09466762481523411, 0.0321473030240408, 0.050334887978221686, 0.017405688696141754, 0.05522457077833159, 0.03095247410237789, 0.030901736646358455, 0.022914795936750512, 0.04434092675468751, 0.03287628033597555, 0.03143801340567214, 0.01238028786610812, 0.04319167842290231, 0.02047742181457579, 0.02751607590887163, 0.03525122754009707, 0.07453636612210955, 0.029942596863423074, 0.0031037126859051307, 0.07937200700065919, 0.11881411448121071, 0.09116448422095605, 0.011975118491266454, 0.05219659468691264, 0.0486552356077092, 0.024095697927155664, 0.03944474358909896, 0.016214433957689574, 0.1006191097466009, 0.022275202042822326, 0.06476447797779526, 0.026029329347823347, 0.014637070741238338, 0.027429041918367147, 0.015793189240087355, 0.008229650989440935, 0.03685025977236884, 0.03354557031499488, 0.023187796019815972, 0.056482835938887935, 0.038060036820492575, 0.009638885102633919, 0.02545018953138164, 0.03456763743555971, 0.0341901175145592, 0.052986748716128726, 0.016812896755124842, 0.017522439127787948, 0.027688868244045546, 0.004121395410038531, 0.10314732444073473, 0.015989769316677536, 0.009803249184707446, 0.04028110246040991, 0.01949903029682381, 0.09969444972063814, 0.036308313852974346, 0.06914235877671412, 0.02590943729904081, 0.019971623151962246, 0.08856998344085046, 0.022334996245003173, 0.054727594767298014, 0.03126326010429433, 0.011627334519289434, 0.012674551540320473, 0.033562930633447, 0.018430322375414625, 0.03204923775047064, 0.023987736220338514, 0.014600560468222414, 0.031049837092203752, 0.018798834744042585, 0.013236352242529392, 0.03450678641508732, 0.024308629001357725, 0.0249056075034397, 0.031381070746907165, 0.04882646731234022, 0.004963939976213234, 0.04127065757555621, 0.005812707556677716, 0.016254681262320707, 0.11069382806973797, 0.029500086858336414, 0.044752129154013734, 0.029953680732952695, 0.023243805692930306, 0.058635854694460116, 0.057751513219305446, 0.04633849992283753, 0.014591013480510031, 0.025448208209127188, 0.0722854347633464, 0.05857875597264085, 0.04050723782607487, 0.03040945270497884, 0.02713598094747535, 0.022023178869858384, 0.05800050842974867, 0.04349952297551291, 0.022911286214366555, 0.03389998272593532, 0.008806532980608088, 0.047998512097235234, 0.014147278719714709, 0.07033731322735548, 0.14768158617828572, 0.0875804079696536, 0.07270440978131124, 0.08729506363826138, 0.21219014110309736, 0.0836744075641036, 0.18737190855400904, 0.08803821554673569, 0.1098929260458265, 0.1283744014799595, 0.09332955375845943, 0.08367844484746456, 0.12724724624838146, 0.13029951389346803, 0.10271053109318018, 0.11173609857048307, 0.11986956213201795, 0.09853583760559559, 0.23136858056698525, 0.13375389496130602, 0.11800759418734483, 0.17337762591029915, 0.1485461483576468, 0.10909631914858307, 0.11680885351129941, 0.14854798040219716, 0.12282079591282777, 0.154242694111807, 0.1349432718540941, 0.1410515390868698, 0.13220577660415853, 0.21066974768681185, 0.09000220123146262, 0.11660411235477243, 0.15803897540484155, 0.16831469615655287, 0.13394866165305885, 0.09400701669177838, 0.07898334214197737, 0.11361534880208117, 0.16298280869211468, 0.17645086028746196, 0.08223868174744503, 0.20883828667657717, 0.056492902005889585, 0.08501969144812652, 0.11873433233371802, 0.1404645655836378, 0.12770171543317183, 0.1060986735724977, 0.1148751779858555, 0.20655083656311035, 0.11363845291946616, 0.11973442509770393, 0.1409642252006701, 0.10889838369829313, 0.16959403322211333, 0.077670824714005, 0.08059040483619485, 0.11828374436923436, 0.09772286444370236, 0.08676731267145701, 0.16765264953885758, 0.10374894072966916, 0.10655926314315625, 0.10543586021023137, 0.12663448841444083, 0.1497787343604224, 0.06326787399926356, 0.13451038008289679, 0.14960570793066705, 0.07265724481216498, 0.1902998685836792, 0.1631313128662961, 0.15117499658039638, 0.14469314153705323, 0.1240838345672403, 0.09449946348156248, 0.19798814531947884, 0.13603156059980392, 0.08616842409329754, 0.11175699066370726, 0.11505869456699916, 0.11698314201618944, 0.15481233783066273, 0.15316961812121527, 0.1402127883796181, 0.12195474095642567, 0.17783045768737793, 0.12642281263002328, 0.20628531223961286, 0.12849115021526814, 0.09649347434086458, 0.16458645835518837, 0.07288177883518593, 0.15428274124860764, 0.08775134451155152, 0.30493556442005293, 0.11841582799596445, 0.16410005731242044, 0.14374891934650286, 0.05750526607568775, 0.06769080273807049, 0.04828250953661544, 0.13308844209781714, 0.12498507834970951, 0.20837985484727792, 0.13039114326238632, 0.09555796453995363, 0.14119698985346726, 0.22872696231518472, 0.16082795789199217, 0.17692787040557179, 0.13005015227411473, 0.11934118691299643, 0.13700171639876707, 0.09905609754579407, 0.0790504492553217, 0.129635146686009, 0.166133708187512, 0.12307372662637915, 0.12887172693652765, 0.14877063488321646, 0.1303907497120755, 0.17796252774340765, 0.11272905993142299, 0.1043166641944221, 0.12588761134871415, 0.10410301387310028, 0.14964749211711542, 0.08377042705459253, 0.11339638555156333, 0.172598966264299, 0.09388884303293057, 0.08421676060450928, 0.1564604586788586, 0.05725047617618527, 0.12355260950114046, 0.1438868519450937, 0.13380975196404116, 0.14631162397563457, 0.10710040160587855, 0.09416211622634105, 0.15875436844570295, 0.15963772604508059, 0.1108069195012961, 0.10722222578312669, 0.2621123237269265, 0.09429475625178643, 0.1352922831262861, 0.10111306288412639, 0.11384727885680539, 0.13236455379852227, 0.11336792100753103, 0.1908058114349842, 0.10478748607316188, 0.2654159478843212, 0.15432448472295487, 0.24211201550705092, 0.10973806399852037, 0.12679762180362428, 0.10497701447457075, 0.16262291371822357, 0.1429729466991765, 0.08854326951716628, 0.0806513304955193, 0.06958179841084139, 0.07387763075530529, 0.12182687781751156, 0.10107355178999049, 0.10287248383143119, 0.09666296560317278, 0.07890341750213078, 0.18445689497249468, 0.08678773657551833, 0.21207823710782187], [0.0380685592203268, 0.05066765172939215, 0.04580848604174597, 0.023606497927435806, 0.04474873647892049, 0.031603297750864706, 0.0316217742594225, 0.010413534606673887, 0.013079426600597799, 0.029346500456865345, 0.02236835641919502, 0.029266738665423224, 0.10312979109585285, 0.019257258091654097, 0.03958304598927498, 0.020442607879106487, 0.020124001761100123, 0.028427830198779702, 0.03236554363476379, 0.0724667189642787, 0.05551131289186222, 0.02779766794161073, 0.028781328283782517, 0.030780373872922998, 0.07177670313311474, 0.03823804708995989, 0.007645385689102113, 0.01564846620229738, 0.05487212611894522, 0.05419298041878002, 0.026217387024579302, 0.043304725749684234, 0.025217416396896754, 0.02753269492781588, 0.06397504319569894, 0.03352072575528707, 0.028209898321490203, 0.015578892614160265, 0.017768872868535773, 0.01725059764326683, 0.035435042676648924, 0.03718551713973284, 0.03132196016875761, 0.04129962084282722, 0.003569441947287747, 0.039246224598692994, 0.0575995213751282, 0.06176109878080232, 0.0517177253828517, 0.029443161162946905, 0.048844380636832545, 0.0025630761270544356, 0.0193929294722953, 0.019526816305837462, 0.04569015971251896, 0.008506952984524625, 0.018879585500274385, 0.04061333695426583, 0.07431632400091205, 0.019904914677941372, 0.11131333054176398, 0.029375192310128893, 0.011055500828661025, 0.06890029819416148, 0.030208792936589037, 0.06407676238034453, 0.08569964460496392, 0.011408227080080127, 0.01679063232482544, 0.03775583939360721, 0.005468930333985814, 0.030668022044535195, 0.025465960381552577, 0.04791013291105628, 0.01381069396822048, 0.023067698714190295, 0.04540473395692451, 0.07205461750605277, 0.03141190337815455, 0.039605637812720876, 0.05368269833603075, 0.013597265018948486, 0.0808714743969696, 0.005959144743558551, 0.04755079772855554, 0.035746972010071786, 0.019575833675584624, 0.0870351507993681, 0.041229904762336185, 0.015594302144433771, 0.010786828950845768, 0.041286477619515996, 0.0944427786661046, 0.027061735645734837, 0.02642825195964958, 0.07763170038482972, 0.024174986440422278, 0.006045632089288639, 0.032646694619740756, 0.03943223479603018, 0.047148931971085925, 0.02905376348644495, 0.020777334292818393, 0.02073537538360272, 0.058855822176805565, 0.04351231336061444, 0.056852953042835, 0.02392022028964545, 0.04368139410923634, 0.030047304994825805, 0.03298275265842676, 0.023338571589972292, 0.0324650881146746, 0.018321436164634566, 0.028199542180768082, 0.030729242866592746, 0.016616469348913858, 0.048522721111242256, 0.05677998338692954, 0.017888303513505628, 0.025072091159277728, 0.05919101847601788, 0.020634475529992154, 0.012868928922606366, 0.019393000718472258, 0.039161241480282376, 0.02525365355956767, 0.005167869011139763, 0.014844215608068874, 0.04604204458051494, 0.020471445617399046, 0.03006702322246773, 0.023704600520431995, 0.08441994113049336, 0.02342116117610463, 0.00979512372785913, 0.027678335684218576, 0.037196869030594826, 0.02777824826937701, 0.044595027941146066, 0.027623518536399518, 0.05516026940728937, 0.04402347414621285, 0.0220897397625127, 0.022881444244246398, 0.041151242197624276, 0.02059144283910947, 0.042984117953372855, 0.04027361821915422, 0.02776432133811925, 0.030352655931242874, 0.143767809761422, 0.017165236241583313, 0.05710592786116259, 0.06974615316305842, 0.011042221898346074, 0.02969735734430807, 0.09998932068369218, 0.060365467598395686, 0.02336553148260074, 0.02339329883190138, 0.03180083965084382, 0.03809373965486884, 0.03135857391836388, 0.021392846978934746, 0.05093864504513996, 0.004651827014250947, 0.020673019711726477, 0.04253313643857837, 0.028554782404431274, 0.053098415224147696, 0.010545662338180202, 0.051545882996703894, 0.052027870169175525, 0.03455132206103631, 0.017131514747494032, 0.020085011442591037, 0.02937474108434149, 0.02678941749036312, 0.03156463821817722, 0.01874237384514085, 0.052009081534509144, 0.03890692994796804, 0.022639120729374032, 0.030426643389676298, 0.041912263325814686, 0.017355760393132056, 0.03544395184144378, 0.07827949776713337, 0.02832292529222156, 0.0737849021596568, 0.026625352811866572, 0.03364939295819827, 0.017183509189635515, 0.024549766776285002, 0.05554384186065622, 0.04053526471502014, 0.03112440130540303, 0.029945443317826306, 0.05716504183198724, 0.00807781605648675, 0.030003563234848634, 0.02229989053947585, 0.028016291924619248, 0.06681079031633479, 0.06414203066378832, 0.03466733119317463, 0.026812094130686352, 0.010567547637037933, 0.010003573926431792, 0.028886881191283464, 0.03358671667852572, 0.06804951027567897, 0.035559747235051224, 0.026946179435721467, 0.011590459533700985, 0.03287131006696394, 0.028769226611724923, 0.027337904487337385, 0.038756743006940396, 0.042385419365018606, 0.025928870541974902, 0.033962737037135024, 0.027406411079157676, 0.0496295779677374, 0.01749960981708552, 0.019885722314938903, 0.03743226979193943, 0.008872847904318144, 0.014958029679421867, 0.014908333774656057, 0.05665499384381941, 0.007385952065565756, 0.036892308587474484, 0.05334986673135843, 0.01609146305625992, 0.05261617020836898, 0.06504701317421027, 0.0050427492741229275, 0.038752851608608446, 0.06218067769493375, 0.0955479493630784, 0.058675515066300116, 0.019757548746253763, 0.026243186622325863, 0.06178395862558058, 0.015389131814507502, 0.05436322485495891, 0.04252417299098202, 0.018868179326610904, 0.0663366639720542, 0.04852703320128577, 0.023606207853715335, 0.004986180657786983, 0.03772085752072079, 0.024442164693027735, 0.010784752633688706, 0.02013387274928391, 0.03235155224267926, 0.028671375076685632, 0.022806181139977913, 0.02708099246956408, 0.05526601230459554, 0.006927107178073908, 0.02965806338137814, 0.04969818464347294, 0.0314049483942134, 0.058311277468289645, 0.051136824768036604, 0.06568242729242359, 0.046890169249049256, 0.016446545520531278, 0.033139433179582865, 0.029538430872240236, 0.0413076614827982, 0.07278678393257515, 0.04323909105733037, 0.012160538363137414, 0.02288254177463906, 0.05140147378136005, 0.017363648362723843, 0.045662370310830216, 0.050622834491410425, 0.018928762325750928, 0.06659739105296986, 0.03200715161593897, 0.031695171392389705, 0.05296886592571225, 0.02642447082325816, 0.07706962233143193, 0.03704235303614821, 0.06270475778728724, 0.08846753822373492, 0.06656184938869306, 0.01795390767178365, 0.04950141627341509, 0.04140148591250181, 0.00914857060914593, 0.016910112163584148, 0.03086941802342023, 0.040726669265755584, 0.06035211402922869, 0.018896830467773334, 0.05436750301825149, 0.010818789646561657, 0.08516972911145006, 0.02184298032495592, 0.04552659884627376, 0.04386609812666263, 0.0587527866342238, 0.02989039377176336, 0.011850866006820329, 0.02959706986855183, 0.030934706662914584, 0.03771274224189775, 0.07845221885613032, 0.01716586049380047, 0.04214736553175109, 0.08279343840799161, 0.04979942885360547, 0.018255177220063548, 0.04015046072059444, 0.05264622591702001, 0.010281754624364632, 0.04709998584751572, 0.0423132300243846, 0.020538698615772382, 0.055091313286019225, 0.023147650495437638, 0.03574314167989152, 0.07487900595047645, 0.06328641157597303, 0.01724335428194276, 0.03043245504211102, 0.005048927335467721, 0.027132277842611074, 0.014287609939596482, 0.013140197893205498, 0.05419109748410327, 0.03643162741458841, 0.047808559611439705, 0.04341932352898376, 0.04579694416107876, 0.04945264317627464, 0.0303110244151737, 0.02545326668769121, 0.028020911051758697, 0.08748083974101714, 0.027146197988518646, 0.07950570554073368, 0.033190693107566664, 0.028987579180725982, 0.09755462168582849, 0.1299585093344961, 0.09518751834652253, 0.19486687066299574, 0.09995904445116009, 0.15977071890873568, 0.10656465071120433, 0.03879748224946005, 0.05424687984798636, 0.21915667371026107, 0.2038273869880608, 0.14440711188529218, 0.19962748592453344, 0.10050525157047169, 0.10655276956302778, 0.09877499405826841, 0.13043731078505516, 0.15932451428047248, 0.18194307200610638, 0.23193342025790895, 0.12651478126645088, 0.11764448295746531, 0.13863865498985561, 0.17891190680009977, 0.11114754408065762, 0.18342210192765507, 0.1048329072073102, 0.12519641486661776, 0.15948743053844996, 0.14150771817990712, 0.16841392511768, 0.14174386193709715, 0.07226411519306046, 0.08831783982792071, 0.08329187666199037, 0.11710033858461039, 0.09013116359710693, 0.1409413314291409, 0.1906282931034054, 0.09945342729666404, 0.08658532957945551, 0.09517285520476954, 0.1768609939941338, 0.16885729346956524, 0.12757454439997673, 0.22347379848361015, 0.18080174896333898, 0.20105916767248086, 0.17711057274469308, 0.09578950782971722, 0.13492573850921222, 0.15501760824450425, 0.11081310774066619, 0.08289711855884109, 0.10965534379439694, 0.16262402651565416, 0.10448808928153344, 0.13691209549350397, 0.19039784904037202, 0.11608620014573846, 0.17545573439981255, 0.09465790140841689, 0.10852495873613016, 0.21199865852083477, 0.15858219697007112, 0.18641476705670357, 0.16989086515137128, 0.1647651573376996, 0.13763100334576198, 0.12241139502397605, 0.1289663961423295, 0.1277256677193301, 0.13304270883756025, 0.181624174118042, 0.14713617973029613, 0.14348433140133107, 0.1407591990594353, 0.10285269096493721, 0.136266577988863, 0.08710452421967473, 0.13387366996279784, 0.10204224195331335, 0.12208594248763152, 0.16360254186604703, 0.09514271467924118, 0.11322042785052742, 0.10619251496557679, 0.15788561291992664, 0.12053880122091089, 0.1517991130905492, 0.17186143941112927, 0.13539631611534528, 0.2394551166466304, 0.107451102430267, 0.09455735608935356, 0.18728914085243428, 0.11787985318473407, 0.2582955913884299, 0.1392301203949111, 0.1106394434879933, 0.10431908656443868, 0.13852509536913463, 0.11378024638231311, 0.13867277173059328, 0.09506612164633614, 0.13241192911352428, 0.15842992014118604, 0.15055816753634385, 0.2445805530462946, 0.16229233145713806, 0.26714490939463886, 0.13965543971530028, 0.06880883167364768, 0.1598735169640609, 0.0673879182764462, 0.15762349484222277, 0.11592071902539049, 0.21341197911117757, 0.09618390630930662, 0.10458692469234977, 0.12890133820474148, 0.1133293259356703, 0.07082490170640604, 0.13765879614012583, 0.12695086215223583, 0.14124459587037563, 0.04933507680626852, 0.1577344217470714, 0.0657857885318143, 0.14126846673233168, 0.14202093492661202, 0.1394766593085868, 0.17645820203636373, 0.13262929102139814, 0.05979294010571071, 0.05987821838685444, 0.15720810927450657, 0.0955694317817688, 0.09671882260590792, 0.12547761334904603, 0.14055392864559377, 0.1283832767180034, 0.21558820376438753, 0.1202687985662903, 0.06580541176455361, 0.12419974191912583, 0.12017577141523361, 0.13730745070746966, 0.12853095307946205, 0.1102917417883873, 0.10896501583712441, 0.304707793784993, 0.1546113828995398, 0.1632026947502579, 0.12441049489591803, 0.10133326785372836, 0.14355443763945783, 0.14866371133497783, 0.1261286541287388, 0.10524898488074541, 0.0958682925307325, 0.07194107145603214, 0.12744624699865068, 0.07674172028367009, 0.09475529153964349, 0.07755698010857616, 0.08352883466120277, 0.1409933886357716, 0.08648227368082319, 0.12616491504013538, 0.1503291076847485, 0.12406421133450099, 0.13031516091099807, 0.1780293227306434, 0.14401531219482422, 0.11194736723388944], [0.03568616509437561, 0.017504839625741755, 0.030028153343924453, 0.031781542114913464, 0.04322625996012773, 0.016139374413926686, 0.048814803295369656, 0.04849422603313412, 0.011814611032605171, 0.02326092173877571, 0.03134988867012518, 0.07904856292796986, 0.053384784143418074, 0.05030383821576834, 0.04900413492162313, 0.07990416165973459, 0.018941481464675496, 0.02203413042505937, 0.04599527994702969, 0.02715995698235929, 0.0317050610402865, 0.012553377908521464, 0.042244514783046076, 0.01699875428208283, 0.026276636702407683, 0.03707942818956716, 0.025156941963359714, 0.0473338429416929, 0.023900351087961878, 0.06500873701380831, 0.047045828575002294, 0.029224279336631298, 0.058740559433187754, 0.08261887170374393, 0.0276902965602598, 0.025420954850103174, 0.06822975631803274, 0.06880146278334515, 0.04647871918444123, 0.05047928023019007, 0.11008767238152878, 0.053019711947334666, 0.017320067754813602, 0.038257962092757225, 0.05513427473072495, 0.008707363391295075, 0.019834954324843626, 0.012074120143162352, 0.014123990549705923, 0.003561850412682231, 0.04559162285711084, 0.03836076693343265, 0.020740489841305783, 0.05995757305728538, 0.04503176700589912, 0.05243802762457302, 0.026928016749609793, 0.04334457950400455, 0.07400499856365578, 0.0527797717867153, 0.01542164381992604, 0.029865047096141746, 0.04827558508675013, 0.022816145426726768, 0.022099693871236274, 0.031216380119855915, 0.038072477760059495, 0.01034948429358857, 0.02629960172011384, 0.02840481429094715, 0.03282513236626983, 0.016325401574639336, 0.10793737455138139, 0.008831559896602162, 0.03545757682461824, 0.0499045407133443, 0.021051794922511493, 0.009196924710912364, 0.04043779655226639, 0.03177526905866606, 0.009580396232195199, 0.018705422524362803, 0.0099677998639111, 0.05202638417748468, 0.00775495043490082, 0.024319215843986188, 0.024059813602694442, 0.020525341653930287, 0.05939381902239152, 0.038227499263095, 0.029309499942298447, 0.10467343112187726, 0.05641856510192156, 0.09239588278744902, 0.023113640623965433, 0.058028328365513256, 0.06889325500066791, 0.05531705170869827, 0.019483293373403803, 0.005122159923692899, 0.04511253981451903, 0.030723902795995985, 0.02842507534660399, 0.07223645132035017, 0.03572482123438801, 0.07765433631305184, 0.016230379530627812, 0.016174666716584137, 0.022407438339931623, 0.028008717777473584, 0.04634354143802609, 0.07299691944250039, 0.014259486359411051, 0.028649383756731237, 0.013463982081572925, 0.05435095354914665, 0.008044699306732841, 0.02100207357268248, 0.023594420004103864, 0.015475796003426825, 0.026944345694833567, 0.059398541626121314, 0.058084205724298954, 0.040355758275836706, 0.07274018893284456, 0.040055041733597, 0.03610703322504248, 0.02027492830529809, 0.044218054240835566, 0.07020754340503897, 0.013186672452970274, 0.03520315333402582, 0.09359302212085042, 0.022319503594189882, 0.016528258100152016, 0.025134660569684844, 0.06300971178071839, 0.007876709303153413, 0.013708602437483413, 0.03449925806905542, 0.02769415912085346, 0.04693340550043753, 0.0606515176062073, 0.04703938588500023, 0.009670278373440462, 0.05225240079952138, 0.03121067024767399, 0.06641543510236911, 0.02159321667360408, 0.04181065270677209, 0.023345117756564702, 0.02360563788429967, 0.022441329467775564, 0.014403651302148188, 0.019177910206573348, 0.00923438323661685, 0.06590097663658005, 0.029474173605974232, 0.034754438126193624, 0.036154741022203646, 0.06048637575336865, 0.030130581597664526, 0.012017429390523051, 0.026467617168756466, 0.09397386347076722, 0.014560615111674582, 0.10706838153834854, 0.01799752051010728, 0.029923248437366316, 0.034171383162694316, 0.01888689162608768, 0.033717368596366475, 0.015952836655612503, 0.05054094549268484, 0.039010627062192986, 0.005669083745617951, 0.08943135650562388, 0.014770297699474862, 0.03396145121327468, 0.03894723832075085, 0.024824541228424226, 0.050181131942995956, 0.025637034326791763, 0.04851067711466125, 0.04216939417113151, 0.01819408362332199, 0.03834331501275301, 0.04368010489270091, 0.053945525482829125, 0.051463478311364136, 0.035267444527042766, 0.03626312342073236, 0.006916949508844742, 0.00821308116428554, 0.07009313561554466, 0.027721225882747343, 0.04704635104696665, 0.011165655051757182, 0.08306048943528108, 0.08418712898024491, 0.034231772779354026, 0.036454419405864816, 0.03798561849232231, 0.03053770600152867, 0.009570333557868642, 0.018928808126864687, 0.018854615411588123, 0.008144042770644384, 0.0325540474482945, 0.030523904599249363, 0.03369749430567026, 0.041521518757300716, 0.03849707104797874, 0.04918164646785174, 0.04793377307110599, 0.01702807717291372, 0.04665647500327655, 0.019262152025476098, 0.048182425621364794, 0.07302178775093385, 0.04681956768035889, 0.03500367760924356, 0.012860453172054673, 0.024196261905932, 0.018188826673265015, 0.025432344060391188, 0.10310547918613468, 0.09047334202166114, 0.03581942258668797, 0.05722760954605682, 0.05256762781313487, 0.01945223512926272, 0.0473880103922316, 0.04576686470370207, 0.031896560585924556, 0.05188613098913005, 0.022193085734865496, 0.010513855161012282, 0.08376033723886524, 0.07062402819948536, 0.05400497193581291, 0.031096394772508314, 0.018611832189240625, 0.030425659513899257, 0.0398045299973871, 0.027675609669781158, 0.027143054675044756, 0.03989812033250928, 0.03998781926929951, 0.02827299020386168, 0.015208286964999778, 0.08461200725287199, 0.043191993941685984, 0.03839266147198422, 0.022906229432140077, 0.0027173081970041884, 0.0320907742716372, 0.020502878752137934, 0.021792731414149915, 0.05383289884775877, 0.040684206544288566, 0.03928739471094949, 0.040644430821495395, 0.00619188352720812, 0.036883216218224595, 0.02162771169761462, 0.07143468755696501, 0.07522704691759177, 0.019687951409390995, 0.035646084030824046, 0.03940808912739158, 0.02148433046282402, 0.034442861630980454, 0.06795028809990201, 0.03364359148378883, 0.004242869717667678, 0.04396588348650506, 0.024566046527719924, 0.03716811950185469, 0.03426803708342569, 0.041795585836683, 0.02109481573903135, 0.0344581015274993, 0.020411307058696235, 0.042772496451756785, 0.03108185376705868, 0.034700172288077216, 0.07403755467385054, 0.03549655866143959, 0.023307499775130833, 0.03721119969018868, 0.048372205080730576, 0.024850686879030297, 0.03582982113584876, 0.017849272482895424, 0.05924408669982638, 0.028137347660958767, 0.06696928252599069, 0.05336982923160706, 0.01713591504708997, 0.0645968798281891, 0.01632543550139027, 0.02799331333621272, 0.041707301645406654, 0.07238403947225638, 0.008872364448117358, 0.010737090637641293, 0.016188814171722958, 0.09314324839838914, 0.05522092025993126, 0.01852881851872163, 0.04913016940866198, 0.04945244640111923, 0.03676664390202079, 0.047733615418629985, 0.07474636592503105, 0.0584452406370214, 0.03178500942885876, 0.1251792615013463, 0.04413739339049373, 0.023460938595235348, 0.019283003406599164, 0.01693697366863489, 0.05169581209442445, 0.030518632382154465, 0.028842718739594733, 0.031701831213597736, 0.033615822438150644, 0.004635792807675898, 0.07694940628217799, 0.01591429247387818, 0.05971229621874435, 0.07497752923518419, 0.004257223277818412, 0.013275572414776044, 0.039529068528541496, 0.02778269097741161, 0.04279435545738254, 0.03765500569716096, 0.03609586114596043, 0.08952213092041866, 0.00803486309346876, 0.04045704319807036, 0.04276741422446711, 0.05764220801315137, 0.02476333058439195, 0.025477237633562515, 0.04308773025072046, 0.010217517714149185, 0.010037672007456422, 0.027555614144408276, 0.023052782818142856, 0.2379251287451812, 0.08719193310077701, 0.13857247068413667, 0.1300440997417484, 0.1402904534978526, 0.10393809593681778, 0.08149696154786007, 0.13287576208157198, 0.06894103065133095, 0.13117102427142008, 0.14174159563013486, 0.14130285488707678, 0.12287465802260808, 0.19406250811048917, 0.08682751229831151, 0.15639422009033815, 0.08703753924263374, 0.1080549918115139, 0.15035027797733033, 0.07593199051916599, 0.1335973297911031, 0.07798678454543863, 0.1888231456811939, 0.1016440504629697, 0.0742862784702863, 0.10791447399450199, 0.1632926549230303, 0.15602592485291616, 0.0823480412364006, 0.11859152785369328, 0.17796072284025805, 0.19733615459075995, 0.17091207392513752, 0.2369224711188248, 0.1261438261717558, 0.07418922760656901, 0.1737165812935148, 0.11380815452763013, 0.12803198556814874, 0.20140295422502927, 0.1976251426552023, 0.10843237263283559, 0.11100843083113432, 0.19285730778106622, 0.12362760119140148, 0.08521932323596307, 0.11200822503971201, 0.07781578015003886, 0.09846722414450985, 0.10089465603232384, 0.18358979507216386, 0.13597269090158598, 0.10995523591658898, 0.16779805959335395, 0.16627739476306097, 0.1630191103156124, 0.131453701960189, 0.18431757816246577, 0.12298532708414964, 0.1205861901066133, 0.08974697028419801, 0.1260388432336705, 0.22382621600159577, 0.13340018822678498, 0.14238635317555495, 0.10820171143859625, 0.11110328324139118, 0.2091531404959304, 0.1289017317550523, 0.11114754408065762, 0.1315780502877065, 0.0719447491158332, 0.22243243721979006, 0.21039173831897123, 0.09507635395441737, 0.14494281528251513, 0.1413019320794514, 0.13335156440734863, 0.14122584116246018, 0.12707070500722953, 0.1673263284776892, 0.11471281812659331, 0.21392354023243698, 0.12119794370872633, 0.13361061550676823, 0.13083957348551067, 0.2043258659541607, 0.07823231922728674, 0.23037059126155718, 0.11494441569915839, 0.10772565126951252, 0.15330137605113642, 0.13799453526735306, 0.13109398340540274, 0.13710657720054897, 0.15691302796559675, 0.21467048515166554, 0.2177676446735859, 0.0880515148331012, 0.06045711732336453, 0.13108442963234015, 0.07551229625408139, 0.07652900634067399, 0.14523402894181864, 0.17651001497038774, 0.10211439736719642, 0.13229207268783025, 0.14930161567670958, 0.15862419828772545, 0.1697392397161041, 0.07953992406172411, 0.15115432840372833, 0.12318655342928, 0.06979081433798585, 0.08383290655910969, 0.16414625197649002, 0.0849103048177702, 0.19923644619328634, 0.09507826063781977, 0.12683879530855588, 0.16968681610056333, 0.23898890880601747, 0.13506052270531654, 0.12689579225012235, 0.15726659899311407, 0.15266873714114937, 0.1140240915119648, 0.14115527352052076, 0.27450283457125935, 0.16422170507056372, 0.14242839520531042, 0.08890297450125217, 0.250322913484914, 0.15861856644707067, 0.0679883946265493, 0.13382702746561595, 0.1252461379127843, 0.10122364373611552, 0.11293484603187867, 0.1650667390120881, 0.23301334945218904, 0.15220643766224384, 0.17089177215737955, 0.12281234136649541, 0.14229916142565863, 0.06975532695651054, 0.09920023195445538, 0.12523179368249007, 0.158486170694232, 0.17470383617494786, 0.14153787227613585, 0.15196550344782217, 0.08438082358666829, 0.11111450621059962, 0.05806023986744029, 0.15792556506182465, 0.19156482070684433, 0.09005609726799385, 0.08725344908556767, 0.11801956354507379, 0.11916917828576905, 0.16640175666127885, 0.10570103848086936, 0.1309870055743626, 0.2242415744279112, 0.09799475342567478, 0.15769290897463048, 0.13564950467220374, 0.16794079621987684, 0.18080330959388188, 0.08589837394122567, 0.16384249899004186, 0.10801969441984381, 0.11276628436254603, 0.11756003248904433, 0.11897950060665607], [0.04847933558214988, 0.022890521346458366, 0.014938906866258808, 0.020702856592833996, 0.025372303889266083, 0.02363727118686906, 0.05463195864909461, 0.05242886061647108, 0.05573571799322963, 0.09305903541722468, 0.020415632719440118, 0.0331704422299351, 0.048892363240676265, 0.044572839846036265, 0.011708943622319825, 0.02736032667702862, 0.035010585095733404, 0.03358286599229489, 0.04409924954442041, 0.02551751207959439, 0.018825197525854622, 0.04088355674009238, 0.10733702712293182, 0.0959794908495886, 0.02481494335058544, 0.022005056895847832, 0.020944701740518212, 0.03803588775917888, 0.020282943500205874, 0.028338463744148612, 0.027942435084176914, 0.026467062466378723, 0.0723003964605076, 0.04689865093678236, 0.032487958137478144, 0.04938772773104055, 0.09436977508344821, 0.03413902382765498, 0.060629295584346564, 0.006882282730657607, 0.015177771548873611, 0.013819001781355058, 0.04243063015331115, 0.0823822326159903, 0.05332648102194071, 0.020681774509804587, 0.03859689033457211, 0.03426933308531131, 0.07291856900389705, 0.03161895494642002, 0.04781700058707169, 0.05504045030102134, 0.026034503177340542, 0.05322219018957444, 0.013027413498743303, 0.005992942996921816, 0.04725495985309992, 0.03540519731385367, 0.032177619968674014, 0.02933619011725698, 0.020386269116508107, 0.02689461416697928, 0.04027780478021928, 0.06742936998073544, 0.009620482384759401, 0.005748065645873014, 0.02017390461904662, 0.04393586848995515, 0.008042984309473207, 0.05606665987787502, 0.03752858105248638, 0.028078861335026364, 0.005821143443297062, 0.022488404531031847, 0.044677992417876206, 0.04120408311220152, 0.03133229086441653, 0.0447416525733258, 0.031264841090887785, 0.05088858612413917, 0.05163997544773987, 0.029356671696794883, 0.05750362402094262, 0.04300371404471142, 0.07126197325331823, 0.03607892830457006, 0.03832506581342646, 0.03399216170821871, 0.08938102277794055, 0.007773448147677949, 0.03336162625678948, 0.014746543884809529, 0.042585529520043304, 0.013262222238284136, 0.026091793585302572, 0.11591305157967977, 0.013529414061589964, 0.03353726165369153, 0.03308710116626961, 0.03792651130684784, 0.03144642384722829, 0.015870401436196904, 0.008861835280965482, 0.026908651360177567, 0.05868033266493252, 0.007034639711491764, 0.004328129339098398, 0.0077709918509104425, 0.011160130928536611, 0.03463208129895585, 0.07771787433219807, 0.011738989152945578, 0.02123141840898565, 0.02713023205952985, 0.047933284525892565, 0.01937353694146233, 0.03210257738828659, 0.02451178408227861, 0.0491717262858791, 0.0341393630951643, 0.04119025796119656, 0.03825263559286084, 0.12583178148737975, 0.026904958433338573, 0.05428831798157521, 0.0340445785384093, 0.05246354054127421, 0.052256583967911344, 0.008202937065756746, 0.0727985565151487, 0.06426762071038995, 0.012361746896723551, 0.01487137736486537, 0.032551550439425876, 0.018384494120255113, 0.019628209793674092, 0.026816077131245817, 0.025241385646430508, 0.03711271033223186, 0.03636347874999046, 0.028942941754524196, 0.010232464144272464, 0.032239509147724936, 0.029876229353249073, 0.052583966936383925, 0.00995156167274607, 0.018041321641898582, 0.03764786411608968, 0.04800308881593602, 0.05627158084618194, 0.07000986579805613, 0.05846295040100813, 0.04583802606378283, 0.017110549711755345, 0.025226473143058162, 0.014181591387438987, 0.028165537398308516, 0.022701858077198267, 0.03426983520122511, 0.009083862117092525, 0.05382339257214751, 0.04862106119149497, 0.06827223261020013, 0.01764957114521946, 0.0514380468188652, 0.0443896794957774, 0.018557503586634994, 0.03961500498865332, 0.07380123449755566, 0.02467442722991109, 0.008591639243864586, 0.031417609857661385, 0.06709447902228151, 0.0400942542723247, 0.026504582060234885, 0.02870475560692804, 0.025894258470673646, 0.024488576488303285, 0.04531902141336884, 0.006958012751835797, 0.032763538349952014, 0.04528831091842481, 0.05139453915346946, 0.012217834708280861, 0.030739488745374337, 0.08715990624789681, 0.090341075190476, 0.06961396097072534, 0.07156574659581695, 0.018949620492224182, 0.026770126739782945, 0.03994366360296096, 0.0017704592277628503, 0.007399322598108223, 0.06733362868960414, 0.022659629450312684, 0.029677971598825285, 0.007570838439278305, 0.04971471714920231, 0.036686166256133995, 0.030482476643685783, 0.03964099966521774, 0.013312701002827712, 0.07339349601949964, 0.04725273086556366, 0.03594322469351547, 0.03033382658447538, 0.05430666217580438, 0.031867522679801495, 0.015289868926629424, 0.03327653457277587, 0.034473019119884284, 0.028719255900276557, 0.04155007490356054, 0.0270153170651091, 0.05761493769075189, 0.031532322987914085, 0.07265291575874601, 0.019182412286422083, 0.06377805090908494, 0.005751714892020183, 0.06692326428102595, 0.04554595405768071, 0.04493055332984243, 0.017335707986993448, 0.01410917388940496, 0.04210264668134706, 0.0217250645094152, 0.004980335502685713, 0.03630357089319399, 0.025212697185842053, 0.018177635934469954, 0.011743895809299179, 0.06118269517485585, 0.041495473190609894, 0.081421895218747, 0.09749000479600259, 0.018145722736205374, 0.0352177757636777, 0.026446920154350143, 0.0241868489288858, 0.06576599566532032, 0.05052129851121988, 0.06757122451173407, 0.038358717757676325, 0.06114559966538634, 0.007907653892678874, 0.020704393474651233, 0.02872204128652811, 0.010108831671199628, 0.03957174498853939, 0.03570021755461182, 0.056079840420612266, 0.04519061544643981, 0.01739993641552116, 0.019302713152553354, 0.002994522194577647, 0.042859481248472414, 0.1493665107658931, 0.04970404040068388, 0.05513560805203659, 0.03163028648123145, 0.011888891109265387, 0.03195489084880267, 0.062444811021643024, 0.04924296907016209, 0.04980228209335889, 0.06743255909532309, 0.02355087671561965, 0.061847876624337265, 0.03492605659578528, 0.10405101094927106, 0.022469559917226434, 0.024254252901300788, 0.04023799513067518, 0.035814896758113585, 0.04513316388641085, 0.006872987649070897, 0.06123610945152385, 0.023351345011698346, 0.05985714987452541, 0.015729542655338134, 0.024137400689401796, 0.023353097328384007, 0.011629706847348383, 0.023938230305377926, 0.039462524599262645, 0.027075408126360605, 0.017095226694696715, 0.028323591952877383, 0.01978516172883766, 0.039771855143564086, 0.012579820418198193, 0.004375131459840174, 0.02237059728109411, 0.01837847212196461, 0.02202638834049659, 0.03801229848925557, 0.019784491675506746, 0.02234837525923337, 0.0631271390510457, 0.039176691722656996, 0.0357427990197071, 0.03019270147862179, 0.01736322936734983, 0.03222814368616257, 0.026807793915005665, 0.05263366284114974, 0.027257286045434218, 0.07224340630429131, 0.03376967007560389, 0.02110581479168364, 0.03287691476621798, 0.031177137047052383, 0.048746593562620025, 0.04828899972406881, 0.02873957123873489, 0.013237729668617249, 0.06403453036078385, 0.032108853837209086, 0.02834398701920041, 0.016264625193018998, 0.05985145018036876, 0.028387837344780564, 0.024758107561085905, 0.11731790405298982, 0.07606794179550239, 0.0486328439520938, 0.03553697559982538, 0.031269706186971495, 0.03143472929618188, 0.048385090460734706, 0.03556386594261442, 0.02878988461036767, 0.009267442310894174, 0.02818441593886486, 0.05240958682926638, 0.030155368481895754, 0.05826628381120307, 0.011008032215093928, 0.047208419136170826, 0.043318530544638634, 0.05627058000702943, 0.034130769449153116, 0.045810830380235396, 0.025821422825434377, 0.03711508181212204, 0.02721394462111805, 0.02335325169510075, 0.030160376070333377, 0.04234936540680272, 0.044660034988607676, 0.09310141671448946, 0.09309178151722465, 0.08825858336474214, 0.0978941402531096, 0.09728670213371515, 0.0852385393476912, 0.10544825704502207, 0.155873390180724, 0.10614950263074466, 0.18122059505965027, 0.16668314513351234, 0.14145506386245998, 0.16623096939708504, 0.14209850504994392, 0.10006870249552385, 0.1461398731917143, 0.07693068550101348, 0.07305405887642077, 0.1074252909581576, 0.12897738840963158, 0.10986497718840837, 0.11287249544901506, 0.13023468665778637, 0.174365708604455, 0.11680274669613157, 0.09781297389417887, 0.07276049748595272, 0.10411019955894776, 0.09455546976200171, 0.09599671885371208, 0.12516768569392817, 0.2656216797019754, 0.15394769422709942, 0.17932384540992125, 0.12519102729856968, 0.1114504285422819, 0.22254149136798723, 0.15352261917931692, 0.2023578972688743, 0.09212366132331745, 0.16882008260914258, 0.16732768554772648, 0.11204961567584958, 0.1472615051482405, 0.061112907848187854, 0.16064164574657167, 0.15091845606054577, 0.11113129995231118, 0.17156470247677394, 0.08673746391598668, 0.10190015672040836, 0.1369485328240054, 0.10137257538735867, 0.13395128079823085, 0.09730652892696005, 0.11891926026770047, 0.11977668425866536, 0.08994821698537894, 0.1259519907512835, 0.1559281615274293, 0.1541436958525862, 0.13787781367344515, 0.1448327704731907, 0.2235352737562997, 0.13461796859545366, 0.13824833450572832, 0.17619687105928147, 0.1330671360982316, 0.2165902778506279, 0.10850920315299716, 0.15322780928441457, 0.1474407333880663, 0.07862923507179533, 0.07658446979309831, 0.09854706057480403, 0.11650067647652966, 0.17788179564688886, 0.13384612144104072, 0.10154298267194203, 0.2205292007752827, 0.16671515841569218, 0.07590273208916187, 0.18586011896175997, 0.15137345450265066, 0.12935990574104445, 0.1737202453826155, 0.07937537931970187, 0.1553555458251919, 0.180920112611992, 0.11902409392808165, 0.06805430751826082, 0.15415646588163717, 0.2563299025808062, 0.15257047169974872, 0.10156596465302364, 0.12763532756694726, 0.08902036784482853, 0.12586739100515842, 0.10751223843544722, 0.10699719642954213, 0.12271028969969068, 0.09667904688311474, 0.06986302403467042, 0.1772321933614356, 0.17829214648476668, 0.08620912262371608, 0.1000230981569205, 0.07971571891435555, 0.0661093954529081, 0.09998966673655169, 0.15055740757712296, 0.11639973760715552, 0.12496953989778246, 0.11618327136550631, 0.11461795893098627, 0.1460128514362233, 0.15733281044023378, 0.10840729397854634, 0.12537032339189733, 0.1287887149623462, 0.09451665077358484, 0.23525365495256015, 0.2212231656802552, 0.13526500601853642, 0.27194106632045334, 0.15715443715453148, 0.12491748269115176, 0.18494427310568945, 0.09066688735038042, 0.19328367204538413, 0.06305020675063133, 0.12443703918584756, 0.12695030575352056, 0.21647784459803784, 0.09572903000350509, 0.11305342002638749, 0.14399346336722374, 0.10869831764804465, 0.25362235786659376, 0.11698167638054915, 0.11492017842829227, 0.08595210712935243, 0.17246088438800403, 0.08871970219271523, 0.1087732007727027, 0.07811067825449364, 0.13276122537042412, 0.1725182748798813, 0.15795856900513172, 0.19318499948297227, 0.2023424402411495, 0.10483015914048467, 0.09939024211572749, 0.13315335075770104, 0.09642455553902046, 0.13209512111331734, 0.13463810751480715, 0.11204952746629715, 0.1276167764195374, 0.1188713014125824, 0.09261263401380607, 0.10733988375536033, 0.1446651994649853, 0.11617846733757428, 0.12987817078828812, 0.09568280141268458, 0.18451416332806858, 0.07446528957890612, 0.14278944368873323, 0.08548222841428858, 0.10592220697019782, 0.13002026959189347, 0.23103186434933118, 0.1493876539170742, 0.09176782398883786, 0.12704622346375669], [0.02713988591650767, 0.012323255301453173, 0.05987186051372971, 0.054443129138754945, 0.027751195078183497, 0.012289825577421911, 0.05139419988596013, 0.04675542576504605, 0.007088520056900701, 0.017083876500172273, 0.020641735854691694, 0.024541047601295368, 0.01641302928328514, 0.007317279232665896, 0.010826168714889457, 0.10438332347465412, 0.030324703681149652, 0.01445429545960256, 0.009879316352973027, 0.04657364623355014, 0.019729336956515908, 0.01742291500392769, 0.02278589972827051, 0.022201469035020897, 0.02170969738758036, 0.01310017959414316, 0.03169544280639716, 0.024987506680190563, 0.039039342664182186, 0.010237040014804473, 0.005610158916429749, 0.060548855257885795, 0.05004640542236822, 0.03276223895539131, 0.04959755790020738, 0.02547456250925149, 0.03870887575404985, 0.09084290611956801, 0.05789152892040355, 0.038367626922471185, 0.04989723289119346, 0.04326042080564158, 0.0497440909301596, 0.08321427939725773, 0.05900246716503586, 0.020304213876702955, 0.03788051002525857, 0.022563072220821465, 0.023649915686941574, 0.02507117174432746, 0.02541792349490736, 0.056319665230278454, 0.0422854677640966, 0.026471969970901097, 0.01760350031379078, 0.026600715205339447, 0.04429064052445548, 0.02381028913493667, 0.0711325698399118, 0.015846544144941226, 0.023576026616085852, 0.04437155243275421, 0.03861827436568482, 0.02989482121276004, 0.03386682611224907, 0.012928467825986445, 0.06370737470154252, 0.020720403508416245, 0.006342785474511662, 0.013472514659432428, 0.02743331159997199, 0.021889882361782447, 0.026842746950153793, 0.029715111213071004, 0.07237245009413787, 0.04468793295589941, 0.010526276592697417, 0.02260163675860635, 0.07769658190331288, 0.05461724122454013, 0.02478182066365012, 0.02481070250671889, 0.041415558728788576, 0.07005326489784888, 0.057662686200014183, 0.027695283792646866, 0.05342493984582169, 0.03775611759296485, 0.028560699229793887, 0.018309429487479583, 0.046440996030079465, 0.028218044134389077, 0.010571261768096259, 0.041113637786890776, 0.04814458711604987, 0.05592664756945201, 0.05192678541477237, 0.05751735756972006, 0.063927525388343, 0.02881141791918448, 0.04925928444468549, 0.06070252986890929, 0.043291073625109026, 0.013191373004311962, 0.0446978768865977, 0.049863458810640235, 0.021214899473956654, 0.058461349058364115, 0.0032449251531423734, 0.01773630827665329, 0.10165579590414252, 0.030230933534247533, 0.04522493574768305, 0.023955103774954165, 0.03431897131460054, 0.018914309529853717, 0.03913403222603457, 0.02848055406606623, 0.09454696093286787, 0.020903166915689195, 0.0613927153338279, 0.04141445950205837, 0.04873327052752886, 0.05404502246528864, 0.0061053508044486594, 0.01890475914946624, 0.018935015025947775, 0.03472947482285755, 0.02748180989042989, 0.03558130429259368, 0.010683315889244633, 0.036129621655813286, 0.04711161593773535, 0.009102061274461448, 0.02274434794006603, 0.013588884263299406, 0.031945404929241965, 0.027022940406043614, 0.07330836701606001, 0.0667854877454894, 0.0326692151970097, 0.026720481725143533, 0.04834850045985409, 0.07664031322513308, 0.031136407982558012, 0.011292337539738842, 0.014868123789450951, 0.045298692504210133, 0.03330655635467597, 0.028262013203597496, 0.04225266059594495, 0.04762593191117048, 0.015583640662953258, 0.050112640618213584, 0.05366588084559355, 0.05691171756812504, 0.020212021323719194, 0.04180009470188192, 0.028997210985315696, 0.1456642879971436, 0.03150492713653615, 0.11393787685249533, 0.02844876130776746, 0.04877568914421967, 0.047607865916298966, 0.03129460842215589, 0.045791878897164545, 0.08101027552038431, 0.07512768903481108, 0.05900399386882782, 0.025415948958003094, 0.025497045767094408, 0.061409325871084414, 0.03188994147681764, 0.015776105424655334, 0.030950177261339765, 0.02064463489555887, 0.03881598589941859, 0.060809419490396976, 0.01661177388658481, 0.013902779651938804, 0.07259748623307262, 0.04981549656284707, 0.03744963350306664, 0.025398997456899712, 0.008610762905196419, 0.027722258952313235, 0.015379337161513311, 0.019695756258442998, 0.0040448223090996695, 0.04825457085722259, 0.04990199959969946, 0.04731136307652507, 0.008363081508183053, 0.02777291159145534, 0.00976675926774208, 0.006393704862732972, 0.020216950880629674, 0.06316477738853012, 0.052002835619662485, 0.011776515532151928, 0.008027990381898624, 0.03652886826811092, 0.08013029702539955, 0.01517919816875032, 0.01046017201484314, 0.021370029542595148, 0.02966107607686094, 0.05060193222016096, 0.018466659622000794, 0.11951734817453794, 0.013913620945199259, 0.016491086255492907, 0.06278673160289015, 0.04556072237236159, 0.026847605260887315, 0.01251677009609661, 0.037731944782925506, 0.017274934998048202, 0.03499319763588054, 0.023319828756419674, 0.056260120389716964, 0.04072382281135235, 0.10290436819195747, 0.01961303435798202, 0.043240129215908904, 0.044738066515752246, 0.013463982929741698, 0.005839673810571964, 0.03296528038169656, 0.035441237701369185, 0.023283852829730937, 0.02885738866669791, 0.02190260150070701, 0.05548735721302884, 0.020907009120232294, 0.01977782676528607, 0.03255125866936786, 0.034430237486958504, 0.04604715055653027, 0.03597258151109729, 0.029729492762791257, 0.033122354453163486, 0.10493595632059233, 0.033575412285115035, 0.029019656923732588, 0.03727896158982601, 0.007670637369821114, 0.01656179638978626, 0.029455937977348055, 0.02030210193645741, 0.03140725202060171, 0.026027492214260355, 0.07549459327544485, 0.06042558580104794, 0.008349369163624942, 0.058410506429416795, 0.04912331959764872, 0.012144788717185813, 0.043750492722860405, 0.0751814968617899, 0.04139875480905175, 0.015497819553794605, 0.036187704253409586, 0.018794968790773834, 0.028675602349851812, 0.06839079981935875, 0.05107950891501137, 0.09948671622467892, 0.033183076551982334, 0.03891651086243136, 0.034065684370164356, 0.04672475937487824, 0.043419387989810536, 0.024640364771974937, 0.028348631591403058, 0.02549359032751194, 0.030250370169856718, 0.03679895234693374, 0.059843782734658034, 0.019945674276511585, 0.03399037716111966, 0.03667936733524714, 0.045987171453556845, 0.02261302257621927, 0.03515566945342081, 0.012085644212285323, 0.06967498162495238, 0.02644429761650307, 0.030881624868405715, 0.06287934484758548, 0.043582551913069825, 0.01217041104765875, 0.01421402536133038, 0.05061517043837479, 0.026421558211690614, 0.0026593201702261077, 0.036527731721954684, 0.06432656504745994, 0.022228362770485025, 0.02384831423738173, 0.014849391133923615, 0.0350345339892166, 0.04761028150096536, 0.0020061178324145396, 0.051034325268119574, 0.03251350837360535, 0.025741722102143934, 0.02963875906009759, 0.059453543674732955, 0.030116491818002293, 0.01681335306992488, 0.034642737691423724, 0.04362268725942288, 0.025641539799315587, 0.02034018132170396, 0.032215020818901915, 0.03503327191408191, 0.03166457285572376, 0.06282889576894896, 0.02227197221613356, 0.06704369067613568, 0.05044167581945658, 0.03491354101736631, 0.015752068321619715, 0.03661881147750786, 0.1057370144075581, 0.025212264619767666, 0.04898761937926922, 0.03425178277705397, 0.030913478694856167, 0.03590487389426146, 0.018056079778554182, 0.037890375924429724, 0.015279268513300588, 0.09214962885848113, 0.04924789184172239, 0.038973752076604536, 0.05846069087939603, 0.0037238222347306354, 0.03225728337253843, 0.026225653277443986, 0.03788676272545542, 0.03780326220606055, 0.031036191752978733, 0.014473333455888289, 0.03765813374359693, 0.0884809053636023, 0.03287508272166763, 0.04506932052650622, 0.03603748677830611, 0.04518692760861345, 0.09918264432677201, 0.07657617130982024, 0.1654238791338035, 0.1790808213076421, 0.08828961955649511, 0.1283575195286955, 0.18093037206147397, 0.18519545319889272, 0.20593930009220326, 0.13092657524560178, 0.12606498040258884, 0.1091658825586949, 0.04751073702105454, 0.09220389130392245, 0.1116999394393393, 0.12418880393462521, 0.08446306881627866, 0.14403927805168287, 0.12152047854449068, 0.23408052218811853, 0.1629362747605358, 0.08226851693221501, 0.11566588841378689, 0.13284701933818205, 0.1123284799978137, 0.11145984660834074, 0.09286126281533923, 0.11241055559366941, 0.15899304992386273, 0.13163896916168077, 0.08675057999789715, 0.136633163318038, 0.1410821003041097, 0.09929745245192732, 0.23011570636715206, 0.10296815048371043, 0.1690424656761544, 0.1345081137759345, 0.23553673976234027, 0.13445693866482802, 0.20374737413866179, 0.08675224919404302, 0.1105468234579478, 0.20366114590849194, 0.1379020916564124, 0.09969933517277241, 0.09258865458624703, 0.20236772245594434, 0.13685105448322638, 0.12935393463288034, 0.13717547564634255, 0.20033578148909978, 0.06970329010593039, 0.11246080789715052, 0.09534021586711917, 0.10955485275813512, 0.10480020860476152, 0.1528344896755048, 0.16328500104801996, 0.14017439686826297, 0.0935029669531754, 0.10986903482781989, 0.17527609903897556, 0.11380175594240427, 0.1590770118470703, 0.15327641953315052, 0.1271515456693513, 0.159512319202934, 0.22680792957544327, 0.17600971753043787, 0.13293558172881603, 0.11147336981126241, 0.07452219152556998, 0.11713590739028794, 0.15846124131764683, 0.12791712316019194, 0.10982239911598818, 0.1271988802722522, 0.14934622256883553, 0.16913131305149623, 0.13369540524269852, 0.10575836111924478, 0.13474253405417713, 0.18405649145799025, 0.14657037651964597, 0.14377513793962343, 0.15052472933062486, 0.12904123855488642, 0.044413954086069546, 0.09931400192103215, 0.22691789296056541, 0.21365641456629547, 0.14607085260961736, 0.12991756653147085, 0.15854822950703756, 0.13976062621389115, 0.13655249907502107, 0.11566696049911634, 0.20998883779559815, 0.14881897371794495, 0.13011591588812216, 0.12119532456355435, 0.18161588242011412, 0.08890161743121487, 0.07976048186953578, 0.11105074427489724, 0.08247373306325503, 0.12178389940943037, 0.08009440930826323, 0.07460585489336934, 0.21040900024984563, 0.22421490800167831, 0.10560271197131701, 0.094557736068964, 0.13435982673295907, 0.11634673045149871, 0.13094895333051682, 0.1455838680267334, 0.14953486887472017, 0.09764350977327142, 0.17134065021361622, 0.17102818483752863, 0.14753202348947525, 0.1978766077331134, 0.09522707015275955, 0.1461032187300069, 0.08551887609064579, 0.1905776879617146, 0.1374276599713734, 0.16328947937914304, 0.0971263846648591, 0.10277682396450213, 0.13408108454729828, 0.1265225572777646, 0.1122475036286882, 0.07392366935632058, 0.14974406122096948, 0.12497475104672567, 0.14753574186137744, 0.0819778935983777, 0.08493809082678386, 0.07242048358810799, 0.11293058483196156, 0.09929728281817266, 0.17104273262832845, 0.11096449568867683, 0.20927757024765015, 0.13998418993183545, 0.11367475454296384, 0.08664078624652964, 0.18521720703159059, 0.13915286239768776, 0.14463607674198492, 0.1124692488727825, 0.1156400769416775, 0.15302825213543006, 0.06246383035821574, 0.2263099934373583, 0.15357215223567827, 0.19465163935508045, 0.14745057214583668, 0.22990701613681658, 0.13253113414560044, 0.10019286761858634, 0.12116576757814203, 0.242445529039417, 0.05368077808192798, 0.1282682514616421, 0.1658526182706867, 0.08182584747139897, 0.14627999067306519, 0.16904705257288047, 0.14193599591297762, 0.10988633747079543, 0.07333587482571602, 0.12104766177279608], [0.017034144972317984, 0.024921849935448596, 0.023702033961723958, 0.03232364749003734, 0.022441083498831307, 0.049329485677714856, 0.042539487526352913, 0.01701492377157722, 0.02373658835754863, 0.014475516642310789, 0.03243787207507661, 0.06881347285317523, 0.04978964777131166, 0.061881396254258494, 0.013543654815293849, 0.02175244170108012, 0.02139455858351929, 0.04265212433944855, 0.04926015975485955, 0.013919774409649628, 0.03788472033504929, 0.04275297499927027, 0.03678613821310656, 0.014426982728764415, 0.0251463059269424, 0.05655673858044403, 0.045164301858416626, 0.009658939205110073, 0.010838797099755278, 0.043946358641343455, 0.03842492920479604, 0.03062153561040759, 0.040948862342962196, 0.041765726903187375, 0.10992662209485259, 0.05055377658988748, 0.0016340267216686957, 0.021050417496423637, 0.09961791775588479, 0.04168508301622101, 0.06789437681436539, 0.007958050384851438, 0.06245189492723771, 0.03924041294625827, 0.06439853047153779, 0.04250973715846028, 0.06551672904086964, 0.025946215593389103, 0.0440359015150794, 0.03666097903624177, 0.025461317505687475, 0.05328942622457232, 0.02033264788665942, 0.00564111368398049, 0.035439286913190565, 0.018495551643094847, 0.0456786449732525, 0.03861958393827081, 0.042704941505300145, 0.033306305296719074, 0.02901065954938531, 0.045812160308871946, 0.052409973594227006, 0.05654243506225092, 0.0874609247382198, 0.046597147293921025, 0.061822730116546154, 0.017619021802342365, 0.010882684744761457, 0.03162371826225093, 0.07034186619733061, 0.035538383559989076, 0.04296004353091121, 0.05168663490829723, 0.019175910224605883, 0.04490190218868, 0.029464056648846184, 0.013668211792329592, 0.015096491535327263, 0.03178413751135979, 0.024795192892530134, 0.04361175945294755, 0.028842179304254905, 0.03085560305044055, 0.0286331871258361, 0.023624972739656056, 0.03271025978028774, 0.1332637755466359, 0.06950112738247428, 0.016774566311921393, 0.04686658676447613, 0.030652157895799195, 0.030328798639987196, 0.017482313959460174, 0.004451130350519503, 0.05675999713795526, 0.043955824204853604, 0.051154466678521464, 0.008119266064438437, 0.02152471517079643, 0.04658346463526998, 0.012950221658684313, 0.05733221250453165, 0.0047370806985002544, 0.014392134866544178, 0.053798693897468705, 0.03548867408452289, 0.030382267199456692, 0.03453918646222778, 0.008141639908509595, 0.08454433695546218, 0.00901085090091718, 0.1699629934238536, 0.07196545121925217, 0.03387070393988064, 0.04252296180597373, 0.030329551813857894, 0.02135462679767183, 0.047407918609678745, 0.015549764802147235, 0.06109131007854428, 0.01476530877075025, 0.015377019964424627, 0.026923256826453974, 0.031802291715783734, 0.026842875871807337, 0.06811550459159271, 0.02245053888431617, 0.03879517523039665, 0.01819496911152133, 0.01451962481119803, 0.04500265446092401, 0.03152888281536954, 0.015564517849790198, 0.023463564525757517, 0.024757596963484372, 0.033236677425780466, 0.030540630487459045, 0.04736548302961247, 0.0369330139032432, 0.03688872931525111, 0.026716429174744656, 0.04659397514270885, 0.04385800659656525, 0.00551284257588642, 0.032721618456499915, 0.03636687821043389, 0.046958484154726775, 0.005355772321178977, 0.04658467921295336, 0.046679110931498666, 0.016952525691262314, 0.010241742262483707, 0.07906161115637847, 0.019846915200884854, 0.029328556598297188, 0.03125309564971498, 0.030917692397321974, 0.05154129270730274, 0.04680397494563034, 0.034851458455835066, 0.023467630646856766, 0.03411336502592478, 0.05037903346653495, 0.032701754343828986, 0.030799226968416145, 0.06664711409913641, 0.016470455398250903, 0.032019745225885084, 0.023999015168685998, 0.03578129909666521, 0.03669699228235653, 0.057722627983561585, 0.01208444744614618, 0.04157967599374907, 0.0321228554073189, 0.038459687161126306, 0.053648072694029124, 0.06879115583641188, 0.060356619501752515, 0.06859141548297235, 0.017271052081403986, 0.03483332800013678, 0.026633052487990687, 0.020735548410032476, 0.019050783278154473, 0.01592383437257792, 0.040732711620096645, 0.03953240692083325, 0.012653988536580332, 0.033457048636462004, 0.05242111513923321, 0.018548129625352364, 0.10436558656926666, 0.0474601522354143, 0.00911472867509084, 0.013090714878801788, 0.05049284753788795, 0.02497457210639758, 0.06518796525363411, 0.0272760967324887, 0.03843852026121957, 0.003444975512268554, 0.01666759356989392, 0.005992643593344837, 0.053626451175659895, 0.016045526235497425, 0.03960222817425217, 0.054545123130083084, 0.03937411827168294, 0.01841996453835496, 0.04578071699610778, 0.014447535554479276, 0.010008934353079115, 0.014066249764125262, 0.027743490313046744, 0.04930957067491753, 0.016215061602581824, 0.03293739598510521, 0.03999330522492528, 0.02434931735375098, 0.021330827181892734, 0.00978215183464012, 0.07164216999496732, 0.04040667215096099, 0.031788690481334925, 0.02377604686522058, 0.07823560333677701, 0.0188730003179184, 0.03064107063359448, 0.05869593897036143, 0.026858529674687555, 0.053540541856948815, 0.017589408837791, 0.04280932733256902, 0.016093030472153, 0.025960648033235754, 0.06031319326055901, 0.0317437680704253, 0.04254359944856592, 0.030001646373420954, 0.039005500730127096, 0.020396255455645065, 0.05270638143909829, 0.041563177414770634, 0.036079291320805035, 0.09074054232665471, 0.03273844951763749, 0.05292481543230159, 0.05460778244638017, 0.017409527508009757, 0.07253601774573326, 0.06020318237798555, 0.019498707992689948, 0.028267151410026208, 0.026596581230738332, 0.023857659360926067, 0.06506261269428901, 0.00951423991604575, 0.03745627296822412, 0.027112483279779553, 0.14630435008023465, 0.020332518965005875, 0.03768246940204075, 0.06720784865319729, 0.051430586326335154, 0.009018546336197426, 0.05061037658846804, 0.017071069151695286, 0.03172952901305897, 0.05852830010865416, 0.07605758056576763, 0.025510093995503018, 0.018734609708189964, 0.0012393550257131989, 0.03291841396795852, 0.006115671746166689, 0.008580212714150548, 0.041863378270396163, 0.017859923786350658, 0.007287936833953219, 0.016283839608409574, 0.05620351360578622, 0.028356017445081046, 0.03625616843679121, 0.0378523847487356, 0.02655132973034467, 0.02180090606478708, 0.06602167444569723, 0.0451321834033089, 0.03112606710887381, 0.06937433632888965, 0.032050750883562226, 0.01617229014768132, 0.015863989280270677, 0.09381237892167908, 0.027015145735016892, 0.05574182141572237, 0.04572380147874355, 0.03462194059310215, 0.09738154097327165, 0.04673383478075266, 0.016180641217423335, 0.029475567995437553, 0.06180069129914045, 0.013735762497942363, 0.004196375225936728, 0.06767831090837717, 0.023635359414454018, 0.05270897683554462, 0.05929879019302981, 0.0615349430590868, 0.054079437761434486, 0.0524533523379692, 0.04774195122133408, 0.03299876608486686, 0.08380265068262815, 0.011757315535630499, 0.07005816392068352, 0.018948470375367572, 0.004986167087086609, 0.013064899165848536, 0.018912954156153967, 0.013058972162460642, 0.02056974159287555, 0.047076209980462275, 0.03479725029319525, 0.021722988192258135, 0.10161937892969165, 0.015700589566092406, 0.06739355690245118, 0.0315845769697002, 0.07242191529699735, 0.015290457555758101, 0.017911017473254884, 0.049688203393348625, 0.06897235182779175, 0.0430686871654221, 0.046810454955058436, 0.015741630756695355, 0.018721398631376878, 0.02858060405456594, 0.03393536154180765, 0.012169026836220707, 0.036642879114619324, 0.028478362397955995, 0.023453093034082224, 0.05026415748787778, 0.028097176691517234, 0.030715271830558777, 0.028566422672676187, 0.06718762830964156, 0.14113474105085644, 0.13308924276913914, 0.12499661344502654, 0.12771486544183322, 0.10126761280532394, 0.2173481471836567, 0.10769751920763936, 0.12286366575530597, 0.084633584666465, 0.08797084380473409, 0.08598441218159028, 0.16649753866451128, 0.08609714398958854, 0.14576958306133747, 0.1450376609074218, 0.08476861313517604, 0.18635553094957555, 0.21421612453247818, 0.15530648774334363, 0.07976947245853287, 0.1439039103154625, 0.11931134494287626, 0.13184757796781404, 0.18000987145517552, 0.10984800702759198, 0.16670890232282026, 0.15869001618453435, 0.11686389627201216, 0.12738314324191638, 0.11570881253906659, 0.16128214209207467, 0.11158154186393533, 0.17360759499881948, 0.20237077586352825, 0.1612513501729284, 0.16185577559684003, 0.07760912552475929, 0.10381299443542957, 0.15042654531342642, 0.11056106590798923, 0.11609598462070737, 0.08119928144982883, 0.11875088858817305, 0.20800151729157992, 0.09493295236357621, 0.10470546476010766, 0.16080982743629388, 0.19198936649731227, 0.1128931093428816, 0.10608012242508785, 0.1628487573138305, 0.13977996446192265, 0.1114144322595426, 0.1708046482609851, 0.1557005401700735, 0.07536843325942755, 0.12214699706860951, 0.16005456367773668, 0.24609482607671193, 0.1864279034946646, 0.07638415947024312, 0.13858779200485774, 0.11879662184842996, 0.11599043171320643, 0.22014475640441689, 0.19005065624203, 0.15912072307297162, 0.14337615934865816, 0.09952421206980944, 0.1322928462177515, 0.17093086934515409, 0.15666286567492144, 0.1393996048718691, 0.21254890970885754, 0.1300687441336257, 0.185348137148789, 0.15645963086613587, 0.1275481900998524, 0.09734936484268733, 0.15301561781338283, 0.1307144516280719, 0.13345513599259512, 0.11005880750183548, 0.1337938742446048, 0.1649868618696928, 0.11159743993942227, 0.0976649514798607, 0.195497188983219, 0.1459980458021164, 0.10519584201808486, 0.21671428691063607, 0.15378229453095368, 0.1272795716566699, 0.11987341621092387, 0.15605820954910346, 0.15979213347392424, 0.15512738163982118, 0.14286752949867929, 0.10943379532545805, 0.10318128511841808, 0.1581939799445016, 0.12065447787089006, 0.1807088168071849, 0.1638735080403941, 0.09267741375203643, 0.0958209986399327, 0.13024911231228284, 0.07216889637389354, 0.15941896635506833, 0.13679660883333, 0.2030174197363002, 0.21558221908552305, 0.271165093673127, 0.20437454405639852, 0.12958371373159544, 0.35804336039083345, 0.10669066823486771, 0.14450938068330288, 0.11127683892846107, 0.15640006906219892, 0.17134956616376126, 0.07516900503209659, 0.11522410783384528, 0.10509087943605014, 0.13936919293233327, 0.11175010353326797, 0.11768383798854691, 0.12768226861953735, 0.19177570939064026, 0.09769072902521916, 0.15603413512664183, 0.18548805106963429, 0.13536940541650566, 0.0978023616064872, 0.11709754302033357, 0.17617187382919447, 0.09770488326570817, 0.19362454089735234, 0.1435814161917993, 0.19042619823345117, 0.12632438434021814, 0.042061384966863055, 0.13860023633709975, 0.08684139512479305, 0.10548976981746298, 0.13363862543233804, 0.17227297089993954, 0.11056696916265146, 0.0807992782709854, 0.16329588474971907, 0.12511172012559005, 0.1680294128933123, 0.20478785330695765, 0.17032428617988313, 0.19062024567808422, 0.1352506075054407, 0.11411885571266923, 0.08366264855223042, 0.12136229846094336, 0.13271865408335412, 0.11322814957903964, 0.11877066109861646, 0.08187159430235624, 0.10901264899543353, 0.05085844220593572, 0.11799300568444387, 0.1413273907133511, 0.09859403555414506, 0.159838735259005, 0.11600021618817534, 0.07840271972651992, 0.11156180328024284, 0.11918781085738114, 0.1373404546507767, 0.07136101222464017, 0.16286600567400455], [0.028478481141584258, 0.029991475133491412, 0.038232893616493256, 0.06808301633489983, 0.02284012994329844, 0.06994182909173624, 0.03418799369995083, 0.0025839851836540867, 0.08782532518463475, 0.0972154423860567, 0.08712518561099257, 0.048955372002507956, 0.057347574537353854, 0.0196968079877219, 0.021002699521237185, 0.03837164045710649, 0.04436999519488641, 0.003316778618942148, 0.03985762536259634, 0.024162443720602562, 0.07137744634279183, 0.02066437856826399, 0.01751694129779935, 0.04145639296621084, 0.07006845729691641, 0.08932365264211382, 0.028087538101577332, 0.05665963163067188, 0.0571902154811791, 0.11783388922257082, 0.0571100397833756, 0.03466370442349996, 0.059227238675313335, 0.07134768579687391, 0.022180378470303755, 0.04661165097994464, 0.03715010778978467, 0.039032961042331796, 0.03803260364968862, 0.05697349818157298, 0.022376210462035875, 0.05433045839890838, 0.044335009929324896, 0.032545562367886305, 0.020551283744030764, 0.07461914739438466, 0.0481274032167026, 0.08491424032087837, 0.0265930324925908, 0.032171723499361954, 0.031010580448699848, 0.018101914819063883, 0.026694805960037878, 0.028600888858948435, 0.02272786123545042, 0.027423269281695997, 0.019441750066887056, 0.026086485745119195, 0.0099438034729766, 0.01678455774007099, 0.010966615285724401, 0.015683465038559267, 0.050775101142270226, 0.041846302936651876, 0.05425879831558891, 0.03627324037786041, 0.03224381784509335, 0.059019464467253, 0.02642686605187399, 0.04231217150975551, 0.027274001755618622, 0.01640021345312042, 0.03436359856277704, 0.06118353655827897, 0.029494529656533684, 0.07180366132940565, 0.026367138006857464, 0.07247686984815768, 0.013809086688395058, 0.048098802965666564, 0.008605399934042777, 0.005868567528003561, 0.04670029140210577, 0.002313066930842719, 0.019377192548875297, 0.05478272234488811, 0.04562355810776353, 0.05693882504212005, 0.0386449916820441, 0.02257270911442382, 0.054010685200669935, 0.04671342444739171, 0.031094555942607776, 0.019656104368290732, 0.04542033008432814, 0.0556017887512488, 0.03648630376639111, 0.060546236112713814, 0.02071684119956834, 0.01096675862624709, 0.06445792942707028, 0.06794942636042833, 0.05239463531013046, 0.06279093852000577, 0.05361637493063297, 0.030070534641189233, 0.022402286562802534, 0.054099661497665305, 0.022617626436320797, 0.022258113138377666, 0.023370082756238322, 0.048508193676493, 0.022713401654203023, 0.11412569534565721, 0.022105712476851683, 0.0173071179139827, 0.0514746402124209, 0.01825465983711183, 0.04241959038855774, 0.03186648452122297, 0.053891140901084454, 0.027178543752857616, 0.020613736107147167, 0.00850808444166822, 0.021743413792657, 0.04681185952254704, 0.027359185041859746, 0.019311011635831425, 0.047572147832917314, 0.04506461488615189, 0.03814795799553394, 0.024648169621026943, 0.059392204109047136, 0.04706439668578761, 0.03374354647738593, 0.048449724313936064, 0.02931741505329098, 0.07530892573829208, 0.050120854284614325, 0.04629665806091257, 0.041131761457238875, 0.05742730240204504, 0.029972432048193047, 0.0515975432603487, 0.0351778609412057, 0.06544518430850335, 0.05828662629106215, 0.03200415588383164, 0.04436074676258223, 0.07870222508375134, 0.03762327400701387, 0.022488791295992475, 0.05307129078677722, 0.012447447565916394, 0.022156972404835478, 0.05386906137157764, 0.04490859593663897, 0.01872853173076042, 0.02193290996365249, 0.01989692323175924, 0.0186236929813666, 0.015653322816693356, 0.02741559674697263, 0.033743543084710836, 0.08493815189493553, 0.02764734868625445, 0.06812051218003035, 0.021215778176805804, 0.044893637632152865, 0.034547138892646344, 0.06677195775721755, 0.028198008691625934, 0.03549422789365053, 0.07436875440180302, 0.021392331292320575, 0.029587797687522004, 0.025350025888266306, 0.02434682034488235, 0.06169171178979533, 0.09082778157400233, 0.020758382809747542, 0.029958104781274284, 0.03305036528035998, 0.023703845650223748, 0.022176079950960617, 0.04786220459001405, 0.03088837968451636, 0.0172105759515294, 0.05164792109280825, 0.01847182327349271, 0.027032319456338882, 0.09007335919886827, 0.05615878118468182, 0.04390880512073636, 0.02632390514814428, 0.024089202650689652, 0.07612572583769049, 0.06149193750960486, 0.030224965818758522, 0.09087148601455347, 0.040418295455830436, 0.02888717974669167, 0.11145893737141575, 0.05607186424146805, 0.016257663423727666, 0.032873600122651885, 0.04026991681062749, 0.026979283462943773, 0.029821787096027817, 0.00802285980898887, 0.028313705697655678, 0.051621312342051945, 0.02976275115673031, 0.03837758442386985, 0.02094199268945626, 0.023618340059848766, 0.058436433252479346, 0.04402886510693601, 0.036865163794053454, 0.03393907991370984, 0.030200480882610594, 0.02985159513939704, 0.03720679599791765, 0.014504144034747566, 0.013890437099949589, 0.04807611275464296, 0.03719356117237892, 0.08803362186465945, 0.013618103677539952, 0.011877289856784046, 0.023519572502534305, 0.03222913773996489, 0.04067245771044067, 0.0452496106736362, 0.0047105037540729556, 0.028598218823650053, 0.06113248358347586, 0.051631941593119075, 0.05226486548781395, 0.02254864995900009, 0.09019514944936548, 0.02058644712503467, 0.010349552995259208, 0.02735550398938358, 0.03892115204195891, 0.047140752231436114, 0.05028283755694117, 0.03823020322514432, 0.06244747766426631, 0.029357479153467075, 0.025021262101030776, 0.09846018773636647, 0.03480292284595115, 0.10310148261487484, 0.0325269399742995, 0.029014225250908306, 0.07575342045830828, 0.0290676938103778, 0.15706005293343747, 0.032910376720662625, 0.018174874296944057, 0.021552509661497812, 0.027431857838694538, 0.10204015206545591, 0.024873063267607774, 0.024068325824503387, 0.01846867487100618, 0.011106424033641815, 0.015735015040263534, 0.015669122504602586, 0.07518604304641485, 0.0712291050170149, 0.030724761142794575, 0.04635633182312761, 0.027437927334436348, 0.05149856535717845, 0.01622047970470573, 0.022900551790371537, 0.07317134365439415, 0.013119613685246025, 0.018646703800186515, 0.006956112853783582, 0.034752198960632086, 0.06494620322648968, 0.02368838183714875, 0.016019097296521068, 0.010943932708219757, 0.06097621696868113, 0.015685327617185454, 0.0330821376826082, 0.020358111609571745, 0.05932308853204761, 0.030412787704595497, 0.004780773688772959, 0.039925217628479004, 0.047699814196676016, 0.04609323326232178, 0.046469694668693204, 0.008026803793784763, 0.005426148701060031, 0.03388858673029712, 0.0390928010456264, 0.061938060713665824, 0.04046554524185402, 0.03707689046859741, 0.007094265552171106, 0.03432349035782473, 0.0693467470950314, 0.017918952940297977, 0.05701625267309802, 0.013759729202969797, 0.012661993553462838, 0.02961339881377561, 0.0955636031659586, 0.08512092887290887, 0.01468198127778513, 0.0285799730169986, 0.06176364328712225, 0.045266797965658565, 0.023457109961392622, 0.0704565861129335, 0.09817525052598544, 0.029752936147685562, 0.03557420681629862, 0.0632992833852768, 0.0482836325120713, 0.033436119223811796, 0.05321765418297478, 0.04637103567698172, 0.03171409573405981, 0.010505247944300728, 0.050391684751957655, 0.04736792575567961, 0.06769801556531872, 0.016333079198375344, 0.0517617046300854, 0.017920030114640082, 0.051388140568243604, 0.03449604181306703, 0.010768924108041185, 0.024902058765292168, 0.0256289580637323, 0.048767451729093275, 0.011108264559879899, 0.048535240082336326, 0.026460957347548435, 0.03261301214141505, 0.031314173979418616, 0.0355760727875999, 0.035547604850892506, 0.043343337784920416, 0.008308133742372905, 0.1532199111367975, 0.12041720774556909, 0.12035752380532877, 0.15282613012407506, 0.08034174889326096, 0.16938743287963526, 0.10797056848449366, 0.07072429531919104, 0.14861632244927542, 0.19750771538487502, 0.19558291509747505, 0.11414518287139279, 0.1418193964553731, 0.10201970780534403, 0.09372561464884452, 0.15575248881110124, 0.10585811933768646, 0.061798974605543275, 0.16601951074387344, 0.1507836040109396, 0.12843176483043603, 0.14296196800257477, 0.2521446985857827, 0.13532162298049244, 0.16941458785108157, 0.21208137193960802, 0.15741099124508245, 0.11706804031772272, 0.11241692025214434, 0.20730292477778026, 0.17893319922898496, 0.07964709188256945, 0.12998452436711105, 0.14000081403979234, 0.07167167269757815, 0.14697114644306047, 0.11503793139542852, 0.11178168933838606, 0.08652542172265903, 0.07817341560231787, 0.09389316530099936, 0.09981372260621615, 0.11935834027826786, 0.13853293923395021, 0.07675463959042515, 0.12438080220350198, 0.1133395718144519, 0.19558249440576347, 0.119105246716312, 0.15546237437852792, 0.12501231474535807, 0.15230490666415009, 0.08957989460655622, 0.09230097609439067, 0.18437967768737248, 0.1080282846731799, 0.07736357048686061, 0.10026437842420169, 0.14788910932838917, 0.09855045324989728, 0.12478159926831722, 0.08286088478884526, 0.21049377641507558, 0.08027663667287145, 0.23401502998811857, 0.07554033332105194, 0.08994073952947344, 0.15442212591213839, 0.19283731813941682, 0.12102809282285826, 0.12706220974879606, 0.13054264656135015, 0.16458183074636118, 0.21603556190218243, 0.09622366846139942, 0.1798676098031657, 0.13904793374240398, 0.11069670505821705, 0.13023453738008225, 0.08784380847854273, 0.12210426293313503, 0.17192611736910685, 0.19868551647024496, 0.1274745011968272, 0.09434227405914239, 0.12418068865580217, 0.08973348779337746, 0.2249696832150221, 0.1407824456691742, 0.12065820981349264, 0.11750159705323832, 0.24095106923154422, 0.08802826143801212, 0.0796629288899047, 0.13756411336362362, 0.20030816511384078, 0.11001033974545342, 0.1926796944545848, 0.1164448873272964, 0.08496937129114356, 0.09896830868508134, 0.14290203978972776, 0.1820657104253769, 0.1477043849549123, 0.11764887986438614, 0.07773596407579524, 0.13151415943035058, 0.19427167331533773, 0.10036331561527082, 0.11235883765454803, 0.13671945940170968, 0.14466669224202633, 0.12075917582426753, 0.18057335407606193, 0.09908079622047287, 0.19668727155242646, 0.1705302894115448, 0.1230353486857244, 0.16263455737914356, 0.10637010115065745, 0.14508598617144994, 0.1688102302806718, 0.08818002258028303, 0.07134217609252248, 0.04023364572120564, 0.09287870116531849, 0.15501508409423487, 0.18932209962180682, 0.10666193227682795, 0.1636014019272157, 0.10172290301748685, 0.17849273500697954, 0.2029559716050114, 0.15839421562850475, 0.10752778367272445, 0.0786996805774314, 0.07971286228192703, 0.15815780045730726, 0.1577144863882235, 0.11548322678676673, 0.1903880645654031, 0.1293530525373561, 0.1671830490231514, 0.09992880893072911, 0.17450153774448804, 0.24270152673125267, 0.1781020209725414, 0.13410780525633267, 0.13255056738853455, 0.30632251713957104, 0.11994375315095697, 0.1115229232236743, 0.10680057733718838, 0.09850222976612193, 0.10433125948267323, 0.13819213823548385, 0.13839328315641197, 0.08826051040419511, 0.11514853260346822, 0.11425008438527584, 0.09141617321542331, 0.14287713755454334, 0.25767771740044865, 0.11803754472306796, 0.18702585569449834, 0.16983681305178575, 0.13837572267012938, 0.06924918054469995, 0.14576712676456996, 0.1278313020510333, 0.14932654505329473, 0.10638808911400181, 0.15794664035950387, 0.17688873250569614, 0.06183400736855609, 0.11088153799729687], [0.03303324584183948, 0.035122774075716734, 0.03176689254386084, 0.12285306703831468, 0.03514557285234332, 0.018210728087329438, 0.01308757919884686, 0.02959203513871346, 0.025560705922544003, 0.049321048094757965, 0.03159159641446812, 0.008531131731745387, 0.04269146919250488, 0.027796645050070116, 0.034914222945060046, 0.05413032788783312, 0.02212225176793124, 0.035339613511626206, 0.009737605162497078, 0.028922022519899265, 0.026184340672833577, 0.03274031209626368, 0.019525598335478987, 0.037247392748083384, 0.041808722274644036, 0.025416140644145862, 0.007805335052710558, 0.10670613883329289, 0.04304889090625303, 0.058742323624236245, 0.016922364809683392, 0.01925806894100138, 0.024978047902030603, 0.04768101538398436, 0.04189225332811475, 0.02441603091678449, 0.047618223753358634, 0.034054386762103865, 0.05134005957682218, 0.005522319165590618, 0.02058415367667164, 0.022107173023479323, 0.03203552116506866, 0.06598694702344281, 0.027693397465295026, 0.031979080622217486, 0.04520710384739297, 0.023556467844173312, 0.11082611525697367, 0.008226891048252583, 0.03146339400804468, 0.01375594552207206, 0.04885772063529917, 0.02105635976684945, 0.04368571976998022, 0.027652295206540396, 0.07657796264226947, 0.05746538857264178, 0.02827386381769819, 0.039667825547180006, 0.039374277727412324, 0.017663326746385013, 0.04429945808702281, 0.03947635992829289, 0.03535872784310153, 0.018722747219726443, 0.0829236696341208, 0.0805462593478816, 0.033513095629002364, 0.013029929167324943, 0.0829947597480246, 0.015497354757306831, 0.07972236855753831, 0.03581069323367306, 0.03876931965351105, 0.06266367927725826, 0.05926921285156693, 0.01901259532730494, 0.030417517093675475, 0.052217395177909305, 0.09903232167874064, 0.05875995196402073, 0.00898482823478324, 0.05161046256710376, 0.04573129589802452, 0.08770407097680227, 0.04639588702203972, 0.017316512231315886, 0.03792310845372932, 0.007625351942676518, 0.07887150600020375, 0.023759409186563323, 0.018948271903874617, 0.01494823841910277, 0.017280090167852383, 0.03096804648105587, 0.032607858667948415, 0.04097947784300361, 0.02828265423886478, 0.03058953589892813, 0.0020774509466718882, 0.03629468547712479, 0.031449819914996624, 0.03999987344390579, 0.021496578019910624, 0.06727703208369867, 0.012647463574207254, 0.02631283993832767, 0.030507596010076146, 0.043547325767576694, 0.03703626657703093, 0.00744839764333197, 0.01596355072355696, 0.06558501001979623, 0.011441231023387184, 0.03820399481004902, 0.03129705793357321, 0.05172533515308585, 0.05362058863309877, 0.04856099048629403, 0.010410997733872916, 0.05694649248783078, 0.03014924470335245, 0.09660420447055783, 0.041243804552193196, 0.06673963913427931, 0.026169979479163885, 0.06667789244758231, 0.03808251668566039, 0.051217495796403716, 0.02554918948693999, 0.053813133122665543, 0.03989458855773721, 0.020557422789611986, 0.013378077851874488, 0.04508002780910049, 0.017056931874581745, 0.031638279623751125, 0.04865309143705027, 0.06009234368268933, 0.050370022521487305, 0.04293706154982958, 0.0650494151881763, 0.03171055378126247, 0.028293032431975007, 0.026841696917212436, 0.06973163929900952, 0.054690594252731116, 0.060170524487538, 0.016095169553799287, 0.026526866846584847, 0.03617602666573865, 0.02511761068100376, 0.03906869948176401, 0.077694620937109, 0.020638261755396212, 0.006993891139115606, 0.0729728110932878, 0.05747842323035002, 0.05027576382937176, 0.015265007403546145, 0.016756025342536823, 0.017748007916712334, 0.015923050664631382, 0.04593112106834139, 0.038037081980811696, 0.025971431651019623, 0.011142045425783311, 0.015910879442734376, 0.008310061629994639, 0.01129303897531437, 0.02647303866355547, 0.00540452336593132, 0.02982251312849777, 0.06697629179273333, 0.07362139557621308, 0.043387276320053, 0.06055511135075774, 0.02580981987661549, 0.02110772656409868, 0.03494393260085157, 0.03454935770215733, 0.03222770942375064, 0.0032863240589254667, 0.006064854562282562, 0.010438676025452358, 0.011502004860501205, 0.024711147848782793, 0.03512248569833381, 0.06609463731625251, 0.029092613008937666, 0.057156722992658615, 0.04411576847944941, 0.04795784070821745, 0.011859006730706563, 0.04168292527486171, 0.033365649969450066, 0.03887461811038, 0.020631060802510807, 0.03687067349840488, 0.06952208054385015, 0.03756487928330898, 0.029323155459548746, 0.03396949863859585, 0.04413519832970841, 0.0825887651049665, 0.034675704315304756, 0.029307538976094553, 0.020230526670015285, 0.011345821366246258, 0.06391802589808192, 0.03278279517378126, 0.002214163454482332, 0.04357208211773208, 0.014925013861751981, 0.03603644183437739, 0.01291240775026381, 0.09069929418287107, 0.01976301604216652, 0.027223466163767234, 0.014269925620672958, 0.024820234227393354, 0.06848945881107024, 0.041972296711589606, 0.13405720011464187, 0.014510878494807651, 0.05337155610322952, 0.0410353110970131, 0.025946709227615168, 0.057874626613089016, 0.02840502972581557, 0.053201691646661074, 0.025175805236878138, 0.0448296619579196, 0.0642473121572818, 0.02988181708912764, 0.054382295081658025, 0.015464264300784894, 0.07366985654724495, 0.03870222611086709, 0.07188965885766915, 0.04710236411275608, 0.0012617928005056456, 0.01690015126951039, 0.017133085556062203, 0.036734752756144316, 0.043732945807278156, 0.046559997501650026, 0.027808222553825805, 0.015558562008664012, 0.01788769961733903, 0.023920854719887887, 0.017225856560149362, 0.03923110683847751, 0.003673416836785951, 0.06326262213821922, 0.05811813926058156, 0.05021371519459145, 0.03592750642980848, 0.1363224485622985, 0.04712349708591189, 0.05236470513045788, 0.014423690137586423, 0.024357351208371774, 0.020177059806883335, 0.005400209155465875, 0.023339647067976848, 0.0273162846653057, 0.014729173388332129, 0.07630094393555607, 0.015980761764304977, 0.008112972652140473, 0.017193924702171768, 0.06465898613844599, 0.02423551176408572, 0.038058259058743715, 0.0404612365444856, 0.03769638276259814, 0.03972252564770835, 0.030864430791033164, 0.04592701932415366, 0.052087079134902785, 0.010029117377208812, 0.06340227821575743, 0.01814933423884213, 0.0379313017640795, 0.03485066456986325, 0.013530465790868869, 0.02833087941897767, 0.04126102916364159, 0.0540369071864656, 0.017076656887573854, 0.04952031686635954, 0.015518123017890113, 0.023070867472727383, 0.04116266533466322, 0.06907359603792429, 0.024790097094540085, 0.014328549349946635, 0.05246773388768945, 0.02241988606484873, 0.059637738790895255, 0.015411632035725882, 0.04419523510815842, 0.03559812178303089, 0.030890194765691246, 0.023329002549871802, 0.036460088565945625, 0.04427484083654625, 0.0275847453490964, 0.04691204861072557, 0.10624040596719299, 0.020717083775837506, 0.038454822065042596, 0.017874882090836763, 0.05770713024373565, 0.05172620367790971, 0.017223495258284465, 0.01803131664304861, 0.03082554734178952, 0.04046150456581797, 0.018999608167048012, 0.049269357297037325, 0.04695118651060121, 0.06336478915597711, 0.03393658969019141, 0.01966901688969561, 0.03135013633540698, 0.02427123493648001, 0.034661892735000165, 0.04118614264630845, 0.07018720771053008, 0.024932616589856998, 0.011161357380582817, 0.01772014387617154, 0.023085605253332427, 0.032087483376796753, 0.028585235056068217, 0.04453289109681334, 0.03758953046053648, 0.0033924325169729336, 0.03401722679180758, 0.011693132908216544, 0.018082963335993033, 0.06548108559634004, 0.04256967894200768, 0.04772666722003903, 0.07044254043804747, 0.022823376913688014, 0.022073872221101607, 0.04237589273335678, 0.048798213114163706, 0.09798134557370629, 0.06845053804240056, 0.09371589124202728, 0.1531141818101917, 0.1271761900612286, 0.1250790554497923, 0.12271300383976527, 0.06847789657435246, 0.09272902991090502, 0.11003248034311192, 0.0723883006721735, 0.09761557448655367, 0.1006964220266257, 0.2010939765189375, 0.19499564303883485, 0.14219887394990238, 0.11674580403736659, 0.1389611626842192, 0.12958500294813088, 0.16312494820782117, 0.11700640219662871, 0.13151652073221548, 0.07190134323069028, 0.14144510296838625, 0.12835871375032834, 0.13423076937241213, 0.0986806166225246, 0.20572263029004845, 0.12404855074627058, 0.23330368101596832, 0.06547510091747556, 0.06476206239312887, 0.11847500982029097, 0.15228334282125744, 0.17708029651216098, 0.09952092796031918, 0.13822379867945397, 0.07817876924361501, 0.10428914959941592, 0.13720740750432014, 0.14942673753414834, 0.14114065787621907, 0.09135076922497579, 0.10882288310676813, 0.10550393084330217, 0.13135988770851068, 0.16833368156637463, 0.11589759455195495, 0.2802662838782583, 0.16112721897661686, 0.15211199915834836, 0.06398748752794095, 0.10386467844780002, 0.14137278470609868, 0.20076971820422582, 0.1163972405982869, 0.11221298655228955, 0.20191390466477188, 0.08417204514678035, 0.12458817607590131, 0.12172711959906987, 0.15237233947430337, 0.19097099399992398, 0.12537432674850735, 0.1836190399314676, 0.1253318368856396, 0.10880143461482865, 0.12470481624560696, 0.09423439377652747, 0.1632554440626076, 0.21496704566691602, 0.11857738718390465, 0.13797540057982716, 0.20823515046920094, 0.13543210205222878, 0.12119923292526177, 0.10539265788559403, 0.10251731824662004, 0.1932502474103655, 0.12826939140047344, 0.13314235849039896, 0.11308153851756028, 0.1231120095721313, 0.21801902832729475, 0.1613743414304086, 0.19804426016552107, 0.190317035519651, 0.06488358122961861, 0.08908237916018281, 0.11440910585224628, 0.13682159249271664, 0.11738419692431178, 0.12551714479923248, 0.1676842285586255, 0.07866118728582348, 0.09847753109144312, 0.05644210687439356, 0.10147409779684884, 0.1378910993891103, 0.09245401966784682, 0.11072181763925723, 0.10878972988575697, 0.13246100076607295, 0.0817201995689954, 0.11115708428301982, 0.19546707559909138, 0.0686101634055376, 0.07679192508969988, 0.09625393790858132, 0.10768939035811595, 0.13779372961393424, 0.07072365749627352, 0.2166727605674948, 0.17216954859239714, 0.10218349937349558, 0.07530874931918723, 0.21602676808834076, 0.181442937414561, 0.18024335535509245, 0.13501005327062948, 0.17254958248564176, 0.1337605717458895, 0.22052051552704402, 0.2201721149363688, 0.1837820918964488, 0.20158258958586625, 0.13214909178870066, 0.11137363873422146, 0.05711536628327199, 0.24386711418628693, 0.07947603998971836, 0.09457809211952345, 0.15912174087549957, 0.1474389691970178, 0.1251619995704719, 0.1410840002021619, 0.0838647773489356, 0.1179986239543983, 0.19997667361583027, 0.19021689732159885, 0.23635535155023846, 0.12648188588874681, 0.21338262568627084, 0.10481224581599236, 0.13901712825255735, 0.18882763758301735, 0.11664216459861823, 0.17371375858783722, 0.18373648077249527, 0.0630920452198812, 0.13654864499611513, 0.16493418041084493, 0.10858700397823538, 0.10079537957374539, 0.12601187825202942, 0.09731435922107526, 0.13570054407630647, 0.08133498845355851, 0.1539601521300418, 0.1297455443335431, 0.186049470944064, 0.14096331596374512, 0.10971466811107737, 0.15731926688126155, 0.08955980997000422, 0.1186085862240621, 0.15662049794835703, 0.09402471967041492, 0.18105804521058286, 0.2188044733234814, 0.13789134366171701, 0.11618875392845698, 0.10050150605716876, 0.11907555402389594, 0.11526110156306199, 0.13263580495757715], [0.04231150993811233, 0.014925198762544563, 0.025491515706692423, 0.04315188234405858, 0.07071021571755409, 0.03568399717499103, 0.0638153635497604, 0.05292183327089463, 0.02075617417826184, 0.015961532081876482, 0.04353333776816726, 0.030581525793032985, 0.024310878344944546, 0.010540784519564892, 0.02403859411632376, 0.030822605892483677, 0.048753195708351474, 0.019334139501942054, 0.023003955438200916, 0.030109221315277473, 0.04316941908161555, 0.08728238181876284, 0.07490309394363846, 0.03103302638711674, 0.024069844046607614, 0.020142700489876524, 0.015803762512015443, 0.009987501128177558, 0.04985225959015744, 0.016339228421981846, 0.04976396522085581, 0.059840152572308264, 0.024571944693369523, 0.043554694657879214, 0.027882673112409453, 0.029641727650804178, 0.017189999377088885, 0.07232221814670733, 0.03380727109366229, 0.06871236435004643, 0.0957424785675747, 0.04934198768543346, 0.06209304489727531, 0.029204700208668197, 0.015240132309762495, 0.027119283897003958, 0.00731517153326422, 0.012751572050287254, 0.054449887347540686, 0.007748955578011061, 0.019229923308427845, 0.05204353075740593, 0.01896389856535409, 0.024947349281449403, 0.014261045293616397, 0.033857489470392466, 0.035012586774038415, 0.012850711105524429, 0.014095291911092187, 0.03112349546115313, 0.009972716698289981, 0.028525333984621933, 0.05054089120988335, 0.04604641773871013, 0.04360318955566202, 0.06106177344918251, 0.06861424818634987, 0.027820967137813568, 0.048459790380937715, 0.03751675418711134, 0.036699618212878704, 0.03896023226635797, 0.012382273429206439, 0.007321140945090779, 0.09196563730282442, 0.05299619392358831, 0.049603220274938006, 0.049838461580553224, 0.015074856446257659, 0.07383094076067209, 0.04670223879760929, 0.0589495346482311, 0.07743350030588252, 0.047844535538128445, 0.024480625754222274, 0.04149974456855229, 0.14093512961907045, 0.04882877433140363, 0.02329421745214079, 0.04116265515663794, 0.030698705398078476, 0.029684336257300208, 0.027114881901070476, 0.010655582466694926, 0.08713546541652509, 0.04492241090961865, 0.025097675322155868, 0.024309679034299085, 0.03463423564764006, 0.018059972873223678, 0.04196920259190457, 0.05311870342120528, 0.06307465436735324, 0.011603290630903627, 0.038078815277133665, 0.0803222952942763, 0.028671168123504946, 0.04732934086184416, 0.04998797337923731, 0.019920420899455036, 0.021154438611119986, 0.06757881731859275, 0.05597433840323772, 0.025920902844518423, 0.018833904826481427, 0.04309664620086551, 0.014304407073983123, 0.021891792437859943, 0.03707041385184441, 0.010822181473486125, 0.05328366546226399, 0.05662204418331385, 0.07238214635955435, 0.020358376238229017, 0.038749764274273596, 0.0536942232533225, 0.06765750023935523, 0.042241797250296385, 0.03650723317904132, 0.04773964759494577, 0.04700692816238318, 0.058311915291207175, 0.05864357642297234, 0.04525619924866727, 0.011702376251508082, 0.016452411455767493, 0.04997208208910056, 0.036662275038127384, 0.04509986817304577, 0.039679849187710454, 0.10600741739783968, 0.02673578099347651, 0.028333612218765274, 0.015114835729556424, 0.020970453840813467, 0.07785497233271599, 0.034317916192646535, 0.03366596278335367, 0.021826278185471892, 0.1030418122453349, 0.08196063845285348, 0.05173082110871162, 0.029107466140495877, 0.05803874387804951, 0.0460164129201855, 0.021565276297873685, 0.05131864840430873, 0.019919759327811853, 0.028320591131757413, 0.037050295288541486, 0.018428590414779525, 0.0157922375947237, 0.04424537545336144, 0.053428095033658404, 0.021101931875039424, 0.04159148928842374, 0.056632707361131907, 0.009986880268635494, 0.0005724980718306531, 0.06635993772319385, 0.05134129111788102, 0.03143673775983708, 0.033238207522247515, 0.02963150552074824, 0.037911831201719384, 0.01948650454037956, 0.036537495840873034, 0.02585792461676257, 0.018523897443498884, 0.01597842081849064, 0.03993624721520713, 0.06448731677872793, 0.020961860194802284, 0.12461866943963937, 0.03249449242970773, 0.0402201123402587, 0.018334140036521212, 0.021471882737906914, 0.04604667218934212, 0.04110465059056878, 0.010892286863444107, 0.007353474835066923, 0.018019829045182893, 0.03372534816818578, 0.02345501837719764, 0.015601596395884241, 0.030588260253093073, 0.018977660951869826, 0.044360037693487744, 0.06452988128044776, 0.023628782713785768, 0.02058707476992692, 0.029817776954067603, 0.04126313940754958, 0.042371047993323634, 0.012515279863561903, 0.06590191301490579, 0.052670252842030356, 0.013975192060960191, 0.00690572866005823, 0.01989077400815274, 0.03985986113548279, 0.012244348464134549, 0.03145342293594565, 0.018570222725559558, 0.04110381938517094, 0.04588679237557309, 0.0504908628229584, 0.0503774558726166, 0.05499311909079552, 0.06611229958278791, 0.031780459851558716, 0.029107930936983654, 0.056176351848989725, 0.01922106503375939, 0.0641169927216002, 0.02136354105147932, 0.02686838200315833, 0.025521669802921157, 0.023791156143748333, 0.06377264977033649, 0.02387765748426318, 0.03558362148968237, 0.09510327143860714, 0.06308262036847216, 0.01203541989837374, 0.058164293212550025, 0.030706447482641255, 0.010651836953391986, 0.018089867429807782, 0.05320783578125494, 0.06601927921708141, 0.022959211142733693, 0.03735858767426439, 0.07306913592453514, 0.027495224527748566, 0.033522544229137044, 0.042446741967328956, 0.03515167627483606, 0.041184297031057734, 0.026100482226216366, 0.06826883314975671, 0.08754618266331297, 0.01641013363509306, 0.009191051142157187, 0.005703785722809178, 0.06313566145087991, 0.023285922361537814, 0.010229466715827584, 0.010675745134774064, 0.06752666511705943, 0.00902071425558201, 0.036043020231383185, 0.07360048312693834, 0.01699649984948337, 0.03257079369255474, 0.018798597256786058, 0.021387160855478475, 0.013239587158230799, 0.016563926989744817, 0.036311177270753045, 0.020610141567885876, 0.02394029644450971, 0.06260634985353265, 0.044636316797030826, 0.04134061114330377, 0.01661921911207693, 0.0517091419148658, 0.08590563426592521, 0.03293969961149352, 0.04178602867094534, 0.09678265239511218, 0.033330925939870734, 0.049482868518680334, 0.024520532095006535, 0.02315961306781641, 0.014036136379997646, 0.016895837483129332, 0.03729463914143188, 0.0335223169199058, 0.0406237456814519, 0.023832950508221984, 0.01220336155633309, 0.021431285987741182, 0.03266990391005363, 0.041157467756420374, 0.03309968120551535, 0.007980284281075, 0.02772129373624921, 0.02277597106461014, 0.03094291015129004, 0.06861193438193627, 0.05617713216426117, 0.024175536053787385, 0.021775133608441268, 0.03893498397831406, 0.02038368729076215, 0.042771376868976016, 0.059476912420775206, 0.01876095213395144, 0.04732523233230625, 0.026633423985913396, 0.03561947528006775, 0.030750324949622154, 0.04427318521110075, 0.031805379050118585, 0.028442160858373557, 0.032994111334638934, 0.049674568232148886, 0.03587823121675423, 0.02268741206665124, 0.07363461343837635, 0.05855941093925919, 0.03049132813300405, 0.022287276573479176, 0.08077130227216653, 0.033286196911441426, 0.12029562784092766, 0.012223746444630836, 0.03954039327800274, 0.03931244961651308, 0.03074350906535983, 0.006483873260939228, 0.009904244881389397, 0.040227718717817745, 0.03680953410054956, 0.02917615763310875, 0.008411188792836453, 0.028426790343863622, 0.03873995605057903, 0.03744768610756312, 0.05654361232050827, 0.04018010252288409, 0.0062956175367747036, 0.0591654037790639, 0.018935674901253412, 0.04777936224958726, 0.05661610360922558, 0.06387489142694644, 0.03928760505680527, 0.05784744450024196, 0.025108635359044586, 0.08910328482410737, 0.10457426322890179, 0.1543544488293784, 0.08230302043791328, 0.10210959333926439, 0.15778539329767227, 0.1261763008577483, 0.19086173629122122, 0.07602260887090649, 0.24403916352561542, 0.10034390951373748, 0.07742561572896582, 0.08578358617212091, 0.18587644451430865, 0.061782642267644405, 0.13109554403594562, 0.10671614722481795, 0.10300863188292299, 0.1464058453483241, 0.09448019987238304, 0.08058744642351355, 0.21612278079347952, 0.2030163612216711, 0.09567672852426767, 0.21041294932365417, 0.10555747404162373, 0.15478797842349323, 0.08725113528115408, 0.20280388476593153, 0.14992440225822584, 0.15199166775814124, 0.1286930279540164, 0.15809742441134794, 0.1576800982334784, 0.08395844910826002, 0.15099347489220755, 0.14033735383834156, 0.130036662997944, 0.13334112853876182, 0.14886719041637012, 0.14975822903215885, 0.1351150226380144, 0.15330011397600174, 0.2423892377742699, 0.12179305963218212, 0.10502750426530838, 0.08476044357355152, 0.18996609720800603, 0.1310155311865466, 0.1471278608909675, 0.09237476677766868, 0.18940587155520916, 0.08389086023505245, 0.09936109225132636, 0.15959438122808933, 0.13243027670042856, 0.16820230361606392, 0.12698329612612724, 0.15477163930024418, 0.1541908268949815, 0.11186433490365744, 0.09862136694469623, 0.15402063674160413, 0.1035485082705106, 0.16887507108705385, 0.17231822918568337, 0.08374694295759712, 0.1310045796313456, 0.14326763445777552, 0.10820675973913499, 0.11424466967582703, 0.09597577926303659, 0.08627720682748727, 0.10448644722678832, 0.17352463730743953, 0.17959573439189366, 0.1564953082374164, 0.11412102702472891, 0.1100017155653664, 0.12771272127117428, 0.15899762324988842, 0.11375195147203547, 0.13386210772608007, 0.13631615175732545, 0.15018877307219164, 0.10860896137143884, 0.24708442868930952, 0.12572298518248967, 0.07945256267807313, 0.06225735215204103, 0.1001710934298379, 0.08622202835977077, 0.12049834696309907, 0.14106942526996136, 0.14672073987977846, 0.15570572417761597, 0.11093024324093546, 0.1415027513035706, 0.08251799390252147, 0.13358821028045245, 0.0934052239837391, 0.1187833904155663, 0.1873526924422809, 0.169804148375988, 0.12692487426102161, 0.16589767299592495, 0.10196771166686501, 0.1693346564258848, 0.11063030362129211, 0.10338652839085885, 0.11892308720520564, 0.14897103341562407, 0.14760617379631313, 0.139710808172822, 0.110016582267625, 0.14786472277981894, 0.09275095337735755, 0.10467141587287188, 0.1164356456803424, 0.14528111927211285, 0.1825699433684349, 0.1964020968547889, 0.13760595183287347, 0.057175090935613425, 0.14886397416038172, 0.18711118825844356, 0.15056473575532436, 0.1255709526262113, 0.14510060181575163, 0.12579543915178093, 0.1553642853562321, 0.10635456948408059, 0.13342857813196524, 0.08559561840125493, 0.11306705858026232, 0.08457066411418573, 0.1068827004304954, 0.1026759258072291, 0.1616772258920329, 0.09096088300326041, 0.1804878722344126, 0.08336329247270312, 0.055693302769213915, 0.10860613866576127, 0.09125350123005253, 0.162430630464639, 0.2065351488334792, 0.11884003451892308, 0.09171750383185488, 0.18984561653009482, 0.1929596715739795, 0.2345101705619267, 0.13225673458405904, 0.1379898940878255, 0.146944059325116, 0.08145143184810877, 0.10483560777668442, 0.11589492112398148, 0.09975915482001645, 0.24752384796738625, 0.11767222146902766, 0.12238031812012196, 0.12221542053989001, 0.15261617781860487, 0.12198132595845632, 0.1680240931787661, 0.14164451083966664, 0.08468862742717777, 0.11224846036306449, 0.12456153679106917, 0.18795244954526424, 0.1534309083861964, 0.11858342614557062, 0.10784460524363176, 0.1009865907420005, 0.1754678123231445], [0.01868175861558744, 0.061422482665096007, 0.022394093252452354, 0.02152058289253286, 0.0511434540551688, 0.05314904072188905, 0.011979840246827474, 0.027534845883824995, 0.03959218246330108, 0.025692236543233906, 0.06601272456880126, 0.010481364359813077, 0.0755631931658302, 0.048880108898239474, 0.02912627173853772, 0.015889191767200828, 0.041182780505291054, 0.050186594149896076, 0.028467895995293344, 0.050190892669239213, 0.04311421347249832, 0.04576622348810945, 0.01480620407632419, 0.04325002904183098, 0.027272252831608057, 0.012870076494956655, 0.05891447474381753, 0.024299436548192586, 0.07809383701533079, 0.062226533091494014, 0.040238890796899796, 0.0625635546499065, 0.03311824931630066, 0.029427297014210905, 0.045336089961762936, 0.010697261480215405, 0.09280923953545944, 0.03050526524228709, 0.0390221146600587, 0.020230681036732028, 0.01524589307207082, 0.04862689998533044, 0.04439503652974963, 0.03392995361770902, 0.13203868057046617, 0.05146459789414491, 0.05938183609396219, 0.04513407312333584, 0.05231860206861581, 0.04926387134141155, 0.053604656630860906, 0.06561973744205066, 0.0319974960626236, 0.04849127779847809, 0.007876380213669367, 0.04512004101915019, 0.06491929931300026, 0.032642257000718794, 0.062083701470068524, 0.03996524101655398, 0.10531218363238232, 0.014404767492253865, 0.037094288106475554, 0.04431491172207253, 0.05145467431949718, 0.0389676452614367, 0.04243702534586191, 0.028395693083958964, 0.04682519952101367, 0.06433677021414042, 0.039385819608079534, 0.02891309299905385, 0.03713227588949459, 0.036818392375218015, 0.037592773857925615, 0.007380526329922889, 0.003147517634455913, 0.05267899576574564, 0.03797840905774917, 0.059657402735735686, 0.02801515537846301, 0.016049877341304506, 0.056523581966757774, 0.07286902916218553, 0.038372434343078306, 0.043620787361370664, 0.026530944842046926, 0.01995295495726168, 0.027244074968621135, 0.042531389210905345, 0.0325030928610691, 0.048899752487029345, 0.0248185039630958, 0.021524827129074504, 0.06224977970123291, 0.019770897226408124, 0.01947982605945851, 0.016112305955695252, 0.0027432307792228778, 0.04380879584433777, 0.023347251749198352, 0.004577516403514892, 0.03050327713468245, 0.022799962366532003, 0.046237645870340724, 0.03474855522758194, 0.029839337404285158, 0.055040199243064435, 0.03966178319283894, 0.02688804085898612, 0.03829674036907298, 0.0039881807502492195, 0.022256572863885334, 0.040882695000618696, 0.03486912411504558, 0.0514270477662129, 0.03199576579832605, 0.03234046158779945, 0.04793333541601896, 0.03023884185988988, 0.05131459076489721, 0.07439762606684651, 0.03296218965468662, 0.034164645309959135, 0.05711558341447796, 0.023069671554757015, 0.02782023262365588, 0.019718756899237633, 0.016214603591444235, 0.003974996814836881, 0.01709952182136476, 0.02112113611240472, 0.05492485846791949, 0.05233470709728343, 0.05898496096155473, 0.023709384192313467, 0.0388501704936581, 0.04493487220523613, 0.029156955092081, 0.0517447378619441, 0.029754876757838895, 0.04131336796230503, 0.024272542812728455, 0.0960841616615653, 0.007099475428861166, 0.02129186230844685, 0.03988724002348525, 0.02789812335478408, 0.029359083888786178, 0.03539260370390756, 0.040230751769351106, 0.06419509210224662, 0.013470141483204705, 0.00430610282013991, 0.01879872108942696, 0.028283885779923627, 0.06035896723291703, 0.01879623086590852, 0.03830987002168383, 0.03399952381317105, 0.05917075742036104, 0.030245796843831028, 0.03774882334151438, 0.04009902776618089, 0.025213250191882253, 0.07306330730872494, 0.02385730652271637, 0.035616876490946324, 0.03788765160632985, 0.00724290161659675, 0.009257793542928994, 0.02211306440377874, 0.03478931821882725, 0.01615704346581229, 0.025506390890638744, 0.030123524833470583, 0.029523740589086498, 0.016566502030140588, 0.010105238828275884, 0.043988339602947235, 0.03060868415715439, 0.0266531015014542, 0.012145753933249839, 0.03746893782434719, 0.05376206657716206, 0.014619381333302175, 0.044507452818964205, 0.04047989286482334, 0.08662396536341735, 0.03593792872769492, 0.043773128651082516, 0.025763643872258917, 0.03042103529774717, 0.02768782838912947, 0.029554223774799278, 0.06252368393221072, 0.06723065421517406, 0.01987403115656759, 0.03913330280088952, 0.02109267496104751, 0.0275456125382334, 0.027464225655421615, 0.03357803821563721, 0.022710830006482344, 0.019846594593088542, 0.032038584750677855, 0.0749118063332779, 0.02146222209557891, 0.012141799770428665, 0.056846754625439644, 0.027134225238114595, 0.02362767161269273, 0.03585845870631082, 0.021594242957819785, 0.04393669291000281, 0.05329549911298922, 0.03441019695518272, 0.06549520591007811, 0.07937660068273544, 0.04340898265529956, 0.07126065011003188, 0.03698785649612546, 0.04115576124084847, 0.014492064415078078, 0.03936629815559302, 0.06315904376762253, 0.039074436495346684, 0.0697929992207459, 0.04803415893443993, 0.05225777818954416, 0.013146515902397888, 0.028686645507280315, 0.040653618185647895, 0.06485357641109399, 0.010035726308290447, 0.02492493387710835, 0.04793313524818846, 0.06926422366606337, 0.011481753982869642, 0.017602901506636823, 0.04749733256176114, 0.01905771790604506, 0.047947180923074484, 0.012048081361821719, 0.026575429597869515, 0.025570293622357503, 0.008860963363466519, 0.03791184137974467, 0.01557586804431464, 0.0335925995771374, 0.047545308380254676, 0.0200888960555728, 0.049814122529434304, 0.06846651754208974, 0.06515958213380404, 0.061716905795037746, 0.06105735618621111, 0.03918400972283312, 0.021501879074743817, 0.04856031195127538, 0.038782880175858736, 0.027327015696625625, 0.04822488834283181, 0.02799399696024401, 0.0777079202234745, 0.03547021793201566, 0.025845349666529467, 0.0461623522319964, 0.06063030660152435, 0.055732457632465024, 0.071783298493496, 0.04282576145072069, 0.03591843780928424, 0.04375689470076135, 0.018845000570373874, 0.036976416395711045, 0.032420705139104805, 0.02479821746237576, 0.03038531382169042, 0.05187485034444502, 0.0709606765636376, 0.04324374920023339, 0.01893206000594156, 0.030201081386102096, 0.010945310982476388, 0.019518745131790638, 0.046233116649091244, 0.02788798264893038, 0.0166557565264936, 0.04991964151018432, 0.016972203206803118, 0.033935219049453735, 0.06853650842926332, 0.043431021472705264, 0.016642776151586856, 0.03877985730235066, 0.04495534360674875, 0.03920388062085424, 0.02945863176137209, 0.024817949260718057, 0.023868697429341928, 0.029598817096224854, 0.011275646426448864, 0.035820569310869486, 0.006684272641515625, 0.04644736068855439, 0.02882164004924042, 0.03798899081136499, 0.03515632084703871, 0.008277351153083146, 0.030778070246534686, 0.021149960279996907, 0.03588386305740901, 0.05351316975429654, 0.03973450518346258, 0.00908108351619116, 0.051665522291191986, 0.011561313910143716, 0.09196241426148585, 0.04542474056194935, 0.03960328668888126, 0.006222784436041755, 0.028451816411688924, 0.019311496788369756, 0.02941146000687565, 0.029201422884528126, 0.04126545321196318, 0.02230222469994, 0.03017543615507228, 0.03169458106692348, 0.03049749940899866, 0.04441513812967709, 0.04936224195574011, 0.019677607143031697, 0.022986101485522728, 0.018039945912148272, 0.06589817428695303, 0.044609562161245515, 0.02712068167914237, 0.026130098583442823, 0.03214289593909468, 0.02173106275898005, 0.062274369810308726, 0.08403798019779579, 0.049830400584531684, 0.025830047005521398, 0.08913849400622503, 0.03341852141810315, 0.056483287164675336, 0.06288560772580759, 0.02032619501863207, 0.005470516833676291, 0.13178733762885841, 0.16546769892530783, 0.09051982845578875, 0.09507296127932412, 0.10667478373008114, 0.0976085245077099, 0.07965091203472444, 0.1429249607026577, 0.20163745592747415, 0.12477880370404039, 0.197178788749235, 0.08868943274553333, 0.18866161363465445, 0.09758201414453131, 0.13530043911721024, 0.08285868633538485, 0.10185537340917758, 0.13071048898356302, 0.1300880688109568, 0.15861115684466703, 0.19192517708454812, 0.11195310764014721, 0.20878677229796136, 0.08753124810755253, 0.11541781601096902, 0.10131654196551867, 0.07910311035811901, 0.07686600754303591, 0.15739402786961623, 0.12576229950147017, 0.20797882708055632, 0.14553487779838697, 0.20500787507210458, 0.19449765261794838, 0.17903952566640718, 0.13599162202860626, 0.21099387029451983, 0.08169636263379029, 0.1038980759414179, 0.17264711510922226, 0.08433214548443045, 0.10587479772844485, 0.1888152068214757, 0.22426133336765425, 0.21143927425146103, 0.1422452586037772, 0.1845285211290632, 0.09240494801529817, 0.15866972798747675, 0.14704152409519466, 0.11437849035220486, 0.24836379289627075, 0.15959447622299194, 0.23325053815330776, 0.1140765965517078, 0.08047552207218749, 0.15190271181719645, 0.1614712905138731, 0.20961876479642733, 0.12367550576371805, 0.14525549778980867, 0.14956897204475744, 0.10630330616342169, 0.11850869229861669, 0.1013364094708647, 0.1591861338487693, 0.1348113782171692, 0.13249624387494155, 0.11740002036094666, 0.08044189387666327, 0.10114470975739615, 0.0883283367646592, 0.20248068496584892, 0.12066310883632728, 0.12773781349616392, 0.14944580436817237, 0.11194069723465613, 0.15751060018582003, 0.12596557502235683, 0.18262783597622598, 0.11749668445970331, 0.08943068475595542, 0.08530305445726429, 0.11072580063981668, 0.11271058342286519, 0.1095026937712516, 0.15862047991582326, 0.09361945784517697, 0.21247560078544275, 0.1421205981501511, 0.17487295424299582, 0.175224082544446, 0.12884607831282274, 0.1295321314994778, 0.18450394459068775, 0.12349114779915128, 0.11096370180270501, 0.07964285103870289, 0.09494587167033128, 0.1269126742013863, 0.0932365944609046, 0.08939042048794882, 0.1480201615818909, 0.06938271623636995, 0.1689015475234815, 0.09428626777870314, 0.09904591273516417, 0.0952510970777699, 0.11648748575576715, 0.10431689489632845, 0.1088832455820271, 0.13248153323573725, 0.13437864929437637, 0.14778432995080948, 0.10476453801883118, 0.17036355978676251, 0.17934611492923327, 0.17186035375509942, 0.11832646493400846, 0.09786910231092147, 0.09027786965348891, 0.16444119757839612, 0.13491429840879782, 0.16600998411221163, 0.08873486066503183, 0.2340643730546747, 0.07847832209829773, 0.16449387903724397, 0.06368103397211858, 0.19965548227940286, 0.11221749881016356, 0.11372278125158378, 0.13363998250237533, 0.0921098327796374, 0.11165065065558467, 0.08248962435339179, 0.12379334015505654, 0.17079622085605348, 0.11274816069219794, 0.1426479827080454, 0.12983557235981735, 0.11495383376521723, 0.15962806370641502, 0.14978162491960184, 0.13329106622508594, 0.121790508340512, 0.12224018706807069, 0.09937670534210545, 0.18128086254000664, 0.14577260932752065, 0.1586626169404813, 0.13745117799511977, 0.10259290704769747, 0.09683557134121656, 0.07754122452544314, 0.12603559983628138, 0.11260038933583669, 0.12555253718580517, 0.1738957552505391, 0.09378639781581503, 0.14729871600866318, 0.16198058532817022, 0.14775964484683105, 0.1313099203897374, 0.08095352963677474, 0.1873337613152606, 0.1310850674552577, 0.13463091504360947, 0.13934551206018242, 0.09804719739726611, 0.14391575753688812, 0.09974977068070855, 0.11535118387213775, 0.15458414650389127, 0.12391144596040249, 0.10126877310020582], [0.039544294854359965, 0.011881500166574759, 0.0464220513323588, 0.031247110970850502, 0.08419825695455074, 0.085994189871209, 0.029596594894038777, 0.04312095471790858, 0.05256390944123268, 0.033142279633986096, 0.03419941683698978, 0.02749618804747505, 0.01537588341826839, 0.022246165833036815, 0.0062904661837300015, 0.07398456108889409, 0.08497108119939055, 0.008814206363500228, 0.046588322946003506, 0.043809138504522185, 0.03346716559359005, 0.02790851511859468, 0.03923871321603656, 0.011417325386511428, 0.06530814059078693, 0.05177221853019936, 0.03249651107138821, 0.012248857329333467, 0.08532063529959746, 0.05938199215701648, 0.05213864101096988, 0.009967754062797343, 0.015740365288885574, 0.028783452098390887, 0.013730015306334411, 0.00676142080088279, 0.023674678822447146, 0.03510143414938024, 0.012239530865502144, 0.018272154166230133, 0.023234608150752525, 0.018705687153020074, 0.014959885472697871, 0.1262105397347893, 0.08032570154006992, 0.049152829085609744, 0.012962890755651253, 0.012913339887745678, 0.016865929355844855, 0.059053506569138596, 0.04538956869925771, 0.07410088234714099, 0.1148162947169372, 0.0779313210930143, 0.03516871428915432, 0.028961662535688708, 0.031087963974901607, 0.038896935127143345, 0.07486693481249468, 0.045067671686410904, 0.04682849380852921, 0.05809293846998896, 0.00431862857658416, 0.03508353778826339, 0.09827831999531814, 0.019696682458743453, 0.048156804139060636, 0.07467139459082059, 0.014253133575298955, 0.0811260471652661, 0.035793851994510205, 0.03784309221165521, 0.057046176067420414, 0.04974271011139665, 0.018396144566525306, 0.03288147791421839, 0.054798759520053864, 0.0820653499769313, 0.009411579264061791, 0.07843422410743577, 0.09482595417648554, 0.0018341002994150455, 0.018975805158593824, 0.01584999279917351, 0.02028775431348809, 0.0112369224329346, 0.032964612024703195, 0.029612442079399313, 0.02511516456226153, 0.057336629767503054, 0.04162916833800929, 0.030112603812345436, 0.015479114039668014, 0.04342357794355069, 0.015498481125437787, 0.021586497480581914, 0.015147732803598046, 0.007887598093865173, 0.01631108787842095, 0.00530148739926517, 0.02646063843608967, 0.013392469579620021, 0.05745320886905704, 0.11402292443173272, 0.038814530441803594, 0.022404164408466647, 0.019265902627791678, 0.0357605698518455, 0.013382747869140335, 0.011056891825449253, 0.04184688986944301, 0.021585120054494058, 0.04956389917060733, 0.003844294006869729, 0.017058428044297864, 0.01870161933558328, 0.025593943960432495, 0.05995508283376694, 0.0646057618515832, 0.04331192500623209, 0.03394060322482671, 0.1034998640950237, 0.02869662336472954, 0.05429527296551636, 0.023833291472068856, 0.035673354353223524, 0.03377791088340538, 0.0169331280714167, 0.04043781690831695, 0.060200542876763005, 0.07445659754531724, 0.029311331986848797, 0.08114101564777748, 0.01879720965267292, 0.03068121276529772, 0.032014622286494286, 0.017556242046079466, 0.02549318320650075, 0.03909210215455719, 0.032198291538017135, 0.02822074979277594, 0.022295539433668767, 0.07597469072788954, 0.07068565274987902, 0.03579267134357776, 0.0189287504513881, 0.04521216571863208, 0.0136512636839013, 0.01756878476589918, 0.03870459419808217, 0.04266200041664498, 0.013945816583665354, 0.017707943816536238, 0.08026404306292534, 0.026371680798807313, 0.023255386589361087, 0.009619419629286443, 0.07681650162807532, 0.041928144437926154, 0.032777288862104924, 0.02001248113811016, 0.04038842973698463, 0.06508702638425998, 0.01959454088604876, 0.010038260636585099, 0.03999713555510555, 0.05291545164904424, 0.05512410009812031, 0.03028785583696195, 0.0057801972475967234, 0.02969620722745146, 0.034062223841569254, 0.03221230667882732, 0.029274663954441036, 0.054271615842091184, 0.009875137425426925, 0.0261650024248021, 0.03573383557211075, 0.07985158198113952, 0.02087330967853112, 0.010104077685225223, 0.034304857786212645, 0.03482641712097185, 0.03871206486863749, 0.01111818474185254, 0.010562623169140091, 0.019643168098160198, 0.01566705127645816, 0.004454991214775613, 0.04366565548947879, 0.015145646308415701, 0.09834700809525591, 0.03836565238556691, 0.03746307188911097, 0.06940801202186517, 0.012937655190138944, 0.057429460143404346, 0.04632237453811935, 0.030890917405486107, 0.062405510273362906, 0.06532531431210892, 0.03406318396862064, 0.035180340986698866, 0.05154303314962557, 0.050359542548124275, 0.019489798827895095, 0.022728214073660116, 0.04563800411831055, 0.02338009623677603, 0.015081584120967557, 0.00662126939278096, 0.026951382102976953, 0.04003040751974497, 0.021233964611643126, 0.03848158348617809, 0.037592773857925615, 0.046436714474111795, 0.017858505648161684, 0.014047176992919828, 0.019508027671171085, 0.04637929005548358, 0.033565481925117116, 0.01981007244570979, 0.01605937852790313, 0.031896014365234544, 0.07184309778468949, 0.03414477441193802, 0.016179684483047043, 0.03257200827023812, 0.054037958915744505, 0.025475851725786924, 0.01977594383060932, 0.06679565898541893, 0.030046270228922367, 0.05637574954224484, 0.026420723613617674, 0.02512897953524121, 0.06946450684751783, 0.031163240649870465, 0.08248262865734951, 0.008475754792535943, 0.02604049294521766, 0.07765515055507421, 0.018151429215712205, 0.024310461045908074, 0.053539144074810405, 0.050423955877444575, 0.05332985334098339, 0.027129702802215303, 0.045336239239467044, 0.04657736121277724, 0.04677217879465648, 0.04482014550428305, 0.033934862818568945, 0.041032447679234405, 0.0867752990286265, 0.08317084637071405, 0.0013671149000791566, 0.03557653079873749, 0.04238583666405507, 0.05384633044845291, 0.0319808278498905, 0.049862949909376245, 0.029823347726570706, 0.008573983762679356, 0.004000024154915341, 0.01793356010291193, 0.01676938569705401, 0.030427393170871904, 0.029881674596773725, 0.057999538124672005, 0.022057561935590844, 0.0322031803828265, 0.0508537331729063, 0.02033073441790683, 0.06852846778929234, 0.04076552218092339, 0.04750378203711339, 0.006511843746661076, 0.021277546915890913, 0.03719646530225873, 0.035158509122473855, 0.07198029078011002, 0.04741082273955856, 0.005704481221203293, 0.00923956639599055, 0.029464239853301218, 0.015979642181524208, 0.034559284669480154, 0.021881047835839645, 0.03903651317315442, 0.023567203964505876, 0.05693644338420459, 0.043961269448378255, 0.07132922964436667, 0.007198365122478987, 0.03674108009519322, 0.05836348395262446, 0.005703355277156723, 0.02597584212864084, 0.04338258085772395, 0.028839739970862865, 0.026027583816487874, 0.03173612776611533, 0.04955744969525507, 0.0492317698496793, 0.07723001443914004, 0.004048692927296672, 0.06196542603096791, 0.030630936713090966, 0.018030583825228468, 0.04463295465601342, 0.019988006379987513, 0.03476181719452143, 0.01801749149204365, 0.03461571164163096, 0.03636629806299295, 0.04628775228879281, 0.06831919401884079, 0.07783442629235131, 0.02034400656287159, 0.048206092922815254, 0.04830214973273022, 0.02548351068980992, 0.03372098518801587, 0.05021142513890352, 0.004628131299146584, 0.02985927615580814, 0.010626897398781563, 0.0393191671131977, 0.04431068105623126, 0.02740669097485287, 0.02795018904310252, 0.028951959484922032, 0.04055134938763721, 0.02465027816859739, 0.03295960443626557, 0.029168395192495415, 0.024451874529144595, 0.03330255299806595, 0.056381069256791046, 0.1023653738998941, 0.05339966780905213, 0.04109097471726792, 0.02641646411003811, 0.05172782537660428, 0.038873742800205946, 0.013270660669409802, 0.039463009751800976, 0.019148634813193764, 0.039744540716388395, 0.037531101810080666, 0.17265822951282772, 0.12111763230391911, 0.15788391658238002, 0.15010050923696586, 0.16311360310230935, 0.1263434783156429, 0.11684408304946763, 0.10282178369483777, 0.17530925225998673, 0.11600573946322713, 0.1459687195186104, 0.08510584503944431, 0.06694913682128702, 0.1602318241660084, 0.06890795206917183, 0.26559801240052494, 0.1419113650918007, 0.09239698879952941, 0.14509722271135875, 0.14163517419781002, 0.1401958250041519, 0.12314472853073052, 0.10770175326615572, 0.10043209192476102, 0.28933197313121384, 0.13001148934875215, 0.11232263781130314, 0.08622445751513753, 0.3181036763957569, 0.11495642576898847, 0.13581839203834534, 0.09736076423100062, 0.11447999919099466, 0.09820060737963233, 0.09159872627684049, 0.11743492420230593, 0.20577668238963398, 0.08790560944804124, 0.16340492532721587, 0.15422294874276432, 0.19956864336771624, 0.08175502877150263, 0.09118045014994484, 0.3007726435150419, 0.20288007067782537, 0.16503030168158667, 0.052132239033068926, 0.10091603667076145, 0.07884089050016233, 0.09667840906019722, 0.14978281914123467, 0.13863352526511463, 0.2598787492939404, 0.14261837143983158, 0.2192279470286199, 0.07554298639297485, 0.18774469569325447, 0.1356976670878274, 0.17334935814142227, 0.11548314536256449, 0.1184477869953428, 0.18513950120125497, 0.14158056569950922, 0.14350467388119015, 0.20005771783845766, 0.1240933747696025, 0.1620008870959282, 0.12120475620031357, 0.15413136008594716, 0.22723711654543877, 0.11950285466653959, 0.1316623921905245, 0.12061262583093983, 0.17045579983719758, 0.07342291729790823, 0.059483534922557216, 0.1314865294843912, 0.16859677673450538, 0.121428143499153, 0.20582166926137038, 0.19822686750973972, 0.0684608585600342, 0.10848229245415755, 0.1576401868036815, 0.19831138583166258, 0.150483691532697, 0.15307846372681005, 0.09947389191282646, 0.08203769288957119, 0.11595677637628146, 0.15201996266841888, 0.14325246241475853, 0.1273682697543076, 0.1395929737814835, 0.1599303646279233, 0.1331526315105813, 0.09730074102325098, 0.1724289118179253, 0.1422039493918419, 0.19257689639925957, 0.13348044534879072, 0.1253383101097175, 0.17931315169802733, 0.13246587264750684, 0.10864659970892326, 0.10329981161547558, 0.1546249400292124, 0.16995736158319882, 0.07515474901135479, 0.14957851224711963, 0.23526850129876817, 0.10784625408372708, 0.17658721868480953, 0.13282287706221851, 0.17156155407428741, 0.12829794415405818, 0.12730383606893675, 0.11898388394287654, 0.14618442580103874, 0.2092686542975051, 0.10550825311137096, 0.18551308901182242, 0.08838341345212289, 0.17257447115012578, 0.17475932676877293, 0.1381391039384263, 0.11116404605231114, 0.07938512308256966, 0.11735339143446513, 0.15179893667144434, 0.18318800734622137, 0.1346869891775506, 0.1986047572323254, 0.11983920447528362, 0.1269289454711335, 0.1006249315770609, 0.1517576953130109, 0.12713128461369447, 0.08120060459311519, 0.13362516329756804, 0.11923788674175739, 0.11260577011853456, 0.14030007512441703, 0.12243674509227276, 0.13054519785302027, 0.13148062622972898, 0.1301541852631739, 0.14140999556652137, 0.07585596067032643, 0.12581185969923223, 0.13519255204924516, 0.12891961793814385, 0.1349809712597302, 0.09763510272439037, 0.07632490300706454, 0.1356826578932149, 0.1143750569650105, 0.13809319425906452, 0.1231416208403451, 0.19160606206527778, 0.1636221922401871, 0.10094164458236524, 0.15759327289249214, 0.1854993961751461, 0.07338098383375577, 0.1537894598607506, 0.1361194308847189, 0.16582026572099753, 0.08122852630913258, 0.18785932739930494, 0.16207245896969522, 0.11454672632472855, 0.1275913313563381, 0.09109743139041321, 0.17823514954320022, 0.14395266984190258], [0.013260415638796985, 0.051930551284125874, 0.028815743579928364, 0.021016821531312804, 0.041071263274976184, 0.05682549612330539, 0.025908234595720257, 0.02201679046265781, 0.0784916417407138, 0.029233310637729507, 0.026226845802739263, 0.011050754476205578, 0.03306998172774911, 0.022984352561512163, 0.0063848389545455575, 0.038681781850755215, 0.012308669343058552, 0.047025947498955896, 0.05711620088134493, 0.026838938672361628, 0.025735742512292097, 0.04801310399281127, 0.04302653996273875, 0.01692258533356445, 0.008686327109379428, 0.009695664064825645, 0.05167947636385049, 0.02490571098003004, 0.05197811998160822, 0.017459559287609797, 0.023534152523747513, 0.013498064047390861, 0.08321478151317153, 0.07572709329958473, 0.044722911436110735, 0.046983681552644284, 0.059160212986171246, 0.0229846850436713, 0.04567567638254591, 0.04831288754940033, 0.04670960768791182, 0.040741525789988894, 0.08889776335230895, 0.018493690760806203, 0.052502630943698544, 0.05458539079076477, 0.036386867852083275, 0.033013514043497186, 0.053801781231803555, 0.04732134432664939, 0.01822720461391977, 0.07037939596921206, 0.030500342470726798, 0.005253848727859024, 0.030629640711205344, 0.08786087363426175, 0.06861751193978957, 0.061654697704528055, 0.04760245799220034, 0.029409370119018213, 0.05979180695222957, 0.05876382639897721, 0.05924329959920474, 0.07204614938902003, 0.04938172948147569, 0.0354718532014106, 0.009035770099477043, 0.027676261063399057, 0.041741279286465476, 0.008897218337681676, 0.033657857682555914, 0.0266082198026457, 0.051590710412710905, 0.04700773561905537, 0.059200429756726534, 0.03732487466186285, 0.020040341785975864, 0.06830383877136878, 0.030562343608055795, 0.057491485029459, 0.04947174732972469, 0.060120245042656145, 0.015328392752313187, 0.024281533401725546, 0.03057293893237199, 0.045990387709545236, 0.037647324680749855, 0.04927497556699174, 0.09432672203651496, 0.048864716331341436, 0.058962040048624785, 0.05368077129657779, 0.03297506146399038, 0.02762394940613636, 0.03207278630829283, 0.008368327432045979, 0.011759557245698358, 0.019854854060603038, 0.020431954879313707, 0.02140131509596748, 0.03550215657534344, 0.0070049962128645605, 0.041520958965910335, 0.04953971957521779, 0.04177964026374476, 0.047982634377798865, 0.0029562239817875835, 0.026304137726713504, 0.037588658543037515, 0.03289993406672563, 0.058689940720796585, 0.059414595764662535, 0.04063240718096495, 0.026225588816617216, 0.023376474556113993, 0.010769964811126036, 0.03295921427862985, 0.03492648407284703, 0.05133449558966926, 0.018853355032790984, 0.007520653141130294, 0.025491419015452266, 0.02401158333356891, 0.05620842959199633, 0.0902747619631035, 0.03638656929667507, 0.025401467324367592, 0.019399575722802962, 0.06782798894814082, 0.027739178223003234, 0.01848584011064044, 0.022344855358824134, 0.07967565820685454, 0.030142652735646282, 0.04247069764616234, 0.061640462039836814, 0.017502485109227042, 0.025799828448465893, 0.02578649014633681, 0.02378639791693006, 0.0344886729227645, 0.06224450069878783, 0.054060055408626795, 0.027553592110052705, 0.009562574509930397, 0.029418394634766237, 0.029105779980974536, 0.02708795084618032, 0.04149225354194641, 0.08713152312806674, 0.006583771427228514, 0.038723162308867486, 0.05349474413586514, 0.04542733256572059, 0.05303030048630067, 0.005536632861809007, 0.03459369318027582, 0.039633305078106265, 0.030092508997768164, 0.020706215341176306, 0.006462330198181527, 0.05513215430879167, 0.04806484228798321, 0.12267226459724562, 0.019414478048150028, 0.03287130667428885, 0.025996569677123, 0.08258174905287367, 0.027931692178494165, 0.04013021323563797, 0.028347337285854986, 0.026985895786700503, 0.008497280467833792, 0.03043741174042225, 0.03920627584947007, 0.006753739784471691, 0.029475683346390724, 0.019294133077242544, 0.017369707680440376, 0.02459630579687655, 0.011106710714687194, 0.019412289772714888, 0.005301020906439849, 0.010659645195119083, 0.032822899986058474, 0.00368894002167508, 0.024388628280056373, 0.005989064745205853, 0.027667428233793805, 0.05151423951610923, 0.034900564035134654, 0.04578062200120517, 0.02553343560014452, 0.07336041065199034, 0.10344321999166693, 0.03648598485493234, 0.010229700810409017, 0.029414062188672166, 0.02421544578724674, 0.007511357211374811, 0.06193168926984072, 0.04816074642751898, 0.05823939346841403, 0.04578418770272817, 0.020157153285773735, 0.03462036299918379, 0.029954294807144573, 0.017807773281154887, 0.060731801869613786, 0.08444673647837979, 0.021438760050971593, 0.02148779608043177, 0.018612110388598273, 0.012641729953299676, 0.04733285228056567, 0.049551712681672404, 0.022214742876323204, 0.03869361889415553, 0.05286837149677532, 0.0029309419790349367, 0.019642672767596583, 0.05018796818330884, 0.03793763588847859, 0.03127433040312358, 0.038313506969383786, 0.01817090486708496, 0.05179300884317074, 0.0556498867060457, 0.025007452217063735, 0.010287301648142082, 0.0020968875822810723, 0.011675849773122795, 0.06900839560798236, 0.05806815837110792, 0.04821130407175847, 0.08922670355864934, 0.0280123750812241, 0.037962921495948515, 0.03484652889892459, 0.019707564464105026, 0.046179129010332484, 0.02334013900586537, 0.06057459209114313, 0.05502402636089495, 0.04692151078156062, 0.015839887716408287, 0.0565388795387532, 0.013378884460377907, 0.07991192410034792, 0.03693183325231075, 0.05093875700341804, 0.0793107081470745, 0.018608157922114645, 0.057635056254054816, 0.03447709711534636, 0.056636968561049016, 0.042169251678777595, 0.039620304347148964, 0.05701073618339641, 0.013619390349569065, 0.045390976659421406, 0.012214117184547442, 0.03832502170865025, 0.029371836954461675, 0.037636142423642535, 0.014752370804282171, 0.017482478504202197, 0.04949351812579802, 0.029755182098597288, 0.04399562706904752, 0.06704657444996492, 0.11426376365125179, 0.055257693465266905, 0.021070481776925068, 0.04895805221583162, 0.013356836313115699, 0.012627107523647802, 0.01269298988128347, 0.00560455845801958, 0.01892804477496871, 0.05614908491926534, 0.039712605465735705, 0.06023130765450852, 0.05502297802429114, 0.034903542803866525, 0.017509787842365246, 0.06746920677168028, 0.06401751948786633, 0.020276631428194896, 0.10425364864724022, 0.050734070129692554, 0.01773623703047633, 0.07164472128663744, 0.013118181976356676, 0.05434955915968333, 0.04865291501794543, 0.03976710539843355, 0.0366856132500938, 0.023139815112309794, 0.027939870221806423, 0.025146487435059886, 0.041962101722934415, 0.0005967590914224274, 0.03112234195162143, 0.07488117047718593, 0.06507738440164498, 0.02402998011426202, 0.021680159061881046, 0.04338748327323368, 0.03274138757426824, 0.02558719253699694, 0.014897158302898918, 0.06755526536809546, 0.02909148664080671, 0.028751733978944163, 0.03758462465235165, 0.06285915164543049, 0.06490790671003716, 0.02286773274785706, 0.04638817547155278, 0.031025060385997807, 0.0376301339960524, 0.009037836238608828, 0.024844120356387327, 0.014962553811658705, 0.07126862968185119, 0.03536513660635267, 0.005145862424147448, 0.006018699338060937, 0.026437539407717328, 0.01334065240475216, 0.025245020897792916, 0.012734352527851505, 0.014849525144589799, 0.0430968972588224, 0.01956350978330842, 0.015406721138528414, 0.012373521175634648, 0.052224092318543365, 0.030769351071545055, 0.014425483166373201, 0.027330311680478708, 0.060149958091122765, 0.016453751562429324, 0.022384600547541465, 0.01240948777246688, 0.03376264723816088, 0.04477078208167638, 0.04042847008843507, 0.040124248912824054, 0.06728868931531906, 0.019787918277350918, 0.1480457694934947, 0.11203998726393495, 0.06101591805262225, 0.16996502902890953, 0.12114476013396468, 0.1443555567945753, 0.20787750823157175, 0.05022173547851188, 0.14174387550779752, 0.077229831234685, 0.12211402026670319, 0.06815950080220189, 0.187599937032376, 0.10145998426846095, 0.14026796684733459, 0.12308181476380144, 0.07750465148793799, 0.17221180775335856, 0.16137417858200415, 0.09465570974030665, 0.0849904330181224, 0.1279329601675272, 0.1337061668080943, 0.14129505173436233, 0.1263548234211547, 0.15078474394977093, 0.20879826668117726, 0.0924632138173495, 0.1056890691231404, 0.09102944218154464, 0.11916811977113996, 0.06561434308865241, 0.14939423570675509, 0.2024167805377926, 0.15139516762324742, 0.1351238571639572, 0.12493349611759186, 0.11446093235697065, 0.13472539425960608, 0.12237974815070629, 0.1068589517048427, 0.1310683483523982, 0.12459143304399081, 0.12361492615725313, 0.09744560824973242, 0.19471695513597556, 0.13147480439926895, 0.09423173391925437, 0.13145944236644677, 0.10692701555256333, 0.1404228356799909, 0.3188712623502527, 0.11113682322736297, 0.11389584839344025, 0.09756403975188732, 0.09956427956266062, 0.08291636181196996, 0.1049318579690797, 0.19217286950775556, 0.22827538368957384, 0.12840405346027442, 0.23575837644083159, 0.17169232134308132, 0.13954515063336917, 0.16766418463417462, 0.09980313067457505, 0.12698044627904892, 0.2642242232603686, 0.15268532053700515, 0.10574295837432146, 0.1034288757613727, 0.07943662389048509, 0.28206521591969896, 0.11791935749351978, 0.1502797103353909, 0.18332245227481636, 0.11295080517551728, 0.20686313909079346, 0.10435814982546227, 0.1846248052482094, 0.12459436431527138, 0.14058933460286685, 0.06831034592219762, 0.07070718266602073, 0.13090122517730507, 0.11314538187746491, 0.08147778614823308, 0.11171893841986145, 0.19241360016167164, 0.11792665853032044, 0.0879221453464457, 0.07770702455724988, 0.11795595767242567, 0.14859413435416563, 0.136192278404321, 0.17375459282525949, 0.14281499731753552, 0.13671731523105077, 0.1282037634934698, 0.12843371901128972, 0.08448510763368436, 0.08551887609064579, 0.10230220907500812, 0.0981269795447588, 0.13186542343880447, 0.10302140191197395, 0.13198772259056568, 0.0864286015608481, 0.1032913706398436, 0.06579540337302855, 0.12004021368920803, 0.15972991181271418, 0.12887174050722802, 0.2544002304119723, 0.1257225644907781, 0.07762891160590307, 0.1306944348450218, 0.10223262530884572, 0.1618504287408931, 0.0642930454175387, 0.1607767827808857, 0.09275231044739485, 0.11126792976366622, 0.13766746781766415, 0.23782617119806154, 0.13337847510618822, 0.10338316285716635, 0.1893182455429009, 0.17427211148398264, 0.12831155556653226, 0.08158111346087285, 0.1510491690465382, 0.31480949744582176, 0.2029451286154134, 0.08706569844590765, 0.11433963743703705, 0.23810874032122747, 0.1451724993863276, 0.105839982096638, 0.10318201793623821, 0.1619393303990364, 0.16347078393612588, 0.1415170141096626, 0.1016418452241591, 0.12040576764515468, 0.14844887357737335, 0.07135954658899989, 0.17096548820180552, 0.05142350920609065, 0.2231492551841906, 0.15842883448515618, 0.11097366269677877, 0.15217008175594465, 0.07797041149543864, 0.10799867340496608, 0.07110234110483102, 0.12408736294933728, 0.08064025001866476, 0.17405025767428534, 0.07343978567847184, 0.1753542119903224, 0.08205431699752808, 0.12843768165579864, 0.16791246059749806, 0.1403005365282297, 0.06764513733131544, 0.1502912997135094, 0.12880692684224673, 0.14041382473494324, 0.1396552361547947, 0.10253780321883303, 0.10193685189421688, 0.08251012968165533, 0.10257284276719604, 0.25251615579639164, 0.1614114437252283], [0.013415083455454026, 0.07537783775478601, 0.06974898265408618, 0.01676463255924838, 0.030392597895115614, 0.017147338184128915, 0.025623290599989038, 0.07419924278344427, 0.044234345866633315, 0.054093110242060254, 0.030039437381284576, 0.014514630793460777, 0.02316319234003978, 0.041905905452689955, 0.0625525623826044, 0.04521676618605852, 0.04771147821364658, 0.02695891384168395, 0.019772800517135432, 0.03917119898168104, 0.024010745342820883, 0.06426140532961913, 0.02308918282921825, 0.023480851901695132, 0.022820184406425272, 0.034507407274629386, 0.012047596209283386, 0.06275029427238873, 0.02431958055655871, 0.03520405239292553, 0.0187436274385878, 0.04775472803573523, 0.03272963534774525, 0.03676303070304649, 0.023991515660392385, 0.07173641850905758, 0.027543836472822086, 0.026980764365621974, 0.01199553391364004, 0.01480075713646199, 0.04249000196744289, 0.01584256114438176, 0.04560408415272832, 0.06900512506919247, 0.02077038779056498, 0.012967436092107423, 0.008285057614557445, 0.029283098144722835, 0.04861162616206067, 0.016062384438035742, 0.021146647332768356, 0.018960577136437808, 0.065817469331835, 0.04944029383893524, 0.010270193235815635, 0.03377535280638507, 0.015412919555923768, 0.03776697415326323, 0.03415895240115268, 0.032555251847952604, 0.04995381931907364, 0.022950139129534364, 0.024957113400367752, 0.02769745171203145, 0.04324245319834777, 0.033271828932421546, 0.013336211393055106, 0.02880440865244184, 0.07126724547041313, 0.016032070886077623, 0.0609301444409149, 0.026503420069015453, 0.045911911741963456, 0.06465308966913394, 0.10121397461209979, 0.09280208099101271, 0.03491107454257352, 0.036925984280450005, 0.016394954806725894, 0.04611654433288744, 0.07046786336494343, 0.013167048372062189, 0.11376541360680546, 0.0662565425570522, 0.010262179737245398, 0.05182698987690466, 0.046014411241880486, 0.02591585454397968, 0.045834518037736416, 0.0724796654124345, 0.03823591649000134, 0.01499598183935242, 0.11192201716559273, 0.04388578921290381, 0.01863328746653029, 0.022095863541056002, 0.024133516076420034, 0.06889934824513537, 0.052519879303872585, 0.058483632148376534, 0.005236308597626963, 0.0385027164593339, 0.04302736438278641, 0.02832721872255206, 0.022147615406928316, 0.0338517490641347, 0.018276931052761416, 0.03584828068103109, 0.019109683510448252, 0.04550365757729326, 0.04621575293796403, 0.03195606471438493, 0.03654324642515608, 0.020248953984784226, 0.04404796586771097, 0.05471061782113143, 0.0707884304491537, 0.06526248196938209, 0.026738116850278208, 0.04179917528693165, 0.04971837106027773, 0.037930073615695746, 0.010520676982456019, 0.03577254938759974, 0.034011357463896275, 0.01832326820918492, 0.0538470938003489, 0.05699251073279551, 0.023209176658253585, 0.037116482986935546, 0.02989987629864897, 0.02492845886653023, 0.02588412963918277, 0.04714068437793425, 0.029126058000006845, 0.028775642160326242, 0.031124964489468505, 0.030091905101601566, 0.03802166227251291, 0.047529254241713455, 0.02229545122411634, 0.06964762987835066, 0.006753233427714024, 0.015458250784182122, 0.0020298504428605414, 0.02802563874450113, 0.061595861933061054, 0.07232168210404259, 0.030312242385532175, 0.06287162990442344, 0.023138062795624137, 0.028053926869428585, 0.0543905392821346, 0.06693294697574206, 0.040933483346764526, 0.01504698901304177, 0.05615988719676222, 0.08061410606439624, 0.08221154713204928, 0.010739093164115079, 0.023442219510408382, 0.023981298619349087, 0.027309853849666457, 0.04317735115598355, 0.04402073286473751, 0.009806597755024475, 0.05026699037158063, 0.029446204392505542, 0.031040347779967954, 0.04609157424420118, 0.0341061759474022, 0.037140574372772656, 0.07056990146104779, 0.011029590968973935, 0.027987079295728887, 0.0045678956251192305, 0.047752281916993, 0.04024733177253178, 0.03308197483420372, 0.0021237592653570963, 0.01792551437392831, 0.06439854404223816, 0.07832166871854238, 0.005701291682531259, 0.03183303953015378, 0.07004130232547011, 0.010174138970406992, 0.02701910668318825, 0.020737458486109972, 0.09464019164443016, 0.03439797993217196, 0.044576972124299834, 0.028018573498619453, 0.016436491327892457, 0.03674450669703739, 0.040200499285544665, 0.03591224278456398, 0.017234473954886198, 0.011430167509908122, 0.018873103794508746, 0.008404243138751813, 0.020813339057245424, 0.0389857180416584, 0.02609010742578123, 0.06204577136252608, 0.03017891025436776, 0.012499395358775343, 0.0515045636067433, 0.03676772616537554, 0.009786365537105926, 0.02502519590780139, 0.03281105276463287, 0.026616274013317058, 0.042462395770209174, 0.0040488239693721485, 0.02287886750751308, 0.022040235543889657, 0.053707281659756384, 0.07818874370838914, 0.03207813316423978, 0.020934786647558212, 0.03744211194238492, 0.019834995036944747, 0.05778884621603148, 0.08757951230342899, 0.07533127668180636, 0.022005145105400255, 0.01514735960933779, 0.06550371473921196, 0.05024622720000999, 0.03039105762062328, 0.024458385072648525, 0.018671658621834855, 0.10216237657836505, 0.047723980221365175, 0.030293097519981008, 0.02428810840605625, 0.021691195433959365, 0.014105486051578606, 0.01740397369888212, 0.05821067786642483, 0.025670379233945693, 0.01429064299112984, 0.025572649835209762, 0.03207333931433303, 0.008214840266321386, 0.01455049476187144, 0.028905663040599654, 0.0333432413504592, 0.011099433426612189, 0.0015440301836601325, 0.005752750506092395, 0.0036746216605284382, 0.029056345312190906, 0.030855029688349793, 0.03653809634436454, 0.01039162979993437, 0.020793554672439183, 0.010575090401938983, 0.015650998834254484, 0.049526739200311046, 0.04132119147107005, 0.030982248218996183, 0.006809118420018682, 0.07247005735657044, 0.04141590817432318, 0.020464589021035602, 0.06987037935427257, 0.10727190811719213, 0.015110238654805081, 0.006404384579842112, 0.02825179785889174, 0.09637753306222813, 0.050910984565104754, 0.02526005044845598, 0.06697220701192107, 0.03164910225729857, 0.03683189182941403, 0.05208145407959819, 0.0344326462862747, 0.04750509839504957, 0.007787764388402658, 0.08436769393405744, 0.01486519760718303, 0.024688396569607512, 0.018819552114499465, 0.013600751840775567, 0.07356944693518536, 0.06274143939039536, 0.029597806079047065, 0.03392000968701073, 0.032795419317803214, 0.026245690416544676, 0.07444464175828866, 0.0385994043068162, 0.02354203031531402, 0.0321747633362455, 0.011956136474119765, 0.01548275098736797, 0.021306352423770086, 0.011415628200796033, 0.10455537959933281, 0.01447434108039098, 0.025754198664799333, 0.005239207214409751, 0.025905669733349766, 0.02540575566568545, 0.07690088424299445, 0.024973895267716477, 0.02363193959796003, 0.06235846744052001, 0.028316277345376353, 0.022709374548867345, 0.021632376625867825, 0.028358492401561568, 0.0266560887518738, 0.018528280779719353, 0.03399953059852123, 0.007866916346496769, 0.0391830665591572, 0.01712253942553486, 0.02909975459000894, 0.031306001025119, 0.00569652539810964, 0.017602251809356467, 0.017136354398514544, 0.042777995978082926, 0.02560679371734815, 0.11775661765464715, 0.027317592541554143, 0.07258653467787163, 0.017028199309217076, 0.08983605514679636, 0.018485661995198046, 0.030857479199767113, 0.013265351981057652, 0.027878886887005398, 0.028428708901628852, 0.017546362576207945, 0.03933999813827021, 0.04114052473700472, 0.005042821792553046, 0.024670076124104004, 0.04000625506575618, 0.0470472806399422, 0.05243974431817021, 0.027192026243678162, 0.06052439407046352, 0.05884951180113213, 0.026386696778770004, 0.04199257812329701, 0.002702527795918286, 0.14478512374418123, 0.10698416855718408, 0.14166547757174286, 0.10681225492485932, 0.14016059546598367, 0.13294862317187445, 0.13398414903453418, 0.10904892347753048, 0.16366093658975192, 0.11267939116805792, 0.11882665380835533, 0.06944588106125593, 0.09247470141521522, 0.2685530866895403, 0.2093859322901283, 0.13889321418745176, 0.1237306028072323, 0.1434616276196071, 0.14334092981048993, 0.14840988495520183, 0.1440291271678039, 0.10864434697266136, 0.12776741119367735, 0.07962125326905932, 0.12166472151875496, 0.13841362563627108, 0.14415606749909265, 0.08116110028432948, 0.13732507904725416, 0.10596120237771954, 0.08480637360896383, 0.14191378067646707, 0.09662465551601988, 0.1192648381526981, 0.284844061093671, 0.10372146684676409, 0.22692439332604408, 0.20600680075585842, 0.11154673301747867, 0.13083440304866858, 0.10467873726572309, 0.19177492229001863, 0.11971644391970974, 0.12265687542302267, 0.174058359382408, 0.09971441900623695, 0.12105359216885907, 0.15029645657965116, 0.15279209480753966, 0.18091431792293275, 0.10964376798697881, 0.08228537174207823, 0.13728872314095497, 0.1241650144968714, 0.17593433228986605, 0.1461513675749302, 0.09419418379132237, 0.1802414283156395, 0.1307634147150176, 0.05446853009717805, 0.13909919027771267, 0.11326050891407899, 0.08293181205434458, 0.12597427384129592, 0.1124545382335782, 0.06576480822903769, 0.10659308811383587, 0.179438232843365, 0.15470894266452107, 0.0673601051260318, 0.12316268256732396, 0.07683149046663727, 0.08532961910324437, 0.10608718597463199, 0.14385916771633284, 0.10998833485479866, 0.06864789673792464, 0.12215060687490872, 0.07410026488027402, 0.16092885604926518, 0.19642656482756138, 0.0862867266737989, 0.1465505768678018, 0.10543940216302872, 0.23399771377444267, 0.13635466540498392, 0.10685838852077723, 0.16805404371448926, 0.22556591193590844, 0.1640572960355452, 0.10464924813381263, 0.13343019304530962, 0.3295953726129872, 0.13355161010154656, 0.14145192903067383, 0.11862689309886523, 0.13647106130208286, 0.16712267297719205, 0.11791821755468845, 0.19614643843046256, 0.11582718975841999, 0.14003634213336877, 0.13474254762487753, 0.12790657872600214, 0.20006774658603327, 0.21455193151320728, 0.13365675588803633, 0.12039083987474442, 0.08528180952583041, 0.1623251996934414, 0.10389024564730269, 0.14206053423030035, 0.1230738487626825, 0.07441990915685892, 0.09122764226049185, 0.0786035457359893, 0.1460854953953198, 0.2371821328997612, 0.10355174488254956, 0.15102092841906206, 0.18931498857481138, 0.13405699655413628, 0.17119039541908673, 0.1441620657486575, 0.08397977546389614, 0.19132980331778526, 0.12452695864651885, 0.13915009397481168, 0.09339289500245027, 0.09578094471778188, 0.1458352923925434, 0.11509055857147489, 0.0672530730121902, 0.15658338208283695, 0.11060511640139989, 0.10626937262713909, 0.19339225121906825, 0.16439471792961868, 0.15649859234690666, 0.08761336441550936, 0.15606666409543582, 0.13618914357253484, 0.1310113106987306, 0.16166596221072332, 0.036489828755812984, 0.15148937542523655, 0.11162274251026766, 0.13078569780503, 0.12151818509612765, 0.16231044834213598, 0.10510010072695357, 0.07954025654388325, 0.14317593723535538, 0.13217251481754438, 0.18190284845020088, 0.0778856421155589, 0.15929038396903447, 0.10373370761850051, 0.16887070132153376, 0.07219410394983632, 0.06040969451091119, 0.08150907339794294, 0.16321808392448084, 0.17671447114220687, 0.10818609156246696, 0.05914791114628315, 0.14286679668085916, 0.10946776957384177, 0.14823033101856709, 0.11351962786700044, 0.10793750347303492, 0.11505082356078283, 0.19180097803473473, 0.12903469747730664, 0.05397131659888795, 0.10837344865181617]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.030708052217960358, 0.029949684161692858, 0.07666267095399754, 0.015407961161274995, 0.027482620739777173, 0.08058057286377464, 0.05489892825218184, 0.06390653151486601, 0.022027088927903345, 0.03685671942574637, 0.03155981383419462, 0.06592340221894638, 0.011820700884397541, 0.03517954031537686, 0.06954441113131386, 0.06716734011258398, 0.044805594320808134, 0.03473454008677176, 0.035623804333486726, 0.06206397645707641, 0.026541034657774226, 0.02598942131070154, 0.019013725088110993, 0.06507391708769969, 0.01312761870212853, 0.02885138363178287, 0.012926210000711893, 0.016289876873738, 0.015874440415895412, 0.006248041205773396, 0.0030728936253581196, 0.01699807065805154, 0.06550104131123849, 0.06373090629598924, 0.03381787320332868, 0.017876150951321636, 0.06503659087632384, 0.023612803214096596, 0.033918567800096104, 0.033165699270154746, 0.030156661091106277, 0.054361318171556504, 0.028282201316739832, 0.0409178329365594, 0.04880108670996768, 0.03940797038376331, 0.01154075175457235, 0.048321915457823446, 0.01947435367453311, 0.032999614253640175, 0.006798349645188344, 0.050509033990757804, 0.014857294370553322, 0.009349899582697876, 0.03882448115785207, 0.03849253843405417, 0.07040677485721451, 0.04307612730190158, 0.010535481768394155, 0.03222377731331757, 0.06818985167358603, 0.05002949972237859, 0.030902086091893058, 0.05009318362655384, 0.018535164517483542, 0.11930571310222149, 0.03332649849887405, 0.056553043957267485, 0.050215625270668945, 0.023914523988163898, 0.009796615656731384, 0.03075063707573073, 0.02779098437167704, 0.06027909009052174, 0.08307733067444392, 0.05026668163814715, 0.02908080649961318, 0.04661781547058906, 0.057775004101651053, 0.02670117570752544, 0.011674072011373937, 0.06239154602267912, 0.022283685426892977, 0.02840897540694901, 0.025953146828604595, 0.04450701855655227, 0.010550543549470603, 0.025014799054978148, 0.05762131591992719, 0.016190658090636134, 0.004635518000993345, 0.015236186628629054, 0.04212724018309798, 0.02812975994311273, 0.04219201992132834, 0.03196075678403888, 0.015586570237896271, 0.08125533522771937, 0.022314456989988685, 0.027503806299396923, 0.03224586702084967, 0.026883286024842943, 0.03490123917747821, 0.023645328790215508, 0.02281572134234011, 0.030388092422591786, 0.09053667648030178, 0.04989409466673221, 0.031164580756532292, 0.015277266834995576, 0.02410404390788504, 0.011597449292561837, 0.026307851009603058, 0.04767624528280326, 0.06818395520427398, 0.046852751435445886, 0.07533547681357179, 0.023797178142038838, 0.02054942286174212, 0.027028955618983934, 0.09748230342354093, 0.03412297986713903, 0.035186251026711295, 0.03378063180883016, 0.02739790564269892, 0.019572463052879487, 0.007454520573706499, 0.04597782802635005, 0.044712886081210206, 0.024885015661961267, 0.030768485939396278, 0.015584212328706468, 0.02105392891514514, 0.05384963830666883, 0.06676611557070698, 0.026142592109473686, 0.016199334857187102, 0.02869243680366448, 0.04871218505182436, 0.01983079660151686, 0.02814690991570907, 0.012729165127633937, 0.10786348887320076, 0.02481845985831959, 0.012360914843156934, 0.013986797554285398, 0.008919939930949892, 0.021879968965159993, 0.1369673960975238, 0.06595711862402302, 0.022376130734171187, 0.005425281024404934, 0.03678596179400172, 0.04734600907457726, 0.024297217738681605, 0.012518497815887843, 0.02987610043159553, 0.037486067440892966, 0.05990044040871518, 0.02842189641004162, 0.0028992066841705567, 0.044079578814229796, 0.013199813131775175, 0.01339719642419368, 0.038840776176324913, 0.04022342019847461, 0.036383403930813074, 0.03367364040708967, 0.04211153888276645, 0.0400268282475216, 0.10717130851532732, 0.012182978364372892, 0.009442406806296535, 0.028813046403229237, 0.01900429175501423, 0.054704606000866206, 0.01548129044074033, 0.014302110232945, 0.04282920162326523, 0.00593353174294212, 0.013514700029710574, 0.06455685304743902, 0.03442069389192121, 0.07505138777196407, 0.048128644935786724, 0.013921262945846787, 0.01600633405282029, 0.028398595517501235, 0.06980351651353495, 0.10148835381759064, 0.037994894066027234, 0.040979376062750816, 0.04107993155983942, 0.04204183637297579, 0.045306159782090356, 0.019611285433971455, 0.03589236170851758, 0.012238587701826223, 0.015110845943646771, 0.02105837331951729, 0.017301411434475864, 0.007180348321396325, 0.020172459339456897, 0.007835221975775701, 0.04614138549992016, 0.012165528988199574, 0.07047657575458288, 0.029366697051695416, 0.022670587790863853, 0.04832712660676666, 0.049623080994933844, 0.05211209672104035, 0.021405464337606515, 0.004942425751193825, 0.07451519582952772, 0.053938027670873065, 0.022808444054265107, 0.06173245103231498, 0.008215190560024763, 0.06517560234559433, 0.0506361032437001, 0.013951528152184827, 0.011605100623065872, 0.0285216359687703, 0.02206243890603738, 0.01821612244072769, 0.05803415698132344, 0.06384720719818558, 0.020530985368947898, 0.04674014176375099, 0.037621737125196626, 0.031681736399020465, 0.09714436584285327, 0.03903960729283946, 0.02846689854881593, 0.05338469932654074, 0.04612682413841997, 0.06288553308695555, 0.026862621240850006, 0.09019296456660543, 0.05994187854230404, 0.03313786576368979, 0.04260962090588041, 0.045531901597444496, 0.019711896910199096, 0.025463728001341224, 0.0667300107223647, 0.016126517871660844, 0.030339536456657306, 0.030822588929108212, 0.02489377894172711, 0.05038761693452086, 0.031149619059371095, 0.024171093345752785, 0.020033076372263686, 0.023593658348545432, 0.03688418652330126, 0.061854105575808456, 0.024708240326227884, 0.03108131093904376, 0.054887586539345126, 0.012761303090623446, 0.059898072321500094, 0.00565004871792293, 0.00675114566027852, 0.019492078705557754, 0.014527290560571211, 0.05177123126174722, 0.02210021125418799, 0.036129431666008065, 0.021168380809415663, 0.06729511504194566, 0.00547577123922695, 0.029675450841231004, 0.04902482684701681, 0.016786997073463032, 0.035032060729073625, 0.06390680292887346, 0.010295226088991123, 0.017048618124265755, 0.04019128477999142, 0.02512134431994387, 0.0699666024052671, 0.03828345126073275, 0.017272151308134198, 0.010996318156165736, 0.043022913193064075, 0.03542918352676289, 0.026531832026583806, 0.04074473865330219, 0.0636788694454091, 0.051213696000299284, 0.03476704530684011, 0.02241052906694157, 0.0019195113189718021, 0.06062598433345556, 0.020807554546211447, 0.014152937701770237, 0.06789793912321329, 0.063236926017063, 0.03814229562080332, 0.07727021763899497, 0.05390589903774006, 0.009054690200303282, 0.022080771225903715, 0.028738485582705055, 0.01387925908368613, 0.027768641909850494, 0.003397936496185139, 0.02286806353367865, 0.032923489409898005, 0.06955538304256541, 0.02542009819964213, 0.0167105787633253, 0.009142054128460586, 0.05558849285755839, 0.12139188258775643, 0.03521779951240335, 0.0285873520853264, 0.08216409039284502, 0.017737395629020672, 0.0332070899062923, 0.03418970700087292, 0.016201114315273504, 0.07588625725890909, 0.03818756408457245, 0.08034902957401105, 0.034776069822588136, 0.029616095990474735, 0.008130732458084822, 0.06308769581041165, 0.023433608901021735, 0.0756941232830286, 0.05997080449014902, 0.032489735899227004, 0.057015967688390186, 0.046141544955649545, 0.04063204077205487, 0.01278646316911493, 0.01691347939361419, 0.02770363655872643, 0.012133992376870342, 0.03822531098765986, 0.015794242665703808, 0.01895419042557478, 0.0408293791115284, 0.007614981383085251, 0.050656696781516075, 0.03993684093334845, 0.02115231649284916, 0.06106988872800555, 0.05902325747800725, 0.09578584374061652, 0.13270246423780918, 0.12253187570188727, 0.137009573834283, 0.14294492320290633, 0.112747326094125, 0.1410431388233389, 0.13239477574825287, 0.09875540475228003, 0.1461516661303384, 0.13136089194033826, 0.12566590681672096, 0.16489566676318645, 0.18946056147771223, 0.16387635788747243, 0.13241465682429926, 0.09387582194592271, 0.10286326932587794, 0.1282866397606475, 0.15378913416394166, 0.09369280748069286, 0.08324089154068913, 0.13811583018728665, 0.17842147525932106, 0.13229041706238473, 0.12285237493259565, 0.05984488196138825, 0.10392947854208094, 0.06775662063487939, 0.1319469562066453, 0.12731629397187913, 0.1359183131051915, 0.18170867886926445, 0.19843843472855432, 0.17972411321742193, 0.1127684081771544, 0.11667695987437453, 0.10349761135876179, 0.18006271576242788, 0.15546004021806376, 0.10049662739038467, 0.13295456713863782, 0.1292449619088854, 0.1297535239053624, 0.12747778530631745, 0.15905474232775824, 0.07623012523565974, 0.10933920754385845, 0.07588888997478144, 0.12234366365841456, 0.10918418264814786, 0.10735283698886633, 0.06112490434731756, 0.09177067383591618, 0.11451791572783675, 0.12073329649865627, 0.15100627206265926, 0.08217250422707625, 0.1719632332346269, 0.10256813373416662, 0.1082454090937972, 0.17500123807362147, 0.1037798479997686, 0.16784768764461788, 0.17839769939226763, 0.2973117620817253, 0.13852775522640773, 0.1578179629785674, 0.15510303580335208, 0.15314725360700063, 0.16031392690326485, 0.11926080765468733, 0.10060417519084044, 0.2183029952325991, 0.14408602911446775, 0.12537904935223715, 0.07997346722653934, 0.1659154234720128, 0.18661409350378172, 0.08894674000995499, 0.1147138359291213, 0.11900748339082513, 0.11370593322707073, 0.16028373209493502, 0.08246574670608554, 0.14794678480497428, 0.07086402603558131, 0.148775384628347, 0.11541770744536604, 0.13910050663564885, 0.12003652245870658, 0.14082534265305313, 0.07111561324979578, 0.07491688856056758, 0.1489556035293, 0.0788668105378747, 0.0768848911726049, 0.13184052120362008, 0.10019170732370444, 0.13190480561128684, 0.12651640975049563, 0.12654417540345872, 0.11133289270635162, 0.10172119310923985, 0.15055491056825432, 0.1484837502773319, 0.1362935836826052, 0.1261726910514491, 0.10613819145198379, 0.1637360504163163, 0.17196074979645865, 0.10444937885871955, 0.17497288888054235, 0.12943565739052637, 0.17718747790370667, 0.19899108793054307, 0.19283776597252913, 0.13075297884643078, 0.13068270975989954, 0.16446642551038945, 0.19491261749395303, 0.11987302266061306, 0.19216057445321763, 0.09934030193835497, 0.07139351405203342, 0.19695586285420827, 0.106776767543384, 0.18759952991136483, 0.21259061247110367, 0.12740552132683142, 0.0880158713885716, 0.13216913571315153, 0.07847408125443117, 0.11361988820135593, 0.1017119311062353, 0.17490768166525023, 0.10488425873752151, 0.1179294405238969, 0.1614841012550252, 0.10222727845289878, 0.16249923035502434, 0.15120120160281658, 0.14804686872022493, 0.13328238097684725, 0.07924580627254077, 0.07830305650298085, 0.1086582772965942, 0.0847526675622378, 0.2941586912742683, 0.1484865594123091, 0.12786616518029145, 0.10158824095768587, 0.08286024696592774, 0.09605702704616956, 0.09354366548359394, 0.1202961163861411, 0.15140168155942643, 0.12361398977892739, 0.15587291520621094, 0.10430249638323273, 0.12315140531531402, 0.1470785585365125, 0.08556872805846588, 0.06344610479261194, 0.12359332160225936, 0.10440295349274363, 0.10919402819126844, 0.07862709768648658, 0.10297019965946674, 0.14883299225143024, 0.11860313080251217, 0.12102692574262619, 0.17897879678223813, 0.16303786502352782, 0.1008052115461656, 0.2159395899091448], [0.07545702279146228, 0.023760642423959713, 0.017881981263469373, 0.04749576175319297, 0.021516910321744423, 0.024607813750792826, 0.02927671991554754, 0.0998213289837752, 0.020103175825040256, 0.09289946433688913, 0.009875732839905789, 0.019693160861996666, 0.017977444355243018, 0.038094604787017615, 0.03402143031624811, 0.018093012439619218, 0.024446587045011774, 0.04272888022075806, 0.03553542175463267, 0.01499709633312055, 0.04667571147105523, 0.025802006545875753, 0.054194113572261164, 0.06733183735715491, 0.030727057983832698, 0.0776608298931803, 0.055762784755123515, 0.03311413400141256, 0.0647135064271944, 0.04690333961376122, 0.03466540415372167, 0.027885543315538337, 0.04425148905387946, 0.032927421520331075, 0.06788147786366087, 0.07289573630051953, 0.037986588797398975, 0.03338681347668171, 0.0365792834199965, 0.04056429583579302, 0.037413314916193485, 0.06837065411465508, 0.02416437415273062, 0.06984084951026098, 0.04295424544917686, 0.02859803561919502, 0.011506796165901636, 0.04260634358174034, 0.018478135345503688, 0.0260117315421147, 0.023534809006378055, 0.05536305299028754, 0.03698675726939525, 0.05658684857189655, 0.024754915053823164, 0.05607039521315268, 0.0535413052088448, 0.05842475566480841, 0.027056134339155893, 0.030952942291540757, 0.04115994780191353, 0.04122124665549823, 0.07112132651465279, 0.017321078771991388, 0.01130256984782006, 0.05879490330283131, 0.05521840628768716, 0.03159766930288502, 0.013314791738853922, 0.03229958663827606, 0.041707176116428206, 0.020452848668875437, 0.034296925711844645, 0.010968430366899286, 0.0810168573100652, 0.10399529643888984, 0.04875181149691343, 0.03562703416017549, 0.04718238714018038, 0.05600129320685353, 0.033608209275241406, 0.1015466128342918, 0.0849970623052546, 0.027070091804489493, 0.025339469579713683, 0.024782561963157992, 0.028904879332653115, 0.020207183369036232, 0.05881895736924239, 0.04527784451576216, 0.017522242352632538, 0.038252404890954494, 0.04247952199407986, 0.028674034933958734, 0.004804480854155762, 0.038509620553148646, 0.024829603099663342, 0.04060724370979837, 0.03355222335085273, 0.035256238521209786, 0.06272417745952096, 0.022797852122624005, 0.01275349993790899, 0.025997631584427187, 0.06263741997203656, 0.054500692657061985, 0.04189115749405963, 0.02432643206390951, 0.07793993848775115, 0.03639919004802193, 0.05479750423026936, 0.029475903870271783, 0.02440805982665292, 0.0826509121273245, 0.02447584886769099, 0.010861304954492619, 0.01503944200729685, 0.0449479882871466, 0.05751434487423726, 0.04748307993369443, 0.02980006379740579, 0.014109550476340311, 0.039409602260483165, 0.04531027509697846, 0.03770123768065657, 0.05072559183463454, 0.022902611144153134, 0.04483361103172813, 0.00893960048311523, 0.058061942990337095, 0.015279633225873113, 0.024095139832102826, 0.014536671307204025, 0.03206409766737904, 0.050051446937556775, 0.037700121490550895, 0.04925130826554128, 0.014735963827531253, 0.07582441557730947, 0.037664423763219795, 0.017732739182455198, 0.022153698473370502, 0.03429306824026363, 0.02291536420982863, 0.055486244415598254, 0.01765609186674867, 0.008973402553237975, 0.01407560845836997, 0.0381542039103806, 0.026437407093388692, 0.048420747475964684, 0.026307569417570318, 0.04886446527338453, 0.031017732207796404, 0.05429998539122088, 0.04249738442844578, 0.03593591347868953, 0.03361198871529528, 0.054624742429171286, 0.05319755258304732, 0.062296686827072074, 0.042908518974270136, 0.029456626690391983, 0.059256368183663914, 0.022118053332503353, 0.011702874974746789, 0.04740831555266466, 0.016986432086144174, 0.03629880418468799, 0.026691319986379573, 0.012097136050994908, 0.0430292269614126, 0.031671185179480484, 0.023783811002171466, 0.05607258688126292, 0.0457390413752624, 0.043159902627979, 0.01252454865191664, 0.046676077879965305, 0.04486838934410896, 0.00940576845979584, 0.0024446458971527007, 0.02676441177858838, 0.033807220203535895, 0.032700444771242995, 0.029950559471866915, 0.01061867016168045, 0.020995390002748797, 0.009298156198513294, 0.043556682765483856, 0.04679444492129343, 0.027888613686497723, 0.03569881637979831, 0.0751545454508492, 0.013710111329731132, 0.020326520715441023, 0.03013432032561728, 0.019810320110991597, 0.049735775483506064, 0.0024809477326925844, 0.04787340381049684, 0.028222296852618456, 0.025981221215001175, 0.024496189651212523, 0.044738324359059334, 0.04076461972934859, 0.04891270911321044, 0.040013121840144904, 0.06914037066910948, 0.00872216563272689, 0.017619439101378833, 0.04772272493158068, 0.04872499918565154, 0.05096056851159249, 0.06328709011099168, 0.008371191697993448, 0.032127279455640485, 0.07409350667148829, 0.024981776451958076, 0.02308889614817287, 0.050923747808805535, 0.009841198800131679, 0.05003104338954602, 0.11094512351389442, 0.023723697888531854, 0.04976560727560094, 0.03876275143453053, 0.025926865470994796, 0.10416255532098667, 0.022405857353338172, 0.05040694839720215, 0.04381689076711025, 0.038003647167767794, 0.01653761849073427, 0.053765357472002506, 0.04002654665548887, 0.034042933090989075, 0.020842575434861437, 0.02995799282299621, 0.012273534799792936, 0.010147151088209024, 0.041657259687781334, 0.04013550241610833, 0.008256084169261158, 0.021059570933825204, 0.04275854916444846, 0.050002714552517445, 0.0066170192190579, 0.00705968019818621, 0.08910990054053919, 0.07224669719913177, 0.01602954334313316, 0.08102231951696531, 0.07349841110408306, 0.05081388620393617, 0.02409366232209972, 0.05980050577116864, 0.02940204194081681, 0.014545008806245667, 0.02336322276719979, 0.015715727682358453, 0.015406395441719463, 0.024046041038153426, 0.05269100583557572, 0.03192249080166221, 0.07488895327384983, 0.03929911979607173, 0.05153612227046064, 0.03330892783456615, 0.028258328758446232, 0.005122397410949426, 0.06963855786515133, 0.044793007496212206, 0.04580288812784212, 0.11341308429837227, 0.05150283673512084, 0.01932763574378831, 0.023525245055290203, 0.008482003251888921, 0.01717626752464899, 0.052372277581265995, 0.02228772610292903, 0.03159846658153193, 0.00603096216218546, 0.011841450485267808, 0.042427298546369584, 0.06272092727678162, 0.024141714475782852, 0.0375470473830189, 0.024088961770758033, 0.012312883893693132, 0.01906720212926822, 0.027306522242724895, 0.024611835767115866, 0.02895419525780848, 0.01884991825292153, 0.05400621026222195, 0.011268039200721043, 0.01904966199903616, 0.05340979494420545, 0.01339953312916415, 0.06979356919016157, 0.04323474843321102, 0.015001360925712755, 0.04623885026999882, 0.05105345317029527, 0.018292664583506327, 0.02672028834266322, 0.04090563287692411, 0.005175808294942337, 0.06527481095067092, 0.0853529539225357, 0.040292522204773765, 0.009893249221412199, 0.08527449491832938, 0.04382738431117364, 0.030834001888121878, 0.03992060698302729, 0.04569713165983558, 0.01735360943712294, 0.03369946884257453, 0.043413135289613686, 0.02571888261341623, 0.033349799391414435, 0.039449988664793115, 0.10005152877420187, 0.022626038574214493, 0.026142076422859515, 0.013881602574006786, 0.04009810835123062, 0.032540924581033845, 0.01616586442105472, 0.0714877557807735, 0.008698439807631075, 0.021278208487534096, 0.04017522385610001, 0.044405591141964705, 0.03498084151319095, 0.04601327469572425, 0.026985466613301208, 0.06701589109642164, 0.017646958785397664, 0.029856762183564048, 0.04576713951038463, 0.012817746177980942, 0.011823160573840141, 0.005826108199211636, 0.024053286095815044, 0.015467718044029815, 0.036652134332273684, 0.03771902886884553, 0.008950119472241827, 0.16911110627864087, 0.13684344132031712, 0.13231662208480494, 0.24580780576382363, 0.08467908043946538, 0.10055641311087779, 0.15862537893865788, 0.16879109559314592, 0.0850796400170241, 0.16487197232033524, 0.09879017967198576, 0.05283099100259798, 0.08715595717408828, 0.11229753880096333, 0.07158123755029269, 0.11305762015815292, 0.10925003447170768, 0.12384378244834286, 0.09027660079300404, 0.06813866299177919, 0.1695292874106339, 0.1043852980115584, 0.18096694509897912, 0.17160894295998982, 0.09247153265667812, 0.12804396849657806, 0.10985720796244484, 0.16257773685668195, 0.2008975406310388, 0.14532876600112232, 0.07927733100950718, 0.17501911068601267, 0.1971661951392889, 0.09778076383684363, 0.10305674001574516, 0.13871801644563675, 0.09080276398786477, 0.11881226886595998, 0.132982590634908, 0.0689325693196484, 0.13813945677663597, 0.1802632635725396, 0.12969400281352655, 0.10701304700757776, 0.16974025751863206, 0.09772678637611014, 0.1430894783032792, 0.2645328481282507, 0.0991866612540824, 0.10365989657917193, 0.12570496329239436, 0.07977385579475335, 0.17959859780967236, 0.11659668918166842, 0.08777371581111636, 0.1959758818681751, 0.15212685907525675, 0.12546500616839953, 0.14634450578263827, 0.17126991972327232, 0.14109268545040063, 0.14897671953908034, 0.1864333724869149, 0.11864591922078814, 0.1339835383530174, 0.14276798841144356, 0.13563966591443333, 0.18830044301492826, 0.1259725367916482, 0.15963487619800226, 0.16485780450914586, 0.11693374466683183, 0.1431377221431051, 0.14973709945167812, 0.13789403066039085, 0.12334547990134784, 0.15327787159809045, 0.14913122196282658, 0.13883477875164577, 0.17717375792562962, 0.1317404644297702, 0.1788324774908168, 0.16160103998013906, 0.13081274421087333, 0.108342405674713, 0.11127179062792233, 0.13938464996005806, 0.1770585426794631, 0.13102018593677453, 0.18383068857448442, 0.1112846624372261, 0.11306509761405842, 0.12524832279554435, 0.10128896630236081, 0.09242809963013444, 0.17582236044108868, 0.09120108439986195, 0.10226058095161404, 0.17979915919048445, 0.11825549017105784, 0.15349344217351504, 0.1618964605565582, 0.08923675266227551, 0.11519338376820087, 0.14554232811289175, 0.11586361351822104, 0.17615101566272123, 0.08092397265136242, 0.24080355571849005, 0.13997185416519642, 0.17188057409865515, 0.06134263266410146, 0.14464932174554893, 0.1335885359772614, 0.10163695298667465, 0.09703155939600297, 0.07035724858620337, 0.19027092227978365, 0.1225199606269598, 0.14646293728479318, 0.136713176167437, 0.12109305576554366, 0.09872518280254942, 0.15391618306083338, 0.08904762459652764, 0.08180556605969157, 0.12111586811287062, 0.12713169173470565, 0.15567653360111372, 0.17073684904192174, 0.08465793050293412, 0.14022663049399853, 0.1395694828991379, 0.08946310515914645, 0.17767158549811157, 0.1298835447856358, 0.10936678999236651, 0.142592369977917, 0.23386233246752194, 0.12440430665654795, 0.12848155573010445, 0.10345549469015428, 0.1445397383400372, 0.09398873695837599, 0.11935105281216757, 0.16521992507789815, 0.1136640336896692, 0.12357896380126476, 0.11495767427342278, 0.11648771645767347, 0.0948818518913218, 0.04627642075398138, 0.12866538443735667, 0.13453397953084537, 0.11017860964472805, 0.1518158729055098, 0.13093488051423005, 0.057750970391290526, 0.14597904682159424, 0.1974069800760065, 0.11312155851296016, 0.10572794917970896, 0.10488452336617879, 0.1462410291922944, 0.12863969510155066, 0.13927807925002916, 0.14789250200348242, 0.12201370564954621, 0.06597923208028078, 0.07403888460248709, 0.07742312550544739, 0.1944147084972688, 0.06706326641142368, 0.14771494295980248, 0.14952994271048478, 0.08096008428505488], [0.020779475070802227, 0.04938792450619595, 0.07309192113046135, 0.01903012188683663, 0.05309673584997654, 0.08116192131170205, 0.03420833617980991, 0.009839786599124116, 0.0241586863329368, 0.014735811157152057, 0.07154141433004822, 0.03983331345287817, 0.05446737998032144, 0.02504699384527547, 0.04462470367018666, 0.007930724931481694, 0.01850957696193031, 0.016151905259383575, 0.02698359216031219, 0.031415927090815136, 0.07200644151972872, 0.016783729927348237, 0.010141763520160956, 0.03813900472596288, 0.09116006695798465, 0.013464323045419795, 0.04008946042241795, 0.04348820161872676, 0.04262948501855135, 0.09496871115905897, 0.03351109055802226, 0.030782046461743966, 0.009419458751965846, 0.034010030927934816, 0.05470308608242443, 0.0402626361298774, 0.010244882183282502, 0.018224385300917283, 0.04440137404682381, 0.04872136563062668, 0.03559408449966993, 0.01584754668043128, 0.059132806956768036, 0.0698672513078366, 0.044871171337685416, 0.06747431614037071, 0.052730581390538385, 0.024690247273870876, 0.040739371441304684, 0.029999970391924893, 0.02356764331593045, 0.02679240982979536, 0.022145060722583106, 0.033479609925832064, 0.02321992634928652, 0.03794615828831281, 0.0386080895550549, 0.036349931798343144, 0.020042962627485394, 0.07690156277801309, 0.044771813454904726, 0.06143068615347147, 0.053864823920386176, 0.02570117963477969, 0.0330959424775626, 0.03621263702266982, 0.03693405206182173, 0.006543102158632661, 0.02002192973824484, 0.02425287038620029, 0.03703761346904295, 0.06712798508150236, 0.031398621055164506, 0.054678733460605145, 0.017324997311724082, 0.02103890784616981, 0.04101858181612832, 0.029619203680860143, 0.032100283939923556, 0.04076785634138754, 0.02707069061164345, 0.041378405543842485, 0.022027032948764305, 0.005396316484880767, 0.05139138735830784, 0.05078335891344717, 0.023931200682584728, 0.04243303216727717, 0.06247505332742419, 0.07050949148833752, 0.0302368232182094, 0.032284496019461324, 0.03323264692776969, 0.011947253602556884, 0.0170450320666922, 0.033819532221449275, 0.0374544239602983, 0.048173546990645785, 0.00635077480027186, 0.03783788445538708, 0.03732685937679239, 0.050259604517902644, 0.04274491061057363, 0.03367249707558325, 0.05257339536079338, 0.03907478594088128, 0.05986164856169905, 0.006568709646152067, 0.028410688707871095, 0.05268917379102536, 0.02299800977510001, 0.028486711771360466, 0.04210936417803168, 0.07365336136094161, 0.0499772830600185, 0.03834148636087775, 0.05314378546816962, 0.009216275681475443, 0.04401902634916561, 0.032230878182287724, 0.018448887093524848, 0.06925842897700411, 0.021867025909679275, 0.06435935864491121, 0.018620207007708292, 0.04213983379304409, 0.01247387650489275, 0.034303086809813976, 0.11200468308691468, 0.007588776360665048, 0.039806273832385025, 0.016978016555575386, 0.04700352530926466, 0.04764767556584307, 0.06910311231123549, 0.06001560815743037, 0.03860781814104744, 0.03125930763781071, 0.0301684472443802, 0.038316312711685896, 0.07701674409742866, 0.030887880961277654, 0.025949811828987937, 0.04607835638203791, 0.032375680947942395, 0.0396444839425385, 0.055578457324632576, 0.005729499231425247, 0.060404904053679535, 0.03418196152363505, 0.024759086347850304, 0.01514137493047331, 0.044631994528962035, 0.007170536705026669, 0.039936179361705265, 0.02019177553510027, 0.035419382088418515, 0.006646202162041196, 0.01916682124803109, 0.034094942800168476, 0.017106738041288087, 0.00945479515939951, 0.06284727049725396, 0.07532546163669654, 0.019200362930340425, 0.033725314241434844, 0.02869891681309257, 0.03786348558164068, 0.035859815776348114, 0.05188992739255939, 0.06889977572219712, 0.05021726393273898, 0.053287373656140904, 0.013498816373092788, 0.01660933794586786, 0.031891637814364264, 0.024575970102367655, 0.027077939061980163, 0.020425646199977825, 0.09884431998112372, 0.03124673099124006, 0.022783338258575116, 0.03976393663989646, 0.01721968867682985, 0.013395181175188293, 0.017253556055948138, 0.016978520367826735, 0.07758030814251729, 0.11038748986486878, 0.04811445337587169, 0.02080611265929682, 0.021456044034234116, 0.017577393678948283, 0.05043758086061903, 0.012934076766084348, 0.031347113461898904, 0.017545458428295593, 0.023325922000887137, 0.008900075818278959, 0.03307948461068528, 0.018887034118441597, 0.053326677797096114, 0.07164050079882145, 0.004294522347793515, 0.027786124364605973, 0.020038078871688673, 0.04376915243587323, 0.02740421092935971, 0.03239572487239327, 0.024962102329092364, 0.03610970665301595, 0.04757973385442581, 0.0255838253069669, 0.07253702197756086, 0.03038293894912515, 0.03627293164442692, 0.015558139620614904, 0.014879745397982853, 0.021440999216533134, 0.00613136329255732, 0.02700335449273033, 0.026097455960033194, 0.06489734870514699, 0.017325017667774643, 0.015507237619853445, 0.06253000109323434, 0.05919445186321225, 0.03884613321029714, 0.07868755515664816, 0.012465241298611675, 0.027908135138984238, 0.056414575316011906, 0.01936260234963681, 0.030142897008252994, 0.028366977481969764, 0.044803165165441375, 0.01834621117450297, 0.08652238867112569, 0.05186097091063857, 0.03939635047156896, 0.07703606198940958, 0.035439887416682074, 0.017272307371188487, 0.012179945312839533, 0.04789896083197423, 0.06122683387781892, 0.025857240992731283, 0.02690151656445648, 0.052936177501188855, 0.04977291509775179, 0.004124742284018014, 0.06481471671057598, 0.015762405802628825, 0.08944491363529648, 0.022557952674105763, 0.031769158850823126, 0.018521207052149942, 0.043217920764748535, 0.03364434805033462, 0.046092174747692685, 0.05346864767904792, 0.021056816081649492, 0.0355756724519389, 0.013952307619287499, 0.01801896052035902, 0.07398609457803623, 0.020473270876599208, 0.0159720408929778, 0.018402039339499812, 0.037218731428895674, 0.04919009083615882, 0.006667077715974301, 0.01428001034738762, 0.0395997006313077, 0.04830465352694903, 0.06636112515947648, 0.026523684517347386, 0.06240534742495843, 0.021936814932684814, 0.04258601127990654, 0.069720558822155, 0.008259106194600463, 0.010794596480471748, 0.008129363513684698, 0.025403633547414626, 0.06541671297912087, 0.057018437555858066, 0.02219280244649521, 0.03170328327853765, 0.009503402863629162, 0.03735822805070451, 0.040000701256628544, 0.0564696011133492, 0.02250734922875251, 0.015247720027608531, 0.009589394454711249, 0.025338395798046674, 0.05272231683401125, 0.06617587831403528, 0.06735756061971188, 0.008252165629528463, 0.045016506753329716, 0.04041185615850346, 0.02489795532476689, 0.033957271437559805, 0.08542540110647678, 0.06720602339399712, 0.019030742746378695, 0.03464789116489036, 0.02677624373297606, 0.06200372933277062, 0.02964382093133671, 0.03714316976921899, 0.014558560846905624, 0.024024473802585686, 0.04451743746176362, 0.11850382041718278, 0.03491538663261703, 0.01749185755449746, 0.01269558273322348, 0.0581004498526454, 0.07389960850455932, 0.03047468027632151, 0.014248580605323826, 0.027463156962767243, 0.032811568451247046, 0.03127788253394621, 0.03360009060374328, 0.013831464773310083, 0.013768282985048634, 0.012570813713994409, 0.07952704546707016, 0.022724767115765383, 0.02345108287408948, 0.05652868115742292, 0.0149230715552611, 0.024283575792131678, 0.07293281145393848, 0.06498658284544945, 0.044328034589333196, 0.0470236879773438, 0.03539185392271195, 0.028033311279224496, 0.0525259962970657, 0.08167978602328471, 0.03344102842467172, 0.06417018986706223, 0.020823764747806957, 0.020906330585213642, 0.029617303782807927, 0.020335959137550423, 0.030921383627823422, 0.11045794894120523, 0.10065200512430497, 0.17293101416102477, 0.19079344852694444, 0.13034013099968433, 0.11821124968784195, 0.14107821908380302, 0.11881026040230479, 0.06665114459714719, 0.06139861858849015, 0.18647476312305244, 0.17126702916409287, 0.20454305144292967, 0.08587983636451618, 0.14905709879738943, 0.09528155651475702, 0.16056254213409765, 0.127191959215062, 0.12665028470967496, 0.04664597128118787, 0.08056815567293338, 0.10588065348565578, 0.08569264890892164, 0.11487521869795662, 0.22499541326292924, 0.09322502543883664, 0.17795260756143502, 0.13398653747779982, 0.11719451924519879, 0.13074289581605367, 0.251673333879028, 0.08730754868260451, 0.07366043169583593, 0.10672447963484696, 0.11612369599086897, 0.16375529366944516, 0.060922205581196716, 0.15848093240388803, 0.12527011734034332, 0.11696350521274976, 0.10242477964077677, 0.09704572720719234, 0.07532629623476948, 0.13862349651753902, 0.06886684641774211, 0.1308900700615985, 0.12363119742700032, 0.11381999496370554, 0.12281084858945437, 0.08723436189549309, 0.20248462046895707, 0.12360683801983084, 0.19308164502893174, 0.20129109094185488, 0.0970766751893929, 0.29070299384849413, 0.08489110906209264, 0.1004170895154987, 0.08961696297462497, 0.17993455406810555, 0.16167182475328445, 0.15340022503265313, 0.17861251000847134, 0.09634458340172257, 0.11725788084524018, 0.12945623057229177, 0.16053924124155725, 0.1272367832383939, 0.06611856924636023, 0.12388461668576513, 0.0805065921906914, 0.18985332468790667, 0.09295398462563753, 0.14526008468653473, 0.1056466471137745, 0.15554358144955976, 0.05683680730206626, 0.2747602436159338, 0.12981550129396574, 0.10030068683304957, 0.13463499982442173, 0.10544753779790231, 0.08814016543328762, 0.06980052417410271, 0.10868415662220546, 0.1180451036031757, 0.09716037926929337, 0.07280380159084286, 0.16912241067205155, 0.14946625541363442, 0.09961069814328637, 0.09188577373112951, 0.06505090796521731, 0.11976935608046395, 0.10901184153876134, 0.1347813598279442, 0.09220841034714665, 0.1981153842061758, 0.13638207821973733, 0.13184847363403865, 0.11242536801312651, 0.1530784365854093, 0.1012885659666998, 0.20809176244906016, 0.1850703584828547, 0.11980750331921236, 0.1375810360269887, 0.144364934148533, 0.09652461231287036, 0.17330450697668962, 0.16199305680181297, 0.05836419641439404, 0.1222799899322646, 0.09092546347528696, 0.21209186209099634, 0.18154160997697286, 0.19176653559718812, 0.12160144134291581, 0.09336452545332057, 0.10972481899495636, 0.08208797233445303, 0.18159597420266696, 0.11057825998536178, 0.1749760237123285, 0.10330916861338274, 0.08433898511741843, 0.13785485204841408, 0.11112662484603268, 0.22515026852488518, 0.17091994493135385, 0.17313173839024135, 0.14014885681016104, 0.11926578810172421, 0.12387002818286419, 0.26861681469849175, 0.12862828214253696, 0.12448117110346045, 0.16075395686285837, 0.1345295419118234, 0.12397687030690056, 0.20830027626029082, 0.11266481623585735, 0.07753697011087622, 0.19380237135503972, 0.3017407501382487, 0.157536723784038, 0.0902852046170405, 0.06997209175356797, 0.07863382875387158, 0.16261127005730355, 0.12346510562513556, 0.10741163204823222, 0.1365233084985188, 0.0648499530340944, 0.0906496322048562, 0.15269948834819452, 0.08625056754265513, 0.0801861472427845, 0.19650731049478054, 0.1114204101530569, 0.10890522333128111, 0.11275058306221451, 0.14668252478752816, 0.10879435749458415, 0.14438132755458355, 0.14657845108636788, 0.06782727648637124, 0.1930410143520151, 0.1443967167288065, 0.12865104020706244, 0.24009774359209196, 0.1353456974029541, 0.17897476628422737, 0.10728415567427874, 0.09578637299793107, 0.16547588205763272], [0.01243782339484564, 0.013143566819573087, 0.033187721124184985, 0.02361153604994927, 0.0017355916456186346, 0.05842669627496174, 0.051807193617735586, 0.023853026663086245, 0.04404459694134338, 0.07846785908831017, 0.04170160873660019, 0.014381488652101584, 0.014445313352293201, 0.03690410491877368, 0.0047633637524476, 0.007319120607072753, 0.04948497197723814, 0.02352511104462402, 0.07280988804996014, 0.05748999225241797, 0.046091255332742415, 0.01959377753415278, 0.0399961075745523, 0.03189149532201035, 0.030618220966841494, 0.0153747740135129, 0.012579115589947572, 0.0230217618934278, 0.0341664196790329, 0.021560200855934193, 0.07418853550085, 0.011852779475572919, 0.1297266132065228, 0.07207234762609005, 0.03537193213456443, 0.028610557982964174, 0.042246421466448476, 0.02184826780908874, 0.03431378052170787, 0.02557673291968448, 0.11491085535713605, 0.028140726765351634, 0.004320974611411137, 0.053421299505446634, 0.013778158214076288, 0.041923208095665486, 0.04956043864201222, 0.03236355891983424, 0.0374068315140903, 0.027010183947693025, 0.030464057810604572, 0.03640603646636009, 0.0514623926553343, 0.010373153291376573, 0.02579104481264949, 0.057951545342803, 0.03588070108422211, 0.031097985937127044, 0.05105276106457625, 0.03989799480353083, 0.04108140737350498, 0.02063485042058996, 0.013514168227889707, 0.01524810679256916, 0.04353270673059991, 0.03833661787211895, 0.020306665084457824, 0.048744388323809416, 0.006353337118136031, 0.03470770402678421, 0.00959162598675383, 0.028242705489641855, 0.010509789039913033, 0.06987441663763352, 0.04395457570041929, 0.023667428675772886, 0.05835016431020839, 0.007583846803754568, 0.06358506876443114, 0.05857167885239635, 0.030636636407247612, 0.025037742020296197, 0.0681348971224257, 0.07091240558241095, 0.08132447794611965, 0.017958163782688122, 0.02963936295626419, 0.05396660417318344, 0.03947212586977652, 0.013859248237817414, 0.013241787308028765, 0.028423334904281155, 0.03302222304046154, 0.0233910036872008, 0.057383068704179356, 0.0307706335027303, 0.04785680005859051, 0.026207941817119718, 0.02340858961854662, 0.03574977096702371, 0.0312104632944933, 0.04072110867127776, 0.04160157571147595, 0.013784429573986148, 0.04253052747143166, 0.038337764596300464, 0.017342332185113003, 0.016680273693054914, 0.02935798805473106, 0.03591126908681222, 0.07185266512845244, 0.05233151459002069, 0.011387742956035903, 0.01455186031359647, 0.028963297805083648, 0.04447375337726303, 0.04235854598560503, 0.02973793713109834, 0.01810606914971556, 0.04646123333701065, 0.06289995195610182, 0.07193452359310218, 0.025310082228056023, 0.016755553760698864, 0.05790125232722078, 0.028500988148152828, 0.022662847402638624, 0.025021966081112623, 0.02000034723563918, 0.01208286137054009, 0.04287397814914584, 0.011279497960848468, 0.017631693443815624, 0.027102144102432897, 0.0829098614464913, 0.04606101302696126, 0.010770857084675558, 0.021114106489611522, 0.020748713685731803, 0.05743895284831524, 0.040647497799779685, 0.06448462299470391, 0.08615809000496354, 0.05654963431879878, 0.05051739014951246, 0.07056837475725583, 0.018017459261630262, 0.05848904007247516, 0.008069382714373725, 0.018642730977652327, 0.0428482922060149, 0.0024215080650589827, 0.013137963816656597, 0.031437063456646035, 0.018566238028662543, 0.039557916444859335, 0.02968908260975565, 0.01232758944388479, 0.055474051141313145, 0.053911951570106406, 0.005983339605986008, 0.030505624865846973, 0.005554547458554485, 0.039065286450620205, 0.06550258158573083, 0.041914865507611206, 0.05400667166603463, 0.051282669084944894, 0.052769790536590984, 0.01170990035669612, 0.03671708370425871, 0.05497018799984029, 0.03962936278964792, 0.1208863468574626, 0.02028132349784885, 0.07081857776003224, 0.010152437724173069, 0.04421305004507303, 0.002131690491556323, 0.02009178831108979, 0.03365473642147013, 0.025415938779977814, 0.04927186109125614, 0.023067929416096637, 0.0500440068010773, 0.010769257438369095, 0.024872454282428538, 0.009576867850098227, 0.03215138441217797, 0.02253524719604424, 0.020414740445890596, 0.01991513680799731, 0.031444059152688296, 0.026213451521471143, 0.058149548646594794, 0.04808923562190362, 0.031031275766768625, 0.013084149204327591, 0.006175095298593598, 0.01992599167195814, 0.04650863240073834, 0.021797445536191975, 0.029607560019940138, 0.011759674292989075, 0.0185394783038646, 0.033637633946325095, 0.05518839468381234, 0.035596170994852266, 0.05030300701037049, 0.03551768484924521, 0.030039735936692784, 0.03264518827199936, 0.010606373410804995, 0.02680855048155146, 0.020253869970994334, 0.08405547283057656, 0.022798510301592093, 0.005718888215986746, 0.026501107960939407, 0.04654294591663139, 0.01662533780160759, 0.010917351947032979, 0.06364803002881152, 0.04837901417964271, 0.039637176120387654, 0.07573430612683296, 0.04640867401446615, 0.0856701826144542, 0.016827237592743974, 0.028386461615030254, 0.05098383887005704, 0.04520861358780946, 0.020456246432981322, 0.03212770014735205, 0.01563160291074642, 0.058381437989217896, 0.011139729076863399, 0.022358076613662497, 0.020020009484142065, 0.055852541367390325, 0.02765681764243969, 0.026831098200221146, 0.024183846411428282, 0.05592884602291243, 0.03874206290181194, 0.06065727836851563, 0.028389462436150228, 0.01842356247029134, 0.057187270639198165, 0.03947729630661862, 0.02921583836099931, 0.08730708049344164, 0.03297975692631943, 0.02445872942917049, 0.015574324377147215, 0.054622537190360684, 0.01885362814313599, 0.031241550376372676, 0.04909744027203747, 0.02805118728429079, 0.04318598551409585, 0.045571093780121634, 0.0886564152315259, 0.04524437577596732, 0.02178555420999016, 0.012973037398686367, 0.03899531591949718, 0.01976761650959296, 0.0020101307309232652, 0.06748519984206983, 0.029420369171670506, 0.051661797133939605, 0.02569828398658761, 0.042295469370271475, 0.015301885781809688, 0.036995669826865196, 0.031447557000709433, 0.04213203403300472, 0.03779130641903196, 0.06681051211697714, 0.009432886959984899, 0.06859987681465489, 0.029434285924902985, 0.06153176751519952, 0.06677585254822459, 0.06637876028461115, 0.04491259929324899, 0.03227369713463953, 0.01928332231805793, 0.0399054892228118, 0.012760331937378007, 0.0475665838457644, 0.016412121742697697, 0.013298746930169207, 0.02707417997797685, 0.033929492213896344, 0.02861113813040512, 0.01705874186674399, 0.02638228460481124, 0.02661413832434586, 0.03764928225427866, 0.017277942604518363, 0.03161548763247473, 0.06066875918103116, 0.03565068789092558, 0.042251805641821454, 0.02464057002881808, 0.02951430555965219, 0.032131055503019264, 0.030823823862842152, 0.04561866247760398, 0.039260497582810264, 0.04173906047695449, 0.02788545680232346, 0.021827664093247483, 0.05705846433660813, 0.06887099905205624, 0.05600282330332058, 0.015356674091890454, 0.007967561749475343, 0.04253602360508271, 0.023226189227508645, 0.046209249179810286, 0.011904660263098776, 0.03272308748481529, 0.037402410858443806, 0.011844474206944662, 0.020387675380334258, 0.06609424376594168, 0.05883290804922581, 0.05831840208598545, 0.02652930448363934, 0.017403010179155638, 0.12490704682256494, 0.03186347182574017, 0.015122640578608428, 0.017056904733181, 0.030269705025213103, 0.025970076277319874, 0.006566727899813226, 0.015914290777540634, 0.0328442738391459, 0.04541266603129251, 0.023881972966981784, 0.04589493140312178, 0.0687411003080862, 0.00996192968783102, 0.03919202322140336, 0.013928982129852687, 0.04512844128268106, 0.026181059956018413, 0.08262358752212354, 0.13729710983378546, 0.12540140029575142, 0.12698058198605264, 0.07098564665232386, 0.10341510150049414, 0.1936320454946586, 0.1500753762998751, 0.1324029860219785, 0.1664656475186348, 0.15590213292411395, 0.09611849553350892, 0.08905543453459229, 0.10231391380407981, 0.10095716267824173, 0.15953237669808523, 0.12005009315907955, 0.08740541378834418, 0.09141101634928159, 0.11509144066699914, 0.17763330255235943, 0.08550385332533292, 0.09682889455663306, 0.17011016766939843, 0.11725697160831519, 0.15937933990997927, 0.12116104497441224, 0.18451238556631974, 0.1573984654886382, 0.0819815101900271, 0.06755597782986504, 0.14146790174501284, 0.10217838321945497, 0.14804970499660286, 0.22629536422235624, 0.07286841848066875, 0.06851179618388414, 0.13303539423005922, 0.13316556438803673, 0.14828948570149286, 0.138969997210162, 0.14371272628860815, 0.10962969517069203, 0.11071006541273423, 0.18113622601543153, 0.10363639891147614, 0.11679944901594094, 0.15234403099332536, 0.12462257780134678, 0.07576734399689095, 0.06856835886303868, 0.11920748837292194, 0.13850506501538412, 0.09986725901918751, 0.09163821701492582, 0.15170280183000223, 0.12305551474647862, 0.11402557071830545, 0.07229388252432857, 0.16434187362236635, 0.13684342774961675, 0.05881401763430663, 0.2273151752139841, 0.12472674649740968, 0.09916947396206004, 0.13406593964568206, 0.12557613663375378, 0.1527771127543279, 0.2483480508838381, 0.10793147129671914, 0.14148772853825772, 0.08601101753967148, 0.12671842319624765, 0.12327749069247927, 0.1619998285812991, 0.09148313783641372, 0.1710857924606119, 0.1458665592862027, 0.14165103834654602, 0.14667408381189617, 0.08534897770732641, 0.1193948183208704, 0.11032314438905035, 0.181634908542037, 0.1910492562289749, 0.17866975122264453, 0.10969651729932853, 0.17720144215439046, 0.12119577239666667, 0.12689637579023838, 0.06675327090280396, 0.07625004702380725, 0.09834368327366454, 0.1709536952631814, 0.14864199821438107, 0.12285492622426578, 0.08123138972691127, 0.09492094229374613, 0.17066545358725957, 0.11418763202215944, 0.08959410312984671, 0.11080744875861065, 0.11376515576349837, 0.15854510824595178, 0.1328646069658654, 0.0859147198498249, 0.16965548135340214, 0.1323241809649127, 0.18308751630995954, 0.17585383089525358, 0.14616207485752447, 0.09340272018952028, 0.1277525377060686, 0.06728045190019266, 0.09602989921612398, 0.12718036983694347, 0.05421470032472696, 0.21413930079766683, 0.14330392251057283, 0.10676933079957962, 0.12847748451999255, 0.13981014569955214, 0.19124129520995276, 0.08611068076321057, 0.13382174846317085, 0.09356459828891925, 0.12812877180320875, 0.14303843889917645, 0.1809802715267454, 0.09414219443819352, 0.1128622359995331, 0.11817368598920958, 0.09817756433039904, 0.1073854338111622, 0.08103010231362921, 0.16607893684080668, 0.12546822242438793, 0.2689174328531538, 0.1270606898303543, 0.0844643512474639, 0.1581609488597938, 0.10279452694313866, 0.17254924321813242, 0.1391676137489932, 0.10055902547069959, 0.08635274813111339, 0.18926188642425196, 0.13496621990842478, 0.10598856769502163, 0.1139409031186785, 0.12038359312074524, 0.08896279414849621, 0.07602362667343446, 0.16248318978718349, 0.08926875237375498, 0.12326963325696332, 0.1005260350980929, 0.16258692422083446, 0.2638164237141609, 0.1132509144289153, 0.12081614562443324, 0.09251814801245928, 0.16819375407482895, 0.09941331230636154, 0.10840231353150946, 0.17850806989840098, 0.18114652617701463, 0.09343600233218499, 0.12664763842310223, 0.22523348405957222, 0.14950634326253617, 0.09439104715628283, 0.19388589901583536, 0.08274495029555899, 0.1874173568295581, 0.05643674644774624, 0.1326096270765577], [0.09523461546216692, 0.07342620819274868, 0.09000112914613315, 0.030206720012107065, 0.032804101173366816, 0.04248541846339192, 0.02244747190603188, 0.040447947436145375, 0.012774079905024596, 0.06650081516376563, 0.04865823133981653, 0.022642464210678424, 0.01964213672493185, 0.0069033635414338535, 0.02555415127426386, 0.055511445206190856, 0.03472697102863874, 0.026087466228221143, 0.04599466587283781, 0.013957002233447773, 0.034172502745475085, 0.04732823145708867, 0.04363630884992225, 0.012933189581547464, 0.03305707599169441, 0.015949174262849346, 0.07927465079618351, 0.019278670960505093, 0.005030418172412152, 0.029969198828829185, 0.026803863500910144, 0.026669242153210298, 0.07058365536587578, 0.01471487495915166, 0.0340266075384404, 0.06375847517379693, 0.019898036029189825, 0.03294339084199496, 0.027649363935259835, 0.01535200237828706, 0.02936548925936222, 0.03022945432790688, 0.06223244991685663, 0.005162264311885727, 0.038243088605148454, 0.01428768118577344, 0.03172458249277302, 0.026545112653236305, 0.0613350330718926, 0.027335575415885875, 0.06045576025332723, 0.015431854075619152, 0.05423833369942648, 0.0382493888027966, 0.031038441096565554, 0.04021269595250487, 0.024393717292696238, 0.0340136543049344, 0.021343537839129567, 0.014507294133571642, 0.020097968068772128, 0.05232929578050971, 0.04786545477275338, 0.03605185815000108, 0.06711391905056578, 0.028170814704416052, 0.007889360588576113, 0.04173456857513104, 0.05732431435691459, 0.03803596579070602, 0.0698972221996103, 0.04005459729315979, 0.029196038709155152, 0.09248023826096739, 0.019484507951087186, 0.03324347973934241, 0.028714367055467198, 0.0619642793067864, 0.020965580263042023, 0.02867640641384891, 0.004651371547619679, 0.039588837285659144, 0.05333606872175421, 0.044158448332122395, 0.025152597642902817, 0.05490630053515945, 0.03990957400362406, 0.014304530906624027, 0.0421271282248199, 0.05902560520917177, 0.015062205160834959, 0.015644557840589966, 0.00784873669700963, 0.0193582902595933, 0.025684855778568556, 0.06528684816190175, 0.04928055651752012, 0.02109809815218406, 0.07164423274142401, 0.04732209750052009, 0.008937639516911336, 0.09504903613456658, 0.07904215755739383, 0.0198022353662444, 0.031722536709691794, 0.027993043618542806, 0.040622266475111246, 0.036455484705844095, 0.09217899585408823, 0.04712205519899726, 0.0397082390928907, 0.06873428103114877, 0.01909237408212253, 0.04321767309946673, 0.048085751344582865, 0.03726947906294039, 0.059436485304364135, 0.004411186266224831, 0.0837328429999096, 0.035776759697390456, 0.05532645281138165, 0.05657326090814812, 0.03382221582744803, 0.0036747934147050338, 0.07303972143147673, 0.043148984999528954, 0.04717064509168267, 0.04322708098750029, 0.01334204085703407, 0.03472266233127032, 0.0407105472737125, 0.031091387184070687, 0.03684195111106549, 0.025022668364856924, 0.02590217188532863, 0.029375185524778705, 0.02068762687434043, 0.03165269510022231, 0.0033311480822573814, 0.03810168529993721, 0.08263893598424536, 0.05859568542135613, 0.03673604197267975, 0.022088418315563883, 0.03572587635634201, 0.055900951448295794, 0.05626811013956155, 0.035313798646841726, 0.030208436705704247, 0.024702242076663033, 0.020306334298636233, 0.0209867268068982, 0.029514108784496784, 0.013208958087489009, 0.054830542100327354, 0.07839537797761814, 0.017934852712122456, 0.047689079772681, 0.02953988972253033, 0.07572321207927805, 0.019554115465975234, 0.0384503030218184, 0.08291055355221033, 0.10065763696495976, 0.0711631446278521, 0.04311865109152027, 0.07069391052105597, 0.008819844141336424, 0.017539041183356727, 0.02745447341086609, 0.010898107845735337, 0.037940421274730136, 0.05533444256122623, 0.0158277572066124, 0.06668885078813348, 0.03828838421031833, 0.059823677742055485, 0.056848515423813036, 0.020098928195823516, 0.039763359885130606, 0.07148495343114648, 0.05386999435722828, 0.024923329141789248, 0.026811890570180755, 0.044852501446647305, 0.07532854897103139, 0.025126669123502712, 0.023033510727275695, 0.04417272470891476, 0.045387960571263514, 0.05111790721171668, 0.0961080596649221, 0.005736305785831064, 0.013137784853045429, 0.060702353449804444, 0.010354053378770394, 0.044483022165617774, 0.04009272078318255, 0.056519914484981976, 0.048224671211625846, 0.04697596321680716, 0.06604863942733832, 0.01702915265091828, 0.0466731669647353, 0.0455424969217607, 0.0591649016631501, 0.014209753135219216, 0.09327554237097502, 0.026971799221688082, 0.05317265713321311, 0.04075430938974023, 0.06732338959617273, 0.014600940447832857, 0.0240904087466853, 0.07430742840681757, 0.03075098312859024, 0.017890598658206205, 0.06949739543987171, 0.023856058018282056, 0.05228392214381269, 0.052086308997656615, 0.022047719785145352, 0.022597480731617128, 0.022089802527001927, 0.04453715568940554, 0.043132578022778034, 0.0689050615099924, 0.075903573472585, 0.026798306299107413, 0.03414843850103872, 0.013089727610349655, 0.03941233675660832, 0.02897839181657348, 0.06242344395390578, 0.03647319786250591, 0.034218619378017526, 0.04197987594774791, 0.04802372306585312, 0.022004176496661136, 0.08830090359385524, 0.06588349757449967, 0.048016303285424194, 0.030161471904388497, 0.022385002579540014, 0.025371450631480132, 0.02505965530872345, 0.05495004229513662, 0.10076617542654276, 0.02183283961910222, 0.026645283081701825, 0.013808620195569736, 0.054605794338775535, 0.02439212443173996, 0.02661314935955618, 0.021295143025262014, 0.01759030620035316, 0.052837850991636515, 0.07416731092546668, 0.03789662862462657, 0.047531201637216976, 0.05677872809714504, 0.05639837868511677, 0.01796923917053001, 0.019577133070145334, 0.013382094779184886, 0.028412576731560484, 0.03450336999126843, 0.051228440566254516, 0.030719298935894455, 0.036317667458206415, 0.040501317608037164, 0.0865562204271555, 0.016060143576136658, 0.05980086539472852, 0.040432995917009454, 0.05870635448289769, 0.0593159639143518, 0.06048101532672133, 0.023454623130549277, 0.011248556763998099, 0.0318928252506469, 0.05166875211788075, 0.09407845964389187, 0.012773397977330854, 0.07878118620387145, 0.02028233281868909, 0.029726140799799135, 0.01912166304620249, 0.026909268827044537, 0.04140714828723243, 0.051764523943087885, 0.008797326108573802, 0.08591716257589203, 0.04967472090252808, 0.030316754643406187, 0.013076967759323972, 0.03853094351610967, 0.024155795773757354, 0.026301289575972726, 0.020447228702583482, 0.06189010864389794, 0.024083572506372417, 0.02743816651803042, 0.04419232080025332, 0.014126396804515804, 0.03171322042388575, 0.050475643282490115, 0.023026336915791035, 0.038394357809530835, 0.0006278226896288938, 0.016889369348064065, 0.05186089966446161, 0.06675580862377371, 0.022603190603799055, 0.021201108249702623, 0.02611883490213326, 0.059674780017563274, 0.05046392498271806, 0.03419669930424009, 0.05587020702660084, 0.054262805064874034, 0.061899506353906224, 0.039670777174511125, 0.02788599793400083, 0.042540895486516614, 0.07880623093140976, 0.05008410143532923, 0.04045020356508238, 0.023618913421939527, 0.006547910003324172, 0.048833900663469515, 0.061839415292654715, 0.027355890754344206, 0.07900058371680123, 0.011846860953872758, 0.027727052802219987, 0.07560864822672946, 0.023403714344437634, 0.06502699639116015, 0.0510224135858672, 0.00523405840587137, 0.017902664707175324, 0.03439102494823081, 0.017656763616417135, 0.02225310554994004, 0.060751289395349364, 0.04225621951211776, 0.012647919040838522, 0.027276792230882814, 0.04846854009000318, 0.03084510950637715, 0.01773461533178176, 0.2289051998938833, 0.2224125290023429, 0.1551570336201361, 0.12371267591203962, 0.12800271356744425, 0.16259718367031642, 0.1119985966277974, 0.16467291728726455, 0.12585749796458653, 0.21968933727060044, 0.09618334991059133, 0.09481721464544535, 0.08846039324998856, 0.10996486432850361, 0.23139762186578341, 0.12492266669869423, 0.12209123506077699, 0.1292412435369832, 0.1169250729892935, 0.11550275502460343, 0.16043387832386152, 0.09103042605732169, 0.14186780314360345, 0.15470017599208014, 0.14766359142959118, 0.14841719956270286, 0.09834263154438563, 0.14679924638143607, 0.1614949849567243, 0.1367752214095422, 0.15041844360530376, 0.18453983909317426, 0.2234352169824498, 0.17743659525045327, 0.13938486709126405, 0.14706095733812877, 0.11316364125481673, 0.11430615851921694, 0.17330696327345713, 0.1279038917273283, 0.09998993136520896, 0.16188952592866762, 0.13832221339855874, 0.16582126995282515, 0.1229498532733747, 0.14956829350973877, 0.15335591669593537, 0.12349971091108662, 0.21293933875858784, 0.09285094908305577, 0.1533625934805189, 0.17567287917648042, 0.1524989948208843, 0.11969486650611673, 0.11873019327010427, 0.15092566210244382, 0.12426546482103211, 0.1802472501460995, 0.1443861722946167, 0.1264428836958749, 0.1234504764101335, 0.16098016686737537, 0.13044869660266808, 0.141415803826281, 0.18919970547514303, 0.1029953733086586, 0.13131152173238142, 0.05831302808863776, 0.2089674390320267, 0.11381917393633298, 0.17990327360374586, 0.28190785007817404, 0.09726270235010556, 0.2164344454982451, 0.10247524229011365, 0.1416842865624598, 0.16344201405133518, 0.14670775271952152, 0.06277149170637131, 0.12583077725555214, 0.15638032369315624, 0.2160723249294928, 0.14914160354861192, 0.13018108239131315, 0.09314759102250848, 0.17846564788903507, 0.08242850870426212, 0.18062395921775273, 0.08906458797199385, 0.14230598748794623, 0.07232122070022992, 0.06420979595610074, 0.12374660266297204, 0.07434087339788675, 0.1319217961281538, 0.19758472910949162, 0.07134755008987018, 0.2090835092323167, 0.12547291788671697, 0.1831048053822347, 0.05546732685927834, 0.13618736581078597, 0.20402440641607555, 0.1946401178304638, 0.17450114419417723, 0.11819143646529742, 0.22139917766409262, 0.16351047823471682, 0.19629696463899954, 0.10751238771315132, 0.10171682334371976, 0.21469544166965143, 0.11093611256884676, 0.11496711948088237, 0.16015961446932384, 0.14706844836473465, 0.2533660073365484, 0.12685427947768144, 0.1681936319385256, 0.13154047301837377, 0.15868608068142617, 0.11458076164126396, 0.11364044781242098, 0.16005670784839562, 0.15776395159108297, 0.1034115527623466, 0.19113373383879662, 0.11133701141391482, 0.1086145592853427, 0.1610236745327711, 0.17089063221854822, 0.0953023536130786, 0.14657718901123318, 0.12717248526002678, 0.0663879747901644, 0.1181765901190894, 0.15075582478727612, 0.09096159546502999, 0.06109200896961348, 0.11658376987491335, 0.15290308956589016, 0.1830455149923052, 0.07815275421100003, 0.1278651338070631, 0.1291129868477583, 0.12488369164722306, 0.07150863430329732, 0.15767430354441914, 0.08555756615740912, 0.15702357489083493, 0.09023282171360084, 0.10485803335905075, 0.10688747731702668, 0.11702470907143184, 0.0949362161170159, 0.1669115943035909, 0.10792418383061886, 0.16695499340338366, 0.11199639817433697, 0.12781083743487084, 0.16698165982961655, 0.10574082098901272, 0.17649172166628496, 0.17370410981987203, 0.16115919154669556, 0.21436766854354314, 0.22604132071137428, 0.07151790987700224, 0.06496312588985477, 0.1768742525683982, 0.11218975351325103, 0.08913979679346085, 0.10167328175157309, 0.08606641313859395, 0.13784487758363995, 0.13594488453652176], [0.0192495261851166, 0.01946786348707974, 0.08405517427516834, 0.03031244933871286, 0.05894347533051457, 0.050942641616399796, 0.03780070073636515, 0.07116290035524539, 0.031376110655920844, 0.03527955976980073, 0.03315551785219993, 0.026753295678645372, 0.015741676557809114, 0.034622422352965386, 0.03858709228890283, 0.05945561999189002, 0.030631900232817446, 0.010935936173024987, 0.028264805375199233, 0.015430276481700795, 0.07765047544879572, 0.013161230782446052, 0.06174395220088107, 0.058615688633705886, 0.041511846240609884, 0.015885707489880066, 0.04831314539270742, 0.0442136200144887, 0.05277412976803524, 0.08474027751279728, 0.037007377948611975, 0.00693225344210597, 0.005881640777390982, 0.02965136624074408, 0.049114030453243425, 0.05670780083164573, 0.05601106071844697, 0.04951744666323066, 0.08894074854574033, 0.036199880564319234, 0.03822826261499098, 0.026609693919973712, 0.04375592100300959, 0.02340315455304725, 0.04191131676946368, 0.006224626234532999, 0.046648688813937564, 0.043136245504553826, 0.017039758153259754, 0.11069242350224938, 0.03743175410532525, 0.028711781837046146, 0.05191215280709522, 0.02779874511595283, 0.028260257494236742, 0.06425680486219269, 0.026523640412571173, 0.03411791121054973, 0.05736262444406748, 0.05277618572914174, 0.047095575369894505, 0.006963463084373091, 0.06688803474285773, 0.004978053504601121, 0.03366608152698193, 0.02682525771004813, 0.05445511545985937, 0.011177558252321822, 0.016485841179798757, 0.015707994079483405, 0.03670667497707265, 0.0064256452023983, 0.02623788726383022, 0.012351264378854206, 0.0417288145981729, 0.0432193456882877, 0.009898834412784448, 0.035341805179736445, 0.019785053163234676, 0.02406501118093729, 0.058000827341207435, 0.009843328551921462, 0.03007190188925181, 0.04066145187243819, 0.010359001595393887, 0.034199759497174194, 0.013355810877068766, 0.011742974698011364, 0.01721644527944071, 0.0639814417809248, 0.05100270553625055, 0.07111979302551065, 0.008372423239052296, 0.020146793752376522, 0.016067091774727617, 0.02213838224166206, 0.05318075205598559, 0.025078203063458204, 0.016515577976991023, 0.02163349451231105, 0.08474300522357225, 0.038563004295740805, 0.016428990123261298, 0.0816123125010303, 0.013954567140899599, 0.020253564630235945, 0.03665646677836776, 0.01475177369346576, 0.005745033442508429, 0.03701619551117931, 0.0340601916291884, 0.058521026213254244, 0.0703722917075668, 0.01807960119497563, 0.040107618019516976, 0.0511916978949947, 0.054547426756471395, 0.05777183534311397, 0.032641887199133635, 0.0039958694001792795, 0.027332669589668512, 0.018177751285423125, 0.035148181819490025, 0.04174761680353965, 0.018246821061308895, 0.048019461865936, 0.06856645217963628, 0.015391398121469786, 0.028419148343216096, 0.010674220975488424, 0.027594909803675752, 0.023681623628363013, 0.0302547976108534, 0.04266577646402376, 0.041736600787511895, 0.034596624451556375, 0.014468710936073746, 0.004933619638904929, 0.02509787379364882, 0.023628105875104666, 0.025896920024284294, 0.01341082395187446, 0.013527748258119183, 0.031125581956335475, 0.00487877959052899, 0.024040650077430264, 0.005838633531571499, 0.05948848822819335, 0.0581401102244854, 0.023465452549446906, 0.011492125390629684, 0.008139131873446916, 0.021254990715533495, 0.06354749828044857, 0.06277512865407125, 0.04290493291669658, 0.02840616287929671, 0.04536049686638372, 0.018073273855926733, 0.04545605156038489, 0.008071622728104038, 0.08137697620051247, 0.0054716610133514875, 0.03627438031669174, 0.014874527463689446, 0.02999756159260869, 0.007359716509069715, 0.02021619601042143, 0.02536640063460384, 0.04797349451109767, 0.08055256293820483, 0.024027730770675198, 0.03349634259939194, 0.04169771733826824, 0.024786265068022267, 0.04650442209094763, 0.017449840969805206, 0.0421443460509181, 0.06805339828133583, 0.01728703497376825, 0.03726165555417538, 0.032963787604655535, 0.026495934131422212, 0.036068031032170565, 0.09815879605178322, 0.055925612803548574, 0.056010338078652105, 0.01912901666946709, 0.02287449434931789, 0.031050929533583776, 0.057336073368787766, 0.02783915526898844, 0.0749449459835887, 0.04279746314776795, 0.041370252945593426, 0.014850308852536338, 0.021384775804887925, 0.011716212428707098, 0.045024330262094736, 0.02675017441755959, 0.03817735891789198, 0.05808345255042825, 0.029348583559372594, 0.015506477660632558, 0.05206048395484686, 0.03773445875516959, 0.014658217285094517, 0.017147487461833016, 0.007819759010869478, 0.026712804101407528, 0.03050121438822576, 0.03808416213308062, 0.002597427386457899, 0.03723206124933703, 0.011866514720687909, 0.0304472742469183, 0.03128070184694869, 0.014801627357623406, 0.08192386185484272, 0.04302232965294804, 0.09251112517501626, 0.004882290161081723, 0.040370662297521315, 0.02233558996314449, 0.03606173422719751, 0.08644166335995708, 0.02625456904726369, 0.040000270386891704, 0.009320494419495975, 0.0858930813680802, 0.03341841624517526, 0.06698469884161438, 0.020680140936747193, 0.11654680328709738, 0.07161922194063663, 0.011309203375796122, 0.08003770413675479, 0.03606050607881375, 0.08563267319862332, 0.036782531799482446, 0.038199540227651596, 0.03226051659190229, 0.06747673851038728, 0.00966903580618756, 0.011107871009569083, 0.01788596256769129, 0.027877377146588903, 0.03747960439484034, 0.024294116833646382, 0.01680378402982439, 0.01960038816157196, 0.03354942100122571, 0.061760080978274345, 0.025930563486846428, 0.08350981532463006, 0.04187727127490299, 0.05023389821872115, 0.019648806724165167, 0.033578967808612754, 0.025856930562960248, 0.032953236385115554, 0.02968266366847924, 0.01681021145278854, 0.01978607944745038, 0.05959018027143819, 0.0779711307425584, 0.07561723848006555, 0.03239737371248858, 0.09659971935408455, 0.03979179050241198, 0.01293693679118795, 0.013374113511028034, 0.05360606119834951, 0.023787271530766572, 0.011887169326655567, 0.05121397080698183, 0.07771205928708826, 0.014759442835514034, 0.03505062544718385, 0.06001693130071674, 0.07257178332656622, 0.06861233471759728, 0.028280747555462376, 0.022485880380762473, 0.04129226891590016, 0.02153179738005357, 0.04313351779377886, 0.05513717546792967, 0.022641207224556377, 0.06563708079712731, 0.04781913457970534, 0.029043666885367463, 0.06029519172651427, 0.006725350727460214, 0.05107250304094382, 0.05253368070615189, 0.03333150947998677, 0.042553224467805455, 0.06960714169378791, 0.035776922545794926, 0.05189021916261741, 0.01901586925876992, 0.03789227582248194, 0.02642290510370263, 0.02368370333819517, 0.03091122256591916, 0.030366145207413604, 0.015074018455509628, 0.03420085193855422, 0.07089751173875161, 0.021572443324008157, 0.027698818960094025, 0.0659128984968577, 0.010085311102946954, 0.07481680464531694, 0.0387883695241596, 0.018626797279076915, 0.020406041626951525, 0.029361560541604246, 0.03825470173199262, 0.019191382519368614, 0.13173150776752404, 0.04503185860812664, 0.011722618647451912, 0.01357457904876875, 0.01973161004882838, 0.0672116077372006, 0.02813480654731393, 0.07404526283166238, 0.02026649241867874, 0.03951975902808564, 0.005887675922297473, 0.02170609267029379, 0.01707456530337887, 0.010633410486791815, 0.005538753283742283, 0.04327250551432371, 0.0658692754805088, 0.04486653694350805, 0.013549985547017838, 0.076928921309965, 0.013837498645963413, 0.02293973888403603, 0.030073245388588736, 0.026404062186234763, 0.04568947099947503, 0.01247422510225858, 0.04789223315726433, 0.011836397943885198, 0.06661140280110495, 0.022809874066816907, 0.032386211811431816, 0.09360037065510239, 0.11709674234901156, 0.14742961898446083, 0.2072618869798524, 0.12785598715501173, 0.15525415912270546, 0.13839868429516042, 0.1737393257873399, 0.13782339516494954, 0.15225160095308507, 0.13406820595264435, 0.0915860173159412, 0.07810280724827733, 0.10642160195857286, 0.1648870493684496, 0.16969366930425167, 0.14516142569482327, 0.1829505879431963, 0.07369315065443516, 0.08459295398954834, 0.12582198344171047, 0.08278792191829, 0.1269961204379797, 0.09625796162124191, 0.07984149895076241, 0.19978527245776995, 0.12409285908298832, 0.16353808103927545, 0.13276624652956212, 0.12291916991983141, 0.11950714300785746, 0.0876091710690941, 0.1103031886741519, 0.11553337052464485, 0.1925124762845891, 0.155403287549104, 0.16031277339373315, 0.15195083352071898, 0.20385205852133886, 0.11821424881262438, 0.1157714548919882, 0.13122551063341753, 0.16685490948813303, 0.12395385439906802, 0.2289018343601908, 0.126886319901262, 0.1443848152245794, 0.11235601494887046, 0.10181811505130359, 0.26279395286525997, 0.0969949456463967, 0.15477854678673403, 0.07529975873019014, 0.16027047352067061, 0.14176222309470177, 0.14225572161376476, 0.08518681462321963, 0.14037932801459516, 0.20297858039183275, 0.1514724391911711, 0.14646224517907414, 0.08385757809238774, 0.10307877204780068, 0.1659722982772759, 0.23306448385119438, 0.2004464098385402, 0.1330119033477136, 0.14688886728669914, 0.10941894897925002, 0.09481493476778269, 0.10424780646072966, 0.06304469026092972, 0.12461003847420216, 0.106871151764478, 0.09709076836173024, 0.1215498862521989, 0.17624459921249322, 0.11794191199753966, 0.14369991554745606, 0.1072411976222481, 0.1970596108585596, 0.11500678663807255, 0.15376991805221352, 0.14821513183414936, 0.23342500307730266, 0.09162031047578369, 0.08807375042566232, 0.10688847476350409, 0.10451357505683388, 0.14992250236017363, 0.28404333548886435, 0.18398384749889374, 0.1114879786702139, 0.07308182452938386, 0.05129228392615914, 0.06966799949961049, 0.18050400779715606, 0.11287247509296451, 0.11120205079870564, 0.2023947010082858, 0.18070596696010657, 0.13636607836399758, 0.09509773459285498, 0.24370583998305456, 0.18226498258965357, 0.24570173716970853, 0.13032909802028111, 0.12704386216189179, 0.1781100548271622, 0.0880993108398148, 0.1597801369747945, 0.10289373554821525, 0.13573168883366243, 0.12747296770768507, 0.09963661818099873, 0.16415349873048918, 0.23335758383784974, 0.10568212770989963, 0.0929219238460064, 0.09974643907376698, 0.11617841305477278, 0.14119712556047098, 0.24670700037053653, 0.17913678687598023, 0.11220972279884986, 0.12598802096077374, 0.14079000454928192, 0.08902314305305481, 0.11565018711345536, 0.09889961379979338, 0.11856644919940404, 0.14746148298893655, 0.07392377113657338, 0.14256349152752332, 0.06695051424737487, 0.09494729659387044, 0.1494625506124326, 0.20799342915415764, 0.16346044306244167, 0.12087874726525374, 0.15803901611694268, 0.06679213060332195, 0.0922683249892933, 0.11089885421097279, 0.15938702092639037, 0.2644977000142847, 0.09699358857635941, 0.11940239077167851, 0.11442393862775393, 0.14767565578222275, 0.13290420626955374, 0.14142140852553503, 0.13484674346234116, 0.1324617335838931, 0.1089820402807423, 0.12175715155899525, 0.14718719199299812, 0.14251560052590712, 0.12711517619235174, 0.08711732139012643, 0.1503131485411099, 0.15872527286410332, 0.15959968737193517, 0.10690714804721729, 0.17887476379317896, 0.1240602351192917, 0.1490432702537094, 0.12448798359504767, 0.13510344683059625, 0.18253288178571633, 0.15411751797156675, 0.10016912567828383, 0.13527750463357993, 0.13911973631807736, 0.13341613379972322, 0.10278018949819462], [0.021371345900531327, 0.03428846098748701, 0.022443392214232256, 0.02499098756483623, 0.02661285419682307, 0.0034063639011167523, 0.057184651494026184, 0.011127456074713596, 0.026921323001650826, 0.03470316802018455, 0.07022671880466597, 0.002440110526679616, 0.020936240408835665, 0.03250830740268741, 0.07353281282952853, 0.013186633437206703, 0.04605889939037817, 0.03597293434930699, 0.02413227266099836, 0.014748613416616405, 0.04652653893988047, 0.029671274458191225, 0.04483035406363862, 0.02879763687295573, 0.051138884121818204, 0.08927646053156682, 0.00978457335648792, 0.008850591955706477, 0.013023632362351885, 0.06094665998326881, 0.0525943247734436, 0.06310170077319656, 0.014926968042605689, 0.010856303303236408, 0.03525390775342073, 0.041367681297872744, 0.0581566257668393, 0.007807139955860163, 0.030781778440411602, 0.060211657280368466, 0.047182078406746895, 0.0406851463152894, 0.0811688220128417, 0.012270170114269214, 0.034016388801059554, 0.0355254676459091, 0.01331067642396582, 0.06600000882255179, 0.02826381301773446, 0.027591605338134935, 0.022476126439869404, 0.05274700533066477, 0.04676954607878413, 0.00788288057914802, 0.04781038147796478, 0.014367412443139722, 0.07786658206688506, 0.058410635351070335, 0.030340248918426887, 0.024748579233086536, 0.06696401030889579, 0.04038049766261663, 0.0007928180743225052, 0.04043274485905256, 0.025178716152108142, 0.05547543874542628, 0.01975038511279438, 0.0663687518930861, 0.036630438175052404, 0.028124206133985093, 0.016646150166967084, 0.07447003932403666, 0.03307144736338939, 0.09484190653477396, 0.03635313109095607, 0.07242296702627625, 0.03528968690495406, 0.046379242558032274, 0.04796418501064181, 0.08104674677763667, 0.034591738999422104, 0.0172237039078027, 0.02374000138869243, 0.025022050897989954, 0.06737940944731236, 0.056345354566084485, 0.028865358060491935, 0.021674476331099868, 0.06376716042203562, 0.03132676419668964, 0.028952526061662605, 0.05999349470117262, 0.031162518010075604, 0.05861604825726577, 0.011795448355509766, 0.04877204880384462, 0.017787420623270527, 0.04355371756745236, 0.05926302461219685, 0.051963999667870145, 0.0670379570552281, 0.03560215228104165, 0.021528014547324607, 0.08533700156424727, 0.08949051118854966, 0.01834454367469464, 0.011468454696504133, 0.03549671811716897, 0.028642632333295684, 0.023570939299783537, 0.047005686443299055, 0.04207377501630357, 0.010185452693674182, 0.03658536309376359, 0.008540109598210879, 0.013199450115540197, 0.019841561559587717, 0.03471230110153556, 0.02902342957843627, 0.009047384074489986, 0.009399658251952912, 0.014335875831810492, 0.05862577844943319, 0.01885955684286143, 0.024973318512950624, 0.018947036970140677, 0.015022359888202377, 0.06346530733363968, 0.03922270657494664, 0.007785571023954877, 0.037701858540198634, 0.04659638733470014, 0.010689719563483127, 0.048484784218349626, 0.04484524451462286, 0.003768396896443197, 0.10010756898139204, 0.03409504797309637, 0.07360243730779205, 0.017224453688998307, 0.027699489013424942, 0.028128251899033785, 0.06252059659787587, 0.048911277404321093, 0.04188634668077741, 0.0483352927757161, 0.07625810123447861, 0.045898344434265576, 0.05097255822537201, 0.03911969817376562, 0.03918063061844025, 0.051813012055520496, 0.035498092150581737, 0.005180022845576916, 0.06902690604329109, 0.015021177540932382, 0.028250456055892364, 0.002741577274199309, 0.02929048060572573, 0.017810490813904574, 0.020288500702008605, 0.010719469931375767, 0.04234067337321384, 0.026681979951847876, 0.030164294610066072, 0.06261874668832336, 0.04671548040849822, 0.03476204111107758, 0.0030636477375602616, 0.06421265937387943, 0.03413489833474159, 0.03897475291575704, 0.010802621005236037, 0.037550399346011024, 0.07605399790086917, 0.021094072743185928, 0.004641760523164911, 0.028400688798033764, 0.06294970214366913, 0.034470776561647654, 0.04976242155368839, 0.0076965675855587634, 0.07279867186610188, 0.010018752754798957, 0.04285467382786529, 0.044195900072476695, 0.03406937560066581, 0.04749834697161402, 0.048956267668732574, 0.06807977972286088, 0.048890626191028526, 0.0572680298771177, 0.052194162138870785, 0.027936572541615794, 0.017324724201379076, 0.015830625713403736, 0.07548997923731804, 0.06215935812464782, 0.029262396041303873, 0.019221689285976545, 0.002930240543459409, 0.042006661117609055, 0.03665882129488247, 0.02796892509130495, 0.04544516107333558, 0.04724174877628684, 0.04173253297007509, 0.03938336331131203, 0.0547630957194737, 0.014590911700257232, 0.01852314087695309, 0.03264902199485472, 0.057809432968497276, 0.018385742624689425, 0.016460784577897618, 0.058877949203763685, 0.03440435816134725, 0.0638877157387989, 0.03693543288058468, 0.018870898555698137, 0.036046762352011034, 0.04986062592693737, 0.05806672666221857, 0.022784875140392354, 0.06117236787187202, 0.050462571305355856, 0.028057967545464635, 0.04026914667338133, 0.017768491192587783, 0.06352708116173744, 0.05028274595471365, 0.079819107295147, 0.08285999590797083, 0.02613010197611792, 0.03388110927439161, 0.017005588826058165, 0.06880880453224693, 0.04448771423527172, 0.010841565522631364, 0.04730124951207212, 0.04033362785620349, 0.04704275141869273, 0.009904813154467514, 0.06121592303471906, 0.011765273903230471, 0.0087847766034039, 0.04481990462435143, 0.01678843217502747, 0.016974623880482147, 0.03651603377823319, 0.014958572507436787, 0.05156180142824139, 0.025636771394472038, 0.04295903929908361, 0.07224204923425402, 0.05681902629190257, 0.010758891119621694, 0.019761867621647458, 0.01276264404545405, 0.001809008710552007, 0.029317367555839673, 0.0323744222654828, 0.018645136384293437, 0.026288266792627316, 0.04124780112345304, 0.061918233920420916, 0.03927752881177834, 0.02506919890376074, 0.05901856880102839, 0.031229238358459303, 0.06622249366981642, 0.057759065314063, 0.011271118901536932, 0.03769718004124505, 0.01160184111047004, 0.018317310671721185, 0.032574854724641354, 0.019524982564949563, 0.0264768384596599, 0.08287041142050709, 0.02061638917907008, 0.02172767008388681, 0.023816041415557265, 0.03901995013334921, 0.056985358973698955, 0.03844110547964062, 0.03561868817944612, 0.032545575938586674, 0.03026372373902372, 0.019082065438851714, 0.033877730169998746, 0.03578029825751271, 0.012412855850665696, 0.0007427155786509891, 0.01242526201531291, 0.039288409120802364, 0.046288997400552034, 0.02624269638077489, 0.00836017822647201, 0.013180122045533997, 0.037129928158330064, 0.043993225055081506, 0.014904701915968741, 0.034212241148842235, 0.030004038209361688, 0.018911149253004363, 0.016656954140801514, 0.043464242547218285, 0.02785127899343414, 0.042345779349229166, 0.037467343267053366, 0.047231689494635375, 0.03063658551712121, 0.02263875092778887, 0.05552184036267655, 0.006033404464168208, 0.011173109607105809, 0.07905498865459647, 0.06125820255173104, 0.040883753515247784, 0.057983334708426676, 0.09200136217155627, 0.012619205135186868, 0.028657437967402593, 0.033623452564435344, 0.06551961960004908, 0.043116788512894084, 0.05217506137809583, 0.032938400216932805, 0.022751896642148495, 0.019991975809846605, 0.0396099465100893, 0.05453413086278098, 0.00826453956376229, 0.016938765001084124, 0.04514816290299807, 0.05863791065556662, 0.006436823218661759, 0.0661249610462359, 0.011885296570004096, 0.020052490955484763, 0.0327679115081472, 0.00912948087456503, 0.02574489594969366, 0.03161024934213076, 0.013805364075648998, 0.00843971610135798, 0.0516023099688547, 0.10130476259759494, 0.0186202799502228, 0.009180163199614202, 0.0111431421080072, 0.12214448648904051, 0.08239249206547226, 0.09474450283284698, 0.10391241338636194, 0.1146554412054164, 0.06332622801086732, 0.1495219359972647, 0.11097647861710616, 0.09593407650079046, 0.09003874034221683, 0.15398768708109856, 0.10881145657705409, 0.1379553430846759, 0.2000905725040606, 0.16978158030126775, 0.08860069393579449, 0.15848610284073011, 0.09364444828991379, 0.10848938314510242, 0.0987523038472448, 0.14683307813746588, 0.22650552008833202, 0.11011570944849934, 0.11150169186294079, 0.13857935102922575, 0.18057363906076976, 0.12382073939910956, 0.07794274762272835, 0.09994451023106064, 0.08340038798217263, 0.10561049476798091, 0.16095261834561825, 0.14262669027916022, 0.10996213661772863, 0.13406693030680927, 0.1094712233170867, 0.29896464624575203, 0.1076637078076601, 0.059948758887393136, 0.20967171766928264, 0.1561993041208812, 0.12996791382985456, 0.1272948794066906, 0.07990999027554478, 0.1404303131358964, 0.12474935528423105, 0.14944098676953996, 0.1369087706719126, 0.0973181522318295, 0.15382722711988858, 0.09032559780670063, 0.15735687129199505, 0.161204653392945, 0.13458701382790292, 0.09675915472741638, 0.157209289925439, 0.1643872811858143, 0.1756920274347067, 0.11674812462713037, 0.029807785525918007, 0.09739325248769351, 0.12110142888767378, 0.13269607243793352, 0.17927967278020723, 0.08911866042762995, 0.12389360048941203, 0.12465649098157883, 0.1468781057213034, 0.1917380371264049, 0.16573185260806764, 0.16891495537544998, 0.13637418007212027, 0.10630730273468153, 0.19766101001628808, 0.14423226698168687, 0.11576435741569314, 0.13966865757746355, 0.07626994167055402, 0.15551010253173964, 0.14243629335292748, 0.08830608760139771, 0.09863168746232986, 0.09223596565425396, 0.13648873035396847, 0.09613689740321466, 0.1754599820290293, 0.1381667067429849, 0.10768345317670278, 0.13302446981625898, 0.2616252712905407, 0.1885170042514801, 0.12419477504278932, 0.11284100463879959, 0.1959517260215112, 0.14117154479026794, 0.17674314603209496, 0.1032962357359273, 0.11091412124889237, 0.09876613917627505, 0.10364418849349022, 0.12495989112981729, 0.18838630483618804, 0.08602327866745846, 0.17874428150909288, 0.1513011905231646, 0.03667313838377595, 0.12345099209674767, 0.14254092345280306, 0.10359711851924658, 0.10548998694866896, 0.1443157267889806, 0.0861014255455562, 0.05110613462914314, 0.1831993388810328, 0.06472745032182761, 0.10359414653586489, 0.13062607922724315, 0.10026278386690787, 0.0836920291185379, 0.1296707290623869, 0.12229623406061105, 0.08443148301116057, 0.09456021950713225, 0.14464162715843745, 0.14578164741396904, 0.17098578996956348, 0.0711109788556184, 0.11410555642630373, 0.10304585631404604, 0.15143953024276666, 0.11912113800644875, 0.13883163034915924, 0.1463670874280589, 0.10610798985830375, 0.15425143364284719, 0.09307123547685997, 0.10577281391514198, 0.086154140931155, 0.18458659015595913, 0.0774396885452526, 0.0780074866488576, 0.1530865654349327, 0.13663517178169318, 0.17238966535244668, 0.16372368750827654, 0.13890111233506883, 0.19360763180468762, 0.10376551055482455, 0.1373547717396702, 0.13339979467647417, 0.1294978926224368, 0.15145145888839448, 0.16749311238527298, 0.09615356900862285, 0.1085096849128604, 0.10282518994063139, 0.10451094234096152, 0.0727858611249498, 0.17541120893188886, 0.10205054722194161, 0.16351061394172056, 0.07079789601266384, 0.18946461911712373, 0.0881919376552105, 0.13855952423598084, 0.26942142152360504, 0.151180804840156, 0.1760148743965796, 0.08200135055397238, 0.1588321557002408, 0.15558836476079055, 0.11344356409140996, 0.16448470524379186, 0.09235645311751536, 0.1512610755328621, 0.06692412602049963], [0.039472404069134166, 0.030856346046285968, 0.028576828007187163, 0.034516855874764066, 0.04460769279726914, 0.01653987292333373, 0.03579878833677087, 0.04120574213032212, 0.048705196141132286, 0.045626801505152664, 0.01284338886450444, 0.06623632899884667, 0.011680744555113571, 0.011856185721366532, 0.039800682703831365, 0.02531160384283534, 0.05360787967219949, 0.019373833800532987, 0.027298452765015618, 0.0382124900684825, 0.02309376124425658, 0.013359614065848291, 0.03144913459462779, 0.035450231683041365, 0.018832747924274633, 0.02436484902032784, 0.09718614324395146, 0.012862600735388696, 0.009707907381068383, 0.030323899617152553, 0.025059784230376993, 0.01878583401308528, 0.019744434360680834, 0.042372303283108134, 0.029534821065941026, 0.10890484335167067, 0.06377625279128551, 0.047654705188636265, 0.029937355180404017, 0.025387435220181942, 0.04737710633448192, 0.10169663014156477, 0.026478015717917254, 0.009646513532581074, 0.08743139489420823, 0.02663399395532906, 0.03273749956861138, 0.023587968832414066, 0.016879474611154625, 0.015826987069366232, 0.043332861204232485, 0.11418429362986769, 0.029366469742464166, 0.007255888776853681, 0.058364237126495154, 0.057824320026806424, 0.05883499115173306, 0.014790266985073686, 0.010552481615117617, 0.04041916398065431, 0.02530044872712876, 0.05543249087142093, 0.07085006178489753, 0.0063947515029992375, 0.0489781436377338, 0.06476497330835887, 0.04182825390515583, 0.01852984819561243, 0.019586208476019756, 0.010634757378803832, 0.027829777915030718, 0.07786307404083864, 0.038794340632323704, 0.038139768077858856, 0.016525774661983763, 0.03843011321233852, 0.04973785858601332, 0.036063559486397674, 0.031137035627450262, 0.03850504044177277, 0.04005633434280753, 0.0649918279211436, 0.018301185287003006, 0.033536260814539025, 0.003926402257223214, 0.02540370648992913, 0.06306956535471336, 0.03012806423274534, 0.06410551190908466, 0.010323246192586209, 0.038220937829464674, 0.05734141343938453, 0.07408927261297192, 0.016380018554627895, 0.0660692397505045, 0.08190579925264631, 0.029257228997136866, 0.05198648971106325, 0.009024825329626245, 0.006924382435889649, 0.010461523147699024, 0.037343235819467475, 0.03254523327840226, 0.05800469499081373, 0.024582158341737728, 0.014098853371771318, 0.06588451537702765, 0.021727804094552994, 0.04741524000252996, 0.018017257397462214, 0.036611205099948814, 0.02995306665876082, 0.0806567994877696, 0.05842602452529328, 0.017592881240748932, 0.03180718734594328, 0.05060928414708801, 0.03765947385025876, 0.029725302809051106, 0.013219031788009619, 0.03195912490731903, 0.09352358084704195, 0.02631250406349344, 0.020893151738813946, 0.0305652036331594, 0.054370152697499306, 0.046354211401194334, 0.03374442518023508, 0.04860610288700887, 0.03887256554194859, 0.03988266669745956, 0.09764984050499541, 0.05429322039708495, 0.06260350679180451, 0.04801057305719171, 0.038056630574698956, 0.020617619023791382, 0.014876198356172867, 0.052117399472211084, 0.04144478323204177, 0.00508098557059254, 0.049294971993991306, 0.0312509277303304, 0.012616553759601499, 0.06557477771171502, 0.0020044250995852053, 0.027689794444346, 0.0024294736420935287, 0.04722217643367393, 0.04932079703680106, 0.03776837872075183, 0.016893162358818308, 0.1187947898038796, 0.04392706789076328, 0.01907675590233079, 0.03129460842215589, 0.027113521438358084, 0.02953906190980758, 0.013908892404288054, 0.017316317152498022, 0.028360963965366994, 0.03991897510630744, 0.08137220609933138, 0.009160137086707567, 0.05401662916743329, 0.04662083834409714, 0.04380661774692791, 0.009064414455289287, 0.038621541511799605, 0.02086662780493498, 0.06653261810008969, 0.03980542227093663, 0.03521994368306228, 0.038884646857955625, 0.05980281957558223, 0.04416775443990316, 0.029449003349457468, 0.03113780915737152, 0.034545903958912404, 0.04025996609457901, 0.03791586509240525, 0.022936536198748008, 0.008810776368980961, 0.032854763990534205, 0.02887089490624411, 0.07086990214884281, 0.06720662729016372, 0.04884266733591046, 0.06833521423063108, 0.03907465023387756, 0.05386257118412426, 0.040622731271599016, 0.021231031644025018, 0.06043188939137118, 0.042213512518044026, 0.04959038578506027, 0.008973317736360644, 0.01914005813055805, 0.04573292777474437, 0.013153348750035678, 0.03987191870276417, 0.04470668087846466, 0.05469871970957943, 0.06613231636583805, 0.0271382387727499, 0.08493523419435535, 0.010893100257297712, 0.052635752729007175, 0.012933271853918476, 0.022635309058906775, 0.051517153824014325, 0.041990875000400205, 0.03050528559833765, 0.013556886248157492, 0.04205175994762352, 0.054095434224499125, 0.0282463458300169, 0.04764166374557784, 0.05508333710687501, 0.006416927299661828, 0.027463100983628204, 0.032400725675480704, 0.04829386142747743, 0.05568230032388653, 0.0065779500208528975, 0.022476884702752744, 0.041086737266076465, 0.09769182825194937, 0.03710200304963759, 0.020170723986146704, 0.011631125833706131, 0.058897837065160275, 0.06336946426225559, 0.07499825169465371, 0.07492988929152489, 0.05506216681429318, 0.03953695649813328, 0.020441065908276608, 0.00899542186276189, 0.05554017098620534, 0.03786084608041814, 0.03544275761981096, 0.023948671262977377, 0.021067564076344882, 0.03046684998220631, 0.05979214621973889, 0.05972164643130132, 0.0972186993541462, 0.006071611074730754, 0.03374868638015219, 0.010351757385901042, 0.041528046264180114, 0.04049053568659084, 0.037896961106785705, 0.07899921307606356, 0.03290759472708617, 0.06522831773119313, 0.05703213717788458, 0.02515016170218587, 0.01501971360162965, 0.014499324739777615, 0.031517171300947666, 0.017618070156978707, 0.035607675556093454, 0.010307596630549856, 0.0594571874077831, 0.035018425567873886, 0.0371959767570453, 0.047685782092490366, 0.08034490408109767, 0.035052247145878415, 0.05828160513192415, 0.042112916308854303, 0.05877477116882801, 0.035584534119282446, 0.04754537284108145, 0.06328901715044465, 0.03426637467263, 0.048569020948239734, 0.04439419175365141, 0.013758151609051441, 0.043540347034909894, 0.01015177191168602, 0.022824213208098496, 0.010429780431357878, 0.040869446604379585, 0.023080982733517885, 0.03526101201506598, 0.06817674237702574, 0.03778513175036226, 0.028178605982767682, 0.04434386820399335, 0.04297348530963063, 0.0074375817951347145, 0.021155592120651687, 0.024134952874322022, 0.05290359424959336, 0.05565744897882853, 0.014513097304318632, 0.022399206013817872, 0.045837639298822196, 0.046746472495474985, 0.019530968940151588, 0.037083818311137814, 0.019803622970357537, 0.06011120695620775, 0.03243067281852875, 0.07689722693924393, 0.034124038381768126, 0.007820341702816742, 0.018083134666085243, 0.05078788474202156, 0.017519931940894042, 0.056353697154138765, 0.05951048633349793, 0.025355033476703932, 0.008180355420336127, 0.004626215285887676, 0.06490900593676738, 0.007283256638662091, 0.04594720234828336, 0.01866768579930067, 0.05466804314138634, 0.033483060276401896, 0.01044231721399618, 0.05346420327467578, 0.011848396987521222, 0.02522185740859381, 0.013889371799970312, 0.021408107231504152, 0.02743116912565061, 0.009255577277924334, 0.06673299627644674, 0.0410101069137454, 0.0269978956785053, 0.00902982019553227, 0.03684496719922338, 0.0067826016955742875, 0.11374057243977274, 0.03425651216613395, 0.017467170754181485, 0.03149310027116111, 0.02794801433836775, 0.023270468726488094, 0.08004372952772038, 0.039473316698734245, 0.002948595763882622, 0.06508492971105234, 0.07229785873953785, 0.02825723122805357, 0.09148085117340088, 0.05263895880697029, 0.10442651901394129, 0.07672348126236882, 0.08097301037716013, 0.11327800833220993, 0.10861173657966511, 0.12039086701614515, 0.08203888711120401, 0.08955932821014098, 0.09753132757863828, 0.17941590904125146, 0.1336230326976095, 0.17372382804751396, 0.16753956489264965, 0.14756519028118678, 0.133008388536317, 0.08524379799408571, 0.08195569871791772, 0.16242422509406293, 0.10313771638487067, 0.16279018617102078, 0.16444408813757555, 0.1363991094487054, 0.19461509345897607, 0.07818896083959512, 0.06681230344942637, 0.09983697600130524, 0.1503209245524236, 0.1461676795567785, 0.061997887146260054, 0.13305923795061453, 0.169470092015607, 0.21189050003886223, 0.031549958113048754, 0.09375313602920089, 0.10848229245415755, 0.16579575703612395, 0.15198022765772684, 0.11948696337640285, 0.15866727169070924, 0.14337393375379698, 0.19310703580932959, 0.16015092922108515, 0.11188087758741208, 0.1384156205292259, 0.14029851449387415, 0.1161128394305706, 0.09071920918566839, 0.09893244810934577, 0.192686724077378, 0.06305482757410832, 0.102174854837358, 0.32771832762019976, 0.07745747294809137, 0.08068299093948943, 0.19190700591674872, 0.17679846020681517, 0.12385682389140129, 0.18332351078944548, 0.14074290064828737, 0.1524627881922892, 0.09914053444351469, 0.1260385446782623, 0.1409328497414078, 0.10942946627203907, 0.09411372310881104, 0.1288096002702202, 0.1282813743289028, 0.12123351251440388, 0.17307479573147638, 0.20762689810778412, 0.1609421553356307, 0.21132198268813746, 0.19367340898939542, 0.11213246480162654, 0.14161469601094723, 0.12252488679119519, 0.07171058668089764, 0.13705522567033768, 0.17973045073449612, 0.1404336786695889, 0.243629301232951, 0.12895627239985125, 0.13505983059959753, 0.17878530573632034, 0.045186615482504876, 0.1543591171503067, 0.15213828560497078, 0.13665943619396004, 0.14088197318570955, 0.17703187625323022, 0.08760824147611856, 0.18831653786557062, 0.12272607242422444, 0.2209378145635128, 0.13630000262388162, 0.2056719165827547, 0.11317197366484574, 0.11323453459356513, 0.1028721717053226, 0.17194405783499989, 0.11936602129467896, 0.1226840711065701, 0.14217598017837318, 0.13126813620328903, 0.08176976655210767, 0.14647445880940982, 0.1371216813900641, 0.0717644759320787, 0.13716142997145653, 0.14256689777331694, 0.12288087340337889, 0.16328980507595198, 0.18896916641720704, 0.11712745284395558, 0.08157995995134115, 0.1939883985157524, 0.11260363273322582, 0.18123477644154004, 0.0680589826245393, 0.08066045000616993, 0.14712917724890368, 0.21078769064375333, 0.14887164160609245, 0.15546734125486442, 0.10029373184910842, 0.13998005086822168, 0.10155833113406386, 0.1005051972876702, 0.12334120513073035, 0.12549775226839952, 0.10531996642904622, 0.1561897774892194, 0.18520240139748367, 0.14187297358044557, 0.12507076375186443, 0.20707433990069798, 0.12098922633699008, 0.1208972984126636, 0.12394645836736475, 0.09446525853127241, 0.11507153244955198, 0.11243042309901544, 0.16625907431755746, 0.08267232669251305, 0.16077147663703986, 0.09625957653458629, 0.13041090220212936, 0.15006287768483162, 0.10600945978824582, 0.08733101920889956, 0.13037662261298724, 0.0955031660518476, 0.23387419325964792, 0.09595898552132504, 0.09124344534107617, 0.15238529949315957, 0.1722076279776437, 0.1542111150920391, 0.08732339926064014, 0.14823198664401258, 0.12310541421175003, 0.09122062620839902, 0.13043931924871036, 0.0746935216177787, 0.16392286467765058, 0.10008614084550313, 0.08259303987558399, 0.13541935916457856, 0.12147463671863079, 0.09263431320765189, 0.08996474609843322, 0.15327560529112816, 0.2045152179364647, 0.11982103330748421, 0.18257117830216885, 0.10011992510408163], [0.06330102722027472, 0.037044717730688195, 0.018741568084806204, 0.054971358472747464, 0.0556564583177013, 0.0021876954997424036, 0.02464277357129114, 0.0094866159072678, 0.006334890719569687, 0.02327024650626949, 0.016415108993117298, 0.032642206110592396, 0.035386507066765, 0.11332849812294755, 0.04185342416167259, 0.08110057496066604, 0.02473611115211887, 0.03916652048272746, 0.03458239896489041, 0.02231370042344289, 0.018526647206661955, 0.029004630765744617, 0.04428398070324745, 0.010425462404132953, 0.056547747991446934, 0.021342092559539845, 0.031239925285003016, 0.03635849830295358, 0.013196156676193433, 0.024134523700922728, 0.010969888369020606, 0.02116277102114899, 0.05351703740390284, 0.07196937315165997, 0.03410121585641589, 0.0119265743996948, 0.046202813275158405, 0.017054177022406032, 0.03325974422373942, 0.06792081253869192, 0.021987408200012784, 0.017486154467665722, 0.033633481312010965, 0.033236039602862935, 0.029831697099975178, 0.013668449279586119, 0.01762453150669379, 0.02132446252341781, 0.047992961680782695, 0.04866920325106808, 0.027728710124003034, 0.05491982034540602, 0.021820849905322705, 0.04624324717691966, 0.027980675621490394, 0.020431252595569407, 0.04582305758127144, 0.018510498073218123, 0.02853747976145574, 0.046636621068630896, 0.05386916993718062, 0.06057436817458697, 0.029477193086807216, 0.047523395091827424, 0.018136635455968123, 0.045464160053857734, 0.03932389310960259, 0.01679628961054342, 0.023641143925487995, 0.03364211906279836, 0.018542736968291656, 0.031766614344503195, 0.026462216030008028, 0.03189770391743098, 0.042287537295903475, 0.019838223167295967, 0.028085200548438088, 0.009004767834474998, 0.03746882586606911, 0.04369766877165862, 0.03109082060733012, 0.03643046033435634, 0.08367987655635391, 0.007836120186506637, 0.020825225294434598, 0.03711410811437028, 0.02918293959062014, 0.03822379106921809, 0.010280907303760094, 0.025730205666539923, 0.030402911627399068, 0.013266162830404937, 0.04643618182412215, 0.04522333779771413, 0.02637453573489828, 0.031229557269918065, 0.039235486782022884, 0.03604134424988713, 0.035937884622918706, 0.03013687500996249, 0.04947430879942008, 0.03878546539427979, 0.04512934373425586, 0.03457212933738317, 0.02138809553746666, 0.032241979015192816, 0.0780513539378132, 0.07962121934230838, 0.04321791737207344, 0.018422161295477833, 0.025097582023590803, 0.05785951563822372, 0.0571129032011543, 0.07215642490025077, 0.04688780455450926, 0.02413349911304457, 0.02303592631194208, 0.0015915376009486082, 0.010423276673204132, 0.009873068741788822, 0.010703072284481354, 0.05180896120145917, 0.04457877702744944, 0.07700041854487998, 0.02630746933365507, 0.021042921380805116, 0.06082181632518768, 0.03425743158108421, 0.027139589057437012, 0.05195840175396629, 0.03790486264707787, 0.016628152025597434, 0.0290926944331399, 0.013701347201796514, 0.01675067000490214, 0.06885491098676409, 0.04097797488793731, 0.03628089764554586, 0.06788812750684363, 0.013128089435797716, 0.04200958560353943, 0.04888187648196306, 0.028789402850504433, 0.04012096819600888, 0.025973713225019828, 0.043953147384205034, 0.024457541992887855, 0.04152092843183449, 0.04437554221866386, 0.050186794317726574, 0.010461160131464047, 0.03942655885059919, 0.03167211477245603, 0.06361850697015013, 0.033025055924164395, 0.06185979848461492, 0.01618063952108579, 0.038517098009054146, 0.016994922255565013, 0.04021371714770794, 0.019305060883717876, 0.060873113572597504, 0.06321912804352385, 0.06494088351194348, 0.06255236560744898, 0.04286250751465559, 0.036856332660785744, 0.007828745359022702, 0.0572701401210257, 0.0511104195777859, 0.017785269667261412, 0.063157605273383, 0.06981296172099453, 0.02956462910931025, 0.039493835597698174, 0.11147140205970832, 0.009878939766037678, 0.08137920179537364, 0.032600337107266696, 0.009928960519443666, 0.021777749360938157, 0.033996616290616136, 0.04771035184551563, 0.063556719571352, 0.03507206715377314, 0.012297428562305868, 0.03605659093175616, 0.04890024442491787, 0.029807483577834706, 0.034879291962300024, 0.01095037963906569, 0.03737548998157893, 0.033742433679955344, 0.08324287286294357, 0.006663678679615259, 0.00716517712654812, 0.03163241368851491, 0.024188119485708218, 0.056825302740825076, 0.03464297178600516, 0.02388530457392335, 0.03603172940867288, 0.01657261054164597, 0.011282084875607064, 0.044344997964799404, 0.0339752458302038, 0.04598722234368324, 0.03917677993220942, 0.033357789141259024, 0.04582064538928015, 0.06016045502786126, 0.03230012946629098, 0.021352272281157117, 0.06979693472385406, 0.033631309999951293, 0.0212942473590374, 0.0350875004327723, 0.03334301743390305, 0.01350254237851394, 0.013698221699866866, 0.027206200840217725, 0.0790028568091137, 0.006049473869747349, 0.0046892834195335, 0.03475828202707427, 0.042498768639883826, 0.07531746849417686, 0.047565359090055735, 0.011820555847537304, 0.005812308069185487, 0.03415834511231099, 0.007336940633000008, 0.04351386720580714, 0.042618608102202415, 0.015146993200427719, 0.10201634227165154, 0.03469578216650656, 0.01648733565317733, 0.06910936161875725, 0.06627959917698588, 0.04877941430147205, 0.012646463583223522, 0.030433893536350558, 0.048987904363977056, 0.017475023100684797, 0.03833278075658849, 0.029420952711786543, 0.015786027302965522, 0.05260219577965992, 0.05107797881854432, 0.05341642762401274, 0.036673816918794594, 0.041660496299820285, 0.028999860664563518, 0.011472966106209372, 0.03828776674345136, 0.08503607128347669, 0.07379596906581096, 0.0502531516498753, 0.05959438718855381, 0.03354213014245033, 0.04591971489467791, 0.047866496324006996, 0.06506611393498522, 0.057937947501029284, 0.04211302826713238, 0.038272160438022444, 0.009403608173930218, 0.021112399974039624, 0.008258370832274002, 0.03439505205356649, 0.049416287269975455, 0.03316737525165081, 0.05609934151704822, 0.07910766332809414, 0.04830849403515458, 0.03126021008938551, 0.050126686293099604, 0.048984352233154435, 0.05412016004057867, 0.043873304168560674, 0.024580092202605944, 0.04323881285797272, 0.0749673308538539, 0.0038403228806730893, 0.029246681170271974, 0.02868816881839718, 0.053631465549447706, 0.09837064146995544, 0.0366080974095634, 0.050443881058267186, 0.07367499305733613, 0.007235778695238488, 0.03446289877008114, 0.029118678931679045, 0.05095022763790829, 0.07947219948151282, 0.03508339190323438, 0.02863425242581538, 0.06921697727271489, 0.01489336698848222, 0.026257373093228255, 0.039794155196951966, 0.03870797669515014, 0.035908364956932406, 0.02445549112079399, 0.02555133535393647, 0.04644583059208734, 0.010945038720300155, 0.00950684812518635, 0.016770328860729933, 0.042294404070292196, 0.0190525780032788, 0.11525223989571844, 0.032754900599164624, 0.05027804709970951, 0.025987858983821104, 0.026729182240420153, 0.010874316711643977, 0.023914659695167626, 0.020397458158965622, 0.01654359808058611, 0.04877361961241279, 0.02983179209487779, 0.022840935703633086, 0.017985595257154534, 0.06174202516142811, 0.007720240824190634, 0.04716597677075437, 0.06690381746739149, 0.057969214394688606, 0.051656911681805334, 0.04412876921040671, 0.050778609168316634, 0.007517235020973853, 0.047295427681612115, 0.05666994197028024, 0.011991284588085753, 0.030783593521586487, 0.041164951997676065, 0.046035038706447394, 0.015011277715010303, 0.09053222529057946, 0.00731391115446708, 0.027573425688647797, 0.01831037943650569, 0.0372031081600913, 0.058008569425770214, 0.09187370937849794, 0.03875475829201085, 0.04706269695556589, 0.04752361561570849, 0.13040498537676676, 0.2002549815390791, 0.10896659682371787, 0.1257162812565054, 0.25331202309046474, 0.12642305690262998, 0.19181847066751548, 0.10133022123149463, 0.14842633264405386, 0.08025106947336878, 0.10374893394431897, 0.10733830276876688, 0.12659545908016817, 0.14251265568392618, 0.0888449258304068, 0.16102249388183865, 0.1158073493944747, 0.14545847475528717, 0.08869428427091666, 0.12239915425223963, 0.11049098681126322, 0.12854841857084207, 0.11358164596770491, 0.14623448811471462, 0.16892094005431446, 0.187404654654009, 0.12303309594946248, 0.15472446754574776, 0.09322561576430287, 0.08160255516746215, 0.09286409909171717, 0.1433482308472906, 0.17764413197125706, 0.20259212755731174, 0.16354349574872426, 0.12052044006330626, 0.10289222920047385, 0.13317472461078847, 0.2212450145078557, 0.18088176181273802, 0.14519654666738852, 0.11849675008228847, 0.08542793204209634, 0.11565771885216236, 0.10969165220324482, 0.22306190058588982, 0.05624329950660467, 0.11264244493629251, 0.09263897474323, 0.2002262795077903, 0.13325646093913487, 0.12318769336811133, 0.12066654222352163, 0.1025469091587833, 0.17768164138708795, 0.068339468645198, 0.060109137424400876, 0.14628627390733787, 0.08223881745444876, 0.2482777275145054, 0.08245193851845604, 0.110120499905731, 0.14015820702271803, 0.21071453099804266, 0.19044472223946027, 0.1956926749220916, 0.17975219099649362, 0.10463953829769577, 0.08956812202398266, 0.0891285263268011, 0.13795959071389266, 0.21863421531660215, 0.16971133835613728, 0.10503967718354293, 0.11289454105177096, 0.09067359806171485, 0.16967719447399887, 0.07632609722869736, 0.11706390125410897, 0.1700873960341726, 0.1430518738925457, 0.12754280253180436, 0.20131897873112134, 0.10698486066290311, 0.10357277946812765, 0.182789788714477, 0.10885995147483689, 0.15265865411077226, 0.13182928466371127, 0.1218409099216972, 0.12880156641559942, 0.08851250473942075, 0.14927554636129312, 0.13229884446731635, 0.11277826050562517, 0.1476369792861598, 0.088049106033785, 0.12897988541850022, 0.16950439874614986, 0.09835472982376814, 0.12623878036226543, 0.22823901421257428, 0.17400608504457132, 0.16079272835382394, 0.1150095279195479, 0.12968425905065878, 0.20038880221545696, 0.1992420916046415, 0.18105489680809633, 0.11369428956615073, 0.1048739178638373, 0.1800856909581593, 0.26359098723956514, 0.1578794111098562, 0.1026026847373162, 0.1486290381955249, 0.12348506812538419, 0.1009226863139442, 0.10891762016607182, 0.13052978153739656, 0.1581534578331879, 0.14247832181198256, 0.11246225996209042, 0.18155129945703916, 0.07190337883574621, 0.11707768908568791, 0.10429177552993808, 0.19758080717708382, 0.1480305024555751, 0.1580731464283807, 0.15154455389295304, 0.09874525386840105, 0.13937642611563206, 0.1745493880340031, 0.15536406822502613, 0.11365902610123158, 0.14922171139291354, 0.24272513974990162, 0.11897038109600544, 0.1609305523868118, 0.24400979653000832, 0.16886549017259053, 0.12177879682609014, 0.12273326489542212, 0.08374076150357723, 0.155718277075461, 0.12042665295302868, 0.1042453298079116, 0.08997669510011162, 0.09949046173798186, 0.15429609481777462, 0.06030291345502649, 0.2284176860536848, 0.0876021482316511, 0.10822166036814451, 0.1448990497738123, 0.08651664826486792, 0.1001789305093033, 0.10794483165123633, 0.11365863933627095, 0.18728280333536013, 0.13011510164609977, 0.29105287364550997, 0.155473583777036, 0.20161867407815798, 0.11694481835833617, 0.1385480027113642, 0.07480247398572308, 0.2006572170981339, 0.1281887950109584, 0.10820482591433184, 0.12240166483180863, 0.15255734883248806, 0.12726925792438643, 0.2267541488898652, 0.13041989957647665], [0.01494779228232801, 0.06210899047021355, 0.03295124149216073, 0.03295261552557349, 0.021644612308591604, 0.05373823642730713, 0.09066477710647242, 0.01947223155626229, 0.013615800899320414, 0.026459564654422656, 0.04510472648377929, 0.020555527980572412, 0.06731770347271647, 0.019499625711302673, 0.10122411871062857, 0.0367628237498658, 0.010849096413169588, 0.04668309393205813, 0.02372687343241913, 0.0346001256922526, 0.010240872041322291, 0.027334790011601787, 0.004122943742134209, 0.04914618283510208, 0.021002523102132336, 0.013582159133095826, 0.07138400099107198, 0.03248383603723986, 0.027253260636436086, 0.03981659774269376, 0.021264525828883052, 0.050979553921414275, 0.023348147415422967, 0.018755749466695955, 0.010003707937097974, 0.04647245291354401, 0.04167257761582732, 0.041514502705207894, 0.028261539925421988, 0.034686774614134004, 0.046077901763575416, 0.017824332928285003, 0.07886005232908896, 0.018410091853833625, 0.05396785267761775, 0.08090774887906653, 0.058591519216341634, 0.05296478793025017, 0.019395935382427912, 0.013941298388609928, 0.022528317657166293, 0.045708931383809874, 0.05462613342595952, 0.034054946553494246, 0.04929815771590386, 0.03630662430077791, 0.018697863644255058, 0.05203675219256963, 0.02862743314887796, 0.022964775129886608, 0.03340181927861912, 0.09622693221483912, 0.04181040504149028, 0.029387154882507663, 0.06815658988697187, 0.035960255922483544, 0.040559278069330115, 0.016627885700602616, 0.014536908794460552, 0.025171013083308935, 0.04063756065443158, 0.016705806965806654, 0.03314346707026873, 0.013543400364661855, 0.03798031234847648, 0.03213186635236655, 0.01944383147305676, 0.018735551175528338, 0.04428192474214094, 0.021725341012435298, 0.039001999489430866, 0.02624807207446013, 0.04838802512469036, 0.056525563289012225, 0.052933934942952225, 0.03684066867988024, 0.0316647017773773, 0.0409960001707077, 0.03485846093722752, 0.024149405670219233, 0.04435081979525941, 0.05149794449763639, 0.059374202575002394, 0.04899643015648637, 0.017525302545566643, 0.06699174203510795, 0.09202703793666192, 0.01857126088413809, 0.04513051759983812, 0.036340076077197275, 0.07202938278870923, 0.028374371817335486, 0.010047509068889278, 0.04246347124821373, 0.015266057436487504, 0.02875649729477508, 0.03705488557794264, 0.00717991151447807, 0.004149078790630613, 0.03113129861386759, 0.028956692266677107, 0.01778877430063273, 0.07723287107156855, 0.038553413203252215, 0.04072901360424502, 0.012926407624036074, 0.023902932913707833, 0.04487237913001861, 0.021881241218319962, 0.01353660992546273, 0.022826574509963393, 0.006622045891292925, 0.0564800437672862, 0.03366744877504451, 0.04894076992890664, 0.040591488126665354, 0.033276334404945374, 0.03701978496142796, 0.009385252953507006, 0.024990025741447295, 0.010059452981555035, 0.019398379804832593, 0.04991374843354736, 0.011085116337718708, 0.055887038087738414, 0.019002893972875814, 0.013811181665265133, 0.011246713693253696, 0.01731510427115219, 0.018109890998208096, 0.08527674765459128, 0.09466324147901364, 0.02227340222868536, 0.04303552037371056, 0.02707259390237076, 0.02427629511138158, 0.09585057598139558, 0.042820367097322426, 0.09553196986338922, 0.06783980902816568, 0.011463083243662757, 0.0013424643589782395, 0.0214556759289865, 0.050419748960328956, 0.07211989936019693, 0.06556854197489363, 0.06070411764085293, 0.027673921813922267, 0.03797098927732025, 0.06266749264406306, 0.04414959005745394, 0.0014598994748666883, 0.02146845613606274, 0.031062091434640542, 0.029398028406181505, 0.06489387460585151, 0.009400753237839257, 0.07927826738783292, 0.0041273987486160225, 0.025452398162867342, 0.07535089991454567, 0.02371441892215184, 0.040457524957933595, 0.037809226528874466, 0.02359277625302119, 0.025035228048052107, 0.03737700650734561, 0.0827168318043862, 0.04702062099905951, 0.0070532837333822885, 0.028468940939222063, 0.05306927553777184, 0.02521826626200761, 0.029201819827514033, 0.010733609752995628, 0.06579022615083627, 0.015268384811601468, 0.0323369705251285, 0.029970674642494748, 0.0329830342504595, 0.10543847257005316, 0.05779462054904018, 0.035118414488221915, 0.04597211815416813, 0.02101924390132938, 0.009407781164294906, 0.050031582824885845, 0.028594357959393944, 0.0409315902340625, 0.01516442306871925, 0.02305915086929287, 0.05553480716688292, 0.031719805606241734, 0.04977206014362829, 0.07536389386015278, 0.05077834453965936, 0.030250024116997207, 0.02655810659884342, 0.021335166413336992, 0.02702269782977445, 0.10902069642075471, 0.02059689486798431, 0.026797222339415123, 0.03156838373148015, 0.021885180114103214, 0.041725767975939174, 0.044892046467534134, 0.10979400242545775, 0.06999128072389535, 0.03917481218065534, 0.0160087649045246, 0.042048679398638864, 0.012859913736714848, 0.00953435169399849, 0.0313982207195035, 0.005390851733474327, 0.02265210449695587, 0.04705873431105699, 0.015872260622148002, 0.044299010253910504, 0.01831910539684551, 0.047002453223935196, 0.012079740109454309, 0.05357543212760772, 0.023907055013946125, 0.020517611443730335, 0.02275811371925686, 0.04681070601301534, 0.03154601582459041, 0.01142491225618869, 0.03385678718664816, 0.02840476848983339, 0.037918867609862766, 0.046592193988284895, 0.026954918966761658, 0.02790006566127496, 0.01659809292427131, 0.03681355102785996, 0.029696705950690166, 0.018355178014774407, 0.013254856740656708, 0.02736523587788854, 0.01579382536666734, 0.05945364545498576, 0.022000597224437764, 0.028579226628478085, 0.01910905077654336, 0.02395240999093013, 0.020111923837768178, 0.024005607136392167, 0.007782708454344953, 0.011894553483996009, 0.018128002794193368, 0.060629377008548806, 0.02307188866793045, 0.04033541240330253, 0.06963319065315382, 0.029638959227928093, 0.06516173987516335, 0.0848630109269704, 0.00899402068794838, 0.01012342271860689, 0.0197930734471551, 0.06233178065823657, 0.017348934330844452, 0.026926223720823015, 0.037258059318576536, 0.015968622772821357, 0.03332718042656779, 0.03046727745926806, 0.03433614503592253, 0.01539187309598284, 0.019888180308043957, 0.0489514873895262, 0.017972180619835854, 0.06180582780923162, 0.039208121464720795, 0.02816702169366181, 0.04783738038635679, 0.022544149575488906, 0.015496408200955816, 0.03267326605107103, 0.06459540062184844, 0.07780692526804549, 0.026961868861690164, 0.022262856098158017, 0.018838213523849845, 0.017017017052109753, 0.010826144966163805, 0.0293220223060676, 0.042435271332838705, 0.0869053809770516, 0.019798367716638104, 0.03499557929379599, 0.07484499777534179, 0.012117048509285917, 0.03500830861074584, 0.021330437024257014, 0.0776645957625338, 0.035963458607771566, 0.061956381159169335, 0.008669441765440362, 0.013023931765928864, 0.024748711547415172, 0.05601331006203379, 0.01563050538035376, 0.03086590321202363, 0.04783088341355324, 0.01927192971509482, 0.021100649443854178, 0.020298700779676437, 0.030431759543716908, 0.09921994339674711, 0.04071593823443566, 0.07367649940507752, 0.01881871073107634, 0.028875651436724832, 0.06524452114743845, 0.056476440746337175, 0.04808087267779878, 0.05460376551906977, 0.044009143486618996, 0.04906403599306941, 0.0303535957022437, 0.053188188799789975, 0.035426978287952285, 0.015707222245899693, 0.008892242979657437, 0.0741231654371534, 0.06301733172897782, 0.062426721278045855, 0.018495229338960986, 0.01832905950556908, 0.041678979593728266, 0.04412000593064087, 0.06852939738226788, 0.0257139513601682, 0.04311871215967195, 0.047583838991288624, 0.06919907751892294, 0.019579041449885284, 0.025490542008940662, 0.08211415700082268, 0.1416819795433964, 0.07309272858713355, 0.13505976274609566, 0.18963843264750072, 0.19104097810174736, 0.15523741287844522, 0.0927520797454885, 0.09761865503553833, 0.15673579461872578, 0.2109372126204627, 0.117941233462521, 0.2665235341659614, 0.12198930553027562, 0.21889923752418586, 0.14354432746767998, 0.06499821293566908, 0.14221575590116636, 0.11450817196496896, 0.07966457773000002, 0.0788970799850566, 0.10540349408984184, 0.15937874279916286, 0.13636614621749946, 0.09340091528637068, 0.14157889650336333, 0.19721924300704682, 0.11665862585817065, 0.11864324579281466, 0.1538452354392835, 0.08332930465361901, 0.10876969953200646, 0.1322123176817383, 0.12286837478833539, 0.24306562862225942, 0.1441718502236264, 0.10716702017400946, 0.14197678943829878, 0.11277271687452282, 0.1011157159560493, 0.12722553312778473, 0.12433857018394129, 0.19752423092722893, 0.16650253268224852, 0.12974133741642746, 0.1741771437227726, 0.22178842606289045, 0.10577182325401477, 0.10060759500733443, 0.09230713719235999, 0.061963091870503764, 0.12567350640892982, 0.12516391303922447, 0.13724875742835657, 0.12455297367913382, 0.09241897333413363, 0.06881890791867461, 0.23868503368326596, 0.12074971704610757, 0.09732615215969936, 0.08182018848934344, 0.12319840065070561, 0.11809219393346991, 0.10964690281876496, 0.12531703125153268, 0.1633214790906225, 0.08925925966884408, 0.08549132756888866, 0.06714720797858068, 0.12728380571518624, 0.09553785954735108, 0.07937641069293022, 0.15781952360911028, 0.09567680994846992, 0.16320732235908508, 0.20310940194342816, 0.09485264095876898, 0.17180195903139456, 0.18462758724178585, 0.15936454784657272, 0.1126384280089821, 0.08380808574812752, 0.1916251696114029, 0.1500740870833397, 0.14906914957932063, 0.12444344455642359, 0.15063300994890078, 0.10806052865726606, 0.12925108229475363, 0.11472429893910885, 0.127997719549707, 0.2522243857383728, 0.15820501292390482, 0.11316645038979394, 0.1384389621338674, 0.14129727732922348, 0.1881156372172492, 0.18290687671729497, 0.1810221914201975, 0.10799116880765983, 0.08496838063001633, 0.08923139223562819, 0.15247665744807037, 0.11736511651958738, 0.1274323777428695, 0.2063671571335622, 0.0930027441520776, 0.13654735577957972, 0.13634731008538178, 0.1408994658184903, 0.15377141082925455, 0.13335119799843856, 0.16935976222157478, 0.056999581067689827, 0.11229904514870473, 0.08547760759081159, 0.15000768564641476, 0.20958612726203033, 0.10290356752063547, 0.10038166320217506, 0.12151106047843184, 0.11984172862555299, 0.10921338001000029, 0.0945300246988024, 0.09387169645300933, 0.1156995708921126, 0.19158349399055752, 0.12693058752587863, 0.27068363236529486, 0.1019498933372753, 0.14601977249341352, 0.0734692205275808, 0.1613611371389457, 0.1027309549972415, 0.16228479971843107, 0.10575278356139149, 0.11295089338506971, 0.14292002096772194, 0.11292586901358195, 0.21654708231134073, 0.23069256969860621, 0.24392427397625788, 0.10105186581079449, 0.12869673275521823, 0.17529372737876006, 0.13710637364004338, 0.28708914348057335, 0.10039368005735533, 0.16808277288717882, 0.11946477528129305, 0.05706946338926043, 0.12410691832857472, 0.1414210285459246, 0.11610944675547735, 0.10997867930148329, 0.14003691210278443, 0.16331986417727812, 0.10859332792460918, 0.13808943517506123, 0.14818049940679753, 0.10128629287438733, 0.12969130224415235, 0.18705562981111662, 0.09487052035651036, 0.20414334003414425, 0.24012635062847817, 0.10413556998329503, 0.15676684438117913, 0.08911438565701246, 0.20398682914674282, 0.12964588111000402, 0.15004530362784863, 0.12690516960408005, 0.1810433752834797, 0.12212677672505379, 0.09391694116805281], [0.022209935455716083, 0.03276012531880822, 0.04307278551693473, 0.009693881214064146, 0.010818305342192096, 0.10917875436799866, 0.05813852245254176, 0.03653542970174125, 0.012371460125515503, 0.01918203739582428, 0.016154390393889377, 0.026517007732763886, 0.030937994165079932, 0.050244585145264864, 0.015534920152276754, 0.04267499775492719, 0.06924409153206007, 0.02686936078992273, 0.03696655388921499, 0.017619800421276262, 0.04654451333252447, 0.033019814241145334, 0.08268910007817404, 0.037300881663603444, 0.055736257428569455, 0.016922090003000836, 0.05842992610165051, 0.04720669565722346, 0.0352637091917651, 0.039288412513477464, 0.04061339123706732, 0.01714453413816435, 0.06895374639758042, 0.036217844778937955, 0.05602714539106403, 0.047087008865284066, 0.021751881909689734, 0.04433698785890426, 0.010781562670932283, 0.036904464542333565, 0.02009348973764905, 0.040674890258482525, 0.013205805444158614, 0.036378050289515934, 0.02431658821712647, 0.05282506399921008, 0.01842763028772814, 0.039255035375910144, 0.02104793575459293, 0.04690138543290751, 0.026921385766140053, 0.035386853119624515, 0.035200110104467185, 0.03405211366979139, 0.08547023191515889, 0.030366352160594294, 0.04948842911315816, 0.01635136910980301, 0.0520258718835456, 0.025623151500310217, 0.022001764304669838, 0.05290971463546157, 0.03427760781986373, 0.011121026955411902, 0.016195341678602353, 0.01089315369193043, 0.033278431078152995, 0.03317587390275938, 0.0411086539471788, 0.05310512932815722, 0.1081816064459937, 0.029052375882331814, 0.020757115645600215, 0.019795565367011086, 0.025421058326693516, 0.0391016389642443, 0.028686078930539743, 0.06189641223422118, 0.021041757693248134, 0.013127008868780519, 0.035487517182316096, 0.02444834614704762, 0.017844105438728417, 0.05172461929864117, 0.04421594399692757, 0.017341122696442262, 0.02610754916843559, 0.012820142254765545, 0.05290057137608528, 0.02502233927537288, 0.017418986286169717, 0.03402515886617558, 0.012265781689036106, 0.022928607517055104, 0.006205272295379213, 0.009963004317666804, 0.03020544097359691, 0.049651535360940864, 0.03950800001621246, 0.04273808454828603, 0.01085720066579857, 0.03076176844271166, 0.028622496806617295, 0.017102266495515193, 0.04832356769059386, 0.08627280313521624, 0.05375889442594988, 0.014742778015456029, 0.02348790018420134, 0.06542295550129243, 0.022563779593578408, 0.02190565999730357, 0.024034544958599975, 0.019123143948880688, 0.028516747123960937, 0.07486654804753405, 0.0678500956190484, 0.006203825743536332, 0.018897768542436615, 0.0412647882476449, 0.04823824530467391, 0.02036229138528662, 0.019551667650895457, 0.048323842497276406, 0.03401849904496755, 0.034168950614652464, 0.02346449751140816, 0.04576393003974642, 0.019142663705029657, 0.06657263809548956, 0.01762771892494389, 0.012977585279648858, 0.05492318248642342, 0.05319207341277173, 0.03860566718503833, 0.044622318619596105, 0.024186409577461224, 0.020195940043777227, 0.06616966971861464, 0.03724097041413188, 0.028754183490361487, 0.01920879033527204, 0.03977646239634071, 0.10812513876174178, 0.01656377431936562, 0.010918212838337889, 0.04424186742731503, 0.04247284181682127, 0.009585233338709389, 0.048485045454331806, 0.040166569141937156, 0.014995573022003685, 0.03703985941995468, 0.05368239299527236, 0.06345525144466332, 0.03129437093489936, 0.06459107156842947, 0.010600302218725639, 0.026518420781940222, 0.03975747698651893, 0.03698108132396426, 0.019841593790001104, 0.05292879504018596, 0.056338362262717316, 0.04783710218699915, 0.056341595482081175, 0.048417846738759956, 0.05198311399934547, 0.04543200767199908, 0.030332710394369702, 0.03014011840735163, 0.05072133742006762, 0.03385285846889019, 0.09810198910002198, 0.014599988802469202, 0.017837815419105545, 0.04736076721123286, 0.023722685175016522, 0.0755183623571481, 0.012430252640375068, 0.05282985445644174, 0.050789201099957736, 0.036755258084407876, 0.04771415164162006, 0.056840281401361735, 0.029568157491407225, 0.03597962470459087, 0.05637682841292449, 0.026908139066238488, 0.005379674565379641, 0.10273670218884945, 0.04961268923112324, 0.009449409287688988, 0.008387932853241051, 0.020226555543818643, 0.028213616693392396, 0.048964820602642636, 0.026524303680551902, 0.06876211453761373, 0.010318459128029644, 0.011355699139780231, 0.04365894817081945, 0.07235644345304795, 0.009797131343345557, 0.035208771603980234, 0.03566787518294794, 0.027276100125163794, 0.029174793777721267, 0.019732987474916235, 0.04526916605287364, 0.040385349187999964, 0.026259576635701314, 0.008661543617823293, 0.116490064188838, 0.03996473890064018, 0.021603506657161882, 0.022352755202778747, 0.04995587528018015, 0.040525995926665406, 0.092597204127482, 0.01961373324905123, 0.033692547785384316, 0.07833442517689296, 0.044102903455495834, 0.03981237725487777, 0.04526636031057153, 0.013252830465457268, 0.009526244896863188, 0.08777807200593607, 0.04170536782060351, 0.08222290580826146, 0.04398799015741263, 0.042812245033149204, 0.016065943354208554, 0.011600573946322714, 0.026765921519004872, 0.012616749686588134, 0.06315694030906473, 0.03350083450121539, 0.04692280678344624, 0.029996889842940227, 0.042325063675109825, 0.05502006371638604, 0.0157255426914032, 0.026121131743171384, 0.031674842483231, 0.034094162484897036, 0.03847906272858381, 0.01651614285739405, 0.0334256731771997, 0.03625263326934405, 0.041011738790465255, 0.010970989292088364, 0.010016366856039634, 0.0953220311286194, 0.023619310364925435, 0.030319892867867435, 0.03228819403531296, 0.03742129788068788, 0.02576758785705481, 0.009042670800616699, 0.04305406134309513, 0.04076503024303487, 0.026512972145740474, 0.0436077187769115, 0.008064735597664756, 0.015587657590263655, 0.014206698879466524, 0.023000805339376842, 0.006698912882711738, 0.0163307670902993, 0.0352330869063735, 0.03775883851838963, 0.04633154154622129, 0.15512636383729322, 0.06385439288403306, 0.02566638944803604, 0.014130941292803203, 0.039429059252142906, 0.03074551074366484, 0.025244118446218114, 0.02343011274933815, 0.0396124028068568, 0.05276311714468258, 0.02340357015574617, 0.0292417482206864, 0.04663816134312323, 0.013296825827897658, 0.021961567890165106, 0.027734477671661546, 0.03385188816381352, 0.029416647407093217, 0.030659387686422894, 0.007006716299136835, 0.03238874274705138, 0.05187290973429169, 0.08084191062620708, 0.032605073281696866, 0.03232798672148159, 0.06446954594658953, 0.033404014339404445, 0.0709096168034843, 0.00430104264523834, 0.008930415663469051, 0.006609173657904778, 0.05105571947725756, 0.022234737606985227, 0.014809656123231565, 0.03376081858628562, 0.04328601175386991, 0.03113204160971301, 0.030645820378725017, 0.04912507700334702, 0.014761256220351373, 0.0837906813248992, 0.021374869193615656, 0.015730962489864657, 0.011887823264779789, 0.0786803016172988, 0.0618273237986224, 0.029967268396701132, 0.03500831539609602, 0.034515770218734226, 0.04491823113390377, 0.024176560641665543, 0.04099535895511508, 0.0689066153551851, 0.030149173457175493, 0.013874906281541501, 0.0727686874036278, 0.036975442697959285, 0.03544307653126972, 0.01906994341074356, 0.035079151059367826, 0.025782717491633127, 0.030737588847322122, 0.04811817514044898, 0.04367432716701712, 0.013542715892461794, 0.039078029338270426, 0.050874564197978804, 0.037305030905242474, 0.0658085330256394, 0.040317929948547056, 0.04622469263683472, 0.026663286312084113, 0.029135666055870906, 0.01924085450757827, 0.024423912101026093, 0.034488106346023936, 0.0336338680769716, 0.023553936908553754, 0.217569783862148, 0.14826212716954096, 0.11722198634275369, 0.09095814172178507, 0.09950129115687949, 0.17051894430603298, 0.15812981767313822, 0.15145596436091832, 0.182019067928195, 0.09504938218742609, 0.10791510503206934, 0.1126589197665453, 0.1502878391849143, 0.10657905600965023, 0.16761181530143532, 0.11284430231899023, 0.14528246277144977, 0.12122432515025139, 0.1062597781419754, 0.0737090487299221, 0.16253745901797498, 0.13361879863909312, 0.15516675024160317, 0.08416483231953212, 0.174106752499938, 0.16146198101341724, 0.165852265432477, 0.1061497808301023, 0.13975551005985054, 0.1702436219368662, 0.09881305987281458, 0.14080747004066194, 0.12106229098779814, 0.09672963166875498, 0.12022639012762479, 0.1308137077305998, 0.07350467398230519, 0.17180045268365315, 0.11114051445786442, 0.09103140314774853, 0.07314942018794161, 0.11478637132261481, 0.09977295622229576, 0.24355433668409074, 0.1641975220824991, 0.17029105153466972, 0.1967954028929983, 0.2394522125167506, 0.09259701413767678, 0.10508735783930336, 0.08179762719997338, 0.12462522408791951, 0.147039244217532, 0.1157952036176409, 0.17528987329985413, 0.15044595141495976, 0.20154623367956706, 0.10420798324048519, 0.10253449875329222, 0.11276654899120331, 0.17888013779052667, 0.16112735468362058, 0.10577000478016478, 0.11870244118784155, 0.10628380506698575, 0.1107743973178523, 0.10048579797148705, 0.11074403966111795, 0.06817804516426154, 0.09016239656401531, 0.2518273341868605, 0.18450921002243245, 0.08985856893871512, 0.0715259098048721, 0.09933465652699981, 0.11733959003218583, 0.1235924530774355, 0.1393975421254124, 0.11055371058838707, 0.08187253068068198, 0.18226013784962042, 0.10848888102918863, 0.1318606465522732, 0.12119843225393977, 0.116776528103011, 0.12632875410573824, 0.10946513007261924, 0.1358039528131485, 0.1303099633327552, 0.11764685783003058, 0.09674084106726305, 0.13865294493734837, 0.05845002430890288, 0.13205389332558426, 0.05754968976335866, 0.14135768051658357, 0.11919577685850007, 0.17737737271402562, 0.2737614129270826, 0.10083276006792273, 0.17755694022136076, 0.12525479601962225, 0.10461344184087855, 0.16681820074362413, 0.13508983541812214, 0.1546229722776583, 0.1550728545657226, 0.10772375815681048, 0.07704411620008093, 0.1681736558675766, 0.1480999437293836, 0.060860540318701944, 0.13951714070779936, 0.10701641932662044, 0.09524322607155357, 0.14109092125935213, 0.12454715184867382, 0.07073751318135432, 0.07311310499374356, 0.13419300211327417, 0.18248372870896543, 0.1480395405420235, 0.08916830204959426, 0.1581163148262671, 0.1398699517760958, 0.1502777561545372, 0.11128853687218257, 0.11286372877657413, 0.09843665614191975, 0.15192990750074387, 0.0407284707762301, 0.11787409920777593, 0.10134069102683238, 0.18033061495849065, 0.08153428097388574, 0.10827430111489125, 0.14304408431053162, 0.1262444664857217, 0.1564752778836659, 0.13301518745720387, 0.1781730500182935, 0.12089246724333082, 0.09686117925282035, 0.2437868570642812, 0.06669395337147371, 0.11721693804221493, 0.15457789041101933, 0.14598233093108448, 0.11030793163393225, 0.11189580535782234, 0.10185709688812494, 0.12119134834834508, 0.09059327308620725, 0.14752876652138575, 0.1513429204268115, 0.18634939699300698, 0.1811695285141468, 0.1595847460308245, 0.08490648466561522, 0.10277090035378933, 0.129018955464874, 0.11436905871544566, 0.14776622663651193, 0.11453004793397017, 0.13732877027775559, 0.10583597195467778, 0.11377475024866206, 0.21208020485937595, 0.09146968248699393, 0.15332053788006306, 0.1663101137216602, 0.07430997969848768, 0.17419870756566525, 0.2985897963600499, 0.11642385274171829, 0.12189204432070255], [0.024348537038479532, 0.04386049682008369, 0.0435094702988863, 0.03217125531019909, 0.017792521510273218, 0.030771308645073856, 0.03273273964545556, 0.035477522361491404, 0.03183365360434566, 0.027458466589450836, 0.04363298402833087, 0.031916234708790264, 0.04637570399791002, 0.009923869810466255, 0.05750768166035414, 0.012048708158545196, 0.044516063428350856, 0.06180318830800908, 0.0331330413797072, 0.0670331326712455, 0.05055147635617426, 0.03539336705580354, 0.03734621119552425, 0.02195234320658658, 0.03869958321696945, 0.009273135219700634, 0.03458205969738109, 0.03276005407263126, 0.02097758524385946, 0.019869025264467512, 0.008453353807064039, 0.050255774187722375, 0.0779842943219202, 0.04139729256608656, 0.040271647074925046, 0.07697387425495045, 0.034222846651183705, 0.036622770729341676, 0.011820533795149198, 0.019660182363752807, 0.02052975891690169, 0.10861628276429006, 0.010972035084185856, 0.00874983798712492, 0.016719842462667396, 0.04362153374989118, 0.04240313930703061, 0.035978739216391525, 0.05547770844506366, 0.011157445626200309, 0.010218100406096449, 0.051938856552754126, 0.060794091384325705, 0.040070631075650454, 0.0540703928896359, 0.04621337467272367, 0.08406943708126034, 0.030646675332848514, 0.045765969037477455, 0.05527468737480896, 0.025641738270808543, 0.02954545370968325, 0.03350396594032645, 0.028014410686280047, 0.03798221563920379, 0.015850572946614454, 0.012090979193869447, 0.028668009542993138, 0.06223484514547246, 0.026335357122921517, 0.013972011428060276, 0.034105938460145674, 0.018356830247544816, 0.007364680840899902, 0.033863063635570664, 0.031063204232071127, 0.10692467460674898, 0.01589335797221533, 0.020921180324096764, 0.02992327218609197, 0.016841234073841145, 0.052594073715486696, 0.019914074900693128, 0.03243694926745125, 0.021662539203784296, 0.006509524005066071, 0.0072236464891050544, 0.013774920753868563, 0.04043675160833767, 0.04155856676931892, 0.028094323451763818, 0.04349938726850918, 0.04378969847623791, 0.1217121918286596, 0.023008710272344093, 0.019566013577527235, 0.0558692740409502, 0.011515712116046675, 0.04229954397305846, 0.045682532978909354, 0.05028547705816371, 0.04236480886382716, 0.038431639916130474, 0.013996386102267673, 0.029105053948504583, 0.015432154327364904, 0.06830818139548812, 0.026697160476552587, 0.033933481999805996, 0.03175327434603657, 0.06969404167362622, 0.013297559493886573, 0.006574368204123208, 0.017547987667577605, 0.07999518034713608, 0.03459055495581456, 0.037494688228304894, 0.04053958359041384, 0.038441224223268886, 0.007621572502622647, 0.04850110298554812, 0.015465132825608765, 0.03921112398217831, 0.0395689256755369, 0.017151862316365753, 0.04843984145138945, 0.09699823654123715, 0.03939069827486362, 0.044715841101216416, 0.03149113251960703, 0.026634484196880033, 0.06970645886446748, 0.02090961130202881, 0.03320247586816549, 0.040178555463041575, 0.02119000063144735, 0.05143392471862691, 0.04173810034990311, 0.011942017856719238, 0.045083121928785524, 0.046134376233177524, 0.007323945839224117, 0.005720009919189448, 0.02479621917674584, 0.02108872588723898, 0.03480921286557402, 0.01786570151203445, 0.029029546571629386, 0.028148434923163483, 0.04930511948519519, 0.0186885541437992, 0.0409301347764475, 0.030460190160998275, 0.014587927842512727, 0.008413365193908768, 0.054551372437604835, 0.04443610825442842, 0.00808652674978865, 0.03613204402582986, 0.013155292752864105, 0.019571404538250396, 0.019280257036111186, 0.013234226731583476, 0.014706384789730822, 0.05002955061250499, 0.039949580428323576, 0.04324488574638963, 0.03381923705871616, 0.01953273143486253, 0.04211667200018253, 0.031635772436857224, 0.022655417444184422, 0.09177273658237287, 0.0319482988810965, 0.02835353909592543, 0.014556245346154486, 0.0070380892138928175, 0.021172526658379605, 0.039483664357768636, 0.038195370629962, 0.012306152826308139, 0.046028568875044584, 0.016272704848753552, 0.036572990007698536, 0.050908443451459916, 0.0156437368132174, 0.034411323323313675, 0.020200571045279503, 0.041337343997188976, 0.017750494747555683, 0.09536059905907937, 0.03910010886777725, 0.06652831618807145, 0.053967971421246014, 0.0254122814762273, 0.05928895143525941, 0.08168478682637215, 0.016914909406165992, 0.02205079185244228, 0.07929286946143423, 0.04757243621030024, 0.060544383712112904, 0.026359601179137826, 0.017647537236501063, 0.054635666842971525, 0.022744290264589444, 0.0610165965876409, 0.033839525255773745, 0.048278736881911755, 0.05546203089345779, 0.024102320428937674, 0.055589758325368166, 0.06970618745046002, 0.03738446021452546, 0.04438951664737292, 0.028879966919443438, 0.03920332761481404, 0.04835214080022914, 0.021965952922723124, 0.016000162776825682, 0.05176986062100955, 0.03452290501445532, 0.04343763379646199, 0.017541276956243173, 0.016381835332140326, 0.01828499204878296, 0.018217493081465364, 0.01500107763734247, 0.01592858411770846, 0.008246040154647614, 0.04220236758036273, 0.04812047876683729, 0.055780762540442605, 0.041341160756668875, 0.03777836675622633, 0.009507401131226547, 0.033436963999910016, 0.06686629448086023, 0.06185249066246407, 0.026259507085861902, 0.020123421613659178, 0.01770887680218688, 0.010148861844624792, 0.015426083135285547, 0.0976169112005404, 0.0478830118663609, 0.04993088483544333, 0.019200332396264588, 0.060154870684657774, 0.020478181773796678, 0.03284444347290056, 0.02485613551523004, 0.037973584673766575, 0.03301658780713167, 0.02344175980293325, 0.015159283165952988, 0.005316542819075818, 0.029274188979927982, 0.03538232050569994, 0.012704502924212387, 0.050511208695492575, 0.033624260021107535, 0.035633456494127, 0.04782323632389307, 0.031698350328952074, 0.03815489262342453, 0.02388427489703255, 0.02102036857312279, 0.0800976934177535, 0.026186822414664284, 0.024736827006563544, 0.004855606771473373, 0.029650830198079348, 0.013845177117868193, 0.03117539660472955, 0.029630884661206176, 0.05957740345703704, 0.031364327895322015, 0.07513938019318239, 0.06130036671778985, 0.029184469687087194, 0.011093708287392343, 0.06057056159313236, 0.050407677822347195, 0.035299861537558694, 0.02480499941988715, 0.048350291792303324, 0.06788652616419963, 0.015025382761710455, 0.015307794125484568, 0.0728319947208677, 0.0676558513992599, 0.13236641298447335, 0.02160753376249756, 0.01876540162733623, 0.016653926178280796, 0.028134928683617284, 0.00928482213722808, 0.02019986367252256, 0.026121988393632427, 0.034515637904405594, 0.03130826733208128, 0.08339038637599774, 0.0312703541879143, 0.010518598968961408, 0.041310701319681745, 0.04932693099336965, 0.03987342844318066, 0.044730005519730706, 0.041044586670718024, 0.021390409341880252, 0.029411758562283855, 0.03451671338241015, 0.012294157175347209, 0.11630276138229029, 0.04405000147276691, 0.03770946152508259, 0.03118785790034703, 0.03260165346520288, 0.08805253942097936, 0.040994693990796804, 0.008704929146915674, 0.040910192632249424, 0.02172748857576932, 0.041485977093023915, 0.02503714830215488, 0.04440839349159172, 0.035177233296313455, 0.007792481054951037, 0.028931145423224995, 0.026211902765291076, 0.06200775983078139, 0.0629537326416799, 0.05457947735807725, 0.07998842213835035, 0.02899187770006912, 0.028052732647795762, 0.058580201252230575, 0.009058276257876838, 0.036654108869177957, 0.057756914358053885, 0.03000230455238904, 0.013983001999024833, 0.01984560053928622, 0.09631049380238567, 0.030712086108646224, 0.05129378009587526, 0.06842021431241717, 0.04557394362719996, 0.029362937967692102, 0.020951758504712155, 0.03689269195976002, 0.08806664616401706, 0.11787394993007183, 0.12841575140399591, 0.11868128446596009, 0.0935820909217, 0.1992040393607957, 0.1742009331605264, 0.14605272215391907, 0.21056606753596238, 0.12531157582998276, 0.11960599198937416, 0.1052723807681884, 0.14917231404355594, 0.11006192876292126, 0.1907200174672263, 0.13782760208206518, 0.14615283321057046, 0.12006511592439242, 0.164778524477567, 0.1468342723590987, 0.21653462440839835, 0.07192423021686928, 0.10012853571346828, 0.21841082801776274, 0.08986929657735995, 0.1856121008417436, 0.1034735030095492, 0.10999831610492297, 0.09278728892760617, 0.0904983663931489, 0.11411030617143426, 0.15477765112050942, 0.21775292046368122, 0.136146178735154, 0.12444360740482807, 0.1641619261354208, 0.1552773378789425, 0.10383689243878637, 0.14672334545425006, 0.12215151611183371, 0.15170732087322644, 0.2291893432182925, 0.13763721872653278, 0.12338191723184926, 0.0857109015009233, 0.11579879985323974, 0.15079435200563499, 0.08610672490405184, 0.1608541900558131, 0.12382939750594751, 0.14606208593717643, 0.16669192537665367, 0.09305725087012563, 0.28297632560133934, 0.12021868196981293, 0.17426050853516373, 0.14054501269544872, 0.10866326452898127, 0.10021293868443795, 0.09730065281369857, 0.10639817214437894, 0.0994354664747204, 0.11645628671560969, 0.11313202152294771, 0.11184458274926458, 0.10563649622989552, 0.05976108967193535, 0.14759315949465546, 0.17146957186715944, 0.13252538016864232, 0.17338686755725316, 0.12078088894486427, 0.1534374901758773, 0.10274449177086353, 0.08939967570560318, 0.11723812190549714, 0.25319121671574457, 0.11243095235632998, 0.07255644843514476, 0.10888191565339055, 0.09645013630922351, 0.12397604249417782, 0.12642217480710574, 0.10405031205820185, 0.12247528588133198, 0.1360198762267828, 0.11671867620732103, 0.14060325814144953, 0.14182905879403862, 0.17186807548361166, 0.0909158486340727, 0.1327640480761017, 0.22984431950109346, 0.21699555324656622, 0.08099601949964251, 0.10746183006891183, 0.1004948021311845, 0.16395935629095348, 0.07976063114723989, 0.09461739965315376, 0.10012895640517984, 0.07872404676995107, 0.15279004563178333, 0.14802421922130243, 0.0821573728961604, 0.11800797416695527, 0.16268984441246304, 0.18583619381700242, 0.07926477132631199, 0.12269879531647478, 0.23528177344373294, 0.11137181347502129, 0.08561629336327314, 0.08058438623057944, 0.17620301858655044, 0.20401644041495665, 0.20886586233973503, 0.12246897550565855, 0.14730223082005978, 0.10085493459233216, 0.15088759628789766, 0.09485045607600893, 0.10383157272424016, 0.13215958194008895, 0.11514424426215035, 0.10860011327479567, 0.15064766630530357, 0.10327914343880755, 0.10120195775691952, 0.10071732769055025, 0.13352051962699207, 0.11302035501492874, 0.10403715526419026, 0.08684688447309391, 0.11621148485158171, 0.12214413365083081, 0.10227123395140682, 0.15368436835706234, 0.1274407101528985, 0.13550534312214169, 0.1447362963642393, 0.12942220882645675, 0.05232581828853913, 0.13902360147663526, 0.13200186326035432, 0.09018224371331078, 0.16744750126131944, 0.14528506834592136, 0.20450961323721067, 0.1259843297302723, 0.13796254912657396, 0.1408652812242508, 0.09873158817312547, 0.09123321303299495, 0.09528398567012378, 0.25826633295842577, 0.20734650029667787, 0.16962831281125546, 0.10535621376974241, 0.08528640320790665, 0.1458325782524688, 0.1137062996359808, 0.059211265960974355, 0.14735465443560056, 0.14480564264314516, 0.12526303343474865, 0.11624676867255143, 0.10175587303404297, 0.11735598343823637, 0.11820626924080507, 0.10945283501808133, 0.18902434488492353, 0.16021468437143735, 0.13570981286466122, 0.09070118051022291, 0.05805510335734912], [0.03407917364633509, 0.01804848188268287, 0.04894294463364141, 0.07493240665644407, 0.042838592547923326, 0.06447069945612124, 0.024880111550113986, 0.06129997316747904, 0.03641996339761785, 0.005922669669546719, 0.033310495250459225, 0.06219386163034609, 0.06722504951592002, 0.016449286802006618, 0.044009835592338016, 0.06450210205678429, 0.05537831663553204, 0.034595145245215723, 0.01567713769951037, 0.011688149916673345, 0.015401097779561366, 0.020350737630256584, 0.025283548116151775, 0.028156775814880217, 0.0548662635763841, 0.04539053900433438, 0.011738868712979768, 0.027106739480846694, 0.02764289410385702, 0.04720270247863872, 0.02184067839490516, 0.05383633902030332, 0.057633577047714164, 0.002427242958219722, 0.06307479007435696, 0.02606637396716646, 0.008199043122918477, 0.014539543206670454, 0.05854223721793719, 0.03652344338063683, 0.06584373542240687, 0.07084782261933599, 0.03070928036634411, 0.042222153661506515, 0.04499027119683368, 0.02515055355615914, 0.04965217996920858, 0.08423195300357682, 0.020616502833685706, 0.032995427692575116, 0.0175663148984313, 0.009515578326370035, 0.06822768000087567, 0.020514132255422216, 0.02689025118680937, 0.03463834078450288, 0.0035335345102274524, 0.007231087473753307, 0.06105076761118003, 0.011277547172669853, 0.03897426776321871, 0.046839408044304164, 0.07391931316150085, 0.026658163372693316, 0.059902034966009, 0.03201328557250755, 0.00844270080727126, 0.02500847171592925, 0.058461667969822884, 0.036026650574058294, 0.026373528110395585, 0.03051878505253366, 0.03298981960064598, 0.017185325967147946, 0.08013702130743436, 0.03708657994866371, 0.028601143309580426, 0.013872161607391067, 0.013817013673750418, 0.034577221742698123, 0.02582883751685066, 0.0811608424410224, 0.013348413149027951, 0.04678621089884213, 0.06929038797638246, 0.026247732806950808, 0.053303634747862816, 0.026524303680551902, 0.0829077579879335, 0.0392362806679947, 0.04399115552327462, 0.03811251132615975, 0.019412199866824915, 0.07071780173906259, 0.07956952175923757, 0.020213525975123048, 0.0321328943329198, 0.03897770115041307, 0.02285567857325077, 0.028617546893656254, 0.04763778931062136, 0.04113654852179544, 0.028631612924592834, 0.05293594679928251, 0.03432634699025324, 0.04720485004197274, 0.0388545368665031, 0.011622601737534361, 0.023821970115282705, 0.0481593316820051, 0.061710805765220096, 0.01097819024497377, 0.054850524956626553, 0.03752550050350172, 0.10218619315751962, 0.02880470720785005, 0.06764172430017165, 0.009261278668418527, 0.07685194151209933, 0.027237408362062912, 0.025950422510504723, 0.048902280029973814, 0.00872556000415768, 0.01821375435351261, 0.023149760739345635, 0.04178934331451144, 0.02451867121271789, 0.025414196641317437, 0.052757631189056804, 0.03864008926653436, 0.0510450054093131, 0.020161163427733948, 0.05410002790657537, 0.01981126836368016, 0.04760276333295873, 0.05424171958916953, 0.019031212631879107, 0.015015588108716267, 0.05366538890770503, 0.006543842185887375, 0.03290519271312015, 0.024950921768322587, 0.11697334397052016, 0.05134231570575919, 0.03245800081640482, 0.03950715184743915, 0.0536127447682832, 0.04490578340898667, 0.06550089203353439, 0.018141432698549967, 0.055304129009268115, 0.04517517198941537, 0.0371366897597909, 0.03990678861737251, 0.028022354635010873, 0.03531021937461836, 0.042161248358232636, 0.03810131889102714, 0.014199182407797446, 0.022339057277089784, 0.03826629450278623, 0.03612861742398568, 0.03117427702194878, 0.015591386140191128, 0.0383083297471915, 0.021862362677763616, 0.05906859040260315, 0.026280416142461554, 0.048247870323913436, 0.10218487679958344, 0.05816309220556702, 0.025964765044461404, 0.05263003946415015, 0.029403412581554482, 0.023180267673784068, 0.01986085739918053, 0.015935143855001246, 0.02244643883646599, 0.006822677246028823, 0.020839513545589786, 0.01644030130202217, 0.03556110430508852, 0.0534840232825705, 0.008022091368080249, 0.05757347920111247, 0.04174089252150484, 0.027291569027251432, 0.0316472803907735, 0.06729426008782216, 0.027709061446200525, 0.03999747142993978, 0.0928083099424839, 0.016278860857710242, 0.012783100179928755, 0.054737440310418606, 0.049181229168815274, 0.042657257456864626, 0.009440255002118647, 0.008075533634317773, 0.013015937775240412, 0.029565721550690274, 0.02981791944642152, 0.013986404003974582, 0.07140601266707693, 0.03864094761333295, 0.032637768491570435, 0.018722631868773272, 0.023672539740800858, 0.046011452829199176, 0.061639288174254556, 0.09109507008854832, 0.010096298281236418, 0.03250683837437204, 0.039719509559550455, 0.05477816258956279, 0.07309822472078459, 0.016869283015174524, 0.030361992573099475, 0.027546180811311518, 0.0767102362588048, 0.034639935341796706, 0.0351498510156359, 0.029685523693582842, 0.03841475457219141, 0.049194603094032834, 0.03377155301028064, 0.02006088613000299, 0.01848359585606626, 0.04013065428340009, 0.018339473321767788, 0.07065053177731377, 0.01679315647509481, 0.03345277386584452, 0.028345433995127678, 0.024373615692768778, 0.017280190251767635, 0.03409466120813574, 0.04763050184452108, 0.027543721121868918, 0.011351209782463099, 0.03829821618273854, 0.022833244509196708, 0.06423454891358103, 0.04282318301764982, 0.022187207925266454, 0.013626344485341437, 0.02329476536916835, 0.01868269160123808, 0.023491835687309504, 0.031435380689799786, 0.026036579494497607, 0.07727377316249268, 0.014938706698428308, 0.013116718885222716, 0.020020591327920556, 0.04458432065855179, 0.02655601331831089, 0.033666254553411684, 0.01551677442954055, 0.04645832581445575, 0.027384682691523006, 0.11331327179712908, 0.026839196515668715, 0.006821589893661439, 0.030464797413774898, 0.014905507676303387, 0.0413382328780634, 0.044896066787519624, 0.07610888459852763, 0.02533659089489707, 0.04409965327275651, 0.07873047249657766, 0.026161752242062773, 0.02967343559222562, 0.01402828233715679, 0.08885597916586058, 0.04233434942684003, 0.06475329572068793, 0.028799275535025766, 0.036555385416639705, 0.07284696320337908, 0.03907784952649048, 0.019903929105826786, 0.01435017426099096, 0.018690450649176325, 0.024883517795907598, 0.07701614698661224, 0.037727001655314646, 0.05447948504505413, 0.04472304714311447, 0.034149269706436565, 0.02146848158112594, 0.021807786409876177, 0.02643194149381348, 0.03833610557817987, 0.04350707167759538, 0.066134752306555, 0.010934423888102174, 0.046034648548811674, 0.023603154446131418, 0.026073334040120244, 0.052693652122148445, 0.006917563158952231, 0.03528409916907549, 0.030567659929926907, 0.007919329784012266, 0.045591918019843955, 0.04914029315114021, 0.020756101235747337, 0.010487984317088766, 0.05754743702709675, 0.03531977314768093, 0.007252185671989406, 0.059352788009813855, 0.013545204419642687, 0.027700737517859255, 0.014142342377454042, 0.039446083695760796, 0.0265010859085513, 0.06077778618782759, 0.06844599185777561, 0.043521677143871784, 0.025298328305195485, 0.05105081366907273, 0.05197376717946359, 0.0144917013988431, 0.023931064975581, 0.006802626112143376, 0.054144879071308036, 0.0575321496331266, 0.0336388858434345, 0.006390976727873619, 0.03310393222740718, 0.040049026520656686, 0.007555231285680617, 0.026837976848972694, 0.019587619828858545, 0.05865485367498227, 0.019414159136691263, 0.05115533859602042, 0.011886779169019843, 0.027331694195579206, 0.024696513544768095, 0.07151599640824965, 0.020232063551832522, 0.03913084989679711, 0.021116267623645917, 0.01658820836538715, 0.0803202393331698, 0.01460094892952059, 0.0467071581764945, 0.05001164746603795, 0.13687309330063208, 0.10427165018128497, 0.1904041865574462, 0.1310838596629245, 0.10619406881076948, 0.23772832644837244, 0.26648067789418356, 0.14432419490601334, 0.1840178556740284, 0.14502212245549473, 0.07888397068849631, 0.18386378751269408, 0.23648858868650027, 0.13668615690299443, 0.11708465085497924, 0.18590045108326844, 0.15095511052225316, 0.11362240556627512, 0.08978022528546196, 0.1325862854719162, 0.13084820445094789, 0.1718279876347099, 0.07661781978926488, 0.09061942382582597, 0.11363233931894813, 0.09924662339368037, 0.11084464604833297, 0.1987915714936597, 0.07195004847432886, 0.15025848576000758, 0.1412022824266127, 0.09885826387575694, 0.11392826879663126, 0.1098684784291046, 0.12906559796205588, 0.11419154038386685, 0.09276271238923073, 0.12965098369334424, 0.12862225675157138, 0.14285859997783387, 0.1344948552016701, 0.149316258462412, 0.17578111908265523, 0.17144316328423365, 0.0927701016355838, 0.13157821313611098, 0.11695458926260471, 0.13165593253714697, 0.1749781814536878, 0.1344841479190758, 0.0850101580311145, 0.13318820031625883, 0.14373270235955715, 0.10985534877649375, 0.15925068967044353, 0.06620368467909948, 0.0872168353359614, 0.10941543416785342, 0.14234277765665734, 0.06967123611164944, 0.1800971989120756, 0.1405985491084201, 0.13465819215135916, 0.11943227345389978, 0.1113618186541966, 0.19375783231641563, 0.26068821442978724, 0.15180782548018865, 0.19918171555868217, 0.15238958783447742, 0.11763136009020464, 0.12541096763951437, 0.10641616689307348, 0.10025070594357592, 0.1522425085838352, 0.13810889555939607, 0.0958207950794271, 0.1863804603261607, 0.14165486528405122, 0.10825473216495343, 0.16604097959186348, 0.14669647546751158, 0.0852117236437542, 0.11106595703001533, 0.1066098954262478, 0.170063796586224, 0.12674857729247638, 0.14371238702109881, 0.23734612124306814, 0.11436633100467068, 0.1600846770618643, 0.1374919308083398, 0.14869332260319165, 0.10936660000256129, 0.12380085832306317, 0.13546963860946043, 0.07116161113870995, 0.13476967545492308, 0.09899766210998807, 0.2632651547236102, 0.09175832449857678, 0.15198826151234762, 0.09479351341724396, 0.12676636848066533, 0.14748035983315536, 0.13987487794033118, 0.12098428660205432, 0.13301809158708366, 0.09430919547698327, 0.0980848560908011, 0.23049020341464452, 0.08147687012595789, 0.08317185060254165, 0.13455688687307493, 0.25536277304802624, 0.10320348678422825, 0.1648529597691127, 0.12810728938451835, 0.17055075402770722, 0.23680427031857626, 0.10204159055969544, 0.06282553023525647, 0.09073290880769491, 0.12202806345054082, 0.1093648900943143, 0.17716841106968267, 0.0804444926657847, 0.070045773871243, 0.20067732887608664, 0.16840019156890257, 0.14613713191023894, 0.11886431250189032, 0.16969795764556952, 0.08690977788397244, 0.14353044464119843, 0.12227372026869229, 0.07063853527818408, 0.2638648439730917, 0.1831695647644145, 0.11891327558883599, 0.13857996171074255, 0.17125628116939748, 0.267822304474456, 0.12124461334730897, 0.12675153570515768, 0.1387035229376384, 0.13502351540539945, 0.16748392502112047, 0.1807378309645823, 0.15053929069212504, 0.16713028614010128, 0.09955506505710737, 0.13687360898724624, 0.2682624022875513, 0.08008335597280945, 0.11190195967044149, 0.10951973857092005, 0.22865786030888557, 0.08316518060330834, 0.13693165087274142, 0.17671426758170128, 0.18338778162641184, 0.11575337871909142, 0.13657407648861408, 0.0795905834862164, 0.12873660347291402, 0.11832864981676851, 0.14634894340166024, 0.1034800373017788, 0.17074846556144102, 0.1595438846520015, 0.10065093303897552, 0.20360630670828478, 0.11747176865381853, 0.07834914938679763, 0.10147148543702704], [0.0694160730178867, 0.008225282920258386, 0.03729617941592421, 0.014187214746406036, 0.01163541926403663, 0.03161705504836781, 0.030428356690598384, 0.06587456126830407, 0.020632460280986767, 0.0344398285794471, 0.04243918647989631, 0.035914536232927015, 0.013327443024276622, 0.02441269761350538, 0.11263438394027096, 0.025045475623171245, 0.0013010265434526705, 0.048838185612112284, 0.09902620129287243, 0.0307975916990212, 0.03580551261880568, 0.04523354635706969, 0.05259623824219618, 0.060236498447401185, 0.036467233539691994, 0.013539301164980446, 0.012582303856366446, 0.08320419636688062, 0.021826352824323943, 0.010468454382914518, 0.014899543353489466, 0.014899729950619596, 0.05146605335175991, 0.048646658925073485, 0.04886837363509195, 0.016822920413687825, 0.074810548552445, 0.046090322347091775, 0.015221603214740753, 0.028715059161186218, 0.0723377498132842, 0.019350088467555385, 0.006993526850627469, 0.05695839399205787, 0.047619014246655364, 0.029180429011051143, 0.01954619356963251, 0.020993975257234912, 0.06127553233610732, 0.05018995289823838, 0.08080306449638945, 0.03179293471787657, 0.013667494241547371, 0.08577266175832067, 0.012607277337727802, 0.05271984018119318, 0.012981895673354822, 0.036627842778606076, 0.0701606362791998, 0.025379857680361186, 0.02440884692727455, 0.04698424134403467, 0.035735504768256626, 0.02799320816328483, 0.014409469739933099, 0.042322315608284304, 0.014405313712943877, 0.007489879881697041, 0.05040165921673179, 0.06958562534834657, 0.030190228218478814, 0.0370391944556364, 0.07221632597169705, 0.036314766721001694, 0.06340105006737368, 0.049777084695441384, 0.032471144039716036, 0.012787151882158858, 0.02172221805501197, 0.024119051406159997, 0.06290516310504504, 0.020328632655686567, 0.04622820744823132, 0.03693173486473305, 0.02946506766602397, 0.026835581620356867, 0.07366437398429428, 0.05733978495533977, 0.029732301897768463, 0.029617622694266692, 0.029853413613247018, 0.0617002613310303, 0.04677418725831168, 0.015523995738476515, 0.07506396781120982, 0.06183816000287022, 0.04399918598522033, 0.0477174425364605, 0.02747310428614063, 0.0413266367145947, 0.040016083645501306, 0.064597531221807, 0.03659462848944323, 0.014098516648768314, 0.018186231276818683, 0.03302649441840393, 0.042891677735107284, 0.019899844325014522, 0.07733804399945907, 0.040399679847593815, 0.015586512562419687, 0.0757734440267086, 0.02259968257775264, 0.03978637240028807, 0.03764314490503498, 0.042032028149281225, 0.05139091916914497, 0.09262228278177125, 0.017656712726290737, 0.010347864291231548, 0.043770411118332825, 0.06753530965319701, 0.005712408206558653, 0.030544257257133722, 0.06962862411247832, 0.03596834745258093, 0.058012219944170544, 0.033129614777863026, 0.031540180423430035, 0.07948207895138434, 0.011321992912728871, 0.029238538750048195, 0.04380669238577996, 0.040956176950463226, 0.060076113125043254, 0.02412387409380504, 0.04000339164797749, 0.026158978730174046, 0.03344974759966135, 0.02957999792748264, 0.06496271198349339, 0.03488288141254868, 0.0926625674058284, 0.01601065632088908, 0.03943669616377779, 0.04797021040160741, 0.007714256993494928, 0.03435832295300705, 0.014093118054526193, 0.061801871950072904, 0.028174370227913772, 0.03602838083835585, 0.017537853747074093, 0.01257456770898508, 0.022074240326349224, 0.026291064053241695, 0.02121507080404886, 0.008179512340575457, 0.03821206259142075, 0.03488247089886239, 0.013092825122709786, 0.005302119709085673, 0.020412715018859932, 0.038079626126480956, 0.10327655143503632, 0.043855306027191024, 0.012075141338365418, 0.015543929400986858, 0.029120599185781817, 0.04676156650696482, 0.09206791967153549, 0.04312191823763507, 0.030039881821721792, 0.02874002924987248, 0.04402548600254314, 0.017906479770317674, 0.03075087795566235, 0.01563025771507195, 0.022219458694702814, 0.02079664709578667, 0.013365210283414593, 0.04670387067432914, 0.05551035955016102, 0.02855352032929659, 0.03122072613665036, 0.03701562214908855, 0.03530193446204066, 0.04909650728638683, 0.04950599977746606, 0.03025883828688945, 0.018376163406563655, 0.009750260688763644, 0.023208437055083256, 0.05049342768532889, 0.08229183139545576, 0.03904954783086266, 0.09806325153580733, 0.015209342086953776, 0.002911427948025188, 0.08815664704889059, 0.10493562383843319, 0.04439041231359754, 0.013114463604454483, 0.03962552906679256, 0.017912416951730847, 0.015169820814792599, 0.03333757219037839, 0.03324635333514639, 0.014410490935136164, 0.0337294058075973, 0.05270464099677546, 0.06467603772346463, 0.05321273819676467, 0.05489595966147525, 0.04386807605624199, 0.048450094115521224, 0.02492672181688249, 0.03113172948360443, 0.014656373366181339, 0.023031917866319418, 0.0975282538150038, 0.06217715609818697, 0.040347018744796515, 0.032814743995134316, 0.022560280049219728, 0.06803319150848047, 0.02138203282707504, 0.056311682265784056, 0.061871279297130446, 0.029614043422043324, 0.045877282707286735, 0.03426603201244559, 0.03279626748657652, 0.01862421036431832, 0.01803931487458093, 0.051363937224128416, 0.014399245913539614, 0.03707510931417346, 0.05802675416426999, 0.02583478487628911, 0.005227149223043982, 0.03436727961525321, 0.02110841018812997, 0.0361960332707635, 0.019370515764291798, 0.01500750845298171, 0.023287513526156545, 0.019111429041783725, 0.041664441980953724, 0.05242374446243048, 0.0507486552399184, 0.023116448062605092, 0.03272221895999142, 0.013863739291472095, 0.06060592005295413, 0.046809817132140906, 0.018777661058785658, 0.04728925640561751, 0.04491501148524029, 0.01647076752435948, 0.026462231297045946, 0.05335984458880765, 0.012642549284334694, 0.04207772409011211, 0.020000365895352194, 0.02188075945845672, 0.10583045546497617, 0.003071475911253531, 0.02544617430040879, 0.008909004490955599, 0.010130138518953962, 0.05531042581424117, 0.01586495110365961, 0.09810251835733652, 0.03857293804841382, 0.04712682869285345, 0.044536616254065714, 0.06455975039196865, 0.01508242211171559, 0.03298799094877072, 0.028683181586010114, 0.03842817260218518, 0.05340453629781093, 0.025183486253289238, 0.021312854485586286, 0.07660323128636394, 0.02006097264321787, 0.01794113764273269, 0.025747057083728056, 0.04570250565718327, 0.010166598750012261, 0.02631402567827276, 0.015695926334176744, 0.02885018601747496, 0.034808710749660215, 0.032931502908468246, 0.022177547282938446, 0.01483794764083411, 0.013098203360901346, 0.05554832697712949, 0.03715850126796535, 0.03952420682513288, 0.057639805999185355, 0.017859192664868066, 0.008652926223086459, 0.07060475101960556, 0.013352344411292245, 0.06298643802957875, 0.016571066874478544, 0.058095693322164674, 0.06370864356202738, 0.01351368731619524, 0.020419882044994404, 0.03582258116719978, 0.04737587818609817, 0.04413539171218872, 0.019646408102874244, 0.026078407785722187, 0.11279251652636699, 0.05869506366018738, 0.05187799535425646, 0.012209376769273408, 0.01715379105215626, 0.00586599503211411, 0.023895100923255086, 0.09048742840864829, 0.02242975535669497, 0.019605483959562013, 0.07330217199133975, 0.032805709301361015, 0.03881712244557483, 0.055416803141789775, 0.03359196175421987, 0.03842467475416405, 0.09589027027998652, 0.028362293894003545, 0.06423017914806094, 0.03495612587513668, 0.04212460068187543, 0.01798246890705611, 0.05269899897809539, 0.027639084129727313, 0.01396044495049864, 0.0769527650305203, 0.02686879251684461, 0.05112524217526827, 0.02014124333592398, 0.04832411730395896, 0.013685583136975765, 0.010491821432619222, 0.009167143808943885, 0.007946678986107665, 0.10839723808956997, 0.07317966927907296, 0.05768335437668221, 0.10013628458338124, 0.11011300209377493, 0.11269287365887846, 0.10481173691472837, 0.12252827946628843, 0.1164720422987427, 0.16174769853906973, 0.10367171665919678, 0.15736031824988977, 0.15760506583111628, 0.07046717125922441, 0.24561173628483499, 0.13338512474937098, 0.05657352553680539, 0.11185359369431223, 0.22794111019798688, 0.08031594420650176, 0.20945158733853272, 0.0765044976558004, 0.12193838826247624, 0.14334934364472116, 0.19957181891160353, 0.11684793712837355, 0.18873281909951142, 0.20158444877181733, 0.0913741515417184, 0.09372099382536751, 0.062444363188530715, 0.11845143751374312, 0.08117517988596644, 0.1260686173502888, 0.11392065563372203, 0.15122602241379873, 0.17329101770051888, 0.14534190243908338, 0.14774694267128194, 0.11763586556272847, 0.09223119555307285, 0.10959095082112721, 0.07148957425462348, 0.15284806037587778, 0.18483911374849932, 0.11872667845870767, 0.12634782093976224, 0.12135628664067813, 0.10931032909346478, 0.20073972695640155, 0.18675651800419601, 0.15509141928383283, 0.14484695185508045, 0.2216697774295296, 0.09080167833183493, 0.16756197011896543, 0.06963828645114388, 0.08650813265038387, 0.14314804944608892, 0.15741184619920595, 0.13667258620262146, 0.11258065753749438, 0.1817807528589453, 0.0805356063480888, 0.09872872475534678, 0.06868977591927562, 0.15149396232196263, 0.08007602100925786, 0.08051320112177304, 0.09608012437820435, 0.15752303094736167, 0.09330343694559165, 0.13682873068111284, 0.09160814434289932, 0.1435614944036518, 0.21561873784022673, 0.10020231282604591, 0.09210259959633861, 0.10190475040248462, 0.08743570359157664, 0.19557911530137062, 0.07442733232996293, 0.1648915276995727, 0.10011626101498093, 0.07501642286245312, 0.14706990042967455, 0.12467036023736, 0.2346710647855486, 0.16004182079008647, 0.09344605822116137, 0.17238011157938413, 0.09032705665699073, 0.1543628898050104, 0.11771931179932185, 0.1266393195837736, 0.19577891672296183, 0.08033748090799366, 0.13446561034236634, 0.10257293776209865, 0.16095682526273386, 0.16722401896757738, 0.21509158398423875, 0.13463505410722323, 0.11837274102228028, 0.08209176534520728, 0.12090681147362504, 0.17047173183943543, 0.17900455397154602, 0.1325594833386796, 0.17202690696077688, 0.08478840600167002, 0.12487818194287163, 0.14476407558790275, 0.13715628667601518, 0.11888328434101172, 0.06718679371156863, 0.08234614133834839, 0.12893785695944512, 0.09817310635532651, 0.0708044438755938, 0.13132554026586668, 0.1734743985746588, 0.09752209271703448, 0.12111247543777738, 0.12729947987411702, 0.11351557701293911, 0.155393353796431, 0.11096100801868097, 0.12307481228240899, 0.15284561764981064, 0.05886762868613005, 0.22876042766230448, 0.07353691796639136, 0.19768093180443558, 0.1896101241665227, 0.07546478523207562, 0.12579607697469847, 0.08914278913289309, 0.13039073614137514, 0.12393355263131005, 0.20448920290384973, 0.11557951090591294, 0.21901321783661842, 0.08025469285036836, 0.12728512207312243, 0.13952126620071276, 0.057850884672786505, 0.0781710407297526, 0.1099107986582177, 0.15387688231255325, 0.1333039448197399, 0.1077985530719161, 0.1467606241681746, 0.11215448326298169, 0.10335304947303874, 0.09930423780211381, 0.07875270130378859, 0.08184900587158543, 0.16901263727673463, 0.12795562323715004, 0.13534831654812607, 0.09822852231029953, 0.09402095380106143, 0.11337467243096658, 0.1761609222739935, 0.13003157398530416, 0.15739927973066056, 0.1843713724187442, 0.10840484446712903, 0.11054959188082389, 0.15355605738503592, 0.15890583103256567, 0.1291586658252137, 0.06368040293455124, 0.11530520633927413, 0.1428227461874485], [0.013560540159232914, 0.03257740940898657, 0.04608952506844487, 0.01742913038469851, 0.019667362960587655, 0.01588018421482827, 0.015497979009523988, 0.046608166702623875, 0.004096142881150756, 0.017075968174529926, 0.038766473199107816, 0.02053333818912506, 0.025395070435479283, 0.04348730255982705, 0.014846424239554575, 0.008649497076735964, 0.0243772696038442, 0.030467335134744644, 0.021199798677116632, 0.03589141515216657, 0.015113928188968982, 0.03358091181144118, 0.031748527993581126, 0.06349177019936697, 0.02527280181779393, 0.02118256388764296, 0.014816456740455968, 0.024373859965375493, 0.03211005823686719, 0.02175271650776267, 0.03060705228043454, 0.019795363502843038, 0.053965074076716385, 0.037059231594737084, 0.030052716311599528, 0.022450540580653718, 0.008446108749402421, 0.014353897721905793, 0.07846229510115725, 0.059563547771956236, 0.07257160690746137, 0.03071220145959939, 0.042100421086485894, 0.021945111719625335, 0.009772904250504715, 0.08788753327514444, 0.0405378465407661, 0.03169419090928776, 0.0329644118568727, 0.022077785671821663, 0.023173270281404257, 0.02296368608118168, 0.032687661171491654, 0.010362041432277432, 0.0025322899330473903, 0.02086299255357257, 0.027059447286384444, 0.008442481131558972, 0.03319987368636897, 0.03318836233977761, 0.008691131985480232, 0.029399799382580177, 0.03372765179457409, 0.009809264397647764, 0.026738412013011317, 0.021783795107954314, 0.03208856224747641, 0.02034633733066065, 0.06774801681084291, 0.03305177663319877, 0.027967902199764336, 0.017525719844603112, 0.023199059701125537, 0.0072452875153560725, 0.034302167394863706, 0.05123626746769462, 0.03008426140461649, 0.029159102655415024, 0.02016818626517696, 0.01658446285208421, 0.060834206374628205, 0.034193191278193674, 0.0368827107096357, 0.07836620775716645, 0.052416087194745026, 0.014772821849744235, 0.028487227457974638, 0.018465329693364244, 0.03360065378780876, 0.05556972457894257, 0.013724631979130208, 0.023198628831388693, 0.04188582420881305, 0.012464026720928294, 0.037598890851118734, 0.011506466228248817, 0.010949362684706492, 0.051495640871248076, 0.023512147633092742, 0.02171283052302897, 0.03022345607834203, 0.02139104886113533, 0.016404634108766913, 0.04778638169435518, 0.0674019775220326, 0.032292896282992194, 0.027523460066212074, 0.020128483484898294, 0.019573753965752463, 0.026223526070160524, 0.02694743811818106, 0.047525026968547275, 0.03645144742248314, 0.04105379778359618, 0.027123031106644442, 0.04309691422219787, 0.0286252550514681, 0.0015968184057523363, 0.01917215283694012, 0.024730514934552566, 0.032012559540037594, 0.040361742954701185, 0.039949967193284204, 0.03991394716181925, 0.01920606262449707, 0.07291783618607692, 0.02705541848471122, 0.04122027295774647, 0.025989809771999717, 0.01032034630355026, 0.010123315001172679, 0.10951792688242026, 0.03896333656406828, 0.037450054194778204, 0.01885709715341883, 0.04548556783369609, 0.03198805085516401, 0.025219133090493933, 0.04561718327126332, 0.04777874817539539, 0.019969058289591755, 0.032800898488078795, 0.033366260650966845, 0.038809326078210554, 0.0698914003691503, 0.018048663390800357, 0.011432251460584146, 0.018309624566297446, 0.05030758372907128, 0.018254965177870223, 0.03136064005749566, 0.01134524545964918, 0.047228883752333264, 0.01791911748504, 0.020557765449796404, 0.04672866773658565, 0.029199726546981504, 0.048968783247151544, 0.04704493969412787, 0.003857057250570506, 0.04928188644615667, 0.030501044754471098, 0.020552021650863544, 0.04966027828465615, 0.04299728153273463, 0.06227469550711768, 0.020579782214813998, 0.013399249840793865, 0.030033008261982883, 0.040038678861622296, 0.013888102091316665, 0.06954185305429356, 0.02594155745048608, 0.01858509112415569, 0.020316373224237134, 0.025991392454930713, 0.02753457277347999, 0.03143659187480807, 0.0001778787370442712, 0.02596533840655216, 0.01665368190567408, 0.04516268694507224, 0.031090189569762776, 0.03131649796185749, 0.010930111798058664, 0.009280117345042527, 0.019594990415498614, 0.03267086742978011, 0.01885964335607631, 0.01563133149673896, 0.04638716445437499, 0.057565954247755666, 0.0064272783513713095, 0.06594347328479801, 0.02983241295441985, 0.0348104274432574, 0.005246722837910056, 0.021226666967517564, 0.011806854529173245, 0.0501167491477515, 0.0496600000852985, 0.014985925950376051, 0.027177997532167604, 0.04728095452966435, 0.03812245186418295, 0.042724717408418655, 0.06009570921638182, 0.010375372949056327, 0.03694432508200407, 0.009402885534135359, 0.05749616013573749, 0.007782211427443794, 0.04342897568962403, 0.026169728421206986, 0.06474296163235392, 0.018455967606444443, 0.06613592617213726, 0.052807038716439686, 0.03898580285853573, 0.023142824415117502, 0.0036679639597423375, 0.03375350397878459, 0.00661220628535375, 0.051509818860462735, 0.05703026442123311, 0.016928637865930796, 0.037575023381837776, 0.08140100312552281, 0.013523927257795419, 0.05883015998240028, 0.0533478718384036, 0.04040509794971772, 0.08110670891723462, 0.042177353386900256, 0.035058438777923584, 0.0621973221589412, 0.03358475910499692, 0.013535756667676781, 0.041401435022375414, 0.014445898588746786, 0.006864632762569402, 0.022324707957782915, 0.019205745409375856, 0.1319278758019209, 0.03667691443115473, 0.00804018959336515, 0.015923335649339215, 0.032958121837249825, 0.026085026894829104, 0.03321449950869594, 0.003291438304586336, 0.03345586798552956, 0.019627224221559506, 0.03266242306147303, 0.059593742580286095, 0.09196083327489239, 0.06742987888199942, 0.047720370415065966, 0.018108045382957374, 0.055717472186578174, 0.043686584902129004, 0.03752434699397002, 0.03812645861346807, 0.03398429070200239, 0.014517884368875196, 0.05576273725767221, 0.020706096597548043, 0.012185578849831862, 0.04526483699945467, 0.05062100583953517, 0.013513135158323815, 0.04058185971475073, 0.04317109506311161, 0.030421730796141282, 0.020289415027946234, 0.04218594364023634, 0.01892567329507853, 0.04718281800991722, 0.016916984026985507, 0.042216939119888205, 0.00347547947811628, 0.05648637789168528, 0.04284890288753169, 0.026305432032261575, 0.033825499936938286, 0.07871289165424449, 0.017021050942795615, 0.020471571146377494, 0.06040904311729329, 0.02768530254252255, 0.033429724031261036, 0.011753612430766225, 0.03947441592546446, 0.027212528179266622, 0.004794823604502848, 0.01852156497937228, 0.014672736238156046, 0.025236403503056084, 0.019462409761867354, 0.0176117241582168, 0.00833925899184708, 0.04900325282609888, 0.0494009014884276, 0.026790513324418237, 0.006615308038557747, 0.03987733001953789, 0.022617655274059092, 0.11020141520670482, 0.020634777478075454, 0.008162922159369503, 0.02852408548018762, 0.052375626151583025, 0.02697445059727345, 0.020907555340922306, 0.0567558580743415, 0.013588394869917204, 0.032232862897217274, 0.05196463409811258, 0.022075434547982047, 0.03377114249659436, 0.04951650010687964, 0.06799418931560856, 0.041994277853518724, 0.02893176967544215, 0.04300415848514863, 0.04019895222570215, 0.029826000798493624, 0.02786911089372422, 0.034267935303172896, 0.03303315084693687, 0.026716376588280712, 0.025349255751020143, 0.03935367061889597, 0.03187343950516411, 0.028579979802348783, 0.03309407650626131, 0.0665947583370975, 0.043664976954460144, 0.02608372750026839, 0.06326076973761831, 0.1058758765991245, 0.060004242695868015, 0.059682841013584814, 0.029262494428881576, 0.046446366634752066, 0.02333539943876011, 0.01779680815525353, 0.05975872837007046, 0.042589651620281596, 0.003072790360809969, 0.024898233524124538, 0.030809849434133087, 0.11180243893925633, 0.09050874797893421, 0.11501769748117242, 0.12075771018862724, 0.07926187398178236, 0.07117555503334318, 0.050486157182604074, 0.10566785133310727, 0.10491467746240751, 0.08170506823807955, 0.06389049773237535, 0.09863504621067218, 0.10448301383959395, 0.08185440022498369, 0.10853471606969833, 0.14017324335873127, 0.04774754574256284, 0.1419771287058081, 0.10718716587871313, 0.12640343366989068, 0.0840217632108501, 0.07922368603093283, 0.1366200947335788, 0.12994047387370042, 0.09185157556618963, 0.14393482437091215, 0.14153142619345868, 0.20738470181822777, 0.12932790602956498, 0.1727467511913606, 0.13169528756822857, 0.08239621043737445, 0.16751562617719173, 0.10262238939425775, 0.12886661078248704, 0.1371859386563301, 0.10248369683644601, 0.07554629764386586, 0.1905723682471684, 0.1384805291891098, 0.14133946863668306, 0.19729933728064808, 0.18038255002881798, 0.12639634976429598, 0.12780129723250866, 0.10576782668275492, 0.11679867548601967, 0.11492129122572285, 0.12768442636089666, 0.1063320217654109, 0.13915925419756345, 0.09591080274965082, 0.07238229563725845, 0.1488464136740991, 0.1377726136041539, 0.1166421781693186, 0.14762382927749837, 0.19302175752818584, 0.1276283793683563, 0.12565184757113457, 0.16781716713947908, 0.15400288626551628, 0.15169402158686093, 0.07010311008031879, 0.1096289623528719, 0.09507760245885168, 0.13081297491277966, 0.2315678255898612, 0.11307690412338291, 0.12125898471900395, 0.12293412483164243, 0.141222014224955, 0.09404447861015797, 0.12357574754527637, 0.14437850484890596, 0.08551682012953929, 0.18849770671554975, 0.15168302931955882, 0.115993254418884, 0.0950496264600328, 0.30374592968395775, 0.15556369322751248, 0.14309021112109932, 0.13463438914290496, 0.1717446499637195, 0.15783907898834773, 0.15723522353385175, 0.0707454520410725, 0.08376654583428587, 0.15400456903236254, 0.07792851874338728, 0.10156185951616083, 0.1288483174783843, 0.06940374403659787, 0.16342908117387975, 0.10174612927117518, 0.10910008501793657, 0.1498729150210108, 0.08562123988355909, 0.14303341774003847, 0.13507477194070816, 0.10043708594249827, 0.1364279743283987, 0.09996548374848706, 0.12908203208020755, 0.14879468216427735, 0.08722792259816613, 0.14552380410688265, 0.15362712714288915, 0.18010775691696576, 0.1024410305544734, 0.08348890966070549, 0.14990809027637753, 0.11543122386293751, 0.12879858086151735, 0.1275285668671131, 0.16971326539559023, 0.1289469628993954, 0.10171475381191288, 0.06090262306055852, 0.08778382598289422, 0.10163799793060337, 0.10139732834483896, 0.11766473044242177, 0.11024076345243625, 0.205601267516613, 0.17336442161883625, 0.13352354589317525, 0.09461543190159968, 0.11273743983890329, 0.13246520768318856, 0.20438234720911297, 0.12123902221875531, 0.08734231003160987, 0.1195308645921094, 0.1678382424371583, 0.0809486306139401, 0.08391976582684688, 0.129841380619577, 0.09778111667505332, 0.09813446378601448, 0.14694690917219433, 0.089510317625744, 0.14629350709063665, 0.20979911940438406, 0.1133080877895866, 0.11355100332626275, 0.09552015656871454, 0.11039185963038887, 0.12205396991755281, 0.14705166140837328, 0.1364882689501558, 0.11274162639996835, 0.15271532535552979, 0.11304831744304725, 0.09862319898924657, 0.12530419336897985, 0.11820332439882414, 0.09984490129032306, 0.05248868704906531, 0.1268970678959574, 0.11722190491855145, 0.15380797029605933, 0.12560907272355898, 0.208168056926557, 0.1794093001101698, 0.07034369145653077, 0.07068076051239457, 0.143271217122674, 0.09591253979929856, 0.11782379262149334, 0.15279039846999304, 0.12597090830760344, 0.08569951568331037, 0.08176361902483872, 0.13497821640755447], [0.013511586402143751, 0.054575138126633, 0.026521155278065374, 0.04096965944128377, 0.10405778951410737, 0.008984799397044947, 0.01792367554402777, 0.018945523837049092, 0.07561639031129223, 0.023283357499167323, 0.02945277261148606, 0.03060690639540553, 0.00432779685693926, 0.023337475755917172, 0.04068646945857576, 0.03494109293179853, 0.057412401773035526, 0.016270730311849287, 0.03637153296066182, 0.030399376459951912, 0.019733871266778027, 0.014225968425827367, 0.05279585985200746, 0.029286287259310484, 0.02657102929827358, 0.007743755455261895, 0.01520768815784582, 0.04278069654745715, 0.06456200312823057, 0.029349648859351873, 0.061759633145162036, 0.04594323291842427, 0.04814493656158447, 0.03423994912632874, 0.014868542784824967, 0.056701449743871174, 0.07340123810406242, 0.03934536535026772, 0.06450845992990903, 0.010300288808399012, 0.10767735314688512, 0.06837293399231774, 0.043829304565276415, 0.022086123170863305, 0.058431045684431276, 0.0677172520330974, 0.08257491620523588, 0.02985600222434316, 0.0616059788901891, 0.018610164689432298, 0.011628777254372835, 0.024381081274311458, 0.02262269170023501, 0.019678813239027346, 0.006528306702551032, 0.04572212888992258, 0.05238089497600283, 0.057140187094254155, 0.01053218832904739, 0.032264184073678086, 0.005957848317588547, 0.014289604832551308, 0.07457259989210538, 0.03914660208725503, 0.04650719051382371, 0.03896237982969199, 0.048459284872348816, 0.04140325349622539, 0.0391404952720872, 0.019309968388240253, 0.07416676809745175, 0.038553185894020965, 0.007940934339006032, 0.07409213603075061, 0.02185201841140432, 0.025364463417125598, 0.04377973758216415, 0.037725899035909345, 0.035802218331290145, 0.03848846722394228, 0.051246693158256154, 0.01633912155271641, 0.04976402968168259, 0.05984521444354739, 0.03881597572139331, 0.004110071508746062, 0.05511518754065037, 0.010284465371764131, 0.020777760073542595, 0.0430661256957267, 0.03064233949407935, 0.012474380317144096, 0.028715870010533502, 0.03029894988451685, 0.020132279888327633, 0.059517658448645046, 0.020445394961695586, 0.015033335192129016, 0.03228592433567558, 0.05766390756304775, 0.02574192057363689, 0.01893280809079962, 0.03829220436247332, 0.006135914142110518, 0.026590555839772736, 0.03809526975133589, 0.03788910027859466, 0.016123425448313355, 0.04639180224122746, 0.017383317396576916, 0.015604636232767786, 0.03068865629445229, 0.015404432779178023, 0.06954734918794461, 0.06149725043880088, 0.02443681444440569, 0.042506880526031764, 0.02016055953156735, 0.035365621758891005, 0.02133774315007031, 0.03263384995183774, 0.07293367997876235, 0.06203480623662472, 0.0035216253724813995, 0.032722310562218936, 0.05998474159943206, 0.043485314452222416, 0.014843864466196724, 0.03887902180265103, 0.039404981437006166, 0.038354751720492325, 0.014389710800190057, 0.036644840080823214, 0.02097883035561868, 0.02069120105755116, 0.0457685576485736, 0.017847576145348803, 0.06777325831353664, 0.003856863868090191, 0.026307718695274422, 0.03234953020832368, 0.07021426768707377, 0.028810325477804457, 0.01883921436300235, 0.040207142143377235, 0.05763394345662423, 0.0720285481906363, 0.04792172568184989, 0.037834685162774155, 0.06915170898927109, 0.023617773483108197, 0.04987002702962075, 0.04398238545815859, 0.03561577047886593, 0.05747594657753195, 0.04774457715185625, 0.03408239329499858, 0.011058437188954225, 0.06311391440353223, 0.046244787451411994, 0.004279788808032338, 0.05106915447062679, 0.05066102922761014, 0.04313963817964707, 0.02352845961494105, 0.0303869321277099, 0.05187687237880059, 0.04948347920019712, 0.02007491484151355, 0.04260934270652277, 0.027993642425696765, 0.013654122860836131, 0.029113949542599063, 0.0075003132057775345, 0.029243705794215202, 0.014435630657577088, 0.00530755562275382, 0.043300610434796126, 0.11756799849016325, 0.021381551067211797, 0.039563860411622694, 0.04472361711253013, 0.03627458048452224, 0.013123948675846415, 0.06120044565094369, 0.04366787429898977, 0.036908135416784456, 0.020093722135892937, 0.044198142630713325, 0.06559881820742573, 0.045854551784162007, 0.016750142443925142, 0.037461691070348024, 0.05073473170133574, 0.005912069680302271, 0.054785663794193945, 0.048802755906113555, 0.027377001675111905, 0.0281227981738214, 0.0032781557695540997, 0.06651451478579215, 0.018941277904169898, 0.03867974963837436, 0.03777179514457073, 0.06757630673902375, 0.08179699616240603, 0.06510035959737641, 0.032351168870393715, 0.029562277985470634, 0.04272347568933453, 0.05362532141485384, 0.026558766474149058, 0.04784034897706338, 0.04259904254493969, 0.02693736187315413, 0.020445213453578095, 0.018443618269105042, 0.058251437464995046, 0.008725135919771023, 0.02675255268279995, 0.03855731477960944, 0.014716467820107937, 0.032687627244740725, 0.007994033945059138, 0.039762029956494055, 0.07263994216918945, 0.03359627723693848, 0.031323727752481184, 0.06043089873024395, 0.028871743075017418, 0.02796353921959443, 0.037755120146487436, 0.022989984402166944, 0.048504536372742484, 0.016062713527519788, 0.02490192136195089, 0.03910858377016016, 0.03155181390632476, 0.04305933016751494, 0.04386490051235471, 0.03289843111165932, 0.07025919349065848, 0.04920326120087078, 0.05542588194033929, 0.05223238401647125, 0.04231512313708663, 0.013847554534939783, 0.05781372809516532, 0.03848027730626719, 0.03126041025721601, 0.033331265207380056, 0.014942903437518647, 0.04401994237144079, 0.08844376914203167, 0.029631648013102155, 0.021039939219398156, 0.05428789389718856, 0.06494620322648968, 0.01414192168574248, 0.010956004694370287, 0.04799583188391157, 0.053740061686507294, 0.003473668637785262, 0.00418551018395062, 0.028171276108228734, 0.03711041009851864, 0.0174169116653502, 0.003105122554448566, 0.03016907488927245, 0.03412218258849212, 0.014454458308007036, 0.1046451497823, 0.009566680494961994, 0.035117705419127426, 0.04384243421788726, 0.01736567887876715, 0.03792109659739903, 0.061656889372638295, 0.03299604176676699, 0.03620374821392553, 0.07602807107780661, 0.05143573979980179, 0.01686722196505538, 0.07604603189975023, 0.08122105563857726, 0.032252801648740254, 0.01609698124229908, 0.049191539508423636, 0.08947395493409463, 0.07227579956608159, 0.019989499157028537, 0.1005151921084949, 0.018699978977175694, 0.025528428011706898, 0.010418119807062405, 0.016007446850250875, 0.03601578383573464, 0.032238274213990996, 0.0530116611293384, 0.08101984286414725, 0.05732172913849354, 0.04437486368364521, 0.01190239395613649, 0.04351206569533263, 0.02654972329868802, 0.04812768480873533, 0.018953671346285512, 0.0491545050671058, 0.06766913032957486, 0.028118464031389782, 0.02803028840571642, 0.010720294351423425, 0.054501988658947606, 0.0478513344590153, 0.026120648286970596, 0.028345696927447404, 0.011363296187482774, 0.07822647025542599, 0.03641138671498213, 0.009478395455516875, 0.04964942850970796, 0.007486782369336912, 0.09762654639780521, 0.05579393629782966, 0.014749083302116819, 0.08647607865610293, 0.042273053965930424, 0.02746091440453061, 0.048470769077539444, 0.018909134003998976, 0.08720867934503726, 0.0013223295744475244, 0.007507883960248104, 0.02384811406955123, 0.024112084547856023, 0.06379606601383005, 0.043119312663163455, 0.04574270885703819, 0.049684668225901465, 0.025294860991250192, 0.017779495334252715, 0.034428086530949385, 0.04536701419523784, 0.06776130931185824, 0.026871152122371962, 0.06285081923540149, 0.008110916691033967, 0.04040206489818437, 0.05739978102168866, 0.011367060360498726, 0.04478335194289684, 0.04987363683591996, 0.08047691306897573, 0.1103782889300159, 0.2306396168257509, 0.106354657693633, 0.16192413121461868, 0.1421399771102837, 0.11660629723753248, 0.10611892105745417, 0.15904691203364305, 0.10195906034537724, 0.08033421715455395, 0.12008083079542432, 0.0990018147443022, 0.15405928609626635, 0.15179702320269176, 0.11212446487375669, 0.13587376049586705, 0.11403652227350644, 0.08349686209112406, 0.12347123958170414, 0.1485999154725245, 0.05814504317407097, 0.13035842430378708, 0.12729003466665745, 0.20759560407272407, 0.11273746698030404, 0.10967521129974298, 0.14254899801952498, 0.27663582297308104, 0.14709465338715486, 0.16249614980603966, 0.10490396339446306, 0.1789426715778453, 0.13501188531517982, 0.12335284879165036, 0.11195263945098434, 0.13350020428853376, 0.14513146158839973, 0.12058952849890504, 0.07180673509304013, 0.13676279064800057, 0.17324694006570748, 0.11645032917814595, 0.05943318083882332, 0.1512419544160366, 0.16795784101954528, 0.15289023811263697, 0.08652466854878835, 0.10720465851149388, 0.0841029431404812, 0.0725767637736031, 0.07818121196968214, 0.1658861379006079, 0.10957023514700787, 0.13165084352450712, 0.13156846937324318, 0.10310126548366887, 0.15555693501872675, 0.13129702822438308, 0.16055777881826672, 0.11240403487214021, 0.18463651676263126, 0.16825802491179534, 0.24517448831881794, 0.10538879023598773, 0.10893628666443483, 0.17420860060623714, 0.12552318376089844, 0.11325630878231355, 0.10411020634429795, 0.23811262154153415, 0.19081062903361662, 0.12571698693292482, 0.15357395713882788, 0.16845923768622534, 0.08240718913397618, 0.16405692962663515, 0.163409186527133, 0.14287339204124042, 0.11087950239224093, 0.11393998031105314, 0.08624753449112177, 0.18713032294596943, 0.1426987506981407, 0.14821714029780456, 0.09881216420658998, 0.08107831901205437, 0.15302462875843048, 0.1092953063281519, 0.07759131398051977, 0.17098796128162316, 0.1067052295963679, 0.1324526954974447, 0.13831989280879498, 0.11377597839704581, 0.27805947086640764, 0.09322822133877448, 0.12391597857432705, 0.18641593413693563, 0.11307216116360255, 0.10749902735863413, 0.07975107058882713, 0.1286278071680239, 0.1262041072228125, 0.1752526488687311, 0.12912319201443875, 0.14948387018271855, 0.187853871977755, 0.2059199618441718, 0.1522880382835865, 0.08678970432707242, 0.1229313292673656, 0.14526319237692015, 0.1595910835478987, 0.24329801329544612, 0.29615092437182156, 0.14511430822312832, 0.08945788722485304, 0.10203688831201621, 0.15640992139066967, 0.09651271080864327, 0.18945187622947351, 0.09686391374894551, 0.13062156018401894, 0.13814027101865836, 0.1590429222477334, 0.1050212617431368, 0.12931019626557827, 0.2580326183566025, 0.1611850844430072, 0.0760879178664514, 0.14223965390452317, 0.15941002326352255, 0.1481633596122265, 0.15382019749709538, 0.12438617620084967, 0.05542959691956639, 0.10870702325233392, 0.12162014176802975, 0.07601412718317338, 0.09793046223265783, 0.219772498522486, 0.16932057003889764, 0.0959361121058464, 0.12372639589011669, 0.14530195029718534, 0.2518158262329442, 0.16112037934362888, 0.0627855509519577, 0.20054398317422184, 0.08160355939928975, 0.1034577474264162, 0.135910835649286, 0.075962409244052, 0.19302246320460523, 0.07555855198630265, 0.08567404347871031, 0.15575217668499264, 0.10138471437884228, 0.21888246413852486, 0.15563632361590862, 0.14899540639349393, 0.18784794158169202, 0.11471451446413994, 0.1435341223009995, 0.11685279543910708, 0.1324960674558367, 0.2314162137252944, 0.19250426601086343, 0.13164825152073587, 0.09594409167766571, 0.06593698649001972, 0.09893427336854593, 0.11282526941171714, 0.16384951504213469, 0.1295269610626357], [0.03480739099904895, 0.12020051080201354, 0.027593137130939534, 0.060908492388469834, 0.025579967835385884, 0.060967233165034225, 0.01417652442718723, 0.008432820489230965, 0.013573411968536675, 0.01661697994651539, 0.024330616928637028, 0.020368398200454454, 0.02780489094688424, 0.06442433515829699, 0.00348453686040427, 0.05160314117425254, 0.0474199388575341, 0.07219616669629302, 0.047485458198934793, 0.04479929073048489, 0.07765426845954997, 0.05797606759837695, 0.03859380639291235, 0.04561111716819661, 0.023083698569930027, 0.04094981907733849, 0.02606406355542796, 0.0874339665419289, 0.02129778252648456, 0.05554869677871466, 0.049874661423798115, 0.018758984382397363, 0.05364051381392138, 0.029813288444919244, 0.028448608637388264, 0.02377549385918038, 0.0786024872213602, 0.025505868418674384, 0.0706555936485529, 0.07913827882813555, 0.01573995647153684, 0.017533604421519806, 0.044050374667027166, 0.013531699028265263, 0.011667990641269301, 0.04186572600156069, 0.01789087176855121, 0.020498770222600018, 0.02162307730343725, 0.04391501710883208, 0.033443562752966366, 0.059413530464683256, 0.011274453052984816, 0.03269263144050326, 0.08360418597502367, 0.04524791433608957, 0.08694124155278717, 0.003692923022234546, 0.01793343118125839, 0.03259130580616849, 0.05263196989627821, 0.028762115564729487, 0.02720285396623824, 0.04167884388672454, 0.04299002799338528, 0.02116327652973788, 0.022645320843106935, 0.04262922378256917, 0.07202157285064459, 0.05676552041300705, 0.016942583456901566, 0.03742568800225854, 0.020980701415932605, 0.030349049517618756, 0.01633345748164824, 0.014549717839275087, 0.0169366174377501, 0.041917179312024794, 0.030625779846949235, 0.040754431526043584, 0.040876537295324464, 0.024472517260749425, 0.013047871329555554, 0.0317615422952388, 0.03986523513283048, 0.013712561689317226, 0.026307009626179934, 0.025696231418156197, 0.03453204148848142, 0.036289789846965244, 0.01284914877864399, 0.05605899921751448, 0.017516853088246923, 0.0194261895625719, 0.027372038191450492, 0.05169002419071538, 0.02579162665642798, 0.023147470683657696, 0.07135185200188841, 0.06112556931163583, 0.007770403221781764, 0.04174831569460886, 0.03773454696472202, 0.07192226925066539, 0.04554131966350334, 0.019795039502371634, 0.023070575702669363, 0.06818575332207338, 0.04857359427426543, 0.08441578849617924, 0.012823777506127954, 0.02506723115220666, 0.03305217696885977, 0.020066592609509826, 0.04489536111110023, 0.021505434598241533, 0.04307917392413531, 0.024477828493607894, 0.0298338955534356, 0.05471978482923337, 0.061454624868929386, 0.04491981890584741, 0.009721523034386337, 0.018565635828833495, 0.03382099446441446, 0.03441706033689635, 0.002105095311500398, 0.013625817772533213, 0.052338225301355124, 0.02737937485133963, 0.033894713901515515, 0.03598558563472969, 0.02675271044219179, 0.015459831770775574, 0.052375208852546554, 0.04393916277747069, 0.07929797883012465, 0.045506514209721766, 0.06026602829141276, 0.01950419394831572, 0.07319594733417034, 0.017738153891904012, 0.021926879483674253, 0.026912178045936992, 0.07920945715159178, 0.026782857753070335, 0.031119353004864285, 0.03559928207791277, 0.03226151743105479, 0.04985682273815785, 0.028845317528716156, 0.0353409739743386, 0.033130534192813296, 0.039692123886197805, 0.055160863125430684, 0.023746654424550276, 0.01544281920152051, 0.04185385503140943, 0.053743298298546245, 0.07223781517573766, 0.03816176957583853, 0.03186835388519934, 0.025704613021974052, 0.011991062367867147, 0.014158462673159582, 0.024405941101057187, 0.03620556668777551, 0.023437785284061517, 0.018228632930134023, 0.01725907763466239, 0.022218245813356977, 0.014327429767165865, 0.07996458520314523, 0.031132160353341272, 0.029465671562190567, 0.01263904889180724, 0.03974977222138217, 0.03253673462729369, 0.024494696874171495, 0.017061031922431927, 0.04705758758687547, 0.023494816152378917, 0.048171653877943754, 0.03722628691632833, 0.02539634268863925, 0.04043065497119512, 0.022486301072474037, 0.047173661179840565, 0.06221202601279531, 0.05629223545214959, 0.029364037194422314, 0.061529474066836495, 0.02377157871212278, 0.030498262760894637, 0.033293006010353565, 0.006822539842687547, 0.0774436511897615, 0.04972615046426654, 0.046334944399339814, 0.010294683260976203, 0.007930968355919634, 0.022906626375125985, 0.039470829867890904, 0.06537110864051751, 0.023861382821840898, 0.06856115282114063, 0.04655114940500685, 0.01951062646029251, 0.08009832445532084, 0.03700506075152329, 0.05245788495189377, 0.02017831170399274, 0.05369402987084218, 0.010875862075148948, 0.049999627218182595, 0.05645148762102638, 0.03224890685773321, 0.01959480551470603, 0.009863822853990963, 0.011033760566663529, 0.006479220631133232, 0.02302156511827239, 0.038266060408204794, 0.04074454187814679, 0.035377085608031066, 0.068921929890556, 0.022414257616869042, 0.042956091064427576, 0.01324381273505943, 0.03666101635566779, 0.040708209720573256, 0.015335023735782929, 0.013656408675680203, 0.008291398524306715, 0.014326271168621523, 0.01422753753805799, 0.07418202835002116, 0.02744156088946121, 0.046888496660228283, 0.05109611605959279, 0.017141623222934346, 0.02323998723711286, 0.04283665533044508, 0.04790959347571645, 0.021213126801220433, 0.027562316374054978, 0.013332106256192284, 0.03692746687946575, 0.017207215506849543, 0.034810434228607585, 0.0273254974745214, 0.013894930698110588, 0.02640566013620368, 0.08253539154039961, 0.03638865239918232, 0.025751847540959716, 0.03419299450303827, 0.09224258137068578, 0.02800647182656186, 0.032099194891218624, 0.013942294138749796, 0.028603565679597, 0.02332400853213455, 0.047725795302540064, 0.046504021755286624, 0.02523442726981427, 0.061536239060972414, 0.05311008941914354, 0.05980791537357228, 0.0129561774998105, 0.010562500184667962, 0.019670594483613968, 0.05635230615735054, 0.06574726131345544, 0.04986475481252585, 0.030825245393706218, 0.046539078267025094, 0.020004432016451443, 0.016234725547422255, 0.030536538921296597, 0.015743871618594443, 0.03456069602231894, 0.018043308053165674, 0.04642613950584616, 0.05989379755088261, 0.022660106121163284, 0.016964820745800222, 0.039754908731473346, 0.00702969022261511, 0.03663526934438518, 0.014801612090585487, 0.03543673222884536, 0.04406615739156093, 0.017451713726456677, 0.043510586488991976, 0.02244505632136549, 0.01879887715248125, 0.030991360944296633, 0.05614444713241287, 0.05163436057046056, 0.027507665467315486, 0.015875266532280614, 0.01923678329746638, 0.006516309779336942, 0.09835923529629197, 0.03788724448531866, 0.033372286041932445, 0.0279269305590008, 0.0608027291351131, 0.04577190282621554, 0.07413343167198555, 0.04383100090282304, 0.038235885955925496, 0.025409782771021128, 0.030916908689375435, 0.03711177734658122, 0.004721439194067248, 0.017141015934092656, 0.029217904500131096, 0.04617120372131467, 0.03473976819909044, 0.043718011251517704, 0.037202195530491214, 0.021500679764098356, 0.014979386569133826, 0.004721538005729339, 0.018230773708117858, 0.03500377260414617, 0.020678576913529208, 0.04442541454253452, 0.060634391382336617, 0.06429263151117734, 0.02548180926325066, 0.06692401066954647, 0.012388392966905875, 0.03887043154931494, 0.056494625484836955, 0.038131177824522765, 0.002696726533551035, 0.006720194709487259, 0.03739022436950888, 0.013663617262084569, 0.01655962168505149, 0.032056321656065326, 0.01942600805445441, 0.019893647603956715, 0.058996224642864296, 0.008127616286011679, 0.12595201789268426, 0.011547049407714179, 0.021675896165626388, 0.032453162861721854, 0.13147685357502528, 0.11895330915493624, 0.10494152709309544, 0.10273606436593191, 0.14417085956249917, 0.12444708150412355, 0.10203307494521141, 0.1604517645069531, 0.10955658302243267, 0.11253909048225198, 0.20965911048863614, 0.1275978452925171, 0.1323743247027908, 0.14705428055354527, 0.10218058845826558, 0.14606197737157345, 0.10901420284062624, 0.19603034108877182, 0.11060407824282135, 0.11810766453189508, 0.2843840414924281, 0.10763750957059008, 0.1523745922105653, 0.18562009398426327, 0.11347641197166272, 0.10372082902384655, 0.1034959489479661, 0.09977065598858254, 0.12201920178319726, 0.1608248773430075, 0.06960977440966026, 0.09214211069047451, 0.15092613707695687, 0.118492366746068, 0.11529453976878098, 0.17901182786694594, 0.10880121748362269, 0.10355133776153837, 0.16923812803413185, 0.09616994884397302, 0.08772566196109567, 0.06058743675904615, 0.15310074681682245, 0.07457061178450074, 0.08628167837326016, 0.1280741904463087, 0.11881981417536736, 0.1386263192232166, 0.12308444747967379, 0.17553057681236947, 0.11776699924043246, 0.1803336547953742, 0.14642525144985744, 0.14957670734397002, 0.1446629874408245, 0.08011301473847457, 0.2094639909586736, 0.05070125956886581, 0.07913223986646958, 0.0734119386013065, 0.10301317128219775, 0.08515213469841651, 0.1325592254953725, 0.11885977988796574, 0.08520997302340609, 0.11169168845351253, 0.1343745645135641, 0.13026592641004495, 0.22801300776856287, 0.15792154813451426, 0.10576461721211672, 0.17569916562310287, 0.06543711652713162, 0.09591199697128364, 0.13061014722500527, 0.03887734582115497, 0.21922958908336504, 0.21147590157176765, 0.24999553390911647, 0.12275161248232637, 0.13654207677713462, 0.13363345499549592, 0.2043254452624491, 0.08519545237400702, 0.09689220187387296, 0.20970284885593823, 0.2056658369089876, 0.08214629920465605, 0.23475509456225804, 0.09508596879563161, 0.16497352187122616, 0.13781602627464704, 0.17334976526243345, 0.07236612614776407, 0.10155438884560551, 0.13599270768463612, 0.11325600344155516, 0.12548040891332285, 0.10862599260040692, 0.0775757348164916, 0.08585131075233221, 0.10942922199943236, 0.1185408141463995, 0.14851584498371395, 0.11924535062696252, 0.13289625383913517, 0.048442463989236524, 0.13547650538384914, 0.1635021051125867, 0.152870845581804, 0.12282652274838515, 0.10170428401657514, 0.07966811289744717, 0.0871033299980419, 0.1942684706300497, 0.09348698066813604, 0.09961146488785744, 0.09080131870827504, 0.10568860093397753, 0.1404604943735259, 0.14312926759677275, 0.1445535533130169, 0.15884065095867428, 0.14647158182093076, 0.11026988617543663, 0.18373928990747246, 0.10073505102523736, 0.11047006757663828, 0.18278604320117406, 0.1226034475756543, 0.12421627103218011, 0.09446323649691683, 0.14965316466987133, 0.12638090630727156, 0.134389478713274, 0.1240183695086411, 0.13083843354667934, 0.13618550662483486, 0.21271947984184536, 0.17618161759206227, 0.12689393306417124, 0.16138587652572564, 0.07234931883535214, 0.10614907515368291, 0.14206601679325104, 0.13902726556573594, 0.08716376711215292, 0.06784559693187475, 0.16289397488747323, 0.10516843598868165, 0.12549787440470286, 0.14028434668268475, 0.10206005349755287, 0.13636584766209126, 0.28773733441318783, 0.17092511536819593, 0.11983293481171131, 0.1411672021661486, 0.18164606365774358, 0.14295470767787524, 0.1261227780154773, 0.14752514314438614, 0.09354585036635399, 0.1449108834245375, 0.11590021369712693, 0.09128800473575081, 0.10037488463733878, 0.11147268449089356, 0.08338583340602261, 0.13933316272284302, 0.09369799148823534, 0.12995040762637342, 0.31187005660363604, 0.10281222313642502, 0.0978996092453599, 0.08511351248515503], [0.07471352483012847, 0.08442378163869892, 0.06687973625957966, 0.10233406629413366, 0.00867052233245756, 0.019477890538317815, 0.0425556604085224, 0.022328173575390662, 0.05256366856130106, 0.022928137631554688, 0.035383748821914196, 0.04640884364822081, 0.02862805061574493, 0.03621383124430265, 0.0267264731893582, 0.02709357250880982, 0.009363587330361562, 0.06518266589513846, 0.07401999418756791, 0.019337840910468782, 0.008216383933488811, 0.01995566231198609, 0.009902454397108938, 0.031638578179159334, 0.036951700757656775, 0.008356475969776511, 0.017044943857139776, 0.01573601927209113, 0.012050109333358705, 0.019196985522285104, 0.026496253042880977, 0.03531535927738462, 0.06897465884685516, 0.002277664790329124, 0.022122633443879228, 0.07199523890657084, 0.03215675162417548, 0.11095684859901667, 0.03660180399726544, 0.007862280255981853, 0.020890315462435995, 0.01191657448985747, 0.08888527830796582, 0.030772248416074684, 0.030087894959641353, 0.050998539331236055, 0.05110235179641417, 0.05452457030436822, 0.008544315667157727, 0.012996323024188834, 0.02601042196952871, 0.033641063940844367, 0.01676702100251402, 0.06707813989903245, 0.03725090755947998, 0.021297231216781905, 0.04057125760508435, 0.04901332228577562, 0.04099840557734881, 0.06115830862628562, 0.03511403454467654, 0.037834417141441784, 0.04701684155900564, 0.07895995982523475, 0.032864826664860756, 0.02309683500789106, 0.015078605352235692, 0.025279074874041334, 0.01650096402902688, 0.016095883711906414, 0.038283719282065115, 0.04634391123961125, 0.03698147826695016, 0.022424452605524232, 0.05345857482669609, 0.021861241398645297, 0.02242975026768233, 0.0630412840151361, 0.02447580306657723, 0.039249298362327475, 0.05260354945702212, 0.03836055998025196, 0.03526039454819901, 0.0409637222598706, 0.020704708993434906, 0.01573037725341107, 0.05684769778911557, 0.037928930284189324, 0.07720845738159758, 0.036122191697359085, 0.0079398834578959, 0.028040279833866016, 0.010774186147110803, 0.03843118529766798, 0.011756211219887649, 0.03943422629630991, 0.025181225035339594, 0.030328089570892707, 0.040003924297967126, 0.01691404257767967, 0.02882167397599135, 0.022050954700846757, 0.031012490524777343, 0.041617467001612694, 0.03322499644543443, 0.03776031433205519, 0.030950197617390325, 0.06885060228939567, 0.036442165063428025, 0.06760863214731216, 0.03863521059975028, 0.08237094179327999, 0.04222881348271455, 0.013491190487651952, 0.0776742377451488, 0.05540490163756268, 0.015472805360332131, 0.008673334011941083, 0.03376693557947874, 0.05175169963123543, 0.024241367521296655, 0.0323150334879756, 0.014710805445377315, 0.025252388091757894, 0.03433252844427313, 0.0631509352741497, 0.021320886643869535, 0.03444751638120838, 0.008510663722907858, 0.03441991696932486, 0.08610852980720145, 0.0705270180478692, 0.01064838660282216, 0.04458424601969974, 0.02381250455177256, 0.019318049740312353, 0.010482645094660776, 0.031541469639965465, 0.021836890473163555, 0.01349268326469298, 0.02356804025891636, 0.028461765431399857, 0.03048233754400696, 0.016687457682564855, 0.053240480101002116, 0.020517664030194283, 0.036194272472390106, 0.0669751993513533, 0.022103739636284963, 0.012961805099621415, 0.05384659507711019, 0.04206852315525923, 0.05128398883555617, 0.03800418660310762, 0.06010071001946926, 0.021808680379763246, 0.03367090591096452, 0.013203475524538329, 0.06303439009934664, 0.025270560955894843, 0.043232441414147615, 0.034560706200344224, 0.03187900688499212, 0.04527041455730796, 0.033515545140419684, 0.06219017718519483, 0.04088447954771774, 0.017875290908185498, 0.02174041297153703, 0.0441739087525223, 0.046715958775686364, 0.03315518537004079, 0.019305308548999683, 0.014343599256660258, 0.004699693843057113, 0.002061628782290167, 0.05152481448437486, 0.04631512099877, 0.018794366590944783, 0.024772385634215813, 0.009036156864437674, 0.056664673145860434, 0.05355913032378469, 0.04010031019736614, 0.03655706818348595, 0.038463931397667954, 0.06156070024839469, 0.044092240277677774, 0.07200263493827411, 0.04340535927829998, 0.029751246595489125, 0.03780692968783634, 0.06210802016513688, 0.050877312264804325, 0.018184841976368, 0.0147545658650675, 0.042456295740391524, 0.0021601211088376916, 0.01437647597465132, 0.04743447307763355, 0.07506130116858653, 0.050448925966130834, 0.059969440634761534, 0.010882004513405263, 0.06341854948550463, 0.04999295721894928, 0.03714358028290527, 0.03062282143426793, 0.013596578002242106, 0.03731562962223377, 0.02529415701116834, 0.09063924383372068, 0.01007460551669023, 0.039470008840518336, 0.032518882370953045, 0.022172641474753618, 0.031357515403734784, 0.01764512504450977, 0.011645152000710368, 0.024622492159583738, 0.00978857756126672, 0.06208032236567565, 0.02197150673185076, 0.03107497002929449, 0.0454270747224135, 0.04914982317547713, 0.05190678559509771, 0.01155633940028825, 0.018618322376694, 0.041555472649633884, 0.0380540996390794, 0.03136888765064733, 0.051598228580717526, 0.02460390199641032, 0.0475962527894548, 0.04614462550463421, 0.04255845258012414, 0.04984886012971401, 0.07755079186920609, 0.030180810152419975, 0.05471887219963329, 0.02577997960283288, 0.03652866131493023, 0.008729428501932748, 0.04580434358545712, 0.0577927002949374, 0.05116245982104114, 0.042270719805466275, 0.01800660609400698, 0.07083518151193857, 0.030941020431263105, 0.033575598882245164, 0.017296907658289586, 0.03680428223950522, 0.02046083502604493, 0.039359261747449636, 0.06724527664482594, 0.042221838142722845, 0.04457230719604662, 0.021805769464533244, 0.06016032610620771, 0.02571093018299767, 0.039964280889502594, 0.027481063501909375, 0.03310789487191609, 0.04486773116514087, 0.03940540212871773, 0.020310992441539253, 0.038889250718057156, 0.03998559706711343, 0.011894907170374478, 0.026646657115114585, 0.06469029374420643, 0.05494594733629908, 0.06610520210649286, 0.008649957632379872, 0.03616754497800555, 0.04547015830342259, 0.02207075265635337, 0.04196927044540644, 0.009244130392159735, 0.007056759529015315, 0.05605657006214772, 0.06430829209940774, 0.038721550788198195, 0.06925127721790757, 0.03558829320328576, 0.04394279293982046, 0.006028707305501614, 0.04024393231208835, 0.063330801336893, 0.08685681822576694, 0.032027395708220344, 0.020491922107924308, 0.026102597559137002, 0.03800436302221247, 0.051886711136571, 0.036498212055968385, 0.03471545289669718, 0.026733574058328356, 0.04538913443684578, 0.04968308045395783, 0.008304272878116794, 0.058682307201836786, 0.033251381279634576, 0.06429047376981803, 0.07285106155489172, 0.02232936949336103, 0.036351991152124744, 0.029880697506346872, 0.009660461668058165, 0.0833119952252933, 0.02156685558812959, 0.042041704058647156, 0.05748775987220662, 0.03252967107774956, 0.04463037961561765, 0.030414260125585964, 0.044604642782360315, 0.014488420682027936, 0.029242199446473802, 0.09585594319339309, 0.022655866973634278, 0.0531127187423408, 0.04272794723510742, 0.047082913906446526, 0.009076882536256952, 0.03310445469937154, 0.04901514754497579, 0.060451614404363294, 0.049166016413697174, 0.038787182087876966, 0.003074784193553829, 0.01613910639259432, 0.016349962845976864, 0.013004188941392516, 0.036766854247876575, 0.02472722064703703, 0.044766836400542936, 0.025529834275533046, 0.05437228669013296, 0.00853994335713131, 0.025430783429848294, 0.032706110538648706, 0.04261572093569806, 0.05309979943558574, 0.019848002553252236, 0.03595158763762031, 0.013766775789138461, 0.0461639094698642, 0.015180173562839627, 0.04865215166604944, 0.16215567450438226, 0.23091189935803413, 0.13949096282677992, 0.1645361924810069, 0.07511962125343935, 0.15843864610152586, 0.15372696678553308, 0.10396568517067603, 0.11677240261009761, 0.05600860442167946, 0.18802509350436075, 0.0822490361918296, 0.10646924190223217, 0.15340217921350682, 0.10243472696415015, 0.1346797017114503, 0.14658225088247231, 0.19041840865143708, 0.1155873683414289, 0.12634917800979956, 0.12073230583752904, 0.12111020913081509, 0.11019749327429704, 0.12391568001891885, 0.1975302563181945, 0.15511666078652653, 0.1099365015647241, 0.09790366009942122, 0.15120889618992805, 0.10205591443393912, 0.15064613281616143, 0.0690193200217826, 0.1705349984445742, 0.12255056255630084, 0.11493601543562752, 0.11613096988626889, 0.11704685645444052, 0.20281907037964889, 0.14790360283638748, 0.09421859748129334, 0.07336568286908524, 0.09974223215665136, 0.19549070218844072, 0.10605738471661295, 0.06760148717356579, 0.09227207050259624, 0.11844036382223878, 0.12580340515289987, 0.13398602179118566, 0.11014597889568124, 0.12143715444420065, 0.12462910530822617, 0.0503226302431098, 0.13049293708588394, 0.08513118153704063, 0.13732164566005978, 0.14500112858201775, 0.147474307300789, 0.11182761937379837, 0.12482279991464955, 0.10595077329448291, 0.1422478641782488, 0.12418210000864097, 0.176471419898527, 0.14390244467982224, 0.07661195724670376, 0.13530825584062509, 0.08470008109829255, 0.0854425612570984, 0.15076107664832047, 0.23961470808301652, 0.16197701623397215, 0.12111183761485986, 0.16808324786169188, 0.11548546595232827, 0.08682148690734591, 0.07685976502086435, 0.1306389578218971, 0.16248978514756474, 0.10475321326936994, 0.16973318718373775, 0.17914492929620401, 0.09803626619811569, 0.09576137576784406, 0.12068293562957219, 0.12135893292725086, 0.16355030824031147, 0.052329268639108965, 0.13463133573532104, 0.14832071188305104, 0.1338403131812811, 0.10094295415495123, 0.1253433312688555, 0.10041402253721442, 0.10148522577115468, 0.13559258915483952, 0.23660358680146082, 0.16265310852655343, 0.1232123106185879, 0.1338683231068509, 0.11713202616998128, 0.10636988401945148, 0.11514877687607493, 0.2728323627795492, 0.11879309346633297, 0.1328901063118662, 0.2086342919085707, 0.18542878782110556, 0.13381315820983478, 0.09929070781384196, 0.17810831777751446, 0.1748819380466427, 0.22080172758017266, 0.11133890452661685, 0.19672263679759844, 0.12179595019136157, 0.12408551733408656, 0.10489480995706149, 0.07200686899679047, 0.11255566030740738, 0.09927861631980964, 0.12996237698410237, 0.10549228718238217, 0.13657710275479726, 0.10601813146578414, 0.10637785002057042, 0.1166772720004831, 0.09524401317217521, 0.13070109805890492, 0.14168872418148176, 0.15730020004723752, 0.1200280272002731, 0.10385886340269021, 0.10054882030401911, 0.1309124617172139, 0.1497520272220884, 0.1516346904848303, 0.17229116920913967, 0.11136506883693592, 0.08353408652224711, 0.13662804716399737, 0.1149738776896681, 0.116191155942423, 0.05507989014898028, 0.12507270436201776, 0.11472006488059248, 0.10839364863932133, 0.1807146386376449, 0.12412016333213874, 0.1201498242361205, 0.09757039762501206, 0.10516185419900076, 0.07862175761588983, 0.15383121690579823, 0.1683637678091015, 0.10203606728464365, 0.08677016251853534, 0.13097314988928183, 0.23884964627879007, 0.1338205135294369, 0.21237424122435705, 0.14642362296581268, 0.13950153440237045, 0.09954503630953175, 0.1556216808302062, 0.12246996616678578, 0.10016701543437583, 0.09281591632004295, 0.14269339027149336, 0.11117372874702726, 0.10372573483203139, 0.15848614355283125, 0.11063062931810107, 0.12281709111162595, 0.06341979798993894, 0.08436652685382537], [0.06280838365533523, 0.05046186223626137, 0.01201096295179533, 0.00743178540973791, 0.01464767285090472, 0.023492407353062714, 0.06820145462240491, 0.021211752767807672, 0.016615817955295955, 0.02036108189661588, 0.02429785386526159, 0.021223874795915823, 0.05385570101706045, 0.025057816478822912, 0.038756648012037785, 0.056167483396295986, 0.015425703155675104, 0.03195812746084162, 0.008717499856304909, 0.07389426843396255, 0.03906015672587922, 0.060825745042945654, 0.02927032472299678, 0.051648443564772606, 0.08713524828531913, 0.03073567198589444, 0.09187716312174286, 0.03306837699243, 0.018447643678103174, 0.05285667694572892, 0.006183495986208851, 0.010682870600638645, 0.05411145443628941, 0.010027032578364015, 0.031777260558945794, 0.04925458219700626, 0.010861664578052503, 0.030406317873192684, 0.030061035150928155, 0.003660142995483641, 0.014105680282227695, 0.07025544797735554, 0.0401312005040901, 0.018164869298094084, 0.03875897199447666, 0.025731757815395082, 0.015436788721542274, 0.02669080769244049, 0.02603328859965716, 0.013309118337929249, 0.036956270691007376, 0.03656388746042337, 0.04952993170757379, 0.012925778282806277, 0.004512311308644712, 0.040972007172448296, 0.03354451180036579, 0.02607529839899923, 0.016222279518842697, 0.10562944625105176, 0.03493459256631987, 0.03600135478856308, 0.04550209355407527, 0.03360172587313822, 0.06753205947045769, 0.015851354958223443, 0.014303428287218724, 0.06619506728436265, 0.019653551380283067, 0.02696775515297694, 0.026362269518098662, 0.04739580675959587, 0.11552141473761626, 0.09037734288722277, 0.04519112774037889, 0.02856499096378684, 0.03698258427903056, 0.02067303837143949, 0.024170647208978022, 0.025515968412426964, 0.05847437014537198, 0.05452081122036491, 0.025039160158485174, 0.03873662105096238, 0.06597750181598322, 0.030594740262521163, 0.05951488324041877, 0.026917772567165748, 0.03251797652670315, 0.03031938735927854, 0.03696631300928337, 0.03674429635118161, 0.07964590444628682, 0.005309383850544691, 0.0534428565629891, 0.028511627577245235, 0.032571265274392705, 0.04453493009454437, 0.02349229369844709, 0.027143767136814337, 0.04332542106775301, 0.023646902991458774, 0.06167267209717205, 0.05272325999768717, 0.017833790010107414, 0.07414994721433946, 0.08482902310788631, 0.08175034009452377, 0.02409772335418633, 0.019487992228407944, 0.03088531270623207, 0.02948891817192946, 0.020797876940507973, 0.02944717469758221, 0.03905371742855225, 0.04338695740859423, 0.03152350203267165, 0.009612148278392851, 0.027644329205421463, 0.05669897309105311, 0.03713594337127038, 0.016429717852068797, 0.017791267916826264, 0.08335447830281087, 0.051246129974190674, 0.023026662612599984, 0.05852922970162971, 0.020393420875604664, 0.016449731242443835, 0.08166723991078989, 0.019037538274590458, 0.09287196331258331, 0.010192986976887499, 0.04928127237196479, 0.04104939069865005, 0.031596115457692316, 0.09167817594217402, 0.07459712214767933, 0.02168217600722398, 0.0520195954346231, 0.01851797044011099, 0.06560220409716878, 0.06844705037240471, 0.03881466954148241, 0.030601549361433302, 0.02455701692295926, 0.03056310356727668, 0.019409350019746592, 0.014350549151588763, 0.023866921363930618, 0.016261013690382242, 0.0349844309634396, 0.0278425886561828, 0.03528542570503695, 0.02499750828636544, 0.05289886825318847, 0.029019972442516258, 0.02243123625937317, 0.0479450638938163, 0.025030001632070968, 0.08573584444820881, 0.03193412089188184, 0.027097874420828054, 0.013450255318145667, 0.04767177373703037, 0.05376379005610943, 0.033452655122216256, 0.08023246404315744, 0.03379590902477503, 0.03476801561191678, 0.05689512738691909, 0.007862377795390785, 0.04022006484280739, 0.05424659147060343, 0.013135922274419239, 0.013497231993824244, 0.04592415590637496, 0.016396815689014535, 0.061021332762071064, 0.034161408697920184, 0.01978756035012858, 0.02088119086277272, 0.035273693834564517, 0.07578053471765347, 0.09448182835642781, 0.06671940522002322, 0.02170379752559321, 0.07080542775137083, 0.014293543728334563, 0.023367728239723613, 0.03096810754920755, 0.01949784964589136, 0.011487687771607722, 0.03638425549226148, 0.03369773518560188, 0.029803653247654438, 0.012172905512021055, 0.06971976493618318, 0.029669045470654964, 0.04177046986296773, 0.022286155294360857, 0.04854703302096043, 0.10192415650401797, 0.013576405156137688, 0.008980569579372448, 0.007521992399623352, 0.038132748633090935, 0.0335458620850529, 0.0718697981376733, 0.08071576418089015, 0.028603745491376946, 0.01985665217840246, 0.011846621770278683, 0.02921109540121896, 0.04953200463205576, 0.010343471625154572, 0.012336630074839507, 0.05021862778812647, 0.03813962897818003, 0.015151887134249722, 0.01631745253689587, 0.045576705264725854, 0.002491816591438172, 0.02136069629341364, 0.011308344180828758, 0.03239448654598423, 0.008737125633550542, 0.04885839577764273, 0.0413248318114451, 0.03992553314726267, 0.009651266670386707, 0.058351650301899226, 0.04736328457615205, 0.032733947437788756, 0.054154300530041964, 0.06294608555201973, 0.053993100965661664, 0.02111565863846668, 0.09665381216577121, 0.01949021782326911, 0.0386636649657573, 0.0257330283722175, 0.08000324812850781, 0.018652786866628697, 0.03295892929392202, 0.03097043153164642, 0.022769677652312175, 0.035002686948116334, 0.09575928587998662, 0.06785358328904424, 0.07324001139828137, 0.07907175525490727, 0.025382208804200803, 0.019780812319368124, 0.02238822901355369, 0.033194889846657, 0.07769173716327973, 0.03966243119378175, 0.017707607941702008, 0.03818587453237601, 0.009305350366048515, 0.027818885731643865, 0.03416894722197737, 0.0698729238605925, 0.01609581585840455, 0.012882285036279686, 0.03188362092311893, 0.022986138804948757, 0.03608766783561025, 0.04121263265343649, 0.03922207893005439, 0.009123619180172682, 0.014238348297242607, 0.08452216243105275, 0.006507031661125698, 0.07609570744846549, 0.03223731069426451, 0.020690140846584524, 0.025328017604936446, 0.08030380521501813, 0.01961879512029035, 0.013483496748709252, 0.026630075415596366, 0.09770331584981509, 0.06159455914582525, 0.029467001490827118, 0.0468732805124351, 0.12060083289231573, 0.06351473182439804, 0.02463116044444697, 0.03239427959280355, 0.0817449050290244, 0.05554955851818834, 0.02107640029862523, 0.046848279889672995, 0.03555349792752947, 0.04340800217219761, 0.06349269979234252, 0.036896535860640664, 0.058675874689860005, 0.035578454445515356, 0.037129015528729985, 0.029849780058222156, 0.04602113552391529, 0.047800254342811446, 0.05059203578691397, 0.049012284127197096, 0.07002494963152067, 0.012364304125575083, 0.02135449617968074, 0.01169746705064816, 0.034835801260279756, 0.02790065768307873, 0.042637149071586986, 0.01632276037707925, 0.04322015314495989, 0.05235974503947156, 0.03685238019430211, 0.08791404363832303, 0.03681292338296771, 0.019468525058722923, 0.02684634318575263, 0.06765593960881233, 0.05677465010168297, 0.07848638987966947, 0.018079243267753294, 0.038741160450237136, 0.012836359241711242, 0.022332906357145736, 0.014200768483403538, 0.03257279537085976, 0.06005931938333171, 0.04788749359015908, 0.01660798766118075, 0.03339998044871858, 0.05661019017653806, 0.056225515103765895, 0.019380476658365557, 0.03500986245593854, 0.04377216173868094, 0.0472708375725363, 0.05505188022341047, 0.04306328263399856, 0.043478725877191336, 0.049734133428760936, 0.034052497042076926, 0.030266627868903533, 0.026024464251739637, 0.047644920713667355, 0.02860806097409555, 0.04991088840844376, 0.03536449878343514, 0.10026108752936125, 0.10703091283461877, 0.2630851258124624, 0.11584443811859403, 0.08516810741275549, 0.1328443187688078, 0.23542318014161928, 0.1832858792373112, 0.22989491107208387, 0.17668665120644228, 0.11612972138183457, 0.15043969532208784, 0.1147804002144507, 0.1350206791290215, 0.11117509260241475, 0.08519096047218357, 0.0996637392256941, 0.11936219435717378, 0.12469047201531273, 0.14000461383589677, 0.15292434128267424, 0.1344843107674803, 0.19939336420169898, 0.11438136734068394, 0.17223703568535192, 0.16533600884888852, 0.217221681826881, 0.07897657036249127, 0.10011499893984624, 0.12005185735012804, 0.15832199236111982, 0.16859885305166245, 0.12469292831208025, 0.15818638035229274, 0.12263459233301026, 0.1321369052997657, 0.12580568503056253, 0.09805306672517743, 0.15511884566928658, 0.16627340497715132, 0.10911617308322873, 0.19273705780506134, 0.1312160518552576, 0.1882667333952018, 0.14390586449631623, 0.07031264169407742, 0.16313884460500308, 0.0792561335755246, 0.10530313876058374, 0.16765592007764749, 0.10776997996228081, 0.14180365444294044, 0.1288547907024622, 0.11846404469438962, 0.1162156510565962, 0.15449976388897213, 0.1605655684002808, 0.15723618705357822, 0.19999256490596704, 0.17178046304200376, 0.09601355330752474, 0.17723588459193707, 0.16237466489630087, 0.0846164720132947, 0.14531254901417665, 0.1106313146384699, 0.23704303322093828, 0.17068724813205854, 0.14986454189888068, 0.11300996664379324, 0.12311693573636667, 0.14846433060509817, 0.18620466547352926, 0.16488946495311602, 0.15798938806567872, 0.21676969608025892, 0.09254240563937596, 0.169669812012996, 0.14235351208065236, 0.12710418392504963, 0.09654110071382352, 0.20977408146219595, 0.06600265510912452, 0.14914294704794884, 0.21856087925178663, 0.06875224863844258, 0.1435323716806514, 0.14301292598247528, 0.10607862964804683, 0.10170400581721749, 0.15375526169581072, 0.19819750051413262, 0.156744425584163, 0.15332967096141406, 0.1127620367333293, 0.14180685712822846, 0.09627221764198371, 0.20365822820791177, 0.11246274850730385, 0.11122976895421743, 0.10119997643466506, 0.08648489282599517, 0.13649415863411768, 0.09241293437246766, 0.13798289160643304, 0.16818782367876597, 0.1816368627228907, 0.19117512447493418, 0.177880126450743, 0.11013835216207163, 0.08228380432618515, 0.2293584341449397, 0.11665805588875498, 0.07468140298234564, 0.12741100388978208, 0.15753833869738237, 0.14740825870207377, 0.10132197703101806, 0.09693695125835282, 0.1335417442023754, 0.20568764502448694, 0.12038862785058362, 0.11271177085914783, 0.16986376446272644, 0.1258994857115405, 0.07407541014254093, 0.09588125933493886, 0.14954845314579351, 0.09620055077331406, 0.11431246889489037, 0.10189205501228571, 0.14154351768749102, 0.10087923971670014, 0.10654617420264653, 0.0753505335056356, 0.12930463227842534, 0.10298160583313022, 0.11602256713168961, 0.17013289859252317, 0.06755759274320942, 0.14823799846427782, 0.08529561092810971, 0.22307306927229675, 0.12930267809757165, 0.10061115731618234, 0.12524517439305782, 0.11850614100694656, 0.08120530005544424, 0.11489032288747174, 0.10132834847484316, 0.09812661313584872, 0.1728864072688988, 0.06893972107874495, 0.11704943488751139, 0.16202273592352867, 0.1365763156541756, 0.0902874641386526, 0.07213458285800048, 0.19397469210837567, 0.08994973011847053, 0.19794993022722857, 0.12596325443259307, 0.09551054851285048, 0.13242594764700957, 0.10838277850832258, 0.18704955013734953, 0.16087439682866844, 0.12910280882247857, 0.11093058929379497, 0.20379206245499, 0.08930728637746402, 0.12855327688157558, 0.17357970720955304, 0.16419232450425625, 0.16639612482062408, 0.08424645329692534], [0.004771527376890714, 0.008880857162044516, 0.01012548292055726, 0.022547606711408923, 0.03722384758293629, 0.09901964664459229, 0.04090604339061039, 0.02971864298784307, 0.029349933844059706, 0.025876507994585803, 0.045180875076247115, 0.019103921051802378, 0.009124914333889527, 0.047401743941009045, 0.03348211032737579, 0.023736449257869805, 0.04940011778048106, 0.0166020877991936, 0.03536364722198673, 0.041944907645561864, 0.07296593074819871, 0.046299870924225876, 0.03153716433527214, 0.048686733203274865, 0.0026538045286932693, 0.05128889464374099, 0.025359720457345247, 0.017194011215386645, 0.03357020452884691, 0.022209606366232038, 0.007477388900172497, 0.02318231515320284, 0.018382414410422956, 0.10883983969688416, 0.0569210745660322, 0.040090315376541445, 0.03488284409312265, 0.03913052759266325, 0.025325406941452196, 0.04457423084282449, 0.05077086029840367, 0.018474859717701162, 0.04435580702764647, 0.03471342407699142, 0.0631663448044232, 0.03997528333482998, 0.03794312523677945, 0.017578506476378868, 0.08659070357680321, 0.03520744167534368, 0.05267207131588033, 0.004574398111019815, 0.048826511417116435, 0.030433934248451675, 0.05252983680527125, 0.030448950228414366, 0.015149890544957348, 0.06600313008363758, 0.019820888293907046, 0.03556255637002843, 0.021887765332524265, 0.01363418495748192, 0.05657644323738558, 0.05318282837314265, 0.006315669518828924, 0.06188294331410101, 0.03789033181965351, 0.025513680053076575, 0.03656687640718051, 0.012247939610720744, 0.026877762749791145, 0.044358073334608755, 0.03058354782738856, 0.06990679632872343, 0.010700668574177792, 0.018030354819659675, 0.01896005466447345, 0.01675259874069265, 0.013311851137716855, 0.057987263426184654, 0.06185177141534431, 0.023436943900638392, 0.05409801944292017, 0.05674236879817077, 0.03882062029359596, 0.06938357797584363, 0.04753207355471594, 0.029708224082631723, 0.04435474851301738, 0.03581440142754998, 0.0367282863174166, 0.03014965521703873, 0.024882413480164747, 0.025820927494870763, 0.017988463763945868, 0.03276353156460183, 0.021615720287497555, 0.01934605627320707, 0.022396688648898686, 0.005800323444418609, 0.06652961218995707, 0.027980543307161758, 0.03586830085675631, 0.013864919094235768, 0.024806417558076124, 0.03329151662598763, 0.03036029962822795, 0.023325562377327254, 0.0498390281572938, 0.024446018771933656, 0.023603777002011026, 0.049350567760744264, 0.01600409488725875, 0.06838301023734467, 0.06235921382904053, 0.03717526447560106, 0.0650412727679525, 0.04431451477908662, 0.034382176851587634, 0.014918737412829484, 0.050295112255428515, 0.03768472553097776, 0.03204672717090164, 0.07025869137474469, 0.025649809444855367, 0.05994351381169898, 0.022022790408560207, 0.011909535537207765, 0.05521858609946711, 0.08017030345009905, 0.032058058705713065, 0.006680722207030547, 0.031043357082775662, 0.008226845247138823, 0.07298655142741543, 0.029894492123275995, 0.052330262692911286, 0.023163570623312677, 0.038652879651635885, 0.04086217949432986, 0.015388629698593701, 0.005149935754681272, 0.027570314605587294, 0.028184387101126567, 0.06897178864372627, 0.04385090233492, 0.044980496899890046, 0.03210474530767117, 0.03659967339730688, 0.02652517220537577, 0.019246684819726006, 0.03163783179063882, 0.04681596126673477, 0.05239666073716112, 0.09059638077659266, 0.04938159038179687, 0.010481748580267387, 0.005200002309201019, 0.06251844564186675, 0.06641329093171017, 0.03541682740407331, 0.03248920324923737, 0.027471182335700308, 0.028822803736797402, 0.017457331996411085, 0.038266097727630816, 0.030801510238753896, 0.05279790563508868, 0.015129056127209748, 0.03508723580411502, 0.07888898506228413, 0.03086040707837258, 0.02633661071636847, 0.02547030130933438, 0.01596987127725567, 0.023466846938910227, 0.028193340370697633, 0.004564490227494389, 0.04363930118935449, 0.06420940240578991, 0.013477658803042556, 0.03205769908215318, 0.043762821704149246, 0.02343834168277681, 0.008681512055253344, 0.04285305891452091, 0.04695896930726511, 0.030627197985138212, 0.05409573956525751, 0.04850951681977936, 0.013959392373050963, 0.02719154448381492, 0.021172864229551384, 0.014609213486047727, 0.02104482297519488, 0.03271051423091974, 0.04398650416572179, 0.049520194730056186, 0.06514134989785296, 0.08522659713136298, 0.01957784383557737, 0.04187305417976209, 0.013863159992199923, 0.022231085392247354, 0.054253230935760906, 0.055630833442722044, 0.0319889125946377, 0.0056004533211567575, 0.02965762572629111, 0.08076873740979604, 0.022320692726810063, 0.016943574118028795, 0.0012276746814937464, 0.015404899272003343, 0.06057303824595042, 0.05989668132471187, 0.06026128533163241, 0.04483346853937421, 0.032072857554469786, 0.05768640099891594, 0.02383937793118613, 0.04203553956800273, 0.0257622206450573, 0.04582415341532656, 0.064114875692342, 0.056355549554739676, 0.04303801738257919, 0.04540647100657225, 0.029806068832320825, 0.02659275768590825, 0.05798653060836451, 0.04352688490013991, 0.026491320093295405, 0.03585836371140821, 0.0914869579885687, 0.0297501541541091, 0.03676740046856659, 0.009090384534959282, 0.02087176770770124, 0.03595907866422619, 0.018471400885443603, 0.032408532220870256, 0.067413125852389, 0.02350482454390398, 0.03306689439341426, 0.008423192077316344, 0.01375137219604637, 0.06727709993720055, 0.011263085895084908, 0.03754745450403009, 0.006003917028595294, 0.02682304398954979, 0.01841225129153047, 0.021678771457767913, 0.026863425304847102, 0.04620376322418451, 0.019115334010816047, 0.03653983000133719, 0.06393338114555393, 0.032343223225325346, 0.018329093432320014, 0.04451651804681335, 0.05450934737122484, 0.037847590898828845, 0.02148925493072186, 0.05244909792340227, 0.06549572838204247, 0.03350055290918265, 0.033977495173790624, 0.014306167872356517, 0.0769344920824681, 0.04578154141615544, 0.03782959615013429, 0.09558762330561876, 0.07930384815803596, 0.04348176571407488, 0.05169699613803199, 0.039582143537700176, 0.062458266371062825, 0.06622795587671654, 0.02153222485711532, 0.06276591414851801, 0.012683144338162882, 0.03960923744099481, 0.01119445716696126, 0.031875400471368005, 0.011442269181965717, 0.02744962867083294, 0.014059075104471828, 0.0643132318343435, 0.04327424256397145, 0.025335659605583975, 0.005358353298756161, 0.09257533494383097, 0.05361805769747921, 0.032632682871605666, 0.04176442072327648, 0.032580208365938494, 0.044473366612302404, 0.029411755169608762, 0.02386056857981852, 0.038270959431039434, 0.06238099480313914, 0.0189316647592932, 0.051829154403614144, 0.020514237428350107, 0.04965805947514517, 0.07580867356487683, 0.021418705948495438, 0.002366237571030589, 0.06416163354047708, 0.031545846190835745, 0.01569180253760091, 0.02951495016791991, 0.023504290197576796, 0.02582287149769919, 0.022556593907730918, 0.018906479235738516, 0.03522163323525872, 0.03286685548456652, 0.05100918893835374, 0.010676942749081977, 0.03154391575870769, 0.029230365795748572, 0.02186778586890016, 0.049305767486138005, 0.029454451985657215, 0.07895251629608017, 0.05199793320415275, 0.09259892082107918, 0.0335123254917562, 0.03775856371170708, 0.03542230996702399, 0.04692068975418806, 0.04179557565865772, 0.03880297499043601, 0.005578552331176719, 0.044266430394990106, 0.03003847725423319, 0.017878113613863076, 0.018626084817307334, 0.028909764784787382, 0.025673300327200974, 0.03856668874089207, 0.04007619845547846, 0.109364442261202, 0.032664316174175055, 0.031238347691084658, 0.013781371077389588, 0.0036203600632558975, 0.028749226792050258, 0.024913190132273094, 0.13953571899660996, 0.056863480513649325, 0.13460869980709894, 0.14747148459511145, 0.0872534897976688, 0.2841054078723703, 0.11068058306617395, 0.07400012668222189, 0.07103091850876808, 0.10709198777164732, 0.1563943015145404, 0.05604378646239638, 0.1471851971000433, 0.1487471711422716, 0.10736386996826955, 0.16916093789041042, 0.1523770892194339, 0.06865084157990557, 0.13449505876217568, 0.274757230920451, 0.1516052692064217, 0.10233953528638397, 0.08803135555769716, 0.23250132692711695, 0.1583756644810949, 0.1778284085116216, 0.07737619123820748, 0.10003293012934071, 0.21541645298046724, 0.21711706529770577, 0.14711568797273294, 0.09927871810006243, 0.09766316014741148, 0.15294070754732403, 0.16640396868543966, 0.09264030467186656, 0.07814088663352386, 0.13325249829462596, 0.13432940122272286, 0.13475474768451282, 0.1285466408090932, 0.1542273863617863, 0.10317447262683085, 0.15920513282929147, 0.11695277078875474, 0.16784709053380148, 0.15180028017078126, 0.16867858091635363, 0.14276308938860893, 0.1490856244095734, 0.12371898628771305, 0.09789797397596495, 0.08198839732046638, 0.09812324760215622, 0.13225752168468066, 0.15068573211984976, 0.1320781713085515, 0.12683371986661637, 0.163480866966503, 0.14060722078595841, 0.10724740621766873, 0.07046196689563138, 0.21365565460707459, 0.13628048795674527, 0.07262358268988983, 0.10763335015092577, 0.14216531360788004, 0.07651919472430434, 0.087727202235588, 0.1290218731654542, 0.15744316737566674, 0.16026519451822552, 0.07327826720263277, 0.1024348558858037, 0.10608335225177662, 0.12610384688845702, 0.07496740549270596, 0.14825243768947466, 0.07553742240582194, 0.13007875931050095, 0.14672177125300678, 0.11155074315943889, 0.13799068118844712, 0.10953334998339415, 0.0761789365538529, 0.21261033069874558, 0.17338601260312966, 0.11376375119600977, 0.15731047306741985, 0.18450421600469522, 0.1801179756543466, 0.13650078113589967, 0.15023555127637728, 0.16159041412174702, 0.11478021022464548, 0.09784167592546769, 0.11734766459890775, 0.16807391121983528, 0.10827576675053154, 0.09173806344291993, 0.1286113051963704, 0.10057255545897142, 0.116347286850214, 0.08975081079240356, 0.1364961399563721, 0.14901114840592655, 0.08787220516907317, 0.14999920395868166, 0.10780540627560445, 0.08968318799244505, 0.1378549470433167, 0.09178404776113373, 0.0727814913594297, 0.179042321230684, 0.15729375396456036, 0.09121924878231116, 0.10256275295146874, 0.12591035584253923, 0.13633648066648416, 0.11607010529509612, 0.14796651660331658, 0.07066659270120518, 0.1553126759827137, 0.1667002984987838, 0.07503014962588038, 0.19023508206009865, 0.07331131864339113, 0.13282616117170878, 0.1763367171266249, 0.12301181709127766, 0.11129549185612372, 0.16381223632821015, 0.1334529782512358, 0.1031261473628027, 0.14725575117128237, 0.07234375484819923, 0.12329540401697159, 0.18679628015628882, 0.11458411360425608, 0.14852533090327466, 0.08967015333473682, 0.15048864483833313, 0.08457890152931213, 0.128175536436694, 0.14054133503564767, 0.1342316921800375, 0.1428614498249122, 0.1458145970744746, 0.07635897903570107, 0.13626504449972085, 0.11249957938811608, 0.2023004117820944, 0.11676701504204955, 0.12578287268323557, 0.16422348283231258, 0.13944389963788645, 0.11523467940943581, 0.06472809493009533, 0.16285136288830213, 0.22537744204912866, 0.16708452573844365, 0.06305758921163422, 0.09602928853460721, 0.0702024001095976, 0.04000006682638611, 0.13405253179371357, 0.0946365071992789, 0.12778161971696786, 0.13150772691837379, 0.3417510289166655, 0.18374621096466268, 0.13620795256325177, 0.077539691036301, 0.16070377241287911, 0.09359302890620061, 0.11274493765085936], [0.008492849634162017, 0.016185577559684004, 0.060943660858486376, 0.03696658781596592, 0.023432207726208226, 0.033891534964953146, 0.07971521679844175, 0.019999003736302257, 0.06937160183276449, 0.0645283477913056, 0.07529521933091538, 0.02823257665815098, 0.042593838181346655, 0.0588740272713559, 0.05865094531327486, 0.04185042503689017, 0.03063799686996, 0.01697054418868252, 0.05570345365309289, 0.02219894658108907, 0.0532988205419055, 0.08994223909186465, 0.06315195986202785, 0.018971939205325077, 0.0066098636432018664, 0.09005137466426406, 0.036757761878626685, 0.02421096067077347, 0.026678200511794006, 0.019376571689333235, 0.05777993705123663, 0.005736518676193165, 0.030750827065535953, 0.05282758136412927, 0.0593411172074931, 0.01595774246379733, 0.07462415498282228, 0.03387023235804268, 0.03150180248277528, 0.013679250708914228, 0.036522496824285815, 0.03212085033633879, 0.03438122011721134, 0.059629806716527255, 0.05486222290034805, 0.046803679782897234, 0.0098691637727565, 0.016311868193692396, 0.04122017117749367, 0.03103574052719133, 0.029893674488578523, 0.021232429426163435, 0.05600389199597495, 0.020536142235089625, 0.057758773544004986, 0.052810909758721075, 0.04347929245393191, 0.02168305471007313, 0.008727927243203988, 0.03895247661109481, 0.02995866796533976, 0.02644866398934807, 0.05763460163559232, 0.024268254471410598, 0.0141885633347556, 0.03501370296414409, 0.04372374826510038, 0.07376232051423617, 0.03521435255450862, 0.030276948386537175, 0.02761282821718071, 0.009311698909316744, 0.05972666759043932, 0.03436922022540655, 0.07522083153682095, 0.07040393858083657, 0.06387067093913044, 0.06487787475011178, 0.013776378755989884, 0.03416561222236071, 0.04383177782541939, 0.036726969959480424, 0.06240713197205748, 0.027699280363906707, 0.22590341525418417, 0.017674941569566727, 0.015594731317833066, 0.040170701420200725, 0.044522475584277084, 0.02818462798105819, 0.05623248705108251, 0.030691309366375208, 0.021901264786720276, 0.03690728385533605, 0.0823453813791275, 0.037222256418317556, 0.06246372179261275, 0.029183875968945876, 0.026677583044927036, 0.02765856317377516, 0.004936567873560956, 0.04261710514713611, 0.05842729338577815, 0.022905136990760053, 0.041920476992215426, 0.0071995118466605034, 0.028669166445199932, 0.003409810859011486, 0.021099811453106146, 0.026344057638198137, 0.08137743081897497, 0.0629519277385303, 0.03586639417335391, 0.03250280109101108, 0.10274976398795843, 0.036159266850778034, 0.04812551010400057, 0.021172757360285947, 0.04739020884569202, 0.05280023640287774, 0.0267970832397363, 0.03300323763063975, 0.0450913695219372, 0.03553405789924519, 0.042061775124498775, 0.03494390206677573, 0.022191896602245312, 0.00757259754131415, 0.04379842782925282, 0.04050919200692858, 0.01388535656899746, 0.017739975758429085, 0.0259324107984347, 0.059662810659834316, 0.045382057316601276, 0.043488663022539446, 0.017538399967764105, 0.023357470486579195, 0.008218122679474098, 0.019100925319695046, 0.06713746421571289, 0.023806382469566803, 0.040310835864927085, 0.011848997491012727, 0.027922387767050947, 0.013574272859841585, 0.06624342647514173, 0.02523940771685115, 0.014749478548765182, 0.015638396742620637, 0.06080050354025193, 0.03927233462621059, 0.08808050184909787, 0.04586482480434435, 0.0230988960580102, 0.07220526585089308, 0.0182770141733012, 0.09383688760655266, 0.06019663451505559, 0.011531239541779672, 0.054339476129306216, 0.06671159528195858, 0.029468545157994543, 0.02383915571096752, 0.0031706684011234237, 0.034721213659005504, 0.06410589867404529, 0.016971831708880405, 0.021930870965921452, 0.021815533583451594, 0.030243408400565386, 0.05673218398754086, 0.00891315542893218, 0.08601632368351732, 0.01888295273030443, 0.024548253643193414, 0.040262836297707896, 0.02559412207587489, 0.019620533866275634, 0.021605252188497355, 0.08877121657133102, 0.01704783780899431, 0.05268643590222512, 0.03710072740380253, 0.04174794928569879, 0.0325908986851573, 0.06660357929233994, 0.039866554883441756, 0.04683980159461498, 0.07804882978754384, 0.039590710042310615, 0.06767131521233491, 0.019972707111654536, 0.03584942061986242, 0.014579086531219738, 0.05694300481783492, 0.04398221243172884, 0.025849207138110484, 0.03280643533383097, 0.01778359877477799, 0.03294185396017773, 0.08600717024611575, 0.031200851845954145, 0.057969099043735435, 0.017726176052487323, 0.030864977011723176, 0.11466414002435547, 0.06752814432340008, 0.030724822210946252, 0.022636728893433298, 0.012907737732997962, 0.04155898406835539, 0.024904364088018025, 0.028869863533015763, 0.03483469524819936, 0.04834772014458265, 0.015727342505540167, 0.042749131098389626, 0.053538340010813305, 0.027523487207612822, 0.058562579697796276, 0.01557621409717415, 0.06762666082275764, 0.03158184925892523, 0.05884565093687602, 0.035784240545971055, 0.057130436546036174, 0.04196244438311883, 0.004551017066530351, 0.0881796358153224, 0.040207366059933386, 0.011242246388324668, 0.013360442726739814, 0.05664577255291598, 0.023057250971240655, 0.09100691481892552, 0.07341363493885313, 0.01030713607490595, 0.03219087175758822, 0.01854907618170338, 0.009546729869076183, 0.02142307741035308, 0.04148622475830572, 0.054307466239801476, 0.05031347680570824, 0.02430469180191202, 0.02123628180873181, 0.019019755568089228, 0.006978095267965857, 0.010519852562408363, 0.031102586404553483, 0.03366171515413693, 0.044040043971368244, 0.07347990066877433, 0.008718721219338477, 0.04331462557560631, 0.02094694090607975, 0.07066345108406884, 0.04080363888559597, 0.015331551332824996, 0.052039856490279944, 0.0277277228555509, 0.05953738346163716, 0.0172075378109834, 0.057714865542948246, 0.055491143438432894, 0.044465363291757445, 0.044759593039218865, 0.03172286579917584, 0.018838444225756184, 0.05052212632394262, 0.040061145156089745, 0.05071472848898598, 0.05253720908824887, 0.023812492677409734, 0.01289743502690856, 0.030646325887313912, 0.019491033761629036, 0.08007118983992509, 0.0471798663825861, 0.03895009156050427, 0.0523822147266141, 0.01970705725917859, 0.030328802032662288, 0.025909686660660163, 0.03630497546068259, 0.005509024968237749, 0.028425772541335652, 0.040892136815403185, 0.028747286181896925, 0.023871143548084155, 0.019333259102755358, 0.03030011696474893, 0.06181469626192536, 0.03224315627345017, 0.012868994231601911, 0.04836871062538453, 0.033577190046863895, 0.02256409341602453, 0.019843259593471885, 0.0409515222002353, 0.05730403973055737, 0.026545643606888394, 0.07663861010223627, 0.038340125898165364, 0.022313327229182636, 0.028580529415713887, 0.04613025074026414, 0.05662095174193382, 0.09380434506705829, 0.026287930917793086, 0.02410672581754625, 0.014490534318611026, 0.07548592838325671, 0.042227931387190304, 0.03082643961533904, 0.022150960584570254, 0.02931099950468966, 0.01858019210132105, 0.041805964029793224, 0.02862984194819416, 0.027252098645216653, 0.009910198178009262, 0.03239679356504764, 0.06513991140361343, 0.03190389894215124, 0.011115847188713295, 0.022629027520971637, 0.007067482078647507, 0.014065807020025594, 0.010064251072305654, 0.03008327752883945, 0.018211465994162217, 0.03220810993973698, 0.01304012754865523, 0.0606167766132525, 0.0018341880848830833, 0.07079467975667544, 0.021741233998909593, 0.03665825811081699, 0.05240374803543091, 0.024935142436463918, 0.05279446206986904, 0.11485357343086175, 0.0721259858193142, 0.017748733949182288, 0.04361711987959487, 0.03573678719944187, 0.03606596150036369, 0.0030590941314585507, 0.010230532015806862, 0.03137396987793701, 0.13220998352127417, 0.07967024349740573, 0.1467084176838398, 0.12711046715932234, 0.23632622882723808, 0.09209398898695197, 0.20727461629680224, 0.23506333945052965, 0.15081686579755374, 0.14449553856892244, 0.19253896629171713, 0.08917690587363072, 0.144091823803527, 0.24063916025417192, 0.1433069080646549, 0.19997664647442953, 0.07137819273131234, 0.09379042152847562, 0.14203059726527759, 0.1176034180181367, 0.10864660649427346, 0.17824406549334526, 0.17682642942028387, 0.24853299238852092, 0.10321606003812381, 0.29637060686945915, 0.0868674237281084, 0.11481637614113943, 0.10086900062326874, 0.15427260393542902, 0.2248492975320135, 0.10345637678567852, 0.11896213011017867, 0.10995978210121393, 0.1459694794778313, 0.09031908387052161, 0.1518921945244074, 0.08271647218082633, 0.06864172885460512, 0.10837485321930476, 0.07288167026958295, 0.09288996484662805, 0.10812484699168376, 0.1559310792280095, 0.12203476737652506, 0.08846061716654471, 0.11717997145439897, 0.11206404811569623, 0.15163412051541464, 0.07852049983505692, 0.14636564893381937, 0.0989896689674684, 0.19726538338831492, 0.15000506650124276, 0.17365391179919243, 0.11678026004561357, 0.11375987676105329, 0.15829329032983097, 0.06435901937740189, 0.19740384524422033, 0.15822785241263254, 0.05434645146929792, 0.09365991210298878, 0.08731043924178396, 0.3074704355427197, 0.17801480208124432, 0.12571852042206696, 0.19355853301073822, 0.0971568033897451, 0.12299371377698012, 0.12504739500582218, 0.11310795388583626, 0.14027521360133374, 0.11446543782949448, 0.17399673483201436, 0.10088444408029318, 0.11279242831681456, 0.1140983368137053, 0.16516485517578466, 0.20408406321491512, 0.10022429057529994, 0.16417761386505195, 0.10466975346207619, 0.11369326497827258, 0.27052094680922373, 0.1184770589960473, 0.251084066927433, 0.13547038499798092, 0.17918889836541244, 0.15526466284479412, 0.19392727608127253, 0.15979414193757943, 0.12228984226073537, 0.15785047837666102, 0.14206004568508693, 0.11553436118577208, 0.13183697925082274, 0.1261645486312253, 0.09461092642907586, 0.08887381106615067, 0.132617498082774, 0.17622764940772737, 0.15484399827463285, 0.15641716814466886, 0.18958690469818457, 0.05975431789244924, 0.14735339236046585, 0.08470922775034394, 0.1197947875729629, 0.10602636888091053, 0.12245182214038712, 0.11825478449463844, 0.1349508443049022, 0.06511586412255253, 0.2088664323091507, 0.10861202834972314, 0.1346155530107873, 0.14118488478873456, 0.08786926711244242, 0.11873476659612996, 0.10329717211425304, 0.07615518104285002, 0.129940785999809, 0.12923660235745565, 0.2086076254823378, 0.11431857571005821, 0.1629961079784802, 0.124185302693929, 0.1282414493284055, 0.0767848818962063, 0.11676504729049546, 0.10649180997695241, 0.09743963035621814, 0.1564471729631935, 0.2190758873309408, 0.11497541117881026, 0.1253526814814125, 0.11837561801075935, 0.10457414787794862, 0.0807141356968454, 0.2069904865430934, 0.08786251568900687, 0.11555072745042187, 0.07563637995294162, 0.12372068262525968, 0.06242119800299406, 0.1843099242874554, 0.08050623256713152, 0.14430871073688778, 0.06714570841618947, 0.12317944238228457, 0.11289797443896532, 0.1408423874527216, 0.15319760090538434, 0.08938851380454642, 0.11756939627230167, 0.13153660536876746, 0.16245117650500365, 0.09181205768670354, 0.15171106638652937, 0.14061553962528706, 0.20556470804980823, 0.1276675851217338, 0.0958065390586853, 0.1119892057031393, 0.0881820378292884, 0.15872274871383393, 0.246421608541693, 0.19325495644339494, 0.10630437824875116, 0.17425487669450895, 0.07677084300667048, 0.11603023457740035, 0.10098391731402703, 0.11227078416517802, 0.09448539066527571], [0.03987705521285534, 0.043559132276901176, 0.06673632788338832, 0.05928097864879029, 0.03570300633353846, 0.022388953349686096, 0.007161971048585006, 0.05873512436768838, 0.05471207667142153, 0.037033589756382365, 0.041848260510180674, 0.032106400933116674, 0.027119531562285762, 0.04428617237135768, 0.06715440723512854, 0.03972568083554506, 0.024208670615085533, 0.037416317433651, 0.03551274172163435, 0.04519538215494581, 0.068193380055683, 0.01582385732659272, 0.017613127029367855, 0.015832613821008375, 0.026687186011778455, 0.03863604859049831, 0.019268357228221636, 0.03635307341547949, 0.037828639415757995, 0.11744907844279494, 0.02743519114197365, 0.040336355566978455, 0.06709797347762755, 0.045227755060685534, 0.10208749345370702, 0.06817006559244224, 0.020422979557354535, 0.05108861146228654, 0.01420952582598797, 0.01838631768311773, 0.044438534017120085, 0.03445243915276868, 0.02954375058678644, 0.03201496494667871, 0.03401717250900609, 0.03180304488965443, 0.04498515843546816, 0.013930911713811969, 0.050061007495969534, 0.07378945512963192, 0.028722390732062713, 0.012871519230040056, 0.05460905469954014, 0.0568617366786514, 0.016571384089599763, 0.04286734886201365, 0.03832548650513802, 0.05425771265955908, 0.018764080180387412, 0.06790428342563765, 0.030049608621214117, 0.05115988478064537, 0.00971347391272762, 0.06670292360442025, 0.13656057364174298, 0.012481002818926104, 0.09384752703564507, 0.038327308371663094, 0.04945479752495885, 0.027164674497076442, 0.03992449838135924, 0.01878052108388926, 0.05562454342309918, 0.011396111837322158, 0.04382532835006714, 0.019790376270455972, 0.052556431985327175, 0.0391864829829761, 0.03165817766317299, 0.0012022091562227744, 0.004972123956706907, 0.03442589147016406, 0.011037833473112966, 0.024699170009366105, 0.03291796613484621, 0.0440121527894267, 0.032733329970921786, 0.05843340698629618, 0.028067841926323514, 0.04639336626444544, 0.016820223236988698, 0.04591722467115947, 0.0145882179162332, 0.05241741033803139, 0.007775482904565121, 0.03392940739701901, 0.010063502987447594, 0.06901564236198153, 0.04578752609501992, 0.019082667638680766, 0.03794234152883291, 0.02785238161283944, 0.04500540252774954, 0.04824929864012769, 0.04007199153836284, 0.03324090130627155, 0.03621186688542366, 0.03757783590949007, 0.04550085522766624, 0.021174837070118104, 0.04625998663582972, 0.013964273584341364, 0.06288983499897377, 0.05716142524033785, 0.0057694471324793994, 0.027365536129634296, 0.02506870187685958, 0.01911854008877916, 0.0513609347066709, 0.03678227395617536, 0.08276835296835218, 0.022792656240718703, 0.03707249356167657, 0.018260936286034327, 0.05544017528050712, 0.07356700420911823, 0.04676603805273771, 0.09506312252155372, 0.04039239916684372, 0.017614065104031136, 0.04571569977062089, 0.013993380192135061, 0.00508442786355902, 0.0558956758385258, 0.024064040875860622, 0.068247703569276, 0.053709422437740226, 0.07236664861972843, 0.05570383024002824, 0.004026681251291717, 0.012152966760498072, 0.0407085354173822, 0.05924530806285994, 0.007707367318549326, 0.07615999185613223, 0.045042308047413826, 0.017244370388133184, 0.010832649572486324, 0.015626810757177215, 0.024249041752357568, 0.018106859643012285, 0.005042472347018442, 0.016803024070603505, 0.06006531084754637, 0.024052415874653628, 0.04212693144966449, 0.06406776500599724, 0.025852345362571732, 0.03666340819160853, 0.036825764658195634, 0.03325724042952061, 0.06290183149810348, 0.015270869946107268, 0.015641015887792622, 0.015354519743206245, 0.0745677687227726, 0.016959809764687504, 0.043833684508821795, 0.013870758736240012, 0.03694236072312508, 0.02995862386056355, 0.08864189458212682, 0.03001943077625973, 0.09086252935230732, 0.0658961318965469, 0.054195066913962364, 0.0579918571082609, 0.06739481897758585, 0.014707830069320542, 0.06638519279658794, 0.048928210245711465, 0.0859246603878481, 0.10273233920867954, 0.044483205370072804, 0.003675490185352308, 0.01876779685595206, 0.030652863572218587, 0.0036862059496343136, 0.03276688352759395, 0.06918570359370538, 0.01566404875900064, 0.027600370314238325, 0.01482442783058754, 0.09990421882165329, 0.022861525848773972, 0.05308059350188289, 0.029414611802037274, 0.06005006416567734, 0.059516871348023415, 0.05995945938463722, 0.01403116695915482, 0.054257458208927085, 0.03158831909032805, 0.03730410809761711, 0.029815151023545435, 0.08768009154924325, 0.0404300137556025, 0.09187833020197493, 0.04539963137358427, 0.06799466429012162, 0.04882482525759509, 0.044628479717565436, 0.014506367933271187, 0.04108685261702963, 0.026177473898444856, 0.05895086457686765, 0.047005102903183014, 0.05687531416437455, 0.014675699739849992, 0.07601265476218291, 0.03312098720510091, 0.03786868994523372, 0.019226829188742807, 0.012134262942709029, 0.0467953100534422, 0.08247152782444443, 0.052561894192227294, 0.03684690102402653, 0.02348151516967586, 0.012441524803372366, 0.02080307451875082, 0.057795115879603794, 0.03651809313201478, 0.04124953478042569, 0.024877960594104867, 0.032912717666476965, 0.026004588264705877, 0.0022770273914959815, 0.020799591937767606, 0.07193864230066538, 0.044589229859411716, 0.015697619279048274, 0.022875676696587886, 0.0156621624316488, 0.07143067062965461, 0.04131535267723458, 0.0634466747620276, 0.014270405684198652, 0.028747211543044875, 0.023957188573798964, 0.04854962841740676, 0.02246339033756937, 0.06566513143479824, 0.037930260212825875, 0.05435245989688805, 0.02790709019505552, 0.0201348074312721, 0.03133314581854003, 0.02549600082316569, 0.05809133034199476, 0.07306988909840584, 0.038115876859852245, 0.09275636130145617, 0.059686545814786635, 0.05101074956889663, 0.03948492982557841, 0.02862905145489744, 0.05986436948712383, 0.025326182167711, 0.03640803475199001, 0.04616478478003826, 0.055561826431325505, 0.020631539169698954, 0.03394785676417606, 0.040986890838082345, 0.045268443413078785, 0.030262129181729894, 0.05274690694308706, 0.01396897922469569, 0.07359815575182438, 0.07950972246804408, 0.04039026517421007, 0.04009533653567944, 0.06348058115690947, 0.037593767911727936, 0.020366291349221553, 0.028042312046246867, 0.04703491094655224, 0.03659648089004414, 0.020897743724552647, 0.01643747859634459, 0.02605017733627132, 0.02355533977970481, 0.06873275432735682, 0.005709616459041301, 0.037704833916255405, 0.03635723962049399, 0.02413442700968257, 0.02622431147444461, 0.014759286772459745, 0.008470456282209073, 0.07535799060549055, 0.015622824363942658, 0.059403447434306145, 0.003665519961422043, 0.1092784922303898, 0.04974646241004978, 0.047577053641102145, 0.0506418741840337, 0.014849158735679728, 0.07833481872720377, 0.034162945579737425, 0.023135016173390404, 0.06555743435663836, 0.015025041797863585, 0.003938991626325462, 0.047117407234119515, 0.011698203261143394, 0.058904832761202536, 0.05722326013658728, 0.02181166423750775, 0.03751871854599033, 0.035522203892469406, 0.03357361077464052, 0.04271695836048041, 0.05196887494197913, 0.012719576579651662, 0.0767530043210302, 0.03351539586271558, 0.07121476078672068, 0.052681190826530964, 0.028085186977737715, 0.01740954107871013, 0.01776767016521522, 0.031192960483687263, 0.023590945904808383, 0.05903027353010007, 0.03610920453710215, 0.023133370725970184, 0.019425796012261083, 0.01899297209456563, 0.081793902042721, 0.035775107464620044, 0.02201780317617314, 0.029154844848173003, 0.00772097533834832, 0.051798813710255284, 0.022195691309337105, 0.03993328880252583, 0.031196573682661568, 0.039766355617237945, 0.027638470055535436, 0.1364589969494513, 0.22025542546595844, 0.1319729440978595, 0.13544051588646003, 0.21790111251175404, 0.14157964289188385, 0.13533873563366278, 0.1289523776088442, 0.16074675082096032, 0.15323543601802417, 0.1483621432312897, 0.14175243861973286, 0.158097790820258, 0.14028531020241125, 0.2466076628438064, 0.15437009584690842, 0.1545162930020264, 0.13292834854551724, 0.10315018107316323, 0.15362146816083364, 0.19388650969735213, 0.09779504021363598, 0.16475340511117662, 0.13160494741584572, 0.20602394055042947, 0.1182687623160226, 0.0976568701277886, 0.15006808883377484, 0.13882689417472907, 0.1998383474669286, 0.11722103639372758, 0.23195008507796697, 0.1558135976748807, 0.12213586909430367, 0.22081585467926093, 0.10785986549620118, 0.09472560563257762, 0.18323923674012932, 0.07084051479718514, 0.13240747792380198, 0.10048226280403988, 0.2717335160289492, 0.12324327895683901, 0.14938240205602987, 0.08436020969280175, 0.14987459778785706, 0.11439583370728151, 0.07511284947395325, 0.09229837730526924, 0.14704881156129496, 0.14809630678168365, 0.07373354384409529, 0.13171885987477644, 0.13616455346345901, 0.09183484967797995, 0.08963410955454622, 0.13939531653055123, 0.10949774725096566, 0.07449751999229193, 0.09986557625234127, 0.10006422416440078, 0.09260578081011772, 0.11661339471382753, 0.17991195885198458, 0.17169666396720068, 0.09700832635696445, 0.2139779587409326, 0.07300723996013403, 0.1468320603349379, 0.1224903900708471, 0.12096526048013143, 0.12245573050209455, 0.1362339947372675, 0.11170953392450299, 0.10958901699632406, 0.11753888933786324, 0.12673229245202883, 0.15339217760733195, 0.12020793397511755, 0.123420403738107, 0.14525962328272207, 0.17066378439111368, 0.11993584143263952, 0.22449439657585962, 0.18338901656014578, 0.11008662743760006, 0.1699127411203725, 0.17736148142388888, 0.10272898046033722, 0.2194503436663321, 0.25681196099945475, 0.1540057361125946, 0.09067466336169414, 0.047687502178762636, 0.13109643970217022, 0.14321369092379296, 0.08415927511772939, 0.08958503790199757, 0.11804963621710028, 0.17262309496956213, 0.11994867931519236, 0.134732559589403, 0.1415202167949506, 0.14851706634674752, 0.1251685813601528, 0.13883823928024086, 0.13700604545218603, 0.24175697884389333, 0.07813827427370207, 0.16743912813918932, 0.0821755440639598, 0.08956677173929554, 0.17738965419786318, 0.1319151057728699, 0.07808013739330427, 0.10901655735714094, 0.09242214209267072, 0.17860732600092888, 0.06033550349197217, 0.10535558273217507, 0.2413589773433549, 0.13097557904464857, 0.12720202867473873, 0.1276203862258366, 0.14424154934074196, 0.11713273184640066, 0.07961986905762128, 0.1438919680991343, 0.0922639077263219, 0.1589293083442109, 0.1120727469346353, 0.0981032308191061, 0.1480777013514723, 0.12756148938621792, 0.17865421277071747, 0.14198478258081845, 0.13121371769479342, 0.11051713755088192, 0.16420195970152104, 0.05896709513451372, 0.15705526247620583, 0.10042438376694918, 0.0773510786571673, 0.09632442412631852, 0.1264137609728745, 0.14046882678355488, 0.08556070777454547, 0.2058061579508441, 0.10347812383302621, 0.17558690878961766, 0.0975276024213859, 0.15810920377927168, 0.08425291295030288, 0.1689711787870952, 0.1813578898353236, 0.185617827677301, 0.14083192444273404, 0.16076090506144933, 0.13225502467581204, 0.09269612096250057, 0.1112989659554192, 0.1906385932649885, 0.10008117396916662, 0.08750451382781778, 0.11423204892448016, 0.17904241622558661, 0.15004499150174005, 0.13916040770709515, 0.16824140080383845, 0.11050273903778621, 0.08287540543824434, 0.1376397293061018, 0.1375821488244193, 0.14351874669747694, 0.1764659916183778, 0.10004300637436764], [0.026000946227993284, 0.11318579542317561, 0.02900977406118597, 0.03792213136330247, 0.061662107306931696, 0.09091207597936903, 0.02392930587354515, 0.030874571496886865, 0.03420697232442243, 0.04887918269793902, 0.01562203387064593, 0.05871476153177874, 0.0201319185684302, 0.016334441357425282, 0.02750792839963521, 0.03094209251659257, 0.041061539868158956, 0.016940843014578735, 0.028983504577939, 0.016952116873913577, 0.02924316975155047, 0.05054970537977559, 0.022124899750841514, 0.04665488383865782, 0.014731673789875848, 0.055214535245405774, 0.012897128837981393, 0.02218579317975257, 0.022517505201644132, 0.02851186167182667, 0.037792704201170375, 0.05442940237532769, 0.03637946842770491, 0.026603844948112965, 0.02547886611760727, 0.03221209294029644, 0.010605022277949112, 0.04956580924668482, 0.052212323128644905, 0.0071276897631053415, 0.08698993322572537, 0.011138528069880391, 0.017059310139822106, 0.029975950252264738, 0.06935387849807739, 0.005760551538384918, 0.03027257862101708, 0.017629501775705388, 0.03318325636376228, 0.0157799137024475, 0.027446178320263113, 0.04131720847051058, 0.05089764795931322, 0.03551650759098785, 0.011730366669196104, 0.029742598666676452, 0.0496721017573561, 0.010243642160535922, 0.040600784056420834, 0.04592129588127136, 0.02275518075163875, 0.04022728445540581, 0.011315573123283684, 0.026128912843497734, 0.004485278473501759, 0.12926054107291357, 0.05681157258472272, 0.021712070563808084, 0.0432267247566155, 0.09057160067771163, 0.011116937933755773, 0.023237980469795208, 0.020202140157510127, 0.047113682076867135, 0.05482159222343138, 0.021949902176856995, 0.06970634351351432, 0.021421146978225027, 0.05202894225450499, 0.015240307032529796, 0.07982390453772885, 0.042160980336900265, 0.021480506917993938, 0.03654925146007112, 0.04203372787950294, 0.019132339794720923, 0.02939147375790136, 0.010271678379337703, 0.0061749209999106824, 0.010106922443290907, 0.018848764743389826, 0.04573513301355498, 0.0422287897339889, 0.04010679359946932, 0.0264047475066036, 0.050538709719798396, 0.012151839544198342, 0.04317854537761637, 0.007236520842915135, 0.05136792701003807, 0.08060149209839956, 0.054772853053041866, 0.030143158244235174, 0.03176239385668721, 0.014921441374878799, 0.02885148880471076, 0.07794695453984396, 0.05383855104446411, 0.017668152826705148, 0.03564837747918708, 0.0387264701670834, 0.04899345138775451, 0.02496569517201611, 0.03457117260300687, 0.0244484072151993, 0.03381860941382391, 0.021811355504074266, 0.04936554302860584, 0.023775180036734258, 0.03704905356945736, 0.03623214829713106, 0.07385076076856681, 0.011156589823908039, 0.018197752801435332, 0.01564992674892502, 0.026721596218911663, 0.03220833385629313, 0.045878646562674215, 0.04428151762112975, 0.04917642853355833, 0.02414199776415314, 0.026036626991948912, 0.026261549476268034, 0.017056363601503626, 0.018641302661438073, 0.10655849639858518, 0.0104621117768277, 0.08931836006896836, 0.0032603694583355847, 0.026756696835426346, 0.0324885314995689, 0.027312635843242918, 0.011627454959255244, 0.12671044362442835, 0.061763181883309565, 0.03466974677784102, 0.028059032845443914, 0.01422125260744776, 0.00461500122245135, 0.020661218291414634, 0.01813534793577024, 0.08195225854537316, 0.012352852150797844, 0.032021522987633944, 0.04203569223838193, 0.026207787450402975, 0.052758157053696256, 0.01109098905830511, 0.0491352312799011, 0.004207591409794986, 0.04088904608839324, 0.00807118252851069, 0.047724132891744375, 0.02704053481907717, 0.009337238119249898, 0.048849710529404025, 0.03473058422761304, 0.06685344981295721, 0.024981591551165496, 0.10512149493609156, 0.047752451550747664, 0.03569289276908551, 0.08150290551462344, 0.0058470346432711396, 0.029281422163226774, 0.05896858112620456, 0.027971642624054636, 0.07750988299293177, 0.06295696925371885, 0.02211310850855495, 0.0278462527452835, 0.03912840038537979, 0.025243275366457443, 0.02544286474585533, 0.025125605519860983, 0.040592502536518235, 0.02410294977016747, 0.04908861931679504, 0.0728594550330724, 0.0444023307812001, 0.04205689985038979, 0.0320730000468237, 0.03702922338353736, 0.030786009106252874, 0.01870016218163073, 0.026597934908100536, 0.02349292643235198, 0.04723676493657487, 0.04407883581838437, 0.05132824628214751, 0.008652650568235134, 0.014912140356110675, 0.0391070095689169, 0.09326428547501564, 0.058493525188948424, 0.021869780761854987, 0.06469368641929966, 0.03374773982380118, 0.03441698909071939, 0.055616136374218125, 0.06197263885821615, 0.01001072144468448, 0.03823548901293959, 0.027784665514315878, 0.009681090828962624, 0.04223243685971413, 0.006548368438546146, 0.026823077916300724, 0.04631308200103896, 0.01030919627685632, 0.0697268352710775, 0.018229099422959343, 0.04657605164019125, 0.039876393641212156, 0.042657315132341216, 0.014425859753308552, 0.028319510564740216, 0.017270370153710246, 0.010493968995953245, 0.07152643227683646, 0.019111537607386708, 0.021679412673360536, 0.03184577902512891, 0.028867848284010376, 0.045663245621004274, 0.001736916379221449, 0.019208013412675688, 0.02846840150388224, 0.033822487241455486, 0.03920571266540459, 0.04065585395853434, 0.04366713808849454, 0.015784626128152013, 0.04156595262299691, 0.01990558473127229, 0.0694634144061378, 0.030844559893012047, 0.06247262417205742, 0.017720435646229556, 0.017563364967437725, 0.028548553452960083, 0.030469594656356742, 0.01205820171162486, 0.03633125512195485, 0.018134657526388764, 0.036032469011843204, 0.018305994403947676, 0.04536121611350349, 0.03639909505311932, 0.04256004713741796, 0.06968870838837964, 0.0512093703395554, 0.03167071020496743, 0.01701500519577946, 0.015657521252121245, 0.024170440255797336, 0.03285204306510942, 0.01677377412228712, 0.01274931846585657, 0.03813319307352815, 0.04937028259571109, 0.0267135708459786, 0.03415996002565537, 0.023896064442981566, 0.04543999742184367, 0.021324199591098086, 0.06087132902549846, 0.026212304797289625, 0.019510670565068722, 0.03312219160475901, 0.034965031647256443, 0.03671290732121893, 0.020425678430391208, 0.04278429278305598, 0.04348744844485607, 0.021509315818548203, 0.04687497006463153, 0.016417670462812697, 0.03329746737810118, 0.022882082067163925, 0.018746204175321118, 0.058552700227924755, 0.08512414512889725, 0.05613702395930886, 0.029296292258160453, 0.09407767254327025, 0.02224362302305443, 0.052656536256628375, 0.0400983186970864, 0.034662849469376464, 0.027951703872531652, 0.07737113615231854, 0.014453374348314745, 0.006198857170862279, 0.05878688980426107, 0.09038733770804745, 0.03206566847594721, 0.03815546598551529, 0.049540717021695206, 0.029205348209611008, 0.05425866600126028, 0.09980678119297538, 0.02084908088935273, 0.018245058566597954, 0.021577764734891907, 0.03555799322202802, 0.020768832249034728, 0.03574859710144145, 0.017735684024436132, 0.06898358836770058, 0.034846165882689614, 0.0679251483774611, 0.07194635045847722, 0.02742847364528903, 0.07333402921046529, 0.024164630299700156, 0.03129232854449323, 0.04585530495803271, 0.026322132475408058, 0.08042012647326503, 0.03050790135083454, 0.02731407094480736, 0.022476270628560866, 0.01994846305543823, 0.07271097800029175, 0.04643517080694437, 0.021866651019081473, 0.039628124463238885, 0.060528071730264595, 0.07307068976972785, 0.06225440731006009, 0.05911109383617129, 0.015367059070350868, 0.05092898949182459, 0.021093285642564297, 0.046515658630856445, 0.08088352517890078, 0.014920628829193967, 0.04462388603548918, 0.008978092078385609, 0.024515661909910183, 0.05227640397580607, 0.10283128318509885, 0.16323339167450154, 0.15210848434695176, 0.10605118969189269, 0.14840248892349855, 0.1471549208675112, 0.14949662664106914, 0.10409774165600538, 0.11383249357874904, 0.14536581401314053, 0.10661638900637627, 0.15834728814661503, 0.11271149265979018, 0.11828401578324181, 0.1284469911562545, 0.09366575428949935, 0.1281364392489195, 0.11665825944926057, 0.06741021493715899, 0.12061938403972558, 0.0843015503404396, 0.1462466881743499, 0.1379087684409959, 0.15157392088856014, 0.07992071112883942, 0.12392405314104897, 0.07442720340830938, 0.11525952736181871, 0.1776366409446512, 0.11579368369919912, 0.17584768336798462, 0.13799969213349478, 0.14019392510609968, 0.1100786750071815, 0.16441120633057185, 0.2183408981987408, 0.15855938462274416, 0.18181396036275796, 0.1479538008570671, 0.10208989546767303, 0.1989320418132203, 0.11711175154362406, 0.155298060338412, 0.11019358491258961, 0.16693439308021749, 0.06584112984793526, 0.08733612857758999, 0.25845773411648615, 0.1277355064771005, 0.03958964813500643, 0.1278227117976972, 0.09686803924185888, 0.18661702477506228, 0.1370286135269063, 0.17409502741481575, 0.10229657723435334, 0.09794635352279459, 0.07165340653487615, 0.148443038176213, 0.1516902217907565, 0.11202493735722133, 0.09858326041804892, 0.10721045998590333, 0.13047673366963863, 0.09686975593545608, 0.2219338496880872, 0.1748912882591997, 0.11135134207350866, 0.11449940529252801, 0.15319267474114895, 0.17282186501792499, 0.10946462117135525, 0.12774978285389288, 0.14636878376560553, 0.12887304329446383, 0.09173414151051215, 0.18125396541186742, 0.13801928822483334, 0.10872440053416149, 0.09293459888015475, 0.11598519342286245, 0.10808145467724119, 0.08553313889673778, 0.11378751349236284, 0.17928774734692915, 0.15897652081080846, 0.09208336991391011, 0.10007771344057151, 0.13714674647365296, 0.11946732657296316, 0.05459604039788246, 0.09061274025589228, 0.0788867866088237, 0.16362724054072583, 0.16853733706687177, 0.1561969971018178, 0.10198657494038343, 0.1426529631550823, 0.12345302770180361, 0.10262990756226437, 0.2814763832305159, 0.14858220570853778, 0.10434487768049751, 0.16629152186214924, 0.08296486349510294, 0.08142257375376565, 0.18276920196201119, 0.14962668823344366, 0.07982887141406536, 0.15521265992096492, 0.20436588594956057, 0.1498056993420635, 0.08340310212224722, 0.16282533428498677, 0.11543395157371249, 0.1426803081163338, 0.20221233793667384, 0.18253731940473827, 0.07714950625917741, 0.1449048716042723, 0.09649591706693172, 0.12013815343379974, 0.1962296539651496, 0.06937180539327008, 0.11799129577619688, 0.10577560947941882, 0.15519648364612035, 0.0803023192233273, 0.145228220682059, 0.13707585313490459, 0.09527697640338115, 0.123992422329528, 0.07787979992904834, 0.09824326687625476, 0.11637421111975398, 0.24020527782184736, 0.05517137363286955, 0.16186641502593244, 0.12141434209687368, 0.16106935351022653, 0.12687760751162255, 0.12308199118290629, 0.0823262534769518, 0.2196723331830331, 0.16458371707371303, 0.12592867628804275, 0.12990265233176096, 0.05323406455240079, 0.16639092724238122, 0.11793750151991844, 0.09057377198977129, 0.27604810308132854, 0.10489136299916677, 0.11083143497151987, 0.13587605394423008, 0.14385179882603033, 0.11900977683918816, 0.15353308218930448, 0.23572550820452826, 0.116847407871059, 0.14912370379481996, 0.11819605050342423, 0.10008821037731, 0.15636836790612765, 0.15294874140194484, 0.13803370030862944, 0.11255803517997265, 0.13166296215994017, 0.13058601851974214, 0.21364040113985538, 0.1290964034519025, 0.12446926959923335, 0.109357310858156, 0.1147786903062037, 0.12208212912082672, 0.1087596368576799], [0.04051426066351788, 0.03079275713701333, 0.012726482369803956, 0.042080465371587446, 0.048087563033082655, 0.03451993303107364, 0.030525580580745424, 0.013910926313006451, 0.016101756432492818, 0.04031971788832119, 0.06085967857922826, 0.030906259082257748, 0.03198542492464185, 0.026328846579417586, 0.025754880592493073, 0.04812613096354263, 0.004954098673936511, 0.010224790761380323, 0.013955328796458031, 0.014680110217471207, 0.032763901366186995, 0.06522206842367138, 0.009928332026382642, 0.01388719370256045, 0.0502544544371111, 0.036826117496405325, 0.038651980592736175, 0.046081039988036664, 0.03726916693683181, 0.07281330786645412, 0.06399928046656506, 0.056204972456076314, 0.021229204688487307, 0.033848729583301713, 0.04243168866794024, 0.05020140656935317, 0.010047139267304113, 0.053490316694868464, 0.01760434848256409, 0.05056125404579299, 0.03044734549309526, 0.030469818572912897, 0.054418790087636025, 0.04523212143353053, 0.011188187503388949, 0.13569336517580918, 0.03425937219123755, 0.015289953743506755, 0.030548152048140764, 0.06254950218967029, 0.01361501803954265, 0.05617280311084219, 0.06468542186277253, 0.0067695475299842656, 0.0290691017705415, 0.027328189562207887, 0.013044769576351558, 0.0512840227623071, 0.02844772654186402, 0.038101396922554286, 0.04170628723555377, 0.04937044544411557, 0.02042485909935619, 0.03398640433858548, 0.04200209118425846, 0.039342159272304604, 0.0109954326679664, 0.07466566775526319, 0.012550024249191796, 0.02039194675827665, 0.040581839358700175, 0.05347254586273006, 0.07227598955588681, 0.050678769525672705, 0.006095866581225502, 0.026479215028562715, 0.0071424546851111305, 0.030386653928352252, 0.07236951203750712, 0.06037911293762071, 0.032142882368394306, 0.0365540317392775, 0.015699300349556973, 0.032181121209370236, 0.019702007262302295, 0.009339210111647844, 0.006218788288866303, 0.07031830067613296, 0.022534397330933383, 0.009922255745290645, 0.0022229244017840494, 0.06815188763929264, 0.023323445348069072, 0.014837123220786452, 0.07774190125720841, 0.03281258286109992, 0.01872471157860543, 0.03656008087896875, 0.04627686180174351, 0.03687059885955282, 0.036151562085641284, 0.05465896434283682, 0.017964525048487952, 0.01609316448281918, 0.01763447543739208, 0.013003227118003582, 0.024925419029646685, 0.011114437532212054, 0.044770934752055576, 0.03279544645920396, 0.039955748311643086, 0.008587493394900645, 0.04873936377199633, 0.024655857422788228, 0.019463220611214638, 0.015439166986782635, 0.04952675277101142, 0.05970067969922509, 0.01752948062494397, 0.06823166978678533, 0.028885188246411935, 0.03630933504817741, 0.0391947645028787, 0.022931016316371303, 0.024341305551518286, 0.03333699543561254, 0.01027966643284474, 0.016804962984419296, 0.03012566900412951, 0.03312911266194923, 0.10514000537140028, 0.11280697610761438, 0.0036846508321884486, 0.021917569983218397, 0.021197450945952108, 0.031117700772093873, 0.025676874510411705, 0.027246247977018356, 0.01568490862181144, 0.030609294838671173, 0.06924279553017446, 0.0051838014374620146, 0.062426049528377395, 0.10718245006033353, 0.01768919250129589, 0.020740328689238856, 0.08926397548722369, 0.08303796885801212, 0.018712458932506185, 0.04335817056042807, 0.025184839930651442, 0.02913801378703543, 0.013543184929793435, 0.0776829162080373, 0.012216280863088156, 0.060376805918557305, 0.025846263992467096, 0.015436025369646294, 0.027918260577800016, 0.05036153404840401, 0.06279359159192868, 0.024157458184553043, 0.02662281848357192, 0.028562704300773994, 0.019040951305734258, 0.03708934837153979, 0.04704153344833425, 0.032171933845217736, 0.0333987658710352, 0.029316356538661888, 0.06780005366142307, 0.02800163726455399, 0.03221132619572537, 0.028529958200774024, 0.02903144307700651, 0.031066970101424625, 0.06085339534495558, 0.013377533327522022, 0.03480539610609412, 0.020140934602490494, 0.04866821598261595, 0.033425734245351384, 0.04948673616828663, 0.01472723956352898, 0.024029517014111792, 0.07513982802629471, 0.03264963946172169, 0.019313776666032414, 0.031598303733127456, 0.044799931946077516, 0.011647724496599818, 0.015468103112652898, 0.04494125721976161, 0.004980252382145929, 0.029692482070199082, 0.016554515709036162, 0.06603264635694878, 0.02941298671066761, 0.018621150171384215, 0.02016644412651658, 0.09717189400855984, 0.011830770344074284, 0.041013007650950124, 0.01855583269415157, 0.018759566226175854, 0.0677867883018085, 0.033853503077157905, 0.021850018429436853, 0.016401657036372592, 0.02738259789267821, 0.024542576001424874, 0.06650368536689452, 0.027511080194796835, 0.01855903707577714, 0.05795561655291489, 0.013057501437807722, 0.0119514257447528, 0.059852956528110166, 0.05435777961143425, 0.02083267560893936, 0.000677941512549296, 0.05915842165372201, 0.0775164987093636, 0.05074883844437344, 0.021075725156281675, 0.02385157290180879, 0.012122280862448471, 0.034347215334751775, 0.058409251139632294, 0.025874899866591607, 0.014322069340518542, 0.022566240979358554, 0.008296406960913112, 0.028769138402172496, 0.021243382677701966, 0.06310311212603535, 0.012511100936015802, 0.02883471202637468, 0.050765923956143, 0.017790151726720587, 0.017764996737241745, 0.047263438148157935, 0.015525259509948748, 0.0455650853525315, 0.02580540600631918, 0.009448543307371438, 0.020261140473719155, 0.040804062969982624, 0.07700428619448628, 0.04384280401947243, 0.07676821707614831, 0.04943495376833847, 0.04244484546195183, 0.07268211312059845, 0.016516320972836444, 0.07410769483872823, 0.034581337057586224, 0.05745952603008066, 0.054958669867898734, 0.02944081343178238, 0.03332411005560841, 0.031133649737707207, 0.07473902417612927, 0.02388652424061937, 0.024935646248715262, 0.01485916882354234, 0.02618725158806358, 0.01621986223783876, 0.021104372904769013, 0.03922431470294084, 0.07727955428085156, 0.004444980702828616, 0.01739111546027873, 0.01457640971057117, 0.05298964945333345, 0.01647783107390361, 0.026941852078640034, 0.016859320424763218, 0.034433816759181876, 0.02718342581231679, 0.04833006127072232, 0.06102622499955552, 0.01702869463978069, 0.03815982218033501, 0.0503253952733108, 0.06059351643281324, 0.04909323674759694, 0.02896503485473139, 0.05532551643305591, 0.026242177301485623, 0.06666585523635149, 0.028227735310792923, 0.04700291123507278, 0.03606039412053568, 0.058220380917191505, 0.047321714128234556, 0.04817289898970297, 0.0058921546775049394, 0.034891400419707806, 0.05543230088161571, 0.02422956270830972, 0.08490345839943204, 0.05953055061399937, 0.02473048440047673, 0.04750060649322612, 0.032564042269119194, 0.02505551794144724, 0.014845681243709155, 0.03689168094258223, 0.03496506557400737, 0.0073985753614189366, 0.04567532354433622, 0.02058159899232643, 0.04824893901656781, 0.04935217588873846, 0.03772514586203864, 0.01910473868649985, 0.01808797092443066, 0.03088417276740074, 0.08701161920492138, 0.059114249024008, 0.022989658705357994, 0.03555098734796047, 0.032603200525045395, 0.040957557769226174, 0.04586544566388641, 0.016488618084362576, 0.02021244540810585, 0.09852700986500297, 0.018451187327238064, 0.017181480369929756, 0.012474155552419168, 0.03718413632096989, 0.06553149396287543, 0.022756610764190555, 0.03675500024110079, 0.06001693808606692, 0.014185562513635626, 0.03884009424863117, 0.06385961760367666, 0.03971190996734159, 0.04219818101929767, 0.03707785738099899, 0.10336510025496994, 0.0692214895305889, 0.028756385336497, 0.04212771176493593, 0.03208750034017222, 0.05651847938341754, 0.05656654001878841, 0.034615178991641314, 0.018807575971420323, 0.17330716683396272, 0.1467325599598033, 0.12489551172724792, 0.18302625816847595, 0.19134644099644252, 0.13868593530995504, 0.16472348171685422, 0.06657269237829105, 0.08683148851352078, 0.12297350700412478, 0.09156606838639293, 0.08944084242518459, 0.09482131299695798, 0.15864607425672667, 0.14443000565682138, 0.07583738916686603, 0.10772396171731607, 0.08110202024025576, 0.1511699211384569, 0.09845072217285633, 0.17019512025373323, 0.1390763372182846, 0.15243190127824033, 0.10264170050088849, 0.22185942796724184, 0.07627906118120466, 0.07638711788292442, 0.15432243554719857, 0.14538066035934857, 0.1776866896876267, 0.10271968453058175, 0.21880344195025309, 0.1149544580174344, 0.09765023405530623, 0.19474681067679608, 0.14042788398052963, 0.08881734338189874, 0.16939854728324072, 0.16293016794536794, 0.12916283203022821, 0.15811981606696332, 0.13838477432727814, 0.0896634358380522, 0.10626975260674953, 0.18921554248247827, 0.15701102199298994, 0.11442469858697482, 0.09159499433423791, 0.13200144256864274, 0.13374370336532593, 0.0693450371867844, 0.08081592273499284, 0.1484598929860762, 0.11487044181142535, 0.06935739330947399, 0.14192801634115831, 0.13654829215790543, 0.14274380542337894, 0.09941216558218002, 0.18408317145492348, 0.1260214727371931, 0.08864952131573643, 0.13527738249727658, 0.10669868173343794, 0.2198420347911971, 0.16260528537843907, 0.17666856146284513, 0.13301575742661953, 0.10883237581167902, 0.1362219439553363, 0.1347174011170864, 0.13255453003304346, 0.1644159967878035, 0.2435536581490721, 0.19823305574910982, 0.12792945892683097, 0.09092114799256835, 0.11089138354041747, 0.3056723177433014, 0.16289191214101656, 0.1182144388024296, 0.20248003357223102, 0.110452337456601, 0.12487325577863626, 0.079547815423991, 0.13272225031895296, 0.2253588366189173, 0.1377463135868311, 0.14919872262648173, 0.05332825199833938, 0.08838690790746893, 0.11879158711859159, 0.10638094414025545, 0.10470539690660578, 0.22048110621316092, 0.1668643139834915, 0.0631783413035529, 0.14184638857841492, 0.18226916236536844, 0.17073735115783556, 0.25830720790794914, 0.12332444531576973, 0.06428299631391253, 0.07305056442107473, 0.09625652312700238, 0.09112192650458642, 0.13988212469433034, 0.1042343850380608, 0.08317861559667758, 0.08240237832069397, 0.1312294461365257, 0.0947482076340488, 0.15390232737575257, 0.08268211795283215, 0.10658461999680315, 0.09362329156803233, 0.11409670832966055, 0.1900104462568249, 0.14079486286001547, 0.11182810113366161, 0.11182745652539389, 0.11494309934122221, 0.22673147224954196, 0.11985052243939467, 0.11769768010292735, 0.12097181512841157, 0.11622760684362479, 0.1255686998899494, 0.1405363410179104, 0.10365733850215163, 0.15832066243248327, 0.2685538466487612, 0.17129556834697723, 0.08429143338331155, 0.18104800289230688, 0.11603756275560174, 0.14670175446995667, 0.09888467245868274, 0.08275557615395103, 0.0684917319033827, 0.13443629762956075, 0.13670481661600725, 0.1618065003837858, 0.1945724000356027, 0.22938318710241998, 0.1504269524344376, 0.14768705517053604, 0.22758076739098343, 0.10472200065851212, 0.06047161761671305, 0.1456457639911345, 0.0752356710976788, 0.14512435054140432, 0.157337112352252, 0.10463390645704099, 0.21290379709431104, 0.09420464001595974, 0.124010797057833, 0.12099160120955535, 0.07691437351916518, 0.14487460894244059, 0.09155541538660016, 0.12686381968004362, 0.10867583099752665, 0.16252021065780095, 0.14917969650455884, 0.1831032583223922, 0.16549279115029744, 0.14398199612540857, 0.10109108513487236, 0.1322893314063549, 0.1381538145776306, 0.10611858178994485, 0.13082337006926537, 0.11122698017529078, 0.09071049679602895], [0.01857606151939503, 0.027597861431006874, 0.03694735474086233, 0.01601551123894751, 0.005912124387188149, 0.019428927451372147, 0.008380477449723651, 0.03806254740006157, 0.04897330229037574, 0.013436123130044766, 0.04869551683909126, 0.08999141252466611, 0.05114362708159855, 0.04124443558976054, 0.03342071987156357, 0.046255677938461304, 0.03830005840531417, 0.055346964924995384, 0.09739019229475941, 0.05087939875998667, 0.07697131617793015, 0.04767521730225001, 0.017713758861646056, 0.007612597180663475, 0.05456064801130976, 0.05155117217717426, 0.04694743421194809, 0.04568307241424918, 0.08548068135444607, 0.01898901623540691, 0.02904442684458835, 0.08416853033538375, 0.06079256468053375, 0.02459808186228786, 0.04433855866747243, 0.02262944482000811, 0.017507530017090694, 0.061086119285651615, 0.026928803850231425, 0.018207099621317217, 0.009651794231363704, 0.02153091867720442, 0.04490635337840233, 0.01707471288474543, 0.01609464199282229, 0.029813203628041914, 0.014911899476179054, 0.060023662368101735, 0.07570996029036385, 0.02790521743840405, 0.02603598577635629, 0.015939871547743678, 0.06885472099695887, 0.04229759657755494, 0.09546278643288783, 0.035009760675685744, 0.05804491176136902, 0.01062976845007922, 0.019014681822487285, 0.03561963812847223, 0.05764609601880823, 0.06317835487425327, 0.04736078417460833, 0.030626397313816205, 0.03281722404062748, 0.024907941663903848, 0.007593163937729384, 0.0649644626038415, 0.016221046281446303, 0.04264430422335863, 0.04287709601755653, 0.022169752611911724, 0.025697671608733277, 0.02597063097969762, 0.07308686604457242, 0.011779737725321735, 0.03851040765377028, 0.016705450734921863, 0.04637332912534475, 0.019859664873885255, 0.022659015376120806, 0.012656433807153786, 0.025719383032992482, 0.03654142116595592, 0.04398442445588963, 0.020348464537944113, 0.03481594393295901, 0.055587641296109984, 0.036054280520017655, 0.018179466282682757, 0.05902747796582324, 0.05637967826000281, 0.025994702009484172, 0.04805717823494758, 0.03784417108233486, 0.03782721449221883, 0.03154963241623981, 0.05607254956183689, 0.027663981275899068, 0.045192003050552945, 0.02785503468476236, 0.035547944118401835, 0.05957957476909671, 0.03347494499757886, 0.03408846618341548, 0.015896832071510807, 0.01406594951237951, 0.026860473677515984, 0.025346712941037755, 0.02297084462562842, 0.040332501488072534, 0.03449050835998995, 0.02500087721273303, 0.017010182508134415, 0.03592440891744835, 0.03869335426549826, 0.020755951958043233, 0.021706689781110202, 0.02884667120607836, 0.01578423088150365, 0.016565555473789573, 0.013758641850602413, 0.0644710658650313, 0.041093006929648776, 0.019821648253127933, 0.05238769389688969, 0.006869830340812249, 0.08881620344306741, 0.020779140892305543, 0.04744829483596342, 0.08074218633451632, 0.05432443300794278, 0.027582409492294704, 0.04351386381313205, 0.04370322258078626, 0.007963470183312893, 0.03683832094871572, 0.09763158791299377, 0.03940779735733356, 0.05223182422508087, 0.056076525777046166, 0.046028348351163526, 0.048479844483413866, 0.041427270243210454, 0.034855522880596776, 0.04900908822725926, 0.03775670452575598, 0.010366708056868186, 0.043483553653849025, 0.0024738324448532823, 0.03877017121495945, 0.04172744056476014, 0.0032817394946635303, 0.015045484361637915, 0.027712581346609762, 0.03586542386827724, 0.13039844429918698, 0.0593295210440244, 0.04219456782032337, 0.032603516043829064, 0.030048872410718883, 0.06273447762110404, 0.07347062509506941, 0.06370871820087944, 0.04809651290997863, 0.017315723434356705, 0.025876826906044568, 0.03994780266657472, 0.06122755991028888, 0.0139721632502707, 0.06152965048594134, 0.020049673338819827, 0.013212259160354733, 0.03532864160037466, 0.020521838716896515, 0.05523819915418114, 0.07250585686415434, 0.041172697474913936, 0.01529250673151442, 0.050700190876211436, 0.05245716231209891, 0.022622837585264018, 0.025334243163732544, 0.041435914779348035, 0.03032662732792752, 0.013670633314177394, 0.0174297376735402, 0.03847923914768866, 0.031207620232765163, 0.029152656572737863, 0.07136287819594145, 0.021014059893786907, 0.026334298608292426, 0.02054717012548021, 0.06023951114288398, 0.06016009540430137, 0.015261614728452904, 0.013632492860779166, 0.03867728994893176, 0.004543841558708144, 0.021477255038917065, 0.061120561723198207, 0.04924443470580237, 0.04512487218848296, 0.06381583173892327, 0.033537512711648426, 0.030022429901042154, 0.02311174411858831, 0.03682956784697516, 0.03430270683020353, 0.07508314321083681, 0.02025412781430142, 0.06843563741339104, 0.028721362751509463, 0.033173125835933855, 0.06830683111080102, 0.028549784994018928, 0.031360490779791556, 0.019929657457396388, 0.018802931399217675, 0.038774439200226746, 0.027587886966232742, 0.037047957735402245, 0.02131029131955334, 0.07684778209243502, 0.023345954050975185, 0.035672326372670274, 0.023083408496209552, 0.06895240968359367, 0.07683219614305667, 0.029976448975503445, 0.06627030324723039, 0.01969572402802961, 0.024295477296358774, 0.013780876594994749, 0.051712079971496544, 0.07778632494487933, 0.045093004791332145, 0.03465138901291149, 0.07452531278665576, 0.03474539325439504, 0.06918455686952386, 0.05785956992102521, 0.06264100263693503, 0.011050275260848659, 0.011043203229616796, 0.014096239315611976, 0.05566649724330221, 0.030173417513391802, 0.030983367801776955, 0.08268673877630915, 0.013931562259261097, 0.01972883314426456, 0.0339454784989357, 0.015218897556353892, 0.021313432936689684, 0.04089989586334143, 0.018247784581035376, 0.020536388204033886, 0.037356494393731864, 0.029614413223628486, 0.027526462583669593, 0.03561539389193058, 0.011596607909138714, 0.02218358454826687, 0.08178630245051213, 0.031443384010344744, 0.020936135235907774, 0.04729846751849566, 0.026179307639332752, 0.0430233033506998, 0.053062435904783864, 0.03160596100081291, 0.0108114504421662, 0.03944872998233352, 0.02501032072385507, 0.010003173590770789, 0.002614527105054419, 0.02954769626791988, 0.033409530829106054, 0.055675043391862085, 0.023897189114774977, 0.018178066804206798, 0.05112061456644109, 0.028925978379057984, 0.07650435516344649, 0.0601163027541978, 0.023420686201591576, 0.07863286523414509, 0.0641843101808003, 0.06207995595676558, 0.03101953032559582, 0.0559610425095473, 0.013810011192357965, 0.02874108437182648, 0.04635132423468998, 0.027152973160679852, 0.017889955746276037, 0.04978345953194158, 0.02179901804109769, 0.01929464876385672, 0.03558074789387839, 0.020738600121278847, 0.06836513083960329, 0.021968526266781346, 0.019628930737131407, 0.055693523293094974, 0.03701762043471847, 0.028024400418092097, 0.02535792064320828, 0.06333166986171689, 0.044939472672662566, 0.023202523622395735, 0.0037735910820109503, 0.026540496918771948, 0.02103080953072224, 0.007135420821474067, 0.020339110932712044, 0.0439935778932912, 0.08806110931826489, 0.04914557554626039, 0.005101094379954572, 0.11197872233710118, 0.021762648564098135, 0.04472071298265031, 0.005289836952994976, 0.025579699814053516, 0.04944023955613375, 0.03292804237987314, 0.016645834648183415, 0.029637581801840236, 0.013228854430573327, 0.0792202390730381, 0.05377829713480813, 0.057195202713566165, 0.05362235960949745, 0.06566233587052141, 0.04458444618753024, 0.037961106414773634, 0.026978866163907305, 0.0326881395386798, 0.027977215092895285, 0.013667475581834359, 0.06703672890684434, 0.10288400535604783, 0.03783978774611439, 0.007283249853311905, 0.020248261879065206, 0.017777473299897144, 0.020639238845823065, 0.02126190498737352, 0.01746491971425712, 0.15849119185337, 0.11164634195821625, 0.10749625893575804, 0.13216674726988586, 0.10015103593468666, 0.07760719848530633, 0.05744146342788424, 0.1035821500367352, 0.08800816323075976, 0.11069281705256019, 0.14511664238359245, 0.17331107519567013, 0.13810413224356516, 0.10993369921509709, 0.09549583787364618, 0.11725414890263762, 0.21725640924913542, 0.08041800265865666, 0.15390494652092457, 0.08434585189180714, 0.13311350718140602, 0.20752019169075148, 0.09794037562928029, 0.08721834168370281, 0.14194250984915666, 0.12577238253184728, 0.10644855336951357, 0.1269500343395131, 0.10208051132836513, 0.11341385104294334, 0.1400682061378445, 0.13797542772122792, 0.16546165996364184, 0.1290784358446087, 0.2093484364449978, 0.08608599565923214, 0.10914774531764643, 0.11913299879857472, 0.14649067579635552, 0.13247405577983173, 0.07885663251259498, 0.13544282290552342, 0.09326618537306786, 0.10029855623309102, 0.0971942517374243, 0.1647825821169785, 0.12402636265116078, 0.12888874459479535, 0.13815386886043207, 0.08649546440158572, 0.0980229601264, 0.11391730367072991, 0.14412086510232516, 0.1249220831585782, 0.14162275700696877, 0.1294757995222296, 0.1392725288335766, 0.16371915489435196, 0.09102877043187618, 0.11373239609279803, 0.22400722200317041, 0.11967617965170316, 0.12042380310595036, 0.11177828987794262, 0.06312896431024585, 0.2120286633393594, 0.09186982815819127, 0.17407935325588497, 0.14644391116287026, 0.10734321536230189, 0.09996221999504737, 0.11288934347352811, 0.11445356346666813, 0.07193273226065294, 0.23796095539416584, 0.13693920975284918, 0.07683874400598661, 0.13932348681347712, 0.11351095618946211, 0.15459770363356384, 0.08218448715550558, 0.07677409997475998, 0.09624072683176824, 0.12684883762683186, 0.1024474562811, 0.08520431404135057, 0.12794536378766808, 0.10107824725231954, 0.24835700754608425, 0.14844466666025774, 0.13986208076987947, 0.14494770073464938, 0.11534339429012366, 0.14448270068636962, 0.1632129813411406, 0.145201622109328, 0.11483124962874822, 0.079446408365454, 0.1214972183640514, 0.1384748566363539, 0.11377476381936244, 0.05797732967351164, 0.1790468945567097, 0.12286471069923469, 0.2020104466272252, 0.08089661411941051, 0.18827896059623786, 0.16553165763616562, 0.06601132678666286, 0.1760596034250089, 0.16927688595439705, 0.2052260105098997, 0.12932502904108592, 0.14377281734985964, 0.12415304513914244, 0.10619323421269655, 0.1255356009517397, 0.0963453162195427, 0.13413709082773753, 0.1145559408302818, 0.12260200908141476, 0.0956090446561575, 0.1908352869961943, 0.1908916054027421, 0.09875304345041513, 0.13266700399773462, 0.1577790014977966, 0.24245242295520647, 0.10251530978296484, 0.12480065253164087, 0.14015944195645197, 0.10117196650909525, 0.08394327027989285, 0.22044826511825832, 0.1318357985998903, 0.1465568465313741, 0.15085030400327273, 0.24581621959805489, 0.087200374076409, 0.11869953705796174, 0.07138292212039232, 0.09687826476458992, 0.1331740596464702, 0.2123540887343032, 0.18863059101360186, 0.1820985379495791, 0.19444298983684608, 0.11288048859153475, 0.10341209559036152, 0.053092138775225194, 0.10590513502912861, 0.08460157138428517, 0.12532849849334785, 0.10610049204634768, 0.07635964400001935, 0.17320377166782105, 0.22153540035443647, 0.1108508003609521, 0.1407617096390043, 0.20412628166377544, 0.15356428122946195, 0.11523713570620332, 0.16073695277529104, 0.1887482896979366, 0.0875750407576561, 0.13618461095861026, 0.1494942381978035, 0.12706147693097591, 0.14315088572246687, 0.2034734631223338, 0.1168774805430855, 0.08698329715324299, 0.096713658954416, 0.10866330524108239, 0.13733095516051563, 0.14782303358827317], [0.0728353602545602, 0.04432404480342354, 0.031033358869275877, 0.02408171501675887, 0.02865046262741089, 0.05378605957542147, 0.028330650413408875, 0.019426842652527348, 0.04359698435291648, 0.002022979427627953, 0.01943582475983671, 0.01759195334411093, 0.03999730179618512, 0.033278417507452626, 0.03192856029740401, 0.06040826958737203, 0.05246086711330073, 0.049413522239774466, 0.04974461679479905, 0.09264176352215664, 0.04585886726688061, 0.03102137933352164, 0.09560386064861502, 0.014633094526029058, 0.012973164624002363, 0.013887131786239999, 0.01395858237187245, 0.01976783703347402, 0.03488600267363446, 0.0046501467919110185, 0.05673934592466269, 0.023060870955565145, 0.013682186221038657, 0.03334579264212932, 0.06684705801308155, 0.028352397460756556, 0.08444340487143823, 0.0015848047312049726, 0.027769164381814853, 0.06178482036505427, 0.013759054908795016, 0.11739247505153928, 0.05399894993752241, 0.07376799985234227, 0.05454881775325962, 0.04765297153166362, 0.03638270164706877, 0.07878580702734844, 0.021452352803732668, 0.020590492890083363, 0.038730850110628774, 0.05817807425877877, 0.04487591090479067, 0.02209668287209102, 0.024937921037365283, 0.030738759320229292, 0.014565291914290615, 0.016428087671686496, 0.042550713888236454, 0.02968381378533585, 0.04628799316872444, 0.032764125282743146, 0.006628358387388289, 0.02069684986158141, 0.018431391068068997, 0.02141332007678492, 0.05442624718749097, 0.039598638724003515, 0.004315629875886121, 0.014938688038715293, 0.05918375815131834, 0.03586558671668172, 0.03719731007835694, 0.036556097878409285, 0.019965855604303733, 0.05744187054889543, 0.0402170487546495, 0.015509495445127999, 0.019050094565110545, 0.056767956353724, 0.017224209416391592, 0.0549211875934686, 0.040979053758616955, 0.04670980107039213, 0.045907945704779456, 0.059955992070691924, 0.011906447354704142, 0.025235497658806186, 0.03342359007469245, 0.02504339930601418, 0.012663998624442943, 0.020620339949216162, 0.02802944871863084, 0.04736824127446328, 0.04538251193506377, 0.028013747418299317, 0.010989766052391912, 0.02940458644713674, 0.03709398615839226, 0.05492555057363851, 0.019084991621119634, 0.011444159750161427, 0.029747762318168367, 0.04501318193173834, 0.03811252489686012, 0.03388011861326439, 0.03555585244404418, 0.007885310582683554, 0.05316273695124047, 0.023596677829378417, 0.009967117088048585, 0.040802495554089546, 0.06916790562016623, 0.033481991583747525, 0.013279155079674507, 0.04650784530011671, 0.02923626565773572, 0.011900404152194304, 0.05363321616979582, 0.011928760130623621, 0.015466150628136737, 0.044931052053081136, 0.06546372867056302, 0.04931597265281847, 0.04190050092126642, 0.03568042468811784, 0.024475353537127376, 0.04067119224263089, 0.03152520515556846, 0.045300616150988, 0.018871273446295942, 0.030887453484215906, 0.00910930463578552, 0.049399751371570995, 0.04033702053129673, 0.07617753877171449, 0.03800777266068118, 0.028242824233270118, 0.028558297215827873, 0.08378116147858755, 0.060546256468764374, 0.062179619180304666, 0.01730700595570462, 0.07453943310039383, 0.05335656047931739, 0.03399443480053118, 0.040710839043770514, 0.03835981359173145, 0.023042647201301794, 0.01780430766354714, 0.0414616855393563, 0.05238885758444667, 0.04397240760070937, 0.028185756045526693, 0.04010278006483402, 0.025050164300150106, 0.008940518201727952, 0.06125612623457398, 0.004512149308409009, 0.01893871813081205, 0.02950190533218639, 0.06550087846283402, 0.03189808728971651, 0.06186640063034637, 0.005836441015292491, 0.061495947651565075, 0.03151339864624398, 0.004790524236990937, 0.02850740708942924, 0.013701183505223265, 0.03151259118957179, 0.013954368669406643, 0.018580146300207292, 0.04184111553643431, 0.03894749955673303, 0.03326895194394248, 0.06726096437445708, 0.027770580823666284, 0.03003914900390165, 0.009462159808858164, 0.022116908304659382, 0.08488545008003712, 0.01483177297216441, 0.009806484100408852, 0.0055204061209224164, 0.009567667763414127, 0.05808971542865038, 0.015900650527328253, 0.002282732386707461, 0.023298712746639336, 0.016334431179400002, 0.025117396942472885, 0.012382949419718767, 0.034463953892035146, 0.013775165026475276, 0.11101595578449112, 0.008142434642650187, 0.04677417029493621, 0.020500719314441085, 0.04592146212235093, 0.024116235485832607, 0.04684666158365352, 0.0234031528567097, 0.016298577389014617, 0.026776769597615515, 0.025968473238338317, 0.044435453468135426, 0.013011729161787246, 0.0864533002355269, 0.04775493159624083, 0.06719535682350397, 0.01632208693107324, 0.04245798868526306, 0.022988900442474654, 0.01963934624966766, 0.0015884744394237974, 0.05451714373858912, 0.055450814709599526, 0.04341211409441062, 0.04955724274207439, 0.007998845606510128, 0.030132308469286988, 0.035110071900167635, 0.06975734220551592, 0.0804829520306417, 0.04620349181017705, 0.016052603355741928, 0.025694351876154542, 0.055964374116488864, 0.054780259262770414, 0.07741432490625552, 0.014489714987576008, 0.03242861685742225, 0.05218309184004154, 0.008184127226871039, 0.0866491390126092, 0.012849414255470037, 0.005588475905824453, 0.02152840979397297, 0.004839159082621336, 0.03566452321995582, 0.030355261505714486, 0.04426595202780195, 0.017920047078015547, 0.02257951651699841, 0.059070524227406294, 0.033878357814891, 0.006886978192986655, 0.038493976928293705, 0.04203618417627045, 0.016654258660439934, 0.05600114053647433, 0.023463540777031864, 0.01865483943506011, 0.06317410724503653, 0.04373813660017081, 0.012013466746014143, 0.013681337204096573, 0.04398004111966916, 0.00437578370162685, 0.0162409528025559, 0.0440642642788589, 0.04551571175189955, 0.02404046687297523, 0.012618700474766749, 0.06974443646946124, 0.02238308741444988, 0.03301487789888467, 0.03572636829423053, 0.07439354807138443, 0.02700664708390832, 0.006641651312487998, 0.030530720483511686, 0.04804598919249006, 0.06652007198759488, 0.008097580085242433, 0.00592438381863758, 0.03197491102452789, 0.048958517012319396, 0.06556595675647259, 0.05433296897847738, 0.031121235939541032, 0.04930287353428347, 0.031749576330184937, 0.028682187532207797, 0.02609162395154791, 0.03878421349717038, 0.05850608487214361, 0.055212852478559525, 0.027513093747464672, 0.027449966242004718, 0.0264271612146071, 0.08475620951503515, 0.02538108922142003, 0.01884273256707404, 0.02468819640177701, 0.07034585598324027, 0.041857132355549505, 0.03957340061398489, 0.03292202038158264, 0.026589175021009784, 0.06157662546528237, 0.03024257719516754, 0.029913687878953557, 0.054665525776467154, 0.029313869707818543, 0.0764316094240972, 0.02410568087361753, 0.04401979648641177, 0.05331966174500329, 0.03712640316890819, 0.04957866069993802, 0.0387436913858567, 0.03645133885688015, 0.02155727976267891, 0.007371378829702735, 0.037400592384593825, 0.005547173479239323, 0.030393761582672596, 0.009162702797246831, 0.03864873040999685, 0.01180982990523002, 0.04425218455227358, 0.022373065452224443, 0.0058437976071478, 0.023258343305704848, 0.04666806777407016, 0.07008211620684181, 0.01986993959040514, 0.010791426025597113, 0.05311418777065618, 0.015833126114947454, 0.043704600006874116, 0.03374719021043607, 0.03245764119284494, 0.046500863174774816, 0.012571012185487365, 0.06468858383595943, 0.058630914959524355, 0.0345873217364507, 0.017926454144929136, 0.015037111239507794, 0.03296187413590295, 0.02222805912606418, 0.028631551856441156, 0.019373957633173892, 0.06369838411254541, 0.037692996872855086, 0.025116007642022202, 0.03240433208910482, 0.011479477497882076, 0.050609216293586154, 0.2135366124234029, 0.10369011852890253, 0.14961656449096544, 0.08570742061627762, 0.10468266598348107, 0.15736782284719603, 0.09439227530466658, 0.15481853964073317, 0.09295996251915183, 0.07009995489248208, 0.09968871609973055, 0.1506364569067955, 0.1258940031485898, 0.12437135699604239, 0.07728841594819512, 0.11182545484708888, 0.10099752194115094, 0.12989683050130094, 0.10643169177430016, 0.2502494959958962, 0.07071966771036386, 0.20706360547670297, 0.1925363200051444, 0.17196988287780965, 0.17311332294983522, 0.136522806382605, 0.12707848101854324, 0.05499596893787384, 0.12952172277229174, 0.08445037342607975, 0.1102919928463442, 0.062491955634738715, 0.13809077867439815, 0.15300396058176244, 0.13708004648131983, 0.074337535005595, 0.22367636832807744, 0.06567013223788568, 0.09056640309946877, 0.07005847604679209, 0.12505772230880602, 0.18768999220005103, 0.12732778835509503, 0.23098634822028025, 0.10064978631479399, 0.11653989580060754, 0.11145202309957572, 0.12137362999575478, 0.12167088261672429, 0.11638314064059939, 0.06244645307638815, 0.13977658535752976, 0.1593398763132947, 0.11140050872095994, 0.1383418637726988, 0.15990430888320717, 0.17483213357627392, 0.10656419609274183, 0.1869006659835577, 0.09587165806442499, 0.15596822223493031, 0.09337399101683072, 0.10262174478599004, 0.14053963869810104, 0.10110696963965893, 0.1761137640901974, 0.21693827132029192, 0.13114422213818344, 0.12612849128033432, 0.16246572429580347, 0.15442870770181927, 0.17348536370056017, 0.11731361571167197, 0.15626936964690685, 0.07992485697780337, 0.1288867225604398, 0.17003599022115978, 0.08070910096700702, 0.13313979362802847, 0.12924710607954434, 0.15248460987848894, 0.09233410217400108, 0.23338548519781657, 0.10625702328979969, 0.14526445445205483, 0.09950992890766688, 0.13340853420751436, 0.07774939228381429, 0.12201332566993577, 0.2922966554760933, 0.09433719183185271, 0.1410474678767579, 0.11461381986737251, 0.20403858779796533, 0.1348981357046536, 0.09646195638924837, 0.10105757907565151, 0.08763095204319273, 0.15223133989742824, 0.11100273113697767, 0.08517552380050931, 0.08947204825069223, 0.2734496939395155, 0.1527692824602127, 0.13845682117555821, 0.09771618087376867, 0.19722951602722916, 0.1259506879640477, 0.13936988503805228, 0.07518704727824245, 0.1332302830581154, 0.08650828192808799, 0.16955470533243247, 0.13473023899963923, 0.08118854702583381, 0.13018940123064177, 0.11002579677317824, 0.09786361974797078, 0.15250504735325063, 0.0787232257425785, 0.1324089571301426, 0.12285920099488326, 0.1293081742312227, 0.10274681236062731, 0.13324461371770926, 0.10868872316288096, 0.14715735002287797, 0.09086523670703173, 0.15406829704131397, 0.0922367459695254, 0.1290271385971989, 0.07535151738141264, 0.10342730156012944, 0.08765279408544302, 0.07041225063481502, 0.09499606290566069, 0.13913922384381294, 0.11866570530193192, 0.11378881627959864, 0.11310464263494525, 0.11107466941965477, 0.08890555971967322, 0.08685814815440349, 0.1684123102043356, 0.19118451539959225, 0.07318470400891133, 0.12782136829836027, 0.14626232162117958, 0.10321478439228875, 0.10132245200553111, 0.16541075626654284, 0.2281125895678997, 0.0872347622311541, 0.0624713824529733, 0.15627078099974565, 0.1286284178495407, 0.1603090957339321, 0.2451183327606746, 0.1325884296425751, 0.15872648065643652, 0.11658033648771898, 0.19818904596780026, 0.15876355580985546, 0.1013813488451498, 0.2058603593281337, 0.13487889245152473, 0.1100070895627141, 0.09825711577598538, 0.13107814639806747, 0.07437841674046856, 0.14229115471243858, 0.20473994873464108, 0.13409095044646943, 0.12431841769388743, 0.1208738482424191, 0.09706693142652512], [0.013075341819785535, 0.011229952181955534, 0.03562554816848465, 0.03189775820023247, 0.030199720923389708, 0.013560247541006123, 0.011684535869530268, 0.037003992058868916, 0.02699782612866589, 0.049916588102600405, 0.06599917422447886, 0.0472618978736656, 0.008675335690246096, 0.0322671865911356, 0.042863694950938225, 0.12304339611104556, 0.04396118463150092, 0.05122819968632289, 0.005849353112612984, 0.06744890500392232, 0.06608496140688658, 0.026994620050702776, 0.06223224635635104, 0.007093013655061701, 0.04637920863128134, 0.041341360924499373, 0.017004197829269936, 0.020846086853582944, 0.04683308070525527, 0.036958363971539905, 0.01962413010187447, 0.11443593512688364, 0.04079068225941487, 0.02453027755421187, 0.02591895205633981, 0.02777074197573321, 0.00957996112161449, 0.03568679952461805, 0.029879778091396605, 0.03366564047921981, 0.03895185575155275, 0.008532611786254814, 0.028638177750898258, 0.04307387795831476, 0.037045301270804236, 0.011919996002689004, 0.017345293990469406, 0.04087897323604141, 0.01657325854258878, 0.013432431051374545, 0.05855323627058949, 0.04560116645214813, 0.05174693970807961, 0.01917453110218048, 0.025188985779615383, 0.01694742650059717, 0.01557547110132873, 0.04235835599579981, 0.03109020314046315, 0.07954225822218827, 0.05548794414581997, 0.015622362960129976, 0.023974482735086764, 0.07283012196421623, 0.0473904191915478, 0.08762586303055286, 0.04139242068465267, 0.03155592243586268, 0.036970187444239855, 0.05030236918745296, 0.07982617763004132, 0.032426825524973016, 0.013925178092904389, 0.03144708541887147, 0.011586847182895457, 0.04688589447843177, 0.027131010678463748, 0.03661714567403708, 0.023897916843582476, 0.02570332889445126, 0.06873544811138085, 0.06671521865895816, 0.02795641969091126, 0.01618311278122876, 0.04096422776845949, 0.02846687819276537, 0.04844924933942301, 0.022407187281974723, 0.0611022412776947, 0.018023752673928226, 0.004801105990606759, 0.024770244856231978, 0.035692814737558365, 0.0064176232221403295, 0.031228251090007167, 0.002423958424645077, 0.03520599300307887, 0.049730784858443906, 0.06659642753324338, 0.04236957896500826, 0.036173505908144374, 0.027492362806307416, 0.06009384324508054, 0.032269435934722424, 0.02337186730333737, 0.06512911591146674, 0.01664794998110405, 0.04915846431893962, 0.03411740570196083, 0.10121681088847773, 0.01850796035224838, 0.04354676597618631, 0.036392516656113524, 0.09842491070074694, 0.028418644530964748, 0.06110167130827904, 0.01585338547426675, 0.031798061049942455, 0.034765443964196105, 0.0458373339580638, 0.016390291574810232, 0.07782884873449802, 0.027247313276997635, 0.0707243699580431, 0.06385297474584409, 0.04447557185111301, 0.09227436395095927, 0.010442530952527054, 0.05743277817964554, 0.07382775164608445, 0.003399457474837878, 0.017568983237392137, 0.02047492141303207, 0.05983077521835055, 0.01387009970910315, 0.07535772597683327, 0.01319553836115769, 0.049183997591691356, 0.040302065799811056, 0.03571431751229933, 0.059180901518889835, 0.016806469332160692, 0.05398532156167286, 0.03638593825910773, 0.012602194262269353, 0.06139990780502558, 0.03757680453626173, 0.04309724670435701, 0.01685731196110802, 0.047994193221841536, 0.04167459965018289, 0.009036539388554437, 0.05883921163954905, 0.009675626077556183, 0.04118123683812363, 0.04213308576228363, 0.049695813163582764, 0.014604750421962567, 0.06923316711825983, 0.04460182346935783, 0.06416164032582726, 0.011185539520478674, 0.03471127312098231, 0.020160734254334654, 0.025504872668534517, 0.04119450898308839, 0.060380320729953904, 0.050068678334355354, 0.019224790191011767, 0.011438339616038969, 0.02009402578031378, 0.03857562504708767, 0.018249677693737403, 0.03346140143860664, 0.021094464597159197, 0.01647164622720863, 0.02172826719470322, 0.05305094152156796, 0.04610058518924883, 0.015603292733430862, 0.05458551971241832, 0.036617586721799204, 0.008038607758602925, 0.010769747679920068, 0.015600291912310889, 0.04737538964088474, 0.053187143855861256, 0.04286325729585119, 0.06760692223906517, 0.05570513302726405, 0.030854249373078346, 0.060938816118453226, 0.005395595117339066, 0.06324464096022503, 0.03194655504609857, 0.07009597189192261, 0.03811207027839763, 0.023563409257414084, 0.039612816713218174, 0.06951815182609217, 0.03231084692691054, 0.007479130190664104, 0.01691758961948965, 0.035113461182585785, 0.044010062901569266, 0.05946237820067576, 0.05765985670898642, 0.024923471634143164, 0.03331260210169213, 0.05677071459857481, 0.014030348476288574, 0.0196059165256364, 0.013103268624815558, 0.06988596530365092, 0.021376209300277487, 0.01184675662911364, 0.011985017469019761, 0.048536281633589945, 0.0667448638539229, 0.07194074575922318, 0.017745056289381216, 0.051405582310897965, 0.015996079692350965, 0.02779833460226655, 0.046405712209109745, 0.03234091281358685, 0.053805238367723565, 0.05491445313340851, 0.03604431623326881, 0.005901224994366723, 0.06445289469723191, 0.006740559241734445, 0.003238010669260153, 0.01483819869879101, 0.04211830048422728, 0.045400255625801425, 0.054215629917702506, 0.010244268109090626, 0.018232286841209446, 0.055160038705383024, 0.02828732764880572, 0.022329069241615276, 0.0744712267603193, 0.0594827410365854, 0.04520911231104817, 0.04626779657389436, 0.08415693417191505, 0.07798207551240921, 0.02173353941179812, 0.10938686784356833, 0.06984738380249057, 0.021974220871925354, 0.050855273447398625, 0.02602303763186293, 0.03948322670268161, 0.029945321181522946, 0.04924046188326819, 0.05572286653997643, 0.016044309961476495, 0.006510636802496654, 0.05851067855421986, 0.015619211164968354, 0.030326956417411566, 0.007989620922931602, 0.03406412034694638, 0.04035451316407748, 0.024394772414650236, 0.04970312098573361, 0.0266654762838568, 0.019154281920886466, 0.03908162218119417, 0.06840411946177483, 0.022176934905084114, 0.03948645652937038, 0.02991655808208244, 0.008212838588016374, 0.016079373258565153, 0.001588455037563108, 0.0688167976747666, 0.024687451709594046, 0.08049405286354677, 0.04192208172753453, 0.03444341463702066, 0.013946826752674366, 0.08955023584089108, 0.05694937626166003, 0.019666550414902822, 0.028573398012667894, 0.034362407733819315, 0.01004599848030401, 0.031127173120954206, 0.0646239873021841, 0.01670334388368896, 0.028576800865786414, 0.010769298150470214, 0.06949335137116057, 0.026821437557893138, 0.09347524201231343, 0.045135135030640025, 0.0220113469154707, 0.04571797964828355, 0.027619060561326996, 0.036289715208113194, 0.04853584397850292, 0.035807748391692124, 0.04163235066724675, 0.027222034454877888, 0.01608818064310721, 0.023336069492091025, 0.04742268692435963, 0.012419063597917557, 0.024926918592037897, 0.013236795834797834, 0.050535771663167646, 0.0355522290670446, 0.07206501944788865, 0.02304787700995803, 0.0905429936413254, 0.038288564022098265, 0.04580476088449359, 0.03223853884264827, 0.062215737599347315, 0.032925267171646865, 0.04800930080403175, 0.03537342830428055, 0.05040241578327758, 0.023944004638386623, 0.07357121791158404, 0.039811888709664345, 0.025156246464965597, 0.045103986880608966, 0.04644048373614039, 0.020187963864633014, 0.055046153387853076, 0.06809279402451855, 0.01845788786054722, 0.024555408794965063, 0.05613492728610124, 0.042575799327875884, 0.01510222176355975, 0.02722771548932152, 0.08216298438076462, 0.04804532422817179, 0.03809863867770348, 0.011927870401580418, 0.007980168081953056, 0.036281725458268604, 0.007216478614801807, 0.04507288283535412, 0.02729187097533473, 0.05897697460438524, 0.016931950813159347, 0.11588639872414724, 0.1537441337215049, 0.08974030707031488, 0.12009004530097757, 0.10794394955571208, 0.11843736469745636, 0.0740846653601953, 0.12439351794975144, 0.15267316118947097, 0.13159295091671602, 0.2806946566062314, 0.11368312087974378, 0.22117990228746617, 0.11879443696566991, 0.11186730688703911, 0.17368106677063874, 0.08644447249493428, 0.12402470702571528, 0.06621704503361668, 0.11639770200209958, 0.1285439809518201, 0.13756395051521914, 0.16222873915519032, 0.13066463358700275, 0.10622464359870978, 0.11889716716749327, 0.06990879122167826, 0.10128724960876362, 0.1289332972041198, 0.0920010432600975, 0.14838948819254125, 0.17787290683814458, 0.2382954460169588, 0.1464824112398284, 0.14824079402855464, 0.16235707726861748, 0.1474314781704119, 0.19816208098615917, 0.09924747834780387, 0.07803156785666943, 0.1170918026140758, 0.14232273373220647, 0.09517388657799788, 0.1668281073548964, 0.10054513585886785, 0.15042657245482716, 0.09640457268272128, 0.13917989523283072, 0.115702678582498, 0.0823396545435701, 0.21432717357363018, 0.18298930515136036, 0.10686955720718418, 0.10669725680989878, 0.08250402965183769, 0.07025683218879358, 0.1175520122051239, 0.15513635187276772, 0.13090771197208337, 0.11413291495825563, 0.15066304190882615, 0.07731792543615613, 0.09326018712350301, 0.14890119859150477, 0.09279660521341221, 0.19866973374571117, 0.1445483285933733, 0.12322377786040306, 0.18602393088596209, 0.12249443413955824, 0.11051501373627357, 0.09275914329503264, 0.10316343286207744, 0.15213314230952943, 0.15874659243438924, 0.1445105206221342, 0.12522266060113907, 0.09347478739385094, 0.13187988980540208, 0.11802761097039495, 0.09824186230876616, 0.12067324614950589, 0.11711841475750719, 0.10045079234987497, 0.17050796560943127, 0.20343923781599316, 0.17746482230722904, 0.08502193061368805, 0.18079147594315664, 0.11359587484704596, 0.0860369104359831, 0.16937487998179027, 0.12114588650209562, 0.08168026099779777, 0.12401930588696684, 0.17432179381804808, 0.14736574169780525, 0.144906825785126, 0.17728287992732866, 0.12210833414324693, 0.11232291601066079, 0.10534771851130895, 0.12275421805679798, 0.14794016230319226, 0.15471312244023594, 0.11579191950815064, 0.07298579825354473, 0.10963572734700781, 0.17837659695318767, 0.12517502744282993, 0.1293380433427436, 0.12387148024780409, 0.16019941733351775, 0.2345703159059797, 0.11209438541637999, 0.24303048050829343, 0.10531328964446272, 0.08218341507017612, 0.11204927640834025, 0.13279773055442742, 0.06660744015659605, 0.17937174998223782, 0.16532880280699047, 0.12830535375646182, 0.13948185688682965, 0.17051110044121742, 0.16869800058858736, 0.08889701696378843, 0.10982752205537898, 0.21828088856169156, 0.10195273639900343, 0.13286449840026243, 0.058868280079747946, 0.10679666897548096, 0.06498241664043494, 0.12050756146865231, 0.061030988315386434, 0.09450927509793214, 0.12305947739098753, 0.1295152631189142, 0.1785486870046173, 0.15431821505938256, 0.08810722255813223, 0.11272397091878311, 0.10735478438436985, 0.1435737894581897, 0.15316170640289783, 0.16052700046982082, 0.1412579087274415, 0.19127968672130788, 0.1176868099719286, 0.09548641980758735, 0.09432313258626632, 0.1314647892223937, 0.07400479500315019, 0.10780599660107068, 0.0833607886784843, 0.12683496837105068, 0.17381393749799046, 0.11572904645332269, 0.20145859409655842, 0.11813184751995973, 0.10412498483700411, 0.1311630718410015, 0.1866312197276524, 0.19202794799847261, 0.1313683015427419, 0.2607024908065796, 0.07733828827206578, 0.07266229311270372, 0.1641628218016454, 0.12917911687067576, 0.11719089586819921, 0.1433352708284344, 0.11502788907715253, 0.07530558056065015], [0.025686609791591763, 0.006902243110484311, 0.029746106692722867, 0.08856667897530965, 0.0331455433874258, 0.04798425268381834, 0.05890443242554154, 0.046773389979664765, 0.05121579945885709, 0.03061060101858207, 0.055765980655061345, 0.0476993697562388, 0.016850669103275453, 0.031857571963753016, 0.029171265395624296, 0.02869126633075731, 0.004519879094524575, 0.06146648566105536, 0.015129178263513106, 0.006520953927455204, 0.024831126410780207, 0.0468239272678537, 0.014861672617761152, 0.04603692503379924, 0.048817273162837536, 0.01991466522615935, 0.0654407466894814, 0.017854985747752444, 0.03336144983768463, 0.06017752018358026, 0.048259283282927105, 0.030711007237966572, 0.05619801068678498, 0.04929998636777912, 0.01286751841793635, 0.0076965692818963104, 0.022226198243775537, 0.014718455927712577, 0.03905947819086058, 0.03099756614704217, 0.07305761439991848, 0.03246225183829665, 0.030943951702543666, 0.034403788191931586, 0.03860791313595005, 0.04481724815975342, 0.01231082369174276, 0.05210531476352896, 0.006953121362520116, 0.012516591980654215, 0.013954409381507762, 0.06709084885993175, 0.04072858612718327, 0.023156929461817657, 0.09672393875994853, 0.0597951046324202, 0.016402089602446983, 0.033035495185426304, 0.03790059466181057, 0.03384645988366433, 0.037971847624118836, 0.013042127530622696, 0.0203811275174043, 0.02555404949401106, 0.037365590155656846, 0.01794632843562535, 0.060659945011138916, 0.019823030768228427, 0.04211591204096164, 0.029931031234030212, 0.05729533412626811, 0.01823948779409485, 0.04571839355464492, 0.05070551737610783, 0.051969556869672875, 0.05822221974709204, 0.010114127637020178, 0.02036862720602325, 0.03000519171889339, 0.06246737909636327, 0.028176763760192052, 0.05174043255725077, 0.022928234322794845, 0.03161005935232554, 0.012048190775593477, 0.009640256591540362, 0.03273500595241785, 0.008555157808586955, 0.048404170865459104, 0.02229299832002393, 0.055177324384983094, 0.008703185311917747, 0.025919571219544326, 0.027847993187606335, 0.05502210949946727, 0.04919359546953014, 0.04001405821847064, 0.023487747513822148, 0.02589709305071405, 0.04963222086163504, 0.03091846253456814, 0.06414900600378003, 0.03964494873902627, 0.026256046557266797, 0.03693340406087892, 0.06466958485543728, 0.09278093105448143, 0.0189058346274708, 0.04158696685252445, 0.04446623520925641, 0.032076993225408454, 0.0037002622266300023, 0.03464946875880871, 0.015099136125562447, 0.09023373095052582, 0.02333391344706927, 0.024278924434578845, 0.0631376224170838, 0.020268565343160714, 0.0214862727693149, 0.04938862339726516, 0.023249564758901085, 0.037830732696290524, 0.015249117809746946, 0.03935347384374056, 0.0459056115443153, 0.03808932239189744, 0.020839696750044823, 0.04011149245447346, 0.01862319595446544, 0.007236561555016253, 0.031945720448025634, 0.03822275630331465, 0.04580803820863366, 0.0636859465656536, 0.029614864449415888, 0.060433205749307356, 0.1674133302377803, 0.020351436521325792, 0.08469306504619972, 0.04352895103927169, 0.08460514047848326, 0.004463831253815442, 0.041076766193977425, 0.05562697257846594, 0.05515919053660972, 0.035821003573281426, 0.021592500819159404, 0.012426280666009655, 0.011738501455900925, 0.01245006247024451, 0.01936585083603859, 0.009337706308412765, 0.02055491560271808, 0.041167119917060645, 0.0064318923894981185, 0.04305485183639186, 0.026206532160618475, 0.00864193310761558, 0.07416253403893538, 0.01866089875277664, 0.008743423286692371, 0.022682022802265625, 0.008762535073661377, 0.032483225355723074, 0.032168307075543065, 0.0089533840738503, 0.05542044008948973, 0.027160101171050752, 0.018727261173938, 0.010451763269624539, 0.027013627512912666, 0.024254274953688894, 0.048294265155813525, 0.048965434676834514, 0.04809001593717507, 0.029372671552534615, 0.026820090665881122, 0.009914974216371775, 0.0264334631085928, 0.027338932467890636, 0.022985431432191814, 0.035039395692625215, 0.0417201802400606, 0.03138859570026398, 0.02772002657210188, 0.023619320542950715, 0.044888619865689955, 0.03499957925773092, 0.04528704205793994, 0.01834793295711279, 0.022043887758627534, 0.037318245374730656, 0.07367019581475429, 0.010556351809230233, 0.020207970469657863, 0.061006126792303154, 0.07584582335714783, 0.018230470063697015, 0.04152179017130818, 0.056450435891747475, 0.018524384292374765, 0.031120462409619774, 0.03226549703893917, 0.05143112236899989, 0.06921087045754705, 0.019980876673279063, 0.05625806442861046, 0.032581762211131196, 0.021293972552354847, 0.050422568273331435, 0.017831834132916162, 0.01035901007708162, 0.027838495393682803, 0.039616938813456466, 0.024835660721042326, 0.01988058241217264, 0.006050961981860122, 0.0057970181307090175, 0.047689480108342, 0.004496097714374108, 0.043404996262065, 0.03413384660546269, 0.0034346274291497786, 0.054880923325462, 0.012525501145449067, 0.03906450613534876, 0.07137706636318139, 0.04970442038029432, 0.04131208213844469, 0.03465739404782653, 0.05438905668311885, 0.03376510353492839, 0.04205388715490699, 0.029130587221256325, 0.07424995649073805, 0.03807800103511129, 0.0519838536025158, 0.02510437585546502, 0.01822116395591625, 0.01338292344007641, 0.011274643042790038, 0.008722810240994607, 0.035181087375219376, 0.02474750714775707, 0.031432259428714, 0.06000533513724804, 0.03446837794035673, 0.032251329227749786, 0.016674614710999385, 0.02767765036384974, 0.07242094499192067, 0.011575757376184421, 0.10812439915857144, 0.044060963205993176, 0.060065846890211105, 0.03739265013220055, 0.010604595649056137, 0.04759920780946102, 0.02125128761066922, 0.004501494612278683, 0.04326827145580735, 0.06524459578629051, 0.0025515817438385314, 0.018431102690686072, 0.04706745348604662, 0.007488974885615919, 0.05103268660604954, 0.03244069478075419, 0.011870339961855539, 0.06469607486256532, 0.03747157393289464, 0.05825404303946665, 0.004559673477030758, 0.020122354617342353, 0.05473263967516167, 0.07515521041516747, 0.011379547949348177, 0.012762890014398311, 0.003282256453530863, 0.027308028590466295, 0.02376661862113646, 0.012239960887070214, 0.012674103707208164, 0.08913524382348571, 0.05546498252078891, 0.03020503045991063, 0.022258674626105597, 0.03738400559606297, 0.010145748217057968, 0.029149243541594063, 0.06669728497841529, 0.08531480668378727, 0.01285070092749915, 0.0877442741766572, 0.04247653643999781, 0.013369035524582224, 0.0378526358066925, 0.043990246286349635, 0.0390375309756824, 0.06619030396853175, 0.03891030565968581, 0.018878058796482425, 0.04153466198061194, 0.04685519416151302, 0.02472736992474113, 0.03480146060298596, 0.03304521180689335, 0.035898183538977585, 0.0418912728450128, 0.02698365831747651, 0.04752505410994802, 0.02953122483034219, 0.039358474646828005, 0.044004654977470636, 0.055122067885739465, 0.006489593735230821, 0.03237590825717364, 0.042490459978580475, 0.011152852792292833, 0.03317559909607683, 0.00478879566903093, 0.026606375883732523, 0.035282538538532596, 0.004659355784367237, 0.0239097284419196, 0.007464367813164634, 0.050948772180293284, 0.016517316722976308, 0.005224494030699134, 0.039671079122594426, 0.0248579896121685, 0.05487629910930991, 0.02112055426862623, 0.059340682945081165, 0.027185273123905063, 0.04331335671512144, 0.029716722733740295, 0.01882677511977298, 0.033662386903805394, 0.023087226952026998, 0.005815510754473507, 0.023098460099260722, 0.07131815595286232, 0.0198234955647162, 0.030970051552035978, 0.0019151807812574717, 0.016058484558016062, 0.0685978683509997, 0.04033710534817406, 0.004604070023300925, 0.027996609320065806, 0.12209479058427469, 0.09299847616681031, 0.12823459612471716, 0.19842233987791197, 0.10060516585196767, 0.12348599093300955, 0.1659416149237326, 0.24815143857683453, 0.09820828839604344, 0.1329346453504903, 0.1809243873826095, 0.11107411302093949, 0.12651845892625196, 0.1676417522664581, 0.10320419246064765, 0.07323579769581556, 0.12118810495095593, 0.16299217247537204, 0.1993892387087856, 0.15283230479274476, 0.10679082000362021, 0.17747220476823194, 0.13084778375923634, 0.21813751411225113, 0.17693051669214452, 0.15550240794462816, 0.14221418169992311, 0.19186572384621414, 0.12132609183234827, 0.15597242915204593, 0.08006508302475725, 0.1661967576614448, 0.15371894650161266, 0.14776567023779663, 0.135554292638387, 0.17791637379143918, 0.11292953310268265, 0.125385956838727, 0.1702843883207866, 0.17665804417005607, 0.1524921144757952, 0.11928348429501057, 0.10590532501893384, 0.18102322279342584, 0.12898065894842148, 0.11819132789969444, 0.12320393749645778, 0.11205112202359097, 0.08972663458968912, 0.13109061787171022, 0.14871029954935822, 0.2016096767038107, 0.1574360156165702, 0.0984460674226284, 0.14100576511451177, 0.16992551114942345, 0.11939225345849991, 0.12499299006802694, 0.15675619138138636, 0.20957282797566482, 0.08752435419176306, 0.16909160518220492, 0.09360780061355659, 0.11609792523086071, 0.1947419387953622, 0.08636536888246026, 0.14851044384496553, 0.10065552672105176, 0.10197917212332998, 0.07800786662846804, 0.18457342657659734, 0.118338746417846, 0.09021978027054242, 0.09327662802700486, 0.11248207318463496, 0.1502137974436794, 0.10564842487552337, 0.2453011300946985, 0.154361274891666, 0.14391509257256985, 0.13703770589615616, 0.17987949773669243, 0.1461640154676778, 0.09682244847395591, 0.1405521101717438, 0.12461397397731032, 0.16438053654772894, 0.1015769840617265, 0.1587277834436723, 0.18728454038500786, 0.13049046721841606, 0.10597524126725537, 0.11175530111151082, 0.12473997793027333, 0.15827206575444766, 0.07060973825199263, 0.10749653713511569, 0.08407981866704566, 0.09405556587236268, 0.15248963103762694, 0.18955984472164086, 0.12811214769525187, 0.16715298992182526, 0.08689329626836947, 0.13840213125305517, 0.13647715454655035, 0.22894002231104033, 0.08802096718656165, 0.2441958508321217, 0.13660260210079805, 0.13387277429657324, 0.09813044685870409, 0.14275034650095872, 0.06339615104453904, 0.14934791890638216, 0.11096017342060804, 0.28143830384526936, 0.15353586418288095, 0.19107684546283313, 0.19911132433584758, 0.12955278610544546, 0.10583893715270928, 0.08349187485873699, 0.07238323201558419, 0.10855003739041941, 0.16775113211146422, 0.1154428810945579, 0.0981426401329892, 0.11989312086786542, 0.07889985519328288, 0.11471717432141304, 0.10852476196097476, 0.07567300048789807, 0.11080343861665044, 0.07748790524367775, 0.15717441322548048, 0.0946650260261127, 0.23554819343345507, 0.14645464558686527, 0.16936630329915456, 0.08835528817559991, 0.1856679849858795, 0.1572995079415185, 0.16613476670214108, 0.0915482636275036, 0.13374995945819787, 0.1590440757572651, 0.10089290541197572, 0.0977889062570674, 0.11565029567905835, 0.08502064139715262, 0.13253515107291086, 0.11181875770645482, 0.1199872608163527, 0.13280128607792513, 0.07229392323642969, 0.18553070378090653, 0.0978155726833003, 0.12392337460603033, 0.10921856401754276, 0.11453235495303359, 0.06801552245659487, 0.10448431662682976, 0.12383538218481199, 0.08971431917910065, 0.06393042273287262, 0.14765601897878305, 0.17086596068527016, 0.06409104554248707, 0.09266718144395522, 0.15714971455080168, 0.09480715197111879, 0.12685692576425417, 0.09484194724687509, 0.1251536128776414, 0.15756873706621782], [0.07134664085294519, 0.014824253107820238, 0.031640993763825724, 0.038595747003065686, 0.022234822423862557, 0.04080257358561669, 0.012837090363193835, 0.008920937377427305, 0.03015171457082033, 0.02154299320786127, 0.04760450377528157, 0.03535875837717738, 0.010452189050348741, 0.03990717198965805, 0.029056487804544822, 0.031008714477398565, 0.02358043539736952, 0.04545563426134842, 0.0724682185266699, 0.0349346264930708, 0.032475707187716446, 0.04408980094428573, 0.07446944899857044, 0.019513079364384924, 0.04661050086308803, 0.11534171152327742, 0.0322894289690469, 0.06764804824654545, 0.01449901600634413, 0.03963089967146516, 0.03101370170978563, 0.018437989821125354, 0.06553631834685802, 0.021803567618397728, 0.062417561055294106, 0.05286221379148109, 0.008819196140393615, 0.04003363395375865, 0.08425692987761327, 0.05081310249598963, 0.027891187030555945, 0.039427542726376226, 0.05891088529356888, 0.03618101389812572, 0.016022255877032876, 0.020279291285467998, 0.07310126455766813, 0.05218460836580821, 0.024501268485827104, 0.020109581195616295, 0.025909321948087642, 0.026261770000149096, 0.03507064901558416, 0.0414405016760741, 0.0391459642643375, 0.059125566988119056, 0.09184525840516601, 0.02414527508829321, 0.027799676405265927, 0.053537715758596144, 0.07745383600039141, 0.029690270046038286, 0.03375197048964245, 0.01462209886605186, 0.026792051902573024, 0.01044837398720639, 0.03900929374088134, 0.009496220570456768, 0.03527244872280529, 0.06358510947653226, 0.008993452414870262, 0.06507452776921646, 0.008587928505481353, 0.05787100323608943, 0.044445760415068696, 0.03808165494618671, 0.05212677004081862, 0.016207950555586388, 0.047147452764745267, 0.023704880416127186, 0.015298605064994522, 0.04619179047378046, 0.033606770781001875, 0.04237414889835885, 0.026553404351164187, 0.05594326489205871, 0.024751466399590884, 0.12253005722803728, 0.02556221396662295, 0.01192545736142035, 0.03077315426032458, 0.01608207043526428, 0.05846699446971927, 0.088491191954485, 0.01950108116891767, 0.0295186685398221, 0.016770055750384927, 0.03531752380409411, 0.04425949915977461, 0.04026185242193086, 0.01719909344267632, 0.026700843225366304, 0.021110730777893747, 0.014957844778629286, 0.011812778139886047, 0.0039596869443942395, 0.02433672544014241, 0.08033376932144165, 0.008263805049604602, 0.030752421622829776, 0.057501181294875484, 0.06828300096094608, 0.018337990722752044, 0.05210973202650036, 0.020153333133618747, 0.03895811184442469, 0.030304334059889828, 0.037255138225321255, 0.03263948179249253, 0.013923924499457436, 0.06535406384084906, 0.06789389505450215, 0.020522688582007374, 0.03992450177403433, 0.05628466300134148, 0.11849542015365191, 0.043615158913390975, 0.06026197065200124, 0.0018742199546457933, 0.049883455237639804, 0.05066083584512983, 0.02234794947850917, 0.029465108378125087, 0.021863165045423166, 0.01736293250827917, 0.04492353727774961, 0.012354271137155592, 0.029057753272354603, 0.03910742008260318, 0.0573529756761023, 0.07905357051640749, 0.029329781354005848, 0.031598042497145276, 0.020830624736845493, 0.025922719622030854, 0.0013980358469000617, 0.014235885215124913, 0.04631676983886531, 0.019049894397280047, 0.05752697241093431, 0.00654032186139375, 0.03439534382362451, 0.028805266999240433, 0.04434060784322875, 0.03930843608187778, 0.06839271328811135, 0.0247880564004715, 0.01420218322891742, 0.02613465833876814, 0.02707169993248369, 0.03023781387933663, 0.03384738608396479, 0.029447011849177734, 0.019652553933805654, 0.037800035772046874, 0.029135109657155614, 0.012636748658094023, 0.021871307465646948, 0.041526064941925664, 0.011674110178968735, 0.015189683231125985, 0.006565085845068097, 0.04241175330909235, 0.012759494794798749, 0.023216886512402977, 0.06140107488525765, 0.05115436150559357, 0.039456801156380346, 0.01709726399609021, 0.016533491301483343, 0.0329771106397467, 0.02775083375828607, 0.027631194463797977, 0.013948930211232176, 0.0163136222067156, 0.06037568633577653, 0.040176723418491225, 0.008602863061241806, 0.0475436391841088, 0.0457465697212943, 0.038782201640840085, 0.02514774611751948, 0.05249771495748844, 0.08218965759234768, 0.03476840237687741, 0.03495476880509939, 0.06747130344488791, 0.03149935297135796, 0.012119911078895842, 0.02022770226800016, 0.060617733347628794, 0.03937512928886073, 0.01871670486538538, 0.011203639442101121, 0.02325464359351567, 0.027898145407172184, 0.000850240107476046, 0.013738338386506906, 0.0439200823727463, 0.08042329523180212, 0.05580340186133981, 0.0703124517042722, 0.01983982790261507, 0.04011408785091979, 0.087804921636624, 0.08833708308104958, 0.031906490945922475, 0.03364909779546516, 0.07644005718507937, 0.020905894626464163, 0.029548965128404752, 0.0979875066716756, 0.050745313454951556, 0.02316959262160318, 0.04062662606260606, 0.031718499426330836, 0.031105575351310626, 0.01614755924258913, 0.029091127017246823, 0.014739548188767262, 0.025104262200849395, 0.03218741122899311, 0.027987613642056073, 0.02831276083764221, 0.02179320638866297, 0.007729992220577384, 0.022285644696759324, 0.05832105515790837, 0.10951445278312479, 0.022482581004234295, 0.03408562990703753, 0.05047687143087387, 0.05333878964717899, 0.01837062825714903, 0.05607558600604534, 0.05578991258516908, 0.024859341593193154, 0.06984709881778274, 0.07217869441956282, 0.04200201315273132, 0.025823507624279176, 0.02667053136974573, 0.06325895804911852, 0.02529873712254422, 0.012614067776926925, 0.05298508630533304, 0.05128899642399379, 0.05327294460896935, 0.10161454776035887, 0.029793319159320424, 0.05654854866276894, 0.04165469482541084, 0.04009707358532718, 0.03676930715196899, 0.06762724436287369, 0.047286521909492354, 0.04391296114772558, 0.050220470010702095, 0.03459738101810217, 0.07423760036804847, 0.07693297894937651, 0.03345771360078028, 0.05077052103089435, 0.015598268181617771, 0.005864323291461915, 0.035909074026026895, 0.01923954832766737, 0.05991439108869859, 0.025347954660121883, 0.024868457711168697, 0.0022186975527022567, 0.05849505867809057, 0.009422196640766092, 0.012505970363106047, 0.008999064747643257, 0.036353212515158315, 0.04897559913141387, 0.06436556045498167, 0.012338809020418142, 0.071584996634296, 0.043347212219876904, 0.04923886054062417, 0.03696091865588512, 0.04050026248608317, 0.02558001533283719, 0.0314158931640642, 0.03348457680216857, 0.06539162075413124, 0.04487362424177783, 0.06675778316067797, 0.04292589964877282, 0.00329177757209566, 0.008429756055452993, 0.027195936301723123, 0.03800273793084281, 0.022242238811616386, 0.05321392224037221, 0.03999272168480924, 0.016412209952250123, 0.05013781426740544, 0.031651097150253396, 0.01580356404052249, 0.004179405065120331, 0.027559707406908274, 0.015280047132234489, 0.07750004423516137, 0.026130629537094916, 0.021421818727893487, 0.025108284217172434, 0.043638992455921004, 0.047204341140708754, 0.042507521741624386, 0.07285266968288592, 0.052112775256059, 0.01837197514916105, 0.07315471954643726, 0.02589394634456507, 0.0026768766277070555, 0.02441261788564069, 0.02524817269295454, 0.007191472903027066, 0.030257501572902714, 0.01892279800293701, 0.008305846231191285, 0.057603083683976104, 0.07708085208599057, 0.02232466046033161, 0.025171430382345403, 0.014758382624547397, 0.010505263211338647, 0.04459354194945522, 0.012198090187406965, 0.01274236008924033, 0.030111894743250947, 0.03425651216613395, 0.04424361126231296, 0.05352561069386346, 0.061044681152062755, 0.044753031605588536, 0.022918622874255692, 0.054102297606212754, 0.025902180367016366, 0.13903615437448025, 0.07858329146568264, 0.13302468694746494, 0.12579187005758286, 0.13173084280320577, 0.127403105742165, 0.09010273976517574, 0.1008115354925394, 0.07653772551566362, 0.11402722634375095, 0.12036795967391559, 0.19989885921989167, 0.12672885906483444, 0.152202149320926, 0.1089745085420353, 0.1564373206347227, 0.13376889058521815, 0.1634863359587533, 0.1274428271821567, 0.06497831828892231, 0.1251959806042058, 0.11827195143061024, 0.1666753419807979, 0.1362553821610553, 0.11718941666185856, 0.16212220915726253, 0.10924228560179472, 0.19351423824472086, 0.06254363964710917, 0.11870195264262812, 0.18867492649172032, 0.13518985147987092, 0.15723845336054051, 0.1525671604488577, 0.17760141140648297, 0.11729118334395544, 0.1377235148102045, 0.11771669265414987, 0.23072307663304464, 0.1615534746753318, 0.13450094844613755, 0.088469505975289, 0.2641294454889638, 0.130747238440173, 0.11153053638658353, 0.15458654851785728, 0.16955271043947764, 0.13799172613237584, 0.051750505409602604, 0.10553705013756241, 0.14937579312494823, 0.12450633118195192, 0.13236497449023382, 0.12133374570735864, 0.09527936484664679, 0.27509117871522903, 0.1837134241525616, 0.10450886602380446, 0.09910195294235434, 0.1706671363541058, 0.18287313995616777, 0.12979632589433873, 0.19273834702159676, 0.09724669570901565, 0.15853986995560782, 0.11199245588587863, 0.11839963815041951, 0.09915833920240402, 0.15006686747074127, 0.13428075026188577, 0.08440858245428119, 0.15250664869589464, 0.22953026635306223, 0.1750463199402605, 0.10043652954378299, 0.16052402848643915, 0.1006769887836916, 0.08722800402236836, 0.07397172320634127, 0.15068418506000722, 0.12603298069110938, 0.21246258648378508, 0.16234183737209865, 0.09425842070153781, 0.1039110766723752, 0.1230685290481363, 0.0934234969317913, 0.20455907844007015, 0.11398005458925452, 0.11069660327796425, 0.11820450504975659, 0.15020884413804325, 0.2199121138879231, 0.18346164694854192, 0.17033602483570576, 0.10216711275279522, 0.06464190062667642, 0.19309167377650738, 0.14141009056142398, 0.09040120017847844, 0.11039623618125916, 0.1720050581331764, 0.1149330163108451, 0.13404637069574424, 0.08588298476700272, 0.10922591933714491, 0.1327625010162592, 0.14922827961189405, 0.20600870065391064, 0.11538815045995371, 0.2551422491669655, 0.1893755274691752, 0.08837602420576982, 0.14550388231873512, 0.10209395989243474, 0.11215038491146904, 0.0765036969844784, 0.1193498857319355, 0.13473359096263135, 0.07190928209040846, 0.149766385023083, 0.18988406232425145, 0.08746861253998109, 0.14790106511541776, 0.12358304858207703, 0.189455350328769, 0.1473185292312077, 0.18334412468331202, 0.12385151774755546, 0.1450248094541686, 0.1323889810591936, 0.06853075445230518, 0.1050093670242599, 0.09379126969724894, 0.10149545807923589, 0.10192049241491727, 0.07934090974075453, 0.07660492762391057, 0.12514224063072885, 0.14019554001944406, 0.21639177921627248, 0.0636554192751646, 0.11893211172095366, 0.08478398873869862, 0.07796612993947097, 0.1227131938295705, 0.19589242206088134, 0.12430823966860771, 0.09184283603514944, 0.1876238486064332, 0.10106528044811317, 0.09721199542816196, 0.1391126795538834, 0.08972152522099869, 0.09059051823403154, 0.10955502917723996, 0.09608574943350894, 0.12851367757788726, 0.14987718979162828, 0.12969472206064633, 0.09025435841509274, 0.12919549670602593, 0.13907601152147564, 0.09905917809477874, 0.09813186499689307, 0.10827778878488711, 0.08511645054178578, 0.081998426068042, 0.10481645273310797, 0.18683783364083084, 0.1231513103204114, 0.08599587263805525, 0.15026749670505524, 0.0799758963819061, 0.12186689781291143, 0.1282287607235568], [0.012590302087898766, 0.006842583343054035, 0.06799424359841005, 0.023138895697359527, 0.034686808540884934, 0.06243015466524022, 0.042447620670178106, 0.06034450765166964, 0.031061236480517045, 0.039143168700060675, 0.03790886939636298, 0.029247247747012546, 0.04294272053188511, 0.024484510367204036, 0.023124307194458585, 0.049744175747036934, 0.010463132972030767, 0.017979418892147284, 0.002041688758514023, 0.05153456163991775, 0.009434702041159784, 0.038588859872626405, 0.023849832459485958, 0.027133862221879617, 0.06634095909872226, 0.04674298821815422, 0.042453920867826254, 0.10110926987337214, 0.019140119198709726, 0.019117468003449694, 0.03374259992103491, 0.05805044860712119, 0.012774556575875198, 0.009596129762940109, 0.05231110764933484, 0.007099695952742228, 0.046956129638212066, 0.02096340386196971, 0.020336118593279804, 0.03930400864088109, 0.04972992990432041, 0.015471261693164706, 0.03874453955463, 0.07772121272448983, 0.049209870131952424, 0.022691104993490235, 0.008170241855883172, 0.03717087096135531, 0.03189598383115871, 0.03808260150253773, 0.01977847476622888, 0.04319722544667976, 0.058352735957929065, 0.025053736787023287, 0.009725802894016462, 0.08965261998985495, 0.015431219645376717, 0.00752860472338008, 0.054866389105362554, 0.038371324938322814, 0.07611495070159435, 0.06324125507048198, 0.027030736773407886, 0.03851053657542382, 0.035959679167717695, 0.014259728935680218, 0.025511881935277154, 0.026427149340244274, 0.011078811051057917, 0.03954570959987385, 0.0135633467497038, 0.07932465204170772, 0.02712668332138232, 0.03235204418056777, 0.034434844739735126, 0.012103312416002154, 0.020548486483416388, 0.021260508901572654, 0.05537087310637746, 0.03135646706713097, 0.029297798605901853, 0.05898010943617139, 0.019219409408313886, 0.007471087006186801, 0.049965602079672475, 0.027516160725748966, 0.0091117363356586, 0.09068776587290422, 0.05662897202585425, 0.04436896042898297, 0.022318950588149682, 0.032536249474755356, 0.04891713655420712, 0.04671808259029474, 0.06977230390267712, 0.07021491229534149, 0.022259804386911646, 0.02450056280940771, 0.0641542375087738, 0.04126592818647623, 0.003973716504073569, 0.013550460521530892, 0.03268948303801673, 0.04029024911246129, 0.01275604953324156, 0.03465931090925421, 0.05430765962228179, 0.01784484843457384, 0.07866247650235891, 0.04501277141805206, 0.027423053846827576, 0.00975428440142423, 0.039415474981069565, 0.027183871949091554, 0.037226086748497825, 0.016417972410895994, 0.04835419676133564, 0.11001408525875636, 0.016929022934553877, 0.03918414882251194, 0.023633276311946765, 0.015554249918620502, 0.03396938328764268, 0.01626292715913483, 0.028433480699147497, 0.07282912451773882, 0.04523632835064616, 0.05593120053942714, 0.050177912294332466, 0.01975377948422517, 0.01103200570547155, 0.011815367599150963, 0.021313887555152178, 0.04576012006561671, 0.01123579521663487, 0.04816255472334368, 0.062486995543752394, 0.02471151595403041, 0.012049873542439724, 0.023290982536439384, 0.06781989402536835, 0.014383500508431877, 0.0148338866087475, 0.024997092683666518, 0.017779198475182056, 0.02487318031489849, 0.062065442092716694, 0.021206904635099427, 0.07506632232772452, 0.07597280440053769, 0.029708359789635454, 0.05329795201708164, 0.06528351655496017, 0.01765980345330068, 0.013083614009831632, 0.06642039519335542, 0.04184742591210774, 0.07294792921415397, 0.024731505595679795, 0.04276820471776383, 0.005909973007094647, 0.022791229620841996, 0.08510385693183967, 0.06092430225440434, 0.02212048588054521, 0.04856487849195089, 0.008328643311480326, 0.057277407231075425, 0.042602662529264174, 0.027990259928628802, 0.02002639789134264, 0.04179488016026361, 0.013442179903254976, 0.010934390809520014, 0.020055895504940833, 0.055988095700740814, 0.02190347681088107, 0.02560141123831272, 0.07212815713137388, 0.025076745909505656, 0.03411470513258662, 0.09681868938995258, 0.066833975857922, 0.06925467667835099, 0.035285100008227994, 0.03262541576155594, 0.012026513278085207, 0.06806654828999724, 0.01166738589693393, 0.029204048815050294, 0.058722096495330334, 0.020851186044248085, 0.05876776190208537, 0.024882808726813112, 0.018782025735293115, 0.020101850985416343, 0.07285990286618471, 0.01947892191154616, 0.052295162076396604, 0.024704956216737628, 0.04395792766341141, 0.06290993999157633, 0.06337656173855066, 0.038462981448641846, 0.05998931492545775, 0.013937629210496587, 0.04978033148550561, 0.044679057717855485, 0.02469881038580622, 0.028672243601509502, 0.044773625143404515, 0.031610429153910706, 0.058452148123511245, 0.02705116237380675, 0.014730827317440083, 0.023367840198001692, 0.031638296587126594, 0.02904758203242506, 0.05577138179380979, 0.013202541690718914, 0.02611293673648366, 0.07665001627589975, 0.0279883278001632, 0.0029219585994724184, 0.04377608706376382, 0.019995768820600848, 0.014853150217926927, 0.07137639461351292, 0.057241539869989665, 0.01848344997103725, 0.061688448036355634, 0.0045660368632525206, 0.047922736699027677, 0.021454096638730595, 0.01488756381773523, 0.03890311658116324, 0.05867973555411611, 0.04318253855620112, 0.030679126270115376, 0.05077286876205887, 0.030440495682082007, 0.027096668324832405, 0.027404587516295056, 0.009666021414367216, 0.05317736277356744, 0.03111556338678513, 0.02671491604165307, 0.024982565248917257, 0.014911000417279345, 0.07160433488232748, 0.015979793155565858, 0.014299380825832486, 0.062063365775559626, 0.03254050388932228, 0.05004924848409636, 0.015703330847567747, 0.06286776904016733, 0.13541986128049238, 0.022846101051462547, 0.07600053612674985, 0.045089564618787596, 0.02233328633675618, 0.06640782872481005, 0.07581777950482708, 0.059484824139092646, 0.01317841128911823, 0.038712611089327505, 0.0183013888475086, 0.07401425378131014, 0.022365498090428964, 0.019393229724041054, 0.037976186855563095, 0.027112155886633054, 0.04202320380136371, 0.1024831540084311, 0.05015907616221479, 0.04962759664548295, 0.01643594171452735, 0.04753947976444449, 0.00752662170478808, 0.017971045770017163, 0.045638628370527706, 0.051920393614896705, 0.03874557092785835, 0.04709781453545604, 0.01903603023051151, 0.019800832495093346, 0.02144560307663466, 0.042608521679150205, 0.02953178122905748, 0.032876802807939906, 0.01305009692441672, 0.04267836328861969, 0.057504383980163505, 0.04604627524635621, 0.027890428767672608, 0.034283422864973545, 0.044196015423429866, 0.07872228936425277, 0.0069731894597810295, 0.08853503210203988, 0.03225255059078336, 0.02675788427170898, 0.08705391907798392, 0.012606117042845913, 0.029472382273525, 0.011852558951691856, 0.021675310929172804, 0.03653524988996131, 0.040985360741615295, 0.031469141199652634, 0.059900637183870585, 0.0063128514780796, 0.0937146766643439, 0.03148222674748727, 0.010763510246761143, 0.04694194147097213, 0.024947157595306635, 0.0235910375070359, 0.04941028902041061, 0.052010241829391034, 0.036052333124514134, 0.029077254368790557, 0.008405770690712546, 0.0168798630724528, 0.0147389273292252, 0.002144497840033312, 0.03538451895916036, 0.07258694858423301, 0.030643696564116647, 0.009507060167379677, 0.03791330023003476, 0.01490293093957007, 0.04005070589482784, 0.07156478986144066, 0.028120952558570673, 0.023893845633470585, 0.059911751587476046, 0.0901501557922789, 0.05986138393304177, 0.06875053873019558, 0.032189219524817805, 0.02230005508421787, 0.028647616173007658, 0.06907247645514351, 0.02883314121780651, 0.026198644191026688, 0.09345119473125253, 0.05359364400750824, 0.0214049435619797, 0.02885381957249982, 0.04396446534831609, 0.10109521062778574, 0.1179086094988244, 0.1564876272210053, 0.13203969837299415, 0.07875918131321669, 0.19932029955089092, 0.20503976621798106, 0.12388150899537972, 0.136228810729725, 0.18593576204563889, 0.13587192845131668, 0.14770442566701344, 0.12639280781149864, 0.1554856752710683, 0.10616189268018518, 0.13566923647054605, 0.14030367136001587, 0.1023964983011995, 0.11381712476057665, 0.12474474124610424, 0.1782846554581608, 0.1370136993271964, 0.08985941032213823, 0.06959633941629104, 0.11441173856811863, 0.127303917493139, 0.15625898806112154, 0.1084306627245886, 0.07863798817353589, 0.08439764446978058, 0.1596400873469455, 0.1602175613599164, 0.17509026186806814, 0.1070496743278844, 0.10315026928271566, 0.08485403390867369, 0.10226666062538113, 0.08511082548648119, 0.1116994373234255, 0.13938789335744722, 0.09126462920435838, 0.09950912145099469, 0.162201692749347, 0.12976649749491895, 0.10463570457484041, 0.13814108526068075, 0.07507177774927445, 0.08881194902850048, 0.1072285497295005, 0.14363420621625014, 0.11853320098349027, 0.12181740546865122, 0.13883974562798226, 0.13555673536445412, 0.11229299940168858, 0.18418476171791553, 0.10490950702556542, 0.10005292655634028, 0.11836743487843446, 0.19463296607136726, 0.11855770966836385, 0.15123848031674111, 0.10751602466085128, 0.1313643931810345, 0.16236809667732033, 0.0643275896353381, 0.17230832257441112, 0.17415650268750532, 0.07162675367934362, 0.1907541070665632, 0.09664224314370326, 0.11038652634514229, 0.1292694027402571, 0.1790520107107503, 0.07523847344730582, 0.0694193910541279, 0.1341891616050686, 0.06861559847103697, 0.13437076471745968, 0.1205734336482627, 0.12462599761784077, 0.20777693577110767, 0.16053704278809683, 0.1715008659022195, 0.19993818710957253, 0.12995621588613304, 0.10669778606721333, 0.18570554868451186, 0.18373885564506054, 0.06554146164229938, 0.06333516431706292, 0.1008599353954196, 0.18620322697928973, 0.09998606371560267, 0.14420702547899314, 0.1517579938684191, 0.1413949728012085, 0.18164182959922723, 0.2415637049291815, 0.1724871572639261, 0.07825999667069741, 0.11757137759455613, 0.12777798276926788, 0.12976067566445895, 0.07311999890953302, 0.1190668416342565, 0.1886777084852968, 0.12281915385808263, 0.19081509379403933, 0.12935071837689194, 0.07273919148636715, 0.10645816821072783, 0.11770253841366086, 0.11714257060417108, 0.11372600429292236, 0.11416830734482833, 0.09487182992909636, 0.20914896072021552, 0.12248171839330878, 0.1502633983535426, 0.0721544503633465, 0.17243321372994355, 0.16553749303732598, 0.13377824079777512, 0.21125520127160208, 0.1467487226639475, 0.08847469676818166, 0.2144832637693201, 0.07585761629577194, 0.10233304849160568, 0.09140200540423393, 0.0689429576907839, 0.08984850626438856, 0.115547348346029, 0.11575856272663389, 0.17494185268878937, 0.10448631830513477, 0.13396687353295939, 0.08182334367718015, 0.07412868871220521, 0.1192479697721345, 0.13188862933644227, 0.08354568268571581, 0.11151640250214509, 0.12509911294494355, 0.08383999046470438, 0.12366737691419465, 0.1346348098346165, 0.14731896349361964, 0.2164918767022235, 0.13641619496047497, 0.1460588425397873, 0.15540513316435473, 0.09973207448742219, 0.06433994575802769, 0.24315226397344045, 0.11844649777880736, 0.15348797318126473, 0.17839859505849226, 0.1581268049776554, 0.0502476283748235, 0.18363726538206848, 0.17206551560333797, 0.16523649490305356, 0.11760964696960789, 0.11609436970736299, 0.14875379364405358, 0.1496467457285949, 0.24549413259540284, 0.1970704131360565, 0.1009260518476367, 0.2405797748693398, 0.09279984861080136, 0.14952060606862816, 0.1203264876135758, 0.14567490028483526], [0.020997515513694713, 0.026048447071973766, 0.031019750849476883, 0.05540747328528336, 0.026500770389767628, 0.018351116982687796, 0.02749458670483104, 0.029555401033056632, 0.045916027056851556, 0.023646573901974728, 0.028974748083523343, 0.049868317121373754, 0.0328192223262574, 0.01700614861744855, 0.04171401235674109, 0.07740690851850168, 0.03343127787645374, 0.01744848389976791, 0.028759435351405824, 0.01610515928561134, 0.032957558653184345, 0.056410568566726785, 0.01830332606498684, 0.02540818991006485, 0.011732111352362802, 0.02512021455913782, 0.01880964889590229, 0.08207113788064037, 0.030026993049042563, 0.025546259911996976, 0.05016256722488573, 0.01573889795690775, 0.01654209173284471, 0.029035202161009823, 0.053642210151468, 0.059703163137393336, 0.04461920414386051, 0.02426793725628938, 0.06290410459041595, 0.038522441472326, 0.01356329840408372, 0.029606470971235206, 0.08222616277635098, 0.04161298188513943, 0.04202833691877978, 0.02055837952398828, 0.056770429613866975, 0.03751809768644827, 0.013308716305930699, 0.04016008234715887, 0.04499811506164925, 0.03379639078463827, 0.010032976545127375, 0.027090016985312104, 0.032060847484639714, 0.01910355464289231, 0.049223864916712046, 0.058171512825148444, 0.05930480879864522, 0.005656637717038393, 0.008152226751138057, 0.012642598478123546, 0.01827355534104364, 0.03997818746470979, 0.03911095525005034, 0.05545443469392402, 0.04685543843411973, 0.06999910423266036, 0.005666076987316566, 0.018188986128994396, 0.0936770247561591, 0.0385422241607947, 0.053987306276602406, 0.06073497062815087, 0.046080989097910266, 0.049881009118897576, 0.05394054503579225, 0.11733770370483398, 0.06724928678678614, 0.1490425510065896, 0.03995411982759833, 0.030604484025388956, 0.18280547644410813, 0.9716408678463527, 0.8682272455521992, 0.3980995624193123, 0.24008827124323162, 0.006402301901419247, 0.14051343367568084, 0.16349227992551668, 0.023581348026969602, 0.08385240087019545, 0.09640884745333876, 0.02168538547786219, 0.0780004027432629, 0.020947110539834415, 0.03733196874548282, 0.073416104806321, 0.009162558608555367, 0.0068672985570239166, 0.14509231011782373, 0.0364421786341284, 0.10906019394419023, 0.02380832307972014, 0.057894528045185974, 0.028526351787149906, 0.02432409281443272, 0.010385676503314503, 0.022363118128851056, 0.047590536131922684, 0.05226948291861585, 0.03625610736863954, 0.012602799006604722, 0.052142322063446045, 0.0160426509433559, 0.0211861092331154, 0.055672760121524334, 0.015226185022454177, 0.01877923695636647, 0.044781370620642386, 0.06770761005048241, 0.029410618623452525, 0.03943307278677821, 0.05005930776574782, 0.031030709190028052, 0.048913055166069946, 0.04162544996610709, 0.038883900469435115, 0.035871042138231654, 0.0355337016683604, 0.06183807857866798, 0.02963062681789909, 0.021011695199246918, 0.0029760482305261704, 0.04027520938377295, 0.0254630867857486, 0.02050234440581075, 0.02177304372058383, 0.04594097339681216, 0.05288320766495807, 0.03438889095559716, 0.015981487796774933, 0.036655995196529796, 0.0453926865676684, 0.03127180625285421, 0.008612896897830069, 0.10030954171504293, 0.09111600967922381, 0.00780987021114145, 0.020229396909209232, 0.048776974968080006, 0.0019129433120334788, 0.057020697077470164, 0.018723885462220227, 0.031047506324414696, 0.03353781805240682, 0.0249742345352258, 0.02742145080784602, 0.04252505508650627, 0.055307606501238685, 0.027605160771469985, 0.0298805821553937, 0.0315494831385357, 0.04586075359423246, 0.021294725726225545, 0.051391489138560634, 0.05388469821108239, 0.038360044293637784, 0.028711666486092975, 0.044161047121243815, 0.048911352043173144, 0.02511077274435333, 0.08374319744429418, 0.12319209027503218, 0.03988686004387481, 0.005215274436133248, 0.09439779179436819, 0.028471916315278838, 0.04716978674488408, 0.044296655737395794, 0.03602998557367495, 0.06821543922913925, 0.00974420306738466, 0.030531768820115497, 0.033219578343310525, 0.06524745241871902, 0.04706563161952155, 0.03666223771870136, 0.02088894651803587, 0.03329390167657818, 0.01799179028187479, 0.03184845245310238, 0.05945325869002512, 0.004171715567021498, 0.032881023295755894, 0.011983325372317007, 0.01142087412465896, 0.031145608917410885, 0.012245257701059538, 0.04645301288525973, 0.011629513464868069, 0.07019827461668424, 0.04104845771299941, 0.05223173940820353, 0.010167714940117938, 0.03505108006564634, 0.015154752248365964, 0.021897831399525915, 0.0394336291854935, 0.020656453279246176, 0.03560570101918919, 0.008530937501096299, 0.020285847630085688, 0.02220719587057829, 0.05674844847193786, 0.033546998631209135, 0.048240576072462966, 0.05446809922744121, 0.057126786027635844, 0.036830270130719454, 0.017653611821255515, 0.010748571450156825, 0.050373184494674206, 0.01857865521950381, 0.0273543114640883, 0.0497723586990365, 0.07929289660283498, 0.05768806340971163, 0.06354635155626706, 0.014173995187905217, 0.021478188024567704, 0.05329992316131081, 0.04726397079814758, 0.014930252152095948, 0.044418388312416415, 0.045267934511814795, 0.03827153279313019, 0.038928666817290444, 0.01116913084739021, 0.033557566814124584, 0.011129512035820101, 0.008407983563042112, 0.03969310097662466, 0.045841415346200974, 0.07375115182782922, 0.010562909002016698, 0.05258068621956876, 0.026312358178464428, 0.044761842382805686, 0.006532239661152873, 0.06400889530777931, 0.036135548659201176, 0.05784209764429501, 0.04983611724206379, 0.05899385655564921, 0.09264687289084707, 0.010858019996833588, 0.18287479558161326, 0.26621037668415476, 0.9569528102874756, 0.7423720817480768, 0.27909553955708233, 0.1655203125306538, 0.04356252834466951, 0.047832108169261894, 0.06655830743589572, 0.015796858418200697, 0.02855598341141428, 0.016714860319292972, 0.03582323934616787, 0.14470469020307064, 0.003946921156187142, 0.013300149801320263, 0.034349705558270216, 0.06541405990719795, 0.012563010561279953, 0.06524302837039743, 0.05332876768495355, 0.024480408623016307, 0.03176765250308173, 0.0520031307823956, 0.08909070478486163, 0.06231839316231864, 0.04039709802184786, 0.009115231639173414, 0.003944923294641609, 0.013294751207078142, 0.013496452526721572, 0.0228375667772655, 0.022703707085124085, 0.025134735208536898, 0.021569048952577368, 0.03629786102101207, 0.10098831422094788, 0.03963290134977017, 0.07503260592264788, 0.04581826712403979, 0.017219133974452103, 0.029674877479140247, 0.007138916124988879, 0.024385037133470178, 0.034785457354571135, 0.034467563698334355, 0.034020076638885906, 0.01624954305589199, 0.022703420404078703, 0.020112951818321432, 0.045710858423262835, 0.016463768435642123, 0.00536100976335417, 0.025568987442446605, 0.0035907106274472816, 0.010223800100253096, 0.03046050907245704, 0.05054460618911045, 0.042320687124239545, 0.023661381232419183, 0.01730709755793214, 0.0075743193239239705, 0.06458649145705359, 0.019343566049688628, 0.08190233193870101, 0.055875686196876426, 0.032436199486255646, 0.02366094188099461, 0.011320526428919817, 0.07238519976713828, 0.048491386364081075, 0.05986568584506001, 0.06631037752543177, 0.023508400423452258, 0.04809242134381618, 0.03599171959129827, 0.0540974019760532, 0.058007544837892056, 0.06985541087176118, 0.01054390408431313, 0.04115629728351321, 0.014220317925459572, 0.018796037483428205, 0.029945073516241143, 0.07264005073479243, 0.05123802487339292, 0.013495975007702197, 0.03191516940881099, 0.042114890845758576, 0.04595559582646404, 0.05206868405054722, 0.010866753590692366, 0.04218858992680907, 0.04790370718442968, 0.019428064015560916, 0.19844914201114858, 0.07568518019148282, 0.15799411066940852, 0.10827935620078019, 0.12142199597188405, 0.11773582734167576, 0.11272971811039106, 0.07421624008566141, 0.11628321957375322, 0.11069545655378274, 0.14268526142196997, 0.11060765412236963, 0.11043643938111407, 0.09467989272837128, 0.17638582949127468, 0.18526311671095236, 0.13611580750771932, 0.14082197711936065, 0.07826161836939198, 0.06470146921596356, 0.09564525807010275, 0.1200225582080228, 0.11703521279352051, 0.10465298686176538, 0.17380709786500248, 0.13241832091339997, 0.0948354604520968, 0.22961790593607084, 0.14421941552843365, 0.10388571981872831, 0.10883136479450123, 0.14222815952130727, 0.09398832305201463, 0.16220817954412528, 0.15917208817388329, 0.1294934278620141, 0.11987109562116009, 0.08745251768933875, 0.09835185962063925, 0.12647599620478495, 0.12295211958033697, 0.07230668648013047, 0.2162162693483489, 0.12952853526387895, 0.0991363071703485, 0.13378505328936235, 0.18463122418948583, 0.10512899274804763, 0.12667108859334672, 0.15278662581528935, 0.1285510512867144, 0.1770198933248009, 0.2832318890307631, 0.11346200667321682, 0.12339902988501958, 0.08921625411936215, 0.09556655479328972, 0.1669528085206236, 0.11253066986267056, 0.08221590332686901, 0.12987320391195162, 0.1203325130045414, 0.13193548896483012, 0.11202659298266683, 0.14622186736336776, 0.08639306668192148, 0.1327813235776765, 0.13918365431683405, 0.18861615178840502, 0.1280398972864662, 0.15459003618785314, 0.09250163247010537, 0.11273235761161361, 0.1390975753643683, 0.24400154554418155, 0.17968466319143772, 0.1843873451330832, 0.19467114045151643, 0.09744919091463089, 0.24200708685176714, 0.12468987490449633, 0.218871444729822, 0.8007847730602536, 1.7546608341591698, 1.5212772488594055, 0.8786375469395092, 0.3729407324322632, 0.11780587929700102, 0.23666023090481758, 0.2712258089865957, 0.14631458238831588, 0.22421783927295888, 0.16008721478283405, 0.14149565382727555, 0.26237418396132334, 0.12780204362102918, 0.14957460388541222, 0.12138129744146552, 0.11066892583455358, 0.06615333059536559, 0.2039640982236181, 0.09990869715277638, 0.1290533979024206, 0.10019626029367958, 0.1708089773144041, 0.23757307763610566, 0.13885205425322056, 0.08489845081099442, 0.11161900378231492, 0.19910626246460847, 0.08603489518697773, 0.1137449625613434, 0.08987829395170722, 0.14415266125329904, 0.1076763082029564, 0.11637816019356251, 0.1219071349395173, 0.1721783016941377, 0.11009899713099003, 0.2015450123165335, 0.11439305171370506, 0.09191763773560524, 0.14088160677679948, 0.07649462497127907, 0.09708473618541445, 0.109368153847754, 0.13194345496594906, 0.14681487982826574, 0.12169300285833222, 0.11010536857481514, 0.17309568103935036, 0.17644765760217393, 0.07405827713332006, 0.13217981585434505, 0.09336282911577395, 0.08977992673005376, 0.08036141962345157, 0.16681072328771862, 0.09034117018537861, 0.15693802519568376, 0.07620715682527848, 0.08863410500011273, 0.1361071765422821, 0.11434776628656046, 0.1462374193859952, 0.14462030758815153, 0.14641961960920266, 0.12767157490764344, 0.09204727185091802, 0.08829869835504464, 0.13870591138090405, 0.1300790307245084, 0.15027783757873944, 0.12623727401452406, 0.1464423776737281, 0.10247677577925579, 0.059907707518764904, 0.08988349152995007, 0.1480667633669717, 0.1384935299200671, 0.11237113270908594, 0.2761746091502053, 0.0749170310529215, 0.16552731501204626, 0.09180567945752825, 0.14980411157011986, 0.16384939290583134, 0.06851149084312574, 0.10364552520747695, 0.15735959900277002, 0.16874800861946174, 0.13349117977278574, 0.14827590143041952, 0.18005835956760816, 0.08580994047224522, 0.10765642034155981], [0.039151792880147696, 0.012597631114268941, 0.01734534148792071, 0.043650629331490824, 0.027365446223744323, 0.04607296542131475, 0.022325104900768826, 0.039478517669652186, 0.017482381812962036, 0.028848771271961074, 0.0378129720421774, 0.05500313766034586, 0.012803109329459923, 0.03965851604672415, 0.01599951307954533, 0.029426146897354295, 0.018638403620570898, 0.01114652630141271, 0.01738868630491197, 0.029360054193862846, 0.06399226441447224, 0.04462782493127244, 0.06782836214240108, 0.03071019978129438, 0.045183775813451836, 0.033771563188305924, 0.022719605160611014, 0.026729312858411243, 0.03026516901861344, 0.060842097736895084, 0.023089601824592267, 0.06119682905929429, 0.02117858936877123, 0.12096470408141613, 0.032332349701651504, 0.029472344954098974, 0.017845762760511467, 0.011327652742953172, 0.016375976182254295, 0.03053684765473008, 0.030355940040733134, 0.027375245965751152, 0.036034582648426294, 0.050208687250103266, 0.01816920004785061, 0.06191298205937658, 0.0520012240989932, 0.0630435978195497, 0.057754899109048505, 0.03691121257309403, 0.10342330498886959, 0.05624129443562456, 0.03899626926119838, 0.013483966634209667, 0.09628899781299488, 0.0482134991325438, 0.080291320170675, 0.054964864892618995, 0.05878163115786655, 0.04080391369227852, 0.0577359747673784, 0.02515420237822192, 0.021069872791745832, 0.1077535729855299, 0.07398061880043574, 0.06311932911298104, 0.07682878989726305, 0.11955977018390383, 0.8196930470211166, 0.43270810533847126, 0.7338223233819008, 0.5874053229178701, 1.250480545418603, 1.8182220863444465, 1.2810919199671065, 1.3953839242458344, 1.1234742062432426, 2.6325048208236694, 5.260199751172747, 9.992607389177595, 21.207785061427526, 30.308924674987793, 42.17292513166155, 42.25392723083496, 44.98012590408325, 42.4328989301409, 15.875075646809169, 11.56761462347848, 10.03623252255576, 9.073800189154488, 4.737039480890546, 2.095965794154576, 2.4683551490306854, 2.2525879612990787, 5.074453558240618, 3.61565038561821, 2.8016652294567654, 1.4328807464667728, 0.664090310888631, 0.13147627003490925, 0.05195521263937865, 0.057874979451298714, 0.039293630447770865, 0.020462193792419772, 0.01284925140706556, 0.038378924530531676, 0.01720154465043119, 0.07640475300805909, 0.023869447210537534, 0.045509866172713895, 0.03631017303892544, 0.032591190455215316, 0.03154327793579016, 0.047671970512185774, 0.036991215244467766, 0.11501693752195154, 0.020352394952039634, 0.03908071294426918, 0.013099683415410774, 0.025113770172798207, 0.016754088125058582, 0.03043862631810563, 0.042843545853559456, 0.04008524671995214, 0.04612451372668147, 0.050876881395067484, 0.01084729829537017, 0.01943014542173062, 0.04585299115361912, 0.034020901058933566, 0.03380527620070747, 0.03243629787383335, 0.01317489902222795, 0.05318628890173776, 0.04255736353141921, 0.08127522987446614, 0.04330073257109948, 0.026826078737420694, 0.018650568057117716, 0.03150535122092281, 0.08605647260057074, 0.0331889187384929, 0.01802462968043983, 0.034412317377115996, 0.00454584662968825, 0.025345001336453215, 0.014136744463550193, 0.05265611217224172, 0.05520410616216915, 0.02759745261365814, 0.04611816942425711, 0.0293749887496233, 0.06421768053301743, 0.0255422328066613, 0.0287306824299906, 0.022537374403327703, 0.035838302823581865, 0.02995884438444461, 0.0277766978168594, 0.10327031569821493, 0.06485033979905502, 0.03716084221377969, 0.009537796955555677, 0.02413123789509492, 0.04852161509916186, 0.03881088670875345, 0.032529196103236506, 0.02214136779574411, 0.02808863902464509, 0.04446000286511012, 0.012031327484042516, 0.04286394600889512, 0.025863936437027793, 0.03445756209215947, 0.05276398906218154, 0.05577162267374141, 0.019129450931879025, 0.03677603143400379, 0.015343011789289969, 0.05443854902737907, 0.02459129142308874, 0.04189065537814583, 0.03499754365267498, 0.03234181187248655, 0.058351555306996615, 0.058294592292181084, 0.025835088520709957, 0.015574234471257244, 0.04006637666108353, 0.021458695409819484, 0.007305440492928028, 0.015294732326375586, 0.10843503927545887, 0.014649679618222373, 0.008332731484967684, 0.02562524817351784, 0.00903769544259246, 0.009982720000802405, 0.015724116071526493, 0.047934085197214565, 0.02905403490045241, 0.038101359603128264, 0.0192159387016935, 0.006088423052070928, 0.02396138700922685, 0.032393746942813904, 0.07597257369863135, 0.03761494838233505, 0.03989636631948607, 0.015395082566621048, 0.09699637735528605, 0.016253334370308688, 0.03498652424397213, 0.041274952702224255, 0.020584733824112585, 0.02801733517221042, 0.006187801714986563, 0.040818413985627036, 0.0071313784491004685, 0.03924174966024501, 0.03805641683616808, 0.07095190989119665, 0.06928316157843385, 0.01550654212145933, 0.021320720402789966, 0.045462823339871, 0.05642144887575081, 0.10228192087795053, 0.03638341071616326, 0.017827539006248116, 0.031122528548751558, 0.023107323462941816, 0.03610955737531185, 0.061276977615697045, 0.02471431321464479, 0.03166372129427535, 0.0635068676035319, 0.030268694008035318, 0.024463928703750883, 0.06959781862263169, 0.0210584937594831, 0.1051158020272851, 0.03727365544598017, 0.02240837980727, 0.6222542843648365, 0.29374684765934944, 0.5506070660693305, 0.5106962876660484, 0.794831143958228, 1.408645755478314, 1.1560451899256026, 1.3615288266113825, 1.3800399133137293, 2.759396731853485, 5.778151912348611, 10.69795376913888, 23.529635054724558, 33.428123882838655, 48.016248975481304, 49.498240675245015, 49.495565618787495, 46.748143672943115, 18.425177437918528, 12.694259813853673, 10.206970606531415, 8.936288390840803, 5.22380074432918, 2.4519007291112627, 2.1578036759580885, 3.095093301364354, 5.292984826224191, 3.8224120565823148, 2.486826717853546, 1.8106683088200433, 0.6587362896118845, 0.10447504783847503, 0.039614448589938026, 0.012307457309881491, 0.07411521300673485, 0.04552676508735333, 0.13822307943233422, 0.0745887558108994, 0.03565651989941086, 0.0252107158635876, 0.01908794155211321, 0.022548538000722016, 0.09350929768489939, 0.07989896408149175, 0.11867607331701688, 0.012335654680750199, 0.05696567467280796, 0.04863336981673326, 0.021011590026319027, 0.07315967285207339, 0.034178938650126965, 0.034654914002333365, 0.054754966869950294, 0.0022078874296442208, 0.010408004546271903, 0.02324005339427718, 0.05726555322429963, 0.004157036310061812, 0.01586696126365236, 0.03974218959254878, 0.03271257358470133, 0.06737674959003925, 0.03458057709836534, 0.044726785871067216, 0.041445882458771975, 0.047441010762538226, 0.02373663415866239, 0.034283724813056846, 0.04820161798436727, 0.05238505100299205, 0.05724818951317242, 0.02807296486571431, 0.04655697802081704, 0.027411644280489002, 0.035847001642520936, 0.03838610343102898, 0.008591933558428926, 0.039798453716295104, 0.005612112249114684, 0.019388907455972264, 0.03304324744801436, 0.059691492335072587, 0.027464412252551744, 0.08104252628982067, 0.0577821083632963, 0.07408328793410744, 0.022750777059367726, 0.012647433040131415, 0.05425518172393952, 0.04256013534697039, 0.016500198980793357, 0.02516149662967239, 0.04669531774041908, 0.031097460072487593, 0.018717754898326736, 0.03887726778962782, 0.042108882418168445, 0.04049536007057343, 0.01819470787553915, 0.030085102788039615, 0.0443473592666643, 0.046137633201267035, 0.0355406329035759, 0.03023235167243651, 0.03700601748589959, 0.011960516417665141, 0.04755475019503917, 0.07122665550559759, 0.11978246537702424, 0.1429689433425665, 0.16340735448258265, 0.13945419979946955, 0.13479038434369223, 0.11000130165900503, 0.10740770333047424, 0.14213106116013868, 0.11733283182340008, 0.1455989722162485, 0.20802343397268228, 0.11603756275560174, 0.13465421593614987, 0.11512445818100657, 0.08666599382247243, 0.0931030994813357, 0.22759079613855906, 0.0976625494658947, 0.09505867133183138, 0.12113428355327674, 0.14056432380207948, 0.155045143195561, 0.09080076230955975, 0.1588237282953092, 0.12042558086769921, 0.24203162267804146, 0.09164887680006878, 0.14448142504053457, 0.099959587279175, 0.14160447727356637, 0.2741844930819103, 0.1276188934487956, 0.15207826239722116, 0.18552766394402298, 0.20180327631533146, 0.12592897484345095, 0.15178109120045388, 0.14557841260518345, 0.1007368830697877, 0.12438362490917955, 0.11093980379934822, 0.09626376988100153, 0.10734455886163882, 0.09750801311539752, 0.1928383766540459, 0.17451026370482786, 0.12171166257134505, 0.1874321081808635, 0.14524175067033085, 0.11497503119919981, 0.22825907170772552, 0.2095676168267216, 0.1148831168455737, 0.1229806180511202, 0.2370168146278177, 0.1285038116787161, 0.1981926422033991, 0.12602702315364564, 0.12913611132119382, 0.11039292493036815, 0.15166378606642994, 0.15542012878826686, 0.11307953005390507, 0.24766715456332478, 0.1516775603273085, 0.1743728332221508, 0.13445651797311647, 0.21392601009990486, 1.6045858242682047, 1.2269632816314697, 1.540191222514425, 1.3422926302467073, 2.3658066860267093, 2.6244813885007585, 2.1942897524152483, 2.1464646501200537, 2.745321201426642, 4.413068430764334, 8.930299043655396, 16.452498742512294, 33.74109506607056, 47.01533317565918, 63.83811010633196, 63.57496098109654, 65.71389443533761, 60.17541585649763, 26.90710575239999, 20.578247002192906, 16.743293012891495, 14.074753965650286, 10.006135531834193, 5.952801832130977, 4.027049532958439, 6.056015585150037, 9.763633847236633, 7.698860253606524, 4.928918761866433, 2.805033585854939, 1.5368299228804452, 0.3029462625937802, 0.10006799003375427, 0.2046628671565226, 0.2031370454600879, 0.15779896399804524, 0.18734735915703432, 0.15324526120509419, 0.12008997744747571, 0.12275520871792521, 0.09798767630543027, 0.15350273810327053, 0.16424754368407385, 0.15622690692543983, 0.25197137360061916, 0.11366060708782502, 0.12070274885211672, 0.1423144963170801, 0.19917224320982183, 0.1252786261694772, 0.10527370391147477, 0.1222219073346683, 0.09876013414136, 0.18193178118339606, 0.14778750549469674, 0.13027892714100225, 0.10744809652013437, 0.1457468792796135, 0.05447082354554108, 0.1428758211966072, 0.13775737370763505, 0.14129936721708092, 0.13848170984004224, 0.09024091663637332, 0.16289709614855902, 0.17462363333574363, 0.1381909033017499, 0.12188126918460641, 0.10253364379916872, 0.21653979484524044, 0.10722901791866336, 0.1086409610829183, 0.2209376652858087, 0.1118741397346769, 0.062254651582666805, 0.13391542700784548, 0.10376209073833056, 0.11190931499004364, 0.07221295365265437, 0.15066479252917425, 0.15196299286825315, 0.10513997144464936, 0.14329795140240872, 0.1422266803149666, 0.11737492813595704, 0.18239376853619302, 0.09178118434335504, 0.0852982232879315, 0.14201493667704718, 0.08824316704911844, 0.16570328628378256, 0.1317226325294801, 0.11795058367507798, 0.14178627037576266, 0.13481045540954384, 0.10953501917954002, 0.10103041731885501, 0.10381057885076318, 0.132543415629438, 0.09723729121365718, 0.11254282921020474, 0.16195617163819925, 0.1647359939025981, 0.11247228192431585, 0.15225872557078088, 0.12156363337167672, 0.13661240014646733, 0.1865768555019583], [0.017164396554497734, 0.03141858694808824, 0.04742367758548685, 0.026130890773077096, 0.06494276983929531, 0.0545696623490325, 0.10884474550506898, 0.014033440899636065, 0.05102791989754353, 0.024214799482641474, 0.03892675334853785, 0.015475288798500384, 0.06561502162367105, 0.02726122663755502, 0.04441828992483871, 0.009397543767201049, 0.0909666098388178, 0.051652535130935054, 0.007956294675490685, 0.03680076064275844, 0.037968237817819626, 0.038106675924999375, 0.019360371665763, 0.015539015111114298, 0.04853541310876608, 0.04305620890642915, 0.014836554947708334, 0.027058212352650504, 0.05085005212043013, 0.04522954639313476, 0.06290030479431152, 0.013018819852732122, 0.060257974080741405, 0.04472910985350609, 0.012421605559731168, 0.012273615375826401, 0.023317056940868497, 0.03480118579630341, 0.01788116871778454, 0.0164634037230696, 0.0038093884691729075, 0.025545533879527023, 0.0438913124879556, 0.06271051854959556, 0.07107111492327281, 0.02501708741432854, 0.055253035322363885, 0.03317408935566034, 0.05755131146205323, 0.049845233360039334, 0.019822827207722833, 0.042528417227523665, 0.04695623141846486, 0.009975677655477608, 0.062047352349119525, 0.05243424818451915, 0.07516983284481935, 0.02788753990483071, 0.07116724976471492, 0.05991990079305001, 0.0641766291643892, 0.02378998227816607, 0.01487677002192608, 0.21480996481009892, 1.5717670938798358, 3.1146472692489624, 9.386754870414734, 14.928691046578543, 19.490699325289043, 26.03710617337908, 28.8115496635437, 30.588322162628174, 36.26052924564907, 35.35938957759312, 34.68597364425659, 35.619960921151296, 48.20837014062064, 64.63575635637555, 85.28132098061698, 87.69081033979143, 105.15608719417027, 96.26517227717808, 92.04466274806431, 93.8842886516026, 103.9501439503261, 102.12899330684117, 99.04295090266636, 89.90389496939522, 86.5823642185756, 83.26286928994315, 72.78914778573173, 66.77748993464878, 65.44430433000836, 69.14886842455182, 79.34422424861363, 68.08862890516008, 62.90832301548549, 48.72675439289638, 29.662036963871547, 14.497860176222664, 11.130396621567861, 5.759493393557412, 2.450789668730327, 0.7177375693406377, 0.07289897969790868, 0.06256380570786339, 0.03430230310186744, 0.041128640196153095, 0.024583696919892515, 0.012090727287743772, 0.05790191050618887, 0.02059201111218759, 0.054819190209465365, 0.029521861047084843, 0.06653982414198772, 0.06815305471952472, 0.018618826188945344, 0.041496545275939364, 0.021835367162046686, 0.02270622953905591, 0.02831855891937656, 0.004345714846359832, 0.06494645428444658, 0.0430877641774714, 0.03148382809013128, 0.01652059404711638, 0.015899418986269405, 0.0016974954030177156, 0.10315552792911019, 0.054785144714904685, 0.03291619176577244, 0.022492974464382445, 0.025016617528828125, 0.015822512130918245, 0.05482663034594484, 0.041155303229710886, 0.009651173371821642, 0.031953055411577225, 0.012145868436034237, 0.04906431419242706, 0.033061608605618985, 0.024048958738733615, 0.05423464925427522, 0.05060120279501591, 0.07209769090903656, 0.020948862856520072, 0.07603566388466529, 0.07142664691699402, 0.07005362452140876, 0.021524179128131697, 0.02868983122919287, 0.07885070890188217, 0.02093595881680293, 0.05130511502336178, 0.02302094256239278, 0.07723069975950889, 0.05293942768392818, 0.01687768497504294, 0.0715244102424809, 0.04650973502014365, 0.07209651704345431, 0.011119224596768618, 0.04893023906541722, 0.0631365231903536, 0.019629955325009565, 0.018156396092048714, 0.030733039270022085, 0.027424970708255256, 0.03598090374310102, 0.07944438633109842, 0.04086867646713342, 0.045080994721502066, 0.03866766832236733, 0.02253028710505792, 0.02568376503352608, 0.04061899932899645, 0.03631393890827894, 0.009976793845583285, 0.03141344025997179, 0.00792092434130609, 0.07790664955973625, 0.03734405006148985, 0.08707606646099261, 0.05030383821576834, 0.013060078174541039, 0.03344913013279438, 0.05660535561453019, 0.0605587415131075, 0.033435803705028126, 0.017542389753673757, 0.023471444013661573, 0.006165027111170015, 0.03942227390195642, 0.03909379170675363, 0.012058110957566117, 0.0572339402777808, 0.024083056819758246, 0.04441276664978691, 0.032446187521730147, 0.049866692030004094, 0.054470518204782686, 0.023058414658797637, 0.00893605683398034, 0.0431629696062633, 0.045254635225449286, 0.04470506596512028, 0.03701816326273339, 0.08370427667562451, 0.05643091443926096, 0.07854255900851317, 0.018784500691773634, 0.0597962581419519, 0.018126221639769416, 0.014154080185107887, 0.014373215613886714, 0.06751899088599853, 0.03000701019274337, 0.02455552584225578, 0.062166163830884864, 0.02279615748141493, 0.016115476410569887, 0.0794673343854291, 0.09174890643251793, 0.0753518905756729, 0.022337193002126048, 0.053876236879399846, 0.07265972146498305, 0.06305457651615143, 0.019626267487183213, 0.048122151355658255, 0.042874544725886414, 0.04197996076462524, 0.08671288059226104, 0.03337107824959925, 0.05812360146748168, 0.05344905158770936, 0.03309705188231809, 0.038167621940374374, 0.018156465641888123, 0.03520887677690812, 1.1438892079251153, 3.212983386857169, 8.299736993653433, 13.367211086409432, 20.178685631070817, 24.11701144490923, 27.551089116505214, 30.69063091278076, 35.27160256249564, 37.338094098227366, 37.730979987553184, 40.63133178438459, 57.79924658366612, 76.6844538279942, 97.92213003976005, 102.2620096206665, 119.2603119441441, 111.54928452627999, 112.27053533281598, 109.80555071149553, 121.30595888410295, 116.98869568961007, 112.2423951285226, 104.6494037083217, 98.64165074484688, 93.96426936558315, 85.04021154131208, 76.40801974705288, 77.42950221470424, 82.08667823246547, 93.07137026105607, 79.12505722045898, 71.44485201154436, 54.91146755218506, 32.68252658843994, 18.17104881150382, 11.97352317401341, 6.035080662795475, 2.8722819430487494, 0.8506201846258981, 0.18187857046723366, 0.11054974115852799, 0.018485215858423283, 0.02858208665358169, 0.004044561921286264, 0.020731989493859664, 0.08451723626681737, 0.028285351415563906, 0.024090020285387124, 0.03522236605307885, 0.0353915757233543, 0.05106110704530563, 0.07580600692225353, 0.04276630821238671, 0.03625907935202122, 0.05999787125204291, 0.031955206367586336, 0.026047858442845087, 0.06229116355202027, 0.029967370176953927, 0.044353683213038106, 0.01853801606089941, 0.01605927335497524, 0.04939109326473304, 0.05405663559213281, 0.05095516058749386, 0.02808339903796358, 0.02653711611804153, 0.05207530315965414, 0.033094663439052444, 0.04323475182588611, 0.03304755953805787, 0.04347095325855272, 0.01823587459512055, 0.011699339807299631, 0.044212435970881155, 0.01789767068943807, 0.012151440904874886, 0.04884834328134145, 0.053299587286476574, 0.07317156078560011, 0.04314990780715432, 0.06247254953320537, 0.05862604307809046, 0.0059493988602688265, 0.047895154250519614, 0.03414047249991979, 0.02599116853837456, 0.024758389153118645, 0.04471708621297564, 0.030811206504170383, 0.02584331575781107, 0.033071766274848154, 0.03942742059007287, 0.03456961875781417, 0.029118661968303577, 0.045352178027055094, 0.021334596443921328, 0.08195438914533172, 0.06658896364803825, 0.01344818324183247, 0.1113509281671473, 0.026883650737415467, 0.026432575924055915, 0.02179324540442654, 0.05585115376327719, 0.039926286321133375, 0.013693260760711772, 0.03402207831719092, 0.026823181392891065, 0.02866757188790611, 0.017686770131279315, 0.0710709181481174, 0.07920024264603853, 0.12193020513015133, 0.07899818170283522, 0.17343874834477901, 0.31140659004449844, 0.22803102965865815, 0.08240665309131145, 0.1271392913269145, 0.1239987462759018, 0.13429372385144234, 0.10607670939394406, 0.11865655864988055, 0.0839459097811154, 0.2029075242046799, 0.06948886625468731, 0.18325709578182015, 0.10993723438254424, 0.08468274452856608, 0.1173869382057871, 0.08495710337800638, 0.10785354154982738, 0.11989354155957699, 0.08905515633523464, 0.1537723879196814, 0.11052670489464488, 0.16941646060773305, 0.10673170603279557, 0.18066582482840332, 0.15844738563256605, 0.13184270608638013, 0.1332783369081361, 0.19313085238848413, 0.18385622863258633, 0.08421709308666842, 0.12383084957088743, 0.09484827119324889, 0.10388357564806938, 0.10334241004394633, 0.0837079950475267, 0.12794483453035355, 0.22621247438447817, 0.13611074563648018, 0.16680137307516166, 0.14927588562880242, 0.11856083092944962, 0.18513631208666734, 0.21154701204172202, 0.1229724892015968, 0.1818689624113696, 0.15045797505549022, 0.12559210934809276, 0.1126561106315681, 0.1075692760891148, 0.15104078235370771, 0.14118518334414276, 0.2218968966709716, 0.16778089265738214, 0.16134259956223623, 0.10931643590863262, 0.18454173899122647, 0.04696004478526967, 0.10144693604005234, 0.3429202804608004, 2.985522163765771, 7.518663934298924, 16.05115168435233, 25.272884232657297, 34.04194859095982, 39.11020088195801, 41.77024575642177, 47.39296429497855, 49.149058955056326, 52.355037689208984, 50.74225657326834, 56.744530882154194, 73.83672768729073, 93.45986488887242, 115.7056691305978, 121.18030766078404, 141.411321912493, 129.4124082837786, 124.52230780465263, 128.97604751586914, 137.00057765415735, 134.80436325073242, 134.21654564993722, 124.56538663591657, 120.1586584363665, 111.84754289899553, 105.7485600880214, 95.4214038848877, 94.9329524721418, 101.72142587389264, 113.91617447989327, 98.65238571166992, 89.02109854561942, 70.45673479352678, 46.29703187942505, 26.515182188579015, 17.90449333190918, 10.74372068473271, 5.3458428127425055, 2.223776170185634, 0.5283045428139823, 0.24791769683361053, 0.1255782943751131, 0.18073473684489727, 0.20583815766232355, 0.12120656110346317, 0.20161294724260057, 0.13933316272284302, 0.17670870359454835, 0.09919514294181551, 0.14712571672030858, 0.133452584700925, 0.1331017685255834, 0.10495731660297938, 0.09037243707903794, 0.141110965183803, 0.16306773413504871, 0.09961742921067135, 0.16318224370479584, 0.1283385612602745, 0.21332408168486186, 0.12360389317784991, 0.07335585089666502, 0.1100622680304306, 0.19296633478786263, 0.13602173541273388, 0.14460699473108563, 0.0872508299403957, 0.17518945011709416, 0.0644229780882597, 0.07796220800706319, 0.13479193140353474, 0.09284478798508644, 0.0908268994784781, 0.0890377111999052, 0.1357127848480429, 0.10466148890554905, 0.11858171623732362, 0.15088824768151554, 0.14910395842577728, 0.1757037118077278, 0.11373683371181999, 0.14094241708517075, 0.19795712269842625, 0.21452921416078294, 0.12126828064875943, 0.09040312043258122, 0.17334042862057686, 0.15361369214951992, 0.13041532625045094, 0.15572126262954303, 0.11827341706625052, 0.11504296612526689, 0.13949052856436797, 0.1311718520841428, 0.1505104393831321, 0.12217515627188341, 0.12821129523217678, 0.1582061800041369, 0.12233780111585345, 0.17212372033723763, 0.1445920126778739, 0.11516036625419344, 0.11106208259505884, 0.08778314066252538, 0.137044613382646, 0.12274252011307649, 0.14368299288409098, 0.10227223139788423, 0.10081785265356302, 0.11899456408407007, 0.131676709279418], [0.04267843114212155, 0.019183888100087643, 0.028122212937367812, 0.026884107052215507, 0.035673096509916444, 0.03601818584970065, 0.04473386299131172, 0.022697149044168845, 0.04824660824877875, 0.01793809441317405, 0.02197397659931864, 0.014068575442901679, 0.05873479188552924, 0.034316850892667256, 0.057246968150138855, 0.02246432162688247, 0.045868227657462866, 0.04716551536694169, 0.030523677290018116, 0.05078621215320059, 0.009069115006630974, 0.043700318450906446, 0.03019268112257123, 0.03510018903762102, 0.02436272181304438, 0.04186365646975381, 0.05548075845997248, 0.05209191369691065, 0.034605679501380236, 0.02136495240431811, 0.04139143341620054, 0.05977923369833401, 0.026518673536234667, 0.0842324144073895, 0.042164756384279044, 0.029995390280549015, 0.0057761111945313, 0.026412240229547024, 0.021454296806561093, 0.0340991497172841, 0.00596021386029731, 0.03981395484879613, 0.016182415586497103, 0.017627194756641984, 0.04208283685147762, 0.012981960982350367, 0.02369637837234352, 0.04727160092443228, 0.009099992590823343, 0.018758380486230766, 0.00879808352328837, 0.028419224678405693, 0.08886619790324143, 0.020623208456007496, 0.025621823268011212, 0.038639315736613104, 0.036239432370556254, 0.04775516569082226, 0.056285901327750514, 0.09138827864080667, 0.06046751926520041, 0.45881636866501396, 6.0797536713736395, 22.21202904837472, 40.31734963825771, 48.439863273075645, 54.94422830854143, 67.42876543317522, 63.507584299360005, 72.00493240356445, 75.33641297476632, 81.27698380606515, 77.53681714194161, 78.90934344700405, 87.30782563345772, 88.81073488507951, 90.3125741141183, 88.61902713775635, 80.44218553815568, 84.80649498530796, 68.54698766980852, 63.407578877040315, 54.25058964320591, 67.33634049551827, 63.43589278629848, 75.76746531895229, 73.3840525490897, 81.85960415431431, 87.02392223903111, 77.04394667489188, 94.27110181535993, 97.85205745697021, 88.70423984527588, 88.17980371202741, 82.31358555385044, 99.76064423152378, 92.31369699750627, 90.87358556474958, 80.20466831752232, 83.36633491516113, 82.04825469425747, 76.52047634124756, 57.784467765263145, 52.83265686035156, 36.63248716081892, 15.78947036606925, 5.151769638061523, 2.59620070031711, 0.29309314702238354, 0.03699495057974543, 0.05184659275359341, 0.012156192346342971, 0.06495285965502262, 0.031096092824425017, 0.022282989928498864, 0.06087229933057513, 0.04218170618904488, 0.014424458578495043, 0.08840015291103295, 0.0391715721759413, 0.03153021613668118, 0.027404151557545577, 0.03446917182632855, 0.040145853467817814, 0.038961087220481465, 0.0457196590224547, 0.04289309248062117, 0.03326475181217704, 0.04178909564922963, 0.055761193590504785, 0.053684801794588566, 0.01608711195045284, 0.06894922735435621, 0.08282079693994351, 0.03272104509440916, 0.019288560608401895, 0.04506743759182947, 0.011661616652937872, 0.0047954156263066185, 0.0631894353511078, 0.051391543421362124, 0.010501962986641696, 0.030720008004988943, 0.018387174333578775, 0.046289072039404085, 0.06682117190212011, 0.07492277824452945, 0.01176932645362935, 0.028092281061357686, 0.08343204842614275, 0.016050135184611593, 0.019693132024258375, 0.03186196887067386, 0.03193822602874466, 0.05084557718198214, 0.06426494728241648, 0.07382416898118598, 0.04232011376214879, 0.01629423476489527, 0.04375326453841158, 0.04730428256360548, 0.07304075280470507, 0.015749754517206123, 0.04691113598112549, 0.03139312492151346, 0.050107795878180435, 0.08929193112999201, 0.07482076050447566, 0.01996194724259632, 0.056991574354469776, 0.03261536665792976, 0.040503919789833684, 0.07598922494798899, 0.0558882458800716, 0.03734792110377124, 0.026069926097989082, 0.0190733869759632, 0.025181764470679418, 0.0038778339928415206, 0.05281048228165933, 0.024879629790250744, 0.012653340535637523, 0.019870258501863906, 0.005306252835518015, 0.028102396322148185, 0.001302844487197165, 0.043848330687199316, 0.04146211301641805, 0.05143732078639524, 0.024427700022767698, 0.041193833840744834, 0.020243188133463264, 0.05453548114746809, 0.06913653694625412, 0.005818950927018055, 0.008994584720182632, 0.03042648732662201, 0.04469994981107967, 0.061636777594685555, 0.02124387800826558, 0.10280649630086762, 0.03643497598490544, 0.009750965517014265, 0.027813396383342997, 0.029945429747125933, 0.04159614403865167, 0.025077088569690074, 0.02911309798115066, 0.02554411913401314, 0.07607184337185961, 0.048600599968007634, 0.023897004213982394, 0.05496959088902388, 0.03169185335614851, 0.01677875965833664, 0.04376846033015421, 0.05138160966868911, 0.02454025371532355, 0.034167695324867964, 0.029887408217681304, 0.018058675175000514, 0.06360330778573241, 0.04247530150626387, 0.023461988628176705, 0.00840902341795819, 0.0042296488869136995, 0.011660396986241852, 0.05700669211468526, 0.06040470049317394, 0.04713229429242866, 0.01797153940424323, 0.05408285418525338, 0.03696173968325768, 0.016786452549110566, 0.03714801111657705, 0.05848182724522693, 0.05595432162018759, 0.4156938668872629, 5.4089072687285285, 20.47738868849618, 43.42767252240862, 49.07273299353463, 60.44297708783831, 74.91574818747384, 68.0745518548148, 82.71309307643345, 86.79675088609967, 93.16904108864921, 91.51707213265556, 91.13921519688198, 101.24052715301514, 106.48068482535226, 106.16358293805803, 98.38807623726981, 95.84002590179443, 99.34863689967564, 85.73076520647321, 83.30793530600411, 74.09076077597481, 88.6103766305106, 81.25779288155692, 94.68592316763741, 91.54127965654645, 98.42376913343156, 103.53124400547573, 93.677079473223, 111.67062786647251, 112.56570870535714, 104.97086906433105, 106.73471791403634, 99.25829642159599, 112.80267701830182, 107.68844849722726, 104.58939211709159, 93.3870130266462, 95.56531497410366, 96.92641844068254, 86.49050903320312, 66.10359110151018, 58.558910506112234, 41.40086562292916, 19.709782975060598, 5.7896833164351325, 2.2676857454436163, 0.2866590608443533, 0.05703683264021363, 0.0815289273325886, 0.030590726727885858, 0.038873668161353896, 0.030808203986712863, 0.01720860819997532, 0.11164130722837788, 0.027535278449899385, 0.05547510287059205, 0.02118561220621424, 0.04973632509687117, 0.07328841808651175, 0.026379587428112115, 0.010265232296660542, 0.08419785661888973, 0.030803549236484935, 0.012851670384407043, 0.030627252267939702, 0.008753356191196611, 0.05440972146711179, 0.0242726462893188, 0.06753735882895333, 0.047154390785310946, 0.037836758087256124, 0.049593917559832335, 0.03100307924406869, 0.03359027220202344, 0.025991171931049654, 0.026841406843491962, 0.062026534894747395, 0.027544565897967135, 0.03782825265079737, 0.017786241668675627, 0.04996054020843335, 0.026240051790539707, 0.0635483328785215, 0.06161141395568848, 0.06224334718925612, 0.056261321396699975, 0.040801460788186104, 0.0183055804975863, 0.009154544261816357, 0.022000531067273447, 0.04908659728243947, 0.009464537225929754, 0.06503990891256503, 0.012019126576238444, 0.028651310796184198, 0.044786032156220505, 0.014850424203489507, 0.058983814237373214, 0.0310041784707989, 0.0703870023467711, 0.04372555995360017, 0.012598769356762725, 0.033392472458737235, 0.09119276556053332, 0.0567705687135458, 0.030864451147083725, 0.004209635496538664, 0.030457889927285056, 0.07401159392403704, 0.05662389658391476, 0.0635908634534904, 0.013022245606407523, 0.03341221443510481, 0.04314519877412489, 0.09144361995692764, 0.16335966704147203, 0.11277702557189123, 0.11823548695870809, 0.08878729785127298, 0.09142522487257208, 0.13537529510046753, 0.10570004781974213, 0.14417062886059284, 0.0788358829117247, 0.1366379809166704, 0.1353798819971936, 0.1696835184203727, 0.13957934879830905, 0.1505908322121416, 0.09700567328504153, 0.129176579149706, 0.1870494687131473, 0.09228598725582872, 0.11550200863608293, 0.12005126023931162, 0.13307100374783787, 0.12247269387756075, 0.11031208426824637, 0.18370852512972696, 0.16747104642646654, 0.16539846121200494, 0.156270903136049, 0.10721148457378149, 0.12999819006238664, 0.10854457518351929, 0.09782910267157213, 0.10165609445955072, 0.2639182582497597, 0.10632661384131227, 0.1288954485207796, 0.12840277781443937, 0.09644205495715141, 0.16746365039476327, 0.16267172752746514, 0.1682330819645098, 0.1539089905896357, 0.13061938887195929, 0.10538154348198857, 0.22175680633102143, 0.1438559650310448, 0.1776924572352852, 0.0933856482484511, 0.06507759474750076, 0.07856039090880326, 0.11901350878179073, 0.11941506580582686, 0.1351298147014209, 0.16140681611640112, 0.11007751471229962, 0.3397931568324566, 0.15960401642535413, 0.12485954937125955, 0.15863273425826005, 0.15661166342241423, 0.1946039790553706, 0.9109896080834525, 10.622439878327505, 38.30998379843575, 64.36198343549455, 70.57928712027413, 80.4550952911377, 93.63269438062395, 91.21467958177838, 95.99941757747105, 101.1997412272862, 109.3637911932809, 105.67458956582206, 107.40546921321324, 114.75032656533378, 119.96715218680245, 120.95620046343122, 113.51002447945731, 105.79447378431047, 110.79497419084821, 92.87358978816441, 84.81659766605922, 78.15253176007951, 88.98753179822648, 86.25048351287842, 97.24868283952985, 97.97998768942696, 107.63086182730538, 112.57169110434396, 103.60303279331752, 120.83580207824707, 125.92171669006348, 116.62876510620117, 114.12133393968854, 107.99909550803048, 125.82323292323521, 121.43434769766671, 122.70194925580705, 112.49891567230225, 111.6895478112357, 114.75209835597447, 107.25383867536272, 84.58575766427177, 77.17037609645298, 56.25402627672468, 29.392853328159877, 11.499201791627065, 5.481240621634892, 0.5737977645226887, 0.19712681296680654, 0.19396916883332388, 0.12948946521750518, 0.17658928143126623, 0.09727140795439482, 0.0875839227810502, 0.1457378411931651, 0.15163063284541878, 0.21783875514354023, 0.20040077157318592, 0.15780185455722467, 0.17388920060225896, 0.1348197784807001, 0.14535484888723918, 0.10973490202533347, 0.1389990792210613, 0.13395358781729425, 0.11873722289289747, 0.07484783405171973, 0.17241713245000156, 0.12673795143408434, 0.16820866827453884, 0.1024295836687088, 0.17364591865667275, 0.16506202997905867, 0.14531990433377878, 0.127459139164005, 0.1559871533619506, 0.11208779684134892, 0.19906635103481157, 0.15109221530812128, 0.13759466101016316, 0.08263925489570413, 0.18421074960912975, 0.07252216206065246, 0.13372592574783734, 0.15911684185266495, 0.16636651355241025, 0.07399558049759694, 0.09776380046137742, 0.13111458372856888, 0.14661214713539394, 0.14030483844024794, 0.19902407830314978, 0.12446165643632412, 0.16735878959298134, 0.15042651817202568, 0.19034667392926558, 0.1847691296466759, 0.11795967604432787, 0.12881407860134328, 0.11129037570208311, 0.21548100880214147, 0.09985847199069602, 0.09284649110798325, 0.1121413739664214, 0.1827697447900261, 0.1752326185149806, 0.09034400646175657, 0.08715168918882098, 0.16995638449277195, 0.10608622245490551, 0.09557716708098139, 0.12872885460300104, 0.15923406556248665, 0.11469426697918347, 0.10088130924850702], [0.09374722598918847, 0.014516408555209637, 0.032472619853381596, 0.04328166912975056, 0.012544569675810635, 0.03235557256266475, 0.010331733817500728, 0.02187229134142399, 0.009268816344306936, 0.004886703607293644, 0.026870061377329484, 0.03521523804270795, 0.02552082502682294, 0.055204509890505245, 0.05837311236453908, 0.021388975936653357, 0.03091738705656358, 0.04870327249435442, 0.020459939359820316, 0.020602178959442035, 0.021239762693377476, 0.02567323247369911, 0.018910380812095742, 0.006303878700626748, 0.05492991355380841, 0.038814981667590995, 0.05361312474789364, 0.013189646132689501, 0.019959209353796074, 0.04680603429941194, 0.05805615508662803, 0.008788254943543246, 0.022629134390237074, 0.05857545829245022, 0.02541742137899356, 0.030248337957475866, 0.06484485045075417, 0.04408440998356257, 0.029517436998763254, 0.0715518162718841, 0.015564660342144114, 0.05475109243499381, 0.012240027892403305, 0.07742376332836491, 0.03320760220023138, 0.03618511224963835, 0.023254172011677707, 0.005624115957678961, 0.04195488550301109, 0.07891812135598489, 0.020656283645491515, 0.02519479064669992, 0.038589684292674065, 0.019235821474077444, 0.06041864438780716, 0.10636279332850661, 0.1313791988151414, 0.027188489379893457, 0.07911322731524706, 0.46008799757276264, 12.142056941986084, 22.0939895766122, 37.509947368076865, 56.59562751225063, 68.29838112422398, 66.83299214499337, 67.35090391976493, 81.09623336791992, 76.92571612766811, 48.629455293927876, 58.329001562935964, 73.58637714385986, 63.28940391540527, 68.8065584727696, 65.22883374350411, 50.64692381450108, 55.365125860486714, 71.91270896366665, 47.69233785356794, 53.96121801648821, 52.32369089126587, 29.806927749088832, 34.60854639325823, 23.414237635476248, 45.445213999067036, 40.619637966156006, 52.74986907414028, 46.45054885319301, 51.31403425761631, 44.20584644590105, 55.7221416745867, 52.27137095587594, 57.52591139929635, 55.43531308855329, 58.80662073407854, 62.99404294150216, 73.2370912006923, 75.62431853158134, 97.83527060917446, 89.39862196786063, 84.35700212206159, 95.37500381469727, 90.01384326389858, 86.86876201629639, 78.09601511274064, 78.14462471008301, 60.029691287449424, 48.76030029569353, 25.014868089130946, 10.882199151175362, 3.730837404727936, 0.14621875967298234, 0.1441872122564486, 0.042863504961133, 0.04796692968479224, 0.06236660307539361, 0.04176002720903073, 0.10825999081134796, 0.020949198731354306, 0.02040924091956445, 0.04080659390560218, 0.03576461052788155, 0.03192051965743303, 0.01604248470227633, 0.05581165963251676, 0.062399579877299924, 0.05377191551295774, 0.061111747553305965, 0.03498363707746778, 0.02086762016239975, 0.042237590333180766, 0.03019829260717545, 0.03145732790497797, 0.04170555781040873, 0.0221326384427292, 0.008020243208323206, 0.024493755406833122, 0.01446310623681971, 0.006735751397042934, 0.055362157324062924, 0.0213625978878034, 0.0450172192150993, 0.01167719327245972, 0.05485468776896596, 0.046060500733022175, 0.0562931887938508, 0.04695829416492155, 0.025350000443203107, 0.07112870219030551, 0.02741637366956898, 0.032358317236815176, 0.03410933792058911, 0.05211196101403662, 0.08836833640400853, 0.05861025356820651, 0.04095777150775705, 0.04523500860003488, 0.043375310354999135, 0.03669063780190689, 0.036867911860878975, 0.06252882722765207, 0.02884998245696936, 0.03835598326155117, 0.08974506360079561, 0.03288223108808909, 0.03431603665064488, 0.07587991974183492, 0.05323071258940867, 0.04848962217303259, 0.021889923073883568, 0.07835548011852161, 0.04983692469873598, 0.04980423288153751, 0.03709409811667033, 0.03343607511903558, 0.03335909192849483, 0.04579032165929675, 0.02563754322805575, 0.046482247566538196, 0.05050565488636494, 0.02458526603212314, 0.028679249475577047, 0.041227387397417, 0.021376623206638863, 0.058145586002085886, 0.010361653819148029, 0.044260778198284764, 0.01829918530503554, 0.018966894297461425, 0.022899279537211572, 0.025370599070031728, 0.028566188578094755, 0.05590876477903553, 0.0642787418993456, 0.015960945149085352, 0.029838570659714084, 0.037019184457936456, 0.05985512784016984, 0.042358213503445895, 0.01995844769823764, 0.016737533566941108, 0.05006264955071466, 0.0571923732225384, 0.03948202908837369, 0.10001232302082436, 0.07357382348605565, 0.07736564680401768, 0.019834866115291203, 0.05684057656409485, 0.016144588955545, 0.03224212829289692, 0.04392670148185321, 0.05374579191473978, 0.007301733147219888, 0.027036048006266356, 0.004499453494125711, 0.03929539803149445, 0.06639763034347977, 0.02502947237475642, 0.030929183387862783, 0.03335798591641443, 0.012079876664626812, 0.04374017559790185, 0.05354497269062059, 0.0498371655786676, 0.08606711202966315, 0.024578316137194633, 0.023358973441645503, 0.058382537215948105, 0.045835335672433884, 0.02116844866291753, 0.027293002432478324, 0.09977767204067536, 0.03297491218628628, 0.03713226571146931, 0.5316946123327527, 10.799213341304235, 23.232811485018047, 45.04797853742327, 69.58570166996547, 79.59304618835449, 81.19258403778076, 81.69341714041573, 92.62722056252616, 88.98733030046735, 65.98381110600063, 74.60685212271554, 90.95123168400356, 80.15345314570835, 87.58379418509347, 83.74453231266567, 72.30652591160366, 82.29201139722551, 98.98684419904436, 77.54502296447754, 86.71839605058942, 73.33854184831891, 45.159073284694124, 55.93109485081264, 42.75918633597237, 59.49951594216483, 54.51771313803536, 71.56712641034807, 68.46700695582798, 72.21927043369838, 66.62493528638566, 84.25332805088588, 77.17302336011613, 77.80096680777413, 73.94334779466901, 73.34175886426652, 79.6877292905535, 90.30828707558769, 89.56698376791817, 113.81234754834855, 100.87576062338692, 97.62797110421317, 108.2640859058925, 102.43931375231061, 102.14908054896763, 91.03224767957414, 90.08167157854352, 69.75834356035504, 54.94965485164097, 27.810135330472672, 11.729476383754186, 3.5059355071612766, 0.2739502085106713, 0.022826637274452617, 0.05475669034889766, 0.008114792822327997, 0.037462909040706496, 0.06116468685546091, 0.026282921633017913, 0.04324638530878084, 0.020888361281582286, 0.06142927480063268, 0.046463465717222006, 0.02000919363594481, 0.04128173126706055, 0.013050809386186302, 0.013228497351519763, 0.004034663367617343, 0.05045944665159498, 0.028801823434020792, 0.0442816431501082, 0.0566894396740411, 0.08499678410589695, 0.09126013051718473, 0.04101552501586931, 0.037202124284314256, 0.008094499536257769, 0.041092911934746165, 0.07391960493155889, 0.0007257871371361294, 0.03122098058728235, 0.021079687800790583, 0.017163570438112532, 0.033284324154789956, 0.056614519229957035, 0.018055808364546726, 0.03413811119805489, 0.02854970356981669, 0.024560357011588554, 0.020423013484105468, 0.035023324590708525, 0.029977436243955578, 0.0704530713015369, 0.05055815653343286, 0.028072903797562634, 0.04610111105388828, 0.04351835910763059, 0.03768281884757536, 0.015735703753307462, 0.03896776739774006, 0.01064450029350285, 0.015901508874126842, 0.028980939715568508, 0.04043801368347236, 0.023475971538573503, 0.05890612876308816, 0.037530833788748295, 0.01654403403933559, 0.04080229877893414, 0.05438569454210145, 0.0447649500731911, 0.03567092180518167, 0.004043772700242698, 0.021795530371101837, 0.01902616602767791, 0.02315449182476316, 0.05564516070964081, 0.15600280037948064, 0.08529673051089048, 0.1194041006799255, 0.1622607252959694, 0.11173659390104668, 0.10285723714956216, 0.164209817137037, 0.10358963427799088, 0.1408925854734012, 0.20767522337181227, 0.11929151814963136, 0.08881321110363517, 0.09715435387832777, 0.18776887868131908, 0.11867213781390872, 0.0863982303334134, 0.1400581502488681, 0.19996319791035994, 0.10876288704041924, 0.11708560080400535, 0.09317086477364812, 0.16212195131395543, 0.09577803380255188, 0.09726804242070232, 0.10647203068115882, 0.16364946934793675, 0.18765212994601044, 0.0636142050581319, 0.21160050774259226, 0.20970957992332323, 0.24521780599440846, 0.12434209856603827, 0.10086223562913281, 0.13111697217183454, 0.12542399551187242, 0.1793551394449813, 0.1881771667727402, 0.14875665706183228, 0.1398943518953664, 0.1577409492539508, 0.10718629735388926, 0.24424798946295465, 0.10650061057614428, 0.147640589092459, 0.1294973769358226, 0.15110015416783945, 0.11397955247334071, 0.15451963139431818, 0.1382199310298477, 0.16564133603657993, 0.19765179551073483, 0.07023133962814297, 0.2189647840069873, 0.11497598114822592, 0.1212260757705995, 0.191941801192505, 0.2041454299220017, 0.1389207627092089, 0.12909879189516815, 2.0865288376808167, 21.32837278502328, 40.13801663262503, 64.29611451285226, 83.24624225071499, 92.25201783861432, 90.71633393423897, 89.92209230150495, 101.15908731733049, 100.05114146641323, 73.82670143672398, 81.61241504124233, 101.87305641174316, 89.51944419315883, 93.95650127955845, 87.83558300563267, 71.50629493168422, 76.29251984187535, 93.41909285954067, 70.91077177865165, 76.86257089887346, 73.014130456107, 48.497908524104524, 55.32983248574393, 39.694547857557026, 64.22142832619804, 59.98932920183454, 76.69327109200614, 66.02030999319894, 71.88877241952079, 63.42305946350098, 74.82068988255092, 73.75382178170341, 79.09285926818848, 75.29626628330776, 83.14065742492676, 89.66946274893624, 98.3202896118164, 99.69010611942836, 121.51430756705147, 112.98283685956682, 108.82179001399449, 116.88526480538505, 113.35697650909424, 112.80503940582275, 104.05158070155552, 107.78504235403878, 89.14470699855259, 71.94516399928501, 40.81527491978237, 18.38035113470895, 6.639878358159747, 0.5579919155154909, 0.26714360660740305, 0.10468181781470776, 0.11319395141409976, 0.10966664140245744, 0.17857802685882362, 0.21688136937362806, 0.10781226626464299, 0.10210547463170119, 0.10988075312759195, 0.0689706758462957, 0.13190376066735812, 0.228347688381161, 0.1765180081129074, 0.13735448675496237, 0.0760151246296508, 0.19342929923108645, 0.11909344020698752, 0.11707463567810399, 0.21332153039319174, 0.15117530870650495, 0.17358341201075486, 0.14097111911645957, 0.09628135750868491, 0.09387992029743535, 0.12599823969815457, 0.14037651887961797, 0.0822058202964919, 0.11710567186985697, 0.08207265779908214, 0.10764216432081801, 0.08132624213716813, 0.10284572241029569, 0.15101460447268827, 0.13110133872500487, 0.1238075215369463, 0.09881635076765503, 0.1362255130495344, 0.12971226897622856, 0.13128991717738764, 0.13205580679433687, 0.18653327998306068, 0.2353368704872472, 0.11218532946492944, 0.1256066028560911, 0.12220938157822404, 0.13716236634978227, 0.1696770859083959, 0.08370269568903105, 0.1265443925346647, 0.08570927301687853, 0.126919066001262, 0.19521422630974225, 0.2304288638489587, 0.1942457261362246, 0.20793806069663592, 0.11533461404698235, 0.09891398517148835, 0.21140359688018048, 0.12302882117884499, 0.09628366452774831, 0.07192224889461483, 0.14552931381123407, 0.19085127328123364, 0.1423240772315434], [0.04613813870985593, 0.02264592473927353, 0.036130239122680256, 0.03396928829274007, 0.03968883977670755, 0.009524211836313563, 0.030628415955496684, 0.031051553785800934, 0.021163982206157277, 0.03590845316648483, 0.039620826819113324, 0.01608997706456908, 0.021303465257265737, 0.04407087999529072, 0.10832265352032014, 0.0181063507417483, 0.06753374902265412, 0.019881298266617314, 0.041337194719484875, 0.013208331290765532, 0.061243580122079165, 0.053267132956534624, 0.04143267816730908, 0.014834502379276922, 0.09756479292575802, 0.021653501117335897, 0.03974603349342942, 0.036384957776005776, 0.017924250602456074, 0.0480684622723077, 0.05086041674283998, 0.05137722633246865, 0.06013759518308299, 0.012056052451953292, 0.07679664090807949, 0.04092131382120507, 0.03127257299742528, 0.04148677097899573, 0.07370788164969001, 0.03075960391600217, 0.012773602386005223, 0.018990067964685813, 0.09702728462538548, 0.06715737243316003, 0.03264237574434706, 0.05649772299719708, 0.04496776419026511, 0.04443933468844209, 0.005956180393695831, 0.008787937728422028, 0.041810137020157914, 0.014256283674123032, 0.0655414005741477, 0.07311547308095864, 0.03531148823510323, 0.14850471700940812, 0.04359501999403749, 6.1759262936455865, 19.341478075299943, 40.07569823946272, 63.10982077462332, 60.434118134634836, 39.18828821182251, 44.66684552601406, 52.21471187046596, 43.16568374633789, 34.84561892918178, 37.623057092939106, 53.698794978005544, 28.470398323876516, 25.931352853775024, 30.762214728764125, 30.581328800746373, 30.73729501451765, 33.44420548847744, 42.62173012324742, 32.043014390128, 26.698199476514542, 18.164223943437847, 12.790763344083514, 15.182946477617536, 22.20967013495309, 23.27875123705183, 30.897030626024517, 16.59931591578892, 19.353097200393677, 16.46023382459368, 20.206902265548706, 21.26317957469395, 18.947112219674246, 10.30372600896018, 24.931861434664043, 35.96417815344674, 30.269517966679164, 27.044669662203106, 22.61136634009225, 31.53061948503767, 40.87210076195853, 36.80565711430141, 50.056622232709614, 60.13733278002058, 51.97829941340855, 55.86864096777779, 68.32397133963448, 81.56003257206508, 78.884170123509, 83.32799475533622, 78.50528485434396, 80.02637754167829, 68.1650938306536, 52.526439326150076, 18.52185641016279, 1.931228131055832, 0.2757350541651249, 0.05330136165555034, 0.07273686411125319, 0.09618480197553124, 0.037346007635018656, 0.006898984446057251, 0.0329711870290339, 0.09043588010328156, 0.03845915451113667, 0.04603817693090864, 0.10254500926073108, 0.02255403752704816, 0.03615760783265744, 0.013962004732872759, 0.0339092820483659, 0.008465361332387795, 0.03713074579302754, 0.023397200408258607, 0.031771309806832244, 0.02090053928882948, 0.02275340468622744, 0.04969029328120606, 0.010158426643881415, 0.016703040239268115, 0.04584325078342642, 0.04062160151079297, 0.02965724913935576, 0.021831518172153404, 0.020390428536172425, 0.040459730196744204, 0.03690250696880477, 0.05155193552907024, 0.03742918245760458, 0.08537411742976733, 0.02190317995181041, 0.030474212087158645, 0.025072508458314196, 0.02445874978522105, 0.026240028041814054, 0.020151499392730848, 0.013304893609269388, 0.05292557539152248, 0.051524390399988206, 0.023253456157233034, 0.07693390854235206, 0.02448888013272413, 0.07356654959065573, 0.03111777880362102, 0.0657385014263647, 0.03857356569330607, 0.09223766199180058, 0.07390174588986806, 0.06204703343766076, 0.023857372679880688, 0.02372334844299725, 0.03524137521162629, 0.01364602878623243, 0.03375685254910162, 0.02328036176705999, 0.01567058983658041, 0.06247993877955845, 0.057220064236649444, 0.028385194450882927, 0.011671740395416106, 0.04559866265792932, 0.00511705521993073, 0.05775698221155575, 0.054584576548742395, 0.03464112277807934, 0.029399083528135504, 0.03203591810805457, 0.01556236350110599, 0.03561713433425341, 0.045756839348801544, 0.07151601676430021, 0.01088297990749457, 0.011716963058071477, 0.07308670319616795, 0.028137045712875466, 0.0779746048418539, 0.03815133709992681, 0.02306622968587492, 0.017100035811641386, 0.012877191782795956, 0.055237754713743925, 0.06529476666556937, 0.02091236785054207, 0.06737088704747812, 0.010912403730409486, 0.08617861568927765, 0.04745643386351211, 0.020840020750516226, 0.02642707639772977, 0.016467537697670714, 0.039732120132872036, 0.029915279043572288, 0.019675064333049313, 0.036929661940251074, 0.04730444880468505, 0.008211973455867596, 0.06194463571799653, 0.03222312252702458, 0.02539219514333776, 0.0265329414313393, 0.018460381476740752, 0.07079066282936505, 0.03065079404041171, 0.04065029675673161, 0.04123581140967352, 0.027071842424837605, 0.050160026111240895, 0.02104667028678315, 0.014855448755302599, 0.03807575847687466, 0.03524518179308091, 0.044961732013949325, 0.06910046602466277, 0.013076889727796828, 0.16239142471126147, 0.03626584434615714, 5.96332357610975, 19.977722883224487, 40.51786075319563, 71.00288404737199, 71.56944016047886, 48.93776076180594, 56.68315396990095, 64.61386953081403, 53.864349705832346, 49.79406370435442, 54.75237464904785, 74.29909556252616, 44.35098041806902, 44.77126652853829, 55.2340133530753, 47.5604749407087, 45.157471724918906, 53.74154724393572, 56.16616630554199, 39.36473076684134, 39.94634015219552, 27.290333645684377, 20.122448648725236, 28.77655679838998, 34.19418709618704, 32.07638658796038, 31.581070355006627, 29.5533185005188, 38.691745621817454, 33.061946868896484, 28.75584942953927, 33.92318650654384, 30.375467572893413, 25.208354575293406, 34.58375174658639, 47.75064713614327, 45.82759768622262, 53.4520331791469, 42.02550172805786, 57.75717871529715, 62.36677346910749, 52.06588840484619, 69.90941129411969, 79.03460557120187, 77.72200053078788, 70.53681973048619, 78.07144628252301, 93.26892839159284, 91.08656174795968, 92.74920313698905, 91.3136705671038, 90.17181055886405, 76.19383457728794, 60.78999791826521, 23.57473407472883, 2.9093963972159793, 0.3223154789635113, 0.09292979485222272, 0.057719669570880275, 0.08001263905316591, 0.03185380609439952, 0.07813420306359019, 0.11308824244354453, 0.10324706908847604, 0.02701199733253036, 0.03806761605665088, 0.03217344358563423, 0.026943594217300415, 0.042155463847198656, 0.03308281282495175, 0.03445080388337374, 0.027592058260259882, 0.019742922923926796, 0.05708636569657496, 0.030419148970395327, 0.0644521958061627, 0.028617903124541044, 0.057208691989736896, 0.004062613921373018, 0.020948737327541624, 0.04916877465854798, 0.05124153629211443, 0.016273227320717912, 0.04423890562195863, 0.050508158680583747, 0.048516828034605296, 0.06330469130937542, 0.06691471473979098, 0.01593198357815189, 0.07033940311521292, 0.04117102827876806, 0.03564157855830022, 0.018294326994302015, 0.051039305715156455, 0.017208487760009508, 0.014115087322092481, 0.020745731524324844, 0.034173286453421624, 0.04699740831607154, 0.008988557632879486, 0.09878783872617142, 0.06369771236287695, 0.07403429092041083, 0.029151316466076032, 0.0695508165018899, 0.05022833083889314, 0.05172349293051021, 0.055557358278227706, 0.024879263381340673, 0.11119485832750797, 0.058073132032794614, 0.05776567424514464, 0.06322279891797475, 0.051136597458805354, 0.038757642065840106, 0.026248021184333732, 0.009518492634275129, 0.06857483887246676, 0.003558800397773406, 0.11922760015087468, 0.11423607942249094, 0.1281591294599431, 0.21849172296268599, 0.08440193281109844, 0.08221835962363652, 0.12750052980014256, 0.0920537586456963, 0.1391828672162124, 0.07073023250060421, 0.2655419111251831, 0.17837036800171646, 0.08577794754611594, 0.06225859387112515, 0.20745123896215642, 0.19601379840501718, 0.24855055287480354, 0.15105413592287473, 0.13961312627153738, 0.09479577972420625, 0.14824338603232587, 0.1289207035941737, 0.12443633350942816, 0.10414683366460459, 0.23896871560386249, 0.1233613169086831, 0.11807680475924696, 0.20279992212142262, 0.1908985943134342, 0.17524617564465317, 0.17901539696114405, 0.28429208642670084, 0.13120622666818754, 0.09704903845808335, 0.1222073459731681, 0.19575581939092704, 0.10408790968358517, 0.10106035428387777, 0.10530372230069977, 0.0941955747881106, 0.0904180414176413, 0.08564259338059596, 0.23217934849006788, 0.12599218716578825, 0.08486515509762935, 0.09036072556461607, 0.09129126170384032, 0.1870302390307188, 0.06929098508719887, 0.07628547333713089, 0.1615690809807607, 0.1538902223110199, 0.1866234301456383, 0.19262971356511116, 0.24796573711293085, 0.3930034930152552, 0.1632383856922388, 11.64961986882346, 34.547093050820486, 61.6857179914202, 87.35202312469482, 86.262330191476, 60.361287117004395, 65.14685889652797, 75.29029778071812, 60.3362249646868, 51.830664089747835, 58.48062515258789, 74.40175519670758, 46.31668138504028, 42.83649199349539, 46.46643590927124, 47.348474979400635, 43.04426397596087, 48.252223696027485, 60.80171952928816, 44.498049463544575, 39.28577143805367, 31.20505816595895, 22.36205107825143, 25.807516847337993, 34.620778696877615, 35.582117557525635, 50.166719913482666, 31.11231361116682, 36.404759952000205, 29.11188554763794, 37.14520863124302, 35.63301311220442, 34.30583422524588, 23.46335792541504, 38.3798896244594, 49.047288690294536, 43.578111444200786, 43.396728719983784, 39.79518904004778, 48.82086426871163, 59.08256149291992, 55.28746584483555, 69.24000794546944, 79.47472531454903, 67.79580402374268, 72.70697838919503, 88.20861094338554, 103.11280958993095, 99.41247000013078, 106.25110939570835, 102.70162909371513, 104.11917277744838, 92.5464755467006, 76.50134795052665, 37.60597494670323, 6.836235753127506, 0.653542294033936, 0.21867738371448858, 0.21437186188995838, 0.163858295285276, 0.12382618124995913, 0.14378184186560766, 0.19091635836022242, 0.2072209713182279, 0.09974455274641514, 0.15731203369796276, 0.21431121442999157, 0.19872092242751802, 0.13972398532288416, 0.16611417994967528, 0.09441218352211372, 0.19108532715056623, 0.14849980441587313, 0.15459182752030237, 0.14318314327725343, 0.2555528985602515, 0.06129911142800536, 0.14870803324239595, 0.13598524379943097, 0.13678123322980745, 0.10407547892204352, 0.1092628248568092, 0.09239574708044529, 0.09071892420096056, 0.2657297024769442, 0.17489203464772018, 0.097614203845816, 0.14731956060443605, 0.23541121078389032, 0.1711132459874664, 0.1170258354395628, 0.10918562792773757, 0.1416042601423604, 0.22474141046404839, 0.06343296156930071, 0.14569284075072833, 0.0916869290439146, 0.09342285910887377, 0.22374616244009563, 0.07895734746541296, 0.18073534752641404, 0.2190447968563863, 0.14233559875616006, 0.08640606741287879, 0.1247135829180479, 0.1270959193685225, 0.16918057469385012, 0.11962799009467874, 0.2500859690564019, 0.22100321176861012, 0.18842635197298868, 0.11663935546364103, 0.1285370463239295, 0.12874819285103253, 0.1663552498711007, 0.06902150490454265, 0.14378769083746842, 0.16537666666720593, 0.12095927580126695], [0.07296984589525632, 0.09238978954298155, 0.04886704031378031, 0.11471323881830488, 0.04460676659696868, 0.04904536270935621, 0.01386658744221287, 0.029456514732113907, 0.07664415373333863, 0.0521317029904042, 0.04687411171783294, 0.10370415741843836, 0.035876707905637364, 0.022781214443966746, 0.04542058453496013, 0.043192781042307615, 0.03724626298727734, 0.0268783615569451, 0.02514545775816909, 0.07397709041833878, 0.034343639455203495, 0.04512009530195168, 0.028672854283026288, 0.015334246813186576, 0.05406354647129774, 0.02481309094998453, 0.057255476979272704, 0.010258994863501616, 0.06644995217876774, 0.03455471473612955, 0.030334386375865767, 0.06372732363109078, 0.04475352354347706, 0.02208370588985937, 0.04782905815435307, 0.031613604697797976, 0.05602105553927166, 0.033799698642854176, 0.04665555898100138, 0.039094561843999794, 0.05737713830811637, 0.03133296261408499, 0.03966002578714064, 0.0013468156768275158, 0.007458260149828025, 0.062227340548166206, 0.03528838751039334, 0.091827392578125, 0.0037907614106578486, 0.043481884457703145, 0.07050916579152856, 0.061140544579497406, 0.02640593155021114, 0.06868253595062665, 0.06477593843426023, 4.615047352654593, 27.206689493996755, 54.98830073220389, 64.2149178641183, 69.54083715166364, 64.36445004599435, 50.65510879244123, 48.104463304792134, 25.942947660173687, 33.44887120383126, 35.45266914367676, 24.510248218263897, 29.869065489087784, 30.67819016320365, 34.73785236903599, 27.630725894655498, 32.021158831460134, 33.20328712463379, 48.75261558805193, 49.777662481580464, 63.705017362322124, 82.56770896911621, 81.92659173692975, 80.48741831098283, 82.65506867000035, 61.753254481724326, 71.30763898577008, 77.44031361171177, 81.79209545680455, 72.61954920632499, 61.81580911363874, 49.369758061000276, 64.34316076551164, 60.61717537471226, 65.52595955984933, 62.3423297064645, 55.589351177215576, 51.65202590397426, 62.773840631757466, 43.62351792199271, 43.733775411333355, 40.33673511232649, 36.8649252482823, 48.92008107049124, 37.234409604753765, 28.520081417901174, 24.22638825007847, 29.71248435974121, 48.85172469275338, 35.72938115256173, 60.609580993652344, 76.80662400381905, 59.15522575378418, 76.25108773367745, 69.52908774784633, 82.3083188193185, 72.17740058898926, 58.510502406529014, 21.040832008634293, 3.2108704830918993, 0.3281383407967431, 0.1975252351590565, 0.04167112894356251, 0.026954225164705088, 0.054833558188485246, 0.04314196216208594, 0.05083652213215828, 0.04982774751260877, 0.0733021991327405, 0.043306761354740174, 0.0674955067890031, 0.015395102922671607, 0.09318463903452669, 0.10232012918485062, 0.031751425338110754, 0.03427188776965652, 0.02103852617022182, 0.01935488740647478, 0.05924795434943267, 0.08050807818238225, 0.07071464655122586, 0.02660596537004624, 0.04641184616567833, 0.028252885211259127, 0.05396682808973959, 0.019727584639830247, 0.050245877754475386, 0.024188740345250283, 0.0685902348320399, 0.013797121571509965, 0.03090289354856525, 0.06504260948193924, 0.04316364135593176, 0.02459243475459516, 0.052261343891067166, 0.01060132765477257, 0.03851386478969029, 0.03432443691417575, 0.09503957057105643, 0.04303454328328371, 0.04244398372247815, 0.016533679594951015, 0.058511262094335895, 0.08134767027305705, 0.09530700836330652, 0.031094522015856843, 0.07825977953949145, 0.03371984524918454, 0.09131146847669568, 0.007908513935815011, 0.04013294433908803, 0.01296321560429143, 0.10503395034798554, 0.032981748426599164, 0.012355366123041936, 0.048425595608672926, 0.06734770829124109, 0.007619111965011273, 0.007999141617412013, 0.05906333175620862, 0.04183938866481185, 0.027216368687472174, 0.05202142747917345, 0.037261350213416984, 0.033911850303411484, 0.03274261572265199, 0.04429838600169335, 0.05794402038944619, 0.0447038513874369, 0.06841830084366457, 0.017388372482465844, 0.07874482351222209, 0.04626473638096026, 0.0330945345173989, 0.018789289452667748, 0.042508271522819996, 0.06222446355968714, 0.03977360237123711, 0.01870096454929028, 0.007877236864130412, 0.04199415910989046, 0.04146577710551875, 0.021311504200899174, 0.03574212048468845, 0.05381896173847573, 0.036589878744312694, 0.008799477912751692, 0.04304451774805784, 0.06629310880920716, 0.06304192183805363, 0.017489516608683125, 0.013549619986276542, 0.061955756906952174, 0.015609643821205412, 0.03829310002869793, 0.06267167241977793, 0.037929045635142496, 0.06414371343063456, 0.04096314889777984, 0.04437801208613174, 0.05239841475018433, 0.042385059741458724, 0.017542097983615737, 0.042058633507362435, 0.014020177236359035, 0.0374932293780148, 0.05594515800476074, 0.052800361931856186, 0.04642083336200033, 0.04021888079919985, 0.05078161168577416, 0.04611052233459694, 0.013426624487952461, 0.0684594539925456, 0.10076424160173961, 0.06412390020809003, 4.834622153214045, 28.34176458631243, 63.06343460083008, 74.83746978214809, 80.3404847553798, 76.40408706665039, 66.35407366071428, 61.347132274082725, 37.84519100189209, 40.735120500837056, 42.41296107428414, 29.507588931492396, 31.282780715397426, 38.45881073815482, 35.46239314760481, 30.352271011897496, 33.05350480760847, 32.25313833781651, 38.37969160079956, 39.38933433805193, 58.86570821489607, 56.38370050702776, 54.87955100195748, 47.81978171212332, 46.571794918605256, 35.37517588479178, 48.64738164629255, 45.49238184520176, 58.55649948120117, 50.865552357264924, 47.61130101340157, 29.805326189313615, 49.17293643951416, 46.72838994434902, 43.83668865476336, 34.45908716746739, 47.483825887952534, 50.3573784828186, 52.93330499104091, 38.682157107761924, 42.79400028501238, 40.52428783689226, 40.1448849269322, 44.40323781967163, 45.980294772556846, 44.31532226290022, 28.307226828166417, 43.90243945802961, 68.75010435921806, 54.600476605551584, 70.93427058628627, 90.4064164842878, 73.90172113691057, 87.78804343087333, 83.3265495300293, 91.75642367771694, 83.96387304578508, 67.19299915858677, 26.278054067066737, 5.101006533418383, 0.05425817406337176, 0.05627738571326647, 0.035052118224224875, 0.049894135378833325, 0.018802542937919497, 0.05827832780778408, 0.06130497397056647, 0.055011955222913196, 0.03936713614634105, 0.02956348917047892, 0.036230282325829775, 0.041097207061414204, 0.017984775926119516, 0.0848207992634603, 0.06967604013958148, 0.038929806756121774, 0.03269983408972621, 0.07993006812674658, 0.03649515186303428, 0.04738356259518436, 0.04951244925281831, 0.03698714742703097, 0.026993071294522712, 0.03052193345502019, 0.09365812755588974, 0.06686537845858506, 0.05597923403339727, 0.014429198145600302, 0.07242533511349133, 0.047046320512890816, 0.08918964197593075, 0.023533848879326667, 0.05742247123271227, 0.03842105816251465, 0.015646199895335094, 0.0361317726118224, 0.040434217280043025, 0.0263506275535162, 0.03766284277662635, 0.04026581167376467, 0.0072910301054694825, 0.04852757602930069, 0.042735716461070945, 0.017139792874721543, 0.07564764363425118, 0.016020573110186627, 0.01600229337678424, 0.015110265796205826, 0.01781731009084199, 0.03460977446021778, 0.013053539641467589, 0.03734525785382305, 0.05789853818714619, 0.004260694832607571, 0.04182554994310651, 0.049561741429248025, 0.021987494713227664, 0.05332450648503644, 0.06638215974505458, 0.02443420547725899, 0.042998482539717636, 0.13813796399959496, 0.18026071228086948, 0.21130018814333848, 0.1599472194377865, 0.13777714621807846, 0.17430879308709077, 0.16917581137801918, 0.11696293524333409, 0.20155847445130348, 0.2113529374556882, 0.1378318497112819, 0.1864103837204831, 0.13264093468231813, 0.18988258311791079, 0.15955467335879803, 0.18516314136130468, 0.1485821378550359, 0.10138774064502545, 0.08152623354856457, 0.16557782515883446, 0.08717570254313094, 0.18730326795152255, 0.07931939339531319, 0.08757787703403405, 0.12447652992393289, 0.048451088169323545, 0.10535026301762887, 0.0706346540578774, 0.18267510272562504, 0.08854391412543398, 0.11762654249157224, 0.15335249687944139, 0.13042289870125906, 0.1381017573709999, 0.1467727292329073, 0.14180583932570048, 0.17934443216238702, 0.21283466794661113, 0.19479521736502647, 0.15106727236083575, 0.15264897820140633, 0.11000557642962251, 0.11742709390819073, 0.13538412962641033, 0.07704236557973282, 0.16573962861938135, 0.07725791579910687, 0.12511594061340603, 0.13235451148024627, 0.16749057466430323, 0.15228689834475517, 0.07860305719077587, 0.11161536683461495, 0.23105542308517865, 0.39734343013593126, 9.85313011918749, 46.90730605806623, 80.44654900687081, 86.87708595820835, 91.69017260415214, 83.72716876438686, 72.64960016523088, 72.98287051064628, 46.73709256308419, 51.26012665884835, 51.99990831102644, 37.95964867728097, 44.01121350697109, 44.083294119153706, 51.50736093521118, 41.908615657261436, 47.56588063921247, 49.853800841740195, 71.26348318372453, 68.66601031167167, 85.41791561671666, 108.51560374668666, 114.39408547537667, 115.03434113093785, 113.10987077440534, 89.24204431261334, 99.04905142102922, 106.19138268062046, 115.02759443010602, 100.648818561009, 80.95544896806989, 71.3791151046753, 90.2507073538644, 85.19603184291294, 96.15220151628766, 94.2585950578962, 84.82623481750488, 76.4053099496024, 85.3627747126988, 57.13437693459647, 61.163727624075754, 52.720033509390696, 55.1915077481951, 70.77221775054932, 55.68213742119925, 41.2362836429051, 34.77642181941441, 45.59840440750122, 65.11575875963483, 49.16862160818917, 80.00025231497628, 99.15564373561314, 79.62448678697858, 99.08526543208531, 90.04159436907086, 105.25561319078717, 98.82235949380058, 86.4464852469308, 38.36030960083008, 9.760144983019147, 0.645543886082513, 0.36333319225481575, 0.13750787638127804, 0.15694083433066094, 0.22628158996147768, 0.1433577574789524, 0.18893433042934962, 0.17563276418617793, 0.16264130201722893, 0.11681192048958369, 0.14990186132490635, 0.15508411824703217, 0.12338564917445183, 0.2645029111632279, 0.1298166819448982, 0.11273455606507403, 0.16436016692646913, 0.18947795911559037, 0.10053539209600006, 0.25496623718312805, 0.15427358102585587, 0.06979498732835054, 0.16983686733458722, 0.11858205550483294, 0.17020202774022306, 0.1980287759963955, 0.1464331088853734, 0.14250758024198668, 0.19929158394890173, 0.07213087805679866, 0.12602289766073227, 0.23446164173739298, 0.15025697941226618, 0.12836452201008797, 0.13644379776503357, 0.11061331988977534, 0.08508217095264367, 0.17166294077677385, 0.1724253970065287, 0.18469320157808916, 0.12435941477971417, 0.11273556708225183, 0.09073353305991207, 0.12000274498547826, 0.12315682002476283, 0.09765937392200742, 0.1305530552885362, 0.21424304880201817, 0.1383307222276926, 0.128319915117962, 0.11599698636148657, 0.14624260339353765, 0.13681993686727115, 0.09425823071173259, 0.1267438954008477, 0.1571563777646848, 0.1795605727072273, 0.1537410667432206, 0.15054401329585484, 0.11158021872064897, 0.21595826319285802], [0.05078582538823996, 0.0419841982158167, 0.050596419123134444, 0.028771452206586088, 0.056839253420808485, 0.12038552016019821, 0.023158732668629715, 0.050087592498000176, 0.04442534329635756, 0.07369712008429424, 0.040234253010047336, 0.024273265452523316, 0.04783970097612057, 0.03752199247745531, 0.010641166142054966, 0.0290600636840931, 0.043484822514333894, 0.07028423143284661, 0.07710853631475142, 0.022903148883155415, 0.011162696639075875, 0.06757347724799599, 0.02715125137807003, 0.0846629584474223, 0.03113337493102465, 0.016929793071800044, 0.06009832836155381, 0.02698251498597009, 0.09851898279573236, 0.00583589225009616, 0.007267053222416767, 0.03421707231817501, 0.009240420501945274, 0.05478685123047658, 0.05279019069192665, 0.04322861786931753, 0.021814851655757854, 0.0362475917541555, 0.019311276264488697, 0.029654942120292356, 0.029200388118624687, 0.08113058656454086, 0.058101379445620945, 0.03202397249905126, 0.021161307081846253, 0.029419975621359687, 0.06343748061252491, 0.0641608125131045, 0.0574780296800392, 0.06809762519385133, 0.029683511837252548, 0.07306600109274898, 0.20871321910193988, 7.196557606969561, 25.34507254191807, 55.00524044036865, 63.68008027757917, 70.53939751216343, 65.94877134050641, 68.5537691116333, 54.800904342106406, 28.586857080459595, 23.666144575391495, 41.36468287876674, 45.733578136989046, 49.636224951062886, 57.088935715811594, 44.46049097606114, 49.59517846788679, 66.06798158373151, 89.10822200775146, 76.8618413380214, 67.47390093122209, 41.052649702344624, 55.57034437997, 43.72499636241368, 35.97238050188337, 35.49364614486694, 41.4444968359811, 47.91934939793178, 68.35066631862095, 73.94555732182094, 71.86290427616665, 47.63649518149239, 61.468857765197754, 78.18143626621791, 70.07721029009137, 48.0917272567749, 61.00603130885533, 57.08620854786464, 73.1826868057251, 55.18855823789324, 59.087682315281455, 72.63757978166852, 102.99275861467633, 74.87994412013462, 89.74198804582868, 68.13919789450509, 62.78715338025774, 71.3077779497419, 60.76198278154646, 74.88262612479073, 45.655400480542866, 35.815361636025564, 37.26626014709473, 35.94819729668753, 26.376322439738683, 33.85285684040615, 39.19484036309378, 45.76914249147688, 61.979974201747346, 70.22920908246721, 76.70793873923165, 71.36601080213273, 57.30116149357387, 19.59178171839033, 5.233782700129917, 0.06129601052297013, 0.2501326251242842, 0.0867740505241922, 0.031034614159060375, 0.022769497840532234, 0.014349809548418437, 0.11817428310002599, 0.08694451209157705, 0.02276845459294106, 0.044401757419109344, 0.059388987853058746, 0.10479252080300025, 0.03400006664118596, 0.04404606596965875, 0.01523947243445686, 0.06814903779221432, 0.015242135684405054, 0.006533010646567813, 0.06266334000974894, 0.016832681139931083, 0.014644105453044176, 0.030361300467380455, 0.002359079026583848, 0.0571148098845567, 0.03364855496745024, 0.04407843887539847, 0.029169704765081406, 0.053897583591086526, 0.030802877486816475, 0.006128638974457447, 0.040184373900826485, 0.047629304230213165, 0.06922027495290552, 0.06768289101975304, 0.061224967906517644, 0.026662477159074376, 0.013919063644217593, 0.011863246726404344, 0.03406816780833261, 0.018873505826507295, 0.03181052913091012, 0.023828395841909305, 0.05125827914369958, 0.04656191097040262, 0.0370129385430898, 0.09997283906808921, 0.028478118125349283, 0.03673831506499222, 0.0429248038147177, 0.009629680775105953, 0.044539500027894974, 0.03611238008098943, 0.049946311329092295, 0.04233452245326979, 0.01790612862844552, 0.03497948783582874, 0.04747407238132187, 0.02395261524777327, 0.01704650618402021, 0.05293990944379142, 0.13264340454978601, 0.06764031973268304, 0.023123752492080842, 0.05041198651971562, 0.015984441120443598, 0.032490146412913284, 0.04300826022933636, 0.011998524556734731, 0.017058648568178927, 0.02028802572749555, 0.025546320980148654, 0.013152279209212532, 0.023145657298820357, 0.01604849482620401, 0.05140225748930659, 0.07254103211952107, 0.020669447224853293, 0.04039810564635055, 0.022026844655296633, 0.04993093911824482, 0.061714788765779564, 0.023450887795271616, 0.10063068555401904, 0.04067255949069347, 0.059800329352063794, 0.02653663944719093, 0.019819833171953048, 0.09727148259324686, 0.03340591763013175, 0.022632311630461897, 0.04264716085578714, 0.012240151725044208, 0.03228438745385834, 0.034762991060103686, 0.09740474687090941, 0.06052241953355925, 0.037396327792001624, 0.083207521188472, 0.027902106355343546, 0.01944554816665394, 0.029146424228591577, 0.02552534407004714, 0.02513766647981746, 0.04085282928177288, 0.04700480434777481, 0.05346440004983118, 0.023905348498374224, 0.018690817058086395, 0.02802143691639815, 0.014821562716471297, 0.015608256217092276, 0.07361252712351934, 7.2158688221658975, 31.138171332223074, 64.65958172934396, 77.9876788003104, 77.15902968815395, 77.44065407344273, 79.11100101470947, 70.9537602833339, 43.84765291213989, 36.30725588117327, 43.54230737686157, 48.89039141791207, 44.668961252485005, 41.55343416758946, 38.77959169660296, 34.34324680055891, 51.02132749557495, 58.76701600211007, 57.022587367466514, 54.43211480549404, 44.0338750566755, 43.00881774084908, 34.02136107853481, 40.786992277417866, 39.806170667920796, 43.66551978247506, 49.37432650157383, 57.241452148982454, 58.25228302819388, 55.92106860024588, 45.42646428516933, 50.967392104012625, 51.54655572346279, 49.395303113119944, 40.70530578068325, 44.893520082746235, 49.59189544405256, 58.975871903555735, 49.22401959555489, 47.35955040795462, 54.9792993409293, 60.70194339752197, 52.59494856425694, 53.97372824805123, 50.44487019947597, 65.56031145368303, 57.261084284101216, 41.98632778440203, 51.128281116485596, 40.976115294865195, 34.85503026417324, 40.89612763268607, 58.75221633911133, 49.87718152999878, 47.722225529806956, 57.13753489085606, 59.46592140197754, 75.3785399028233, 75.78300843920026, 89.30708639962333, 82.52417850494385, 69.31065722874233, 27.495996849877493, 8.864253810473851, 0.5501104870012828, 0.3352693910045283, 0.020935322690222944, 0.0167080936288195, 0.02249787687989218, 0.23165600800088473, 0.05377314705401659, 0.052543149662337134, 0.05328053402315293, 0.008331660247806991, 0.020405005164710537, 0.04138726381851094, 0.02105204089145575, 0.03171044521565948, 0.021901861897536685, 0.022965986314894896, 0.03150019096210599, 0.0038701402538988206, 0.02303187545788075, 0.0526034103573433, 0.10259296133049897, 0.0589140404814056, 0.007448355234893305, 0.055922226913805516, 0.059919887222349644, 0.0420198959431478, 0.0348975275909262, 0.0205256877067898, 0.019032785136784827, 0.04618993807317955, 0.053685229271650314, 0.07850504959268229, 0.049668824433216026, 0.08481117763689586, 0.037461826777351756, 0.037013050501367876, 0.0679708748523678, 0.03818190170984183, 0.05608026450499892, 0.04160000829558287, 0.0873457637748548, 0.06283524685672351, 0.03427213543493833, 0.08427216977413211, 0.06620561850390264, 0.05222554099080818, 0.014734678003670914, 0.004902801850611078, 0.06713743707431213, 0.020608699680971246, 0.049788514617830515, 0.0659109918134553, 0.03675105795264244, 0.024856907348813753, 0.0060232752085929465, 0.006035161021697734, 0.018871522807915295, 0.048400411781455786, 0.021022170083597302, 0.12575993819960526, 0.2630772819476468, 0.15823231717305525, 0.1701698787510395, 0.14399224200419017, 0.1528744553881032, 0.1390490736812353, 0.1528201318745102, 0.09587222803384066, 0.09188432845153979, 0.16423805776451314, 0.08863658843828098, 0.19103297138852732, 0.06728868252996888, 0.05992433162672179, 0.10665046503501278, 0.1618206410535744, 0.16408951287823065, 0.18696940158094677, 0.11075550011758294, 0.11211314012429544, 0.1333418884979827, 0.17056158344660485, 0.15957851707935333, 0.18576403840311936, 0.06885468707020793, 0.15419295749494008, 0.08165377099066973, 0.2261176151888711, 0.1301057378628424, 0.08134890520679099, 0.11813196965626307, 0.08098277449607849, 0.11820660850831441, 0.08315439868186202, 0.21165588977081434, 0.15882043061511858, 0.0940976282581687, 0.16345368485365594, 0.12119209473686558, 0.09977512074900524, 0.14116835567568028, 0.09836161695420742, 0.1500773440514292, 0.08984854697648968, 0.14268098665135248, 0.239915597651686, 0.1788282027201993, 0.11816760631544249, 0.1797233261168003, 0.18539142768297875, 0.17436484007963113, 0.36967361345887184, 13.437156864574977, 46.360878876277376, 84.03167356763566, 88.32137325831822, 88.82048320770264, 84.41316441127232, 86.35512338365827, 75.14363520486015, 42.24477992738996, 39.05921152659825, 64.03654370989118, 68.89786475045341, 72.23745386941093, 79.60673413957868, 65.41725499289376, 73.40935094015938, 90.41069657461983, 116.59952708653041, 112.59766347067696, 95.46876975468227, 63.44399438585554, 77.00854560307094, 63.99075508117676, 52.57050827571324, 52.78794520241873, 61.948846272059846, 69.68101011003766, 94.7631801877703, 108.29638808114188, 102.91436903817313, 74.73246165684291, 91.55858761923653, 115.07976845332554, 96.85287175859723, 67.28180408477783, 80.32149532863072, 80.48916925702775, 100.93589728219169, 76.92585509163993, 82.89355863843645, 96.87006160191127, 130.1991250174386, 98.03066090175084, 120.44453511919293, 91.36188411712646, 84.27774402073452, 90.45661721910749, 81.01828152792794, 97.91093649183, 62.37700816563198, 50.860494068690706, 55.27418088912964, 52.446715695517405, 38.30820158549717, 48.1480667250497, 55.897215434483115, 60.83297252655029, 79.68728460584367, 88.90725231170654, 96.6213299887521, 96.69582857404436, 83.07109206063407, 41.37511212485177, 14.784425599234444, 1.1751445936305183, 0.39394304688487736, 0.1480433131967272, 0.13214265927672386, 0.17063648014196328, 0.26055641578776495, 0.18323682115546294, 0.1566771420517138, 0.16560128889977932, 0.12593600446624414, 0.09614080576492207, 0.1641822550445795, 0.16253557269062313, 0.18615973288459436, 0.1062740884455187, 0.1693107041397265, 0.11965335373367582, 0.05549314172406282, 0.13951469798173222, 0.15661060490778514, 0.2880893855222634, 0.13230024224945477, 0.1256065485732896, 0.16126568083252224, 0.15456232481769153, 0.12065757199057511, 0.10550218022295407, 0.08771571463772229, 0.12291142104991845, 0.11761075976703848, 0.21281254770500319, 0.12752323358186654, 0.14308311364480428, 0.14999054585184368, 0.18178913955177578, 0.14140052321766103, 0.29475903191736763, 0.12227836144821984, 0.15921472731445516, 0.19476941946361745, 0.1737074346414634, 0.09915962841893945, 0.07633334398269653, 0.1369980794510671, 0.1824791689536401, 0.22527809095169815, 0.10643108109278338, 0.13156306823449476, 0.16255139612725802, 0.12481947509305817, 0.11567650070147854, 0.1456405528421913, 0.12488396306123052, 0.07952098614935364, 0.08833479641803674, 0.1083975230742778, 0.12471134375248637, 0.09994870357747589, 0.1448739439781223], [0.005447630695666054, 0.021208584009270583, 0.09088293968566827, 0.018498488003388047, 0.06311619428119489, 0.047846533823758364, 0.007935780865539397, 0.029950433942888464, 0.04281911180753793, 0.03128613351977297, 0.07941178272345237, 0.013347714257958745, 0.01551949535496533, 0.012947263246003007, 0.035137552568422895, 0.019100891392944113, 0.04987901083326765, 0.05856270183409963, 0.005821792292408645, 0.030669311261070625, 0.03289984246449811, 0.03673602840197938, 0.04381919100082346, 0.024481268666152443, 0.09494812440659318, 0.004130483114360166, 0.029907581063785722, 0.018812318931200674, 0.01943147704670472, 0.08839032772396292, 0.10151417207505022, 0.04237690714320966, 0.05112428883356707, 0.017684948264754245, 0.007785385274993522, 0.014778032998687454, 0.03134444003392543, 0.016093627582969408, 0.012276961401637112, 0.048852872502590926, 0.014190742280334234, 0.043190609730247936, 0.04958176160497325, 0.0727299769808139, 0.03297994691612465, 0.056605386148606024, 0.02685957122594118, 0.04114149504208139, 0.05049812314765794, 0.06822609222893204, 0.6500597809042249, 9.52265989780426, 32.43765122549874, 58.46123273032052, 69.50421319689069, 74.69633797236851, 69.46290615626744, 62.85871287754604, 40.13741908754621, 19.01200839451381, 28.96076396533421, 35.11657435553414, 39.95643241064889, 35.03353990827288, 27.689842905317033, 36.432844570704866, 49.992882932935444, 42.94644376209804, 34.99490097590855, 35.82181303841727, 45.17391463688442, 23.878643069948467, 12.728660345077515, 5.9132987175668985, 1.850535443850926, 2.933740713766643, 0.8112554912056241, 1.6906155965157916, 2.315938161952155, 2.863963212285723, 3.2362594178744724, 4.5485270363943915, 3.080937432391303, 2.946478064571108, 2.0983329585620334, 1.2073615448815482, 0.8192575361047472, 1.95782561813082, 1.9613826615469796, 2.325330606528691, 1.6191226499421256, 3.0676535623414174, 5.000444820949009, 6.323120840958186, 10.755680271557399, 12.208063091550555, 16.32138102395194, 17.48868359838213, 18.594077723366873, 35.525024209703716, 52.5426390511649, 48.65789079666138, 68.2183587210519, 63.50572913033621, 52.52087034497942, 35.07913746152605, 34.34740877151489, 36.33153288705008, 30.626933302198136, 26.74627579961504, 34.54433809007917, 66.22834600721086, 70.75797394343785, 73.74770041874477, 73.74800613948277, 68.52115426744733, 58.3876929964338, 28.854821307318552, 6.035776351179395, 0.7567877482090677, 0.14717448981744902, 0.02641926985234022, 0.1529531247381653, 0.013187277197305645, 0.12020819181842463, 0.03353308866332684, 0.03551380702161363, 0.008365951711311936, 0.07022943294474057, 0.07212232851556369, 0.015073814895004034, 0.019131366096969162, 0.013840407864855868, 0.04127662529104522, 0.048924895602145364, 0.025739006265731793, 0.036105112970939705, 0.09492041303643159, 0.07048781907984189, 0.04350997580747519, 0.010089779256044753, 0.008598637484413172, 0.07217640097119979, 0.04593795391597918, 0.015436773454504353, 0.030704506872487918, 0.015207528702116438, 0.04542840804372515, 0.013974422771882797, 0.038487167829381566, 0.035663759868059836, 0.041482044982590845, 0.03271777794829436, 0.025480218098631928, 0.0520739698383425, 0.056822571637375016, 0.09788199447627578, 0.028245470519842844, 0.07323347710605178, 0.05904245323368481, 0.056478082801082304, 0.04706868841978056, 0.02888648085562246, 0.09130358389977898, 0.08937480061181954, 0.02601052205344396, 0.05040993055860911, 0.06233596043395145, 0.047515748002167256, 0.037759815608816485, 0.0513453182232167, 0.04875258841950979, 0.011494160995685627, 0.01780047733336687, 0.03572582207354052, 0.022013648845521466, 0.06340340458388839, 0.06213442874806268, 0.03953543318701642, 0.02767102446939264, 0.02143625625675278, 0.06812277848699264, 0.02228137501515448, 0.013168178981037011, 0.011226220239352967, 0.02805059865516211, 0.036412977879600864, 0.04943158823464598, 0.08727897557296924, 0.04829440764816744, 0.04302511503919959, 0.006960161163338593, 0.023108515988237092, 0.13471942315144197, 0.06386340382908072, 0.030290695506014993, 0.06378677008407456, 0.031275222676673105, 0.07015788142702409, 0.026099091229428138, 0.07368767487683467, 0.0600266411368336, 0.09163027136985745, 0.029133657592215707, 0.030532800193343843, 0.06173638653542314, 0.04775392057906304, 0.016928593761154583, 0.0384926741410579, 0.05496361978085978, 0.03212027358157294, 0.011423209981460656, 0.023618857442800487, 0.07173217766519104, 0.024093382426404526, 0.01108687459158578, 0.015863198786973953, 0.04136407488424863, 0.0272126655826079, 0.01334941738085555, 0.023526094920401062, 0.06444582436233759, 0.09374987906111137, 0.08387686884296791, 0.06303073958094631, 0.02341632322142167, 0.4115993965949331, 9.641071966716222, 36.34109708241054, 70.07755770002092, 81.3888498033796, 83.59493064880371, 74.09706974029541, 77.02829933166504, 59.675444330487935, 41.85944325583321, 41.52735410417829, 30.610525131225586, 34.6612936428615, 44.20261900765555, 35.784449100494385, 41.91327442441668, 49.61569997242519, 43.957031454358784, 42.73129974092756, 38.271577630724224, 45.45587600980486, 25.39392532621111, 14.125509687832423, 5.670090922287532, 2.653327703475952, 3.282337482486452, 1.575506853205817, 1.694147669843265, 2.748001686164311, 2.900166366781507, 4.361609637737274, 5.473978451320103, 4.2181093607630045, 3.6379803759711127, 2.123600082738059, 1.8214024071182524, 1.5484642471585954, 2.221316073622022, 2.3106586166790555, 2.5894859177725653, 2.334482252597809, 2.915371848004205, 4.782957519803729, 6.236100733280182, 10.359832712582179, 10.621381146567208, 13.36809698172978, 13.860828484807696, 14.790352412632533, 26.911691563470022, 37.515380859375, 42.19015319006783, 48.37546042033604, 50.9426599911281, 48.67863464355469, 31.871897629329137, 26.598305225372314, 33.736290386744905, 37.49764558247158, 39.95992388044085, 48.576176507132395, 84.87311431339809, 79.00870268685478, 83.36971868787492, 83.45215906415666, 81.14162594931466, 73.80396693093437, 40.515234334128245, 9.621884516307286, 0.6200460600001472, 0.23334181468401635, 0.0711972817246403, 0.09348181701664414, 0.039870609130178175, 0.10432179391916309, 0.08509356355560677, 0.0390240247361362, 0.01335714165387409, 0.12508802568273886, 0.11817549089235918, 0.015921630830104862, 0.01865213716934834, 0.021905700709404688, 0.004194491443091205, 0.04864432815728443, 0.026761495774345737, 0.06782558014882462, 0.061919787765613625, 0.1126988786937935, 0.04001034323924354, 0.04015190600018416, 0.032912208765212975, 0.13958903827837535, 0.03442063621644463, 0.03237521954412971, 0.008381616540386208, 0.036083521986646314, 0.05121419811621308, 0.02023203471409423, 0.060643348044582775, 0.03625174438846963, 0.023974365687796047, 0.038642511636550934, 0.03109681885689497, 0.08709577790328435, 0.05180741074894156, 0.046665614869977744, 0.02557014943366604, 0.034395459174577675, 0.04660508276096412, 0.014794585860467382, 0.02057842175210161, 0.008295963368644672, 0.06333956800933395, 0.017754776303523352, 0.03519154359985675, 0.027600085329530493, 0.030643167306802103, 0.06486880952226264, 0.0709054505984698, 0.034778068108218055, 0.027847258673448647, 0.07605426931487662, 0.048226560931652784, 0.061905151765261374, 0.06554513251675026, 0.14805102135453904, 0.14415732957422733, 0.1819067703826087, 0.10941134938704115, 0.21037037803658418, 0.2381794165287699, 0.12390703548278127, 0.0988969878692712, 0.13360825420490333, 0.1082121269511325, 0.11600017547607422, 0.18748480321041175, 0.16902039971734795, 0.21007189048188074, 0.14084502016859396, 0.09110695123672485, 0.08489385034356799, 0.132844834455422, 0.09440922510943242, 0.08800762718809502, 0.12075636668929032, 0.13604656979441643, 0.12761054746806622, 0.10857458000204392, 0.17645991194461072, 0.11631075452480998, 0.20021414730165685, 0.0733864935381072, 0.1576997350369181, 0.13352208025753498, 0.15075526838856085, 0.13062175017382416, 0.19482113740273885, 0.14136271524642194, 0.1432520281523466, 0.0827680476275938, 0.10075507459363767, 0.06564535213900463, 0.13505204101758345, 0.19886046993945325, 0.14700200621570858, 0.10042632437710251, 0.09003929674093213, 0.29513439748968395, 0.1324050080563341, 0.18754359148442745, 0.17179484798439912, 0.1689376998692751, 0.1849620642938784, 0.1293382469032492, 2.2047124845640997, 15.901847055980138, 48.66801084790911, 83.84714330945695, 93.70473330361503, 92.01148509979248, 87.57917363303048, 80.09137793949672, 55.661251136234824, 27.731690168380737, 39.86667210715157, 51.64179120744978, 57.93300288064139, 54.231718335832866, 44.270933696201865, 57.428581033434185, 71.09894289289201, 60.924118995666504, 52.193773474012104, 51.49049070903233, 60.44300488063267, 33.61226504189627, 17.96794775554112, 8.551804610661097, 3.2953034724508012, 5.289852925709315, 2.269110777548381, 2.996489678110395, 3.5837381780147552, 4.910008805138724, 4.95987776347569, 6.369325058800833, 4.9566351260457715, 4.735827020236424, 3.518576668841498, 2.148889354297093, 1.8639504611492157, 3.6814556888171603, 3.0450955842222487, 3.931763674531664, 2.5209716856479645, 4.446709871292114, 6.576152086257935, 9.844968591417585, 15.542533125196185, 17.39949131011963, 22.77336880138942, 23.741673231124878, 24.694311210087367, 45.75669131960188, 71.54036889757428, 62.56139251164028, 87.20435306004116, 85.45993832179478, 73.05345031193325, 48.56677559443882, 50.15726341520037, 48.8352644102914, 43.22791876111712, 37.21985312870571, 49.37808200291225, 86.93759781973702, 89.57145840781075, 92.25444275992257, 91.96768365587506, 91.52910641261509, 88.09523023877824, 54.58326244354248, 15.608686923980713, 1.7734639623335429, 0.36612167262605255, 0.2333789441202368, 0.2222750713782651, 0.08347135595977306, 0.17534307044531616, 0.1344995235225984, 0.10294077838105814, 0.06298188505960362, 0.27110589827810017, 0.2502477860876492, 0.08463716054601328, 0.15371088550559112, 0.1523905513542039, 0.12323730784867491, 0.11282037717423268, 0.16033667139708996, 0.15406897557633265, 0.2285755675818239, 0.21597015112638474, 0.1234499200114182, 0.08533923394445862, 0.08641505800187588, 0.22903493578944886, 0.20075802026050432, 0.06824290632669415, 0.12475672417453357, 0.08342232501932553, 0.08478635004056351, 0.09973225090652704, 0.0741419947839209, 0.12641036829778127, 0.06883021909743547, 0.12263185105153493, 0.1109269116339939, 0.20655782547380241, 0.09777460952422448, 0.19184604633067334, 0.14419462185885223, 0.13238385133445263, 0.2992714526397841, 0.13043556016470703, 0.1201484671660832, 0.18214792172823632, 0.22337379599256174, 0.17065997102430888, 0.11397071794739791, 0.1240020575267928, 0.23002063004033907, 0.11078947436596666, 0.10806447094572441, 0.14356400498322078, 0.09135013818740845, 0.13851915140237125, 0.14692397468856402, 0.13794569431671075, 0.07220426161906549], [0.022121948123510395, 0.012211259703950157, 0.006205202321455414, 0.029611407313495874, 0.03556791679667575, 0.053178774126406224, 0.02477310148866049, 0.031945309934339354, 0.048722274867551665, 0.005624075245577842, 0.013310683209316006, 0.0475168811556484, 0.015311890780659658, 0.06423052520092044, 0.05133465504539864, 0.017892415435718637, 0.010443904985939818, 0.04663105368880289, 0.1015668942459992, 0.05132995279771941, 0.10690145513841084, 0.06810952669807843, 0.04079240573836224, 0.005548451669580702, 0.0292739786340722, 0.028897262777068784, 0.028124762532700385, 0.024542520022285835, 0.06920599857611315, 0.004233018237365676, 0.04324135736429265, 0.0010838958675906593, 0.010923363767298204, 0.00872752775571176, 0.01009362400509417, 0.024554770972047533, 0.06725031816001449, 0.061265551085983, 0.08105935395828315, 0.024201814018722092, 0.010190280470331865, 0.025330799598512903, 0.06844412588647433, 0.0946366021941815, 0.07443340521837984, 0.033714301618082185, 0.0763580562280757, 0.06296208540775947, 2.119831119264875, 12.058061037744794, 40.604074001312256, 67.00853143419538, 67.77368790762765, 71.02059500558036, 60.77382946014404, 56.252709593091694, 41.05394901548113, 26.015344415392192, 23.302223988941737, 23.96733856201172, 41.01940952028547, 71.72291891915458, 56.830573899405344, 48.06646013259888, 28.91913730757577, 23.58105172429766, 15.737386669431414, 12.112309966768537, 6.539302749293191, 3.484776722533362, 0.8976959128464971, 0.25818227604031563, 0.06781684061778442, 0.045151616646242995, 0.13109994094286645, 0.013172049175149627, 0.08206437967185463, 0.07095876309488501, 0.04101488380027669, 0.13001361994871072, 0.08246981113084725, 0.12747279128858022, 0.06210199477417128, 0.004456751589064619, 0.06246373536331313, 0.13812284623937948, 0.08285771603030817, 0.09278515832764761, 0.04035174134852631, 0.09295135869511537, 0.13252384667950018, 0.042906066070177724, 0.036110402151410065, 0.08530639963490622, 0.030355994323534623, 0.07044380251318216, 0.007990843134133943, 0.44691676433597294, 2.700074315071106, 3.4737516684191565, 6.972075641155243, 13.088678649493627, 26.92632794380188, 30.491269724709646, 47.54185724258423, 80.37209211077008, 77.80827631269182, 66.07576356615338, 50.96165984017508, 33.620029653821675, 25.105262415749685, 21.27481085913522, 38.537617206573486, 61.531217847551616, 73.43091814858573, 64.43279947553361, 63.63181114196777, 68.08022853306362, 66.86506502968925, 37.1160192489624, 7.188460350036621, 0.13156533454145702, 0.2559258485479014, 0.07327942749751465, 0.06675584933587483, 0.0644218720761793, 0.12712757981249265, 0.02233096065797976, 0.02207633699955685, 0.04618362769750612, 0.06938757454710347, 0.018983705002548437, 0.03708390312801514, 0.05406947347468563, 0.051147433663053174, 0.01849437438483749, 0.06274241648082222, 0.06171658009822879, 0.06374424629445587, 0.049953771821622334, 0.037431072177631516, 0.02826678330477859, 0.032520324257867675, 0.022668263808424984, 0.08892910488482032, 0.02414589934051037, 0.035838679410517216, 0.033576464014393945, 0.033299794753215144, 0.03138164410899792, 0.028504367252545695, 0.06106895234967981, 0.0857953926814454, 0.01644872870695378, 0.03639906451904348, 0.03704315370747021, 0.08653405947344643, 0.013960380489671869, 0.03109021671116352, 0.07858028555555002, 0.04740985921983208, 0.05222351895645261, 0.005470976965235812, 0.013658778459232832, 0.04705662406714899, 0.022749104470546757, 0.007801905058191291, 0.00568114173698372, 0.052991681665714295, 0.02579139425818409, 0.05955121200531721, 0.008659920222791178, 0.038112864164369445, 0.01264876890594938, 0.03808203831847225, 0.031108995167804614, 0.012982700585520692, 0.022961630120075176, 0.032538437750190496, 0.015504857658275535, 0.060810403366174014, 0.08690525205539805, 0.033114999133561335, 0.007888729551008769, 0.03589067215632115, 0.08220920618623495, 0.0103179171481835, 0.06363626423158816, 0.01718323607929051, 0.03487116311277662, 0.04524213321773069, 0.07515787705779076, 0.007858604292518325, 0.04443115494879229, 0.031736999683614285, 0.03377711360475846, 0.042714349393333705, 0.03607894526794553, 0.0022772042346852167, 0.03645289948742304, 0.018053891503119042, 0.03529928817546793, 0.03897932963445783, 0.029000627409134592, 0.010799757587457342, 0.03553989330040557, 0.03128674080861466, 0.1162733401038817, 0.01797141387526478, 0.03131400773833905, 0.029211068259818212, 0.016982320163931166, 0.0324468660567488, 0.07721315962927681, 0.040123916430664916, 0.06736365386417933, 0.020810662236596857, 0.04538150431056108, 0.045103515298771005, 0.1237997862377337, 0.027610673868496503, 0.07962012011557817, 0.024477302628968443, 0.05993785482964345, 2.1867281581674303, 14.597793510981969, 48.04792581285749, 78.47015476226807, 80.36765916006905, 80.62506212506975, 69.43607221330915, 79.32884093693325, 60.998165948050364, 43.77417571204049, 32.129283223833355, 20.80041912623814, 36.935220173427034, 59.217898505074636, 56.916926111493794, 45.24656500135149, 35.756322792598176, 29.99427202769688, 23.657351630074636, 17.83056971005031, 10.22396068913596, 4.884814637047904, 2.5069109201431274, 0.5757337063550949, 0.031061697884329727, 0.11452539318374225, 0.029105091267930608, 0.06538769882172346, 0.010345181533401566, 0.04598328684057508, 0.13025728187390737, 0.03436335089749523, 0.12556566005306585, 0.16229372923927649, 0.07092782189803463, 0.0326642449279981, 0.03546815179288387, 0.48009853810071945, 0.07279694160180432, 0.2724306971899101, 0.13906060877655232, 0.12885728771133081, 0.15487317528043473, 0.14162234988595757, 0.05492213414981961, 0.07341864252729075, 0.056255872760500224, 0.05455895167376314, 0.028358105636600937, 0.527050718665123, 1.9248994077954973, 2.8678344445569173, 5.766399468694415, 11.48369254384722, 21.27154346874782, 24.862893615450176, 32.06024939673287, 48.393042836870464, 54.856257166181294, 53.8042755808149, 44.205523354666575, 27.50248646736145, 36.26617118290493, 38.597521100725444, 59.92254311697823, 79.18055943080357, 83.4593643460955, 72.15996755872453, 70.96857384272984, 81.05941486358643, 79.84806592123849, 49.2038767678397, 11.512531042098999, 0.5699453141008104, 0.27842224282877787, 0.009901310217433741, 0.014693694488544549, 0.08153129541980368, 0.009640170926494258, 0.03022305913535612, 0.09697970574987785, 0.0690617420311485, 0.01931887924937265, 0.015094111573749354, 0.03509701688640884, 0.03333462056304727, 0.026262894671942507, 0.04254879702680877, 0.017272616104621972, 0.05892212861882789, 0.07529421509908778, 0.011307006618673248, 0.012684585376908737, 0.02092983334192208, 0.02070170986865248, 0.014559083318869983, 0.10236645277057375, 0.04260605859703251, 0.08648860441254717, 0.013137725481231297, 0.04746239818632603, 0.0186764558644167, 0.004382429103965738, 0.059250960259565284, 0.022863586898893118, 0.058710276415305476, 0.02567227404298527, 0.02362543244713119, 0.03524015724126782, 0.07049091319952693, 0.06109748474721398, 0.03970017470419407, 0.048781785781362226, 0.05137870214613421, 0.024875360108645897, 0.004988287084935499, 0.013536621799825557, 0.020976704844672765, 0.032463340887001584, 0.028246693579213958, 0.0876667108386755, 0.09255871083587408, 0.04726265783288649, 0.036018759211791415, 0.019617575453594327, 0.030353371785687547, 0.05637667913522039, 0.06286696836884532, 0.16868107792522224, 0.1042134997301868, 0.18315344277237142, 0.13906698700572762, 0.17192820725696428, 0.17066647138978752, 0.11468528317553656, 0.13949922738330706, 0.17144878155418805, 0.1630818069513355, 0.11442503785448414, 0.17436239735356399, 0.10349185738180365, 0.15689975582063198, 0.0948526748855199, 0.15040678637368338, 0.060244444092469554, 0.14356327216540063, 0.1863068121352366, 0.1622325660926955, 0.15879522982452596, 0.1147921931530748, 0.10641053505241871, 0.15814059280923434, 0.08030790356653077, 0.08186206767069441, 0.1404077722025769, 0.12062532800648894, 0.1984444601195199, 0.19215625897049904, 0.13836117487932953, 0.14636963871972902, 0.07057355197944812, 0.09772686780031238, 0.1177933399698564, 0.12310561777225562, 0.12740292932306016, 0.2706448473036289, 0.1318586788007191, 0.172413400507399, 0.10782794720892395, 0.11948475135224206, 0.11424732953310013, 0.30999436868088587, 0.10428995705608811, 0.1719710635287421, 0.16216024783040794, 0.12869248512600148, 4.519214757851191, 23.91133781841823, 63.44120815822056, 89.78379535675049, 89.01707553863525, 88.78278228214809, 77.29383168901715, 75.099472454616, 55.134925092969624, 37.53908463886806, 35.86766767501831, 34.90552282333374, 59.7813070842198, 96.70436791011265, 79.1290454864502, 66.2226345879691, 47.207423073904856, 38.39061764308384, 27.064798593521118, 20.954248768942698, 11.925530229296003, 5.857941550867898, 2.62949538230896, 1.1432342316423143, 0.36271906378013746, 0.17560214868613652, 0.3762023417013032, 0.19607640004583768, 0.1943603442715747, 0.22493374800043447, 0.3104380763002804, 0.42809053882956505, 0.6037998689072472, 0.3052694850734302, 0.2176930872457368, 0.10214824269392661, 0.09326159847634179, 0.3768435301525252, 0.17464439650731428, 0.2480784553502287, 0.17488497788352625, 0.3006877994963101, 0.4058456639094012, 0.2530596894877297, 0.1432334091514349, 0.14824040047824383, 0.11554183864167758, 0.22719374458704675, 0.09053751107837472, 0.978739104100636, 4.405504882335663, 5.237226401056562, 9.13599612031664, 17.49408061163766, 33.23436641693115, 36.49214397157942, 57.47863585608346, 106.3045688356672, 100.06120940617153, 89.83053588867188, 69.01497663770402, 49.38262612479073, 36.48778050286429, 32.1126457623073, 56.00422811508179, 79.43492603302002, 91.50370379856655, 83.0380116871425, 80.47777421133858, 91.54759556906563, 95.91017491476876, 63.284866741725374, 15.795671633311681, 0.9099162199667522, 0.33435407440577236, 0.24966117899332727, 0.20406529493629932, 0.17040180202041352, 0.13319012735571178, 0.08247430981802088, 0.15613763885838644, 0.1123972563073039, 0.2329260627073901, 0.09929471795580216, 0.11239829446588244, 0.09955366048961878, 0.13831968924828938, 0.10977538342454604, 0.0842091745830008, 0.17163060179778508, 0.21270890826625483, 0.12527523349438394, 0.14850532769092492, 0.09688365233263799, 0.10938410620604243, 0.1381879856011697, 0.17692816896098001, 0.11844675562211446, 0.15309823623725347, 0.0875456194792475, 0.11659238726965018, 0.10018963100654737, 0.13254584478480474, 0.17081418846334728, 0.18562412448227406, 0.19774054789117404, 0.16747424911175454, 0.10670847977910723, 0.12485346969749246, 0.1574895248881408, 0.18875909197543347, 0.13567239844373294, 0.11768106956567083, 0.1050676531823618, 0.0759164249258382, 0.10351374013615505, 0.12352131546608039, 0.07074676839900867, 0.149721303156444, 0.0964871911065919, 0.11992111722273485, 0.11844849267176219, 0.14213760223771843, 0.10792333566184555, 0.08012978812413556, 0.0851357209363154, 0.12463384148265634, 0.22677975680146897], [0.06629838781165225, 0.048844265285879374, 0.05860122905245849, 0.03704636996345861, 0.03308295192463057, 0.020471750958157436, 0.006346818517028753, 0.03148375345127923, 0.04040048730426601, 0.05331512573840363, 0.036627802066504955, 0.024777802040002177, 0.023711046603109156, 0.007135028967500797, 0.03886502701789141, 0.03624019232977714, 0.039921326230147054, 0.04980467053662453, 0.039765100327453444, 0.02424436664607908, 0.02483458354670022, 0.027066029076065336, 0.027335324357928972, 0.014723005505012614, 0.03532936084749443, 0.06830406268792492, 0.018320823786780238, 0.013917340165270227, 0.10089437783296619, 0.04558567889034748, 0.06494007605527129, 0.04687765027795519, 0.039157119380044084, 0.0187141841077911, 0.022958456272525445, 0.02434604681496109, 0.045170958286949565, 0.008577272113013481, 0.03224434031705771, 0.05302878735320909, 0.027632972225546837, 0.09380708634853363, 0.05360805609130433, 0.0498107128909656, 0.016579178760626485, 0.11577533611229487, 0.4396131219608443, 8.451207722936358, 47.124381678445, 59.378228187561035, 60.612693786621094, 71.97692421504429, 65.02108955383301, 65.6230536869594, 46.648166043417795, 19.53545962061201, 14.468173129217965, 26.34121319225856, 47.59273542676653, 78.89052772521973, 58.26936864852905, 32.21984951836722, 25.220890862601145, 13.750909720148359, 7.615255185535975, 2.8268984811646596, 1.9598223567008972, 0.5778126833694321, 0.08105773904493876, 0.09326081137572016, 0.032876144628971815, 0.028891478266034807, 0.02678620462704982, 0.030659984797239304, 0.029868829928870713, 0.055698673373886516, 0.040505639876105955, 0.03521929228944438, 0.03906813290502344, 0.05338392240394439, 0.04114277068791645, 0.13402152274336132, 0.05565443289067064, 0.14093978436929838, 0.17380096390843391, 0.27043393147843225, 0.18462243037564413, 0.07924419135919639, 0.09274172530110393, 0.07204834105713026, 0.05156709400138684, 0.10268097410776786, 0.08359662030956574, 0.04642953896628959, 0.02914302816082324, 0.05545922175848058, 0.17139215102153166, 0.06348478807402508, 0.07668250453259264, 0.021122645852821212, 0.17554559957768234, 0.8362305739096233, 2.529058737414224, 7.9176260232925415, 12.131662436894008, 15.060117959976196, 22.07774642535618, 32.683120659419465, 51.93272965294974, 71.04960373469761, 55.90493140901838, 35.08514417920794, 17.43705674580165, 24.162569046020508, 36.437597138541086, 54.46500757762364, 60.640632493155344, 67.18477943965367, 65.06197275434221, 67.03224563598633, 68.15766620635986, 50.156575543539866, 11.850276027406965, 0.15791260504296847, 0.3889495719756399, 0.029397305766386644, 0.038261364945875745, 0.06665571113782269, 0.034351069413657696, 0.09080398535089833, 0.03241673570924571, 0.10126977733203343, 0.0276182819423931, 0.023324100134362067, 0.03287660603278449, 0.02885386028460094, 0.0104923846166847, 0.06085821294358798, 0.010098026849196425, 0.08868209099663155, 0.021843397623992393, 0.010328869551553257, 0.0519945439217346, 0.03596639327172722, 0.036918252373912504, 0.03330813394859433, 0.040864622220396996, 0.04223744784082685, 0.01922746531532279, 0.03271125044141497, 0.0026241714201335397, 0.010691120738296636, 0.00932476919011346, 0.014256963905479227, 0.05089290499953287, 0.01083389892508941, 0.021764419540496807, 0.009194229230550783, 0.037453908273684125, 0.018447893039722527, 0.05790718272328377, 0.06353672314435244, 0.08977785719824688, 0.054492404351809194, 0.0548852388081806, 0.053444556293210814, 0.0348710206204227, 0.030206445205424513, 0.024816347918074046, 0.029815510647105317, 0.07266895632658686, 0.026097898704132864, 0.044520982807236056, 0.02272747447048979, 0.020043941414249793, 0.025307108548336794, 0.03726765041106513, 0.04192106392500656, 0.08208783662744931, 0.034493059651660066, 0.03697914071381092, 0.05994952563196421, 0.027075292775407434, 0.017077973245510032, 0.016547806694039276, 0.03130357865510242, 0.01689690787212125, 0.03895588285688843, 0.023778681277430484, 0.02129487500392965, 0.046081888156809976, 0.013650496091161455, 0.029087798802980354, 0.059455212870878835, 0.015978865258927857, 0.0049958646247562554, 0.05417427660099097, 0.09656341094523668, 0.04876815401283758, 0.05628896491335971, 0.024376784451305866, 0.03294585731678775, 0.013542262122168072, 0.04806222653548632, 0.043345098583293815, 0.03020686928981117, 0.03532277227246335, 0.025387348706967065, 0.01517738139123789, 0.05152839036392314, 0.023231853298576813, 0.011537177571361619, 0.10932715676192727, 0.009260894447964216, 0.012920404285458582, 0.058655145445040295, 0.012942739961934941, 0.12974477080362185, 0.04152174267385687, 0.0361587308081133, 0.04755141519542251, 0.04284876039517777, 0.14583496669573442, 10.830362115587507, 53.59080260140555, 70.32717868259975, 69.62357630048479, 75.62682683127267, 68.98349434988839, 81.37788554600307, 66.85069615500313, 33.024739265441895, 26.596747091838292, 29.574892657143728, 35.45550053460257, 49.40944964545113, 49.9161331312997, 40.314129148210796, 31.098622185843332, 21.713601759501866, 11.03485541684287, 4.827879360743931, 2.425613305398396, 0.8280200830527714, 0.1877886647624629, 0.05955078452825546, 0.016849747991987636, 0.01531703577243856, 0.07887076639703341, 0.09413673901664359, 0.06124382439468588, 0.11230420880019665, 0.1770116694803749, 0.08412534836679697, 0.16021317802369595, 0.13457098683076246, 0.19605997949838638, 0.13734772854617663, 0.30421303319079535, 0.14635657013526984, 0.7140138777238982, 0.7735200417893273, 0.4215459328676973, 0.8022897094488144, 0.28810195199080874, 0.11520752443798951, 0.10262506960758142, 0.22887333588940756, 0.10410163644701242, 0.04957362936277475, 0.16186952271631785, 0.039322797275547466, 0.23018689826130867, 0.02784919928360198, 0.06834710216415779, 0.12435694491224629, 0.13432234445852892, 0.7155181084360395, 1.818693369626999, 5.947701854365213, 10.776601297514778, 14.82437252998352, 18.93914089884077, 31.593570164271764, 41.55015114375523, 52.506379876817974, 39.395803110940115, 32.97215529850551, 32.73426634924752, 40.92192281995501, 53.50882428033011, 62.28681359972273, 71.21565873282296, 74.1138357434954, 75.2573355266026, 76.87698146275112, 83.58755166190011, 62.06671551295689, 19.304452862058366, 0.714884031031813, 0.28596896358898705, 0.0602095809632114, 0.01418797385745815, 0.07867932452687196, 0.04185687790491751, 0.10557278857699462, 0.11733592594308512, 0.07749575589384351, 0.032632682871605666, 0.03264198897938643, 0.00896836188621819, 0.04472164596830096, 0.02295392026592578, 0.08290779191468443, 0.0269983977944191, 0.09909245345209326, 0.006078836624510586, 0.020337277191824148, 0.0143962908935334, 0.043373736153755865, 0.05874518704201494, 0.0233396962617657, 0.005530865314150495, 0.03921542250152145, 0.04180961794086865, 0.07802827696182899, 0.04166085592338017, 0.064641412081463, 0.07062986360064574, 0.0096881179072495, 0.04692875414288469, 0.05558357347867318, 0.01831783484002309, 0.05349395364256842, 0.03692688333934971, 0.04358381398820451, 0.035021027749670405, 0.021939505324033753, 0.051835756549345594, 0.03781040717980691, 0.007550161780922541, 0.05453296038987381, 0.022434598400390575, 0.02785565215162933, 0.05445809762126633, 0.045726088141756396, 0.07087671464043004, 0.02104133869787412, 0.03664698085880705, 0.032306965706603866, 0.045037721150687764, 0.0317338818152036, 0.16138943204922335, 0.21552423148282937, 0.11736833277557578, 0.1415498416338648, 0.16362283006310463, 0.09573979835425105, 0.12677867710590363, 0.10673839638807944, 0.1834725577916418, 0.18379009860966886, 0.08392997099352734, 0.12158907843487603, 0.12694594955870084, 0.14714780982051576, 0.12091914724026408, 0.119038478870477, 0.2064772562256881, 0.19129264674016408, 0.09093638110373702, 0.084395622435425, 0.13019074472997869, 0.2332200040774686, 0.16906009401593888, 0.14678153661744936, 0.10288337431848049, 0.14859789343816893, 0.11173849379909889, 0.10392107827855007, 0.13609509861895017, 0.08066755426781518, 0.1795911339244672, 0.13939591364136764, 0.1499689141554492, 0.17383565061858722, 0.095593526560281, 0.11212531982788018, 0.2168144386793886, 0.07554799398141247, 0.11035115431462016, 0.13954577488558634, 0.0921719390898943, 0.2162425693656717, 0.09316039497831038, 0.2002510731773717, 0.10916861026946988, 0.14972128958574363, 1.3222619507993971, 20.351730516978673, 70.45708915165493, 84.35028321402413, 81.2432780947004, 84.35131849561418, 80.50855473109654, 81.37791333879743, 62.9982396534511, 26.780115263802664, 21.984506811414445, 37.475939410073416, 65.880678994315, 109.17145810808454, 80.69141047341483, 46.99978658131191, 38.68426588603428, 23.35934512955802, 12.502503429140363, 4.937903216906956, 3.3022334320204596, 1.1134085463626044, 0.46924849173852373, 0.22549472004175186, 0.25249088715229717, 0.1288388722709247, 0.1327418056981904, 0.11363881932837622, 0.12408942569579397, 0.1391638003821884, 0.12519573633159908, 0.07933652640453406, 0.21041486279240676, 0.17895480378397874, 0.17772307273532661, 0.20502280284251484, 0.30116630239146097, 0.28748054962073055, 0.7329866396529334, 0.5260027348995209, 0.2945181519857475, 0.7848682414208139, 0.3929745059992586, 0.17403028160333633, 0.12034341027694088, 0.3112734614738396, 0.2821656662438597, 0.23093347677162715, 0.26423877105116844, 0.24355344101786613, 0.47878060596329824, 0.3082109886620726, 0.21482185274362564, 0.1720200537570885, 0.6778899761182922, 1.8727685936859675, 4.7197766814913065, 11.740010721342903, 17.069451877049037, 18.837754522051128, 28.839766298021587, 43.50857387270246, 68.12733731951032, 93.0412289755685, 74.22530569349016, 51.4055837222508, 26.024628945759364, 34.85987663269043, 51.09539181845528, 71.48888969421387, 81.80482455662319, 86.50202914646694, 82.5965300968715, 85.27425466264997, 96.8066314969744, 71.05972031184605, 23.814184631620133, 1.2456687007631575, 0.4920106274741036, 0.2074763990406479, 0.11374942053641592, 0.18154110786105904, 0.1391530388167926, 0.1686371359974146, 0.18462795365069593, 0.240706878049033, 0.2051508016884327, 0.15857044474354812, 0.10246599385780947, 0.1806647798844746, 0.114521199837327, 0.09371158254465886, 0.11020315225635256, 0.19741643885416643, 0.1257419977337122, 0.08810188248753548, 0.12037717417946883, 0.096463143825531, 0.17178932470934732, 0.1260154609169279, 0.15128578777824128, 0.07259931827762298, 0.10425133484282664, 0.1639155229287488, 0.09043431268738848, 0.13103763785745415, 0.10823595031563725, 0.11084446962922812, 0.21814704074391297, 0.1285920212311404, 0.0923913773149252, 0.15496633813849517, 0.1391559158052717, 0.1566674661423479, 0.11306549116436924, 0.17569586794291223, 0.21171638795307704, 0.1288460918835231, 0.1526382980602128, 0.10812114219048194, 0.14545297862163611, 0.1942443283540862, 0.14118231992636407, 0.21296843434018747, 0.1525342379297529, 0.11277108160512787, 0.14234486754451478, 0.12274663203528949, 0.20162927279514925, 0.08035793195345572], [0.07860005806599345, 0.06671830599329301, 0.0246627479459026, 0.017439359300104634, 0.05411845691768186, 0.028504499566874335, 0.020109571017591015, 0.027290622470900416, 0.06623316702565976, 0.025726237933018377, 0.050293992672647746, 0.03236109923039164, 0.009543824891027595, 0.03555277528773461, 0.003865688216007714, 0.024996426023010696, 0.07984575336532933, 0.004435519380162337, 0.03380459427301373, 0.030001690478197167, 0.009935729754423457, 0.09831850962447268, 0.033794463745185306, 0.012335664010606706, 0.06352984279926334, 0.014954075516600693, 0.04680489096790552, 0.04835182188877037, 0.041892114228435924, 0.04719984245353511, 0.02561054431966373, 0.04438715534550803, 0.036611279738800864, 0.054282374014811854, 0.05212691931852272, 0.020975790518735136, 0.05108114418440631, 0.03134932887873479, 0.03597624899287309, 0.0021753321676182425, 0.04887697745912841, 0.010055151917705578, 0.09738228057644197, 0.1314409047897373, 0.13115058679665836, 4.7875120639801025, 38.54434306280953, 64.67680631365094, 68.41748714447021, 66.00560760498047, 63.16278689248221, 62.95361137390137, 45.84765018735613, 22.325684206826345, 17.77605414390564, 31.110441071646555, 42.595729964120046, 54.62292970929827, 52.81747852052961, 48.61666018622262, 31.468863895961217, 12.69252450125558, 3.9426619240215848, 0.7502079669918332, 0.16473094560205936, 0.010765574689555382, 0.07372071953224284, 0.02940276118793658, 0.036508237410868914, 0.006980372177037809, 0.019167705039892877, 0.052831659359591346, 0.08541460561433009, 0.08958216769886868, 0.07121336978993245, 0.13081829462732586, 0.08617544693074056, 0.12500584152128014, 0.04517435774739299, 0.028112859332135746, 0.12213790469935962, 0.060468299580471854, 0.05623294845489519, 0.12448081826525075, 0.49354569081749233, 0.4352847199354853, 0.47766704857349396, 0.49986002913543154, 0.04712731384539178, 0.053695590501385074, 0.2115048071635621, 0.12983699728335651, 0.10980375297367573, 0.12516254239848681, 0.08015884977898427, 0.0481686174337353, 0.019835770263203552, 0.023894198471680284, 0.07174529374710151, 0.05549382704443165, 0.030963079604719366, 0.003456214172599305, 0.031011761099632298, 0.039428099125091515, 0.16880202000694616, 0.4256926232150623, 2.95969158411026, 5.66719526052475, 13.305075083460126, 32.81905174255371, 56.658856119428364, 57.30116844177246, 42.438117027282715, 27.027299165725708, 17.753837278911046, 23.917334113802227, 32.874064104897634, 66.05347374507359, 76.407151222229, 66.4869579587664, 70.47736399514335, 61.041932650974815, 70.10918590000698, 33.362789971487864, 7.467146515846252, 0.07999309724462883, 0.09564079330968005, 0.03003146798749055, 0.02736129698210529, 0.1544769922537463, 0.0471437717122691, 0.03907621425709554, 0.027622856964756335, 0.06948035742555346, 0.013513465095976633, 0.003173462693147095, 0.03155881299504212, 0.011193838851925517, 0.08474125460322414, 0.008608918986283243, 0.04199991647952369, 0.03271423938817211, 0.035498614622546096, 0.0459986895854984, 0.039236406196973155, 0.026802553928324153, 0.028902572313589708, 0.013764054863713682, 0.025716636662504504, 0.05348973994010261, 0.017690249319587435, 0.029966769673462425, 0.04866298108494707, 0.06554171270025627, 0.021188799624464343, 0.04187934419938496, 0.019265497203118036, 0.03900814701669982, 0.014754262220646654, 0.07647156156599522, 0.005319118283555976, 0.061851710347192626, 0.006288242709290768, 0.031192363372870853, 0.05179135321772524, 0.003166763432091102, 0.044037017705185075, 0.05392526103449719, 0.02918954173635159, 0.030950214580765793, 0.016510205675980875, 0.031109612634671584, 0.03483129918043103, 0.02687657531350851, 0.08055678342602082, 0.035199238186968226, 0.05293366352894476, 0.01459583786449262, 0.006157920305018446, 0.04955159054536905, 0.0038315574804853115, 0.032591600968901596, 0.048917564031268866, 0.029909385966935327, 0.06928279516952378, 0.037218792497047355, 0.07016143016517162, 0.03115195661251034, 0.04663058549964002, 0.019646196060680916, 0.0263751515054277, 0.02464012728471841, 0.11281187513044902, 0.016379044856876135, 0.027560204433809434, 0.007004095881711692, 0.022721484702612673, 0.00863093405496329, 0.0871884725721819, 0.03420408515791808, 0.03747727023437619, 0.040882169135979245, 0.017812402586319616, 0.03696632657998374, 0.048769416087972264, 0.07677401855055775, 0.02750149249498333, 0.017674505610817244, 0.010828262843590761, 0.06660317895667893, 0.06862911488860846, 0.02258710762751954, 0.02682334084862045, 0.011579917644017508, 0.07590164643313203, 0.041947788026716025, 0.02863133811791028, 0.07831827604344913, 0.011757181524964315, 0.10122045462152787, 0.1730277325425829, 6.3860003011567255, 45.80835117612566, 75.32949256896973, 77.99901826041085, 76.72132096971784, 82.13856737954276, 84.21196542467389, 64.13242885044643, 37.980211871010916, 31.9707670211792, 32.05776194163731, 29.985729217529297, 39.62780693599156, 45.966916016169954, 46.967223848615376, 33.9425824029105, 15.11361561502729, 5.4795925957815985, 0.7684766267027173, 0.17342767465327466, 0.15011422921504292, 0.033727638223873715, 0.027483092321615134, 0.08762194109814507, 0.08576849555330616, 0.1665412498904126, 0.18919515929051808, 0.40620794732655796, 0.14606923769627297, 0.2384452936904771, 0.35669858540807453, 0.7186149965439523, 0.5006204769015312, 0.5738738147275788, 0.3101379195494311, 0.3832171724310943, 0.4570682996085712, 0.46282716201884405, 0.5694218107632228, 1.7517706006765366, 2.7484379027570998, 1.850228637456894, 1.3024056277104785, 0.527584427169391, 0.729859244610582, 0.2933532159243311, 0.30280843856079237, 0.12444573800478663, 0.2682047810937677, 0.21564186231366225, 0.1365788940872465, 0.08468465799731867, 0.10567553234951836, 0.3062496967613697, 0.03192212439275213, 0.10411725632314171, 0.10521024731653077, 0.053556928477649174, 0.04827561901350107, 0.058919387337352545, 0.33987414677228245, 2.533880570105144, 4.883419786180768, 12.410610897200447, 30.41270991734096, 49.80766132899693, 45.503995759146555, 30.255819593157085, 27.144918271473475, 22.243601662772043, 42.97671706335885, 50.66716391699654, 73.76981653485979, 87.03563690185547, 75.58666624341691, 79.6715121950422, 69.68991075243268, 85.76983492715019, 46.51329803466797, 14.075297662190028, 1.0072639563253947, 0.07626857781516654, 0.019271018781832287, 0.04610935186168977, 0.16517291617180618, 0.03470411118386047, 0.027525855294827904, 0.013524690609691399, 0.036298132435019524, 0.07124619731413466, 0.04033563631985869, 0.0308536692256374, 0.04140827465536339, 0.06436214063848768, 0.016546899153451835, 0.04917447096002953, 0.0273102083842137, 0.05225974254842315, 0.04322545589613063, 0.03178319434768387, 0.06600832087653023, 0.01945327328784125, 0.0439324826002121, 0.04208081142444696, 0.030949162851486887, 0.01986170556795384, 0.015179094692159976, 0.07552396027105195, 0.042530490152005634, 0.04252495669892856, 0.03624522027426532, 0.05816787587744849, 0.04819401499948331, 0.05190984918070691, 0.04082951142585703, 0.008133697656116315, 0.029327318271888152, 0.044117213759039126, 0.01993930452902402, 0.11492677378867354, 0.031902745432619534, 0.03820504314665284, 0.022536555072292686, 0.04423657146149448, 0.030366793208356415, 0.02477296069264412, 0.053751250728964806, 0.004540166019329003, 0.05539696956319468, 0.03502641531771847, 0.011843388550914824, 0.14791131099419935, 0.16779620040740284, 0.12176290553595338, 0.13899860424654825, 0.11611141450703144, 0.16229739332837717, 0.08221440376447779, 0.1432840142931257, 0.15377392140882357, 0.15519009184624466, 0.1319890253778015, 0.10511278254645211, 0.08612312509545259, 0.14664357687745774, 0.11549290269613266, 0.09838841908744403, 0.25479687484247343, 0.07841779677463429, 0.09503419657370873, 0.1252930382532733, 0.07370284691985164, 0.1375614670770509, 0.1445121762475797, 0.07957098739487783, 0.16282789914735726, 0.08890058605798654, 0.12730505743197032, 0.15300022863915988, 0.12137764692306519, 0.16595875471830368, 0.09618405558701072, 0.10300941219819443, 0.15170747015093053, 0.12809046171605587, 0.27883408644369667, 0.1332608171339546, 0.1496572494506836, 0.10413821626986776, 0.173748608146395, 0.10707239846565894, 0.1502607384962695, 0.17238791473209858, 0.17039414814540318, 0.16051946873111383, 0.8227726189153535, 12.858239037649971, 61.833818844386506, 88.10072626386369, 87.92085129874093, 82.19353457859584, 80.96918555668422, 80.77308654785156, 62.771679741995676, 31.746597290039062, 26.431020396096365, 43.619640827178955, 57.99337230409895, 74.02541991642543, 72.89449637276786, 63.907196044921875, 43.22635889053345, 18.937685251235962, 6.436016474451337, 1.2705294638872147, 0.39914171078375404, 0.2633789857583386, 0.22022999397345952, 0.09425645294998374, 0.21787768948291028, 0.20110458880662918, 0.21012966095336846, 0.17984033269541605, 0.4560679761426789, 0.28298419660755564, 0.1492344814219645, 0.2590945799435888, 0.4915511778422764, 0.3413790560194424, 0.3385406354708331, 0.27468451910785263, 0.2856456823647022, 0.3351500502654484, 0.41842301615646904, 0.22949313691684178, 1.1611055412462779, 2.5176521837711334, 1.368813687137195, 0.7889409714511463, 0.3420067009116922, 0.4155065097979137, 0.3573443064732211, 0.46041836270264214, 0.2263251654803753, 0.22867721212761744, 0.21360532087939127, 0.2033747634185212, 0.18514336885086127, 0.14803597144782543, 0.5675500854849815, 0.1398427832339491, 0.19088099311505044, 0.14472942958985055, 0.252655635454825, 0.19294439096535954, 0.23273922130465508, 1.2490537762641907, 4.956642508506775, 7.669082011495318, 17.961333070482524, 42.303203855242046, 80.75352042061942, 75.22062819344657, 58.7805233001709, 41.31818205969674, 30.114924022129603, 39.153380462101524, 47.019377027239116, 81.88839054107666, 94.99483312879289, 86.9280787876674, 85.76008660452706, 81.75076062338692, 97.63810157775879, 61.04842921665737, 20.400715317044938, 1.4893605900662286, 0.20731222070753574, 0.08538679246391569, 0.1090173376724124, 0.33488048187323977, 0.13346698321402073, 0.10079869082463638, 0.19442990768168653, 0.15210477954574994, 0.20620479727430002, 0.15644749866000243, 0.15238778293132782, 0.15443357958325318, 0.164161424019507, 0.0691714882850647, 0.11403767578303814, 0.11220240819134883, 0.1363852537636246, 0.174020008583154, 0.1665657992873873, 0.1418571908559118, 0.08428137749433517, 0.09836915547826461, 0.19724573301417486, 0.19806988164782524, 0.08560214590813432, 0.11220622155815363, 0.09322269127837249, 0.17205608396657876, 0.0991060377231666, 0.12812867680830614, 0.1289045408900295, 0.1523150032652276, 0.1158429996243545, 0.13546697875218733, 0.0779424219259194, 0.07178049614386899, 0.17681678065231868, 0.12653850285070284, 0.13527814245649747, 0.14613491988607816, 0.11003391205200128, 0.10485247615724802, 0.09571724385023117, 0.1372272614389658, 0.1514803237680878, 0.11040672633264746, 0.10470372771045991, 0.2364295289984771, 0.1818448608475072, 0.0990771185606718], [0.013429381884634495, 0.0302947090406503, 0.008198609708675315, 0.06500218236552817, 0.0777954715969307, 0.08487758585917098, 0.01786325030427958, 0.01947462508854057, 0.02650607144460082, 0.04403468693739601, 0.013743896436478411, 0.01319794207146125, 0.012042659018853945, 0.025380634602957537, 0.01592298281112952, 0.0837665797610368, 0.02740224148146808, 0.057154985943010876, 0.03606788853981665, 0.02970707735845021, 0.07101876594658409, 0.05899906770459243, 0.03456156454714281, 0.012564935904395367, 0.027648536122537086, 0.07266529223748616, 0.05614042681242738, 0.04760110770751323, 0.008981350742812668, 0.06390228388564927, 0.047738836745598486, 0.04172618866765073, 0.01068668142293713, 0.04150366989363517, 0.023464670537837913, 0.059621596442801614, 0.016981561901047826, 0.0357309009081551, 0.03285725082137755, 0.08524267841130495, 0.03565636383635657, 0.050956670327910354, 1.3229004251105445, 9.578638059752327, 31.47729900905064, 59.10812391553606, 67.35710171290806, 65.56181921277727, 66.45064667293003, 40.70860270091465, 23.42834074156625, 19.04823282786778, 16.48734395844596, 25.21416848046439, 42.73661511284964, 61.43206705365862, 68.35785075596401, 63.22184658050537, 31.78826216288975, 15.31106778553554, 4.1758525882448465, 1.0749450560126985, 0.01197372070912804, 0.04535392525472811, 0.04837368428707123, 0.09627450430499655, 0.03838506527245045, 0.12189912822629724, 0.02919574354642204, 0.17246775116239274, 0.08219735217945916, 0.0805260254336255, 0.12556304090789386, 0.19966418109834194, 0.1691922183547701, 0.127546900883317, 0.7890701102358955, 0.6198874456541879, 0.48098416200705935, 0.15279038489929267, 0.841449213879449, 0.7281797347324235, 0.7503124071019036, 0.25662832228200777, 2.049151220491954, 2.9813239318983893, 2.168032727071217, 1.2704749639545168, 0.8945050612092018, 0.4067228196987084, 0.5416713569845472, 0.7578551109348024, 0.11761412530073098, 0.0835736518991845, 0.1585932028080736, 0.11184893215873412, 0.09567941552294151, 0.034412931451307874, 0.10650449179645095, 0.027683482372335026, 0.08570116452340569, 0.09516838365899664, 0.039178883390767236, 0.04383427483428802, 0.1210513665739979, 0.06544657530529158, 0.10626025990183864, 0.17064551822841167, 0.7708310346518243, 5.742147650037493, 14.663346290588379, 55.43021658488682, 95.20250783647809, 56.12063823427473, 36.23837491444179, 15.277605261121478, 19.81845280102321, 33.766997950417654, 38.72574315752302, 57.568212032318115, 61.08651924133301, 71.59450231279645, 66.21239989144462, 65.08356775556291, 63.1445061819894, 45.70310681206839, 9.65971050943647, 0.3661771225077765, 0.07137990942490952, 0.09939320731375899, 0.06616976471351725, 0.03465954839651074, 0.04100042761170438, 0.02441398852637836, 0.009299310556213771, 0.04038230595844133, 0.0157957269610571, 0.09702050606054918, 0.07643829977938107, 0.0025082104215731044, 0.044867351185530424, 0.02215784941134708, 0.05425458461312311, 0.05705969248499189, 0.04487431634749685, 0.0383395525360746, 0.058907770817833285, 0.04168517461844853, 0.027970838560057536, 0.018233364015551548, 0.03984980185383132, 0.022672891417252164, 0.007544824254832098, 0.058455818997962136, 0.035917769452290874, 0.00372130614206461, 0.011815902793646922, 0.011284431758602815, 0.036414100855056725, 0.024097609699570706, 0.00944385547856135, 0.042507090871887546, 0.03688063099980354, 0.07939817809632846, 0.03168039968503373, 0.05327416257932782, 0.10563424349363361, 0.025516076978029947, 0.06794051719563347, 0.06443335288869483, 0.065406202471682, 0.06802443840673991, 0.027117502742580006, 0.035682582429477146, 0.0379405400183584, 0.02671562002173492, 0.06232276292783873, 0.06637996129159417, 0.026065725966223648, 0.035817068070173264, 0.04818486495475684, 0.06450810709169932, 0.019947238299729567, 0.07985768879630736, 0.02263235573523811, 0.0474737059724118, 0.046992984267749956, 0.01050490019510367, 0.03360927118254559, 0.02862771813358579, 0.05560603977314063, 0.01615556765214673, 0.03503032707210098, 0.038818649149366787, 0.03367204584979585, 0.0405291646852025, 0.022050030196883848, 0.02448010158592037, 0.02640657955115395, 0.01809440682908254, 0.04177836801058479, 0.03133811948022672, 0.04876147722825408, 0.041092589630612304, 0.04211719447214689, 0.058424837089010646, 0.03365827498159238, 0.01889210956038109, 0.041264177566128116, 0.017668654942618947, 0.02355369772495968, 0.05222684717071908, 0.013708385306277444, 0.0220511090675635, 0.009264570411427744, 0.06035247365278857, 0.06892585860831396, 0.09494675376585551, 0.9266249005283628, 12.767196791512625, 38.016012464250835, 69.41647829328264, 79.12845488956997, 72.1886705671038, 75.58290031978062, 55.45132868630545, 36.31869609015328, 26.941032069069998, 30.085248265947612, 26.906186853136333, 27.846173899514334, 39.08847039086478, 43.63299526487078, 47.64213364464896, 32.692820344652446, 18.72781491279602, 5.90285861492157, 1.2607347837516238, 0.10156451937343393, 0.05500945821404457, 0.05593089519866875, 0.07720482721924782, 0.27918388481651035, 0.9892303411449704, 0.21416861351047242, 1.2589886145932334, 0.684938597892012, 0.8614099770784378, 0.6324933235134397, 1.5924727256808962, 1.3992224782705307, 2.3530059329101016, 3.0047113512243544, 3.0573615431785583, 1.8691336001668657, 1.7894375451973505, 2.4915549669946944, 1.5746952167579105, 4.0323966060365946, 1.713586232491902, 3.1487991852419714, 5.812568945544107, 4.776916061128889, 4.009168343884604, 3.890803609575544, 2.274195338998522, 1.492497593164444, 1.5175643052373613, 1.231277461562838, 0.4320808675672327, 1.3494766333273478, 0.5244758139763559, 0.6377264027084623, 0.1059296437140022, 0.16872822253831796, 0.270123189581292, 0.3784965771649565, 0.15782666179750646, 0.1636950940425907, 0.13326376197593554, 0.07437298846031938, 0.10298020805099181, 0.15860392366136822, 0.3184080400637218, 0.5441719485180718, 4.945914924144745, 14.00645751612527, 45.4068078313555, 64.29828929901123, 44.219593456813264, 34.523406641823904, 24.927650826317922, 30.413658346448624, 55.557990482875276, 56.130452564784456, 69.34181295122418, 74.69093922206334, 82.30389281681606, 74.80703667231968, 75.21557685307094, 80.52345166887555, 62.134884289332796, 16.478926215853008, 0.26223370007106234, 0.12719957237797125, 0.0514686182141304, 0.041325316963983436, 0.03392450837418437, 0.06937058403023652, 0.1127237266461764, 0.01847849157638848, 0.06727741884865931, 0.03464087172012244, 0.07094223398183074, 0.05318224483302661, 0.0303124289826623, 0.10379624819116932, 0.06819285079836845, 0.03485260857269168, 0.006314296757669321, 0.033865906697298796, 0.007173317850434354, 0.021561425611642853, 0.0927927443491561, 0.03308575766693268, 0.04387708021593945, 0.059681701074753485, 0.029754710516759326, 0.04033349554187485, 0.026897838904655406, 0.06784460627074752, 0.05430314057905759, 0.025502192455210855, 0.03710759078551616, 0.013269179766731603, 0.013062441172743482, 0.02979802479967475, 0.039228769285338264, 0.05332742418561663, 0.08772773149290256, 0.0485378626201834, 0.04733653333304184, 0.04481878164889557, 0.01011462211941502, 0.031583525240421295, 0.04262176329003913, 0.044290691414581876, 0.02278837638108858, 0.02092751784117094, 0.01712865981140307, 0.0520643278557275, 0.06261911309723343, 0.12504031110022748, 0.18323581692363533, 0.12430049079869475, 0.1529689481748002, 0.16383166957114423, 0.20606533118656703, 0.07573197196636881, 0.10106625753854002, 0.13242872964058602, 0.20444025338760444, 0.19423591451985495, 0.09447245778782026, 0.13778922414141043, 0.07910754119179078, 0.16779970164809907, 0.11941478082111903, 0.1124030306403126, 0.12293896957167558, 0.152059154851096, 0.14264122449925967, 0.12233488341527325, 0.16795239916869573, 0.11593473755887576, 0.10545270144939423, 0.07903607109827654, 0.12419356725045613, 0.18052528665534087, 0.15884489858789103, 0.14397381299308368, 0.09731486133698906, 0.11895083928746836, 0.17484787558870657, 0.15416782455784933, 0.1385302250938756, 0.13666067112769398, 0.1057439354647483, 0.09661453855889184, 0.10371436937046902, 0.07466076194707837, 0.16131446750036307, 0.1735040776963745, 0.3307532247688089, 2.4590934174401418, 21.860752446310862, 54.09766674041748, 85.3827577318464, 87.56212970188686, 81.62114197867257, 83.74260766165597, 55.616942473820274, 32.73604161398751, 29.348016602652415, 26.279377698898315, 39.11311565126692, 57.98522554125105, 83.2361673627581, 93.84380149841309, 81.86551012311662, 43.73040206091744, 22.833161524363927, 7.094938899789538, 1.654015309044293, 0.1980548317411116, 0.18452758475073747, 0.12585835291871003, 0.2943013736179897, 0.14192764993224824, 0.3914259805210999, 0.14213116972574166, 0.646015115082264, 0.3156220295599529, 0.3543750372316156, 0.35062382423451965, 0.48977401320423397, 0.5319252599562917, 1.379868705357824, 2.016140763248716, 2.8096252594675337, 1.0628351058278764, 1.2679371344191688, 2.5955499580928256, 2.171099271093096, 5.304869285651615, 3.207500172512872, 5.2257141045161655, 9.892602835382734, 7.63740256854466, 6.049951979092189, 3.400251886674336, 1.5162070180688585, 1.1593364647456577, 1.4505988700049264, 1.290165507367679, 0.5432647200567382, 1.2723585771662849, 0.56583371758461, 0.3406981868403298, 0.1877554301172495, 0.21653064819318907, 0.2761620698230607, 0.5370341943843024, 0.3896025669361864, 0.1974437159619161, 0.4485301034791129, 0.42652315007788794, 0.3356377812368529, 0.2374689360814435, 0.5695529037288257, 1.2909380601985114, 8.288386242730276, 17.756719044276647, 69.43263980320522, 121.97890581403459, 78.2745282309396, 51.14735739571707, 21.796879393713816, 29.92603029523577, 49.45210811070034, 52.42546115602766, 74.62049838474819, 81.37300791059221, 89.32251834869385, 82.03603976113456, 87.45998423440116, 93.69179575783866, 76.00843579428536, 20.897527149745397, 0.5902401879429817, 0.290879168680736, 0.18024691087859018, 0.21025406356368745, 0.08453577384352684, 0.12113135228199617, 0.18512906533266815, 0.08926196023821831, 0.18076989852956363, 0.08784689581287758, 0.18639050264443668, 0.20936412417462893, 0.09747424921286957, 0.16610067710280418, 0.11762534826993942, 0.13644482913826192, 0.0835489532245057, 0.10715410765260458, 0.09134676586836576, 0.11094670450048787, 0.19514874768044266, 0.11592240179223673, 0.13616307425711835, 0.14329629577696323, 0.08812918673668589, 0.09103586112282105, 0.08859063804681812, 0.14433020672627858, 0.14581075656626905, 0.1408867636429412, 0.138802222641451, 0.08194388542324305, 0.0730223645056997, 0.07893983447658164, 0.16970337235501834, 0.12258922548166343, 0.2105255997074502, 0.10859963151493243, 0.1592931795333113, 0.1924748175910541, 0.13625306157129152, 0.10971718547599656, 0.15013508738151618, 0.12420618800180298, 0.11658234495137419, 0.11110185153250184, 0.1021273098886013, 0.14725720323622227, 0.11774938447134835], [0.054437571936952214, 0.02143863621833069, 0.03132452163845301, 0.06604824587702751, 0.029102156603974954, 0.04603243652465088, 0.047938838335020204, 0.023064879401187812, 0.020765697417248572, 0.02889237393225942, 0.055901107511350086, 0.057648728734680584, 0.046331388875842094, 0.04772653490571039, 0.025825738308152983, 0.03039944770612887, 0.07456820977053472, 0.03203653896759663, 0.015003920699070607, 0.037232970486262014, 0.045518975505339246, 0.05061351142025419, 0.01837271814500647, 0.01904980279505253, 0.11254618117319685, 0.009526816562616398, 0.021595783232312118, 0.025756022227661948, 0.044707814031945806, 0.05301646176459534, 0.05174150803525533, 0.01459622971846589, 0.08256688913596527, 0.019997300613405447, 0.0375332425880645, 0.02219916201595749, 0.07166844965623957, 0.0274336101553802, 0.05247639199452741, 0.021122795130525316, 0.06580083165317774, 4.40899852343968, 43.72435017994472, 65.89811897277832, 72.83345644814628, 73.45436137063163, 70.04743031093052, 74.51916585649762, 46.11374534879412, 38.18086889811924, 141.71818215506417, 100.48085975646973, 37.09041861125401, 47.988233838762554, 71.21859087262834, 67.09571743011475, 32.480865546635215, 16.35244641985212, 5.202679089137486, 0.8536951424820083, 0.0918319591188005, 0.07145620390240635, 0.14398929716220923, 0.12516593507358006, 0.11789692512580327, 0.02964283705555967, 0.19429113369967255, 0.32766059786081314, 0.26288026251963204, 1.0205299130507877, 0.435582053980657, 1.2903179334742683, 0.7517001469220433, 1.1316876283713748, 2.280053321804319, 1.7182862545762743, 3.2980082758835385, 2.284075894526073, 2.387696768556322, 1.1753220983913966, 2.1305085463183264, 0.789015664585999, 0.5010756381920406, 1.4123965884957994, 3.1434964069298337, 2.596463211945125, 3.1931076305253163, 2.958493236984525, 1.664441081030028, 2.8013781820024763, 0.8653305524161884, 0.3844033602092947, 0.8405695610812732, 0.2911823109856674, 0.3014889865049294, 0.2276957519352436, 0.10232156767909016, 0.11361695014472518, 0.08830389593328748, 0.1651080617947238, 0.0954620943271688, 0.12184149346181325, 0.11798448328460966, 0.0534428565629891, 0.05042293468224151, 0.06166560176227774, 0.09579060705644743, 0.08976886660924979, 0.05653979895370347, 0.2517982657466616, 2.051556382860456, 6.761174363749368, 40.02501113074166, 60.44082314627511, 50.41392292295183, 67.50950350080217, 46.28843695776803, 15.577680587768555, 18.25474681173052, 21.696985142571585, 37.80745880944388, 49.085934570857454, 60.14726870400565, 65.60365431649345, 62.25043283190046, 62.33215754372733, 68.89059693472726, 36.86794771466936, 3.367942111832755, 0.4055398074643952, 0.03928728275267141, 0.04343087898035135, 0.04014187046725835, 0.043706174208117385, 0.007509291072243026, 0.01688992913945445, 0.019471093313768506, 0.044790537628744326, 0.016360603971406817, 0.01636416288757963, 0.02102634816297463, 0.0674773763333048, 0.03172252992434161, 0.02527603503715779, 0.016940792124452334, 0.03319120200883065, 0.02775741385162941, 0.00597380322038329, 0.005857712239958346, 0.022590429056435823, 0.028897120284714868, 0.03140840553013342, 0.03591694163956812, 0.025154506022642766, 0.029912239206688743, 0.02443815115839243, 0.0662244614213705, 0.09210065898618527, 0.011414370366505213, 0.06239820245121207, 0.03610880420144115, 0.048107786769313474, 0.07226807783756937, 0.037720416472958665, 0.02277131631438221, 0.019038847847176448, 0.06603390843208347, 0.05795771322612252, 0.05428096944732325, 0.006117235345300287, 0.048326699129704914, 0.029134950201426233, 0.020250748709908555, 0.03363989346793719, 0.06484238058328629, 0.03846361927155938, 0.0251265741286001, 0.03409216419926711, 0.0419114524764674, 0.05298280642767038, 0.0338872432309602, 0.0077333161939999884, 0.001772796780902094, 0.047807606269738505, 0.008629688095035297, 0.026116807778765048, 0.08943136329097406, 0.028969323196049248, 0.05840927828103304, 0.046737156209668944, 0.017621530685573816, 0.06088274198451212, 0.03681509130235229, 0.030075420093323504, 0.017813724033268433, 0.010986095177941024, 0.004425105988048017, 0.0204740528882082, 0.04585415144850101, 0.031298231799155474, 0.054852302718375406, 0.040850067644246986, 0.13449501805007458, 0.04430058106247868, 0.026543801384312764, 0.06121659478438752, 0.07048422284424305, 0.03674418778557863, 0.01899815270943301, 0.01322343123943678, 0.07134168754730906, 0.05355032293924263, 0.07348997691380126, 0.02381492861812668, 0.041546780616045, 0.11913530581763812, 0.022746605765340582, 6.297610529831477, 54.00062125069754, 77.59493882315499, 84.44533457074846, 81.16168539864677, 75.21039349692208, 81.00959627968925, 62.84517778669085, 42.297989232199534, 96.9865620476859, 67.37779344831193, 31.425524507250103, 37.69256339754377, 50.28186546053205, 57.05659532546997, 36.71570226124355, 18.24083478110177, 5.922799076352801, 1.5463843473366328, 0.25146695066775593, 0.02543526854632156, 0.07277761013912303, 0.08422710147819348, 0.4544471731143338, 0.6995787780199731, 2.0693020820617676, 1.329951978155545, 1.3416180035897662, 1.9123650746686118, 2.333714476653508, 5.14798286982945, 3.7859392251287187, 5.158552382673536, 6.120652071067265, 5.855961748531886, 7.866132055010114, 8.455223781721932, 5.67735743522644, 6.642936434064593, 8.405928918293544, 7.737277712140765, 5.779259281499045, 9.586276735578265, 6.192020058631897, 7.061050798211779, 6.860692543642862, 8.288957732064382, 5.756392325673785, 5.067863626139505, 4.9527137364659986, 2.6010025569370816, 2.650424442120961, 0.8900844327041081, 1.0582767618553979, 0.9943615858043943, 0.8476440214685032, 0.8618613385728428, 1.2618672315563475, 0.5127004086971283, 0.43342260271310806, 0.5580686171139989, 0.30250597479087965, 0.07168250890182597, 0.07563310262880155, 0.10717776138335466, 0.06666667626372405, 0.11524751729198865, 0.08409613064889397, 0.16778792228017533, 1.7530016260487693, 7.251226902008057, 38.10692616871425, 50.3179544040135, 39.66584137507847, 36.96793576649257, 34.454848766326904, 24.095194101333618, 33.174306188310894, 46.277236461639404, 51.46295152391706, 59.272462708609446, 69.6370210647583, 75.53650719778878, 69.6656129019601, 73.62680871146065, 84.64938926696777, 51.08294759477888, 5.960544730935778, 0.29441273478525026, 0.013350006858153003, 0.09052575885185174, 0.08390739613345691, 0.04710579749995044, 0.06300118259553399, 0.05460116672994835, 0.008884666288005454, 0.03478363888072116, 0.024527327623218298, 0.02748455456458032, 0.009404519955361528, 0.04363739450595208, 0.045697688058550866, 0.0095542641522895, 0.0516611966304481, 0.03540240514225193, 0.01370970590505749, 0.0008636679974318083, 0.00719676208349743, 0.0574906300753355, 0.02007277575986726, 0.08535542379000358, 0.0683457450941205, 0.04282149685812848, 0.06300340819039515, 0.03483580804562994, 0.046722303078110726, 0.061932863135422976, 0.04521391973165529, 0.031078881783676997, 0.03852154580610139, 0.012176412689898695, 0.023105231878746833, 0.031456031903092346, 0.016745277347841432, 0.013015900455814387, 0.09743203754935946, 0.0238911026556577, 0.048032696691474745, 0.07760426042867558, 0.01980591132970793, 0.04207570544843163, 0.0795837574239288, 0.06935902179351874, 0.036707835271954536, 0.05837893419499908, 0.1289691509945052, 0.0690297151782683, 0.18003801708774908, 0.19711286228682312, 0.08882566222122737, 0.14682754129171371, 0.09123214773301568, 0.07581177446991205, 0.07293569522776774, 0.0962981783917972, 0.19123288137572153, 0.20094706011669977, 0.18762828622545513, 0.13665874408824102, 0.10517245291599206, 0.15138446034065314, 0.12824671476015023, 0.1240528119461877, 0.09813436200576169, 0.15030945731060846, 0.14373160313282693, 0.10707210669560091, 0.1623277509851115, 0.07957735883870296, 0.2234797560210739, 0.12662475822227343, 0.19423413675810608, 0.16074683224516256, 0.13909685611724854, 0.1945577979620014, 0.1379294501883643, 0.12923163548111916, 0.22682310161846025, 0.11029159929603338, 0.20381050503679685, 0.1640928919826235, 0.2037581628454583, 0.1985051618622882, 0.11851535551249981, 0.19861439242959023, 0.1599318166928632, 9.871455992971148, 70.32111985342843, 91.01203536987305, 93.85595389774868, 89.23866053989956, 84.87829072134835, 90.04838275909424, 65.25672381264823, 51.04227631432669, 145.57170867919922, 108.73849500928605, 50.48789691925049, 65.26939732687813, 98.49381392342704, 89.35868372235979, 47.452757017953054, 24.682184866496495, 7.4297947372709, 1.895918037210192, 0.5186585975544793, 0.1504808145442179, 0.3641716172652585, 0.34847235253879, 0.7841158817921365, 0.3642629480787686, 0.8276695247207368, 0.3906894443290574, 0.7453228405543736, 3.265579947403499, 1.4622354741607393, 6.932559932981219, 4.926346625600543, 5.059815440859113, 6.073047791208539, 5.3321027500288825, 8.6635559626988, 8.398156489644732, 9.139362522533961, 6.3144751105989725, 7.009091300623758, 5.20943968636649, 4.349981827395303, 8.712771790368215, 8.56884159360613, 11.552256499017988, 11.09258713041033, 10.701418314661298, 5.780750972884042, 7.341511794498988, 5.235682598182133, 2.06283244064876, 2.4485484404223303, 1.341753167765481, 1.0097289383411407, 0.9823081982987267, 0.6513287499547005, 0.3389622228486197, 0.6919426534857068, 0.42977634551269667, 0.38676308787294794, 0.6139965674706868, 0.5353181521807397, 0.37675705764974865, 0.09621369399662529, 0.27165190183690613, 0.21679257628108772, 0.2795629416193281, 0.2641967018800122, 0.5824094052825655, 3.3506658502987454, 9.502616950443812, 50.89625644683838, 80.9457562310355, 69.9633640561785, 86.77150113242013, 64.01795727866036, 25.074697290148052, 30.482924938201904, 36.846443040030344, 48.29849522454398, 64.73348276955741, 80.70551531655448, 85.10893617357526, 79.38220310211182, 83.70210661206926, 96.99268341064453, 62.41963536398751, 8.197963254792349, 0.48242146202496117, 0.08413357221122299, 0.17959565296769142, 0.23007059735911234, 0.22307775116392545, 0.11634920031896659, 0.15380096781466687, 0.0825410233810544, 0.12215447452451501, 0.12904628685542516, 0.16154054179787636, 0.08273070106016737, 0.1431306925203119, 0.1427117378583976, 0.11207392080021755, 0.10872685004557882, 0.11839665259633746, 0.13893916457891464, 0.19137462734111718, 0.15044941194355488, 0.13350983948579856, 0.07881867526365177, 0.1155529259038823, 0.0990502621446337, 0.11721919077847685, 0.13541663145380362, 0.13799784651824407, 0.16856441061411584, 0.25404864070670946, 0.14141478602375301, 0.1529287789016962, 0.07612003292888403, 0.09237231726625136, 0.10671473587197916, 0.135588531515428, 0.09755498130938836, 0.1696324111627681, 0.21806411019393376, 0.10705169636223998, 0.18446819936590536, 0.2263993564993143, 0.12299135247511522, 0.1919689697346517, 0.11655175659273352, 0.1879615554852145, 0.1505614516458341, 0.15254882643265383], [0.01996742302019681, 0.03727587764816625, 0.03300933087510722, 0.06425007379480771, 0.018303304012598734, 0.11758129777652876, 0.038989409272159846, 0.06459561096770422, 0.030426076812935725, 0.03995256258973053, 0.014099503917220448, 0.02321857606459941, 0.08176427041845662, 0.048133177549711297, 0.016914556567956294, 0.01963710199509348, 0.06679390836507082, 0.061543146547462256, 0.04347348080149718, 0.05635103051151548, 0.01751477677108986, 0.03707169967570475, 0.02034440859487014, 0.02811211803262787, 0.03815322681995375, 0.03785927527184997, 0.06106876914522477, 0.01848903770691582, 0.021495633159897158, 0.03870158489527447, 0.023846192119110907, 0.020603184887607182, 0.07644182137612786, 0.0703326788331781, 0.0655163490612592, 0.022013784552525197, 0.10703431908041239, 0.07312217700694289, 0.08018573333642312, 0.5906582740800721, 4.510374912193843, 21.13580867222377, 16.477606058120728, 72.65391499655587, 65.6039878300258, 75.92053413391113, 57.467866148267476, 36.90697922025408, 24.95762014389038, 30.06423691340855, 94.50567994798932, 68.01882035391671, 53.05942521776472, 53.312509877341135, 39.30939531326294, 26.825891733169556, 7.951555814061846, 1.885890918118613, 0.12290048306541783, 0.22466867151004927, 0.059250363148748875, 0.05058919272518583, 0.049385308753699064, 0.05456865472452981, 0.010887101159564086, 0.22864485957792827, 6.2432730112757, 7.289210098130362, 2.6279029420443942, 2.4734312423637936, 4.310932082789285, 3.7632511854171753, 3.52793111545699, 10.674533997263227, 5.689304428441184, 8.133913023131234, 9.323280470711843, 6.451550040926252, 4.027347436973026, 5.293740877083369, 4.869125604629517, 3.8877255575997487, 5.572831341198512, 4.801175262246813, 3.050027285303388, 4.665400947843279, 5.173010715416499, 4.500775975840432, 7.527739150183542, 5.118902053151812, 4.866663336753845, 3.388630373137338, 2.1071439257689883, 0.869000721190657, 1.8495296921048845, 0.6253969328744071, 2.1726139783859253, 0.3947648342166628, 1.3392190294606345, 0.7760808329497064, 0.26342205916132244, 0.2387949020734855, 0.24051137853946003, 0.30094477427857264, 0.07279329108340399, 0.12157746191535677, 0.10001931871686663, 0.06026161102844136, 0.022107483453250358, 0.08314651410494532, 0.019397014253107563, 0.23794670615877422, 1.0861494605030333, 22.114262683050974, 55.28792095184326, 96.05077866145542, 80.8475364957537, 69.35397229875836, 34.39976692199707, 14.263653772217886, 16.360381262642996, 38.684106077466694, 57.39841195515224, 49.19431257247925, 60.229959215436665, 64.38580186026437, 60.826816422598704, 74.61828190939767, 60.11685643877302, 9.285816652434212, 0.27504411552633556, 0.08873756123440606, 0.05577125287215624, 0.08429053093173675, 0.055309156953756294, 0.02114984662538128, 0.040570874232798815, 0.03826562275311776, 0.023550701992852346, 0.007815461339695113, 0.04713236893128071, 0.025725835901019827, 0.04034647930945669, 0.003981405578088015, 0.02830000437929162, 0.042887677771172354, 0.033062918178204975, 0.03278450168935316, 0.02446870389394462, 0.043173419045550485, 0.011801699359369065, 0.024619593118716563, 0.024278055909754973, 0.013417981648152428, 0.02094717669699873, 0.042646556959620545, 0.01867553814580398, 0.04118986441088574, 0.08196568675339222, 0.028145259379276207, 0.049065237000052414, 0.06269314805311815, 0.034899536054581404, 0.044523710518011024, 0.04340160358697176, 0.028031117914776717, 0.029748909042349884, 0.03133157840264695, 0.006884607561265251, 0.07068202937287943, 0.09052546708179371, 0.05611383163237146, 0.03618778567761183, 0.09417657580758844, 0.01832928681480033, 0.017707221176741377, 0.0682791740234409, 0.02698877447151712, 0.06089104725314038, 0.024153202073648572, 0.05350383650511503, 0.01709632422508938, 0.02494975638442806, 0.048767343163490295, 0.07861606470708336, 0.02729340107180178, 0.01900125022179314, 0.052752413254763396, 0.0333531818884824, 0.0049578331610453975, 0.03456312178501061, 0.05255037606028574, 0.03472949517890811, 0.06534689172570195, 0.041778561393065114, 0.021815024682187607, 0.021504611874531423, 0.006116723899529981, 0.007018156823635633, 0.027947600432006375, 0.05320113864062088, 0.043971108206148656, 0.027353807651836957, 0.037799455624605925, 0.011151361711589354, 0.0387522239637162, 0.02313202722663326, 0.04159978437902672, 0.038882231273289235, 0.01993487708802734, 0.06980458181351423, 0.030076722880559306, 0.1142432311815875, 0.05144629441201687, 0.04342627851292491, 0.4284352074776377, 7.593138200896127, 33.162876401628765, 23.766252483640397, 79.7028694152832, 71.861097744533, 87.48924309866769, 74.35400022779191, 56.361167498997276, 34.257328850882395, 35.318120752062114, 105.9740777696882, 82.41325051443917, 40.2641681262425, 42.86780057634626, 42.579214096069336, 32.359998158046174, 9.490845833505903, 2.3894398978778293, 0.23459173047116824, 0.1456259779099907, 0.07942234072834253, 0.16449843879256928, 0.06914269804422345, 0.4832300586359841, 0.4446205204086644, 0.9581068626471928, 8.364794714110237, 7.040171027183533, 5.980688427175794, 3.5708397158554623, 0.9288625461714608, 6.2902202521051676, 5.485231927462986, 7.444334711347308, 11.082043239048549, 9.442287479128156, 9.000149284090314, 10.955174343926565, 11.778832912445068, 13.921814560890198, 8.185366170746939, 9.713568602289472, 11.473734906741551, 10.311177083424159, 8.526065877505712, 7.45434706551688, 7.243380648749215, 8.700712323188782, 10.456311055592128, 7.902433787073408, 8.666753002575465, 6.972254991531372, 6.500892238957541, 3.7021713086536954, 5.8744348372731885, 5.682960723127637, 4.158675338540759, 3.632931424038751, 2.578141680785588, 2.7375316194125583, 2.2545890424932753, 0.5546666596617017, 0.03526995849928685, 0.8407622650265694, 0.4388710760644504, 0.1889261608677251, 0.04674754797347954, 0.09737614661987339, 0.04503838611500604, 0.05007352985973869, 0.04934752453118563, 0.09344735422304698, 2.114020036799567, 20.843489272253855, 49.97079808371407, 80.33913680485317, 72.12507370540074, 51.88948406491961, 32.518014090401785, 19.2580441066197, 30.300461769104004, 51.00926194872175, 65.19266836983817, 60.483561515808105, 67.40416186196464, 73.94953169141496, 68.04835019792829, 85.53483295440674, 76.65893309456962, 18.15078960146223, 0.14585927182010242, 0.03701122184949262, 0.04219475441745349, 0.09940044049705778, 0.06267561470823628, 0.03082501808447497, 0.04357685900426336, 0.05869659036397934, 0.02529763619947646, 0.014414175380287426, 0.055174111521669796, 0.009345416162562157, 0.06666544132999011, 0.02048122669969286, 0.03476236341521144, 0.013322245446033776, 0.014856564945408275, 0.04218428462211575, 0.06765623137887035, 0.0716263126315815, 0.052385088322418075, 0.030954960933221237, 0.057606232086462636, 0.03567905744005527, 0.02634528069756925, 0.01639235092859183, 0.062413930892944336, 0.01869209609659655, 0.041628676400120766, 0.027923176564010124, 0.021255346946418285, 0.051559708147708855, 0.0488106642317559, 0.011532529606483877, 0.046451567605670006, 0.02955718558015568, 0.021953846161652888, 0.039260853813695054, 0.014819617017305322, 0.02712886141879218, 0.04912913803543363, 0.03635907505771943, 0.017633148901430622, 0.01923851016908884, 0.03094857252602066, 0.036652029159345796, 0.07954527770302125, 0.15419769366937025, 0.08045682843242373, 0.1442108524164983, 0.12345890381506511, 0.17142971472016402, 0.14697984526199953, 0.07832915295979806, 0.20730900445154735, 0.12334561560835157, 0.09882273578218051, 0.1377756262996367, 0.16995517670043878, 0.1254222991743258, 0.10543326142110995, 0.10332341106342417, 0.2771237982170922, 0.1132561866460102, 0.15684940852224827, 0.15887431986629963, 0.11574904966567244, 0.11274136177131108, 0.12466611260814325, 0.06509590840765409, 0.16586939165634768, 0.1910453885793686, 0.16436191754681723, 0.15888343937695026, 0.19404549045222147, 0.10291676502674818, 0.09874133872134344, 0.10247487588120358, 0.2564912853496415, 0.1834960893860885, 0.10300835368356534, 0.1565834635070392, 0.21178725415042468, 0.15852320513554982, 0.11789115757814475, 0.7601039388350078, 11.493051767349243, 48.06332996913365, 29.725599084581646, 87.94469056810651, 80.94632598331997, 92.42123426709855, 74.59818077087402, 51.05383811678205, 39.52303852353777, 44.058242389133994, 97.84035669054303, 78.72186715262276, 73.80126408168248, 72.47485991886684, 53.56639705385481, 37.90471969332014, 11.95361658505031, 3.344669337783541, 0.5322766325303486, 0.7588235161134175, 0.14636997798723833, 0.28606545126863886, 0.13359116869313375, 0.3998730901096548, 0.24972729544554437, 0.41544658158506664, 10.766801731927053, 16.074389934539795, 8.705907838685171, 14.76373212678092, 14.983413321631295, 19.592281988688878, 15.986191238675799, 25.173874139785767, 19.541572298322404, 21.429715735571726, 25.30981390816825, 18.214782510484966, 12.987746511186872, 16.549169029508317, 11.469071796962194, 12.625431827136449, 11.897408264023916, 12.068604929106575, 10.900757789611816, 15.406475237437657, 15.545124803270612, 19.168492249080114, 15.795918294361659, 16.95062378474644, 11.454521400587899, 10.736526693616595, 9.346528274672371, 8.977810825620379, 6.262572501386915, 4.62914741890771, 5.467946980680738, 5.385500090462821, 2.8505351671150754, 5.266785774912153, 2.711959643023355, 1.2855181396007538, 1.0388689232724053, 1.4243445588009698, 1.0109064408711024, 0.349506358483008, 0.12006815576127597, 0.20791714824736118, 0.11776435295385973, 0.22057986019977502, 0.20472112617322377, 0.9327528859887804, 2.831706417458398, 31.949700083051408, 72.49081298283168, 121.67932728358677, 101.79948193686349, 89.02913066319057, 45.53373057501656, 20.206028529575892, 26.744969538279943, 51.20287002835955, 69.72490882873535, 65.48439543587821, 81.79477051326207, 83.43872124808175, 77.89797755650112, 93.1203898021153, 90.13973767416817, 24.337001834596904, 0.2846668006053993, 0.35563097840973307, 0.14315205280269894, 0.2470220848917961, 0.09645542209701878, 0.08699662358100925, 0.18204975128173828, 0.1687359714082309, 0.09328800705926758, 0.22732798595513615, 0.19849528239241668, 0.12380498381597654, 0.12677202746272087, 0.049310384916939905, 0.13318362699023314, 0.1268786931676524, 0.1095115282971944, 0.1124624228104949, 0.15245707492743218, 0.11619631280856473, 0.13031201250851154, 0.11327300752912249, 0.17490891659898417, 0.08478605827050549, 0.12038986278431756, 0.10151307284832001, 0.14454743292714867, 0.08276160154491663, 0.13762197883001395, 0.06812135356345347, 0.11778161488473415, 0.1072323630963053, 0.2143507730215788, 0.1324579202170883, 0.08768309067402567, 0.1501317625599248, 0.09035875102771179, 0.10747191988463912, 0.16226523076849325, 0.08369261265865394, 0.23476177134684154, 0.11459440019513879, 0.09767799970826932, 0.13777148723602295, 0.13168193399906158, 0.13312745786138944], [0.04779290580855949, 0.05202178031738315, 0.10674900189042091, 0.037797718574958186, 0.028886151766138415, 0.035616622040314336, 0.02279558072664908, 0.016836355407057062, 0.06032602435776165, 0.018265652104413936, 0.07243733839797122, 0.016653388439278518, 0.04536075470969081, 0.03251303679176739, 0.03051189792209438, 0.12071151552455765, 0.029591105545737913, 0.08512213666524206, 0.02335023899961795, 0.02908104398686971, 0.03302094400195139, 0.03356320204745446, 0.05931908517543759, 0.06838539189526013, 0.02311800021146025, 0.03582293061273439, 0.07358788951699223, 0.03589971363544464, 0.038888182025402784, 0.03583909670955368, 0.1108627493626305, 0.011900773105610694, 0.09378324941332851, 0.07222563547215291, 0.007396393871333982, 0.1038096153310367, 0.1705497090837785, 0.14450345028723988, 0.4358828621251242, 8.196174093655177, 51.03739867891584, 61.67105034419468, 17.21770211628505, 53.05956070763724, 63.57664244515555, 28.46668972287859, 18.666632550103323, 21.80591552598136, 23.652472257614136, 23.581668376922607, 19.843535797936575, 27.652249676840647, 41.207139423915315, 35.288417203085764, 18.225237812314713, 6.554203161171504, 0.3831131937248366, 0.055548164128725014, 0.00740306217422975, 0.08850832496370588, 0.028636101433741193, 0.21857451780566148, 0.23267074355057307, 0.6449937298893929, 0.7758627789361137, 4.901593233857836, 11.342865586280823, 8.145451375416346, 7.885355114936829, 0.3701809676630156, 4.408824384212494, 5.992441305092402, 3.315886207989284, 5.292398571968079, 9.466117194720677, 7.234454384871891, 5.82532627241952, 9.596605232783727, 7.579181006976536, 11.757855432374136, 13.319029671805245, 17.56261416843959, 13.787498065403529, 15.771841049194336, 8.19639904158456, 5.319690227508545, 4.392311121736254, 10.013988733291626, 7.330317378044128, 3.085398393017905, 5.382534946714129, 3.4531326719692776, 5.158578872680664, 2.212983012199402, 3.0262119003704617, 2.728604487010411, 1.9308244841439384, 4.822207025119236, 3.981041167463575, 1.5544223274503435, 2.0902068231787, 0.6345967277884483, 0.301860687988145, 0.33358350289719446, 0.42583506128617693, 0.26215157019240515, 0.22155845697437013, 0.11484798230230808, 0.1174627034259694, 0.09186354492391859, 0.15366017179829733, 0.02582592999429575, 0.09688445300396, 0.27534774637648035, 6.588629748140063, 25.49920964241028, 51.029623644692556, 59.005582400730674, 71.58733872004917, 97.56748008728027, 39.183782305036274, 21.025474752698624, 35.06793696539742, 37.31941386631557, 47.073058809552876, 58.956792150224956, 68.80296625409807, 59.51677526746477, 63.97701154436384, 67.70717975071499, 19.53444344656808, 0.4812926511679377, 0.1577029920050076, 0.03107470540063722, 0.029305262491106987, 0.001667302185004311, 0.017987836119053618, 0.11097012074398142, 0.06581232603639364, 0.03528342402673193, 0.014369305555841752, 0.0687243812052267, 0.08372520269559962, 0.021991584583052566, 0.05142555498917188, 0.021934730133840015, 0.04418064321258238, 0.012067221138360245, 0.10220208444765636, 0.04594684272472348, 0.03390364342236093, 0.07589650313769068, 0.04460980982652732, 0.01502172545795994, 0.015207616911668862, 0.039373609370418956, 0.03272861415254218, 0.04080917573134814, 0.050665453275931735, 0.023005024130855287, 0.06284140795469284, 0.03362316079437733, 0.07377153501978942, 0.014716064091771841, 0.03763521283066698, 0.026166344227801477, 0.021222916365201985, 0.03065401708175029, 0.023136603945334042, 0.08366477915218898, 0.02668789677721049, 0.0425965251800205, 0.02370626971657787, 0.056400075022663386, 0.04364402379308428, 0.03821915328236563, 0.029842590979699577, 0.03263652337981122, 0.01662318854193602, 0.0684602614492178, 0.013992655856002654, 0.013494412680821759, 0.031683836464903185, 0.006791308572116707, 0.07708140169935566, 0.011801334646796542, 0.05153893819078803, 0.03908079776114651, 0.01415060438947486, 0.06266873436314718, 0.04258576700729983, 0.04159228317439556, 0.004194181013320173, 0.03780265830989395, 0.047493800786989074, 0.07274140351052795, 0.01322603935841471, 0.04571464804134198, 0.016582737676799297, 0.04268647517476763, 0.1273191845310586, 0.005127357926020133, 0.0035324742992608143, 0.0813756055597748, 0.04668101082955088, 0.012680852586137397, 0.04137781861105135, 0.024310142134449313, 0.12232868160520281, 0.019672624999657273, 0.016057459970137904, 0.110891621027674, 0.16429057637495653, 0.15323555815432752, 0.37109566000955446, 12.869662744658333, 62.35734476361956, 68.14693818773542, 20.045773540224346, 64.81487396785191, 72.59579331534249, 47.91748033251081, 30.920769146510533, 27.49722146987915, 28.083065782274517, 21.049508571624756, 25.800054482051305, 34.5849746295384, 41.64941658292498, 40.72561536516462, 21.72349078314645, 7.610573836735316, 0.5401946476527623, 0.08937188291123935, 0.11839233711361885, 0.05238327324124319, 0.01665417553990015, 0.11186846039657082, 0.1858713419309684, 1.0229685136250086, 2.489224063498633, 5.469124700341906, 6.459015446049826, 3.028320461511612, 2.1639823615550995, 0.13644923961588315, 1.4380910268851688, 1.6083058246544428, 4.058803669043949, 2.7288628731455122, 6.092404169695718, 10.485906038965497, 9.993493284497942, 13.509988750730242, 12.456118123871939, 9.305818779127938, 14.442192077636719, 16.369089092527116, 17.71602691922869, 15.963383776800972, 8.414962444986616, 7.946355955941336, 9.243233748844691, 7.969619393348694, 8.802721432277135, 7.337778006281171, 8.750649894986834, 7.4929199899945935, 6.535989327090127, 3.8725502576146806, 5.090172989027841, 4.8763647590364725, 7.602196046284266, 8.118270891053335, 6.538313499518803, 2.679118982383183, 4.105541595390864, 0.9208879683698926, 0.21085133722850255, 0.18716441254530633, 1.1056773726429259, 0.5690098042998994, 0.2736472561955452, 0.022286306268402507, 0.18079528930996144, 0.06408381235918828, 0.19930402828114374, 0.06050715928098985, 0.16313181498220988, 0.37862270325422287, 6.814123545374189, 28.914997918265207, 51.92923123495919, 55.30390528270176, 54.65118455886841, 53.115066392081125, 28.30672308376857, 30.54492024012974, 50.40459149224417, 49.726186752319336, 55.973638670785085, 66.744277545384, 80.18178095136369, 69.27354690006801, 71.17891665867397, 82.30836745670864, 33.904759883880615, 0.9202422201633453, 0.12773356586694717, 0.03962573601997324, 0.03164463071152568, 0.030739977290587764, 0.05465913058391639, 0.0936464499682188, 0.04871773546827691, 0.06189287028142384, 0.07728628534823656, 0.010930116038902529, 0.03064021228679589, 0.03091307496652007, 0.022252343894381608, 0.01422609225846827, 0.052498963461922746, 0.01622243388555944, 0.035278307872691324, 0.06899635839675154, 0.0479701662968312, 0.05625486174332244, 0.02519109602352338, 0.027222964047853435, 0.03836869900780065, 0.010682259919121861, 0.0312904863219176, 0.015739588366289223, 0.04506090669227498, 0.0039110236851099345, 0.012917669789333428, 0.00258140017727523, 0.03441749120663319, 0.02909895052601184, 0.02771377217556749, 0.052764813482229195, 0.05678664320813758, 0.02459087242771472, 0.03188317309000662, 0.025293936487287283, 0.03465477150997945, 0.026920013429064835, 0.014980287324371082, 0.046184479258954525, 0.022545404865273407, 0.05543460111532893, 0.12107155977615289, 0.19655940841351235, 0.24401978456548282, 0.09758441615849733, 0.11876884262476649, 0.16402563559157507, 0.1729960042451109, 0.08800139823662383, 0.12695361700441155, 0.10686054626213652, 0.21431867831519671, 0.18062360637954303, 0.09533117778067078, 0.1736919233309371, 0.1767941718654973, 0.18897072704774992, 0.07915921841881104, 0.14742211438715458, 0.12973398209682532, 0.20180183782109193, 0.10591416633022682, 0.12630744810615266, 0.11913352805588927, 0.13121318843747887, 0.18812053624008382, 0.1493786701134273, 0.16694562962012632, 0.1352201955659049, 0.12337909452617168, 0.19892775347190245, 0.17125332275671618, 0.14328093374414103, 0.19524993082242353, 0.08980046598506825, 0.09108861722052097, 0.21202772696103367, 0.32924253440329004, 0.35530392453074455, 0.8902751824685505, 20.170585768563406, 77.77798216683524, 78.02997248513358, 29.60289737156459, 73.39823382241386, 77.55793271745954, 43.88225494112287, 29.67868137359619, 35.983205795288086, 40.03841767992292, 37.0727493422372, 30.99018165043422, 40.03714268548148, 59.71288122449602, 50.807732922690256, 28.08720690863473, 10.862467135701861, 1.0290836883442742, 0.3389313087931701, 0.19981092108147486, 0.2035409773566893, 0.20907715814454214, 0.6486576018588883, 1.139168232679367, 3.9875103746141707, 4.956474883215768, 13.663452744483948, 23.609044279370988, 21.550015108925955, 24.97210192680359, 11.327905246189662, 16.228947401046753, 23.32689356803894, 18.605568306786672, 19.62572887965611, 24.909062658037456, 23.461379425866262, 20.92618325778416, 23.919778142656597, 23.215183905192784, 26.983506407056534, 26.034274782453263, 31.15354422160557, 30.245098522731237, 30.30913312094552, 19.733582292284282, 19.904355117252894, 18.072646686008998, 24.64800841467721, 18.710039683750697, 14.552958522524152, 17.317683219909668, 11.517557195254735, 17.39454766682216, 7.772012625421796, 10.613302997180394, 7.768538526126316, 11.018064226422991, 16.365846020834788, 10.624220354216439, 5.652250119618007, 6.1205626130104065, 1.9289447792938776, 1.2803050364766801, 1.5475554444960185, 2.8413885150636946, 0.8167510820286614, 0.5255950167775154, 0.32779084944299286, 0.6122271652732576, 0.2716489162828241, 0.660709795142923, 0.21093718547906193, 0.47039271891117096, 0.6442725285887718, 10.212083612169538, 37.83477912630354, 66.49789442334855, 76.23012501852853, 96.89056573595319, 124.94388280596051, 49.034733295440674, 29.4371828351702, 49.34959438868931, 54.39235026495797, 62.965708187648225, 74.29286997658866, 89.49634838104248, 81.5929114477975, 79.082930292402, 92.25297669001988, 42.21295370374407, 1.9399470346314567, 0.35732001491955345, 0.12850739434361458, 0.08979561445968491, 0.2342199475637504, 0.11679611062364918, 0.15937216100948198, 0.2838035954960755, 0.1361801733395883, 0.16483367580388272, 0.2329997516104153, 0.2832326761313847, 0.07077791994171483, 0.14806293642946652, 0.09318980947136879, 0.10910860741777079, 0.07573782772357975, 0.18445967696607113, 0.1963275529976402, 0.16146565867321833, 0.19976745412818023, 0.10755625500210694, 0.16363089105912618, 0.11050880514085293, 0.11556775867938995, 0.09867661326591458, 0.11021129467657634, 0.14475821304534162, 0.06875897970582757, 0.10566520504653454, 0.08829312079719134, 0.20909281873277255, 0.0627615036708968, 0.10891789836542946, 0.1004391758303557, 0.18376751696424826, 0.13541486726275512, 0.11429003652717386, 0.15305930189788342, 0.13926650344261102, 0.09818001384181635, 0.13561461440154485, 0.16255485665585312, 0.09697697803910289, 0.15583073746945175], [0.031404436100274324, 0.04206549349640097, 0.04713505932262965, 0.060519053999866755, 0.012575907815646912, 0.04061200702562928, 0.029400389708046402, 0.04039848901863609, 0.05957404470869473, 0.04453965269827417, 0.020710161022309746, 0.027257840747811964, 0.0678040502326829, 0.04508925588535411, 0.030639686422156434, 0.07164891463305269, 0.05794389146779265, 0.01794832163224263, 0.009103484501663064, 0.0395281626842916, 0.07201382398073163, 0.03506979745413576, 0.03699992424143212, 0.07030093017965555, 0.047161535759057314, 0.07183198338108403, 0.08141761366277933, 0.026201195482696806, 0.09366016316094569, 0.05795016113136496, 0.02428648840369923, 0.10771740028368575, 0.021222683966958096, 0.03054405369662813, 0.035935767593660524, 0.16237907537392207, 0.6659853234887123, 1.8019162927355086, 34.08436039515904, 87.1782556261335, 76.87425776890346, 68.21462753840855, 43.23783384050642, 38.165152072906494, 22.928320578166417, 12.930885059492928, 35.747231074741904, 40.09672001429966, 28.571595362254552, 37.20045028414045, 49.22742073876517, 42.471027169908794, 29.30654627936227, 12.464158926691328, 3.1847780432019914, 0.053680231861237965, 0.06074107065796852, 0.05727101543119975, 0.037280396691390445, 0.028665068093687296, 0.9590564859764916, 1.4421553973640715, 0.13059241031961782, 0.7448364666530064, 3.598113566637039, 1.5301149232046944, 4.313533314636775, 2.9687331446579526, 2.84546428493091, 1.5344244348151344, 0.406605134585074, 1.801973398242678, 3.225492532764162, 2.66868018252509, 7.727721333503723, 3.582629506077085, 2.3369988032749722, 10.560574855123248, 13.916176097733633, 11.243405597550527, 7.264149248600006, 10.393843276160103, 14.028944492340088, 7.900184307779584, 7.779434170041766, 2.9807587393692563, 6.138006499835423, 4.230462389332907, 6.218499209199633, 5.348668558256967, 6.809120408126286, 5.730350477354867, 5.8356834309441705, 1.4603854077202933, 6.930448549134391, 10.462249159812927, 6.753226927348545, 3.201500403029578, 3.542617218835013, 2.355897903442383, 2.61566629580089, 0.17222149723342486, 0.15226424884583267, 0.1733194211763995, 0.15164002377007688, 0.47219675353595186, 0.27526740783027237, 0.06411096054528441, 0.09129376549805913, 0.2454450066600527, 0.10817409506333725, 0.017048066814563105, 0.04061421226443989, 0.050452878432614465, 0.1114168885563101, 3.7547913193702698, 24.409396852765763, 43.017919881003245, 66.64646080562046, 106.36150932312012, 75.58961227961949, 38.19051994596209, 20.545682532446726, 32.24788897378104, 65.31956332070487, 43.95548548017229, 29.009528160095215, 56.65503808430263, 61.790573256356375, 65.28066730499268, 72.27942793709892, 50.25149835859026, 4.533789038658142, 0.7111833010401044, 0.04817091427477343, 0.04578982972140823, 0.08841405609356505, 0.1179550891476018, 0.06039935363722699, 0.11297599239540951, 0.09107026284826653, 0.04731588551242437, 0.04683884146756359, 0.05570260548431959, 0.04774984258360096, 0.06225630720811231, 0.02903587730335338, 0.06949195358902216, 0.026754936037052954, 0.05591335506843669, 0.006912282460169601, 0.01826999642487083, 0.038315091348652325, 0.06708465383521148, 0.018473443275849735, 0.04041184258780309, 0.015404919628053904, 0.06392011578593935, 0.043320874883128066, 0.010234360649649586, 0.03508290335802095, 0.02573284856043756, 0.03531779861077666, 0.023936226930735365, 0.03776775786120977, 0.03387983362855656, 0.033485435148967166, 0.05204563421596374, 0.06976266870541231, 0.05548360491437571, 0.021359196731022427, 0.03759203425475529, 0.08501114190689155, 0.08029030236814703, 0.04735518626070448, 0.0408104004870568, 0.012057864988621856, 0.05627963844952839, 0.0775967219046184, 0.009377169056928583, 0.032725082377770116, 0.026218089308323603, 0.036305026350809, 0.042106354875223975, 0.05702679032193763, 0.07255773086633001, 0.06414842924901418, 0.0689758937805891, 0.06237801603440728, 0.06634076232356684, 0.05906013585627079, 0.06708535951163087, 0.01718401300188686, 0.053505356423556805, 0.051523121539503336, 0.019088029761665633, 0.03445344338459628, 0.03243467278246369, 0.024980287067592144, 0.041405591049364636, 0.008766877697780728, 0.03563531907275319, 0.05662580326731716, 0.01882557411278997, 0.03116775969309466, 0.04088266446654286, 0.07168691937944718, 0.06577280137155737, 0.03224623342975974, 0.08650737947651319, 0.019084586196445992, 0.11346974197242941, 0.5700903034635952, 4.604744911193848, 46.26029327937535, 99.2150091443743, 88.24895913260323, 80.8883363178798, 51.7469938823155, 46.47299500874111, 32.960871423993794, 12.69549572467804, 26.84537969316755, 36.46636268070766, 27.415684359414236, 37.195513589041575, 47.482693331582205, 41.98260702405657, 31.56918546131679, 13.949615171977452, 3.618768172604697, 0.07056278362870216, 0.018113765433164578, 0.08837656024843454, 0.19006996734866075, 0.0657790167523282, 1.3587051438433784, 1.7937708326748438, 0.1818525418639183, 0.8303782365151814, 2.4927687304360524, 6.427833667823246, 2.571268392460687, 1.542916219149317, 0.624044694006443, 0.8922706725341933, 0.3795950167945453, 1.0065706563847405, 0.4943596071430615, 1.7588446268013544, 5.99499476807458, 6.7383265154702325, 9.175194382667542, 9.808871831212725, 11.22553743634905, 13.08406504562923, 14.357008031436376, 12.853109530040197, 14.673542772020612, 9.282220959663391, 7.2621177690369745, 3.882633830819811, 4.598312182085855, 2.5475346488612036, 3.560432400022234, 4.039681792259216, 3.19679907815797, 5.601170003414154, 7.1230617335864475, 1.536517253943852, 0.820528296487672, 0.635754797075476, 2.7660007774829865, 2.726811634642737, 8.928990176745824, 7.7612950290952405, 5.384108279432569, 1.256772899201938, 0.22404279080884798, 0.08481277219418969, 0.6852101204650742, 0.8888485761625426, 0.4469157058213438, 0.23778782039880753, 0.13844892302794115, 0.3431992397776672, 0.2264313833521945, 0.06823290472051927, 0.03763829677232674, 0.14454949567360537, 0.03956306652565088, 3.3866672899041856, 24.474595274244034, 35.88979768753052, 64.13228988647461, 100.64062663487026, 51.384721755981445, 29.998190811702184, 26.71806958743504, 43.55491835730416, 73.70693533761161, 53.1327669279916, 46.12463665008545, 66.68137550354004, 72.48735972813198, 73.79437841687883, 83.92447675977434, 70.07283987317766, 10.155969091824122, 0.5515502297452518, 0.029383684175887277, 0.08091078193059989, 0.08467762837452547, 0.11377940499888999, 0.011669100894193565, 0.021903286821075847, 0.03155943724725928, 0.04590223922527262, 0.05983128411961453, 0.03545248102662819, 0.03402891795017889, 0.04205227902691279, 0.015006550022267869, 0.04080747600112643, 0.0824691325958286, 0.024840315471270254, 0.027967652838144983, 0.058807015152914185, 0.026471605258328573, 0.054527616926601956, 0.02320614530305777, 0.04416826334116714, 0.061381173453160694, 0.009781954211315938, 0.026710044160219173, 0.012161538354121149, 0.027925856777333787, 0.06156557212982859, 0.013728832959064415, 0.029141420032829046, 0.051712008725319586, 0.051090752240270376, 0.041092308038579564, 0.028773294429161718, 0.05944050901702472, 0.016718687256798148, 0.005763215212417501, 0.060060907155275345, 0.08310569343822342, 0.009948521835862525, 0.0401550510099956, 0.04554885818756052, 0.1495720525937421, 0.18970230993415627, 0.16924814321100712, 0.10889284685254097, 0.1350132423852171, 0.09260899028075592, 0.07707229575940541, 0.17577820138207503, 0.16796648555568286, 0.13882196801049368, 0.10136720817536116, 0.09073178243956395, 0.15783275504197392, 0.18536501910005296, 0.12090233314250197, 0.22977339902094432, 0.12505188690764563, 0.12993709476930754, 0.09857733002198593, 0.11984229859496866, 0.19197332592947142, 0.1738646240638835, 0.13674151178981575, 0.15473822823592595, 0.09137989873332636, 0.29920555331877297, 0.17083725865398133, 0.11258153963301863, 0.2860799990594387, 0.16248571393745287, 0.11034459288098983, 0.22919420152902603, 0.1365397290459701, 0.14850618264504842, 0.07436868654830114, 0.27005886446152416, 0.78258016705513, 7.720004490443638, 60.383813176836284, 113.72705146244594, 95.13643046787807, 89.62453569684709, 60.6588784626552, 58.28048576627459, 39.95732525416783, 23.278169325419835, 55.57778590066092, 57.28928702218192, 44.88986880438668, 58.79720592498779, 70.18058558872768, 61.92095620291573, 44.21147448675973, 20.10336021014622, 4.71561210496085, 0.2076287708644356, 0.20708450435527734, 0.12450160857822214, 0.43552570843270844, 0.29959530383348465, 2.16164168715477, 3.6893835834094455, 0.6063606600676263, 4.503094937120165, 12.737612230437142, 15.850555453981672, 20.76722410746983, 11.94558881010328, 8.723802055631365, 4.736666883741107, 2.6775070003100803, 9.376089385577611, 10.862140570368085, 13.724009769303457, 24.824204308646067, 18.15208544049944, 19.337203196116857, 24.237625224249705, 25.18588583809989, 24.926551273890905, 20.173130546297344, 22.865387269428798, 30.08478968484061, 23.030160324914114, 22.51566011565072, 15.43006784575326, 21.39894563811166, 14.669535398483276, 23.223784037998744, 20.500727687563213, 16.973012617656163, 19.395057371684484, 17.229781559535436, 6.67638897044318, 14.188062582697187, 22.237975358963013, 19.145855018070765, 10.796664220946175, 13.136946048055377, 10.47012494291578, 11.254096269607544, 2.3277173127446855, 0.49979266417878015, 0.5881557283656937, 1.1293007050241743, 1.148198502404349, 0.8190681976931435, 0.8586014392120498, 0.6677545085549355, 0.8506624166454587, 0.808845226253782, 0.23857728232230457, 0.1903505144374711, 0.16520737218005316, 0.263109200234924, 6.643183095114572, 37.400415965488975, 63.794774191720144, 82.22421782357353, 121.7491010938372, 94.63386726379395, 48.02943318230765, 32.07880456107003, 45.719900608062744, 80.82031345367432, 59.341791834150044, 43.16680588041033, 74.69394084385463, 82.99677412850517, 79.83377347673688, 94.72018473488944, 78.28472123827252, 12.709896734782628, 0.6612938780869756, 0.13606970783855232, 0.23320304070200237, 0.24454619203295025, 0.23337281016366823, 0.20527918051396096, 0.2202126777597836, 0.13882157446018287, 0.08227240493787186, 0.0970419409817883, 0.13572752262864793, 0.08699316983776433, 0.14586961269378662, 0.10791930516383477, 0.17365560813673905, 0.22431932097034796, 0.24304372551185743, 0.09803393203765154, 0.16909696560885223, 0.11059455161115953, 0.14058219641447067, 0.1122331933251449, 0.08801961690187454, 0.13174494276089327, 0.07010469785226242, 0.11913915989654404, 0.08851543601070132, 0.1066275644781334, 0.16148567545626843, 0.08536923197763306, 0.10046708397567272, 0.1177112508033003, 0.08779712526925973, 0.10953661373683385, 0.17387127370706626, 0.24119482615164348, 0.2193316678915705, 0.12581279607755796, 0.18077933016632283, 0.26802779201950344, 0.11807282854403768, 0.1400066494409527, 0.11708745998995644], [0.013589931751734443, 0.005128189131417977, 0.1050491291763527, 0.02240717031859926, 0.0338952261954546, 0.0742061570552843, 0.04549436504021287, 0.040725027211010456, 0.03653727192431688, 0.03100895875000528, 0.04579489498532244, 0.04113197519576975, 0.0499522858299315, 0.03409776211317096, 0.04181211155706218, 0.06728241965174675, 0.0032956308028328097, 0.04683529951476625, 0.015598215595153826, 0.042377276944794824, 0.010002982752796794, 0.0384846911765635, 0.016651244268619587, 0.10105600487440825, 0.028400617551856806, 0.026804667564907243, 0.029965846865837063, 0.009431246601577317, 0.04329551802948117, 0.13446444326213428, 0.07265363500586577, 0.038295732744570286, 0.07958190502332789, 0.03113962084587131, 0.11226260781820331, 0.7142416483589581, 12.269692744527545, 59.88855947766985, 91.36935343061174, 66.15371540614537, 63.21587807791573, 71.51690483093262, 58.80685002463204, 42.16172463553292, 26.210404668535503, 37.31525536945888, 39.712345668247764, 32.96710743222918, 49.54960870742798, 43.78019632611956, 33.398910181862966, 20.078608989715576, 6.701692572661808, 0.8604099793093545, 0.008123590028844774, 0.12295628578535148, 0.17940526961215905, 0.042997586873493025, 0.03071988926136068, 0.11852053952004228, 0.39450690948537415, 0.775302526141916, 0.13625690207949706, 0.6058030671307019, 0.2842768872422831, 5.818471005984715, 3.421099956546511, 0.2089637206601245, 0.12068411628050463, 0.33162620078240124, 0.1132451875933579, 0.04597053038222449, 0.7348308435508183, 0.4728752885546003, 1.3408237376383372, 6.55064959185464, 9.342139618737356, 11.218227062906537, 6.790090160710471, 5.02691615479333, 10.873140437262398, 10.210727844919477, 12.729845881462097, 10.201553617204938, 4.7299171430724005, 3.9785137602261136, 7.404078585760934, 4.882328050477164, 7.853294389588492, 8.587174415588379, 6.297709107398987, 6.00897410937718, 1.7065535698618208, 2.5488387388842444, 1.566836804151535, 3.975496070725577, 5.244044755186353, 6.878524226801736, 5.304141461849213, 2.7635107168129514, 3.161026929106031, 0.4666318435754095, 0.03316900712837066, 0.1995990960193532, 0.044765207916498184, 0.1525658576616219, 0.42555127079997745, 0.1105718749708363, 0.04763525498232671, 0.509969983782087, 0.1756394681121622, 0.06591236245419298, 0.07862223259040288, 0.07809891245727028, 0.014089476017813598, 0.09979774310652699, 0.7363335543445179, 15.904021842139107, 41.801582132067, 44.01963472366333, 39.45477247238159, 47.06393582480294, 60.26324108668736, 36.08354125704084, 36.544036592756, 37.187408515385215, 20.408782175609044, 41.19384057181222, 56.068589278629844, 57.910900660923545, 55.31571027210781, 68.26865673065186, 61.509358814784456, 17.663013901029313, 0.528225832751819, 0.2654876011822905, 0.0780927785007017, 0.14943192154169083, 0.03931564551645091, 0.06568252907267638, 0.02928071648680738, 0.07821950848613467, 0.03898466970505459, 0.007600280921906233, 0.043649920262396336, 0.046157609272216044, 0.04898355834718261, 0.01903688009562237, 0.027869319543242455, 0.03160570315750582, 0.011373674380593002, 0.06248628308198281, 0.05762041346835239, 0.011443220827329372, 0.03816458210349083, 0.029976533792380775, 0.023840248152347546, 0.04800725502095052, 0.020202185958623886, 0.056867745106241534, 0.06728518807462283, 0.012396283481003982, 0.02799755078740418, 0.04406699538230896, 0.02692213894001075, 0.04588104518396514, 0.003990028485921877, 0.026975151184680204, 0.05276266931157027, 0.032090183946170976, 0.032371989717440944, 0.05203323059582284, 0.034538161874349625, 0.008757324772886932, 0.015768940094858408, 0.029907272330352237, 0.04920617550877588, 0.026463834336027503, 0.07440742411251579, 0.022513678264138953, 0.027167273286197866, 0.07400778734258243, 0.05566225979211075, 0.03683407331949898, 0.01971835147456399, 0.0377984140733523, 0.022264681357358183, 0.02932439717863287, 0.02418592612126044, 0.03541398773502026, 0.05482801795005798, 0.021231396356597543, 0.022381808375939727, 0.05738986762506621, 0.03246989553528173, 0.03428643895313144, 0.036775081484977684, 0.02839424441169415, 0.050864440455500565, 0.051653437582509856, 0.01969888260854142, 0.018976312363520265, 0.015539084660953708, 0.0581999027303287, 0.09277931614113705, 0.05006126194660153, 0.025074773068938936, 0.021554909979126284, 0.038296346818762164, 0.02363705914467573, 0.22661096443023, 0.3713608043534415, 21.52682375907898, 75.10730307442802, 101.1091228212629, 75.37838009425572, 70.7913600376674, 78.65799931117466, 66.5757142475673, 50.21629878452846, 26.587196792875016, 25.54973520551409, 39.32220779146467, 33.90980427605765, 47.51715987069266, 42.89833096095494, 38.50718409674508, 21.968819516045706, 9.224364178521292, 1.0294352237667357, 0.06274646054953337, 0.07962054759263992, 0.04575762305674808, 0.08248114945100886, 0.057149218395352364, 0.1884530319699219, 0.5846409169690949, 0.8005194930093629, 0.12734253970640047, 0.361232583544084, 1.1624931182180132, 1.95950990489551, 0.45055357632892473, 0.7711381667426654, 0.1882482636719942, 0.2712106912263802, 0.14324729197791644, 0.25849117232220514, 0.4127026673938547, 0.8698354278291974, 3.4585889620440344, 3.34200405223029, 4.5236581308501105, 5.558184104306357, 5.679186982767923, 7.258790016174316, 8.384243590491158, 9.477401069232396, 6.055923955781119, 3.387020996638707, 2.0136856607028415, 0.8875895408647401, 2.9893265196255276, 4.736556581088474, 8.530889664377485, 6.974572650023869, 3.5995077661105563, 2.245264559984207, 1.364052108355931, 1.933104361806597, 1.4369821378162928, 2.2062311002186368, 1.2577063462563922, 1.049464926123619, 1.7582761773041315, 3.9704039096832275, 4.469988942146301, 1.0486358106136322, 0.1001878600301487, 0.5656842227493013, 0.25574709528258865, 0.1449192836880684, 0.5584745981863567, 0.15362651646137238, 0.13484558995280946, 0.393607850585665, 0.5991291595356805, 0.11868520639836788, 0.1486058865806886, 0.12089382431336812, 0.05964270566723176, 0.07602412200399808, 1.0598404322351729, 16.865147045680455, 38.43912649154663, 48.388578619275776, 38.495323521750315, 44.98942606789725, 51.532867772238596, 34.087136200496126, 42.99326767240252, 44.16610622406006, 36.03495945249285, 54.83809110096523, 66.40669236864362, 67.91102600097656, 63.516603061131065, 74.69352395193917, 78.86108820778983, 32.837801456451416, 1.7842567946229662, 0.4118993090731757, 0.09887313057801553, 0.1309164786445243, 0.090759873789336, 0.02573942526110581, 0.02320104102337999, 0.0308161190977054, 0.03647964733785816, 0.011380742170980998, 0.03949205783594932, 0.023533925214516263, 0.033781927810715776, 0.07135393510439567, 0.0535145471803844, 0.03944371560854571, 0.02509068980413888, 0.03057436046323606, 0.06921394422118153, 0.022280202845909765, 0.04576790286228061, 0.01523170490483088, 0.034085365278380256, 0.06015781552663871, 0.01969396322965622, 0.04651833205882992, 0.022220072768894688, 0.009316161125233131, 0.020354186284488866, 0.07145387652729239, 0.051558083056339195, 0.08806319920612232, 0.023678485403901765, 0.016435663515169705, 0.05301642105249422, 0.034141843140657456, 0.03962019917422107, 0.09199942834675312, 0.04161051201767155, 0.050862876432282586, 0.022197072128100053, 0.04521794344431587, 0.15395738370716572, 0.15560773015022278, 0.1782884688249656, 0.12584350657250198, 0.165103230625391, 0.2194907572120428, 0.12100306845137052, 0.20280674818371022, 0.11864728986152581, 0.09745771331446511, 0.13962132297456264, 0.16034720226057939, 0.11818603532654898, 0.1540533692709037, 0.10019673526819263, 0.10944349159087453, 0.12064681042517934, 0.1437258491558688, 0.14362330894385064, 0.09555328943367515, 0.12746375320213182, 0.1462690255471638, 0.15310602581926755, 0.27122643323881285, 0.09473798889666796, 0.10265428054013423, 0.10044197139463254, 0.10065137408673763, 0.13446786307862826, 0.26008032847728046, 0.18582668075604097, 0.16974367733512605, 0.08926559040056807, 0.16895965726247855, 0.3298753361616816, 1.4778933482510703, 34.55924892425537, 94.16257790156773, 110.43924726758684, 82.1382199696132, 80.91948509216309, 87.69012246813092, 77.09893471854073, 61.582592827933176, 40.80179194041661, 56.4669885635376, 62.84395490373884, 48.58303090504238, 71.49751240866524, 60.18921497889927, 50.246846539633616, 30.990800040108816, 11.988536494118826, 1.795340039900371, 0.15018946517791065, 0.40685323412929264, 0.3123484509331839, 0.6006732338241169, 0.377638040376561, 0.3792191083942141, 0.963883312685149, 1.5275110857827323, 0.24352735813174928, 2.717308670282364, 6.067466216427939, 12.635857599122183, 6.8457973429134915, 2.8339943289756775, 0.20709449239075184, 0.48973074981144493, 0.2496494267668043, 1.2460336983203888, 2.0844478522028242, 4.1466653772762845, 6.8067037378038675, 18.471806798662456, 21.67810341290065, 26.142930712018693, 21.62842379297529, 15.525310277938843, 29.599190507616314, 24.965360437120708, 27.69830581120082, 23.566840921129497, 14.60028270312718, 10.193284392356873, 12.83510501044137, 11.263303501265389, 15.832314695630755, 17.978967598506383, 15.501220873423986, 13.83733662537166, 10.57396924495697, 7.261147626808711, 6.968641059739249, 11.63146596295493, 13.053768294198171, 18.088908944811138, 16.941504274095806, 10.12223732471466, 13.669236251286097, 3.510207780769893, 0.1830710279090064, 0.8334150335618428, 0.5843931159802845, 0.4203334722135748, 1.1689857755388533, 0.41459670290350914, 0.6022468379565648, 1.1268735038382667, 1.4116158932447433, 0.26941148777093205, 0.338845324835607, 0.289771880954504, 0.11529741675726005, 0.20686217557106698, 1.638130532843726, 24.98113805907113, 60.43958636692592, 56.83904722758702, 56.297129426683696, 66.62020356314522, 74.79892117636544, 48.0234751020159, 47.9689039502825, 47.94158363342285, 32.30203628540039, 57.387103761945454, 71.63787296840123, 77.1221694946289, 71.8906831741333, 84.90194933755058, 91.59036867959159, 41.67743171964373, 2.3930325508117676, 0.6025718290890966, 0.28564826079777306, 0.37543220445513725, 0.14658729918301105, 0.08244784016694341, 0.07598019364689078, 0.1582569344235318, 0.15136658772826195, 0.08582000993192196, 0.23576049347008976, 0.12489456177822181, 0.0933747034786003, 0.26234647259116173, 0.16194555935050758, 0.12288308542753969, 0.11807586838092123, 0.09754276089370251, 0.14830339566937514, 0.08640711235680751, 0.09082512171672923, 0.10673983488231897, 0.0947626129324947, 0.16614627465605736, 0.18447521541799816, 0.1364274179296834, 0.1197749064969165, 0.09216713506196227, 0.10558006247239453, 0.0804248626476952, 0.11757159472576209, 0.2980738383318697, 0.2634196164352553, 0.058436399325728416, 0.1994338184595108, 0.14247741257505758, 0.07189858837851457, 0.21371490428490297, 0.13342066641364778, 0.12247755218829427, 0.058990178895848136, 0.10806856929723706], [0.01626791778419699, 0.025550507541213716, 0.011800412687339952, 0.045523538653339655, 0.06826565082051925, 0.0763480206951499, 0.057791485717254024, 0.018695290300196836, 0.02667112848056214, 0.008217906396436905, 0.015846098008166467, 0.07795582977788788, 0.08703143242746592, 0.05562565622052976, 0.21457650805158274, 0.16581053552883013, 0.09578875465584652, 0.06763812127922263, 0.03619192474122558, 0.007083444614961211, 0.006523567983614547, 0.019411733373999596, 0.04217576561495662, 0.004557257044195596, 0.028571905235626867, 0.005668212252203375, 0.0244973058413182, 0.11711997538805008, 0.12540977341788156, 0.023824268652658378, 0.030726884957402945, 0.04360867890396288, 0.13342776388994285, 0.026124027391363467, 2.645618894270488, 41.185735498155864, 75.55252974373954, 77.22680936540876, 69.08668204716274, 78.53247315543038, 64.84963580540249, 36.26197099685669, 36.88715600967407, 31.138101850237163, 39.06074707848685, 44.24104601996285, 28.724441834858485, 51.11741760798863, 46.214980602264404, 34.47584622246878, 14.399485843522207, 3.675598357404981, 0.12131043124411788, 0.0431077436410955, 0.0649201881938747, 0.01308867333656443, 0.04946697722854359, 0.09437588868396622, 0.09500435460358858, 0.13606628802205833, 0.10613044936742101, 0.10547687765210867, 0.5242637853537286, 0.2985769041946956, 0.7133568386946405, 1.6788816090141023, 0.27528765531522886, 0.2559877580830029, 1.1758315967661994, 0.8054982029965946, 0.45182398387363976, 0.5890099225299699, 0.5458709459219659, 0.41403967993600027, 3.939671593053, 3.0197591951915195, 5.441166886261531, 3.6181825697422028, 3.449067975793566, 7.824427230017526, 11.936543124062673, 9.141923802239553, 7.580135515757969, 3.5191752995763506, 9.649534872600011, 18.629386731556483, 41.246080602918354, 48.985623427799766, 63.224723134722026, 50.092363766261506, 40.99495880944388, 14.100569997514997, 8.135447706495013, 4.025717215878623, 3.743647711617606, 2.1818978573594774, 2.8967124606881822, 4.515289459909711, 12.710628032684326, 11.884859817368643, 6.065026530197688, 1.2896563346896852, 0.32071693188377787, 0.19028414014194692, 0.02698860314142491, 0.3146420621446201, 0.36233246166791233, 0.10386615765414067, 0.17032925305621965, 0.24168622121214867, 0.1414339885647808, 0.11709235901279108, 0.1343166854764734, 0.05452047873820577, 0.1153184784842389, 0.11833810859492847, 0.011921820413720394, 0.06042692930038486, 6.109276132924216, 22.499719211033412, 42.76856640407017, 41.61192410332816, 45.8067079271589, 47.10680621010916, 64.3207597732544, 76.14527361733573, 22.256212643214635, 19.24114261354719, 31.82669264929635, 50.00020286015102, 57.977763175964355, 50.88212728500366, 66.56217220851353, 71.83884961264474, 47.082779339381624, 5.256036477429526, 0.556134358048439, 0.12039816805294581, 0.03086783703682678, 0.05506282838593636, 0.0316588765542422, 0.044290766053433926, 0.013028000431534435, 0.03389894456735679, 0.03115750363628779, 0.04687581823340484, 0.05708230805716344, 0.016704251424276402, 0.01768061412232263, 0.03632769620578204, 0.03288642782717943, 0.022414515460176126, 0.044765961090368886, 0.054996630509517024, 0.02037629295539643, 0.053697181666003804, 0.00460484779406605, 0.008043254875311894, 0.041356088527079136, 0.06809681773717914, 0.07899554220161267, 0.05664249183610082, 0.03353675953777773, 0.0657975407583373, 0.012744182803934174, 0.021451479189896157, 0.029984720317380767, 0.023983659921213984, 0.030552202902202095, 0.09050942651395287, 0.10229591227003507, 0.08669790532439947, 0.09568677084254366, 0.05098699066521866, 0.012047309528238006, 0.04858909879944154, 0.03599528868549636, 0.006231798349680113, 0.017802558739536574, 0.005680101033898869, 0.024423849336536865, 0.0413598747524832, 0.061953870579600334, 0.03952714488176363, 0.009473313228227198, 0.005486267751881054, 0.06460903239037309, 0.09912964395646538, 0.07564247998275928, 0.06500245377953563, 0.09412645242576088, 0.10563514594520841, 0.07629592277641807, 0.05473380336271865, 0.06567026794488941, 0.0783601077273488, 0.03107138057904584, 0.02793193984377597, 0.056184976029076746, 0.08705873667661633, 0.027580377279913852, 0.03965897745053683, 0.016964756284973452, 0.10832895711064339, 0.057839247797216685, 0.020872659981250763, 0.031090976670384407, 0.05174726879756365, 0.14635872787662915, 0.014337388964902078, 5.924555667809077, 59.61514091491699, 90.65871252332414, 87.37137385777065, 75.06138242994035, 90.11671829223633, 77.16970906938825, 54.92076424189976, 59.02704538617815, 44.84912109375, 40.95119905471802, 43.14237254006522, 30.28311559132167, 43.5593478339059, 44.002146107809885, 37.309665543692454, 17.08822069849287, 4.617677245821271, 0.15278605584587368, 0.024175892284672176, 0.07303457813603537, 0.040788273460098674, 0.03454622287037117, 0.027202265337109566, 0.16074897641582148, 0.34349062985607554, 0.3696669638156891, 0.7528643501656396, 1.9001206117016929, 1.1681265873568398, 1.8113828876188822, 1.1532567909785678, 1.5976954911436354, 1.3231730333396365, 2.5063952335289548, 1.610109533582415, 1.0202108387436186, 1.5581831485033035, 1.5050713356052126, 1.0676850570099694, 3.186591305903026, 2.3717929933752333, 1.673320010304451, 1.3059115367276328, 0.93232861161232, 2.191767773457936, 3.218132436275482, 1.8476803856236594, 1.4917395881244113, 2.1624880645956313, 8.463056138583593, 18.95240327290126, 40.095521450042725, 52.01148748397827, 62.773118019104004, 52.27385493687221, 41.39061008180891, 16.650772537503922, 8.603775399071829, 5.8347267508506775, 5.664500662258693, 5.056659655911582, 5.082577305180686, 6.424321787697928, 5.48656120470592, 2.820938229560852, 1.6354444026947021, 0.45981256663799286, 0.15912681631743908, 0.3126942595200879, 0.23579450164522442, 0.5252973298941339, 0.7612500116229057, 0.5117599048784801, 0.26404859125614166, 0.4388790013534682, 0.11848346436662333, 0.18448470133755887, 0.06607241529439177, 0.09389014582016639, 0.07696976911808763, 0.14513247939092772, 0.08136745635420084, 0.032563387482826195, 6.311309771878379, 24.28549657549177, 42.233881677900044, 38.413859367370605, 41.37353835787092, 37.11205530166626, 55.78735399246216, 69.69854041508266, 27.938802071980067, 31.106327738080704, 42.86540692193167, 59.2280706678118, 65.79601519448417, 63.55364390781948, 75.68529592241559, 85.41458048139299, 69.55159991128104, 11.238547938210623, 0.652424014040402, 0.09167016244360379, 0.06845640058496169, 0.03591356932052544, 0.095429863913783, 0.023564564463283335, 0.009544285446671503, 0.026293684894751226, 0.011118345893919468, 0.05177346024928348, 0.03169465570577553, 0.02375850164597588, 0.032512300581272156, 0.018494642406169857, 0.04449084567438279, 0.030615869843001877, 0.04365941635998232, 0.06044616576816354, 0.01745754912761705, 0.005826844409706869, 0.03937734131302152, 0.08490999947701182, 0.06033954756068332, 0.06715170666575432, 0.04125533625483513, 0.057004201891166825, 0.043767551093229225, 0.06145583266126258, 0.055863353822912486, 0.03870398351656539, 0.02885211305692792, 0.01102614146657288, 0.00396625346703721, 0.00925408280454576, 0.05531158271644797, 0.04605290114081331, 0.023362179519608617, 0.0022846942010801286, 0.02505690384922283, 0.03746828303805419, 0.09973027636962277, 0.11177380476146936, 0.12204371046807085, 0.07991246014301266, 0.1079878711274692, 0.10905690304934978, 0.17697036026843957, 0.16347465158573218, 0.10835246834903955, 0.048291289779756746, 0.17539523621754988, 0.10242194336439882, 0.16276058847350733, 0.20398195726530893, 0.18707750578011784, 0.31559336824076517, 0.16740374932331697, 0.12790763724063123, 0.16202109386878355, 0.17448898484664305, 0.15121311667774404, 0.08740642480552197, 0.18027768922703608, 0.17917167714663915, 0.10827179732067244, 0.10442658008209296, 0.1096315204298922, 0.25351843344313757, 0.18747196532785892, 0.14680383327816213, 0.17514491107847008, 0.14379852025636605, 0.23521766545517103, 0.2642849385738373, 7.44928617136819, 76.30136489868164, 105.16252817426408, 93.65159348079136, 85.99765941074916, 97.89622020721436, 82.77819074903215, 50.83319459642683, 51.41905975341797, 49.806011131831575, 57.292820181165425, 60.8511073248727, 42.98169544764927, 73.24001639229911, 62.6575277873448, 49.70626279285976, 24.337519475391932, 6.417139087404523, 0.35537063809377806, 0.1816526861595256, 0.5275213505540575, 0.15038073062896729, 0.3027517944574356, 0.3506127234016146, 0.366658339543002, 0.39781403488346506, 0.46648283728531426, 0.7945686866130147, 1.7136194535664149, 2.271210870572499, 4.020083963871002, 6.795419863292149, 2.6945787242480685, 1.856179552418845, 4.42021074465343, 2.4333866025720323, 1.4836733809539249, 2.3780563601425717, 1.762053934591157, 1.5923046661274773, 9.266823751585823, 10.170321464538574, 11.850427150726318, 13.159177677971975, 14.931249720709664, 22.016108955655778, 21.49695345333644, 18.312790325709752, 19.65121487208775, 11.055758203778948, 11.687257392065865, 17.555893523352488, 37.90962164742606, 45.590559891292024, 59.23136411394392, 47.525751318250386, 40.37954643794468, 19.304287842341832, 12.693513751029968, 7.529327682086399, 5.808667532035282, 4.699490981442588, 4.91101108278547, 10.400021961757115, 21.00459541593279, 25.788860934121267, 18.326012747628347, 5.813014933041163, 1.144631905215127, 0.60846715846232, 0.7604106909462384, 1.2531813319240297, 0.8709487680877958, 0.6767430348055703, 0.2691148594021797, 0.376131964049169, 0.8689726026994842, 0.4466753958591393, 0.463261858693191, 0.2915565094777516, 0.39586685651115006, 0.35256172024777954, 0.24619492356266293, 0.13473325169512204, 10.410066451345172, 36.74397448131016, 59.60118893214634, 58.70222405024937, 65.30930083138603, 66.25667381286621, 77.61510249546596, 88.58798953465053, 31.030366556985037, 28.373863526753016, 47.53134114401681, 65.92678724016461, 75.54813153403146, 71.95041683741978, 82.72913646697998, 95.37927695683071, 81.76497663770402, 13.860477600778852, 0.8423399403691292, 0.22305765295667307, 0.23012007613267216, 0.17755092840109551, 0.17276424382414135, 0.219309927629573, 0.05511126560824258, 0.1757981503116233, 0.06575735112918274, 0.13035448880067893, 0.08744514879903623, 0.17510346615953104, 0.13884370827249118, 0.12878100680453436, 0.1251256572348731, 0.1197660176881722, 0.10366516201091663, 0.14115315649126256, 0.18051787705293723, 0.1396600944655282, 0.154456459784082, 0.1689146432493414, 0.10338849614241294, 0.17969528904982976, 0.14968331876610005, 0.18197296825902803, 0.2119236939719745, 0.12882569512086256, 0.18906854465603828, 0.15751399286091328, 0.14498325596962655, 0.19621904167745793, 0.12712863832712173, 0.15107575404856885, 0.11615203161324773, 0.23020318310175622, 0.1892793790570327, 0.1164957367415939, 0.12997992389968463, 0.13822937623730727], [0.08885631164801971, 0.03156301312680755, 0.11571215093135834, 0.23817759805491992, 0.18207767978310585, 0.07725404136415039, 0.14151421854538576, 0.060810891911387444, 0.07694845633315188, 0.056354989763349295, 0.008692707883061042, 0.031077938620001078, 0.26745480990835596, 0.20594938312258038, 0.35386068054607933, 0.11595039814710617, 0.058978894858488014, 0.16745706860508236, 0.09402349152203117, 0.10808058615241732, 0.04485114098393491, 0.07633838549788509, 0.11436885515494005, 0.18858871183225087, 0.1958451010286808, 0.02651431903775249, 0.09968468560171978, 0.16529868942286285, 0.05908400671822684, 0.08373166234897715, 0.24771568338785852, 0.21653030892567976, 0.1439412704535893, 1.3673621650253023, 58.736332757132395, 89.01848602294922, 75.35913358415876, 66.88223402840751, 65.66761943272182, 44.722222668784006, 28.124834878104075, 27.23872242655073, 15.211255175726754, 26.64093589782715, 41.50881631033761, 39.85533612115042, 42.07777302605765, 32.25919369288853, 23.65719529560634, 7.264224810259683, 1.3673061451741626, 0.021761408541351557, 0.0007868615970697387, 0.05966595906232085, 0.06397846979754311, 0.06352981565786259, 0.05376781376877001, 0.0894696055246251, 0.19496590963431767, 0.4030086004308292, 1.163730006132807, 1.239084739770208, 1.6130299483026778, 0.36365419360143797, 0.8554491826466152, 2.7530942814690724, 3.5853264927864075, 7.281914489609854, 10.441119687897817, 10.646296518189565, 14.828128031321935, 17.408629928316387, 17.052857841764176, 15.643071821757726, 20.07584708077567, 14.021388326372419, 9.166007995605469, 5.506954167570386, 5.143595082419259, 7.425259300640651, 9.857940009662084, 9.981888924326215, 9.1724020753588, 32.61241579055786, 68.42151709965297, 88.71492617470878, 96.27817235674176, 93.90484142303467, 104.92763042449951, 104.02821390969413, 103.13559968130929, 60.28455121176583, 26.244869470596313, 24.794585875102452, 25.890594720840454, 26.169498886380875, 23.016310828072683, 16.145471743174962, 11.643373438290187, 11.116276144981384, 6.5727678792817255, 2.476895787886211, 2.8952405282429288, 1.587678034390722, 0.2900235360222203, 1.0610158720186778, 0.6994670097317014, 0.21988660097122192, 0.23460616969636508, 0.6736117856843131, 0.3183618453996522, 0.128551146281617, 0.5037426607949393, 0.14771054605288164, 0.42663328988211496, 0.05982021042811019, 0.09621796876724277, 0.18898827396333218, 0.020070573913731744, 0.10285100819809095, 4.3794708507401605, 25.209653888429912, 49.73970447267805, 41.09200777326311, 77.44425324031285, 107.62858281816754, 61.653165681021555, 30.530085836138042, 16.86543713297163, 31.429029873439244, 33.47240127835955, 61.855573654174805, 65.15100002288818, 58.07093504496983, 66.20675795418876, 61.278359004429404, 11.878907816750662, 0.5179915162069457, 0.06302861576633793, 0.03009865652503712, 0.12511148942368372, 0.040582813056451936, 0.04423118728612151, 0.1800439339131117, 0.10249672470880405, 0.08991669224841253, 0.07814495105828557, 0.04739808324458344, 0.10947609519852058, 0.1709876898676157, 0.1686252209224871, 0.15337171299116953, 0.34369679593614166, 0.05348170608548181, 0.13034414792699472, 0.05118553679702537, 0.036117967816868, 0.09784469540630068, 0.2633906565606594, 0.24828397003667696, 0.17599222489765712, 0.1799623468624694, 0.19992434499519213, 0.2539300870682512, 0.0983911400128688, 0.055640977541250844, 0.041558858539376936, 0.0628987102370177, 0.03340954779248152, 0.06614712199994496, 0.1114210072638733, 0.02365653818872358, 0.017558947704466324, 0.024366226446415697, 0.07661769765296153, 0.24943799525499344, 0.08952609356492758, 0.012762739040356661, 0.08854490478656121, 0.06935771222093276, 0.005714481555125011, 0.13001387779201778, 0.12005473433860711, 0.09867357342903103, 0.02706548964072551, 0.039080499205738306, 0.011292965184631092, 0.0718898827742253, 0.20980420841702394, 0.12382421349840504, 0.1923169224922146, 0.11483686789870262, 0.06519899823303733, 0.07835971417703799, 0.05450270451339228, 0.052340379650039334, 0.08444463980517217, 0.07065959700516292, 0.06767686562878744, 0.1603823232331446, 0.12086768714444977, 0.021813553957534686, 0.08898572863212653, 0.09800586782928024, 0.0941935188270041, 0.05040062784350344, 0.15744613935904844, 0.03343594619738204, 0.14082523408745015, 4.656994930335453, 79.23755550384521, 97.8029545375279, 82.84512274605888, 74.09003816332135, 81.44646426609584, 57.094021797180176, 44.32250322614397, 33.508121967315674, 21.401116950171335, 34.628025668007986, 45.95559392656599, 52.99869796207973, 48.366101196834016, 41.07038845334734, 28.235962629318237, 8.728099516459874, 1.392380673970495, 0.05439522456643837, 0.05715789007289069, 0.12495508710188524, 0.055951559982661686, 0.03965452965348959, 0.05905021567429815, 0.3017215340265206, 0.45038000707115444, 0.9293116820710046, 2.151226771729333, 3.2928353420325687, 4.268033904688699, 2.7597882194178442, 2.8941722427095686, 4.701704851218632, 7.541179571832929, 11.3658059324537, 12.885783433914185, 14.052256567137581, 18.087237903050013, 19.6149765423366, 19.24471398762294, 18.889904226575577, 20.7355055809021, 17.556814159665787, 12.091976932116918, 7.715279715401786, 5.779155927045005, 6.6215342453547885, 7.7224893399647305, 8.095557229859487, 10.580892256328038, 36.212374755314414, 74.14201068878174, 98.66511481148856, 108.36332702636719, 105.79550211770194, 118.58694812229702, 117.63957514081682, 111.57654230935233, 67.9269790649414, 32.45661285945347, 31.740531512669154, 31.017821584429058, 30.509831837245397, 27.86296943255833, 20.364402294158936, 15.407753705978394, 13.996790834835597, 7.920003175735474, 5.1613920245851785, 3.759884783199855, 2.562715594257627, 0.6877175516315869, 1.2721748841660363, 1.2686153437410082, 0.6421336233615875, 0.849865653685161, 1.2534475347825458, 0.854010416993073, 0.32026852880205425, 0.5613451270120484, 0.4962412118911743, 0.45140022518379347, 0.22294033425194876, 0.12724028447909014, 0.12896160568509782, 0.043761807294296365, 0.11496817799551146, 6.201510429382324, 26.960863964898245, 46.46106842585972, 39.30149868556431, 76.6680908203125, 113.35435009002686, 42.667039326259065, 27.938682215554373, 24.566408770424978, 44.27689177649361, 48.32965442112514, 65.93933568681989, 72.91033826555524, 66.4080194745745, 74.1956785746983, 82.81220218113491, 22.57887135233198, 0.4191375678139073, 0.030996036050575118, 0.02539508230984211, 0.051656334927039485, 0.07982693758926221, 0.04892404404069696, 0.20252104422875813, 0.09460604097694159, 0.05783849462334599, 0.04597995523363352, 0.053875690658709834, 0.08874400731708322, 0.09976067473845822, 0.10909800191542932, 0.1109811808647854, 0.13867073612553732, 0.032537087465503385, 0.0757909163034388, 0.03095305764249393, 0.003554925962816924, 0.036959819429154904, 0.21478765457868576, 0.0912852023861238, 0.09206969064793416, 0.11170356281633888, 0.04278548700468881, 0.039487837348133326, 0.06894850132188626, 0.03605132210733635, 0.05902055012328284, 0.04528716419424329, 0.05824136121996811, 0.043272905849984715, 0.06881657375821046, 0.04914464934595993, 0.05780916155448981, 0.020552552604515637, 0.0335877310883786, 0.16217452420720033, 0.20321686831968172, 0.09457026182540826, 0.09710629324295691, 0.3304308392107487, 0.19086833165160247, 0.3194644919463566, 0.29030149110725945, 0.28536381891795565, 0.12387086956628732, 0.09462718412812267, 0.0641708548313805, 0.13436805057738507, 0.3815038443676063, 0.30228327959775925, 0.5915315757904733, 0.3562665485910007, 0.193665280139872, 0.2969637821827616, 0.14290168695151806, 0.18007653073540755, 0.10295598435082606, 0.2210355100354978, 0.16318168730608054, 0.2797144449182919, 0.3516350042607103, 0.10017236229032278, 0.19504328976784432, 0.2489746915442603, 0.16118782572448254, 0.18457046816391603, 0.2783834034843104, 0.27447333186864853, 0.27230093415294376, 9.81055416379656, 99.85904461996896, 109.34340517861503, 91.88707760402134, 88.99957997458321, 90.26349203927177, 60.581100327628, 42.53790010724749, 38.078337805611746, 23.95181976045881, 42.60940401894705, 55.92811407361712, 58.01785775593349, 62.422838483537944, 49.90026344571795, 36.77411576679775, 12.451722519738333, 2.589888479028429, 0.31408837756940294, 0.16626902164093085, 0.36248410067387987, 0.32410523721149986, 0.2032206952571869, 0.10709267987736634, 0.5269481241703033, 0.393465873918363, 0.8205333447882107, 1.7727572002581187, 3.7461486288479398, 4.793549614293235, 2.421819806098938, 2.849737209933145, 5.798775468553815, 6.789866949830737, 14.747838122504097, 16.522637333188737, 17.308487279074534, 20.642333711896622, 21.608411243983678, 19.711730207715714, 22.18619043486459, 28.773885216031754, 19.063187088285172, 13.342324376106262, 9.780524918011256, 11.043437310627528, 14.94093029839652, 19.65203823362078, 20.48776408604213, 15.353655031749181, 40.31953484671456, 71.53156552995954, 91.0910085950579, 101.38891983032227, 101.13430309295654, 112.90448202405656, 111.20819745744977, 106.17476953778947, 69.73323277064732, 36.24718523025513, 32.75150482995169, 33.8598085130964, 33.02246025630406, 31.287453378949845, 20.061605010713848, 14.973576409476143, 16.745337520326885, 11.137560214315142, 5.8878218446459085, 5.666424444743565, 3.8765450375420705, 2.6517189783709387, 3.638179268155779, 2.6725277474948337, 0.5040565782359668, 0.904653828058924, 1.7035090646573474, 1.0640424638986588, 0.31925634454403606, 1.1566109252827508, 0.34072619676589966, 0.6723712608218193, 0.29769144313676016, 0.4166249526398522, 0.3575352733688695, 0.17397240256624563, 0.2848565732794148, 10.051346591540746, 39.34318787711007, 66.24368068150112, 58.7479362487793, 87.31348146711076, 106.98280334472656, 76.6588636125837, 41.69977365221296, 27.854251180376323, 45.054499421800884, 48.15135669708252, 75.7547709601266, 84.81478418622697, 75.63892364501953, 85.65423774719238, 94.33438600812639, 28.129978282111033, 0.6239214177642549, 0.15241222376269953, 0.17446763813495636, 0.2087956882481064, 0.2760871595570019, 0.12476555870047637, 0.33484017689313206, 0.3533667070525033, 0.1624039640384061, 0.28754023356097086, 0.18930618119026932, 0.19820974128586905, 0.28423723365579334, 0.32702481054833954, 0.27403505252940313, 0.44660488250000135, 0.24739696191889898, 0.27691489085555077, 0.12758014909923077, 0.12175991998187133, 0.2636254296771118, 0.37965144376669613, 0.3743632403867585, 0.26741572629128185, 0.31525198370218277, 0.3512963338622025, 0.33320591173001696, 0.1376338531928403, 0.17910091951489449, 0.1627853007188865, 0.13407056725450925, 0.16220504471233912, 0.14421655211065496, 0.21974585923765386, 0.13790347586785043, 0.1546053575085742, 0.07963777559676341, 0.17417417173939093, 0.3619325059865202], [0.08959708189857857, 0.05498320908684816, 0.02821777102404407, 0.14317318238317966, 0.11568625803504672, 0.14992575932826313, 0.16020743761743816, 0.08285060498331275, 0.02284937328658998, 0.05698845987873418, 0.06874452012458018, 0.05243235507181712, 0.19465474704546587, 0.03659538505598903, 0.24692755139299802, 0.09446678523506437, 0.09499486189867769, 0.06159457950187581, 0.10896908026188612, 0.03549907263368368, 0.04165594332984515, 0.08176731025534016, 0.24350067813481602, 0.25639075360127855, 0.08096446762127535, 0.17891705009554112, 0.13459464056151255, 0.10638584316309009, 0.2974898096706186, 0.061712508888116906, 0.14612379191177233, 0.13494590456996644, 10.899963089397975, 59.89885670798165, 65.01906762804303, 68.01724311283657, 71.24186038970947, 61.73350770132882, 27.91012511934553, 20.80412425313677, 18.13480700765337, 25.87197528566633, 65.34438228607178, 55.43517759868077, 37.39536462511335, 44.09623513902937, 28.847492694854736, 13.790319034031459, 6.0558666331427435, 0.40736688513840946, 0.08208520391157695, 0.08201633939253432, 0.03454157490549343, 0.033257891823138507, 0.05978690792939492, 0.02893093168469412, 0.025848998488592248, 0.166556109807321, 0.14921822372291768, 0.7736053743532726, 1.094253665634564, 0.9642346309764045, 1.8123313167265482, 0.881795231785093, 5.475812341485705, 11.516789419310433, 27.919329745428904, 33.444809981754844, 41.219729559762136, 46.466970920562744, 50.73811544690813, 52.88001578194754, 56.742988382067, 49.89624738693237, 47.10967581612723, 53.8813693182809, 53.83230113983154, 39.252673694065635, 40.795788696834016, 30.053328241620743, 35.77300541741507, 37.93525007792881, 49.558259214673726, 72.8561909539359, 71.19252123151506, 65.84851578303746, 60.14788709368025, 59.92799745287214, 60.487918036324636, 64.14683246612549, 62.46848814828055, 45.631568159375874, 41.58588225500924, 56.819373403276714, 63.96794414520264, 56.0188957623073, 53.42387213025774, 54.93675552095686, 56.93010337012154, 53.328285762241904, 43.01114886147635, 32.46343946456909, 30.158225195748464, 27.567191566739762, 18.81076077052525, 8.081131032535009, 4.705423874514444, 1.495356342622212, 1.042806706258229, 0.7344600377338273, 0.20838068266000065, 0.844364688864776, 0.014777379908732005, 0.11872925689177853, 0.45768446368830545, 0.25051553600600784, 0.05366939226431506, 0.061104975773819854, 0.07675730623304844, 0.014651382741119181, 0.011271492943965962, 0.7447031480925423, 13.20326747213091, 34.07905197143555, 30.020685604640416, 27.326420852116176, 57.289474623543875, 45.45625121252877, 26.480680908475602, 15.08374183518546, 19.7552433013916, 38.17685978753226, 46.21085684640067, 51.758281230926514, 53.45774459838867, 64.14626271384103, 63.066338947841096, 19.190597942897252, 0.4289492927491665, 0.046326221831675084, 0.037660885203097544, 0.01680317334830761, 0.03775327792391181, 0.06666793833885874, 0.25382689546261517, 0.04511685868991273, 0.035431225917169025, 0.04153142197589789, 0.11342396800007139, 0.05655879114887544, 0.061532127138759406, 0.07142801755773169, 0.13729898259043694, 0.058304057855691226, 0.012794347746031625, 0.013992806830044304, 0.02605704919967268, 0.11670898672725473, 0.11722879883434091, 0.08031510282307863, 0.1820831759167569, 0.29762928932905197, 0.32185383087822367, 0.5097077435680798, 0.11363791687680141, 0.08647252313260521, 0.07338588285659041, 0.11587255660976682, 0.06329846914325442, 0.08783331832715444, 0.024194628332874606, 0.01917177964267986, 0.057830603261079104, 0.01666222805423396, 0.018702475986044322, 0.1528383030423096, 0.06758057472429105, 0.04660886559369309, 0.012536451004312506, 0.12339864990540914, 0.09344470115112406, 0.08092993018882615, 0.09777378171150174, 0.03767452375697238, 0.02458135597407818, 0.04330952977761626, 0.08111144509166479, 0.048504278529435396, 0.14969355107418128, 0.07514524952109371, 0.2875820313181196, 0.06244631736938443, 0.16385233774781227, 0.07796578388661146, 0.03375134623742529, 0.012756019847334495, 0.0675304988399148, 0.07139942409204585, 0.22178320134324686, 0.2443438528903893, 0.12740991823375225, 0.07108519452490977, 0.07143161379333053, 0.18844062834978104, 0.25236744806170464, 0.09455745786960636, 0.05825392768851348, 0.1819514451282365, 17.63939697401864, 83.18163095201764, 76.98741613115583, 78.84703895023891, 82.43338639395577, 74.0131424495152, 45.13709265845162, 37.93714346204485, 24.808572598866053, 28.871863501412527, 42.34439972468785, 52.43831532342093, 47.47056872504098, 52.111993176596506, 35.9040275982448, 17.770839520863124, 5.628181993961334, 0.44372034871152466, 0.05536106149000781, 0.10502258488642317, 0.062641219768141, 0.06583482625761203, 0.27347127135310856, 0.19882142703448022, 0.19869194898222173, 0.6543254320110593, 1.265069156885147, 1.295442447066307, 4.2145180106163025, 3.9702310732432773, 5.293145937579019, 3.0220764194216048, 7.7319084916796, 13.425397906984601, 30.308393137795584, 35.38338170732771, 47.36412579672677, 50.19143812997, 54.15194606781006, 58.22696031842913, 58.27558033806937, 53.23573228291103, 53.517137799944194, 57.72308043071202, 57.741618224552695, 44.107216766902376, 45.04311827250889, 35.39215728214809, 41.70774671009609, 43.035603046417236, 54.9331841468811, 80.7484621320452, 85.28098746708461, 79.35796083722795, 69.54429735456193, 70.0131756918771, 69.68398393903459, 77.58034760611397, 74.42924227033342, 54.04055254799979, 49.22459282193865, 59.84243038722447, 67.1080574308123, 63.64138575962612, 60.67130878993443, 58.79211984361921, 60.46647589547293, 56.80703687667847, 45.75112581253052, 38.020240443093435, 34.42468316214425, 31.62908935546875, 21.850363152367727, 9.737294963427953, 3.5623201387269154, 0.40360025582568987, 1.4210797739880425, 0.6734840582524027, 0.9149282595940998, 1.8595507315226962, 1.089636696236474, 1.9284666563783373, 3.3215379161494116, 0.5789727068373135, 0.28475441304700716, 0.24178162323577063, 0.025238418752061467, 0.029935567240629877, 0.08078991448772804, 0.5794753112963268, 14.487660220691136, 36.30896861212594, 38.26780475888933, 34.56635693141392, 44.704873016902376, 42.634900433676584, 31.273160934448242, 27.047197069440568, 32.57682711737496, 60.624227796282085, 57.37601096289498, 64.73858274732316, 65.65155519757951, 71.98904187338692, 78.33137839181083, 35.16517005647932, 0.46207762509584427, 0.08018094287919146, 0.12333893882376806, 0.09985404115702425, 0.07852215546050242, 0.051565624973071475, 0.14475408755242825, 0.047091422735580375, 0.025286737230739424, 0.049571410553263764, 0.07136080187878438, 0.03442810349432485, 0.06622977435056653, 0.14588504258011067, 0.24561632318156107, 0.041582301924271245, 0.016136317613667676, 0.06281216309538909, 0.05966458163623299, 0.11951885452227932, 0.11309664949242558, 0.09617907513997384, 0.11173165416611092, 0.2088865033750023, 0.24825389736465045, 0.3618958108127117, 0.039736815595201085, 0.002407030884309539, 0.018809385963582566, 0.04578405538839953, 0.06889683766556637, 0.04783077824062534, 0.03730403345876506, 0.023029108731342212, 0.0655152905466301, 0.03191725251131824, 0.016625772064019526, 0.21904399618506432, 0.2648448928126267, 0.19417301432362624, 0.18231128581932612, 0.30713651488934246, 0.23282072693109512, 0.26596325423036304, 0.36372997239232063, 0.19599066036088125, 0.10462862066924572, 0.11104964504816703, 0.15772105460720404, 0.15502562852842466, 0.5610132962465286, 0.3732188775071076, 0.5666797150458608, 0.24291754513978958, 0.29326166797961506, 0.20970899638320717, 0.25584038027695244, 0.07486736907490663, 0.15738344272332533, 0.23769749381712504, 0.37211034127644127, 0.4606679550239018, 0.31155502636517796, 0.2819612372134413, 0.2202011290937662, 0.27836752576487406, 0.4383376661155905, 0.23426383520875657, 0.30353748372622896, 0.3473658247717789, 26.21981774057661, 106.66993985857282, 87.63860852377755, 91.57364436558315, 94.40887764522007, 80.55857481275285, 44.9579542023795, 35.14971726281302, 28.213023151670182, 40.86256435939244, 85.81669357844761, 73.1211188180106, 56.98100239889962, 62.937686102730886, 45.10689231327602, 24.48898846762521, 9.69346833229065, 0.9587553249938148, 0.20541921657110962, 0.22807410306164197, 0.15205300732382707, 0.08747670067740337, 0.35786840692162514, 0.27203353707279476, 0.24353346494691713, 0.45033533232552664, 1.26897708433015, 2.53134143778256, 3.5521818484578813, 6.440242716244288, 7.9140954698835095, 2.327371422733579, 9.454967073031835, 16.553039176123484, 37.836380686078755, 41.92135517937796, 52.62530871800014, 53.52986689976284, 62.461505208696636, 65.2362196786063, 66.28743348802838, 55.21069867270333, 60.157600675310405, 63.167706217084614, 61.19982351575579, 47.49352557318551, 46.59053768430437, 37.49860443387713, 44.12269040516445, 46.77883734021868, 60.179313795907156, 82.72084726606096, 87.63661439078194, 81.22625500815255, 74.37041187286377, 75.99854155949184, 77.26909610203334, 84.44901711600167, 80.1508823122297, 61.82436234610421, 58.04642180034092, 64.66051973615373, 73.68554183415004, 69.51236343383789, 61.75899369376046, 64.8203352519444, 64.94431890760148, 61.27439158303397, 46.433244364602224, 38.764576639447895, 35.90929433277675, 35.281385626111714, 23.29790394646781, 12.62769433430263, 10.27748874255589, 5.347067867006574, 3.4833792660917555, 2.980707496404648, 1.0387852191925049, 1.835619398525783, 0.5396602877548763, 1.5414091114486967, 2.540840710912432, 0.8228354783994811, 0.2837397860629218, 0.3761134264724595, 0.39064878651074, 0.14811328372785024, 0.23814358987978526, 1.6158587336540222, 22.016221863882883, 48.78734615870884, 44.463506494249614, 39.27092661176409, 77.682555607387, 62.9710305077689, 40.70921761648995, 24.45995020866394, 30.430111680712017, 56.153357301439556, 60.089334624154226, 73.0605583190918, 75.98088618687221, 82.84879834311349, 90.02856649671281, 41.507339818137034, 0.7611387861626489, 0.2469454918588911, 0.17020672320255212, 0.14756049481885775, 0.21309633819120272, 0.291346760732787, 0.40661517690335003, 0.1924005722893136, 0.19178884582860128, 0.1868996074689286, 0.3723776840737888, 0.14018865967435495, 0.1264419744589499, 0.3234754210071904, 0.48774725624493187, 0.20094084473592894, 0.17791946791112423, 0.12652613994266304, 0.1398449545460088, 0.35298553322042736, 0.4052702933549881, 0.3016727880707809, 0.33398617271866116, 0.4292846518967833, 0.44352563630257336, 0.5645410269498825, 0.4090464492993695, 0.17427569414888108, 0.1340531153338296, 0.1952998981411968, 0.2511972465685436, 0.26789148790495737, 0.14205954356917314, 0.09353479024555002, 0.23113513737916946, 0.09219598637095519, 0.09378740204764263, 0.3226955128567559], [0.05966783181897231, 0.037400663630770783, 0.032376108425004144, 0.01742692175321281, 0.05150094022974372, 0.08162147272378206, 0.04392090340011886, 0.03330008991594825, 0.046643599801297696, 0.02692775212095252, 0.02927234336467726, 0.08939924822854144, 0.07698364515921899, 0.09726787278694765, 0.1152349915355444, 0.016242915465097343, 0.049557551475507874, 0.02125567094688969, 0.02154227565707905, 0.07596448556120906, 0.07204060575791768, 0.15574298932084016, 0.19071401921766146, 0.17369450176400797, 0.01927150902338326, 0.14820660943431513, 0.11595787560301167, 0.08751361298241786, 0.06982184374438864, 0.05457878525235823, 0.06874587719461747, 7.0167399644851685, 81.1467537198748, 69.3887688773019, 78.6008642741612, 65.58440780639648, 72.9717047555106, 28.340048381260463, 24.778526851109095, 14.892980779920306, 27.266508272715978, 49.20377949305943, 53.65743235179356, 45.20247868129185, 39.5413088117327, 27.84672107015337, 7.566118393625532, 1.9874544739723206, 0.0548136499710381, 0.056490934254335504, 0.11549858881958894, 0.0801405632602317, 0.05723977567894118, 0.06815454071121556, 0.06634433820311512, 0.14032490950609955, 0.7051238747579711, 0.2101863729102271, 0.9242514393159321, 1.279336848429271, 5.451675168105534, 4.286629455430167, 5.571333135877337, 11.225673794746399, 21.582888773509435, 31.030727863311768, 48.93824018750872, 56.00733048575265, 62.89482266562325, 69.65473897116524, 68.74895095825195, 71.73116643088204, 69.27465166364397, 69.59294169289726, 70.43784264155796, 68.45099135807583, 66.67612961360386, 77.12843676975795, 72.38868835994175, 71.3674282346453, 58.56789452689034, 64.254807472229, 50.400342668805806, 52.462665285382954, 47.618773800986155, 52.61124903815133, 54.09270920072283, 56.180344104766846, 58.11225250789097, 67.02369240352085, 42.42088549477713, 22.566258634839738, 52.203737190791536, 65.7398806980678, 66.19024903433663, 73.19100379943848, 68.46356759752545, 66.41449519566127, 70.66448593139648, 74.39901760646275, 72.54892076764787, 74.61268860953194, 68.02540029798234, 68.21117428370884, 62.39410073416573, 45.631481306893484, 29.72427545275007, 18.42464590072632, 5.527576420988355, 0.6415755418794495, 0.42761700281075066, 0.400162471724408, 0.32699525356292725, 0.7636415490082332, 0.44215116862739834, 0.31579570738332613, 0.45078910940459793, 0.14357141458562442, 0.09177028707095555, 0.032113396629158936, 0.012236950736093734, 0.1406756035451378, 0.1243742611259222, 4.9696816716875345, 22.28837411744254, 49.288165364946636, 50.127684933798655, 43.449149404253276, 41.25837891442435, 36.95107248851231, 34.122457368033274, 11.388394526072911, 22.92525815963745, 42.94173288345337, 51.53091532843453, 54.69458648136684, 56.73351451328823, 61.54751137324742, 28.901209218161448, 1.1473500622170312, 0.1816625113465956, 0.029143425103809153, 0.01905731757038406, 0.16726942653102533, 0.0655063067429832, 0.03955851016300065, 0.09570344244795186, 0.05182573797979525, 0.007568695116788149, 0.0017926337521722807, 0.05471101137144225, 0.011586504522711039, 0.06075677874365023, 0.07161821092345885, 0.1025672923507435, 0.060067176818847656, 0.07322122954896518, 0.16464800148137979, 0.08168978762945958, 0.11426053382456303, 0.15684600227645465, 0.11723054945468903, 0.21394750608929566, 0.2760852053761482, 0.0937283830717206, 0.02705624120842133, 0.01671721483580768, 0.07350850770516054, 0.07690881631736245, 0.14811849487679346, 0.017578737178285207, 0.049859224752123864, 0.07002751449389116, 0.005391361906991473, 0.04454975269202675, 0.035005160208259306, 0.07092937574322734, 0.046525443105825355, 0.048313345560537915, 0.020911272016486952, 0.023247686913236976, 0.03906778345948883, 0.029874841749135937, 0.052212770961757214, 0.027869185532576272, 0.03741970332339406, 0.03253259217100484, 0.07745676048632179, 0.04182858977999006, 0.0410112638159522, 0.06870072068912642, 0.04104101757651993, 0.07448748445936612, 0.09958471025207213, 0.025755004425133978, 0.038615312560328414, 0.0036383696549039867, 0.14306039629237993, 0.13893601617642812, 0.11388618605477469, 0.041743559164128134, 0.09230624152613537, 0.02284219438609268, 0.16370365715452603, 0.06419635417738132, 0.0580804669963462, 0.05964860213654382, 15.062237160546438, 100.26424966539655, 79.2601649420602, 85.74835109710693, 73.19303962162563, 79.33745670318604, 47.29560613632202, 38.395988600594656, 14.277114169938223, 19.642135313579015, 32.78444971357073, 55.57951600211007, 52.12587915148054, 40.08701685496739, 27.423462867736816, 9.463212847709656, 2.1270227219377245, 0.029536955058574677, 0.025073353234412413, 0.02872999371694667, 0.1359481415046113, 0.04186682862096599, 0.12885347434452601, 0.30007896359477726, 0.6770139059850148, 0.5018694155982563, 0.9885028430393764, 2.118449079138892, 2.432084683861051, 1.8868743053504398, 1.279436620218413, 2.8961138299533298, 8.804856266294207, 20.447726828711374, 33.26294435773577, 48.46725307192121, 59.06437110900879, 67.10900933401925, 72.763272694179, 73.75296715327671, 75.96432862962995, 74.40554891313825, 72.69729954855782, 75.93061597006661, 72.99411964416504, 69.70602362496513, 79.31748063223702, 74.36768817901611, 75.8161096572876, 64.29906054905483, 68.30214704786027, 55.00568165097918, 58.72212369101388, 56.04399960381644, 58.86347089494978, 58.51327473776681, 60.95650454929897, 65.50851958138603, 73.75781004769462, 48.93327569961548, 29.556292329515728, 56.01993104389736, 66.05512046813965, 68.50408254350934, 75.17727143423897, 68.56069646562848, 71.11605630602155, 77.72699628557477, 79.75865650177002, 78.6416849408831, 77.68876729692731, 74.65875516619, 71.12136472974504, 67.40006937299455, 50.054437024252756, 34.615925380161826, 20.143949849264963, 8.22610432761056, 1.7595681079796381, 0.5962311093296323, 1.5979542029755456, 2.8179472471986498, 3.213450653212411, 2.3068505695887973, 1.9485297969409396, 1.4312290293829781, 0.6859229622142655, 0.16193269432655402, 0.11493277203823839, 0.022876411210745573, 0.05054476225216474, 0.10802885464259557, 4.470638598714556, 23.72503055844988, 39.44094555718558, 44.47643709182739, 37.200321742466514, 33.8063143321446, 33.49928733280727, 39.04551315307617, 21.135582855769567, 38.69392040797642, 58.30839320591518, 56.5787399155753, 64.89887074061802, 63.55847985403878, 76.52324172428676, 50.32476363863264, 2.4254917119230543, 0.2329347479556288, 0.017815135386107222, 0.04109180252999067, 0.054292216165257354, 0.1776024563504117, 0.058612472377717495, 0.04047844758523362, 0.12576122741614068, 0.021620066304291998, 0.049390489368566444, 0.037406692414411476, 0.044448766325201304, 0.04237085800351841, 0.12259077254150595, 0.07236092178417103, 0.0702437228922333, 0.06375081451343638, 0.10130276770464011, 0.09315500741026231, 0.10027455644948141, 0.056586064863950014, 0.22928471810051373, 0.20526377776903765, 0.17438481615058013, 0.092322892775493, 0.09929338802716561, 0.1085416574829391, 0.03126383685906019, 0.010744573182559438, 0.09075749213142054, 0.010446965178873922, 0.008719772100448608, 0.054091020354202816, 0.02150562289170921, 0.06867862080356904, 0.02128385898790189, 0.1262559201568365, 0.11484741233289242, 0.1626700990434204, 0.10750605698142733, 0.2261438744940928, 0.1782060403909002, 0.0834650116573487, 0.249611211674554, 0.1373526682811124, 0.11510615130620343, 0.12866666008319172, 0.19783707628292696, 0.16747665112572058, 0.25516616074102266, 0.23976328011069978, 0.18442542451832974, 0.21670250754271234, 0.1673199095364128, 0.1593247585530792, 0.12237905604498726, 0.18931711917476995, 0.3165969486747469, 0.2678057753614017, 0.43077485050473896, 0.1942216788551637, 0.25871636452419416, 0.1452354538653578, 0.2364697525543826, 0.12951930718762533, 0.15505020506680012, 0.11912824905344419, 24.28030800819397, 119.44631522042411, 87.21705436706543, 102.37451485225132, 84.96789469037736, 91.58178765433175, 45.45221430914742, 40.31107194083077, 26.85012010165623, 42.10059438432966, 65.43786334991455, 69.84164551326207, 63.67716898236956, 58.08828122275216, 42.94871929713658, 13.839236089161464, 4.152507943766458, 0.12044557050934859, 0.11764140240848064, 0.40444033646157806, 0.13149528258613177, 0.1339323225298098, 0.20474239146070822, 0.18069733599466936, 0.6381647906133107, 1.4974486189229148, 3.246868448598044, 6.3135475260870795, 9.275978871754237, 16.236008507864817, 13.774823682648794, 14.9739168712071, 23.022772652762278, 31.45548513957432, 42.432784284864155, 57.50453874043056, 65.56460544041225, 73.9924715587071, 78.51573494502476, 78.39033385685512, 78.99930872235979, 77.83709744044712, 77.73209626334054, 78.08880288260323, 82.7529409953526, 79.73856925964355, 81.37062467847551, 77.96337400163922, 80.78974832807268, 69.71519524710519, 73.34457288469586, 59.2776460647583, 65.01929691859654, 63.16111237662179, 67.38558237893241, 64.17950984409877, 68.38396903446743, 71.19052015032086, 81.98387963431222, 55.68265506199428, 36.30982324055263, 61.70948083060128, 69.51213414328438, 73.82337324959892, 73.65105792454311, 68.97114045279366, 71.73301465170724, 82.66697788238525, 84.75250053405762, 83.29819393157959, 82.22425951276506, 77.14154802049909, 76.95475264957973, 71.06054714747837, 52.90177059173584, 35.227703843797954, 24.516699620655604, 12.589780620166234, 4.214491954871586, 3.0990157766001563, 2.6540702922003607, 2.4369403890201022, 3.85669663974217, 1.6656282458986555, 1.6246450564690997, 1.5125609508582523, 0.32036756777337616, 0.2099240105599165, 0.1400399247982672, 0.19838560399200234, 0.2883610709437302, 0.20932922033326967, 8.05663776397705, 33.80056469781058, 71.6373518535069, 68.96414361681256, 57.76322364807129, 57.327814783368794, 52.21185963494437, 47.64881086349487, 18.327628203800746, 37.23166854040963, 58.98944173540388, 68.504971912929, 73.93907465253557, 74.62290940965924, 87.50129127502441, 59.60760906764439, 2.434940827744348, 0.2456544025668076, 0.10365456329392535, 0.15922029130160809, 0.38579943243946346, 0.3456053520951952, 0.13069318634058746, 0.13793101081890718, 0.2513643561729363, 0.1760766210832766, 0.10862775000610522, 0.10512487404048443, 0.13096594384738378, 0.21498837880790234, 0.23567228391766548, 0.19626527705362865, 0.10726352820971183, 0.11798605748585292, 0.2130456787667104, 0.2069819098604577, 0.16701655010027544, 0.21336541803819792, 0.5215269550681114, 0.4777782740337508, 0.4238675268633025, 0.15933476015925407, 0.1393489454473768, 0.1948654864515577, 0.16061850770243577, 0.18118403559284552, 0.2911656733070101, 0.06756221356668643, 0.1303093255098377, 0.17466720885464124, 0.1644865915711437, 0.27555089976106373, 0.24121311945574625], [0.17496539785393647, 0.025886938774159977, 0.036737918122006316, 0.08640905296696083, 0.005769410661222147, 0.0503552134947053, 0.02611014117220683, 0.032483299994575124, 0.016384286539895192, 0.01332998413792146, 0.07229625739689384, 0.02762092822896583, 0.061053251049348285, 0.016218479722738266, 0.05584783911971109, 0.08858271954315049, 0.0032161798652461065, 0.007490298028902284, 0.017732026720685617, 0.0119481111011867, 0.019180156157485077, 0.19686715118587017, 0.08050110284239054, 0.07167309083576713, 0.0864457752821701, 0.10216755380055734, 0.07233506281461034, 0.06453932648790733, 0.11300564437572445, 0.08596955905003206, 12.307193909372602, 78.47845091138566, 74.24029295785087, 84.7734979901995, 69.30466093335832, 68.42476190839494, 35.96139887401036, 23.902664729527064, 28.150609220777238, 65.898515020098, 65.39122704097203, 68.67548765454973, 48.254502705165315, 39.76215730394636, 23.479621921266826, 5.1131459048816135, 0.36864726138966425, 0.09150855575821229, 0.10935047122516803, 0.08890066069683858, 0.041135859808751514, 0.11003797647676297, 0.04262575986129897, 0.6205179403935159, 0.684554438505854, 1.0440469597067152, 0.7267391777464322, 1.7340698476348604, 2.610808853592191, 0.32311300188302994, 4.628943315574101, 8.555598327091761, 16.18577650615147, 24.689230339867727, 39.04987662179129, 50.27710247039795, 66.00040340423584, 65.0825046811785, 77.63948372432164, 74.29029914311, 78.61540685381208, 73.20249611990792, 74.87569877079555, 68.58923966544015, 64.90676389421735, 71.08379581996373, 74.80450057983398, 76.50141048431396, 79.0534143447876, 79.00807734898159, 77.0115055356707, 72.15561103820801, 57.31465836933681, 36.18038524900164, 49.03907591956002, 52.89099740982056, 53.22787734440395, 53.9212589263916, 64.04212311335972, 52.43377120154244, 28.413268498012, 36.13421794346401, 59.17254761287144, 70.19840771811349, 70.47236824035645, 67.32386153084892, 67.63254914964948, 71.80619307926723, 66.195814541408, 64.32517187935966, 61.32846941266741, 68.22114494868687, 73.44037464686802, 73.8991641998291, 70.48556981767926, 71.24625859941754, 66.67476081848145, 54.5473541532244, 37.597345284053254, 19.076280968529836, 7.472926548549107, 1.595259496143886, 4.1946587562561035, 4.289740511349269, 3.899663431303842, 0.8522831382496017, 1.0310576281377246, 0.47146084159612656, 0.26424941048026085, 0.034920994724546156, 0.06360092612781695, 0.0144473472610116, 0.05106008585010256, 0.06270519204969917, 1.2109598432268416, 13.607319116592407, 37.69739586966378, 52.98454795564924, 54.68885074343, 41.64362873349871, 34.220934186662944, 32.63804074696132, 17.62429506438119, 15.856079271861486, 38.3519926071167, 50.91281400408064, 57.39534779957363, 64.49744551522392, 77.4171552658081, 39.99090242385864, 1.1040751614740916, 0.133190317345517, 0.08246806051049914, 0.02598283443200801, 0.14361231667654856, 0.03463111438655427, 0.015486788270728928, 0.05656195651473744, 0.011203183975469853, 0.07538410741835833, 0.0634461183633123, 0.09551535254078251, 0.12254797055252961, 0.01549245573447219, 0.013945862384779113, 0.017065243928560188, 0.03241341767300453, 0.08991334028542042, 0.022767738738496388, 0.050240079672741036, 0.1421038383351905, 0.08410091432077543, 0.19132208158927305, 0.08269362590674843, 0.044346256647259, 0.07254534081688949, 0.017109784663521817, 0.06856619433632918, 0.040277407837233374, 0.043078698949622254, 0.03921439791364329, 0.07381397738520588, 0.018121146197829927, 0.06421463391078369, 0.03124652403805937, 0.02354116687950279, 0.027974229538813233, 0.1008286074336086, 0.027620410846014107, 0.06383054916347776, 0.017434278769152503, 0.04814441069694502, 0.038130210912121196, 0.03872984927147627, 0.027305609613124813, 0.06744203144418341, 0.027481731858902743, 0.05471282305994204, 0.03757117269560695, 0.022754436059455787, 0.03498552340481963, 0.015805502954338278, 0.03988704664100494, 0.062420831594083986, 0.01856065877447171, 0.0327078204468957, 0.047212235895650725, 0.11507237383297511, 0.0719744214521987, 0.07748435650553022, 0.036493608195866854, 0.025827482143150907, 0.029375884415847913, 0.10182305478623935, 0.09767192003450223, 0.0481102294953806, 18.903932639530726, 94.72087260654995, 84.48953901018415, 95.57067898341587, 81.69084630693708, 80.79252065931047, 66.20272105080741, 37.001102992466514, 36.01888132095337, 53.618796893528526, 62.62217535291399, 77.67557266780308, 50.00047731399536, 38.9494925226484, 22.617503336497716, 6.474863852773394, 0.2846563240247113, 0.08547055761196784, 0.023127594696623937, 0.20538139502917016, 0.02920032026512282, 0.2675012488450323, 0.6442382761410305, 2.081938466855458, 1.7026483565568924, 1.0897965048040663, 0.20078087331993238, 0.22760215481477125, 0.4480241063450064, 2.3344455574240004, 5.143902974469321, 8.482293094907488, 15.305003745215279, 23.612877947943552, 39.025947025844026, 54.56653812953404, 67.6162417275565, 71.10301453726632, 79.74887343815395, 76.09570516858781, 78.48770591190883, 73.99236038752964, 73.43407957894462, 69.64676938738141, 68.40142985752651, 76.81832477024624, 77.79819447653634, 77.76464857373918, 80.39547279902867, 81.78698853084019, 78.32781396593366, 75.94556849343437, 60.21352672576904, 44.13369982583182, 56.46893058504377, 60.208871432713096, 59.16490459442139, 60.56597409929548, 71.13214833395821, 59.98546600341797, 36.246000562395366, 42.35545430864607, 60.4465970993042, 69.76769583565849, 71.85527515411377, 67.81176403590611, 69.88862923213414, 76.69516100202287, 69.95588779449463, 66.60956587110246, 67.02041285378593, 72.04416888100761, 76.80991050175258, 77.86299337659563, 73.91574954986572, 76.8092782156808, 71.3544420514788, 62.34023829868862, 42.51238979612078, 23.49029609135219, 9.563486644199916, 2.2572643160820007, 1.868411204644612, 5.312713801860809, 6.602140086037772, 3.6923244084630693, 4.033975149903979, 1.8195903386388506, 1.0844509516443526, 0.24650797247886658, 0.2172524058925254, 0.13485088252595492, 0.05304411206660526, 0.025643327739089727, 1.2300977877208163, 15.03579579080854, 36.16285146985735, 46.08007090432303, 40.85224628448486, 23.41723230906895, 23.984688213893346, 20.623533623559133, 30.722801072256907, 30.076368468148367, 56.55336856842041, 59.32449776785714, 66.69905172075543, 75.80477019718715, 88.22236837659563, 63.17311886378697, 3.581009490149362, 0.3378715185182435, 0.04027663430731211, 0.03587456712765353, 0.042643751217318435, 0.021492103081462637, 0.037546511340354166, 0.02811879142453628, 0.04645673804251211, 0.03261199773156217, 0.060955467367810864, 0.11919653681772095, 0.0205232789074736, 0.052153382184250016, 0.07273495742785079, 0.028375021514615843, 0.032886994403920004, 0.04758976938735161, 0.06138266623020172, 0.10327531650130238, 0.1985816191881895, 0.07038185226597957, 0.1866169162094593, 0.1443619757358517, 0.04811471461185387, 0.02632543694094888, 0.06651984807103872, 0.016155706751825552, 0.022377330044816648, 0.0070972146349959075, 0.025092750854258026, 0.03554400522261858, 0.012360324517690709, 0.11906859225460462, 0.008008103368670812, 0.03378711181825825, 0.2889407298394612, 0.16223173827997275, 0.14284179945077213, 0.12464912209127631, 0.09095741568931512, 0.16796303859778813, 0.1400630357010024, 0.10258481891027518, 0.16352318041026592, 0.2232187914529017, 0.13504243296171936, 0.2211817479027169, 0.20824127085506916, 0.09912323858588934, 0.17680335922964982, 0.151170871087483, 0.18629291573805468, 0.12979948786752565, 0.07776161948485033, 0.12302109945033278, 0.10884325272802796, 0.41856881976127625, 0.18259134436292307, 0.2975738123059273, 0.15172794833779335, 0.16944113214101109, 0.12861092521675996, 0.1961980206625802, 0.17833068727382592, 0.12522301343934877, 28.599039009639196, 115.10871464865548, 89.61602415357316, 111.89910548073905, 88.47705459594727, 85.17590291159493, 52.599138328007285, 37.40415409633091, 39.46977015904018, 86.45408657618931, 79.03898293631417, 82.91283988952637, 63.2783145904541, 54.83431822913033, 33.452842099326, 8.171653032302856, 0.8085667011993272, 0.17448074743151665, 0.24137317229594502, 0.25021171516605784, 0.1784358737724168, 0.26442262689982143, 0.5311265970979417, 1.7401358421359743, 2.3595268172877173, 3.2095388174057007, 3.351997515984944, 5.781579111303602, 8.962915624891009, 7.232610506670816, 11.001331227166311, 14.288031526974269, 26.088585376739502, 32.34000819069998, 48.32580859320504, 60.311663082667756, 75.64282158442906, 73.27212401798793, 85.86418451581682, 79.13462488991874, 82.37435449872697, 75.89932823181152, 76.46893460409981, 73.75776835850307, 72.61471326010567, 79.70721203940255, 84.06583091190883, 82.36316095079694, 84.0665535245623, 83.42737483978271, 81.60591847555978, 78.2863540649414, 65.04947294507707, 50.383354323250906, 62.07506724766323, 68.39932455335344, 65.72701958247593, 66.14931024823869, 80.29397351401192, 67.22668402535575, 41.62164115905762, 47.88016503197806, 65.0825116293771, 73.2978184563773, 72.70817347935268, 67.68939931052071, 73.15958404541016, 79.45771612439836, 72.03042534419468, 71.32301534925188, 69.73926380702427, 74.6976511819022, 79.84313270023891, 82.60550022125244, 76.16030257088798, 79.86375495365688, 73.84749739510673, 62.26662213461739, 43.527191570826936, 25.912573610033306, 11.9334876537323, 6.194204832826342, 13.345807160649981, 11.265090925352913, 12.306098699569702, 3.8296720555850436, 3.2771604231425693, 1.4513309278658457, 0.6992542754326547, 0.1511954747672592, 0.18807112532002584, 0.18073641961174353, 0.2589191107877663, 0.29594312980771065, 2.2538844517299106, 21.153860092163086, 53.91022866112845, 75.07796083177838, 78.68715395246232, 59.092580795288086, 49.555083887917654, 48.74958964756557, 25.866300344467163, 26.656003066471644, 54.58084447043282, 66.18084812164307, 76.61556243896484, 83.35055555616105, 98.6756065913609, 69.67685508728027, 3.603403317076819, 0.3278512933424541, 0.2648607976734638, 0.09857372021568672, 0.20825227669307164, 0.1356969749821084, 0.13926761624004158, 0.2182410449853965, 0.11892407786633287, 0.21012826317123004, 0.18784363966967377, 0.2112136206456593, 0.20930532232991286, 0.20609549885349615, 0.2887339395071779, 0.14843421722097055, 0.13588634053511278, 0.16045837343803473, 0.17456287731017384, 0.20306704778756413, 0.35666777991822785, 0.17303043311195715, 0.23491813295653888, 0.2388791489814009, 0.16039573108511312, 0.12983323819935322, 0.11468783446720668, 0.1230352401201214, 0.11560469812580518, 0.137753587482231, 0.1762676015496254, 0.1887989491224289, 0.19346062040754727, 0.22912509952272686, 0.12768211934183324, 0.15666388347744942], [0.10598699349377837, 0.06959817824619156, 0.07106808187173945, 0.04658417709703956, 0.015202972339466214, 0.05355380043121321, 0.030502937867173126, 0.04245877917855978, 0.06507490096347672, 0.00943193955546511, 0.03278231341391802, 0.06554332082825047, 0.05097846148003425, 0.01721157000533172, 0.025561565965680138, 0.024621258922187344, 0.02991719590499997, 0.052044124475547245, 0.04907621230397906, 0.046308681701443026, 0.0570302169237818, 0.007384169214804257, 0.029057763450379883, 0.057258082553744316, 0.05304976087063551, 0.04741437826305628, 0.09729181150240557, 0.09825179606143918, 0.11418324868593897, 9.655955876622881, 69.56140381949288, 75.3292076928275, 77.82139451163155, 66.88044139317104, 67.26352337428501, 28.44838990483965, 11.197894896779742, 24.14574224608285, 41.90199749810355, 41.04146657671247, 40.918198585510254, 31.607862608773367, 32.24763536453247, 14.726314340318952, 1.2149547317198344, 0.010003608701351498, 0.06549137897257294, 0.028310497923355018, 0.07785698758172137, 0.22900258323975972, 0.14057659171521664, 0.5794527296509061, 0.3247056321374008, 2.429687989609582, 2.1909498402050565, 1.1384297694478716, 0.6392455611910138, 2.0019571014813016, 13.485879370144435, 33.70932790211269, 38.28153787340437, 45.480583803994314, 49.130528109414236, 48.60746077128819, 55.506521701812744, 61.55097157614571, 63.68195629119873, 69.69486481802804, 66.77284853799003, 68.14586816515241, 69.28997244153703, 68.6087224142892, 67.0285005569458, 61.66053771972656, 70.62775775364467, 72.84560884748186, 72.9522567476545, 71.27914442334855, 71.60642542157854, 73.67071437835693, 74.78098092760358, 77.86726651872907, 80.54229518345424, 64.10790170942033, 30.505475316728862, 54.9729973248073, 56.92317949022566, 59.68360151563372, 62.02606160300118, 43.138255732400076, 37.48087610517229, 60.7191401890346, 73.23839051382882, 70.52550111498151, 69.24585138048444, 69.10702637263707, 70.44350542340959, 67.81281321389335, 64.06882504054478, 63.42853464399065, 60.25492409297398, 63.16608728681292, 64.79250771658761, 67.59855161394391, 67.14399351392473, 68.95931461879185, 69.40578501565116, 71.90994358062744, 67.51495783669608, 52.669832774571006, 33.75205932344709, 16.523224455969675, 5.108247424874987, 5.600041355405535, 5.122583295617785, 4.831264870507376, 1.678409131509917, 2.3415772318840027, 1.278101263301713, 0.42583818254726274, 0.010764500059719597, 0.04245106423539775, 0.05017474692847047, 0.07352492825261184, 0.015985938986497264, 0.2908877996461732, 5.840014764240809, 19.114252873829432, 42.32782827104841, 53.009735175541465, 55.55953993116106, 42.55258165087019, 35.63775178364345, 18.58244296482631, 9.397237965038844, 30.101225648607524, 54.7614802633013, 60.72327436719622, 56.36406489780971, 73.88408660888672, 41.812977177756174, 0.6386381909251213, 0.08096849811928612, 0.09725534703050341, 0.03709392848291567, 0.030204789579979012, 0.045784873023097, 0.055197978990950754, 0.043098254328859706, 0.033098595549485514, 0.09932599842016186, 0.07002420324300017, 0.08316642232239246, 0.07452345360070467, 0.0686471639201045, 0.06400582832949502, 0.041084813619298596, 0.026645230495237877, 0.07709439564496279, 0.06887632555195264, 0.14138836387012685, 0.12416175752878189, 0.07586407594914947, 0.049459109615002356, 0.13237194983022554, 0.06788487732410431, 0.03071158399273242, 0.07562051580420562, 0.007952185297783996, 0.09582927676716022, 0.06278901148055281, 0.0012344748746337636, 0.07717372317399297, 0.027973530647744025, 0.03496011226837124, 0.12266154374395098, 0.03756600904411503, 0.058783965318330696, 0.10299649967678956, 0.08724825829267502, 0.03644529989521418, 0.01632203264827175, 0.03362456875454102, 0.03901828772255352, 0.03946258566741433, 0.030617613677999804, 0.06059877507920776, 0.07615211406456572, 0.048518100287765265, 0.023335126328415105, 0.013697265813659345, 0.09567412973514625, 0.03235519936840449, 0.011416859741854881, 0.026599064668906585, 0.030032590962946415, 0.0454486623140318, 0.07325467454003436, 0.08631409877645117, 0.02228377533278295, 0.08647011433328901, 0.04951490554958582, 0.10434928137276854, 0.10285081820828573, 0.06450052107019083, 15.129427977970668, 84.37166976928711, 84.5072569165911, 86.34235259464809, 77.62541362217495, 75.12207494463239, 45.59437445231846, 20.682162523269653, 25.55730526787894, 31.69134521484375, 49.168875217437744, 47.26670857838222, 35.569450991494314, 37.372977529253276, 17.52821363721575, 1.4948831051588058, 0.042061116945530684, 0.060645858624151776, 0.020997121963383894, 0.25701579291905674, 0.5387460025293487, 0.883331869329725, 1.4697026163339615, 3.0533917333398546, 6.228149822780064, 3.3188967321600233, 0.16771990592990602, 0.33145073162657873, 2.2032501058919087, 14.41227834565299, 32.98191056932722, 41.85773747307913, 47.38430683953421, 51.51757478713989, 51.638702733176096, 57.64133487428938, 64.03682858603341, 67.889326776777, 71.96336133139474, 69.54729202815464, 69.53697395324707, 71.16269261496407, 69.19022410256522, 67.93309347970145, 66.1450857434954, 71.25385992867606, 75.65401513235909, 76.57412338256836, 74.78748444148472, 76.48896626063755, 77.8484855379377, 76.96080453055245, 78.1219596862793, 82.84078012193952, 68.19845213208879, 38.84551967893328, 60.855338777814595, 61.87190192086356, 65.42430741446358, 69.83940124511719, 50.416479860033306, 43.517134053366526, 61.76542772565569, 74.33401026044572, 71.0627636228289, 69.35013689313615, 69.80539676121303, 73.27558422088623, 70.85897295815604, 68.00662626538957, 67.46826594216483, 66.04384354182652, 65.91872732979911, 69.04776518685478, 72.07061372484479, 70.60407829284668, 72.84510162898472, 74.4188894544329, 74.9963959285191, 72.57141208648682, 58.00346456255232, 38.44827726909092, 21.212897198540823, 7.3138883624758035, 2.319262440715517, 0.8425343270812715, 2.3536933703081946, 2.671295527900968, 4.42979621887207, 2.213226850543703, 0.9390350346054349, 0.7833663448691368, 0.06984051702810185, 0.20026662519999913, 0.05523494557876672, 0.09504343822066273, 0.12321524188986846, 5.97107298885073, 20.79472507749285, 42.587274006434846, 47.36607824053083, 44.8033880506243, 34.52741575241089, 22.38177875110081, 17.393859795161656, 15.652163539613996, 46.363348960876465, 64.60048730032784, 68.98530782972063, 65.7151312146868, 80.57493087223598, 63.503047125680105, 4.691727672304426, 0.12079490747834955, 0.04423526528158358, 0.02049517059432609, 0.025999750310022916, 0.031224902519690137, 0.008712833231714154, 0.053012095391750336, 0.04271963857380407, 0.07477872526007039, 0.05359128609831844, 0.03170582778485758, 0.06219728823219027, 0.04674590252605932, 0.06008443874972207, 0.014123652978534145, 0.035164829676172564, 0.03394100695316281, 0.10567728975521666, 0.14200391726834433, 0.13114998968584196, 0.0619879262521863, 0.07683931397540228, 0.018224610913810984, 0.09814581567687647, 0.004360366113749998, 0.05120215072695698, 0.054095915984362364, 0.07932208717933723, 0.030531002075544426, 0.024679316074720452, 0.05894756011132683, 0.028706560510077646, 0.06274617556482553, 0.1267475594899484, 0.14585605556411402, 0.15091380131031784, 0.23556656816176005, 0.16987198830715247, 0.1276010615485055, 0.11776904841618878, 0.1645775152636426, 0.19868110599262373, 0.13538498458053383, 0.11324182884501559, 0.10992939730307885, 0.2880076084818159, 0.17506611959210464, 0.05336851965902107, 0.07604888853217874, 0.13740083069673606, 0.10050326346286706, 0.13622317888907023, 0.10947455492402826, 0.10810624156147242, 0.11646756396761962, 0.17936370255691664, 0.25306951467479977, 0.11031792645475694, 0.17724081075617246, 0.11123719891267163, 0.22850106443677629, 0.18821084925106593, 0.31255103434835163, 26.53278718675886, 101.55275835309709, 92.58897072928292, 101.86399596078056, 82.86052690233502, 84.55859020778111, 42.59439243589129, 15.879642350333077, 35.30021524429321, 58.80967099325997, 51.671373162950786, 53.30718060902187, 47.09858996527535, 48.26878125326974, 25.079368216650828, 2.3463360965251923, 0.16678535964872154, 0.21742863500756876, 0.24138009335313523, 0.21462008357048035, 0.5505496891481536, 1.1194473994629723, 2.1607071544442857, 4.652094713279179, 7.221297536577497, 6.684492307049887, 5.126423478126526, 2.237460647310529, 2.890294062239783, 15.157026222773961, 37.48013959612165, 42.28957496370588, 51.75857652936663, 52.98393998827253, 52.79375042234148, 62.394225801740376, 67.04412705557687, 68.94419533865792, 75.81311498369489, 69.7713644845145, 71.57438032967704, 72.80764389038086, 69.36381094796317, 71.59991495949882, 70.53421415601457, 74.45520768846784, 79.72076797485352, 78.37618732452393, 77.68603665488106, 78.44193812779018, 80.78286266326904, 82.48216274806431, 83.46323449271065, 86.05446788242885, 72.9845380783081, 45.66963733945574, 68.29748480660575, 69.96556663513184, 71.75267110552106, 77.14318084716797, 56.25811876569475, 49.67677811213902, 65.97185325622559, 76.36111940656389, 71.70918927873883, 70.53092765808105, 72.69335297175816, 75.68741512298584, 73.41046265193394, 69.21133967808315, 73.18117904663086, 68.64451953342983, 68.86313765389579, 71.80617918287004, 74.06199523380825, 73.87634631565639, 77.26606668744768, 76.2768030166626, 80.0354449408395, 74.58577128819057, 60.096039635794504, 38.45259210041591, 22.731745617730276, 10.938850419861929, 15.840291227613177, 14.4895327602114, 12.478672845023018, 9.350463560649327, 11.275029454912458, 4.901379576751164, 0.7700265092509133, 0.588614960866315, 0.21047428888934, 0.31147319504192894, 0.15053618300173963, 0.22164955708597386, 0.5338955085192407, 10.790535909788948, 29.996936661856516, 62.20548493521554, 74.66042968205043, 81.1424388885498, 65.87954643794468, 48.03221593584333, 27.629263298852102, 15.179064171654836, 45.8746508870806, 68.40981633322579, 78.48483630589077, 77.43943119049072, 90.82390594482422, 73.78993156978062, 4.668413860457284, 0.3040148466825485, 0.12319081462919712, 0.11369139900697128, 0.11110268613057477, 0.09458932187408209, 0.08761051456843104, 0.26008323260716026, 0.16513934225908347, 0.1664916489805494, 0.2387458575623376, 0.16024820400135859, 0.15329834978495324, 0.11090423499367066, 0.12683575547167233, 0.1050608814028757, 0.0899111350466098, 0.10197424595909459, 0.18876446597278118, 0.18475672602653503, 0.2894949029598917, 0.20679923466273717, 0.1424250839544194, 0.23804981634020805, 0.3012552447617054, 0.17962972899632795, 0.16750999433653696, 0.1385110496942486, 0.21293496899306774, 0.09251169514443193, 0.09207610280386039, 0.13155796565115452, 0.11059080609785658, 0.13095340452023915, 0.19336519124252455], [0.19202101337058203, 0.14029399545064994, 0.04366637473659856, 0.027364536986819336, 0.07738337692405496, 0.0265187074629856, 0.02661025201502655, 0.030695818231574128, 0.05602002416604331, 0.027425464342481325, 0.05540832484673176, 0.02228377533278295, 0.03214982378163508, 0.0299865625399564, 0.02186685797226216, 0.015085962368175387, 0.020128648029640317, 0.011751909307869417, 0.05933494932417359, 0.02344794973864087, 0.06266834759818656, 0.046396192362798114, 0.028890083876571486, 0.03930805949494243, 0.043836154376289675, 0.03981038575459804, 0.028685637882777622, 0.12048465412642274, 23.91304533822196, 78.69551958356584, 84.51297528403146, 71.1403819492885, 70.35670157841274, 54.69209207807268, 37.97644247327532, 16.443997621536255, 32.45579644611904, 42.0410726411002, 44.25259392602103, 42.062077045440674, 48.47044576917376, 47.79562282562256, 9.033203601837158, 0.8382421316845077, 0.01784384759542133, 0.14073611529810087, 0.041768831200897694, 0.020041098352521658, 0.0035259487007611562, 0.3995823785662651, 1.1901250183582306, 0.7850758188537189, 2.1189682398523604, 3.5463494871343886, 1.6782384663820267, 0.5209339697446141, 11.835994005203247, 47.752752440316335, 68.08982399531773, 75.87457874843052, 79.7787298474993, 70.48581300462995, 67.75695664542062, 67.17599691663469, 64.56443309783936, 64.30065168653215, 64.67611149379185, 65.70791898454938, 66.44725595201764, 67.20145511627197, 65.31833348955426, 64.66857964651925, 59.1916412625994, 61.906413623264854, 68.51373359135219, 68.66396059308732, 69.39408424922398, 69.80205467769078, 70.03754997253418, 67.51576382773263, 63.227175848824636, 70.51000663212368, 70.04139232635498, 77.12827001299176, 61.91346604483468, 27.701495034354075, 48.08024883270264, 56.08601883479527, 50.03301920209612, 38.62440368107387, 57.43375744138445, 67.46639687674386, 71.87249279022217, 69.022383417402, 66.77373095921108, 66.818678855896, 66.75444970812116, 69.5507869720459, 64.16723932538713, 57.04186167035784, 53.3531950541905, 54.188823631831575, 58.36588260105678, 59.94129630497524, 58.895015716552734, 60.82940810067313, 63.87112099783761, 64.73063400813511, 70.15223693847656, 71.00233513968331, 61.20969690595354, 43.91257340567452, 23.952943631580897, 16.195104462759836, 7.087658056191035, 3.8776875819478716, 7.634327990668161, 2.911928798471178, 2.024183303117752, 0.4716503971389362, 0.8903306052088737, 0.2389475181698799, 0.046104921028018, 0.08411019667983055, 0.04381418341238584, 0.062456488609313965, 0.10527276753314904, 5.8436243534088135, 15.811954736709595, 26.43093180656433, 44.948973655700684, 47.23069953918457, 70.48978042602539, 50.25153309958321, 34.25668266841343, 17.087331329073223, 27.396361419132777, 47.19237674985613, 55.01093448911394, 57.73053584780012, 64.78950609479631, 54.91987139838082, 3.373604242290769, 0.16166696644255094, 0.0533690082042345, 0.08111301250755787, 0.07319461740553379, 0.019502931873181036, 0.0011168095869444577, 0.0582506571497236, 0.07229952793568373, 0.0681368988007307, 0.03218655627486961, 0.016943894725825106, 0.16754781587847642, 0.005787700572649815, 0.07808636634477548, 0.032703379435198646, 0.09943472687155008, 0.07174462878278323, 0.07552339708698647, 0.05282132527125733, 0.1217093826936824, 0.028223397775686214, 0.08892628217914275, 0.02222399300496493, 0.05441663234627672, 0.09799366098429475, 0.07828152658683912, 0.027208551964057342, 0.11334987876138516, 0.05793027326996837, 0.05779548907386405, 0.09849602795605149, 0.04984051075630954, 0.08613524373088564, 0.1501182054302522, 0.04994692540328417, 0.06999814749828406, 0.017138803909931864, 0.0399973119742104, 0.07322633213230542, 0.04746088505323444, 0.025803005688690712, 0.06486578325607947, 0.07182736934295722, 0.14134073071181774, 0.058325737049537044, 0.012770509962657732, 0.08444723180894341, 0.05259979037301881, 0.0570578807964921, 0.02501458701278482, 0.04307784738817385, 0.014248102238135678, 0.023729392493675863, 0.054702851987843, 0.008940670872107148, 0.03148358042484947, 0.009524946350471249, 0.045068835373967886, 0.038468440262866874, 0.010179297532886267, 0.11637380399874278, 32.46299130575997, 93.59557710375104, 92.17206491742814, 80.34289578029087, 77.4578161239624, 65.08295631408691, 63.30296679905483, 27.333429847444805, 25.253140926361084, 29.049211059297832, 34.08041034426008, 37.65799263545445, 41.54338359832764, 42.362201009477886, 11.141613619668142, 0.6966160769973482, 0.04164864568571959, 0.07845701609871217, 0.024017264368012547, 0.08582183519112212, 0.5652485489845276, 1.0143999734095164, 2.00164595246315, 1.958266828741346, 1.9443235312189375, 2.3745429600988115, 0.4369930811226368, 1.164276851075036, 14.316442711012703, 48.76206513813564, 70.68424660818917, 79.91399737766811, 82.78496524265834, 73.02685955592564, 69.0065415246146, 69.17919036320278, 66.86766365596226, 66.90576757703508, 67.28695269993374, 66.67297513144356, 67.14388234274728, 67.37687628609794, 65.86603219168526, 66.20854364122663, 60.34163761138916, 64.45219189780099, 67.8388342176165, 71.49435792650495, 70.1605052947998, 73.65589387076241, 72.28243650708879, 71.82100663866315, 67.33374881744385, 73.68169948032924, 71.52674348013741, 78.2981868471418, 64.3690983908517, 35.533125809260774, 55.05880062920706, 63.02741513933454, 57.13922677721296, 45.380366461617605, 61.16989067622593, 69.35584831237793, 72.60389491489956, 68.05859879084996, 67.42346395765031, 70.30483327593122, 70.15052768162319, 72.50441755567277, 66.34579835619245, 59.229258809770855, 57.1737072127206, 58.64004462105887, 61.79164327893938, 63.30011108943394, 63.02691486903599, 63.45074108668736, 65.73202228546143, 69.56025041852678, 73.38288525172642, 74.77948706490653, 67.9135273524693, 47.785071986062185, 29.44769893373762, 17.739921774183, 9.84164127281734, 6.45641074010304, 4.573524049350193, 0.669817634991237, 1.8302043633801597, 1.7228397130966187, 1.0878266905035292, 1.1503598264285495, 0.5275852414114135, 0.46933925258261816, 0.087511434885008, 0.02521639859436878, 0.026844443287700415, 5.634939985615866, 18.18761157989502, 29.801000935690745, 44.763484546116416, 48.11435406548636, 53.08306993756975, 43.759483746119905, 37.24102776391165, 26.727105719702585, 46.03858321053641, 64.71712671007428, 65.33922672271729, 67.32529285975865, 74.43131978171212, 80.06709398542131, 10.109302384512764, 0.17510000563093595, 0.03132655045815876, 0.02105497385907386, 0.04975457429619772, 0.05278035871950643, 0.016229809561212147, 0.029699141891407113, 0.025831716201667274, 0.007660784193181566, 0.08681393481258835, 0.030206916787262474, 0.11013341921248607, 0.02525270700321666, 0.030229793595416204, 0.018060763366520405, 0.10450555477291346, 0.031046583516789333, 0.1312620701002223, 0.06096135705177273, 0.09364455685551677, 0.03535685169377497, 0.044776529273284335, 0.04437103335346494, 0.1031302185729146, 0.07715174542473895, 0.07644805711294923, 0.06450120639055967, 0.05328978245545711, 0.03500715170853904, 0.026681623720963086, 0.023175719792821577, 0.022556315708373274, 0.012942540642273213, 0.33019639179110527, 0.1506153680384159, 0.1269293933042458, 0.13266605404870851, 0.2685062406318528, 0.1596805416047573, 0.12960529114518846, 0.15340064572436468, 0.0959789344508733, 0.13318631398890698, 0.2310360712664468, 0.12484814998294626, 0.15094130911997386, 0.21515514914478573, 0.1387585521276508, 0.08850655398730721, 0.1413618331508977, 0.09256268026573317, 0.17703228337424143, 0.14303372986614704, 0.15605685247906617, 0.12518542259931564, 0.23382883997900145, 0.07363228606326239, 0.12061863765120506, 0.18968430161476135, 0.11088809264557702, 0.40450843423604965, 48.31059898648943, 112.80788121904645, 102.01163823263985, 92.8351662499564, 87.28369453975132, 71.82516860961914, 54.54718739645821, 27.649017027446202, 49.500022888183594, 62.6196323122297, 61.398208481924875, 61.547108377729145, 68.40174947466168, 68.85942731584821, 14.936308009283882, 1.3709399444716317, 0.07132451382598706, 0.36421004948871477, 0.12446963600814342, 0.1736689345645053, 0.5341260475771767, 1.2286148901496614, 2.9498525006430487, 2.4718151347977773, 6.846464804240635, 10.781590104103088, 5.72158054794584, 2.170966169663838, 15.629038197653633, 55.62157692228045, 76.64491162981305, 84.22600078582764, 85.7753517968314, 73.65970843178886, 69.70305674416679, 69.42079312460763, 68.32022626059396, 67.16980607169015, 68.537704876491, 68.68818201337541, 69.02850478036063, 69.17649446214948, 67.44721290043422, 67.81398051125663, 63.20388548714774, 63.955534662519185, 70.1542866570609, 73.39894948686872, 74.60438551221574, 77.57697772979736, 76.20860644749233, 75.08483954838344, 68.5310137612479, 75.51418958391461, 75.06944928850446, 81.087568964277, 68.78813879830497, 40.22088779721941, 59.55926350184849, 67.91488919939313, 63.698645864214214, 50.68528829302107, 65.66603524344308, 71.94318376268659, 75.13020433698381, 70.05315562656948, 68.92046724046979, 73.08295236315045, 72.115811756679, 76.25075422014508, 69.91852038247245, 62.9072390965053, 59.1007935660226, 61.657563890729634, 64.83177198682512, 66.4070189339774, 64.9263300214495, 67.09642614637102, 70.56643295288086, 72.01921789986747, 75.35866805485317, 77.94739314488002, 68.13220800672258, 48.96837452479771, 28.388430425098964, 22.619884831564768, 13.184073073523384, 13.319985917636327, 18.535761492592947, 11.497143387794495, 7.63391717842647, 3.8641225269862582, 2.032398679426738, 0.6748306517090116, 0.40332360352788654, 0.3159596414438316, 0.21592991399977887, 0.15715039308582032, 0.48165764872516903, 9.614250183105469, 25.977966581072124, 42.122060843876426, 61.16677788325718, 64.98370824541364, 98.17200810568673, 70.0120987210955, 48.36609424863543, 25.842212677001953, 40.71736437933785, 63.039685658046174, 73.1545535496303, 78.5723488671439, 84.91244111742292, 88.0121158872332, 9.73173119340624, 0.3789815125720841, 0.1146611680409738, 0.1801090868456023, 0.18120972492865153, 0.22959014028310776, 0.13163959341389792, 0.17488002457789012, 0.13720188422926835, 0.11037476054791893, 0.1780878124492509, 0.16947112338883535, 0.29201183361666544, 0.13734335878065654, 0.11192591195659977, 0.12974083530051367, 0.22708942661327974, 0.1114009226273213, 0.19774843246809073, 0.13528574204870633, 0.16911599173077516, 0.10429877122598034, 0.11611777916550636, 0.1283951646515301, 0.17546416180474417, 0.13901448196598462, 0.18141789947237286, 0.15907789394259453, 0.20126385454620632, 0.09674614721110888, 0.1203371813254697, 0.14776485599577427, 0.17202411139650003, 0.1405536165194852], [0.02775123409394707, 0.07238882314413786, 0.016863871698400805, 0.009565143613144755, 0.029576635786465237, 0.02015001849005265, 0.0143737499602139, 0.05585594761318394, 0.015074004884809256, 0.04960814983184848, 0.03618323610031179, 0.03216041910595127, 0.002810641749030245, 0.03106576230909143, 0.03667616804263421, 0.0436693670760308, 0.03782776410558394, 0.03450346498617104, 0.02563600125722587, 0.016664589356098856, 0.03408427283700023, 0.020801323898402706, 0.026989712546180402, 0.05013696609863213, 0.0220723692660353, 0.028411436792729155, 0.07917303339179073, 26.88489236150469, 76.68363394056047, 74.14861842564174, 81.52936322348458, 69.2425023487636, 55.53904274531773, 31.295019967215403, 19.27683550970895, 27.303655079432897, 38.974933351789204, 46.61476605279105, 51.38876560756138, 48.49732487542288, 39.35642072132656, 6.745148777961731, 0.18255676621837275, 0.09235991364611046, 0.06861521170607635, 0.01925804858495082, 0.08351744884358984, 0.04622066553149905, 1.17388316988945, 0.9428731543677193, 0.7082296652453286, 1.3166137167385645, 0.9064769159470285, 3.1712366555418288, 1.7644824385643005, 30.96834693636213, 73.38372598375592, 72.87722315107072, 73.36214487893241, 68.25843593052456, 70.19552421569824, 70.73655959538051, 67.68759277888707, 64.40079607282365, 66.32237597874233, 63.24982002803257, 64.04670197623116, 59.99073968614851, 65.3023178918021, 61.99360656738281, 65.16370827811105, 65.01960958753313, 66.77165344783238, 68.80539117540631, 68.999009677342, 66.26128741673061, 67.85002081734794, 67.82992662702287, 69.73689447130475, 66.65814767565045, 69.15825544084821, 59.261665207999094, 64.80195031847272, 64.8476208278111, 72.96926593780518, 48.06428187234061, 26.07797200339181, 47.57061583655221, 36.52654797690255, 58.6443247113909, 63.75780282701765, 68.52375984191895, 69.67568778991699, 67.8060109274728, 67.76239708491734, 68.79015377589634, 64.97792039598737, 62.10041427612305, 57.63852432795933, 55.28715317589896, 52.156409536089214, 53.80400807516915, 55.82628127506801, 58.623209135872976, 60.466128485543386, 64.79421002524239, 64.94131033761161, 64.9375444139753, 66.03813907078334, 70.50132138388497, 68.75699002402169, 64.41807624271938, 53.687535422188894, 45.216930934361045, 40.60242033004761, 31.615345818655832, 25.94825782094683, 14.322264432907104, 2.6374271852629523, 1.848257520369121, 1.1979552039078303, 1.2136508588279997, 0.4927630413855825, 0.11343153366552931, 0.07432877511850425, 0.057632498177034516, 0.009740471124782093, 0.1817104702017137, 2.627456303153719, 11.360128385680062, 21.10794292177473, 36.891213757651194, 39.986719608306885, 42.91810553414481, 29.958301203591482, 28.053275380815776, 13.5299847977502, 13.768072639192853, 35.79163701193673, 49.98931850705828, 64.31716755458287, 64.0770378112793, 64.30732890537807, 6.032079041004181, 0.09961060993373394, 0.05472742513354335, 0.02859264126579676, 0.0330533169076911, 0.02177839057653078, 0.012612874403462877, 0.023714420618489385, 0.01789182171757732, 0.022727471077814698, 0.03488572447427681, 0.030035091364490132, 0.05186831944489053, 0.14380184507795743, 0.0287115545278149, 0.05705553985067776, 0.01975446650093155, 0.07928003836423159, 0.014585113618522882, 0.053173071039574485, 0.04555742469217096, 0.04890268375830991, 0.0138479226401874, 0.003467492272778015, 0.00713440980429628, 0.028158540005928705, 0.018688019797472016, 0.07059061713516712, 0.031574653395052464, 0.05565396809418287, 0.02615941808159862, 0.026352347639788474, 0.039434294149811776, 0.02487277828289994, 0.025576062866353562, 0.03118238551542163, 0.02945098127903683, 0.01894794451072812, 0.03964657383039594, 0.05803557511951242, 0.03972802856670959, 0.04397325237680759, 0.026649786857888103, 0.039007465089006085, 0.02879938410062875, 0.034639724995940924, 0.016735798213630915, 0.006239453921028013, 0.04638842313683458, 0.11147344445011445, 0.019212352644119943, 0.030937637934195142, 0.030689660526279892, 0.02243664757614689, 0.06084143955792699, 0.006823954588201429, 0.061481338792613575, 0.023617700540593693, 0.07806141661213976, 0.21329562392617973, 35.42088460922241, 92.04764352525983, 85.36273997170585, 90.1703861781529, 78.90979507991246, 76.25225503104073, 46.855607986450195, 28.41075325012207, 23.142773253577097, 19.184354986463273, 42.710611479622976, 50.68221718924386, 50.39728546142578, 42.28947768892561, 9.362916469573975, 0.19780143962374755, 0.07635422250522034, 0.10122891595321042, 0.0951503821249519, 0.09663271651204143, 0.33708371222019196, 2.3464225147451674, 2.7138091666357855, 2.560759893485478, 1.91049296941076, 0.4672080012304442, 0.6752928154809135, 3.734837395804269, 36.77597440992083, 78.52747740064348, 77.26465620313371, 77.10744626181466, 71.83110237121582, 74.3964398247855, 72.57742227826799, 67.35824816567558, 63.52536473955427, 67.3442336491176, 64.48620332990373, 64.982971736363, 62.03644915989467, 66.2685899734497, 62.34650557381766, 64.71156120300293, 67.77532073429653, 67.747284752982, 69.43628065926688, 70.13060024806431, 68.8104772567749, 70.53659043993268, 68.81557723454067, 73.30744865962437, 70.42430060250419, 70.86664376940045, 62.965854099818635, 67.42849445343018, 67.36443206242153, 77.64381940024239, 50.28185851233346, 31.580024651118688, 54.836937699999126, 42.76972675323486, 62.870274680001394, 67.69488838740757, 70.50524016789028, 70.76974419185093, 71.00237682887486, 69.30448722839355, 70.84622301374162, 67.50143664223808, 63.706177711486816, 60.375134876796174, 59.645164081028526, 55.26031575884138, 56.81703880855015, 58.07679237638201, 61.15203380584717, 63.613308089120046, 65.24992847442627, 68.18140125274658, 69.4468002319336, 70.76289326804024, 72.21560178484235, 71.10425131661552, 67.8452057157244, 58.389499528067454, 48.96290281840733, 46.57778079169137, 37.02237490245274, 31.42227622440883, 17.04978847503662, 4.180619052478245, 2.4414595408099036, 2.323438959462302, 3.1480535566806793, 2.080955079623631, 0.7015349673373359, 0.4759794505579131, 0.1029210262266653, 0.007413317382867847, 0.0867243003366249, 2.247501879930496, 13.449425646236964, 22.637826817376272, 38.77376215798514, 37.162009375435964, 35.82043382099697, 23.57497031348092, 27.070379734039307, 17.753743478230067, 22.4797066620418, 45.972759451184956, 56.87767573765346, 73.72989913395473, 70.27877058301652, 83.6897805077689, 13.882194195474897, 0.07966235213513885, 0.017160274454259446, 0.015286199748516083, 0.013162235014273651, 0.07636826818010636, 0.04423194724534239, 0.02686278408925448, 0.02731086825951934, 0.023746259177901914, 0.04124288513724293, 0.016696527999426638, 0.04632289022473352, 0.07297536917030811, 0.027352247021294067, 0.06971385489617075, 0.016391124476545622, 0.028482915367931128, 0.07581725024751254, 0.05081742476405842, 0.06284621198262487, 0.11175093134599072, 0.02180788479745388, 0.06075377283351762, 0.05400917885292854, 0.054504624767495055, 0.04240168045674052, 0.08246709020542246, 0.04031803512147494, 0.0955513081114207, 0.048482592550239394, 0.026244672614016702, 0.050635726656764746, 0.08798152394592762, 0.1864513536649091, 0.11274111749870436, 0.08760653156787157, 0.09467318880238704, 0.1322725173085928, 0.09462266508489847, 0.2789526400821549, 0.10494329128414392, 0.15445252428097384, 0.128713316151074, 0.10750085940318448, 0.12244218694312231, 0.10179358601037945, 0.12522703036665916, 0.09302368374275309, 0.1385997070797852, 0.141909994451063, 0.12953195508037293, 0.12867894156702928, 0.0740634204287614, 0.1769262147801263, 0.18222177347966603, 0.17439878040126391, 0.13173275627195835, 0.14257527089544705, 0.34497453165905817, 48.894848687308176, 105.2721221106393, 93.3777997153146, 100.96746989658901, 86.55135440826416, 76.79569448743547, 45.45974963051932, 27.33964327403477, 37.78003774370466, 58.97375270298549, 66.44392081669399, 69.88828182220459, 69.74894264766148, 57.63679770060948, 12.61754822731018, 0.5726117938756943, 0.2101734671741724, 0.25236644382987705, 0.09610751683690719, 0.18895461862640722, 0.3333725056477955, 2.8984130322933197, 3.0481349868433814, 3.7661364248820712, 4.664082961423056, 4.808392269270761, 11.742720518793378, 7.198333740234375, 39.4695269720895, 84.77893148149762, 77.7456521987915, 78.5553674697876, 73.33253165653774, 75.46848433358329, 74.2008341380528, 66.2785814830235, 62.135863985334126, 67.74397046225411, 64.08350658416748, 65.90068285805839, 61.249968664986746, 67.61288574763707, 64.0838748386928, 66.81972108568463, 69.21703720092773, 71.76990263802665, 73.72240897587368, 75.66060897282192, 71.70862647465297, 72.66824218205043, 73.45267295837402, 76.91433497837612, 73.2495562689645, 74.8035556248256, 66.95268181392125, 70.55966540745327, 70.79575824737549, 79.75081198556083, 56.01590803691319, 37.83487292698452, 61.33354159763881, 49.16456733431135, 67.75540719713483, 69.77985518319267, 74.4060491834368, 72.75358690534318, 71.58253056662423, 72.02581868852887, 75.94525582449776, 71.14066682543073, 67.71893610273088, 65.0154059273856, 63.69371959141323, 60.42147241319929, 59.44763374328613, 61.57232339041573, 63.80799661363874, 65.4877097266061, 68.13454954964774, 70.81898607526506, 72.74948746817452, 73.35373755863735, 75.7905194418771, 75.72100966317313, 71.36441271645683, 58.38247489929199, 49.58272034781319, 46.65370723179409, 33.9442777633667, 30.40018231528146, 21.449476412364415, 7.1203771233558655, 7.113682968275888, 4.136832807745252, 4.2970947452953885, 2.6364978637014116, 0.9492252192326954, 0.3885708680110318, 0.24360408687165805, 0.11405876465141773, 0.39948515806879314, 4.399091695036207, 19.40897635051182, 36.07631860460554, 54.52661725452968, 55.177670410701204, 58.70892211369106, 42.85114574432373, 40.79029961994716, 20.77260548727853, 23.878168855394634, 50.1401743207659, 66.00740718841553, 83.16427435193742, 79.77459566933769, 94.8607954297747, 13.52307047162737, 0.17976086267403193, 0.13689658418297768, 0.09792528501046555, 0.15779809547322138, 0.10667498729058675, 0.11964810187263147, 0.1095284509605595, 0.10516483975308281, 0.08801540998475892, 0.08646407537162304, 0.12190283302749906, 0.11269579814480883, 0.23770995172006743, 0.11831104861838476, 0.17811548310731137, 0.15360238775610924, 0.12357734888792038, 0.13597058744302817, 0.16737097608191626, 0.21805442071386746, 0.23122255983097212, 0.14583415245371206, 0.1400867844266551, 0.1609881871512958, 0.08211132750979491, 0.12170613929629326, 0.188827298315508, 0.17344079752053532, 0.23890984590564454, 0.13138660841754504, 0.15725818515888282, 0.13905120428119386], [0.07666267773934773, 0.10945955930011612, 0.022289549665791646, 0.043127305805683136, 0.05082043745954122, 0.04668512275176389, 0.03586470801383257, 0.037650093103625944, 0.01961381806592856, 0.00741579573202346, 0.04736766451969743, 0.016472684385787164, 0.027208246623298953, 0.016040930857083628, 0.012082721422692495, 0.008111948912431086, 0.028382772080866352, 0.08062268274703197, 0.04850586969405413, 0.04505310693223562, 0.09702700642602784, 0.04334149556234479, 0.018856776545622518, 0.022743808504726206, 0.0430443379362779, 0.04967103645737682, 19.481937646865845, 79.99463817051479, 85.7419934953962, 84.81200490679059, 72.6432912009103, 52.01074750082833, 15.353177343096052, 16.6062901701246, 41.24936362675258, 48.39367512294224, 49.45414740698678, 41.62771041052682, 35.45060552869524, 25.62485044343131, 8.062546338353838, 0.7104910867554801, 0.08132942446640559, 0.041736227593251636, 0.10510642467332737, 0.17600822475339684, 0.06708794473005192, 0.09171440292681966, 1.1656664907932281, 1.857523377452578, 1.9006701707839966, 0.949121756213052, 0.18386905294443878, 2.8167515056473866, 42.26272365025112, 73.94299343654087, 69.4197439466204, 66.94776248931885, 65.16405568804059, 68.69028036934989, 71.31744289398193, 72.40514169420514, 67.08473232814244, 66.04848493848527, 63.88946424211775, 66.49997888292584, 66.88291495186942, 67.6903303691319, 65.1855742590768, 68.25710187639508, 68.37187222072056, 70.7388733455113, 65.80246312277657, 64.48573780059814, 63.17927496773856, 67.65865353175572, 70.08306067330497, 67.43112782069615, 66.83134542192731, 68.2139813559396, 65.01520442962646, 55.6910901750837, 55.60586704526629, 65.27239894866943, 66.81435707637242, 70.1708789552961, 31.881642477852957, 27.694539887564524, 38.19554001944405, 68.96706880841936, 62.85332107543945, 65.06293855394635, 67.17931120736259, 66.2950348172869, 67.64904417310441, 65.56195817674909, 60.69994231632778, 56.24500404085432, 52.427128723689485, 51.32284457342965, 52.48594175066267, 55.30884197780064, 60.000939641680034, 64.70433507646833, 66.78118637629917, 69.25243132455009, 69.2032311303275, 69.66874653952462, 70.83170127868652, 69.92009762355259, 69.78319726671491, 67.83652741568429, 67.58389786311558, 70.7516232899257, 66.43440873282296, 69.23895181928361, 66.7209871837071, 48.40183578218733, 27.51064886365618, 4.041526538985116, 0.136563667761428, 2.6085856471742903, 1.2014553589480264, 0.7986556387373379, 0.12094632935311113, 0.16464576231581823, 0.020036460565669195, 0.04427214365984712, 0.03674235913370337, 0.46022115328482216, 4.558264068194798, 20.507008859089442, 40.72343363080706, 62.06538840702602, 62.09497383662632, 38.68538454600743, 41.892461095537456, 41.537112849099294, 26.295732021331787, 44.25116607121059, 51.664657729012625, 65.34869711739677, 63.196680205208914, 63.674799646650044, 1.840534814766475, 0.0742442567965814, 0.07990900639976774, 0.01071682958198445, 0.055602158552833965, 0.02166379618990634, 0.043264485230403285, 0.04269991356081196, 0.06410593938614641, 0.04078951857185789, 0.0028402110328897834, 0.015678645743589317, 0.019595029431262186, 0.0026997674306455466, 0.054929041636309454, 0.011729534615629485, 0.03536585246079734, 0.03143926869545664, 0.03332527374316539, 0.05674107958163534, 0.0822391974340592, 0.08059318004442112, 0.01059799435149346, 0.030805296464157955, 0.028597584393407618, 0.07074320609016077, 0.07629634346812963, 0.03212083337296333, 0.028232456218185167, 0.04411872349945562, 0.020346635886068856, 0.043808385330651484, 0.04088419456300991, 0.05236555329923119, 0.041252842638641596, 0.06495263573846646, 0.05821529868990183, 0.02261328381220145, 0.014499034666057144, 0.00921154289972037, 0.053117587231099606, 0.014091277528288109, 0.06747686743204083, 0.034034556576183865, 0.037298299837857485, 0.07764069775917701, 0.005395857625574405, 0.018772271794400046, 0.029266918477203165, 0.05287252413108945, 0.05100011692515441, 0.01440756136019315, 0.09837267707501139, 0.031415469079677544, 0.06542137451469898, 0.020792299382654682, 0.20484109116452082, 0.0722188161952155, 26.692849363599503, 98.3401267187936, 96.74541091918945, 94.39389038085938, 84.0067503792899, 78.26578044891357, 33.28517164502825, 26.919100080217632, 36.61106933866228, 38.389710903167725, 45.88631343841553, 43.09111567905971, 41.80636944089617, 30.93517276218959, 10.736593570028033, 0.3258712467338358, 0.031462620478123426, 0.038771161876086674, 0.025471865332552364, 0.18107350223830768, 0.39734093312706265, 1.2057697560106004, 2.8795968762465884, 2.3527134571756636, 2.756598562002182, 0.7338639040078435, 0.4252530410885811, 4.118321938174112, 47.591793945857454, 77.46343721662248, 72.25943796975272, 71.83084528786796, 68.1680190222604, 70.8814503805978, 75.79202025277274, 76.08922249930245, 67.96386010306222, 69.25664888109479, 65.07041481563023, 69.47751126970563, 69.53628608158657, 67.62475327083042, 66.19479315621513, 68.00197097233364, 69.5644679750715, 71.89328180040631, 68.19958468845913, 66.90800489698137, 65.78213269369942, 70.5642442703247, 71.52316515786308, 67.77183273860386, 68.84902586255754, 69.5370225906372, 66.6105455671038, 57.54963949748448, 58.65453161512102, 67.92885507856096, 70.65401499611991, 71.53890977587018, 33.76546587262835, 32.817905289786204, 40.29479578563145, 69.68008599962506, 66.64718341827393, 70.02181925092424, 68.87174647194999, 69.18942505972726, 68.69474806104387, 68.21525982448033, 64.43610681806291, 58.75267492021833, 54.79765605926514, 53.94920110702515, 55.10768815449306, 56.919729709625244, 62.773917061941965, 67.03251661573137, 69.65106337411063, 70.42311246054513, 70.98907102857316, 73.40297249385289, 74.35992704119, 71.768401827131, 71.44030094146729, 68.1780035836356, 68.42563043321881, 73.19724328177315, 67.77927425929478, 70.58232348305839, 70.32408673422677, 55.907446656908306, 32.94754130499703, 7.112901730196817, 1.4814012114490782, 3.3564096220902035, 3.301336028746196, 1.582228149686541, 0.7132786714604923, 0.5228614434599876, 0.07182805466332606, 0.06135100578623159, 0.05615744447069509, 0.17926872122500623, 4.7456943307604105, 19.899156127657207, 39.64493077141898, 49.21792949948992, 38.14080558504377, 21.254412685121807, 20.816118580954416, 25.30995634623936, 35.27206114360264, 62.91774477277483, 61.03128801073347, 74.04290158408028, 69.92704582214355, 80.5324843270438, 6.527544225965228, 0.11232987099460193, 0.058748756136213026, 0.03749812500817435, 0.014576391050858157, 0.05502939357289246, 0.0880512637751443, 0.01745967972757561, 0.0647572244384459, 0.012997396805855845, 0.04003650415688753, 0.04635595862886735, 0.023025181709921787, 0.03417250613815018, 0.044190471792327504, 0.055404514872602055, 0.07032167978052582, 0.013528888196950513, 0.015212643159819501, 0.034025861149919887, 0.013745682679915001, 0.02653547575963395, 0.03382859066394823, 0.022439753570194756, 0.02925908818308796, 0.03979354451543518, 0.04596203173111592, 0.016982645860740116, 0.016734320703627806, 0.030604830078248466, 0.022699907289019654, 0.03680942892762167, 0.16536601366741316, 0.14882235282233783, 0.18682870055947984, 0.13169922307133675, 0.18366721591779164, 0.14309212458985193, 0.08401238585689239, 0.12617759007428372, 0.1036241649250899, 0.14763773924538068, 0.2486414494259017, 0.09675902580576283, 0.18687547876366548, 0.1745424126940114, 0.06650109336312328, 0.15184009660567555, 0.1561851091682911, 0.1444391794502735, 0.16092430986464024, 0.10275941275592361, 0.2183769148375307, 0.17991282737680844, 0.17862080170639924, 0.18146220780909061, 0.2781218689467226, 0.1466012227215937, 39.38025304249355, 111.67643656049455, 105.16269493103027, 108.67986610957554, 90.96806022099086, 72.15170615059989, 26.60547055516924, 28.482705320630753, 61.1361780166626, 70.94601999010358, 70.75626468658447, 60.19994299752371, 55.278884819575715, 41.11241463252476, 15.240590470177786, 1.163696242230279, 0.16629807651042938, 0.09036048807735954, 0.13124708804701055, 0.3304188698530197, 0.23924629070929118, 0.9347242202077592, 6.166794623647418, 5.993399287973132, 8.299901144845144, 5.343136055128915, 2.8259322472981045, 4.267589219978877, 52.03563942228045, 82.05617564065116, 74.28895814078194, 73.3294049671718, 71.09893594469342, 75.48063673291887, 77.79810414995465, 77.76546846117292, 67.53211988721574, 72.72106238773891, 64.98595946175712, 69.98123482295445, 71.91830921173096, 70.25210339682442, 66.34716715131486, 70.00893729073661, 71.65063680921281, 75.2612612588065, 72.6186876296997, 71.295257295881, 69.3929933820452, 74.60648386819022, 76.10106222970145, 71.69399356842041, 71.01998356410435, 72.37109552110944, 70.02341038840157, 59.89137349809919, 61.95197296142578, 70.17399174826485, 72.54339694976807, 71.82213224683488, 37.374478340148926, 39.250446796417236, 44.502499784742085, 72.09899711608887, 70.66241536821637, 70.89026764460972, 72.92322717394147, 70.5620972769601, 71.849258014134, 73.09218651907784, 67.26055649348667, 62.674675941467285, 57.05114793777466, 57.08136565344674, 58.11787360055106, 58.74815859113421, 66.3616749899728, 70.9561574118478, 73.39832414899553, 74.09220600128174, 75.83633586338588, 75.66909967150006, 75.900968006679, 74.17590400150844, 71.99660846165249, 68.961044720241, 70.53873743329729, 73.04748180934361, 66.97941848209926, 73.64043412889752, 72.69592380523682, 51.27089636666434, 32.37783070972988, 7.371847629547119, 4.940017640590668, 8.949934652873448, 5.063954830169678, 3.216044068336487, 0.6024587580135891, 0.4379259853490761, 0.1947059357272727, 0.20905402010040625, 0.19996018521487713, 0.8493084950106484, 7.9822572980608255, 32.666761125837056, 61.66548483712332, 85.266847882952, 79.57536997113908, 53.82820517676217, 57.815769399915425, 53.67059918812343, 41.89483390535627, 61.211003167288645, 68.1633220400129, 85.81703404017857, 78.53705201830182, 91.51812825884137, 7.59518791948046, 0.2909079114241259, 0.19162449107638427, 0.11321428710860865, 0.11233867837914399, 0.17013760762555258, 0.22960419952869415, 0.11338685213455132, 0.19620016483323915, 0.07210832355277878, 0.05987469679010766, 0.08929763760949884, 0.042773880663194826, 0.10953331605664321, 0.13421094257916721, 0.16969670914113522, 0.22524626765932354, 0.10534404085150786, 0.14844964710729464, 0.1650992679808821, 0.12245898747018405, 0.09423152357339859, 0.1300023698381015, 0.11417358634727341, 0.11008283442684583, 0.1467818216021572, 0.08532140204416853, 0.12666621671191283, 0.06047656413699899, 0.1066259088526879, 0.10736029408872128, 0.09292219526001386], [0.03151388379878231, 0.043370655604771206, 0.010797098578353013, 0.025060043770021627, 0.05461828277579375, 0.07432387609566961, 0.017292383526052748, 0.07381363811769656, 0.09096910684768643, 0.03415975985782487, 0.03870348140065159, 0.025441677309572697, 0.025496528384142687, 0.04474082476060305, 0.02944628581670778, 0.00669786030526406, 0.033769374912870784, 0.10040073003619909, 0.012905127069513713, 0.017764009468789612, 0.017806543436433588, 0.07265026947217328, 0.0971283388457128, 0.1536878967391593, 0.16222289018332958, 6.1251106432506015, 77.27866377149309, 75.22412313733781, 82.46784945896694, 52.012098925454275, 35.90381220408848, 17.596835783549718, 37.561468260628835, 36.13713271277291, 30.897725445883616, 33.09661143166678, 35.195960998535156, 38.54938398088728, 27.139978102275304, 12.292268310274396, 0.9277226073401315, 0.17626420887453215, 0.013109511146987123, 0.08010141857500587, 0.081558050055589, 0.17701935049678597, 0.34995473442333086, 0.9944497410740171, 4.809724586350577, 3.137330097811563, 1.7021179050207138, 1.4073136555297034, 3.510321340390614, 55.002266611371724, 76.19349411555699, 72.28342315128872, 69.68693692343575, 61.28229168483189, 58.6784542628697, 69.17110266004289, 70.03996794564384, 71.56936373029436, 66.24889877864292, 71.00077179500035, 69.4951388495309, 65.82443332672119, 60.81162071228027, 66.51069300515312, 67.5951053074428, 69.50403949192592, 67.33948108128139, 60.389816420418875, 58.36991950443813, 58.14911617551531, 59.06627491542271, 61.039695331028526, 63.891854422433035, 65.21682030814034, 67.30297524588448, 65.86451053619385, 65.91779627118791, 55.14188371385847, 52.8285539490836, 61.96692548479353, 64.30174950190953, 71.69630731855119, 49.79519626072475, 19.819272688456945, 33.93749284744263, 66.29201929909843, 66.36402348109654, 61.90012550354004, 64.26600796835763, 66.39078794206891, 64.98468794141496, 63.53569671085903, 53.702550479343955, 50.76474094390869, 52.052641664232524, 54.4325247492109, 58.026313713618684, 63.132986068725586, 64.90958486284528, 68.36076205117362, 69.93881607055664, 68.8401460647583, 64.5281982421875, 65.65645367758614, 66.1728299004691, 69.36567306518555, 64.62478515080043, 64.87671293531145, 65.27661650521415, 68.47441373552594, 72.07300390516008, 72.26707404000419, 74.26368754250663, 72.45065934317452, 61.825988224574495, 24.47666757447379, 2.1134292227881293, 2.252095941986356, 1.4129397422075272, 0.4957403444818088, 0.8907814238752637, 0.2490615983094488, 0.014278537926397153, 0.041857173067650626, 0.0758541761232274, 0.10212219373456069, 0.0493572241892772, 0.5925981785569872, 7.683121715273176, 25.062567472457886, 49.44505568913051, 64.43126392364502, 80.77678993770054, 118.00681522914341, 80.73818574632917, 11.437190856252398, 27.068875449044363, 43.811973912375315, 60.67101696559361, 68.62857341766357, 42.14444446563721, 0.9046437314578465, 0.0432463072772537, 0.025310357034738575, 0.009985887911170721, 0.013519515083836657, 0.047661609282451015, 0.044792332353868654, 0.046863546927592585, 0.02645151553276394, 0.02069551993294486, 0.03660620429686137, 0.014927468462181943, 0.03374506300315261, 0.06081376211451633, 0.04021213276843939, 0.05032297629596932, 0.01593612433810319, 0.006909001743354435, 0.021906592982954214, 0.08969048224389553, 0.030654868643198694, 0.07113028317689896, 0.016397891167019094, 0.019079675299248526, 0.050094774791172574, 0.013912495425237077, 0.0038649592149470535, 0.03933455628742065, 0.04449915433568614, 0.025665833049320748, 0.10070306488445827, 0.029366123689604656, 0.013644922774152031, 0.004857836607178407, 0.018627801510904516, 0.04369406235803451, 0.07249338539051157, 0.03125291923061013, 0.09538168792745896, 0.056442537744130404, 0.04833232418500951, 0.020647332072257996, 0.04615566187671252, 0.05244425318336912, 0.04911609659237521, 0.029345693000193154, 0.008360189252666064, 0.018904944050258825, 0.08793100701378924, 0.0307286152217005, 0.05897340551018715, 0.06373737273471695, 0.14154187563274587, 0.0054005836219792915, 0.1408103605998414, 0.24469069285052164, 8.978113072259085, 93.12482275281633, 86.7202512196132, 92.09039579119, 61.98121098109654, 55.76859385626656, 29.099681036812918, 22.40291690826416, 21.502854210989817, 32.90468829018729, 42.2830992426191, 42.106375285557334, 46.34699290139334, 32.34136308942522, 14.485824159213475, 1.0732202742780959, 0.14331054501235485, 0.157480690362198, 0.14993363033447946, 0.2854639435453074, 0.580936712878091, 1.3252378425427844, 3.3303449749946594, 5.4876629284449985, 2.2876713701656888, 0.8213340161102158, 0.32395878221307484, 5.308721627507891, 58.17673179081508, 78.006744657244, 74.2776881626674, 72.36727401188442, 65.1837329864502, 61.7277615410941, 70.53105967385429, 73.4579883302961, 73.88138375963483, 68.45716830662319, 70.84834221431187, 70.4411986214774, 68.32869611467633, 64.66724559238979, 69.88294560568673, 69.52309145246232, 70.74334798540387, 69.26462541307721, 63.88188375745501, 61.700378690447124, 60.23766476767403, 63.271741594587056, 64.06740760803223, 66.37375790732247, 68.44893469129289, 69.07045105525425, 69.32001645224435, 68.4392419542585, 57.99357032775879, 53.82688849312918, 61.94528879438128, 67.75783906664167, 73.13154111589704, 51.2668525150844, 23.95705870219639, 36.365846565791536, 68.38257939474923, 67.75626182556152, 64.2530495779855, 66.54293959481376, 68.8138679776873, 68.27772412981305, 66.657730783735, 56.75623164858137, 52.02220160620553, 53.37140628269741, 57.72808313369751, 60.92828791482108, 64.18490859440395, 67.04032639094761, 69.53480611528668, 72.13953290666852, 70.59026527404785, 65.61462552206856, 67.82789080483573, 66.24048451014927, 69.15744944981166, 66.41446045466832, 65.49328218187604, 64.32722854614258, 66.82873289925712, 74.54706982203892, 74.11899825504848, 74.51835986546108, 75.16812760489327, 62.88300377982003, 30.080106598990305, 5.437240285532815, 0.5321945569344929, 1.9449914268084934, 1.2464246430567332, 3.005541226693562, 1.6533319971391132, 0.2016955249543701, 0.18309393525123596, 0.04398445498996547, 0.02593997137487999, 0.007734285650907883, 0.730136684009007, 8.751016412462507, 27.324810607092722, 46.634950569697786, 51.53393432072231, 69.51399626050676, 108.71176528930664, 78.77611868722099, 20.802698135375977, 39.82177284785679, 51.35728331974575, 70.83744743892125, 77.08181435721261, 61.818796839032856, 2.927736384528024, 0.1296407106731619, 0.03774726949632168, 0.04776650061830878, 0.08631111322236912, 0.05731754257742848, 0.07451527725372996, 0.023334654746577144, 0.02024230094892638, 0.035211692697235515, 0.014873572425650699, 0.02667935232498816, 0.015126501442864537, 0.08401375649763004, 0.021308622123407464, 0.04796461248770356, 0.008119639258698692, 0.038655980556671105, 0.1349923570773431, 0.029523017949291637, 0.027007926122418473, 0.10022253995495183, 0.06501707620918751, 0.031476028330091915, 0.027385469792144637, 0.011423874097610158, 0.06487677552338157, 0.020613425677376132, 0.03882134971874101, 0.029285001435450146, 0.048468655440956354, 0.23141662084630557, 0.12739128566214017, 0.12554119208029338, 0.08755511218415839, 0.08420496766588517, 0.25846071967056816, 0.052569697344941754, 0.1098667210234063, 0.25168470612594057, 0.12845269085041114, 0.15917416449104035, 0.08657759428024292, 0.1243587498153959, 0.24606619189892495, 0.18671075760253839, 0.0536844828831298, 0.14073165053767817, 0.15905593654939107, 0.08821775591267006, 0.11115276201495103, 0.09300026749925953, 0.22565523428576334, 0.18492398490863188, 0.29923117480107714, 0.37250600861651556, 14.304618614060537, 109.18607016972133, 95.75493826184953, 104.71133300236293, 70.43226323808942, 55.03198405674526, 29.65871572494507, 52.018710136413574, 50.399105889456614, 51.42079332896641, 46.036057540348594, 49.85691016060965, 58.438526017325266, 41.9284006527492, 19.759252411978586, 1.7210010460444858, 0.2960729742688792, 0.26419843892966, 0.153839359326022, 0.3243406345801694, 0.5491593437535423, 2.1132828763553073, 5.206339921270098, 14.922510623931885, 9.90767434665135, 8.346631254468646, 5.375358760356903, 5.000618960176196, 63.679524421691895, 81.91298716408866, 77.95465401240757, 75.74505737849644, 67.02063519614083, 63.82082298823765, 74.63014248439244, 77.31411348070417, 76.71741608210972, 69.02950532095772, 70.34567478724888, 73.35425867353166, 72.74449171338762, 67.53619847978864, 72.31116036006382, 72.35372502463204, 75.21470138004848, 72.27695437840053, 65.63767964499337, 65.69783020019531, 64.08417361123222, 67.903459412711, 68.50113650730678, 69.50749969482422, 72.09048557281494, 72.24580560411725, 73.68926606859479, 73.38134969983781, 60.742840494428364, 56.61221286228725, 66.49918678828648, 71.30016272408622, 76.51249980926514, 60.89861215863909, 29.768903732299805, 44.41196475710188, 74.456784929548, 70.92952496664864, 68.12533623831612, 69.06334999629429, 71.1608999797276, 71.25884873526437, 69.594984463283, 58.594721521650044, 56.181897027151926, 57.640379496983115, 60.58897958483015, 63.85936464582171, 68.96531786237443, 72.29901490892682, 74.62592492784772, 75.88040828704834, 72.88099602290562, 65.97226319994245, 68.264237676348, 67.95241641998291, 70.68974263327462, 67.62410708836147, 66.24409062521798, 66.73496695927211, 68.03268201010567, 76.61681311471122, 76.96816962105888, 80.87380068642753, 79.62845420837402, 66.50660746438163, 28.509334291730607, 5.979344385010855, 8.399802344185964, 7.101283039365496, 3.0172013895852223, 3.917915914739881, 1.9884910583496094, 0.25801076952900204, 0.25528338445084436, 0.22561072238854, 0.2447652502783707, 0.2697549621973719, 1.4007747492619922, 12.43559227670942, 41.41718346732003, 68.26328577314104, 81.09984643118722, 89.80988584245954, 126.29102734157017, 89.14448465619768, 20.237825223377772, 41.22658395767212, 60.43520900181362, 80.68822819846017, 85.35995374407086, 67.91287422180176, 2.4617072428975786, 0.24608592369726726, 0.1088831438017743, 0.136001800053886, 0.23130105276192936, 0.12823636031576566, 0.130114273833377, 0.11498337717992918, 0.0826902739437563, 0.06852227954992227, 0.10171560876603637, 0.057048123462923934, 0.08661302737891674, 0.2576144779367106, 0.11900190583297185, 0.20163003275437014, 0.06660263612866402, 0.07840687914618424, 0.19181944775794232, 0.20529965870082378, 0.10488153102674655, 0.21036917024425097, 0.11555863916873932, 0.13829729759267398, 0.15879394060799054, 0.09497034642845392, 0.14741465050194943, 0.06518552252756697, 0.1475990763200181, 0.07249844047640051, 0.19526655493038042], [0.09241905475833587, 0.08119739512247698, 0.0534156948061926, 0.07666571757623128, 0.05440933130947607, 0.03371818283838885, 0.03186267454709325, 0.0455348125126745, 0.03888175969145127, 0.03414326806419662, 0.08133857111845698, 0.03352525158386145, 0.018463185522705317, 0.04273571306839585, 0.036399491996105225, 0.07288316304662398, 0.05033856563802276, 0.04622925578483513, 0.027088649737249528, 0.0892216009753091, 0.05176030684794698, 0.049493552052548954, 0.006059446214099548, 0.058076483995786736, 0.5689264801996095, 46.81026751654488, 89.0809850692749, 81.26420606885637, 77.13238334655762, 67.7887932913644, 39.09433814457485, 111.581100327628, 119.84166772024972, 59.20683002471924, 44.717692443302695, 42.98373474393572, 51.699388299669536, 27.326340947832378, 10.838766830308096, 0.05199300364724227, 0.0790238438972405, 0.017141896333279352, 0.0366287316594805, 0.12844720828746045, 0.06971562587256942, 0.37536283103483065, 1.1171195358037949, 0.9666368620736259, 2.0222378075122833, 1.3179745865719659, 2.0476814593587602, 5.423468955925532, 63.1585693359375, 75.689298084804, 71.72288417816162, 69.00859124319894, 60.801434653145925, 57.78661823272705, 64.73642880575997, 67.34026622772217, 73.24076679774693, 70.06391838618687, 65.77927698407854, 67.44564260755266, 67.72649574279785, 60.10352979387556, 58.842681884765625, 61.27092443193708, 65.02325044359479, 63.481632777622764, 64.18485995701381, 62.11870888301304, 55.0256472996303, 51.198544774736675, 53.36958932876587, 56.80367742265974, 59.54576315198626, 60.95100852421352, 67.27205576215471, 63.51449775695801, 58.537336349487305, 50.19409581593105, 50.2741425377982, 58.75667708260672, 69.86226081848145, 60.09131486075265, 40.33186442511422, 23.262603623526438, 29.68390989303589, 61.12522765568325, 63.298408780779155, 61.92649391719273, 60.76406029292515, 65.53772980826241, 61.8668714250837, 62.13559300558907, 51.92489555903843, 49.93084246771676, 49.77898958751133, 55.392807483673096, 59.72754887172154, 64.65454428536552, 66.88345691135952, 65.93536131722587, 64.6314206804548, 62.094744546072825, 63.97426700592041, 65.10508632659912, 67.46853692190987, 62.97443512507847, 61.32864311763218, 64.10317693437848, 62.46258217947823, 69.58989143371582, 69.74747657775879, 68.66846997397286, 69.67277649470738, 72.33750792912075, 74.01701954432896, 59.186124392918174, 19.961014202662877, 0.8789418020418712, 2.5642570086887906, 1.0083905415875571, 1.2699691568102156, 1.0015827183212553, 0.16356219617383821, 0.10714525277061121, 0.08913637697696686, 0.08487032553447144, 0.1991206066949027, 0.04697806667536497, 0.04319662833586335, 1.5973467784268516, 17.49181202479771, 32.02363239015852, 64.58458982195172, 88.04252120426723, 113.77932970864433, 46.86464064461844, 20.75997539928981, 50.41819259098598, 56.95617995943342, 62.67323766435896, 67.27316747392926, 32.69451570510864, 0.3249422237277031, 0.10004335242722716, 0.06024245598486491, 0.026653084538078735, 0.07112655123429638, 0.03352250351703592, 0.043772602786443064, 0.10245745788727488, 0.05281188006379774, 0.03931491948398096, 0.01513930709500398, 0.05815585223691804, 0.022745384402307015, 0.06527851575187274, 0.058725373819470406, 0.0641084024682641, 0.04016417730599642, 0.015026466721402747, 0.015751454247427837, 0.03054473901699696, 0.034136472535984855, 0.03437341357182179, 0.034908652172556946, 0.03461437153496912, 0.07976033937718187, 0.07886431352900607, 0.02667591724145625, 0.1022498058155179, 0.04488880307014499, 0.017497424934325472, 0.03471551396484886, 0.015329339308664203, 0.03656476955594761, 0.014671916907121028, 0.041191984832819016, 0.015747942828706334, 0.08784922318799154, 0.05164070826556001, 0.08705849240400962, 0.015105850229571973, 0.04917061348844852, 0.02452947518655232, 0.008039618775780712, 0.02739713041644011, 0.09177756775170565, 0.055436785998088975, 0.01076175453740039, 0.02317178768238851, 0.01242423233842211, 0.016751387555684363, 0.04389294097200036, 0.03359240958733218, 0.06383723273341145, 0.10320360213518143, 1.0676317512989044, 58.28321640832083, 101.06860092708042, 89.3352335521153, 85.74006884438651, 73.8515065056937, 42.5156033379691, 89.8790204184396, 103.43286446162632, 53.85450758252825, 38.20986373083932, 33.40161303111485, 51.22755002975464, 31.99107313156128, 13.479421888078962, 0.08329993765801191, 0.0592427703418902, 0.03922202803992799, 0.12043844589165278, 0.5155694718871797, 0.6817582228354045, 1.535795618380819, 5.02508921282632, 7.831087946891785, 2.034436455794743, 0.724512225815228, 0.4038356803357601, 7.371582729475839, 65.37199442727226, 78.04684965951103, 74.9211538859776, 71.63869285583496, 63.417174339294434, 60.89588846479143, 67.37170682634626, 70.9720618384225, 75.14951338086809, 71.83648027692522, 69.54726423536027, 68.30104923248291, 70.67957047053746, 61.257618631635395, 61.91441099984305, 65.1373051234654, 67.68042918613979, 68.23776503971645, 66.80880546569824, 62.42474923815046, 58.79744216373989, 54.75881215504238, 55.90088408333914, 58.78378200531006, 61.3165602002825, 62.99659293038504, 70.28150122506278, 65.6451975958688, 61.76470511300223, 52.82464558737618, 52.574982915605815, 61.10862146105085, 70.44922379084996, 63.6660657610212, 50.81627573285784, 25.49716166087559, 34.36094733646938, 67.68871143886021, 65.27835355486188, 64.11729567391532, 62.688336099897114, 67.17555918012346, 62.463235310145784, 65.46362032209123, 53.392042432512554, 52.01267910003662, 53.45457969393049, 57.78927591868809, 61.56067820957729, 67.99981703077043, 69.11880356924874, 67.1348705291748, 67.05191598619733, 63.354953220912385, 64.348114831107, 65.77002198355538, 67.72616917746407, 65.08841064998082, 61.986053875514436, 62.92221941266741, 61.37901060921805, 71.45360674176897, 72.64684173039028, 72.6037767955235, 72.35734503609794, 73.19400542122978, 77.65833418709892, 62.43267018454415, 24.56199492727007, 2.170271566935948, 1.0954142319304603, 1.205685400537082, 2.445159890822002, 2.868711003235408, 1.1441564964396613, 0.4939505862338202, 0.11942068407578127, 0.06234894759420838, 0.09280501226229326, 0.04725751453744514, 0.049246982604797394, 1.1890520645039422, 18.465706280299596, 34.908288206372944, 64.77702713012695, 97.57448387145996, 114.52486446925572, 45.01899412700108, 33.89367750712803, 57.799896240234375, 64.01804065704346, 68.10381766727993, 77.20891775403703, 44.428348609379356, 0.4954323438661439, 0.043197741133293936, 0.08354664620544229, 0.04892455294196095, 0.08273361876074757, 0.046077430181737454, 0.004783649829083255, 0.09587643495095627, 0.031713356130889485, 0.03507981263101101, 0.030993834204439605, 0.07309461491448538, 0.05035858581374798, 0.03312895320621984, 0.04825765819155744, 0.03945860605952995, 0.04827071999066642, 0.021928752240325724, 0.027725210579644357, 0.05868409174893584, 0.037686007962163, 0.01840432600251266, 0.012639537437020667, 0.018605560829330767, 0.07193646420325552, 0.051016985305718014, 0.10959375995610442, 0.04222237757806267, 0.0397354992372649, 0.024296539203662957, 0.1006305566323655, 0.11625504679977894, 0.174782980499523, 0.15335036627948284, 0.10911352001130581, 0.1550641693174839, 0.2412828728556633, 0.1960462188082082, 0.14876099968595163, 0.11658573762646743, 0.14894045862768376, 0.1586097047797271, 0.06730862467416696, 0.0864694629396711, 0.10295981807368142, 0.140728515705892, 0.15164302289485931, 0.1592627947351762, 0.09141245484352112, 0.16714207907872541, 0.1780498552003077, 0.11971287482551166, 0.13751840724476747, 0.1497735639235803, 2.2327706132616316, 77.24217878069196, 109.90597997392926, 102.09891455514091, 95.37061950138637, 86.38666820526123, 49.603773389543804, 123.68573079790387, 122.89077350071499, 72.27646105630058, 60.24229921613421, 58.69838169642857, 77.9844617843628, 43.36351980481829, 18.66204673903329, 0.6937877801912171, 0.21039172474827084, 0.2301233331007617, 0.37038561382463997, 0.3850182757845947, 1.1549218616315295, 1.8790035162653242, 5.3084558589117865, 6.125592240265437, 5.530125541346414, 5.712819738047464, 5.429178638117654, 6.846983313560486, 70.90896524701799, 80.18874999455043, 77.62870012010846, 74.77258055550712, 66.37096473148891, 64.03324331556047, 71.40622002737862, 75.19845649174282, 79.3541601725987, 74.7993380682809, 68.79375294276646, 69.57397311074394, 75.86978449140275, 67.13770539419991, 64.72911930084229, 67.66854776654924, 73.61050823756626, 71.97978687286377, 71.46647480555943, 67.00905949728829, 62.58370317731585, 57.998962129865376, 59.42039680480957, 62.274147033691406, 65.41353075844901, 67.10133157457624, 72.4329275403704, 69.17716148921421, 66.0383266721453, 53.713441780635286, 55.601527895246235, 63.81704316820417, 73.33483151027134, 66.98210743495396, 52.30609457833426, 30.691673142569407, 37.671086515699116, 69.02978324890137, 68.43544823782784, 66.65144961220878, 66.67235674176897, 69.24312768663678, 66.83670943123954, 68.62969207763672, 57.87548916680472, 55.7146897315979, 54.61610310418265, 60.95230783735003, 67.0022224698748, 70.3646433694022, 71.67038358960832, 69.8556878226144, 68.06008570534843, 63.82998766217913, 66.21007919311523, 68.56280176980155, 70.68081419808524, 67.24089309147426, 61.74679960523333, 63.776597704206196, 63.285881178719656, 73.50407573154995, 76.82009656088692, 77.78323500497001, 76.19098581586564, 78.29282978602818, 82.23125634874616, 65.37952627454484, 24.565074716295513, 3.7229703068733215, 7.8372179950986585, 4.455183199473789, 3.6771395547049384, 3.731705061026982, 1.3333993703126907, 0.5568537137338093, 0.3556373837803091, 0.31484423843877657, 0.41304141921656473, 0.16192179705415452, 0.2989157645830086, 2.7438957350594655, 29.441685267857142, 47.38962568555559, 72.9918406350272, 90.0569429397583, 116.71529797145298, 58.46852139064244, 33.79750401633126, 66.81750461033413, 73.7218461717878, 80.33352266039167, 88.14345073699951, 49.136409759521484, 0.6805245918887002, 0.1793200998966183, 0.18746207228728703, 0.10955722763070039, 0.17091098826910767, 0.13951783281351837, 0.16196571184056147, 0.30808849952050615, 0.24366719062839234, 0.21458539686032704, 0.17585927274610313, 0.22380808554589748, 0.17488704062998295, 0.14370991715363093, 0.14803255163133144, 0.11241615350757327, 0.14456993314836705, 0.163715517946652, 0.06151766755751201, 0.12685887994510786, 0.18676244840025902, 0.07330688102436916, 0.24411887781960623, 0.13414497540465423, 0.20124049937086447, 0.18117418326437473, 0.21738891356757709, 0.229717134897198, 0.0848119036693658, 0.0616802309772798], [0.06614964615021433, 0.10278347360768489, 0.06939361350876944, 0.037070681873176775, 0.025510492634826472, 0.033986662181892564, 0.01750178282548274, 0.056962051295808384, 0.030864848090069633, 0.01709538954310119, 0.029480477196297476, 0.07824188657104969, 0.012413399526849389, 0.04569527247388448, 0.07115742457764489, 0.09122066013514996, 0.07092843257955142, 0.045836475611265214, 0.03737710150224822, 0.029791897628456354, 0.09518253789948565, 0.07903210166841745, 0.15986983930425985, 0.23171664189015115, 33.77781629562378, 91.45213426862443, 78.87646457127163, 76.13338524954659, 54.264628478458945, 44.874634878976, 53.796396323612754, 66.81963075910295, 50.818947315216064, 33.00361326762608, 52.418339252471924, 64.82517119816372, 24.352152381624492, 5.9978474378585815, 0.17499548409666332, 0.021146075667015145, 0.011503906454890966, 0.09280326842729535, 0.05540792111839567, 0.4560060937489782, 0.25362081080675125, 1.071295080440385, 1.0041045887129647, 6.242958171027047, 0.8987701694880212, 0.7548885558332715, 10.606112480163574, 73.77137987954276, 73.16713673727853, 71.49412168775285, 69.25579425266811, 62.19554901123047, 54.67327635628836, 58.14556564603533, 61.913952418736045, 65.58603368486676, 65.77640737806047, 64.19808237893241, 60.977835518973215, 65.26508249555314, 61.509574208940776, 58.76163809640067, 52.710573537009104, 52.872344970703125, 57.637586321149556, 59.61960860661098, 58.33214214869908, 54.5387418610709, 55.443709986550466, 49.97913244792393, 50.36480958121163, 51.65217876434326, 56.87927382332938, 57.35041727338518, 60.027162143162315, 53.065035888126914, 48.751736640930176, 48.294308934892925, 56.79980032784598, 58.66196618761335, 67.41700213296073, 60.70145007542202, 74.75787816728864, 17.648780516215734, 41.567549433027, 73.91557584490094, 55.31161430903843, 66.51136003221784, 61.0284948348999, 68.69840976170131, 61.83827263968331, 61.68266078404018, 48.90846368244716, 46.72647224153791, 48.6623272214617, 59.53506292615618, 62.1549437386649, 70.68944386073521, 62.702392305646626, 64.53482682364327, 62.06520080566406, 66.66077409471784, 64.86054447719029, 65.16022723061698, 63.41748700823103, 67.67164666312081, 65.10967908586774, 58.682289668491904, 61.68881688799177, 68.79993683951241, 65.7671593257359, 66.73061738695417, 63.66095188685826, 69.12829480852399, 67.62380136762346, 72.69301945822579, 53.72757094247, 19.05458174433027, 0.3218845820852688, 1.0776197867734092, 2.8300245191369737, 2.2745507827826907, 0.1658277024648019, 0.2583784540849072, 0.08893926255404949, 0.0690237847822053, 0.04667707871911781, 0.029811425866293054, 0.07688734746937241, 0.06116202699818781, 0.5364561911140169, 16.83917989049639, 27.257454769951956, 48.925545828683035, 38.52188995906285, 29.37704270226615, 21.775958367756434, 32.54371895108904, 50.116915225982666, 54.18361595698765, 66.92592430114746, 60.85854189736502, 10.466806309563772, 0.11805689654179982, 0.012727475575437503, 0.014712910600272673, 0.04010734999818461, 0.1032884054418121, 0.023943020762609582, 0.06240444497338363, 0.05344116022544248, 0.07498685230634042, 0.044922929988907914, 0.014469706686213613, 0.023290359980559776, 0.02001168385946325, 0.09408456645905972, 0.035534176642873457, 0.021976816268371682, 0.07100227754563093, 0.06171322813523667, 0.036713745311966965, 0.03297202841245702, 0.010027537238784134, 0.05337331350892782, 0.005461253982502967, 0.04880141240677663, 0.03393219956862075, 0.01921064273587295, 0.02220169804058969, 0.05011483567899891, 0.1124701581097075, 0.05953350902668067, 0.03572562190571001, 0.04730808235970991, 0.020802831942481653, 0.08661026574139084, 0.0392737358010241, 0.015713274778266038, 0.05322096882654088, 0.029328739802752222, 0.03495622765538948, 0.043449599761515856, 0.00867881572672299, 0.03523431166208216, 0.022308933714936887, 0.03320221123950822, 0.05470657714509538, 0.03195265507591622, 0.034656525523002656, 0.03026175598746964, 0.01102851125012551, 0.07492634055337735, 0.08497975966227905, 0.09134786509509597, 0.22201519246612275, 44.25418158939907, 107.68229239327567, 88.21684455871582, 84.15109920501709, 60.70156819479806, 58.460100173950195, 66.21722888946533, 87.33533355167934, 77.57592160361153, 47.57237025669643, 49.423599651881624, 58.11832870755877, 29.872133118765696, 7.767731666564941, 0.1798225822193282, 0.011728330215971385, 0.05509065171437604, 0.064263183091368, 0.26203334225075586, 0.5294096863695553, 1.895824019398008, 2.079163747174399, 2.3463011384010315, 1.7589935788086482, 0.3734201581350395, 0.529485356594835, 12.275656035968236, 76.82861505235944, 76.02873843056815, 74.3549451828003, 70.04728439876011, 65.24868474687848, 57.670590264456614, 61.13634477342878, 64.05373355320522, 68.57840047563825, 68.74726949419293, 68.295136315482, 60.92575877053397, 66.84616592952183, 63.929854120527, 61.75513744354248, 56.30221550805228, 55.96120139530727, 60.12406866891043, 61.257993834359304, 61.899375098092214, 58.157405376434326, 57.32797111783709, 53.43888371331351, 53.40189150401524, 54.13307476043701, 59.917992046901155, 60.40631144387381, 63.10902173178536, 55.20528950010027, 51.005242415836875, 49.624809060777935, 60.005553245544434, 61.60268007005964, 72.31924111502511, 62.8548218863351, 76.18089703151158, 20.944755792617798, 42.51849726268223, 75.5788356236049, 59.073681695120676, 69.94578511374337, 62.52913202558245, 71.82915687561035, 65.46685818263462, 64.75798906598772, 52.04891742978777, 48.844898087637766, 51.9430616242545, 61.272487776620046, 65.54348986489433, 72.58933843885148, 63.50416578565325, 64.2058504649571, 62.13236209324428, 68.50270680018834, 67.36102049691337, 66.4656617300851, 66.00713620867047, 68.68828623635429, 65.53255340031215, 57.68890224184309, 64.99581895555768, 70.41853359767369, 67.90088163103376, 68.94277095794678, 64.12518187931606, 71.72654587881905, 68.33777046203613, 74.97195216587612, 56.93361221040998, 22.975474527903966, 0.7623930445739201, 0.648646202470575, 1.644068419933319, 3.1599675459521155, 1.2819037735462189, 0.6366609398807798, 0.22620719538203307, 0.1402964788888182, 0.26208914497068947, 0.05566977117476719, 0.04196855119828667, 0.08946038423372166, 0.3267283450279917, 17.8273092678615, 32.60190316608974, 57.656158855983186, 43.27616705213274, 27.082045759473527, 27.278367110661097, 45.221092905317036, 55.51011044638497, 62.95034572056362, 72.55848843710763, 73.66904681069511, 16.89950588771275, 0.07061581792575972, 0.03964868068162884, 0.022124185592734387, 0.04179232547591839, 0.08173628763428756, 0.03703529287927917, 0.030174574415598596, 0.05614596026550446, 0.0584683379690562, 0.08055312612227031, 0.030870262799518447, 0.058305014590067525, 0.027790283784270287, 0.06983643903263978, 0.08226247797054903, 0.016235158113496642, 0.044866340168352635, 0.02962412984509553, 0.11314646753349475, 0.08071145548352174, 0.02414433192461729, 0.03996713073658092, 0.03959359720881496, 0.03128234050901873, 0.020829135352479558, 0.03028530115261674, 0.08681684572781835, 0.06393114197999239, 0.04376325257388609, 0.15145969630352088, 0.17220667802861758, 0.2276890208678586, 0.11165154632180929, 0.19919312851769583, 0.10745952304984842, 0.06366120717887368, 0.14080554300120898, 0.11850193408983094, 0.09874365252575704, 0.11871354202074663, 0.15374671215457575, 0.16665843288813317, 0.12691796677453177, 0.12234854911054883, 0.16296690383127757, 0.1896509855453457, 0.11778261911656175, 0.13498853013983794, 0.17221517328705105, 0.23979780397244863, 0.14201974070497922, 0.2785783330244677, 0.22634123318961688, 60.626833370753694, 115.29375212533134, 97.5720658983503, 95.86870111737932, 73.77658408028739, 59.427157402038574, 68.65520586286272, 74.82052312578473, 59.86032894679478, 45.225025585719514, 69.13923127310616, 88.65230206080845, 37.80423831939697, 11.808598126683917, 0.39328239804932047, 0.1545360248003687, 0.1576351656445435, 0.1638457966702325, 0.42820645975215094, 0.7995099957500185, 2.4034878526415144, 2.853435605764389, 5.019176295825413, 12.515735404832022, 5.8892883488110135, 3.894651174545288, 12.461357934134346, 84.03955977303642, 78.759199823652, 78.83599131447929, 73.97003582545689, 67.56829915727887, 58.847809655325754, 63.5759128843035, 68.00390951974052, 69.97658647809709, 71.50555147443498, 69.22423553466797, 61.89738096509661, 71.59205654689244, 66.78969097137451, 65.34088039398193, 59.225847244262695, 58.47348240443638, 63.63105378832136, 64.35501439230782, 64.64340632302421, 60.78851795196533, 61.9899240221296, 57.60214008603777, 56.55819756644112, 58.148949418749126, 62.19130366189139, 63.60556779588972, 68.85655770983014, 59.285073689052034, 55.0536207471575, 52.91484362738473, 62.186856814793174, 64.89422934395927, 75.0407462801252, 65.02980259486607, 75.88974666595459, 26.139293330056326, 43.55156585148403, 77.30306584494454, 61.22017478942871, 74.00126797812325, 66.97152532849992, 74.8234761101859, 67.286285672869, 68.027512550354, 54.01631028311593, 50.76344510487148, 53.96016883850098, 65.09399700164795, 66.48278209141323, 75.88419505528041, 64.55938175746373, 65.0177891595023, 62.95597376142229, 70.64861624581474, 69.02531555720738, 70.79996190752301, 69.69895730699811, 72.91674450465611, 68.48990821838379, 57.0352018220084, 65.43660572596959, 73.23763316018241, 71.25991875784737, 72.21305179595947, 68.71031202588762, 75.06937285831997, 71.89891678946358, 77.95475128718785, 59.435467447553364, 23.686629601887294, 2.16066437959671, 4.9882789594786505, 8.6172479561397, 6.022127049309867, 1.5361889515604292, 0.7953733748623303, 0.20317432417401246, 0.37558533623814583, 0.23709199630788394, 0.21344937996140548, 0.16316175194723265, 0.22437724071953977, 0.9899515424455915, 27.148606027875626, 44.46575076239449, 60.17319243294852, 47.29545675005232, 42.772221156529014, 30.58566447666713, 48.975343567984446, 67.35152230943952, 74.40614645821708, 81.51983029501778, 85.67909840175084, 19.83230229786464, 0.22446737731141703, 0.1132162209334118, 0.0748036207099046, 0.16887912872646535, 0.2159632436398949, 0.13604347567473138, 0.13544286361762456, 0.13081719540059566, 0.1668516525200435, 0.1622202167553561, 0.14243978102292332, 0.13011708296835423, 0.11413007868187768, 0.2227236373083932, 0.14294591386403355, 0.12646585889160633, 0.1428151058831385, 0.1592850506837879, 0.32875377205865725, 0.23545021297676222, 0.1873806073729481, 0.2533919816570622, 0.09366206984434809, 0.13093350987349237, 0.05237893740247403, 0.05644155726102846, 0.115610804940973, 0.16300806376550878, 0.19472967088222504], [0.07054880580731801, 0.055956964514085224, 0.019601105712354183, 0.03850948823882001, 0.03896356048062444, 0.04213728589404907, 0.05123809611956988, 0.04433313038732324, 0.03218866651877761, 0.054743967817298005, 0.054237868902938705, 0.039786616672894785, 0.02642666588404349, 0.009818999678827822, 0.040624587064875026, 0.04941289798755731, 0.00600295774971268, 0.035382700485310385, 0.023498877184465528, 0.034499777148344686, 0.018167369699637805, 0.03881540235930255, 0.025293668465954915, 6.435374200344086, 83.18024826049805, 80.06898389543805, 82.3140788759504, 64.7185719353812, 62.00386905670166, 27.400651931762695, 25.778916324887955, 41.87332575661795, 28.256124564579554, 44.77471283503941, 50.541384152003694, 20.68329507963998, 3.485217498881476, 0.06519055725740534, 0.059524280950427055, 0.01066507093076195, 0.024588444968685508, 0.28145279735326767, 0.126210892572999, 0.8953810770596776, 1.3939147059406554, 1.0569300055503845, 3.922077017171042, 5.352844425610133, 0.43812607175537516, 19.85052568571908, 75.84993348802838, 70.5879932131086, 70.84306853158134, 66.59403664725167, 61.85047367640904, 53.96526881626674, 52.02218770980835, 56.48964316504342, 60.38013757978167, 66.6613438470023, 66.76286397661481, 66.02213042122978, 64.67683410644531, 64.59309441702706, 61.87080410548619, 53.69269445964268, 47.23146384102957, 46.14285830089024, 47.50136661529541, 48.97938394546509, 50.352139541081016, 47.32124498912266, 50.37049320765904, 46.81675713402884, 48.19242402485439, 46.81807729176113, 50.291245528629844, 50.23042447226388, 49.35261685507638, 45.306868416922434, 46.86477266039167, 53.714289460863384, 64.07003402709961, 62.55723748888288, 67.2799906049456, 60.69616944449288, 62.948594774518696, 24.09776840891157, 35.63674429484776, 66.20336723327637, 57.919228076934814, 65.39910629817417, 57.97193363734654, 64.64788096291679, 62.15141405378069, 56.58978755133492, 49.2788165637425, 46.30546004431588, 49.63522093636649, 58.59718813214983, 64.3195229939052, 55.99884326117379, 57.7250919342041, 62.891174861363, 62.56877844674246, 64.84063788822719, 60.43053981236049, 58.413255419049946, 56.71549088614327, 60.40385178157261, 65.27893025534493, 60.44967515127999, 62.2135865347726, 66.5275354385376, 64.81945283072335, 62.878480502537315, 60.45413589477539, 65.48479843139648, 64.71971838814872, 70.48325606754848, 66.92570195879254, 58.820968764168875, 15.7490040574755, 0.2134574545281274, 1.2737120645386832, 2.174100024359567, 1.3277334400585719, 0.3124256139355046, 0.12042828143707343, 0.038350582122802734, 0.05169993419466274, 0.12389811953263623, 0.05920490130249943, 0.14046403632632323, 0.02461697906255722, 0.3651556016079017, 21.013709715434484, 34.77528926304409, 28.189215149198258, 51.34498848233904, 37.782938616616384, 17.75500110217503, 39.28914131437029, 48.64728437151228, 59.740375246320454, 64.49096284593854, 45.00977386747088, 3.318979024887085, 0.054971768986433744, 0.026272784319839308, 0.050749611974294694, 0.022534929980923022, 0.03983155943985496, 0.05587816624236958, 0.06916293874382973, 0.08870622648724488, 0.02358069154433906, 0.02997911222545164, 0.008504275315707284, 0.04657592271853771, 0.08994013563330684, 0.03493145773453372, 0.08222929760813713, 0.0030710762117191082, 0.06192212871142796, 0.07241614774933883, 0.01752922447797443, 0.08376991136797837, 0.0390225149957197, 0.050010646626885445, 0.025360653442995887, 0.019812367590410367, 0.019894814684188793, 0.008941050003548818, 0.039775481913238764, 0.08287347161344119, 0.057900967342512946, 0.04196156228759459, 0.05415348968069468, 0.01708374757851873, 0.030052855411278348, 0.04548220908535378, 0.01778070143024836, 0.04221545991354755, 0.01670732518791088, 0.020753380310322558, 0.04428172457431044, 0.02786693279631436, 0.023012350612719144, 0.003579765009427709, 0.023247496923431754, 0.012406294417035366, 0.010368082938449723, 0.03261059316407357, 0.0021196174451948275, 0.038927747402340174, 0.024911266485495225, 0.05747387704572507, 0.05388614349067211, 8.716049603053502, 99.13733523232597, 89.20560101100376, 91.72105039869035, 71.59540557861328, 74.33808190482003, 40.13995170593262, 32.61990247453962, 41.52069078172956, 32.319010734558105, 47.05555282320295, 47.541812079293386, 26.488283974783762, 3.2223899449620927, 0.015390388800629547, 0.05553286994940468, 0.0817783839468445, 0.11631374007889203, 0.7007662685854095, 0.9564712132726396, 2.3243107412542616, 1.7359330505132675, 1.12860849073955, 0.6354888113481658, 0.7056892301355089, 0.8937561213970184, 21.067337649209158, 82.2765724999564, 73.01618017469133, 74.31732068743024, 69.34822613852364, 63.837804385593955, 56.5238595690046, 54.5266033581325, 59.14705467224121, 64.04348496028355, 68.81830092838833, 68.80097212110246, 66.47085203443254, 65.58007213047573, 66.10969856807164, 66.36215441567558, 57.05136680603027, 49.12862777709961, 48.62509182521275, 50.37977947507586, 51.66712433951241, 54.405742917742046, 50.28307792118618, 52.64431551524571, 48.90262719563076, 48.87753030232021, 51.5235641343253, 53.14273064477103, 52.459132126399446, 51.885641711098806, 46.19721753256661, 49.82719966343471, 56.236252784729004, 66.3471463067191, 66.29215826307023, 68.81680706569126, 61.12438692365374, 67.42438806806291, 27.558848517281668, 36.67874826703753, 71.55630806514195, 58.77059432438442, 68.16189071110317, 59.958708490644185, 66.78558458600725, 63.224285398210796, 60.994358335222515, 52.557362283979145, 49.21258633477347, 50.14471844264439, 62.46357577187674, 65.61429895673479, 61.43027441842215, 58.63154002598354, 62.54279913221087, 65.66968304770333, 66.12413692474365, 62.8148558480399, 60.307417733328684, 59.05262170519148, 62.64276286533901, 68.52742154257638, 60.54759611402239, 62.8423707144601, 69.75974014827183, 66.59589876447404, 64.23886135646275, 61.8911623273577, 68.61263425009591, 68.48186220441545, 73.50575719560895, 69.75474439348493, 60.51892784663609, 19.285598925181798, 0.4316703538809504, 0.16845416224428586, 1.317385835306985, 2.1144453968320573, 2.2210355401039124, 1.1587826716048377, 0.44923507422208786, 0.15340452694467135, 0.14123046877128737, 0.24768680493746484, 0.06173962993281228, 0.03747638813885195, 0.24951836094260216, 22.895948920931133, 33.672561509268625, 24.600185700825282, 43.14828545706612, 29.419457980564662, 28.586381128856114, 50.718490259987966, 55.38928474698748, 64.80281884329659, 71.42897537776402, 57.71794918605259, 5.601161318165915, 0.03569200388821108, 0.03449151598449264, 0.04768329526164702, 0.030043936068458215, 0.008299375551619699, 0.05490600537242634, 0.03478550485202244, 0.058074835155691416, 0.016188206882881265, 0.09661416536463158, 0.03520021527739508, 0.04415062821603247, 0.12662724166044168, 0.042163060046732426, 0.08356722617255789, 0.01222146487063063, 0.025149992068431208, 0.06891460849770478, 0.052391676897449155, 0.055605883710086346, 0.06776959422443594, 0.027796548358829956, 0.03997412303994809, 0.03144233228106584, 0.025982676672616174, 0.02344552567228675, 0.01616280592445816, 0.057743879700345654, 0.15641410116638454, 0.212487325870565, 0.1965186284588916, 0.14050268568098545, 0.1464028326528413, 0.09814117449734892, 0.09495521509753806, 0.0910532587606992, 0.10286488423922233, 0.19411487744322845, 0.19831199651317938, 0.11119588291538612, 0.09491639610912118, 0.11140518382723842, 0.0848872142710856, 0.09158063653324332, 0.10273611864873342, 0.13744802959263325, 0.16377197206020355, 0.09665635667209115, 0.1389436564807381, 0.11209853126534394, 0.13561962198998245, 12.039613570485797, 110.38999148777553, 98.52198886871338, 103.8314756665911, 84.39894144875663, 79.81777872358049, 41.427341733660015, 33.93670422690255, 54.15008395058768, 40.52508340563093, 62.76240389687674, 70.77356570107597, 32.058032921382356, 6.069479891232081, 0.14721474051475525, 0.15893795288034848, 0.17776367627084255, 0.1334256332899843, 1.1074304899999072, 0.829321838915348, 3.5526819016252245, 2.7240323552063535, 4.979454747268131, 12.193601284708295, 16.71622804233006, 3.581189057656697, 22.862237998417445, 86.70883532932827, 74.39497375488281, 78.47387204851422, 71.10934434618268, 66.10930946895054, 58.14886951446533, 57.48485449382237, 61.87669617789132, 68.12290436880929, 72.78545829227993, 70.0109453201294, 69.61166013990129, 66.78157547542027, 68.25477422986711, 69.18903596060616, 58.4154441016061, 51.69490671157837, 50.78669377735683, 53.608645575387136, 54.4784836087908, 57.38278545652117, 51.541174343654085, 57.011706488473074, 52.40025656563895, 53.0573650768825, 53.34214047023228, 56.905246189662385, 55.66608360835484, 55.01611089706421, 49.14491088049752, 52.01677506310599, 58.83679676055908, 69.0423664365496, 68.52931145259312, 71.26681137084961, 64.60007040841239, 69.73361492156982, 31.834874153137207, 39.76104211807251, 72.93106474195207, 62.30178696768624, 71.54968643188477, 63.3437944139753, 68.5327091217041, 67.25089154924665, 62.97590119498116, 53.4830846786499, 51.461641788482666, 53.834496770586284, 66.23642676217216, 68.43704632350376, 64.32248987470354, 62.30473300388881, 65.57852963038853, 68.93701090131486, 70.56219455174038, 67.18172918047223, 63.671978678022114, 62.96798024858747, 67.0023614338466, 70.83058956691197, 60.63868004935128, 65.40403257097516, 71.56623009272984, 70.74291719709123, 68.7928079877581, 66.39154529571533, 70.4318949835641, 71.32673263549805, 76.85089097704206, 72.83386639186314, 67.45790617806571, 19.66905437197004, 1.9255681719098772, 7.082875958510807, 8.015340277126857, 4.437190839222499, 3.0424997806549072, 0.5569586423890931, 0.4259913143302713, 0.26743078976869583, 0.2598808120403971, 0.3162343395607812, 0.36506435221859385, 0.07661281220082726, 0.7128124364784786, 33.75055503845215, 53.5394241469247, 43.254936831338064, 68.14282485416958, 53.01689876828875, 28.622826167515345, 55.66170971734183, 63.99103300912039, 77.27577332087925, 79.73508821214948, 67.46392331804547, 5.908807141440255, 0.19785797516150133, 0.10580893911953483, 0.12718012556433678, 0.09684066713920661, 0.09394577890634537, 0.15816824989659445, 0.18835917700614246, 0.19513896320547375, 0.09012382863355534, 0.21774618939629622, 0.0718224092519709, 0.1542605667241982, 0.27396109221237047, 0.19407435533191475, 0.18630427441426686, 0.08510338195732661, 0.11436363043529646, 0.1649889246161495, 0.15928426358316625, 0.1548652228500162, 0.14553163440099784, 0.1443153875214713, 0.12436634940760476, 0.15790815385324614, 0.10000511697892632, 0.11495629006198474, 0.1314494271895715, 0.1513863873801061], [0.06535766007644789, 0.020637939451262355, 0.01475613158462303, 0.037000660451927354, 0.011693998040365321, 0.03962678774925215, 0.034023275931498835, 0.0067424506580989274, 0.05546248551192028, 0.0071129519825002974, 0.0233456962076681, 0.04384169800739203, 0.04239081032574177, 0.02041942403385682, 0.01701032500048833, 0.043604288782392225, 0.04520112256120358, 0.020264958929536597, 0.0455223647877574, 0.029418666048773696, 0.02285795166556324, 0.04647650716028043, 0.02808806057354169, 41.94713994434902, 90.15820598602295, 73.72518825531006, 66.30075318472726, 55.29168687547956, 23.430723973682948, 19.28455148424421, 29.29283400944301, 41.77660683223179, 59.870278767177034, 50.50265836715698, 23.902027232306345, 1.8369393391268594, 0.005191104170600218, 0.02051136383254613, 0.06813579278865031, 0.03876015943075929, 0.20521908945270947, 0.42289733035223825, 0.2737813889980316, 1.6575587817600794, 1.3166738620826175, 1.2309532846723283, 1.3574350348540714, 2.7290396179471696, 33.08828054155622, 77.39059230259487, 69.05752045767647, 69.35536888667515, 67.45746844155448, 59.243176051548545, 54.86187825884138, 51.248804569244385, 53.74117204121181, 53.36262375967843, 57.7453042439052, 60.93999562944685, 64.56418991088867, 65.55012539454869, 62.929521969386506, 63.69869450160435, 62.75164113725935, 55.40367446626936, 47.42821250643049, 44.33215079988752, 45.6218615259443, 44.06160184315273, 46.1110702923366, 43.22490324292864, 44.970294203077046, 45.88290882110596, 46.65104259763445, 44.41057859148298, 45.83968407767159, 42.05027205603463, 45.25661904471261, 45.03392580577305, 47.51333141326904, 55.12462786265782, 66.78433391026088, 61.51038714817592, 68.68767479487828, 59.170477049691335, 72.45675986153739, 29.546933106013707, 36.71669585364205, 67.2284071786063, 55.509856837136404, 61.2806727545602, 57.585481779915945, 62.82447215488979, 61.26194735935756, 57.2983717918396, 48.59495401382446, 45.2717661176409, 50.26080199650356, 57.182072843824116, 64.38394669124058, 54.87485401970999, 55.17311586652483, 65.21015003749302, 60.95184925624302, 56.172642026628765, 55.30014978136335, 52.5409436907087, 53.28662436349051, 57.11865316118513, 61.57380335671561, 62.16675567626953, 61.22451741354806, 66.375974382673, 64.31980787004743, 57.045321873256135, 54.71635866165161, 66.37591879708427, 65.48499992915562, 65.58753449576241, 63.47223881312779, 62.37216527121407, 57.04885503223964, 20.93633805002485, 0.8425303644367627, 1.2756245562008448, 2.037058097975595, 1.386006895984922, 0.513891047665051, 0.21342564480645315, 0.06935641621904713, 0.08806397952139378, 0.1053764001865472, 0.07625747698226146, 0.11352112742939166, 0.08837176979120288, 1.903625760759626, 36.83021204812186, 51.26492786407471, 49.76250498635428, 42.81460516793387, 19.747332777295792, 29.57269355228969, 47.614750794001985, 48.443653515407014, 58.80737113952637, 59.866095951625276, 29.535166331699916, 0.40553503057786394, 0.007744456042668649, 0.008333551664171475, 0.03311104327440262, 0.09819475840777159, 0.05841509332614286, 0.07172033722911562, 0.027658054272511175, 0.028415952443278263, 0.03246105761666383, 0.03783587259905679, 0.07826781339411225, 0.02287331030571035, 0.06631304416805506, 0.045642095684473, 0.003908318450807461, 0.04019431783152478, 0.05171504856220313, 0.07853276774819408, 0.03632521955296397, 0.03206218080595136, 0.044142940414271185, 0.05158465788034456, 0.04079227003135851, 0.13525284667100224, 0.01584032197882022, 0.06582768806921584, 0.09337447277669396, 0.07099074923566409, 0.008097861677275171, 0.04515923659450241, 0.05166408718962755, 0.02506958566872137, 0.07242289238742419, 0.005249903046725584, 0.02123310456850699, 0.04453754923971636, 0.020212738874501417, 0.01478885902490999, 0.015595026480566179, 0.02769196914908077, 0.027904625416600277, 0.049067635621343336, 0.03510183448504124, 0.012429892168646412, 0.03765682756368603, 0.0949924463140113, 0.019296431614618217, 0.04774791893682309, 0.14515770732292108, 0.041843174890215905, 51.78971140725272, 104.63983603886196, 82.76944296700614, 78.18839836120605, 68.19250447409493, 32.79426751817976, 26.24523251397269, 35.57191065379551, 43.09190082550049, 47.767381872449604, 46.84173590796334, 28.080517530441284, 2.5752512301717485, 0.05904613767883607, 0.009793592783223306, 0.049429145508578846, 0.28870926797389984, 0.5343246683478355, 1.0070530133587974, 1.578392961195537, 1.6306403747626712, 0.8284692189523152, 2.0439852348395755, 0.9400707504578999, 4.331622081143515, 36.01135989597866, 80.45542185647147, 71.45457254137311, 71.50717735290527, 70.11390372685024, 61.819762638636995, 57.08214732578823, 53.90437480381557, 56.95038168770926, 55.640507289341514, 60.50115435464041, 63.8878105708531, 66.74456936972481, 66.35395554133824, 63.60779816763741, 65.28776141575405, 67.23488984789167, 58.86962699890137, 49.193666390010286, 46.93855210712978, 46.98467424937657, 46.63905348096575, 48.03963661193848, 46.35544538497925, 48.31229434694563, 48.4888584954398, 50.68616724014282, 46.32505049024309, 49.408226762499126, 44.56519685472761, 47.75648362295968, 46.48172194617135, 49.66968747547695, 57.95294073649815, 70.49456078665597, 63.05010100773403, 68.79825537545341, 60.112444332667756, 72.4490612574986, 32.196951729910715, 39.59306594303676, 69.25616945539201, 57.90762111118862, 63.93794877188546, 61.53132207053048, 65.43035234723772, 62.64403438568115, 60.46724714551653, 51.36078521183559, 48.0028841154916, 53.21375165666853, 60.955865315028596, 67.28680678776333, 58.60876383100237, 59.72756971631731, 65.83876051221574, 62.44292572566441, 57.854588985443115, 59.21370874132429, 54.597777230399, 56.10911117281233, 60.564945765904014, 64.35563278198242, 61.85236358642578, 60.39811951773507, 68.59438828059605, 66.21379647936139, 58.538656507219585, 57.0561089515686, 67.14590426853725, 68.29164137159074, 68.47558798108781, 67.22605868748256, 66.41692706516811, 61.62542847224644, 24.624047551836284, 1.175079128571919, 0.3056508217539106, 0.9304621517658234, 1.631210561309542, 1.6856520857129778, 0.9652071616479329, 0.6349111880574907, 0.5392823166080883, 0.08115166186222009, 0.151779530569911, 0.03826859134382435, 0.07317051584167139, 1.7582691205399377, 39.05121067592076, 47.83654771532331, 52.4426440511431, 38.3647460256304, 25.112293992723735, 37.181106499263215, 54.67965132849557, 55.81739452907017, 64.01518494742257, 71.57042680467877, 41.02994646344866, 0.5657075643539429, 0.06684635912201234, 0.03597292756395681, 0.08217641258878366, 0.038883316929319074, 0.038232608631785424, 0.05586983722501567, 0.05131959496065974, 0.034786186779716184, 0.01588879312787737, 0.025010417415095226, 0.058834570460021496, 0.005126498731052769, 0.046767703856208494, 0.11094964255711862, 0.025746465061924288, 0.03747858998498746, 0.05542551213875413, 0.04092934428315077, 0.03982403787917324, 0.08996607602706977, 0.025453351504568542, 0.01325477022744183, 0.04633462209520595, 0.033391295200479884, 0.06811151480568306, 0.098583117925695, 0.021933461273355142, 0.10751605180225202, 0.16041935767446244, 0.15785634091922215, 0.13554714087929043, 0.08555491308548621, 0.17211346088775567, 0.11436171696654387, 0.12689910350101336, 0.16394913755357265, 0.11258635723165103, 0.1025572025350162, 0.11268101965210267, 0.14082002293850693, 0.22280189953744411, 0.12477298187358038, 0.12416686011212212, 0.13113804746951374, 0.14007756992110185, 0.18603725731372833, 0.15357874759605952, 0.13130833261779376, 0.19428597683353083, 0.07194356167955057, 59.29185513087681, 113.87310259682792, 95.37417003086635, 87.69862706320626, 73.46624279022217, 37.694151060921804, 30.081273896353586, 42.41370105743408, 55.60682242257254, 79.32814611707414, 70.67517226082938, 37.0536105292184, 4.142548135348728, 0.12156501758311476, 0.10154872986354999, 0.16396441816219262, 0.352874470608575, 1.387671206678663, 1.9457783102989197, 2.55868781038693, 4.496210140841348, 8.096783586910792, 7.323858158929007, 5.0786793657711575, 4.869035712310246, 38.692773955208914, 84.35764830453056, 73.57449572426933, 74.15473978860038, 73.50781386239188, 64.06168229239327, 59.616926601954866, 56.90815053667341, 59.96048028128487, 58.63389546530587, 62.779746600559776, 65.22990376608712, 68.78454657963344, 68.6791215624128, 63.99865518297468, 67.75744301932198, 70.20118004935128, 62.00590487888881, 51.36728177751814, 49.61662408283779, 50.891396181924, 49.2824296270098, 50.756656714848106, 48.53706857136318, 50.20936795643398, 52.35630920955113, 52.51402984346662, 48.486197335379465, 51.443058831351145, 46.94817188807896, 49.2760511807033, 49.60878651482718, 52.52635942186628, 61.582078661237446, 72.06875160762242, 67.99359839303153, 72.64329814910889, 65.08064951215471, 73.42910466875348, 34.478566442217144, 43.11670242037092, 69.78831808907645, 60.6946199962071, 65.1578231539045, 65.3034782409668, 66.570419720241, 67.44740050179618, 63.582694326128276, 54.67620154789516, 50.35427263804844, 56.76263093948364, 65.1177806854248, 69.1362088067191, 59.038204193115234, 60.236045837402344, 69.03511946541923, 66.0852131162371, 60.06041622161865, 61.73118005480085, 57.965843541281565, 58.14528424399239, 62.503771100725444, 68.17635686056954, 63.167852129255024, 62.8711154120309, 72.28357601165771, 69.40455518450055, 60.81474045344761, 59.778680665152415, 72.2067289352417, 70.22932025364467, 72.31516252245221, 69.27311611175537, 67.89994362422398, 65.37685121808732, 27.342597995485576, 1.9250644275120325, 7.138030758925846, 6.942528860909598, 5.716291666030884, 2.327170793499265, 0.7594080876026834, 0.7500914760998317, 0.5052553596241134, 0.5047001551304544, 0.3228764645755291, 0.3034422445510115, 0.2566935159265995, 3.624671535832541, 55.70667151042393, 68.85361167362758, 64.52129173278809, 57.95155109677996, 29.110857214246476, 41.97834777832031, 63.93172318594796, 66.1130337033953, 73.78488717760358, 80.67125374930245, 42.878837789808, 0.8142472335270473, 0.15792361088097095, 0.09329057870698826, 0.1676671973296574, 0.17515868533934864, 0.15948597847351006, 0.168592542675989, 0.17072405187147005, 0.06807996292731591, 0.08380033009286438, 0.09152251322354589, 0.1687325651624373, 0.09316075460187026, 0.1114192973556263, 0.20884748761143002, 0.23085943503039225, 0.10143655445426702, 0.12399224591042314, 0.20480903717023985, 0.12845807841845922, 0.1492597364953586, 0.11520447103040558, 0.2033647618123463, 0.15497302849377903, 0.25162244375262943, 0.12431307083794049, 0.2737993566053254, 0.19979391699390753], [0.020470081762011563, 0.02297376062987106, 0.039100458313311846, 0.06776135002395936, 0.06741355332945075, 0.031070735970778123, 0.044939493028713126, 0.031299134250730276, 0.020400579420051405, 0.020954623618828397, 0.02688414606797908, 0.01886236767417618, 0.032160897473139424, 0.014544113140021051, 0.0417867479180651, 0.029223169931875806, 0.05849568293030773, 0.041783219535968134, 0.06641776247748307, 0.06029901187866926, 0.0506309803043093, 0.09695194009691477, 3.6264481033597673, 67.50981616973877, 76.01760741642543, 75.24559307098389, 53.83069610595703, 34.186915806361604, 61.19042955126081, 31.395779269082205, 35.84708363669259, 41.03664452689034, 46.01131847926548, 36.08250250135149, 2.79289356299809, 0.03624782584873693, 0.059196338190564086, 0.03609568811953068, 0.18139018810221127, 0.08096013856785637, 0.9956398372139249, 0.6995751410722733, 1.7677758846964156, 1.9632528126239777, 1.4584328553506305, 3.2566195939268385, 20.220767395836965, 57.900388036455425, 78.02840219225202, 69.25386960165841, 69.19307286398751, 63.27128301348005, 57.38511310304914, 53.276851722172324, 54.818577085222515, 54.82046004704067, 50.06179516656058, 52.28827592304775, 55.90987157821655, 62.502923420497346, 63.631658281598774, 63.53930977412632, 61.931378500802175, 61.69439629146031, 60.928253173828125, 56.45464856284005, 47.763702801295686, 45.378351484026226, 45.18848500932966, 44.93046365465437, 44.31072950363159, 43.38298518317086, 43.95887967518398, 43.836327348436626, 43.27908876964024, 42.26575306483677, 44.032176222120015, 44.89186641148159, 45.502717290605815, 43.07754584721157, 45.338778018951416, 48.71085344042097, 57.503510407039094, 58.118756021772114, 60.98558276040213, 55.57660470690046, 68.11510848999023, 40.05663238252912, 36.81172636577061, 64.74766404288155, 56.876261779240195, 61.8873964037214, 56.397510051727295, 62.96355424608503, 55.74333715438843, 53.91613462993077, 46.421025957380024, 47.084822109767366, 47.001610483442036, 54.00001328332083, 61.23133359636579, 62.64264474596296, 61.90027141571045, 63.25979764120919, 57.51309197289603, 55.007119928087505, 46.44953441619873, 45.13832596370152, 47.278819288526265, 55.34875243050711, 61.025333404541016, 60.00974995749337, 60.225283077784944, 67.63786452157157, 61.00016008104597, 57.86225284848894, 49.87783466066633, 58.98746149880545, 64.97699628557477, 69.32168401990617, 65.02937875475202, 63.12512765611921, 54.97203152520316, 58.43709468841553, 26.94931779588972, 1.0665031032902854, 1.5571959614753723, 1.8253163056714194, 3.8198811752455573, 0.8927223054426057, 0.3426584745092051, 0.11023036829595055, 0.21931697082306656, 0.223219239286014, 0.18729725613125733, 0.05457686839093055, 0.017194498064262525, 4.5380270055362155, 29.09298644747053, 27.62065100669861, 34.51735823495047, 28.353067568370275, 22.604366030011857, 26.788100481033325, 35.407293932778494, 56.51885339191982, 63.406911849975586, 66.60610566820417, 12.04960594858442, 0.27504859385745867, 0.04179088358900376, 0.06602080592087337, 0.01384424073954246, 0.06623432053519146, 0.030071589763143232, 0.04171872138977051, 0.08241170817720038, 0.03623869616006102, 0.05793811034943376, 0.022762190018381392, 0.0462256595492363, 0.022425801193873798, 0.02305212803184986, 0.04792267902355109, 0.0615888594516686, 0.01865223216425095, 0.01809597254863807, 0.038177911923932176, 0.025445567011567097, 0.01009699293146176, 0.09965131524950266, 0.0057014502900918675, 0.058736393228173256, 0.06245093819286142, 0.033750854299536774, 0.07216689469558851, 0.031725162640213966, 0.021241240203380585, 0.017316702221121107, 0.034973954382751665, 0.04366227299241083, 0.030128674914262125, 0.02703778335957655, 0.050596368233008046, 0.062173403799533844, 0.017617985340101377, 0.09613501107586281, 0.03963958152702876, 0.04666499061776059, 0.014385542898838009, 0.02696115809625813, 0.025061212546591247, 0.0436561627845679, 0.029573860578238964, 0.03167978221816676, 0.03756865193801267, 0.032636876218020916, 0.10813313190426145, 4.7220222524234226, 79.3204266684396, 85.95141914912632, 83.15713855198452, 61.14118766784668, 44.99745123726981, 61.184898785182405, 28.240913220814296, 27.137871061052593, 32.413259574345176, 44.036900997161865, 37.37408924102783, 3.3784844832760945, 0.039973858411290815, 0.06958981869476182, 0.2555872867149966, 0.2814794773502009, 1.239406202520643, 1.87458250778062, 1.5530129287924086, 1.3302302317959922, 1.1320337355136871, 0.26793304138949936, 5.556833113942828, 22.1972484929221, 59.816840171813965, 82.50334085736955, 72.92076056344169, 73.96646445138114, 67.97938932691301, 60.816859654017854, 55.46915428979056, 57.80801173618862, 57.04868827547346, 52.590289797101704, 55.00407314300537, 58.20733513150896, 64.56530162266323, 66.19425119672502, 65.47355624607631, 62.35536452702114, 63.83313519614083, 65.2327664239066, 60.08679158346993, 49.54893473216465, 47.0795692716326, 47.66797399520874, 47.47272614070347, 46.28409433364868, 46.402606282915386, 47.12171357018607, 46.70966107504708, 46.579615116119385, 44.329017162323, 46.876275403159006, 46.5376410484314, 47.93689012527466, 45.39021553312029, 47.147738048008506, 51.024082456316265, 59.008841105869834, 59.287950243268696, 63.79595538548061, 58.29414939880371, 70.70573043823242, 43.15962144306728, 39.786444732121055, 66.54864406585693, 57.631770678928916, 65.10012531280518, 58.925698961530415, 65.10222366877964, 59.44798810141427, 55.82133763177054, 47.44753892081124, 49.80457632882254, 48.503974301474436, 57.295175620487754, 61.7407477242606, 65.10319641658238, 63.38250282832554, 66.50656577519008, 61.14698246547154, 57.862940720149446, 49.753625188555034, 48.815191064562114, 50.004691396440776, 57.7591415813991, 64.54730578831264, 60.46370356423514, 59.49217864445278, 69.94464560917446, 63.008516039167134, 61.17003658839634, 51.727514607565745, 64.2215325491769, 67.19107450757707, 70.85100337437221, 67.71182809557233, 66.93593665531704, 60.80809102739607, 62.39256518227713, 30.96220472880772, 2.685097255877086, 0.9467778248446328, 0.30798422225884026, 1.248951290334974, 1.4000855748142516, 1.2877387404441833, 0.6243658853428704, 0.3161669746041298, 0.2650582513638905, 0.3082557719733034, 0.05571435431816748, 0.05334668779479606, 4.053808782781873, 34.46301984786987, 27.664832864488872, 31.127179282052175, 25.409400701522827, 33.21797909055437, 36.99846267700195, 42.02505704334804, 62.91808523450579, 69.61286217825753, 76.37252140045166, 18.649936028889247, 0.2922480180859566, 0.06681840347924403, 0.03441471939108201, 0.045371801259794405, 0.06654903186219079, 0.0945062284756984, 0.11771515916500773, 0.01402177264182163, 0.025517861525128995, 0.10113714409193822, 0.03855270413415773, 0.11164706120533602, 0.02176878591334181, 0.038434004610670466, 0.06360435272966113, 0.007658232053342674, 0.01718871694590364, 0.029037841662232364, 0.03766188264957496, 0.01987993610756738, 0.020706491844196404, 0.007020557989432875, 0.023987731131325876, 0.033144335595092604, 0.08544659175510917, 0.03972377415214266, 0.05816780123859644, 0.12906559796205588, 0.10079337789544038, 0.16999825010342257, 0.1653053390660456, 0.2145870660564729, 0.11836873766567026, 0.08165042581302778, 0.0999933715377535, 0.13271436574203627, 0.045708351236368926, 0.21227672217147692, 0.14886146358081273, 0.09823806929801192, 0.1495875639042684, 0.09777440596371889, 0.14627889144633496, 0.26166305212037905, 0.13322071571435246, 0.13184042620871747, 0.09283110871911049, 0.2471227523471628, 0.1742145310023001, 6.439445410455976, 87.44107818603516, 95.661130632673, 96.04430988856724, 72.95346573420933, 49.173523562295095, 70.23686599731445, 42.37820618493216, 50.70797416142055, 58.723958015441895, 64.808502469744, 56.06055021286011, 4.609827084200723, 0.20044467278889247, 0.22562426594751223, 0.43895160460046356, 0.7011307775974274, 1.505029212151255, 3.5222099253109524, 4.155807903834751, 5.974513649940491, 7.662806051118033, 5.3483350447246005, 6.63397673198155, 21.96399572917393, 62.23774542127337, 83.00805105481828, 74.75820473262242, 77.11845220838273, 69.45516586303711, 63.04745374407087, 58.1834055355617, 60.10466235024588, 60.42502989087786, 56.37855536597115, 58.84862954275948, 61.00993619646345, 67.62606648036412, 67.38295595986503, 66.32365444728306, 62.0432653427124, 64.53306892939976, 66.72881085532052, 63.18759890965053, 53.792446272713796, 50.899435247693745, 50.46019097736904, 51.14761447906494, 49.60118865966797, 49.03533084051949, 50.30633354187012, 49.65015261513846, 48.464741298130576, 46.411437443324495, 49.04662166322981, 49.47974804469517, 51.084469250270296, 49.39212083816528, 49.032033920288086, 53.893024921417236, 63.100030762808665, 63.061183384486604, 66.00532272883824, 63.32372106824602, 73.57824080330985, 46.61455065863473, 44.32628999437605, 68.02496256147111, 60.4842563356672, 67.2657606942313, 61.13027899605887, 67.42784827096122, 63.119152205330984, 58.88316208975655, 49.535945074898855, 52.032919202532085, 52.05245753696987, 58.35741969517299, 66.09647614615304, 68.11540031433105, 65.99818692888532, 68.92132881709507, 65.14786638532365, 60.041072436741416, 50.76215968813215, 51.03521694455828, 52.4004476411002, 60.081642968314036, 67.93398979731968, 62.20627008165632, 61.44934722355434, 72.04519721439907, 67.61590821402413, 63.81222806658064, 54.55600813456944, 66.40152290889195, 70.37062576838902, 75.94497094835553, 73.45632771083287, 71.71171842302594, 63.096376010349815, 64.72456128256661, 33.469489983149934, 2.882999539375305, 3.86344290631158, 6.1218306592532565, 9.627122589520045, 3.5056764696325575, 1.1644417622259684, 0.3820804091436522, 1.1794839607817786, 0.46232955157756805, 0.2907175416392939, 0.17583542902554783, 0.13003358244895935, 7.212607077189854, 44.47700684411185, 38.54158810206822, 47.02980974742344, 42.53756659371512, 32.98460647038051, 41.55354533876692, 50.837221077510286, 72.46293681008476, 78.13557815551758, 86.80745111192975, 19.5513744694846, 0.434461629816464, 0.11336904737566199, 0.1521654405764171, 0.13688675899590763, 0.14824059046804905, 0.11806832307151385, 0.1839005776814052, 0.09910953896386282, 0.12159803509712219, 0.292251709316458, 0.09939201987747635, 0.17516005598008633, 0.10316264576145581, 0.140327908630882, 0.10237486660480499, 0.13354031927883625, 0.09264240813042436, 0.1483308763376304, 0.0860891304910183, 0.12100017789219107, 0.10693057786141123, 0.15085045328097685, 0.09709484635719232, 0.1469440728958164, 0.15485036293310778, 0.15300113787608488, 0.1568747450198446], [0.034652264323085546, 0.0439316276460886, 0.07980760612658092, 0.03477705709104027, 0.0687363777043564, 0.04647969966754317, 0.06680885649153165, 0.028471434555415596, 0.014610260126313992, 0.1066345941009266, 0.05520456756598183, 0.010553531648058976, 0.07148909249476024, 0.024551405438355038, 0.02811405185743102, 0.030809791758656502, 0.07665551919490099, 0.03660284894119416, 0.13174757547676563, 0.040685868955084255, 0.2682122178375721, 0.2578364131706101, 22.55459782055446, 88.93915843963623, 80.72756889888218, 72.91281877245221, 63.48313358851841, 39.30972882679531, 37.94076694761004, 35.09667124067034, 47.92830215181623, 59.51300934382847, 36.86270529883248, 10.816219057355609, 0.05225974933377334, 0.15059440130633966, 0.08098098994897944, 0.0887466739597065, 0.4023819054876055, 1.0322038637740272, 0.3441861553915909, 0.3251068906060287, 0.9218519223587853, 1.295769446662494, 12.80804351397923, 42.20719017301287, 65.56502928052629, 69.44758537837437, 66.44125270843506, 69.20370360783168, 62.515708105904714, 59.54265035901751, 50.37938690185547, 51.96554252079555, 54.01033135822841, 54.00319903237479, 52.6665358543396, 48.9856720651899, 51.391075883592876, 57.09187132971627, 61.87031773158482, 63.175175530569895, 59.30300004141671, 61.090702056884766, 61.411945070539204, 55.94777052743094, 46.37740169252668, 43.19802761077881, 45.13684252330235, 44.18176051548549, 47.854727676936555, 45.534977776663645, 45.00501782553536, 42.57469776698521, 48.11935329437256, 44.93224239349365, 44.98822750364031, 43.15576171875, 44.44786957332066, 44.52253144127982, 44.947987011500764, 43.70157745906285, 44.94490201132638, 43.19005107879639, 48.5267504964556, 51.68879924501692, 67.80098043169293, 46.539329460689, 37.737209047589985, 63.796240261622835, 55.46947043282645, 60.02825995853969, 58.854000500270296, 60.78145163399832, 53.776340348379954, 50.281479835510254, 44.06155667986189, 44.6362977709089, 42.95792218617031, 51.01863159452166, 58.69369861057827, 62.82905796595982, 60.33542592184884, 59.38538483210972, 54.470177037375315, 48.04624087469918, 46.19249275752476, 45.48602076939174, 46.53166907174246, 55.80142409460885, 62.68131841932024, 60.27399689810616, 55.81628629139492, 63.37072563171387, 60.29266670772007, 59.31376280103411, 49.703830923352925, 51.29317923954555, 62.22722584860665, 63.66500268663679, 63.83529608590262, 66.99119567871094, 62.6324656350272, 54.16722863061087, 59.30475098746163, 46.93070411682129, 8.801035625594002, 0.3945309839078358, 1.870152814047677, 1.241796599967139, 0.5823826981442315, 0.8121695050171444, 0.04922041456614222, 0.08591456378677062, 0.10142442224813358, 0.034013471100479364, 0.027360615054411546, 0.2104778851249388, 14.257581046649388, 53.36860268456595, 48.5433532169887, 44.235588209969656, 14.788670948573522, 20.266832215445383, 38.45769207818167, 49.086896896362305, 57.24130276271275, 61.0175792149135, 59.044096265520366, 5.7927500775882175, 0.08563773506986243, 0.05231021876846041, 0.08335646641041551, 0.06107849933739219, 0.09588328815464463, 0.04929558267550809, 0.0359337218105793, 0.019875954803345457, 0.09583348368427583, 0.02269083188314523, 0.08441759339932885, 0.07313624982322965, 0.1509107750441347, 0.014860848197713494, 0.05001030057402594, 0.033392173903329034, 0.05518444561000381, 0.059255954277302535, 0.04125371455614056, 0.06616551708430052, 0.0360044556935983, 0.034504472610673735, 0.07827028326158013, 0.02302647431913231, 0.02795163432269224, 0.03884250983329756, 0.05237306468188763, 0.021947897105876888, 0.03236280235328844, 0.035572055860289505, 0.04668276144989899, 0.07235115766525269, 0.0723554120798196, 0.03801427981151002, 0.011826635521304394, 0.05061579808326704, 0.0675540372197117, 0.028458296421117017, 0.07635536244405167, 0.08111715157117162, 0.1336646540356534, 0.09443327917584352, 0.04873371157529099, 0.05529206804931164, 0.12325679537441049, 0.06961654618914638, 0.24730345979332924, 0.33693068900278633, 28.51054154123579, 103.27918420519147, 87.26899215153286, 82.56542995997837, 71.11389541625977, 44.964426449366975, 57.03403105054583, 46.7536119052342, 37.04680824279785, 52.972822870527, 38.259720529828755, 12.77074384689331, 0.08940285803484065, 0.08967649763716118, 0.23219585046172142, 0.7806380369833538, 1.4272986288581575, 2.0190012497561316, 1.3521043551819665, 0.8876746562974793, 1.0268952229193278, 2.317354074546269, 15.06692372049604, 45.7031033379691, 69.95322663443429, 74.13265841347831, 68.0910816192627, 74.87741497584751, 67.30225263323102, 62.06031622205462, 53.38655335562569, 55.67926434108189, 56.47529166085379, 56.890908581869944, 57.43597044263567, 51.513982568468364, 53.953272751399446, 60.49606132507324, 63.99663325718471, 63.62130546569824, 59.37351036071777, 62.648383957999094, 63.83253765106201, 58.239401068006245, 49.18467889513288, 46.784732886723106, 47.43820054190499, 47.02995218549456, 51.50361933026995, 48.450000694819856, 47.18915973390852, 45.29433386666434, 49.835818903786794, 47.026717799050466, 46.24402059827532, 44.925110067640034, 46.03452546255929, 45.76875686645508, 46.12829835074288, 46.065583910260884, 47.360359873090474, 45.09799861907959, 51.391169684273855, 54.22937331880842, 70.27103723798479, 48.94001545224871, 40.99070303780692, 64.90451267787388, 55.95076172692435, 63.42761748177664, 60.73398848942348, 63.70061220441546, 54.63117027282715, 53.00946419579642, 47.70057841709682, 47.56106206348964, 46.046580587114605, 54.840067863464355, 61.553931508745464, 64.65152181897844, 63.62972668239048, 62.388590812683105, 56.17881897517613, 51.46091570172991, 49.12270791190011, 47.85180595942906, 48.60181883403233, 57.02096496309553, 66.23486341748918, 61.54275185721261, 55.946530273982454, 66.01040186200822, 64.07084696633476, 60.45906911577497, 49.88850014550345, 53.8711450440543, 62.99179172515869, 65.7895325251988, 66.71223245348249, 69.14990370614188, 65.48651463644845, 61.73994173322405, 63.205031939915244, 51.765743596213206, 11.951276779174805, 0.485802954861096, 0.6681691205927304, 0.19133500089602812, 2.03910716516631, 1.6076551909957613, 0.8936442988259452, 0.7302184339080537, 0.48865193341459545, 0.260115205177239, 0.03656964822273169, 0.10003101666058813, 14.818978990827288, 57.696736335754395, 47.31980323791504, 37.5516608783177, 20.963687896728516, 25.022634438105992, 46.12161070959908, 56.267047200884136, 65.46855354309082, 68.55870928083147, 72.43953527723039, 9.238048655646187, 0.19084915625197546, 0.08398415201476642, 0.12541376320379122, 0.07928950392774173, 0.014910364290699363, 0.019282647175714374, 0.069416229080941, 0.0453358558671815, 0.0690682695380279, 0.042084919953984876, 0.08058266953698226, 0.017829511846814836, 0.18541421288890497, 0.019823363250387565, 0.031078912317752838, 0.024394838571814553, 0.058250908207680495, 0.06912006211600133, 0.01579818156148706, 0.04746640493561115, 0.01928755976924939, 0.03500374885542052, 0.056487928344202895, 0.03834346089778202, 0.025147690138380443, 0.1063277062826923, 0.1067847539005535, 0.18120118895811693, 0.1859824995377234, 0.15947966809783662, 0.06692868577582495, 0.2542755428169455, 0.25541762581893374, 0.1341173726000956, 0.11532873793372087, 0.20229266291218145, 0.16198563362870896, 0.048437524254300764, 0.18681854967560085, 0.21545631012746266, 0.22187146517847264, 0.15976313288722718, 0.11769136972725391, 0.12671655043959618, 0.20588333452386515, 0.13812884448894433, 0.393567898443767, 0.4675866780536515, 33.99877595901489, 114.56519181387765, 95.29966449737549, 93.93070261819022, 82.79711069379533, 53.952491079057964, 44.059659821646555, 44.781747886112754, 66.20204707554409, 81.00825527736119, 53.62636695589338, 16.881249495915004, 0.25620958475129946, 0.3182382977434567, 0.2969202473759651, 1.9718896406037467, 2.1816748636109486, 3.881885596684047, 2.922691340957369, 2.4136000871658325, 4.3433228475706915, 4.893182439463479, 14.892614262444631, 43.774526596069336, 73.67424406324113, 77.19279098510742, 69.73005744389125, 76.47689029148647, 67.65709018707275, 65.13150337764195, 55.3679780960083, 59.250172887529644, 60.3345365524292, 59.7916043145316, 59.331022126334055, 54.76520102364676, 55.08214657647269, 62.20462335859026, 65.6806195122855, 65.02730124337333, 59.63364396776472, 63.486058780125205, 66.09304373604911, 61.45096615382603, 50.603761604854036, 48.01544993264334, 50.74381296975272, 49.62651831763131, 54.60360329491751, 51.763520172664094, 50.47394841057913, 47.61701243264334, 51.649600982666016, 51.07950823647635, 49.57625157492501, 46.68870530809675, 48.60097115380423, 48.979929379054475, 47.95434052603585, 48.35278844833374, 48.879694666181294, 48.11082090650286, 53.209485462733674, 57.53426660810198, 73.82102475847516, 52.11174998964582, 45.52090767451695, 67.55309649876186, 59.01716504778181, 65.77035549708775, 63.3647015435355, 66.9614018031529, 58.20532362801688, 54.78248119354248, 50.892626013074604, 48.348949568612234, 48.22299262455532, 57.26517677307129, 64.93418148585728, 67.38256686074394, 66.13159929003034, 65.12709127153668, 59.448196547372, 53.491189752306255, 51.11433955601284, 49.3349232673645, 51.788936683109824, 60.67943818228585, 68.3490960257394, 62.33272729601179, 56.181990827832905, 70.18654714311872, 66.32564163208008, 63.75930363791329, 53.33304180417742, 56.282680647713796, 66.48900072915214, 67.73672349112374, 67.96830000196184, 73.2701437813895, 70.70288862500871, 64.11298779078892, 64.48310443333217, 52.97250325339181, 11.23453882762364, 1.9117568901606967, 6.461943243231092, 6.751730024814606, 4.094349784510476, 2.3144846856594086, 1.1716336905956268, 0.7601512734379087, 0.8428170319114412, 0.35136326455644196, 0.17495410703122616, 0.3582174724766186, 22.176947593688965, 75.41464274270194, 66.32228565216064, 58.102264472416465, 21.40168149130685, 31.244127886635916, 51.89059230259487, 65.0406139918736, 73.48714991978237, 77.95615482330322, 81.27706023624965, 10.741193277495247, 0.470305432166372, 0.13889378415686743, 0.24294419799532208, 0.1778471903609378, 0.1529364056353058, 0.1427763072507722, 0.26857808391962734, 0.1287839109344142, 0.20784491140927586, 0.07075119244733027, 0.17896585033408233, 0.09402917086013726, 0.3013074648167406, 0.18062781329665864, 0.13530028983950615, 0.12005256302654743, 0.11341821402311325, 0.23271262273192406, 0.12047149054706097, 0.10887798693563257, 0.12390459275671414, 0.10947279073297977, 0.19041321107319423, 0.13089190210614884, 0.08816903709833111, 0.20369321347347327], [0.029596516862511635, 0.04016233169074569, 0.063392656589193, 0.040247097677950344, 0.050572154710867574, 0.03058697103655764, 0.01944697478653065, 0.04186303561021175, 0.045328042536441765, 0.02719892355214272, 0.011850475849184607, 0.010742848855443299, 0.055106817811195336, 0.05706522933074406, 0.07762314405824457, 0.032437118901205916, 0.033595469780266285, 0.024757483308868747, 0.10754284715013844, 0.04019325592422059, 0.0294391476283116, 0.1397687414927142, 49.80821371078491, 79.26607091086251, 78.38390677315849, 76.85691506522042, 53.76217991965157, 23.143127611705236, 16.800415890557424, 26.43369718960353, 49.58933503287179, 38.63692086083548, 21.373101813452585, 0.3880220146051475, 0.009485262229905596, 0.07862108586622135, 0.3988369128533772, 0.9214618461472648, 0.5783121394259589, 1.236647984811238, 0.5543738582304546, 0.290334549333368, 1.6280872374773026, 24.382319722856792, 59.85821669442313, 74.45971706935337, 64.19748483385358, 69.72077465057373, 70.82730306897844, 63.35254914419991, 61.329073905944824, 51.70196260724749, 49.64746018818447, 54.17552825382778, 55.42283412388393, 55.7591165133885, 53.2700320652553, 49.64664724894932, 50.401680197034565, 57.01564611707415, 61.89346218109131, 64.65355764116559, 59.764513288225444, 59.29867131369454, 64.0207018171038, 57.59339925221035, 45.13071073804583, 44.4227796282087, 46.420390197208945, 50.8924731527056, 54.53494814464024, 53.340208871024, 49.20967503956386, 46.211266790117534, 49.02851813180106, 43.12649590628487, 42.644092900412424, 41.36606209618704, 45.001540252140586, 43.71824966158186, 46.4150505065918, 44.85309198924473, 46.45668758664812, 45.44213247299194, 49.975158078329905, 52.98875856399536, 63.76702308654785, 46.563088825770784, 35.16315507888794, 60.4970896584647, 54.84885733468192, 61.206827299935476, 58.33940996442522, 58.68188667297363, 50.24153811591012, 48.7099814414978, 42.15192767551967, 45.67317049843924, 43.095715386526926, 43.933233874184744, 48.41718087877546, 56.28795085634504, 53.95749030794416, 52.45324352809361, 48.774853297642295, 44.86586972645351, 43.87024845395769, 44.21101243155343, 46.15704652241298, 55.69938979830061, 60.16023404257638, 61.06161689758301, 56.535939012254985, 63.826256479535786, 62.09000587463379, 59.558485303606304, 53.21713195528303, 49.68882976259504, 52.69538824898856, 63.27150535583496, 62.84428146907261, 65.5033084324428, 59.88061768668038, 62.25761726924351, 59.120456968035015, 64.4966812133789, 65.36355931418282, 30.867028304508754, 0.28882016773734775, 1.2172666362353732, 2.4327252209186554, 1.0668849285159792, 0.22865891882351466, 0.23152239088501247, 0.5891666912606784, 0.0777434143903, 0.11410137665058885, 0.08827204549951212, 0.6866740733385086, 19.894837822232926, 34.05922181265694, 31.81874738420759, 28.118044751031057, 19.88801642826625, 36.75766590663365, 48.775471687316895, 58.72585487365723, 59.610923358372276, 68.00087315695626, 39.75965247835432, 1.0879312391792024, 0.10072854387440852, 0.02607441969615008, 0.02911636173459036, 0.013705278464060808, 0.038592791983059475, 0.016544020468635217, 0.0450285643206111, 0.058193124165492396, 0.056133251304605176, 0.0019563337180963053, 0.08186761808714696, 0.058448965794273784, 0.052062943644289456, 0.023705838846841028, 0.016269198519044688, 0.02227636064136667, 0.005053870038994188, 0.062475555443337986, 0.02938514981152756, 0.014345441479235888, 0.00991896739495652, 0.0670196773218257, 0.0692174726032785, 0.012816510396078229, 0.020585196924262812, 0.06282778975686856, 0.0314515366085938, 0.05116158451086708, 0.026081466282318746, 0.019546308920585682, 0.02371730439231864, 0.04155100110386099, 0.09602638440472738, 0.031149992253631353, 0.025638108108458773, 0.014910769715373005, 0.022340069990605116, 0.04801109213648098, 0.02008726926786559, 0.014469311439565249, 0.02467228305925216, 0.02060904573383076, 0.055436392447778156, 0.032553246776972494, 0.05598758001412664, 0.03409315146771925, 0.3884335053818566, 64.3857671192714, 85.94138595036098, 86.78667599814278, 82.25523458208356, 64.24234935215541, 34.50730071749006, 21.77003676550729, 25.77453895977565, 42.36256231580462, 39.27725642068045, 26.400078330721172, 0.33585056981870104, 0.03719541018030473, 0.129595085978508, 0.722362084048135, 2.524662264755794, 2.575853769268308, 2.1789225084441046, 1.566062405705452, 0.27841963725430624, 2.7592343177114214, 26.95884551320757, 65.24168791089738, 77.95459147862026, 68.65858268737793, 72.22796957833427, 73.33353914533342, 65.96225084577287, 64.17491013663155, 54.945138522556846, 52.705581256321494, 57.15275839396885, 59.050321851457866, 57.099903447287424, 55.43033817836216, 51.88520744868687, 52.94443253108433, 61.174156870160786, 64.35666111537388, 65.87337643759591, 60.675199781145366, 60.50141838618687, 65.3103222165789, 59.79653058733259, 47.94224371228899, 46.50572449820382, 48.59705236979893, 53.24379219327654, 57.24440165928432, 54.40684073311942, 52.154300757816856, 48.5149107660566, 51.102888924734934, 46.01673460006714, 44.781747886112754, 44.295245443071636, 46.559590407780235, 46.21928153719221, 49.60164029257638, 46.57059635434832, 48.48913642338344, 46.8672844341823, 52.616185733250205, 56.00324147088187, 66.49298204694475, 49.99210820879255, 39.29321295874459, 62.37480558667864, 55.54755776269095, 63.047259194510325, 61.178777422223774, 61.343282972063335, 51.71176304136004, 50.833757400512695, 44.420545782361714, 46.90779938016619, 45.9041633605957, 46.445386341639924, 50.439829281398225, 58.18029621669224, 56.92177595411028, 55.22250018801008, 50.26350137165615, 47.22670085089547, 45.38047068459647, 46.713284560612266, 47.513341835566926, 59.56814329964774, 62.5453074319022, 62.446934836251394, 56.48962232044765, 66.38106046404157, 63.39338370731899, 62.34191281454903, 55.72939906801496, 52.503558908190044, 54.405020305088584, 64.89538969312395, 64.83052825927734, 68.00434725625175, 62.45371627807617, 64.62986428397042, 60.52863448006766, 68.94122845785958, 69.38724027361188, 34.70432036263602, 0.7435911649039814, 0.5749442715729985, 0.552186587027141, 1.754705997450011, 1.2891535673822676, 0.7830991649201938, 0.8156742740954671, 0.19560804803456577, 0.0889936742771949, 0.18107693562550203, 0.40273428229349, 23.07534098625183, 35.48566613878523, 29.623116629464285, 22.56837957245963, 28.064152785709926, 50.612620558057515, 57.62108782359532, 63.98375824519566, 66.43038572583879, 74.60962445395333, 51.96438217163086, 2.535403311252594, 0.08484545722603798, 0.06118395724999053, 0.011267934027793152, 0.03660340533990945, 0.04470093707953181, 0.021734553821650997, 0.05640216491052082, 0.058973432651587894, 0.045600355602800846, 0.02597942140086421, 0.0075849197372528055, 0.0733859371393919, 0.05812964042914765, 0.010272780150574232, 0.0184122377208301, 0.02609749836847186, 0.09118661124791418, 0.01825612547275211, 0.04580411966890097, 0.005254836844479931, 0.03722980512040002, 0.03907158664826836, 0.07906585200024502, 0.048768106515386274, 0.029726005092795407, 0.11708835565618106, 0.13942498208156653, 0.1597150790372065, 0.16707567764180048, 0.14185510096805437, 0.1519992673503501, 0.13330254703760147, 0.16601435387773172, 0.09660044538655452, 0.1399960100118603, 0.08524098207375833, 0.11385424062609673, 0.13801277428865433, 0.12336274183222226, 0.1334941517561674, 0.18741511766399654, 0.07883580827287265, 0.10117268575621502, 0.16222112599228108, 0.13336246167974813, 0.11669884941407613, 0.7884369013564927, 73.89740630558559, 97.97362313951764, 97.99097973959786, 94.74166856493268, 71.00863715580532, 35.38820375714983, 28.299696717943462, 36.542271750313894, 65.58130196162632, 54.96850184031895, 34.470020157950266, 1.026126361318997, 0.15630060939916543, 0.22196025827101298, 1.9034064582415988, 3.6367529332637787, 3.155735658747809, 4.4400326524462015, 3.941289220537458, 3.6445737821715216, 3.9189316545213972, 27.622681617736816, 66.69245093209403, 82.5614139011928, 71.28968484061105, 75.89652810777936, 76.2338284083775, 67.51768153054374, 66.8726246697562, 56.844105516161235, 54.25654077529907, 59.81985569000244, 61.868608474731445, 60.614382198878694, 58.22881201335362, 55.381864070892334, 55.904948779514854, 64.92733056204659, 66.86919920785087, 68.77545138767788, 61.18975557599749, 62.38979285103934, 68.8529793875558, 63.575072152274, 50.635421071733745, 49.24073348726545, 52.078891958509175, 55.88515336172921, 59.758579526628765, 58.711069107055664, 55.21176174708775, 50.86017097745623, 52.71777534484863, 47.63711357116699, 46.84650237219674, 47.18931606837681, 49.81192752293178, 50.48314087731497, 51.239764962877544, 49.62706722532, 52.095327922276084, 50.58537319728306, 53.938393184116904, 59.89050497327532, 69.78544153485979, 52.090947083064485, 42.94236864362444, 65.95466341291154, 58.55285167694092, 65.15672533852714, 63.434822763715474, 63.10540172031948, 56.099779742104666, 54.34916026251656, 47.72381666728428, 49.83447095326015, 47.40565170560564, 49.148895672389436, 53.2907828603472, 61.79319272722517, 60.503127643040244, 59.654314858572825, 53.16169227872576, 50.2641510282244, 47.83950417382376, 48.47509411403111, 49.96222400665283, 63.101350920540945, 66.04671314784459, 64.88957405090332, 59.18207359313965, 69.43270233699253, 67.47966793605259, 65.62246309007917, 57.540634632110596, 54.593281745910645, 58.09099449430193, 70.1189272744315, 69.12978172302246, 71.64549514225551, 64.91443470546177, 67.74541568756104, 63.14997441428048, 69.94080325535366, 71.8779193333217, 35.07167509623936, 0.6713409732495035, 4.589815403733935, 7.2226711085864475, 4.759882986545563, 1.3144341536930628, 0.8010408250348908, 2.4141003574643816, 0.4999291854245322, 0.2783441027360303, 0.25342829685126034, 1.2902344465255737, 33.111091477530344, 49.73955856050764, 47.839771679469514, 39.3981967653547, 31.055439131600515, 50.57802547727312, 65.81139850616455, 74.28388595581055, 75.40902859824044, 82.85997104644775, 59.677681650434224, 2.9358870557376315, 0.18340641419802392, 0.11310157565666096, 0.18010995537042618, 0.07368811592459679, 0.17143252385514124, 0.09331060906073876, 0.16478422417172364, 0.13230942961360725, 0.1565120273402759, 0.14451824235064642, 0.2197231418852295, 0.14131360288177217, 0.2430396814431463, 0.11569980159401894, 0.11649486821677003, 0.2127830178609916, 0.17371283578021185, 0.15487005401934895, 0.11661975937230246, 0.11901790568871157, 0.15231112204492092, 0.14803974410252912, 0.14523347254310334, 0.21326409918921335, 0.09788408436413322], [0.025587971155930842, 0.053842031929109774, 0.054849286630217514, 0.04652724800897496, 0.021574765610109483, 0.0410412347077259, 0.026102526312960044, 0.044096864493829865, 0.01888418766403837, 0.13722754642367363, 0.026005037794155732, 0.013646921059781951, 0.0021034367174641894, 0.03273861575871706, 0.031517242547124624, 0.08096765673586301, 0.06327615212649107, 0.12468623795679637, 0.041292784602514336, 0.12920000217854977, 0.5203788195337568, 10.258649570601326, 83.5865650177002, 75.46724755423409, 77.30969442640031, 61.73297963823591, 44.30545582090105, 19.991687025342667, 33.27474239894322, 58.6808374949864, 48.93773644311087, 37.01985618046352, 5.494347095489502, 0.06956716241048914, 0.15536459748234066, 0.2964087133961064, 0.4291989122118269, 0.5143753588199615, 0.8974401865686689, 0.7385783653174127, 0.23958903231791087, 1.0622761015381132, 23.46470935004098, 63.341584886823384, 70.50137002127511, 68.13809313092912, 71.41513456617082, 67.00300761631557, 64.8296388898577, 59.65876170567104, 54.11135121754238, 51.28581762313843, 55.325062547411235, 58.5421792439052, 59.87662247249058, 56.94583061763218, 52.61457027707781, 43.921564374651226, 50.83440705708095, 57.74669735772269, 60.655717032296316, 61.34156676701137, 58.04457357951573, 59.5525723866054, 62.86153384617397, 54.79147563661848, 45.39786549976894, 43.52625356401716, 48.51279156548636, 55.463811125074116, 58.4495667048863, 55.94796160289219, 53.92792919703892, 46.84122174126761, 42.95656033924648, 42.03103596823556, 43.81941195896694, 44.13687515258789, 52.70699521473476, 53.75563471657889, 58.338416372026714, 57.44691385541643, 56.96318374361311, 52.4578640801566, 58.59278992244175, 53.42597048623221, 67.19376346043178, 43.60401085444859, 32.69213594709124, 58.228294372558594, 52.43560900006975, 59.9593894141061, 55.08755227497646, 57.48789433070591, 48.11323193141392, 47.09775618144444, 42.01095914840698, 44.026850427900044, 41.37714447293963, 43.3580550466265, 41.65434980392456, 44.345949922289165, 43.89760003771101, 45.219692843300955, 42.215427262442454, 43.73987940379551, 42.489311354500906, 45.628507477896555, 43.9863771711077, 52.23303427015032, 58.77148369380406, 63.62500190734863, 53.2862491607666, 62.34957667759487, 62.35371085575649, 62.172168322971885, 56.26825966153826, 56.61679172515869, 48.58233955928257, 52.34808601651873, 59.107269287109375, 63.821073123386924, 62.96276909964425, 62.50953115735735, 64.47971371241978, 67.39778341565813, 59.818236759730745, 72.13760130746024, 39.721541609082905, 1.9614091515541077, 2.4892755235944475, 1.6904918317283903, 0.7671605401805469, 0.6617482251354626, 0.4125527654375349, 0.13839405668633326, 0.1265971011349133, 0.24328039852636202, 0.03219399641134909, 7.759338242667062, 30.03201116834368, 34.102192946842735, 46.59145484651838, 19.489283629826136, 16.98119412149702, 32.60289328438895, 43.45355108806065, 54.27458872113909, 59.29373114449637, 64.72909150804792, 24.54992938041687, 0.2550847908215863, 0.03702893500615444, 0.07727911323308945, 0.02465618142325963, 0.09717505598174674, 0.04098984246541347, 0.03633819314252053, 0.048743750500891886, 0.0818126228238855, 0.008479541866108775, 0.05504757831139224, 0.004914106668106147, 0.03940509678795934, 0.02431537363944309, 0.017215127225166986, 0.0674992183755551, 0.07672395623688187, 0.03816202402647052, 0.05472832419244306, 0.07309213826166731, 0.028908943757414818, 0.059866330453327725, 0.0489510361637388, 0.09814387506672315, 0.0572292244594012, 0.019969531567767262, 0.00929242342577449, 0.052752189338207245, 0.0414294517332954, 0.045489170854645114, 0.049247284552880695, 0.016242331924981306, 0.04068198773477759, 0.03317288156332714, 0.07761451309280736, 0.037061779493732114, 0.05125431989186576, 0.03553644973518593, 0.06145938139941011, 0.05989775341004133, 0.06280746763306004, 0.08053452747740916, 0.09755374637565442, 0.0978953887575439, 0.2651996852031776, 0.6106792911887169, 14.28393816947937, 98.81492492130825, 82.2746547971453, 85.18615845271519, 68.51572077614921, 52.16716534750802, 27.020123413630895, 33.52093097141811, 44.04562793459211, 48.034189224243164, 44.420872347695486, 6.305994834218707, 0.15058616389121326, 0.051861822472086976, 0.7833939205322946, 1.8191081987959998, 1.26955888739654, 2.1616178027221133, 2.5228463964802876, 1.4841985127755573, 1.122108125260898, 27.92815743173872, 65.4644193649292, 74.50313636234829, 68.50966889517647, 75.52095712934221, 68.2215132032122, 67.47308104378837, 63.03058351789202, 56.44837433951241, 53.60561268670218, 57.394639083317344, 60.44883441925049, 61.33205468314034, 59.09451239449637, 55.69771875653948, 46.60098777498518, 53.358875206538606, 59.42524664742606, 64.16505064283098, 63.85489695412772, 58.68060820443289, 60.57242202758789, 64.18821593693325, 56.00864022118704, 47.64548962456839, 44.09953553336007, 49.72654805864607, 59.00475556509835, 62.29102420806885, 59.024432863507954, 56.82654047012329, 49.058864389147075, 44.735205377851216, 44.68245118004935, 45.7031762940543, 46.31822388512747, 54.79344892501831, 57.117663042885916, 61.49794292449951, 59.019318989345, 60.34033135005406, 56.19824266433716, 61.47541686466762, 55.08848333358765, 69.52407114846366, 46.15535116195679, 36.62427091598511, 62.89815085274832, 54.75833967753819, 62.743602071489605, 57.91094582421439, 60.19951220921108, 52.16919074739729, 49.10676874433245, 44.8106176512582, 45.71621458871024, 45.14544786725725, 45.050719601767405, 44.58761869158064, 46.37174585887364, 46.55758932658604, 45.920165061950684, 45.058626651763916, 45.95140763691494, 44.04181684766497, 47.99620689664568, 45.65011984961373, 54.46554953711373, 61.246703011649, 64.2478175844465, 55.78979281016758, 62.810436793736045, 65.36704730987549, 63.46226814814976, 59.191905294145855, 59.37282248905727, 51.950048037937705, 55.91772999082293, 61.5339206968035, 67.66301700047084, 67.07033566066197, 63.14681298392159, 68.02426079341343, 67.19896071297782, 63.70389175415039, 75.1190733228411, 46.11161225182669, 2.939378525529589, 0.6645454178963388, 0.6492370164820126, 0.9498662991183144, 1.5692201448338372, 0.7828410501990999, 0.37547402935368673, 0.5389723075287682, 0.3902105614542961, 0.08798092004976102, 7.521799308913095, 38.48614842551095, 33.63585417611258, 40.727331570216585, 27.696499279567174, 29.434910774230957, 42.76903540747506, 50.816511971609934, 61.12444250924246, 64.86536652701241, 76.39622865404401, 33.42474358422415, 0.29664115235209465, 0.05730803630181721, 0.07794458645262889, 0.009552748474691595, 0.07739477631236825, 0.06405682702149663, 0.06730926249708448, 0.05787730682641268, 0.048359930382243226, 0.05694789026996919, 0.012238798047682005, 0.03309877536126545, 0.039248209313622544, 0.007868960433240448, 0.02285792791683759, 0.08167453416224037, 0.06009792124054261, 0.03305676725826093, 0.06560879945755005, 0.039702719210514, 0.05654743925801345, 0.10097967647016048, 0.033314050773956945, 0.018369788570063453, 0.0723187711888126, 0.061900273098477294, 0.08998683241329022, 0.19560792589826242, 0.16507484072021075, 0.16349907884640352, 0.15244914963841438, 0.10836099074887377, 0.18713178858160973, 0.18009137708161557, 0.18145839444228581, 0.20078848648284162, 0.13763803296855517, 0.07023820640253169, 0.1934355960360595, 0.09675319718995265, 0.1768114473670721, 0.16153613132025513, 0.3031674107270581, 0.12648493929633073, 0.4052656793168613, 0.6679744081837791, 17.012825795582362, 112.71819387163434, 92.60388156345913, 96.95206424168178, 77.95765563419887, 60.6731014251709, 30.167657375335693, 43.48523834773472, 80.78362696511405, 70.06876128060478, 55.95416634423392, 8.625955786023821, 0.28953127243689125, 0.4115547218493053, 1.1767274801220213, 3.517053710562842, 2.8633387429373602, 4.43544032743999, 3.9320481164114813, 4.528810220105307, 2.909546869141715, 28.690192426953995, 69.46266991751534, 75.98586109706334, 72.74135112762451, 77.48414979662213, 71.10275745391846, 70.21678570338658, 66.45585782187325, 59.20763601575579, 55.6183876991272, 60.931227002825054, 64.17304801940918, 66.18646921430314, 61.99490588051932, 58.48806667327881, 48.290160860334126, 55.48678534371512, 62.5260956627982, 66.24649470193046, 63.65931211199079, 58.98464747837612, 63.67279856545584, 68.57994992392403, 59.61269514901297, 50.77569477898734, 46.27094834191458, 52.51491226468767, 62.779628481183735, 65.53802858080182, 62.437665939331055, 59.47375896998814, 52.49357087271554, 45.900494711739675, 45.61177968978882, 48.03249386378697, 49.75390311649868, 57.187336104256765, 60.9261965070452, 64.76282501220703, 62.90721130371094, 63.37014198303223, 60.65857969011579, 65.00616482325962, 60.032421929495676, 71.45355115618024, 49.49695873260498, 40.97943305969238, 63.87000928606306, 56.481624943869456, 65.60859448569161, 59.91417748587472, 62.560822759355815, 54.98916578292847, 52.797054290771484, 46.57574496950422, 49.163677964891704, 45.85267720903669, 47.060176849365234, 47.36408063343593, 49.58436707087925, 48.24273245675223, 50.14738655090332, 47.00773532049996, 48.58515705381121, 47.088167667388916, 50.44809763772147, 49.06485373633248, 58.06464345114571, 65.12696620396206, 70.82746982574463, 56.05597482408796, 64.73062705993652, 68.47995144980294, 67.4758950642177, 61.295632226126536, 62.7151700428554, 54.619229793548584, 57.886529854365754, 63.50383227212088, 68.1185895374843, 69.73061329977853, 66.59384209769112, 70.07868330819267, 71.53003692626953, 65.70199217115129, 77.67542675563267, 46.36333506447928, 2.7531188172953467, 5.720341163022177, 8.287954585892813, 5.10645956652505, 2.483227333852223, 0.8917758305157933, 1.4422167369297572, 0.5054588115641049, 0.6588810618434633, 0.2304504955453532, 11.739969900676183, 49.25764192853655, 50.02723135266985, 62.726426124572754, 29.004150254385813, 25.74184247425624, 46.185971873147146, 58.42104434967041, 70.6931403023856, 75.78274440765381, 83.4742682320731, 36.81785815102713, 0.4261482459093843, 0.1410983715738569, 0.21996650525501796, 0.10310343679572855, 0.16971797442861966, 0.09615270726914917, 0.20894451811909676, 0.12042100754167352, 0.19594762766999857, 0.09353260536278997, 0.0932001978425043, 0.13577805991683686, 0.11441313635025706, 0.09885622148535081, 0.06266503634729556, 0.15091826607074055, 0.22573344223201275, 0.15934284829667636, 0.17316136322915554, 0.14256552713257925, 0.1430825436753886, 0.15396729031843798, 0.09438217191823892, 0.1625961930091892, 0.19608214045209543], [0.06672314394797597, 0.07352873483406645, 0.06193348738764014, 0.028762912843376398, 0.03534565247329218, 0.018463256768882275, 0.028625309334269593, 0.036194682986076386, 0.035059507470577955, 0.002663821401906067, 0.032899062149226665, 0.036320357849555354, 0.03244348016700574, 0.007249721741702939, 0.05026850689734731, 0.022239763855135868, 0.0515422664050545, 0.12132324198526995, 0.049741291973207674, 0.08279410337230989, 0.06636725911604506, 32.804835728236604, 83.08923380715507, 69.83068125588554, 70.934937613351, 58.554067611694336, 46.2341228893825, 29.44878285271781, 41.06995071683611, 42.320327690669465, 43.267311573028564, 18.09797808102199, 0.14356070730303014, 0.019193440176812664, 0.059566689389092584, 0.5003306067415646, 0.08813817732568298, 1.5389461921794074, 1.2524636047227042, 1.6035273096391132, 0.19535054399498872, 15.274565424237933, 62.01455538613455, 70.27680424281529, 69.79006903512138, 66.44185025351388, 65.34334700448173, 63.950928006853374, 61.32937267848423, 53.123741218021934, 54.598600591932026, 52.97274644034249, 61.00661495753697, 58.822358403887065, 61.555612972804475, 55.33046129771641, 49.38241420473371, 45.81227690832955, 51.53167268208095, 57.47583225795201, 62.447587966918945, 58.508146967206685, 58.622194698878694, 59.36007949284145, 60.07292992728097, 50.57694155829293, 43.60772466659546, 41.59771156311035, 52.134373324257986, 59.782050541469026, 59.58317225319998, 59.14597075326102, 55.45061649594988, 46.408943040030344, 46.59317799976894, 42.76088169642857, 44.50193003245762, 51.12972981589181, 57.81439365659441, 55.23942599977766, 55.51297310420445, 54.98722376142229, 59.5292820249285, 59.74570451463972, 61.391037940979004, 58.88679599761963, 65.01479448590959, 40.81274924959455, 31.707871505192347, 56.60004309245518, 52.39295400891985, 59.287262371608186, 54.83079549244472, 55.98490170070103, 47.455852440425325, 45.387578691755024, 42.25463247299194, 42.74030113220215, 40.88166148321969, 40.3531745501927, 40.38273566109793, 44.669173172542024, 42.20761053902762, 44.30199214390346, 41.0746476990836, 43.03833021436419, 42.951571532658164, 44.18211834771292, 42.59296458108084, 47.792378016880576, 54.84669297082083, 59.767924853733604, 56.97194194793701, 55.80931030000959, 61.7978549684797, 61.99870654514858, 62.08871350969587, 58.64447757175991, 54.27936213357108, 49.376831327165874, 53.23492281777518, 61.4293155670166, 62.943772724696565, 66.08701269967216, 63.03446061270577, 64.0075488771711, 64.42116819109235, 62.68612657274519, 69.03448717934745, 41.060417788369314, 0.9253781331436974, 0.8379902594855854, 1.2768036872148514, 0.8123903817364148, 0.15880582854151726, 0.16210985981992312, 0.17450358692024434, 0.10396950532283102, 0.07486907898315362, 0.03195699770003557, 15.157078334263392, 38.6349093573434, 38.557492528642925, 30.352597577231272, 15.568508965628487, 15.51153200013297, 30.175032888139995, 47.38765239715576, 56.812532901763916, 58.33643613542829, 57.864142758505686, 4.698996790817805, 0.10565014156912055, 0.08100748674145766, 0.04353057273796626, 0.018832430709153414, 0.012091893519807075, 0.02665848906950227, 0.012307972996495664, 0.048648402760071416, 0.03519549945901547, 0.09064708091318607, 0.012281151355377265, 0.006483382171219481, 0.04086561966687441, 0.0399589577822813, 0.04049034230411053, 0.03392839298716613, 0.08855732197740249, 0.014119969381551658, 0.02241438823486013, 0.09605158519531999, 0.03855519775035126, 0.02547772617877594, 0.04121735864984138, 0.020354647688301544, 0.027635538784254874, 0.03222172813756125, 0.009732192997554583, 0.04891502970297422, 0.06378128752112389, 0.06057658019874777, 0.03979060645880444, 0.016905097789796333, 0.0028281835755998535, 0.047826652747711966, 0.042886989058128426, 0.013638834618697209, 0.0319685294026775, 0.050922085398009846, 0.02331680927558669, 0.062347217329910824, 0.015397891701598252, 0.036351190480802736, 0.040230772125401666, 0.07703283216272082, 0.11903082499546663, 43.32150404793875, 92.23493916647774, 77.42907837459019, 78.64488111223493, 64.977434022086, 52.93443059921265, 27.934108563831874, 26.503066267286027, 38.827937262398855, 47.67226103373936, 21.04446417944772, 0.1698405992771898, 0.02665666550663965, 0.20672876201570034, 0.9835727704422814, 1.4360838660172053, 3.402242111308234, 1.3337493858167102, 0.8058367105466979, 0.5936852459396634, 19.40309296335493, 64.57645348140171, 72.30401066371373, 73.90910707201276, 67.45963627951485, 67.12831142970494, 65.50664356776646, 63.995667457580566, 55.872056007385254, 57.60614572252546, 56.29569809777396, 63.76739828927176, 61.655847685677664, 63.067554882594514, 58.70932510920933, 51.36933497020176, 48.53834703990391, 53.65848500388009, 60.93164389474051, 65.30438845498222, 61.93891729627337, 59.135729108537944, 60.182572501046316, 61.889390536717, 52.647049631391255, 45.60479327610561, 44.64629970278059, 55.3895001411438, 60.69580813816616, 62.158466475350515, 60.95483003343855, 58.01220192228045, 48.51356628962925, 47.11440406526838, 45.09044592721121, 46.43194852556501, 52.31232016427176, 59.92028495243618, 58.512211663382395, 58.23426634924752, 57.70890957968575, 63.13841956002371, 61.511075019836426, 63.386303492954795, 62.27136080605643, 65.30196353367397, 41.699544361659456, 34.819646562848774, 58.594978604997905, 53.58556365966797, 61.045003754752024, 56.42985739026751, 58.774165698460166, 48.7358843258449, 47.42172636304583, 43.2494512285505, 44.94053506851196, 44.217502049037385, 43.253290108272004, 43.12694753919329, 44.3366254397801, 45.70191172191075, 45.75394678115845, 43.05497462408883, 44.0151218686785, 44.89133140019008, 45.631248542240684, 45.00842939104353, 51.03822204044887, 59.50902107783726, 62.66722052437918, 59.75097819737026, 57.648713861192974, 63.22730786459786, 62.78690324510847, 63.89077050345284, 60.2871915272304, 57.37222419466291, 50.19939729145595, 57.11354276112148, 63.25473240443638, 64.80129023960659, 68.01356056758335, 67.76845591408866, 65.82346752711705, 68.03040994916643, 63.7277866091047, 71.92345087868827, 46.24466330664498, 2.162647004638399, 0.8202010254774774, 0.27982683745878084, 1.6636754763977868, 1.848470526082175, 0.710681347974709, 0.6186535975762776, 0.39278940164617127, 0.12420594372919627, 0.08253765106201172, 15.947397708892822, 40.61574697494507, 32.440409660339355, 21.432244879858835, 17.28198684964861, 25.05949115753174, 40.87483140400478, 55.379911627088276, 63.40587656838553, 66.56577832358224, 70.67363670894078, 8.833888445581708, 0.21347862482070923, 0.0574181896767446, 0.02669467364570924, 0.026840003972340907, 0.03225872525945306, 0.06782285922339984, 0.04719784416790519, 0.06796056790543453, 0.07880946075809853, 0.0282962741330266, 0.061691386092986376, 0.06749224982091359, 0.023855717054435184, 0.022606729163921306, 0.04808435356244445, 0.03045792385403599, 0.04138850214491997, 0.05985507355736835, 0.05275066602709038, 0.02158661452787263, 0.034191620469625504, 0.02227364819762962, 0.058622236496635845, 0.03526139199467642, 0.09389157074370555, 0.19376013933547906, 0.12105588561722211, 0.09621804340609483, 0.2718773925943034, 0.17262423490839346, 0.1159339640289545, 0.11695906759372779, 0.11405192501842976, 0.15541756392589637, 0.12893550922828062, 0.12351161241531372, 0.1534633016479867, 0.10058248242629425, 0.11486421285995416, 0.12253102074776377, 0.09978077294571058, 0.18464567698538303, 0.1414985986692565, 0.16880356706678867, 0.11063153176967587, 52.48994738715035, 103.13404328482491, 87.48036330086845, 89.43530150822231, 73.80613476889474, 60.93110193525042, 41.217207363673616, 58.044545786721365, 60.558713231767925, 59.27216393607003, 28.47330961908613, 0.4689173123666218, 0.14308787696063519, 0.39443463193518774, 1.5623313316277094, 1.7663931931768144, 5.704336421830313, 6.004901596478053, 6.665072960512979, 3.209955709321158, 20.803319999149867, 70.0793433870588, 73.81006050109863, 76.87871851239885, 73.23219966888428, 70.75113691602434, 69.97121552058628, 67.58603096008301, 57.85581186839512, 60.26793112073626, 59.05048860822405, 66.94483034951347, 64.18984876360211, 65.90648460388184, 61.15361104692732, 53.573230607169016, 51.08467422212873, 56.72571168627058, 63.445919036865234, 65.85271944318498, 62.47548498426165, 59.57280554090227, 63.30231366838728, 65.24001339503697, 56.238295555114746, 48.587356158665244, 46.966046128954204, 57.303864342825754, 64.23708956582206, 64.44963496071952, 64.41378225599016, 61.981113706316265, 50.658249378204346, 50.30922746658325, 47.50667156491961, 49.125073773520334, 56.62737383161272, 62.04317501613072, 60.37065328870501, 61.38695934840611, 60.11999702453613, 65.69087505340576, 64.60379464285714, 65.59359332493374, 66.58219691685268, 66.10452216012138, 45.30506535938808, 39.16545990535191, 62.20370619637625, 56.431663921901155, 64.23065553392682, 58.90519482748849, 61.35989611489432, 52.34905876432146, 51.51117549623762, 45.180907998766216, 47.527738503047395, 45.34102576119559, 44.77478231702532, 44.952944551195415, 47.89905023574829, 47.78467246464321, 47.86485467638288, 44.163924489702495, 46.49824823651995, 47.925376960209434, 48.40220403671265, 47.2260650907244, 53.45492362976074, 60.875120299203054, 64.10419831957135, 62.729941913059776, 57.8510627746582, 66.61487429482597, 68.0416590826852, 67.3134183883667, 63.856182370867046, 60.070908001491, 52.995880467551096, 59.124514716012136, 66.60549422672817, 68.69451182229179, 72.07664476122174, 68.65679005214146, 69.78066117422921, 70.52099868229458, 69.26406955718994, 73.39441926138741, 48.337964466639924, 2.138487901006426, 4.835979657513755, 7.071653749261584, 4.4415425828525, 1.5169466755219867, 0.7884830960205623, 1.2205471630607332, 0.5410038413746017, 0.16846396028995514, 0.07800482000623431, 23.13955797467913, 56.91950041907174, 51.83614274433681, 41.17947169712612, 23.678104162216187, 24.396341187613352, 43.07940796443394, 61.805762018476216, 74.64121791294643, 72.71827616010393, 76.32464831215995, 10.193888885634285, 0.2958700108741011, 0.19167479766266687, 0.15475770219096116, 0.09390330261417798, 0.10543030979377882, 0.18432867899537086, 0.07343747187405825, 0.127176895737648, 0.14848049330924237, 0.17222326142447336, 0.10893190332821437, 0.13540559847440037, 0.23295461546097482, 0.16360284042145523, 0.09044661452727658, 0.06608115482543196, 0.18218444048294, 0.1694404264645917, 0.06221497764012643, 0.14247856608458928, 0.11225168340440307, 0.060406288265117576, 0.1076146090137107, 0.061941935148622305], [0.035484226287475655, 0.017051769919427376, 0.037196787606392584, 0.10187316459736653, 0.020336255996621082, 0.04705206770449877, 0.059921366428690295, 0.054297305177897215, 0.050437909950103076, 0.02505155190426324, 0.0196244914217719, 0.026261875173076987, 0.029618701564946344, 0.057219392486980984, 0.06763564462640456, 0.03523218784747379, 0.07698574183242661, 0.021280939590984156, 0.12714591382869653, 0.10114758674587522, 2.7658476999827792, 66.35956968579973, 77.58450957706997, 73.57039628710065, 57.939002650124685, 37.69542605536324, 28.094082151140483, 36.10617501395089, 64.10889530181885, 45.765529428209575, 41.567410469055176, 4.111750245094299, 0.06536049635282584, 0.0893202463963202, 0.13185645320585795, 0.24036253509776934, 0.8178602967943464, 2.0875654220581055, 1.6504442606653487, 2.0485347849982123, 9.06363410609109, 56.01045370101929, 74.56694861820766, 70.51296656472343, 65.36538669041225, 60.992600440979004, 61.62723500388009, 56.786018575940815, 52.93234613963536, 54.45350136075701, 55.98868499483381, 60.269508361816406, 64.39725249154228, 62.433205195835654, 61.36724730900356, 53.1471323285784, 47.87499557222639, 45.73619760785784, 51.840002468654085, 58.616552761622835, 61.564659527369905, 59.09476252964565, 56.80875655582973, 60.09722082955496, 56.54415873118809, 48.18075452532087, 41.393837520054404, 43.10597440174648, 54.295756408146445, 59.558693749564036, 58.2787834576198, 59.49195630209786, 55.19785145350865, 50.93404075077602, 47.531622546059744, 43.441318784441265, 45.76729079655239, 49.25394548688616, 54.682576520102366, 60.48330443246024, 58.178826672690256, 52.242994512830464, 57.13322353363037, 56.10878460747855, 59.02225807734898, 55.01133748463222, 61.02898815699986, 38.321580341884065, 32.89998435974121, 56.00159822191511, 49.48044286455427, 59.54154559544155, 55.464999267033164, 55.60000971385411, 46.494197436741416, 44.914639132363455, 41.56347778865269, 44.096137864249094, 42.059231758117676, 43.561595576150076, 40.55592993327549, 44.5402250289917, 41.686596393585205, 42.040211064474924, 43.84196581159319, 44.33728551864624, 42.96524558748518, 42.91371774673462, 42.87397405079433, 42.91031312942505, 51.30679076058524, 56.5792019707816, 58.502435547964915, 57.39407627923148, 57.80916166305542, 59.45877170562744, 60.57657010214669, 62.087462833949495, 58.30038888113839, 50.96143402372088, 45.24854523794991, 58.74954128265381, 63.75447463989258, 63.02828366415841, 63.53137493133545, 61.977556228637695, 58.03061464854649, 64.50836113521031, 62.04038184029715, 69.91014780317033, 37.885139669690815, 0.3289530442229339, 0.110886090967272, 1.571705971445356, 1.238028613584382, 0.0655604741935219, 0.5446836182049343, 0.21505342317478998, 0.07675415783056191, 0.00453033235057124, 1.1766641863754816, 24.710321596690587, 43.68569735118321, 53.873104436056956, 51.84754473822457, 27.470151288168772, 15.288491351263863, 36.82447631018502, 50.543357440403526, 57.969529560634065, 69.75048514774868, 44.69880029133388, 0.6275127136281559, 0.034024867096117566, 0.05351127324891942, 0.07358199983303036, 0.02739503374323249, 0.039653715411467214, 0.027814195358327458, 0.004429058030447257, 0.05519033529396568, 0.022491938002141457, 0.056121102135096274, 0.026336799009836147, 0.07794014883360692, 0.04879993998578616, 0.060626194679311345, 0.06979641903723989, 0.04171872138977051, 0.03239414049312472, 0.036524237266608646, 0.021240076515823603, 0.024601879962054745, 0.08684602951897041, 0.059047929011285305, 0.029560181312263012, 0.040943359423960955, 0.03200539421024067, 0.04509780542658908, 0.04746072220482996, 0.026503409890990173, 0.08085252969924893, 0.04889182719801154, 0.02584593490298305, 0.01303601817094854, 0.0033433651052681462, 0.027381837933457324, 0.022340466933591024, 0.07642780284264258, 0.06006061538521733, 0.1293645062084709, 0.06971619584198509, 0.0870758154030357, 0.020428268737824898, 0.012088802792797131, 0.10481365716883115, 4.513670529638018, 81.27084159851074, 85.60485689980644, 81.97484697614397, 66.56301988874162, 51.917738914489746, 41.755883829934255, 35.53123937334333, 59.78336375100272, 42.44656603676932, 43.63619143622262, 6.1271308319909235, 0.23611363023519516, 0.0520583024647619, 0.663035161793232, 1.3889158027512687, 1.736210435628891, 2.2968258389404843, 1.17384386914117, 0.2782514691352844, 10.701256769044058, 59.51942947932652, 76.26940318516323, 73.34483691624233, 68.08969892774309, 63.301090785435264, 61.95666994367327, 60.51327201298305, 55.99166577202933, 56.71595641544887, 57.17065347943987, 62.3227288382394, 65.76398399897984, 65.07216576167515, 63.66119507380894, 56.00776474816458, 49.45525564466204, 47.35377645492554, 53.36813020706177, 62.00092996869768, 64.24222428458077, 60.68164076123919, 56.85570205960955, 64.27920954568046, 59.38640621730259, 50.84248086384365, 43.22871780395508, 46.03143004008702, 57.03121355601719, 61.41289002554757, 59.338901383536204, 61.62374700818743, 58.45826584952218, 53.30508572714669, 49.44168928691319, 46.15398931503296, 48.321156774248394, 53.943798882620676, 58.18843603134155, 61.41145869663784, 60.77061244419643, 56.5031852040972, 60.16092191423689, 57.090606757572715, 60.05801909310477, 55.92561272212437, 59.72141361236572, 41.08619907924107, 36.394341128213064, 58.69833305903843, 51.006357601710725, 60.54685960497175, 56.98113094057356, 58.65118258340018, 48.86820929391043, 47.57202632086617, 43.032042094639365, 45.672770977020264, 46.08002574103219, 45.83192988804409, 42.049146447862896, 46.96178340911865, 43.662250655038015, 44.31012153625488, 46.12539747783116, 45.43497582844326, 45.59179319654192, 44.99344212668282, 45.08766317367554, 46.09605870928083, 52.928510734013145, 60.555892263139995, 59.475530760628835, 58.65690095084054, 58.74686622619629, 61.54010459354946, 62.884400367736816, 65.16384724208287, 61.075617517743794, 53.5043739591326, 48.40758194242205, 61.22778306688581, 66.45863710130963, 66.08056477137974, 64.73347582135881, 65.0517658506121, 60.81961114065987, 67.00139563424247, 64.93079771314348, 72.734361239842, 43.7691764831543, 1.2716977383409227, 0.39038852761898724, 0.4354095975203173, 2.8456890157290866, 1.9228624999523163, 1.0049465149641037, 1.2025786872420992, 0.37352489680051804, 0.06126628390380314, 0.8189665802887508, 26.98187358038766, 37.23738343375069, 42.0424553326198, 40.42630781446184, 27.972445249557495, 23.629388604845317, 43.84216383525303, 56.26846463339669, 65.5759449005127, 75.00055095127651, 58.71314661843436, 1.1130184701510837, 0.049144150622721226, 0.06163284209157739, 0.029130047785916498, 0.02453147686485733, 0.039836282043584754, 0.02690039019632552, 0.023255854778523957, 0.03316763988030808, 0.013945259336781288, 0.02511624343294118, 0.03574231047449367, 0.025891814048268964, 0.022301235735150318, 0.06155510911984103, 0.07550549054784433, 0.060764201916754246, 0.07812241691031627, 0.012527024456565934, 0.03612197795882821, 0.045792051923594305, 0.007478969038597175, 0.018147130696369067, 0.006369896341181759, 0.13854798914066382, 0.08446064644626208, 0.11101564365838255, 0.16584434014345917, 0.12299736429538045, 0.10978136131806032, 0.13686109680150235, 0.1372259043689285, 0.09786615068359034, 0.1120682821742126, 0.09833232459745236, 0.1328519590731178, 0.13905066145317896, 0.1620500266019787, 0.19270452883626732, 0.16233110294810363, 0.2000369139547859, 0.1479193584195205, 0.34727471108947483, 0.22796344757080078, 5.362377788339343, 95.06459999084473, 93.4511171068464, 93.20703383854458, 75.24785818372453, 55.59110559735979, 40.16928700038365, 52.887023040226524, 84.72142818995884, 60.98641654423305, 61.54111903054373, 7.237801245280674, 0.284271024699722, 0.38524409223880085, 0.8626655382769448, 1.721453981740134, 3.3268545908587317, 5.584363179547446, 6.341943510941096, 7.008746496268681, 11.205846241542272, 62.503145762852256, 78.77812671661377, 76.37635680607387, 70.71347073146275, 66.37010315486363, 65.43800231388637, 61.636142594473704, 58.728717531476704, 60.43675150190081, 60.30089337485177, 66.26455307006836, 68.94684955051967, 68.01815332685197, 66.79331793103898, 58.716342789786204, 51.39929560252598, 49.42778941563198, 56.04248489652361, 64.52369580950055, 67.03298909323556, 62.977283886500764, 56.7814153943743, 66.56210272652763, 60.909138679504395, 54.192923069000244, 44.88795110157558, 48.72763681411743, 59.97798974173409, 65.37778922489711, 62.50576523372105, 63.45484052385603, 59.79053429194859, 56.9331362588065, 52.77387162617275, 47.03604228155953, 51.39714166096279, 55.65930216653006, 61.190686634608674, 64.00315761566162, 62.72547422136579, 57.19396815981184, 58.932077407836914, 61.266123226710725, 61.24674470084054, 58.356613704136436, 61.268346650259836, 43.682633195604595, 40.685458251408164, 61.57977185930525, 52.98507601874215, 62.323701586042134, 59.078955377851216, 60.13852787017822, 51.17595270701817, 50.88353429521833, 45.43074437550136, 48.904854093279155, 46.9262364251273, 48.48567622048514, 45.43526070458548, 50.5253199168614, 45.80438722882952, 45.60787827627999, 48.6645575932094, 48.668188026973176, 48.143779686519075, 48.148094517844065, 48.225254263196675, 48.766272272382466, 56.68460961750576, 62.61839553288051, 63.910531180245535, 61.19630772726876, 60.517225537981304, 61.801447187151226, 65.56477219717843, 68.59560421534947, 63.574710845947266, 56.08886064801897, 50.776268005371094, 63.53650270189558, 70.43782874516079, 67.60274137769426, 68.02122443062919, 67.33646556309291, 63.251932280404226, 68.62404319218227, 68.12444686889648, 74.1952269417899, 48.679430212293354, 0.896921188703605, 2.2710321715899875, 7.599408950124468, 4.901721341269357, 1.8777986552034105, 1.4356871673039027, 2.051190299647195, 0.5108135928000722, 0.18044999640967163, 2.0346739973340715, 38.924656186785015, 62.67880317143032, 70.18760326930455, 60.29973997388567, 37.14794969558716, 23.89787220954895, 49.63984843662807, 64.62147780827114, 72.61626270839146, 85.01418358939034, 61.89264229365757, 1.2169336655310221, 0.13585302446569714, 0.1559921202382871, 0.1390442560826029, 0.08281806244381837, 0.15006857737898827, 0.14134372983660015, 0.10043587815016508, 0.15262784862092563, 0.18405893418405736, 0.14015136738973005, 0.16949160157569818, 0.21758663867201122, 0.12200020280267511, 0.09654900564679078, 0.16147332611892903, 0.19931274067078317, 0.2030459317777838, 0.12267347238957882, 0.07754820665078503, 0.12647930745567593, 0.1703666674771479, 0.13301936723291874, 0.11620757648987429], [0.07733085152826139, 0.0738898783123919, 0.031768707625035725, 0.03171514407066362, 0.039330600428261926, 0.0180224600647177, 0.040710730478167534, 0.054916095188153644, 0.011918946817916418, 0.03198449193899121, 0.020023933112887398, 0.027890579741714255, 0.06883942681763854, 0.032471914176962206, 0.05189537263608404, 0.06274439101772648, 0.104708606377244, 0.08686287754348346, 0.09840340792600598, 0.09957475614334856, 19.304399013519287, 84.29479490007672, 63.37852151053292, 67.93368407658168, 56.10696070534842, 35.631776332855225, 13.43352382523673, 32.37073312486921, 31.340447289603098, 45.633746419634136, 23.205600602286204, 0.06737302443278687, 0.022741333548245684, 0.2217984955225672, 0.16997516634208815, 0.6251012001718793, 0.6543823203870228, 1.2603789057050432, 0.6484410677637372, 1.4371138278927122, 41.49081005368914, 70.97102655683244, 70.28097316196987, 66.59430067879813, 66.26572731563023, 59.915094648088726, 56.29955087389265, 55.134539467947825, 57.317052023751394, 54.74851145063128, 60.104863848005024, 61.176977838788716, 65.39291545322963, 61.41808727809361, 60.716180256434846, 47.710931232997346, 46.01671722957066, 45.23860583986555, 55.510475226810996, 59.32961859021868, 61.80023125239781, 57.173675945826936, 59.23941012791225, 58.66944939749581, 54.578009605407715, 45.869992119925364, 42.71589905875069, 43.35070037841797, 54.96079281398228, 58.08115931919643, 56.267662116459434, 58.92968027932303, 57.22644404002598, 52.521912574768066, 48.73018332890102, 48.06614746366228, 51.06563268389021, 54.84090164729527, 57.305469376700266, 56.65745605741228, 56.27964081083025, 56.68950114931379, 58.23956782477242, 57.217296736580984, 57.751574993133545, 53.555811473301475, 59.53578553880964, 39.97308724267142, 33.93867056710379, 56.11975581305367, 51.93080847603934, 55.33985526221139, 53.74423272269112, 55.85811097281319, 46.29922751017979, 44.029191970825195, 39.59107181004116, 46.453029360089985, 46.266775948660715, 46.181177616119385, 45.07901266642979, 45.55261925288609, 42.904820578438894, 44.76950863429478, 45.197816440037315, 46.580042430332725, 42.78982441765921, 42.337597438267295, 42.47741256441389, 43.603604384831016, 42.88938168116978, 52.435782705034526, 54.04453386579241, 58.793759618486675, 57.87933152062552, 57.5755284854344, 57.86685603005545, 61.048484802246094, 60.12830012185233, 56.389140946524485, 44.22300502232143, 50.245071274893625, 57.78107009615217, 63.58073493412563, 58.76996898651123, 61.972720282418386, 59.78374590192522, 59.025607109069824, 63.8942654473441, 63.20178018297468, 63.58400058746338, 34.759978907448904, 0.5137466011302811, 0.8539556456463677, 3.072705554110663, 1.1208949046475547, 0.2292919648545129, 0.2299095131456852, 0.20765315741300583, 0.054008625846888335, 0.030354606719421487, 4.763563360486712, 32.68908568790981, 36.06314829417637, 72.35871383122036, 88.29275362832206, 43.2204772404262, 23.98763598714556, 47.147241251809255, 48.62325750078474, 55.16018874304635, 64.14872932434082, 19.81251903942653, 0.41890643164515495, 0.11048910048391138, 0.16384742515427725, 0.024097680945747664, 0.026879915402137806, 0.024367125505315404, 0.030217800488961593, 0.02461617160588503, 0.013518912884007608, 0.058318931343300004, 0.06300978641957045, 0.07433167246303388, 0.01828365194212113, 0.02045684863281037, 0.03495615301653743, 0.03254220701221909, 0.10706359786646706, 0.07144074687468153, 0.03893080080992409, 0.06660691768463169, 0.019657434296927283, 0.044945291110447476, 0.0423441542578595, 0.0284999974870256, 0.12685714289546013, 0.04743479538176741, 0.039917234663984606, 0.011832791530261082, 0.047046093203659566, 0.06305597429828984, 0.05735546589962073, 0.02555473311804235, 0.0631440549290606, 0.03323695562513811, 0.07120418242577996, 0.03971115679347089, 0.030620924928890805, 0.057826789894274304, 0.018650562968105078, 0.07141522717263017, 0.011401820861335312, 0.09898464102298021, 0.08995442558079958, 24.368723835263932, 95.88445963178361, 69.11675385066441, 74.4467100415911, 61.636246817452566, 43.91255603517805, 21.230837447302683, 29.515787805829728, 32.391813959394185, 47.18868725640433, 26.246604783194407, 0.08436077966221742, 0.03437025159863489, 0.45961812564304894, 0.7958872701440538, 1.3770680384976524, 2.113033175468445, 2.272758581808635, 0.6927076610071319, 2.179884833948953, 44.68453563962664, 71.76252365112305, 72.34935460771833, 68.04291670663017, 68.03678144727434, 63.634152684892925, 60.88574409484863, 58.11203016553606, 59.653362955365864, 57.42307111195156, 62.18134689331055, 65.99715859549386, 67.47824355534145, 64.62245750427246, 61.40753296443394, 48.63678911754063, 46.71112714494978, 47.38229881014143, 58.0808744430542, 61.65482630048479, 65.17944594791958, 57.42898402895246, 59.51405157361712, 60.75383949279785, 56.14831985746111, 48.71211453846523, 43.857456820351736, 45.81627559661865, 57.57603222983224, 60.31897258758545, 57.1948436328343, 59.781946318490164, 60.09969438825335, 55.034791128976, 52.315721307482036, 50.59788342884609, 53.50735821042742, 57.48519842965262, 62.086205210004536, 58.72811998639788, 57.900818824768066, 56.95321307863508, 59.978378840855186, 58.58249964032854, 57.08834511893136, 54.58819913864136, 62.38279601505825, 42.80065318516323, 34.86938871656145, 57.71939788545881, 53.89373016357422, 57.2564046723502, 56.81574991771153, 59.36197635105678, 49.85928297042847, 46.60401371547154, 42.26922716413225, 48.15312501362392, 49.862927300589426, 49.44620909009661, 47.424880845206125, 47.442574432918, 43.908804007938926, 47.31544671739851, 46.63478033883231, 50.35784748622349, 45.40453577041626, 45.153361865452354, 44.08833156313215, 45.65580000196184, 44.68739482334682, 53.70649010794503, 56.73366737365723, 61.280735288347515, 58.11773811067854, 57.57067516871861, 60.17223358154297, 63.63427080426897, 61.178666251046316, 59.56856713976179, 45.48510708127703, 52.94866050992693, 59.99717371804373, 66.22405202048165, 62.28585474831717, 64.53387492043632, 62.598433358328684, 62.737703050885884, 64.71383326394218, 64.8370109285627, 65.69468961443219, 42.436838558741975, 1.3301917995725359, 0.831950375011989, 0.9496702296393258, 2.1259791893618445, 2.11968976684979, 1.0452574661799838, 0.49740899779966896, 0.1426332720688411, 0.05653373285063675, 5.162191935947963, 34.55304765701294, 36.46013709477016, 63.240363529750276, 71.09227262224469, 40.63929441996983, 31.022219794137136, 53.449170521327424, 55.127643380846294, 62.13859462738037, 70.72866644178117, 30.611556938716344, 0.281845994825874, 0.12998433437730583, 0.09616287172372852, 0.043095645361713, 0.0492297613860241, 0.05362073112545269, 0.018448081333190203, 0.09701373428106308, 0.05411687253841332, 0.03658568200522235, 0.014103811766420091, 0.07319809829017945, 0.01205464533995837, 0.03265898288892848, 0.015383152224655663, 0.07309196184256248, 0.054079417405383925, 0.042816306065235815, 0.04916094097175768, 0.031248861591198614, 0.0274069250694343, 0.021772685793361495, 0.06160026562533208, 0.2394608977649893, 0.21278878540865012, 0.06771384578730379, 0.10849074700048991, 0.10376557840832643, 0.13654134395931447, 0.1452817978071315, 0.11706189279045377, 0.14333947774555, 0.12112483834581715, 0.1372363402375153, 0.15295035631528922, 0.14492465768541607, 0.1526840313204697, 0.1885716670325824, 0.08776765649339982, 0.25900951879365103, 0.1711493440504585, 0.1585703497486455, 0.28691714842404636, 28.953715017863683, 106.41079289572579, 78.32893957410539, 86.74883610861642, 68.91988359178815, 49.441446099962505, 20.19699934550694, 47.09405626569475, 44.70428589412144, 66.24133913857597, 37.01101459775652, 0.2680278463023049, 0.2350719975573676, 0.6810605259878295, 1.123704473887171, 2.3271230246339525, 2.8712397132601057, 6.327985014234271, 3.3026904932090213, 2.2552215456962585, 49.81317819867815, 73.2478609085083, 75.49315738677979, 71.57146903446743, 70.51493985312325, 65.44882065909249, 62.99728080204555, 61.13583755493164, 62.638058934892925, 58.976128986903596, 65.74142319815499, 67.255234173366, 69.43455750601632, 66.3133294241769, 65.54087039402553, 50.79149498258318, 49.902268001011436, 50.13676275525774, 61.341705730983186, 64.90733364650181, 66.97834151131767, 58.41863332475935, 62.60578455243792, 65.27175971439907, 59.56040300641741, 50.71858753476824, 47.759054456438335, 48.39562061854771, 59.26491696493966, 64.06303024291992, 59.68940326145717, 61.087964466639924, 62.75549738747733, 58.514886719839915, 53.93821947915213, 54.66347244807652, 56.17850978033883, 61.16429042816162, 65.6620122364589, 61.15322889600481, 59.153377532958984, 58.21823338099888, 60.35219192504883, 59.12121432168143, 59.59459509168352, 57.04541219983782, 63.19637448447091, 44.901090145111084, 40.330662386757986, 59.32979924338204, 55.34231492451259, 58.18545872824532, 59.00920936039516, 61.672863824026926, 52.74922636577061, 49.823857579912456, 44.856027603149414, 51.643767969948904, 52.9959534236363, 52.321964263916016, 51.00941480909075, 49.80575057438442, 46.652699742998394, 50.140959467206685, 48.87421948569161, 51.493575709206716, 46.812713282448904, 46.88521078654698, 47.399318422589985, 50.08998053414481, 48.01505388532366, 57.04595763342721, 59.49341542380196, 63.851019859313965, 61.344672611781526, 59.25204195295061, 62.08929715837751, 65.53421401977539, 64.75664111546108, 62.58571815490723, 48.413480963025776, 55.04933023452759, 60.720203263419016, 69.86221218109131, 65.63371222359794, 65.85727746146065, 66.0326430456979, 65.12474278041294, 69.94771671295166, 67.13845579964774, 69.89323588779995, 46.125661509377615, 1.2218405050890786, 4.680177160671779, 11.78050308568137, 4.988305883748191, 2.475005009344646, 1.1335756927728653, 0.7863929367491177, 0.24351498165300914, 0.23436233135206358, 8.458536335400172, 49.378502368927, 48.552587372916086, 81.4868471963065, 97.48169067927769, 52.406172956739155, 34.12439591544015, 62.42939758300781, 64.76931462969098, 69.67876584189278, 79.09784807477678, 30.487107753753662, 0.5762921678168433, 0.2161178681999445, 0.1914996134915522, 0.09674642541046653, 0.2156968236501728, 0.11593669173972947, 0.07281188294291496, 0.1370425506361893, 0.10486412660351821, 0.15413708692150457, 0.12644998117216996, 0.18544115072914533, 0.11058075020888022, 0.09229788197470562, 0.12020398490130901, 0.1506828958434718, 0.1794283262320927, 0.10839301081640379, 0.11371128008301769, 0.14777936307447298, 0.11784098669886589, 0.14717526334737027, 0.13461918995848723], [0.026991286747423664, 0.028742034320852587, 0.03653588092752865, 0.058918695231633525, 0.021417187726391212, 0.03704026993364096, 0.025978116917290857, 0.11921959343765463, 0.03521734828661595, 0.04085435259288975, 0.037965564389846156, 0.040114983517144404, 0.036058694390313964, 0.024847764089437466, 0.04801031521388462, 0.03128599442009415, 0.0760238573753408, 0.018736672454646656, 0.010239005221852233, 0.3431419442806925, 53.3038524218968, 75.81665856497628, 67.00194454193115, 69.22679941994804, 52.64797374180385, 33.12599883760725, 27.372160843440465, 41.30267020634243, 38.61458935056414, 41.63549239294869, 5.346995779446193, 0.16342114231416158, 0.07048346967037235, 0.4216324325118746, 0.36312816611358095, 0.3848782261567456, 0.8860985008733613, 1.0205702994550978, 0.21923727009977612, 23.327602284295217, 67.67214693341936, 68.12693432399205, 72.44644873482841, 66.95506504603794, 64.42280101776123, 61.21044731140137, 62.96945326668875, 59.961202893938335, 59.3874762398856, 61.682320322309224, 61.77407128470284, 67.89120973859514, 62.40901851654053, 62.74866036006382, 54.43269150597708, 44.8284467288426, 45.73837586811611, 47.35491248539516, 57.26195280892508, 57.48290205001831, 59.84527914864676, 57.05301352909633, 58.94099889482771, 56.67838403156826, 51.34728833607265, 42.12614985874721, 41.05487659999302, 42.6719308580671, 53.10174322128296, 57.898734365190776, 56.10844414574759, 50.88493088313511, 58.07590300696236, 54.71154008592878, 52.382135663713726, 52.872414452689036, 54.253368922642295, 53.369884627205984, 58.02702937807356, 59.584040778023855, 55.950365679604666, 52.82087966373989, 58.1397500038147, 56.76708473478045, 62.594806398664204, 54.59548085076468, 61.558204650878906, 40.14442981992449, 34.24639933449881, 56.91609927586147, 53.07679918834141, 55.233172621045796, 53.83085591452462, 55.343173027038574, 49.2640585899353, 44.84731108801705, 41.851702962602886, 46.042369978768484, 50.96804870877947, 53.71857302529471, 52.844441005161826, 52.91181421279907, 49.57147816249302, 50.43110581806728, 53.132499422345845, 52.73781047548567, 51.07930326461792, 42.76514441626412, 41.67151880264282, 43.11006341661726, 41.44177314213344, 44.71363122122628, 52.21427413395473, 53.52932494027274, 59.40360300881522, 54.42492341995239, 53.2792523247855, 60.42139598301479, 58.036666529519216, 54.44774825232369, 45.18132489068167, 45.02200269699097, 54.47512762887137, 58.680663790021626, 59.66235392434256, 60.56682177952358, 56.949957847595215, 57.72839232853481, 58.43825503758022, 62.416098730904714, 60.923820223127095, 69.02526691981724, 39.13998086111886, 0.19886808310236248, 2.392707939658846, 2.624845083270754, 1.500687456556729, 0.7378345823713711, 0.34079823004347937, 0.056145274945135625, 0.0590732858649322, 0.07963362974779946, 13.995557529585701, 37.92666210447039, 31.898721149989537, 69.71315247671944, 68.74881199428013, 21.680821895599365, 43.380452564784456, 47.65105513163975, 55.95319707053048, 53.72839082990374, 64.04586124420166, 3.6268762860979353, 0.44588647676365717, 0.0741823540468301, 0.04424601327627897, 0.07692689249025923, 0.005711799221379417, 0.023750757865075554, 0.011470457222977919, 0.0375560820767922, 0.03842607932165265, 0.032362636112208874, 0.05781673400529793, 0.042576813737728765, 0.034281736705452204, 0.01695832546933421, 0.031126199423202446, 0.013133636459575167, 0.05323044117540121, 0.0555202627687582, 0.02477714216469654, 0.04215079213359526, 0.05088228253381593, 0.017334349220618606, 0.03571424626612237, 0.02285990075740431, 0.004231030553845423, 0.04406912937494261, 0.009717948851175606, 0.055033410500202856, 0.03053557200889502, 0.039391865355095694, 0.06485432279961449, 0.009855511648181294, 0.0336533454246819, 0.03149268636479974, 0.0823041671620948, 0.022516981033342223, 0.033189468351858, 0.045425714259701114, 0.026283216795751026, 0.011568474999096776, 0.03096521020467792, 0.8337046865906034, 63.93152168818882, 86.04831872667584, 73.38403865269252, 78.51196207318986, 60.506018093654085, 45.22171824319022, 25.382370471954346, 34.86874600819179, 44.8630313873291, 43.15878071103777, 7.338195766721453, 0.1203157939016819, 0.05400038164641176, 1.165819676859038, 1.883545683962958, 1.3347612172365189, 2.801679560116359, 1.8547115283352988, 0.8292625620961189, 26.466100113732473, 67.49131311689104, 70.24655873434884, 74.88687842232841, 69.64707510811942, 65.9342565536499, 64.53231157575334, 66.97090693882534, 62.146682330540244, 62.05659198760986, 62.12205791473389, 64.54468631744385, 69.58553491319928, 65.55762250082833, 64.45265742710659, 59.55984715053013, 46.756512778145925, 47.520098958696636, 49.54829549789429, 59.28359372275216, 58.79853303091866, 62.68256909506661, 58.156151226588655, 61.42906543186733, 59.03905882154192, 52.67010375431606, 43.940831729343955, 43.257896763937815, 45.14007690974644, 55.15045084272112, 59.333113534109934, 58.731211934770855, 54.44186660221645, 60.36291994367327, 57.938759463174, 56.092591830662315, 56.28154114314488, 55.69008616038731, 55.172997747148784, 61.661524363926475, 60.583942140851704, 57.450610297066824, 56.238483156476704, 60.28008352007185, 57.46328033719744, 63.61306490216936, 58.336248534066335, 63.0392826625279, 42.26605183737618, 36.836034638541086, 60.53057997567313, 54.772333349500386, 56.585649899074006, 56.386028153555735, 59.31970351082938, 51.42346143722534, 46.703372955322266, 43.31645965576172, 48.327007157461985, 54.541538511003765, 57.57676179068429, 58.14544057846069, 55.59472908292498, 52.842999253954204, 52.34430619648525, 55.79980516433716, 54.90413720267159, 53.37419251033238, 44.42275183541434, 44.45014163425991, 44.750116212027415, 43.93822962897164, 46.63145215170724, 54.89687286104475, 56.493773869105745, 61.11314473833357, 55.10154594693865, 56.03032554898943, 62.15698650905064, 60.55585057394845, 57.38567590713501, 49.51286315917969, 46.660169056483674, 56.46957676751273, 60.45558112008231, 61.48792362213135, 62.42219230106899, 60.662637438092915, 61.25267151423863, 60.75546537126814, 63.570062501089915, 65.17252554212297, 69.31450653076172, 47.61486196517944, 0.5683785496013505, 0.5453039620603833, 0.6390795101012502, 1.9344036749431064, 2.170057258435658, 0.6708529708640916, 0.36344265352402416, 0.22029893313135418, 0.0163282819557935, 16.415713242122106, 40.18397201810564, 26.78576762335641, 69.00668743678501, 60.97921126229422, 27.47319459915161, 55.878840923309326, 55.270369802202495, 62.99027006966727, 60.325323241097585, 75.23029313768659, 7.680565646716526, 0.6263299456664494, 0.113517537979143, 0.08723363586302314, 0.031217330068882023, 0.03684452275878616, 0.03428347036242485, 0.02140733879059553, 0.05408784820299063, 0.01987857055584235, 0.06041907186486891, 0.02936540444248489, 0.03246533577995641, 0.015274997135358197, 0.009046686879758323, 0.033276524394750595, 0.029558929415153604, 0.027429991867393255, 0.004905081728273737, 0.031222480149673562, 0.09165247303566762, 0.03608807495662144, 0.025967092419575368, 0.1059388310781547, 0.08968887411590133, 0.13628255070320197, 0.153445374752794, 0.14736640666212353, 0.2359245903789997, 0.12780204362102918, 0.14817003639680998, 0.17075515591672488, 0.07920353354087897, 0.14019715493278845, 0.14320742126022065, 0.12856000794896058, 0.102803198620677, 0.20412420534661838, 0.12083323113620281, 0.12827210554054805, 0.04271297535992094, 0.1102435454460127, 1.1079534505094801, 75.82464899335588, 93.8839829308646, 85.85832023620605, 86.38286754063198, 68.25692817143032, 47.70952769688198, 40.64754540579659, 57.45676987511771, 54.71109192711966, 63.56426075526646, 8.913018873759679, 0.2336912059358188, 0.20639782691640512, 1.9755921619279044, 2.0770777676786696, 2.2476712422711507, 4.363300221306937, 6.071830987930298, 1.71776068849223, 28.59954101698739, 69.69050829751151, 70.93943309783936, 76.69033200400216, 71.77816404615129, 69.17729350498745, 66.92903709411621, 68.73119831085205, 65.3784076145717, 65.51620428902763, 66.10724585396903, 66.17239911215646, 71.90961701529366, 67.78774411337716, 68.62118748256138, 61.977118492126465, 50.37595101765224, 51.04326295852661, 53.16452019555228, 62.53437096732003, 61.08163465772356, 64.03200653621128, 59.951718602861675, 63.673806054251536, 63.614815848214285, 54.27875764029366, 46.57229518890381, 44.67078515461513, 47.315707274845664, 56.789569105420796, 63.732740674700054, 60.18069648742676, 56.18312338420323, 62.43556758335659, 60.88270078386579, 57.336861337934224, 59.05392101832798, 57.67110790525164, 57.639135769435335, 63.50388090951102, 63.158555439540315, 59.84976768493652, 59.40984943934849, 61.767685890197754, 60.67892401559012, 64.55779061998639, 59.84907981327602, 62.60444355010986, 44.23908315386091, 41.28364256450108, 63.07766451154436, 58.1147677557809, 60.04159355163574, 59.414407457624165, 59.97267436981201, 54.6305136680603, 50.36597340447562, 45.33652332850865, 51.814648491995676, 56.93186126436506, 59.586417061941965, 60.33746174403599, 58.939908027648926, 55.327754974365234, 54.96430860246931, 58.20594549179077, 57.06953634534563, 57.09539406640189, 47.11184712818691, 46.447026116507395, 47.95170368467058, 46.46230867930821, 50.40843384606497, 58.507966314043315, 60.09044633592878, 64.02547522953579, 55.431574957711355, 56.276118074144634, 65.93124798366001, 61.810194969177246, 59.32419899531773, 51.256770678928916, 49.844719546181814, 59.25494629996163, 62.751175607953755, 64.37765162331718, 66.2990369796753, 62.98635128566197, 62.453452246529714, 64.40825843811035, 67.29828521183559, 66.55232661111015, 73.27269377027238, 49.76416907991682, 0.5381979090826852, 6.528022348880768, 7.880758881568909, 5.599937566689082, 3.8455052631241933, 1.0972284717219216, 0.821807253573622, 0.30137320128934725, 0.2232160230300256, 21.819461039134435, 56.05551624298096, 43.013153416769846, 74.63404737200055, 76.02989877973283, 30.623021466391428, 58.78630420139858, 61.37741947174072, 73.31404944828579, 68.4531591960362, 84.40536853245327, 7.949649402073451, 0.6669504716992378, 0.2713516636618546, 0.1510371318353074, 0.16851240769028664, 0.1125140864668148, 0.10869581385382585, 0.11626492626965046, 0.13638305531016418, 0.07776212838611432, 0.08637571654149465, 0.13143494725227356, 0.0790665712473648, 0.10515617486089468, 0.1020119453647307, 0.1137258278738175, 0.10985675334398236, 0.11353807723415749, 0.18590205242591246, 0.15109217459602015, 0.1490236334502697, 0.13799197040498257, 0.10540675784328155], [0.024841329881123135, 0.05622905705656324, 0.04999462641509516, 0.029656292404979467, 0.0792712988331914, 0.02923407738230058, 0.027968836881752526, 0.04028521438262292, 0.0378249244365309, 0.02800946925500674, 0.0396892638610942, 0.0542178419418633, 0.04399298417514988, 0.10565170219966344, 0.04020188349698271, 0.09945325766290937, 0.07020041878734316, 0.0454830029713256, 0.15959115140140057, 5.6309851578303745, 77.62341254098075, 63.41308879852295, 67.46975285666329, 46.75109665734427, 22.87127239363534, 12.861343145370483, 34.0935389654977, 25.017914874213083, 38.71450792040144, 29.26954017366682, 0.38978826840009007, 0.06641868528510843, 0.25225277564355303, 0.6971388746585164, 0.46150846992220196, 0.7181821997676576, 2.422388038464955, 1.2158891558647156, 8.382265959467206, 59.71030344281878, 65.65276418413434, 69.1904742377145, 69.90586076463971, 68.57114655630929, 66.33206871577671, 66.25645841870988, 62.96148368290493, 60.97921821049282, 62.35785893031529, 62.12114075251988, 65.52218668801444, 61.88892500741141, 60.70163072858538, 60.705855233328684, 49.272782053266255, 43.835083620888845, 44.78881767817906, 54.21757180350167, 57.74246937888009, 59.35900947025844, 58.9686735698155, 55.58709648677281, 59.22126143319266, 52.20521368299212, 48.6173689024789, 40.847299167088096, 42.3621141569955, 41.27026033401489, 52.84817566190447, 54.119220052446636, 55.843714305332725, 53.188355990818565, 57.071228231702534, 56.45397458757673, 58.903110367911204, 55.55530153002058, 57.07098157065255, 58.04463611330305, 60.94888932364327, 54.346332345690044, 52.15301186697823, 51.933455739702495, 56.216085638318745, 53.651342255728586, 55.324169703892295, 50.52722372327532, 58.33970873696463, 37.14992298398699, 32.74330595561436, 59.388747760227744, 50.87693698065621, 57.68165179661342, 55.319736753191265, 58.70328712463379, 49.817194257463726, 42.18173197337559, 40.76476846422468, 43.51811374936785, 51.3478615624564, 55.42283064978463, 58.24354566846575, 56.01590803691319, 56.13523639951433, 57.00277805328369, 57.59246819359915, 57.905269145965576, 56.990347726004465, 46.36649649483817, 41.38670866830008, 41.14019005639212, 41.10274274008614, 40.43708099637713, 46.432629449026926, 53.84957783562796, 57.09289966310774, 55.36517449787685, 51.80708885192871, 58.60608182634626, 56.99017402103969, 53.015311104910715, 45.86960996900286, 45.07336378097534, 47.28267553874424, 54.64941624232701, 58.22476816177368, 52.36744717189244, 55.47790902001517, 57.34516096115112, 55.74392080307007, 56.17393786566598, 62.80148751395089, 60.5897091456822, 70.52741881779262, 40.624685832432334, 0.0823301211265581, 1.4309068066733224, 2.123411829982485, 1.4027485804898399, 0.24519978410431317, 0.34755812159606386, 0.0966766584398491, 0.06814438982733659, 2.5760936992509023, 27.09491034916469, 36.334315640585764, 57.55879374912807, 82.25070435660226, 29.928792204175675, 20.34991877419608, 38.359336853027344, 41.07887915202549, 56.47470453807286, 57.65362971169608, 43.24445199966431, 0.8968924731016159, 0.0433904382932399, 0.03131827911628144, 0.05771227353917701, 0.04747763469016977, 0.02519902809789138, 0.06256839938993965, 0.0015751078296619067, 0.06535074580460787, 0.08398381953260728, 0.04105397420270102, 0.03686445811763406, 0.10749808419495821, 0.04374861657353384, 0.03770270331629685, 0.026772472774609923, 0.012352931878662534, 0.059869865620774884, 0.029022764614117996, 0.04515536555222102, 0.021350404613518288, 0.015186741781820143, 0.03084977443463036, 0.049723860408578596, 0.03582777535276754, 0.033938509944294176, 0.1081967649183103, 0.06773945369890758, 0.05006817961111665, 0.04337180572162781, 0.028346022624256353, 0.024665587614955645, 0.054550734614687305, 0.044478662578122954, 0.030182475955890756, 0.016829303731875758, 0.0537178668060473, 0.09306379873305559, 0.06173973171306508, 0.07811033898698432, 0.13678149107311452, 7.9864661693573, 89.368056842259, 71.37585639953613, 74.78637967790876, 56.06231505530221, 35.01521750858852, 21.14652453150068, 29.806809629712784, 28.724671125411987, 38.178589888981406, 32.63991676058088, 0.39540485558765276, 0.0695952537602612, 0.4081455176430089, 1.9641215545790536, 1.5757137792451041, 2.0036114241395677, 2.753593683242798, 1.2334236949682236, 10.352935756955828, 60.68956170763288, 67.23943396977016, 70.53221307482038, 72.5257763181414, 69.73680414472307, 69.37068966456822, 68.02945804595947, 65.08454745156425, 63.37749317714146, 64.23749256134033, 65.28387042454311, 67.95151315416608, 65.08467251913888, 63.29328795841762, 62.96133082253592, 54.06109837123326, 45.550145694187705, 46.26362146650042, 55.84361008235386, 60.136582374572754, 61.23672539847237, 59.22308186122349, 57.55633756092617, 61.12255259922573, 56.874872139522004, 50.85283020564488, 43.442864758627756, 43.67277717590332, 44.23461546216692, 53.94510514395577, 57.408747400556294, 59.255946840558735, 53.4557991027832, 57.500390665871755, 59.74601718357631, 60.079746110098704, 60.113208634512766, 59.736637115478516, 58.75722599029541, 62.33038575308663, 55.1465494292123, 54.381868907383506, 54.462509700230186, 58.12290757043021, 54.882170472826274, 57.03345782416207, 53.30007955006191, 58.41611112867083, 39.184477124895366, 35.81624753134591, 60.342533929007395, 53.19072880063738, 59.95873628343855, 57.7809728213719, 59.90888295854841, 52.31464433670044, 44.13663196563721, 42.90388951982771, 45.950292451041086, 54.226024287087576, 57.14890909194946, 59.73452486310686, 59.31778580801827, 58.59680598122733, 61.01601587023054, 58.23853254318237, 61.217590059552876, 58.939032554626465, 48.159277643476216, 44.16801003047398, 43.14511707850865, 43.0567672593253, 42.993420532771516, 47.79468134471348, 55.63096393857683, 60.07840510777065, 56.27043097359793, 53.782069138118196, 61.662142753601074, 59.49434648241316, 56.68636056355068, 49.050418853759766, 47.169329575129915, 49.07009267807007, 58.217163358415874, 61.48297650473458, 56.328118392399375, 58.85896846226284, 59.40447153363909, 58.39614200592041, 58.49705069405692, 65.89964757646833, 63.540185247148784, 70.80028847285679, 49.14616503034319, 0.17967083464775765, 1.1225459703377314, 0.8610151782631874, 2.018110143286841, 1.835371000426156, 1.0879747739859988, 0.3531607581036431, 0.01594695884601346, 1.8621404554162706, 34.19004249572754, 35.03868504932949, 56.30003029959542, 69.61623900277274, 34.29678072248186, 33.62234687805176, 45.102014677865164, 46.86311204092843, 61.347160066877095, 63.826409339904785, 55.498204708099365, 1.2661082382713045, 0.11798631532916001, 0.05826766123729093, 0.06423197726586036, 0.01271205417080117, 0.032913630296077044, 0.06704407065574612, 0.032237561752221415, 0.07054615952074528, 0.01038741779380611, 0.017713684222794006, 0.030843229964375496, 0.05190640900816236, 0.027402755471744707, 0.05366253906062671, 0.025420389969700148, 0.04355812804507358, 0.023357214339609658, 0.04733925086579152, 0.044376929822776995, 0.03840442726920758, 0.017950577761179635, 0.06399874442390033, 0.1418165330375944, 0.1478329673409462, 0.15980638270931585, 0.21373982009078774, 0.10733736639044114, 0.1376655814903123, 0.14251693045454367, 0.12712901830673218, 0.06268869007804564, 0.11538215221038886, 0.14582086673804692, 0.12101176727030959, 0.16932446482990468, 0.1635244424854006, 0.12843515750552925, 0.12784141222281115, 0.17535898887685367, 0.2854323238134384, 9.523584008216858, 100.28905473436627, 78.37465177263532, 86.56686278751918, 61.67951325007847, 38.56822749546596, 21.17990367753165, 49.42373514175415, 36.581237248011995, 53.82415785108294, 42.96554436002459, 0.8083625435829163, 0.11219653207808733, 0.6978553533554077, 2.421931194407599, 2.428485951253346, 2.96553111076355, 7.686013034411839, 4.697948481355395, 8.988488469805036, 66.77178546360561, 69.07752432141984, 74.3033756528582, 75.04485961369106, 73.19488089425224, 70.977217401777, 71.22928415025983, 67.22400896889823, 67.01228346143449, 66.89303847721645, 68.41699382237026, 68.63880116598946, 66.81209196363176, 66.7660254069737, 66.77853216443742, 54.63009330204555, 48.65765108380999, 49.273716585976736, 58.83622006007603, 61.42850957598005, 64.3231430053711, 60.38624504634312, 60.60179206303188, 64.52596092224121, 60.34357615879604, 53.87553630556379, 44.20366818564278, 47.98780999864851, 46.55435841424124, 57.80283185413906, 58.90044920785086, 61.18091746738979, 54.524643966129844, 59.02532918112618, 61.722751889910015, 62.046107155936106, 62.961712973458425, 61.86539145878383, 61.537957600184846, 63.8821964263916, 59.11027090890067, 55.40860768726894, 54.95328875950405, 58.928012711661204, 56.49225221361433, 60.51027733939034, 55.299267360142295, 59.2582744870867, 42.097947120666504, 42.33913993835449, 64.3611843926566, 57.30052573340279, 62.0285073689052, 60.122991698128835, 63.045098304748535, 54.86696434020996, 44.795685972486226, 45.201669216156006, 46.80529955455235, 57.29816334588187, 59.6444206237793, 62.9879424231393, 60.35622188023159, 61.77996335710798, 62.903445380074636, 62.50988551548549, 64.70959486280168, 62.19142178126744, 52.21751894269671, 45.77328361783709, 44.56967496871948, 45.7155510357448, 44.43552609852382, 51.349296365465435, 59.64025170462472, 64.96173804146903, 58.008074692317415, 53.24354553222656, 63.423948832920615, 63.04749543326241, 58.55618681226458, 50.485353878566194, 49.773125307900564, 51.991271700177876, 59.746496609279085, 64.15232154301235, 59.392513683864046, 61.74755695887974, 63.01713180541992, 62.22589874267578, 61.789211409432546, 69.8409229006086, 66.26207951136998, 74.34951863970075, 51.04532657350813, 0.20543537927525385, 5.890658012458256, 7.385290656770978, 4.919816621712275, 3.204299658536911, 0.9073045658213752, 0.38811293829764637, 0.12441633029707841, 3.1302032002380917, 43.634638513837544, 53.975670269557405, 62.11977890559605, 86.04348972865513, 39.3945072719029, 30.71472031729562, 52.42593363353184, 55.5313788822719, 72.24706322806222, 71.8490217753819, 62.37964848109654, 1.546844448362078, 0.19385337004704134, 0.10963791222976786, 0.19046256771045073, 0.1622791135949748, 0.09337344140346561, 0.16265150718390942, 0.09391561123941626, 0.21212619596293994, 0.11610680046890463, 0.1589301632983344, 0.09256235456892423, 0.1847678811422416, 0.17802265951676027, 0.2170658494744982, 0.10371595035706248, 0.17542073556355067, 0.11335807546441044, 0.1868876245404993, 0.1354896689632109, 0.15673750452697277, 0.07897821920258657], [0.027384640283084342, 0.06355956263308014, 0.04130694902102862, 0.03413656413821237, 0.022279319054047977, 0.045375675694750886, 0.03052676123167787, 0.022216576617211103, 0.0242356457747519, 0.05207505549437233, 0.046639576088637114, 0.05110115757478135, 0.026633408718875477, 0.0581896568515471, 0.012525722517498901, 0.043648122144596915, 0.03900689511959042, 0.07276434477950845, 0.1104183564228671, 22.70515833582197, 77.12021010262626, 64.13424233027867, 76.05922017778668, 50.22924327850342, 31.57553264072963, 26.229451417922974, 45.4791316304888, 36.90971681049892, 55.78929948806763, 8.998393126896449, 0.08210916298308543, 0.08105038372533661, 0.2194951269775629, 0.7047121397086552, 1.2184439216341292, 0.6654973753861019, 1.7698873771088464, 0.4455419438225882, 38.220143590654644, 66.17914581298828, 69.00580501556396, 67.27671800340924, 66.98456014905656, 67.89990193503243, 64.5755363191877, 65.93105343409947, 65.59689371926444, 61.022880690438406, 64.49893242972237, 63.34282166617257, 64.85663264138358, 56.46166276931763, 60.5111528124128, 58.84833771841866, 47.31742695399693, 41.393410205841064, 50.75404071807861, 55.713560649326865, 57.35850845064436, 57.0833945274353, 56.612959793635774, 56.79619768687657, 54.93414299828665, 49.821067878178184, 42.94563429696219, 42.93769598007202, 39.72106565747942, 42.51937273570469, 48.43669836861746, 54.035654067993164, 56.07520743778774, 54.678063665117534, 54.32597064971924, 51.570818832942415, 52.925408363342285, 54.759743213653564, 56.23470333644322, 52.08399541037423, 50.4200963973999, 47.813677719661165, 56.522219794137136, 56.36943932941982, 54.9307279586792, 55.813218661717, 55.42427240099226, 52.23536191667829, 56.58593477521624, 37.50309297016689, 32.1252497945513, 58.29242624555315, 44.748983655657085, 51.04676137651716, 49.16095079694475, 53.11605651038033, 44.434136458805625, 41.99878243037632, 38.601071630205425, 41.40278679983956, 44.72927509035383, 58.348331451416016, 55.26876824242728, 55.969066756112234, 51.52252885273525, 54.18699278150286, 51.4587721824646, 52.35065337589809, 56.71411166872297, 46.667801652635845, 41.23511634554182, 42.39655637741089, 40.29554966517857, 40.65693589619228, 42.47157607759748, 51.81291144234793, 55.88698768615723, 57.58034358705793, 51.72957474844796, 58.37130914415632, 55.20877749579293, 52.723736899239675, 44.81763185773577, 44.514040742601665, 45.39306429454258, 47.94456788471767, 51.838303634098594, 58.280673367636545, 50.90928084509713, 55.442045892987935, 53.13407318932669, 55.25411449159895, 56.179708344595774, 62.25264235905239, 59.25052029745919, 69.28558118002755, 44.599791935511995, 0.22714495791920594, 0.8644560022013528, 1.0924304148980548, 0.7796089979154723, 0.5217387665595327, 0.3653555251657963, 0.17127004185957567, 0.0499028850878988, 13.170112405504499, 23.571930476597377, 50.1536989893232, 47.01315491540091, 25.735373701368058, 14.595658676964895, 36.10627228873116, 50.07416296005249, 51.98147126606533, 47.258805002485005, 60.92214570726667, 24.325995888028825, 0.6556424413408551, 0.05568958439731172, 0.05474438511633447, 0.025530059888426746, 0.050412956824792285, 0.009448722270982606, 0.021778322723028914, 0.04230090782844594, 0.012131492823495396, 0.0250152994745544, 0.030914676309164082, 0.06645989271679095, 0.004227539067090089, 0.03439064496862037, 0.020044933771714568, 0.07268938701599836, 0.04075568342315299, 0.019399574026465416, 0.03093352261930704, 0.05135482110615287, 0.05054035855989371, 0.028417219607425586, 0.04007262596860528, 0.01139813132717141, 0.05352573622284191, 0.07142908285771098, 0.021435414873329655, 0.03289458042542849, 0.06541671297912087, 0.01715431691679571, 0.0718753756955266, 0.008599152322858572, 0.001644537123086463, 0.02603487128258816, 0.08641902743173496, 0.005807423465219992, 0.05872375212077584, 0.023701497919059226, 0.06803208549640008, 0.08786155895463058, 28.75970046860831, 90.15161909375871, 71.56614671434674, 84.97300161634172, 56.409044061388286, 36.469256605420796, 20.368152584348405, 43.08847188949585, 36.931586265563965, 53.63323872429984, 11.04875441959926, 0.15096382291189261, 0.1025662338361144, 1.1684479415416718, 1.6255572246653693, 2.8411214436803545, 2.5348494095461707, 1.2927703218800681, 1.54371135362557, 39.37587915148054, 68.73728493281773, 68.39465536390031, 69.73425415584019, 68.69865989685059, 70.33155604771206, 66.53815228598458, 68.71385560716901, 69.09799371446881, 63.69490078517369, 67.55751555306571, 65.15469646453857, 63.468591008867534, 60.332208905901226, 62.87841796875, 61.13068199157715, 51.47546175548008, 44.241761684417725, 52.703225816999165, 58.73100348881313, 60.76319176810128, 59.483187675476074, 58.08607169560024, 59.36432484218052, 58.70086220332554, 51.80564362662179, 45.33949020930699, 44.22038555145264, 42.27092252458845, 44.331963198525564, 50.69419240951538, 56.00909880229405, 57.8405327796936, 55.81978818348476, 53.64877142224993, 53.054651805332725, 54.933750425066265, 55.128365993499756, 57.303016662597656, 51.52352591923305, 52.550810132707866, 50.38015120370047, 58.315925053187776, 56.52366501944405, 57.24569402422224, 56.348890032087056, 56.67884956087385, 54.336024693080354, 57.55015366418021, 39.24646200452532, 35.00989866256714, 60.834216254098074, 46.54459966932024, 52.34624126979283, 53.90628555842808, 55.45993403026036, 45.5353217124939, 45.372820717947825, 40.7765109198434, 42.68232536315918, 47.05325991766793, 58.91542952401297, 57.11628035136631, 57.6472338948931, 52.48407963344029, 54.3103962625776, 53.34952640533447, 57.674543789454866, 58.41185188293457, 49.80746677943638, 42.482415267399375, 44.86792639323643, 42.23703963415963, 44.049404280526296, 44.444256510053364, 54.70570012501308, 59.86688804626465, 59.57482746669224, 53.70691047395979, 60.62597874232701, 56.827912739345, 56.24810988562447, 47.68110261644636, 47.709652764456614, 47.25931569508144, 49.16894817352295, 53.66609328133719, 59.598722321646555, 54.34802770614624, 58.70683070591518, 56.924218245915, 58.25296395165579, 58.907682282584055, 64.73016153063092, 61.5017922265189, 71.11001137324742, 51.70559304101126, 0.1565074540142502, 0.9506299495697021, 0.338911875550236, 1.9558130289827074, 1.406841937984739, 0.5656735290374074, 0.33300653100013733, 0.17833656338708742, 17.217250483376638, 31.37763057436262, 44.42076465061733, 49.33167151042393, 20.11131763458252, 18.607996702194214, 45.15119055339268, 56.4706745828901, 59.30035277775356, 53.65346145629883, 68.42130865369523, 33.91563728877476, 0.509937196969986, 0.06067071336188486, 0.05649254916767989, 0.0225410418851035, 0.03847252165100404, 0.09825114466782127, 0.017178791674918363, 0.039462731552443335, 0.0390277363226882, 0.05960942352456706, 0.05261712694274528, 0.0705704442890627, 0.026625391827630143, 0.028807370457798243, 0.052686096634715796, 0.041417428092764955, 0.051759244940642796, 0.040497948681669574, 0.0596208975517324, 0.04113721348611372, 0.037104072581444464, 0.11259842836963278, 0.14126833102532796, 0.13156384176441602, 0.1576597150415182, 0.13660189642437867, 0.11764327516513211, 0.11759465134569577, 0.11587490434093134, 0.14685901174587862, 0.20510046796074935, 0.15462637852345193, 0.1351890100964478, 0.15260248498192855, 0.19786132712449345, 0.11107017073248114, 0.09804989796664033, 0.2506085495863642, 0.13350114066685947, 0.32786255702376366, 35.658050945826936, 101.10965088435582, 78.98914350782121, 94.826902117048, 64.42706026349748, 44.48606382097517, 37.44544724055699, 64.8807567868914, 49.6669533593314, 79.46338585444859, 13.858568583215986, 0.27838698614920887, 0.2550470914159502, 1.6643670392887933, 2.9428098499774933, 4.159644612244197, 6.115357543740954, 6.346447680677686, 2.2113021995340074, 40.8658195904323, 72.64045633588518, 69.34526620592389, 71.76888820103237, 70.78295966557094, 73.94478607177734, 68.48511396135602, 71.53164196014404, 68.8610531943185, 66.37363978794643, 69.52232715061733, 67.09930964878627, 64.94474274771554, 61.406046049935476, 67.3006545475551, 62.91265174320766, 54.41534880229405, 47.119021143232075, 56.5764331136431, 62.137343951633994, 63.686048780168804, 59.36568668910435, 58.44174998147147, 61.75455379486084, 60.68938800266811, 54.27115978513445, 48.19538395745413, 47.9517696925572, 44.83014556339809, 47.422143254961284, 53.919195311410085, 57.56644718987601, 60.38532788412911, 56.22241544723511, 56.32853528431484, 54.1993362562997, 54.150587694985525, 58.112464427948, 60.292659759521484, 53.145944186619346, 53.1697313444955, 51.75295891080584, 59.11494009835379, 57.98061888558524, 59.09270586286272, 59.62522275107247, 58.443730218069895, 56.80698129108974, 57.37672315325056, 42.38293790817261, 40.25561836787632, 62.80298832484654, 50.48420742579869, 55.01500265938895, 57.15913336617606, 56.73075260434832, 50.146045548575266, 45.93428380148751, 42.151441301618306, 44.45081908362252, 49.26043510437012, 63.25969341823033, 59.997680936540874, 58.26012059620449, 55.11848218100411, 56.43564871379307, 56.38898808615548, 59.29746927533831, 62.119396754673545, 52.8612973349435, 45.68187311717442, 47.231672286987305, 45.44109719140189, 46.52537400381905, 47.5341134752546, 57.48900951657976, 62.48931189945766, 59.91129398345947, 52.7659888948713, 63.30542646135603, 59.95457431248256, 57.95855835505894, 51.33403812135969, 49.3643593106951, 50.58310113634382, 51.72594084058489, 56.787328311375205, 62.93546267918178, 56.18465198789324, 60.297752789088655, 59.250603675842285, 60.41069575718471, 61.665658542088096, 66.97988401140485, 64.7774579184396, 71.52247728620256, 54.460974148341585, 0.28585515969565933, 6.627658648150308, 8.981334430830819, 3.6786282062530518, 2.4515333431107655, 1.1409391547952379, 0.608286396733352, 0.5275139138102531, 21.135947636195592, 40.18482664653233, 60.40203135354178, 51.97901507786342, 31.80977725982666, 22.251489605222428, 49.28338500431606, 64.82554640088762, 69.38528088160923, 60.52012293679373, 76.93408870697021, 37.43097414289202, 0.7653110708509172, 0.12887209334543773, 0.1639647710004023, 0.10040558156158243, 0.10534703997629029, 0.1076631039114935, 0.16713428949671133, 0.12772399852318422, 0.11425593335713659, 0.0852215149040733, 0.10376780400318758, 0.1364139150828123, 0.08284859651965754, 0.12481482034283024, 0.10455181050513472, 0.1695841130401407, 0.11626341992190906, 0.13153877668082714, 0.1242247527199132, 0.07550343458673783, 0.16151872011167662], [0.04415516761530723, 0.04712833504059485, 0.021509270017434443, 0.020521372224071195, 0.00454883006334837, 0.025395285870347704, 0.04940465378708073, 0.029292716378612176, 0.020292275053049837, 0.030526839263205017, 0.02913053972380502, 0.05388535978272557, 0.024249540475596274, 0.0440289227824126, 0.04343901461522494, 0.08313273984406676, 0.028527115139045885, 0.0327451229095459, 0.7586321149553571, 58.03100374766758, 63.83668572562081, 66.35255200522286, 49.10799510138375, 39.02691282544817, 21.07413646153041, 41.506061349596294, 39.72695772988455, 39.81630114146641, 32.81908995764596, 0.6569789924791881, 0.022793248262522475, 0.10669361986219883, 0.31686152304921833, 0.6185856897916112, 0.4483988748065063, 1.9250474912779671, 1.2066851811749595, 7.399544886180332, 58.347824232918875, 71.81446143559047, 68.54930141993931, 65.46766417367118, 67.45780195508684, 62.32400035858154, 64.97862216404506, 64.12843363625663, 65.7332729612078, 61.21190643310547, 62.7556710924421, 57.75378104618618, 63.18328407832554, 51.904283727918354, 62.67245946611677, 55.03336327416556, 43.856126240321565, 42.42582218987601, 54.91410091945103, 57.688367230551584, 59.99890381949288, 54.87563221795218, 57.99749953406197, 54.7896135193961, 54.75835009983608, 42.387033871241975, 41.1455089024135, 41.051680428641184, 41.88587767737252, 40.9495210647583, 48.744249956948416, 54.043637548174175, 55.67983756746565, 54.06133460998535, 52.2188286781311, 52.47135748182024, 56.31355496815273, 53.797435079302105, 55.38792984826224, 49.75162410736084, 50.87856980732509, 51.084889616285054, 53.62614113943917, 52.55864770071847, 55.43198490142822, 51.17112718309675, 54.19757488795689, 49.846057074410574, 54.784044538225444, 33.8102331161499, 32.56689119338989, 57.660341671534944, 44.41374002184187, 43.91169098445347, 40.59561456952776, 43.11487851824079, 37.613941056387766, 40.66089636938912, 38.7854768208095, 41.2548839705331, 40.71235472815377, 48.63843584060669, 54.30633851460048, 55.25136995315552, 55.55197334289551, 43.787749017987935, 40.86863708496094, 53.8022814478193, 53.47250257219587, 49.029522146497456, 42.09945140566145, 39.44030979701451, 40.12138959339687, 40.80473102842058, 41.39186770575387, 48.0443822315761, 56.31859588623047, 55.05075808933803, 55.02912139892578, 57.87732696533203, 54.35247802734375, 51.02847719192505, 46.21263558523995, 43.536040101732524, 44.62977341243199, 44.98595544270107, 48.811418192727224, 51.148972851889475, 54.21018934249878, 54.110361099243164, 56.437375341142925, 51.97312995365688, 55.40851041248867, 54.95363964353289, 62.69486740657261, 58.62937913622175, 72.35171699523926, 31.371953896113805, 0.15317862906626292, 0.5719291876469339, 1.746650972536632, 1.6573518557207925, 0.5535390973091125, 0.08131267822214536, 0.043216522982610125, 2.344420130763735, 17.380984783172607, 29.836075442177908, 27.53236198425293, 35.94238860266549, 30.677651677812847, 14.8026750428336, 25.57341292926243, 39.5639043535505, 53.53744738442557, 52.903702190944124, 62.66125202178955, 5.986503200871604, 0.46248800307512283, 0.06283127742686442, 0.020368669614461914, 0.04900705262220331, 0.07155609104250159, 0.019250727192099606, 0.04830842957432781, 0.04775505033986909, 0.055285903558667214, 0.026197511037545543, 0.053358297528965135, 0.040499621270490546, 0.015060722561819213, 0.02302662529317396, 0.011518210821252848, 0.026962817114378725, 0.025290121424144933, 0.005486526019272527, 0.05946055294147559, 0.07803809536354882, 0.04038251630429711, 0.048489564497556, 0.052540985135627646, 0.06776519053216491, 0.03640154456453664, 0.06771294333572898, 0.02635485821935747, 0.03531966797475304, 0.03572507568502, 0.047256703688097854, 0.036143029507781775, 0.02241226442025176, 0.05789231602102518, 0.11170371887939316, 0.05275207059457898, 0.03817979146593383, 0.026491650879116993, 0.005375164427927562, 1.9962137639522552, 69.71853733062744, 72.43067632402692, 73.75409276144845, 57.29518951688494, 48.06688049861363, 33.12369550977434, 35.4720824105399, 38.06885698863438, 44.3455399785723, 32.635032176971436, 1.1640352926083972, 0.12836724972086294, 0.11164112402392284, 1.6063640202794756, 1.9458034975188119, 3.8255587220191956, 1.3517955946070808, 0.8151760665433747, 7.895425660269601, 64.26364558083671, 73.03894942147392, 69.806654385158, 69.08458369118827, 68.69301101139614, 65.32678944723946, 67.33541638510567, 66.31315571921212, 65.34853036063058, 64.54772268022809, 64.45513098580497, 59.529295921325684, 64.63014916011265, 56.24568496431623, 64.23082229069301, 57.78187608718872, 46.303083760397776, 44.26349564961025, 55.983286244528635, 60.581308773585725, 63.1627174104963, 57.08932481493269, 59.57661315373012, 58.600168909345356, 55.17566932950701, 44.41881915501186, 42.28495788574219, 43.095354080200195, 42.18303823471069, 43.68657977240426, 49.32586976460048, 55.27076237542288, 57.9365360396249, 55.49918440410069, 54.13300180435181, 53.90358618327549, 58.57350867135184, 55.93301602772304, 56.81609385354178, 52.491295337677, 51.83326966421944, 49.70431729725429, 55.719529151916504, 53.457018511635916, 57.1700177192688, 52.867609773363384, 56.01455661228725, 51.707097326006206, 53.07275186266218, 36.627859660557334, 35.17366770335606, 60.20322254725865, 46.19616488048008, 46.65095574515206, 42.76130206244332, 44.092340673719136, 40.09985712596348, 43.249732630593435, 40.493924209049766, 42.59975297110421, 42.75946078981672, 48.807235377175466, 54.96352693012783, 59.201452119009836, 58.44432776314871, 45.11188459396362, 43.264705998556956, 55.8069201196943, 57.00078739438738, 52.07667200905936, 42.36193697793143, 41.98513616834368, 41.889956269945415, 43.275475706372944, 44.001468658447266, 50.51049593516758, 59.12397970472063, 57.73197412490845, 55.087545326777864, 60.629640442984446, 57.65889297212873, 54.02431113379342, 47.32797084535871, 45.45488241740635, 46.420716762542725, 47.538355350494385, 50.48199789864676, 54.592903069087434, 57.96449211665562, 55.150315352848594, 58.52409308297293, 54.06576408658709, 58.259748867579866, 55.684465067727224, 64.01653984614781, 60.61849553244454, 73.75777530670166, 38.62909024102347, 0.2515963880079133, 0.5338571848613876, 2.201812480177198, 2.840089201927185, 1.6383350704397475, 0.1475929423634495, 0.016976886794769337, 1.3031028360128403, 27.076091153281077, 34.399023464747835, 31.143090656825475, 30.33022437776838, 24.629006828580582, 23.090234449931554, 37.242035252707346, 45.31531742640904, 59.09528364453997, 59.44475024087088, 72.45649582999093, 10.327544433729988, 0.6766154159392629, 0.13129753034029687, 0.0480200182646513, 0.0480619856555547, 0.005154921290730792, 0.10576148238033056, 0.0283532032210912, 0.004320814731597368, 0.0637858472764492, 0.04443067318892904, 0.09759548985000167, 0.03151428074176822, 0.007530270526850862, 0.047944324290645976, 0.027913945095081414, 0.0743947219369667, 0.025447534763121178, 0.06257930344768933, 0.04111490325470056, 0.08361557857798678, 0.14275563907410416, 0.1831183625119073, 0.07971914551619973, 0.13791640874530586, 0.0906687058242304, 0.1582141731466566, 0.13526947077895912, 0.10541607412908759, 0.12891946866043977, 0.14991771190294198, 0.10375561072890248, 0.12337399194283144, 0.1324297881552151, 0.2766847317772252, 0.1669755665851491, 0.14434331602283887, 0.14362942932971887, 0.10602152414087739, 2.7859416731766293, 82.9585451398577, 80.62314442225865, 84.7960865838187, 66.34910569872174, 53.68208108629499, 31.071996688842773, 59.04809842790876, 53.60380615506853, 53.83889845439366, 46.15662963049752, 1.4923049977847507, 0.23405015096068382, 0.2126028939549412, 3.1300056108406613, 3.1663887671061923, 6.831280819007328, 7.252447613648005, 4.744539627007075, 9.12187738077981, 66.04290553501674, 71.87109620230538, 73.2341729572841, 69.99439471108573, 72.15135874067033, 66.43712547847203, 69.0439784186227, 68.70284966060093, 68.77641023908342, 65.2826475415911, 66.68813610076904, 60.99063410077776, 65.16388198307583, 58.85840565817696, 67.46005317143032, 61.643354824611116, 48.93493284497942, 46.67395428248814, 59.14681148529053, 63.4460232598441, 64.9506904057094, 57.39742531095232, 61.66729136875698, 61.473436628069194, 59.17912060873849, 45.385897227696006, 44.886985301971436, 45.186918190547395, 45.064251218523296, 45.81474699292864, 53.72358267647879, 59.148624965122764, 59.587890080043245, 57.18181576047625, 54.13693101065499, 54.35006005423409, 59.18500573294503, 57.30406584058489, 58.01765625817435, 53.40285382952009, 53.01592602048601, 51.46577944074358, 56.492471081869944, 54.396439279828755, 59.49059445517403, 55.399109499795095, 57.716827051980154, 54.91663701193673, 52.09366730281285, 39.05379887989589, 40.59584733418056, 62.39385754721505, 49.23018959590367, 48.721046447753906, 45.30837270191738, 47.380124023982454, 42.35878944396973, 45.852465288979666, 44.85670157841274, 44.61379950387137, 44.77936117989676, 52.3242050579616, 58.81914833613804, 59.55590057373047, 59.83767087118966, 47.04864283970424, 44.16909742355347, 57.93159934452602, 60.50767871311733, 55.63610907963344, 45.20481327601841, 42.96433884756905, 43.667739731924875, 45.31583506720406, 45.534751960209434, 52.66959653581892, 62.1828407560076, 58.73510292598179, 56.16020475115095, 62.48788057054792, 59.59267044067383, 58.410955565316335, 50.94492162976946, 47.58647857393537, 49.837722710200715, 49.521350383758545, 54.729403904506135, 57.40600981031145, 60.51511328560965, 58.513907023838584, 61.47159535544259, 58.08247252873012, 60.32944352286202, 59.82805456433977, 67.15547193799699, 63.869918959481375, 77.8652445929391, 37.69160802023751, 1.2227710208722522, 5.608141652175358, 6.467078396252223, 5.629443526268005, 1.9438097987856184, 0.40717591824276106, 0.11225504893809557, 3.627092331647873, 30.970761435372488, 43.966182231903076, 36.466734409332275, 49.006478445870535, 42.120337690625874, 23.675151177815028, 40.26595728737967, 53.17338957105364, 68.30622564043317, 66.51338195800781, 82.11341490064348, 11.102882623672485, 0.8272452503442764, 0.2520892487040588, 0.18134582548269204, 0.12680205942264625, 0.13141753604369505, 0.16651406777756556, 0.16544964989381178, 0.10975353459694556, 0.12845619209110737, 0.11579718493989535, 0.15160157797592028, 0.1430416687258652, 0.14191614197833197, 0.11062077698963028, 0.07801986991294793, 0.19009229115077428, 0.07762139343789645, 0.18065065278538636, 0.14272970546569141, 0.1944970012243305], [0.06280235826436963, 0.06883224113179104, 0.07646827067115478, 0.009042294213681348, 0.01151451704624508, 0.019226423764069165, 0.02508970762469939, 0.01960924982891551, 0.019860694550776055, 0.007394176758160549, 0.04889565413551671, 0.017836792527564933, 0.031149859939302717, 0.021595644132633294, 0.046444592265678306, 0.048961597561304054, 0.09504335679646049, 0.17418961519641535, 13.867195640291486, 72.51880727495465, 62.51615973881313, 63.51902798243931, 41.11786202022007, 33.85587583269392, 14.785148211887904, 62.99231284005301, 61.30847249712263, 42.13880947657994, 13.688608697482518, 0.05769649759999343, 0.0615554755287511, 0.22280966197805746, 0.8446410426071712, 0.037478583199637275, 3.5288345984050205, 1.3402857950755527, 0.10483238473534584, 34.9762624331883, 69.00676386696952, 62.60713250296456, 72.80082770756313, 64.86966746194022, 65.7073700768607, 63.303758893694194, 64.6966712134225, 60.20529311043875, 61.01591164725167, 59.40341540745327, 56.48227112633841, 61.088332721165244, 53.51343093599592, 53.79390886851719, 59.3360595703125, 49.07805183955601, 41.65052482060024, 45.07523284639631, 57.8605192729405, 57.65079484667097, 53.930548667907715, 52.687130314963206, 59.095915930611746, 52.48125866481236, 47.674109254564556, 41.51376690183367, 42.426850523267476, 39.49181679316929, 40.52815103530884, 39.632007122039795, 47.714558192661826, 52.14452116830008, 55.76362589427403, 54.98486484800066, 56.72134474345616, 55.72694635391235, 57.11585651125227, 54.66749198096139, 53.87025220053536, 54.39335427965437, 56.21435553686959, 48.039789472307476, 56.063395500183105, 50.26927532468523, 55.179129532405305, 50.35615907396589, 55.684381689344136, 48.61074379512242, 57.55275576455252, 29.2809282711574, 35.62986557824271, 57.935014384133474, 44.14519214630127, 45.03585393088204, 38.96041856493269, 42.22000959941319, 41.33029276984078, 47.937855924878804, 44.11079508917672, 41.76410354886736, 38.89008889879499, 40.88577481678554, 45.01114961079189, 52.47340372630528, 54.18783003943307, 59.242370060511995, 45.341126510075156, 50.11799219676426, 53.521563802446636, 47.31228181294033, 42.73880379540579, 40.81220729010445, 40.23746967315674, 40.351027556828086, 42.397615977696006, 49.188813073294504, 53.03105224881853, 55.90523018155779, 52.653678212847026, 56.57143388475691, 55.500341279166086, 52.29665197644915, 45.90236725125994, 45.158131803785054, 42.454024927956716, 44.92963334492275, 42.66469430923462, 48.79900523594448, 48.52589586802891, 54.121731826237266, 52.279278005872456, 56.144175257001606, 51.5742130279541, 55.15681191853115, 53.89052356992449, 63.894272395542686, 56.98913179125105, 73.12903281620571, 15.141371931348528, 1.2186876514128275, 2.0800357460975647, 1.4600108563899994, 0.3860215033803667, 0.1752874848565885, 0.05829456515078034, 0.49106811519180027, 9.943420222827367, 24.148438147136144, 20.87122126988002, 12.033222096306936, 35.720907824380056, 12.345500196729388, 18.193055493491038, 31.905186448778423, 45.29687690734863, 49.359262807028635, 61.47161620003836, 38.150661604745046, 0.24935410118528775, 0.07280208489724568, 0.09173387688185487, 0.031463906301983764, 0.018018036016396115, 0.048869296442717314, 0.03549989026838115, 0.01777117988759918, 0.013817274909732597, 0.023309528594836593, 0.06384854391217232, 0.039294604145522626, 0.025587854108640125, 0.04627344198524952, 0.02975175210407802, 0.08763547108641692, 0.06864544722650733, 0.0118271596896063, 0.03476361531232085, 0.032163872849196196, 0.024420532996633222, 0.06538930694971766, 0.07015502479459558, 0.04262219415977597, 0.06683941770877157, 0.03677931215081896, 0.024731978873855302, 0.05048884418127792, 0.08963819433535848, 0.013776790966013712, 0.05040119442024401, 0.01890679305818464, 0.08061405178159475, 0.009047943017711597, 0.0324476192306195, 0.07273362071386405, 0.01923947368881532, 0.24830218191657746, 18.195117371422903, 85.26748711722237, 67.87250518798828, 74.15635871887207, 50.305833271571565, 46.139589173453196, 20.034051929201397, 52.92909090859549, 49.32219764164516, 38.05950123923165, 16.19599209512983, 0.0646040587286864, 0.057303741175149164, 0.8951453268527985, 1.8160904007298606, 2.30108790738242, 3.5927538999489377, 1.6299922381128584, 0.10491093873445477, 37.64695194789341, 71.4942467553275, 65.10626752035958, 74.21741948808942, 66.67090456826347, 69.21879509517125, 65.72954872676304, 66.70784814017159, 60.81701946258545, 64.27053819383893, 58.424032075064524, 57.64005987984793, 59.85146999359131, 55.81472642081124, 57.81934772218977, 63.628726141793386, 52.56789575304304, 44.40684393474034, 46.66747856140137, 60.245745522635325, 60.391574314662385, 55.570184571402415, 53.14783409663609, 60.8574093409947, 56.02388456889561, 50.96436268942696, 43.1317834854126, 42.96857030051095, 42.70128352301461, 43.499280657087056, 41.78596952983311, 48.6996077810015, 54.16954585484096, 57.970860140664236, 56.1723050389971, 57.38621439252581, 58.2259840965271, 60.02482060023716, 55.15923683983939, 56.768960748400005, 56.970854554857524, 56.88296331678118, 49.24325915745327, 57.319942474365234, 51.354733330862864, 56.224583285195486, 51.99984230313982, 58.0047847202846, 50.193998541150776, 57.951078619275776, 30.51530006953648, 38.4109411239624, 60.09978471483503, 46.274929659707205, 46.66625567844936, 41.13260957172939, 43.24456664494106, 43.498908928462434, 50.21666703905378, 45.41448559079851, 42.99578292029244, 41.510289328438894, 42.53595461164202, 45.99732480730329, 54.31563173021589, 56.561442375183105, 59.88185446602957, 46.06926645551409, 52.05114780153547, 56.857689244406565, 49.09555435180664, 44.50966337748936, 42.09524427141462, 41.4354224886213, 43.1483827318464, 44.738891397203716, 51.81928641455514, 56.3746782711574, 57.17168876102993, 51.88621493748256, 57.94615234647478, 56.70417921883719, 56.4324768611363, 47.677968978881836, 47.73879698344639, 44.29878555025373, 47.1639620917184, 44.90176064627511, 50.97454874856131, 50.225494725363596, 53.88751152583531, 54.45011411394392, 59.10462202344622, 54.583092212677, 59.779479707990376, 55.37379721232823, 65.97226319994245, 60.41897106170654, 76.94734586988176, 20.028404780796595, 0.7617159751909119, 0.5681295001081058, 3.2195533428873335, 1.6523147374391556, 0.8019820888127599, 0.04563429931710873, 0.29115690663456917, 9.239882980074201, 34.08587162835257, 22.482861144202097, 13.216433439935956, 31.0194022996085, 13.74633172580174, 25.080490350723267, 40.93393278121948, 50.34799494062151, 54.45858744212559, 67.47174004146031, 49.58353328704834, 0.39025542618972914, 0.08257015288940497, 0.03970861228715096, 0.045518659986555576, 0.05909470721547093, 0.08169980280633483, 0.0329379014936941, 0.07478458780263152, 0.08183586264827422, 0.02139713192757751, 0.027264883941305534, 0.02887649621282305, 0.059130934200116565, 0.05995340685227087, 0.019712373581049696, 0.06517812649586371, 0.024779008135997822, 0.042917797940650156, 0.009743305704822498, 0.0773649343422481, 0.18464721047452518, 0.19339826303933347, 0.22153325618377753, 0.09046011737414769, 0.14058345848960535, 0.10364838862525565, 0.0982994292197483, 0.13471265137195587, 0.2708619513681957, 0.10029973009867327, 0.160589371408735, 0.08874586650303432, 0.111592954822949, 0.0793101042509079, 0.15921733288892678, 0.18773290275463037, 0.25073619559407234, 0.44224988190191133, 23.397666181836808, 98.8410918372018, 77.39745712280273, 82.94934572492326, 55.778595788138254, 48.00576761790684, 22.856649909700664, 82.03245449066162, 75.1222208568028, 60.49799987248012, 20.837922028132848, 0.11955666249351841, 0.12769372229065212, 1.2381378305809838, 3.5288467577525546, 2.955669011388506, 10.638863682746887, 8.00870474747249, 2.201084439243589, 40.49212809971401, 75.66588960375104, 66.62859698704311, 74.29292556217739, 69.27768107822963, 71.85084220341274, 66.63708768572126, 69.02217497144426, 63.07610811505999, 65.5033014842442, 59.59022467476981, 59.18797261374337, 60.01092420305525, 59.374052320207866, 60.1712121963501, 65.61977413722447, 55.589351177215576, 46.86227478299822, 49.658570357731406, 61.52230330875942, 63.18457644326346, 59.106240953717915, 54.58503076008388, 63.651002066476, 58.75172996520996, 51.57162829807827, 47.14684520448957, 45.59531940732683, 44.38319574083601, 44.12310382298061, 45.07251957484654, 51.47154297147478, 57.472900118146626, 59.819362367902485, 58.23725060054234, 59.90508229391915, 60.87425177437918, 63.18833541870117, 61.2538457598005, 60.124749592372346, 60.451842989240376, 60.16423620496477, 49.67940105710711, 58.17140252249581, 53.54694904599871, 56.9504268510001, 54.60063988821847, 59.9803660256522, 53.718048436301096, 58.57818480900356, 34.882948126111714, 42.91861275264195, 61.39014162336077, 49.97341060638428, 48.98418515069144, 44.250651904514854, 47.16796772820609, 46.32745804105486, 54.247838156563894, 47.04991783414568, 44.838087354387554, 44.034722736903596, 45.681629930223735, 49.08747707094465, 56.40322494506836, 58.50110149383545, 62.16856220790318, 45.77353375298636, 54.00359507969448, 59.70801053728376, 51.76487159729004, 47.063880239214214, 45.372382981436594, 44.18700293132237, 45.044605187007356, 45.878927503313335, 55.46665988649641, 58.10998044695173, 60.079926763262065, 53.118394579206196, 61.796027592250276, 60.77018860408238, 57.495641572134836, 49.88157973970686, 49.56244897842407, 46.20881755011422, 50.43929079600743, 46.04781041826521, 55.001717703683035, 53.43417978286743, 58.700146538870676, 57.38848645346505, 61.726441383361816, 58.04050540924072, 62.89178630283901, 58.897287777491975, 69.14517893110002, 63.081395694187705, 79.68673569815499, 18.898678064346313, 2.7917699090072086, 8.618185094424657, 6.0743562238557, 2.7527112620217458, 1.0436957499810626, 0.23034738536391938, 0.9370660888297218, 15.324396167482648, 38.24483054024832, 33.5813490322658, 21.063750641686575, 52.19430153710501, 20.258930376597814, 28.887215546199254, 45.34361049107143, 59.72363703591483, 62.95810685838972, 75.82054955618722, 56.5021846635001, 0.4887341175760542, 0.1658025695277112, 0.2067873738706112, 0.11311813191111598, 0.10822888676609312, 0.15110725164413452, 0.0715702927804419, 0.13145200562264236, 0.20703520200082234, 0.09615573353533234, 0.1977119951375893, 0.09336356871894427, 0.16806302751813615, 0.10629508910434586, 0.09166083258709737, 0.12318188510835171, 0.2610998951963016, 0.1438424621841737, 0.1281642456139837, 0.13609726993100985], [0.05922144398625408, 0.0825238021622811, 0.06166166625916958, 0.04748290012191449, 0.040693349803664854, 0.03211077409131186, 0.03765105323067733, 0.05012038270277636, 0.010522040837843503, 0.05797146713095052, 0.031036924570798874, 0.03248410405857222, 0.09301505956266608, 0.02430244076198765, 0.050177016628107855, 0.05915437079966068, 0.08761698100715876, 0.21097659479294503, 39.45903866631644, 73.27174186706543, 60.68510791233608, 53.368745122637065, 44.89512511662075, 21.790375879832677, 27.10538649559021, 51.299502100263325, 75.73703915732247, 35.122376101357595, 0.7944245114922523, 0.05765767861157656, 0.09799119790217706, 0.7038415521383286, 0.5075961425900459, 2.207416202340807, 1.8526898196765353, 1.1109829736607415, 4.7691905328205655, 67.16021755763462, 67.39862414768764, 61.337898118155344, 57.69038915634155, 68.7852622440883, 64.0055547441755, 64.72984191349575, 61.83223465510777, 61.64509187425886, 61.584107535226, 63.67320850917271, 62.24897371019636, 54.72239317212786, 50.26652731214251, 59.709539140973774, 55.653698444366455, 45.51071119308472, 41.26929800851004, 46.543237822396414, 57.01454830169678, 55.197087151663645, 57.25223922729492, 59.10468455723354, 56.61034379686628, 54.75391367503575, 46.95102064950125, 43.71617909840175, 44.02997364316668, 42.29005438940865, 41.618465832301546, 41.81682300567627, 44.62354435239519, 50.064320836748394, 55.09777307510376, 56.21179165158953, 56.5091050692967, 53.37269169943673, 51.209436076028005, 47.918400968824116, 49.97390392848423, 54.65942164829799, 54.307120186941965, 52.9006484576634, 52.85697208132063, 50.9622608593532, 54.34399080276489, 51.85523986816406, 53.574481282915386, 46.45051063810076, 53.63592072895595, 28.53187424795968, 32.95712981905256, 58.88052177429199, 47.48321097237723, 48.98487302235195, 42.6789276940482, 46.966921601976665, 50.39082363673619, 54.765874998910085, 51.40830046789986, 47.57550389426095, 38.68655184337071, 41.05657543454851, 40.5235721724374, 49.141888414110454, 49.14087397711617, 53.89878150394985, 51.361302852630615, 47.67178855623518, 54.67735494886126, 49.742494174412315, 41.92987714494978, 40.58602952957153, 40.51281636101859, 42.45491777147566, 41.16644035066877, 47.84061241149902, 54.76450967788696, 54.97986561911446, 53.74329818998064, 55.79995107650757, 55.23724773951939, 52.24805974960327, 45.37676729474749, 43.037392207554404, 44.00729819706508, 43.54134157725743, 44.36261517660958, 44.22197668892996, 47.217730726514546, 47.86380202429635, 50.627135344914024, 51.095857347760884, 52.06532907485962, 51.095513411930625, 54.2258540562221, 56.15597677230835, 63.88103607722691, 59.427004541669575, 62.18067291804722, 1.243326072181974, 1.6575642100402286, 1.8888265320232935, 1.0601676489625658, 0.1957855527954442, 0.1396892171885286, 0.015786164706306796, 3.228988996573857, 16.418348346437725, 27.600009645734513, 21.447683777127946, 14.785365343093872, 22.677884919302805, 13.49547483239855, 30.08549840109689, 43.45879350389753, 51.71513639177595, 50.19678129468645, 61.96229798453194, 8.003191351890564, 0.33011320339781897, 0.08660341253770248, 0.05377267547217863, 0.04363705863111785, 0.028029555587896278, 0.03577634918370417, 0.033332815659897666, 0.09209107128637177, 0.03346278904271977, 0.029301618758056844, 0.034954592385994535, 0.020845554203593304, 0.01609894729751561, 0.0967588968841093, 0.03389354342860835, 0.010777303167352719, 0.04054390925115772, 0.01044085921187486, 0.007980402176534491, 0.04162943635934165, 0.05201171085770641, 0.011941855856483536, 0.049398893024772406, 0.03129408255751644, 0.07381044221775872, 0.07334393582173757, 0.037135281799627204, 0.0319298257652138, 0.038223651969539266, 0.042511168867349625, 0.0710875897535256, 0.10484940239361354, 0.04135936585121921, 0.05431125585788062, 0.04170603617759688, 0.02401723892294935, 0.39984592156750814, 51.00085462842669, 81.82767023359025, 66.8461103439331, 59.28699834006173, 50.663505690438406, 31.361177240099224, 26.047260965619767, 51.52114963531494, 72.34859725407192, 35.97184201649257, 0.9229738393000194, 0.06072277056851557, 0.16529798374644347, 1.9609720664364951, 2.1502918047564368, 3.603130166019712, 3.3855479785374234, 2.075825789145061, 5.875694198267801, 72.0511587687901, 69.89138071877616, 62.87761197771345, 60.90965979439871, 69.18268530709403, 65.39779308864048, 66.97962692805699, 64.977281161717, 66.24125576019287, 62.0075238091605, 64.43061079297746, 64.37888145446777, 57.73935311181204, 53.409339972904746, 63.606422424316406, 57.40040956224714, 47.34660938807896, 43.23249067578997, 49.772739682878765, 59.394021442958284, 58.85932976858956, 60.976626532418386, 58.715641021728516, 58.87863186427525, 56.309896741594585, 48.84850072860718, 46.80949626650129, 46.14501919065203, 44.03085259028843, 42.99928133828299, 42.0330822127206, 46.45180647713797, 52.654525893075125, 57.11041954585484, 58.899010930742534, 58.24045719419207, 55.98881006240845, 54.38073287691389, 50.70918662207467, 51.399941784994944, 56.70718778882708, 56.03231968198504, 52.53455482210432, 53.6747715813773, 51.58821364811489, 56.92639998027256, 52.57124478476388, 56.29614625658308, 47.63517154966082, 55.983644076756065, 30.372924532209122, 35.59560053689139, 61.45491967882429, 49.83555834633963, 50.839684213910786, 43.85080392020089, 50.53407464708601, 51.68576635633196, 58.371621813092915, 54.15018122536795, 48.18397501536778, 40.172827107565745, 42.88865906851632, 42.348377568381174, 49.52898645401001, 53.369217600141255, 56.49321453911917, 52.555215290614534, 49.76664958681379, 58.22726951326643, 52.065436771937776, 43.84337977000645, 42.48666756493704, 42.31317799431937, 42.73211962836129, 44.59397281919207, 51.00097622190203, 57.98898104258946, 57.00188520976475, 55.20406314304897, 58.679315839494976, 58.46268490382603, 54.778986249651226, 48.22509445462908, 44.46950626373291, 46.027167320251465, 44.42187983649117, 47.797832352774485, 46.179676805223735, 50.25279767172677, 47.78997394016811, 53.92493799754551, 52.65934099469866, 54.281488282339915, 52.476290702819824, 57.247594356536865, 58.53907339913504, 66.57015568869454, 61.28894805908203, 66.57083661215646, 2.094346646751676, 1.4686216286250522, 1.103851624897548, 3.30507806794984, 1.2400150384221758, 0.6432502205882753, 0.04474221236471619, 0.7348029421908515, 21.499281099864415, 29.60901526042393, 23.13513544627598, 20.1762398651668, 21.19187021255493, 21.12661967958723, 38.6246121270316, 50.35071168627058, 58.57155622754778, 56.02818202972412, 70.50865173339844, 11.899099281855992, 0.5487337123070444, 0.041201168804296424, 0.04490621427872351, 0.017600105942359993, 0.037169815839401314, 0.01536307267711631, 0.05943825628076281, 0.05402777749778969, 0.026784345441098725, 0.021379976865968535, 0.08901154688958611, 0.04289290588349104, 0.052993439071412594, 0.02513351893451597, 0.06226965399192912, 0.015062288281374743, 0.04395322880840727, 0.02209246577695012, 0.05922506057790347, 0.1501643458115203, 0.12809616141021252, 0.1499498744628259, 0.1599549547369991, 0.0990933355476175, 0.16388421532298836, 0.13326541760138103, 0.103445696644485, 0.1794143212693078, 0.11782376548009259, 0.08337069528975657, 0.1765664555132389, 0.1548771107835429, 0.12214041527892862, 0.21792355845017092, 0.17204301538211958, 0.1328669139849288, 0.460432801927839, 60.82771968841553, 91.16928700038365, 79.39152758462089, 67.47338676452637, 58.37615203857422, 30.416517530168804, 42.37061527797154, 64.5416569028582, 84.73366396767753, 54.14887843813215, 1.3780021369457245, 0.12298432285232203, 0.5861617582184928, 2.7036962807178497, 2.426567379917417, 9.838325245039803, 9.863715699740819, 5.573785849979945, 5.624769125665937, 78.25710214887346, 70.25647381373814, 69.94499996730259, 61.341559818812776, 70.85695103236607, 66.54140404292515, 70.1183853149414, 65.79580674852643, 68.70152255467006, 64.37642874036516, 68.62074974605015, 64.35954461778913, 60.52174881526402, 56.82820108958653, 66.1108797618321, 60.77011217389788, 50.21576724733625, 44.37970774514334, 50.35258075169155, 60.21472181592669, 61.60882922581264, 62.25240612030029, 60.62317167009626, 61.88412380218506, 60.79354149954659, 51.063364097050254, 49.76796279634748, 50.488657746996196, 47.723424094063894, 45.216229166303364, 45.54258605412075, 50.575704778943745, 54.35193954195295, 59.342597825186594, 62.93829754420689, 59.97546059744698, 59.84748867579869, 56.4769731249128, 53.766967228480745, 54.581198828560964, 58.759803771972656, 59.42361382075718, 51.60563973018101, 55.601989950452534, 53.96347270693098, 57.33405426570347, 54.73240205219814, 58.22215563910348, 50.83212457384382, 55.215961933135986, 34.165289538247244, 38.23973056248256, 63.2034546988351, 53.50374514716012, 53.52494062696184, 46.54843854904175, 52.68040098462786, 55.49055126735142, 60.373738288879395, 56.93226773398263, 51.404503277369905, 42.93643140792847, 46.17826632090977, 45.57470757620675, 52.629512378147666, 55.961666924612864, 58.70162650517055, 54.24547576904297, 50.42769772665841, 59.86820820399693, 55.05748047147478, 45.8014794077192, 44.27636023930141, 45.44571426936558, 45.713959898267476, 46.86630473818098, 53.18253687449864, 59.874079431806294, 59.16021456037249, 55.33899368558611, 60.33332756587437, 61.11422865731375, 57.40586737224034, 49.85820599964687, 46.94362429210118, 49.12211384092058, 46.07485975537981, 50.3940406526838, 48.67968034744263, 53.72092499051775, 51.68680511202131, 56.93224341528756, 56.53897190093994, 58.70767143794468, 55.21297768184117, 60.79857199532645, 62.012686320713584, 70.41797079358781, 64.0419007710048, 69.56298106057304, 1.7122920219387328, 5.65513014793396, 7.684888294764927, 4.407210665089743, 2.4627638033458163, 0.3771235751254218, 0.15696760932249681, 4.454609538827624, 26.488028628485544, 40.75377293995449, 32.0474716595241, 23.440769331795828, 37.07681403841291, 23.064494848251343, 44.07904876981463, 57.01131044115339, 66.96238149915422, 62.44575364249093, 79.8727250780378, 14.24164709023067, 0.7938562791262354, 0.14461558498442173, 0.13860470109752246, 0.11038901656866074, 0.13459168214883122, 0.09895684144326619, 0.13325608095952443, 0.21829445926206453, 0.05398590849446399, 0.17342787821378025, 0.17997397695268902, 0.09687339288315602, 0.10701950666095529, 0.15395373318876537, 0.10241806892944233, 0.166102780561362, 0.16242980265191623, 0.17124641527022633, 0.06032512869153704], [0.02316176232748798, 0.023146929551980326, 0.08503854793629476, 0.05106793310759323, 0.051111047222678146, 0.03374771268240043, 0.07407169177063874, 0.013654915898639177, 0.0397425831428596, 0.033666522574744055, 0.019195828620078306, 0.09579990298620292, 0.029697951062449386, 0.04615610292447465, 0.042339920199343135, 0.04469446046277881, 0.14377311590526784, 4.178245808397021, 63.77495098114014, 60.99082865033831, 69.50908388410295, 66.36639976501465, 48.07733753749302, 22.3036219392504, 39.86023112705776, 35.041158608027864, 37.61190870829991, 13.593090074402944, 0.05362615262025169, 0.011213242408952542, 0.24985909408756665, 0.4358513509588582, 1.19648120871612, 2.5022402107715607, 1.5033476395266396, 0.6854792003120694, 29.40916769845145, 78.55117770603725, 60.47855186462402, 67.47322000776018, 59.175715991428916, 59.050370488848, 61.312738691057476, 63.343773569379536, 59.14742292676653, 62.404738426208496, 62.16057872772217, 61.0194274357387, 60.52903747558594, 59.12190219334194, 59.00362300872803, 56.75444596154349, 46.90546131134033, 42.79449360711234, 43.28868423189436, 45.23294653211321, 57.31003434317452, 54.865560804094585, 63.332218715122764, 54.35321453639439, 56.34038891111101, 51.84448405674526, 48.326750074114116, 45.73979677472796, 48.252230644226074, 45.54641103744507, 42.37249823978969, 38.36223772593907, 43.60889196395874, 44.98366948536464, 51.91311488832746, 54.47739274161202, 57.41979503631592, 51.504637241363525, 46.20695195879255, 43.42076601300921, 53.65660899026053, 51.97383866991316, 55.74571343830654, 46.36044461386544, 50.925741127559114, 54.52835430417742, 55.79804727009365, 51.867656299046104, 55.20220102582659, 50.55797645023891, 56.38516310283116, 31.171779768807546, 35.18035534449986, 61.352802004132954, 45.720928941454204, 54.71076536178589, 46.33122049059187, 55.13098199026925, 52.39813389096941, 57.84594890049526, 52.68871450424194, 50.36795016697475, 43.40085594994681, 44.29278925486973, 41.967991488320486, 43.6939240183149, 48.3154627255031, 54.70961890901838, 51.050047874450684, 50.33511298043387, 53.27927316938128, 49.95984772273472, 43.18744550432478, 40.95731346947806, 38.85166188648769, 39.538821356637136, 41.44908612115042, 47.65950414112636, 53.271366119384766, 56.32943160193307, 53.97425978524344, 57.24782712118966, 56.15373945236206, 52.146515301295686, 45.48948792048863, 42.70433725629534, 43.094589778355186, 41.87257535117013, 43.22179044995989, 42.3585775239127, 42.17238317217146, 45.31463302884783, 46.34325477055141, 45.93416568211147, 45.99820722852434, 46.14709670203072, 49.334746088300435, 50.43641424179077, 58.595235688345774, 58.1571934563773, 67.7503628049578, 33.562960624694824, 0.1352731077266591, 1.7179755398205347, 2.045296924454825, 0.17176983718361172, 0.10127821152231523, 0.04661439565409507, 0.22910827185426438, 9.581759537969317, 25.10220868246896, 24.691559723445348, 15.417092084884644, 56.15707458768572, 31.589227540152415, 27.76468368938991, 32.919401100703645, 39.41511215482439, 49.18148619788033, 57.064394678388325, 29.691921166011266, 0.16072799611304486, 0.04452620752687965, 0.024471312861091325, 0.03678211789312107, 0.015280932620433825, 0.013292941214915897, 0.011714408373726266, 0.0014323432135695058, 0.02116365311667323, 0.055782913496451716, 0.025682882938001837, 0.025154645122321587, 0.026426601423216716, 0.07249414534973246, 0.04725452559068799, 0.014742160548589059, 0.038776685151138475, 0.08544550609907933, 0.05907863272087915, 0.013909021325941597, 0.05691732226737908, 0.030693986187023774, 0.09279235079884529, 0.09588928640420948, 0.011608413570294423, 0.016332899386595403, 0.07241815621299402, 0.01672042769912098, 0.037917184843016524, 0.08992975404752152, 0.15529842674732208, 0.035045309125312736, 0.13570526668003627, 0.05525926427383508, 0.03594901938257473, 0.10477857012301683, 6.645958466189248, 78.29660960606166, 67.88728400639125, 75.91365541730607, 70.43448666163853, 51.5773640360151, 23.87379843848092, 35.64333813531058, 41.05480711800711, 49.802074977329795, 15.288604259490967, 0.06199619759406362, 0.0294405521958002, 0.3946574085525104, 0.9299420139619282, 3.0703672681535994, 5.2242536800248285, 1.5343987047672272, 0.9259194412401744, 32.78277519771031, 83.3569756916591, 61.970524651663645, 71.45928342001778, 63.042798451014924, 60.716583251953125, 64.04850155966622, 66.30334486280168, 59.06061213357108, 63.53345244271414, 63.206018584115164, 63.130206789289204, 62.28370080675398, 61.90070915222168, 61.17109966278076, 59.128760065351216, 49.10087319782802, 45.258092062813894, 44.71828651428223, 46.80262449809483, 59.45333126613072, 56.87853384017944, 62.98209203992571, 55.36812400817871, 58.10054131916591, 53.978869915008545, 51.72958517074585, 48.34209169660296, 50.161755425589426, 47.93454163415091, 44.94298778261457, 40.47273220334734, 45.195613861083984, 46.818751267024446, 53.74306542532784, 56.77728121621268, 58.566004616873606, 53.28899369921003, 47.97819716589791, 45.94626249585833, 55.4794202532087, 55.43358646120344, 56.95811850684029, 48.04093245097569, 52.118138858250205, 56.94263097218105, 58.41939762660435, 54.52912902832031, 57.22279623576573, 52.707787309374126, 55.97291953223092, 33.95455067498343, 37.03934587751116, 63.42406695229666, 48.58020646231515, 56.79990802492414, 48.821176937648225, 58.46492917197091, 53.44653367996216, 60.20775972093855, 54.442168848855154, 53.73682246889387, 45.27332946232387, 47.354005745479036, 44.65226820537022, 46.5892140524728, 50.778619970594136, 57.59277738843645, 52.886501925332205, 51.68649244308472, 55.03367246900286, 52.950018882751465, 44.89015020642962, 43.31838778087071, 41.05575554711478, 42.278034005846294, 43.90616716657366, 50.382753304072786, 55.01843159539359, 58.95055961608887, 54.13805661882673, 58.763069425310405, 57.58207368850708, 54.825146606990266, 47.375065735408235, 44.48355204718453, 44.56647184916905, 45.43419763020107, 44.90946619851248, 44.887291022709434, 45.91848012379238, 47.548492772238596, 48.18143197468349, 48.210795061928884, 49.21833596910749, 49.446205615997314, 50.915332726069856, 52.74837173734392, 60.356305258614675, 61.72874123709542, 70.73442649841309, 38.37711034502302, 0.2041921809847866, 0.8163116627505848, 2.430495934826987, 3.686503120831081, 0.5507276824542454, 0.08131458490554776, 0.24897526151367597, 6.878552453858512, 32.02467114584786, 25.247412136622838, 15.593451261520386, 45.97062635421753, 28.39296065058027, 35.621451309749055, 40.601440634046284, 45.28818818501064, 55.57241841724941, 64.23164912632534, 39.197852407182964, 0.35961606885705677, 0.033668483540947945, 0.04836096514814666, 0.04747987724840641, 0.010278825049421616, 0.06431325219039406, 0.022585969385025755, 0.036362583083765845, 0.0578108239652855, 0.04279450134241155, 0.04797912974442754, 0.028132966021075845, 0.03234774905389973, 0.05757668188640049, 0.04041176116360085, 0.07758962442832333, 0.031835831701755524, 0.015931157461766685, 0.08213320347879614, 0.08957615587860346, 0.21312510807599339, 0.21698827935116632, 0.10423675312527589, 0.1517487522214651, 0.09722220059484243, 0.11192647514066525, 0.18686063241745743, 0.2562222055026463, 0.12021321297756263, 0.1815421935170889, 0.29747824743390083, 0.10467790945300035, 0.1735473410891635, 0.16770816727408341, 0.11359301821461745, 0.34440874201910837, 10.045899203845433, 92.95800345284599, 75.74853842599052, 88.20276750837053, 78.88251645224435, 62.9977046421596, 30.62315000806536, 57.440861974443706, 46.47529138837542, 55.03626067297799, 20.901539734431676, 0.2898172613765512, 0.08329817346696343, 1.047668382525444, 3.6795349461691718, 4.019944999899183, 9.500624554497854, 8.42221462726593, 3.570961960724422, 34.63171168736049, 84.88987336839948, 63.916819299970356, 71.52666010175432, 68.18024090358189, 65.17851488930839, 64.41863904680524, 68.98733670370919, 60.442330905369346, 66.85131454467773, 65.82576043265206, 65.09933321816581, 63.91064929962158, 64.50480365753174, 63.319982937404085, 59.93031120300293, 51.488583428519114, 48.126381397247314, 47.76742703574044, 50.95472206388201, 63.68484674181257, 59.39516789572579, 65.68467726026262, 56.10834687096732, 60.9759247643607, 56.9771774155753, 52.281713349478586, 49.958204473767964, 51.69993025915963, 50.3949647630964, 46.72434956686837, 42.18212454659598, 47.557785987854004, 49.781202588762554, 56.956895623888286, 60.45927061353411, 62.37634113856724, 55.52493790217808, 50.78239631652832, 48.48088196345738, 57.54566165379116, 57.52558830806187, 57.252868039267405, 48.29637254987444, 54.13203253064837, 57.8715877532959, 61.55424417768206, 56.19897222518921, 59.546916552952354, 54.87850877216884, 58.33659594399588, 38.61048296519688, 39.44291884558541, 64.60485771724156, 51.928473881312776, 59.876928193228586, 50.61034154891968, 61.080745288303916, 56.47923823765346, 62.45305619921003, 57.65480743135725, 56.48610305786133, 48.1192421231951, 49.63735055923462, 46.290132318224224, 48.20896421160017, 53.33558137076241, 58.6045879636492, 53.5052980695452, 54.069345882960725, 59.151070731026785, 55.66691739218575, 48.74361767087664, 44.69181040355137, 43.02219649723598, 43.78115865162441, 46.22279732567923, 52.44428730010986, 59.29320308140346, 60.8424985068185, 56.98059245518276, 61.15848868233817, 60.58497742244175, 57.12431594303676, 50.718007360185894, 47.364056314740864, 46.98399680001395, 46.981078556605745, 49.61684989929199, 47.215354442596436, 48.997147015162874, 49.55210658482143, 51.587987831660676, 51.0736265863691, 53.268416609082905, 51.40382930210659, 54.2821900503976, 56.63520792552403, 63.08848285675049, 65.01990141187395, 73.238404410226, 40.31662007740566, 0.47115479516131537, 8.03287318774632, 6.162625704492841, 3.450802202735628, 0.8364368485552924, 0.11055278778076172, 0.9885826387575695, 13.465535044670105, 39.538150855473106, 35.8403126171657, 21.19064732960292, 65.38896192823137, 43.13740457807268, 38.580817631312776, 45.75685807636806, 54.26161643436977, 62.779447828020366, 72.83080223628453, 45.34131063733782, 0.6012505314179829, 0.19769847872001783, 0.13602852076292038, 0.10614885802247695, 0.09593214946133749, 0.13089994953147002, 0.09229199907609395, 0.06941192716892276, 0.1645521516246455, 0.26633292010852266, 0.14289159035044058, 0.1216157041490078, 0.07007889995085341, 0.17733679631991045, 0.1897140078778778, 0.12648815555231913, 0.0883258261850902, 0.20959699739302906, 0.15120612776705197], [0.022725026655410017, 0.05685850345928754, 0.02652640374643462, 0.014672815966020738, 0.03036777369145836, 0.02459425153210759, 0.07706365800861802, 0.020832405891269445, 0.049157694181693454, 0.023197594065485255, 0.02896042081660458, 0.056742833594658544, 0.0510868269151875, 0.08485904149711132, 0.0385305771071996, 0.10790632478892803, 0.045510517566331794, 31.659598895481654, 72.12791551862443, 64.58121994563511, 65.05485779898507, 48.0625205039978, 31.523431573595317, 23.582276344299316, 38.80424043110439, 38.77690274374825, 32.52604968207223, 5.377644283430917, 0.26602961495518684, 0.07645084589187588, 0.2927553451486996, 0.3292130859834807, 2.9997792158808028, 1.2979085147380829, 2.3838811218738556, 2.1169712841510773, 70.03374930790493, 63.99129009246826, 66.13250255584717, 58.166306018829346, 64.08183206830705, 54.68921552385603, 58.02847807747977, 58.827854428972515, 60.71487399509975, 58.42517852783203, 57.89332519258772, 57.37272099086216, 58.01553010940552, 59.58918939317976, 56.30609260286604, 50.8464343888419, 43.41084745952061, 41.75224992207119, 44.53036553519112, 47.255511556352886, 51.00396394729614, 55.93494067873274, 57.517677783966064, 56.18066372190203, 55.91604157856533, 55.03099741254534, 52.67277186257498, 51.94161639894758, 50.864360741206575, 46.84920522144863, 43.37054443359375, 41.59243093218122, 41.77665894372122, 41.15241541181292, 43.68630879265921, 48.67059210368565, 48.6999135017395, 43.24008158275059, 41.199663162231445, 47.83458832332066, 52.46917574746268, 54.64461503710066, 52.808991295950754, 47.67912932804653, 56.35353142874581, 52.512428283691406, 55.451512813568115, 51.52959517070225, 56.94670261655535, 50.31859711238316, 59.791201319013325, 30.60051277705601, 31.420608656747, 56.29865108217512, 52.841223989214214, 55.232877322605674, 52.99167333330427, 54.110868317740305, 46.95734003611973, 47.376420634133474, 51.603944369724815, 52.20110729762486, 49.63621800286429, 49.66032477787563, 47.27588714872088, 46.42785256249564, 46.91291672842843, 51.33021661213466, 52.128908566066194, 52.44978332519531, 52.039050987788606, 50.63466024398804, 41.52184418269566, 39.73222099031721, 40.106628145490376, 40.86283533913748, 41.38255017144339, 47.22930989946638, 51.34650666373116, 54.565242290496826, 53.592557021549766, 54.229394163404194, 55.332059383392334, 52.30993693215506, 43.46823957988194, 42.58092335292271, 40.438873631613596, 41.37270457404, 41.658966881888254, 42.2194641658238, 42.7052891595023, 45.39095204217093, 45.14492327826363, 45.67292036328997, 45.906376361846924, 46.814988817487446, 48.59490885053362, 52.84800543103899, 55.578914982931956, 60.33244514465332, 59.76960631779262, 61.095357349940706, 4.740005058901651, 1.4980067546878542, 2.423649136509214, 1.5328142983572823, 0.5879400627953666, 0.08961549733898469, 0.05070792278274894, 1.5947445694889342, 30.08804838997977, 24.300876413072857, 82.00523144858224, 114.86279705592564, 99.31034537724086, 17.4353665964944, 27.879009349005564, 45.40429605756487, 47.06071880885533, 49.54399456296648, 53.75380386625017, 8.973250201770238, 0.27247773323740276, 0.017433193113122667, 0.03688733831846288, 0.03558171480627997, 0.03130147858921971, 0.03133835357480815, 0.09842430680458035, 0.09933488044355597, 0.04322378669998475, 0.05917873699218035, 0.03629376266949943, 0.032505399880132506, 0.03102939622476697, 0.010655641838509058, 0.01960989782985832, 0.03616135334596038, 0.024119439867458174, 0.01653021397734327, 0.036812821602714915, 0.049829559201108556, 0.040248559920915535, 0.05096283821122987, 0.08492171099143368, 0.04581235029867717, 0.12561291323176452, 0.045387930037187676, 0.012676356443470078, 0.05178905976936221, 0.09487641682582242, 0.0328712320354368, 0.04108856252527662, 0.0460864954095866, 0.02051768947525748, 0.06747245695441961, 0.07833589081253324, 40.23264067513602, 84.06598377227783, 70.00435147966657, 74.09009374891008, 53.3410496030535, 43.55234752382551, 25.33383730479649, 36.287957259586875, 39.70432397297451, 39.234014306749614, 9.079434309686933, 0.4093619409416403, 0.20905993692576885, 0.977804245693343, 2.2880669832229614, 4.337744312626975, 2.0441061769212996, 2.0089163737637654, 2.551523349114827, 73.0682430267334, 66.50489125932965, 67.59996209825788, 62.798902784075054, 67.40259156908307, 58.60535226549421, 61.01122161320278, 60.757334436689106, 61.52358177730015, 60.78018706185477, 59.88911533355713, 60.17656230926514, 59.86096123286656, 59.69815799168178, 58.710992676871165, 52.99086386816842, 44.06170606613159, 43.44210393088204, 45.48945665359497, 48.635705198560444, 52.9600590297154, 58.83457333700997, 59.760483333042686, 58.44594669342041, 58.666051728384836, 57.15714618137905, 55.105700969696045, 55.22646760940552, 52.83699948447091, 50.26747226715088, 44.65391492843628, 43.36198425292969, 43.19825690133231, 41.8418538911002, 44.4977194241115, 52.187905720302034, 49.793063163757324, 45.6689772605896, 42.3304442678179, 49.188555989946636, 53.009231431143625, 56.29325580596924, 54.7115991456168, 51.112508705684114, 57.84489277430943, 53.94147818429129, 57.18564074380057, 52.84828335898263, 60.112117767333984, 53.596965653555735, 61.28227778843471, 34.452086857386995, 32.394179821014404, 55.70463221413748, 54.2336151940482, 56.823601382119314, 53.52754620143345, 56.397353717258994, 49.43966736112322, 49.91665077209473, 52.88708209991455, 54.846644333430696, 52.41170719691685, 50.786412375313894, 48.813638142177034, 49.94774396078927, 49.95368119648525, 54.594594955444336, 53.64762149538313, 53.0207758631025, 54.490198271615164, 54.49582631247384, 43.78986474445888, 41.7943560055324, 41.949992179870605, 42.784022671835764, 43.67439610617501, 48.98956305640084, 55.5296904700143, 58.41064984457833, 54.794720445360454, 55.76882662091936, 57.553540910993306, 55.212126527513774, 43.57855265481131, 44.578749316079275, 42.4614143371582, 43.88356120245797, 43.305196625845774, 43.548327990940635, 44.79987921033587, 47.96276869092669, 47.495728152138845, 48.29603556224278, 48.829393182482036, 49.17507301058088, 50.54025854383196, 55.77553163255964, 56.59402595247541, 62.69593048095703, 62.18637044089181, 65.50658103397915, 6.341117978096008, 1.0488490334578922, 0.5623565784522465, 2.461397179535457, 1.9947876461914607, 0.24183834876332963, 0.06055767621312823, 0.25400049186178614, 34.74949060167585, 24.55661702156067, 65.31759698050362, 106.2863437107631, 86.93011460985456, 26.809398446764263, 34.840536321912495, 52.306278705596924, 52.565463883536204, 56.451000758579795, 63.479207856314524, 12.723017539296832, 0.2166589591652155, 0.04971584691000836, 0.042087274470499585, 0.053919602052441666, 0.010734897273193513, 0.021665804653561542, 0.02387440051617367, 0.06511070047106061, 0.018657723208889365, 0.037631633558443615, 0.04621941363438964, 0.050596829636820724, 0.04391570582187601, 0.013321906178524452, 0.018409794994762967, 0.06176052202603646, 0.030738365769918476, 0.032152982362146885, 0.09091017608131681, 0.14457840126539978, 0.12093723698386125, 0.11868086377424852, 0.19569681398570538, 0.09830852837434836, 0.24656768356050762, 0.09868092196328299, 0.10644439394984927, 0.11988999960677964, 0.1664809145565544, 0.15487222533140863, 0.19622700767857687, 0.1861479263752699, 0.08916271770639078, 0.20654695534280368, 0.16623694050524915, 47.80370705468314, 91.07301276070731, 79.19709614345005, 82.60786260877336, 61.49945763179234, 43.5022405896868, 32.99750927516392, 51.24144990103585, 52.46856083188738, 50.23411743981497, 10.476908121790204, 0.47723761733089176, 0.30818515004856245, 1.3036228652511324, 2.8668755931513648, 8.630224585533142, 5.755833429949624, 8.43568023613521, 2.656806145395551, 79.28579684666225, 68.79934624263218, 72.52761759076799, 63.70800508771624, 69.47120230538505, 59.31039292471749, 64.50315693446568, 62.13555826459612, 65.67998027801514, 62.37165110451834, 63.327625955854145, 63.04339599609375, 64.37754045213971, 63.50170612335205, 62.2691512789045, 55.50419405528477, 46.94847413471767, 45.14593424115862, 48.18095602308001, 50.75472164154053, 54.89427423477173, 62.186592783246724, 61.80157920292446, 59.36287266867501, 60.86298179626465, 60.919025966099326, 57.04529755456107, 57.07189178466797, 56.37071432386126, 52.17921004976545, 47.64128943852016, 45.73648943219866, 45.348568030766074, 44.19042491912842, 47.99454975128174, 54.42893600463867, 51.76829705919538, 46.89277390071324, 43.701170989445274, 52.45272936139788, 57.74642637797764, 58.25928333827427, 54.1118723324367, 52.47009638377598, 60.192202704293386, 56.19743319920131, 60.065495354788645, 55.530051776341026, 61.22943673815046, 55.73051077978951, 65.28826863425118, 37.26847662244524, 36.3339786529541, 57.052363872528076, 56.83159181049892, 59.158873558044434, 55.78461292811802, 60.5464357648577, 51.54244933809553, 50.336773599897114, 55.34521927152361, 56.00242158344814, 54.542122159685405, 53.778681891305105, 51.619362422398154, 50.55577039718628, 51.73893397194998, 56.270024503980366, 55.07615375518799, 56.457552909851074, 56.042599541800364, 56.99587154388428, 46.50901794433594, 43.74352025985718, 44.8263692174639, 46.50763872691563, 46.01200287682669, 51.110726492745535, 56.9049265725272, 60.248490061078755, 56.495695046016145, 56.461308411189485, 61.2061950138637, 56.97371373857771, 46.19995512281145, 47.42339393070766, 45.30664260046822, 45.845861026218955, 46.456072671072825, 47.17964417593819, 47.89226879392351, 51.87060233524868, 51.06812361308506, 51.58065400804792, 50.86452054977417, 51.9662686075483, 54.18584285463606, 57.503270694187705, 60.310384614127024, 66.77653108324323, 65.22881984710693, 67.27332033429826, 6.66348659992218, 3.493678016322, 9.955266901424952, 2.7875614719731465, 1.942802527121135, 0.5508241429924965, 0.15523422376385757, 2.4638451167515347, 40.97178309304373, 38.08473709651402, 88.8186697278704, 114.29690102168492, 106.43925966535295, 25.64409521647862, 40.52546208245413, 59.63356753758022, 61.94751916612898, 62.660216740199495, 70.38987227848598, 14.810078348432269, 0.3659488633275032, 0.15808981124843868, 0.08499204793146678, 0.21791910726044858, 0.07632966632289545, 0.1162467822432518, 0.1298203460339989, 0.2369489882673536, 0.07975722490144627, 0.10208319154168878, 0.16555567777582578, 0.1719818115234375, 0.1134022752355252, 0.09640352773879256, 0.12444286101630755, 0.14993382032428468, 0.07877853313194853, 0.14408924537045614], [0.03444487348731075, 0.02130575361661613, 0.03851708783102887, 0.025951219789151634, 0.02137142902107111, 0.01872408563005073, 0.04569550996114101, 0.029402801900037696, 0.023984126414039304, 0.06921204432312932, 0.050089587390955, 0.08250115944870881, 0.04008078535220452, 0.025679866849843944, 0.015234510647132993, 0.023079366123835956, 1.7253862278802055, 61.41735771724156, 60.72806862422398, 65.48698016575405, 52.79669645854405, 44.59918744223458, 15.710391180855886, 31.733652796064103, 54.63717699050903, 36.298421246664866, 26.37693735531398, 0.7012282152261052, 0.07650434159274612, 0.03795194958469697, 0.17942764769707406, 0.5189684980681964, 3.3560155289513722, 1.3730658761092593, 1.6922934779099055, 23.81368609837123, 78.90677956172398, 60.84377697535923, 63.74395506722586, 57.13713536943708, 62.89895684378487, 57.31314366204398, 65.17061478751046, 58.55540861402239, 60.99446950639997, 57.58928591864449, 57.165563923971995, 52.35911280768258, 53.369509424482075, 48.63403068270002, 48.205677713666645, 43.488285132816856, 43.875918184007915, 43.17041894367763, 43.3845728465489, 43.254919460841585, 49.15274844850813, 56.99929700578962, 59.769342286246165, 55.60702044623238, 55.20625529970442, 54.819640159606934, 55.91086517061506, 54.69367626735142, 54.923804078783306, 50.72268349783761, 43.777587277548655, 39.323788506644114, 40.95980439867292, 39.796891348702566, 39.71597957611084, 40.13989264624459, 40.91496072496687, 40.64939362662179, 46.47604179382324, 49.562021664210725, 54.62687628609793, 51.660575662340435, 48.74178682054792, 51.87796742575509, 53.6447935785566, 51.19393464497158, 52.075615882873535, 51.542136669158936, 53.71065902709961, 48.112728187016074, 57.54122870309012, 33.69706085750035, 28.01056480407715, 45.123856340135845, 42.37293945040022, 51.33241919108799, 49.68597057887486, 51.94865492412022, 51.98447288785662, 46.257350717272075, 48.30010025841849, 55.79722738265991, 51.65423890522548, 52.88781860896519, 50.65521648951939, 50.84355436052595, 48.141618796757285, 54.476993220193044, 50.41046619415283, 51.9055552482605, 52.16562284742083, 50.8156156539917, 44.27852807726179, 39.42293235233852, 38.36734117780413, 40.66745546885899, 39.55528163909912, 45.1860739844186, 51.87561546053205, 54.92018059321812, 52.15168128694807, 54.94126142774309, 54.61219126837594, 49.39492096219744, 40.375672817230225, 42.20413643973214, 40.68291868482317, 42.10793515614101, 40.09538943426949, 42.72294800622122, 41.548511368887766, 44.31045157568795, 44.25779117856707, 43.77005543027605, 45.897920404161724, 50.927714415958945, 52.820309911455425, 57.37855052947998, 53.73732968739101, 60.78743403298514, 62.02899374280657, 66.47263077327183, 29.604287011282786, 0.07477098996085779, 0.8121135394488062, 7.288252983774457, 1.2859893143177032, 0.6186059372765678, 0.3041091359087399, 0.04381704683016453, 12.611335669245038, 39.12973574229649, 38.26749903815133, 56.42264516013009, 31.40030254636492, 27.89811863218035, 19.601599522999354, 27.927858659199305, 40.04388243811471, 49.23797852652413, 59.30118656158447, 33.92168916974749, 0.76753688284329, 0.014077903603070548, 0.026849271064358096, 0.02619426933649395, 0.044290375895798206, 0.09032733485634838, 0.029678673882569586, 0.022819904510730078, 0.06826467373009239, 0.02028095199992614, 0.031661102149103365, 0.04319640781198229, 0.016719443823343942, 0.08858441588069711, 0.03590296381818397, 0.020946085951956253, 0.00406849173097206, 0.05523532216570207, 0.018525137466245463, 0.08120402440960918, 0.015720545280990855, 0.024732706602662802, 0.012448269441457731, 0.022264474404177496, 0.026817841322294304, 0.022350529607917582, 0.020754279369222264, 0.04006993218458124, 0.054519063992691894, 0.06862543044345719, 0.03548979366730366, 0.041632693327431164, 0.02674705146013626, 0.08620237798563071, 2.550478513751711, 70.85026686532157, 69.11696924482072, 71.08564404078892, 60.299184117998394, 54.02646507535662, 24.864100864955358, 25.113428286143712, 44.46345438276018, 38.51348958696638, 33.39387968608311, 1.0598564999444144, 0.03848461653771145, 0.07196523408804621, 1.4380646454436439, 2.63203256045069, 3.982149839401245, 1.7319246998855045, 1.2471331421818053, 26.760943446840557, 81.96369511740548, 63.27355507441929, 68.04729407174247, 58.1735634122576, 64.6802248273577, 60.416956084115164, 66.30539458138603, 60.90625517708914, 64.42718533107212, 59.54310894012451, 59.72852161952427, 55.300142833164756, 55.57061535971505, 49.79708269664219, 50.02130453927176, 45.484787464141846, 45.099700927734375, 44.750081471034456, 44.38275800432478, 45.707432065691265, 51.0488805770874, 57.386975220271516, 61.04662963322231, 56.16473497663225, 56.79884842463902, 59.01060594831194, 56.98437227521624, 56.620891162327354, 56.311578205653596, 53.69626930781773, 45.782423973083496, 42.138680934906006, 41.77894490105765, 40.96253851481846, 41.15448944909232, 42.32792207172939, 43.896088804517476, 43.282542024339946, 50.266944204057964, 50.48562833241054, 57.27541494369507, 54.112726960863384, 50.55783748626709, 54.7484176499503, 56.280776841299875, 54.685859543936594, 54.4574270929609, 53.18945380619594, 56.262312003544395, 51.44041851588658, 59.394563402448384, 37.13122885567801, 29.94252531869071, 45.26293495723179, 44.769821303231375, 51.841548442840576, 50.88240868704659, 55.1726781300136, 53.58409758976528, 47.973726000104634, 47.33983142035348, 56.6766539301191, 53.87173216683524, 55.115056719098774, 51.9312288420541, 53.6104416847229, 50.30629185267857, 54.901962416512625, 51.719624928065706, 53.41964067731585, 53.428642068590435, 53.36717482975551, 46.62155096871512, 40.381967885153635, 41.05046101978847, 42.60507181712559, 41.09828894478934, 46.60647685187203, 52.65279579162598, 55.658218247549875, 55.75240455354963, 57.4477094241551, 55.86845336641584, 49.939475604466026, 43.172659737723215, 45.03576707839966, 44.04200097492763, 43.82734680175781, 43.869907992226736, 44.83012124470302, 43.591299125126426, 45.89554412024361, 47.677906445094514, 45.750000204358784, 47.52793652670724, 52.9339268548148, 55.39920677457537, 59.22679219927107, 57.955751282828196, 62.6428462437221, 64.72715990883964, 66.90858854566301, 33.44055073601859, 0.05975764271404062, 1.0002451900924956, 4.2592379195349555, 3.1636835294110432, 0.995907125728471, 0.044255109038203955, 0.16237873610641274, 10.592126624924795, 47.18730803898403, 39.764380727495464, 76.16275528499058, 39.84140150887625, 28.14522784096854, 30.274645737239293, 34.28266545704433, 45.07432263238089, 55.70613997323172, 66.01823943001884, 42.01857437406267, 0.9277080595493317, 0.056594879033842256, 0.047183299769780467, 0.02279942462752972, 0.047452498360403945, 0.029018533948276724, 0.051423332786985805, 0.012740618798748722, 0.029747592684413706, 0.050820223721010346, 0.018666866468265653, 0.057016978705567975, 0.04254904808476567, 0.03859865791829569, 0.01927065067658467, 0.033506008330732584, 0.0447560137669955, 0.029649340813713412, 0.0606197893087353, 0.12845845839806966, 0.1230436810957534, 0.07648393804473536, 0.11468541888254029, 0.09776152736906495, 0.15825977069990976, 0.13397285821182386, 0.14300973686788762, 0.1424350177070924, 0.18058810542736733, 0.11336844347949539, 0.17978013306856155, 0.11703960970044136, 0.11521353625825473, 0.12845921835729054, 3.494588230337415, 79.97877543313163, 75.87786524636405, 81.49444157736642, 67.45855236053467, 62.60245636531285, 24.748224020004272, 43.37807280676705, 70.10745579855782, 51.20740720203945, 39.14519548416138, 1.330832770892552, 0.2473120093345642, 0.17529291313673767, 0.9057864929948534, 3.1229887987886156, 7.9053129468645364, 9.999944686889648, 3.5369459688663483, 30.957452160971506, 87.06608390808105, 66.20436082567487, 70.23300279889787, 60.36332293919155, 68.09256853376115, 63.15415028163365, 69.67093522208077, 63.10710402897426, 66.6713284083775, 62.131556102207725, 62.06173365456717, 57.434490476335796, 57.737021991184776, 52.316277163369314, 52.73334625789097, 48.28163194656372, 48.76734924316406, 47.13217060906546, 46.54377630778721, 48.725409916469026, 53.707442011152, 62.83126054491316, 63.568631172180176, 58.725569997514995, 59.643586839948384, 60.88828713553292, 59.771975653512136, 59.43564115251814, 59.23620006016323, 55.88149166107178, 48.749815464019775, 42.809456552777974, 44.759520598820274, 43.74171372822353, 42.959659235818044, 45.09234625952584, 44.92350850786482, 46.77093376432146, 53.38858917781285, 54.20539855957031, 60.08605507441929, 55.081990242004395, 52.715822901044575, 57.429241112300325, 59.310184478759766, 57.22840690612793, 56.66081551143101, 56.34361287525722, 58.88276604243687, 52.68591785430908, 60.8062983921596, 39.31258801051548, 32.96923358099801, 46.19075223377773, 45.92379896981375, 53.614603655678884, 52.40760081154959, 56.37582472392491, 56.80614750725882, 48.16700056621006, 49.329600947243826, 60.28732354300362, 56.104445457458496, 58.15987893513271, 55.73862974984305, 54.94213342666626, 52.57975285393851, 57.863187381199424, 54.13544062205723, 55.361960956028526, 55.042691230773926, 55.79604966299874, 48.324047224862234, 42.8534699167524, 43.05419989994594, 44.477795464651926, 43.300881794520784, 49.736279010772705, 56.36493342263358, 58.73500565120152, 54.53492035184588, 60.09761687687465, 58.52150140489851, 52.19209548405239, 44.40142433983939, 47.05837031773159, 46.963371072496685, 47.02664136886597, 46.40318298339844, 47.582542419433594, 46.32656519753592, 48.98412261690412, 50.25179018293108, 49.057888167245046, 49.717421599796836, 54.62319721494402, 57.68769325528826, 63.67133944375174, 60.53063556126186, 66.6116920198713, 66.11161627088273, 71.02436787741524, 34.869235856192454, 0.20849295306418622, 5.2428679040500095, 15.210386650902883, 4.149024290697915, 1.4538621348994119, 0.6950304763657706, 0.3732050625341279, 15.220272200448171, 54.81201451165335, 49.031311307634624, 63.580498695373535, 40.26842737197876, 39.00399419239589, 31.481221267155238, 40.25092485972813, 53.02703966413225, 64.37544904436383, 73.4711412702288, 47.17968586512974, 1.3358870425394602, 0.1243526701416288, 0.12109681484954697, 0.08453410464738097, 0.16679629763322218, 0.2163472401776484, 0.1675599209432091, 0.13667986009802136, 0.20890934286373003, 0.12421946014676775, 0.15731985042137758, 0.09661261151943888, 0.2372543290257454, 0.188589444650071, 0.1621895876846143, 0.12333573613848005, 0.10863987542688847, 0.09888282005808183], [0.012485925590486398, 0.01760432473383844, 0.02433103762034859, 0.014172041855220283, 0.0269097404088825, 0.03923764452338219, 0.07661589274981193, 0.013557981234043837, 0.05638554419523903, 0.06499479990452528, 0.07765309459396771, 0.023595675293888365, 0.11186115935977016, 0.07706232807998147, 0.18766728841832706, 0.07306159061512776, 13.50337667124612, 76.48623561859131, 58.62587029593331, 66.60460485730852, 53.04185322352818, 28.307857377188547, 21.416526317596436, 57.437481675829204, 48.07897383826119, 41.09794153485979, 22.68944845880781, 0.5542107384119714, 0.08954528932060514, 0.14381703069167479, 0.6615160033106804, 3.2201415513242995, 1.6544869180236543, 1.3269885714565004, 0.2998381650873593, 57.01257153919765, 70.17311627524239, 64.60719231196812, 57.395618779318674, 58.3735534123012, 60.51504380362374, 62.918286732264924, 60.383889607020784, 61.16529096875872, 61.79649312155587, 60.886174883161274, 58.562203952244346, 57.10991580145699, 52.20688819885254, 46.99280364172799, 41.765746797834126, 42.08781317302159, 42.644068581717356, 40.51869453702654, 43.07460675920759, 43.503036158425466, 52.763758523123606, 57.825107778821675, 54.84663043703352, 51.67046294893537, 55.09577546800886, 55.36638001033238, 56.710839067186626, 53.796973024095806, 55.655689103262766, 51.66537686756679, 45.7999438558306, 40.66059412275042, 40.54683821541922, 40.24006135123116, 41.56123699460711, 42.022889205387656, 40.478388037000386, 40.374182428632466, 48.88258511679513, 49.68011324746268, 54.6567257472447, 47.9178729057312, 52.16354881014143, 52.65657908575875, 50.27851642881121, 48.11928033828735, 50.755284445626394, 49.10633100782122, 51.93688814980643, 50.18254790987287, 58.59331103733608, 39.1185873576573, 30.591118812561035, 52.48720284870693, 45.21328313010079, 50.06704453059605, 46.07768767220633, 50.687970297677175, 48.212810039520264, 55.024243763514924, 51.39307696478707, 53.326659883771626, 50.95052535193307, 52.83383805411202, 52.29147556849888, 51.9831040927342, 51.26003980636597, 52.70163120542254, 49.54074280602591, 50.57152196339199, 53.37670081002371, 50.94026633671352, 43.03884438105992, 40.69778782980782, 40.07721989495413, 40.48792791366577, 39.2736850466047, 45.3844450541905, 52.28302655901228, 53.393810749053955, 53.88673332759312, 55.76822560174124, 52.5314177104405, 49.44781412397112, 43.81248460497175, 41.03993449892317, 41.06586170196533, 39.82750858579363, 43.108402797154014, 40.379153864724294, 43.66047191619873, 41.59440769468035, 43.001695837293354, 44.10695620945522, 53.25333901814052, 55.55959899084908, 59.41879177093506, 55.46957465580532, 65.7360452924456, 63.12776797158377, 61.42252022879464, 49.1330155645098, 55.51411608287266, 8.33686990397317, 0.7562632677810532, 2.1264162744794572, 3.263059054102216, 0.2688237407377788, 0.19723746845764772, 0.07773575372993946, 0.8627652557832854, 33.91362925938198, 31.521152564457484, 11.840301019804818, 21.126935822623118, 54.530435289655415, 10.353118147168841, 16.289657286235265, 37.038578101566856, 47.00257975714547, 55.00598737171718, 52.79253796168736, 4.737756013870239, 0.0904779832011887, 0.10846007043229682, 0.06989083718508482, 0.06293211451598577, 0.02006690134294331, 0.0379003775306046, 0.03106791665777564, 0.005550893123394677, 0.03554295010066458, 0.026521158670740466, 0.023797139126275266, 0.035990454123488495, 0.0033208298970878658, 0.03133089308227811, 0.01838000221843166, 0.04589229529457433, 0.013213222680081214, 0.050800071230956485, 0.021750456986150572, 0.07748823094048671, 0.032257782095777135, 0.007225697361198919, 0.06886432905282293, 0.04624928953126073, 0.02727264807825642, 0.06497031157570225, 0.04991743287869862, 0.02509505278430879, 0.034450278018734286, 0.008607474554862295, 0.062265087451253615, 0.20456696301698685, 0.19793923651533468, 18.018292665481567, 89.16871997288295, 62.630950927734375, 76.424070085798, 59.52701691218785, 43.191360814230784, 25.483558825084142, 47.82394020898001, 52.65699945177351, 45.246756076812744, 24.031565972736903, 0.13329411963266985, 0.09470559563487768, 0.8142641697611127, 1.8532261337552751, 4.342783059392657, 4.818316033908299, 2.153304934501648, 0.2578040877623217, 57.90704093660627, 74.35087353842599, 65.09619263240269, 62.67301532200405, 58.96384457179478, 62.94915063040597, 63.56251675742013, 62.37640367235456, 62.893822125026155, 64.90552711486816, 61.492328780038015, 61.519176619393484, 58.81077575683594, 53.70528112139021, 48.40344429016113, 44.24781009129116, 44.75331238337925, 44.60960974012102, 42.634521756853374, 45.68775824138096, 45.66263355527605, 54.76775448662894, 57.841005257197786, 56.75143739155361, 53.81696646554129, 58.419203077043804, 56.869469915117534, 58.943541935511995, 55.67353555134365, 57.38475527082171, 53.22809968675886, 47.58106940133231, 42.976331438337056, 43.27186264310564, 41.16167736053467, 43.09479475021362, 43.81906802313668, 42.40142706462315, 42.2317659514291, 52.27240971156529, 53.06421947479248, 55.73738602229527, 51.30880226407732, 55.44247668130057, 55.28707674571446, 53.75084740774972, 49.6455841745649, 52.33003807067871, 50.79653590066092, 54.14737415313721, 52.063248089381624, 60.64234175000872, 41.24569845199585, 31.67668798991612, 52.83505746296474, 46.36710793631417, 52.58176435743059, 47.325184617723735, 50.93165404456002, 49.6044682094029, 55.50797387531826, 52.46839754922049, 54.34831258228847, 51.8996319089617, 55.1649169921875, 54.88374423980713, 54.05850669315883, 53.93264354978289, 53.696936334882466, 50.97029645102364, 51.961609840393066, 54.975793974740164, 52.47334814071655, 45.324832984379356, 42.2857916695731, 43.276924405779155, 42.10734108516148, 40.70949901853289, 47.47397681644985, 53.81198460715157, 56.16229963302612, 56.29184184755598, 56.75886501584734, 53.63974918637957, 50.64405420848301, 44.82254076004028, 42.80572189603533, 42.263998644692556, 42.047395501817974, 45.864093099321636, 41.67364842551095, 45.093492712293354, 44.76712192807879, 44.755045958927695, 45.29762036459786, 54.017637389046804, 58.27308246067592, 60.47582122257778, 58.144127368927, 64.38993603842599, 64.40996769496373, 63.345906666346956, 52.174572127205984, 60.42597484588623, 10.230361717087881, 0.811938043151583, 1.0873021015099116, 3.2320344788687567, 1.7074896224907465, 0.7516796823058809, 0.03678383458671825, 0.3624884161565985, 36.67896366119385, 38.76160281045096, 13.429725766181946, 25.55912743295942, 55.37006255558559, 15.634379625320435, 22.055911711284093, 44.651097433907644, 53.396107128688264, 59.42270360674177, 62.150663648332866, 7.093459367752075, 0.0908532944907035, 0.09328118778233017, 0.03708764864131808, 0.04935776701729212, 0.045898571743496826, 0.056739902323377986, 0.026010864713628377, 0.009464348084293306, 0.016289829376286695, 0.06839704234153032, 0.01069728098809719, 0.03419519295649869, 0.05030361429921218, 0.042090992842401774, 0.04260076263121196, 0.10658377182802983, 0.032437339425086975, 0.23392220639756747, 0.1338010531451021, 0.1659486445465258, 0.12175442384822027, 0.1053240444245083, 0.13123682859752858, 0.1556327680924109, 0.08752090044851814, 0.21084972231515817, 0.09988199679979257, 0.1665075674120869, 0.1253609053258385, 0.21437678805419377, 0.1645863905016865, 0.36176702486617224, 0.2710769926863057, 22.093277386256627, 95.97051307133266, 72.36441830226353, 83.703996522086, 69.5896829877581, 41.790037700108115, 30.872322831835064, 76.27131393977574, 62.85222326006208, 58.84676742553711, 31.33883878162929, 0.9234094044991902, 0.22589861122625216, 1.5117768900735038, 3.0994967222213745, 9.3972145148686, 8.095088226454598, 6.981620294707162, 0.32671637567026274, 65.14323193686349, 75.51983846936906, 70.56520312173026, 62.17985997881208, 63.98920563289097, 63.95160893031529, 67.69672271183559, 64.0968679700579, 65.97595964159284, 66.67470523289272, 63.849776131766184, 64.3578075681414, 62.615164620535715, 55.90992021560669, 52.47832999910627, 45.48550312859671, 47.31686762401036, 46.79390450886318, 44.623349802834646, 47.35306773866926, 47.98004886082241, 57.11815289088658, 61.29049750736782, 58.2123760495867, 54.46518823078701, 59.13961315155029, 59.72197641645159, 60.51013837541853, 58.443591254098074, 59.64685944148472, 56.45210552215576, 49.10053621019636, 44.87007686070034, 44.4493738583156, 43.75632578986031, 45.86256796973092, 45.51691593442644, 43.75129876817976, 44.448362895420615, 54.491195338112966, 54.92482198987688, 57.81711387634277, 51.60310711179461, 56.42991644995553, 58.97186974116734, 55.79899222510201, 52.66286720548357, 53.359517914908274, 53.48368917192732, 55.451933179582866, 54.927740233285085, 62.36744744437081, 45.40512636729649, 34.10665021623884, 53.4843874658857, 48.524235248565674, 55.040040493011475, 49.17419753755842, 53.724263599940706, 51.680899143218994, 58.83879089355469, 57.03988838195801, 56.36026075908116, 53.39480086735317, 54.7341217313494, 56.89906576701573, 55.73839003699166, 55.71547140393938, 56.199166774749756, 52.14549044200352, 53.6983676637922, 57.02677713121687, 55.256365707942415, 47.15652404512678, 44.589366163526265, 45.05491631371634, 43.80526890073504, 42.78044087546212, 50.20299645832607, 57.48454877308437, 58.01322330747332, 57.90457780020577, 59.74838651929583, 55.487459318978445, 54.70388317108154, 47.866091455732075, 45.64001716886248, 45.19168812888009, 44.40307453700474, 48.71088470731463, 44.80525711604527, 48.52801854269845, 46.82668610981533, 47.249886989593506, 47.65704100472586, 56.42822108949934, 61.60879448481968, 62.89738655090332, 61.3048802784511, 67.98450320107597, 67.15128912244523, 66.27482945578438, 52.55679947989327, 62.892126764569966, 11.66042605468205, 1.5540865340403147, 12.494741422789437, 7.558636920792716, 2.1414300288472856, 0.5945555620959827, 0.12382095653031554, 1.2531627672059196, 42.88001898356846, 46.49825518471854, 18.018289191382273, 29.646764823368617, 74.02727508544922, 17.211742298943655, 25.563030583517893, 50.60054458890642, 61.195334979466026, 65.79801627567836, 70.7760740007673, 8.157191225460597, 0.15655136880065712, 0.14082253351807594, 0.15537704181458267, 0.21824945881962776, 0.1559590348707778, 0.315582810235875, 0.06524082313158683, 0.12394913179533822, 0.10033267975917884, 0.14324418428753102, 0.07412269724799053, 0.09499133351658072, 0.11171202414802142, 0.10578400974294969, 0.12524715571531228, 0.21355110593140125, 0.09308623788612229], [0.012628203357702919, 0.060606836075229306, 0.11205332726240158, 0.0741541948435562, 0.013961940272045987, 0.06215391627379826, 0.03624907774584634, 0.03598680021241307, 0.03301745633195553, 0.039591866944517405, 0.031712847229625495, 0.03429843884493623, 0.028297907706083994, 0.09453644364007882, 0.07779114254351173, 0.056603991759142706, 38.353086948394775, 71.89718668801444, 62.89262008666992, 64.15517725263322, 39.933854239327566, 28.727959360395158, 22.173251152038574, 33.56633744921003, 24.808996438980103, 51.19773530960083, 17.195639848709106, 0.23630622561488832, 0.10567849754754986, 1.2244702896901538, 2.650828089032854, 3.0031562575272153, 2.2810041393552507, 2.059819528034755, 9.091878533363342, 74.41090597425188, 60.03321402413504, 64.98299952915737, 56.277792590005056, 57.086833885737825, 55.939655031476704, 60.68174498421805, 59.68812479291643, 60.75453431265694, 57.54895857402256, 58.76473004477364, 57.412520272391184, 58.336102621895925, 51.47190080370222, 42.5985300881522, 44.00061403002058, 43.686638832092285, 41.81321689060756, 42.83469935825893, 40.79404122488839, 43.600071225847515, 52.11702367237636, 55.70766510282244, 54.18093395233154, 55.63613339832851, 55.016107422964915, 55.648879868643625, 54.399996757507324, 55.05189759390694, 55.65147154671805, 54.12245443889073, 45.49718999862671, 40.07269661767142, 39.71742132731846, 40.74291637965611, 39.85349832262312, 40.0216829436166, 39.42070198059082, 42.699153900146484, 50.052977902548655, 53.064917768750874, 51.58556638445173, 49.783578872680664, 54.38285902568272, 50.22259037835257, 47.95900624138968, 46.83267893110003, 47.5451055254255, 45.69355998720442, 50.628768171582905, 49.686901637486045, 55.6929383959089, 40.50280400684902, 34.0366644859314, 55.42425503049578, 48.895678997039795, 55.52697025026594, 48.55912562779018, 50.867338044302805, 46.25765643801008, 51.343373026166645, 49.10966961724417, 54.27465125492641, 48.55203151702881, 49.21729026521955, 48.772032329014365, 51.57019002096993, 49.26595892224993, 51.4750657081604, 45.37449870790754, 51.411097117832725, 52.37633044379098, 50.93417624064854, 43.67198508126395, 40.286044529506135, 38.52600676672799, 39.969026020595, 37.793819495609824, 42.497541495731895, 48.60213497706822, 52.79608849116734, 52.8620651108878, 54.54479374204363, 52.16862794331142, 47.9444636617388, 40.00650460379464, 40.012924739292686, 37.841438974652974, 42.710944993155344, 41.068488121032715, 43.955127647944856, 41.45241430827549, 44.5612850189209, 45.45859622955322, 53.708115986415315, 52.83802086966378, 59.60021618434361, 54.92164666312081, 62.47950799124581, 64.33983952658517, 57.528346742902485, 55.428983279636924, 63.639197077069966, 52.809272697993684, 47.117895535060335, 0.9671203047037125, 2.099778618131365, 2.9299956347261156, 0.43435539837394443, 0.44114642111318453, 0.09287097943680626, 0.3262917755969933, 15.785363980701991, 52.23461151123047, 41.03655072620937, 17.778241089412145, 25.789640869413102, 38.52258130482265, 18.713928937911987, 31.04156357901437, 42.79892308371407, 49.10208565848214, 60.180967467171804, 24.23091847555978, 0.646238597376006, 0.08602378078337226, 0.08587844536772796, 0.008787498376997454, 0.04496951141793813, 0.0270849483287228, 0.05719425954989024, 0.07854234187730721, 0.004446403930030231, 0.058572940927531035, 0.05071500329566853, 0.03880329729456987, 0.039093106386384795, 0.01885802505005683, 0.05223362912823047, 0.072805335079985, 0.026601319101506045, 0.037556970957666636, 0.07978545195822205, 0.028095154657161663, 0.04454742870958788, 0.04216060035728982, 0.06060644931026867, 0.07354287550385509, 0.04896551610103675, 0.03296534823519843, 0.011259785670387958, 0.024565069437293068, 0.010777700110338628, 0.016614808634455715, 0.029118156459714686, 0.061025716098291535, 0.07670287415385246, 46.99764653614589, 79.42582389286586, 69.28644275665283, 69.15052904401506, 49.27044398444039, 30.90659134728568, 26.10966100011553, 36.03449739728655, 27.90698627063206, 60.378178187779014, 15.890161922999791, 0.47351381714854923, 0.05743814539164305, 1.3153391565595354, 2.056361279317311, 2.6443547563893453, 2.3424670355660573, 1.8651564078671592, 10.293910809925624, 78.71634333474296, 63.257685388837544, 66.70601381574357, 58.43103585924421, 59.01153700692313, 58.85866274152483, 64.45183753967285, 62.90521717071533, 62.692803791591096, 59.26998914991106, 60.814837728227886, 60.61958639962332, 59.74031271253313, 52.503791672842844, 44.564290114811485, 45.41647277559553, 44.121839250837056, 43.725983006613596, 44.734586988176616, 42.833167280469624, 45.51914283207485, 55.28140006746565, 57.820886748177664, 56.34064599445888, 57.4778402873448, 56.31260306494576, 58.991039821079795, 56.783736092703684, 56.71180486679077, 58.686020851135254, 56.61938687733242, 46.28934369768415, 42.57914808818272, 40.51996258326939, 41.614925725119456, 41.41717651912144, 41.12025220053536, 41.20635775157383, 45.30807045527867, 51.653022970472065, 56.7324583871024, 52.45576919828142, 50.017965929848806, 57.13948733466012, 52.14658825738089, 50.113732951028005, 49.7594894681658, 48.982621806008474, 48.34868901116507, 52.758724553244456, 52.809418610164094, 57.52693278448922, 42.428462505340576, 34.286156926836284, 57.32003974914551, 51.37740182876587, 56.431073325020925, 50.74595301491873, 53.44146496909005, 50.43296446119036, 53.999947275434224, 52.50938844680786, 55.14916542598179, 49.02692699432373, 49.675867898123606, 51.07816028594971, 53.725215503147666, 51.44427129200527, 53.296866008213584, 46.50502273014614, 52.46149451392037, 54.22247723170689, 53.42535557065691, 46.76365205219814, 42.00800963810512, 40.02045658656529, 41.568893909454346, 40.01202147347586, 44.34420592444283, 50.57077155794416, 55.42295919145857, 55.727161748068674, 55.90397950581142, 54.68706505639212, 49.342667034694124, 42.025161266326904, 43.32250806263515, 40.65619938714163, 43.75436292375837, 43.386344637189595, 45.353893824986045, 43.45843914576939, 46.39763137272426, 47.40667309079851, 56.55057539258684, 56.25658668790545, 62.821484429495676, 57.37526750564575, 62.38721506936209, 63.74378136226109, 61.49638652801514, 57.036858967372346, 65.08943898337228, 55.537059034620015, 52.56145477294922, 1.9360556091581071, 1.1127934136560984, 1.2691074716193336, 2.7908158344881873, 1.5703913505588258, 0.10597239142017705, 0.325844403888498, 14.54789241722652, 62.410686084202354, 29.090827294758387, 16.668672834123882, 32.61556679861886, 36.76750455583845, 24.873293331691197, 37.878021240234375, 50.07986395699637, 54.37361444745745, 67.49555846623012, 31.266143253871373, 0.7527233234473637, 0.10415918978729419, 0.05744586033480508, 0.0463281726198537, 0.032529094322983704, 0.03260931073288832, 0.04162477143108845, 0.007626856594080371, 0.0013197810393259196, 0.04465664231351443, 0.03917644405737519, 0.023371292244909064, 0.024024865656558956, 0.06496404869748013, 0.12774686515331268, 0.05208575938429151, 0.04886044495339904, 0.12330482208303042, 0.1263591524745737, 0.18960834640477384, 0.18071809916624001, 0.08835943402456385, 0.1617166759180171, 0.1469322256743908, 0.08769190484391791, 0.09877754534993853, 0.11934026410537106, 0.16168346841420445, 0.18587480245956353, 0.11216714472642966, 0.27894512191414833, 0.11764461866446904, 0.19190597454352037, 52.69673619951521, 87.19181156158447, 80.59764453342983, 79.30363982064384, 54.50377852576119, 39.879015581948416, 32.44460637228829, 47.64361361094883, 37.165354933057515, 67.75402450561523, 20.876201391220093, 0.6437221009816442, 0.1304799634963274, 3.0254523754119873, 7.732863000461033, 11.284264479364667, 8.368726525987897, 5.76767098903656, 11.641259448868887, 81.96448721204484, 64.4604741505214, 68.92248221806118, 61.58705357142857, 61.75180230821882, 61.109232902526855, 66.50953265598842, 64.43444619859967, 65.54686668940953, 59.43555082593645, 63.45325633457729, 62.956807545253206, 63.333344323294504, 55.86507306780134, 46.299001693725586, 48.21110773086548, 47.29365021841866, 46.589683055877686, 48.0915778705052, 45.19468627657209, 48.584493500845774, 56.478939465114046, 60.44506849561419, 58.22359044211251, 58.12695837020874, 59.340958050319124, 61.37372997828892, 58.89228507450649, 58.24806547164917, 61.60073457445417, 59.46988187517439, 49.320356369018555, 44.43243762425014, 42.82078906467983, 43.44742625100272, 43.88418654033116, 43.56040743419102, 41.98698091506958, 49.20552001680647, 56.2862867627825, 59.09574917384556, 53.5180584362575, 52.49895920072283, 58.58161721910749, 55.65948281969343, 54.273477009364534, 52.223605564662385, 53.25192158562796, 49.84577219826834, 54.23434822899954, 55.58098554611206, 58.203899247305735, 45.574603353227886, 36.89909648895264, 59.33473941258022, 54.329114709581646, 58.45769609723772, 53.25741066251482, 56.20041397639683, 52.53153582981655, 55.99194369997297, 55.15192386082241, 58.980089460100444, 48.651595728737966, 50.38693264552525, 52.966764041355674, 56.20352676936558, 53.9056567464556, 54.618931021009175, 46.778267587934224, 54.209591797419954, 56.97992542811802, 55.99785314287458, 48.46296255929129, 45.16637584141323, 42.31896584374564, 43.313565731048584, 42.40789236341204, 46.29148721694946, 54.3473676272801, 57.17981120518276, 56.48517894744873, 57.73601450238909, 57.41867985044207, 52.9394645690918, 44.81950092315674, 43.81637907028198, 42.674157755715505, 46.492008754185264, 46.990201541355674, 49.37053278514317, 46.654176235198975, 49.85183102743966, 49.83798326764788, 58.990483965192524, 59.60319001334054, 65.03532641274589, 60.214541162763325, 65.72355243137905, 66.291261945452, 65.4785658972604, 57.40952559879848, 67.7661143711635, 58.86397811344692, 54.86630426134382, 2.1896123119762967, 4.860419946057456, 11.49118183340345, 3.6162316458565846, 1.5416707545518875, 0.4151123895176819, 0.37547527785812107, 19.271542719432286, 69.53254795074463, 63.06574140276228, 26.08080860546657, 35.40715149470738, 51.06983286993844, 28.16774000440325, 43.437452111925396, 58.329842294965474, 61.58602523803711, 74.09421403067452, 37.51967484610421, 0.9655707478523254, 0.17164631666881697, 0.18908875142889364, 0.23042234991277966, 0.15538199512021883, 0.0795913434454373, 0.13575273698994092, 0.14927395858934947, 0.11137368623167276, 0.20600886350231512, 0.15019121579825878, 0.11287204083055258, 0.09348143025168351, 0.16618419119289943, 0.25291782138603075, 0.24523476936987468, 0.19534917335425103], [0.04297627748123237, 0.02563357719087175, 0.02391616943558412, 0.029786757725690092, 0.052554189427090545, 0.04820574347728065, 0.11567929626575538, 0.06267459690570831, 0.0651104087010026, 0.07852612489036151, 0.038890821526625326, 0.048720568351979764, 0.018752853818503872, 0.14066606334277562, 0.054740473361951966, 3.7294920597757613, 57.73543085370745, 58.27456590107509, 56.92145981107439, 55.74004370825631, 45.967430182865684, 50.50406885147095, 28.002105372292654, 36.98235675266811, 44.93416009630476, 48.87469891139439, 2.30462714603969, 0.05120743990742734, 0.05104914786560195, 1.2484121535505568, 1.1473436568464552, 2.0082363188266754, 2.877261847257614, 1.2664929947682788, 30.96023838860648, 72.56892463139125, 63.14897387368338, 60.50471878051758, 50.09362833840506, 51.20853281021118, 53.68332828794207, 59.420931816101074, 58.757719312395366, 59.845362527029856, 58.37088530404227, 58.180247579302105, 58.04510859080723, 55.832354000636506, 48.419796875544954, 43.41198696408953, 42.890271050589426, 42.27279853820801, 41.370797293526785, 40.69383430480957, 40.90782839911324, 41.09175763811384, 51.17581374304635, 54.90380368913923, 53.346232959202354, 52.37802233014788, 54.57818331037249, 54.02315078462873, 53.78035293306623, 54.74073641640799, 55.83815574645996, 54.20856693812779, 47.45248256410871, 40.2634767804827, 38.60536214283535, 38.002498217991416, 40.30709062303816, 41.14085013525826, 40.63107817513602, 43.0862832069397, 50.54631042480469, 53.98267405373709, 49.683208669934956, 48.49465676716396, 54.299306937626426, 48.41319956098284, 45.28554786954607, 41.062835761478965, 46.690699441092356, 40.945880208696636, 49.945006370544434, 47.90915986469814, 58.78777027130127, 38.01348679406302, 35.50553103855678, 56.64640842165266, 47.790112904139924, 48.58400712694441, 48.680312633514404, 52.20222248349871, 47.91372830527169, 49.192474773951936, 47.28704595565796, 50.023333413260325, 52.968695640563965, 48.787613664354595, 46.65693467003958, 49.59233318056379, 48.247891494206016, 49.26899528503418, 44.73925617762974, 50.27147442953927, 53.17871536527361, 51.730019433157786, 42.52790859767369, 39.613014221191406, 38.543446745191304, 37.643821784428184, 37.92466449737549, 39.89016396658761, 46.57894808905465, 51.85916560036795, 54.760559626988, 55.2016521181379, 51.98283658708845, 44.90942798342024, 39.525991507938926, 39.841078417641775, 39.11302185058594, 39.88997636522566, 40.22490733010428, 40.54031385694231, 42.09194040298462, 44.8206022126334, 49.994793687547954, 55.12592370169503, 56.94865158626011, 56.63731670379639, 52.60037858145577, 59.55667182377407, 53.864818709237234, 57.37667798995972, 57.50785650525774, 58.632040296282085, 56.32921968187605, 60.07595934186663, 38.52395009994507, 0.13738420658877917, 2.06595761009625, 2.5762320118291036, 0.8703857468707221, 0.19189378805458546, 0.08648982577558074, 0.4476053688142981, 45.837853227342876, 40.96402195521763, 30.46246944155012, 24.100268023354666, 24.36253125326974, 14.448575735092163, 22.078403030123027, 45.6642107963562, 52.20398037774222, 55.43065084729876, 44.71726165499006, 4.619466406958444, 0.09413965671722378, 0.03563971597967403, 0.04196489050186106, 0.008900538918429186, 0.037568774074316025, 0.03378377003329141, 0.04901086938168321, 0.027431488037109375, 0.07493040497813906, 0.04491285713655608, 0.051309440684105666, 0.024478332305859243, 0.011748050139950854, 0.039447766462607045, 0.021291560360363553, 0.02245583654647427, 0.04613820995603289, 0.027981713780068924, 0.019518611121124456, 0.05583339650183916, 0.016479461254285913, 0.03417481994256377, 0.02688978978299669, 0.051697542358722, 0.014011111160341119, 0.051724113790052276, 0.05783757860107081, 0.043099211063236, 0.03090088169223496, 0.12049342079886369, 0.10686629345374447, 4.909722191946847, 68.85771805899483, 64.68610300336564, 65.53840378352574, 62.765718187604634, 52.010813508714946, 52.99688100814819, 23.45565758432661, 33.790931020464214, 48.93067707334246, 54.64082132066999, 2.3998244149344305, 0.11105858135436263, 0.21015511958726815, 1.7567601672240665, 2.55482656615121, 3.555998580796378, 0.2092054962579693, 0.39395203068852425, 34.16656800678798, 75.15446744646344, 64.9559918812343, 62.35842868259975, 53.177537645612446, 55.21348490033831, 56.55438647951399, 60.031879970005576, 61.05744797842843, 61.84464413779122, 60.374912534441265, 61.195070947919575, 60.33636392865862, 58.30440493992397, 51.53549419130598, 43.79527044296265, 44.020951407296316, 42.73614263534546, 42.88497999736241, 41.937992640904014, 43.78250312805176, 42.80277238573347, 53.38134568078177, 57.470892088753835, 56.87892293930054, 55.55191428320748, 56.26140178952898, 56.04062277930123, 55.3211715562003, 57.25874274117606, 56.12907682146345, 54.92238664627075, 50.3487731388637, 42.3233015196664, 40.7576813016619, 39.583505221775596, 41.6592378616333, 41.10328122547695, 41.468864168439595, 47.487598759787424, 54.38027776990618, 56.68689904894148, 52.56987598964146, 51.53980207443237, 55.22066586358206, 51.16479737418038, 48.55049249104091, 42.352657658713206, 48.86135837009975, 43.30097559520176, 51.949902125767295, 49.290934222085134, 59.58087239946638, 39.71646247591291, 38.13628230776106, 58.93773324148995, 49.418166160583496, 52.75908585957119, 50.411598750523154, 52.935681274959016, 49.9702422278268, 50.87143400737217, 50.08426564080374, 52.53292546953474, 54.76185546602522, 50.292259965624126, 49.148690700531006, 52.38949033192226, 50.96430015563965, 50.44912944521223, 45.74178395952497, 51.14528335843767, 54.91078315462385, 52.30309643064226, 44.9102235521589, 42.50456959860665, 40.776194776807515, 39.198008741651265, 39.52733251026699, 41.430371148245676, 49.818455355507986, 55.09462901524135, 58.61176545279366, 56.398719038282124, 55.75424582617623, 46.77444955280849, 41.758062090192524, 42.69323403494698, 41.377074990953716, 44.040597438812256, 43.13832174028669, 43.7248261315482, 44.03431626728603, 47.26708378110613, 51.357700211661204, 56.21127053669521, 60.12650053841727, 57.1305102620806, 54.290593896593364, 61.162233761378694, 56.908966950007844, 57.78890419006348, 60.9829216003418, 61.62103026253836, 59.21598775046212, 63.61544813428606, 45.40161405290876, 0.41051241063645905, 0.40722051156418665, 1.9176930402006422, 3.309980022055762, 0.5922866495592254, 0.05300892324053815, 0.19014360196888447, 48.729825496673584, 48.441958154950825, 26.45468074934823, 17.111962693078176, 22.74739817210606, 20.544699362346105, 28.599155391965592, 51.67788015093122, 56.89738777705601, 60.76752049582345, 53.312714849199565, 6.446916026728494, 0.09187372294919831, 0.022277447993734052, 0.015851451649463603, 0.030301538495612994, 0.03637273736031992, 0.051414667894797664, 0.03249461117333599, 0.030517092107662132, 0.016345966274717023, 0.02287026707615171, 0.07605760092181818, 0.013211504290146487, 0.017107511571209346, 0.017124042380601168, 0.00993575350314911, 0.0044813599337690645, 0.08314990678003856, 0.13904608812715324, 0.10905425676277705, 0.14668331188814981, 0.13403666764497757, 0.12940618182931626, 0.3011142180434295, 0.15721146123749868, 0.12747918308845588, 0.17573985058282102, 0.14049420399325235, 0.1649663294000285, 0.12660330294498376, 0.28533768174903734, 0.2028392364404031, 6.124105325766972, 78.00714765276227, 74.02423177446637, 73.58637714385986, 71.73706545148576, 57.297697816576274, 57.56429672241211, 39.88362571171352, 51.36041348321097, 66.13442025865827, 62.64613968985421, 2.987004952771323, 0.1831905586378915, 0.3044003631387438, 3.0199389798300604, 6.177695044449397, 7.021023528916495, 11.82415861742837, 2.5684695712157657, 40.0851616859436, 76.37786456516811, 69.39892019544328, 64.67740385872978, 53.72659124646868, 57.2410317829677, 60.20186070033482, 63.55315753391811, 63.75021539415632, 64.15574700491769, 62.97797870635986, 64.1107713154384, 62.864848136901855, 60.980587005615234, 54.02559655053275, 45.388162340436665, 48.19838210514614, 46.159078870500835, 44.758690289088655, 44.167252676827566, 45.54670980998448, 44.607143129621235, 55.34397554397583, 59.36143439156668, 58.69627639225551, 58.043962138039724, 58.006643363407676, 57.296197005680625, 58.36028930119106, 60.54736682346889, 59.26985018593924, 58.76381288255964, 52.79530334472656, 44.37280123574393, 42.635338170187815, 40.868154185158865, 44.82107121603829, 45.39191436767578, 45.109185218811035, 48.93713889803205, 56.508396353040425, 60.802970205034526, 53.09007024765015, 53.11738361631121, 59.127300943647114, 54.531463623046875, 51.09605884552002, 46.05008942740304, 50.27488252094814, 45.97034495217459, 54.93355240140642, 53.70977313177926, 62.00721114022391, 44.06781005859375, 40.272273199898855, 60.70217963627407, 51.987839290073936, 53.25470086506435, 52.65345934459141, 56.29082046236311, 52.7915096282959, 53.0772681917463, 52.092347145080566, 54.60601084572928, 57.054163455963135, 52.29915680204119, 49.81868117196219, 54.237370695386616, 52.03962074007307, 53.53808661869594, 46.33384690965925, 51.5566132409232, 58.49081815992083, 56.02654572895595, 46.32671110970633, 43.44973652703421, 42.83770792824881, 41.81308140073504, 41.669719219207764, 43.499673230307444, 52.12830407278878, 57.22744805472237, 60.978127343314036, 58.374963896615164, 57.76251840591431, 49.72986582347325, 44.10453128814697, 44.031335490090505, 45.28362669263567, 44.894041197640554, 45.26794808251517, 45.16797740118844, 47.035121645246235, 49.857222829546245, 53.923996516636436, 58.97612203870501, 61.39957727704729, 60.39646584647042, 55.842018944876536, 61.15719631740025, 60.882624353681294, 60.37109797341483, 62.34185722896031, 64.996492930821, 61.4473808833531, 65.42494664873395, 45.77567032405308, 0.839735885815961, 7.192829898425511, 6.809484754289899, 2.7555131231035506, 0.4759284790073122, 0.16650747241718428, 0.8064781161291259, 57.28326293400356, 55.08746542249407, 43.68467249189104, 32.03684091567993, 35.706038679395405, 22.496217318943568, 33.70088931492397, 57.21067162922451, 66.02698026384626, 68.17856638772147, 60.563917432512554, 7.062904230185917, 0.22777115074651583, 0.08539410707141672, 0.1575694563133376, 0.09717716622565474, 0.08691289235970803, 0.22301988569753511, 0.21548666778419698, 0.11189022101461887, 0.15959225062813076, 0.13852823020092078, 0.13467138287212166, 0.11214808467775583, 0.0829881304608924, 0.13975833276552813, 0.10175633443785564, 0.13712506049445697], [0.061316712626389096, 0.020866332642201866, 0.060989699459501674, 0.02653352327511779, 0.07046555634588003, 0.002548376514044191, 0.045293359218963554, 0.06547859537282161, 0.013145515063245381, 0.06783964617976121, 0.024069570936262608, 0.07306686961757285, 0.04782089198540364, 0.17295195375170025, 0.250870409820761, 11.666013274874006, 72.02661078316825, 55.044337953839985, 62.334617206028526, 40.884961877550396, 27.835933991840907, 10.614818572998047, 47.80242163794381, 35.99230098724365, 44.02876465661185, 39.55603551864624, 0.21509277820587158, 0.030562608236713067, 0.1946544756314584, 0.7341028569000108, 1.1589520339454924, 0.1865775476076773, 0.5911197864583561, 0.5985601129276412, 53.85386487415859, 69.34712137494768, 59.44607734680176, 59.523320470537456, 54.113449573516846, 48.513594082423616, 49.0061935697283, 53.35952138900757, 54.763960770198274, 57.42706980024065, 56.46639101845877, 56.156470094408306, 57.66178689684187, 50.84142821175711, 45.751320362091064, 41.953455856868196, 44.592228821345735, 39.29212556566511, 42.10338756016323, 41.39582470485142, 40.01481812340872, 38.79802526746477, 45.92066880634853, 50.64848368508475, 52.78181341716221, 50.84782402856009, 50.530683926173616, 50.47619267872402, 52.31070818219866, 51.923860277448384, 53.886653423309326, 53.48744467326573, 47.76257371902466, 40.947982038770405, 38.32034356253487, 40.406474181583945, 39.94114637374878, 38.90725442341396, 40.41631630488804, 46.106755461011616, 50.791877133505686, 53.110452788216726, 46.755484444754465, 50.03029203414917, 53.0713518006461, 44.422970703669954, 43.887184688023154, 36.945632049015586, 42.50116845539638, 45.72629989896502, 52.29190288271223, 49.19341278076172, 56.03600917543684, 37.90439312798636, 38.118057182856965, 53.61650398799351, 48.29247113636562, 49.68723862511771, 48.53320189884731, 48.41894572121756, 47.258426325661794, 42.19915805544172, 45.18764427730015, 49.437218121119905, 50.12202910014561, 49.97984116418021, 50.873237064906526, 49.95971918106079, 47.7198805127825, 50.31594984872, 48.50165360314505, 47.261084011622835, 51.35250643321446, 48.38560479027884, 44.49681963239397, 39.635481221335276, 38.984167507716585, 37.62524577549526, 40.436299324035645, 37.52638333184378, 44.75048794065203, 50.71699639729091, 54.82768964767456, 53.25634411403111, 50.410570417131694, 40.841615540640696, 39.12499359675816, 39.19131415230887, 38.9881522996085, 40.83372586114066, 41.99327598299299, 41.99932091576712, 44.07701642172677, 47.80211591720581, 54.96526745387486, 54.7155214037214, 56.59377581732613, 50.153358527592246, 59.8683054787772, 54.9759954724993, 58.54397187914167, 55.48526021412441, 58.23853254318237, 56.11841481072562, 58.642108236040386, 54.452761377607075, 65.70857211521694, 27.119291578020366, 0.42027362542493, 2.865303997482572, 2.805395109312875, 0.40368881821632385, 0.04439697035455278, 0.12880972240652355, 15.577805655343191, 54.50631809234619, 26.931935140064784, 45.34341246741158, 34.900158814021516, 31.588987827301025, 16.606378759656632, 35.099040576389854, 44.06834854398455, 53.87732546670096, 53.1735771724156, 22.581787858690532, 0.5066316457731384, 0.024473906561200107, 0.0458441634130265, 0.008216757975917841, 0.11365920930568661, 0.05892966714288507, 0.0335857735148498, 0.06589348560997418, 0.016008817490988543, 0.022597161820158362, 0.10813811913664852, 0.06692360354853527, 0.029618633711444478, 0.06719902091260467, 0.027885046288637177, 0.06534951765622411, 0.031036849931946824, 0.010516275834691311, 0.07029494550079107, 0.07083689820553575, 0.0429299267541085, 0.042350430706782, 0.05150338634848595, 0.02055896645677941, 0.0556377341438617, 0.005191742841686521, 0.03551806482885565, 0.06342573517135211, 0.05358375096693635, 0.1551491083311183, 0.24136918251003536, 16.61368305342538, 82.47999491010393, 61.33201994214739, 70.81006458827427, 48.7407272202628, 43.719215461185996, 18.936615228652954, 36.44343709945679, 34.71004567827497, 51.6022629056658, 41.384731905800955, 0.09088023233094386, 0.10411500358687979, 0.7152790469782693, 1.653326677424567, 2.635354667901993, 1.9594052476542336, 0.8835308700799942, 0.8604654563324792, 57.78294958387102, 72.87242889404297, 60.95621272495815, 61.37518909999302, 56.52685076849801, 50.98681926727295, 52.66397891725813, 55.22805527278355, 55.9614063671657, 58.97644165584019, 57.617707524980815, 59.124146461486816, 60.54555334363665, 53.40516063145229, 46.13063294546944, 44.62497220720564, 45.22229841777256, 41.342980180467876, 44.48289196831839, 43.851978165762766, 42.37365164075579, 40.25536823272705, 47.24825068882534, 53.480086530957905, 55.58854866027832, 52.64467682157244, 51.03760017667498, 53.730263369424, 53.50681625093733, 54.262495381491526, 56.44243710381644, 57.01314129148211, 50.663589068821494, 43.58818980625698, 39.95931938716343, 42.02527938570295, 40.69840274538313, 41.49830715996878, 42.45621361051287, 48.33513307571411, 52.96984209333147, 54.532491956438335, 49.72274739401681, 52.62031296321324, 56.27643421718052, 48.15023456301008, 45.8124749319894, 39.82281855174473, 43.80502223968506, 48.43979379108974, 55.08948734828404, 51.54472139903477, 57.98201894760132, 40.81613302230835, 40.1933034488133, 56.20346423557827, 50.09958641869681, 51.70693751743862, 50.56026588167463, 51.442978927067344, 50.363732610430034, 44.81616926193237, 46.69065080370222, 52.3683956010001, 52.242424760546, 52.899491582598, 51.014719758714946, 52.426770891462056, 50.282629762377056, 52.87593718937465, 49.80974926267351, 48.70172003337315, 53.272582054138184, 51.02304022652762, 45.86816126959664, 41.07106590270996, 41.38333184378487, 39.74279267447335, 42.38954217093331, 39.82533379963466, 46.15528515407017, 52.40280308042254, 57.79853786740984, 55.06488377707345, 52.19518395832607, 42.983071190970286, 41.38783427647182, 41.05722509111677, 40.21712187358311, 42.00622395106724, 43.31790835516793, 44.27611705235073, 46.386406557900564, 50.92987183162144, 56.537370341164724, 56.72127873556954, 59.25739901406424, 53.12405388695853, 60.95222445896694, 57.97106858662197, 59.35254069737026, 59.80356216430664, 60.84650066920689, 58.05433232443673, 61.41482857295445, 56.147510392325266, 69.12049198150635, 32.695238317762104, 0.09456075554979698, 0.5151605595435415, 2.1818490028381348, 1.2887139852557863, 0.15974065980740956, 0.14333366948579038, 14.545004572187151, 61.55038097926548, 29.57369061878749, 34.74730886731829, 34.51586784635271, 29.796203204563685, 23.44917491504124, 40.631342206682476, 49.20820549556187, 57.79963220868792, 62.417349406651084, 28.43696185520717, 0.4334456729037421, 0.06038211206240313, 0.03820955201185175, 0.012879607367462345, 0.04570345560620938, 0.04916543626625623, 0.037770122555749755, 0.017731215871338333, 0.053600989149085114, 0.008867246597739202, 0.026248121268248985, 0.023067910756383623, 0.0820621337209429, 0.09074863724942718, 0.009519018498914582, 0.010946324544160493, 0.21129573695361614, 0.11455234459468297, 0.1972184016236237, 0.23832882993987628, 0.22157683170267514, 0.11895345843264035, 0.10224613494106702, 0.20876233146658965, 0.07708034997007676, 0.1504808145442179, 0.09713169080870492, 0.1617570487516267, 0.11835910246840545, 0.3700644224882126, 0.44837626601968494, 19.7811461857387, 91.02254104614258, 70.2781035559518, 79.20116778782436, 54.29684380122593, 40.76412575585501, 17.112693990979874, 65.37489182608468, 52.334140981946675, 57.58853898729597, 47.19790751593453, 0.5471269956656865, 0.17531302491469042, 0.9259865347828183, 4.0830433283533365, 4.8237312861851285, 5.571346598012107, 4.489606312343052, 0.9030350606356348, 63.02864497048514, 73.29626205989292, 65.73000035967145, 62.83924402509417, 59.98660550798689, 53.48325490951538, 53.96899652481079, 58.06738798958914, 60.72649833134243, 62.43080806732178, 59.060361998421804, 61.08928462437221, 62.60713945116316, 55.4312310218811, 50.061048235212056, 46.03005082266671, 48.050395897456575, 42.49549872534615, 46.85179342542376, 45.881877013615195, 45.51496001652309, 42.02178791591099, 51.15424306052071, 55.420676708221436, 59.45476259504046, 54.69275910513741, 54.38696541104998, 55.96535641806466, 56.39484889166695, 56.41052402768816, 58.590545654296875, 59.3971620287214, 52.761305809020996, 48.48199020113264, 41.36919920785086, 44.292313303266255, 43.91799300057547, 43.2354610306876, 44.64304794584002, 49.67285932813372, 56.95220558983939, 57.43365321840559, 50.27287449155535, 55.22541495731899, 59.375122342790874, 49.891616412571494, 49.22590255737305, 41.388459614345, 46.149594579424175, 50.788170269557405, 56.587220191955566, 53.09749787194388, 58.22156504222325, 42.91306114196777, 43.0142616544451, 57.6723690032959, 53.03601673671177, 54.45966788700649, 52.3690139906747, 52.0825640814645, 52.936230182647705, 45.44512367248535, 50.038904326302664, 53.55612414223807, 54.46731090545654, 54.046757289341514, 51.89691516331264, 54.01025145394461, 53.1334547996521, 52.775445393153596, 51.07585000991821, 49.28075858524868, 55.39783450535366, 53.21166024889265, 47.273983342306956, 43.21504374912807, 43.3376099722726, 40.90499005998884, 44.744835581098286, 41.47330059323992, 48.36452395575387, 55.44836180550711, 60.52409035818917, 57.60892152786255, 54.45951155253819, 45.08735397883824, 43.684769766671316, 43.309021609170095, 41.736203057425364, 45.48901891708374, 47.520554065704346, 46.53577545710972, 47.384636878967285, 53.08335828781128, 59.42527444022042, 59.693905694144114, 61.51075540270124, 54.89270741598946, 61.87620285579136, 60.06254237038748, 61.284876414707725, 60.74597413199288, 63.3195868900844, 62.20335183824812, 65.60570403507778, 57.99231617791312, 71.50626713888985, 31.969860281263077, 0.463966395173754, 8.046896389552526, 9.366279397691999, 1.1907113811799457, 0.27358898360814365, 0.19721587747335434, 19.561345134462627, 67.44448920658657, 39.079336983816965, 59.253063338143484, 45.40938908713204, 40.601294721875874, 25.68948606082371, 47.281167779650005, 58.174244335719514, 65.93384660993303, 69.73606068747384, 33.63685471670968, 0.6562958977052143, 0.19277114740439824, 0.16601238612617764, 0.12237400774444852, 0.16140178138656275, 0.1633611326771123, 0.07399014543209757, 0.12765602288501604, 0.13863078398363932, 0.09225679667932646, 0.18992106962416852, 0.1358768410448517, 0.1895216703414917, 0.245157389236348, 0.08518120313861541, 0.12604180164635181], [0.0037918390090843396, 0.04658280645630189, 0.04210849565320781, 0.02718373793842537, 0.023081508598157337, 0.023270753711195927, 0.028024149360135198, 0.03489965479820967, 0.025676704876657044, 0.10122437655393567, 0.02160140489494162, 0.03378534423453467, 0.05667598771729639, 0.11458571494690009, 0.07650034502148628, 39.15786552429199, 63.06540094103132, 56.3689147404262, 54.733065605163574, 30.852555206843785, 15.119321823120117, 22.616129330226354, 40.40393461499895, 28.512381076812744, 67.19148445129395, 16.510097571781703, 0.286288390734366, 0.1687739829399756, 0.6392203196883202, 1.5438192678349358, 2.632367811032704, 1.7508689633437564, 0.6158024477107185, 8.493278196879796, 67.18354960850307, 62.49705219268799, 63.73090635027204, 59.281696864536826, 59.38529450552804, 54.19934320449829, 51.62172480991909, 47.12557329450335, 46.26037318365914, 53.35120439529419, 56.28726645878383, 56.59696504047939, 53.61191817692348, 51.333148751940044, 44.63133328301566, 40.44976493290493, 42.28480155127389, 39.56243828364781, 39.88534886496407, 40.03856706619263, 39.700985363551546, 39.31846271242414, 38.793849400111604, 43.434929915836875, 47.60455431256975, 45.67223596572876, 48.32754216875349, 50.76368134362357, 52.4218168258667, 54.100115980420796, 55.51527990613665, 54.032072271619526, 49.22064277103969, 42.36060987200056, 39.99241713115147, 38.93307392937796, 39.44690016337803, 38.52849769592285, 43.35507426943098, 47.35676418031965, 51.0671717098781, 49.65651716504778, 47.55646930422102, 51.10773529325213, 51.32428632463728, 44.672261646815706, 40.275677817208425, 38.725489548274446, 40.92574780327933, 49.02717365537371, 53.19122907093593, 50.54605681555611, 56.15156814030239, 39.55346468516758, 35.20052943910871, 57.21172775541033, 47.78436326980591, 49.75622728892735, 48.67609160287039, 49.63359158379691, 48.00083787100655, 47.070765904017854, 41.34807668413435, 48.40344776426043, 51.606751441955566, 50.67003699711391, 50.1618527003697, 50.68792513438633, 49.77024875368391, 51.52884129115513, 50.17839983531407, 50.44640227726528, 50.69400828225272, 51.69638320377895, 45.92020327704293, 43.83510446548462, 39.28907878058297, 37.65466792242867, 38.15590054648263, 39.41798870904105, 38.42547675541469, 48.8872195652553, 52.85295949663435, 52.29954590116228, 47.70331253324236, 42.01771627153669, 40.0667941229684, 40.326219013759065, 38.37039491108486, 42.0280065536499, 39.86579663412911, 43.54963772637503, 46.598198073250906, 54.4503573008946, 54.715246949877056, 55.703777585710796, 52.38809721810477, 56.469917229243684, 53.472453934805735, 56.91227429253714, 56.4358606338501, 56.617309365953716, 51.50136463982718, 55.05538558959961, 51.59931686946324, 61.611386162894114, 53.25662899017334, 68.44099984850202, 14.72862114225115, 0.7774808406829834, 5.791076864515032, 1.7657324629170554, 0.07700828276574612, 0.026413892462317432, 1.3174713850021362, 47.48322139467512, 47.37369346618652, 25.45694896153041, 43.826346261160715, 50.838225092206685, 16.745761360440934, 24.152511528560094, 42.889319147382466, 46.95164598737444, 53.40807887486049, 40.99578217097691, 2.327408335038594, 0.03566373951200928, 0.004416365608839052, 0.06227673789752381, 0.08668267221323081, 0.057844730360167365, 0.059657253458031585, 0.020406596329329268, 0.023560265943940197, 0.030047858000866005, 0.011517426265137536, 0.09292721641915185, 0.011747400442670499, 0.05192294151389173, 0.027332393086648414, 0.040728823614439795, 0.03847663357321705, 0.03794603275933436, 0.04305062456322568, 0.09685790871403047, 0.07343546341040305, 0.05919411259570292, 0.028973285840558152, 0.06380640010216407, 0.011194477523011821, 0.02375388760784907, 0.05445398569905332, 0.025288489547425082, 0.002656426006329379, 0.006750962455823485, 0.13702176032321794, 49.64009509767805, 70.23970781053815, 62.8731164932251, 61.380560057503835, 37.47530712400164, 21.936963762555802, 26.72602527482169, 38.75505065917969, 34.276794229234966, 73.88806097848075, 19.59489103725978, 0.46154196241072243, 0.05064437458557742, 2.007612935134343, 4.9630109667778015, 3.50271805695125, 1.0021354258060455, 0.4849771506020001, 10.640210764748709, 70.79125581468854, 63.45868287767683, 66.64702360970634, 61.57021113804409, 63.21426609584263, 57.075258186885286, 52.9286219051906, 49.23438630785261, 48.93561029434204, 54.357678753989084, 56.87604291098458, 58.44770458766392, 56.659516198294504, 53.73274040222168, 46.64373309271676, 44.034886019570486, 45.352660519736155, 42.38481739589146, 41.648280552455354, 42.200224603925435, 42.46028872898647, 41.4954514503479, 42.34054347446987, 45.37090996333531, 49.539433070591514, 48.74247121810913, 49.67369311196463, 50.34322500228882, 55.84605584825788, 56.13196727207729, 57.26325559616089, 56.27492298398699, 51.73466777801514, 43.82516854149954, 41.16675649370466, 41.314673219408306, 41.2246766771589, 40.91670472281319, 45.97632735116141, 50.04649175916399, 54.67533649717058, 51.09039953776768, 48.784803118024556, 53.90215832846505, 52.92259781701224, 46.30453593390328, 43.09390190669468, 40.31344822474888, 45.06858342034476, 51.82099567140852, 55.72607088088989, 52.4931435585022, 56.06699119295393, 41.80367006574358, 37.182760170527864, 58.704989433288574, 49.722292287009104, 51.10879141943795, 50.495894295828684, 52.92507137571062, 48.83605997903006, 49.02139622824532, 43.52511405944824, 49.67306777409145, 53.05818496431623, 52.90624523162842, 51.781067848205566, 52.32875612803868, 51.93489749091012, 54.380111013139995, 52.3186742918832, 53.4305875641959, 51.22754308155605, 53.20498303004673, 49.13414464678083, 46.330866132463726, 41.12276744842529, 40.106933866228374, 39.76751436505999, 40.987281050000874, 40.36127962384905, 51.397558552878245, 54.30220433643886, 54.14501176561628, 50.02616133008684, 43.326308727264404, 42.115689345768516, 42.56034973689488, 41.848607540130615, 44.203292982918875, 42.07874924795968, 45.847792625427246, 49.62280103138515, 58.221238476889475, 57.00479997907366, 58.363832882472444, 53.12105573926653, 58.605810846601216, 55.385327747889924, 59.38655907767159, 56.99947765895298, 59.434327942984446, 53.04227706364223, 57.94818122046334, 53.45917592729841, 62.773444584437776, 56.519346714019775, 71.79199096134731, 17.99710587092808, 0.7726282296436173, 0.4373720022184508, 1.4039818857397353, 0.5140441251652581, 0.06081817259213754, 1.07605014528547, 50.78052377700806, 52.46059819630214, 29.3218184198652, 40.22511577606201, 42.609390122549875, 21.837828602109635, 31.952402932303293, 47.91164037159511, 52.019165243421284, 59.35090787070138, 49.68644653047834, 3.8056065355028426, 0.04715154433090772, 0.026771553359659653, 0.04231937076630337, 0.061650436504610946, 0.05061899398320487, 0.05150246014818549, 0.039772523500557454, 0.05327397598219769, 0.04579704933400665, 0.032804023141839674, 0.06522339156695775, 0.005362712886250977, 0.09431718861950295, 0.02886552090889641, 0.017751334434641258, 0.1899775644498212, 0.2407723973904337, 0.06570246443152428, 0.2402331791818142, 0.09484647986079965, 0.17648182862571307, 0.08767259373728718, 0.13789739619408334, 0.1232188381254673, 0.2273046172090939, 0.16081495716103486, 0.10289818673793759, 0.0704028189980558, 0.34207319734351976, 0.3492719924875668, 56.49997166224888, 79.81736877986363, 73.0393454687936, 70.2151459285191, 42.778516224452424, 23.07184430531093, 33.68682268687657, 57.53828614098685, 42.98548916407994, 82.88972323281425, 21.3282025541578, 0.6366378696901458, 0.21776022150048188, 2.2332728377410342, 7.5374014888490946, 6.733580027307783, 9.458447252001081, 1.9979901143482752, 14.615652118410383, 71.99700450897217, 64.59994534083775, 70.97422272818429, 64.0964024407523, 65.45705427442277, 59.73979159763881, 56.32176079068865, 53.51458433696202, 52.52937494005476, 57.486310141427175, 60.26832021985735, 61.21119771684919, 59.06022303444998, 56.47708429609026, 49.836027349744526, 45.53695106506348, 47.226322174072266, 43.965091364724294, 44.03762708391462, 45.95047657830374, 44.66904810496739, 44.06122664042881, 44.167544501168386, 48.41172306878226, 52.86500072479248, 50.163297925676616, 53.36445461000715, 53.622837271009175, 58.539643151419504, 59.23934759412493, 60.381978852408274, 59.325526101248606, 54.177522386823384, 47.44277940477644, 44.4536782673427, 42.38686711447579, 44.2053461756025, 42.30452748707363, 47.75388152258736, 53.018097332545686, 56.160197802952354, 53.49240568705967, 50.80866050720215, 56.70422785622733, 55.301275389535085, 48.03530093601772, 44.974091393607004, 42.68679652895246, 46.46046045848301, 54.41939960207258, 57.262873445238384, 53.01579747881208, 58.55893135070801, 44.284010205950054, 40.95892545155117, 60.796529224940706, 53.02452441624233, 55.28382151467459, 52.254809924534385, 56.8262278011867, 53.06009919302804, 51.954515729631694, 46.210519858769004, 52.32513264247349, 55.61489275523594, 54.77089854649135, 53.41533279418945, 55.5222350529262, 54.511741161346436, 57.35464525222778, 54.3310671533857, 55.13076312201363, 54.24494423185076, 56.00818164008004, 51.572020871298655, 49.691876547677175, 42.57631669725691, 41.20244591576712, 41.4778481892177, 43.692402362823486, 42.524521350860596, 53.8712979044233, 56.627172333853586, 55.294045788901194, 52.071106501988, 46.70592641830444, 43.90180022375924, 45.47386142185756, 43.589843477521626, 47.14950636454991, 44.5162467956543, 49.02932759693691, 52.0593466758728, 59.37492084503174, 61.05399472372872, 59.6836918422154, 55.66499621527535, 59.17463902064732, 56.534028257642476, 62.23971176147461, 61.49991621289934, 60.933561597551616, 56.00170939309256, 59.840533529009136, 56.442332880837576, 66.29511819566999, 59.37352425711495, 74.09828567504883, 19.703262090682983, 1.629011673586709, 17.273223434175762, 4.162408258233752, 0.4945916661194393, 0.0677408039835947, 1.9739602037838526, 57.92794459206717, 60.28720542362758, 38.016544001443044, 53.750819614955354, 57.7574462209429, 25.641637291227067, 36.301315171378, 55.257755347660606, 60.801142828805105, 66.04995795658657, 56.23161833626883, 4.461409219673701, 0.1411263950701271, 0.08903398604265281, 0.12830728079591477, 0.2698016454066549, 0.18409746140241623, 0.10278092231601477, 0.08955421205610037, 0.09799824788102082, 0.11323529455278601, 0.12292064912617207, 0.1223751205418791, 0.10325263986097914, 0.2357422544487885, 0.09936728049069643, 0.10164258482732944], [0.01584274604517434, 0.01757168211042881, 0.048309681471437216, 0.028718258453799144, 0.09190351742186717, 0.021128018153831363, 0.03059500828385353, 0.027467803231307437, 0.026683426927775145, 0.014782434994620937, 0.011882406858993428, 0.02823325519316963, 0.05717220037643399, 0.022066895184772353, 1.4944827152150018, 58.451505252293174, 61.14279964991978, 61.267255783081055, 51.39040885652815, 24.650348220552715, 25.43942039353507, 46.266251359667095, 42.76185097013201, 35.11482688358852, 62.23336110796247, 3.952197023800441, 0.07304602502179997, 0.20205003236021313, 0.5836649121982711, 1.6163347938231059, 1.9472013882228305, 0.7722629063895771, 0.15725205120231422, 35.61253677095686, 71.64764213562012, 63.54272133963448, 64.59458133152553, 62.54147202627999, 61.96058872767857, 60.18175261361258, 58.81812695094517, 50.56446259362357, 44.184529372623985, 44.96842166355678, 47.66402741840908, 50.664912700653076, 49.95055798121861, 46.30285446984427, 43.681663921901155, 41.34696497235979, 41.06032746178763, 40.96063470840454, 39.542851311819895, 39.293278966631206, 39.91411788122994, 39.026992729731965, 40.57646533421108, 41.413792746407644, 43.04381929125105, 41.569064140319824, 45.431268964494976, 49.08365903581892, 52.56388316835676, 52.58853537695748, 53.925806522369385, 53.7277272769383, 47.24630171912057, 40.7114132472447, 40.78992441722325, 38.37125301361084, 37.9706164087568, 38.493975571223665, 45.06519269943237, 49.83057648794991, 50.64441898890904, 47.740884917122976, 48.06052984510149, 51.935026032584055, 52.02826738357544, 41.54144852502005, 40.26272637503487, 39.849899155753, 46.35437536239624, 47.76462343760899, 52.28927993774414, 49.12462908881051, 55.34189803259713, 37.714147976466585, 37.39803968157087, 55.850172655923025, 45.418164661952424, 48.96633175441197, 46.46004704066685, 51.30300051825387, 47.40160437992641, 45.297307695661274, 40.258192675454275, 42.30393689019339, 47.962945869990754, 51.904335839407786, 50.38289226804461, 49.45506804330008, 50.16029977798462, 49.33690002986363, 50.937455790383474, 51.42870385306222, 51.782259464263916, 51.20091758455549, 48.92699105398995, 46.260550362723215, 40.22872883932931, 37.48799453462873, 36.039983000074116, 38.04505246026175, 37.95629269736153, 42.30988802228655, 47.09779439653669, 48.78272908074515, 45.87321260997227, 40.1438809122358, 38.77934850965227, 38.22086272920881, 40.38388558796474, 41.864445958818706, 41.63916104180472, 45.685402802058626, 51.976315702710835, 54.081942967006135, 54.492310523986816, 53.757552419389995, 55.29762063707624, 55.42123256410871, 54.29063905988421, 54.54139954703194, 53.74758870261056, 53.52131714139666, 50.556934220450266, 52.68611240386963, 51.51662288393293, 53.905201639447895, 57.09229864392962, 55.85709653581892, 58.1668827193124, 4.617793193885258, 1.8787831280912672, 0.720167267535414, 0.6380867319447654, 0.23443591168948583, 0.1118070665480835, 15.189029625483922, 58.28432812009539, 29.38248314176287, 43.83153656550816, 56.106853008270264, 21.40933666910444, 17.31670352390834, 32.79060581752232, 48.81114721298218, 47.147883960178916, 58.9289368220738, 14.988318749836512, 0.2232998763876302, 0.07260910953794207, 0.044534427978630574, 0.03534239550520267, 0.035291780185486586, 0.056425421698285, 0.04995932563074997, 0.05629530582310898, 0.005591387245138841, 0.041437672185046334, 0.03119982386540089, 0.034658059012144804, 0.011524459280605828, 0.07037544689540352, 0.02765656997715788, 0.04509192592065249, 0.07186621547277484, 0.053416098534528694, 0.035509552607046704, 0.022901757886367183, 0.02665022451297513, 0.06034276381667171, 0.06176289689860173, 0.016096396005845497, 0.024869935221171806, 0.02913343028298446, 0.030509665541883026, 0.052627298182674816, 0.08518232272139617, 3.029169878789357, 69.19564369746617, 67.8568092073713, 69.37095369611467, 59.7961345400129, 35.469146796635215, 31.05596719469343, 36.71956545966012, 39.41153730664934, 44.269356455121724, 66.34348460606166, 5.088865859167917, 0.39115437652383533, 0.229780374360936, 2.0735057422092984, 5.657246742929731, 5.132118829659053, 1.3020721141781126, 0.2618093985532011, 38.75656189237322, 73.97250243595668, 64.55567141941616, 67.61474091666085, 64.82697078159877, 64.73429570879254, 63.23923792157854, 61.695320401872905, 52.869607380458284, 47.519077573503765, 46.83006293433053, 50.83207941055298, 52.22391823359898, 52.599961689540315, 47.49396330969674, 46.27126101085118, 43.39750344412667, 42.214596952710835, 43.32114621571132, 41.699252537318635, 42.2286114692688, 42.664148875645225, 41.91200637817383, 42.670899050576345, 42.030049324035645, 44.978302001953125, 43.89997284752982, 49.07968119212559, 51.303573744637625, 54.750106062207905, 54.55738387789045, 56.22567415237427, 55.3629059110369, 49.212763513837544, 42.84477424621582, 41.91601896286011, 40.11154399599348, 40.73534631729126, 40.95657001222883, 46.74757392065865, 51.86064556666783, 53.33871848242623, 47.542934213365825, 48.78557436806815, 52.22891051428658, 54.19196769169399, 46.02098689760481, 42.59897824696132, 42.14533730915615, 49.687047549656455, 50.96695784160069, 54.625285148620605, 50.730006899152485, 57.66031040464129, 40.38926001957485, 40.18885312761579, 57.859751496996196, 47.12311710630144, 49.62098407745361, 47.829748903002056, 51.98094320297241, 48.91305296761649, 47.893453461783274, 43.26632840292794, 44.19511147907802, 49.33248444965908, 54.2220846584865, 52.68664394106184, 52.4057491166251, 50.66537128176008, 52.19577802930559, 53.34338072368077, 52.168544564928325, 53.63540308816092, 54.308815547398154, 51.063218184879844, 47.230341706957134, 42.87109054837908, 39.36755173546927, 38.62586975097656, 40.414381231580464, 40.86922420774187, 44.973406996045796, 49.700572218213765, 50.93488843100411, 46.90514169420515, 42.04320226396833, 40.99845722743443, 41.26415981565203, 42.67925425938198, 43.08058915819441, 43.75790303094046, 48.46529367991856, 53.857290336063926, 55.854324204581125, 56.0286614554269, 54.49053873334612, 55.26418937955584, 56.22255093710763, 55.81366682052612, 57.54346602303641, 55.22616536276681, 55.637335436684744, 53.63983951296125, 55.257918630327495, 54.164616107940674, 56.13578530720302, 60.60341099330357, 58.090028694697786, 64.12869766780308, 6.741223045757838, 1.2372161086116518, 3.32296598809106, 1.3591473315443312, 0.22337429810847553, 0.140305204849158, 14.686490740094866, 65.15755912235805, 33.84593643460955, 37.257613113948274, 49.59111377171108, 20.84577522959028, 22.582453148705618, 39.97628688812256, 53.82010357720511, 51.79761150905064, 65.21540287562779, 18.49186451094491, 0.24707202506916864, 0.04173381879393544, 0.012549058184958994, 0.006675489853867995, 0.05112216162628361, 0.029770269324736934, 0.04318868608347007, 0.013413715359222676, 0.03281163291207381, 0.0888327257707715, 0.019904904499916092, 0.033136888673262935, 0.09520799653338534, 0.061372868184532435, 0.042102253131036244, 0.11400160486144678, 0.1957195449088301, 0.13768915379686014, 0.10723279735871724, 0.18141787233097212, 0.1231517174414226, 0.13438840662794455, 0.15153813495167665, 0.09721474349498749, 0.11473629543823854, 0.11575226592166082, 0.13964014553597995, 0.1495554827685867, 0.24220622330904007, 4.3687662822859625, 80.44877937861851, 75.90924331120083, 77.36467552185059, 65.68333625793457, 35.48120886938912, 36.85094199861799, 58.6614659173148, 57.646271569388254, 49.499484402792795, 72.60422842843192, 5.183978881154742, 0.3506886921823025, 0.2526842696326119, 4.576061878885541, 4.154396116733551, 6.227207907608577, 5.16981280701501, 0.3060426621564797, 46.18324817929949, 71.01429993765694, 68.16865825653076, 67.56483200618199, 68.76789869580949, 65.78078474317277, 66.22307232448033, 63.525059018816265, 55.66886636189052, 50.152569907052175, 51.19717945371355, 51.97703831536429, 56.03805194582258, 55.57417631149292, 50.49054765701294, 49.17207486288888, 45.14828273228237, 45.25915861129761, 45.760564940316335, 42.86229065486363, 44.470760413578574, 44.637506757463726, 44.28537900107247, 44.9151428767613, 44.374993392399375, 48.05812576838902, 45.981597559792654, 51.64501517159598, 55.5334598677499, 58.59430462973458, 57.65084000996181, 58.30785124642508, 59.86998694283621, 50.66907467160906, 44.24937343597412, 43.33165536608015, 41.924936975751606, 42.26181691033499, 41.79653426579067, 49.25489739009312, 54.12196806498936, 55.03157411302839, 48.236572878701345, 50.20283317565918, 55.68454497201102, 57.22084379196167, 48.74481623513358, 43.84767375673567, 45.05519424165998, 51.31551769801548, 52.94023929323469, 55.78297662734985, 55.10469695499965, 58.72037969316755, 43.014438833509175, 43.588478156498496, 60.036493573869976, 50.88281863076346, 52.48231131689889, 50.23796674183437, 54.208744117191856, 51.68485614231655, 50.314657483782085, 46.7457708631243, 44.997287954602925, 53.03869874136788, 57.92864983422415, 54.6562636920384, 53.71836110523769, 55.40157611029488, 55.464571952819824, 56.034206117902485, 55.885844707489014, 55.952439716884065, 56.25682292665754, 53.121437890189036, 50.114702224731445, 45.324249335697715, 41.71300649642944, 40.46379681995937, 42.25696359361921, 42.034200872693745, 47.91078921726772, 52.85396351133074, 53.16437080928257, 50.8283725466047, 45.138982568468364, 43.342129775456016, 43.040067264011924, 44.75198180334908, 45.65823187146868, 45.72468791689192, 51.0031475339617, 57.65905278069632, 57.47802094050816, 58.234332357134136, 56.58802270889282, 58.04025527409145, 58.813902446201865, 58.1915522984096, 59.83970669337681, 57.61495951243809, 59.680613790239605, 55.643915380750386, 57.662547724587576, 57.98054592950003, 59.6232008252825, 62.830134936741416, 60.21360315595354, 65.45261437552315, 7.051061459950038, 3.4314553780215125, 7.925069281033107, 1.0132311561277934, 0.6779352479747364, 0.22239932471088, 19.370342629296438, 70.64852591923305, 41.135743209293906, 54.975693225860596, 63.5361761365618, 31.280724048614502, 26.989391531263077, 46.25337634767805, 61.7532753263201, 59.27387319292341, 73.48072283608573, 21.940611566816056, 0.3781054967216083, 0.19148404789822443, 0.1496258197086198, 0.08679577043013913, 0.1213416438549757, 0.14236060955694743, 0.14869505965283938, 0.16471246230815137, 0.17720938101410866, 0.14734444926892007, 0.27443595815982136, 0.16604967841080256, 0.1481945857937847, 0.181477067725999, 0.1906421895005873], [0.04662065174696701, 0.07405114573027406, 0.030441991851798127, 0.03527649957686663, 0.05964326885129724, 0.060281376753534587, 0.020079279518021003, 0.021822279917874506, 0.03027942164668015, 0.044541562774351666, 0.05841511368219342, 0.02938089200428554, 0.21504149452916213, 0.11779061225908143, 9.967569555555071, 66.47808510916573, 55.30619818823678, 56.58159562519619, 38.20301628112793, 19.29938588823591, 22.280444485800608, 56.341031619480674, 35.66373804637364, 57.91034133093697, 43.207550116947715, 0.1027180967586381, 0.11906365251966886, 0.25549302463020596, 1.3204702926533562, 10.616709351539612, 6.302506838526044, 1.9898442200251987, 8.127245358058385, 69.06461456843785, 64.1645781653268, 64.81873716626848, 64.84517506190709, 62.29963302612305, 60.20801680428641, 59.40281091417585, 57.985413142613, 57.71705286843436, 51.72053166798183, 43.74667821611677, 43.15698460170201, 43.47793231691633, 44.57323244639805, 42.32823474066598, 40.942089966365266, 42.65820469175066, 42.509058134896414, 41.17881161825997, 40.80550575256348, 40.660086904253276, 40.34618813650948, 39.83942474637713, 40.26039178030831, 39.29807669775826, 42.60484252657209, 41.24091114316668, 43.59553752626692, 49.33505180903843, 52.02353913443429, 51.91706146512713, 54.82653277260916, 49.751516410282676, 47.9924236025129, 40.641813141959055, 38.54479469571795, 38.11317259924752, 37.79113054275513, 39.382511207035606, 45.64870589120047, 50.33462313243321, 53.54139396122524, 50.37598575864519, 48.04977403368269, 53.376464571271626, 48.88936308452061, 39.30585868018014, 39.71932165963309, 39.19554213115147, 45.91843148640224, 46.72754226412092, 52.844527857644216, 48.687945229666575, 56.18610068729946, 38.36172355924334, 35.95315136228289, 57.55696637289864, 43.1100286756243, 43.426053592136924, 42.63564736502511, 49.76428025109427, 47.90306976863316, 45.4171849659511, 42.35913685389927, 40.28980003084455, 43.008915015629356, 48.39983122689383, 46.949884619031636, 46.43822274889265, 44.2787504196167, 47.12459707260132, 47.1513545853751, 50.25669213703701, 50.29232944761004, 51.01072801862444, 47.972044536045615, 47.313563755580354, 40.76761375154768, 38.6900189944676, 36.59593268803188, 38.623239857809885, 40.75710807527815, 40.65409755706787, 42.16807876314436, 45.215301581791465, 42.439590045383994, 39.16962535040719, 40.78279556546892, 38.78103344781058, 40.4336381639753, 39.68947219848633, 42.818770612989155, 47.97957985741751, 54.060240268707275, 56.13602154595511, 52.84644208635603, 55.16716126033238, 54.62324237823486, 53.63792181015015, 51.70745515823364, 51.694420337677, 50.066697120666504, 50.096160956791465, 48.107242584228516, 47.384619508470806, 52.474678720746724, 51.508201667240684, 55.12640312739781, 56.464122431618826, 62.13878222874233, 39.063668795994346, 0.122784928551742, 0.7317215789641652, 1.0549275130033493, 0.11501796889517989, 0.08254392751093421, 1.7194048059838158, 48.819943632398335, 46.59984827041626, 26.240070002419607, 28.44646872792925, 25.84383855547224, 14.766230004174368, 25.793389422552927, 41.080904551914756, 43.45721278871809, 46.759712423597065, 24.854981354304723, 0.07469897703932864, 0.051238913754267354, 0.03471950035808342, 0.016201131278648973, 0.04488905752077699, 0.06422831996210984, 0.015830298320257237, 0.04450912880046027, 0.02630195114761591, 0.03352450858801603, 0.02142794759544943, 0.032010242342948914, 0.08232753590813705, 0.028499003433223282, 0.037678734066763094, 0.031102932457412993, 0.01632049576645451, 0.041145159131182094, 0.061637320422700474, 0.03194706055468746, 0.015277356740885546, 0.028031725203618407, 0.11637323402932712, 0.06033981218934059, 0.0469841768832079, 0.04457443440333009, 0.05161765164562634, 0.17673033529094287, 0.16098560871822493, 13.844295246260506, 77.96257495880127, 59.78843593597412, 63.34366239820208, 44.46001502445766, 24.9756281375885, 23.03257656097412, 48.148994309561594, 39.41859320231846, 64.85772350856236, 47.03087977000645, 0.13042747202728475, 0.03885504916044218, 0.7575993303741727, 1.9455531452383314, 8.128722718783788, 4.7885482140949795, 0.8753932267427444, 9.611073987824575, 73.26828166416713, 65.5688785825457, 67.33281775883266, 65.16789804186139, 62.95760658809117, 61.5242349079677, 62.68789141518729, 59.70852470397949, 60.01044477735247, 54.28774513517107, 46.01210709980556, 45.60202094486782, 46.328792095184326, 46.46230867930821, 44.88947623116629, 42.245287145887104, 44.72805915560041, 44.27500534057617, 42.26677097593035, 43.10539075306484, 41.77093015398298, 41.119244711739675, 42.409448759896414, 41.80008132117135, 42.41933257239205, 42.50090789794922, 41.50883368083409, 46.59184047154018, 51.188108580453054, 53.85614388329642, 53.822785581861226, 56.698860372815815, 53.54252304349627, 49.470055307660786, 43.419890539986746, 42.4353585924421, 39.87091745649065, 39.34257296153477, 42.8753011567252, 47.52861050197056, 51.850233691079275, 54.92339413506644, 50.25887039729527, 49.31282799584525, 54.933580194200786, 50.85814210346767, 41.280029501233784, 42.16101939337594, 41.98948574066162, 47.31581844602312, 49.467602593558176, 54.38830641337803, 52.20627328327724, 58.74354498726981, 40.810564041137695, 38.44300706045968, 59.30809307098389, 45.38860355104719, 46.03763130732945, 44.53464215142386, 51.71445199421474, 50.09067187990461, 46.822430338178364, 43.51973615373884, 41.64285748345511, 43.91404642377581, 50.50419044494629, 49.47056252615792, 48.44456720352173, 45.792283466884065, 50.05155004773821, 49.46334334782192, 51.82089144842965, 52.78394651412964, 52.79670340674264, 51.47209187916347, 49.33225168500628, 42.64500311442784, 40.22969811303275, 38.752577100481304, 41.756363255637034, 41.904999119894846, 42.664211409432546, 45.630546774183, 47.79510171072823, 44.09278883252825, 41.498626777103965, 41.72029863085066, 40.63216209411621, 42.10092789786202, 41.277646269117085, 45.83828748975481, 52.768858500889365, 56.674830027988975, 57.76246976852417, 55.25089747565133, 56.10662024361746, 56.75738157544817, 56.46328517368862, 54.05913897923061, 54.373687403542654, 51.27616657529558, 50.84338065556118, 50.19173342841012, 50.441389151981895, 53.87608173915318, 53.3263715335301, 56.518908977508545, 58.89572443280901, 64.37416362762451, 42.85669388089861, 0.12260929654751505, 0.10635708684899978, 3.540107182094029, 0.459347308746406, 0.0798215703772647, 1.6090694751058305, 53.989615304129465, 51.78556680679321, 30.63088682719639, 33.126089164188926, 26.951103482927593, 21.980370896203176, 32.772439752306255, 45.70605632237026, 48.661017486027305, 53.99031359808785, 34.99384484972273, 0.28016444934265955, 0.012860369203346116, 0.0021651554145916763, 0.03284139345799174, 0.03429184348455497, 0.02274715368236814, 0.09689423069357872, 0.026112468547320793, 0.03338136484048196, 0.052563000204307694, 0.003812659856131566, 0.002655084415372195, 0.029902149390961443, 0.03751809090109808, 0.066412775245096, 0.13390273840299674, 0.11370243198637452, 0.11100562169615712, 0.16593872436455318, 0.08292039230998073, 0.14202078564890794, 0.12515034233885153, 0.20979536032038076, 0.11994102544018201, 0.14948385661201818, 0.10235340454216514, 0.13357791011886938, 0.2065427348549877, 0.2546433359384537, 17.24154485974993, 88.0093435559954, 66.59953267233712, 74.37314251491001, 50.21983194351196, 29.11654257774353, 32.37976230893816, 73.43533025469098, 50.7991623197283, 72.00527286529541, 52.03749459130423, 0.4942685748849596, 0.2139932257788522, 1.2918130989585603, 4.0317825589861185, 18.375789642333984, 16.500020946775162, 4.31021294423512, 12.282453111239843, 76.52110862731934, 67.8604987008231, 69.70990071977887, 67.65998063768659, 66.72226565224784, 63.21958146776472, 64.79753821236747, 61.65267930712019, 63.20469147818429, 57.25183970587594, 47.06631905691964, 49.15829658508301, 48.30175045558384, 49.58426284790039, 46.84695747920445, 43.033473423549104, 46.183741501399446, 47.994615759168354, 46.02159139088222, 46.49804326466152, 46.367781911577495, 44.2622241292681, 45.7632052557809, 44.4920323235648, 44.80542039871216, 45.71543639046805, 45.20337152481079, 48.136980874197825, 55.2669860294887, 56.79414449419294, 56.66789919989449, 59.060646874564036, 54.461919103349956, 51.13892228262765, 45.85260425295149, 44.116186891283306, 42.671507017953054, 41.680593150002615, 44.95719684873308, 50.69723572049822, 55.088577134268625, 56.72856044769287, 51.762509209769114, 51.984434672764365, 58.08206953321184, 54.36102431161063, 43.37170130865914, 43.602447509765625, 44.676670278821675, 49.75899962016514, 51.88895947592599, 56.73558855056763, 55.257995060511995, 60.97252014705113, 43.78589037486485, 42.8896735055106, 62.57614353724888, 47.29381002698626, 48.537485463278635, 46.09629494803292, 55.13315677642822, 52.80783442088536, 48.38224186216082, 46.17349638257708, 43.40457671029227, 45.275997570582796, 52.7373241015843, 51.60867261886597, 50.534783363342285, 48.064907210213796, 53.595179966517854, 50.8618802343096, 53.912455558776855, 55.71962642669678, 54.35995428902762, 53.27390916006905, 52.43250315529959, 44.93120016370501, 43.09862320763724, 42.170701708112446, 44.52533156531197, 45.93715688160488, 44.90105887821743, 46.43414068222046, 49.414323806762695, 46.599757943834575, 42.9075859614781, 45.158861364637104, 43.077729974474224, 44.11313663210188, 43.00577095576695, 47.31243814740862, 54.42086567197527, 58.81056036267962, 62.90817015511649, 57.14766189030239, 59.1688928604126, 58.34003530229841, 58.439040184020996, 56.39879894256592, 58.528734479631694, 54.217988695417134, 55.526077406747, 52.428396769932334, 52.9605975151062, 56.40628562654768, 56.54408924920218, 59.976551464625764, 62.68691866738455, 64.59564440590995, 44.65786845343453, 0.2114874366670847, 5.25511714390346, 7.182943914617811, 0.25423203515154974, 0.22310339978763036, 2.5964167458670477, 58.89352880205427, 58.647381918770925, 39.36108991077968, 39.97074569974627, 38.04207863126482, 24.938648087637766, 37.57612548555647, 53.66306734085083, 58.31356961386544, 61.90504482814244, 43.532475675855366, 0.6068426913448742, 0.0990993609385831, 0.13883765574012483, 0.09479506047708647, 0.13767995286200727, 0.12465220264026097, 0.10744122974574566, 0.13076764877353395, 0.10496311807738883, 0.25726720371416634, 0.08977287675121001, 0.19926921943468706, 0.2035815944629056, 0.10814707579889468, 0.19145892853183405], [0.1237036513962916, 0.052422149905136654, 0.004531602059224886, 0.06822576653212309, 0.05965146555432251, 0.051116791021611006, 0.041885624040982554, 0.05599547476906862, 0.0802054244226643, 0.0501163488120905, 0.027890857941071902, 0.016535501461476088, 0.033026307821273804, 0.056175954906003814, 29.22841031210763, 68.47495569501604, 57.0102265221732, 53.12902879714966, 38.72501359667097, 27.602827140263148, 37.42825392314366, 40.04826675142561, 32.84574672154018, 70.1576565333775, 17.906301600592478, 0.06424835710121052, 0.027594300818496516, 0.19342890568077564, 0.5440210423299244, 3.475283746208463, 5.980749223913465, 0.6208743612681116, 47.19889416013445, 71.40512221200126, 61.79277583530971, 61.35772132873535, 62.50993415287563, 62.25531741550991, 58.1453537259783, 56.51669250215803, 58.94957297188895, 56.220671449388774, 58.62237535204206, 48.60508796146938, 43.113937037331716, 41.77018322263445, 43.15112032209124, 41.68730510984148, 41.542799949645996, 40.61831086022513, 42.06492233276367, 40.14416578837803, 39.11983803340367, 37.83285100119454, 37.28708042417254, 37.69365773882185, 39.69708047594343, 40.08384847640991, 40.562218053000315, 38.78569916316441, 40.43268278666905, 48.98406703131539, 50.85467842647007, 52.281744616372244, 53.44053391047886, 50.48674699238369, 44.14926379067557, 39.88862146650042, 37.67064183098929, 38.11198445728847, 38.728018692561555, 39.64406572069441, 44.59768315723964, 47.11691236495972, 48.068937165396555, 45.44067335128784, 51.850386551448274, 51.568591935294016, 45.768180165972026, 37.946957792554585, 40.809097971235005, 38.575724601745605, 44.96093497957502, 43.4249210357666, 48.642736775534495, 46.54736157826015, 55.026859760284424, 39.62174463272095, 37.25452463967459, 56.049262864249094, 46.35350683757237, 45.31804459435599, 40.84765005111694, 48.491658619471956, 45.89442546027047, 46.806901114327566, 42.361332484654014, 41.37846115657261, 37.62005547114781, 37.808563573019846, 38.30101367405483, 41.51742512839181, 38.790566376277376, 42.10430472237723, 43.93047891344343, 46.64709254673549, 50.162123680114746, 51.196408203669954, 49.18034669331142, 47.83159364972796, 42.03333582196917, 38.57356718608311, 36.76314108712332, 37.13590499332973, 39.7755742754255, 40.71031890596662, 39.99484552655901, 40.158531188964844, 39.311441557747976, 41.06919683728899, 39.848349707467214, 40.02739436285836, 39.49313000270298, 40.38052960804531, 46.282510144369944, 53.44738483428955, 54.65747962679182, 53.09966570990426, 54.57388584954398, 54.77634246008736, 52.33429036821638, 50.94059985024588, 48.43743487766811, 48.283487115587505, 46.360243116106304, 48.89901065826416, 48.523550851004465, 49.996485573904856, 47.83027696609497, 52.76716661453247, 53.43445076261248, 57.692279066358296, 54.36906337738037, 62.73868274688721, 12.966976608548846, 0.42342761904001236, 3.068024856703622, 0.6005719963993345, 0.18870046654982225, 0.15376142279378005, 19.727978570120676, 57.29401874542236, 35.34189053944179, 28.586523566927227, 24.045177493776592, 16.056305510657175, 13.258125237056188, 30.792588778904506, 43.46456398282732, 47.18108592714582, 36.091441358838765, 0.6074898509042603, 0.08666794121797596, 0.021754048132736768, 0.022051992859425287, 0.023458847011040364, 0.014853823663932937, 0.027527855276795368, 0.08755408081093005, 0.03724331135994621, 0.04293219645374587, 0.012430295048813735, 0.03318943103243198, 0.03526379061596734, 0.05187238047697714, 0.03483211002977831, 0.0372431688675923, 0.04105578589120081, 0.06416961989764657, 0.021764645153390508, 0.0306213286572269, 0.02801066686931465, 0.027290281507053545, 0.04201216742928539, 0.0557780009029167, 0.017820139581869756, 0.03198987611436418, 0.04865858757070132, 0.020095974872154847, 0.04003800032660365, 41.958010401044575, 75.23464271000454, 62.83613123212542, 58.648514475141255, 45.55332449504307, 36.723842075892854, 30.38528537750244, 36.594487462724956, 40.20336791447231, 75.71268572126115, 20.068940571376256, 0.32197252022368567, 0.07406848230000053, 1.5488496550491877, 2.2474999257496426, 5.300715999943869, 3.1301756245749335, 0.41655329934188295, 50.921283858163015, 72.73916939326695, 64.06929751804897, 63.350666182381765, 64.35899571010044, 63.48291819436209, 58.13206877027239, 58.33403900691441, 62.25425434112549, 59.2621237891061, 59.18238626207624, 52.16635935647147, 45.3535464150565, 44.180982317243306, 46.50548825945173, 43.27817160742623, 43.32887956074306, 43.068669523511616, 44.05357667378017, 42.93143217904227, 42.44116381236485, 38.727574007851736, 40.87223277773176, 40.761582715170725, 41.806091512952534, 41.415946687970845, 41.92575338908604, 39.619107791355674, 41.307408877781455, 49.83763238361904, 53.889342376164024, 54.13733400617327, 55.97629983084542, 52.60961273738316, 46.79112522942679, 41.12987198148455, 40.002714361463276, 38.79906402315412, 41.06652178083147, 42.63364280973162, 46.29953670501709, 50.84810195650373, 49.023296560559956, 48.069357531411306, 54.24594477244786, 52.8665223802839, 48.567043100084575, 40.64737170083182, 41.89422246388027, 41.46097796303885, 46.266379901341026, 46.40867900848389, 50.623286042894634, 49.548611640930176, 58.983778953552246, 41.613602093287874, 38.81853634970528, 57.014270373753135, 49.369115352630615, 47.80559696469988, 42.67664173671177, 50.24235800334385, 48.2189279283796, 49.36945928846087, 44.427243845803396, 43.860364641462056, 38.38513898849487, 39.61499098369053, 40.31069326400757, 42.79155799320766, 40.37115996224539, 44.783380712781636, 46.15472929818289, 50.63182537896292, 52.47690909249442, 53.05952944074358, 50.61871065412249, 49.71163722446987, 44.83684362683977, 41.260810783931184, 38.61957468305315, 39.880002226148335, 41.007191113063264, 41.695531776973176, 42.17348793574742, 41.848520687648225, 40.64229951586042, 42.64629895346505, 42.40256656919207, 41.90367201396397, 41.466849190848215, 42.666226387023926, 49.44569492340088, 54.81021492821829, 55.60104846954346, 53.55012089865548, 55.803327901022776, 57.70571688243321, 54.97481427873884, 54.33619492394583, 51.295847347804475, 50.44809763772147, 48.30706582750593, 51.792581013270784, 49.28072037015642, 52.86102288109915, 51.076253005436485, 54.606969697134836, 54.656051771981375, 60.362086159842356, 57.636617047446116, 65.75369371686662, 16.69519410814558, 0.6188207343220711, 1.8669855211462294, 1.9410941387925829, 0.37286356942994253, 0.1782907351319279, 20.656306539263042, 64.03008188520158, 40.01062488555908, 29.743831157684326, 27.606495789119176, 22.324162551334926, 17.93474578857422, 34.550153732299805, 49.85716724395752, 53.93936940601894, 48.28814935684204, 1.978506931236812, 0.13237840948360308, 0.04243193972589714, 0.07611649097608668, 0.00522191050861563, 0.05410812622202294, 0.011427224364264734, 0.07263819154884134, 0.056032709378216944, 0.010353920216272985, 0.011230734193564525, 0.04455066532162683, 0.04826985485851765, 0.011469572582947356, 0.029967044480144978, 0.18713376990386418, 0.17006241237478598, 0.14831301729593957, 0.21123719295220716, 0.13103989059371607, 0.20675460062921047, 0.1443352143147162, 0.1680135080324752, 0.166406601401312, 0.15255193412303925, 0.12994526433093206, 0.16061092168092728, 0.20400178405855382, 0.2040372442986284, 48.51319456100464, 84.1471734728132, 71.88019139426095, 67.92396354675293, 50.97467381613595, 39.9901624407087, 51.52666303089687, 56.14243473325457, 46.24684156690325, 85.10830388750348, 21.95244608606611, 0.3682203542973314, 0.17118080093392304, 3.25842438851084, 2.9751517602375577, 16.713257687432424, 14.904092686516897, 0.8029768754329, 58.28727763039725, 74.61162553514752, 68.44188921792167, 65.12371444702148, 67.41557080405099, 65.41225923810686, 60.441156659807476, 59.951197487967356, 64.86906991686139, 61.66714545658657, 62.09092998504639, 53.69186762401036, 47.39970752171108, 45.95922783442906, 48.44308723722185, 45.854918003082275, 45.63261038916451, 44.64767892020089, 47.544417653764995, 44.90262222290039, 42.43956225258963, 41.47315468106951, 42.23101554598127, 42.87942838668823, 43.61211940220424, 42.92063467843192, 44.43425457818167, 42.173606055123464, 44.05279500143868, 53.453322069985525, 55.00791202272688, 57.35619122641427, 57.84665414265224, 55.33643674850464, 48.79774066380092, 43.494382177080425, 41.76405143737793, 40.94885056359427, 44.57306221553257, 45.406109537397114, 48.52232449395316, 52.52171802520752, 50.08910158702305, 50.61219671794346, 56.496657371520996, 56.16378307342529, 51.0259028843471, 41.79654468808855, 43.20567757742745, 43.13173484802246, 50.6012533051627, 48.174178055354524, 54.109058312007356, 51.82929529462542, 60.145552498953684, 45.547265665871755, 41.47839709690639, 58.768780844552175, 51.12395586286272, 50.99163089479719, 46.29962355749947, 52.88639422825405, 50.61501768657139, 51.703237601688926, 47.465413161686485, 46.425733361925396, 43.954700333731516, 40.777893611363, 42.25524391446795, 44.79764883858817, 43.042735372270855, 47.09704746518816, 47.75378424780709, 51.92557995659964, 55.070893968854634, 56.1943655695234, 53.806766510009766, 51.150094985961914, 47.51957436970302, 42.80478041512625, 41.8575325012207, 40.89321286337716, 43.10054438454764, 44.52901758466448, 44.968689169202534, 44.20564494814192, 43.031760692596436, 45.31778056280953, 44.57268353870937, 44.33026783806937, 43.55334806442261, 45.046415192740305, 50.52712992259434, 58.42452539716448, 59.185964584350586, 54.20968907220023, 57.9517491204398, 58.76762049538748, 56.70450578417097, 55.957174914223806, 53.19872965131487, 52.32165159497942, 49.78946399688721, 56.39523799078805, 53.12244537898472, 54.77314281463623, 52.092534746442524, 57.1949200630188, 57.87651750019619, 63.487337248665945, 58.33415017809187, 70.17486722128731, 16.749060017721995, 2.1893332983766283, 10.638513667242867, 1.978066806282316, 0.3995305656322411, 0.2092181984335184, 26.48561065537589, 68.85151331765312, 49.299372809273855, 41.86523805345808, 35.47098459516253, 23.786761828831263, 21.83911575589861, 42.40939664840698, 58.585751397269114, 59.396870204380576, 56.4499967438834, 3.5715877328600203, 0.3326347480927195, 0.11407798076314585, 0.17653611142720493, 0.12755017142210687, 0.12483730699334826, 0.0997825235660587, 0.2030962790761675, 0.12444235890039376, 0.11709501887006418, 0.10193790362349578, 0.10398931176002536, 0.11040783913007804, 0.08316051906773023, 0.14882934173302992], [0.024295258468815258, 0.015022249626261848, 0.05377312330529094, 0.042663930848773034, 0.017396557311128293, 0.0698216198278325, 0.06602875835129193, 0.0342027687999819, 0.04263526613691023, 0.02769343478472105, 0.06592522069279637, 0.08093180294547762, 0.02019360927598817, 1.0463480076619556, 48.94848183223179, 62.25091920580183, 58.024215357644216, 49.88470990317208, 34.694287163870676, 21.131408725466045, 33.1393324307033, 40.65840891429356, 42.862519945417134, 66.7150742667062, 6.466958974088941, 0.0752269858494401, 0.1629141816603286, 0.04970273082809789, 2.1302905465875352, 5.838929108210972, 3.9022842049598694, 3.4949134928839545, 74.27397782461983, 57.94163949148995, 62.947357995169504, 56.678373609270366, 63.172806194850374, 59.19556699480329, 62.94616985321045, 56.19270495006016, 56.41659675325666, 56.53410121372768, 58.06639092309134, 54.256954193115234, 50.003506728581016, 43.751482895442415, 43.04119634628296, 40.266332490103586, 41.96257536751883, 39.634821142469136, 42.09781163079398, 38.5065587588719, 39.808192593710764, 37.939978327069966, 40.59654215403965, 39.04209811346871, 39.820171288081575, 36.75761726924351, 41.45405755724226, 37.24758686338152, 39.72095101220267, 40.850901808057515, 50.38303123201643, 52.07238149642944, 51.36118125915527, 46.76693160193307, 43.71951770782471, 38.94591072627476, 38.43226514543806, 38.93314688546317, 39.11494302749634, 41.1521965435573, 44.804225308554514, 49.54878881999424, 50.39176164354597, 49.428258419036865, 53.90139055252075, 47.37192167554583, 41.629082679748535, 37.358928271702354, 38.92012596130371, 37.56482771464756, 42.80010775157383, 41.206333432878765, 46.055748735155376, 46.0061594418117, 56.39568267549787, 41.4849214553833, 35.91091673714774, 54.77228123801095, 49.02233076095581, 44.554500102996826, 38.321392740522114, 42.539640630994526, 43.95215034484863, 44.169851303100586, 43.0196465083531, 39.04882396970476, 38.6382132257734, 38.097306387765066, 38.245914459228516, 38.7939327784947, 38.123184953417095, 37.72092941829136, 44.131160259246826, 45.29396908623831, 50.89019066946847, 49.57145036969866, 49.608491216387065, 46.662684304373606, 42.78092377526419, 39.392579146793906, 37.25565024784633, 37.46236957822527, 38.92537532533918, 39.618656158447266, 39.660373142787385, 38.357742241450715, 40.35259090151106, 39.7924861907959, 39.58432510920933, 39.785503251211985, 38.818814277648926, 38.40016794204712, 49.41827385766165, 52.96176133837019, 53.49480281557356, 53.23540224347796, 53.79744897569929, 53.10269512448992, 50.17401899610247, 46.018214566367014, 45.918167454855784, 46.56365510395595, 45.250949314662385, 45.102674756731304, 47.159032344818115, 45.00137349537441, 49.53197765350342, 48.8324225970677, 50.54942669187273, 55.10739285605294, 55.874612944466726, 60.942788805280415, 46.427227224622456, 0.6030658025826726, 1.6907164539609636, 1.2365227001053947, 0.040620373362409215, 0.05590116518682667, 3.755824863910675, 52.77464287621634, 49.207764284951345, 36.088293824877056, 38.39099631990705, 25.26303689820426, 23.847794805254253, 26.477012259619578, 41.81719126020159, 47.07317345482962, 48.39238623210362, 9.015214715685163, 0.22717245215816156, 0.04641064855137041, 0.024384426451953392, 0.11228246175284896, 0.07681458815932274, 0.010056683710510177, 0.023047917722059146, 0.05174405932692545, 0.014082743254091059, 0.018978105392307043, 0.01421447319444269, 0.07455440836825541, 0.040693224274686406, 0.1212474631943873, 0.038794065825641155, 0.03327158805248993, 0.034776717823530943, 0.07551162450441293, 0.04272502953452723, 0.05400925349178059, 0.02646142214403621, 0.033571663379137, 0.020016157101573687, 0.049527974134044986, 0.022046868223696947, 0.05925336905888148, 0.058531618144895346, 2.6372938667024886, 60.26857730320522, 69.3805352619716, 63.44472394670759, 57.257738726479666, 43.437983649117605, 24.68082128252302, 28.94680503436497, 42.54838146482195, 51.20207098552159, 71.23374489375523, 6.6362500957080295, 0.11229782378567116, 0.18875508861882345, 0.5035427915198463, 2.54409789613315, 4.988453967230661, 2.0452610978058408, 4.498641141823359, 77.49994305201939, 59.69578865596226, 66.46316732679094, 57.46762296131679, 66.8461172921317, 59.02526664733887, 65.61689063480922, 57.65743385042463, 59.99223354884556, 57.48230797903878, 59.160624504089355, 56.87851299558367, 52.61144011361258, 46.39553301674979, 43.77803543635777, 41.55032484872, 43.90951272419521, 41.142173767089844, 44.8483498437064, 40.59256083624703, 43.54231085096087, 39.461456639426096, 43.37507813317435, 41.337379932403564, 42.19183118002755, 40.077522141592844, 43.08528961454119, 39.96870640345982, 42.55579171861921, 43.365590367998394, 53.85248218263899, 54.05042246409825, 54.91813434873308, 49.206364222935264, 47.09339966092791, 40.97356183188302, 40.32537133353097, 40.10635716574532, 41.40824808393206, 41.855913570949006, 48.08951078142439, 50.8280668258667, 51.755161489759175, 48.96702310017177, 54.90769815444946, 49.01143251146589, 43.327253682272776, 38.70352281842913, 41.269843442099436, 40.53460591179984, 45.180400780269075, 43.80837821960449, 47.72933006286621, 47.750324044908794, 57.63345561708723, 42.948760986328125, 38.37338611057827, 57.21114758082798, 51.23229564939226, 45.78479330880301, 40.242062432425364, 45.58094358444214, 46.254230976104736, 46.71961089542934, 44.80536828722273, 41.706207684108186, 40.63793952124459, 39.29000983919416, 42.00353152411324, 41.612170764378135, 38.85594197681972, 39.49134431566511, 46.22103943143572, 47.34177344185965, 52.17074714388166, 52.23125900541033, 51.93040548052107, 49.12153366633824, 45.51772539956229, 41.31391933986119, 38.870161465236116, 39.888214996882844, 40.47797809328352, 41.70672879900251, 40.72427783693586, 40.006855487823486, 42.65822901044573, 40.24537672315325, 41.71486166545323, 40.8366128376552, 42.108914852142334, 40.69180195672171, 51.038625035967144, 53.397816385541645, 54.82490689413888, 55.17669071469988, 55.40710687637329, 54.94995362418038, 53.00925922393799, 48.345888887132915, 49.859015464782715, 47.43161712374006, 46.926840918404714, 47.00877407618931, 49.60811601366316, 47.64146661758423, 51.52221965789795, 50.383903230939595, 54.884418215070454, 56.09727839061192, 59.02548204149519, 61.37186786106655, 51.32629435403006, 0.8942584001592228, 0.44496144354343414, 3.6927100334848677, 0.712846037532602, 0.07544066331216268, 3.018828136580331, 57.10780702318464, 53.062069007328574, 37.47393832887922, 36.77121836798531, 24.654868023736135, 26.747959000723704, 30.679492950439453, 46.368407249450684, 52.554986000061035, 56.58120305197579, 15.095199414661952, 0.2247965617903641, 0.06334239071501152, 0.06229523476213217, 0.0876223278631057, 0.037804300364639075, 0.04280348853873355, 0.0057554510754666156, 0.010319348857072847, 0.024440598973472203, 0.04845860633733017, 0.028583141775535684, 0.02449056289957038, 0.04044952163738864, 0.07109792384185962, 0.13468601208712372, 0.1294625545186656, 0.10710974503308535, 0.1995483823120594, 0.09924682695418596, 0.1129663639834949, 0.23057564454419271, 0.1365542361246688, 0.10690262221864291, 0.2009724916091987, 0.1573920329766614, 0.20995630882680416, 0.215526728491698, 4.001530536583491, 73.20491409301758, 77.82772432054792, 71.78574453081403, 63.89261177607945, 47.489339283534456, 28.137086289269583, 48.71092987060547, 59.871988024030415, 55.822397232055664, 78.8246796471732, 8.40133876459939, 0.15897441735225065, 0.33737705647945404, 2.286579634462084, 5.327826568058558, 14.159740856715612, 7.373430950301034, 5.551013997622898, 82.5419728415353, 62.15813296181815, 69.21698161533901, 60.36495576586042, 69.30256257738385, 62.0963773727417, 67.67367553710938, 59.54846600123814, 61.35343429020473, 58.91161496298653, 63.23474243709019, 59.85798740386963, 55.618787220546174, 48.294319357190815, 46.42689371109009, 44.28245728356497, 47.11979239327567, 42.21803978511265, 48.00011873245239, 42.99897909164429, 45.08087478365217, 40.661980288369314, 45.65534836905343, 43.63945361546108, 45.24398374557495, 40.153531960078645, 46.98015444619315, 40.70978389467512, 45.3235718863351, 43.905288219451904, 56.52639218739101, 57.814765385219026, 57.64101178305489, 49.722337450299946, 50.92700569970267, 43.90617758887154, 43.646342754364014, 44.78611830302647, 43.417274543217246, 43.83438185283116, 49.378693444388254, 53.32631594794137, 53.856407914842876, 52.18090888432094, 57.16598776408604, 51.63194561004639, 45.34684487751552, 39.4941965511867, 43.47486121313912, 41.920500550951274, 47.08675370897566, 46.25401905604771, 50.491947719029014, 49.65543324606759, 61.63059793199812, 46.02186584472656, 39.57482692173549, 58.43506581442696, 54.00253200531006, 48.47977025168282, 44.7740284374782, 45.633489336286274, 48.65486485617501, 48.32277570452009, 46.62558092389788, 44.36664513179234, 42.35712882450649, 40.27572298049927, 44.71918978009905, 43.585347993033274, 42.096936157771516, 40.327275139944895, 49.93014417375837, 50.48904684611729, 55.93940142222813, 54.20105593545096, 53.90623344693865, 51.56627123696463, 47.80220971788679, 44.4174017224993, 41.66618258612496, 41.884192739214214, 42.532108783721924, 43.849000862666536, 43.54034798485892, 41.86892754690987, 45.15723548616682, 42.371786049434114, 43.53593935285296, 43.304845741816926, 43.57524878638131, 42.400231974465505, 54.15553133828299, 55.62510313306536, 58.3300507409232, 56.598271301814485, 57.79917710168021, 57.44275188446045, 56.72455481120518, 51.081158433641704, 52.87939044407436, 50.98076043810163, 49.838264669690815, 49.021166937691824, 52.35231399536133, 51.30352510724749, 55.59665720803397, 53.178065708705354, 57.490107331957134, 60.73293931143624, 62.15536757877895, 64.73514338902065, 53.35276773997715, 1.15143321454525, 6.026858772550311, 4.934301444462367, 0.4520104452967644, 0.15292196641010897, 5.123680242470332, 61.59591252463204, 60.784189224243164, 50.75975213732038, 47.48743895121983, 34.834084919520784, 35.27868972505842, 37.787604331970215, 56.24450377055577, 58.461892809186665, 65.87164633614677, 17.30667553629194, 0.304714741983584, 0.18071565644017287, 0.20315482307757649, 0.23700888933879988, 0.17572215438953467, 0.07069656359297888, 0.12684433215430804, 0.15068012742059572, 0.09543806740215846, 0.15739887260964938, 0.21262878685125283, 0.17816369980573654, 0.11275408430291073, 0.22355200642985956], [0.029193460276084285, 0.033426375460944006, 0.032874818093010356, 0.059647543621914725, 0.04769618742700134, 0.026840221103546873, 0.046563125548086, 0.049427116688873084, 0.04024202223601086, 0.019422393159142563, 0.017102471752358333, 0.06335202591227633, 0.05391288794843214, 8.922343356268746, 59.21534851619175, 57.234712396349224, 58.779620034354075, 34.68560538973127, 15.85632940701076, 31.531175340924943, 48.99562535967146, 30.892135620117188, 55.83709614617484, 45.82583284378052, 0.26131162526352064, 0.06349584819482905, 0.11545661464333534, 0.13334061285214766, 4.627451624189105, 21.103233780179703, 0.625000288443906, 22.166860546384537, 76.93032973153251, 56.12014838627407, 59.10923562731062, 46.74947772707258, 57.30916234425136, 57.3903728893825, 59.88662787846157, 59.064642088753835, 60.15765626089913, 53.46198647362845, 59.51066085270473, 53.08494247709002, 54.252941608428955, 47.63147858210972, 48.138162067958284, 42.403250966753276, 42.25368056978498, 39.23805815832955, 40.51845135007586, 39.231057848249165, 40.38236045837402, 37.8235890524728, 41.87977715900966, 38.41396706444876, 40.941249234335764, 39.109916005815776, 40.74013710021973, 38.21697868619646, 39.887391635349815, 37.40261854444231, 43.18270335878645, 48.542964117867605, 48.2184658731733, 44.63184744971139, 41.98064415795462, 38.49353436061314, 37.88821772166661, 37.976258346012656, 38.87631409508841, 40.367199489048545, 45.82249076025826, 48.741359506334575, 54.6851612499782, 50.811523165021626, 50.32588577270508, 41.03962530408587, 39.09741619655064, 36.23793717793056, 40.24535935265677, 42.033360140664236, 47.80906411579677, 45.692632402692524, 49.7459647996085, 45.32197380065918, 55.73131329672677, 40.48569754191807, 33.33175236838204, 56.443250043051584, 48.15072093691145, 45.92054721287319, 35.610500948769705, 39.90227467673165, 38.91384826387678, 41.41191325868879, 38.32927547182356, 39.95303126743862, 38.26387207848685, 39.86796794618879, 38.288611139569966, 40.822115421295166, 39.62100117547171, 39.73342997687203, 39.382657119206016, 42.65597432000296, 46.15920393807547, 46.29690333775112, 45.37695142201015, 43.80725955963135, 38.414606298719136, 38.63999891281128, 37.782775333949495, 39.79833309991019, 38.6072416305542, 40.12953635624477, 39.678045885903494, 39.62702178955078, 39.3936630657741, 39.68109267098563, 39.19871745790754, 38.28142670222691, 40.88723393848964, 39.79416070665632, 46.82270131792341, 54.07525532586234, 52.12492030007498, 52.30448954445975, 51.50824335643223, 46.78227322442191, 44.52490425109863, 44.55878019332886, 42.8534699167524, 42.89517995289394, 42.50143248694283, 43.922405106680735, 45.633833272116526, 46.917940276009695, 45.494150161743164, 46.794783455984934, 48.214258738926475, 52.10267216818673, 56.77671146392822, 54.68882295063564, 57.82192202976772, 14.636369909558978, 0.1873108675437314, 3.886334180831909, 1.0664471920047487, 0.09464266829724823, 0.013970164964640779, 26.75228078024728, 57.72665875298636, 34.6313990184239, 41.83264057976859, 51.281287397657124, 19.176837035587855, 15.506402492523193, 39.66320105961391, 43.22621645246233, 49.628352642059326, 27.18883957181658, 0.13898796481745584, 0.031177496670612266, 0.1100758658722043, 0.06978738773614168, 0.12401735170611314, 0.015821702977908508, 0.0983505296920027, 0.0009944066405296326, 0.05573462215917451, 0.012850884131954184, 0.06938247874911342, 0.05368271869208131, 0.055914274483386955, 0.03129940227206264, 0.017322028721017495, 0.008665941372912909, 0.06979311457169907, 0.09757537128669874, 0.051582985291523595, 0.03575658345861094, 0.02526343464186149, 0.07734311944139854, 0.018124058809397475, 0.0350315687911851, 0.05169422432248082, 0.0971938988992146, 0.12221656047872134, 15.212422473090035, 71.54169600350517, 61.629944801330566, 65.10265445709229, 42.163642338344026, 26.177352087838308, 23.4333747114454, 34.530156816755024, 38.830389976501465, 63.73089940207345, 50.02792269842965, 0.3018755886171545, 0.0693348930882556, 0.36028507724404335, 1.6803239030497414, 6.052045123917716, 30.14141402925764, 0.3611373172274658, 25.30084204673767, 77.54671832493374, 60.07361085074288, 61.381956645420615, 49.3883410181318, 60.50064018794468, 60.142509187970845, 61.40321118491036, 62.678414072309224, 59.98477118355887, 55.720387254442485, 62.35426671164376, 57.47434186935425, 57.19887706211635, 49.14893388748169, 48.28176743643624, 44.622154712677, 42.98667730603899, 42.16124868392944, 42.30817529133388, 42.98931762150356, 42.49932370867048, 40.65992709568569, 42.026328563690186, 40.49799237932478, 44.63081216812134, 39.8664984021868, 41.530960219247, 40.049114431653706, 40.979162079947336, 39.14389617102486, 45.56418105534145, 50.297196660723, 50.87968846729824, 47.09609208788191, 43.44310794557844, 39.50779070172991, 39.42146280833653, 40.549964904785156, 40.03117765699114, 41.45818478720528, 48.814583097185405, 51.29620170593262, 56.82742983954293, 53.22517796925136, 53.918382372174946, 44.23110662187849, 41.702375752585276, 39.26695224217006, 43.17840242385864, 43.765556471688406, 50.728377546582905, 47.40121875490461, 50.68989494868687, 47.67793771198818, 57.614973408835276, 40.81660549981253, 35.20723097664969, 59.23198250361851, 50.20519208908081, 47.55588218144008, 37.332115173339844, 41.91217313494001, 41.794154507773264, 44.18155901772635, 40.04015472957066, 41.285396984645296, 39.22905676705496, 40.517009598868235, 42.228819915226524, 41.733277865818565, 40.73232732500349, 40.56338882446289, 41.832734380449565, 46.011450495038716, 47.417161396571565, 48.23201138632638, 47.55106707981655, 44.93541772024972, 40.64708335059029, 40.270199162619456, 39.3088116645813, 41.09875099999564, 39.92849717821394, 41.816819531576975, 40.864450795309885, 41.656041690281455, 40.6069609778268, 42.08904995237078, 42.63554661614554, 41.37918724332537, 43.70003843307495, 40.46431793485369, 48.69559867041451, 54.653161321367534, 53.92380196707589, 54.897897720336914, 54.61753443309239, 50.53449501310076, 45.564750807625906, 46.24170684814453, 46.428787095206125, 44.95802021026611, 44.76730605534145, 46.10131502151489, 47.46611492974417, 49.843357699257986, 47.80054562432425, 48.712625231061665, 50.61003582818167, 53.49669272559029, 58.507236753191265, 57.78912305831909, 61.43306759425572, 18.633053643362864, 0.2785302927451474, 2.195941903761455, 2.1397279373237064, 0.15342735286269868, 0.04485122240813715, 25.962388719831193, 62.414556230817524, 39.87988410677229, 36.229946749550955, 41.620928968702046, 22.825205836977275, 20.48594192096165, 44.88172551563808, 49.903400557381765, 55.25826604025704, 36.99288327353341, 0.22784660384058952, 0.023876461566292813, 0.06908376727785383, 0.018272761455071822, 0.07495239629809346, 0.033483094203152826, 0.012688407225401273, 0.02913961512967944, 0.004581451906623053, 0.012253101565875113, 0.04857945342415145, 0.06819262009646211, 0.015533264526831252, 0.061458438235734186, 0.09088299396846976, 0.11011622513511352, 0.19326864928007126, 0.22866719695074217, 0.1483247559517622, 0.09458654666585581, 0.09878722125930445, 0.11176248001200811, 0.1665291991084814, 0.13461525445537909, 0.24098885006138257, 0.22325080473508152, 0.26859805999057634, 20.024183750152588, 81.86232089996338, 70.17444338117326, 74.4802212033953, 47.04790980475289, 25.991800444466726, 42.83700268609183, 69.31209550585065, 45.62576641355242, 71.18470450810024, 54.66642195837838, 0.5848918663603919, 0.2357947187764304, 0.8874771754656519, 2.5226210142884935, 16.212040696825298, 35.88683775493077, 2.40141989503588, 28.170873641967773, 79.74832453046525, 61.636649812970845, 64.93484851292202, 50.9069948877607, 62.623335702078684, 62.716941833496094, 63.454639026096885, 64.71814114706856, 62.04788589477539, 57.97262498310634, 64.4572571345738, 60.78295939309256, 59.97030503409249, 51.40090063640049, 52.02994884763445, 46.593831130436485, 46.55622053146362, 44.93238830566406, 45.41323491505214, 44.69927971703665, 44.49962670462472, 43.27100454057966, 46.713611125946045, 41.87996128627232, 46.72004863194057, 41.625754492623464, 43.49333994729178, 41.170557158333914, 44.23585571561541, 40.5134972844805, 47.86479214259556, 53.839711393628804, 53.116171155657085, 49.40650013514927, 46.79144137246268, 42.89779594966343, 41.4808463369097, 41.93199634552002, 41.16777440479824, 44.459580762045725, 50.144131319863455, 53.38312094552176, 60.5780222756522, 54.17907878330776, 56.16043751580374, 46.413719926561626, 44.55147416251046, 40.038754667554585, 45.786297593797954, 46.25524193899972, 53.87707185745239, 49.376813956669395, 52.518608706338064, 49.60786935261318, 59.58120591299874, 45.26940025602068, 36.850542477199006, 61.20069898877825, 53.20223501750401, 49.114759172712056, 38.2609920501709, 44.41268042155674, 44.1686110496521, 46.47147682734898, 42.158789021628245, 45.362933431352886, 41.697418212890625, 42.887001923152376, 43.65967634746006, 44.24809149333409, 42.56902803693499, 42.708047594342915, 44.21903760092599, 47.35685450690133, 50.63288845334734, 51.16646146774292, 49.79358775275094, 46.96076897212437, 42.2605836050851, 42.60689919335501, 42.12648337227957, 44.0129714012146, 42.0294691494533, 44.625594070979524, 44.08716426576887, 43.6408953666687, 43.626818316323416, 44.957405294690815, 43.803893157414024, 42.17533963067191, 46.9771215575082, 42.36577933175223, 51.054567677634104, 58.108594281332834, 56.81192493438721, 57.79160009111677, 57.12226969855172, 52.906894888196675, 49.49964421136038, 49.31341164452689, 48.482344559260774, 48.13510486057827, 48.05299799782889, 49.94148710795811, 51.601040022713796, 52.58807332175118, 51.16818809509277, 52.28330448695591, 53.47597667149135, 55.303074972970144, 60.891406876700266, 59.07279232570103, 62.40647547585623, 19.154354401997157, 0.48042928321020945, 11.655590108462743, 2.191050806215831, 0.2431183915053095, 0.20425905739622457, 33.046956130436485, 67.73021302904401, 48.20844309670584, 52.56037432806832, 60.656238147190635, 27.504117556980678, 24.383332422801427, 54.09693023136684, 56.68794822692871, 62.88892364501953, 42.262744494846885, 0.4389260102595602, 0.15396555326879025, 0.19667599430041655, 0.18727672366159304, 0.26116853579878807, 0.14956726213651045, 0.13225752168468066, 0.13390053994953632, 0.2013306495334421, 0.14132235598351273, 0.16351825424603053, 0.28884996899536675, 0.08421212621033192, 0.1262260510453156], [0.028561930770852735, 0.06721905126635518, 0.016867830950234617, 0.02671821541818125, 0.045056353722299845, 0.0283051341040326, 0.02482318924739957, 0.07996004580387048, 0.02359065752742546, 0.08522150811872312, 0.01748264135260667, 0.07780005170830659, 0.22571917942592076, 35.6924341065543, 69.67479842049735, 57.03303745814732, 53.705586842128206, 25.015806095940725, 26.74417049544198, 54.851035594940186, 34.61629363468715, 38.15990270887102, 69.35573019300188, 23.404346874782018, 0.11285213261310544, 0.11632869499070303, 0.5151758130107607, 1.5961257410900933, 1.0421660606350218, 0.48377152958086556, 0.0806661904124277, 48.54179334640503, 69.96587235586983, 57.61303833552769, 60.004344258989605, 46.14786100387573, 47.858021123068674, 53.49172476359776, 58.926136698041645, 58.33347620282854, 58.18068878991263, 56.583548069000244, 58.66617679595947, 54.750912053244456, 57.93903391701834, 52.820216110774446, 50.28979682922363, 48.54900557654244, 45.478697368076865, 41.39367423738752, 39.45852797372, 39.377588408333914, 40.79530232293265, 39.43940653119768, 40.33606113706316, 39.55095985957554, 38.875091212136404, 40.142230715070454, 38.23067705971854, 38.1700644493103, 39.706995555332725, 38.28857292447771, 38.830278805324006, 40.29447964259556, 42.51201111929757, 39.51713602883475, 39.38326161248343, 38.6844812801906, 38.745298862457275, 38.25601019178118, 39.21211358479091, 40.15276418413435, 43.02430874960763, 46.965490273066926, 50.72500419616699, 49.555754389081685, 45.53551973615374, 36.29665987832205, 40.420641558510916, 36.21402495247977, 43.94881868362427, 44.500526496342246, 49.41991015842983, 49.48196799414498, 54.20446055276053, 47.78407491956438, 57.77414274215698, 34.05705744879586, 28.932837418147496, 57.56950787135533, 46.99957813535418, 46.45532921382359, 35.438783168792725, 39.6778895514352, 37.13359819139753, 40.365160192762104, 37.615747588021414, 39.553593226841514, 36.35091141292027, 39.01557683944702, 37.67852108819144, 40.129692690713064, 40.315536158425466, 40.707866191864014, 39.53825855255127, 40.44649927956717, 38.84878533227103, 39.51798023496355, 39.40560007095337, 38.58903387614659, 36.77264969689505, 38.10096114022391, 37.903208460126606, 39.6917199407305, 37.74532454354422, 39.25626243863787, 38.11132090432303, 40.120020798274446, 38.82292413711548, 40.11824205943516, 39.774500778743196, 41.02826499938965, 40.388030188424246, 41.76325934273856, 40.751584257398335, 47.88243709291731, 49.88898651940482, 49.32073851994106, 45.167376382010325, 43.74564640862601, 40.831262724740164, 42.37233148302351, 41.78810262680054, 41.95901094164167, 42.896743297576904, 44.69965839385986, 44.69181387765067, 44.208771637507844, 46.506030218941824, 48.96788467679705, 50.93882458550589, 54.46909659249442, 53.46512358529227, 55.96044404166085, 61.36993626185826, 38.43053504398891, 2.3417522396360124, 4.073628085000174, 2.294682536806379, 0.1564239670655557, 0.0665718713509185, 6.325394204684666, 54.7630227633885, 47.39319358553205, 42.41395466668265, 91.21426963806152, 44.99589136668614, 19.34326376233782, 45.87358086449759, 45.20184639522007, 48.56062296458653, 37.45048468453543, 0.8241309374570847, 0.1355981124298913, 0.050131758342364004, 0.08034394734672137, 0.06190793375883784, 0.02696417079174093, 0.03217348429773535, 0.017746421841106245, 0.026550177917150513, 0.11767478633139815, 0.08411977759429387, 0.06440697823251997, 0.024519074941053987, 0.015456418739631772, 0.0472595399644758, 0.06799015881759779, 0.013021415249178452, 0.025570648156904748, 0.03619343448164208, 0.02769473417928176, 0.05209735215508512, 0.0697490233661873, 0.021225150441750884, 0.027487735197480236, 0.017912742648539797, 0.03471376673717584, 0.14315833603697165, 48.179212025233674, 76.76280866350446, 63.28884111131941, 59.668378012520925, 34.4110438483102, 32.16924231392996, 43.65541362762451, 35.38790151051113, 45.87140260423933, 73.43642112186977, 24.81650744165693, 0.29973643911736353, 0.18447110349578516, 0.9362634633268628, 6.450010580675943, 6.944534284727914, 0.21080240128295763, 0.4820326886006764, 49.739450863429475, 72.8734016418457, 60.399585587637766, 62.33735479627337, 48.62242371695382, 50.56442437853132, 56.44238499232701, 61.041522707257954, 59.8762264251709, 60.38826697213309, 56.21481759207589, 60.60670443943569, 56.2988213130406, 59.88203511919294, 54.999824319567, 53.42514712469918, 51.63309553691319, 47.8287935256958, 44.90585313524519, 41.07796893801008, 41.68362603868757, 43.34269952774048, 41.40093510491507, 41.89000143323626, 42.29911136627197, 41.25594009671892, 41.59365381513323, 41.285963262830464, 39.86203418459211, 40.47768974304199, 39.66255835124424, 40.53866713387625, 41.656059060777935, 44.25429276057652, 42.39131048747471, 41.74352298464094, 41.173715114593506, 40.98060383115496, 40.11987836020333, 41.61900084359305, 41.544179167066304, 46.60393033708845, 49.27654797690255, 52.60348095212664, 50.962643010275706, 46.86065237862723, 39.20587757655552, 42.48645911897932, 39.31420694078718, 45.81847817557198, 44.79476533617292, 52.35678516115461, 51.42740453992571, 57.809397901807515, 49.47335917609078, 60.28713594164167, 36.47812598092215, 30.90906490598406, 58.18508005142212, 49.64861706324986, 47.71372093473162, 38.14672197614397, 41.225378445216585, 39.35022292818342, 42.545727252960205, 40.49150276184082, 40.68953684398106, 38.31935344423567, 40.54061957768032, 39.268692765917095, 42.91833829879761, 43.153441020420615, 42.875683307647705, 41.560677664620535, 42.35256385803223, 40.99653952462332, 42.215590545109336, 42.33489806311471, 40.839617933545796, 39.011866501399446, 39.81874690737043, 40.01009682246617, 40.97594853809902, 40.50611482347761, 40.60382734026228, 39.34995542253767, 42.39321429388863, 39.55143928527832, 41.68876770564488, 42.082796573638916, 43.73327166693551, 43.08219419206892, 43.47452769960676, 42.39307880401611, 50.36800227846418, 53.0681208883013, 51.25119822365897, 45.72668899808611, 45.2550105367388, 42.617460455213276, 44.440824099949424, 43.04379844665527, 44.36377899987357, 44.48607076917376, 47.282130105154856, 47.683600493839805, 47.151774951389854, 48.65920400619507, 51.17092568533761, 54.690525259290425, 55.80928945541382, 55.00837755203247, 60.388572692871094, 61.60362502506801, 43.40302378790719, 4.003296681812831, 1.4865280049187797, 3.3472718724182675, 0.7358626510415758, 0.05463452011879001, 5.839219629764557, 57.961924757276265, 52.96535355704171, 37.434281485421316, 72.53810242244175, 41.39469562258039, 26.97043858255659, 51.03027677536011, 51.99237298965454, 52.87045158658709, 49.84296860013689, 3.289253762790135, 0.29501744519386974, 0.08672763872891665, 0.1258903526301895, 0.05544298780815942, 0.05754779665065663, 0.024285134726337025, 0.04730846233932035, 0.029660828411579132, 0.09682050786380257, 0.04367123983268227, 0.07060480530240706, 0.03671221182282482, 0.06667335983365774, 0.08721672677035842, 0.21034615433641843, 0.09488208259322814, 0.08245966024696827, 0.11596464738249779, 0.16562372126749583, 0.15090370470924036, 0.17251923839960778, 0.1591379035796438, 0.17377070124660218, 0.09296891918139798, 0.15729834086128644, 0.30177793385727064, 56.97230325426374, 84.69242640904018, 72.46171392713273, 66.96982301984514, 38.3718957219805, 34.18155527114868, 68.03692735944475, 51.16621133259365, 51.9511284828186, 80.43427848815918, 28.544339316231863, 0.3380529044994286, 0.2505852351231234, 1.4102855303457804, 4.809206511293139, 10.674195272581917, 0.58028173659529, 0.7383846842816898, 55.19624989373343, 74.27178914206368, 63.812318393162315, 64.42987428392682, 50.83616495132446, 51.87694604056222, 58.87485204424177, 63.01267106192452, 62.77804429190499, 62.84256526402065, 58.53597450256348, 62.1617807660784, 59.259059633527485, 61.70028836386544, 58.02812719345093, 55.13712419782366, 54.65628106253487, 49.54870891571045, 46.17829063960484, 43.978734152657644, 43.93378973007202, 45.66468327386038, 41.10932615825108, 43.68712173189436, 44.402862616947715, 42.03963088989258, 44.48998260498047, 42.615469796316965, 42.587975774492534, 43.26362555367606, 41.398273944854736, 43.022001947675435, 43.669410773685996, 48.636803013937815, 45.216201373508994, 44.28310694013323, 43.58262082508632, 43.44284738813128, 42.71654871531895, 43.34634733200073, 44.59376089913504, 49.03596660069057, 51.55063779013497, 56.23185110092163, 54.20423126220703, 49.10259287697928, 40.94073854173933, 43.69321182795933, 40.15659611565726, 47.58375488008772, 47.46738297598702, 54.46953432900565, 53.11275611604963, 58.484995569501606, 52.72430317742484, 61.99965844835554, 38.91209036963326, 32.83359432220459, 61.31335013253348, 51.870626653943745, 49.9054468018668, 39.252315861838206, 44.609064306531636, 41.48484155109951, 45.953505992889404, 42.32340921674456, 43.918604442051475, 40.780335903167725, 42.835487978799, 41.74033028738839, 44.58481509344918, 45.696335792541504, 44.43748549052647, 44.107928957257954, 43.466203757694785, 42.17127840859549, 44.44329418454851, 44.11739935193743, 45.002988951546804, 40.098272936684744, 42.557903970990864, 41.65460688727242, 44.20458882195609, 43.80762086595808, 44.3327066557748, 41.15577139173235, 44.6070944922311, 43.55105168478829, 44.00475515638079, 44.56856673104422, 45.42643649237496, 45.35748604365757, 45.821431159973145, 43.76246452331543, 52.56342806134905, 54.92525625228882, 55.14388132095337, 48.717426436288015, 49.589984689440044, 47.208176953451975, 46.2883813721793, 45.563635621752056, 47.92985160010201, 46.73984752382551, 49.393270765032085, 50.11785323279244, 48.808440889631, 49.56026029586792, 52.98970351900373, 57.08075768607003, 61.27616337367466, 56.729206630161826, 62.99409852709089, 63.01910509381975, 44.68951749801636, 3.9331993460655212, 7.790299415588379, 7.7243445089885165, 0.696533621421882, 0.09766242732959134, 7.99460858958108, 64.47924123491559, 61.18392603737967, 55.701693126133506, 95.28511496952602, 53.85564013889858, 30.13302755355835, 56.89016859872, 58.738479750497, 59.140710966927664, 59.18884113856724, 4.3339657953807285, 0.4342238168631281, 0.21721408223467215, 0.22359490341373853, 0.12094166103218283, 0.09557176594223295, 0.12293023004063539, 0.07967710348644427, 0.12242248228618077, 0.18979972042143345, 0.1969364703233753, 0.14435666959200585, 0.10303183099521057, 0.12729646717863424], [0.04517235606908798, 0.01562048341812832, 0.06018670754773276, 0.04234245792031288, 0.056370477325149944, 0.014126879412547817, 0.05165876068973115, 0.01565091062470206, 0.08396881033799478, 0.0989452384944473, 0.06514770098562751, 0.05165618225666029, 1.3476367720535822, 56.16098642349243, 62.73270034790039, 50.44098615646362, 45.56828049251011, 17.850721223013743, 25.164103235517228, 64.89902360098702, 31.585597106388636, 48.73340381894793, 62.901618003845215, 6.123430916241237, 0.38421483603971346, 0.10750839114189148, 0.3657422629850251, 2.492166191339493, 1.767024502158165, 1.0790963875395911, 4.138439578669412, 69.35197816576276, 60.89717388153076, 66.41279288700649, 58.69442122323172, 60.77849170139858, 43.93387310845511, 46.312283175332205, 51.6350861958095, 57.956890787397114, 57.573159149714876, 59.9181865964617, 54.769536699567524, 59.49181038992745, 54.537654467991416, 55.04874311174665, 51.380716119493755, 51.35898215430123, 49.60621220724923, 47.53926903860909, 40.5609951700483, 39.60170602798462, 39.83520024163382, 41.86740589141846, 41.21554674421038, 39.67275135857718, 40.72161667687552, 39.971582957676475, 39.60959570748465, 39.826244013650076, 40.62416124343872, 40.3143584387643, 39.478135790143696, 40.86311674118042, 40.0193691934858, 39.88787106105259, 38.96099179131644, 39.20229230608259, 38.447936807359966, 37.22232321330479, 39.047118186950684, 39.000829287937705, 41.414077622549875, 43.505794593266074, 47.88701595578875, 43.119877747126985, 38.4007168497358, 37.37635087966919, 38.82900728498186, 38.80800288064139, 46.372986112322124, 46.71607773644583, 51.39232655933925, 49.59847886221749, 54.28374992098127, 49.07744039808001, 54.6613358770098, 30.50148705073765, 30.503512450626918, 57.19288771493094, 45.97516005379813, 48.10183341162545, 36.691908155168804, 39.70347629274641, 38.40484060559954, 38.63801867621285, 35.52899510519845, 38.15075193132673, 36.472213063921245, 37.6369743347168, 38.92188038144793, 40.1288936478751, 38.845224380493164, 42.225245067051475, 39.682162693568635, 40.873351437704905, 41.30477203641619, 38.90659087044852, 39.117923804691856, 37.61818987982613, 35.09176581246512, 36.74625696454729, 36.343612330300466, 39.45675270898001, 38.37319850921631, 38.411344119480674, 39.65428652082171, 40.369054658072336, 39.459431239536826, 38.69100563866751, 38.52634375435965, 40.53383813585554, 38.45412417820522, 39.697514738355366, 39.247761317661826, 40.6501544543675, 42.05553184236799, 41.60274205889021, 39.916719981602256, 40.76791252408709, 39.39699820109776, 40.610077244894846, 41.23665189743042, 44.68829461506435, 47.433764117104666, 47.45506729398455, 50.58107921055385, 52.4412578855242, 51.04782445090157, 55.65321207046509, 54.61932359422956, 56.44770731244768, 56.08247525351388, 58.906438555036274, 54.9250373840332, 53.89946242741176, 18.806385142462595, 2.4819345346518924, 1.824356151478631, 0.26747760868498255, 0.07229845585035426, 0.2672947027853557, 33.50321306501116, 58.3386595589774, 36.0416853087289, 68.79498972211564, 45.456918239593506, 14.899334907531738, 26.84519382885524, 43.65717152186802, 46.69844320842198, 45.38136352811541, 11.454030684062413, 0.2592185618621962, 0.1398528798350266, 0.049083201214671135, 0.020268755332965935, 0.04606780516249793, 0.024889276861878376, 0.04462273931130767, 0.08856031431683473, 0.03483421348833612, 0.037321424311293025, 0.06815604027360678, 0.04388407930465681, 0.031720015952097516, 0.044210549643529315, 0.03823169260951025, 0.05359757611794131, 0.021381457768646733, 0.05265254307804363, 0.06175666116178036, 0.07245091588369437, 0.028470542281866074, 0.17298347848866666, 0.01570554626440363, 0.019308575695114474, 0.08397704096777098, 2.7807832871164595, 67.81293133326939, 67.16137095860073, 57.98113305228097, 52.080219064440044, 27.787201063973562, 25.00994529042925, 53.65641791479928, 36.36575623920986, 53.96190241404942, 68.6475350516183, 7.062045693397522, 0.5687168943030494, 0.07417668827942439, 1.242645474416869, 2.607696060623441, 0.7557755910924503, 0.5854884886315891, 5.013286394732339, 71.97222028459821, 62.91316590990339, 69.51045962742397, 62.8419051851545, 61.95150048392159, 45.29108558382307, 50.400769983019146, 54.435918944222585, 60.13703400748116, 58.96655436924526, 61.1820569719587, 55.37129586083548, 61.5445305960519, 56.716335092272075, 57.16115876606533, 53.92656735011509, 52.33014576775687, 51.30376829419817, 49.304174014500205, 42.33995287758963, 41.90732329232352, 41.03925704956055, 42.765269483838765, 42.584050042288645, 41.21628325326102, 42.53775419507708, 41.56865072250366, 42.43865898677281, 42.241316250392366, 41.185572215488975, 41.52444280896868, 40.56797463553292, 42.71101794924055, 40.49055085863386, 41.39754785810198, 40.761120659964426, 41.69986745289394, 39.11721508843558, 38.929492133004324, 41.173944405147004, 43.04597323281424, 44.43575191497803, 45.3063507761274, 49.0281012398856, 44.589501653398784, 39.649638175964355, 38.22237048830305, 41.151366233825684, 40.34240484237671, 48.946598870413645, 48.37632547106062, 52.440041950770784, 51.30857297352382, 55.532591342926025, 49.09592955453055, 56.215328284672324, 30.935169288090297, 32.53881352288382, 59.73726940155029, 48.93744114467076, 49.45961911337716, 37.68937417439052, 41.17654650551932, 39.434845038822715, 42.30499996457781, 36.92726796013968, 40.510843072618755, 37.30850172042847, 41.104639598301475, 40.054884910583496, 42.66046980449131, 41.80317326954433, 44.99026332582746, 42.67655488422939, 44.59007140568325, 42.59291246959141, 41.2651812008449, 39.944547516959055, 39.524904114859446, 37.693192209516255, 38.91888918195452, 38.62974337169102, 41.05640867778233, 38.85078293936593, 41.0571278163365, 39.841154847826274, 42.23916578292847, 40.82260179519653, 41.235668727329795, 40.81846761703491, 41.933663913181846, 40.48013898304531, 41.90911940165928, 42.08793824059622, 44.02636405399868, 42.04472739355904, 43.45760883603777, 41.83726808003017, 43.397131715502056, 42.415340832301546, 42.23512193134853, 42.34593875067574, 47.59851632799421, 48.82938276018415, 50.617293221609934, 52.39653580529349, 54.49784129006522, 52.83468573434012, 56.687677247183665, 56.26504611968994, 58.7641533442906, 59.46730409349714, 60.803484371730256, 55.57496493203299, 54.571037088121685, 22.396208422524587, 1.9415898493358066, 2.2887070860181535, 0.5523810823048864, 0.06076755387974637, 0.33386886758463724, 34.68247175216675, 65.31488718305314, 37.51730898448399, 65.18025193895612, 39.26816470282418, 21.966047184807913, 32.64595821925572, 49.003136362348286, 50.668247835976736, 56.35281923839024, 22.05868751662118, 0.27833674741642817, 0.07837463516209807, 0.06844536760555846, 0.014081101199345929, 0.03479972355333822, 0.06808205960052353, 0.07653350502784763, 0.03237936200041856, 0.049589106746550114, 0.044370422671948156, 0.03890774079731532, 0.021232721196221452, 0.03616735838087542, 0.15871718472668103, 0.1763048531221492, 0.14350406319967338, 0.12743008429450647, 0.15430194378963538, 0.18268874127949986, 0.21840548116181577, 0.09948161364133869, 0.20813319379729883, 0.2874607635395867, 0.2922236993908882, 0.31142124640090124, 3.787895577294486, 73.22070040021623, 75.87698977334159, 64.77509553091866, 60.358459200177876, 27.548304625919886, 35.21996702466692, 74.95022514888218, 44.07748889923096, 60.253951345171245, 74.77917439596993, 7.505295600209918, 0.5201135937656675, 0.21373881585896015, 2.181238212755748, 5.310181617736816, 4.71512051991054, 5.7476562687328885, 6.112282531602042, 75.48172760009766, 62.61182253701346, 72.84286430903843, 63.36063684735979, 67.49685777936662, 45.512090410505024, 53.60737405504499, 56.61823695046561, 63.00473621913365, 60.90899971553257, 64.81838975633893, 55.65271527426583, 63.662494386945454, 58.64428997039795, 59.344209807259695, 54.90680183683123, 56.16177156993321, 55.035367829459055, 52.65908391135079, 44.25689833504813, 44.16692263739449, 43.87030403954642, 45.60431732450213, 44.61542190824236, 43.86066688810076, 44.10408660343715, 45.12752846309117, 45.05601412909371, 43.67990950175694, 44.204898016793386, 42.88437550408499, 42.46313401630947, 46.95879915782383, 42.55336332321167, 43.502178055899485, 43.05174371174404, 43.43703522000994, 41.83589928490775, 41.43189975193569, 42.986868381500244, 46.85724081311907, 46.435766560690745, 47.7819835117885, 52.60608652659825, 46.90274109159197, 41.262811865125386, 41.153777258736746, 42.90071766717093, 43.39005844933646, 51.04471860613142, 51.59576286588396, 55.206706932612825, 54.014361313411165, 58.19719076156616, 52.879067352839876, 57.47027369907924, 35.28323384693691, 35.42457757677351, 61.67658805847168, 50.462212903159006, 51.71029002325875, 41.60149833134243, 44.72589479173933, 41.56956788471767, 44.5862637928554, 40.06415728160313, 43.85960381371634, 41.33901623317173, 43.134114606039866, 43.205236366816926, 44.68603297642299, 44.284604276929585, 47.475036416734966, 43.91942432948521, 47.21414545604161, 44.9661009652274, 44.470315728868755, 43.38363831383841, 41.609203883579795, 39.569716521671836, 40.067145006997244, 40.15475136893136, 43.173629011426655, 41.54944590159825, 41.22681324822562, 42.6481819152832, 44.145112242017476, 43.66805240086147, 42.2626576423645, 42.274219444819856, 45.07623338699341, 42.973885672433035, 43.96297216415405, 43.01901422228132, 46.724717821393696, 45.692083495003835, 45.378070081983296, 44.46823474339077, 45.54368386949812, 44.63981703349522, 44.95776660101754, 45.898924418858115, 50.40228121621268, 51.531835964747835, 53.988156182425364, 54.084558963775635, 57.52017913545881, 55.36725895745413, 60.12360313960484, 57.656322138650076, 62.221347672598704, 60.92255565098354, 63.97517721993582, 56.5291679927281, 56.12144422531128, 26.12463436807905, 3.60371880871909, 7.525028484208243, 0.4438445477613381, 0.19606897687273367, 0.4729741918189185, 39.67428343636649, 70.65323679787772, 46.3394193649292, 74.81965460096086, 53.05269936152867, 24.20245691708156, 36.10629660742623, 58.278880732400076, 57.170674324035645, 64.58189392089844, 24.6697666985648, 0.5488917295421872, 0.24381101291094506, 0.25000180357268875, 0.09773817219372306, 0.11293689520763499, 0.14532461336680821, 0.2772586095545973, 0.18938508124223777, 0.18153728092355387, 0.07456006056496076, 0.14534758856253965, 0.1719291029231889, 0.11281161728714194], [0.04630655449415956, 0.02962715271860361, 0.008790768067618566, 0.09055794176778623, 0.08002471019114767, 0.035916480235755444, 0.08502585933144603, 0.07355348779154675, 0.12438571479703699, 0.010595415918422597, 0.09238518907555512, 0.26222884176032885, 11.475673454148428, 70.76345607212612, 57.53257819584438, 59.966365405491416, 37.15487357548305, 18.939227751323156, 37.28826856613159, 59.31311661856515, 33.58633783885411, 62.37042127336775, 45.57028157370431, 0.6605781593493053, 0.071513716530587, 0.17625124885567597, 0.7153732276388577, 5.636921090739114, 2.328522218125207, 0.36250554238046917, 38.23292132786342, 63.959606306893484, 62.063144138881135, 64.23654760633195, 63.55979306357247, 59.761254583086284, 54.42237343106951, 41.327013220105854, 43.62750618798392, 51.95096867425101, 56.31475353240967, 56.42961072921753, 57.06382840020316, 53.05395698547363, 55.77638973508562, 55.80928945541382, 53.82673563276018, 54.960959570748464, 50.86497565678188, 46.9023346219744, 44.243005411965505, 40.97576788493565, 38.398826939719065, 36.848287786756245, 40.302056653159006, 40.81028263909476, 40.421190466199604, 39.812910420554026, 39.35967942646572, 40.27525397709438, 40.69195481709072, 38.383905683244976, 39.79153081348964, 37.534481457301546, 40.87979589189802, 37.70402445111956, 40.41357871464321, 37.97985403878348, 39.10125160217285, 38.227237701416016, 38.97216796875, 38.195123127528596, 39.75495202200753, 41.175872530256, 39.31941114153181, 37.22459180014474, 38.19117307662964, 37.673990862710134, 38.75049958910261, 43.45110879625593, 47.51438406535557, 46.012496198926655, 51.16715281350272, 47.38959094456264, 53.49892657143729, 45.56097446169172, 49.76704910823277, 26.2894960130964, 34.447799818856375, 57.09527594702584, 44.43511962890625, 45.74562978744507, 36.9094215120588, 41.48190941129412, 36.760306222098215, 39.01200893947056, 35.667045388902935, 36.716820921216694, 36.27429710115705, 36.838261536189485, 35.18859590802874, 39.02493953704834, 38.84513405391148, 41.38248416355678, 40.66802174704415, 40.873504298073904, 38.39483172552926, 39.51224102292742, 37.61512572424752, 37.87498140335083, 36.90417562212263, 37.415476185934885, 36.992376055036274, 39.35535764694214, 37.99945838110787, 38.822086879185264, 37.63099193572998, 39.19084167480469, 38.72667421613421, 38.36981473650251, 40.316460268838064, 39.746655872889924, 40.81111989702497, 40.58458777836391, 40.15094723020281, 42.919846057891846, 38.61165721075875, 39.29619026184082, 38.950006689344136, 39.68472310474941, 40.423309666769846, 43.89569970539638, 46.773852007729666, 51.320089612688335, 53.074600083487375, 55.03773716517857, 51.95831292016165, 52.96352965491158, 55.257025786808555, 55.63437897818429, 56.94301659720284, 57.767927578517366, 56.93665899549212, 55.96249376024519, 55.58169426236834, 51.49572270257132, 29.664552211761475, 0.5019192472100258, 2.1999855382101874, 1.2494764221566064, 0.042067518923431635, 0.06572210123496396, 11.349751251084463, 60.82580893380301, 42.1523688861302, 48.22954477582659, 36.095436573028564, 16.44805884361267, 20.691570384161814, 35.522821630750386, 46.94435385295323, 49.77206570761544, 33.598427704402376, 0.4308403969875404, 0.0645610803206052, 0.045033137646636794, 0.08229413841451917, 0.03393560242173927, 0.029937738552689552, 0.025346278678625822, 0.015083512856758066, 0.013569312768855264, 0.04905989353678056, 0.01821187311517341, 0.018832990500543798, 0.06403016059526376, 0.03530883516318031, 0.04838872740843466, 0.05756795592606068, 0.034012049569615295, 0.03749228282166379, 0.04182819283700415, 0.15196810902229377, 0.01177470469182091, 0.07023824032928262, 0.08439118481640305, 0.17715505750051566, 0.2053546200373343, 15.575533594403948, 81.75121225629533, 62.50789138248989, 64.04219954354423, 42.40143748692104, 24.474155800683157, 28.485818113599503, 56.62533106122698, 41.325501986912315, 65.6591773714338, 50.085047313145225, 0.473421753517219, 0.02298461040481925, 0.2818909409855093, 1.0631375695977892, 4.0331131390162875, 0.9283849660839353, 0.2997665932135922, 38.90144920349121, 67.35840102604458, 61.725941113063264, 68.54550075531006, 63.642685072762625, 64.25808007376534, 55.44909484045846, 44.99171897343227, 46.262332575661794, 54.4787928036281, 56.99123362132481, 58.86207430703299, 58.11920765468052, 54.567496980939595, 57.42862967082432, 57.07123865400042, 55.766676153455464, 57.031171866825645, 52.26146977288382, 49.31282452174595, 46.36305366243635, 42.03218242100307, 40.798328263419016, 39.16920845849173, 42.103985105242046, 43.96711676461356, 42.04480034964425, 40.99853713171822, 41.87442357199532, 41.878637654440745, 42.88932262148176, 41.335417066301616, 41.7212679045541, 39.34633888517107, 40.583090441567556, 40.135539599827354, 41.10124887738909, 40.39586080823626, 40.905559812273296, 39.31471415928432, 41.47296013150896, 40.624223777226035, 40.14432212284633, 43.82370941979544, 41.59346621377127, 39.113939012799946, 38.950503485543386, 39.70135709217617, 41.30123540333339, 44.5984822000776, 48.49535158702305, 49.59522363117763, 51.12279551369803, 49.7315160206386, 54.197220529828755, 47.15350505283901, 51.97869198662894, 27.853342703410558, 34.609724112919395, 58.76776640755789, 46.75077704020909, 47.396282059805735, 38.00727163042341, 42.77124146052769, 37.765394415174214, 40.80007920946394, 38.408936568668906, 39.011668477739605, 38.09821660178048, 38.989726066589355, 37.42876808983939, 41.32412624359131, 42.41139425550188, 44.10169989722115, 42.157072816576274, 42.931293215070454, 40.01363345554897, 42.088223116738455, 40.01549904687064, 39.31043406895229, 38.670171465192524, 39.87771626881191, 39.41269418171474, 41.62831490380423, 39.99886505944388, 41.056241921016145, 39.93365274156843, 41.78818253108433, 40.11100203650338, 40.78532818385533, 42.432190213884624, 42.47814907346453, 41.64840909412929, 42.65469932556152, 41.547618525368826, 42.87246281760079, 40.38629313877651, 41.64764479228428, 39.88566153390067, 41.66207272665841, 41.74211597442627, 45.9642652784075, 48.126596791403635, 53.9747531073434, 56.42816202981131, 57.30438893181937, 54.892829009464805, 56.360903467450825, 56.60910701751709, 59.013294901166645, 59.58465916769845, 60.35989052908761, 59.30034582955496, 56.96069628851754, 56.43740313393729, 53.43652132579258, 32.89810487202236, 1.0177840718201228, 0.6484541499188968, 2.203655706984656, 0.30424321442842484, 0.020496271517393843, 12.01211520603725, 65.9745283126831, 46.13213375636509, 52.135898453848704, 35.29709202902657, 20.914927176066808, 26.422197920935496, 40.337092944553916, 53.647892475128174, 56.01955931527274, 41.884606157030376, 0.3661300593188831, 0.05146390239575079, 0.01603732105078442, 0.01600110254782651, 0.022893873309450488, 0.03678720012041075, 0.02310781879350543, 0.037093019245990684, 0.03217568275119577, 0.056663495887603076, 0.032704634724983146, 0.0440621540349509, 0.06447556455220495, 0.12541041124079907, 0.1193632393011025, 0.16854774579405785, 0.15402769350579806, 0.18269041047564574, 0.10334395710378885, 0.26548198291233605, 0.11487962917557784, 0.2209733562277896, 0.1901988075780017, 0.3046284866120134, 0.31890733327184406, 18.383707114628383, 93.46795954023088, 69.60879748208183, 76.30160808563232, 49.761094502040315, 29.57164090020316, 51.36213663646153, 73.54002571105957, 48.31282588413784, 75.06298051561627, 54.54099655151367, 1.2095570670706886, 0.2095389012247324, 0.9452008008956909, 1.9617027129445757, 15.244542258126394, 12.450509190559387, 0.45615661995751516, 47.04607548032488, 66.31592805044991, 66.26036330631801, 69.73580360412598, 66.22043895721436, 64.25087479182652, 58.27364526476179, 44.82161317552839, 48.795701367514475, 56.38093164988926, 61.66442176273891, 61.098907879420686, 60.627375330243794, 53.663380009787424, 59.13899476187569, 59.24945027487618, 57.623443262917654, 60.21620873042515, 54.82282590866089, 51.859050955091206, 48.96767970493862, 45.278450284685405, 43.675782271793906, 40.3024457522801, 44.362476212637766, 46.05364343098232, 45.975354603358674, 41.88993542534964, 44.269554478781565, 45.49504995346069, 45.408072403499055, 42.45276035581316, 43.262704917362754, 40.54888793400356, 43.85749156134469, 41.41632189069475, 43.74470840181623, 42.665872028895784, 42.25693232672555, 41.90255682809012, 42.11807952608381, 41.01587636130196, 42.99079758780343, 44.959100655147004, 43.98928499221802, 40.98315034593855, 41.255776814052034, 43.55863911764962, 43.98392445700509, 47.909858158656526, 51.396186283656526, 50.91506174632481, 56.358871119362966, 52.349079608917236, 58.339472498212544, 48.542123385838096, 53.974582876477925, 30.650932380131312, 37.73940815244402, 60.02240262712751, 49.171765668051584, 50.007244859422954, 40.56216246741158, 45.578334535871235, 40.52303716114589, 43.53807244982038, 40.34462826592581, 42.02673155920846, 40.57700034550258, 42.30523272923061, 39.401795932224815, 44.671198572431294, 44.118062904902864, 46.89492784227644, 46.40327330998012, 46.83395045144217, 42.861370018550325, 45.14581959588187, 43.06220769882202, 42.24048246656145, 41.44796746117728, 41.47146279471261, 41.79200404030936, 42.68324947357178, 41.33328744343349, 43.01503985268729, 42.23717859813145, 43.41613851274763, 42.17046199526106, 40.837401458195274, 45.11587633405413, 45.22742966243199, 44.22935567583357, 43.79005234582083, 43.35370200020926, 45.20684562410627, 42.1798038482666, 44.44497217450823, 42.34289196559361, 43.51229463304792, 44.23213842936924, 48.98642594473702, 51.98236410958426, 56.63630921500069, 57.761024543217246, 57.545932633536204, 57.27053383418492, 58.59042058672224, 59.37619931357247, 61.65474987030029, 61.74388831002371, 62.13767051696777, 61.06843308040074, 57.73379455293928, 57.25453560692923, 53.67243003845215, 35.865520681653706, 1.569528688277517, 7.442176427159991, 5.88682564667293, 0.4738714322447777, 0.12012185502265181, 14.863860879625593, 72.12092563084194, 51.65472180502755, 58.217962401253835, 43.87476478304182, 26.548698561532156, 30.33103036880493, 50.33892406736101, 59.573416982378276, 64.88987282344273, 47.964655126844136, 0.6108031102589199, 0.1829985739397151, 0.1077991569680827, 0.10941143759659358, 0.10885517458830561, 0.13216900000614779, 0.09554685692169837, 0.10190410579421691, 0.15618467490587915, 0.09546788901622806, 0.1657563748636416, 0.17528132375861916, 0.12084062716790608], [0.010800521787522095, 0.028019134986347387, 0.07428941330207245, 0.012232139074642743, 0.035647095048001835, 0.0447802612158869, 0.08327899806733642, 0.02031235968960183, 0.05209636488663299, 0.04077181898589645, 0.06961746221142155, 0.15316762322826044, 23.737337555204117, 67.69845281328473, 55.40708603177752, 52.51471076692854, 39.3670723097665, 21.909841469355992, 39.021736417497905, 51.63666691098894, 35.52446140561785, 68.12585735321045, 22.095162085124425, 0.044255258315908055, 0.032410812098532915, 0.2280057067317622, 0.554627847458635, 1.2286865434476306, 0.126456386542746, 26.806146689823695, 72.46003246307373, 64.33292606898716, 65.75784873962402, 60.61102621895926, 63.71924727303641, 59.70704473767962, 57.72085700716291, 47.6020564351763, 41.81308487483433, 45.43169627870832, 53.758622441973, 52.315120288303916, 56.58843265260969, 57.39844669614519, 51.701326847076416, 54.812361921582905, 53.961951051439556, 51.18924808502197, 52.28598996571132, 48.83752604893276, 45.78615515572684, 42.11168718338013, 38.74345758983067, 38.62962177821568, 37.56104094641549, 41.43767717906407, 41.13865450450352, 38.602242401668, 39.81196199144636, 38.54476342882429, 38.474392073495046, 39.799573353358674, 39.15394674028669, 39.371998582567485, 39.45780536106655, 40.40861075265067, 41.100276129586355, 38.47029958452497, 40.11608811787197, 36.981689725603374, 39.33135162081037, 37.725365843091694, 38.167528356824604, 36.807501861027305, 38.52897364752633, 38.103789057050435, 37.542371136801584, 37.28285244532994, 41.92068120411464, 46.25970615659441, 48.877318382263184, 48.576329367501394, 51.03761059897286, 46.51124136788504, 52.49291774204799, 44.87999194008963, 48.812286717551096, 29.18689135142735, 37.43592126028878, 53.14188296454293, 44.720145157405305, 44.71316221782139, 37.953902517046245, 40.73372391292027, 38.5127009664263, 40.69045400619507, 36.9627628326416, 37.805089473724365, 35.22936793736049, 35.76766572679792, 34.75080381120954, 38.575398036411826, 38.71183633804321, 40.025959559849326, 38.29264804295131, 40.699834074292866, 39.66483736038208, 37.3298465864999, 37.40444244657244, 37.501244749341694, 37.49882330213274, 37.308842182159424, 36.367330006190706, 37.176020417894634, 37.7614096232823, 39.1205050604684, 38.894841466631206, 39.85001727512905, 39.479907580784385, 38.09733765465872, 37.19559349332537, 39.49620805467878, 41.400587694985525, 38.79942880358015, 40.80515486853463, 39.0806119782584, 39.9732539994376, 39.89996787479946, 40.01166016714913, 41.113112926483154, 45.345086983272004, 48.052643639700754, 50.64737892150879, 51.128451347351074, 55.23595190048218, 56.208675384521484, 61.09538514273507, 58.60861791883196, 54.55209629876273, 54.32490062713623, 55.211449078151155, 53.12105573926653, 55.96343871525356, 55.71125037329537, 55.43502126421247, 49.795241424015586, 58.64727074759347, 11.367285898753575, 0.3871175002838884, 1.3716842702456882, 0.21453819796442986, 0.05517597070762089, 1.8531903071062905, 48.89948660986764, 53.027546882629395, 40.707831450871055, 30.27524675641741, 23.426869460514613, 20.107350213187082, 38.06705045700073, 46.140016487666536, 49.61033943721226, 35.371938024248394, 1.4113864941256387, 0.13057517553014414, 0.08539417492491858, 0.061025302191930156, 0.057709403336048126, 0.029194033638175045, 0.020711073651909828, 0.024779232052553977, 0.05723082580204521, 0.011560929689689406, 0.01446655489105199, 0.011285959310563547, 0.05374196158455951, 0.04034618414672358, 0.021790938385363137, 0.002996175063474636, 0.05284552861537252, 0.012983524157399578, 0.06618083840502159, 0.026521245183955346, 0.019759937189519405, 0.14421208735023225, 0.03841620324445622, 0.08245474765343325, 0.13618520806942666, 31.727656500680105, 77.26571232931954, 60.83491802215576, 59.41434492383684, 44.77043274470738, 28.621610232761928, 42.33845206669399, 51.35229451315743, 39.954615456717356, 75.69795554024833, 22.754593031747, 0.08567782291876418, 0.06786728969642095, 0.6458476526396615, 1.7679899760654993, 1.0682794536863054, 0.4255488280739103, 29.947976180485316, 76.82197952270508, 65.76917430332729, 67.93862424577985, 62.40120874132429, 65.64415536608014, 60.57365880693708, 59.212339946201865, 50.854042666299, 44.65160117830549, 47.38850702558245, 55.782076835632324, 55.19620473044259, 59.380541937691824, 58.187887123652864, 54.11797979899815, 54.5141487121582, 55.697996684483115, 51.43918521063668, 53.99109527042934, 49.64515686035156, 47.14565706253052, 43.33439643042428, 40.719702448163716, 41.12434468950544, 39.45490796225411, 42.05692148208618, 41.944159167153494, 39.289290700639995, 41.19015802655901, 40.29157876968384, 40.61627156393868, 40.95585782187325, 40.9281518799918, 40.40894774028233, 40.39437736783709, 41.41746834346226, 40.91288668768746, 39.28127942766462, 41.96487522125244, 39.46556649889265, 41.3152950831822, 38.44445923396519, 39.708565848214285, 39.23024490901402, 41.28568533488682, 40.00271783556257, 39.64644547871181, 39.456936836242676, 43.45469059262957, 47.48784194673811, 49.807720388684956, 50.655734130314414, 54.457913466862266, 48.985210009983604, 53.97845997129168, 46.58993666512625, 52.086430753980366, 30.052612577165874, 39.85027435847691, 56.00034754616873, 46.79583610807146, 46.13584756851196, 39.888961928231375, 42.98253270557949, 40.517429964882986, 43.467833110264365, 39.781876291547505, 39.68563331876482, 37.31701673780169, 37.72353151866368, 36.23716940198626, 40.5788311958313, 42.869158949170796, 41.47927604402815, 41.09391505377633, 43.03068024771554, 42.27993433816092, 41.84725611550467, 39.4679080418178, 38.24517100197928, 38.558145659310476, 39.743313789367676, 38.9331989969526, 40.28327914646694, 39.9855557850429, 40.488532406943186, 39.82286718913487, 41.10589722224644, 40.736739431108745, 40.73343903677804, 39.69274132592337, 41.70570741380964, 43.446276324135916, 40.20839146205357, 42.51153516769409, 41.80572673252651, 40.82776778084891, 41.93863187517439, 42.22723920004708, 43.09378031321934, 47.75122731072562, 51.19415003912789, 54.19514996664864, 54.086855343409944, 57.81945889336722, 58.19244514192854, 60.129001889910015, 59.35041454860142, 56.706791741507395, 55.50164754050118, 56.904877935137065, 54.821672507694785, 56.761508805411204, 56.37964275905064, 58.09853328977312, 52.722475801195415, 59.78446156638009, 14.426272017615181, 0.34540388147745815, 1.3624513085399355, 0.3675737918487617, 0.02162382029928267, 1.1622310408524104, 51.72617360523769, 58.32483264378139, 46.17750896726336, 34.41663367407662, 24.108690977096558, 27.569550480161393, 43.18679584775652, 50.32204689298357, 53.295650073460166, 45.603174345833914, 3.0056371986865997, 0.24338291159697942, 0.12963231040963105, 0.07161369188023464, 0.0157496663076537, 0.015916010863812904, 0.0621628322239433, 0.018194770640028373, 0.04569764734644975, 0.057637573618974, 0.043751256074756384, 0.012660823080555668, 0.09549928483154092, 0.09643591421523265, 0.06812188282076802, 0.18571542815438338, 0.11919745962534632, 0.07827841211110353, 0.1239412607891219, 0.14803850916879518, 0.12094896206898348, 0.2839910068682262, 0.18535347043403558, 0.14441992262644426, 0.25148527111325947, 37.648317268916536, 83.79849202292306, 69.24868624550956, 67.81199332645961, 53.39856331689017, 32.51282031195504, 51.2456431388855, 63.29121739523751, 46.19160338810512, 81.64032595498222, 28.300688573292323, 0.1843417068677289, 0.12595025370163576, 1.4040270490305764, 4.30640880550657, 9.880261966160365, 0.7519600529755864, 35.54257188524519, 76.91696834564209, 68.89428642817906, 69.03417451041085, 64.03210381099156, 66.87386144910539, 63.35605798448835, 61.15919739859444, 51.51420838492257, 46.85829693930489, 51.22749791826521, 58.3043007169451, 56.21523448399135, 61.85048757280622, 61.15286064147949, 55.545042514801025, 58.51392092023577, 57.63868066242763, 54.98808533804757, 56.99416923522949, 53.43883160182408, 49.76252930504935, 45.966839585985454, 43.209464345659526, 43.91043683460781, 41.6414852142334, 45.791856152670725, 44.268870081220356, 41.10134962626866, 41.991434710366384, 42.621549470084055, 41.022001198359895, 43.4141652243478, 41.857000964028494, 41.76713643755232, 42.56814908981323, 44.33395733152117, 44.12143972941807, 41.90807717187064, 45.14402001244681, 41.8808193887983, 43.20067140034267, 42.99633877617972, 42.098607199532644, 41.154326166425435, 43.59933819089617, 42.18712377548218, 41.499755859375, 42.16194002968924, 45.71836853027344, 49.902146407536094, 52.90165247235979, 52.98616688592093, 55.38308000564575, 51.44675179890224, 58.975725991385325, 49.21610907145909, 53.06889908654349, 31.651108196803502, 42.964623723711284, 56.719896044049946, 48.66771902356829, 49.23870461327689, 42.99901730673653, 45.987354142325266, 41.96831805365426, 45.217834200177876, 42.816196305411204, 42.36600514820644, 39.246260506766184, 40.97026491165161, 38.67094966343471, 44.273000785282676, 45.308539458683555, 44.465806347983225, 44.37824167524065, 46.21522031511579, 44.389143398829866, 44.75987843104771, 41.97633974892752, 40.188245160239084, 41.091615200042725, 41.92779268537249, 40.6603787285941, 40.944507939474924, 43.13858229773385, 42.45932987758091, 42.40686403002058, 44.30090127672468, 43.19113152367728, 41.640873772757395, 40.7314692224775, 44.748698779514854, 45.24195834568569, 43.34937327248709, 45.07998888833182, 43.438428333827424, 43.33915247235979, 44.81636381149292, 44.63228866032192, 45.89687122617449, 50.465787751334055, 53.519145829336985, 56.692478452410015, 55.37099361419678, 60.20151329040527, 60.8645520891462, 61.57415076664516, 60.91508633749825, 59.15145983014788, 56.78338173457554, 57.214680739811485, 55.763459137507844, 59.07003389086042, 58.275559493473594, 62.55185958317348, 54.36093398502895, 62.34498391832624, 15.139171089444842, 2.6395466029644012, 5.318220683506556, 0.4379060092781271, 0.09324914735874959, 2.4621690809726715, 58.76584870474679, 62.785277366638184, 51.846717902592246, 40.31270476749965, 33.19051286152431, 29.34408392224993, 51.437253611428396, 60.37715680258614, 62.25701972416469, 54.76504121507917, 4.132782007966723, 0.49476602247783114, 0.3243341477853911, 0.11443723791411944, 0.13866635278931685, 0.11468018059219633, 0.21723214483686856, 0.12795050708310945, 0.11852001026272774, 0.14757810958794185, 0.13130613416433334, 0.07051926239260606, 0.1916449692632471], [0.034827906505337784, 0.025502748853926147, 0.05271317696731005, 0.01482287228905729, 0.00962414562569133, 0.07691018695810012, 0.044849838196699104, 0.03054940394525017, 0.07584559944059167, 0.06822240099843059, 0.04672772457290973, 0.5160037342991147, 36.73613691329956, 69.58413832528251, 57.15995325360979, 48.03917108263288, 20.9734240600041, 21.6021682875497, 28.262671504701885, 32.592342444828574, 47.915510518210276, 63.14186586652483, 8.620532717023577, 0.300966948802982, 0.4392249456473759, 0.39275599058185307, 1.9438760238034385, 2.702232599258423, 17.85107558114188, 64.76742471967424, 62.605645588466096, 63.2155237197876, 58.85220091683524, 59.77916703905378, 59.31427001953125, 59.16514083317348, 59.09014197758266, 51.158603055136545, 42.39559405190604, 41.64939226422991, 45.11469166619437, 53.95409263883318, 55.1896664755685, 56.55316012246268, 55.4400760786874, 49.93992376327515, 50.200453417641775, 52.991284234183176, 50.5634377343314, 47.80067764009748, 45.09703629357474, 40.912403787885395, 40.274434089660645, 39.962710108075825, 40.82225438526699, 37.32081740243094, 40.9946357182094, 38.175880091530935, 38.428068433489116, 40.00822080884661, 38.618059975760325, 39.13898032052176, 39.06165729250227, 39.211119992392405, 40.373803751809255, 38.86301176888602, 41.3664824622018, 38.41664212090628, 38.96254818780081, 37.93540293829781, 39.29156276157924, 39.47415794645037, 38.96972220284598, 37.10276208605085, 38.46852084568569, 37.76965018681118, 37.97173159463065, 38.776305198669434, 46.71861382893154, 48.93144484928676, 49.185543945857454, 49.58043439047677, 51.68422038214547, 47.73873444965908, 49.49001748221261, 45.058994906289236, 47.77659865788051, 25.036582946777344, 38.48416471481323, 54.91962473733084, 44.89743539265224, 41.580469608306885, 37.82521840504238, 40.41905042103359, 38.36084461212158, 39.305910791669575, 36.96214096886771, 38.820151805877686, 35.80823973246983, 36.28261756896973, 34.778853688921245, 35.99933951241629, 36.53524712153843, 38.45100791113717, 36.747493743896484, 39.58669444492885, 38.482941831861226, 39.18634966441563, 38.04874542781285, 39.60716731207711, 37.08287286758423, 38.19528988429478, 38.040470123291016, 38.710405009133474, 37.385616302490234, 39.5476907321385, 39.049904414585654, 38.85613652638027, 39.32603277478899, 39.939992972782676, 37.84776530947004, 41.61251122610909, 38.651915073394775, 37.56433439254761, 39.190563746861045, 39.082223960331504, 39.17183835165841, 40.85117973600115, 38.43156337738037, 44.77660969325474, 51.31444420133318, 52.88371917179653, 54.63426916939871, 53.72337770462036, 51.7692037991115, 49.26660510471889, 47.81462614876883, 55.79317658288138, 56.11862325668335, 51.80589376177107, 54.62941585268293, 57.682117325919016, 56.97106647491455, 55.821480069841655, 56.14266749790737, 56.78237771987915, 54.11942155020577, 40.17685011454991, 1.0652616556201662, 1.0130683077233178, 0.39760738025818554, 0.04413303041032382, 0.05437152673091207, 19.776681968144008, 65.76900059836251, 40.460138593401226, 35.59518711907523, 32.809869698115754, 13.651052815573555, 21.400213684354508, 35.78871529442923, 44.29211875370571, 50.35797255379813, 8.17027381488255, 0.28039262709873064, 0.10918292735836335, 0.07051272131502628, 0.13019041903316975, 0.1097443743741938, 0.09504904970526695, 0.04015003663620778, 0.047477655046220334, 0.039804421431784115, 0.049000212989215336, 0.04506489647818463, 0.04170873674697109, 0.03547413647174835, 0.02788302255794406, 0.029008481451975446, 0.010279123604829823, 0.04892861736672265, 0.013978044452544833, 0.01615729452376919, 0.055370404917214594, 0.04976075575021761, 0.07529555181307451, 0.06625943311623164, 0.4150473044386932, 49.58864368711199, 75.24731622423444, 60.96646131787981, 55.45795726776123, 31.413219247545513, 18.14666063444955, 28.30365719114031, 41.4515631539481, 52.03180054255894, 69.4464806147984, 8.39252758026123, 0.21923606230744294, 0.10049896155084882, 1.5019160934856959, 2.1414028874465396, 3.4954936674662997, 21.79301619529724, 67.92707633972168, 65.86417007446289, 63.43649727957589, 62.37622996738979, 61.50354317256382, 60.283606256757466, 60.73992225102016, 61.68188953399658, 53.51643255778721, 46.31876931871687, 43.91507475716727, 47.30618824277605, 55.11368097577776, 55.98286935261318, 57.02366781234741, 56.90621198926653, 53.37615885053362, 52.740777356284006, 55.807993616376606, 52.16524069649832, 49.81694064821516, 46.68148960386004, 43.890745639801025, 42.84761258534023, 40.28364045279366, 40.471988746098106, 39.636387961251394, 42.21055310113089, 40.357141971588135, 39.98323161261422, 40.75011471339634, 40.42308732441494, 41.473665373665945, 41.263239179338726, 41.5785345349993, 42.314855984279085, 40.75346027101789, 40.95736905506679, 40.3760723386492, 42.461063453129356, 41.54582936423165, 41.8118828364781, 41.34103468486241, 40.73188958849226, 37.39511448996407, 40.77151863915579, 39.37455551964896, 40.93340124402727, 40.45979813167027, 50.68004935128348, 49.24872044154576, 51.80603272574288, 50.30027123859951, 54.211043970925466, 49.98245716094971, 51.309285163879395, 48.46628727231707, 49.30008847372872, 26.995655332292827, 40.69117314474923, 56.42544181006295, 46.686641693115234, 43.992119857243125, 39.95960078920637, 43.21193790435791, 40.65504598617554, 42.07141889844622, 37.71669796534947, 41.818396772657124, 39.38831990105765, 38.2447749546596, 36.85556949887957, 36.1366081237793, 38.6399051121303, 41.143066610608784, 39.36324732644217, 42.7115911756243, 39.82713338306972, 38.79380076272147, 39.70367431640625, 41.25028773716518, 37.144687516348704, 41.11151136670794, 39.29616594314575, 41.02754586083548, 39.94265760694231, 42.00432709285191, 40.4490909576416, 40.960148334503174, 40.857922962733674, 41.41617945262364, 39.01538923808506, 43.11376333236694, 40.07795640400478, 39.94406114305769, 41.44120338984898, 40.6527669770377, 41.50239964893886, 42.26494012560163, 40.90681048801967, 47.57912390572684, 54.15325232914516, 55.55950171606881, 57.28209563664028, 54.1888861656189, 53.412786279405864, 51.61821249553135, 49.02910525458199, 54.6696320261274, 55.89747946602957, 52.8024183000837, 55.09350340706961, 57.83542932782854, 57.99638087408883, 58.40878772735596, 57.2698563848223, 59.97202123914446, 56.30967787333897, 42.94140979221889, 1.7125872118132455, 0.30378126778772896, 1.57241490483284, 0.10343790706247091, 0.0668623454070517, 19.350575004305156, 69.00883443014962, 47.091881479535786, 36.77619675227574, 26.3238913331713, 17.1395001411438, 25.540591376168386, 42.35420363289969, 49.423224449157715, 63.7367775780814, 13.687279854501996, 0.38909822542752537, 0.06451443103807313, 0.09520429173218352, 0.041618274458284886, 0.044836447308106084, 0.05635904061741062, 0.04861009267291852, 0.01241111456017409, 0.009692455442356212, 0.06232956863407578, 0.032066927158406804, 0.04959422290059073, 0.07959717884659767, 0.1282524008836065, 0.102007080268647, 0.10182074098182575, 0.1012486070394516, 0.1976142453828028, 0.09924504240708691, 0.20672735066286155, 0.24140188789793424, 0.17785234722707952, 0.1685557525072779, 0.7170215249061584, 58.91707624707903, 83.32449981144497, 70.11520303998674, 64.62065097263881, 31.498894010271343, 30.475928102220806, 36.38466228757586, 46.62143284933907, 61.854809352329795, 73.59638254983085, 10.668707932744708, 0.499158966754164, 0.8969000726938248, 1.237027638724872, 8.23178447995867, 7.452033315386091, 23.866238798413956, 70.31258051736015, 67.00294508252824, 69.30331298283168, 63.977213042122976, 64.41888223375592, 63.88590676443917, 63.2451091493879, 63.62621784210205, 56.21030821119036, 48.77737896783011, 46.27705233437674, 49.241706235068186, 58.99024772644043, 59.35844666617257, 60.13985497610909, 58.60303156716483, 54.900788170950754, 54.965941429138184, 59.09358828408377, 54.198384353092735, 51.2132054737636, 49.51733085087368, 46.170261996132986, 44.793274947575156, 43.709018979753765, 42.430321148463655, 40.91081959860665, 45.06822906221662, 42.45110668454851, 43.025681018829346, 44.046614578792024, 41.08891582489014, 43.55710703986031, 44.05790540150234, 44.234344482421875, 45.13986151559012, 43.12089218412127, 44.969092164720806, 42.64997107642037, 43.79502378191267, 43.00650746481759, 43.53393827165876, 42.81130477360317, 42.32789775303432, 39.559443610055105, 42.39130006517683, 42.837360518319265, 42.95928750719343, 42.341533592769075, 52.15312303815569, 52.11131920133318, 52.739825453077046, 52.17345346723284, 57.04356745311192, 51.407480580466135, 52.85043382644653, 50.97758511134556, 50.680097988673616, 30.17344175066267, 43.07072271619524, 59.414921624319895, 48.66800389971052, 44.41298614229475, 42.21289464405605, 45.58884368624006, 43.15901000159127, 44.34785720280239, 40.45241567066738, 44.70931986400059, 42.53163283211844, 40.48623602730887, 39.59351410184588, 39.668262822287424, 40.33036014011928, 44.461946623665945, 41.327107020786826, 45.73422431945801, 43.59588493619646, 42.47267041887556, 41.69292620250157, 43.14433193206787, 40.636240686689106, 43.983160155160085, 41.67031329018729, 41.35972881317139, 40.34757777622768, 45.250959736960276, 43.196867261614116, 43.9501770564488, 43.82695770263672, 42.73528800691877, 41.12022788184029, 45.810317516326904, 41.823114599500386, 42.11929893493652, 45.253349917275564, 41.78224182128906, 44.081810678754536, 45.01131636755807, 42.53806338991438, 50.56171458108084, 56.80823196683611, 55.38679381779262, 60.179904392787385, 54.82239512034825, 55.49147537776402, 55.10708018711635, 53.2269150188991, 55.38955920083182, 57.17729943139212, 54.06534024647304, 56.98072099685669, 59.87491321563721, 62.37887723105294, 61.85539994921003, 61.473061425345286, 62.09381348746163, 58.973641531808035, 44.07263558251517, 1.7587715621505464, 3.5922727371965135, 2.5408383224691664, 0.279660379248006, 0.1514401544949838, 24.12957899911063, 75.9659823008946, 51.96679319654192, 48.02613278797695, 43.05574240003313, 21.66639048712594, 33.680072511945454, 51.04163360595703, 55.503454072134836, 72.00615528651646, 16.98067648070199, 0.5170953071543148, 0.17925251780876092, 0.21675893451486314, 0.19636275539440767, 0.16881557713661874, 0.20668275734143599, 0.16273335207785877, 0.14773003357861722, 0.15655006601342134, 0.10689011003289904, 0.1561150572129658, 0.10847593458103282], [0.09112042694219522, 0.04936818252982838, 0.00819821106935186, 0.041411402701799355, 0.03469782455691269, 0.02939039488722171, 0.09197462789182152, 0.03971741288634283, 0.04064050888908761, 0.05565641760560019, 0.07472780120692082, 2.3101961272103444, 56.89668600899832, 61.01652308872768, 53.424997738429475, 39.240858282361714, 14.89710453578404, 35.03654500416347, 44.631444454193115, 31.772003378186906, 57.91588946751186, 51.08517796652657, 1.8541626206466129, 0.11005721294454165, 0.13873723255736486, 0.87911349854299, 0.6218420064875058, 1.0419025719165802, 56.130709648132324, 67.18752397809709, 64.48206220354352, 59.49576391492571, 58.25100803375244, 58.38318361554827, 56.51135975973946, 55.72702278409685, 57.27749592917306, 51.73278481619698, 44.03581012998308, 43.1820502281189, 41.22493028640747, 43.670612812042236, 53.05760478973389, 54.170080866132466, 54.35628911427089, 51.6647515296936, 53.458508900233674, 52.23977402278355, 51.402196475437705, 44.86219065529959, 42.78169502530779, 39.80892562866211, 39.44656317574637, 38.41452292033604, 40.906039237976074, 39.31838280814034, 39.91232872009277, 38.36024011884417, 39.44202252796718, 38.623969418661936, 40.887894017355784, 39.44577802930559, 40.64512395858765, 38.37030805860247, 38.344224521092, 37.940575872148784, 41.33662952695574, 38.81522900717599, 40.23705278124128, 39.14849240439278, 38.93537725721087, 38.96573393685477, 40.69275038582938, 37.16554600851876, 38.42576510565621, 36.86957359313965, 39.067844663347515, 41.387323583875386, 50.335769585200715, 48.51817294529506, 53.34400258745466, 49.73772423607962, 51.10855170658657, 48.03457832336426, 53.02802630833217, 48.38921785354614, 51.1888416154044, 25.515991279057094, 40.84416900362287, 53.52006993974958, 45.73614549636841, 44.150684697287424, 43.315598079136436, 44.243022782461985, 43.098036084856304, 42.422928265162874, 38.769926752362935, 37.67828484943935, 35.69118343080793, 36.279810496738975, 35.32417958123343, 35.44961888449532, 37.30939456394741, 38.48646804264614, 38.37299353735787, 37.749719279153005, 38.7325176511492, 36.68074934823172, 37.544274943215505, 37.58410896573748, 37.023048877716064, 38.68787200110299, 37.58343846457345, 39.06319284439087, 38.29281827381679, 38.551044600350515, 38.04618501663208, 38.199649878910606, 38.704669271196636, 38.06179067066738, 38.962739263262065, 39.51260927745274, 37.73829991476876, 38.63866138458252, 39.330528259277344, 38.240897859845845, 39.8687287739345, 40.74591105324881, 43.09238025120327, 51.30905587332589, 53.57210152489798, 54.42030981608799, 49.12154756273542, 53.03219175338745, 53.820256437574116, 55.165083748953684, 51.12401144845145, 48.122976779937744, 54.065444469451904, 55.14951631001064, 54.11474193845476, 54.85877241407122, 52.99926771436419, 56.863991260528564, 53.92011594772339, 57.49071182523455, 56.51627908434187, 60.368909290858674, 14.550142765045166, 0.43837498554161614, 0.6929853718195642, 0.03369705665058323, 0.06768249746944223, 1.9056057802268436, 53.53730147225516, 51.894611835479736, 42.42300122124808, 40.323328563145225, 23.939571823392594, 28.994294234684535, 41.87128298623221, 45.98402942929949, 48.623254026685444, 21.8277884551457, 0.3497880862227508, 0.14750864117273263, 0.032675993761845996, 0.027187039011291096, 0.039884939789772034, 0.03541019811694111, 0.04501363655020084, 0.05574548889749816, 0.05189498247844832, 0.07848231188420739, 0.022489619108715227, 0.009163063268975487, 0.04462462563865951, 0.012579068092496266, 0.04936918676165598, 0.009776025511590498, 0.09022441466471978, 0.05133363724287067, 0.0680836338017668, 0.1063750951683947, 0.00966832334441798, 0.11220844036766461, 0.1706981182630573, 4.835979223251343, 69.102781023298, 64.98254789624895, 62.5151036126273, 46.87048060553414, 19.688347782407487, 32.97644581113543, 39.34364298411778, 38.057079792022705, 62.30695642743792, 54.46140146255493, 2.03738249199731, 0.07991089272711958, 0.38077691623142784, 1.7512070366314478, 1.8656684032508304, 1.8821553928511483, 56.755095618111746, 69.16719777243478, 66.7773301260812, 60.833438055855886, 61.633682932172505, 59.87594154902867, 59.57538332257952, 57.6027376311166, 58.87508828299386, 54.57189171654837, 46.507110663822715, 44.22721215656826, 43.10485226767403, 46.01221479688372, 54.674051080431255, 54.84852729524885, 55.746575014931814, 54.452757903507774, 56.97219555718558, 54.25701672690255, 53.48667342322213, 46.86911875861031, 44.92979662758963, 41.58369704655239, 41.70414754322597, 41.71320104598999, 42.6590211050851, 41.7224907875061, 41.32744400841849, 41.000065735408235, 41.11140366962978, 40.330756187438965, 43.365857873644146, 41.62728309631348, 41.62738037109375, 40.32712227957589, 41.37076602663313, 39.57964202335903, 41.232350962502615, 40.200258595602854, 41.976367541721885, 39.851076875414165, 39.4506139755249, 39.31739616394043, 43.28689507075718, 39.451319217681885, 40.18291241782052, 37.808424609048025, 41.5441062109811, 42.52669613701956, 53.97314807346889, 50.69154167175293, 54.46124860218593, 51.54889726638794, 52.37275906971523, 50.522099426814485, 53.64291756493704, 50.37930004937308, 53.26694706508091, 28.701526675905498, 43.04286043984549, 54.81763213021414, 47.054482800619944, 46.49414185115269, 46.0802515574864, 46.8959527015686, 44.76076432636806, 44.205290590013774, 40.79612915856497, 39.47883408410208, 37.75563219615391, 39.61729431152344, 38.84007576533726, 37.218998500279014, 38.68249062129429, 40.49643250874111, 40.77489198957171, 39.53480182375227, 40.303908348083496, 38.51427820750645, 38.325610297066824, 39.39203371320452, 38.88949135371617, 41.25958095278059, 40.376701150621685, 40.67462600980486, 41.360208238874165, 40.950792585100444, 40.482081004551475, 38.86265046255929, 40.869835649217876, 40.663241386413574, 39.73089735848563, 41.339137826647075, 38.33222845622471, 40.84115695953369, 41.70638486317226, 40.44146530968802, 43.275680678231375, 41.46292693274361, 44.60886280877249, 53.27864783150809, 55.28056628363473, 55.42773955208914, 51.55663755961827, 54.81385578427996, 56.85645593915667, 55.36465685708182, 53.344735622406006, 49.58519738061087, 53.900671413966585, 56.106759207589285, 55.42932721546718, 56.60891246795654, 55.42422028950283, 57.54056862422398, 55.176009791237966, 59.716132981436594, 60.07917635781424, 62.10218606676374, 18.946354866027832, 0.3529433012008667, 1.7705413763012205, 0.27582573358501705, 0.027500981897381798, 1.7171266653708048, 57.00166286740984, 56.324870109558105, 44.3828934941973, 30.729335853031703, 23.28466762815203, 36.1651964868818, 49.10056747709002, 51.58159548895699, 55.436334473746165, 31.69237354823521, 0.4513240392718996, 0.10913783870637417, 0.05281846524615373, 0.07216080823647124, 0.08532404833074127, 0.06391007346766335, 0.028735086122261624, 0.08822850390736546, 0.03800943507147687, 0.05770733380424125, 0.060245665455503125, 0.03144829321120467, 0.15207268483936787, 0.11648190819791385, 0.09262708680970327, 0.12438390989388738, 0.20093467006725924, 0.18522647581994534, 0.15205621000911507, 0.2862086764403752, 0.16003876738250256, 0.2444512785545417, 0.32334014826587265, 7.1020972813878736, 80.8226341520037, 73.11403165544782, 70.06553036825997, 54.82467065538679, 23.332090820584977, 47.92070082255772, 60.20964963095528, 45.49939257758004, 69.44194344111851, 60.2848082951137, 2.9595207018511633, 0.2585185579955578, 0.9360777075801576, 3.317275196313858, 7.086970618792942, 2.153764601264681, 58.90542411804199, 70.27082184382847, 72.42077514103481, 61.228325026375906, 62.19035870688302, 61.94958972930908, 61.785584449768066, 59.729529108319966, 62.622564452035085, 56.44802345548357, 48.36095258167812, 47.78448486328125, 45.348998819078716, 48.14667361123221, 57.502020018441335, 56.521806376320974, 59.242293630327495, 56.09030934742519, 58.33945165361677, 55.86558723449707, 56.40416990007673, 48.2190842628479, 48.233321121760774, 43.28285469327654, 44.350709438323975, 42.64009768622262, 46.61122247150966, 42.29545313971383, 43.33602925709316, 43.46239961896624, 43.59484270640782, 40.33338955470494, 46.04184538977486, 43.32711124420166, 44.600830691201345, 41.71922860826765, 42.431446756635395, 41.10409763881138, 46.09768806185041, 43.21861859730312, 43.273992265973774, 42.74561997822353, 41.644354820251465, 42.038109234401155, 45.70968328203474, 41.26630680901663, 42.64322784968785, 40.25022656576974, 44.51443678992135, 44.74071182523455, 55.13370221001761, 53.05315794263567, 57.309120655059814, 53.503779888153076, 54.789936610630576, 51.28894778660366, 55.49332012448992, 54.78009101322719, 55.11729056494576, 31.052166530064174, 46.01008864811489, 57.97018616540091, 49.76296009336199, 48.62630775996617, 50.0348813193185, 48.324332101004465, 47.985541411808555, 47.184285572596956, 44.50800623212542, 41.72224760055542, 40.645346300942556, 41.55510173525129, 41.016067436763215, 39.80565997532436, 40.94498041697911, 41.986744676317485, 43.05959170205252, 42.62905005046299, 42.88465690612793, 39.717407430921284, 41.890995025634766, 42.013370173318044, 41.55583129610334, 43.37317780085972, 40.732323850904194, 42.00664431708199, 44.077454158238, 42.95269019263131, 42.77897480555943, 42.101410797664094, 41.969749382564, 42.62100403649466, 42.37004899978638, 42.665625367845806, 41.43052748271397, 42.39457614081246, 43.13709190913609, 42.73913383483887, 44.82922492708479, 45.32760531561715, 47.40947668892996, 55.33726705823626, 56.48091275351388, 60.074541909354075, 55.64445734024048, 55.51203509739467, 59.227716309683665, 57.45596735818045, 55.83967740195138, 52.8939608165196, 55.23601443426949, 58.009860379355295, 58.73876462663923, 59.141801834106445, 59.15733800615583, 60.38359778267996, 60.15794808523995, 61.46258354187012, 62.56410925728934, 63.27333273206438, 18.880147218704224, 1.238543105976922, 3.757643989154271, 0.4476915699030672, 0.13669047238571302, 2.751356363296509, 65.19949844905308, 61.998254912240164, 56.95710406984602, 51.32406398228237, 34.94989054543631, 39.73433671678816, 57.05658837727138, 58.491047450474326, 65.34249932425362, 36.156115191323416, 0.5837848771895681, 0.22121321835688182, 0.09695194688226495, 0.2076406180858612, 0.15234378672071866, 0.16377514760409081, 0.16883563463176998, 0.14971320144832134, 0.10357207379170827, 0.26888866296836306, 0.19837218256933348, 0.06297265019799982], [0.04062515703429069, 0.015366523027686136, 0.012807624980009027, 0.09426159624542509, 0.062099043146840165, 0.016683791897126606, 0.07987966654556138, 0.028075253225064704, 0.015182964038103819, 0.11585418188146182, 0.10853845479765109, 9.423402275357928, 63.43815789903913, 57.203424658094136, 47.70561238697597, 34.076682635716026, 30.25649356842041, 21.190494469233922, 31.85299505506243, 43.8245918410165, 64.28173174176897, 37.293243476322715, 0.03463074458496911, 0.08884451870939561, 0.33293664189321653, 1.4005424188716071, 1.528796068259648, 14.17377621786935, 72.49890068599156, 59.68360846383231, 62.94275828770229, 53.52441256386893, 54.98419782093593, 50.66416924340384, 53.998370034354075, 50.791977882385254, 53.57566942487444, 49.546329157693044, 44.16188171931675, 40.417897020067485, 41.320238726479666, 39.60355077471052, 43.55370242255074, 49.804475579942974, 54.196025439671104, 57.819240025111604, 56.290209020887104, 54.43786791392735, 49.217248576028005, 42.054204736437114, 41.25440107073103, 40.40984058380127, 40.15081174033028, 38.65695251737322, 39.860672337668284, 38.709581647600444, 39.87067774363926, 38.631452628544395, 39.56741666793823, 37.63075917107718, 40.29213115147182, 39.468425682612825, 41.24790103094918, 39.25716917855399, 38.76268325533186, 38.47969354901995, 39.12340940747942, 40.36392341341291, 40.2923013823373, 41.385221753801616, 39.34100614275251, 37.59135593686785, 40.00973899023873, 38.88284887586321, 38.467985834394185, 37.837839807782856, 39.076960699898855, 45.62663493837629, 50.259881360190256, 50.406814915793284, 51.48675605228969, 48.51625524248396, 53.12681579589844, 47.41981908253261, 52.481540066855295, 48.2346065385001, 49.89861672265189, 31.295002596718923, 39.12470872061593, 52.1425895690918, 47.51349122183663, 47.51893513543265, 47.169527598789756, 50.165483134133474, 47.64650406156267, 47.03499657767159, 42.96472099849156, 38.45518030439104, 36.481499331338064, 36.37537602015904, 37.51136827468872, 36.06394733701433, 36.64832557950701, 37.13991410391671, 37.2364627974374, 36.77212510790144, 36.84876026426043, 37.71906730106899, 37.474608830043245, 37.610783100128174, 36.46455267497471, 38.52521119798933, 39.54766641344343, 40.04523386274065, 39.758919443402974, 37.499358313424246, 40.83024481364659, 37.31275054386684, 39.979542119162424, 37.30938761574881, 40.312798568180625, 37.36756140845162, 37.22014842714582, 37.57432590212141, 39.16972957338606, 38.89030429295131, 40.00813743046352, 39.080219405038015, 44.89617082050869, 51.10888522011893, 51.65549652917044, 38.2363989012582, 46.844918182918, 54.56447104045323, 52.87982470648629, 52.34156860624041, 53.0333833694458, 52.22872986112322, 51.331220626831055, 55.75201545442854, 51.28664445877075, 53.699524538857595, 52.900266306740896, 55.05970389502389, 52.42121580668858, 56.38842180797032, 54.61394221442086, 58.753696305411204, 46.26273904527937, 2.643874462161745, 0.8464403003454208, 0.38796626616801533, 0.0196093295567802, 0.041348007175007036, 20.656242268426077, 64.15938091278076, 43.54521172387259, 38.618417807987754, 19.9967748437609, 19.00477705683027, 32.986030851091655, 42.29775646754673, 48.05804933820452, 36.99284158434187, 1.0770111680030823, 0.08896459905164582, 0.047186271753162146, 0.011722017295791634, 0.07147357439888374, 0.012896959204226732, 0.04188194638118148, 0.03842918701203806, 0.06216034200042486, 0.02713947370648384, 0.025911060694072927, 0.06094206630119255, 0.06394677542682205, 0.017749821301549673, 0.02206782138507281, 0.03348081432549017, 0.08602165696876389, 0.03231236684535231, 0.02678822835774294, 0.01155818671187652, 0.11267502818788801, 0.0937928913959435, 0.21545360955808843, 13.707129989351545, 74.0359742300851, 61.22142546517508, 54.44514267785208, 37.6423522404262, 36.31088284083775, 29.657909733908518, 31.722466196332658, 48.150606291634695, 69.98030376434326, 38.604698589869905, 0.01750493122796927, 0.045133486190544705, 0.9422948254006249, 3.4970331277166093, 0.734214788036687, 13.807322144508362, 72.99024949754987, 62.145876339503694, 65.55459308624268, 56.043235301971436, 55.704514094761436, 51.955992221832275, 54.301829133714946, 52.80899824414934, 55.510860851832796, 50.31835045133318, 46.53933988298689, 42.04851416179112, 44.147314820970806, 41.660665716443745, 46.75788157326834, 51.73753390993391, 56.88236229760306, 57.661088602883474, 57.227930954524446, 55.77618823732649, 51.00144522530692, 43.51095015662057, 43.71186774117606, 42.696256501334055, 41.58835928780692, 40.23799078805106, 42.70556361334664, 40.43744577680315, 41.48016193934849, 40.68460014888218, 41.24809210641043, 39.04424858093262, 40.983251094818115, 41.62376383372715, 42.761694635663716, 41.21040507725307, 41.34192752838135, 39.924866744450156, 41.277722699301584, 41.65463468006679, 41.41431038720267, 40.93746594020298, 40.062093666621614, 41.061241149902344, 42.83806576047625, 39.234153270721436, 41.126832144601, 40.71547099522182, 42.014467988695415, 47.22737830025809, 53.83553205217634, 50.44262593133109, 53.78771454947335, 50.05872753688267, 53.297244685036794, 50.266937255859375, 53.933300154549734, 48.48037821905953, 52.606857776641846, 33.39278187070574, 41.486133916037424, 54.488912854875835, 48.79825830459595, 50.67221525737217, 48.72576080049787, 51.60828004564558, 49.50327117102486, 49.48701933452061, 45.48260572978428, 40.19557203565325, 38.63777896336147, 37.349885191236226, 38.151182719639365, 38.01981312888009, 37.051776204790386, 40.2187442779541, 39.740954875946045, 39.80681685038975, 39.7646621295384, 39.44545146397182, 38.2971886907305, 40.17869486127581, 39.70326437268938, 40.23545469556536, 39.00761420386178, 42.4626441683088, 40.07838371821812, 39.24975197655814, 42.663207394736155, 39.845949104854036, 42.296241760253906, 39.119441986083984, 41.36450569970267, 38.26279163360596, 39.33105284827096, 40.02011612483433, 41.60126904078892, 39.93873882293701, 42.7547881262643, 41.42946788242885, 46.808940410614014, 54.74983508246285, 53.35106543132237, 42.38519607271467, 51.27542311804635, 55.02488647188459, 54.980768884931294, 53.0720396723066, 55.3631352015904, 52.999959060123985, 52.2483411516462, 55.62135805402483, 55.09275647572109, 56.33498321260725, 56.01897914069039, 55.85508503232683, 55.850926535470144, 58.564726148332866, 57.33251871381487, 60.24272305624825, 50.71981389181954, 3.3285523397581915, 0.6991097746150834, 0.6384954271571976, 0.10587452631443739, 0.08351130810167108, 22.321404116494314, 70.23889487130302, 46.82718985421317, 34.58487388065883, 25.386185032980784, 28.757791451045446, 39.604353291647776, 49.360360622406006, 52.21992996760777, 49.505074228559224, 2.915443935564586, 0.21131861715444497, 0.03942204320005008, 0.05082726012915373, 0.03667199505226953, 0.04612295309613858, 0.07055430872631924, 0.05744484931762729, 0.06197483052632638, 0.07743457239121199, 0.03560721415228077, 0.12280346612845149, 0.25366418276514324, 0.07008491177111864, 0.08107162187142031, 0.21930097096732684, 0.17620867756860598, 0.1946863667773349, 0.21348532874669346, 0.18713641619043692, 0.24768251659614698, 0.2205195248659168, 0.31635501022849766, 17.030507223946707, 85.6263963154384, 68.44672516414097, 63.007272311619346, 45.66211591448103, 41.75206579480852, 29.750185285295757, 45.6399233681815, 57.7195576940264, 74.9741130556379, 43.91486978530884, 0.1478286382875272, 0.17352478658514364, 1.1326681928975242, 7.450951133455549, 6.116885278906141, 14.830660649708339, 76.47298540387834, 66.53594275883266, 67.50004700251988, 57.888496194567, 60.13981328691755, 54.25852101189749, 57.210164410727366, 56.17620645250593, 57.39662626811436, 53.841813223702566, 48.701563698904856, 44.614859104156494, 45.2383383342198, 45.488939012799946, 49.873061248234336, 53.830647468566895, 59.80287429264614, 63.02617835998535, 59.367131914411274, 59.31473554883684, 54.83349139349801, 45.49959407533918, 46.85840463638306, 43.53393479755947, 45.12115001678467, 42.182284355163574, 44.844375474112375, 42.14526435307094, 44.51353005000523, 42.0466833114624, 42.03341572625296, 41.77603360584804, 43.45250538417271, 44.49944257736206, 45.131256171635215, 42.985343251909526, 43.09614964893886, 42.47569983346121, 44.733857427324565, 43.65768568856375, 44.35999570574079, 43.92375653130667, 42.634830951690674, 42.069890294756206, 44.02779538290841, 42.47689839771816, 44.25259392602103, 42.66303368977138, 44.14741209575108, 50.5583690234593, 55.45250293186733, 54.91085263660976, 55.87806967326573, 52.73305095945086, 55.546449525015696, 53.0590569632394, 57.513811111450195, 50.63196086883545, 54.03705760410854, 37.32012605667114, 43.01957702636719, 56.50028085708618, 51.28089829853603, 51.82525839124407, 50.84379407337734, 54.717063903808594, 51.791097572871614, 52.7774464743478, 46.65170267650059, 41.65066031047276, 41.07073586327689, 41.041657652173726, 42.56174285071236, 40.81169312340872, 40.44641590118408, 41.998758111681255, 42.526192392621724, 41.40044525691441, 41.75505699430193, 41.98429543631417, 40.9685035433088, 43.20745284216744, 41.48700244086129, 43.09201547077724, 42.007811614445274, 44.93209648132324, 43.6924648966108, 42.62224776404244, 45.65280532836914, 41.5988267489842, 45.81099843978882, 40.846298626491, 44.730598722185405, 40.15437616620745, 41.582613127572195, 41.26596982138497, 42.912050179072786, 41.8200226511274, 43.62847546168736, 43.40587254932949, 48.62980270385742, 57.501780305589946, 56.6987943649292, 45.926348958696636, 53.02066816602434, 57.69681971413748, 58.36259610312325, 57.407743385859895, 57.30477108274187, 54.96890483583723, 57.14909321921212, 57.79021392549787, 56.87758193697248, 58.888387135096956, 58.69157246180943, 58.52456556047712, 58.386206081935335, 61.53993088858468, 58.99381215231759, 61.28778770991734, 51.53565052577427, 3.39828793491636, 2.8336119609219685, 1.289738301719938, 0.17096056203757012, 0.2297158863927637, 26.94109112875802, 74.71775926862443, 54.310302461896626, 51.96969059535435, 28.128590379442485, 29.371828079223633, 45.44100686482021, 58.9152558190482, 60.81861754826137, 60.73682335444859, 4.066537014075688, 0.3783182310206549, 0.2310284445328372, 0.18403192849031516, 0.1092088066839746, 0.18245996641261236, 0.1003762281366757, 0.09766619998429503, 0.15676835072892054, 0.1666810145335538, 0.14459026205752576, 0.2510969048099858], [0.07032649059380804, 0.03582394162991217, 0.022576593727405583, 0.1469102275690862, 0.05995662310825927, 0.08243201673030853, 0.015146718393745167, 0.12624298727938107, 0.022844404713915925, 0.13507226136113915, 0.1995181603623288, 17.957092932292394, 63.67622402736119, 51.22370420183454, 46.46394845417568, 23.048920461109706, 16.257645198277064, 33.02839401790074, 36.34924037115914, 44.98850890568325, 67.73340920039585, 14.648431982312884, 0.1743536035397223, 0.13302384556404181, 0.8654180020093918, 1.0052696061985833, 0.6885159973587308, 31.45869173322405, 58.81514617374965, 63.34020219530378, 61.80831200735909, 53.105109623500276, 48.84399134772164, 46.86335522787911, 49.93953466415405, 49.98575408118111, 50.775385584150044, 45.570385796683176, 41.73288876669747, 41.123833996909006, 40.804268973214285, 40.8858825138637, 40.28801434380667, 39.1504795891898, 45.9755665234157, 47.59369775227138, 51.224037715366904, 46.83212654931204, 41.52410234723772, 39.245565686907085, 40.62833363669259, 37.953749656677246, 38.144891125815256, 41.037652015686035, 40.25178296225411, 37.97863115583147, 41.383901596069336, 39.13132687977382, 40.05107034955706, 38.83238410949707, 39.18884406770979, 39.57565375736782, 39.858143193381174, 39.978857721601216, 37.356993198394775, 36.44927706037249, 39.37993689945766, 39.592329433986116, 38.363460608891074, 39.3685279573713, 39.1658524785723, 39.52144043786185, 36.921518325805664, 37.59443746294294, 37.250282764434814, 38.03724615914481, 40.715557847704204, 46.788043703351704, 51.167889322553364, 47.911675112588064, 51.28370189666748, 48.14710092544556, 50.27931547164917, 46.84252452850342, 51.50179195404053, 50.146945340292795, 54.00002370561872, 30.21628781727382, 32.98270961216518, 55.98726061412266, 44.8653381892613, 51.23563078471592, 49.19695636204311, 49.95768683297293, 48.68637841088431, 49.69827583857945, 45.39949485233852, 43.05167422975813, 36.76927982057844, 37.34846428462437, 36.08797420774187, 35.61368669782366, 36.29796961375645, 37.59345081874302, 37.44196619306292, 37.49531446184431, 38.59073618480137, 39.5951121875218, 38.92421497617449, 38.86970983232771, 38.43609707696097, 38.70198726654053, 40.45094960076468, 40.1279730115618, 39.454741205487935, 39.14535876682827, 38.06721026556832, 37.76532145908901, 36.89347192219326, 38.953633649008616, 39.29409537996565, 38.80605738503592, 38.967266014644075, 38.7378226007734, 38.96465696607317, 38.04974249431065, 38.65077209472656, 38.99273463657924, 44.85759442193167, 52.6350987298148, 51.73689814976284, 47.584206512996126, 52.46129649026053, 51.97830983570644, 50.723385265895296, 52.01133809770857, 50.44581168038504, 52.41046346936907, 49.42621564865112, 51.12555047443935, 55.06439045497349, 50.6817238671439, 52.25991685049874, 50.665975775037495, 52.30562557492937, 50.62449502944946, 59.71416664123535, 55.7548121043614, 62.02865328107561, 21.465267930712017, 0.3364414652543408, 0.1961662923651082, 0.15773534455469676, 0.03617895454434412, 4.361134120396205, 54.7370399747576, 52.31734023775373, 39.83925104141235, 22.35610863140651, 13.178520594324384, 27.569065843309673, 41.21043634414673, 43.710443360464915, 45.596434593200684, 5.657880766051156, 0.27885818800755907, 0.08311849060867514, 0.07498347998729774, 0.034080411972744126, 0.017173979165298597, 0.010458522326579052, 0.009777264686168304, 0.012493109579996338, 0.014981778405074562, 0.018147846550813744, 0.06358827823506934, 0.04725731436961463, 0.05413778838036316, 0.01923705980048648, 0.14916646507169518, 0.012987965169096631, 0.07461677930716958, 0.02161769482440182, 0.06619937598173108, 0.08985437559229986, 0.11172635480761528, 0.14135101730270044, 24.16414281300136, 73.18861361912319, 56.81148024967739, 49.89904056276594, 28.374143191746303, 22.605059112821305, 31.215160846710205, 41.451618739536826, 50.40198591777256, 72.33803599221366, 15.828236103057861, 0.20945774843650206, 0.14992525721234934, 1.8971294122082847, 2.382470203297479, 0.7498743448938642, 35.87319149289812, 63.47709560394287, 64.54486697060722, 63.22185352870396, 55.7488922391619, 49.781160899571006, 49.20337649754116, 53.19745465687343, 51.81030586787632, 51.72633688790457, 47.79041167667934, 43.48877845491682, 43.949589933667866, 41.80393757138933, 42.26405075618199, 42.625322341918945, 41.93919815335955, 47.97906221662249, 49.40821286610195, 53.86275162015642, 50.03499596459525, 43.1393118585859, 42.104627813611714, 43.019590922764365, 40.08776378631592, 41.35476432527815, 41.879144872937886, 42.058338914598735, 39.68156167439052, 41.50237185614449, 41.42246062414986, 41.08059883117676, 39.21410076958792, 41.27908802032471, 40.6614522252764, 39.82165820258004, 40.49860034670149, 39.2160393169948, 39.229848861694336, 40.181102412087576, 40.48819541931152, 41.0618908064706, 42.38301433835711, 41.03427519117083, 40.76033551352364, 41.501312255859375, 40.25937386921474, 38.83455889565604, 39.592767170497346, 41.075175762176514, 49.8302047593253, 53.02482318878174, 49.95704065050398, 52.87595108577183, 50.189916474478586, 52.280716282980784, 49.18646110807146, 54.48627948760986, 49.93525109972273, 55.794649600982666, 33.22895377022879, 34.3373373576573, 55.59324564252581, 47.268278871263774, 52.97599819728306, 50.04761389323643, 52.38902480261666, 48.64069053104946, 50.53220558166504, 48.28713491984776, 44.40081984656197, 38.05348062515259, 40.910902976989746, 37.9394085747855, 38.099783420562744, 39.440917764391216, 37.95639344624111, 39.25786747251238, 39.55435405458723, 41.20993259974888, 40.190989698682515, 39.7823348726545, 40.33558518545968, 40.40562302725655, 40.83871119362967, 40.95738295146397, 40.94818006243025, 41.33703947067261, 41.63484968457903, 39.59815897260393, 39.98481232779366, 38.51326724461147, 41.205398900168284, 40.39843511581421, 40.29720681054251, 40.341286182403564, 41.39255557741438, 39.86874614443098, 40.95256437574114, 40.91346686226981, 41.03753737040928, 46.569814682006836, 53.722728048052105, 53.60330588476998, 50.655734130314414, 54.092396531786235, 53.13158573423113, 53.24673475537981, 54.065374987465994, 50.49436221803938, 53.79848425728934, 52.85554422651018, 54.00214638028826, 55.96610682351248, 52.9289311000279, 55.50350965772356, 52.344636235918315, 56.07805619921003, 52.39924212864467, 61.4816563470023, 58.55896609170096, 65.49461623600551, 23.882711240223475, 0.5250183162944657, 1.0564544882093156, 0.19054633964385304, 0.07106225325592927, 4.081429174968174, 60.608149664742605, 55.88590029307774, 42.446107455662315, 23.56320353916713, 17.238136768341064, 29.888450963156565, 47.720227922712056, 48.79960625512259, 59.48200648171561, 9.739699040140424, 0.4270800101969923, 0.060026858268039565, 0.047714518050530126, 0.04942063667944499, 0.0343764703720808, 0.02744476866376187, 0.03877356728272779, 0.05180866603872605, 0.059498856243278296, 0.06623035789068256, 0.04605596472642251, 0.2434625987495695, 0.13786326588264533, 0.09691308039639678, 0.2518497258424759, 0.14621600482080663, 0.261451104921954, 0.11927847670657293, 0.1951731885118144, 0.09751804186297314, 0.28156084726963726, 0.32032530861241476, 31.933423927852086, 82.5207530430385, 64.13761220659528, 60.89081627982003, 33.20550012588501, 24.783015387398855, 40.51326104572841, 54.521232400621685, 56.0354185785566, 79.35429913657052, 18.229370253426687, 0.18596907811505453, 0.2673149231289114, 2.580526432820729, 8.57889563696725, 3.9161949328013828, 40.44971629551479, 68.96310833522251, 66.63763659340995, 66.26095390319824, 57.65689883913313, 51.97227185113089, 50.675150871276855, 56.606341634477886, 53.9971957887922, 57.067403248378206, 50.1373359816415, 45.355387687683105, 45.0202830178397, 43.82099962234497, 46.74886628559658, 43.93738889694214, 43.36771304266793, 50.20940964562552, 51.24780402864729, 57.12239129202706, 51.92478091376168, 46.147666454315186, 43.45222398212978, 45.5385456766401, 41.47324848175049, 42.96541581835066, 44.447515215192524, 43.18576404026577, 40.647694792066304, 44.4975665637425, 42.88999659674508, 43.896457059042795, 40.94425433022635, 43.70186580930437, 44.01743561880929, 40.386418206351145, 42.7494866507394, 41.00086825234549, 41.62744985307966, 42.19190066201346, 42.409361907414024, 43.059577805655344, 44.467057023729595, 41.6445563180106, 43.6007729939052, 40.91732658658709, 41.37953117915562, 41.8142625944955, 41.858314173562185, 45.239029679979595, 52.12389544078282, 55.86480903625488, 52.20154503413609, 56.353604384831016, 51.64809322357178, 54.18935864312308, 52.98582642418997, 56.70722600391933, 52.15649291447231, 58.679864747183665, 36.79568992342268, 37.95459386280605, 57.8283873285566, 49.892665590558735, 55.38641514096941, 53.59698649815151, 52.97006443568638, 50.76113830293928, 53.12489809308733, 49.911564690726145, 47.56070075716291, 41.141555377415244, 43.51866960525513, 40.54911722455706, 40.917375223977224, 40.92017534800938, 39.885328020368306, 42.79710612978254, 41.484504563467844, 42.87587090900966, 42.61958660398211, 42.94457817077637, 43.19040891102382, 43.90479489735195, 42.926749093191965, 43.613620213099885, 44.48245423180716, 43.71225336619786, 44.26128264835903, 42.344114848545615, 41.388598578316824, 40.44915001732962, 43.84301151548113, 43.22166885648455, 43.44043288912092, 42.18293401173183, 44.56504052025931, 42.11289964403425, 41.1774845123291, 42.24173314230782, 41.99004507064819, 49.42355448859078, 55.828751359667095, 56.639397689274375, 51.916922501155305, 56.212354455675396, 56.491467067173545, 57.35479116439819, 55.96354293823242, 54.58684771401541, 55.83776664733887, 55.70766857692173, 55.07594878332955, 58.59627096993582, 54.99612787791661, 57.64233888898577, 55.84800481796265, 57.55676487513951, 55.61184597015381, 64.45129558018276, 61.09801851000105, 67.32692568642753, 24.540662220546178, 2.0488537507397786, 2.4143750284399306, 0.34874680638313293, 0.21988361541713985, 5.2620814102036615, 68.02405234745571, 63.07810224805559, 53.696189403533936, 29.224265711648123, 23.105213029044016, 35.49610928126744, 57.966142313820974, 55.63318041392735, 70.548492704119, 12.453264151300703, 0.5696582666465214, 0.2068405845867736, 0.20280821381935052, 0.10634781806064503, 0.09234068396368197, 0.09609594102948904, 0.11936190937246595, 0.10657029612255947, 0.07399533622499023, 0.10841072058039052, 0.16857108739869936], [0.03701320656442216, 0.038982993723558526, 0.011787055725497859, 0.03715929515393717, 0.03340523909511311, 0.027914606666724597, 0.018463129543566277, 0.009853368325691138, 0.05358578996466739, 0.07245907187461853, 0.40497591772249764, 32.94432776314871, 66.50569030216762, 48.7376526423863, 47.362982818058555, 19.31387288229806, 33.19531406675066, 47.96740313938686, 37.25856154305594, 54.54271623066494, 57.44261639458792, 4.99561755997794, 0.05197193852758833, 0.19086620105164392, 0.19460429118147918, 2.2756168970039914, 3.3266101011208127, 61.47991234915597, 62.93830449240548, 64.1010855266026, 54.660432611192974, 49.39924968991961, 44.809318338121685, 46.6798220361982, 45.13101993288313, 49.071204389844624, 44.005102566310335, 45.32060500553676, 40.59440558297293, 41.50491142272949, 39.13324110848563, 42.109481130327495, 39.091023853846956, 39.57520907265799, 38.55757590702602, 40.26163898195539, 38.73573119299752, 40.148727280753, 39.10443040302822, 43.409881659916465, 41.176390171051025, 41.12198577608381, 39.77187783377511, 39.846918378557476, 39.407646315438406, 39.57189130783081, 39.43469565255301, 39.16735676356724, 37.209892886025564, 38.30809736251831, 38.060758863176616, 39.65104866027832, 36.636531012398855, 39.40397071838379, 37.79779386520386, 38.067335333142964, 39.10676499775478, 39.03616087777274, 38.64461251667568, 41.56670522689819, 39.769491127559114, 39.67448146002633, 40.26431403841291, 39.57840176991054, 38.02984980174473, 38.264007568359375, 41.00199038641793, 47.15452643803188, 49.7056930405753, 49.50319821493966, 50.00711631774902, 50.21801846367972, 50.63280160086495, 48.252598898751394, 51.00028487614223, 48.13798836299351, 48.691707679203574, 33.29032373428345, 24.645684242248535, 48.6288994380406, 46.2960695539202, 51.331658363342285, 49.191529818943565, 50.47895111356463, 47.368482317243306, 48.46148954119001, 46.104420866285054, 42.59201267787388, 37.06777443204607, 38.30835444586617, 35.99542767660958, 37.610029220581055, 36.03352812358311, 36.46683168411255, 36.71806117466518, 39.65617643083845, 39.481682845524375, 39.10406214850289, 34.988373143332346, 39.05454233714512, 39.110266889844624, 38.802725723811555, 37.020828928266255, 40.103522300720215, 38.40197794778006, 40.061409269060405, 36.33641052246094, 38.86636080060686, 35.7816732951573, 40.15215621675764, 37.180446420397075, 38.430024351392476, 37.87274408340454, 37.888919489724294, 38.52702120372227, 38.97082001822335, 38.93057952608381, 39.64457293919155, 40.8138609613691, 48.133902822222026, 50.295612471444265, 54.985656942640034, 50.930184500558035, 49.71948174067906, 46.40130696977888, 45.33825690405709, 45.52426018033709, 49.916015011923655, 49.040420395987375, 47.057046685900005, 52.83955989565168, 51.97401932307652, 53.066675662994385, 52.00561278206961, 50.038459641592844, 53.07572569165911, 51.94956166403634, 56.91958032335554, 58.371517590114046, 50.55638878686087, 2.416644266673497, 0.5091688239148685, 0.1198358525122915, 0.013248909381218255, 0.6299035996198654, 33.166437353406636, 59.33281476157052, 37.35855654307774, 38.85660205568586, 15.253409896578107, 29.528572491237096, 51.41263614382063, 45.656797068459646, 46.45133747373308, 13.617328865187508, 0.5117779267685754, 0.058741774010871134, 0.03144224746418851, 0.04144366704193609, 0.0661215955125434, 0.05526277569255658, 0.0636812714593751, 0.049693048133381774, 0.010928211051837673, 0.0743228786491922, 0.06502492007400308, 0.03706592195002096, 0.02829277967768056, 0.0225315780179309, 0.03225492546334863, 0.034158497782690186, 0.06124560894178493, 0.026360201682629328, 0.043376728493188105, 0.028104304701888135, 0.03529483359307051, 0.2756389193236828, 44.10042142868042, 72.92725712912423, 54.57468836648123, 55.321967124938965, 26.927736691066197, 29.899307523454937, 33.530856473105295, 41.644320079258506, 61.080627168927876, 64.25268132346017, 5.159278035163879, 0.10946546934012856, 0.20862452100430215, 3.1109922996589114, 1.7739619527544295, 4.048070873532977, 63.919139998299734, 63.62197249276297, 65.58142702920097, 57.03060906273978, 52.80553109305245, 48.11913442611694, 48.23848015921456, 48.48726040976388, 52.32307597569057, 47.27343443461827, 47.38153450829642, 42.37996407917568, 42.80815723964146, 40.42658574240548, 43.91540479660034, 40.85238872255598, 40.56959356580462, 41.25718035016741, 41.848659651620046, 40.944865771702354, 41.616537707192556, 41.20068107332502, 44.635008880070274, 43.06024135862078, 41.55042559759957, 40.95055634634835, 41.40327664784023, 41.28517116819109, 40.19004126957485, 40.29669959204537, 40.55158730915615, 39.50054720469883, 39.23200280325753, 39.916883264269146, 42.086722305842805, 39.69011490685599, 40.594461168561665, 40.2091383934021, 39.422463348933626, 40.77480513708932, 40.37347023827689, 39.32163803918021, 43.63677161080496, 41.292598792484824, 40.10057626451765, 41.28973960876465, 40.06774950027466, 40.78633567265102, 40.703398500170024, 42.15473127365112, 48.469747475215364, 51.51794304166521, 50.237970215933665, 51.93286861692156, 52.593531131744385, 51.90814692633492, 50.37157365253994, 53.814628396715435, 49.961153984069824, 52.26166084834507, 36.02681616374424, 25.41692907469613, 51.05434880937849, 48.1436893599374, 53.923558780125205, 50.27499369212559, 50.672861439841135, 49.79464040483747, 50.20569583347866, 48.973481450762065, 43.36457940510341, 38.07351575578962, 39.51820257731846, 38.36118507385254, 40.86720923015049, 37.02433776855469, 38.66818428039551, 38.504300594329834, 42.22098582131522, 41.29540239061628, 42.07718242917742, 38.271640164511545, 40.66270637512207, 40.7532240322658, 39.69298103877476, 38.95464808600289, 42.47320543016706, 40.1066837310791, 41.26044947760445, 38.038187640053884, 38.83235631670271, 38.22684512819563, 42.11949348449707, 39.281710215977256, 39.481898239680696, 38.660961627960205, 40.57931062153408, 41.16697188786098, 41.77919851030622, 39.31233440126692, 41.20923777988979, 42.45052303586687, 51.683265004839214, 52.69679178510393, 55.34475721631731, 52.533359731946675, 51.92756714139666, 48.07009751456124, 47.41607052939278, 48.27063642229353, 51.71282264164516, 51.86933428900582, 50.29976054600307, 55.05829341070992, 54.41486937659127, 54.38641650336129, 54.630506719861714, 52.247562953404014, 55.14613948549543, 53.40085274832589, 59.46617153712681, 60.36502524784633, 54.748688629695344, 2.90943244099617, 0.21960935156260217, 0.3862864305930478, 0.06098525505512953, 0.3737449864191668, 34.01589979444231, 64.96463544028146, 40.15821852002825, 29.328561646597727, 19.750073841639928, 33.74611166545323, 56.92731714248657, 52.84732103347778, 55.35111481802804, 23.888301065989904, 0.6567705465214593, 0.04359016168330397, 0.03682468918019107, 0.027170923804598193, 0.07012142374047212, 0.10638354971472706, 0.04147270494805915, 0.08968373760581017, 0.0461297689804009, 0.020761363274816955, 0.04240774316713214, 0.18850348783390863, 0.11295244044491223, 0.15266231819987297, 0.06374776110585247, 0.16808368212410382, 0.22452589417142527, 0.07637988469962563, 0.1837175360747746, 0.15317409645233834, 0.19311178555446012, 0.5879370772412845, 54.529080390930176, 83.59110219138009, 62.42769527435303, 63.264313970293315, 29.036530596869333, 44.41911097935268, 59.26331193106515, 50.403667381831575, 65.84009456634521, 68.29745701381138, 6.30869768347059, 0.2284744115812438, 0.3292556165584496, 5.18490559714181, 8.188030804906573, 5.104683433260236, 68.4258041381836, 65.53514507838658, 68.42148235866001, 59.40382535117013, 55.27831506729126, 50.02016156060355, 51.66353212084089, 50.5107912336077, 54.794095107487266, 49.082866941179546, 50.75401987348284, 44.783627373831614, 46.28534153529576, 41.7163416317531, 46.51478842326573, 43.173681122916086, 43.63975933619908, 42.35524238858904, 44.409011772700715, 42.18833276203701, 43.52945320946829, 43.96207584653582, 46.612740652901785, 44.73559100287301, 45.05883509772164, 43.03077752249581, 43.84698241097586, 45.06311171395438, 42.273500306265696, 43.474822998046875, 43.94912093026297, 41.75911126817976, 42.07877009255545, 41.36113234928676, 43.82498788833618, 40.87828465870449, 44.18100316183907, 42.39241872514997, 40.89613458088466, 41.76798759187971, 42.971141133989605, 41.60131767817906, 46.978337492261616, 42.836280073438374, 42.204511642456055, 42.996206760406494, 42.80785846710205, 42.3690310886928, 43.61926562445504, 44.45190647670201, 50.1351056098938, 54.0515376499721, 52.95804057802473, 52.49867779867989, 54.38263668332781, 55.10958848680769, 52.57702221189226, 56.25052091053554, 53.881609031132285, 53.50278976985386, 39.7266971724374, 27.836927584239415, 51.07812901905605, 49.38402966090611, 53.45259598323277, 51.199368136269705, 52.72508832386562, 52.02951111112322, 52.694220951625276, 51.13176563807896, 46.48714501517159, 41.991497244153706, 41.43523488725935, 41.64959723608834, 44.05955212456839, 39.786538532802034, 40.68970012664795, 40.09666442871094, 44.494856766292024, 43.1609902381897, 44.28801236833845, 39.18304927008492, 42.47799621309553, 43.40125894546509, 41.20589917046683, 39.43930925641741, 45.09988158089774, 43.25346728733608, 42.95433691569737, 40.76666184834072, 41.56161567143032, 39.89538206372942, 44.89422532490322, 39.70613745280674, 42.53636802945818, 41.51378774642944, 41.94165781566075, 42.68747050421578, 43.6469715663365, 42.86052581242153, 43.74981880187988, 45.7935654095241, 54.34470994131905, 53.73670782361712, 60.1988799231393, 54.98681034360613, 55.41291209629604, 50.959801197052, 49.655457564762656, 50.06912899017334, 54.84662001473563, 52.509374550410676, 52.70569590159825, 54.18066644668579, 57.31422063282558, 57.4152717590332, 57.45867715563093, 53.823727062770296, 57.89362049102783, 56.52772624152047, 63.189092772347585, 63.51003006526402, 56.054512228284565, 2.7736889592238834, 2.8930768157754625, 0.528192720242909, 0.13865797966718674, 0.8735814839601517, 41.16554750714983, 68.20950671604702, 51.71519545146397, 51.062783922467915, 24.615933792931692, 38.89739145551409, 64.74084786006382, 60.43957247052874, 67.6659630366734, 31.55095338821411, 1.328728660941124, 0.11146961751260928, 0.1397378138665642, 0.105447490300451, 0.14315864816308022, 0.18004301110548632, 0.19188203582806246, 0.16242358727114542, 0.17110593137996538, 0.16900495626032352, 0.16019480329539093], [0.08098142421139137, 0.052911909696246893, 0.09861916170588561, 0.04632292415148445, 0.0389683984353074, 0.045111522011991055, 0.04140832893816488, 0.034485704332057915, 0.1188062841870955, 0.12137642556003161, 1.3148775356156486, 51.776461192539756, 60.394610677446636, 40.947756222316194, 25.206280538014003, 16.27135920524597, 54.008351121629985, 49.69162293842861, 40.868369579315186, 61.33282593318394, 43.19892392839704, 0.7710804098418781, 0.0675903931260109, 0.2039839792996645, 1.7783367122922624, 1.7012319011347634, 18.158015727996826, 75.28578839983258, 55.21274144308907, 64.32069723946708, 51.07396009990147, 49.98319714409964, 42.342204093933105, 44.506237915584016, 44.84800590787615, 48.07001066207886, 42.018258231026785, 43.878301416124614, 40.87307003566197, 40.93301909310477, 38.88369655609131, 41.06622648239136, 39.3962755884443, 40.02061986923218, 38.932726519448416, 39.68039090292794, 38.46518918446132, 40.368623869759695, 39.7924861907959, 41.39049891063145, 41.48677315030779, 42.468918391636436, 38.997886725834434, 38.736200196402415, 38.48036057608468, 39.405113697052, 39.04051392418997, 37.62915761130196, 37.819889136723106, 38.29934958049229, 38.86375175203596, 38.33156490325928, 37.66643469674246, 37.92392104012625, 38.03016594478062, 38.05097579956055, 36.901771545410156, 39.58998441696167, 38.11007717677525, 38.76474339621407, 39.87166786193848, 39.53205381120954, 39.83363342285156, 38.407939502171104, 38.26507411684309, 38.23037828717913, 40.20589705875942, 47.38472720554897, 49.470979418073384, 46.65933527265276, 48.666909558432444, 46.91450786590576, 48.94113063812256, 47.12008769171578, 51.6172536441258, 47.53917176382882, 53.856414863041465, 35.54618147441319, 22.71682436125619, 54.44293662479946, 47.22406053543091, 50.50462818145752, 47.420951638902935, 49.442415373665945, 47.9369352885655, 50.51169102532523, 47.11099597385952, 41.51806436266218, 37.03952653067452, 38.79341513769967, 37.85346630641392, 36.98289523805891, 36.27361617769514, 38.699711731501985, 38.059000968933105, 38.15642166137695, 38.15182195390974, 39.815509046827046, 35.715220723833355, 38.398173809051514, 39.37576103210449, 39.426871980939595, 38.30083302089146, 38.18473904473441, 37.06874370574951, 37.96306371688843, 37.415715898786274, 38.26291670118059, 37.009319237300325, 38.41357796532767, 35.72223493031093, 37.66224840709141, 38.36831045150757, 38.93333796092442, 37.65421976361956, 38.6921694619315, 39.01091112409319, 40.227134227752686, 38.529039655412944, 39.85928617204939, 42.1801894732884, 44.386485712868826, 42.64864049639021, 42.935562883104595, 40.48461709703718, 43.57946286882673, 45.55393941061837, 47.20641558510916, 50.80788925715855, 49.25307348796299, 48.96562303815569, 55.97242621013096, 49.291594300951274, 52.95819691249302, 48.79336677278791, 51.56307506561279, 49.05418130329677, 55.75176531927926, 54.276857307979036, 63.567241532461985, 17.978380475725444, 1.096599008355822, 0.37982699434672085, 0.12493971149836268, 0.1142703318702323, 20.20019030570984, 63.40554305485317, 44.72204201562064, 55.48633371080671, 20.9891026701246, 17.223580292293004, 40.577240058353965, 45.51821524756295, 43.261284010750906, 27.856827225003922, 2.2594100066593716, 0.15228475417409623, 0.01180299960209855, 0.049315996401544125, 0.07280306198767253, 0.037905676889100244, 0.036589318952922306, 0.03181223225380693, 0.055156204982527664, 0.022789848802079047, 0.008618811178686363, 0.07023853888469082, 0.05235979253692286, 0.0169339321354138, 0.06304355710744858, 0.016318980937025378, 0.015326430089771748, 0.010434947475524885, 0.02956047308232103, 0.09560094973338501, 0.24442885975752557, 2.982404811041696, 64.56960255759103, 65.37680258069719, 47.89971031461443, 34.90108987263271, 27.171755688531057, 47.256856032780235, 44.342232636043, 45.798255443573, 66.2351621900286, 46.171682902744834, 0.7051148638129234, 0.023097805312967727, 0.6578448574457849, 3.287535169294902, 1.279804983309337, 19.820368766784668, 78.12678173610142, 57.68535171236311, 66.67560155051095, 50.78919860294887, 51.56588561194283, 45.51835421153477, 47.980722836085725, 46.79689918245588, 50.58275372641427, 44.49347060067313, 45.535269601004465, 44.25881256375994, 43.4860269682748, 40.435166767665315, 42.920454025268555, 40.466089725494385, 41.85219281060355, 40.22848565237862, 40.772866589682444, 39.83369943073818, 43.113808495657786, 40.67944458552769, 42.64373854228428, 41.42650100163051, 43.68973772866385, 42.06995977674212, 41.09468630381993, 39.956543581826345, 41.510341439928325, 40.00359330858503, 39.648092201777864, 39.97733606610979, 40.47426775523594, 39.17521865027291, 40.38897514343262, 40.5905111176627, 40.44069058554513, 39.25306279318673, 39.203230312892366, 39.83304282597133, 40.620544706072124, 40.81548683983939, 41.63920620509556, 41.7226471219744, 40.702404907771516, 41.152662072862896, 40.809869221278596, 39.457760197775706, 38.867295333317344, 41.253678458077566, 48.936444078172954, 49.4761176109314, 50.95735543114798, 49.09055164882115, 49.03796420778547, 50.0184314591544, 49.74549579620361, 53.31358337402344, 51.105435439518516, 54.53206811632429, 37.48154660633632, 23.968066385814122, 56.86160455431257, 49.36168425423758, 52.526602608816965, 48.437782287597656, 52.524577208927695, 49.72133343560355, 52.18450457709176, 47.91192524773734, 41.158811228615896, 38.67121022088187, 40.41462441853115, 39.746304988861084, 38.02785914284842, 38.9544882774353, 39.11630140032087, 38.28137806483677, 39.707221371786936, 40.411466462271555, 42.53858797890799, 37.785665784563335, 40.1348100389753, 41.40985311780657, 40.6018887928554, 40.5977372441973, 39.51258495875767, 39.206867694854736, 41.29330056054251, 39.80474976130894, 39.94833081109183, 39.35508666719709, 40.037629059382844, 37.26894562585013, 39.362274578639436, 39.3742220061166, 41.64474391937256, 39.31489828654698, 39.47764941624233, 41.22325577054705, 42.229431356702534, 40.42322628838675, 42.01597227369036, 44.34533500671387, 46.59553691319057, 44.23731483731951, 46.29006283623831, 42.76360191617693, 46.11516972950527, 48.016235079084126, 50.175558022090364, 52.243946416037424, 52.487977572849815, 51.1430356161935, 58.05134807314192, 52.723976612091064, 55.32289123535156, 50.61444446018764, 54.2569020816258, 51.74812296458653, 58.773616790771484, 56.11546530042376, 66.23910181862968, 20.29580967766898, 0.6571104111416, 0.49430510721036364, 0.17398823957358087, 0.10161208467824118, 20.449234587805613, 69.49857125963483, 48.92693894250052, 46.0710243497576, 22.974204744611466, 25.924422025680542, 45.47978128705706, 51.851477418627056, 51.780911513737266, 41.47014263698033, 3.248193166085652, 0.1177179818706853, 0.07870064409715788, 0.06123096615608249, 0.04463726674605693, 0.024009135518489138, 0.05566897389612027, 0.05283038032108119, 0.06069512026650565, 0.0013189530145609751, 0.021962385524862578, 0.28674450197390144, 0.16513016846563133, 0.17704136217279093, 0.12220114416309766, 0.11207375795181308, 0.09203862731478044, 0.09418640099465847, 0.22206088501427854, 0.2291845663317612, 0.4065724291971752, 5.020330131053925, 75.77879088265556, 71.69974667685372, 57.36503628322056, 36.8443238394601, 25.988312448774064, 63.38280854906355, 62.623703956604004, 54.011078289576936, 71.0140220097133, 52.07159982408796, 1.0141277994428362, 0.08780144075197832, 0.7757784234625953, 8.495290568896703, 4.645494358880179, 20.463533980505808, 79.98815550122941, 60.1424674987793, 68.77809170314244, 53.41003826686314, 52.89700412750244, 48.88907126017979, 50.15320566722325, 49.40289749417986, 54.85982159205845, 46.98037678854806, 47.68759570802961, 44.911595821380615, 45.359038966042654, 43.179055554526194, 45.5184897014073, 43.331109932490754, 43.28797551563808, 42.47401489530291, 43.36416251318795, 40.22597387858799, 44.06043801988874, 44.035434927259175, 44.324684960501536, 43.71674190248762, 46.32152080535889, 43.57904945101057, 42.16030372892107, 41.34715257372175, 43.95422438212803, 44.38367516653878, 42.42969233649117, 41.10176999228341, 43.2441532271249, 42.330722195761545, 43.267388003213064, 42.51624257223946, 42.610401085444856, 40.37916776112148, 41.91691180637905, 40.147170884268625, 42.52740485327584, 42.65076664515904, 42.853000913347515, 44.42117806843349, 43.251969950539724, 44.40342194693429, 44.03988177435738, 42.025710174015586, 40.80052389417376, 44.22745534351894, 50.47727312360491, 52.98701804024832, 51.94328396660941, 50.480889660971506, 51.10012354169573, 53.836136545453755, 52.07753011158535, 57.04754182270595, 55.37948431287493, 56.86553723471505, 39.69020523343767, 28.214459691728862, 58.342328207833425, 52.740568910326274, 55.05444410869053, 51.353687626974924, 54.65809454236712, 52.972239221845356, 55.28639234815325, 51.52488776615688, 44.56103835787092, 40.540206159864155, 42.89473874228341, 41.007715702056885, 39.999521664210725, 41.87185621261597, 42.667126178741455, 41.267345564705984, 41.715195178985596, 42.0241641998291, 44.583192689078196, 39.24819558007376, 42.1542101587568, 45.16336032322475, 43.29874522345406, 41.97876814433506, 41.80879088810512, 40.41541303907122, 44.117097105298726, 40.974280970437185, 43.40572663715908, 41.00085783004761, 42.686386585235596, 40.51844440187727, 41.47100073950631, 44.243012360164094, 43.90284245354788, 41.70600618634905, 42.46330772127424, 43.60032830919538, 45.392501490456716, 40.91165338243757, 43.587321281433105, 46.610503332955496, 49.08529533658709, 47.49954618726458, 48.9902092388698, 44.10288803918021, 47.823676177433555, 50.382788045065745, 52.332167693546836, 54.207872118268696, 57.219283921378, 54.359419277736116, 58.22432695116316, 54.54179212025234, 58.03722585950579, 53.54842553819929, 57.35684435708182, 55.40334790093558, 62.46972492762974, 59.202049664088655, 67.74550601414272, 21.28741315432957, 2.3077405904020583, 1.743224859237671, 0.28956978608454975, 0.27177403814026285, 24.246524129595073, 74.61322362082345, 57.274143423352925, 70.77667849404472, 31.00725337437221, 29.08857434136527, 53.149991512298584, 60.842380387442454, 60.78784397670201, 52.856478759220664, 4.037960376058306, 0.24794624958719524, 0.1417140606790781, 0.06870067319167511, 0.10552408333335604, 0.10639679471829108, 0.16314382505203995, 0.15579820850065776, 0.21960023205195153, 0.09448244582329478, 0.09268060286662408], [0.0643546496118818, 0.02004905926462795, 0.03272188308515719, 0.03298117167183331, 0.030863925282444273, 0.074203090077, 0.06411259581467935, 0.087052175242986, 0.10801379116518156, 0.08941363995628697, 4.194677863802228, 61.244806153433665, 50.53898007529122, 49.430676392146516, 24.837782825742448, 14.668965646198817, 54.838438510894775, 43.42947905404227, 43.107881682259695, 65.9941986628941, 28.24124673434666, 0.052227030375174115, 0.01386043312959373, 0.061986759171954224, 1.256859968815531, 0.4031326637736389, 41.08349970408848, 66.39392852783203, 58.26015533719744, 58.01489782333374, 50.79551451546805, 51.612539291381836, 46.477931703839985, 48.36992270605904, 42.94613456726074, 46.350803988320486, 44.12402098519461, 41.998775482177734, 41.963864258357454, 41.26544175829206, 39.972646032060894, 39.65347705568586, 39.70337206976754, 40.21168490818569, 40.37229946681431, 38.937124729156494, 36.875298908778596, 38.04310001645769, 39.43473039354597, 38.43266119275774, 36.781710147857666, 39.91440970557076, 38.41354322433472, 39.347919600350515, 39.34158631733486, 38.71231228964669, 38.77306386402675, 36.63103151321411, 37.79757152284895, 37.45932279314314, 38.20148072923933, 37.16379853657314, 38.62165914263044, 36.56522512435913, 37.1676686831883, 37.88828025545393, 37.34979486465454, 39.542326722826274, 39.02300793784005, 38.010380949292866, 40.533963203430176, 39.667842456272666, 37.90612322943551, 37.332688399723594, 37.01554829733712, 37.24156972340175, 40.361627033778596, 44.71625764029366, 47.29535252707345, 48.12091663905552, 49.61064863204956, 46.86187526157924, 45.7431458064488, 45.637793745313374, 49.61186804090227, 47.88137749263218, 51.51763732092721, 45.17812524523054, 31.05527584893363, 53.34978001458304, 45.20769330433437, 49.03758553096226, 47.55109487261091, 50.45697743552071, 48.80710336140224, 48.80457421711513, 43.79956095559256, 37.22375454221453, 37.20900699070522, 37.195666449410574, 38.561807359967915, 37.48634433746338, 37.13868079866682, 38.93754856927054, 38.01962552751814, 39.54093360900879, 38.06579283305577, 38.584899697984966, 38.244198254176546, 38.46976457323347, 38.402155126844136, 38.68605504717146, 37.73952627182007, 38.447575501033235, 36.36674983160836, 37.70063720430647, 37.49382059914725, 38.307312216077534, 38.244601249694824, 38.80816616330828, 35.27337782723563, 40.00363499777657, 36.261196272713796, 34.88503605978829, 36.50799628666469, 37.86828333990914, 39.027465207236155, 39.76116371154785, 39.086316449301584, 39.46253708430699, 38.418334007263184, 37.18628985541207, 38.71806192398071, 39.474790232522146, 42.488032885960166, 43.0951942716326, 44.44234922954014, 46.362928594861714, 47.56319516045706, 50.78839956011091, 44.320078304835725, 49.0453953061785, 55.2564560345241, 51.76177964891706, 51.200243609292166, 50.50719206673758, 48.875588280814036, 50.93694509778704, 57.22434915815081, 62.90005465916225, 43.284487519945415, 0.7803429013916424, 0.46943023055791855, 0.3120047593755381, 0.04352213515500937, 7.290602343423026, 51.775457177843364, 51.63140017645699, 39.469634669167654, 29.94279282433646, 15.97117097037179, 36.17583417892456, 51.39891345160348, 47.49050310679844, 38.156241008213584, 6.038171308381217, 0.18860555307141372, 0.039689260468419106, 0.08118050638586283, 0.06272274575063161, 0.020634660430784737, 0.042146317195147276, 0.08289838741932597, 0.016501194730933224, 0.025601496055190052, 0.016761080428425754, 0.023594832214127694, 0.04164650830041085, 0.05349784164822527, 0.024749519004087363, 0.0513829192412751, 0.11389857610421521, 0.04137205106339284, 0.015108481249106782, 0.15401922538876534, 0.030829211430890218, 6.8637284721646985, 70.88293034689767, 55.53436313356672, 55.79715095247541, 26.837481328419276, 20.909816776003154, 53.88145269666399, 45.53839976446969, 47.298051902226035, 71.92099816458565, 30.001619747706822, 0.039854843369019885, 0.0490895455170955, 1.543550567967551, 2.74871735061918, 0.5126560053655079, 44.30532727922712, 69.20193876538957, 60.525570324489046, 60.63740158081055, 52.70078352519444, 53.453888348170686, 48.36971426010132, 49.49446432931082, 44.70905583245413, 48.12817055838448, 46.60715082713536, 45.88247455869402, 43.23998083387102, 43.18668120247977, 41.923397949763704, 41.26968363353184, 41.82352106911795, 44.28724806649344, 41.80103669847761, 40.596698488507954, 39.54531444822039, 38.46354940959385, 40.988139152526855, 40.55097586768014, 39.63157285962786, 41.80409390585763, 39.91005318505423, 41.48347970417568, 42.3411340713501, 39.70781544276646, 40.49622753688267, 38.519385133470806, 39.77905879701887, 38.80336843218122, 40.47785997390747, 40.43158497129168, 40.13101632254464, 39.13244901384626, 40.601791518075125, 40.051574093954905, 39.85974475315639, 41.0705760547093, 39.999778747558594, 39.62972811290196, 42.012341839926584, 39.885387080056326, 40.14140387943813, 40.06217009680611, 38.815545150211875, 39.31340789794922, 41.802926608494346, 46.720274448394775, 50.96992472239903, 49.69427020209176, 48.996935095105854, 49.98732437406267, 47.362777846200125, 49.29004832676479, 50.23716075079781, 49.50152022497994, 52.80463130133492, 47.56248297010149, 32.928301743098665, 54.69918271473476, 46.67889445168631, 51.42760951178414, 49.90394599097115, 51.7389235496521, 51.098858969552175, 51.093380314963206, 46.25599234444754, 40.27973209108625, 40.00802625928606, 40.17714193889073, 39.83027049473354, 40.64835139683315, 37.87781626837594, 40.711253438677105, 38.81235245295933, 41.106185572487966, 39.84513963971819, 40.50124761036464, 39.775289399283274, 40.967402253832134, 41.914327076503206, 40.89013481140137, 39.77254833493914, 39.476367473602295, 38.663789544786724, 38.84323719569615, 39.81059667042324, 39.883448532649446, 40.075343881334575, 40.78475843157087, 37.75541680199759, 40.64384201594761, 39.50125592095511, 37.29791613987514, 39.397064208984375, 40.158354009900776, 41.06305462973458, 42.9391689981733, 40.02892296654837, 40.507431507110596, 40.42590134484427, 40.101920740945, 41.46556030000959, 40.93062891278948, 44.7023160798209, 44.981630189078196, 46.81065314156668, 49.12946503502982, 49.94413784572056, 52.95096731185913, 46.1595652444022, 51.37572731290545, 55.725455965314595, 55.11752332959856, 52.739676066807334, 52.028889247349326, 51.217881611415315, 52.783112730298726, 57.83702046530587, 64.46083545684814, 48.07517317363194, 1.0428746683256966, 1.0434614654098238, 0.5174073246972901, 0.06714858540466853, 7.144482595579965, 54.85845627103533, 58.54705687931606, 42.679045813424246, 31.966858659471782, 24.378774404525757, 43.18165765489851, 59.15946415492466, 52.718265192849294, 53.71378571646554, 9.172840680394854, 0.2872577730034079, 0.09188339207321405, 0.009826999606697686, 0.05930315317319972, 0.07655006128230266, 0.06368444700326238, 0.05702432045446975, 0.008152073232590087, 0.0700983399791377, 0.01905343126106475, 0.1050560570188931, 0.1771738122084311, 0.15093166035200867, 0.0799835773983172, 0.11575609285916601, 0.22074037444378647, 0.16235333175531455, 0.13225441399429524, 0.25762112757989336, 0.2529835035758359, 11.291250024523054, 83.92699895586286, 62.601580892290386, 66.33893353598458, 32.46815729141235, 23.14510611125401, 65.40267767224992, 55.589966092790874, 52.008110659463064, 77.65865380423409, 34.332001141139436, 0.15330343879759312, 0.13745404141289846, 1.8998505004814692, 8.35457478250776, 1.770003759435245, 47.66818591526577, 71.6863852909633, 62.00461251395089, 63.48446069444929, 54.892624037606375, 56.51996162959507, 50.570747239249094, 53.51419871194022, 46.62747778211321, 50.797362736293245, 48.33220441000802, 47.68474347250802, 48.15620306559971, 46.64305911745344, 45.59676810673305, 43.9769206728254, 44.846671853746685, 46.76746661322457, 44.35001809256417, 43.11253350121634, 40.958254950387136, 40.38549062183925, 42.37503433227539, 42.75872080666678, 40.94832250050136, 44.033548491341726, 43.36085169655936, 43.45157432556152, 44.773722716740195, 42.25586577824184, 42.734124183654785, 41.423721722194124, 41.95995937074934, 42.45210027694702, 42.82767472948347, 41.476503712790354, 42.536663327898296, 40.46825408935547, 42.0768141746521, 42.42547477994646, 42.24898011343819, 43.82333074297224, 42.41221414293562, 42.49611364092146, 45.89190673828125, 43.100401946476524, 41.908702509743826, 41.92491265705654, 40.50357525689261, 41.86242403302874, 44.57159267153059, 49.29105234146118, 53.0761147907802, 52.598728384290425, 52.892366204942974, 51.89246136801583, 50.28525618144444, 51.258049147469656, 52.5826016153608, 52.0768735068185, 56.346795150211875, 48.69750247682844, 35.32262665884835, 55.776271615709575, 48.60311119897025, 53.749096461704795, 52.34248576845442, 54.19330174582345, 53.85399341583252, 54.047591073172434, 49.15903309413365, 42.70951019014631, 41.82028668267386, 41.411176749638145, 43.759664399283274, 42.28757735661098, 41.253223351069856, 43.11343329293387, 42.29884386062622, 44.22999838420323, 42.09060982295445, 42.04807989937918, 42.464426381247385, 43.208606243133545, 43.78775596618652, 43.22817931856428, 42.832163265773225, 41.19524758202689, 40.59462792532784, 42.39392301014492, 42.85879571097237, 42.26922369003296, 43.01930257252285, 44.15901211329869, 39.359703745160786, 44.39451783043997, 41.96841532843453, 38.639762674059185, 41.326224599565776, 42.5344364302499, 43.06442764827183, 43.6175285748073, 43.11875908715384, 43.371861117226736, 42.67619705200195, 42.02136754989624, 44.52344512939453, 43.56175538471767, 49.40167808532715, 47.266864912850515, 49.72533907209124, 50.68734148570469, 53.57158388410296, 54.71558393750872, 49.87000751495361, 54.19400003978184, 58.22436169215611, 56.81677825110299, 56.445060048784526, 54.45256335394723, 55.273190770830425, 56.42911393301827, 61.40023735591343, 67.34633200509208, 48.44837829044887, 1.0270322327102934, 3.695566177368164, 0.8932608993990081, 0.13818867770688875, 9.30613579068865, 62.85102122170584, 62.59021363939558, 55.95129326411656, 41.0245372908456, 25.427669252668107, 49.88914980207171, 64.97849709647042, 62.11208724975586, 68.07782445635114, 12.912276915141515, 0.4220509800527777, 0.2940509670547077, 0.16426874111805642, 0.1783867206956659, 0.12029252015054226, 0.19852882916373865, 0.16637825220823288, 0.1101478584376829, 0.1820537139262472, 0.1796419969094651], [0.06464118816490684, 0.05258806189522147, 0.05130944746945586, 0.086659283111138, 0.018844734245379056, 0.009287677921487816, 0.026950913913814083, 0.03934812359511852, 0.10669423054371562, 0.17659166987453187, 8.371239168303353, 59.61272989000593, 53.45635148457119, 45.324541160038535, 33.43595797674996, 27.92671046938215, 42.11879519053868, 51.617434297289165, 46.91035631724766, 67.38241400037492, 11.847976173673358, 0.10288855832602296, 0.030393748011972224, 0.8358384892344475, 0.914580089705331, 1.4518691961254393, 59.54353278023856, 62.08666379111153, 59.904658453805105, 56.63603476115635, 57.14420516150338, 53.57238987513951, 51.83581965310233, 46.721337522779194, 46.950370992933, 44.917220388139995, 42.7102084841047, 43.272654737745015, 41.71994774682181, 39.99806601660592, 38.98190934317452, 37.269018581935335, 40.73620094571795, 39.56069081170218, 40.31150272914341, 37.11023834773472, 40.254940918513704, 39.35831063134329, 39.24296358653477, 39.75034884044102, 38.60948937279837, 39.09895174843924, 40.503794125148225, 39.59224258150373, 38.862914494105745, 37.367516245160786, 37.996314321245464, 38.63310629980904, 38.920865944453645, 37.42280306134905, 37.221503325871055, 38.42640781402588, 39.18892049789429, 38.76631716319493, 37.36095019749233, 37.73131002698626, 37.38022450038365, 39.255359172821045, 38.90159511566162, 38.34180307388306, 38.02510418210711, 38.52195596694946, 37.61784594399588, 38.51798507145473, 37.119674001421245, 37.99287148884365, 37.61019597734724, 43.1871988432748, 47.62345341273716, 45.259902068546836, 47.13023553575788, 46.379420144217356, 44.490920611790244, 44.093504496983115, 47.191119125911165, 49.326866831098286, 49.81826080594744, 48.951382705143516, 36.960390022822786, 50.6624321937561, 46.946101324898855, 44.59606422696795, 43.059150491442, 42.70738404137747, 43.25281763076782, 40.75673287255423, 38.505450521196636, 37.53348439080374, 38.68343905040196, 37.54111351285662, 38.141396181924, 37.254580225263325, 36.659272466387065, 38.37310470853533, 37.79228741782052, 38.91971601758684, 37.58137484959194, 38.27612175260271, 37.79400709697178, 37.23408651351929, 37.83252443586077, 37.322464125497, 37.846472944532124, 37.44524574279785, 38.54041385650635, 36.84227064677647, 36.95266362598964, 36.66258675711495, 36.256245681217735, 36.06130007335118, 37.49070085797991, 36.41587706974575, 37.23058114733015, 36.54069103513445, 37.24154887880598, 38.16545779364449, 38.63273804528372, 37.52645281382969, 38.02759511130196, 37.475922039576936, 39.08691052028111, 38.28101675851004, 39.52360480172293, 40.70811285291399, 40.83306578227452, 41.09772614070347, 41.899277278355186, 44.04507555280413, 46.67559405735561, 48.1434565952846, 53.13834980555943, 45.96413673673357, 47.78571122033255, 48.51546662194388, 52.33213642665318, 51.61556870596749, 48.8408716065543, 49.52004412242344, 57.259788445064, 56.21624197278704, 59.577884674072266, 7.167737782001495, 0.7056222451584679, 0.2585986251277583, 0.012053408709886883, 0.950737755213465, 37.39925561632429, 58.92252363477434, 41.390564918518066, 29.241820335388184, 14.548767021724156, 40.97048377990723, 40.99927364076887, 41.07099642072405, 45.34580612182617, 13.346331749643598, 0.45130840582507, 0.1444411879139287, 0.028060919172795754, 0.05300549663869398, 0.03341676401240485, 0.09352015424519777, 0.1203425010400159, 0.023311606608331203, 0.050459293981215785, 0.022460150332855325, 0.05173947582287448, 0.04874705157375761, 0.08269346984369413, 0.00876758252603135, 0.013828685324239944, 0.02321215033797281, 0.1098184771835804, 0.06334621086716652, 0.13546981502856525, 0.19820341733949526, 13.596110803740364, 70.3357458114624, 58.07527419498989, 52.75452436719622, 32.76375797816685, 28.746594429016113, 45.77875879832676, 53.604056290217805, 52.18905912126814, 71.80279541015625, 13.839067595345632, 0.1579011378011533, 0.013524380179920366, 1.6639628495488847, 2.733243929488318, 1.6242214334862572, 61.897658893040244, 64.5844578061785, 62.21455928257534, 59.74818502153669, 59.31946727207729, 56.68984855924334, 54.92804247992379, 49.2250930922372, 48.47691106796265, 47.20856952667236, 45.33705486570086, 44.87096970421927, 44.01924215044294, 42.12376662663051, 40.79400995799473, 39.61789533070156, 41.978545801980154, 40.791449546813965, 40.86849464688982, 39.08958210263933, 41.65743480409895, 41.74289069856916, 41.13114350182669, 41.04118170057024, 41.65989099230085, 40.73978621619088, 41.889157227107454, 40.530773980276926, 41.19007117407662, 38.96789135251726, 39.210296630859375, 39.99229553767613, 39.96156712940761, 38.44326066970825, 39.6482172693525, 40.12696552276611, 39.76340797969273, 40.58370883124215, 39.877660683223176, 40.26177099772862, 38.848757539476665, 40.54050145830427, 40.72219337735857, 39.71420431137085, 39.36226415634155, 40.092443398066926, 40.49107892172677, 40.01115642275129, 39.01822410311018, 40.84298433576311, 39.833369391305105, 45.77128253664289, 50.54428849901472, 47.3121463230678, 48.851936612810405, 47.082411084856304, 45.64404017584664, 45.30963032586234, 50.154713426317485, 50.2036634853908, 53.678172724587576, 50.28570434025356, 40.02623053959438, 53.84704869134085, 49.26459360122681, 46.49443367549351, 45.02694981438773, 43.09039306640625, 45.12931415012905, 43.64392130715506, 39.31735447474888, 38.825373377118794, 41.882285458701, 41.05599525996617, 40.15790237699236, 39.53678206035069, 39.228827476501465, 39.594344411577495, 38.86082656042916, 41.072490283421104, 40.32715354646955, 40.20915228979928, 39.696114676339285, 39.824409689222065, 40.51925386701311, 39.13665962219238, 39.6087132862636, 38.20465953009469, 40.32045200892857, 39.465920857020784, 39.055025236947195, 38.920865944453645, 38.93901463917324, 37.524052211216514, 40.01602016176496, 39.23888151986258, 38.235384464263916, 38.21488380432129, 39.372874055589946, 40.88583040237427, 40.64821590696062, 40.31375741958618, 40.48881728308541, 39.18003027779715, 40.11286415372576, 39.60708393369402, 41.51895720618111, 43.177391460963655, 42.38324710300991, 42.21478802817208, 44.29037822995867, 46.649778025490896, 50.381457465035574, 50.29958684103829, 54.84185355050223, 48.27633394513811, 51.07271984645298, 51.0032274382455, 56.01913547515869, 51.41808353151594, 51.21661703927176, 51.53387873513358, 59.108957699366975, 59.10296140398298, 62.34689467293875, 8.52745725427355, 0.7734237983822823, 0.4033306874334812, 0.056360638567379544, 0.6453227379492351, 40.811015674046104, 63.423941884722026, 46.01718275887625, 27.376112631389073, 20.893667425428117, 49.19261373792376, 48.48530796595982, 49.470962047576904, 55.47478233064924, 21.067592995507376, 0.841242179274559, 0.11219829626913581, 0.07027953597051756, 0.03576660881351147, 0.04154318438044616, 0.08445930973227535, 0.02345271305447178, 0.0059529874623487035, 0.0597155803282346, 0.04035384819975921, 0.183262293360063, 0.11403687511171613, 0.14654368295201234, 0.20060301572084427, 0.12361978446798665, 0.07663967540221554, 0.2645320067448275, 0.206037131271192, 0.3697213280413832, 0.41387227177619934, 19.51311595099313, 82.33716079166958, 66.45621218000139, 62.48201629093715, 43.75096525464739, 40.68839733941214, 51.11693123408726, 66.16447816576276, 56.34956053325108, 79.34505803244454, 14.432697364262172, 0.3024814932474068, 0.11684453088257994, 4.5927536232130866, 9.216191359928676, 1.5718938985041209, 66.30067675454276, 64.29484299251011, 65.63428892408098, 61.807638032095774, 61.47528484889439, 57.81868069512503, 58.16196686880929, 50.864954812186106, 51.74457243510655, 49.776974609919954, 47.52067913327898, 48.60512965066092, 47.063546725681846, 44.443363666534424, 42.94909102576119, 42.34685591288975, 45.08367143358503, 44.60166794913155, 44.60056318555559, 39.98372493471418, 43.574654715401785, 44.57862424850464, 43.39489786965506, 43.91807637895857, 42.248691763196675, 42.433805670057026, 43.57757643290928, 42.46116420200893, 42.35966491699219, 42.3310626574925, 40.87159701756069, 41.9636731828962, 43.04433693204607, 40.73084388460432, 40.83610214505877, 42.75656339100429, 43.72923823765346, 42.2427510534014, 42.30867208753313, 42.339313643319265, 40.17241368974958, 44.73139081682478, 43.48414053235735, 43.396746090480256, 41.64951385770525, 42.71073654719761, 43.324748856680735, 43.07291834694998, 41.03200313023159, 43.04964188167027, 42.003302233559744, 47.80440534864153, 52.730924810682026, 48.88193198612758, 52.48327711650303, 49.28846066338675, 48.53786414010184, 48.072324412209646, 51.341135706220356, 52.5264949117388, 56.46511949811663, 52.66873148509434, 41.48053714207241, 57.14719636099679, 50.729499680655344, 50.203163215092246, 47.334703649793354, 46.16109037399292, 47.598151547568186, 45.33545330592564, 42.62538487570626, 40.65388216291155, 44.2842047555106, 42.15079511914934, 41.88313661302839, 42.58933067321777, 41.3913813318525, 43.81575720650809, 41.30102000917707, 43.84623895372663, 41.69190829140799, 42.34730754579817, 41.18836191722325, 41.003213269369944, 42.80737556729998, 41.293106010981965, 41.435950551714214, 40.161320890699116, 44.60230023520333, 41.523709774017334, 41.30818360192435, 40.699531827654155, 40.99926321847098, 39.60996396200997, 42.050115721566335, 41.646446228027344, 42.14976678575788, 40.194592339651926, 42.1192433493478, 42.50410406930106, 43.11069222858974, 42.09416730063302, 42.2648081098284, 42.03547586713518, 44.01546927860805, 41.99505124773298, 45.452773639133994, 46.19153390611921, 45.87175348826817, 45.30971717834473, 45.97769962038313, 48.682080950055806, 51.82277093614851, 53.11163745607649, 56.97384922845023, 51.962165696280344, 54.55755410875593, 53.28419944218227, 58.294684410095215, 56.50646127973284, 54.87805713926043, 53.45638622556414, 61.25367900303432, 60.878233092171804, 64.91628987448556, 9.318286452974592, 2.0240690921034132, 1.6530154198408127, 0.14737091213464737, 1.7928292432001658, 46.991070066179546, 69.42089734758649, 55.63685948508126, 39.78985629762922, 21.604195424488612, 51.09090328216553, 58.5530184337071, 57.27864933013916, 67.85552379063198, 28.43982972417559, 0.9332284033298492, 0.37409497478178566, 0.15767386928200722, 0.17291346724544251, 0.1668063263807978, 0.2566564679145813, 0.19653952733746596, 0.24537479185632297, 0.2160667609423399, 0.14983395354024], [0.07529574858822993, 0.060553231808756075, 0.0608677938580513, 0.0639229995597686, 0.016654263749452572, 0.10755905735173396, 0.02448954000802977, 0.03937095290582095, 0.04596520048965301, 0.1586341048989977, 15.296747548239571, 59.26114409310477, 43.94840179170881, 39.076154708862305, 19.006170170647756, 23.95606337274824, 38.71777357373919, 44.60084458759853, 55.02929162979126, 57.17231062480381, 3.963039253439222, 0.058700715856892724, 0.10715633324746575, 1.1565235299723489, 2.763325721025467, 8.675320999962942, 71.77874769483293, 55.823717389787944, 62.732207025800435, 55.716843673161094, 59.31304713657924, 52.14227342605591, 55.49707909992763, 50.340838296072825, 48.83722727639334, 44.85084772109985, 45.37933465412685, 40.62818425042288, 41.13871356419155, 38.28000579561506, 39.75906188147408, 39.59524767739432, 39.67339754104614, 39.33232089451381, 39.58080932072231, 40.19958462033953, 39.22581543241228, 39.81314665930611, 38.095840317862375, 40.130884306771414, 38.933994565691265, 38.41874395098005, 39.15711511884417, 39.136256626674104, 37.80018057141985, 37.24547461100987, 37.000213623046875, 37.4293725831168, 37.07628597532, 36.54233775820051, 36.71938828059605, 36.165092263902935, 38.2384694644383, 37.05621610369001, 37.93050793239048, 38.320861203329905, 38.000886235918315, 37.663332326071604, 38.241318225860596, 37.58077730451311, 38.13112327030727, 38.82257325308663, 37.80161884852818, 36.85463496616909, 36.71236365182059, 35.16151877811977, 38.43405778067452, 40.63869687489101, 45.01962988717215, 46.807825224740164, 46.354722772325786, 44.00727040427071, 43.183464186532156, 40.777608735220774, 46.14906999043056, 45.48408569608416, 47.93899890354702, 48.54901947293963, 42.26325866154262, 49.99309485299246, 47.61476469039917, 43.3873417036874, 38.95583275386265, 39.22489479609898, 38.53147847311837, 38.36563886914934, 40.406543663569856, 39.073701994759695, 40.01089586530413, 41.66651609965733, 40.334331035614014, 37.05382592337472, 36.8977381161281, 38.306412424360005, 38.0245726449149, 39.204234327588765, 39.37594863346645, 37.792113712855745, 38.556446824754985, 36.537633827754426, 36.183623109545024, 37.454921109335764, 37.56473043986729, 37.55212640762329, 36.9965831892831, 36.84025566918509, 37.240061964307515, 38.47395781108311, 36.90983492987496, 36.93554673876081, 36.336313247680664, 37.38576916285923, 36.85571541104998, 35.93833432878767, 35.49720709664481, 37.849533626011436, 37.92481735774449, 38.62292718887329, 38.76072038922991, 39.22751079286848, 37.68595218658447, 37.41113356181553, 38.50036791392735, 38.128493377140586, 39.13941805703299, 40.7692847933088, 42.41472939082554, 42.999225752694265, 43.536460467747276, 46.45034735543387, 48.67257581438337, 53.57192087173462, 50.29862798963274, 50.33610309873308, 50.39009754998343, 48.47934293746948, 46.087185859680176, 50.08858394622803, 56.57570702689034, 57.49270248413086, 62.358970642089844, 22.107019186019897, 0.122880113444158, 0.19947913102805614, 0.07771234427179609, 0.12120339913027627, 22.506207091467722, 64.96524688175747, 42.84275926862444, 46.86720452989851, 18.413509675434657, 24.763645546776907, 43.92730706078665, 38.19766616821289, 48.919243812561035, 23.243265049798147, 1.8556538777691978, 0.08615768288395234, 0.09043469266699893, 0.061045563247587, 0.037141364866069386, 0.07790358258145196, 0.05992569548210927, 0.021508409974298308, 0.013674013266739036, 0.03467389601948006, 0.015313846657850912, 0.019188649719581008, 0.0649439844169787, 0.02653778956404754, 0.019868165221331373, 0.0915338583290577, 0.07961373510105269, 0.021277954036902105, 0.030024909946535314, 0.18319785967469215, 22.44758861405509, 70.90859004429409, 50.763184547424316, 47.35330397742135, 25.828653267451696, 23.70727617400033, 36.21010616847447, 52.49074642998831, 58.010305064065115, 64.29466233934674, 4.192483101572309, 0.10024934887353863, 0.13094470570130007, 2.2168538102081845, 1.9753832817077637, 9.171845350946699, 75.20502948760986, 57.86518151419503, 65.1077961240496, 58.127469062805176, 61.33725888388497, 53.434645312173025, 57.24488108498709, 51.635999883924214, 52.986625467027935, 46.97252185004098, 48.033890451703755, 42.27589396068028, 43.625644070761545, 41.56063944952828, 42.28332505907331, 42.47060332979475, 42.443057196480886, 39.94427306311471, 42.38280936649868, 41.798090662275044, 40.67051615033831, 41.063669545309885, 39.64262396948678, 39.629339013780864, 41.18410961968558, 39.80237695149013, 41.51174150194441, 40.97877298082624, 40.17449467522757, 39.02707263401577, 40.10547821862357, 39.56674269267491, 38.05540527616228, 37.77964864458357, 38.57724973133632, 37.89734418051583, 41.07590184892927, 39.0853054864066, 39.9634952545166, 39.874933515276226, 40.11316292626517, 38.66152443204607, 42.14746345792498, 40.046866689409526, 38.63358225141253, 41.64707503999983, 40.36503512518746, 38.80672788619995, 37.6952280317034, 38.30105536324637, 39.28998899459839, 42.220728737967356, 46.138626847948345, 46.99838651929583, 47.2625709261213, 45.277036326272146, 44.86312518801008, 43.90280771255493, 48.084553241729736, 47.537368706294465, 50.7399845123291, 50.38638373783657, 44.67903961454119, 53.671304430280415, 49.49856376647949, 46.29866470609392, 41.235258783612935, 42.23807144165039, 40.56390299115862, 40.02248198645455, 40.92641135624477, 41.42132806777954, 40.58204821177891, 42.53906045641218, 41.15812335695539, 38.92406211580549, 38.737940720149446, 40.62391458238874, 40.625245162418906, 40.276337896074565, 40.97631679262434, 41.05130522591727, 40.11524738584246, 40.164517062050955, 39.28528159005301, 39.95316675731114, 39.85571479797363, 39.016059739249094, 37.55824777058193, 38.73324721200125, 39.61720398494175, 38.45096274784633, 39.351324217660085, 38.53325721195766, 37.97554962975638, 39.36742319379534, 38.16347755704607, 37.59286369596209, 38.64083269664219, 40.57777854374477, 40.68395744051252, 40.13105801173619, 40.585841928209575, 40.61136613573347, 39.53932510103498, 39.4895829473223, 39.488294056483674, 40.04594257899693, 41.68931661333357, 42.07409048080444, 43.904551710401265, 45.72458369391305, 45.28649282455444, 48.14735800879342, 50.778164863586426, 53.793783800942556, 52.839330605098176, 53.10860456739153, 52.609164578574045, 50.97180768421718, 48.996532099587576, 51.04841504778181, 58.32554136003767, 60.34164455958775, 64.50645732879639, 24.70875825200762, 0.06366070506295987, 0.9155444779566356, 0.10979857575148344, 0.10689392339970384, 25.245360680988856, 70.00438622065953, 48.163279805864605, 43.847621645246235, 19.999799047197612, 33.04311030251639, 49.25559915815081, 45.96944516045706, 57.904616015298025, 34.66240535463606, 2.7109245785645077, 0.1293900598372732, 0.1008070707321167, 0.01729773377467479, 0.1119024550010051, 0.05242208205163479, 0.0631481193538223, 0.026241446180003028, 0.022310390868889432, 0.04487048940999167, 0.1742343306541443, 0.13423368707299232, 0.16531937117023127, 0.14470627797501429, 0.11243685561099223, 0.2567268455667155, 0.12083920224436692, 0.10389295978737728, 0.13251972118658678, 0.3076583354600838, 30.071230275290354, 80.37540640149797, 56.77825743811471, 56.89676938738142, 28.84843417576381, 35.367247990199495, 49.19459050042288, 58.716301100594656, 62.46811294555664, 69.62615408216203, 5.719746223517826, 0.22904579234974726, 0.14012592232653073, 4.625686347484589, 8.487335750034877, 9.575367195265633, 80.06093093327114, 59.44826602935791, 67.9332115990775, 59.75221497671944, 64.06082766396659, 56.37417452675955, 61.508844648088726, 54.476239340645925, 56.93262904030936, 49.57184989111764, 51.770982537950786, 44.92112527574812, 46.16709361757551, 42.9956613268171, 45.991262504032676, 45.19006225040981, 44.5859545980181, 43.26457050868443, 44.190449237823486, 45.20536913190569, 42.80800090517317, 42.842995507376536, 42.23667137963431, 42.60175405229841, 43.33836385181972, 43.108552183423726, 43.00281797136579, 42.78846951893398, 41.24005651473999, 41.99909509931292, 41.703866141183035, 41.66371250152588, 40.17432444436209, 39.87446798597063, 41.21124580928257, 39.59889895575387, 42.46355785642351, 40.97335686002459, 42.28227588108608, 40.870888301304404, 42.90338577542986, 41.15651832308088, 43.363561494009836, 42.22978918892996, 41.54290764672415, 42.52763066973005, 41.15506962367466, 40.54725163323538, 39.257099696568076, 40.10238627025059, 42.65516485486712, 46.08551481791905, 47.96157707486834, 50.02570622307913, 50.11238847460066, 47.476752621786936, 47.4488000188555, 44.275547300066265, 50.38101972852434, 49.711394037519185, 52.2325895854405, 52.658597537449424, 47.71601036616734, 55.16956186294556, 52.06648594992501, 48.02211672919137, 43.21538421085903, 44.773670605250764, 42.34208597455706, 41.73814507893154, 44.164886815207346, 43.124269008636475, 42.12026473454067, 45.09848846708025, 44.7612680707659, 40.3401779447283, 40.890621185302734, 42.24519681930542, 42.27857249123709, 43.44064480917794, 43.077597958701, 41.556682450430735, 41.25729499544416, 42.22988646371024, 41.65903983797346, 42.11023848397391, 41.75042601994106, 41.11044134412493, 40.36217941556658, 40.279176235198975, 42.560082231249126, 42.85419600350516, 41.85293279375349, 41.30210740225655, 39.44022989273071, 42.6360434123448, 41.60148096084595, 39.55026156561715, 39.53407573699951, 43.030774048396516, 42.76473099844796, 41.94912712914603, 43.22694948741368, 43.60767255510603, 41.13172367640904, 41.93047816412789, 43.25172676358904, 42.7125118119376, 43.88659061704363, 45.134841442108154, 48.327514375959126, 48.112731661115376, 47.12675448826381, 51.12022120612008, 54.176038946424214, 57.75516721180507, 55.256733962467735, 55.940881388528005, 55.496231419699534, 53.98660326004028, 53.27282871518816, 53.62691238948277, 61.59306376320975, 61.05549553462437, 66.82689162663051, 26.571228095463344, 0.5792973722730363, 2.1775404683181216, 0.2632705015795571, 0.36791517638734406, 30.487691402435303, 76.60153402600969, 54.77796833855765, 59.4403520311628, 28.27978491783142, 33.28418847492763, 58.121962615421836, 53.224517890385215, 71.60815552302769, 46.56385660171509, 2.964920537812369, 0.17728457626487526, 0.18416401211704525, 0.14537998182432993, 0.19772905350795814, 0.11494141657437597, 0.15702489124877111, 0.16415739352149622, 0.1481618939765862, 0.14144234811621054], [0.059782069974711964, 0.030210278928279877, 0.057517893612384796, 0.022547800093889236, 0.005277339610204632, 0.027458451322412918, 0.005667462471007768, 0.024113392424104468, 0.08483193402311631, 0.10094441300524132, 25.514549527849468, 56.36841447012765, 48.15896150044033, 37.337142195020405, 23.428241729736328, 29.41937460218157, 32.26690966742379, 45.73152494430542, 60.75319331032889, 37.90861068453108, 0.5207197698099273, 0.05708504933863878, 0.1621254796960524, 0.582426015819822, 0.5722859342183385, 27.436489003045217, 68.91511712755475, 56.749537059238975, 61.553709166390554, 55.24542924336025, 57.47836487633841, 53.15395545959473, 54.87293631689889, 50.10711479187012, 47.529378277914866, 45.684141704014365, 42.27258314405169, 38.85648046221052, 40.722360134124756, 38.495698724474224, 39.39294045312064, 37.718678201947895, 38.598782198769705, 37.08276169640677, 36.45763226917812, 37.185463019779746, 38.822670527866904, 38.238229751586914, 39.29716648374285, 37.91506208692278, 37.82052142279488, 38.18102175848824, 40.31086002077375, 39.840623310634065, 38.007872649601524, 35.57608304704939, 36.33069562911987, 36.01776960917881, 37.72048125948225, 37.37987014225551, 36.8273354939052, 36.8268769127982, 38.10051645551409, 37.117092745644705, 38.52205671582903, 36.79957744053432, 37.839097431727815, 36.98357268742153, 38.926414081028526, 38.327590533665244, 37.91926922116961, 37.42559971128191, 37.6166786466326, 36.575320856911794, 35.46146903719221, 36.8125010899135, 35.98062801361084, 39.650544915880474, 43.83543103081839, 45.01196255002703, 45.37785121372768, 40.8793477330889, 41.49588918685913, 41.33642455509731, 42.411567960466655, 46.59210450308663, 48.23908812659127, 48.35294130870274, 39.01824842180525, 47.98433589935303, 50.71425533294678, 47.17456504276821, 41.044047832489014, 39.14539350782122, 39.6186283656529, 39.73794630595616, 40.28131628036499, 40.88618128640311, 39.60934904643467, 40.089535576956614, 40.64689922332764, 37.73854310171944, 36.8013596534729, 37.69834082467215, 38.33733885628836, 37.58216347013201, 37.99117265428816, 38.54633024760655, 38.419466563633506, 37.15609645843506, 37.9476317678179, 38.2113367489406, 37.66765757969448, 36.259650298527305, 37.06308787209647, 36.63170896257673, 37.41373218808855, 36.548677989414756, 36.080008098057334, 35.13700205939156, 37.4422858101981, 36.130458968026296, 36.787883622305735, 36.49517338616507, 37.32001141139439, 37.34355885641915, 37.787312507629395, 36.59615503038679, 38.034525939396445, 38.492450441632954, 37.66628878457205, 35.91248355593, 36.987178802490234, 38.04533733640398, 39.269655091421946, 40.289098262786865, 40.564146178109304, 40.5518548148019, 41.71317325319563, 43.624400343213765, 46.646870204380576, 47.711633001055034, 48.707563468388145, 49.20717716217041, 47.98396069662911, 45.91789994921003, 46.51894344602312, 48.250208718436106, 55.76759678976876, 57.92866373062134, 60.602730069841655, 36.67997809818813, 0.9383305524076734, 0.5449209968958582, 0.09711774012872151, 0.0625278637079256, 13.62301422868456, 64.88115283421108, 45.78934090478079, 39.35102197102138, 25.531817538397654, 23.366117886134557, 40.16549328395298, 38.843431745256694, 39.07648822239467, 30.273176193237305, 6.722901080335889, 0.14405193951513084, 0.036145767396582026, 0.046560896560549736, 0.02447901084087789, 0.04065721442124673, 0.05404597580698984, 0.032987434550055435, 0.052941083309373686, 0.03960685578307935, 0.06481143938643591, 0.003056398863139163, 0.04410756499107395, 0.023030394555202553, 0.047888531748737605, 0.01857943383843771, 0.05372621278677668, 0.011165767858204032, 0.006666112499910274, 0.25951752439141273, 35.643345083509175, 66.44203090667725, 53.66289710998535, 51.00987686429705, 30.1821026802063, 27.42805388995579, 34.205498763493125, 50.748298031943186, 65.03433282034737, 43.077184540884836, 0.7579397921051297, 0.06467988501702036, 0.2920047497110707, 0.7258882405502456, 0.42766667157411575, 29.736306258610316, 69.77296951838902, 58.76208972930908, 63.98200729915074, 57.259701592581614, 59.76091412135533, 55.850481850760325, 57.72171858378819, 52.082817690713064, 52.55384649549212, 46.95703084128243, 44.89267240251814, 41.029609475817, 44.439858300345286, 41.67587532315935, 42.59813404083252, 39.53422164916992, 40.257025378090994, 38.696091720036094, 39.67114632470267, 39.52559546061924, 41.42490986415318, 39.564262185777935, 41.23425129481724, 39.80999217714582, 39.91966601780483, 41.07400846481323, 41.50683954783848, 41.043224470955984, 40.21227203096662, 38.37875359398978, 40.05832774298531, 39.64707081658499, 39.256189482552664, 39.319098472595215, 38.88094506944929, 38.94516726902553, 39.6750477382115, 38.67590025493077, 39.509691034044536, 39.272903374263215, 40.35541534423828, 38.17170075007847, 39.57517780576433, 39.6920291355678, 40.37696518216814, 40.31968423298427, 40.12721913201468, 38.74329430716378, 38.43441908700125, 37.25116171155657, 38.85716485977173, 40.0386643409729, 45.59898458208357, 46.68510614122663, 46.071354389190674, 44.05148179190499, 42.96389068875994, 42.93572963987078, 43.76360750198364, 48.50690991537911, 50.994437967027935, 49.74250112261091, 41.43345267432076, 49.662138257707866, 52.50177322115217, 48.43355083465576, 43.02882507869175, 40.53338302884783, 42.07640423093523, 42.18344470432827, 43.6402839251927, 42.366352558135986, 41.69672686713082, 42.443220479147776, 42.53983170645577, 39.77108573913574, 40.03719479697091, 38.91916363579886, 41.2029253414699, 39.71926259994507, 40.15565810884748, 40.7317784173148, 40.19412333624703, 39.68666165215628, 38.58990587506975, 41.18281725474766, 40.171951634543284, 39.16875682558332, 39.46868971415928, 37.64784826551165, 39.80536467688424, 37.437762532915386, 38.18186943871634, 37.3643513407026, 38.94945430755615, 39.1142829486302, 39.793716021946494, 38.72630943570818, 38.49028607777187, 40.46778161185128, 40.01118074144636, 38.21362965447562, 39.55879742758614, 40.10956028529576, 39.50014420918056, 39.41493150166103, 38.18894270488194, 40.305923325674875, 40.858002867017476, 43.375074659075054, 42.85773958478655, 43.39586019515991, 45.05855022157942, 45.73379005704607, 47.70596327100481, 49.423731667654856, 51.86168432235718, 52.224866662706646, 50.16409349441528, 49.81927176884243, 48.86093800408499, 50.658892086574006, 58.30272347586495, 59.247414452689036, 62.79147515978132, 42.244797297886436, 1.780998415180615, 0.7029925691229957, 0.1613493034882205, 0.08310865863625493, 15.234057426452637, 68.66031278882707, 51.482229300907676, 40.59546865735735, 26.22133765901838, 29.456127098628453, 44.41825287682669, 44.24399553026472, 48.07372794832502, 43.302264486040386, 9.159153597695486, 0.08265819280807461, 0.040004558728209565, 0.07849181815981865, 0.059142442154032845, 0.04553061916625925, 0.038209080430013795, 0.011447076602572841, 0.03153200407645532, 0.05647863919979759, 0.1879359068615096, 0.12027314119040966, 0.1650732529482671, 0.1266917431993144, 0.1718364150396415, 0.15068410363580498, 0.11293108016252518, 0.0757206336462072, 0.1311662880969899, 0.6087116482002395, 47.229459285736084, 73.60113511766706, 62.810249192374094, 52.767468861171174, 35.20308290209089, 41.190599237169536, 44.29337985174996, 57.82965537479946, 70.48812675476074, 47.55894981111799, 1.329402853335653, 0.10042282313640628, 0.8674068695732525, 5.012417869908469, 2.139458477497101, 32.408837045942036, 73.67122159685407, 60.40741620744978, 68.61161286490304, 61.69128349849156, 60.98174735477993, 57.566957882472444, 60.07124151502337, 55.01836906160627, 54.27545724596296, 49.53984301430838, 46.94385010855538, 42.53996024812971, 45.962990283966064, 42.91292565209525, 44.59582451411656, 42.83549492699759, 43.45467669623238, 40.13376433508736, 40.93881041663033, 41.30387224469866, 42.518750871930806, 42.64800821031843, 44.03960384641375, 41.30709620884487, 41.278938634055, 41.84220824922834, 44.307189396449495, 43.7050724029541, 41.87363495145525, 38.50739254270281, 40.03335244315011, 41.007733072553364, 42.74169077192034, 42.245568547930034, 40.709307943071636, 41.001774992261616, 41.5568596294948, 41.16128478731428, 42.54500464030674, 40.72338151931763, 41.08571965353829, 40.9155513218471, 43.05742038999285, 41.83367238725935, 43.056791578020366, 40.941669600350515, 41.9844309261867, 39.789772919246126, 40.2909951210022, 40.03394651412964, 39.35433278764997, 44.01433324813843, 48.552531787327354, 50.03854301997593, 49.77135351725987, 45.58257988521031, 44.67607273374285, 45.71015228543963, 46.86594690595354, 51.53922189985003, 51.7649758202689, 52.93352733339582, 44.54982743944441, 51.76949214935303, 55.72824566704886, 51.443864822387695, 46.07291425977434, 43.107728821890696, 44.40284524645124, 44.29661423819405, 45.40611301149641, 45.79308598382132, 44.566794940403526, 44.377817835126606, 44.8336752482823, 41.260425158909385, 40.70104306084769, 42.52083880560738, 42.346369538988384, 41.34060737064907, 42.490520341055735, 44.05258655548096, 42.27442789077759, 41.636517252240864, 41.891064507620676, 43.995097160339355, 41.36085442134312, 40.414791175297324, 40.816129548209055, 40.0646401814052, 42.26174048015049, 39.14688042231968, 41.11727837153843, 41.26461839675903, 41.119029317583355, 41.36287634713309, 41.616912909916465, 41.1289096559797, 41.08437170301165, 41.22684104101998, 42.464638301304404, 41.372513498578755, 41.7986604145595, 43.35589068276541, 41.22643109730312, 41.58203295298985, 40.37277889251709, 42.08876160212925, 43.258084365299766, 46.046410356249126, 46.502285139901296, 46.24458687646048, 47.102119650159565, 48.18811961582729, 49.960250718253, 52.75339181082589, 52.50652926308768, 54.23933703558785, 54.50913906097412, 51.567063331604004, 51.581748349326, 53.087409087589805, 60.30832099914551, 63.101649693080354, 65.13242748805455, 44.295321873256135, 1.935309112071991, 1.5272777783019202, 0.4630005412868091, 0.16228631963687284, 17.380625213895524, 76.22861725943429, 57.712814467293875, 52.277433259146555, 37.42125013896397, 31.816836629595073, 53.015380586896626, 52.764512402670725, 57.84851278577532, 55.59741456168038, 12.840822509356908, 0.3334570511111191, 0.16183243399219854, 0.1890387569687196, 0.183460303449205, 0.12360295679952417, 0.16687179143939698, 0.11070118338934012, 0.1383321742926325, 0.12103445748133318], [0.04714007030374237, 0.014864973690626877, 0.05476972839928099, 0.06626576384795563, 0.08325047924050263, 0.0547457761131227, 0.055263939380113564, 0.03316114290750452, 0.0318241473287344, 1.6105544354234422, 40.60419906888689, 53.19160427365984, 44.673032896859304, 35.463282517024446, 38.177415643419536, 34.94457517351423, 31.044057982308523, 49.95426484516689, 57.65305648531233, 36.774160930088584, 0.5074616298079491, 0.013187233940698206, 0.09313997107424907, 1.214689614517348, 0.5465666343058858, 46.51781088965279, 65.80572182791573, 57.19523273195539, 57.701572281973704, 53.61266163417271, 51.62265239443098, 50.10975163323538, 50.84939432144165, 48.50785834448678, 46.07215690612793, 41.88548510415213, 40.4008982522147, 38.64170469556536, 38.81811250959124, 37.96127802985055, 37.19049004146031, 38.930968625204905, 37.997318335941856, 37.59748772212437, 36.72055210386004, 36.763485022953574, 38.30025632040841, 37.98284523827689, 37.054923738752095, 38.73482097898211, 38.39946617398943, 37.30838360105242, 38.05815328870501, 37.90212801524571, 38.686600480760845, 38.349991525922505, 37.293709005628315, 38.0435551234654, 37.50640031269619, 35.480639117104666, 35.538264002118794, 35.99029990604946, 38.42644950321743, 35.43433632169451, 37.612301281520296, 36.93619292122977, 37.125437532152446, 38.44645684106009, 38.36380801882063, 40.092245374407085, 38.89305925369263, 38.34217480250767, 36.06672314235142, 37.43558774675642, 35.65910359791347, 36.507020064762656, 37.172428199223106, 38.25052458899361, 42.45769010271345, 43.77605867385864, 42.83865635735648, 42.28882108415876, 39.319973945617676, 40.38902725492205, 39.635404791150776, 46.475176743098665, 48.16730976104736, 49.02628428595406, 33.03944860185896, 46.110465799059185, 51.94200202396938, 46.883470262799946, 42.24335554667881, 39.003942080906455, 39.408313342503135, 39.63120807920183, 41.199138573237825, 40.26504359926496, 41.133863721575054, 41.57943780081612, 38.886104106903076, 36.38524941035679, 37.88977411815098, 37.033742155347554, 36.819386754717144, 38.2983455657959, 38.30892767224993, 38.080814838409424, 37.31809718268258, 36.61164951324463, 36.60159894398281, 36.70717682157244, 36.561309814453125, 37.86944021497454, 36.00946651186262, 36.27990777151925, 37.00702633176531, 36.04900871004377, 36.762161391122, 36.39509848185948, 37.371966566358296, 37.40868432181222, 37.814573764801025, 36.42990895680019, 36.38961287907192, 36.81546449661255, 38.10127033506121, 38.52812944139753, 37.096116134098594, 37.87670455660139, 37.171417236328125, 37.17270960126604, 36.372072151729036, 37.57043491091047, 38.83687611988613, 38.426258427756174, 40.10151774542672, 40.35851076671055, 41.4783866746085, 43.41260882786342, 47.02521698815482, 46.83178261348179, 46.60826601300921, 44.19899899618966, 43.72879007884434, 44.28284985678536, 44.27985518319266, 47.7833696774074, 54.14320523398263, 57.798558712005615, 60.279256684439524, 53.42175987788609, 5.346190222672053, 0.8579327293804714, 0.6763016613466399, 0.23812336953622953, 5.282594229493823, 55.4625917162214, 55.11206899370466, 42.647393294743125, 35.0343702180045, 16.725872141974314, 42.68066474369594, 41.059295654296875, 37.2719646181379, 42.54115533828735, 12.23452009473528, 0.29111814871430397, 0.10388490557670593, 0.04172368148075683, 0.0046419068322783065, 0.057925944216549397, 0.05423252883234194, 0.0696984182244965, 0.02793059973711414, 0.009621419611253908, 0.01005324353796563, 0.04775342864117452, 0.02464516201455678, 0.039905706354017766, 0.012458023382350802, 0.09806986725223915, 0.06433453783392906, 0.030703553530786718, 0.09641577529587916, 2.589777959244592, 51.95172255379813, 60.38159670148577, 50.59346090044294, 38.24660927908761, 38.61609016145979, 32.88036959511893, 37.695842947278706, 54.53658444540841, 62.374221937997, 39.50345849990845, 0.5755704779710088, 0.0655815630619015, 1.0651255143540246, 1.986028356211526, 0.7297814030732427, 49.252295289720806, 67.78106689453125, 60.177555901663645, 58.831939969744, 55.01091711861746, 54.60481228147234, 51.937315464019775, 53.055381366184776, 49.78636857441494, 48.77775069645473, 42.79012666429792, 42.782452378954204, 41.5821475982666, 41.25233398165022, 39.15248761858259, 38.58448280606951, 39.71575723375593, 41.53202676773071, 41.175789151872905, 38.74183518545968, 39.46494116101946, 40.051358699798584, 38.95654494421822, 39.44741085597447, 41.468426431928364, 40.0261367389134, 39.414222785404746, 40.13726622717721, 41.473759174346924, 39.12260341644287, 40.9535927091326, 39.69311305454799, 38.26203427995954, 38.649854932512554, 37.03634078162057, 39.0479519707816, 37.99917003086635, 38.55707563672747, 37.06899036679949, 40.85700580051967, 39.53368316377912, 39.75357280458723, 41.35197809764317, 40.58107198987688, 41.10918024608067, 39.735764571598594, 40.30996022905622, 37.6956136567252, 39.25802033288138, 39.12318359102522, 38.561199392591206, 39.94799034936087, 41.32634966714041, 44.80652168818882, 46.66326100485665, 44.37142896652222, 43.335782596043174, 41.39520978927612, 43.157814911433626, 41.74407884052822, 47.42771918433053, 50.665725639888215, 50.84710489000593, 33.58814089638846, 45.89809758322579, 53.95372091020857, 49.3585957799639, 43.20961373192923, 41.485824721200125, 41.55414983204433, 41.94275563103812, 43.088381562914165, 42.369319438934326, 42.91166802815029, 43.18194947923933, 41.22484343392508, 39.88032531738281, 38.59419986179897, 38.56666415078299, 38.81658738000052, 40.124651772635325, 40.26876088551113, 40.69407401766096, 39.870055879865376, 38.980241775512695, 38.19838878086635, 39.37353760855538, 38.70276893888201, 39.57292658942086, 39.35620880126953, 38.687336989811485, 39.37895025525774, 37.22698892865862, 39.76321690423148, 38.63237673895699, 39.22055912017822, 38.63572924477713, 38.18532964161464, 39.02150365284511, 38.70174755368914, 38.099338735852925, 39.594601494925364, 40.139229093279155, 39.58789300918579, 39.97836787360055, 39.969741685049875, 38.12773602349417, 38.524898529052734, 39.36248649869646, 41.198016439165386, 40.78155531202044, 42.10679912567139, 42.43363891329084, 44.214045320238384, 45.79884604045323, 48.39449501037598, 47.75350284576416, 47.832955496651785, 46.259212834494456, 45.90412514550345, 46.42681728090559, 46.355487074170796, 49.8859987940107, 56.58313812528338, 59.88362625667027, 61.8232923235212, 55.56547369275774, 6.288596979209355, 1.067666383726256, 1.1189139080899102, 0.24728763635669435, 5.224318819386618, 60.344145911080496, 59.3213015965053, 45.22046756744385, 29.910855429513113, 24.119335617337907, 48.79630586079189, 48.427439893995015, 46.84037406103951, 57.974803243364605, 17.685548646109446, 0.4436085804232529, 0.07674419693648815, 0.002098838158417493, 0.024250427660133158, 0.07249865760760647, 0.04202992808339851, 0.022533421936844076, 0.03968657346974526, 0.07818988364722047, 0.11487280311329023, 0.12891554672803196, 0.10945623447852475, 0.10825962440243789, 0.1431563954268183, 0.13907527870365552, 0.18673872681600706, 0.14339555187949113, 0.22555933014622756, 4.451836773327418, 63.89113180977957, 66.4215337208339, 61.120627948216026, 45.02194363730294, 45.23483991622925, 41.74192489896502, 43.76960379736764, 61.20409665788923, 66.2549159186227, 44.16362919126238, 0.8668606217418398, 0.13699909725359508, 1.219786443880626, 6.904041486127036, 1.0398918283837182, 52.607524803706575, 68.71981716156006, 62.55449989863804, 63.413873944963726, 58.03032629830496, 56.2638510295323, 54.445264271327424, 55.55130631583077, 52.756733894348145, 51.471657616751536, 45.54107482092721, 44.66980198451451, 43.39405018942696, 42.988428252083914, 41.91435486929757, 40.09322507040841, 42.336569104875835, 44.09780543191092, 42.263793672834126, 38.87302759715489, 42.1540572983878, 41.57946211951119, 42.04511996677944, 41.38118485042027, 43.215200083596365, 42.389993803841726, 40.431532859802246, 42.55749750137329, 43.278956753867014, 40.535926069532124, 43.717148372105186, 41.01414278575352, 42.08275488444737, 41.823180607386995, 38.55968121119908, 40.68287352153233, 39.276419162750244, 41.47371401105608, 38.013594491141184, 43.650466510227744, 42.07330533436367, 41.74509327752249, 43.1472293308803, 43.37939991269793, 44.63243804659162, 41.54350519180298, 43.26881585802351, 39.587837423597065, 41.87886347089495, 41.04520123345511, 40.756479263305664, 41.866547788892476, 44.648575237819124, 48.70386355263846, 48.807860715048655, 47.288456439971924, 46.69899211611067, 43.24518156051636, 45.488146918160574, 44.052756786346436, 49.18822595051357, 53.61657346997942, 52.0050082887922, 37.57716424124581, 48.50059052876064, 56.28685998916626, 51.91734981536865, 45.479246275765554, 43.19372320175171, 44.267195565359934, 43.1141037940979, 44.54282365526472, 44.8685691016061, 46.73031459535871, 47.068785667419434, 44.20882027489798, 40.64762878417969, 41.63540554046631, 41.31763662610735, 41.23496348517281, 42.13955988202776, 41.813414914267405, 43.076590469905305, 40.649074009486604, 41.12951414925711, 39.3606903893607, 41.24478823798043, 40.81392696925572, 41.66046074458531, 40.38605342592512, 41.36281033924648, 43.529043265751426, 40.34094224657331, 43.064722946711946, 41.76880400521414, 41.81758730752127, 41.98203032357352, 40.762534618377686, 41.23466123853411, 40.787916387830464, 40.457539967128206, 42.093625341142925, 42.65613065447126, 41.412215505327495, 41.98700870786394, 41.88166012082781, 41.60637944085257, 41.561494077954976, 42.732724121638704, 44.30760281426566, 42.99543898446219, 45.19793108531407, 45.17508888244629, 46.42240864889962, 49.25040190560477, 51.66772188459124, 51.08903769084385, 51.56946740831648, 49.375726563589915, 48.238886628832134, 50.10784782682146, 49.502371379307334, 54.44326319013323, 58.857481547764365, 63.739112172807964, 64.52156966073173, 58.95061520167759, 7.426593354770115, 2.23545326931136, 1.3083028026989527, 0.42043275545750347, 6.893304347991943, 65.57291548592704, 63.76256234305245, 57.49183395930699, 46.780352047511506, 24.366008826664515, 53.61541312081473, 58.900067056928364, 55.40704434258597, 70.34549413408551, 24.52516426358904, 0.716559958245073, 0.19327775522002152, 0.09830692703170435, 0.1186406673597438, 0.13678558942462715, 0.1303694165710892, 0.16016285786671297, 0.10415524749883584, 0.1967382566737277], [0.019616147137380073, 0.05389856746686356, 0.051890456649873934, 0.03839724836871028, 0.05685799455802355, 0.08743000389741999, 0.03325494019580739, 0.11341429887605564, 0.08856251955564533, 4.3566659944398065, 51.488256863185335, 51.295795236315044, 52.18881940841675, 44.836975642613, 24.6342579296657, 29.399794578552246, 36.59608554840088, 49.783210618155344, 62.24314417157854, 26.231534140450613, 0.2339450865983963, 0.08725420225943838, 0.2745325272636754, 0.34389883652329445, 15.247693266187396, 58.75549588884626, 58.77502727508545, 58.892715862819124, 56.21685688836234, 50.098005703517366, 44.416633946555, 45.08295576913016, 43.14312989371163, 41.27671521050589, 40.474097524370464, 41.02862630571638, 40.14106689180647, 40.44867753982544, 38.64172901426043, 38.32829230172293, 36.39197874069214, 37.08393941606794, 37.701398032052175, 36.63585703713553, 37.26170212881905, 36.32760715484619, 38.039080483572825, 37.76569666181292, 37.012063775743755, 37.034179891858784, 38.06511190959385, 37.27381978716169, 37.8918377331325, 40.86495106560843, 37.448035444532124, 37.19745561054775, 37.638634954180034, 36.68389688219343, 36.09441518783569, 37.983126640319824, 36.90490518297468, 36.85090030942644, 37.56757920128958, 36.51427050999233, 38.971073627471924, 36.965312821524485, 37.49797214780535, 38.159277370997835, 37.79697050367083, 39.027086530412944, 38.68262958526611, 38.236763681684224, 36.84479284286499, 37.27710281099592, 36.320516518184114, 36.11215393883841, 36.92558649608067, 39.87181724820818, 38.60864864076887, 40.87658929824829, 41.087901387895855, 42.08520065035139, 38.44260059084211, 40.01696164267403, 37.9414895602635, 46.26389592034476, 47.99013417107718, 50.13438299724034, 34.31409910746983, 45.80345269611904, 50.439631257738384, 47.33088214056832, 41.99903951372419, 38.44620323181152, 38.70718451908657, 39.3546906198774, 40.99805770601545, 38.82700967788696, 38.99930763244629, 40.04233993802752, 39.68593903950283, 38.33821085521153, 36.13582297733852, 38.18198755809239, 37.26585715157645, 37.72647755486624, 36.893426758902415, 38.17073147637503, 38.646828992026194, 37.38893754141671, 38.11683777400425, 39.326755387442454, 37.26601696014404, 36.73408024651663, 35.6803685597011, 35.6500118800572, 35.84355395180838, 37.89036471503121, 36.23414693559919, 35.40957989011492, 36.24613952636719, 36.00821931021554, 37.4926289830889, 37.27685614994594, 37.381843430655344, 38.97156694957188, 37.54449381147112, 37.932429109300884, 37.08472456250872, 38.11502776827131, 37.6066107068743, 37.10468673706055, 35.563722201756065, 39.98272786821638, 38.62678691319057, 40.52330814089094, 40.48115342003958, 41.20451995304653, 39.928090708596365, 43.320527826036724, 43.247186115809846, 40.729777336120605, 41.260313987731934, 41.72644083840506, 40.557389054979595, 42.6211325781686, 44.5743476322719, 45.83847509111677, 52.09859357561384, 57.304875305720735, 57.45587008340018, 58.410003662109375, 13.370755536215645, 0.4234574202980314, 3.9106841427939276, 0.038445621130189726, 1.026018989937646, 45.21113961083548, 61.37699563162667, 42.5189836365836, 40.23696592875889, 15.628331218447004, 26.596191235951014, 42.658232484545024, 36.25117697034563, 45.0285062108721, 19.394009930746897, 1.5176969724042075, 0.08158359011369092, 0.01571702877325671, 0.0612307625955769, 0.011268508238052683, 0.017732340543131744, 0.050967469212732146, 0.05357381382158824, 0.0596362595845546, 0.03703118434974125, 0.024145364994183183, 0.03431167367047497, 0.041747542164687595, 0.01588409936188587, 0.047041038117770634, 0.012507797318643757, 0.17463306497250283, 0.127748005092144, 6.6247221657208035, 62.935268129621235, 54.42120613370623, 61.76725510188511, 46.00830296107701, 36.409974575042725, 38.58357606615339, 40.86842169080462, 57.38369219643729, 65.01831027439663, 31.32341030665806, 0.10531020909547806, 0.0341663212914552, 0.5609482654503414, 0.14705665542611054, 17.509231158665248, 62.2692346572876, 61.255311829703196, 61.350418772016255, 58.6837557383946, 51.73778404508318, 46.49053921018328, 47.38653026308332, 45.946457045418875, 44.89339501517159, 43.37242044721331, 42.6145213672093, 41.40565640585763, 41.93460886819022, 39.58385610580444, 38.95882395335606, 39.83887236458914, 39.66261741093227, 40.05256421225411, 37.51014191763741, 38.29126187733242, 38.862890175410676, 40.25485406603132, 41.34619719641549, 38.531714711870464, 39.403202942439485, 40.11461509977068, 38.976691246032715, 39.149086475372314, 41.94577809742519, 39.17155000141689, 40.25239787782942, 40.456973688943044, 38.13503163201468, 38.86559302466256, 40.067026887621196, 39.635078225817, 38.352788175855366, 39.04497466768537, 37.81649841581072, 40.15401138578142, 39.27406024932861, 39.81218433380127, 38.92608404159546, 39.791325841631206, 41.044398716517854, 41.137768609183176, 39.19427408490862, 38.54374899183001, 38.82025602885655, 38.90816463742937, 39.05395868846348, 39.137142521994456, 40.857881273542134, 41.09048959187099, 43.02978393009731, 43.6750214440482, 43.3126346724374, 39.68130806514195, 41.35238804136004, 39.25591850280762, 48.83693545205252, 50.09640414374215, 52.14746025630406, 37.91460697991507, 45.4237197467259, 53.09407588413784, 48.84086118425642, 43.27499280657087, 41.07829202924456, 41.6977447782244, 41.66228117261614, 42.376736640930176, 42.372765745435444, 41.85691063744681, 41.998810223170686, 42.10859523500715, 40.14312703268868, 37.789080824170796, 41.02136196408953, 39.11641604559762, 40.94914933613369, 38.5691168648856, 40.223635809762136, 39.51002107347761, 39.54421315874372, 39.883313042776926, 40.13948270252773, 39.4395489692688, 39.61373683384487, 38.927546637398855, 36.869528429848806, 37.48329060418265, 39.68634550912039, 37.02128403527396, 38.61522511073521, 38.499961444309776, 39.47637094770159, 39.468797411237446, 39.16230542319161, 40.05527400970459, 40.70120634351458, 38.88874789646694, 39.597321714673726, 38.916175910404746, 40.20255497523716, 40.051323958805625, 40.089639799935476, 38.21750674928938, 41.37700203486851, 39.99092674255371, 40.731087071555, 42.25983667373657, 43.99320377622332, 40.68457930428641, 44.76348802021572, 45.29137740816389, 44.32559517451695, 43.15708187648228, 43.24308320454189, 41.25461646488735, 45.07127584729876, 47.45374018805367, 47.76131609507969, 51.263621602739605, 59.798670632498606, 58.73246955871582, 62.597627367292134, 14.479650684765407, 0.5244663687688964, 7.248808928898402, 0.042861676309257746, 1.3218725259814943, 46.65929358346121, 66.02155372074672, 46.95751026698521, 38.623556000845774, 16.391926084245952, 33.67779002870832, 49.43812486103603, 44.002066203526084, 55.87093734741211, 28.241951976503643, 1.8617235635008131, 0.0920301117002964, 0.00617935268175123, 0.05827419552952051, 0.02180234286268907, 0.028022373294723884, 0.03457244146349175, 0.04816938417830637, 0.05185410752892494, 0.12679972526218208, 0.170048841674413, 0.1300328496311392, 0.07369131182453462, 0.11513808316418103, 0.12903464319450514, 0.08787522464990616, 0.4764230496117047, 0.4008420652576855, 10.595279370035444, 72.37062999180385, 62.55531283787319, 69.75842693873814, 56.83470460346767, 34.73486464364188, 38.095701353890554, 50.4072630746024, 61.01440388815743, 74.92778941563198, 36.32420948573521, 0.47121179210288183, 0.2390898476753916, 1.5957921189921243, 2.9872136158602576, 18.409559624535696, 65.50661577497209, 63.19335896628243, 63.56683158874512, 60.16010897500174, 54.71288456235613, 49.34459515980312, 49.592069149017334, 46.6700667653765, 45.78173610142299, 45.92658519744873, 46.44318723678589, 44.273841517312185, 45.35878535679409, 42.7090550831386, 41.7560818535941, 40.98039191109793, 41.13335997717721, 42.16362844194685, 41.136375495365684, 41.929856300354004, 42.63624143600464, 42.87626000813076, 42.61631747654506, 40.94453225816999, 41.38874101638794, 41.502194677080425, 41.999359130859375, 40.52461787632534, 44.341885226113455, 42.36656795229231, 41.74792119434902, 43.013243743351524, 39.68678671973092, 41.801571709769114, 42.95229761941092, 41.03278827667236, 40.519427571977886, 41.01468474524361, 39.97281626292637, 43.58357967649187, 40.19101054327828, 41.01828391211373, 41.07776396615164, 41.32868078776768, 41.687308583940776, 43.44462265287127, 41.50105169841221, 39.25133963993618, 40.94992406027657, 41.36876841953823, 39.98688636507307, 41.802593094961985, 43.82672493798392, 43.72103936331612, 44.3065710067749, 47.352265221732004, 47.084530285426546, 41.25243125643049, 44.64274917330061, 42.78862237930298, 50.21471112115042, 52.79781859261649, 54.25558539799282, 40.61408288138253, 47.09691544941494, 54.39073828288487, 50.54204075677054, 44.67162936074393, 43.63385336739676, 43.9504827771868, 43.74025460651943, 44.40609352929251, 42.89959553309849, 43.91022491455078, 45.40185376576015, 44.365828718457905, 43.080217429569785, 39.24244247164045, 43.00058759961809, 40.11022383826119, 44.07887853894915, 40.202565397535054, 41.90133741923741, 42.540401458740234, 41.03057874952044, 42.199904986790244, 44.157775333949495, 41.76078230994088, 42.057585035051616, 41.94004583358765, 39.112445150102886, 40.2685489654541, 41.425833974565776, 39.958697523389546, 41.04968976974487, 40.97868265424456, 42.21517365319388, 42.62152862548828, 42.43141201564244, 43.32301875523159, 43.40543828691755, 41.1900121143886, 42.3180000441415, 40.504770347050254, 42.64046246664864, 42.807417256491526, 42.219200134277344, 40.13691534314837, 43.206796237400596, 42.76392500741141, 44.35436766488211, 45.29271493639265, 47.8619190624782, 43.590211732046946, 48.33726964678083, 48.78458077566964, 46.84050260271345, 46.73521307536534, 46.508125100817, 45.1657782963344, 47.59501791000366, 50.4536075592041, 50.234329359872, 57.02181959152222, 63.78808307647705, 61.350460461207796, 63.44792706625802, 15.985254968915667, 1.0155956063951765, 7.742111921310425, 0.16495072309459957, 1.399480538708823, 52.78025354657854, 70.15931715284074, 54.719311646052766, 52.04554060527256, 21.489444187709264, 38.65720265252249, 57.12844317299979, 52.54927805491856, 67.1215716770717, 38.31634834834507, 2.456696071795055, 0.14244032385093824, 0.12743346339889935, 0.15425437848482812, 0.11917547509074211, 0.12735142851514475, 0.09494797512888908, 0.1597221629428012, 0.11348479187914304], [0.09138148650527, 0.02316870374072875, 0.051950310223868916, 0.0313435002629246, 0.049511343240737915, 0.02714789262972772, 0.03361967312438147, 0.0594194337193455, 0.13220763579010963, 10.022685272353035, 58.63155392238072, 50.0367990221296, 45.37357112339565, 16.94152511869158, 10.207496064049856, 26.55133366584778, 42.61563655308315, 51.862907205309185, 59.3009364264352, 21.547124658312114, 0.007468560311411108, 0.22248917631804943, 1.6214457367147719, 0.6760963637913976, 22.866205419812882, 57.74033628191267, 60.15809399741036, 61.95193822043282, 57.49934148788452, 53.15241643360683, 41.38830327987671, 41.79386963163103, 42.704649925231934, 42.560314995901926, 42.42024278640747, 42.6653995513916, 40.59167146682739, 41.55479254041399, 40.611352239336284, 41.29610068457467, 42.06977564947945, 43.28128787449428, 45.60637051718575, 47.40713514600481, 45.04903813770839, 41.89170374189104, 37.561391830444336, 36.93496309007917, 36.59165607179914, 37.474105085645405, 38.56033434186663, 36.22586815697806, 36.73623071398054, 37.6971492086138, 38.115948404584614, 37.64480495452881, 37.990450041634695, 37.67853151048933, 36.63722235815865, 37.23719583238874, 35.9204739843096, 38.095909799848286, 36.53184250422886, 37.861640862056184, 37.89794519969395, 38.23714235850743, 36.38518687656948, 38.706159659794395, 38.09546511513846, 41.005940437316895, 39.40858432224819, 37.98538480486189, 37.805398668561665, 37.76635326657976, 37.09353835242135, 37.22079808371407, 36.086278847285676, 37.55956792831421, 36.430933816092356, 38.59918172018868, 37.90162774494716, 39.33948796136038, 37.92162813459124, 39.256078311375205, 38.11931133270264, 46.258695193699424, 46.80146067483084, 50.44760431562151, 40.43004594530378, 45.442469460623606, 50.234496116638184, 44.28256845474243, 41.129722595214844, 39.22208077566964, 38.523140634809224, 38.6318347794669, 38.8493446622576, 38.793387344905305, 38.50592647280012, 37.89410979407174, 38.43248748779297, 37.040832792009624, 36.314290932246614, 36.90944930485317, 36.2925500188555, 36.62082460948399, 37.68676512581961, 37.220457621983115, 38.4912622996739, 38.29135567801339, 37.517159598214285, 37.03405482428414, 36.31686176572527, 36.475892135075156, 37.2561331476484, 37.211598668779644, 35.686024393354145, 35.86287341799055, 35.61186626979283, 35.27822419575283, 35.32169560023716, 36.33089017868042, 37.03345033100673, 36.97154882975987, 36.756585461752756, 38.61556209836687, 36.24679960523333, 37.84277302878243, 36.80008118493216, 38.45505176271711, 41.14317083358765, 41.30067607334682, 41.255203587668284, 42.750073773520334, 41.81537430627005, 41.28618907928467, 42.13510956083025, 41.57583168574742, 40.69272606713431, 40.30278621401106, 38.136150291987825, 41.584902559007915, 40.33071797234671, 41.805782318115234, 45.613089425223215, 50.51475518090384, 49.65879964828491, 52.680387088230674, 50.19770540509905, 57.68570259639195, 55.74742269515991, 63.962858063834055, 19.224244594573975, 0.15413167221205576, 4.102851339748927, 0.10613403881766967, 0.20953295725796903, 28.451500960758754, 68.40248598371232, 44.44075461796352, 44.06414140973772, 39.473272051130024, 25.435211522238596, 47.7477080481393, 47.31748948778425, 45.52888420649937, 38.42822824205671, 5.869925890650068, 0.05497477150389126, 0.017017739691904614, 0.019324460199901035, 0.04088868646483336, 0.07713132830602781, 0.05773604940623045, 0.028734468655394654, 0.013657802216974753, 0.006329765235672572, 0.026085501869342158, 0.03028962342068553, 0.042003237908439975, 0.046990924913968356, 0.0370452673440533, 0.06455181153225047, 0.08860240384404149, 0.12876240137432302, 15.38140092577253, 67.82914842878068, 55.55850812367031, 52.41976710728237, 23.381853818893433, 15.804883207593646, 22.83111354282924, 46.81355748857771, 56.058413641793386, 64.93427876063755, 23.835967234202794, 0.09038631990551949, 0.17739873299641268, 0.45845218534980503, 0.189571420529059, 26.29512926510402, 60.61157512664795, 61.753254481724326, 61.568057196480886, 59.52184050423758, 55.280660084315706, 43.837536334991455, 43.715588501521516, 42.58805915287563, 43.514636175973074, 43.87611273356846, 43.79598610741751, 42.71035787037441, 43.150356020246235, 42.40804869788033, 43.27922078541347, 44.07576922007969, 45.543843678065706, 47.81723172324044, 50.02049854823521, 46.00323077610561, 42.9521621295384, 38.04831116540091, 38.46599864959717, 37.4335241317749, 39.00969866343907, 40.10155943461827, 39.08354411806379, 39.90056889397757, 38.94584124428885, 40.81897136143276, 40.36901644298008, 40.32109471729824, 38.17527559825352, 38.87313529423305, 39.7369179725647, 38.55848959514073, 40.73315068653652, 38.01927464348929, 39.80021606172834, 39.95576538358416, 39.34403903143746, 39.16852753502982, 40.30419322422573, 39.73200907026018, 42.592016151973176, 41.4074490410941, 40.56644255774361, 39.410484654562815, 38.872836521693635, 39.400100571768625, 40.56900296892439, 38.94796044485909, 39.486588273729595, 37.86741134098598, 40.823494638715474, 40.71962949207851, 39.99722875867571, 39.916059902736116, 40.34444761276245, 39.802234513419016, 47.41489280973162, 48.375394412449424, 54.17564637320382, 42.3898583139692, 47.29390035356794, 51.56276587077549, 46.39065885543823, 41.613296372549875, 41.399541991097585, 39.1180453981672, 40.75158078329903, 40.48219564982823, 40.45118931361607, 41.62309333256313, 41.21767289297921, 40.18980850492205, 38.98790911265782, 37.46692759650094, 39.2009026663644, 39.12981564658028, 39.03392008372715, 39.29039546421596, 39.14326041085379, 40.632043974740164, 40.55176796231951, 40.44638810838972, 39.37273856571743, 38.92966931206839, 39.215698855263845, 39.250196661267964, 38.993960993630544, 38.552441188267295, 37.704125199999126, 38.64516142436436, 37.951613085610525, 37.41749463762556, 38.69833946228027, 38.846398626055034, 38.90457936695644, 38.026869024549214, 40.05661848613194, 38.73727716718401, 40.37140314919608, 39.07033559254238, 40.46975490025112, 43.24974652699062, 43.353740215301514, 43.18900537490845, 44.66245426450457, 43.72116790499006, 43.46447018214634, 42.7999062538147, 42.528763226100374, 42.94234432492937, 42.19066388266427, 41.386670453207834, 44.37140464782715, 42.74215630122593, 44.613632747105186, 46.546173436301096, 53.24199260984148, 50.95301628112793, 55.02606419154576, 52.2982292175293, 59.335823331560405, 56.659814970833914, 67.75172465188163, 21.284649508340017, 0.6527884144868169, 5.415300045694623, 0.10217676830611058, 0.15608879790774413, 31.256485257829937, 71.96671036311558, 49.80488204956055, 44.588918004717144, 35.37232364927019, 32.46668774741036, 54.99211181913103, 56.70649644306728, 54.6278247152056, 50.407888412475586, 7.455810529845102, 0.02675993853647794, 0.09258231706917286, 0.014743220759555697, 0.03590366270925317, 0.01628273698900427, 0.06270097156188317, 0.08092784030096871, 0.023810117804844464, 0.23925644159317017, 0.10192598854856831, 0.1740806017603193, 0.13168776940022195, 0.11167667247354984, 0.1346162451165063, 0.16936759251568997, 0.2826575498495783, 0.19056547433137894, 21.65674638748169, 78.46599279131208, 63.55594376155308, 62.58154228755406, 26.96314123698643, 17.644547326224192, 35.45133856364659, 57.27616882324219, 60.99310071127755, 72.41798891339982, 27.607628345489502, 0.18879274731235846, 0.5829754120537213, 7.327376552990504, 1.7705817627055305, 30.286857196262904, 61.53623444693429, 65.49378940037319, 64.34395980834961, 62.28077561514718, 57.31387669699532, 47.794789041791645, 45.486184052058626, 45.608785016196116, 46.59195859091622, 46.978472982134136, 46.98749869210379, 44.53786958966936, 46.523216588156565, 46.0825548853193, 45.5967298916408, 45.40249994822911, 48.11463894162859, 48.92482321602957, 52.116589409964426, 50.23070934840611, 44.94343594142369, 39.82034151894705, 40.6956547328404, 40.11720677784511, 41.167204652513774, 42.67351852144514, 39.64441660472325, 41.42776904787336, 40.67754077911377, 43.250830445970806, 41.89358670370919, 42.031960078648154, 42.08792087009975, 41.69951656886509, 40.95680625098092, 40.76825993401663, 43.068693842206685, 41.01599448067801, 41.600046157836914, 40.56617157799857, 42.12272439684187, 39.51820952551705, 41.65692758560181, 41.340405872889924, 45.64081621170044, 44.40520415987287, 41.75617912837437, 41.87919351032802, 41.51357582637242, 42.256254877362935, 43.873903206416536, 41.73389972959246, 41.04708766937256, 39.6144802910941, 42.51435266222273, 42.29258700779506, 42.707953793661936, 42.6185930115836, 42.66825526101248, 42.181214332580566, 49.03920446123396, 50.699358395167756, 55.49578673498971, 46.0944675718035, 49.5848708152771, 54.68209709439959, 48.12056228092739, 43.37415402276175, 45.02521276473999, 43.20363828114101, 43.16617012023926, 45.09840856279646, 41.808106490543906, 43.55136782782418, 42.018859250204905, 42.50328070776803, 40.67810705729893, 40.320250511169434, 42.5551837512425, 41.48162453515189, 41.21519586018154, 41.06983954565865, 40.495873178754536, 44.91911724635533, 43.52398845127651, 42.38330616269793, 40.86260952268328, 41.23080151421683, 41.36712169647217, 41.0526635987418, 41.70321301051548, 41.26628943852016, 40.607485566820415, 40.725917611803325, 38.97779253550938, 39.11427252633231, 40.614458084106445, 42.23378092902047, 41.711919103349956, 40.604390144348145, 42.69677414212908, 40.878315925598145, 42.33120856966291, 41.302187306540354, 42.81160354614258, 46.402707031794954, 45.469994749341694, 45.688171659197124, 47.65503297533308, 47.53195258549282, 44.37915883745466, 47.6278828893389, 45.25062622342791, 45.74858972004482, 45.1501761163984, 43.339190687452046, 46.23344544001988, 45.4073497908456, 46.199743202754426, 49.39930527550833, 56.20622614451817, 54.88156597954886, 58.496578216552734, 56.41895566667829, 62.53818552834647, 61.180764607020784, 69.4896080834525, 24.399042299815587, 0.5326617690069335, 7.266349656241281, 0.18357866709785803, 0.3057744508343083, 35.21461691175188, 79.10664449419293, 56.1896790095738, 57.91514948436192, 49.535715784345356, 36.9501622744969, 62.44822025299072, 66.74930109296525, 62.99004077911377, 59.20176478794643, 9.607752748898097, 0.12008794184241976, 0.17097620905510016, 0.09329779831958668, 0.11744461368237223, 0.1395146029868296, 0.17600541561841965, 0.1446253423179899, 0.09614712292594568], [0.032887968101671765, 0.07633322184639317, 0.02380886421139751, 0.032803500669875314, 0.061630806486521444, 0.025669872029019252, 0.018694779702595303, 0.020210671039032083, 0.04204919508525303, 16.00221378462655, 58.06057528087071, 45.92441388538906, 47.95675155094692, 23.271111692701066, 30.459273270198278, 40.13428544998169, 42.340435777391704, 55.47316687447684, 59.02928270612444, 21.592373064586095, 0.1279285904020071, 0.12400835433176585, 0.6630000951034682, 0.46349310342754635, 28.79165002277919, 64.95690209524972, 56.92627143859863, 62.556236948285786, 57.65146534783499, 51.38372468948364, 41.35499014173235, 45.035301549094065, 40.468577180589946, 43.635513986860005, 43.303730555943076, 44.27073914664132, 43.03187533787319, 44.29411288670131, 43.968495982033865, 45.81094632829939, 45.47433737346104, 49.10644565309797, 52.097791058676584, 51.72268908364432, 51.65794576917376, 51.410395349775044, 47.24004486628941, 38.38454491751534, 35.97345747266497, 38.37891687665667, 39.01851940155029, 38.32449163709368, 37.98447111674717, 39.680293628147666, 36.98994071143014, 36.719760009220664, 36.57452181407383, 36.16436617715018, 36.218603815351216, 35.78506401606968, 37.27209315981184, 37.372359139578684, 35.964174679347444, 36.62018884931292, 37.76570013591221, 39.53457253319876, 36.96327005113874, 39.29942117418562, 40.37514475413731, 39.77654354912894, 37.36225298472813, 36.917203494480674, 39.147078445979524, 37.069997855595176, 34.686154297419954, 37.506570543561665, 35.7194174357823, 37.69671147210257, 37.56731169564383, 36.3727947643825, 36.80296816144671, 37.590230328696116, 36.53298200879778, 38.40774147851126, 37.96827139173235, 45.335765974862234, 47.38461603437151, 51.33604962485177, 40.73409564154488, 46.88638503210885, 49.36733661379133, 45.18922846657889, 40.52412802832467, 38.35733229773385, 37.98462397711617, 36.048796789986746, 38.430760860443115, 36.607341630118235, 39.23943737574986, 36.74374171665737, 37.797964096069336, 36.56020505087716, 34.83719423839024, 37.55109460013253, 38.05271632330758, 37.99449041911534, 39.99538401194981, 38.412546157836914, 37.57523264203753, 40.35561336789812, 36.80176959718977, 36.616388184683665, 37.523934091840474, 36.623513562338694, 36.96849857057844, 36.65960250582014, 35.21458217075893, 36.23262875420706, 35.71316753114973, 35.11373601640974, 35.86891140256609, 38.34500619343349, 37.82298108509609, 37.85353578839983, 36.44916588919503, 36.94152218954903, 36.4928492137364, 39.42400584902082, 36.88477625165667, 39.25202751159668, 42.33440474101475, 45.30498545510428, 44.42356130055019, 46.03009598595755, 45.61250925064087, 44.21771396909441, 41.542077336992534, 45.268166950770784, 41.386951855250764, 44.92387328829084, 43.011006423405235, 45.113566058022634, 46.72459275381905, 52.26136902400425, 51.82787091391427, 55.96329280308315, 55.52967309951782, 58.34156390598842, 53.4853115762983, 59.03588349478585, 52.830402169908794, 64.96319716317313, 24.161464282444545, 2.2493924413408553, 5.316790223121643, 0.06104378548583814, 0.06870029321206467, 16.272602932793752, 69.57552255902971, 49.21847145898001, 53.556405544281006, 27.868300437927246, 24.68305860246931, 43.98912170955113, 39.95457376752581, 44.7723365511213, 47.166689259665354, 11.165614434650966, 0.15338609793356486, 0.04233424086123705, 0.047617345050509484, 0.08879215616200652, 0.06126671138086489, 0.05443318520805665, 0.021958699383373772, 0.036037724265562635, 0.038767480823610506, 0.058373349851795604, 0.03478456847369671, 0.04960393273670759, 0.04357029417795794, 0.043959155811795166, 0.0267897296164717, 0.017872490254896026, 0.04662365087174943, 21.136552129473003, 67.25828443254743, 53.08259398596627, 55.20982319968087, 26.58527214186532, 27.63468289375305, 39.08951956885201, 48.869491236550466, 60.29469558170864, 65.54845087868827, 22.526815448488506, 0.049868232304496427, 0.03493421597938452, 0.9940781210150037, 0.31298521533608437, 31.959861823490687, 64.067428452628, 59.980317388262065, 64.47760840824672, 60.595107895987375, 54.23303501946585, 43.536925997052876, 47.24903236116682, 42.059606960841585, 45.31961836133684, 44.15013231549944, 46.003970759255544, 45.780572278159006, 47.43995148794991, 46.51701532091413, 49.36202124186924, 48.31780774252755, 51.74597249712263, 52.036323819841655, 54.34899697984968, 52.01028544562203, 53.299714769635884, 48.13261045728411, 40.314275060381206, 37.46207775388445, 39.218888078417095, 40.496540205819265, 39.19540664127895, 39.247452122824534, 40.44788544518607, 39.29637786320278, 39.952239172799246, 38.90942226137434, 39.20615897859846, 36.90722588130406, 37.55036851337978, 39.082637378147666, 39.95376777648926, 37.905143533434185, 39.63177783148629, 38.42151975631714, 40.15950393676758, 39.09882320676531, 42.091113567352295, 42.65842703410557, 41.78730010986328, 39.323291710444856, 38.32164287567139, 40.79279402324131, 39.19538232258388, 38.50109052658081, 38.88718802588326, 38.09142821175711, 39.42482573645455, 39.62775829860142, 38.82260799407959, 39.32964236395699, 39.697143009730745, 38.44708217893328, 39.9137669972011, 40.404546056474956, 48.22244719096592, 48.13827323913574, 53.514233452933176, 41.7251797403608, 47.84637246813093, 50.798092297145296, 45.97327014378139, 42.41434723990304, 39.43637016841343, 38.23758009501866, 38.42473329816546, 40.44162859235491, 38.02298150743757, 40.763264179229736, 40.07901947838919, 39.28581312724522, 37.68884263719831, 37.3544397354126, 40.32047285352434, 40.37314019884382, 39.480227197919575, 42.05678251811436, 39.44545841217041, 39.0155143056597, 42.68570566177368, 39.9000859941755, 39.62521178381783, 39.40675694601876, 39.015059198652, 39.48441348757063, 39.442161491939, 38.6774913924081, 38.932691778455464, 37.529680252075195, 37.76727737699236, 37.739376885550364, 41.19724518912179, 39.97667251314436, 39.02879578726632, 37.78203535079956, 39.84171417781285, 38.834169796534944, 40.46829577854702, 39.71228313446045, 42.00345856802804, 43.74202639716012, 47.98914752687727, 46.438347816467285, 47.87599263872419, 47.47414704731533, 46.09109769548689, 44.745426177978516, 47.205501896994456, 43.014060156685964, 48.26559550421578, 46.91429247174944, 46.77210800988333, 49.030043261391775, 54.52897616795131, 54.9289561680385, 59.03993429456438, 57.83214977809361, 61.41766343797956, 55.10669803619385, 62.01372855050223, 55.58687761851719, 67.62105682918003, 26.253669364111765, 1.3179419083254678, 1.9609952994755335, 0.13811352316822323, 0.016935618294935142, 18.198577574321202, 73.03543363298688, 54.368038518088206, 54.74574259349278, 33.336070673806326, 33.208463532584055, 49.40192127227783, 46.00334194728306, 53.59751456124442, 57.82727214268276, 15.643427916935511, 0.1206103323825768, 0.051183090678283145, 0.027321543311700225, 0.04988197942397424, 0.08632139981325183, 0.014905738378209727, 0.06608537531324796, 0.053549257639263353, 0.11128469636397702, 0.1368013314370598, 0.10309808993978159, 0.10755729316068546, 0.1150843296200037, 0.21979265101253986, 0.09706460405141115, 0.13468153375600064, 0.1123913801940424, 28.961891310555593, 76.82622487204415, 60.181043897356304, 62.75522640773228, 33.86254957744053, 40.56181158338274, 53.04811702455793, 55.98289714540754, 64.86128098624093, 70.55328001294816, 26.01643875667027, 0.27461107447743416, 0.1764015443623066, 1.693146477852549, 0.9774710578577859, 35.307830469948904, 66.81124428340367, 62.31495380401611, 66.97805663517543, 62.917918477739605, 55.25448969432286, 46.7261699948992, 49.42997809818813, 45.47835690634591, 47.06279632023403, 46.809808935437886, 47.792687211717876, 48.58680377687727, 51.203648226601736, 49.507363659994944, 51.002515247889924, 48.99963099615914, 54.00039543424334, 55.19534315381731, 54.31042752947126, 53.64570379257202, 55.14090401785714, 50.760961123875205, 42.13264989852905, 39.20783349445888, 42.9472462790353, 43.19775315693447, 41.443180152348106, 41.538287094661165, 43.93352222442627, 41.28801645551409, 40.40770401273455, 40.987520762852256, 40.97350624629429, 39.82358285358974, 39.46515655517578, 40.50599670410156, 42.960183824811665, 39.90457105636597, 41.723876953125, 40.33625568662371, 42.74067286082676, 41.30109296526228, 43.84029129573277, 45.64902203423636, 44.290802070072715, 41.88819490160261, 40.01282051631382, 42.89941487993513, 41.14923661095755, 41.156031949179514, 41.145554065704346, 40.05890791756766, 42.203747340611045, 42.93610831669399, 39.65049280439104, 42.039380754743306, 41.49480526787894, 40.83193670000349, 42.7785370690482, 41.84188168389456, 50.626381465366904, 51.38242885044643, 56.147871698652, 45.18808896200997, 50.112635135650635, 53.9101105417524, 49.57593890598842, 45.70012603487287, 43.353389331272666, 42.392967632838655, 40.75247710091727, 42.77787699018206, 40.428565979003906, 43.33217300687517, 41.83900165557861, 42.56114877973284, 40.189780712127686, 38.86714594704764, 40.98702049255371, 42.90270485196795, 42.5503443309239, 44.532873834882466, 42.1322295325143, 41.44136667251587, 45.25491326195853, 40.41082027980259, 40.353358677455354, 42.282161235809326, 40.80788551058088, 41.93984433582851, 40.670703751700266, 41.10517808369228, 42.38436576298305, 40.07833855492728, 40.29597697939192, 39.32066529137747, 44.4891106060573, 42.5119868006025, 41.386291776384624, 41.11265434537615, 40.679698194776265, 41.43497780391148, 43.845262731824604, 41.36972379684448, 42.91993638447353, 46.127634797777446, 51.73087058748518, 48.479738984789165, 51.19495603016445, 51.36941487448556, 49.516719409397666, 45.20293378829956, 49.72482490539551, 44.87063271658761, 49.65175070081438, 48.85081100463867, 50.10762548446655, 51.18673978533064, 59.07714884621756, 57.037783077784944, 61.684738295418875, 61.46473053523472, 64.49417291368756, 57.950203146253315, 65.95834595816476, 58.445634024483816, 72.26150158473423, 29.062560285840714, 3.6711471676826477, 9.31611340386527, 0.20502339995333127, 0.18561393288629396, 19.5414993422372, 80.70743996756417, 59.49053886958531, 70.0825742994036, 37.857277393341064, 35.74818645204817, 57.049264975956504, 56.84681183951241, 62.900520188467844, 68.58973993573869, 20.052483763013566, 0.17464932267154964, 0.08955822219806057, 0.09673137550375291, 0.11747996535684381, 0.1458978940333639, 0.11435744219592639, 0.13168250396847725, 0.24513619180236543], [0.03807157530848469, 0.057735981552728584, 0.04352313260148678, 0.05537683742919138, 0.031970995877470286, 0.023981665028259158, 0.047213847416320016, 0.06945360278976814, 0.402924652078322, 22.598810945238384, 56.26332991463797, 41.91273941312517, 40.86656999588013, 19.70302758898054, 25.4307108266013, 25.30574573789324, 47.61102308545794, 54.00086096354893, 60.61673069000244, 13.740626386233739, 0.17009278360222066, 0.19734549123261655, 0.5732077647532735, 0.8404045413647379, 40.95933539526803, 66.21091297694615, 59.16125679016113, 60.64606598445347, 54.24229349408831, 44.99021468843733, 40.71446698052542, 44.123096874782014, 46.93205901554653, 52.682832854134695, 50.30395030975342, 49.886651924678254, 49.464368207114084, 48.826631273542134, 48.89868409293038, 50.09519863128662, 52.52449383054461, 51.938350745609824, 52.14818981715611, 49.830684185028076, 50.501973969595774, 52.789859431130544, 50.194735050201416, 46.31917231423514, 37.2034136908395, 37.86613982064383, 36.50369882583618, 38.05498143604824, 37.31721476146153, 37.24688509532383, 36.52813564028059, 37.487112113407676, 36.63924428394863, 37.98448848724365, 36.408456393650596, 36.36887945447649, 35.941811902182444, 36.90749338694981, 37.46598611559187, 38.72589949199131, 37.171264375959126, 39.32806164877755, 37.12895679473877, 39.02406406402588, 37.12051820755005, 38.77145883015224, 39.399360588618684, 38.57524865014212, 36.21292018890381, 39.11263622556414, 36.237707887377056, 38.11071988514492, 35.514716557094026, 38.15148149217878, 36.90276166370937, 37.41188396726336, 38.635305404663086, 38.41490159715925, 37.05235637937273, 38.25266810825893, 40.88307891573225, 46.229995659419465, 46.49289117540632, 50.88070985249111, 41.55315971374512, 45.89608607973371, 49.012867314474924, 44.760774748665945, 40.68862315586635, 38.28371613366263, 37.322967869894846, 35.76603290012905, 37.15267447062901, 35.61218588692801, 36.31086547034127, 37.83053725106375, 37.410734040396555, 35.61741440636771, 36.14323670523507, 36.98873519897461, 35.77088621684483, 36.34677723475865, 36.8689204624721, 38.32256351198469, 37.71685082571847, 38.43697254998343, 39.03615045547485, 38.03184740883963, 38.941679273332866, 38.162108761923655, 36.25170155933925, 36.4138377734593, 35.34987054552351, 35.74106454849243, 36.03773525782994, 37.42037466594151, 36.62713704790388, 36.9406293460301, 36.479501724243164, 36.36662128993443, 37.411977767944336, 37.23122385569981, 36.21791941779, 38.48979275567191, 38.37937198366438, 40.14890098571777, 45.22125966208321, 45.334779330662315, 47.962004389081685, 48.27713993617466, 47.11230918339321, 48.66569014957973, 45.49292727879116, 49.4880302974156, 46.99209145137242, 50.45168290819441, 48.62835053035191, 52.918220451899934, 52.533710615975515, 54.95150307246617, 56.68206657682146, 58.90035193307059, 55.449959891183035, 60.12074048178536, 57.68595620564052, 61.912993567330496, 57.572516441345215, 66.87898227146694, 23.13850358554295, 0.7619280038135392, 0.97584040250097, 0.13087659435612814, 0.10549238896263496, 7.877786789621625, 63.42312894548689, 53.854486737932476, 44.24112592424665, 31.59368133544922, 21.142293078558787, 29.264749390738352, 35.01696498053414, 42.62086854662214, 53.783500467027935, 26.53397706576756, 0.5403826289943287, 0.026103600094627057, 0.055001424359423776, 0.011355553254751223, 0.03491369029507041, 0.02014835607925696, 0.06342827967767205, 0.009352832550315984, 0.011903489790191608, 0.052527305869651694, 0.05891125848782914, 0.02210644699100937, 0.057696416175791194, 0.0477049914188683, 0.04177017809290971, 0.04307906535853233, 0.3566185454172747, 30.21590566635132, 63.60147530691964, 47.86980874197823, 47.730664116995676, 26.437060117721558, 26.461448294775828, 25.73301305089678, 54.59862838472639, 60.43827315739223, 65.5448169708252, 14.901652131761823, 0.15348817674177034, 0.1320686446768897, 1.1061784029006958, 1.1413625606468745, 42.07200949532645, 69.81441552298409, 60.80000332423619, 62.616714068821494, 56.08185338973999, 46.5795247895377, 43.786453178950715, 45.985954080309185, 49.7558833530971, 55.389402866363525, 52.91566004071917, 51.790482657296316, 51.481715134211946, 50.93674012592861, 51.208029065813335, 51.5518467766898, 53.12679147720337, 53.85929489135742, 54.27321992601667, 52.03815467017037, 52.159744671412874, 53.992213930402485, 52.6932829448155, 47.31835453850882, 39.61271892275129, 40.695192677634104, 38.67147077832903, 39.63679790496826, 38.672888210841585, 39.287963594709126, 39.39071355547224, 40.153379099709646, 37.37198393685477, 40.44129160472325, 37.89509643827166, 38.61096586499895, 38.2202582359314, 40.208443573543, 39.836902550288606, 41.12572390692574, 39.00585978371756, 41.06636892046247, 39.21705027988979, 40.66281407220023, 40.21548557281494, 39.98477758680071, 40.90668542044503, 39.37345770427159, 39.1972096988133, 40.931222983769004, 39.466626099177766, 41.07661056518555, 38.56975609915597, 40.11867979594639, 38.44919443130493, 39.15167815344674, 39.91157831464495, 39.9721040725708, 39.31396722793579, 39.52043989726475, 41.54021174567086, 47.55134500776018, 49.429443086896626, 52.56347669873919, 42.937612601688926, 47.74746833528791, 52.064853123256135, 47.45449754170009, 41.97039556503296, 39.39354494639805, 39.51329020091465, 38.5642739704677, 38.657925265175955, 38.14624602454049, 39.11775704792568, 39.41855846132551, 39.25132574353899, 40.030889306749614, 38.56581647055489, 39.52033567428589, 38.930384976523264, 39.15635429109846, 39.927361147744314, 40.94526181902204, 40.336398124694824, 39.85610389709473, 40.04314592906407, 39.97564765385219, 41.46902745110648, 39.57855115618025, 37.3562775339399, 37.97106109346662, 38.75156961168562, 38.300982407161165, 37.88256188801357, 38.45538180215018, 37.824666023254395, 39.62779303959438, 38.889817919049946, 37.94276108060564, 39.54771505083357, 39.47186156681606, 38.14352233069283, 40.8720451763698, 39.84807525362287, 42.876722063337056, 47.52245439801897, 47.56454658508301, 52.05845035825457, 50.42737463542393, 50.445241928100586, 50.46225111825125, 48.093033518110005, 51.4034332547869, 49.723244190216064, 52.24576684406826, 52.37549665996006, 54.28785283224923, 54.69039324351719, 57.5477739061628, 58.98864269256592, 62.40721198490688, 58.56310026986258, 61.75232342311314, 60.35767405373709, 64.34532165527344, 58.75906031472342, 66.04811668395996, 24.06210504259382, 0.6495599448680878, 1.5749230959585734, 0.04361159321186798, 0.08761759168867554, 8.057348217282977, 68.74026571001325, 59.12427152906145, 49.97061743055071, 28.868775027138845, 23.58503999028887, 36.97321292332241, 45.88003921508789, 49.40041698728289, 63.638696806771414, 33.8708040373666, 0.6087998034698623, 0.02019654224360628, 0.017949934849249463, 0.032593266772372384, 0.019940737934250916, 0.01151861370142017, 0.04282042816547411, 0.056944015835012705, 0.19255967518048628, 0.16799148278576986, 0.10972646104970149, 0.13671470965657914, 0.13271906120436533, 0.09025537621762071, 0.11646555550396442, 0.10787321228001799, 0.915448505963598, 41.56911277770996, 73.17443929399762, 58.53189590999058, 53.18983595711844, 31.433264800480433, 34.59420878546578, 35.01576294217791, 61.091799872262136, 64.82192638942173, 72.79081535339355, 16.809808118002756, 0.3848719836345741, 0.3728694591139044, 2.624960162809917, 1.4262111272130693, 45.65182910646711, 71.74591050829206, 64.3199051448277, 66.09184864589146, 60.07081767490932, 48.62071098600115, 45.91218852996826, 47.71367924554007, 52.2368175642831, 58.16852249417986, 55.58421993255615, 53.967909131731304, 54.15197038650513, 52.409052985055105, 53.495323930467876, 53.65308625357491, 55.98622533253261, 55.90874249594552, 56.42059891564505, 54.2278481892177, 54.242342131478445, 55.89435625076294, 55.47340311322893, 50.19947024754116, 41.60717153549194, 42.28512464250837, 40.50829308373587, 41.55734600339617, 41.296510628291536, 41.03961835588728, 42.286712305886404, 42.49902146203177, 40.27918665749686, 43.22467047827584, 40.61292948041643, 39.46135589054653, 39.93817949295044, 42.37701456887381, 42.032707009996685, 43.1228654725211, 41.37383713041033, 41.12346921648298, 40.27251986094883, 41.93433788844517, 41.125487668173655, 42.693511962890625, 43.68083708626883, 41.90605872017996, 40.777893611363, 42.813100882938926, 41.928442341940745, 42.54758937018258, 39.860217230660574, 41.87043878010341, 40.8479905128479, 41.78343343734741, 42.15597152709961, 42.9621501650129, 41.530571120125906, 42.30034119742257, 45.84519747325352, 49.64444119589669, 50.67427887235369, 55.79791872841971, 45.75893906184605, 49.5870977129255, 53.025952271052766, 48.5429675919669, 44.47962284088135, 41.2241381917681, 41.8597628729684, 39.419916834150044, 42.567155497414724, 40.09124830790928, 41.058010237557546, 42.156826155526296, 43.193695408957346, 41.86748579570225, 40.278269495282856, 42.258964674813406, 40.22997604097639, 40.89516183308193, 42.179102080208914, 43.99059125355312, 41.25426210675921, 42.032262325286865, 42.93120288848877, 41.03648819242205, 43.670689242226736, 42.18833276203701, 40.63679306847708, 40.75147656032017, 39.57018552507673, 41.606820651463096, 39.58108377456665, 41.54626015254429, 40.34381880078997, 41.32531785964966, 39.72285829271589, 38.98744705745152, 42.683992930821006, 41.2911605153765, 40.10620083127703, 43.419897488185335, 42.4810916355678, 43.99666745322091, 50.166813714163645, 49.420250620160786, 53.30553388595581, 53.25470781326294, 52.56433480126517, 53.17601946422032, 47.66824497495379, 53.69623456682478, 51.626129967825754, 55.68355485371181, 53.53280598776681, 56.83927999223982, 57.661286626543315, 59.344501631600515, 60.81000873020717, 64.6776123046875, 60.429761614118306, 65.8817698614938, 64.51767866952079, 67.60561793191093, 63.1867025920323, 69.60209941864014, 27.978469337735856, 1.9957432406289237, 4.268897652626038, 0.23685193061828613, 0.2238017480288233, 9.927328194890704, 75.6411053793771, 62.84330177307129, 57.49820893151419, 39.24233130046299, 30.21605157852173, 43.06774541309902, 52.617002146584646, 59.6911472593035, 70.3301386151995, 39.68071052006313, 1.0245245844125748, 0.20789954704897745, 0.1360289143132312, 0.09563763812184334, 0.13927134818264417, 0.09219494821237666, 0.08588839947645154, 0.09970603231340647], [0.01138303307483771, 0.013700288687167423, 0.025981149968824217, 0.04458583379164338, 0.047540334718567986, 0.06128241268119641, 0.032965188779469044, 0.04615467460826039, 1.4602309188672473, 32.40503985541207, 54.52144432067871, 41.49326276779175, 35.36848824364798, 11.729184559413365, 42.61938163212368, 44.65793793542044, 46.42208555766514, 59.310622215270996, 54.8836921283177, 11.600893020629883, 0.25019700452685356, 0.09583378902503423, 1.5472132457154137, 1.791332666363035, 49.6242983681815, 63.824463844299316, 53.94848196847098, 57.32739789145333, 46.55286455154419, 43.08895131519863, 44.608300004686626, 53.15960781914847, 52.514512743268696, 53.61093848092215, 50.83197866167341, 52.16417414801461, 50.49967411586216, 52.41464281082153, 50.65063762664795, 52.97643940789359, 51.944510323660715, 52.71086188725063, 48.76943717684065, 47.50302376065935, 47.450425897325786, 49.87514918191092, 49.029668058667866, 49.88616555077689, 41.02129248210362, 37.41589307785034, 37.29281963620867, 36.0945611000061, 36.045770849500386, 36.700218200683594, 38.198552063533235, 37.5624166897365, 34.84239843913487, 37.46217850276402, 35.759657927921836, 37.07908957345145, 37.72006089346749, 38.14545740400042, 36.85528114863804, 36.61458512714931, 36.687982422964915, 38.479005677359446, 38.53895820890154, 39.8262995992388, 37.97390638078962, 40.28584997994559, 38.5950162751334, 37.28053522109985, 37.512702328818186, 37.09678316116333, 37.30350596564156, 38.08509145464216, 36.76332868848528, 38.55096122196743, 35.97235270908901, 37.361450467790874, 37.253746441432405, 36.669726031167166, 38.232810156685964, 38.81339120864868, 40.682491370609824, 46.693468298230854, 45.55538811002459, 49.22596856525966, 44.21231174468994, 47.78391858509609, 49.56557566779, 46.8771265574864, 41.655374663216726, 38.03524160385132, 37.24721513475691, 36.48034593037197, 36.140919481004985, 35.43231439590454, 35.472937038966585, 35.30476631437029, 36.40718139920916, 36.30117620740618, 35.35422011784145, 38.724398681095664, 37.731633118220735, 38.21844475609915, 38.39071144376482, 36.96053940909249, 37.84622975758144, 38.540222781045095, 38.39139584132603, 37.62287296567644, 38.583510058266775, 36.30198219844273, 36.425590651375906, 36.79027727672032, 36.91786009924752, 37.11454275676182, 35.60887507029942, 35.39254985536848, 35.98755884170532, 36.433779103415354, 37.3837194442749, 36.480429308755056, 36.981251989092144, 37.98964057649885, 39.44373178482056, 38.92665031978062, 38.375699860709055, 40.87244817188808, 44.43811777659825, 47.52869388035366, 47.71509320395333, 50.51664509092058, 49.05344132014683, 48.47103984015328, 51.90650715146746, 52.465913568224224, 54.78217199870518, 54.4821001461574, 54.67506551742554, 55.59161628995623, 53.86117090497698, 59.195344652448384, 55.543618134089876, 49.13140705653599, 44.68651935032436, 50.32524653843471, 52.7049628666469, 57.44357524599348, 55.918876443590435, 60.88572325025286, 18.63910378728594, 0.2771343019391809, 0.19474476150103978, 0.11067291562046323, 0.08089373034558126, 3.5996410846710205, 56.1838390486581, 54.88666248321533, 55.81720345360892, 58.73601313999721, 45.91729893003191, 17.954926831381663, 24.99003870146615, 44.91731071472168, 55.288848536355154, 34.136583055768696, 0.6338146211845535, 0.024968309228175452, 0.012475399816009616, 0.03649789992985981, 0.0027716425247490406, 0.043954867470477305, 0.05291235074400902, 0.05762761951025043, 0.04161912601973329, 0.06938459577837161, 0.02645701845176518, 0.01756795695317643, 0.08912277913519315, 0.035798696734543355, 0.011016488457763833, 0.023296772136486003, 1.5466191747358866, 40.83514329365322, 61.12492888314383, 49.443308217184885, 43.00976616995675, 22.53898869241987, 38.81772688456944, 40.968989917210166, 54.70931666237967, 62.687418937683105, 60.74102701459612, 12.467782412256513, 0.23777123700295175, 0.12260453323168413, 1.30446728851114, 2.2352376580238342, 51.64272921425955, 66.10694013323102, 56.02591691698347, 58.71518244062151, 47.97523375919887, 45.786606788635254, 45.98368896756853, 54.99954291752407, 56.21346269335066, 55.8262152671814, 52.43331956863403, 53.48510660443987, 53.51187801361084, 53.833211353846956, 52.29395954949515, 54.52067654473441, 53.415437017168315, 54.94018793106079, 50.463043212890625, 47.26527030127389, 48.12795169012887, 52.23671334130423, 50.85366398947579, 50.33387620108468, 43.0383996963501, 38.78123494556972, 39.108887672424316, 39.31604821341378, 38.36381844111851, 39.01074436732701, 40.339733260018484, 38.41269901820591, 37.89100047520229, 39.05310753413609, 36.254310607910156, 39.05397258486067, 38.63446814673287, 38.04734883989607, 38.23048945835659, 39.23510864802769, 40.19025666373116, 39.825900077819824, 40.010670048849924, 41.62293004989624, 40.353730406079976, 41.54929651532854, 39.93155091149466, 37.99294097082955, 38.64307001658848, 37.38054411751883, 37.740749154772075, 39.56743056433541, 39.49897691181728, 39.51791770117623, 38.247088704790386, 38.592556612832205, 40.31255538122994, 40.00727237973894, 39.79131541933332, 40.656063897269114, 42.591741698128835, 46.23636020932879, 47.57641758237566, 51.18474565233503, 45.3570100920541, 49.551766123090474, 52.12141840798514, 47.88954510007586, 44.15389823913574, 42.489026478358674, 40.4321825163705, 38.42459086009434, 38.739757674080984, 38.30068016052246, 37.86818259102957, 38.58059876305716, 38.81243583134243, 39.068966797419954, 36.95431382315499, 40.71083654676165, 38.84675645828247, 40.077452659606934, 41.001788888658794, 39.661867005484446, 40.71949747630528, 39.93725190843855, 39.29168782915388, 37.439169543130056, 39.632615089416504, 37.773944173540386, 39.02838931764875, 38.7133058820452, 39.20504379272461, 38.83670588902065, 38.37729794638497, 38.45581953866141, 38.16895621163504, 38.94416325432913, 39.12639365877424, 38.357252393450054, 38.998824732644216, 39.826191902160645, 41.10295813424246, 40.44751719066075, 39.88099929264614, 42.932606424604145, 44.93522664478847, 50.26687124797276, 49.59707185200283, 51.45149047034127, 50.819520541599815, 51.48992790494646, 54.2796539579119, 55.90262113298689, 56.605997698647634, 56.693072523389546, 56.508285181862966, 56.23213250296456, 55.87896946498326, 60.664833068847656, 56.38968638011387, 49.8574868610927, 45.56857579095023, 50.54021338054112, 53.79540967941284, 61.06007439749581, 57.2747027533395, 61.35282979692732, 20.521115439278738, 0.6158567305122102, 0.6493687608412334, 0.31254134486828533, 0.038407416215964725, 4.089646722589221, 60.52530629294259, 60.08331053597586, 59.093755040849956, 49.126942838941304, 41.976687158857075, 25.518558638436453, 32.19072266987392, 51.15521580832345, 59.304396629333496, 42.71330738067627, 0.889967561832496, 0.009044654667377472, 0.030573376587459018, 0.046881263476929495, 0.023644197333071913, 0.06449754230145897, 0.052749458234757185, 0.04384493801210608, 0.11478886833148343, 0.1455166387770857, 0.07678643574139901, 0.15062994297061646, 0.21148069202899933, 0.09706943522074393, 0.12331542080002171, 0.16256537394864218, 2.572909904377801, 52.47536659240723, 69.37944439479283, 56.59636402130127, 49.65427984510149, 19.90468168258667, 50.832110677446636, 58.50798715863909, 59.05974360874721, 68.68601417541504, 65.59901291983468, 14.403293456350054, 0.3531970732978412, 0.2498986662498542, 4.509164188589368, 2.4549192871366228, 54.23372636522566, 69.17132500239781, 59.04778575897217, 62.64944008418492, 49.989888259342735, 47.94127443858555, 48.428777422223774, 57.39088010787964, 57.90681512015206, 58.28959832872663, 55.30909906114851, 56.672516277858186, 56.58520868846348, 56.167437825884136, 54.195136070251465, 55.88446201596941, 56.61522838047573, 58.157704148973735, 49.80834920065743, 48.32283476420811, 48.823466369083945, 54.60789728164673, 54.1341552053179, 55.653104373386924, 44.82771021979195, 41.7470109803336, 40.32708753858294, 43.16380078451974, 41.16263621194022, 40.22686324800764, 42.34208944865635, 39.69253287996565, 38.5715765271868, 41.501809052058626, 38.683112485068186, 40.60034629276821, 41.85433285576956, 42.678924219948904, 40.19893148967198, 41.234727246420725, 41.220448698316304, 43.13341631208147, 41.459730761391775, 44.25347982134138, 41.916505336761475, 44.68501853942871, 43.88443667548043, 41.103465352739605, 40.66150433676583, 40.690123966761995, 41.105233669281006, 41.23875720160348, 39.82778303963797, 41.737790720803396, 40.69448396137783, 40.83419486454555, 42.46013239451817, 41.001337255750386, 41.558739117213655, 44.03256532124111, 44.0261903490339, 48.88190071923392, 48.91640894753592, 53.697808333805625, 48.939977237156455, 52.48979105268206, 55.236420903887065, 51.23444611685616, 45.814163344247, 44.220399447849815, 43.01780523572649, 41.74084792818342, 41.18077448436192, 41.76761933735439, 39.969078132084434, 39.33547190257481, 39.99352536882673, 40.50045204162598, 39.549952370779856, 42.67914656230381, 40.52954067502703, 42.2461313520159, 42.64376286097935, 40.77389144897461, 40.91859810692923, 42.69616617475237, 41.55903788975307, 41.00275468826294, 42.47834014892578, 41.277489934648784, 40.776451860155376, 40.71321630477905, 41.662798813411165, 42.177163532802034, 39.88418504170009, 40.5787547656468, 38.487666606903076, 39.98379441670009, 41.36660752977644, 40.30479424340384, 40.84179966790335, 42.859792777470176, 43.83704996109009, 44.77159309387207, 43.475646359579905, 45.505941254752024, 47.793072836739675, 51.87651872634888, 52.14833572932652, 53.33150972638811, 52.42845235552107, 54.0312489100865, 55.552039350782124, 58.16152218409947, 59.633331298828125, 59.22850840432303, 58.331530707223074, 59.35987104688372, 58.17674568721226, 63.08352879115513, 58.931778635297505, 51.253828116825645, 47.32903044564383, 51.5312488419669, 55.841331073216026, 62.13101414271763, 59.765902927943635, 62.85311957768032, 22.726289544786724, 1.0373657239334924, 1.492932181273188, 0.5799281927091735, 0.17938263368393692, 5.284239649772644, 65.32282202584403, 63.83855479104178, 67.09837164197648, 70.55842862810407, 55.5892539024353, 26.749826329095022, 39.62544802256993, 61.28675242832729, 70.45153059278215, 53.51177726473127, 1.6261498842920576, 0.17898299012865337, 0.11253461215112891, 0.17311491072177887, 0.10794969674732004, 0.12064523622393608, 0.1461086334394557, 0.15260879535760197], [0.016457088258383528, 0.03461977945906775, 0.0521213587240449, 0.038403711414762905, 0.011248138616792858, 0.07090908076081957, 0.05510640390483396, 0.0842359292187861, 2.8679282452378954, 35.60299342019217, 50.641903741019114, 43.60114124843052, 30.876314571925572, 15.933761869158063, 43.986040183476035, 38.67329815455845, 52.82208170209612, 53.16958890642439, 55.0756048474993, 9.392332536833626, 0.1807660444506577, 0.09715456422418356, 0.49435255037886755, 2.2918815442493985, 54.87257848467146, 63.11897155216762, 57.81414352144514, 51.68671131134033, 42.365466662815635, 48.759171213422505, 53.55607203074864, 53.86218534197126, 53.269281659807476, 56.20657702854702, 54.28825582776751, 52.606736183166504, 52.11525188173567, 50.555954524448936, 51.02499961853027, 50.10185153143746, 50.536926882607595, 51.554063252040315, 44.64778661727905, 51.29891150338309, 41.8258695602417, 46.599914278302876, 49.927503858293804, 47.98678166525704, 45.3397855077471, 40.3308812550136, 37.2762725012643, 36.2940126146589, 36.84516109739031, 38.90803262165615, 38.33447272436959, 37.720752239227295, 35.803202288491384, 36.03134291512625, 35.44486631665911, 35.770945276532856, 35.48653813770839, 35.844818523951936, 38.03339685712542, 36.36946310315813, 37.33678783689226, 39.115995679582866, 37.54460150854928, 38.818376541137695, 38.43490546090262, 36.84231581006731, 37.50191872460501, 37.29913902282715, 36.72635384968349, 36.719315324510845, 37.47947951725551, 37.059707573481965, 36.314197131565635, 37.57334968021938, 35.87078741618565, 37.57693495069231, 38.59281369618007, 37.00589377539498, 36.14968810762678, 38.65408638545445, 42.00762748718262, 46.70157337188721, 47.16063737869263, 50.12028857639858, 40.22798538208008, 39.265288148607524, 48.333163261413574, 45.88459028516497, 40.92703669411795, 37.64755991527012, 37.00157894407, 35.75278615951538, 36.49314103807722, 35.85520608084542, 35.42711366925921, 35.596875531332834, 36.041094711848665, 36.15549680164882, 37.80949115753174, 36.97985887527466, 36.26993710654122, 36.29410294124058, 37.6096887588501, 39.381201471601216, 37.44803891863142, 37.958001954214915, 39.794772148132324, 38.771014145442415, 37.80988373075213, 37.29459490094866, 36.53044244221279, 37.322682993752615, 36.785712310246055, 36.59363630839756, 36.61935159138271, 38.44886091777256, 37.040294306618826, 37.29914249692644, 36.13102872031075, 38.74431916645595, 36.87868268149239, 36.597624574388774, 38.557923316955566, 40.21906042098999, 37.33646127155849, 40.08399786267962, 40.495657784598215, 44.167405537196565, 47.86196422576904, 50.23625748498099, 51.20893580572945, 51.40110213415963, 50.0070537839617, 53.791483947208945, 52.07103354590279, 52.02642611094883, 52.04061433247158, 54.14117635999407, 51.70601340702602, 50.14371790204729, 48.75232376371111, 51.88479403087071, 45.873500960213796, 52.164327008383616, 52.028246538979666, 54.80042144230434, 50.82604142597744, 56.696921825408936, 16.533123901912145, 0.40003729558416773, 0.42125988964523586, 0.15319012344947883, 0.016601293913221786, 1.6633751839399338, 47.499570505959646, 60.62545762743269, 51.66930954796927, 48.08489717755999, 37.77021646499634, 12.679522684642247, 28.362421580723353, 44.04165356499808, 51.11350924628121, 44.45418201174055, 4.14690899848938, 0.1829922499933413, 0.014486985580463494, 0.0333457519300282, 0.026810760809374706, 0.0316755447669753, 0.07138515450060368, 0.032305805411721976, 0.05000262295028993, 0.023246833655451025, 0.04313294103901301, 0.031024799150015627, 0.07981777736651045, 0.0242066282246794, 0.06723701887364898, 0.0661165811387556, 4.000887828213828, 47.069146973746165, 58.77868897574288, 51.46585239682879, 38.318484919411794, 16.203603846686228, 39.956467151641846, 44.79212849480765, 55.987642765045166, 60.440434047154014, 59.313512665884836, 9.892014844076973, 0.4264165386557579, 0.0986050074653966, 2.141318206276212, 2.1110770404338837, 56.43502337591988, 63.701307024274556, 59.92858804975237, 55.11692578451974, 46.14305632455008, 52.1470433643886, 56.93135404586792, 55.86783845084054, 55.3626766204834, 59.541893005371094, 56.256166321890696, 55.19597543988909, 53.69849273136684, 54.461488315037315, 52.57454865319388, 52.25661645616804, 49.780063084193635, 50.207870619637625, 43.63065719604492, 50.64607266017369, 43.71560934611729, 48.55212531770979, 51.10549449920654, 50.78257002149309, 46.34074994495937, 41.48445245197841, 38.9076817376273, 37.5991587638855, 38.8791698047093, 39.43651608058384, 39.61796481268746, 38.21267775126866, 38.32444647380284, 38.06615761348179, 38.092289788382395, 38.30931677137102, 37.462897641318186, 38.49371153967721, 39.52047116415841, 38.91574512209211, 39.07806198937552, 38.92870003836495, 39.529778276171, 39.46876614434378, 40.29372228894915, 39.38345963614327, 39.71386384963989, 39.93388898032052, 38.137317589351106, 38.589513301849365, 38.602256298065186, 39.64005661010742, 38.13492740903582, 39.0521764755249, 39.613337312425884, 39.48160294124058, 39.33611808504377, 40.05669839041573, 39.50069659096854, 40.339031491960796, 42.64873429707119, 48.72315175192696, 48.35071093695504, 53.762159075055806, 42.78845909663609, 42.64917203358242, 51.16179575238909, 47.11927127838135, 42.9741427557809, 39.71135207584926, 39.2451731136867, 37.51926837648664, 38.46120439256941, 37.31965357916695, 38.66255971363613, 37.72749546595982, 36.972413880484446, 38.119186265128, 39.28293309892927, 38.83814764022827, 39.844344070979524, 38.775672912597656, 38.207306793757844, 39.58668054853167, 38.39826760973249, 39.195959023066926, 41.44651528767177, 40.78310823440552, 41.240077359335764, 39.80990185056414, 39.22728497641427, 39.133067403520855, 38.38793216432844, 37.30553831372942, 39.298990385872976, 39.5876532963344, 37.62468991960798, 39.188437598092214, 38.617948804582866, 40.23392609187535, 39.99207319532122, 39.33256755556379, 39.902545656476704, 40.15473747253418, 40.61101177760533, 41.08722741263253, 43.25465542929513, 46.539603914533345, 50.40292045048305, 53.08511618205479, 52.63238198416573, 53.0741936138698, 51.80807202202933, 54.43730163574219, 54.320974894932334, 54.28536190305437, 54.21359395980835, 55.78302526473999, 53.5906150000436, 51.730102811540874, 51.643656798771445, 53.21684013094221, 47.94132655007498, 52.86043575831822, 52.667140347617014, 53.854497160230366, 49.7681816646031, 55.04674897875105, 19.420039619718278, 0.5412654844777924, 1.0066719480923243, 1.3256966407809938, 0.04184183478355408, 1.5863833895751407, 50.238765784672324, 66.4346102305821, 56.282156058720176, 47.75540665217808, 42.844930580684114, 22.0833067212786, 33.45037201472691, 53.76018231255667, 57.48086970193045, 52.273198332105366, 6.053556791373661, 0.23628326398985727, 0.0419451926302697, 0.01131003542936274, 0.0544041947993849, 0.021623094266812717, 0.018069664049627523, 0.033308011812290976, 0.11641117770756994, 0.09667069411703519, 0.1317653123821531, 0.13287422859242984, 0.15972148440778255, 0.10175603588244744, 0.33499786843146595, 0.2628134675323963, 5.646272931780134, 60.45660250527518, 67.11615903036935, 60.31374059404646, 43.27834531239101, 23.827210766928538, 55.07858909879412, 52.4394131387983, 63.263362067086355, 63.63746697562081, 65.52180453709194, 11.038537962096077, 0.5129822450024741, 0.2251308759940522, 2.220727865185056, 2.6159772276878357, 58.638849530901226, 68.46259484972272, 62.145945821489605, 57.64192547116961, 46.92282485961914, 54.5013918195452, 59.06692804609026, 57.27232646942139, 57.32838453565325, 60.966704504830496, 57.715020520346506, 56.144661630902974, 56.69346162251064, 55.12462786265782, 54.63060399464199, 52.33133738381522, 51.040358611515586, 51.84079456329346, 44.863549028124126, 52.5849848474775, 46.985754694257466, 51.79187229701451, 53.54688651221139, 52.304562500544954, 48.86553423745291, 43.64570699419294, 40.58871153422764, 39.10910306658064, 41.59871210370745, 42.514401299612864, 41.763954162597656, 40.7510700907026, 40.518235955919536, 41.412017481667654, 38.869150502341135, 39.32729039873396, 38.477074078151155, 41.78542409624372, 41.49900892802647, 39.250540597098215, 40.80733660289219, 41.65053871699742, 40.69615500313895, 42.50520535877773, 41.7935917036874, 40.77058063234602, 40.419679233006065, 41.67200517654419, 39.88454634802682, 40.44762141363961, 40.398730414254324, 41.678793566567556, 40.66673980440412, 42.050501346588135, 41.998150144304546, 41.98688016619001, 43.065056460244314, 40.20242990766253, 41.24239458356585, 43.33500092370169, 45.8338406426566, 50.78982741492135, 52.82799114499773, 55.25617115838187, 44.874301365443635, 46.164293493543354, 52.136961528233115, 48.97185557229178, 44.78198412486485, 40.71222966057913, 40.80120134353638, 40.350746154785156, 40.64336953844343, 40.52659463882446, 41.83385304042271, 39.02326502118792, 38.63652828761509, 40.45162010192871, 42.075695514678955, 41.90219899586269, 42.21516670499529, 42.343857765197754, 39.885935987745015, 42.4359005519322, 39.479779039110454, 40.70705672672817, 44.735083784375874, 43.75188589096069, 43.023315157209126, 41.49704258782523, 40.681911196027485, 40.63500043324062, 40.75914389746529, 39.923091479710166, 41.841068744659424, 42.13178832190377, 39.791325841631206, 41.47870976584298, 39.5497647694179, 43.177853516169954, 41.46911082948957, 40.684919766017366, 41.80299956457955, 44.12583793912615, 42.380742277417866, 43.35407372883388, 45.00240182876587, 48.15224606650216, 52.46517358507429, 54.78851917811802, 55.963775702885215, 56.43409579140799, 55.310579027448384, 56.96776260648455, 54.20820563180106, 55.13611323492867, 55.900852816445486, 58.73783356802804, 53.795805726732524, 53.5125207219805, 54.159995555877686, 53.98408453805106, 47.45199966430664, 54.74753522872925, 53.240022795540945, 56.530383927481516, 51.44535173688616, 57.85415472303118, 21.472167491912842, 1.0215821308749062, 3.2486636894089833, 1.9864543676376343, 0.18290998440768036, 2.3207154827458516, 54.79762131827218, 72.54591914585659, 61.74163709368025, 63.348359380449565, 46.29185547147478, 22.244055032730103, 42.193509169987266, 61.654055050441194, 64.6876802444458, 64.13243579864502, 7.97288852078574, 0.63712049807821, 0.14460151216813497, 0.15479420737496444, 0.07668048249823706, 0.180193673021027, 0.15151061357132026, 0.11304246168583632], [0.04017196349533541, 0.007671404114392186, 0.014321886136063507, 0.06466152385941573, 0.01816982090739267, 0.01787787103759391, 0.028414254409394095, 0.007156455407052168, 4.426088052136557, 43.687965938023154, 46.00009366444179, 42.63537291118077, 27.558544533593313, 27.36241773196629, 46.72795220783779, 32.30873782294137, 57.00298302514212, 53.985019070761545, 57.561378479003906, 7.771054642541068, 0.2912929393351078, 0.10143387424094336, 1.5778336312089647, 1.8458686428410667, 56.84814589364188, 59.56839343479702, 55.730969360896516, 50.72828722000122, 52.59484781537737, 55.783688817705425, 53.97966548374721, 59.581657545907156, 51.37715516771589, 49.47773306710379, 46.156994410923545, 46.74628502982003, 48.87895815713065, 48.92311743327549, 47.66896758760725, 46.6657623563494, 46.73521307536534, 47.94046149935041, 60.15178503308977, 44.82168960571289, 46.607783113207134, 48.822292123522075, 48.6209055355617, 51.02320350919451, 47.6128956249782, 42.21624367577689, 35.099693707057405, 37.378421442849294, 35.286763531821116, 35.63849524089268, 36.56708376748221, 36.22684437888009, 36.274898120335166, 37.23546225684029, 37.07972880772182, 37.50456598826817, 35.61249508176531, 36.66235746656145, 38.22008453096662, 37.70821074077061, 37.21872752053397, 36.481190136500764, 37.543031215667725, 38.03063147408621, 39.88547740663801, 39.32838821411133, 38.912653173719136, 40.908234868730815, 37.79674121311733, 38.01552956444876, 36.35036250523159, 37.01451996394566, 35.71912561144148, 34.93825231279646, 33.25825432368687, 38.78288514273507, 38.03622824805123, 38.294850621904644, 36.96240152631487, 39.4025810786656, 38.90827580860683, 47.48880079814366, 45.07139049257551, 51.18648617608206, 34.18218755722046, 38.84321287700108, 49.433299337114605, 45.7524424961635, 40.40510538646153, 35.4140510559082, 36.96482644762312, 35.68024001802717, 37.57120268685477, 33.918541635785786, 35.13308674948556, 37.08346693856375, 37.29654039655413, 37.75390209470476, 35.36313118253435, 34.88599143709455, 36.833529812949045, 36.83669819150652, 36.87085206168038, 38.54863010134016, 38.5888705934797, 37.28873756953648, 38.94444465637207, 38.89474766595023, 39.30244364057268, 36.53148119790213, 37.79956565584455, 37.58121156692505, 38.18357869556972, 36.730804170881, 37.42571088245937, 36.04812281472342, 37.48037930897304, 37.45924983705793, 39.031974588121685, 38.27097313744681, 38.562029702322825, 38.14065967287336, 36.65342903137207, 36.660370281764436, 38.742648124694824, 36.36801092965262, 38.80542162486485, 40.04153047289167, 42.45384774889265, 49.50435856410435, 50.841122491019114, 52.17708042689732, 49.042873110089985, 50.64038208552769, 52.154464040483745, 52.791155270167756, 51.68001324789864, 52.57721676145281, 52.570543016706196, 52.5737669808524, 55.91578796931675, 58.74178014482771, 61.10401480538504, 60.148700032915386, 57.811068943568635, 58.595200947352815, 54.260049615587505, 53.96066910879952, 19.262673343930924, 0.6189023213727134, 0.27167098224163055, 0.3261377481477601, 0.09870293363928795, 0.13652936103088514, 37.200822012765066, 63.72242954799107, 52.76529060091291, 56.12469598225185, 28.431610005242483, 13.654159528868538, 20.49994601522173, 42.616421699523926, 52.315815108163015, 48.63734497342791, 12.235207097870962, 0.11419687366911344, 0.04498017120308109, 0.0444307987179075, 0.03388842048921755, 0.04121231374197772, 0.034222680410104137, 0.0262508727277496, 0.05841345127139773, 0.03314933639818004, 0.04869654142696943, 0.05168963742575475, 0.03258734316165958, 0.02020199427248112, 0.03240773494222334, 0.06812737216906888, 6.0623514737401685, 55.19228942053658, 51.56539576394217, 53.18493052891323, 32.28466926302229, 30.795826639447892, 51.40177263532366, 35.65095336096627, 62.66495541163853, 57.221875599452424, 62.677059173583984, 8.305300763675145, 0.20514645906431334, 0.011719605103800339, 2.976665164743151, 2.1151202406202043, 58.369030135018484, 60.901044028145925, 57.02577659061977, 51.41485609327044, 53.14599282400948, 58.20097058159964, 56.13420111792428, 60.01630905696324, 55.509961060115266, 49.28555284227644, 47.885358810424805, 48.88205705370222, 48.34101472582136, 49.10340234211513, 48.75758007594517, 48.75280318941389, 47.94802113941738, 49.58097982406616, 58.96036352430071, 45.49207959856306, 48.48788227353777, 52.35101120812552, 51.934793267931255, 52.30857508523123, 47.95667512076241, 44.19667134966169, 36.93538345609392, 39.205561433519634, 37.702582699911936, 37.52427455357143, 38.60054704121181, 39.39616789136614, 38.6574249948774, 40.36320774895804, 39.287421635219026, 37.79913486753191, 37.16411120550973, 37.415389333452495, 39.65878895350865, 38.0251840863909, 39.00830554962158, 39.616578647068565, 39.53495468412127, 40.52928359167916, 40.128716468811035, 39.5526065826416, 41.517828123910085, 42.242956025259836, 39.565148081098286, 40.4444009235927, 37.61510835375105, 39.093775340488975, 38.13622324807303, 36.88479709625244, 35.85725579942976, 40.41115031923567, 40.54907553536551, 40.138843468257356, 39.902649879455566, 43.03211852482387, 40.77469049181257, 51.568821225847515, 48.309230191367014, 53.111213615962434, 37.40661028453282, 42.063682079315186, 50.32359634126936, 47.92521367754255, 42.93144954953875, 37.112472193581716, 39.46122734887259, 38.28987571171352, 39.49697930472237, 37.37824773788452, 36.768390451158794, 39.52501876013619, 40.14406851359776, 39.28501755850655, 37.70589351654053, 37.9089025088719, 39.95774909428188, 38.224663393838064, 39.853435788835796, 40.336988721575054, 40.683015959603445, 39.97906616755894, 41.317184993198936, 40.271620069231304, 39.48163420813424, 39.02709347861153, 39.70720052719116, 39.3292567389352, 39.80190794808524, 38.04980502809797, 39.53094209943499, 39.30939531326294, 39.53287717274257, 38.239824363163535, 40.81404856273106, 39.82247461591448, 39.451232365199495, 39.118747166224885, 40.325756958552766, 39.313883849552695, 41.311345032283235, 39.39204066140311, 41.897717407771516, 40.82356064660208, 42.823502336229595, 50.869575364249094, 50.95395776203701, 52.69670493262154, 52.342562198638916, 53.18284954343523, 53.57401922770909, 54.07658243179321, 52.29209395817348, 53.57045480183193, 54.705307551792686, 54.37670292173113, 57.13562066214425, 59.75515406472342, 62.11991786956787, 60.971429279872346, 60.64911624363491, 57.48911026545933, 56.47238383974348, 56.42118951252529, 22.241840294429235, 0.8263815566897392, 0.716863887650626, 1.0153022621359145, 0.39750796130725313, 0.22277899219521455, 40.036781379154746, 70.70825263432094, 55.61168616158621, 59.20265415736607, 28.781865222113474, 18.329474687576294, 29.360964570726665, 49.45203168051583, 58.089959212711875, 58.358190945216585, 14.943454231534686, 0.020269637428490177, 0.07079147707138743, 0.04141577246731945, 0.007758828262532396, 0.014299879549071193, 0.06007621490529605, 0.07658320771796362, 0.18679617159068584, 0.06612703736339297, 0.10668751304703099, 0.16497140484196798, 0.1903882274138076, 0.14634361011641367, 0.11051149892487697, 0.12552080888833317, 9.951869232313973, 68.04072107587541, 60.68517739432198, 59.71780054909842, 39.014472075871055, 37.69203186035156, 58.29601846422468, 44.99581493650164, 67.94844899858747, 63.025400161743164, 68.3679256439209, 9.573996663093567, 0.3500512492443834, 0.42485590811286655, 3.9395977684429715, 2.371413665158408, 61.67175906045096, 63.289181573050364, 60.22390038626534, 54.98966952732631, 57.037098680223735, 60.73011834280831, 58.272724628448486, 63.22855854034424, 55.585210050855366, 51.728664534432546, 47.19671589987618, 49.50007152557373, 50.11061320986067, 50.26098264966692, 49.071940898895264, 50.99326719556536, 48.08038779667446, 49.36922652380807, 57.2292024748666, 47.06832708631243, 52.374794891902376, 53.91436283929007, 54.48586259569441, 54.873099599565776, 50.49394532612392, 46.2396571295602, 38.22039025170462, 40.67548758643014, 40.15604025976998, 38.81990514482771, 39.90455021177019, 41.20950181143624, 39.92210136141096, 41.63427298409598, 41.1279091153826, 40.42722845077515, 39.20041281836373, 40.88632719857352, 41.72769846235003, 41.28203405652727, 40.68461057118007, 41.803930623190745, 40.77988427025931, 41.84434482029506, 42.73189728600638, 40.35361923490252, 44.52363967895508, 44.273094585963655, 40.08020067214966, 42.57229716437203, 39.371835299900596, 40.52994367054531, 39.75061634608677, 39.64548315320696, 37.641886711120605, 43.20145654678345, 42.916816643306184, 41.641978536333355, 42.507626805986675, 44.30745342799595, 42.5106075831822, 52.17054912022182, 50.88238089425223, 54.533461230141775, 41.07934120723179, 43.78837088176182, 51.273870195661274, 50.042764050619944, 45.24748911176409, 38.50376558303833, 40.648844718933105, 40.17555774961199, 43.141747202192036, 39.519877093178884, 39.386388301849365, 43.03757286071777, 41.92072636740548, 41.478331089019775, 39.0853020123073, 39.3772166797093, 43.30604430607387, 40.58141245160784, 41.483528341565815, 43.31100879396711, 43.729908738817485, 40.649206025259836, 43.19269486836025, 42.02659954343523, 41.86456060409546, 41.33452769688198, 41.62951694216047, 41.49219969340733, 41.78690753664289, 42.163006578172954, 42.271561758858816, 40.593019417354036, 41.82108572551182, 40.11385079792568, 43.2510666847229, 42.308494908469065, 42.98412036895752, 41.78164080211094, 41.892110211508616, 40.73826803479876, 43.6924718448094, 40.124325207301546, 44.1369446345738, 44.47837216513497, 45.16971445083618, 52.49670103618077, 54.46500062942505, 57.16167640686035, 54.47337320872715, 55.49469239371163, 55.18340614863804, 55.61787353243147, 53.491696970803396, 54.99518987110683, 55.71308469772339, 56.02756711414882, 57.787521498543875, 61.99449593680245, 65.46496827261788, 62.582612310137065, 63.953630856105256, 62.35396793910435, 57.19312742778233, 59.126821517944336, 23.638214554105485, 1.6928428198610033, 2.1585658064910342, 2.5328884976250783, 0.681781890136855, 0.41218467376061846, 44.5808059828622, 76.21909127916608, 63.67741911751883, 67.09587029048375, 36.523442132132395, 22.027887889317103, 31.29326207297189, 59.574327196393696, 68.02508762904576, 71.18300914764404, 18.929812942232402, 0.17409308680466243, 0.13143718641783508, 0.12704653558986528, 0.1606880711125476, 0.1067224033176899, 0.1180076077580452, 0.109878717522536], [0.03243006213701197, 0.06738588945674044, 0.03162387432530522, 0.041237280437988896, 0.04461787421522396, 0.062279587744602134, 0.08817327115684748, 0.10607105719723872, 15.901219981057302, 53.08556434086391, 50.741804940359934, 43.2096380506243, 28.03329062461853, 14.119681886264257, 24.567150490624563, 39.78170953478132, 54.911523137773784, 54.20530128479004, 53.349967615945, 6.476179667881556, 0.35473889485001564, 0.3162876995546477, 2.012344006981168, 0.5628219449094364, 50.54401057107108, 62.08693477085659, 54.8577892439706, 52.441021646772114, 51.85881124223982, 54.712818554469514, 55.91451644897461, 45.98375844955444, 42.50747047151838, 49.70458132880074, 45.59312377657209, 50.05165427071707, 49.04059757505144, 53.4062237058367, 50.50819608143398, 50.746324743543354, 47.975185121808735, 40.30002083097185, 39.045547894069124, 58.11351013183594, 44.39201647894723, 46.31209557397025, 48.3065481867109, 48.6710159437997, 48.01226070949009, 44.27486637660435, 36.69955117361886, 35.79658760343279, 35.8476916040693, 35.31345156260899, 36.25444262368338, 37.51702063424246, 36.27223348617554, 36.51546907424927, 36.46752997807094, 37.72197164808001, 36.69364867891584, 37.438655376434326, 37.62561750411987, 37.94693347385952, 39.484951972961426, 37.169864313943044, 37.783921786717, 38.78410802568708, 38.8193736076355, 40.56935385295323, 38.39546748570034, 37.93770974023001, 37.099083014896934, 38.8514221736363, 36.68319511413574, 38.186684540339876, 36.661666120801655, 35.56786332811628, 35.687900406973704, 37.88510840279715, 40.15699911117554, 40.751351492745535, 38.07636799131121, 39.962348801749094, 38.02575731277466, 46.267675740378245, 44.41086694172451, 52.06623234067644, 37.19768837520054, 41.825032302311485, 52.4607823235648, 43.285686084202354, 39.65070819854736, 36.76335300718035, 36.48890611103603, 37.345219475882395, 38.51727635519845, 36.498762130737305, 35.07493380137852, 37.97820731571743, 35.572094781058176, 36.87469094140189, 36.720201219831196, 34.644798619406565, 37.03354760578701, 36.970680304935996, 36.63031932285854, 38.99054247992379, 37.40365730013166, 39.220090116773335, 39.24488476344517, 40.125621046338765, 38.96547337940761, 38.242645331791465, 35.606728076934814, 37.283932890210835, 37.24808018548148, 36.82438250950405, 37.77881833485195, 39.65427957262312, 37.22574520111084, 39.269867011478965, 36.16502973011562, 37.27803039550781, 37.24793427331107, 37.16300296783447, 37.612693854740684, 36.574421065194265, 38.50434228352138, 36.54670122691563, 37.83038439069475, 37.04634966169085, 37.77128301348005, 42.674380098070415, 48.516415051051546, 50.74130119596209, 53.48321322032383, 53.60672092437744, 52.403581278664724, 51.81268562589373, 54.2678177016122, 56.53998286383492, 55.61405897140503, 55.068038259233745, 54.35125167029244, 53.141813482557026, 53.75495726721627, 52.92641237803868, 55.50843940462385, 58.00766127450125, 58.275337151118684, 60.290491921561106, 28.382826702935354, 0.45151012071541374, 0.5354331231542996, 0.7673800055469785, 0.054971080273389816, 0.029009299086672918, 28.078202043260845, 63.14308180127825, 56.00482218606131, 46.002007893153596, 50.113003390175955, 43.8409548486982, 15.872779267174856, 36.89386102131435, 41.489924158368794, 54.75757884979248, 15.857246569224767, 0.25668936329228537, 0.03526398399844766, 0.06694735227418797, 0.0035877153194243355, 0.0660673330671021, 0.06467267897512231, 0.053957423594381125, 0.09666455337511641, 0.03586484711351139, 0.015152943952541267, 0.02229599065945617, 0.04960692168346473, 0.04388487319062863, 0.12313145638576575, 0.08191596370722566, 19.44993598120553, 62.19597979954311, 57.607702119009836, 50.48617376599993, 30.821065970829554, 17.28528376988002, 33.18625014168875, 42.033884729657856, 59.30957303728376, 59.978927748543875, 59.93295151846749, 6.807120629719325, 0.2279830165207386, 0.3424494042992592, 3.348518205540521, 0.8556744562728065, 50.901484966278076, 63.60403224400112, 56.48762123925345, 56.271514892578125, 54.27206652505057, 58.5605502809797, 57.8508334841047, 47.68767213821411, 43.38743550436837, 49.026364190237864, 45.65497316632952, 49.19513940811157, 50.740363189152305, 53.55345950807844, 51.23007222584316, 51.585861682891846, 48.68465525763375, 43.812369959695, 43.77434594290597, 53.9732939856393, 46.4849076952253, 50.87528330939156, 49.42756012507847, 51.24642481122698, 50.32508325576782, 45.49879503250122, 38.07580518722534, 39.141162054879324, 36.83689968926566, 39.05567141941616, 38.740626198904856, 39.304493359157014, 36.86498083387102, 38.503762108939036, 37.891191550663535, 39.34827395847866, 38.471466881888254, 39.59462581362043, 39.28928027834211, 40.191493443080354, 40.614447661808555, 38.60922186715262, 39.42392941883632, 40.09339182717459, 40.7309376852853, 40.687261308942524, 39.91831806727818, 39.05431304659162, 39.02044057846069, 39.13175766808646, 38.24952752249581, 40.218070302690776, 38.49607392719814, 37.47552946635655, 37.08411659513201, 41.352214336395264, 42.48337064470564, 42.29637030192784, 40.52972132819039, 43.797420910426546, 42.07925994055611, 47.92214952196394, 45.66473191125052, 54.29175771985735, 40.680201939174104, 44.35511807032994, 52.69579471860613, 44.963919230869834, 42.24355009623936, 39.72388315200806, 39.24956784929548, 39.60819217136928, 39.946142128535676, 38.78631060464041, 37.61398621967861, 38.5283830506461, 36.83703865323748, 38.12731218338013, 39.31743090493338, 35.87750285012381, 39.28133153915405, 39.714638573782786, 38.928825105939595, 40.21134444645473, 39.259062562670024, 42.167304039001465, 40.15786068780081, 41.90539864131382, 41.2814747265407, 39.91570554460798, 36.99475581305367, 38.50215012686593, 38.842472893851145, 38.639686243874685, 38.95317159380232, 41.63866424560547, 38.56034823826381, 39.309287616184776, 37.979781082698274, 39.46862718037197, 39.63636711665562, 39.953660079411094, 39.20423780168806, 39.28732088633946, 39.472507749285015, 38.89498390470232, 39.51918922151838, 39.756810665130615, 39.15697268077305, 44.000054700034006, 51.75768715994698, 52.16858625411987, 54.9934458732605, 55.315904821668354, 54.316962310246055, 53.70828969138009, 54.403915541512625, 56.37789181300572, 56.49597297395979, 55.22074924196516, 55.836658409663606, 54.88551255634853, 55.863172735486714, 55.656210218157085, 56.29769917896816, 59.829729080200195, 60.63102313450405, 62.99772548675537, 29.759117194584437, 0.349903545741524, 0.7071428692766598, 2.4807450899056027, 0.2008848384554897, 0.05571549425699881, 29.62488842010498, 67.89328724997384, 62.55154691423689, 52.066482475825715, 47.27689463751656, 31.01652921949114, 16.93619932447161, 43.97273785727364, 48.059838499341694, 65.22752748216901, 20.65888605798994, 0.19967400628541196, 0.03718501841649413, 0.0618652267647641, 0.03784808962206755, 0.027597759650754075, 0.045496661881250997, 0.006241610814218542, 0.17608924183462346, 0.1701136553393943, 0.13435998958136353, 0.1057731599680015, 0.12301563045808248, 0.24161350939955029, 0.2366935605449336, 0.13404763277087892, 25.550007922308787, 74.56767817905971, 66.92057418823242, 59.75297927856445, 38.820151805877686, 21.2370091847011, 35.277578013283865, 53.19881302969796, 65.53910555158342, 64.04948820386613, 63.45655672890799, 8.486495886530195, 0.48324737484966007, 0.7091343966977937, 5.886940726212092, 1.0069892853498459, 54.45751741954258, 65.2995525087629, 59.35859257834298, 58.81862027304513, 55.99728339059012, 59.74912302834647, 58.967554909842356, 49.580691473824636, 45.16079296384539, 50.542148453848704, 46.42762327194214, 48.796969413757324, 53.1714961869376, 57.68252379553658, 53.242312226976665, 52.98786572047642, 52.6331775529044, 46.17759581974575, 46.39251749856131, 52.38700982502529, 45.90859283719744, 53.16527754919869, 50.94378559929984, 53.15634216581072, 51.145919118608745, 48.993582589285715, 40.442514487675254, 40.50546864100865, 38.93682943071638, 39.945061683654785, 40.92237792696272, 41.77934789657593, 39.69674696241106, 41.00498158591134, 39.88892023903983, 41.38290105547224, 41.039152826581685, 42.292705127171104, 42.484124524252756, 41.487085819244385, 43.974850109645296, 40.854358536856516, 40.2597073827471, 42.79478543145316, 43.14817428588867, 44.14014775412423, 43.160430908203125, 40.67399024963379, 40.42739520754133, 42.18204116821289, 40.12825788770403, 40.78933382034302, 41.1315986088344, 39.505299772535054, 38.632140500204905, 43.349425383976524, 46.11541291645595, 44.704668045043945, 41.77334117889404, 44.92310551234654, 43.80333382742745, 50.9913147517613, 48.296692167009624, 57.026283809116904, 45.534540040152415, 47.873334952763145, 55.426610469818115, 48.50377975191389, 43.08999007088797, 41.64677974155971, 40.312214919498985, 43.22182171685355, 43.304588658469065, 39.69814007622855, 38.09290470395769, 42.44224773134504, 38.06889520372663, 40.885340554373606, 40.21840034212385, 37.314921855926514, 41.44636937550136, 41.7006630216326, 40.717395646231516, 41.68574871335711, 40.541317871638704, 43.40854065758841, 42.16825246810913, 42.79426779065813, 42.9915132522583, 42.602872712271555, 38.863953249795095, 41.02749374934605, 41.17715447289603, 39.72876426151821, 42.16212068285261, 44.5582069669451, 40.513219356536865, 41.91660261154175, 38.683762141636436, 41.30400078637259, 41.43613815307617, 42.03928695406233, 41.332936559404644, 40.86255046299526, 41.699638162340435, 41.37823534011841, 41.70573173250471, 42.339699268341064, 42.54597738810948, 47.301946367536274, 54.43441118512835, 55.493882928575786, 56.80194732121059, 58.896335874285015, 57.91440602711269, 55.59072344643729, 57.725178786686485, 59.47061838422503, 60.75883524758475, 58.237153325762065, 58.79410702841622, 56.805046217782156, 60.27824919564383, 58.63074793134417, 59.772753851754324, 62.1377261025565, 64.20088945116315, 63.97089712960379, 35.10366112845284, 0.7099251342671258, 4.708970929895129, 7.031412822859628, 0.20261764047401293, 0.08252547814377717, 32.5773412840707, 73.41691752842495, 64.86243438720703, 60.51056916373116, 60.267173767089844, 53.68648624420166, 23.668182134628296, 52.74429314477103, 56.071636063711985, 74.98772457667759, 27.770843267440796, 0.466237370456968, 0.2159721731607403, 0.13801646551915578, 0.14142219562615665, 0.179013212078384, 0.1122604568621942, 0.18997923364596708], [0.05659021410558905, 0.0738156737227525, 0.020402506459504366, 0.04300088116100856, 0.06456023893718209, 0.058338147455028126, 0.061466444948954244, 0.10653670185378619, 14.796661376953125, 53.26506062916347, 45.903333050864084, 41.57817322867257, 19.76580282620021, 25.39302727154323, 41.874986376081196, 34.381041526794434, 62.344101497105186, 49.98883213315691, 56.618827547345845, 4.0221119693347385, 0.12224332189985684, 0.1700123364904097, 0.7978089898824692, 0.12406461845551219, 31.368365151541575, 68.9815696988787, 50.641201972961426, 59.131254468645366, 52.720589365277974, 59.979219572884695, 35.877429894038606, 42.187311376844136, 52.270822048187256, 56.07973418916975, 51.68882008961269, 54.91498334067208, 50.649216720036094, 52.36619302204677, 48.45761244637625, 50.131277152470176, 49.232888971056255, 50.66520799909319, 39.14611612047468, 37.741339751652305, 50.22818367821829, 44.52205548967634, 49.60927636282784, 45.80328246525356, 49.132758481161936, 45.373557226998464, 38.2675233568464, 37.61367702484131, 35.53091628210885, 36.860155309949604, 36.354020731789724, 35.76362187521798, 35.336668968200684, 36.76901926313128, 36.35461827686855, 36.568716594151084, 35.48098305293492, 36.756248474121094, 34.806587423597065, 36.34536327634539, 37.90032148361206, 38.279991899217876, 38.31062650680542, 39.405072007860454, 38.24652590070452, 36.22874471119472, 38.62927436828613, 37.44017703192574, 36.13924496514456, 37.96279273714338, 35.79576424189976, 37.88320459638323, 35.986401966639924, 35.727724007197786, 35.52106026240757, 38.73698534284319, 40.86814376286098, 41.833773136138916, 38.56056363242013, 40.38710955211094, 40.009117126464844, 45.76338938304356, 43.73148945399693, 48.69183622087751, 40.369902338300435, 42.6103698185512, 50.972502504076274, 44.98160934448242, 40.11155094419207, 38.99266168049404, 39.75232212884085, 38.75005143029349, 39.70190599986485, 37.351952280317036, 35.384802613939556, 37.582667214529856, 37.32003573008946, 36.82146079199654, 35.29542098726545, 35.813263280051096, 37.24927180153983, 35.22312845502581, 38.589735644204275, 37.14620917184012, 38.60584504263741, 36.40022625241961, 37.27813809258597, 37.27352796282087, 37.23101193564278, 37.84797722952706, 37.02109643391201, 36.56490550722395, 37.88976716995239, 36.9302522114345, 35.97956146512713, 37.02928141185215, 37.89295639310564, 36.0648193359375, 37.426367487226216, 36.37028646469116, 36.946993895939414, 35.659638609204976, 37.376441206250874, 35.43224491391863, 36.86050966807774, 37.302161489214214, 37.573283672332764, 38.16033697128296, 37.8896073613848, 35.84962667737688, 40.30823360170637, 43.54899501800537, 45.4866669518607, 50.587718214307515, 52.607302461351665, 51.04302671977452, 53.098112787519185, 50.42339331763131, 51.327576296670095, 52.04364374705723, 50.838423115866526, 49.11063541684832, 52.741513865334646, 51.88336270196097, 54.16731200899397, 55.79094621113369, 56.44898578098842, 61.20718165806362, 38.25421060834612, 0.8399872151868684, 0.2847763161574091, 1.0271001947777612, 0.13244810860071862, 0.12699306703039578, 19.374167612620763, 65.2800350189209, 54.95145443507603, 54.8303473336356, 56.301072529384065, 38.647541182381765, 21.282862084252493, 29.111044815608434, 43.026563440050396, 54.21621690477644, 25.316220147269114, 0.8339052615421159, 0.05508519629282611, 0.02977178245782852, 0.02625711016090853, 0.013413925705078458, 0.07158085757068225, 0.06868320091494493, 0.08016872924885579, 0.05970008258840867, 0.018290442381320254, 0.039567873946258, 0.07316618000290223, 0.010647294161442136, 0.048219382031155486, 0.06065063551068306, 19.602030311311992, 63.600134304591585, 52.780006885528564, 49.50285080501011, 30.647211619785853, 30.490988322666713, 37.70366314479283, 40.482758453914094, 68.84656620025635, 55.069994177137104, 61.940022059849326, 4.301873368876321, 0.060758454725146294, 0.524786365883691, 3.5969158709049225, 0.3805711572723729, 32.86108486992972, 71.95788615090507, 53.847746985299246, 60.53119141714913, 54.18303230830601, 62.28186648232596, 38.651015281677246, 43.477866309029714, 51.171551023210796, 55.24388326917376, 50.18085602351597, 56.40715067727225, 53.84137201309204, 54.503361633845735, 49.9951410974775, 52.06231355667114, 49.64825923102242, 52.576466356004985, 39.2882901600429, 41.6981269291469, 49.60388803482056, 48.25448186056954, 50.25674077442714, 48.53908702305385, 49.729462827954976, 46.18456138883318, 40.88613264901297, 38.12634638377598, 36.728132588522776, 38.984535762241904, 37.227746282305034, 38.09262677601406, 37.13682910374233, 39.145949363708496, 38.40651164736067, 38.7107697895595, 35.59556926999773, 38.13117190769741, 36.01019607271467, 39.65235144751412, 38.38724776676723, 39.51445402417864, 39.785562310900005, 41.02762923921858, 39.209712982177734, 38.21280281884329, 39.701551641736714, 39.0949113709586, 38.47708797454834, 39.67679868425642, 38.13414226259504, 39.83763905933925, 38.18954372406006, 38.066487652914866, 37.92819765635899, 40.59047637666975, 41.40115744726998, 43.047717230660574, 40.473103931971956, 42.94772917883736, 43.71918419429234, 46.166405745915, 45.758584703717915, 48.76026208060128, 43.22249569211687, 45.06888566698347, 52.58097573689052, 46.741918087005615, 42.34560176304409, 40.54213081087385, 42.15218823296683, 40.77915818350655, 42.91994333267212, 38.82552623748779, 38.23826101848057, 41.049390997205464, 38.65787662778582, 37.30183492388044, 37.59098073414394, 38.47367293494088, 39.16860743931362, 36.436033793858115, 39.5567546572004, 40.21408551079886, 38.43934188570295, 38.2530745778765, 39.58900472096035, 38.63017763410296, 41.09198692866734, 38.9561037336077, 38.98842675345284, 39.04055213928223, 38.6907103402274, 39.72349405288696, 37.323482036590576, 38.96412542888096, 38.54916163853237, 38.26070717402867, 38.49414232798985, 38.385090351104736, 38.539802415030344, 38.46292059762137, 38.7621100289481, 38.57763188225882, 38.52704552241734, 40.331579548971995, 38.15914535522461, 40.36106422969273, 39.803321906498496, 39.55302347455706, 40.994208403996055, 44.1591545513698, 46.63713925225394, 53.078689098358154, 55.46733038766043, 53.01016248975481, 55.331166539873394, 52.6118882724217, 51.97127825873238, 53.35546016693115, 53.60729762486049, 53.35981668744768, 54.90066657747541, 53.63821016039167, 55.38330929619925, 57.47513396399361, 57.99939291817801, 63.115664209638325, 41.08337116241455, 1.0142730602196284, 0.3949824811092445, 2.929251743214471, 0.44953509526593344, 0.1570798118731805, 20.294842141015188, 70.31629085540771, 60.825676918029785, 58.37509591238839, 57.94254970550537, 41.204766614096506, 26.791958468300955, 36.255596024649485, 49.065392221723286, 61.94827651977539, 33.17497321537563, 1.0419750937393732, 0.07860606988625866, 0.00782815333721893, 0.035684824987713776, 0.07505248699869428, 0.017594414729891077, 0.030148121727896587, 0.21248970074313028, 0.15865972638130188, 0.13096541459006922, 0.15230843504624708, 0.16214242950081825, 0.14578548792217458, 0.16963142050164087, 0.22082181221672467, 25.16857440131051, 72.81405012948173, 60.16363865988595, 58.040790285382954, 32.59238065992083, 35.33684614726475, 54.172582217625205, 46.67417662484305, 72.89027186802456, 59.8842168535505, 67.98241179330009, 5.28705540725163, 0.1756371068102973, 0.7046345153025219, 5.37408333165305, 0.3499743033732687, 33.7980112348284, 76.10941396440778, 54.146248544965474, 64.03854479108537, 56.42406606674194, 64.33094583238874, 40.904941422598704, 43.68397419793265, 51.037555013384136, 56.956131322043284, 51.98367037091936, 58.028158460344585, 55.34206131526402, 57.36018296650478, 52.415938649858745, 55.7221486227853, 54.15352330889021, 55.52617468152727, 43.523651463644846, 47.08325181688581, 49.34495299203055, 48.38116141727993, 52.91173083441598, 50.61656366075788, 54.55418423243931, 49.724057129451204, 41.206607886723106, 41.326224599565776, 38.97228608812605, 42.442386695316856, 40.941541058676584, 40.628924233572825, 39.32476820264544, 40.992141314915244, 40.04325015204293, 41.38874796458653, 38.71967738015311, 40.73443957737514, 37.238053934914724, 40.93079219545637, 41.33148438589913, 42.564789635794504, 41.26821756362915, 44.20875079291207, 41.78464937210083, 39.78593751362392, 41.983708313533235, 41.423277037484304, 40.51054777417864, 40.665798323495046, 40.174293177468435, 42.60020807811192, 38.56377370016915, 40.553195817129954, 39.949056897844585, 43.991828032902305, 44.92381770270211, 46.41649225779942, 42.28095572335379, 45.22402851922171, 45.86100809914725, 49.95681830814907, 48.81751871109009, 51.46898603439331, 46.66196516581944, 46.87103646142142, 55.41827610560826, 50.28817442485264, 44.95346219199044, 43.85593169076102, 42.53570795059204, 42.28043113436018, 45.79312072481428, 42.47452558789934, 41.69515310014997, 42.899248123168945, 40.23897395815168, 39.60253981181553, 38.736731733594624, 39.57898541859218, 41.71462542670113, 38.030530725206646, 41.44529587881905, 42.51059021268572, 40.341501576559885, 40.72665064675467, 41.5725417137146, 40.86436741692679, 42.96336609976632, 40.77860232761928, 42.13241365977696, 40.22494207109724, 42.56484522138323, 41.72078847885132, 38.700236320495605, 40.28027752467564, 42.7314248085022, 40.4024407523019, 40.412647656032014, 41.081873825618196, 40.37047903878348, 41.483820165906636, 41.86739894321987, 39.90678405761719, 40.663224015917095, 42.158900192805696, 40.3598587172372, 42.383809907095774, 41.59253862925938, 40.851999623434885, 43.819741998400005, 46.94496182032994, 48.80181578227452, 56.44479949133736, 58.907723971775596, 55.54922533035278, 57.576073919023784, 55.78419951030186, 54.217147963387625, 57.14914533070156, 56.63525308881487, 55.38392768587385, 57.63386903490339, 57.31680883680071, 60.0036563873291, 59.89106777736119, 61.78404194968087, 66.85398265293666, 44.95849963596889, 1.7339426087481635, 2.386716855423791, 6.146769915308271, 0.8472389089209693, 0.2199059392192534, 23.29400600705828, 76.69125611441476, 65.87571103232247, 66.79426288604736, 65.68465641566685, 50.071630341666086, 33.06702947616577, 45.16852283477783, 58.95465905325753, 71.8526278904506, 42.275411060878206, 1.7449890502861567, 0.1904219641749348, 0.1613036109400647, 0.12084586545825005, 0.1394969475056444, 0.2006230325038944, 0.17960462320063794], [0.039364367723464966, 0.033832176721521785, 0.09264402982911893, 0.0521668409263449, 0.03625374606677464, 0.03963460786534207, 0.042979863538805924, 0.0355047350084143, 18.646578311920166, 53.8974335534232, 46.15096337454659, 37.21561125346592, 17.4849419934409, 17.61153643471854, 47.84277677536011, 37.615295955113, 61.00075762612479, 50.29188476290022, 53.20767893110003, 2.656156054564885, 0.09452438607279744, 0.2717894273144858, 2.714843362569809, 1.0811431748526437, 8.45328870841435, 67.15921701703752, 57.51072611127581, 59.602133887154714, 54.970332690647666, 45.47679008756365, 44.92594037737165, 63.080728667122976, 52.800073283059255, 54.728545801980154, 51.20741762433733, 52.12623698370797, 50.33377545220511, 49.60388803482056, 48.57956027984619, 49.559381348746165, 45.26207685470581, 46.05731555393764, 45.57606247493199, 34.98550353731428, 32.95198120389666, 48.2345301083156, 47.2530379976545, 48.60949659347534, 45.55019780567714, 43.931295326777864, 38.91252810614449, 37.17902898788452, 35.00023719242641, 35.74718591145107, 35.30205651691982, 36.34695788792202, 35.93580865859985, 34.29949746813093, 35.063010692596436, 38.15227358681815, 35.786446707589285, 36.89572661263602, 34.24797657557896, 38.35959046227591, 35.169710704258506, 37.69039555958339, 36.18343203408377, 39.27104473114014, 35.281350885118755, 37.019779750279014, 36.07246582848685, 39.016695499420166, 36.56275156566075, 36.44651515143258, 36.465695653642925, 37.94810424532209, 36.618986810956685, 37.78014196668352, 34.1639381136213, 38.01221874782017, 40.811790398189, 42.20230558940342, 38.52409601211548, 44.099302768707275, 40.09225927080427, 44.13925838470459, 44.49616302762713, 48.44693653924124, 44.12370484215872, 45.34748758588518, 48.13291965212141, 43.98041214261736, 41.09660053253174, 39.05204793385097, 39.00639826910836, 41.16027382441929, 39.834123270852224, 36.13580213274275, 36.07418898173741, 36.7553973197937, 36.13879680633545, 36.30449397223336, 34.640244075230186, 34.763015270233154, 36.25423070362636, 36.93059614726475, 37.190830503191265, 36.16211148670742, 37.205272333962576, 38.76171745572771, 38.143053327287944, 37.526119300297324, 38.25835868290493, 36.69711930411202, 37.10727841513497, 36.19936077935355, 37.13225024087088, 37.635532583509175, 34.9429840360369, 35.91894538061959, 37.509426253182546, 36.2219945362636, 38.41635724476406, 37.085005964551655, 36.23642941883632, 35.250077043260845, 37.55187627247402, 36.547871998378206, 35.79618460791451, 38.746636390686035, 36.36206327165876, 37.07928759711129, 38.0073550088065, 39.236776215689524, 37.134508405412944, 37.65204497746059, 39.840908186776296, 37.3551276070731, 41.714389187949045, 39.83883762359619, 39.95985092435564, 42.66900566646031, 42.93610136849539, 40.32879332133702, 39.77894762584141, 39.12524025780814, 39.17613928658621, 41.33724791663033, 47.16413232258388, 51.5153409412929, 59.921910830906455, 56.61259848730904, 49.9266631262643, 2.2020118066242764, 0.19890927017799445, 1.125969912324633, 0.5912991911172867, 0.337170021874564, 10.314674632889883, 63.05440889086042, 56.74988446916853, 55.11144018173218, 42.72668266296387, 18.71865545000349, 15.421509402138845, 28.164149522781372, 37.22766637802124, 56.10792303085327, 35.70252289090838, 1.4252889709813255, 0.15250534590865883, 0.035741808358579874, 0.012675935751758516, 0.03639655393947448, 0.03411908846880708, 0.020069198183981434, 0.039431284847004075, 0.04125442023255995, 0.14106923528015614, 0.04509877912434084, 0.021467675820791295, 0.1301985207412924, 0.008324757850329791, 0.051402664610317776, 24.856760093144008, 62.554235867091585, 50.58436918258667, 44.74086468560355, 19.756163937704905, 20.566574028560094, 46.949162006378174, 42.5389666557312, 65.35708359309605, 55.931112221309114, 58.62400817871094, 2.8592497280665805, 0.11117666680365801, 0.35534241103700226, 5.570971395288195, 2.437969808067594, 8.531197122165135, 70.45565782274518, 57.28889444896153, 62.3569278717041, 57.042500904628206, 47.535697664533345, 46.63983515330723, 63.39147990090506, 53.587001936776296, 55.07631703785488, 52.46296058382307, 54.90242099761963, 51.45564896719796, 51.5897387777056, 49.11923728670393, 50.39777878352574, 47.66207497460501, 50.14906454086304, 47.50706761223929, 36.54281718390328, 35.22260039193289, 50.40466444832938, 48.229388441358296, 48.20152269090925, 45.68856770651681, 47.74152762549264, 38.89333023343767, 38.174688475472585, 37.280107906886506, 37.276119640895296, 37.58515119552612, 37.267750535692485, 37.45626905986241, 36.95535952704293, 36.892822265625, 39.1240416935512, 37.105826241629465, 38.883092062813894, 36.51303720474243, 38.36033044542585, 37.55275869369507, 40.023711817605154, 37.88564688818795, 40.320535387311665, 36.95754126140049, 37.85412291118077, 37.592655250004356, 41.332012448992046, 38.341990675245015, 37.39923129762922, 37.50597299848284, 39.300188950129915, 36.93649516786848, 39.289596421378, 37.84005628313337, 39.6460668018886, 43.131995405469624, 45.72045646395002, 42.19039985111782, 44.756623200007844, 43.06879111698696, 44.920701435634065, 48.818647793361116, 51.98453542164394, 46.9114784513201, 48.60629347392491, 50.99959005628313, 46.32131930759975, 44.31842463357108, 40.77222735541207, 41.40745946339199, 42.0131756237575, 41.379173346928184, 38.6039377621242, 37.31470646177019, 38.76942300796509, 38.303907598767964, 40.01612785884312, 36.53958279745919, 36.63149356842041, 39.10775164195469, 37.57735184260777, 39.35565989358084, 38.27472169058663, 38.814808641161235, 39.36943817138672, 38.862435068402974, 39.49525615147182, 38.89889921460833, 38.805546692439485, 38.18954719815935, 38.62585585457938, 38.787530013493125, 38.69495568956648, 37.838506834847585, 37.25289181300572, 38.836691992623464, 37.92733260563442, 40.73713200432913, 39.43419190815517, 39.42894949231829, 37.85219478607178, 37.96011768068586, 39.069929122924805, 38.07927581242153, 40.418668270111084, 39.514106614249094, 38.72089678900582, 38.8225975717817, 39.77824933188302, 40.27257544653756, 38.11494786398751, 41.10901001521519, 39.19649403435843, 44.06368630273001, 41.93095758983067, 43.489942278180806, 44.31019449234009, 44.66409751347133, 41.72578770773751, 41.862712383270264, 40.44166680744716, 41.61301497050694, 42.78257049833025, 49.29896286555699, 54.706895215170725, 61.71321896144322, 59.47368948800223, 53.36336374282837, 3.064632833003998, 0.45298172746385845, 2.799255724464144, 0.759597968842302, 0.2391736874622958, 11.05642523084368, 67.78938388824463, 61.57907009124756, 60.03871699741909, 49.39277744293213, 30.397316183362687, 22.462278842926025, 35.839048045022146, 45.14849465233939, 64.84696769714355, 44.29359524590628, 1.911882826260158, 0.0887172594666481, 0.044262423645704985, 0.04888755242739405, 0.07742899483335869, 0.05448839420984898, 0.029517155406730514, 0.11312752283577408, 0.17575563330735477, 0.26439399272203445, 0.1940828098782471, 0.08452968738440957, 0.15968834475747176, 0.14783945413572447, 0.2402239239641598, 33.1364871433803, 73.3391671861921, 61.42784949711391, 52.124211583818706, 26.415946279253276, 23.462362595966884, 59.48535551343645, 50.72847482136318, 70.77912425994873, 60.007929529462544, 64.38412039620536, 3.3318334094115665, 0.31559317825095995, 0.6363256350159645, 10.191251175744192, 2.4679315260478427, 9.849953055381775, 74.14491503579276, 59.85889761788504, 65.82275186266217, 58.66712869916643, 49.88462652478899, 44.54703426361084, 62.42436708722796, 55.01060444968087, 58.52690710340227, 54.705786977495464, 57.30995443889073, 55.46783760615757, 55.442535740988596, 51.582849638802664, 52.63886117935181, 48.93226473672049, 53.45876250948225, 48.10188552311489, 40.53088862555367, 41.474377564021516, 51.615797996520996, 49.527266774858745, 51.44014753614153, 47.40748603003365, 49.87618793760027, 41.14342444283621, 42.378536224365234, 39.1799955368042, 39.414316586085725, 39.79537664140974, 39.24389464514596, 39.452778339385986, 39.17985657283238, 38.58168268203735, 42.253809111458914, 38.1840546471732, 42.14838062013899, 37.7589430127825, 42.65414694377354, 37.89483935492379, 40.96951103210449, 39.106587818690706, 42.7979051726205, 38.98525142669678, 40.78917748587472, 39.15039621080671, 43.57082973207746, 39.82511840547834, 40.75051770891462, 38.53302444730486, 42.09107535226004, 40.08920553752354, 41.76466287885393, 40.58694321768624, 42.94056906018938, 46.51724461146763, 46.311640466962544, 43.55560622896467, 49.55834606715611, 46.07652037484305, 48.571434361594065, 49.185391085488455, 53.29656376157488, 50.485048157828196, 51.138828481946675, 53.24391726085118, 47.3380492074149, 45.217712606702534, 42.30221026284354, 42.83411223547799, 45.039640699114116, 43.47412470408848, 41.12576559611729, 39.66946833474295, 41.76904371806553, 39.174169472285676, 42.19035121372768, 38.30094766616821, 38.71679735183716, 41.993262086595806, 40.91136850629534, 41.8534643309457, 40.4278781073434, 40.00837019511631, 42.01485708781651, 41.50291728973389, 41.34691286087036, 41.563474314553396, 40.08456066676548, 40.65511894226074, 41.17242969785418, 40.774454253060476, 41.7672232900347, 39.763849190303254, 39.12068918773106, 42.119986806597026, 39.50957638876778, 43.57706574031285, 41.579097339085166, 40.780078819819856, 40.60317420959473, 40.43772370474679, 40.82473141806466, 39.08360317775181, 43.02413157054356, 41.500547954014365, 41.404867785317556, 42.377070154462544, 43.06044980457851, 42.274441787174766, 40.98783343178885, 44.491368770599365, 41.292300019945415, 46.63834129061018, 44.00140959875924, 44.176677908216206, 47.42779908861433, 47.89562129974365, 44.42665324892317, 44.15491615022932, 43.335991042000906, 44.88311515535627, 45.8091641153608, 51.473585741860525, 55.87226445334298, 65.04506083897182, 61.5041754586356, 56.42695999145508, 3.2694718071392606, 0.8930901257055146, 8.28618540082659, 1.6643040712390627, 0.32852000317403246, 13.042619909558978, 73.67009598868233, 66.56438868386405, 66.05904620034354, 55.57034090587071, 29.08742962564741, 24.339331218174525, 42.622157437460764, 54.388841424669536, 72.42758437565395, 55.685031345912385, 3.352142993892942, 0.26734434440732, 0.2176187876611948, 0.10819794556924275, 0.14969812440020697, 0.13077321276068687, 0.09222853569579975], [0.10762219503521919, 0.007881464137296592, 0.0374331349240882, 0.044127727659153085, 0.007043824531137943, 0.037721390170710425, 0.01934782724960574, 0.18163062020071916, 17.330549546650477, 49.604280608040945, 43.70275865282331, 40.41115031923567, 24.126994269234793, 33.19246530532837, 37.95179026467459, 47.70914902005877, 59.33889443533761, 53.11635528291975, 50.49469573157174, 2.1173566920416693, 0.19539808215839521, 0.32617707603744095, 2.6940447986125946, 0.9174927962677819, 0.12270131946674415, 33.249881744384766, 61.49296801430838, 52.78005204881941, 53.60040153775896, 57.15127495356968, 63.597744124276296, 53.789555822099956, 53.25585079193115, 52.08668436322893, 51.45107357842581, 52.26607295445034, 48.81211301258632, 46.58562878199986, 47.44848040172032, 50.421041352408274, 50.41055999483381, 49.257516860961914, 45.27633455821446, 50.2736804825919, 45.49786049979073, 45.9106251852853, 46.471240588596885, 45.97577496937343, 45.70457288197109, 43.23262269156319, 38.49399988991873, 36.480370249067036, 35.479635102408274, 34.55121333258492, 34.88400425229754, 34.189490113939556, 36.59426859446934, 34.83094433375767, 35.02957943507603, 37.21503107888358, 35.16360323769705, 36.31914077486311, 36.27780941554478, 37.3298465864999, 36.37790516444615, 36.07906314304897, 37.90890598297119, 37.73161574772426, 36.879773548671174, 36.88278559276036, 36.562466689518516, 36.9330974987575, 35.848393372126985, 36.43238598959786, 35.116525718144004, 36.942046778542654, 37.145253794533865, 36.82296160289219, 33.47844621113369, 38.2503091948373, 43.732125214168, 43.69305896759033, 42.365612574986045, 42.09943403516497, 41.053935119083945, 40.99573353358677, 41.84240974698748, 45.95117139816284, 44.97533164705549, 43.76274939945766, 48.926000935690745, 44.23085996082851, 40.52607352393014, 39.08024719783238, 41.96542065484183, 41.572322845458984, 40.03670842306954, 35.96099240439278, 35.69345896584647, 36.76533671787807, 35.04133578709194, 35.45426722935268, 34.38312251227242, 34.9577420098441, 37.2163199697222, 37.26745523725237, 37.04090574809483, 36.99068069458008, 38.16079207829067, 38.73140246527535, 37.631596429007395, 38.08623443331037, 36.04993976865496, 35.447735922677175, 37.254708766937256, 37.39139025551932, 37.671736172267366, 37.54591471808297, 37.29188857759748, 36.239121845790315, 35.70318296977452, 36.659067494528635, 37.68897812707083, 37.054048265729634, 37.14083474023001, 35.60378898893084, 35.413957255227224, 38.051830427987234, 36.26202310834612, 37.00988204138619, 39.895326478140696, 40.788242953164236, 39.90068701335362, 40.412769249507356, 39.30637979507446, 39.17408609390259, 36.52584968294416, 37.63857242039272, 37.86660187585013, 39.15115009035383, 37.92436225073678, 37.439280714307515, 41.207507678440635, 42.69227865764073, 47.10768515723092, 48.36682728358677, 52.21781424113682, 51.94485078539167, 53.231730120522634, 52.091384819575715, 56.85713338851929, 56.83096994672503, 59.09500571659633, 6.017496943473816, 0.33001302448766573, 1.1744735496384757, 0.645310252904892, 0.07846492781702961, 4.683316877910069, 59.00237233298165, 59.41740907941546, 59.45746544429234, 45.979738916669575, 26.69710166113717, 10.176641719681875, 21.872371571404592, 42.72436196463448, 58.046682357788086, 45.2564696584429, 2.7981492238385335, 0.08510412834584713, 0.04413155798933335, 0.03592921633805547, 0.09379916105951581, 0.06037419355873551, 0.05834189296833106, 0.048324741556176116, 0.027869429805182984, 0.04282862486849938, 0.047451846966786046, 0.023020805159051503, 0.0615506036473172, 0.052141012490860054, 0.170739441045693, 23.952384301594325, 60.63424709865025, 49.78234904153006, 47.85441153390067, 22.415545259203228, 25.31298749787467, 39.409876687186106, 51.615735462733674, 62.42753546578543, 58.86190755026681, 53.39116695949009, 2.5483530163764954, 0.13523823102670057, 1.1072662302425929, 10.528809428215027, 2.35786663208689, 0.059474836103618145, 38.11215468815395, 60.445075443812776, 56.059664317539756, 54.11334187643868, 60.679306166512625, 64.94517353602818, 55.18599087851388, 54.429307733263286, 54.28722054617745, 52.73900556564331, 53.86775432314192, 51.11808116095406, 49.76297051565987, 49.10478155953543, 52.52812426430838, 51.23316070011684, 50.60805211748396, 48.641159534454346, 52.92297649383545, 45.31363596235003, 47.02816997255598, 48.41723299026489, 48.04608801433018, 48.08621038709368, 44.81989349637713, 40.349776881081716, 37.626270634787424, 37.09035955156599, 37.584234033312114, 36.67429099764143, 35.986652101789204, 38.05141701017107, 36.134349959237234, 36.082985401153564, 39.336548873356406, 37.53606564658028, 37.46725763593401, 38.043746198926655, 38.5416819027492, 38.702654293605256, 39.65711791174752, 38.61358880996704, 38.63837650844029, 36.8819066456386, 37.97273908342634, 37.741787910461426, 38.5017922946385, 37.405981472560335, 37.8149003301348, 37.923973151615684, 38.03006867000035, 38.170161724090576, 38.6432854107448, 35.94874620437622, 40.93747983660017, 44.36740248543875, 47.12023707798549, 43.98078734534127, 43.50241082055228, 43.56317976542881, 43.31565366472517, 44.4130973134722, 49.389567375183105, 46.86187873567854, 46.90683705466134, 51.22019188744681, 47.36519929340908, 42.151361397334504, 41.69087995801653, 43.58470181056431, 43.751604488917756, 42.113486766815186, 38.78898566109793, 37.894314765930176, 37.43870401382446, 39.352807658059255, 37.14388847351074, 36.03458077566964, 38.10224308286394, 38.12992123195103, 40.2132899420602, 39.82888780321394, 39.18328550883702, 39.49407148361206, 40.91196257727486, 39.21036263874599, 39.01086596080235, 37.78523499625069, 36.95759684698922, 39.27449451174055, 38.503289631434846, 39.38427952357701, 40.16380139759609, 38.79890421458653, 37.94044385637556, 38.26425075531006, 38.58192934308733, 38.08818340301514, 38.75204903738839, 38.322379384722026, 36.59990010942732, 37.91555540902274, 39.77631425857544, 38.038969312395366, 39.55557346343994, 40.44435576030186, 42.156628131866455, 42.29445954731533, 40.9670409475054, 41.10526146207537, 40.933797291346956, 39.094317299979075, 39.43431002753121, 40.23151854106358, 40.81298896244594, 41.79515157427107, 38.92383977345058, 42.348137855529785, 44.84450054168701, 50.61590705599104, 49.93358700616019, 55.77972487040928, 53.76567138944353, 55.05353389467512, 52.848978178841726, 59.988919258117676, 58.50933510916573, 59.84315994807652, 7.226705840655735, 0.49519083968230654, 1.683853479368346, 1.313538704599653, 0.10697933060250112, 5.074477442673274, 63.00666781834194, 65.94080870492118, 63.96431023733956, 53.3666467666626, 35.656987871442524, 12.7021929195949, 27.80894545146397, 49.32072114944458, 64.1305180958339, 53.89859390258789, 3.9186997583934238, 0.044847073166498115, 0.04726247462843146, 0.03845440476600613, 0.09306558328015463, 0.038602759662483416, 0.05626464621829135, 0.17743161480341638, 0.2801367651138987, 0.1339975433158023, 0.11697717090802533, 0.11018193446631942, 0.20956031578992093, 0.09233408181795053, 0.4085287813629423, 30.730249541146414, 69.89803709302629, 57.12993703569685, 56.167000089372905, 35.88408626828875, 43.41848005567278, 48.53626258032662, 59.89437511989048, 69.07372365679059, 64.47696917397636, 58.85734258379255, 2.7931000547749654, 0.31574609290276257, 1.1447094210556574, 11.386659213474818, 4.477547713688441, 0.19533245425139154, 39.30662645612444, 64.92798369271415, 57.21752255303519, 56.90725074495588, 60.393068177359446, 64.15767860412598, 58.822615487234934, 57.18857288360596, 57.48427779333932, 55.23077201843262, 56.86438730784825, 53.553918089185444, 51.21668652125767, 52.69640268598284, 55.312972681862966, 52.46330451965332, 52.73095260347639, 50.21108763558524, 54.00521053586687, 48.815489837101524, 50.327237197331016, 49.12418440410069, 50.026661600385395, 49.33484336308071, 47.99640492030552, 42.85027721949986, 40.859750338963096, 40.67320857729231, 39.406023911067415, 38.928505488804404, 39.12082120350429, 39.63368163790022, 38.83588947568621, 36.99936941691807, 41.58009787968227, 39.88723530088152, 40.48205321175711, 39.458736419677734, 40.55875437600272, 40.0137619972229, 40.72334677832467, 40.240905557359966, 40.874800137111116, 40.555770124707905, 40.948881830487935, 40.04232604163033, 41.84728043419974, 38.721664564950125, 39.354548181806294, 39.32840558460781, 41.307582582746235, 40.46943180901663, 40.050743784223286, 36.92257097789219, 42.355940682547434, 47.17206021717617, 49.41947589601789, 46.20958185195923, 45.556715215955464, 45.74487590789795, 45.802375725337434, 45.001130308423726, 51.53558104378836, 50.529895305633545, 48.69377824238369, 53.6348055430821, 49.69273465020316, 43.43805660520281, 44.29226813997541, 46.378405707223074, 47.31037105832781, 44.29075343268258, 40.350770473480225, 39.8804156439645, 39.73935331617083, 40.47001893179757, 39.136103766305105, 37.7820040839059, 40.17114911760603, 40.59611136572701, 41.19384057181222, 40.64218487058367, 40.75879996163504, 41.17258603232247, 42.465659686497276, 40.78256280081612, 40.46450901031494, 39.4404730796814, 39.854491915021626, 42.633896418980186, 41.09956741333008, 41.954605783735005, 41.92133086068289, 39.90774290902274, 40.464366572243826, 39.929567200796946, 40.11715119225638, 41.837045737675254, 41.455408981868196, 41.15095976420811, 39.552978311266216, 40.592102255140034, 42.30149459838867, 40.05654205594744, 41.872797693525044, 42.7681599344526, 45.19124344417027, 44.032881464277, 45.26328236716134, 44.104051862444194, 44.11013848440987, 42.25617497307913, 42.08456489018032, 41.65566996165684, 42.88221114022391, 43.68252549852644, 41.31639984675816, 45.546150479997905, 47.030445507594514, 51.96478864124843, 51.56292915344238, 57.781288964407786, 57.28025436401367, 58.83468450818743, 55.366703101566856, 63.18468761444092, 61.21321269444057, 63.17204884120396, 7.805219803537641, 0.779991474534784, 5.816651880741119, 3.5402146620409827, 0.18085915302591665, 5.832858119692121, 70.36139856066022, 72.89163371494838, 69.85651465824672, 60.40411581311907, 34.539245060511995, 18.11651587486267, 35.99381569453648, 58.37211513519287, 72.42618083953857, 63.196457862854004, 5.396079157079969, 0.12959942860262735, 0.11793332174420357, 0.2578216482486044, 0.14409550146332809, 0.14970748818346433, 0.14645360064293655], [0.005913850834726223, 0.027185393563870872, 0.052237842830696275, 0.057701471261680126, 0.013556036383046635, 0.04657815170607396, 0.09882557205855846, 0.3648126700094768, 15.35607647895813, 53.80053744997297, 40.25005633490426, 36.64861740384783, 17.999885150364467, 35.24054064069475, 29.591189656938823, 42.355117321014404, 58.864909172058105, 52.55286679949079, 48.94003977094378, 1.549409310732569, 0.23338583803602628, 1.320383982998984, 6.101506309849875, 2.7196495618138994, 0.2684183839176382, 7.62836035660335, 57.142968382154194, 47.694971220833914, 55.77873475211007, 56.9568886756897, 50.20708547319685, 54.184039797101704, 54.27225065231323, 51.06047017233712, 49.725894927978516, 45.468657221112935, 44.963113239833284, 43.98710673195975, 44.046513829912456, 45.10484259469168, 47.43488277707781, 50.59989840643746, 50.11077649252755, 47.51884133475167, 48.48126758847918, 46.846707344055176, 45.63011598587036, 44.74760791233608, 45.10687146868025, 42.952182974134175, 39.70900705882481, 36.5587910924639, 34.41861738477434, 35.285346099308555, 34.26056671142578, 35.07421466282436, 33.08186388015747, 35.70109156199864, 35.42587341581072, 36.54204593385969, 36.35077244894845, 37.000144141060964, 36.931947571890696, 36.54307426725115, 37.283675806862966, 36.898227964128765, 34.178529330662315, 37.772092478615896, 35.36107798985073, 35.140820094517295, 34.9145450592041, 36.25374085562569, 35.889297417231965, 36.613848618098665, 34.65733316966465, 36.410627705710276, 35.22382327488491, 37.22976473399571, 33.72626413617815, 36.98332602637154, 41.48627288000924, 43.176439557756694, 42.43008838381086, 41.82015814099993, 40.3802238873073, 43.457184995923726, 44.77450091498238, 46.44162041800362, 49.18746859686715, 45.26729147774832, 47.911074093409944, 45.17991093226841, 42.81715863091605, 40.17783675874983, 40.38059561593192, 42.586391585213796, 39.62096643447876, 35.79232835769653, 35.389784472329275, 37.671468666621614, 35.54650109154837, 37.43406956536429, 36.581914697374614, 35.34064333779471, 35.34473582676479, 37.01315116882324, 36.72170203072684, 37.495877265930176, 37.4279134614127, 37.90785333088466, 38.61288356781006, 36.527419975825715, 36.894069467272075, 36.29431138719831, 36.85840783800398, 36.13824789864676, 36.28905160086495, 36.67995030539376, 35.10390084130423, 37.38742978232247, 36.72474186761038, 36.274046966007774, 37.222027914864675, 36.54731614249093, 36.410721506391255, 35.50131695611136, 37.39292580740792, 36.97422041211809, 37.06309482029506, 39.08026456832886, 44.04758732659476, 46.328132016318186, 45.8719619342259, 43.559313092912944, 44.0322596005031, 40.91390112468174, 41.575126443590435, 38.618195465632844, 37.945766176496235, 37.80769157409668, 43.64064523151943, 46.046573638916016, 50.314518519810264, 51.44658156803676, 53.13375357219151, 52.016754218510215, 50.22507783344814, 51.73371240070888, 58.425706590924946, 53.879990100860596, 58.783615248543875, 56.37400776999337, 65.05950614384243, 7.093766391277313, 0.3670412504247257, 0.4672436107482229, 0.6749141929405076, 0.08616079735968794, 3.2284316207681383, 54.759871755327495, 60.02090876443045, 57.733686855861116, 56.7469801221575, 43.37212514877319, 21.96585089819772, 32.272534234183176, 37.804505825042725, 55.38202040536063, 42.06127800260271, 2.8985209465026855, 0.105253008593406, 0.06362180465034076, 0.14157390248562607, 0.041715030159269056, 0.005122140839895499, 0.03456364764965006, 0.015025869610586336, 0.06321739099387612, 0.09616817108222417, 0.05691732226737908, 0.004612694203387946, 0.09955582501632826, 0.125043459502714, 0.4185222179761955, 22.701072795050486, 64.05415044512067, 47.42015954426357, 46.69257892881121, 25.057900020054408, 36.8597731590271, 35.91157334191458, 47.67228882653372, 64.89379160744804, 58.91062831878662, 53.00953367778233, 1.7538735164063317, 0.271210501236575, 2.301162383386067, 12.415521536554609, 6.348054017339434, 0.5153639572007316, 9.23795746053968, 58.89829526628767, 48.53640154429844, 56.63038240160261, 56.19285781042916, 52.715899331229075, 55.37766735894339, 55.54441022872925, 52.25413247517177, 51.415300777980256, 48.65816525050572, 46.53265571594238, 46.29624673298427, 47.19160549981253, 47.49198307309832, 49.39792605808803, 51.34237595966884, 52.85542263303484, 49.65795544215611, 50.96881301062447, 47.784599508558, 47.63835729871477, 48.05221632548741, 46.820790563310894, 44.24970347540719, 41.96375308718, 38.3482266834804, 35.83509452002389, 37.63887814113072, 35.910934107644216, 37.31500176021031, 35.84161540440151, 37.19959218161446, 37.314331259046284, 36.926833697727744, 38.366135665348594, 39.56549896512713, 38.08231564930507, 37.68597303118025, 39.31040975025722, 37.743288721357075, 37.470227990831646, 38.0432459286281, 36.96999938147408, 36.541879177093506, 36.94606283732823, 39.47395992279053, 36.613181591033936, 38.29416275024414, 36.803951331547324, 38.069367681230815, 39.18075636454991, 38.58271448952811, 35.791247912815635, 38.10534545353481, 43.04436125074114, 46.27272013255528, 44.49936267307827, 43.73447717939104, 41.41109684535435, 44.1545444216047, 47.582535471235005, 50.498451232910156, 51.093463693346294, 48.34363072259085, 50.2772136415754, 47.47248642785208, 44.22644090652466, 42.70123141152518, 42.92369883401053, 43.999915736062185, 41.47882093702044, 38.06488609313965, 37.47211790084839, 39.141808237348286, 38.454023429325645, 39.590418679373606, 37.59213760920933, 37.62541600636074, 37.17900814328875, 38.81730651855469, 39.36449452808925, 39.91212722233364, 38.636701992579866, 39.74689558574131, 39.06411348070417, 37.32759884425572, 37.94623865400042, 38.850223609379356, 39.788966928209575, 38.14311238697597, 38.65641403198242, 38.73188189097813, 37.20608874729702, 39.15245982578823, 37.47774941580636, 37.41660179410662, 37.664482252938406, 38.203148296901155, 38.07746580668858, 38.25010422297886, 38.19984442847115, 38.249086311885286, 38.52275848388672, 42.68321473257882, 47.490291186741416, 47.278329440525596, 48.25360986164638, 45.582750116075786, 46.60788038798741, 43.6949280330113, 42.29474094935826, 41.22904361997332, 40.2299656186785, 40.412279401506694, 45.95946059908186, 48.43385655539376, 53.082736424037385, 53.285582133701865, 56.065684931618826, 53.83489281790597, 51.53837421962193, 54.62568814413888, 61.024569102696006, 56.75694383893694, 60.59125164576939, 57.875864369528635, 67.07374027797154, 8.286051648003713, 0.6319972329906055, 1.4340711683034897, 1.4985392689704895, 0.10198469539838177, 3.352532310145242, 58.922697339739116, 64.74275166647774, 62.889055660792756, 61.07849407196045, 37.04984113148281, 23.63171798842294, 32.90551165172032, 46.0255240712847, 61.68796225956508, 51.46316344397408, 4.2814599956784924, 0.10755096242896148, 0.0681488952998604, 0.14651715223278317, 0.02733110047743789, 0.02578257330294166, 0.0975905569004161, 0.10412717650511435, 0.14097975008189678, 0.24019352559532436, 0.16218881415469305, 0.14367726604853356, 0.25516355516655104, 0.22810965829661914, 0.6085166643772806, 33.727184772491455, 74.2025225503104, 54.83899784088135, 52.959322520664756, 29.265927110399517, 43.175737789699006, 39.247702257973806, 53.723381178719656, 68.54237406594413, 63.24176011766706, 58.15481717245919, 2.2852269070489064, 0.37772201587046894, 3.2551252969673703, 19.35451810700553, 10.674333368028913, 0.7574276881558555, 10.875031215803963, 62.61094011579241, 48.802955286843435, 57.387180192129954, 59.86156572614397, 55.631068161555696, 56.873756953648154, 58.44037423815046, 54.395143440791536, 53.43952989578247, 50.4112548146929, 48.28299379348755, 48.35618264334542, 50.539094720567974, 50.72803708485195, 51.803996903555735, 54.35798794882638, 55.91312680925642, 51.47176878792899, 53.91668701171875, 52.59927729197911, 49.373426709856304, 49.87992606844221, 48.623733452388215, 47.23355524880545, 44.162586961473735, 40.31625877107893, 38.0334871837071, 41.14433118275234, 38.2669848714556, 39.258173193250386, 37.50833191190447, 40.22346210479736, 39.50581046513149, 40.00076886585781, 40.843706948416575, 41.97455753598894, 40.592890875680105, 40.048152106148855, 41.29262311117989, 40.687705993652344, 37.100833960941856, 40.75415856497628, 39.26193216868809, 37.59874882016863, 38.66070801871163, 40.666628633226665, 40.659013407570974, 40.72468083245413, 38.40960706983294, 39.51137597220284, 38.53482403073992, 40.56122446060181, 37.22835772378104, 41.39193371364048, 45.08978237424578, 47.927746295928955, 47.85069077355521, 46.30756882258824, 45.26029116766793, 47.42014912196568, 50.311475208827424, 52.93387821742466, 52.87706627164568, 49.308401993342805, 52.63647794723511, 51.594463552747456, 47.469703674316406, 44.02994237627302, 45.34866530554635, 46.9745055607387, 44.731515884399414, 42.2086249760219, 39.30291264397757, 41.77108301435198, 40.74781138556344, 41.71890204293387, 40.647958823612754, 39.760128429957796, 39.04745170048305, 39.64093208312988, 40.81894704273769, 41.621811389923096, 41.57905912399292, 42.304798466818674, 41.945687770843506, 39.441174847739084, 39.88689831324986, 39.99540485654558, 40.885552474430625, 39.6586708341326, 40.19391489028931, 40.95195293426514, 39.49685076304844, 41.14648512431553, 40.27522965839931, 39.70892368044172, 40.925966671534944, 39.609025955200195, 40.46131978716169, 40.61715745925903, 40.54054662159511, 41.09129558290754, 41.91878087180001, 43.49365609032767, 51.03549139840262, 50.04522718702044, 50.78718362535749, 47.94697196143014, 49.098010540008545, 46.738357135227744, 46.40806061880929, 43.90349905831473, 41.61287253243582, 41.10011979511806, 48.980985505240305, 50.15015888214111, 56.04520859037127, 55.041086196899414, 58.62021446228027, 56.31781768798828, 54.667912346976145, 57.804218019757954, 64.03323636736188, 59.76599325452532, 63.590066364833284, 60.71853569575718, 68.2034409386771, 8.253600086484637, 0.9508898556232452, 4.418412029743195, 2.549168344054903, 0.2855058227266584, 4.0221849254199435, 66.43467276436942, 69.61052063533238, 67.48640074048723, 70.93260996682304, 54.904724325452534, 31.388494082859584, 45.62714563097273, 53.324856826237266, 69.6582339150565, 61.290066719055176, 7.037427791527339, 0.2873317604618413, 0.2351571944143091, 0.3101468490702765, 0.1549894761826311, 0.18038074512566837, 0.140479710485254], [0.021016587436731373, 0.016310617992920533, 0.0358120808377862, 0.042804804896669726, 0.054011343379638026, 0.05946919069226299, 0.026368205003174286, 0.2622249876814229, 23.55513494355338, 53.10883385794503, 40.80701698575701, 28.36742080960955, 11.925082070486885, 41.41316046033587, 47.02078056335449, 42.19596535818917, 61.096128599984304, 51.93579380852835, 48.14622892652239, 1.1538034187895911, 0.22183304652571678, 1.9552137468542372, 10.142136096954346, 1.7831987142562866, 0.43298844886677607, 6.770088468279157, 54.48945828846523, 48.058799743652344, 57.433385712759836, 53.258032526288716, 59.36789621625628, 49.98258222852434, 50.755798612322124, 46.00171954291207, 48.20065416608538, 43.502417768750874, 40.74079717908587, 39.35293967383248, 40.56419134140015, 41.7221086365836, 46.894906997680664, 44.17455175944737, 45.31062739236014, 46.42987101418631, 44.2423939704895, 43.30764586584908, 45.916788237435476, 45.780596596854075, 43.18728222165789, 42.08175086975098, 39.56423091888428, 36.07548482077462, 34.672779015132356, 33.90035125187465, 34.47987617765154, 34.511514799935476, 35.40296173095703, 34.03575427191598, 36.86195141928536, 36.71969747543335, 35.7549262046814, 33.28149952207293, 36.62069606781006, 35.144919531685964, 37.11860745293753, 36.29102488926479, 36.52836493083409, 36.53846761158535, 35.65640074866158, 37.89324474334717, 39.14003644670759, 37.900995458875386, 37.06905290058681, 35.495824405125205, 35.47333656038557, 34.95396218981062, 36.11555855614798, 35.96953174046108, 34.729948793138774, 36.47622912270682, 40.86437783922468, 45.98730550493513, 44.686126777103965, 41.70892442975725, 41.48125628062657, 43.407918793814524, 46.739833627428325, 46.350880418504985, 50.179230145045686, 48.59040641784668, 47.34923233304705, 47.029795851026265, 44.23743643079485, 39.674026353018625, 43.96213838032314, 41.211162430899485, 39.33728885650635, 37.19620840890067, 36.64565052304949, 35.11557034083775, 35.37399469103132, 36.50144413539341, 35.56294052941458, 33.755620275224956, 34.79947941643851, 36.721698556627544, 36.995617389678955, 37.01144191196987, 37.78916072845459, 37.848883969443186, 36.665661334991455, 37.91918236868722, 39.15765707833426, 34.146373067583355, 35.469817297799246, 37.49619688306536, 36.872811453683035, 37.450324875967844, 34.453295843941824, 36.24448585510254, 36.63659354618618, 35.2748612676348, 36.851845264434814, 35.80274370738438, 35.856300422123496, 36.12082529067993, 35.24395220620291, 35.71547085898263, 37.40397344316755, 43.56855072293963, 46.18459612982613, 45.148091656821116, 47.53354719706944, 47.22583927427019, 49.40567677361624, 44.272708960941856, 45.83127328327724, 46.07459919793265, 44.785746574401855, 45.30117089407784, 49.0672995022365, 49.7785518510001, 53.144332204546245, 54.661308084215435, 55.168523107256206, 55.929604462214876, 62.74643693651472, 64.66751657213483, 56.510609354291645, 58.83863108498709, 59.14665862492153, 68.15107931409563, 55.203809533800396, 5.772186015333448, 0.43454696238040924, 0.29644364437886644, 0.6629988465990339, 0.07148984566863094, 1.3749645799398422, 48.166076455797466, 61.40475368499756, 58.97659451620919, 60.09843676430838, 48.61119542803083, 15.214783123561315, 23.9760377066476, 38.39308772768293, 47.53984921319144, 50.974416732788086, 4.871427195412772, 0.1832650482122387, 0.08755524110581193, 0.02076811300191496, 0.011555256288764732, 0.05386844051203557, 0.04910220358786838, 0.020059749583846757, 0.040400317670511346, 0.015043591248935886, 0.04055436886847019, 0.04945519107526966, 0.028462620385523354, 0.03123594567711864, 0.3154429505978312, 32.602274894714355, 61.64674554552351, 47.19194943564278, 35.93227202551705, 19.2096620627812, 35.68661151613508, 42.5408114024571, 51.23479700088501, 63.78365707397461, 58.082833835056846, 50.5750412259783, 1.4117494289364134, 0.1756621040403843, 4.301417393343789, 15.862191949571882, 7.859223808561053, 0.49219073780945366, 7.755279626165118, 55.706021853855674, 47.641942569187705, 59.58666719709124, 54.81296294076102, 60.560908862522666, 52.31453316552298, 52.70933675765991, 49.01939514705113, 49.63877146584647, 44.73447234289986, 42.48930788040161, 41.55141918999808, 41.955394404275076, 44.81054816927229, 48.753939219883506, 47.14298895427159, 48.48502308981759, 47.69214677810669, 46.462374687194824, 45.52613966805594, 47.704584053584504, 47.70921155384609, 44.33519411087036, 43.89246531895229, 41.332801069532124, 37.76051330566406, 37.0662145614624, 36.51294687816075, 35.847135748182026, 36.7628562109811, 37.71465172086443, 37.405158111027305, 38.273808002471924, 36.81609330858503, 37.304673263004844, 35.48167439869472, 38.028977802821565, 37.44886228016445, 38.8389710017613, 37.41300957543509, 37.313292503356934, 39.199825695582796, 36.73367725099836, 37.6674804006304, 39.664173807416645, 39.6766597202846, 39.609505380902974, 37.634177684783936, 37.58420624051775, 36.8796762738909, 37.559383801051546, 37.97650153296334, 35.61216504233224, 37.781962394714355, 43.06464999062674, 46.41072177886963, 45.50207110813686, 44.285622188023154, 43.231194836752756, 45.65355225971767, 48.60177367074149, 50.29705769675118, 51.06649078641619, 50.00534452710833, 49.676896231515066, 50.25785596030099, 45.20386832101004, 42.12439543860299, 44.79091256005423, 44.02333116531372, 42.40838915961129, 36.53023052215576, 38.46773222514561, 36.76437439237322, 37.2861841065543, 36.8548503603254, 37.23816163199288, 35.60073178155081, 35.877325671059744, 38.506187030247276, 39.42296361923218, 38.05748973573957, 40.182078633989605, 40.22906582696097, 38.78687340872628, 39.17721973146711, 41.58405140468052, 37.139990534101216, 37.264328547886436, 37.52639722824097, 38.40886013848441, 38.12317453111921, 37.206668921879356, 37.38396610532488, 38.05614525931222, 38.05088894707816, 36.74121604646955, 37.18954856055123, 38.445810658591135, 37.46116059167044, 37.81358017240252, 37.53732674462454, 38.69456659044538, 46.13644858769008, 49.665567193712505, 47.87891435623169, 50.56662695748465, 49.02624954496111, 51.35936777932303, 46.782151630946565, 48.31196778161185, 46.625869274139404, 46.17932939529419, 47.515527044023784, 49.91277367728097, 52.392658710479736, 55.852607999529155, 56.54041712624686, 57.91842555999756, 58.84442588261196, 63.7625276020595, 64.24023015158517, 59.006020137241904, 59.3328286579677, 60.55526692526681, 65.82368292127336, 59.865324701581685, 6.723193773201533, 0.4716055595449039, 1.1904015349490302, 1.904695566211428, 0.05862151046416589, 1.4552960693836212, 53.51738793509347, 66.09079946790422, 65.12137985229492, 63.23284557887486, 50.49160725729806, 27.466958590916224, 34.56911884035383, 45.07261337552752, 53.9948125566755, 59.901622091020855, 7.22369509935379, 0.2409570946225098, 0.030972728372684548, 0.11738408835870878, 0.07769289745816163, 0.10577315318265132, 0.02877868538988488, 0.0694341491907835, 0.14045965299010277, 0.08438778535595962, 0.14554439085934842, 0.0984130838353719, 0.1701351377580847, 0.11981177808982985, 0.4413682749228818, 41.94086572102138, 71.30995273590088, 54.98965563092913, 44.18202454703194, 20.158233608518326, 47.45224979945591, 53.49182203837803, 55.425477913447786, 69.48923288072858, 64.03780828203473, 56.7126282283238, 1.878764237676348, 0.4716760186212403, 7.170228276933942, 22.96324222428458, 7.227696393217359, 2.812556096485683, 10.086799774851118, 58.678725242614746, 47.440941606249126, 60.94745799473354, 58.407182693481445, 63.26272283281599, 55.542527266911094, 55.673636300223215, 49.68305580956595, 52.35699013301304, 46.99116039276123, 45.70755018506731, 43.09405129296439, 45.201961040496826, 46.25437341417585, 50.77540990284511, 47.99728386742728, 49.58240073067801, 50.05093165806362, 47.314140456063406, 48.33495242255074, 50.535304478236604, 51.34873356137957, 46.97407129832676, 46.32477603639875, 43.42170401981899, 39.771405356270925, 39.85453360421317, 39.60579851695469, 38.522317273276194, 38.70543704714094, 39.1686178616115, 36.87893281664167, 40.495751585279194, 39.63854537691389, 39.28739384242466, 37.749597685677664, 41.056130749838694, 39.104684012276785, 40.63813407080514, 38.966220310756135, 39.61172880445208, 40.46281017575945, 40.47454220908028, 41.4864570072719, 42.70518146242414, 42.225238118852886, 41.14092309134347, 39.70581783567156, 39.10985347202846, 38.761085169655935, 39.770734855106895, 40.012625966753276, 37.714446749006, 40.532118456704275, 44.39770705359322, 49.24840429850987, 48.695292949676514, 47.25730071749006, 45.82863991601126, 48.906698840005056, 49.59846496582031, 51.95915712629046, 52.76144477299282, 51.07097932270595, 52.47078078133719, 52.57725845064436, 47.82166814804077, 43.15082502365112, 46.294711181095664, 45.54153340203421, 44.870365210941856, 39.575556482587544, 40.687535762786865, 39.68828058242798, 39.2487062726702, 39.27741275514875, 40.064358779362266, 38.58847107206072, 38.59925815037319, 40.99197455814907, 41.81090661457607, 40.407554626464844, 41.15017809186663, 41.50476898465838, 40.223514216286794, 41.451643058231895, 44.787066732134136, 38.6524327141898, 39.443895067487446, 41.055814606802805, 40.07329068865095, 41.658744539533345, 38.426154204777305, 40.5545437676566, 39.66389240537371, 39.762838227408274, 39.87743834086827, 40.38035590308053, 39.676941122327534, 40.01724304471697, 39.94509642464774, 40.41566317422049, 39.973024708884104, 47.88598067419869, 50.47066191264561, 50.09361791610718, 53.14756311689104, 50.11028664452689, 53.31673090798514, 48.52454096930367, 50.63478183746338, 49.17315183367048, 47.6182005746024, 49.639087608882356, 52.55915144511631, 55.57462794440133, 57.225794383457725, 60.34834262302944, 59.493394579206196, 61.47477068219866, 65.59250940595354, 65.97985758100236, 61.90824099949428, 61.18418312072754, 64.34114578792027, 65.0593671798706, 60.55125781467983, 8.482379078865051, 1.2722548970154353, 2.8370280861854553, 5.61808191878455, 0.15219920447894505, 1.8638303875923157, 57.13334860120501, 71.63422516414097, 69.32134355817522, 73.37147630964006, 62.88038430895124, 24.875853742871964, 39.724362577710835, 56.75008944102696, 62.71047306060791, 71.49396187918526, 11.077508670943123, 0.37883687604750904, 0.16960566331233295, 0.19256686765168393, 0.0783902278968266, 0.18833027141434805, 0.1685747243463993], [0.03680830255949071, 0.023396951046639254, 0.039390294546527524, 0.018162584331418787, 0.06149011903575488, 0.004033176527757729, 0.06925253250769206, 0.5103332442896706, 27.640243189675466, 57.33489499773298, 40.98128128051758, 33.54702145712716, 15.026224647249494, 33.231066022600444, 55.17862926210676, 42.57538216454642, 59.70746857779366, 53.680205072675435, 46.497018405369346, 0.7341632736580712, 0.1597938976649727, 1.5411435599837984, 12.708002482141767, 3.3433172617639815, 0.7164749513779367, 16.533966370991298, 57.29799311501639, 46.03715188162667, 58.21920265470232, 54.604739325387136, 50.495526041303364, 44.24002463476998, 42.41551801136562, 39.87110505785261, 40.12710796083723, 39.156416824885774, 38.54929365430559, 39.247083868299214, 39.80956833703177, 41.422359875270296, 43.40969753265381, 39.91546583175659, 42.09443480627877, 39.64396149771554, 44.247917788369314, 42.48686211449759, 45.54353100912911, 43.98204149518694, 41.47933510371617, 40.049764088221956, 34.69760492869786, 34.58975499016898, 34.2687794821603, 34.408507755824495, 36.910748617989675, 35.99513932636806, 35.30854960850307, 34.648630550929475, 35.291943413870676, 36.15472207750593, 35.5268098967416, 36.60633414132254, 36.15467344011579, 35.5680752481733, 36.38145569392613, 37.13502604620797, 34.486414432525635, 34.490385328020366, 36.442054407937185, 37.00655385426113, 37.047933850969585, 37.6909236226763, 38.019861766270225, 36.44129010609218, 38.38225201198033, 32.98298059191023, 37.140428270612446, 35.47649451664516, 35.081996645246235, 34.86948251724243, 39.58264364515032, 42.33663163866316, 44.78372812271118, 43.15181861604963, 40.19746194566999, 44.54688835144043, 47.04224354880196, 45.24231617791312, 34.97190938677107, 38.25035783222744, 46.16790655681065, 46.036790575299946, 43.721984318324495, 42.062358447483604, 43.037600653512136, 41.00826460974557, 40.542297567640034, 34.72966391699654, 35.32536424909319, 36.49664987836565, 37.10460335867745, 36.401494298662456, 34.488120215279714, 34.0772419657026, 34.81877456392561, 37.2497547013419, 37.84507635661534, 38.04909283774239, 38.32257046018328, 37.02145774023873, 37.70679330825806, 35.526156766074045, 36.78454153878348, 35.71061406816755, 36.05684975215367, 35.625714029584614, 37.33089229038784, 37.015784536089214, 34.62260259900774, 38.20483323505947, 36.08656024932861, 35.01887573514666, 36.77120794568743, 35.72882877077375, 36.11624295370919, 34.95631415503365, 36.26028258459908, 34.68462221963065, 38.35508108139038, 41.7151152747018, 49.5140825680324, 48.45530564444405, 48.35951083047049, 49.21322556904384, 48.47857863562447, 51.021056515829905, 50.03306089128767, 46.13315861565726, 49.92587797982352, 49.84069653919765, 50.79111977985927, 50.97082451411656, 54.716035570417134, 53.18297461100987, 52.22683995110648, 53.17608199800764, 39.204286439078196, 47.5072934286935, 56.952306338718955, 54.83292164121355, 65.0461517061506, 68.29192624773297, 49.083672932216096, 6.683242065565927, 0.2798479806099619, 0.47147506369011744, 0.6533109407339777, 0.1280971792127405, 0.8556427551167352, 48.60332659312657, 61.390190260750906, 57.541312081473215, 54.843951906476704, 39.320891107831685, 15.707410403660365, 8.139279638017927, 31.654818534851074, 47.44917869567871, 55.977522713797434, 7.349147864750453, 0.2506659807903426, 0.0707407837201442, 0.05862957824553762, 0.025962780329531858, 0.05812462605535984, 0.05922017512576921, 0.039294495579919646, 0.011925225811345237, 0.04988595563918352, 0.021967520338616202, 0.08206483429031712, 0.03696882698152747, 0.05860996858349868, 0.6989571856600898, 35.46941777638027, 66.91839245387486, 48.481316225869314, 38.56577825546265, 17.195094415119716, 41.036811283656526, 55.2370149748666, 48.283650398254395, 64.01080758231026, 58.21355029514858, 50.37511723382132, 0.6832551796521459, 0.21910909483475344, 3.7559212701661244, 12.037687182426453, 3.9770020927701677, 0.4604620060750416, 17.067325728280203, 58.80009637560163, 47.75982223238264, 60.00755432673863, 55.71292488915579, 52.961448669433594, 45.62934126172747, 44.15274831226894, 42.40716975075858, 43.798980781010215, 40.79490974971226, 41.16635002408709, 40.85894087382725, 41.35785279955183, 40.966683115277974, 45.67576912471226, 41.72493307931082, 43.377666337149485, 42.55612523215157, 47.05560493469238, 44.390790121895925, 46.101196902138845, 45.646729128701345, 43.47127941676548, 41.469010080610005, 37.17800065449306, 35.17326818193708, 35.76703691482544, 35.848171029772075, 37.477276938302175, 38.025152819497244, 36.91224595478603, 37.02219077519008, 36.649531091962544, 37.390393189021516, 37.573061329977854, 38.6566606930324, 37.9615490095956, 36.586854866572786, 37.31112813949585, 38.60547678811209, 35.78556776046753, 37.41504887172154, 38.57264654976981, 37.193644523620605, 38.58115809304373, 38.59411300931658, 39.25292035511562, 37.42590543201992, 37.72204113006592, 35.69075959069388, 37.73691374914986, 36.38544395991734, 38.14523158754621, 36.794734546116416, 42.39334978376116, 44.45550216947283, 45.81511524745396, 44.01100853511265, 42.46120241710118, 45.585949761526926, 50.253749574933735, 47.35067408425467, 37.74021414348057, 39.906429699489046, 49.327405316489084, 47.56025954655239, 44.25984437125069, 45.33359466280256, 44.03092902047293, 43.60393442426409, 43.394842284066335, 37.08406448364258, 36.85472181865147, 37.66112974711827, 38.86912270954677, 36.275850023542134, 37.39990874699184, 35.45015736988613, 37.730757645198274, 39.214601039886475, 39.84540367126465, 40.50139004843575, 38.83867570332119, 38.8967730658395, 39.52580043247768, 36.8042813709804, 36.89155421938215, 37.87785448346819, 36.737391063145225, 36.814860003335134, 39.18861477715628, 37.60650300979614, 36.58766780580793, 39.30346155166626, 38.45397479193551, 36.603019850594656, 39.37012604304722, 37.90985788617815, 37.15417528152466, 36.94453770773751, 39.095217091696604, 37.192289624895366, 40.552657331739155, 43.72719199316842, 50.601482595716206, 50.34330143247332, 49.05995873042515, 49.4136255128043, 51.21933031082153, 51.99856383459908, 51.9321460042681, 48.38914489746094, 52.99838876724243, 51.20077167238508, 53.665669441223145, 54.484469481876914, 56.35656084333147, 54.92736503056118, 51.91186421258109, 55.855144092014854, 36.81413391658238, 46.54948077883039, 58.78114168984549, 57.13571446282523, 64.08842590876988, 66.04268319266183, 53.235718386513845, 7.126308279378073, 0.2900060841015407, 1.6818910475288118, 1.2218678636210305, 0.2805599809757301, 0.954792354788099, 51.2756940977914, 68.17774650028774, 62.27127047947475, 62.728184018816265, 41.12487275259835, 14.166956560952322, 13.252108097076416, 39.4898921421596, 53.50077479226248, 65.1115550994873, 10.476876854896545, 0.2820688257259982, 0.05884457206619637, 0.05864372570067644, 0.09238871067230191, 0.0877028089016676, 0.028036471556073854, 0.13304193530763897, 0.11149558504777295, 0.10132359194436244, 0.09406171339963164, 0.1630847653640168, 0.0972334099933505, 0.23570941335388593, 0.9456133501870292, 48.67591789790562, 76.32450239998954, 56.358895438058035, 46.97672551018851, 21.86171998296465, 41.200476101466585, 67.5621361051287, 54.806365626198904, 70.74808665684291, 63.815973145621165, 55.872511114392964, 1.0157835334539413, 0.28327352393950733, 8.47996197428022, 21.54776041848319, 9.660945551736013, 2.5207176421369826, 21.286871194839478, 61.25565923963274, 46.96729680470058, 61.817087582179475, 59.40382535117013, 56.905624866485596, 47.510315895080566, 47.87984888894217, 43.99255064555577, 45.12999507359096, 43.38129677091326, 41.80962119783674, 43.176234585898264, 43.87369476045881, 44.369222913469585, 47.449335030147004, 43.40118598937988, 45.685069288526265, 43.76874916894095, 49.19824525288173, 46.98759249278477, 49.07462985174996, 48.62088816506522, 46.50025626591274, 44.38957071304321, 39.109495639801025, 38.39682238442557, 39.278263909476145, 38.469007219587056, 40.61540651321411, 39.4597612789699, 39.06216103690011, 38.21399790900094, 38.66246591295515, 39.2645377431597, 39.6363080569676, 41.18513100487845, 40.23536784308297, 37.99960429327828, 40.51156915937151, 41.8035033089774, 38.75785425731114, 39.177754742758616, 40.62910488673619, 39.11294889450073, 41.257562501089915, 42.09650536945888, 40.61479507173811, 40.142880371638704, 41.11432538713728, 35.999530587877544, 40.50770596095494, 38.235228129795615, 38.734115736825125, 38.984021595546174, 43.76552520479475, 45.661452361515586, 48.82252141407558, 45.98830604553223, 43.60870088849749, 48.666506562914165, 51.5276392527989, 49.48435122626168, 40.78009271621704, 41.99331767218453, 52.199887888772146, 48.5877799987793, 47.99572399684361, 47.81816278185163, 47.393151896340505, 44.19761630467006, 45.27828005381993, 38.259487765175955, 40.388989039829795, 40.00375311715262, 40.971098695482524, 39.6163979939052, 39.51701096126011, 37.57836627960205, 39.07312182017735, 41.1404401915414, 42.02407734734671, 43.40717533656529, 42.02081864220755, 40.87931299209595, 42.24497447695051, 39.59281580788748, 40.53035361426217, 38.83673368181501, 38.220042841775076, 39.672765254974365, 40.932167938777376, 40.42489038194929, 39.16282306398664, 41.06817545209612, 40.35004786082676, 39.03564671107701, 42.74869108200073, 41.35517774309431, 40.85679040636335, 39.17943968091692, 40.30249786376953, 37.994514737810405, 42.05820689882551, 45.858451162065776, 54.42364147731236, 53.17162472861153, 50.976876395089285, 51.38113995960781, 52.887214115687776, 55.699035440172466, 54.73977061680385, 49.82971838542393, 54.96603870391846, 53.45415585381644, 55.419182845524375, 55.14803981781006, 59.206510407584055, 55.904632636478965, 54.424735818590435, 56.561511857169016, 40.85466773169381, 50.051862716674805, 59.71885667528425, 58.753946440560476, 68.35410567692348, 63.502317564828054, 55.619363921029226, 8.452834469931465, 0.6476668321660587, 4.224965929985046, 4.063605308532715, 0.5799967518874577, 1.3432963192462921, 55.66432918821062, 72.82949597494942, 67.28250585283551, 69.20551708766392, 47.95359012058803, 23.21860068184989, 19.333845479147776, 48.303372859954834, 62.929230145045686, 76.1290704182216, 15.287763527461461, 0.42838241745318684, 0.19645483259643826, 0.1399763324963195, 0.18536036434982503, 0.2639432283384459, 0.18888335887874874], [0.021391050557472875, 0.04730849626607128, 0.02833683186742876, 0.03520888016958322, 0.07189223729074001, 0.021791557548567653, 0.048272189018981795, 0.7494115297283445, 25.955278975622996, 57.29248666763306, 39.600740228380474, 32.36271490369524, 16.748325245721, 18.063162394932338, 35.96375778743199, 50.02716187068394, 55.255611828395296, 51.73573432649885, 46.594432149614605, 0.7738780911479677, 0.1345099593911852, 2.95439966235842, 21.7006607396262, 11.148405483790807, 0.05194231368867414, 29.63428933279855, 49.68137781960623, 53.63067136492048, 56.84245184489659, 52.78157717841012, 51.807616915021626, 47.62414823259626, 40.69210072926113, 41.95163195473807, 38.68027414594378, 40.69728061131069, 37.72063064575195, 40.15205199377877, 38.97724710191999, 41.53781809125628, 40.10475560597011, 42.44817801884243, 39.37627867289952, 41.67226225989205, 41.14771148136684, 39.90946953637259, 41.450538294655935, 41.25353602000645, 37.38683571134295, 35.46630845751081, 35.119176455906455, 35.40396227155413, 35.302685328892295, 34.899953842163086, 33.111588273729595, 35.75147294998169, 34.15132365907942, 34.20363664627075, 33.91407741819109, 35.409156050000874, 35.721654755728586, 37.040224824632915, 35.97012233734131, 36.91916636058262, 35.447082792009624, 34.545564447130474, 35.71909434454781, 35.13650178909302, 34.5048827443804, 37.88793631962368, 37.95841189793178, 38.250312668936594, 37.10461378097534, 37.374777112688335, 36.1594364302499, 35.038361958095, 34.901600565229145, 35.6128876549857, 35.328240803309846, 36.27489117213658, 38.61955036435808, 41.86820493425642, 44.639514786856516, 45.98384877613613, 40.66048295157296, 42.31437655857631, 47.36888183866228, 48.137192794254844, 41.842003277369905, 38.00173739024571, 46.41393184661865, 46.4248092515128, 44.85744850976126, 44.00502961022513, 43.64755174091884, 42.82115731920515, 38.41523858479091, 34.06280360903059, 34.443266119275776, 36.138286113739014, 34.992041792188374, 34.438256468091694, 35.40292351586478, 35.05116401399885, 36.4180657523019, 37.574002810886924, 38.315073353903635, 40.08213227135794, 40.94814184733799, 38.95321328299386, 38.477299894605366, 35.60647446768624, 35.93609006064278, 35.8230949810573, 35.50253289086478, 37.19447135925293, 36.74285929543631, 39.290662969861714, 35.08544989994594, 36.97513410023281, 36.2404420035226, 37.2347674369812, 35.25436060769217, 34.52498040880476, 35.9573654447283, 35.43640341077532, 35.103338037218364, 37.23743554524013, 35.371392590659006, 41.360114438193186, 50.657467705862864, 49.44733122416905, 48.237910406930105, 46.59533541543143, 48.65508025033133, 50.74183620725359, 50.727998869759695, 49.613841329302105, 51.07695477349417, 53.25243575232369, 53.64837884902954, 51.072549615587505, 49.65737526757376, 52.177976744515554, 53.424209117889404, 58.260829312460764, 40.300795555114746, 41.35754707881382, 57.9734240259443, 50.55676051548549, 54.50104440961565, 42.42448813574654, 58.75473158700125, 7.3207114934921265, 0.230476904128279, 0.8486009186932019, 1.03512319283826, 0.07193331580076899, 0.2875178690467562, 43.35002987725394, 64.03748171670097, 60.644273349217, 56.52718775612967, 48.35931975500924, 33.83863040379116, 11.109485149383545, 24.66846912247794, 43.2585950578962, 56.2527756009783, 13.351486444473267, 0.2356868317084653, 0.13835212322218077, 0.10137306393257209, 0.033073130130235634, 0.032488836840327294, 0.07811168927167143, 0.017207585308434706, 0.09989273800913777, 0.031278907121824365, 0.05886043621493237, 0.002275257687350469, 0.013749838706904223, 0.026312834849315028, 0.8519774717944009, 36.52993522371565, 66.45831748417446, 47.18943418775286, 38.15359721864973, 18.65280737195696, 21.88573816844395, 43.266317980630056, 54.42234911237444, 61.42741870880127, 56.91858673095703, 50.452075481414795, 0.7846660922680582, 0.02188105971020247, 5.894673636981419, 18.514812673841202, 5.25583324262074, 0.11170880110668284, 31.861252989087784, 49.80970062528338, 53.34328692299979, 60.60523836953299, 54.837184361049104, 53.269118377140586, 49.62546566554478, 42.600555488041465, 42.19866820744106, 41.04428407124111, 43.32106283732823, 39.34476164409092, 42.24492931365967, 41.54449531010219, 43.47032751355852, 42.717643056597026, 43.879725796835764, 41.396512576511924, 44.83307075500488, 44.155649185180664, 41.26630680901663, 43.37843063899449, 42.227312156132285, 40.62211847305298, 37.34466361999512, 35.1860910824367, 35.58303819383894, 37.606513432094026, 36.77946240561349, 36.951659611293245, 37.04595708847046, 35.415510177612305, 36.682142462049214, 36.84827389035906, 35.38986437661307, 36.945948192051475, 38.27493013654436, 37.61582401820591, 38.51391690117972, 37.061997004917686, 37.13993147441319, 38.422673157283235, 37.32002878189087, 37.0964982850211, 39.36224678584507, 38.788884912218364, 38.31769282477242, 38.53651244299752, 38.81770256587437, 36.970020226069856, 35.28496047428676, 37.947607449122835, 37.37667744500296, 35.26843418393816, 38.13833550044468, 40.1924592426845, 44.690903663635254, 45.849481037684846, 46.69867944717407, 42.20260436194283, 45.300830432346885, 50.26377929959978, 50.18224218913487, 43.83116136278425, 38.88866451808384, 47.83399077824184, 49.544453144073486, 46.7147193636213, 46.561959743499756, 46.269655976976665, 44.394358021872385, 39.08902972085135, 35.365326813289094, 38.22940901347569, 36.640098912375315, 37.642314025333945, 36.77346611022949, 36.477316515786306, 36.78579568862915, 36.934997831072124, 39.59188822337559, 41.91858632223946, 41.249485220227925, 43.516592093876426, 39.79338945661272, 39.545884200504844, 36.78311368397304, 37.975778920309885, 38.297407558986116, 37.602250712258474, 38.489817074366975, 38.16310235432216, 39.32764475686209, 36.40850155694144, 39.07083933694022, 38.58689383098057, 39.2859069279262, 37.00747101647513, 37.186560835157124, 38.39221225466047, 37.63785675593785, 36.17980507441929, 39.04983493259975, 38.09894616263253, 43.65169286727905, 51.77718380519322, 50.76141275678362, 51.85772384916033, 48.539910384586875, 51.470636231558665, 51.68062468937465, 52.515026909964426, 52.254264490945, 52.767958709171836, 54.26582704271589, 54.52731554848807, 52.83368866784232, 51.26832900728498, 54.436964648110525, 53.01957382474627, 58.26096827643258, 43.33033868244716, 42.17228937149048, 58.82999447413853, 50.91530840737479, 57.85087169919695, 43.3435263633728, 59.870674814496724, 8.857534033911568, 0.28449295993362156, 1.597510929618563, 1.1632599170718874, 0.05343998296718512, 0.24620244173066957, 46.552861077444895, 69.66974708012172, 65.97455610547746, 61.26748507363455, 53.64391115733555, 32.93257141113281, 14.765550817762103, 31.66759627205985, 50.41303007943289, 63.53605106898716, 18.46591646330697, 0.16475493860031876, 0.10963851612593446, 0.06317264839474644, 0.01992831565439701, 0.05091016353773219, 0.02697359225047486, 0.08320883076105799, 0.14203944536192076, 0.15579634931470665, 0.18921985796519689, 0.15773744801325457, 0.08955530449748039, 0.0756810682692698, 1.063820230109351, 47.90175655909947, 73.55038547515869, 55.18992703301566, 47.41876643044608, 24.86227696282523, 24.010697058268956, 50.604842049734934, 62.009045464651926, 65.2867122377668, 61.83453450884138, 53.939216545649934, 0.955733944262777, 0.19507883143212112, 9.791576027870178, 34.813678060259136, 23.188794646944316, 0.24929050888334, 36.707809107644216, 52.28584057944161, 53.49781485966274, 62.14285387311663, 57.16379908152989, 55.85728413718087, 51.2537065233503, 43.03121525900704, 44.8387439591544, 43.556116921561106, 44.48369448525565, 42.58704124178205, 44.71256814684187, 44.594407081604004, 45.84211247307913, 45.732858998434885, 46.902463163648335, 44.30338873182024, 45.48175457545689, 45.426551137651714, 45.08305999210903, 47.234482833317344, 43.82488019125802, 42.61510501589094, 40.687671252659385, 38.31267275129046, 38.01455681664603, 39.66517782211304, 38.11302668707711, 38.892201151166645, 39.19505228315081, 36.49562154497419, 38.507020814078196, 38.836709363119944, 38.48245545795986, 38.819773129054475, 40.586571489061626, 40.50332859584263, 41.53955166680472, 38.36772332872663, 37.78400863919939, 39.54541867119925, 38.82606472287859, 37.92056506020682, 41.3581793648856, 42.66131748471941, 40.727838788713726, 39.10168586458479, 42.19747659138271, 39.96036856515067, 38.11086927141462, 39.48644583565848, 38.91368498120989, 37.52010563441685, 41.27314036233084, 42.15457493918282, 45.383694648742676, 48.72494091306414, 49.34616197858538, 45.019650731767925, 46.30630772454398, 52.559349468776155, 52.58830261230469, 45.32640675136021, 41.10623073577881, 50.48232446398054, 52.06900119781494, 49.2109500340053, 48.50660766874041, 48.271775926862446, 47.01505177361624, 42.5176739011492, 37.68150881358555, 39.62351989746094, 40.16684818267822, 39.292764799935476, 40.054360321589876, 38.0371801512582, 38.26580367769514, 38.73615503311157, 41.46382672446114, 43.6764805657523, 42.3764830316816, 45.26303570611136, 42.94528341293335, 42.20517519542149, 39.35787984303066, 41.90089620862688, 38.810573714120046, 39.9123843056815, 41.662670271737234, 40.818127155303955, 41.94877971921648, 38.01999030794416, 41.769742012023926, 41.15855414526803, 41.7324093409947, 39.28765092577253, 38.89806195667812, 39.2091189111982, 39.84126601900373, 38.77244547435215, 41.02108056204659, 39.429828439440044, 45.85739156178066, 56.03307008743286, 52.95396545955113, 53.1724202973502, 51.27356794902256, 51.617288385118755, 54.67809493201119, 54.10791533333914, 54.54825047084263, 55.05749784197126, 57.540057931627544, 57.769136565072195, 54.8931416784014, 53.767627307346885, 55.97876991544451, 53.73350470406668, 60.46432890210833, 44.765860830034526, 43.57906334740775, 58.769621576581685, 51.61208765847342, 60.385598863874165, 46.61773293358939, 61.04560824802944, 9.936604040009634, 0.48216996980564936, 3.4813275933265686, 2.3553833024842397, 0.19292218929954938, 0.6419450991920063, 49.39615079334804, 74.0144487108503, 70.73813683646065, 69.09811878204346, 61.91158308301653, 45.89193800517491, 23.653361627033778, 42.05409703935896, 60.78207697187151, 75.25144345419747, 22.958368062973022, 0.3012952511864049, 0.20644122601619788, 0.1582762183887618, 0.08391657671225922, 0.10201176216027566, 0.168903203148927], [0.031320199370384216, 0.10059659595468215, 0.03160348095531974, 0.038824372592249086, 0.027352930645325353, 0.020223376607256274, 0.02531347829582436, 0.396164706242936, 36.01809964861189, 53.5557141985212, 41.12097481318882, 33.01006119591849, 15.425959723336355, 37.069139753069194, 30.769538130078995, 48.93136494500296, 55.76655108588082, 54.38559661592756, 46.51478147506714, 1.4803281490291869, 0.2558525396244866, 5.710300581795829, 18.378678355898174, 0.6429598618830953, 0.18697845323809556, 40.721870286124094, 58.20548691068377, 50.74016169139317, 53.30240024839129, 53.40801286697388, 53.42298970903669, 46.8395402772086, 41.23816313062395, 38.16863659449986, 38.660395349775044, 40.49161393301827, 39.63071823120117, 40.51168727874756, 41.814641271318706, 39.79312889916556, 39.87752866744995, 41.668374742780415, 43.64516156060355, 38.47528144291469, 40.65288162231445, 37.442306654793875, 35.90024430411202, 35.10988324029105, 34.38717678615025, 34.97663416181292, 34.11623873029436, 34.76487738745553, 35.41956097739083, 35.41209166390555, 34.417102677481516, 33.83030646187918, 33.130480425698416, 33.002967085157124, 35.14455822535923, 36.16613449369158, 35.28086798531668, 36.055192606789724, 36.0107102394104, 35.02362135478428, 35.00341599328177, 35.64045115879604, 34.088473728724885, 35.261423451559885, 35.45633431843349, 36.84751306261335, 40.25614643096924, 37.06894520350865, 38.329428332192556, 35.80260474341256, 36.27065971919468, 34.56510278156826, 35.90884617396763, 35.081197602408274, 36.17963831765311, 34.57271453312465, 37.94062450953892, 41.576165199279785, 42.70577205930437, 44.88886478969029, 45.04531390326363, 43.052237033843994, 43.44986159460885, 46.983652864183696, 42.3386674608503, 40.878427096775596, 45.07164410182408, 45.254312242780415, 44.25495283944266, 43.36587177004133, 43.723853383745464, 43.39060040882656, 38.1373245375497, 34.693616662706646, 34.86109604154314, 34.77477857044765, 33.547080516815186, 34.155249391283306, 35.124700273786274, 34.13416508265904, 36.07931327819824, 38.257566588265554, 39.88739858354841, 41.59151724406651, 41.508413314819336, 37.37255368913923, 36.46491398130144, 36.05586658205305, 35.18873487200056, 36.247629914964946, 37.38382714135306, 36.06321430206299, 34.87735482624599, 34.848811626434326, 35.910871573856895, 36.45116697038923, 37.643498693193706, 36.45023938587734, 34.88963924135481, 35.03190360750471, 35.8029591015407, 35.147361823490684, 36.06570175715855, 36.285539286477224, 37.41585486275809, 37.410209451402935, 48.629976408822195, 49.20836877822876, 50.53509603227888, 49.32206909997122, 50.8243738583156, 48.6166740826198, 52.03452771050589, 50.45707471030099, 51.32192741121565, 47.65029082979475, 51.569439615522114, 51.48741613115583, 54.9351852280753, 53.61250877380371, 55.7398213659014, 54.45871250970023, 61.23654474530901, 59.58984252384731, 57.72169426509312, 57.632396016802105, 49.88024568557739, 33.11021600450788, 53.03217090879168, 9.66991741316659, 0.5380462972181184, 0.08315468366656985, 0.30385107547044754, 0.039277712016233375, 0.1042300695553422, 38.86723974772862, 63.999231883457725, 58.199542726789204, 61.784417152404785, 41.36270611626761, 18.435509409223283, 13.207289610590253, 28.76669556753976, 40.101274558476035, 55.90108905519758, 18.13979755129133, 0.1895264879401241, 0.10710078837083918, 0.07455071713775396, 0.011112153413705528, 0.009679490334487386, 0.02796179029558386, 0.041935157097343884, 0.05226063821464777, 0.011933447111264935, 0.08918726710336548, 0.05674720336017864, 0.038522054707365375, 0.08030024290617023, 0.5694006947534425, 45.18232890537807, 61.111025537763325, 49.1818197114127, 39.67084060396467, 17.255100795200892, 33.95583956582205, 39.083828994206016, 54.327030250004356, 61.64200687408447, 58.767022950308665, 50.92169727597918, 1.3453649282455444, 0.08471726839031492, 3.9424356733049666, 23.738430159432546, 2.9800013857228413, 0.25236009274210247, 46.240251200539724, 58.05039964403425, 54.924978324345176, 55.0238789830889, 56.38374219621931, 53.8376373563494, 49.84052630833217, 43.02272456032889, 40.30011463165283, 39.95199945994786, 42.235563141959055, 41.42067493711199, 41.67158828462873, 42.996498584747314, 42.03084489277431, 43.05070495605469, 43.50922005517142, 44.47569710867745, 42.39965179988316, 42.757987771715435, 40.04490382330758, 37.74837132862636, 36.33914463860648, 34.16248594011579, 37.314991337912424, 36.47243888037545, 37.27845423562186, 37.24026346206665, 36.50046443939209, 36.64529269082205, 35.86235230309622, 36.06604221888951, 35.603160176958355, 35.36914484841483, 37.09707498550415, 36.58357531683785, 36.95480367115566, 37.98723649978638, 37.36146783828735, 36.209710121154785, 37.213665757860454, 35.90738705226353, 37.60540519441877, 36.701958724430625, 39.26041398729597, 42.723215511866975, 39.61751665387835, 40.306006704057964, 38.72024713243757, 36.48486225945609, 36.374490124838694, 36.92672600064959, 36.96479518072945, 38.31436116354806, 36.729494435446604, 40.50416585377285, 43.079960346221924, 44.49621166501726, 46.95601987838745, 46.08392020634243, 44.11822966166905, 44.59116574696132, 48.86444684437343, 45.2442512512207, 41.90992886679513, 47.58819477898734, 46.983986377716064, 47.130544730595176, 45.17784036908831, 45.622427804129465, 44.452392850603374, 40.375655446733745, 37.38889932632446, 36.33414193562099, 35.99668182645525, 35.823859282902305, 37.91271359579903, 36.89717878614153, 36.077051639556885, 37.69900437763759, 39.742945534842356, 42.45522696631295, 43.82791655404227, 42.66509730475289, 39.128669193812776, 37.592474596840994, 38.01914957591465, 36.146613529750276, 38.15733882359096, 38.24514668328421, 38.692405700683594, 37.54997246606009, 37.97967685971941, 36.48696061543056, 38.9469564301627, 38.10102367401123, 38.704523359026226, 36.48530347006661, 38.30720451899937, 37.20176696777344, 36.378485339028494, 37.818714891161235, 39.5415415763855, 39.807730538504465, 39.30121728352138, 50.18818984712873, 51.264135769435335, 52.49559627260481, 52.451972007751465, 51.72755977085659, 50.24184731074742, 53.704728739602224, 54.98231485911778, 52.792131492069785, 50.71081597464425, 51.960244519369944, 52.141491753714426, 55.31576933179583, 54.37790496008736, 56.54305049351284, 54.99429702758789, 61.90367603302002, 59.42405155726841, 60.40125315529959, 58.175189290727886, 53.75895248140608, 35.60824278422764, 54.4199207169669, 10.786305325371877, 0.4764017164707184, 2.874798493725913, 2.457396537065506, 0.08844824068780456, 0.06970333081803151, 41.32338626044137, 70.34906550816127, 63.38485131944929, 67.43266337258476, 44.256648199898855, 21.786957366125925, 18.615757840020315, 36.671595096588135, 49.335896015167236, 65.62135137830461, 23.368257931300572, 0.17876071562724455, 0.1683310488505023, 0.03155706237469401, 0.01860317408240267, 0.050135334221912284, 0.0148192268596696, 0.16000979393720627, 0.23958460826958927, 0.13982724478202208, 0.13127040251025132, 0.10679668254618134, 0.11189043136047465, 0.09537023425634418, 0.6227074914744922, 55.4705091885158, 71.10311181204659, 56.12244476590838, 48.57797261646816, 23.184822014399938, 48.57920592171805, 42.472573144095286, 59.74735818590437, 65.81396933964321, 64.67318630218506, 55.18741525922503, 1.9745842388698032, 0.3303112270576613, 11.125454715320043, 34.172911712101524, 3.9142807040895735, 0.38256675590361866, 49.95740543093, 57.307630266462056, 57.3327271597726, 56.21699237823486, 58.61316898890904, 56.95113556725638, 50.713480608803884, 45.34467703955514, 42.289217131478445, 41.634179183415, 44.69968966075352, 43.59507894515991, 44.09478643962315, 45.21577058519636, 43.92862721851894, 45.155574866703574, 47.03000429698399, 48.61978687558855, 44.5701960836138, 45.89452968324934, 41.57236106055123, 40.27283252988543, 39.15864372253418, 36.987897941044395, 39.841891356876914, 37.861727714538574, 39.401813302721294, 39.75240898132324, 40.0250632422311, 39.10914822987148, 37.74108614240374, 37.69383144378662, 35.89550563267299, 38.72946391786848, 40.26032229832241, 38.69521624701363, 39.895538398197715, 41.434057167598176, 38.19964640481131, 38.63201543263027, 40.50855711528233, 37.11599840436663, 40.28532191685268, 40.435920647212434, 41.17592464174543, 44.923532826559885, 40.890895639147075, 41.68153463091169, 39.39536884852818, 39.70466096060616, 39.38941771643502, 39.24026421138218, 38.22557013375418, 40.39025361197335, 38.813478061131065, 43.383589676448274, 47.28287703650338, 46.64594956806728, 48.72868251800537, 48.88877248764038, 47.42537069320679, 45.33805193219866, 51.673850195748464, 47.56571735654558, 44.55518797465733, 51.59042664936611, 49.81065252849034, 47.90768684659685, 47.73758799689156, 48.00020211083548, 48.01054450443813, 42.324857916150776, 39.90588426589966, 38.54232461111886, 38.39069754736764, 36.98289523805891, 39.399371010916575, 39.24953658240182, 37.426433495112825, 39.82025466646467, 41.36534295763288, 42.80611446925572, 45.52721316473824, 43.75842761993408, 40.470411505017964, 40.30380759920393, 40.636007922036306, 38.81248794283186, 40.636171204703196, 41.27234479359218, 40.654743739536826, 39.18151371819632, 40.228711468832834, 38.02242912564959, 42.36585576193673, 41.29416561126709, 41.00276858466012, 38.19914960861206, 39.42479794366019, 39.49679517745972, 39.50223561695644, 39.847508975437705, 42.41650465556553, 41.91832229069301, 41.82351759501866, 51.87468440192086, 53.32842820031302, 54.366725308554514, 53.63500356674194, 54.534260272979736, 52.000978333609446, 56.23618677684239, 56.40232515335083, 54.9601605279105, 51.876303332192556, 53.081433636801584, 56.15320791516985, 58.441416467939106, 58.99614674704415, 59.696761403764995, 59.2684188570295, 65.23824855259487, 62.224133900233674, 62.223550251552034, 61.08709594181606, 56.23807668685913, 40.26245192119053, 58.23737914221627, 12.667548332895551, 0.48810226576668875, 4.052247609410967, 3.381460266453879, 0.21617497370711394, 0.2652700085725103, 45.12931762422834, 75.9821993964059, 68.9731137411935, 74.03680106571743, 51.95096867425101, 26.304379054478236, 25.839746066502162, 47.27478585924421, 57.6410882132394, 76.257890020098, 29.197577680860245, 0.3248477173703057, 0.22711975712861332, 0.3090853217457022, 0.202508450618812, 0.1478027453912156, 0.18232827633619308], [0.02155141722011779, 0.03313034759568317, 0.04077166970819235, 0.03175756608002952, 0.07357290067843028, 0.0505950858018228, 0.1744589257453169, 0.43908120478902546, 31.39523036139352, 57.77109248297555, 43.66524532863072, 44.023473603384836, 23.255325385502406, 23.19441400255476, 32.56116587775094, 54.543716771262034, 55.959394863673616, 53.06036669867379, 43.57598876953125, 0.5272846232567514, 0.24015085931335176, 6.877351718289511, 12.202792882919312, 2.620475317750658, 0.996106452175549, 52.84336403438023, 49.67547879900251, 45.18066133771624, 53.92054673603603, 53.208432810647146, 52.55522223881313, 50.08153847285679, 46.28297914777483, 41.69240508760725, 39.168260029384065, 41.21882976804461, 39.523976530347554, 40.01544346128191, 41.0341397012983, 40.51057209287371, 41.27980021068028, 40.31007834843227, 40.01648569107056, 39.99985517774309, 36.763179302215576, 36.553156103406636, 34.508461066654746, 33.7672689301627, 34.61537994657244, 35.02643537521362, 34.52811404636928, 36.55927399226597, 34.42076785223824, 33.793512276240754, 33.94257198061262, 34.26217174530029, 33.595856870923726, 34.74070460455758, 35.16444744382586, 35.189811842782156, 33.79252910614014, 34.293556758335654, 35.604355267116, 34.54755858012608, 34.587215423583984, 34.547787870679585, 34.04283101218087, 36.12679031917027, 35.287979466574534, 36.808488505227224, 37.63555690220424, 38.31852313450405, 36.5335031236921, 35.693670885903494, 35.7049686568124, 35.00381204060146, 34.82017115184239, 34.77644961220877, 33.427026067461284, 33.8065436226981, 35.743871620723176, 39.489631584712434, 41.25815657206944, 42.98872702462332, 44.661596161978586, 45.786273275102886, 46.02473545074463, 47.43569571631295, 45.80842065811157, 41.10224941798619, 42.955003942762104, 46.58335324696132, 46.235852990831646, 44.251527377537315, 44.24184158870152, 39.984652519226074, 37.13007892881121, 34.88651950018746, 34.577116216932026, 34.561378547123496, 35.77534696034023, 34.805857862745015, 33.72992583683559, 36.015695571899414, 35.06833301271711, 38.289107935769216, 39.974841662815635, 38.999012334006174, 39.91718898500715, 37.348384380340576, 34.99434164592198, 35.493312631334575, 36.763280051095144, 35.351086480276926, 34.74130909783499, 35.505774225507466, 35.05878618785313, 36.50960826873779, 35.268917083740234, 35.447221755981445, 35.66881717954363, 34.703194754464285, 35.71349062238421, 35.0168433870588, 36.628960950034006, 33.00984927586147, 35.90559789112636, 36.083860874176025, 35.76178060259138, 34.21731070109776, 39.494015898023335, 48.42997251238142, 48.813467911311555, 49.29668733051845, 52.10270343508039, 50.70492737633841, 50.41767495019095, 50.20983695983887, 47.620333671569824, 49.032572405678884, 51.96882554462978, 53.354459626334055, 53.15780823571341, 51.07006216049194, 52.362215178353445, 54.13127865110125, 52.12286363329206, 50.82878596442086, 58.938587869916645, 53.08092294420515, 58.0282244682312, 33.432650634220664, 40.86061886378697, 10.168032033102852, 0.30566249255623135, 0.9526504640068326, 1.11138716340065, 0.06791172016944204, 0.04497001692652702, 39.531789779663086, 59.564412117004395, 64.67559037889752, 55.51529032843453, 59.24711568014962, 37.95982585634504, 12.226654733930316, 26.664127247674124, 38.660044465746196, 61.57284450531006, 22.354760680879863, 0.05985402861343963, 0.02425754549247878, 0.09020641313067504, 0.040025637418563874, 0.022579513124323318, 0.029410530413900102, 0.05868964216538838, 0.027026816537337642, 0.03728184197098017, 0.007040479353496006, 0.08452252883996282, 0.030521200637200048, 0.04492877556809357, 0.5876190885901451, 41.04646233149937, 65.53708362579346, 50.42028399876186, 49.04481165749686, 25.36155888012477, 26.073033571243286, 36.34672859736851, 59.43324402400425, 60.950042724609375, 59.15205042702811, 48.29698746544974, 0.6658433196800095, 0.3446871856493609, 3.5812196731567383, 13.203739081110273, 1.9166353940963745, 1.3343905742679323, 54.51569468634469, 51.6691323689052, 49.67132725034441, 54.32482419695173, 54.31230354309082, 54.47442933491298, 51.004266193934846, 47.05800206320626, 43.9972927910941, 41.18848351069859, 44.128645011356895, 41.5334928376334, 43.33613348007202, 43.26249647140503, 43.17383050918579, 42.34277037211827, 41.66069350923811, 41.607807295663015, 42.793350628444124, 39.69216809953962, 36.686926296779085, 37.09583820615496, 34.999698707035606, 36.46644605909075, 36.99587099892752, 36.1653528213501, 37.483672755105154, 36.74810865947178, 36.41712427139282, 36.76011862073626, 36.90641989026751, 34.76723630087716, 35.04367733001709, 35.30646167482649, 36.90232045309884, 37.44861214501517, 36.395887102399556, 36.258493423461914, 37.49502263750349, 35.87631818226406, 36.34520346777779, 35.31360789707729, 38.06985752923148, 36.45439093453543, 39.54342106410435, 39.931582178388325, 39.545199802943635, 38.814978872026714, 37.26188278198242, 36.56662171227591, 36.64300673348563, 35.55004467282976, 37.048517499651226, 34.38416821616036, 37.602191652570454, 38.907188415527344, 41.12691899708339, 44.09622471673148, 46.23936530521938, 47.96417222704206, 46.94771678107125, 48.119829245976035, 48.32587112699236, 46.76716784068516, 41.69294704709734, 44.90949746540615, 47.54484496797834, 47.28351627077375, 45.07275928769793, 46.99336644581386, 43.15692554201399, 38.0334871837071, 37.02827739715576, 37.96737160001482, 36.34155913761684, 37.166150501796174, 36.38047252382551, 35.91558592660086, 38.21829884392874, 38.02508681161063, 40.660969325474326, 41.00276511056082, 42.18935414722988, 42.71152169363839, 38.18450975418091, 36.056651728493826, 36.5885398047311, 36.49812984466553, 36.45489467893328, 38.34684746606009, 37.894502367292134, 37.83958727972848, 38.66991785594395, 37.13832991463797, 36.55104385103498, 37.442883355276926, 37.62755605152675, 37.0475378036499, 36.634849548339844, 38.74139050074986, 34.96946709496634, 37.2858019556318, 38.50026021684919, 40.07903684888567, 37.26223019191197, 41.65337358202253, 49.30643217904227, 49.7125370161874, 50.210135732378276, 53.345916816166465, 52.39884955542428, 50.76813166482108, 51.017026560647146, 48.70886625562395, 50.61356898716518, 54.348270893096924, 55.340925284794395, 54.58083404813494, 52.33452660696847, 54.25659983498709, 56.80036660603115, 54.48149912697928, 53.27806070872715, 60.14198112487793, 55.253992898123606, 58.828653471810476, 38.26678337369646, 41.499759333474294, 12.111977321760994, 0.34923782146402765, 2.8121311707156043, 3.466439340795789, 0.12815885804593563, 0.039812312794051, 40.44229561941964, 66.68305696759904, 67.86930206843785, 64.27665260859898, 50.148359298706055, 24.546712364469254, 19.78082135745457, 35.382975237710134, 47.914384910038535, 69.96816526140485, 27.129270928246633, 0.15407053620687552, 0.04018210080851402, 0.06597332882561854, 0.019377158622124364, 0.060314190707036426, 0.03125919567953263, 0.0927375183839883, 0.09597226445163999, 0.16542444910321916, 0.16681778005191258, 0.18400041732404912, 0.09025370023612465, 0.23879020661115646, 1.0039535739592143, 52.85081945146833, 74.27450588771275, 59.37704004560198, 57.653577600206646, 36.04336329868862, 31.567118372235978, 43.572271483285085, 64.9400110244751, 65.6109846660069, 62.88732555934361, 53.323168413979666, 0.7385141487632478, 0.5347275553005082, 13.995303920337133, 26.06355275426592, 7.762900062969752, 1.7232460741485869, 58.47748456682478, 51.69818278721401, 51.38696949822562, 56.04877301624843, 58.211608273642405, 55.087632179260254, 54.72564492906843, 49.42618785585676, 47.88175616945539, 42.00941317422049, 46.515764645167756, 44.761719703674316, 46.13399587358747, 45.42776707240513, 46.22129651478359, 44.941539083208355, 43.393563815525596, 45.071317536490305, 45.4022011756897, 42.57421139308384, 40.29685245241438, 38.63273804528372, 37.813225814274375, 40.083928380693706, 39.21759918757847, 37.20956284659249, 41.25400154931204, 39.17718151637486, 40.217014176504954, 38.42758205958775, 38.98768677030291, 36.1402941431318, 37.3462929725647, 38.68594735009329, 39.2569259916033, 39.39015075138637, 38.0331814629691, 39.24196304593767, 38.935922690800254, 37.9920585496085, 39.186575480869834, 36.58452722004482, 39.75800575528826, 38.3129472051348, 40.7185629435948, 41.911815302712576, 41.79782315662929, 39.308061259133474, 40.164277349199565, 38.81950214930943, 38.9860018321446, 37.75901249476841, 38.94838775907244, 37.22622115271432, 38.30745118004935, 40.37672894341605, 42.95504910605294, 46.13910627365112, 46.813213552747456, 48.9968968800136, 49.92572511945452, 51.09163284301758, 51.87837042127337, 49.05081490107945, 42.95028611591884, 48.338565485818044, 52.19694880076817, 49.39179079873221, 48.126888615744456, 48.5333582333156, 44.835686751774375, 41.68903521129063, 39.15297051838466, 40.287837164742605, 37.876846994672505, 39.91946799414498, 37.95907892499651, 37.899525914873394, 40.430289132254465, 38.85182864325387, 42.02154125486101, 43.96726962498256, 42.736205169132774, 43.59221976143973, 40.81953069141933, 37.37328324999128, 39.645212173461914, 40.16134173529488, 39.144344329833984, 38.428669452667236, 39.7408332824707, 37.47920853751046, 40.9226211139134, 39.993838037763325, 38.997382981436594, 39.48684535707746, 38.965928486415315, 39.55847781045096, 40.21050718852452, 41.016796997615266, 38.01184007099697, 39.869618143354145, 40.18762329646519, 40.97340897151402, 38.76396172387259, 42.9249529838562, 52.702332973480225, 52.51994276046753, 53.62686027799334, 55.19549254008702, 54.6269770349775, 54.35426718848092, 52.22597142628261, 49.32793337958199, 52.75467027936663, 55.875349453517366, 56.877446447099956, 57.224842480250764, 54.79874692644392, 56.787408215659006, 59.5423515864781, 56.87743255070278, 55.83499779020037, 62.842252595084055, 57.5734474999564, 63.04646709987095, 43.32497467313494, 46.40132781437465, 14.168988909040179, 0.37026746730719295, 4.760546539510999, 3.458326016153608, 0.17322522694511072, 0.16430008943591798, 46.664636748177664, 69.69106415339878, 73.89713532584054, 69.3713914326259, 74.22510419573102, 50.96177101135254, 22.478610583714076, 44.29943173272269, 56.08508777618408, 80.83336217062813, 33.76823820386614, 0.28599119239619797, 0.13841690974576132, 0.16713662365717546, 0.20336864303265298, 0.12029368723077433, 0.21055374534002372], [0.01275275185305093, 0.05323913660166519, 0.09529433332915817, 0.021631482655980756, 0.02767849344361041, 0.0094194443330967, 0.02794688118488661, 0.2844609873635428, 34.68115159443447, 51.3125056539263, 43.927334853581016, 32.9239695412772, 18.09810835974557, 33.82365008762905, 41.78780732836042, 51.989562443324495, 61.10691220419747, 52.6699925831386, 45.230865546635215, 0.3576948105224541, 0.06729395474706378, 3.6609875985554288, 6.16619838135583, 1.8340669104031153, 2.3998789148671285, 44.991927419389995, 36.40696600505284, 50.35466521126883, 47.24341821670532, 57.59115498406546, 49.01094266346523, 49.40959555762154, 42.77298198427473, 43.18572929927281, 41.706138202122276, 42.771991865975515, 40.467093740190776, 42.50671659197126, 39.25796822139195, 39.64039707183838, 38.09773370197841, 39.85199751172747, 34.55381890705654, 35.29620960780552, 33.71466064453125, 34.84278753825596, 33.489754404340474, 35.31616830825806, 33.2324070249285, 36.93829127720424, 34.005619934626985, 34.502030508858816, 33.03566878182547, 35.151961530957905, 33.95815331595284, 34.59192630222866, 35.5695343698774, 34.605909551892964, 33.44245106833321, 35.839280809674946, 34.05591099602835, 35.13910388946533, 34.001249517713276, 35.99462168557303, 34.5522312436785, 34.53625733511788, 34.014392035348074, 34.91591732842581, 34.27189574922834, 38.78725208554949, 39.76500606536865, 38.133433546338765, 36.62244006565639, 36.3876291683742, 34.940315927777974, 34.06554119927542, 34.45885092871529, 35.159812995365684, 33.49955483845302, 33.476205417088096, 34.02178839274815, 38.684071336473735, 39.63374069758824, 44.21742214475359, 44.105913979666575, 44.94989429201399, 44.561906882694785, 46.793352127075195, 43.30677734102522, 43.27643803187779, 41.992216382707866, 45.87993846620832, 44.67648615155901, 41.3305151121957, 41.26302031108311, 41.55623776572091, 34.961153575352256, 34.453358377729145, 34.41068949018206, 35.219765526907786, 34.0571026120867, 34.983123779296875, 34.16587666102818, 35.21645818437849, 35.62261165891375, 35.84583990914481, 37.01462766102382, 38.034081254686626, 38.38939823423113, 37.147946221487864, 34.53028188432966, 36.037408692496165, 35.68555538994925, 37.4562794821603, 34.37383277075631, 35.50163309914725, 35.77885580062866, 36.32894468307495, 35.84742757252285, 35.73740979603359, 36.51046984536307, 35.79775142669678, 34.96850824356079, 35.499427046094624, 35.21534994670323, 36.279150417872835, 36.18114260264805, 36.68393857138497, 36.29753882544381, 36.37938860484532, 38.00779969351632, 40.9647410937718, 44.043477467128206, 47.80863332748413, 49.87342255456107, 49.71716799054827, 50.799745968409944, 51.03656142098563, 51.98545605795724, 53.43565280096871, 54.24764708110264, 52.716420446123394, 49.149316038404194, 50.30379050118582, 48.79006290435791, 49.049748352595735, 50.515804358891074, 51.66810403551374, 54.18485968453543, 53.46323714937483, 59.893451009477886, 43.33859314237322, 49.601390157427105, 8.842233232089452, 0.3806591225521905, 3.4130422174930573, 2.2119375254426683, 0.0550150154158473, 0.04233001698074596, 38.740282263074604, 62.12907559531075, 59.137077059064595, 61.28954560416085, 65.21114362989152, 79.48706531524658, 14.00190384047372, 22.799610410417827, 44.169250283922466, 54.51398195539202, 19.190731695720128, 0.32322449875729425, 0.02224341267719865, 0.031391679641923735, 0.012074904699277664, 0.0759984055267913, 0.05410030610593302, 0.028058956510254314, 0.06441617916737284, 0.03456991392054728, 0.03873080261317747, 0.026293925774682845, 0.0447084213207875, 0.05889120099267789, 0.46744619416339056, 43.65177277156285, 61.82710688454764, 51.82920149394444, 41.89023419788906, 20.298724446977886, 31.350918224879674, 43.13985729217529, 54.511671679360525, 64.95303889683315, 56.39695072174072, 48.38381562914167, 0.3822885294045721, 0.059054924707327566, 0.926917593394007, 7.383545790399824, 1.3965799914939063, 3.163665073258536, 47.513692719595774, 39.626243591308594, 51.56863709858486, 49.07195826939174, 59.19009876251221, 51.30812134061541, 51.88989053453718, 43.885635239737375, 45.20420183454241, 42.58632557732718, 44.95258671896798, 41.13635465076992, 43.4785715511867, 41.6078976222447, 42.44071912765503, 40.14676788875035, 39.87838676997593, 38.25492974690029, 37.37847702843802, 35.370044640132356, 37.19481529508318, 35.770094122205464, 36.6235795702253, 35.7433956691197, 37.70536197934832, 37.035784925733296, 36.99423817225865, 35.23186928885323, 36.32916702542986, 35.63158525739397, 36.639650753566194, 36.60951294217791, 36.59166301999773, 35.387279646737234, 37.335432938167024, 34.465027877262656, 37.34588302884783, 35.792064326150076, 38.08007485525948, 37.137596879686626, 37.04475852421352, 35.812318325042725, 36.233351366860525, 35.729534012930735, 40.704798562186106, 39.90677016122, 40.46220220838274, 37.41842917033604, 38.5438288961138, 37.95653241021292, 36.11742067337036, 36.10319423675537, 36.64566789354597, 35.550808974674766, 33.96998609815325, 35.94432715007237, 40.70978389467512, 42.40459196908133, 45.83852025440761, 47.318521295275005, 46.90177876608712, 46.297163895198274, 49.1750556400844, 44.705293382917134, 44.90309470040457, 45.05752188818795, 45.45463228225708, 46.64302090236119, 44.905318123953684, 42.405352796827046, 41.32965006147112, 38.25405774797712, 36.33740758895874, 36.62824181147984, 35.644449847085134, 35.068781171526226, 37.0985757963998, 37.93868596213204, 37.83122859682356, 35.85261787687029, 38.03057241439819, 38.36821665082659, 39.653702872140066, 40.472968442099436, 40.1318153653826, 36.7260342325483, 36.43201078687395, 37.41004964283535, 38.94627203260149, 36.63397754941668, 37.95428466796875, 36.45460632869175, 37.42389045442854, 37.73452704293387, 37.164451667240684, 38.02237006596157, 37.76760394232613, 35.959279673440115, 36.967550141470774, 37.66949190412249, 37.912922041756765, 38.03926461083548, 38.359913553510395, 38.791664191654746, 37.73420742579869, 40.07062258039202, 42.65020384107317, 46.982040882110596, 48.33462585721697, 51.565784863063264, 51.74741077423096, 52.99420247759138, 52.75128650665283, 53.02833897726876, 54.63023921421596, 55.318263735089985, 53.3452775818961, 52.52627256938389, 50.92197172982352, 51.42850930350167, 51.020156724112375, 53.37047174998692, 53.390388761247905, 56.52098648888724, 57.36711379459926, 62.09646075112479, 47.502398422786165, 49.7368209702628, 10.10804910319192, 0.3257129580846855, 3.028801841395242, 7.27733302116394, 0.05819938704371452, 0.047578790690749884, 41.09081615720476, 66.36834526062012, 64.79753821236747, 63.513629232134136, 63.878958565848215, 64.71376378195626, 14.79236044202532, 29.291423525129044, 49.62370777130127, 64.54059382847377, 25.433561325073242, 0.28637752309441566, 0.009495534401919161, 0.03195116908422538, 0.0912749565073422, 0.07615983579307795, 0.039754552500588555, 0.1583723532302039, 0.161692330081548, 0.16117319650948048, 0.19399694805698736, 0.2415007640208517, 0.10850842962307589, 0.15288190570260796, 0.7226872923118728, 53.12295607158116, 69.7783682686942, 60.310572215488975, 47.01544782093593, 25.370320558547974, 44.339571475982666, 54.59621041161673, 60.184955733163015, 71.25729233877999, 61.280283655439106, 53.9454664502825, 0.47686811430113657, 0.37678552897913115, 4.46623170375824, 20.749283858707972, 5.011181090559278, 3.186910488775798, 55.57679230826241, 42.00600160871233, 54.653428827013286, 51.25750718797956, 62.14943381718227, 52.655401366097585, 53.3591114452907, 46.272469997406006, 47.26576362337385, 45.02171087265015, 48.661337103162495, 43.99638952527727, 46.084826946258545, 44.28691107886178, 44.81225047792707, 41.68276098796299, 42.9657667023795, 39.49727112906319, 40.36348915100098, 38.19577973229544, 39.257304668426514, 37.27541092463902, 40.54105036599295, 38.04028252192906, 40.829240798950195, 39.085176944732666, 38.01539754867554, 38.2357040813991, 37.34908962249756, 37.93285642351423, 39.33756678444998, 39.61859709875924, 38.67777974264962, 37.53025000435965, 39.45980644226074, 36.48761027199881, 38.52508265631539, 37.219359806605745, 39.33507238115583, 37.95198481423514, 39.08926943370274, 37.532449109213694, 39.56802116121565, 37.08494690486363, 42.461226735796245, 41.84296212877546, 42.289647919791086, 39.158133029937744, 40.28771557126726, 38.85960367747715, 38.44381652559553, 37.584310463496614, 38.637772015162874, 37.15145853587559, 35.976163796016145, 38.42247860772269, 43.532096999032156, 45.475893769945415, 49.605840478624614, 49.316771098545615, 48.99778972353254, 49.34057215281895, 50.663446630750386, 46.75518567221505, 44.24719864981515, 45.4762932913644, 52.36211442947388, 47.98352643421718, 46.01905182429722, 45.01468971797398, 43.885840211595806, 40.3670778955732, 37.74935449872698, 38.3797367640904, 36.03217669895717, 37.69382449558803, 38.95922000067574, 39.133949824741904, 39.298931326184956, 38.32129546574184, 38.40530613490513, 39.77822848728725, 42.21804673331124, 42.16172810963222, 40.549002579280305, 38.883196285792756, 38.833502769470215, 38.742700236184255, 41.97446026120867, 37.28603819438389, 40.22532422201974, 39.103415966033936, 40.25276960645403, 40.37409905024937, 38.79584353310721, 39.85703842980521, 40.464220660073416, 38.528296198163716, 38.67957237788609, 39.24574286597115, 41.31544099535261, 39.70267724990845, 41.67009789603097, 40.32234539304461, 39.925870759146555, 42.8500930922372, 44.42376627240862, 50.779071603502544, 51.483952454158235, 54.26069232395717, 54.08972494942801, 55.72757169178554, 54.79489067622593, 56.82748195103237, 58.061739104134695, 58.50045531136649, 56.68898350851876, 54.742806979588096, 54.31110497883388, 54.41366386413574, 53.369106428963796, 56.125307423727854, 56.328729833875386, 59.500579016549246, 58.704079219273154, 66.11012240818569, 51.11093841280256, 52.82767847606114, 12.483077134404864, 0.5926184803247452, 6.625796965190342, 7.361305475234985, 0.22524240000971726, 0.23675720712968282, 45.529137815747944, 73.49591854640416, 70.23056398119245, 73.38484464372907, 77.78470802307129, 84.28670719691685, 22.60235105242048, 39.368896211896626, 59.53419440133231, 74.89192281450543, 33.86825752258301, 0.4674806094595364, 0.11798170129103319, 0.2631242365709373, 0.13500188370900496, 0.22274701962513582, 0.14994703818644795], [0.08469947041677577, 0.08659866279257195, 0.04076753742992878, 0.046491360291838646, 0.055881738729242764, 0.0856543184657182, 0.041735701728612185, 0.4005028520311628, 34.370872838156565, 51.78575440815517, 40.613058022090364, 33.11643464224679, 19.869584594454082, 23.164151123591832, 33.335685048784526, 53.415617670331685, 57.64901958193098, 53.69495957238333, 45.14139011928013, 0.5954833094562803, 0.2082040464239461, 1.5405381981815611, 8.121644241469246, 0.7059765490038055, 8.578686322484698, 44.57698447363717, 35.56918695994786, 52.97848217827933, 49.29578406470162, 57.12338835852486, 51.02598278863089, 50.03630917412894, 40.8202463558742, 41.337963581085205, 38.889817919049946, 38.365263666425435, 36.35965919494629, 39.091857637677876, 36.84926053455898, 38.19654403414045, 34.03342662538801, 35.23445054462978, 33.03447716576712, 35.67043610981533, 34.725842407771516, 36.17771019254412, 34.41301713671003, 36.80223512649536, 34.67702783857073, 35.66397081102644, 34.666577747889924, 36.71573005403791, 35.192639759608674, 35.75680569240025, 33.891134466443745, 34.64867918831961, 32.70827661241804, 33.15881517955235, 34.2405663217817, 33.77788577760969, 32.12591334751674, 34.05353818620954, 33.10541132518223, 34.48657424109322, 33.62952436719622, 34.47653062002999, 33.22538934435163, 35.44513382230486, 34.280216217041016, 37.190205165318076, 46.56791434969221, 41.54821607044765, 36.030057498386924, 38.34718792779105, 33.92726509911673, 33.47990185873849, 33.387727056230815, 33.04960339409964, 32.49532127380371, 33.89263875143868, 33.76967300687517, 35.41531562805176, 38.607314586639404, 40.66401611055647, 40.967839990343364, 43.374914850507466, 44.55739402770996, 47.96574599402291, 41.46058191571917, 42.21758815220424, 41.202081135341096, 42.7816880771092, 41.448464257376536, 41.140082359313965, 40.11058861868722, 39.87171649932861, 34.30765812737601, 34.03971821921212, 34.238718100956504, 33.57714537211827, 34.33421066829136, 35.33666549410139, 33.94231489726475, 35.49210017068045, 35.82107652936663, 36.32927819660732, 36.62190852846418, 36.92828934533255, 38.21378598894392, 38.804167475019185, 34.1647823197501, 36.91965273448399, 35.63815825326102, 35.67280197143555, 34.947545528411865, 35.86411019733974, 34.33208104542324, 36.254883834293906, 34.62112610680716, 34.46434695380074, 34.826375893184114, 34.321717807224815, 33.91762447357178, 34.61613382611956, 34.589341572352815, 36.38976226534162, 37.896611145564485, 36.52010004861014, 36.41505023411342, 36.11417586462838, 36.24445458820888, 35.888852732522146, 37.62730939047677, 40.64072574887957, 42.85105889184134, 44.99100678307669, 45.63491719109671, 48.9999714578901, 49.33889068875994, 50.3738283429827, 50.29448338917324, 48.68628461020333, 46.1516547203064, 40.598386900765554, 40.63684170586722, 41.527013642447336, 43.528126103537424, 42.165306431906565, 49.68287863050188, 52.071644987378804, 59.02957453046526, 51.83790411267962, 60.93104634966169, 10.74984552179064, 0.21027094551495143, 1.9204362758568354, 6.288764604500361, 0.10418652117784534, 0.07367502019873687, 31.76508297239031, 65.98112215314592, 56.644834654671804, 63.77040685926165, 45.96677357809884, 50.517444133758545, 39.358526025499614, 21.014960391180857, 38.274058137621196, 51.243589946201865, 21.994630336761475, 0.1771777341408389, 0.040020460196371586, 0.018696325066100274, 0.025584349475268806, 0.045859454199671745, 0.04830033804423042, 0.0523047497762101, 0.08377985190600157, 0.011266694853215345, 0.03151704916464431, 0.08432891565774168, 0.03943215337182794, 0.032726351238254986, 0.5150929231728826, 44.74873004640852, 61.21281664712088, 46.79707983561924, 38.030537673405235, 29.71523584638323, 29.078046083450317, 37.238912037440706, 59.01196779523577, 61.58367674691336, 56.189536571502686, 48.3990078653608, 0.5737384334206581, 0.16341119499078818, 1.2620551586151123, 5.0325954386166165, 0.9215982045446123, 8.53273354257856, 47.909385681152344, 38.06170729228428, 56.64761046000889, 50.63971505846296, 58.19505419049944, 51.55260065623692, 52.13116673060826, 43.65464237758091, 43.847225597926546, 40.095615250723704, 40.65357991627285, 38.07749359948294, 42.76811129706246, 40.180963448115754, 39.67838634763445, 36.791896206992014, 37.210563387189595, 36.012805121285574, 39.4059613772801, 36.01334360667637, 38.435270241328645, 37.47181912830898, 38.9712438583374, 37.027620792388916, 38.1914301599775, 36.9931229863848, 38.438845089503694, 37.16988515853882, 38.063475608825684, 36.04071603502546, 36.62375327519008, 34.564689363752095, 35.49393449510847, 35.57308489935738, 36.18344593048096, 34.072868074689595, 35.53345932279314, 35.60542181559971, 36.10325329644339, 36.25782639639718, 35.60107224328177, 34.54009274074009, 37.29462964194161, 35.759623186928884, 40.04993084498814, 46.25961930411202, 43.949179989951, 38.657702922821045, 40.0879305430821, 37.62135478428432, 35.850331919533865, 34.87769528797695, 35.926901068006245, 34.419416427612305, 35.681323937007356, 34.82480560030256, 37.468897410801475, 40.720317363739014, 42.990874017987935, 43.580501624516074, 45.73272350856236, 45.869606494903564, 49.13723659515381, 43.97531911305019, 44.07501881463187, 44.61907318660191, 43.75257723672049, 43.874149867466514, 43.30905982426235, 40.04255185808454, 41.503678117479595, 37.101084096091135, 34.27008574349539, 36.019795009068076, 34.46149124417986, 36.98200934273856, 36.91183253696987, 35.622344153267996, 36.73496961593628, 37.325434480394634, 38.033351693834575, 38.62347262246268, 39.11407102857317, 39.048396655491416, 40.4618513243539, 37.55175467899868, 37.316200324467246, 37.04855918884277, 37.46138640812465, 36.46328115463257, 37.689881392887656, 37.18026576723371, 36.870556763240266, 35.79694890975952, 36.32407052176339, 35.6804449898856, 36.84821483067104, 35.10398421968733, 37.56677668435233, 37.35828903743199, 39.33412047794887, 39.104822976248606, 38.66220882960728, 39.19481951849801, 38.02776881626674, 39.59312500272478, 38.223926884787424, 39.898533071790425, 43.3857992036002, 44.849423340388704, 46.61986255645752, 49.170865876334055, 50.30552755083357, 50.59720597948347, 52.21276984895979, 51.539329596928184, 50.257588454655235, 47.83018316541399, 43.083931241716655, 42.70101949146816, 43.21478319168091, 45.07860272271292, 44.46514974321638, 51.02209874561855, 53.6172821862357, 61.086970874241416, 55.61733852113996, 62.241115297589985, 12.536602582250323, 0.2906749839229243, 2.3608613056795935, 8.762506995882307, 0.1357507828090872, 0.07074040374053375, 35.40002959115164, 69.23282350812639, 62.89496162959507, 67.00581468854631, 56.999168464115684, 64.05189228057861, 33.386424268995015, 24.763246025357926, 45.399446214948384, 61.642180579049246, 28.105779443468364, 0.39217041486075943, 0.013779363461903163, 0.06687927485576697, 0.04076209218640413, 0.02292248034583671, 0.022936030690159117, 0.20399440159755095, 0.20020109228789806, 0.12720251721995218, 0.12059763020702771, 0.14650852126734598, 0.09776432971869196, 0.08339571966124432, 1.1063723010676247, 54.839303561619346, 70.90574823107038, 54.996555192129954, 44.81029803412301, 29.432760306767054, 31.39866624559675, 45.669658184051514, 64.98933628627232, 68.93626744406563, 60.905073983328684, 53.172604424612864, 0.7394169260348592, 0.40382140395896776, 4.820826504911695, 15.232825858252388, 1.1153707610709327, 10.575963377952576, 52.74172925949097, 42.03973511287144, 61.10629381452288, 52.787528310503276, 60.78887231009347, 54.04696920939854, 54.18703447069441, 44.1191086087908, 44.10632044928414, 42.86274576187134, 41.31785896846226, 39.50920813424246, 44.26716777256557, 42.041816098349436, 43.82165970121111, 38.80745049885341, 39.67762204578945, 38.390978949410574, 42.14464943749564, 39.69898428235735, 39.826431615012034, 38.8625670841762, 41.42168937410627, 38.93198306219918, 40.160778931209016, 39.51983540398734, 40.932167938777376, 39.244596413203645, 40.55397054127285, 38.61893197468349, 38.858832427433555, 36.99816737856184, 37.910917486463276, 38.80962528501238, 38.92310673849923, 34.38710035596575, 37.59060205732073, 36.79454347065517, 38.37186792918614, 38.28199992861067, 36.62259987422398, 36.845379965645925, 39.78662885938372, 38.64324024745396, 41.545131070273264, 47.82798753465925, 46.23405340739659, 39.62299878256661, 40.69053738457816, 39.641269070761545, 37.130805015563965, 37.15024607522147, 37.67891713551113, 36.55857917240688, 37.16914170128958, 37.067718846457346, 40.005094119480674, 43.89649527413504, 44.616978304726736, 45.045581408909385, 46.935800620487754, 49.4789594241551, 52.953096934727256, 44.63490118299212, 44.68903807231358, 46.883279187338694, 46.655041285923545, 44.55083840233939, 44.740451267787385, 42.60851117542812, 45.2377164704459, 39.43586294991629, 36.70081227166312, 37.99938889912197, 37.49212176459176, 39.36546032769339, 38.43463448115757, 37.92023502077375, 38.301882198878694, 37.80028826849801, 41.196480887276785, 39.76497827257429, 39.81225381578718, 41.49957173211234, 42.070154326302664, 38.89614772796631, 39.51261622565133, 40.437018462589805, 39.20024258749825, 38.85799516950335, 39.26445089067732, 39.094445841653005, 39.855544567108154, 38.36794219698225, 38.245150157383506, 37.38166972569057, 39.08416598183768, 37.92812817437308, 39.416494846343994, 39.255352224622456, 42.19232102802822, 42.42334863117763, 41.587039130074636, 41.16768060411726, 41.104733398982454, 43.03402927943638, 40.176857062748496, 41.21627630506243, 45.78135395050049, 45.74294778278896, 49.886429582323345, 50.35336937223162, 52.648661613464355, 53.61641713551113, 54.48691177368164, 54.17408650262015, 53.81668158939907, 50.16728619166783, 44.98038993562971, 44.658730030059814, 47.52229806355068, 48.261982440948486, 46.43779196058001, 54.848298004695344, 57.687071391514365, 65.60903917040143, 58.821691376822336, 64.3840092250279, 14.334378617150442, 0.2830061540007591, 6.833317509719303, 12.075752019882202, 0.19731235158230576, 0.16505992652050086, 38.468249865940635, 77.28974614824567, 67.8864015851702, 74.33976336887905, 58.5720009122576, 65.26324122292655, 49.119501318250386, 36.49154642650059, 57.34024511064802, 69.68761089869908, 36.62149511064802, 0.49294440022536684, 0.11824596353939601, 0.20727169859622205, 0.10873275330024106, 0.0958881193239774, 0.08391243764864546], [0.004557102677478854, 0.03012136709211128, 0.05573129394490804, 0.054865978591676266, 0.018193674805973257, 0.022007453820801208, 0.050952819641679525, 0.4311012258487088, 39.18428257533482, 48.970000403267996, 42.27919088091169, 26.238883597510203, 11.941524982452393, 33.82289273398263, 41.4348840032305, 50.793374470302034, 58.85928807939802, 52.21357583999634, 50.70841189793178, 1.414416994367327, 0.11041039042174816, 0.27574395654456957, 1.9078046679496765, 1.104146814772061, 11.56712998662676, 44.13896656036377, 33.18503073283604, 53.424028464726035, 51.91483456747872, 55.0736836705889, 49.103207792554585, 44.5492924281529, 35.76412909371512, 39.27722862788609, 35.35505042757307, 38.19199643816267, 35.52329410825457, 36.00015939985003, 34.0073778288705, 35.64419971193586, 33.61054188864571, 36.88757984978812, 36.83158084324428, 34.90725987298148, 35.01644039154053, 35.37022876739502, 35.36006007875715, 36.919656208583284, 36.32815258843558, 36.845095089503694, 36.322833742414204, 35.55760431289673, 36.353617736271445, 36.42965882165091, 33.60474361692156, 33.35670682362148, 33.543238162994385, 33.28844077246529, 32.16346836090088, 32.434785093579976, 34.364904335566926, 34.02329615184239, 33.48307023729597, 32.700390407017295, 33.22943319593157, 32.920061179569785, 33.09554488318307, 36.7440231187003, 33.91313941138131, 37.714450223105295, 46.807509081704275, 43.964361803872244, 37.661060265132356, 37.48629222597395, 35.776482990809846, 35.44062096732003, 34.571814741407124, 33.441321986062185, 33.3081180708749, 36.246118681771414, 33.78586230959211, 35.19836507524763, 38.816754136766704, 39.82535464423043, 38.54456887926374, 40.53024591718401, 41.976093087877544, 41.878543853759766, 40.556798458099365, 39.22433546611241, 41.27014568873814, 41.1260643686567, 39.68793664659773, 40.22317028045654, 38.060539994921, 36.321631704057964, 33.51638684953962, 33.74424260003226, 34.91912392207554, 35.232053416115896, 33.71593911307198, 34.26580565316336, 35.396017006465364, 36.39680773871285, 34.644548484257285, 34.56160088947841, 36.0548278263637, 37.02840941292899, 40.425015449523926, 37.14924553462437, 34.16087048394339, 35.53891713278634, 36.10945456368582, 35.265178952898296, 34.61753388813564, 33.75123248781477, 34.93201630456107, 35.230448382241384, 34.43787431716919, 34.93316970552717, 35.536592960357666, 35.6274128641401, 35.07807786124093, 33.07729196548462, 33.14030517850603, 34.74110412597656, 35.73034347806658, 36.474742208208355, 36.413104738507954, 35.409343651362825, 34.848724773951936, 36.87373903819493, 37.01940107345581, 35.21535342080252, 36.02767079217093, 39.585888453892295, 41.02662175042288, 42.235382488795686, 43.93848671231951, 42.903354508536204, 43.6508903503418, 40.90454190117972, 39.8759549004691, 38.81634766714913, 42.40417160306658, 44.40242140633719, 49.9150561605181, 50.25035537992205, 51.26928091049194, 52.3804680960519, 60.553363118852886, 54.42711557660784, 68.4814453125, 11.313488602638245, 0.29084730467626024, 2.5154867342540195, 11.96643601145063, 0.7135868892073631, 0.055794828571379185, 33.71400056566511, 61.28862844194685, 56.90271009717669, 59.02136870792934, 40.63658462251936, 17.06158651624407, 24.086078064782278, 29.71332856587001, 39.20328937258039, 63.362526757376536, 25.148497581481934, 0.1467958672770432, 0.027564309570672255, 0.05735644977539778, 0.02705592568963766, 0.031742855440825224, 0.02789789265287774, 0.08043280829276357, 0.03941675401957972, 0.02695959068036505, 0.06322535020964486, 0.026614662492647767, 0.04835888543831451, 0.029212703529213156, 0.6276661711079734, 45.39638205936977, 58.56614358084542, 47.11664138521467, 35.52406535829817, 15.693315982818604, 18.61187379700797, 42.74302135195051, 54.9975974219186, 62.96690327780587, 55.37751449857439, 54.577717781066895, 1.2381043923752648, 0.11682182710085597, 1.2620532044342585, 3.252712969269071, 1.0191542782953806, 13.165254746164594, 45.478106771196636, 36.27589866093227, 58.00684486116682, 54.6826251574925, 56.37893056869507, 51.17958314078194, 45.84074715205601, 37.20174264907837, 41.62106793267386, 37.35599613189697, 38.357829093933105, 36.141725472041536, 38.112543787275044, 36.64505992616926, 37.37270654950823, 35.6818311555045, 39.80406188964844, 37.518583978925435, 35.65940931865147, 37.20169401168823, 38.130904402051655, 37.054607595716206, 38.640370641435894, 37.837391648973735, 38.033445494515554, 36.164466926029746, 38.98035294669015, 37.13624198096139, 37.07399654388428, 34.97268411091396, 36.478431701660156, 34.48601838520595, 35.98592948913574, 35.48908812659127, 34.20526252474104, 34.71200507027762, 36.092608656202046, 33.58774484906878, 33.77146564211164, 34.38774306433541, 34.0603335244315, 35.37268148149763, 37.71662153516497, 36.6305764062064, 39.097284180777415, 48.25293241228376, 45.05736902781895, 40.243306159973145, 38.19828803198678, 37.93532998221261, 36.77158314841134, 35.183808599199565, 35.71829530170986, 35.7346305165972, 37.29270846503121, 33.86884464536394, 37.40817362921578, 41.065048762730186, 41.60090773446219, 42.26257773808071, 42.83520310265677, 43.78131151199341, 44.95929520470755, 42.41674089431763, 43.657706533159526, 41.8996524810791, 43.55334806442261, 41.73159987585885, 42.170434202466694, 41.509365218026296, 38.05624600819179, 33.97705589021955, 35.42877776282174, 35.708397592817036, 37.321630341666086, 34.81594317299979, 36.11288002559117, 36.492974281311035, 36.71852322987148, 36.277600969587056, 34.881575856889995, 36.88983106613159, 39.02688503265381, 40.72922148023333, 40.17627688816616, 36.236405100141255, 36.873360361371724, 38.320784773145405, 37.751647404261995, 36.28406279427664, 37.09722784587315, 35.36945751735142, 38.477459703172954, 36.791434151785715, 36.50025599343436, 36.49974182673863, 36.901434557778494, 36.24529879433768, 36.46423305783953, 36.29870612280709, 37.08283117839268, 37.99544927052089, 39.417516231536865, 38.47008419036865, 37.081146240234375, 36.72060768944876, 37.44726072038923, 38.123931884765625, 38.12850032533918, 37.96952206747872, 41.25231313705444, 42.203122002737864, 44.329649448394775, 45.70891898018973, 45.44083315985543, 46.15147059304373, 43.929582595825195, 41.456822940281455, 42.237689290727886, 44.36096497944423, 46.366677148001536, 51.195348603384836, 52.88050215584891, 53.261461462293354, 55.261760984148296, 60.783119201660156, 56.07847656522478, 69.97682271684918, 12.751132556370326, 0.6337259773697171, 2.980686217546463, 5.412890757833209, 0.5739142011318887, 0.012931079337639468, 36.902275289808, 68.25242573874337, 60.624755859375, 63.94904504503523, 47.0580507005964, 28.073590176446096, 30.936996664319718, 36.97173295702253, 47.14432300840105, 72.39032118661063, 31.146728038787842, 0.28342635716710773, 0.04729105452341693, 0.09269507601857185, 0.01928950546841536, 0.041573324905974526, 0.01597977619219039, 0.19165927278144018, 0.24144363137228148, 0.1483691864247833, 0.169385967243995, 0.10554418832595859, 0.17498549606118882, 0.1110409733706287, 0.8607847477708543, 56.59996318817139, 65.44922365461076, 57.04908779689244, 38.04021651404244, 16.960016012191772, 44.345873492104666, 54.02488783427647, 60.95576804024832, 70.47694710322789, 60.72981262207031, 61.31560829707554, 1.6308775906051909, 0.3132919403059142, 2.1748502126761844, 9.56969051701682, 1.7374782647405351, 14.790482691356114, 50.261277948107036, 40.11911058425903, 60.738115719386506, 57.81589099339077, 58.60449068886893, 54.12442772729056, 47.98921700886318, 39.58511372974941, 43.10573468889509, 39.217626980372835, 41.363095215388704, 39.30422932761056, 40.641761030469624, 38.72298124858311, 39.171233858381, 37.263446126665386, 41.66098533357893, 40.391452176230295, 37.61938844408308, 38.85817929676601, 39.558783531188965, 39.80468027932303, 40.64078133446829, 40.15259395326887, 40.96157966341291, 38.87602227074759, 41.26974269321987, 40.02486869267055, 39.92792395183018, 38.145189898354666, 38.425108500889365, 37.75488873890468, 37.53437723432268, 36.66898257391793, 35.69490419115339, 36.44862045560564, 38.65759869984218, 36.65531546728951, 35.33156204223633, 35.91201107842581, 35.54661921092442, 36.668430192129954, 39.82771703175136, 38.57337263652256, 39.962265423366, 50.028502873011995, 47.51423120498657, 41.66510908944266, 40.824300629752024, 39.33289412089756, 38.823837825230186, 37.31255252020699, 37.842863355364116, 37.094427721840994, 40.05271012442452, 36.81989049911499, 39.92843117032732, 43.727532454899375, 43.562262603214805, 43.296938691820415, 45.01248366492135, 46.092535972595215, 48.24654701777867, 44.519453389304026, 42.816832065582275, 44.78389140537807, 44.64388172967093, 44.1880555834089, 44.835429668426514, 43.22726215635027, 40.695296900612966, 37.39266177586147, 36.77802760260445, 39.3388626234872, 39.44741085597447, 37.03843566349575, 38.018986293247764, 37.877746786390034, 37.38919462476458, 37.059509549822124, 37.103825160435264, 38.78483411243984, 39.444054876055034, 42.33753490447998, 40.750708784375874, 37.89847673688616, 37.87290736607143, 41.46221474238804, 40.62034668241228, 39.483784675598145, 38.46963603155953, 37.10239383152553, 39.434657437460764, 39.63544648034232, 38.75277859824044, 39.16297245025635, 40.2989890234811, 38.9737035206386, 38.00067431586129, 37.82884536470686, 39.13662140710013, 41.003564153398784, 41.15229034423828, 41.736932618277415, 37.79772785731724, 38.466040338788716, 41.43612773077828, 41.82049512863159, 38.950451374053955, 40.89721849986485, 44.24300193786621, 44.04043068204607, 46.69139426095145, 48.980064868927, 47.05177647726876, 48.601867471422466, 45.83900662830898, 44.16867010934012, 43.66935518809727, 47.532001222882954, 48.23367895398821, 53.73239646639143, 55.39920677457537, 55.74617549351284, 58.20288481031145, 65.8975909096854, 59.121547835213796, 71.83274909428188, 13.838853069714137, 0.5754499701516969, 5.936232549803598, 24.493449211120605, 1.5202705200229372, 0.10192205983081035, 40.186959743499756, 73.24774278913225, 67.5216975893293, 71.32572514670235, 54.770703996930806, 27.271721158708843, 36.804201466696604, 45.91293546131679, 57.38436617170061, 81.78050586155483, 40.696419034685405, 0.36022699464644703, 0.09731907503945486, 0.14706795981952123, 0.045102392323315144, 0.17280425024884088, 0.10330779797264508], [0.07180028222501278, 0.01312434731516987, 0.021766254977722253, 0.037872737406619957, 0.03416442817875317, 0.06627811997064523, 0.07599974224077803, 1.1613961713654655, 48.98653016771589, 47.362298420497346, 41.455801555088584, 13.899937289101736, 47.875103269304546, 80.96891457693917, 45.53743396486555, 50.921144894191194, 56.19387224742344, 52.699855940682546, 55.7770220211574, 3.6982798831803456, 0.28108646986739977, 0.6725680902600288, 1.8705727458000183, 0.47876996653420584, 11.898069211414882, 51.42822790145874, 38.27383232116699, 56.05319207055228, 49.490291936056956, 54.55490684509277, 42.42380721228463, 42.34298229217529, 42.60585348946707, 48.04179055350167, 42.439607415880474, 42.472788538251606, 35.42717967714582, 37.168533733912874, 34.52078717095511, 36.46108552387783, 35.62690217154366, 35.3911463192531, 33.495816707611084, 37.0040351322719, 33.83964484078543, 34.402976989746094, 36.42866175515311, 36.72416516712734, 35.34839752742222, 38.38231801986694, 35.317081996372764, 36.41015175410679, 33.32286214828491, 32.98338706152779, 31.57106842313494, 35.14826856340681, 34.00274338041033, 33.29873105457851, 33.307239123753135, 33.78198868887765, 31.845695972442627, 33.481916836329866, 34.14277390071324, 33.90781014306204, 31.358877386365617, 33.97525978088379, 32.96167046683175, 34.437836102076936, 34.06564194815499, 35.230594294411794, 44.11119113649641, 45.615684577396934, 38.72792836597988, 37.60713529586792, 35.69716930389404, 35.24072476795742, 34.288654804229736, 33.586139815194265, 32.60763890402657, 33.92156410217285, 34.21124839782715, 36.403217451913015, 37.244647775377544, 39.78390169143677, 38.6373690196446, 41.5045223236084, 40.2934513092041, 39.44588572638375, 42.011671338762554, 38.897165639059885, 38.87288515908377, 40.52515288761684, 39.814477239336284, 36.99982452392578, 36.81383861814226, 35.176613739558626, 34.744091851370676, 34.25418479101998, 33.676963193076, 34.67038188661848, 35.18306514195034, 36.226017543247764, 34.50595971516201, 34.63914278575352, 34.182698249816895, 34.50821787970406, 34.78068453924996, 40.102150031498496, 39.609376839229036, 38.59733002526419, 34.430967807769775, 34.352178709847585, 34.34275000435965, 35.82681226730347, 35.03503029687064, 35.56607416697911, 33.6409124646868, 35.38030365535191, 34.06599283218384, 36.3649537222726, 34.03708832604544, 35.01076718739101, 33.025177001953125, 35.2544196673802, 33.24810995374407, 35.65375001089913, 35.54307910374233, 35.9396892275129, 36.69963107790266, 37.234315804072786, 36.68287549700056, 38.00956106185913, 35.84803901399885, 37.68593481608799, 36.91707842690604, 37.449199267796104, 35.21226494652884, 38.78329856055123, 38.1454713003976, 38.73608207702637, 38.468406200408936, 38.17138808114188, 37.807507446834016, 41.13587522506714, 48.480930600847515, 52.9888072013855, 53.72690044130598, 54.39560202189854, 55.820166860307964, 53.39512743268694, 58.087079184395925, 56.72559356689453, 63.75449548448835, 13.349304710115705, 0.44568340480327606, 0.6961716094187328, 4.975818668093, 0.31979070444192204, 0.05146657243104918, 33.06068229675293, 61.26113442012242, 56.21566527230399, 58.176707472120015, 52.05936057226998, 45.091231073652, 13.844092011451721, 26.127602985927037, 43.77902208055769, 59.701159613473074, 19.374021700450353, 0.13155411157224858, 0.07359575373785836, 0.05253021678488169, 0.07097951948110547, 0.038339620389576466, 0.06362002010324172, 0.021926092383052622, 0.056789045222103596, 0.002566860444078754, 0.058411205320486, 0.04213968790801508, 0.055537562019058635, 0.06626817264727183, 1.3972301908901759, 58.02124152864729, 56.661503383091514, 47.16869381495884, 23.433600527899607, 31.785284859793528, 62.92373411996024, 49.046944754464285, 54.03038733346121, 61.11361721583775, 55.00845398221697, 60.45312145778111, 3.9491623980658392, 0.2624345192951815, 0.5325479922550065, 1.7374594828912189, 0.8740988533411707, 14.309577022280012, 50.448559692927766, 40.90119286945888, 60.32029969351632, 50.84607308251517, 56.684394223349436, 44.13804244995117, 43.62374373844692, 44.98167187826974, 49.00160081045968, 45.09396866389683, 44.345536504473, 37.8135211127145, 37.94766303471157, 35.85337175641741, 37.773857321058, 37.477492332458496, 36.324539525168284, 35.75929662159511, 36.35190153121948, 35.66790696552822, 37.285089765276226, 39.08522210802351, 38.40865864072527, 37.43914175033569, 40.29620974404471, 36.229029587336946, 38.840312004089355, 36.56395707811628, 35.34154312951224, 34.704824107033865, 36.95296934672764, 35.56172112056187, 35.919112137385774, 34.26292562484741, 35.8318636076791, 34.512859276362825, 35.14137942450387, 35.725229603903635, 34.63288940702166, 34.16519921166556, 35.09874875204903, 33.94799852371216, 37.3628956930978, 36.079049246651785, 36.3804794720241, 46.92688260759626, 44.950158323560444, 38.5477476801191, 39.7799516405378, 36.544262409210205, 35.68286643709455, 34.9743412562779, 36.16813904898507, 33.95943178449358, 34.74659667696272, 36.09975140435355, 37.344969340733115, 39.04229613712856, 39.65996667316982, 41.088641371045796, 42.32971470696585, 43.51859664916992, 42.059454100472585, 42.77224547522408, 42.214451040540425, 40.81997537612915, 42.65636689322335, 40.03437382834298, 40.077480452401296, 39.581549303872244, 35.85626915522984, 37.27833959034511, 35.47666474751064, 35.24551207678658, 37.161571638924734, 38.14106961659023, 36.95711742128645, 35.028443404606406, 37.17532559803554, 35.07283544540405, 35.818012373788015, 37.05951649802071, 40.53372001647949, 42.02748196465628, 40.169696944100515, 36.87666770390102, 36.63902888979231, 36.008254051208496, 36.155444690159385, 35.99957922526768, 37.214978967394146, 35.09366961887905, 37.1714380809239, 36.819807120731895, 37.21800838197981, 35.31644623620169, 36.60965538024902, 35.30758728299822, 36.945923873356406, 35.43529517310006, 36.85611840656826, 37.679462569100515, 39.487488065447124, 38.483678340911865, 39.76323080062866, 38.44472326551165, 40.317568506513325, 37.80838639395577, 38.614116873059956, 38.943395478384836, 39.13350861413138, 38.07237972532, 40.34931135177612, 39.060153007507324, 39.72979954310826, 41.09636081968035, 40.10884462084089, 40.424344948359895, 42.07896811621529, 51.80021708352225, 55.354432582855225, 55.590643542153494, 55.91247020448957, 58.53092316218785, 56.5306271144322, 61.055842944553916, 58.97644165584019, 66.3677477155413, 14.301944426127843, 0.5745592436620167, 3.135311863252095, 7.148142993450165, 0.36659675570470945, 0.12580295731978758, 35.768360546657014, 67.83372729165214, 63.55982085636684, 64.29408563886369, 54.725099495479036, 41.153117179870605, 17.926713671003068, 35.5790672983442, 50.253714833940776, 66.8648704801287, 25.305870805467876, 0.09113732924950974, 0.0948652345687151, 0.026279433963022063, 0.03249468241951295, 0.014302532620994108, 0.031854111435157914, 0.12521155976823398, 0.11502221652439662, 0.13658937066793442, 0.1070932023493307, 0.1165646623287882, 0.12286327220499516, 0.16989265648382051, 1.848444904599871, 69.3800766808646, 63.06624862125942, 55.631769929613384, 25.57390104021345, 61.273043632507324, 85.1782375063215, 55.9537216595241, 61.353649684361045, 64.99909850529262, 61.72111906324114, 65.48873111179897, 4.91387243781771, 0.36032288521528244, 2.9262557668345313, 6.123510820525033, 1.0048024484089442, 16.477447986602783, 56.9997729573931, 44.00565147399902, 62.09303528921944, 54.62346819468907, 59.88631520952497, 45.54939876283918, 46.02989796229771, 46.638226645333425, 53.41238328388759, 46.89744656426566, 47.528065068381174, 39.75603594098772, 40.81714398520333, 37.17149019241333, 39.35164383479527, 39.431905950818745, 38.018840381077354, 37.704357964651926, 39.47563443865095, 38.17403187070574, 39.35799101420811, 40.486764090401785, 39.5130226952689, 41.176087924412315, 42.80649314607893, 39.08709464754377, 40.332086767469136, 37.67065225328718, 37.27282272066389, 35.738212312970845, 39.44511447634016, 38.55304568154471, 37.87588119506836, 36.14376824242728, 38.77082306998116, 34.809929507119314, 36.56389454432896, 37.95884963444301, 37.347078119005474, 35.86681304659162, 37.05944354193551, 35.86884886877877, 39.13400888442993, 38.072636808667866, 39.63632195336478, 49.41557795660836, 47.7035869870867, 40.81520196369716, 42.54389292853219, 36.71195718220302, 37.16646664483206, 37.414121287209646, 38.17539719172886, 36.5451865196228, 37.19859511511666, 38.65077556882586, 40.809455803462434, 41.03088447025844, 44.302662645067485, 43.55727727072579, 45.70101193019322, 44.44282170704433, 44.64473635809762, 41.82765177318028, 43.86514152799334, 43.52703176225935, 43.180584158216206, 42.801351479121614, 41.16576637540545, 42.650353227342876, 38.47245005198887, 39.70238195146833, 37.684788363320486, 38.10385853903634, 39.2424772126334, 39.77331263678414, 40.15026978084019, 37.38143001283918, 37.837794644492014, 37.59278726577759, 36.51676491328648, 37.707203251974924, 44.10296099526541, 43.489709513528005, 42.66226938792637, 38.93376180103847, 39.36931310381208, 37.26091003417969, 39.2482442174639, 38.916057791028706, 39.577981403895784, 37.27709238869803, 39.42853954860142, 37.99773175375802, 39.39050510951451, 37.61370134353638, 38.075002670288086, 36.958976064409526, 39.61031484603882, 37.55607993262154, 39.87669488361904, 40.09134905678885, 41.95143740517752, 41.842236042022705, 42.720137459891184, 41.4630902154105, 43.92963123321533, 40.0964594568525, 40.83960403714861, 39.921719210488455, 40.80726364680699, 39.90952859606062, 42.384032249450684, 42.05386774880545, 42.83030809674944, 42.879216466631206, 41.934907640729634, 41.79817751475743, 45.54501097542899, 53.793283530644004, 58.25545488085066, 57.58250100272042, 58.32964774540493, 61.05404336111886, 59.33863040379116, 61.9423497063773, 62.9821754183088, 66.22262069157192, 18.286772796085902, 0.6195391129170145, 5.8854798674583435, 15.460525274276733, 0.6958740853837558, 0.173144169151783, 38.8546530859811, 72.28955146244594, 67.67704541342599, 71.42988559177944, 64.18569374084473, 57.808616229466026, 24.604116644178117, 45.213620117732454, 58.85412556784493, 77.10727255684989, 33.668257100241526, 0.27813226410320824, 0.1850527437137706, 0.11654304420309407, 0.13126726767846517, 0.21935965067573956, 0.09299615557704653], [0.0576811016404203, 0.0527967419475317, 0.06612995506397315, 0.06402027434004204, 0.013657994751286293, 0.02355285294886146, 0.06910472043922969, 1.5750190679516112, 47.63815927505493, 51.302757331303184, 38.57220186505999, 23.127455949783325, 67.36562715257917, 87.68017264774868, 56.867225646972656, 41.61721168245588, 61.47711917332241, 47.909812995365684, 55.63897173745291, 3.3553061613014767, 0.05503892359722938, 0.5556788710611207, 0.46485842445066994, 0.9956635045153754, 12.47774612903595, 60.684107371738975, 42.45043618338448, 57.29215662819998, 48.089663641793386, 48.4256785256522, 44.08719900676182, 49.193082741328645, 48.022964409419465, 51.858585425785606, 50.4094934463501, 47.53247022628784, 39.045179639543804, 37.54438264029366, 34.51993254252842, 35.87650578362601, 34.66020277568272, 36.760243688310894, 36.26944725854056, 37.34802654811314, 37.5252229826791, 39.985149315425325, 39.75254099709647, 39.475773402622764, 38.13898515701294, 36.86640521458217, 35.68873071670532, 36.161458356039866, 34.13046864100865, 33.776979037693565, 31.327579225812638, 34.38477618353707, 33.7186211177281, 34.86805813653128, 33.89622402191162, 34.88139172962734, 34.17461749485561, 33.50654125213623, 31.768383366721018, 33.765695163181846, 33.38202953338623, 34.413395813533235, 31.74867480141776, 34.183865547180176, 34.605781010219026, 34.6379303250994, 42.54687717982701, 49.042407580784385, 38.977427755083355, 36.40703548703875, 36.509788921901155, 35.66368246078491, 34.85826812471662, 34.11246933255877, 33.24643196378435, 33.78207206726074, 32.355832712990896, 34.19827263695853, 34.750015190669465, 37.077234404427664, 38.20928703035627, 39.618902819497244, 40.67374011448452, 46.10237462180001, 40.69352510997227, 38.41946308953421, 40.09120314461844, 38.73465074811663, 38.93935162680489, 37.55999871662685, 37.267656735011506, 34.248650550842285, 33.60127993992397, 34.63171516145979, 32.778099060058594, 33.50140305927822, 33.33233949116298, 34.92008972167969, 34.434612137930735, 35.77834163393293, 33.56106724057879, 34.92585672651018, 34.232054778507774, 38.24826989855085, 41.01329163142613, 35.53774288722447, 33.78096035548619, 34.71588911328997, 33.95231335503714, 32.625117097582134, 35.12204606192452, 33.66623517445156, 34.580819606781006, 36.75083582741873, 34.172220366341726, 35.00338820048741, 34.12795339311872, 34.47309473582676, 35.180782658713206, 35.42444903509957, 35.18424980981009, 35.243285179138184, 34.645552498953684, 35.58320147650582, 35.56099850790841, 37.16980872835432, 37.89730943952288, 38.061290400368826, 36.62587594985962, 35.377538272312705, 37.1461501121521, 36.36775732040405, 38.67012977600098, 37.562711988176616, 38.42985759462629, 39.03748450960432, 39.196893555777415, 38.98740536825997, 41.522063050951274, 49.109416007995605, 55.34040069580078, 53.82773617335728, 54.68564762387957, 55.40961170196533, 55.62355021068028, 57.96369654791695, 60.70612621307373, 58.76264558519636, 64.02637154715401, 12.358000874519348, 0.7562197872570583, 0.7913510735545839, 2.6192637256213596, 0.21884928377611296, 0.06639949631478105, 30.53718342099871, 63.78424767085484, 58.13985422679356, 63.4624696459089, 49.06597587040493, 39.109478269304546, 18.777770723615372, 30.070229734693253, 45.72066143580845, 61.78539684840611, 21.87654570170811, 0.03985822925876294, 0.02613532499942396, 0.05343685492074915, 0.053514974657446146, 0.06832593187157597, 0.009366778989455529, 0.06430591722684247, 0.058405695616134574, 0.020229088175775747, 0.017565671986501132, 0.030571843098316873, 0.015921637615455047, 0.030042918265930245, 1.5267973755087172, 58.587217467171804, 58.34879003252302, 47.015399183545796, 26.51012216295515, 68.59125464303153, 88.66704613821847, 60.03866836002895, 48.00565297263009, 65.57442324502128, 53.57747943060738, 61.23306369781494, 3.7622680153165544, 0.22350995082940373, 0.4878440967627934, 1.1265935131481715, 0.8211472832730838, 12.689388258116585, 60.370618547712056, 45.09788744790213, 60.25332600729806, 51.61795541218349, 50.159601484026226, 45.64849744524275, 50.8180718421936, 48.20969377245222, 54.55431277411324, 52.954312869480674, 50.67580400194441, 41.1011620249067, 39.296478612082346, 35.390746797834126, 37.287559849875315, 35.56778342383248, 38.08343430927822, 37.97165516444615, 39.3544648034232, 40.53259093420846, 40.70462485722133, 40.210541929517476, 41.6672282900129, 38.355306897844585, 41.19926711491176, 38.07170575005667, 38.614071709769114, 35.86887318747384, 35.69774947847639, 34.14197833197457, 35.37278570447649, 35.68430471420288, 36.652473654065815, 35.15428570338658, 36.58871350969587, 36.05639811924526, 34.86544908796038, 32.5827956199646, 35.194373335157124, 34.42321014404297, 35.56027242115566, 33.80145059313093, 36.69801214763096, 36.52394240243094, 36.166200501578196, 43.71065180642264, 50.39544766289847, 39.72541175569807, 36.84684256144932, 36.66165917260306, 36.51702894483294, 35.96769741603306, 34.86276708330427, 34.553857122148784, 35.125659125191824, 34.64124461582729, 35.136216912950786, 35.88976642063686, 40.39908824648176, 41.89820378167288, 40.5678391456604, 39.87736538478306, 46.61047554016113, 43.608801637377056, 40.42516483579363, 41.9011150768825, 39.73168250492641, 39.46885994502476, 38.309730189187185, 38.65694209507534, 36.208792958940776, 34.54715558460781, 36.708184310368125, 34.297760418483186, 35.55420664378575, 35.4328077180045, 36.0526773588998, 36.025238922664094, 36.33112989153181, 34.32395165307181, 35.796882901872905, 34.03251641137259, 40.61519806725638, 43.5237626348223, 37.383910519736155, 35.58683885846819, 36.37160314832415, 35.31035961423601, 34.168833119528635, 36.45347029822213, 35.93522153581892, 35.69717277799334, 37.24679824284145, 36.581685406821116, 36.3097676549639, 36.75400768007551, 37.472896099090576, 36.212524141584126, 36.96872091293335, 36.939003467559814, 36.04136569159371, 37.65463318143572, 37.986385345458984, 37.99119349888393, 39.62620537621634, 39.62896728515625, 40.21102482931954, 37.88080399377005, 38.35699183600289, 38.57160084588187, 37.81438268933977, 40.46640934262957, 39.04180976322719, 39.930473940713064, 40.03377628326416, 40.2377267565046, 40.25816835675921, 43.088020256587434, 50.79621628352574, 57.142273562295095, 56.48437295641218, 58.060776778629844, 55.684364318847656, 58.88144588470459, 56.89731134687151, 62.67250810350691, 60.51880972726004, 68.59390885489327, 14.087018404688154, 0.6472282271300043, 2.3001911555017744, 2.0487883942467824, 0.031171230399715047, 0.0780760593978422, 35.16022293908255, 68.1072917665754, 63.01176084790911, 69.00197655814034, 52.619308948516846, 44.646355288369314, 21.803917918886455, 37.11532095500401, 52.58876119341169, 70.41879762922014, 27.732129641941615, 0.08732069869126592, 0.02570175638954554, 0.010394646736261035, 0.016426471062004566, 0.030970842045332705, 0.014659070542880466, 0.15385510133845465, 0.13966882042586803, 0.13083236744361265, 0.12524531010006154, 0.1330766220177923, 0.1420715536390032, 0.27155185863375664, 2.0496512736592973, 66.59824030739921, 66.99143191746303, 54.375917775290354, 35.500868797302246, 73.24959795815604, 91.0115350995745, 66.8743200302124, 51.24562576838902, 73.1327292578561, 57.35293599537441, 63.98309121813093, 4.529320912701743, 0.3600415103137493, 1.8817943036556244, 5.387581075940814, 1.6329578161239624, 14.936789172036306, 65.10368279048375, 49.022473199026926, 63.75380761282784, 52.62961312702724, 51.714584009987966, 48.81713656016758, 53.43668808255877, 50.5111768586295, 57.02662079674857, 55.02992044176374, 52.47120462145124, 44.26534039633614, 41.11010435649327, 37.04589455468314, 39.190598487854004, 37.511218888419016, 40.484200205121724, 40.91044092178345, 42.28892878123692, 42.47239943913051, 43.91998365947178, 44.24606956754412, 44.2569956098284, 42.44569056374686, 43.24263851983206, 39.03397914341518, 40.91082654680525, 38.065355096544536, 37.57520137514387, 34.93447249276297, 38.919229643685476, 37.51151418685913, 38.51388563428606, 37.45709589549473, 38.28309774398804, 38.64031158174787, 37.51089927128383, 34.580218587602886, 36.734955719539094, 36.79876102719988, 38.6051675932748, 35.169297286442344, 39.05910382952009, 37.930518354688374, 38.34802518572126, 46.38018792016165, 51.83227259772164, 42.704062802451, 36.84650904791695, 38.31749480111258, 37.38711363928658, 37.96489804131644, 36.58967236110142, 36.6117467880249, 38.01264953613281, 37.38747841971261, 38.35971205575125, 38.26625878470284, 42.21981157575335, 43.60059928894043, 43.36736215863909, 43.633422579084126, 45.86970376968384, 44.741927759987966, 42.86051539012364, 44.05374690464565, 41.93753753389631, 42.03195660454886, 40.73747246606009, 41.085834298815044, 39.26910965783255, 36.24396474020821, 38.946146965026855, 36.13183123724801, 38.129737104688374, 37.104033606392996, 37.49606834139143, 38.664751870291575, 38.10178450175694, 35.32237304959978, 37.29166970934187, 35.81536511012486, 41.3780129977635, 45.119207995278494, 40.077060086386545, 37.66927303586687, 38.033136299678254, 37.511576720646445, 36.341072763715474, 38.73842361995152, 39.140185832977295, 37.348693575177876, 38.45241492135184, 39.56286212376186, 39.42090000425066, 36.68357726505825, 39.52038778577532, 40.19510998044695, 40.16418007441929, 39.10624735695975, 39.11322682244437, 39.13668046678816, 40.77902964183262, 39.830051626477925, 42.1323059626988, 42.65453256879534, 42.60479736328125, 40.92716523579189, 40.44523818152291, 40.67663403919765, 40.63123798370361, 43.6316681589399, 40.758247579847065, 41.10422618048531, 43.35943078994751, 44.346078463963096, 42.5221381187439, 45.935471943446565, 54.664643219539094, 60.93654932294573, 58.97879014696394, 60.210073471069336, 58.844078472682405, 60.98825086866106, 61.92644527980259, 64.22914777483258, 63.26844120025635, 69.17866230010986, 17.244833094733103, 0.9396715547357286, 7.587579642023359, 5.770755989210946, 0.19573531406266348, 0.2449433792914663, 38.37792328425816, 75.88741901942662, 68.04568208966936, 74.4366421018328, 61.83500003814697, 51.95113543101719, 31.725245475769043, 47.242494106292725, 60.932095527648926, 79.88976900918144, 35.46713529314314, 0.12597837219280855, 0.1163439213165215, 0.15284648617463453, 0.09776040100093399, 0.16331938920276506, 0.08426949634615864], [0.07395744004419871, 0.08122904878109694, 0.032294582442513535, 0.06184732022562197, 0.017081472789868712, 0.024907812742250304, 0.12112809531390667, 0.5693105310201645, 42.50218984058925, 55.55252225058419, 41.1000086239406, 34.54786082676479, 44.294140679495676, 71.2819514955793, 41.13185221808297, 48.06580352783203, 59.20742756979806, 47.28043474469866, 58.06452185767037, 5.449899469103132, 0.2087480958018984, 0.4200192562171391, 0.5176562656249318, 0.3794264415545123, 8.505567823137556, 64.25484221322196, 49.294255461011616, 56.91171843664986, 50.6947934286935, 52.00484848022461, 49.281905038016184, 54.23810025623867, 50.5773480279105, 53.649657317570274, 48.605966908591135, 51.58891541617257, 40.124564920152935, 39.003566878182546, 34.90955972671509, 37.35434593473162, 35.047540528433665, 38.211896078927175, 36.59135035106114, 39.91614328111921, 38.69433035169329, 39.251843384334016, 38.52293218885149, 38.74066093989781, 36.84234012876238, 37.82086535862514, 34.48396519252232, 33.80956956318447, 32.81207227706909, 32.742058753967285, 33.453995500292095, 32.41310671397618, 32.63970136642456, 33.16927221843174, 34.313341753823416, 33.65550715582711, 31.881149155753, 33.81205701828003, 33.60127993992397, 34.79665844781058, 32.63731118610927, 33.34348440170288, 33.578291824885774, 34.89699043546404, 32.64575324739729, 33.4380007471357, 39.22774008342198, 49.36535290309361, 39.04965427943638, 35.03296668188912, 35.85254144668579, 33.345864159720286, 35.56563990456717, 35.03103160858154, 34.41049146652222, 31.412427152906144, 31.981960569109233, 34.32025521142142, 35.12359203611101, 35.03299100058419, 36.77897603171212, 40.35621091297695, 44.59615107945034, 39.79706852776663, 35.73195546013968, 38.93031896863665, 39.4588406426566, 39.71859209878104, 36.435915674482075, 36.09903573989868, 35.196138177599224, 33.64547743116106, 33.669810022626606, 34.25151668276106, 33.897624083927695, 34.601740632738384, 34.46400301797049, 35.79470811571394, 34.638409750802175, 33.93038484028408, 33.61053146634783, 36.33201231275286, 34.77257946559361, 42.67490121296474, 40.356085845402305, 33.56201566968645, 34.96010439736502, 33.866857460566926, 32.522843088422505, 33.459012099674766, 32.992325919015066, 34.90943465914045, 35.49641152790615, 34.327154772622244, 33.69270086288452, 33.808503014700754, 34.983287061963765, 34.631214891161235, 33.323556968144004, 35.47222832271031, 34.44415896279471, 35.397861753191265, 34.300084590911865, 36.532558168683735, 37.74977486474173, 37.25857196535383, 37.84452050072806, 38.2870443207877, 37.433774266924175, 36.40858146122524, 37.24816008976528, 39.06978668485369, 36.67913041796003, 37.693251269204275, 41.08234282902309, 40.39378329685756, 40.629497459956575, 37.83366741452898, 43.68661798749651, 49.84160327911377, 54.33605248587472, 54.27149677276611, 53.930899551936555, 50.52660533360073, 58.5629335130964, 54.61894839150565, 62.53982530321394, 51.599511419023784, 53.42769363948277, 12.878471323422023, 0.601536818913051, 2.6843850655215125, 5.003223231860569, 0.851141516651426, 0.14949750873659337, 30.19729839052473, 62.43840939658028, 58.3440374646868, 63.81672355106899, 55.091002055576865, 33.995055198669434, 20.18629911967686, 26.955145597457886, 40.07251249040876, 62.075372968401226, 17.89350301878793, 0.04442962145965014, 0.09169085776167256, 0.0644731828942895, 0.03399928971858961, 0.05338189358423863, 0.012753908755257726, 0.02726801368407905, 0.003949546238540539, 0.0415655047898846, 0.014711522996159536, 0.024761837807350924, 0.0257940507227821, 0.10119129797177655, 0.5715455710887909, 51.38431528636387, 60.57172720772879, 47.57196726117815, 31.183765411376953, 48.56374965395246, 81.68537112644741, 50.836724281311035, 51.18565934044974, 64.2005420412336, 51.676730224064414, 62.579721859523225, 6.0850412505013605, 0.2197019173098462, 0.5116467252373695, 1.8918798310416085, 0.47931426018476486, 9.696762646947588, 66.81466279711042, 49.567580223083496, 59.41301086970738, 51.89713750566755, 53.99610839571272, 50.087562561035156, 55.64335952486311, 52.673411096845356, 54.061449255262104, 50.693681716918945, 53.16538872037615, 42.392463888440815, 39.21817588806152, 36.617357458387104, 38.46514402117048, 37.46791771480015, 40.12491927828108, 38.62015833173479, 41.26076909473964, 41.42340210505894, 41.76555572237287, 40.324728625161306, 41.39147513253348, 39.66421202250889, 40.56282949447632, 35.363537652151926, 36.64471599033901, 36.7175817489624, 35.92772790363857, 34.3328001839774, 35.065015247889924, 34.120355537959504, 35.74449348449707, 36.954782826559885, 34.98421464647566, 34.54154144014631, 35.21065296445574, 34.939683641706196, 33.93881300517491, 33.14268146242414, 34.03659847804478, 34.062772342136924, 35.84433215005057, 34.78578104291643, 36.81698267800467, 41.15643841879708, 51.06788737433297, 39.648762702941895, 36.996346950531006, 36.13210221699306, 33.56631660461426, 35.69836439405169, 36.22235931668963, 35.38620267595564, 34.82346459797451, 33.7168528011867, 34.87917178017752, 37.400579248155864, 37.85344198771885, 38.9818502834865, 40.345625332423616, 45.591247762952534, 44.517900466918945, 36.648176193237305, 40.40182931082589, 39.613090651375906, 41.99102476664952, 39.56504385811942, 38.39235816683088, 36.88649940490723, 36.15377017429897, 36.0598201070513, 35.57690640858242, 36.02175440107073, 35.60692957469395, 37.107069969177246, 36.92412042617798, 35.33325045449393, 35.91164977209908, 35.2335854939052, 35.393130029950825, 35.295320238385884, 43.13728298459734, 42.50951671600342, 35.21558965955462, 35.40452854973929, 35.60624170303345, 33.676428181784495, 35.352132184164866, 35.67753369467599, 37.15869508470808, 35.68560750143868, 36.38124029976981, 37.2202387537275, 35.26414714540754, 36.27429362705776, 36.826779638017925, 36.707600661686485, 36.81955698558262, 37.05248839514596, 37.966492652893066, 37.362916537693565, 39.29172951834542, 40.09663316181728, 38.67696680341448, 39.40023258754185, 40.272512912750244, 39.30994422095162, 39.24042749404907, 39.96066733769008, 40.36903381347656, 38.38744926452637, 41.68674577985491, 41.6390255519322, 42.01966176714216, 42.316419328962056, 39.25749226978847, 46.39141273498535, 51.78575093405587, 55.26973751613072, 55.442782402038574, 56.53816590990339, 51.11410331726074, 59.66910062517439, 57.651826654161724, 61.83884239196777, 53.99549348013741, 60.74894796098982, 13.807217053004674, 0.7167015820741653, 2.2096465740885054, 3.287850226674761, 0.20867986232042313, 0.0511572588501232, 33.13829367501395, 69.5031292779105, 62.63994884490967, 71.00551741463798, 57.43268741880144, 39.658299105507986, 27.957940884998866, 33.48465095247541, 49.44716099330357, 70.05265535627092, 23.666940144130162, 0.07488145546189376, 0.06023989790784461, 0.036095067259988615, 0.05942848537649427, 0.037527732883713076, 0.013610361592977174, 0.1694435884377786, 0.12968163990548678, 0.11717979503529412, 0.11738138778933457, 0.11088524958384888, 0.08873574276055608, 0.26929095281021936, 0.7603647676961762, 60.147386823381694, 69.61854580470494, 54.83497483389718, 46.51879753385271, 51.917891774858745, 74.53953102656773, 51.62879460198538, 59.465601784842356, 68.62723241533551, 55.01308148247855, 66.97240080152238, 6.926382550171443, 0.383249145001173, 2.0421687151704515, 7.694311789103916, 0.6457953240190233, 10.540631788117544, 67.77361842564174, 51.971271310533794, 62.9750257219587, 55.622483662196565, 58.35146508898054, 52.849346433367046, 58.617574146815706, 53.7916715485709, 58.176603249141145, 51.61265046255929, 56.29863371167864, 43.98670373644148, 42.4945433480399, 38.36319310324532, 41.139422280447825, 39.29880278451102, 42.59999615805489, 40.04949310847691, 44.08859559467861, 43.9807630266462, 44.12894378389631, 42.86565705708095, 44.62592758451189, 42.49060719353812, 41.986400740487234, 38.68071188245501, 37.936702251434326, 39.86567504065377, 38.027949469430105, 37.26456478663853, 37.21090037482125, 36.56111526489258, 37.31360864639282, 38.4132479258946, 36.79504721505301, 35.66526665006365, 36.62305498123169, 35.87100281034197, 36.76636157717024, 35.44768728528704, 35.563055174691335, 37.03126164845058, 38.747518811907085, 36.20146608352661, 37.735913208552766, 42.47308383669172, 52.88003315244402, 40.97936010360718, 37.27661296299526, 37.22606829234532, 34.16738442012242, 37.55870287758963, 38.05463750021798, 37.674643993377686, 35.14861944743565, 35.62163543701172, 38.62037719999041, 41.62097760609218, 41.07437324523926, 42.47595691680908, 42.33092021942139, 46.72557592391968, 45.131343024117605, 39.528975759233745, 41.72076416015625, 41.88928576878139, 42.59167569024222, 41.58023336955479, 40.502748421260286, 39.55857855933053, 38.275628430502756, 37.12190089906965, 37.736573287418906, 37.14560120446341, 37.73919970648629, 38.44642557416643, 37.70298222133091, 36.69048030035836, 37.22449452536446, 35.9827298436846, 37.883843830653596, 35.263591289520264, 45.016221795763286, 44.92085429600307, 37.26802846363613, 37.16658476420811, 37.83107921055385, 35.36751549584525, 36.270183767591206, 36.52491862433297, 38.97883823939732, 38.11736236299787, 37.884357997349326, 38.673273835863384, 37.36896841866629, 39.36470297404698, 39.16974694388253, 39.73287064688546, 39.987386635371614, 39.81282009397234, 40.18158878598894, 39.42183106286185, 41.24470138549805, 44.0436372756958, 40.66883121218, 41.94074065344674, 42.05654975346157, 42.43723113196236, 41.53512566430228, 41.8764385495867, 43.69098145621163, 40.2214332308088, 42.40700299399239, 44.99850388935634, 43.009095668792725, 44.10814782551357, 42.873032569885254, 48.956211703164236, 54.872738293239046, 58.970605169023784, 59.38388402121407, 57.21241562707083, 52.84061254773821, 62.03513595036098, 58.95513153076172, 63.60072490147182, 56.196345806121826, 62.97781194959368, 17.293583393096924, 0.677406804902213, 7.149437963962555, 11.526403989110674, 2.1207858451775143, 0.22133523252393517, 37.05166155951363, 73.61423942020961, 67.79626260484967, 75.49848665509904, 66.87133230481828, 45.960228375026155, 30.62721470424107, 42.77542427607945, 56.75212178911482, 80.4740013395037, 30.032931804656982, 0.09992322458752564, 0.3051513928387846, 0.19273232163063117, 0.13585793705923216, 0.3169605348791395, 0.0853223248517939], [0.0854059678635427, 0.018099745203341757, 0.04386482587350266, 0.04722833074629307, 0.060750617645680904, 0.0514180130724396, 0.11680727931005613, 0.013020135362499526, 38.39226089205061, 55.825579507010325, 44.100699356624055, 34.10661200114659, 23.8318886416299, 21.225230251039775, 34.54958398001534, 50.48579508917672, 57.41587277821132, 49.49233818054199, 59.41508143288748, 5.417944269520896, 0.19270938714700087, 0.0822628986622606, 0.33935680453266415, 0.2905702723988465, 3.8533489108085632, 64.3400549207415, 51.19435501098633, 57.188322748456685, 48.634193965366904, 52.42708356039864, 48.65535470417568, 53.59701429094587, 46.77738516671317, 49.93370859963553, 50.790091446467805, 48.64527634211949, 39.40320641653878, 37.03596210479736, 35.496133599962505, 36.97530780519758, 36.196598870413645, 39.34715529850551, 38.38602488381522, 40.48177528381348, 39.85156324931553, 40.58937856129238, 37.99968419756208, 38.79728528431484, 34.124086720602854, 36.93561274664742, 33.042002064841135, 34.009094033922466, 33.13711248125349, 33.83750826971871, 31.22499254771641, 33.18090697697231, 32.18245431355068, 33.806849343436106, 33.28726305280413, 34.204915114811485, 34.89661523274013, 34.16466767447335, 31.738172599247523, 32.95289141791207, 33.101238931928364, 32.26643371582031, 33.45114326477051, 34.26107045582363, 31.95424767902919, 35.77854313169207, 37.86773790631975, 46.99818502153669, 41.94376311983381, 36.79791334697178, 35.490946769714355, 34.00086736679077, 33.99337373461042, 35.55024964468819, 36.396547181265696, 33.11306824002947, 32.44251496451241, 33.86751059123448, 33.20490952900478, 36.164887292044504, 39.55518089021955, 38.118067605154856, 34.834453174046104, 35.80220522199358, 38.10070058277675, 38.68870578493391, 37.859730107443674, 38.860249859946116, 35.75901869365147, 35.062333243233816, 33.815954957689556, 33.0031407901219, 31.400045463017054, 33.51303781781878, 33.47741787774222, 35.31980916431972, 35.264595304216655, 36.91636276245117, 35.066192967551096, 35.70197050912039, 35.279797962733674, 35.24129452024187, 36.842249802180696, 43.86610385349819, 40.17569671358381, 34.29562732151577, 34.1090647152492, 34.136725493839805, 34.46932533809117, 32.84168897356306, 32.80629832404, 34.13343899590628, 33.12402554920742, 33.62699522290911, 34.22042349406651, 32.86905445371355, 33.903790610177175, 34.699703284672324, 35.91322006498064, 34.85873365402222, 34.22001007625035, 34.07600171225411, 35.285940170288086, 35.17068345206124, 34.28377022062029, 35.355029582977295, 36.18012816565377, 36.92722627094814, 36.55408368791853, 36.45462717328753, 39.47831991740635, 40.962378706250874, 41.24213750021798, 37.42528009414673, 41.31353718893868, 41.223099436078755, 40.779727935791016, 38.01312548773629, 42.06587076187134, 46.14377893720354, 52.00696768079485, 52.762077059064595, 57.31614875793457, 55.77138008390154, 59.15141814095633, 54.40738616670881, 62.016410555158345, 48.955919878823416, 57.13502311706543, 14.070711851119995, 0.5408295935818127, 1.8914985486439295, 1.5652127712965012, 0.2645397149026394, 0.005659563475221927, 36.214073589869905, 61.54175131661551, 58.073273113795686, 63.71040916442871, 52.558845724378315, 41.847339493887766, 15.936096463884626, 30.42599139894758, 43.991348607199534, 62.409581320626394, 14.563819425446646, 0.1612836755812168, 0.07317641909633364, 0.051614035053976944, 0.008866376376577785, 0.07217284544770207, 0.013208180316723883, 0.05572962135608707, 0.09095590255622353, 0.024817238495286022, 0.03504846431314945, 0.01972298077972872, 0.05007466979857002, 0.1089439812515463, 0.11577927161540304, 43.3765754699707, 61.970128604343955, 50.366682120731895, 40.57103879111153, 31.571016311645508, 40.324669565473286, 40.42707906450544, 54.186013085501536, 62.009643009730745, 53.77820246560233, 60.94884763445173, 6.804234087467194, 0.22726636140474252, 0.13309460319578648, 1.6120027005672455, 0.6220534379993166, 4.564727195671626, 66.99175153459821, 52.24007626942226, 60.530482700892854, 51.559423787253245, 55.800600733075825, 52.18644312449864, 55.67824642998831, 49.0115784236363, 51.81865412848336, 52.314244815281455, 50.487045764923096, 42.0220172064645, 38.16449894223894, 36.201271533966064, 38.96360083988735, 39.56474161148071, 41.78576455797468, 40.15712070465088, 42.114497729710166, 41.37453889846802, 43.29714366367885, 40.2848424911499, 41.14052356992449, 37.55640997205462, 37.96511343547276, 34.51498542513166, 37.39592048100063, 35.35631499971662, 35.92173160825457, 33.91555391039167, 36.27444301332746, 33.903429303850444, 35.793325424194336, 34.1237462588719, 36.588449478149414, 35.37527315957205, 35.5761525290353, 33.65382916586739, 34.89373173032488, 34.32886055537632, 33.77094800131661, 34.55026142937796, 35.28213255746024, 35.045473439352854, 36.21119008745466, 39.62544454847063, 49.93120724814278, 44.181923798152376, 38.22454180036272, 35.81689371381487, 35.335699694497244, 36.472282545907156, 37.5953164100647, 36.417304924556184, 34.31785808290754, 34.902799129486084, 34.19177607127598, 33.9948467527117, 36.89817585263933, 40.1124472618103, 40.98238951819283, 37.83201026916504, 37.1133268220084, 39.67203916822161, 40.71674598966326, 41.16636739458357, 39.616717611040386, 37.972280502319336, 36.814199924468994, 35.3899164881025, 36.60371814455305, 34.711890425000874, 37.55810185841152, 35.92857558386666, 35.61446837016514, 37.191250869206016, 36.95547069822039, 35.14487089429583, 37.19512448992048, 36.11055932726179, 37.02835382734026, 38.01732914788382, 45.391626017434255, 42.907464368002756, 35.05856384549822, 36.286498137882774, 35.51596375874111, 35.627395493643625, 35.248430320194785, 34.08690343584333, 35.840684345790315, 35.61740745816912, 36.401039191654746, 36.26696675164359, 34.48063005719866, 35.159806047167095, 37.56573098046439, 37.48469066619873, 37.17598220280239, 35.19681562696184, 35.33015155792236, 37.813236236572266, 37.98954677581787, 37.18530668531145, 36.15257855824062, 37.66057736533028, 38.98739147186279, 39.99244144984654, 38.8341315814427, 41.55596678597586, 43.7672518321446, 43.305418968200684, 41.32845149721418, 43.926160608019146, 42.3797938483102, 43.35637010846819, 40.82612453188215, 43.05635036740984, 48.90394735336304, 54.761740820748464, 55.72063738959176, 59.09054497310093, 56.83886310032436, 60.26363018580845, 55.10180303028652, 62.54267406463623, 52.88353851863316, 60.65331295558384, 16.804388523101807, 0.7399410264832633, 2.374085247516632, 1.949550096477781, 0.19397306362433092, 0.09072490887982504, 38.43728174482073, 68.07257856641496, 64.08687646048409, 68.75924124036516, 57.71071611131941, 41.042547021593364, 18.469216857637676, 37.74757923398699, 48.94846446173531, 71.51325007847377, 17.84157739366804, 0.22194811249417917, 0.06361968762108258, 0.06415668702019112, 0.03314536018297076, 0.03443948931193777, 0.024909166419612508, 0.1453377226633685, 0.19905519591910498, 0.1158059516123363, 0.2773509717413357, 0.17588192224502563, 0.12780756689608097, 0.26023020329219954, 0.3219472515795912, 49.66198192323957, 71.13425363813127, 56.82935101645333, 49.06416239057268, 35.75594411577497, 32.29154797962734, 48.578549316951204, 58.72652884892055, 67.45746149335588, 58.80757958548409, 69.15463542938232, 7.147396062101636, 0.34704927461487906, 0.9891432715313775, 3.1135577048574175, 0.8323422425559589, 5.038087555340358, 70.65822560446603, 53.768968309674946, 63.536120550973074, 52.592759881700786, 58.61513532911028, 52.66859252112252, 58.36022676740374, 51.74072660718645, 56.025451387677876, 54.21021018709455, 54.20816741670881, 43.3217750276838, 40.06277806418282, 39.30616092681885, 41.045017106192454, 40.74266971860613, 43.019910539899556, 41.85989836284092, 44.15286990574428, 43.64115245001656, 45.37105240140642, 42.52937466757638, 43.20515298843384, 38.69442762647356, 41.453779629298616, 37.91156019483294, 39.821123191288535, 37.251213823046, 38.67705365589687, 34.42907442365374, 38.14449855259487, 36.842576367514475, 38.551127978733604, 35.83548361914498, 38.52298430034092, 37.85530063084194, 36.77155882971627, 34.36434847967965, 36.10269744055611, 36.71616084235055, 35.68393298557827, 35.87502581732613, 37.44246646336147, 35.18221746172224, 38.867444719587056, 41.17209618432181, 51.67764738627842, 45.771299907139365, 38.371051515851704, 36.878720896584646, 35.36959300722395, 36.647345883505686, 37.87365082332066, 40.73857028143746, 36.33827263968331, 35.83763061250959, 35.58086688177926, 36.22709451402937, 40.249900000435964, 41.710230691092356, 41.91515391213553, 40.72144644601004, 40.369686944144114, 41.68826396124703, 42.41359683445522, 41.33985001700265, 42.22903878348214, 38.7938528742109, 39.72017976215908, 36.94886643545968, 38.25363738196236, 35.25923824310303, 40.24435881205967, 38.0061251776559, 37.32725838252476, 38.50766004834856, 39.015823500497, 36.224329130990164, 39.08523947851998, 36.79436976569039, 36.339099475315635, 39.7506754057748, 46.86258397783552, 44.2932756287711, 37.15423434121268, 36.42411068507603, 37.03523601804461, 38.46491820471627, 36.75720385142735, 34.846150466373985, 37.43032796042306, 35.73498487472534, 36.19404540743147, 38.11433294841221, 35.666805676051546, 36.91945123672485, 39.869006701878135, 41.00287280763899, 39.74897657121931, 37.80351570674351, 36.830931186676025, 39.94419663293021, 40.31156178883144, 39.54582861491612, 39.236751896994456, 40.517892020089285, 40.65750217437744, 41.9197154045105, 40.93074008396694, 44.046864713941304, 46.260925565447124, 47.53400577817644, 43.65566028867449, 47.45084626334054, 45.254027366638184, 46.28778382710048, 42.540992055620464, 46.095040798187256, 53.00443370001656, 56.04920727866036, 56.937652587890625, 61.336619649614605, 59.23535237993513, 61.984441893441335, 58.08909068788801, 66.03640896933419, 54.41343109948294, 62.232478686741416, 19.1563172680991, 0.8719074023621423, 6.195865886551993, 5.106619809355054, 0.4522223382123879, 0.12138345518282481, 42.51719100134713, 72.76865059988839, 68.99984346117292, 72.69392967224121, 64.44801603044782, 54.88501228604998, 25.048434836523874, 46.76478460856846, 58.281402928488596, 80.19080666133335, 24.204676866531372, 0.31032245393310276, 0.18283751686768873, 0.15082195481019361, 0.11925235310835497, 0.2088396301759141, 0.10322712694427796], [0.036101777971323044, 0.06193102430552244, 0.05249307377796088, 0.03280640479975513, 0.13542804441281728, 0.015156085569677609, 0.045477612010602436, 0.07264015930039541, 27.994274752480642, 59.30823203495571, 43.64945207323347, 38.06139462334769, 20.45546191079276, 18.626702989850724, 32.50204018184117, 52.36853109087263, 57.438503061022075, 48.279999119894846, 58.079241616385325, 7.141969519002097, 0.41490207080330166, 0.14297604081886156, 0.8374801097171647, 0.2784609193248408, 1.5737677408116204, 54.68337903703962, 51.62681436538696, 54.52962582451956, 48.70851537159511, 47.007849965776714, 40.420050961630686, 51.5222543988909, 48.76850611822945, 51.6549198286874, 47.379971163613455, 45.21698651994978, 38.36840425218855, 37.7338878086635, 35.526802948543, 38.115048612867085, 36.4411164011274, 41.45365456172398, 39.77353497913906, 40.9816495350429, 38.74784190314156, 39.908291816711426, 36.88970252445766, 37.11908687864031, 34.06096928460257, 34.66711275918143, 31.944297858646937, 33.24280500411987, 33.97875819887434, 32.5774941444397, 32.654160567692344, 34.10749442236764, 33.519416264125276, 34.36340699877058, 33.556127071380615, 34.122707503182546, 33.04967982428414, 33.54616682870047, 33.00051784515381, 32.55807045527867, 33.777152742658345, 32.02388252530779, 32.35967854091099, 32.90431308746338, 33.47388819285801, 33.53363227844238, 36.35063001087734, 44.89943994794573, 44.85464143753052, 37.350757190159385, 35.825068269457134, 33.41504389899117, 35.265220642089844, 36.273911476135254, 36.5403470993042, 35.026609080178396, 32.84973151343209, 32.9113655090332, 34.28764731543404, 37.69636058807373, 32.88189819880894, 34.05334711074829, 37.23097024645124, 41.424666677202495, 38.342598642621724, 37.55530868257795, 38.21708638327462, 37.09890930993216, 34.00332702909197, 33.95525939123971, 34.3919050352914, 34.83988666534424, 33.21750661305019, 35.199303082057405, 37.332466057368684, 35.08190631866455, 36.5109874861581, 34.14558792114258, 31.85463830402919, 34.270523480006624, 35.34783819743565, 33.498245103018625, 37.626305375780376, 45.68272079740252, 37.00930186680385, 34.29005834034511, 33.972511768341064, 32.957004751477925, 33.26858976909092, 32.96656894683838, 33.65888745444161, 34.25498383385794, 33.10709626334054, 32.791776588984895, 35.100808892931255, 33.56290851320539, 34.1103709765843, 34.61183983939034, 33.97330733707973, 34.5260191644941, 35.13418803896223, 34.286379269191194, 34.229449204036165, 34.025797503335134, 34.33106313432966, 34.918502058301655, 35.618946484157014, 36.55052968433925, 36.402137007032124, 38.78107861110142, 39.446361677987234, 41.30606440135411, 40.75689615522112, 40.86364133017403, 41.53151954923357, 40.555332388196675, 39.41450418744768, 38.33978809629168, 38.88288361685616, 40.80467196873256, 46.16342496871948, 50.978728090013774, 53.57473489216396, 52.04754516056606, 55.12637880870274, 53.03827142715454, 57.94022900717599, 57.590748514447895, 65.51833738599504, 23.247319323675974, 0.7159625217318535, 1.0668620211737496, 1.545013272336551, 0.09452496961291347, 0.07060646771320275, 33.289542061941965, 63.23030948638916, 56.93940700803484, 65.70948927743095, 55.27826295580183, 41.225830078125, 21.637765645980835, 31.739034175872803, 46.44595956802368, 60.124895504542756, 12.076325246265956, 0.19387749875230448, 0.03335610298173768, 0.04544628065611635, 0.08738729690334626, 0.02513145618805928, 0.02424771521639611, 0.03954866801255515, 0.027687635006649152, 0.06378719077578612, 0.004941542807500809, 0.06340784898826055, 0.030732265740100826, 0.10613011009991169, 0.05267487705818244, 31.529921191079275, 66.61577756064278, 50.242163453783306, 43.42124196461269, 20.8883398941585, 20.50454224858965, 44.759857586451936, 54.210922377450125, 62.82978057861328, 51.746021134512766, 62.09293106624058, 7.242688434464591, 0.26376689065779957, 0.1647620089352131, 1.7139702290296555, 0.8505091762968472, 2.0080962691988264, 57.837027413504465, 54.000933919634136, 57.241299288613455, 50.00398962838309, 48.155873026166645, 43.60582780838013, 51.46325029645647, 50.3448543548584, 55.42138889857701, 50.19281734739031, 47.63552590778896, 39.884820801871165, 40.809389795575825, 37.21991218839373, 39.301210335322786, 38.13702229091099, 43.17722817829677, 40.733345236097065, 42.59925617490496, 41.121978827885215, 42.20336866378784, 38.196811539786204, 38.46557828358242, 35.807927063533235, 36.99207380839756, 33.86037131718227, 36.456590039389475, 33.92308923176357, 35.70090743473598, 34.03977727890015, 35.657991886138916, 36.19973945617676, 36.04362038203648, 35.30761854989188, 36.628009046827046, 34.59545251301357, 35.813287598746165, 34.84142916543143, 33.94654982430594, 34.70572737285069, 33.473700591496055, 33.334809575762065, 35.596764360155376, 34.80781030654907, 35.022638184683665, 36.10091870171683, 46.54517984390259, 45.44228533336094, 35.97022656032017, 36.688927377973286, 33.28284747259957, 34.42744159698486, 37.13229193006243, 36.33773415429251, 37.549764020102366, 35.07950919015067, 34.71820286342076, 36.026948179517476, 39.179314613342285, 36.38013901029314, 36.22004209245954, 38.936440331595286, 42.87882041931152, 40.71873664855957, 39.881742749895366, 39.46811301367623, 37.72578273500715, 35.48524577277047, 35.52621929986136, 35.36637599127633, 35.23917531967163, 33.93390757696969, 36.02410289219448, 39.93345819200788, 36.09641626902989, 36.77852439880371, 34.81618635995047, 34.54616894040789, 33.837897368839805, 36.04996061325073, 34.17940827778408, 37.43507358006069, 47.56069033486502, 39.70914602279663, 36.15355825424194, 36.518898010253906, 34.45761067526681, 35.66340453284127, 34.139410972595215, 33.32006549835205, 36.18667336872646, 33.2519279888698, 34.65318162100655, 36.44601488113403, 35.17853144236973, 35.34799453190395, 36.79630136489868, 36.1502092225211, 36.43041270119803, 36.263742787497385, 36.340249402182444, 36.15939474105835, 36.57978507450649, 36.63413388388497, 38.01823936189924, 37.438231536320274, 39.756946155003135, 39.716719559260774, 39.732662200927734, 41.073032242911204, 43.63270344052996, 43.05544015339443, 43.16943577357701, 42.00129073006766, 42.458277225494385, 41.49267564501081, 40.39363738468715, 41.317476817539756, 43.5706456048148, 48.384503500802175, 52.64627143314907, 56.54654891150338, 54.997996943337576, 58.35421657562256, 56.11403744561331, 61.353934560503276, 60.28974151611328, 68.28069795880998, 25.44159517969404, 0.47585014892475946, 0.8446377313562802, 2.632218207631792, 0.17852594251079218, 0.08853263008807387, 37.902913161686485, 69.0508918762207, 63.07706696646554, 71.41977596282959, 60.63592856270926, 44.8731757572719, 25.306980780192784, 40.559782709394185, 52.52116216932024, 70.85187189919608, 16.197426898138865, 0.2805715703538486, 0.07307198577161346, 0.03398951202897089, 0.050519982153283696, 0.05736749632550137, 0.02884066277848823, 0.10499708554042236, 0.23614747556192534, 0.18047807418874331, 0.18349925135927542, 0.18211803904601506, 0.15059919176357134, 0.2655730965946402, 0.27792845932500704, 37.5157664843968, 75.49090617043632, 56.440349170139854, 49.66432694026402, 29.807768481118337, 28.172631536211284, 45.91151455470494, 62.10673713684082, 67.34366389683315, 57.4068922315325, 66.68385601043701, 8.393913745880127, 0.4837675669363567, 0.22912045834319933, 3.1039433521883826, 1.1290937789848872, 2.3263741391045705, 59.54237243107387, 54.99423796789986, 57.33754573549543, 52.938578673771445, 49.400840827396934, 44.95732191630772, 53.42702661241804, 50.9672531400408, 56.88357475825718, 51.563148021698, 50.19350869315011, 41.98008482796805, 41.947306701115195, 39.10519470487322, 41.31049387795584, 40.70990201405117, 44.92795535496303, 43.67037657329014, 44.815999031066895, 43.19435896192278, 44.862218448093955, 41.24749803543091, 42.18053340911865, 38.40614686693464, 37.79157175336565, 36.21528952462332, 37.296759264809744, 36.88542938232422, 37.8755442074367, 37.25769649233137, 37.612971782684326, 37.308397497449604, 39.03905132838658, 37.882770333971294, 38.80849620274135, 35.085588863917756, 37.772957529340474, 37.46367931365967, 35.50364807673863, 36.79629094260079, 34.904136657714844, 35.510926314762656, 37.6900759424482, 38.03214618137905, 37.15505075454712, 39.03799172810146, 48.67652586528233, 47.55889422552926, 37.41958604540144, 38.259418283190044, 34.85270956584385, 35.87809344700405, 39.92498138972691, 38.35682855333601, 39.079257079533164, 38.280488695417134, 36.54014907564436, 38.76542084557669, 40.44637073789324, 37.390410559517996, 39.44135202680315, 41.27354335784912, 44.6008689062936, 42.380182947431294, 42.65158653259277, 42.38977493558611, 40.219723973955425, 37.440976074763704, 38.181077344076975, 36.618403162275044, 38.00513505935669, 35.99762330736433, 38.11816487993513, 42.44884852000645, 36.98112344741821, 38.69360079084124, 35.23024688448225, 34.25676604679653, 33.94368716648647, 36.56851509639195, 34.20076356615339, 38.39720106124878, 51.06844670431954, 42.4593368257795, 38.03538056782314, 37.50429848262242, 36.623489243643625, 36.570099285670686, 35.87583180836269, 36.55574778148106, 36.84720039367676, 35.6695363180978, 35.68806021554129, 39.431958062308176, 36.95517539978027, 36.65176146371024, 38.49810627528599, 38.279168537684846, 38.5264618737357, 40.00143241882324, 38.41651010513306, 39.360301290239605, 40.07233183724539, 39.381663526807515, 38.93215329306466, 39.29349783488682, 41.51741123199463, 42.90215594427926, 43.611032009124756, 43.96488291876656, 46.88633292061942, 46.49820307322911, 47.42081267493111, 45.72711631229946, 45.261719022478374, 45.89155238015311, 42.94235127312796, 43.51577915464129, 45.7666654586792, 49.191248416900635, 56.28911467960903, 59.11361994062151, 57.58241067613874, 59.956693513052805, 58.17159707205636, 62.64587565830776, 62.8502082824707, 68.80984497070312, 28.948450020381383, 0.619760315333094, 5.8441758666719705, 6.6518366421972, 0.49818024784326553, 0.2065375101353441, 40.55402960096087, 74.56348146711076, 66.23610714503697, 76.05754566192627, 67.92363698141915, 56.97845935821533, 34.658576897212434, 48.784045764378135, 60.220329012189595, 83.1686100278582, 21.372507742473058, 0.40220605635217255, 0.13106652987854822, 0.17340379022061825, 0.15033878359411443, 0.20320128915565355, 0.09615918727857725], [0.0484664739508714, 0.02596791514328548, 0.015988037356042435, 0.05779854926679816, 0.08543983354632344, 0.07036931293883494, 0.19463566664074147, 0.070373899835561, 15.593095166342598, 56.167086941855295, 45.255785260881694, 35.410639490400044, 25.58717383657183, 34.5231808253697, 34.43489006587437, 53.0914876801627, 56.89909355981009, 50.47849600655692, 57.14936767305647, 8.51045674937112, 0.45904907903500963, 0.22054743979658398, 1.0902926496097018, 0.43518057838082314, 0.5360406562685966, 41.26671327863421, 44.66820042473929, 59.57773181370327, 50.57817138944353, 59.491546358381, 46.43448461805071, 55.38448701586042, 52.79477875573294, 52.99897589002337, 44.28483356748308, 43.72852604729788, 37.55659409931728, 37.13916369846889, 36.14807265145438, 39.71989836011614, 38.01870141710554, 40.31129080908639, 39.032860483442036, 41.461961133139475, 37.63691527502877, 36.15716436931065, 33.5112486566816, 35.25863027572632, 31.49890443256923, 34.61534867967878, 34.16368450437273, 34.450989042009624, 32.419071742466514, 34.77784620012556, 33.332134519304546, 34.656999656132285, 31.757353101457866, 32.640809604099815, 32.725911140441895, 34.88245480401175, 35.020546776907786, 33.9654871395656, 32.64582620348249, 32.81910732814244, 33.1844470841544, 32.25342321395874, 31.47066695349557, 34.698615891592844, 32.68753971372332, 32.96648556845528, 34.82181092670986, 43.09556600025722, 41.580031871795654, 37.66565997259957, 33.821649006434846, 33.63275180544172, 33.08124896458217, 34.98755325589861, 33.31617103304182, 35.4607047353472, 33.62878090994698, 32.66948134558541, 33.36856392451695, 32.51272651127407, 33.80339956283569, 37.06737838472639, 36.86270877293178, 37.33933782577515, 38.95983839035034, 37.070897647312705, 37.23302691323416, 36.3411283493042, 34.68157543454851, 34.84530626024519, 32.80605513708932, 34.70142296382359, 35.01880277906145, 35.499006680079866, 35.278324944632395, 34.349545342581614, 34.74899727957589, 34.03406585965838, 33.31667825153896, 33.474902629852295, 35.12090308325631, 34.823238781520296, 38.22926310130528, 42.81227057320731, 35.20624085835048, 34.823127610342844, 35.56975671223232, 35.59958185468401, 33.18409967422485, 33.48823274884905, 33.172051497868125, 33.30585643223354, 34.1864572252546, 34.1482595035008, 34.834918703351704, 34.56457471847534, 33.98812089647566, 36.12675905227661, 33.04377385548183, 34.0975341796875, 33.77112170628139, 33.09835542951311, 34.911904743739534, 34.81144421441214, 33.118689332689556, 35.29524728230068, 34.515902587345664, 37.03712592806135, 36.60072694505964, 37.619506563459126, 39.54394565309797, 39.72982038770403, 36.739982741219656, 39.68852724347796, 38.44912494931902, 37.766638142721995, 39.69916493552071, 37.64220980235508, 38.50218486785889, 37.898146697453086, 38.97232777731759, 40.85216290610177, 48.5698675428118, 49.1413950920105, 53.67435816356114, 52.02880934306553, 56.661694458552766, 54.3383731842041, 63.26649570465088, 34.944724559783936, 0.5235945326941354, 1.3332054721457618, 0.8027336341994149, 0.439626936933824, 0.03388517369915332, 34.87616321018764, 64.0575203214373, 56.36069849559239, 65.43311773027692, 54.8611660684858, 39.9077741759164, 11.98904023851667, 31.93042230606079, 46.264597688402446, 54.761733872549875, 9.722845315933228, 0.33209151295678957, 0.08620910905301571, 0.04487121204978653, 0.06403161944555384, 0.03668670569147382, 0.08730693121573754, 0.026712403765746524, 0.007608249467531485, 0.04969588440975972, 0.049861077152724774, 0.05842825012015445, 0.06107661979539054, 0.05993598885834217, 0.14283816250307219, 18.382899386542185, 66.03412996019635, 51.81760147639683, 44.18901096071516, 30.183874470846995, 36.45907749448504, 42.154415130615234, 58.488490513392854, 62.58004147665841, 54.973831108638215, 62.52418490818569, 9.030087334769112, 0.33521299117377823, 0.16116398200392723, 3.5721720329352786, 0.5145504208547729, 0.4550655356475285, 46.47616686139788, 47.26729917526245, 59.728188105991904, 52.16400044304984, 57.91437823431832, 47.82835578918457, 54.53366272790091, 53.486815861293245, 53.85698461532593, 47.97117601122175, 47.052898611341206, 39.17467669078282, 39.33230699811663, 38.77771915708269, 40.81964881079537, 39.35476010186331, 43.11996807370867, 41.31018468311855, 41.90854964937483, 39.20693717684065, 39.12245403017317, 35.49265602656773, 36.055783203669954, 33.303688594273154, 35.73838601793562, 35.758174487522666, 36.44091837746756, 34.920353753226145, 38.35954529898507, 34.22975492477417, 37.02193021774292, 35.24847548348563, 35.751021317073274, 36.16976840155465, 36.513245650700156, 35.91661425999233, 34.78345339638846, 34.69339084625244, 35.584038734436035, 35.291529996054514, 34.08202232633318, 32.88314192635672, 34.65046487535749, 34.33676413127354, 34.659007685525076, 36.75916324343, 46.53629657200405, 42.776185103825156, 38.63129281997681, 35.404681410108296, 33.244416986192974, 34.42451640537807, 34.938592774527415, 34.444926738739014, 37.167053767613, 34.681043897356304, 33.74163007736206, 34.321745600019185, 34.60983180999756, 36.05776344026838, 38.0496278490339, 36.873745986393516, 39.6808112689427, 39.890935216631206, 39.1994365964617, 38.5945576940264, 37.91966526848929, 35.8679073878697, 35.46431085041591, 34.98426328386579, 35.963636193956646, 35.249562876565115, 37.76802430834089, 36.22067437853132, 34.49842439379011, 34.63502597808838, 34.998326437813894, 34.74765975134713, 33.55743333271572, 36.91068261010306, 34.58019079480852, 38.874622208731516, 47.872522013528005, 36.593681471688406, 35.502890723092214, 37.20591851643154, 37.04536649159023, 34.953031131199424, 35.139972414289204, 33.945653506687705, 34.415824208940776, 35.296178340911865, 34.753291266305105, 37.11792652947562, 36.07317801884243, 36.20912299837385, 37.72185352870396, 36.096183504377095, 36.215702942439485, 36.73819358008248, 35.52237694604056, 37.55944286073957, 35.255034582955496, 36.13984251022339, 37.2270827293396, 36.97199351446969, 38.80833292007446, 38.987502643040244, 39.95479263578142, 40.0116844858442, 40.66711848122733, 40.397007261003765, 41.84153427396502, 40.490245137895855, 40.905337469918386, 41.241783142089844, 39.70904179981777, 39.88362571171352, 41.37874950681414, 41.21071079799107, 43.22390617643084, 50.09915910448347, 53.645999091012136, 54.66253096716744, 54.95973668779646, 59.33862345559256, 58.261996609824045, 64.7673899786813, 40.936250005449565, 0.6055117856178964, 0.7078610307403973, 1.6144928698028838, 0.44273085466453005, 0.11622453986534051, 37.368492467062815, 68.14030960627964, 60.97702257973807, 70.24782330649239, 61.544961384364534, 46.248245103018625, 17.05701286452157, 39.958020074026926, 52.18842683519636, 64.92203603472028, 14.097557953425817, 0.45917539511408123, 0.0924503623640963, 0.02870160381176642, 0.0367133755103818, 0.08471141263310399, 0.017946002738816396, 0.0584609555080533, 0.11222859285771847, 0.173196565625923, 0.1617009746176856, 0.1554863673767873, 0.15080265727426323, 0.34275102668574875, 0.18914466271443026, 20.060074669974192, 75.54330948420933, 58.723555019923616, 50.500626019069124, 36.02540915352957, 44.8458936555045, 45.736194133758545, 63.68764686584473, 68.30988734109062, 58.633061681474956, 67.56879942757743, 10.399687579699926, 0.788037217089108, 0.37134962209633415, 6.003608797277723, 0.8114432554159845, 0.654655037181718, 52.40316786084856, 48.81184203284127, 62.2979793548584, 55.50325257437569, 61.14503002166748, 48.580849170684814, 57.927631923130576, 56.180788789476665, 56.37440729141235, 50.138642242976594, 49.340071882520405, 42.402691636766704, 41.17066832951137, 39.9196903364999, 43.7375864982605, 41.38103199005127, 45.235319341932026, 43.88167476654053, 46.19751630510603, 42.53985602515084, 39.342861311776296, 37.267218998500276, 39.29065602166312, 35.41850137710571, 39.04343564169747, 39.183990750994, 38.38088321685791, 36.606629439762656, 40.72318696975708, 37.3768754686628, 39.179099219185964, 36.33484370367867, 37.166873114449636, 37.89426612854004, 37.90141235079084, 38.16449546813965, 37.21338782991682, 37.031984261104036, 36.66069337299892, 37.633191040584016, 35.14932121549334, 35.23239735194615, 37.74934755052839, 36.66044323784964, 38.70517996379307, 38.493315492357524, 47.83444935934884, 44.31395346777779, 38.57819468634469, 35.32829986299787, 34.15804604121617, 36.44692162105015, 37.580600125449045, 36.67483990533011, 38.88549266542707, 36.13733768463135, 35.864283902304514, 35.977803570883616, 36.51650782993862, 38.108729226248606, 39.836020129067556, 38.68792411259243, 42.40443563461304, 42.5206755229405, 41.219590595790315, 41.11565944126674, 40.116435527801514, 38.71649510519845, 38.45751142501831, 36.1159268106733, 39.259055614471436, 37.72586611339024, 38.606706619262695, 38.207883494240896, 35.47713375091553, 37.41751200812203, 35.196416105542866, 35.3936824117388, 33.177095890045166, 37.11455317905971, 34.551362718854634, 39.690479687282014, 50.177051884787424, 39.07598795209612, 38.64084659303938, 39.384724208286826, 39.09400463104248, 37.488758836473735, 35.96303864887783, 36.24087626593453, 34.87844916752407, 36.488829680851524, 36.753472668784006, 40.56646340233939, 38.97046218599592, 38.2909700529916, 41.17497968673706, 37.83968802860805, 38.06664398738316, 39.587090492248535, 39.22184106281826, 40.55268512453352, 39.26752894265311, 37.70870406287057, 38.62820781980242, 37.11089147840227, 39.91278035300118, 40.7379275730678, 42.25982277733939, 45.37163952418736, 44.71494443075997, 42.34527172361101, 44.12929119382586, 43.376002243586946, 44.10986750466483, 44.25414684840611, 41.96139417375837, 41.349966594151084, 44.16706507546561, 43.01522050585066, 45.79517044339861, 53.030267102377756, 54.208744117191856, 57.407083306993755, 58.447496141706196, 60.89908463614327, 60.81130109514509, 65.36121777125767, 43.181344985961914, 0.7299080448491233, 6.889583587646484, 3.2775942512920926, 0.6183033106582505, 0.25912590112004963, 40.82197298322405, 74.32235813140869, 64.1809481212071, 75.50221783774239, 68.56489317757743, 53.74297162464687, 22.331048216138566, 49.68934392929077, 58.78663076673235, 75.64777565002441, 19.129168919154576, 0.6751641109585762, 0.23920487293175288, 0.17520352293338093, 0.12226133021925177, 0.15486805912639412, 0.09712546185723372], [0.03470730029844812, 0.08477765122162444, 0.028418988887486712, 0.024901202114831125, 0.07238354414169278, 0.04876248146008168, 0.014252673867823822, 0.02973730948620609, 6.443690759795053, 59.42829690660749, 47.35296698978969, 33.79044812066214, 15.023262977600098, 20.69668425832476, 42.3724148614066, 49.53316232136318, 58.771226610456196, 47.870753696986604, 59.808418955121724, 9.917382717132568, 0.38453895864742144, 0.39934179719005314, 2.4086038981165205, 0.4717131480574608, 0.17740850390068122, 31.480248519352504, 52.96337679454258, 56.61492960793631, 53.98808322634016, 56.254700251988, 56.45571858542306, 51.27510002681187, 50.33242750167847, 47.59392009462629, 42.468515396118164, 41.321360860552105, 36.64078330993652, 35.59417268208095, 35.52032027925764, 38.36422838483538, 38.55626964569092, 38.2842754636492, 38.667041301727295, 37.828352042606895, 33.99221338544573, 34.092135429382324, 32.32455539703369, 34.47249024254935, 33.756888321467805, 34.32768978391375, 32.72847849982125, 34.16006449290684, 35.44236149106707, 34.94034024647304, 33.30750315529959, 34.1836154120309, 33.43629149028233, 34.07720375061035, 33.132134096963064, 33.209130559648784, 34.532130105154856, 33.68404688153948, 31.100640637534006, 31.761212825775146, 32.72460835320609, 32.98200784410749, 31.839585031781876, 34.558265754154746, 35.31193338121687, 34.90703405652727, 34.37426355906895, 45.57631608418056, 44.342416763305664, 39.31698969432286, 35.03576333182198, 33.92915153503418, 33.67743567058018, 34.6141813823155, 32.39585433687483, 34.97356653213501, 34.22576665878296, 32.93776518957955, 32.00480277197701, 33.95855631147112, 34.63728066853115, 33.43645477294922, 35.307788780757356, 36.678567613874165, 35.483407974243164, 36.80111299242292, 36.14701999936785, 34.85817084993635, 34.786569663456504, 31.813345159803117, 33.402054241725374, 34.83472415379116, 35.045671463012695, 37.09087719236101, 33.981627804892405, 32.17270599092756, 33.78639384678432, 34.18806225912911, 35.100207873753135, 35.779696532658164, 34.995335238320486, 35.730305262974326, 38.26357330594744, 45.78957714353289, 34.14023780822754, 33.22598688943045, 35.66921670096261, 34.26285266876221, 34.59093618392944, 33.63885579790388, 34.366627488817485, 33.04546226773943, 33.954581941877095, 34.391658374241416, 33.752816677093506, 33.616975920540945, 32.94770111356463, 35.38534457342965, 33.269833496638704, 33.38687242780413, 35.15448720114571, 33.18574292319161, 33.700291769845144, 34.32133565630232, 33.42776952471052, 34.508179664611816, 34.7579083442688, 35.21328285762242, 35.85733222961426, 36.56074006216866, 36.614088330950054, 38.664435727255686, 35.89788539069039, 36.663208620888845, 38.22008453096662, 37.150294712611604, 37.30991220474243, 37.15491873877389, 38.15070676803589, 38.65923500061035, 40.04211064747402, 39.88377162388393, 41.0547376360212, 42.33166715076992, 47.743483543395996, 49.28022704805647, 54.411169460841585, 55.86969709396362, 60.92556422097342, 41.69124821254185, 1.1515212612492698, 0.9277299898011344, 1.603221806032317, 0.2319333388337067, 0.14313210387315067, 40.868814264025005, 62.793114934648784, 59.55228751046317, 61.73687062944685, 57.81754813875471, 39.44378389630999, 23.020974806376866, 33.70692382540022, 47.402326992579866, 54.80316250664847, 8.85991292340415, 0.2601638697087765, 0.07200810393052441, 0.04046262754127383, 0.005568122823855707, 0.03603107462237988, 0.010805559910035558, 0.04401749625269856, 0.08756718332214014, 0.08688355929085187, 0.08848881708191973, 0.040972227696329355, 0.04130468949941652, 0.01592619058543018, 0.06754107720085553, 8.095163788114276, 65.98434611729213, 52.935938358306885, 38.620787143707275, 19.802862780434744, 26.641578606196813, 48.230354240962434, 54.863472870418, 62.84560162680489, 51.8935661315918, 63.058466638837544, 10.857829213142395, 0.34987426017011913, 0.2386204914322921, 4.2057771767888745, 0.49764344521931236, 0.010053006898877876, 37.95780740465437, 56.24299601146153, 58.21970987319946, 55.170194149017334, 56.4393937928336, 56.830917835235596, 52.81402179173061, 52.34031445639474, 49.71388496671404, 44.077829360961914, 44.098649638039724, 39.18230928693499, 38.11390216009957, 37.83931629998343, 40.688692637852256, 40.24044002805437, 41.36606904438564, 39.05369813101632, 40.29479578563145, 36.37375014168875, 37.354547432490754, 34.79703712463379, 36.62393740245274, 35.03184107371739, 35.47942665645054, 35.85513659885952, 36.59709651129586, 36.16039875575474, 36.41972984586443, 35.0740270614624, 35.88679606573922, 34.29826763698033, 36.374705518995015, 34.43724550519671, 34.84725175585066, 35.702178955078125, 35.36656706673758, 32.84981141771589, 33.33526815686907, 33.356838839394705, 35.17624201093401, 33.34659024647304, 36.467095715659006, 36.13761908667428, 36.61709342684065, 36.54932764598301, 47.30225556237357, 46.35085609980992, 40.23109122685024, 36.72656576974051, 34.750494616372244, 33.63097306660244, 33.499401978084016, 34.333731242588584, 35.87483474186489, 35.42064142227173, 34.40023592540196, 33.244048731667654, 34.54568951470511, 34.92904247556414, 35.40003653935024, 36.34605114800589, 38.993919304439, 37.61451775687081, 38.24211032049996, 37.659385749271934, 35.657724380493164, 34.814115796770366, 34.43100949696132, 35.36065762383597, 37.548304898398264, 36.23714508329119, 38.03991426740374, 34.15093108585903, 34.41586937223162, 35.09487860543387, 36.39111021586827, 34.7335444859096, 35.19826432636806, 35.18371479851859, 35.73546082632882, 38.81109830311367, 47.10815068653652, 36.80195025035313, 35.73461662020002, 36.02408899579729, 34.82059151785714, 35.846096992492676, 35.660948344639365, 36.372784342084614, 34.360985551561626, 35.39418268203735, 35.34122698647635, 34.69936282294137, 35.872920513153076, 34.23321860177176, 37.88787725993565, 36.48192317145211, 34.66126932416643, 36.52305998120989, 37.834143366132466, 34.660414695739746, 35.80339683805193, 35.059098856789724, 37.06924050194876, 36.25474834442139, 37.238106046404155, 37.160268851688926, 39.06994996752058, 37.932988439287456, 40.28254263741629, 38.762193407331196, 39.757488114493235, 39.55749464035034, 40.18900598798479, 40.009839739118306, 40.01840686798096, 41.047219685145784, 40.98875754220145, 42.09128727231707, 40.65392732620239, 43.960547242845806, 45.08165645599365, 51.28392423902239, 51.21215282167707, 55.5292318889073, 60.68921429770333, 61.2362459727696, 48.82779162270682, 1.3461455149309975, 1.174064257315227, 2.43680859037808, 0.3443445254649435, 0.24976781755685806, 44.44292940412249, 67.57764448438371, 62.58009706224714, 69.016692842756, 63.18295751299177, 41.890255042484824, 22.337405817849294, 39.461925642830984, 53.667684418814524, 63.54884965079171, 12.263951795441763, 0.39717851898499895, 0.04165211978501507, 0.05996924385960613, 0.04932352474757603, 0.03403974058372634, 0.025581223125170385, 0.23582842839615686, 0.11153289768844843, 0.1689504834690264, 0.15420203629348958, 0.13132183546466486, 0.1519983716841255, 0.18678205806229795, 0.19719577926610196, 9.124266692570277, 79.09240068708147, 60.097790581839426, 46.195404052734375, 25.122825724737986, 28.131044830594742, 53.906966481889995, 59.80265889848982, 67.87707015446254, 56.10833297457014, 70.98385987962995, 12.661942873682294, 0.6367824790733201, 0.4616003707051277, 9.048579096794128, 2.1918965322630743, 0.34532636563692776, 43.36317586898804, 57.06537784848894, 60.19421073368618, 57.7413125038147, 59.72075353349958, 56.952598163059776, 56.09554481506348, 54.19159596306937, 50.41877623966762, 46.25019407272339, 48.1104040145874, 40.7758195740836, 39.42184843335833, 38.89641523361206, 43.211392470768516, 42.269845553806846, 42.66598667417254, 41.872617040361675, 42.94473450524466, 38.00418663024902, 37.52945096152169, 36.0098625591823, 39.69850138255528, 37.186578205653596, 37.34399311883109, 36.52700655800955, 38.886642592293875, 39.320307459150044, 40.16114371163504, 38.44181891850063, 39.21594551631382, 37.74676282065255, 37.801076889038086, 37.26980025427682, 36.90363366263253, 38.875365665980745, 35.77803591319493, 33.43922363008772, 34.99688121250698, 34.689277512686594, 36.424586636679514, 34.84059190750122, 38.26427159990583, 38.73308392933437, 38.59625652858189, 39.37369394302368, 49.665112086704795, 48.944736753191265, 42.431151458195274, 36.850712708064485, 35.260068552834646, 34.02064193998064, 36.00962632043021, 35.610150064740864, 37.79215887614659, 38.224930899483816, 36.03333704812186, 35.70392990112305, 38.10314287458147, 38.286620480673655, 37.243678501674104, 39.07494224820818, 40.00710909707205, 40.01593330928257, 40.50659772327968, 39.98955447333199, 38.07004165649414, 36.827363286699565, 34.812587193080354, 38.296028341565815, 39.76513113294329, 38.94515684672764, 40.875168391636436, 35.53241014480591, 34.482554708208355, 35.15460532052176, 35.962736402239116, 34.97864219120571, 36.45693050112043, 35.59193536213466, 36.65089988708496, 39.150861740112305, 50.93532269341605, 38.86888647079468, 37.806048325129915, 40.07789387021746, 37.08537769317627, 38.5583610534668, 37.695547648838584, 38.293273380824495, 37.598974636622835, 37.850607122693745, 37.460444927215576, 36.34772566386631, 37.34458371571132, 35.96704428536551, 40.419217177799766, 38.250347409929546, 37.12726838248116, 38.70188651766096, 39.01726525170462, 36.72247328077044, 39.09494958605085, 38.062412534441265, 39.45296941484724, 38.46276773725237, 39.834998743874685, 40.632902077266145, 39.924026012420654, 39.54703412737165, 43.515108653477256, 39.82354463849749, 41.36045489992414, 41.78604596001761, 40.8315406526838, 40.84339427947998, 43.134104183741975, 42.64046941484724, 43.895324502672466, 44.725196497780935, 43.943517208099365, 46.31864077704293, 48.24009561538696, 52.18384797232491, 55.11930206843785, 56.935644558497835, 63.236013957432334, 60.758077893938335, 55.53127465929304, 2.7963125109672546, 1.9156674231801714, 5.541717742170606, 1.1162000937121255, 0.587679342499801, 48.544294697897776, 73.93576036180768, 68.56004333496094, 75.45501177651542, 69.82506016322544, 53.84393242427281, 34.477597168513704, 51.25467232295445, 62.116388184683665, 76.74046325683594, 16.834385633468628, 0.5550624898501805, 0.18026322286043847, 0.15915224780993803, 0.10205708151417119, 0.10558898520788976, 0.08604185017091887], [0.019889264267736247, 0.038220734268959076, 0.04169486749118992, 0.05224975112027355, 0.10127388925424644, 0.0321074424843703, 0.01990122684011502, 0.024574955692514777, 1.7643334865570068, 44.221858569553916, 51.3410210609436, 39.59853764942714, 29.82037251336234, 31.260140010288783, 32.745855944497244, 45.7924085344587, 55.35187564577375, 51.25456462587629, 56.82056154523577, 18.956869227545603, 0.5054178280489785, 0.2843792103230953, 2.4184996528284888, 0.42134011962584084, 0.06454123317130975, 38.15528563090733, 60.35347039358956, 51.95439413615635, 52.98836251667568, 51.456771101270405, 50.733185700007844, 50.42155204500471, 44.77446617398943, 44.08617067337036, 40.66239023208618, 39.084739208221436, 35.91151775632586, 36.12191615785871, 36.69707414082119, 38.22906507764544, 37.07662296295166, 36.980918475559776, 36.698074681418284, 34.68303108215332, 33.36258847372872, 35.12997743061611, 34.981185231889995, 33.33146401814052, 33.56598309108189, 33.55438307353428, 32.92818362372262, 33.201928751809255, 33.67197091238839, 33.73924684524536, 32.85480717250279, 33.48486287253243, 33.42146403448922, 33.384853976113455, 32.789942264556885, 33.667364256722585, 33.036599840436665, 32.40431376865932, 32.86051859174456, 32.39820630209786, 33.01394176483154, 34.963939802987234, 34.015792097364155, 33.91349376950945, 34.45015525817871, 33.9468103817531, 35.20616790226528, 44.96816110610962, 45.79423243658883, 42.01613555635725, 36.993001392909456, 35.283143520355225, 34.22680194037301, 34.12849882670811, 33.22005312783377, 37.0157914842878, 33.79836211885725, 33.312436376299175, 33.513319219861714, 33.58906848090035, 32.28148351396833, 34.69404745101929, 33.96839496067592, 33.92797728947231, 35.568936824798584, 34.37624726976667, 34.10218252454485, 34.275633880070274, 32.43970789228167, 33.9289048739842, 33.040122577122276, 34.031894547598704, 34.97844416754586, 35.329974378858296, 33.391972405569895, 32.64717762810843, 32.74290990829468, 34.49636772700718, 35.4392625944955, 34.67337308611189, 36.8122683252607, 33.45695890699114, 39.56016274860927, 41.3554139818464, 32.69767018726894, 35.01506812231881, 34.25819737570626, 33.43810149601528, 31.75099549974714, 33.9225993837629, 33.45291158131191, 33.18013225282942, 34.17226900373186, 34.05282946995327, 35.03246293749128, 35.63306174959455, 34.49149009159633, 36.09846946171352, 33.94724464416504, 33.00957134791783, 32.726296765463694, 34.449008805411204, 33.6235419682094, 34.982592242104666, 34.904532705034526, 35.54479878289359, 34.8720429284232, 34.08972440447126, 36.212232317243306, 36.89620951243809, 36.89348929268973, 35.72284984588623, 34.94741003853934, 36.868437562670024, 36.8234201839992, 37.25642497198922, 38.438991001674104, 37.61405222756522, 38.80474417550223, 37.89530488422939, 40.116254874638145, 39.986059529440745, 42.887985093253, 43.47601808820452, 45.60913242612566, 46.07092707497733, 54.069199970790315, 56.49832146508353, 60.31519276755196, 42.90980243682861, 3.0591698118618558, 1.8133063444069453, 1.5968244693108966, 0.3686190886156899, 0.45717930793762207, 44.30206509998867, 62.1430275780814, 59.04228973388672, 62.203803471156526, 52.51439809799194, 43.70465203693935, 19.28037735394069, 31.19604287828718, 52.11833340781075, 55.20339611598423, 5.596178591251373, 0.20003679181848252, 0.034575766285083125, 0.019387660647875497, 0.021695266644071256, 0.04070871862183724, 0.01544356219736593, 0.031128821961049522, 0.016418859595432878, 0.04303431258137737, 0.1247176541281598, 0.046751768461295536, 0.02146604055139635, 0.03127313618149076, 0.03587514727509447, 2.4756277416433607, 52.54708589826311, 56.874076570783345, 44.16056156158447, 30.72394057682582, 23.842667034694127, 41.88249043055943, 51.37492479596819, 61.61949471064976, 53.30259479795183, 63.9844947542463, 20.368784870420182, 0.39742626569100786, 0.23043741339019366, 3.7334247401782443, 0.2057184369436332, 0.05208640059988413, 42.452916690281455, 61.03920895712716, 53.93265744618007, 55.40283720833914, 53.08069712775094, 54.08377034323556, 52.71990496771676, 48.616326672690256, 47.037178312029155, 43.760762214660645, 40.64902189799717, 37.68782820020403, 38.387772355760845, 38.48424114499773, 40.033109256199424, 38.27524280548096, 39.20131261008126, 38.90049730028425, 36.19098472595215, 35.542217527117046, 37.64974512372698, 37.207450594220845, 36.89817932673863, 35.74845743179321, 35.4417222567967, 34.15157726832798, 36.076450620378765, 35.49518864495413, 36.054129532405305, 34.276141098567415, 35.226272514888215, 36.01454217093331, 35.09205763680594, 34.26068830490112, 34.73456934520176, 35.43193571908133, 35.43290499278477, 33.983145986284526, 33.808725357055664, 33.52040638242449, 35.25270346232823, 35.991943155016216, 35.33919811248779, 34.66672713415963, 35.03688893999372, 36.338679109300884, 46.432490485055105, 47.97319793701172, 42.46511425290789, 37.020683016095845, 34.47254582813808, 33.926601546151296, 34.27327496664864, 35.073634488242014, 36.820168427058626, 35.114305768694194, 35.48603439331055, 34.28513554164341, 34.396160806928364, 34.400875159672324, 37.684753622327534, 36.507370948791504, 36.49193205152239, 37.11719349452427, 37.840299470084055, 36.65096936907087, 37.17404365539551, 34.91978747504098, 35.9665961265564, 35.584500789642334, 36.38044820513044, 36.13401297160557, 37.52169329779488, 34.95424706595284, 33.38692453929356, 32.977352551051546, 35.18899890354702, 35.343179430280415, 33.49402754647391, 35.22514690671648, 33.91944490160261, 41.31646932874407, 44.18314668110439, 32.61417021070208, 36.35273878914969, 35.83166905811855, 35.35449457168579, 33.42802313395909, 36.71833215441023, 33.95000307900565, 34.4945855140686, 35.26385532106672, 35.8849652154105, 36.4336644581386, 37.29493883677891, 35.83122784750802, 37.14101539339338, 36.180287974221365, 36.59075280598232, 35.32579503740583, 36.88662794658116, 35.58372606549944, 38.31865167617798, 37.046165534428184, 37.07576486042568, 37.042618479047505, 35.5891352381025, 37.35318211146763, 38.93718726294381, 37.564855507441926, 38.13005324772426, 37.42136478424072, 39.605913162231445, 37.76285137448992, 39.713832582746235, 39.8575074332101, 40.31122132710048, 40.14413799558367, 40.1232864516122, 41.70398426055908, 42.72117274148123, 44.83003786631993, 47.600687640053884, 46.954539912087576, 48.47910669871739, 54.63549205235073, 60.08092730385916, 62.258006368364605, 51.54206371307373, 3.8640274235180447, 1.98653644323349, 2.5946115170206343, 0.37786268975053516, 0.41542885825037956, 47.15014212472098, 67.10402052743095, 65.36169719696045, 67.54144436972481, 57.009170395987375, 49.178335189819336, 25.34303845678057, 42.3096205166408, 56.89678675787789, 65.96084730965751, 8.62692940235138, 0.2762824690767697, 0.07168850715139083, 0.006712729976113353, 0.03444775726114001, 0.03188300006357687, 0.026339735370129347, 0.1086884042514222, 0.13865777610668115, 0.13109156782073633, 0.1769389169556754, 0.28185856129441944, 0.08077565846698624, 0.13640630191990308, 0.13600493488567217, 2.671764531305858, 61.18234879629952, 66.52967548370361, 52.54762090955462, 41.02367571422032, 40.82119131088257, 43.06428868430001, 57.39715085710798, 65.86465644836426, 57.1359680720738, 71.04801954541887, 22.155177150453838, 0.5713966190814972, 0.5938447288104466, 7.92025591645922, 2.030360685927527, 0.17600294575095177, 46.88994598388672, 62.217394147600444, 55.646263871874126, 55.91689273289272, 55.10579129627773, 55.1198023387364, 55.72100217001778, 50.483863489968435, 49.18171548843384, 45.378976821899414, 44.81558908735003, 41.069644996098106, 40.858961718423025, 40.94272572653634, 43.34371049063546, 40.72830779211861, 41.2039224079677, 41.68016583578927, 37.8844587462289, 37.17068420137678, 39.74493619373867, 38.928807735443115, 37.692368847983225, 36.81006227220808, 38.7120030948094, 37.29796825136457, 38.003946917397634, 39.061851842062815, 38.87343406677246, 37.00685262680054, 37.349739279065815, 38.627759660993306, 37.690652642931255, 35.31588690621512, 37.25747067587716, 36.99656234468733, 35.756072657448904, 36.7714580808367, 34.89585787909371, 36.15976994378226, 38.23911912100655, 37.62386308397566, 37.664009775434224, 37.52320800508772, 37.87788575036185, 38.02231100627354, 48.742492062704905, 49.61156579426357, 45.112673214503694, 36.939441204071045, 35.36740779876709, 35.307239873068674, 34.99835770470755, 35.701362541743684, 40.14584725243704, 36.20389447893415, 36.929046698978965, 37.837561879839214, 36.523647103990825, 36.68462296894619, 38.24567474637713, 38.186469146183555, 38.706913539341514, 38.726569993155344, 39.894312041146414, 36.9953498840332, 38.99190780094692, 37.46091740471976, 38.763954775674, 36.879176003592356, 37.50310686656407, 38.191041060856406, 38.55733272007534, 36.31123719896589, 34.15601716722761, 33.75449119295393, 36.20568364007132, 34.93550430025373, 35.79800156184605, 36.42294338771275, 34.20286192212786, 43.14880657196045, 46.48211451939174, 35.5100543158395, 39.01620217732021, 37.87797955104283, 38.312439986637656, 35.2461895261492, 38.56767858777727, 36.21054737908499, 36.61755895614624, 37.180498531886506, 37.99885041373116, 39.574423926217214, 40.22149576459612, 37.82812622615269, 40.709891591753276, 38.96766901016235, 38.94877338409424, 37.156315326690674, 40.95112262453352, 37.42901127679007, 41.51904058456421, 39.53363105228969, 39.275904996054514, 38.95704868861607, 37.76430354799543, 39.556417669568745, 41.94603518077305, 38.87159626824515, 39.35416603088379, 39.19307552065168, 41.79677397864205, 40.01525238582066, 42.482363155909944, 42.992569378444124, 42.814584323338096, 42.9340238571167, 43.35212823322841, 44.650121212005615, 45.99014384405953, 45.88978753771101, 50.543649264744346, 49.06734813962664, 52.40652731486729, 56.969218254089355, 64.18929290771484, 62.06964070456368, 60.40591539655413, 5.898665377071925, 2.6850933475153784, 5.661893350737436, 1.2015596904924937, 0.6440190279058048, 51.36490201950073, 74.87844330923897, 70.4881614957537, 74.54039260319301, 64.09101063864571, 60.78805242265974, 28.626183884484426, 47.599016598292756, 65.35340104784284, 76.46739210401262, 13.232479436056954, 0.4645155742764473, 0.29224353975483347, 0.1783800981938839, 0.10219374525227717, 0.15157374446945532, 0.09250890636550528], [0.03471701013456498, 0.04894206253811717, 0.03240540756710938, 0.0293340221978724, 0.04965876515156456, 0.05285916377657226, 0.06491393888635294, 0.05576202479590263, 0.42269561546189444, 34.20471361705235, 58.91899394989014, 39.085364546094624, 25.2568964276995, 27.83664444514683, 33.99321045194353, 38.97198384148734, 57.187096391405376, 46.92122677394322, 56.16282769611904, 24.28119216646467, 0.08603693079203367, 0.09019613332514252, 2.4903192733015334, 0.060806705350322385, 0.4782918436186654, 45.839277608054026, 57.7868892124721, 52.32044955662319, 49.37055015563965, 47.28705637795584, 48.42661305836269, 46.50654785973685, 41.86892754690987, 43.297994818006245, 40.22175979614258, 38.789478983197895, 36.887475626809255, 35.337450640542166, 35.87396969114031, 37.68297488348824, 36.3327488218035, 36.06905426297869, 35.20123815536499, 36.17574732644217, 33.95901836667742, 34.78758757455008, 32.6506586756025, 33.83863387789045, 33.16772624424526, 33.39072520392281, 33.688424246651785, 32.8296651159014, 32.61649785723005, 32.42421340942383, 32.18187413896833, 33.134364468710764, 31.8526337487357, 33.43058007104056, 32.50834219796317, 34.76729883466448, 33.80045005253383, 33.85080017362322, 31.913308892931255, 32.78127786091396, 33.757927077157156, 34.22682973316738, 32.322644642421174, 34.37802948270525, 34.5573034286499, 36.00821931021554, 34.88801336288452, 43.60552903584072, 43.39265012741089, 42.50916930607387, 37.49689865112305, 36.311678409576416, 33.60989570617676, 31.755657741001674, 32.55251884460449, 33.46301426206316, 34.96822336741856, 34.24459975106375, 32.60937942777361, 33.09366886956351, 33.512975284031455, 32.12244619641985, 34.09589440482003, 34.86237103598458, 33.88166754586356, 34.37722001756941, 33.968096188136506, 33.39291736057827, 33.134854316711426, 33.42551136016846, 32.76309789930071, 33.07935905456543, 34.3859087399074, 34.922632762363975, 34.40226132529122, 35.43668481281826, 33.56734841210501, 34.195201533181326, 34.36666570390974, 36.14950050626482, 34.363813468388145, 35.47972195489066, 41.6349504334586, 41.25638130732945, 34.79015840802874, 34.92913627624512, 34.23686988013131, 34.48347881862095, 33.802489348820274, 34.1505628313337, 32.579884324754985, 33.69929470334734, 34.465868609292166, 34.591804708753315, 33.53885384968349, 33.66332040514265, 34.586461544036865, 33.61464827401297, 33.405392851148335, 32.54629325866699, 33.04478134427752, 32.25247131075178, 33.85143593379429, 34.03495870317732, 35.632127216884065, 37.596070289611816, 35.96324014663696, 36.25932373319353, 36.79552664075579, 36.60465962546212, 35.77980422973633, 37.7209780556815, 36.57720381872994, 37.544549397059846, 36.94273117610386, 37.535759925842285, 38.24122789927891, 38.03099972861153, 40.29235001972744, 39.886071477617534, 40.83164487566267, 41.26575442722866, 42.40672854014805, 44.02485282080514, 45.19019774028233, 47.987823895045686, 53.45981863566807, 55.960749762398855, 58.832537514822825, 44.619198254176546, 2.6752816225801195, 1.5427323090178626, 1.0886989065579005, 0.2936149404517242, 0.7242491713591984, 45.45697035108294, 59.90237249646868, 58.079446588243755, 63.51300389426095, 51.183616570064, 37.04456050055367, 17.782020909445627, 26.396442685808452, 51.846519878932405, 45.89327900750296, 7.362831473350525, 0.27587399099554333, 0.07627055913742099, 0.012932019956809069, 0.04654496116563678, 0.04870374068351729, 0.015829043030472736, 0.036092329371188364, 0.014413581662146109, 0.02434890005471451, 0.032679467861141474, 0.06432793568819761, 0.05856107335005488, 0.05581971723586321, 0.03102441577773009, 0.6491351819464138, 40.858301639556885, 66.48414393833706, 44.41623442513602, 29.900686740875244, 29.430370126451763, 36.012728691101074, 44.863555976322715, 62.988887378147666, 52.21542753492083, 61.25358172825405, 26.460480758122035, 0.18159572993006023, 0.08676613202052456, 3.103173622063228, 0.3853179711316313, 0.7174299487045833, 48.77414805548531, 59.933639390128, 54.67599310193743, 51.496987274714876, 51.28382696424212, 49.203373023441856, 49.19415623801095, 45.1029839515686, 45.94724914005825, 42.35700028283255, 40.42890296663557, 38.10363619668143, 38.267401763371055, 37.6631829398019, 39.16370895930699, 38.95211199351719, 37.86221408843994, 36.5544102532523, 38.12006173815046, 36.358387674604145, 37.78902176448277, 34.52836070741926, 35.377117906297954, 34.761521407536094, 35.16866847446987, 35.94941323144095, 35.61261667524065, 35.51876040867397, 34.89295353208269, 33.52934523991176, 35.63524348395211, 34.1248961857387, 34.98263393129621, 34.26077168328421, 36.40421104431152, 34.80261305400303, 35.16880743844168, 33.72675051007952, 34.081529004233225, 34.408705779484336, 36.229286670684814, 34.05953448159354, 35.48164660590035, 35.92566081455776, 36.28526135853359, 35.92844009399414, 44.59333011082241, 45.803192138671875, 43.912750584738596, 37.48493732724871, 34.903271606990266, 33.13446174349104, 33.02509709766933, 32.90530667986189, 35.795937946864534, 36.44153676714216, 37.070546763283865, 35.003277029309956, 35.44915335518973, 34.389170919145855, 34.796998909541536, 36.43351854596819, 36.29760135923113, 35.67855160576956, 36.198235171181814, 35.77462087358747, 35.2505773135594, 36.53463568006243, 35.003068583352224, 34.62679236275809, 36.4103810446603, 37.011834485190256, 36.80664375850132, 36.107495171683176, 36.02769858496529, 34.32290594918387, 33.74080671582903, 34.510639326913015, 35.76489339556013, 35.411334310259136, 35.92569555555071, 42.811874525887625, 43.04358652659825, 36.630889075142996, 36.39096777779715, 36.01445879255022, 35.65748119354248, 35.731024401528494, 37.679737022944856, 34.461004870278494, 35.98960856028965, 35.30962310518537, 37.15740271977016, 35.980836459568565, 36.02375895636422, 35.343547684805735, 34.89509357724871, 36.4200564111982, 35.78824976512364, 36.41926084245954, 36.53916590554373, 36.03871495383126, 37.20643268312727, 37.52825934546334, 39.1550931930542, 37.06683989933559, 39.39724138804844, 38.35779435294015, 38.31572648457119, 38.85459055219378, 39.791916438511436, 38.52893195833479, 40.39532579694475, 38.187806674412315, 39.46748767580305, 40.44077396392822, 40.97971446173531, 41.296750341142925, 43.00845643452236, 42.016413484300884, 44.281679085322786, 44.266629287174766, 46.49752909796578, 47.81742974690029, 51.939396449497764, 55.01948772157942, 58.589482579912456, 59.821203640529085, 52.37030635561262, 3.155977108648845, 0.3310468947248799, 1.9828172028064728, 0.486089893749782, 0.7559467447655541, 50.6551331111363, 66.73207650865827, 63.33564417702811, 68.65970134735107, 55.518080030168804, 48.65438543047224, 18.682783637728008, 31.32237502506801, 59.45606190817696, 55.114455699920654, 9.132975390979222, 0.24385112790124758, 0.07329254357942513, 0.04906165094247886, 0.03887346799352339, 0.10193614621779748, 0.023447345842474272, 0.1364391158734049, 0.07118279500199215, 0.20188303132142338, 0.14678058666842325, 0.18134174070187978, 0.1512553079852036, 0.20287354317094597, 0.15708386951259204, 0.8059625923633575, 46.592872279030935, 75.68735953739711, 50.55734763826643, 36.86964654922485, 35.53803818566458, 44.235226903642925, 52.49400166102818, 67.94393266950334, 54.59407731464931, 67.17961692810059, 28.613633700779506, 0.23073466601116316, 0.2793033884039947, 7.872899600437709, 1.2208464784281594, 1.2375517934560776, 53.78674874986921, 61.43650695255825, 56.37771463394165, 53.96066910879952, 52.999368463243755, 50.8912467956543, 52.71513850348336, 46.84758281707764, 48.546129022325786, 42.80657305036272, 44.51384619304112, 40.372921330588206, 39.93945448739188, 40.666020665849956, 41.41819790431431, 39.5461482320513, 39.87668793542044, 37.873536178043906, 40.73780945369175, 37.81692573002407, 40.31802708762032, 36.7815294946943, 37.08636086327689, 37.03011519568307, 36.57098170689174, 38.43039608001709, 37.03452035358974, 36.97178159441267, 36.78374249594552, 36.24211999348232, 37.517218657902305, 35.37978948865618, 37.2029481615339, 36.17916931424822, 37.62762205941336, 36.44100522994995, 38.19984095437186, 35.126055172511506, 35.5905248778207, 37.27659559249878, 37.785596302577424, 35.336550848824636, 37.61244024549212, 37.40419231142317, 39.36215993336269, 38.78390652792794, 47.51173332759312, 46.330421447753906, 44.92690617697579, 38.42045668193272, 36.71064397266933, 33.92503820146833, 33.15434053965977, 34.168874808720176, 37.03902278627668, 36.79177461351667, 36.7332638331822, 37.19197348185948, 37.253155844552175, 37.458763463156565, 36.42677531923567, 39.24638557434082, 37.979902676173616, 37.74470962796892, 39.16852753502982, 38.11071988514492, 37.861137117658345, 39.46632037843977, 36.78617089135306, 36.98994765962873, 36.40691041946411, 38.32734039851597, 38.499190194266184, 38.7722613470895, 37.03552784238543, 33.44878435134888, 33.65440239225115, 35.753029346466064, 36.226430961063926, 36.0301547731672, 35.588343143463135, 45.53574207850865, 45.56933314459664, 38.712215014866416, 39.182416984013145, 37.92663778577532, 37.08245597566877, 37.902607440948486, 40.30958502633231, 34.87717417308262, 37.44957447052002, 37.35623237064907, 38.40711266653878, 37.39446830749512, 38.418816907065256, 37.588232721601216, 36.80491713115147, 38.06727279935564, 37.802800042288645, 39.1496319089617, 37.04740578787667, 38.84862552370344, 39.16412932532174, 40.19323396682739, 43.24378844669887, 39.71154662540981, 41.06787667955671, 41.57268067768642, 41.38470411300659, 40.7290894644601, 43.21341439655849, 41.128068923950195, 42.02384458269392, 39.92438384464809, 40.598532812935964, 42.19645868028913, 43.46016577311924, 44.929164341517854, 45.05858496257237, 44.24650730405535, 45.63517427444458, 46.85750137056623, 49.87357888902937, 50.26098264966692, 54.24569811139788, 57.35938739776611, 61.57438005719866, 61.87056786673409, 59.256461007254465, 5.606054152761187, 1.895543485879898, 4.376792754445757, 0.830247089266777, 1.096712893673352, 54.56966134480068, 72.12391335623605, 69.73975018092564, 75.4318117414202, 61.45022964477539, 53.685065337589805, 25.944891418729508, 40.49991355623518, 65.26378318241665, 67.48428848811558, 12.833113483020238, 0.3218999169766903, 0.10784552126590695, 0.12007207769368376, 0.15839029369609697, 0.24536947214177676, 0.10218495143843548], [0.04472587324146714, 0.028732209133782556, 0.041624245566448996, 0.042504434407289536, 0.06663293271724667, 0.07274479618562119, 0.04417831923014351, 0.12867382541298866, 0.06933793292513915, 26.719388008117676, 56.53888157435826, 42.79728330884661, 35.478443486349924, 27.64312842914036, 37.88123825618199, 36.830628940037315, 56.53125245230538, 48.358187198638916, 58.24188157490322, 32.591314111437114, 0.01304549815332783, 0.21138166662837776, 1.3122260378939765, 0.3603664743048804, 3.7287481682641164, 57.2545599256243, 54.40486397062029, 53.607057912009104, 49.98882865905762, 46.82007837295532, 42.61675868715559, 42.30770976202828, 41.52717692511422, 40.35715586798531, 39.50229467664446, 38.04928738730294, 36.41800321851458, 36.39859342575073, 35.76807219641549, 37.07964195523943, 34.93701900754656, 33.95448119299752, 35.1335904938834, 34.70081499644688, 35.11159944534302, 34.62706681660244, 32.94112811769758, 31.73221104485648, 32.273604256766184, 35.96656138556344, 34.96018082754952, 32.533741337912424, 33.12130185535976, 33.060668400355745, 33.67093563079834, 32.03535747528076, 32.0878198487418, 33.26058891841343, 33.2526228087289, 34.14328459330967, 33.32284130368914, 33.09017045157296, 32.030643122536794, 31.52750321796962, 33.21123933792114, 34.772860867636545, 33.124459811619346, 34.93040779658726, 35.910520689828054, 33.24933978489467, 33.023769991738455, 41.11075053896223, 43.95499563217163, 44.87241840362549, 37.242281913757324, 36.052079813820974, 34.84757832118443, 33.69497292382376, 32.7852452823094, 35.28356041227068, 34.505674839019775, 35.269028254917686, 33.29770966938564, 31.40135519845145, 32.1181035723005, 33.89087390899658, 33.12353917530605, 34.10246045248849, 33.33553218841553, 34.49585008621216, 34.526144232068745, 34.44546175003052, 33.20561477116176, 33.08533797945295, 33.034438950674875, 34.11942795344761, 35.13040821892874, 35.840976170131135, 34.19469778878348, 33.793880530766074, 33.89020340783255, 35.356273310525076, 34.80774777276175, 36.04628849029541, 33.6016377721514, 40.41687910897391, 42.16957957404, 41.33530242102486, 36.879749229976106, 33.37761742728097, 36.292108808244976, 33.332537514822825, 34.40254620143345, 33.33383335386004, 33.15400355202811, 32.34400340488979, 34.27841663360596, 33.29292236055647, 34.43064819063459, 34.096113273075645, 34.61777707508632, 35.12004845482962, 35.093648774283274, 34.22066668101719, 34.352581705365864, 34.766968795231406, 34.51765700748989, 34.391324860709055, 35.3635584967477, 35.42272935594831, 36.64250646318708, 36.96851246697562, 38.1885848726545, 36.74217142377581, 37.21858160836356, 37.38465050288609, 37.11792305537632, 36.60468047005789, 38.110973494393484, 38.86171245574951, 38.40057441166469, 40.6704466683524, 40.330453940800254, 42.14920745577131, 40.841393198285786, 41.75419889177595, 44.10939155306135, 45.45736639840262, 46.782829080309185, 48.960738454546245, 57.06612477983747, 58.394439697265625, 61.60274955204555, 43.60107176644461, 1.1186363058430808, 0.08270254185689346, 0.9833743125200272, 0.6423558028680938, 1.4437018058129718, 52.21207850319998, 56.935971123831614, 59.694892338344026, 63.63293675013951, 54.2798068182809, 27.769807985850743, 24.188327755246842, 39.72458144596645, 48.0757394518171, 53.51206908907209, 5.237169946943011, 0.13046415363039288, 0.052632706106773446, 0.03650580147015197, 0.06729970872402191, 0.01883015761684094, 0.05833456479012966, 0.049896323654268465, 0.010617085782411908, 0.012546348285728266, 0.055319463900689564, 0.014566289360768028, 0.05892594198563269, 0.05715820219899927, 0.10940599574574403, 0.05748383115444865, 30.961940697261266, 65.61611243656704, 47.50525760650635, 39.43813501085554, 27.30174606187003, 39.34098529815674, 43.29768909726824, 59.76580565316336, 52.89815405436924, 63.160931723458425, 34.042681625911165, 0.0312855669430324, 0.1401935044143881, 1.0574319043329783, 0.3413149208894798, 4.469601580074855, 60.82378005981445, 55.66305071966988, 56.36057342801775, 50.94313594273159, 49.74659013748169, 44.88126693453108, 44.38578394481114, 42.33041647502354, 43.9030613218035, 40.73680543899536, 40.3095954486302, 37.85422018596104, 38.631000995635986, 37.72767611912319, 39.13298055103847, 38.30867753710066, 36.37346179144723, 36.39439671380179, 36.90626702989851, 35.488646915980745, 36.33838728496006, 34.238704204559326, 33.76521921157837, 35.041613715035574, 37.5326714515686, 36.92106669289725, 35.648590973445344, 35.848334312438965, 36.22940131596157, 35.5552453994751, 33.62386505944388, 33.590676988874165, 35.77134827205113, 35.38249233790806, 35.43478100640433, 33.780755383627756, 34.683051926749094, 32.82416214261736, 32.95088686261858, 35.43460382734026, 34.979555879320415, 34.37172399248396, 35.83744995934622, 37.10299137660435, 35.032275336129324, 34.272420338221956, 42.93961715698242, 46.66161775588989, 44.03491381236485, 37.25067186355591, 35.85088777542114, 35.36328056880406, 34.036456039973665, 33.1899847984314, 34.55114732469831, 36.91592155184065, 37.08591617856707, 35.18134198869978, 34.25749213354928, 34.03568826402937, 34.870906897953574, 36.079862185886924, 35.69704076222011, 35.435593945639475, 35.59496130262102, 35.601909501211985, 36.08844321114676, 35.139920302799766, 36.47415508542742, 34.76426942007882, 36.440657820020405, 36.61418560573033, 37.38261815479824, 35.31353146689278, 33.971681458609446, 34.886762687138145, 35.739376136234824, 34.05197484152657, 33.72379057747977, 32.75633382797241, 39.209695611681255, 44.411780629839214, 43.770444529397146, 39.09730502537319, 34.42043086460659, 35.82738549368722, 34.88143341881888, 36.48938206263951, 34.24416548865182, 34.665379183632986, 34.59103345870972, 34.52519580296108, 34.82679278509957, 36.69466311591012, 35.88046625682286, 35.48565571648734, 36.115718364715576, 37.31868083136422, 36.27228559766497, 35.94861766270229, 37.479111262730186, 35.61409316744123, 34.7622891834804, 37.5622673034668, 37.79593522208077, 38.61502013887678, 39.746520383017405, 39.018658365522114, 38.62358379364014, 38.4374554497855, 40.34181077139718, 38.10503625869751, 38.536133766174316, 40.9715016910008, 40.74036291667393, 40.47629662922451, 42.085127694266184, 43.018364565713064, 44.11735766274588, 43.360076972416465, 43.31644228526524, 45.65889889853341, 47.2593434878758, 49.065399169921875, 51.288072313581196, 58.589885575430735, 61.060303688049316, 61.7593480518886, 49.14436892100743, 1.3134965811456953, 0.1204864861709731, 1.3123050736529487, 0.5684401605810437, 1.5806801127535957, 55.35877520697457, 63.186382974897114, 64.58297783987862, 67.95664092472622, 59.82824911390032, 40.13720716748919, 25.15076790537153, 43.22514990397862, 54.21919073377337, 62.01438862936837, 7.556053059441703, 0.16211893861847265, 0.0845114958605596, 0.013203180361805218, 0.0633731826341578, 0.04520374170637556, 0.04301761383456843, 0.14733689038881234, 0.14239706045814923, 0.10344541844512735, 0.16814370533185347, 0.14560480761740888, 0.23550360011202948, 0.1386207959481648, 0.27254409396222656, 0.13880020060709544, 35.36310338973999, 71.96042224339077, 55.47240604673113, 48.07691369737898, 36.21911103384835, 50.81460121699742, 48.66570404597691, 65.2466072354998, 58.17020395823887, 70.52822480882917, 38.743798051561626, 0.14563189473535332, 0.4343343637883663, 6.170493670872279, 1.0891731211117335, 5.849933751991816, 63.271783283778596, 57.3703099659511, 58.25197383335659, 53.978828225817, 50.8864803314209, 45.69662414278303, 44.90341779163906, 44.852442332676475, 45.901884351457866, 44.12550442559378, 42.270335401807515, 40.92978123256138, 40.443237100328716, 41.138529436928884, 42.14926651545933, 39.821689469473704, 37.51994235174996, 40.10824012756348, 39.36213214056832, 39.3032739503043, 38.57952874047415, 36.60909257616316, 35.298235007694785, 38.063680580684114, 42.17675706318447, 40.60952138900757, 37.950188704899375, 38.13055351802281, 38.17832933153425, 38.70012862341744, 36.20574269975935, 34.736045837402344, 37.282946246010916, 37.19141067777361, 37.04287903649466, 36.06847408839634, 37.909500053950715, 35.091418402535574, 34.38742344720023, 37.85451895850045, 38.32266773496355, 37.196840694972444, 39.010365690503804, 39.87707356044224, 36.40097318376814, 36.4290578024728, 44.55478845323835, 46.83021926879883, 45.80604090009417, 38.38114377430507, 36.78369385855538, 35.53411940165928, 33.985091481889995, 36.00884812218802, 36.49566323416573, 39.22035067422049, 39.83161844526018, 36.82089103971209, 35.47650841304234, 36.586872237069265, 35.9437643459865, 36.84391736984253, 38.008887086595806, 38.17048134122576, 37.1264728137425, 38.435954638889854, 37.803057125636506, 36.34971284866333, 39.15571158272879, 36.59984104973929, 38.872252873011995, 39.49074329648699, 38.66074275970459, 36.47645146506173, 35.51065533501761, 36.67521858215332, 34.86714792251587, 36.598149163382395, 35.46583250590733, 34.46489586148943, 40.63874898638044, 48.8951335634504, 45.12558991568429, 41.052760873522075, 37.39241164071219, 39.48729004178728, 36.11406469345093, 37.085433278764995, 37.77876622336251, 36.09260170800345, 36.12377827508109, 36.54506492614746, 36.65303645815168, 38.225333895002095, 38.77209111622402, 37.02783618654524, 38.308194637298584, 40.08813204084124, 39.08057376316616, 38.76271799632481, 39.777432918548584, 39.47417879104614, 37.438551153455464, 40.02400016784668, 40.20805447442191, 41.64793314252581, 42.17369638170515, 41.69420467104231, 41.253556864602224, 41.926778248378206, 43.22857883998326, 40.11869369234358, 41.84880903788975, 43.78517123631069, 42.45213849203927, 42.41423954282488, 45.89383486339024, 44.25643975394112, 47.1137752532959, 45.735593114580425, 46.13798066547939, 48.685867718287874, 50.68520491463797, 50.97089399610247, 54.51316901615688, 61.95526640755789, 64.1266062600272, 64.5009821483067, 53.04296840940203, 2.5803240665367673, 0.5196749887296132, 3.9808084028107777, 1.3452368208340235, 2.0614089284624373, 61.21193422589983, 68.09158188956124, 70.68035561697823, 72.60353360857282, 65.56480693817139, 41.196644169943674, 36.37462214061192, 56.465838636670796, 60.96993541717529, 76.6479549407959, 10.806103348731995, 0.3094033646796431, 0.17247980194432394, 0.18020459743482725, 0.20793716503041132, 0.11757482455245086, 0.10462750787181513], [0.008253063840259398, 0.04912807273545435, 0.02268137819399791, 0.043922077265701125, 0.08650974756372826, 0.08823058700987271, 0.030128746160439084, 0.07858569347964865, 0.12364490383437701, 18.77556119646345, 60.16359697069441, 43.94869014195034, 28.035890987941197, 15.654545034681048, 33.29096296855381, 37.63934367043631, 50.98075348990304, 52.27777372087751, 52.82554537909371, 42.09643588747297, 0.5609496225203786, 0.48596080924783436, 0.6020498456699508, 0.4505146827016558, 18.029487950461252, 64.03074196406773, 52.527339117867605, 55.21321044649397, 50.59396117074149, 48.750704833439414, 44.86190925325666, 42.446117877960205, 38.0798351424081, 39.676555497305735, 37.00317702974592, 37.515005656651084, 35.62300075803484, 34.775751318250386, 35.11374296460833, 36.04151160376412, 35.311895166124614, 34.72087444577898, 33.89814172472273, 35.105387755802695, 33.01861790248326, 32.75544098445347, 33.42277029582432, 32.73017038617815, 33.196620328085764, 34.904720306396484, 33.23175389426095, 34.23386478424072, 33.00305393763951, 32.698031493595664, 31.177070822034562, 32.18083538327898, 32.7584182875497, 32.79155077253069, 33.308955328805105, 32.47762073789324, 32.16858570916312, 31.86127383368356, 31.900190693991526, 33.79676055908203, 35.3123641695295, 33.9096861566816, 33.97925499507359, 34.502183369227815, 34.83359854561942, 33.46396616527012, 31.58018445968628, 40.81544862474714, 46.451167242867605, 44.76066705158779, 36.65348809106009, 36.74722971235003, 36.61316074643816, 33.304734298161094, 32.26130594526018, 33.11956480571202, 34.910261494772776, 34.48361430849348, 33.45336321422032, 32.69107634680611, 33.134691034044536, 31.140276636396134, 32.742520809173584, 35.10181985582624, 33.83493743624006, 34.94379350117275, 33.571270670209614, 34.29517568860735, 33.64061369214739, 33.35482038770403, 33.55062757219587, 33.14896263395037, 35.268017292022705, 36.13047981262207, 34.9048627444676, 33.177231379917686, 33.84195859091622, 35.267923491341726, 35.81858212607247, 35.05852563040597, 36.76675762448992, 41.09834105627877, 41.812351839882986, 44.14023460660662, 36.08166176932198, 34.31896979468209, 34.234097548893516, 34.416525976998464, 34.49155609948294, 33.31722021102905, 32.54747097832816, 33.550123827798025, 34.01524666377476, 34.77413238797869, 34.76926170076643, 34.49317850385393, 33.686127867017476, 32.9125189099993, 33.447933197021484, 34.93851287024361, 34.97687387466431, 33.728119305201936, 34.251461097172324, 34.540412357875276, 34.62315150669643, 36.81722933905465, 37.34308637891497, 36.906555380140034, 36.4292106628418, 35.60503271647862, 36.504404067993164, 36.89159938267299, 35.545055866241455, 36.47612489972796, 37.19409268242972, 35.87527595247541, 37.36883292879377, 38.63277278627668, 41.84897926875523, 41.25946283340454, 41.90444673810686, 41.44081081662859, 41.84938226427351, 42.82263033730643, 48.82696826117379, 53.15076971054077, 53.90099450520107, 58.39261926923479, 61.54477378300258, 41.79933091572353, 0.07904509561402456, 0.20376721450260707, 0.7726757270949227, 0.27615134896976606, 2.096171200275421, 56.54964085987636, 55.06280973979405, 60.078905378069194, 63.728481428963796, 52.45108263833182, 32.068955489567344, 24.918534789766582, 35.88869987215315, 51.82504994528634, 49.7867750440325, 2.9377565554210117, 0.1558836903423071, 0.08236185620938029, 0.0337094229512981, 0.023695874560092176, 0.03825256773935897, 0.039453842743699036, 0.07532159398709025, 0.10953186399170331, 0.033970316273293326, 0.035553592922432084, 0.05444955486538155, 0.09908894542604685, 0.056935893770839484, 0.11642328277230263, 0.10255666649235146, 22.986741031919205, 64.93459837777274, 50.19573559079851, 35.245515550885884, 20.306381361825125, 39.31435285295759, 41.0005521093096, 55.53033665248326, 55.68631328855242, 57.343747002737864, 44.719811643872944, 0.5717209045376096, 0.16779393410044058, 0.6572975782411439, 0.43403795255081995, 20.077452114650182, 68.41677148001534, 55.46601022992815, 57.40018374579293, 52.293785844530376, 51.220473289489746, 46.42651850836617, 44.59881223951067, 39.816846575055806, 42.90344136101859, 40.11733184541975, 40.05446801866804, 36.93121106284005, 37.41975280216762, 37.46650375638689, 38.316838196345735, 36.19033506938389, 36.12697792053223, 36.461332184927805, 35.47783204487392, 34.45530039923531, 34.509704794202534, 34.84804385049002, 33.99883154460362, 35.063250405447825, 36.58288049697876, 33.964048862457275, 36.14647109167916, 36.84499086652483, 35.97830384118216, 33.5249331338065, 35.60565805435181, 34.93608794893537, 34.856597082955496, 34.32128701891218, 35.11976705278669, 35.64898354666573, 33.494840485709055, 34.16298621041434, 35.48234142575945, 35.431880133492605, 35.61917577471052, 35.71539095469883, 36.30048486164638, 36.8291072845459, 35.634923866816926, 34.1578688621521, 42.383243628910606, 46.2213625226702, 46.85719912392752, 36.99454389299665, 36.937485286167686, 37.84859561920166, 33.52223375865391, 32.55910921096802, 33.608040537152974, 34.84395830971854, 36.15877635138375, 35.99144983291626, 34.33362007141113, 35.849783011845176, 34.02761098316738, 35.45895378930228, 36.434713636125835, 35.63804013388497, 37.30435364586966, 34.29971981048584, 36.70408139910017, 36.231489249638145, 33.51193305424282, 34.49241420200893, 35.03430421011788, 37.995595182691304, 37.40313965933663, 36.05998338971819, 34.62823758806501, 34.33433920996529, 34.81283385413033, 35.59868206296648, 35.210958685193745, 35.47595255715506, 42.77275616782052, 44.586611202784944, 46.79378291538784, 36.923286642347065, 36.290198053632466, 36.25115959984915, 35.33689131055559, 35.51444557734898, 35.60994509288243, 35.33727693557739, 35.10742705208914, 35.34062944139753, 35.7547663961138, 37.44313696452549, 35.5564717565264, 35.89002002988543, 34.81092309951782, 37.0931179864066, 36.466331413814, 36.41189227785383, 35.77983897072928, 37.21840442929949, 37.60113205228533, 37.14087642942156, 37.83225345611572, 39.34641184125628, 39.33908496584211, 38.91245862415859, 38.27294642584664, 38.09026786259243, 38.940960134778706, 39.002392632620676, 38.64870153154646, 39.67512764249529, 38.54877948760986, 40.027151175907676, 39.93988527570452, 43.2425342968532, 43.32773658207485, 42.62209142957415, 44.18200717653547, 43.73269149235317, 45.27717529024397, 49.7391242980957, 55.66670547212873, 56.66692992619106, 60.56554331098284, 64.00711808885846, 45.09256860188076, 0.40426950848528315, 0.5889310496194022, 2.058339995997293, 0.7805434220603534, 2.3371488409382954, 59.2829475402832, 60.650992257254465, 64.902268409729, 70.0511337007795, 56.96230479649135, 33.4646748815264, 25.26262174333845, 44.4807310785566, 57.896538734436035, 59.99206679207938, 3.3463362540517534, 0.23096303375703947, 0.06552186555096082, 0.06458090711385012, 0.00921327740486179, 0.014950092516041227, 0.032595665393663306, 0.14005713244634016, 0.1802431382238865, 0.10694387036242656, 0.11428082202162061, 0.12582500970789365, 0.1865894626826048, 0.12457385898700782, 0.21935511806181499, 0.2496216068310397, 27.23873805999756, 77.33618095942906, 57.78332826069423, 42.09123863492693, 27.079021556036814, 43.264275210244314, 49.116412843976704, 59.54590211595808, 58.73819487435477, 60.78501605987549, 51.08970471790859, 0.8424358037965638, 0.7296708290066037, 4.036342748573848, 0.9485187828540802, 23.936712639672415, 69.05585289001465, 57.26723343985421, 60.372682162693565, 54.26378774642944, 53.30584308079311, 50.18405219486782, 47.30685526984078, 42.97812754767281, 43.46078763689314, 41.567504269736155, 42.064057282039094, 39.40554448536464, 39.133814334869385, 39.675871099744526, 41.15305812018258, 38.72258867536272, 38.80553279604231, 39.9950852394104, 38.370881284986226, 37.264415400368826, 36.83921691349575, 37.799600396837505, 37.21487821851458, 37.82618767874581, 39.43410505567278, 37.10452345439366, 39.018074716840474, 38.22238438470023, 37.65488331658499, 35.8681366784232, 38.27499961853027, 37.511962345668245, 37.47451850346157, 36.1025515283857, 37.06435244424002, 36.722660882132395, 35.19195883614676, 35.38058853149414, 36.69301986694336, 37.32265520095825, 37.03459678377424, 36.821412154606406, 37.77940893173218, 38.221981389181956, 37.21783120291573, 35.33733946936471, 43.543071678706575, 50.39067425046648, 47.431988852364675, 37.19359936032976, 36.92449562890189, 38.51718602861677, 35.11095673697335, 33.597183976854595, 34.03998572485787, 37.20229850496565, 37.436244351523264, 37.11501176016671, 36.624903202056885, 37.65327133451189, 34.29585313796997, 36.30183628627232, 38.86911923544747, 36.916810921260286, 39.63116986410958, 37.19759110042027, 39.002906799316406, 37.85974400384085, 35.42872217723301, 36.32513359614781, 36.57742616108486, 40.40995175497872, 39.22368928364345, 37.86627531051636, 34.39683478219168, 33.98707866668701, 35.464345591408865, 35.767547607421875, 36.343414306640625, 36.24518762316023, 45.91367197036743, 47.402368681771414, 48.03967482703072, 39.78983545303345, 39.49120535169329, 39.47323036193848, 37.808824130467, 37.763970034463064, 36.989631516592844, 36.35168266296387, 37.35964046205793, 38.4764278956822, 37.69899048124041, 39.23190205437796, 38.00157758167812, 37.74850681849888, 37.267083508627756, 38.48339693886893, 39.068942478724885, 39.53766448157174, 37.852295534951345, 39.66614709581648, 39.01603889465332, 38.615040983472554, 41.25048228672573, 42.0124808038984, 41.781668594905305, 42.47633906773159, 39.559158733912874, 40.859774657658164, 41.99057313374111, 40.33576931272234, 41.588025774274556, 40.89239992414202, 40.64135456085205, 42.566495418548584, 42.576556410108296, 47.09104422160557, 45.0793114389692, 46.27786874771118, 47.4473408971514, 46.13387428011213, 48.6906133379255, 52.865740707942415, 58.052605697086875, 59.46895776476179, 64.1698796408517, 66.85977745056152, 48.998915331704275, 1.2493361553975513, 1.3210839054414203, 6.217915994780404, 1.009599853839193, 3.1804406302315846, 64.4551031930106, 65.1344633102417, 70.212616784232, 75.12769603729248, 62.70600536891392, 43.465630531311035, 36.02451631001064, 53.468799182346885, 64.94865458352226, 70.16154057638985, 5.543210302080427, 0.3829886146954128, 0.11875299204673086, 0.1753020869301898, 0.1155522202274629, 0.19518006885690348, 0.13605522790125438], [0.0411443482818348, 0.05458113976887294, 0.05518576196793999, 0.14486563870949404, 0.016769730053575974, 0.12617172753172262, 0.06972906765128885, 0.06896352408719914, 0.13698775214808329, 12.449057017053876, 57.85983487537929, 45.304870809827534, 27.699801410947526, 24.640221221106394, 37.25653614316668, 39.5030311856951, 54.75477525166103, 55.86903006689889, 49.1100309235709, 51.75399766649519, 3.0719744733401706, 0.41770786738821436, 0.26781744616372244, 0.006620827496850065, 34.77112034388951, 62.511782373700825, 52.245881489345, 52.76371683393206, 49.82517078944615, 46.36950853892735, 45.51621764046805, 43.48365068435669, 40.455927985055105, 40.95433269228254, 39.906394958496094, 37.09589726584298, 34.48009157180786, 36.6474848474775, 35.87684971945626, 34.15774379457746, 35.18320063182286, 35.45420816966465, 33.25693416595459, 32.737323556627544, 33.841552121298655, 31.523226601736887, 32.2805871963501, 33.66348368780953, 32.46774387359619, 32.72639056614467, 31.905790942055837, 32.53786856787545, 32.0653841154916, 32.53226137161255, 32.58295890263149, 32.341279711042134, 32.61408683231899, 33.45771278653826, 33.409242153167725, 32.77627515792847, 32.623008319309776, 33.32144471577236, 32.38958011354719, 32.617102350507466, 34.01488535744803, 32.70308630807059, 32.65039116995675, 33.56534038271223, 33.29772703988211, 33.19235413415091, 33.472689628601074, 39.389740807669504, 45.37034715924944, 44.8065390586853, 40.59494406836373, 36.49282489504133, 35.82213265555245, 34.07124219621931, 33.66284792763846, 33.576638153621126, 33.071705613817485, 36.83649321964809, 35.15086371558053, 32.45580339431763, 33.10556418555123, 33.91163860048567, 33.534500803266255, 35.04436867577689, 34.4895897592817, 33.13717154094151, 33.412903853825156, 32.5520463671003, 31.48170416695731, 34.05219023568289, 34.58776780537197, 35.05407183510916, 34.30216210229056, 33.89096770967756, 33.6938716343471, 34.03891570227486, 34.41207912990025, 35.260461126055034, 34.62313413619995, 35.04933316367013, 35.94776998247419, 38.7952355657305, 46.183904784066335, 41.416957650865825, 34.33644451413836, 32.71020473752703, 33.9401262147086, 33.99228286743164, 34.90193060466221, 34.23883622033255, 32.41792181559971, 33.62590782982962, 33.5609004838126, 33.61257076263428, 35.10854571206229, 34.57858576093401, 33.93576622009277, 34.75181130000523, 35.36559084483555, 33.225354603358674, 34.84100532531738, 33.70777497972761, 33.047883714948384, 33.27502032688686, 34.80705990110125, 33.51181493486677, 32.341092109680176, 34.68198537826538, 35.72718204770769, 37.51921279089791, 37.4541255405971, 35.28593669618879, 36.6236629486084, 35.257178102220806, 35.79095261437552, 36.15604223523821, 39.13339049475533, 38.23900100163051, 40.279964855739046, 39.73512533732823, 39.7841830934797, 41.76443011420113, 41.70984506607056, 45.39219924381801, 53.17486606325422, 54.332474163600374, 56.355629784720286, 55.34581681660244, 59.54360921042306, 43.7628744670323, 0.21170831338635512, 0.3928956059472901, 0.5834938128079686, 0.6361119236264909, 2.5243022612162997, 56.63772317341396, 55.25317301068987, 61.655222347804475, 60.378907748631065, 50.30308525902884, 34.080104623522075, 18.84000747544425, 33.53850643975394, 50.15722867420742, 48.35356317247663, 2.296788058110646, 0.1652662418782711, 0.016203574004716108, 0.014480246031390769, 0.01925530899981303, 0.014345321039270078, 0.03607640754697578, 0.0771670328187091, 0.10441881764147963, 0.02281506994872221, 0.11338216345757246, 0.031714496069720814, 0.02006679617001542, 0.06931348530841724, 0.11342500615864992, 0.1387307457625866, 15.065542766026088, 65.37815053122384, 48.99381535393851, 33.53978490829468, 22.140004021780832, 36.60359307697841, 43.698360443115234, 58.253547600337434, 58.98958764757429, 55.34127269472395, 55.63404199055263, 3.018842250108719, 0.5554509375776563, 0.20874128331031117, 0.017965873636837517, 36.80245052065168, 63.504728589739116, 54.57705075400216, 55.56252418245588, 50.816074235098704, 47.64176191602434, 46.65531921386719, 45.396170139312744, 41.852251870291575, 42.583070346287315, 41.47322416305542, 39.39615052086966, 38.13397550582886, 37.661748136792866, 38.5244642666408, 35.37359516961234, 37.4299874986921, 36.86714172363281, 33.957333428519114, 35.728634221213206, 35.911180768694194, 33.36387389046805, 34.504038538251606, 35.130686146872385, 34.1960631098066, 36.1215374810355, 33.90948118482317, 35.78667599814278, 34.990002495901926, 34.93073088782174, 35.19567959649222, 34.65248332704817, 35.145878383091514, 35.016079085213796, 35.013334546770366, 34.76933118275234, 35.77897392000471, 35.2646404675075, 34.38209070478167, 33.15948568071638, 34.75035217830113, 33.206156730651855, 33.729696546282085, 34.562889780317036, 35.77426651545933, 35.92352076939174, 34.77598408290318, 41.486321517399375, 47.4948422568185, 44.64462171282087, 40.26600245067051, 35.42198589869908, 35.77781704493931, 33.185874938964844, 35.154636587415425, 34.59615428107125, 36.3153783253261, 36.793438707079204, 37.19596522194998, 34.81125661305019, 34.88625199454171, 35.37095832824707, 35.83359023502895, 36.582077980041504, 37.736024379730225, 35.12946673801967, 35.223673888615195, 34.32938167027065, 34.59207221439907, 35.14179284232003, 34.569129262651714, 37.941545145852224, 36.16408477510725, 34.90348352704729, 34.75979478018624, 34.7589054107666, 35.484481470925466, 34.80497544152396, 35.13903093338013, 35.363638401031494, 36.813001360212056, 42.03281818117414, 48.007931981767925, 43.76382637023926, 37.237015179225374, 33.77539832251412, 36.46454920087542, 35.3423421723502, 36.34286887305123, 35.199261392865864, 34.36466114861624, 34.99523448944092, 34.575500760759624, 36.45404699870518, 37.17580502373831, 36.01001194545201, 35.52578156335013, 37.21435362952096, 36.00376551491873, 36.76058415004185, 35.02561896187918, 35.427961349487305, 36.067129611968994, 35.52968645095825, 35.88739708491734, 35.555328777858186, 35.22855499812535, 36.576745237622944, 37.43929461070469, 40.716433320726665, 38.95788942064558, 37.291409151894705, 37.93961007254464, 38.119019508361816, 38.224868365696494, 38.07921327863421, 40.201200076511924, 40.868942805698936, 43.17241307667324, 42.415452003479004, 43.3060234614781, 43.10553666523525, 43.18093851634434, 48.53995554787772, 54.35967288698469, 55.91095897129604, 58.6241888318743, 58.67509133475167, 58.72514615740095, 45.78400468826294, 0.6543744493808065, 0.3827349511640412, 2.0465962375913347, 0.8652545022112983, 3.200175468410764, 59.460779735020225, 60.65467480250767, 64.56783771514893, 64.88088880266461, 58.29583086286272, 37.53135476793562, 21.996843338012695, 40.648226329258506, 55.861911637442454, 59.31748008728027, 3.8286254831722806, 0.20516688296837465, 0.05985033059758799, 0.08720834007752792, 0.05596361754994307, 0.040618575244609795, 0.010971445606888404, 0.1405669158058507, 0.2035534352596317, 0.1340649082724537, 0.24592644082648413, 0.1232678419245141, 0.15761140334819043, 0.16386611200869083, 0.20476612661566052, 0.23342665870274815, 18.994841132845195, 74.86381040300641, 56.36298097882952, 40.136946610042024, 35.793023177555625, 48.335942540849956, 49.249422209603445, 65.28207084110805, 65.01280035291398, 58.69269112178257, 60.95485087803432, 3.675386437347957, 0.9548104852437973, 1.2445413555417741, 0.12531821190246514, 40.19450896126883, 64.92873409816197, 57.949602127075195, 58.67732865469796, 54.55324969972883, 50.80540875026158, 50.482362679072786, 47.67841018949236, 44.93109246662685, 44.585933753422324, 45.30982487542288, 41.400955949510845, 39.192801066807334, 40.86193902151925, 40.00705003738403, 38.0156546320234, 38.50833749771118, 39.97699907847813, 38.58808197293963, 38.04306180136544, 38.78874594824654, 35.90604952403477, 37.6554982321603, 37.86711604254586, 36.26005329404558, 37.14821025303432, 37.84803976331438, 37.49428612845284, 36.685984815870015, 37.57121658325195, 38.01292746407645, 36.9503880909511, 36.5212847164699, 37.281323841639924, 36.445382595062256, 36.13728209904262, 37.36791229248047, 37.71645130429949, 35.8028062411717, 35.108142716544016, 37.15989364896502, 34.04179573059082, 35.355918952396934, 36.70140634264265, 36.68064859935215, 37.31160756519863, 37.01809481212071, 44.15051794052124, 50.184674058641704, 47.30505221230643, 42.494953291756765, 36.075561250959126, 36.19584846496582, 34.56278208323887, 36.38313020978655, 36.73957279750279, 36.10011618477957, 40.25463172367641, 39.93114096777779, 37.39866501944405, 36.845286164964946, 38.656441824776785, 37.01467282431466, 38.818230628967285, 40.68837302071707, 37.180446420397075, 38.62632485798427, 36.039955207279746, 35.95315136228289, 37.52172803878784, 37.089748110089985, 39.29818786893572, 37.72104058946882, 36.76013599123274, 36.52783339364188, 36.61603382655552, 35.16105324881417, 36.30440364565168, 34.47874362128121, 34.583407810756135, 37.803408009665354, 42.48223808833531, 50.045508589063374, 46.16867780685425, 39.727680342538015, 35.868570940835134, 37.77701875141689, 37.70892640522548, 39.27100651604788, 36.81367186137608, 37.33182334899902, 38.27692426953997, 37.153622899736675, 37.11009243556431, 38.77854251861572, 37.7837724004473, 37.475414821079795, 40.71854209899902, 39.32216610227312, 38.724982329777305, 37.8940611566816, 37.469824995313374, 37.35591622761318, 38.02545506613595, 39.50485508782523, 38.008063725062776, 36.672564370291575, 39.743768896375386, 39.34840944835118, 44.679491247449604, 41.10666152409145, 40.68334252493722, 40.5815166745867, 40.03800426210676, 40.01849719456264, 41.3822375025068, 43.08071769986834, 42.89941487993513, 45.32220309121268, 44.97980628694807, 44.5794232913426, 46.28008869716099, 44.99271256583077, 51.90510014125279, 56.44026926585606, 57.811016832079204, 59.78902653285435, 60.86415604182652, 59.831931659153526, 49.05222191129412, 1.3663939769778932, 0.701293734567506, 4.165280904088702, 1.7774486456598555, 3.7176128114972795, 66.20676490238735, 64.68214947836739, 70.53054550715855, 69.95290701729911, 62.97073868342808, 47.26970672607422, 28.16061462674822, 49.31111526489258, 62.70262854439871, 71.35699898856026, 6.5191130212375095, 0.36121784576347893, 0.16006102333111422, 0.21567208426339285, 0.09209116628127438, 0.10719404622380223, 0.22377345311854566], [0.04596521745302847, 0.03509799397683569, 0.14199254502143177, 0.0050682006985880435, 0.031781284271606376, 0.015047667548060417, 0.037520082401377816, 0.057932546362280846, 0.10098767639803034, 6.27618054832731, 52.06939377103533, 48.127736295972554, 38.25982475280762, 34.983175890786306, 35.79669182641165, 42.38419553211757, 53.455698353903635, 56.05646467208862, 49.34600217001778, 54.724293504442485, 6.456799839224134, 0.5667679788810867, 0.22515275196305343, 0.046107964257576635, 43.53227765219552, 58.69399043491909, 52.56214959280831, 48.68051413127354, 48.641750131334575, 49.06044510432652, 46.45557240077427, 43.25056641442435, 40.92752654211861, 38.4607458114624, 38.9949163709368, 37.73500299453735, 36.27262953349522, 35.027012075696675, 34.638778005327495, 34.360249042510986, 36.18713194983346, 34.399395193372456, 34.402042457035606, 33.030648708343506, 32.130843094417024, 32.93308210372925, 32.3349221093314, 31.776953969682964, 33.18520096370152, 32.83863524028233, 34.10968310492379, 32.03612525122506, 33.70231022153582, 32.132687841142925, 32.16058138438633, 33.38004582268851, 33.51483392715454, 33.116528442927766, 32.08643020902361, 33.16848707199097, 32.81484808240618, 33.16644777570452, 32.1775176184518, 31.649187019893102, 33.62407003130232, 33.92015361785889, 34.40638855525425, 35.24105133329119, 35.33440385546003, 32.175693716321675, 33.1463292666844, 38.726827076503206, 41.536265168871196, 45.19771221705845, 41.70645087105887, 36.046576840536936, 35.516130515507285, 34.125399930136545, 32.503985677446636, 34.91456242970058, 34.43621022360665, 36.94679587227957, 34.18789897646223, 33.92663976124355, 33.38058778217861, 33.08939225333077, 33.59261553628104, 35.0900912966047, 34.492341245923726, 33.37481382914952, 34.97057185854231, 33.17026233673096, 32.84469754355294, 33.40284286226545, 34.55656691959926, 33.47333928516933, 35.611855847494944, 33.42993041447231, 33.45610775266375, 31.914319855826243, 33.74591711589268, 33.926789147513254, 33.78346170697893, 36.87680319377354, 34.96187966210501, 42.98956080845424, 43.620453766414094, 43.198906557900564, 36.801502091544016, 32.992471831185476, 34.856527600969585, 33.46573795591082, 34.98108795710972, 33.1955120904105, 34.03393384388515, 33.04292964935303, 34.01915502548218, 32.56026956013271, 34.231276580265586, 34.45591531481062, 34.31974451882498, 33.743572098868235, 33.955440044403076, 34.03537906919207, 33.10201365607125, 34.32472290311541, 33.30425139835903, 32.83708579199654, 34.61309051513672, 34.440167222704204, 33.428509507860454, 34.16717250006539, 34.10735545839582, 35.512444496154785, 36.13846329280308, 35.42662034715925, 35.50568389892578, 36.341645990099224, 36.52488388334002, 35.617695808410645, 38.8384325163705, 39.32374334335327, 40.51941367558071, 39.52310453142439, 41.28033174787249, 39.170601572309224, 43.76842260360718, 51.24081761496407, 51.743568420410156, 55.26041303362165, 54.59387581689017, 55.96953228541783, 39.50214876447405, 46.63984904970442, 1.2551003375223704, 0.6120832615665027, 0.5009126269391605, 0.8278892072183746, 3.420941016503743, 56.16385950360979, 55.08483552932739, 59.23054422651018, 59.99156652178083, 53.41815376281738, 32.84652839388166, 18.03470778465271, 32.870138372693745, 51.08583804539272, 44.98544127600533, 1.21028228529862, 0.14577408853386128, 0.043435547301279645, 0.010762121794479234, 0.028865208782787834, 0.03228156814085586, 0.01753198272282524, 0.02343122724310628, 0.03880464079390679, 0.02998803835362196, 0.05801097822508641, 0.03985967453835266, 0.07566322958362953, 0.02700373956135341, 0.04945124539413622, 0.0867172639284815, 8.504106095858983, 59.621109417506624, 53.9500036239624, 41.88844851085118, 37.76093367167881, 40.599415234157014, 47.1558188029698, 59.49789006369454, 60.78551633017403, 54.07600573131016, 59.56268201555525, 6.7449094993727545, 0.45931278488465715, 0.12364441528916359, 0.07212017077420439, 47.18706832613264, 58.991213526044575, 55.01574959073748, 50.4891163281032, 52.108140400477815, 50.593565123421804, 48.128361633845735, 44.12047740391323, 44.0434809412275, 40.42950745991298, 40.94927092960903, 39.20832334245954, 38.285435812813894, 38.19016211373465, 36.40665681021554, 35.23802539280483, 37.6985353742327, 35.18844652175903, 35.37283781596592, 34.85978283200945, 34.61007152284895, 34.21976341520037, 35.07755674634661, 33.52770893914359, 35.40924637658255, 35.2518036706107, 36.59031506947109, 34.74389730181013, 36.10212768827166, 35.252265725817, 34.70655768258231, 35.36426026480538, 35.58146095275879, 35.147886412484304, 34.548368045261924, 35.38635206222534, 35.54377044950213, 34.21468080793108, 35.175814696720664, 33.86346326555525, 34.68648086275373, 35.45805399758475, 35.4039101600647, 36.8806003843035, 37.326216152736116, 34.33355058942522, 35.14270305633545, 41.34845536095755, 43.63915831702096, 46.720951897757395, 43.313694272722515, 36.32011352266584, 36.11778892789568, 34.46427052361624, 33.40072018759591, 36.811722891671316, 36.230169091905864, 37.75320380074637, 36.27472441537039, 35.92305176598685, 35.30379704066685, 35.90744611195156, 35.34801885059902, 36.07576969691685, 36.724797453199116, 36.22012199674334, 35.74452127729143, 34.05790165492466, 35.474997179848806, 35.2448068346296, 37.147963591984336, 37.2054877281189, 36.75258329936436, 34.86147471836635, 35.35654776436942, 32.94037423815046, 34.412718364170615, 35.721085003444124, 33.41772242954799, 35.30392558234078, 36.59015873500279, 44.66506331307547, 45.39338043757847, 45.10730225699288, 38.03309113638741, 34.6096442086356, 37.22686733518328, 35.884701183864046, 35.28828518731253, 35.06314965656826, 34.747889041900635, 34.06003475189209, 35.64345972878592, 34.573350293295725, 36.13393306732178, 35.59181376865932, 36.04535395758492, 35.08688817705427, 36.516556467328755, 36.11993244716099, 36.23022467749459, 35.3410359110151, 35.31961114065987, 34.743456091199604, 36.43936892918178, 36.45248365402222, 36.74121257237026, 37.79930509839739, 37.06248337881905, 37.68834931509835, 39.45354264123099, 37.57186623982021, 38.36860574994768, 38.9039922441755, 38.298533167157856, 38.290615694863455, 40.50909907477242, 40.31137766156878, 43.488371985299246, 41.46064097540719, 42.56345558166504, 41.85268265860421, 45.80546072551182, 54.19272157124111, 54.44242245810372, 57.24055583136422, 57.589324133736746, 56.6519079208374, 41.27152490615845, 49.69679239818028, 1.527164327246802, 0.6398615081395421, 0.6628504917025566, 0.6210826986602375, 3.964770657675607, 61.79103878566197, 59.65846988133022, 64.59566525050572, 63.54012271336147, 56.959793022700715, 27.545626095363072, 17.864845173699514, 39.06944622312273, 56.5482998575483, 54.9601640020098, 2.2347749514239172, 0.09562655085963861, 0.033340109911348136, 0.022003372432664037, 0.0127657568248521, 0.06459340572889362, 0.08436995345566954, 0.11250787108604397, 0.09258451552263328, 0.3723406089203698, 0.1885648002581937, 0.13092543530677045, 0.18600962736776896, 0.16448672727814742, 0.19410830922424793, 0.23043027520179749, 9.265038064547948, 68.09519495282854, 60.47115203312465, 51.62152678625924, 46.649322918483186, 46.37447302682059, 55.34714044843401, 62.25178773062569, 66.16834136417934, 58.39065987723214, 65.23521218981061, 8.27921896321433, 0.879837902528899, 0.39882461779883926, 0.15811313928237983, 50.28864690235683, 60.977988379342214, 57.47719063077654, 52.511921065194265, 54.47821262904576, 53.839436939784456, 50.05284588677542, 47.11306653703962, 45.34874868392944, 43.353003706250874, 43.388554164341514, 42.3246043069022, 40.87184367861067, 40.353223187582834, 37.35624974114554, 36.64391694750105, 39.99053764343262, 38.306787627083914, 38.46587010792324, 36.71091495241438, 36.08594880785261, 36.37865209579468, 36.48238522665841, 34.61399030685425, 37.00070694514683, 37.48942238943917, 39.209917954036165, 35.80862883159092, 38.358138288770405, 37.1943358693804, 37.02938216073172, 37.063362325940815, 39.046645709446494, 36.998257705143516, 35.86972434180123, 36.394007614680696, 37.07799175807408, 36.177192551749094, 36.30673129217965, 34.69542319434029, 37.29949338095528, 37.29889236177717, 36.38507917949131, 38.20641395023891, 38.63030617577689, 35.18881477628435, 37.55917535509382, 43.922790731702534, 46.14431742259434, 48.05400548662458, 43.63583360399519, 35.72886003766741, 37.078023024967735, 34.59046023232596, 34.394076347351074, 37.49328906195504, 36.878745215279714, 40.29456302097866, 38.1580753326416, 37.93131739752633, 37.37713950020926, 37.63903447559902, 37.608993938991, 38.1783640725272, 39.81447376523699, 37.7951466015407, 38.98141254697527, 36.88786472593035, 36.914531912122456, 37.239624227796284, 38.71947588239397, 36.89065442766462, 38.81487464904785, 34.77823182514736, 36.08997181483677, 33.40769270488194, 35.79434333528791, 34.91548654011318, 33.68852152143206, 36.562484060014995, 37.47378199441092, 45.38850975036621, 48.210666520254954, 48.66614178248814, 41.360524381910054, 36.733611243111746, 40.73597860336304, 36.77012055260794, 38.549648012433735, 37.28220278876168, 37.55556924002511, 35.984988008226665, 37.490422930036274, 36.390773228236604, 38.6473640033177, 38.01750980104719, 39.212738922664094, 37.51295593806675, 40.18438196182251, 40.4837520463126, 38.44665833881923, 38.46550532749721, 37.551528862544465, 36.85802221298218, 39.0022154535566, 38.39672858374459, 38.485915660858154, 40.21585035324097, 39.03514644077846, 40.640979358128135, 41.5138190133231, 40.757594449179514, 40.22272906984602, 41.46327434267317, 41.21771110807146, 40.03055231911795, 42.375131607055664, 42.86418751307896, 46.16587768282209, 44.20362302235195, 45.49890272957938, 44.21980537687029, 47.13513054166521, 57.69831357683454, 57.5534644808088, 60.01973451886858, 59.58889756883894, 59.1459846496582, 40.75763266427176, 54.41343109948294, 2.320379146507808, 1.3064860658986228, 2.8212806454726627, 1.642773232289723, 4.5921604207583835, 66.46015180860246, 64.84625203268868, 68.41499968937465, 69.28824928828648, 65.31478296007428, 43.454068728855674, 27.95274363245283, 49.04800088065011, 64.40565981183732, 66.1470868246896, 3.3444661029747556, 0.38587702970419613, 0.16493312189621584, 0.11241225871656622, 0.14108097393597874, 0.15552128478884697, 0.19261094528649533], [0.05703058333269187, 0.01757593482865819, 0.044751460797020366, 0.05963237836424794, 0.0417586871023689, 0.07333094187613044, 0.055497504704232724, 0.042266282186444314, 0.019403724964441996, 2.29339451449258, 50.27564334869385, 45.890023776463096, 43.55465432575771, 17.7885730607169, 12.773265174457006, 42.090203353336875, 49.49094506672451, 58.87214919498989, 46.46056815556118, 58.180101667131694, 12.72265362739563, 0.4769961674298559, 0.17131713218986988, 0.5223756666694368, 42.80055243628365, 57.347485133579795, 52.59015083312988, 47.27844408580235, 43.62066568647112, 45.188995701926096, 45.069583960941856, 42.2576653616769, 40.9040207862854, 39.35688625063215, 37.82754257747105, 33.95977572032383, 36.50789901188442, 34.72697843824114, 34.76978281566075, 33.06028624943325, 33.90416233880179, 33.03566878182547, 33.47092826025826, 32.87463733128139, 33.437100955418174, 32.53794847215925, 33.36255373273577, 31.837226118360245, 33.14303582055228, 33.428339276994976, 31.1675900050572, 33.19982692173549, 31.51279388155256, 32.64559343882969, 33.14910854612078, 31.628123555864605, 34.1212831224714, 32.872059549604145, 35.05835539954049, 33.07955707822527, 32.82831021717617, 34.683163097926546, 33.84270552226475, 34.23432336534773, 34.624919823237825, 34.6902711050851, 35.68760510853359, 35.501184940338135, 35.49958685466221, 32.47522013528006, 32.823675768715994, 38.97186919621059, 43.10140596117292, 43.61681638445173, 43.14089952196394, 35.77477720805577, 34.168145247868125, 34.68805462973458, 33.29033415658133, 34.08238710675921, 34.60640287399292, 34.526932852608816, 33.94072028568813, 33.48088155473982, 34.67233780452183, 33.07030555180141, 33.85832159859793, 35.285349573407856, 34.67757674625942, 33.35080780301775, 32.72571659088135, 31.880138192858013, 34.30848843710763, 34.21903732844761, 34.977419308253694, 34.41920798165457, 34.98522213527134, 33.05530091694423, 34.62952995300293, 33.97335250037057, 34.40871272768293, 35.34482267924717, 34.027958393096924, 35.466405732291086, 37.253541469573975, 42.21863038199288, 43.154806341443745, 43.32824032647269, 35.89401524407523, 32.28593730926514, 36.13801513399397, 33.729241439274375, 34.844840730939595, 34.70508466448103, 34.633229868752615, 32.81960759844099, 34.40252535683768, 33.91501889910017, 35.43036195210048, 34.064797742026194, 33.957524503980366, 33.520034653799875, 34.58874750137329, 32.352136271340505, 33.21219818932669, 32.96561704363142, 34.4287235396249, 33.857706683022634, 33.32796907424927, 33.49896771567208, 34.033360617501394, 32.405283042362754, 33.284799916403635, 36.202438831329346, 35.59672267096383, 35.22600848334176, 35.142466817583355, 33.374178068978445, 35.90974596568516, 35.161074093409944, 36.41964994158064, 37.465134961264475, 38.3129437310355, 39.616140910557334, 39.27578340257917, 43.57451227733067, 50.265273162296836, 55.9961508342198, 52.911928858075825, 56.615690435682026, 54.53178671428135, 58.88102204459054, 48.374967098236084, 45.163679940359934, 3.6447956902640204, 1.2454122688089098, 0.2624050708753722, 0.5630265910710607, 4.230688205787113, 54.607928548540386, 55.50861658368792, 57.77500431878226, 60.903052057538716, 50.989344937460764, 56.270639419555664, 27.72588321140834, 36.340739250183105, 51.60835647583008, 41.78394760404314, 1.03533131309918, 0.01964840299582907, 0.051520746666938066, 0.06919948463993413, 0.03049102279224566, 0.04672062709661467, 0.118631832833801, 0.023257641021960547, 0.0574204491983567, 0.05096219699563725, 0.02694681047328881, 0.043561001640877554, 0.07889649644494057, 0.038385845587721894, 0.03254392031314118, 0.03101830556988716, 3.2133258027689795, 56.283827100481304, 51.379010336739675, 48.649820463997976, 25.10860797337123, 25.463096380233765, 49.32697800227574, 53.154108319963726, 61.38224152156285, 50.81126955577305, 61.89755467006138, 13.154734304973058, 0.4078037531248161, 0.11107774996863944, 0.5087703881519181, 47.72506734303066, 56.65838016782488, 54.82210677010672, 51.06281866346087, 46.304066930498394, 45.83675193786621, 46.78710222244263, 43.816570145743235, 42.408291884831016, 41.78668172018868, 39.47756603785923, 37.63886077063424, 39.565978390829905, 36.11242144448416, 37.461970056806294, 34.457634993961875, 36.1841824395316, 34.83949409212385, 36.246469565800254, 34.50944076265608, 35.18733480998448, 33.93133326939174, 35.105620520455496, 33.93156255994524, 34.858209065028596, 34.579495974949424, 34.51284537996565, 34.62477738516671, 33.68769815989903, 35.5108186176845, 34.54719032560076, 33.93962941850935, 35.175859860011506, 34.132233483450754, 35.719570296151296, 35.09632383074079, 34.89526728221348, 35.542099407741, 35.27413518088204, 35.54480225699288, 34.891463143484934, 35.95665325437273, 37.661515372140066, 35.80836132594517, 37.02142299924578, 34.30340582983834, 35.455521379198345, 39.91462162562779, 44.19630309513637, 46.453011989593506, 43.983313015529085, 34.753590038844514, 35.64730903080532, 35.47977059228079, 34.1212831224714, 34.27580411093575, 35.75267151423863, 36.10013355527605, 36.93695027487618, 34.15501315253121, 35.875526087624685, 34.32541077477591, 35.7735265323094, 36.89351708548409, 36.19052267074585, 35.807857581547324, 35.79175165721348, 34.61376796449934, 36.524171692984446, 35.96556779316494, 35.95188679013933, 34.740419728415354, 36.693360328674316, 34.5032707623073, 34.8080986567906, 35.0153807912554, 34.19535091945103, 34.99790607179914, 34.24252223968506, 34.77652604239327, 37.434298855917795, 44.1207275390625, 45.40260417120797, 45.64787905556815, 37.33209432874407, 34.45084660393851, 37.68556656156267, 35.868494510650635, 36.649041243961875, 36.90445702416556, 35.40025193350655, 34.1750864982605, 36.03304522378104, 35.40632118497576, 37.89189679282052, 35.018778460366384, 36.009025301252095, 35.69288573946272, 37.143145016261506, 35.397424016680034, 35.15392787115914, 34.00275380270821, 36.277017320905415, 36.26141166687012, 36.82934352329799, 35.488872732434956, 37.14997162137713, 36.030849593026296, 33.8910893031529, 38.494875362941194, 38.52278280258179, 38.12758663722447, 36.935418197086875, 36.439448833465576, 38.32175057274954, 37.49967098236084, 37.938064098358154, 39.89773402895246, 40.0910051209586, 41.54930346352713, 40.866611685071675, 45.49671057292393, 53.18912724086216, 58.028304372514995, 54.12520939963204, 58.942075865609304, 55.81097786767142, 60.96676703861782, 48.99578169413975, 47.58883053915841, 4.143037983349391, 0.8446149868624551, 1.2690323442220688, 0.9165334020342145, 4.435077718326023, 59.690716470990864, 59.76228986467634, 62.759492601667134, 64.72647203717912, 57.01135560444423, 54.191516058785574, 28.465133326394216, 43.567751680101665, 57.5285621370588, 50.742534501211985, 1.3137328198977878, 0.0016596502183736967, 0.019186949989359294, 0.005105535391651626, 0.03358066753883447, 0.056285589201641936, 0.022081599038626467, 0.10621135788304464, 0.13947196384625776, 0.10053082555532455, 0.15566989752863133, 0.22292426654270717, 0.1590041643274682, 0.1753689633416278, 0.14093407110444137, 0.11128712551934378, 3.5460635253361295, 63.95193549564907, 58.617066928318565, 57.49655178615025, 27.112907920564922, 21.823534420558385, 54.47256374359131, 59.46134948730469, 66.9842196873256, 54.59270504542759, 68.05631283351353, 14.623745032719203, 0.784336541380201, 0.1975374895014933, 0.9683171319110053, 51.12700959614345, 58.44300760541643, 56.35992724554879, 53.49808931350708, 48.390086378370015, 48.141122000558035, 48.70762252807617, 45.65421233858381, 45.27390963690621, 43.30783346721104, 42.68005677631923, 38.58858571733747, 41.60139063426426, 39.58865731103079, 39.496055194309776, 37.532039165496826, 37.47451155526297, 36.4539601462228, 38.451376165662495, 36.96079649244036, 38.04659496034895, 37.17877885273525, 37.93786607469831, 35.73798302241734, 37.36991684777396, 36.681722096034456, 35.90084532329014, 37.54190560749599, 35.04252392905099, 37.09114817210606, 36.23190614155361, 35.24756874356951, 37.7470372744969, 35.26864262989589, 38.83419064113072, 36.178436279296875, 36.30696405683245, 37.81590781893049, 36.54474183491298, 37.55536079406738, 37.89888668060303, 37.57834543500628, 38.57314682006836, 38.699326106480186, 39.08584744589669, 36.86426864351545, 36.866714409419465, 41.69395106179373, 46.02610077176775, 48.584827014378135, 45.56258644376482, 34.221979890550884, 35.874060017721995, 35.98974405016218, 34.9453637940543, 35.496793678828645, 37.68838405609131, 37.5822503226144, 38.14480079923357, 36.0761205809457, 38.4092561858041, 36.749911717006135, 37.84964827128819, 39.32258994238717, 38.54197720118931, 37.50119958605085, 37.42756257738386, 36.12179456438337, 38.33980546678816, 38.344432967049734, 38.76007073266165, 37.13703407560076, 38.03864969526018, 35.22031790869576, 36.3747159412929, 36.02879640034267, 34.96494034358433, 35.39165006365095, 35.08156933103289, 36.79333101000105, 37.76770469120571, 46.21787800107683, 49.233719280787874, 47.2717981338501, 39.416630336216514, 36.31321743556431, 39.774226324898855, 37.38495969772339, 39.13428681237357, 39.722354548318044, 38.283045632498606, 36.272626059395925, 39.055977140154155, 37.396653515951975, 39.882899624960764, 38.2052674974714, 36.770679882594514, 38.34400912693569, 38.88523210797991, 35.351385252816335, 37.671694483075825, 36.27129200526646, 39.12078993661063, 39.48122773851667, 37.873706408909385, 37.31936175482613, 39.73079660960606, 37.32863759994507, 36.641648360661094, 41.127502645765034, 40.27002198355538, 40.55710070473807, 39.85825089045933, 38.08393805367606, 41.04051467350551, 39.12896449225289, 39.88487638745989, 42.21051141193935, 42.77191196169172, 44.7915483202253, 43.48753125326974, 48.071535791669575, 55.61764076777867, 60.40503297533308, 56.69899238858904, 59.90411649431501, 57.44625377655029, 62.579096521650044, 48.180688517434255, 49.318879876817974, 5.47846394777298, 1.9574968814849854, 4.9814558284623285, 1.1999417373112269, 5.2941056575093945, 65.88536208016532, 65.14270387377057, 68.75090340205601, 70.06847640446254, 65.17103167942592, 67.47458880288261, 37.57734489440918, 52.289446694510325, 64.68351827348981, 60.15370968409947, 2.3585964100701466, 0.18757122143038682, 0.19358585083058902, 0.14568262201334747, 0.11972497989024435, 0.14125622596059526, 0.19850814741637024], [0.01875009896632816, 0.040280926041305065, 0.0395339370173003, 0.024969944497570395, 0.04435495885887316, 0.034498667743589194, 0.011855687846296599, 0.027929000090807676, 0.07255859260580369, 0.9121960976294109, 39.492591517312185, 58.01219497408186, 43.23529427392142, 22.98510299410139, 20.575778654643468, 34.49302911758423, 53.12140314919608, 56.12895522798811, 47.782542841775076, 57.79317038399832, 21.51445596558707, 0.4799285243664469, 0.023235094999628406, 0.17655768884079798, 39.051106452941895, 58.02947514397757, 53.72445814950125, 49.12969779968262, 43.96339947836739, 43.273974895477295, 42.68811321258545, 39.77805825642177, 38.69734239578247, 38.86806658336094, 37.9146590914045, 36.45123645237514, 37.14478479112898, 34.93766171591622, 33.111734185900005, 32.36767244338989, 33.694941656930105, 32.482505321502686, 34.434963021959575, 34.68136004039219, 33.04099457604544, 33.11756372451782, 33.55194425582886, 32.23533705302647, 32.93110186713082, 33.63740709849766, 32.767558642796104, 33.31352724347796, 31.58760166168213, 32.93392283575875, 32.79496233803885, 32.65024873188564, 33.12429652895246, 32.20474760872977, 34.23422261646816, 33.71334048679897, 33.87797457831246, 33.548331192561555, 34.36879185267857, 33.709192412240164, 33.677369662693565, 34.150232791900635, 33.08969449996948, 34.800813470567974, 34.98301608221871, 34.13018723896572, 31.983152185167583, 38.75732619421822, 43.1877373286656, 41.97239317212786, 42.18499067851475, 35.79489571707589, 34.93363870893206, 34.31838962009975, 33.61414452961513, 31.630155903952463, 34.11727053778512, 34.11777080808367, 33.376929555620464, 33.97910908290318, 33.629496574401855, 33.25991841724941, 34.31433187212263, 34.40275117329189, 34.48616429737636, 35.55545037133353, 34.02079132625035, 33.81429433822632, 33.30051326751709, 34.839994362422395, 36.00783021109444, 33.71242332458496, 33.47447531563895, 33.322299344199045, 32.97417375019619, 34.5098090171814, 34.16005059650966, 34.63279560634068, 35.899827412196565, 37.297697271619526, 38.020480155944824, 43.03525216238839, 43.62634236471993, 42.407409463609966, 36.48753036771502, 34.09034626824515, 35.515633719308035, 33.83708790370396, 33.957038130079, 34.119379316057476, 34.57049458367484, 33.59406770978655, 32.9461864062718, 34.24631943021502, 34.76199041094099, 36.443152223314556, 33.3991116796221, 34.96550662176949, 34.317284856523784, 33.9176800591605, 31.037947041647776, 32.9750839642116, 34.02808346067156, 33.8804863521031, 33.864748682294575, 34.61952454703194, 34.41856527328491, 34.642001969473704, 34.24268204825265, 35.13647747039795, 36.18655524935041, 35.34733097893851, 35.84277922766549, 37.1529107093811, 36.165828772953574, 36.785104342869346, 36.851956435612266, 37.081573554447715, 37.0593705858503, 38.98450796944754, 39.118326800210134, 44.760079928806846, 51.17470897947039, 53.52199806485857, 54.430353437151226, 54.75463628768921, 53.26330968311855, 58.12612458637783, 58.493764196123394, 54.66792971747262, 4.932547892842974, 0.7669073651943887, 0.37388916153992924, 0.6934917760746819, 3.8230664900371005, 56.56481225149972, 54.20613506862095, 61.32344586508614, 57.44205011640276, 48.03826086861746, 35.63920048304966, 23.44224234989711, 40.55083690370832, 56.379990168980186, 36.86060694285801, 0.5910354309848377, 0.005397945817094296, 0.01767612391683672, 0.06332321531538453, 0.05362257674070341, 0.04452265200338193, 0.04816182529819863, 0.038989748539669175, 0.0951063519875918, 0.02174617034117026, 0.0072036475175991654, 0.06931053368108613, 0.04332343635282346, 0.01976278025124754, 0.05931150593927928, 0.09001803145344768, 0.7537766812103135, 46.36599622453962, 59.89397212437221, 51.137473583221436, 24.802175045013428, 22.344327960695537, 45.71304273605347, 54.71074104309082, 60.72246142796108, 52.086736474718364, 62.46369389125279, 22.249017783573695, 0.3398102287735258, 0.047327122052333186, 0.18512284995189734, 44.1139634677342, 60.83990682874407, 56.01854140417916, 50.025966780526296, 45.93571513039725, 44.40683003834316, 44.40490538733346, 41.41228151321411, 41.23358079365322, 40.783810002463206, 40.63317653111049, 38.456785338265554, 38.0058194569179, 35.96547399248396, 35.076285226004465, 34.678209032331196, 34.90014839172363, 35.54729666028704, 35.64496053968157, 35.91044773374285, 34.774882793426514, 34.20948008128575, 34.81979942321777, 33.882216453552246, 34.374652658190044, 35.28873334612165, 34.701343059539795, 35.879229477473665, 32.761482443128315, 34.547468253544395, 34.48426396506173, 34.45560959407261, 35.087405817849294, 34.47233738218035, 36.22988074166434, 35.10982765470232, 35.12796940122332, 34.794365542275564, 34.902045249938965, 34.47111797332764, 35.765977314540315, 35.63183886664254, 33.953029019492014, 36.664025034223286, 36.30172511509487, 35.44707236971174, 33.28816979272025, 41.00204597200666, 44.13684735979353, 42.838423592703684, 43.23553051267351, 36.107595920562744, 34.91671289716448, 34.24769169943673, 34.255560534340994, 33.103278228214805, 35.07889774867466, 35.78098889759609, 35.40243019376482, 34.88727337973458, 35.47073793411255, 35.70900208609444, 36.006614276341026, 36.318366050720215, 36.76013251713344, 36.63947010040283, 35.50980765478951, 35.49842997959682, 34.52114152908325, 36.29028838021414, 36.08059869493757, 35.92217281886509, 35.247308186122346, 34.88800294058663, 33.64775991439819, 34.45617239815848, 33.40322848728725, 35.56058856419155, 35.93379715510777, 37.73373147419521, 38.51430252620152, 45.65462575639997, 46.245559624263215, 45.25791140965053, 36.654453890664236, 35.255875314985005, 37.937070505959646, 34.57165493283953, 36.01430593218122, 35.870339257376536, 35.26662417820522, 35.17623853683472, 34.80289445604597, 35.43117141723633, 35.872343812670024, 38.10375084195818, 36.43256664276123, 36.10069635936192, 36.16255964551653, 37.067649364471436, 34.21378101621355, 35.272373812539236, 36.884001527513774, 36.51576089859009, 36.630579880305696, 36.36145183018276, 35.6742958341326, 36.81786509922573, 37.062400000435964, 36.79604080745152, 37.54938881737845, 37.282741274152485, 37.18597371237618, 39.546537331172395, 37.50932897840227, 38.97866106033325, 37.869436740875244, 38.999001911708284, 40.38008144923619, 41.6093567439488, 41.36397763660976, 47.12701504571097, 53.24668264389038, 55.96189968926566, 56.16161176136562, 57.46709489822388, 54.97448771340506, 60.44993223462786, 60.90856892721993, 57.16927773611886, 5.569224791867392, 1.038951215999467, 0.46353924380881445, 0.6709279354129518, 4.418666507516589, 62.30664375850132, 59.45437349591936, 67.40421049935478, 63.292655672345845, 55.55791057859148, 45.76849283490862, 25.492141587393625, 49.124771526881624, 62.22909491402762, 44.794039249420166, 1.1278076022863388, 0.14972917416266032, 0.02460879084121968, 0.005874628966142024, 0.027546976393620883, 0.006341186252289585, 0.02262991470550852, 0.1353803434010063, 0.15274799003132752, 0.12807267052786692, 0.11027508375367948, 0.18506106255309923, 0.15478028383638176, 0.13086119161120482, 0.14721020790083067, 0.260308994778565, 1.37214024577822, 51.72843524387905, 69.84566157204765, 56.07072237559727, 32.24494293757847, 28.56512658936637, 47.87631572995867, 60.880081312997, 66.05136149270194, 56.295138767787385, 68.15749250139508, 25.891041142599924, 0.5340061911514827, 0.13315291649528913, 0.33438962964074953, 48.36663620812552, 61.61153902326311, 58.78310803004673, 51.77606861931937, 49.89481953212193, 47.80498899732317, 46.67661196844918, 42.18438618523734, 43.442433970315115, 42.62672240393502, 43.08930219922747, 41.16813223702567, 40.82283108575003, 38.361834730420796, 37.470450333186555, 36.862066064562114, 37.580169337136404, 35.881810733250205, 37.508335386003765, 38.976510592869346, 36.58839389256069, 36.45613840648106, 36.947716508592876, 35.97716433661324, 38.482187952314106, 37.64679561342512, 38.74294689723423, 36.71857534136091, 34.44289091655186, 37.05734518596104, 37.4003186907087, 36.37953451701573, 37.495199816567556, 35.55455405371529, 38.030846868242534, 35.85720368794033, 37.342912673950195, 36.14950745446341, 38.630347864968435, 36.96338817051479, 37.20759303229195, 37.574381487710134, 35.41517318998064, 38.329650674547466, 37.671840395246235, 37.71455097198486, 36.14716591153826, 43.54986354282924, 46.7611437525068, 44.537261622292654, 43.74860634122576, 35.66462046759469, 35.476504938943044, 35.24256951468331, 35.20401743480137, 32.560554436274934, 36.89802994046892, 36.995033740997314, 37.083564213344026, 37.53985241481236, 37.19275515420096, 37.816640853881836, 38.55314643042428, 38.388133662087576, 39.2447840145656, 38.772737298692974, 37.67082943235125, 37.342679909297395, 36.56399529320853, 37.77773788997105, 40.18410055977957, 36.818917751312256, 36.434998512268066, 35.32167475564139, 34.77775239944458, 37.40210785184588, 33.81471470424107, 34.74802105767386, 37.405390875680105, 39.6088661466326, 39.85188981464931, 46.47667407989502, 48.92310701097761, 47.03349576677595, 40.15422330583845, 38.43174403054373, 40.665513447352815, 36.42251259940011, 39.59844037464687, 38.25897707257952, 38.42702272960118, 37.437488079071045, 36.949953828539165, 37.396764687129426, 37.7730131149292, 41.54818827765328, 37.94918121610369, 38.5807203565325, 38.428700719560894, 39.401809828622, 35.366796357291086, 37.153633322034565, 39.08391237258911, 37.9560877255031, 37.9730031149728, 39.33326237542288, 39.705727509089876, 38.490359033857075, 38.7598796572004, 40.08525548662458, 40.67808621270316, 40.230125427246094, 39.98877280099051, 42.60848685673305, 40.46728481565203, 41.13460717882429, 39.62364149093628, 40.378323554992676, 42.89279672077724, 43.428061621529714, 42.377601691654746, 49.59650557381766, 53.447687080928254, 58.41952964237758, 58.49849591936384, 59.258628845214844, 57.59561225346157, 63.531208174569265, 62.04975496019636, 59.837274823869976, 6.726960131100245, 1.1792876741715839, 2.781571690525327, 1.0352825671434402, 5.353799802916391, 67.8492009299142, 63.73725700378418, 71.48877852303642, 68.53529385157994, 60.19128554207938, 48.761373792375835, 34.27050263541085, 56.99904339654105, 70.74320902143205, 53.01053769247872, 1.6291004802499498, 0.19124434861753667, 0.09875740643058505, 0.20124667403953417, 0.16407664785427706, 0.11035522552473204, 0.1852308184440647], [0.02419049266193594, 0.018466791936329434, 0.008231606018463416, 0.014504098233633807, 0.05664291592048747, 0.07678090568099703, 0.06486484687775373, 0.049442967266908715, 0.04643492992701275, 0.11946059550557818, 31.747219153812953, 57.3202759878976, 41.65587493351528, 30.26702356338501, 36.19603259222848, 37.997637953077046, 51.128142152513774, 58.406050137111116, 49.55286741256714, 54.537286213466096, 30.840649468558176, 0.07501235165234123, 0.03582621472222464, 0.12487915903329849, 22.640946558543614, 64.0598201751709, 51.62623071670532, 55.788979870932444, 45.77209894997733, 43.42032480239868, 40.9469050679888, 41.051294803619385, 37.81972932815552, 38.86976541791643, 36.186600412641255, 34.73625428336007, 33.4165620803833, 33.150588512420654, 33.06856850215367, 36.404916286468506, 35.37199708393642, 37.796393803187776, 37.14898497717721, 36.187910148075645, 35.70172732216971, 35.90882880347115, 34.87910924639021, 32.56326423372541, 31.991691521235875, 32.07640743255615, 31.543723787580216, 33.8096147264753, 31.821464129856654, 33.394209725516184, 30.57375873838152, 32.34503868647984, 33.347083568573, 32.67998702185494, 33.54239395686558, 33.44651229040963, 33.356168338230674, 33.34157017299107, 32.29320165089199, 33.825300284794395, 33.401025908333914, 34.541322571890696, 33.14008631025042, 34.612486021859304, 33.41496052060808, 34.032186371939524, 31.803308486938477, 34.501241888318745, 41.79271970476423, 43.03650631223406, 43.05121217455183, 37.882547991616384, 34.2105188369751, 32.73302262169974, 33.677373136792866, 31.317243780408585, 32.89648594175066, 34.979562827519004, 34.416088240487234, 33.91665519986834, 33.660478591918945, 34.23764113017491, 33.53773518971035, 34.06811898095267, 35.36712639672415, 34.778784206935335, 33.68842772075108, 33.22899545942034, 33.08921160016741, 33.96545934677124, 33.986585344587056, 35.74258620398385, 34.689131600516184, 33.72713960920061, 33.49882527760097, 34.14421912602016, 36.81762538637434, 35.33713102340698, 34.54307351793562, 35.77933522633144, 39.30594205856323, 42.315550804138184, 43.87204803739275, 44.3272453716823, 34.949251311165945, 31.80455916268485, 34.405311584472656, 34.366988795144216, 33.83188370295933, 33.802242687770296, 32.35335220609392, 32.895770277295796, 33.76401022502354, 34.09120784487043, 33.829754080091206, 34.857726165226524, 34.57035909380232, 35.13740158081055, 33.82703733444214, 33.749575342450825, 33.168664251055034, 34.01549332482474, 34.045874323163716, 34.35722310202462, 34.03088705880301, 34.72154147284371, 34.715284620012554, 34.450228214263916, 35.35395608629499, 35.961603845868794, 34.27276427405221, 35.12703486851284, 35.90547629765102, 35.20401743480137, 36.14887864249093, 36.39542852129255, 36.54904276984078, 38.77489471435547, 38.01478263310024, 37.58241013118199, 37.32971109662737, 41.50823960985456, 50.37139647347586, 53.956899711063926, 54.04570811135428, 55.47298622131348, 50.61684853690011, 53.425161021096365, 51.61801099777222, 59.22235230037144, 6.182102807930537, 0.5360124292118209, 0.6539133712649345, 0.7614569376621927, 6.194558756692069, 59.63623564583914, 53.7711500440325, 60.94003731863839, 56.33758183888027, 47.42593697139195, 38.723415510995046, 36.640765939440044, 41.17943000793457, 55.45305183955601, 29.311677524021693, 0.33287136682442253, 0.06327522253351552, 0.10762650373258761, 0.002836889391931306, 0.13598992569105967, 0.01046762487385422, 0.032128826515483, 0.016375579239268388, 0.005593376624996641, 0.04803446088252323, 0.06384191462504012, 0.0625829811074904, 0.0348137895842748, 0.032388213489736827, 0.09268088785133191, 0.021174418074744086, 0.20454101583787374, 37.855109555380686, 64.49488162994385, 48.66368212018694, 32.38385132380894, 32.23338113512312, 44.305639948163716, 56.47152573721749, 62.76440497807094, 55.82265778950283, 60.04182979038784, 34.1192855153765, 0.16525060843144143, 0.01668147470003792, 0.15861806433115685, 24.759483575820923, 63.5499335697719, 54.21259689331055, 57.28471858160836, 47.10726131711687, 44.04398468562535, 41.81975861958095, 42.863617760794504, 40.42147881644112, 40.85469899858747, 37.66800846372332, 37.97026552472796, 34.91679974964687, 35.50806713104248, 35.51740550994873, 36.67992946079799, 35.91076040267944, 38.71872200284685, 39.515211377825054, 37.66139725276402, 37.312316281454905, 37.50065415246146, 36.82592848369053, 35.185660294124055, 33.94222109658377, 35.20381246294294, 33.63969305583409, 35.036023889269146, 33.961373805999756, 34.2816093308585, 31.690650394984655, 35.00181443350655, 34.967122077941895, 35.0594983782087, 34.534596715654644, 34.75874212809971, 34.83803497041975, 35.58140536717006, 33.7772604397365, 35.97024393081665, 34.299997738429475, 34.81395598820278, 34.124635628291536, 36.263065338134766, 35.53391790390015, 36.74995340619768, 33.32571785790579, 38.03687790461949, 44.05433055332729, 46.080143860408235, 44.38861880983625, 37.80941472734724, 34.27754463468279, 33.95053461619786, 33.956801891326904, 32.35257748195103, 34.396709714617046, 37.19794545854841, 36.93004723957607, 35.83512578691755, 35.074951171875, 37.00191593170166, 37.110721247536794, 35.28659677505493, 36.58958203451974, 37.00208963666643, 36.052534920828684, 36.22370726721627, 33.970204966408865, 34.515888690948486, 35.044615336826865, 36.36729179109846, 35.20978096553257, 35.03269917624337, 33.36523226329258, 34.94199391773769, 36.28287812641689, 35.45898158209664, 35.72339180537632, 36.122621400015696, 40.1878456388201, 45.22839546203613, 45.38899612426758, 45.463640621730256, 36.468217849731445, 33.10457059315273, 36.62610871451241, 35.85458769117083, 36.44791521344866, 36.09372384207589, 35.001602513449534, 34.10135916301182, 35.55886541094099, 35.80751364571707, 35.977202551705496, 35.90294367926461, 35.15158632823399, 36.29414463043213, 35.747592381068635, 36.03795065198626, 35.24679749352591, 35.83635214396885, 36.8626184463501, 36.61667653492519, 35.93982471738543, 35.26974739347185, 37.09168665749686, 35.84702457700457, 36.36227171761649, 37.45918035507202, 35.040123326437815, 37.05679627827236, 37.427635533469065, 37.17449876240322, 38.84820863178798, 38.33903769084385, 39.0544867515564, 40.67685290745327, 39.61746801648821, 40.002335684640066, 39.093775340488975, 42.6154420035226, 53.75648587090628, 57.42926890509469, 54.49544416155134, 59.460369791303364, 53.51181895392281, 57.18581097466605, 53.92539310455322, 61.937173298427034, 7.6683185781751355, 0.4568044309105192, 0.5513904211776597, 0.8687657852258001, 6.752323227269309, 65.15611389705113, 57.92242077418736, 66.00217519487653, 61.53263528006417, 53.91455044065203, 40.05196666717529, 37.39657013756888, 48.63800505229405, 61.631376130240305, 37.4483585357666, 0.33835118849362644, 0.034290496592542956, 0.07123044851635184, 0.05463476778407182, 0.021646196687860147, 0.03156553388440183, 0.030984097226922, 0.06523301319352218, 0.07137735134788922, 0.09279478673956224, 0.16279600800148078, 0.12935417890548706, 0.15125589152531965, 0.18733895889350347, 0.30346857170973507, 0.10461118231926646, 0.30968256826911655, 43.829087325504844, 72.55379145486015, 55.22966030665806, 42.479827063424246, 47.96565914154053, 49.83270958491734, 60.82375226702009, 65.94043350219727, 60.57162993294852, 63.18796716417585, 39.35596214021955, 0.21639447978564672, 0.12151358462870121, 0.172257378165211, 27.01598402432033, 66.11536829812187, 55.335686343056814, 59.966914313180105, 50.068010330200195, 46.94290515354702, 44.29540525163923, 44.81327881131853, 41.66567536762783, 43.85649796894619, 41.50784008843558, 40.259419032505576, 38.23179919379098, 38.46246896471296, 37.12484693527222, 39.74530097416469, 39.326644216264995, 42.43808576038906, 42.524212156023296, 39.860158170972554, 39.44995389665876, 40.95154646464756, 38.673781054360525, 36.645070348467144, 36.793424810682026, 37.79742908477783, 34.6522991997855, 38.51111330304827, 35.22663034711565, 36.76546178545271, 34.375392641339985, 36.62010199683053, 37.876082692827495, 35.67139843532017, 36.29631246839251, 36.574626037052695, 36.81231696265084, 37.92386892863682, 35.50184154510498, 37.25963156563895, 36.33454145703997, 37.20629371915545, 35.05789681843349, 38.07333162852696, 36.472352027893066, 37.73171649660383, 34.81381702423096, 40.351555619921, 45.650804247174946, 47.58088527406965, 47.15828193937029, 39.446962697165354, 34.30996492930821, 34.29220185961042, 34.36900724683489, 32.60044404438564, 35.366973536355154, 39.72639492579869, 38.099766050066265, 37.647219453539165, 38.75790636880057, 39.086538791656494, 39.64228350775582, 37.62145553316389, 39.29755905696324, 39.16969830649239, 37.160088198525564, 37.45597723552159, 36.7942863873073, 37.7301218850272, 37.02875682285854, 40.23475987570626, 37.37299837384905, 36.085705620901926, 34.850576468876426, 36.64007806777954, 37.43743944168091, 35.07893596376692, 35.38337475912911, 36.40211616243635, 40.55703122275216, 45.95264441626412, 47.508846351078574, 49.22098323277065, 38.641520568302695, 34.78437403270176, 39.08345031738281, 38.870849336896626, 37.2034831728254, 38.7751761163984, 37.27329519816807, 34.679244313921245, 37.83353539875576, 37.55733060836792, 39.26519782202584, 38.04193271909441, 37.29943779536656, 38.35392768042428, 36.9229531288147, 38.703957080841064, 37.77627876826695, 38.51146766117641, 39.35468367167881, 40.316838945661274, 38.62531042098999, 37.903232778821675, 39.00712782996041, 38.070757320949006, 41.146179403577534, 40.77992595945086, 38.43273762294224, 39.49428340366909, 38.17026594706944, 40.429267747061594, 40.451630524226594, 39.26719890322004, 41.15393706730434, 43.78649139404297, 42.39970391137259, 41.22694526399885, 41.61535651343209, 45.435934679848806, 55.45218331473214, 59.75128391810826, 57.97887488773891, 61.0996652330671, 55.84326614652361, 59.53689725058419, 55.452902453286306, 64.84352139064244, 9.524238875934056, 0.784517628805978, 3.1077785406793867, 1.3763249069452286, 7.284309012549264, 70.77247483389718, 60.96181297302246, 71.54059818812779, 66.11812673296247, 60.769577162606375, 49.48962490899222, 47.977266107286724, 57.307626792362754, 69.18302576882499, 45.420464515686035, 0.6184968831283706, 0.13508583206151212, 0.23974069846527918, 0.14637452417186328, 0.3485508183283465, 0.09673220331647567, 0.0884044955351523], [0.043344911986163685, 0.0448185136275632, 0.044558095280081034, 0.0408547291798251, 0.00527025231193485, 0.006820196776451277, 0.026605093452547277, 0.020453040355018208, 0.08679871527212006, 0.11028459681464092, 15.606757061822073, 54.41227075031826, 43.20583391189575, 30.942325932638987, 23.72257263319833, 36.753538676670615, 48.82309116636004, 50.93816103254046, 52.52776295798165, 52.016893182482036, 41.34731585638863, 0.5206891000270844, 0.06474729747112308, 0.056935262733272145, 2.9416510207312445, 53.67524058478219, 53.06938893454415, 53.12933104378836, 50.25848477227347, 46.81806686946324, 43.43639945983887, 42.28637184415545, 38.148465973990305, 38.07569749014718, 36.588011741638184, 34.13101060049874, 34.63345915930611, 38.04073415483747, 37.52417727879116, 41.875722885131836, 40.78893082482474, 40.84753540584019, 39.20995269502912, 37.745508670806885, 37.055222511291504, 34.731880392347065, 33.700361251831055, 33.43038204738072, 31.773073400769913, 34.69578797476632, 32.48408951078142, 31.572016852242605, 33.45718819754464, 33.62104409081595, 34.0030004637582, 34.386051177978516, 35.00140796388899, 35.15548774174282, 35.4228891645159, 34.2521732875279, 32.513119084494456, 32.977745124271934, 32.77397877829415, 34.79927444458008, 32.782841205596924, 35.694462980542866, 34.78276899882725, 34.56063856397356, 34.41518497467041, 35.028933252607075, 31.159540516989573, 35.7731374331883, 40.29740136010306, 40.39845943450928, 44.82487188066755, 39.81908042090279, 32.36069645200457, 33.40040404456002, 34.64520161492484, 32.62570769446236, 32.738490853990825, 36.31638928822109, 35.136911732809885, 34.68714788981846, 34.176823547908235, 32.17761836733137, 33.687531403132844, 33.9619539805821, 35.33904872621809, 36.435245173318044, 34.634775842939106, 32.52455929347447, 34.15397439684187, 33.477483885628835, 34.95815890175955, 34.40439094815935, 33.41198321751186, 34.584154742104666, 32.912008217402864, 34.03761638913836, 34.137635707855225, 35.36497245516096, 36.244593552180696, 38.55577632359096, 40.96515103748867, 43.73192024230957, 42.75459705080305, 42.23884269169399, 37.17915058135986, 32.173970563071116, 34.61960097721645, 34.5415483883449, 33.27444362640381, 33.03679438999721, 33.86628770828247, 32.95941925048828, 34.51559339250837, 33.93135411398751, 32.867077691214426, 34.971134662628174, 34.39980861118862, 33.41372374125889, 34.11484561647688, 32.32378414699009, 32.001575333731516, 32.45030736923218, 32.35306732995169, 32.251634052821565, 32.812735830034526, 34.108658245631624, 33.68646832874843, 35.26777063097273, 32.833142689296174, 34.14394467217581, 33.96560525894165, 35.58102321624756, 34.99658938816616, 34.9924830027989, 35.58587653296334, 35.1695682661874, 37.18131147112165, 37.83452551705496, 37.536941119602744, 39.9537330354963, 39.332852431706016, 39.92438037054879, 40.58649158477783, 46.34035389763968, 46.25255298614502, 48.922057832990376, 44.82165833881923, 53.745785645076204, 54.25181252615792, 60.03457587105887, 6.828341731003352, 0.6834955981799534, 0.42482057000909534, 0.5007191087518419, 6.055722892284393, 61.873805727277485, 51.7040296963283, 61.35072449275425, 55.757501057216096, 46.958750520433696, 26.327276842934744, 33.68192768096924, 42.939259324754985, 57.34781864711216, 19.943888630185807, 0.23504757029669626, 0.07434218297047274, 0.04804664397878306, 0.043153419225875816, 0.040149018833679814, 0.11381762687649045, 0.052822980896702836, 0.09322586003690958, 0.06630034877785615, 0.03664958643327866, 0.0832425132393837, 0.030283567495644093, 0.024782718026212285, 0.08800295208181654, 0.02935278369113803, 0.07121899484523705, 0.09194454164909464, 20.326227154050553, 62.33718803950718, 47.977603094918386, 35.30303968702044, 27.357086726597377, 41.871210030147004, 53.34130321230207, 58.15414319719587, 56.515031882694785, 56.69724491664341, 44.689163139888215, 0.41926030122808045, 0.047042113595775197, 0.03501521948991077, 3.7185877306120734, 57.08867168426514, 54.069130488804404, 54.98167215074812, 52.94876473290579, 49.15391574587141, 44.008045128413606, 44.44457612718855, 40.36397899900164, 39.54645395278931, 38.39870534624372, 35.46727425711495, 36.485779421670095, 39.19921425410679, 38.89725249154227, 42.51330348423549, 42.568552085331504, 41.9428459576198, 40.82720497676304, 40.72364207676479, 39.73048046657017, 37.80983509336199, 35.17120109285627, 34.613420554569785, 33.288923672267366, 36.68970905031477, 34.08503089632307, 34.52082538604736, 34.836582796914236, 35.05391550064087, 35.626005853925435, 36.06632709503174, 35.56084564753941, 36.007472378867014, 35.780214173453196, 36.268860135759624, 35.052616187504356, 35.48701408931187, 33.784611633845735, 35.249767848423545, 34.01758473260062, 35.3209035055978, 35.269490310123985, 36.18226473672049, 37.22295549937657, 36.21739830289568, 33.41540173121861, 39.3867426599775, 43.08377143314907, 43.25412041800362, 45.85575178691319, 40.573519298008506, 33.88179956163679, 33.46004738126482, 34.74277169363839, 32.89164652143206, 34.08862658909389, 37.69521760940552, 36.419347694941926, 36.61061075755528, 35.495626381465364, 33.63836594990322, 34.66169316428048, 36.84439679554531, 36.5096047946385, 38.1238693509783, 35.49647406169346, 34.30507687159947, 36.32869454792568, 35.36421857561384, 37.232172284807476, 37.044383321489605, 35.01387998035976, 35.02216223308018, 32.88007429667881, 34.54702704293387, 34.75239494868687, 35.85904148646763, 35.45541368212019, 38.22214467184884, 42.61189494814192, 45.39564902441842, 44.96520117350987, 44.834658418382915, 39.40524223872593, 34.00387593678066, 36.303246770586284, 36.35619899204799, 35.206376348223, 34.86243009567261, 34.262779712677, 35.30363375799996, 37.144996711185996, 35.377058846609934, 35.20728308813912, 37.16765826089041, 36.054508209228516, 35.53406729016985, 36.751791204724995, 35.746703011649, 32.96140990938459, 34.20246934890747, 33.434874057769775, 35.43377004350935, 34.09086043494088, 35.6279548236302, 35.33180522918701, 37.681168351854595, 36.45955344608852, 36.20730604444231, 36.74558993748256, 36.91399342673165, 37.11343799318586, 38.301378454480854, 38.25876862662179, 38.03359488078526, 38.61763613564627, 40.03604487010411, 40.18416656766619, 40.96717643737793, 41.35888113294329, 42.351747444697786, 42.82046944754464, 49.226965631757466, 49.21312829426357, 50.73139306477138, 47.1973169190543, 56.17950337273734, 57.13463054384504, 61.59906700679234, 7.992665699550083, 1.2268383226224353, 0.3050377517938614, 0.6172710146222795, 7.210586888449533, 66.18808119637626, 56.368664605276926, 67.77346556527274, 61.66113526480538, 52.71460001809256, 34.57560150963919, 39.63119765690395, 47.89905023574829, 64.67402008601597, 25.781707763671875, 0.41522833758166855, 0.06527696869203023, 0.01509264254543398, 0.05921657889017037, 0.02788364002481103, 0.08730117045342922, 0.040000423057270904, 0.17507887605045522, 0.1835492051073483, 0.09411242032157523, 0.10594734669263874, 0.24489913880825043, 0.1422331535390445, 0.15247496111052378, 0.14055951977414743, 0.20734213053115777, 0.19526544213294983, 23.006465230669292, 69.27940423148019, 55.27120358603341, 41.58474622453962, 33.72803940091814, 48.55022498539516, 57.51274456296648, 59.98363862718855, 61.833339418683735, 59.71572303771973, 50.19826473508562, 0.5712843622480119, 0.19237393300448144, 0.20568493088441236, 4.686368874141148, 60.63212094988142, 55.11902414049421, 58.10251113346645, 53.97135196413313, 52.045655250549316, 46.68999419893537, 46.88847991398403, 41.99930354527065, 42.87842437199184, 39.82709864207676, 38.18440900530134, 38.871002197265625, 42.4339029448373, 41.57163497379848, 46.32409858703613, 45.18129709788731, 44.377814361027305, 43.21272652489798, 43.06270102092198, 43.14833409445626, 39.3606139591762, 38.11840806688581, 37.43939535958426, 35.45408310209002, 38.76999276024954, 36.908921241760254, 35.98984479904175, 38.45126152038574, 37.77881486075265, 38.094638279506135, 39.512220178331646, 39.32972921643938, 38.05520377840315, 38.688608510153635, 38.32843126569475, 35.35539436340332, 35.54690408706665, 34.79862131391253, 36.639077527182444, 36.26759556361607, 38.143928800310405, 37.927054677690776, 39.0479484966823, 39.0603996685573, 39.116304874420166, 35.25431891850063, 41.84464011873518, 44.18931668145316, 44.91755390167236, 48.994920117514475, 42.26620469774519, 33.615878105163574, 34.38602338518415, 36.29763262612479, 33.50066655022757, 33.983031341007774, 39.196969985961914, 39.2402468408857, 39.87113285064697, 37.797234535217285, 36.23495292663574, 36.80264507021223, 38.89191974912371, 38.17835365022932, 41.694176878247944, 37.19192484446934, 35.95723342895508, 38.827336243220735, 35.81701183319092, 38.6716479573931, 39.116346563611714, 35.50751822335379, 36.5896897315979, 34.09123911176409, 34.828665324619834, 34.75331211090088, 36.593156882694785, 36.1996282849993, 40.17887551443917, 43.681458950042725, 46.56633016041347, 47.10997806276594, 46.88589865820748, 42.69925117492676, 36.70892776761736, 37.23844303403582, 37.48457949502127, 37.592064653124126, 36.46277046203613, 35.68261282784598, 35.97765418461391, 39.097027097429546, 37.640538760593955, 35.386612619672505, 39.437245641435894, 38.667795181274414, 38.16603796822684, 38.015557357243125, 38.66093383516584, 35.18083477020264, 35.89028058733259, 35.980040890829905, 38.22249902997698, 36.69872433798653, 39.30075175421578, 36.97304616655622, 39.407958984375, 37.95587927954537, 38.56495141983032, 38.907806805201936, 41.0448260307312, 40.47657108306885, 39.306595189230784, 39.41897535324097, 38.80022784641811, 41.687513555799214, 41.63723986489432, 41.25816004616873, 44.81988654817854, 43.53133269718715, 44.54928547995431, 45.27572659083775, 50.246433121817454, 51.550300802503315, 53.99505226952689, 48.764340673174175, 58.88941546848842, 59.973647117614746, 63.830877031598774, 9.596524459975106, 1.3451716814722334, 1.2594932275159019, 0.9121626594236919, 8.10938240800585, 71.6149925504412, 60.442768641880576, 70.91084126063755, 65.83566856384277, 58.62341758183071, 37.53060436248779, 46.26857900619507, 57.69277933665684, 71.84824357713971, 32.31277125222342, 0.5694943868688175, 0.33706579889569965, 0.12868572691721575, 0.12717954202422074, 0.10468584831271853, 0.18492494842835835, 0.21687735244631767], [0.06272212149841444, 0.06870260701647826, 0.0686419459858111, 0.013698817962514502, 0.09495573756950242, 0.06763278799397604, 0.0667157479162727, 0.06548153342945234, 0.06681885809770652, 0.04594309042607035, 6.986152257238116, 52.128206798008506, 42.55871343612671, 36.11082335880825, 22.984903233391897, 32.05199841090611, 47.912293502262656, 52.670756884983604, 53.09016752243042, 48.73101363863264, 47.81320871625628, 3.27037159885679, 0.5274939920221056, 0.2543798200786114, 0.1621360241302422, 19.90304364476885, 60.09531702314104, 51.543026038578574, 53.18347488130842, 46.64413608823504, 44.63058982576643, 45.04908330099923, 39.96698325020926, 36.67784152712141, 36.59250375202724, 38.275642326899934, 42.09008870806013, 47.42203555788313, 48.93616962432861, 43.91866002764021, 42.74202428545271, 42.19906772886004, 40.75394664491926, 39.46270036697388, 37.762170451028005, 36.90689584187099, 34.446900027138845, 31.907788549150737, 33.40063680921282, 32.35016993113926, 32.3005667413984, 33.26654699870518, 33.67654282706124, 32.394839899880544, 33.8059287071228, 33.29911320550101, 30.839065279279435, 32.07809584481375, 32.84195647920881, 33.73072835377285, 33.98831197193691, 34.56501245498657, 33.55534192493984, 33.88309192657471, 31.55637993131365, 32.95659133366176, 33.637511321476524, 34.49392543520246, 36.11448505946568, 35.249187673841206, 32.75367614201137, 35.540543011256624, 40.52335677828108, 41.52089922768729, 44.765961578914094, 40.049635546548025, 34.29130901609148, 33.643806389399934, 33.2760625566755, 32.94612387248448, 34.75988858086722, 35.2261335509164, 36.34849343981062, 33.74384307861328, 32.145885944366455, 33.31188746861049, 34.42760140555245, 35.38302387510027, 34.74005842208862, 35.09793928691319, 33.32337284088135, 32.23933574131557, 33.5884188243321, 35.21298061098371, 34.37251261302403, 34.41500084740775, 34.492494106292725, 33.31496899468558, 31.82274259839739, 33.059879779815674, 35.740425314222065, 35.91761132649013, 34.853053501674104, 38.2427773475647, 43.66434553691319, 44.331216267177034, 41.17763042449951, 41.80164813995361, 37.670964922223774, 32.34895747048514, 34.98637901033674, 34.92580114092146, 34.25610944202968, 33.90994324002947, 33.139228207724436, 35.240422521318706, 34.46270717893328, 33.35466752733503, 34.82537882668631, 34.08250175203596, 33.58837366104126, 35.428100313459126, 34.66668544496809, 33.12693337031773, 32.20078713553292, 31.807939461299352, 31.888997146061488, 33.312943594796316, 33.38402019228254, 32.496808188302175, 33.54536083766392, 32.46845953805106, 33.953296525137766, 33.72908510480608, 32.937132903507774, 34.26666028159005, 33.85254764556885, 34.45234394073486, 35.57934522628784, 34.43108940124512, 34.1218250819615, 36.56776816504342, 36.16507141930716, 35.110748291015625, 35.16535070964268, 37.83343464987618, 38.80793687275478, 39.75466019766671, 38.81315844399588, 41.42844302313668, 44.225374358040945, 54.54179559435163, 52.725004945482524, 60.007387569972444, 5.541257858276367, 0.7673082979662078, 0.22651020197996072, 0.5547034091183117, 9.253094979694911, 60.36899266924177, 50.47314241954258, 59.93495954786028, 49.59572390147618, 46.897773129599436, 30.029179777417863, 38.79818507603237, 42.62807730266026, 55.11915268216814, 10.818255748067584, 0.3411010466516018, 0.06499969892735992, 0.04665318410843611, 0.03404380840116313, 0.06547183037868567, 0.04049926843228085, 0.017222798063552806, 0.04246053997693317, 0.04905717261135578, 0.03609870760036366, 0.05379542675135391, 0.01531978723193918, 0.014405193272978067, 0.10345390013286046, 0.021177144089181508, 0.05717992889029639, 0.09140870254486799, 9.596126675605774, 61.69024126870291, 48.82855592455183, 39.82385383333479, 22.626044409615652, 37.43843303407942, 55.19168840135847, 54.278375489371165, 57.78519037791661, 53.6607084274292, 52.47966405323574, 3.4672533656869615, 0.6010834489549909, 0.3188668383019311, 0.14389681283916744, 22.636049815586635, 60.75926603589739, 52.374437059674946, 55.26834092821394, 48.36238391058785, 45.77731704711914, 45.59131724493844, 42.263817991529194, 38.17063420159476, 37.43622350692749, 40.59369339261736, 43.896526541028706, 49.06060143879482, 49.45779173714774, 47.31239298411778, 45.51370586667742, 45.24127394812447, 42.63040147508894, 41.95331341879708, 40.323637757982524, 38.08273948941912, 36.30819388798305, 34.03829383850098, 35.32785865238735, 34.488988740103586, 33.86432484218052, 34.981716769082205, 35.451526165008545, 34.64439909798758, 34.87003142493111, 34.777908733912874, 34.060750416346956, 34.83173295429775, 35.372229848589214, 34.90346268245152, 34.93292651857649, 34.81142684391567, 35.43291541508266, 36.12511232921055, 33.835847650255474, 34.74273695264544, 34.16064119338989, 36.68519272123064, 37.300438335963655, 36.82525798252651, 33.61592674255371, 36.61091995239258, 43.21691281454903, 42.81806189673287, 44.563862800598145, 40.399915082114084, 34.27313947677612, 34.30232538495745, 34.01416621889387, 34.308804580143516, 35.34373181206839, 36.59964302607945, 35.68004894256592, 35.851009368896484, 35.06476511274065, 35.33260079792568, 36.997416973114014, 36.23797539302281, 37.59288106645857, 35.25263745444161, 34.765391554151265, 34.17194938659668, 33.7957878112793, 35.605588572365896, 35.35152769088745, 35.987579686301096, 35.032775606427876, 35.04794699805123, 33.09668786185128, 33.510918617248535, 34.60685798100063, 35.36439575467791, 35.00183527810233, 38.56812674658639, 44.39921481268746, 45.493180888039724, 44.17999219894409, 45.59422159194946, 38.823709283556255, 34.9870217187064, 37.558442320142476, 36.02214697429112, 35.886406966618125, 34.11786460876465, 33.78158221926008, 35.84375892366682, 36.216904980795725, 33.86262600762503, 36.30061687741961, 36.040556226457866, 36.1010194505964, 36.44913114820208, 36.71928405761719, 35.05505847930908, 34.8974038532802, 33.925201484135215, 33.92823089872088, 35.38606023788452, 34.63133995873587, 35.91556160790579, 34.673439093998496, 35.80945566722325, 35.89077043533325, 35.74353115899222, 36.60724088123867, 37.149763175419395, 36.43916048322405, 37.59284632546561, 38.16586078916277, 36.429096017565044, 36.27339383534023, 37.011257784707205, 38.137779644557405, 37.61925990240914, 37.80762209211077, 40.38208947862898, 40.43659462247576, 41.2333619253976, 40.534713608878, 43.88498905726841, 46.64458772114345, 56.69584832872663, 55.732477119990754, 62.83274051121303, 6.632605765547071, 0.7523144111037254, 0.6908841388566154, 0.7675324316535677, 9.451304503849574, 67.37140110560826, 55.37744154248919, 64.440810748509, 56.01659590857369, 53.312919821058, 35.42984431130545, 44.14968415669033, 48.52296025412423, 63.552337646484375, 15.424184458596365, 0.3763630459351199, 0.08260094480855124, 0.06036924025309937, 0.04381377289869955, 0.06822592938052756, 0.05887727066874504, 0.0335684030183724, 0.12466615332024437, 0.1337757437889065, 0.1765129326709679, 0.09458076554749693, 0.21575170356248105, 0.1410460565239191, 0.14984759209411486, 0.20518007368913718, 0.1802276269133602, 0.2568173621382032, 11.700182778494698, 72.27309117998395, 55.40997995649065, 47.624019690922324, 33.18459299632481, 43.38693870816912, 57.98493371691023, 62.323152678353445, 63.3378050667899, 58.322331292288645, 57.11705507550921, 4.291854066508157, 0.9399887834276471, 0.44690533780625885, 0.15949095892054693, 24.887248788561138, 63.10558237348284, 56.4887364251273, 59.40297072274344, 50.42496708461216, 48.38943324770246, 48.94333669117519, 43.79406145640782, 40.3186593736921, 38.899215357644216, 43.549314635140554, 46.86081566129412, 51.86092349461147, 51.55669314520699, 48.631828103746685, 47.7122757094247, 48.64304249627249, 44.37003237860543, 45.92299992697579, 41.88867780140468, 40.64327573776245, 39.05838469096592, 35.47735956736973, 38.2290164402553, 36.11992202486311, 35.95911291667393, 38.24121400288173, 37.616623061043875, 37.27713407788958, 37.04695068086897, 37.15536689758301, 34.0704778943743, 35.912956033434185, 36.16534239905221, 38.03014857428414, 37.69417537961687, 37.86968340192522, 37.83071790422712, 38.56283916745867, 35.19699280602591, 36.06062957218715, 35.937642983027864, 37.95015396390642, 39.04052087238857, 39.43709625516619, 35.28732981000628, 38.878110204424175, 44.776759079524446, 43.69152341570173, 48.30131271907261, 39.87691375187465, 35.16932160513741, 34.58079528808594, 34.32671703611101, 34.54440062386649, 37.80562448501587, 37.39807789666312, 39.60619109017508, 37.667487348829, 36.253125940050396, 37.882377760750906, 39.50512259347098, 38.4073280606951, 39.63662420000349, 37.979534421648296, 37.0676771572658, 36.59188188825335, 37.31724950245449, 39.73605292184012, 39.06841788973127, 36.88637433733259, 36.27689225333077, 35.393685885838096, 33.890526499067036, 34.593791893550325, 35.508202620915, 35.98664167949131, 36.289082867758616, 39.79634244101388, 46.72821971348354, 49.01848145893642, 44.635877404894146, 46.6194178717477, 41.30644307817732, 36.400934968675884, 39.295936652592246, 36.96909611565726, 37.812395504542756, 36.12588357925415, 36.60307543618338, 39.20897994722639, 38.65172747203282, 35.33290304456438, 38.23318188531058, 38.85332250595093, 38.05504049573626, 38.980988706861226, 39.16796473094395, 37.29586294719151, 37.27038737705776, 35.96718324933733, 36.09409557070051, 38.55157266344343, 37.37693452835083, 36.47486727578299, 37.0576092175075, 37.323044300079346, 38.584941387176514, 37.25065796715872, 38.09524972098214, 38.32563461576189, 39.09800679343087, 39.50856195177351, 41.57586990083967, 37.146153586251394, 37.85529020854405, 40.425116198403494, 40.2242750440325, 39.286160537174766, 39.74920586177281, 43.01663793836321, 41.51992647988455, 43.176224163600374, 42.0176294190543, 47.041774545397075, 49.20286580494472, 58.41171291896275, 57.33940437861851, 65.60992159162248, 7.1978230476379395, 0.7560719751885959, 2.45493991460119, 1.4377203839165824, 11.00869631767273, 72.67828232901437, 60.02933692932129, 69.30152034759521, 59.45148304530552, 61.44079399108887, 42.797853061131065, 50.23607683181763, 56.015828132629395, 71.34588881901333, 22.144044399261475, 0.5553517628993306, 0.22956275460975512, 0.15382645358996733, 0.07335665835333721, 0.15903742611408234, 0.17422863095998764, 0.18812764728707926], [0.046933493709989955, 0.05352044025702136, 0.03986480087041855, 0.04572210853387203, 0.07774411328136921, 0.025447151390835643, 0.12387747849736895, 0.052718293121350665, 0.025485936452501586, 0.05816415750554629, 4.856670090130397, 47.83332027707781, 50.392897674015586, 39.33539547239031, 31.87240137372698, 32.39360312053135, 46.22745609283447, 56.77083328792027, 52.666685240609304, 46.6245630128043, 52.24815355028425, 7.521515301295689, 0.5023359219942773, 0.15666822610156877, 0.07251224866403, 1.436186460512025, 46.64383036749703, 55.660566738673616, 50.75279699053083, 51.06516368048531, 42.841595445360454, 43.91319179534912, 38.749301024845664, 36.45391845703125, 41.09964731761387, 46.684901169368196, 51.224176679338726, 49.6199939591544, 42.992183753422324, 41.446987765175955, 40.64578056335449, 44.6964795930045, 42.712181772504536, 41.76746300288609, 36.622450487954275, 34.46141481399536, 33.104591437748496, 32.36503560202462, 32.98794855390276, 32.68962069920131, 32.984248638153076, 31.93986143384661, 32.49888917378017, 32.24323715482439, 32.00814485549927, 33.10560587474278, 33.70326907294137, 33.11282157897949, 34.45955269677298, 34.033798354012625, 33.94976684025356, 33.58996479851859, 33.05698932920183, 33.55001960481916, 33.98125260216849, 35.535648005349294, 33.81850842067173, 35.04156160354614, 35.6370222227914, 34.26587860924857, 32.0394013268607, 34.19158499581473, 38.50041307721819, 39.92117377689907, 44.47452286311558, 41.78790807723999, 36.92165034157889, 34.342308793749126, 31.57173545019967, 32.21892540795462, 33.92081369672503, 36.09967497416905, 34.58046872275216, 33.19270849227905, 33.611813408987864, 32.60292107718331, 35.054245540073936, 35.74904108047485, 34.438659463609966, 33.862278597695486, 34.96583318710327, 33.39603015354702, 31.76868908745902, 34.75133882250105, 33.62731831414359, 34.70679044723511, 34.27258709498814, 32.81266982214791, 32.254969188145225, 33.135083607264924, 33.67852306365967, 36.27177143096924, 39.645142691476, 38.30274377550398, 42.62878254481724, 44.09434870311192, 42.24473476409912, 41.06583390917097, 35.18061242784773, 33.665759222848074, 35.930663517543245, 35.51105833053589, 35.752782685416086, 36.84005069732666, 34.41365984507969, 33.387271949223106, 34.5097291128976, 33.46145786557879, 32.460517747061594, 33.78769663402012, 33.3240259715489, 33.06575795582363, 33.782485485076904, 34.173359870910645, 33.40194307054792, 32.43444463184902, 32.34665066855294, 33.55271897997175, 32.0802115712847, 34.80803959710257, 33.04127597808838, 34.50556019374302, 34.19078247887747, 34.015997069222585, 34.5068872996739, 34.69855683190482, 34.574594020843506, 35.94293751035418, 37.38254519871303, 38.26039797919137, 38.55984796796526, 41.50918109076363, 42.635869707380024, 41.326103006090435, 43.012267521449495, 41.24413858141218, 38.43398829868862, 38.515372548784526, 40.40283679962158, 40.91891424996512, 45.95491647720337, 55.36429555075509, 54.94703538077218, 57.16506712777274, 4.108614870480128, 0.577152604503291, 0.26556707120367457, 0.3365014748913901, 10.289300680160522, 63.205900464739116, 50.78231988634382, 63.106985909598215, 51.67496190752302, 45.169495582580566, 21.373878274645122, 36.01405579703194, 42.484551838466096, 50.415399415152415, 5.794232215200152, 0.1928133387118578, 0.03675663551049573, 0.06510002032986709, 0.08174895588308573, 0.1086921701207757, 0.0642420874376382, 0.05135311119790588, 0.06870267486998013, 0.034710479235010486, 0.05796567922724145, 0.06527439704430954, 0.07372622245124408, 0.02648179855064622, 0.010858017452327269, 0.053319495503923724, 0.03349833409967167, 0.16824081726372242, 6.235678195953369, 55.09047746658325, 52.23232902799334, 44.00983428955078, 32.060124329158235, 37.36205843516758, 51.8616669518607, 60.101716314043315, 57.10789734976632, 51.386521339416504, 56.05372708184378, 7.4825619629451205, 0.7011994453413146, 0.4115620500275067, 0.10717124744717564, 2.0123036205768585, 50.34279073987688, 56.417145660945344, 53.35908365249634, 53.234988825661794, 45.66769184385027, 45.77884912490845, 40.48433916909354, 38.00833123070853, 43.5156957762582, 47.34836033412388, 53.33676603862217, 51.46749217169625, 45.076521737234934, 43.60638019016811, 42.92813525881086, 46.43959501811436, 44.30919395174299, 42.76545361110142, 40.00313125337873, 37.84704269681658, 34.67164298466274, 34.91689355032784, 36.20369298117501, 34.96088259560721, 35.12203563962664, 35.31773165294102, 33.87718595777239, 34.25779438018799, 34.3128136907305, 35.66518327168056, 34.679004601069856, 33.942422594342915, 35.40056112834385, 36.01014396122524, 34.63402196339199, 34.804141657693044, 34.443564891815186, 35.63771704265049, 36.21916661943708, 37.899011748177664, 36.00913994652884, 36.47264732633318, 37.26513106482369, 36.836538382938926, 33.15466710499355, 36.63627392905099, 42.304833207811626, 42.3764100755964, 45.71243824277605, 43.17173562731062, 37.508252007620676, 34.68675879069737, 32.44341823032924, 32.144934041159495, 35.835876192365376, 37.19873060498919, 36.225034373147146, 36.4115309715271, 34.69399186543056, 34.47764580590384, 36.23493903023856, 36.00115646634783, 36.57236092431204, 36.060219628470286, 36.98433004106794, 34.728663376399446, 34.56815651484898, 34.96363755634853, 36.248616559164866, 35.69593252454485, 37.042180742536274, 34.805076190403526, 33.03900044304984, 33.5549076625279, 35.71392141069685, 36.69940526144845, 38.27616344179426, 40.62458855765206, 45.354956899370464, 46.238458565303254, 42.855821881975444, 43.99663271222796, 36.96882166181292, 35.541995184762136, 37.40142692838396, 37.66149452754429, 36.768769127982004, 38.1619176864624, 35.622583866119385, 36.3500394139971, 35.45206117630005, 35.157725061689106, 33.59238624572754, 35.28791693278721, 34.843322549547466, 35.9036454473223, 34.92354992457798, 35.17073556355068, 35.03631918770926, 35.04483767918178, 32.97962808609009, 35.411334310259136, 34.96456514086042, 35.35289648600987, 34.41219030107771, 36.60138007572719, 35.12574250357491, 36.706787722451345, 36.41897944041661, 37.713557379586355, 37.131089891706196, 38.52944612503052, 39.30267293112618, 39.80872065680367, 41.226983479091096, 43.23540544509888, 43.86074331828526, 42.80478736332485, 43.82705497741699, 43.715546812329976, 40.0165239061628, 41.28767251968384, 42.56549835205078, 43.316369329180034, 47.49595396859305, 58.075381892068044, 57.535583291734966, 59.64166218893868, 4.581465840339661, 0.8893858130489076, 0.7052185439637729, 0.5612431839108467, 11.280752164976937, 68.18492398943219, 55.734182902744834, 67.17070238930839, 54.659859384809224, 52.49629456656319, 26.024144308907644, 40.9240837097168, 46.76940516063145, 59.17731407710484, 9.754282440458026, 0.3097021372190544, 0.046585232218993564, 0.04676622464986784, 0.04471656713368637, 0.060019374026783874, 0.01956785240742777, 0.025660223261054074, 0.2295601490352835, 0.11228218355349132, 0.15468747381653103, 0.09387049544602633, 0.15975969950003283, 0.11183665746024676, 0.25612354651093483, 0.16311289742588997, 0.25359706208109856, 0.18043247663549014, 6.656347325869969, 63.59633363996233, 61.40760244641985, 48.51282978057861, 42.38656834193638, 44.609064306531636, 57.23835325241089, 63.98556477682931, 62.07922921861921, 56.35097796576363, 60.57995387486049, 8.836358530180794, 0.9778431121792112, 1.4863762302058083, 0.18885163058127674, 2.4571461847850253, 51.787481035505024, 58.30463423047747, 54.916720390319824, 55.722027029309956, 46.47869253158569, 48.86235891069685, 41.59355306625366, 40.6088786806379, 47.573909282684326, 49.49058028629848, 52.88152354104178, 52.616588728768484, 46.690338134765625, 45.97952699661255, 45.088722773960654, 48.6130644934518, 46.61516557421003, 45.59961339405605, 41.03864213398525, 39.32695688520159, 37.82026433944702, 35.613082204546245, 38.42115150179182, 36.80103308813912, 37.694734709603445, 37.527752126966206, 36.401150362832205, 35.42732906341553, 37.058241503579275, 39.483381680079866, 38.87184292929513, 36.5238972391401, 38.27811241149902, 38.30214623042515, 37.03310292107718, 37.59436798095703, 36.274057388305664, 36.643322876521516, 36.842583315713064, 39.38064908981323, 37.255556447165354, 38.87256901604788, 40.48803908484322, 38.55555745533535, 35.79233530589512, 37.81306947980608, 45.40124579838344, 45.82367890221732, 47.55151176452637, 44.048931803022114, 37.235285077776226, 35.35041945321219, 33.10280575071062, 33.3670665877206, 37.12786940165928, 39.747232573372976, 38.77945968082973, 38.64932686941964, 37.139372144426616, 36.12903806141445, 38.787307671138215, 39.01672676631382, 38.115100724356516, 36.81355026790074, 39.517872537885395, 36.89592463629586, 36.05987916673933, 37.94982739857265, 38.89312873567854, 37.11661679404122, 38.272609438214985, 35.013129574911936, 35.94590786525181, 34.07835715157645, 36.04965489251273, 36.66719341278076, 39.119990893772666, 41.615002155303955, 48.36616025652204, 48.5026159286499, 46.17942667007446, 45.11569915499006, 38.72736208779471, 36.62625115258353, 38.909102644239155, 39.89596918651036, 39.377716950007844, 39.90671110153198, 37.19619451250349, 37.760534150259836, 38.34898056302752, 38.02131741387503, 34.754545416150776, 36.82051931108747, 36.949432713644846, 37.683596747262136, 39.097944259643555, 39.4397782598223, 38.11544118608747, 37.35867118835449, 36.034455708095, 39.30595595496041, 37.1933388028826, 38.71884707042149, 37.6057665007455, 39.6622838973999, 38.5975558417184, 39.09957013811384, 40.654340744018555, 40.61436080932617, 39.70078386579241, 40.31093297685896, 42.18288884844099, 41.833196435655864, 42.53641666684832, 45.610706193106516, 46.38588891710554, 45.56177697862898, 46.1549585887364, 45.76865611757551, 42.2072422845023, 43.40434741973877, 43.97839021682739, 44.93653290612357, 48.72172737121582, 61.32391139439174, 60.06872626713344, 62.948671204703196, 5.733691692352295, 0.8053688470806394, 2.1832403796059743, 0.679189669234412, 12.760832241603307, 74.07115295955113, 59.38513469696045, 72.55898870740617, 61.98361505780901, 57.41476106643677, 31.51759856087821, 45.94945519311087, 54.64562599999564, 67.42137254987443, 13.780822583607264, 0.41718349552580286, 0.1050348731556109, 0.15794303055320466, 0.1515929334397827, 0.17284923712057726, 0.10568360691624028, 0.1150338194732155], [0.010267298435792327, 0.006053827095976365, 0.03424354875460267, 0.058177687493818145, 0.044272102947746, 0.06713356942470584, 0.059677833425147195, 0.021937832735212784, 0.1740634348243475, 0.05222336967874851, 2.5417248691831316, 47.635734353746685, 48.65870720999581, 36.070318835122244, 30.423187800816127, 28.330637046269008, 52.026085649217876, 53.996817111968994, 54.94419009344918, 46.314489228384836, 55.891538756234304, 17.440895625523158, 0.17534129268356732, 0.3925076467650277, 0.1718772899891649, 0.03966817160003951, 24.145512955529348, 63.299687249319895, 46.571006298065186, 51.31871386936733, 43.53332683018276, 43.585709299360005, 35.90379135949271, 42.04462317058018, 43.26550851549421, 51.71896137510027, 46.77010692868914, 42.19303321838379, 40.48845945085798, 44.50016171591622, 44.21333312988281, 44.23402486528669, 42.35626029968262, 40.246179240090505, 35.54823119299752, 33.83176905768258, 31.584745952061244, 33.39162846973964, 31.515319551740372, 32.986715248652864, 31.940309592655726, 33.33043221064976, 31.645942211151123, 32.25918327059065, 32.16178689684187, 32.687442438943044, 30.268288135528564, 32.600583008357454, 32.70863791874477, 34.32032469340733, 32.01997763769967, 32.83354915891375, 33.949752943856375, 34.54753426143101, 33.86785452706473, 33.858669008527485, 34.05546283721924, 36.207941804613384, 35.06738805770874, 33.66445296151297, 32.24748945236206, 34.65970597948347, 39.20469985689436, 40.6456971849714, 41.001979964120046, 43.06098828996931, 34.774059431893484, 35.340143067496165, 33.06779725211007, 33.91135719844273, 33.23501607349941, 35.268736430576865, 35.16194609233311, 34.36057560784476, 33.24705382755825, 34.106876032693044, 34.34213161468506, 35.248482431684224, 33.880156312670024, 33.55840955461775, 33.98602601460048, 33.47381176267351, 33.05619723456246, 32.96852486474173, 33.538700989314485, 34.56855951036726, 35.29785980497088, 34.1375766481672, 32.58192362104143, 32.923201765332905, 34.41653987339565, 36.06787306921822, 40.902943815503804, 44.34397315979004, 41.95004776545933, 42.807921000889365, 39.41897882734026, 37.407114028930664, 33.179795265197754, 31.723022052219935, 35.92999301637922, 35.6361745425633, 35.12016657420567, 35.17318480355399, 32.97990948813302, 34.23166915348598, 32.89843838555472, 34.41977078574044, 34.325438567570274, 35.52799456460135, 34.706370081220356, 33.94006715502058, 33.20922436032976, 33.41023227146694, 32.75140060697283, 32.61673757008144, 32.04280594417027, 33.40122740609305, 32.54834297725132, 33.67057432447161, 33.79949467522757, 36.08430903298514, 35.23807750429426, 34.09572764805385, 33.322744028908865, 34.49416514805385, 34.36268091201782, 37.73223066329956, 39.032103129795615, 43.02207490376064, 44.00832305635725, 49.07001972198486, 50.28104209899902, 52.91616725921631, 50.66165052141462, 53.281406266348704, 49.02758707318987, 41.17793961933681, 36.654700551714214, 41.790055070604595, 47.81163147517613, 54.959983348846436, 52.76078469412667, 51.210766656058176, 2.1623601743153165, 0.9174977902855191, 0.8219618509922708, 0.4257543699017593, 12.99600965636117, 63.853104318891255, 45.95226921354021, 62.40571812220982, 49.549949169158936, 45.300392695835654, 30.309678554534912, 46.866249152592246, 49.954122407095774, 41.22637203761509, 1.9305841198989322, 0.1690802736473935, 0.03356863372027874, 0.03336672544745462, 0.041709174402058125, 0.04778759966471365, 0.02552808026250984, 0.025609158411888138, 0.054699316820395846, 0.024223274385024394, 0.053168205943490775, 0.02179229715173798, 0.05898515773671014, 0.08495613307292972, 0.03369107536439385, 0.006690968933980912, 0.13882380005504402, 0.05995454000575202, 3.5343384402138844, 53.123418126787456, 55.6618903705052, 40.43203660420009, 37.49035692214966, 34.52924312864031, 56.10860742841448, 57.56476919991629, 59.35272829873221, 49.524310316358296, 60.29725251879011, 17.601487602506364, 0.2748466618359089, 0.11356795313102858, 0.6350029802748135, 0.013527484477630683, 25.757189307894024, 65.53884846823556, 49.19229064668928, 53.5355783190046, 44.642495564052034, 45.04693283353533, 37.84855393001011, 43.06277397700718, 44.38963672092983, 53.335696016039165, 48.56051179340908, 44.486842019217356, 43.75962618419102, 46.207400117601665, 45.88627174922398, 46.42401715687343, 45.26960522787911, 43.370023318699424, 37.06442192622593, 35.26025268009731, 33.65665013449532, 35.02026537486485, 34.7079507963998, 34.602418082101, 33.75268118722098, 35.689581871032715, 34.370914527348106, 35.08698892593384, 34.160377161843435, 33.21390397208077, 32.613989557538716, 34.486404010227744, 34.720440183367046, 36.030234677451, 34.345901012420654, 36.82936436789376, 34.103617327553884, 34.775028705596924, 35.83020298821585, 35.73529406956264, 35.45310688018799, 37.59659487860543, 37.09252738952637, 36.382629939488, 33.08577571596418, 35.28271273204258, 42.87210498537336, 42.58761099406651, 43.943722179957796, 44.43900714601789, 36.33778626578194, 35.96941014698574, 33.74734844480242, 34.931696687425884, 35.09180402755737, 35.94693272454398, 35.086676256997244, 36.470326628003804, 34.40631212506975, 35.458342347826274, 34.73163720539638, 36.176299708230154, 36.20613179888044, 35.005667209625244, 35.87735346385411, 34.87346036093575, 35.00071314402989, 36.25580447060721, 35.59043107713972, 35.62317098890032, 35.671189989362446, 34.68264198303223, 34.20391110011509, 33.563895157405305, 34.19050107683454, 36.129017216818674, 41.681048257010325, 44.708843912397114, 44.67043774468558, 43.99052177156721, 42.11344855172293, 41.42600767953055, 35.75153200966971, 34.143628529139924, 36.393434388296946, 36.622082233428955, 35.6020519392831, 36.71915551594326, 35.391097681862966, 34.674595969063894, 35.31074523925781, 35.607113701956614, 35.35864264624459, 37.174168722970144, 35.35031523023333, 35.21591622488839, 34.73981523513794, 35.886948926108225, 35.18074444362095, 34.76001017434256, 33.57745109285627, 36.14222574234009, 33.28834697178432, 36.7384089742388, 35.31739466530936, 37.52402094432286, 37.27040127345494, 36.79018695013863, 34.852146761757986, 37.441809858594624, 36.8979674066816, 39.35981491633824, 41.13580921718052, 45.07164062772478, 47.02617583956037, 50.661970138549805, 51.88892126083374, 55.29821123395647, 53.13587277276175, 56.251552718026296, 51.30925389698574, 42.97870772225516, 39.12171057292393, 43.942454133714946, 50.57971388953072, 57.52496297018868, 55.03006635393415, 54.25789219992501, 2.6699996888637543, 0.6369900022234235, 0.9409405780690057, 0.5965702139905521, 14.788122040884835, 69.82835360935756, 51.67844295501709, 67.52251747676304, 54.62804358346121, 48.16827208655221, 25.698975563049316, 48.54648338045393, 55.170253208705354, 49.56953614098685, 3.321903999362673, 0.23432322059358868, 0.01447011889623744, 0.10803289192595653, 0.034204868865864616, 0.04052170758534755, 0.023219554851363813, 0.04869164240413478, 0.1972572138266904, 0.11203354118125779, 0.1120562788897327, 0.1644372892166887, 0.1459980458021164, 0.21770873426326684, 0.2429963637675558, 0.08161400883857693, 0.25063699377434595, 0.20438172295689583, 4.399512929575784, 60.787003244672505, 62.50264549255371, 47.81156546728951, 43.267002378191265, 39.1088216645377, 63.11492770058768, 62.405294282095774, 65.32480921064104, 53.527188369206016, 65.52518830980573, 21.36710204396929, 0.40421196871570175, 1.451770401426724, 0.7113619457398141, 0.17359576134809426, 27.542940616607666, 67.40325164794922, 51.36517994744437, 55.88281876700265, 47.09307656969343, 47.18606778553554, 39.3749098777771, 45.53451919555664, 47.54451840264456, 54.51200519289289, 51.63994646072388, 45.279676641736714, 44.63505751746041, 47.93371132441929, 47.83952849251883, 48.04661955152239, 47.85286903381348, 46.07818794250488, 39.709055696214946, 38.306249141693115, 35.37052753993443, 36.67464535576956, 36.78371817725045, 36.97580112729754, 35.917767660958425, 38.16464832850865, 36.36806651524135, 36.47121252332415, 35.93306412015642, 36.21367754255022, 34.91727570125035, 36.211544445582796, 35.99912759235927, 37.97788769858224, 35.34707389559065, 36.323552880968364, 36.12080792018345, 37.56996243340628, 37.93868596213204, 38.52137926646641, 35.82156637736729, 38.823434829711914, 39.27655117852347, 38.36990853718349, 36.47384589059012, 38.11537517820086, 44.504789216177805, 45.72375685828072, 44.181187289101736, 45.502435888562886, 36.67371777125767, 36.43718024662563, 33.96481316430228, 37.92853464399065, 36.61694751467024, 39.51972770690918, 37.23088686806815, 37.97696358816964, 37.052821908678325, 36.993977614811485, 38.609690870557515, 37.97649111066546, 37.80005202974592, 36.69440255846296, 37.726592200142996, 38.60798856190273, 36.90843834195818, 38.32760443006243, 36.48868029458182, 37.162155287606375, 38.64360850197928, 36.40649700164795, 35.31195075171334, 34.81558881487165, 34.93639019557408, 37.2671286719186, 41.93491806302752, 45.62643344061715, 46.95057943889073, 45.298266547066824, 43.97607299259731, 43.92931161608015, 37.649001666477744, 35.11517081941877, 39.61181913103376, 38.36610439845494, 37.846514633723665, 38.28855902808053, 36.37000853674752, 37.54614053453718, 37.63561596189226, 38.68797969818115, 37.42529746464321, 39.233416761670796, 39.63443204334804, 36.709761551448274, 37.542447566986084, 37.824151856558665, 38.324317932128906, 37.05520861489432, 36.01663357870919, 39.004320757729666, 35.74228048324585, 38.353858198438374, 37.89740324020386, 41.183668409075054, 41.040636266980854, 38.62519924981253, 37.23570544379098, 39.91275256020682, 38.58864825112479, 41.57416411808559, 43.08991016660418, 47.083046845027376, 47.734607219696045, 53.64156266621181, 54.715719427381245, 56.568352358681814, 55.12568398884365, 56.37374721254621, 52.40984507969448, 47.264214175088064, 41.14903858729771, 46.58925574166434, 52.11854532786778, 60.516190256391255, 57.19449274880545, 55.44018724986485, 3.887517980166844, 1.4051484231437956, 2.7349707739693776, 0.7430950200983456, 17.754914249692643, 74.08750901903424, 54.82649108341762, 73.43250233786446, 58.19841711861746, 58.103852135794504, 42.61558444159371, 58.67919077192034, 63.110835211617605, 59.68560954502651, 5.268702174936022, 0.4764854205506188, 0.21800249921424047, 0.16694359401507036, 0.11712745284395558, 0.18175528065434524, 0.07852179583694253, 0.1148983296006918], [0.046009189914911985, 0.027635438700339625, 0.04715522199070879, 0.042832733398037295, 0.028546161617019346, 0.06661421193608216, 0.042027034131543975, 0.08011773734220437, 0.041214973599250825, 0.02965369022318295, 1.08204904624394, 40.809302943093435, 52.03506619589669, 34.95192289352417, 22.71507167816162, 27.462831360953196, 46.21917036601475, 53.12821585791451, 51.020507608141216, 48.133628368377686, 53.533889906747, 30.954255989619664, 0.10081352360014405, 0.259651032941682, 0.17043779151780264, 0.17670126685074397, 12.392359716551644, 60.197413853236604, 47.194680077689036, 51.7655942099435, 42.40644366400582, 39.81957026890346, 39.619503838675364, 45.717569487435476, 48.49053995949881, 43.48990753718785, 40.1831625529698, 46.59677716663906, 41.93755143029349, 46.35122782843453, 43.27039309910366, 43.22915554046631, 38.86026723044259, 36.36974103110177, 32.25489970615932, 33.35206195286342, 32.382652759552, 35.15680095127651, 31.485890456608363, 34.10357216426304, 31.152706963675364, 33.360167026519775, 32.19305726460048, 34.744227341243196, 32.68452419553484, 33.484678745269775, 32.62146929332188, 35.08305277143206, 33.43609694072178, 34.298010553632466, 33.55679062434605, 33.95279278073992, 33.4884272984096, 32.74160017286028, 34.67604814256941, 34.39115462984358, 33.72928312846592, 33.72654901232038, 34.97900697163173, 32.645708084106445, 31.820018904549734, 34.740909576416016, 37.056407179151265, 39.08683409009661, 42.3529703276498, 43.35583509717669, 36.11249787466866, 33.659127167293, 32.287083762032644, 33.07917840140206, 33.54595838274275, 33.70234496252877, 35.37212562561035, 34.35265118735177, 32.2500707081386, 32.08739948272705, 32.04274688448225, 36.407375948769705, 34.035007340567454, 37.826184204646516, 34.29326145989554, 34.13869530814034, 34.98702866690499, 33.690182140895296, 34.33687877655029, 34.84798131670271, 35.27329444885254, 34.42615965434483, 32.01389101573399, 34.61436898367745, 33.93904576982771, 34.97650909423828, 35.41402326311384, 47.496499402182444, 41.696612221854075, 41.4484920501709, 40.63998923982893, 38.75701699938093, 32.502974714551655, 32.27627236502511, 33.6812676021031, 35.2158328465053, 34.79635272707258, 34.07068286623274, 33.82119737352644, 33.40279769897461, 32.85414709363665, 33.21882677078247, 32.25787353515625, 34.25752340044294, 33.505155086517334, 33.708567074366975, 32.9428825378418, 33.25799376623971, 33.0653931753976, 33.187271526881624, 31.967987741742814, 35.16178628376552, 32.84628520693098, 34.012172085898264, 33.83824825286865, 33.649750573294504, 34.86043248857771, 36.082505975450786, 35.05564212799072, 36.042974199567524, 35.93932792118618, 37.081865378788535, 42.029962471553254, 44.41327796663557, 47.038078103746685, 49.83901507513863, 50.6193915775844, 49.015062945229666, 46.27029173714774, 45.51957014628819, 51.310990946633474, 48.969673837934224, 40.237587792532786, 37.66435718536377, 47.817012854984824, 54.485560349055696, 56.347173827035085, 48.9755311693464, 1.2918794325419833, 0.3794749975204468, 0.5465079003146717, 0.31550133175083567, 17.325407879693167, 63.9545202255249, 49.50934042249407, 63.37185818808419, 49.436259269714355, 43.732764448438374, 20.977546078818186, 43.03244161605835, 55.91631950650896, 34.390501499176025, 1.3811871260404587, 0.1447370291820594, 0.0427437197816159, 0.09003843500145844, 0.0004841252469174963, 0.03934930424605097, 0.0805616145953536, 0.026990072169740285, 0.020773712612156357, 0.06826968131853, 0.03009959290336285, 0.022374856784673672, 0.038321978479091606, 0.05583128286525607, 0.021574729987021004, 0.012538867437147667, 0.03466876968741417, 0.017477818664961627, 1.9826975635119846, 47.374999727521626, 57.83982753753662, 38.54678535461426, 27.869354827063425, 32.939450127737864, 52.54984780720302, 57.58645452771868, 55.18318728038243, 51.234717096601216, 58.56082820892334, 33.5495297568185, 0.0744057617017201, 0.36447446101478165, 0.5165561703698975, 0.16003234844122613, 15.132045711789813, 62.95696040562221, 50.45595605032784, 52.366887841905864, 42.81152711595808, 41.28102656773159, 42.09513657433646, 47.959482192993164, 48.5753288269043, 47.840494292122976, 41.35162026541573, 45.87237535204206, 43.83267259597778, 49.29383162089756, 44.827977725437705, 45.443369252341135, 40.47346871239798, 39.12066486903599, 33.83162661961147, 35.50610773903983, 33.92368677684239, 37.55740009035383, 33.944514002118794, 35.449365275246755, 32.94432428904942, 34.94579805646624, 33.64784329278128, 35.210642542157856, 34.958589690072195, 35.65958997181484, 34.60231038502285, 36.260682106018066, 36.350008147103445, 35.594148363385884, 34.94414438520159, 36.066539015088765, 35.440388202667236, 34.149211406707764, 35.05256755011422, 35.41850137710571, 35.118089062826975, 34.90221548080444, 36.345318113054546, 34.099021094185964, 34.404932907649446, 36.26697022574288, 39.537945883614675, 40.95660475322178, 43.620446818215505, 44.504094396318706, 36.41711384909493, 34.44108785901751, 32.96925095149449, 34.05815873827253, 35.214773246220176, 35.0939336504255, 35.14318248203823, 36.53347533089774, 34.80945702961513, 34.96717766353062, 34.65282031467983, 37.21177237374442, 35.745313371930806, 37.05467012950352, 36.22849457604544, 34.95598064150129, 35.301545824323384, 35.25337743759155, 35.713153634752544, 36.10926696232387, 36.478567191532676, 33.93762138911656, 34.085822990962434, 34.7245500428336, 35.41032682146345, 35.07491295678275, 38.199410166059224, 48.353896686008994, 44.866147654397146, 43.247227805001394, 43.119380950927734, 40.13124213899885, 33.09385994502476, 36.15773064749581, 35.70885269982474, 37.08782345908028, 35.5924460547311, 35.22012683323452, 35.2352739061628, 35.54058470044817, 35.230879170554026, 34.25869069780622, 35.217166900634766, 35.56591783251081, 35.81853001458304, 36.50873626981463, 35.75930009569441, 34.82581656319754, 35.270160811288015, 35.81833893912179, 33.77433524812971, 36.81875099454607, 34.76999126161848, 36.32210418156215, 35.11946133204869, 36.45760795048305, 36.35919713973999, 38.17939935411726, 37.08969947269985, 38.141691480364116, 37.32509401866368, 39.83295249938965, 43.627134459359304, 46.40378400257656, 48.911500045231406, 51.73702669143677, 52.59704344613211, 50.24859401157924, 47.938199860709055, 46.2377359526498, 53.99007041113717, 52.217140265873496, 42.025942938668386, 40.98985535757882, 50.033220699855256, 56.327083110809326, 59.8330294745309, 51.31869649887085, 1.851276295525687, 1.0345467094864165, 0.2537202297576836, 0.2485472144825118, 18.623343535831996, 69.0892528806414, 53.33652979987008, 68.27836336408342, 52.65038129261562, 55.474125725882395, 28.12400804247175, 46.47950547082083, 61.07022571563721, 43.89936140605381, 1.738741208400045, 0.11731396854988166, 0.03393169406003185, 0.03173506246613605, 0.027179461471470337, 0.03436360874080232, 0.04999092161389334, 0.07493464582200561, 0.10558674604232822, 0.23536355048418045, 0.22024097267006124, 0.1353814426277365, 0.1187100950628519, 0.19830574042030744, 0.1696579647915704, 0.22564770254705632, 0.12689311882214888, 0.1285308716552598, 2.285222564424787, 54.15770959854126, 66.09207098824638, 46.67592409678868, 32.30740029471261, 37.77303395952497, 59.46471241542271, 61.12628378186907, 59.57921872820173, 56.869977133614675, 62.75164808545794, 39.03324610846383, 0.23491593450307846, 0.8417910326804433, 1.8129422153745378, 0.24612289028508322, 17.12860883985247, 65.53615951538086, 53.00862693786621, 55.63158580235073, 46.06716809953962, 42.54163476399013, 44.31690297807966, 51.76254047666277, 50.337614331926616, 50.365730217524934, 42.468327794756206, 48.767460414341514, 46.44284677505493, 50.31528282165527, 47.302213873182026, 48.80105495452881, 42.74783297947475, 41.07785081863403, 35.68804284504482, 37.17518663406372, 35.87238202776228, 39.89345741271973, 35.14748689106533, 37.966371059417725, 35.33550861903599, 37.59694923673357, 35.1152229309082, 37.53579814093453, 38.05561719621931, 36.867683683122905, 37.309495312826975, 38.6410585130964, 37.61915915352957, 38.2719076701573, 35.84672580446516, 37.68744952338082, 36.5780063356672, 37.00845071247646, 38.01703037534441, 37.96096536091396, 37.77494818823678, 36.25139931270054, 39.77433402197701, 37.504649366651265, 35.44595718383789, 38.212625639779226, 41.66227422441755, 42.60298040934971, 45.21616663251604, 46.4590117590768, 35.471001965659006, 34.551268918173655, 34.87136895315987, 34.51004525593349, 37.15011058534895, 35.71630464281355, 37.86600085667202, 38.4060252734593, 36.64258636747088, 35.502942834581646, 37.488484382629395, 40.03980384554182, 37.95957224709647, 40.18460430417742, 37.80646174294608, 37.45845774241856, 37.74222217287336, 36.856142725263325, 37.840153557913645, 37.672962529318674, 39.29511676515852, 36.3994654246739, 35.60860409055437, 36.79729495729719, 36.37841585704258, 34.7453807422093, 40.653465270996094, 52.17682681764875, 45.48306431089129, 45.96825701849801, 45.36586209705898, 43.03387641906738, 34.53491285869053, 37.18441731589181, 36.90471410751343, 39.87831033979143, 36.56634031023298, 36.41034630366734, 36.37395511354719, 37.78517246246338, 37.76888935906546, 36.60711233956473, 35.57057659966605, 38.217555386679514, 37.9606214250837, 37.795382840292795, 37.31241703033447, 38.04775183541434, 38.23612444741385, 37.64607994897025, 36.404099873134065, 40.36832857131958, 36.49124070576259, 39.439218929835725, 36.92114312308175, 37.25241238730294, 38.82402195249285, 40.834257398332866, 39.152894088200156, 40.83633490971157, 38.5925600869315, 41.51455899647304, 46.50316061292376, 49.342736516680034, 50.53934138161795, 54.963266372680664, 55.09261056355068, 52.732408251081196, 49.541236128125874, 47.919884409223286, 53.82474844796317, 53.390777860369, 43.632098947252544, 43.275277682713096, 51.122156279427664, 60.15566907610212, 61.492773464747835, 54.40663228716169, 2.5168896189757755, 1.0819976947137286, 1.8121672741004398, 0.5624929911323956, 21.87116605894906, 74.26245076315743, 58.57097257886614, 73.25541360037667, 59.29661464691162, 58.15172522408621, 29.300532613481792, 52.099601064409526, 66.08346911839077, 55.640861647469656, 2.803856517587389, 0.22759668582252093, 0.19709264194326742, 0.15095208425606998, 0.11451341025531292, 0.09390925336629152, 0.24011177569627762, 0.19240666553378105], [0.005128125942844365, 0.023328910947644284, 0.03650852578825184, 0.02637869006554995, 0.0453362087053912, 0.05361667348604117, 0.018083704635500908, 0.04554958422003048, 0.017602094049964632, 0.04511737098385181, 0.10503559240273067, 27.090772696903773, 52.08899463926043, 41.97000994001116, 34.65890693664551, 24.154748848506383, 42.02391753877912, 51.67586169924055, 47.939228194100515, 50.314664431980674, 47.74685689381191, 40.009836265019004, 0.6175003051757812, 0.32571958058646744, 0.47149607113429476, 0.1970557432089533, 12.180056640080043, 62.73500714983259, 47.29209034783499, 47.88927412033081, 38.69265236173357, 40.43885973521641, 42.88361120223999, 50.49674197605678, 43.41238301140921, 44.384144169943674, 45.490627425057546, 44.45941053118025, 45.70500714438302, 46.43443945475987, 43.28163528442383, 42.00432709285191, 35.954690388270784, 31.974473885127477, 32.10607624053955, 32.343784536634175, 32.846399852207725, 34.32609517233712, 31.66649498258318, 33.34489836011614, 32.23979432242257, 33.33766875948225, 33.51304824011666, 33.433484418051584, 33.85959659303938, 33.74800157546997, 33.590128081185476, 32.7808574948992, 32.89380741119385, 32.89313691002982, 33.14381054469517, 34.80023329598563, 34.10873120171683, 32.81108910696847, 33.52328988483974, 34.08210570471627, 33.8551219531468, 34.14722074781145, 35.59454788480486, 33.466721126011436, 31.488742692129954, 33.91369526726859, 39.58953973225185, 37.987712451389854, 38.69436509268624, 46.59536668232509, 40.6455408505031, 34.914326190948486, 33.24690096718924, 33.48024926866804, 36.17319386345999, 33.287172726222444, 36.618813105991904, 33.24664388384138, 33.173996993473594, 32.35758365903582, 35.22618913650513, 34.8626663344247, 35.09010866710118, 34.77511555807931, 35.151926789964946, 35.11045299257551, 34.04325485229492, 34.23616811207363, 32.801792417253765, 33.391663210732595, 35.70194966452462, 33.93400485174996, 32.576556137629915, 32.878875732421875, 33.50538785117013, 34.77428872244698, 36.25617619923183, 40.07612555367606, 44.878828116825645, 40.50348493031093, 41.339867387499126, 38.289698532649446, 31.55271475655692, 32.77647318158831, 34.91757794788906, 34.79742274965559, 33.21946947915213, 33.713465554373606, 33.933598382132395, 35.07767833982195, 32.79695994513375, 34.13106271198818, 35.50610079084124, 33.841604232788086, 33.957666942051475, 34.833348410470144, 31.846981389181956, 33.6196231842041, 33.49777957371303, 32.01975876944405, 33.013556139809744, 32.76558882849557, 33.78499378476824, 33.112394264766145, 34.54402542114258, 33.42854772295271, 32.8292794908796, 32.853090967450825, 32.9000677381243, 33.79467262540545, 35.1407401902335, 35.74060596738543, 40.219116006578716, 41.1059250150408, 46.17715113503592, 48.58051218305315, 49.77713441848755, 49.88119411468506, 50.74815559387207, 42.54106848580496, 47.16105774470738, 49.14881576810564, 42.30744225638253, 37.4595034463065, 46.550022738320486, 53.481715883527485, 57.45490428379604, 38.74395786012922, 0.09706573041954211, 0.9513003421681268, 0.1657794179128749, 0.3616076505609921, 21.75906903403146, 61.995204653058735, 48.69728708267212, 59.415032795497346, 49.56852170399257, 32.70863791874477, 16.531195776803152, 34.17285960061209, 53.76686300550188, 30.660569531576975, 0.5429410859942436, 0.053129634620355706, 0.06014683683003698, 0.027402173627966216, 0.009287950183664049, 0.07489510758646897, 0.022281568397634795, 0.009026670944876969, 0.03349303134850093, 0.037257889684821875, 0.03893466506685529, 0.04874890058168343, 0.044704767409712076, 0.03775375968377505, 0.04766338365152478, 0.05705273071570056, 0.019714738275589686, 0.020962036613907133, 0.1780482538576637, 35.298106466020855, 58.84749003819057, 44.65244885853359, 33.0876829964774, 30.594613756452286, 51.90669475282942, 53.41503749574934, 54.20338705607823, 53.965303557259695, 53.00757428577968, 42.310784339904785, 0.5960661981787, 0.5203455984592438, 1.0023634135723114, 0.19649772958031722, 13.78942358493805, 64.67310987200055, 47.97668593270438, 49.96383251462664, 41.955255440303254, 42.880991731371196, 43.6600341796875, 51.48499468394688, 46.04136943817139, 45.73208774839129, 47.08900839941842, 45.84892865589687, 46.86082260949271, 47.94867427008492, 45.5414673941476, 43.77805628095354, 39.47268145424979, 32.96844843455723, 33.92970391682216, 34.497475964682444, 35.052282673971995, 35.87576927457537, 33.903860092163086, 34.926568916865754, 34.46570185252598, 35.08152764184134, 34.2817656653268, 34.92106246948242, 36.29141746248518, 35.791734286717, 33.79733378546578, 34.41783571243286, 35.22875649588448, 34.98111922400338, 35.11658130373274, 36.03606421606881, 35.27383640834263, 34.72642605645316, 34.56328930173601, 34.984822613852366, 35.418091433388845, 35.890711375645225, 36.912753173283164, 35.837342262268066, 34.79436206817627, 35.79426690510341, 40.69844443457467, 40.96334103175572, 39.19589648927961, 46.85364859444754, 40.28022541318621, 35.77648646490914, 32.374328817640034, 34.5881256375994, 36.29943915775844, 35.23088264465332, 36.39640474319458, 34.919822216033936, 34.52596010480608, 34.213457924979075, 37.536221981048584, 35.74871104104178, 35.789045333862305, 36.68819086892264, 37.074698311941965, 35.39419310433524, 36.518699986594065, 35.81570904595511, 34.34052310671125, 35.34184537615095, 37.07875605991909, 34.669760022844585, 34.486980710710796, 32.76253856931414, 34.42433227811541, 35.28414058685303, 36.86704444885254, 43.5447427204677, 45.33889961242676, 42.373495306287495, 44.14696046284267, 40.215402194431846, 32.477026666913716, 33.79599973133632, 36.631427560533794, 35.810296399252756, 33.33490685054234, 35.578094550541465, 34.778398581913535, 36.68247250148228, 35.01417180470058, 36.679158210754395, 36.00590556008475, 35.56228392464774, 35.89774295261928, 35.33411203111921, 33.767574650900706, 35.342713900974815, 35.502043042864116, 33.96422951562064, 34.58888646534511, 35.40468488420759, 35.21695498057774, 35.10240350450788, 34.60765354973929, 34.134446484701975, 35.968711853027344, 34.83961568559919, 35.37549202782767, 36.028070313589915, 37.234590257917134, 38.340111187526155, 41.44952733176095, 43.8956093788147, 48.411858558654785, 51.4798321723938, 50.85511268888201, 51.69928060259138, 51.42254427501133, 43.12984841210501, 47.8804429599217, 52.21964161736624, 45.44362980978829, 40.512309142521445, 49.468339102608816, 54.07944161551339, 58.14554827553885, 42.79382310594831, 0.08659529725887946, 2.9158467139516557, 0.8380539332117353, 0.45213638139622553, 24.463672706059047, 66.34282452719552, 53.91012096405029, 64.48816967010498, 53.153781754629954, 40.268225874219624, 15.211616482053484, 37.337364537375315, 59.462634904044016, 39.15671559742519, 0.8578843091215406, 0.04723072936758399, 0.021182777626173835, 0.05152230729748096, 0.012532412024614002, 0.07045254882957254, 0.044320940505713224, 0.006175353565985071, 0.11168320676577942, 0.10519414568053824, 0.1429885122925043, 0.11712114246828215, 0.19870556039469583, 0.1847680982734476, 0.24028260367257254, 0.16714933940342494, 0.11209755417491708, 0.12392614302890641, 0.2060265868370022, 39.30977051598685, 68.9588212966919, 51.968940189906526, 44.828415461948936, 35.46333115441458, 54.73260702405657, 61.61897359575544, 59.033597537449424, 58.30833067212786, 56.539722306387766, 50.18848514556885, 0.9665310106107167, 1.2096478279147829, 2.2913050608975545, 0.26172906000699314, 15.595558302743093, 66.2873431614467, 51.75495651790074, 51.841496331351145, 43.86313002450125, 45.83308328901018, 45.62924746104649, 53.724211488451274, 48.9999749319894, 47.89307131086077, 47.522739274161204, 49.503034932272776, 48.60710293906075, 50.3973514693124, 48.116890157972065, 46.389741693224224, 40.85142987115042, 35.16421120507376, 35.83575112479073, 36.68233353751046, 36.74239724023001, 38.87081112180437, 35.952967235020225, 37.53661108016968, 36.58605234963553, 38.367775440216064, 37.394124371664866, 37.801118578229634, 39.06743471963065, 37.343881947653635, 37.04933043888637, 35.41303314481463, 35.66121237618582, 36.75150980268206, 36.368393080575125, 37.189492974962505, 38.29659461975098, 37.06594010761806, 37.576028210776194, 37.27793312072754, 36.344623293195454, 36.84713438579014, 39.11911889484951, 39.52895144053868, 36.80406597682408, 37.6355117389134, 43.62185730252947, 43.15781838553292, 41.1102294240679, 49.339126927512034, 41.459953103746685, 36.17957578386579, 34.16026946476528, 36.37929827826363, 37.509971686771934, 36.38943222590855, 40.46863971437727, 36.684327670506065, 36.800018651144846, 36.02432523454939, 41.14010667800903, 39.029375961848665, 38.53680426733834, 38.73844446454729, 38.376120226723806, 39.18580075672695, 38.487329619271414, 37.50142192840576, 35.067408902304514, 37.182110513959614, 38.32536711011614, 36.50756549835205, 35.78730828421456, 34.323322841099326, 33.62332657405308, 35.3803140776498, 37.58833694458008, 48.093325342450825, 48.68908820833479, 44.543032101222444, 47.664041314806255, 40.7349328994751, 34.042990820748464, 35.83925649097988, 39.202243668692454, 37.811092717306956, 35.912931714739116, 37.15873677389962, 38.04018872124808, 38.83576093401228, 35.88917929785592, 37.3111628804888, 38.76021317073277, 37.60380710874285, 36.9526184626988, 37.582159996032715, 36.05971588407244, 38.146596908569336, 38.475986685071675, 37.28283507483346, 36.737408433641704, 37.844801902770996, 38.21516520636422, 38.15455954415457, 37.573867321014404, 36.135131631578716, 37.6647184916905, 37.11531400680542, 36.46529265812465, 37.221649238041465, 39.8919392313276, 40.37793098177229, 44.18081556047712, 44.78326954160418, 50.33792005266462, 53.459127289908274, 51.86302532468523, 54.584603445870535, 52.85475908006941, 44.42183814729963, 50.430122647966655, 53.87995535986764, 47.253444467272075, 43.167247091020855, 51.84624195098877, 58.10197959627424, 61.917968477521626, 45.1000657081604, 0.4908510925514357, 4.372701134000506, 2.0017718885626112, 0.5664525415216173, 27.1698796749115, 72.77475806644985, 58.81457642146519, 69.37082862854004, 58.93774018968855, 44.46049445016043, 25.023424795695714, 45.21505144664219, 65.6832389831543, 48.43723685400826, 1.5599750237805503, 0.2208269690828664, 0.136862684573446, 0.1761938447930983, 0.12083959579467773, 0.1957257738603013, 0.12067894584366254, 0.08619867318442889], [0.028923844386424338, 0.015151366358622909, 0.04455653804221323, 0.02740311509530459, 0.025540858773248534, 0.022107815935409496, 0.0531337024377925, 0.06561116075941495, 0.021047248737886548, 0.007479789217800966, 0.03614668681153229, 15.663502999714442, 52.89105994360787, 41.46533100945609, 33.97960587910244, 27.48304888180324, 38.12493937356131, 48.92609126227242, 51.12813173021589, 49.62142876216343, 47.836856910160606, 46.07209437234061, 3.311162301472255, 0.690896352486951, 1.0247855761221476, 0.3274361113352435, 10.569210597446986, 59.183011599949424, 47.55308553150722, 46.69854048320225, 37.091710976191926, 41.83068813596453, 47.74182639803205, 45.51367807388306, 44.090641839163645, 49.26054627554757, 42.20438657488142, 50.10962309156145, 47.67047534670149, 44.01743909290859, 40.476532867976594, 36.140808309827534, 31.49806022644043, 33.71343776157924, 32.43355873652867, 32.64542668206351, 32.31969165802002, 31.914118358067103, 33.26481342315674, 33.18049703325544, 34.628282751355854, 33.35417767933437, 32.5827956199646, 32.18356255122593, 33.68058320454189, 32.79293693814959, 33.01780496324812, 34.026610442570274, 33.489351408822195, 33.494906493595664, 32.853528703962056, 33.9594144139971, 32.91479097093855, 34.99869121823992, 34.62816115788051, 33.67802974155971, 33.98668261936733, 35.215523651668, 35.83091517857143, 33.7376835005624, 33.098605564662385, 32.412978172302246, 41.07604776109968, 38.368734291621614, 39.764512743268696, 44.89793913705008, 33.56326287133353, 33.71649496895926, 34.169913564409526, 33.89310080664498, 35.35447720118931, 35.96318456104824, 33.92894656317574, 34.617589473724365, 32.75056334904262, 33.49107803617205, 32.450356006622314, 33.270101002284456, 33.989302090236116, 34.26012202671596, 34.39672361101423, 32.125072615487234, 32.9570186478751, 33.47881099155971, 33.57814243861607, 34.43491785866873, 33.61528403418404, 35.08384486607143, 33.60671690532139, 33.87722764696394, 33.908393791743684, 35.02257565089634, 39.22926868711199, 37.98339067186628, 40.711673804691856, 41.48582819529942, 41.0490540095738, 35.899236815316335, 30.318391595567974, 33.00754942212786, 32.82080963679722, 35.749669892447336, 33.42832885469709, 32.991005761282786, 31.990253244127544, 33.877783502851216, 34.578554494040354, 33.264208929879324, 34.56611721856253, 35.689324787684846, 34.73760570798601, 34.38878182002476, 33.90282481057303, 34.44277627127511, 33.73676633834839, 34.15500967843192, 35.153041975838796, 34.180228165217805, 33.42340953009469, 34.038387639181956, 32.57422849110195, 34.52351781300136, 34.55519117627825, 33.61571134839739, 34.383615834372385, 33.7266845021929, 33.295774596078054, 35.27804701668875, 38.130595207214355, 38.739295618874685, 43.474437373025076, 45.157419613429475, 49.343413966042654, 48.28016587666103, 50.80936574935913, 52.40701021466936, 49.19536175046648, 47.88154077529907, 49.9343443598066, 38.014007908957346, 45.460774489811485, 49.86388267789568, 62.93276677812849, 26.074197394507273, 0.13647686956184252, 0.054394230512636046, 0.16970139103276388, 0.100439732229071, 30.1987019266401, 59.02361297607422, 50.13194765363421, 61.36775452750069, 48.43863691602434, 35.56574412754604, 39.81476558957781, 39.633052825927734, 47.0831059047154, 26.979749168668473, 0.3405682880963598, 0.013690204808621534, 0.05853800994477101, 0.04028758925518819, 0.08466141138757978, 0.03917976887896657, 0.016645514040387104, 0.06681514651115451, 0.03791735786944628, 0.05581161552774055, 0.06008466945162841, 0.029492049611040523, 0.006824898600046123, 0.011591582509156848, 0.067042720371059, 0.04042765923908778, 0.04074526112526655, 0.028973085672727654, 0.05409987523619618, 19.515031916754587, 59.23813165937151, 46.939354624067036, 38.12565156391689, 32.23224857875279, 49.33882815497262, 54.576053687504356, 56.00132724217006, 55.05905423845564, 51.89614391326904, 50.70479883466448, 3.257825323513576, 0.7090442872473172, 0.6434968816382545, 0.47519978668008533, 12.30481675692967, 60.18786008017403, 49.769164834703716, 49.657205036708284, 40.116411209106445, 42.89254311152867, 48.69465718950544, 47.351751055036274, 44.552603244781494, 48.50721911021641, 43.54550354821341, 50.448215757097515, 49.37150205884661, 46.35899938855852, 44.23806176866804, 38.37150314876011, 33.861104352133616, 34.89168895993914, 35.55259466171265, 33.93306337084089, 35.188053948538645, 33.57579047339303, 35.235079356602256, 34.52600179399763, 35.247530528477256, 37.31053754261562, 34.53802912575858, 34.501651832035606, 35.29173149381365, 34.64786277498518, 36.595842361450195, 35.126458168029785, 35.066575118473594, 34.73820672716413, 34.54056521824428, 35.813562052590505, 34.88148553030831, 35.88046973092215, 35.511534282139365, 35.58005394254412, 35.5833751814706, 37.85702725819179, 37.182523931775776, 35.549051080431255, 34.21227673121861, 34.958426407405305, 41.23191670009068, 40.60201038633074, 41.30955587114607, 45.930215631212505, 36.6850711277553, 34.36790943145752, 34.97958019801548, 35.52323852266584, 37.266541549137656, 36.33775847298758, 36.3729441506522, 35.078779629298616, 35.21536731719971, 34.62272419248308, 36.23013087681362, 35.83327061789376, 35.39246647698538, 36.85717453275408, 36.47207062585013, 33.30689866202218, 34.030154023851665, 35.50855350494385, 36.798378876277376, 34.77547339030674, 35.010683809007915, 35.88387087413243, 33.6343047278268, 35.7571565764291, 36.31028529575893, 34.390268734523225, 40.45949935913086, 41.804333618709016, 42.66142518179757, 42.86557367869786, 44.0158896446228, 38.10238899503435, 32.64722973959786, 34.98560428619385, 36.57219416754586, 37.56206233160836, 35.57627064841134, 35.98484557015555, 33.71766226632254, 35.92388902391706, 34.122422627040315, 35.57315785544259, 35.20266948427473, 37.641758169446675, 37.04077025822231, 36.22746276855469, 36.00183391571045, 35.93809461593628, 35.15413631711687, 36.07713849203927, 37.10245289121355, 37.367960929870605, 35.82636063439505, 35.78389324460711, 34.80814034598214, 36.3435880116054, 36.48069681440081, 34.936397143772666, 36.40555204663958, 35.6818311555045, 36.468843187604634, 37.51055186135428, 39.77730437687465, 40.50274494716099, 45.45290565490723, 46.79207713263375, 51.090660095214844, 50.4253249168396, 52.35332843235561, 52.57480573654175, 49.77674184526716, 49.84379196166992, 52.26778221130371, 40.53065586090088, 47.47055830274309, 52.24709047589983, 65.01273087092808, 28.39030817576817, 0.09349753867302622, 1.2508383776460374, 0.07813104787575346, 0.10282795836350747, 32.32453107833862, 64.45208767482212, 52.90288577760969, 68.78440066746303, 52.76208053316389, 39.473838329315186, 34.58010394232613, 41.18035064424787, 53.106985637119834, 32.79405559812273, 0.26967288660151617, 0.02219577782255198, 0.04178552994770663, 0.05306791168238435, 0.01155809426148023, 0.04398466194314616, 0.0710749893582293, 0.06283603395734515, 0.12597244179674558, 0.16542782820761204, 0.08271393445985657, 0.13143456727266312, 0.0676411407600556, 0.16658965657864297, 0.1644719216440405, 0.13578172400593758, 0.08897281611072165, 0.25688084587454796, 0.1354677929942097, 23.936712639672415, 70.40958431788853, 53.33385474341256, 44.37593487330845, 37.542440618787495, 50.910573210035054, 57.90220151628767, 60.58879198346819, 58.75291115897042, 56.24545914786202, 55.406835896628245, 4.451129359858377, 1.319584180201803, 2.5727807113102505, 0.5167160875030926, 13.884437595094953, 62.678956031799316, 50.348536900111604, 52.37719896861485, 40.13232258387974, 46.29873071398054, 50.70223494938442, 48.864603178841726, 47.86879777908325, 51.3233448437282, 45.20385095051357, 53.60638741084507, 52.80998836244856, 48.90920713969639, 45.92054721287319, 41.10765164239066, 35.725219181605745, 37.059596402304514, 37.38209009170532, 35.89268466404506, 37.501963887895855, 35.19417878559658, 37.33736106327602, 37.60916416985648, 38.65448243277413, 36.61817387172154, 36.06556279318673, 37.57928344181606, 39.01738684517996, 36.867315428597585, 37.14113351276943, 37.754322460719514, 38.80047450746809, 38.507232734135215, 36.30553272792271, 36.21556397846767, 36.13194588252476, 37.59549706322806, 38.97084781101772, 37.737233366285054, 36.93714829853603, 39.428765365055625, 38.39102758680071, 37.82225499834333, 36.206732818058555, 36.395730767931255, 45.3081989969526, 43.488955633980886, 43.714191913604736, 47.95875610624041, 36.5871501650129, 35.74372918265206, 36.352186407361714, 37.18642881938389, 38.02698366982596, 39.491622243608745, 37.854147229875835, 37.62319605691092, 36.04388788768223, 37.174682889665874, 38.13004629952567, 37.33782311848232, 38.12460238592965, 38.240039757319856, 39.35523952756609, 35.52244642802647, 37.53064605167934, 37.71240397862026, 38.48858029501778, 37.05348546164376, 36.07706553595406, 37.470398221697124, 35.1070032119751, 37.61582054410662, 36.16689879553658, 35.87815945489066, 42.170878887176514, 45.74766213553292, 46.61366128921509, 47.375058787209646, 46.27356086458479, 39.495610509599956, 34.560530866895405, 36.26474680219378, 38.60309703009469, 39.75694268090384, 36.25115959984915, 35.87338604245867, 34.513290064675466, 38.754397528512136, 37.08963693891253, 36.589908599853516, 37.142742020743235, 40.45506640842983, 38.48330661228725, 37.13778795514788, 38.002008369990754, 39.544668265751426, 36.89180782863072, 38.05542959485735, 39.18598140989031, 38.8819317136492, 36.71697378158569, 37.92602981839861, 37.39627136502947, 38.14967496054513, 41.26912430354527, 35.70617764336722, 39.344893659864155, 37.477078914642334, 36.773125648498535, 40.36287076132638, 42.10516282490322, 41.872533661978586, 48.296838079180034, 50.13239581244332, 52.567798478262766, 52.566398416246685, 54.241233893803184, 54.91122089113508, 50.0126679284232, 51.800738198416575, 53.98591538837978, 42.51415811266218, 49.60997118268694, 53.918097496032715, 66.8188247680664, 31.427668026515416, 0.22093218272285803, 0.47333842941692894, 0.21746262961200305, 0.2791080246014254, 36.342135838099885, 70.69519002096993, 58.11665766579764, 71.15833609444755, 57.892157895224436, 50.39242172241211, 50.821889877319336, 51.018002782549175, 60.31274005344936, 41.263854094914024, 0.40506342159850256, 0.06985225568392447, 0.10719869418867997, 0.11225671813424144, 0.09937584360263177, 0.137483096282397, 0.11535070889762469, 0.1410139753882374], [0.0470455232342439, 0.01985050125845841, 0.08193473877119166, 0.050508491162742884, 0.023695874560092176, 0.05860327144286462, 0.11027645439441715, 0.09366764740220138, 0.03438434137829712, 0.137718547933868, 0.14509118374969276, 8.750566516603742, 51.678043433598106, 44.90527296066284, 28.77237571988787, 17.52616391863142, 38.83122028623308, 49.43227447782244, 51.09744848523821, 50.977161271231516, 45.47828047616141, 51.3552440234593, 7.912347997937884, 0.751542943928923, 0.6577738555414336, 0.36284185147711207, 7.465505872453962, 59.28553921835763, 48.76617499760219, 45.48232085364205, 39.70221519470215, 49.761782373700825, 46.83910254069737, 43.13963494982038, 47.11993483134678, 46.293821811676025, 49.41525139127459, 46.24998215266636, 44.78526714869908, 41.01890924998692, 35.3491062436785, 33.129347869328086, 31.840818337031774, 33.31560475485665, 34.152977330344065, 33.14093746457781, 32.61936746324812, 32.57545484815325, 33.005763735089985, 33.666429724012104, 32.30186258043562, 32.90006078992571, 31.938850470951625, 33.1064327103751, 32.37084082194737, 33.31816864013672, 32.13079793112618, 33.21813889912197, 32.62361281258719, 33.8185327393668, 33.50508560453142, 34.097898960113525, 35.30671180997576, 35.32572208132063, 34.38724626813616, 33.61610739571707, 35.4895293372018, 34.85614545004708, 36.245663574763704, 33.50391135896955, 31.0816581589835, 33.91478960854666, 35.92221450805664, 38.52299819673811, 38.08394847597395, 32.592873982020784, 34.65764583860125, 34.035497188568115, 33.54682343346732, 36.30153751373291, 34.93182175500052, 34.94135815756661, 33.47495821544102, 33.1599303654262, 34.14558097294399, 33.136706011635916, 33.13326317923409, 33.50266763142177, 33.46912520272391, 33.360997336251394, 35.371983187539236, 33.21271930422102, 30.820951325552805, 34.3284957749503, 33.05646126610892, 33.17479951041085, 34.776123046875, 33.292217118399485, 34.30430909565517, 33.668274470738, 34.748840945107595, 35.861292702811106, 43.53726993288313, 40.817619936806814, 34.422022002083914, 38.65351663316999, 41.43370280947004, 37.08790683746338, 30.41949830736433, 32.50097015925816, 34.26368645259312, 34.9695018359593, 34.338793005262104, 34.02237204142979, 34.49314376286098, 33.26185349055699, 33.355595111846924, 34.99662412915911, 34.543775285993306, 33.9678703716823, 34.16326066425869, 32.543996879032676, 31.70586347579956, 33.03406374795096, 33.42689405168806, 34.31644412449428, 34.812941551208496, 34.018286500658306, 33.909731319972444, 33.61590242385864, 33.542063917432515, 35.5408695765904, 34.908409799848286, 33.928022452763145, 33.03548118046352, 33.241682870047434, 33.24101931708199, 32.939655099596294, 34.6918830871582, 34.818051951272146, 38.191093172345845, 39.34744712284633, 43.58073786326817, 45.56842293058123, 49.629492146628245, 48.52710485458374, 51.01306956154959, 48.67011267798287, 52.55420085362026, 43.60603625433785, 48.11323887961251, 46.852793966020855, 59.76274149758475, 12.77139002936227, 0.44155063799449373, 8.385688815798078, 0.43588050082325935, 0.11794070420520646, 33.73229169845581, 57.40108701160976, 51.377030100141255, 48.71071447644915, 46.79146221705845, 34.70763465336391, 19.460538932255336, 37.185344900403706, 49.24794224330357, 17.964183568954468, 0.14735502084451063, 0.07747580017894506, 0.06491574378950254, 0.026932869971330677, 0.022024099981146197, 0.023931947071105242, 0.042388913820364645, 0.04160428645887545, 0.02987102498965604, 0.04696490988135338, 0.033256785811058114, 0.04504433686711958, 0.04508975800126791, 0.050914092255490165, 0.06513000479234116, 0.07537236876253571, 0.025313286609681587, 0.11471470445394516, 0.07749410026839801, 11.867836730820791, 58.639982087271555, 49.68004029137747, 34.31613840375628, 25.916704314095632, 47.00892693655831, 53.069781507764546, 54.46735259464809, 55.55988386699131, 50.05743169784546, 54.991566385541645, 8.529251626559667, 0.7778633173022951, 0.6354026102593967, 0.8384059571794101, 8.357719710894994, 62.04089600699288, 51.315062591007774, 47.416372776031494, 42.21751519611904, 49.401452268872944, 50.92979540143694, 45.834191526685444, 49.196271964481895, 48.15295478275844, 50.56149918692452, 49.45118400028774, 46.51621627807617, 44.51044504983084, 37.25854417255947, 34.1655535697937, 32.30973488943917, 34.127036230904714, 36.39112063816616, 34.06693778719221, 35.09663997377668, 34.19244657244001, 34.13786847250802, 34.540436676570344, 34.85985926219395, 33.460057803562705, 35.04071739741734, 34.243248326437815, 33.89418819972447, 36.15336717878069, 34.457662786756245, 34.191657951899934, 35.27146707262312, 34.24069486345564, 36.06809193747384, 36.800546714237754, 37.70211022240775, 35.407818521772114, 34.49454035077776, 35.130463804517476, 35.36342300687517, 35.94955914361136, 37.344389166150776, 35.09705686569214, 32.943636417388916, 35.01471723828997, 38.51282950810024, 41.395616258893696, 40.602684361594065, 36.68478972571236, 36.35108511788504, 34.01605960300991, 34.75996501105172, 36.68428250721523, 36.98780066626412, 35.313955307006836, 34.963133811950684, 34.91494805472237, 36.23012045451573, 33.98223924636841, 34.55183172225952, 36.52107627051217, 35.475518294743125, 36.124403612954275, 36.829454694475444, 34.68639053617205, 33.92174475533621, 34.31145879200527, 35.34842879431588, 36.81397410801479, 35.307163442884175, 36.01162740162441, 35.26477943147932, 35.03339399610247, 34.29876790727888, 37.54004349027361, 44.33751480919974, 43.94257572719029, 38.95945276532854, 41.797979491097585, 43.91190985270909, 38.15470893042428, 33.369675636291504, 35.39623587472098, 35.558191435677664, 36.84312527520316, 35.06396606990269, 35.27625438145229, 37.58876773289272, 35.31258303778512, 34.7127172606332, 36.775776386260986, 37.25503533227103, 36.113512311662944, 35.093812056950156, 34.752064909253804, 34.92420652934483, 33.569022927965435, 35.132596901484895, 33.991188526153564, 36.119800431387766, 35.70085184914725, 37.15092352458409, 36.15883541107178, 36.662256717681885, 36.305907930646626, 36.95214251109532, 35.875282900674, 34.8457544190543, 34.79199620655605, 36.035685539245605, 36.356431756700786, 37.31039163044521, 36.16097545623779, 40.55144139698574, 41.651309967041016, 46.64536244528634, 48.08760697501046, 52.90520647593907, 50.80390446526663, 52.08999170575823, 50.732536043439595, 54.83030217034476, 45.17311906814575, 49.660362992967876, 49.880238737378804, 61.9788555417742, 13.399477652141027, 0.28611631425363676, 5.905110699789865, 0.8803237336022514, 0.11237316831414189, 36.82149205889021, 62.61587333679199, 56.10041897637503, 55.32514592579433, 53.43740027291434, 38.633075032915386, 25.799029622759136, 44.09719399043492, 54.604985986437114, 23.645187071391515, 0.1674946594451155, 0.05350926139258912, 0.010025027507383908, 0.044967234932950566, 0.01469825254753232, 0.037756694347730706, 0.03393168727468167, 0.07972498770271029, 0.15182858865175927, 0.11286590008863381, 0.17048383690416813, 0.11549497901328973, 0.1739321518689394, 0.15398976339825562, 0.20419374161532947, 0.15171905952904904, 0.18409377017191478, 0.3595237066703183, 0.2499707266688347, 13.352904745510646, 69.30918421064104, 55.84479475021362, 39.41051244735718, 26.963115181241715, 49.57782186780657, 59.27413722446987, 59.19557394300188, 61.264872550964355, 55.159629413059776, 61.20525005885533, 10.362664103507996, 1.0865484390939986, 3.1310391553810666, 0.9351196161338261, 9.31730762549809, 64.43621104104179, 53.469084058489116, 50.2662215914045, 45.65221473148891, 52.981136390141074, 52.46221712657383, 46.75215973172869, 49.83787209647042, 51.847284180777415, 53.248402323041645, 49.472153663635254, 49.545411995479036, 46.00126443590437, 39.113501276288716, 37.52462543760027, 34.88921192714146, 36.814484800611226, 38.118425437382285, 35.51241670336042, 37.09837777273995, 36.18618699482509, 36.95413664409092, 36.93966702052525, 37.01245287486485, 35.05859163829258, 35.59814705167498, 36.83277245930263, 36.08012274333409, 38.1915864944458, 36.87427404948643, 36.68637044089181, 37.083960260663716, 36.3649537222726, 36.91727645056588, 38.83641406467983, 39.8986998285566, 37.95887047903878, 37.177632399967735, 36.738360336848665, 38.443948541368755, 37.96567276545933, 39.19249882016863, 36.05203117643084, 35.704339844839915, 37.60002728870937, 41.17263466971261, 43.71073865890503, 44.50693620954241, 37.51449843815395, 35.86218554633004, 36.26221070970808, 34.18915660040719, 38.78457702909197, 38.04952015195574, 37.55599308013916, 37.558133125305176, 36.348687989371165, 38.834583214351106, 36.3865521975926, 37.649679115840364, 38.962409223829, 37.06712824957711, 37.37231050218855, 38.72140400750296, 35.566407680511475, 35.17568268094744, 37.31631844384329, 37.29396608897618, 38.549922466278076, 38.2598351751055, 37.26917839050293, 35.14687197549002, 36.98262773241316, 37.505927835192, 38.258973598480225, 46.895706040518625, 46.02364805766514, 43.380744389125276, 44.76907784598214, 45.97081395557949, 41.868628774370464, 36.00933102199009, 38.53368105207171, 38.15072413853237, 38.20335674285889, 36.70842749731881, 36.808651787894114, 38.37238556998116, 37.033141136169434, 36.44416318620954, 39.80960307802473, 38.81475305557251, 37.98589549745832, 38.10946226119995, 36.86159358705793, 37.367283480507986, 36.63948399680001, 37.751143659864155, 37.440805843898225, 38.233591829027446, 39.45189591816494, 38.788509709494456, 38.38424614497593, 38.16347755704607, 38.433863231113975, 39.29340403420584, 37.369805676596506, 35.30348089763096, 36.23961864198957, 37.277825423649375, 37.83218050003052, 40.04973976952689, 38.5024037361145, 43.07219226019723, 44.23089122772217, 47.674210003444124, 50.732362338474815, 55.11824246815273, 53.43513516017369, 54.46990953172956, 52.49232367106846, 56.692471504211426, 49.44092845916748, 52.40233407701765, 52.36770078114101, 63.78793716430664, 15.93763722692217, 0.544324374624661, 22.315838609422954, 2.840572318860463, 0.5101489541786057, 41.3866218158177, 67.19078268323625, 59.42586503710066, 58.30037498474121, 58.60289260319301, 45.55833067212786, 29.36290659223284, 49.81649248940604, 64.16609287261963, 32.19150086811611, 0.17027783367250646, 0.12803847236292704, 0.1506149744881051, 0.06668862687157733, 0.10896829994661467, 0.08493854544524636, 0.20075287696506294, 0.20326518001300947], [0.06430776962744338, 0.07814722415059805, 0.04271535362516131, 0.07807130286736147, 0.02427759620227984, 0.047498614992946386, 0.08486811351031065, 0.03894838165225727, 0.06627734644072396, 0.06521507272762911, 0.06647371447512082, 3.0695749563830237, 41.49868583679199, 49.18462330954415, 28.045984983444214, 23.14555948121207, 35.31850290298462, 43.55414015906197, 52.82004240580967, 52.738460132053916, 44.67965800421578, 52.597800799778526, 16.473447561264038, 0.6483580693602562, 0.7306552476116589, 0.4749102422169277, 2.4635645832334245, 49.44495494025094, 51.89406640189034, 46.50870527539934, 47.56789561680385, 47.90017236982073, 43.98585605621338, 50.20690482003348, 46.92279706682478, 50.280889238630024, 45.950386251722065, 44.46420478820801, 42.78912959780012, 37.299031325748985, 32.30658040727888, 33.23389393942696, 31.684240681784495, 32.930181230817524, 33.59735073362078, 33.88328300203596, 32.68725483758109, 32.63066176005772, 32.35763924462454, 33.76118925639561, 33.532030718667166, 33.89974675859724, 32.68146698815482, 33.31105715887887, 34.072138513837544, 33.75152431215559, 32.80505459649222, 31.996902670179093, 33.45170954295567, 32.26316458838326, 33.692353452954976, 33.96677950450352, 34.275018964494976, 33.19778067725045, 32.6737197467259, 35.415947914123535, 35.66002770832607, 35.64521762302944, 36.2035505431039, 33.83692462103707, 30.349036625453405, 33.22502456392561, 37.38005774361746, 37.814959389822825, 34.808300154549734, 40.185757705143516, 37.226547718048096, 33.09455476488386, 33.221849237169536, 33.99289083480835, 35.95912333897182, 34.823805059705464, 32.34024790355137, 32.80540548052107, 34.08909559249878, 33.62088428224836, 33.8042368207659, 33.93311895642962, 33.82958732332502, 34.29762840270996, 34.37994718551636, 33.44252749851772, 32.83659594399588, 33.73567199707031, 33.4599883215768, 32.56006458827427, 32.963014943259104, 35.396027428763254, 35.170120647975374, 34.98734828404018, 34.65237562997, 39.57115132468087, 43.40290566853115, 40.34687948226929, 38.24114799499512, 38.82157966068813, 38.74251958302089, 38.11108119147164, 31.91108546938215, 31.341222013745988, 33.796041420527864, 34.14238132749285, 35.48135478155953, 33.753285680498394, 33.98761715207781, 32.89342178617205, 33.964354583195274, 33.6945595060076, 33.79538481576102, 34.52629361833845, 35.53160415376936, 31.8673152923584, 33.578361306871685, 33.330967221941265, 33.028289794921875, 32.887314319610596, 33.84804521288191, 33.421436241694856, 32.708853312901084, 32.723142283303396, 33.328986985342844, 33.335556507110596, 34.33889722824097, 33.05402939660208, 34.613653319222585, 35.2159857068743, 34.18272604261126, 32.98618023736136, 33.426202705928254, 34.804871218545095, 34.57814802442278, 35.47691488265991, 38.32561377116612, 41.89879437855312, 47.08117083140782, 47.651016916547505, 52.97411870956421, 49.417280265263145, 54.65844195229666, 46.9113255909511, 49.8971471786499, 49.96081352233887, 57.297392095838276, 0.9288206398487091, 0.25375630067927496, 1.856520014149802, 0.11431351383881909, 0.05547209017510925, 36.13385316303798, 54.64454208101545, 51.92325578417097, 50.23814392089844, 45.9633446420942, 26.752906118120464, 22.19784951210022, 33.43132700238909, 53.47091143471854, 12.945205296788897, 0.6335640517728669, 0.1993999324206795, 0.13289459821368965, 0.02106332323247833, 0.13799065404704638, 0.04169057236452188, 0.018559361076248542, 0.055222267151943276, 0.0394048626933779, 0.027131273610783473, 0.04377210406320436, 0.01581675815396011, 0.002330301720316389, 0.018376149835863283, 0.05773902817496231, 0.052029366338891644, 0.05334818396451218, 0.018392002110236456, 0.11443862212555748, 4.673562041350773, 51.66905246462141, 55.113375255039756, 30.233147621154785, 19.533875431333268, 38.03518254416329, 50.10648945399693, 55.81549072265625, 57.43264920370919, 48.972581659044536, 57.974733761378694, 16.785098586763652, 0.7521521598100662, 0.6765467481953757, 0.618322798183986, 3.177967288664409, 50.73610046931675, 54.05361516135079, 49.963443415505544, 48.25657674244472, 49.64103657858712, 47.07641478947231, 50.809060028621126, 49.42948477608817, 51.08176987511771, 47.334634167807444, 45.568249225616455, 45.36893320083618, 38.093266010284424, 34.984162534986226, 34.00247587476458, 32.94497047151838, 34.567645822252544, 33.78360761914934, 34.61021743501936, 33.61561059951782, 33.29518747329712, 35.583152839115684, 35.80307027271816, 34.95011636189052, 37.15341445377895, 35.27339172363281, 34.68918718610491, 34.942289216177805, 35.542078563145225, 34.6376176561628, 34.819622244153706, 34.74396678379604, 33.7223835672651, 35.027303900037495, 35.491321972438264, 36.114644868033274, 35.209610734667095, 34.85166038785662, 36.13302285330636, 36.80460793631417, 36.439473152160645, 37.64296020780291, 33.99169921875, 33.88338722501482, 34.88519934245518, 38.877081871032715, 38.97995342527117, 38.16609355381557, 42.6843855040414, 38.666422912052695, 33.60575457981655, 35.442462239946636, 35.133250032152446, 37.15288291658674, 37.27950341360909, 34.752700669424875, 35.883665902274, 35.83976370947701, 34.4994284084865, 35.92518833705357, 34.519616399492534, 36.057096413203645, 35.812231472560335, 36.37499039513724, 33.55972971235003, 34.77479941504342, 34.22725009918213, 36.02712535858154, 34.396254607609336, 34.94080924987793, 35.51177746909005, 37.267493452344624, 35.63750512259347, 36.35017490386963, 40.95855024882725, 44.756254945482524, 43.51068959917341, 41.25178507396153, 40.17040913445609, 42.45821816580636, 39.215681484767366, 32.6043141910008, 33.71675205230713, 35.78610624585833, 36.337341581072124, 37.448129245213096, 34.73727914265224, 35.23185191835676, 33.82997294834682, 35.220724378313335, 35.363485540662495, 35.80696473802839, 35.32132387161255, 36.19211033412388, 33.893774781908306, 35.895172119140625, 35.365722860608784, 34.049560342516216, 35.12630878176008, 35.18194648197719, 35.01316779000418, 35.727098669324604, 35.02901315689087, 35.1398925100054, 35.884881837027415, 35.75656597954886, 36.160641942705425, 35.116167885916575, 36.29907437733242, 36.02644790921892, 34.79070731571743, 36.14170462744576, 37.089918340955464, 36.9804425239563, 36.03697443008423, 41.35037306376866, 44.17674739020211, 50.72826637540545, 49.63455043520246, 55.165281772613525, 50.34848826272147, 56.36500637871878, 48.98904194150652, 53.034811224256245, 52.123283999306814, 60.73883138384138, 1.5434323400259018, 0.43992410813059124, 3.7641427261488776, 0.3347997362060206, 0.11949749423989228, 39.22977590560913, 60.67345578329903, 55.82676764896938, 52.43392058781215, 51.49067483629499, 31.868809155055455, 20.816158533096313, 38.83882508959089, 59.104517800467356, 16.2605391229902, 0.6222733919109616, 0.22508143793259347, 0.11149013641157321, 0.04259772279432841, 0.0576542927218335, 0.07905043568462133, 0.032463493557380776, 0.05220271846545594, 0.22944211108343943, 0.2288041796003069, 0.19507364742457867, 0.16841913626662322, 0.13853091719959462, 0.12048666259007794, 0.18315725613917622, 0.18665589126093046, 0.19580852799117565, 0.185785710811615, 0.2012291814067534, 5.5277093052864075, 60.22737448556082, 61.48606845310756, 38.036766733442036, 32.40612724849156, 46.326884814671104, 54.1170973777771, 61.01595333644322, 62.50378499712263, 54.43708971568516, 61.146218163626536, 20.958758149828228, 1.075776451400348, 2.8509084156581332, 0.7835712081619671, 3.7474253603390286, 53.273422786167686, 55.70512901033674, 52.093761103493826, 50.38012341090611, 51.206285067967, 50.2041255405971, 53.506760665348594, 51.15931524549212, 53.185107707977295, 50.30939769744873, 48.27478449685233, 47.49816002164568, 40.626026834760395, 37.081052439553396, 36.175160203661235, 34.31190695081438, 37.734617369515554, 36.49671936035156, 36.73462915420532, 36.17258937018258, 34.285635811941965, 37.147473743983674, 38.02458306721279, 37.80105951854161, 39.94217470714024, 36.71956198556082, 37.520289761679514, 38.30427237919399, 40.180817535945344, 37.73094177246094, 37.130342960357666, 36.94390542166573, 36.294912406376426, 37.56823580605643, 36.003980909075054, 37.75928347451346, 35.98937232153756, 36.48917709078108, 37.99981273923601, 37.93208864756993, 39.45554372242519, 39.75686625071934, 36.89089066641671, 35.644380365099224, 37.517090116228374, 42.47963946206229, 44.20447070258004, 41.49131727218628, 43.788829462868826, 38.91925048828125, 35.246578625270296, 36.94809171131679, 36.73498698643276, 39.08450296946934, 40.18499340329851, 35.92869022914341, 37.71449538639614, 38.22984674998692, 36.43910142353603, 38.47532660620553, 37.19351250784737, 38.142890044621055, 38.17204468590872, 38.2260217666626, 36.56903273718697, 36.61796542576381, 36.276843615940635, 37.618245465414866, 35.41174077987671, 35.591310024261475, 39.68436527252197, 37.8712397984096, 37.69217429842268, 37.88203729901995, 42.65731184823172, 47.54053361075265, 44.91867256164551, 44.60576738630022, 43.785629817417686, 44.98517724445888, 42.24914687020438, 36.03236082621983, 36.167287894657676, 37.66652849742344, 38.37003360475813, 38.251254149845664, 38.19449084145682, 38.50663866315569, 35.598418031420024, 37.826441287994385, 37.31102739061628, 37.062417370932444, 37.86700487136841, 38.55323328290667, 35.66397081102644, 38.07482896532331, 38.36638927459717, 35.959297043936594, 37.264484882354736, 37.808785915374756, 36.59197916303362, 37.51936912536621, 36.95171867098127, 37.512803077697754, 37.14280455453055, 37.453851086752756, 36.81963341576712, 37.987712451389854, 39.002100808279856, 37.04109334945679, 37.01225485120501, 37.69765295301165, 39.80684116908482, 38.12235116958618, 38.600557463509695, 42.236146790640696, 46.516834667750764, 52.298531464168, 52.769931997571675, 57.64426006589617, 51.76431226730347, 58.672951289585654, 52.629922321864534, 54.93385117394583, 54.69809184755598, 64.40756361825126, 2.2289169686181203, 0.464991851576737, 8.51495657648359, 1.714674168399402, 0.2577424496412277, 43.71211787632534, 67.19781426021031, 60.167779786246165, 61.866961751665386, 58.9915748323713, 40.15372998373849, 33.55840955461775, 46.09568003245762, 68.76315307617188, 23.72038221359253, 0.9377314874104091, 0.3780889947499548, 0.17531943028526648, 0.11810062133840152, 0.23428866959043912, 0.20222874491342477, 0.19112298584410123, 0.13572931396109716], [0.04114848734544856, 0.031947647487478595, 0.040890216561300416, 0.033916976635477374, 0.018601201241835952, 0.03135844499671033, 0.03445976733097008, 0.057823180087975094, 0.026584275998175144, 0.07254125603607722, 0.1577013363795621, 1.455323102218764, 36.05594301223755, 50.60053069250924, 32.34280136653355, 27.584299768720353, 29.95792600086757, 47.34348964691162, 53.03496061052595, 50.119100434439524, 45.82396377835955, 50.678624970572336, 25.36057049887521, 0.10263391770422459, 0.7490494091595922, 0.12890819140842982, 0.03483040351420641, 29.7576858656747, 58.92882565089634, 44.28899206433977, 51.087651525224956, 42.335325377328054, 52.157809598105295, 48.35508482796805, 49.789248602730886, 44.83148309162685, 45.71610689163208, 40.75487075533186, 38.08833973748343, 30.352430820465088, 33.87872845785958, 32.28936277117048, 32.43458359582083, 33.59067004067557, 33.47966909408569, 31.2329968724932, 32.23233890533447, 33.29874842507498, 32.9663222857884, 33.209790638514924, 34.239527566092356, 33.29128953388759, 34.20278549194336, 33.912020751408164, 33.987023081098286, 33.91132940564837, 34.10946076256888, 32.48052508490426, 33.2078138760158, 31.74477686200823, 33.85059520176479, 34.66883591243199, 35.387314387730186, 34.05376052856445, 33.446870122637065, 33.60930858339582, 34.59924275534493, 36.59688459123884, 35.963104656764436, 32.61691474914551, 31.6097594669887, 35.18742166246687, 36.961977686200825, 37.60822268894741, 37.0774359021868, 41.22044175011771, 40.12022229603359, 34.036678382328574, 35.204003538404194, 34.51721927097866, 35.17874336242676, 33.75782632827759, 32.771685872759136, 33.30581474304199, 34.180460929870605, 32.15421336037772, 33.3077324458531, 33.11013610022408, 33.298595564705984, 32.50526067188808, 34.82847077505929, 34.54942069734846, 32.58519969667707, 32.34065784726824, 32.63420534133911, 31.43397699083601, 35.04808248792376, 35.72401366915022, 36.95609951019287, 34.760270731789724, 35.01701361792428, 36.56989778791155, 41.0771073613848, 40.721613202776226, 36.13616343906948, 40.194915430886404, 38.852290698460166, 36.29812594822475, 31.933295386178152, 30.196933610098704, 36.21805143356323, 36.234397070748464, 35.00418724332537, 32.96152455466134, 33.74578857421875, 33.92827953611101, 35.71367474964687, 33.14757994243077, 34.84195722852434, 33.21555069514683, 32.807125159672324, 32.51639516013009, 31.357421738760813, 31.949439525604248, 32.705872535705566, 33.07455090114048, 32.238001687186106, 32.415291922433035, 34.22514132090977, 32.25390611376081, 33.431049074445454, 33.19431005205427, 34.19348880222866, 33.340298652648926, 33.22774478367397, 34.052627972194124, 34.12061609540667, 33.50504738943917, 33.38245684759957, 34.54452221734183, 34.39657769884382, 33.824855600084575, 33.15863800048828, 36.86588409968785, 43.57347352164132, 47.761566230228965, 47.31508541107178, 51.883188996996196, 51.36840043749128, 53.83522285733904, 49.57646002088274, 59.44802284240723, 25.346981559480938, 0.09155477077833243, 0.11745148045676095, 1.3561071689639772, 0.23914448331509316, 0.022695077816024423, 39.823068686894004, 53.65122413635254, 49.811142376491, 55.398946217128206, 36.418034485408235, 21.181731053761073, 25.07822002683367, 37.010441371372764, 52.818003109523225, 6.875885214124407, 0.25273407410298077, 0.048762328789702485, 0.05400244439286845, 0.033954299454178126, 0.05194222887179681, 0.039022314827889204, 0.016674550250172615, 0.035426567774266005, 0.060440052167645524, 0.06651130531515394, 0.032970450818538666, 0.02146065976869847, 0.028927891847810576, 0.10222959904266254, 0.03442706533574632, 0.05810127088001796, 0.026633054184328233, 0.02161012915894389, 0.09237163194588252, 1.9665228085858482, 42.8345673424857, 54.07013102940151, 36.44947508403233, 32.497023582458496, 36.92132377624512, 52.600691250392366, 56.68013150351388, 57.761434486934114, 49.258701528821675, 56.315239906311035, 26.59033564158848, 0.07353657191353184, 0.8053079417773655, 1.114185984645571, 0.12762414530983993, 34.18059989384243, 60.37628132956368, 46.93376479830061, 54.58622932434082, 45.82662493841988, 51.894045557294575, 49.36603382655552, 50.318885462624685, 45.71644040516445, 47.80887304033552, 42.54738092422485, 39.75255141939436, 32.981813294546946, 35.58336475917271, 35.059425422123496, 33.97134794507708, 34.03147070748465, 34.72096477236067, 33.51923908506121, 33.379941599709646, 35.13682835442679, 36.02272367477417, 34.32513632093157, 37.00843334197998, 35.21824039731707, 37.06985889162336, 35.50714302062988, 37.1219356400626, 35.183218002319336, 33.720264366694856, 34.55328042166573, 35.27761275427682, 34.09655448368618, 35.57405417306082, 36.50301790237427, 35.597747530256, 35.437358788081575, 35.467086655753, 35.41125440597534, 36.03883307320731, 37.468932151794434, 38.50212928227016, 35.22318056651524, 32.97290917805263, 37.47124242782593, 39.19653919764927, 39.804180009024485, 39.85980033874512, 41.70665584291731, 40.91258791514805, 34.1998325075422, 36.543379987989155, 36.162889684949604, 36.557752336774556, 34.551466941833496, 34.55063663210188, 35.42343807220459, 36.006614276341026, 34.20534937722342, 35.55650997161865, 34.26943261282784, 36.52392850603376, 35.73793091092791, 35.962677342551096, 36.45443262372698, 35.394818442208425, 34.75848504475185, 34.928132261548726, 34.03056049346924, 37.147227082933696, 36.57976075581142, 36.950467995234895, 35.44998366492135, 35.39328983851841, 37.827608585357666, 42.45021731512887, 42.81699187414986, 39.73386076518467, 41.795697007860454, 39.00302144459316, 39.619083472660606, 33.00510365622384, 32.6508914402553, 37.26534298488072, 38.528396947043284, 36.63093076433454, 33.74884925569807, 34.86360434123448, 35.263223034994944, 36.34798969541277, 35.555182865687776, 35.69677325657436, 35.40965979439871, 34.82453114645821, 34.77332639694214, 33.74897084917341, 34.829318455287385, 35.51561287471226, 34.71121644973755, 34.49488428660801, 35.84680918284825, 36.486404759543284, 34.347245488848, 35.83522653579712, 35.950823715754915, 36.57123531614031, 36.007969175066265, 34.93731778008597, 34.85575982502529, 36.28864165714809, 34.575400011880056, 35.814524378095356, 35.94696399143764, 35.12969602857317, 35.094017028808594, 36.37905509131295, 39.39861018317086, 46.262058121817454, 48.43134478160313, 50.35863263266427, 53.323682580675396, 52.74763175419399, 55.75831399645124, 53.141125610896516, 61.081551279340474, 28.022428853171213, 0.12275413663259574, 0.7645457919154848, 3.4071842346872603, 0.13522987147527082, 0.145295097093497, 45.407780579158235, 56.47005271911621, 55.83138472693307, 59.633991377694265, 43.96287488937378, 28.77173474856785, 29.64432600566319, 43.25911269869123, 58.93128531319754, 10.795218995639257, 0.38348456951124327, 0.03183295132060136, 0.07438832335174084, 0.03255170989515526, 0.0884489192228232, 0.04936667957476207, 0.06182849766420467, 0.03960853176457541, 0.16416236039783272, 0.1675350729908262, 0.08164896017738751, 0.13583911449781486, 0.10763104991721255, 0.18602308950253896, 0.1145216476704393, 0.13558884364153656, 0.10056189567382846, 0.14639853074082307, 0.2722968900842326, 2.5748254358768463, 49.44667114530291, 63.54093565259661, 43.34589569909232, 38.57520696095058, 41.88051019396101, 59.00893143245152, 61.841176986694336, 60.77635165623256, 53.313923835754395, 59.41238553183419, 31.07928534916469, 0.2052489857056311, 3.121463234935488, 1.1002545207738876, 0.38288520595857073, 34.96101461138044, 63.50739669799805, 49.5545905658177, 56.20624698911394, 47.80651412691389, 53.65812022345406, 51.539854185921804, 51.658414772578645, 48.25767803192139, 50.394474915095735, 44.942046301705496, 41.83360290527344, 34.99254553658621, 36.754824093409944, 37.39868933813912, 36.605993679591585, 36.79596785136631, 36.78273153305054, 34.744022369384766, 35.29190867287772, 37.504246371132986, 37.147181919642854, 35.84597192491804, 39.32595981870379, 38.27425616128104, 39.19133847100394, 39.105173860277446, 38.81708765029907, 38.94731078829084, 36.66540077754429, 36.823743275233674, 38.75917441504342, 35.89966412952968, 36.44616774150303, 37.4836345400129, 37.30588572365897, 36.59334795815604, 37.32969372613089, 36.47767434801374, 37.719789913722444, 39.80010141645159, 39.671288762773784, 35.78246538979666, 35.648076806749614, 40.62818772452218, 40.56763069970267, 43.8619418825422, 44.014732769557405, 44.402588163103374, 41.08868653433663, 36.25910486493792, 38.80779790878296, 37.35598223549979, 37.71565226146153, 35.57129226412092, 37.63816247667585, 37.10669476645333, 38.12819113050188, 36.49412073407854, 36.23486954825265, 36.657135895320344, 38.11394384929112, 38.17973286764962, 38.38225201198033, 39.06802184241158, 36.64009196417672, 36.44525752748762, 36.902584484645296, 35.34909234728132, 38.37980277197701, 39.523427622658865, 40.84843519755772, 36.452952657427105, 35.71381718771798, 39.91702222824097, 43.99884918757847, 46.10350022997175, 43.603382042476106, 46.26570245197841, 41.83128220694405, 41.723640714372905, 35.790681634630474, 33.74284601211548, 39.43081160954067, 39.66975668498448, 37.51518630981445, 34.6649831363133, 36.80955852781023, 38.3589824948992, 39.181965351104736, 37.482550621032715, 37.37860557011196, 37.48137290137154, 36.62484761646816, 37.4955507005964, 34.56667307444981, 36.34893117632185, 36.77989666802542, 37.18846811567034, 36.87523637499128, 37.11762775693621, 38.79015295846121, 37.325340679713655, 36.38084077835083, 37.71500955309187, 38.13631704875401, 37.10675730024065, 36.66732542855399, 37.903052125658306, 37.05578531537737, 36.627724170684814, 38.271494252341135, 38.332290990012034, 37.84119578770229, 37.95950623920986, 37.45323964527675, 40.662435395377024, 48.006893226078574, 51.44854096003941, 52.09195804595947, 54.97469615936279, 53.929374422345845, 58.33872209276472, 54.73380558831351, 62.07034247262137, 29.668686389923096, 0.182636059820652, 0.4853530047195298, 5.747581575598035, 0.652610855443137, 0.20404348682079995, 50.40384108679635, 62.839369092668804, 61.610392570495605, 63.9413811819894, 48.338040896824424, 32.22034284046718, 35.44058970042637, 49.545207023620605, 68.03063229152134, 14.221329689025879, 0.5719709854040826, 0.108626250443714, 0.1618656279253108, 0.12314205510275704, 0.17315949047250406, 0.12005024243678365, 0.11847726255655289, 0.12018429381506783], [0.04117747436144522, 0.03908433632126876, 0.060361016408673356, 0.00859920321298497, 0.0435476718204362, 0.0476591563783586, 0.08199996634253434, 0.03171525942161679, 0.011962648713961244, 0.009644676399018084, 0.044205385992037396, 0.7976454900843757, 32.20492478779384, 51.86606863566807, 30.235391889299663, 17.30323965208871, 23.712284088134766, 43.318238394601, 52.372220584324424, 49.35041775022234, 49.2854277747018, 49.23398331233433, 36.47585391998291, 0.335034183625664, 1.3164153673819132, 0.40195893389838083, 0.14559866009013994, 3.4497265347412656, 47.396848337990896, 53.81105702263968, 49.851657322474885, 52.46720593316214, 51.240803718566895, 47.34598405020577, 44.85163286754063, 41.51127597263881, 38.18764686584473, 35.094506876809255, 33.15860325949532, 34.18695402145386, 32.877298491341726, 32.27101605279105, 33.58365930829729, 33.53170067923409, 31.773820332118444, 31.32750279562814, 33.645376682281494, 32.13985143389021, 34.90046106066023, 35.384389196123394, 35.098227637154714, 35.64963320323399, 35.667371954236714, 34.85935204369681, 35.680670806339805, 34.86783926827567, 34.890400069100515, 32.7703274999346, 32.880032607487266, 32.13736745289394, 33.54913370949881, 35.06534876142229, 33.65753950391497, 34.676346915108816, 33.329244068690706, 33.785358565194265, 32.99402475357056, 35.400109495435444, 36.27152476991926, 34.792857783181326, 31.208872726985387, 33.81806721006121, 37.82121276855469, 37.792662620544434, 36.17203351429531, 43.08059958049229, 38.80833639417376, 34.935240268707275, 35.109709535326274, 35.03161178316389, 34.47490474155971, 33.189442838941304, 33.05145856312343, 33.03242744718279, 31.992521830967494, 32.656015736716135, 33.1498624256679, 34.196615491594585, 35.34078924996512, 33.040424823760986, 34.243984835488455, 33.0524035181318, 32.72220427649361, 33.054658208574565, 32.617477553231375, 33.70295292990548, 33.36787952695574, 35.35787487030029, 35.02251311710903, 34.88215255737305, 35.65641464505877, 35.7964312689645, 40.092926297869, 41.176834855760845, 35.77299152101789, 37.06086444854736, 37.58846548625401, 35.99574729374477, 31.845664705548966, 30.863491671425955, 33.52171611785889, 34.78453384126936, 35.61446837016514, 32.65152372632708, 34.35059104646955, 35.30896997451782, 35.741908754621235, 33.55487639563424, 34.37444073813302, 33.870880467551096, 33.686829635075156, 34.33427667617798, 33.85195704868862, 34.15370341709682, 35.0070811680385, 33.48503657749721, 34.14535515648978, 34.20117698396955, 33.46839564187186, 35.42913906914847, 34.414983476911274, 36.19908632550921, 35.46623550142561, 37.4851770401001, 37.8386492729187, 41.23968826021467, 43.11562544958932, 42.168606826237266, 37.06849009650094, 35.22928803307669, 32.569371700286865, 33.40511839730399, 34.450005871909006, 36.374740259987966, 37.57433285032, 44.52146141869681, 46.92763301304409, 49.78896720068795, 49.69280760628836, 54.069001947130474, 49.3593635559082, 53.19922297341483, 4.698443540505, 0.13678599654563836, 0.7242830981101308, 2.1179177590778897, 0.1070109639050705, 0.20579346934599535, 38.39601639338902, 52.7503137588501, 50.75464868545532, 53.98265320914132, 28.7428389276777, 22.726119313921245, 23.16519856452942, 36.46326378413609, 43.980954102107454, 2.752483057124274, 0.1582273774381195, 0.030946143370653902, 0.04566881978618247, 0.045082338220838986, 0.01052721297102315, 0.0211858581751585, 0.03094047760324819, 0.04378031433693, 0.01611041453933077, 0.0647474874609283, 0.0849046390503645, 0.05641377803736499, 0.06841283863676445, 0.06993353060845818, 0.036847094406506846, 0.021061754120247703, 0.015021001121827533, 0.020226862580914582, 0.04054560558870435, 1.0131081512996127, 37.567624364580425, 58.21419300351824, 35.075614724840435, 20.69975883620126, 33.473565101623535, 50.69954252243042, 57.31176444462368, 53.60202741622925, 53.0206230027335, 53.84246288027082, 39.47962965284075, 0.2553258607430117, 1.1801717238766807, 2.308467762810843, 0.36685280767934664, 4.349341290337699, 52.15601348876953, 55.615907192230225, 51.87792921066284, 52.318507535117014, 53.10740947723389, 49.016786098480225, 48.0293984413147, 43.21835803985596, 41.12722471782139, 35.60905224936349, 35.87902797971453, 34.16232960564749, 34.6254791532244, 33.227782998766216, 36.23257316861834, 34.423856326511924, 33.28850678035191, 33.31359672546387, 34.246882234300884, 33.67072371074131, 36.227726800101145, 36.44388178416661, 37.12675421578543, 37.43908963884626, 37.64713607515608, 37.22043330328805, 37.19429070608956, 37.38444553102766, 37.11466782433646, 34.155635016305105, 36.61594002587454, 35.17859397615705, 34.948421001434326, 36.18217788423811, 35.56168637956892, 36.61644377027239, 33.685957636152, 33.946949345724924, 34.162555422101704, 36.60795654569353, 38.515403815678184, 36.78946433748518, 33.349428585597444, 36.50513710294451, 39.98759160723005, 39.166717529296875, 40.39408901759556, 43.70008359636579, 40.81965575899397, 35.76231908798218, 35.765761920383994, 35.66044807434082, 36.130535398210796, 34.07510886873518, 35.03257410866873, 34.52519232886178, 34.75278752190726, 35.12889003753662, 34.04367869240897, 36.182191780635286, 35.76104061944144, 35.81017827987671, 36.219107559749055, 34.64257172175816, 35.26501914433071, 35.434384959084646, 34.600851263318745, 35.370378153664724, 35.85755109786987, 37.39714336395264, 37.158809729984824, 36.254300185612266, 35.776601110185894, 34.72019352231707, 41.32761771338326, 42.03154666083199, 39.02316427230835, 40.1009966305324, 39.34131186349051, 37.603734152657644, 32.69869157246181, 32.37349850790841, 34.817270278930664, 36.928403990609304, 37.00152335848127, 35.12586062295096, 35.45808179037911, 36.92978320802961, 37.022833483559744, 36.30741221564156, 37.52346856253487, 34.83125352859497, 35.92283984592983, 36.736338411058696, 35.0241459437779, 35.89562027794974, 36.09505442210606, 34.84671674455915, 35.774450642721995, 35.01288986206055, 35.14110844475882, 37.76005472455706, 36.31048331941877, 36.380614961896626, 37.46946368898664, 37.68576805932181, 39.80173771721976, 42.796661445072715, 43.967373847961426, 43.03900766372681, 38.79238680430821, 37.4495848928179, 34.950126784188406, 35.28620072773525, 36.16603374481201, 38.57432801382882, 39.377126353127615, 48.3718056678772, 48.92180074964251, 52.0262975692749, 51.87139442988804, 56.29785551343645, 52.072263377053396, 54.15662567956107, 6.222029328346252, 0.3571637618754591, 3.487083090203149, 5.771588035992213, 0.24563496932387352, 0.30278661687459263, 43.69482033593314, 56.30079460144043, 56.281607151031494, 58.383301734924316, 34.8231588772365, 25.71932336262294, 24.21526939528329, 43.375588825770784, 51.32763188225882, 3.9605161888258795, 0.16841326015336172, 0.06299078743904829, 0.07557073168988739, 0.023857703465702276, 0.026139073905401995, 0.06703450331198317, 0.07100121224565165, 0.039999096521309445, 0.1653389401201691, 0.27461818552442957, 0.16008420208735125, 0.173790487327746, 0.08674098551273346, 0.1516224361423935, 0.1284417664366109, 0.18163880333304405, 0.13694925207112515, 0.15377550918076718, 0.11000074526028973, 1.3787390802587782, 46.20576729093279, 66.02843243735177, 42.64721264157976, 25.52917374883379, 34.87648630142212, 55.573432854243684, 61.435270173209055, 59.1339225769043, 57.581451824733186, 58.53341061728341, 44.653310435158865, 0.7236477179186684, 2.8259109684399197, 3.191854349204472, 0.22261176045451844, 5.403635323047638, 52.35151147842407, 58.015193121773855, 54.85462433951241, 55.15130199704851, 55.46368258340018, 50.764383111681255, 50.28425564084734, 44.576949732644216, 42.57741798673357, 37.204157148088726, 37.527602740696494, 37.41654620851789, 36.58171667371477, 36.63343906402588, 38.902557441166465, 37.44361639022827, 35.06284393583025, 33.66740942001343, 36.415738105773926, 34.98626089096069, 39.101460048130576, 40.09032072339739, 39.37911353792463, 39.97834355490548, 39.0295045035226, 40.6264819417681, 39.4881203515189, 40.13839183534895, 39.26875877380371, 36.16882692064558, 38.58809586933681, 36.59195137023926, 36.65146616527012, 38.29847410746983, 36.55319084439959, 38.44553273064749, 35.119110448019846, 36.27134411675589, 36.12767621449062, 36.815238680158345, 39.63708278111049, 39.95790195465088, 34.98885256903512, 37.48368317740304, 42.422466209956575, 43.027386801583425, 42.71038566316877, 46.32714189801897, 42.58418900626046, 37.27778026035854, 37.29530014310564, 37.42534262793404, 37.6969963482448, 35.62505395071847, 38.4854952948434, 36.29744502476284, 35.864721638815745, 36.530748162950786, 36.216724327632356, 37.175652163369314, 38.21959120886666, 37.34385068075997, 39.14399344580514, 37.095192023685996, 37.86650807516915, 37.0262519972665, 37.76875386919294, 37.61405570166451, 38.7732584135873, 40.261767523629324, 37.482293537684846, 36.603791100638254, 37.68986054829189, 36.919510296412874, 43.62380279813494, 44.68089478356497, 41.414821079799104, 43.312537397657124, 41.73093632289341, 39.77154084614345, 35.13656432288033, 34.91076176507132, 36.342615263802664, 38.7726400239127, 39.81778458186558, 35.70748043060303, 37.10302611759731, 38.823493889399934, 39.77400745664324, 37.98692383084978, 38.19447694505964, 37.03698696408953, 38.85863092967442, 38.84226792199271, 37.865330355507986, 39.058276993887766, 39.46222788946969, 37.12030281339373, 38.27681309836251, 37.401145526341026, 37.301845346178325, 39.1372641154698, 38.176488058907644, 38.56180041176932, 39.98030642100743, 40.42112793241228, 41.801898275102886, 44.49837255477905, 45.93142809186663, 46.30592557362148, 41.49332530157906, 40.19088200160435, 36.984889371054514, 36.931662695748464, 37.560801233564106, 41.08676535742623, 41.18338005883353, 50.584063461848665, 51.36206715447562, 54.29445709500994, 53.062791619982036, 57.22900792530605, 51.649993555886404, 56.00248759133475, 7.465900182723999, 0.3290839200573308, 3.8099665301186696, 12.015916739191328, 1.196027187364442, 0.45034589033041683, 47.76140642166138, 61.02451351710728, 61.85881151471819, 62.910588128226145, 40.225348540714805, 33.350852966308594, 33.33558429990496, 49.145636967250276, 60.70757143838065, 6.738338240555354, 0.3847537828343255, 0.2616751571851117, 0.21880783885717392, 0.1583759087537016, 0.07331980033112423, 0.16651956391121658, 0.23444201850465365, 0.13413034618965217], [0.006305061047896743, 0.02737754619946437, 0.08178593604160206, 0.0445656439821635, 0.06273571934018816, 0.05635156994685531, 0.020703889662399888, 0.022204456285440495, 0.054331744222768714, 0.02055312766294394, 0.06912433010126863, 0.3081838201199259, 31.78100824356079, 50.489950111934114, 42.815723827907014, 29.311458655766078, 19.259993076324463, 40.267395564488, 54.12412895475115, 49.088224002293174, 50.41016742161342, 43.03335877827236, 48.39198323658535, 2.3079868171896254, 1.2034782618284225, 2.3647308009011403, 0.31121233903935974, 0.05185606510245374, 9.934324162346975, 52.56186124256679, 50.04928493499756, 54.09251117706299, 47.48132106236049, 46.74374198913574, 41.93295867102486, 37.34254094532558, 34.40359190532139, 32.873362336839946, 33.394108976636616, 33.632692745753694, 32.594628402165, 33.36041021347046, 32.99076952253069, 32.030240127018516, 33.03044721058437, 34.430373736790244, 35.34022991997855, 37.6394305229187, 35.325669969831196, 36.544432640075684, 34.46237366540091, 37.31791305541992, 35.60221522194998, 35.89431054251534, 37.33482149669102, 36.195629596710205, 34.946805545261924, 35.41687897273472, 33.185781138283865, 32.641754559108186, 33.55653006689889, 33.939455713544575, 33.949308259146555, 34.78402314867292, 33.71779775619507, 33.75876086098807, 34.951738766261506, 35.38759578977312, 35.92361109597342, 35.30540207454136, 31.917842592511857, 33.44759273529053, 37.47953510284424, 37.487754821777344, 37.391748087746755, 39.55125168391636, 38.71740531921387, 34.815804209027974, 35.97977685928345, 35.44558892931257, 34.14611945833479, 31.93196828024728, 33.074759347098215, 32.89417219161987, 32.67414011274065, 34.432930673871724, 33.60507713045393, 33.500548430851524, 33.88603796277727, 33.7410637991769, 32.93330097198486, 33.051580156598774, 33.38057041168213, 32.9966025352478, 32.96234096799578, 33.57840647016253, 33.48003734861101, 35.07193217958723, 35.811032908303396, 34.58203206743513, 35.27413518088204, 35.79140077318464, 39.79917730603899, 42.11708245958601, 36.61283418110439, 36.0751964705331, 39.07524796894619, 37.29168013163975, 32.22857298169817, 30.374883924211773, 35.29727268218994, 35.42084986822945, 34.281859466007774, 34.12107467651367, 34.992691448756624, 34.57383666719709, 35.24609572546822, 34.43768324170794, 34.86225291660854, 34.62976271765572, 32.97140489305769, 33.38334969111851, 32.53545754296439, 32.28977618898664, 32.94170134408133, 33.85756424495152, 34.295213903699604, 33.46458108084542, 33.926618916647776, 34.42354713167463, 35.539344446999685, 36.223849705287385, 39.0286602973938, 42.38390370777675, 46.782613686152864, 44.097364221300396, 44.25713804789952, 45.161800452641074, 42.883753640311106, 41.53240197045462, 36.925058432987754, 33.502469607761924, 33.83702884401594, 34.92989362989153, 33.570808615003315, 37.33931698117937, 43.85672378540039, 46.07523843220302, 49.66030740737915, 54.20021520342146, 54.193583147866384, 36.83281067439488, 0.1884440210248743, 0.09590778326881783, 3.0315622304167067, 1.6032060640198844, 0.04238198597782424, 0.5659930376069886, 43.42534834997994, 53.2012414251055, 50.732355390276226, 54.41103744506836, 30.43115391050066, 25.080467769077845, 34.629165172576904, 39.828860010419575, 46.02339792251587, 1.158673671739442, 0.07451998628675938, 0.006896244012750685, 0.03600271525127547, 0.04926664315696273, 0.03180681415168302, 0.02716035901435784, 0.017771497102720395, 0.0574858599741544, 0.051216949575713704, 0.048980009609035084, 0.027935556435425366, 0.027116805547848344, 0.052281336925391636, 0.025223857390561273, 0.03534947262544717, 0.0361729393314038, 0.03392462372513754, 0.04594607258747731, 0.060359584699784, 0.4853566959500313, 36.342643056597026, 56.09139674050467, 46.26124518258231, 27.68105517114912, 29.13574913569859, 47.52894401550293, 59.192204066685264, 54.319553988320486, 54.83253949029105, 47.955143042973106, 52.505841391427175, 1.9234420231410434, 1.0903850389378411, 1.7156574470656258, 0.9136122273547309, 0.1473389124231679, 11.674592563084193, 55.461288928985596, 50.14460727146694, 56.443472385406494, 49.25496687207903, 49.24256781169346, 44.178974287850515, 39.82489258902413, 36.146801131112234, 35.12073632649013, 34.53161941255842, 35.566185338156565, 33.93341425486973, 35.230483123234336, 35.0906297819955, 33.92947115216936, 33.77269894736153, 36.03446613039289, 36.838365759168354, 39.177539348602295, 36.2421304157802, 37.535923208509175, 36.82607092176165, 39.034771238054546, 36.69694907324654, 38.596801962171284, 39.21037653514317, 37.99448694501604, 37.68629264831543, 37.478777749197825, 35.5001357623509, 34.766701289585654, 34.076939719063894, 35.49601200648716, 35.68824086870466, 36.45494679042271, 34.52850661958967, 35.25628873280117, 35.80127763748169, 36.04338761738369, 37.63484123774937, 37.32102584838867, 32.98817784445626, 35.630959919520784, 39.22032635552542, 39.62455865315029, 39.02900423322405, 41.35646315983364, 40.127740246909006, 36.46428516932896, 37.159574031829834, 36.91721044267927, 35.19282388687134, 34.1385771887643, 34.204008374895366, 34.586742946079795, 34.70481021063668, 36.1202346937997, 35.85288538251604, 35.4091352054051, 35.01670094898769, 34.69491597584316, 35.950156688690186, 35.641208512442454, 35.48052794592721, 34.970082010541645, 34.515614237104145, 34.60300520488194, 34.627098083496094, 37.34028625488281, 37.96148994990757, 36.26978077207293, 34.63466119766235, 35.897690841129844, 40.449917793273926, 44.4496031488691, 38.703050340924946, 38.81778941835676, 41.316618715013774, 39.763533047267366, 34.42114305496216, 31.479880264827184, 35.72988837105887, 36.26062652042934, 36.869535378047395, 35.372334071568076, 36.29986994607108, 35.93130275181362, 36.00231681551252, 35.619978291647776, 36.011967863355366, 35.51164892741612, 34.936133112226216, 36.35676874433245, 35.76725925718035, 35.38545574460711, 34.83243472235543, 35.70300579071045, 36.14193739209856, 36.41503633771624, 34.99745791299002, 37.14053249359131, 36.83799055644444, 38.30555084773472, 40.19605493545532, 45.313667229243684, 48.06332302093506, 46.95485258102417, 45.87497050421578, 48.087964807237896, 45.5614469391959, 43.02231461661202, 39.2532434463501, 35.256851536887034, 35.088555744716096, 35.91044078554426, 36.98844684873308, 39.54871211733137, 45.857353346688406, 48.181435448782786, 51.86961221694946, 56.043756416865754, 53.50228255135672, 39.669430119650706, 0.6207510307431221, 0.45986256109816687, 5.836641413824899, 6.256598787648337, 0.14894660615495273, 0.5193748048373631, 48.94384043557303, 57.27496331078665, 55.392585141318186, 58.49843338557652, 41.5738445009504, 31.63409205845424, 35.44766991479056, 45.54010902132307, 53.263365268707275, 2.0066069662570953, 0.09625318473471062, 0.042361134596701176, 0.14956161672515528, 0.027496808907017112, 0.02606516787117081, 0.03445013552638037, 0.018174126212085997, 0.023259892061884915, 0.114289059436747, 0.17891831217067583, 0.17555394555841172, 0.192591539184962, 0.14709259064069816, 0.05200277455151081, 0.10104503974850688, 0.09230143071285316, 0.13205880591911928, 0.11656334597085204, 0.11052274903548615, 0.48126550976719173, 43.59483923230852, 62.95181179046631, 53.788079329899375, 40.307903562273296, 29.239318983895437, 49.460157598767964, 64.97932393210274, 57.692268644060405, 61.035665375845774, 50.9372820854187, 58.246731417519705, 2.7688977420330048, 2.3928514633859908, 5.550627938338688, 1.12606403870242, 0.18708976012255463, 13.914817724909101, 55.47987536021641, 52.29342801230294, 57.64219645091465, 52.135120255606516, 51.9496693611145, 46.512068203517366, 43.11569840567452, 37.852326801845, 37.281831060137065, 36.590405396052766, 36.52262224469866, 36.04707363673619, 37.118920121874126, 36.143747397831504, 35.97437463487898, 36.974248204912456, 37.67234761374337, 39.97091940471104, 41.260220187050955, 38.33564696993147, 40.787221567971365, 38.50668730054583, 42.247635637010845, 39.48500755855015, 40.74159969602312, 41.17117902210781, 41.15785585130964, 39.586051736559185, 41.16468940462385, 37.80059746333531, 36.859227725437705, 36.715893336704795, 35.71133320672171, 37.21897070748465, 38.87288515908377, 36.07286187580654, 37.06445666721889, 37.94718708310808, 38.557106903621126, 39.0863025529044, 39.298663820539204, 35.87251056943621, 36.575081144060405, 40.672982760838096, 41.566448143550325, 41.86925063814436, 42.76025635855538, 41.15472568784441, 37.20479638235909, 39.33720547812325, 39.70569624219622, 36.57350737707955, 35.701671736580984, 36.86663103103638, 36.63729531424386, 37.415559564317974, 37.08674648829869, 37.87750359943935, 36.69339506966727, 37.717493534088135, 37.00478901181902, 38.10530376434326, 36.71210309437343, 37.96520723615374, 36.86953885214669, 37.244863169533865, 36.11949471064976, 37.56005777631487, 38.94410419464111, 38.860017095293315, 36.326787267412456, 36.18773296901158, 38.16147994995117, 42.68393734523228, 46.55772481645857, 41.12443501608712, 41.5879910332816, 43.87078693934849, 42.29207631519863, 37.07155772617885, 33.69083179746355, 40.11899593898228, 38.43997417177473, 37.51835816247122, 37.40861483982631, 38.39667994635445, 37.34576838357108, 38.40174865722656, 37.46874107633318, 37.40210785184588, 38.252998147692, 37.511510712759836, 38.48319544110979, 37.81545271192278, 37.460090569087434, 36.522403376443044, 37.395666871752056, 39.25933354241507, 37.278443813323975, 36.37092569896153, 39.097933837345664, 39.1410300391061, 40.15315328325544, 41.95271587371826, 47.342909472329275, 49.48113073621477, 49.21488618850708, 48.61030953271048, 49.224373953683035, 46.983840465545654, 45.47326040267944, 40.77680969238281, 37.19792461395264, 37.656172207423616, 38.721553393772666, 38.19736392157418, 42.17481504167829, 46.92953334535871, 50.410879611968994, 54.34095791407994, 60.42941420418875, 53.90622302464077, 41.25631182534354, 1.1091121711901255, 0.35103982048375265, 7.358278666223798, 8.932390451431274, 0.7448542171290943, 0.8773309056247983, 55.868095534188406, 61.150588580540244, 59.661061559404644, 63.892215728759766, 43.39315734590803, 35.96811778204781, 45.48503065109253, 51.23670775549752, 62.47979981558663, 3.2050379046372006, 0.20452414745731012, 0.15997886631105626, 0.2158591563680342, 0.19606531278363296, 0.09682593614395175, 0.13106488782380307, 0.09770526324531861, 0.12630363473934786], [0.07979584711470775, 0.024011447626565183, 0.028189335317750062, 0.04916881197797401, 0.06025826585079942, 0.024897224203284298, 0.050876474274056296, 0.050276706993047676, 0.05258527650896992, 0.04204492709998574, 0.028659225907176733, 0.17337747663259506, 22.72379514149257, 54.0289421081543, 38.50150394439697, 23.033493723188126, 28.80468831743513, 26.844313144683838, 49.2201702935355, 51.24980510984148, 51.52043744495937, 43.35992063794817, 51.48673520769392, 6.310137263366154, 1.2591476632016045, 1.291781832064901, 2.458497175148555, 0.30711024201342035, 0.49536503319229397, 41.084625312260215, 53.78051968983242, 48.51559516361782, 44.72959818158831, 39.691365582602366, 36.052055495125906, 35.18430192129952, 32.24970245361328, 36.206399304526194, 33.84506443568638, 33.49959652764456, 32.2479202406747, 33.40740435464041, 31.654766423361643, 35.15862832750593, 36.03296879359654, 37.22436945778983, 38.43121944155012, 39.033218315669465, 36.25984484808785, 38.964445046016145, 37.36813463483538, 37.45634549004691, 35.69014467511858, 37.13326120376587, 36.482239314488, 37.82790388379778, 37.01291145597185, 35.525649547576904, 34.313032558986116, 33.06051206588745, 35.269518102918354, 35.12779222215925, 35.60262516566685, 33.74662583214896, 34.112260886601035, 33.85116842814854, 32.998297895704, 34.27512318747384, 35.94044310706002, 33.4861204964774, 32.53209808894566, 35.60626949582781, 37.54759618214199, 36.46745007378714, 39.09854180472237, 39.94381448200771, 41.14767326627459, 38.85435083934239, 37.00957979474749, 34.99661718096052, 33.269149099077495, 33.915581703186035, 33.03266716003418, 33.05710744857788, 32.969007764543804, 34.834241253989084, 31.975168704986572, 34.45120096206665, 33.23380708694458, 35.931924615587505, 33.93106576374599, 33.015974112919395, 34.39681393759591, 33.79491581235613, 32.921888555799214, 33.85672351292202, 33.351304599217, 34.50126620701381, 35.71200370788574, 36.22561802182879, 35.77700410570417, 34.880846296037944, 39.295936652592246, 41.0778751373291, 38.760126318250386, 33.051434244428364, 37.39835582460676, 38.7484255518232, 31.930783612387522, 30.29496226991926, 34.730525493621826, 34.785166127341135, 34.83864293779646, 34.427337374006, 34.19858877999442, 33.50086457388741, 32.681929043361116, 34.757630416325156, 34.00155871255057, 36.04881068638393, 33.53835357938494, 34.861964566367014, 32.78123964582171, 32.66004221779959, 34.8912546975272, 34.59088407244001, 33.97161545072283, 35.49889898300171, 36.35259287697928, 36.129437582833425, 34.812931128910606, 39.22282075881958, 44.9496511050633, 49.19000816345215, 42.53375898088728, 42.675109658922466, 46.75857291902815, 45.14500665664673, 47.74126706804548, 45.676818302699495, 42.460472856249126, 36.763033390045166, 34.29450866154262, 34.43958009992327, 35.391184534345356, 35.99001850400652, 38.44730799538748, 44.761195114680696, 48.627600124904085, 49.4606613431658, 55.4381479535784, 30.42613731111799, 0.08283997233957052, 0.40330731868743896, 4.977418925080981, 6.308750663484846, 0.3776103290063994, 1.743116619331496, 47.21778631210327, 51.314687388283865, 51.5550776890346, 52.1460462978908, 29.242428302764893, 20.077556337629044, 31.67710140773228, 43.53799949373518, 24.048597744532994, 0.07899948449007102, 0.013868097182629364, 0.03782805248296686, 0.06083177721926144, 0.013781280323330845, 0.009085720454874848, 0.012074581546975034, 0.042962710173534494, 0.0539625601044723, 0.1154154682798045, 0.02505471896646278, 0.018752350006252527, 0.02735513588413596, 0.09193188018564667, 0.0042137673507178465, 0.0551450430814709, 0.00826691189182124, 0.07922353675322873, 0.04877051870737757, 0.18898361921310425, 0.22564473056367465, 30.31980902808053, 60.469908305576865, 46.580952644348145, 25.563417945589336, 24.489513056618826, 36.18055895396641, 54.12025533403669, 54.7175989151001, 55.717069489615305, 48.821715423039024, 54.56646864754813, 6.788190696920667, 1.271021700331143, 1.9102089617933546, 2.7031638750008176, 0.4934652979884829, 0.6361981789980615, 43.51683875492641, 53.24893038613455, 49.407521520342144, 46.681444440569194, 42.91193553379604, 38.08404227665493, 37.63912827627999, 34.033336298806326, 36.464351177215576, 36.09738901683262, 35.20283971514021, 34.22692353384835, 36.069214071546284, 34.524580887385774, 35.68434292929513, 37.27725567136492, 39.652622427259175, 39.59890590395246, 41.2158385685512, 37.95111976351057, 39.28431926454817, 39.64577497754778, 38.33694975716727, 37.74430315835135, 38.308976309640066, 39.045016356876914, 39.70835740225655, 38.69656767163958, 38.27317919049944, 35.51913561139788, 34.73086595535278, 35.190940925053184, 35.40706811632429, 34.95563670567104, 35.476352078574045, 34.77446242741176, 35.60303510938372, 33.660006114414756, 34.85493646349226, 36.53423615864345, 35.2132237979344, 35.00304773875645, 36.65896674564907, 39.92282049996512, 38.842910630362375, 39.603529930114746, 42.30180379322597, 43.29549694061279, 38.69531004769461, 37.73856047221592, 36.13780321393694, 35.547550269535606, 34.884535789489746, 34.026468004499165, 34.596421786717, 34.01257855551583, 36.08609472002302, 34.477461678641184, 36.52755199159895, 35.3252843448094, 36.7331074987139, 34.685914584568565, 35.016548088618684, 35.84073298318045, 36.07462671824864, 34.55135924475533, 36.05647454942976, 35.18815469741821, 36.53317308425903, 36.967661312648225, 37.86145326069423, 36.937672887529644, 35.33190597806658, 39.5582207271031, 43.18494067873274, 40.46112871170044, 36.53905126026699, 40.3530981200082, 39.717595032283235, 33.0437912259783, 31.063999312264578, 36.96954427446638, 37.21914093835013, 36.18015595844814, 36.158206599099294, 36.399434157780235, 36.96970060893467, 33.05671487535749, 36.32471323013306, 36.515062604631694, 37.81040831974575, 35.5865227154323, 36.67748716899327, 34.35421800613403, 34.29745122364589, 35.7995023727417, 38.21504708698818, 34.80788326263428, 37.5377471106393, 37.70462547029768, 38.43228251593453, 34.90498086384365, 41.44892283848354, 45.956094196864534, 49.0648398399353, 45.9872499193464, 46.148781640189036, 47.36895132064819, 47.0708075932094, 47.180231298719136, 47.109894684382844, 43.78294781276158, 37.74183654785156, 35.48144858224051, 36.14917046683175, 37.512615476335796, 37.60505083629063, 39.98477063860212, 45.707876750401084, 50.73492622375488, 54.07892050061907, 55.4071763583592, 34.62311329160418, 0.07283860365194933, 1.9296055095536369, 7.602987272398813, 1.9444436047758376, 0.13555407550718102, 1.6243074174438203, 53.661552633558, 55.20572028841291, 56.548296383449006, 56.48905951636178, 35.37675659997122, 23.719438995633805, 37.594454833439414, 48.186115060533794, 32.9964531489781, 0.04255816081006612, 0.03734317814399089, 0.06367793985243354, 0.0651100015799914, 0.059424251317977905, 0.0302593166540776, 0.05482284412054079, 0.014279925530510289, 0.07079491724393197, 0.2160103339701891, 0.08826981311930077, 0.18842627054878644, 0.14264119735785893, 0.18753379343875817, 0.14216341370982782, 0.1978599971958569, 0.08214318472892046, 0.1855261440255812, 0.15189513936638832, 0.30715475391064373, 0.511497013270855, 35.48978294645037, 67.97192696162632, 51.43576322283064, 32.4465206010001, 39.32887806211199, 38.4103296824864, 58.00337076187134, 60.266583170209614, 61.54882458278111, 51.827509607587544, 61.40932559967041, 8.349272438458033, 2.4396280390875678, 4.0105527724538526, 6.661646630082812, 0.9255503181900296, 1.0544589438608714, 48.138318402426584, 54.85961314610073, 52.58111122676304, 47.0268428666251, 44.012290477752686, 39.56439420155117, 40.79814066205706, 35.841285364968435, 40.025132724217, 38.29314831324986, 37.619753224509104, 36.70712123598371, 37.240395477839876, 35.302247592381065, 39.94685779299055, 39.94856704984392, 41.43243476322719, 42.16989919117519, 43.927644048418315, 40.59766428811209, 42.42939008985247, 41.93372297286987, 41.28426095417568, 38.64653369358608, 41.47740350450788, 41.62345116479056, 41.29491949081421, 42.08241094861712, 39.76575647081648, 37.572099004473, 37.29083939961025, 38.042620590754915, 38.66277510779244, 38.41967153549194, 35.85539368220738, 37.09904479980469, 37.680800097329275, 34.757064138139995, 36.451229504176546, 38.343818051474436, 36.90589182717459, 37.8468724659511, 39.31930691855294, 42.3687218938555, 41.63465860911778, 42.026241711207796, 43.429065636226106, 44.215049334934776, 41.47652455738613, 40.52568095070975, 37.428733348846436, 36.8116568837847, 37.91600704193115, 35.96000576019287, 35.538736479622976, 36.751798152923584, 38.972762039729524, 35.40722792489188, 38.219243798937114, 37.14460413796561, 40.127292088099885, 37.51886190686907, 37.80548204694475, 37.71570437295096, 37.88122088568551, 38.181007862091064, 38.294482367379324, 36.189105238233296, 37.394947733197895, 39.47758688245501, 39.125872543879915, 37.71385267802647, 37.40451192855835, 41.73868703842163, 43.87625169754028, 42.646107878003804, 38.24413224628994, 42.78701387132917, 41.651765074048726, 35.477036476135254, 34.091253008161274, 38.12382418768746, 38.380202293395996, 38.32096890040806, 38.319600105285645, 38.79281064442226, 37.58469956261771, 34.89807782854353, 37.77935682024275, 37.628525325230186, 39.581886291503906, 36.406330244881765, 38.233008180345806, 36.92389113562447, 37.39868238994053, 38.56630284445626, 39.52345194135393, 36.81864677156721, 40.904163224356516, 38.62884357997349, 38.66129514149257, 37.746484892708914, 43.61435324805123, 47.90428917748587, 52.697573457445415, 49.770099367414204, 47.30042471204485, 48.48212916510445, 48.687438011169434, 50.05723367418562, 49.93268026624407, 45.071824754987446, 40.438168389456614, 37.49152421951294, 38.645241328648154, 39.99871914727347, 40.387884276253835, 41.93773555755615, 48.86463791983468, 54.15880046572004, 56.40540320532662, 56.1625462940761, 37.50138371331351, 0.1937804546739374, 1.533692485519818, 11.583203775542122, 13.565193925585065, 0.8470116268311227, 2.3998865144593373, 58.36377729688372, 57.09245845249721, 62.180547850472585, 59.77385861533028, 39.691389901297434, 29.444950921194895, 44.85879993438721, 56.11650405611311, 43.11224167687552, 0.39478424031819614, 0.12013168020972184, 0.19361772840576513, 0.1846832406840154, 0.14448890249644006, 0.1323794544275318, 0.10542543791234493, 0.1271959761423724, 0.15481623262166977], [0.009792722562061889, 0.02790111569421632, 0.04455864489344614, 0.045450633458260975, 0.047563879883715084, 0.03194076035703931, 0.03818226133340171, 0.0673033795984728, 0.01869476443555738, 0.038075880613178015, 0.04333009956670659, 0.0809056047084076, 20.755710942404612, 52.64887005942208, 40.49785688945225, 37.523162841796875, 76.20935685294015, 45.32446820395333, 38.84205252783639, 54.271687848227366, 50.39468336105347, 43.489924907684326, 49.39048106329781, 15.667753560202462, 0.9641452814851488, 0.898992946105344, 1.0962953503642763, 1.5241944066115787, 0.09202686830290727, 31.404697281973704, 55.34179033551897, 46.68895196914673, 44.33236619404384, 36.8333283151899, 35.41795941761562, 35.282191617148264, 34.88866996765137, 38.31100518362862, 36.54254273005894, 36.481732095990864, 33.461489132472444, 32.6359806060791, 32.82886259896414, 37.86674083982195, 41.11840745380947, 42.31929240907942, 41.174830300467356, 39.934691497257774, 38.672905581338064, 38.168865885053364, 38.56234584535871, 39.11410229546683, 39.51411703654698, 37.669745513371055, 37.384956223624094, 38.13553190231323, 37.66669525418963, 38.71547719410488, 35.36461114883423, 33.359069211142405, 34.0892310823713, 35.076198373522075, 34.88524797984532, 35.55534962245396, 33.57383108139038, 33.9562668800354, 33.11368662970406, 35.80613095419747, 37.19976588657924, 34.178032534463064, 31.630875042506627, 36.01689066205706, 38.96211739948818, 37.404432024274556, 38.74411766869681, 39.70482076917376, 41.83434983662197, 38.2818192754473, 36.737262521471294, 35.39605522155762, 34.83471025739397, 33.82453598294939, 34.19812325068882, 31.949512481689453, 32.98703486578805, 33.39718008041382, 32.93061549322945, 34.07227052961077, 33.35793318067278, 37.981841223580496, 37.08209119524275, 33.65074069159371, 35.03066335405622, 31.695482867104666, 33.66342115402222, 33.953372955322266, 33.52051755360195, 34.459274768829346, 34.47005142484392, 35.905865396772114, 35.98539795194353, 36.33264112472534, 37.38094711303711, 40.07954406738281, 37.965985434395925, 36.753093991960796, 36.3244491985866, 37.66793203353882, 33.62574454716274, 30.04297889981951, 33.45857783726284, 36.09400871821812, 35.26613433020455, 33.31053951808384, 33.80763101577759, 33.77453327178955, 34.7356984274728, 34.50517109462193, 36.78909608295986, 34.80812644958496, 34.496027265276226, 33.170929363795686, 33.722658021109446, 33.228338854653494, 34.7505328314645, 34.4533896446228, 37.18374334062849, 35.395871094294954, 35.61744914736067, 35.57205656596592, 40.16173778261457, 44.89614302771432, 46.874805859157014, 44.87598630360195, 41.900847571236746, 45.298471518925254, 45.1820718220302, 46.40448924473354, 45.7016407421657, 48.32928269250052, 46.25789267676217, 44.82467038290841, 37.802713189806255, 35.10174689974104, 34.96344648088728, 35.06431000573294, 35.44299030303955, 40.899744170052664, 46.71142591748919, 49.96364491326468, 56.253755296979634, 28.72860380581447, 0.15269002957003458, 2.0613735360758643, 7.913001997130258, 2.599738201924733, 0.4901739146028246, 5.618370703288487, 55.88199887956892, 47.59045989172799, 53.81689003535679, 49.018140997205464, 33.47042451586042, 24.253734622682842, 30.335525853293284, 44.70782252720424, 15.520384005137853, 0.006207633173159722, 0.062030965728419166, 0.013692103858504976, 0.022639090195298195, 0.005240670305543712, 0.06877710337617568, 0.017163008950384598, 0.03983879940850394, 0.02260903618298471, 0.01841656507791153, 0.033329880995942016, 0.05004226296607937, 0.030953098354595046, 0.027158331890989627, 0.10144743815596614, 0.009591522510163486, 0.044145169401807446, 0.06485599199576036, 0.03997440463198083, 0.08809386220361505, 0.13955901988915034, 24.181412560599192, 59.38241795131138, 45.36121722630092, 35.37163577760969, 59.19489996773856, 38.632953439440044, 46.7925009727478, 59.961862972804475, 54.92784098216465, 47.63299328940255, 54.06923818588257, 15.561209883008685, 0.9632032577480588, 0.9328749137265342, 3.3286250787121907, 3.2172367700508664, 0.08086580862956387, 34.8576705796378, 55.72028997966221, 49.25190271650042, 46.44287109375, 39.82180758884975, 37.19006620134626, 36.573632444654194, 37.53051403590611, 39.647852488926475, 38.85084547315325, 38.38463176999773, 34.68479592459542, 34.70841979980469, 35.18435403278896, 40.271467208862305, 42.46623638698033, 44.313887459891184, 42.49425152369908, 41.53615052359444, 40.65202351978847, 40.93884515762329, 39.87154974256243, 39.51380784170968, 40.302612509046284, 38.87639052527291, 39.16184336798531, 39.470398971012656, 38.837883608681814, 40.712639604296, 36.0180127961295, 36.08461822782244, 35.416983195713584, 35.35733985900879, 35.02531671524048, 36.69778633117676, 34.70039810453142, 36.817715712956016, 36.064524037497385, 37.24324771336147, 38.06239168984549, 35.81833546502249, 33.57278537750244, 36.983586583818706, 41.802422864096506, 40.51178107942854, 40.088670526232036, 41.279532705034526, 42.433736188071116, 39.64252322060721, 37.80762904030936, 36.14227785382952, 36.55703319822039, 35.43947451455252, 35.280607427869526, 33.81335980551583, 34.452816418239046, 35.23803581510271, 36.30387558255877, 36.02361304419381, 35.695918628147666, 38.3923407963344, 38.47467347553798, 35.57292856488909, 35.71193075180054, 34.08978346415928, 34.73507308959961, 35.53190640040806, 36.23676988056728, 34.91367653438023, 34.78294617789132, 36.99129908425467, 35.68116412843977, 36.505126680646626, 39.102283409663606, 42.232947145189556, 40.1423453603472, 37.95653935841152, 40.01090281350272, 38.57402924128941, 34.771617140088765, 31.162757532937185, 35.48536736624581, 36.59087092535836, 35.444751671382356, 35.260151931217735, 34.547179903302876, 35.92831155232021, 34.43914236341204, 35.38385418483189, 36.884887422834126, 37.61148139408657, 36.15299545015608, 34.52567522866385, 34.902938093457905, 35.21109764916556, 37.053061621529714, 36.49519770486014, 38.480513436453684, 37.30276598249163, 37.860167843954905, 36.60161631447928, 41.92127180099487, 46.320197173527305, 48.72829689298357, 46.93926429748535, 44.405565466199604, 46.673005853380474, 45.12336996623448, 47.54393822806222, 45.85262162344796, 49.0593855040414, 46.61412334442139, 47.015774386269705, 37.949170793805806, 36.520148686000276, 37.69174698420933, 36.432563168661936, 37.852142674582346, 42.47653709139143, 48.608117376055034, 53.649299485342844, 56.71120037351336, 32.38874980381557, 0.11558799259364605, 2.8514403871127536, 8.19713989325932, 2.378553156341825, 0.26664729895336287, 5.692460213388715, 61.38782092503139, 52.691201959337505, 58.5298045022147, 54.05605745315552, 36.93626240321568, 22.894010373524257, 34.71459674835205, 49.16107586451939, 21.009099585669382, 0.05382361648870366, 0.021103919982644062, 0.018298279460785643, 0.013299182888918688, 0.03475617178316627, 0.040337142667600086, 0.04653073228629572, 0.054349084185170274, 0.023065164385895644, 0.13468830553548677, 0.17109484411776066, 0.12200419258858476, 0.09266163102750267, 0.17911121967647756, 0.14760835867907318, 0.12815146201423236, 0.09230335775230612, 0.16039887948759965, 0.11123025071408067, 0.2608671576849052, 0.21741490145879133, 30.565514700753347, 69.93475137438092, 52.183834075927734, 47.79494537625994, 78.52695628574916, 54.32290302004133, 49.11783027648926, 62.293998037065776, 59.457590511866975, 52.25321183885847, 59.11983857836042, 18.573488473892212, 1.8921336574213845, 3.2000521378857747, 5.161463677883148, 4.543016246386936, 0.29229551553726196, 39.2572386605399, 57.37778970173427, 51.642197677067344, 47.87088918685913, 41.61280305044991, 39.99420976638794, 39.33272736413138, 38.46438666752407, 43.306475094386506, 40.395798274448936, 40.88758134841919, 36.70690931592669, 37.237970556531636, 36.579524517059326, 42.6833085332598, 46.22513539450509, 47.195329734257285, 44.72671120507376, 45.03114652633667, 41.949769837515696, 43.18482950755528, 42.516881806509836, 43.336227280753, 43.75930309295654, 41.33041088921683, 41.42570890699114, 41.67168208530971, 40.66385282788958, 43.56070620673043, 39.258840220315115, 38.27824790137154, 37.39095599310738, 37.65383761269705, 37.60235146113804, 39.4875054359436, 36.97446012496948, 38.165742669786724, 37.017622334616526, 39.068643706185476, 39.9867057119097, 39.25448022569929, 36.427306856427876, 39.608219964163645, 44.49207401275635, 43.105428968157085, 40.86602108819144, 43.293627875191824, 44.97019345419747, 41.56447832924979, 39.24836581093924, 38.069530963897705, 38.52397094454084, 37.36402130126953, 38.8597982270377, 35.5823711667742, 37.09200627463204, 37.852062770298545, 37.53231709344046, 38.06873539515904, 37.86002540588379, 42.17584337506975, 38.820811884743826, 39.65954630715506, 39.3633063861302, 35.103852203914094, 37.46514885766165, 37.18320138113839, 37.38978522164481, 38.278240953172954, 37.33405719484602, 38.07558631896973, 37.78455754688808, 38.39512702396938, 40.41076816831316, 44.436015946524485, 41.55805819375174, 41.93088115964617, 43.86223370688302, 41.6708448273795, 36.59781912394932, 34.519463539123535, 37.20751312800816, 39.426468985421316, 36.752520765577046, 37.326549666268484, 36.12150968824114, 38.000980036599294, 36.24427393504551, 37.49400820050921, 39.94367551803589, 39.80830723898751, 39.88516126360212, 36.26258243833269, 38.560931886945454, 36.470121656145366, 39.40862601143973, 38.27691732134138, 41.235838958195274, 38.787401471819194, 39.73177630560738, 38.73035676138741, 44.22426264626639, 48.47837366376604, 50.094368321555, 50.67498411451067, 45.506886209760395, 46.82734618868147, 45.515630517687114, 48.61733763558524, 47.947166510990684, 51.643913882119314, 48.41465173448835, 49.314558097294395, 40.925539357321604, 38.22719253812517, 38.41295610155378, 38.30745118004935, 39.44190093449184, 44.580892835344585, 51.081672600337434, 56.13755709784371, 55.98297010149275, 35.6937438419887, 0.14278003919337476, 5.67327971117837, 16.61889246531895, 7.927170242582049, 1.0216910221746989, 7.707258888653346, 66.32358496529716, 55.499764578683035, 63.60893072400774, 59.316486494881765, 45.04578290666853, 34.59962490626744, 42.4719478062221, 57.407913616725374, 27.807717357363018, 0.1360615925597293, 0.09010574567530837, 0.14395946876278945, 0.09532526095530816, 0.15875310637056828, 0.139931997018201, 0.159586618787476, 0.2269512361713818, 0.11663331650197506], [0.029405332835657255, 0.037061803242457766, 0.01828372149196054, 0.020091966426532184, 0.060681488497981, 0.08508942449199301, 0.020060668998797025, 0.041180425988776345, 0.04443962306582502, 0.032224618696740696, 0.1303295458533934, 0.030402721637593846, 16.268856116703578, 59.711262294224326, 38.266057286943706, 48.39960541043963, 82.14416762760708, 62.934135573250906, 33.35926376070295, 41.816218512398855, 49.99359164919172, 45.49148900168282, 47.322224685123985, 27.312847546168737, 0.37527690136006897, 1.5524296058075768, 1.8603195931230272, 1.3008092790842056, 0.0934055700365986, 33.987818649836946, 54.70296948296683, 44.7385196685791, 44.65052420752389, 35.656376429966514, 35.22364609582083, 38.44984756197248, 42.156867844717844, 41.61878544943673, 43.09589603969029, 38.12972320829119, 34.05940593991961, 32.66963768005371, 39.53664657047817, 43.2267792565482, 44.28164087023054, 43.918152809143066, 42.28450972693307, 41.159572056361604, 42.32255458831787, 39.638104166303364, 40.86817502975464, 40.48750407355172, 39.72245877129691, 39.67678478785923, 38.061974797930034, 38.96316657747541, 39.678476674216135, 36.994964259011404, 36.53279788153512, 34.11310856682913, 34.2655485698155, 34.35579524721418, 34.28167881284441, 34.858851773398264, 33.258455821446006, 34.26152556283133, 33.66852113178798, 36.60476732254028, 36.32080486842564, 33.653224672589985, 33.06687661579677, 37.26328979219709, 38.61997420447213, 37.41735567365374, 39.1870653288705, 39.855287483760286, 39.15348815917969, 36.76859194891793, 36.2376001902989, 32.892132895333425, 34.040367875780376, 33.74881451470511, 32.081100940704346, 31.7408059665135, 32.36899607522147, 32.84950917107718, 35.93129580361502, 35.93089280809675, 36.23807961600167, 34.22350154604231, 41.775401319776265, 32.936524936131065, 33.92170306614467, 31.46950660433088, 32.850388118198936, 32.88680362701416, 33.278848784310476, 34.66195024762835, 35.69988604954311, 33.90560409000942, 35.769948210035054, 36.97687809807913, 37.77983277184622, 40.171642439705984, 36.93004029137747, 35.25127560751778, 33.309577192579, 36.90230655670166, 33.231066022600444, 30.06042582648141, 34.044766085488455, 35.086273261478965, 36.06603527069092, 34.384421825408936, 33.15344769614083, 32.48293610981533, 34.91174840927124, 33.93498454775129, 33.318286759512766, 34.39115115574428, 33.88665982655117, 33.393445423671174, 32.6453606741769, 32.52018192836216, 33.15991299492972, 35.59880018234253, 37.126670837402344, 37.64689636230469, 36.9915839603969, 40.93169546127319, 44.9840863772801, 46.52769122804914, 46.65479115077427, 43.10911498750959, 45.96920197350638, 45.328710079193115, 47.36420917510986, 47.54425089699881, 48.219730445316856, 47.57838044847761, 46.669069698878694, 47.31543282100132, 44.59329884392874, 38.74073389598301, 33.59460619517735, 36.58026450020926, 35.540664604731965, 41.63479062489101, 47.07133218220302, 50.872285161699565, 50.42030831745693, 32.54947900772095, 0.05874233040958643, 3.241365909576416, 6.425171204975673, 0.8376056658370155, 0.16767493262887, 14.798952545438494, 56.99955756323678, 46.887326513017925, 54.92081635338919, 42.59126227242606, 29.451791422707693, 21.636212723595754, 38.91810056141445, 44.47633286884853, 10.583690643310547, 0.22801925029073442, 0.09072279185056686, 0.05479302589914628, 0.036377459964049716, 0.04014313932774322, 0.004267934377172163, 0.036537312636418004, 0.0347054004003959, 0.011759720094102834, 0.033155409286596944, 0.021029347287757055, 0.030495219531336, 0.044140392515276156, 0.03778431411566479, 0.031731805498046536, 0.013473066817303854, 0.01631288429988282, 0.03584841299535973, 0.03875404243756618, 0.03395778712417398, 0.011951411325883652, 21.233394384384155, 65.67305292401994, 45.035909516470774, 53.031114782605854, 75.96830994742257, 59.54967498779297, 36.32820469992501, 48.95981434413365, 54.411245891026084, 49.917276109967915, 53.03617654527937, 28.153301647731237, 0.48332005952085766, 0.9444630976234163, 2.503915160894394, 3.0712470838001797, 0.09378472183431898, 35.22038391658238, 57.7416911806379, 46.8718250819615, 45.59338433401925, 37.06581504004342, 35.990953036717, 38.87075553621565, 43.74362448283604, 43.422204290117534, 44.679748330797466, 40.135077544621055, 35.802809715270996, 34.405558245522634, 40.5456292288644, 44.88546364648001, 46.031669752938406, 44.22573219026838, 44.58330038615635, 41.8724433353969, 42.340960366385325, 42.997287205287385, 41.95232330049787, 42.770140171051025, 42.316193512507844, 40.749336515154155, 38.13784565244402, 40.52758475712368, 40.87137120110648, 40.36523314884731, 38.51015445164272, 36.9266391481672, 35.84533963884626, 35.681178024836946, 35.96429974692208, 35.902151584625244, 35.48834466934204, 36.062439577920095, 35.05921697616577, 37.53663192476545, 38.75014523097447, 35.866410051073345, 34.490416594914024, 38.470264843532014, 40.42396627153669, 38.84868458339146, 40.71444613592965, 40.44603375026158, 41.170953205653596, 38.75305652618408, 38.42049142292568, 34.85523523603167, 35.581961223057334, 35.51964282989502, 33.95009340558733, 33.75133671079363, 34.2137428011213, 35.63761976787022, 36.42360346657889, 38.46387250082833, 35.82612092154366, 38.68995993477957, 41.1498932157244, 35.66537434714181, 35.82727084841047, 35.118877683367046, 34.79316350391933, 34.91990212031773, 34.91433661324637, 35.491572107587544, 36.72570071901594, 35.4033716746739, 37.511458601270405, 38.40129007611956, 38.039876052311485, 41.4696249961853, 38.611302852630615, 37.1072540964399, 36.678935868399485, 41.67998170852661, 34.95856189727783, 32.5040933745248, 36.03126648494175, 35.982097557612825, 36.711547238486155, 36.6995963369097, 34.41331243515015, 34.57944386345999, 36.259427956172395, 35.9229371207101, 36.120484828948975, 35.905247007097515, 34.851545742579866, 33.548956530434744, 34.285250186920166, 36.1162360055106, 35.796625818525044, 38.18765728814261, 38.843577657427105, 39.526703698294504, 38.65778282710484, 42.335401807512554, 46.120328766959055, 47.77485466003418, 49.1063414301191, 45.98631191253662, 47.47459173202515, 45.32613229751587, 48.66240017754691, 49.259427615574424, 48.332298210689, 50.480896609170095, 49.67039966583252, 48.45118188858032, 46.43459578922817, 40.07959965297154, 35.711114338466096, 38.49746356691633, 36.410318510872976, 44.78054584775652, 48.41464131219046, 52.94436304909842, 53.113315446036204, 34.48076902117048, 0.04781275974320514, 2.6996576402868544, 8.04057787145887, 1.360230056302888, 0.44857168410505566, 16.80313958440508, 62.02090603964669, 52.70860024860927, 59.005318369184224, 49.981022357940674, 32.538250718797954, 22.220549276896886, 40.91765662602016, 51.436506680079866, 14.191481964928762, 0.1216507436973708, 0.031004117402647222, 0.09742863808891603, 0.04978966812736221, 0.06214833193059478, 0.0812359901943377, 0.030876902264675925, 0.01997753149563713, 0.09767024405300617, 0.15772853206310952, 0.132486472970673, 0.12665833213499614, 0.09029295348695346, 0.1383295687181609, 0.180716497823596, 0.17414502187498979, 0.1098567262025816, 0.09164084294544798, 0.15282076969742775, 0.33850073761173655, 0.06949937676212617, 21.91634498323713, 72.97242736816406, 51.2024427141462, 59.154037611825125, 81.00127928597587, 67.77885041918073, 42.604783466884065, 51.98287827627999, 56.825883865356445, 55.73192126410348, 57.17046587807791, 33.832307543073384, 0.8046926462224552, 4.02189700944083, 6.666553795337677, 4.419937593596322, 0.531572693160602, 38.261992590767996, 60.58121149880545, 49.972687993730815, 48.02918652125767, 39.91940893445696, 37.40971612930298, 42.05929776600429, 46.37782553264073, 45.750257287706646, 46.93500852584839, 42.65480007444109, 37.78333466393607, 36.77127047947475, 43.31259993144444, 47.853355407714844, 50.04773548671177, 46.425955704280305, 46.982426507132395, 44.28737660816738, 45.302539689200266, 44.95017221995762, 45.56286089760916, 45.598623275756836, 44.017202854156494, 42.78142751966204, 40.6443144934518, 43.55336543491909, 43.8132905960083, 41.73805475234985, 40.20526477268764, 38.11026477813721, 38.38864435468401, 36.50970901761736, 37.33086449759347, 37.82527051653181, 37.1675192969186, 37.59273515428816, 36.29111521584647, 40.55434921809605, 40.35834053584507, 37.20901393890381, 36.82494183949062, 41.716702938079834, 43.103045736040386, 41.60604592732021, 43.814047949654714, 43.362460204533164, 42.4506585257394, 40.26091636930193, 39.66830798557827, 35.581551279340474, 37.65544959477016, 37.574124404362266, 34.758026463644846, 34.482419218335835, 36.26201268604824, 37.07981218610491, 38.6032429422651, 39.48680714198521, 39.10005303791591, 40.29335750852312, 42.96325840268816, 36.41194091524397, 38.93933425630842, 35.837502070835654, 36.730720792497905, 35.92819690704346, 38.02788693564278, 37.89560713086809, 38.56265156609671, 37.14134543282645, 38.16680921827044, 40.099954400743755, 41.128913130079, 42.840094634464805, 41.056901999882285, 39.430172375270296, 38.88881737845284, 43.776506832667756, 37.2848813193185, 34.43240261077881, 37.52946138381958, 38.98259721483503, 38.68130595343453, 39.255546774183, 36.184800829206196, 35.24156549998692, 37.63564028058733, 38.00495440619332, 35.622222559792654, 37.581611088344026, 37.849328654153005, 37.76126371111189, 37.124596800122944, 37.610904693603516, 37.83866316931588, 40.80399799346924, 41.59620380401611, 41.63996008464268, 41.145991802215576, 44.33374541146414, 48.30926840645926, 50.18281888961792, 51.92652143750872, 48.33719669069563, 47.409094538007466, 49.14650549207415, 50.13833999633789, 51.09932449885777, 50.74312857219151, 51.19465725762503, 51.046347958701, 50.43671996252877, 48.322546413966585, 42.928138732910156, 36.96547957829067, 40.665138244628906, 37.626854283469065, 47.38926090512957, 49.63107981000628, 56.51690789631435, 50.953071866716655, 39.3299446105957, 0.1952110914779561, 6.032384327479771, 17.648533855165752, 6.491381457873753, 0.6207054331898689, 18.502054044178553, 66.44890962328229, 55.39171314239502, 63.65929821559361, 53.03767040797642, 41.62528896331787, 29.578001976013184, 47.70980562482561, 58.59219932556152, 18.501732689993723, 0.29116040787526537, 0.24243662665997232, 0.13507838174700737, 0.13093454124672071, 0.17032172131751264, 0.15337311077330792, 0.12210617640188762, 0.13207598642579146, 0.1275741644203663], [0.1087632602346795, 0.05246673983388713, 0.010525090004583555, 0.028382821274655204, 0.06333447899669409, 0.038707393155034096, 0.02300820985276784, 0.04534953852583255, 0.02507254577774022, 0.05779269350958722, 0.05383389290156109, 0.05972934101841279, 5.871150076389313, 47.168026787894114, 38.42916972296578, 35.91909129279, 71.52171298435756, 66.79827894483293, 39.4681408064706, 43.71600191933768, 50.663985116141184, 46.072299344199045, 45.9246883392334, 35.32542678288051, 0.100502388152693, 0.7262444985764367, 1.2171037878308977, 3.0144092994076863, 0.11603796987661294, 29.591634341648646, 57.31809772763933, 46.474228313991, 45.40279524666922, 38.29898827416556, 37.337868281773154, 42.024973664964946, 44.21567119870867, 44.36884076254708, 43.42685610907418, 37.28689282281058, 32.53195912497384, 37.800003392355784, 43.836421149117605, 45.12739297321865, 46.87124490737915, 42.182920115334646, 44.364796910967144, 42.76200383050101, 42.263116223471506, 43.78060279573713, 43.323651041303364, 42.94236516952515, 43.51932621002197, 43.5029354095459, 42.58974756513323, 39.958502973829, 40.21309539249965, 39.47233057022095, 39.13769142968314, 35.40630381447928, 33.73317411967686, 34.43879842758179, 34.33471441268921, 35.08333069937569, 34.23335756574358, 35.01317473820278, 34.364834853581016, 34.69905015400478, 36.70047875813076, 33.798838070460725, 33.97137573787144, 35.88851921898978, 39.03003256661551, 36.34477267946516, 37.504024028778076, 37.67976481573922, 39.52284744807652, 37.0539996283395, 36.11066355024065, 34.064763001033235, 33.79903609412057, 33.797802788870676, 34.66830090114048, 32.39153950554984, 33.35708897454398, 33.14668015071324, 36.844271727970664, 37.2366886138916, 37.848890917641775, 36.68920530591692, 41.238652978624614, 39.59066881452288, 35.30094827924456, 34.83742700304304, 33.959212916237966, 33.97298771994454, 32.69928911754063, 34.33860887799944, 33.45163311277117, 34.84974615914481, 34.318170751844136, 36.84637703214373, 36.686738695417134, 40.93275506155831, 37.15033292770386, 35.928134373256135, 33.658873558044434, 37.733495235443115, 35.65944058554513, 30.753803934369767, 32.48476696014404, 35.6281042098999, 34.49118784495762, 33.28394876207624, 31.940386022840226, 34.267025062016074, 34.38218797956194, 34.30403464181082, 33.32712834221976, 32.00729022707258, 32.88148478099278, 32.707199641636436, 31.230895042419434, 31.312109061649867, 34.08891841343471, 38.3733583177839, 38.62725591659546, 42.008183343069895, 42.16934333528791, 44.65341118403843, 46.31619153703962, 47.84496545791626, 42.43462903159005, 43.170662130628315, 45.960016454969136, 46.81157030378069, 47.9566091128758, 46.40501730782645, 47.39534057889666, 47.31803492137364, 47.451256207057405, 49.64099488939558, 45.90962464468819, 44.34567894254412, 34.70396253040859, 35.420474665505544, 36.70576981135777, 44.421171120234895, 48.855125835963655, 52.68492078781128, 49.848339557647705, 30.49346535546439, 0.07299852078514439, 0.9101774830903325, 5.0388210245541165, 1.6270194947719574, 0.12933142084096158, 23.918214797973633, 58.085158007485525, 46.08507708140782, 54.33224834714617, 36.09066663469587, 26.98631521633693, 24.416921751839773, 35.79986367906843, 41.35978787285941, 4.076047360897064, 0.12943184402372154, 0.08695225417613983, 0.04317383295191186, 0.013785400727231587, 0.049488164484500885, 0.05154932316924844, 0.022653307200276425, 0.052352929155209234, 0.029082709790340493, 0.04767541068473032, 0.06960188304739338, 0.027437762789694325, 0.004112023993262223, 0.025068416892151748, 0.06579177999602896, 0.027964589252535785, 0.00330219605322262, 0.09122251932110105, 0.0523149447648653, 0.07980989278959376, 0.024203332240826318, 8.651814375604902, 57.63465418134417, 41.89764445168631, 44.7054705619812, 79.27267169952393, 69.8280200958252, 41.78402403422764, 46.46129771641323, 54.778454712459016, 51.46659585407802, 50.636223588671, 37.61638682229178, 0.07009905244090728, 0.6287047096661159, 3.9118549142565047, 4.419038670403617, 0.062354660859065394, 32.35463762283325, 57.011998312813894, 49.066351073128835, 47.56674568993704, 39.59401437214443, 39.08271380833217, 43.424931458064485, 46.59797920499529, 46.75916699000767, 45.356304849897114, 39.21191208703177, 35.402374608176096, 40.19025318963187, 46.48042958123343, 47.182211535317556, 46.45252561569214, 46.313158648354666, 46.60846751076834, 44.585628032684326, 44.257634844098774, 46.26706429890224, 45.29499394553048, 44.7687999180385, 44.88129472732544, 44.17929737908499, 43.90031678336007, 40.72977386202131, 42.16398974827358, 40.42616190229143, 40.664888109479634, 35.83294057846069, 35.58384418487549, 35.148195607321604, 35.60444906779698, 36.30816262108939, 35.94331966127668, 35.19359513691494, 35.96917738233294, 36.246618952069966, 38.17323977606637, 35.06013413837978, 35.95599317550659, 39.347172669001985, 40.44188220160348, 38.80885056086949, 38.82374055044991, 41.160774094717844, 42.298169885362896, 37.9345691544669, 37.11305931636265, 34.922257559640066, 35.037146023341585, 34.378957067217144, 36.26741491045271, 34.86964232581002, 35.383326121738975, 35.50456176485334, 36.406441416059224, 38.248460974012104, 40.81096703665597, 36.95149285452706, 42.26043421881539, 40.82311248779297, 37.04944508416312, 35.92085613523211, 36.198586055210654, 34.9718016896929, 34.38155916758946, 36.27723271506173, 35.34387425013951, 35.831321648189, 36.381684984479634, 37.009114265441895, 38.581710474831716, 42.22198288781302, 38.905611174447195, 36.78420107705252, 36.053031717027935, 40.28412682669503, 37.36045340129307, 32.8664037159511, 33.926351411002024, 38.76501785005842, 37.38248266492571, 36.52030849456787, 34.35504136766706, 34.946277482169016, 35.57269580023629, 36.249189785548616, 34.83958441870553, 33.9485057422093, 35.90201609475272, 34.47295229775565, 32.54117938450405, 34.760305472782676, 36.0665841783796, 40.47077628544399, 40.569454601832796, 43.07621874128069, 43.417660168239046, 47.84111615589687, 48.58048786435808, 49.33209882463728, 45.59576061793736, 46.19048820223127, 48.6713980947222, 48.46012422016689, 49.40201507295881, 50.27188784735543, 48.046921798161094, 49.063297339848106, 48.679979119982036, 51.54378686632429, 47.28830705370222, 46.167090143476216, 36.84006111962454, 38.3801988192967, 37.775966099330354, 46.79590559005737, 50.27211018971035, 55.01706974846976, 50.145531381879536, 31.842701298849924, 0.23900883059416497, 3.077396239553179, 8.831589460372925, 2.616363286972046, 0.1898320729711226, 25.793856688908168, 63.31548745291573, 51.82927097593035, 59.42706707545689, 42.07616451808384, 34.75384712219238, 23.749983276639664, 40.408249446323936, 48.133788176945274, 5.621819615364075, 0.15171102567442826, 0.04664991356964622, 0.08992712133164917, 0.03484056457611067, 0.11336870810815267, 0.054175443681223054, 0.045075810713959594, 0.052529850375971625, 0.06754452415875026, 0.13432420364448003, 0.1592116874775716, 0.07641325505184275, 0.1255272685417107, 0.1229946365846055, 0.2568265087902546, 0.10615235247782298, 0.13241556606122426, 0.23608011060527392, 0.12069440287138734, 0.14579027837940625, 0.14346409748707498, 9.302761571747915, 62.9820225579398, 48.62398011343819, 47.61839165006365, 76.06308337620327, 72.97891698564801, 49.094057015010286, 54.35488905225481, 58.77771622794015, 55.39991896493094, 55.8103803225926, 42.12355123247419, 0.33106136109147755, 1.541893639734813, 7.629748259271894, 7.7581778935023715, 0.1375997228814023, 35.119777475084575, 59.05199636731829, 52.53227233886719, 49.67016690117972, 42.42340769086565, 41.58995042528425, 45.68125125340053, 47.99322959354946, 49.47691665376936, 47.44040659495762, 41.34002719606672, 37.08772965839931, 43.17996229444231, 47.99039125442505, 49.701138496398926, 49.22899797984532, 48.00774785450527, 47.97150257655552, 47.374322278159006, 46.0722576550075, 48.66208403451102, 46.89000504357474, 47.459729535239084, 47.824826104300364, 46.55325017656599, 46.95771523884365, 42.70104381016323, 43.86382484436035, 44.08287027903965, 43.962277344294954, 38.51443454197475, 37.30820989608765, 36.048376423971995, 36.4876206942967, 38.52127504348755, 37.63140187944685, 38.04996483666556, 37.4872510773795, 38.08544928686959, 39.11442886080061, 37.77320419039045, 37.36872523171561, 42.19404765537807, 41.816020488739014, 40.714084829602925, 40.304978370666504, 41.043884549822124, 43.21842057364327, 40.95208147593907, 39.611461298806326, 37.90327794211251, 36.35234274183001, 37.22350093296596, 38.49129704066685, 35.51622779028756, 37.64275523594448, 37.71071556636265, 40.017983027866904, 40.569916657039094, 42.6365019934518, 41.3129118510655, 45.534237793513704, 40.317995820726665, 39.74687474114554, 36.82799904687064, 37.284891741616384, 36.70645768301827, 36.8716059412275, 37.96096188681466, 37.5320600100926, 38.12294176646641, 38.12447384425572, 38.51948240825108, 39.84583445957729, 44.70258705956595, 40.59401648385184, 38.64884744371687, 37.74630076544625, 42.07666826248169, 38.953143801007954, 35.933991704668315, 35.116553510938374, 41.19645309448242, 38.48046827316284, 37.40052713666643, 35.83005360194615, 37.5300624029977, 38.89948633738926, 38.09350572313581, 37.422205516270225, 35.32931777409145, 37.663735321589876, 36.70649242401123, 34.157187938690186, 35.5848343031747, 38.61935581479754, 44.92096546718052, 43.21583236966814, 45.34500707898821, 44.59868369783674, 49.09378603526524, 50.269973618643625, 51.46102339880807, 47.8858208656311, 46.683372565678184, 50.34342302594866, 51.59292452675955, 51.97889348438808, 50.608090332576204, 50.436855452401296, 50.53306368419102, 49.96741083690098, 54.26462153026036, 49.50397293908255, 50.02067225319998, 38.85900960649763, 41.2299781526838, 38.90819590432303, 50.31984083993094, 52.75036934443882, 57.52629355021885, 49.82444470269339, 35.703353200639995, 0.5310367047786713, 3.9679312195096696, 17.505242892674037, 5.306961561952319, 0.28480799017207964, 29.575910568237305, 68.73965426853725, 56.4123409816197, 64.1525160925729, 45.206178597041536, 36.68083272661482, 32.34701892307827, 46.948237895965576, 55.308633531842915, 7.414607712200709, 0.452323385647365, 0.31314684237752644, 0.13940724517617906, 0.2865005007811955, 0.22243721410632133, 0.1203774455934763, 0.123865400574037, 0.21978902763554028, 0.11668077324117933], [0.038463778727288754, 0.01001291735363858, 0.02181357770626034, 0.06457211330000844, 0.02523729408026806, 0.05971121056271451, 0.056590743362903595, 0.007886508196991469, 0.027165819524920413, 0.03500239517805832, 0.0442782776164157, 0.041890506100441725, 1.1439143951450075, 36.470823424203054, 46.19305903570992, 26.064784322466167, 22.93329201425825, 36.61704478945051, 34.587291853768484, 51.19297579356602, 45.71079499380929, 51.64869771684919, 43.02454498835972, 45.34928716932024, 2.0583380418164388, 0.12211940783475127, 1.7288716179983956, 3.078664937189647, 1.0545656638486045, 14.403159703527178, 66.4300730569022, 43.31423623221261, 49.35847766058785, 36.337626457214355, 45.659413065229145, 44.08242212023054, 48.87378174918038, 46.206663608551025, 43.53732204437256, 34.12768241337368, 35.33184691837856, 44.06999179295131, 47.33754893711635, 45.829275676182334, 45.62707267488752, 44.21835667746407, 44.922778947012766, 46.052222524370464, 45.422840799604145, 44.053236212049214, 44.70252105167934, 45.18267631530762, 45.30295658111572, 44.01505238669259, 44.76647227151053, 44.652125767299104, 45.01251145771572, 40.96720770427159, 40.4815286227635, 36.12722110748291, 35.24483115332467, 33.59588466371809, 35.118749141693115, 34.70086363383702, 34.71612535204206, 33.60529599870954, 32.97827666146414, 35.39166396004813, 35.91994939531599, 32.71544715336391, 33.856198923928396, 37.07273197174072, 36.930995668683735, 37.46546152659825, 36.29669809341431, 37.395976066589355, 38.30941752025059, 36.692936488560264, 35.13874953133719, 34.09246894291469, 33.3367828641619, 32.89615242821829, 34.249001434871126, 33.391955035073416, 35.18302345275879, 35.96318456104824, 37.36199590138027, 37.71380751473563, 40.182287079947336, 37.63177360807146, 36.67030273165022, 42.20381334849766, 35.32924829210554, 36.29751798084804, 33.89880180358887, 34.15500967843192, 34.66647352491106, 32.58759682519095, 33.43105949674334, 33.589773723057334, 33.58393028804234, 35.66847671781267, 37.549770968300955, 38.64240993772234, 39.27344880785261, 34.68136004039219, 36.20034047535488, 37.50021989004952, 36.538912296295166, 30.407356330326625, 32.2564491544451, 34.62049034663609, 34.84826271874564, 32.68718188149588, 32.234253134046284, 33.40035193307059, 34.06466225215367, 32.455765179225374, 33.35916648592268, 31.84753029687064, 32.99400390897478, 30.298047270093644, 31.070023400442942, 32.556593963078086, 32.159375871930806, 37.38784320013863, 38.70074701309204, 42.25942325592041, 44.0075170653207, 44.57954141071865, 46.16446372440883, 44.95869765962873, 40.81239489146641, 44.78773028509957, 48.176887852805, 46.327847140175955, 45.791394097464426, 45.020234380449565, 49.44081728799002, 47.570956298283164, 45.455810001918245, 48.71655791146414, 49.37555980682373, 46.63919939313616, 40.97852284567696, 33.43068429401943, 38.04538597379412, 43.60875299998692, 51.06391647883824, 49.542094230651855, 53.1983996118818, 21.799375534057617, 0.035311908926814795, 2.672231580529894, 3.899521427495139, 0.5716805181332997, 0.10326429709259953, 32.85613080433437, 52.43800960268293, 47.69032287597656, 52.493473597935264, 33.310661111559185, 18.982624462672643, 23.2759267943246, 40.646770681653706, 29.48009490966797, 0.49483653583696907, 0.034828035426991324, 0.08334235288202763, 0.004199824728337782, 0.024914033212033764, 0.05875286127307585, 0.02770797748650823, 0.028725603595376015, 0.009441273652815392, 0.0570594889244863, 0.007724646212799209, 0.028676959419889108, 0.11222542409918138, 0.04533755899007831, 0.060024463039423735, 0.04298947498734508, 0.0024543915684002316, 0.011333589924366345, 0.0333213552034327, 0.05146720686129161, 0.02456879798722054, 0.009116443672350474, 2.044570620570864, 45.801726068769185, 50.086155550820486, 29.651652881077357, 39.141558102199006, 57.002076285226, 41.9287098475865, 55.73632642201015, 50.201853479657856, 57.261904171534944, 47.5809999193464, 49.59247561863491, 1.889285113130297, 0.08946668103869472, 3.469376257487706, 6.32213636807033, 0.7361337393522263, 15.651909930365425, 66.8145238331386, 45.193505082811626, 51.29406860896519, 37.48828635896955, 46.866745948791504, 45.977473803928916, 51.43489817210606, 47.62184490476336, 45.34130368913923, 36.277719088963096, 36.932545116969514, 46.111212730407715, 47.4134441103254, 46.51337793895176, 47.81920848573957, 46.059229782649446, 47.18427167619978, 46.351564816066194, 47.193262645176475, 46.43143435886928, 46.540392535073416, 47.00201347896031, 47.18936817986624, 46.94686215264456, 46.58576774597168, 45.58872904096331, 45.406759193965364, 42.36797496250698, 42.816703523908345, 36.23530381066458, 36.8167325428554, 34.910793031964985, 36.95780529294695, 34.778871059417725, 35.50068467003958, 34.703253814152305, 35.10086795261928, 35.68775796890259, 37.706070695604595, 34.28454841886248, 36.94886296136038, 39.2320236478533, 39.68322229385376, 37.253617899758474, 37.68743910108294, 40.475195339747835, 39.92700678961617, 36.885092394692556, 37.031032357897075, 35.55661072049822, 35.13294431141445, 34.45629399163382, 37.506622655051096, 35.29866927010672, 37.95356205531529, 37.359522342681885, 39.01862015042986, 39.670833655766074, 42.40155908039638, 37.583900519779746, 40.35936886923653, 43.10856260572161, 37.74345200402396, 37.692368847983225, 33.75823974609375, 35.64260857445853, 35.16316897528512, 34.167478220803396, 35.10296630859375, 35.803785937173025, 35.868331227983745, 37.12657356262207, 38.88083042417254, 41.570915835244314, 39.65047543389456, 36.7040570804051, 36.69425664629255, 40.38939550944737, 38.816806248256135, 32.17218835013253, 34.87443310873849, 36.170796734946116, 34.907826151166645, 33.93199682235718, 35.270365783146445, 34.690660204206196, 35.2765531539917, 35.62350102833339, 34.62227603367397, 34.3395607812064, 35.27566378457205, 33.0138201713562, 33.25194188526699, 33.63899476187569, 34.00335134778704, 39.25714485985892, 42.39809192929949, 43.687382289341514, 44.869809355054585, 46.95035014833723, 47.286966051374165, 45.41479478563581, 43.94118956157139, 46.289308956691194, 50.17878546033587, 47.716729504721506, 47.986663545881, 47.55193560464041, 49.860755988529746, 48.26730128696987, 47.384046282087056, 47.79733555657523, 51.02257817132132, 48.375474316733225, 42.27627263750349, 34.70295851571219, 39.724345207214355, 45.3940544128418, 52.9597498348781, 51.28596700940813, 52.98395388466971, 24.845493589128765, 0.4782612824014255, 3.7041884575571333, 6.988338334219796, 2.0773704605443135, 0.12170915199177605, 36.460123198372976, 57.608153751918245, 52.971183095659526, 56.63943590436663, 41.15174143654959, 23.782318455832346, 24.62450439589364, 47.428678035736084, 36.45040961674282, 0.9538584734712328, 0.10671566546495471, 0.02035647803651435, 0.05967815233660596, 0.03618696465023926, 0.014500071128298129, 0.02221833571924695, 0.02610673662275076, 0.06608102590377841, 0.051965275313705206, 0.20128900105399744, 0.22442017841551984, 0.24101249022143229, 0.12809242946760996, 0.08707816991955042, 0.14270742237567902, 0.1464516736034836, 0.1280758867838553, 0.078434705867299, 0.1334783961730344, 0.12277986668050289, 0.07371343206614256, 1.995767559323992, 55.08074304035732, 57.409827845437185, 37.82321037564959, 34.88032865524292, 45.61147744315011, 45.19947705950056, 61.5826484135219, 54.40583324432373, 61.947234289986746, 51.64486231122698, 53.86432191303798, 3.170346200466156, 0.9916888092245374, 6.221450022288731, 8.889215213911873, 1.42070272564888, 16.206200735909597, 70.31554044995988, 47.31073931285313, 53.42995180402483, 39.00310134887695, 49.377029350825715, 47.43983336857387, 53.74833563395909, 49.79730156489781, 46.37866973876953, 38.0210360118321, 39.63151032584054, 48.346542017800466, 50.85013083049229, 48.79743146896362, 49.82349279948643, 47.53556217466082, 48.81280435834612, 50.01361288343157, 49.32453571047102, 48.51800618852888, 48.83977379117693, 49.89835616520473, 49.465886388506206, 49.12102992194039, 49.10862391335623, 49.98467016220093, 48.85976723262242, 45.3831353187561, 46.32269157682146, 38.06888825552804, 38.14077779224941, 37.23608412061419, 39.567527839115684, 37.451120444706504, 37.7281277520316, 36.38379723685128, 35.327750955309185, 37.7654013633728, 38.823511259896414, 36.56119516917637, 38.42174557277134, 41.717449869428364, 41.67682375226702, 41.18259143829346, 39.41306938443865, 41.82838133403233, 40.0509626524789, 39.70704071862357, 38.589864185878206, 37.302592277526855, 37.01335961478097, 36.164508615221294, 38.485238211495535, 37.29137441090175, 38.585875919886995, 40.19648224966866, 40.23086888449532, 42.61568866457258, 44.58366169248308, 39.72481421061924, 42.3657272202628, 43.59940072468349, 39.89342614582607, 39.69286291939871, 35.45139067513602, 37.79697397777012, 38.896804332733154, 35.76162426812308, 37.00808245795113, 37.73792123794556, 38.09190763745989, 37.91502039773123, 40.92648778642927, 42.6771593775068, 42.582858426230295, 38.58603572845459, 38.89368806566511, 41.43589496612549, 41.47843531199864, 34.03954798834664, 36.71526452473232, 38.32420328685215, 38.46432760783604, 35.603813307625906, 38.08860029493059, 35.74387856892177, 36.87722355978829, 36.713690757751465, 37.348985399518696, 35.66759082249233, 36.82694639478411, 35.08482108797346, 35.285731724330354, 35.66942514692034, 35.76439312526158, 41.74215766361782, 44.66521617344448, 45.774377959115164, 46.344227518354145, 49.35443728310721, 48.850546973092214, 47.95135280064174, 43.19708612986973, 47.23160975319998, 52.567590032305034, 50.70669221878052, 48.67879097802298, 48.59107344491141, 52.00183991023472, 50.53282397133963, 46.683563641139436, 50.05239772796631, 52.30276986530849, 50.28862953186035, 44.793900285448345, 37.07590382439749, 42.148773193359375, 48.0832712990897, 55.79756784439087, 53.60262148720877, 54.97627340044294, 27.067430223737443, 0.6177419722080231, 5.742199761526925, 10.262154068265643, 3.7337426202637807, 0.1834656231637512, 42.04935489382063, 62.17867183685303, 57.11087465286255, 61.0209629876273, 44.20783363069807, 27.689273153032573, 32.49291024889265, 53.575603416987825, 43.68457869121006, 1.8992618577820914, 0.23959231642740114, 0.14602396583982877, 0.09623947154198374, 0.11452761877860342, 0.08079488814941474, 0.17725442216864654, 0.13315396143921784, 0.20023622683116368, 0.1853298167032855], [0.0740820055029222, 0.061583967214184146, 0.024668856457407986, 0.03463547397404909, 0.041245884262025356, 0.0830466133941497, 0.022363414987921715, 0.034194412641227245, 0.032223753564591916, 0.08644272187458617, 0.06282658196453537, 0.07754243231777634, 0.1476324059601341, 22.809692246573313, 54.28463929040091, 35.469654015132356, 22.8934770992824, 18.27337666920253, 27.337082862854004, 48.375095639910015, 46.849142687661306, 50.095646790095735, 41.858175209590364, 50.77402721132551, 7.131595424243382, 0.15022725957844937, 2.3930989929607938, 6.563474229403904, 1.401845748935427, 8.102352568081447, 64.16699613843645, 43.89522722789219, 50.549464906964985, 41.4865334374564, 48.288830280303955, 46.25553376334054, 51.631962980542866, 45.73256022589547, 41.62482343401228, 32.39499276024954, 39.59151996885027, 44.13234492710659, 47.25748831885201, 43.17747483934675, 45.50937713895525, 46.284407002585276, 48.02888427461897, 45.65757179260254, 47.976505279541016, 45.465596539633616, 47.70725563594273, 45.05942569460188, 46.713541643960134, 44.6024044581822, 47.62576716286795, 44.84321512494768, 46.53513274874006, 45.999100072043284, 44.18310499191284, 36.626918179648264, 34.47951487132481, 34.23504250390189, 36.69932188306536, 34.32419484002249, 35.773019313812256, 32.951790128435405, 35.82219866343907, 35.613992418561665, 35.4329640524728, 33.00162608282906, 35.92980888911656, 38.14887591770717, 38.42947544370379, 35.874859060559956, 37.593092986515586, 37.96850415638515, 37.106142384665354, 34.006665638514924, 34.88699197769165, 33.114853927067344, 33.832641056605745, 33.02715376445225, 35.10728461401803, 34.48385749544416, 35.543273653302876, 37.25543832778931, 40.75180312565395, 40.54721341814314, 40.692653111049104, 38.50895241328648, 36.41490432194301, 40.028342791966026, 38.735289982386995, 36.703004428318565, 35.94626569747925, 33.282347202301025, 34.830972126552034, 32.181457247052876, 33.283702101026265, 32.61147778374808, 32.9959910937718, 33.553761209760395, 36.119953291756765, 35.95190416063581, 37.806041376931326, 36.63858420508248, 35.6528536932809, 36.91149207523891, 38.927185331072124, 31.95672471182687, 32.498291628701345, 34.30592802592686, 33.52140344892229, 34.11343513216291, 32.825596945626394, 33.791823863983154, 34.335860865456716, 32.35939713886806, 34.982960496629985, 32.014394760131836, 32.874046734401155, 31.853797571999685, 32.241406304495676, 32.00208602632795, 33.59574917384556, 36.38879646573748, 38.69175257001604, 40.24804483141218, 43.458675384521484, 44.40076773507254, 46.83146299634661, 44.76087202344622, 44.39967686789376, 46.72979348046439, 46.782460825783865, 46.75380992889404, 45.786797864096506, 46.03074564252581, 45.885024547576904, 48.2512092590332, 48.851585728781565, 46.83418321609497, 49.89604936327253, 47.05791173662458, 47.71486043930054, 35.813690594264436, 34.42703512736729, 42.84336028780256, 52.725057056971956, 51.08957270213536, 51.59594004494803, 16.452820096697124, 0.03473724404882107, 3.6597747036388943, 5.739674091339111, 2.177843366350446, 0.46734267686094555, 41.08423273903983, 50.054968561444966, 48.6192900793893, 49.29756627764021, 35.24835736410958, 29.67714582170759, 24.497758831296647, 43.174278667994905, 20.445326226098196, 0.2448674647935799, 0.02597485146751361, 0.02988539296867592, 0.0370488805430276, 0.07156032510101795, 0.028510121229503835, 0.08065673841961793, 0.024390826733516793, 0.029755942057818174, 0.0365522743335792, 0.023179509410900728, 0.012476835765742829, 0.04317294067836233, 0.11843081004917622, 0.04923559678718448, 0.086463892167168, 0.05740999297371932, 0.05082794884219766, 0.0684867175295949, 0.0492485364499901, 0.08151871538055794, 0.04441912791558674, 0.1222076988113778, 30.57068763460432, 59.940247126988, 37.74658216748919, 21.09134020124163, 28.25802837099348, 36.219649519239155, 52.94557898385184, 52.81732218606131, 55.021071910858154, 46.835284505571636, 54.53315550940377, 7.7721750395638605, 0.07491992839745112, 2.098595687321254, 7.482421261923654, 2.513655883925302, 8.786004934992109, 66.57346303122384, 45.73810141427176, 52.32840871810913, 42.304979119982036, 50.28433901923043, 47.12801558630807, 55.16933257239205, 46.16747576849801, 44.34137453351702, 33.650393281664165, 41.36363022668021, 45.40625892366682, 50.1455591746739, 45.38040120261056, 46.88234118052891, 46.76028912408011, 49.3089474269322, 46.40012230191912, 50.99297884532383, 46.9422207559858, 49.153071539742605, 44.53275918960571, 48.07869243621826, 46.725402218954905, 48.74938814980643, 46.19788455963135, 48.53655093056815, 47.423911571502686, 45.9336758341108, 37.80799729483468, 35.584056104932515, 34.81422349384853, 37.52942664282662, 35.86711529323033, 37.24080542155674, 35.127125195094514, 37.18863834653582, 35.656602246420725, 36.66498041152954, 34.579902444567, 37.795740672520225, 40.14152547291347, 40.44344902038574, 37.57746648788452, 39.64386074883597, 39.233639104025706, 40.43819965635027, 36.21314253125872, 36.41051306043352, 35.544079644339426, 35.219539710453574, 33.37860059738159, 35.73304285321917, 35.5307286807469, 37.0868924004691, 37.65456369944981, 41.18482528414045, 42.428639684404644, 42.72309739249093, 39.74861526489258, 38.51786347797939, 43.5840208871024, 40.60414695739746, 39.715684277670725, 38.94304459435599, 34.24941832678658, 35.59615986687796, 33.26373645237514, 35.458797454833984, 34.05912453787667, 35.709808077131, 35.25686195918492, 36.38429055895124, 37.27770383017403, 38.88044132505144, 37.668724128178184, 38.34324482509068, 38.3004196030753, 40.47374316624233, 34.16072109767369, 35.079971245356965, 36.11674322400774, 35.869797297886436, 35.23099034173148, 34.457197257450645, 34.86885717936924, 36.392333098820274, 34.489106859479634, 36.46008150918143, 34.53246014458792, 35.219831534794395, 33.13708816255842, 33.44274984087263, 33.238757678440635, 34.835467611040386, 37.84892913273403, 41.52039548328945, 42.69290746961321, 46.347562653677805, 45.765272344861714, 48.379024846213206, 45.755291257585796, 44.47808034079415, 47.49835457120623, 47.75182832990374, 48.44058241162981, 47.340175356183735, 46.63158764157976, 47.598467690604075, 49.46480246952602, 50.49088117054531, 48.41124364307949, 50.96097891671317, 50.03501680919102, 49.40412385123116, 36.985170773097444, 36.74456507819039, 44.88275037493025, 54.873426164899556, 52.496742725372314, 52.48990569795881, 18.32553505897522, 0.07055527224604573, 3.030004096882684, 6.232924972261701, 1.5618978291749954, 0.3810737888727869, 45.95022644315447, 53.51315300805228, 52.666890212467735, 55.24773951939174, 41.16227143151419, 27.127367121832712, 25.02068199430193, 49.19609131131853, 24.70439304624285, 0.27584296837449074, 0.08494256237255675, 0.06289503936256681, 0.014103073011418539, 0.05265839883525457, 0.0066232481705290926, 0.025068924097078185, 0.026223459912996207, 0.02164643756779177, 0.03947722506044166, 0.1301917489618063, 0.19601678395909922, 0.11162268144211598, 0.2462769720171179, 0.19780766857521875, 0.2056833566831691, 0.17549621579902513, 0.1667972475822483, 0.19594241652105535, 0.2619173941867692, 0.23182081058621407, 0.1663234265787261, 0.19835824546005043, 34.05921139035906, 69.22473580496651, 46.73825291224888, 34.33768129348755, 29.02866871016366, 38.934870038713726, 58.066352707999094, 55.71472794669015, 59.54069791521345, 52.44465902873448, 58.61561475481306, 10.381194949150085, 0.5165960139461926, 7.149174800940922, 12.319746698651995, 3.4071479737758636, 9.191956043243408, 67.3853530883789, 47.486150060381206, 55.44458198547363, 44.62698718479702, 54.061730657305034, 49.62535449436733, 56.140183516911094, 48.96863160814558, 46.81114993776594, 36.0326943397522, 44.182653359004426, 46.7775936126709, 52.362284660339355, 46.56011847087315, 49.64469133104597, 49.48624113627842, 52.63503967012678, 46.757183279309956, 52.53596878051758, 47.98616674968174, 51.31303719111851, 46.534399713788716, 49.24508653368269, 47.48657042639596, 51.68518965584891, 48.17005777359009, 50.310137680598665, 49.74134772164481, 48.42005395889282, 39.649002415793284, 37.52503538131714, 38.249541418892996, 40.35075657708304, 37.65282664980207, 38.66431760787964, 36.04637534277779, 39.214208466666086, 37.573533807482036, 38.121100493839805, 36.65006957735334, 39.48879780088152, 42.24687133516584, 42.738404273986816, 39.52656473432268, 40.27977378027779, 40.74491398675101, 42.20473745891026, 38.25312321526663, 38.18079941613333, 36.95486273084368, 38.1051995413644, 36.099740982055664, 38.0847544670105, 36.96709850856236, 39.48905488422939, 41.351595946720664, 44.30840185710362, 45.60106209346226, 44.62666061946324, 41.29176153455462, 40.50947775159563, 43.34304346357073, 41.214059829711914, 41.250798429761616, 40.73274769101824, 39.017004694257466, 40.31722457068307, 35.195168903895784, 36.473380361284526, 36.05353198732649, 38.09690339224679, 36.57853787285941, 38.07209137507847, 39.09038461957659, 40.41927971158709, 40.404195172446116, 39.965513706207275, 42.11205543790545, 42.94723585673741, 35.53160762786865, 37.19083397729056, 38.94737679617745, 37.60426221575056, 36.94263390132359, 36.247953006199424, 37.45469529288155, 37.88324628557478, 35.14300530297415, 40.03127840587071, 35.91691650663103, 37.23421158109392, 36.10157183238438, 36.12754419871739, 35.074346678597585, 37.54661648614066, 40.29500770568848, 43.247589111328125, 44.6060904775347, 48.214112826756065, 47.38207994188581, 49.79558188574654, 46.34855624607631, 46.98992708751133, 50.05139371326992, 48.77080944606236, 50.78652354649135, 48.902366638183594, 48.975927216666086, 49.3273914200919, 51.56887681143624, 52.14553213119507, 50.354025976998464, 53.93511710848127, 52.45782239096505, 52.15257065636771, 38.686061995370046, 38.341671058109824, 48.25569084712437, 57.291704995291575, 56.22012601579939, 53.20421525410244, 21.372638021196636, 0.2500405072101525, 7.71129926613399, 15.595282111849103, 5.485901125839778, 0.6359230194772992, 51.076186997549875, 58.75100040435791, 57.32364239011492, 60.27759606497628, 46.52374117715018, 40.91648585455758, 34.52337537493025, 55.32333244596209, 33.19726651055472, 0.45334680644529207, 0.12189730975244727, 0.12069968187383243, 0.18266150488385133, 0.15376660680132254, 0.10369895305484533, 0.12206068741423742, 0.11156143687133278, 0.0797055001769747, 0.09049812890589237], [0.01968411259752299, 0.06914872343518905, 0.09637425573808805, 0.008712945189992232, 0.06723372797880854, 0.048126660220857174, 0.04028943826311401, 0.039001850211726766, 0.018305117397436073, 0.04333276960200497, 0.019333993616913046, 0.057390844715493064, 0.047424213628151586, 2.968369232756751, 43.31694255556379, 44.38001346588135, 30.48237255641392, 31.40469033377511, 24.856421368462698, 45.974489552634104, 51.19198914936611, 49.11796229226248, 43.30731930051531, 49.65285546439034, 17.16347142628261, 0.14719135819801263, 1.2932847057070052, 4.908505388668605, 0.20631951040455274, 7.84640177658626, 61.36653164454869, 46.371151787894114, 49.53656693867275, 43.829406942640034, 49.70344182423183, 48.47689369746617, 49.69913741520473, 43.87628296443394, 38.47517374583653, 32.84882477351597, 45.04890612193516, 45.10160820824759, 46.87922838756016, 42.06414066042219, 46.52031224114554, 44.646268435886924, 46.380695138658794, 46.21916341781616, 46.484077385493684, 44.30122436795916, 45.045341696058, 44.4466849054609, 45.866055965423584, 44.19740091051374, 47.411915506635395, 45.4258702141898, 48.43845278876168, 43.93270928519112, 44.662110328674316, 37.27613353729248, 34.29672513689314, 35.22296517235892, 34.38451910018921, 33.85306181226458, 33.558638845171245, 33.78464984893799, 35.59066036769322, 35.67289229801723, 35.95027828216553, 33.87435804094587, 35.89140272140503, 37.745946407318115, 37.93098735809326, 35.62357745851789, 36.48100600923811, 37.98300852094378, 35.76164163861956, 35.690627574920654, 35.225998061043875, 34.51198032924107, 34.90050622395107, 34.50119325092861, 34.1830734525408, 34.445440905434744, 39.10095282963344, 39.84439270836966, 40.07514238357544, 40.749405997140066, 43.05391502380371, 37.992732524871826, 36.52697876521519, 39.279059478214805, 42.347839082990376, 38.89275353295462, 37.09211049761091, 34.49663175855364, 33.349223613739014, 34.40367875780378, 33.80265957968575, 33.74870334352766, 33.004596437726704, 33.70185511452811, 35.057410444532124, 35.44697162083217, 37.274413858141216, 35.45466327667236, 35.44743367603847, 35.35067653656006, 38.961641447884695, 33.537811619894846, 31.004456724439347, 34.462189538138254, 34.49700001307896, 33.50607572283064, 33.62987872532436, 33.48172576086861, 34.62744549342564, 33.69615759168352, 34.00231259209769, 31.782804352896555, 32.423223291124614, 32.80889000211443, 31.52547434398106, 30.4501085962568, 32.72528232846941, 34.31249407359532, 39.96560055868966, 40.05315480913435, 42.978224822453086, 43.5799422945295, 45.86194610595703, 43.78939226695469, 48.34577076775687, 48.2951010295323, 45.912730489458355, 44.78111907414028, 45.00369766780308, 42.662974630083355, 45.113069261823384, 45.37492602212088, 47.573315211704795, 43.74407958984375, 46.22165782111031, 49.51025063650948, 45.95729276112148, 40.714873450142996, 35.28451926367623, 39.97444214139666, 49.97164576394217, 47.735722405569895, 49.37035213197981, 13.623606562614441, 1.1986000835895538, 1.8870236916201455, 5.358158929007394, 0.9750880428722927, 1.1604591416461127, 48.41469342367989, 46.60211338315691, 51.81272384098598, 47.79116208212716, 31.0069511277335, 21.196039131709508, 27.69602506501334, 45.12792451041085, 11.951620715005056, 0.16650949445153984, 0.03790448945281761, 0.02235053469693022, 0.012055747959363674, 0.08374526697610106, 0.044569399673491716, 0.006554820034320333, 0.02847246253596885, 0.025603938781257187, 0.03615148744678923, 0.01576130827223616, 0.013654672474201237, 0.071029859994139, 0.012900021941667157, 0.05100830005747931, 0.06534231839967625, 0.018332691364256398, 0.021008287257115756, 0.0012107805378036574, 0.08049104695341416, 0.0406331807108862, 0.09422418182449681, 0.055758109648845026, 5.751599371433258, 53.423024450029644, 48.8663923399789, 31.939757210867747, 28.267036710466655, 32.27696371078491, 50.18072053364345, 54.214910643441335, 53.65891579219273, 48.26325396129063, 56.005951268332346, 17.553550243377686, 0.1764694657176733, 1.062343412211963, 8.433978796005249, 0.7617880627512932, 8.193510328020368, 63.547981125967844, 47.31553356988089, 53.278696468898225, 45.870353426252095, 52.706988266536165, 48.72800506864275, 51.520774432591026, 46.89715821402413, 39.73277684620449, 34.40657268251692, 47.25808586393084, 46.965198448726106, 49.586496693747385, 42.63329539980207, 47.84642110552107, 45.41590302331107, 47.39542048318045, 47.044088295527864, 47.39370775222778, 45.02214860916138, 47.8958158493042, 45.08922304425921, 46.30631119864327, 45.17245898927961, 49.311170850481304, 46.69593490873064, 48.994458062308176, 46.67934608459473, 46.45200102669852, 39.73946796144758, 36.28061648777553, 37.57706001826695, 35.817095211574006, 34.98227957316807, 36.46085623332432, 35.1672545160566, 36.49915817805699, 35.31626558303833, 37.788684776851106, 34.847352504730225, 37.82429082053048, 40.06088120596749, 40.04472664424351, 37.36449725287301, 38.21697521209717, 39.69716385432652, 36.589040075029644, 36.03501156398228, 37.51178516660418, 35.42740201950073, 35.94167641230992, 36.644538811274934, 34.737178393772666, 36.39519228254046, 41.12894787107195, 40.76368801934378, 41.11286279133388, 42.92727715628487, 44.13890750067574, 39.66495895385742, 37.11960104533604, 42.51322705405099, 43.55740581239973, 40.5289431299482, 40.70613261631557, 36.8495488848005, 35.44117334910801, 36.58619131360735, 34.88163144247872, 34.392009258270264, 35.10256331307547, 35.12262276240757, 35.6418581690107, 36.62363168171474, 38.73846878324236, 37.27358702250889, 37.14341252190726, 37.13786785943167, 39.93650150299072, 34.841658455984934, 34.353498867579866, 34.814980847494944, 35.3403445652553, 35.1495018686567, 35.84044810703823, 34.26775114876883, 34.87674685886928, 35.211910588400706, 35.913755076272146, 33.307068892887656, 34.36025946480887, 34.16898250579834, 33.10026271002633, 34.14499732426235, 33.8268393107823, 35.34158829280308, 40.039046491895405, 42.12647294998169, 45.231338024139404, 46.00734410967146, 46.78278391701834, 45.83773510796683, 49.83855996813093, 49.714642320360454, 48.903019768851145, 45.85600539616176, 46.55108233860561, 45.958970751081196, 47.649790559496196, 47.92158324377877, 49.618062359946116, 44.903740882873535, 48.58544887815203, 51.33247477667672, 47.81789527620588, 43.47898844310215, 36.16601290021624, 41.41599185126168, 52.48193611417498, 50.75840071269444, 49.84750229971749, 15.391034603118896, 1.0516440549067088, 2.5895519256591797, 8.257075922829763, 2.3043648515428816, 1.6392207486288888, 51.15890530177525, 52.66112668173653, 56.64231940678188, 51.70114619391305, 38.47635841369629, 26.345437697001866, 30.550982543400355, 50.80029487609863, 15.671312774930682, 0.18889953515359334, 0.02561953999767346, 0.029718816014272825, 0.0221995589589434, 0.058077827495123656, 0.05147546123979347, 0.08151370100677013, 0.08595478734267609, 0.0073174166360071725, 0.05445227239813123, 0.08646974792437893, 0.17536523139902524, 0.16364490959261144, 0.16129132945622715, 0.19621714177940572, 0.20971328472452505, 0.20241530133145197, 0.10492861457169056, 0.1532193547380822, 0.20924505484955652, 0.11382467006998402, 0.18707578230117047, 0.18107766844332218, 6.099130025931767, 61.912993567330496, 56.79259852000645, 40.39914035797119, 41.345808097294395, 35.86895309175764, 55.78631523677281, 59.418993268694194, 57.058690207345144, 49.87721279689244, 60.792721612112864, 21.60139008930751, 0.34948616528085297, 4.759686699935368, 11.557002118655614, 0.7404446080327034, 9.935343810490199, 64.79708657945905, 50.38253443581717, 54.61923674174717, 47.70633152553013, 55.57977308545794, 49.792389188494, 54.610627923692974, 48.21395301818848, 41.56937680925642, 36.4546480178833, 49.8500349181039, 50.672347273145405, 51.956377846854075, 43.17097132546561, 50.40417112622942, 46.60985715048653, 48.53018638065883, 48.74647685459682, 48.45262711388724, 45.30363403047834, 49.83907413482666, 47.234090260096956, 47.793715545109336, 45.41613231386457, 52.01320021493094, 48.680434226989746, 51.03688103812081, 48.02575758525303, 49.112476689474924, 41.30700240816389, 38.49935000283377, 38.44492823737008, 38.08638729367937, 36.11428703580584, 38.03719057355608, 37.954819679260254, 39.08647625786917, 37.36170755113874, 40.627284458705354, 37.66429117747715, 40.07835939952305, 40.622604846954346, 43.51287133353097, 38.84664528710501, 39.614160673958914, 42.34824902670724, 37.08355379104614, 38.45500659942627, 40.02528558458601, 37.4303731237139, 37.13804503849575, 39.608553477696006, 38.29924188341413, 37.53786870411464, 43.305940083095, 43.51842641830444, 42.75881460734776, 45.20812061854771, 47.32325301851545, 39.750123023986816, 40.23682001658848, 41.923005376543315, 45.02257939747402, 43.24249260766165, 41.81058699744088, 38.79205676487514, 37.52167592729841, 38.79729918071202, 38.591458797454834, 36.50848266056606, 35.49389280591692, 36.74112919398716, 38.41434921537127, 38.3781282561166, 40.74378490447998, 39.0954463822501, 38.51956231253487, 39.76307099206107, 42.79775926045009, 38.12218441282, 36.108460971287315, 38.267919404166086, 37.55849443163191, 37.275407450539724, 38.633537088121685, 37.29304197856358, 37.13378231866019, 36.94607325962612, 37.585991927555625, 35.73265027999878, 36.99193484442574, 36.8364063671657, 35.392605440957205, 35.94907276970999, 35.44369901929583, 37.50484044211251, 43.36586134774344, 44.90143060684204, 46.22269657679966, 48.120874949863975, 48.72943639755249, 46.85955803734915, 52.15509980065482, 51.192885466984336, 50.388061727796284, 48.46219825744629, 49.33654567173549, 46.502771513802664, 48.62659958430699, 49.46178000313895, 51.34804916381836, 48.38973896844046, 50.7203871182033, 52.75791161400931, 49.473251479012625, 45.31799595696585, 39.20848315102713, 43.13396174567086, 54.84557778494698, 52.31212561471121, 51.589068276541575, 17.958114317485265, 1.9720125368663242, 7.129273423126765, 16.522715500422887, 4.8511011089597424, 1.661623369370188, 59.66029725755964, 55.57251916612898, 59.96074431283133, 56.452494621276855, 42.0480694770813, 30.54135581425258, 38.298529693058555, 57.19199487141201, 20.64946951184954, 0.38001228868961334, 0.1520573092358453, 0.08614885514335972, 0.08003215372030224, 0.17304301315120288, 0.11554059013724327, 0.25478813531143324, 0.17054111883044243, 0.08052525190370423, 0.13309475247349056], [0.021667638394449438, 0.0534724237264267, 0.0036106650700925714, 0.0238681104965508, 0.02524832875600883, 0.028880207799375057, 0.04094667746020215, 0.03032741442854915, 0.049241615392799885, 0.024287146582667316, 0.020632461977324316, 0.04494285856240562, 0.029042269103229046, 0.024274179778460945, 20.919316700526647, 51.89319092886788, 30.311690058026993, 21.36836835316249, 33.006208419799805, 41.662875243595664, 50.53366470336914, 50.408169814518516, 45.28275121961321, 49.13281406675066, 28.694951942988805, 0.14263941959611007, 0.36106506681868006, 8.138563105038234, 0.060108031412320476, 2.8832629195281436, 53.709265913282124, 48.51684583936419, 52.145427908216206, 46.2288179397583, 50.46604136058262, 47.1662723677499, 49.094289779663086, 40.45339189256941, 35.40732519967215, 37.831235545022146, 46.229113238198416, 46.733986718314036, 45.35641949517386, 42.2803373336792, 47.25424351011004, 45.842320919036865, 46.0558077948434, 44.395327295575825, 46.98898908070156, 44.594320229121614, 46.13224145344326, 43.54290492194039, 47.03435039520264, 45.66384949002947, 46.51329108646938, 46.243426527295796, 45.77483306612287, 45.442570209503174, 44.388156754629954, 35.14912666593279, 32.45195409229824, 34.81004415239607, 35.077758244105745, 33.202331747327534, 33.52289383752005, 33.27327980313982, 35.88597617830549, 35.4530999319894, 35.13499402999878, 32.04863895688738, 36.23263222830636, 38.125113078526084, 36.62832866396223, 36.56341511862618, 37.83743333816528, 36.517574378422324, 33.097431319100515, 35.572539465767996, 33.43879631587437, 35.50112240655081, 33.24030017852783, 34.619990076337544, 31.959038461957658, 35.16545145852225, 39.94415841783796, 40.27491004126412, 43.86648253032139, 42.85076011930193, 43.505881445748464, 40.77881077357701, 38.06711299078805, 38.990900312151226, 41.37102310998099, 38.956548418317524, 38.71125963756016, 32.04903153010777, 32.005535806928364, 33.54247733524868, 32.629612582070486, 33.341952323913574, 33.13875225612095, 34.28083113261631, 36.570509229387554, 34.880418981824604, 34.69820942197527, 34.072524138859336, 35.7011957849775, 34.77305889129639, 35.418657711574006, 34.94723980767386, 32.200047152382986, 33.48055498940604, 33.93875394548689, 33.57337597438267, 32.45690815789359, 33.59260858808245, 33.425629479544504, 33.698106561388286, 32.72009897232056, 32.11765888759068, 31.773049082074845, 31.593413829803467, 31.507547991616384, 33.23127099445888, 31.933163370404923, 32.862693377903526, 36.063638142177034, 38.35062381199428, 40.84195600237165, 41.4150573185512, 42.65697833469936, 43.1014997618539, 45.856863498687744, 43.844130175454275, 43.61813654218401, 43.48230273383004, 43.25494725363595, 43.935943671635215, 43.178301674979075, 46.168253966740195, 45.31123883383614, 46.598017420087544, 44.29607922690255, 47.700168473379954, 46.289500032152446, 45.413036891392295, 35.22671372549874, 39.780073234013145, 47.10613570894514, 54.24911315100533, 44.802467414310996, 17.031017916543142, 2.165821462869644, 1.0808721951075961, 2.1555665731430054, 1.1024311525481088, 2.724019978727613, 47.40396329334804, 51.33562925883702, 43.04363168988909, 41.88561364582607, 25.70568925993783, 19.788215977805002, 30.372368676321848, 42.4407434463501, 3.222007142645972, 0.15342716287289346, 0.05591213709807821, 0.028233952387901287, 0.022591256869158576, 0.09303967681314264, 0.05988444055297545, 0.05987428966909647, 0.025446365986551558, 0.00533719318419961, 0.07288013678044081, 0.024716891647715653, 0.05798947545034545, 0.037905978837183545, 0.03924891159736684, 0.0402902457197862, 0.021912862646526525, 0.029494071645396094, 0.04297681013122201, 0.03363665007054806, 0.01869286284116762, 0.06432505191436835, 0.029071225585149865, 0.0671992583998612, 0.1563797401530402, 27.47527211053031, 58.24038076400757, 29.647952965327672, 24.93186664581299, 38.340198040008545, 46.70267118726458, 56.783513750348774, 54.27348048346383, 48.2699624470302, 52.81530373437064, 28.94133332797459, 0.14349051964070114, 1.2682512147086007, 7.964939781597682, 0.5998196910534586, 4.06272679567337, 54.90304633549282, 49.28495529719761, 56.8249180657523, 48.414352961948936, 53.09716435841152, 48.030888829912456, 50.899355343409944, 42.54930904933384, 38.8926215171814, 39.719318185533794, 49.41220808029175, 48.90557323183332, 47.78651373726981, 42.646055766514365, 48.54790081296648, 47.15226827348982, 46.84744037900652, 45.5048816544669, 47.88630723953247, 45.49025917053223, 47.75156429835728, 44.338859285627095, 47.33610718590872, 46.51989534923008, 48.602690832955496, 48.30803510120937, 48.95893887111119, 46.24243640899658, 46.234609263283865, 36.30097470964704, 33.86400522504534, 35.90282208578927, 36.35596970149449, 34.95324305125645, 35.32564912523542, 33.84599549429757, 36.03915269034249, 36.485581398010254, 36.918627875191824, 33.608829157693044, 39.51322071892874, 38.75207683018276, 38.990976742335725, 38.95275470188686, 38.48959820611136, 38.04790122168404, 37.01915093830654, 36.653373445783345, 35.227311270577566, 36.22781365258353, 36.61908408573696, 35.557138783591135, 34.64316231863839, 37.02922930036272, 42.401826586042134, 41.33709505626133, 44.498341287885395, 44.39914880480085, 44.89671972819737, 41.746837275368826, 40.47344091960362, 42.659142698560444, 44.78904002053397, 41.91574798311506, 40.6249463898795, 34.86495923995972, 34.146202836717876, 34.9376790864127, 35.32653849465506, 35.16762971878052, 35.014619963509695, 36.06642436981201, 36.83055598395211, 35.9306183542524, 37.13370588847569, 36.23626961026873, 37.97624444961548, 36.8439382144383, 37.3923282623291, 36.921844891139436, 34.79491792406355, 35.881984438214985, 35.5914420400347, 35.771226678575786, 35.27144970212664, 34.79927791867937, 35.585949489048545, 36.26362814222063, 34.50706795283726, 34.57357610974993, 34.64238064629691, 33.864891120365684, 33.266018935612266, 33.74237353461129, 34.266358034951345, 34.92395292009626, 37.14187697001866, 40.69170468194144, 42.57687602724348, 43.13715444292341, 44.94372776576451, 45.65031092507498, 48.408137798309326, 46.44823162896292, 46.181914125170024, 45.055100440979004, 45.137585980551584, 44.89704629353115, 44.90147924423218, 47.448723588671, 47.941027777535574, 48.714838232312886, 46.58308226721627, 49.70679433005196, 48.99527447564261, 45.968625273023335, 37.47673845291138, 41.21082544326782, 48.0501457623073, 55.188770157950266, 43.46699932643345, 21.273315259388514, 1.73894259759358, 2.5085094400814603, 4.040599388735635, 1.5391499698162079, 2.79037093264716, 51.039271218436106, 54.46081781387329, 48.36086572919573, 47.42622184753418, 31.871129853384836, 21.447372845241002, 33.59869173594883, 49.23115886960711, 5.264028208596366, 0.16666684672236443, 0.08019880192088229, 0.036486259661614895, 0.0562372130474874, 0.05734251945146492, 0.0433018317978297, 0.023693632001855543, 0.06578542212290422, 0.01920677169359156, 0.03796849226845162, 0.10024084682975497, 0.2058303409389087, 0.12635273353329726, 0.07208510408444063, 0.11268754037363188, 0.0919410539790988, 0.12463086949927465, 0.11477585402982575, 0.11635215873164789, 0.1849031267421586, 0.14507006773991243, 0.06521801078425986, 0.13616478416536534, 0.3394740553838866, 33.1934380531311, 67.15373488834926, 38.83404472896031, 32.07824175698416, 44.106059891836985, 51.98273236410958, 57.390105383736746, 61.01491805485317, 54.16606828144619, 60.30283887045724, 35.35835429600307, 0.2355930581688881, 2.5041867920330594, 20.838523047310964, 1.0797951157603944, 4.642832764557429, 57.30112675258091, 51.25919907433646, 57.557244300842285, 50.596292291368755, 54.6076124055045, 49.17089714322771, 53.18344708851406, 43.457226685115266, 39.415747914995464, 41.12720039912632, 51.41721153259277, 51.156310149601524, 48.928033283778596, 43.551364353724885, 49.394410269601, 48.99465608596802, 49.04912648882185, 48.183929852076936, 48.87511232921055, 48.44054767063686, 51.68993527548653, 47.030007771083284, 50.94812822341919, 48.73045083454677, 50.84333201817104, 50.9060012953622, 50.523885113852366, 49.46831130981445, 48.13174888065883, 38.285189151763916, 35.78729786191668, 38.968468053000315, 39.33464854104178, 37.43147441319057, 36.11130625861031, 35.14731318610055, 38.98889575685774, 38.7278276171003, 39.95872531618391, 34.059954847608296, 41.457260676792686, 40.92948940822056, 42.545428480420796, 39.172283036368235, 41.482774462018696, 39.32982301712036, 38.35285070964268, 38.92181089946202, 37.14233555112566, 38.5778021131243, 38.10685668672834, 37.17887960161482, 36.647550855364116, 37.97068241664341, 45.17766319002424, 44.13296331678118, 47.67228882653372, 46.95881652832031, 48.16499948501587, 43.46802071162632, 41.08435433251517, 42.88969087600708, 46.42331886291504, 42.95402772086007, 42.35779932567051, 36.57930564880371, 35.61145632607596, 37.90384422029768, 37.05135931287493, 37.48303699493408, 36.70614848818098, 37.415517875126426, 39.43651260648455, 37.31113856179373, 39.0003012248448, 37.64902251107352, 39.278983048030305, 39.69416223253523, 38.62152017865862, 38.680812631334575, 37.12069886071341, 38.031208174569265, 37.58281660079956, 38.153395720890586, 35.43997825895037, 37.38728734425136, 36.29899794714791, 37.37684072766985, 37.31395953042166, 36.68859386444092, 36.90303611755371, 36.42275578635079, 36.08799852643694, 36.61361237934658, 36.62773806708199, 37.048312527792795, 38.24107156481062, 42.48655639375959, 44.24745225906372, 44.579864501953125, 46.65544775554112, 47.28972796031407, 48.85312475476946, 47.46904012135097, 47.164726393563406, 46.546625069209504, 46.5072009904044, 47.262859276362825, 47.12941217422485, 50.487115246909006, 48.68574612481253, 48.61443676267351, 46.18637834276472, 49.714687483651296, 50.50313431876046, 49.81584978103638, 39.09479325158255, 44.130885805402485, 51.445431641169954, 57.902892862047466, 46.85924536841256, 25.466124057769775, 3.109486277614321, 4.3615879246166775, 13.072365147726876, 3.3848575013024464, 3.653095313480922, 57.43653324672154, 59.52975450243269, 54.73033148901803, 53.10430015836443, 35.13272891725813, 28.700203044073923, 41.65433938162667, 56.86472429547991, 7.692083154405866, 0.3761363338146891, 0.18119124163474354, 0.14197342390460627, 0.0878691721175398, 0.14263625762292317, 0.12584645141448292, 0.14733587258628436, 0.18827684356697968, 0.07223940973303147, 0.1207629484789712], [0.04997644506927047, 0.06133958604186773, 0.017248260090127587, 0.03435363427602819, 0.030415359352316176, 0.05892366889332022, 0.02424556595672454, 0.028106798318081667, 0.04987595064033355, 0.038563099290643416, 0.05467513043965612, 0.02350168631944273, 0.04903074706505452, 0.0843632427443351, 6.241131229060037, 48.96972942352295, 43.29540661403111, 27.849766118185862, 22.463564259665354, 31.953000477382115, 45.44384520394461, 47.42730229241507, 48.43709441593715, 45.19298396791731, 40.97882161821638, 1.1325860087360655, 0.7672379474554742, 3.5529563554695676, 4.7510987264769415, 0.5345477706619671, 36.81885869162423, 54.14289951324463, 46.070805481501985, 44.40080942426409, 47.05646651131766, 51.13375282287598, 44.40357480730329, 44.304232937949045, 40.966641426086426, 46.1922287259783, 45.68195302145821, 48.09643118722098, 42.949490547180176, 47.27592536381313, 46.891245297023225, 44.949831758226665, 44.6837921823774, 45.452276842934744, 46.56331811632429, 45.852757113320486, 45.625026430402485, 45.932525907244, 44.17391947337559, 46.15996476582119, 45.5764342035566, 45.28301872525896, 44.52988958358765, 46.380816732134136, 39.94273056302752, 34.34552580969674, 33.52423136574881, 33.79465178080967, 33.41857705797468, 33.80770397186279, 34.37819971357073, 35.1305958202907, 33.497720514025005, 36.51142522266933, 33.97636801855904, 33.075197083609446, 36.41157613481794, 36.94151176725115, 35.99068900517055, 36.17821741104126, 35.52843924931118, 35.82169491904122, 34.67507539476667, 35.50456176485334, 33.16668054035732, 33.93984481266567, 34.23168304988316, 33.671300411224365, 31.47517286028181, 36.25964682442801, 40.47104031699044, 41.62563984734671, 42.42147609165737, 43.80925716672625, 44.32507405962263, 41.894413539341514, 38.24404886790684, 37.98500960213797, 42.51243148531233, 41.71984352384295, 42.137458051954, 35.62863227299282, 33.899718965802876, 33.1736078943525, 32.79756096431187, 32.493643283843994, 35.12555490221296, 32.837964739118306, 34.85860858644758, 33.543144362313406, 32.4615912437439, 34.80144575663975, 34.987813813345774, 34.77050542831421, 37.090998785836355, 35.581346307482036, 32.67714868273054, 33.18071937561035, 35.29962812151228, 33.756923062460764, 32.7891605922154, 32.67088835580008, 34.012585503714426, 32.11196831294468, 32.92563016074044, 33.249437059674946, 31.344244480133057, 32.235403060913086, 31.31775447300502, 31.89380877358573, 32.49769408362252, 32.38261801855904, 31.491699150630406, 34.57099485397339, 35.31101969310215, 38.36853974206107, 38.84580455507551, 39.80792856216431, 38.29087625231062, 40.15539060320173, 40.1634817804609, 40.52751874923706, 41.38217844281878, 41.014313016619, 42.13415765762329, 44.685914857046946, 44.861447198050364, 47.09905202048165, 45.09232541493007, 47.09638043812343, 48.030527523585725, 46.42214461735317, 40.41225855691092, 37.52031408037458, 47.96750388826643, 49.22190039498465, 42.52419131142752, 10.351368938173566, 0.2794529375221048, 3.6678697892597745, 3.9842712112835477, 1.9599450358322688, 3.8625982659203664, 50.45262786320278, 47.64268602643694, 44.114171913691926, 33.21606138774327, 22.44042502130781, 20.873416900634766, 39.89041410173689, 29.245690482003347, 0.36632637307047844, 0.07155664744121687, 0.06830575902547155, 0.11212707723357848, 0.05099102116322943, 0.0929004821394171, 0.018251092439251285, 0.026464758839990412, 0.01865608454681933, 0.010028682266628104, 0.054933981371245215, 0.061333696357905865, 0.03762530961206981, 0.01649822953290173, 0.011874361130009805, 0.04489839755530868, 0.038508460258266757, 0.04006405607131975, 0.04728703420343144, 0.048252318120960674, 0.028848435397126844, 0.0952025003997343, 0.03875041227521641, 0.056461173708417585, 0.07169453932770661, 9.026221530778066, 57.73331165313721, 47.272423471723286, 25.37468923841204, 33.97050721304757, 43.0924254144941, 48.83198833465576, 55.11024161747524, 53.88227258409773, 50.97185632160732, 42.59325293132237, 1.1189450664179665, 0.9330153976167951, 4.473648905754089, 2.9611565683569228, 0.6425671258143016, 40.355606419699534, 56.29378039496285, 49.405586447034565, 46.78257199696132, 47.95530979973929, 52.02840287344796, 48.09819255556379, 45.28358152934483, 42.24296644755772, 47.109665393829346, 48.19750663212368, 50.73743799754551, 44.25319841929844, 47.468220233917236, 47.42877183641706, 46.603027071271626, 45.68198081425258, 47.81767293385097, 47.51158741542271, 48.86171620232718, 47.596254689352854, 47.09038066864014, 46.604482718876426, 46.29946027483259, 46.70015593937465, 47.66139752524239, 47.335071904318674, 47.95027582986014, 42.58429670333862, 35.76580708367484, 34.56406055177961, 34.85032980782645, 35.97526747839791, 35.02106441770281, 35.98919514247349, 35.09402745110648, 35.24097490310669, 36.912840025765554, 35.14181021281651, 35.075538294655935, 36.50908367974417, 37.44863993780953, 38.286439827510286, 39.203918184552876, 38.915369919368196, 37.72698129926409, 37.07648747307913, 36.14948313576834, 35.604355267116, 35.65237079347883, 35.24532100132534, 35.883509567805696, 34.10253340857369, 38.73126002720424, 43.16440527779715, 43.26834338051932, 45.35009316035679, 45.64735794067383, 47.036664145333425, 42.791123730795725, 41.04698692049299, 41.178172383989605, 44.31490537098476, 44.24720212391445, 43.65571934836251, 36.96420805794852, 35.344728878566194, 35.534449441092356, 34.68315267562866, 35.26339673995972, 35.221179485321045, 35.915099552699495, 37.12995038713728, 35.581224714006694, 35.40558467592512, 36.75456006186349, 36.59753424780709, 35.79215465273176, 38.398747035435264, 37.083373137882774, 35.29451077325003, 35.19963312149048, 37.35607603618077, 36.17527832303728, 33.69593872342791, 32.957494599478586, 34.56953225816999, 33.549627031598774, 35.25574677331107, 34.1835424559457, 33.98872538975307, 34.46955115454537, 33.08149562563215, 34.08555201121739, 34.09829500743321, 34.42700386047363, 33.88199063709804, 36.87935665675572, 37.5804055758885, 42.09306948525565, 42.27414301463536, 41.28013372421265, 40.9695040839059, 41.86186817714146, 42.40747199739729, 42.425304549080984, 42.79032121385847, 42.88296501977103, 43.26696068899972, 46.3273468698774, 46.95540843691145, 49.410780225481304, 47.81385142462594, 48.64115606035505, 50.32485049111502, 49.07383080891201, 42.77191196169172, 39.69791425977434, 50.43839447838919, 49.84536920275007, 43.30115624836513, 12.96167252744947, 0.517495262835707, 6.471889155251639, 2.3913217740399495, 1.338146509868758, 3.9383427500724792, 54.51202951158796, 52.98370027542114, 48.05883795874459, 41.35250268663679, 27.908766746520996, 19.648312262126378, 43.35934393746512, 36.415807587759836, 0.9747686428683144, 0.06548217803772007, 0.05086247609662158, 0.0970209538936615, 0.014289640455639787, 0.06555598229169846, 0.07186907889055354, 0.06122869306377002, 0.06503677408077888, 0.007812146696129015, 0.0627581924200058, 0.1477486797209297, 0.22030799835920334, 0.07193875765161854, 0.10761895842318024, 0.1143780696604933, 0.12694106410656655, 0.10613766219466925, 0.11206161217497927, 0.101237560489348, 0.11241697453494583, 0.17763433392558778, 0.17897973316056387, 0.20309701189398766, 0.21565418450960092, 9.930282047816686, 67.83048248291016, 53.360737323760986, 37.964439460209434, 32.86245713915144, 43.1418514251709, 53.36628546033587, 56.13611882073538, 57.40525245666504, 54.56066690172468, 51.14944880349295, 1.8593472795827048, 1.8839237093925476, 11.393937451498848, 7.402602093560355, 1.9733277005808694, 43.02570881162371, 54.791326250348774, 50.229163374219624, 47.682221276419504, 49.740944726126536, 54.64690099443708, 50.525438036237446, 48.20662614277431, 44.42047282627651, 50.3121144430978, 49.78715372085571, 53.217726026262554, 45.661761556352886, 50.951904569353374, 50.05460378101894, 48.94127655029297, 48.538642338344026, 50.53780582972935, 50.87817028590611, 51.67337424414498, 50.12195266996111, 50.01860516411917, 47.77476780755179, 49.01121711730957, 48.38266222817557, 50.600905895233154, 48.33485862186977, 51.037794726235525, 44.95285422461373, 36.76355797903878, 36.7670772416251, 36.906701292310444, 38.61682667051043, 36.68882662909371, 38.24030378886631, 38.86057642527989, 36.66361509050642, 37.902913161686485, 36.88765280587332, 38.50026716504778, 39.7634322983878, 40.382113797324045, 39.91106414794922, 41.05591882978167, 39.41483422688076, 39.321026597704204, 38.830629689352854, 38.681472710200715, 36.20622559956142, 37.21361364637102, 37.79158912386213, 38.065379415239605, 35.81434719903128, 39.93282243183681, 44.54660694939749, 45.72236721856253, 46.14032915660313, 47.46005957467215, 48.2653488431658, 45.526976925986155, 40.79204709189278, 42.00183963775635, 47.40514101300921, 46.11947066443307, 47.27030079705374, 39.94994626726423, 37.501074518476216, 37.032446316310335, 36.20489501953125, 37.05900927952358, 39.196438448769705, 37.69605834143502, 40.13342734745571, 36.94547918864659, 35.69932324545724, 37.86612592424665, 38.73963608060564, 37.88551834651402, 39.63033955437796, 39.4166442326137, 36.445681367601665, 37.260802337101524, 40.29085268293108, 37.58744757516043, 35.05786902563912, 35.81397894450596, 37.48021950040545, 34.27761064256941, 37.48951619012015, 36.410026686532156, 36.13960974557059, 36.314113753182546, 34.91084514345442, 37.03174454825265, 35.801781381879536, 35.27597645350865, 34.74803147997175, 37.9667775290353, 39.6599041393825, 42.74969857079642, 43.38541010447911, 42.63454607554844, 42.1638195174081, 44.77778741291591, 44.68693971633911, 44.44509376798357, 45.2653112411499, 44.89079638889858, 44.582609040396555, 50.16842222213745, 49.405225140707834, 49.54072196143014, 46.89406973975045, 48.87803404671805, 51.42922496795654, 50.35778495243618, 45.220116683415, 41.74388429096767, 53.48141711098807, 50.86015360695975, 45.31954887935093, 15.281178372246877, 0.5215822149600301, 8.59205378804888, 10.722458328519549, 3.352947465011052, 5.033158242702484, 57.8455354826791, 56.47461073739188, 53.47933612551008, 44.3934200150626, 32.24055167606899, 29.977707522256033, 51.90700394766671, 44.01214109148298, 1.6226033717393875, 0.15045946783253125, 0.12102288167391505, 0.19594116801662104, 0.13004870020917483, 0.21416347021503107, 0.20045824348926544, 0.2051697192447526, 0.13503939312483582, 0.13662375882267952, 0.16810506954789162], [0.01904082577675581, 0.040551193324582915, 0.0036493305399614784, 0.02962766501254269, 0.08846056288374321, 0.040380640154970546, 0.043374075421265194, 0.047825933500592194, 0.02540402370505035, 0.05174366916928973, 0.0593182777187654, 0.09017434556569372, 0.030908223441136733, 0.012883463142705815, 0.43717321859938757, 27.22053725378854, 43.92032412120274, 23.43126940727234, 27.306840828486852, 31.089495726994105, 45.24546023777553, 44.05698823928833, 45.68993650163923, 44.60944993155343, 49.034948689596995, 6.627116254397801, 1.2402356437274387, 2.3753265866211484, 18.276315757206508, 0.36636703088879585, 26.348128386906215, 49.62488896506173, 47.4316588129316, 43.48759726115635, 39.85868862697056, 49.049550328935894, 45.152524607522146, 45.79338475636074, 46.54044812066214, 44.39951358522688, 47.126584257398335, 49.03963524954659, 48.26402521133423, 47.66829361234392, 44.20062140056065, 44.17955098833357, 43.042443547930034, 46.97942835944039, 45.788854530879426, 48.32688208988735, 46.302395888737266, 46.32736424037388, 45.641316481998985, 46.26925298145839, 44.65281016486031, 45.24911151613508, 42.80808080945696, 42.55959585734776, 34.34180852345058, 33.387150355747764, 31.520263195037842, 34.615300042288645, 34.62239415305001, 34.40886211395264, 33.1108899797712, 34.159296716962544, 34.47718375069754, 34.824277537209646, 33.90658726011004, 35.06477900913784, 36.37435116086687, 37.499236719948904, 34.17959240504673, 34.64198112487793, 36.00962284633091, 35.243979998997276, 34.10816839763096, 34.863319465092246, 34.323434012276785, 32.918681962149485, 33.86597156524658, 31.75249978474208, 31.191794054848806, 38.323150634765625, 41.01633494240897, 43.15558453968593, 44.7917845589774, 45.103772572108674, 44.8672593661717, 46.1863922391619, 35.72170686721802, 38.45156029292515, 46.256023611341206, 42.86410066059658, 42.21299191883632, 35.264442443847656, 33.19879511424473, 33.008942535945344, 33.02601078578404, 33.17813464573452, 33.78117227554321, 33.78090476989746, 33.97905349731445, 34.08818885258266, 33.256836891174316, 34.84818976266043, 35.228304862976074, 35.35912207194737, 36.79220887592861, 35.45714725766863, 32.09380919592721, 32.7207555770874, 34.5944241796221, 34.1179757799421, 33.26082168306623, 34.25521659851074, 32.63705062866211, 34.266073158809114, 32.32599367414202, 31.932385172162736, 32.207839557102744, 31.4178432737078, 32.38383047921317, 32.5024014881679, 32.83191633224487, 33.570805140904014, 31.958996772766113, 31.70611013684954, 33.52464825766427, 34.38362625667027, 34.5948862348284, 34.6188714163644, 34.36973333358765, 34.74324764524187, 37.26594052995954, 37.91236965996878, 37.33306360244751, 37.494831562042236, 40.54599053519112, 41.34244864327567, 45.074645723615376, 45.63394791739327, 47.441688537597656, 44.65339381354195, 48.17618261064802, 46.977031230926514, 43.59780263900757, 43.324533462524414, 49.20125034877232, 49.932537828172954, 42.88907943453108, 1.3162719522203719, 2.1158754229545593, 11.090512224606105, 2.527709266969136, 0.25539593983973774, 4.090167837483542, 54.48824235371181, 44.90662785938808, 53.15336833681379, 27.91924810409546, 22.23486951419285, 26.806195327213832, 42.911869525909424, 18.14337239946638, 0.08591685723513365, 0.03469341068661638, 0.008474999922327697, 0.04970856283658317, 0.04123786397810493, 0.033341490730111084, 0.053558000562978644, 0.05652016893561397, 0.012930490708510791, 0.048261512270463366, 0.014740438765979238, 0.007511473410496754, 0.08975478700761284, 0.08113505811031375, 0.04118518251925707, 0.05249992358897414, 0.05531634942495397, 0.016995393837402974, 0.060605071884180815, 0.028083711164072156, 0.0586829043126532, 0.0299129652391587, 0.060358634750757895, 0.03985445321138416, 0.06047787370958498, 0.8186880009514945, 34.849641936165945, 50.692677702222554, 22.839897802897863, 27.9393527167184, 38.769753047398154, 45.9654221534729, 50.10794162750244, 51.65012557165963, 48.993443625313894, 52.188412938799175, 6.161571749619075, 1.1051599489791053, 1.8057693945510047, 14.81319808959961, 0.7494793832302094, 29.629953656877788, 53.38398947034563, 46.69688333783831, 45.494372504098074, 40.772352422986714, 50.707605906895225, 46.469569546835764, 46.529271943228586, 48.94653981072562, 46.709067004067556, 48.36741093226841, 49.957527024405344, 49.22536754608154, 49.66075209208897, 45.90907573699951, 47.148432867867605, 46.55875662394932, 48.897951057979036, 46.64550835745675, 48.311665534973145, 48.086498737335205, 48.21275792803083, 46.9061769757952, 49.14052309308733, 46.95412302017212, 47.57676499230521, 45.01043047223772, 43.953084877559114, 35.64389746529715, 33.95713540485927, 33.48849330629621, 37.32101195199149, 35.173459257398335, 36.33775847298758, 35.39744486127581, 35.885097231183735, 37.08997392654419, 37.0503066607884, 36.13065699168614, 36.08262409482683, 38.852839606148855, 38.24844012941633, 36.124188218797954, 35.813065256391255, 36.016991410936626, 37.68061597006661, 35.08535609926496, 35.72236347198486, 36.66857957839966, 36.398791449410574, 36.437037808554514, 33.916662148066926, 33.72782400676182, 40.32316875457764, 41.81971345629011, 45.334171363285606, 46.70448119299752, 46.668923786708284, 47.72617210660662, 48.09983580453055, 39.84165859222412, 40.71071147918701, 45.76186077935355, 45.27271454674857, 45.25703593662807, 37.26785475867135, 36.06732068743025, 35.47430235998971, 34.71290833609444, 34.671028069087434, 35.47941623415266, 35.60198245729719, 34.96681635720389, 36.277771200452534, 35.50324855531965, 37.4869453566415, 34.79038769858224, 37.04410539354597, 38.20815794808524, 37.25703641346523, 34.72508158002581, 34.36135728018624, 36.36631556919643, 35.24820102964129, 34.93236371449062, 35.80508872440883, 34.34171124867031, 35.84560367039272, 34.67410959516253, 33.832401343754356, 33.9845529964992, 33.5422272000994, 34.39313834054129, 33.34243174961635, 33.874667235783164, 34.628494671412874, 34.05125222887312, 34.48762689317976, 34.71265125274658, 35.3142123903547, 36.211940492902485, 36.96152605329241, 35.668323857443674, 36.99468633106777, 39.4626829964774, 39.71392638342721, 38.898485796792166, 39.98515278952462, 42.978540965488975, 43.078383105141775, 48.291581766945974, 47.395423957279746, 48.391979762486045, 43.62243052891323, 50.205393586839946, 49.00944185256958, 47.54603658403669, 44.18119771139962, 52.12297133037022, 49.09937586103167, 44.04802853720528, 1.8906226413590568, 2.2266136407852173, 5.745197909218924, 4.5368779471942355, 0.3027583898178169, 4.622157965387617, 59.729244232177734, 48.514545985630576, 56.99822350910732, 34.15283489227295, 26.16363286972046, 24.874571800231934, 47.98131343296596, 22.115645374570573, 0.07301074798618044, 0.020279754385618225, 0.014545449854007788, 0.061907458784324784, 0.07581227658582584, 0.04466837757666196, 0.03568367826353226, 0.02964029594191483, 0.03438246862164565, 0.017352908849716187, 0.07802919298410416, 0.07104568343077387, 0.2689852592136179, 0.1766822271581207, 0.08078061177262238, 0.18679109614874634, 0.09166088686989886, 0.0972728260925838, 0.19519425023879322, 0.05924564054501908, 0.216495133670313, 0.13592793473175593, 0.14821540324815682, 0.17373764302049363, 0.1276517752557993, 0.8931335519467081, 39.9809421811785, 60.249886648995535, 33.883647782461985, 39.20375142778669, 42.229757922036306, 54.36297675541469, 54.78357553482056, 56.456868512289866, 54.189407280513215, 57.24896662575858, 9.004550099372864, 2.7196486932890753, 9.724954094205584, 26.322579860687256, 1.3379250360386712, 33.15092897415161, 50.99061298370361, 47.212154797145296, 45.21558993203299, 40.562586307525635, 51.855354513440815, 48.7129031590053, 48.00782775878906, 51.54957471575056, 49.739555086408345, 49.416321413857595, 51.482993602752686, 50.861678736550466, 51.83641372408186, 48.436913762773784, 48.77920286996024, 46.34930317742484, 51.634019647325786, 48.571913787296836, 53.15976415361677, 49.22804955073765, 49.98401703153338, 48.954075132097515, 51.396752561841694, 48.53638069970267, 48.60170071465628, 46.93203122275216, 46.03232288360596, 37.10684067862374, 36.14006832667759, 34.136537892477854, 38.89742272240775, 37.125840527670725, 37.18710279464722, 36.869861943381174, 37.15670789991106, 38.074870654514854, 38.67370115007673, 38.407015391758506, 38.627613748822895, 40.63027565819876, 40.62458855765206, 37.400502817971365, 37.58700636454991, 38.86080224173409, 39.90648528507778, 36.547236238207134, 38.44354901994978, 39.25877768652779, 38.59845910753523, 38.71275002615792, 35.572761808122905, 35.71193422589983, 42.676137992313926, 44.591620853969026, 48.085331439971924, 47.627003942217144, 48.90700456074306, 49.74641643251692, 49.96760886056082, 38.118296895708355, 42.528130940028596, 50.5752739906311, 45.941322326660156, 47.77127981185913, 38.548428603581016, 37.77743911743164, 36.91809286390032, 36.88537032263619, 37.09823880876814, 37.28344999040876, 37.57492344720023, 36.844858850751606, 36.98193291255406, 37.29547037397112, 39.113431794302805, 37.43291963849749, 39.06902585710798, 40.363437039511545, 38.72855370385306, 35.946828501565115, 35.55196237564087, 38.67197104862758, 37.327647481645855, 36.39572034563337, 37.903121607644216, 36.14139543260847, 37.62854616982596, 35.91903223310198, 35.99500731059483, 36.7596252986363, 37.060746329171316, 37.0411558832441, 36.45838267462594, 37.32024417604719, 37.42225415366036, 36.14947966166905, 35.195669174194336, 37.10959216526577, 36.307374000549316, 38.46593264171055, 39.26104627336775, 37.85641581671578, 38.736783845084055, 41.67164387021746, 41.766789027622764, 41.61718388966152, 42.38696091515677, 44.414629391261506, 45.5931897844587, 49.28791870389666, 49.12147460665022, 49.19387483596802, 44.52527250562395, 52.08814695903233, 50.493656975882395, 48.41529444285801, 47.16642870221819, 53.695734296526226, 51.760761737823486, 45.81047732489449, 3.0996089790548598, 3.5622382802622656, 20.208095618656703, 9.625539268766131, 0.6720832362771034, 5.858721486159733, 64.35017844608852, 53.82159743990217, 61.872228486197336, 36.87409687042236, 32.819871629987446, 34.388785294124055, 55.33581141063145, 29.346324716295513, 0.2875197689448084, 0.18091597354837827, 0.11238080183310167, 0.10576608963310719, 0.2715678720601967, 0.11561172774859838, 0.16302695418042795, 0.2316932731441089, 0.16749408947569983, 0.1199112106114626, 0.12568623572587967], [0.016900420987180302, 0.040184485859104564, 0.024716669427497045, 0.045240735435592275, 0.04834549794239657, 0.024198277154937387, 0.010200514474750629, 0.06752800861639635, 0.013786427859616066, 0.06287117528596095, 0.02560208298798118, 0.09262583151991878, 0.018118447324793254, 0.1160590723156929, 0.02999551241685237, 10.141682726996285, 49.228740896497456, 35.74423292704991, 31.155256952558243, 28.28167482784816, 44.56569365092686, 47.62532247815813, 48.55135406766619, 43.57814271109444, 49.688256536211284, 11.183856061526708, 0.8284497857093811, 2.393262927021299, 19.996846062796457, 2.7606699892452786, 18.910496950149536, 40.708338669368196, 45.274455070495605, 48.85485485621861, 40.37925461360386, 46.971820081983296, 48.18119921003069, 49.69259568623134, 46.54972049168178, 47.313317094530376, 46.19252402441842, 45.377767835344585, 44.48216935566494, 44.2679112298148, 42.64777544566563, 42.968921184539795, 43.28238916397095, 45.79615361349923, 44.9336702483041, 46.75523083550589, 45.55448831830706, 45.78661721093314, 45.63018546785627, 45.65609877450125, 45.73637478692191, 43.84853880746024, 43.23442922319685, 36.58099058696202, 34.69697264262608, 33.74735539300101, 33.04132114137922, 34.96521132332938, 34.840220178876606, 34.54250029155186, 34.88478592463902, 35.59108073370797, 34.46903351375035, 35.955617972782676, 32.93752895082746, 35.10664537974766, 37.916496889931814, 37.236622606004985, 36.96254743848528, 37.173619815281455, 36.27046864373343, 35.95232800074986, 35.2066091128758, 34.19554546901158, 34.730018275124685, 33.52879980632237, 34.778322151729036, 31.83998802730015, 33.93027714320591, 37.96712146486555, 43.479478291102815, 43.65185267584664, 44.87837300981794, 46.92227247783116, 48.720462799072266, 41.698352745601106, 30.560105528150284, 43.42483070918492, 46.350821358816965, 42.12933908190046, 39.472490378788535, 35.70953709738595, 31.299192360469274, 32.74153069087437, 31.102871009281703, 33.953998293195454, 33.477337973458425, 34.65988315854754, 33.34783049992153, 33.19346237182617, 33.31584446770804, 34.687939984457834, 34.6459242275783, 34.643968309674946, 35.1333646774292, 33.956649030957905, 33.38019520895821, 33.75230598449707, 33.86087506158011, 34.6515348979405, 33.60641118458339, 32.40910107748849, 32.83417102268764, 34.52462952477591, 32.91155311039516, 32.916076387677876, 33.51326363427298, 33.43494006565639, 31.21948610033308, 31.471003941127233, 31.70419590813773, 33.81641353879656, 32.94168744768415, 32.10166066033499, 32.181307860783164, 31.711498464856827, 30.73166697365897, 31.05190944671631, 32.694567816598074, 33.152422836848665, 31.25353227342878, 32.69597830091204, 34.63744395119803, 35.60024193355015, 36.74906403677804, 40.534442629132954, 42.370962687901084, 45.034759589603965, 46.62743956702096, 45.2025203704834, 45.17330319540841, 50.83394500187465, 46.97260870252337, 46.46507058824812, 48.11475706100464, 52.6031231198992, 29.803081921168737, 0.6438992800457137, 0.7629254502909524, 3.162765064409801, 2.5187137382371083, 0.5365356068525995, 15.245587962014334, 56.09870971952166, 45.12146963391985, 45.57873753138951, 29.014030592782156, 30.588190146854945, 28.00023283277239, 48.063687801361084, 4.346487752028874, 0.0889773147978953, 0.03086465470758932, 0.02465800159344716, 0.0523057031179113, 0.03900237946904131, 0.04391630293269243, 0.01413646202334868, 0.00998506264295429, 0.021442066212849956, 0.04705773686457958, 0.01954548280420048, 0.02041946813863303, 0.019611234543845057, 0.026948298161317195, 0.017671849146219235, 0.012234533455089798, 0.0511059005345617, 0.06862454156258277, 0.012774998471806092, 0.04728832681264196, 0.031297583798212666, 0.016879907177229012, 0.09449841175228357, 0.011612167565285094, 0.10478401197386639, 0.06769513179148946, 14.226663299969264, 56.97692380632673, 35.76400055204119, 32.165292263031006, 39.019360133579795, 50.63850954600743, 49.54760067803519, 51.066539423806326, 48.53719711303711, 53.84807007653372, 11.346659302711487, 1.0138081823076521, 4.4017723969050815, 29.542753764561244, 2.2667583780629292, 21.552156891141617, 41.41787828717913, 45.79866886138916, 48.86694124766758, 41.07747909000942, 46.58970390047346, 49.60700082778931, 50.917382444654194, 48.64406040736607, 49.78329747063773, 48.54048013687134, 47.63006462369646, 46.208060196467805, 47.42721543993269, 45.80464431217739, 45.32638243266514, 45.593314852033345, 47.19279711587088, 46.9888779095241, 47.212387561798096, 46.863059929439, 48.30928577695574, 48.57542610168457, 46.36863654000418, 46.723779814583914, 45.14247751235962, 44.304069655282156, 38.95752464021955, 35.82455062866211, 35.33252089364188, 33.852287088121685, 36.95504685810634, 37.44527006149292, 36.66843366622925, 36.623058455330984, 35.972665378025596, 35.4534021786281, 36.954925264631, 35.68938037327358, 36.04024703162057, 40.12645483016968, 39.535315990448, 38.87085281099592, 37.436372893197195, 37.91408239092146, 36.932333196912495, 36.787171431950156, 35.87437963485718, 36.06209911618914, 36.199617862701416, 35.3655561038426, 33.02863720485142, 35.25496857506888, 39.93333312443325, 45.55634696143014, 44.984517165592735, 46.2947632925851, 47.53533983230591, 49.67959213256836, 44.18048204694475, 34.03138732910156, 44.34963246754238, 48.486711502075195, 43.69417067936489, 41.41612734113421, 39.078023774283274, 33.604899951389854, 34.33642019544329, 33.597468852996826, 34.50812060492379, 34.428136416843955, 36.84667233058384, 34.82701512745449, 35.4678544316973, 36.74778209413801, 36.2615784236363, 35.373303345271516, 36.928549902779714, 36.479407923562185, 36.19536556516375, 34.18235431398664, 35.13460840497698, 36.117973055158345, 35.89274024963379, 34.59987851551601, 34.652969700949534, 35.10764939444405, 36.25209413255964, 34.94383519036429, 34.50979512078421, 34.52521317345755, 35.83252021244594, 33.47807100840977, 33.620036602020264, 34.40935891015189, 35.36251279285976, 34.78414821624756, 34.0801671573094, 33.89217322213309, 33.486881324223106, 31.483368260519846, 33.442058495112825, 33.13008090427944, 34.41894047600882, 34.261779172079905, 34.05898904800415, 35.23338052204677, 36.87840475354876, 39.69963046482631, 41.792806557246614, 45.757382665361675, 46.97119127001081, 49.22557599203927, 44.45463711874825, 45.989351749420166, 51.414974212646484, 49.252826826913015, 48.9186566897801, 49.17706019537789, 52.3952990259443, 32.716124602726524, 0.9947333144290107, 2.3233816368239264, 4.97539222240448, 1.3492449543305804, 0.8310852157218116, 15.721589939934866, 58.77871676853725, 49.69333566938128, 50.610980783190044, 33.81678179332188, 25.14649302618844, 30.142577852521622, 53.2581193787711, 6.973658527646746, 0.07417683755712849, 0.016877817289371575, 0.05993957830859082, 0.07492385032985892, 0.008651556430517562, 0.020654219202697277, 0.06759552963610206, 0.05449990555644035, 0.05806334077247551, 0.03304953407496214, 0.04068119724148086, 0.08868357020297221, 0.16989387784685406, 0.10768747010401317, 0.08558933516698224, 0.1402736394000905, 0.10167420455919844, 0.1122986108862928, 0.12897539351667675, 0.10954016247498137, 0.1336139403283596, 0.1534538564405271, 0.23571074328252248, 0.07175292048071112, 0.23140820701207432, 0.10655745824000665, 17.152107647487096, 67.31830992017473, 44.00497055053711, 41.29484306062971, 37.46176508494786, 55.6205346924918, 55.584796633039204, 58.386275563921245, 52.16192293167114, 59.756925855364116, 14.86406237738473, 1.3766055490289415, 7.141345918178558, 27.05829507963998, 6.7855555926050455, 26.185703822544642, 41.43693372181484, 46.248630728040425, 48.79557977403913, 41.26470177514212, 46.88591602870396, 51.971281732831685, 53.29822438103812, 50.329099314553396, 50.86338799340384, 48.357019901275635, 48.91387980324881, 48.021480969020296, 50.041106905256, 46.30698864800589, 48.71968807492937, 48.372257300785606, 50.478304931095664, 48.51906926291329, 49.80057069233486, 48.904065472739084, 49.805281570979524, 49.629189899989534, 48.05443280083792, 49.437454359872, 48.64907005855015, 46.86555085863386, 40.406071186065674, 37.49628373554775, 36.196838583265034, 36.177682399749756, 38.206809997558594, 38.91187844957624, 38.43648965018136, 38.21081215994698, 38.604107992989675, 36.48723159517561, 38.70859152930123, 37.34039395196097, 38.23004477364676, 42.29799618039812, 41.23624195371355, 40.776538712637766, 40.24583183016096, 38.96752657209124, 39.3968905040196, 39.477698053632466, 37.22303540366036, 38.9840806552342, 38.378083092825754, 37.719921929495676, 35.55943863732474, 37.10173027856009, 42.093385628291536, 49.49167810167585, 46.28665474482945, 48.93758010864258, 49.41411188670567, 51.46798896789551, 44.25255223682949, 35.88847058159964, 46.990788664136616, 50.028589725494385, 44.55476066044399, 44.30915573665074, 41.0738799231393, 35.47076572690691, 36.86431728090559, 34.80701126371111, 36.06568786076137, 36.38258130209786, 38.95958825520107, 37.01487084797451, 36.7421783719744, 37.64416224615914, 38.49385050364903, 36.82044635500227, 39.34769378389631, 38.55914619990757, 37.3088630267552, 37.66603864942278, 37.556364808763774, 37.2465237889971, 38.10753413609096, 36.805427823747905, 35.93040643419538, 35.08966398239136, 39.019592898232595, 36.42053583690098, 36.21737051010132, 37.64082363673619, 37.59257187162127, 34.754524571555, 34.6377739906311, 35.651088850838796, 38.919007301330566, 36.53048413140433, 35.61795636585781, 35.7424750328064, 34.374993119921, 33.96194008418492, 35.71538053240095, 35.50516625813076, 36.79930993488857, 35.95259550639561, 36.311077390398296, 36.133140972682405, 39.203171253204346, 41.45261928013393, 44.18008599962507, 46.93658576692854, 49.19593150275094, 49.12804760251726, 45.465106691632954, 45.40167311259678, 55.19439819880894, 51.50748947688511, 50.97551454816546, 52.850770814078196, 53.24829462596348, 34.73702205930437, 1.9735139991555894, 1.4054414417062486, 9.772323438099452, 7.6118245124816895, 1.8837235144206455, 19.251764672143118, 64.49811254228864, 53.22661624635969, 54.612823554447715, 38.91601610183716, 39.693946838378906, 36.875427450452534, 60.862446784973145, 10.077072296823774, 0.37825678288936615, 0.1590568186449153, 0.2326358397092138, 0.2519233604626996, 0.10269595616097961, 0.19425048945205553, 0.14105417180274213, 0.14138560901795114, 0.1230287668960435, 0.10747618786990643, 0.09950754046440125], [0.04728823521041444, 0.0472007041930088, 0.09923468117735215, 0.043008392543665, 0.053430581864501746, 0.015195523721299, 0.03129704436287284, 0.019558568352035115, 0.04423843064744558, 0.042187392312501154, 0.017066846967541745, 0.11789488952074732, 0.014411795418709517, 0.05339969155777778, 0.0784430925601295, 2.91748822586877, 37.0167155947004, 37.123335702078684, 22.088667256491526, 18.90025356837681, 35.64379671641758, 46.66174629756382, 50.358476298195974, 44.04776797975813, 46.77565506526402, 25.70971052987235, 0.3829428000109536, 0.22645248579127447, 2.8835430187838416, 23.835793529238018, 23.655944619859966, 38.4107917376927, 46.77747549329485, 50.29902056285313, 47.14801945005144, 38.95900460651943, 48.24554647718157, 45.70196383340018, 49.47187226159232, 46.639949798583984, 48.003182888031006, 45.450032574789866, 45.30183097294399, 44.58732339314052, 41.12542860848563, 42.28701107842581, 42.9925103187561, 43.49858583722796, 45.769698347364155, 44.57340962546212, 45.910048484802246, 45.96806246893746, 46.70040954862322, 46.36418621880667, 47.17391538619995, 42.9985100882394, 39.15552398136684, 34.49792412349156, 35.68473202841622, 31.83424186706543, 35.126843793051584, 35.3720109803336, 36.46926007952009, 36.45944574901036, 36.34247282573155, 34.226826259068076, 35.84212262289864, 35.69241326195853, 34.751866885593955, 35.494848183223176, 38.40590367998396, 37.90437923158918, 36.43317461013794, 35.82146562848772, 35.02150910241263, 35.16404792240688, 34.61436550957816, 34.285472529275076, 34.77310752868652, 34.960569926670615, 34.15613876070295, 32.721082142421174, 32.76262889589582, 36.19197831835066, 41.68464742388044, 43.12712819235665, 43.558138847351074, 43.197336265019004, 49.676260471343994, 40.450233936309814, 40.62856987544468, 46.56527056012835, 44.82034512928554, 42.62857757295881, 40.54957580566406, 35.77408586229597, 32.60911887032645, 33.08838129043579, 32.07839461735317, 32.47973299026489, 34.020867756434846, 34.73906135559082, 34.459729875837056, 33.38745955058506, 33.737860679626465, 34.81520318984985, 33.24384723390852, 34.637551648276194, 34.748069695064, 33.96766192572457, 34.30503865650722, 32.492812974112375, 32.83903476170131, 34.140807560511995, 32.850311688014436, 32.70449679238455, 33.574821199689595, 34.15854631151472, 33.417236055646626, 33.61684043066842, 32.90329170227051, 31.853352887289866, 31.15605252129691, 32.59214442116873, 32.727008955819265, 32.22226054327828, 31.90398441042219, 33.36973122188023, 34.16494907651629, 34.864990506853374, 34.05205127171108, 35.511999811444966, 35.39201136997768, 36.20795917510986, 35.46673924582345, 35.41732018334525, 33.299387659345356, 32.285225118909565, 34.38958086286272, 36.070749623434885, 39.92087500435965, 44.88199302128383, 44.72359493800572, 46.92805337905884, 45.28307431084769, 45.98356737409319, 48.20219666617257, 49.41082886287144, 50.91252217973982, 49.68696069717407, 10.81567188671657, 0.14885857302163327, 1.386046630995614, 5.285209357738495, 0.8793390435831887, 0.04956992795424802, 25.139979090009415, 53.91279949460711, 45.159128870282856, 40.91934156417847, 24.919632605143956, 26.92106815746852, 36.7242693901062, 37.64351953778948, 0.9366410544940403, 0.1126365823937314, 0.017268100454072868, 0.05536511234406914, 0.09663808372403894, 0.0367860703596047, 0.018103485627632056, 0.02376234724319407, 0.021588119179276482, 0.026191984369818653, 0.03752545639872551, 0.042056217922696044, 0.05930605051772935, 0.039263998823506494, 0.02455210772209934, 0.04940082684957555, 0.013229570285018002, 0.036418762390634844, 0.04135708936623164, 0.020417520743129507, 0.08717454903359924, 0.033401693749640665, 0.07023442696247782, 0.07187782520694391, 0.04653085442259908, 0.032485077756323984, 0.04506887608606901, 4.028336252485003, 44.61704431261335, 43.275475706372944, 22.64741359438215, 28.337706838335308, 41.31863716670445, 48.530436515808105, 52.87925148010254, 47.16585200173514, 52.490826334272114, 25.113734006881714, 0.438269134078707, 2.116654706852777, 4.805438850607191, 26.425255128315516, 25.43212478501456, 40.74603959492275, 47.045933042253765, 49.86007159096854, 48.734105587005615, 39.9671882220677, 47.502770151410786, 47.06245585850307, 50.24991416931152, 47.024633339473176, 49.669795172555105, 45.989515032087056, 46.239719663347515, 47.82699046816145, 43.86507552010672, 43.64913593019758, 44.83043738773891, 46.697731018066406, 47.61140176228115, 46.35121045793806, 48.097063473292756, 48.792793546404155, 47.22169467381069, 47.51926864896502, 47.59642492021833, 45.42942769186837, 41.518786975315635, 35.21656240735735, 36.64355911527361, 34.404811314174104, 36.225548539842876, 37.30403402873448, 38.344224521092, 37.82262325286865, 36.64007806777954, 36.548532077244346, 38.57216017586844, 36.38276195526123, 35.51901054382324, 37.60440117972237, 39.633455821446006, 38.70970671517508, 37.21389504841396, 36.91717570168631, 36.842816080365864, 36.33193588256836, 36.839814458574565, 34.38035365513393, 36.0492970602853, 37.22890663146973, 36.575261797223774, 33.81190068381173, 34.850809233529226, 37.63832228524344, 43.04376023156302, 45.89511333193098, 46.07849018914359, 45.35180589130947, 49.99325813565935, 43.55802420207432, 39.03699813570295, 48.6388909476144, 47.80444703783308, 44.16077695574079, 42.64604187011719, 37.50156089237758, 34.16424036026001, 35.3683249609811, 34.007832935878206, 34.9020174571446, 34.86191245487758, 36.04299851826259, 36.24280786514282, 35.77922058105469, 36.2172280720302, 36.04576390130179, 36.08538252966744, 36.500520024980815, 36.47987345286778, 36.66012362071446, 34.90572084699358, 36.60837343760899, 35.65878745487758, 35.564771379743306, 34.45052351270403, 34.338039125714985, 35.296313830784385, 35.56207547869001, 35.6080447605678, 34.865344864981516, 34.2808450290135, 33.78796066556658, 34.729733398982454, 33.86861188071114, 34.610477992466514, 34.455852781023296, 33.997174399239675, 34.2601671900068, 35.82998411996024, 36.57764155524117, 35.549436705453054, 37.32071665355137, 37.06788560322353, 37.46072285515921, 36.422554288591655, 36.457326548440115, 34.15463100160871, 34.24806342806135, 35.077643598829, 37.65125288282122, 42.06909820011684, 46.97186524527413, 47.37339121954781, 48.35022108895438, 45.19949790409633, 49.06707715988159, 50.97897475106375, 50.98704160962786, 51.905002866472515, 51.52779558726719, 13.185646840504237, 0.5678042375615665, 3.297674762351172, 4.915927801813398, 1.7935740032366343, 0.28171218772019657, 27.245133876800537, 57.149100167410715, 49.818076678684776, 46.690181800297324, 31.59534890311105, 28.771125044141495, 39.50110306058611, 43.36459330150059, 1.8846102782658167, 0.08900879882276058, 0.021631175618884817, 0.021184972686959163, 0.0942383903477873, 0.03268404457984226, 0.05702854772763593, 0.027113109228334258, 0.011417009867727757, 0.0519960027720247, 0.007075952316102172, 0.05093744403815695, 0.13066969545824186, 0.14728738447385176, 0.1338253989815712, 0.1507801841944456, 0.07279842759349517, 0.1189462523907423, 0.11496025270649365, 0.07698120921850204, 0.09379821111048971, 0.13822415151766368, 0.14832666942051478, 0.3080000456954752, 0.08073986574475255, 0.07541124881910426, 0.19002137067062513, 4.520339931760516, 54.19269725254604, 50.94554696764265, 29.111011811665126, 27.94215284075056, 45.43163027082171, 53.57783031463623, 58.13120371954781, 53.0535192489624, 54.52408463614327, 31.448905195508683, 0.7618411513311523, 3.4963893336909155, 4.264933271067483, 30.51587677001953, 29.912953785487584, 38.77283457347325, 48.24779421942574, 50.281170640672954, 48.29841532026018, 41.309785161699565, 48.0814335005624, 47.94887924194336, 50.68570171083723, 48.4118446622576, 50.992329188755576, 47.587388787950786, 48.491391113826204, 48.90706014633179, 45.95036540712629, 46.607477392469136, 48.2721962928772, 48.073008809770855, 49.63766322817121, 47.95823151724679, 49.773580414908274, 50.79390600749424, 49.002021176474436, 50.75792476109096, 51.06389563424246, 46.538453987666536, 43.95557233265468, 37.398581641060964, 39.34495619365147, 34.62110526221139, 38.183495317186626, 38.40391649518694, 40.47963176454817, 39.7442170551845, 37.87797955104283, 36.92239727292742, 40.279989174434114, 39.017004694257466, 37.4079304422651, 38.7930850982666, 43.57790994644165, 41.290003640311106, 39.27362946101597, 39.328565393175396, 38.258803367614746, 38.42857565198626, 38.3772736276899, 36.817166805267334, 37.4007112639291, 38.97011130196707, 37.98782014846802, 36.62344408035278, 36.24011543818882, 39.17176192147391, 44.873120171683176, 48.40313509532383, 48.73379986626761, 46.65089668546404, 51.707542010716026, 46.532759938921245, 44.7958527292524, 51.84930263246809, 49.31319277627127, 44.96454804284232, 44.45900058746338, 39.42865071977888, 37.53312655857631, 36.902532373155864, 35.03388384410313, 36.190157890319824, 37.14804002216884, 37.15804195404053, 39.049459729875835, 36.67621217455183, 36.89495536259243, 38.834583214351106, 37.33155584335327, 37.48177242279053, 37.71443632670811, 38.52657304491316, 37.49719047546387, 38.11655637196132, 36.60558720997402, 37.800270898001536, 37.44293199266706, 35.568321909223286, 37.2589819090707, 38.30828148978097, 37.233388219560894, 37.27199241093227, 36.436641761234824, 35.30130958557129, 36.537137031555176, 35.991821561540874, 36.70376525606428, 36.371815068381174, 35.07181406021118, 36.089339528764995, 37.552345275878906, 39.186141218457905, 37.19576372419085, 38.46096815381731, 38.56943995612008, 41.11802182878767, 38.76972525460379, 40.13533462796892, 36.01815523420061, 35.21237959180559, 37.277217456272666, 39.0640926361084, 43.42048808506557, 48.90259592873709, 50.41567734309605, 48.50706972394671, 45.698163168770925, 48.173038550785606, 52.86603600638253, 52.899752140045166, 54.24635819026402, 51.93108640398298, 15.378479208265032, 0.8021784839885575, 4.025882235595158, 12.766883254051208, 6.256211859839303, 0.48442699440887993, 31.18528359276908, 63.53932367052351, 53.295316559927805, 51.50645419529506, 34.51983526774815, 35.378163610185894, 45.80124316896711, 51.22106736046927, 3.3669270234448567, 0.19280477559992246, 0.06933594481753451, 0.12348261182861668, 0.19543126252080711, 0.13638176609362873, 0.11207542714795896, 0.1160837709903717, 0.07611212799591677, 0.1173631487680333, 0.09647157123046261, 0.11604390027267592], [0.047443256713449955, 0.016040028405508826, 0.017032643713589226, 0.06808511979345765, 0.002876581782142499, 0.054736768560750146, 0.05383183354777949, 0.014979206757353885, 0.023889630234667232, 0.022002152765968015, 0.04120804236403533, 0.04748752433806658, 0.07864488887467555, 0.07335696369409561, 0.04490435170009732, 0.09686478905911956, 21.366349901471818, 46.67949547086443, 26.392890419278825, 29.04349790300642, 32.506737164088655, 46.19748156411307, 47.9441614151001, 47.80046572004046, 44.546488830021445, 33.852888107299805, 0.1551026286823409, 4.132942685059138, 1.755734873669488, 2.5831402582781653, 11.413311634744916, 35.63262401308332, 57.86279133387974, 44.38714231763567, 54.52540826797485, 43.408082076481406, 46.872224603380474, 45.99760968344552, 49.09167378289359, 46.75302478245327, 49.0113456589835, 44.73717866625105, 44.57758896691458, 41.180538245609824, 39.86687013081142, 40.58288894380842, 43.69595289230347, 43.47859239578247, 42.626566069466726, 45.113274233681814, 46.80235004425049, 44.423338958195274, 46.438785552978516, 45.72686965124947, 44.06042064939226, 40.86982522691999, 34.22446039744786, 34.242810589926584, 34.46232850211007, 34.92909458705357, 37.96152469090053, 36.94599682944161, 38.69568177631923, 36.16435922895159, 34.29904236112322, 34.4693774495806, 36.25283758980887, 35.00347852706909, 34.9427547454834, 35.71210445676531, 36.21449742998396, 34.9486711365836, 34.70804807118007, 34.29247631345476, 34.71776165281023, 34.154804706573486, 35.7898200580052, 35.12247337613787, 34.51972757066999, 36.7338752746582, 34.122353145054404, 32.9296601159232, 31.79407433101109, 36.81720502035958, 39.45815971919468, 40.96818740027291, 42.0840368270874, 44.3536832673209, 46.61358833312988, 48.03935520989554, 45.5289363179888, 45.99672031402588, 47.409685134887695, 40.23948117664882, 40.219063895089285, 36.932159491947715, 33.26112045560564, 33.77525588444301, 34.831712109701975, 34.64404126576015, 34.823179721832275, 34.21728638240269, 33.62544230052403, 34.23013012749808, 34.40714243480137, 35.476171425410676, 35.01052747453962, 33.62657485689436, 33.913952350616455, 34.12002202442714, 33.770395619528635, 33.104619230542866, 35.0692640713283, 34.14479235240391, 32.18129743848528, 34.38024595805577, 33.514024462018696, 32.93809175491333, 33.175244195120676, 33.3316307749067, 33.30493927001953, 33.49681724820818, 33.77348409380232, 33.12974739074707, 32.81265245165144, 31.57734612056187, 31.920580182756694, 32.91145930971418, 35.804894174848286, 40.810074193137034, 42.24294907706124, 42.045227663857595, 41.460905006953645, 41.79386615753174, 41.3544898714338, 39.43724911553519, 38.61584350040981, 35.78186089651925, 37.40295900617327, 35.54346820286342, 36.42120633806501, 41.50737803322928, 42.98290096010481, 49.14004366738455, 45.12113264628819, 45.015287263052805, 49.22797312055315, 48.82468925203596, 47.11332362038748, 27.918614080974034, 1.7866782418319156, 0.849979213305882, 5.0072358165468485, 3.55595645734242, 1.03150209571634, 0.02247673542504864, 34.01626110076904, 50.78219829286848, 48.05987671443394, 34.39604616165161, 21.726598364966257, 18.17268511227199, 37.90837444577898, 18.577438524791173, 0.23313290732247488, 0.092738780459123, 0.05726577714085579, 0.03226092032023838, 0.044306009342627864, 0.025111161205651503, 0.014973751335803951, 0.042725148278155496, 0.09155983264957156, 0.007848374528943427, 0.010356256073074681, 0.02027225148464952, 0.01852796017192304, 0.02686948292622609, 0.07803695542471749, 0.06430597150964396, 0.03486572465460215, 0.05423579937113183, 0.04634004019732986, 0.04762343490230186, 0.023820570636806742, 0.016590715552281057, 0.016270172216796448, 0.08070711285940238, 0.037883868773600886, 0.10912439014230456, 0.023444416267531257, 0.1645151036126273, 26.824691431862966, 54.519450187683105, 22.691204616001674, 23.73936469214303, 44.292389733450754, 48.66867787497384, 52.66262749263218, 51.75266708646502, 50.270411355154856, 37.09758915219988, 0.1599953139999083, 3.186533114739827, 5.681470334529877, 5.009904359068189, 15.482120275497437, 36.24872773034232, 58.14838661466326, 45.449292591639924, 54.410717827933176, 43.89220128740583, 46.56644480569022, 46.35733182089669, 48.664592334202354, 47.8805193901062, 51.4008971623012, 46.26619577407837, 47.00126654761178, 42.89939750943865, 42.13097538266863, 42.90076977866036, 46.01443127223423, 45.49010631016323, 46.865630762917654, 46.004029818943565, 49.175177233559744, 47.336006437029155, 47.72247566495623, 48.85080058234078, 45.96630457469395, 43.72158827100481, 36.86408799035208, 36.01896817343575, 36.01044968196324, 35.498499461582725, 39.232325894492014, 38.419449193137034, 40.86840084620884, 37.66126523699079, 36.50721114022391, 36.365794454302105, 37.91093485695975, 36.57459824425833, 37.29509169714791, 36.669072900499614, 36.76912348611014, 37.635077476501465, 36.870591504233225, 35.37995971952166, 36.05308730261666, 35.53977176121303, 37.36770732062203, 35.72423948560442, 36.91193675994873, 38.31700842721121, 36.95386219024658, 34.214725971221924, 34.342847279139924, 37.662199769701274, 40.98367493493216, 43.13666459492275, 44.89099441255842, 46.65305062702724, 48.54552105494908, 49.4054023197719, 47.33338696616036, 47.61108214514596, 47.347265992845806, 42.16108887536185, 41.66105481556484, 38.432980809892925, 35.81168603897095, 35.62107610702515, 35.06515768596104, 37.06784043993269, 35.950372082846506, 36.532558168683735, 35.36684846878052, 36.71677575792585, 35.84732334954398, 35.47966636930193, 36.20460319519043, 35.437643664223806, 36.26410756792341, 36.35005331039429, 34.28026485443115, 34.876156261989046, 36.748515129089355, 35.488407203129356, 34.501429489680696, 35.56800924028669, 35.12673609597342, 34.23866598946707, 34.44871003287179, 34.41521276746477, 34.85126086643764, 36.375862394060405, 35.25942931856428, 35.319322790418354, 34.54265315192086, 33.60590396608625, 33.561289582933696, 33.86304289954049, 37.64615985325405, 41.9754364831107, 43.501302582877024, 43.40680708203997, 42.05653585706438, 43.98822886603219, 41.88218123572213, 40.87355988366263, 39.36708620616368, 37.65319837842669, 37.78658989497593, 37.709655966077534, 38.15968384061541, 44.42484671728951, 44.53611169542585, 49.60841826030186, 46.33587230954851, 45.20401423318045, 49.76569420950753, 50.9326684815543, 48.928950445992605, 33.36876194817679, 2.9677616996424536, 2.900008729525975, 3.9763146553720747, 3.252808506999697, 0.34044585323759485, 0.02335046461251165, 37.25839826038906, 55.49901417323521, 51.317800181252615, 44.28398241315569, 29.27411208833967, 19.904230049678258, 44.04138258525303, 24.215663705553325, 0.28602962461965425, 0.07418463392449276, 0.03838006107668791, 0.026151921965980103, 0.041281632879482846, 0.03843002839546118, 0.02189361091170992, 0.015135183298428143, 0.04945957441149013, 0.027909426051857214, 0.011417211731895804, 0.03490374297169702, 0.10663703004164354, 0.16943915081875666, 0.13254102718617233, 0.2328292764723301, 0.07039479871413537, 0.14018412706043037, 0.13996998140854494, 0.08952885520245348, 0.10054288990795612, 0.09291939291038684, 0.2235866388572114, 0.15710607117840222, 0.12122329377702304, 0.17985986093325274, 0.11745576879807881, 0.2004783959793193, 32.18825953347342, 61.5314610345023, 34.32742575236729, 40.82159430640084, 43.437743936266216, 54.945208004542756, 55.47986841201782, 56.882633277348106, 54.62539631979806, 42.60134758268084, 0.23896673428160803, 9.4279203414917, 6.335423060825892, 3.6853492856025696, 17.689067908695765, 37.413648809705464, 57.48120321546282, 47.24069799695696, 53.053606101444785, 45.96984815597534, 50.26864998681204, 47.91917221886771, 50.14339828491211, 48.998665196555, 53.7854494367327, 48.08259384972708, 49.94955396652222, 45.69769069126674, 44.33401639120919, 46.98586933953421, 48.97573961530413, 46.92795263017927, 47.24807698386056, 47.5751564843314, 51.429200649261475, 48.103605202266145, 48.889668805258616, 49.45804187229702, 48.2788075038365, 46.0621897152492, 36.95202439171927, 36.58120250701904, 37.63352108001709, 38.650344780513215, 40.42102370943342, 39.76048626218523, 41.88860484531948, 38.8295909336635, 37.565567697797505, 37.043466159275596, 38.837042876652305, 37.47662033353533, 40.233943462371826, 39.126626423427034, 38.75999777657645, 38.61822673252651, 38.25085810252598, 37.591352462768555, 38.267988886152, 37.71179253714425, 40.1574125289917, 37.583848408290315, 37.792620931352886, 41.06902660642351, 37.84581633976528, 37.682113306862966, 35.31231205804007, 40.371479579380576, 42.78501279013497, 46.53570597512381, 45.72663688659668, 48.712976115090505, 50.5884234564645, 52.15705919265747, 48.678082261766704, 50.17025307246617, 50.51791313716343, 43.231517927987234, 44.85191774368286, 40.435031277792795, 36.638855184827534, 39.58488096509661, 37.99233300345284, 38.166927337646484, 38.145419188908164, 38.3837319782802, 37.55462775911604, 38.85369423457554, 38.39751025608608, 38.45580564226423, 37.70207895551409, 37.69015237263271, 37.865709032331196, 38.33280168260847, 37.93931824820382, 36.00144829068865, 38.64555399758475, 37.33049624306815, 35.53694037028721, 37.32295397349766, 36.41037062236241, 35.65752635683332, 36.93958364214216, 37.32606329236712, 36.44860655920846, 37.16871438707624, 38.88248062133789, 37.3382955959865, 36.347194126674104, 35.92267656326294, 35.64366817474365, 36.52436624254499, 39.18105861118862, 45.81099843978882, 46.012496198926655, 45.78566183362688, 44.226506914411274, 45.4105737549918, 45.46558264323643, 43.278623240334646, 42.66079984392439, 40.14244958332607, 41.15317276545933, 38.81410339900425, 40.13920477458409, 45.181439535958425, 46.19135672705514, 51.9970143863133, 46.627557686397004, 44.69892535890852, 48.898944650377544, 50.49368129457746, 49.467533111572266, 34.03093917029244, 4.030279576778412, 1.9617680694375719, 10.769657441547938, 12.348033683640615, 3.8817101546696255, 0.2413379970405783, 42.63238171168736, 59.3153053011213, 57.19066776548113, 46.10748502186367, 31.59153781618391, 26.995366982051305, 50.08940730776106, 29.334915774209158, 0.5180857511503356, 0.17783117693449768, 0.16035223699041776, 0.1072824661220823, 0.12036311493388244, 0.1609629320779017, 0.13133175564663752, 0.1237571199557611, 0.20964932601366723, 0.10184246767312288, 0.18966577760875225, 0.11560187542012759], [0.02986438213182347, 0.08448740786739758, 0.0645297591441444, 0.013098303444816597, 0.03574970989887204, 0.023231156103845154, 0.045014243839042525, 0.039616935420781374, 0.009479414954382395, 0.02184270042926073, 0.021991596457415392, 0.08728597805436168, 0.027875350023220693, 0.02138810232281685, 0.13669508642383985, 0.0600186072822128, 5.837852571691785, 41.308096749441965, 39.878834928785054, 28.52495731626238, 21.966306005205425, 46.1404299054827, 47.356851032802034, 48.032559871673584, 42.20717280251639, 39.81382063456944, 0.9930263374532972, 3.552383780479431, 3.8124861206327165, 0.10834721648799521, 1.904514478785651, 41.29710122517177, 52.788966587611604, 50.0471761567252, 51.53661632537842, 54.29729543413435, 48.787467752184185, 50.61598001207624, 50.06012412479946, 47.80671909877232, 48.54914106641497, 45.280378409794395, 39.948525360652376, 39.8236905506679, 40.499368122645784, 41.4719352722168, 42.38520302091326, 41.81975861958095, 44.48397936139788, 45.52673373903547, 45.644404956272666, 44.411575657980784, 45.38820055552891, 45.08374438967024, 42.11760357448033, 36.14088126591274, 32.89953967503139, 34.95302765710013, 36.659633772713796, 37.62412016732352, 35.51107917513166, 36.05977841785976, 35.44790267944336, 35.250959464481895, 34.3456369808742, 35.29131807599749, 34.89590651648385, 36.59941373552595, 33.73003005981445, 34.75357961654663, 35.23901898520333, 32.72184297016689, 33.80100243432181, 35.08136783327375, 34.52792991910662, 34.859897477286204, 34.078628131321494, 34.48963144847325, 34.44106701442173, 36.34817729677473, 32.27500779288155, 33.39163541793823, 31.5092259815761, 35.054916041237966, 36.39724547522408, 37.864600794655935, 41.21128749847412, 44.4619049344744, 47.386710916246685, 47.284940651484895, 46.50890677315848, 46.08211367470877, 44.571738583701, 39.986858572278706, 39.82008443559919, 36.140318461826865, 34.186839376177105, 34.30146728243147, 34.40512745720999, 34.40129205158779, 35.442865235464915, 34.00760364532471, 32.412668977464946, 34.927145617348806, 35.4525579724993, 35.073822089603965, 34.18665524891445, 35.87525510787964, 33.31589657919747, 35.13628986903599, 33.70825093133109, 33.931006704057964, 34.14580678939819, 32.85804155894688, 32.978544167109895, 32.68446513584682, 33.26104749952044, 32.88941267558506, 32.52807855606079, 32.42662443433489, 32.238703455243794, 32.666306018829346, 33.05347006661551, 33.751760550907676, 33.07759421212332, 32.42907020023891, 33.98698834010533, 32.88505615506853, 38.96774196624756, 45.44348389761788, 45.82479061399187, 44.700964655194966, 43.811004638671875, 43.43872363226754, 42.10980074746268, 42.936962945120676, 46.161180700574604, 41.14515454428536, 40.07018484388079, 39.96784135273525, 41.01331942422049, 42.22271939686367, 41.714191164289204, 46.435551166534424, 44.565193380628315, 43.958018098558696, 45.17405012675694, 47.61466046742031, 43.00386714935303, 7.497779386384146, 0.3144721569759505, 0.8913455850311688, 3.153107068368367, 1.2906320137637002, 0.916069609778268, 0.3303222193249634, 40.24722146987915, 49.96989481789725, 43.09821673801967, 27.246056250163488, 17.78702882358006, 23.841143642153057, 39.69223410742623, 3.346964631761823, 0.12997248715588025, 0.022957976208999753, 0.0024780459352768958, 0.07736536860466003, 0.050567574599491696, 0.02463258706432368, 0.0595179298626525, 0.011890662933832832, 0.04266341176948377, 0.09116717800498009, 0.05424035573378205, 0.019222157475139414, 0.013508016459776886, 0.020507575910804526, 0.014641825575381517, 0.003761099252317633, 0.02978910206417952, 0.07603971473872662, 0.04457235469349793, 0.03422001037480576, 0.03145877318456769, 0.04716528466503535, 0.034930070130420585, 0.029899940759475743, 0.04198021860793233, 0.02766472427174449, 0.04846900488649096, 0.11455855997545378, 8.25693782738277, 50.75178950173514, 40.66140706198556, 30.531642232622417, 36.115895543779644, 50.495876925332205, 50.232026032039094, 51.87486505508423, 46.082468032836914, 42.0962552343096, 0.9575129002332687, 2.111509782927377, 6.748111750398364, 0.5118651592305729, 3.2127447596618106, 42.84850890295846, 53.502810614449636, 49.255640847342356, 52.28229699816023, 54.74783400126866, 51.39516142436436, 51.12686368397304, 49.938346522195, 50.87978574207851, 49.10901301247733, 47.11748906544277, 42.001134395599365, 40.076865536826, 42.0963351385934, 42.36477184295654, 43.8945324080331, 44.4593688419887, 45.186619418007986, 47.387569018772666, 48.362429073878694, 46.52922330583845, 47.29818391799927, 47.36922924859183, 44.57149887084961, 37.769938537052695, 33.622652598789756, 35.64610699244908, 37.968799454825266, 39.647987978799, 37.616220065525596, 36.45135457175118, 36.66731153215681, 35.6556955065046, 35.618064062935964, 36.31433262143816, 36.725457532065256, 37.734009402138845, 35.52371447426932, 36.72332443509783, 36.085643087114605, 34.51654182161604, 35.74643203190395, 37.03219965526036, 36.788081645965576, 36.7404065813337, 35.69334432056972, 37.26581546238491, 35.06142997741699, 37.34489985874721, 35.09611538478306, 34.54886484146118, 34.682339736393516, 36.17544160570417, 38.79842826298305, 39.754427433013916, 41.81129918779646, 45.395999908447266, 48.87697792053223, 48.51033190318516, 47.78357812336513, 49.72832679748535, 46.54220254080636, 42.85084697178432, 41.54154927389962, 37.289651257651194, 35.65595953805106, 35.900358949388774, 36.13605921609061, 36.62535483496529, 36.940830843789236, 35.59168522698538, 35.922878061022075, 37.089591775621685, 36.39637000220162, 36.543018681662424, 37.53986631120954, 36.3993820462908, 35.75765337262835, 36.42743539810181, 36.745246001652305, 34.294286319187705, 34.763376576559885, 35.390013762882774, 33.49316944394793, 34.2961345400129, 35.060061182294575, 35.252442904881065, 33.677310603005544, 34.76055213383266, 34.77570962905884, 35.50387389319283, 34.61262151173183, 34.877347878047395, 35.2880037852696, 34.64216177804129, 35.72942631585257, 34.77913161686489, 41.70328944069998, 45.6652113369533, 46.97546441214425, 46.56624330793108, 44.628863198416575, 45.68160908562796, 44.72682237625122, 46.423572472163606, 46.03939267567226, 43.831404549734934, 42.15008292879377, 42.23011922836304, 43.23210505076817, 41.70654814583914, 43.856925283159526, 48.11267607552664, 44.55653245108468, 43.25599990572248, 45.02505990437099, 46.75824982779366, 43.94155434199742, 9.922588654926844, 0.42443201371601647, 3.382970413991383, 1.8641764947346278, 0.35331945387380465, 0.5315559740577425, 0.45169226665581974, 43.65114743368966, 54.26873138972691, 48.247610092163086, 35.15131882258824, 22.29426097869873, 25.05717740740095, 45.60288599559239, 5.738419072968619, 0.18913076631724834, 0.08533405672226634, 0.024978468593742167, 0.011331779084035327, 0.03156205299975617, 0.018429776154724613, 0.005761032450079385, 0.028764612573598112, 0.05372671490269048, 0.050822147367788215, 0.030262190249881575, 0.020719368742512803, 0.24560584660087312, 0.1569339811269726, 0.09804801842463867, 0.12579150364867278, 0.20971998865050928, 0.10857928224972316, 0.17306809180549212, 0.2507775862302099, 0.09869814996740647, 0.2006295057279723, 0.1517901157162019, 0.21340333457504, 0.1217561201857669, 0.13248318886118277, 0.2107074335217476, 0.3072936635996614, 10.43589116845812, 58.81434713091169, 49.39675876072475, 38.648003237588064, 33.90534700666155, 56.94900941848755, 55.18422603607178, 57.650020122528076, 48.77564886638096, 47.98540939603533, 1.261575190084321, 7.563121114458356, 9.531988722937447, 0.5250270015427044, 4.7255675707544595, 45.58044331414359, 52.44223410742623, 51.04985332489014, 53.06856557301113, 55.25460433959961, 53.618661403656006, 53.44546365737915, 53.30407476425171, 52.38314315250942, 52.167318207877024, 50.69650615964617, 44.45477955681937, 43.03907019751412, 43.468889236450195, 44.983481884002686, 45.760582310812815, 47.45505339758736, 47.760940892355784, 49.52382741655622, 49.43772881371634, 48.65037979398455, 49.85371746335711, 49.22191081728254, 46.877175194876536, 38.900611945560996, 35.53952857426235, 38.26298270906721, 39.66273553030831, 40.70744582584926, 37.98853928702218, 38.21751022338867, 37.62210518973214, 37.68128994532994, 36.15118544442313, 38.41365439551217, 37.02144384384155, 39.51063598905291, 37.66020563670567, 37.854883738926475, 38.78566789627075, 35.025594643184114, 36.8914395741054, 40.32836948122297, 38.194007941654746, 37.92721448625837, 38.22850227355957, 38.820898737226216, 37.460358074733186, 39.87967218671526, 36.92691707611084, 37.61474009922573, 36.87067835671561, 38.85286739894322, 38.95412697110857, 41.58131381443569, 45.13693979808262, 47.93671989440918, 51.074797357831685, 51.995576109204976, 49.45637083053589, 51.42090450014387, 48.48089585985456, 44.749275479997905, 43.41349819728306, 40.317610195704866, 37.63664082118443, 37.62039940697806, 38.337898186274934, 39.97192341940743, 39.852775709969656, 37.799093178340364, 36.71682786941528, 39.20897994722639, 39.7050952230181, 40.002050808497835, 39.54290689740862, 38.96069996697562, 37.6195968900408, 39.286348138536724, 36.98772423607962, 36.194274697984966, 36.905044146946494, 37.80010066713606, 35.12905332020351, 35.90184586388724, 37.557455675942556, 37.25112349646432, 35.558160168784006, 36.35717173985073, 36.88249724251883, 36.788526330675396, 36.74903276988438, 37.41795669283186, 35.796386105673655, 36.13909905297415, 38.81266164779663, 36.730223996298655, 43.51063748768398, 48.877155099596294, 49.57854100636074, 49.24731343133109, 47.23834950583321, 47.85336930411202, 45.96458836964199, 47.8701422555106, 48.29922478539603, 45.69924013955252, 43.670765672411235, 44.51031650815691, 46.59863233566284, 45.187995161329, 46.464209011622835, 50.00307594026838, 46.08780772345406, 43.00893586022513, 44.04848364421299, 47.2777909551348, 43.79517664228167, 12.983692237309047, 0.5947114623018673, 2.01662084034511, 9.512914180755615, 6.318963212626321, 2.113332165139062, 0.6454441685761724, 50.6579714502607, 57.68523359298706, 53.18393693651472, 36.64708532605852, 26.513874190194265, 32.71565212522234, 54.01631375721523, 8.984743390764509, 0.36452421120234896, 0.12950720212289266, 0.06102487471486841, 0.17981511833412306, 0.10716237220913172, 0.10572156416518347, 0.12233894105468478, 0.21511443704366684, 0.12375572217362267, 0.26789260070238796, 0.15506514640791075, 0.10370780793683869], [0.04742357241255896, 0.0331445866530495, 0.11401052081159183, 0.01207496746376689, 0.04645193740725517, 0.00328324329789861, 0.03867075904937727, 0.03870111331343651, 0.026272394162203585, 0.04127971601805516, 0.047599031390356164, 0.020992021076381207, 0.02798741008155048, 0.033377955202013254, 0.05333673029339739, 0.03394260490313172, 0.7297281516449792, 30.87055104119437, 44.20804902485439, 23.474796397345408, 25.30690782410758, 37.10494382040841, 42.72129086085728, 49.6335186277117, 40.40718984603882, 44.999945640563965, 2.1579697813306535, 2.256501534155437, 8.137817042214529, 0.49019899325711386, 1.2769337488072259, 36.69505916322981, 56.43914018358503, 50.64570440564837, 52.4580933707101, 48.22110966273716, 49.432246685028076, 46.544544083731516, 46.53676210130964, 44.39289195196969, 42.415643078940256, 38.30682584217617, 36.97919184820992, 38.16780628476824, 41.84378549030849, 41.1213778087071, 43.64423745019095, 41.82126637867519, 43.88716384342739, 45.45644228799002, 45.08525562286377, 44.81906318664551, 44.519529819488525, 43.59361287525722, 37.43092550550188, 34.52254506519863, 38.01641893386841, 38.4293121610369, 37.85865661076137, 35.66723993846348, 34.693984917231965, 35.50756686074393, 36.819251264844624, 36.13808461597988, 35.46526970182146, 34.66196414402553, 36.32600212097168, 33.95704160417829, 35.77105644771031, 34.83095475605556, 36.13666023526873, 34.30782835824149, 34.14566782542637, 34.00332008089338, 35.83590398515974, 34.36316728591919, 35.03227186203003, 34.86848545074463, 33.86085769108364, 34.80704600470406, 33.13881131580898, 33.26298952102661, 33.09721939904349, 33.570138113839285, 35.582107135227744, 37.372650963919504, 38.89157581329346, 43.85330179759434, 47.07069642203194, 48.50802162715367, 48.026035513196675, 46.94020925249372, 46.0405912399292, 42.83805186407906, 38.45866482598441, 37.1729736328125, 35.75010068075997, 36.777437005724224, 35.569496154785156, 35.456775529044016, 33.9177634375436, 31.686599595206125, 33.394313948495046, 33.548845359257285, 34.927677154541016, 35.56113052368164, 33.500996589660645, 34.356239931924, 34.82840476717268, 32.998224939618794, 32.840167318071636, 32.04875360216413, 35.11530630929129, 34.89668818882534, 33.16779572623116, 33.169550146375386, 31.694221769060405, 33.581244809286936, 33.18520443780081, 33.47351993833269, 31.504442146846227, 30.78530011858259, 30.658238410949707, 32.012147017887656, 32.942913804735454, 34.455293451036724, 32.743997301374165, 32.27724163872855, 38.104647159576416, 46.28193344388689, 42.698837757110596, 44.05057852608817, 42.2937126159668, 43.596822943006245, 39.57293701171875, 41.61306708199637, 45.06400455747332, 44.72063500540597, 41.86764907836914, 44.828484943934846, 42.45228787830898, 46.11866119929722, 43.24429219109671, 48.61929702758789, 40.47667530604771, 47.42567988804409, 37.39921392713274, 45.746501786368235, 22.751440286636353, 0.10122717890356268, 0.05795281420328787, 4.9836349572454175, 1.8432461321353912, 0.44126448620642933, 0.4889034799167088, 2.081511152642114, 49.65739263807024, 47.88849592208862, 37.85638107572283, 24.889560801642283, 23.50355499131339, 32.13392114639282, 30.892799173082622, 0.48648697244269506, 0.07313265358763081, 0.06084304090057101, 0.05596883548423648, 0.05428333074918815, 0.011315187206491828, 0.005764756335078606, 0.020896201753722768, 0.0026015202248735087, 0.0756094828248024, 0.02856990016464676, 0.02922207409782069, 0.02243662382742124, 0.025393355438219647, 0.015910368845132843, 0.026463963257681047, 0.054020340753985305, 0.032611502400998554, 0.036682407172130685, 0.023336161094318544, 0.04158906013305698, 0.0777841264914189, 0.08638324828020164, 0.035756512212433984, 0.017991498511816775, 0.02330462957200195, 0.028013070579618216, 0.07461323056902204, 0.02090185564676566, 1.6393078182424818, 37.14938449859619, 51.89045333862305, 22.768614496503556, 28.089126348495483, 50.45134939466204, 45.27005686078753, 55.29413611548287, 43.20168236323765, 51.57108286448887, 2.5009995230606625, 1.6923790276050568, 5.968886911869049, 1.2965299487113953, 1.6673518334116255, 37.88303436551775, 55.65575163705008, 51.52666303089687, 53.26198952538626, 49.03466033935547, 51.95164264951433, 48.82633250100272, 48.76804058892386, 48.64613444464547, 44.67254999705723, 39.96228974206107, 38.17674166815621, 42.3943190574646, 43.013417448316304, 42.16792242867606, 45.01766354697091, 43.646770068577354, 44.97331666946411, 48.64335169110979, 47.59151949201311, 47.02603687558855, 46.55488300323486, 44.956366539001465, 40.123157909938264, 36.43839965547834, 38.223179953438894, 40.07837677001953, 39.446465900966096, 37.223049300057546, 36.13649000440325, 36.9203336579459, 37.334258692605154, 37.708360127040315, 35.76808956691197, 36.1094754082816, 37.62776797158377, 36.0912572315761, 35.57782704489571, 36.58276237760271, 37.98135832377842, 36.31194591522217, 35.7656820161002, 35.693663937704905, 36.44890533174787, 35.93522153581892, 36.307672773088726, 36.77127742767334, 35.79766457421439, 36.54399490356445, 36.32589094979422, 33.63415881565639, 35.10350826808384, 35.25902284894671, 38.53820085525513, 39.87638568878174, 40.805582182747976, 46.82994481495449, 48.96010269437517, 49.6982410975865, 48.36929736818586, 48.94652591432844, 46.151807580675396, 44.589657987867085, 38.315757751464844, 38.064660276685444, 36.972361768995015, 38.179729393550325, 38.37770789010184, 37.640924385615754, 37.21464892796108, 34.54850353513445, 36.013955048152376, 35.29458025523594, 35.85147489820208, 36.80867958068848, 34.87706300190517, 35.90701184953962, 36.08802284513201, 34.34522703715733, 35.092655181884766, 35.21586758749825, 36.61107281276158, 37.01676770618984, 35.17283739362444, 35.41877235685076, 34.49743774959019, 35.02085597174508, 34.68087714059012, 34.856812477111816, 34.23379877635411, 33.34965787615095, 33.268110343388145, 33.37800652640206, 33.72520453589303, 34.499018464769634, 35.345364638737266, 33.270642961774556, 40.05408239364624, 47.24626350402832, 44.128585951668875, 44.85679190499442, 43.95630189350673, 43.31509780883789, 40.712281772068565, 43.039528778621126, 47.09446273531233, 46.60748086656843, 43.34446437018258, 47.24194867270333, 43.13192592348371, 48.060575008392334, 44.7288373538426, 48.88248436791556, 40.82653794969831, 46.95599555969238, 39.06832408905029, 45.22336496625628, 25.960571765899658, 0.489236124924251, 0.038382687007210085, 1.3965906309229987, 1.1704088534627641, 0.11903037716235433, 0.24671370429652079, 1.7443258230175291, 53.992648192814414, 52.40177822113037, 46.01523378917149, 34.93181480680193, 20.532163075038365, 34.17724043982369, 40.958640575408936, 1.1776866572243827, 0.09757354602749858, 0.01827002695894667, 0.05353916443086096, 0.053485468562160215, 0.10953128045158726, 0.01586552446575037, 0.013505108089053204, 0.057510070103619776, 0.04278504934960178, 0.020401307148858905, 0.049843435242239914, 0.059385581607265134, 0.1669225322880915, 0.09080041625670024, 0.2312296980193683, 0.22295017300971917, 0.11162918859294482, 0.08182003242628914, 0.13001199146466597, 0.16129545494914055, 0.10123737728489296, 0.13147578148969583, 0.10009376757911273, 0.08204503463847296, 0.20581515532519135, 0.1390617894274848, 0.18481185021145002, 0.08237887386764799, 1.5433544984885623, 48.5442008972168, 58.070195061819895, 31.94027485166277, 33.90600708552769, 50.47986132758004, 49.73281185967581, 60.22836112976074, 47.34599099840437, 55.35311937332153, 3.0595645563943044, 5.41312004838671, 20.61651768003191, 1.3727179233516966, 2.9498034289905, 40.66710805892944, 56.083760670253206, 53.664331912994385, 53.480840410505024, 51.96340594972883, 52.63719013759068, 50.567985330309185, 49.62776551927839, 49.552426201956614, 46.2706287247794, 41.20354373114449, 39.920166288103374, 43.486975397382466, 44.984020369393484, 44.44674743924822, 46.70028795514788, 46.63846983228411, 48.496331283024375, 50.62017672402518, 48.81199141911098, 49.74013178689139, 47.935180868421284, 47.185015133449006, 41.66391052518572, 38.72371080943516, 39.588129247937886, 41.55493150438581, 40.55882038388933, 38.72933537619454, 37.6020770072937, 38.04529217311314, 39.821449756622314, 40.35427236557007, 38.617365155901226, 37.74769735336304, 39.50069311686924, 36.65058721814837, 38.37425463540213, 38.212788922446116, 39.876493385859895, 37.26875455038888, 36.6242743900844, 37.87607227052961, 38.18808807645525, 37.521960803440635, 38.06451783861433, 40.33775649751936, 36.742348602839876, 38.186924253191265, 37.96960197176252, 36.601501669202534, 37.11014454705374, 39.998656613486155, 40.57677452904837, 42.149450642721995, 42.435278688158306, 47.819750445229666, 51.582474436078755, 50.68621587753296, 48.27663271767752, 49.97836119788033, 48.50173698152815, 46.99142095020839, 41.80279459272112, 40.450980867658345, 40.494448798043386, 39.51479796000889, 39.41938877105713, 39.50943047659737, 38.87526144300188, 35.135119097573416, 37.377323627471924, 35.73502656391689, 39.08498239517212, 38.53404583249773, 35.08150332314627, 38.35771792275565, 38.36561802455357, 36.82500089917864, 36.18036787850516, 34.96207421166556, 39.09855917521885, 38.70914738518851, 36.473269190107075, 38.70502015522548, 34.21870034081595, 35.613356658390586, 37.019772802080425, 37.56498752321516, 36.720430510384695, 35.20513956887381, 35.43720245361328, 34.86871821539742, 36.51760911941528, 37.81821114676339, 35.277373041425435, 35.90645251955305, 41.876747744424, 49.950203623090474, 45.9707236289978, 45.815695422036306, 46.55333702904837, 45.765272344861714, 42.63669306891305, 44.534381593976704, 48.802493231637136, 49.286105224064414, 45.22696760722569, 48.72209562574114, 45.55986622401646, 49.60440220151629, 46.63998801367623, 51.275978973933626, 40.81124496459961, 46.1332802091326, 40.702814851488384, 46.36266108921596, 28.15555807522365, 0.8255603121859687, 0.09657087483044181, 11.713696156229291, 8.495602369308472, 0.6745049549000603, 0.9614871612616948, 2.238734556095941, 59.64755426134382, 56.527809619903564, 47.65873983928135, 34.07136378969465, 32.00502511433193, 41.82872526986258, 49.0038172858102, 2.2199223084109168, 0.1808866336941719, 0.1373833380639553, 0.1484926933688777, 0.09811842321817364, 0.2612020011459078, 0.050421333339597495, 0.08928224164992571, 0.10930994911385433, 0.14422995996262344, 0.10113241470285825, 0.18553200656814234, 0.1606305856257677], [0.022224983666092157, 0.06188002561352082, 0.05217430820422513, 0.006609909444315625, 0.06432011896478278, 0.021536297763564756, 0.013632398714045329, 0.028987457044422626, 0.007811242548216666, 0.034636094833591154, 0.0298380617584501, 0.013268150938009577, 0.020720542608095065, 0.05863537971994706, 0.07681911398789712, 0.07136520557105541, 0.10217798966914415, 15.112731456756592, 50.600958006722585, 36.93195799418858, 29.95942681176322, 33.374786036355154, 33.67645250047956, 53.02995443344116, 39.76849058696202, 45.8974791935512, 5.611845910549164, 1.3089683098452431, 2.9343104660511017, 1.2769516621317183, 0.35699168539472986, 32.09156492778233, 57.134435994284495, 50.97988496507917, 52.43450076239449, 49.19363512311663, 45.16222776685442, 43.755429472242085, 41.84296212877546, 39.36234406062535, 37.86308608736311, 36.890963622501914, 40.44354282106672, 41.77470997401646, 43.58025843756539, 46.55789157322475, 45.166605131966726, 45.140594550541465, 47.19675064086914, 44.82052230834961, 43.741255147116526, 44.247216020311626, 43.02714014053345, 39.52064486912319, 35.797035762241904, 37.257991790771484, 38.80395902906145, 36.072823660714285, 34.7370012147086, 35.78052684238979, 35.17173263004848, 35.3893780027117, 34.3621563230242, 33.8491256577628, 34.36845486504691, 33.27199786049979, 34.4903610093253, 36.486095564705984, 34.63768713814871, 34.29315376281738, 35.8453048978533, 35.01343876974923, 35.19034685407366, 35.47514656611851, 34.86495923995972, 34.928868770599365, 33.99307843617031, 34.23438589913504, 37.054023947034565, 35.654569898332866, 33.923968178885325, 31.260230336870464, 33.22696311133248, 32.07403809683663, 31.83629505974906, 34.800212451389854, 39.651559352874756, 45.16250569479806, 45.69872944695609, 48.241110052381245, 49.38227524076189, 49.92356422969273, 44.82455573763166, 39.92914683478219, 38.497234276362825, 39.624065331050325, 39.29964351654053, 38.982402665274485, 38.00265802655901, 36.17945071629116, 34.20986918040684, 33.280099460056846, 35.03857387815203, 34.56833021981375, 34.22809083121163, 34.76058340072632, 35.90239477157593, 33.712923594883506, 33.50183732169015, 34.85870933532715, 34.653466497148784, 34.65352208273751, 33.63372107914516, 34.03140122549874, 32.52515683855329, 33.5693599155971, 32.4934070450919, 32.553071226392476, 34.60117782865252, 33.15760619299752, 32.31706871305193, 32.44068758828299, 31.336097717285156, 32.58558532169887, 32.381214482443674, 32.619947637830464, 33.588609899793354, 33.436201163700645, 32.54592153004238, 40.47708177566528, 41.86040905543736, 43.00961330958775, 42.713293484279085, 43.962485790252686, 42.19193540300642, 42.22147566931588, 42.919828687395366, 43.226980754307334, 45.125930377415244, 45.79826239177159, 44.6958646774292, 45.23905052457537, 43.81139373779297, 43.31590379987444, 43.29634462084089, 46.14274018151419, 45.853434562683105, 47.56084666933332, 5.462353680815015, 0.1748569001044546, 1.0889987647533417, 4.331104006086077, 0.6626873718840736, 0.1487288914088692, 0.271444351545402, 5.703079232147761, 53.69525834492275, 41.87509407315935, 30.433026450020925, 20.91766129221235, 26.504417691911968, 41.069895131247385, 15.095965453556605, 0.1355246135166713, 0.10335530899465084, 0.022764585246997218, 0.04219261024679456, 0.0667849788442254, 0.07770254622612681, 0.0556026945954987, 0.038614264223724604, 0.030672608941261257, 0.06786874176136085, 0.05978744397205966, 0.024042086875332252, 0.002017974171654454, 0.055166461039334536, 0.027606014029255936, 0.05225552206060716, 0.06640284827777318, 0.02509091541703258, 0.045800615035529645, 0.03603986165087138, 0.050996388375226936, 0.031566405801900795, 0.05354467413521238, 0.012007803523114749, 0.07456585525402001, 0.0036913505173288286, 0.01916147269574659, 0.025934040978817, 0.09710697856332574, 0.09911705713186945, 21.76673810822623, 56.23061779567173, 34.28707408905029, 30.852565629141672, 40.17133671896798, 38.24783911023821, 57.803985255105154, 44.213215010506765, 51.410395349775044, 5.248322239943913, 1.0600333533116748, 3.945737370422908, 2.542377782719476, 0.5529248874102319, 33.93318496431623, 56.14633614676339, 51.63220616749355, 55.500431605747764, 50.429222856249126, 47.271770341055735, 45.70481606892177, 43.82990026473999, 41.73216962814331, 39.211915561131065, 38.698280402592246, 42.572557721819194, 43.726281779153005, 45.25368343080793, 48.23833772114345, 45.702245235443115, 46.1225209236145, 48.672141551971436, 45.19628436224801, 46.55970505305699, 46.32737118857247, 45.30078526905605, 42.42741680145264, 37.2499075617109, 37.95745652062552, 40.129161153520855, 37.66519791739327, 36.90893166405814, 37.76851068224226, 37.348408699035645, 38.390655858176096, 35.77939428601946, 35.693431173052105, 36.28109243937901, 35.21397420338222, 36.570349420819966, 37.995775835854666, 35.70809882027762, 35.12771231787545, 37.17702790669033, 38.081912653786794, 37.07470178604126, 37.13995926720755, 36.76123380661011, 37.021770409175325, 36.87405865533011, 36.570286887032644, 37.19413784572056, 34.85130255562918, 35.916728905269075, 34.03913457053048, 33.192076206207275, 33.32653079714094, 34.978020327431814, 38.15073108673096, 40.54220724105835, 46.56236621311733, 48.83879409517561, 48.51157910483224, 51.301259994506836, 50.786780629839214, 45.71961920601981, 42.17393262045724, 40.09939507075718, 40.564378942762104, 41.30986854008266, 41.00922346115112, 38.10351112910679, 37.96855974197388, 36.324452672685894, 35.07722323281424, 35.82152468817574, 34.99842023849487, 35.57395689828055, 36.618934699467246, 35.74350684029715, 36.25353935786656, 35.6378664289202, 36.174263886043, 35.805630683898926, 36.20554467609951, 35.62570013318743, 35.1724066053118, 33.87040799004691, 35.31380244663784, 34.24406473977225, 33.58224534988403, 36.35226283754621, 34.581274713788716, 34.71614967073713, 33.82850340434483, 33.893371786390034, 34.10515635354178, 32.77073744365147, 34.7728157043457, 34.96934897559029, 34.57132141930716, 35.60533148901803, 41.63112892423357, 43.75081934247698, 45.406040055411204, 45.4768248285566, 44.81128815242222, 44.51006637300764, 44.25610971450806, 42.90171820776803, 44.79154484612601, 46.87059872491019, 47.734513419015066, 47.18418829781668, 46.63899094717843, 45.36287784576416, 45.88186311721802, 43.989086968558176, 46.304136412484304, 44.08063643319266, 47.48057413101196, 7.377432244164603, 0.14613311498292855, 1.045543970806258, 0.6610584535769054, 0.3760956217135702, 0.13547072426549026, 0.603810996881553, 5.515425324440002, 60.02616160256522, 46.37636293683733, 38.38987071173531, 29.978680270058767, 25.8139317716871, 44.62432255063738, 20.047567912510463, 0.18525227372135433, 0.04232704499736428, 0.018517088344586746, 0.02128360284093235, 0.0599397886544466, 0.08727128777120795, 0.035933599674275944, 0.06898459938487836, 0.025158105650916696, 0.034223613395754776, 0.009576446310217892, 0.0011585337654521155, 0.0456517851645393, 0.1300791528608118, 0.16912179999053478, 0.20068519988230296, 0.15280516339199884, 0.08557953712131296, 0.10359761384981019, 0.18722309225371905, 0.14283064433506557, 0.1381563658693007, 0.16182278522423335, 0.11536267825535365, 0.180930263495871, 0.1092030798484172, 0.32271985869322506, 0.10983218359095709, 0.20546376918043407, 0.16182575720761502, 25.087360382080078, 64.43076365334647, 46.61789969035557, 39.57517780576433, 43.415301254817415, 41.49772351128714, 62.32108211517334, 47.56082929883684, 56.25083705357143, 7.193439168589456, 2.304109505244664, 10.612726296697344, 3.9026094675064087, 1.3646617042166846, 35.86047281537737, 57.31124332972935, 54.578874656132285, 57.000019618443076, 52.38106911523001, 49.37073080880301, 47.28840780258179, 44.73377057484218, 43.37180553163801, 41.28852367401123, 40.26219483784267, 45.8104703766959, 46.46398319516863, 46.78332935060774, 50.932018824986045, 49.09123952048165, 47.91522911616734, 51.208484172821045, 48.62852076121739, 48.72033078329903, 46.94287388665335, 48.3402921131679, 43.527139459337505, 39.673501764025005, 40.26468229293823, 43.00179658617292, 37.891945430210654, 38.97257096426827, 39.517174243927, 38.77972718647548, 41.575786522456575, 36.52471365247454, 36.401313645499094, 38.79709073475429, 36.319283212934224, 39.41114820752825, 41.02804265703474, 37.96276841844831, 36.30781173706055, 37.922038078308105, 39.8067751611982, 39.22069461005074, 39.15357501166207, 38.27563190460205, 38.86311946596418, 37.53981072562081, 39.70673847198486, 40.73738213947841, 38.03772211074829, 36.98078645978655, 35.81561524527413, 36.567080293382915, 36.58559029442923, 35.95256771360125, 41.02332483019148, 43.35816274370466, 48.8154307774135, 49.39430604662214, 50.24257687159947, 53.33289589200701, 51.50594697679792, 48.68412372044155, 44.64784915106637, 42.72223234176636, 42.391699586595806, 42.82674019677298, 43.061335699898855, 40.86782414572579, 38.73309782573155, 37.17751775469099, 37.21926253182547, 38.8762480872018, 37.18184300831386, 36.679519517081125, 37.86492041179112, 38.42735276903425, 37.49698897770473, 37.097603048597065, 39.75368397576468, 37.817161968776155, 38.30159384863717, 37.26356772014073, 35.663057122911724, 35.18066453933716, 36.48269442149571, 35.28622852052961, 35.58990996224539, 39.39916951315743, 37.30818557739258, 35.52223450796944, 36.08228015899658, 35.018316405160085, 36.74874789374215, 34.919377531324116, 37.70693574632917, 37.176604066576274, 36.978698526109966, 35.447444098336355, 44.240709032331196, 46.114540917532786, 46.81554467337472, 46.54225812639509, 46.47870295388358, 44.68675906317574, 44.44405501229422, 44.90856293269566, 45.919984408787315, 47.18568216051374, 49.25901767185756, 47.73694181442261, 48.351916449410574, 47.60131992612566, 46.32297992706299, 45.48403705869402, 46.991712774549214, 45.96123586382185, 48.86265768323626, 10.187903012548174, 0.5651599051696914, 3.9827491215297153, 13.13550169127328, 1.8320742973259516, 0.2846550483788763, 1.0531559394938605, 7.03239642722266, 64.61811488015312, 49.8080677986145, 38.86148663929531, 29.710076808929443, 34.86563321522304, 54.32158286230904, 28.26428348677499, 0.2218430752732924, 0.23318007907697133, 0.06569050864449569, 0.057464784676475186, 0.20979544174458298, 0.19566841050982475, 0.10688240866043738, 0.25454752679382053, 0.09241697165582861, 0.17521592655352183, 0.1404986416122743, 0.1849861251456397, 0.13188648516578333], [0.08487964182027749, 0.08046398697687046, 0.05915894412568637, 0.06048314592667988, 0.06749112345278263, 0.0165518863858389, 0.04017761569204075, 0.03351756717477526, 0.05135732490037169, 0.04148911531748516, 0.042354583341096125, 0.023856660218111107, 0.042172600249094624, 0.01722768012301198, 0.024340883163469176, 0.0940503818648202, 0.019041938574186394, 2.6780202984809875, 38.79963377543858, 38.11089359010969, 27.975818599973405, 41.42601810182844, 31.546708038875035, 53.10479000636509, 38.94036258969988, 52.22784743990217, 11.409177456583295, 1.0316860058477946, 1.773410330925669, 1.3759827081646239, 0.09675139228680305, 19.838243007659912, 60.921298027038574, 50.20269768578665, 52.4068260874067, 47.78984192439488, 46.85262026105608, 42.08613518306187, 41.79436295373099, 39.555431025368826, 43.03971985408238, 42.04949385779244, 43.49627208709717, 45.19495030811855, 45.31169046674456, 46.1430459022522, 47.00966691970825, 45.291877678462434, 46.38116066796439, 46.65279701777867, 46.87561879839216, 45.72126245498657, 44.20039211000715, 36.38398136411394, 35.920963832310264, 35.49239894321987, 35.18174498421805, 34.142353534698486, 35.5512432370867, 34.26174790518624, 36.200295312064036, 34.840355668749126, 35.73153509412493, 35.00390236718314, 34.9242308480399, 35.12497125353132, 34.828505516052246, 34.74162524087088, 35.443740708487375, 36.565089634486604, 35.284925733293804, 35.29759924752371, 35.97464561462402, 34.73300947461809, 36.089356899261475, 36.229887689862935, 33.42206505366734, 32.80741350991385, 34.914795194353374, 34.79187808718, 34.2122037751334, 32.19483600343977, 32.96322686331612, 34.89632340839931, 33.43876157488142, 36.2164602960859, 40.65501471928188, 45.74742589678083, 47.37111568450928, 48.20559433528355, 45.25936358315604, 51.27767433438982, 46.99311283656529, 40.11865200315203, 39.52310800552368, 42.02797876085554, 41.44352756227766, 39.181096826280864, 40.90140131541661, 38.56455189841134, 37.10787943431309, 35.14472845622471, 33.619873319353374, 35.804369585854666, 34.43945503234863, 34.18674904959542, 36.74632297243391, 34.12531655175345, 33.71959733963013, 35.40917689459664, 35.09724794115339, 35.11361789703369, 34.85986968449184, 35.06648131779262, 33.079570974622456, 34.32946504865374, 33.433244705200195, 33.33753326960972, 34.35338074820382, 31.913684095655167, 32.53065286363874, 32.05452060699463, 32.80738919121878, 31.898794106074742, 31.183112280709402, 32.87358815329415, 31.85682351248605, 31.955404554094585, 32.91492646081107, 34.599864619118826, 41.3743235043117, 41.33549697058541, 43.13944387435913, 44.530633040836875, 43.64124277659825, 42.37102174758911, 41.98288842609951, 41.14582504544939, 40.93738603591919, 44.08984627042498, 44.908344064440044, 44.086250577654155, 41.13062586103167, 42.1046347618103, 42.042465754917686, 47.679476737976074, 42.91550690787179, 38.17942714691162, 2.2009061745234897, 0.1793330599154745, 2.693589908736093, 0.5005398126585143, 0.11972975677677564, 0.08292496563600642, 0.20858273681785378, 7.033997118473053, 55.7734124319894, 35.74540369851248, 27.31011516707284, 23.33023738861084, 26.215737410954066, 32.519223076956614, 2.260341933795384, 0.18452200719288417, 0.21841351501643658, 0.04355940369090863, 0.03817442086126123, 0.09922174151454653, 0.0685181879837598, 0.022138273676059077, 0.0303574124617236, 0.023607632777254497, 0.039292025712451766, 0.05694675033113786, 0.08294500277510711, 0.04997520335018635, 0.08169491056885038, 0.051507664511778524, 0.07092613234583821, 0.03373620133580906, 0.041353930785719833, 0.03573757430006351, 0.024000105913728476, 0.05019257204341037, 0.039975188339927366, 0.0255479308044804, 0.056896481064281294, 0.00854036828968674, 0.06347725633531809, 0.10327641572803259, 0.008915151170055782, 0.049370933989329, 0.026149994926527143, 4.878588616847992, 47.440451758248464, 43.87813465935843, 29.135222809655325, 50.017031397138325, 37.473351206098286, 57.72333403996059, 42.355238914489746, 57.30168955666678, 11.910818287304469, 0.5537123137286731, 3.384540055479322, 2.4749941527843475, 0.06934852485678025, 21.120612961905344, 60.45196805681501, 51.5794415473938, 55.07402065822056, 48.18501724515642, 49.68761035374233, 42.97649472100394, 44.72303213391985, 40.6523813520159, 44.24413102013724, 44.33580207824707, 45.42398030417306, 46.95891727719988, 47.65877110617501, 47.03985684258597, 48.653471742357524, 48.06458759307861, 47.417487961905344, 47.10642058508736, 49.47352245875767, 47.58666270119803, 45.74272196633475, 39.29094784600394, 36.89771727153233, 37.089317321777344, 36.70908062798636, 34.79055445534842, 36.54222311292376, 36.916845662253245, 37.622994559151785, 36.080035890851704, 37.3585878099714, 36.33729641778128, 37.286288329533164, 35.5910598891122, 36.36911916732788, 37.94192729677473, 37.9538573537554, 37.35754905428205, 37.24556841169085, 35.38395840781075, 37.73927961077009, 37.698722975594656, 38.70735822405134, 37.70546620232718, 36.76084123338972, 34.53350584847586, 38.04775530951363, 37.426572459084646, 36.36278935841152, 34.47556482042585, 35.338437284742085, 35.33507783072335, 36.41180542537144, 38.146843569619314, 42.21751519611904, 47.464454310280935, 50.02916642597744, 49.136906555720735, 49.948393617357524, 52.516378334590364, 48.1916423525129, 43.864307744162424, 41.29371050425938, 44.233236244746614, 41.74601738793509, 42.27639423097883, 42.23234265191214, 40.12103870936802, 40.162495136260986, 36.19922181538173, 36.04238707678658, 36.14111750466483, 37.24039200374058, 37.076164381844656, 36.821283612932476, 36.4956910269601, 34.839789390563965, 37.074010440281455, 36.36551652635847, 36.076158796037944, 35.91136837005615, 36.3272944859096, 34.528603894369944, 35.19153847013201, 33.9862414087568, 34.92320251464844, 35.98143400464739, 33.293193340301514, 33.646491868155344, 33.38614981515067, 34.80897760391235, 33.278358936309814, 33.840892042432515, 33.99921022142683, 33.64380291530064, 33.97673627308437, 33.68894188744681, 36.9343238558088, 42.57512508119856, 43.99966212681362, 45.32263387952532, 46.7611472266061, 44.243828773498535, 45.26476580756051, 42.91565976824079, 42.93145649773734, 42.17984553745815, 45.69968135016305, 45.65582432065691, 45.223260743277415, 43.202842712402344, 44.05345160620553, 41.4435727255685, 47.2072319984436, 44.12114790507725, 40.9918703351702, 2.7606691207204546, 0.7812627234629222, 6.249426943915231, 0.0635940186413271, 0.11057559334273849, 0.10859023380492415, 0.19623656145163945, 7.119855139936719, 60.49656159537179, 37.6070727620806, 33.09441580091204, 23.078964471817017, 24.89481016567775, 42.375562395368306, 4.076674001557486, 0.2396651639470032, 0.18458492095981324, 0.09191458432802133, 0.08097837758915764, 0.08299125172197819, 0.08644920866936445, 0.031836377922445536, 0.03949353025693979, 0.02399366831273905, 0.04938586175973926, 0.06700192684573786, 0.015219548949971795, 0.06926595393036093, 0.20389752036758832, 0.15024965123406478, 0.20008481852710247, 0.1288955570863826, 0.17125197925737926, 0.17008336553616182, 0.09024891656424318, 0.17807479814759322, 0.1347795549247946, 0.0893325957336596, 0.1049272371456027, 0.17276929212468012, 0.1457783497337784, 0.17017584985920362, 0.0856737924207534, 0.257788997143507, 0.16868789041680948, 5.337544058050428, 54.66673810141427, 48.324297360011506, 36.94752195903233, 52.56732252665928, 41.25477974755423, 63.39912986755371, 48.09237691334316, 60.667883328029085, 15.11910469191415, 1.662439457007817, 9.808548739978246, 5.0447856187820435, 0.2765070641679423, 24.207480464662822, 62.31325149536133, 55.03739322934832, 55.47141592843192, 50.300278186798096, 52.0940876688276, 44.82113374982561, 46.87472595487322, 42.980326652526855, 47.61737721306937, 47.71921001161848, 47.978735651288716, 50.95330810546875, 50.98528718948364, 49.13865402766636, 51.500940799713135, 49.28123106275286, 49.97396298817226, 50.950869287763325, 50.86566700254168, 50.649115971156526, 48.29311384473528, 39.28386763163975, 38.915686062404085, 38.691627502441406, 39.54301459448678, 38.2032698903765, 37.8041410446167, 38.72948128836495, 41.0221505846296, 38.5127009664263, 39.825052397591726, 38.57819468634469, 38.63315841129848, 37.444380692073274, 39.000992570604595, 38.898433685302734, 37.5842409815107, 39.20269530160086, 38.43619782584054, 37.49029438836234, 39.18399769919259, 38.27701807022095, 41.44332259041922, 39.258909702301025, 38.0951246534075, 35.63630655833653, 40.808754035404746, 39.473932129996165, 38.847489493233816, 36.2616548538208, 37.55477714538574, 38.86687844140189, 37.78149686540876, 40.641281604766846, 44.277082851954866, 49.60201549530029, 50.978644711630686, 51.337592124938965, 50.72003623417446, 53.70227255140032, 48.75182349341256, 43.654034410204204, 44.81579753330776, 46.24866199493408, 43.20436784199306, 43.28521013259888, 45.099753039223806, 41.74066727502005, 41.40963772365025, 39.03607749938965, 36.905002457754954, 37.90376779011318, 37.67798955099923, 38.180674348558696, 39.03229420525687, 37.37453392573765, 36.47303989955357, 40.54196058000837, 38.16690649305071, 38.79157386507307, 38.06963171277727, 38.02812317439488, 37.69197627476284, 37.598436151232036, 35.89106920787266, 37.74732909883772, 37.46223061425345, 35.43376309531075, 36.14969505582537, 35.54046310697283, 37.14368002755301, 35.648052488054546, 35.43302658626011, 36.27518647057669, 35.53560284205845, 36.3977700642177, 36.73046023505074, 38.67038685934884, 44.45885467529297, 45.94646399361746, 46.7998799596514, 48.498071806771414, 46.109222071511404, 46.28542143957955, 45.59209196908133, 46.30025584357125, 43.041304043361116, 45.52495500019619, 46.296462127140586, 48.303939138139995, 42.37818186623709, 44.286806855882915, 42.55821316582816, 47.90642922265189, 43.02852978025164, 42.07514313289097, 4.495345524379185, 0.8831839486956596, 7.478664023535592, 2.964020528963634, 0.7377349734306335, 0.3944939358958176, 0.5540195543851171, 8.509061898503985, 65.53813975197929, 42.9450923374721, 36.895021370479036, 31.99692698887416, 33.86122247150966, 49.45416477748326, 7.334619181496756, 0.5269675574132374, 0.3549365656716483, 0.20702692387359484, 0.14529995540423052, 0.3297977117555482, 0.17343763554734842, 0.16200547399265425, 0.14490645937621593, 0.09638024041695253, 0.1976895627698728, 0.13514574670365878, 0.19540950868810925, 0.13983694783278874], [0.025274964648165872, 0.036880651355854104, 0.03583726805767842, 0.028034347741465484, 0.01862208654970995, 0.052060962322035005, 0.07930979212479931, 0.04205119337088295, 0.018535188266209195, 0.03376678290909954, 0.034047784616372416, 0.06095703478370394, 0.0010916401785964678, 0.024162603176331947, 0.018277299158009033, 0.03342950350737997, 0.009582445407951517, 0.3557402496891362, 23.512299299240112, 46.82665484292166, 25.01910822732108, 21.680844477244786, 30.41431495121547, 43.26980250222342, 42.75018841879708, 50.99783911023821, 18.502298968178884, 0.33303193535123554, 2.103627485888345, 1.8844634975705827, 0.059005744489175935, 9.90299039227622, 57.410126617976594, 50.285457679203574, 53.84973417009626, 47.6235020501273, 43.99350949696132, 42.67078440529959, 45.33268444878714, 45.101038455963135, 46.92753226416451, 47.630839347839355, 48.117574555533274, 46.345057828085764, 47.95884990692139, 47.4337397984096, 47.470527035849436, 47.19911650248936, 48.91218096869332, 47.04270907810756, 46.6619929586138, 44.3785126549857, 40.44351850237165, 33.29756375721523, 37.03455509458269, 35.71079124723162, 35.86800466264997, 34.62357882090977, 34.65862553460257, 33.97552381243025, 36.56951911108834, 34.44834525244576, 35.11315931592669, 33.76418045588902, 35.024774755750386, 34.41120365687779, 35.693670885903494, 35.460871492113384, 36.10937465940203, 34.64713321413313, 37.76055499485561, 33.99564232145037, 35.58993428094046, 36.04711880002703, 35.72675125939505, 37.16315582820347, 36.029852526528494, 33.519954749516074, 35.07822377341134, 33.93996293204171, 34.92868116923741, 33.64554691314697, 34.568323271615164, 32.77315889086042, 31.666637420654297, 34.27957698277065, 38.35131515775408, 46.176821095602854, 47.63651950018746, 47.538303239004954, 47.369680881500244, 46.53399324417114, 49.35622991834368, 42.68170002528599, 42.57829345975603, 43.61621536527361, 48.37213223321097, 42.77041809899466, 42.592950684683665, 40.233297279902864, 41.594543184552876, 35.9831988470895, 33.28380632400513, 35.34289802823748, 33.536498410361155, 35.626923016139436, 36.26473637989589, 34.868078981127056, 33.86203193664551, 33.78798498426165, 34.74931342261178, 34.37711579459054, 33.57269157682146, 33.07725722449166, 33.23848669869559, 33.39223643711635, 34.34221499306815, 33.56230749402727, 33.91832276753017, 32.84065021787371, 32.85082238061087, 32.61164454051426, 31.408185277666362, 32.43709536961147, 32.238814626421245, 31.983940805707658, 32.70815849304199, 31.47377974646432, 31.783110073634557, 33.05697890690395, 36.31914077486311, 39.78681993484497, 43.08873244694301, 42.88190541948591, 43.86268881389073, 42.80747979027884, 41.517647470746724, 41.39506040300642, 42.64183126177107, 40.384531770433696, 40.15012386866978, 42.531097820826936, 44.29068742479597, 42.462616375514436, 43.32313687460763, 43.780957153865266, 45.49729074750628, 27.7096973827907, 0.961004804287638, 0.04801413197336452, 0.866154565342835, 0.15771851688623428, 0.16564775497785636, 0.1562680397182703, 0.2946415367935385, 12.044659699712481, 54.452872548784526, 37.29974351610456, 29.562226091112407, 28.017089162554058, 36.616353443690706, 19.64574316569737, 0.5012212789484433, 0.045906239189207554, 0.08836921849953276, 0.0849961598536798, 0.026161916786804795, 0.020149326384333626, 0.08727214272533144, 0.10886783605175358, 0.02863900556362101, 0.049549487086811235, 0.031165113406521932, 0.04739673974524651, 0.05217604186119778, 0.032233724636690955, 0.00903936124606324, 0.026526162866503, 0.06407819408923388, 0.017835150472819805, 0.05524347137127604, 0.07010961723114763, 0.024830603938815848, 0.03441693141524281, 0.03160351827474577, 0.09660310524382762, 0.07226770464330912, 0.013799269134843988, 0.014129289060032793, 0.03765837462352855, 0.016421597484233122, 0.029566596860864332, 0.028459285385906696, 0.6783478515488761, 30.801333086831228, 51.969402245112825, 27.033719301223755, 32.7347457749503, 35.38512223107474, 49.29562078203474, 45.29972914287022, 56.18062898090908, 20.081059966768535, 0.2994158448917525, 1.4489067665168216, 1.8680648803710938, 0.12046290029372488, 11.442406347819738, 58.45898151397705, 51.25261218207223, 55.62118782315935, 48.098863056727815, 47.673251152038574, 46.27917153494698, 46.49322468893868, 45.87645047051566, 49.055477142333984, 48.18241514478411, 48.71132244382586, 48.974297864096506, 49.04917165211269, 48.72666754041399, 48.77681268964495, 46.945656640189036, 49.293713501521516, 48.54624366760254, 48.273325375148225, 45.57511057172503, 42.54533120564052, 35.91534621374947, 37.40838554927281, 36.10494518280029, 36.41502244131905, 36.00616264343262, 36.77742658342634, 35.520393235342844, 37.31333419254848, 37.11287171500069, 36.49834871292114, 36.19737012045724, 36.3769463130406, 36.674923283713206, 37.089463233947754, 37.238929407937185, 38.32856675556728, 36.8736070224217, 37.36044645309448, 34.56028767994472, 36.70958437238421, 36.68766975402832, 37.79807179314749, 37.09269067219326, 36.94454118183681, 36.31237670353481, 37.59905801500593, 36.04276922770909, 38.27192851475307, 34.99308054787772, 36.818136078970774, 34.45876407623291, 35.186792850494385, 36.44995450973511, 38.84733315876552, 48.360271658216206, 49.37267630440848, 50.027106285095215, 48.85068941116333, 51.186711992536274, 50.90937464577811, 44.93006760733468, 45.198580741882324, 43.35342754636492, 48.52374540056501, 43.09460367475237, 44.203671659742085, 41.769158363342285, 42.618582589285715, 36.603207451956614, 33.340958731515066, 36.559961863926475, 35.42932319641113, 36.6069073677063, 36.44832863126482, 36.70488739013672, 35.76912832260132, 36.18390103748867, 35.62414721080235, 36.896223408835276, 35.14300530297415, 34.46826226370675, 34.99677351542881, 34.11824675968715, 35.678742681230815, 35.27846390860421, 35.614558696746826, 33.462732860020225, 34.64883552278791, 33.926118646349224, 33.819682666233604, 32.53593349456787, 33.69791201182774, 33.49335009711129, 32.97913128989083, 33.18294974735805, 33.16114282608032, 34.312890120915, 38.19890989576067, 41.965993881225586, 42.56259053094046, 45.42137820380074, 46.0454341343471, 44.395685127803254, 44.010831356048584, 43.740508215767996, 45.79624741418021, 42.57814754758562, 42.166609219142366, 45.34333603722708, 44.906329086848665, 43.29846034731184, 44.818958963666645, 44.55681037902832, 46.405461992536274, 29.665351254599436, 1.462872645684651, 0.6529368779488972, 2.8229375737054005, 0.08659606400345053, 0.13719318541032927, 0.209138280579022, 0.4527855765606676, 12.501701780727931, 59.177369662693565, 42.0738125528608, 39.80369710922241, 22.21966164452689, 38.32144832611084, 29.06029691014971, 0.8504052790147918, 0.02889478612425072, 0.01204181254641818, 0.035640062032533545, 0.01230178730163191, 0.038085777046425004, 0.010246033996476658, 0.03958863711782864, 0.029619505628943443, 0.03834286378696561, 0.06924249697476625, 0.04250339285603591, 0.06861591059714556, 0.030282332561910152, 0.15897593727069242, 0.11657740521643843, 0.1507234043840851, 0.0660624069028667, 0.2205218318849802, 0.14641332280422958, 0.14677738398313522, 0.11217998260898249, 0.13167551505778516, 0.2583246598286288, 0.08332165756395885, 0.20027448263551506, 0.08356647978403739, 0.14289788715541363, 0.13675151339599065, 0.20161688274570874, 0.19177405376519474, 0.8458283703242029, 34.990172726767405, 59.21596690586635, 34.78431149891445, 29.716385773250035, 39.743543079921174, 53.80793728147234, 50.253746100834434, 59.83715670449393, 25.094395433153423, 0.5784341671637127, 7.095834348882947, 7.0876259207725525, 0.27426447878990856, 12.859553115708486, 59.90961946759905, 53.049621309552876, 56.74616718292236, 50.46325513294765, 49.151966776166645, 48.01465436390468, 49.77892705372402, 47.869624614715576, 51.03832973752703, 51.545343262808665, 50.61771706172398, 49.79496349607195, 51.03122867856707, 49.97013105664934, 49.72046491077968, 46.91244077682495, 52.11041246141706, 48.75028099332537, 52.026408740452354, 48.35141270501273, 44.25129461288452, 37.385651043483186, 41.2467337335859, 39.10475696836199, 38.51000159127371, 37.23268297740391, 37.67487675803048, 36.314436844417024, 40.65090833391462, 38.09633016586304, 37.79313162394932, 37.13541514532906, 38.26403883525303, 38.01664127622332, 38.734477043151855, 40.22744689668928, 39.47914327893938, 37.562875270843506, 39.76086841310774, 36.30502898352486, 39.77121080671038, 37.92023502077375, 39.15905019215175, 39.514217785426546, 39.55366618292672, 38.36387402670724, 40.45013318743025, 38.09907123020717, 39.298121861049104, 36.98071002960205, 38.52994639532906, 36.47019113813128, 36.56472485406058, 37.066499437604634, 41.207441670554026, 50.483342375074116, 51.54955734525408, 50.18740470068795, 50.66218900680542, 50.850280216761995, 51.40276970182146, 48.26310110092163, 47.1640385219029, 47.65481063297817, 49.59925011226109, 45.66844572339739, 46.553013937813894, 43.12932729721069, 44.42659418923514, 39.20298712594168, 34.9590482711792, 38.21770477294922, 36.5717043195452, 37.85696472440447, 37.7471866607666, 38.77070147650582, 36.92922387804304, 37.5516574042184, 39.04780605861119, 38.836890016283306, 35.61186279569353, 36.174149240766255, 35.95899479729788, 36.53894008908953, 38.23078128269741, 36.85544095720564, 38.48924732208252, 35.43547930036272, 36.1219265801566, 36.83993257795061, 36.06816141945975, 35.893094607761924, 36.056009020124165, 35.33132580348423, 35.85155132838658, 33.61856010981968, 35.21840020588466, 36.09104878561837, 39.394694873264854, 43.18141099384853, 45.28738219397408, 47.32558413914272, 47.81394869940621, 45.71992840085711, 46.504539830344065, 45.118360315050396, 47.97323267800467, 45.365684917994905, 43.633283615112305, 46.56526361192976, 44.836006368909565, 43.68970646177019, 45.137113503047395, 44.421351773398264, 46.06693533488682, 33.78175939832415, 2.2166525295802524, 0.4111505592507975, 2.5263823781694685, 0.6513734789831298, 0.592235732291426, 0.5318651146122387, 0.5638872448887143, 15.371621336255755, 64.8448554447719, 47.0164726802281, 41.03832599094936, 36.45723622185843, 45.63215528215681, 38.196623938424246, 1.7956131909574782, 0.18229983214821133, 0.31257917998092516, 0.15876412577927113, 0.11452064343861171, 0.11638764611312322, 0.2022176305098193, 0.17196250041680677, 0.14066216855176858, 0.1130663121917418, 0.15897048184914248, 0.20626855242465222, 0.2323894500732422, 0.11453364416956902], [0.07765131004686866, 0.06552145164459944, 0.022064274343262826, 0.019636594790167043, 0.027743580218936716, 0.018121231014707258, 0.07574193964579276, 0.024359149326171194, 0.08653860565807138, 0.025550051226413677, 0.0445796998350748, 0.00928943363084857, 0.02474647238185363, 0.04983786107706172, 0.03918094952989902, 0.021744434987860065, 0.04449499152334673, 0.026092886026682596, 8.434678827013288, 47.676655769348145, 35.68750088555472, 25.339845759528025, 24.300586325781687, 34.419656140463694, 47.43720347540719, 47.84091813223702, 29.797075203486852, 0.1054284098957266, 1.3650429866143634, 0.629464886018208, 0.08534562574433428, 2.893448110137667, 45.026279313223704, 53.51363590785435, 49.76714985711234, 49.59335803985596, 47.07731110709054, 46.45011459078108, 48.23265756879534, 49.22176143101284, 50.867199080330984, 48.102354526519775, 47.51526996067592, 46.49605260576521, 48.90144600187029, 46.3016037940979, 48.17245837620327, 46.738798345838276, 46.39234379359654, 46.566323212214876, 44.745509556361604, 41.67289802006313, 34.95803730828421, 35.064125878470286, 35.88638264792306, 35.54244681767055, 36.11937311717442, 34.671149662562776, 35.06732552392142, 33.5187839780535, 35.75458574295044, 34.742994035993306, 37.04406370435442, 36.83065325873238, 37.091221128191265, 35.14749731336321, 36.02130971636091, 36.20507219859532, 36.79270567212786, 35.89769778932844, 35.28496047428676, 34.97341019766671, 35.577580383845735, 35.94027635029384, 37.10242509841919, 35.17568615504673, 33.496598379952566, 33.6409888948713, 34.82159900665283, 33.734765257154194, 35.77246345792498, 34.93940223966326, 35.09544140951974, 34.356834002903526, 33.379288469042095, 33.91075617926461, 38.962284156254356, 45.517100061689106, 50.033693177359446, 47.160230909075054, 47.83497394834246, 43.426863057272776, 50.44171919141497, 46.6074982370649, 43.86951889310564, 42.242441858564106, 46.893183844430105, 47.501755714416504, 45.25307198933193, 44.48586927141462, 41.49506235122681, 37.21273469924927, 33.74088314601353, 34.60965115683419, 34.80969326836722, 35.54403795514788, 34.454463141305105, 36.61998735155378, 34.465208530426025, 34.16351427350725, 35.65929467337472, 32.51506805419922, 34.92111805507115, 34.5470791544233, 33.45396075929914, 32.62303958620344, 33.45424563544137, 33.431247098105295, 32.518681117466514, 32.57864754540579, 31.225214890071324, 32.44267477308001, 32.11484486716134, 30.97608028139387, 32.77200548989432, 31.08448260171073, 31.985834189823695, 33.2396366255624, 32.922385351998464, 33.92015709195818, 36.588261876787456, 39.0581762450082, 42.646931239536826, 45.00146382195609, 45.46621492930821, 42.58433491843087, 41.38522522790091, 40.61782448632376, 39.33081660951887, 39.053097111838206, 40.272214140210835, 45.55140331813267, 44.52739865439278, 45.2841408593314, 44.014871733529226, 43.54035840715681, 41.61890704291207, 14.238136512892586, 0.0825861527451447, 0.8771930815918105, 1.841070911714009, 0.10864516121468373, 0.1452669378902231, 0.20951588531689985, 0.07971075882336923, 17.703841515949794, 55.15783677782331, 28.14319896697998, 19.7049400806427, 25.431318793978008, 40.83036640712193, 14.380388719694954, 0.18528634974999086, 0.07988082684044327, 0.04227106585832579, 0.019184544582718184, 0.02165203887437071, 0.009667383573417152, 0.0524351268873683, 0.06339097382234675, 0.02520365740305611, 0.020632176992616484, 0.019828979824004427, 0.043677367003900666, 0.027251666079142263, 0.025306860883054987, 0.03517527233010956, 0.02804822038992175, 0.01596409864058452, 0.07773875285472188, 0.06080192167844091, 0.03375271348548787, 0.011253438823457276, 0.03514148128618087, 0.03261462366208434, 0.01701046240382961, 0.02622229792177677, 0.035040779904063256, 0.04195137408428958, 0.03605728303747518, 0.017387152815769826, 0.019736215605267456, 0.05216282060635941, 0.1595894279224532, 13.546912346567426, 54.69180372783116, 34.21509769984654, 24.19520820890154, 37.03606980187552, 40.360786301749094, 49.383289677756174, 52.95635911396572, 31.46799189703805, 0.048947331362536976, 0.9186382719448635, 1.1894105481249946, 0.07719237610165562, 3.7531089867864336, 48.39296293258667, 53.955603872026714, 51.66532128197806, 49.1476936340332, 50.2496223449707, 47.66072007587978, 49.288703850337434, 50.30901207242693, 52.20157977512905, 49.665396962847026, 49.24470438276018, 47.740096296582905, 50.1902882031032, 47.262192249298096, 49.735671043395996, 47.12810243879046, 48.213668142046245, 48.65167563302176, 47.40009314673287, 43.179031235831125, 37.58130536760603, 35.30040284565517, 36.59672825677054, 36.31924499784197, 37.063504764011924, 36.578134877341135, 37.06430728094918, 36.19182893208095, 38.58674097061157, 36.22620167051043, 37.36807557514736, 36.887347085135325, 38.05829572677612, 36.89590031760079, 38.194042682647705, 38.24953099659511, 37.33467558452061, 37.87581171308245, 37.05523988178798, 35.763920647757395, 38.07927928652082, 36.40113994053432, 37.85128804615566, 37.402639389038086, 35.62297643933977, 35.98879909515381, 36.48983716964722, 35.96968807492937, 37.217053004673545, 37.188085964747835, 37.21827936172485, 36.36043739318848, 35.372445242745535, 37.142147949763704, 39.83503348486764, 46.748612676348, 50.36127642222813, 49.072131974356516, 48.17080817903791, 46.552114146096365, 54.46805088860648, 46.61882380076817, 45.394370555877686, 44.27423061643328, 49.471271242414204, 46.39664125442505, 47.87531866346087, 45.232376779828755, 43.83799491609846, 38.03063147408621, 34.20085389273507, 36.92876182283674, 35.757462297167095, 37.01766402380807, 37.1622873033796, 37.619649001530235, 36.135750021253315, 35.808913707733154, 36.190449714660645, 34.7059497152056, 36.07266385214669, 35.85536241531372, 35.821708815438406, 35.15841293334961, 35.41125440597534, 35.65921476909092, 35.36361060823713, 33.47898122242519, 33.496365615299766, 32.81193331309727, 34.02678762163435, 32.964515754154746, 35.18176930291312, 33.822427204677034, 33.72677830287388, 34.46259948185512, 35.06063788277762, 35.36466326032366, 38.70739991324288, 41.47020517076765, 44.35806063243321, 45.975517886025564, 45.98651688439505, 44.51157760620117, 42.83908714566912, 42.45638384137835, 42.622817516326904, 42.631058079855784, 42.83516836166382, 46.97475569588797, 44.87649352209908, 46.39538363048008, 44.14495243344988, 44.06520101002285, 43.48876803261893, 16.50301562036787, 0.39499882023249355, 1.8166996708938052, 3.370700763804572, 0.06185270779367004, 0.20167105698159762, 0.2662915566137859, 0.14576259415064538, 19.552345480237687, 59.926705087934224, 34.75191899708339, 26.015703984669276, 23.741805246898107, 46.88712848935808, 18.994450296674454, 0.19959628688437597, 0.03855750476941466, 0.13897148998720305, 0.037822169584355185, 0.0211653257054942, 0.04969703113394124, 0.02931675687432289, 0.03187829442322254, 0.036019451317510436, 0.02812399578812931, 0.0580891522445849, 0.042088790996266265, 0.06459874579949038, 0.02365876378358475, 0.13989090493747167, 0.15262012689241342, 0.07100220290677887, 0.1128556134977511, 0.2148648990052087, 0.10009190160781145, 0.06448927774493184, 0.17997530688132557, 0.15062642815921987, 0.13335826833333286, 0.10937607913677182, 0.09850398038647004, 0.12036566622555256, 0.16667640049542698, 0.14513758197426796, 0.11177558252321822, 0.2571366535765784, 0.31174469047359055, 14.587623085294451, 63.64592293330601, 43.065435137067524, 33.55832270213536, 35.97868251800537, 43.866673605782644, 53.92698424203055, 56.94920744214739, 37.62183768408639, 0.14593376139444963, 4.12401772396905, 3.798876770905086, 0.35392679699829643, 4.728458021368299, 48.811247961861746, 54.692668778555735, 52.89345012392317, 53.34062576293945, 50.61927693230765, 50.95792170933315, 51.411983013153076, 53.393390383039204, 53.80244125638689, 53.02242258616856, 50.88438892364502, 49.407215799604145, 51.57005800519671, 48.70746619360787, 51.91540084566389, 50.14973504202706, 50.599731649671284, 52.26246336528233, 48.64506442206246, 45.852552141462056, 39.02986233575003, 38.071400029318674, 38.78422267096383, 39.91546583175659, 41.02142449787685, 38.71689115251814, 38.360358238220215, 37.91519062859671, 39.98380136489868, 38.66479008538382, 39.70529672077724, 41.20360279083252, 40.80459206444876, 38.805400780269075, 40.58022778374808, 40.441986424582346, 39.22914709363665, 39.949571064540315, 38.60714088167463, 37.2374598639352, 39.26436056409563, 40.238730771201, 39.23115164893014, 37.17095170702253, 37.09706456320626, 37.110498905181885, 38.86496768678938, 38.67286736624581, 39.762615885053364, 37.99065848759243, 38.67144993373326, 38.98510898862566, 37.88240902764456, 38.94336073739188, 42.26967532294137, 49.09318849018642, 53.45281137738909, 50.04773896081107, 50.78260128838675, 47.840143408094136, 53.55934810638428, 51.1132869039263, 47.205338614327566, 47.49911887305123, 48.52771282196045, 49.521635259900776, 50.77770280838013, 47.86868660790579, 45.979367188044954, 39.929487296513145, 36.827741963522776, 38.284966809409006, 38.18288734980992, 38.88278981617519, 38.964771611349924, 40.19512735094343, 37.68957914624895, 38.42975337164742, 38.3999525478908, 35.92048440660749, 36.926475865500315, 37.667619364602224, 37.473521436963765, 36.34845175061907, 37.70893335342407, 36.33032042639596, 36.177414894104004, 35.01373406818935, 34.53988776888166, 34.93346847806658, 35.8848922593253, 35.05616324288504, 37.56130845206124, 34.274820940835134, 36.31320701326643, 37.50937761579241, 37.02344492503575, 36.75303840637207, 40.00037281853812, 42.01542684010097, 45.944184984479634, 48.23504774911063, 48.33687012536185, 46.057635171072825, 44.01016780308315, 44.11631543295724, 43.15178040095738, 44.794372762952534, 45.693799700055806, 46.51355859211513, 47.148655210222515, 46.4984393119812, 45.52476739883423, 45.61941228594099, 44.531508513859336, 18.34893138068063, 0.6486132528100694, 2.885719759123666, 7.1728286402566095, 0.17682348457830294, 0.594242513179779, 0.7573951727577618, 0.4263394299362387, 22.96548649242946, 65.12194265638078, 36.75588369369507, 28.64209004810878, 31.152981417519705, 52.8873496055603, 25.219945907592773, 0.3172912799886295, 0.16563707483666285, 0.20977157088262693, 0.12179955999766078, 0.13951944772686276, 0.1696784429784332, 0.17251040387366498, 0.18204132387680666, 0.12138800136744976, 0.13354379337813171, 0.06388416700065136, 0.1244902363313096, 0.13441714937133448, 0.13794097171298095], [0.03348570317029953, 0.09588754935456173, 0.03873033781668969, 0.06771007991795029, 0.023029626114293933, 0.024978281996612037, 0.006523778329470328, 0.035063378512859344, 0.03731650493240782, 0.03461959964728781, 0.014607703745631235, 0.01228271283408893, 0.008802430388251585, 0.005828987308112639, 0.019243529631889293, 0.03324384614825249, 0.0523645422820534, 0.06680283110056605, 0.9859636021511895, 31.322319439479283, 44.382841382707866, 23.530934367861065, 18.96528697013855, 29.777140821729386, 40.382284028189524, 49.068213190351216, 34.814647333962576, 0.21842221383537563, 0.7205449672681945, 0.7568250947764942, 0.07009128321494375, 0.16098406165838242, 22.36033139910017, 54.0988826751709, 50.91649654933384, 51.97300836018154, 46.11788994925362, 48.936874866485596, 48.97071606772286, 48.472578866141184, 45.81107486997332, 44.22918544496809, 46.194212436676025, 46.67874506541661, 46.661576066698345, 46.58347831453596, 44.544793469565256, 44.58520071847098, 41.93225690296718, 42.67753805433001, 38.66643680844988, 34.56899029867989, 33.36918926239014, 35.134552819388254, 35.1475042615618, 34.48205443790981, 33.91857985087803, 35.02292306082589, 34.84471913746425, 34.79772499629429, 34.937074593135286, 34.72735711506435, 34.67004837308611, 35.839423247746055, 35.360939025878906, 35.519045284816194, 34.886766161237446, 34.94164650780814, 36.75197185788836, 36.83082001549857, 34.388639381953645, 34.70789173671177, 35.187015192849294, 36.1127028465271, 34.13837569100516, 34.312699045453755, 34.47364016941616, 36.07810776574271, 37.0031144959586, 35.36980145318167, 36.56392233712332, 34.44989470073155, 33.95641279220581, 35.405073983328684, 34.59131833485195, 34.18852778843471, 38.18077857153756, 45.75875840868269, 49.19608783721924, 48.643601826259065, 48.468778201511924, 42.865452085222515, 45.55733707972935, 46.800640787397114, 44.515413011823384, 45.33575207846505, 45.00570569719587, 46.776836259024485, 45.36063357761928, 46.16746882029942, 43.25299480983189, 36.911373955862864, 34.862093108040945, 34.145250933510916, 34.81514065606253, 34.918724400656565, 35.00164072854178, 35.701004709516255, 35.491005829402376, 33.91070754187447, 33.835687841687886, 34.02590520041329, 33.44739818572998, 33.593473638807026, 33.063131536756245, 34.19881807054792, 34.215549332754954, 33.43517630440848, 33.43111508233206, 33.03622811181204, 32.83401468821934, 31.48646715709141, 31.557092121669225, 30.514789376940044, 32.07484408787319, 32.18105772563389, 33.188438824244905, 33.32829563958304, 35.25842182976859, 38.70806346620832, 41.29826504843575, 41.688757283346995, 41.67889084134783, 43.12053435189383, 42.70965262821743, 42.060079438345774, 40.73702778135027, 40.40254497528076, 41.34070117133004, 39.7891788482666, 40.90365947995867, 44.85662167412894, 44.781278882707866, 45.29833950315203, 45.036183970315115, 43.27842174257551, 33.69587966373989, 4.5645317775862555, 0.1502036058476993, 4.130709273474557, 2.660852385418756, 0.10186883554394756, 0.16045465506613255, 2.1938954421452115, 0.5740571820310184, 27.60757449695042, 49.15055629185268, 24.69283298083714, 28.091033629008702, 24.837440626961843, 42.313973563058035, 3.9976382425853183, 0.10588011744299106, 0.04455823777243495, 0.050737344061157534, 0.02064998514418091, 0.010049542977607675, 0.03577185049653053, 0.015606008569843002, 0.054555976297706366, 0.05650937344346728, 0.06927845254540443, 0.043246300491903505, 0.013283184729516506, 0.03731026919558644, 0.11513728249285902, 0.039184528802122386, 0.005292289433003004, 0.048700402291225534, 0.027678345862243856, 0.04285876539402774, 0.018217934129227484, 0.05605794409556048, 0.047960463246064525, 0.03084914678973811, 0.011321140503111695, 0.04837714481566634, 0.038761010992207696, 0.0512027410524232, 0.03231688588857651, 0.027426974082897817, 0.04760497535711952, 0.0655896986967751, 0.03801950113847852, 1.9132579181875502, 38.25856712886265, 47.170969349997385, 22.065078122275217, 28.02273804800851, 36.65452337265015, 44.58516945157732, 52.956810746874126, 37.63751629420689, 0.1989431426461254, 0.36420296558312004, 0.11194592195429973, 0.07048569526523352, 0.44294578741703716, 25.10387625013079, 53.76312140056065, 52.18583863122122, 52.50186702183315, 48.00485045569283, 51.18507916586739, 50.2335581098284, 50.05121653420584, 47.670791489737375, 48.50250823157174, 48.20851257869175, 48.18168558393206, 49.25118705204555, 47.47012056623186, 46.78528526851109, 47.235591070992605, 46.557287079947336, 44.56742375237601, 41.089093003954204, 36.94392279216221, 34.44217872619629, 37.110446793692454, 36.063940388815745, 36.76192167827061, 35.72021995271955, 35.72229398999895, 37.18739114488874, 37.00758566175188, 36.55059221812657, 36.56266123907906, 36.623249530792236, 39.47047540119716, 38.051083496638704, 35.857415607997346, 36.60321092605591, 36.807133606501985, 38.400275639125276, 36.91866609028408, 35.65760278701782, 36.86174644742693, 37.25208234786987, 37.166748046875, 35.742429869515554, 36.2182286126273, 36.445174149104524, 37.258575439453125, 38.01152045386178, 37.364024775368826, 38.481645992824006, 36.5458778653826, 35.91529410226004, 36.857779026031494, 37.68264831815447, 36.82520587103707, 41.3568765776498, 46.400754587990896, 50.457279682159424, 49.25994873046875, 49.95401471001761, 46.748518875667024, 50.87763180051531, 47.66230773925781, 46.99528762272426, 46.12978526524135, 50.96660000937325, 49.32717950003487, 46.43163585662842, 46.027757917131694, 44.59723152433123, 39.2178111076355, 36.2997796194894, 35.09317977087838, 35.80121162959507, 37.01000363486153, 37.56394181932722, 35.85313204356602, 37.44371713910784, 36.765500000544954, 36.75264930725098, 36.12798540932791, 36.49679926463536, 34.79660286222185, 35.043184007917134, 35.88653203419277, 36.398096629551475, 34.803464208330425, 34.48025138037545, 33.84822934014456, 34.58465501240322, 33.33848864691598, 33.41594021660941, 32.98778179713658, 34.59679004124233, 34.276287010737825, 34.55979435784476, 35.68904685974121, 36.470274516514365, 40.123588698250906, 42.229712758745464, 43.6667982510158, 43.837425163814, 43.85183572769165, 45.16026490075247, 45.532240186418804, 42.83391073771885, 42.199915409088135, 41.90741014480591, 42.88625151770455, 43.035738536289756, 45.3573887688773, 45.61890506744385, 45.38309015546526, 45.37997041429792, 43.67561204092843, 35.809994152614046, 5.612358774457659, 1.0969328475849969, 3.6414916047028134, 3.257178706782205, 0.21160520320492132, 0.13340295664966106, 2.995514541864395, 0.797940408544881, 30.565247195107595, 54.92400557654244, 32.32142175946917, 30.412164483751567, 22.995659044810704, 49.705939701625276, 5.727490425109863, 0.24407162464090756, 0.07705133581267935, 0.023998870979994535, 0.07942590303719044, 0.04396761375080262, 0.057046793534287384, 0.04539141431450844, 0.03259798937610217, 0.01149808632076851, 0.0244486073830298, 0.04707571804257376, 0.040990782236414294, 0.03851304715499282, 0.11636528159890856, 0.09854731841811112, 0.17151219743703092, 0.15352556402129786, 0.19778615901512758, 0.15064685206328118, 0.12675495552165167, 0.17903033830225468, 0.11509237704532486, 0.13249348902276584, 0.2018801136208432, 0.13616031940494264, 0.08030278062713997, 0.13475782823349747, 0.13742057606577873, 0.12194505147635937, 0.136015153623053, 0.1698275035513299, 0.14429151665951523, 2.485399297305516, 44.662211077553884, 55.02916656221662, 31.019871303013392, 29.956692695617676, 38.89069339207241, 47.501258918217246, 57.566402026585166, 40.997314248766216, 0.47370728105306625, 3.168148832661765, 2.5610145883900777, 0.30353577381798197, 0.6660177303212029, 26.22836923599243, 56.84852457046509, 53.908870288303916, 56.78162384033203, 50.625954151153564, 52.90544618879046, 51.39735358101981, 51.70050695964268, 48.331662450517925, 51.51453495025635, 51.795780658721924, 49.67167466027396, 51.4566981451852, 50.44532878058297, 47.36744703565325, 48.69931248256138, 47.81032173974173, 46.728146757398335, 42.71962676729475, 39.29636396680559, 36.82465696334839, 39.14085633414132, 38.77061809812273, 39.0209755897522, 36.914385999952046, 36.54604809624808, 38.90382548740932, 39.81788880484444, 37.7069149017334, 37.57454129627773, 38.246977533612935, 42.02972623280117, 39.89099080221993, 37.93692806788853, 37.04814577102661, 38.887028217315674, 39.96647950581142, 39.041604791368755, 36.953445298331125, 36.83282109669277, 38.03315714427403, 37.94641930716378, 36.308881759643555, 37.86349950517927, 40.06745072773525, 40.103213105882915, 41.442700726645334, 39.74341106414795, 40.32381841114589, 38.94948557444981, 36.17098781040737, 39.790391308920725, 40.56061996732439, 39.35247414452689, 42.69052423749651, 48.28845507758004, 52.870458534785676, 50.496186120169504, 53.40195056370327, 46.4169682094029, 49.543198994227815, 50.72519874572754, 48.63746656690325, 50.234315463474815, 50.452391624450684, 49.36945928846087, 47.88679361343384, 49.67938716070992, 47.30996458871024, 40.0038469178336, 39.12851980754307, 37.28770228794643, 38.07618038994925, 38.44452524185181, 39.084430013384136, 38.9783935546875, 39.14131838934762, 36.83720193590437, 38.787241663251606, 38.51250294276646, 37.67305285590035, 37.42228889465332, 36.73224939618792, 38.99570499147688, 38.26443140847342, 37.101546151297434, 36.17612600326538, 37.0324706350054, 37.44318560191563, 34.517973150525776, 35.51177746909005, 32.79932928085327, 36.759250095912385, 36.25407089505877, 36.4561071395874, 38.07194198880877, 38.7285988671439, 42.271881375994, 44.99195173808506, 44.95803410666329, 46.1118380682809, 46.10785327638899, 45.17228875841413, 45.434551988329204, 44.49473169871739, 44.83572496686663, 44.539304392678396, 43.271831376211985, 47.46938753128052, 48.09537853513445, 46.096607616969514, 47.976272514888215, 46.95319196156093, 45.70718540464129, 36.759944915771484, 7.138378603117807, 1.043839925101825, 8.39055255481175, 7.676484448569162, 0.4338778725692204, 0.4071183241903782, 4.561347331319537, 2.2020237488406043, 34.352581705365864, 59.966323716299875, 34.60820593152727, 38.688445227486746, 31.553055218287877, 55.22620357785906, 8.348814725875854, 0.4008635612470763, 0.15894323188279355, 0.14675607798354967, 0.18869334193212645, 0.12627128218965872, 0.2211768353091819, 0.12441152626914637, 0.11919929166989666, 0.12547226649309906, 0.09679688805980341, 0.1337810635034527, 0.09826035917337451, 0.11468244689915862, 0.18420382855193956], [0.06916122883558273, 0.020785866870677898, 0.047957711786563904, 0.043826067953237464, 0.0359209212474525, 0.03774500997470958, 0.049986589167799265, 0.041347515237118514, 0.030871494340577295, 0.028529279665755372, 0.05808517602937562, 0.09519038176430122, 0.024754886216084872, 0.03718570712953806, 0.028866623528301716, 0.02345651454691376, 0.0029910987733663724, 0.050147663203201125, 0.0553123155342681, 14.807616949081421, 47.28304031917027, 30.20209959575108, 27.6573201247624, 27.961977788380214, 35.964681897844585, 45.85870129721505, 40.15764529364449, 0.9948427485568183, 0.5278671862823623, 0.19383826585752623, 0.11457873960690838, 0.023733139703316346, 8.764815534864153, 43.66554062707083, 51.52139629636492, 51.173951625823975, 48.15388584136963, 47.44361318860735, 51.37688766207014, 48.221995558057515, 46.368834563664024, 49.09298004422869, 43.21278558458601, 47.64334263120379, 43.26767635345459, 44.236255237034385, 41.90830646242414, 40.79332208633423, 36.566093649183, 34.53306116376604, 33.98459121159145, 34.021639006478445, 34.21313483374459, 34.34706136158535, 34.609209946223665, 35.17050627299717, 34.29049607685634, 35.1054607118879, 36.249429498400005, 35.16449955531529, 34.882166453770225, 35.85925340652466, 35.49683884211949, 36.15288775307791, 34.32960748672485, 33.887719426836284, 35.540477003370015, 34.96923085621425, 37.016666957310264, 36.580997535160606, 36.20640972682408, 36.0369987487793, 36.97446707316807, 35.04052284785679, 36.07332393101284, 36.00242798668997, 35.228381293160574, 37.26487398147583, 37.350159645080566, 38.018312317984446, 36.656048502240864, 36.530550139290945, 36.19450051443917, 37.20022446768624, 36.57443496159145, 36.76739338466099, 39.68149219240461, 45.44122920717512, 48.20402751650129, 49.056797300066265, 45.84823383603777, 42.015788146427695, 43.54868582316807, 48.54686900547573, 45.81434747150966, 46.37384074074881, 42.464964866638184, 46.74358218056815, 47.19029923847744, 45.57783079147339, 44.78876904078892, 40.91334874289376, 33.3490047454834, 34.44483641215733, 35.07099069867815, 35.519809586661204, 34.355666705540244, 35.31887463160923, 34.940065792628694, 34.82877996989659, 35.26864262989589, 35.856317792619976, 33.96461514064244, 34.45033243724278, 33.885172912052695, 34.26896708352225, 34.03592797688076, 33.85581677300589, 32.06231995991298, 33.14184767859322, 32.049587385995046, 32.380134037562776, 32.83937174933297, 31.43667984008789, 31.07970224108015, 30.688674994877406, 32.37087903703962, 33.580042770930696, 35.593974658421104, 39.100945881434846, 40.224459171295166, 42.55145951679775, 44.30416693006243, 43.219935280936106, 42.79976381574358, 42.06672191619873, 40.510860443115234, 41.87130383082798, 42.083077975681846, 39.21821410315377, 39.893019676208496, 43.80036694662911, 44.316451345171245, 45.49054404667446, 44.40831695284162, 42.771898065294536, 20.725500174931117, 1.0774030898298537, 0.49588484529938015, 1.9771889448165894, 1.8152967861720493, 0.13965529043759617, 0.13599086206938538, 1.516363461102758, 0.08439137480620827, 35.78868055343628, 39.3933538709368, 23.537175587245397, 19.53008345195225, 35.203840255737305, 27.623289585113525, 0.07341804541647434, 0.07817567512392998, 0.06648263042526585, 0.07458412141672202, 0.008194215346260794, 0.021234924738694514, 0.02362703887878784, 0.05308000996176686, 0.022949872804539542, 0.024523560057527254, 0.011518952968929495, 0.035974159105015655, 0.009925896085665693, 0.06243954558989831, 0.04676565807312727, 0.06344300388757672, 0.06879344928477492, 0.011197127202259642, 0.05304001032241753, 0.03798842762729951, 0.02289552384588335, 0.019286362154941474, 0.05871495830693415, 0.0735733417261924, 0.04647114673363311, 0.018698900106496046, 0.06414743858788695, 0.0028406011905255063, 0.010486342262343636, 0.05370427914229887, 0.012040550471283495, 0.025375484522165995, 0.05484363443351217, 0.11185420437582902, 20.48622853415353, 54.18431077684675, 26.975731372833252, 26.638250419071742, 35.69889940534319, 39.851907185145784, 51.433126381465364, 42.627233096531455, 0.9593235573598317, 0.47494492892708096, 0.22652388124593667, 0.3489966429769993, 0.054013287382466454, 9.932535001209803, 48.61426305770874, 52.14425366265433, 53.96769373757498, 48.991258416857036, 48.271480628422324, 50.11836739948818, 48.142758301326204, 46.28102322987148, 49.02081605366298, 44.35293633597237, 48.957719462258474, 46.01660605839321, 46.028720242636545, 43.061283588409424, 43.37279217583792, 38.214932441711426, 36.29544741766793, 34.9656525339399, 36.294835976191926, 35.92632784162249, 35.10587065560477, 36.13008723940168, 36.998070103781565, 36.16868448257446, 36.24624374934605, 37.27964585168021, 36.1521303994315, 36.633109024592805, 37.941305433000835, 36.98835999625069, 37.58643661226545, 37.277637822287424, 36.54585007258824, 36.10766887664795, 36.563658305576865, 38.327552318573, 37.3461366380964, 37.767117568424766, 36.733986445835654, 37.81091901234218, 36.713760239737375, 37.397296224321636, 37.765488215855186, 38.342709813799175, 39.37801572254726, 38.78984376362392, 39.36548464638846, 39.22376571382795, 38.40649427686419, 37.19125434330532, 38.531381198338096, 36.9827423776899, 37.315213680267334, 40.34422179630825, 46.637702056339805, 48.48970964976719, 51.392969267708914, 47.323006357465474, 44.369827406747, 47.40661403111049, 50.8988550731114, 46.46320152282715, 47.29742309025356, 46.19229473386492, 49.08160236903599, 48.117762156895225, 48.034988267081125, 47.122741903577534, 43.5686479977199, 35.43828637259347, 35.53383799961635, 36.17227670124599, 38.81522553307669, 37.16702944891793, 36.63358497619629, 35.760078293936594, 37.68671301433018, 35.9609055519104, 37.17315428597586, 36.83260570253645, 35.32682337079729, 35.11574404580252, 35.93504088265555, 35.60821846553257, 34.41058874130249, 34.87994303022112, 34.92778485161917, 33.58062294551304, 33.99005249568394, 34.56717334474836, 33.83466993059431, 32.48832096372332, 33.28686353138515, 33.80876357214791, 35.30456134251186, 38.10640505381993, 40.494820526668, 42.562767710004536, 44.780573640550884, 45.3423250743321, 45.405928884233745, 44.84411839076451, 44.08355467660086, 42.090873854500906, 43.946011611393516, 42.43405927930559, 41.69266217095511, 44.17066076823643, 44.87749406269619, 45.137860434395925, 47.171209062848774, 44.15455136980329, 43.92217581612723, 22.613200664520264, 1.4189535166536058, 1.6474118062428065, 4.043874161584037, 2.0813001011099135, 0.10904865206352302, 0.1163636531148638, 2.396320568663733, 0.6116060071757862, 39.87244258608137, 45.08733313424246, 32.97479908806937, 23.869393280574254, 34.30642829622541, 34.04477303368704, 0.30355919684682575, 0.02184874108726425, 0.06840638576873712, 0.09495808530066695, 0.028453477126147066, 0.04809595311858824, 0.009904975154703217, 0.08756431311901126, 0.021284245752862523, 0.024552777775430253, 0.04158110770263842, 0.035340512570525916, 0.028493995844785656, 0.013565493464869047, 0.07396168088806526, 0.13929084927908011, 0.12229440201606069, 0.11895541261349406, 0.16602309340877192, 0.18568242421107634, 0.14465906550841673, 0.19869027978607587, 0.13179657927581243, 0.17811323037104948, 0.16039005853235722, 0.12205158147428717, 0.13144687589790138, 0.1400367221129792, 0.1135232105318989, 0.12105432498667922, 0.10559469168739659, 0.10277015396526881, 0.1252266639577491, 0.15755713411739894, 22.63941969190325, 60.86315550122942, 37.149686745234895, 37.58326128550938, 37.66570860998971, 43.78812769481114, 54.870886598314556, 49.49180664334978, 1.724033500467028, 1.8949381240776606, 0.8229723253420421, 0.5570913095559392, 0.12376120473657336, 11.047132015228271, 48.15989603315081, 54.546888623918804, 55.95484726769583, 51.58300944737026, 50.28223371505737, 52.66534423828125, 49.84197848183768, 47.0144750731332, 50.014210428510395, 48.387317521231516, 51.51077944891793, 47.6542513029916, 48.36994007655552, 45.69746487481253, 44.369521686008994, 40.03286954334804, 38.069951329912456, 37.436313833509175, 38.1899745123727, 37.976591859545024, 37.612704277038574, 37.73863690240042, 38.75841358729771, 37.892768791743684, 37.36273241043091, 38.475420406886506, 37.21758801596505, 39.54604400907244, 39.49214335850307, 38.84616586140224, 40.41351270675659, 38.27463483810425, 37.68928384780884, 38.91839933395386, 37.83567544392177, 40.22180495943342, 38.611216000148225, 40.21463789258684, 39.25695031029837, 40.6596109526498, 39.08517347063337, 39.70837129865374, 40.32046243122646, 40.82627739225115, 40.87477929251534, 39.702263832092285, 41.295628207070486, 41.42172064099993, 40.11131123134068, 39.4570688520159, 41.354684420994346, 40.29114103317261, 38.26938199996948, 42.78775038037981, 47.936483655657085, 49.93011638096401, 53.14835173743111, 47.6895238331386, 45.4028126171657, 46.01542139053345, 51.02138655526297, 48.90866865430559, 48.65829379217965, 46.63340112141201, 50.63736309323992, 50.425543785095215, 48.977424553462434, 49.638368470328196, 45.27227333613804, 37.6478864806039, 38.05771555219378, 38.867573261260986, 40.177002974918906, 39.16283001218523, 39.36581121172224, 38.13744265692574, 39.27212865012032, 38.63502400262015, 40.34814405441284, 37.64072288785662, 37.84417309079851, 37.29131187711443, 38.03058631079537, 37.408118043627056, 37.525622504098074, 36.0738068308149, 38.041060720171245, 35.56766530445644, 35.98095110484532, 36.37103687013899, 35.28227846963065, 34.71467317853655, 33.13480915342058, 36.461280073438374, 36.57697105407715, 39.5067206791469, 42.54738092422485, 43.78414290291922, 45.266513279506135, 48.13670642035348, 46.63395002910069, 46.20723336083548, 46.1175286429269, 42.965283802577424, 45.57429763248989, 44.88294492449079, 42.923865590776714, 47.428087438855854, 46.54360260282244, 46.449367659432546, 47.395886012486045, 45.8243077141898, 45.83740159443447, 25.51072801862444, 1.653580938066755, 1.3583822697401047, 6.0265543545995435, 4.397249119622367, 0.4803632210407938, 0.3634515016206673, 3.691925321306501, 1.2429980954953601, 44.936126436506, 50.64731291362217, 33.853409222194124, 28.590596948351177, 43.569825717381065, 39.41518858500889, 0.6380185527460915, 0.249088604003191, 0.14001700388533728, 0.2552927482341017, 0.19015595130622387, 0.137434486033661, 0.07164076542747871, 0.17804039642214775, 0.05756846482732466, 0.2070155380559819, 0.11602557982717242, 0.0855537120785032, 0.08972333690949849, 0.16301782109907695, 0.16259897500276566], [0.03780029361535396, 0.06742073222994804, 0.044520382303744555, 0.044165722227522304, 0.030934143478849103, 0.02940455252038581, 0.045308385376951525, 0.03154201925333057, 0.01686958665959537, 0.0289356610737741, 0.059270719199308326, 0.06256508813904864, 0.025572420829640966, 0.006187425976219986, 0.03384279240188854, 0.09316918200680188, 0.012270324480985957, 0.055160245658563714, 0.0372791142602052, 1.936156792300088, 32.82650368554251, 40.145326137542725, 26.248920270374843, 24.52566453388759, 37.76447377886091, 41.20939758845738, 46.35137374060494, 2.1895595490932465, 0.23371959584099905, 0.12346400639840535, 0.12991413314427647, 0.04607863458139556, 0.6059200465679169, 22.93218377658299, 49.597825731549946, 51.63965811048235, 45.86912359510149, 48.066328116825645, 49.043317794799805, 49.74454736709595, 46.69444452013288, 48.29883916037423, 48.465512548174175, 44.94526331765311, 44.70671081542969, 43.10478973388672, 40.37111479895455, 35.36904409953526, 33.81769895553589, 33.44249970572335, 34.043814182281494, 35.225021839141846, 34.74111802237374, 35.70527785164969, 36.33896745954241, 36.65961987631661, 35.5370272227696, 35.65752288273403, 35.147493839263916, 34.16131516865322, 35.76496287754604, 35.41665663037981, 38.266512393951416, 35.48626715796334, 37.85426534925188, 35.68987022127424, 36.195035525730674, 37.0101842880249, 35.12350170952933, 35.031229632241384, 35.599362986428396, 34.603825092315674, 36.34980664934431, 36.161242961883545, 36.71637623650687, 37.08176115580967, 35.509460244859966, 42.22920206614903, 41.34436634608677, 42.26144518171038, 40.320594446999685, 39.68428884233747, 38.577645778656006, 36.734733377184185, 36.25375822612217, 36.04603140694754, 39.59055764334542, 47.32023402622768, 47.67794466018677, 48.378389086042134, 47.48844296591622, 44.81635338919503, 40.63858222961426, 48.603298800332205, 45.42086056300572, 47.125604561397004, 41.08349622998919, 44.10283940179007, 47.07174907411848, 46.28890248707363, 46.508114678519114, 39.92293167114258, 33.7269971711295, 34.566471576690674, 34.57995803015572, 35.50003501347133, 33.43459265572684, 35.43325587681362, 33.34506859098162, 34.75619213921683, 34.19608742850167, 33.41392523901803, 32.781993525368826, 33.405014174325125, 33.317932401384624, 32.30312715257917, 34.30139085224697, 32.833580425807405, 33.02252973828997, 33.12340715953282, 31.87348529270717, 31.77521344593593, 31.892540727342876, 32.44364404678345, 30.98673186983381, 31.613521916525706, 32.604529585157124, 31.353638444628032, 32.45970133372715, 36.045194149017334, 38.90862321853638, 40.67112411771502, 40.70769943509783, 41.368181296757285, 43.31752273014614, 42.9297958782741, 41.87443399429321, 41.61333111354283, 42.74321590151106, 39.71904720578875, 38.01092638288225, 41.82652963910784, 43.83108145850045, 44.48076581954956, 46.80323941367013, 35.436604908534456, 9.020847099167959, 0.12326200652335371, 1.9530196360179355, 1.2120570072105952, 1.691521467907088, 0.298732940107584, 0.27805740811995094, 0.7238420503480094, 2.1480444967746735, 49.20270599637713, 32.12777893883841, 22.66363068989345, 21.50961480821882, 40.686625548771445, 13.001292024339948, 0.1397699899971485, 0.0360898018282439, 0.04763701238802501, 0.03344172053039074, 0.07531288838280098, 0.01419969046089266, 0.03563517318772418, 0.049270073151482005, 0.033852040834192715, 0.05665651036958609, 0.016368290076830556, 0.019731231765555482, 0.02153330372779497, 0.020147178820999603, 0.01689069758036307, 0.012972440287869955, 0.029511265722768645, 0.010140431047018086, 0.04991526835198913, 0.03821467495124255, 0.06138780952564307, 0.05274477634312851, 0.09785321102078472, 0.020401341075609838, 0.03191982076636382, 0.053860220060284646, 0.02494262158870697, 0.016652340102674704, 0.02123792895248958, 0.01623227264332984, 0.03382065858958023, 0.021358133127380694, 0.010455932867314135, 0.08922485794339861, 4.343939934458051, 46.77754497528076, 42.67771175929478, 24.813587461199077, 34.019280093056814, 42.95401382446289, 46.543720722198486, 50.07605287006923, 2.392430228846414, 0.19981197959610394, 0.04320106256221022, 0.04970681560891015, 0.018666764688012854, 0.8689210883208683, 26.461460454123362, 50.88989189692906, 52.763772419520784, 47.81768683024815, 50.61893647057669, 51.28740528651646, 49.215834617614746, 47.59294387272426, 48.7365756716047, 50.51899358204433, 48.23499911172049, 47.29698882784162, 43.84077419553484, 40.629285539899556, 38.229818957192556, 35.76272208350045, 35.44521025248936, 36.7663129397801, 35.98710373469761, 35.809240273066926, 37.12219272341047, 37.85044036592756, 37.01119177682059, 36.116173471723286, 37.64507940837315, 35.766508851732524, 36.089356899261475, 37.70078311647688, 39.1669294493539, 38.96867649895804, 37.54072093963623, 38.24757507869175, 37.470759528023855, 37.66513538360596, 38.344742161887034, 36.74833795002529, 37.250188963753835, 36.363265310014995, 35.95911986487252, 38.493246010371614, 35.53707586015974, 37.7952994619097, 39.100740909576416, 37.823234694344656, 43.92307560784476, 44.49644790376936, 44.017109053475515, 41.562897614070344, 42.06570747920445, 38.524863788059776, 37.47682877949306, 38.03888245991298, 38.63540267944336, 42.52604648045131, 48.62817335128784, 50.37473508289882, 49.92396722521101, 48.92540686471121, 46.29264061791556, 45.75891126905169, 49.73541743414742, 47.820212500435964, 48.00810916083199, 47.00641516276768, 45.94937528882708, 49.394761153629844, 48.53353541237967, 48.227303981781006, 42.03058780942644, 34.486362321036204, 35.26697506223406, 35.64796910967146, 38.33410446984427, 36.01977416447231, 36.81124694006783, 35.18691791806902, 36.86706876754761, 35.39648600987026, 35.91435956954956, 36.20371729987008, 36.15504169464111, 34.94065638950893, 33.976277691977366, 35.604327474321636, 34.915517807006836, 34.41824565614973, 35.36634472438267, 33.672328744615825, 34.723493916647776, 32.16572652544294, 35.04898575374058, 32.292048249925884, 34.020454338618684, 33.626255239759175, 33.9952323777335, 35.57014581135341, 38.099081652505056, 40.939328057425364, 43.0458516393389, 43.961085728236604, 44.39510842732021, 44.81025287083217, 44.59655407496861, 42.41020958764212, 44.50398669924055, 43.39201784133911, 41.96036236626761, 40.89888259342739, 44.52448388508388, 45.30140365873064, 46.96674789701189, 47.18601219994681, 37.92272594996861, 10.534618122237069, 1.0013081559113093, 3.764922227178301, 3.768116227218083, 3.1682556612151007, 0.6207129784992763, 0.219497786834836, 0.6610332663570131, 1.990216817174639, 53.20492397035871, 38.670967033931184, 29.967361654554093, 18.8690961088453, 45.66808441707066, 16.17529341152736, 0.19582986113216194, 0.015988301984699707, 0.017395341037107364, 0.08813041488506965, 0.047549922418381484, 0.008534763590432703, 0.07574704222913299, 0.027350767814953412, 0.04094301337110145, 0.08277459549052374, 0.008269218910884644, 0.02474387189639466, 0.010905210411043038, 0.031199912074953318, 0.03893383386145745, 0.09223405218550138, 0.12639731328402246, 0.1512545615966831, 0.11493635470313684, 0.16092042864433356, 0.09895699750632048, 0.18303065507539681, 0.2921494948012488, 0.08972879233104841, 0.09182291424700192, 0.15335257830364363, 0.1393026015056031, 0.08547910715320281, 0.08058467800063746, 0.145627552111234, 0.1506831401160785, 0.12163686087088925, 0.15730356558093003, 0.17833760833101614, 4.398785974298205, 53.02588626316616, 51.26134259360177, 35.8458433832441, 36.33464568001883, 48.422096729278564, 51.010363238198416, 56.004783970969065, 3.505372268812997, 0.4221752333853926, 0.2311067474739892, 0.44371041495885166, 0.09608756112200872, 0.9901029914617538, 27.65817996433803, 52.6414806502206, 55.30510037285941, 49.09552655901228, 51.908570766448975, 51.38170971189226, 51.0760897227696, 47.72540085656302, 50.52818257468087, 51.93508161817278, 49.795481136866975, 49.586715562003, 46.47818183898926, 42.82129280907767, 40.45129701069423, 37.501613003867014, 38.00317219325474, 38.13525397436959, 38.81282145636422, 38.13390602384295, 40.23770938600813, 41.266935620989116, 40.14207438060215, 39.969835485730854, 40.76132215772356, 37.893738065447124, 37.07122768674578, 39.170876026153564, 39.714266845158164, 42.013946873801096, 39.194037846156526, 41.77823271070208, 40.13077660969326, 38.936464650290354, 39.98469420841762, 39.002628871372764, 38.58373587472098, 38.20987067903791, 37.52870403017317, 40.33727012361799, 38.272821358272004, 39.85987329483032, 41.10829087666103, 40.503940037318635, 47.4272050176348, 45.94936834062849, 44.682287897382466, 44.280074051448274, 43.91756221226284, 42.41968693052019, 39.85032646996634, 40.484294005802695, 40.91291448048183, 43.45093856539045, 50.483922549656455, 51.99610069819859, 52.103168964385986, 49.42657000677926, 46.95489427021572, 44.512866497039795, 50.11991684777396, 48.53680453981672, 48.86131320680891, 46.587668078286306, 47.91879006794521, 50.282424790518625, 51.19367756162371, 49.84126629148211, 42.94386945452009, 37.24326160975865, 37.60435601643154, 37.197931562151226, 39.47857700075422, 37.19102505275181, 39.25053364889962, 36.6540196282523, 37.859403542109895, 36.98816544669015, 36.76841824395316, 36.126290048871724, 38.33852699824742, 36.226910386766704, 35.47352416174752, 38.74836301803589, 36.714496748788015, 36.31542696271624, 36.652188777923584, 35.496227400643484, 36.40990856715611, 34.626629080091206, 36.36173670632498, 34.93718923841204, 36.00293173108782, 36.18808037894112, 35.01075676509312, 35.82913991383144, 39.07956280027117, 44.03299610955374, 43.99164737973894, 45.29288169315883, 44.389681884220664, 46.867364338466096, 46.02593054090227, 46.39249665396554, 44.11592633383614, 45.167803696223665, 42.36446264811924, 43.386292525700156, 45.70400660378592, 44.77592876979283, 47.520432472229004, 48.767401354653494, 40.47331237792969, 11.430996537208557, 0.5348418205976486, 4.160997773919787, 5.193206088883536, 4.253749711172921, 1.3853721129042762, 0.5541992304580552, 1.6864475458860397, 3.1034765200955525, 59.75885050637381, 40.06273637499128, 31.04278646196638, 29.50836018153599, 52.544918060302734, 20.35805685179574, 0.24499771637575968, 0.18298610246607236, 0.1244489135486739, 0.14679096825420856, 0.11602811754814216, 0.16694263049534389, 0.22788243048957416, 0.08667191064783505, 0.12153798474797181, 0.22746004244046553, 0.05101927196873086, 0.09554942856941905, 0.14612251626593725, 0.1050816106476954, 0.11720312306923525], [0.022126336548743502, 0.049824789099927456, 0.03945080290681549, 0.038709578037794144, 0.04005400696769357, 0.050609406283391375, 0.03204059660700815, 0.05410085911197322, 0.034119037578680685, 0.03823084783341203, 0.008098535971449954, 0.051069531057562144, 0.06910132776413645, 0.13134177082351275, 0.012635125263061906, 0.043653021167431555, 0.04455277895820992, 0.05612171620928815, 0.05867250237081732, 0.05064153152384928, 9.591993365968976, 45.07334641047886, 32.03713968821934, 27.273890733718872, 37.976428576878135, 28.65316026551383, 51.37296540396554, 6.877868490559714, 0.37373963956321987, 0.13831888857696736, 0.1289879735559225, 0.07294598860400063, 0.003733352683151939, 4.400933401925223, 34.44618088858468, 50.921936988830566, 49.5181542124067, 49.84381628036499, 49.51956122262137, 47.296054295131135, 47.83644001824515, 45.253179686410085, 47.621344634464805, 46.640248571123394, 45.894408089774, 44.165828296116416, 40.41979387828282, 38.20245347704206, 34.50593887056623, 33.78152315957205, 34.100924900599885, 36.61418907982962, 36.38812249047415, 38.02808148520333, 39.55885648727417, 39.74456793921334, 37.30569117409842, 36.82354872567313, 35.10015228816441, 37.060753277369905, 34.895270756312776, 36.66222892488752, 37.115334851401194, 36.481534072331016, 33.88776459012713, 35.36892250605992, 35.435868399483816, 36.63850777489798, 34.36779478618077, 35.319048336574006, 35.52190794263567, 35.25386381149292, 35.30726071766445, 35.22304507664272, 35.05490909303938, 36.471775327410015, 38.59833403996059, 43.86410624640328, 43.81482267379761, 44.45961202893938, 43.01358420508248, 43.613456930433, 39.203984192439485, 38.85183211735317, 36.628085477011545, 40.335404532296316, 40.71261181150164, 45.803483963012695, 47.48355490820748, 48.53436919621059, 46.12129456656319, 44.49494014467512, 44.03439964566912, 48.48267807279314, 45.87270539147513, 47.01498229163033, 39.161513328552246, 43.0217205456325, 47.36947590964181, 47.534120423453196, 46.9392260823931, 38.917857374463765, 33.15180792127337, 34.71138320650373, 34.0720134462629, 33.5358487537929, 33.467759881700786, 34.7131723676409, 33.749050753457205, 33.90899133682251, 33.92734152930123, 33.73843043191092, 33.26747110911778, 32.75917216709682, 32.91135508673531, 33.95482165472848, 33.916703837258474, 32.946335792541504, 32.77981526511056, 32.62339741843087, 33.30834041322981, 32.920755999428884, 31.6926132610866, 33.32334852218628, 31.76708057948521, 31.47074338368007, 31.533749648502894, 32.58227103097098, 31.69187327793666, 34.42317887714931, 33.03477593830654, 36.05300045013428, 39.03687654222761, 41.35584824425833, 40.25184897014073, 43.29482991354806, 41.15597288949149, 42.51248359680176, 41.25212900979178, 42.19058745247977, 39.49745178222656, 39.05017886843, 43.42385448728289, 43.80343805040632, 42.11023848397391, 24.05368730000087, 1.9171756165368217, 0.48634133168629234, 3.8116775240216936, 3.506780798946108, 2.181845311607633, 0.48545554493154797, 0.31841097133500235, 0.44618839770555496, 11.025999069213867, 49.852275712149485, 27.05623667580741, 24.509126084191458, 24.566181216921123, 34.22903578622, 3.125172487327031, 0.09398681670427322, 0.010679516093140202, 0.03274434259427445, 0.054977882586951764, 0.10224997544927256, 0.041062567848712206, 0.09196694687541042, 0.050356757161872726, 0.023944220073255043, 0.021826754856322492, 0.07753404562494584, 0.018388768890872598, 0.030735288613608906, 0.06852014216461352, 0.02850374300032854, 0.027649425003411512, 0.015244061027520468, 0.0442729579018695, 0.08452084607311658, 0.055820531477885585, 0.05339277728593775, 0.026110668733183826, 0.014217670790718069, 0.03549012954213789, 0.025984179627682482, 0.04620156816339918, 0.035751219639288526, 0.051148329329277785, 0.0698435025821839, 0.02402895383004631, 0.05356263156448092, 0.04272810329816171, 0.07462548491145883, 0.034798515761005025, 0.006611559132579714, 17.778242826461792, 53.67059918812343, 29.754951749529155, 32.493566853659495, 47.0398394720895, 33.69737352643694, 56.03355993543352, 6.6198827454022, 0.41726597824266976, 0.14178532042673656, 0.28199719956942965, 0.02579585392959416, 0.041189942442412884, 5.622792363166809, 36.29953990663801, 53.03665944508144, 50.71627378463745, 50.45211369650704, 50.98625646318708, 47.99005079269409, 47.5229685647147, 45.57238687787737, 48.86876514979771, 48.73066275460379, 46.91145065852574, 45.61208888462612, 41.6066677910941, 39.378404821668354, 36.65376254490444, 35.01072897229876, 35.87007522583008, 36.167503288814, 37.70834970474243, 39.995741844177246, 41.08398607798985, 41.35668897628784, 38.097452299935476, 38.90853289195469, 36.92546490260533, 38.668371881757466, 37.34511872700283, 38.763899190085276, 37.79624441691807, 38.334691592625205, 36.9293281010219, 36.45305688040597, 37.3279254095895, 38.9111384664263, 37.63378858566284, 36.362372466496055, 37.454302719661165, 37.09424359457833, 38.336553709847585, 36.30226707458496, 37.085818903786794, 38.57279246194022, 39.19332912990025, 45.411056654793875, 45.737378801618306, 46.84860072817121, 45.75249113355364, 44.823708057403564, 40.677099568503245, 41.21063436780657, 38.605299609048025, 41.620883805411204, 42.78870575768607, 47.21144955498831, 50.15904215403965, 50.663710662296836, 48.30310535430908, 43.504929542541504, 48.951872553144185, 51.67229379926409, 46.34907041277204, 49.10692507880074, 45.545104776109966, 44.8082309450422, 47.7792945589338, 48.236975874219624, 47.87700360161917, 40.89374787466866, 33.421728066035676, 35.44030829838344, 35.52509021759033, 35.8915764263698, 34.95324305125645, 34.85475581032889, 35.2405058997018, 35.990178312574116, 35.18733828408377, 35.88130351475307, 34.380433559417725, 33.90747315543038, 34.969932624271934, 35.78779813221523, 35.633978911808555, 35.273711340767996, 33.795065198625835, 34.22525944028582, 33.968061447143555, 35.653454712459016, 33.38544804709298, 33.58271435328892, 33.594519342694966, 34.46582344600132, 33.643372126988, 33.992279393332346, 35.06542866570609, 36.46200616019112, 36.84106513432094, 39.291597502572195, 40.11630351202828, 42.83373703275408, 44.12333311353411, 45.22440719604492, 43.191114153180806, 43.43526690346854, 42.643842765263145, 43.007542746407644, 42.88208607264927, 42.02652311325073, 44.238287585122244, 45.20837075369698, 43.38539620808193, 26.364500079836162, 2.9889117990221297, 2.036100115094866, 5.386377734797342, 6.050526074000767, 5.368612493787493, 0.55081116940294, 0.39143822129283634, 1.0551754768405641, 12.844704815319606, 55.58515793936593, 34.81433119092669, 27.806814091546194, 23.622725282396587, 44.86878449576241, 4.097397003855024, 0.15445788470762117, 0.0029142298735678196, 0.04415687073820403, 0.04050948038431151, 0.04615976701357535, 0.012829020885484559, 0.021200731662767272, 0.044222447755081315, 0.054351031580673795, 0.005418167008818793, 0.029942505261195556, 0.020613495227215544, 0.017035318837900246, 0.054634007824850936, 0.0052123618245657, 0.12394154577382974, 0.15284723256315502, 0.1541188343295029, 0.17405712444867405, 0.1642464715987444, 0.17541423519807203, 0.13723672021712574, 0.14242099917360715, 0.13362604539309228, 0.09151956838156496, 0.06860083354903118, 0.08228399431599037, 0.12076543191713945, 0.22003237743462833, 0.07499709818512201, 0.21303521575672285, 0.16995790441121372, 0.14871438433017048, 0.12222354938941342, 0.17989222705364227, 25.010018246514456, 59.732245853969026, 40.943837438310894, 38.686319078717915, 48.42783941541399, 37.07899577277047, 60.70626517704555, 10.384819303240095, 0.4719796766127859, 0.4272751568683556, 0.6365801127893584, 0.22257612379533903, 0.20700827773128236, 6.314626233918326, 36.55508770261492, 54.592388902391704, 50.672388962336946, 53.71270179748535, 52.76800734656197, 47.95033141544887, 48.768790994371685, 46.29077502659389, 49.91527850287301, 50.645829473223, 49.82480948311942, 48.33676937648228, 44.462606702532085, 42.09790195737566, 38.85291256223406, 37.38864919117519, 37.67420973096575, 38.82825687953404, 38.38632018225533, 42.161068030766074, 43.41437019620623, 44.85710457393101, 38.99625389916556, 40.84864364351545, 39.16447673525129, 41.00780255453927, 39.12377766200474, 41.19081115722656, 40.36364548546927, 40.02110971723284, 37.425756045750205, 37.71996709278652, 38.60027953556606, 41.64037350245884, 37.87678446088518, 38.5862580708095, 39.46946096420288, 39.35288061414446, 39.52745410374233, 38.035151277269634, 37.73054225104195, 38.9153664452689, 43.58347545351301, 47.9487750189645, 48.02077572686331, 48.67388902391706, 47.85275091443743, 48.36009447915213, 42.96637119565691, 43.251952580043245, 40.81636231286185, 44.77282987322126, 44.25149958474295, 48.1273124558585, 52.284756660461426, 51.465525831495015, 50.14514228275844, 43.42237104688372, 47.22496032714844, 52.968181473868235, 47.57575402941023, 48.50844199316842, 44.16211795806885, 46.918916497911724, 49.59205525262015, 52.239916460854666, 49.19467387880598, 42.885219710213796, 37.045703479221885, 37.68506976536342, 37.19109453473772, 35.82287263870239, 35.843317713056294, 37.33050319126674, 37.37931081226894, 38.352176734379356, 37.52085951396397, 37.76486982618059, 36.515938077654155, 35.96693658828735, 37.09902048110962, 37.368561949048726, 37.292361055101665, 36.536782673427034, 35.64317832674299, 35.40232597078596, 36.20340463093349, 35.97678913388933, 34.59932960782732, 35.97164051873343, 35.38929462432861, 35.683363233293804, 35.6290283203125, 35.53691257749285, 36.08950628553118, 37.729962076459614, 37.405852930886404, 41.086546489170615, 43.09999895095825, 44.14698478153774, 45.082823753356934, 46.364370346069336, 44.2171824319022, 44.79870843887329, 43.54947444370815, 43.62863874435425, 44.83653443200247, 42.99346569606236, 44.37334666933332, 44.393704891204834, 45.56922197341919, 28.69596811703273, 3.225700761590685, 1.3619086976562227, 7.939992274556841, 8.082140258380345, 5.030407190322876, 1.6820479248251234, 0.6840712130069733, 2.3730938264301846, 15.36579874583653, 60.830915859767366, 36.52642985752651, 35.20559120178223, 32.58269487108503, 52.06415135519845, 5.685047788279397, 0.29824572482279366, 0.1459066742765052, 0.1892380834157978, 0.10740924360496656, 0.20565156053219522, 0.1961782481521368, 0.18372850120067596, 0.13276768502380165, 0.20300128417355673, 0.16906185820698738, 0.2648558850799288, 0.09972932642059666, 0.13334477905716213, 0.1393236903739827, 0.12559273360030992], [0.014491833713171738, 0.011589926883711346, 0.02355919555494828, 0.014893368684819766, 0.03532273834571242, 0.014179556630551815, 0.04394590063020587, 0.03440081620854991, 0.05906644623194422, 0.10000690152602536, 0.0522865277182843, 0.06818493229470082, 0.021209637434887033, 0.0302600189378219, 0.04796206798138363, 0.04168529675475188, 0.05727741401642561, 0.018597776336329322, 0.025653970560857227, 0.18594573651041302, 3.5646093530314307, 33.81831039701189, 35.57989065987723, 24.73379782267979, 30.925486973353795, 29.185136931283132, 44.87317228317261, 20.478785276412964, 0.2942836231419018, 0.11277777196041175, 0.11239914942000594, 0.0497202947070556, 0.02878644104514803, 0.1866527564291443, 10.856399621282305, 39.997121061597554, 49.715302399226594, 52.53037200655256, 48.36413138253348, 49.722309657505576, 47.06730570111956, 47.5564032963344, 46.99315105165754, 45.49909380504063, 44.18169103349958, 47.076317514692036, 40.788927350725444, 40.05531569889614, 36.71725170952933, 37.1838892527989, 36.0375337600708, 37.77164431980678, 38.25036825452532, 41.1957791192191, 40.672135080610005, 41.95538050787789, 40.41091408048357, 42.00192649023873, 37.03923123223441, 36.7426369530814, 35.55626678466797, 35.57274791172573, 36.167416436331614, 35.25951964514596, 35.87894460133144, 37.411831855773926, 36.653439453669954, 36.68825340270996, 36.24726513453892, 36.018002373831614, 34.054260798863, 36.94113656452724, 34.25860384532383, 37.47604710715157, 36.632132802690776, 37.04796164376395, 40.24500152042934, 46.16150726590838, 46.91818693705967, 46.633484499795095, 44.82476070949009, 43.55933393750872, 41.20702130453927, 41.742831638881135, 40.042569228581016, 41.67040014266968, 43.81293623788016, 47.2649576323373, 45.80766677856445, 48.89317764554705, 49.31759793417794, 51.69731773648943, 40.116890634809224, 47.58234439577375, 46.92290823800223, 48.842170919690815, 35.83737700326102, 45.2431777545384, 47.11321244921003, 46.47721951348441, 45.095257554735454, 38.742623805999756, 33.351926462990896, 32.96344920567104, 35.87002658843994, 34.893596240452354, 34.67219189235142, 34.36094386237008, 31.871216705867223, 35.16005270821707, 33.99164015906197, 32.78077759061541, 32.74829476220267, 33.45593057359968, 34.90198619025094, 32.6988513810294, 32.97906180790493, 34.37279748916626, 32.11300359453474, 33.758674008505686, 32.90953813280378, 32.19203935350691, 32.662161418369834, 34.75199542726789, 31.820696353912354, 32.7153012411935, 33.24296481268746, 33.760602133614675, 33.50207008634295, 34.176462241581504, 34.157340799059185, 34.92849356787545, 37.256619521549766, 37.8294220651899, 39.68861757005964, 43.09257827486311, 42.993163449423655, 43.319996288844514, 40.37771558761597, 42.14951317650931, 38.77985225405012, 41.219736507960725, 43.83953046798706, 44.4212440763201, 38.61945308957781, 10.583986810275487, 0.4515067551817213, 2.8032305283205847, 4.215207619326455, 4.758255805288043, 3.2115683427878787, 0.4771565188254629, 0.25931447957243237, 0.32841477596334046, 27.990437609808787, 39.77652965273176, 22.96117513520377, 19.5010312965938, 27.557142734527588, 14.638782671519689, 0.21068163562033856, 0.03946975438988634, 0.06155029830655881, 0.015086486536477293, 0.08389461253370557, 0.03100418864882418, 0.013936187323581959, 0.02756903726341469, 0.02733823188048388, 0.02027800037259502, 0.06994003097393683, 0.059745591932109425, 0.022192478446023803, 0.009217298573016055, 0.037108455917664936, 0.05926001870206424, 0.011305281443388333, 0.005398844451909619, 0.06793461394097124, 0.03336067291508828, 0.030942187511495182, 0.030717422786567892, 0.02507289352693728, 0.02042322382996125, 0.050197817119104524, 0.026805685367435217, 0.030393164471856186, 0.024231557601264546, 0.029308360003467118, 0.037715015334210227, 0.04153456020035914, 0.007087163410947791, 0.0557820212229022, 0.03181046127740826, 0.04411243687250784, 0.20105809558715138, 5.771787362439292, 49.05816609518868, 38.296695368630544, 26.072936296463013, 42.77322169712612, 32.660973276410786, 52.23830100468227, 19.072044304439, 0.2813465659107481, 0.10620247585965054, 0.23342155611940793, 0.09275099408945867, 0.01242997104834233, 0.5059805235692433, 12.565489717892238, 43.161084038870676, 49.647567885262625, 52.517615113939556, 49.953118392399375, 50.76314285823277, 48.03294549669538, 48.011611052921836, 48.536505767277305, 48.988322802952354, 47.30025795527867, 47.96081624712263, 43.30104507718767, 40.66036135809762, 38.982263701302664, 38.075249331338064, 38.18482937131609, 38.7768680027553, 40.59215089253017, 43.286922863551546, 41.9640657561166, 43.6654120853969, 42.40876088823591, 42.994851861681255, 38.546389307294575, 38.762516498565674, 36.314659186771934, 37.069122382572715, 37.669745513371055, 37.49338286263602, 38.35309737069266, 39.394552435193745, 39.030216693878174, 37.71572174344744, 37.91634055546352, 36.70319550377982, 36.84935780933925, 38.04041106360299, 36.170588288988384, 38.386281967163086, 37.34991298403059, 38.21191692352295, 41.312932695661274, 48.559358392442974, 48.02974585124424, 47.88610921587263, 45.73047229221889, 45.876141275678364, 43.09157426016671, 43.21359852382115, 39.62815087182181, 43.17057180404663, 44.82402420043945, 48.262579986027305, 48.98464720589774, 51.09374162128994, 48.888946192605154, 48.99800164358956, 45.31128747122628, 48.33166592461722, 48.68854624884469, 51.43404006958008, 42.89283493586949, 44.768775599343435, 47.518202100481304, 49.37038687297276, 47.62248413903372, 40.30568013872419, 35.92567818505423, 35.07144233158657, 39.043612820761545, 36.031311648232595, 35.78960118974958, 33.91897242409842, 33.82037401199341, 35.96792670658657, 35.91299424852644, 35.33799260003226, 34.656006063733784, 33.9288284437997, 35.846378394535606, 34.910876410348074, 34.00846522194998, 35.05084787096296, 33.880455085209434, 34.396657603127615, 34.340603010995046, 32.87260845729283, 33.76969037737165, 35.53347669328962, 32.44585009983608, 33.79504435403006, 34.446747166769846, 35.12800761631557, 35.47722407749721, 35.37228543417794, 35.63142544882638, 37.25317668914795, 38.96367727007185, 40.545736925942556, 42.58966071265084, 44.298948832920615, 45.01988697052002, 43.80628333772932, 43.38198811667306, 43.115444796425955, 41.74647944314139, 43.12719767434256, 44.22211912700108, 44.531491143362864, 41.223467690604075, 12.581005913870674, 1.1186459681817462, 4.415621893746512, 5.6249119979994635, 7.128033169678279, 5.881465545722416, 0.6877893677779606, 0.15861237820770058, 0.4950996445758002, 30.39516224179949, 46.94715397698538, 31.53164781842913, 20.83832676070077, 29.013177701405116, 23.65691041946411, 0.12794450883354458, 0.05354081666363137, 0.057299344268228324, 0.044095402250864675, 0.06318871610398803, 0.01975286176561245, 0.015455383973728334, 0.05782550067773887, 0.03511092006894095, 0.022927849254171764, 0.01778161575618599, 0.0618582514247724, 0.03447114297055772, 0.03688274124371154, 0.0173414551786014, 0.020167024273957525, 0.06797181123069354, 0.06773464288562536, 0.1337119886385543, 0.0554004266991147, 0.11941501152302537, 0.13044199267668383, 0.1313849256506988, 0.10008647332766227, 0.13567239844373294, 0.21319365368357726, 0.1914288287184068, 0.1826671910073076, 0.18971292222184793, 0.11589462256857327, 0.12440341099032334, 0.1257716225726264, 0.16994189098477364, 0.16673480878983224, 0.19244246504136495, 0.3121099051620279, 8.017781700406756, 54.72598886489868, 46.21335472379412, 35.20652226039341, 41.314037459237234, 39.31112888881138, 54.42108106613159, 27.241461753845215, 0.2493948404278074, 0.5040915906429291, 0.7375143681253705, 0.3176301675183432, 0.12908428481646947, 0.6891245618462563, 12.777383719171796, 43.79762240818569, 51.226834365299766, 56.579973220825195, 52.11083630153111, 52.52692570005144, 48.71664128984724, 49.33885942186628, 51.379541873931885, 49.44741460255214, 48.210649149758474, 51.02458620071411, 44.62697328839983, 42.75768552507673, 40.858763694763184, 41.356553486415315, 40.329366547720774, 40.94712393624442, 42.64093147005354, 45.89244522367205, 44.2350948878697, 45.69367463248116, 44.14573410579136, 45.43118558611189, 41.19643224988665, 40.28955684389387, 38.78334372384207, 39.51776136670794, 38.27107736042568, 38.58551113946097, 39.41971186229161, 41.78816516058785, 40.96275738307408, 40.065800530569895, 39.85139996664864, 38.32747936248779, 38.975739342825754, 40.386571066720144, 38.04891913277762, 41.16774313790457, 38.71958357947213, 40.24317067010062, 43.077361719948904, 50.475779260907856, 51.08790166037423, 50.02969796316964, 49.14117622375488, 47.56418875285557, 46.01619611467634, 45.55056258610317, 42.86888796942574, 45.89318173272269, 47.73390545163836, 51.03657184328352, 50.562197480882915, 52.05388191768101, 51.82698849269322, 47.317604133060996, 45.32325921739851, 50.0864508492606, 50.74985442842756, 49.58389459337507, 41.63934169496809, 48.66894885471889, 49.3771961075919, 52.01888731547764, 48.39699983596802, 43.08499779020037, 37.60710055487496, 37.470168931143625, 39.735472747257774, 37.84708091190883, 39.637402398245676, 37.00603968756539, 34.01781402315412, 38.051507336752756, 37.93452051707676, 36.17162357057844, 35.38804742268154, 35.33766256059919, 37.93707398005894, 35.576836926596506, 35.43086222239903, 36.89813763754708, 34.21413190024239, 36.39345175879342, 36.79933425358364, 36.08441325596401, 36.7818352154323, 38.15525088991438, 34.52597747530256, 34.983867236546104, 36.391742501940044, 37.52163771220616, 37.19400930404663, 36.96390928540911, 37.83007172175816, 37.911362171173096, 41.95531102589199, 41.555414404187886, 43.9908309664045, 46.183414936065674, 45.97309296471732, 46.66951090948922, 44.03891944885254, 43.52308518545968, 43.71564061301095, 45.25526067188808, 45.402232442583355, 46.361712660108296, 43.42796087265015, 13.978928753307887, 0.8744991347193718, 6.826510012149811, 8.584255303655352, 10.584163120814733, 10.44011219910213, 1.3933393082448413, 0.36816335735576494, 0.783622396843774, 36.47136885779244, 51.087342330387656, 32.90624468667166, 27.865720919200353, 40.07060520989554, 32.48527765274048, 0.24736428367240088, 0.20704965479671955, 0.16535332506256445, 0.07739417920155184, 0.20258246521864617, 0.10754051977502448, 0.15499821571367128, 0.11154567450284958, 0.12462298492235796, 0.13438430827643189, 0.13554141404373304, 0.1642444088522877, 0.10925728801105704, 0.09468763481293406, 0.14085540175437927, 0.10874280240386724], [0.025366042707381502, 0.02909528643691114, 0.014551901025697589, 0.03371026772739632, 0.041339868147458346, 0.02402238730740334, 0.01997098702538226, 0.013025723098378097, 0.022997053040723716, 0.030620032655341283, 0.03945350008351462, 0.05795102965618883, 0.07380143127271108, 0.007748108257406524, 0.01712388631754688, 0.09272666182368994, 0.017146724109937037, 0.028158110832529407, 0.05839352948325021, 0.06123811112982886, 0.09605408220418862, 12.712037648473467, 42.10122667040144, 31.04148714882987, 27.030936547688075, 31.281106199537003, 32.48777553013393, 37.02606439590454, 0.16963123051183565, 0.07817243172654084, 0.7005067425114768, 0.09361421276948281, 0.059141933252768855, 0.028140891310093657, 0.8779739396912711, 17.428642477308, 43.9454870223999, 49.075776304517476, 50.2201863016401, 49.297604492732454, 48.423580169677734, 45.68106712613787, 46.03891324996948, 47.08515909739903, 46.009758608681814, 46.34996325629098, 45.837585721697124, 42.06617300851004, 40.66706984383719, 35.84250824792044, 36.73420878819057, 38.65772724151611, 38.85846764700753, 39.887221404484336, 43.0950414112636, 44.13521800722395, 44.9476500238691, 44.320217268807546, 42.969709805079866, 38.47474990572248, 36.44037641797747, 36.50036369051252, 37.46836239950997, 35.666447843824116, 37.625266620091026, 35.40843343734741, 35.03203909737723, 35.61673695700509, 35.5615439414978, 35.30680908475603, 35.79920360020229, 35.95092446463448, 35.92922524043492, 35.30171258108956, 37.09109606061663, 33.5921847479684, 38.350967747824534, 46.63175787244524, 47.9942683492388, 45.646753447396414, 48.132391589028494, 46.2965316091265, 43.88627099990845, 43.41286938531058, 42.766648701259065, 42.80539533070156, 45.182123933519634, 45.165566376277376, 49.19030346189226, 45.22897563661848, 50.4632134437561, 52.06700359072004, 43.04744277681623, 46.49470812933785, 49.88146162033081, 43.7896979876927, 34.813987255096436, 50.28777837753296, 44.68506717681885, 47.07871464320591, 44.00585297175816, 40.70723043169294, 32.015423093523296, 34.98664651598249, 33.08993073872158, 34.281859466007774, 35.31776639393398, 34.69381121226719, 32.505545548030305, 34.05104725701468, 32.29956272670201, 34.29272297450474, 32.61077948978969, 35.04570620400565, 33.94808190209525, 34.32722772870745, 34.512946128845215, 36.36991473606655, 34.50191238948277, 35.47726576668875, 33.16904640197754, 34.14776618140084, 33.41483197893415, 33.09176158905029, 32.85105167116438, 32.05109167098999, 31.974894251142228, 36.93200315747942, 37.1218626839774, 39.74195194244385, 39.51408576965332, 38.89593233380999, 37.26923050199236, 39.39767565046038, 39.61645705359322, 43.21760416030884, 41.3238969530378, 42.77680696759905, 41.49341562816075, 41.473672321864534, 37.13456746510097, 40.399991512298584, 42.77070992333548, 45.516043935503276, 27.356049707957677, 3.846475839614868, 0.6202357241085598, 3.0277439781597684, 3.557601660490036, 4.198695659637451, 5.447859738554273, 0.05035428050905466, 0.02443834623721029, 3.1719751187733243, 39.94791391917637, 29.979965686798096, 23.667556796755107, 23.801116807120188, 28.514731304986135, 3.163519161088126, 0.20825432586882794, 0.02208449468681855, 0.04455895023420453, 0.0900754558720759, 0.10694321896880865, 0.08523257502487727, 0.035249541380575726, 0.021893383602478673, 0.017812463654471294, 0.03218245453068188, 0.04263402441782611, 0.033393201883882284, 0.0242440799650337, 0.0032247149876119302, 0.023470466923234717, 0.02466520933168275, 0.03166820301807352, 0.06765331367829017, 0.04244749514119966, 0.039280894345470836, 0.017996675734009062, 0.015412213879504373, 0.010724070398802204, 0.011740522642087723, 0.0188745830008494, 0.036848458261894326, 0.004675943845151258, 0.07868157726313386, 0.05659575095134122, 0.03251328784972429, 0.011596221144178083, 0.03441878720851881, 0.04783825230385576, 0.011678652122749813, 0.0367722146745239, 0.015333977095516664, 0.14796102046966553, 20.779070786067418, 50.21812268665859, 27.213307653154644, 31.858355590275355, 38.12700646264212, 36.82796083177839, 40.7789705821446, 0.1015197021354522, 0.05143732757174543, 0.19272352781678947, 0.22421253312911305, 0.020651510151635324, 0.00586162314617208, 1.6277391761541367, 19.074969496045792, 46.93374047960554, 51.613432134900776, 50.008436475481304, 50.95890140533447, 49.661728313991, 47.03586162839617, 47.363799231392996, 49.34614808218819, 47.15118088041033, 47.089588574000764, 47.28697994777134, 43.412935393197195, 42.11565807887486, 38.380775519779746, 38.936318738119944, 40.93997423989432, 40.35753801890782, 41.65709434236799, 45.258178915296284, 45.25209576742989, 46.83608702250889, 45.634389128003804, 43.37255246298653, 39.674874033246724, 38.09381839207241, 37.73799071993147, 38.029818534851074, 38.8967661176409, 37.82899822507586, 37.09151642663138, 37.29756872994559, 38.1453149659293, 36.65004873275757, 36.433779103415354, 37.50075142724173, 38.242329188755576, 36.86988973617554, 36.536004475184846, 39.50503921508789, 34.94415133340018, 40.47098125730242, 47.72777019228254, 49.26125846590315, 47.82557998384748, 47.674699851444785, 48.04059893744332, 44.99808699744088, 46.4284987449646, 44.90304258891514, 45.623087882995605, 47.46060848236084, 48.52795948301043, 51.2728453363691, 47.48532322474888, 45.37353638240269, 49.46421882084438, 47.00188146318708, 49.04121249062674, 50.45693574632917, 51.41699961253575, 38.009144169943674, 50.38088076455252, 46.90226513998849, 47.36355951854161, 45.3560026032584, 41.851154054914204, 34.92011751447405, 35.257761750902446, 36.278611932482036, 34.900099754333496, 36.11421407972063, 35.48173345838274, 33.90151160103934, 35.29663692201887, 34.40838268824986, 35.41553102220808, 35.07123041152954, 35.688741139003206, 35.2669437953404, 35.536460944584434, 36.08678606578282, 38.21240677152361, 36.4379688671657, 36.78264468056815, 34.45691932950701, 35.60586650030953, 34.68595279966082, 34.728381974356516, 33.86421019690377, 33.27705267497471, 33.90858486720494, 37.68264136995588, 39.95769003459385, 40.32954025268555, 41.57798562731062, 39.0462600844247, 38.680058751787456, 41.1125362260001, 41.03841631753104, 43.50947713851929, 43.621346609933035, 45.14647272654942, 43.44919804164341, 42.555294922419954, 39.96177210126604, 43.924110889434814, 42.07409395490374, 46.29641348975045, 28.82325564111982, 5.056472488812037, 2.0564683250018527, 4.972102250371661, 6.290195499147687, 6.405896033559527, 8.687687924930028, 0.18371993808874063, 0.04949281244937863, 4.000207339014326, 44.65792751312256, 35.01983806065151, 33.629718916756765, 20.26809331348964, 36.68910803113665, 6.593978124005454, 0.15438294730016164, 0.018728658956076418, 0.09054762125015259, 0.0642021827931915, 0.07258237525820732, 0.0183705434402717, 0.0343613085070891, 0.011346423566075308, 0.009634846122935414, 0.03939009777137211, 0.0341762584368033, 0.05278704907479031, 0.009736162427413677, 0.024669916668374623, 0.020045522400843244, 0.00926584012008139, 0.10306020732969046, 0.1378796457179955, 0.16852429562381335, 0.14975061586924962, 0.11258686613291502, 0.11346514150500298, 0.14119243009814195, 0.03730460003550563, 0.16768956184387207, 0.1878144626638719, 0.11377349495887756, 0.16456637371863636, 0.13649873196014337, 0.09069271917854037, 0.08644612812037979, 0.15673232051943028, 0.1280411865030016, 0.07242742500134877, 0.2049387323537043, 0.18918437058372156, 0.25699497546468464, 28.2263081073761, 56.16360936846052, 39.711678641183035, 37.34635203225272, 41.78070279530117, 40.94245474679129, 47.19074044908796, 0.23463529241936548, 0.20675806115780557, 2.259473843233926, 0.40695905845080105, 0.12450209712343556, 0.08436345987554107, 2.1044121980667114, 18.721862043653214, 48.59214346749442, 51.65542009898594, 53.399529116494314, 50.79894345147269, 51.27823713847569, 47.47205216544015, 48.91609280450003, 50.10856349127633, 49.83061817714146, 49.464899744306294, 50.6421399797712, 46.70515169416155, 45.67647436686924, 40.2989855493818, 41.59300763266427, 43.63065024784633, 43.773786612919395, 43.67734214237758, 47.327293395996094, 48.97765384401594, 49.947132519313264, 47.64587524959019, 48.78980582101004, 42.5468042237418, 40.713063444410054, 39.03216913768223, 40.47766889844622, 40.608051845005576, 40.88848114013672, 38.62266663142613, 38.91727025168282, 39.20959138870239, 38.39804874147688, 39.0625501360212, 39.74517590659005, 40.1887662751334, 38.1294070652553, 37.77972854886736, 43.32697575432913, 36.389189038957866, 42.752929483141216, 50.12176506859915, 52.49915027618408, 50.10373796735491, 51.03165946687971, 50.00895411627633, 46.765507221221924, 48.20667825426374, 45.95707736696516, 45.462858949388774, 48.378792081560405, 49.01807151521955, 52.98637533187866, 47.94099651064192, 43.808353900909424, 48.38416303907122, 48.85389600481306, 48.08999368122646, 51.97637823649815, 46.79917471749442, 42.11879519053868, 51.58360004425049, 49.46792915889195, 49.14950711386544, 45.823866503579275, 44.88005794797625, 35.84176131657192, 37.194989000047954, 36.846717493874685, 37.596542767116, 40.42255231312343, 37.12117828641619, 34.96052476337978, 38.78410455158779, 35.54210983003889, 36.140499114990234, 35.214807987213135, 37.22276789801461, 38.24802671160017, 38.14032963344029, 39.42088610785348, 40.126281125204905, 36.74827194213867, 37.95245729173933, 36.81534290313721, 37.797363076891216, 36.48367411749703, 36.687614168439595, 36.883668013981406, 34.68479592459542, 36.63501283100673, 40.08847597667149, 42.28259202412197, 42.80035441262381, 44.98340892791748, 41.71426064627511, 41.052562849862234, 43.42088065828596, 42.9123524257115, 44.63925770350865, 45.123050349099294, 46.638535840170725, 46.357415199279785, 43.482549394880024, 41.62698779787336, 44.43864583969116, 43.038663727896555, 45.961353983197895, 31.414205891745432, 5.258290299347468, 1.6999358449663435, 7.949513912200928, 9.313275064740862, 13.0747674873897, 17.33477405139378, 1.2158163083451135, 0.14801619893738202, 5.901742994785309, 51.086546761649, 38.41404696873256, 36.760382652282715, 31.66957998275757, 44.64764417920794, 12.211965373584203, 0.36793895225439754, 0.07584257995975868, 0.23721478400485857, 0.27862194925546646, 0.2298337072134018, 0.16666572035423347, 0.14309850281902722, 0.09946635338876929, 0.13926354502992971, 0.08808412522609745, 0.10431363114288875, 0.11564351032887187, 0.09475773426571063, 0.09076478638287101, 0.1402031938944544, 0.07835887279361486], [0.019852708193606565, 0.0805204953732235, 0.05193117892901812, 0.06612713914364576, 0.016088577586093118, 0.015448439167812467, 0.022417568867760043, 0.04996093715141926, 0.06069532382701125, 0.07642831852925674, 0.050197579631848, 0.03280693405706968, 0.07837846888495342, 0.01686018386057445, 0.10387340440813984, 0.027278916045491184, 0.0478484201511102, 0.05747239105403423, 0.07504121653203454, 0.06436381661998374, 0.07758467790803739, 1.4746799149683543, 18.48078908239092, 37.64863688605172, 24.87285385813032, 31.267894199916295, 30.649938787732804, 45.85419191632952, 5.45696405002049, 0.19391069268541677, 1.028251315866198, 0.2306041158735752, 0.06994946261069604, 0.09493464191577264, 0.1394415111946208, 1.7273652702569962, 21.298589331763132, 45.53168085643223, 51.68055520738874, 48.794878005981445, 49.18490123748779, 44.95451831817627, 47.82312726974487, 45.71530784879412, 48.09289108003889, 48.1180921963283, 47.82598645346505, 43.21938637324742, 39.606566292899, 36.09529760905674, 38.01303168705532, 38.26506716864449, 40.27650465284075, 42.66227633612496, 43.88658366884504, 42.834247725350515, 45.199008056095664, 45.75356115613665, 47.06507880347115, 40.664064747946604, 36.4006917817252, 36.38584695543562, 35.53974396841866, 36.39173902784075, 36.155670506613596, 34.94032635007586, 38.060904775347026, 35.05040666035244, 35.71398047038487, 34.219940594264436, 35.612019130161826, 33.34335238592965, 36.41474103927612, 35.412320954459055, 35.97949545724051, 34.471757207598, 37.578018869672505, 46.473856585366384, 47.93179709570748, 46.149834292275564, 49.60733086722237, 47.055056027003694, 46.42768580572945, 44.59992047718593, 45.94871173586164, 43.505652155194966, 47.936518396650044, 45.78115245274135, 50.41828639166695, 47.67089571271624, 63.35511302947998, 43.77699668066842, 38.91818741389683, 54.39585910524641, 49.25739874158587, 33.30574526105608, 43.36630950655256, 49.242373262132915, 45.74631071090698, 45.18913466589791, 42.40286186763218, 36.55009542192732, 33.84181962694441, 36.65939405986241, 34.26102181843349, 33.48806251798357, 34.22585698536464, 33.32122932161604, 32.61534445626395, 34.10151202338082, 33.696775981358115, 32.38117279325213, 32.720543657030376, 32.710114410945344, 33.14385223388672, 32.45987156459263, 35.924396242414204, 40.63551459993635, 40.5307913507734, 39.43264593396868, 36.59803104400635, 34.73912736347744, 32.265971660614014, 33.23093400682722, 32.00036634717669, 33.02579886572701, 33.97674669538225, 39.596300329480854, 41.18614544187273, 40.31321893419538, 45.35842752456665, 44.77534164701189, 42.22343506131853, 43.37561314446585, 42.24850416183472, 42.096890994480674, 41.629958152770996, 44.280563899448936, 42.518535477774485, 41.09099333626883, 37.73195273535592, 39.61977481842041, 41.44052594048636, 41.659911836896626, 16.285974740982056, 0.7660827008741242, 2.833536616393498, 3.6921233449663435, 6.471602976322174, 5.601307230336325, 7.6797440222331455, 0.3072184276367937, 0.051244956108608415, 16.38920760154724, 48.184763635907856, 26.5910929952349, 19.936643396105083, 27.980027471269878, 25.09584413255964, 0.21800602759633744, 0.055548974978072305, 0.0036545934271998703, 0.04622989021507757, 0.033292388543486595, 0.04390875083793487, 0.04086752295760172, 0.10091107657977513, 0.03497928427532315, 0.043686734179833105, 0.02407030714675784, 0.05696658390973296, 0.10382590695683445, 0.03938383828582508, 0.013211042886333806, 0.09472281006830079, 0.03514276711004121, 0.010371413697222514, 0.09282633861792938, 0.060048354257430346, 0.02605380240960845, 0.051018671465239356, 0.0592659151713763, 0.032857454381883144, 0.05824792943894863, 0.0055387308072697905, 0.06121878645249775, 0.036943507447306595, 0.04695781579773341, 0.03365588993100183, 0.020820500994367257, 0.0685462521921311, 0.054002376539366584, 0.05187870442335095, 0.03744628493274961, 0.026100236257272105, 0.04607340307640178, 0.08609893532203776, 3.6091407920633043, 31.355712481907435, 39.413013798849924, 24.32421714918954, 41.48129449571882, 33.83854702540806, 49.59456007821219, 4.5196177533694675, 0.2295696756669453, 1.7896770409175327, 0.3128699729485171, 0.0535417530419571, 0.20221851260534354, 0.11083646970135824, 2.6582400798797607, 25.57801263672965, 47.60852173396519, 51.236860615866526, 49.28915548324585, 50.83466066632952, 46.88779204232352, 49.978270871298655, 47.06654487337385, 48.95953989028931, 47.59458017349243, 49.057019642421174, 44.17685161318098, 42.922656604221885, 36.590714590890066, 39.19075829642159, 38.95374829428536, 42.41554927825928, 43.65372174126761, 44.37341962541853, 45.070869377681184, 46.53785991668701, 46.77430364063808, 47.29819434029715, 41.972525187901084, 38.889817919049946, 38.54930407660348, 37.86865506853376, 38.24355207170759, 38.09956455230713, 37.285614354269846, 40.59031656810215, 36.24452059609549, 38.19252797535488, 36.16433491025652, 36.86357382365635, 36.661895411355154, 37.23379468917847, 37.15737492697579, 37.12281111308506, 35.6087326322283, 40.0438928604126, 48.59155287061419, 49.65811177662441, 47.22546754564558, 49.92824731554304, 48.420998913901194, 47.54839549745832, 44.975189208984375, 47.35517304284232, 46.05063138689314, 50.343926770346506, 49.03674827303205, 51.15808194024222, 47.56383439472744, 53.43157420839582, 49.528972557612825, 42.218644278390066, 47.34138434273856, 56.2332581111363, 39.75320455006191, 42.55163322176252, 50.09624433517456, 47.18382699148995, 47.03610481534685, 43.02508347375052, 38.86188268661499, 35.12034027917044, 37.814361844744, 36.22472865240914, 35.4319600377764, 35.1981566292899, 35.307351044246126, 33.64862149102347, 36.24479157584054, 35.095681122371126, 34.52742964880807, 34.74241386141096, 34.796227659497944, 36.551815101078574, 34.474161284310476, 37.00753355026245, 42.81226362500872, 41.42490986415318, 40.65825605392456, 37.923837661743164, 35.64156287057059, 34.04701730183193, 35.119124344417024, 33.00532252447945, 34.201513971601216, 35.61719553811209, 40.676929337637766, 42.4730977330889, 42.77970436641148, 45.6821927343096, 44.82044587816511, 42.779280526297434, 44.65187215805054, 43.91955634525844, 43.144067900521414, 43.30137511662075, 44.90841007232666, 44.09672498703003, 43.90591008322579, 39.640369279044016, 44.35694544655936, 41.36979327883039, 43.0765974181039, 17.777157170431956, 0.8575247398444584, 3.5119396192686896, 5.074876529829843, 7.466916356767927, 7.189723185130528, 7.09087290082659, 0.1568447130599192, 0.02364381226444883, 16.845768519810267, 48.65975291388375, 36.51161977222988, 26.9821515083313, 28.26201663698469, 35.323866912296836, 1.048415748136384, 0.04933817092595356, 0.04216591328648584, 0.05510024280686464, 0.025275843351015022, 0.11552615091204643, 0.042239083110221794, 0.10110710534666266, 0.011758946564181574, 0.049170599917748144, 0.09357419955943312, 0.042892987307693274, 0.035823276665593894, 0.09372140094637871, 0.01462636176230652, 0.01709002742011632, 0.01951714718182172, 0.0743649003228971, 0.17389447960470403, 0.13628556339868478, 0.15350448872361863, 0.1566296038883073, 0.24058067053556442, 0.09077518832470689, 0.22831883707216807, 0.09375630478773798, 0.2684783935546875, 0.1721708785210337, 0.21854616861258233, 0.1769978545073952, 0.12813090240316732, 0.15485461056232452, 0.20562467697475637, 0.2168246709874698, 0.13207663781940937, 0.1455647469099079, 0.2565671998475279, 0.25102150599871365, 4.260676196643284, 38.84751728602818, 48.18060861315046, 34.75075517381941, 42.00976405824934, 38.8185259274074, 56.624750886644634, 7.54197861467089, 0.3496130241879395, 2.5870299467018674, 0.4302348723368985, 0.12828674832625048, 0.38338783755898476, 0.30072566175035065, 2.190576808793204, 25.92364035333906, 49.39205483027867, 54.17052902494158, 50.47570630482265, 51.05021115711757, 46.60807146344866, 50.868005071367534, 47.65844106674194, 51.39054087230137, 50.9208322252546, 53.06275340488979, 46.32967799050467, 43.96473700659615, 38.26788466317313, 42.051446301596506, 42.45372268131801, 45.676450048174175, 45.92285748890468, 46.185405594961985, 47.77118601117815, 49.85335268293108, 48.59969963346209, 51.40350273677281, 44.32443135125296, 40.17106226512364, 40.797956534794395, 38.97895983287266, 40.080763476235525, 40.233589104243684, 40.61922802243914, 43.45412084034511, 37.78495012010847, 40.62422725132534, 38.72332518441336, 38.105401039123535, 39.14163800648281, 39.43569619315011, 39.74286215645926, 38.974975040980745, 38.38307189941406, 42.1685825075422, 50.23410701751709, 52.58622162682669, 49.608355726514546, 52.632729394095286, 50.120087078639436, 50.70118924549648, 47.93889120646885, 49.730567591530935, 48.70145947592599, 53.513423987797324, 50.11317709514073, 53.37634992599487, 46.430562359946116, 56.94506631578718, 54.38295977456229, 42.66500002997262, 50.35198668071202, 49.90054137366158, 40.94749219076974, 47.353380407605854, 51.58331169400896, 49.66919762747628, 47.86163418633597, 45.68097332545689, 41.132234369005474, 37.51911899021694, 41.24406909942627, 38.03887203761509, 36.87687267575945, 38.05747931344168, 36.27943181991577, 35.1547269139971, 37.41884953635079, 36.98625121797834, 34.667710304260254, 36.06278351375035, 35.93558284214565, 38.17699875150408, 34.50486189978463, 39.341770444597515, 44.965034416743684, 43.717304706573486, 42.42060061863491, 40.708706923893516, 38.11049754279, 36.03327104023525, 37.3529771396092, 35.7050381387983, 36.28001199449812, 36.85380118233817, 42.34441014698574, 45.55090652193342, 45.271571568080354, 48.439015592847554, 46.41254915509905, 45.675480774470735, 47.15797274453299, 45.70184571402413, 45.15134688786098, 45.836546966007774, 47.00737401417324, 47.59475040435791, 44.79207985741751, 42.779624462127686, 44.00104134423392, 41.0295330456325, 44.69690343311855, 20.361965213503154, 1.4170592640127455, 6.05146929195949, 7.551742570740836, 11.835486786706106, 10.450112393924169, 12.051814607211522, 2.2301926144531796, 0.1784416413200753, 21.29018895966666, 57.715927260262625, 34.28618124553135, 31.146602971213206, 38.071003981998985, 43.58400351660592, 2.288982625518526, 0.3575895018875599, 0.10840184534234659, 0.1651566991848605, 0.12453364900180272, 0.20273676408188684, 0.09797008867774691, 0.21809256795261586, 0.2155788806932313, 0.24386076309851237, 0.09786914980837277, 0.21325120702385902, 0.21963979064353875, 0.13744394481182098, 0.07765375277293579, 0.21287493221461773, 0.07098869327455759], [0.043492734232651334, 0.03546590244929705, 0.008357977228505271, 0.02646884531714022, 0.08729291946760245, 0.06410367307918412, 0.027636222408286164, 0.05764431147170918, 0.042527945645685704, 0.053400502407125065, 0.06442493905446359, 0.03408324146377189, 0.03385571849399379, 0.046066376846283674, 0.006510945960014526, 0.04187000077217817, 0.04941933389220919, 0.025352553431210772, 0.01674176423278238, 0.0436634909627693, 0.04209326932738934, 0.23512006497808866, 5.30456052507673, 39.713950702122276, 27.400822162628174, 28.103128705705913, 30.273544447762625, 42.83215979167393, 24.625063725880214, 0.07951991406402417, 0.9741531844649995, 0.043283474032900164, 0.06377853945429836, 0.01157489394037319, 0.032360268024993796, 0.036216698054756434, 5.506929414612906, 29.467077459607804, 48.211003507886616, 50.21392944880894, 50.31269809177944, 48.352243014744346, 44.767497130802695, 45.13013751166207, 48.587373529161724, 47.62235559735979, 47.66910307747977, 43.0792099407741, 39.3932774407523, 35.831432819366455, 36.561163902282715, 38.37156220844814, 39.38656200681414, 41.372051443372456, 44.57306221553257, 43.34225484303066, 46.53575461251395, 48.54062952314104, 46.63936267580305, 45.217271396092, 38.502337728227886, 35.62708282470703, 37.82207087108067, 37.96402604239327, 35.01214640481131, 36.501892294202534, 37.0631434576852, 35.392365728105815, 35.402082783835276, 35.86823047910418, 36.06872074944632, 37.01114313943045, 37.11206224986485, 35.681563649858745, 34.53453070776803, 34.843638692583355, 38.298196179526194, 46.17679330280849, 46.12376117706299, 46.396450178963796, 45.94135706765311, 47.49727412632534, 48.77540915352957, 47.81463309696743, 45.33469942637852, 45.59049040930611, 47.01571185248238, 50.69140270778111, 49.78914785385132, 44.40283135005406, 28.64002295902797, 28.676613909857615, 66.77689238956997, 60.295987946646555, 32.2694388117109, 39.323104109082905, 47.62532247815813, 46.554420948028564, 44.07674196788243, 41.02759102412632, 39.22448485238211, 35.70490264892578, 34.566926683698384, 31.149038314819336, 33.82068320683071, 33.966133322034565, 35.075597354343955, 33.72972086497715, 34.70462608337402, 33.014636584690635, 34.13751064028059, 33.06152997698103, 33.48709324428013, 34.953847544533865, 34.35783454350063, 32.94227804456438, 40.62977191380092, 43.52005577087402, 44.68183626447405, 44.02702413286482, 41.06453807013375, 36.58124072211129, 33.77789967400687, 32.01178918566023, 31.559082780565532, 31.228688989366802, 34.07486915588379, 39.892238003867014, 42.17132009778704, 40.734543800354004, 40.14110510689871, 43.30817740304129, 43.72816474097115, 44.29444292613438, 42.963880266462056, 42.77465302603585, 43.65031712395804, 42.52404539925711, 41.66266679763794, 41.34861169542585, 39.63715921129499, 40.934467792510986, 41.23877109800066, 34.71649013246809, 3.779893858092172, 0.5536356121301651, 2.106412410736084, 3.6252847143581937, 8.622868180274963, 6.915030496461051, 6.3528938719204495, 0.43079813782657894, 0.8846271655389241, 44.756102085113525, 31.555546147482737, 16.24104768889291, 19.107950857707433, 27.90763419015067, 15.310892343521118, 0.046779998910746405, 0.0724577826580831, 0.045655374614787955, 0.02894079079851508, 0.04550712149856346, 0.06587489375046321, 0.07523369656077453, 0.03177558118477464, 0.052340905514678786, 0.084650758387787, 0.11130980215966702, 0.0499501246958971, 0.009255367780237325, 0.02400828056436564, 0.026855698487322246, 0.02675853227265179, 0.060653173231652806, 0.048777870634304624, 0.07077587076595851, 0.036966072129351754, 0.040822882138724835, 0.13686336310846464, 0.07717563664274556, 0.05273115135995405, 0.02380385492662234, 0.07170135860464402, 0.01732206604044352, 0.004092952494309949, 0.03597078339329787, 0.04256177061636533, 0.045587914663233926, 0.027271022986886755, 0.05590924993157387, 0.0222204697118806, 0.006731019463456635, 0.06734816969505378, 0.02479796131540622, 0.10054028433348451, 0.21459412282066687, 9.841051544461932, 48.3697316305978, 24.573718275342667, 33.473050934927805, 38.25837952750069, 47.23515680858067, 24.34900311061314, 0.09153022138135773, 1.1797698140144348, 0.1296357437968254, 0.01612885033578745, 0.27942319054688725, 0.2734826978828226, 0.20232645395611012, 6.866750070026942, 32.437005043029785, 49.97434513909476, 51.0733972958156, 51.15820353371756, 50.04008204596383, 45.91503381729126, 48.117550236838206, 50.06074946267264, 48.207675320761545, 48.111126627240864, 45.37588487352644, 41.37622731072562, 37.674421651022776, 38.838064261845176, 39.475752558027, 41.318696226392476, 42.60854244232178, 45.494886670793804, 44.895448207855225, 47.47366762161255, 50.11198895318167, 49.446275097983225, 45.2331098147801, 39.9136141368321, 36.86335842950003, 39.11653069087437, 39.32273932865688, 38.29072686604091, 38.14796570369175, 37.92705120359148, 37.37204647064209, 37.43131113052368, 36.80864136559622, 37.40965359551566, 37.31207309450422, 38.07658338546753, 37.89323779514858, 37.05559771401541, 36.14456728526524, 40.023267132895334, 47.76938990184239, 48.13796751839774, 47.54704754693167, 48.848660537174766, 48.75674629211426, 49.03919751303536, 47.725105558122905, 47.13378259113857, 47.38743700299944, 48.31925991603306, 52.03933933803013, 50.15260812214443, 44.86211422511509, 38.58228717531477, 30.89767680849348, 54.704605783735005, 63.385935238429475, 40.32205704280308, 40.01232024601528, 49.226878779275076, 46.890216963631765, 46.615210737500874, 42.950303486415315, 41.13711895261492, 37.606093066079275, 37.92673853465489, 33.599935463496614, 36.204360008239746, 36.776453835623606, 38.243916852133616, 34.34223583766392, 35.476112365722656, 34.68921845299857, 35.47940928595406, 35.42193031311035, 35.6280312538147, 35.02333647864205, 35.875578199114116, 34.14308309555054, 40.87547063827515, 44.61097158704485, 47.35479089191982, 45.421072483062744, 41.53267642429897, 37.80428695678711, 35.500882693699424, 32.63757174355643, 33.49544150488717, 32.73454080309187, 35.816306591033936, 41.06123767580305, 44.07957683290754, 40.92558799471174, 40.72583770751953, 45.603775365012034, 46.16651691709246, 45.7742737361363, 43.62515074866158, 44.21558434622628, 45.55843489510672, 43.89434480667114, 43.544478688921245, 44.16811772755214, 42.54086698804583, 41.536470140729634, 42.336676801954, 35.22641147886004, 5.524599552154541, 1.5060814299753733, 5.002153209277561, 7.759676967348371, 7.557559950011117, 7.200083383492061, 2.7647227432046617, 0.4504741605903421, 0.5304485506245068, 44.19569165366036, 41.66855887004307, 24.76587244442531, 17.413542304720195, 33.84567935126168, 23.166070563452585, 0.05427868278431041, 0.07075743496950183, 0.021806091768667102, 0.0873911916943533, 0.04026903132242816, 0.09789455415947096, 0.07164204785866396, 0.05485648588676538, 0.013033190376258321, 0.022556700776996355, 0.12033108808100224, 0.04274586395227483, 0.03594400840146201, 0.008661622497519212, 0.031285061434443505, 0.029899347041334425, 0.06674106405781847, 0.16614877166492598, 0.09675794014973299, 0.07315687050244638, 0.18591429319764885, 0.26772467685597284, 0.25074930489063263, 0.08613263815641403, 0.09847529192588159, 0.09785353671759367, 0.21081783116928168, 0.11342680427644934, 0.11030206230602094, 0.17242474561291082, 0.12250079879803316, 0.15620645587997778, 0.11047425413770334, 0.1844928301870823, 0.09100284360881362, 0.16811455546745233, 0.1493546771151679, 0.13762467939938816, 0.23966961513672555, 15.652785403387886, 54.86778770174299, 32.590688773563926, 38.69161360604422, 42.030400208064485, 51.6105694770813, 31.30223219735282, 0.19061578091766151, 2.4947860964706967, 0.14586156526846544, 0.2093014953924077, 0.14071041239159449, 0.22909540683031082, 0.24237425572105817, 7.622963343347822, 32.96814271381923, 50.85352502550398, 52.64657367978777, 51.47981480189732, 50.395993096487864, 46.456517355782644, 49.43411227634975, 51.077006884983604, 52.05201980045864, 52.55857127053397, 47.11652673993792, 41.55827358790806, 39.73689365386963, 41.02182749339512, 41.73226342882429, 43.28916365759713, 47.06013863427298, 49.37403467723301, 47.40412310191563, 52.72015510286604, 51.99587835584368, 51.915525913238525, 48.205993856702534, 42.76100328990391, 37.33581508908953, 41.96723066057478, 40.53126035417829, 39.260024888174875, 39.494279929569785, 40.71116658619472, 39.65599577767508, 38.38483326775687, 38.26969466890608, 39.44553484235491, 41.11005571910313, 41.08493103299822, 39.33917529242379, 37.646472522190635, 38.7257535798209, 41.66075604302542, 50.00994770867484, 50.59838022504534, 49.13362005778721, 48.985588686806814, 50.402791908809114, 51.386806215558735, 50.90806838444301, 50.388937200818745, 49.859390667506624, 50.47301040376936, 52.290415968213765, 50.9582656451634, 44.099542481558665, 46.50685705457415, 35.783882822309224, 55.04713807787214, 58.640169688633506, 38.89921883174351, 45.30459983008248, 48.683039801461355, 49.778075899396626, 48.02367312567574, 45.30400228500366, 44.05951043537685, 40.47708524976458, 39.4570688520159, 35.046126570020405, 37.30998168672834, 38.087099484034944, 40.34519454411098, 35.7118821144104, 37.39474623543875, 36.36998421805245, 37.56333385195051, 37.117905684879844, 38.270163672310964, 37.73708050591605, 36.427612577165874, 35.83952052252633, 45.85007510866438, 46.64058208465576, 48.85083532333374, 47.55196687153408, 43.417326654706685, 38.67547294071743, 37.6139132635934, 34.156409740448, 34.47505412782942, 34.20888253620693, 37.14754670006888, 44.352269308907644, 46.26073448998587, 42.78950480052403, 42.46378367287772, 47.137989725385395, 48.629007135118755, 48.02657747268677, 46.227699279785156, 45.464026246752056, 47.29374054500035, 46.60840497698103, 44.769074371882844, 46.04656669071743, 42.23306179046631, 44.55591753550938, 42.480177947453086, 36.91062355041504, 5.188521700245993, 2.0920943447521756, 6.0706910490989685, 10.344249640192304, 15.58597673688616, 13.539640188217163, 18.029705081667217, 1.4244721233844757, 1.4437783445630754, 53.40885359900338, 42.24118423461914, 24.880521195275442, 28.274301052093506, 40.46122946058001, 30.562183039528982, 0.15747077018022537, 0.15005774796009064, 0.132526642243777, 0.13106484711170197, 0.14802472133721623, 0.3010766272033964, 0.14602061387683662, 0.10829765629023314, 0.11693580741328852, 0.1749278205846037, 0.1970027360532965, 0.07809466482805354, 0.07622310239821672, 0.07318958267569542, 0.09151286445558071, 0.12208535894751549, 0.1830139902553388], [0.022245724785274694, 0.04887804275910769, 0.04119190001594169, 0.07717658659177166, 0.010658315266482532, 0.018965102965012193, 0.06345029813902718, 0.028905259312263558, 0.0149592425607677, 0.02374083429042782, 0.03270314194794212, 0.010440552174778921, 0.021719802470345582, 0.01801196821699185, 0.018602565097223436, 0.03893810523939984, 0.04765804358092802, 0.06883661768266133, 0.03542752790131739, 0.0436230808097337, 0.04677238914051226, 0.06309479328670672, 2.0524246905531203, 25.74589327403477, 33.24480608531407, 24.389809880937847, 33.26066882269723, 30.98083632332938, 39.70121465410505, 1.099323353597096, 0.06933556483792407, 0.07994605441178594, 0.1316742394119501, 0.28834353759884834, 0.40621275135449, 0.32629155846578733, 0.1476667941148792, 11.42117438997541, 37.27698121752058, 50.454948561532156, 47.967326709202354, 49.30584853036063, 47.272482531411306, 48.47689717156546, 47.30448246002197, 47.33583273206438, 45.39687885556902, 42.994198731013704, 37.71729898452759, 35.62396308353969, 37.21000405720302, 37.62472466060093, 40.19865356172834, 45.17867415291922, 46.00528744288853, 47.93050820486886, 48.541060311453684, 47.273920808519634, 48.04633814947945, 47.26623262677874, 39.45377540588379, 35.8639086995806, 36.91795737402779, 36.447397572653635, 35.5801477432251, 36.757346289498464, 35.008453437260215, 36.53096355710711, 35.71236154011318, 36.274634088788716, 35.6695363180978, 36.15959276471819, 35.022936957223074, 34.420976298195974, 36.636624813079834, 34.827946186065674, 39.78293936593192, 46.74879680361067, 47.28095933369228, 47.476168973105295, 46.50641236986433, 47.28877258300781, 47.46960639953613, 45.07975264957973, 47.68063708714077, 44.56234809330532, 48.03082282202584, 46.834853717258994, 50.09940576553345, 32.9346523966108, 22.456015041896276, 61.398938042776926, 57.095161301749094, 32.911639962877544, 38.96589374542236, 46.32971967969622, 47.669082232883994, 45.82682296207973, 42.25320809228079, 40.28742722102574, 38.54314797265189, 33.406403814043315, 33.69138765335083, 32.97988516943795, 34.14923225130354, 33.54709441321236, 34.01595885413033, 32.59806081226894, 32.9911447252546, 34.694585936410085, 33.516303471156526, 32.96777098519461, 34.61207955224173, 32.68731042316982, 33.66379983084542, 33.63634055001395, 41.35376031058175, 46.875983578818186, 45.31951066425869, 46.164001669202534, 42.62284530912127, 40.828810010637554, 37.33648559025356, 33.32857356752668, 33.014577525002615, 32.39478431429182, 32.939648151397705, 35.34905413218907, 42.01406499317714, 43.480662958962576, 44.572429929460796, 44.17884922027588, 43.55167007446289, 45.004600933619905, 44.41653667177473, 42.867828369140625, 43.59018046515328, 42.49103798185076, 43.570728983197895, 40.106041022709434, 44.75122792380196, 40.26659304755074, 45.61689703805106, 19.42244369643075, 0.7811139885868345, 0.6749832406640053, 3.089071818760463, 4.5662510224751065, 5.213881756578173, 5.210919652666364, 2.9711665340832303, 1.0427370071411133, 11.40187576838902, 40.62800359725952, 31.141589845929825, 33.77970967973982, 21.102926322392054, 25.062784603663854, 3.255185442311423, 0.06827763374894857, 0.062029825789587836, 0.04234503974605884, 0.05759768933057785, 0.06317904697997229, 0.014843240213979567, 0.04383851567815457, 0.07559207840157406, 0.023656582293499793, 0.023747528038386787, 0.063091237763209, 0.0257160107139498, 0.004180517862550914, 0.026341141633955494, 0.09808708168566227, 0.028483532834798098, 0.020744464360177517, 0.054619168263993094, 0.01709226149666522, 0.0445991296853338, 0.0635138972263251, 0.017992687644436955, 0.07544048010770764, 0.013735906686633825, 0.014146612059058887, 0.03196482460147568, 0.08307470474392176, 0.0025988588833050536, 0.02820844964922539, 0.048244749062827656, 0.018234721085588847, 0.03312015939237816, 0.08100145456514188, 0.013412770499209208, 0.019995468568855097, 0.0033771135287159787, 0.020475240324490836, 0.02880321443080902, 0.0316237352256264, 3.0890016853809357, 36.55954497201102, 34.43681124278477, 25.505549873624528, 43.97694499152047, 35.64137526920864, 44.160589354378835, 0.7869823394077164, 0.5464552459972245, 0.15263748381819042, 0.10954810133469955, 0.7211183022175516, 1.0379646803651537, 0.7173162262354578, 0.275018005498818, 14.624335629599434, 40.71265002659389, 52.264433179582866, 49.24217871257237, 50.047551359449116, 47.87027079718453, 49.64146736689976, 48.94487224306379, 48.32879631859915, 47.78572859082903, 44.41610588346209, 38.90940836497715, 36.21847179957798, 38.87245437077114, 38.59743424824306, 41.000871726444785, 45.97592435564314, 47.29681512287685, 49.21474722453526, 48.643681730542866, 50.0583940233503, 47.77054330280849, 47.951457023620605, 41.21562317439488, 37.465503215789795, 39.17136240005493, 37.2111748286656, 37.302102429526194, 38.467231954847065, 36.473567962646484, 38.44452524185181, 37.18245097569057, 38.324554170881, 36.63923733575003, 37.10991873059954, 35.84368249348232, 36.25747203826904, 37.66764715739659, 34.480779443468364, 42.39998183931623, 48.17274325234549, 49.86178084782192, 49.14541809899466, 49.200948102133616, 49.433684962136404, 49.23831898825509, 45.9747223172869, 48.3976286479405, 44.70020382744925, 50.23316206250872, 47.94778490066528, 52.948382581983296, 32.581892354147776, 26.765317337853567, 52.41065801892962, 64.62092195238385, 44.45621088572911, 36.99413742337908, 50.00447947638375, 49.628745215279714, 47.88795396259853, 43.5066249029977, 43.77294935498919, 38.2927314213344, 36.1671176637922, 34.3437123298645, 35.454645906175884, 36.13070215497698, 35.73751401901245, 35.04521288190569, 33.63362380436489, 32.73468671526228, 36.01666137150356, 34.588896887642996, 36.36570412772042, 35.493389061519075, 35.24968447004046, 35.33860404150826, 35.79818568910871, 41.97479030064174, 47.47540814535958, 46.84986877441406, 47.84775515965053, 44.90409524100167, 42.177250385284424, 37.756323541913716, 34.22315066201346, 34.30625111716134, 32.963067054748535, 33.438851901463096, 37.31715570177351, 44.430526869637625, 44.76807730538504, 44.97803449630737, 45.234648840767996, 45.69338975633894, 45.16714014325823, 44.78986685616629, 43.77320991243635, 45.51736061913626, 43.13824878420149, 45.186935561043875, 41.83676780973162, 43.366302558353965, 41.70459917613438, 45.56799561636788, 21.65749158178057, 1.5616495396409715, 3.1119691729545593, 7.7138466494424005, 6.185353262083871, 5.38356979404177, 6.985719297613416, 1.1831247082778384, 0.7884086200169155, 12.039797697748456, 49.45943151201521, 28.664477143968853, 28.466425691332134, 19.738315752574376, 35.79141466958182, 6.731286687510354, 0.08735089349959578, 0.0542670425160655, 0.03736348330442395, 0.022367138448836546, 0.043507258274725506, 0.016196340821417313, 0.05951518179582698, 0.07343620301357337, 0.06036086713096925, 0.019488952355459332, 0.023260524795789803, 0.023082266861040677, 0.039290040997522216, 0.03473069957856621, 0.04236168081739119, 0.06138403687093939, 0.058520395175686905, 0.19065510880734238, 0.1007247915757554, 0.1626570304589612, 0.21216781730098383, 0.13291036736752304, 0.1549430372459548, 0.10729836419756923, 0.06101082903998239, 0.1273970939218998, 0.10971417278051376, 0.09867854709071772, 0.1416352420513119, 0.08595640225602047, 0.12503831620727265, 0.09160460917545216, 0.15884507500699588, 0.09492641807134662, 0.15348643969212258, 0.1121177270210215, 0.16330507211387157, 0.1459951823843377, 0.1707535817154816, 3.5181612968444824, 42.173640796116416, 43.69732863562447, 32.909583296094624, 44.12598385129656, 40.85795075552804, 49.23732539585659, 2.17410414985248, 1.1480841828244073, 0.3177806394440787, 0.33762719162872856, 0.702616063611848, 0.9006430347050939, 1.0798210629395075, 0.23873668376888546, 14.119814770562307, 41.09237255368914, 53.8595415524074, 50.88320772988455, 50.931504658290315, 49.09254230771746, 50.08116674423218, 49.589633805411204, 50.49244451522827, 49.64730732781546, 46.48122862407139, 40.90514986855643, 39.1914496421814, 40.59691388266427, 41.33171715055193, 43.262955052512034, 49.420789105551584, 49.21812752314976, 51.22561843054635, 52.49225071498326, 50.961381912231445, 52.373638016836985, 50.417817388262065, 42.74374743870327, 39.29630838121687, 39.83932399749756, 39.908222334725515, 38.68595082419259, 42.0180150440761, 37.64548587799072, 40.89484569004604, 38.749450411115376, 41.696587903159006, 39.479754720415386, 39.15884174619402, 37.396128926958355, 37.36484466280256, 39.82496207101004, 35.649122510637554, 46.395487853458945, 49.544880458286826, 52.41184616088867, 51.706478936331614, 52.2707907812936, 52.1640317099435, 52.03817204066685, 47.448539461408345, 51.333913053785054, 46.9809604372297, 52.532220227377756, 50.59219285420009, 54.14259726660592, 36.10849918637957, 30.01457813807896, 51.64139516013009, 64.58867536272321, 47.213280405317036, 41.13286665507725, 49.145369461604524, 50.28602048328945, 50.42605447769165, 45.43473958969116, 44.727642263684956, 42.12671613693237, 36.15052189145769, 37.67766298566546, 38.39727054323469, 38.36544779368809, 37.74810034888131, 37.327331338609966, 34.76162215641567, 34.171046120779856, 38.13428817476545, 36.79716294152396, 38.218198095049175, 37.44862604141235, 36.560719217572895, 36.728063106536865, 38.0370967728751, 44.160804748535156, 49.16230916976929, 46.95893464769636, 48.348202637263704, 47.038276127406526, 44.154165744781494, 40.426429407937185, 36.44914157049996, 36.902077266148154, 35.296025480542866, 36.06310313088553, 39.47862216404506, 46.0279872076852, 46.23225729806082, 46.234147208077566, 46.57500498635428, 45.49075249263218, 46.45779929842268, 45.99906185695103, 45.426620619637625, 47.1997765813555, 45.70315892355782, 45.13686684199742, 42.685809884752544, 44.830072607312886, 41.64097799573626, 47.145465987069265, 21.839786257062638, 2.2030866060938155, 2.7864999175071716, 9.012693388121468, 10.24166817324502, 12.724781513214111, 13.692814963204519, 8.881599119731359, 1.827263972588948, 15.24457699911935, 50.906845501491, 40.54096351351057, 45.730395862034385, 29.130393811634608, 44.62134872164045, 10.379529118537903, 0.25898775139025276, 0.22689721121319703, 0.10298847939286913, 0.13887829998774187, 0.1280998254993132, 0.10541244396673781, 0.16310295010251658, 0.1353902771536793, 0.14570835206125463, 0.10101212401475225, 0.1401832178235054, 0.12717741142426217, 0.11809231606977326, 0.13002328228737625, 0.20179877084280762, 0.1287200336477586, 0.20439124958855764], [0.02667574251868895, 0.055978650493281226, 0.03773066235174026, 0.06917614303529263, 0.03913105006462761, 0.03618592649166073, 0.030725544850741113, 0.012595423330952014, 0.09221261726426226, 0.06581989848720175, 0.04263790563813277, 0.06711997836828232, 0.0046561471618978036, 0.07224131641643387, 0.06688802117215735, 0.054909211450389454, 0.02950073146660413, 0.03679401261199798, 0.06445277934627873, 0.04592872244705047, 0.04403586419565337, 0.035665554593184164, 0.036736863000052314, 8.584838952336993, 45.20194714409964, 23.106696469443186, 27.68936174256461, 33.023144653865266, 39.72267069135393, 13.081643598420278, 0.5705124608107975, 0.1532656443970544, 0.2503940239548683, 1.9874622906957353, 1.3170474363224847, 0.9769896779741559, 0.13603716529905796, 2.3830254077911377, 22.681890555790492, 46.25521762030465, 48.792863028390066, 51.40347146987915, 49.88356692450387, 50.1418696812221, 46.097483089991975, 49.295179571424214, 45.40790912083217, 41.702622413635254, 35.20151260920933, 35.67211757387434, 36.52577325275966, 42.01672962733677, 44.38777807780674, 47.333206312997, 46.753108160836355, 49.65278945650373, 48.305731773376465, 48.15124552590506, 48.219945839473176, 47.48930106844221, 37.694658279418945, 36.338578360421316, 35.48304319381714, 36.560097353799, 35.82519333703177, 36.31974526814052, 35.92907932826451, 38.20483323505947, 35.226786681583945, 35.66796255111694, 35.367300101688926, 35.654879093170166, 36.07856287275042, 36.29481513159615, 35.24649524688721, 36.490514619009836, 39.655408654894146, 47.587242875780376, 47.31590877260481, 47.32209961754935, 46.61801780973162, 45.99634163720267, 46.077562604631694, 48.035888058798655, 46.55970852715628, 48.88550683430263, 45.88742515019008, 46.41874694824219, 48.561265672956196, 46.24055692127773, 49.44557680402483, 33.09354032788958, 26.49800103051322, 42.457394804273335, 48.25118146623884, 46.77000617980957, 47.93468059812273, 44.36262559890747, 42.720394543239046, 38.51329503740583, 34.39859962463379, 34.202403341020855, 34.778106757572715, 34.211682660239084, 33.014518465314595, 33.58940894263131, 33.95986604690552, 32.020516123090474, 32.89111845833914, 32.404067107609336, 32.86456939152309, 34.312073707580566, 33.37075955527169, 32.206863335200715, 32.454035077776226, 33.80652625220162, 40.14909553527832, 46.52313320977347, 44.76533276694161, 45.356732164110454, 45.26159742900303, 44.069665227617534, 41.54298060280936, 35.89894151687622, 32.436327593667166, 31.242234502519878, 32.11581414086478, 31.772204875946045, 33.62744338171822, 40.69915662493025, 45.6315473147801, 45.2125883102417, 43.73167358125959, 43.31018195833479, 45.51367112568447, 43.34841442108154, 44.436460631234304, 42.89169890539986, 44.39643553325108, 44.79542541503906, 45.97175196238926, 43.32370662689209, 42.54082529885428, 6.807259159428733, 0.48680159556014196, 2.467617988586426, 5.5876752989632745, 12.636092969349452, 6.6264665978295465, 2.573224093232836, 0.656656064093113, 0.07033512834459543, 26.174409525735037, 31.978576796395437, 37.46560396466936, 34.15601716722761, 17.317103045327322, 14.95859956741333, 0.8256342453616006, 0.08528478829456226, 0.009226747173150735, 0.05849237846476691, 0.04067817436797278, 0.018432727782055736, 0.020942986743258576, 0.02774885413236916, 0.02014926022716931, 0.02283813165766852, 0.05804578707154308, 0.06642734339194638, 0.06208791517253433, 0.0312734177735235, 0.02733798760787717, 0.01721111199419413, 0.04718457880829062, 0.031414933037012815, 0.0281093682694648, 0.11069977203650133, 0.03797804604151419, 0.043673112589333735, 0.03901978049959455, 0.04377651793350067, 0.03767503605091146, 0.04178924492693373, 0.03811197867617011, 0.012701141631363757, 0.06665370945951768, 0.056764109060168266, 0.08581038830535752, 0.025186298780941536, 0.03531016169914177, 0.036022945772856474, 0.05589895655534097, 0.009547209084433104, 0.028678743966988156, 0.023091220130611743, 0.04321596658389483, 0.019351706773574864, 0.11493604257702827, 13.837476457868304, 49.11628082820347, 21.47092202731541, 34.06067051206316, 39.225930077689036, 45.86671257019043, 11.80662831238338, 0.5712414788348334, 0.28258342668414116, 0.4399329019444329, 1.9636080392769404, 2.8027912718909125, 2.0993936445031847, 0.31026958248444964, 2.7572629834924425, 25.611363989966257, 46.09990801130022, 50.35279614584786, 51.883206367492676, 50.936701910836355, 51.42716482707432, 49.21468121664864, 51.09117078781128, 47.07375710351126, 43.36891508102417, 37.88510145459856, 38.87799555914742, 37.85981001172747, 42.12905420575823, 45.78568615232195, 48.05957794189453, 49.21844366618565, 52.196413789476665, 49.21746744428362, 49.27119091578892, 49.95062746320452, 49.18546404157366, 39.435866424015586, 37.71211562837873, 37.592415537152974, 37.4545076915196, 36.94304384504046, 38.5373010635376, 38.0577746118818, 41.04775817053658, 37.34645625523159, 36.65481519699097, 37.07800912857056, 37.08817434310913, 37.93770626613072, 37.39585794721331, 37.55336666107178, 38.23650312423706, 41.80090468270438, 49.49100412641253, 47.84355844770159, 50.05595520564488, 48.70789698192051, 48.484842436654226, 47.57694911956787, 50.00104706627982, 49.94777175358364, 48.13493115561349, 47.37415204729353, 49.15516642161778, 50.11021021434239, 46.17302737917219, 48.77164670399257, 39.89189754213606, 31.528899805886404, 40.40460511616298, 48.55305985042027, 49.006641728537424, 50.01393597466605, 48.11891903196062, 44.416654791150776, 41.91565765653338, 37.555826323372976, 35.86679915019444, 37.07993377958025, 36.79101031167166, 34.66939524241856, 35.260169301714214, 36.73619597298758, 34.21787003108433, 34.735034874507356, 33.13168593815395, 35.2205228805542, 35.488973481314524, 34.253674098423545, 34.01588589804513, 34.43292372567313, 35.46924754551479, 42.23364543914795, 46.80659886768886, 45.18838773454939, 46.492019176483154, 46.37262480599539, 46.149028301239014, 43.23912273134504, 37.23334305627005, 33.83852618081229, 33.25007976804461, 35.34317595618111, 34.23432683944702, 36.772017410823274, 43.085887159620015, 46.9627492087228, 44.54096153804234, 44.31278964451381, 44.776484625680105, 46.830705642700195, 44.38625642231533, 46.17533418110439, 44.403411524636404, 45.70249189649309, 45.63377768652779, 46.761657919202534, 43.712656361716135, 43.872857502528596, 7.89715141909463, 1.1782199314662387, 3.817293405532837, 4.675367270197187, 10.608135274478368, 8.066354819706508, 7.0187371373176575, 0.6741560793348721, 0.1801156279231821, 28.074041809354508, 37.86743218558175, 45.172330447605674, 33.99027483803885, 22.202841792787822, 26.839685644422257, 1.0041140339204242, 0.045065405379448614, 0.026444475731945465, 0.01600506010332278, 0.037082244109894545, 0.04249877203255892, 0.048614574396716695, 0.02037841168099216, 0.02610678242386452, 0.038915903573589664, 0.012993748831961836, 0.04551735719931977, 0.014803057370175208, 0.06770389167858021, 0.026946089529831494, 0.02208126655646733, 0.029569287252213274, 0.04282020085624286, 0.11389407063169138, 0.17828010927353585, 0.1330550853163004, 0.17103027472538607, 0.1273207858737026, 0.18271892251712935, 0.14253063686192036, 0.16104479054255144, 0.14203602554542677, 0.15256201715341636, 0.11578981604959283, 0.15081485733389854, 0.1376890316605568, 0.07783983421644994, 0.21928499825298786, 0.11901007539459638, 0.1142525135406426, 0.09151158202439547, 0.1516439321317843, 0.12478230494473662, 0.12037891122911658, 0.15756762426878723, 0.31018042298299925, 17.10727092197963, 58.528359276907786, 29.59318378993443, 36.12839535304478, 41.81195231846401, 50.47937147957938, 15.776501553399221, 0.5236926759992326, 0.2999791646642344, 0.7565068347113473, 3.9110180905887058, 3.0367731622287204, 1.969944796391896, 0.5300436552081789, 4.000643772738321, 25.355963843209402, 49.04261602674212, 49.77590806143624, 52.7357086454119, 50.920898233141216, 54.598322663988384, 48.28693689618792, 53.039122581481934, 49.89588955470494, 46.16572134835379, 38.41100365774972, 40.3926785332816, 39.12397915976388, 45.9522761617388, 47.50273888451712, 49.43244470868792, 51.06123447418213, 54.175267696380615, 50.97727939060756, 51.57597439629691, 53.19559948784964, 51.667548179626465, 41.65031290054321, 40.02328450339181, 37.62502690723964, 39.76943554197039, 38.50928940091814, 40.26458501815796, 38.78319781167166, 42.83510930197579, 38.8222154208592, 38.88971717017037, 39.17950221470424, 39.38706227711269, 39.02223668779646, 39.68866968154907, 37.96648570469448, 41.1001649584089, 42.55198063169207, 50.79498297827584, 49.43214593614851, 52.00665848595755, 50.97272832053048, 48.752497468675884, 49.77421270098005, 53.53163521630423, 51.21325063705444, 52.07446248190743, 48.43186937059675, 50.555304867880686, 51.652053696768625, 51.14346293040684, 49.2931923866272, 40.68675409044538, 39.463186740875244, 43.54881089074271, 51.48549495424543, 52.68434756142752, 52.039902142116, 49.76458249773298, 45.39795235225132, 42.062445299965994, 38.47161626815796, 38.359482765197754, 39.41532754898071, 38.82960135596139, 36.54612452643258, 38.1526974269322, 38.71119015557425, 35.19681562696184, 35.85363926206316, 35.49259696687971, 36.57803760256086, 37.72816596712385, 35.92208596638271, 34.88855184827532, 36.100856167929514, 37.13803114209856, 43.63792153767177, 49.828606673649375, 47.63525840214321, 46.446887152535574, 48.937166690826416, 47.44002096993582, 45.23166806357247, 40.88272108350481, 36.219930921282085, 35.08322300229754, 36.925576073782786, 35.53020061765398, 37.65326091221401, 45.00558410372053, 48.841243335178916, 47.86769648960659, 44.99040923799787, 46.6624550138201, 49.25475147792271, 44.62782096862793, 47.2209130014692, 45.292221614292686, 46.766476494925364, 47.29256282533918, 48.03134046282087, 44.00900745391846, 43.760463442121235, 9.264896495001656, 1.731039347393172, 6.5233370917184015, 10.287162372044154, 20.937416757856095, 14.198095781462532, 13.640205809048243, 1.878109587090356, 0.34318273780601366, 31.760031632014684, 43.068016392844065, 44.73093570981707, 43.91139568601336, 30.347174508231028, 39.15372787203108, 2.9065322194780623, 0.27261458017996376, 0.19706099506999764, 0.14093698880502156, 0.12711409053632192, 0.1256203499755689, 0.13427279783146723, 0.15843671906207288, 0.1270241303635495, 0.15817147972328321, 0.09126272252095596, 0.10578309372067451, 0.09426094485180718, 0.2264460939913988, 0.11587695351668767, 0.266182366758585, 0.0891304330102035, 0.11110473530633108], [0.031298683024942875, 0.09323943073728255, 0.017136834462040236, 0.03177161854026573, 0.045616552233695984, 0.04769471161333578, 0.03506393151889954, 0.028487400484404395, 0.050283818040043116, 0.009537140472925134, 0.003394820960238576, 0.022254382892112647, 0.009373182663694024, 0.04048365194882665, 0.02692018136648195, 0.027652514034083912, 0.03310047509148717, 0.06771064310201577, 0.03970526032415884, 0.04607507905789784, 0.02885362279734441, 0.03151623831529703, 0.03585831282128181, 1.3134560861757822, 24.460226399557932, 38.953341824667795, 31.78099434716361, 33.541813782283235, 33.28169754573277, 33.79785490036011, 0.18560636043548584, 0.03282532235607505, 0.18625968109284127, 1.2946391701698303, 2.8196404363427843, 1.176027883376394, 0.2425957838339465, 0.19821592952523912, 7.925447089331491, 32.340421608516145, 49.37033823558262, 49.2616024017334, 48.01706191471645, 51.34434229987008, 50.670346191951204, 46.54267154421125, 42.719880376543315, 39.932318687438965, 36.374618666512625, 36.26104688644409, 41.431767736162456, 48.47444793156215, 47.357135908944265, 48.296608788626536, 48.806085450308665, 48.504658699035645, 48.108065945761545, 48.49939543860299, 46.29449231284005, 45.5367044040135, 34.4943527494158, 35.35395956039429, 36.99779912403652, 35.99825211933681, 36.2714969771249, 35.94929163796561, 36.06683431352888, 36.372096470424104, 36.58721617289952, 36.78642450060163, 36.888660294669016, 35.15285784857613, 34.74789251599993, 36.17335019792829, 36.63889339991978, 37.347164971487864, 43.57142032895769, 45.950528689793174, 49.143218994140625, 47.44223397118704, 47.59505959919521, 46.978146416800364, 46.7984937940325, 45.48143148422241, 44.18278884887695, 46.36376585279192, 45.378188201359336, 47.912171908787315, 47.23806810379028, 51.35106815610613, 43.95983852658953, 33.409457547324045, 42.91047293799264, 44.800032070704866, 46.91038063594273, 48.417243412562776, 45.83010598591396, 41.21951069150652, 38.58277007511684, 34.32584156308855, 33.85844666617257, 34.33112914221627, 34.12037638255528, 34.934913703373496, 33.95893498829433, 33.1194987978254, 34.524254322052, 33.991480350494385, 33.27711868286133, 33.91332006454468, 34.25604690824236, 34.22674288068499, 33.6859506879534, 31.5245224407741, 32.911101477486746, 34.37480551855904, 38.50088555472237, 45.354873520987375, 44.25904532841274, 44.328388350350515, 45.12454421179635, 44.93107162203108, 44.314102854047505, 42.462866510663716, 36.98815849849156, 33.92848450796944, 31.545391355242046, 33.004047530038015, 31.71361071722848, 32.66212667737688, 38.610041754586355, 42.37489536830357, 41.87086956841605, 46.61474173409598, 42.44517987115042, 42.542854172842844, 44.43628345217024, 45.49970177241734, 43.77679865700858, 47.85847970417568, 44.36216354370117, 45.0992215020316, 32.56233664921352, 1.3294175096920557, 0.7943192571401596, 4.330724460738046, 7.964357869965689, 5.939916397844042, 4.1568101814814975, 3.7739970088005066, 1.0988725892135074, 2.230290106364659, 43.65262392589024, 30.731719085148402, 24.141628912517003, 30.007004601614817, 16.622609751565115, 6.329439793314252, 0.1381789610854217, 0.12756123154291085, 0.0450371002911457, 0.03138119288321052, 0.04254062067983406, 0.029695447268230573, 0.017368016431906393, 0.0652730128328715, 0.05741441702204091, 0.025468847548056926, 0.05463120886789901, 0.03812286237786923, 0.028542989465807165, 0.028549279485430037, 0.01602173170873097, 0.040067021269351244, 0.04038001251007829, 0.07822624633886985, 0.011578789579549005, 0.06307514969791685, 0.022914806114775792, 0.06162910336362464, 0.05518352619505354, 0.052262778992631605, 0.004478145798202604, 0.007682755157085401, 0.09875188315553324, 0.02252361032047442, 0.030894893620695387, 0.06103737332991191, 0.03394933257784162, 0.053497977355229, 0.006804615067916789, 0.010051468320723091, 0.050193233615053554, 0.01634666177311114, 0.06737742133970771, 0.029617836432797567, 0.028057253387357508, 0.03642565291374922, 0.04423075980905976, 2.7576071364539008, 35.65374653679984, 36.50108977726528, 28.07559299468994, 41.650288581848145, 39.81040212086269, 35.255479267665315, 0.10459575243294239, 0.05453867365473083, 0.2943684400192329, 1.7166821977921893, 5.050783216953278, 4.537022990839822, 2.140058845281601, 0.6126396059989929, 8.567756806101118, 36.619570459638325, 49.316969122205464, 49.9343513080052, 49.964256354740684, 52.422303199768066, 51.51822444370815, 47.19746283122471, 43.98679058892386, 41.042547021593364, 38.47356871196202, 37.9692302431379, 42.699230330330984, 48.95136533464704, 50.98875781467983, 50.40378897530692, 49.02534627914429, 48.05822999136788, 48.1228586605617, 50.414944308144705, 48.85249594279698, 48.208092212677, 36.327944142477854, 37.208753381456646, 37.99676595415388, 38.57013477597918, 38.216071946280344, 38.47478812081473, 38.08927774429321, 39.240076610020225, 36.44379840578352, 37.64664275305611, 37.580228396824424, 36.67293957301548, 36.88849353790283, 37.421538489205496, 38.20410367420742, 39.15850823266165, 43.42004687445504, 48.80063458851406, 50.872319902692524, 49.891206468854634, 49.68119021824428, 49.62017808641706, 48.56509065628052, 47.045873982565745, 45.824151379721506, 47.96338013240269, 48.411841188158306, 49.31376600265503, 49.69043132237026, 52.07880163192749, 46.253706387111116, 31.70817722593035, 42.1211645262582, 46.7215633392334, 46.56578472682408, 49.286483900887625, 46.9110163961138, 44.302586214882986, 41.16850049155099, 36.02383886064802, 35.25832455498831, 36.478087765829905, 36.302294867379324, 36.226166929517476, 36.08189453397478, 35.20093938282558, 35.62546736853463, 34.46436432429722, 35.174626554761616, 34.25219413212368, 35.08330985477993, 35.70255068370274, 34.76460640771048, 34.22978966576712, 34.87385640825544, 35.67588002341134, 39.665827478681294, 47.37795966012137, 45.796358585357666, 46.085469654628206, 45.69667625427246, 45.071317536490305, 45.49830518450056, 43.08165223257882, 38.10502583639962, 34.725217069898335, 33.98053693771362, 35.41983890533447, 33.86812898090908, 35.008738313402446, 40.95222391401018, 43.71134662628174, 43.029856886182515, 48.1067909513201, 44.009716170174734, 44.84549413408552, 44.80795649119786, 46.76634447915213, 45.206727504730225, 48.13860327856881, 46.03437260219029, 44.42152547836304, 34.30331202915737, 1.750405062522207, 1.622098975947925, 4.682990746838706, 4.726280629634857, 7.520062259265354, 6.639898768493107, 1.5114159094435828, 0.599757482962949, 2.2929613377366747, 44.601938928876606, 37.6316693850926, 32.45507035936628, 32.177243164607454, 23.037481989179337, 15.799592154366628, 0.2554204213832106, 0.17281816021672317, 0.025832209835893342, 0.04598265580300774, 0.04154963046312332, 0.054610730681036196, 0.02953232066439731, 0.04645378641518099, 0.03401303683806743, 0.020988180568175654, 0.012936734078851129, 0.03222623361008508, 0.04169375808643443, 0.039856597382043085, 0.07016010023653507, 0.041215577495417426, 0.05776575566934688, 0.05933427757450512, 0.12940863812608377, 0.22205621669335024, 0.1044183833790677, 0.15424287053091185, 0.21698228110160145, 0.09919390800808157, 0.11470643989741802, 0.08196979867560522, 0.14299384557775088, 0.14114844745823316, 0.10106256630803857, 0.08590693026781082, 0.1259777479405914, 0.13784418547792093, 0.1365673997040306, 0.08747495684240546, 0.09046113517667566, 0.138405836054257, 0.13712757107402596, 0.12014370385025229, 0.10518766567111015, 0.10883278971804039, 0.18449122884443828, 2.9439884381634847, 38.29731028420584, 48.0635210445949, 41.16054480416434, 45.03942877905709, 43.34154960087368, 42.437884262629915, 0.5893411561846733, 0.17760709752993925, 0.5982485296470779, 3.9252553837639943, 9.126671637807574, 6.1216864841324945, 1.6296589417116982, 0.5483775628464562, 9.498159681047712, 35.72465637751988, 50.81609507969448, 49.561927863529746, 49.91552863802229, 54.0856602532523, 54.59596722466605, 49.560315881456646, 46.09029517854963, 42.361454078129356, 42.14291933604649, 40.01341806139265, 46.42398588997977, 52.9155592918396, 52.933478696005686, 52.415723255702424, 51.33086974280221, 49.659581320626394, 49.80388845716204, 53.37952525275094, 49.92707306998116, 51.11415890284947, 36.895664078848704, 38.276674134390696, 40.79024403435843, 40.22800622667585, 40.328543186187744, 40.04101978029524, 38.45082030977522, 40.79489932741438, 39.18194450650896, 39.99339682715279, 40.40905891145979, 39.25688082831246, 38.20251601082938, 39.76915066582816, 40.51823943001883, 41.32824999945504, 46.17919737952096, 50.05835580825806, 52.987233434404644, 52.55435371398926, 51.57040888922555, 50.994722843170166, 51.35336800983974, 48.69844395773751, 47.79353836604527, 50.25455904006958, 50.67828450884138, 51.094116824013845, 52.90991735458374, 53.13739790235247, 45.707588400159565, 37.80046544756208, 42.444564955575125, 48.24632120132446, 49.83071545192173, 52.34726960318429, 49.37478160858154, 45.4725273677281, 43.44787440981184, 39.2340282031468, 37.01278638839722, 37.92776339394705, 37.23906489780971, 38.125106130327495, 37.895565441676546, 37.00818320683071, 37.868116583142964, 36.658845152173726, 36.362605231148855, 36.42934267861502, 37.09301723752703, 37.86228009632656, 37.91117456981114, 34.935882977076936, 36.471167360033306, 37.561416149139404, 40.67769363948277, 48.83448968614851, 45.819853918892996, 47.83222246170044, 47.479177543095176, 47.229987348829, 46.90034743717739, 44.6410677092416, 40.47728327342442, 39.14066873277937, 34.86663375582014, 36.92482219423567, 35.43690020697457, 36.643124852861675, 41.4614052772522, 47.45713438306536, 44.34026282174246, 50.29033184051514, 45.99517781393868, 46.46190568378994, 47.21737289428711, 47.6786846433367, 48.05432857785906, 50.06621074676514, 49.5711863381522, 43.90105676651001, 35.672808919634136, 2.816228436572211, 2.3832920449120656, 9.67030564376286, 17.277896097728185, 12.123362813677106, 10.490423236574445, 10.450632640293666, 2.0397025389330725, 3.606103777885437, 53.577670506068635, 39.93908275876726, 35.464578356061665, 42.31749977384295, 31.640977723257883, 26.711791890008108, 0.6804784515074321, 0.36385425286633627, 0.1567836177668401, 0.14939666486212186, 0.2014946107353483, 0.13368225523403712, 0.1417816291962351, 0.16882025902824743, 0.1319195298211915, 0.0933437826378005, 0.08524928734238658, 0.09437210924391236, 0.1476995266441788, 0.10188893375119992, 0.13466752879321575, 0.27382533092583927, 0.15860099239008768, 0.1261063710387264], [0.047312957633818896, 0.0326470745993512, 0.020065116795844266, 0.013576957314009113, 0.01411802792322955, 0.06415563529091221, 0.07267289182969502, 0.057897126834307394, 0.06184628206704344, 0.0096512064504038, 0.038904999515839984, 0.019454742316156626, 0.01583678341869797, 0.044967173864798884, 0.05993705415832145, 0.04315497985641871, 0.03744888372187104, 0.03852030747969236, 0.03907117274190698, 0.024525431117841175, 0.08183974386858088, 0.02693797255467091, 0.0024247970515196876, 0.08632258724953447, 5.013174789292472, 40.960183075496126, 34.01997491291591, 38.6870243208749, 31.4438955443246, 39.34090886797224, 7.6154175996780396, 0.2918290634240423, 0.05956689973494836, 1.610529573900359, 3.5571847685745785, 1.7838312174592699, 2.351086275918143, 0.2575368263891765, 0.9916817524603435, 15.798624617712838, 45.90053987503052, 48.66690261023385, 51.59947320393154, 49.00963640213013, 50.66191802706037, 44.03960037231445, 42.41917971202305, 36.974428858075825, 37.25594554628645, 40.81277356828962, 47.13126386914934, 47.097815241132466, 49.076210566929404, 46.958027907780235, 46.754070486341206, 45.87681177684239, 50.02580002376011, 46.471174580710276, 46.8344680922372, 39.11389037540981, 36.28882925851004, 36.42537873131888, 36.343688760484966, 35.24227769034249, 38.15458386284964, 35.795434202466694, 35.9110244342259, 35.32327631541661, 36.47444690976824, 35.46987983158657, 37.34499018532889, 34.91275937216622, 36.834867341177805, 34.72690895625523, 35.80427231107439, 35.937114919934956, 42.513838495527, 44.58990812301636, 44.54474483217512, 44.16740206309727, 45.35697882516043, 46.027184690747944, 43.74025460651943, 45.78701673235212, 46.02495779309954, 44.0928270476205, 45.46369620731899, 45.036190918513704, 47.175617694854736, 49.51738296236311, 49.682194232940674, 45.32726832798549, 41.51366267885481, 46.418941497802734, 48.83806453432356, 44.29174355098179, 43.474975858415874, 39.923407622746055, 35.51263557161604, 33.62371914727347, 34.58140672956194, 35.79082407270159, 36.09352581841605, 35.225636754717144, 34.28647654397147, 33.50875077928816, 33.1041293825422, 32.74676963261196, 33.518103054591585, 33.9810128893171, 33.29964474269322, 32.21750102724348, 33.369196210588726, 33.2121148109436, 32.758737904684885, 33.186743463788716, 38.65318659373692, 42.49097892216274, 44.27506787436349, 44.948588030678884, 44.18798262732369, 45.79535804476057, 44.70579712731497, 43.719997133527485, 43.57207693372454, 39.13176809038435, 36.09191383634295, 33.038955279758994, 30.555061135973247, 30.852586473737443, 31.312199388231548, 34.43224280221121, 37.34684188025338, 38.55234043938773, 40.43546554020473, 40.78246552603585, 39.82008443559919, 41.84176009041922, 40.73848690305437, 43.87180832454136, 43.984136377062114, 47.04215669631958, 22.37652243886675, 0.30785657625113216, 1.7023270023720605, 1.5350251282964433, 0.3304273379700524, 4.951067881924765, 4.197570051465716, 2.1819106681006293, 0.38023758945720537, 10.563581688063485, 41.32838896342686, 27.189310312271118, 42.62640973499843, 41.24534061976841, 17.979825701032365, 4.0471919264112195, 0.04213784568543945, 0.01631802080997399, 0.04334245229672108, 0.04468690497534616, 0.07742700672575406, 0.021390550137896622, 0.019724135985597968, 0.0021878248454803334, 0.02834026186194803, 0.01413510410514261, 0.05508810720805611, 0.02959645240168486, 0.05711350031197071, 0.05976426521582263, 0.05174717040998595, 0.053549803859953365, 0.027107328109975373, 0.014518691825547388, 0.06312702370009252, 0.005158967055779482, 0.015542078696723496, 0.025612734291436415, 0.039091966447553465, 0.04538592496620757, 0.06110390368849039, 0.04171708272770047, 0.0831581170537642, 0.0442452431390328, 0.045458942119564326, 0.026741180435887406, 0.02869180915877223, 0.01647765465479876, 0.02546566352248192, 0.03523146520767893, 0.08469211509717361, 0.01840275519394449, 0.035078740545681546, 0.004367620077183736, 0.059110883490315506, 0.03697601266737495, 0.05465459118464163, 0.08328680800540106, 9.988453234945025, 49.333853244781494, 34.31514828545706, 43.27126162392752, 38.7070038659232, 44.1583867754255, 7.578652943883624, 0.42905427568725174, 0.020975474999951463, 1.9374561054365975, 3.3391570278576443, 6.051794120243617, 4.285923779010773, 0.7318775877356529, 1.5166472515889575, 17.75341691289629, 46.276559012276785, 49.85466936656407, 50.95333937236241, 51.88996696472168, 51.69350317546299, 47.01966885157994, 43.893952233450754, 40.1354284286499, 38.62973642349243, 41.902261529650005, 49.1189524105617, 50.147588048662456, 49.59863519668579, 47.13474491664341, 48.58509799412319, 46.146044049944194, 51.53928443363735, 49.25579023361206, 49.385561738695415, 42.65835755211966, 37.87960890361241, 37.907245363507954, 37.5288325718471, 37.22068343843733, 39.928399903433665, 35.95483977454049, 38.6410585130964, 36.8774493762425, 38.01917389460972, 37.36149910518101, 38.37806919642857, 37.18996197836739, 38.06393766403198, 36.88161482129778, 38.75957046236311, 38.29961013793945, 44.71588938576834, 46.4455565725054, 47.55029582977295, 47.6990532875061, 47.18243040357317, 46.72189685276577, 46.120474679129465, 47.28981481279646, 46.64426115580967, 45.688887323652, 46.38542686189924, 47.88471262795584, 49.82560852595738, 51.258254119328086, 50.16988481794085, 46.52286917822701, 42.27436188289097, 46.427550315856934, 49.66996192932129, 46.32428618839809, 44.185251985277446, 40.52643830435616, 38.20009108952114, 35.72390944617135, 36.07554388046265, 35.90181459699358, 37.97514316013881, 36.807213510785786, 37.45325354167393, 36.35428128923689, 34.5713700566973, 34.06283835002354, 34.99729463032314, 34.918543747493196, 33.56144939150129, 34.243762493133545, 34.33282102857317, 34.75451067515782, 33.509195463997976, 34.387166363852366, 41.06154687064034, 44.791680335998535, 45.34491327830723, 46.88632944652012, 45.60006502696446, 46.58586154665266, 45.32161944253104, 46.308211530957905, 44.37369755336216, 40.56246471405029, 36.042838709695, 34.74650982448033, 32.22672823497227, 32.51360545839582, 33.223579338618684, 35.49677630833217, 38.87659202303205, 40.92842633383614, 43.03813566480364, 42.71815374919346, 40.72215516226632, 43.7365060533796, 42.828320911952424, 45.07440948486328, 45.94772856576102, 47.63421964645386, 23.534630809511455, 0.49541106500795906, 3.1498624767575945, 7.30354596887316, 5.647465416363307, 6.352531697068896, 5.536128350666591, 1.181298743401255, 0.37407670861908365, 10.702617747443062, 47.90675578798567, 30.830136844090053, 44.35753951753889, 46.58178990227835, 28.232137645993912, 8.399263858795166, 0.08349283837846347, 0.018076819201399173, 0.03091161950890507, 0.0609402342566422, 0.05350089505580919, 0.015449663923521127, 0.07449249204780374, 0.032856596035084555, 0.08504657500556537, 0.037472296572689495, 0.009675842360593379, 0.008444672799669206, 0.02042537648230791, 0.022104440223691717, 0.010151098465680011, 0.06411731163305895, 0.03710518537887505, 0.05354514232437525, 0.14356621700738156, 0.1189395756061588, 0.1296241544187069, 0.06272550060280732, 0.12529834439711912, 0.17802880704402924, 0.1527762578002044, 0.2632096777004855, 0.18446498310991696, 0.10567319140370403, 0.24355650799615042, 0.1600036464099373, 0.14674941476966652, 0.11082616275442497, 0.11985901769782815, 0.1305304193603141, 0.1648084885839905, 0.12620743204440388, 0.14606227592698165, 0.20713966925229343, 0.1428398045578173, 0.16750160764370645, 0.15536571027977125, 0.19072045172963822, 12.030489717211042, 54.27121189662388, 41.96994045802525, 48.4485103062221, 41.143014499119346, 49.96694530759539, 11.160018529210772, 0.7408371269702911, 0.4210076103253024, 5.056446433067322, 9.914923923356191, 9.564254420144216, 5.065264565604074, 0.40782847894089563, 1.7942832623209273, 18.151936054229736, 48.7620165007455, 49.70437983104161, 53.670376845768516, 52.85643012183053, 54.23113121305193, 48.45051833561489, 46.79487030846732, 40.432210309164866, 40.9738883972168, 45.04889222553798, 50.64465522766113, 52.13138212476458, 52.53959574018206, 47.595851693834575, 49.30675527027675, 48.296702589307515, 54.45747225625174, 51.37928826468331, 51.4943573815482, 42.397188663482666, 39.573961871010916, 39.482867513384136, 39.81866700308663, 37.56812810897827, 42.438502652304514, 37.85277496065412, 39.86517129625593, 38.78576864515032, 41.418732915605815, 38.48515830721174, 40.77089330128261, 37.581798689705984, 39.81219823019845, 39.653358936309814, 40.369902338300435, 38.9208277293614, 47.30224166597639, 47.65592234475272, 48.111161368233816, 48.367515155247276, 48.68455450875418, 49.7425080708095, 47.656572001320974, 48.70888710021973, 50.37606566292899, 47.94734716415405, 48.74708482197353, 49.76565252031599, 50.84156370162964, 52.38919503348214, 52.58154896327427, 47.18696757725307, 43.53363602502005, 49.788605894361226, 51.65653528485979, 48.50709751674107, 46.01120730808803, 43.2858806337629, 39.65932396480015, 37.450522899627686, 38.18276228223528, 38.42419481277466, 39.46920735495431, 38.350505692618235, 39.10426712036133, 38.00483628681728, 37.01238686697823, 35.52847399030413, 37.08556529453823, 35.86485365458897, 35.582909652165, 35.771594933101106, 36.93170438494001, 35.57833078929356, 35.32402672086443, 35.48574256896973, 42.33282402583531, 46.065163544246126, 47.34397949491228, 46.384693826947895, 47.92228153773716, 47.22482483727591, 46.55428545815604, 48.44999027252197, 45.04921184267317, 42.53900487082345, 38.494816303253174, 37.083605902535574, 33.530606337956016, 34.84203365870884, 33.791737011500764, 37.398196016039165, 40.90521935054234, 41.80031061172485, 43.64433472497122, 44.72813211168562, 42.654546465192524, 46.131591796875, 44.64546939304897, 46.46864891052246, 45.58656120300293, 46.72749015263149, 25.289594650268555, 1.1400354547160012, 4.092736499650138, 7.569084405899048, 5.7591234019824435, 11.219496846199036, 12.057691046169825, 9.7735550062997, 0.7346150694148881, 12.794278264045715, 50.46524926594326, 38.77257054192679, 51.10810702187674, 48.26345198495047, 37.80132702418736, 16.54881293433053, 0.11057334060647658, 0.11239968546267066, 0.21133597408022198, 0.15723925403186254, 0.12624289228447846, 0.16423230378755502, 0.18656628392636776, 0.10857819659369332, 0.12497434392571449, 0.09586766827851534, 0.13047282530793122, 0.09612088397677455, 0.09563960587339741, 0.10490105926458325, 0.1374834491206067, 0.15676065614180906, 0.0981472609564662, 0.1409937957567828], [0.05381077182080064, 0.04733564105949231, 0.037479950447699854, 0.008583918363521141, 0.012651181097940674, 0.025850978114509156, 0.06294597020106656, 0.022708288892837505, 0.05823095249278205, 0.027071291115134954, 0.026313012964757423, 0.07200918280120407, 0.029116819745727947, 0.01008422120607325, 0.02331096030372594, 0.012339135565395867, 0.038814343844673464, 0.048978998591857295, 0.054034522135875056, 0.04225514064143811, 0.0629601583683065, 0.014711965740259205, 0.021946272014507225, 0.04481376388243266, 0.8023338413664273, 26.0485029561179, 35.45526776994978, 23.32827799660819, 35.458856514522004, 27.49888035229274, 28.213189908436366, 0.06175616583121674, 0.20862674659916333, 0.8681798023836953, 2.9437302691595892, 3.591185126985822, 3.2022657905306136, 1.550371310540608, 0.10931881078119789, 5.152609935828617, 29.637850284576416, 51.60265547888619, 50.24529709134783, 52.660966873168945, 48.55619348798479, 46.81944261278425, 40.93838657651629, 38.02353388922555, 41.653377056121826, 47.33756283351353, 48.45287377493722, 51.568897656032014, 47.115081514631, 47.79567493711199, 45.537687574114116, 49.89542402539934, 47.40627704347883, 47.1681136403765, 39.81535618645804, 35.41248771122524, 35.08747182573591, 37.005831241607666, 36.51945039204189, 37.2748133795602, 37.416591371808735, 35.644706930433, 35.65395498275757, 35.859798840114046, 36.36420331682478, 36.247268608638215, 37.83223261151995, 34.841925961630686, 36.44522973469326, 36.378485339028494, 35.055461474827354, 37.280476161411826, 43.459686347416465, 44.608522347041536, 42.513115882873535, 44.773792198726106, 43.02231461661202, 41.83146980830601, 43.35879155567714, 44.39343738555908, 44.213326181684224, 45.44879926953997, 44.75437198366438, 46.393198422023225, 45.27100528989519, 47.029538767678396, 46.89901338304792, 40.970251015254426, 47.59461491448538, 46.900816440582275, 46.38531221662249, 43.861552783421104, 38.394029208592, 34.16135685784476, 35.12220934459141, 38.378802231379915, 40.039421694619314, 44.11336244855608, 43.180743966783794, 42.139563356127056, 35.790066719055176, 35.255781514304026, 34.13544702529907, 32.81538656779698, 32.93078224999564, 35.326875482286724, 32.73253624779837, 34.219367367880686, 34.034107548849924, 33.344738551548545, 33.190662247794016, 33.07909849711827, 36.65616314751761, 42.047378131321494, 43.92801577704293, 44.73789780480521, 43.66184071132115, 43.371131556374685, 44.868332862854004, 46.36180993488857, 43.881209237234934, 44.05277763094221, 42.93928016935076, 42.035281317574636, 36.028560161590576, 35.96571717943464, 33.53874962670462, 31.337442193712505, 31.729021821703228, 32.283561025347026, 32.822560582842144, 34.93558767863682, 36.101123673575266, 39.749581064496724, 40.48287309919085, 44.08947801589966, 44.73709181376866, 43.53872210638863, 10.164170571735927, 0.597107776573726, 1.4081464622701918, 5.263550954205649, 3.6374082352433885, 3.331436276435852, 3.9090760690825324, 0.63592850204025, 0.09699468780308962, 16.278533220291138, 32.00246817725045, 27.24310847691127, 28.582898344312394, 29.292900017329625, 14.603270428521292, 3.4564332834311893, 0.2530909020985876, 0.029856382203953605, 0.08857752196490765, 0.04330467485955783, 0.060015689581632614, 0.03902871002043996, 0.04203521726386888, 0.038351012992539575, 0.07773306673126561, 0.024800850178248117, 0.0689484877511859, 0.03664592234417796, 0.027054217477728213, 0.07872888472463403, 0.011775292472780814, 0.05080629339707749, 0.06836891027965716, 0.08825196764831032, 0.0517226990445384, 0.02710523482944284, 0.043459509765463214, 0.07321147221539702, 0.048518235994768996, 0.027655304509348104, 0.0660929341933557, 0.016861910732196908, 0.051743024561022005, 0.02710462245158851, 0.06618564243295363, 0.004473295120988041, 0.01842575074572648, 0.0105498921558527, 0.01594152717318918, 0.013148421737631517, 0.03365622241316097, 0.020028966146388223, 0.007521158649719187, 0.064236767723092, 0.14725887243236813, 0.018815526705501334, 0.016224769742361138, 0.022448116514299597, 1.7976138378892625, 34.3869092805045, 38.67347880772182, 27.174152817044938, 42.978575706481934, 35.296418053763254, 29.907982349395752, 0.053538899802203686, 0.05688554307978068, 0.8500574891056333, 2.0397972081388747, 6.672606979097639, 5.401664640222277, 4.070875729833331, 0.7630326045410973, 7.884985991886683, 33.78821427481515, 51.52157347542899, 51.08266619273594, 54.25456748689924, 51.30152402605329, 48.66320616858346, 43.47614662987845, 38.314465386526926, 42.848543643951416, 48.41294595173427, 49.061324051448274, 50.92325019836426, 48.55567932128906, 48.75950125285557, 46.69907202039446, 50.53149686540876, 48.978060313633506, 48.47409009933472, 42.36748858860561, 37.65938227517264, 36.23351812362671, 38.43313019616263, 37.824363776615684, 38.581349168504985, 39.7425216947283, 37.623046670641216, 37.506629603249685, 37.71515199116298, 36.973442213875906, 37.34420851298741, 39.12226642881121, 37.23724446977888, 38.062388215746196, 37.55619805199759, 36.490066460200715, 38.422614097595215, 44.789314474378315, 46.807140827178955, 45.19717025756836, 46.14860446112496, 44.66410446166992, 45.159434591020855, 45.27855103356497, 45.88603203637259, 45.20523016793387, 48.145339557102744, 47.84208195550101, 48.600717544555664, 48.00843225206648, 49.170212745666504, 49.23004020963396, 43.433748722076416, 47.90191984176636, 48.66795526232038, 48.15231902258736, 45.41635465621948, 40.28800739560808, 37.24309832709176, 37.04621417181832, 37.71069472176688, 40.20176635469709, 43.687239851270405, 43.164863858904155, 43.03602341243199, 37.51916067940848, 35.60138838631766, 35.89768736703055, 34.51309551511492, 34.28388139179775, 35.361418451581685, 34.93641798836844, 35.703797885349815, 35.887668064662385, 34.75399650846209, 34.32147809437343, 34.842071873801096, 38.31747395651681, 42.787323066166465, 45.70876611982073, 47.13763189315796, 46.03990684236799, 44.74287618909563, 45.96395608357021, 46.94051497323172, 46.54137223107474, 46.11733061926705, 43.25442961284092, 41.318838664463584, 37.60654469898769, 36.96927676882063, 34.19788701193673, 32.41658081327166, 32.84927988052368, 34.94306741441999, 34.594854967934744, 35.42936141150338, 38.445706435612266, 39.92504044941494, 42.164535181862966, 45.37358501979283, 45.45908955165318, 44.57114103862217, 11.745076826640538, 1.0483212960617883, 4.833365397793906, 7.5185284444264004, 5.538984928812299, 7.535186750548227, 3.5082968090261732, 0.8716004331197057, 0.10080446515764509, 19.98503933634077, 37.55707005092076, 36.01986449105399, 34.47385556357247, 37.65688787187849, 26.821665491376603, 5.817928177969796, 0.22608832961746625, 0.0424561057505863, 0.03534592727997473, 0.012903359485790133, 0.04092552413099578, 0.06293220951088838, 0.03261798580310174, 0.020702435901122432, 0.04086152131536177, 0.014026890492199786, 0.04012186046955841, 0.04105522270713534, 0.05490781366825104, 0.07801468590540545, 0.051837442708866935, 0.03778762875923088, 0.045361117725925784, 0.05832915008068085, 0.1978771234197276, 0.17204718158713408, 0.1761801926685231, 0.11035467591136694, 0.08116827239947659, 0.133773178926536, 0.15500099770724773, 0.14341099533651555, 0.15470149235001632, 0.09819172535623823, 0.08114923270685331, 0.13588672051472322, 0.06886831883873258, 0.07694672606885433, 0.09489196206309966, 0.07295371711786304, 0.12131499099944319, 0.10061839049948113, 0.09803465807012149, 0.2733953025724207, 0.22629328790519918, 0.09512324072420597, 0.09592773219836609, 0.13751656162951673, 1.7641216750655855, 38.703564507620676, 47.26936626434326, 29.880856582096644, 44.7999313218253, 36.6647024835859, 36.39790555409023, 0.22785648331046104, 0.6767187703933034, 2.337278251137052, 10.032701969146729, 11.386544568198067, 8.0360016141619, 4.713748684951237, 0.27763204808746067, 7.195555763585227, 33.21399082456316, 52.29583556311471, 50.49777725764683, 55.88998930794852, 53.92535488946097, 51.23817382540022, 44.37521573475429, 40.581648690359934, 44.740030901772634, 52.27250698634556, 51.6684444972447, 54.91375698362078, 48.68478727340698, 50.55814320700509, 47.24134765352522, 54.36322341646467, 51.03725276674543, 49.8167530468532, 43.42712014062064, 40.433933462415425, 37.315317903246196, 40.719598225184846, 39.87175818852016, 42.16541065488543, 40.4336381639753, 38.657685552324565, 39.32503570829119, 39.96959924697876, 39.13217108590262, 39.488450390951975, 43.022592544555664, 39.00035681043352, 40.16151891435896, 39.47933782849993, 38.04491349628994, 42.10634749276297, 48.07596179417202, 49.323305879320415, 47.272103854588096, 49.69891159875052, 47.33377953938076, 46.84956305367606, 48.39174352373396, 48.852249281747, 47.680994919368196, 49.82122073854719, 49.1131854057312, 50.67237506593977, 49.52183328356062, 51.067876952035085, 49.60036529813494, 46.48471661976406, 50.53626332964216, 50.25751897266933, 49.59931264604841, 46.927869251796174, 41.445796149117605, 37.21497201919556, 39.50170407976423, 41.502246788569856, 43.87212446757725, 46.525710991450715, 44.74740294047764, 46.28301041466849, 39.33738613128662, 37.960798604147776, 37.86921787261963, 35.50063255855015, 36.16622829437256, 38.202710560389924, 34.795393875667024, 37.94459193093436, 37.86091477530343, 36.39972250802176, 36.45068407058716, 38.00216817855835, 40.72153329849243, 44.87605925968715, 47.84879044124058, 48.897402150290354, 47.57693174907139, 45.5472274507795, 45.64567995071411, 47.75824499130249, 48.784125668661936, 48.00456557955061, 44.99874012810843, 44.397846017565044, 40.461184297289165, 39.47245911189488, 37.53657633917672, 34.532925673893516, 35.100353785923545, 36.89848157337734, 36.30963216509138, 37.93237699781145, 38.87698459625244, 42.60387672696795, 44.80255079269409, 47.78028467723301, 47.462550503867014, 45.947356837136404, 11.596180404935565, 1.1931322855608804, 5.512624766145434, 14.640898397990636, 8.10264699799674, 9.614033920424324, 14.556621091706411, 2.6118816988808766, 0.2650017701089382, 21.88643819945199, 42.42819847379412, 36.843896525246755, 38.035151277269634, 42.054058824266704, 38.162761892591206, 8.53451314994267, 0.5578936093619892, 0.2854945319039481, 0.1612675128770726, 0.11653452180325985, 0.16820509918034077, 0.15442436507769994, 0.14814516130302632, 0.16735511193318026, 0.17559505120984145, 0.0801532179383295, 0.1729683064456497, 0.19057627660887583, 0.12866554728576116, 0.14850228785404138, 0.10502466798893043, 0.17194217150764807, 0.11319248577845947, 0.17899706294494017], [0.04848827528102057, 0.027142640768683383, 0.011036015847431762, 0.03800708055496216, 0.03574840032628604, 0.022060766317216412, 0.01752365879448397, 0.013325394696689077, 0.027135965680437427, 0.04049766369696174, 0.021449592862544314, 0.06094771171254771, 0.11009038652160338, 0.0015880483406363055, 0.04863065567665866, 0.05681189149618149, 0.029868120859776224, 0.032124514425439496, 0.06030591257980891, 0.06801613313811165, 0.04571283635284219, 0.05031527492350765, 0.02156399386668844, 0.037647233078522344, 0.036282967177352736, 3.01004387651171, 37.74322271347046, 24.168949229376658, 34.813841342926025, 30.216082845415386, 28.99479624203273, 7.974703737667628, 1.0795960064445222, 0.18635889648326806, 1.9629842213221957, 5.415954479149409, 5.962512808186667, 3.3364153121198927, 1.824436490024839, 0.5043432457106454, 7.575908405440194, 39.31801107951573, 50.94387592588152, 53.63198110035488, 48.734998430524556, 49.03771754673549, 39.64787333352225, 41.234786306108745, 47.183847836085725, 47.528117179870605, 48.268308775765554, 49.34125655038016, 45.22518539428711, 47.27758598327637, 50.40506049564907, 48.045174326215474, 45.74583823340279, 42.584341866629465, 36.17927006312779, 37.01451996394566, 34.8534391266959, 36.14231954302107, 35.41664273398263, 37.18947213036673, 34.67802837916783, 36.30598783493042, 36.65503406524658, 37.35471766335623, 35.42779459272112, 36.9805189541408, 36.90754549843924, 37.067572934286936, 35.76397623334612, 35.42299338749477, 36.10671697344099, 38.61079216003418, 45.74600151606968, 48.75593335287911, 45.16742501940046, 46.45511729376656, 45.936493328639436, 44.35637222017561, 43.68491915294102, 44.53816141401018, 42.27713768822806, 43.09760529654366, 42.277992316654746, 46.46912486212594, 47.021631717681885, 48.86502007075718, 47.08780983516148, 46.37936455862862, 47.02435193743025, 47.31289325441633, 47.16395514351981, 39.40959528514317, 35.55849715641567, 38.41168458121163, 41.25886181422642, 43.143744809286936, 45.39691012246268, 47.48419761657715, 47.1954721723284, 46.21094369888306, 38.41705901282174, 33.07685422897339, 33.285880361284526, 33.64235074179513, 34.363893372671946, 34.510545526232036, 33.06592123849051, 33.81152548108782, 33.700086797986714, 32.766446931021555, 33.41460963657924, 33.10770075661795, 38.80558490753174, 42.11150653021676, 43.385587283543174, 44.00112124851772, 45.557194641658235, 44.32697786603655, 43.188446044921875, 43.75101389203753, 44.019759791237966, 44.40414455958775, 43.68415832519531, 41.689521585192, 43.649882861546104, 43.13299594606672, 41.037189960479736, 40.29328107833862, 39.6635172026498, 39.0226605279105, 37.497659478868755, 35.18497589656285, 37.66233178547451, 38.23399135044643, 42.43422603607178, 43.41777828761509, 47.288491180964876, 33.954262324741904, 3.3370028691632405, 1.0524627481188094, 3.345249512365886, 8.724361385617938, 8.392405986785889, 5.998363775866372, 3.1165958046913147, 0.6819707942860467, 0.5578963777848652, 26.646087987082346, 30.22576516015189, 26.30073298726763, 25.39060582433428, 28.620877197810582, 11.295417206627981, 0.014457028259390166, 0.01742605831740158, 0.005958503952050316, 0.030091328346835713, 0.06098634749650955, 0.04374986507796815, 0.03129474752183471, 0.016356614185497165, 0.03590054144816739, 0.03127794360209789, 0.03840653412044048, 0.0832796630316547, 0.025390149360256534, 0.01291347389841186, 0.019965253404474685, 0.046986171776162725, 0.04809902688222272, 0.015415606554597616, 0.07050150513116803, 0.05451657037649836, 0.007853265070090336, 0.040880425300981314, 0.03185371109949691, 0.004302143992390484, 0.02125638340865927, 0.0069177395780570805, 0.047371542347329, 0.03672436438500881, 0.08049408000494752, 0.05656368677903499, 0.018757478034655963, 0.06431011735860791, 0.06724386529198714, 0.030472525927637304, 0.046807907056063414, 0.042587344601218186, 0.04338970886809485, 0.04656469635665417, 0.051792381198278496, 0.014378308019201671, 0.024442159604015093, 0.02859554539567658, 0.0116878462722525, 0.06047616380133799, 6.256022087165287, 46.23916728155953, 21.763451610292705, 36.84873941966465, 35.15339980806623, 34.397164821624756, 6.071974728788648, 0.7767937289816993, 0.769457354077271, 1.950485497713089, 5.74593311548233, 4.767348825931549, 8.29304848398481, 2.358687388045447, 1.7834828304392951, 10.597164937428065, 41.86507477079119, 49.88236141204834, 54.51256799697876, 49.372853483472554, 50.98295954295567, 41.3990660394941, 42.65448045730591, 46.595109598977224, 50.992211069379536, 51.216912337711875, 51.61096205030169, 46.082082407815115, 46.98934343882969, 51.69368035452706, 50.61522613252912, 47.23143604823521, 44.84988192149571, 38.23382111958095, 38.544065134865896, 38.114704677036826, 37.87850761413574, 37.90090165819441, 38.81359270640782, 36.257659639631, 38.581151144845144, 37.35438414982387, 37.78239665712629, 36.18006910596575, 40.12171615873064, 38.89330244064331, 37.68144975389753, 36.85144921711513, 36.88631527764456, 37.44035768508911, 39.26104279926845, 46.655958448137554, 50.29047775268555, 47.15209804262434, 47.38915320805141, 47.35487079620361, 46.08825240816389, 44.68098163604736, 44.37669917515346, 42.98292875289917, 45.76764862877982, 44.37445490700858, 47.73566681998116, 48.022099358694895, 49.84281573976789, 48.2705843108041, 49.26495490755354, 49.500787190028596, 47.96917840412685, 48.195738315582275, 42.62273413794381, 37.881776741572786, 39.477722372327534, 41.154180254255024, 43.20432962690081, 47.06085082462856, 48.032611983163015, 48.43506554194859, 48.34558664049421, 38.475746972220286, 34.02503320149013, 34.98465238298689, 35.72829375948225, 34.548645973205566, 35.29014383043562, 34.40211541312081, 36.248932702200754, 34.97522367749895, 35.17577300752912, 34.27397673470633, 34.5382410458156, 39.526481355939595, 42.7560909135001, 46.27014929907662, 45.9061644417899, 46.41005475180489, 44.97523089817592, 45.2367194039481, 45.17285851069859, 44.96798392704555, 45.324944155556814, 45.1714688709804, 44.89951637813023, 43.51358004978725, 44.49274798801967, 41.0836421421596, 40.085050514766145, 40.1043039730617, 39.15334572110857, 37.71207741328648, 36.35602181298392, 37.98201492854527, 39.73118918282645, 44.45370953423636, 46.65522541318621, 49.22688920157296, 36.64211736406599, 3.695164918899536, 1.7007828738008226, 5.156127895627703, 9.879152859960284, 13.617377502577645, 7.737423624311175, 2.543611087969371, 1.0963221660682132, 0.46427721849509646, 26.859347309385026, 35.10064908436367, 30.807829652513774, 23.35520921434675, 34.455741609845845, 16.368991817746842, 0.06062354839273861, 0.04315448113318, 0.04862803992416177, 0.020727923372760415, 0.06921324533011232, 0.0799549160791295, 0.06292412137346608, 0.04090772955013173, 0.050547388182686906, 0.052774112804659774, 0.02823040704242885, 0.015661200608259866, 0.0755065151357225, 0.006952201099401074, 0.011228714703715273, 0.11621628887951374, 0.06659407980207886, 0.06513398779290062, 0.017180050357377956, 0.11202476772346667, 0.1147493233105966, 0.09164779792938914, 0.09046127088367939, 0.12063922440367085, 0.07891117315739393, 0.10450503908629928, 0.1427639036306313, 0.1635997463017702, 0.21297467686235905, 0.11892500067395823, 0.11967959946819715, 0.1966381591877767, 0.16106141465050833, 0.14588600609983715, 0.13899956776627473, 0.1510159479720252, 0.09976627943771225, 0.1674776824989489, 0.14033911802939006, 0.09127659177673714, 0.1194318663328886, 0.08634630204843623, 0.1056208967098168, 0.1291666996798345, 6.205589021955218, 52.48302003315517, 32.6913195337568, 44.37962784085955, 40.41914769581386, 39.370758329119, 9.696618471826826, 1.6924624059881483, 1.6041716464928217, 5.536672915731158, 17.966283661978586, 13.327692338398524, 7.332311511039734, 3.0655625888279507, 1.3546621607882636, 9.93089348929269, 42.143860816955566, 51.925291606358115, 57.12927000863211, 51.67291913713728, 52.45132235118321, 42.88459437234061, 45.45800563267299, 49.9318881716047, 51.90398842947823, 54.318379742758616, 51.962353297642295, 47.49054479598999, 47.936028548649375, 55.42096158436367, 51.95439066205706, 49.93338898250035, 46.33381216866629, 40.16159881864275, 41.36906024387905, 40.2992183140346, 39.92820535387312, 39.81228855678013, 41.26789099829537, 38.13551453181675, 39.7936361176627, 39.61594288689749, 39.427438259124756, 38.3336945261274, 41.66698510306222, 40.34257159914289, 39.964037214006694, 37.75553144727434, 39.37430885859898, 40.77821670259748, 42.064804213387625, 50.385317189352854, 51.05673551559448, 49.4780387878418, 50.24160064969744, 50.01001371656145, 47.64298479897635, 47.08225475038801, 47.91836622783116, 45.51537690843855, 45.995445319584434, 46.665633814675466, 49.67588874271938, 50.015544482639854, 51.36467272894723, 49.66186727796282, 49.88537345613752, 49.665883336748394, 50.643164839063374, 51.163199288504465, 44.0610807282584, 38.95388725825718, 41.20277942929949, 44.546513148716514, 46.203241620744976, 48.92170694896153, 50.32427726473127, 50.53574916294643, 50.277911935533794, 41.14203480311802, 37.14901624407087, 35.65372569220406, 36.45292139053345, 38.540865489414756, 37.20881938934326, 35.48340450014387, 37.84744221823556, 36.47064624513899, 36.03602252687727, 35.753484453473774, 36.155601024627686, 42.5929228918893, 44.858608858925955, 47.69601345062256, 47.249105317252024, 48.83158881323678, 46.84775652204241, 46.48223958696638, 45.14570147650582, 46.437548773629324, 46.358349731990266, 46.67405155726841, 45.1709303855896, 46.14445638656616, 48.151645047324045, 43.67219352722168, 43.64599881853376, 43.07911614009312, 42.243348598480225, 40.3982127734593, 38.660430090767996, 40.27790124075753, 42.294789586748394, 45.48492642811367, 48.815767765045166, 48.95029183796474, 36.62754699162075, 4.579590695244925, 2.488938970225198, 7.703512941087995, 14.79337661606925, 14.165973390851702, 12.75621690068926, 9.322779331888471, 2.6397170509610857, 0.735921602163996, 35.428388663700645, 38.15901681355068, 36.83521127700806, 33.042592661721365, 43.53104434694563, 24.618992737361364, 0.18380993897361414, 0.10857497355235474, 0.1183385428573404, 0.06570405220346791, 0.17310182856661932, 0.1585775422198432, 0.11911758248295103, 0.17879447952977248, 0.08986939157226256, 0.17119439877569675, 0.1363264654896089, 0.23167546838521957, 0.15278589299746922, 0.054967019241303205, 0.0829063466350947, 0.1684922416295324, 0.13622738580618585, 0.10858114143567425, 0.22105250055236475], [0.06915417885673897, 0.04213879902714065, 0.05436965058158551, 0.0024291856887949897, 0.06484803956534181, 0.058391833145703585, 0.04023927416918533, 0.06103807222098112, 0.0181211852135935, 0.05593591296513166, 0.12112026501979146, 0.05426670324855617, 0.01672781185646142, 0.04015394839059029, 0.019173129927366972, 0.004749669219433729, 0.03186964649440987, 0.0164120454075081, 0.019228135368653705, 0.03507001458534172, 0.023111593144546663, 0.03330253264201539, 0.040112500078976154, 0.02480227340544973, 0.042493045197001526, 0.02351142160062279, 15.06294240270342, 36.786160469055176, 27.904844488416398, 37.0293231010437, 30.866121564592632, 19.15399135862078, 0.021561540962596024, 0.5221323168703488, 0.9883288123777935, 4.706438311508723, 2.682938103164945, 10.728286130087715, 3.6941930396216254, 1.2893854635102409, 0.9982197902032307, 17.150379283087595, 50.97797073636736, 53.25678532464163, 51.01860727582659, 47.84034143175398, 42.564035756247385, 45.65072781699044, 50.49456024169922, 49.789967741285054, 49.416328362056184, 48.67205817358834, 49.34565823418753, 49.477034773145405, 47.789143630436485, 46.502799306597026, 41.79652731759207, 37.84558704921177, 36.37974296297346, 36.52060726710728, 36.9101927621024, 38.815777914864675, 38.50316456386021, 38.76377064841134, 36.86039502280099, 38.19431018829346, 37.92969151905605, 36.49809857777187, 36.62615040370396, 37.04441111428397, 36.84547029222761, 35.65789808545794, 35.88075113296509, 35.92639037540981, 35.238338061741416, 37.783428464617046, 46.72681965146746, 48.57350492477417, 47.27853788648333, 44.44060870579311, 45.92916297912598, 45.58446284702846, 47.33407483782087, 45.47924974986485, 44.859689303806846, 44.86369841439383, 42.83014133998326, 45.343019894191194, 47.24986267089844, 48.522512095315115, 44.708208152226035, 45.106141907828196, 50.0332658631461, 45.908460821424214, 40.48879991258894, 37.82844931738717, 40.45335367747715, 41.351373604365754, 44.9156813621521, 46.53138419560024, 46.20687552860805, 48.07585409709385, 46.95126731055123, 48.356703758239746, 39.96161576679775, 33.18077148709978, 34.66946472440447, 32.92669323512486, 35.06120068686349, 34.17808812005179, 34.22618007659912, 34.05633136204311, 33.69823162896292, 33.001612186431885, 32.56983028139387, 33.19626596995762, 38.26372616631644, 42.725508417402, 43.79151494162423, 44.01949575969151, 45.48859507696969, 44.242345333099365, 44.149010181427, 45.532618863242014, 44.98918982914516, 46.02839020320347, 45.59741428920201, 44.56185129710606, 45.70894677298409, 44.29277883257185, 45.646590164729524, 42.76191350391933, 43.689372948237825, 41.85106372833252, 43.93415798459734, 40.504343032836914, 38.782360553741455, 38.99764353888375, 43.57568652289254, 44.37208557128906, 49.12147460665022, 22.359158890587942, 0.85879284037011, 1.8037148990801402, 6.184045697961535, 7.273790742669787, 7.443704162325178, 6.861314407416752, 0.5555453896522522, 0.725423796900681, 1.8717739156314304, 37.13517195837838, 33.45187977382115, 27.800324474062236, 22.981194632393972, 22.601409571511404, 1.202666516814913, 0.07804338793669428, 0.02944829428036298, 0.04145156179687806, 0.011688732608620609, 0.03291259213749852, 0.0376807866351945, 0.009967027182158614, 0.08956237483237471, 0.02344378862263901, 0.04308558947273663, 0.05571109735007797, 0.03708780470437237, 0.05799067645732846, 0.04563267422573907, 0.07733542485428707, 0.04257496812247804, 0.009497381713507431, 0.0658721863957388, 0.06637317594140768, 0.06120046600699425, 0.019455381835411702, 0.042443674989044666, 0.04729832163346665, 0.025948739743658474, 0.02018934129072087, 0.046115353503929715, 0.02172876931061702, 0.04093688619988305, 0.03531367311786328, 0.041551465900348764, 0.061337964343173165, 0.03365547263196536, 0.07635549136570521, 0.01060431744969849, 0.05057739300121154, 0.051695269266409535, 0.030225328834993497, 0.023263245721214583, 0.06559737971318619, 0.010456968481386346, 0.02848449974719967, 0.010405137735818113, 0.07665083051792212, 0.06944060884416103, 0.07003047290657248, 22.032591819763184, 39.368079798562185, 28.882850340434484, 42.457460812159944, 33.547962938036235, 22.12985965183803, 0.0348660028539598, 0.6398205789072173, 1.20513117313385, 2.8226316358361925, 6.068345597812107, 5.681358294827597, 4.7771249413490295, 2.386334704501288, 1.484080284833908, 20.43992747579302, 54.19163070406233, 54.17760576520647, 52.232266494206016, 50.23411743981497, 42.677708285195486, 46.92398173468453, 52.45638063975743, 52.76616607393537, 50.512691565922324, 49.419732979365754, 48.426015513283865, 51.27597549983433, 47.921426909310476, 47.95054333550589, 44.69581256593977, 39.56919540677752, 38.73448746544974, 38.55283376148769, 38.40376363481794, 40.24491466794695, 40.570003509521484, 40.75148698261806, 37.69990416935512, 39.80828639439174, 37.720015730176655, 37.77287762505667, 37.54210710525513, 38.52757011141096, 39.17421463557652, 37.735802037375315, 36.92915787015642, 39.0917603628976, 37.10455124718802, 39.67910896028791, 48.394672189440044, 49.325501510075156, 50.16772392817906, 47.31595393589565, 47.56434161322457, 49.02208757400513, 46.66354240689959, 47.95736646652222, 47.87220587049212, 46.308527673993794, 46.38669490814209, 47.12715400968279, 49.479605606624055, 48.94607775551932, 47.26985263824463, 47.639027799878804, 49.62878690447126, 49.33436393737793, 43.59471416473389, 39.30462537493025, 42.64045204435076, 44.64050490515572, 45.157291071755544, 48.09043141773769, 48.846586499895366, 49.12218679700579, 48.23273747307913, 48.58678988048008, 41.88042334147862, 33.84376164845058, 35.438345432281494, 34.44107048852103, 36.16946962901524, 35.030166557856965, 35.55940389633179, 36.114353043692454, 35.33201367514474, 35.186636516026084, 34.451805455344065, 34.05252027511597, 39.313248089381624, 43.89410509381975, 45.88348204748971, 46.74388442720686, 47.013537066323416, 43.529977798461914, 42.81277779170445, 45.683276653289795, 46.44689410073416, 46.58696978432791, 47.11182975769043, 45.3860570362636, 45.43957553591047, 46.05543259211949, 47.47282688958304, 44.843354088919504, 44.41765185764858, 43.8582523890904, 44.4158661706107, 41.53897844042097, 41.051287855420796, 39.938561643872944, 45.78275401251656, 45.488146918160574, 50.201533862522666, 23.40113159588405, 0.5298664761441094, 2.4319489768573215, 5.6584444386618475, 9.974195531436376, 11.479099784578596, 9.23491849218096, 0.8395679348281452, 0.5028710961341858, 2.3506606987544467, 38.798577649252756, 41.99883106776646, 32.621816703251426, 26.246347699846538, 33.986258779253276, 2.818286406142371, 0.06113929607506309, 0.018492277711629868, 0.03906123559655888, 0.030922476069203446, 0.0383509994218392, 0.012579526103633856, 0.06281544720487935, 0.0773931478283235, 0.0527088886259922, 0.04589360486716032, 0.03597263918657388, 0.04104155361918466, 0.02324988367035985, 0.05137973691203764, 0.0877749982423016, 0.04902349691838026, 0.014975279735933458, 0.02369416125917009, 0.028566443028726747, 0.16211326606571674, 0.15857408169124806, 0.10925897756325346, 0.08885519885058914, 0.17368002182671002, 0.1839435560894864, 0.1376552948994296, 0.1479240403111492, 0.12074608009840761, 0.12182111026985304, 0.17439021728932858, 0.16747631185821124, 0.17491268925368786, 0.16200191846915654, 0.07411165069788694, 0.13519821103130067, 0.1862169469573668, 0.11885224814925875, 0.10671815568847315, 0.14563424246651785, 0.10594202697809253, 0.1532521822622844, 0.08905472207282271, 0.1433977231915508, 0.14607885932283743, 0.1587973739951849, 23.93198265348162, 48.88693816321236, 37.94257695334298, 47.78383520671299, 40.14834860392979, 25.74674790246146, 0.10299343948385545, 1.161325060895511, 3.07632144008364, 12.113142882074628, 10.83156154836927, 17.34309104510716, 9.363893560000829, 3.2608399731772284, 1.840608422245298, 20.39853879383632, 56.50332416806902, 56.69916261945452, 55.95661211013794, 53.724718706948416, 45.3047387940543, 50.56602941240583, 55.38338572638375, 54.5076938356672, 52.06084401266915, 51.478748253413606, 50.68282515662057, 53.17087779726301, 51.20111560821533, 49.26927668707711, 45.74904482705252, 42.3975499698094, 39.84653970173427, 39.45178474698748, 41.491442339760916, 43.54195301873343, 43.595773765019004, 43.76990256990705, 41.25887223652431, 43.083879130227224, 39.25368813105992, 39.10777596064976, 40.22969463893345, 40.44782291139875, 41.516858850206646, 39.718411445617676, 39.964912687029155, 39.78694152832031, 39.04396717888968, 41.63690635136196, 48.77320310047695, 51.261967931474956, 52.327012130192344, 49.40665994371687, 50.57413101196289, 51.74752541950771, 50.90176289422171, 49.84609876360212, 49.569584778376985, 48.78512620925903, 47.37325920377459, 49.63968515396118, 51.67995418821062, 51.764937605176655, 48.439720835004536, 49.14414657865252, 53.41973100389753, 51.3272636277335, 44.3782069342477, 42.210205691201345, 45.0008419581822, 46.182240690503804, 49.21758556365967, 50.15613085883004, 50.32803276606968, 51.724617208753315, 50.33345930916922, 52.32564333506993, 43.292523111615864, 36.4087621143886, 37.89941126959664, 35.79628535679409, 37.5506568636213, 35.783264432634624, 37.19197000776018, 37.72617530822754, 37.02262156350272, 37.80476985658918, 36.131813866751536, 35.57447453907558, 40.55082300731114, 45.8139340536935, 46.94817188807896, 47.50917291641235, 48.39258425576346, 45.680448736463276, 44.20667675563267, 47.7681496483939, 47.74254901068551, 48.15861061641148, 49.39562273025513, 49.34045055934361, 47.128838947841096, 48.230861459459575, 49.23911108289446, 46.72570446559361, 46.559076241084504, 45.86952311652047, 48.03871944972447, 44.525557381766184, 41.559479100363596, 42.53007296153477, 46.24229744502476, 47.83187157767159, 50.3031964302063, 25.351317235401698, 1.4053670742682047, 3.5849106865269795, 15.502014705113002, 13.184212906020027, 15.76173142024449, 16.765805176326207, 4.4657957042966565, 2.463326390300478, 2.803662185158048, 47.61864525931222, 44.05192995071411, 38.18917546953474, 33.21485587528774, 42.47911139896938, 2.873588421515056, 0.23072983484183038, 0.1952351794711181, 0.07065562078995363, 0.08485163189470768, 0.16082418523728848, 0.12873517854937486, 0.14078757539391518, 0.20644148385950498, 0.10460553012256112, 0.13059606083801814, 0.11399350315332413, 0.1168200493391071, 0.08599771146795579, 0.0842307112844927, 0.1978477428534201, 0.10893755552491971, 0.10896650861416544, 0.17561934276350907, 0.13868334330618382], [0.041493532580456564, 0.014301189121657183, 0.03350885817781091, 0.03279915465308087, 0.07823794428259134, 0.11656327811735016, 0.02080998200524066, 0.020945095290829028, 0.030626834968903234, 0.04439504670777491, 0.022281800795878683, 0.054555484359817843, 0.0538512566126883, 0.058781922927924564, 0.020285918876262646, 0.04646981680499656, 0.04846848580720169, 0.016802681410419087, 0.04091649961524776, 0.02756227905462895, 0.03269736082958324, 0.05283026836280312, 0.027832955155255537, 0.049989829172513316, 0.07688090817204543, 0.03788579920572894, 0.6041877738067082, 28.49372168949672, 26.390083347048076, 25.3623457636152, 36.31099401201521, 25.542967660086497, 2.0633192488125394, 0.7330957480839321, 1.2456047556229999, 2.2147224502904073, 2.0232313999107907, 5.368359753063746, 1.5394796835524696, 2.7650458344391415, 0.09807442700756447, 3.9489291991506303, 38.64518574305943, 53.76272535324097, 50.8810989516122, 48.28817367553711, 46.39724227360317, 49.0722952570234, 51.15396513257708, 49.82310717446463, 47.86497974395752, 49.740864821842735, 49.75796086447579, 47.701241970062256, 49.71717841284615, 43.54219967978341, 37.229445116860525, 37.59796019962856, 37.080708503723145, 40.97682401112148, 41.542730467660085, 41.264594078063965, 40.89620058877127, 38.41804565702166, 37.07022367204939, 38.07441554750715, 37.608545780181885, 35.76193346296038, 36.83401271275112, 36.54564510072981, 36.184053897857666, 35.87824630737305, 36.65757015773228, 35.01904944011143, 35.48848363331386, 37.015555245535715, 48.10684653690883, 48.98346601213728, 49.93021018164498, 45.34048727580479, 47.03725126811436, 47.89056995936802, 48.642198290143696, 48.17790923799787, 48.383989334106445, 45.616494042532786, 47.10476343972342, 47.361381258283345, 47.792325905391145, 48.91017641339983, 44.881065436771934, 49.587816851479666, 47.42098637989589, 43.18255744661604, 40.16736234937395, 41.92314781461443, 42.462633746010916, 46.867760385785786, 49.74955007008144, 45.37316117967878, 46.27592672620501, 47.83513723100935, 47.707352910723, 45.343287399836946, 37.82762942995344, 32.545198917388916, 35.60039826801845, 33.852071693965364, 33.25205305644444, 32.84838703700474, 34.25278125490461, 33.29559394291469, 34.34696756090437, 34.28180388041905, 32.39392968586513, 32.68804693222046, 38.231399672372, 43.929290771484375, 44.72671120507376, 46.38966873713902, 45.04517493929182, 44.5854925428118, 45.643376622881206, 45.58118329729353, 43.881028584071565, 44.335075991494314, 45.64850786754063, 43.42521980830601, 45.78023876462664, 43.44705104827881, 44.04567657198225, 42.76365750176566, 45.288021428244456, 42.6981394631522, 43.94850254058838, 40.92125926698957, 40.5420161655971, 39.60728195735386, 45.18324954169137, 44.461877141680034, 44.43485907145909, 7.814996787479945, 0.19848722139639513, 1.188286459871701, 6.658611570085798, 7.8986652578626355, 16.6019058568137, 10.657834001949855, 1.0340418794325419, 0.11661107412406377, 7.700822251183646, 36.79099294117519, 24.184535775865825, 15.311232805252075, 33.58543457303728, 4.926344020026071, 0.10809813985334975, 0.03544477626149144, 0.028387213092563406, 0.01923239147955818, 0.0486595544831029, 0.045008123453174315, 0.02107988457594599, 0.031878860999963114, 0.009565841656045189, 0.027443411593724574, 0.004709570344337928, 0.02710576239041984, 0.016657822665625384, 0.04019463674298354, 0.027098520725433315, 0.020264923306448118, 0.026373010727443864, 0.024333575341318334, 0.030483192498130456, 0.04092405510268041, 0.09062965613390718, 0.045001819862851074, 0.06162900158337184, 0.03874938090198806, 0.04018560204921024, 0.16085075666861876, 0.020086538146382997, 0.05451074515336326, 0.08227420984102146, 0.06427835513438497, 0.047608520702591965, 0.01675742651735033, 0.025053146461557065, 0.021939468004607728, 0.11257911047765187, 0.08551147327359233, 0.028643439789967876, 0.017985537581677948, 0.04106772471485393, 0.034321682062000036, 0.009252035325126988, 0.008847313783397632, 0.031875325832515955, 0.025831449876672456, 0.02982100678075637, 0.030714403305734907, 1.7281664844070161, 37.74270159857613, 27.426759787968226, 32.91022947856358, 42.31763178961617, 29.44908857345581, 1.6344759975160872, 0.7180429100990295, 0.2123189949031387, 2.8567251435347965, 4.903569996356964, 5.407788608755384, 4.538095184734889, 3.0867183336189816, 0.7549199312925339, 5.015736937522888, 42.40729481833321, 56.02093505859375, 52.64764370237078, 49.29399490356445, 48.00953701564244, 50.03991528919765, 52.94167409624372, 51.54337344850813, 49.93318053654262, 49.75743627548218, 52.4787712097168, 49.626747608184814, 51.540062631879536, 46.79374122619629, 39.1870653288705, 39.585957935878206, 39.433997358594624, 42.346070766448975, 44.08913060597011, 43.68277563367571, 43.46921927588326, 40.260489055088584, 38.18047979899815, 40.28040606634957, 38.385337012154714, 38.14932755061558, 38.12578010559082, 37.49611350468227, 39.59397963115147, 37.62473160879952, 36.80858925410679, 36.86100993837629, 37.24467209407261, 38.626943247658865, 50.1362555367606, 51.75204522269112, 51.765826974596294, 47.81183992113386, 50.28509289877755, 50.2742154938834, 50.97706747055054, 49.28713355745588, 49.82621649333409, 48.732167039598735, 49.95367772238595, 48.35857629776001, 49.0358623777117, 50.03584017072405, 46.33078622817993, 50.53337287902832, 49.13241801943098, 45.193307059151785, 41.88271277291434, 44.0201210975647, 44.297621726989746, 47.40436281476702, 50.87216009412493, 47.34456314359392, 48.991650990077424, 49.22575664520264, 50.034196921757285, 46.60870027542114, 39.27127749579293, 35.01427255358015, 37.313163961683, 36.344373158046174, 35.36908578872681, 34.246573039463584, 35.77903297969273, 34.52825648444039, 35.75568355832781, 35.155647550310405, 34.430314677102224, 34.25746781485421, 39.15482916150774, 45.37624965395246, 46.21947261265346, 46.209477628980366, 46.125748361860005, 45.11463955470494, 46.267519405909944, 46.6846684047154, 45.3669216973441, 46.49443367549351, 47.620684555598665, 44.71433646338326, 45.977560656411306, 46.642009939466206, 46.50285141808646, 44.83475916726248, 47.23400688171387, 44.67854281834194, 45.03034053530012, 42.694738319941926, 41.6040483202253, 40.49218021120344, 45.85486936569214, 44.45650271006993, 44.87157072339739, 9.322584782327924, 0.2691494918295315, 3.735732844897679, 6.548334104674203, 8.809414284569876, 8.596245288848877, 6.443633871419089, 0.42745306875024525, 0.5357890554836818, 8.843746202332632, 41.31676115308489, 34.40504060472761, 17.71531994002206, 36.67475305284773, 9.18598927770342, 0.1352539323270321, 0.009347401725660478, 0.05738870054483414, 0.03957657955054726, 0.019839344446414282, 0.07938277535140514, 0.04595352290198207, 0.033485954228256426, 0.029357530043593476, 0.02232748655868428, 0.027630227551396404, 0.03721770005566733, 0.04384209155770285, 0.061324488637702804, 0.027832244389823506, 0.0668912170720952, 0.03982144248272691, 0.025465488799714615, 0.010535324857171093, 0.055332169468913756, 0.2153889180294105, 0.08929843149547066, 0.17711049132049084, 0.10212323867848941, 0.15131006576120853, 0.2947075718215534, 0.12561712014888013, 0.16467284943376267, 0.16327772715262004, 0.2213599176279136, 0.08527186220245701, 0.13829143505011285, 0.1352429807718311, 0.17770994986806596, 0.23519481239574297, 0.15765706875494548, 0.12049177874411855, 0.05190282973593899, 0.1572684988911663, 0.20091330978487218, 0.16909065523317882, 0.14658033741371973, 0.06855461174356085, 0.14349241953875336, 0.16164608113467693, 0.1474011612257787, 1.7836907335690089, 42.40776382173811, 34.32133565630232, 34.28289474759783, 46.708688327244346, 36.708278111049104, 2.716312906571797, 2.049845823219844, 4.533753429140363, 6.2472929784229825, 10.270786336490087, 13.781130041394915, 7.422448754310608, 5.8771168419293, 0.7550555297306606, 4.8943123902593335, 42.572825227464946, 57.51570796966553, 53.72605970927647, 50.577400139399934, 49.79610300064087, 53.20090791157314, 56.2089706829616, 52.55546889986311, 49.700478417532786, 52.22186851501465, 54.36904600688389, 51.91175651550293, 54.67638914925711, 47.31118399756295, 42.19656637736729, 42.20638418197632, 42.00527899605887, 47.11969511849539, 46.544311319078716, 45.19689927782331, 46.02289070401873, 42.00123861857823, 40.830029419490266, 43.05603769847325, 40.31617539269583, 40.180133138384136, 40.08762829644339, 40.139760630471365, 40.54702581678118, 39.60222019468035, 39.1478670665196, 37.89797994068691, 39.36920540673392, 41.06913777760097, 51.76862709862845, 53.62240648269653, 53.27689688546317, 49.75299637658255, 49.90727070399693, 52.277356828962056, 53.20434379577637, 51.42692511422293, 52.00282308033535, 50.20879473005022, 51.70523868288313, 51.518057686941965, 51.674520696912495, 51.04974215371268, 46.80927045004708, 52.91750478744507, 52.291145529065815, 47.457130908966064, 43.786831855773926, 48.33210366112845, 46.816472257886616, 50.59671613148281, 53.16259554454258, 48.93777118410383, 49.797794886997764, 50.71260166168213, 52.161651951926096, 49.285309655325754, 41.42738689695086, 37.37656627382551, 40.18873153414045, 37.70316287449428, 36.66380616596767, 36.156851700374055, 36.6321154321943, 35.80906309400286, 37.57707044056484, 37.206248555864605, 36.41935464314052, 35.82977219990322, 41.335382325308665, 47.43735980987549, 47.55711896078927, 48.10252823148455, 46.49550717217581, 46.380917481013704, 48.32967526572091, 48.349585328783306, 46.83807420730591, 47.21010160446167, 49.961668150765554, 46.422380856105256, 48.79758780343192, 46.81200456619263, 48.986335618155344, 46.34279618944441, 48.920563970293315, 45.69222245897566, 47.85071856634957, 44.132942472185405, 44.086406912122456, 41.916359424591064, 47.8257988521031, 46.08403485161917, 45.54842254093715, 9.177311846188136, 0.8604432003838676, 5.130635389259883, 14.726642642702375, 16.109777109963552, 26.674077068056377, 22.174864871161326, 2.673013470002583, 1.1849480675799506, 10.808055792536054, 47.1057778767177, 32.36598750523159, 23.2167090347835, 47.11655453273228, 12.438510520117623, 0.29599165863224436, 0.1577744417424713, 0.19281171022781304, 0.08789007099611418, 0.1743210338588272, 0.1858665786151375, 0.10711385016994816, 0.16024205647408962, 0.07433117713247027, 0.13224187466715062, 0.09557286516896316, 0.13153091924531118, 0.12009978906384536, 0.15324401270065988, 0.16483621352485248, 0.15191822312772274, 0.12139209971896239, 0.10084434266069106, 0.0732017420232296, 0.15535541011818818], [0.05095705709287098, 0.04606163388650332, 0.04865776654332876, 0.029683277742671113, 0.03935606245483671, 0.04543223498123033, 0.03673719208953636, 0.04477648177583303, 0.02376306988298893, 0.03865288643698607, 0.031850237000201426, 0.08760637550481729, 0.04258597735315561, 0.021596436322267567, 0.028721386500235115, 0.035430516848074536, 0.09800696027066026, 0.02891953568905592, 0.03294451381745083, 0.0350781095081142, 0.037026329431682825, 0.03141397630263652, 0.04292842379904219, 0.04250519097383533, 0.05260347142549498, 0.03333123128062912, 0.024008882764194692, 6.144579495702471, 36.64001553399222, 20.108533143997192, 32.65981640134539, 32.85499824796404, 7.210701099463871, 0.22835091820784978, 0.040887946861663034, 1.8096473578895842, 4.76889089175633, 2.532824661050524, 2.356946212904794, 3.24974348289626, 0.7152303553053311, 0.8086928001471928, 26.456049544470652, 57.656818934849326, 52.20400817053658, 50.70948192051479, 48.48689910343715, 50.045327935900005, 52.311142444610596, 51.286529813494, 52.88776649747576, 50.01151105335781, 49.421852179935996, 49.1164093698774, 42.550521509987966, 37.50103977748326, 36.66913890838623, 39.73688670567104, 40.22364970615932, 43.32187925066267, 43.07514871869768, 43.31003952026367, 41.1822509765625, 38.26543194907052, 37.621132441929404, 37.421152864183696, 36.48328501837594, 38.18051106589181, 37.43839829308646, 35.67673117773873, 36.23776347296578, 37.03038270132882, 36.145223890032085, 36.59277820587158, 35.43029247011457, 34.44301945822579, 41.84184346880232, 48.9986686706543, 49.777697222573416, 47.290078844342915, 46.6161105292184, 44.67025709152222, 46.53311777114868, 45.42457437515259, 47.8940440586635, 49.03954839706421, 49.19587591716221, 47.58160441262381, 48.8116683278765, 47.71278640202114, 43.291029248918804, 49.07447004318237, 47.84852293559483, 43.87866619655064, 44.16250010899135, 46.519666058676584, 47.49432461602347, 48.493218490055625, 47.76887573514666, 47.231679235185894, 47.938258920397075, 46.861833572387695, 47.61490018027169, 44.69358914239066, 36.59432070595877, 32.96892091206142, 34.563480377197266, 34.290454387664795, 34.05962133407593, 33.63565615245274, 34.47441489355904, 34.70743662970406, 34.00411912373134, 33.2503924369812, 35.1059262411935, 33.67424297332764, 35.99629272733416, 44.631743226732524, 45.21476657049996, 44.64887053625924, 43.8664790562221, 45.317151750837056, 45.75405100413731, 44.472844873155864, 42.46804986681257, 42.52614375523159, 41.76702874047415, 43.44581774302891, 42.582764625549316, 43.7884646824428, 42.83096470151629, 41.97233411243984, 41.51646627698626, 42.64470434188843, 40.385216167994905, 40.801079750061035, 39.13957439150129, 44.04099696023123, 43.82563407080514, 46.95877136502947, 26.793269940785, 0.40418300884110586, 0.10978165987346854, 2.942912987300328, 3.4858374084745134, 5.638178280421665, 5.513868927955627, 3.462389192410878, 0.08555917428540331, 0.1615930875497205, 11.63579990182604, 38.771229539598735, 22.0875711781638, 27.842890875680105, 27.42826407296317, 0.5193254074880055, 0.1023643221706152, 0.035811439622193575, 0.13263465144804545, 0.028179233627659932, 0.035252889950892756, 0.017403364713702883, 0.05901724565774202, 0.021676450868004134, 0.04928336565249732, 0.0527929251880518, 0.03642663339685116, 0.044536623039415905, 0.038636170726801665, 0.02016780628556652, 0.02795276408349829, 0.041950183255331855, 0.0021890746221678065, 0.06223385448434523, 0.05823118319468839, 0.02901258658883827, 0.017616933610822474, 0.058555285446345806, 0.036932678028408966, 0.02964179211163095, 0.07325389422476292, 0.028345400068376745, 0.043024931834744554, 0.02851693711376616, 0.052981449357633076, 0.08631284348666668, 0.06295334587671927, 0.024002063487257277, 0.09521022891359669, 0.041277592203446796, 0.09578585731131689, 0.027844140805037956, 0.04437311984864729, 0.06680379462029253, 0.03605526100311961, 0.057120373871709616, 0.037320613461945734, 0.02426587281349514, 0.04678522702306509, 0.032396895345300436, 0.0747827896848321, 0.0509145265179021, 0.01594440416166825, 12.00557347706386, 41.80075182233538, 22.672234296798706, 40.91315419333321, 38.00990152359009, 8.013810804912023, 0.15400484044636997, 0.10520352303449597, 2.0279058005128587, 2.1443035432270596, 4.197629979678562, 4.9715055738176614, 4.402287432125636, 0.8100137721214975, 1.0185485907963343, 29.96506874901908, 57.50258977072579, 54.644733156476704, 51.61638164520264, 50.65692227227347, 50.74193695613316, 53.81056022644043, 50.97948891775948, 54.388292516980854, 51.439859185900005, 50.95231103897095, 50.29090159279959, 47.72440379006522, 39.398617131369456, 38.7487382207598, 38.870786803109304, 42.41773101261684, 43.17568220411028, 45.81075872693743, 44.8454316002982, 43.18420416968209, 40.19363348824637, 39.61388622011457, 39.25181211744036, 39.40723637172154, 39.42675038746425, 39.22676386151995, 37.68520178113665, 37.923368658338276, 38.360948835100444, 37.57177938733782, 38.16197327205113, 37.92777034214565, 35.76880175726754, 43.55825349262783, 51.740316663469585, 50.32148061479841, 47.97810683931623, 47.900245325905935, 47.09673827035086, 48.437584263937815, 47.32073082242693, 48.15235028948103, 50.3261011668614, 49.63166693278721, 49.74639211382185, 50.979544503348215, 49.16461249760219, 44.352123396737234, 51.57613073076521, 49.5467460496085, 45.7095616885594, 45.839885575430735, 46.619935512542725, 49.15683398927961, 49.15786232267107, 47.662328583853586, 50.42116641998291, 49.07301092147827, 47.16186720984322, 48.412285872868125, 45.73110805238996, 37.89319610595703, 34.94721548897879, 35.519330160958425, 35.75528403690883, 35.195102896009175, 35.231108461107524, 36.93282651901245, 36.817055634089876, 35.23784473964146, 35.744111333574565, 36.01932947976248, 34.94638170514788, 36.696917806352886, 46.08269732339041, 48.622038091932026, 47.50846767425537, 45.49141951969692, 46.19013384410313, 47.88597025190081, 45.8131662777492, 44.53537866047451, 45.00912421090262, 44.05274983814785, 44.5645124571664, 45.83331257956368, 44.67214352743966, 44.3175630569458, 44.755518436431885, 44.204255308423726, 43.89584561756679, 43.41014569146292, 42.633083479745046, 41.79038858413696, 45.956003870282856, 45.59748029708862, 48.53162465776716, 28.381259884153092, 0.6336389077561242, 2.274744898080826, 7.216871968337467, 8.887843813214984, 6.736615087304797, 6.434870455946241, 1.2246400862932205, 0.21074486151337624, 0.16711934815560067, 13.113376889910016, 45.792585713522776, 21.650560753686086, 23.20767985071455, 36.952173777988975, 1.0627940680299486, 0.11695095231490475, 0.028715473067547594, 0.04582178872078657, 0.04509529823969517, 0.050649656980697594, 0.04977387183212808, 0.042556291446089745, 0.026731764066166112, 0.034858097920992544, 0.03457447706854769, 0.012188432937754052, 0.011182469997688063, 0.05333699831472976, 0.0795449995036636, 0.014847623550200036, 0.04332287995410817, 0.030527019074984958, 0.03139008508462991, 0.04510311835578509, 0.00742214173078537, 0.09876001879040684, 0.1221111568489245, 0.1316793691366911, 0.19103793826486382, 0.2488988313291754, 0.11758292626057353, 0.08031941830579724, 0.10496772533016545, 0.13734265310423716, 0.18927415433738912, 0.10553890253816332, 0.14988728639270577, 0.2221239616296121, 0.14451313976730618, 0.23272939611758503, 0.13069454341062478, 0.17844799240784986, 0.146874088793993, 0.13509225100278854, 0.16351267668817723, 0.12076157783823353, 0.1476985088416508, 0.12785738493715013, 0.1550062767096928, 0.11234852392226458, 0.18308592853801592, 0.0896527896236096, 13.114142060279846, 48.94972555977957, 29.315672738211497, 40.7450772694179, 43.62946905408587, 11.297356622559683, 0.3895279552255358, 0.6995541336280959, 3.9072356649807523, 12.727064864976064, 7.900356275694711, 8.06420087814331, 8.459681919642858, 2.0162782073020935, 1.2540806893791472, 30.13003635406494, 59.37113407679966, 57.12120315006801, 54.132366044180735, 51.98021364212036, 52.98968614850725, 55.985377652304514, 53.31309005192348, 57.22068050929478, 53.29222113745553, 54.425764151981895, 53.45527798788888, 47.31991440909249, 41.878561224256245, 41.29299136570522, 43.2350823538644, 44.05108227048601, 46.63849415097918, 47.05396515982491, 48.777299063546316, 45.72926677976336, 42.86603920800345, 40.631220613207134, 41.046114921569824, 40.25015013558524, 42.59275266102382, 40.723791463034495, 39.4758220400129, 39.41375725609915, 40.55697216306414, 39.966934612819124, 40.79058102199009, 39.75492422921317, 37.44665275301252, 45.48632649012974, 52.653007711683, 53.81279059818813, 50.12651763643537, 49.07865980693272, 48.97397824696132, 50.36084563391549, 47.22259793962751, 49.27403620311192, 52.22853878566197, 52.911755153111045, 49.724640778132844, 53.26224660873413, 50.79940550667899, 44.73767893654959, 53.24179458618164, 51.84610646111624, 47.68094628197806, 49.5481287411281, 50.34667130878994, 51.64770759854998, 50.011670861925396, 50.28639221191406, 50.604254926954, 49.99784047263009, 49.24533666883196, 50.1905973979405, 48.52091748373849, 40.82555477959769, 37.0473050389971, 36.51914814540318, 37.29945516586304, 36.33648347854614, 36.912909507751465, 38.28316027777535, 37.801306179591585, 37.21948834827968, 36.525078432900564, 38.87100567136492, 36.75142642429897, 37.96076386315482, 47.22093732016427, 50.162141050611226, 49.16417128699166, 46.44933639253889, 48.801256452287944, 49.1998850277492, 47.480094705309185, 46.26433365685599, 46.34892450060163, 46.57420594351632, 46.85824482781546, 47.663304805755615, 47.01520115988595, 46.308819498334614, 45.02029691423689, 45.736458165305, 45.04116930280413, 44.703903743198936, 44.80963448115757, 44.11460270200457, 47.883145809173584, 47.29010316303798, 49.22442953927176, 28.253256695611135, 1.2594210313899177, 1.470113754272461, 7.42407636983054, 13.349888358797346, 13.10548026221139, 14.052355578967504, 8.090634431157794, 0.9563992342778614, 0.35015137387173517, 18.78489783832005, 48.41760471888951, 30.023117474147252, 35.790494033268516, 41.27445704596383, 1.395039011325155, 0.27267901386533466, 0.08584782308233635, 0.265290446047272, 0.09499768460435526, 0.1603378520480224, 0.16651309068713868, 0.15367944219282695, 0.09394844554896865, 0.18066893251878874, 0.13802606000431947, 0.1312645806797913, 0.13696208995367798, 0.15680869642112935, 0.13452651564564022, 0.07371208178145544, 0.11502385857914176, 0.12118260881730489, 0.13432941479342325, 0.15929370879062585, 0.08631338631468159], [0.037455034641815085, 0.03925547642367227, 0.06304625089147262, 0.034942768913294585, 0.017363356592665826, 0.05509754563016551, 0.05045884954077857, 0.04148972599900194, 0.03438456529485328, 0.004463596311065235, 0.011795288899780383, 0.019090377492830157, 0.06287231522479228, 0.0309392664182399, 0.030812566966882775, 0.024821849140737737, 0.022331869894904748, 0.05187362219606127, 0.05740702099033764, 0.04706291747944696, 0.009438065878514732, 0.03947362543216773, 0.03108506663037198, 0.01515348847689373, 0.09068068196730954, 0.00987265822810254, 0.07737019977399281, 0.10681722180119582, 23.736467293330602, 30.626436505998882, 21.9800478049687, 37.14018508366176, 14.102449485233851, 0.3241307501282011, 0.15102594957820006, 1.231630734034947, 1.9857098247323717, 2.191818799291338, 4.3441627110753736, 2.7473370475428442, 1.5069953352212906, 0.19960361506257737, 16.403036253792898, 52.865834508623394, 52.86956569126674, 53.53013440540859, 51.32301480429513, 52.57803317478725, 51.45797661372593, 52.17723676136562, 50.511784826006206, 49.00386592320034, 48.41128880637032, 41.57341023853847, 36.6919845853533, 37.580839838300435, 40.41218907492501, 43.304630347660606, 43.994006293160574, 43.86241783414568, 44.70865978513445, 41.335132190159385, 38.35935422352382, 36.557794025966096, 37.98148339135306, 42.88596316746303, 43.89398002624512, 37.892067023685996, 36.64131137302944, 36.42231110164097, 36.11364780153547, 37.147473743983674, 34.20810433796474, 35.533719880240305, 35.05376958847046, 35.777657236371724, 36.9858968598502, 43.36645541872297, 47.76285164696829, 47.812433992113384, 47.67018352236067, 46.644966397966655, 46.627925940922324, 47.03499657767159, 46.9220084462847, 46.19695350102016, 46.30596031461443, 48.83136647088187, 46.95706558227539, 43.26116936547415, 45.193314007350374, 49.70452921731131, 47.57113347734724, 47.00484834398542, 44.758631229400635, 48.45497907911028, 46.11799417223249, 60.508387429373606, 49.46217952455793, 44.283968516758506, 47.98992919921875, 46.370432649339946, 47.16685601643154, 40.73985569817679, 34.07138810838972, 33.19556072780064, 34.79532091958182, 34.12494134902954, 33.61123670850481, 33.70338371821812, 35.32473891122, 34.566009521484375, 33.41225419725691, 33.811942373003276, 33.64487293788365, 32.77302687508719, 35.01468249729702, 43.04829045704433, 43.89856931141445, 45.56463616234915, 44.29513774599348, 46.95535979952131, 44.89167881011963, 43.142490659441265, 42.056056431361604, 38.837223529815674, 37.232418945857454, 36.72061811174665, 36.89568492344448, 37.335040364946636, 36.97132648740496, 38.132679666791645, 38.07010071618216, 39.068591594696045, 38.06035239355904, 40.71592262813023, 40.05720213481358, 45.16163716997419, 43.34083046231951, 42.35231024878365, 3.348830440214702, 0.10138936234372002, 1.1153587102890015, 6.394533123288836, 2.3205050826072693, 4.144663427557264, 4.3726416400500705, 1.4925488361290522, 0.05452122173405119, 0.2570087904376643, 20.25706478527614, 36.87941224234444, 18.916894504002162, 33.05345964431763, 13.084844980921064, 0.11659426002630166, 0.036660575307905674, 0.057302994786628654, 0.035369509764547856, 0.05581416681941066, 0.05492030210526926, 0.06205493837062802, 0.07106342712151152, 0.04381949634158185, 0.04667711264586874, 0.08382108647908483, 0.0174111118872783, 0.04132691491395235, 0.04824520707396524, 0.025132372210334455, 0.0320203389440264, 0.06565466842481069, 0.061285466088780334, 0.03180120945242899, 0.05234470870345831, 0.06557077435510499, 0.04433086747303605, 0.025545849398310696, 0.07406975794583559, 0.03489579054127846, 0.05943003922168698, 0.1118210782962186, 0.032120972472642145, 0.023811407021379898, 0.02285889143656407, 0.025596162769943476, 0.031970398766653876, 0.012016118969768286, 0.03185148550463574, 0.05351815020133342, 0.01811005893562521, 0.10601509841425077, 0.021701208914497068, 0.03202971290530903, 0.06007695450846638, 0.08095177223107644, 0.05577622992651803, 0.025252060698611394, 0.01526184203768415, 0.08078239631972142, 0.0477652860406254, 0.05028354662603565, 0.06957208857472454, 0.20213627416108335, 32.730781827654155, 29.903931549617223, 26.414419412612915, 46.59313631057739, 15.300067050116402, 0.29968641751578873, 0.15909419235374245, 0.6457319759896823, 1.726812019944191, 3.689141264983586, 4.382891970021384, 5.982329070568085, 2.9805309687341963, 0.48746845977646963, 19.068624053682598, 55.668241024017334, 53.353858607155935, 55.175374031066895, 52.98771980830601, 54.58711174556187, 51.42300633021763, 53.405018193381174, 51.571548393794465, 51.636882305145264, 49.72193792888096, 43.604761259896414, 38.2060352734157, 39.71496513911656, 42.133448941367014, 44.04530831745693, 43.83106408800398, 46.11405801773071, 46.00725030899048, 44.14357321602957, 40.50641707011631, 37.37103203364781, 39.786291871752056, 43.21342829295567, 44.05850294658116, 39.80059821265084, 38.801937103271484, 37.64406844547817, 38.25917509623936, 38.5831800188337, 35.71916035243443, 36.436659131731304, 35.44229548318045, 38.13065079280308, 39.37850209644863, 46.67929744720459, 50.085641384124756, 48.99823440824236, 50.743510723114014, 49.14687027250017, 47.68813419342041, 48.23919929776873, 46.32751710074288, 47.668644496372764, 49.17103958129883, 50.257744789123535, 47.71915790012905, 45.09487540381295, 46.68390757696969, 50.86086927141462, 49.35633414132254, 48.082194328308105, 46.3611672265189, 49.979677881513325, 46.64425073351179, 54.27091659818377, 51.841211455208914, 45.991863523210796, 49.60123034885952, 48.16011142730713, 48.882609435490195, 41.282027108328684, 36.108249051230295, 34.16602952139718, 35.35668672834124, 35.17456749507359, 35.30034031186785, 35.183301380702424, 35.558896677834646, 36.42869649614607, 35.05746603012085, 35.082646301814485, 35.077796459198, 35.338847228458945, 37.560627528599326, 43.71987901415144, 46.17351722717285, 46.99706983566284, 44.64098085675921, 47.97947563443865, 46.155458859034944, 44.53056355885097, 43.32096903664725, 39.9946996143886, 39.27700628553118, 38.97331442151751, 38.45445074353899, 39.594910689762656, 39.13816043308803, 38.821402481624055, 40.61685173852103, 40.67395898274013, 40.09533732278006, 42.374950953892295, 42.240965366363525, 46.563974721091135, 45.73059041159493, 44.133095332554404, 6.503387076514108, 1.189106130174228, 5.1400202342442105, 10.79367823260171, 5.67052127633776, 5.11185701404299, 4.035760402679443, 0.11987026780843735, 0.11595375011009829, 0.3919646830431053, 20.585066659109934, 45.440485749925884, 18.590197154453822, 34.99935129710606, 18.456475598471506, 0.09978996030986309, 0.030817527057869092, 0.09612424951046705, 0.02404647190789027, 0.057320114225149155, 0.07046174976442542, 0.03732898997675095, 0.048248185842697106, 0.01815460984861212, 0.0442069432299052, 0.08048116069819246, 0.030101136570530276, 0.03334644064307213, 0.022876114351674914, 0.0499856663601739, 0.05989545317632811, 0.04322287067770958, 0.025476528564468026, 0.009069652745633252, 0.03364976275978344, 0.033293416524039846, 0.19403717161289283, 0.14356411354882376, 0.15211689818118299, 0.11095549831432955, 0.20925023885709898, 0.18023331303681644, 0.1175916250795126, 0.10425129413072552, 0.23222092911601067, 0.13082634205264704, 0.12779698174979004, 0.09739820579332964, 0.14501598849892616, 0.16403874488813536, 0.0991541797827397, 0.24524030621562684, 0.08479797334543296, 0.1356770396232605, 0.167612493836454, 0.1791990628199918, 0.09656288847327232, 0.08562038492943559, 0.12928530760109425, 0.16068936032908304, 0.16028104509626115, 0.10505815369210073, 0.15086297903742107, 0.5955678820610046, 35.72127955300467, 40.79758480616978, 32.01080254146031, 47.50104352406093, 23.086534534181865, 0.7852668943149703, 0.6076511793902942, 5.192461763109479, 5.596428292138236, 10.512606229100909, 11.425428424562726, 8.530987807682582, 4.8064398254667005, 0.4798270155276571, 19.899786676679337, 56.751913343157085, 56.38329751150948, 58.33034256526402, 55.70511163984026, 54.82922172546387, 53.32151126861572, 54.95735345567976, 55.06872613089425, 54.997934409550254, 53.11525746754238, 44.41579321452549, 40.50977652413504, 42.87194865090506, 46.51070635659354, 48.41410977499825, 46.32216698782784, 48.021550451006206, 49.72642299107143, 46.370533398219514, 41.910040037972585, 39.078812394823345, 43.80665506635393, 46.187232971191406, 47.29476540429251, 42.431651728493826, 41.19520589283535, 38.88355411802019, 40.25043501172747, 42.030622550419395, 38.331665652138845, 38.5233108656747, 37.17832721982683, 39.15783773149763, 41.96558741160801, 47.67133692332676, 52.696090017046245, 51.52884129115513, 51.518432889665874, 50.73927232197353, 49.21291984830584, 49.22466230392456, 46.867760385785786, 47.679921422685894, 48.75660037994385, 50.17335196903774, 48.93321663992745, 44.73687989371163, 46.841749804360525, 52.65796872547695, 50.94937195096697, 48.83076197760445, 48.49160998208182, 52.48818254470825, 49.892724650246755, 56.32027040209089, 51.91536610467093, 46.29969303948538, 50.91175440379551, 49.691841806684224, 50.39767108644758, 43.707108225141255, 37.84077542168753, 35.6314879826137, 37.33669056211199, 36.77716950007847, 37.96301507949829, 36.73415667670113, 38.59450210843767, 37.48629570007324, 36.84004027502877, 37.085440226963584, 36.91836731774466, 36.74148007801601, 38.834600584847585, 45.88230432782854, 48.271174907684326, 48.19285828726632, 46.17586571829659, 48.48836864743914, 48.165621348789756, 45.36564670290266, 45.875001771109446, 42.018748079027446, 41.26772076742989, 40.23154980795724, 40.06487989425659, 41.96878358295986, 39.89323854446411, 40.965609618595664, 42.245408739362446, 42.743118626730784, 41.41639484677996, 44.36665207999093, 43.15300675800869, 49.71912390845162, 47.25023439952305, 46.34605836868286, 5.872884086200169, 0.9486617637532098, 4.73109746830804, 16.13014575413295, 9.178610290799822, 11.451896718570165, 12.225234695843287, 3.1512729610715593, 0.16849106097859995, 0.5417913219758442, 28.40758660861424, 47.613121441432405, 27.364307641983032, 44.16014119556972, 22.260169642312185, 0.2207249038453613, 0.12929661199450493, 0.18466836719640664, 0.09242915135941335, 0.18454595947904245, 0.1877190334988492, 0.15561500404562267, 0.1681844581450735, 0.09682347984718424, 0.13945002002375467, 0.15457133576273918, 0.20254100672900677, 0.11106330395809241, 0.12328913435339928, 0.13117702252098493, 0.17976074053772859, 0.14755847278450215, 0.15064046026340552, 0.09679100516119174, 0.1934382558933326, 0.21271251807255404], [0.010638112734471048, 0.017369102087936232, 0.06196383147367409, 0.04862816206046513, 0.025979392563125918, 0.0455800979398191, 0.07489993197045156, 0.0048367816655497465, 0.06463092193007469, 0.08074605398412261, 0.013863124369111444, 0.018448761564546397, 0.029783609323203564, 0.024306143866851926, 0.03045547773529376, 0.015090511945475425, 0.054824693128466606, 0.02824901756165283, 0.0457683065906167, 0.03549303367201771, 0.054610561047281535, 0.059127080121210644, 0.012730998868521835, 0.047349998860486915, 0.007949407545051404, 0.020623315325272933, 0.052752976438828876, 0.058564730653805394, 6.79910284280777, 38.2360132762364, 21.66178904260908, 35.98653398241316, 34.053343636649, 4.451960103852408, 0.1130799168188657, 0.6519000221576009, 0.5754209831357002, 2.591667217867715, 2.628701767751149, 3.5966490166527882, 0.8396640153867858, 0.10845156838851315, 8.649337342807225, 43.581919057028635, 53.79544442040579, 54.2542131287711, 53.63915858949934, 52.116690158843994, 53.20084885188511, 50.97933953148978, 49.85251195090157, 46.08103322982788, 41.56674344199044, 39.616220814841135, 37.545775754111155, 41.880419867379324, 45.10892118726458, 44.07541486195156, 45.67493186678205, 44.364345278058735, 42.169662952423096, 39.34947599683489, 38.637740748269216, 38.64472368785313, 45.22130135127476, 49.682461738586426, 50.58696780885969, 47.406287465776714, 38.90658392224993, 36.11486373628889, 36.67954730987549, 36.19748476573399, 36.04728903089251, 36.21063075746809, 36.07312590735299, 35.2387375831604, 35.9503755569458, 36.211912700108115, 42.793034485408235, 47.68501445225307, 45.65636280604771, 46.775352818625315, 49.310562883104595, 48.917305265154155, 49.301731722695486, 48.1227058001927, 50.67846168790545, 50.4165632384164, 50.21055609839303, 45.60943814686367, 44.89544473375593, 47.21155377796718, 49.51845645904541, 46.72423144749233, 46.25191375187465, 45.268906933920725, 49.367656230926514, 50.81076928547451, 45.89575604030064, 47.23993369511196, 47.04114573342459, 45.55741350991385, 44.47730909075056, 38.17494208472115, 33.16271659306118, 34.91543442862374, 33.45827211652483, 35.225174699510845, 32.78706571034023, 36.07554735456194, 34.795223644801546, 34.414785453251426, 34.38905279976981, 33.93058633804321, 33.499488830566406, 33.76374271937779, 35.120034558432444, 41.49654579162598, 44.39431285858154, 45.980030741010395, 44.29909127099173, 45.03672592980521, 47.01403038842337, 44.62216166087559, 43.632005146571565, 39.812747137887136, 36.12704392841884, 34.62304380961827, 37.83556774684361, 37.42114591598511, 40.46032272066389, 36.637430804116384, 38.4315390586853, 37.40089886529105, 43.36721624646868, 39.33445746558053, 45.87369203567505, 43.14052431924002, 52.15685422079903, 13.01018224443708, 0.12551979108580522, 1.0252195128372736, 6.545261263847351, 7.438675403594971, 5.022638670035771, 4.147166950362069, 2.312403048787798, 0.24007917887398175, 0.052682069529380114, 1.5444552451372147, 34.56749643598284, 26.277479103633336, 19.259706463132584, 34.45254891259329, 1.9243216216564178, 0.18051512220076152, 0.01643023523502052, 0.032794133493942876, 0.054078223183751106, 0.013381798768283, 0.026485438891021267, 0.09983068598168236, 0.018289909731330614, 0.018431799885417734, 0.06808773215327944, 0.03739227693794029, 0.04502683744898864, 0.06390763074159622, 0.05699916037597826, 0.019648721907287836, 0.01618803894546415, 0.0354937393484371, 0.0624287093856505, 0.04843742247404797, 0.06054916059864419, 0.015673826448619366, 0.04160303795444114, 0.036713819950819016, 0.02149112768737333, 0.05516863235139421, 0.022602206728022014, 0.06672072836330958, 0.05468094887744103, 0.012871369952335954, 0.03887542895972729, 0.07789554872683116, 0.023191168338858655, 0.038917986676096916, 0.0424139381918524, 0.057798243926039765, 0.048419977338718515, 0.06331631461424486, 0.07770251908472606, 0.013202254161504763, 0.07123236198510442, 0.050622539328677316, 0.03679432473810656, 0.0564174387337906, 0.025422992151496664, 0.06133271926747901, 0.019351048594606773, 0.028737827403736965, 0.02482505521870085, 0.03260030657319086, 10.904449888638087, 42.06838600976126, 19.17512951578413, 41.069988931928364, 33.410339968545095, 4.598660460540226, 0.03961655204849584, 0.3273167163133621, 0.9711485228368214, 1.8382668793201447, 5.229740585599627, 5.419844167573111, 2.995175165789468, 0.5017541732106889, 9.808910914829799, 45.36259644372122, 53.50873395374843, 55.518639360155376, 54.14834342684065, 53.444344997406006, 53.31485489436558, 54.187211649758474, 51.26769324711391, 48.17192336491176, 42.55620513643537, 42.34227010181972, 40.54005677359444, 43.21434892926897, 46.32460233143398, 45.688317571367534, 46.772889682224815, 47.096991879599436, 44.49101441247122, 41.80306904656546, 39.93631042752947, 40.93526336124965, 45.642115524836946, 52.73029599870954, 51.17296845572335, 47.62097985403878, 38.711881501334055, 37.86064032145909, 38.640440123421804, 38.21259437288557, 37.40858704703194, 38.56638274874006, 37.25225257873535, 38.40169307163784, 36.30910757609776, 38.02125835418701, 44.007395471845356, 49.64313840866089, 47.62182058606829, 47.82848085675921, 49.91549737112862, 49.890424796513145, 49.707989420209614, 49.48714440209525, 50.44262593133109, 48.739285469055176, 49.22590603147234, 46.30445255552019, 45.897322859082905, 49.817228998456685, 49.89209931237357, 49.153662136622835, 47.81514378956386, 48.11782816478184, 49.36400147846767, 55.01421403884888, 47.58086095537458, 47.64542709078108, 48.64090245110648, 47.47196878705706, 46.160270486559185, 39.459448610033306, 35.05156353541783, 36.37014055252075, 35.10136822291783, 35.161883558545796, 34.88760689326695, 36.158060686928884, 35.31199591500418, 35.69395923614502, 35.459756306239534, 36.23279203687395, 35.45749119349888, 36.47948087964739, 36.94925206048148, 42.02028363091605, 46.641408920288086, 46.195112228393555, 45.87893097741263, 45.104446547372, 47.783004896981375, 46.587487425122944, 45.19028459276472, 41.50023181097848, 37.252461024693076, 36.63242810113089, 37.701912198747905, 38.48215668542044, 42.13790968486241, 38.1621539252145, 39.985666956220356, 38.56460748400007, 45.592498438698904, 40.212855679648264, 47.133539404187886, 43.443100997379844, 52.134328160967144, 15.696552106312343, 0.3025503781225, 2.4191775364535193, 7.033182876450675, 8.00125801563263, 5.283044993877411, 4.442874031407492, 1.7195133715867996, 0.339967350342444, 0.07077546364494733, 1.9750918916293552, 37.83467837742397, 34.43299668175833, 18.758748292922974, 40.21879986354283, 4.381218322685786, 0.2984120473265648, 0.01823750138282776, 0.01777511878338243, 0.08296385926327535, 0.06105232824172292, 0.05170103342139295, 0.10899732767471246, 0.059162533575935025, 0.03455571896795716, 0.053298223431089094, 0.035336207265832593, 0.029152140886123692, 0.049991701929164786, 0.020761497285483137, 0.04963070433586836, 0.026716880400532057, 0.01409567189070263, 0.06692734227648803, 0.02176912178817604, 0.007384545801739607, 0.010797320798571621, 0.07489466653870684, 0.18192823923059873, 0.19121399096080235, 0.17291211017540523, 0.10158504505774804, 0.09227391611784697, 0.12769307089703424, 0.13435441202351026, 0.17029892254088605, 0.2488152358148779, 0.13127093176756585, 0.10591250391943113, 0.10053237940051726, 0.11175640033824102, 0.13242503841008457, 0.10179535698677812, 0.1906329207122326, 0.1072297575218337, 0.14234389045408793, 0.16080576979688235, 0.16848161577114038, 0.23683146600212368, 0.13504426500626973, 0.09569269445325647, 0.11549716389604978, 0.16540622365261826, 0.15063694545200892, 0.10606178162353379, 12.395922405379158, 51.329573903764995, 30.34677846091134, 44.29070479529244, 43.995996952056885, 8.343089410236903, 0.37659002946955816, 2.132002191884177, 3.4915546902588437, 7.579479779515948, 10.70546477181571, 9.490504503250122, 2.6571055693285803, 0.5283151279602731, 11.221492716244288, 44.11868824277605, 55.27664055143084, 55.789921351841514, 55.89678117207119, 52.99896894182478, 55.73987347739083, 56.34701749256679, 54.35842221123831, 50.201936858040945, 44.394503934042795, 45.008599621909006, 42.82506568091256, 44.56794834136963, 48.19461270741054, 47.64881086349487, 49.657628876822336, 48.251706055232454, 45.920585427965435, 43.64745099203927, 43.21264662061419, 42.56468888691494, 49.73267636980329, 52.85739939553397, 54.24810218811035, 51.19316339492798, 42.130457741873606, 39.372109753744944, 40.42608894620623, 40.14588199343, 38.99805695669991, 40.55948393685477, 40.030291761670796, 40.05889402117048, 40.31270476749965, 40.05661153793335, 45.9166145324707, 51.609614099775044, 49.06289781842913, 49.91752971921648, 53.26534897940499, 52.395201751164024, 51.46682167053223, 53.1645062991551, 54.103951386043, 51.40849849155971, 51.93289640971592, 47.561617919376914, 46.038128103528706, 50.17763900756836, 54.85462433951241, 52.13002722603934, 49.82355880737305, 51.28982325962612, 49.272292205265586, 57.06012153625488, 51.34126772199358, 47.5919954436166, 51.18948432377407, 49.795335224696565, 48.52711875098092, 41.215098585401265, 36.45751414980207, 36.80741153444563, 38.23199026925223, 38.224183968135286, 35.59358555930001, 38.19146490097046, 38.0999710219247, 37.40706886563982, 37.11000905718122, 38.115614891052246, 37.11420924322945, 39.0403402192252, 38.70754929951259, 44.42146641867501, 49.060309614454, 48.11669908251081, 46.77049602781023, 46.73891299111502, 49.64139788491385, 47.98953662599836, 46.96962792532784, 43.0131881577628, 39.316954953329905, 38.076715401240754, 41.15136970792498, 41.434303828648154, 44.98995065689087, 41.37074518203735, 41.44884640829903, 40.246273040771484, 47.06998075757708, 42.1736546925136, 49.112844944000244, 45.65599455152239, 54.27285861968994, 15.14976361819676, 0.25411258584686686, 3.757468981402261, 11.673281959124974, 15.826759610857282, 10.587663275854927, 10.585647429738726, 7.293101957866123, 0.8623402757304055, 0.19635964770402226, 3.6608421206474304, 45.18685565676008, 35.16675424575806, 24.78707834652492, 46.88090985161917, 5.222828430788858, 0.4302126435296876, 0.100407603595938, 0.13168884148555143, 0.1312481737030404, 0.21501516737043858, 0.1616600996681622, 0.22207889333367348, 0.1444741782865354, 0.11123171634972095, 0.22734189592301846, 0.1553886311927012, 0.17088775523006916, 0.13936243472354753, 0.12969356855111464, 0.18102555695388997, 0.0485205939039588, 0.1295162673507418, 0.13879049755632877, 0.15447374885635717, 0.13228344172239304, 0.04752342562590327], [0.013816608249076774, 0.07836760553930487, 0.05220728161345635, 0.04711858109970178, 0.03840362320521048, 0.05373469108183469, 0.02766057163743036, 0.08457542064466647, 0.05807742715946265, 0.03744888711454613, 0.029330283469919647, 0.0409734117399369, 0.07093328410493475, 0.04454477224498987, 0.049202966038137674, 0.02833365462720394, 0.008628503203258982, 0.026892688823863864, 0.06365350580641202, 0.04192093500335302, 0.007031228800769895, 0.05047224721472178, 0.05804081340985639, 0.027724708463730555, 0.01642397405313594, 0.04321540679250445, 0.057201323099434376, 0.11320014643882002, 0.37213826977780884, 28.7753495488848, 30.165110860552105, 25.59578091757638, 47.063942773001536, 15.373495612825666, 0.3405122953866209, 0.5599648782185146, 0.4308154268988541, 1.1159679804529463, 3.4150589321340834, 4.941070292677198, 5.084974867956979, 0.4183986974614007, 0.3938724792429379, 22.330308232988628, 49.36458512714931, 53.46128470557076, 53.123880181993755, 53.222092969076975, 51.191016401563374, 49.713297843933105, 47.17639241899763, 42.64692429133824, 38.0607727595738, 40.74195752825056, 45.42788519178118, 47.47601958683559, 46.27171959195818, 46.82015132904053, 42.48335674830845, 42.757765429360525, 40.13539368765694, 38.78753696169172, 40.85947935921805, 45.490342548915315, 49.0191137450082, 50.40567193712507, 50.9109970501491, 47.47234746388027, 42.64043467385428, 35.30381441116333, 38.458765574863975, 36.67820978164673, 36.243676389966694, 36.01102985654558, 36.030179091862266, 35.46718740463257, 35.56014387948172, 35.01203523363386, 35.958251340048655, 38.61505487986973, 43.69019978387015, 43.979970932006836, 48.66347367422921, 47.71078879492623, 48.07088960920061, 46.72648613793509, 50.080520561763215, 48.037062304360525, 48.30901479721069, 46.23092324393136, 41.47799062728882, 46.776725087847026, 47.84751892089844, 49.22500971385411, 47.53985268729073, 50.818645068577354, 41.39632497514997, 24.019231183188303, 48.35856934956142, 48.90308230263846, 47.28300905227661, 46.97740990774972, 40.34254380634853, 35.03463077545166, 34.058999470302034, 33.655864988054546, 33.58032417297363, 34.00965683800833, 34.753197465624126, 34.72851399012974, 35.036906310490195, 34.938558033534456, 35.35289648600987, 34.588028362819124, 33.466439723968506, 34.465646266937256, 33.356317724500386, 39.54533529281616, 44.151619229997905, 45.42412621634347, 44.745794432503835, 44.47532538005284, 45.180727345602854, 44.47353274481637, 44.17123746871948, 39.654765946524485, 35.352132184164866, 38.491696562085835, 42.81556054524013, 42.92744738715035, 42.63218021392822, 41.378336088997976, 42.81072807312012, 42.019244875226704, 41.217909131731304, 43.884322030203684, 44.18991770063128, 44.70945187977382, 26.72409020151411, 0.12036935745605401, 0.570529614176069, 3.000403468097959, 5.918627117361341, 7.541808383805411, 4.755847820213862, 2.969810115439551, 1.7114736544234412, 0.17089341421212467, 0.04232797119766474, 8.619590367589678, 44.565544264657156, 22.642073903764995, 27.920642954962595, 19.610515798841202, 0.061176439081983905, 0.015404069762943047, 0.13179250806570053, 0.04918895089732749, 0.10106570792517491, 0.013619677878783217, 0.015781306395573274, 0.04288522147440484, 0.06583506374486855, 0.0054923609963485175, 0.026068584294989705, 0.04166269475328071, 0.03822766211149948, 0.11914671877665178, 0.04692519861938698, 0.031813216129583974, 0.02965339845312493, 0.06086041818239859, 0.02228086781022804, 0.07588701043277979, 0.04703746223822236, 0.02671349111811391, 0.022655444585585167, 0.032831507202770026, 0.053350775968283415, 0.045772591539259465, 0.04206447908654809, 0.02783716207237116, 0.07075086675052132, 0.07441286596336535, 0.04334195696615747, 0.03744415772546615, 0.011273499711283615, 0.06460138530071292, 0.06216338862265859, 0.01429716031998396, 0.06269578076899052, 0.07244343164243869, 0.044656292867979834, 0.02784180494823626, 0.029449074595634426, 0.023949667013117244, 0.04856137725125466, 0.06124063528009823, 0.06604023916380745, 0.020037754871217266, 0.01603008108213544, 0.025920327786090117, 0.013008223680247153, 0.05967796913215092, 0.8346614209668977, 37.480869156973704, 29.53201184953962, 25.89115231377738, 53.651991912296836, 16.12186176436288, 0.26475757892642704, 0.14638774203402655, 0.7790604159235954, 1.210675184215818, 6.647513994148799, 4.373118894440787, 1.8883807616574424, 1.6342365017959049, 0.9064920608486448, 26.702733176095144, 51.570665972573416, 53.50329351425171, 54.50823926925659, 54.0069580078125, 53.647277559552876, 51.798876081194194, 49.1915784563337, 44.684445313044954, 39.78917190006801, 41.35563632420131, 46.01989255632673, 49.1510009765625, 47.93943664005825, 49.40697956085205, 45.758807046072825, 44.07071787970406, 43.102823393685476, 38.86449868338448, 40.806113719940186, 46.85787657329014, 51.248780250549316, 50.56095027923584, 52.40858745574951, 51.52063199451992, 43.28467859540667, 37.5225305557251, 39.62600040435791, 37.825110707964214, 38.79003831318447, 37.33984504427229, 38.85321133477347, 38.37837144306728, 35.76995515823364, 36.97849702835083, 38.78920105525425, 42.88479239600045, 46.5375576700483, 45.754123960222515, 50.41639648165022, 49.33700425284249, 50.41597611563546, 49.57771417072841, 51.87444468906948, 50.41653544562203, 49.30835335595267, 48.53374038423811, 43.82718004499163, 47.870885712759836, 49.854412283216206, 50.71940047400338, 49.73280838557652, 51.26766892841884, 44.03263480322701, 26.299530948911393, 49.194653034210205, 50.42645399911063, 49.017453125544954, 47.89642381668091, 41.846825327192036, 36.82056794847761, 35.73763908658709, 35.91982085364205, 35.52217892238072, 34.95731469563076, 35.96256269727434, 35.31610230037144, 35.962889262608115, 36.4305169241769, 36.32602991376604, 35.25158827645438, 34.77947555269514, 35.871979032244, 35.71519987923758, 41.067897524152485, 46.303761209760395, 46.29577425548008, 44.761219433375764, 44.827842235565186, 45.76485892704555, 45.899070331028526, 45.54404517582485, 40.95476695469448, 37.655296734401155, 40.9155513218471, 44.13858788354056, 44.80229718344552, 44.78258514404297, 43.53564058031355, 44.63883038929531, 43.162807192121235, 43.1901205607823, 45.45841210229056, 46.122104031699045, 45.67745753696987, 30.437650476183208, 0.2822978177240917, 1.7751249074935913, 3.325785002538136, 9.315077253750392, 7.360263245446341, 5.060673109122685, 2.8701184477124895, 0.6767919436097145, 0.09132898825087718, 0.07977816449212176, 8.824939165796552, 49.57431302751814, 23.41420636858259, 27.989254678998673, 29.01560435976301, 0.03610491619578429, 0.015357781800308397, 0.0639302327430674, 0.02894540483664189, 0.11277672701648303, 0.030301012630973543, 0.05008466122671962, 0.020506970318300382, 0.03618470173595207, 0.03861517685332468, 0.012614797202071973, 0.03387430017547948, 0.05704564002475568, 0.042706569989344904, 0.034067010906125815, 0.03725485663328852, 0.07770080917647906, 0.006184996820853225, 0.052746499822075875, 0.036755702524845085, 0.019972437393984625, 0.010596522778671767, 0.15587548006858143, 0.15410586073994637, 0.1662574051214116, 0.13246832894427435, 0.11316472012549639, 0.08690891614449875, 0.24858122265764646, 0.19162730021136148, 0.17572874974991592, 0.11473290276314531, 0.11007467843592167, 0.1362700385174581, 0.1501047568661826, 0.14087663990046295, 0.1147518881729671, 0.12821554286139353, 0.11986520593719822, 0.12227452094001429, 0.14019742634679588, 0.08465749624052218, 0.07476387212851218, 0.20315630228391715, 0.10869049413927964, 0.09885601792484522, 0.09834523033350706, 0.13786789349147252, 0.1667753037597452, 0.1669090294412204, 1.2090880636657988, 41.774730818612234, 42.29431363514492, 32.1495406968253, 53.217274393354145, 25.038988760539464, 0.5614093435662133, 0.7763113720076424, 1.503632081406457, 6.3687566093036105, 13.237291932106018, 11.891382438795906, 9.854324340820312, 1.3064078986644745, 0.667299455830029, 25.92048066002982, 51.1520995412554, 56.014379433223176, 55.660875933510916, 55.91819552012852, 56.00606591360909, 52.67108692441668, 50.8850212097168, 46.87402071271624, 40.88187687737601, 43.987985679081504, 49.05219064440046, 51.09709760120937, 51.610260282244, 51.63979707445417, 46.68863582611084, 46.49493047169277, 45.58026613507952, 41.716814109257285, 44.849346910204204, 50.22235066550118, 51.99189703805106, 53.87341710499355, 53.80778442110334, 52.280382769448416, 47.17857762745449, 39.19485773359026, 41.97591938291277, 39.538751874651226, 40.894456590924946, 39.142423152923584, 40.678986004420686, 40.399821281433105, 38.46870149884905, 39.16443157196045, 39.63165971211025, 43.05587441580636, 48.228193351200645, 47.92985507420131, 52.888183389391216, 51.31654603140694, 52.54236459732056, 50.797456536974224, 52.65150342668806, 52.445961815970286, 50.20306594031197, 50.00061975206648, 43.62900352478027, 47.30857147489275, 50.16622311728341, 51.15489271708897, 51.344425678253174, 51.14925077983311, 43.25087213516235, 31.110472338540212, 50.663470949445454, 51.43030888693673, 51.52801098142351, 49.688232217516216, 43.53546340124947, 38.00167833055769, 37.75196702139718, 37.97163084575108, 37.35737534931728, 37.00693947928292, 38.03829186303275, 38.53483097893851, 37.338240010397776, 38.77588135855538, 37.18320485523769, 37.05479867117745, 35.72855084283011, 37.85564456667219, 37.39021600995745, 42.63398674556187, 49.12585891996111, 47.060399191720144, 46.98999309539795, 45.292687143598286, 46.119873659951345, 48.856703077043804, 47.221107551029746, 42.923344475882395, 40.084338324410574, 41.536272117069785, 47.28823757171631, 46.21723181860787, 46.893242904118125, 44.96182434899466, 47.35952608925955, 44.26757424218314, 44.5199293409075, 47.47620371409825, 48.195154666900635, 46.62844010761806, 28.96373779433114, 0.24684021036539758, 2.6075555767331804, 6.573624244758061, 12.428281903266907, 17.44902328082493, 8.610305837222509, 10.127037661416189, 3.6108947779451097, 0.5561535198773656, 0.15923627758664743, 14.023293001311165, 54.19327047892979, 29.77950668334961, 39.10323531287057, 32.24229219981602, 0.22462707731340611, 0.12240585817822389, 0.19058458187750407, 0.18234917521476746, 0.21475908825440065, 0.10180816094258002, 0.11669389610843998, 0.12993477417954377, 0.24560609087347984, 0.08121057905788932, 0.09180885500141553, 0.14726179013294832, 0.11088284756988287, 0.24428509175777435, 0.15276355562465532, 0.1421758309006691, 0.12807989014046534, 0.19709774452660764, 0.11597892375929014, 0.1212265236037118, 0.14820964927119867, 0.09283664556486265], [0.018608353000932505, 0.049393376535070796, 0.09567483541156564, 0.062224551769239564, 0.021319695814911808, 0.03507418418303132, 0.01997772996713008, 0.047328014325882704, 0.046648162949298105, 0.02262977390949215, 0.07153150093342577, 0.0146303125324526, 0.03420706053397485, 0.03022124744685633, 0.027378735332084552, 0.02157449928511466, 0.02404361018644912, 0.09184461379689829, 0.08597552337284599, 0.01876671119992222, 0.06999816106898443, 0.0600064072225775, 0.022996225228000964, 0.021533300335119878, 0.04511433453964336, 0.017117667544100965, 0.020934342207120996, 0.01760590572043189, 0.11996751544731003, 7.958896585873195, 42.02580050059727, 19.53007824080331, 35.519389220646445, 39.910080977848594, 2.2761301951748982, 0.15628303534218244, 0.32895757683685845, 0.4170386961528233, 4.696447670459747, 3.2086587846279144, 1.835425283227648, 1.7968521416187286, 0.032190345892948766, 3.127428480557033, 32.42088522229876, 50.51068353652954, 52.1287522315979, 53.618574551173616, 53.822959286826, 51.69157157625471, 44.401320116860525, 43.076590469905305, 41.867927006312776, 47.28039305550711, 50.109428542000906, 49.241070474897114, 47.568520954677034, 45.44232702255249, 43.495438303266255, 39.19289834158761, 37.06188930783953, 37.630206789289204, 46.72982474735805, 50.69305637904576, 50.948604175022666, 51.31763342448643, 51.267686298915315, 47.560238701956614, 45.874623094286235, 38.23826101848057, 35.51737771715437, 35.6829046521868, 36.93583856310163, 35.83380215508597, 35.88275916235787, 35.3815404347011, 35.758886677878245, 35.55095836094448, 37.314004693712505, 36.603096280779155, 36.15875898088728, 36.77344526563372, 42.16667522702898, 42.58064195087978, 44.887482098170686, 43.499346664973665, 46.08840874263218, 44.7725693157741, 50.77038288116455, 43.01284074783325, 40.721022605895996, 47.636995451790945, 44.06691026687622, 45.901849610464915, 44.81247976848057, 45.16958243506295, 41.50176041466849, 46.72579479217529, 49.53307894298008, 45.81261389596121, 46.112626688820974, 42.24451242174421, 33.122899941035676, 32.402670519692556, 34.382962703704834, 35.31154775619507, 33.864495073046, 35.72245727266584, 34.97224290030343, 34.59270102637154, 38.98732198987688, 41.59679092679705, 37.469679083142964, 35.83506325313023, 34.413044929504395, 33.64386197498867, 34.75902700424194, 37.69481808798653, 44.39520570210048, 44.801824705941335, 43.97409275599888, 43.76369782856533, 45.525271143232075, 46.05430350984846, 45.08475187846592, 40.08333778381348, 35.362061159951345, 42.280632632119314, 43.11616393498012, 43.774474484579905, 43.044878891536165, 44.10460424423218, 43.87838479450771, 43.942349910736084, 44.35120970862252, 44.13551677976336, 44.81693008967808, 35.95561449868338, 2.671211063861847, 0.403544371681554, 1.4668255192892892, 1.3933836030108588, 7.414904747690473, 1.0459698736667633, 3.797633477619716, 2.477616229227611, 0.7925203793815204, 0.15687425647463116, 0.13427723545048917, 20.990980420793804, 43.435086250305176, 18.479769434247697, 33.38313429696219, 8.903047340256826, 0.27359967732003754, 0.044022551338587484, 0.013314956283595945, 0.04514617818806853, 0.10491499637386628, 0.07692843276475157, 0.01097655073473496, 0.04170802089252642, 0.062337622844747136, 0.041054225260657926, 0.044882842140006166, 0.03986863459327391, 0.06314417706536395, 0.042728883613433154, 0.04437705195908036, 0.049321160053036044, 0.020322843055639948, 0.015917281420635324, 0.05675135599449277, 0.049024107599897046, 0.06661204740937267, 0.024187681830621192, 0.012567750976553984, 0.03072095795401505, 0.05033561061801655, 0.010741367104596325, 0.036938554141670465, 0.03648976768766131, 0.01770905831030437, 0.025494163689602698, 0.01613653983388628, 0.03411111907501306, 0.07641636952757835, 0.05583292152732611, 0.03169060145903911, 0.05871314661843436, 0.039957376795687845, 0.08505301430289235, 0.02840756914312286, 0.04687672407765474, 0.026278232956039052, 0.03462891932576895, 0.023220972989552786, 0.05941924372954028, 0.03853927592613867, 0.02003424514883331, 0.07715217968715088, 0.03110002154218299, 0.047925630650882206, 0.04514377617410251, 0.06341246981173754, 12.780723197119576, 45.3646913255964, 19.916474512645177, 45.14177574430193, 42.02540792737688, 2.5797067625182013, 0.18828167473631247, 0.5011712302054677, 0.5312678409474236, 3.4245690618242537, 3.6895820413317, 4.368208255086627, 3.8574296746935164, 0.5660214275121689, 2.982084108250482, 34.894172940935405, 50.12251894814627, 53.30022546223232, 55.30976956231253, 55.91772304262434, 53.29048408780779, 48.00098378317696, 43.2379206929888, 43.52832065309797, 48.682303292410715, 52.15698971067156, 51.45632641656058, 49.409050124032156, 48.55609621320452, 45.69286516734532, 42.055517945970806, 39.6779659816197, 39.60973814555577, 48.11379473549979, 52.32803004128592, 54.11292151042393, 51.90453386306763, 54.12111691066197, 48.6713980947222, 45.19056946890694, 38.77751765932356, 37.165473052433555, 37.57361718586513, 38.07180997303554, 37.926728112357004, 38.480711460113525, 38.15198523657662, 37.23340559005737, 37.75340182440621, 38.35270479747227, 37.08336966378348, 38.7647260257176, 39.51332841600691, 44.523782117026194, 45.55807358877999, 47.93996817725045, 45.69924708775112, 48.40427112579346, 47.74967786243984, 52.87154245376587, 46.20580898012434, 42.41888441358294, 46.27525969914028, 45.10174717221941, 48.64450856617519, 46.27991499219622, 45.34144960130964, 41.89755065100533, 42.7361113684518, 51.07999113627842, 47.95505619049072, 47.910414014543804, 44.480717182159424, 37.70811346599034, 33.741042954581125, 36.09603411810738, 35.51548433303833, 34.99597794669015, 37.56812810897827, 36.32380301611764, 36.02660771778652, 41.032301902770996, 41.705512864249094, 38.442412989480154, 36.75923272541591, 35.48337670734951, 35.55524887357439, 35.94689450945173, 39.19116129193987, 46.176932266780305, 45.45486504690987, 45.788854530879426, 44.47403996331351, 45.48111534118652, 47.64355455126081, 47.057133538382395, 42.52491044998169, 37.12452384403774, 42.48743881498064, 45.09150205339704, 45.31155150277274, 43.43162604740688, 46.79981395176479, 44.44095958982195, 46.66724579674857, 44.82996491023472, 45.320142950330464, 45.84377309254238, 39.22463423865182, 3.6655768837247575, 0.593196972140244, 3.700888063226427, 3.7434249350002835, 5.4914796607834955, 4.487811940056937, 7.100226044654846, 3.2165063406739915, 0.5954040565661022, 0.1529980166149991, 0.17561354807444982, 22.186065367289952, 53.53255932671683, 21.25120782852173, 38.24643210002354, 12.096758161272321, 0.37817324165787014, 0.015016729743885142, 0.057571335030453544, 0.03746273262160165, 0.11131848740790572, 0.010141789813392928, 0.043413528839924505, 0.032042102954749546, 0.006062052636739931, 0.021371194926489676, 0.017130708987159387, 0.01013164232218904, 0.06504622607358865, 0.05813663612518992, 0.032510339615068266, 0.023521485971286893, 0.04206039769841092, 0.05521746990936143, 0.038522166665643454, 0.004525683113440339, 0.017472339494686042, 0.05486961893205132, 0.12913658629570687, 0.13499619758554868, 0.1963343247771263, 0.11432618887296744, 0.10491736446108137, 0.15833369030484132, 0.16585503385535308, 0.16372816583939961, 0.08195562407906566, 0.07939315693719046, 0.1375929375312158, 0.15282823358263287, 0.08921896147408656, 0.17533841569508823, 0.13655123699988636, 0.1501607767173222, 0.25897868616240366, 0.1189799891518695, 0.20498219930699893, 0.14408768473991326, 0.14936367448951515, 0.14149363179291996, 0.1229253988713026, 0.1291735257421221, 0.1539750120469502, 0.08958632033318281, 0.11320624646863767, 0.197369375665273, 0.24837958919150488, 13.993016225951058, 54.860603264399934, 28.660457611083984, 45.487299237932476, 52.669172695704866, 4.95652482339314, 0.3518853022583893, 1.9136070651667458, 2.730454227754048, 12.121234927858625, 10.406544583184377, 7.911766954830714, 3.2629845780985693, 0.18592554330825806, 4.298984655312129, 36.14960820334298, 49.80659130641392, 52.153237683432444, 58.28738880157471, 57.06726428440639, 56.60583094188145, 48.92670965194702, 46.190859930855886, 45.22270141329084, 52.637839794158936, 53.75360931668963, 54.658101490565706, 51.62397950036185, 49.667342458452495, 46.75180537360055, 43.054071358272004, 41.0256906918117, 42.111256395067485, 51.56380810056414, 56.74792855126517, 55.086287702832905, 54.891439369746614, 57.11857325690133, 50.52397196633475, 48.973359857286724, 41.533544949122835, 38.38167878559658, 40.0474260193961, 41.16515840802874, 39.988512243543354, 40.28817067827497, 40.8693596976144, 38.732614925929475, 40.61182124274117, 40.021533557346885, 39.44670213971819, 39.951502663748606, 39.953955377851216, 45.78550549915859, 46.695827211652485, 48.05562789099557, 47.50613307952881, 50.18933629989624, 50.774888787950786, 54.109461307525635, 52.345542975834434, 46.65956456320626, 47.010441643851145, 46.42489262989589, 48.314417021615164, 46.55250324521746, 45.92846815926688, 44.65852505820138, 45.79942274093628, 54.98980501719883, 48.64536666870117, 50.25124822344099, 44.753923824855256, 37.950053215026855, 35.317255701337544, 38.53981631142752, 38.51290593828474, 37.27346542903355, 39.84556695393154, 37.936424323490684, 38.27742453983852, 43.84573173522949, 45.68271732330322, 41.28435822895595, 39.223491259983604, 38.00173044204712, 36.300564765930176, 37.76568971361433, 39.59940617425101, 48.69573416028704, 47.16263151168823, 48.48396348953247, 45.368439878736226, 46.387681552342, 47.880470752716064, 49.97156238555908, 44.43904536111014, 38.17115184238979, 47.12727907725743, 46.733472551618306, 46.493665899549214, 45.5086475781032, 48.19551249912807, 46.63588857650757, 48.20278378895351, 48.55627686636788, 46.78477110181536, 46.70860147476196, 37.4734137398856, 3.660516858100891, 0.8035930395126343, 6.138222328254154, 4.846879644053323, 17.98228883743286, 6.585860456739153, 13.012261492865425, 10.483091150011335, 1.529529863170215, 0.37454606486218317, 0.458973517375333, 30.20974956239973, 54.41652652195522, 26.251749924251012, 46.170664991651265, 14.402783632278442, 0.6610887976629394, 0.08374774362891912, 0.14149526027696474, 0.1185175132538591, 0.2399425490626267, 0.12058411378945623, 0.1380840747484139, 0.12556625716388226, 0.10809746810368129, 0.10593213393752064, 0.1362067312002182, 0.13851442879864148, 0.1980962088065488, 0.10453860621367182, 0.16111594172460691, 0.09561426937580109, 0.19294126970427378, 0.13689589207725866, 0.16840405921850884, 0.1279935533446925, 0.1732564259852682, 0.19806796817907266], [0.02565487810144467, 0.01076338641412024, 0.014526506852624672, 0.058692329164062224, 0.016595765549157347, 0.03126671045486416, 0.04893966391682625, 0.03722809860482812, 0.08006764788712774, 0.12090136962277548, 0.037853110781205554, 0.019622169135670577, 0.0568611836726112, 0.03854746923648885, 0.09235274153096334, 0.030932949257216284, 0.04673050656648619, 0.05816778088254588, 0.024279852331216847, 0.02583980603542711, 0.04961563068042908, 0.026602557427915077, 0.009067705350129731, 0.09567554108798504, 0.06310925286795412, 0.013030561901229833, 0.002517356437497905, 0.05438318396253245, 0.00814579932817391, 0.54154520375388, 30.728502069200786, 31.94145257132394, 23.18889192172459, 51.684004987989155, 15.606307165963308, 0.13841016510767595, 0.2597503161856106, 0.319276429180588, 2.5700544118881226, 2.944601616689137, 0.2684346687580858, 4.538243702479771, 1.2614647788660867, 0.05202156997152737, 5.393287284033639, 31.365082127707346, 56.062005860464915, 56.36516271318708, 51.90300178527832, 53.60459130150931, 49.26239102227347, 46.57356323514666, 47.61227028710501, 48.81709139687674, 50.23645898274013, 51.56502056121826, 49.363782610212056, 47.490103585379465, 40.486986432756694, 39.63574872698103, 38.66481440407889, 45.81862408774239, 50.08198315756661, 51.09689262935093, 49.82251310348511, 50.14915486744472, 50.8654203414917, 47.48932538713728, 43.42880507877895, 40.91609328133719, 38.536363056727815, 36.964333125523154, 36.83488818577358, 35.678357056209016, 37.0472320829119, 35.29080043520246, 35.37360559191023, 36.118633134024485, 35.57556888035366, 36.53533744812012, 36.91836731774466, 34.97470603670393, 35.986103194100515, 38.151339054107666, 37.494709968566895, 41.38727842058454, 44.61161429541451, 44.76905352728707, 49.94888693945748, 48.35437958581107, 44.91719606944493, 49.21313871656145, 48.66535316194807, 47.87678125926426, 47.519821030753, 50.29718623842512, 54.72319916316441, 51.289322989327566, 47.82351636886597, 47.36682169778006, 42.11236810684204, 36.43140976769583, 33.97216783251081, 33.207699230739046, 34.10891880307879, 34.88354914528983, 34.865935461861746, 34.57339545658657, 35.8997996194022, 43.57713174819946, 45.415566035679404, 45.37290062223162, 43.641103812626426, 38.98896523884365, 34.91025802067348, 33.68443250656128, 34.039509773254395, 38.67143256323678, 45.2637756892613, 45.47840901783535, 44.70694705418178, 45.45643533979143, 45.100722312927246, 45.29176650728498, 44.93838460104806, 41.28725562776838, 36.56881039483206, 40.3770763533456, 45.4265580858503, 44.558272974831716, 45.801493304116384, 45.189235414777485, 46.85584075110299, 45.18492405755179, 44.320755754198345, 43.560351848602295, 42.59577860151018, 7.491130828857422, 0.01387258738811527, 1.1202829203435352, 1.8860806907926286, 2.6550408686910356, 16.553991079330444, 8.666032126971654, 5.440915882587433, 0.4203764099095549, 0.224193683426295, 0.03458611733679261, 1.3004907476050513, 38.035856519426616, 20.98974711554391, 17.645829268864222, 28.65539758546012, 0.6504251584410667, 0.07682868133166007, 0.029498865495302846, 0.029037821306181804, 0.013427673672725047, 0.037608678718762736, 0.018072208555947458, 0.02923396203134741, 0.07355170324444771, 0.09619559068232775, 0.1659966983965465, 0.050426144152879715, 0.030573603896690265, 0.05528047188584294, 0.05085279340190547, 0.01829101743974856, 0.05029997395883713, 0.030011631016220366, 0.08399749879858323, 0.09510092370744262, 0.014682379917108586, 0.026872336165979505, 0.022294265484171252, 0.07341339066624641, 0.011955517310915249, 0.00735433233369674, 0.014752299558105213, 0.0410610648936459, 0.05070612466494952, 0.022750973834523132, 0.07564943496670042, 0.05254749567913158, 0.08243840174483401, 0.06818139712725367, 0.01897700616557683, 0.06895785153444324, 0.010967359977907367, 0.09949943197092839, 0.042803797272167037, 0.0037068588592644247, 0.019536168214731982, 0.01748411886260978, 0.05354289976613862, 0.0322523266742272, 0.037892957750175676, 0.013569115145531083, 0.07625126160149064, 0.0881376141416175, 0.030663699776466404, 0.0589007344096899, 0.02505485976247915, 0.023764835770374963, 1.1693656465836932, 39.058815479278564, 31.75107192993164, 28.814247301646642, 59.2708090373448, 15.11039686203003, 0.0248752837734563, 0.10100394088242735, 0.6047541062746729, 0.37808682343789507, 3.399089366197586, 5.2904852117810925, 5.308349464620862, 3.083160638809204, 0.16993787405746325, 8.098023840359279, 35.10059002467564, 56.51718235015869, 56.0618634223938, 53.72129324504307, 55.18812050138201, 50.42175701686314, 47.51902198791504, 49.37202664784023, 52.17560740879604, 52.72549131938389, 52.09691905975342, 51.89096750531878, 48.96434456961495, 42.637325354984824, 41.66408423015049, 41.128840173993794, 47.04189613887242, 52.353606360299246, 52.93628576823643, 51.466623646872385, 50.94385160718645, 54.24421467099871, 50.75514548165457, 46.316785608019146, 42.5647166797093, 40.47790513719831, 38.67040770394461, 38.49223852157593, 36.69796003614153, 39.1462516103472, 38.74704286030361, 37.81673812866211, 38.52737903594971, 37.93609080995832, 38.66393198285784, 38.677710260663716, 36.954421520233154, 37.77772746767317, 39.722938196999685, 40.69747863497053, 44.218985489436555, 46.17465673174177, 48.19081204278128, 51.482847690582275, 49.644694805145264, 45.115323952266145, 48.792939458574565, 48.43294634137835, 48.23262630190168, 48.14685426439558, 49.63540506362915, 53.68170240947178, 52.28943279811314, 50.226832253592356, 49.9477196420942, 44.69242531912667, 38.643330574035645, 35.18837356567383, 35.50745221546718, 34.12047365733555, 36.492380210331504, 36.618788787296836, 36.927966254098074, 36.80931881495884, 44.44279738834926, 46.85469429833548, 46.832060541425435, 42.67649582454136, 39.53681680134365, 35.62769774028233, 35.30797290802002, 36.32197216578892, 40.236403124673025, 46.367962564740864, 47.36146811076573, 47.43686301367623, 45.592911856515066, 45.5986510685512, 46.66427196775164, 47.53193521499634, 42.57553849901472, 39.58580160140991, 41.49811608450753, 47.11068330492292, 45.82165697642735, 47.17490203039986, 47.505083901541575, 47.559766224452424, 45.23400265829903, 44.9485741342817, 44.043734550476074, 43.308431012289866, 10.708284871918814, 0.3219170703419617, 1.9658197377409254, 3.447404533624649, 6.109051184994834, 11.696168456758771, 10.600535682269506, 3.5232043862342834, 0.23085525525467737, 0.1570846973253148, 0.03076314247612442, 1.223968825169972, 42.76260832377842, 33.08189167295183, 17.100567647389003, 36.67157425199236, 1.7938750556537082, 0.04877047460260136, 0.010593911267018743, 0.059204697741993835, 0.0252564016263932, 0.0708022793488843, 0.023424297704228332, 0.05118312121235898, 0.08639127534947225, 0.043103173707744906, 0.07137057278305292, 0.013588879174286765, 0.05383909726515412, 0.02630212078137057, 0.03501738401662026, 0.02127998455294541, 0.05199633864685893, 0.04951252728434546, 0.021627287613227963, 0.02004276415599244, 0.02445673623255321, 0.007045369470558528, 0.02478239911475352, 0.25653815854872974, 0.06712153221347503, 0.0920871968514153, 0.17053691191332682, 0.07135613355785608, 0.12530620183263505, 0.08087511813001973, 0.11255904619715043, 0.15046709456614085, 0.2294057144650391, 0.16841074957379273, 0.05909440866006272, 0.21622707162584576, 0.12426801611270223, 0.22840112979922975, 0.17573576580200875, 0.14505765054907116, 0.1789408123918942, 0.10265442981783833, 0.1045840477038707, 0.10743828490376472, 0.18117092629628523, 0.06070444333766188, 0.23453704054866517, 0.17137988310839447, 0.12591518701187202, 0.14678062738052436, 0.2109016709561859, 0.2648732012936047, 1.7878806058849608, 45.405800342559814, 42.77066476004464, 33.79656253542219, 62.03368377685547, 22.912273713520594, 0.24800634064844676, 1.1796427922589439, 1.1635050582034248, 8.34885207244328, 11.627550653048925, 9.459353991917201, 9.806579794202532, 2.972852340766362, 0.1384369536702122, 7.239790167127337, 34.90326465879168, 58.04610913140433, 58.89526585170201, 57.626840932028635, 56.88187939780099, 53.84873710359846, 50.42506435939244, 51.41254581723894, 54.09896605355399, 55.37019804545811, 55.04820115225655, 53.72864096505301, 50.70643860953194, 43.88941158567156, 43.63097333908081, 43.67728655678885, 50.106847286224365, 54.624024050576345, 53.83573702403477, 52.58910165514265, 52.17450959341866, 55.190090315682546, 52.81800658362252, 47.74553326198033, 45.05406863348824, 42.01226888384138, 40.788722378867014, 40.795753955841064, 39.38409539631435, 42.70807191303798, 39.29987975529262, 38.90946742466518, 40.56372581209455, 39.90177093233381, 40.107732909066335, 41.42901624952044, 39.21519858496529, 39.34075253350394, 41.36874062674386, 42.29229518345424, 44.86658539090838, 48.35141965321132, 49.63738530022757, 53.815806116376606, 52.218519483293804, 47.37941183362688, 50.83972937720162, 49.86942039217268, 50.899476936885286, 49.43340356009347, 51.13175521578108, 54.062494959150044, 54.225148814065115, 50.86617769513811, 51.894705636160715, 46.88144138881138, 40.5985814503261, 37.27715492248535, 38.45197371074131, 37.43742207118443, 38.191246032714844, 39.100608893803184, 38.24795028141567, 40.129581519535606, 47.67217418125698, 49.09751026970999, 49.17604923248291, 46.238680907658164, 41.913976192474365, 37.90808262143816, 37.529749734061106, 38.6999305997576, 41.783075605119976, 48.79185206549508, 49.49803222928728, 48.585848399571006, 47.19361700330462, 45.64819172450474, 46.68798964364188, 49.377098832811626, 43.97898776190621, 41.7260274205889, 42.353171825408936, 49.44703245162964, 48.137203216552734, 49.47563818522862, 48.58208247593471, 48.097549847194124, 47.912491525922505, 44.250731808798655, 43.929572173527305, 43.749262945992605, 9.835185527801514, 0.26106827546443256, 2.3418714446680884, 6.231993479388101, 10.231165971074786, 28.49943310873849, 17.87452401433672, 8.881491422653198, 3.5552844362599507, 0.45508282471980366, 0.14002805043544087, 2.6915019750595093, 49.40766395841326, 29.150055476597377, 24.991417918886455, 42.239815439496724, 2.469758902277265, 0.2233282255807093, 0.14794043371719973, 0.21353311118270668, 0.14316430714513573, 0.08975373527833394, 0.11907247347491128, 0.10799697706741945, 0.1898500541491168, 0.19909436096038136, 0.23579832858272962, 0.16730813016848906, 0.1303919032216072, 0.11901863850653172, 0.20863863453269005, 0.09658767535750355, 0.1263051275163889, 0.14789182346846375, 0.25363245446767124, 0.18736129626631737, 0.08077540740902935, 0.1035586523690394, 0.13988082190709455], [0.021065277413332036, 0.03652609305988465, 0.04148762593311923, 0.03703923177506242, 0.04879121741812144, 0.02513457914548261, 0.08580745024872677, 0.021941345850271837, 0.01052769473088639, 0.03453037907768573, 0.05128008386652384, 0.013810851727612317, 0.03625684018645968, 0.0049805195553095215, 0.008394205061319684, 0.045753548453961096, 0.02504262068708028, 0.021741747989186218, 0.017383420873167257, 0.025073570365618383, 0.052362638991326094, 0.04894709387528045, 0.02547813329978713, 0.03076577858467187, 0.013330196180114788, 0.02533291662777109, 0.04249673982017806, 0.016680382258657898, 0.035916297031300407, 0.03377907457096236, 12.168968183653694, 39.51346043178013, 21.37582377025059, 42.3789496421814, 34.36837148666382, 1.61943390752588, 0.2010788723294224, 0.32244518771767616, 0.2427149617246219, 1.759141445159912, 4.849727536950793, 5.261696219444275, 5.679140950952258, 0.5270793257015092, 0.235324819705316, 4.0335100548607965, 41.02969632829939, 59.203480992998394, 55.42198644365583, 54.55768265042986, 54.15587527411324, 51.513169629233225, 51.724530356270925, 54.19328784942627, 52.71964093617031, 49.49926553453718, 50.26204572405134, 41.961199624197825, 39.200579575129915, 38.63373858588082, 45.4161114692688, 50.965686321258545, 51.68444619859968, 50.49540444782802, 48.859798499516074, 51.395963941301616, 50.25567422594343, 48.90244654246739, 44.70419904163906, 41.86813545227051, 39.473907811301096, 37.057967049734934, 36.685897963387625, 36.016150678907124, 35.24850327627999, 36.20872695105416, 36.86060346875872, 35.828681332724436, 34.71383939470564, 36.743283135550364, 37.56041213444301, 37.922791957855225, 38.55552618844168, 39.53511449268886, 42.54742956161499, 42.064032963344026, 42.091335909707205, 45.87414366858346, 51.47570494243077, 48.18371793201992, 44.52629041671753, 53.4059978893825, 51.90259531566075, 48.51495940344674, 49.61806583404541, 48.55440085274832, 46.06929077420916, 47.20156226839338, 48.27531255994524, 44.78075776781355, 39.080896854400635, 33.45704228537423, 33.85374968392508, 34.698650632585796, 34.64331865310669, 34.09649542399815, 35.51455674852644, 35.796875953674316, 45.065157958439414, 48.025347641536165, 47.34399686540876, 47.89278990881783, 42.83628702163696, 39.27888577325003, 35.87760707310268, 34.50824914659773, 35.35910470145089, 39.72133663722447, 45.2682329586574, 46.48372302736555, 45.288337571280344, 44.13040637969971, 46.12406342370169, 46.775592531476704, 46.088770048958914, 43.68414095469883, 38.24506677900042, 36.00045469829014, 42.47862502506801, 43.36436748504639, 45.447885581425254, 44.05283669063023, 43.72516311917986, 44.888246400015696, 48.39840337208339, 43.26626239504133, 21.820859364100865, 0.6952098810247013, 0.29952913309846607, 1.0383404259170805, 2.2052683404513767, 1.6060370206832886, 9.95576196057456, 8.701206513813563, 2.8245406533990587, 0.445458429732493, 0.060522215973053656, 0.02361198897207422, 7.729526128087725, 42.33115645817348, 16.70894980430603, 32.60510975973946, 17.022584540503367, 0.04025602041344557, 0.020114186752055372, 0.03530110325664282, 0.052699752151966095, 0.03451237754364099, 0.07329706940799952, 0.017781690395038043, 0.017506369722208807, 0.09957785026303359, 0.024220141249575784, 0.059987123257347515, 0.07428391038307122, 0.04168516444042325, 0.14526190316038473, 0.07791766218308892, 0.017600032999845486, 0.05520411294751933, 0.09294144529849291, 0.013586533987628562, 0.042595297031636746, 0.031314587885779996, 0.04342453807060208, 0.021109982693035687, 0.0012773425966900373, 0.044448189570435455, 0.04490154256512012, 0.0500776417819517, 0.022937676137579337, 0.02121152206590133, 0.047289928155285973, 0.012922844467019396, 0.00471282731242744, 0.03829468101529138, 0.06847344538463013, 0.03629575416977916, 0.0496903238152819, 0.03530024151716914, 0.023262385678078448, 0.02002482538643692, 0.06701077494238104, 0.0353231013619474, 0.003129929582688159, 0.03908743383362889, 0.007106438046321273, 0.03246744602386441, 0.012974941537582448, 0.003135285768491615, 0.12272441679877893, 0.02591742026353521, 0.05412329826503992, 0.06753188983670302, 0.04698506576408233, 0.08885380106845073, 18.346456084932598, 45.11321169989449, 23.905206033161708, 52.50687667301723, 37.9308831351144, 1.194530827658517, 0.20060458992208752, 0.43101657181978226, 0.20875942733670982, 1.1119319455964225, 5.304266963686262, 9.76626113482884, 9.619807873453412, 2.33238867350987, 0.4773374434028353, 6.847144424915314, 44.29010725021362, 59.02676745823452, 57.125827176230295, 57.5068872315543, 54.395435265132356, 55.15703773498535, 52.63047817775181, 56.126182896750315, 53.440579073769705, 52.63144397735596, 51.766334193093435, 45.318385056086946, 40.78031505857195, 39.79217004776001, 45.38658162525722, 53.443983691079275, 51.774866580963135, 54.45275442940848, 48.04247842516218, 52.21328401565552, 51.191857133592876, 50.24030481066023, 45.92747456686837, 43.10878842217581, 40.94280563082014, 38.73142678397042, 39.37484386989048, 37.53893872669765, 38.22902338845389, 38.06808573859078, 38.46163170678275, 37.004483291081016, 37.174332005637034, 37.67595372881208, 38.3607508114406, 39.42865766797747, 40.0705565725054, 42.176420075552805, 41.50863218307495, 43.798115730285645, 43.74033798490252, 48.21155936377389, 52.67850065231323, 50.146719523838584, 44.88991396767752, 53.31987149374825, 53.780978270939414, 50.84127187728882, 51.70354332242693, 51.36896671567644, 48.09235954284668, 48.42730787822178, 50.44867433820452, 47.63283000673567, 41.36977243423462, 35.835726806095664, 35.649560247148784, 36.40777547018868, 35.75021185193743, 36.23969854627337, 36.631795815059114, 37.04351132256644, 44.44398900440761, 49.19326686859131, 50.398720264434814, 48.93267468043736, 45.56121417454311, 40.952619961329866, 36.73270797729492, 36.032947949000764, 36.56372083936419, 40.73564856392996, 47.03900221415928, 47.750160762241904, 47.307167938777376, 45.153879506247385, 45.05528804234096, 45.92135667800903, 47.16382312774658, 45.06695406777518, 40.724434171404155, 38.84232350758144, 44.78127540860857, 44.55596964699881, 46.80427122116089, 44.74726745060512, 46.4168188231332, 46.12247576032366, 48.66184779575893, 42.7208913394383, 25.442003386361257, 1.2618545293807983, 0.9806462760482515, 2.4376349917479923, 3.469868493931634, 6.264460674354008, 20.88268232345581, 15.382670709065028, 2.1120949515274594, 0.0802709369787148, 0.2685521910233157, 0.0143486730022622, 7.694575820650373, 53.23295995167324, 17.617612634386333, 30.46739224025181, 23.309693302427018, 0.06120715636227812, 0.06525874324142933, 0.0336655420916421, 0.0748979574335473, 0.025149817345663905, 0.04146366346893566, 0.03443980483072145, 0.027980814721169214, 0.02223161973857454, 0.05230517386059676, 0.03604699305391737, 0.03337548194187028, 0.022968055846701776, 0.023487791618598357, 0.027648766824443425, 0.05148711847141385, 0.00211542855166564, 0.08076285451118435, 0.02946966134810022, 0.015814941376447678, 0.01482379000767001, 0.12071744592062064, 0.024641401234215925, 0.10461797445480313, 0.10515128262341022, 0.14731719930257114, 0.14587984500186785, 0.07857193278947047, 0.17291129593338284, 0.14884421522063868, 0.16989478708377906, 0.09908268254782472, 0.23575568944215775, 0.15497543050774507, 0.1366576041494097, 0.1578494741448334, 0.0812827344717724, 0.10823735488312584, 0.103700724031244, 0.14326717305396283, 0.10651438483702284, 0.08468697180173226, 0.09397384990006685, 0.1329989568995578, 0.07715664444757359, 0.2685434514922755, 0.17843348532915115, 0.23023119302732603, 0.13119408089135373, 0.15765371679195336, 0.19925811860178197, 0.13758905631090912, 0.15335895653281892, 20.035716022763932, 53.378323214394705, 30.45342288698469, 53.05902917044503, 45.204625674656455, 3.3493743538856506, 0.8423963944826807, 2.5059753017766133, 1.0891843033688409, 7.30797370842525, 11.18043407372066, 12.580259851046971, 9.624386736324855, 1.1510899301086153, 0.335149344589029, 5.080512387411935, 44.457437242780415, 62.10404123578753, 60.87053448813302, 60.03754275185721, 57.34916312353951, 57.035907064165386, 55.266958236694336, 57.72034631456648, 54.74529790878296, 53.94866609573364, 54.362848213740754, 46.826561042240684, 42.899161270686555, 42.54360457829067, 48.895877020699636, 56.876699515751426, 53.997831548963276, 54.40457909447806, 49.082043579646516, 53.851398263658794, 54.0523818561009, 52.30038315909249, 47.913974966321675, 46.86608934402466, 43.37431035723005, 41.30289602279663, 41.878988538469585, 39.47322688783918, 39.110840116228374, 40.95562505722046, 39.82256146839687, 38.91056176594326, 38.02555928911482, 39.99008253642491, 40.666791915893555, 42.30588238579886, 42.556830474308555, 44.976749079568044, 45.33295890263149, 46.76973867416382, 45.63766867773873, 50.84028870718819, 56.10034254619053, 53.95609024592808, 47.779506478990825, 54.72814975466047, 56.057555539267405, 52.996471064431326, 54.26708814076015, 53.0463730267116, 50.92930555343628, 50.45130770547049, 52.34366001401629, 49.187621457236155, 43.58230815614973, 37.1433812550136, 37.878302642277305, 36.91530316216605, 38.46691928591047, 37.29145084108625, 38.48231301988874, 39.61971575873238, 49.24968276705061, 50.47000878197806, 51.584892409188406, 52.96940088272095, 46.5681540625436, 43.76674461364746, 39.25484848022461, 37.71722255434309, 38.23320272990635, 43.90169252668108, 48.993342876434326, 50.54257229396275, 49.34726674216134, 45.96837166377476, 47.02662399836949, 47.557195390973774, 48.41596841812134, 47.6600078855242, 43.429083006722585, 39.5952650478908, 46.135531425476074, 44.528499943869456, 47.717379161289756, 46.021886689322336, 47.66060890470232, 47.699560506003245, 50.95090055465698, 44.6057118007115, 24.43889716693333, 1.2663607618638446, 1.026092054588454, 4.704858464854104, 5.982854962348938, 10.384378092629568, 17.465257746832712, 14.547381724630084, 9.541638902255468, 0.8058144003152847, 0.7542362394077438, 0.13108428035463604, 11.836646267345973, 53.44609594345093, 23.59772218976702, 42.71652092252459, 26.21941474505833, 0.1290913958634649, 0.0847706962376833, 0.11354323410029922, 0.2005202073071684, 0.17453007692737238, 0.13975662285728113, 0.16052558911698206, 0.12381263769098691, 0.1711457206734589, 0.17732743253665312, 0.1209183329982417, 0.1465319442961897, 0.11988748902721064, 0.1603016589901277, 0.16522038648171083, 0.08490280022046395, 0.10319120530039072, 0.18902828038803168, 0.13090368147407258, 0.07136438454368285, 0.07780927299921002, 0.16096678615680762, 0.16478400704051765], [0.03830457744853837, 0.049668790506465096, 0.06483127296503101, 0.016391624896121875, 0.05073409387841821, 0.014082188551713313, 0.04570994579366275, 0.023593295332310454, 0.00850860182461994, 0.019322818145155907, 0.01726882139753018, 0.0978267142283065, 0.019567044950755577, 0.01945900351607374, 0.06280554737895727, 0.01687374777559723, 0.03151405682521207, 0.051869639195501804, 0.0015577573711717768, 0.005943490940678332, 0.05278549862227269, 0.011522950388358107, 0.027430700936487744, 0.03150778716163976, 0.008318672239381288, 0.04697770705180509, 0.05030748534149357, 0.01824429691103952, 0.003709564941735672, 0.08822736396853413, 0.5207236781716347, 27.16587403842381, 35.63352033070156, 24.748307398387364, 47.65472725459507, 14.817637988499232, 0.04854027820484979, 0.19148794268923147, 0.016909596476969973, 0.5023908561893872, 4.602985714163099, 5.746500262192317, 11.141815117427281, 4.7214937550680975, 0.40004497660057886, 0.02744737932724612, 7.185830456869943, 53.1206944329398, 53.880007471357075, 56.732920442308696, 53.250399930136545, 54.98211683545794, 52.59631041118077, 53.16183819089617, 51.91602965763637, 51.63407523291451, 47.52196455001831, 41.79153503690447, 38.87376758030483, 42.56906625202724, 49.82993030548096, 52.0515125819615, 51.92283889225551, 49.50826692581177, 51.282920224326, 52.76935182298933, 50.82481159482683, 46.24717160633632, 45.714474064963206, 43.578128814697266, 41.980397496904644, 37.377236774989534, 36.92527035304478, 37.073718615940635, 35.297800745282856, 35.78834009170532, 36.928935527801514, 35.77150460651943, 38.40086971010481, 37.42803505488804, 37.83302123206002, 39.62546191896711, 41.6557741846357, 43.18026801518032, 44.84431988852364, 43.62845114299229, 46.28555692945208, 47.21846376146589, 48.169154507773264, 48.32190023149763, 47.92570699964251, 50.30536079406738, 46.40535429545811, 45.84264748437064, 46.23643316541399, 45.627461774008616, 48.03779533931187, 48.19895185743059, 44.14093290056501, 41.684056827000205, 35.53646789278303, 35.27316243307931, 34.86917332240513, 34.78868538992745, 33.32539129257202, 35.828226225716726, 35.617841720581055, 46.24782126290457, 48.118835653577534, 47.081014496939524, 48.785240854535786, 50.397452218191965, 42.972899028233115, 41.43653072629656, 37.03178971154349, 34.40301867893764, 34.512800216674805, 41.234358991895405, 46.38350568498884, 46.13317251205444, 45.419554301670615, 46.01021718978882, 46.82349688666207, 46.128003052302766, 47.4588749068124, 43.14665263039725, 39.73945753914969, 35.763885906764436, 39.914972509656636, 42.783772536686485, 39.80296060017177, 41.45099687576294, 42.16733530589512, 45.52730001722063, 45.56423316683088, 35.60957683835711, 8.300828729357038, 0.07102922217122146, 0.7568362770336015, 2.340297677687236, 3.3094890883990695, 6.388610652514866, 2.6536588285650526, 2.2211415001324246, 1.5812044846160072, 0.06393688917160034, 0.10007594924952302, 0.04307165914880378, 21.474118198667252, 33.49228702272688, 18.456008332116262, 35.35329948152815, 5.327559930937631, 0.08076794352382421, 0.027388428204825947, 0.011860021140559443, 0.08505782511617456, 0.03426240524277091, 0.06318935392690556, 0.01674341137654015, 0.02297466986679605, 0.036030033071126254, 0.07161498109677009, 0.03676308159317289, 0.013331578695215285, 0.04550647349762065, 0.0976301154920033, 0.02361065904343767, 0.02082849752956203, 0.0868670776752489, 0.007864475316767181, 0.047268679831176996, 0.012887071252667477, 0.011745267298205622, 0.053396797605923245, 0.04058180203927415, 0.04441321448289922, 0.057640403110001764, 0.021438508993014693, 0.05001692646848304, 0.03454741709200399, 0.04228663484432867, 0.01427714862594647, 0.03320764969768269, 0.07677894471479313, 0.017612579112340297, 0.014673760826034206, 0.031719361165804524, 0.018571413554517285, 0.017234898039272854, 0.10060564761183091, 0.019408620594601547, 0.05158997420221567, 0.01512479831996773, 0.029219149611890316, 0.013362731086090207, 0.027451379291181053, 0.045457934495061636, 0.038773658884955306, 0.013610188566547419, 0.014848924641098295, 0.02625314242738698, 0.021174477446558218, 0.03307826664032681, 0.06951570910002504, 0.017907363562179462, 1.337966616664614, 38.52434614726475, 34.613653319222585, 31.93101637704032, 59.620741162981304, 12.812228066580635, 0.027446831410218562, 0.1365040245332888, 0.22391779108771256, 0.16022341033177717, 1.2636219773973738, 10.888797334262303, 15.954837492534093, 6.433093888419015, 2.541741805417197, 0.1658877528139523, 10.313829558236257, 56.25659016200474, 54.38588496616909, 58.367161069597515, 55.05941207068307, 57.13090978349958, 55.107243469783235, 54.815766538892476, 55.59927320480347, 54.29380396434239, 50.00903402056013, 45.253471510750906, 40.656331402914866, 43.225851672036306, 51.4099645614624, 53.859767368861604, 53.99234594617571, 50.297154971531455, 51.50161130087716, 53.40871116093227, 51.31084850856236, 49.20279632295881, 47.48970406396048, 45.89691986356463, 44.741514342171804, 40.37499189376831, 38.420710291181294, 38.04042843409947, 37.81978838784354, 38.5748039654323, 38.1260267666408, 38.5698116847447, 39.7241541317531, 39.402740887233186, 40.074555260794504, 41.82359402520316, 43.74123082842146, 44.75785303115845, 46.200153146471294, 45.56603969846453, 45.729881695338655, 49.429526465279714, 51.85240152903965, 51.13969700677054, 48.04833575657436, 53.41555513654436, 49.366457666669575, 47.71875837871006, 49.83234827859061, 49.02192429133824, 50.20685965674264, 49.01666103090559, 47.85298367909023, 43.36376646586827, 37.416667801993235, 35.79116800853184, 35.95606960569109, 35.961826188223704, 35.50539207458496, 38.69387871878487, 37.42136478424072, 45.00183555058071, 48.761981759752544, 49.516385895865305, 49.08124106270926, 50.00703293936593, 44.65853548049927, 43.11726869855608, 39.120334829602925, 36.60360697337559, 35.98468228748867, 42.44562455586025, 47.6959787096296, 47.09319816316877, 46.17119305474417, 46.86469970430647, 48.14138603210449, 47.573026861463276, 49.134780406951904, 43.90263748168945, 40.72058834348406, 37.43937798908779, 40.82683672223772, 43.632974420275005, 41.6437155859811, 43.13127974101475, 43.437545912606375, 48.487163134983604, 46.655121190207346, 38.89844410760062, 9.283272743225098, 0.6158124900289944, 1.44824994461877, 2.5373822450637817, 4.693162041051047, 5.147238109792982, 6.418741949966975, 2.7636247106960843, 0.9889320028679711, 0.019087605677278977, 0.08031398324029786, 0.021435229972537075, 24.014749595097133, 43.359503746032715, 15.661633934293475, 40.556763717106406, 8.201496413775853, 0.1693690445806299, 0.01989360519551805, 0.024858281382226517, 0.03876540789912854, 0.026337382549952184, 0.007502987481919783, 0.02339859988673457, 0.05448776317228164, 0.047598729442272864, 0.04399150496880923, 0.02042533068119415, 0.07163053990474769, 0.05950012510376317, 0.034682062188429494, 0.019718590658158064, 0.011226147296838462, 0.04891931465161698, 0.008649205306677945, 0.06657252952988658, 0.08448717716549124, 0.030754121353051493, 0.04400138104600566, 0.010221119038760662, 0.10313651537788765, 0.17606732515352114, 0.18331287136035307, 0.06309089849569968, 0.0832250884601048, 0.11842296618436064, 0.117654077442629, 0.11251519926424537, 0.1602591826979603, 0.11295284078057323, 0.14179176650941372, 0.1680632989321436, 0.10537034086883068, 0.05237443871530039, 0.21890432653682573, 0.10341841275138514, 0.11556880362331867, 0.12450093004320349, 0.1312284419046981, 0.0737196406615632, 0.13579579682222434, 0.12900051288306713, 0.1321051770022937, 0.10655870674444096, 0.07346283551305532, 0.1215048043855599, 0.12298074018742357, 0.087405807338655, 0.1303509468478816, 0.20511561286236557, 1.945448705128261, 44.25000919614519, 45.299871580941335, 34.08708756310599, 59.255071367536274, 21.486138582229614, 0.14202618678765638, 0.5786369134272847, 0.49094386185918537, 2.526727399655751, 12.767169867243085, 12.298015339033944, 16.884529045649938, 10.358177304267883, 1.6786340794392993, 0.1540836455034358, 9.575002414839608, 55.965207031794954, 56.032583713531494, 60.28755978175572, 56.659481457301546, 58.37958444867815, 58.77070549556187, 55.793989522116526, 56.86732292175293, 55.981604780469624, 51.69922154290335, 47.316516739981516, 42.649102551596506, 47.37500320162092, 53.779348918369834, 55.78796543393816, 55.245870453970774, 51.70905671800886, 52.23713023321969, 56.454912594386506, 55.15408475058419, 50.02261427470616, 48.96448700768607, 48.804122584206716, 46.757475103650776, 41.783700942993164, 40.674945626940044, 41.45711823872158, 39.43250696999686, 39.39982611792428, 40.59699378694807, 40.29742567879813, 44.096711090632844, 42.123613766261506, 43.12937593460083, 44.9438111441476, 46.35676901681082, 47.51073278699602, 49.50225673403059, 48.06460496357509, 50.026960372924805, 50.78464753287179, 51.42389917373657, 52.01405484335763, 50.88429512296404, 54.27376535960606, 51.67611183438982, 49.44923850468227, 51.589589391435894, 49.97077029091971, 51.27917167118618, 51.7393091746739, 48.96095037460327, 44.37130389894758, 39.36406026567732, 38.020970003945486, 37.15178162711007, 37.33117369243077, 37.868373666490825, 39.6027204649789, 40.89311211449759, 50.087722369602744, 50.03714643205915, 51.70741694314139, 49.65188619068691, 52.91653898784092, 45.24250030517578, 45.22931957244873, 40.44667993273054, 38.646280084337505, 37.10733052662441, 43.92272472381592, 50.06177084786551, 49.77885757173811, 47.79739114216396, 48.28522763933454, 48.213324206215994, 47.62344299043928, 49.775063855307444, 45.97984661374773, 42.47485910143171, 38.35511929648263, 42.24341113226754, 47.22011743273054, 43.37658589226859, 43.70372097832816, 43.787901878356934, 49.23796115602766, 47.29796852384295, 37.75921399252755, 10.102830137525286, 0.5821176352245467, 2.29363574726241, 8.252334645816259, 8.707282713481359, 16.807569061006816, 5.932095331805093, 7.7059812886374335, 5.525579682418278, 0.15048118095312799, 0.3716965706220695, 0.3699250785367829, 30.625606196267263, 45.45997197287423, 23.756224496023997, 47.91159520830427, 9.142158303941999, 0.524722583591938, 0.12764811116669858, 0.15282583156866686, 0.1382798185305936, 0.1151383952902896, 0.1684717634426696, 0.10288921650499105, 0.19479486452681677, 0.07901087709303413, 0.20188988452511175, 0.14066414987402304, 0.11418593568461281, 0.13397112116217613, 0.161983815154859, 0.132656866684556, 0.16344333040927136, 0.22124543519956724, 0.11319754086434841, 0.12532323306160315, 0.15459288603493146, 0.06818772785897766, 0.18383268346743925, 0.17033093582306588], [0.03810920686061893, 0.03723687545529433, 0.03183601151353546, 0.03906502860731312, 0.009138995631864029, 0.02322433004155755, 0.04353419611496585, 0.023803612350353172, 0.11754236343715872, 0.04510334227234125, 0.04664951662666031, 0.05495392351544329, 0.027248214032234888, 0.058177687493818145, 0.05099644265802843, 0.061427137415323935, 0.03174490800925663, 0.05618715073381152, 0.015532211101214801, 0.01858804784049945, 0.024793494858645966, 0.027186126381691014, 0.01835334936289915, 0.015004724763067705, 0.061411816094602854, 0.020137170429474542, 0.023759295531947697, 0.05355434665190322, 0.02415512572042644, 0.04529712848099215, 0.07432876154780388, 7.262754397732871, 38.23511348451887, 22.99855296952384, 36.17740447180611, 37.49821880885533, 2.573899805545807, 0.12480452018124716, 0.25826408022216385, 0.3528025187551975, 0.4597773370998246, 12.418460624558584, 14.82526363645281, 7.176604986190796, 3.3688104195254187, 0.5811575895973614, 0.09462098910340241, 15.279719250542776, 51.225368295397075, 55.971192904881065, 56.57168401990618, 55.152847971235005, 55.43879761014666, 54.08121688025338, 51.6050317628043, 49.45206989560808, 44.529107911246165, 41.67556960242135, 41.0389061655317, 47.08526679447719, 51.40467350823538, 52.13654811041695, 49.55347885404314, 52.57865156446184, 52.11609608786446, 53.41686487197876, 51.28353861400059, 48.61983551297869, 47.41570574896676, 46.35016475405012, 44.01992654800415, 40.9960218838283, 36.333363737378804, 37.24904251098633, 36.653269222804475, 34.39419099262783, 37.03799097878592, 35.998047147478374, 37.31549160821097, 36.45003093991961, 41.11357498168945, 44.5455265045166, 45.08963646207537, 47.21340199879238, 46.43637105396816, 46.761254923684255, 45.63212054116385, 47.32047373907906, 49.88826738085066, 50.926335198538645, 49.964343207223074, 50.0433338029044, 48.767154693603516, 44.41876356942313, 42.577515261513845, 41.66865961892264, 42.39959968839373, 41.954758644104004, 39.45808676310948, 35.13041516712734, 35.76026242119925, 33.97196633475167, 35.21903944015503, 34.7501402582441, 34.73725482395717, 34.90421308789934, 43.80100270680019, 48.43191800798689, 49.71903010777065, 50.47449037006923, 49.429793970925466, 46.01533106395176, 42.90390689032418, 40.58101987838745, 35.91613483428955, 34.70181206294468, 35.02854067938668, 43.44554328918457, 46.65858486720494, 45.34971100943429, 46.397725173405235, 48.670004980904714, 47.011014870234895, 47.214770793914795, 46.71014744894845, 45.53976508549282, 40.85765545708792, 39.28914131437029, 37.55076456069946, 38.971778869628906, 41.454380648476736, 42.23588970729283, 44.04243871143886, 47.37864405768258, 42.64097663334438, 20.74659490585327, 1.8010472250836236, 0.5761485355240958, 1.7147634093250548, 1.5923379957675934, 2.9324092652116502, 5.80287230014801, 8.488390139171056, 2.334775813988277, 0.10193583409168891, 0.034651402583611865, 0.051271558074014525, 4.108127628053937, 39.41516774041312, 21.504553045545304, 26.45105378968375, 25.30038172858102, 0.23038649612239429, 0.08851630453552518, 0.05054228899202176, 0.10683918597974948, 0.030410412832030227, 0.05056983751377889, 0.026310848438047936, 0.030646529447819506, 0.02193455201839762, 0.12943530455231667, 0.03421108763931053, 0.07571793986218316, 0.041684614827058146, 0.008050732331217399, 0.0578674544979419, 0.03717402954186712, 0.034081619765077314, 0.022847486959238137, 0.06760791968554258, 0.18506957138223307, 0.026074848869549375, 0.02237348275126091, 0.03478859897170748, 0.03749487482543502, 0.013188138088610555, 0.023456595971115997, 0.012048418084824724, 0.03658910521439143, 0.06398043076374701, 0.03738565782883337, 0.020539758826739023, 0.0051271704807212305, 0.10453661810606718, 0.0336621833432998, 0.0918127837191735, 0.025374068080314567, 0.03500936373269983, 0.048046800041837354, 0.016292012562709193, 0.07087576469140393, 0.03442801528477243, 0.10218154519264187, 0.029071117019546882, 0.014673886355012655, 0.020431423925661614, 0.09543283589716468, 0.04267333873680659, 0.00579036509485117, 0.07700407584863049, 0.011880822479724884, 0.04193152014964393, 0.024184231480051364, 0.025211650545575788, 0.07160229927727155, 0.06633107284350054, 13.125848906380789, 45.11124883379255, 21.943151133401052, 49.04995332445417, 42.987434659685405, 1.4655079671314784, 0.1110659231032644, 0.09818376614046948, 0.10640601600919451, 0.5940775477460453, 7.338517989431109, 11.688792943954468, 3.7810511674199785, 3.2680396097046986, 1.1213705305542265, 0.2126846709953887, 20.872400726590836, 55.14207478931972, 56.53658172062465, 58.2707965033395, 56.98015471867153, 57.41973597662789, 56.10085671288626, 52.8235581942967, 52.80812277112688, 46.52359873907906, 43.78333343778338, 42.745658193315776, 47.959395340510774, 53.66069800513131, 53.957893303462434, 50.0252754347665, 51.63132722037179, 52.30593129566738, 54.70128107070923, 53.974179880959646, 50.0550971031189, 49.37915897369385, 46.81620822634016, 46.275565419878276, 41.72293199811663, 37.990793977464946, 38.2491523197719, 38.29469428743635, 37.88301352092198, 38.092640672411235, 37.07657085146223, 38.18516983304705, 39.30372210911342, 42.856878008161274, 46.066289152417866, 44.98913771765572, 48.10437297821045, 49.16263573510306, 46.26345470973423, 47.81602273668562, 49.774824142456055, 50.4981872013637, 52.839948994772776, 50.46641308920724, 52.46556963239397, 50.9321334702628, 46.1319009917123, 44.85248749596732, 44.385405267987935, 45.62021827697754, 45.735919679914204, 40.8612824167524, 36.683806555611746, 36.66446624483381, 36.374097551618306, 36.81844874790737, 35.9263208934239, 36.653199740818565, 36.47011470794678, 44.69643790381295, 51.112449645996094, 50.0526374408177, 52.28635474613735, 51.64308704648699, 48.16824776785714, 43.92618145261492, 42.61327416556222, 38.96352440970284, 36.192429951259065, 36.38980048043387, 44.91950634547642, 48.72838027136666, 47.676527227674214, 46.1207526070731, 48.8799934387207, 47.572613443647114, 48.6084508895874, 47.683524063655305, 47.543629033224924, 42.29332004274641, 39.87315130233765, 39.905512537275044, 40.599373544965474, 42.616439070020405, 43.94056074959891, 45.96136787959507, 47.47005803244454, 42.526397364480154, 23.63619957651411, 2.5784022382327487, 1.8085495425122124, 2.7710783907345364, 3.103960071291242, 4.375198577131544, 4.475152322224208, 5.390657825129373, 1.3073560020753314, 0.09634665971887962, 0.036326135575239143, 0.04945845143603427, 3.251193485089711, 46.140624455043245, 24.31743744441441, 23.944253172193253, 33.04346466064453, 0.40611078111188753, 0.1402862872928381, 0.06352826181266989, 0.010912156913296452, 0.031907746235706975, 0.024834642918514352, 0.03216213919222355, 0.02168139908462763, 0.032250976389540095, 0.009520932815835943, 0.026345438456961086, 0.019602732500061393, 0.014810205736596669, 0.023627052449488213, 0.06415078376552888, 0.03839218310479607, 0.02422002250594752, 0.06271549899663244, 0.06239951880914824, 0.028758902701416185, 0.032412830740213394, 0.025103073068229214, 0.045318970523242436, 0.015874923872096196, 0.13321786586727413, 0.10238703952303954, 0.12131303681858949, 0.09720821598810808, 0.12508300452360085, 0.12729886919260025, 0.17544144445231982, 0.11380269232073001, 0.24593762308359146, 0.11978199040251118, 0.21549266603376183, 0.16673505306243896, 0.17191640074763978, 0.14341148388172897, 0.1318336815706321, 0.2418452426791191, 0.12189401207225663, 0.18763404020241328, 0.0732611816908632, 0.09136360032217843, 0.08890356482671839, 0.1680905217570918, 0.13047768361866474, 0.09918797761201859, 0.17455679763640675, 0.16127832872526987, 0.15143115712063654, 0.2533728741109371, 0.07084069121629, 0.13497761929673807, 0.16613628662058286, 17.621809346335276, 55.381332533700125, 31.411728858947754, 45.986701011657715, 51.349904332842144, 4.25425215278353, 0.43883530369826723, 0.7819311618804932, 0.9110741806881768, 4.739984214305878, 26.56591272354126, 28.236311776297434, 15.332935503550939, 6.537104512963976, 1.5397951751947403, 0.14631222108645098, 19.237500020435878, 55.23627151761736, 59.45588820321219, 58.53940691266741, 59.39605726514544, 58.388068199157715, 58.268958704812185, 55.656151158469065, 55.05164745875767, 49.38737521852766, 44.201576777866904, 44.36055156162807, 50.87109007154192, 55.98960215704781, 55.6340663092477, 50.80896970203945, 53.373417786189485, 55.04410866328648, 56.41117715835571, 56.764673709869385, 52.28732401984078, 52.705567359924316, 49.81564480917794, 49.2428492137364, 45.16697686059134, 39.62398542676653, 41.48482765470232, 41.85164042881557, 39.225867543901714, 41.834433215005056, 38.51397248676845, 39.64485086713518, 40.120826789310996, 45.43953037261963, 48.18625055040632, 46.92648656027657, 51.14438704081944, 50.928322383335654, 49.91081428527832, 49.82560505185808, 51.15923534120832, 54.06138672147478, 54.37083169392177, 52.08318941933768, 53.36568791525704, 54.39307287761143, 47.85206651687622, 46.616298130580354, 45.612874031066895, 47.85656200136457, 46.30800308500017, 43.95408541815621, 38.192472389766145, 39.49284512656075, 38.07675014223371, 39.423543793814524, 38.14233071463448, 38.063836915152415, 37.66046619415283, 46.16468606676374, 51.67463534218924, 52.15900468826294, 54.420122214726035, 53.67887101854597, 48.58353464944022, 46.18042721067156, 44.68624142238072, 40.8622864314488, 37.02690512793404, 37.530468872615266, 48.377541405814036, 51.10910408837454, 49.962168421064106, 47.52050542831421, 49.53157465798514, 48.89648151397705, 50.40394878387451, 50.51650265284947, 49.4219251360212, 44.571992192949565, 41.64154427392142, 41.47864375795637, 41.70767027991158, 45.14586475917271, 45.52321795054844, 47.85043716430664, 49.60953344617571, 43.78182567868914, 23.299411705562047, 2.5830816328525543, 2.4810788205691745, 5.70579684632165, 4.5101039324487955, 6.93788572720119, 14.264640416417803, 18.41151033129011, 8.048089742660522, 0.3605571155037199, 0.23139669905815805, 0.1396743572716202, 7.067876100540161, 51.74334955215454, 30.10856294631958, 35.13383715493338, 37.75384303501674, 0.7072281475578035, 0.2702848980469363, 0.12179798579641751, 0.1721313606415476, 0.08903807082346507, 0.1849820946476289, 0.12055940154407706, 0.17538556030818395, 0.0997808679406132, 0.16462442917483194, 0.22299471204834326, 0.1549993556525026, 0.18530762860817568, 0.10449338185467891, 0.21126733347773552, 0.08359672887516872, 0.13628663548401423, 0.10899332431810242, 0.10089838118957621, 0.32635373941489626, 0.0864516921075327, 0.1184682651822056, 0.14941503959042685, 0.07724034852747406], [0.032258531876972744, 0.02723797324246594, 0.05993450965200152, 0.04889310284384659, 0.07148995423423392, 0.0356319501463856, 0.038944361332271776, 0.036873787974140475, 0.049236136222524304, 0.05870443422879491, 0.05274193328140037, 0.020702434204784886, 0.03447894612327218, 0.030423763008522134, 0.062293769126491885, 0.024750806524285247, 0.04243946807192905, 0.049179393731589825, 0.02439526265620121, 0.09482109586575202, 0.043768334801175764, 0.053283804561942816, 0.01529063397486295, 0.060749436994748454, 0.024949101598135064, 0.05940659583679267, 0.018923479930630753, 0.05060747924393841, 0.013139967191299158, 0.06534970086067915, 0.12993309141269752, 1.2705426003251756, 28.200592824390956, 35.44486631665911, 25.73899371283395, 46.36328642708914, 20.21988844871521, 0.43454875371285845, 0.028180702655975307, 0.030846588712717806, 0.1529147196561098, 5.760110914707184, 7.413458653858729, 1.4986672678164072, 3.92682307107108, 0.648907085614545, 0.04643036338633724, 0.3917921722999641, 20.70639783995492, 48.83231142589024, 53.28443915503365, 53.144985335213796, 56.47435017994472, 51.88409226281302, 53.59407867704119, 47.053120953696116, 44.85847684315273, 42.943212849753245, 44.324632849012104, 50.0750766481672, 54.119838442121235, 52.001148564474924, 49.84167276109968, 49.61452920096261, 49.253907271793906, 52.40065261295864, 51.29916511263166, 49.66062355041504, 49.49780641283308, 47.83557844161987, 47.08067403520857, 41.93763828277588, 37.31204530170986, 37.997926303318565, 36.18606192725045, 36.87833874566214, 36.49560417447771, 38.205291816166465, 37.315762587956016, 38.11190455300467, 43.66622502463204, 46.99993944168091, 46.557568481990266, 46.99819196973528, 48.89814213344029, 48.1967944417681, 47.79354531424386, 49.988217217581614, 48.882783140454976, 48.99355132239205, 51.533621651785715, 49.445166860307964, 48.403927189963206, 47.32912424632481, 40.476876803806846, 37.26329674039568, 39.11063167027065, 37.96689912251064, 35.29381595339094, 36.620588370731895, 34.26565626689366, 35.94647066933768, 34.6744361604963, 35.91758353369576, 37.07064751216343, 44.030546869550435, 49.087101868220735, 51.22095966339111, 50.61586536679949, 50.51182304109846, 50.5363883972168, 45.37217800957816, 42.35699680873326, 40.26995250156948, 36.921938691820415, 36.554868834359304, 34.803446837833945, 43.309546198163716, 47.16344445092337, 44.698817661830354, 47.78738921029227, 48.17236804962158, 46.95710032326834, 47.697594165802, 44.91009848458426, 44.53077547890799, 41.01373979023525, 38.944371700286865, 38.974151679447715, 42.64216130120413, 40.65561573845999, 43.586685521262034, 44.79703392301287, 47.23269714627947, 31.71025821140834, 9.74018280846732, 0.07921544183045626, 0.884173252752849, 1.8133756092616489, 1.350090137549809, 2.5933289229869843, 1.1169014275074005, 2.4102999099663327, 0.9380491503647396, 0.10902996520910944, 0.04424166725948453, 0.7330633955342429, 22.43598164830889, 33.69504240580967, 18.05276788984026, 38.80994490214756, 8.681254761559622, 0.08015899905668837, 0.0312459065711924, 0.02505376562476158, 0.015333885493289148, 0.055796433306698284, 0.03620517992281488, 0.022396573297945515, 0.09283539706042834, 0.035600265953689814, 0.00528352233647768, 0.06832621007093362, 0.009612052435321468, 0.02727246657013893, 0.01697702250177307, 0.033365833173905096, 0.010028449868384217, 0.024759890411847403, 0.06940564393465008, 0.04167092199038182, 0.008077847438731363, 0.08157041296362877, 0.03020384980897818, 0.0190286070574075, 0.007974280094328736, 0.0636527594178915, 0.06109434991542782, 0.05770781556410449, 0.051928624244672913, 0.05526193770180855, 0.057591148252998076, 0.033763559867760966, 0.037202249813292704, 0.03358236726905618, 0.011798284631887717, 0.032842933732484064, 0.02369851915032736, 0.06774161822561707, 0.023134841450623105, 0.018415628699585795, 0.02081460282871766, 0.03811626362481287, 0.03543310545917068, 0.027778219431638718, 0.06009608919599226, 0.040056341128157716, 0.06247313307332141, 0.04999316417212997, 0.07740413331027542, 0.02703527786902019, 0.049257445614784956, 0.042074945489210744, 0.05355563586843865, 0.036489319854549, 0.06892135313579015, 0.005524942975690854, 1.980665649686541, 39.61239930561611, 34.391161578042166, 28.165530477251323, 58.74273899623326, 18.7292149748121, 0.23305506578513555, 0.03438351695824947, 0.06737088704747812, 0.17060214627001966, 0.2545673128749643, 5.228921566690717, 4.04803352696555, 5.192107404981341, 2.4081099246229445, 0.27691168817026274, 1.0754141679831912, 26.055807249886648, 51.6376952443804, 55.13931288037981, 55.25959314618792, 59.12270123617989, 53.17890991483416, 56.26975005013602, 47.630967889513286, 46.15282549176897, 44.37276649475098, 45.66017041887556, 51.88622188568115, 55.333070346287315, 53.7293427331107, 51.47405821936471, 51.36557946886335, 50.49748543330601, 53.560939243861604, 52.004115445273264, 51.50225053514753, 51.40545865467617, 51.37685292107718, 48.11792196546282, 43.78014074053083, 39.27662066050938, 39.28419072287423, 38.79964419773647, 36.83405787604195, 37.714603083474294, 39.18497044699532, 40.08919511522566, 39.2671537399292, 45.61139406476702, 47.760520526341026, 48.0131014415196, 50.04355614525931, 50.84217514310564, 49.1232533454895, 50.01141030447823, 50.10253592899868, 51.65081344332014, 50.80346325465611, 52.01458638054984, 51.92981835774013, 49.6495863369533, 46.858574867248535, 41.95789575576782, 39.767083576747346, 40.53189958844866, 38.93424817493984, 37.20700590951102, 38.42837068012783, 36.08601481573922, 37.07001175199236, 36.87566021510533, 37.540449959891184, 37.30672992978777, 44.4310097694397, 51.34943185533796, 52.849294321877615, 51.79239688600813, 51.984750815800254, 51.22779321670532, 47.52955545697893, 43.859308515276226, 40.800701073237825, 39.442324774605886, 38.65867567062378, 38.64343132291521, 44.1018944467817, 48.19289650235857, 45.50332178388323, 47.38268790926252, 48.73944180352347, 49.086365359170095, 47.22649935313633, 46.565388679504395, 45.5676725251334, 41.78792197363717, 40.62146881648472, 40.74218334470476, 42.814157009124756, 42.63381651469639, 45.2806077003479, 47.299681254795615, 48.31982272011893, 35.53498445238386, 11.223247136388506, 0.857678088758673, 2.430301602397646, 2.4772429806845526, 3.1682977846690585, 4.56881707906723, 4.013945230415889, 2.105589483465467, 0.19201223312744073, 0.07250232848205737, 0.07731152006558009, 0.5079171710780689, 23.504150799342565, 42.901871068137034, 18.947299821036204, 40.612099170684814, 13.819690806525093, 0.1690780751939331, 0.008028113366370755, 0.020945683919957707, 0.0419435336121491, 0.023837890243157744, 0.05361026133011494, 0.03827619093603321, 0.06248964183032513, 0.05955345795622893, 0.021404234492885213, 0.0677375877276063, 0.043267986471099515, 0.03429004875943065, 0.030619710351207426, 0.02383290640344577, 0.021195790231493965, 0.039814378933182785, 0.03166453892897282, 0.05596548352124436, 0.050930892782551904, 0.03847804831873093, 0.03200903794329081, 0.010272014254171933, 0.021638963504561355, 0.12683840175824507, 0.20271465741097927, 0.12782705442181655, 0.14941182333443845, 0.1645521516246455, 0.14636397973767348, 0.14386348319905146, 0.1473766661116055, 0.1173516543848174, 0.09989124523209673, 0.10710276969309364, 0.059313819743692875, 0.1436553086553301, 0.11261303722858429, 0.1138467224580901, 0.11877184174954891, 0.11826915586633341, 0.1068650313786098, 0.10642410575279168, 0.1713117446218218, 0.1480686225529228, 0.21296122829828942, 0.10083972862256424, 0.20772749770964893, 0.15243088347571238, 0.16401733032294682, 0.1212826520204544, 0.22225828442190373, 0.12827711312898568, 0.22663579881191254, 0.47300290742090767, 3.133198742355619, 47.54712050301688, 46.4478668485369, 35.2179068837847, 55.12965835843767, 29.53204311643328, 1.113891554730279, 0.20769125036895275, 0.2568316385149956, 0.447692655559097, 11.43041375705174, 17.41175661768232, 7.7632900306156705, 10.521483421325684, 2.9228554921490804, 0.2708042487502098, 0.7988538252455848, 23.29911814417158, 51.12540108816964, 54.7565644127982, 56.055231366838726, 61.270292145865305, 55.034391607557026, 57.90566866738455, 49.55198846544538, 48.23490878513881, 47.25629322869437, 47.76990059443882, 54.18765980856759, 58.3368877683367, 54.30368430273873, 52.17653846740723, 52.69025353022984, 51.772431237357004, 55.571657589503694, 54.44047348839896, 52.00214563097273, 53.149880341121126, 52.39510795048305, 50.45836707523891, 45.98405374799456, 41.63988018035889, 42.29577970504761, 41.41427912030901, 40.893219811575754, 39.85583291734968, 41.47211592538016, 42.1404527255467, 41.20978321347918, 47.59671674455915, 49.903511728559224, 49.675343309129985, 51.78978088923863, 53.61442995071411, 51.24203354971749, 53.25570487976074, 54.5535033089774, 52.56901788711548, 50.46938344410488, 53.46612759998867, 53.804091453552246, 51.24913113457816, 50.13434130804879, 44.312303270612446, 41.70513766152518, 41.86101354871477, 42.162405558994834, 38.46141283852713, 40.84428364889962, 38.20108468191964, 38.76379844120571, 38.69022396632603, 39.13972725187029, 40.62575238091605, 47.92131573813302, 53.20419093540737, 55.50745276042393, 53.46796192441668, 54.10409729821341, 53.73408487864903, 48.32358864375523, 45.3652263368879, 42.7686185155596, 38.89757210867745, 41.12592887878418, 39.79005432128906, 46.53007793426514, 49.822888306209016, 48.48089585985456, 47.540790694100515, 50.49391058513096, 49.496969154902864, 49.97246217727661, 48.38753291538784, 48.46508870806013, 44.79034628186907, 43.80211789267403, 41.9242456299918, 47.30163369859968, 44.451253346034456, 47.681390966687886, 48.03982073920113, 50.50614288875035, 33.02447523389544, 11.968498757907323, 0.5052783212491444, 2.904374803815569, 4.633352381842477, 6.040576687880924, 6.750321711812701, 7.161913888795035, 13.109859364373342, 1.684936638389315, 0.3504619800618717, 0.10531501312341009, 1.3829108221190316, 31.02951887675694, 44.237884589603965, 26.188319819314138, 51.06371150697981, 14.843247311455862, 0.26083545652883394, 0.12151469742613179, 0.12556038105062076, 0.07401890853153807, 0.10729364837918963, 0.10628938941018921, 0.08685247560164758, 0.14460261139486516, 0.22641555991555962, 0.08216783590614796, 0.13990452992064611, 0.10670256295374461, 0.1340073820735727, 0.1527341886290482, 0.09821953172130243, 0.13687017560005188, 0.1115459119901061, 0.09602124110928603, 0.12907868011721543, 0.21383092020239147, 0.10067500746143715, 0.19354668578931264, 0.10795778488474232, 0.09509231988340616], [0.05066100887155958, 0.053095378779939244, 0.06444610256169524, 0.02180002396926284, 0.02033811348623463, 0.08235836175403424, 0.04172080788495285, 0.03002327467714037, 0.010173758990796549, 0.05916488130709954, 0.0383636507072619, 0.03489746652277453, 0.06752896535077266, 0.04897639641006078, 0.02754995007334011, 0.03125420166179538, 0.05818260008735316, 0.03738954922716532, 0.07559914195111819, 0.05099579126441053, 0.06603384057858161, 0.03083788650110364, 0.024692325287365487, 0.019245024105267863, 0.054228440658854585, 0.027659501248438443, 0.0566898434023772, 0.026974258911130682, 0.04245855186932853, 0.07466284504958562, 0.025227701291441917, 0.06106080314410584, 10.694465773446218, 41.818747656685964, 31.31281430380685, 31.366478715624126, 45.32432229178292, 11.854508348873683, 0.2911163573818547, 0.049176292826554606, 0.08236946258693933, 0.34992642594235285, 3.4178612274782996, 2.3025813358170644, 2.687756678887776, 2.228900249515261, 0.30221947016460554, 0.012656770530156791, 2.469566306897572, 27.830140931265696, 50.66664627620152, 57.00087424686977, 58.05521127155849, 57.87384244373867, 52.2687132699149, 49.207093783787315, 47.114268575395855, 41.94114364896502, 46.41152776990618, 50.941246032714844, 54.85638918195452, 53.271004813058035, 51.08907243183681, 51.45090682165963, 51.85337775094168, 51.40569836752755, 52.364188466753276, 51.63829278945923, 51.39037411553519, 50.214259488242014, 49.97222246442522, 46.960994788578574, 37.909149169921875, 37.84188713346209, 38.88527032307216, 37.42607913698469, 38.532597133091514, 37.56145783833095, 38.11281476702009, 40.28888981682913, 46.39493547167097, 46.704436029706685, 48.550423009055, 48.79247392926897, 50.907432624271934, 50.52703264781407, 50.392571108681814, 49.0824431010655, 51.762252126421245, 50.178208759852815, 48.2929470879691, 50.84001772744315, 51.4244168145316, 50.54685238429478, 49.23687376294817, 41.35628250667027, 36.32939979008266, 36.964927196502686, 36.45217445918492, 34.488842827933176, 36.39784302030291, 34.740093163081575, 35.073915890284944, 34.851347718920024, 42.20502928325108, 49.27467891148159, 48.416378361838206, 50.484395027160645, 49.08246741976057, 51.0770902633667, 47.44050734383719, 44.877431528908865, 41.12366724014282, 40.211278438568115, 37.93540988649641, 35.006917885371614, 35.136463574000764, 43.88572556631905, 47.46729959760393, 47.47519622530256, 47.80003145762852, 49.17071301596505, 46.69786998203823, 46.22778613226754, 44.527537618364605, 43.55928182601929, 40.84542315346854, 39.02610336031233, 43.264542715890066, 41.67138678686959, 45.60092312949044, 43.13310364314488, 47.288928917476106, 40.07228667395455, 19.44710632732936, 1.6162029951810837, 0.39285956216709955, 2.895571219069617, 2.1089984433991567, 2.0403637034552435, 3.4511298537254333, 2.480408319405147, 0.8997130617499352, 0.03810331717665706, 0.06450913846492767, 0.20252674392291478, 8.66285332611629, 38.28686714172363, 26.364738055637904, 23.296945095062256, 25.479396854128154, 0.5664231202432087, 0.13361079192587308, 0.11996018726910863, 0.0666900450097663, 0.036971890567136664, 0.12410746115658965, 0.023298246253814017, 0.0070168960207541075, 0.03105405079466956, 0.0328251968270966, 0.014518810569175651, 0.05729136469640902, 0.053083331390683136, 0.09228260815143585, 0.035671501952622614, 0.049025675015790124, 0.02532261816252555, 0.01123008195177785, 0.06856567186436482, 0.031092744254107987, 0.05440314646278109, 0.036138486715831926, 0.04161262565425464, 0.019492787774652243, 0.003157643285313887, 0.006483760454492378, 0.10549258573779038, 0.028551026713103056, 0.016238688191931163, 0.03435539168172649, 0.017262675566598773, 0.017716147304911698, 0.022077378550810472, 0.0364574931694993, 0.014319636792476689, 0.04750643510903631, 0.046088605653494596, 0.09030454286507197, 0.010209941870665975, 0.06552925479731389, 0.026887428481131792, 0.04725241534677999, 0.025944480240078907, 0.036772896602217636, 0.05080063780769706, 0.034298408310860395, 0.030214244965463877, 0.029895886512739316, 0.03185099356674722, 0.027186460560187697, 0.013769358463053192, 0.04839099032272186, 0.03187646237867219, 0.04036204829545958, 0.017517350115148083, 0.1128094799018332, 0.06390534407858338, 17.015438318252563, 50.091880866459434, 27.997392756598337, 38.86392198290144, 53.87655421665737, 10.275178466524396, 0.2020249401352235, 0.09778775953288589, 0.026870232707421695, 0.07755136183862175, 0.698344169982842, 2.150251852614539, 4.867218324116298, 4.24230385678155, 1.5771555304527283, 0.2596333638897964, 3.953593611717224, 32.171945163181846, 52.34631075177874, 58.28665229252407, 60.13214247567313, 57.872518811907085, 52.58293512889317, 50.63293709073748, 49.24996416909354, 44.56540182658604, 48.07091045379639, 53.86905711037772, 55.132910115378245, 54.11489827292306, 51.15268666403634, 52.86435801642281, 51.70327581678118, 53.379549571446006, 53.33794723238264, 53.39591605322701, 52.17675733566284, 52.176493304116384, 52.5066682270595, 47.608747550419395, 40.53527293886457, 39.82964515686035, 39.71997479030064, 39.061191763196675, 39.336361271994456, 38.89597749710083, 38.849177905491416, 41.31396797725132, 48.61699717385428, 48.73905617850167, 50.1709200995309, 51.999776295253206, 51.91107211794172, 51.81270299639021, 52.43122468675886, 51.34358147212437, 53.77272381101336, 51.906111104147776, 48.939060074942454, 52.95551838193621, 52.36413982936314, 51.50254235948835, 49.06620168685913, 43.366114956992014, 38.097587789808, 38.40171044213431, 38.346371514456614, 35.89468574523926, 39.33692407608032, 37.13770110266549, 36.54082652500698, 35.59291158403669, 41.85973508017403, 50.13165235519409, 48.91995252881731, 51.2683151108878, 49.516865321568076, 52.36034958703177, 50.1624641418457, 46.44904456819807, 43.05336611611502, 42.38497025626046, 39.571818351745605, 36.640963963099885, 36.76772689819336, 44.65001698902675, 49.27913965497698, 48.80916002818516, 48.975788252694265, 49.599677426474436, 48.05822651726859, 45.96044724328177, 46.75396973746163, 44.58488457543509, 41.89753328050886, 40.95120252881731, 45.09694596699306, 42.895242486681255, 46.4508649962289, 45.58724907466343, 48.22425372259957, 40.5882112639291, 21.814440965652466, 2.673131589378629, 1.1379953984703337, 2.4403853927339827, 3.4783474675246646, 2.9190094470977783, 4.42661828654153, 1.1475092193910053, 0.1512722306485687, 0.04365393040435655, 0.024131824827886054, 0.1077633099630475, 9.439180765833173, 43.05086129052298, 29.17554841722761, 22.998440061296733, 34.12964875357491, 1.3150803361620222, 0.09784016957772629, 0.06268862900989396, 0.055589527623461824, 0.0837765745818615, 0.0026054226493995103, 0.05725622336779322, 0.034908577533704896, 0.046136740927717516, 0.04345115699938365, 0.03152653169152992, 0.022094296125162925, 0.028585089171039205, 0.0950374738978488, 0.023652370287371532, 0.029848833501871144, 0.019545199515830194, 0.03353495802730322, 0.07255866724465575, 0.012382286999906813, 0.06869974359869957, 0.021344146824308803, 0.030277671026332036, 0.049043483167354546, 0.09630932672215359, 0.1845219936221838, 0.1927197008792843, 0.2392359769770077, 0.14033833092876843, 0.1532568505832127, 0.15369947254657745, 0.1793409852044923, 0.0958611611276865, 0.13867271744779178, 0.07060424211834158, 0.11438001027064663, 0.15047758471752914, 0.17646436313433306, 0.19357392218496117, 0.1302930135279894, 0.08901699552578585, 0.26016699096986223, 0.10110284414674554, 0.15698416557695183, 0.16732323435800417, 0.128537209172334, 0.11113166636122124, 0.09807397917445217, 0.07810641026922635, 0.2251371049455234, 0.11565231771341392, 0.1454644865755524, 0.11414865697068827, 0.1571845912507602, 0.16523775697818824, 0.2759199413870062, 0.15904957189091615, 19.70380057607378, 56.99845279966082, 39.95059592383248, 41.237100056239534, 56.42554950714111, 17.772415024893625, 0.7759550596986498, 0.25800976529717445, 0.23139368636267527, 1.0632562318018504, 9.463269301823207, 8.073620898383004, 8.385267581258502, 8.078005211693899, 1.31117316867624, 0.15545879171362945, 3.7875638008117676, 30.215554782322474, 54.314982073647634, 59.8473288672311, 61.91170815059117, 61.09104946681431, 55.767207690647666, 53.34720570700509, 50.47288533619472, 46.4187365259443, 49.967285769326345, 55.977644307272776, 58.47861017499651, 55.5456782749721, 52.57124478476388, 54.88397700445992, 53.29899215698242, 55.558528968266074, 54.67965480259487, 56.385659899030415, 54.12724869591849, 53.587318079812185, 54.183807032448904, 51.10345867701939, 42.19800118037632, 42.90524441855294, 42.92199305125645, 41.84140920639038, 41.753292151859824, 41.304289136614116, 41.01782185690743, 43.04482678004673, 50.97062996455601, 49.892425877707346, 52.15444319588797, 54.59229857581002, 55.24070446831839, 54.57884338923863, 55.503992557525635, 52.70059592383248, 55.5749579838344, 52.68371180125645, 49.9359632900783, 54.38892132895333, 55.26783718381609, 54.20864336831229, 52.54063449587141, 46.90634373256138, 40.204604693821494, 40.5706080027989, 40.874080998556956, 38.789690903254915, 40.91744123186384, 39.2330276625497, 37.468966892787385, 37.0190988268171, 45.24629054750715, 52.32394102641514, 49.936748436519075, 53.275225843702046, 51.16108356203352, 52.95953096662249, 52.27361522402082, 48.1622063091823, 45.974413122449604, 44.339373452322825, 41.572381905147004, 38.84745822634016, 38.12418549401419, 46.47641352244786, 51.33732809339251, 50.60802085059029, 50.57315479006086, 50.53411981037685, 49.55419104439871, 48.15520599910191, 48.229284218379426, 46.438201904296875, 44.89494446345738, 43.536401408059255, 48.1279273714338, 43.99387080328805, 49.522680963788716, 47.66498626981463, 50.76764529091971, 39.870979990277974, 22.996128048215592, 2.4068149541105543, 2.282469774995531, 7.575490644999912, 5.484486298901694, 8.361207706587654, 11.718930755342756, 7.76033878326416, 2.027067456926618, 0.2534675975995404, 0.20449336910886423, 0.3864171435790402, 14.02813936982836, 50.13528626305716, 35.22503226143973, 30.85605709893363, 37.5928567477635, 1.3618109886135374, 0.24389341420360974, 0.23053881366338047, 0.1776415535381862, 0.2018752553101097, 0.18617072515189648, 0.1121051266257252, 0.1383692223046507, 0.13113451908741677, 0.12327510224921362, 0.14630749848272118, 0.13572589414460318, 0.14517874190849916, 0.19527621726904595, 0.14716313114123686, 0.13738027108567102, 0.093098234385252, 0.07256509297128234, 0.1486313452145883, 0.13777330570987292, 0.12592023531241076, 0.1229045135634286, 0.08785047169242587, 0.10267298096524817, 0.16459187306463718], [0.0183565384774868, 0.04844436388728874, 0.03214547437216554, 0.01704891667967396, 0.04258903754608972, 0.041138519666024616, 0.03434080657150064, 0.02816869258614523, 0.010707388615368732, 0.02228535123036376, 0.06071308108844927, 0.0021998925907869954, 0.020374550816736052, 0.008520757779479027, 0.020985077966802886, 0.018102170966033424, 0.024999101147321717, 0.04573408467695117, 0.014307277277112007, 0.014943290202479278, 0.04915220144071749, 0.038540911195533614, 0.043123655287282806, 0.00462085273881842, 0.022058555989393165, 0.040084591933659146, 0.035947404469230344, 0.06147667047168527, 0.018984453087406497, 0.06037864474845784, 0.018809733712779622, 0.012172389825406884, 0.40473826761756626, 23.407761914389475, 35.51628337587629, 29.175826345171245, 34.764557770320344, 37.688964230673655, 11.149947115353175, 0.7037180587649345, 0.05396495533308812, 0.18021734032247747, 1.2010660426957267, 1.9178320041724612, 4.635138068880353, 2.50388736810003, 1.0015006427253996, 0.4688206346971648, 0.07662668145660843, 4.42955172913415, 29.000234944479807, 50.676488399505615, 59.38876165662493, 54.22458948407854, 57.75871426718575, 51.284254278455464, 49.680172307150706, 47.626302174159456, 46.25401905604771, 51.854746546064106, 54.27537734167916, 51.87767907551357, 53.793842860630576, 52.35053873062134, 52.15290069580078, 50.962194851466585, 51.92595168522426, 52.230223723820274, 53.64781257084438, 51.84051316125052, 51.11160543986729, 49.307939938136506, 40.33381339481899, 37.27182218006679, 38.012670380728586, 38.325961181095664, 37.28625358854021, 36.731012616838726, 39.08364486694336, 40.982976640973774, 45.82203912734985, 46.858727727617534, 49.847078459603445, 48.947755745479036, 51.91191979816982, 50.8185373714992, 49.592763968876426, 50.267236028398784, 51.68221582685198, 47.391762256622314, 48.93435614449637, 47.97779764447893, 51.348198550088064, 48.74563264846802, 49.27761452538626, 47.42016996656145, 40.26773950031826, 37.230695792606895, 36.598892620631624, 36.02803904669625, 35.10519320624215, 35.48881714684622, 36.08484404427664, 38.79115697315761, 47.75687272208077, 50.66998488562447, 49.08443375996181, 50.32251589638846, 51.65845993586949, 48.782041209084646, 44.72193431854248, 41.379319259098594, 39.98126179831368, 41.047667843954905, 38.39060027258736, 36.16830580575125, 34.86038385118757, 45.31486579350063, 47.87961612428938, 47.25439984457833, 49.030248233250205, 48.52765376227242, 47.84946094240461, 44.72139235905239, 41.594171455928254, 41.746159826006206, 41.77299724306379, 42.32976334435599, 43.23804923466274, 47.092805589948384, 44.39014393942696, 46.801068101610454, 42.67333092008318, 24.88830144064767, 4.620701014995575, 0.028375864594376514, 1.2174281818526131, 1.5628523379564285, 2.6517011736120497, 2.0538918461118425, 2.0467625600951056, 1.4261954937662398, 0.10390079008149249, 0.05273023873035397, 0.14862654118665627, 8.414649776050023, 32.402145930698936, 33.54563181740897, 19.64076999255589, 34.45827422823225, 8.889431476593018, 0.20429877883621625, 0.13342735676893167, 0.05758193374744483, 0.04326194750943354, 0.022473122226074338, 0.034618534347308536, 0.06932341906109027, 0.03489756151767714, 0.010520642207536315, 0.08750358423484222, 0.024762229661324194, 0.0047105003613978624, 0.06916496756353549, 0.04783889351944838, 0.04647890917424645, 0.02398974807666881, 0.03486043208145669, 0.03728455611105476, 0.02661775321965771, 0.047972883829580884, 0.021956081934539334, 0.020069574770916785, 0.0034135481026688857, 0.014891151571646333, 0.024940185647990023, 0.05625837994739413, 0.0441832962845053, 0.049427808794592104, 0.006250227784870991, 0.04868499615362712, 0.03275664443416255, 0.039841483014502695, 0.017252986086532474, 0.06259699285562549, 0.0036487291883012013, 0.03310897034992065, 0.0329884557452585, 0.0379918949412448, 0.02180980844423175, 0.03258743815656219, 0.0357922981493175, 0.020944038472537483, 0.029791137669235468, 0.06303411868533917, 0.023285681481606195, 0.005384085891169629, 0.0677317116143448, 0.05671051497172032, 0.0279023302718997, 0.04728239980925407, 0.0841413482225367, 0.014759553097454565, 0.016966842780155793, 0.0261846069978284, 0.015621971106156707, 0.0727977626291769, 0.07504894504589693, 1.1453057719128472, 32.877701486860005, 39.77406999043056, 27.324881826128276, 43.90953356879098, 42.42832701546805, 9.250373891421727, 0.6347485025014196, 0.06585685828966753, 0.1358376488621746, 0.09996635227331094, 0.9892535741840089, 2.585902167218072, 4.711297707898276, 4.674380191734858, 0.7531603542821748, 0.07085169026894228, 7.257256201335362, 33.948801040649414, 55.809991223471506, 59.35723073141915, 56.14165653501238, 57.68454572132656, 52.870097228458945, 49.34933383124215, 47.07592494147164, 48.041582107543945, 54.32558849879673, 56.53471960340227, 54.21910040719168, 53.36340890611921, 53.123289585113525, 52.06163610730852, 51.876362391880576, 52.654800346919465, 53.17884390694754, 55.28745889663696, 54.65392909731184, 51.791639532361714, 50.154869760785786, 42.581562587193076, 40.402631827763145, 40.420297622680664, 38.97164337975638, 40.45102603094918, 39.75507014138358, 39.762667996542795, 42.1752666745867, 47.927378041403635, 48.89748205457415, 51.12203468595232, 51.82180166244507, 53.427749225071494, 53.755117075783865, 51.99141066414969, 51.093071120125906, 51.31999928610665, 47.701325348445344, 50.67943096160889, 49.55788401194981, 52.89792128971645, 51.20864398138863, 49.85212632587978, 47.46810558864048, 41.265605040958945, 37.72878088269915, 37.33103125435965, 38.11197056089129, 36.64020660945347, 37.12982184546334, 37.4889429637364, 39.58437027250017, 48.08738463265555, 52.85396351133074, 50.272176197596956, 50.237893785749165, 52.531796387263704, 50.74257966450283, 46.454485007694785, 43.89285789217268, 40.6070374080113, 42.35745191574097, 39.869548661368235, 37.70496245792934, 37.35444668361119, 47.13356024878365, 48.75015939985003, 47.55293614523751, 49.985441412244526, 50.09783547265189, 49.37519155229841, 46.75271558761597, 44.55051531110491, 44.203643866947715, 42.446701526641846, 44.00526932307652, 43.75014884131295, 47.11391421726772, 45.92987864358084, 48.28059319087437, 45.29291296005249, 28.492543969835552, 7.754015054021563, 0.7874608965856689, 2.7521267448152815, 3.9864907264709473, 2.9670953239713396, 5.001317688396998, 1.2905897817441394, 0.49040727636643816, 0.08772176038473845, 0.042835671454668045, 0.1591997588319438, 7.997208952903748, 32.09268011365618, 40.19749321256365, 22.34361229624067, 36.966049330575125, 13.151607615607125, 0.2045907253133399, 0.05912374172891889, 0.04187502193131617, 0.07460834511688777, 0.01258209181417312, 0.07133061385580472, 0.018801209616607854, 0.024774080275424888, 0.07701769404645477, 0.07835166675171681, 0.046923407286937745, 0.011051168382566954, 0.07875217883182423, 0.03487803327984043, 0.031198907843125716, 0.0420501145002033, 0.02849694068676659, 0.059226492286792824, 0.06789900442319256, 0.05977323544876916, 0.03392839977251632, 0.030590285680123737, 0.01742496417968401, 0.030104593706450293, 0.03665788830923183, 0.19434424942093237, 0.0835267108465944, 0.09641161587621484, 0.08805103307323796, 0.11948986750628267, 0.08723321517131158, 0.15561722964048386, 0.11228655331901141, 0.18618690142674105, 0.13105871315513337, 0.09678873206887927, 0.13147776281195028, 0.09557773705039706, 0.07621595742447035, 0.11152685872678246, 0.12892078501837595, 0.08311663142272405, 0.12150754566703524, 0.1876896529325417, 0.08209835392023836, 0.12678683309682778, 0.20791280562324183, 0.10246634669601917, 0.11844290154320852, 0.11601033993065357, 0.20398244581052236, 0.09291769657284021, 0.12344970288021223, 0.11122251541486808, 0.19682388779308113, 0.16314120590686798, 0.1790670741881643, 0.8922539534313338, 37.31530748094831, 47.88472652435303, 39.279525007520405, 44.6027831350054, 48.48287957055228, 16.04498863220215, 1.5096469415085656, 0.12506120997880185, 0.3920044180537973, 2.632018664053508, 7.6787808282034735, 10.834838492529732, 7.824659994670323, 4.889826025281634, 1.0422695236546653, 0.29697670148951666, 5.597139613968985, 33.13030324663435, 54.760542256491526, 62.6595983505249, 58.23057338169643, 62.46557685307094, 54.42840446744646, 52.524511201041086, 51.230718408312114, 51.76087638310024, 56.81168174743652, 59.52639157431466, 54.25764206477574, 55.93938752583095, 54.258180550166536, 53.66908795492989, 54.15546185629708, 54.166203771318706, 54.467567988804404, 57.934413364955354, 56.27153921127319, 54.12357309886387, 52.69157716206142, 45.91313001087734, 41.23576947620937, 42.61670657566616, 40.37451246806553, 42.4015451839992, 40.89389378683907, 44.03760276521955, 44.60338415418352, 50.67091247013637, 50.992645331791465, 53.93282767704555, 54.10388537815639, 55.64360966001238, 55.14187329156058, 52.99590826034546, 53.15786382130214, 50.75722994123186, 47.79804079873221, 49.97056531906128, 49.25049570628575, 55.25901297160557, 52.409344809395925, 53.24598434993199, 50.15780190059117, 42.659253869737896, 39.72770118713379, 40.36376360484532, 39.67841414042881, 39.123885359082905, 38.762645040239605, 40.12468998772757, 43.083948612213135, 50.34487519945417, 54.448745318821494, 53.15546669278826, 51.31198453903198, 55.98768098013741, 52.14184611184256, 49.13118124008179, 43.94103670120239, 42.34067896434239, 43.91152422768729, 41.90885189601353, 39.23882246017456, 38.63802215031215, 49.31825106484549, 51.00858449935913, 49.73169667380196, 50.613047872270855, 51.374782357897075, 50.31577614375523, 47.73501716341291, 44.700815268925254, 45.21401963915144, 43.65366962977818, 45.651085649217876, 46.96733154569353, 50.54938847678048, 48.17206580298287, 50.13745757511684, 43.977268082754954, 28.277012586593628, 5.505588412284851, 0.7243370552148137, 4.147481790610722, 6.252661764621735, 5.046583899429866, 4.489854276180267, 7.918318237577166, 4.282393225601741, 0.17526374970163616, 0.16101257369986602, 0.4819857339773859, 12.564283336911883, 40.29315601076399, 42.347519465855186, 28.09219571522304, 45.34641408920288, 14.577961615153722, 0.3652213109391076, 0.28313727410776274, 0.16883475253624575, 0.20563381005610737, 0.08151346351951361, 0.1901528843279396, 0.10498880062784467, 0.21391903475991317, 0.13929536832230432, 0.16775900311768055, 0.17360790712492807, 0.08948804810643196, 0.19893551591251576, 0.12479403002985887, 0.12891915653433117, 0.09359210609857525, 0.12992851808667183, 0.12386655408356871, 0.12366045585700444, 0.1595819911786488, 0.06505624125046389, 0.07905058496232543, 0.08527947536536626, 0.1179952041379043, 0.14792541095188685], [0.04725784362692918, 0.046839282515325716, 0.02959337524537529, 0.04355183124010052, 0.03775133392108338, 0.04734811592581017, 0.08352290426513978, 0.0357578116069947, 0.03611210188163178, 0.03369567922449537, 0.02954024256074003, 0.06831160121198211, 0.026970045208664875, 0.06279394443013839, 0.03025542525574565, 0.027548291055219512, 0.01235881562544299, 0.007963955335851227, 0.026860312525449053, 0.022993507695251277, 0.02970373218080827, 0.040112815597759824, 0.012348201641413783, 0.02895269908809236, 0.044471032451838255, 0.024250242759340575, 0.033778277292315445, 0.03986252099275589, 0.08589812966861896, 0.042945970714624436, 0.025121863399233137, 0.05532920087820717, 0.10428170607026134, 2.9917366760117665, 35.2448867389134, 33.39386926378523, 25.704278775623866, 34.37296077183315, 38.973363058907644, 11.670043230056763, 0.3629206701048783, 0.009680018743633159, 0.03746609136994396, 0.1680191263024296, 2.209256172180176, 4.973959590707507, 4.487026359353747, 1.2096100470849445, 0.15531783284885542, 0.26323128225547926, 9.77549181665693, 45.10020467213222, 60.122039794921875, 62.35879693712507, 56.15505266189575, 53.685881750924246, 51.736227648598806, 47.81485196522304, 46.58838026864188, 51.725951262882774, 52.12455899374825, 53.71824993406023, 53.48441525868007, 56.42892633165632, 50.91701766422817, 50.4299350466047, 51.214633328574045, 52.429505007607595, 51.039278166634695, 52.45378201348441, 52.203608649117605, 50.77232837677002, 42.86775541305542, 39.42157050541469, 38.63687917164394, 37.099023955208914, 37.42427607945034, 38.4861866406032, 37.63604327610561, 39.317253725869314, 44.29197978973389, 44.82344402585711, 49.333544049944194, 51.63160514831543, 51.15145335878645, 53.31943028313773, 48.86074692862374, 45.64938334056309, 44.393979345049175, 52.313122681209016, 46.91886438642229, 51.770801884787424, 51.83362054824829, 53.33658191135952, 50.5312363079616, 49.47871623720442, 44.851028374263215, 39.848134313310894, 37.997200216565815, 36.160186835697715, 35.48335933685303, 36.43203163146973, 36.55538994925362, 44.82930135726929, 50.53947687149048, 52.353821754455566, 51.54855333055769, 53.22996527808053, 49.61507116045271, 47.354401792798726, 41.54388039452689, 39.063265800476074, 42.64106001172747, 42.189374991825645, 41.09048959187099, 36.51781409127371, 34.86109604154314, 44.447421414511545, 47.34751612799508, 47.043532439640586, 47.731355462755474, 49.65897682734898, 48.09696619851248, 44.4591360773359, 44.83027410507202, 44.633973598480225, 43.826266356876914, 44.17556619644165, 47.045290333884104, 44.71421834400722, 49.95365687779018, 43.721814087459016, 24.067267554146902, 4.190311789512634, 0.28375883932624546, 0.6524488755634853, 0.5945440541420663, 2.5632542967796326, 1.583436376282147, 5.337690838745662, 1.7952574214765002, 0.17132743235145295, 0.06991261815918343, 0.1930401593978916, 8.425363898277283, 29.796689578465053, 33.83023003169468, 21.695979390825542, 26.726073912211827, 20.979496785572596, 0.3354907291276114, 0.04699231591075659, 0.016120558637859564, 0.013583020024400736, 0.025345427117177417, 0.022760198518101658, 0.03388250705653003, 0.07418880012950727, 0.02767281240916678, 0.02569782088643738, 0.05913258982556207, 0.04893895484773176, 0.03819380321406892, 0.07045076428247349, 0.08357178592788321, 0.061592964588531425, 0.020029422461188266, 0.033649854362010956, 0.06501201433794838, 0.014936214778572321, 0.012476142811855035, 0.05211201190416302, 0.10160489220704351, 0.030230305889355283, 0.022207367200670496, 0.016177545401400754, 0.07892702373542956, 0.039528691941606145, 0.06550078346793141, 0.0386253616639546, 0.05309010317016925, 0.06763799235756908, 0.013859359347926719, 0.03192680289170571, 0.0038483028765767813, 0.04994082537346652, 0.07485343875097376, 0.0543269809069378, 0.02816844152818833, 0.06696411887449877, 0.02176689788965242, 0.021434673573821783, 0.024567150843462775, 0.03193311666005424, 0.015972736391371915, 0.015234078081058604, 0.010975145319077586, 0.04872020872841988, 0.017350259170468365, 0.04151987670255559, 0.0343702482059598, 0.01928493892773986, 0.05104464578575321, 0.033955683665616174, 0.06590524462184735, 0.03305725580347436, 0.03860041871666908, 0.054318478863154135, 0.03688641551083752, 5.744503957884652, 44.07728392737252, 35.53165973935808, 26.959458691733225, 43.4903279032026, 45.73941114970616, 10.084249785968236, 0.031400677016271014, 0.013204545065361475, 0.034853609411844184, 0.18952210460390362, 0.8810447177716664, 3.4955425219876424, 8.897377610206604, 1.9190086381775993, 0.3802226888281958, 0.4212244158344609, 12.126933319228035, 43.26723166874477, 62.627768652779714, 61.49265534537179, 58.612918853759766, 53.78415707179478, 52.79343775340489, 47.932453700474326, 49.11549915586199, 52.573892048427034, 54.52411242893764, 54.92940432684762, 55.50743886402675, 57.51696559361049, 51.979557037353516, 53.07591676712036, 52.29451540538243, 52.78446415492466, 53.716047355106895, 53.86363056727818, 54.70789228166853, 53.02777617318289, 44.796568393707275, 39.51687199728829, 40.20584842136928, 39.44867542811802, 39.24702133451189, 39.48148829596383, 39.10617092677525, 40.62762492043631, 46.2451878956386, 48.31200252260481, 51.53422614506313, 52.919568402426584, 55.33926119123186, 54.14542170933315, 51.36319971084595, 46.80807188579014, 47.167262486049104, 52.69275140762329, 47.156485830034526, 51.69159936904907, 53.0562082018171, 54.74761513301304, 50.75713961465018, 51.59123958860125, 46.897568157741, 42.21536472865513, 40.3056697164263, 39.62098033087594, 37.296672412327354, 37.554033688136506, 37.71981075831822, 45.16354097638811, 51.5056586265564, 51.494030816214426, 51.18170581545149, 53.191263811928884, 52.413287912096294, 48.63202265330723, 43.55325773784092, 41.05608211244856, 43.39861168180193, 44.04199750082833, 42.99868031910488, 37.67306327819824, 37.27056803022112, 46.551530497414724, 49.941560064043315, 47.561465059007915, 48.46324743543352, 50.45627566746303, 49.83101075036185, 45.628121852874756, 47.82949529375349, 45.82826123918806, 45.7646678515843, 45.531830242701936, 47.63569961275373, 46.16178519385201, 50.10682644162859, 46.14772203990391, 26.7256726537432, 5.668281350816999, 1.1745369519506181, 2.9372234983103613, 2.770212471485138, 2.769865712949208, 3.6709235225405012, 2.6708910124642506, 0.7525478814329419, 0.02981724091140287, 0.014171732273618025, 0.09838889406195708, 6.955041263784681, 30.59803921835763, 41.71732827595302, 27.35201975277492, 27.937348161424907, 28.997651951653616, 1.0531367233821323, 0.07287282895828996, 0.03305965442476528, 0.01539549816931997, 0.03704457863100937, 0.024177756559635912, 0.045867837499827147, 0.04488339514604636, 0.031194728067410842, 0.014180872988487993, 0.016549635345914533, 0.017542118339666297, 0.03272043102021728, 0.032330558369202275, 0.029068389308771918, 0.04699314372347934, 0.02980631310492754, 0.031793891452252865, 0.03760488910068359, 0.048487908872110505, 0.025715089602661983, 0.10089707840234041, 0.031868998493467054, 0.04608979648245232, 0.04109403830287712, 0.02332534863879638, 0.2313730317567076, 0.11704331450164318, 0.1282586298350777, 0.11269780660846404, 0.1524425542780331, 0.22094309356595787, 0.16111514105328492, 0.08741300659520285, 0.13031294888683728, 0.13665906978505, 0.15292337776294776, 0.17904878088406154, 0.12020450058792319, 0.1764844206294843, 0.11755957108523164, 0.1923945333276476, 0.071230563867305, 0.23555411025881767, 0.09055972631488528, 0.1797562622066055, 0.13418346191091196, 0.12929425069264003, 0.11189570357756955, 0.10855195764452219, 0.12694907081978662, 0.14219092151948384, 0.11380398153726544, 0.16998611789728912, 0.15680478805942194, 0.10492555437875645, 0.17549164247299942, 0.12556344802890504, 0.12591377565903322, 5.4279535838535855, 50.326601437159944, 44.57372576849801, 35.44349752153669, 44.001486028943745, 49.91880471365792, 16.88772174290248, 0.6583208633320672, 0.30504011309572626, 0.2896609269082546, 1.1441021050725664, 7.382936085973467, 9.986048289707728, 8.289788041796003, 1.9278417527675629, 0.47526291757822037, 0.7152051680854389, 11.761364272662572, 49.672633511679514, 63.54097039358956, 65.95426736559186, 61.160357747759136, 56.78022377831595, 55.719949517931255, 50.13104786191668, 50.08397381646292, 55.40547752380371, 56.785031931740896, 57.57415969031197, 57.54295533043997, 59.89459746224539, 53.714508329119, 55.003263677869526, 54.649159158979145, 55.685715743473594, 55.86907523018973, 57.94080918175833, 57.52504634857178, 56.47990526471819, 47.54033211299351, 41.36535337993077, 42.741617815835134, 42.28659766060965, 41.12100608008248, 40.36528526033674, 40.859031200408936, 41.76786599840437, 48.014088085719514, 49.90607213973999, 52.34666163580758, 55.145121574401855, 55.27270439692906, 57.18603331702096, 52.39455556869507, 46.75468192781721, 46.307481970105854, 54.9616231237139, 48.68879985809326, 53.85824223927089, 55.69056906018938, 58.59927953992571, 54.60083096367972, 54.5350558417184, 49.26670585359846, 45.06760719844273, 42.7998228754316, 40.417306423187256, 39.398391314915244, 38.171721594674246, 40.003468241010395, 49.38112531389509, 53.920953205653596, 54.25663110188076, 51.842729636601035, 56.91128764833723, 54.1489965575082, 52.63881949016026, 45.5233291217259, 42.323440483638215, 47.69563824789864, 45.74303116117205, 46.001132420131135, 41.028098242623464, 38.388758999960764, 48.75111130305699, 51.602686745779856, 49.881749970572336, 49.11561380113874, 51.554306438991, 51.81093120574951, 47.73626089096069, 50.02387537275042, 47.710351058415, 47.59183216094971, 47.543465750558035, 49.61170128413609, 47.52280180794852, 52.218418734414236, 46.710494858878, 26.887254749025615, 5.330819504601615, 0.9211231214659554, 3.4146207613604407, 4.036798724106379, 6.2117994087083, 6.995712544236865, 11.281968968255178, 4.567367511136191, 0.3794315169964518, 0.23678163439035416, 0.36273860558867455, 12.827660015651158, 39.65156282697405, 43.74033451080322, 31.452879565102712, 35.74119309016636, 30.547129767281668, 0.9348048844507763, 0.14696828302528175, 0.09561931089098964, 0.12655273851539406, 0.108729876311762, 0.09162214252033404, 0.10885810585958616, 0.14477145804890565, 0.07556603622755834, 0.14941288184906754, 0.09207554640514509, 0.13030452148190566, 0.1627987628536565, 0.11846609387014594, 0.153057795550142, 0.08868639969399997, 0.1519251306142126, 0.09965642461819307, 0.1018467220876898, 0.11678899957665376, 0.13913838246038981, 0.18828825652599335, 0.2491295603769166, 0.24162623871650013, 0.19214783156556742, 0.09642224851995707], [0.018250822721581374, 0.004412140032010419, 0.029241612513682673, 0.023558786737599542, 0.04501311747091157, 0.02972479730046221, 0.01768925187311002, 0.04094664692612631, 0.04572203050234488, 0.02445280921113278, 0.05964932816901377, 0.023865572775581052, 0.04207523386659367, 0.05616073875821062, 0.04245511848213417, 0.024364530108869076, 0.012450723193718918, 0.024601136966209327, 0.05419685146106141, 0.03385936561971903, 0.07530059332826308, 0.03226931379841907, 0.01515911692487342, 0.013722968720165747, 0.01929487776942551, 0.04518074954726866, 0.052132988814264536, 0.010487712054912533, 0.04631003198613014, 0.05165347829461098, 0.03995813675490873, 0.030700204960469688, 0.039083321911415884, 0.10616191982158593, 9.121254648481097, 38.1167266028268, 31.669958659580775, 28.564112152372086, 38.27406855991909, 45.70677893502371, 15.281834977013723, 0.4739574704851423, 0.07840748304235083, 0.10548388013350112, 0.49928897406373707, 2.3089984314782277, 8.971734625952584, 0.7485489760126386, 0.25611016580036705, 0.07743858253317219, 0.5725659791912351, 14.286945002419607, 46.63450935908726, 58.72855772290911, 57.860651288713726, 56.85607378823416, 54.98688677379063, 52.87849065235683, 47.80905369349888, 49.223053795950754, 50.60783324922834, 53.51160703386579, 53.0150123323713, 54.31223406110491, 53.584514481680735, 52.121467045375276, 48.4645710672651, 51.7519097328186, 52.88936805725098, 52.96223381587437, 52.331653526851106, 51.371085916246685, 43.313524041857036, 38.2434652192252, 38.792598724365234, 39.46339518683297, 38.5682726587568, 39.71366582598005, 39.99984128134591, 37.7422638620649, 41.414223534720286, 45.317877837589805, 48.22174194880894, 52.318851470947266, 51.3329507282802, 52.45911128180367, 51.40141480309622, 50.049135548727854, 35.51654045922415, 39.657722405024934, 48.64521033423287, 49.978347301483154, 51.713579995291575, 51.39717640195574, 51.353892598833355, 50.04084287370954, 46.356386865888325, 40.53882694244385, 34.92214986256191, 36.235435826437815, 35.93412372044155, 38.576975277491975, 39.66706773212978, 47.23169313158308, 51.39635304042271, 50.3953469140189, 51.13241529464722, 51.014667647225515, 50.04476513181414, 41.75934403283255, 40.214519773210796, 41.040104729788645, 43.070323194776265, 43.783965723855154, 43.21685722896031, 40.79446159090315, 35.455907004220144, 39.62395763397217, 50.01441192626953, 47.79668590000698, 48.15728351048061, 47.63991716929844, 49.95813499178205, 48.58630003247942, 47.231456892830984, 45.083834716251914, 46.96263803754534, 45.853750705718994, 47.25463260923113, 48.65959310531616, 44.27095454079764, 21.809808254241943, 3.7610681482723782, 0.017921560211107135, 1.3982291030032294, 1.7717765271663666, 4.380710235663822, 2.823623925447464, 1.8554169876234872, 4.058107112135206, 0.20661422530455248, 0.03474468418530055, 0.2269766948052815, 11.188038877078466, 34.41931567873274, 36.09457847050258, 27.870230300085886, 22.178651639393397, 29.357962948935374, 4.504699970994677, 0.03120927925088576, 0.038316947141928334, 0.01349746693657445, 0.0647053640069706, 0.020860580361581275, 0.03660818222644074, 0.03838161152920552, 0.07902310429407017, 0.07359433559966938, 0.06485491312508072, 0.026580717082002332, 0.0702530595340899, 0.023659069124343138, 0.04876733298546501, 0.013278803937802357, 0.014114951615088751, 0.031101755199155638, 0.028243692758093988, 0.03284672335056322, 0.01246444062728967, 0.05411014147102833, 0.02129139581562153, 0.061017071562153954, 0.029498044467930282, 0.017518968421167562, 0.053850754496774504, 0.020774185890331864, 0.03211009216361812, 0.053973365774644275, 0.03781211369537881, 0.013879715398486172, 0.02247187202530248, 0.025096498063898513, 0.027958550290869813, 0.037728012672492435, 0.03058653338147061, 0.02947530336678028, 0.031017369191561426, 0.02834921852419419, 0.01564549930792834, 0.06078057496675423, 0.03239218970494611, 0.07274837206516947, 0.018604071444964836, 0.050155442607189925, 0.04764264762135489, 0.019597119319119623, 0.09205398934760264, 0.048148604043360264, 0.03166829462030104, 0.06822985131293535, 0.018135805946907828, 0.0230480178059744, 0.010160647997898715, 0.05666605396462338, 0.012857397219964435, 0.015887330884912183, 0.04458734692473497, 0.01574325584806502, 0.11689383323703494, 15.375474112374441, 44.46160963603428, 31.64373615809849, 29.983102798461914, 47.65714175360543, 49.28341974530901, 11.725521121706281, 0.4118684764419283, 0.026626109378412366, 0.06827889582408325, 0.1356491246925933, 2.2206618572984422, 9.820009793554034, 2.7010099334376196, 0.8003607158149991, 0.35980622151068276, 0.997088753751346, 19.968898671013967, 51.08972903660366, 61.46719019753592, 59.6955315726144, 56.66007552828108, 55.63476460320609, 55.98845223018101, 48.40642854145595, 51.58609792164394, 53.20949241093227, 54.69248465129307, 54.20416178022112, 55.88844680786133, 54.284781728472026, 53.720706122262136, 49.58143840517317, 53.087412561689106, 53.9949688911438, 56.88185855320522, 54.115891865321565, 53.022634506225586, 45.32683059147426, 40.018910612378804, 40.02362149102347, 42.075987339019775, 40.56643213544573, 42.30655288696289, 43.04025139127459, 40.828441756112234, 43.97207430430821, 46.4318026133946, 50.0736140523638, 54.204818384987966, 52.82803283418928, 55.333063398088726, 53.85594238553728, 48.666207790374756, 35.984036105019705, 40.52104997634888, 49.97895526885986, 49.53848116738455, 51.37112413133894, 51.220421178000315, 53.37928901399885, 52.51160839625767, 49.337250913892476, 41.892349924360005, 37.55979027066912, 37.49863917487008, 37.86514275414603, 38.46860074996948, 41.09856339863369, 48.502737522125244, 53.58172130584717, 51.45590605054583, 52.72121122905186, 52.63254526683262, 52.53480495725359, 44.63759708404541, 41.18407140459333, 42.993771416800364, 44.1885905947004, 45.25858538491385, 45.724660124097554, 42.040468147822786, 37.293125356946675, 41.576147828783306, 51.004874161311555, 49.18077400752476, 48.118192945207866, 48.838516167231965, 51.00613873345511, 49.60493721280779, 49.55702938352312, 46.19468491418021, 47.18146112986973, 47.65684298106602, 48.42633860451834, 49.21401071548462, 45.50864062990461, 26.23687035696847, 5.070342830249241, 0.41256850744996754, 2.8907302788325717, 3.4621223381587436, 2.5382221085684638, 4.015914610454014, 2.2895007005759647, 0.06440141424536705, 0.17853593054626668, 0.06903082797569887, 0.16634045780769416, 7.90263615335737, 38.17687020983015, 39.87681647709438, 31.827957221439906, 23.85180217879159, 35.06139176232474, 7.805740049907139, 0.1993060503154993, 0.027347368354509984, 0.03705453613240804, 0.03073988908103534, 0.02404461272193917, 0.023794514892090644, 0.08262727875262499, 0.054951022778238566, 0.031339859922549555, 0.05919107275881937, 0.05823178709085498, 0.036490877092416794, 0.018138878014204756, 0.021035764532695924, 0.005169408437463322, 0.048841127061418126, 0.03164811498884644, 0.03359658597037196, 0.03801924329517143, 0.013835402820924563, 0.04252628662756511, 0.027309811441227794, 0.06236967683902808, 0.02346823793569846, 0.07260940809335027, 0.06391077914408275, 0.14517108803348883, 0.06991803286863224, 0.1735032634543521, 0.07843598151313406, 0.13851518875786237, 0.09380549857658999, 0.08713568254773106, 0.15731581992336682, 0.11133446690759488, 0.15943044716758387, 0.18689588909702642, 0.11837915996355669, 0.08222147409937211, 0.1883877840425287, 0.13692349488181726, 0.14214583965284483, 0.12290464927043233, 0.2839247004262039, 0.1386748751891511, 0.1273637507110834, 0.11825007546160902, 0.12603535556367465, 0.21598374896815845, 0.08223033576671566, 0.20367464875536306, 0.1825395314288991, 0.09372870876852955, 0.08222582350884165, 0.10998378188482352, 0.14260900765657425, 0.12829525715538434, 0.1055678284860083, 0.17033492560897553, 0.23151688118066105, 13.84502567563738, 54.72145863941738, 42.8324168750218, 38.61471094403948, 47.15594734464373, 57.34154789788382, 20.88701973642622, 1.0094900940145766, 0.19458031175392015, 0.35689006799033707, 1.9242480141775948, 6.45057121344975, 17.49079237665449, 5.608899874346597, 0.6360670860324587, 0.4484636884714876, 0.9598579172577176, 16.376184940338135, 50.8638083594186, 62.24934891292027, 60.597421646118164, 59.10180105481829, 58.98200716291155, 59.66605036599295, 52.8088002204895, 53.36406551088606, 55.936431067330496, 57.42499576296125, 57.03664009911673, 58.255906513759065, 55.362999711717876, 54.13066373552595, 50.06261157989502, 54.04341173171997, 55.93809863499233, 58.34359972817557, 56.80264561516898, 54.79608924048287, 46.656517778124126, 42.08729553222656, 41.68386227743966, 43.542779854365754, 42.61471244267055, 44.02233062471662, 44.62185594013759, 41.83991881779262, 46.19665125438145, 48.6426533971514, 52.398693220955984, 56.40391629082816, 55.308022090366904, 56.54880012784685, 56.44368083136422, 52.291135106767925, 36.318418162209646, 40.39550297600882, 51.022178649902344, 50.494119031088694, 52.552258832114084, 53.014616285051616, 54.84689794267927, 53.38815491540091, 49.9900689125061, 44.544268880571636, 38.252146993364605, 39.57711287907192, 39.35676465715681, 41.700642177036826, 44.11814628328596, 51.10611636298043, 56.2299542427063, 52.369917256491526, 53.391281604766846, 54.67480843407767, 56.101725237710134, 46.51269006729126, 43.24289560317993, 44.83784416743687, 46.10916648592268, 47.03216518674578, 47.80925171715872, 46.11955751691546, 40.5915915625436, 43.938354696546284, 53.853319440569194, 50.99083880015782, 49.59810365949358, 49.74902548108782, 51.261700425829204, 50.36782857349941, 50.19539860316685, 48.10106563568115, 50.78516864776611, 48.56102248600551, 51.05266039712088, 52.68246112551008, 47.655321325574604, 23.582576853888376, 4.68311972277505, 0.27277563725199017, 3.9891562291554044, 5.593486598559788, 11.163338031087603, 5.440408664090293, 8.325858746256147, 7.868667278970991, 0.6195272792662893, 0.2397274263203144, 0.42838553871427265, 15.55246557508196, 46.572104113442556, 45.47024141039167, 39.15729577200753, 31.558891705104283, 42.52481664930071, 7.797637581825256, 0.48050989317042486, 0.11869892637644495, 0.14498104394546577, 0.15568449960223266, 0.11445812322199345, 0.13113902455994061, 0.21726041260574544, 0.12095793230193001, 0.139263992863042, 0.3135929655815874, 0.17725953832268715, 0.21475797545697006, 0.1242647184325116, 0.08884614719344036, 0.08049643452146224, 0.1148313039115497, 0.1274555700698069, 0.10201727186462708, 0.11410018242895603, 0.12699686682650022, 0.15431601660592215, 0.07619588635861874, 0.15129428303667478, 0.12292222332741533, 0.20347695079232964, 0.12438416773719446], [0.020211001824853674, 0.052638612754110775, 0.029826764150389602, 0.10224848945758172, 0.01677855779416859, 0.044078323524445295, 0.03101919445076159, 0.05554567729788167, 0.0417780117797, 0.012400602356397679, 0.029895570993955647, 0.012140426585184676, 0.07392753022057669, 0.027164723690865294, 0.0214889580716512, 0.0135704747600747, 0.06256586166896991, 0.036631466155605655, 0.04878433368035725, 0.04259721389306443, 0.02164580992289952, 0.010630882943847349, 0.0186983454041183, 0.05185305919232113, 0.08741786490593638, 0.04772033988099013, 0.014920275990984269, 0.014028745437307017, 0.06133307210568871, 0.046324786730110645, 0.01797239266202918, 0.03292999316805175, 0.01407068144596581, 0.048470938711294105, 0.1614546121231147, 14.173673731940132, 38.30089555467878, 33.484539781297954, 29.135575430733816, 33.197957856314524, 44.61055816922869, 20.066133499145508, 1.9074596464633942, 0.1314720224056925, 0.04187843496245997, 2.0129571855068207, 12.258350678852626, 1.8353234486920493, 0.756732596882752, 0.204523306073887, 0.03926729989637222, 0.162465561447399, 11.7769056558609, 53.42844751902989, 62.58540548597063, 56.0890656198774, 56.69992692129952, 54.10466357639858, 51.716904708317344, 50.9137659072876, 49.87958560671125, 53.61301946640015, 54.33717809404646, 56.14641605104719, 55.79717527117048, 52.390143462589805, 53.063538551330566, 51.78445509501866, 53.61371776035854, 53.87220117024013, 53.765337875911165, 52.83407776696341, 48.90629931858608, 38.81587866374424, 38.512568950653076, 38.900243691035676, 39.82110234669277, 37.85481425694057, 39.516326563698904, 38.43687527520316, 38.271869455065044, 42.23476757322039, 46.19811037608555, 47.184250831604004, 52.70361491612026, 51.57615157536098, 53.453033719744, 53.49280868257795, 54.5663366317749, 47.63056836809431, 34.36743695395333, 53.94400385447911, 50.001741886138916, 52.43338557652065, 53.18266541617257, 49.54479707990374, 48.87693970543997, 41.99709749221802, 36.11868871961321, 38.057517528533936, 38.39455032348633, 36.80806466511318, 41.448763029915945, 50.073197160448345, 51.81864023208618, 52.91826908929007, 50.92493861062186, 50.62845202854702, 46.9364572252546, 41.450163091932026, 44.616085461207796, 47.48723745346069, 46.22107417242867, 47.07209300994873, 46.500259740012034, 43.157693317958284, 38.14628076553345, 37.817669187273296, 47.1825624193464, 49.82452808107649, 46.7900447845459, 48.77066353389195, 48.682226862226216, 48.791011333465576, 48.442315987178254, 51.70389073235648, 48.94067900521414, 48.530804770333425, 49.17933573041643, 45.205080781664165, 25.85277567590986, 3.3275355143206458, 0.06057415104338101, 1.2070258600371224, 1.4579854565007346, 2.6224384009838104, 1.4919402173587253, 1.54900837796075, 2.4696375259331296, 0.050742602707552056, 0.026151981337794235, 0.39987181446381975, 10.95042872428894, 39.28369740077427, 28.610859632492065, 40.33288928440639, 25.52099745614188, 29.350299085889542, 12.665199841771807, 0.045318244490772486, 0.03670681407675147, 0.01852446062756436, 0.026226764378537024, 0.04561801447666117, 0.0366099599881896, 0.04270079565633621, 0.036119440237858465, 0.045515586222921095, 0.10426585549222571, 0.023128860164433718, 0.07271718659571239, 0.04390443196254117, 0.03000717982649803, 0.056731515630547485, 0.02961803999330316, 0.02627156804581838, 0.05892950429448059, 0.02707361170489873, 0.015026743224422847, 0.0426281041997884, 0.028061154963714734, 0.027990234483565603, 0.06372394452669791, 0.023517116205766797, 0.04361500285033669, 0.03601639451725142, 0.0550356496657644, 0.030695648597819463, 0.03553017667893853, 0.04550103164677109, 0.028069339792377183, 0.03936830661924822, 0.05184345452913216, 0.0306305160213794, 0.013950814842246473, 0.0183006356736379, 0.012311745651199349, 0.03137011919170618, 0.054973451753279994, 0.02499938613202955, 0.029273982026747296, 0.030661691312811205, 0.027854237406115447, 0.03883557520540697, 0.0627406726458243, 0.023339126292350035, 0.03374751590724502, 0.010770891011426491, 0.07007608403052602, 0.04864161740988493, 0.032315145446253676, 0.021539003421951617, 0.020823062464062656, 0.029627827860947167, 0.02967799874022603, 0.10845515105341162, 0.03917522947969181, 0.07190948565091405, 0.03443702622982008, 0.013421058804461998, 0.2881824533854212, 21.8520758833204, 45.20088059561593, 34.62593426023211, 29.935962745121547, 46.573670932224815, 52.43689789090838, 16.048858778817312, 1.0222825961453574, 0.10109653377107211, 0.14185697372470582, 0.20103525609842368, 3.2883867578847066, 2.7634481830256323, 2.2663425718035017, 1.334720288004194, 0.07496393139341048, 0.44917606881686617, 17.841294254575455, 56.01191977092198, 62.45709310259138, 57.239353793007986, 58.2083808353969, 56.24629293169294, 53.57308122089931, 52.449168409620015, 51.24667147227696, 53.982701846531455, 55.96960524150303, 57.2097544670105, 56.47110537120274, 53.57314028058733, 53.01659304755074, 54.282738958086284, 55.64240762165615, 55.17563806261335, 56.45034762791225, 55.66729954310826, 51.19964953831264, 40.06869445528303, 40.51590483529227, 42.776004450661794, 40.019852093287874, 39.41999326433454, 39.79390362330845, 39.94860873903547, 41.055505411965505, 44.15954712459019, 47.56938253130232, 50.2123487336295, 55.13894809995379, 53.60930912835257, 56.69252361570086, 56.023450306483674, 56.31040048599243, 47.94656549181257, 38.93879577091762, 53.1739627974374, 51.91369506290981, 53.7443334715707, 54.73571286882673, 52.22065258026123, 49.961831433432444, 44.44160924639021, 38.938952105385916, 38.90201895577567, 39.70712757110596, 39.810739108494346, 43.52049003328596, 50.83046742847988, 53.437705993652344, 54.61410897118704, 52.62357514245169, 52.00707537787301, 48.40165512902396, 42.13274369921003, 45.08903891699654, 49.160172598702566, 46.7036508832659, 49.000030517578125, 47.075139795030864, 44.75476108278547, 39.13855995450701, 40.017281259809224, 49.41256243841988, 50.25995431627546, 49.22808081763131, 49.48880502155849, 48.774776867457796, 50.01276520320347, 49.38415125438145, 52.59548357554844, 50.899289335523335, 48.84277541296822, 51.37351083755493, 48.577951771872385, 30.559275218418666, 4.873522077287946, 0.11533211703811373, 1.7052584907838275, 3.618521077292306, 3.6410482227802277, 4.653901679175241, 2.618799064840589, 0.5539841077157429, 0.18779068679681846, 0.021748506197971956, 0.36402290953057154, 8.004540170942034, 43.58036266054426, 36.783930097307476, 40.29764107295445, 29.439187390463694, 31.902528762817383, 19.254234756742203, 0.15604064906282084, 0.038362666831484864, 0.00926710813239749, 0.058085087819823196, 0.022674424906394312, 0.061712447819965224, 0.04846382427162357, 0.0050713100853109995, 0.07810068343366895, 0.0696638807920473, 0.044613660512758155, 0.020642405908022608, 0.005220437663540776, 0.07597257369863135, 0.044977032978619845, 0.04246607343001025, 0.07383562265230076, 0.05216391644041453, 0.04749143948512418, 0.07180229747401816, 0.014834281855395861, 0.043222802824207714, 0.004478376076024557, 0.037444480029600005, 0.013147383579052985, 0.035164680398468456, 0.03345564067629831, 0.14367949164339475, 0.12586103991738387, 0.14460464699992112, 0.18294814521712915, 0.1078803368977138, 0.11248207318463496, 0.12105044376637254, 0.11830707240317549, 0.1221911289862224, 0.1447700331253665, 0.06965733292911734, 0.11143407584833247, 0.2778955910887037, 0.09570269605943135, 0.1051693112988557, 0.12086529870118413, 0.16381765103765897, 0.21576515212655067, 0.19715052098035812, 0.1276962057288204, 0.09551812096365861, 0.07875964950237956, 0.15362232311495713, 0.20550425057964666, 0.15724711146737846, 0.16112654044159821, 0.13496242011232035, 0.08363657923681395, 0.08978122951728956, 0.22437534082148755, 0.10151330355022635, 0.1119773652670639, 0.11119014929447855, 0.10286858225507395, 0.339249351727111, 21.202883107321604, 55.63072769982474, 44.41745383398873, 40.36863429205758, 43.494006974356516, 56.798827580043245, 27.65485872541155, 3.016484422343118, 0.2124449445733002, 0.20635297575167247, 4.0006211910928995, 21.27653227533613, 7.473247034209115, 3.6645481160708835, 1.0661017362560545, 0.17056526110640594, 0.7216204181313515, 13.667291624205452, 56.87773132324219, 65.60824707576207, 59.71267972673689, 59.084270749773296, 58.89883722577776, 58.60657514844622, 56.28457750592913, 55.08525242124285, 59.3149995803833, 59.17448616027832, 60.06745474679129, 59.30536242893764, 55.101935046059744, 55.78243466785976, 55.302671977451865, 57.221507344927105, 57.991319111415315, 60.01957471030099, 57.10765068871634, 54.05301414217268, 42.4882378578186, 42.8892948286874, 43.73864262444632, 43.77235180991036, 40.44542578288487, 42.344139167240684, 41.25208384650094, 41.9241726739066, 46.28771434511457, 49.87541321345738, 51.5552270753043, 57.83685718263899, 56.93823276247297, 57.10758120673043, 59.37023081098284, 58.3511871610369, 50.29719318662371, 41.00812564577375, 54.93860721588135, 52.87758043834141, 56.368456159319194, 56.86126061848232, 54.26409694126674, 52.99873270307268, 46.02874803543091, 40.22923953192574, 40.946498598371235, 41.06486463546753, 40.525566305433, 45.780811991010395, 53.3646491595677, 56.94700138909476, 54.89570903778076, 52.263411794389995, 53.78044325964791, 50.854664530072895, 45.915919712611604, 48.36378744670323, 51.39746822629656, 49.450631618499756, 50.95864084788731, 49.962637424468994, 47.1463623046875, 41.600681918007986, 41.4286653654916, 50.20559508459908, 53.71284770965576, 50.29904835564749, 52.08478055681501, 51.368125983646934, 51.329421043395996, 51.039139202662874, 55.01121241705758, 53.37762144633702, 52.13687814985003, 53.13211032322475, 49.54539462498256, 30.195846217019216, 4.4155480691364835, 0.13899232101227554, 2.4289371498993466, 3.360220057623727, 9.235150388308934, 4.906086981296539, 8.06190276145935, 7.2385086587497165, 0.7813781829816955, 0.16249274356024607, 0.5937528280275208, 15.084196942193167, 48.920574392591206, 37.42265020098005, 49.187159402029856, 34.5569178036281, 40.72991630009243, 20.002296924591064, 0.21025386000318186, 0.095147620487426, 0.11731765978038311, 0.11773502667035375, 0.08916102815419436, 0.24089206382632256, 0.12757221023951257, 0.12674656882882118, 0.22022090160420962, 0.1784280841904027, 0.1129611935466528, 0.18273965854729923, 0.09844867299710001, 0.2042947347675051, 0.20884717548532145, 0.08057428962950196, 0.19122377543577126, 0.11949711426028184, 0.11698406482381479, 0.12516311236790248, 0.12714163905807904, 0.1236947625875473, 0.09269470960966178, 0.1508098497454609, 0.0656543562987021, 0.13245743167187485, 0.1304566218916859], [0.008815658428440136, 0.05489760171622038, 0.03770291705482772, 0.015283310885674186, 0.02125929093121418, 0.06514970944928271, 0.0538540691403406, 0.07024303078651428, 0.04239097995949643, 0.03273921626220856, 0.05678987642750144, 0.05854567739048174, 0.06591677971716438, 0.02136708639695176, 0.09290268059287753, 0.004814417999503868, 0.01837389879593892, 0.0850736146260585, 0.047697361292583604, 0.053877766975866895, 0.07227667487625565, 0.093190508362438, 0.025081963843799064, 0.03057164293048637, 0.06679004071546452, 0.04630599131009408, 0.054545964513506205, 0.033042511237519126, 0.044758263110582314, 0.038950539393616576, 0.06293337659112044, 0.008875570526080472, 0.010966516049977924, 0.06754040545118706, 0.02154373620370669, 0.4318225899977343, 12.299703751291547, 38.728018692561555, 32.77442346300398, 24.372111082077026, 33.3066520009722, 45.884072644369944, 23.86120309148516, 4.629722382341113, 0.029953714659703628, 0.1407633109816483, 0.698634745819228, 0.955634063908032, 1.1424993510757173, 1.851082180227552, 0.06157119718513318, 0.05571370631722467, 0.10401407150285584, 9.221624851226807, 50.23645898274013, 61.04275253840855, 63.410212244306294, 60.33754512241909, 57.02311890465872, 55.28175095149449, 52.712699685777935, 50.89611053466797, 54.666849272591726, 57.18536976405552, 54.15633038112095, 53.216756752559114, 52.5009046963283, 55.45960051672799, 54.18716648646763, 53.08210413796561, 51.70571116038731, 50.92237819944109, 46.15639339174543, 40.40718984603882, 40.44093377249581, 44.301189626966206, 45.50976971217564, 45.50973497118269, 42.00624132156372, 40.72722734723772, 40.459270068577354, 40.7931865964617, 41.5205830846514, 43.685978753226145, 46.11276912689209, 49.29444653647286, 50.774829728262766, 50.5116354397365, 47.262508392333984, 45.27214132036482, 33.478314195360454, 53.91117361613682, 51.065511090414866, 49.68914590563093, 51.69299595696585, 53.481646401541575, 49.68692248208182, 41.12594624928066, 36.7739177431379, 40.050656931740896, 37.71136522293091, 41.256746087755474, 48.91377558026995, 50.620527608054026, 52.29240662711007, 53.776632172720774, 51.162615639822825, 49.42650747299194, 42.3618084362575, 43.26789174761091, 50.04252781186785, 49.423901898520334, 49.07819080352783, 49.77575520106724, 48.81102214540754, 45.375933510916575, 42.291343280247276, 37.68542412349156, 42.92427553449358, 48.48505088261196, 48.695643833705354, 51.321222169058665, 48.900223118918284, 47.64152567727225, 47.0251579284668, 46.551523549216135, 48.72133827209473, 49.5749557358878, 43.43722629547119, 24.91465422085353, 3.449758453028543, 0.05799239993627582, 0.423034313001803, 0.9810475345168794, 3.602607314075742, 1.6137943587132861, 2.2773304964814867, 3.481266362326486, 0.07606397915099349, 0.022684127957160984, 0.25676071803484646, 10.038069452558245, 39.851584093911306, 26.048037426812307, 29.20266376222883, 40.58033200672695, 25.594733476638794, 19.60328619820731, 0.25059272614972933, 0.005910525164966072, 0.0926791847284351, 0.02142925886437297, 0.022230866564703838, 0.02001786700982068, 0.04510087579754846, 0.049009491955595355, 0.04492662800475955, 0.04029214222516332, 0.12402643050466265, 0.03830005501263908, 0.028864957724830935, 0.06384138536772557, 0.0649395671540073, 0.022244869831151197, 0.016849527468106577, 0.03363819034504039, 0.04990181300256934, 0.05129587337640779, 0.05230621541185038, 0.10110383480787277, 0.026006160769611597, 0.05310937695737396, 0.0340414131725473, 0.03948597137683204, 0.027783542538860014, 0.045257780235260725, 0.02218979484002505, 0.03967795607500842, 0.06263041749064412, 0.07285964502287762, 0.0028106858538064572, 0.07672950665333442, 0.018443229807806865, 0.004512276533725006, 0.0648929246568254, 0.031932326166757515, 0.046490515515740426, 0.04200285453615444, 0.02942611975595355, 0.04985039022618106, 0.03841745174889054, 0.031471129307257276, 0.011477988113516142, 0.02200806450231799, 0.023684297056336488, 0.025682594560618912, 0.10341700818389654, 0.04683426135618772, 0.03447069174477032, 0.01505164715594479, 0.04073921537825039, 0.01631703693419695, 0.029408345531140054, 0.008110415423288941, 0.015714631848303334, 0.03453875559249094, 0.03654130581500275, 0.061431330761739185, 0.015214795812166162, 0.07099276448466948, 0.11591267160006932, 0.9806680977344513, 19.167823484965734, 46.01736341203962, 33.425226484026226, 24.574680600847515, 41.265167304447715, 59.17940548488072, 24.01938578060695, 2.4800168318407874, 0.03628770674445799, 0.2305092295365674, 0.2934938898043973, 1.2856135687657764, 2.292866017137255, 2.9311672747135162, 0.9808137927736554, 0.09462400179888521, 0.20326758202697548, 14.446063961301531, 55.31150313786098, 61.2857449395316, 63.564059257507324, 60.46416909354073, 57.594590868268696, 56.37870127814156, 53.49848883492606, 52.48683112008231, 56.835375104631694, 57.63739177158901, 55.42190306527274, 53.393150670187815, 54.22246333530971, 57.23990617479597, 57.04666287558419, 56.26775244304112, 54.561347825186594, 52.90930591310774, 48.389158793858115, 41.96247114453997, 43.720348017556326, 46.308562414986746, 46.07819141660418, 46.25250782285418, 44.142579623631065, 43.28736407416207, 42.06536701747349, 41.02340126037598, 43.51772117614746, 45.173935481480186, 48.74092524392264, 52.96002776282174, 52.76839644568307, 53.0371492930821, 51.19735663277762, 47.07962138312203, 34.43660627092634, 55.0351802280971, 52.349472182137625, 51.266133376530235, 53.8786039352417, 54.46839829853603, 50.54354156766619, 43.40971837724958, 39.00014836447579, 41.61444629941668, 38.867941515786306, 42.299413612910676, 49.96857813426426, 53.80931997299194, 54.287234442574636, 55.531417097364155, 52.9576028415135, 52.12255791255406, 45.10095507758004, 44.44519451686314, 50.384657110486714, 50.00379160472325, 50.973454407283235, 51.88310214451381, 49.956043584006174, 46.90376247678484, 42.727658884865896, 40.0103052684239, 44.33950546809605, 50.30640302385603, 50.064921855926514, 52.49838597433907, 50.19948761803763, 51.06261369160244, 48.81015362058367, 48.77891104561942, 49.51693480355399, 49.95009592601231, 44.88756547655378, 28.811339480536326, 5.616255845342364, 0.10473243652709893, 1.0422734320163727, 3.5962720768792287, 6.3471550941467285, 4.923732365880694, 2.768340800489698, 0.9501511752605438, 0.06335535073386771, 0.10137533023953438, 0.2757081298955849, 7.784283144133432, 42.372446128300254, 38.47923149381365, 30.55534601211548, 44.89012936183384, 30.560452938079834, 26.833324568612234, 0.7696960355554308, 0.03767979597406728, 0.06920992729387113, 0.03620103407385094, 0.02288372072923396, 0.03947015133287225, 0.043246225853051455, 0.00472694423349042, 0.11220611299255065, 0.011289361315513296, 0.04641872990344252, 0.022632111462631395, 0.02016362820618919, 0.019372252813939537, 0.04396638220974377, 0.025969172129407525, 0.012320189171337655, 0.05365257477387786, 0.009490877955353685, 0.0194324405664312, 0.04845665554915156, 0.042553916573524475, 0.050708102594528875, 0.033048607874661684, 0.011279094232512372, 0.07135021673249346, 0.03482259018346667, 0.06320059725216456, 0.18677785114518233, 0.1333372608891555, 0.1062574168401105, 0.1683090507451977, 0.09054447963301625, 0.19374498086316244, 0.1941472299929176, 0.09025608189404011, 0.21410785748490266, 0.13739210473639624, 0.12066686792033059, 0.11350020819476672, 0.14074319920369557, 0.14044134611529963, 0.12720650700586184, 0.1269558561699731, 0.0916850630726133, 0.10134381228791815, 0.10856508729713303, 0.11831365419285637, 0.24165788558976992, 0.12568639857428415, 0.13860208195235046, 0.1479848370488201, 0.23677655894841465, 0.14522512656237396, 0.11222194321453571, 0.09805558409009661, 0.09630441412861858, 0.1252562209431614, 0.10715547150799207, 0.13242404774895736, 0.08864817103104931, 0.16690385900437832, 0.1906963230243751, 0.8117997305733817, 19.71629864828927, 54.307189668927876, 44.64923184258597, 35.27153655460903, 44.14035620008196, 57.575097697121755, 32.15293141773769, 6.704550887857165, 0.11116121656128339, 0.657878187085901, 2.21475892833301, 6.861964498247419, 7.7260911124093195, 4.872865038258689, 0.4204243416232722, 0.20101990763630184, 0.601383307150432, 11.908330832208906, 55.403420857020784, 63.82622173854283, 68.47762380327497, 65.16226305280412, 62.15397793906075, 58.851429666791645, 56.24210664204189, 55.4916456086295, 59.4398170198713, 59.236373765128, 56.79038551875523, 53.249722480773926, 55.65440368652344, 59.78726863861084, 60.47256251743862, 57.28057745524815, 54.973497595105854, 54.171116147722515, 51.41415779931204, 44.730709893362864, 46.37517826897757, 50.363708291734966, 49.24196679251534, 50.13306283950806, 47.80194221224104, 47.53514180864607, 46.078302587781636, 44.3563027381897, 45.58998319080898, 46.139081954956055, 50.62554768153599, 54.50161763599941, 56.901945795331685, 55.3464560508728, 51.37795421055385, 50.75252948488508, 37.26269224711827, 54.654585702078684, 51.89360434668404, 51.378110545022146, 55.1739044870649, 57.41684900011335, 53.40629666192191, 45.80088186264038, 40.074624742780415, 44.20418235233852, 41.760619027274, 45.535637855529785, 53.7141227040972, 52.87572526931763, 57.48799160548619, 56.38270344052996, 54.53493077414376, 55.16103989737374, 46.053459303719656, 48.48677403586251, 53.27577127729143, 51.33991977146694, 52.89659070968628, 52.9037959916251, 50.91231025968279, 49.37678268977574, 47.01778588976179, 40.76130131312779, 46.167541776384624, 51.694524560655864, 52.525657653808594, 54.00787169592721, 52.865518365587505, 51.47458280835833, 49.498084340776714, 48.22606372833252, 51.1461067199707, 50.363440786089214, 45.01097590582711, 28.582198313304357, 4.78374570608139, 0.12310078660292284, 1.437221524970872, 4.553709958280836, 9.68809563773019, 8.443464824131556, 8.26545979295458, 10.352013383592878, 0.8908250129648617, 0.1737772694655827, 0.6135888493486813, 14.187432033675057, 49.91225603648594, 36.95064517429897, 37.62932784216744, 45.66579498563494, 38.898468426295686, 29.999490124838694, 0.5333840559635843, 0.15340158210269042, 0.18341618510229246, 0.16426312284810202, 0.17374035716056824, 0.07171855946736676, 0.20422817048217567, 0.09658853031162705, 0.19901062973908015, 0.18232332303055696, 0.1828063585396324, 0.13676889746316842, 0.08573336779539074, 0.08085898935262646, 0.15072834411902086, 0.15214197683547223, 0.1178975629487208, 0.07004033880574362, 0.08405993759099926, 0.14665868106697286, 0.22834516423089163, 0.30095796499933514, 0.1721206805003541, 0.10368219323988472, 0.2365195570247514, 0.24653535815221922, 0.14617913322789328, 0.12620397151580878], [0.027985796864543642, 0.050280055563364706, 0.024074587006387965, 0.018148236708449464, 0.03267335086794836, 0.04019207188061305, 0.01913108959394906, 0.04114780202507973, 0.03188166334959013, 0.01674045805287148, 0.020547105664653436, 0.02551657230859356, 0.007840472988651266, 0.020116624389109865, 0.046594623143651655, 0.03580767375284007, 0.05823397197361503, 0.035953297545867305, 0.06100316159427166, 0.04056165972724557, 0.022445667002882277, 0.036796428196664364, 0.02772391288142119, 0.030121350128735815, 0.033135558744626384, 0.021032232757923857, 0.028655565210751126, 0.0406120477377304, 0.039049161065902026, 0.07738212841962065, 0.03524017759731837, 0.048244185878762176, 0.059917736266340525, 0.040421945974230766, 0.01805998644392405, 0.019726105433489596, 0.09734810955290284, 12.206585730825152, 37.41247456414359, 34.75947863715035, 26.616040502275737, 27.549176624843053, 42.23843274797712, 32.35187571389334, 3.993781558104924, 0.1956118614013706, 0.08972478897443839, 0.493989072740078, 0.37105635926127434, 1.54814712703228, 0.9863661634070533, 0.07476924612585988, 0.23420024290680885, 0.341291606426239, 8.92044302395412, 44.47030530657087, 63.43974208831787, 59.39607116154262, 58.328522137233186, 55.959068298339844, 55.628931590488975, 53.80044712339129, 56.29515961238316, 57.88926049641201, 55.115039348602295, 53.981100286756245, 57.751429080963135, 58.793092591421946, 52.50119652066912, 52.071988923209055, 52.22098956789289, 51.16598899023873, 46.92263378415789, 43.13283266339983, 48.937027726854595, 54.03979866845267, 52.115901538303916, 52.746203899383545, 52.65394919259207, 47.976897852761404, 44.219739368983674, 41.97225073405674, 39.821939604622976, 43.93799339021955, 44.55548674719674, 48.47423601150513, 52.8699026788984, 55.553936208997456, 52.99089166096279, 44.647838728768484, 31.952590533665248, 56.28473036629813, 52.910942213875906, 54.12449026107788, 54.79743719100952, 52.3315875189645, 49.723998069763184, 39.522639002118794, 39.37161643164498, 39.97761051995413, 45.99006046567644, 50.63850607190813, 51.79728146961757, 53.28481435775757, 51.57368843896048, 52.489395005362375, 51.38119207109724, 49.54853868484497, 46.217714718409944, 47.70099878311157, 52.17998824800764, 50.12691715785435, 49.221921239580425, 51.612084184374126, 49.91034528187343, 47.72926752907889, 45.79471186229161, 41.86819798605782, 40.88635499136788, 46.14037431989397, 50.61276299612862, 51.256857531411306, 51.897234780447825, 48.36580242429461, 47.97625861849104, 49.50824955531529, 46.44675513676235, 41.93714148657662, 22.108137845993042, 2.497820939336504, 0.45871399130140034, 0.05872998107224703, 0.6569432743958065, 2.221098291022437, 5.037806587559836, 3.8287905028888156, 3.2742749665464674, 0.45924677699804306, 0.07864402034985167, 0.10005315047289644, 12.526342698505946, 38.949593271527974, 30.87792307989938, 19.27107892717634, 30.59561082295009, 29.804680006844656, 20.09724405833653, 1.4935828149318695, 0.12053519141461168, 0.013601845978493137, 0.06834781462592737, 0.06492875130581004, 0.08626985150788512, 0.07274111174046993, 0.049595824243234735, 0.04999920313379594, 0.0027642473412145463, 0.03792165299611432, 0.023320125615490333, 0.08451594705028193, 0.022589228049452816, 0.016770157530637722, 0.017435776635206172, 0.01661451007904751, 0.043130613663899045, 0.009856022245782827, 0.010954122607862311, 0.020806351842890893, 0.0249517190469695, 0.09554082474538259, 0.041825437984828434, 0.05673466403303402, 0.04313170610527907, 0.05160037614405155, 0.006860624316946736, 0.033598872633384805, 0.039794491071786196, 0.010560173657722771, 0.038081376746829064, 0.02488494271944676, 0.030926303006708622, 0.013657512991423053, 0.022941564143236195, 0.03786962293088436, 0.05097322318969028, 0.043223287976746044, 0.03075936982142074, 0.019199957505666783, 0.014661257121978062, 0.033805198169180324, 0.02300400293565222, 0.039929746849728484, 0.041667437713061056, 0.041196436022541354, 0.0289188435833369, 0.02279055617483599, 0.08740094902792148, 0.050980595472667894, 0.07136547698506288, 0.039475135172584226, 0.030407471382724385, 0.02028728273165013, 0.048883179269198856, 0.030860966869762967, 0.04053171597687261, 0.010345058548929436, 0.035295111792428155, 0.03577997595337885, 0.046323924990636964, 0.05038089943783624, 0.03817775586087789, 0.05647907006953444, 0.5378063672355243, 19.7238860811506, 45.75695882524763, 33.34159101758684, 28.792537655149186, 35.33290651866368, 53.24433762686593, 32.24582188470023, 2.7169245651790073, 0.024220879156408564, 0.057936719352645535, 0.16608531506998198, 0.8415767241801534, 2.750480456011636, 2.6785058038575307, 0.5878311172127724, 0.44691426732710426, 0.6999211396489824, 14.296298146247864, 52.54882294791085, 63.26762131282261, 59.70619705745152, 60.576285226004465, 57.381357601710725, 55.43715436117989, 55.63737712587629, 58.26541512353079, 59.67799431937081, 55.95760917663574, 54.436526911599294, 56.8969326700483, 58.547036034720286, 54.60436759676252, 53.41178921290806, 54.13956437792097, 52.78210176740374, 48.88369335447039, 43.326885427747456, 49.9336564881461, 55.50769942147391, 53.22010925837925, 53.52582999638149, 52.266302245003835, 46.95814602715628, 45.00212737492153, 42.43985407693045, 42.33595418930054, 46.69967998777117, 46.287439891270225, 50.771362577165874, 53.698485783168245, 55.95746673856463, 54.59063795634678, 46.62490347453526, 34.177056312561035, 54.65185158593314, 51.89770030975342, 53.810247557503835, 56.843146664755686, 54.82705388750349, 52.10404443740845, 42.10043804986136, 40.603566782815115, 41.49066414151873, 45.11375365938459, 53.14587817873274, 53.51832594190325, 55.112756865365164, 52.30761970792498, 54.2100191116333, 52.84314169202532, 50.825395243508474, 46.20492308480399, 49.002250467027935, 53.74108171463013, 52.92315019880022, 51.68048572540283, 52.80006980895996, 50.35703454698835, 49.670344080243794, 46.691668714795796, 41.80544533048357, 41.93888895852225, 49.53457280567714, 51.94177968161446, 51.39706175667899, 50.58428233010428, 49.09113529750279, 49.504396779196604, 50.20670679637364, 46.566948550088064, 44.87642751421247, 26.96498772076198, 5.014342086655753, 0.8604454802615302, 0.9297860051904405, 1.7008166377033507, 4.990045538970402, 9.916085141045706, 2.932756240878786, 0.9622011972325188, 0.06073045837027686, 0.021503695852256248, 0.07952244499964373, 8.744840332439967, 42.87193822860718, 41.35511520930699, 19.996554238455637, 34.693067755017964, 37.15130567550659, 26.68283874647958, 3.0907048625605444, 0.1948733167456729, 0.004502872886535312, 0.0933137506778751, 0.02277424419298768, 0.011554138402321508, 0.030293029666479145, 0.08892291664545025, 0.0212328976153263, 0.029652336545820748, 0.07339234929531813, 0.05343539946313415, 0.03570746091593589, 0.030065242068043778, 0.008732928894460201, 0.01692314682129238, 0.0061249401104370394, 0.06373732523726565, 0.08758418740970747, 0.05362342490947672, 0.034708158645246706, 0.021828524136383618, 0.06853393678154264, 0.015345893866781677, 0.027158172435260246, 0.01629439422062465, 0.03174101661092468, 0.04237988591194153, 0.01392984386932637, 0.20410156941839627, 0.10397196161959853, 0.08899732479559523, 0.19931314779179438, 0.10915319395384618, 0.11143866274505854, 0.1717816572636366, 0.14345832993941648, 0.19858051996145928, 0.16836173220404557, 0.0708418447258217, 0.09728530435157673, 0.08464651075857026, 0.10550744565469877, 0.12417551821896008, 0.1192535473299878, 0.24099894666246005, 0.07113239342080695, 0.13101850316992827, 0.08427275331424815, 0.1793618705123663, 0.1231894711298602, 0.2409420040036951, 0.12298671129558768, 0.16207418244864258, 0.09805800646011319, 0.11341387818434409, 0.18290743311601027, 0.08952958123492342, 0.1699724250606128, 0.09688727570963757, 0.14392202720046043, 0.20957195945084095, 0.07719451348696436, 0.12132626825145312, 0.15591360016592912, 0.40922761814934866, 19.22229562486921, 54.43189941133772, 47.02500854219709, 37.51208741324288, 36.931037357875276, 53.231063093457905, 41.987627097538535, 5.639363382543836, 0.5089585323418889, 0.17856190486678056, 2.3686178837503706, 5.187289697783334, 4.4572867665972025, 3.57622652394431, 0.5546709480030196, 0.838664071900504, 0.9762893212693078, 12.027675696781703, 49.57572003773281, 64.73031439099992, 61.525068691798616, 61.55921213967459, 60.10810170854841, 58.516359737941194, 58.13242660249983, 59.038127762930735, 61.91810049329485, 56.25633307865688, 55.5881005014692, 60.83734294346401, 63.909426416669575, 55.734023094177246, 56.86972005026681, 58.370850563049316, 55.704003402165, 51.3042060307094, 47.03181777681623, 53.189043862479075, 58.795441082545686, 55.70650822775704, 56.52569389343262, 56.629631996154785, 52.637263093675884, 48.604559898376465, 45.19074664797102, 43.973908628736226, 48.54252290725708, 47.68358659744263, 53.46990394592285, 58.0027871131897, 58.99560478755406, 56.94108847209385, 50.21091045652117, 37.33163227353777, 56.248241901397705, 53.12019763674055, 57.26825482504708, 60.474153654915945, 57.981226852961946, 54.663135460444856, 45.23593078340803, 43.11444078172956, 44.10602167674473, 48.06637328011649, 56.48475858143398, 55.37064273016793, 55.859212262289866, 54.1756637437003, 53.986356598990305, 53.56929097856794, 53.01076698303223, 48.93947696685791, 51.563026428222656, 55.520362513405935, 55.33456073488508, 51.96107830320086, 54.99579783848354, 53.095211914607454, 51.45943226133074, 47.99642923900059, 44.740829944610596, 44.77281945092337, 49.92479753494263, 54.85480151857649, 53.578177724565776, 51.30937549046108, 49.75807898385184, 49.43103075027466, 54.091076374053955, 47.10380111421858, 43.554383346012656, 25.169264010020665, 3.5579156322138648, 0.6374152536903108, 0.6477838658860752, 2.405354312488011, 5.651776773588998, 9.578223773411342, 9.667403902326312, 8.4331328528268, 0.7185856838311467, 0.1912250510816063, 0.3217649427907807, 17.345345735549927, 48.8567864554269, 39.647272314344136, 28.04295904295785, 41.18792765481131, 42.00544227872576, 30.206970282963344, 2.3876379259995053, 0.21911841790590966, 0.10518763174435922, 0.1963740869292191, 0.1121219000113862, 0.10871458213244166, 0.08928596680717808, 0.14663879999092647, 0.14376589629266942, 0.0979185810844813, 0.129236724493759, 0.11309504136443138, 0.17773345432111196, 0.0828571460608925, 0.05153532499181373, 0.08720797366861786, 0.17453804292849132, 0.15525349415838718, 0.1622843790267195, 0.09159586964441196, 0.0819743312895298, 0.18762901904327528, 0.18857963303370134, 0.11985141810561929, 0.16698913728552206, 0.1183864881417581, 0.13789057013179573, 0.1433865273637431, 0.14389451939080442], [0.04464907664805651, 0.07084316786910806, 0.019696690940431187, 0.08823862764984369, 0.015456245713202017, 0.0038395010051317513, 0.03616102086380124, 0.06885130118046488, 0.00988304999191314, 0.04673231825498598, 0.06442288987870727, 0.004663144554277616, 0.021934903160269772, 0.0649248022320015, 0.03454360033252409, 0.029116185315485512, 0.050630128742860894, 0.028579375906182185, 0.056101428012230566, 0.07579304690339736, 0.0145638432420258, 0.017040731851011515, 0.055440711323171854, 0.041295756585896015, 0.04171224477301751, 0.014204481766293091, 0.018239404673555067, 0.03403415284784777, 0.05220034698556576, 0.046104856567191224, 0.054271436030311246, 0.08333722315728664, 0.012139187410606869, 0.04303544573485851, 0.06735460899238076, 0.07729623945696013, 0.04949897015467286, 0.29307317095143454, 12.514401350702558, 38.30148615155901, 31.16984816959926, 34.39632756369454, 33.968874386378694, 40.455156735011506, 33.17759616034371, 3.233501200165067, 0.0690323207527399, 0.048291422094085386, 0.7778024662818227, 3.0792214444705417, 3.6387800702026913, 0.29657416737505365, 0.263416658022574, 0.5103878527879715, 0.055532642640173435, 5.07401191336768, 38.35605730329241, 63.18647330147879, 59.99494334629604, 59.19455255780901, 55.3660569190979, 55.08368212836129, 57.76635033743722, 58.2102290562221, 54.52711405072893, 54.399017061506, 59.6270431791033, 54.796144826071604, 51.98352445874895, 50.96919516154698, 48.80431365966797, 48.472690037318635, 48.44041218076433, 50.108553068978445, 54.002563272203716, 55.267274379730225, 55.62137542452131, 55.108351707458496, 57.22879600524902, 54.256429604121614, 54.03233282906668, 49.30936779294695, 44.89118896211897, 41.08065441676548, 44.27077388763428, 46.160194056374685, 52.39639336722237, 52.63388279506138, 52.786583355494905, 49.35553509848458, 35.27426372255598, 52.31993191582816, 50.60278538295201, 53.828253814152305, 53.51701273236956, 52.4661602292742, 45.449070249285015, 38.120225020817344, 41.50440420423235, 47.57657739094326, 52.16869395119803, 53.775482245853965, 54.74415145601545, 52.700335366385325, 53.22662319455828, 52.473289081028526, 52.30725492749895, 49.47542973927089, 48.17417458125523, 51.84754821232387, 52.53389821733747, 51.53989587511335, 51.03065892628261, 52.43792622429984, 52.226363999503, 50.01937641416277, 45.730423654828755, 46.55129425866263, 42.95157848085676, 45.64468288421631, 48.09594481331961, 50.06689167022705, 51.19249289376395, 51.042915548597065, 50.33832999638149, 47.33734049115862, 37.65467487062727, 16.8678012575422, 1.717252058642251, 0.012082565359638205, 0.20523902481155737, 0.708651714026928, 1.6420201127018248, 3.9791881697518483, 14.535595842770167, 3.3329735653741017, 0.5267276274306434, 0.13662149251571723, 0.19868612715176173, 14.258341874395098, 37.280219078063965, 22.75917363166809, 22.324537754058838, 26.053903443472727, 25.513705321720668, 12.17310323034014, 1.5064554384776523, 0.0538923724421433, 0.0841889406687447, 0.023538610498820032, 0.034413871222308705, 0.02235159321155931, 0.03565327650202172, 0.05464264218296323, 0.011810225151878382, 0.0750654334468501, 0.04023191545690809, 0.04749446914398244, 0.03535479233999338, 0.10361559502780437, 0.017405317198219042, 0.05702718387224844, 0.06316179861979825, 0.03145980116512094, 0.04673519863614014, 0.014253474539145827, 0.12590260697262629, 0.015581966377794743, 0.02831415013809289, 0.00842556610171284, 0.06750347957547222, 0.07460075231002909, 0.0141382346960849, 0.0381921577666487, 0.045914208583001576, 0.037240268130387576, 0.08020568905132157, 0.07928582626794066, 0.0343137194535562, 0.02757693880370685, 0.03938879159146121, 0.03656876612720745, 0.03367717557453683, 0.051509387990725894, 0.029598684781896215, 0.019650699836867194, 0.05632552777283958, 0.009630856337025762, 0.04549466359562107, 0.018241604823353033, 0.012494202869545137, 0.04426913096436432, 0.09093691036105156, 0.04736866196617484, 0.04292975372767874, 0.029738934577575753, 0.053335383401385376, 0.01520940994045564, 0.05791529121675661, 0.02688818165500249, 0.039237919330064736, 0.04822494262563331, 0.006228445962603603, 0.03525347688368388, 0.011966459536259728, 0.05807340344680207, 0.05694943054446152, 0.01803265674971044, 0.002241178266038852, 0.0456262349284121, 0.041693089729441066, 0.04319170895697815, 0.053608619275369813, 0.7370257143463407, 20.48514982632228, 45.55973073414394, 33.09789684840611, 29.75613989148821, 37.88047048023769, 56.46662378311157, 33.995305333818706, 2.666106526340757, 0.15492090343364648, 0.15809571450310095, 0.08666473174733774, 1.4184928728001458, 1.9735826126166751, 3.345437330859048, 1.1998510850327355, 0.4095885173550674, 0.03400117604594145, 8.59124345438821, 44.53629582268851, 63.13202026912144, 59.06396811349051, 59.53461824144636, 58.54119954790388, 58.284084933144705, 59.146825381687705, 59.40497180393764, 55.670443602970664, 53.78971563066755, 59.97601645333426, 57.27818380083357, 54.972160066877095, 53.36243963241577, 50.79956878934588, 51.43727445602417, 50.76083605630057, 49.826473576681956, 54.395949431828086, 56.44897883278983, 58.07452726364136, 57.24400213786534, 58.56878389630999, 55.93675763266427, 54.68167325428554, 49.17088672092983, 45.6313145501273, 42.85214975902012, 46.34443596431187, 47.59241928373064, 53.05948427745274, 54.52295902797154, 55.42868798119681, 52.571560927799766, 35.858419622693745, 54.010383469717844, 52.22599574497768, 54.28097064154488, 55.989459718976704, 54.68975053514753, 46.90514169420515, 41.00054516111101, 43.261805125645225, 48.10673189163208, 54.302075794764924, 55.607965401240754, 55.605512687138145, 56.13112654004778, 54.016737597329275, 53.01056201117379, 54.94112593787057, 50.82767425264631, 48.71250016348702, 51.64251034600394, 53.15020343235561, 53.67397253853934, 52.741385323660715, 54.07851750510079, 54.0923478943961, 51.48877797807966, 47.45963226045881, 47.33248370034354, 44.0511725970677, 47.08143138885498, 51.3286497933524, 52.95067548751831, 51.531957558223176, 50.69814246041434, 49.84121070589338, 48.69908319200788, 41.25414398738316, 21.734760761260986, 2.698042401245662, 0.21583817606525763, 1.1364124034132277, 2.1810015397412434, 3.0945999792643955, 6.905304321220942, 4.543910826955523, 1.2411429264715739, 0.1670317357139928, 0.050366616275693686, 0.10204045062086411, 11.65780918938773, 47.254962648664204, 34.75190510068621, 24.800498792103358, 28.363033022199357, 32.153216293879915, 21.558399847575597, 3.3932956542287553, 0.07654093498630182, 0.05364626779087952, 0.055301224879388294, 0.019232313448031033, 0.02396386705472001, 0.015721137302794626, 0.054986957992826185, 0.028094605043796555, 0.125623919069767, 0.023962029921157018, 0.03788045234978199, 0.051607734856328795, 0.04532077881906714, 0.04854108226884689, 0.04764443216845393, 0.018582522869110107, 0.03704809004973088, 0.04652512419436659, 0.030929658362375836, 0.018838206738499657, 0.06597850604781083, 0.028024505591019988, 0.05503270482378347, 0.029873450752347708, 0.048452737009418864, 0.05437982860686524, 0.021741608889507394, 0.043254833069763014, 0.040217879960047345, 0.12236847089869635, 0.10998512538416044, 0.07324328193707125, 0.1415818277746439, 0.15254694010530198, 0.08383918979338237, 0.10897779265152556, 0.2395765744149685, 0.08346582589937107, 0.1185469888150692, 0.08375381651733603, 0.10816742506410394, 0.10747565861259188, 0.1739652915192502, 0.1040294538917286, 0.11084148407514606, 0.19563510801110948, 0.1541337078171117, 0.13974618698869432, 0.09418415504374675, 0.1230328381061554, 0.12448910996317863, 0.2119662245469434, 0.16807235058929237, 0.17538500390946865, 0.09823070719305958, 0.09913781351808991, 0.12262753556881632, 0.14157606022698538, 0.23962494039109775, 0.1140935734978744, 0.16956599615514278, 0.0734517075387495, 0.11486390073384557, 0.11637303046882153, 0.16752679486359867, 0.15997802492763313, 0.48898995241948534, 20.141255685261317, 54.836010115487234, 43.04735245023455, 45.71457481384277, 43.60564715521676, 49.8484194619315, 42.1213139125279, 5.630906122071402, 0.3727374704820769, 0.35640678820865496, 2.5182071711335863, 10.827762620789663, 10.867178014346532, 1.6882915326527186, 0.3132885747722217, 0.6951767685157912, 0.1043016549998096, 7.074701402868543, 43.37978206362043, 64.02913693019322, 62.08080645969936, 63.245234216962544, 60.094017710004536, 59.89673055921282, 60.816331590924946, 61.758569853646414, 55.2502304485866, 55.36964566367013, 62.34482410975865, 59.15908200400216, 55.967628479003906, 54.4469005720956, 53.13917664119175, 53.43575702394758, 53.14457886559622, 53.129212924412315, 58.2917731148856, 58.672145298549104, 59.8948267527989, 59.25593294416155, 62.44456550053188, 58.44843414851597, 58.855654171534944, 54.07563400268555, 49.9563319342477, 45.00133180618286, 49.33067444392613, 50.14226572854178, 56.22168588638306, 56.453919001988, 58.53797558375767, 54.257100105285645, 40.5499266896929, 51.88190358025687, 50.70061949321202, 56.82735340935843, 57.733652114868164, 57.21330499649048, 48.99237707683018, 42.51278236934117, 45.62129872185843, 51.149657249450684, 56.95028441292899, 57.69504444939749, 58.17984805788313, 57.43297576904297, 55.80662134715489, 55.76305961608887, 57.47661740439278, 51.94870356151036, 53.136675289699006, 54.167617729731965, 54.769964013780864, 55.072651863098145, 54.143462317330496, 56.02609757014683, 55.35834094456264, 53.85005031313215, 49.256592750549316, 50.409326689583914, 46.7518435886928, 49.02959162848336, 52.39316245487758, 55.329624039786204, 52.542190892355784, 52.73588582447597, 50.44603402273995, 47.94913979939052, 40.64504752840315, 20.080623967306956, 2.4039127784115926, 0.22035587579011917, 0.8225507108228547, 2.6466652495520453, 4.142780465739114, 16.792915310178483, 31.453178337642125, 9.069754600524902, 1.0274987391063144, 0.460175555731569, 0.6460781916975975, 18.798889773232595, 47.31695100239345, 30.477164881569998, 31.24680641719273, 37.34396185193743, 40.22161388397217, 22.75967390196664, 2.868371192898069, 0.17138756412480557, 0.13096177764236927, 0.13629154807754926, 0.06311073885964495, 0.15027505558516296, 0.12223861286682741, 0.25715318268963266, 0.1694720054843596, 0.2763257324695587, 0.11565805811967168, 0.0933058728863086, 0.1448928751051426, 0.17457890430731432, 0.11442841695887701, 0.14023931909884724, 0.10911767943097012, 0.07946472202560731, 0.1709814202040434, 0.18309633726520197, 0.11083377591733422, 0.06651635361569268, 0.1816326558057751, 0.22909904377801077, 0.10322275717875787, 0.15070439183286258, 0.14825384904231342, 0.19323578104376793, 0.1228202802262136, 0.14609632481421742], [0.006927895550948701, 0.02218604932672211, 0.02472772615562592, 0.035901627104197226, 0.00976676435675472, 0.04511129470275981, 0.008333315873252494, 0.04515702457034162, 0.027664888816486512, 0.06442502726401601, 0.030276300385594368, 0.010974715297509516, 0.049337495783610005, 0.03231700123952968, 0.007252165315938848, 0.044460311598543606, 0.017116142536646554, 0.04491729814825313, 0.03965014631726912, 0.019748208711722066, 0.03092900357608284, 0.012915865734352596, 0.07399509195238352, 0.07586631511471101, 0.10966032424143382, 0.05575523266036596, 0.0027562476253868745, 0.04039372909548027, 0.041126434957342486, 0.027069830568507314, 0.02550989043499742, 0.0453601033160729, 0.006399158587945359, 0.051874148060700724, 0.00795795114910496, 0.010609419184869953, 0.05151317760880504, 0.0363615042130862, 0.12316045697246279, 9.0004107100623, 39.92951161520821, 36.854888575417654, 32.84466280255999, 32.75923817498343, 46.33677557536534, 39.26196690968105, 6.000648430415562, 0.1545144473867757, 0.058299850938575606, 1.0274326226540973, 1.1196985117026736, 5.976539484092167, 12.612492544310433, 7.777399216379438, 0.6872398086956569, 0.11909506869103227, 1.9983755222388675, 28.415248734610422, 54.0944254057748, 62.7825745173863, 62.51033020019531, 61.109892981392996, 59.209810801914756, 59.35083144051688, 55.034895351954866, 58.33593586512974, 58.64838245936802, 57.0790901184082, 54.11453001839774, 54.63849367414202, 52.00747489929199, 54.82316289629255, 51.35615076337542, 52.22950805936541, 58.38824190412249, 55.76043667112078, 55.773228304726736, 53.36109515598842, 53.061110155923025, 54.71009833472115, 55.21484327316284, 55.75400611332485, 48.25513846533639, 45.39968940189907, 42.72722462245396, 46.92239754540579, 54.181350844247, 57.723156860896516, 59.59867368425642, 51.91710662841797, 32.453837054116384, 58.596882411411826, 55.421569551740376, 55.192174775259836, 53.28777429035732, 52.49013498851231, 40.52709490912301, 41.23075635092599, 46.70121553965977, 50.32992615018572, 54.68869093486241, 56.57639142445156, 55.141716957092285, 54.127307755606516, 51.62696375165667, 55.29848221370152, 53.86621182305472, 50.62925454548427, 52.13792037963867, 52.0481253351484, 54.78432246616909, 52.19150141307286, 52.010049206869944, 53.75537068503243, 53.10266733169556, 50.70221063068935, 48.70115375518799, 49.5134676524571, 48.898267201014924, 47.716093744550435, 51.055495262145996, 52.4720071383885, 52.378380162375315, 51.05284105028425, 45.42797899246216, 31.31282820020403, 8.999920862061636, 0.7946431083338601, 0.08893384105925049, 0.16305438056588173, 4.495584802968161, 2.9199976112161363, 1.7006043919495173, 2.605735148702349, 2.7680958764893666, 0.1922041228307145, 0.12404912071568625, 0.676307632454804, 14.646741833005633, 37.470554556165425, 24.315648283277238, 25.895166635513306, 24.678408520562307, 25.629978213991436, 8.573000958987645, 0.16461685672402382, 0.02244860675585057, 0.020630217722750137, 0.024715205488194312, 0.053228388606969795, 0.030081574405942644, 0.04945546927462731, 0.023716373103005544, 0.08047989862305777, 0.09809325635433197, 0.016776145602177297, 0.055558949442846436, 0.056852440748895915, 0.05906466847019536, 0.028399693047893897, 0.05685170453840068, 0.017061842771779214, 0.0530053337902895, 0.05666195900578584, 0.038928609141813855, 0.014219790364482572, 0.007748458551109901, 0.05492462098066296, 0.01737997561161007, 0.03930417488196066, 0.038844684538032324, 0.08140869771263429, 0.015763374411367943, 0.08388450236192771, 0.03766631009057164, 0.07028334255197219, 0.021024107301075543, 0.015705624295930778, 0.02888508646615914, 0.05206755089706608, 0.026619176446859325, 0.036727383865841796, 0.031234232376196554, 0.0280436012627823, 0.064492304011115, 0.07857297773339919, 0.018038614287174175, 0.007861029207041221, 0.05579685739108494, 0.04546351205291493, 0.03840711087520633, 0.02174755115993321, 0.01876374430555318, 0.04730076775220888, 0.025401396078190634, 0.07059099032942738, 0.047538065018930604, 0.03249918110668659, 0.04456661089456507, 0.0720499288290739, 0.018122186052746007, 0.011510149825231304, 0.019503973424434662, 0.013622866993370866, 0.03481609321066311, 0.04077993765739458, 0.023014528710129004, 0.044317534259919605, 0.01588609255850315, 0.05539987708574959, 0.03607685877276318, 0.049753115445907624, 0.020875506435653994, 0.03627778995516045, 0.4480807233069624, 15.898046391350881, 45.75881052017212, 39.46801921299526, 30.784494127546036, 34.72848619733538, 58.218632902417866, 34.95000171661377, 5.355692318507603, 0.184413753716009, 0.1259473767131567, 0.18581961042114667, 0.48190490688596455, 4.013010263442993, 8.241517169134957, 6.363351779324668, 1.1687711413417543, 0.35174291847007616, 4.6779085738318305, 37.09629678726196, 58.665363856724326, 64.36513791765485, 61.69302749633789, 63.26887198856899, 60.68723406110491, 60.94378934587751, 53.6509427343096, 57.84326342173985, 60.01760837009975, 57.13659340994698, 53.914727619716096, 54.38281386239188, 54.751818793160574, 56.68428305217198, 54.58434288842337, 55.26898711068289, 59.64965956551688, 58.1764886038644, 56.28022793361119, 54.26684495380947, 56.80418464115688, 55.306076594761436, 56.61215032849993, 55.77933577128819, 49.41135345186506, 45.98887232371739, 44.78422491891043, 50.66346400124686, 57.30857522147042, 59.38095188140869, 60.51173646109444, 51.95050661904471, 35.55583599635533, 57.48396165030343, 55.23838029588972, 58.17652334485735, 54.678133147103445, 55.562319210597444, 44.06778573989868, 43.05158390317644, 48.192795753479004, 52.55325937271118, 56.42105402265276, 58.10551970345633, 55.05955798285348, 53.83493103299822, 53.075114250183105, 53.98253161566598, 53.74931880405971, 52.52524423599243, 52.200693879808696, 55.54714087077549, 56.48934439250401, 52.79953479766846, 53.307097230638774, 55.02842657906668, 54.032464844839915, 51.766796248299734, 49.33775813238961, 52.424231324877056, 48.95421757016863, 48.34260586329869, 50.67538711002895, 53.2379035949707, 53.61715711866106, 51.279699734279085, 45.7789602960859, 35.204799107142854, 12.321104202951703, 1.7529326868908746, 0.6808846497109958, 1.2328300582511085, 2.990240207740239, 5.991276179041181, 6.5481182762554715, 4.271020327295576, 1.1221989946705955, 0.09990518912672997, 0.19554794340261392, 0.39316379012806074, 11.904207944869995, 40.127830573490684, 29.9904922076634, 21.38751064028059, 26.619257518223353, 29.81393153326852, 16.89231971332005, 1.1828125821692603, 0.0511320071694042, 0.011883903028709548, 0.010702249560771244, 0.01242870558053255, 0.02421010402031243, 0.059272340898002894, 0.04309556733018585, 0.023959215697167174, 0.07160766648926906, 0.027966923412999938, 0.1023900250771216, 0.036227663180657795, 0.06926418295396225, 0.016567256900348833, 0.06281649214880806, 0.02474917804024049, 0.01851499845672931, 0.0361891563183495, 0.0208940779391144, 0.02503091935068369, 0.02472535128306065, 0.013670927628741732, 0.05026659342859473, 0.04828531188624246, 0.03450349212757178, 0.0375761158232178, 0.0057548378494435126, 0.011625091112884027, 0.08046039752662182, 0.06763901694544724, 0.1295997542994363, 0.1246758292296103, 0.1374283113649913, 0.12735062784382276, 0.11505874884980065, 0.08987815145935331, 0.0677801590146763, 0.10554198308714799, 0.13607120061559336, 0.1780165255601917, 0.2019925604441336, 0.07779861999941723, 0.10567904037556478, 0.16606657393276691, 0.1969905767057623, 0.15102423966995307, 0.057115936252687655, 0.09131277126393147, 0.13914493710866996, 0.1374441348016262, 0.11592609302273818, 0.09869635184960705, 0.16289978314723286, 0.21152597745614393, 0.19682443062109606, 0.09268443658947945, 0.10051025237355914, 0.14734801836311817, 0.15382048248180322, 0.12069577351212502, 0.11010421506528344, 0.15854578678097042, 0.12277924242828574, 0.19483925428773674, 0.12994894199073315, 0.11045309741582189, 0.06548850876944405, 0.06817300364907299, 0.4056724746312414, 14.716022321156093, 54.08171020235334, 50.177343709128245, 44.12599427359444, 40.69000584738595, 56.008188588278635, 48.90095615386963, 9.02736450944628, 0.33324323115604265, 0.22069158777594566, 2.958843252488545, 5.375116007668631, 15.577574627740042, 22.538875784192765, 11.885075211524963, 1.1355709114245005, 0.30444080382585526, 3.0377398303576877, 31.644087042127335, 56.32086099897112, 67.23420197623116, 65.73668452671596, 66.31431606837681, 61.37377861567906, 60.90047427586147, 54.663607937949045, 60.47962883540562, 61.12904221670968, 61.01860754830496, 58.0250734601702, 59.87083462306431, 59.13332503182547, 60.6610324042184, 56.81664276123047, 57.65014171600342, 62.19323526109968, 59.68923650469099, 58.261628355298726, 54.478511401585166, 56.210374219076975, 57.318594523838584, 60.36836733136858, 59.51954065050398, 52.33213990075247, 50.02840212413243, 46.36219555991036, 52.96647916521345, 59.58014283861433, 62.7632029397147, 63.10746533530099, 54.466748101370676, 38.43637500490461, 60.93379088810512, 57.89009428024292, 59.582873480660574, 56.56024381092617, 58.303807394845144, 45.28582927158901, 46.16715267726353, 52.747009890420095, 53.51941333498274, 57.61004018783569, 60.42626667022705, 57.88817310333252, 56.93247965403965, 54.1898832321167, 56.14013835362026, 56.15403822490147, 53.013594899858745, 56.86416843959263, 56.43638869694301, 58.982681138174875, 53.317029680524556, 55.63869728360857, 58.29319749559675, 55.79617125647408, 54.128565379551475, 51.06321471078055, 55.104988779340474, 52.57559435708182, 50.967187132154194, 54.07049233572823, 56.24843645095825, 52.809581892830984, 52.79804788316999, 47.47104467664446, 34.472181047712056, 10.29233877999442, 1.5516607442072459, 0.30755514385444777, 0.6830720294799123, 7.659635935510908, 8.38707411289215, 7.75456656728472, 13.616107719285147, 9.301931262016296, 0.7423070509518895, 0.29845332939709934, 1.3311365374497004, 19.16787212235587, 46.794390882764546, 33.38053567068917, 34.53211620875767, 34.36748559134347, 37.901217801230295, 16.974848679133824, 0.9538938658578056, 0.14307239279150963, 0.15009299106895924, 0.11832003242203168, 0.11829859071544238, 0.11314380089087145, 0.10164852200874261, 0.16991014911660127, 0.12869320437312126, 0.22840840369462967, 0.12067885084875993, 0.1742277488644634, 0.1331788365330015, 0.11119983198919467, 0.06904916199190275, 0.12495026950325284, 0.14607287464397295, 0.1240609407957111, 0.15971938094922475, 0.13186450063117913, 0.08574173413217068, 0.09093218097197157, 0.12581673158066614, 0.13799068118844712, 0.13680515837456497, 0.14897093842072145, 0.1499492773520095, 0.07654104355190482, 0.22217094339430332, 0.11563462152012757, 0.1851644441485405], [0.07415184711239167, 0.013387420430912502, 0.04909019012536321, 0.01882059875476573, 0.022925744099276404, 0.04535535017826727, 0.0741994802707008, 0.017447608589593853, 0.059477421322039196, 0.005189089769763606, 0.03519319583262716, 0.04241551239309566, 0.059990658424794674, 0.06294699478894472, 0.0316913580255849, 0.0208308469570641, 0.08011337436203446, 0.008797213302126952, 0.07142408883997373, 0.017962821925591146, 0.04853614592658622, 0.05996993596532515, 0.03262461169755884, 0.030664999171027114, 0.05917963944375515, 0.009401982234391783, 0.0556150439328381, 0.017470319156668017, 0.03744136555386441, 0.03975989257118531, 0.0877430731696742, 0.07548893429338932, 0.07115945339735065, 0.005300786387774029, 0.02230548336436706, 0.06216401966022594, 0.04552611369373543, 0.03333190642297268, 0.06100267983440842, 0.1268904861062765, 8.688348872320992, 37.96863269805908, 43.1181754384722, 27.616895505360194, 26.234391587121145, 43.04589680262974, 43.393417903355186, 9.502948726926531, 0.41619082593492096, 0.05461898505953806, 0.3130645496504647, 4.893579355307987, 20.249399185180664, 9.117771863937378, 8.125034962381635, 0.8713460096291133, 0.12258302367159299, 2.753213269369943, 22.783864055361065, 46.359774112701416, 56.324116230010986, 62.09810747419085, 61.77323750087193, 59.115322249276296, 59.10929816109793, 56.88560710634504, 60.65322262900216, 56.890394415174214, 54.86548784800938, 57.925061089651926, 56.46164192472185, 54.88197939736502, 53.995472635541645, 55.45072071892874, 57.02515472684588, 55.92411885942732, 54.55950655255999, 54.506922585623606, 53.03669766017369, 58.327313150678364, 59.23759664808001, 56.394859313964844, 51.15521580832345, 46.83534703935896, 45.659729208265034, 47.92912898744856, 52.93794986179897, 56.54900162560599, 57.49139622279576, 55.493702275412424, 31.176261356898717, 58.06777708871024, 56.75676665987287, 54.902417523520334, 56.0288872718811, 48.72053575515747, 42.71292175565447, 42.63860034942627, 46.2253612109593, 51.38345718383789, 55.63153369086129, 55.897027833121165, 57.76614883967808, 55.990984848567415, 57.72288588115147, 54.615515981401714, 55.56869765690395, 55.060766969408306, 52.706852776663645, 52.88414648600987, 53.69295154299055, 54.132331303187776, 53.103264876774375, 51.0886937550136, 52.89276572636196, 52.20775672367641, 51.21799973079136, 50.60753795078823, 52.282623563494, 50.453979287828716, 50.72857209614345, 53.84419992991856, 52.54492153440203, 46.16003772190639, 23.26380739893232, 4.429807075432368, 0.28054915155683247, 0.1286372523754835, 1.113104671239853, 1.3239424377679825, 1.0218261863504137, 3.655035597937448, 6.625366611140115, 4.39323262657438, 0.061432735329227786, 0.08649430410670382, 1.1396643774850028, 19.56840624128069, 39.53474971226284, 43.101211411612375, 50.14816474914551, 40.203739643096924, 26.711149181638444, 11.929618375641958, 0.8659867229206222, 0.04558302242574947, 0.02633655982624207, 0.03984510978417737, 0.0314067057999117, 0.03408993181905576, 0.058249713986047676, 0.038469939825258086, 0.08642732591501304, 0.10779120453766414, 0.07338177771972758, 0.05745465414864676, 0.03330283798277378, 0.008454590437135525, 0.04919271676668099, 0.05249834938773087, 0.05891284625977278, 0.004674300094068582, 0.04484774830884167, 0.06397596600332431, 0.012282496551051736, 0.056777428702584336, 0.09617874944316489, 0.07238884350018841, 0.06189476339412587, 0.03264382441661187, 0.005452937687680657, 0.040682706981897354, 0.016632253769785166, 0.07173056275184665, 0.049315619814608774, 0.02692919740054224, 0.0434582137635776, 0.019301824271678925, 0.060661797411739826, 0.05650526491392936, 0.023494115564972162, 0.04024389159998723, 0.06629907991737127, 0.02128659687670214, 0.010613806761934288, 0.050426347713385306, 0.07281285324799162, 0.06352870286043201, 0.029781624608274018, 0.023304748315630213, 0.026536266252930676, 0.04093325264485819, 0.04804561599822981, 0.07053106890193053, 0.0666376892477274, 0.02973282097705773, 0.04338994974802647, 0.04789780392976744, 0.0014120155766639592, 0.039979113665010245, 0.08342269821358578, 0.013487394084222615, 0.057983090435819964, 0.0668136469487633, 0.028439702865268503, 0.04239794172878776, 0.026915450281064426, 0.009324166142115635, 0.03364544388438974, 0.03277862218341657, 0.018434049229004552, 0.05841941559421165, 0.03195976951558675, 0.01031058472913823, 0.03609173565304705, 0.26334337624056, 16.235968555722916, 44.561701910836355, 44.1376359803336, 26.04822850227356, 30.29464612688337, 59.13390868050711, 40.012136118752615, 6.507266776902335, 0.24655180584107125, 0.08049068732985429, 0.11799808112638337, 0.9045953654817173, 20.783866780144827, 16.61287358828953, 3.6799114516803195, 0.7773186436721257, 0.1619146317243576, 5.0699228984969, 30.144408702850342, 51.02529491697039, 60.08624267578125, 63.44678061349051, 62.85641302381243, 58.24113811765398, 58.359142848423545, 58.598244258335654, 61.22914491380964, 58.93802506583077, 57.57505600793021, 59.58684090205601, 56.888619150434224, 56.589791025434224, 55.228420053209575, 57.63812828063965, 58.80766296386719, 56.34095171519688, 57.62006296430315, 55.67321593420846, 54.76208128247942, 59.0154835837228, 59.534673827035085, 57.13761132104056, 52.74373728888375, 48.642702034541536, 45.809056418282644, 49.195768220084055, 54.894767556871685, 56.814075401851106, 59.17962782723563, 56.60539320537022, 34.45449093409947, 58.40042209625244, 56.97348097392491, 56.62698820659092, 56.76801926749093, 51.076683793749126, 43.123584611075266, 44.83744812011719, 48.1940255846296, 52.42506858280727, 58.935405594961985, 57.92291062218802, 57.60354362215315, 57.10873113359724, 57.674175534929546, 56.3918959072658, 56.48686735970633, 57.185053621019634, 53.75719806126186, 54.57934365953718, 55.27387169429234, 56.03389344896589, 51.946209158216206, 52.242007868630544, 54.01547302518572, 53.755999497004915, 53.34115382603237, 52.82948153359549, 52.29258033207485, 49.41311829430716, 50.73839684895107, 53.23004865646362, 53.888272353581016, 47.83718694959368, 29.0984651020595, 7.054129089627947, 0.901791550219059, 0.4871111160942486, 3.675319995198931, 3.56383940577507, 3.8832257304872786, 7.314523254122053, 2.617335166249956, 0.38263184098260744, 0.13598350674978324, 0.17274989959384712, 0.6477571587477411, 17.43269501413618, 46.87603916440691, 46.591371468135286, 40.26476567132132, 40.27750519343785, 30.5824613571167, 18.098679849079677, 1.5722053732190813, 0.07850410642900638, 0.01168722371637289, 0.1301543481115784, 0.01960280035356326, 0.0027629784807296737, 0.07738924625196628, 0.03388557064213923, 0.07874670305422374, 0.04756626493430563, 0.060200705725167475, 0.036633488189961226, 0.009164300747215748, 0.045814050028898885, 0.011777507041447928, 0.02702860108443669, 0.017065802023613026, 0.005299738475254604, 0.05172985419631004, 0.014815406707514609, 0.018803226561950784, 0.03049779117905668, 0.08765292979244675, 0.042672466819307635, 0.016152107123551623, 0.017285747453570366, 0.06037346074091537, 0.03364583064935037, 0.019457788938390355, 0.02429931441188923, 0.024164224875026515, 0.013298819872683712, 0.335189513862133, 0.08946457079478673, 0.18828339821525983, 0.1549626061958926, 0.07878373749554157, 0.18278186342545918, 0.15585653537086078, 0.15697704095925602, 0.10404179644371782, 0.1211151760071516, 0.16976988235754625, 0.14142504547323498, 0.1410286317446402, 0.24697933718562126, 0.12887655810586043, 0.1224182482276644, 0.14166120280112537, 0.2014826549483197, 0.1288300377449819, 0.0882375216377633, 0.11518438639385359, 0.13576899468898773, 0.1026873251955424, 0.05785557334976537, 0.15821785080645764, 0.10668141980256353, 0.13446350688380854, 0.13554503742073262, 0.13440602139702865, 0.12598118132778577, 0.13864518249673502, 0.17739128268190793, 0.1698712826307331, 0.06543236678200108, 0.09744290089500801, 0.18680463970771857, 0.13161406692649635, 0.061397193664950986, 0.10076726786792278, 0.3065471393721444, 14.450109549931117, 53.82594701222011, 55.27275650841849, 38.76178693771362, 36.731895038059776, 54.55839484078543, 52.615893908909385, 12.997592108590261, 0.8908236558948244, 0.45121482227529797, 0.9945137947797775, 9.897582956722804, 31.094790254320415, 13.737537911960057, 12.655776347432818, 2.2761532110827307, 0.23210180550813675, 4.19034913608006, 26.24497890472412, 49.40675721849714, 59.64990970066616, 65.26721559252057, 64.53254086630685, 59.27413722446987, 59.945937701633994, 59.531561034066335, 63.969681194850374, 60.5345960344587, 60.963077545166016, 62.152678625924246, 59.31528445652553, 60.39035837990897, 57.48665755135672, 59.90261568341936, 59.982693672180176, 58.58877386365618, 58.40092236655099, 56.608794348580496, 55.728937012808665, 62.641095297677175, 62.523316383361816, 61.056836536952424, 54.73748813356672, 52.145632880074636, 49.63896254130772, 52.24331065586635, 58.26508160999843, 59.56311975206648, 61.03729820251465, 56.34482881001064, 37.97725888660976, 57.826049259730745, 56.50550937652588, 60.4777250289917, 59.48432718004499, 52.54481036322457, 45.009061677115305, 47.1744886125837, 49.824938024793354, 55.354491642543245, 59.116572925022666, 60.07938480377197, 58.39863640921456, 56.85048048836844, 58.7236453465053, 59.21926730019705, 58.842501231602256, 60.130641664777485, 56.57893099103655, 56.59731592450823, 55.6724134172712, 57.15660422188895, 53.92853716441563, 53.24646030153547, 54.8009147644043, 57.00079434258597, 56.15859971727644, 54.66290964399065, 54.88815982001168, 52.646542412894114, 52.84439584187099, 56.26479598454067, 54.08798442568098, 48.65560483932495, 25.692635331835064, 5.9319937144007, 0.6954795036997113, 0.28219375759363174, 2.9232013821601868, 4.00381475687027, 2.7697347828320096, 10.875634840556554, 14.225361381258283, 9.992803675787789, 0.9122471234628132, 0.23550693850432122, 2.197290505681719, 25.293504749025615, 49.86235407420567, 50.95385701315743, 53.86277593885149, 47.92906992776053, 39.22994613647461, 18.628209011895315, 1.469532168337277, 0.18391815173838819, 0.1892873179167509, 0.21154218087238924, 0.10529033480478184, 0.23139452774609837, 0.23737065706934246, 0.1432624775916338, 0.1928215625562838, 0.14086981383817537, 0.22362409399024077, 0.07814982972506966, 0.08812204176293952, 0.074228596208351, 0.15683083023343766, 0.0927956077669348, 0.11207747632371527, 0.08326820257518973, 0.11422126021768365, 0.14852288817720755, 0.046329672182244916, 0.17685403222484247, 0.17561723930495127, 0.13013894536665507, 0.08647020254284143, 0.14237515734774725, 0.14016632230154105, 0.16601795011333056, 0.114679841324687, 0.1597222172256027, 0.10834640224597283, 0.11622011581701891], [0.03324973243953926, 0.02963452160890613, 0.02150551262976868, 0.024643184084977423, 0.028363966482824514, 0.00888779348627265, 0.019355718611872623, 0.08125230896153621, 0.017167872350130762, 0.008230293053202331, 0.024960244839478816, 0.015740121016278863, 0.01411056234168687, 0.04696526950491326, 0.06776104468320097, 0.03717792433287416, 0.02992907366050141, 0.025525462813675404, 0.03570329810359648, 0.012407953435155963, 0.021825979630063688, 0.03250537613140685, 0.038033434855086465, 0.027679560439927236, 0.06739067312862192, 0.06477512419223785, 0.03418211419401424, 0.031513666667576344, 0.021382752074194804, 0.05556198588705488, 0.01135383062397263, 0.05686996391575251, 0.026374104865161434, 0.022392395218568187, 0.017229905717873147, 0.07189126020031315, 0.08810952279184546, 0.015307563423578228, 0.04221395695848124, 0.05949952799294676, 0.13749175438923494, 6.817780903407505, 32.612273352486746, 43.21723590578352, 29.925648144313268, 33.99032000132969, 48.694024903433665, 46.86186483928135, 17.8869925567082, 1.2055495849677493, 0.02699545634511326, 0.1674400373761143, 4.332996087414878, 3.8625995687076022, 1.8891144480024065, 1.11294301705701, 0.24258324450680188, 0.10781082777040345, 2.2199668203081404, 13.672526223318917, 29.823787552969797, 47.29664141791207, 54.83132355553763, 58.83974279676165, 58.366167477199006, 61.52705587659563, 58.916624614170615, 59.80953066689627, 59.93723160879952, 59.90199729374477, 56.479342460632324, 59.73922879355294, 59.41387244633266, 58.15954194750105, 58.940130370003835, 59.69732420785086, 57.54291711534773, 55.65239913122994, 55.73580183301653, 57.46809891292027, 56.55235413142613, 55.34120668683733, 52.74727392196655, 48.44702339172363, 50.88543810163225, 50.26239660808018, 58.45065062386649, 59.102398599897114, 62.12774848937988, 48.38374614715576, 17.653814486094884, 58.908043588910786, 56.01634577342442, 58.07038613728115, 59.86881269727434, 50.1258818762643, 46.33755029950823, 45.39412042072841, 46.34219864436558, 49.49858113697597, 50.9895464352199, 55.41307537896292, 57.302047388894216, 57.19665363856724, 55.18266616548811, 55.408986364092144, 54.96297107424055, 56.695865699223106, 52.9286219051906, 56.554640088762554, 57.5729124886649, 56.78282240458897, 54.72119460787092, 55.030076776232036, 54.8923739024571, 56.11192519324166, 53.233130182538716, 53.6104416847229, 52.29804856436593, 51.27366869790213, 53.507740361349924, 52.76263986315046, 41.27400541305542, 16.918740238462174, 2.3899006502968922, 0.15750726179352828, 0.41420165981565205, 1.4573128925902503, 4.550859025546482, 7.362221768924168, 9.824566943304879, 6.667730212211609, 1.7210585858140672, 0.20835905096360616, 0.14566013536282948, 3.408689388207027, 24.88065321104867, 41.362796442849294, 26.848424741200038, 21.64631540434701, 31.74321699142456, 28.900333745138987, 10.99845380442483, 0.5979390091129712, 0.05240163779152291, 0.04295246090207781, 0.02604456415532955, 0.05468666214229805, 0.03164113964885473, 0.09943181595632009, 0.03275632891537888, 0.04690839469965015, 0.06974789021270615, 0.011573887164039271, 0.025755528593435884, 0.05843442478882415, 0.01564001844131521, 0.09061233313488108, 0.030405384887542044, 0.024620454858190248, 0.0466187993463661, 0.01342783058394811, 0.02297199304614748, 0.028119032304467897, 0.026550880200894814, 0.026606908533722162, 0.02405498073702412, 0.035518122504332235, 0.053846133673297505, 0.03388365038803645, 0.038244062302900214, 0.02933315367304853, 0.08093865614916597, 0.044744539739830155, 0.03875699067222221, 0.04258585521685226, 0.04489023817170944, 0.03683151524247868, 0.07186973706952163, 0.025720185400652032, 0.009657174165892814, 0.017264387171183313, 0.03495610551908612, 0.027967284732897366, 0.013450736229840134, 0.031067957369876758, 0.04060933020498071, 0.03983633293371115, 0.064433868575309, 0.029331715178808997, 0.018141775358734385, 0.0605146638782961, 0.051267819346061776, 0.014870442682877183, 0.04745699704757758, 0.03564886263172541, 0.027621586407933916, 0.02699725446291268, 0.03448874416894146, 0.0422227643430233, 0.0585488597197192, 0.035275074653327465, 0.009918741782062819, 0.024287289075021232, 0.05331129201554826, 0.023535451918308224, 0.03685873467475176, 0.05276072870141693, 0.057252036806728156, 0.025070231973326633, 0.10711265594831534, 0.047935937597815476, 0.03875313998599138, 0.03435012285730668, 0.01763752375596336, 0.06588585887636457, 0.223119942471385, 13.028110333851405, 41.73654351915632, 42.97562619618007, 27.036962372916086, 34.9668094090053, 59.168204988752095, 52.11323690414429, 16.331744262150355, 0.7274958799992288, 0.009281834038639707, 0.419836377458913, 3.5039296490805487, 2.2896767939840044, 2.5068488206182207, 0.9903700628450939, 0.561652313385691, 0.45420892589858597, 3.8206424372536794, 19.77922327177865, 35.29452814374651, 51.94916214261736, 56.26007815769741, 58.74151611328125, 56.96858596801758, 59.44728633335659, 61.811299732753206, 60.182794843401226, 60.44766017368862, 60.256779261997764, 59.672998564583914, 60.40185764857701, 59.58732032775879, 60.728082520621165, 59.98294380732945, 59.719898905072895, 57.16971894672939, 55.91062545776367, 54.96048709324428, 59.67905044555664, 58.353751046316965, 57.26903302328927, 53.54709495816912, 50.85706513268607, 51.399392877306255, 52.58974436351231, 59.96864441462925, 61.953237533569336, 62.534461293901714, 50.911570276532856, 22.006560393742152, 58.28604779924665, 56.10417447771345, 61.17836053030831, 61.6785682950701, 51.96270070757185, 47.1395218031747, 47.29190969467163, 48.47324936730521, 51.76176575251988, 52.85968535287039, 58.02866220474243, 59.32724230630057, 57.559335708618164, 55.50986378533499, 55.667184897831504, 55.06490114756993, 58.70908192225865, 55.67001976285662, 57.6348626273019, 59.493846212114605, 56.311929089682444, 54.16615513392857, 53.43380805424282, 55.723510469709126, 55.03876549857003, 53.087589740753174, 54.282071931021555, 53.00718866075788, 52.41961424691336, 54.10239846365792, 54.04340478352138, 45.120684487479075, 22.391976969582693, 5.368784461702619, 0.6208159529737064, 1.0667482444218226, 3.1805646121501923, 4.09636823620115, 15.951841081891741, 7.340613739831107, 2.7231397288186208, 0.4905916750431061, 0.2593348356229918, 0.09560278177793537, 1.9378217543874467, 25.066703387669154, 50.07287754331316, 34.223216669900076, 27.93564932686942, 38.739980016435894, 37.13293463843209, 17.534520864486694, 1.649358604635511, 0.045181560396615944, 0.06695972196757793, 0.03246945109484451, 0.04386859852820635, 0.04371661346937929, 0.024586312672389404, 0.11363807293985571, 0.05195239671905126, 0.05326880893803068, 0.03980746805401785, 0.06243722500013454, 0.08135281356849841, 0.027331507598449076, 0.01829564504857574, 0.024588450057698146, 0.07635613597397294, 0.02650449554702001, 0.015783474314957857, 0.030595656284796338, 0.04866543398903949, 0.04396348486521414, 0.017414404478456293, 0.020822480620284165, 0.02146487856017692, 0.05894036764012916, 0.04799245956486889, 0.018638133902900984, 0.008517551701515913, 0.07974598836153746, 0.03434441298512476, 0.03191809728741646, 0.006128080455320222, 0.1041857340772237, 0.14582887345126697, 0.17282349350196974, 0.12361028497772557, 0.10506983127977167, 0.12019502823906285, 0.0972647854526128, 0.09023955278098583, 0.08398184499570302, 0.07042999432555266, 0.15843872752572807, 0.10406854429415294, 0.12560675213379519, 0.13869495982570307, 0.12475192014660154, 0.10464744323066302, 0.1366846234138523, 0.122845073895795, 0.12269408628344536, 0.0817388796380588, 0.11615916980164391, 0.11484659809087004, 0.16372850510690892, 0.08501552524311201, 0.1411756295710802, 0.22894070084605897, 0.09166164682911974, 0.10446666793099471, 0.13092881441116333, 0.12309154495596886, 0.04002097249031067, 0.1893438534545047, 0.10047222048576389, 0.10536664963832923, 0.11460962652095727, 0.1806884336152247, 0.11210714866008077, 0.146850801472153, 0.13280680935297692, 0.15202077691044125, 0.2464000311281, 11.642722913197108, 46.77902841567993, 55.095598288944785, 40.271227496010916, 45.05891500200544, 56.562623568943565, 57.17011151994978, 22.699332271303447, 2.08577104977199, 0.1287222592426198, 1.1014617702790668, 8.213198917252676, 11.02402925491333, 3.3707824051380157, 4.071286107812609, 0.7607393733092717, 0.28639836769018856, 2.9259967293058122, 16.275321415492467, 32.81841598238264, 49.51628514698574, 57.50319078990391, 60.140244075230186, 59.223686354500906, 61.99085508074079, 62.91014344351632, 61.87254810333252, 63.34217548370361, 62.92481803894043, 62.429863112313406, 63.76753725324358, 63.60783985682896, 63.005007198878694, 63.40609891074044, 63.028915950230186, 59.951572690691265, 56.632828167506624, 56.81642389297485, 61.866301672799246, 58.17250381197248, 59.31434644971575, 57.36845132282802, 54.25395604542324, 54.83290774481637, 55.645791394369944, 61.70412376948765, 64.20941489083427, 66.8979994910104, 51.45372084208897, 24.091845069612774, 58.347977093287874, 58.081260068076, 64.71932928902763, 65.43065111977714, 55.11315638678414, 50.15825700759888, 50.2486252784729, 50.64768116814749, 53.01252487727574, 55.23875897271292, 59.65642711094448, 60.93743174416678, 60.04292065756661, 55.996466977255686, 58.50043446677071, 55.33145489011492, 58.16708074297224, 55.8998418535505, 59.69872774396624, 60.66517353057861, 59.36853545052664, 56.558902808598106, 55.948427132197786, 56.67789765766689, 57.50236395427159, 55.21146992274693, 56.46588727406093, 55.22715548106602, 57.018352440425325, 58.590365001133506, 55.36799546650478, 44.20907735824585, 19.955851691109793, 4.048519466604505, 0.6639689888272966, 0.8064135195953506, 3.8436136160578047, 8.497014590672084, 13.52910237652915, 21.0777964251382, 14.763542788369314, 6.3210576602390836, 0.8541590975863593, 0.26695760658809115, 4.709340921470097, 32.549270561763215, 51.318495001111714, 36.84643609183175, 30.074697426387242, 41.4919148172651, 41.994172300611226, 18.499549218586512, 0.9650944705520357, 0.12477425751941544, 0.1144560876169375, 0.15738779891814503, 0.16527746484747954, 0.12182739350412573, 0.14913920153464588, 0.2442929356225899, 0.1614517622760364, 0.1140737874167306, 0.08937839684741837, 0.1220812877374036, 0.21418844030371734, 0.09860690057809864, 0.16134369878896646, 0.10364602732339076, 0.1371596929218088, 0.05056799529120326, 0.08280749086822782, 0.12537884579173156, 0.14098956169826643, 0.18135639705828258, 0.15006146633199283, 0.08135946999703135, 0.08843984720962388, 0.15100490142192158, 0.09884799764092479, 0.14599012051309856, 0.084622341341206, 0.1380418970116547, 0.12468117608555726, 0.14163079086158956, 0.07530890538224153], [0.054409602723483524, 0.013452173027742122, 0.04499068171051996, 0.021131851876686727, 0.0481350333429873, 0.029841121951384202, 0.08117103403700249, 0.005577537073155067, 0.05131616496614047, 0.02424220720838223, 0.03763573869530644, 0.021952136253405894, 0.013663206748398287, 0.03353796393743583, 0.007953832441541766, 0.07505434618464538, 0.058282039394336085, 0.05559666581185801, 0.05285881093836256, 0.0348091721534729, 0.061094010647918494, 0.06870019821716206, 0.03322660796610372, 0.048412649160517116, 0.02130988928755479, 0.03329531302941697, 0.027898281114175916, 0.06570302083023957, 0.030277253727295568, 0.03434053176481809, 0.011111239087767899, 0.0101066747780091, 0.05737115362925189, 0.038482563969280036, 0.014777325625930513, 0.04477598305259432, 0.03625696571543813, 0.04303327781547393, 0.10774602767612253, 0.042121621913143566, 0.015194185310974717, 0.012720307701134255, 3.8691725645746504, 28.123858656202042, 42.153386797223774, 37.827247279030935, 28.004125561032975, 32.919481004987446, 42.35408203942435, 27.81640260560172, 3.819295355251857, 0.043981099634298255, 0.8228065456662859, 3.0034074783325195, 1.2303434716803687, 1.1738920722688948, 1.335855124252183, 0.7617740035057068, 0.0768198264496667, 0.9362375161477497, 4.109159435544695, 13.199117660522461, 27.45705393382481, 44.235379764011924, 55.97806467328753, 59.30511229378836, 59.87189769744873, 58.52077184404646, 57.775636604854036, 57.821428707667756, 54.58091742651803, 56.77440466199602, 58.375033378601074, 57.957147870744976, 57.63050263268607, 59.252688135419575, 59.16885117122105, 60.0846654347011, 60.75546537126814, 60.684948103768484, 59.417520250592915, 56.47255059650966, 56.16606208256313, 50.118030411856516, 54.029282569885254, 55.578921931130544, 58.10622841971261, 56.87046698161534, 60.33896950313023, 39.36385529381888, 23.939163616725377, 52.80954715183803, 60.02523749215262, 59.641877583095, 56.907570362091064, 56.67818600790841, 45.70520864214216, 45.49372632162911, 45.03842823845999, 47.761208398001536, 49.27498115812029, 56.13923856190273, 58.002828802381245, 58.28351518086025, 58.904638971601216, 55.8239049911499, 59.189299719674246, 54.59084987640381, 58.742996079581125, 58.799978256225586, 57.22939355032784, 57.38525554112026, 54.609523160117014, 52.660494395664756, 55.53364746911185, 55.497304916381836, 56.998706408909385, 56.702476910182405, 56.344231264931814, 54.64280155726841, 49.662079198019846, 29.043986013957433, 9.297845721244812, 0.2618775777518749, 0.440016008913517, 0.4592656674129622, 1.7381121792963572, 3.6550903150013516, 3.952652999332973, 15.7145323072161, 10.848932913371495, 2.750685427870069, 0.10187437238969974, 0.011119579979484635, 4.379747475896563, 31.82813787460327, 38.42494869232178, 30.00730684825352, 23.568927117756434, 31.241699491228374, 30.875282764434814, 8.775851879801069, 0.1535444272948163, 0.03496369154059461, 0.02294782193244568, 0.02863407939938562, 0.06644161298338856, 0.007088106998708099, 0.03647588146850467, 0.07830718199589423, 0.09778859413095883, 0.041327854684953175, 0.06756581658763544, 0.026570956355759075, 0.062498788482376506, 0.021902304641636353, 0.01844989471802754, 0.0459465272059398, 0.022032861564574496, 0.015070761487420117, 0.024972129380330443, 0.09817673651767628, 0.09717760048806667, 0.047923052217811346, 0.05253245255776814, 0.008381598728841968, 0.03185891546308994, 0.05455596611968108, 0.07576462307146617, 0.03428792155214718, 0.030149302378829037, 0.019048769725486636, 0.018393808709723607, 0.10279231491897788, 0.026497669484732405, 0.024865073517763188, 0.04447130386584571, 0.016895259032025933, 0.012078867343786572, 0.054050908756575415, 0.03872177131207926, 0.0559104882579829, 0.061749658680387905, 0.02180187636986375, 0.05103871538969023, 0.03829038588862334, 0.03221831510641745, 0.020962867819304978, 0.03136312349566391, 0.05535700724327138, 0.034902660708342276, 0.035378357861191034, 0.08858529119087116, 0.027265537031260983, 0.04948935192078352, 0.014192174837392355, 0.031645953854812045, 0.07829867316676037, 0.008868871689108866, 0.04156668883349214, 0.019433621217363646, 0.01817390738454248, 0.0708296446661864, 0.07182394952646323, 0.04283848737499543, 0.014668449593175734, 0.01529921405017376, 0.00226232353764187, 0.030064828161682402, 0.03394551581836172, 0.03507646066801889, 0.030919090179460387, 0.08260512458426611, 0.04942347634849804, 0.030090588743665388, 0.03612889223066824, 0.05701925179788044, 0.06500866237495627, 8.528672320502144, 41.131779261997764, 44.94446427481515, 37.98757348741804, 33.690654618399485, 46.75172199521746, 57.84723779133388, 26.680217538561138, 2.2327365236622945, 0.011194352842202144, 0.2244128230959177, 1.1358403712511063, 0.5997408181428909, 1.3549917659589221, 1.8378743060997553, 0.9704145107950483, 0.06328362958239657, 1.932176560163498, 7.652372462408883, 18.693468230111257, 35.48917497907366, 48.56937074661255, 57.86894743783133, 60.34734903063093, 59.22085843767439, 60.68130724770682, 59.39557089124407, 59.37271131787981, 58.154994351523264, 58.533632959638325, 59.8232672555106, 58.56320449284145, 60.33859430040632, 60.9385712487357, 60.58334459577288, 62.24558298928397, 63.0706398827689, 61.48686749594552, 60.753637995038716, 57.3596271106175, 56.51357970918928, 49.922299657549175, 53.26488692419869, 55.93766437258039, 57.90343482153756, 59.03954519544329, 61.748710359845845, 43.70329019001552, 20.898178543363297, 55.292475496019634, 59.67345714569092, 61.6467524937221, 58.809768268040244, 56.61843844822475, 48.87685980115618, 47.636901651109966, 46.80276346206665, 50.610904353005544, 50.64294597080776, 57.12684161322457, 58.939546721322195, 60.658649172101704, 59.329521315438406, 57.67213971274239, 59.093942642211914, 56.190804617745535, 60.24097211020333, 59.94781371525356, 57.49089247839791, 58.92319761003767, 55.586106368473594, 52.823346274239675, 55.76788861410958, 56.06448289326259, 56.26894058500017, 56.444340910230366, 57.03483356748308, 55.39114686420986, 53.9469325201852, 36.61738177708217, 14.138880627495901, 1.3747584138597762, 1.0275505248989378, 0.7367487634931291, 5.350027365343911, 4.1474049261638095, 6.275967759745462, 11.992235541343689, 11.061384507587977, 0.4737257372055735, 0.15107867174914905, 0.042600494609879594, 3.3138849096638814, 34.35994332177298, 47.783845629010884, 34.476089409419465, 25.273346287863596, 30.326468876429967, 34.71114001955305, 15.598823956080846, 0.7876320502587727, 0.014321775874122977, 0.04511656691985471, 0.05542739846610597, 0.07850246437426124, 0.02638794358686677, 0.04630778603521841, 0.015529939705239875, 0.025623277029288665, 0.019754644616373947, 0.10583707796675818, 0.023880687143121446, 0.018522201105952263, 0.04184846067801118, 0.007504263975923615, 0.023312570128057684, 0.050088060687163045, 0.028088927402028015, 0.1422950087913445, 0.09291763550468854, 0.03742088058165141, 0.02147553495264479, 0.047144568990916014, 0.013035187813719469, 0.021353863445775847, 0.028164302464574575, 0.08290576309497867, 0.04309644264035991, 0.038999326061457396, 0.026031894210193838, 0.04090097812669618, 0.06225744036159345, 0.009705121146648057, 0.008291426513876234, 0.2095560138779027, 0.12365217772977692, 0.21674091262476786, 0.1238439181553466, 0.15940152800508908, 0.13952377678028174, 0.2530560525400298, 0.21927496950541223, 0.08498260950935738, 0.10111146154148237, 0.11518677483711924, 0.16783339769712516, 0.10386461737964835, 0.19937055185437202, 0.10950225272348948, 0.14480894032333577, 0.15460300977740968, 0.10018563443528754, 0.198025519028306, 0.12012709331299577, 0.17892904659467085, 0.14961805726800645, 0.1332963995103325, 0.14757790602743626, 0.12129125584449087, 0.1257197553558009, 0.12390829755791596, 0.1448085332023246, 0.13089357130229473, 0.08694864436984062, 0.08053914830088615, 0.12473730450229985, 0.0947197430900165, 0.11627673277897493, 0.09028858372143336, 0.21208574170512812, 0.13556531204708985, 0.11693654023110867, 0.13245412042098387, 0.19382008111902646, 0.13394600179578575, 0.18789989022271975, 7.987140144620623, 44.59139156341553, 58.424177987234934, 50.40470961162022, 38.54448897497994, 42.37140737261091, 53.016363756997244, 35.89253180367606, 5.442545669419425, 0.17149264205779347, 1.5950850312198912, 9.13939552647727, 4.395301018442426, 2.0020964997155324, 3.3235376945563724, 1.6850019948823112, 0.22561828126864775, 1.6795425564050674, 5.868099817207881, 16.081975630351476, 31.642367362976074, 48.12398426873343, 58.548912048339844, 61.44606767381941, 61.17882605961391, 60.362245968409944, 59.99886907849993, 59.074237551007954, 58.65059893471854, 59.157588141305105, 59.566531317574636, 62.23388222285679, 61.70229639325823, 63.358427320207866, 62.638753754752024, 65.52033151899064, 65.15942123958042, 64.2587332044329, 64.65938023158482, 60.67844458988735, 59.75267355782645, 53.6383387020656, 58.73994582039969, 60.09913853236607, 61.95729528154646, 61.00596877506801, 61.51022039140974, 43.98681490761893, 30.35619674410139, 55.38499076025826, 60.58451884133475, 63.03762204306466, 61.04874883379255, 59.39307648794991, 50.67331654684884, 49.745676449366975, 48.633947304316926, 51.78289869853428, 54.08112307957241, 60.40690204075405, 63.169137545994346, 61.89311477116176, 62.59787055424282, 58.5281925201416, 60.989042963300435, 56.74973160879952, 61.83845329284668, 60.16761302947998, 59.0084867477417, 58.91923713684082, 56.91970886502947, 51.94787325177874, 55.9017665045602, 56.57094056265694, 59.00183732169015, 56.77098267418997, 57.66269016265869, 56.76974936894008, 51.99991525922503, 32.80213287898472, 11.637661150523595, 1.1029122067349297, 1.287835255265236, 0.6941082115684236, 6.1532030786786756, 8.542084949357168, 14.863904305866786, 26.23088448388236, 16.80344877924238, 9.86706212588719, 0.3433377152042729, 0.13676877532686504, 7.208668751376016, 39.799479552677695, 49.624816008976524, 40.21793481281826, 32.922447885785786, 40.57470743996756, 43.278769152505056, 16.12535844530378, 0.8294288845998901, 0.10250120982527733, 0.06939964568508522, 0.21041497135800974, 0.2571868108851569, 0.1100166297650763, 0.15476447397044726, 0.1245023278253419, 0.1574022245726415, 0.08259401696601085, 0.2868929111531803, 0.1326714823288577, 0.15023551056427614, 0.14451109059154987, 0.05402507014306528, 0.12032688116388661, 0.215236044089709, 0.0966123468907816, 0.21590882513139928, 0.23353508859872818, 0.1775707280529397, 0.10048879709626947, 0.1718736666121653, 0.16601263039878436, 0.13121742249599525, 0.11926263969923769, 0.1869443500680583, 0.14971976966730186, 0.16084891105336802, 0.12060684471258096, 0.09259927365928888, 0.1587589689131294, 0.19636156117277487, 0.0555458130048854], [0.08516204130968877, 0.1015229658888919, 0.05942195786961487, 0.03995767535109605, 0.04258868810055511, 0.006731489773041436, 0.02464052931671696, 0.01668761035294405, 0.021063752405877625, 0.010117012259018208, 0.024816386933837618, 0.04255877827693309, 0.006990816103227968, 0.05743715473051582, 0.06938579678535461, 0.07469802709030253, 0.02089992182196251, 0.03519738917904241, 0.03052451867344124, 0.008339436259120703, 0.02007134913999055, 0.03650967590510845, 0.0338569195009768, 0.0035984561046851532, 0.021447937237098813, 0.02923892890768392, 0.024678652806739722, 0.05318103704069342, 0.048912885532315285, 0.03718011600098439, 0.02041924761475197, 0.04734718294015952, 0.07482950682086603, 0.03349047666415572, 0.08687354411397662, 0.0556597254638161, 0.010095098122422184, 0.039427542726376226, 0.06338992209306785, 0.040603817107954195, 0.020626916649884412, 0.08773987726973635, 0.05644656145679099, 2.566040958677019, 24.779916490827286, 39.04690626689366, 36.13675056185041, 23.635647194726126, 29.104303325925553, 39.8476687840053, 34.83979981286185, 9.571004595075335, 0.4987762730036463, 0.19092224804418428, 0.6845613324216434, 0.5315330124327114, 0.6697003298572132, 1.2249056377581187, 0.1601883979248149, 0.029617663406367813, 0.08016393879162413, 0.23054530045815877, 2.9804480246135165, 12.819142392703466, 28.0541022164481, 45.015794481549946, 55.27895777566092, 58.706608363560264, 58.06011322566441, 56.57213217871529, 58.00453111103603, 59.865178789411274, 60.7685557774135, 58.53117329733712, 59.07173619951521, 59.69250215802874, 59.87350273132324, 57.20927504130772, 58.142140184129985, 59.79342474256243, 58.86108071463448, 58.93480804988316, 58.16374908174787, 58.694011279514854, 59.538738523210796, 59.984055519104004, 60.280055727277485, 63.28195544651577, 55.08025666645595, 32.26755237579346, 40.51199299948556, 45.843203340257915, 62.61812455313546, 59.172485079084126, 62.90069389343262, 54.8960633959089, 54.84125600542341, 50.89912257875715, 49.97385876519339, 49.16169078009469, 51.58193595068795, 54.10717535018921, 57.9774956703186, 59.50321238381522, 56.31145313807896, 55.22579710824149, 59.45166369846889, 58.17228146961757, 57.54091256005423, 56.74266529083252, 56.763843400137766, 53.01111091886248, 57.141099316733225, 55.66743850708008, 59.80152634211949, 54.534128257206504, 56.326746123177664, 54.30306591306414, 46.49212339946202, 29.980056013379777, 13.11510612283434, 1.7504345923662186, 0.17485291031854494, 0.2261721965457712, 0.5457095088703292, 0.9137099363974163, 3.8117001056671143, 3.3892094620636533, 2.4488830396107266, 9.28727056298937, 0.6395304373332432, 0.05141095970092075, 0.2288558839687279, 8.113418442862374, 37.27385800225394, 36.743908473423545, 27.673955849238805, 25.103949206215994, 33.67590706689017, 20.154474633080618, 2.4730623364448547, 0.02598624407047672, 0.07072506206376211, 0.034031486205224476, 0.035208832672131915, 0.03288090794480272, 0.041959180629679134, 0.04286690781425152, 0.016980406695178578, 0.06562419541712318, 0.027088525904608623, 0.03261481365188956, 0.01931612778987203, 0.019134611190695847, 0.007556705403008631, 0.03487698155056153, 0.04550528945401311, 0.08241795748472214, 0.06092901807278395, 0.026529613217072825, 0.13806853629648685, 0.039939171701137505, 0.015541568099121963, 0.046218772418797016, 0.035704020743391345, 0.03203322771670563, 0.029901189263910055, 0.0032256638764270712, 0.03264944947191647, 0.013591979231153215, 0.058006961297776015, 0.0336128334913935, 0.07881823421588965, 0.04634643538988062, 0.05330789934045502, 0.05772070772945881, 0.08704655697303158, 0.019265079904081564, 0.02973210172993796, 0.04739792378885405, 0.042962248769721816, 0.037003316916525364, 0.04208895045199564, 0.014946073892393281, 0.011981573055631347, 0.030360537115484476, 0.015221815256934081, 0.03815973736345768, 0.051831142511218786, 0.03860414387392146, 0.009621720711168433, 0.06431357788720302, 0.015259480735819255, 0.020038691249543, 0.004187373610745583, 0.035412891900965145, 0.03193147121263402, 0.021407644131353924, 0.04792868745114122, 0.07043286452868155, 0.031386834901890585, 0.01755129891846861, 0.015645019244402647, 0.040830081395272694, 0.07272389730704681, 0.04371869317921145, 0.023014135159818188, 0.019696840218135288, 0.05854328216186591, 0.055309872808200974, 0.030089621831263815, 0.050051263733101745, 0.06038740463554859, 0.028865337704441378, 0.016548434338931526, 0.05448448245546647, 0.07694319090140717, 0.03142735701320427, 0.002272791212557682, 5.665134251117706, 35.824098995753694, 45.535346031188965, 32.940461090632844, 21.669378212520055, 30.579028947012766, 59.163890157427105, 43.067158290318076, 7.551076412200928, 0.17612365713076933, 0.12143555310155664, 0.026104432996362448, 0.4083775223365852, 1.6678797879389353, 1.2820479486669814, 0.44168984623891966, 0.15260551124811172, 0.2279229797422886, 0.7974625027605465, 5.141068109444209, 17.518744979585918, 35.31427492414202, 49.22344636917114, 57.89138317108154, 59.79741995675223, 58.47319058009556, 55.91288014820644, 57.73507302148001, 60.08771569388253, 60.4971730368478, 59.84787777491978, 58.99322850363595, 61.971261160714285, 60.5095408303397, 58.58533450535366, 58.9961884362357, 60.60534259251186, 60.00226674761091, 60.00717217581612, 59.39042227608817, 58.44796167101179, 63.24584565843855, 62.60490213121687, 63.12571825299944, 66.08040496281215, 62.087462833949495, 35.803115436008994, 38.90185219900948, 49.18777084350586, 63.26600238255092, 61.361292702811106, 62.241671153477256, 57.69528416224888, 53.87366376604353, 52.03254747390747, 52.54733255931309, 52.29666239874703, 52.52593558175223, 57.01246384211949, 59.420890126909526, 61.01923983437674, 57.96334566388811, 57.9584367615836, 60.60842064448765, 57.65399101802281, 57.36927121026175, 58.147938455854145, 57.841029575892854, 54.277809211185996, 57.835714203970774, 56.925944873264854, 59.14422675541469, 56.38043485369001, 56.50413015910557, 56.583961486816406, 51.309431076049805, 37.604814597538535, 19.043864148003713, 4.174586713314056, 0.3520018474331924, 1.0466894464833396, 1.6899754937205995, 2.6547466559069495, 5.716053255966731, 3.6872439725058417, 1.9015521577426364, 1.8022822673831667, 0.999406629375049, 0.0712418139779142, 0.12449540676815168, 4.9914586288588385, 38.372215339115684, 43.348740986415315, 30.634888989584788, 27.80934844698225, 36.399142333439414, 31.610099928719656, 7.992785555975778, 0.13380728209657328, 0.04998433643153735, 0.0017281693206833942, 0.025944984052330256, 0.01940540094593806, 0.05261304555460811, 0.07853081356734037, 0.025160531413608363, 0.06592838945133345, 0.06705122241484267, 0.056422096876693625, 0.06333128988210644, 0.018478014905537878, 0.0229488414313112, 0.022340741740273576, 0.024979920658682073, 0.045641583390533924, 0.024420974044395343, 0.012912518860373114, 0.043427411666406054, 0.021059623520289148, 0.020070770688887154, 0.11206133397562162, 0.018033828918955157, 0.05868050908403737, 0.009353769776810492, 0.030084336043468544, 0.02547130045214934, 0.019887929250087057, 0.02002963450338159, 0.034195983449795415, 0.08311230236930506, 0.023430648792002882, 0.09139604108142, 0.05507036690999355, 0.23892257522259439, 0.15501087717711926, 0.08596575246857745, 0.12947365535157068, 0.10194904516850199, 0.08110180989439998, 0.17876114988965647, 0.09852846871529307, 0.09075011645576783, 0.1431535862918411, 0.1572224942169019, 0.09808472038379737, 0.12291399948298931, 0.26059723645448685, 0.21320262391652378, 0.21748388132878713, 0.12618943729570933, 0.09073344485035964, 0.132539195141622, 0.14218539824443205, 0.08524023568523781, 0.0795123687546168, 0.1601162017988307, 0.15111316846949713, 0.10739585610904864, 0.09045895029391561, 0.19567363522946835, 0.13608938535409315, 0.18937727808952332, 0.141745531133243, 0.11238216568848916, 0.09396462860916342, 0.14155788905918598, 0.1148729252495936, 0.16587121013019765, 0.1041980834145631, 0.08421978008534227, 0.14492051862180233, 0.12715412410242216, 0.19313740703676427, 0.17751299829355308, 0.1994244275348527, 0.10279860493860074, 4.889683152948107, 37.79442398888724, 54.58858823776245, 48.379007475716726, 33.92959969384329, 35.69133629117693, 49.035719939640586, 44.477211815970286, 12.504194446972438, 0.8611944200737136, 0.16118498944810458, 3.129934391805104, 7.08021262713841, 4.603393920830317, 3.059621010507856, 0.5477514650140489, 0.17208649590611458, 0.3568886566374983, 0.5482580864003727, 4.043290078639984, 15.404317821775164, 32.490214347839355, 49.16380303246634, 57.60729912349156, 61.682500975472585, 58.43002142224993, 57.49072919573103, 59.36162199292864, 61.6948687689645, 63.569082805088584, 62.26483644757952, 61.47752911703927, 64.24180739266532, 63.53592600141253, 61.133544649396626, 62.77453545161656, 63.15923636300223, 61.20341573442732, 64.29794188908168, 61.055439949035645, 61.403523853846956, 65.04365730285645, 65.65265996115548, 64.90769495282854, 65.81202384403774, 61.54679570879255, 40.40204470498221, 43.00182785306658, 53.29586546761649, 61.74133832114083, 64.66536957877022, 64.25539112091064, 60.843512943812776, 58.09881121771676, 56.755918979644775, 56.08369813646589, 54.84406655175345, 54.54731593813215, 60.01355757032122, 61.215693201337544, 63.15999371664864, 57.32254804883684, 56.5720522744315, 58.24357346126011, 56.58583402633667, 58.04895789282662, 58.62791306631905, 57.34805488586426, 54.995054381234304, 59.6178229195731, 57.52431331362043, 59.80017144339425, 55.36852700369698, 56.19894095829555, 56.76982579912458, 49.895924295697895, 34.0893109866551, 15.905654668807983, 3.0935909705502644, 0.35506122612527435, 0.8806478019271577, 1.8904113726956504, 4.591044366359711, 9.27076164313725, 9.483350464275905, 9.927243947982788, 21.130008663449967, 3.5132243846143996, 0.1903751588293484, 0.3617662106241499, 10.845982534544808, 45.25618130820138, 46.695233140672954, 37.072474888392854, 35.0183824130467, 46.195779255458284, 35.80075652258736, 7.534451978547232, 0.15153369733265468, 0.209860499682171, 0.09048421893801008, 0.11695566134793417, 0.11448990580226694, 0.12693023468766892, 0.17255408795816557, 0.22682998196354934, 0.14800489454397134, 0.127743784604328, 0.14665769040584564, 0.14563052409461566, 0.0728671360494835, 0.1058754762634635, 0.1455853200916733, 0.1043706348698054, 0.16436858076070035, 0.21257625467010907, 0.0954472819077117, 0.19197457443390573, 0.10676885582506657, 0.11900291006479945, 0.11968960107437202, 0.13396130954580648, 0.08228336327842303, 0.15925305097230844, 0.13503106071480683, 0.10994591963078294, 0.0898601838520595, 0.08127518237701484, 0.125124707285847, 0.17951315668012413, 0.10669180817369904, 0.17910188303462096, 0.1632345180426325], [0.027628855214321187, 0.04247233970090747, 0.03782127391813057, 0.08092537721885101, 0.01587269827723503, 0.03927066543006471, 0.018493570320840393, 0.06757625245622226, 0.0967154638575656, 0.019926571819399084, 0.029082971026322672, 0.012220475057672178, 0.04105915142489331, 0.04007593382682119, 0.02061224333010614, 0.014523027664316552, 0.06430925561913423, 0.10836329776793718, 0.045993715923811705, 0.0144637389707246, 0.04206912026607564, 0.04069284090240087, 0.04876059852540493, 0.02904764310057674, 0.018714709972430552, 0.03258814722565668, 0.012949393845961561, 0.054116343281098774, 0.09682020252304417, 0.04414121354264872, 0.04469780903309584, 0.02729822206310928, 0.04834842582100204, 0.036435281325663836, 0.022225747017988136, 0.028606110185916935, 0.012929765524209609, 0.039241851440497806, 0.054520390528653345, 0.051611626254660745, 0.03340542229956814, 0.04343574746911015, 0.026433003401117663, 0.02111321930507464, 0.8534969016909599, 20.050308976854595, 38.879878520965576, 39.9887832232884, 29.17305748803275, 18.41564450945173, 28.470841271536692, 41.87002536228725, 20.543813467025757, 2.235189889158521, 0.0062140326065543506, 0.1697421438459839, 1.202880173921585, 0.5192762272698539, 0.3023238831332752, 0.056384397471057515, 0.09291207830288581, 0.03488343781126397, 0.07919214772326605, 0.38005739769765307, 2.8594712018966675, 11.767283269337245, 29.758252143859863, 44.90524864196777, 55.61562231608799, 58.19741310392107, 55.55072614124843, 52.842116832733154, 58.31946168627058, 58.368363107953755, 60.943817138671875, 60.51071507590157, 61.57929938180106, 60.89710439954485, 61.37716933659145, 60.867532866341726, 62.69468675340925, 60.165542466299875, 64.89808559417725, 59.60794258117676, 63.585959979466026, 58.490929331098286, 59.3151524407523, 49.77185378755842, 42.64682354245867, 21.849419934409006, 32.395506926945274, 39.40102815628052, 57.993678024836946, 59.679953711373464, 58.96136406489781, 57.70659930365426, 54.63223334721157, 57.99216331754412, 52.69439465659005, 55.27709913253784, 55.39206402642386, 57.16773523603167, 59.80716827937535, 61.15250628335135, 60.09341321672712, 57.66850233078003, 60.13194792611258, 57.777300698416575, 60.3534426007952, 58.34321757725307, 60.88425718035017, 60.820778438023154, 56.50605133601597, 53.58224242074149, 51.0481857572283, 47.85330677032471, 40.299687317439485, 24.742293732506887, 11.2486150094441, 1.5612366646528244, 0.07794309367558785, 0.025436381343752146, 0.3442045029784952, 1.741987862757274, 1.7357099481991358, 2.4984519226210455, 4.999226280621119, 1.2429812678268977, 1.971559601170676, 0.9989679157733917, 0.3099152243563107, 0.5595132453101022, 15.008807250431605, 36.24260984148298, 31.716264929090226, 32.15458161490304, 25.88230378287179, 33.67145674569266, 19.31715590613229, 1.5408273083823067, 0.04640640431482877, 0.1571248530277184, 0.058875350414642265, 0.04112014154504452, 0.05761220319462674, 0.023048397785584842, 0.04702249714838607, 0.09009730469967638, 0.038173348775931766, 0.011984342326676207, 0.08561023404555661, 0.055731667139168294, 0.04444681892969778, 0.03973016255934324, 0.04742692776822618, 0.05437027483380266, 0.019034562898533683, 0.04229398677125573, 0.04604338129450168, 0.028975779456751685, 0.028539556078612804, 0.04759849874036653, 0.10253968954618488, 0.006732245491418455, 0.005741373594251594, 0.011189287578287934, 0.014999998766662819, 0.07522881110864026, 0.05144215874107821, 0.045630808254437785, 0.06348406882690531, 0.06259330162512404, 0.025364059688789502, 0.0069807118686315206, 0.030051070864179304, 0.016958829281585555, 0.026833910727873445, 0.04568755413804736, 0.038624069054744074, 0.04173902655020356, 0.08058143460324832, 0.04086971801838704, 0.015502867854333349, 0.07111464294471911, 0.07564851215907506, 0.020655800189290727, 0.0263696536754391, 0.0435528931474047, 0.04311439667695335, 0.029006137113486017, 0.012534464593045413, 0.05461920897609421, 0.08174936300409691, 0.07468941648091589, 0.01618006276631994, 0.03162023737760527, 0.03300059134406703, 0.03212659752794674, 0.05309326175068106, 0.04403687860550625, 0.03365325382245438, 0.023434497781896164, 0.05437597792063441, 0.07420533602791173, 0.03136937280318566, 0.04770481160708836, 0.04866908111476472, 0.07406192765172039, 0.019940607316259826, 0.04187279294377991, 0.022555582890553132, 0.03352220496162772, 0.03264088635998113, 0.08718602306076459, 0.11601871305278369, 0.03865636053628155, 0.02964519157207438, 0.037683544880045314, 0.03184184691469584, 0.03653136527697955, 2.6790091139929633, 29.5458630834307, 49.15649700164795, 34.181343351091655, 22.629739114216395, 20.554442473820277, 44.38712842123849, 57.02262558255877, 17.781013420649938, 1.1108689797776086, 0.030598526487925222, 0.1179563512227365, 0.5864784440823964, 0.6983290250812257, 0.6327549666166306, 0.5303692977343286, 0.2874241769313812, 0.11799392849206924, 0.08017449001116411, 1.2234624751976557, 6.078240701130458, 16.813874551228114, 38.15714774812971, 50.70796026502337, 58.0280716078622, 60.2768942969186, 56.40275246756417, 55.65623106275286, 59.411586488996235, 59.561368806021555, 61.75051689147949, 62.236543382917134, 64.77366420200893, 63.9716614314488, 63.847323417663574, 62.17535754612514, 62.44972801208496, 61.8683305467878, 63.88666411808559, 61.468079566955566, 64.134763445173, 60.25577177320208, 59.64747783115932, 54.01233243942261, 47.86211013793945, 27.940931694848196, 33.16353300639561, 45.30454771859305, 60.45159980228969, 59.171213558741975, 62.74592971801758, 58.56858934674944, 56.228220667157856, 58.927825110299246, 52.82718515396118, 56.21030821119036, 55.488643986838206, 57.91108478818621, 62.30087675367083, 64.84646742684501, 61.991772242954795, 60.672086988176616, 62.83362293243408, 58.88462815965925, 61.697411809648784, 59.43515477861677, 62.399687085832866, 60.52217960357666, 57.89975227628435, 56.42524031230381, 53.32949474879673, 51.5151047025408, 46.123295647757395, 32.174099104745046, 17.319785049983434, 3.9884383933884755, 0.41892032804233686, 0.41891413980296677, 1.0898677238396235, 2.213544947760446, 3.2008073202201297, 3.76082626410893, 4.134781352111271, 3.4483190902641843, 0.19885843433439732, 0.5316684480224336, 0.2969897836446762, 0.04273852898872324, 13.664436783109393, 46.8756674357823, 42.22279235294887, 33.53007827486311, 27.651567016329082, 36.891213757651194, 29.046412672315324, 3.700595804623195, 0.31160768068262507, 0.11417628691664763, 0.01590077775264425, 0.03644175115706665, 0.0582509557051318, 0.05081257663135018, 0.04144920049501317, 0.06807441929621355, 0.021834072856498615, 0.05328942283189722, 0.04614285792091063, 0.014811111580846565, 0.025416834446202432, 0.035845580111656866, 0.10033823017563138, 0.025046990452600375, 0.020261635804282765, 0.025930037622206976, 0.03643154599038618, 0.02002656413242221, 0.06070928807769503, 0.10170357155480556, 0.0327962776646018, 0.045178069333945, 0.030826833165649856, 0.018872974872855202, 0.0624410587229899, 0.01679799273344023, 0.012169550156353839, 0.014747229205178363, 0.03727236283676965, 0.0458969296887517, 0.010060101830666619, 0.033406222970890145, 0.01742054522037506, 0.04883850113089595, 0.15213030603315147, 0.1375451958073037, 0.14486665651202202, 0.2517102190426418, 0.2297213418143136, 0.14361998412225926, 0.17972985362367971, 0.15014469543738024, 0.18149393610656261, 0.13575929163822106, 0.14923867476837976, 0.1338072278137718, 0.20256733388773032, 0.1112411819132311, 0.12272843372608934, 0.10888462300811495, 0.1391734762915543, 0.14598618500999042, 0.15969016323132174, 0.07629612633692366, 0.15564006912921155, 0.1676558115120445, 0.20413869885461672, 0.12925528921186924, 0.11043465483401503, 0.09888334931539637, 0.1904735599777528, 0.19317197161061422, 0.18049868808260985, 0.2650855284716402, 0.13211198949388095, 0.18486400241298334, 0.13952883865152085, 0.09596431202122144, 0.12847904515053543, 0.1958892193755933, 0.07470078194247824, 0.1451741007289716, 0.2344353145786694, 0.18303525554282324, 0.2387152420622962, 0.20130124182573386, 0.12882123036043985, 0.1327452797974859, 1.857915299279349, 30.474614892687114, 56.95745842797415, 51.10251372201102, 39.8615790775844, 25.61401125362941, 36.64605351856777, 54.65017359597342, 25.090245621544973, 3.0311750854764665, 0.30202815043074743, 0.9464708013193948, 2.8898174592426846, 1.8121949583292007, 1.0465975999832153, 0.4574085442083222, 0.45587500078337534, 0.1241546736231872, 0.34144194264497074, 0.9347026156527656, 4.702206858566829, 13.758073312895638, 35.47111661093575, 48.6559487751552, 57.83973721095494, 59.18585341317313, 59.01646327972412, 56.4476934160505, 61.269013677324565, 61.36852577754429, 64.00520733424595, 64.3554173878261, 66.88572897229875, 67.39684540884835, 66.57533209664481, 66.77976199558803, 67.02267101832798, 65.33266067504883, 68.85637010846818, 64.46596322740827, 68.28642327444894, 63.06144046783447, 60.33907372610909, 56.165096282958984, 54.53861331939697, 29.02761432102748, 33.38961001804897, 48.07972076960972, 57.66563272476196, 60.332646642412456, 62.034976141793386, 62.07986845288958, 57.42834826878139, 61.6633517401559, 55.80245590209961, 59.27731949942452, 61.45179993765694, 60.38709967476981, 64.28322560446603, 66.31561538151333, 64.87443392617362, 61.447617122105186, 64.23942416054862, 61.462854521615164, 61.915147508893696, 58.78040518079485, 62.53019509996687, 60.65098530905587, 57.318295751299175, 55.27671003341675, 51.40147386278425, 50.28354345049177, 43.218972955431255, 29.004667895180837, 14.062669311250959, 2.5729604959487915, 0.1777791604399681, 0.14107842264430864, 1.238665025149073, 5.1008032986095975, 4.634083245481763, 5.985529584544046, 11.865011419568743, 9.137664556503296, 5.159800887107849, 2.589534338031496, 0.3698868363031319, 0.9838199743202755, 19.45505506651742, 45.90319061279297, 41.17306545802525, 42.187439918518066, 36.04594802856445, 46.16142736162458, 31.28647368294852, 4.039145043918064, 0.22098908466952188, 0.3235368419970785, 0.09880591489906822, 0.09779713010149342, 0.16203513954366955, 0.09835031934614692, 0.11214216106704303, 0.17875459524137632, 0.14610263518989086, 0.18901665029781206, 0.1399968649659838, 0.1420110554567405, 0.15952017663844995, 0.13704012148082256, 0.14828191325068474, 0.2069441426013197, 0.08981253712305001, 0.19169804427240575, 0.17235355371875422, 0.08788574872804539, 0.13688008221132414, 0.13546978788716452, 0.2146499662527016, 0.08300833044839756, 0.09894337252314601, 0.10473392251878977, 0.140082414661135, 0.14757333270141057, 0.21229764819145203, 0.08990201553595917, 0.131739256637437, 0.11824012813823563, 0.05968766539756741, 0.10363308766058513, 0.10028966063899653, 0.17270073294639587], [0.032293462859732766, 0.073063381947577, 0.028525116853415966, 0.035118509483124526, 0.00952323220138039, 0.022170924781156436, 0.0721088731661439, 0.031204709317535162, 0.01658257143571973, 0.02841596431764109, 0.0248405427805015, 0.05376392576311316, 0.03248164097645453, 0.058427361239280017, 0.0417090861925057, 0.0318136028945446, 0.09203404720340456, 0.0707039867660829, 0.028029246854462793, 0.04289473792804139, 0.11719069230769362, 0.02427582352954362, 0.017603027035615275, 0.016229287089247788, 0.02832753084866064, 0.05761932781232255, 0.04300367672528539, 0.06557768862694502, 0.03920526483229228, 0.056663516243653636, 0.0256175366230309, 0.062170710015509806, 0.012870111269876361, 0.03456175114427294, 0.02871215163863131, 0.05662217649764248, 0.0416288596045758, 0.05192397288712008, 0.034750882602695904, 0.057335991944585524, 0.06292157008179597, 0.01649111170055611, 0.021257888060063124, 0.018148637044110467, 0.053104525431990623, 0.35177377824272427, 10.040965114321027, 40.17440782274519, 38.81396096093314, 33.95199721200125, 25.97202413422721, 27.25670436450413, 45.620121002197266, 32.72000517163958, 6.95011716229575, 0.13289049986217702, 0.21198400216443197, 0.5958008095622063, 0.8459262964980943, 0.5688375106879643, 0.2220828966902835, 0.2592621509517942, 0.05121301067993045, 0.06340090078966958, 0.014931256383923548, 0.5333856844476291, 5.75854800428663, 17.40467640331813, 32.26976537704468, 50.855348927634104, 56.91058240618025, 61.47044195447649, 60.6278269631522, 59.714375087193076, 60.53555488586426, 59.59139197213309, 56.68439074925014, 53.91858386993408, 53.593303952898296, 53.23746933255877, 59.317688533238, 64.16026333400181, 64.88423088618687, 67.20316437312535, 63.931222915649414, 65.21268612997872, 60.85019711085728, 55.58686024802071, 39.17145620073591, 28.387415988104685, 40.23447152546474, 37.56922939845494, 53.02509764262608, 66.48545019967216, 61.171280315944124, 62.38404669080462, 60.24426555633545, 60.84514577048165, 61.73744732992989, 62.36220155443464, 60.81239891052246, 60.90003653935024, 60.12788322993687, 64.59655461992536, 54.96209907531738, 60.19899804251534, 57.69669464656285, 55.18222842897688, 51.40526410511562, 51.058872086661204, 46.06690754209246, 44.27011380876814, 38.804827553885325, 33.885464736393516, 30.87555374417986, 21.420924527304514, 10.415563344955444, 2.2415342458656857, 0.05617563599454505, 0.14664040133357048, 0.45653681669916424, 1.2676637662308556, 1.1412773366485323, 1.458931714296341, 2.2778268584183285, 2.9162095401968275, 2.325444600411824, 1.853320368698665, 0.4002971202135086, 0.08987864678991692, 2.9281257007803236, 26.55694259916033, 35.11990949085781, 22.34959990637643, 21.065331356866018, 25.953724316188268, 34.885202816554475, 14.976416485650198, 0.7642206379345485, 0.039266787602433136, 0.0390561533692692, 0.03695995852883373, 0.027867024398541877, 0.07064265398574726, 0.011831073140326356, 0.048502873961946795, 0.0016476079181302339, 0.04903763758816889, 0.0658231418845909, 0.03459290947232928, 0.052624343162668605, 0.01902899721504322, 0.033533282045807154, 0.05194428822557841, 0.055487143474497964, 0.03130954637059143, 0.025414963385888507, 0.019962279724755456, 0.07588555836783988, 0.08438933920115232, 0.039587191838238917, 0.01004722832502531, 0.028847973993314163, 0.03623835010720151, 0.01075356886056917, 0.06077433244458266, 0.030871423094400337, 0.034439740369894674, 0.014796095600883876, 0.00426905056727784, 0.018869088563535894, 0.03665888575570924, 0.02561482078661876, 0.04710183485544153, 0.02647864505914705, 0.04467018587248666, 0.03300205358703222, 0.05324985066960965, 0.051725630315818956, 0.0025970823938093546, 0.01512146501668862, 0.12477713450789452, 0.031035336798855236, 0.03828696946480444, 0.016796226846054196, 0.06811109411397151, 0.0103999359167314, 0.02870350710249373, 0.050370263401418924, 0.010391083579244358, 0.020068862309147204, 0.025071597525051663, 0.07941521611064672, 0.030351095300699984, 0.029593127580093484, 0.04170473339036107, 0.02810543615903173, 0.0124020730810506, 0.00674285226601309, 0.02958145338509764, 0.09027557620512587, 0.032511136893715174, 0.05831970487322126, 0.042410783004015684, 0.017174695019743273, 0.0383664632349142, 0.05066951091534325, 0.06801610599671092, 0.04731287960229175, 0.02098792781388121, 0.014456595693315779, 0.03318581783345767, 0.05403735501957791, 0.038689937841679366, 0.05112688083733831, 0.030177536220954995, 0.029994131598089422, 0.07275501492300204, 0.09136889289532389, 0.02648914199588554, 0.04495680584971394, 1.2743943993534361, 18.38593922342573, 49.43829509190151, 36.809089524405344, 20.033152137483867, 16.196237019130162, 37.57329756872994, 61.51666831970215, 33.665734904153005, 4.739187342779977, 0.05403220493878637, 0.17959145962127618, 0.17722470233482973, 0.9142803400754929, 0.9479015874011176, 1.0825826461826051, 1.4065928884914942, 0.34921347562755856, 0.2079571003892592, 0.39559039420315195, 1.2281240650585719, 9.033105458532061, 21.22565930230277, 40.33659962245396, 52.33276523862566, 58.8340174811227, 60.80840369633266, 60.816414969308035, 59.616454124450684, 59.84158270699637, 58.93986633845738, 57.76013169969831, 54.98590707778931, 56.497539792742046, 57.14076580320086, 63.05515234810965, 65.81946536472866, 66.34724358149937, 68.71835803985596, 67.11945942470005, 65.70129040309361, 60.05605970110212, 58.63011564527239, 46.09507553918021, 26.859468902860367, 41.20209503173828, 43.63922085080828, 56.43115322930472, 65.58710370744977, 60.944553647722515, 63.54514626094273, 61.27677481515067, 62.31573895045689, 62.983280181884766, 64.63014916011265, 62.29769447871617, 63.58233996800014, 61.80173206329346, 64.83265440804618, 57.185251644679475, 60.05936704363142, 60.19086170196533, 56.17250306265694, 54.43443897792271, 54.38673612049648, 51.64570304325649, 49.98539972305298, 43.75798640932356, 40.06546354293823, 35.43520137241909, 27.21072813442775, 15.214849131447927, 4.728905745915004, 0.780392298741, 0.16178953700831958, 1.5976616186755044, 4.202330870287759, 2.592721389872687, 3.286154431956155, 5.137906679085322, 3.4717966190406253, 0.6032535125102315, 0.06712632267070667, 0.5651838981679508, 0.13127528796238558, 1.4048496506043842, 25.41718963214329, 49.17797040939331, 29.312452248164586, 21.653477260044642, 31.01380899974278, 37.80042028427124, 23.232585668563843, 2.63660186954907, 0.09228005007441555, 0.025298855866172483, 0.02183581329882145, 0.01953599518830223, 0.040653390876416645, 0.0161688618494996, 0.0481144974806479, 0.0480674071503537, 0.020971573423594236, 0.04132339670988066, 0.037549581711313555, 0.02036742789537779, 0.05231736713488187, 0.031960780532764535, 0.02823927379878504, 0.05653442834903087, 0.027378540253266692, 0.028194370047588433, 0.013218363431016249, 0.045786046888679266, 0.035282128024846315, 0.0785523366981319, 0.04289550127993737, 0.07487621038619961, 0.049929995954568894, 0.036692232359200716, 0.08727592216538531, 0.003758721411161657, 0.029439717597727264, 0.016784500064594404, 0.024304501812106798, 0.019232644233852625, 0.007989270629228225, 0.031827808025160005, 0.027889100535373603, 0.06904200344745602, 0.021400002130706395, 0.09690542652138642, 0.1544073067073311, 0.06360870892448084, 0.097753961703607, 0.18495054276926176, 0.16201657482555934, 0.12502527476421424, 0.10866082858826433, 0.09331674980265753, 0.12822261319628783, 0.13300631221915993, 0.08215703362865107, 0.12752286717295647, 0.2098865554268871, 0.19727267085441522, 0.11738503830773489, 0.22669481778783457, 0.1522140372544527, 0.1688167035047497, 0.12926542652504786, 0.23912247163908823, 0.12898405162351473, 0.0746323788272483, 0.15893544230077947, 0.29816044654164997, 0.13534575168575558, 0.15568762086331844, 0.20328944442527636, 0.11900532564946584, 0.10324987143810306, 0.22353830002248287, 0.22523782668369158, 0.2115418008927788, 0.17862115454460892, 0.1325528879782983, 0.08858485692845923, 0.15404270270041057, 0.14339428980435642, 0.11001683332558189, 0.09926522203854152, 0.21755047275551728, 0.14859070096697125, 0.12515564848269733, 0.17234910252903188, 0.1848315955804927, 1.0668824315071106, 18.76140250478472, 57.27574845722744, 51.1182861328125, 43.73544645309448, 33.30245876312256, 36.25120823723929, 56.475072792598176, 42.813889503479004, 9.41330827985491, 0.3813800795802048, 1.1051374758992876, 2.4050418606826236, 3.6207431980541775, 1.251470338021006, 1.0426261616604668, 2.369991890021733, 0.38980224622147425, 0.35375567046659334, 0.26953351550868576, 1.0984901125941957, 7.382439289774213, 19.38060164451599, 36.131727014269146, 53.66860505512783, 58.54640374864851, 63.83218329293387, 63.99866213117327, 62.71537848881313, 64.34769793919155, 62.77214527130127, 60.30048343113491, 58.8939665385655, 60.14102227347237, 58.99684156690325, 65.2568210874285, 70.00127342769078, 66.56138706207275, 71.45022296905518, 65.99808965410504, 67.52335820879254, 62.11476925441197, 61.72559370313372, 50.37912287030901, 33.6127027784075, 46.018951075417654, 51.685540539877756, 55.78729840687343, 67.15999521527971, 63.58354895455496, 65.50596959250313, 65.5556492124285, 66.22897134508405, 67.25050939832414, 66.49205098833356, 64.09527683258057, 66.93071160997663, 64.89365264347622, 67.31073638371059, 58.49986471448626, 60.91831030164446, 57.65808350699288, 54.748897075653076, 53.82452263150896, 54.39623778206961, 49.729452405657085, 48.02848127910069, 41.7172657421657, 36.756575039454866, 33.042026383536204, 24.203860453196935, 12.871189611298696, 3.5848917961120605, 0.49542523281914846, 0.22100116259285382, 1.2695573674780982, 3.427319245679038, 2.5448328852653503, 4.643796392849513, 9.549398303031921, 8.125724571091787, 10.251677053315298, 5.549606553145817, 1.086310463292258, 0.28421989030071665, 4.365665648664747, 32.42071499143328, 44.13336631229946, 29.07069488934108, 29.48320770263672, 37.20782232284546, 46.377780369349885, 23.956058161599294, 2.1228349123682295, 0.17712467270238058, 0.1866502594202757, 0.14175762262727531, 0.09238077181258372, 0.09695622843823262, 0.051480407760079415, 0.14714027808180877, 0.11003077722021512, 0.11034704239240714, 0.12838680510010037, 0.13628379920763628, 0.10064097893025194, 0.17918517999351025, 0.10181861038186721, 0.2073210280920778, 0.11456770662750516, 0.1346242246883256, 0.17191911488771439, 0.09277094301900693, 0.2831530432615961, 0.1603043188474008, 0.13953339840684617, 0.14504150141562733, 0.1739435512572527, 0.07768181019595691, 0.07562768113400255, 0.31606687711817877, 0.1737755731280361, 0.08527407422661781, 0.12392933214349405, 0.16514441770102295, 0.10508530187819685, 0.09821625439716236, 0.13893626044903482, 0.12842443665223463, 0.1495824884623289, 0.08175109326839447], [0.037679575450186215, 0.04026415944099426, 0.020897399368030683, 0.023463981824793985, 0.05868661589920521, 0.050289280246943235, 0.0500653399420636, 0.03359661311177271, 0.02786790649406612, 0.024077333376875946, 0.021382575655089955, 0.04265645339286753, 0.04222962433206184, 0.045197896127189906, 0.08149219823202916, 0.05703389458358288, 0.10196481432233538, 0.073713812045753, 0.013732695519658071, 0.04787789910499539, 0.061988123027341704, 0.048224372656217644, 0.04789639936227884, 0.07817505765706301, 0.12961815616914205, 0.021387864835560322, 0.030264663510024548, 0.044954478474599976, 0.07421100858066763, 0.028650262459580387, 0.006692811156556542, 0.048738230618515184, 0.0035315845702176113, 0.03342041113813009, 0.05319575785792299, 0.055881050016198835, 0.047848932445049286, 0.050332716666162014, 0.004032735479995608, 0.015564263399158205, 0.006568601504633469, 0.05417059215583971, 0.027991318443257893, 0.0354269715026021, 0.03294782167566674, 0.0597923429948943, 0.013534285094855087, 5.840776026248932, 38.33326721191406, 46.365471635546, 40.872243200029644, 33.67709173474993, 21.462301049913677, 41.25705875669207, 43.636757714407786, 15.492648533412389, 1.3412215220076698, 0.33843429546271053, 0.22341532233570302, 1.0090888355459486, 0.767613910138607, 0.44662084164363997, 0.6175357518451554, 0.1674756333231926, 0.27497121372393196, 0.061187444919986386, 0.1852856847856726, 1.2623096363885062, 6.066493468625205, 14.226706726210457, 26.46905309813363, 36.8663774217878, 48.99201577050345, 52.24368585859026, 56.961894852774485, 53.538903032030376, 52.95924956457955, 50.47633859089443, 54.72785793031965, 56.33153690610613, 61.370499065944124, 59.204710824149, 65.65684972490583, 64.3325925554548, 65.37794208526611, 58.36595903124128, 57.28109162194388, 53.868577684674946, 40.7079495702471, 47.351973397391184, 48.12212215151106, 28.848147562571935, 47.1427457673209, 62.385700362069265, 57.94423464366368, 64.27802835191999, 63.013018471854075, 62.847561018807546, 61.17420550755092, 59.814456939697266, 65.57704966408866, 64.15399605887276, 68.50456196921212, 57.33108391080584, 61.97848728724888, 59.9562349319458, 48.931000164576936, 40.11438233511788, 28.977740151541575, 19.591953686305455, 16.402268477848597, 14.005415286336627, 9.706319894109454, 7.341416256768363, 4.717382592814309, 2.235252205814634, 0.4763530247977802, 0.10245947992163044, 0.1509106121957302, 0.3537875073296683, 2.114147058555058, 5.825937279633113, 2.818292051553726, 1.5099729640143258, 3.106759761060987, 2.7457947645868575, 0.9339236574513572, 0.1870957990842206, 0.5118896950568471, 10.090946980885096, 39.652452196393696, 28.035986525671824, 19.234703370503016, 27.746500253677368, 30.086540630885533, 31.986532483782085, 11.548289946147374, 0.3901439835982663, 0.1551691386848688, 0.030723173370850936, 0.09391675117824759, 0.0966069253959826, 0.0677212146776063, 0.04343946244833725, 0.023147940569158112, 0.0298117549557771, 0.09351072260843855, 0.02474466578236648, 0.025796356045507958, 0.082100342027843, 0.024852188137759055, 0.036803281400352716, 0.042682325933128595, 0.06663076140518699, 0.018932260173772062, 0.08648291828909091, 0.019682784365223985, 0.026212504965120127, 0.012117032394079226, 0.03457820561847516, 0.032806197846574445, 0.03960867425692933, 0.017353390609579425, 0.05955040454864502, 0.012484956133578504, 0.03547698292615158, 0.02281787060201168, 0.03858376407463636, 0.08217587654611894, 0.04111398383975029, 0.03402806638873049, 0.07058744159127985, 0.02530596182415528, 0.05651775674362268, 0.02410816091911069, 0.06687264556863479, 0.04160649169768606, 0.03345591209030577, 0.029794262322996343, 0.032119669685406346, 0.03943896247074008, 0.034483030904084444, 0.02867409260943532, 0.010389185377529689, 0.015583111405638712, 0.04156738093921116, 0.040483268576541116, 0.029184493435812846, 0.04136599174567631, 0.02761693505038108, 0.019648496294394135, 0.020333913354469196, 0.061348868400922844, 0.062493699469736645, 0.050004478743565936, 0.022321754634114246, 0.07073051748531205, 0.03710595890879631, 0.025265285346124853, 0.03341815500919308, 0.04331632869850312, 0.02631968635666583, 0.16737062324370655, 0.07139566500804254, 0.05658284182261143, 0.01702232998130577, 0.07187023918543543, 0.07580563372799329, 0.06485122189457927, 0.10536540113389492, 0.028859651580985104, 0.04109377706689494, 0.033693324707980664, 0.03988117392041853, 0.030528345610946417, 0.03801556902804545, 0.048766817298850844, 0.005277670396026224, 0.048137642310134, 0.020550108182110956, 0.02594443443896515, 0.05053289806736367, 0.3373375114585672, 13.735450846808297, 49.21523012433733, 47.49879578181675, 32.937452520642964, 21.771252700260707, 26.733039481299265, 59.175097601754324, 46.599156924656455, 13.048526746886116, 0.953630160008158, 0.2818060969667775, 0.3390084446540901, 0.1141577357692378, 1.2797560202223914, 2.1802934748785834, 1.4142026858670371, 1.6731706240347453, 1.469372576900891, 0.09101640073848621, 0.5462464200598853, 2.8201815273080553, 9.76593109539577, 20.267368963786534, 32.55807392937796, 44.49009377615792, 53.35337918145316, 55.32882152284895, 59.54561723981585, 58.077501092638286, 57.26666021347046, 56.27264397484915, 59.036335127694265, 57.88675914491926, 61.084261076790945, 60.468067032950266, 63.22078350612095, 62.97911821092878, 62.618722098214285, 55.71380731037685, 55.617665086473735, 55.13211802073887, 44.55885314941406, 49.3745106288365, 51.474537645067485, 36.996902806418284, 49.368514333452495, 64.31166458129883, 59.36451939174107, 65.29454980577741, 62.9453638621739, 62.178942816598074, 62.23608480181013, 60.6232203074864, 64.6045172555106, 63.54781436920166, 68.89850398472377, 62.70243399483817, 60.0821293422154, 62.81901087079729, 53.961384773254395, 44.42457226344517, 33.77147953850882, 24.65205921445574, 21.099365370614187, 18.929307460784912, 14.266814334051949, 10.784946952547346, 8.373679723058428, 4.340107134410313, 1.199927406651633, 0.6633175952093942, 0.9851146191358566, 1.1974446198769977, 3.001488038471767, 5.807733867849622, 4.023314441953387, 3.113988710301263, 2.114084307636533, 0.1511698261435543, 0.9522988200187683, 0.20729419881744043, 0.12376414957855429, 7.86957141331264, 45.25911692210606, 41.38930034637451, 20.974330799920217, 19.40424289022173, 29.056204421179636, 36.335764339991975, 19.590982675552368, 1.0504056470734733, 0.04103737384346979, 0.05297055208523359, 0.0333759229896324, 0.03107798272477729, 0.051099674975765605, 0.06626883761159011, 0.05921898090413638, 0.01781883170562131, 0.031083892764789716, 0.04708323281790529, 0.008090355383631374, 0.04763000990663256, 0.04356235871091485, 0.04563563603109547, 0.008849416393786669, 0.06786513874041182, 0.044108423337872536, 0.01429589994118682, 0.031107288652232716, 0.030424499219017367, 0.007118278482396687, 0.057376215500491004, 0.04785352273445044, 0.040776504270200215, 0.03408722107165626, 0.011365470892217542, 0.015079746987404568, 0.017318851480792676, 0.03268551021548254, 0.006546099162993154, 0.012204815317610545, 0.10219229318733726, 0.027683811461819068, 0.014966586006007023, 0.02663560038698571, 0.015451694439564432, 0.01771861038702939, 0.059733412228524685, 0.2111641147306987, 0.11374777848167078, 0.05579998543752091, 0.1462748609483242, 0.13155730068683624, 0.16611032587076935, 0.1621696523257664, 0.13935836351343564, 0.0662980078320418, 0.14474142608898027, 0.08129497524350882, 0.11075127962976694, 0.12938092675592217, 0.12558357337755816, 0.12745717141245091, 0.06047824690384524, 0.14726664844368184, 0.24736474507621356, 0.20205289577799185, 0.1118540618834751, 0.168606696916478, 0.14853341904069695, 0.08426066182021584, 0.14853985155267374, 0.1932088839156287, 0.060916010556476455, 0.21896806811647757, 0.1377942453005484, 0.1391828265041113, 0.05743220142487969, 0.20962922780641488, 0.13709239581865923, 0.1573241523333958, 0.19202535599470139, 0.17204129190317222, 0.09228931886277028, 0.13249981296913965, 0.1368025799414941, 0.08514486758836678, 0.1860729075436081, 0.15647591570658342, 0.15730020004723752, 0.09784465469419956, 0.12035699454801423, 0.07846505673868315, 0.1340627505310944, 0.21034783710326466, 12.458862662315369, 56.171433040073936, 62.22817775181362, 50.26334851128714, 44.17941549846104, 27.499860048294067, 51.2929117338998, 52.76172617503575, 20.48276833125523, 1.8216795751026698, 0.8067590839096478, 1.261429712176323, 4.907986445086343, 3.1869020206587653, 3.2016840960298265, 2.6884215346404483, 1.605327001639775, 1.358820114816938, 0.10832162893244199, 0.5188635151301111, 2.106070646217891, 8.16169365814754, 15.455145631517683, 29.117207867758616, 39.82658447538103, 51.45680236816406, 53.832714557647705, 59.530018533979145, 55.8663306917463, 56.68771546227591, 54.2923344203404, 60.542190415518625, 61.40405886513846, 68.02636609758649, 62.31862940107073, 68.04344476972307, 63.91189997536795, 67.62355123247418, 57.46321432931082, 58.60471303122384, 55.32339150565011, 50.35851798738752, 57.61907632010323, 55.709214551108225, 38.35592876161848, 50.34258229391915, 61.474527495247976, 61.442454610552105, 64.33951296125139, 63.794148853846956, 65.07709203447614, 64.6424127306257, 63.65895080566406, 69.11726106916154, 66.25318581717355, 70.46009772164481, 64.56328664507184, 65.49906308310372, 62.25062738146101, 55.80024637494768, 42.291412762233186, 32.52025835854666, 20.44829831804548, 18.621200016566686, 15.731960126331874, 12.04347242627825, 8.855327980858938, 6.2080152460506985, 2.9580459467002322, 1.0780736995594842, 0.7320509670036179, 0.855310218674796, 0.7390802098172051, 3.4857032213892256, 10.776450174195425, 7.7035224948610574, 7.674655335290091, 9.322724614824567, 7.904975959232875, 3.060704278094428, 0.45044647636158125, 0.8223150691815785, 13.079933473042079, 49.00947659356253, 37.48389162336077, 26.814725978033884, 34.44405126571655, 40.18961048126221, 44.332751819065635, 17.931520087378367, 0.9117649836199624, 0.25609594370637623, 0.12223330672298159, 0.17828419405434812, 0.13669473358563014, 0.10865530531321253, 0.2186494009303195, 0.11760295661432402, 0.12922315379338606, 0.21406966953405313, 0.101540288887918, 0.047966865223965476, 0.14401968196034431, 0.11190374421754054, 0.15015224074678762, 0.08895816653966904, 0.2761520546461855, 0.1796178546335016, 0.23572792378919466, 0.1268642403717552, 0.10040075039224965, 0.1215859300323895, 0.3008175625332764, 0.18292119380618843, 0.09516192400561911, 0.09704261273145676, 0.19674131008131163, 0.14832924785358564, 0.12117990824793066, 0.09429273421743087, 0.13431479914912156, 0.16244401117520674, 0.22246803316686833, 0.13684041505413397, 0.10626364579158169, 0.12652833839612349, 0.10882805354361023, 0.09235679238502469, 0.2057036448802267], [0.016105780145153403, 0.03190445534086653, 0.029138604112501656, 0.031081650206553083, 0.0661816865737949, 0.05244588506008897, 0.04718367635671582, 0.020603463086964827, 0.09287065373999731, 0.048993868686790974, 0.0335799482917147, 0.05474922985636762, 0.03339590923860669, 0.02319378748403064, 0.04364897370604532, 0.0179609610433025, 0.06671089639088937, 0.005971056001726538, 0.03685767276744757, 0.018975243670865893, 0.05550422898626753, 0.04967947404033371, 0.016541526852441684, 0.030267224979719946, 0.04565261636993714, 0.06683667642729622, 0.03812237043998071, 0.03102101292461157, 0.044860579406044314, 0.06581720470317773, 0.03778970507638795, 0.022653062927669713, 0.05689171774845038, 0.037588940135070255, 0.04169979365542531, 0.03795200386749847, 0.05451151868328452, 0.0420635698496231, 0.03270830899210913, 0.023701241772089685, 0.05196049164182373, 0.044448359204190116, 0.03748269172917519, 0.014159142056347003, 0.011063393887265452, 0.08758283712502037, 0.033092834787177186, 0.07466705875205142, 3.701238512992859, 28.59807321003505, 49.36546754837036, 40.444901193891255, 30.983209133148193, 22.248541831970215, 33.52043417521885, 42.93375287737165, 29.16121080943516, 5.333636130605425, 0.2594068689005715, 0.010035541407497866, 1.3036155913557326, 1.2372244681630815, 0.32673043491584913, 1.2314759194850922, 1.4598519163472312, 0.3632679714688233, 0.053512708350483856, 0.08670559312616076, 0.15299032202788762, 0.7871068098715374, 3.62279834491866, 8.25905876500266, 13.331990667751857, 14.035566994122096, 13.926062515803746, 14.575411626270839, 16.12720145498003, 16.89389521735055, 21.789229427065166, 29.595768519810267, 37.939710821424214, 48.98938240323748, 55.93693828582764, 60.98532567705427, 59.30104064941406, 61.916189738682334, 57.158942290714805, 49.2034911428179, 40.01012461526053, 47.93173803601946, 47.8970422063555, 35.97265148162842, 50.8820195879255, 67.00548117501395, 58.49911430903843, 62.04389762878418, 67.2156572341919, 66.89064134870256, 72.68514020102364, 68.67737061636788, 68.09088706970215, 65.666104725429, 60.32529544830322, 61.91165256500244, 59.3199953351702, 41.18060425349644, 29.021070855004446, 15.472821848733084, 7.023027649947575, 3.472722900765283, 1.9878338021891457, 1.0664837786129542, 0.5374788790941238, 0.5977032046232904, 0.21025323575096472, 0.3071495699031012, 0.13903711789420672, 0.4407846805240427, 1.3923389847789491, 1.7717070451804569, 3.770935893058777, 7.172724851540156, 2.459084297929491, 2.1897973077637807, 1.8664099063192094, 0.1621028980506318, 0.13649457932582923, 4.268832079001835, 25.768104927880422, 34.26950209481375, 21.653036049434117, 16.341007947921753, 29.29934447152274, 37.90563685553414, 27.8613018648965, 5.130417823791504, 0.04071957178946052, 0.08291870954313449, 0.03014633378812245, 0.03616053231858781, 0.015517266367429068, 0.02911361027508974, 0.04949123824813536, 0.07991596138370888, 0.03263209593881454, 0.01657900064518409, 0.03693403509844627, 0.029305320166583573, 0.06813280044921807, 0.02400158342373158, 0.00981857644260994, 0.04926340654492378, 0.06325135845690966, 0.028314586096842374, 0.04349214390718511, 0.06130485183426312, 0.06781874730118684, 0.03937684598245791, 0.0727676356743489, 0.02480452783804919, 0.04848731515396919, 0.09176869251366172, 0.044058337275471, 0.09828322580350296, 0.06778813180114542, 0.02201405257385756, 0.02886103918509824, 0.04170079788725291, 0.040095662232488394, 0.029104124355529035, 0.017079469415226152, 0.08220341828252588, 0.02789419294068856, 0.026334380032494664, 0.03363143552892974, 0.042669043610138555, 0.057672714947589805, 0.034419126476028135, 0.012490847513877919, 0.007068285718560219, 0.0300226572102734, 0.028657030846391405, 0.02622482207204614, 0.029415931552648544, 0.05890612876308816, 0.026039502284090434, 0.022030071089310304, 0.058689207902976444, 0.026709068766129867, 0.02266767348295876, 0.029078770894557238, 0.02611799182237259, 0.08223702612199954, 0.04364446144817131, 0.11086921580135822, 0.053785133375121016, 0.04214081088347094, 0.030499192353870188, 0.06626100053212472, 0.04094041797465511, 0.05578562763652631, 0.005959446267557463, 0.036816689252321205, 0.00507984690401437, 0.060296413089547835, 0.011113349331675895, 0.04616031323426536, 0.021732066990807652, 0.01674443426808076, 0.014214262000418134, 0.04646916541137865, 0.01922194373660854, 0.03362436180136033, 0.044959693016218286, 0.03898990460272346, 0.029420348815619946, 0.04880962607317737, 0.03963295902524676, 0.019269001836489354, 0.04668106171967728, 0.033353745072547875, 0.09395280174378838, 0.037992017077548165, 0.17782688859317983, 8.760907173156738, 39.129492555345806, 53.43971402304513, 39.60843883241926, 21.701944419315883, 22.078562838690623, 47.28655958175659, 55.7131541797093, 30.21793106624058, 3.9784924813679288, 0.08125239038573843, 0.2112893858658416, 0.08778744257454361, 0.5691542508346694, 1.163983615381377, 1.0048957062619073, 2.4614855519362857, 0.9529759436845779, 0.3499635282371725, 0.18294745311141014, 0.30777227506041527, 1.3350656351872852, 5.976441775049482, 12.702291931424822, 19.507369790758403, 20.666421379361832, 22.80474512917655, 21.75260373524257, 21.716862201690674, 23.780577932085308, 28.609975474221365, 38.1134157861982, 49.16942759922573, 55.40864590236119, 61.42165865216936, 67.8823299407959, 67.34772859300885, 68.7347002029419, 62.61603314535958, 56.8720372744969, 51.914959635053364, 53.206845147269114, 51.53044979912894, 39.40522139413016, 57.01266533987862, 67.57311425890241, 58.19096864972796, 64.03950364249093, 65.6699470792498, 65.45515741620744, 71.17524106161935, 67.07164887019566, 69.98885004861015, 68.02988883427211, 62.992847851344514, 60.766909054347444, 62.24505492619106, 45.98545381001064, 33.17193685259138, 19.310478687286377, 9.732033440044948, 6.143119071211133, 4.58335314478193, 2.9926536210945676, 1.9061143015112196, 1.8713198942797524, 1.303417133433478, 0.9608886390924454, 0.9925920750413622, 1.001451245376042, 2.9043587361063277, 6.491121768951416, 4.078542632716043, 4.218661308288574, 1.1645528248378207, 0.37738068561468807, 0.4442954207105296, 0.20964057291192667, 0.04088696637856109, 1.5911950170993805, 27.373936108180455, 48.06784977231707, 32.5585081917899, 15.032101086207799, 22.524388790130615, 39.80151884896414, 36.354611328669954, 11.298049705369131, 0.16124930099717208, 0.06211265455931425, 0.03416355626125421, 0.03498644960512008, 0.03529803627835853, 0.050772719484354766, 0.06224277043449027, 0.05212160299665161, 0.08661371269928557, 0.07268977378095899, 0.04162600636482239, 0.027167714333959987, 0.03477697566683803, 0.04153112681316478, 0.006816135744364666, 0.05858116477195706, 0.014518829228888665, 0.0941832729482225, 0.010812039071294879, 0.03652901415313993, 0.06065937504172325, 0.08779299299099616, 0.028820964906896864, 0.03353759752852576, 0.04167127822126661, 0.013318752687025284, 0.0660429804452828, 0.1862601289259536, 0.012137770968755441, 0.014724148836519037, 0.023245549527928233, 0.028894300971712385, 0.05492259894630738, 0.010251643784743334, 0.08146127060587917, 0.012051723398534315, 0.042200325189956596, 0.022056501724624207, 0.04899970408795135, 0.00698010203528351, 0.13844603246876172, 0.1979625238371747, 0.11012183661971774, 0.11275460677487509, 0.19563953205943108, 0.11676518299749919, 0.1360946779272386, 0.11534988108490195, 0.19171415269374847, 0.09839021041989326, 0.09321760226573263, 0.1730089642639671, 0.13857437058218888, 0.12322330288589001, 0.12047625386289187, 0.1771490049681493, 0.1427697390317917, 0.1618892273732594, 0.20785621580268654, 0.08698880007224423, 0.13069364774440015, 0.21687063494963305, 0.1515430204038109, 0.1555214204958507, 0.15226859146995203, 0.15210353104131563, 0.11313166868473802, 0.06472694820591382, 0.10679214314690658, 0.15972909757069179, 0.09126644767820835, 0.186647396002497, 0.06943271069654397, 0.09781967103481293, 0.21516840771905013, 0.13910760411194392, 0.17911001188414438, 0.114058628944414, 0.1999066352312054, 0.13385091189827236, 0.1535218320786953, 0.13023096828588418, 0.1312362179160118, 0.10459362183298383, 0.059105869116527696, 0.16144952311047486, 0.12828520126640797, 0.23989657152976307, 7.163867201123919, 42.50163051060268, 66.4001054763794, 53.56888450895037, 43.04372549057007, 29.355155876704625, 43.60242319107056, 54.873707566942485, 37.341436181749614, 8.321608185768127, 0.5127743961555618, 0.5165495478681156, 3.980759331158229, 5.978764644690922, 5.086156930242266, 4.563829141003745, 3.8136238881519864, 1.2317058614322116, 0.34280501093183247, 0.2727545755250113, 0.4623809573905808, 1.27035282765116, 4.922152084963662, 10.07323168005262, 16.341464791979107, 16.03434225491115, 18.296852895191737, 16.419578177588328, 18.49826553889683, 19.634191785539898, 25.227908543178014, 33.45977292742048, 41.65082359313965, 53.1522079876491, 58.10995265415737, 63.48724692208426, 62.12100178854806, 66.53166961669922, 62.63799640110561, 56.84400129318237, 55.28828225816999, 61.15047740936279, 56.01771804264614, 49.45586013793945, 62.609084946768625, 67.94036129542759, 62.94715649741036, 69.53374998910087, 67.07366384778703, 66.5118603025164, 72.64933613368443, 68.62744780949184, 69.04058769771031, 68.61722700936454, 64.5258844920567, 63.35749626159668, 59.05993815830776, 45.401221479688374, 29.06615945271083, 16.582711458206177, 7.652164884975978, 4.931097456387111, 3.099925990615572, 2.344912584338869, 1.296144215123994, 1.1768006533384323, 0.755684070289135, 0.5161684826016426, 0.7943039493901389, 1.3473535243953978, 3.9178481698036194, 7.155305283410208, 10.599739245006017, 17.278712511062622, 9.74698075226375, 9.31596749169486, 4.904240497520991, 0.89657752428736, 0.27928745640175684, 5.518147281238011, 32.43564667020525, 43.339336599622456, 32.38812099184309, 24.97530504635402, 37.84184544427054, 49.33018112182617, 40.28010034561157, 10.096150313104902, 0.22530448596392358, 0.14256013956453117, 0.17852024281663553, 0.09131733101925679, 0.10760357603430748, 0.19076337585491793, 0.13137556186744145, 0.24724298875246728, 0.2007372435182333, 0.23192063665815763, 0.13941563186900957, 0.06290201470255852, 0.14368110655673913, 0.12390527129173279, 0.05086945482928838, 0.13359088370842592, 0.17112954439861433, 0.22316518718642847, 0.09423050577087061, 0.12779809454722063, 0.1525380920086588, 0.11255070700177125, 0.20377793535590172, 0.12445165483014924, 0.14644273051193782, 0.14266493251281126, 0.23457889258861542, 0.23538681066461972, 0.15018434902387007, 0.13817195860402925, 0.1282175106129476, 0.08822975241179977, 0.1557552708046777, 0.10641542728990316, 0.25507849401661326, 0.11256949563643762, 0.18992140889167786, 0.11450651633952345, 0.14339344842093332, 0.12623381348592894], [0.025234074431604574, 0.10555602197668382, 0.024192038025440912, 0.04948869713449052, 0.03459860238113573, 0.030519076822591678, 0.023805117001757026, 0.05105960409023932, 0.03342920495197177, 0.0044161115822914454, 0.05317764436560018, 0.048521900083869696, 0.012973513221368194, 0.027036755379023295, 0.021145356419895376, 0.09403550837721143, 0.06455388106405735, 0.02151360415986606, 0.04372421645426324, 0.08282992323594433, 0.008435871352308562, 0.039051722535597425, 0.04289114847779274, 0.03610510279291442, 0.040321746708026955, 0.049204930397016663, 0.07850114123097487, 0.04199653058978064, 0.011797110766305454, 0.04454965091177395, 0.021613818693107793, 0.026892894080707004, 0.03660110171352114, 0.03571818855458072, 0.03285487934148737, 0.07461602613329887, 0.0326982293544071, 0.030596144830009768, 0.023355233017355204, 0.04632587577881558, 0.009581566705102367, 0.015663952067760483, 0.05871769958840949, 0.04286282642611435, 0.0261983609026564, 0.05173500766977668, 0.027348794974386692, 0.032079405417399745, 0.07617882120289973, 1.4416754288332803, 22.141501358577184, 46.09569045475551, 43.759348256247385, 37.70883955274309, 17.71612593105861, 22.253402096884592, 32.657353264944895, 42.54675211225237, 20.32926004273551, 2.2711594104766846, 0.41782655673367636, 0.7268523031047412, 1.1349977936063493, 0.4704932506595339, 3.1475856389318193, 1.471636061157499, 0.15860301442444324, 0.15201104671827384, 0.07312685889857155, 0.04925613943487406, 0.04371424198948911, 0.018766906278740083, 0.08808388095349073, 0.2105893548578024, 0.1331057311700923, 0.49023894539901186, 0.43966317070381983, 0.7590606776731355, 0.9281348309346608, 1.4992599274430956, 2.4264242904526845, 4.485039174556732, 5.644257954188755, 4.644976718085153, 6.165088406630924, 3.2738739252090454, 3.7391695976257324, 2.6409601271152496, 8.380970120429993, 28.876223496028356, 29.228139332362584, 22.220531906400407, 7.937519584383283, 27.788976328713552, 52.54176705224173, 54.812507833753315, 63.53855242047991, 66.95598915645054, 60.35019779205322, 63.253877776009695, 61.22539288657052, 55.580158710479736, 56.25464119229998, 43.49651179994856, 24.70788972718375, 12.639631339481898, 4.091940496649061, 0.9492956783090318, 0.44093452819756096, 0.3573846114533288, 0.4022196541939463, 0.4688308398638453, 0.8706289881042072, 0.665449932217598, 1.6685081656490053, 1.638343755687986, 1.1901634505816867, 0.7962899399655206, 2.2767611784594397, 6.643677285739353, 2.3721100049359456, 0.940070207629885, 0.7588724792003632, 0.07762671993779284, 0.12809658210192407, 2.906972561563764, 20.982340335845947, 33.44356625420706, 22.343372583389282, 18.41755700111389, 24.019118274961198, 33.34003462110247, 35.9307746887207, 16.39999120576041, 2.083030636821474, 0.08235055860131979, 0.015575518598780036, 0.06017748625682933, 0.031207033299974034, 0.05644806780453239, 0.036385015451482365, 0.04958396345110876, 0.03254998980888298, 0.015910384112170765, 0.02226557193457016, 0.03513258569208639, 0.03962728647249086, 0.05714577143745763, 0.006817511050030589, 0.04976196014987571, 0.039032228224511654, 0.03878549932103072, 0.04093345620536378, 0.06627824210694858, 0.05233344162947365, 0.01989236008375883, 0.012600192583964338, 0.07896702337477889, 0.05074660945683718, 0.021330116416460702, 0.04065569450280496, 0.007253446898955319, 0.05200745305046439, 0.030966261933956827, 0.03364849050662347, 0.012627387419342995, 0.06119804363697767, 0.018013109852160727, 0.02533856712813888, 0.03976860835349985, 0.01764410554564425, 0.030915850174746344, 0.006195986119564623, 0.07220990703042064, 0.06757288013717958, 0.032120395717876296, 0.0053241996626768795, 0.03795875868360911, 0.054169292761279006, 0.07238636684737035, 0.0061993800669110245, 0.03780620704804148, 0.0013620249332494236, 0.03806449140289, 0.025856143462338617, 0.039538944605737925, 0.020030833814027052, 0.015196665356467878, 0.026324020499097447, 0.0759707959368825, 0.052369672006794384, 0.02115106798841485, 0.07094257324934006, 0.04975047255200999, 0.0441768196677523, 0.028903637613568987, 0.01795649458654225, 0.02264986533139433, 0.04598676772522075, 0.010509902694528657, 0.04389560761462365, 0.019667909181277667, 0.04559871354805572, 0.046110305203390975, 0.05100511772824185, 0.028113028965890408, 0.013107328808733394, 0.031086746004543135, 0.044516959094575474, 0.04490382244278278, 0.03197743856747236, 0.07037746892975909, 0.04468756993966443, 0.05547980511827128, 0.0556957217465554, 0.03488624355356608, 0.0254062815303249, 0.05974030614431415, 0.029221500735729933, 0.026342410494440367, 0.036498191699917824, 0.03883177540930254, 0.08502480081681695, 0.045064848980733326, 0.1094886955938169, 4.364375455038888, 33.698516505105154, 53.695004735674175, 40.51529686791556, 29.732700143541607, 19.08750578335353, 31.102040699550084, 48.491436277117046, 45.917163440159385, 16.24701792853219, 0.6888617245214326, 0.1616859111402716, 0.36286524736455505, 0.5778950303792953, 0.6162725910544395, 2.250088563987187, 1.2476943177836282, 0.5855453770075525, 0.8120487800666264, 0.9829328847782952, 0.6732201895543507, 0.13682977562504156, 0.07040771123554025, 0.4918432193143027, 0.5260029520307268, 0.6626890546509198, 0.5843284108809063, 2.623583116701671, 1.8334923812321253, 2.3512562896524156, 3.2085979878902435, 3.728550578866686, 9.492002708571297, 11.650385907718114, 11.080464260918752, 12.513392993382045, 9.49189761706761, 9.556587951523916, 7.2953618594578336, 14.974022831235613, 43.22068221228463, 42.5669401032584, 32.92659943444388, 14.554656488554818, 37.39000756399972, 58.92909663064139, 58.3278203691755, 65.76830577850342, 67.5592178617205, 62.711730684552876, 66.48115621294293, 63.190009934561594, 58.05233471734183, 59.417638369968955, 51.818515164511545, 33.81792824608939, 17.987743173326763, 9.112929838044302, 2.6120860193456923, 1.461569858448846, 1.0504848999636514, 1.5451503906931197, 1.723224686724799, 1.8612415322235651, 2.14088220681463, 5.265710975442614, 6.792481209550585, 3.23845483149801, 2.9733337206499915, 4.449795739991324, 2.479230599743979, 1.6898069999047687, 0.34180791729262894, 0.5268390700221062, 0.5569033824971744, 0.1170598164732967, 1.0590868783848626, 17.00395815713065, 47.62462765829903, 37.482825074877056, 19.434411968503678, 17.126751933779033, 28.455058438437327, 41.826269081660676, 25.413581780024938, 5.325447244303567, 0.10202820306377751, 0.02209899158749197, 0.021447905006685426, 0.03170047414356044, 0.1133792796837432, 0.056125315837562084, 0.010621560720859893, 0.028007674529882412, 0.02176092847782586, 0.06785021097000156, 0.054488594377679486, 0.035117165983787606, 0.04296872877914991, 0.06540370546281338, 0.010491030091153724, 0.06661623397043773, 0.03653930752937283, 0.05139831180817314, 0.021068902486669164, 0.025220359542540143, 0.07171241194009781, 0.046769261094076295, 0.0545111760231001, 0.09044134231018168, 0.07201424467244319, 0.06067761406302452, 0.06979001366666385, 0.024179184875850166, 0.04854540453691568, 0.004541772026901266, 0.01938534514712436, 0.028597312979400158, 0.026192576391622424, 0.03336665080860257, 0.07350109131740672, 0.038969317850257666, 0.023376542409615855, 0.016696650135729994, 0.042199575408760986, 0.05329195376751678, 0.036222967718328745, 0.04793915046112878, 0.17881328852048942, 0.13687785661646298, 0.21898819346513065, 0.10731713247618505, 0.10292730946093798, 0.12088307631867272, 0.14403973945549556, 0.13350912023867878, 0.08515626697668008, 0.09520064799913339, 0.13750707570995602, 0.10589020047336817, 0.16003175133040973, 0.08762681297957897, 0.1343181375414133, 0.14916295026029858, 0.1646339422357934, 0.16143851727247238, 0.16334053235394613, 0.12215998422886644, 0.1636142669511693, 0.13961540614920004, 0.08340095795158829, 0.1438982920455081, 0.09950593233640705, 0.201099852632199, 0.10251542513391801, 0.07849286988909755, 0.13970740192702838, 0.133551990081157, 0.10328026302158833, 0.16888746113649436, 0.08593618869781494, 0.13354623610419886, 0.1969524837498154, 0.14912943063037737, 0.22349851072898932, 0.15903845748731069, 0.16126113464789732, 0.10770197039736168, 0.11327101942151785, 0.11249940296901123, 0.15152176868702683, 0.13577871131045477, 0.10568850593907492, 0.13141616540295736, 0.08270916435867548, 0.1472336852124759, 3.146546883242471, 32.36787394114903, 63.73806299482073, 56.84888935089111, 49.1802077293396, 26.34587369646345, 30.645203590393066, 40.549381256103516, 53.75906365258353, 26.96417999267578, 2.651209588561739, 0.41439281670110567, 2.3002111315727234, 4.137774288654327, 5.03203741141728, 8.482985309192113, 4.0591936366898675, 1.0688078424760272, 0.4273688218423298, 0.7830166007791246, 0.3054559464965548, 0.15523844425167355, 0.09207280512366976, 0.27791868842073847, 0.27802331852061407, 0.6029610367757934, 0.7858624852129391, 1.4336992225476672, 0.988632470369339, 1.2640035854918616, 1.8088973867041724, 3.162439150469644, 6.299932965210505, 7.575898851667132, 6.387911490031651, 8.354391523769923, 4.966242747647422, 5.651978271348136, 4.312619626522064, 11.74403633390154, 41.82402828761509, 40.49583843776158, 30.51084974833897, 11.083430273192269, 31.931287356785365, 57.037706647600444, 59.61650276184082, 67.56310190473283, 68.21464143480573, 59.96341242109026, 67.49150766645158, 65.99492822374616, 59.00435951777867, 60.18060616084507, 45.59688622610909, 29.303996290479386, 16.56121894291469, 6.884645589760371, 1.409902076636042, 1.146764025092125, 0.8108401734914098, 1.220053840960775, 1.499972443495478, 1.912770458630153, 2.6480789908341, 3.4399478137493134, 4.469791787011283, 3.6864453639302934, 5.280269188540323, 10.312300954546247, 13.123362319810049, 9.296964168548584, 6.80734601191112, 4.7462310791015625, 1.6040313797337669, 0.3689239951116698, 3.6634112170764377, 26.628265857696533, 43.21952881131853, 32.521290166037424, 26.948906115123204, 32.948934418814524, 42.03057391302926, 50.912716729300364, 27.97226980754307, 4.210122840745108, 0.16866506449878216, 0.12430218713624136, 0.13612926964248928, 0.179949196853808, 0.2378406918474606, 0.10901021305471659, 0.10829985474369355, 0.16824803687632084, 0.10454063503337757, 0.09838854122374739, 0.21021968897964272, 0.1286994061831917, 0.10167058796754905, 0.1768072268792561, 0.10133974786315646, 0.11794713671718325, 0.1530974084245307, 0.14620495827070304, 0.1379100712282317, 0.09706028178334236, 0.12818692225430692, 0.09497914702764579, 0.22932084330490657, 0.15364751033484936, 0.19599454158118793, 0.17390425050897257, 0.14196354443473475, 0.11243959689246756, 0.12524138816765376, 0.12590211842741283, 0.07500174614999976, 0.21574361542505877, 0.15511227745030606, 0.21736614193235124, 0.16727705326463493, 0.08718548701809985, 0.12126222811639309, 0.08690918077315603, 0.16493853660566465, 0.19876654712217195, 0.12837684420602663], [0.07220595795661211, 0.02752072557008692, 0.028719011627669846, 0.049895818145679574, 0.0594715452087777, 0.0852200153416821, 0.009502709061572594, 0.032855395028101544, 0.05249204919008272, 0.021893283518563424, 0.0697902918660215, 0.02651821043608444, 0.055982521535562615, 0.04890567609774215, 0.02236435645526009, 0.04454037533806903, 0.04038569524085947, 0.052786628383078744, 0.017562406536723887, 0.14576944735433373, 0.09887333413852112, 0.027740070496552756, 0.04566415146525417, 0.019698263445336903, 0.07056047660963875, 0.023891808332077095, 0.03512551535719207, 0.09930510632693768, 0.06034405303320714, 0.05301928786294801, 0.08874143566936255, 0.04635391623846122, 0.02040109341032803, 0.039299299607851675, 0.028089991005669748, 0.018335870300818766, 0.05015168691586171, 0.052831489725836685, 0.006249114987440407, 0.023915870880175914, 0.02382742044782, 0.025834874782179083, 0.0182106466631272, 0.02169945659781141, 0.12127106264233589, 0.04303338298840182, 0.026276166816907268, 0.04627487708681396, 0.1339561798210655, 0.05497059512085148, 0.370327069823231, 10.93139934539795, 41.49112272262573, 43.701087611062185, 36.254102161952424, 26.15881429399763, 29.351702622004918, 31.52689525059291, 33.782544544764924, 33.11474275588989, 11.515497054372515, 1.9798008160931724, 0.0815449950418302, 0.1640717624021428, 1.7103572743279594, 1.7220721542835236, 1.1003566810062952, 1.9383337497711182, 0.748582794197968, 2.8177416239465987, 0.9184564245598656, 2.1108381961073195, 1.206487917474338, 0.8434557233537946, 0.08488034071134669, 0.4815634680645806, 0.8307819377098764, 0.33854413671152933, 0.6200393832155636, 0.5579268304365022, 0.1720730880541461, 0.14617795257696084, 0.11985463436160769, 0.07971897588244506, 0.017588000877627304, 0.11695066733019692, 0.10094788031918661, 0.08828758395143918, 0.20837059962962354, 1.4140191014323915, 2.402456045150757, 0.2430337103349822, 0.08617594904665436, 1.0979694319622857, 12.282434003693716, 23.58107951709202, 33.05439070292881, 47.63340323311942, 48.39549207687378, 42.81042235238211, 28.27006091390337, 23.615158694131033, 16.283869436808995, 5.659657767840794, 0.8477617065821375, 0.04590297882844295, 0.09727184900215693, 0.36245519508208546, 0.224673936941794, 0.7212332189083099, 1.9210913607052393, 1.3336954287120273, 3.0905928228582655, 3.993624355111803, 8.799058863094874, 11.238414185387747, 2.6639412939548492, 2.2380138976233344, 2.541359003101076, 2.9889209185327803, 0.9683853111096791, 0.1998709307185241, 0.04563511695180621, 1.5761719260896956, 15.454608883176531, 40.43168919427054, 27.191769974572317, 19.24191038949149, 25.728653056280955, 30.969896384647914, 37.81109619140625, 31.52025624683925, 9.070771643093654, 0.3626516716820853, 0.022799110805083598, 0.05608744340549622, 0.040813175695283074, 0.06341384045247521, 0.02598200661928526, 0.014978367070268308, 0.032666314459804974, 0.010329883961406137, 0.010569927598615842, 0.03232250076585582, 0.03672208450734615, 0.06615909135767392, 0.014866554677220327, 0.023423062770494392, 0.03341289297012346, 0.020906052385855998, 0.030375101869659762, 0.01864063600078225, 0.06390440091490746, 0.03392011146726353, 0.016715186016101922, 0.06319780168788773, 0.053302996924945285, 0.002686990616244397, 0.03563517997307437, 0.03617781799818788, 0.023096880809004818, 0.050368190476936955, 0.029948500118085315, 0.10297686287334987, 0.07109968124755792, 0.08546377904713154, 0.03978898136743477, 0.013610962944637452, 0.012055993928307933, 0.04548789520881005, 0.03495789345886026, 0.012862862819539649, 0.045992016193589995, 0.05253300895648343, 0.0310917841270566, 0.043618622834661176, 0.04719329798328025, 0.05891480722597667, 0.02763644971751741, 0.06010010612330266, 0.06906588788011245, 0.08280812869114534, 0.060057310919676504, 0.025734551683334366, 0.004729308503946024, 0.015587598218449523, 0.042194656029875786, 0.049414831812360456, 0.018289714652512754, 0.015668264157803993, 0.042713528365961144, 0.07456245579357658, 0.05876610627663987, 0.024128389744354144, 0.037335395347326994, 0.013725179896157767, 0.053047504741698503, 0.016069822878177677, 0.06273604503699712, 0.029970545720841204, 0.029142719427389756, 0.013177666596935263, 0.01788128067606262, 0.08309092851621763, 0.04400323683928166, 0.02960103590573583, 0.0063224485077496085, 0.02840101788751781, 0.04075318302160927, 0.030303139838257005, 0.07438410964927503, 0.021929910838870064, 0.04300213305811797, 0.042656300722488334, 0.013678853765928319, 0.02375074090170009, 0.03409989610580461, 0.03101556428841182, 0.06930412831051008, 0.0135479592718184, 0.07648778533829109, 0.02756416707831834, 0.05522140541246959, 0.020907221162425618, 0.07542852432067905, 0.03132475234035935, 1.1509345727307456, 19.335420983178274, 53.09510769162859, 46.763322012765066, 28.490228482655116, 19.78739956447056, 24.520802531923565, 47.25125231061663, 55.83197184971401, 39.19958945683071, 7.527001772608076, 0.26498513243028093, 0.03521980458338346, 0.13211076813084738, 0.9105112680367061, 1.1802406630345752, 0.9994416960648128, 1.6202560748372759, 2.5452030939715247, 5.413117008549826, 2.4766321906021664, 2.1551631433623175, 2.1357531334672655, 2.7778910994529724, 0.7579342009765762, 1.4866644718817301, 2.3858042529651096, 2.1301813295909335, 1.9229825735092163, 1.7614814681666238, 0.398285698145628, 0.43597137023295673, 0.19735634779291494, 0.44257196890456335, 0.08014094323984214, 0.2196640550558056, 0.18058939464390278, 0.17679710313677788, 0.5681436679192952, 4.186699160507747, 6.385073150907244, 0.938747010060719, 0.146281184894698, 2.827051558664867, 17.822188445499965, 32.07564313071114, 42.67363664082119, 53.936558859688894, 54.05997623716082, 49.44610834121704, 39.58692373548235, 32.197917529514854, 24.875860691070557, 9.634558030537196, 2.393462036337171, 0.5098040955407279, 0.681354033095496, 0.8286069887025016, 1.6803716719150543, 2.9435958649430956, 5.794325581618717, 3.907249127115522, 4.783805634294238, 5.010909242289407, 8.410013590540204, 13.730491570064, 4.722894685609, 2.0493694373539517, 1.0317945714507784, 0.5404955372214317, 0.8019235176699502, 0.31783231667109896, 0.10601170573915754, 0.20228205062448978, 10.215051361492701, 43.11013289860317, 44.98271063395909, 25.4263299873897, 15.071783985410418, 22.253122431891306, 38.39318152836391, 42.261118616376606, 16.54735902377537, 1.381137945822307, 0.05364075130117791, 0.04139896176223244, 0.03691660353381719, 0.04144309367984533, 0.0149619787532304, 0.056409258994140794, 0.018752377147653272, 0.07929068457867418, 0.014696579958711351, 0.039405727825526676, 0.0657530560025147, 0.0483545699555959, 0.06721194021935974, 0.04982879584921258, 0.010613944165275564, 0.05265435815921851, 0.04100107900532229, 0.025314769208697335, 0.019108942210940377, 0.013040773005091717, 0.06602995257292475, 0.07544552840824638, 0.05621821406696524, 0.04680634642552052, 0.009202769441929246, 0.014223503647372127, 0.04114674351045063, 0.007375485662903104, 0.011122725837464844, 0.05218224706394332, 0.011308691930025816, 0.035828236756580215, 0.08402605155216795, 0.0083261463026117, 0.0406940792288099, 0.05745757184922695, 0.03236869203725031, 0.07014354398208004, 0.06910995194422347, 0.057533024943300655, 0.03643998357334307, 0.04671017087197729, 0.16634360621018068, 0.1601487307676247, 0.13333869938339504, 0.18009912595152855, 0.19071551199470246, 0.2023694866469928, 0.1066998555990202, 0.12496582152588026, 0.11458253940301281, 0.12442734970578126, 0.11884265366409506, 0.09310953877866268, 0.13076340114431723, 0.13908433036080428, 0.2250008008309773, 0.12013550714722701, 0.2405884601175785, 0.25628829481346266, 0.10120951663702726, 0.2840918371719973, 0.15376539900898933, 0.09869504227702107, 0.1298824862710067, 0.10403145557003361, 0.11233353508370263, 0.12340520455368928, 0.18116215962384427, 0.24163668815578732, 0.16444184897201403, 0.1636406755340951, 0.20078725154910768, 0.07608964134539876, 0.0951275901336755, 0.11327906006148883, 0.18131799197622708, 0.0867569310856717, 0.14290942225073064, 0.22380805840449675, 0.07771511948002235, 0.13592562771269254, 0.10324283502995968, 0.14641615908060754, 0.20536534089062894, 0.1387847707207714, 0.2265042308717966, 0.10288836833621774, 0.1719429993203708, 0.13919437517012867, 0.18185051982956274, 0.10570709101323571, 0.7958590973700795, 16.456057957240514, 59.878477641514365, 58.10420649392264, 45.535259178706575, 38.59209108352661, 36.44402769633702, 38.01924337659563, 44.675624574933735, 41.49912357330322, 15.354850121906825, 2.7751050889492035, 0.1734689702945096, 0.7213432501469339, 5.185062800134931, 5.191511596952166, 5.692090656076159, 3.8423976813043867, 3.8413567543029785, 6.931874232632773, 2.0547794784818376, 3.243909384523119, 2.032340488263539, 1.325428266610418, 0.2615996226668358, 0.7060943969658443, 1.986729038613183, 0.8525157943367958, 0.8270968954477991, 0.8201862605554717, 0.2053432342197214, 0.25050576510173933, 0.1400513241865805, 0.3278442637196609, 0.14418171612279757, 0.22906188720038959, 0.37574902602604454, 0.22555311476545675, 0.7568078871284212, 3.570258238485881, 4.758535036018916, 0.8183772319129535, 0.18879711707787855, 1.924494240965162, 14.328014067241124, 27.897538457598003, 38.73449093954903, 52.00397995540074, 55.49193743297032, 47.7450920513698, 33.864661829812185, 25.542443071092876, 17.95050256592887, 7.094435155391693, 1.4276635178497858, 0.16773354448378086, 0.34920826447861536, 0.8814503188644136, 0.9978724888392857, 2.0272435503346578, 6.753081449440547, 7.376957161085946, 6.5369520868573865, 9.595841799463544, 15.968409061431885, 17.346716267721995, 7.034367544310434, 7.216082913534982, 8.28155095236642, 7.694730418069022, 4.013071928705488, 1.2121173696858543, 0.2147389900471483, 2.0706372218472615, 20.275743280138286, 49.48113421031407, 34.907739298684255, 25.435581513813563, 35.485930170331685, 40.19693388257708, 50.089369092668804, 49.03948238917759, 17.737107753753662, 1.003814609987395, 0.13215282373130322, 0.11723852902650833, 0.0993622729022588, 0.1525568195751735, 0.07528077332036835, 0.11835860035249166, 0.11498401500284672, 0.34279692279441015, 0.09071570794497218, 0.08559906535914966, 0.184809556763087, 0.17441745368497713, 0.2533524366361754, 0.11650480196944304, 0.1382020448467561, 0.14018893108836242, 0.06281389335968665, 0.0655512393319181, 0.16471190590943607, 0.14366745443216392, 0.18887178307133062, 0.20376866656754697, 0.08667744749358722, 0.13947313092648983, 0.1393545094345297, 0.10246003632034574, 0.1295937153377703, 0.08657070714980364, 0.114119574959789, 0.14253290316888265, 0.17128836230507918, 0.15757440961897373, 0.13853728185806954, 0.10590758454054594, 0.17433802437569412, 0.17520677990147046, 0.12138435084904943, 0.12732957968754427, 0.13816792810601847, 0.14502286884401525, 0.2657126033944743, 0.1466625351458788], [0.013926727697253227, 0.03420231418151941, 0.03817778978762882, 0.033221576628940444, 0.03623473351555211, 0.058773095187331946, 0.014422171915482198, 0.017088263229067837, 0.10343981374587331, 0.033539005488689454, 0.05494068190455437, 0.03619124959888203, 0.04213486013135739, 0.046307446767709086, 0.07062079158744641, 0.0534011368373675, 0.07330508969191994, 0.026274239777454307, 0.07041512083794389, 0.023755731526762247, 0.020423096604645252, 0.028952651590641056, 0.024945384922570417, 0.06280701301459755, 0.038109763259334226, 0.06565833251391139, 0.029337140066283088, 0.06594924083245651, 0.03929796628654003, 0.03327417666358607, 0.0177493310599987, 0.04733170894905925, 0.046136157387601476, 0.04615368055445807, 0.026773626284141625, 0.03767599957063794, 0.0895080106066806, 0.023476205633154938, 0.08707291805850607, 0.02062610919321222, 0.0580666113112654, 0.04072112902732832, 0.04250501116205539, 0.04241700517013669, 0.05817158067865031, 0.09883758891373873, 0.021993839015652026, 0.029737757319318395, 0.036879338390593014, 0.03542125145239489, 0.04775934207386204, 0.015414268144273331, 4.238163598946162, 30.143029485430034, 49.19328076498849, 44.37994050979614, 37.08667353221348, 39.89068160738264, 19.390056405748638, 24.86125210353306, 42.602570465632844, 30.92612968172346, 13.184595925467354, 3.327440845114844, 0.17648912966251373, 0.19794948239411625, 0.5654579177498817, 2.080260911158153, 5.523062697478703, 11.929488096918378, 5.797466601644244, 4.898278074605124, 3.376156185354505, 4.848081682409559, 3.8317052721977234, 2.1549371097769057, 5.0057458622115, 7.8026741572788785, 5.298153851713453, 2.99299538561276, 0.5169574831213269, 0.995124584862164, 0.5134349635669163, 0.5156854742339679, 0.12773085172687257, 0.4150674162166459, 0.15120828550841126, 0.16903464895273956, 0.2929002530872822, 0.0778413609202419, 0.05545797325404627, 0.07918468383806092, 0.05026262739141073, 0.039076305859323056, 0.1158397833683661, 0.39119191308106693, 0.6918827795556614, 2.8760902072702135, 5.948085742337363, 4.526861684662955, 2.721876459462302, 0.4359181730874947, 0.253709400338786, 0.01797951727972499, 0.04588535388133355, 1.1825626641511917, 2.3326464082513536, 0.7481299670679229, 3.7502141935484747, 4.100237080029078, 3.23952094571931, 3.5249221112046922, 2.8037475177219937, 3.089253557579858, 8.253752946853638, 19.346182005746023, 5.948562562465668, 1.6381889411381312, 0.8306923710874149, 0.17136218691510813, 0.12590228127581732, 1.9284249671867915, 14.019446304866246, 35.794534410749165, 34.73075131007603, 24.31725331715175, 25.017082827431814, 33.150261947086875, 36.7575477872576, 37.3930960382734, 24.429355553218297, 2.7843485815184454, 0.10579234893832888, 0.004103675043942141, 0.015050072954701526, 0.0643784458349858, 0.023939831648021936, 0.02549042665798749, 0.0912270180082747, 0.015694827107446532, 0.052612482370542626, 0.04384097197492208, 0.03696196699248893, 0.009963162077058638, 0.03009475494867989, 0.06308304106018373, 0.06508654462439672, 0.012393348817048329, 0.05980484839528799, 0.042782840718116076, 0.011955297635202962, 0.026467885190088834, 0.03686974051275423, 0.038275176526180336, 0.016156967130622694, 0.021341883910021613, 0.02700300165452063, 0.05802551244518586, 0.01844092957409365, 0.08095220649348837, 0.06062160099723509, 0.054428893474063704, 0.05129122880420514, 0.025174824753776193, 0.0672829489090613, 0.11801294104329177, 0.05140512090708528, 0.025837251351081898, 0.12632031313010625, 0.04883971570857933, 0.0562922829496009, 0.10281890670635871, 0.054416242188641, 0.07182544230350427, 0.23776917425649507, 0.022743918766666735, 0.05282745583515082, 0.022091755011518086, 0.06745189734335456, 0.03780852085245507, 0.031119868691478456, 0.03266290821401136, 0.09179058883871351, 0.006013989032778356, 0.02845265100976186, 0.011472782901754337, 0.05632217920252255, 0.04314321066652026, 0.018749193122078265, 0.07659251043306929, 0.044366527880941115, 0.023044696377058114, 0.02793336646365268, 0.024345743170540248, 0.04241291021129914, 0.025211104324885776, 0.050544355131153546, 0.015930066716724207, 0.03176342522991555, 0.023567329493484328, 0.08783857018819877, 0.028103337789486562, 0.016001457082373754, 0.07033295024718557, 0.0650256189650723, 0.04509910821382489, 0.04746666277891823, 0.04823033697903156, 0.051333684740321975, 0.09251363575458527, 0.013516888305145715, 0.029841807271753038, 0.025434625634391392, 0.03336100878992251, 0.0564286854517247, 0.0346097642821925, 0.15614548272320203, 0.05662893809910331, 0.0367381759653134, 0.05399653096018093, 0.04503823683730193, 0.06304485310933419, 0.05800880691302674, 0.07027563439416033, 0.02271533547900617, 0.04410127157877598, 0.017977904062718153, 0.1738232605691467, 9.961063436099462, 42.64643096923828, 56.44489329201834, 43.47144617353167, 33.42484780720302, 26.961939198630198, 21.150109801973613, 39.965006487710134, 56.16065290996006, 36.81429025105068, 12.444193278040204, 1.7620172394173486, 0.20382798409887723, 0.18213730944054468, 0.40255447051354815, 0.6993187634008271, 4.5021547589983255, 4.71240941967283, 5.265875560896737, 4.776566914149693, 3.890529589993613, 5.6607508063316345, 3.5235722064971924, 4.0012122222355435, 4.115634288106646, 5.43032682793481, 4.728405475616455, 6.331044827188764, 3.889981116567339, 2.4975718898432593, 2.8219559235232214, 1.7498888330800193, 0.8983242362737656, 0.5589750313333103, 0.7337109350732395, 0.49298114968197687, 0.8039443578038896, 0.19152370148471423, 0.12804578697042807, 0.09949745064867394, 0.1068088486790657, 0.22271966109318392, 0.8658615467803819, 1.0058856074299132, 3.1302149253232137, 7.557942969458444, 11.28630724975041, 8.08511929852622, 5.062906086444855, 1.9991376527718134, 1.1715160054819924, 0.316255618418966, 0.14806370995938778, 2.194397449493408, 3.7216418981552124, 2.724275976419449, 4.3652309519904, 4.81802681514195, 6.3149910143443515, 2.8822265522820607, 4.249234684876033, 3.4708045465605597, 2.5415798255375455, 9.038203699248177, 1.0163439490965434, 0.2623117858810084, 0.34238727763295174, 0.18688918517104217, 0.10332478848951203, 1.1923207576785768, 6.925220029694693, 37.02989632742745, 53.77534328188215, 35.63017129898071, 18.227183307920182, 17.18717520577567, 35.23907804489136, 44.831417083740234, 34.50303104945591, 7.380164623260498, 0.16856268713516848, 0.09717175830155611, 0.014571636216714978, 0.011217114299402704, 0.02286159200593829, 0.027012329814689498, 0.060810572999928675, 0.002091186191786879, 0.06881326929266963, 0.01370682382756578, 0.045397375244647264, 0.03548679793519633, 0.03877799133104937, 0.09454794480864491, 0.022858095854254704, 0.04133239747690303, 0.03289480094930955, 0.04557359078899026, 0.018127582102481807, 0.035589551885745356, 0.02678926312364638, 0.05557482037693262, 0.021943445916154554, 0.04028117709926196, 0.03513917426711746, 0.070602220083986, 0.057421677346740446, 0.025407273887789676, 0.020272451652480022, 0.05684681569359132, 0.03937545159299459, 0.02697092221517648, 0.049623902022306404, 0.0783936952107719, 0.05709357173847301, 0.017858295302305902, 0.006105134097327079, 0.03628952521830797, 0.03612109925597906, 0.06857084230120693, 0.08168895303138665, 0.13097082929951803, 0.04515793380726661, 0.059493054768868854, 0.13444372080266476, 0.07716565539262124, 0.18312168733349868, 0.2029696644416877, 0.11801209965986864, 0.13078329579106399, 0.1840210719300168, 0.10034882889262267, 0.19260592412735733, 0.0998005997389555, 0.11974833506558623, 0.16960217564233712, 0.18188785282628878, 0.13537593292338507, 0.19478142953344754, 0.17342540834631237, 0.1397170235535928, 0.13411574411605084, 0.1398173924535513, 0.19073907073054994, 0.11198312602937222, 0.13405584304460458, 0.2589535532253129, 0.12127917792115893, 0.24287865151252064, 0.19297187163361482, 0.07984732756657259, 0.1419408677944115, 0.18008475457983358, 0.09180386098367826, 0.10983240750751325, 0.15091924316116742, 0.23518577430929455, 0.18637336284986564, 0.11840275941150528, 0.14987900826547826, 0.18954596189515932, 0.12756470564220632, 0.2043484611702817, 0.11108021983610732, 0.25923720800450867, 0.15512374469212123, 0.08388353884220123, 0.1457000875047275, 0.13390877736466272, 0.12311127675431115, 0.12244699097105435, 0.16994544650827134, 0.16426017800612108, 0.09532481990754604, 0.16853332013956138, 0.2965715618005821, 7.506436841828482, 45.97749464852469, 69.87879058292934, 59.943957465035574, 50.72433022090367, 51.69731773648943, 26.12809804507664, 32.558866024017334, 54.485782691410606, 40.63151938574654, 17.212940863200597, 4.845866509846278, 0.5725989831345422, 1.0166461957352502, 1.6782672362668174, 6.261751311165946, 12.821602923529488, 20.880712509155273, 13.176931193896703, 11.66338164465768, 7.9650387934276035, 9.74605143070221, 7.43871796131134, 5.117958835193089, 11.22027678149087, 13.862255471093313, 12.420702287128993, 5.533281760556357, 3.3834565707615445, 2.4552836333002364, 1.7445059333528792, 2.464485002415521, 1.2807579721723283, 1.1286991430180413, 0.5132222292678696, 0.564627825149468, 0.516883441380092, 0.21137143432029656, 0.26047081180981224, 0.1832168586552143, 0.13141266416226113, 0.2465442605316639, 0.3468069833304201, 0.6449541034443038, 1.3771795353719165, 4.1414676904678345, 6.958270873342242, 5.090762283120837, 3.132005823510034, 1.1311290583440234, 0.8137050569057465, 0.2868376784026623, 0.3460758754185268, 2.64821035521371, 5.6591483780315945, 3.8770092640604292, 8.883231946400233, 11.942692279815674, 12.583589775221688, 10.028916937964302, 9.996377655438014, 7.259155230862754, 16.359530108315603, 30.636421067374094, 15.976630517414637, 5.512514463492802, 2.440374970436096, 0.6538129480821746, 0.269379976604666, 2.996692261525563, 17.926307201385498, 45.83312497820173, 45.687761715480256, 32.3249305997576, 34.510722705296104, 44.43451860972813, 47.82398189817156, 55.54795033591134, 39.525803906576975, 6.266137361526489, 0.2319107029054846, 0.17086305655539036, 0.0688632908942444, 0.14694129090223992, 0.10590902982013566, 0.15445829182863235, 0.17296114111585276, 0.06385843016739402, 0.1744354755750724, 0.12596503219434194, 0.11813761506761823, 0.1190221126058272, 0.09062082839331456, 0.20104145790849412, 0.157975790223905, 0.10284374787339143, 0.20772789125995977, 0.09564307997269289, 0.10681545082479715, 0.12524186314216681, 0.10719800208296094, 0.15773011983505317, 0.13626849145761558, 0.12707027074481758, 0.07988742220082454, 0.2025185472198895, 0.22795242816209793, 0.1518828985946519, 0.15965652146509715, 0.1544384786060878, 0.19386490514235838, 0.07912562415003777, 0.17221950234047004, 0.173974126045193, 0.13079443733607019, 0.08037372824868985, 0.24479339591094426, 0.08100163098424673, 0.13560841259147438, 0.15379301538424833, 0.15822884307375976, 0.17401451244950294, 0.3147186551775251, 0.21574297760214123], [0.016737382592899457, 0.015211479472262519, 0.02266022147211645, 0.0713063697995884, 0.028303502227312753, 0.0657651067844459, 0.07702511721955878, 0.10597322601824999, 0.06540097096668822, 0.029696858621069362, 0.03906099810930235, 0.0481533537884908, 0.08413186908832618, 0.04410535975226334, 0.027098559741196886, 0.07664984664214508, 0.0707561457529664, 0.034541741146573, 0.023919404351285527, 0.030385795581553663, 0.03181838317375098, 0.04371760073783142, 0.034798159530120235, 0.035941619958196364, 0.07901680070374693, 0.01699958718381822, 0.0358119790575334, 0.009722210051092719, 0.060376724494355063, 0.02400946630431073, 0.07608375844678708, 0.013311176843542074, 0.0478296484798193, 0.009046782722829707, 0.025272703430216228, 0.05926167432750974, 0.04517732633809958, 0.04726452719686287, 0.037470691837370396, 0.09681249436523233, 0.01685412963187056, 0.039525940482105525, 0.019690867413633635, 0.04826574293630464, 0.027280373199443732, 0.029388932644256523, 0.013334412427086915, 0.046768697910010815, 0.020132795574941804, 0.15660386026969977, 0.05475946216444884, 0.041356556716242006, 0.0921484414221985, 0.5336772916572434, 15.91314308983939, 47.100566727774485, 45.503710883004324, 40.264126437050955, 34.47871582848685, 28.00438438143049, 19.776676756995066, 24.036865711212158, 34.553721632276265, 34.60481868471418, 19.23022873061044, 8.324452604566302, 1.585994073322841, 0.024201374667297517, 0.07764960692397185, 0.32889045615281376, 1.0300768464803696, 1.6384759885924203, 4.018464599336896, 7.548772215843201, 6.334298321178981, 4.761875816753932, 2.9336382278374264, 5.263952646936689, 2.4247697506632124, 7.80027529171535, 5.07445399250303, 3.0595688990184238, 4.620907723903656, 0.9034637862018177, 0.7576118697013173, 0.45238095255834715, 0.4731685242482594, 0.8888711578079632, 1.144793450832367, 0.17683093489280768, 0.2983309216797352, 0.133159606850573, 0.17196866151477608, 0.9353027663060597, 1.5748212614229746, 0.08473537170461246, 0.271435802004167, 0.15172391783978256, 0.06779630136276994, 0.07757859144892011, 0.10909737087786198, 0.08855360360550028, 0.06963713972696237, 0.14554202955748352, 0.8547563169683728, 2.3662285719599043, 2.946763809238161, 2.7688658237457275, 1.8100327657801765, 4.563308026109423, 5.375393935612269, 1.8197201831000192, 3.845268590109689, 3.0280965992382596, 1.221596123916762, 4.257288081305368, 0.4159399579678263, 0.2842189132102898, 0.9872861483267376, 7.461898020335606, 20.531833035605295, 41.21481023515974, 56.287815366472515, 26.023783002580913, 20.8439131123679, 25.48042345046997, 34.26949862071446, 40.30890757696969, 36.357022353581016, 13.858115213257925, 0.8386683602418218, 0.23601361417344638, 0.03451106797105499, 0.09799990350646631, 0.01985637058636972, 0.00912590414684798, 0.024794775593493665, 0.0324356193388147, 0.029738344252109528, 0.022308407850297432, 0.04810650094545313, 0.03192372573539615, 0.04979175462254456, 0.07849926847432341, 0.04107400794912662, 0.0032172776076809634, 0.03837747585826686, 0.013495150587654539, 0.1092163927054831, 0.061143611557781696, 0.02200222061946988, 0.07753042903329645, 0.009833775627027665, 0.05313855057050075, 0.028947023142661368, 0.06073418352752924, 0.04771893870617662, 0.012592173148212689, 0.018910073774999807, 0.07175841661436216, 0.037122186073767285, 0.021534611604043415, 0.05486456384616239, 0.02289659932388791, 0.05615858440952642, 0.06318699262504067, 0.05558882873239262, 0.04714379546099475, 0.027722479476194297, 0.024082454619929194, 0.0447960269770452, 0.029278443394494907, 0.055351684136050086, 0.08030157283480678, 0.1612555706607444, 0.020916179521009326, 0.028476435358503034, 0.014505838675956641, 0.03251887897827795, 0.04428271523543766, 0.023184732434206774, 0.04154760842876775, 0.16168521903455257, 0.022611509443127682, 0.04571446483688695, 0.015433569072878786, 0.008203527391222971, 0.053520789702555964, 0.012697878726092833, 0.0717066918898906, 0.006433534868327635, 0.05909429330910955, 0.023927224467375448, 0.09113281699163572, 0.015808720906664218, 0.022632287881736244, 0.026158403671745743, 0.027473910046475272, 0.029037081703011478, 0.020718444238549898, 0.030618550056325536, 0.05638637200796178, 0.025435215959857618, 0.056212086895746846, 0.07223453785159759, 0.021592836693993638, 0.08698015553610665, 0.01908669644035399, 0.01764881457867367, 0.02936212033299463, 0.029442648869007826, 0.017843845899083784, 0.05378708755597472, 0.05713097258870091, 0.01720567692869476, 0.04091247929526227, 0.037535793879734616, 0.029922274739614556, 0.045160617413265366, 0.02590878420908536, 0.06143113398658378, 0.10845882871321269, 0.10091844547007765, 0.06200607706393514, 0.06140387723488467, 0.04469890486715095, 0.061969286895224025, 0.02336361801384815, 0.07447844637291771, 2.4950475224426816, 28.291256393705094, 57.844065938677105, 47.46103927067348, 38.193201950618196, 19.187400034495763, 17.410898515156337, 29.83804178237915, 43.34105975287301, 48.223135062626426, 40.371375356401714, 17.512562819889613, 5.3864845633506775, 0.41681868795837673, 0.04113087257636445, 0.04341485537588596, 0.1137066592595407, 1.0187275069100517, 0.19471757938819273, 0.7933687652860368, 2.924468342747007, 2.27888645870345, 2.9977414395127977, 2.789694134678159, 2.0799221864768436, 2.908859431743622, 4.2077074732099256, 2.1475073141711096, 4.405248233250209, 6.419183594839914, 4.167025770459857, 2.242652254445212, 0.8576795543943132, 2.138533715690885, 2.290231998477663, 2.8819727259022847, 0.5438518428376743, 0.6128504403999874, 0.7005430577056748, 1.0941731099571501, 2.38421094417572, 1.9434743310723985, 1.3616179589714323, 0.809553291116442, 0.550236097403935, 0.15823281928896904, 0.71296312553542, 0.1794716031955821, 0.6716598847082683, 0.13312634506395885, 0.7850932436329978, 2.6424505157130103, 0.7912798545190266, 2.5609005945069447, 0.8415654333574432, 2.4816987301622118, 2.1470328824860707, 2.1414287260600497, 0.02720916603824922, 0.8782999621970313, 0.26950034871697426, 0.5712884877409253, 1.2762568422726221, 0.5333733622516904, 0.17368260025978088, 0.31371792459062164, 3.430673271417618, 17.01491025515965, 36.50976460320609, 61.44776998247419, 44.45686054229736, 22.586351088115148, 19.118103912898473, 30.047783579145158, 41.593744141714915, 43.88120228903634, 21.58718797138759, 2.455941757985524, 0.18011121744556086, 0.014408363727852702, 0.00853629453506853, 0.047606722584792545, 0.047690572549722025, 0.07684714426951748, 0.01668439748963075, 0.11801697154130254, 0.05875475438577788, 0.031222527647124868, 0.05245368821280343, 0.0519195929435747, 0.022784155893272588, 0.01919499402200537, 0.019686404349548475, 0.05808516924402543, 0.03054404691127794, 0.06931661335485322, 0.06817548030189105, 0.040059218116636784, 0.09008458216807672, 0.028803604588444744, 0.0627417243751032, 0.05626928400514381, 0.07546517199703626, 0.017097822091143047, 0.010311249693456506, 0.05178948724642396, 0.08875450425382171, 0.052460429458213706, 0.054477120350514135, 0.06549205750759159, 0.030687950618032898, 0.05575753967942936, 0.10455566458404064, 0.03707268355148179, 0.017501616584403173, 0.017895684278170978, 0.0474623608669, 0.07984658117805209, 0.051168702343212705, 0.027704157334353243, 0.1622389443218708, 0.2098014671355486, 0.14002734475902148, 0.09006660777543272, 0.13367717979209764, 0.0981041875534824, 0.1308159197547606, 0.13729651272296906, 0.11112549847790174, 0.3127750594701086, 0.170592443219253, 0.09300473904503243, 0.12362304143607616, 0.08638059520827872, 0.16706924512982368, 0.12227479235402175, 0.214384401217103, 0.058410601424319405, 0.20225024090281554, 0.1640206551445382, 0.1585428419389895, 0.0715745607657092, 0.11343005445918866, 0.08304027587707553, 0.10332072406475033, 0.16260885447263718, 0.17394397194896424, 0.2579159646161965, 0.1639447949294533, 0.10642654847885881, 0.12298460783702986, 0.14098684755819185, 0.11012383151267256, 0.15489201141255243, 0.09437181068850414, 0.13602245465985366, 0.16068424417504243, 0.13214069152516977, 0.07089014284844909, 0.1626990046352148, 0.17607472118522438, 0.17167675574975355, 0.15228832326829433, 0.1339328789285251, 0.16986046678253583, 0.2016009371727705, 0.22066557274333068, 0.13525435301874364, 0.19439405389130116, 0.18297881499997207, 0.16698989724474295, 0.15067745399262222, 0.20579152873584203, 0.11908927400197301, 0.15590680124504225, 0.19883756259722368, 1.2766862192324229, 25.926317146846227, 67.04910196576799, 62.49669088636126, 52.910452365875244, 45.59585789271763, 37.40676661900112, 27.317567110061646, 32.34994758878435, 43.33887801851545, 44.24752174104963, 24.470205749784196, 10.534476552690778, 2.1141366362571716, 0.21625638433865138, 0.49275131630046026, 0.766247340611049, 3.5107938178947995, 5.279686842645917, 10.374545523098536, 20.7256304536547, 16.570215123040335, 15.766973836081368, 10.63515681879861, 13.774124520165579, 8.45908350603921, 17.830137184688024, 14.429938060896736, 11.268006563186646, 6.755796892302377, 5.650315480572837, 4.374983182975224, 2.0611509765897478, 3.321545732872827, 3.5720074474811554, 2.6248159876891544, 0.8221151999064854, 0.7811973126871246, 0.5216121790664536, 0.8807275976453508, 2.6481169887951443, 3.8877073185784474, 0.43707920078720364, 0.5404554765139307, 0.3699890508183411, 0.4146701746753284, 0.46118054751838955, 0.2029089219868183, 0.4199939604316439, 0.6422862665993827, 0.7102475741079876, 3.5152699777058194, 5.126165091991425, 12.471860136304583, 9.667656643050057, 10.824777500970022, 14.47860758645194, 16.722059317997523, 9.217561892100743, 10.664398312568665, 11.320037279810224, 5.044700937611716, 7.704163466181074, 1.8509264971528734, 0.5095079828585897, 1.5043900864464896, 9.113976410457067, 25.610462461199077, 47.87440497534615, 64.85413128989083, 34.68831171308245, 28.871095725468226, 35.780752658843994, 46.332530226026265, 51.14293139321463, 53.22003630229405, 23.063049622944423, 1.822547665664128, 0.2690626393471445, 0.16588851277317318, 0.11345846472041947, 0.16868153932903493, 0.09550793615302869, 0.12426701188087463, 0.1415651493838855, 0.20036356071276323, 0.09626964599426303, 0.18999205795781954, 0.19841759013278143, 0.14622327871620655, 0.15299146196671895, 0.14075676990406855, 0.10205788897084338, 0.1545065220977579, 0.11129884381911584, 0.17831970857722418, 0.2170906974268811, 0.11333321394132716, 0.2030263899692467, 0.14596002069967134, 0.17135095037519932, 0.11555604716496808, 0.16320216549294336, 0.12240155626620565, 0.16499185588743004, 0.12529740801879338, 0.1575225016900471, 0.20712527073919773, 0.19912520716232912, 0.1639057927365814, 0.11076169514230319, 0.2038552612066269, 0.11392296265278544, 0.12664010668439524, 0.10532357623534543, 0.09720786314989839, 0.19277745778007166, 0.1105607266404799, 0.08129156221236501, 0.1920600969876562, 0.31043294657553944, 0.27571092545986176, 0.24371409096888133], [0.027728604951075146, 0.00374347684971456, 0.017209091656176106, 0.027781654515170624, 0.0042179925034620935, 0.032801872185830555, 0.056948304176330566, 0.010793163923413625, 0.022111561448712434, 0.06062498688697815, 0.017176279399011816, 0.04873111617884465, 0.07607409610812153, 0.036172179372182915, 0.02179697904336665, 0.05086428778512137, 0.029349207811589752, 0.01806316877316151, 0.09378751061324563, 0.012097373538251435, 0.03464568592607975, 0.03585084215072649, 0.028599921946546862, 0.03394875582307577, 0.060199402937931676, 0.04603194458676236, 0.048320436251482794, 0.02560900743784649, 0.04314557196838515, 0.07487473796520915, 0.022164012205653956, 0.07729392565254654, 0.08180642779916525, 0.07066662662795611, 0.030869475698896816, 0.048261994030326605, 0.029455917621297494, 0.021266571611964276, 0.059198061669511456, 0.021959371133042232, 0.07452100408928734, 0.06104809418320656, 0.03600379412195512, 0.10081042948045901, 0.1004322547731655, 0.0380300014678921, 0.06677649037114211, 0.02497895204994295, 0.03670956892892718, 0.006397772256085383, 0.01619375390665872, 0.0159651130504374, 0.019029166848797883, 0.06316631087767226, 0.15108890405723027, 5.731780503477369, 33.07419654301235, 47.61444854736328, 42.84474992752075, 33.607922417776926, 30.24918406350272, 24.265708105904714, 25.839699166161672, 21.106061697006226, 30.986558164869034, 30.61323492867606, 28.347562858036586, 18.094290324619838, 7.9524330241339545, 3.563988140651158, 0.895187993134771, 0.07989424147776195, 0.2621234788426331, 1.9118272406714303, 0.8630140338625226, 1.2995944299868174, 2.1938007729394093, 0.5830648701105798, 1.5043428604091917, 3.481745570898056, 2.327191855226244, 2.316463836601802, 8.774043611117772, 4.94880884885788, 2.160452025277274, 0.4963132994515555, 1.8453831374645233, 1.6906475148030689, 3.1799876945359364, 0.6773660385182926, 1.0604394972324371, 1.3195604043347495, 1.8598230140549796, 2.5014253173555647, 0.8994376308151654, 3.9066398569515774, 1.3857429730040687, 0.5976007729768753, 0.2414313091763428, 0.740323394536972, 1.8572519634451186, 0.877904837684972, 0.2997118761496884, 1.5453984630959374, 2.4102855793067386, 0.9562877374035972, 0.7940648336495671, 0.5554129938994135, 1.2223710651908601, 0.577012229178633, 0.87443757802248, 1.012331255844661, 0.33731438698513166, 0.018110142056164995, 0.05952050829572337, 2.291970568043845, 6.195031668458666, 18.986994879586355, 27.286268949508667, 41.891130515507285, 27.87933244024004, 54.47265407017299, 25.46003917285374, 27.023873703820364, 38.98420572280884, 35.26766640799386, 43.04973220825195, 26.66616828101022, 3.681793979236058, 0.12219270318746567, 0.039258645182209354, 0.006123770061614258, 0.03417045696239386, 0.03524269496223756, 0.1251656636595726, 0.035003399409885914, 0.03373933616759522, 0.03239152134795274, 0.03906014994052904, 0.018550017649041753, 0.03521939067702208, 0.05260296252423099, 0.04424460870879037, 0.06355266193194048, 0.08055503280567271, 0.013849206767710192, 0.03883241323222007, 0.06704012158193759, 0.0830149936622807, 0.073427056361522, 0.028442617173173597, 0.03147359238937497, 0.0328492916056088, 0.03395959881267377, 0.03346975759736129, 0.03584659791418484, 0.06815407252205269, 0.09443920957190649, 0.031772510813815255, 0.10015077809137957, 0.033950635365077426, 0.11648975206272942, 0.08457573277077504, 0.026012011437809894, 0.07568978065890924, 0.045130809369896135, 0.044109264721295664, 0.027417394864772047, 0.03124520768012319, 0.02787011512555182, 0.09759019727685622, 0.012913015887274273, 0.02601972807730947, 0.06142669636756182, 0.032496528034763675, 0.029347803244101148, 0.032304533158562014, 0.015561466138543827, 0.030572219685252224, 0.04014610791844981, 0.05261875881946512, 0.01703951388065304, 0.02935610172737922, 0.031927803730858226, 0.06900197666670595, 0.06729069099362407, 0.04157594405114651, 0.03240566201774137, 0.11408646245087896, 0.019805787497067025, 0.06983639832053866, 0.04998985970658915, 0.1161113330828292, 0.0232187321276537, 0.005139570284102644, 0.03068857147757496, 0.046601788473448584, 0.07925980444997549, 0.014399410458281636, 0.007173248300594943, 0.0676566588559321, 0.02391193198439266, 0.06940612569451332, 0.03801905330536621, 0.024300681659951806, 0.026912357857716934, 0.028688229886548858, 0.019816135156101415, 0.08868632505514792, 0.04709661013579794, 0.048804082442075014, 0.025391966137768965, 0.057377341868621964, 0.015954907883756926, 0.024184295940878134, 0.04223271845174687, 0.043431883212178946, 0.02966101500870926, 0.017707489198073745, 0.03325395292735525, 0.02576810184733144, 0.04893827631271311, 0.062116026878356934, 0.028366731513025503, 0.021459518133529594, 0.02171498317537563, 0.030402874307973043, 0.040085765799241405, 0.051128183624574115, 0.05113753383713109, 0.44963790689195904, 13.747275812285286, 47.2083853994097, 52.64078235626221, 43.648917061941965, 32.035215037209646, 17.075154611042567, 13.424038665635244, 22.759686061314174, 36.38479430334908, 47.56748219898769, 44.230922494615825, 35.68131351470947, 15.178534371512276, 5.127505660057068, 1.296403904046331, 0.1519745143928698, 0.057141510237540515, 0.0966384569182992, 0.6708162756902831, 0.28866614028811455, 0.5792880356311798, 0.8045911916664669, 0.9156096173184258, 0.3891772340450968, 1.8292494203363145, 1.6812171808310916, 0.6901040407163757, 2.2131929780755724, 2.2819291182926724, 1.2499781038079942, 0.8292012768132346, 1.1252631502492088, 1.2005440592765808, 2.512410853590284, 1.3936577311583926, 1.2588428109884262, 2.19878197993551, 2.9881952660424367, 2.2027852279799323, 1.0040235987731387, 2.236375859805516, 2.5883105865546634, 1.767137627516474, 0.7922115102410316, 1.0658002495765686, 1.5857732508863722, 2.197009972163609, 1.0462742916175296, 1.9628133390630995, 1.6722597586257117, 0.6985244431665966, 0.7606220138924462, 1.0297085919550486, 1.4073976853064127, 1.128882727452687, 0.253839516213962, 0.11645900085568428, 0.4333717668695109, 0.027708116586187055, 0.08739790240568773, 1.2129053388323103, 2.894255403961454, 10.109324097633362, 24.412464482443674, 56.26013026918684, 51.75604043688093, 65.39343656812395, 41.28726257596697, 19.680209704807826, 26.509250164031982, 35.82797956466675, 46.799483912331716, 34.56656190327236, 9.426556757518224, 0.2747292752776827, 0.026969941732074534, 0.02364915233504559, 0.02432901897866811, 0.02827894943766296, 0.07774038133876664, 0.020005751767062714, 0.008503841053295349, 0.010357628410149897, 0.05610547208094171, 0.019987086965037242, 0.03274461400828191, 0.010438515721554202, 0.0773456571623683, 0.03895402706361242, 0.09721373926315989, 0.018243418208190372, 0.04623475191848619, 0.03715121719454016, 0.03936050685920885, 0.05360068380832672, 0.019906955372009958, 0.011533560131543448, 0.047645297300602706, 0.04691400279157928, 0.0684419817158154, 0.04546574104045119, 0.03666277715404119, 0.031898185677294216, 0.03761162356074367, 0.0793722037758146, 0.03123524339337434, 0.06051755443747554, 0.09171121381223202, 0.04893631534650922, 0.02110050355882517, 0.035138095396437814, 0.02342124260030687, 0.04138704329462988, 0.00942665122316352, 0.04020655181791101, 0.029168361265744482, 0.0476485135565911, 0.04477257341412561, 0.021882864613352076, 0.06534282730094024, 0.02396127674728632, 0.1139783039689064, 0.12131581881216594, 0.12963421030768327, 0.15804745709257467, 0.13878466215516838, 0.1550631650856563, 0.09930220219705786, 0.08718358033469745, 0.12106305094701902, 0.20836764121694223, 0.08697208096938473, 0.1944273156779153, 0.25647084787487984, 0.14233675226569176, 0.11654457769223622, 0.16002982429095677, 0.14480113717062132, 0.13896370040518896, 0.19520243337111814, 0.08617095502891711, 0.10665167961269617, 0.13585663427199635, 0.13112109766474792, 0.10772398207336664, 0.15181611717811652, 0.06819232154105391, 0.1835073394966977, 0.13481687435082026, 0.13221154415181705, 0.19491846646581376, 0.12398711618568216, 0.197537950905306, 0.23855399500046456, 0.14548462549490587, 0.10630629171750375, 0.12027415899293763, 0.13787245324679784, 0.14570091531745025, 0.2043974378279277, 0.09446554351598024, 0.17620058943118366, 0.1857313465859209, 0.12851622886955738, 0.21004493907094002, 0.12650376185774803, 0.11494976255510535, 0.2764266441975321, 0.0736405166930386, 0.08110696676054172, 0.10239694613431181, 0.08864631184509822, 0.19234812153237207, 0.151996607493077, 0.13681757556540625, 0.32994487243039267, 10.375319378716604, 48.50770895821707, 68.18044240134103, 58.36131763458252, 47.42474882943289, 42.53923416137695, 34.83012792042324, 36.42916897365025, 29.622185570853098, 41.79337978363037, 42.23804364885603, 41.38824422018868, 24.938771418162755, 11.942381347928729, 4.8112510187285285, 1.3094809566225325, 0.1941629448639495, 1.1047913687569755, 3.593933790922165, 1.8656082579067774, 3.2970674463680814, 7.061934956482478, 4.6254466346332, 10.217548370361328, 13.511639816420418, 8.98703282220023, 9.834387353488378, 21.129310369491577, 9.732272284371511, 7.736067857061114, 1.979609523500715, 4.256195911339351, 4.4582182594708035, 7.425299252782549, 3.0064725024359564, 2.621611565351486, 5.3405009508132935, 5.309968829154968, 4.895931754793439, 3.665228171007974, 8.934501835278102, 4.680703052452632, 3.8469196557998657, 1.4924427675349372, 2.052171949829374, 3.2791176438331604, 4.939952501228877, 2.0682001411914825, 7.336337123598371, 13.075534394809178, 7.637637938771929, 6.469363485063825, 6.223641310419355, 7.502801196915763, 5.109482032912118, 3.4015440344810486, 2.07325365287917, 1.218611872621945, 0.2452881293637412, 0.3443716125828879, 3.537102520465851, 8.570816619055611, 23.370668956211635, 35.505249636513845, 52.17994655881609, 36.303100858415874, 60.59989520481655, 33.697745255061555, 39.36605787277222, 49.46552855627877, 47.639944962092805, 58.91526276724679, 38.343307358878, 8.05169151510511, 0.2834135192845549, 0.1100954958902938, 0.08160955086350441, 0.16605298966169357, 0.10565433491553579, 0.24109866416880063, 0.10795253980904818, 0.14317269383796624, 0.0975563180233751, 0.16331158605005058, 0.12818464237664426, 0.09976339566388301, 0.10147959393049989, 0.1156542311821665, 0.14884025257612976, 0.18796298040875367, 0.16381842456758022, 0.12989556842616626, 0.1405678250427757, 0.10663437696972064, 0.12647477484175138, 0.09678567187594515, 0.1401968156652791, 0.13101794677121298, 0.15357806906104088, 0.17710190106715473, 0.1424449243183647, 0.17623018712869712, 0.1723974006516593, 0.11853758431971073, 0.25256425035851343, 0.14252970048359462, 0.20126751863530704, 0.15333991684019566, 0.2342035812991006, 0.18188849064920629, 0.09186480699905328, 0.1682744997420481, 0.12904197137270654, 0.1125413907159652, 0.13890392147004604, 0.18795170315674373, 0.19173126534691878, 0.12200645889554705, 0.1027954633214644, 0.14871563283460482, 0.09109444583633117], [0.07299785582082612, 0.021953978475981524, 0.04251662428889956, 0.07854229437985591, 0.05183552924011435, 0.015236602231327976, 0.04992890690586396, 0.006908658659085631, 0.03094859966742141, 0.022331111632021408, 0.05294403154402971, 0.037660403443234305, 0.026067900670958415, 0.031092279457620213, 0.03616805048659444, 0.025034966812069927, 0.01629978687768536, 0.017956170586070845, 0.05946579123181956, 0.04141205070274217, 0.1595558947218316, 0.07266590970435313, 0.032867092971823046, 0.02121600548603705, 0.016036008085523332, 0.013099298346787691, 0.017886074525969367, 0.04125914962163993, 0.06636109801807574, 0.025396230730361173, 0.0638066308040704, 0.03005520992779306, 0.052181700843253305, 0.06428455694445542, 0.030908410038266863, 0.03441543863820178, 0.05178982651393328, 0.02444585761986673, 0.019308965852750198, 0.004351175356922405, 0.052633605165673156, 0.018951947867338146, 0.0218554416205734, 0.020162413628505807, 0.03294752651293363, 0.039308239306722365, 0.02859856826918466, 0.018462695281154344, 0.03504969924688339, 0.016318005542936068, 0.035256404762289355, 0.013386775822644787, 0.026363635069823692, 0.07108013943902083, 0.03471392619290522, 0.05189149820112756, 0.7198549242956298, 15.314597470419747, 39.020989486149375, 52.93499687739781, 44.1564621244158, 35.73704848970686, 32.41760567256382, 32.08166721888951, 23.661001171384537, 15.02913420540946, 19.86240710530962, 29.87327609743391, 40.54774842943464, 33.44144357953753, 28.366210086005076, 22.48904504094805, 14.692973409380231, 8.583510109356471, 4.347708463668823, 2.182976565190724, 0.6280295944639614, 0.24623113019125803, 0.1661924828908273, 0.33693793575678554, 0.1574302887810128, 1.9698670634201594, 2.6547664148466925, 2.3196799840245927, 1.502911422933851, 0.565426270876612, 0.6170779306973729, 0.6031579747796059, 1.3131228983402252, 0.28479501658252304, 0.2967592988695417, 0.9106332414916584, 2.9380644474710738, 2.7814594336918423, 0.722094252705574, 5.15665682724544, 2.9127899408340454, 2.1073564972196306, 1.2805944723742348, 0.911667274577277, 0.9006410262414387, 1.9965127536228724, 0.8010755660278457, 1.2255121937819888, 1.766644305416516, 0.5876986671771322, 0.575589042689119, 0.06360226284180369, 0.18138290063611098, 0.28953566934381214, 1.8263259657791682, 4.893668379102435, 8.117797545024327, 19.668826818466187, 28.43587272507804, 32.4047862461635, 35.69790581294468, 70.82361357552665, 56.864866733551025, 20.746056420462473, 27.98497632571629, 35.72458689553397, 30.472426210130962, 36.43246936798096, 44.93204436983381, 38.17288541793823, 14.920021431786672, 0.8907645419239998, 0.17887852287718228, 0.08809987402388028, 0.021002514620444605, 0.02737700337144945, 0.04200359074664967, 0.04998827532732061, 0.04516260212819491, 0.05376317937459264, 0.05741750435637576, 0.02281139568159623, 0.041508066800556014, 0.032927387593580146, 0.08348847539829356, 0.06082718353718519, 0.03704350654567991, 0.0238543531990477, 0.050077136273362806, 0.046736562491527626, 0.044398215466312, 0.005744941840280912, 0.07372212409973145, 0.03246376497138824, 0.011858492740429938, 0.04022559490320938, 0.013220672994585974, 0.051256983141813955, 0.05229698394292167, 0.033915422790284665, 0.05396281455510429, 0.06062295806727239, 0.024230042771835412, 0.05798978079110384, 0.020435707177966833, 0.04682383566562619, 0.01513990420582039, 0.03886454186535307, 0.05990343274814742, 0.03225603486810412, 0.04335313243791461, 0.05413635327879872, 0.034545683435031345, 0.09251781553030014, 0.04267915378191641, 0.07911752922726528, 0.040324627089181116, 0.01788149611093104, 0.017787105104486858, 0.03909307245963386, 0.027794836754245416, 0.036429069337568114, 0.05533539929560252, 0.027382131399852887, 0.08576364402792283, 0.002906426720853363, 0.04987792856991291, 0.04327494824039085, 0.057245712860354354, 0.02708863277387406, 0.020489584554785063, 0.04480388441256114, 0.01705129664125187, 0.03117666207253933, 0.018084484950772355, 0.03480494148763163, 0.023354710545390844, 0.030728611829025403, 0.0404695214570633, 0.0752778420490878, 0.04502478827323232, 0.027598126059664146, 0.018816413890038217, 0.06855948362499475, 0.05171097735209124, 0.03219025429072125, 0.07349635514297656, 0.03191983772973929, 0.04729099006259015, 0.03495662799105048, 0.08576739632657596, 0.03196105873212218, 0.04053062353549259, 0.031972458120435476, 0.036025079765490124, 0.0064599756816668165, 0.037515661745731316, 0.031145286613277028, 0.03840978430317981, 0.01855075216319944, 0.01962287481208997, 0.01799382927960583, 0.035188642862652025, 0.04402106873957174, 0.048735299347234626, 0.028309473335476856, 0.04940770040931446, 0.016163608292117715, 0.05908993711428983, 0.0421841557004622, 0.029573107404368262, 0.06299785098859242, 0.03158373897895217, 0.04294367048091122, 0.017012404710320488, 0.06817662024072238, 3.1984247394970486, 28.89646359852382, 51.729939528873985, 52.72666903904506, 42.335412229810444, 27.119708469935826, 25.11884788104466, 20.102557693208965, 21.226920400347026, 23.71829080581665, 33.79215737751552, 48.05052096503121, 52.5929023197719, 40.75849076679775, 28.467327220099314, 18.17923378944397, 8.512668013572693, 3.162296712398529, 1.5874263793230057, 0.6349636795265334, 0.38076690105455263, 0.20484786294400692, 0.231903076171875, 0.35435834527015686, 0.2593248204461166, 0.24159494468144008, 0.9303183023418699, 0.7453307658433914, 0.9828452723366874, 0.657350015427385, 0.2619594633579254, 0.44442130252718925, 0.781267663197858, 0.34490836092403954, 0.9796359645468848, 0.5944567673972675, 0.5351376618657793, 0.24101949270282472, 0.7750072819846017, 1.4937808385917117, 0.6613841503858566, 0.7842812814882824, 0.7476427246417318, 0.8287158800022942, 0.43863440304994583, 1.4443668786968504, 0.743288972548076, 0.7852110915950367, 0.48402019909449984, 0.2751770541071892, 0.4855617220912661, 0.06396391522139311, 0.22973502108028956, 0.4118734976010663, 0.8422130271792412, 2.0752341066087996, 6.360421810831342, 10.378820402281624, 24.19094548906599, 35.68947764805385, 48.28927843911307, 67.36766992296491, 58.11528539657593, 31.678803716387065, 24.737440415791102, 38.615881715502056, 24.3503805909838, 31.982092584882462, 49.35588598251343, 45.92718274252755, 24.82310996736799, 1.945474760872977, 0.20264307196651185, 0.10453372076153755, 0.014925675433395165, 0.08894747282777514, 0.04486647926803146, 0.041426259226032665, 0.004841682808806321, 0.03268154417829854, 0.025700847152620554, 0.04031960932271821, 0.05035979699875627, 0.027932825331975306, 0.06517640301691634, 0.029926566473607506, 0.045467623975127935, 0.030765290039458444, 0.007342733625721718, 0.00729371455963701, 0.03625584613265736, 0.025392468253682767, 0.061200683138200214, 0.028491987381130457, 0.0616907754114696, 0.0342700930445322, 0.04975057772493788, 0.07650299130805902, 0.04314216911526663, 0.0763521869001644, 0.0554712114722601, 0.01163973135408014, 0.043760331480630806, 0.03598737357450383, 0.05705461025770221, 0.005038705205411783, 0.04754196659528783, 0.029488283741687025, 0.0559177655460579, 0.044298694735126834, 0.024426646597151245, 0.026980679548744644, 0.008286917648677315, 0.050006738265178034, 0.02326749843944396, 0.05830255150794983, 0.049604485742747784, 0.035034567915967534, 0.04456796796460237, 0.033088868749993186, 0.11059650579201323, 0.10765539575368166, 0.1263116957353694, 0.19025942789656775, 0.18211427996201174, 0.1545988300016948, 0.15271894873252936, 0.11255732950355325, 0.2022575826517173, 0.09802353688116584, 0.12967789439218386, 0.08063145620482308, 0.07390120306185313, 0.10798957425036601, 0.14687136108321802, 0.10955362460975136, 0.13726644005094255, 0.09825796394475869, 0.11736834634627615, 0.11932216079107352, 0.19782077787177904, 0.18066465774817125, 0.11509275702493531, 0.17246225502874168, 0.1085578744698848, 0.08219131321779319, 0.13186052441596985, 0.13092135052595819, 0.2522373321865286, 0.08452513441443443, 0.1350851942385946, 0.18321885354816914, 0.10635665258658783, 0.15975511260330677, 0.14441294728645257, 0.1457152459770441, 0.12260044845087187, 0.12378530630043574, 0.1471315656921693, 0.11079149640032224, 0.16397403978875705, 0.060464934046779356, 0.07323275785893202, 0.10520875453948975, 0.21351331153086253, 0.1216223266507898, 0.15217384083994798, 0.0996372424332159, 0.1483873983046838, 0.10791986156255007, 0.20328055561653205, 0.16388687518026146, 0.09674402339650051, 0.1283432702933039, 0.10020018901143755, 0.21081133080380304, 1.6802632148776735, 26.241039276123047, 60.67291382380894, 69.24042483738491, 56.55577611923218, 47.33364404950823, 44.472862243652344, 44.95755468096052, 33.40689713614327, 22.902233566556657, 28.506801673344203, 40.99339893886021, 50.499340602329795, 43.989152976444785, 37.03594820840018, 29.521669455936976, 19.74968647956848, 12.404638920511518, 5.629316287381308, 3.2175463991505757, 1.343944673027311, 0.3920377476939133, 0.6807450886283601, 0.619288326374122, 1.8310444440160478, 4.363189050129481, 5.432697032179151, 6.389026241643088, 5.821278946740287, 5.653104748044695, 5.769086684499468, 4.151768394878932, 8.904379657336644, 4.440826918397631, 6.581447047846658, 5.7369682022503445, 9.9576701096126, 11.401998230389186, 6.465503760746547, 17.55818816593715, 13.320982115609304, 8.852981226784841, 4.614654779434204, 6.063914818423135, 2.9017668409006934, 5.749337298529489, 4.126401390348162, 2.9108791862215315, 3.77211708681924, 1.4996933213302066, 1.5786683921303069, 0.10053061520946877, 0.3197139485606125, 0.6020091878516334, 2.5640626762594496, 6.361161359718867, 11.28735555921282, 24.26488127027239, 36.434258529118125, 42.77279438291277, 46.86206981113979, 78.39205006190709, 65.4593402317592, 26.36753817967006, 35.90491001946585, 45.141563824244905, 41.844904150281636, 47.692786012377056, 59.39659227643694, 55.35421371459961, 23.137949466705322, 1.2779441688741957, 0.36167992811117855, 0.22156813288373606, 0.12131294182368688, 0.18967176228761673, 0.1578391875539507, 0.20081547860588345, 0.1766515573752778, 0.13046689491186822, 0.1418966951646975, 0.1390342273350273, 0.10305299450244222, 0.12530751819057123, 0.1482854959155832, 0.12261994954730783, 0.13731487388057367, 0.1740983250950064, 0.14918682112225465, 0.10861343291721173, 0.09030713486884322, 0.16080450772174767, 0.22012320613222464, 0.10887715233755962, 0.14253957995346614, 0.15776891846741947, 0.16457367475543702, 0.1717729584446975, 0.15541575902274676, 0.1659589447081089, 0.1546300019004515, 0.1428737584501505, 0.1521054987928697, 0.18403465620109014, 0.09887194992708308, 0.14126533190054552, 0.2646310457161495, 0.1310116635369403, 0.23186971939035825, 0.10777669067361526, 0.1334572665925537, 0.22220396090831074, 0.12423356010445527, 0.1591024026274681, 0.16702649742364883, 0.15456631460360118, 0.09398915765008756, 0.12583673479301588, 0.08386054329041924, 0.19783993970070565], [0.11677456035145692, 0.0033019916445482522, 0.034868052029716115, 0.01603791137625064, 0.035712329404694695, 0.0255780034765069, 0.029258653920676028, 0.05393930331670812, 0.02987802747104849, 0.02895909088796803, 0.027523052945200886, 0.0063689765021471036, 0.045014335441270044, 0.03513842109324677, 0.02082008708800588, 0.010408211499452591, 0.017153104035449878, 0.08098723247115101, 0.041057363485119173, 0.028665068093687296, 0.02905182626896671, 0.032480568891125064, 0.031013603322207928, 0.010930804751946457, 0.07417158569608416, 0.011178465792909265, 0.025093424300264035, 0.04111406187127743, 0.01731478875236852, 0.010680510995111294, 0.01575548983445125, 0.0369396906878267, 0.07835764464523111, 0.08155986852943897, 0.02796909981407225, 0.015699184998603802, 0.06924622891736881, 0.07626064574079854, 0.08538468900535788, 0.1017998353179012, 0.02052059190879975, 0.03649603056588343, 0.007098630228678563, 0.03712685439469559, 0.034659633213388066, 0.06575821286865643, 0.013182289116749806, 0.02581472907747541, 0.027177817720387663, 0.08560910767742566, 0.07046534600002424, 0.01163556260455932, 0.04657549863415105, 0.024664429016411304, 0.02054241529133703, 0.03313701080956629, 0.023662626344178404, 0.04035558524940695, 3.217912048101425, 24.032448393957957, 48.20229741505214, 49.210421970912385, 49.839894022260395, 45.84072978155953, 38.437045506068635, 27.620555468967982, 20.79041198321751, 15.943967035838536, 21.96362226349967, 35.112214360918315, 27.619113717760357, 31.159578732081822, 35.18481608799526, 39.062213148389546, 37.1559088570731, 35.12293543134417, 29.78908130100795, 27.8338234765189, 20.853331395557948, 15.661208357129778, 7.708694560187204, 5.256660512515476, 2.27279115148953, 0.46901936403342653, 0.24670523617948803, 0.0774798985304577, 0.19007352287215845, 0.40836745287690845, 1.2062222574438368, 0.9856775317873273, 1.3676859076533998, 0.28016119237457004, 0.6564779622214181, 0.46046656583036694, 0.30105624401143616, 0.8185223841241428, 0.5559619558709008, 0.6995322033762932, 0.18085295121584619, 0.052819310022251945, 0.04334383650815912, 0.19481956320149557, 0.5500831827521324, 1.8658735922404697, 5.248590614114489, 8.645890167781285, 12.180543882506234, 19.592061383383616, 25.862970420292445, 31.661603450775146, 29.277412482670375, 34.162975788116455, 37.498844146728516, 35.55299765723092, 22.046778304236277, 35.12618024008614, 21.517756359917776, 56.02697651726859, 69.29359245300293, 30.599956921168737, 46.248964241572786, 38.46217714037214, 49.44132450648716, 38.42645297731672, 23.728793007986887, 2.817484323467527, 0.14149990145649227, 0.03576014576745885, 0.031187403281884532, 0.14108226315251418, 0.03267270625968065, 0.03219611344060727, 0.0078719459873225, 0.09829814678856305, 0.05398139623658998, 0.0622147944356714, 0.06294567843100854, 0.026305549079552293, 0.034368728287518024, 0.02851527470297047, 0.01103234666931842, 0.012472684827766247, 0.031436951498367956, 0.04369368237842407, 0.017033688657517945, 0.03941739523517234, 0.059799976513854096, 0.0708989230915904, 0.05391483195126057, 0.042453564636941464, 0.04071609769016504, 0.012397190173422652, 0.0683412260508963, 0.06383847445249557, 0.0045790910288425425, 0.07053733178015266, 0.020663752619709288, 0.046366669304136715, 0.04983964562416077, 0.021111188789031336, 0.018412919648523842, 0.07462989538908005, 0.044782853219658136, 0.025720712961629033, 0.04829195813675012, 0.02383752553058522, 0.03970661400152104, 0.030046070061091865, 0.09008749986865691, 0.025242864852771163, 0.030143697679575, 0.05433977468471442, 0.03947319795510598, 0.06956571713089943, 0.019762832837711488, 0.017859246947669556, 0.054077527685356994, 0.01395128557591566, 0.03487610284771238, 0.04204161924176982, 0.03225763960342322, 0.03205586364492774, 0.027350710139476826, 0.04899468632148845, 0.002383418077702767, 0.0714317291442837, 0.02804791335282581, 0.034083458594977856, 0.0673745647072792, 0.10532882131103959, 0.042772886609392505, 0.008736891538969107, 0.028988834470510483, 0.07399473232882363, 0.05237482887293611, 0.0303486763233585, 0.04437844974121877, 0.02837883827409574, 0.014585977054334112, 0.05863473511167935, 0.03956458644409265, 0.04615393500509007, 0.0545968749959554, 0.04573946885232415, 0.04131732042878866, 0.015790565005902733, 0.039589251192020516, 0.023266154940107038, 0.04054832312145403, 0.030303431608315026, 0.037432286755314896, 0.04479294303538544, 0.012274654382573707, 0.012945166572795382, 0.06290174328855105, 0.04461436279650245, 0.05122098685907466, 0.017236312784786736, 0.09196869071040835, 0.024984090256371667, 0.06063570095492261, 0.02585511887446046, 0.046930983130420954, 0.02046006149612367, 0.06859439425170422, 0.07001479196229152, 0.017432974285579154, 0.02592388670226293, 0.006892335226958883, 0.035980554297566414, 0.06631514084126268, 0.03609607149181621, 0.09613558783062867, 0.30072346329689026, 8.19880485534668, 39.89299188341413, 57.15121589388166, 51.43972717012678, 47.82629564830235, 42.810957363673616, 29.14252884047372, 16.711103745869227, 13.299704994474139, 20.1049895627158, 32.04713119779314, 44.34378555842808, 45.553453036717, 52.117913041796, 58.2123829977853, 54.5131516456604, 49.854238578251426, 41.93712411608015, 31.53615025111607, 24.589028630937847, 14.819896153041295, 8.716683626174927, 3.444403563226972, 2.0036652726786475, 0.48844023048877716, 0.37522199430635994, 0.17553751144026006, 0.1849083921739033, 0.17469382099807262, 0.43970049012984547, 0.13028652673321112, 0.19598858404372418, 0.4116678743490151, 0.2597574543740068, 0.06866911452795778, 0.16390052730483667, 0.21510254911014012, 0.05135848519525357, 0.3019712349133832, 0.44712306612304276, 0.36736225177134785, 0.060373793223074505, 0.07023797570062534, 0.24024083305682453, 0.47870368723358425, 0.46707598545721596, 1.2997826827423913, 2.6010016884122575, 7.57472026348114, 14.556501235280718, 22.981383970805577, 33.09938376290457, 34.36950751713344, 45.6735839162554, 48.80116612570626, 57.73760216576712, 44.5019474029541, 47.098336356026785, 31.946920803615026, 71.87149224962506, 69.27923052651542, 19.07963000025068, 29.866206305367605, 37.167557512010845, 47.67473111833845, 49.81564828327724, 37.21361017227173, 7.993322304316929, 0.029837512145084993, 0.12150868560586657, 0.01752381825021335, 0.1308979546385152, 0.0863083583701934, 0.025063185387157967, 0.0039956344574290726, 0.03069047476830227, 0.06585355382412672, 0.05370986009282725, 0.03977113928911941, 0.035170817747712135, 0.047415043227374554, 0.03543630475178361, 0.022205670863123875, 0.005995530759849186, 0.06569137716931955, 0.016524734807067683, 0.018534815071948936, 0.03750309527718595, 0.035370198477591784, 0.057832978133644374, 0.01101881668104657, 0.029605924750545194, 0.04332252711589847, 0.020238533383235335, 0.06746544768767697, 0.0382865385950676, 0.08778350028608527, 0.03976847603917122, 0.019067403993436267, 0.09133432832147394, 0.021821447016139115, 0.03391381466229047, 0.009224311232433786, 0.09183818128492151, 0.018162845567400967, 0.03598867296906454, 0.022149739221536686, 0.01763498264231852, 0.06962546892464161, 0.08216779519404684, 0.04763449502310582, 0.005423271288496575, 0.048961617917354615, 0.018449289125523398, 0.017781912615256648, 0.039917540004743, 0.035968710468815904, 0.05236698840079563, 0.17707123128431185, 0.10210808699152299, 0.14759888633021287, 0.0762672411011798, 0.1528400129505566, 0.1360691242984363, 0.1086555699418698, 0.16823897164847168, 0.09913597468818937, 0.13687526461269173, 0.0956405626077737, 0.08956084134323256, 0.12446564622223377, 0.1927114770348583, 0.08902515151671, 0.09384652280381747, 0.12821612640150956, 0.1605175281209605, 0.1893812950168337, 0.0800269018592579, 0.17560247438294546, 0.07227088697254658, 0.10259886458516121, 0.1731836191777672, 0.1354270808930908, 0.09880844583468777, 0.14371366266693386, 0.13713324362678186, 0.16530607188386576, 0.14842213929763862, 0.09855493836637054, 0.0825466959338103, 0.32256273712430683, 0.14290475392980234, 0.07167634101850645, 0.15865648298391274, 0.17982503851609571, 0.11644998991063663, 0.2620358392596245, 0.18567342683672905, 0.09603941227708544, 0.07489262414830071, 0.15424919447728566, 0.14414636444832596, 0.15947290988905088, 0.1590723299554416, 0.11934301895754677, 0.10404323493795735, 0.13255149019615992, 0.2899041681417397, 0.12542995304933616, 0.13385547165359768, 0.1881682372518948, 0.21975333669355937, 0.14286339043506555, 0.1631816601646798, 0.1331020670809916, 0.25489596809659687, 5.380138252462659, 36.86201395307268, 67.28292969294957, 65.43045657021659, 65.42550250462124, 59.596714292253765, 50.050865650177, 39.70285095487322, 29.963762487683976, 24.300320557185582, 30.74898883274623, 44.816162313733784, 38.311866760253906, 42.637241976601736, 47.16593885421753, 50.214884826115195, 48.641760553632466, 44.941823959350586, 39.07024874005999, 37.76600238255092, 27.297290529523575, 21.582847084317887, 11.54883885383606, 7.543445553098406, 3.4833988079002927, 0.9690388760396412, 0.375921618193388, 0.33541196478264673, 0.3375043767903532, 1.0141447356769016, 2.2332800030708313, 2.198132323367255, 2.4710319425378526, 1.5559136931385313, 1.6375992127827235, 1.2262477257422038, 1.2137707152536936, 1.429747543164662, 1.2909722583634513, 1.253005781344005, 0.3239487127533981, 0.11793846503964492, 0.19177123105951718, 0.30462745523878504, 0.9415487625769207, 3.1527685608182634, 7.004176318645477, 11.134351015090942, 16.144148111343384, 25.276391335896083, 34.071068491254536, 40.16697325025286, 40.03346014022827, 43.529241289411274, 49.22900145394461, 49.694235461098806, 32.54295464924404, 45.503394739968435, 30.27103614807129, 65.13594327654157, 75.6732199532645, 39.6501384462629, 57.67042350769043, 49.75970833642142, 63.06500489371163, 58.110282693590435, 39.06204639162336, 5.762803341661181, 0.20728934050670692, 0.1351386492273637, 0.30951307022145813, 0.2728920467197895, 0.18934336490929127, 0.12743441334792546, 0.10068694289241518, 0.13906060877655232, 0.21616377787930624, 0.15328202423240456, 0.0809401421408568, 0.10895567919526782, 0.2116852296250207, 0.08633897387023483, 0.18140806071460247, 0.13957371695765428, 0.09019822999835014, 0.12959640233644418, 0.1409936057669776, 0.11923738462584359, 0.12481096626392432, 0.12201442489666597, 0.12514320415045532, 0.08029120481972184, 0.10357313909168754, 0.06275709319327559, 0.21197937455560478, 0.08080579899251461, 0.21661391801067761, 0.14822602910654886, 0.12143992286707674, 0.19376611044364317, 0.12614956657801354, 0.07789275316255433, 0.06570460181683302, 0.17862822487950325, 0.10068550439817564, 0.13226022225405487, 0.18745471696768487, 0.1521578138428075, 0.160182725372059, 0.1636158140110118, 0.13555464547659668, 0.09651841728815011, 0.125441773129361, 0.20104841967778547, 0.11559517149414335, 0.11800611498100416, 0.1328451737229313, 0.14212628427360738], [0.029898780464593853, 0.038227207493036985, 0.028319990628265908, 0.031695975456386805, 0.06005019308733089, 0.037018136121332645, 0.023109659319743514, 0.07682138029485941, 0.015520158622946058, 0.01970746268385223, 0.01324942846050752, 0.04473068066207426, 0.019302026135846972, 0.04443780459197504, 0.029383422939905098, 0.030099419876933098, 0.0353470468627555, 0.04157774216894593, 0.032039989318166456, 0.07783876213112048, 0.030659241801393882, 0.05379927404490965, 0.00957007656273033, 0.04016213830826538, 0.043881497478910854, 0.0673405768881951, 0.09433700184204749, 0.060589526646903584, 0.019367952598258853, 0.03362665864239846, 0.09227908655468907, 0.0465032821521163, 0.036916196412805996, 0.03926828037947416, 0.026246558941368545, 0.052722778237823925, 0.041625928333295245, 0.05594077127586518, 0.06142601104719298, 0.08643922741924014, 0.023961700831672976, 0.04130663350224495, 0.04367686488798686, 0.02410027464585645, 0.07770927050816161, 0.058569968944149356, 0.020464326088715876, 0.02637677320412227, 0.02111465610297663, 0.013482931868306227, 0.0241256009654275, 0.026178800434406315, 0.038982786770377836, 0.046313540012176545, 0.05835818459412881, 0.05583294188337667, 0.04554638832009264, 0.04881825025326439, 0.01802188839896449, 0.10615259675042969, 3.7777455619403293, 17.23715533529009, 38.72643450328282, 53.15452521187918, 52.07066876547677, 47.48327350616455, 43.83023030417306, 43.6983083316258, 36.4406612941197, 34.63769408634731, 26.25647643634251, 34.30000468662807, 17.483105931963237, 19.633133922304424, 20.677771261760167, 25.98696276119777, 34.96090344020298, 31.61627687726702, 32.581273964473176, 31.06399236406599, 43.897502762930735, 38.40020268304007, 33.549147605895996, 35.95215082168579, 25.010431664330618, 18.893725735800608, 17.00603219441005, 12.159327558108739, 12.346180251666478, 9.624508329800197, 8.080602100917272, 5.842937784535544, 6.5750408087457926, 6.916042327880859, 7.140191648687635, 9.316110798290797, 10.859979680606298, 11.952960848808289, 15.01045744759696, 17.683747325624736, 21.92408527646746, 31.205138070242747, 33.55234030314854, 40.641073158809114, 36.944468225751606, 37.4796393258231, 31.043050493512833, 33.04051515034267, 22.934139694486344, 27.43266749382019, 53.961374350956504, 31.307644844055176, 22.18778157234192, 12.721705198287964, 20.946187121527537, 26.180560418537684, 34.395740440913606, 33.64922251020159, 39.52666548320225, 37.33910853522164, 45.27916594914028, 44.25986868994576, 29.69183431352888, 4.066499667508261, 0.28733284611787113, 0.08872168351496969, 0.0866285590454936, 0.03691178932785988, 0.060828744167728085, 0.0831935637231384, 0.07043834709163223, 0.026704682037234306, 0.0683336943121893, 0.01415523115013327, 0.020612755624045218, 0.03855838347226381, 0.03116323725719537, 0.06949920712837152, 0.02130242540234966, 0.027585277999086038, 0.02171249464819474, 0.025538424528869133, 0.05243868241086602, 0.0716964527964592, 0.034486494825354645, 0.0369545506047351, 0.006262321399325239, 0.00682962077969153, 0.03343311331367918, 0.0026005416501513018, 0.010703710107398885, 0.03728485805913806, 0.02135146312814738, 0.006855684157926589, 0.019558045880070755, 0.01363854793765183, 0.09447988096092429, 0.0078117378787802795, 0.10030400486929075, 0.030703143017100434, 0.06347891874611378, 0.08078101210828338, 0.029514926419194256, 0.061092667148581574, 0.0021217550425457633, 0.06111771187611988, 0.020937044472832764, 0.03323295905387827, 0.01805231560553823, 0.020303581142798066, 0.04607057358537402, 0.06616565279130425, 0.05226121496941362, 0.07481204811483622, 0.08499096227543694, 0.04899930035961526, 0.06847919257623808, 0.00707865330956078, 0.03935100058359759, 0.022290089101131474, 0.023579990956932306, 0.04781519229124699, 0.05202327309442418, 0.05239860134731446, 0.019331493215369325, 0.026634658919647336, 0.051984447320657115, 0.023079878417775035, 0.014512467963088835, 0.03383619025615709, 0.030950489387448345, 0.0024710218255807248, 0.012816345851336206, 0.05926554197711604, 0.05655534079830561, 0.015217721994434084, 0.10408982315233775, 0.07511000641222511, 0.030054388900420496, 0.015176324572946345, 0.028903888671525886, 0.010113897783282613, 0.00535704372617017, 0.06223542190023831, 0.04232144708346043, 0.06893807223864964, 0.016552266365449344, 0.020915506075003316, 0.05261458922177553, 0.01797921024262905, 0.02488786381270204, 0.06182238406368664, 0.03489943427432861, 0.03819747069584472, 0.03253137420064636, 0.07275624307138578, 0.0680016532008137, 0.017039317105497633, 0.02590283515330936, 0.06749769167176314, 0.030177451404077665, 0.015201786599521126, 0.01953904011419841, 0.0301075521191316, 0.008504483965225518, 0.03729927692828434, 0.03386913652398756, 0.03184349575479116, 0.014471976385850991, 0.09040201442050082, 0.07737190289688961, 0.07390490107770477, 0.03716837055981159, 0.05170186462679079, 0.04394732216106994, 0.42709390659417423, 10.613033754484993, 30.566216468811035, 55.058116231645855, 59.27922330583845, 55.10515901020595, 45.16208185468401, 34.98415558678763, 26.72989889553615, 23.858505453382218, 28.749460560934885, 21.221274988991873, 25.69137944493975, 21.233370065689087, 30.043041433606827, 31.123798983437673, 39.87197010857718, 49.22698300225394, 54.30628292901175, 53.02401372364589, 59.59104456220354, 56.05981370380947, 36.15554543903896, 37.54748501096453, 32.98492956161499, 22.826922042029246, 15.880159991128103, 10.668700984546117, 8.842386960983276, 3.534482398203441, 2.8843118803841725, 1.8019177040883472, 1.903244478361947, 1.376281697835241, 2.4104803459984914, 1.5993413456848689, 3.5218436249664853, 5.011332648141043, 8.195378524916512, 12.263270003455025, 12.943918142999921, 17.312849010740006, 27.526921544756206, 35.72029290880476, 45.8350704738072, 50.5755866595677, 56.982190540858674, 53.119996138981406, 54.85078198569161, 44.90473447527204, 45.45941611698696, 52.22826433181763, 35.137947014399934, 27.81929131916591, 17.992195231573923, 16.316374846867152, 26.554649693625315, 22.664285557610647, 39.490208285195486, 49.85644115720476, 31.51272439956665, 46.148635728018625, 51.53016839708601, 43.32961259569441, 12.285791720662798, 0.7408353899206434, 0.19100488003875526, 0.03092712742675628, 0.046196418082607646, 0.17008465475269727, 0.010166240822789925, 0.05414253134014351, 0.03183013200759888, 0.059250376719449244, 0.11117001716047525, 0.040205683293087144, 0.05091306088226182, 0.023889017856812904, 0.05449922362874661, 0.07580163715673344, 0.0683522183181984, 0.0345920443401805, 0.028536081979317323, 0.011509634138617133, 0.02743702657919909, 0.05623417321060385, 0.047098547353276184, 0.006717354192265442, 0.02835659759252199, 0.01746868049459798, 0.012321132335013576, 0.02895822236314416, 0.020611537653686743, 0.052032362070998976, 0.02950892477695431, 0.02917591336050204, 0.06763485074043274, 0.03343746272314872, 0.014644071526293243, 0.07408657882894788, 0.04100777614595635, 0.05826670450291463, 0.03446605395791786, 0.03310302299048219, 0.013820799899154475, 0.019751757449869598, 0.07332672138831445, 0.0582810283771583, 0.04870194595839296, 0.027582441722708087, 0.05969343973057611, 0.012523078775432493, 0.06070183776319027, 0.03908024475510631, 0.042289898597768376, 0.09319794510624238, 0.007620575904314007, 0.12617792934179306, 0.08967012619333607, 0.15633780668888772, 0.13496578564601286, 0.0806464586140854, 0.16344303185386316, 0.09147036102201257, 0.22574105539492198, 0.0993724170007876, 0.13539225847593375, 0.07368601925138916, 0.04954381114138024, 0.08669394267989056, 0.11093010753393173, 0.13132587953337602, 0.10781274802450623, 0.17973980094705308, 0.12496177745716912, 0.12526589685252734, 0.20228715320783003, 0.12764665910175868, 0.16422254645398685, 0.0856491480288761, 0.13612441133175576, 0.09085442764418465, 0.14055205588894232, 0.21348482663077967, 0.10007250907697848, 0.08275017501520258, 0.2530323038143771, 0.1280674050961222, 0.1385994628071785, 0.28857290957655224, 0.16475765274039336, 0.1282787551837308, 0.12461622671357223, 0.05820686449962003, 0.12773926556110382, 0.17649755706744535, 0.15759540349245071, 0.13798859130058969, 0.10367521789989301, 0.1176275195819991, 0.2374542254422392, 0.15281469002366066, 0.13035162538290024, 0.07776396043066468, 0.0778098361832755, 0.09630104859492608, 0.07817315097366061, 0.15660111898822443, 0.06782216033233063, 0.1568635491920369, 0.1188658324203321, 0.2522658035159111, 0.13173044925289495, 0.16941587706761702, 0.11533234774002007, 0.14256383079503263, 0.2980693871421473, 6.403174076761518, 28.811155353273662, 59.3822511945452, 72.74825068882534, 68.47665105547223, 62.82234600612095, 55.98547492708479, 54.55445521218436, 45.72791535513741, 46.15354115622384, 36.69930451256888, 45.97941582543509, 26.077584641320364, 29.13440465927124, 28.589928184236797, 34.42078522273472, 46.257368087768555, 41.052743503025596, 41.074765818459646, 43.428270067487446, 54.806178024836946, 53.45808853421892, 45.58042941774641, 49.73871782847813, 36.40779978888375, 29.190198693956646, 25.503623485565186, 19.159084388187953, 16.957274947847637, 14.555492009435381, 10.413326025009155, 8.659117800848824, 9.718299457005092, 10.01659083366394, 10.810539773532323, 13.167474695614406, 15.000874144690377, 18.385574442999705, 21.325355529785156, 24.30055853298732, 29.891709668295725, 42.953520502362935, 45.22323295048305, 51.032305649348665, 47.93819291251046, 48.68106651306152, 41.31722668239048, 42.86029999596732, 30.610024860927037, 37.222045285361155, 67.05467442103794, 39.25031130654471, 32.141897678375244, 19.74716775757926, 30.846951484680176, 38.66269172940935, 44.339380400521414, 46.588078022003174, 51.67944696971348, 49.039475440979004, 59.83264037540981, 63.86916160583496, 44.44128615515572, 10.419802614620753, 0.5174664929509163, 0.2542341521808079, 0.14215307283614362, 0.09369704832455941, 0.24273708196622984, 0.16313192354781286, 0.25394270781959805, 0.18676738813519478, 0.23893926718405314, 0.17319542568709168, 0.1527551689318248, 0.14792788081935473, 0.16536563368780272, 0.13147507581327642, 0.13618490951401846, 0.17246232288224356, 0.12034773933035986, 0.09683316254190036, 0.16785264095025404, 0.1436703178499426, 0.1648259540753705, 0.10940583968268973, 0.11008862233055489, 0.12517175690404006, 0.21135908498295716, 0.08526311588606664, 0.10076006182602473, 0.18089966156652995, 0.18413098103233747, 0.1506935352725642, 0.14274536605392182, 0.16109603350715979, 0.12071515247225761, 0.12777237807001385, 0.2026098101798977, 0.17689551785588264, 0.15698146500757762, 0.13589445581393583, 0.10244563102189984, 0.12744028946118696, 0.07513131919716086, 0.15328609544251645, 0.09585647245070764, 0.15653825950409683, 0.07731048190700156, 0.17002984269389085, 0.14974649037633622, 0.19768938635076794, 0.1773587130010128, 0.1756103861012629, 0.18187289791447775, 0.1602353932602065], [0.024387496822912778, 0.03425591166264244, 0.026658414430650215, 0.0174842325172254, 0.006077281931149108, 0.053287207415061336, 0.058164089652044434, 0.06380080218826022, 0.042058541905134916, 0.05997022095003298, 0.06755054276436567, 0.02927956297727568, 0.07387794288141386, 0.020764849248475263, 0.010253113661227482, 0.04515880572476557, 0.06262710623975311, 0.04471831775403448, 0.01673230715095997, 0.06484685891440936, 0.07071449048817158, 0.026315844152122736, 0.03348324348085693, 0.02962269474353109, 0.08815203301076378, 0.049864296801388264, 0.046158250487808666, 0.01945780250909073, 0.054871573112905025, 0.08822698398892369, 0.051323995260255675, 0.03354839302067246, 0.02879235447783555, 0.04316628424982939, 0.0746672690979072, 0.03797064661713583, 0.04084356727876833, 0.0457731784720506, 0.040524028175111325, 0.044909501780888865, 0.037500506666089804, 0.00785907163351242, 0.027449772859524404, 0.008015743672980793, 0.00926055433228612, 0.05537991119282586, 0.0226748320274055, 0.026529065300045267, 0.027459084056317806, 0.03051578253507614, 0.008033355897558587, 0.03963789197483233, 0.0028736246417143513, 0.018425623520410488, 0.0192634073152606, 0.06395043273057256, 0.07427595795265265, 0.007948519512345749, 0.020901149970346262, 0.08556805630879742, 0.12265858533126967, 0.040280736051499844, 1.8039459266832896, 11.3118896484375, 25.579780953271047, 36.288026741572786, 45.57144539696829, 52.08906759534563, 49.21811710085188, 54.21013723100935, 50.88842582702637, 49.45402928761074, 41.6769939831325, 37.40377194540841, 36.139547211783274, 32.765776429857524, 33.34211213248116, 27.449614150183542, 26.600631134850637, 24.136198895318167, 12.1256730897086, 65.06829561505998, 59.64336449759347, 21.16508664403643, 35.909019878932405, 26.50543212890625, 27.51336213520595, 29.575941835130962, 26.679084982190812, 25.19359139033726, 31.129590306963237, 30.321118763514928, 30.005774770464214, 29.524354934692383, 36.689705576215474, 33.92661544254848, 27.46476296016148, 29.281331266675675, 19.501825128282817, 37.38193028313773, 69.81121935163225, 33.20019170216152, 28.656959193093435, 25.352519273757935, 29.500064032418386, 23.646232775279454, 29.001002720424108, 28.022513968603953, 41.39543907982962, 55.3051872253418, 48.459123679569785, 27.328592164175852, 29.885963508061, 38.78429215294974, 43.99693843296596, 42.84862354823521, 47.13839619500296, 49.387062549591064, 53.615350587027415, 50.07272468294416, 27.523049661091395, 7.973057883126395, 0.3681589333074433, 0.05211359289075647, 0.04196183030892696, 0.01282443483692727, 0.055231447730745585, 0.023280511044764092, 0.09997863375714847, 0.05752025491424969, 0.006479092133564076, 0.04092153434508613, 0.023456638379554664, 0.031138525011816194, 0.0514446693206472, 0.025852258849356855, 0.020043413853272796, 0.0409213511406311, 0.04640666555081095, 0.019512037813131298, 0.04076475204367723, 0.046273564121552875, 0.03296829986252955, 0.03414359036833048, 0.02275345557635384, 0.01501314198997404, 0.0328123419811683, 0.055744545733822246, 0.015821000694164207, 0.048934211887951405, 0.019267100242099593, 0.04230572542707835, 0.10187250641839844, 0.021059540399749364, 0.023213775429342474, 0.011044332142254072, 0.01474905276804098, 0.056651954006935866, 0.041961782811475654, 0.045707099339259524, 0.047525250885103426, 0.05054694374224969, 0.03930961673281022, 0.043192540162375996, 0.02801973548983889, 0.02273238536768726, 0.0270633861821677, 0.00993992988618889, 0.03853883148570146, 0.009984607176323022, 0.006614901765715331, 0.014514464552381208, 0.01717742103418069, 0.06885804581855025, 0.0473722480237484, 0.01714403202225055, 0.033423227058457475, 0.028312061946573, 0.005257159130581255, 0.01532301027327776, 0.055614222905465534, 0.044303430909557004, 0.03240356195185866, 0.03757577994838357, 0.05053346125142915, 0.00930140892575894, 0.008613253976883633, 0.04707813362724014, 0.08991918925728117, 0.030411009942846637, 0.054766301797436814, 0.035788522101938725, 0.017109425039961934, 0.05657714891380497, 0.08500245665865284, 0.03924503716241036, 0.03262863541021943, 0.053931629085647206, 0.02749835935953472, 0.011158679711765476, 0.010138771180728716, 0.02470202833813216, 0.031161578239074776, 0.019019187295011113, 0.06695373050336327, 0.0919366842135787, 0.040914369015289206, 0.03680525254458189, 0.05919776311410325, 0.032849430705287626, 0.0704421265316861, 0.019811546563037803, 0.06028121390513011, 0.01900903132211949, 0.012758099557166653, 0.020890810792999606, 0.039892817581338544, 0.04073933072920356, 0.046189975392605574, 0.010279252526483365, 0.0360532559321395, 0.013603778106958737, 0.051791142871869464, 0.008691727399959095, 0.048038962962371964, 0.022206659827913557, 0.005990992632827589, 0.06393123018954482, 0.013105997183759297, 0.0205779993640525, 0.021012745232188275, 0.045059481768735817, 0.020074360139135803, 0.05179648633514132, 0.025528865666793923, 0.0389640320624624, 0.17102008312940598, 0.4412914104759693, 5.291199573448726, 23.626070840018137, 40.85540076664516, 50.84753220421927, 58.95076806204659, 59.76896708352225, 50.75823743002755, 50.3523827280317, 44.75287117276873, 43.57019049780709, 28.19943768637521, 23.51299933024815, 21.048184939793178, 22.917875698634557, 26.645219462258474, 19.16314387321472, 23.73373144013541, 26.01932747023446, 24.12397701399667, 67.83504050118583, 58.33288560594831, 42.70484447479248, 50.64825439453125, 48.30096183504377, 47.8745995249067, 45.85799952915737, 54.164463247571675, 46.583773612976074, 50.27807174410139, 46.65070908410208, 51.52221270969936, 52.56926454816546, 54.98134905951363, 54.975939886910574, 51.70991482053484, 49.36953224454607, 36.05598817552839, 44.79149620873587, 62.613087109157014, 50.56677286965506, 45.073478426252095, 41.45334536688668, 35.85065501076834, 27.915589877537318, 24.220153978892736, 22.917674200875418, 20.680001633507864, 30.985606261662074, 47.15451601573399, 23.14501404762268, 24.726833990642003, 25.955567325864518, 34.534141608646934, 37.32463196345738, 45.526959555489675, 47.92105518068586, 51.66024562290737, 54.827022620609824, 41.54713909966605, 17.031858648572648, 1.9777467548847198, 0.05618079286068678, 0.03232068907735603, 0.025900144761960422, 0.04228115567405309, 0.03465727869687336, 0.13451485841401986, 0.030744906847498248, 0.059051708451339176, 0.0594140122245465, 0.03463306178205779, 0.015412478508161647, 0.011921279282043023, 0.04956418754799025, 0.03897218466071146, 0.044797217806002924, 0.03543961260999952, 0.028323727659881115, 0.03282569555033531, 0.042094531402524026, 0.060582958427923064, 0.023747478844597936, 0.04423158083643232, 0.04219473066872784, 0.013730121327431073, 0.048111922440252135, 0.045931199099868536, 0.024240334451730763, 0.024842629275683845, 0.0129913569960211, 0.11786769383719989, 0.02393871545791626, 0.031167020089924335, 0.04154388327151537, 0.03781905171594449, 0.01399240140537066, 0.04761825768010957, 0.08523633410888058, 0.05207769499559488, 0.03005359162177358, 0.06480592968208448, 0.07482561881520919, 0.02896845806390047, 0.006856637075543404, 0.037680494865136485, 0.007579215802252293, 0.021896224967869263, 0.04094284373734679, 0.019370186674807752, 0.09415016043931246, 0.09656839139227356, 0.038576008419373205, 0.029657442521836077, 0.02751805553478854, 0.1191697618258851, 0.2551703133753368, 0.13038449361920357, 0.17201277986168861, 0.14338058339697973, 0.13944009984178202, 0.1404532611902271, 0.09769034226025854, 0.1262516182448183, 0.16349540118660244, 0.102715945802629, 0.18843251307095799, 0.25428949349692886, 0.11370944803846733, 0.13561724711741718, 0.15024992264807224, 0.14167847830270017, 0.23356860822864942, 0.1288665429289852, 0.09059842316699879, 0.1892122719436884, 0.09510325108255659, 0.11298741213977337, 0.07960517877446753, 0.11260109501225607, 0.08023980579205922, 0.1434147408498185, 0.12036857035543237, 0.2033784275076219, 0.27282074626002994, 0.16687282281262533, 0.10290915186383895, 0.09695782299552645, 0.19273754635027476, 0.2755223741488797, 0.1315000323312623, 0.1572413167783192, 0.1553807466157845, 0.09486465102859906, 0.15511484231267655, 0.14750231722635881, 0.13054416647979192, 0.09074234722980432, 0.05280031104172979, 0.07752814915563379, 0.1818430966564587, 0.12750769512993948, 0.11222743256283657, 0.04763502088774528, 0.10561373138001987, 0.0950641335387315, 0.10193649905600718, 0.059844271279871464, 0.09193369187414646, 0.14641742115574224, 0.09440992400050163, 0.13337767443486623, 0.1741030476987362, 0.08728694835943834, 0.19230398961475917, 0.1968318945063012, 0.23597317348633493, 3.3656270589147295, 18.346572467258998, 38.88809476579939, 56.655263900756836, 68.73035757882255, 73.09166540418352, 66.48578371320451, 69.83283519744873, 65.93750136239188, 64.01706790924072, 54.04610068457467, 47.1336783681597, 47.974205425807405, 41.317796434674946, 42.871806212833945, 35.74304131099156, 36.36052424567086, 31.888545513153076, 17.27458528109959, 75.98292200905937, 70.16518838065011, 34.96077837262835, 50.69698905944824, 43.387296540396555, 41.43062823159354, 45.49818011692592, 45.15143026624407, 41.05272265842983, 47.31486654281616, 45.32163681302752, 44.28672000340053, 42.98202896118164, 51.47088636670794, 48.61943251746041, 39.41753012793404, 42.81254850115095, 30.169234616415842, 51.65842866897583, 85.69030584607805, 45.18115813391549, 38.94104698726109, 34.97010285513741, 38.87803724833897, 31.8105137688773, 38.57217754636492, 37.318163190569194, 53.06740174974714, 65.20341723305839, 59.62580639975411, 35.775711740766255, 42.69458545957293, 50.96074962615967, 55.21936307634626, 55.044918128422324, 64.52099296024868, 63.941144943237305, 68.39837265014648, 65.50492041451591, 41.52378273010254, 12.722228918756757, 0.9025816906775747, 0.24729515452470097, 0.15274922496506146, 0.1263501008174249, 0.20460525953343936, 0.14665549195238523, 0.2378593108483723, 0.07299112475344113, 0.19285919410841806, 0.13518753089010715, 0.08852867422891514, 0.1364378673689706, 0.19761910369353636, 0.1179440968802997, 0.0972826648503542, 0.14656887017190456, 0.14132331950323923, 0.08685847385121243, 0.1556920584823404, 0.13084030630333082, 0.1305624462131943, 0.16138545583401406, 0.09818727416651589, 0.10782078187912703, 0.0950940026502524, 0.17858390297208512, 0.18420040873544558, 0.09478383750787803, 0.1435704239244972, 0.13367776333221368, 0.19392004289797374, 0.09485227454985891, 0.09982637049896376, 0.1251914208488805, 0.12304805086127349, 0.15018243555511746, 0.12454438342579774, 0.14836134255996772, 0.13487991025405272, 0.13577902343656334, 0.09888638236692973, 0.11275217761950833, 0.08992457682532923, 0.08605571942670004, 0.07895468082278967, 0.08789596746542624, 0.13652120503996099, 0.12512970130358422, 0.15450361796787807, 0.172584594892604, 0.21120828736041272, 0.14244244088019642, 0.08628914904381547, 0.055283175847892246], [0.003301490588845419, 0.009661171585321426, 0.021425336931965182, 0.05552051043404, 0.042246455393199406, 0.050761007969932895, 0.05019480103094663, 0.07518697263939039, 0.028174724762461016, 0.018134660919063857, 0.03166753466108015, 0.07037530440304961, 0.012619356109228517, 0.0958630203136376, 0.06653527795736279, 0.06932618748396635, 0.03900295961648226, 0.021074671730665222, 0.0049794898784187224, 0.03487810791869249, 0.03299685940146446, 0.04820829816162586, 0.0778063145865287, 0.032949962453650575, 0.0407333901551153, 0.040714228326188664, 0.054455946665257215, 0.017282344600451843, 0.0730066971321191, 0.0459185647778213, 0.06272275932133198, 0.011017892177083662, 0.07352556607552937, 0.034520034811326435, 0.03258003873218383, 0.02997745999268123, 0.045755397461886914, 0.04576425573655537, 0.0005501999268225127, 0.042682943399995565, 0.04174594760739377, 0.04648579969736082, 0.051262221432157924, 0.06212497675525291, 0.027956343355721662, 0.027035238853256618, 0.017256894448239888, 0.010289785934479108, 0.015234378332804357, 0.02148387923703662, 0.02625172259286046, 0.043166457276259146, 0.022570824483409524, 0.044268255654190264, 0.0354153753391334, 0.055052942130714655, 0.03346966599513378, 0.040603929066232274, 0.006710116344038397, 0.02984544761212809, 0.02617735685115414, 0.10279206386102097, 0.012028490359495794, 0.08188061203275408, 0.17003381890910013, 2.4661097952297757, 6.7280648946762085, 16.521157366888865, 29.221514225006104, 32.500692231314524, 38.45020539419991, 49.600507736206055, 56.89283670697893, 55.128355571201865, 53.453339440482004, 57.40180267606463, 54.480227606637136, 60.25836345127651, 55.55602414267403, 46.744026865277974, 42.44814327784947, 38.022144249507356, 64.34395286015102, 32.809657778058735, 47.66578531265259, 39.002048696790425, 27.19724862916129, 27.989244256700786, 20.257274968283518, 24.99425278391157, 29.56863580431257, 30.78687388556344, 22.411603893552506, 25.83682782309396, 18.895933525902883, 28.244825056621007, 28.191122429711477, 31.058451175689697, 29.723941939217703, 59.65528065817696, 89.1173380443028, 28.6701694556645, 39.03455931799752, 40.31433412006923, 46.935140541621614, 51.75266013826643, 57.8422976221357, 54.88758659362793, 66.70836230686733, 58.43116092681885, 47.9030385017395, 50.8743348802839, 60.14710889543806, 55.073603766305105, 49.531915119716096, 46.09392213821411, 38.02127225058419, 28.64737936428615, 16.733000993728638, 5.1669783762523105, 0.4096589764314038, 0.09973964693823031, 0.03742722827675087, 0.06615396841828312, 0.01689937095423894, 0.03392785355182631, 0.056441849031086476, 0.01990466022730938, 0.06857447924890689, 0.03265713048832757, 0.026566929250423397, 0.049554182549140284, 0.017391831314723407, 0.02676885957563562, 0.0477628263511828, 0.04828895901196769, 0.04200314969888755, 0.054184271421815665, 0.01854032138362527, 0.06068135279097727, 0.02087232580275408, 0.024035584813516055, 0.04699225823528, 0.02645022631622851, 0.06680487349097218, 0.055020090857786794, 0.03243964983682547, 0.05824858083256653, 0.04873616108670831, 0.028130268844376718, 0.04215144691988826, 0.034181747785104175, 0.039963195233472755, 0.015352708054706454, 0.060643938370049, 0.05146500162248101, 0.028060853015631437, 0.033212806563824415, 0.014353807816015822, 0.015300372648718101, 0.02554237360267767, 0.05354234676009842, 0.08760548662394285, 0.04175906029662915, 0.023505576021437134, 0.0071580796502530575, 0.0507849500780659, 0.07654835815940585, 0.06315157309706722, 0.0663828043533223, 0.02365944910395358, 0.08803483644234282, 0.037634961772710085, 0.045269976902220926, 0.008589430612378886, 0.0607504208705255, 0.015481188660487533, 0.050397723713623624, 0.04422907025686332, 0.036353192159107754, 0.06125042654041733, 0.014281145197206309, 0.010797369992360473, 0.053252524097583125, 0.03084245304177914, 0.03659003141469189, 0.08414495802883591, 0.09484730088817221, 0.03068805918363588, 0.11219375008451087, 0.024462405392634015, 0.1003332497285945, 0.019694585785535828, 0.024945544378299798, 0.0229953278654388, 0.022984958154016306, 0.05102257304159658, 0.025825202265488248, 0.07173046097159386, 0.038628150442881246, 0.0376206446838166, 0.04186886761869703, 0.021338799968361855, 0.041568795684725046, 0.0321938912384212, 0.06610773304211241, 0.039231520744838884, 0.02194584284110793, 0.09706812564815794, 0.05869228845196111, 0.03515244980475732, 0.0342380119088505, 0.01566837781241962, 0.08364009404821054, 0.10981917607464961, 0.019830231721113836, 0.0291576573758253, 0.056569284692938836, 0.02349667533833001, 0.008303899683856537, 0.03064262108611209, 0.03413197384881122, 0.04772479446338756, 0.01867249491624534, 0.0815738667068737, 0.013164018713203924, 0.018892582838556597, 0.026990384295848862, 0.03750054059284074, 0.06704286286341292, 0.04038524740774717, 0.018143415717141967, 0.02497560008695083, 0.023014046950265765, 0.08732595055231027, 0.04240979912823864, 0.027032804608877217, 0.05627614399418235, 0.034686645692480464, 0.2149882431008986, 1.5331559543098723, 7.425317491803851, 17.26912225995745, 30.850588866642543, 42.76505756378174, 51.62819010870797, 55.700320856911794, 60.22226755959647, 60.61939879826137, 57.45522737503052, 56.27588183539254, 47.50861358642578, 47.8508505821228, 40.42691578183855, 40.37363004684448, 22.265618767057145, 14.038272448948451, 50.415760721479145, 63.81405544281006, 20.793559517179215, 40.882474422454834, 29.138599634170532, 24.169619730540685, 26.96955442428589, 20.060529776981898, 27.424579790660314, 33.951802662440706, 34.8132437978472, 24.878810201372417, 26.759032692228043, 26.78848784310477, 29.543761253356934, 23.126823663711548, 26.830694675445557, 17.439337491989136, 52.534732001168386, 92.91577925000871, 24.124371324266704, 27.281518118722097, 23.063223327909196, 29.40921286174229, 28.56197210720607, 37.85968494415283, 42.22150346211025, 57.011560576302664, 61.200900486537385, 51.68668351854597, 47.05477809906006, 56.879812308720176, 58.206685474940706, 57.26594802311489, 57.131580284663606, 49.57490015029907, 43.6813964162554, 30.44967085974557, 12.895933015005928, 1.7985242690358842, 0.039267405069300106, 0.08202989652220692, 0.0292246796722923, 0.009821534007122474, 0.025727661160219992, 0.11401915177702904, 0.035280139917241674, 0.05693375638553074, 0.04951341277254479, 0.014103117964363523, 0.05815589973436935, 0.0518969502300024, 0.048414871362703185, 0.023065042249592285, 0.049801498385412354, 0.036362623795866966, 0.04364472607682858, 0.018903011921793222, 0.03090405723612223, 0.04580798053315707, 0.03727415756189397, 0.03850659089429038, 0.016913309759859527, 0.053257423120417764, 0.0251127693336457, 0.02083470782132021, 0.022995441520054425, 0.029453030454793146, 0.06309726993952479, 0.028379292892558233, 0.09042698450918708, 0.05509247358090111, 0.004510457635790641, 0.04401808997083988, 0.0606366576892989, 0.06387086771428585, 0.03143014239945582, 0.03404730624918427, 0.03598724804552538, 0.031786515776600154, 0.014036784380940455, 0.049513677401202064, 0.060506745374628475, 0.057983076865119595, 0.028881032219422714, 0.06879343571407454, 0.03894206788390875, 0.08223195746541023, 0.05639024305024317, 0.03125265120927777, 0.03984446517590966, 0.0340782135192837, 0.030026921802865605, 0.01499176983322416, 0.031746000450636656, 0.09610297743763242, 0.06594678453568902, 0.10313159599900246, 0.16273574052112444, 0.14037552821849072, 0.0938984714448452, 0.13614123900021824, 0.2087428303701537, 0.09049899743071624, 0.08496877418032714, 0.08045891832028117, 0.14756132263158048, 0.039921027674738846, 0.1998023579695395, 0.11636669295174734, 0.24545135774782725, 0.1206208768167666, 0.11527544579335622, 0.07500384960855756, 0.1842316756291049, 0.12774058191904, 0.10689478513917752, 0.1509549341031483, 0.20385931884603842, 0.11242129680301462, 0.10412555480641977, 0.08397190445767981, 0.1246511305549315, 0.07707147473203284, 0.1862232166209391, 0.1588352226785251, 0.14127283649785177, 0.14292356292051928, 0.14828743652573653, 0.11745179258286953, 0.14659428809370312, 0.1492201779037714, 0.20365277278636182, 0.16536886351449148, 0.1139365876359599, 0.13143641288791383, 0.14832152612507343, 0.11972469490553651, 0.19116538071206637, 0.07034033270818846, 0.09535719959863595, 0.11491120819534574, 0.09028215799480677, 0.21602189620690687, 0.05813230707177094, 0.16258753490235123, 0.11269889226449387, 0.18391717464796134, 0.1312912471060242, 0.09904794155486993, 0.14972184598445892, 0.16883695098970616, 0.22285730870706694, 0.11125283914485148, 0.14352884329855442, 0.0941821669361421, 0.25531937394823345, 0.13054935048733438, 0.18228798492678575, 0.6836964988282749, 4.1116629583495, 12.448865941592626, 25.779400961739675, 43.31836346217564, 54.056905133383616, 61.10621043613979, 71.20239462171281, 76.05325167519706, 74.26818302699498, 74.83314800262451, 68.92678315298897, 68.86982876913888, 70.82560076032365, 70.34957272665841, 56.92811271122524, 51.80777324948992, 50.404647077832905, 73.26772580827985, 47.82298483167376, 62.21920762743269, 53.26591525759016, 40.160341194697786, 41.55611269814627, 27.79920928818839, 35.97904035023281, 40.65116541726248, 41.011839457920615, 31.52681187220982, 35.0627292905535, 30.22994797570365, 38.061057635716026, 37.0990343775068, 42.82776158196585, 39.3092702456883, 71.28933048248291, 96.37549577440534, 37.7604855128697, 52.571321214948384, 52.45118338721139, 58.07878303527832, 61.18935258047921, 70.36451830182756, 67.99663475581578, 79.3912079674857, 71.54188360486711, 63.894418307713096, 69.90347753252301, 78.12945679255894, 72.57619244711739, 69.33624744415283, 64.33360699244908, 51.07271637235369, 41.702021394457134, 23.024075439998082, 8.624884026391165, 0.7346341226782117, 0.11206752900034189, 0.14872591942548752, 0.1739276871085167, 0.13920010200568608, 0.10671525155859334, 0.18938409058111055, 0.08063805156520434, 0.16176908596285752, 0.13882355578243732, 0.08033792874110596, 0.13849004225007125, 0.12665807429168904, 0.07238590544355766, 0.1569207361234086, 0.2635161041149071, 0.08339465436126504, 0.12305793033114501, 0.10397333904568638, 0.12909542636147567, 0.09750248984034572, 0.1166101513164384, 0.1589801170464073, 0.0929302494706852, 0.21229044214955398, 0.13673328794538975, 0.09890746444995914, 0.09537336908813034, 0.12117088373218264, 0.13722808925168856, 0.11185117810964584, 0.27072741144469803, 0.15551786497235298, 0.10083383893860237, 0.12609881215861865, 0.18121336187635148, 0.15373006090521812, 0.18723263245608124, 0.08394605227346931, 0.1257916529263769, 0.11787962248282773, 0.07191158232412168, 0.16616516507097653, 0.1877482919288533, 0.10007627494633198, 0.07800043667001383, 0.08879579989505665, 0.10552141669073276, 0.18275466774191174, 0.13301593384572438, 0.06253367875303541, 0.1998888033309153, 0.1312810555100441, 0.10167922571833644, 0.09480590346668448, 0.21111790649592876], [0.02873287409810083, 0.06241071463695594, 0.013669294903853109, 0.011745700712448784, 0.03202938720850008, 0.034182609524577856, 0.0756201765366963, 0.06723269660558019, 0.03508224857172795, 0.021393489890864918, 0.02636220505727189, 0.029685537264283215, 0.07847018646342413, 0.06877084049795355, 0.02731236442923546, 0.04744706329490457, 0.01689797147576298, 0.11849102324673108, 0.03249602931152497, 0.03340406183685575, 0.03628038535160678, 0.06199247243681124, 0.0632617739694459, 0.0067204198982965735, 0.033686447755566666, 0.011849135742522776, 0.04163582476654223, 0.0437752456803407, 0.016745441892583455, 0.011347796751319297, 0.05030271863298757, 0.021529802487098744, 0.016076370741107633, 0.060893598544810495, 0.018200273559029614, 0.020795064412855675, 0.04288365066583667, 0.07765898427792958, 0.011433944405455674, 0.017943690630740354, 0.029789152954305922, 0.04719491968197482, 0.0388244166970253, 0.05636704733063068, 0.026743579057178328, 0.01087145329386528, 0.029111408428954225, 0.011680434125342538, 0.019968927671600665, 0.028000577053587352, 0.0007370878728189771, 0.014526048841487085, 0.0660578878596425, 0.05815870886934655, 0.0275141098536551, 0.043470885405050855, 0.03623976146004029, 0.06623105678175177, 0.041040152444371154, 0.05203861137852073, 0.02277009155867355, 0.07215906440147332, 0.05579897102766803, 0.037170362060091326, 0.02318634225853852, 0.07477176349077906, 0.022255020715030174, 0.03305117952238236, 0.6705877450960023, 1.024469324520656, 2.6434799347605025, 6.293979227542877, 15.15819525718689, 18.318112645830425, 18.474372420992168, 40.10493973323277, 49.715524741581504, 45.93912322180611, 46.517856052943635, 56.14011056082589, 58.93890748705183, 52.28248112542288, 44.257686955588206, 57.89143875667027, 46.79823671068464, 53.43884549822126, 51.65779638290405, 48.92071335656302, 58.929624693734304, 52.61408390317644, 54.496114662715364, 56.817684991019114, 59.42018141065325, 55.15204545429775, 50.610150473458425, 55.89372396469116, 62.030334745134624, 54.875027724674766, 53.05291822978428, 53.727101939065115, 45.35249376296997, 54.29262277058193, 61.037166186741416, 59.725832666669575, 63.50376279013497, 53.75430761064802, 52.63077000209263, 45.659263678959434, 43.9709278515407, 38.00656986236572, 29.91787311008998, 28.254340614591325, 20.79897563798087, 14.110212360109601, 8.1675831249782, 2.237180765186037, 0.7631441556981632, 0.18997852796954767, 0.07887027106646981, 0.06267224917454378, 0.04439561328451548, 0.009556696700331355, 0.03138014115393162, 0.0436531025916338, 0.011545939154789915, 0.07264019322714635, 0.06880431263042347, 0.046997099582638056, 0.047557728963771036, 0.03104696688907487, 0.023221198602446487, 0.04334097309038043, 0.05470678409827607, 0.04571928582819445, 0.02968109625258616, 0.04600453516468406, 0.015068166090973785, 0.04097135577883039, 0.11275185870804957, 0.014023368895453001, 0.017919560229139667, 0.016251950158870647, 0.06749142879354102, 0.06930322585893528, 0.02875656175560185, 0.08424595118101154, 0.02707083480033491, 0.05072525595980031, 0.03109125486974205, 0.0412211109484945, 0.03295236446761659, 0.0221178294159472, 0.011163409100845456, 0.01761738314027233, 0.028166706174878136, 0.015356160101613827, 0.04926494342674102, 0.04940333403646946, 0.024411594994100075, 0.11973116812961442, 0.052289231680333614, 0.05764220801315137, 0.03678740028824125, 0.06307122098015887, 0.010527426709554024, 0.03509233160210507, 0.0027666135200498892, 0.019274828755961995, 0.033370342039104016, 0.08464132675102778, 0.08428054289626223, 0.03683532860928348, 0.029684838373214006, 0.01400211887500648, 0.039942710261259756, 0.037831183922077925, 0.015344105927007539, 0.051728846571807346, 0.09376547858119011, 0.040931783616542816, 0.022702350015086786, 0.034205170813947916, 0.042835389862635305, 0.05122354493609496, 0.02244987222366035, 0.037652491724916866, 0.02042324927502445, 0.015532448588471328, 0.03915677332718458, 0.029479201550462415, 0.061190973302083354, 0.05860076764864581, 0.023119026495675956, 0.04465231665277055, 0.0328384995061372, 0.13246826109077248, 0.019863198344994868, 0.04805692717699068, 0.03874723333865404, 0.036737877409905195, 0.023039437730663588, 0.016157934043024267, 0.0040769742668739384, 0.007171657135976213, 0.04724414400490267, 0.021029259078204632, 0.04176979811329927, 0.032055649906396866, 0.0372869479469955, 0.053449183902038, 0.019292550394311547, 0.06311712387417044, 0.0850646308224116, 0.03230153742645468, 0.016672521430466856, 0.012630280523028756, 0.06144323905131646, 0.023023017183212296, 0.011576180612402303, 0.03647371694179518, 0.012046261191634195, 0.04487331211566925, 0.08250250973339592, 0.026581719617492387, 0.03829082015103527, 0.04965545729334865, 0.047635424616081376, 0.005956387770960906, 0.057936943269201686, 0.07552445560161557, 0.011683320443678116, 0.06568509393504687, 0.026555351746667708, 0.02732134484020727, 0.005182285335779722, 0.061302490532398224, 0.05545405810698867, 0.03289755919416036, 0.011430173447089536, 0.022184632884870683, 0.031725067645311356, 0.04168647740568433, 0.10324489777641636, 0.5045850755912917, 2.6291023748261586, 5.296600929328373, 10.70136272907257, 17.544998747961863, 28.55345187868391, 32.77002872739519, 33.42520563943045, 53.16822011130196, 62.72489057268415, 60.22547762734549, 59.20499570029122, 55.15963288715908, 56.26629332133702, 44.758794512067524, 50.11021368844168, 54.93090513774327, 46.423794814518516, 47.18515409742083, 41.46258994511196, 39.300293173108784, 31.925263268607004, 33.672947134290425, 36.109440667288645, 38.09319305419922, 32.70333991731916, 32.34435428891863, 26.932388510022843, 35.397038391658235, 40.75671550205776, 42.49483517238072, 49.452868938446045, 61.24995476858956, 60.54341329847063, 49.39966310773577, 58.44650254930769, 60.91621889386858, 67.12775557381767, 65.8586254119873, 64.14642947060722, 56.67193610327584, 58.83701910291399, 51.752201557159424, 43.95120538984026, 43.212962763650076, 36.311848640441895, 26.275210516793386, 16.685426677976334, 7.73869514465332, 3.784748477595193, 1.1084793422903334, 0.17991506654236997, 0.04609962506219745, 0.04241546489564436, 0.01717990616868649, 0.1425286555396659, 0.056814765091985464, 0.0173457231638687, 0.05850824261350291, 0.03384963542755161, 0.028858626993106942, 0.029856589157134295, 0.005985703452357224, 0.02169198083824345, 0.03959733254409262, 0.04702690423333219, 0.04971859836950898, 0.023136653139122894, 0.03972464946231671, 0.01883461559191346, 0.017835004587790797, 0.05323995423636266, 0.014134987906020666, 0.020959770306944847, 0.045551545186234374, 0.05265461939520069, 0.031348684270467074, 0.026337095868906805, 0.024867399196539606, 0.031947179298315725, 0.026447990543342063, 0.03680654176111732, 0.021382392450634922, 0.00452277940764491, 0.02399098301040275, 0.03611052768038852, 0.0442873157028641, 0.034202361678970714, 0.01154963717064155, 0.04245932539924979, 0.043538213042276244, 0.02446436126982527, 0.04496516879381878, 0.032315868086048534, 0.08541324854429279, 0.028981323087854043, 0.06124382439468588, 0.0380019372595208, 0.02226961769961885, 0.025649655078138624, 0.11383440026215144, 0.037233757586883645, 0.08567111899277993, 0.0077083664613642865, 0.014238266873040369, 0.02691102453640529, 0.055177310814282725, 0.02116884390956589, 0.06319349977586951, 0.06520184129476547, 0.16081788843231543, 0.18113060774547712, 0.22531336120196752, 0.06430480442941189, 0.1299545331192868, 0.13363468992922986, 0.15896467358938285, 0.05974291171878576, 0.1675161961466074, 0.07355006118970257, 0.07130405599517481, 0.21662453029836926, 0.17125548049807549, 0.14320586062967777, 0.11432542891374656, 0.10998205162052598, 0.27066064359886305, 0.09026859407978398, 0.1934584898075887, 0.19208688555019243, 0.13605624570378236, 0.1518729512712785, 0.0979817391240171, 0.12660326223288262, 0.09464764195893492, 0.11696650433753218, 0.1223214077098029, 0.17171092677329267, 0.09837340310748134, 0.23427129909396172, 0.09252616151102952, 0.16480475664138794, 0.14235237214182103, 0.13023860859019415, 0.13835490521575722, 0.17713027740163462, 0.12825162735368523, 0.12515962469790662, 0.14344688983900206, 0.1873859813702958, 0.19635796493717603, 0.14706573422466004, 0.1127372362783977, 0.18477678352168628, 0.10150004497596196, 0.16435749349849565, 0.09627685203616108, 0.11607123166322708, 0.1271335780620575, 0.08203527051955462, 0.09698468619691474, 0.165467305374997, 0.19668514095246792, 0.1133463503792882, 0.1027195556089282, 0.17857713119259902, 0.13373921146350248, 0.10642548317887954, 0.13341134334249155, 0.09716590254434518, 0.1588455228401082, 0.13809170148202352, 0.14120361235524925, 0.12191093473562173, 0.22166808109198297, 0.14353907560663565, 0.18965994220759186, 0.9219523455415453, 2.9985702293259755, 7.195809807096209, 11.636463454791478, 21.006483588899883, 28.406561749322073, 32.96781267438616, 54.013777664729524, 67.48046003069196, 67.82841886792863, 69.77945913587297, 75.43561240604946, 75.65097876957485, 66.919969694955, 58.49509825025286, 70.82797704424176, 62.417995589120046, 66.30524172101701, 64.11790016719273, 61.986095564705984, 69.5914478302002, 64.3963839667184, 65.80202538626534, 71.7279702595302, 71.66688169751848, 68.03270980290004, 62.90587724958147, 68.06359454563686, 76.28924724033901, 68.31864901951381, 69.22518048967633, 69.77273327963692, 62.33070537022182, 71.09200164249965, 79.06958280290876, 78.96885476793561, 83.00639738355363, 76.88491630554199, 72.56433882032121, 63.22595991407122, 60.32833181108747, 54.63271624701363, 44.81432104110718, 39.460529054914204, 30.225171089172363, 20.38640376499721, 12.391710928508214, 4.355963792119708, 1.598131816302027, 0.38662203401327133, 0.16448664585394518, 0.13974412424223764, 0.09250751536871706, 0.10448798750128065, 0.25900430764470783, 0.1473979042576892, 0.12304966577461787, 0.1913170875715358, 0.14145673305860587, 0.11003456344561917, 0.21328982923712048, 0.06215320381202868, 0.05344452236645988, 0.15874560177326202, 0.13112161335136208, 0.07552789577416011, 0.10389664423252855, 0.13269035917307648, 0.14725820746804985, 0.18425072889242852, 0.20282904484442302, 0.11857039827321257, 0.0973947656207851, 0.16252622247806617, 0.14403034853083746, 0.14047757988529547, 0.12623280925410135, 0.1822704380112035, 0.12902574081506046, 0.07380897658211844, 0.11981325729617051, 0.12355529649981431, 0.10837808983134371, 0.0921264501022441, 0.07900137760277305, 0.13859129324555397, 0.11775521987250873, 0.12814650870859623, 0.15828356013766356, 0.179654400529606, 0.07587169589740889, 0.1665541013436658, 0.10895773515637432, 0.17538029487643922, 0.12781846416848047, 0.17214802546160562, 0.24097207667572157, 0.14163160510361195, 0.07036151657147066, 0.20745680294930935, 0.07045158530984606, 0.2159295068787677, 0.1606537779527051, 0.13630955639694417, 0.13388844845550402, 0.10456460089023624, 0.15009779509689125, 0.15446176592792782], [0.04363456501492432, 0.04093017888122371, 0.030149536473410468, 0.02928114396386913, 0.038050025036292415, 0.035367735395474095, 0.028071757073381116, 0.07277809189898626, 0.033452675478266816, 0.01804400185522224, 0.030512043807123388, 0.019437290395476987, 0.07668553079877581, 0.04400261937241469, 0.031643127756459374, 0.059877872333994935, 0.03368489730304905, 0.061718697127486975, 0.01312272307196898, 0.017493212928197215, 0.022863980449203933, 0.0399104594918234, 0.017790507957605377, 0.034636827651411295, 0.055399500498814244, 0.06672634663326399, 0.0380286952879812, 0.049630867184272835, 0.022038981950442706, 0.043319317645260265, 0.08445841406605073, 0.027653569156037908, 0.04204356324459825, 0.020604177245071957, 0.030424580643219606, 0.02644846891053021, 0.032348570081272295, 0.031163600273430347, 0.052084253036550114, 0.019605568776439344, 0.044814411883375475, 0.04925479932821222, 0.03178356075659394, 0.035970457696488926, 0.05698067708207028, 0.019038213416934013, 0.020206246990710497, 0.0723573255485722, 0.010614698187315037, 0.029655932781419585, 0.06724410277924367, 0.05331202144069331, 0.04398494014250381, 0.040209496659891944, 0.019956742879003286, 0.011741725345408278, 0.014925349736586213, 0.08099929682378258, 0.04200243723711797, 0.06239960023335048, 0.03715021296271256, 0.038360763540757556, 0.05109316443226167, 0.015061499484415566, 0.023023941687175205, 0.023119842434035878, 0.09351105509059769, 0.030685721630496637, 0.044948096852749586, 0.051198354323527644, 0.08172599425805466, 0.037374400932873995, 0.07568821324301617, 0.06208616455218621, 0.2893041531954493, 0.8340898230671883, 4.195040907178607, 7.691707951681955, 15.915204967771258, 28.250626802444458, 40.240777015686035, 57.36084304537092, 61.656716210501536, 57.767524582999094, 60.580349922180176, 58.42039816720145, 58.13901349476406, 63.029603821890696, 62.69606944492885, 62.56622150966099, 60.66752896990095, 58.73502649579729, 59.54175404139927, 58.18230077198574, 55.489818232400076, 53.49781138556344, 51.84544290815081, 51.58803299495152, 46.59942443030221, 49.28599057878767, 50.71141699382237, 41.3677122933524, 33.1051299231393, 18.828688859939575, 17.11959876332964, 9.870582256998334, 8.338278651237488, 5.972791799477168, 2.6666250356606076, 1.2701227771384376, 0.13803550521177904, 0.13613521360925265, 0.05514633908335652, 0.06424064894339868, 0.07769309423331704, 0.009122016989359898, 0.020419093248035227, 0.04177166069192546, 0.012501386010886302, 0.05911447972591434, 0.007648447578373764, 0.018578507638137256, 0.042909340001642704, 0.012895707307117326, 0.07524130972368376, 0.06789171695709229, 0.031173907220363617, 0.04020667056153927, 0.025927467670823847, 0.05817183173660721, 0.09607024490833282, 0.02576063117677612, 0.010952434752003422, 0.06895709836057254, 0.04092494737622993, 0.038839564991316626, 0.04694623320496508, 0.017790865884827714, 0.04473082654710327, 0.045407475238399844, 0.06617340166121721, 0.09311737585812807, 0.004792448731937579, 0.03579148051462003, 0.04478474972503526, 0.06587165035307407, 0.06669229774602822, 0.03737239586189389, 0.03828657930716872, 0.019298278926206485, 0.049386750640613694, 0.04910885323105114, 0.03983298436339412, 0.027238848552639996, 0.013993373406784875, 0.016655773489869068, 0.009736772260761686, 0.06527987960726023, 0.05847077390977314, 0.013511008799209126, 0.018678713689691255, 0.007606827936667416, 0.02924323421237724, 0.048591022446219406, 0.03409867474277105, 0.0067886864583540174, 0.006375501888604569, 0.009761514192047929, 0.03686876342232738, 0.014719561939792973, 0.031101052915411334, 0.07284314983657428, 0.03116654172273619, 0.0801496488441314, 0.0743448156863451, 0.01950454678652542, 0.03587020414748362, 0.06888592003711633, 0.04271391173824668, 0.034747238869645765, 0.02128171142456787, 0.06307173666677304, 0.04299871663429907, 0.023040838905477097, 0.011848296055437198, 0.04158842570281454, 0.02839274993831558, 0.012548060738481581, 0.050420515704900026, 0.02322416380047798, 0.019227906363084912, 0.06190942653587886, 0.06933217216283083, 0.0098191116371059, 0.047723403466599326, 0.059279017682586393, 0.013123872340656817, 0.011729301369216825, 0.06810850211020027, 0.055200411538992605, 0.03107194376311132, 0.034933286386408975, 0.08016359273876462, 0.04099545734269278, 0.018388226062857678, 0.04493598160999162, 0.03815324717600431, 0.014078132608639342, 0.03909274676282491, 0.03488604338573558, 0.03931868535333446, 0.025173857841374617, 0.01626149714658303, 0.04214621541489448, 0.03364889084228447, 0.028702058430228914, 0.0258871287639652, 0.05511054636112281, 0.013091637686427151, 0.029866668794836317, 0.038666871043720415, 0.0342861064709723, 0.05373623814167721, 0.07382834875690085, 0.061111822192158015, 0.05451874168855803, 0.04056971054524183, 0.021391975061435784, 0.06320618159536805, 0.027521185277562057, 0.026776559251759733, 0.06276421102562121, 0.03369213387902294, 0.015436030458658934, 0.07327981426247529, 0.021616543011207665, 0.04217354341277054, 0.07053305700953517, 0.04058190381952694, 0.028344675732244338, 0.04843766335397959, 0.05984171320285116, 0.06717531968440328, 0.009971083125232585, 0.0365199421399406, 0.055285211452948194, 0.03097599551879934, 0.08148814059261765, 0.3231138161250523, 0.3980301889990057, 1.4380114482981818, 3.548315393073218, 11.672911099025182, 17.835270166397095, 27.425813095910208, 44.2425468308585, 54.336240087236675, 70.07884311676025, 67.41449383326939, 66.37068680354527, 66.59987313406808, 64.4653239931379, 65.7944449016026, 69.80668912615094, 71.78088079180036, 69.14692987714494, 69.8885111127581, 70.78543322426933, 70.90463651929582, 69.60759544372559, 68.86761924198696, 66.62754780905587, 66.98152378627232, 65.09109265463692, 58.574217387608115, 57.888854026794434, 59.03520951952253, 55.527324608394075, 48.978369508470806, 35.62546042033604, 33.16028124945504, 21.53620730127607, 18.920865399496897, 14.184980188097272, 8.776744723320007, 4.890698458467211, 1.3828337405409132, 1.0908244039331163, 0.031427879485168626, 0.11783113437039511, 0.0319960406050086, 0.0962961767134922, 0.06909705977886915, 0.025603898069156066, 0.018886550662240813, 0.0167986102003072, 0.05301695030980876, 0.00884625272426222, 0.03826266434043646, 0.031853755204273124, 0.009068759623914957, 0.05486748833209276, 0.03932045293705804, 0.07215913225497518, 0.08988227016691651, 0.05886135223720755, 0.054096648802182505, 0.050070021833692274, 0.0560990022495389, 0.01802591041528753, 0.012173802026414444, 0.06634182083819594, 0.02566296623886696, 0.03041187846767051, 0.029572282984320606, 0.027522625468139137, 0.007835509504989853, 0.02134732067185853, 0.006865112402010709, 0.04208483513710754, 0.03339678794145584, 0.03983277062486325, 0.04317443006272827, 0.054834586169038496, 0.013400081894360483, 0.022719566144847443, 0.05092924054978149, 0.024019841104745865, 0.05783837927239282, 0.006874369740087006, 0.07456044732992138, 0.04868228201355253, 0.01803908247633704, 0.034306971422795735, 0.04620089302105563, 0.00932084980221199, 0.04368407432256, 0.023039466568401883, 0.05828420392104557, 0.007686375989578664, 0.0549269585338022, 0.0070166708319447935, 0.03174210905230471, 0.02641460662042456, 0.056879867134349685, 0.04835842064182673, 0.06412276705460888, 0.016643062832632234, 0.05037657038441726, 0.06987750397196837, 0.003121413756161928, 0.03426128565999014, 0.1576916876115969, 0.11130275896617345, 0.08046610400612865, 0.10971935678805624, 0.12181474561137812, 0.1262813245079347, 0.08472878991493157, 0.1484744679182768, 0.09454075233744723, 0.09361426026693412, 0.11921731355999197, 0.14206012710928917, 0.1689819132110902, 0.15102513533617767, 0.079319495175566, 0.13888575030224665, 0.20529896659510477, 0.17835088047598088, 0.23814060432570322, 0.11858761949198586, 0.0939685030441199, 0.09989602211862803, 0.09164538913007293, 0.09174891321786813, 0.15262915140816144, 0.10526487617088215, 0.19352535264832632, 0.18984609150460788, 0.13085755466350488, 0.1590999056185995, 0.1911491094423192, 0.0839204036497644, 0.12599236358489307, 0.1760174256882497, 0.15816126098590239, 0.10376128328165837, 0.12134996269430433, 0.08763855163540159, 0.17655468971601554, 0.1115058512826051, 0.12734965075339588, 0.09912842259343181, 0.07821681470211063, 0.11757010194872107, 0.19594959542155266, 0.1331113087279456, 0.10197326886866774, 0.157304691949061, 0.11043479732636895, 0.14191850328019687, 0.20370943046041898, 0.09319766690688473, 0.18372016879064695, 0.18663096188434533, 0.05301552199359451, 0.09507347018058811, 0.12271889352372714, 0.1815173319940056, 0.1755282969347068, 0.1054455836170486, 0.0897033472678491, 0.2198102114988225, 0.160975132137537, 0.1214329610977854, 0.23951393206204685, 0.15729747233646257, 0.21376325669033186, 0.14638300585959638, 0.08983127147491489, 0.13814759919685976, 0.1816825552710465, 0.2163581374500479, 0.16704103164374828, 0.12240778521767684, 0.495468333363533, 1.356421792081424, 6.76687970331737, 13.354382974760872, 22.987385477338517, 41.98426069532122, 57.058665888650076, 74.16742025102887, 80.96510001591274, 77.57638018471854, 80.90225355965751, 78.19540909358433, 79.13704981122697, 84.2364022391183, 82.94927624293736, 83.57170282091413, 81.82377229418073, 82.46762711661202, 81.01689883640834, 78.13645362854004, 77.85943589891706, 74.94505568913051, 72.73976693834577, 72.06642396109444, 65.06623894827706, 68.40886443001884, 71.8032123020717, 57.58363355909075, 48.30984858104161, 30.451157774244034, 26.92516933168684, 15.967549221856252, 13.274307591574532, 8.62248342377799, 4.501179839883532, 2.0047025084495544, 0.4306979589164257, 0.31363726034760475, 0.11884828550474984, 0.20606904955846922, 0.2080381174704858, 0.1827402827995164, 0.10103846474417619, 0.1422084548643657, 0.1696676542716367, 0.18301479092666081, 0.11743941610412938, 0.16087001349244798, 0.17565039252596243, 0.22795557656458446, 0.16402997821569443, 0.1304953119584492, 0.20488021549369606, 0.14059081380920752, 0.18795273452997208, 0.1311755840267454, 0.19633840955793858, 0.2117015958896705, 0.1079730587080121, 0.14113370967762812, 0.15585608753774846, 0.12304921794150557, 0.1843876979712929, 0.15457106434873172, 0.11191898411405937, 0.10366662764655692, 0.1269720731569188, 0.12130994269890444, 0.11420224766646113, 0.1266485612307276, 0.13702447446329252, 0.08133713262421743, 0.15315752662718296, 0.14875846196498188, 0.0906027386497174, 0.10441816624786172, 0.12904419696756772, 0.12965603199388298, 0.2211587591362851, 0.16173054517379828, 0.12542658751564367, 0.12953010946512222, 0.08478787674435548, 0.15786506687956198, 0.3573479705623218, 0.0834398583642074, 0.09744163881987333, 0.09316228130566222, 0.16178524866700172, 0.0989555793681315, 0.09635077164109264, 0.06857500172087125, 0.08416040148586035, 0.05140315654820629, 0.19738993527633802, 0.18884253821202687, 0.11390883555369717, 0.14400746833000863, 0.13824327263448918, 0.2404792159795761, 0.13143795994775637, 0.13523752535028116], [0.07330216520598956, 0.0210011609430824, 0.0253381820595158, 0.019932965315612297, 0.040990690634186776, 0.03577095143763082, 0.013504478747823408, 0.050462455954402685, 0.020515960907297473, 0.013876622975138682, 0.039382681383618286, 0.030497906530009847, 0.06470290092485291, 0.06023472747100251, 0.044844844178961854, 0.07710514363965817, 0.007302461724196161, 0.04271621875731008, 0.037499444758785624, 0.026905002538114786, 0.040418573655188084, 0.04431634682363697, 0.008802852776300694, 0.028933238703757524, 0.028258118412590454, 0.05255395193983402, 0.004114151624630072, 0.0792524694864239, 0.013658910773561468, 0.004663272203677999, 0.047461119147815874, 0.035165012880627594, 0.03427835420838424, 0.02540689899719187, 0.025102445423336964, 0.0067944841160039815, 0.03179994059194412, 0.06141412989901645, 0.010256974525483591, 0.020793656452691982, 0.07687161224228994, 0.03789942079622831, 0.04060955412153687, 0.04512562196967857, 0.018794439533459287, 0.026112563542223403, 0.03589585616386362, 0.06817879833813224, 0.021690255662958537, 0.025985974352806807, 0.07059990627957241, 0.0006630926218349487, 0.03202062392873423, 0.019280480952667337, 0.060627314262092113, 0.044506238241280825, 0.007427708262444607, 0.018320213105263453, 0.05425386197332825, 0.015709590333114778, 0.062385730977569304, 0.09404601209930011, 0.04794707575014659, 0.0306544140247362, 0.06574721381600414, 0.03838507205780063, 0.06326876288013798, 0.01850439465072538, 0.02119791574243988, 0.014022043207660317, 0.01760981577847685, 0.03242316482854741, 0.015073087166196533, 0.054211585848991356, 0.028545700213206664, 0.08045544422098569, 0.10653907672635146, 0.1686772374170167, 0.0734403081504362, 0.1274096875318459, 0.6238520443439484, 2.1324609901223863, 4.69447351353509, 9.2755845614842, 8.407534820692879, 12.370451177869525, 11.020359737532479, 8.691737856183734, 11.185380322592598, 14.446207267897469, 11.081582920891897, 10.935700280325753, 9.302534018244062, 8.757611121450152, 6.321118891239166, 5.509418606758118, 7.107289322784968, 4.402044679437365, 3.8502348150525774, 5.277817777224949, 2.5938541633742194, 1.7915103882551193, 0.43806106810058865, 0.03536071255803108, 0.08332612910973174, 0.11411135111536298, 0.16067243766571793, 0.19680630016539777, 0.19358514515416964, 0.14007083885371685, 0.08867770766041108, 0.017833715371255363, 0.014604524809068866, 0.05734666530042887, 0.08339218449379716, 0.03896705154329538, 0.051010963307427507, 0.0454217550078673, 0.025969289176698242, 0.06712531165352889, 0.045272684256945334, 0.03957143286243081, 0.0404524495159941, 0.05058707908860274, 0.05726561429245131, 0.06214825050639255, 0.021643511385523846, 0.03883382458505886, 0.041210559728954516, 0.08247200279895749, 0.00815394429290401, 0.06093074155173131, 0.03838470904156566, 0.08812947850674391, 0.04553888711546149, 0.03820303807567273, 0.021107616302158152, 0.06020444445312023, 0.013218890143824475, 0.04048931432355728, 0.01471053233503231, 0.017910863106538142, 0.022251617861911654, 0.13237630602504524, 0.040301316018615446, 0.03969737235456705, 0.014339036108659846, 0.06852569258106606, 0.030635757704398463, 0.04316458112693258, 0.024949137221223543, 0.01191173229433064, 0.04968529587079372, 0.04395333398133516, 0.03583103571353214, 0.07477394158818892, 0.04912579285779169, 0.056832386646419764, 0.005658029986079782, 0.0582932759342449, 0.030698915743934255, 0.029985836507486444, 0.06458106996225459, 0.010575796078358377, 0.021397963132975355, 0.03301754114883287, 0.03166612670091646, 0.04481788258999586, 0.008275257872550614, 0.03683486381279571, 0.007973363223884786, 0.01079859389990036, 0.05044043410037245, 0.06756591158253805, 0.03828045213595033, 0.02300108184239694, 0.030780655464955738, 0.018109809574005858, 0.03136698096724493, 0.016215933520080786, 0.022773462181378688, 0.047137308666216474, 0.015578208990128977, 0.008519397316766637, 0.03119982386540089, 0.051876394011612446, 0.01193350987575416, 0.013351468252949417, 0.009729882585816085, 0.025638332025014927, 0.04695093205996922, 0.05320264159568718, 0.03127966368837016, 0.04269915360159107, 0.005933152611500451, 0.008455906795071704, 0.045620555590306006, 0.035012216972453256, 0.021396748555291976, 0.04415857386110084, 0.07734238662357841, 0.040523074833410125, 0.0067646362087024105, 0.01953007836293961, 0.03546017900641475, 0.013438481039234569, 0.022372548069272722, 0.0372929733379611, 0.042094120888837745, 0.027993974907855903, 0.01834791260106223, 0.026005553480769907, 0.04558077308216265, 0.058812660564269335, 0.014582470724625247, 0.01589586685544678, 0.0552766245922872, 0.027389340834426026, 0.06629135818885905, 0.047250963281840086, 0.030079494696110487, 0.0577620305120945, 0.03661973089245813, 0.03700370368148599, 0.015976069694651023, 0.015293648366683295, 0.06216775838817869, 0.03727833394493375, 0.010247419056083475, 0.06470766424068383, 0.02370363530436797, 0.013586200657300651, 0.0166306541234787, 0.05992607546171971, 0.06979856320789882, 0.04019791745979871, 0.04698515058095966, 0.01980831504001149, 0.06999214246336903, 0.02597098721058241, 0.07300603895315103, 0.04068765010950821, 0.020642707856105905, 0.025900706249688352, 0.0437018451546984, 0.041811653545924594, 0.0435615308981921, 0.03616833207862718, 0.07694063282438687, 0.058321923682732243, 0.061142037356538434, 0.08597610691296202, 0.059729822778276036, 0.2996186725795269, 0.4848638081124851, 0.8504840433597565, 3.7984303491456166, 7.139992322240557, 12.80574105467115, 18.97938139098031, 20.758113282067434, 25.174172912325176, 24.76301326070513, 23.32178143092564, 22.553812674113683, 26.307570014681133, 22.647088766098022, 21.45108492033822, 19.659389427730016, 18.637356315340313, 14.944506883621216, 13.838892153331212, 15.711131164005824, 12.825493046215602, 12.598565748759679, 13.551028285707746, 8.879673600196838, 5.901750811508723, 2.6288042536803653, 0.3582944454891341, 0.29781018676502363, 0.2588938150022711, 0.1812041609414986, 0.09490936648632799, 0.17347768268414906, 0.1687102820724249, 0.1145910346614463, 0.08150103954332215, 0.060152441529291015, 0.034168930258601904, 0.03270750492811203, 0.04913862395499434, 0.020892242501888956, 0.015110742467056428, 0.02418339348930333, 0.04639416354309235, 0.049828483723104, 0.03890271285282714, 0.05092693692339318, 0.021208541600831916, 0.003508664929540828, 0.05287996766024402, 0.04699440240593893, 0.009072005565810417, 0.03145770788458841, 0.017648370138236454, 0.03165503604603665, 0.016296146537310312, 0.00954029057174921, 0.01722476920778198, 0.02595626639335283, 0.040195712220988104, 0.021789337042719126, 0.0760063850986106, 0.03760238191378968, 0.023928598500788212, 0.027752525006820048, 0.015384901148666228, 0.04776516051164695, 0.018924923513882926, 0.014373514169294919, 0.02535204792262188, 0.04737631584118519, 0.03318749720762883, 0.11515153172825064, 0.010328665991047663, 0.03012605237641505, 0.03726820680978043, 0.029007287230342627, 0.03520311262192471, 0.019102090703589574, 0.02113887980314238, 0.012334685223842306, 0.03355459143806781, 0.018303495698741505, 0.0419265668440078, 0.0429500554954367, 0.017054909840226173, 0.02973200673503535, 0.02351455812874649, 0.01377311669888773, 0.048638068671737394, 0.025654392948906337, 0.05945559963583946, 0.034495132576142035, 0.055143764042960744, 0.0566431025176176, 0.011927170662342437, 0.02992605757234352, 0.051015808047460656, 0.03144254941227181, 0.03072788579655545, 0.18005403051418917, 0.18149377325815813, 0.15648020404790128, 0.08302666446460144, 0.16354128372456345, 0.15009182398872717, 0.09583754810903754, 0.18406361607568605, 0.1679067744740418, 0.19058935876403535, 0.1262463799544743, 0.15961487298565252, 0.1560655648687056, 0.1577147985143321, 0.13178686265434536, 0.09914477528738123, 0.07945488326783691, 0.1638296746781894, 0.09252202244741575, 0.13412168808281422, 0.11404614390007087, 0.09014446288347244, 0.10492801067552396, 0.1937451165701662, 0.13743616880050727, 0.09505871882928268, 0.09623536640512091, 0.15007002944392817, 0.12153064299907003, 0.08732307356383119, 0.09990909070308719, 0.12936411265816006, 0.10010794896100249, 0.1278878240180867, 0.08728561843080179, 0.08947212967489447, 0.17953284776636533, 0.1579395971660103, 0.054245841689407825, 0.1354721084769283, 0.21209347700434072, 0.10534511972218752, 0.16093612994466508, 0.16275647655129433, 0.0742916999650853, 0.1383018573479993, 0.14269908996565, 0.10033622171197619, 0.07995266334286757, 0.06811329935278211, 0.1657454233084406, 0.12396141327917576, 0.08969631085970572, 0.21122545429638453, 0.13616133720747062, 0.2101758284760373, 0.10188165985580001, 0.16091299190052918, 0.1477490732712405, 0.17330686827855452, 0.11227874338094677, 0.16823799455804483, 0.17116496392658778, 0.1215730785791363, 0.17870674495186123, 0.10425227800650255, 0.1900166752082961, 0.14811683925134794, 0.16073620638677052, 0.06992619564490658, 0.17585183600229876, 0.10145167221448251, 0.18335518480411597, 0.10052624544394867, 0.13635214125471457, 0.1810050651963268, 0.17051279677876405, 0.3767855832619326, 0.25734979499663624, 0.3861710253570761, 1.6376792256321226, 3.4705083795956204, 6.995815898690905, 13.081828594207764, 14.27345073223114, 18.11235042980739, 18.92505690029689, 17.32000912938799, 16.518536158970424, 19.738937616348267, 17.182526860918315, 16.20606177193778, 15.210862602506365, 13.931157282420568, 10.90214569228036, 9.400829315185547, 10.323145355497088, 8.206081356321063, 8.2749571119036, 8.207580430167061, 4.473637614931379, 3.1191913911274503, 0.9404020926782063, 0.14956388303211757, 0.20596336094396456, 0.28532335108944346, 0.3268486628574984, 0.2599240211503846, 0.4385702136371817, 0.2930210866034031, 0.22060643163110527, 0.10008198142583881, 0.1142900093857731, 0.20608073393149035, 0.21195505586053642, 0.14432453417352267, 0.10408650511609656, 0.1722755493330104, 0.18712788021990232, 0.2717015706002712, 0.11767285929194518, 0.2036719210445881, 0.16173035518399306, 0.16656045243144035, 0.14116760928715977, 0.1659153691892113, 0.10421291619007077, 0.11418266514582293, 0.13186996962342942, 0.11192099257771458, 0.0856499554855483, 0.12123459817043372, 0.08291694535208599, 0.20319530447678907, 0.11086097160088164, 0.1112309428197997, 0.06979948601552419, 0.1355576581720795, 0.1852123351501567, 0.12780146008091314, 0.05954271674688373, 0.0917504331363099, 0.25490264488118036, 0.222401835290449, 0.09248099822018828, 0.10457328613847494, 0.08799305225589446, 0.15194528310426644, 0.22156373597681522, 0.11809949497027056, 0.18627374033842767, 0.07209469856960432, 0.16538759108100617, 0.1988310215196439, 0.15682426201445715, 0.16114073539418833, 0.11746824027172156, 0.16224876950894082, 0.1003906334351216, 0.18759862067443983, 0.10278368395354066, 0.12573579592364176, 0.10768648622823612, 0.1385155687374728, 0.09034007774399859, 0.12608824058302812, 0.06771382543125323, 0.1237689128943852, 0.18385184529636586, 0.11072969543082373, 0.07983792307121412, 0.08246508852711745, 0.1236010840428727, 0.13422379403242043, 0.07958947068878583, 0.09959163809461252], [0.06483554095029831, 0.017484302067064812, 0.11706106497773103, 0.025495385052636266, 0.025351097973595773, 0.058937124242740016, 0.03686113329604268, 0.04200388930205788, 0.030371624377689192, 0.059543924539216926, 0.03345544050846781, 0.04112019582784601, 0.013620530288400394, 0.06774534338286944, 0.044952866953930685, 0.024935038959873573, 0.05305896180548838, 0.048932943027466536, 0.028738203990672315, 0.06525923178664275, 0.013873722237933959, 0.0346930001729301, 0.023912486686770405, 0.05986019649675914, 0.029241612513682673, 0.013334123201535215, 0.01746868897628571, 0.004515272689916725, 0.06135648834918227, 0.007121491345709988, 0.05950233034257378, 0.009013782172197742, 0.025536763814410994, 0.054005524941853116, 0.04880919859611562, 0.07477723926837955, 0.014821062296895044, 0.07329919322260789, 0.018718287548316375, 0.009399641288577445, 0.048476794468505044, 0.016614126706761972, 0.029976700033460344, 0.008609032640898866, 0.017376528653715338, 0.012889865968775536, 0.03918692063806312, 0.017814696034682647, 0.02930491304557238, 0.06802916101046971, 0.032983692429427586, 0.012094713680978333, 0.03354608939428415, 0.029062611583088125, 0.0668317231216601, 0.014570830456380333, 0.037755082827061415, 0.10418888247971024, 0.022962537660662617, 0.023385801019945314, 0.06454731963042702, 0.02615222561040095, 0.03521579444142325, 0.014278685507763709, 0.03539662741656814, 0.011532153019548526, 0.08744974248111248, 0.05620288256821888, 0.006798623603702123, 0.04805098321022732, 0.07787955565644161, 0.11534082942775317, 0.0824399623753769, 0.009183372670252408, 0.014839701653857316, 0.049158423606838496, 0.046348694911492724, 0.1602784123803888, 0.09473834173487765, 0.1474876065871545, 0.06732972711324692, 0.04694008228502103, 0.039014121517539024, 0.22684603610209056, 0.20917314370828016, 0.24464191975338118, 0.19040103815495968, 0.23045033269694873, 0.27377780633313314, 0.33827744530779974, 0.2811306560678141, 0.2124281847583396, 0.3214348762163094, 0.22461917916578905, 0.11431468091905117, 0.1647205911576748, 0.2613211790365832, 0.18113907586250985, 0.1461391132324934, 0.1296690870076418, 0.07716959768107959, 0.1037106713546174, 0.041771511414221356, 0.06737860199064016, 0.016639739707378403, 0.042352361138910055, 0.16950251241879805, 0.0943687776369708, 0.11227127949574164, 0.043868754591260634, 0.11054240619497639, 0.021067567469019974, 0.051427783976708136, 0.045758746032203944, 0.013190284803775805, 0.04065968089603952, 0.014542915525713136, 0.07282779458910227, 0.023965853465987102, 0.02577726885543338, 0.05765158536710909, 0.08280958075608526, 0.03417969182399767, 0.05143806378224066, 0.06144999047475202, 0.028755408246070147, 0.01636345381848514, 0.01268693565257958, 0.026569019138280834, 0.024908080763582672, 0.06921133864670992, 0.047212890681943724, 0.011642179169159914, 0.07431738251554114, 0.057190466539136, 0.011614757872718786, 0.0047931438062473065, 0.011838626931421459, 0.025903461101864065, 0.0134827452711761, 0.03809615523953523, 0.020392660916383778, 0.06454904310937438, 0.03361104215894427, 0.019615385481821637, 0.03765882245664086, 0.012401379278994032, 0.006711657466699502, 0.04186314756848982, 0.03996982791328004, 0.031561279469834905, 0.04322886214192424, 0.005586066682423864, 0.02920026598232133, 0.026212827269253985, 0.05170908423938921, 0.049364898420338116, 0.007351077061944774, 0.03129940566473773, 0.06711967302752392, 0.0623631425467985, 0.068536169161754, 0.053870954484279664, 0.018230539613536427, 0.05568633760724749, 0.017346308400322284, 0.018379267704273974, 0.08289222632135664, 0.02761379343324474, 0.05966656295848744, 0.023883996697674905, 0.010359487596100994, 0.07842086375291858, 0.062261219801647325, 0.018910027973886048, 0.03410786210692354, 0.024692798565540994, 0.01514189231342503, 0.14054717043680803, 0.0693362026608416, 0.037167084735951254, 0.02217295190452465, 0.05645128406052079, 0.018695700813883116, 0.017994429783097336, 0.11294705966221434, 0.006453112724037575, 0.034050536075873036, 0.021973588138020465, 0.06553173145013196, 0.07912388031503984, 0.053096440687243424, 0.042970923839935234, 0.019854294269212654, 0.0228246389888227, 0.05725714617541858, 0.03771133088905897, 0.08365890982427768, 0.06407051985817296, 0.023868481994473507, 0.05552308547443577, 0.053310800077659745, 0.005593366446971361, 0.03858967072197369, 0.032885929103940725, 0.026994279086855904, 0.01678288515125002, 0.04313548893800803, 0.00919694421879415, 0.055647281131574085, 0.028790454579783336, 0.03042657214349934, 0.008755373984708317, 0.04160649848303624, 0.05164203819419656, 0.03872390530471291, 0.019152013917586634, 0.03461537576679673, 0.030374765994825532, 0.08345742563584022, 0.034432554684047184, 0.01852779053816838, 0.04852166938196335, 0.0700095808133483, 0.04429814512176173, 0.037234259702797444, 0.028105412410306077, 0.06717262590037924, 0.05571898192699466, 0.025931856096056954, 0.0517935822052615, 0.02164068359083363, 0.04209721500852278, 0.0889235951804689, 0.00861064755424325, 0.012906946391532463, 0.012802183977328241, 0.024227501658190573, 0.023601994151249528, 0.010845439109419073, 0.004200359922833741, 0.0662511685597045, 0.01913597165340824, 0.0259537218870329, 0.017903689295053482, 0.06850843065019165, 0.051560949866792986, 0.11305109265127353, 0.09380602104855434, 0.04240964645785945, 0.061979763475911956, 0.0542961550610406, 0.04895622695663145, 0.05887619858341558, 0.16273322994155542, 0.08923477134002106, 0.07241850226585354, 0.05376080110935228, 0.04232943004795483, 0.1397418307938746, 0.2085444810135024, 0.13061332276889256, 0.27316929612840923, 0.17763155193201133, 0.24935996372784885, 0.34885263070464134, 0.2744788687144007, 0.24025627651384898, 0.16937677987984248, 0.04574014738734279, 0.06922900091324534, 0.03462789473789079, 0.1438745433198554, 0.1039755374991468, 0.13664605548339231, 0.07821041611688477, 0.08654918401901211, 0.18323325206126484, 0.13938983396760055, 0.06072119636727231, 0.09841933314289365, 0.08727955232773509, 0.10944595467299223, 0.03432999411597848, 0.05057323697422232, 0.04744685294904879, 0.07463399374059268, 0.020581215620040894, 0.014192151088666703, 0.012909027797702168, 0.0102338771934488, 0.030876169446855783, 0.00862094686765756, 0.020306829629199843, 0.03844973983775292, 0.05362076505220362, 0.02271271463749664, 0.030910289580268518, 0.0406852955929935, 0.028083923206265484, 0.047605803169842274, 0.023729344996224557, 0.038558010278003554, 0.02884329210168549, 0.06666757871529885, 0.02876630551846964, 0.016130563636709536, 0.009162483969703317, 0.02648338462625231, 0.015732724984575595, 0.03156557459650295, 0.06813443571861301, 0.009544066619127989, 0.07034515709217105, 0.05247057016406741, 0.024988797593063543, 0.058571278516735346, 0.0468142377877874, 0.0074601091577538425, 0.005187873495742679, 0.009418012624207352, 0.06532048314277615, 0.008140574608530318, 0.08931264001876116, 0.010242327498937292, 0.04173683827476842, 0.010484282908562039, 0.05161864909210375, 0.0392891453312976, 0.077567198845957, 0.025456878190327967, 0.05162668294672455, 0.03401983575895429, 0.04106334477130856, 0.028843967244029045, 0.08390684652009181, 0.01807153850261654, 0.0646890520251223, 0.03597596740084035, 0.04045347749654736, 0.06976601388305426, 0.0191931212653539, 0.04547931174082415, 0.05754208338579961, 0.013854422157497277, 0.012913677458917456, 0.030002569181046317, 0.034488326869904995, 0.04243582773155399, 0.03437415656766721, 0.04120172859568681, 0.025303610700315664, 0.13009056581982545, 0.11870062271399157, 0.2202788892069033, 0.11790821594851357, 0.0969384168939931, 0.16054409955229076, 0.12333684893591063, 0.0714634642271059, 0.08719885415796723, 0.24722352836813244, 0.14744747802615166, 0.25333045210157124, 0.06720727189843144, 0.18615175331277506, 0.1961825229227543, 0.16100439056754112, 0.12063902084316526, 0.11423066471304212, 0.1762669501560075, 0.10162183522645916, 0.08064907775925738, 0.15360629611781665, 0.12735041071261677, 0.12554264414523328, 0.10045586779181447, 0.1225222676460232, 0.14236275372760637, 0.1385761754853385, 0.14314639382064342, 0.14572159706481866, 0.12822968353118214, 0.19166999363473483, 0.07890763120459658, 0.12194115668535233, 0.09754509505416666, 0.10682999861559697, 0.06465373427740165, 0.15824660712054797, 0.11706871885274138, 0.09108541453523294, 0.13617170522255556, 0.2025145302925791, 0.15161109103688172, 0.2258758803031274, 0.11859394343835966, 0.08352223251547132, 0.2238348333963326, 0.13821185646312578, 0.18049266269164427, 0.1276987705911909, 0.08390825787293059, 0.1765666997858456, 0.10127454064786434, 0.1808278997029577, 0.14518343737082823, 0.07904896326363087, 0.11333833688071795, 0.13282541478318827, 0.13329023841236318, 0.13913094571658544, 0.09086037161094801, 0.1096250879179154, 0.1498042879892247, 0.08268511029226439, 0.11204170395753213, 0.22433798068336078, 0.15939531262431825, 0.14151979610323906, 0.09167564500655447, 0.1147773875189679, 0.2642245760985783, 0.19013867580464908, 0.20174796214061125, 0.16101547782974585, 0.17141849175095558, 0.14808243752590247, 0.14112494300518716, 0.22882027445094927, 0.31887069238083704, 0.18549931475094386, 0.17532730129148277, 0.1256964544632605, 0.127314651917134, 0.3303149454295635, 0.280560632369348, 0.38396681791969706, 0.4733382665685245, 0.3687235830085618, 0.4196874797344208, 0.4966888821550778, 0.6362734692437308, 0.33414147581372944, 0.46848978102207184, 0.34182612917252947, 0.22330481612256595, 0.35499315549220356, 0.5799445318324226, 0.29229841966714176, 0.25715092995337074, 0.2324373817869595, 0.20997192870293344, 0.25043470891458647, 0.23602737486362457, 0.21141560695001058, 0.15995599968092783, 0.1327082724975688, 0.24107898665325983, 0.19822500832378864, 0.16383587648825987, 0.13708884029516152, 0.13828957586416177, 0.11663946402924401, 0.22231629916599818, 0.17600774977888378, 0.11115439049899578, 0.11673999577760696, 0.10411407399390425, 0.25467332718627794, 0.148621547168919, 0.132067491167358, 0.19797944650053978, 0.1450828377689634, 0.11566560342907906, 0.14956233597227506, 0.1913571889911379, 0.07282703462988138, 0.07935873485569443, 0.1569079253822565, 0.16624010247843607, 0.10457215977034398, 0.17939091181116446, 0.11741976572998933, 0.11582690477371216, 0.20677608304790088, 0.1297087405941316, 0.1334719636610576, 0.06485361033784491, 0.07080410460808448, 0.16665048045771463, 0.06894267270607607, 0.16064259569559777, 0.0794489596571241, 0.13959620360817226, 0.11221418755927257, 0.12828103506139346, 0.14487496178065026, 0.126425567482199, 0.15678093076816627, 0.08509817080838339, 0.0796119234125529, 0.0858053332194686, 0.18860673372234615, 0.16317826748958655, 0.11848908263657774, 0.12937260791659355, 0.18177926008190426, 0.14380564487406186, 0.062350528580801826, 0.14942970951753004, 0.14696016774645873, 0.1216546113469771, 0.17800366053623812, 0.15433691548449652, 0.09499436656811408, 0.12886798142322473, 0.09871146960982255, 0.12806919642857142, 0.17810297092156752, 0.06221055359180484, 0.0965694227655019, 0.08940766206277267, 0.11924410212252821, 0.11796110096786704, 0.09330495007868324, 0.07770056490387235, 0.13098103446619852], [0.00702485311610092, 0.05905605786080871, 0.01687232794107071, 0.021452308698956455, 0.06792514159211091, 0.021484266001997248, 0.054017867493842325, 0.06726514415017196, 0.05362385238653847, 0.02427546220964619, 0.02141084851297949, 0.04286443116143346, 0.020814032859301994, 0.046108361200562546, 0.030069333634206226, 0.014230216055044105, 0.034068079598780186, 0.02997671699683581, 0.04182855924591422, 0.024501945324508206, 0.07258344734353678, 0.04606588151572006, 0.11081176424132926, 0.020833415212109685, 0.017974440141447952, 0.018398790853098035, 0.04218375197212611, 0.04225816012227109, 0.03627084514924458, 0.04710570250504783, 0.010921855723219258, 0.03730786039627024, 0.02287820423953235, 0.10121381854904549, 0.016916464947696244, 0.06413373896586043, 0.03779114017795239, 0.027581539271133285, 0.03685346585033195, 0.028565906986062015, 0.04692035387935383, 0.045728629255401235, 0.033086290316922326, 0.0216249347930508, 0.01704895739177508, 0.0332893249578774, 0.027987924071827104, 0.04805106124175446, 0.030173743210200752, 0.010325705882028809, 0.05962549801915884, 0.021282281393983533, 0.07549548894166946, 0.0563912846014968, 0.028677176551095078, 0.04073646391874977, 0.028696168746267046, 0.05698757778320994, 0.017167850297742655, 0.018100679885329943, 0.0237088651130242, 0.045640348456799984, 0.036530408542603254, 0.06361482252499887, 0.026693006145900915, 0.05393807516832437, 0.043551756601248465, 0.04152098271463599, 0.01152086304500699, 0.027955301804468036, 0.042459050592567237, 0.05091508970196758, 0.09249670630586998, 0.048587429603295665, 0.05678967286699584, 0.028748039355767623, 0.07016252939190183, 0.11170538807553904, 0.0800177144951054, 0.02838961680286697, 0.04083748081965106, 0.008941089867481163, 0.03369582850219948, 0.05855358910879918, 0.070640679448843, 0.06519370565989188, 0.15719438929642948, 0.09784155378916434, 0.13745480137211935, 0.14243473272238458, 0.07600083468215806, 0.05192781678800072, 0.12289577403238841, 0.04720182716846466, 0.0325381832995585, 0.0658357897773385, 0.0740360618968095, 0.06810874638280698, 0.016412856256855384, 0.06811125696237598, 0.04017228240679417, 0.025495420675724745, 0.06935942212917975, 0.06973433308303356, 0.044259828249258656, 0.025275665235572627, 0.06777080880211932, 0.011341595789417624, 0.019259736440809708, 0.039854483745459995, 0.04141452057021005, 0.055961079828973324, 0.04704653425142169, 0.04550492983045323, 0.039949539716222456, 0.04697836183809808, 0.04423753498122096, 0.0378624745644629, 0.0508422320043402, 0.06092546254928623, 0.012714256016936685, 0.06716483631836516, 0.0449772093977247, 0.026213449825133597, 0.05223032466268965, 0.024258129032594816, 0.017406796404559697, 0.04430991431166019, 0.007357767417228648, 0.037312063920710764, 0.03567336453124881, 0.025115883809381297, 0.06027229116963489, 0.025533603537561636, 0.018528981367126107, 0.05942768470517226, 0.05614812479221395, 0.027999632193573883, 0.03130546158977917, 0.06269303948751517, 0.028240871748753955, 0.07798134269458906, 0.0487526834144124, 0.08939607947000436, 0.013509358262776263, 0.014236428043139833, 0.023133402956383567, 0.018768935098445842, 0.03374847264162131, 0.020835342251562645, 0.03755464018987758, 0.02552086064991142, 0.042244586029223034, 0.020946265763736198, 0.09157410902636391, 0.04483788240967052, 0.04406358913651534, 0.026531407942197154, 0.011552723656807627, 0.062112586705812385, 0.01995194224374635, 0.022323339013382792, 0.02509585515196834, 0.022424959810450673, 0.041514183793749125, 0.047703647919531376, 0.007337063617472137, 0.0467581602611712, 0.026947148044460585, 0.03671778259532792, 0.028089042752981186, 0.0009692621471393587, 0.024572692778227583, 0.057703242238078795, 0.035381224671644826, 0.02106648181299014, 0.004096996138936707, 0.03644424138058509, 0.027776027763528482, 0.023965415810900073, 0.06633889635226556, 0.03819359626088824, 0.04920289818463581, 0.020018011198512146, 0.016502214229798744, 0.022596306866034865, 0.023118544735812714, 0.040583630691149404, 0.03102229196312172, 0.06365934120757238, 0.05932027261172022, 0.022024678432249596, 0.013401489854524178, 0.06309177380587373, 0.028272538978074278, 0.09352134846683059, 0.07192024721630982, 0.025431607849895954, 0.02765455303181495, 0.07690511151616063, 0.0275813068728894, 0.023381482144551616, 0.04687390137197716, 0.049417152402124236, 0.021480386478028128, 0.023322566645219922, 0.0721571645034211, 0.02764285508809345, 0.01650029736837106, 0.041833841641034396, 0.023129263892769814, 0.04886804115293281, 0.041012190016252656, 0.03757492160158498, 0.06038412731140852, 0.022229903044977357, 0.035391043073364666, 0.01898896534528051, 0.04514554715050118, 0.04410709001656089, 0.0601315155093159, 0.013224728089491171, 0.01719406889086323, 0.027781914054815258, 0.01576950667159898, 0.03437402086066348, 0.00728602845421327, 0.019194439319627624, 0.025294433514188443, 0.013461199239827693, 0.04257285787857004, 0.05363896336140377, 0.09264741571886198, 0.04424627111958606, 0.013284703799789506, 0.012055595288984478, 0.02154401609940188, 0.07425343737538372, 0.019879591751045415, 0.01354653010743537, 0.007043647687948708, 0.07160403632691928, 0.06610558887145349, 0.03551715898460575, 0.018973045217405473, 0.04962631082162261, 0.0763599154140268, 0.011422249854409268, 0.07398895121046475, 0.03886901680380106, 0.03342462484059589, 0.02044507265756173, 0.09543083421885967, 0.03323135771123426, 0.04843401283557926, 0.020616747106292417, 0.05758118735892432, 0.07047856386218752, 0.05505821434780955, 0.03501958247008068, 0.04336964798026851, 0.05078215790646417, 0.01889762096107006, 0.06152498895036323, 0.060167091100343635, 0.027644955153976167, 0.11477814747818879, 0.030390759065215076, 0.04278879486290472, 0.06288988928177527, 0.09526608591633183, 0.07406226691922971, 0.04015563455011163, 0.04887459919388805, 0.05536422346319471, 0.02437833320748593, 0.01696081060384001, 0.008984876580403318, 0.03527025366201997, 0.013767998848509575, 0.00775160695359643, 0.06338433096451418, 0.04902300837316683, 0.040480235525007756, 0.12160942091473512, 0.050133128983101675, 0.02955027130831565, 0.054383282350110154, 0.051649261199470074, 0.04665678712938513, 0.07400438109678881, 0.009637126000598073, 0.05342249372707946, 0.044167910502957444, 0.042780353887272735, 0.034209974841879945, 0.03370654596281903, 0.017504457949793766, 0.04640566471165844, 0.012560986830586833, 0.0374699352708246, 0.03262505953067115, 0.02800304861739278, 0.017745071556419134, 0.017776945738920143, 0.054566846428705115, 0.039451148959675005, 0.0341705892767225, 0.09127513292644705, 0.006406933751090297, 0.05382475982021008, 0.049547132570296526, 0.0408661251754633, 0.039566822216979096, 0.03824429979015674, 0.04535006099779691, 0.02560197951139084, 0.03185477300680109, 0.07199505570211581, 0.045311136836452146, 0.06457970610686711, 0.0283442414698324, 0.028797585982829332, 0.04067077494359442, 0.011819319217465818, 0.03946119806330119, 0.05205212101074202, 0.03694156344447817, 0.011497546885428684, 0.030818585572498183, 0.07082111548100199, 0.06059249863028526, 0.02239288037110652, 0.037241635378450155, 0.028436211802597557, 0.020651581397812282, 0.028510966005602052, 0.040392385596143346, 0.04714777846155422, 0.03397356645603265, 0.018613469154973115, 0.03578741269718323, 0.016989263273509483, 0.03082661603444389, 0.02832975305084671, 0.07164081971028022, 0.012017526081763208, 0.04243045712688139, 0.03406923310831189, 0.03431943611108831, 0.01182966263565634, 0.042202645779720376, 0.114878652085151, 0.1287124611969505, 0.08961473059441362, 0.12712129657821997, 0.09301210114998476, 0.10380258570824351, 0.1793230175971985, 0.2388604756976877, 0.13290510193577834, 0.18096378312579223, 0.1593780778348446, 0.14805440045893192, 0.10553781688213348, 0.1534298634422677, 0.09691244257347924, 0.09540737047791481, 0.09370863091732774, 0.2585679010621139, 0.09637879513736282, 0.14968303378139222, 0.2236478291451931, 0.10604555106588773, 0.18322011562330381, 0.22495869094771997, 0.13247508715306008, 0.14774057801280702, 0.09122011730713503, 0.1552813412355525, 0.11886721663177013, 0.1207222363778523, 0.14129663950630597, 0.06624555707510028, 0.06345113952245031, 0.15009504024471554, 0.055654616095125675, 0.12706261686980724, 0.12686083412596158, 0.09027665507580553, 0.11737524026206561, 0.1018501894016351, 0.10511860437691212, 0.13703881869358675, 0.14988875202834606, 0.21693288375224384, 0.17854548431932926, 0.11821483235274043, 0.13554995001426765, 0.08401841124785797, 0.09178339636751584, 0.09583555321608271, 0.18398478387721948, 0.09350703137793712, 0.16418579699737684, 0.15566752265606607, 0.10573508058275495, 0.12411663495004177, 0.13760668465069362, 0.1521510827754225, 0.165590798748391, 0.15541566402784415, 0.1463747141616685, 0.12656409719160625, 0.11146906111389399, 0.10844371773834739, 0.10356812471789972, 0.17662071117333003, 0.13524804264307022, 0.11660621581333024, 0.1548856331833771, 0.15347316754715784, 0.12042969278991222, 0.16972865456981318, 0.19552929726030144, 0.22089201344975404, 0.18068011477589607, 0.1011572355138404, 0.2311325589460986, 0.17429991784904683, 0.21147411023931845, 0.13044098844485624, 0.11210549303463527, 0.15989514866045543, 0.1408249083906412, 0.12641066685318947, 0.15680698651288236, 0.1292137357273272, 0.21486732816057547, 0.2126316638397319, 0.27852915280631607, 0.22861760961157934, 0.2548289831195559, 0.22497079601245268, 0.23134798024381908, 0.13367248432976858, 0.33432022907904213, 0.15509321061628206, 0.244195606559515, 0.17522785519914968, 0.21066069602966309, 0.1577124372124672, 0.18823372945189476, 0.11040169838815928, 0.1336083220584052, 0.13961035784866127, 0.1433765393282686, 0.1306240979049887, 0.15518847693290028, 0.12904034288866179, 0.1764639424426215, 0.07979284120457512, 0.09237415609615189, 0.10589112328099352, 0.13072468393615314, 0.22442635308418954, 0.18530393737767423, 0.14786701622818196, 0.11678472480603627, 0.10702147441250937, 0.1568483364369188, 0.12976755600954804, 0.06762391954128232, 0.17197689892990248, 0.13108783587813377, 0.11092849940593753, 0.09976874251982995, 0.10257230672453131, 0.08683699143252202, 0.07765643977160964, 0.09749469347298145, 0.09657875940735851, 0.14067591567124638, 0.08232545280562979, 0.18123803340962955, 0.14517925759511335, 0.15072288869747094, 0.11601403116115502, 0.15526089019009046, 0.1319385152310133, 0.11792307586542197, 0.10735197524939265, 0.08149737545422145, 0.15884287655353546, 0.13740585185587406, 0.1475513753082071, 0.11908380500972271, 0.11175091098994017, 0.08914707068886076, 0.1006155406524028, 0.1360991969704628, 0.21656927040645055, 0.1658556173954691, 0.1416845444057669, 0.1421391221561602, 0.07882921291249138, 0.1361358921442713, 0.2089724194790636, 0.14479531534016132, 0.10379256374601807, 0.09916264789977244, 0.113193632502641, 0.06765277085027524, 0.10612330439367465, 0.09102484849946839, 0.057340918108820915, 0.13444290656064237, 0.11419935710728168, 0.10580005709614072, 0.15664138325623103, 0.12494535690971784, 0.09930229719196047, 0.1552842589361327, 0.09339744797242538, 0.11958250110702855, 0.10148646070488862, 0.07839642292154686, 0.17863388386155876], [0.06370741541364364, 0.016340716110010232, 0.026336227344082933, 0.01758262518394206, 0.016770216902451854, 0.03042762048010315, 0.052807038716439686, 0.08099565987608262, 0.0712511438344206, 0.061037352973861356, 0.020170286331059675, 0.009896225445637745, 0.05730505074773516, 0.034580271757606945, 0.06635470621820007, 0.024547352887956158, 0.023891869400228773, 0.00642339331430516, 0.019504394116146222, 0.04150263512773173, 0.028812093061528037, 0.0727236530344401, 0.019179969560354948, 0.034332813428980966, 0.07559610889958483, 0.00331720821642583, 0.07681778405926057, 0.024260503905160085, 0.0036900922589536223, 0.013020416954532266, 0.022810839282880937, 0.020877326605841517, 0.10384092293679714, 0.04298919339531234, 0.01849015728969659, 0.023381721328145692, 0.03822246114058154, 0.009454101357342941, 0.015597336892304676, 0.034026583789714744, 0.024724686318742375, 0.03404433087312749, 0.03666649891861847, 0.033243971677230935, 0.013622414071245917, 0.004170586230299834, 0.01849637775948005, 0.016198121975841265, 0.008627410761878958, 0.01429205434396863, 0.02895583052720342, 0.010524778726643749, 0.043019754612552266, 0.014769824421299356, 0.019229690910183957, 0.017590801530916775, 0.04021149155284677, 0.004960595222655684, 0.022050218490351523, 0.05599807355819004, 0.09670126890497548, 0.022909328640837754, 0.06607805392039673, 0.021979294617527297, 0.016732463214014257, 0.005026807093859783, 0.06849194224923849, 0.014909689148355807, 0.07666541223547288, 0.029813417366572788, 0.04220073909631797, 0.046765814136181555, 0.028807875966387134, 0.053165118609155924, 0.01923273753241769, 0.009523523123269635, 0.061099723912775517, 0.05141956352495721, 0.04532979315678988, 0.040847370467547855, 0.03569048396976931, 0.06462099496275187, 0.02203824065093483, 0.10438924030001674, 0.0764632291559662, 0.09447097858147961, 0.10767929375703846, 0.006615080729326499, 0.11762363836169243, 0.08386991385902677, 0.07880491457347359, 0.041653035807290247, 0.09839231387845107, 0.06827024450259549, 0.05661168295357909, 0.04451229077364717, 0.1362286207399198, 0.012928226097886051, 0.07348581749413695, 0.023877353839842335, 0.05441048481900777, 0.15624327319008963, 0.020202498084732463, 0.09706942843539373, 0.016456406330689788, 0.041379263890641074, 0.06585198640823364, 0.041867144139749665, 0.033293732042823515, 0.06123484059103897, 0.04528695045571242, 0.07536049439970936, 0.020240355249760405, 0.029353804886341095, 0.03610023769683071, 0.010590176779909857, 0.030031966710729257, 0.05011029627972415, 0.03168777536068644, 0.03272171684407762, 0.015466796932742, 0.06670451816171408, 0.024550828683589185, 0.016171314753592014, 0.04126500537885087, 0.06354362384549209, 0.08324233682027884, 0.043736233309443505, 0.07674651074090175, 0.06324830504932574, 0.03434437905837383, 0.025531503471678922, 0.02201904828793236, 0.018258086438956003, 0.045704368235809464, 0.053396159783005714, 0.022693179614309753, 0.02085161691398493, 0.014761865205530609, 0.09343578520097903, 0.02605130709707737, 0.05481372460989015, 0.04529257890369211, 0.031428792114768705, 0.02573095714407308, 0.0411176445361759, 0.018912779433386664, 0.04976199746930173, 0.07580187464398996, 0.033522869925946, 0.006693987566645124, 0.0370044534626816, 0.008616698390272046, 0.016449558216014078, 0.04424603023965444, 0.033049228734203746, 0.02287370215968362, 0.05104790614651782, 0.08376468664833478, 0.050141698880387206, 0.028775574306824377, 0.01217007517282452, 0.030590879398265054, 0.024962104025429914, 0.014194023845318173, 0.006365191973080593, 0.019164300490436808, 0.057369654066860676, 0.028431010831679617, 0.02658503086838339, 0.01686830253207258, 0.005996434907761535, 0.05052607539775116, 0.07168980993862663, 0.025095325894653797, 0.010784964675882032, 0.05640801048970648, 0.03608110640197992, 0.03722286370715924, 0.020485291124454567, 0.01973013423516282, 0.01735805893050773, 0.0630715059648667, 0.04028004055310573, 0.05498077993148139, 0.03423977949257408, 0.030837299568312507, 0.01903929059127612, 0.012021453103183635, 0.034474596713802645, 0.04347796252529536, 0.06923781508313757, 0.026370135435302342, 0.08124581538140774, 0.019542242799486433, 0.02747375059074589, 0.03658253699541092, 0.0381911535348211, 0.02705873143193977, 0.06923275321189847, 0.05377623778102653, 0.028986673336476088, 0.03667860059067607, 0.00871848882109459, 0.020674453116953373, 0.004677484543727977, 0.05578679471675839, 0.04639142565429211, 0.0105675264328186, 0.014833925624511071, 0.04287231573835015, 0.050282376153128486, 0.0021520690185882685, 0.025075421069881747, 0.07942690048366785, 0.009734048790830587, 0.07626429625919887, 0.002886862647885989, 0.06015755768333163, 0.027451406432581798, 0.04000274703970977, 0.06491437993411507, 0.03775359683537057, 0.027898606810984865, 0.04292345353003059, 0.04801300899790866, 0.026548892093290175, 0.04808228403063757, 0.033461784810892174, 0.03777438375566687, 0.03838580487562077, 0.03663217183202505, 0.04799744340458086, 0.05852626450359821, 0.025928358248035823, 0.06505555593009506, 0.02226294600404799, 0.07166074828377791, 0.041781852287905555, 0.0532382273647402, 0.04174589332459228, 0.08407907227852515, 0.07934083510190248, 0.006469079501195145, 0.0364670774766377, 0.05220603650169713, 0.023791140876710415, 0.03771895083731838, 0.03431826563818114, 0.04139023580189262, 0.035142834963543076, 0.008111186408703881, 0.03454335945259247, 0.06028501370123454, 0.07273163939160959, 0.02545932600540774, 0.0068453530381832805, 0.025268808639209186, 0.02804796933196485, 0.04937061847054532, 0.06774008473647491, 0.07140246392892939, 0.09923684570406165, 0.06023812693144594, 0.10342065191694669, 0.03899941087833472, 0.042628070273037465, 0.05176771305767553, 0.07358432042279414, 0.03173120499455503, 0.09533441439270973, 0.08167618300233569, 0.06920604607356445, 0.08813924262566225, 0.09141969481217009, 0.05481275769748858, 0.026231834731463875, 0.11279548850974866, 0.029907961043396165, 0.08962632675788232, 0.0063839797595781934, 0.04233219847083092, 0.030447046937687055, 0.013319611033823873, 0.025003033257754784, 0.08155675405370337, 0.11301214474120311, 0.03290749294683337, 0.047537634149193764, 0.024713973947135464, 0.050053306123507876, 0.009429588431625493, 0.0463325898828251, 0.0038825811934657395, 0.032354877064270635, 0.10206412470766477, 0.025285928077729683, 0.044467945117503405, 0.02256674988062254, 0.04655381265495505, 0.02977223029094083, 0.04479435778089932, 0.026594340368839245, 0.034941333811730146, 0.024974746829164878, 0.027081877957763414, 0.0767132964517389, 0.09899439157119819, 0.01525144518486091, 0.014090922993740864, 0.02209821466489562, 0.033292388543486595, 0.04825721714379532, 0.023771787361641015, 0.025886217830702662, 0.048568664717354944, 0.060388381725975444, 0.024528701656631062, 0.040687158171619685, 0.03662408030192767, 0.03490499147613134, 0.02625679803479995, 0.02516400720924139, 0.0339504962653986, 0.06409721342580658, 0.038779229657458406, 0.015216339479333587, 0.008286881177420062, 0.024613576209438697, 0.039784316439181566, 0.040263430015849214, 0.02945519837417773, 0.03387734340503812, 0.007420466597458082, 0.039837476265217574, 0.019939523356567537, 0.021017818977790217, 0.04064737227080124, 0.04861253200631056, 0.03036305108772857, 0.053163347632757256, 0.021218984254768918, 0.004948556315087314, 0.04263131367042661, 0.014841379331690925, 0.030768492724746466, 0.05986132965024028, 0.05968145680214677, 0.03923752577975392, 0.029128507511424165, 0.033750501461327076, 0.02059184487110802, 0.1272360504205738, 0.09950797472681318, 0.11562193291527884, 0.10543706800256457, 0.15761630237102509, 0.1076180220448545, 0.12831477182252066, 0.14720639453402587, 0.12533001841178962, 0.1647225317678281, 0.08497088442423514, 0.054410820693842, 0.1606797929853201, 0.09576594230851956, 0.2202657391982419, 0.06446246882634503, 0.12673635009144033, 0.16113435716501304, 0.11244250102234737, 0.17237035424581595, 0.07805826142430305, 0.161512002614992, 0.0739957569167018, 0.1771873286260026, 0.16623879969120026, 0.12156817955630166, 0.12990453865911278, 0.123745218451534, 0.08208218443074397, 0.0881978544805731, 0.16128881887665816, 0.15200465491839818, 0.16782201187951223, 0.09734397048928908, 0.11263259939317193, 0.12044894961374146, 0.1205671097018889, 0.10170460971338408, 0.1358633789100817, 0.19077500594513758, 0.13967704427029404, 0.18277708653892788, 0.09545697817312819, 0.1268559486738273, 0.07178701008004801, 0.12031626887619495, 0.0692975465208292, 0.06279566112373557, 0.14652806307588304, 0.14110677183738776, 0.07957581856421062, 0.1597244699618646, 0.10843672204230513, 0.09058442498956408, 0.14171302930584975, 0.1278093989406313, 0.11866866371461324, 0.13501924063478196, 0.08331141168517725, 0.15500559817467416, 0.09729140438139439, 0.22166307350354536, 0.17354329702045235, 0.15317615919879504, 0.09465048502066306, 0.18328520070229257, 0.15124194084533624, 0.09927223809063435, 0.15447939426771232, 0.1533256404634033, 0.11015823323811803, 0.16326387146753923, 0.18409188384456293, 0.16509993294520037, 0.1693570345107998, 0.09001444878854922, 0.1846175177821091, 0.18494193894522531, 0.14420592625226292, 0.09272884670644999, 0.08832243350999695, 0.24365693117891038, 0.13390889950096607, 0.13726863850440296, 0.2368854231068066, 0.23863946327141353, 0.24732338158147676, 0.19140484929084778, 0.3168402170496327, 0.2225693248744522, 0.20712476862328394, 0.21796671327735695, 0.28540895506739616, 0.23477189508931978, 0.21494480328900473, 0.18843605502375535, 0.2931599962924208, 0.10276537029338734, 0.22622624864535673, 0.10296310218317167, 0.15361373286162103, 0.23483263754418918, 0.07002726343593427, 0.2079129684716463, 0.14741868099996022, 0.2047563014285905, 0.16884844537292207, 0.13647773808666638, 0.11465250993413584, 0.13955270951347692, 0.19290221322860035, 0.09989346404160772, 0.09844141267240047, 0.178061146023018, 0.1618780858282532, 0.09567147666322333, 0.09396819770336151, 0.1034277697492923, 0.13883620367518493, 0.1870837483022894, 0.1092186997245465, 0.13697040879300662, 0.20539173590285437, 0.111799989427839, 0.14555120335093566, 0.17323668061622552, 0.23284328143511498, 0.15425735046820982, 0.2134213021823338, 0.12516722429011548, 0.19599376805126667, 0.11452755092510156, 0.07984552266342299, 0.07225560636392661, 0.1111231507467372, 0.15522599991943153, 0.13757995037095888, 0.10667522477784327, 0.13270740397274494, 0.1773388319249664, 0.13487627330635274, 0.20403956488839217, 0.14945108337061747, 0.09325372747012547, 0.16064693831971713, 0.08819646348378488, 0.11064122124974217, 0.14818520843982697, 0.09312698391399213, 0.11789502522775105, 0.1594056806394032, 0.07716769099767719, 0.10246234333940915, 0.06537493557802268, 0.0955521087827427, 0.087928815345679, 0.1137468149619443, 0.1186957915446588, 0.13174301572144032, 0.1734917690711362, 0.08000562978642327, 0.1154515120599951, 0.13644296995231084, 0.14578081960124628, 0.11698603257536888, 0.08104478581143276, 0.07115287839301995, 0.14197047906262533, 0.10058113214160715, 0.10371874592133931, 0.1785004838768925, 0.17063331816877636, 0.13925192851041043, 0.18185092695057392, 0.09168116828160626, 0.21752592335854257], [0.014494868461042643, 0.01634503498540393, 0.023534513843644942, 0.03559406414361937, 0.027513611130416393, 0.017375254704217826, 0.011526494885661771, 0.06334001584244625, 0.059292378037103584, 0.04542495430048023, 0.04412307290892516, 0.05371293046378663, 0.11651013525468962, 0.04262892522716096, 0.020331904890813997, 0.014129655468942863, 0.01734634063073567, 0.049665696386780055, 0.041925582968230755, 0.021876396478286812, 0.036437544239951034, 0.07698292591209922, 0.027303509547242096, 0.029861121771058867, 0.04529185287122216, 0.03850912522258503, 0.037377579869436364, 0.017261735795597945, 0.08450107356267315, 0.03329076684479203, 0.057082375910665305, 0.039123749027826955, 0.061954637324171405, 0.04304157290607691, 0.05075652285345963, 0.022807979257777333, 0.0556868363304862, 0.01826337561942637, 0.0037764964841439253, 0.02743804607806461, 0.039517452009022236, 0.09639216227723019, 0.0033314763235726525, 0.0320672291064901, 0.05378014614273395, 0.024267285862671475, 0.03790895760591541, 0.01865115498990885, 0.0595481043149318, 0.015528092393651605, 0.044194892447974, 0.03735266745622669, 0.06751994083502463, 0.06493244932166167, 0.01936791358249528, 0.022787280547033464, 0.006988400094477194, 0.023989899050710455, 0.03306298942438193, 0.028349922504276037, 0.05088673711621335, 0.008976169279776514, 0.029115381251488413, 0.020045473207054392, 0.012084695959596761, 0.060605560429394245, 0.045167032961866686, 0.03623454352574689, 0.02914842590689659, 0.03212205473599689, 0.05800778911049877, 0.07134480202304465, 0.0276598235525723, 0.01609417549999697, 0.0633660037336605, 0.059413421899080276, 0.05695313534566334, 0.015689805948308537, 0.037753135431557894, 0.027681324630975723, 0.002802815695758909, 0.0401911931777639, 0.04646734354485359, 0.01982430980673858, 0.040011890299086056, 0.08387343545577355, 0.02900040688525353, 0.028226819288517748, 0.07391887889908892, 0.06543792398380381, 0.1255837090845619, 0.0637517576771123, 0.016564897294821482, 0.038949714973568916, 0.06619394770158188, 0.05154828501066991, 0.09246921885226454, 0.031702896513577015, 0.009747681407524007, 0.04693260822179062, 0.03788683397163238, 0.06836708502045699, 0.06874249130487442, 0.04193206976300903, 0.030646790683801686, 0.015808047460658208, 0.04152936940746648, 0.021987018042377064, 0.03551983241257923, 0.01984116292026426, 0.05837917846760579, 0.055146702099591494, 0.06678502634167671, 0.009788637781249625, 0.07065712713769504, 0.00973562044756753, 0.05253264933292355, 0.015294214943423867, 0.01631318115895348, 0.011730400595947035, 0.03124312118494085, 0.011852392710612288, 0.030406748742929528, 0.049894142164183516, 0.031964746569948535, 0.019331408398491994, 0.04772350524685212, 0.010367783534872745, 0.04082296695560217, 0.029204245590205704, 0.05815670719104154, 0.040893375141812224, 0.06401725485920906, 0.01049615303054452, 0.05042905846078481, 0.01900859536337001, 0.030920823836433034, 0.01205561903771013, 0.034468612034938166, 0.03410172815035496, 0.03588149157751884, 0.036948297904538255, 0.06250746694526502, 0.04493327425526721, 0.025179659315784062, 0.046798068298293014, 0.04334291709320886, 0.012464784983811634, 0.0333631224265056, 0.013243104514133717, 0.02764685165935329, 0.0945756561788065, 0.021052140975371003, 0.03595930597345744, 0.05174387272979532, 0.04880822829103895, 0.0306844358066363, 0.016738904207678776, 0.03502585891900318, 0.04479588109201618, 0.04526527804721679, 0.009287925586769623, 0.060199375796530924, 0.02504771818140788, 0.04220480012840458, 0.05429899473009365, 0.0163555929902941, 0.036990112625062466, 0.02637568415541734, 0.00971071736421436, 0.031047774345747063, 0.07120796186583382, 0.1143214934106384, 0.052739164858524284, 0.03702825307846069, 0.03282864378499133, 0.03674916483994041, 0.01597093996991004, 0.014795539202168584, 0.06608321757188865, 0.018034510846648897, 0.03386651398614049, 0.05091791919299534, 0.054888502561620305, 0.018415808511365737, 0.03172379539215139, 0.06147987315697329, 0.0616011612915567, 0.00951071662296142, 0.0635171609797648, 0.03345969831570983, 0.03504685279248016, 0.06235203492854323, 0.0037992672712009934, 0.041609355115464756, 0.03256264787965587, 0.05908997104104076, 0.020641036963622485, 0.07606946849929434, 0.035507062383528264, 0.05793275670813663, 0.0473266097583941, 0.049804056462432654, 0.035010995609419684, 0.09242509372000184, 0.06324211680995566, 0.030358789887811457, 0.014153747702948749, 0.007788397122307548, 0.013836750561105353, 0.007979140101399804, 0.0180165873441313, 0.015134628596050399, 0.027204898052981923, 0.008038132784089871, 0.010700804281181522, 0.02140796134647514, 0.05659217846446803, 0.02015956038875239, 0.043451452162116766, 0.023518754867836833, 0.03298907660480056, 0.09910270611622504, 0.006992993776553443, 0.01730236647251461, 0.03176764232505645, 0.08369321655482054, 0.06242155762655394, 0.07400231835033212, 0.037731581766690524, 0.043820493788059266, 0.023591032418023263, 0.019669787026941776, 0.04550922156444617, 0.028686642114605223, 0.07481031106518847, 0.019561630241306763, 0.08453039306082896, 0.051052157168409655, 0.033170292952231, 0.06812112964689732, 0.03282996014292751, 0.03734534606337547, 0.019253592306215848, 0.015813959197008183, 0.07455485620136772, 0.02753691711196942, 0.03757364256307483, 0.06354534732443945, 0.021666113386995027, 0.012873900887955512, 0.07210202674780573, 0.018184141388961246, 0.03572373218568308, 0.011816937559550362, 0.06145204643585852, 0.0646854422188231, 0.03142135197828923, 0.029641904069909027, 0.01967466908640095, 0.05344690402437534, 0.04841740229832275, 0.020910471345164945, 0.04858263575338891, 0.09111535828560591, 0.0432894281776888, 0.013882572030914682, 0.04539809109909194, 0.018143909351368035, 0.025788432452827692, 0.0889975419268012, 0.05908846469329936, 0.029647027009299824, 0.008150428633338638, 0.052616353412824016, 0.052564815285482576, 0.011487498629971274, 0.05671564808913639, 0.07663725981754915, 0.05248522312779512, 0.09046036843210459, 0.03265725262463093, 0.03802962148828166, 0.01880209001579455, 0.00947179161344788, 0.014114934651713287, 0.0719936511346272, 0.025984464612390314, 0.0446395398383694, 0.012723652878776193, 0.03504697832145861, 0.019194054251004542, 0.02483227992031191, 0.017395914399198124, 0.1024514257109591, 0.020918949640222957, 0.04369237959118826, 0.03427613200619817, 0.01534574628541512, 0.04870315035805106, 0.07415986061096191, 0.07361937354185752, 0.04173254654077547, 0.02393455264557685, 0.013236853510274418, 0.006122795939778111, 0.045819250999816825, 0.10570829202021871, 0.01700555659564478, 0.0201178372704557, 0.06043949576893023, 0.029514200386724303, 0.006031431199517101, 0.04810844834095665, 0.043131210774715455, 0.055468066462448666, 0.02944242495245167, 0.01723390568180808, 0.008865154165375446, 0.021015123497428637, 0.040299555220242055, 0.025737343854936104, 0.03469732244099889, 0.014020326514063137, 0.03284715082762497, 0.047918539959937334, 0.04211887384631804, 0.057925774582794735, 0.017324970170323337, 0.06114155559667519, 0.03373937009434615, 0.03696402634627052, 0.024592991153310453, 0.02216173572066639, 0.016780423765469874, 0.023322023817205002, 0.016421655159709708, 0.01597366089533482, 0.05732128130538123, 0.035571492676224024, 0.07681893756879227, 0.040183230569320064, 0.018195778264531066, 0.010518965377871479, 0.062033510234739096, 0.032466485896813016, 0.02457743404167039, 0.06167792395821639, 0.041220008329089196, 0.07113119919917413, 0.06002855460558619, 0.030007536057382822, 0.07899056853992598, 0.08427962687398706, 0.08905400282570294, 0.20570094431085245, 0.07130276677863938, 0.14964461512863636, 0.12065925475742136, 0.08322170935571194, 0.15284512910459722, 0.18348706487034047, 0.1604752011064972, 0.22085928092045443, 0.20101743776883396, 0.24884975967662676, 0.09035786893218756, 0.05398477194830775, 0.10699149673538548, 0.12187523022294044, 0.13227122809205735, 0.09141622071287461, 0.11739860900810786, 0.16458568482526711, 0.14788157758968218, 0.19103736829544815, 0.1551558801106044, 0.1389963107981852, 0.2126243763736316, 0.0790758536064199, 0.12014845359538283, 0.10676067269274167, 0.13954748479383333, 0.12446318992546626, 0.1912448371627501, 0.07978604228368827, 0.07860332860478333, 0.1591628465269293, 0.148883013853005, 0.09164840182555573, 0.06898797848927123, 0.15874212767396653, 0.11578133436185972, 0.1964275554886886, 0.11995132560176508, 0.1312463687998908, 0.0685880770906806, 0.18616014000560555, 0.18071837058024748, 0.08965192788413592, 0.11910334681825978, 0.077294597402215, 0.20643321930297784, 0.14566685285951408, 0.14917638525366783, 0.12729892347540173, 0.08094483760318585, 0.11875920742750168, 0.1396203458841358, 0.0892351988170828, 0.09636150606508766, 0.15535831424806798, 0.11434187660259859, 0.18965849014265196, 0.1380867888884885, 0.16563651843794755, 0.10711889168513672, 0.12256527319550514, 0.09290861098894052, 0.08651482979101793, 0.09411054077957358, 0.10900551080703735, 0.10519816260784864, 0.16899363829621247, 0.17982826834278448, 0.09439139320914235, 0.20384080841072968, 0.18094281639371598, 0.14436354993709496, 0.06923431384244136, 0.10012500054602112, 0.1285124019320522, 0.16756872832775116, 0.09423000365495682, 0.1154657748660871, 0.1326796654611826, 0.126040498859116, 0.13452921621501446, 0.11837769432791642, 0.1392643457012517, 0.26177951587097986, 0.18389969558588096, 0.20830848653401646, 0.1676310178424631, 0.12661946564912796, 0.13167201381708893, 0.22861636110714503, 0.1889989541045257, 0.19546715702329362, 0.11828229230429445, 0.18172495013901166, 0.16143770303045, 0.0935960958844849, 0.184891279520733, 0.12622325548103877, 0.11753806152514049, 0.16419146955013275, 0.10082900098391942, 0.1318498985575778, 0.14840068402034895, 0.11164744118494646, 0.08263145174298968, 0.1299661360681057, 0.1616294298853193, 0.17128159052559308, 0.07605978580457823, 0.07486071264637367, 0.12376075690346104, 0.1419673306601388, 0.06456042892698731, 0.15379913577011653, 0.1401923101927553, 0.18770151372466767, 0.13602326890187605, 0.1120846891509635, 0.12533512099512986, 0.14786249718495778, 0.2516642686511789, 0.11849486375493662, 0.05821939025606428, 0.10778967783387218, 0.06321170487041984, 0.11846895728792463, 0.15780186812792504, 0.09837303669857127, 0.09936073262776647, 0.1589995910014425, 0.09692208455609423, 0.09318607074341603, 0.15500852944595472, 0.11718484333583287, 0.16902867784457548, 0.09983131023389952, 0.11338814135108675, 0.10158774562712226, 0.08633714861103467, 0.18542287099574292, 0.1394546747739826, 0.11542678624391556, 0.0913908299324768, 0.10574666996087347, 0.1088111037388444, 0.14145467031214917, 0.1594551729836634, 0.10116545935826642, 0.12908446123557432, 0.14131501423461096, 0.1631178507315261, 0.1044904166566474, 0.08410679043403693, 0.06140417579029288, 0.1254891213029623, 0.0985758915277464, 0.05177474607314382, 0.1088414206834776, 0.11373257251190287, 0.16678744953657898, 0.13914443499275617, 0.13383580770875725, 0.060968407030616484, 0.14987820759415627, 0.0616185317880341, 0.08882777925048556, 0.16002861649862357, 0.172247335846935, 0.12718672092471803, 0.1070666987715023, 0.08977927533643586], [0.03683495202234813, 0.04670156365526574, 0.03998554617698703, 0.035999380251658816, 0.025462566010121788, 0.025923793403697864, 0.04675174471256988, 0.08422478767377989, 0.04450623145593064, 0.05088240806279438, 0.025911632359826138, 0.03779559815302491, 0.031061904837510416, 0.03416904221687998, 0.024373054205040847, 0.04708176039691482, 0.031428086438349316, 0.0519824965324785, 0.019766369701496193, 0.04444464083228793, 0.01540092475313161, 0.025337902163820605, 0.008605066603714866, 0.06070200739694493, 0.022314813220873475, 0.030067175892846923, 0.07076039338218314, 0.05477837293541857, 0.027557927948821868, 0.035578786927674494, 0.03540478680016739, 0.011849842267110944, 0.07259153548095908, 0.025546548289379904, 0.04383944866380521, 0.036565800929175954, 0.0617177336077605, 0.06366668974182435, 0.03709980459617717, 0.035135479643940926, 0.01695868678923164, 0.05773921137941735, 0.03498851235157677, 0.010733568192725735, 0.016109057469293475, 0.0652061499921339, 0.016679691849276423, 0.010922553766119694, 0.11669593171349593, 0.02092056455356734, 0.03757860943941133, 0.07026006201548235, 0.07247030841452734, 0.010606869589537382, 0.010317953619440752, 0.048488485626876354, 0.07554495414452893, 0.04350733630625265, 0.03100827003696135, 0.051443834722574265, 0.052436962324593744, 0.061632007493504455, 0.028892116088952337, 0.03525603835337928, 0.018291349921907698, 0.019692925071077685, 0.045063220496688566, 0.008149968925863504, 0.01584911748899945, 0.028894647024571896, 0.04746189946308732, 0.0616279702101435, 0.013310054716254984, 0.08080503224794354, 0.026808416470885277, 0.008625957848770278, 0.06841002271643706, 0.02997163137687104, 0.053133522626012564, 0.06537336137677942, 0.05495395404951913, 0.05738870054483414, 0.06133490415023906, 0.044378015478806834, 0.026947836757504513, 0.024422892602160573, 0.0713008533098868, 0.10840474268687622, 0.09463348093309573, 0.0040145367467110706, 0.03611952844741089, 0.04469615340765033, 0.08582143485546112, 0.07533039458628212, 0.02176227536983788, 0.032490428004946025, 0.022988634117479836, 0.016651305336771265, 0.07271427568048239, 0.021433053571464758, 0.008134594170509704, 0.020688164613342712, 0.08752951784325497, 0.00774031104187348, 0.012534597755542823, 0.09364018030464649, 0.07322586394314255, 0.04615305969491601, 0.020486485346087387, 0.00974379594637347, 0.03117235337517091, 0.010810028063133359, 0.07397023721465043, 0.01320545090961137, 0.11189260267253433, 0.011534373525397053, 0.08697473404130765, 0.08131974855703966, 0.052790519781410694, 0.021276327249194895, 0.06551043902124677, 0.03652038658037782, 0.014016116204272424, 0.03308350153799568, 0.033528946207037995, 0.0201534807149853, 0.10381490790418216, 0.054218863137066364, 0.045446728489228656, 0.03784290900720017, 0.020465116582012603, 0.04989837961537497, 0.038099843077361584, 0.015683806002406136, 0.027370967802458575, 0.06895527988672256, 0.034569981774049144, 0.0195536303134369, 0.04546042811125517, 0.022753662529534528, 0.035512416024825404, 0.033537288795092275, 0.06345023028552532, 0.05071750030453716, 0.010717642127669283, 0.05343369634023734, 0.01706322019786707, 0.07186084147542715, 0.019494032886411463, 0.01611253835393914, 0.061859974903719764, 0.042794179038277695, 0.06475069014621632, 0.06636943042810474, 0.09856512317700045, 0.03218542651406356, 0.03793231278125729, 0.04794755411733474, 0.039176895283162594, 0.03600421481366668, 0.09297816761370216, 0.02656556200236082, 0.011044195587081569, 0.023148349386506846, 0.02877341995814017, 0.004761022806633264, 0.08250249616269555, 0.03817127924412489, 0.03694830129721335, 0.03811793282095875, 0.014282880550516503, 0.04994184656866959, 0.048225536343774626, 0.027675898047164083, 0.03485562466084957, 0.06528492112244878, 0.03348653776837247, 0.05515604552679828, 0.022125517217708484, 0.009961085759901574, 0.04506078455597162, 0.045419373349951844, 0.03298363136127591, 0.008670000708661973, 0.04962358311084764, 0.06555467950446264, 0.055055350930030854, 0.03402670253334301, 0.10240099698837314, 0.04807552582185183, 0.040220556780695915, 0.025564692315778563, 0.040774170109736066, 0.09745174220630101, 0.0402035967979048, 0.03418276898030724, 0.04287470757429089, 0.04578847265137093, 0.032188306895217726, 0.04226923042110034, 0.06302872433194093, 0.0408822403821562, 0.03077214663582189, 0.06011943080063377, 0.054437653361154456, 0.0060926715294564405, 0.0508384186375354, 0.04505189235455223, 0.028119349519589117, 0.004775193162328962, 0.09306923379855496, 0.03486426919698715, 0.02693724482586341, 0.03800090927896755, 0.04775942349806428, 0.03678776330447622, 0.022145606943273118, 0.12612190949065344, 0.04193947258006249, 0.032228333675967794, 0.026669610258457915, 0.07420035558087484, 0.033051447543714724, 0.021899376763030887, 0.025077509261401634, 0.004321572994480708, 0.0518632643590016, 0.012760947707907429, 0.04087890538253954, 0.01423120841250888, 0.06334830754037414, 0.04326440041352596, 0.026715017821905867, 0.011633978225290775, 0.02260600313145135, 0.0190979618180011, 0.028404108614527752, 0.13818782275276525, 0.06724370244358267, 0.017217461385631135, 0.08737836738250085, 0.03768486802333167, 0.01350797405133822, 0.002774822733564568, 0.03464269019397242, 0.031635043011712174, 0.021137558356193558, 0.04933719044285161, 0.012031201955064066, 0.017502510554290245, 0.04270132830632584, 0.05447175992386682, 0.03387622042958226, 0.04702119096847517, 0.04866456885689071, 0.03959943260997534, 0.0299391193714525, 0.039011224173009396, 0.030539487155952623, 0.0071560287781591925, 0.04451803457258003, 0.007801220585991229, 0.06157658475318125, 0.008112024399451911, 0.04526453505137137, 0.013696700933256319, 0.01570182110715125, 0.04360688417883856, 0.0264892386871257, 0.041077417587595325, 0.05315170736451234, 0.022867690339418392, 0.01032804258699928, 0.035607153084129095, 0.07091013927544866, 0.0582339380468641, 0.018362635114629353, 0.030100807481046234, 0.06542957121772425, 0.02565432170272938, 0.029135706767972027, 0.045884088413523774, 0.10714156154010977, 0.028516438390527452, 0.05820387216018779, 0.03116846876218915, 0.05563621761809502, 0.03211986306788666, 0.06710676729146924, 0.005807414559447872, 0.04731991940311023, 0.08711057675204106, 0.03487449132704309, 0.12767328481589044, 0.0484898664456393, 0.06255432657365288, 0.07187148768986974, 0.06493543487574373, 0.016814913700467775, 0.051554547888892036, 0.0395187242621822, 0.07222454303077289, 0.08732875290193728, 0.04470965964719653, 0.07623619133872644, 0.06059735694101878, 0.042082704537148984, 0.02877148274066193, 0.051953411128904135, 0.03948692811120834, 0.04222676430695823, 0.016632669372484088, 0.01733903111224728, 0.01630085557033973, 0.017709814876850163, 0.03669947911319988, 0.03552412414657218, 0.06816630650843893, 0.02409847992073212, 0.01755079340987972, 0.04301587678492069, 0.0142244705597737, 0.05081762832456401, 0.07959596426891428, 0.03439794261274593, 0.07917686032929591, 0.11751771904528141, 0.043192109292639155, 0.0376439896811332, 0.009851482846508068, 0.0840328029756035, 0.036067152329321416, 0.06215994845011404, 0.03246187864403639, 0.029371141456067562, 0.042012557586921115, 0.038764115289918015, 0.032453352851527076, 0.0577132302735533, 0.08824215603194066, 0.014765066194481083, 0.023884420782061558, 0.01988176136676754, 0.07702891701566321, 0.04777073467682515, 0.06118428973214967, 0.046795079351535866, 0.028370303999898688, 0.05502599071977394, 0.037537965191794295, 0.05667342964027609, 0.022151276103353927, 0.11656330525875092, 0.15757826369787964, 0.1519057923661811, 0.09814671812845127, 0.1509731595537492, 0.14980312090899262, 0.07842042949050665, 0.13707172764199121, 0.07274309306272439, 0.20297682977148465, 0.18532039863722666, 0.14628380403986999, 0.174283768715603, 0.1357539583529745, 0.09322533077959504, 0.14058429987302848, 0.15753907151520252, 0.14799269448433602, 0.10942721353577715, 0.08747414938573327, 0.09797574087445225, 0.2180358695664576, 0.09573462113205876, 0.17732983455061913, 0.15855801398200647, 0.11009275460881845, 0.23560120058911188, 0.16476868571979658, 0.17610297538340092, 0.1164673739778144, 0.1468352358788252, 0.1622621909316097, 0.20993488069091523, 0.1314207115875823, 0.16758319469434874, 0.10409027777080025, 0.0748874062140073, 0.09631029024188008, 0.1128171541328941, 0.14871244372001716, 0.11407188751867839, 0.22631945221551827, 0.08470927524779524, 0.13298796463225568, 0.0952908049470612, 0.19877132400870323, 0.07249540063951697, 0.09250137462679829, 0.15835993603936263, 0.08742524058158908, 0.13837029438998016, 0.15696674079767295, 0.30323520994612146, 0.08872831958745207, 0.10717489796557597, 0.1399357696729047, 0.1712611937629325, 0.11646593548357487, 0.10044834962380783, 0.07892153438712869, 0.15884622851652758, 0.21279247663915157, 0.14907360076904297, 0.11447455734014511, 0.1397294271737337, 0.1496178401368005, 0.09621249298964228, 0.054671961681119034, 0.09804398114127771, 0.11808648066861288, 0.13121993307556423, 0.13656820037535258, 0.1231558293636356, 0.15355216259402887, 0.10310473958296434, 0.051479250857872624, 0.23350051045417786, 0.21709966765982763, 0.15152939542063645, 0.10338667766856295, 0.07417014720184462, 0.13597654498049191, 0.13150072443698133, 0.13805172219872475, 0.1344056414174182, 0.1677683533302375, 0.21995516014950617, 0.18357454160494463, 0.13474025417651447, 0.12195094116032124, 0.16867957157748087, 0.14215999389333384, 0.18018274860722677, 0.18490354743387016, 0.13354781030544213, 0.13134519064000674, 0.09304676071873733, 0.06330553269279854, 0.323672141879797, 0.14682756843311445, 0.09907990055424826, 0.11082671915314027, 0.28234322528753963, 0.09429194711680923, 0.13263511285185814, 0.13693916904074804, 0.20639478707952158, 0.14096373665545667, 0.13120341753321035, 0.12421328547809805, 0.11802461184561253, 0.08914476366979734, 0.1396823368434395, 0.11444597744515964, 0.19028713926672935, 0.1936093010008335, 0.1343641286449773, 0.2274818776973656, 0.12641543016902038, 0.14593597341861042, 0.2319752722978592, 0.28819187145148006, 0.08723388013562985, 0.09240420162677765, 0.14730812050402164, 0.19447642804256507, 0.1819360288126128, 0.1973735418702875, 0.1334455143660307, 0.12963491598410265, 0.13324004039168358, 0.10477010879133429, 0.17614328036350863, 0.18039025818662985, 0.1472654677927494, 0.19737557747534343, 0.12305531118597303, 0.09615170982267175, 0.07586824215416398, 0.229805588722229, 0.07558534733418908, 0.1561821507556098, 0.14903590136340686, 0.1373674739152193, 0.1332507205328771, 0.16563460496919497, 0.08826466303850923, 0.2477820169712816, 0.12163152758564268, 0.20131728239357471, 0.17056511182870182, 0.20925882911043509, 0.14847574356411183, 0.13972048408218793, 0.14435517681496485, 0.12335294378655297, 0.15009736083447933, 0.10108080532933984, 0.14427665674260684, 0.16146229313952581, 0.16757267740155968, 0.18168058751949243, 0.09553408010729722, 0.22140928783587047, 0.13288893923163414, 0.09227732914899077, 0.13597830917154038, 0.1574106655482735, 0.0787081690505147, 0.18519770593515464, 0.09412728023848363, 0.19322595585669788, 0.14250608746494564, 0.1274381588612284, 0.12164865380951337, 0.1639339926519564], [0.015309342881664634, 0.045847830894802294, 0.008935643775787736, 0.0041292965262463045, 0.05116354547707098, 0.1015601631786142, 0.012196124132190431, 0.07030069947774921, 0.01924058309357081, 0.008002496124910457, 0.042867789909775765, 0.08358450845948287, 0.027158511702769568, 0.05180764823619809, 0.07226513299558844, 0.043121334697519026, 0.03697539520050798, 0.036567487088697295, 0.02058986694152866, 0.03918895285044398, 0.0443331507433738, 0.021247609950868145, 0.02631926566495427, 0.06062424049845763, 0.0173882181157491, 0.027142028390829052, 0.03221014215211783, 0.029282385682953254, 0.07037105677383286, 0.07787138609481709, 0.019179453873740773, 0.06738542805292777, 0.023045524189780866, 0.07814942938940865, 0.07970021438917943, 0.015364811423101594, 0.06236139192645039, 0.021045482850500515, 0.04840390284412673, 0.03284073867169874, 0.02212872159933405, 0.03405104497713702, 0.048840448526399474, 0.030219412009630884, 0.008653936392095472, 0.011193979647941887, 0.01801165269820818, 0.05201417054714901, 0.0557217266011451, 0.09125661570578814, 0.012495317363313265, 0.008929073860469674, 0.06523096401776586, 0.04380155587568879, 0.023085807117500474, 0.04812505887821317, 0.02701152066167976, 0.016774462835331048, 0.020085067421730076, 0.037517551465758255, 0.010899930560429181, 0.01897499430924654, 0.05049045230927212, 0.03960561406399522, 0.029389492435646907, 0.035687162540853024, 0.03686676513669746, 0.018586519440369945, 0.05659034302724259, 0.036093041832957945, 0.012475130946508475, 0.05283185613474675, 0.11398650067193167, 0.01064685226551124, 0.05045244756287762, 0.04590967596907701, 0.02812197884278638, 0.007020119486177074, 0.010529385131251599, 0.09237241226115397, 0.04880935465916991, 0.032212829150791676, 0.04835583542340568, 0.11832883980657373, 0.038148711169404645, 0.05036105228854077, 0.07243195761527334, 0.03976777714810201, 0.060770709067583084, 0.06533784006855317, 0.056950468703040054, 0.07397333811968565, 0.05830550313528095, 0.05061569291033915, 0.00326538149965927, 0.033804970859949074, 0.0946147194398301, 0.03854248539677688, 0.00805061443575791, 0.0406494994780847, 0.03889487577336175, 0.06231763320309775, 0.028148258504058634, 0.023187470323007022, 0.0651374686775463, 0.06087869791580098, 0.04032272379845381, 0.02767851379966097, 0.03268685371481946, 0.04515933498208012, 0.01779194814818246, 0.01538306231876569, 0.02585813156994326, 0.01565396912129862, 0.06083882041275501, 0.006441282890071827, 0.023661856206932237, 0.03496874662648354, 0.05777957742767675, 0.06443444533007485, 0.013610937499574252, 0.014057817270181008, 0.05702970802251782, 0.023832653649151325, 0.053050761709788015, 0.04081403064940657, 0.06305151632321732, 0.08484756746994597, 0.0958513698673674, 0.007430754036509565, 0.0382118386748646, 0.09224896638521127, 0.04900215020669358, 0.022679101709010344, 0.018780770445508615, 0.011000028046380197, 0.01605827421216028, 0.024514974893203804, 0.011838576889463832, 0.024708396389282176, 0.09606844000518322, 0.017685709920312678, 0.037879152955221276, 0.03886691334524325, 0.044550332839467695, 0.019035344910142676, 0.006893119358989809, 0.06524534217481102, 0.014746092659022127, 0.04510021083323019, 0.01585521242980446, 0.016440884842138206, 0.06989334776465382, 0.04494936232055936, 0.0369386864559991, 0.07646538011197533, 0.04074569878035358, 0.05848680090691362, 0.08344063189412866, 0.01679517511677529, 0.03012151297714029, 0.04851792386866041, 0.01885495807177254, 0.0398175341210195, 0.05358831072226167, 0.03865973964067442, 0.09033479195620332, 0.06900976624872003, 0.016565774301333085, 0.06977796967008285, 0.020463846025190184, 0.02141034130805305, 0.013703443026835365, 0.04755527266700353, 0.017922359186091592, 0.010540858310248171, 0.01392005684985114, 0.05853089889777558, 0.0588941594053592, 0.02928016348076718, 0.0346468122942107, 0.05670723764758025, 0.011893031021047915, 0.05464926468474524, 0.05810353040163006, 0.04532555570559842, 0.036052428119416745, 0.05751539660351617, 0.01986728312580713, 0.0262279314587691, 0.0984429529468928, 0.02697831315786711, 0.05614859637405191, 0.05324051063507795, 0.08606131734060389, 0.031038254499435425, 0.05305063618080957, 0.038224154085453065, 0.016844893073929206, 0.04750189231708646, 0.03458174757127251, 0.00584157752538366, 0.03476390368970377, 0.052304593713155816, 0.05474536220676132, 0.023112604161724448, 0.04531282299597349, 0.09786468504795007, 0.021845592684777718, 0.052471574395895004, 0.042723166955901046, 0.04539927514269948, 0.10015771271927015, 0.029146173170634677, 0.014826251393450158, 0.019338619529402683, 0.017518508713692427, 0.02866818935477308, 0.01647357496299914, 0.025417507892208438, 0.02444069057569972, 0.04000480978616646, 0.05324622050725988, 0.034146372361906936, 0.04112318138192807, 0.09975840843149594, 0.018889827986380885, 0.01234491922826107, 0.0759107998705336, 0.01515638073241072, 0.024820334311308603, 0.049979009931640964, 0.035625782263066084, 0.03595050537426557, 0.04289256322330662, 0.02215929638727435, 0.034077507842864306, 0.046567346035901985, 0.03731539213497724, 0.07327233002121959, 0.03167220976735864, 0.04534488716827972, 0.015204027461420213, 0.03978038772142359, 0.023244509673012153, 0.05548783218754189, 0.040398275280105214, 0.04034260148182511, 0.07899368980101176, 0.0561052753057863, 0.05917244018720729, 0.017977829423866103, 0.04512577124738267, 0.02239865470411522, 0.03028488385358027, 0.057144414367420335, 0.009994353483697134, 0.019251134313110794, 0.022727793381948556, 0.007319665979593992, 0.013897976472175546, 0.06702049156384808, 0.031313834711909294, 0.05015633488073945, 0.037705844933433194, 0.03603498637676239, 0.05423152460051434, 0.027099586025412594, 0.032596516955111704, 0.02210102040719773, 0.021368411236575673, 0.033279347100428174, 0.07076479028910398, 0.02702600059897772, 0.030941135782216276, 0.03644479438662529, 0.10416930674442224, 0.032332580403557847, 0.02460759661958686, 0.07830696486468826, 0.015168241524536694, 0.07709164757813726, 0.024340021423995495, 0.030153655180973665, 0.08478698107813086, 0.028088299757135764, 0.05406996541257415, 0.023868950183636377, 0.012577749190053769, 0.03699994120480759, 0.08056017610111407, 0.014668675206069435, 0.025016648062903966, 0.06930146845323698, 0.08998318868024008, 0.05253778923568981, 0.05220507637464574, 0.08696365356445312, 0.041484871080943515, 0.05180847604892083, 0.02117740871783878, 0.05872586236468383, 0.018476203217038085, 0.06001619169754641, 0.05628901580348611, 0.02657953303839479, 0.03283373958298138, 0.05783524444060666, 0.03678351906793458, 0.03393788569207702, 0.07246621684836489, 0.029173928645572493, 0.012221120514108666, 0.03399662307596632, 0.037245092514370165, 0.04797566582315734, 0.03278234055531876, 0.017582379214997803, 0.005403884694845016, 0.03426848152386291, 0.022763628512620926, 0.06471801189971821, 0.00878948818093964, 0.027638008651722754, 0.005167813032000724, 0.029885565995105674, 0.034257787811969004, 0.033438714620258124, 0.055092487151601484, 0.04410117658387337, 0.039185407504971535, 0.03583554457873106, 0.01940227289950209, 0.01925653375552169, 0.0766160555982164, 0.05333002297473805, 0.03198646308322038, 0.05051368534831064, 0.030891721469483206, 0.020170980133116245, 0.044747399764933755, 0.026755984373656765, 0.032558970219854794, 0.0737523731908628, 0.022409551976514713, 0.09162157255091838, 0.011992919009311922, 0.023143424918609004, 0.05047353643125721, 0.045349562274558206, 0.040966188734663386, 0.04870102993611779, 0.07811298527355705, 0.0950702607099499, 0.21344064043036529, 0.09455835353583097, 0.0659286133678896, 0.22291647696069308, 0.04770535782777837, 0.17183106818369456, 0.1393824786479984, 0.09773347673139401, 0.19166352041065693, 0.20097839486386093, 0.1703766148005213, 0.14962542615830898, 0.2369857920067651, 0.13930816549275601, 0.1217816738145692, 0.08968096918293408, 0.18276171093540533, 0.11992210788386208, 0.11521863884159497, 0.10811335939381804, 0.08729373370962483, 0.16749042538659914, 0.1332787847412484, 0.10473912009703261, 0.0642690524192793, 0.07484650412308318, 0.11982677371374198, 0.12195427955261298, 0.09277266649795429, 0.21031374750392778, 0.08418672185923372, 0.13709274865686893, 0.12443722917565278, 0.07874299825302192, 0.1673388270927327, 0.1196925730577537, 0.16440762366567338, 0.12011432328394481, 0.09933341480791569, 0.09714794850775174, 0.1284826820982354, 0.09879326700632061, 0.1492130532860756, 0.0980627154931426, 0.13769809688840592, 0.20459413155913353, 0.13496045236076626, 0.213571000578148, 0.13546126548733028, 0.12626704813114234, 0.18928497018558638, 0.16611320285924844, 0.09409449342638254, 0.13232734293809958, 0.07937014102935791, 0.18033016712537833, 0.09110073585595403, 0.1328214928507805, 0.10941474884748459, 0.08883641021592276, 0.19518483217273438, 0.1705482570188386, 0.1948283298739365, 0.14936543868056365, 0.11092752910086087, 0.169389970600605, 0.14132159602429184, 0.11345003731548786, 0.08157808719468967, 0.11812237517109939, 0.18136543514473097, 0.2207395602017641, 0.12524476727204664, 0.1474105521504368, 0.14514486944036825, 0.0676103149141584, 0.17196871579757758, 0.21137824681188377, 0.13899583582367214, 0.12494015933147498, 0.2115826215595007, 0.15372080568756374, 0.14032978138753346, 0.14786165580153465, 0.08500244987330266, 0.1245955042541027, 0.19447450100311212, 0.10705763354365315, 0.14858379348048142, 0.11376726600740637, 0.16394536489886896, 0.18912579944091185, 0.10201567730733327, 0.1997706432427679, 0.21424009038933686, 0.11938293038734368, 0.14317250384816102, 0.10655483230948448, 0.12529424604560646, 0.13787020051053592, 0.11877101393682615, 0.16154017538896628, 0.08908078460288898, 0.183083675801754, 0.16624095743255957, 0.1397586041795356, 0.15290465019643307, 0.10302633486155953, 0.11966966571552412, 0.09058911366654293, 0.08647572581789323, 0.11170516415898289, 0.16268867733223097, 0.09551744921399014, 0.0882295827780451, 0.16595669197184698, 0.20059753315789358, 0.18504073364394052, 0.10658706950822047, 0.14059727346258505, 0.11616425881428377, 0.09135541040450335, 0.11609051562845707, 0.16585139690765313, 0.09186291388635125, 0.13593063530113014, 0.14812416742954934, 0.09946375459964786, 0.0943551187270454, 0.17635924448924406, 0.11836455788995538, 0.11163575002657515, 0.19329475930758885, 0.11056776983397347, 0.07072959467768669, 0.1320175374192851, 0.21174199586468084, 0.22170569907341683, 0.24885372232113565, 0.13237295406205313, 0.09132694586047105, 0.12690164122198308, 0.07590250138725553, 0.19530975046966756, 0.07731139792927674, 0.08985903712787799, 0.07567889695721013, 0.09352183022669383, 0.2102051411888429, 0.154099916773183, 0.16725458018481731, 0.12057070593748774, 0.11963249556720257, 0.18774445142064775, 0.08722560879375253, 0.13699153837348732, 0.145530548744968, 0.15133149389709744, 0.039655998681804965, 0.13594584805624826, 0.09756227556083884, 0.14753457478114537, 0.12260760020996843, 0.10692785015063626, 0.1770911802138601, 0.13591812311538629, 0.10908023108329092, 0.27818271996719496, 0.06957913855356829, 0.11037099467856543, 0.16992331269596303, 0.19535629797194684, 0.09210065220083509, 0.11372645891138486], [0.004554526364829923, 0.04246073675208858, 0.02142003926980708, 0.03425444941967726, 0.021966779039108326, 0.01695088533285473, 0.04561834356614521, 0.03206156333908439, 0.06470571005983011, 0.024780843573223268, 0.05297420260363391, 0.04043802046882255, 0.04898628945063267, 0.012242302681053323, 0.07717940929744925, 0.022785039685134376, 0.005953266085790736, 0.040826834605208466, 0.016316032702369348, 0.0809893969978605, 0.02154097965519343, 0.045221146129603894, 0.01829600297579808, 0.04470051299514515, 0.13220451452902385, 0.014991812241662825, 0.029311725537159612, 0.027539960341528058, 0.03562087306220617, 0.04896321925999863, 0.04831229383125901, 0.017029731102021675, 0.023491991750363792, 0.030522723948316913, 0.06767056882381439, 0.06849366572818585, 0.022017468997676457, 0.06409511675259896, 0.04703395760485104, 0.028076271027592675, 0.02289315066965563, 0.02365817006544343, 0.05759010330906936, 0.04959987848997116, 0.06411518781845059, 0.07102289822484766, 0.04731472182486739, 0.02585093061705785, 0.08050934025751692, 0.009122079753849124, 0.06284230362091746, 0.0172537256897028, 0.0433379230754716, 0.04269840042772038, 0.042581787399415455, 0.03526750898786953, 0.017192304699814746, 0.034025294573179314, 0.011972646079292255, 0.030698318633117845, 0.018426076442535435, 0.0213375463749149, 0.04003389858241592, 0.026012460967259746, 0.030069333634206226, 0.005462007580458054, 0.029993161293012754, 0.015755081017102514, 0.02678749045091016, 0.032715857694191594, 0.06551132111677102, 0.008442430241432573, 0.02072987924995167, 0.0435116280402456, 0.02664990390517882, 0.04105703778831022, 0.059801116452685425, 0.03851811581158212, 0.06971280995224204, 0.0312117185842778, 0.03320364634107266, 0.03857940448714154, 0.029636441863008907, 0.02872617356479168, 0.03477009871442403, 0.074513750549938, 0.011539818768921708, 0.026818165322765708, 0.0327291569805571, 0.05386569583788514, 0.0335693054699472, 0.028666567656078508, 0.027474719199485013, 0.03834503509902528, 0.030412784311920404, 0.03679170559293457, 0.111113719109978, 0.04036126119483795, 0.06317095884255, 0.06385363292481218, 0.06585669544126306, 0.022251505903633576, 0.046005505469760725, 0.04262994642236403, 0.026343099207484295, 0.006991118051311267, 0.07151588784264666, 0.021978765360212753, 0.02350032246405525, 0.04977618224386658, 0.019356205460748503, 0.06805394110935074, 0.04597154479207737, 0.01589453692681023, 0.0044480773670199725, 0.04638032142871192, 0.026104785834572146, 0.06853388249874115, 0.05531071758429919, 0.02799104872558798, 0.03279071707012398, 0.038333523752433915, 0.04996732895129493, 0.13142866401800088, 0.023946567804419568, 0.027959091422547187, 0.027148428672392453, 0.036469201291246076, 0.010060657381213136, 0.03589635488710233, 0.021570521373567835, 0.030377622627254044, 0.01228012252665524, 0.03740920638665557, 0.06729087419807911, 0.02945543246875916, 0.05466657072039587, 0.018772271794400046, 0.006958732847124338, 0.03799800854176283, 0.04206608721454229, 0.039490473456680775, 0.0283463262686772, 0.05737147932606084, 0.016858497701053108, 0.02080497780947813, 0.027218154930908765, 0.021207768070910658, 0.031088554300367832, 0.023685974734170095, 0.011455587128044238, 0.01977589463682047, 0.024692952932257737, 0.0489478707978768, 0.00882749377550291, 0.049975026931081495, 0.0380496314859816, 0.055661815351673534, 0.013528261400227035, 0.027198655530810356, 0.006198883464094251, 0.04799651720428041, 0.04539490198450429, 0.1094288488051721, 0.10002794968230383, 0.04224485744323049, 0.03409797924437693, 0.06518200093082019, 0.04656110690640552, 0.032363725160913806, 0.01888356850083385, 0.04396030932132687, 0.030205654712127786, 0.019558456393757036, 0.045268741968486986, 0.05397766090131231, 0.008212577352034194, 0.021366334919418608, 0.02733100378619773, 0.052464636375329325, 0.027189759936715876, 0.010769802810890334, 0.0363090364927692, 0.04044817813805171, 0.036299367368753464, 0.045319343717502694, 0.027225152323288575, 0.015050921123474836, 0.04808349860832095, 0.039878802440528355, 0.0385458882498954, 0.02986872136326773, 0.01772044412791729, 0.09807668652917657, 0.03737947976748858, 0.025271437962406447, 0.03153970884159207, 0.05797908029385975, 0.052928693259933164, 0.07833665077175413, 0.06681733817926475, 0.032882298941590955, 0.021344557337995087, 0.033280436149133105, 0.04690961267000862, 0.036419301825974665, 0.02129315661399492, 0.062078612457428656, 0.030431108150099005, 0.03943182767501899, 0.058295508314456256, 0.08641043717839889, 0.07708824133234364, 0.009362077589945068, 0.0201736382940518, 0.0304908022683646, 0.057258957863918374, 0.030534289577709775, 0.08699926986758198, 0.06692008873713867, 0.04618886598785009, 0.05195266134770853, 0.08791210981351988, 0.018577389751694033, 0.06219950025635106, 0.017441137061853493, 0.031231996603310108, 0.034285967371293476, 0.06367649457284383, 0.02952081271048103, 0.03102236320929868, 0.02229672178093876, 0.008626089314930141, 0.037100408492343764, 0.045137866134090085, 0.06353183090686798, 0.019457312267539755, 0.054631962041769705, 0.029328105372509787, 0.052810719768915854, 0.013180541040908014, 0.015517673488440258, 0.029903886440609182, 0.009622636733443608, 0.04263217540990029, 0.02865706816581743, 0.05778792340840612, 0.036153662151524, 0.010844279662705958, 0.06679785743887935, 0.019419126013027768, 0.08057290541806392, 0.07790773521576609, 0.014475584495812654, 0.03085946391469666, 0.02698303745793445, 0.03541589781109776, 0.0639524208381772, 0.06517465918191842, 0.041890858938651424, 0.022000790606918078, 0.06878057747547116, 0.05937918980738946, 0.053326888142951896, 0.04708676120000226, 0.03155665864635791, 0.05741732793727091, 0.05112695886886545, 0.048507623707077334, 0.03397189725988677, 0.009823563674997007, 0.03711306995579174, 0.07908867791827236, 0.05552056810951658, 0.057515288037913184, 0.0337523470765778, 0.016424067351701002, 0.04553342830123646, 0.009135384129227271, 0.03333143823380981, 0.023985040739976933, 0.01817065041645297, 0.05780467643801655, 0.07511133634086166, 0.07543601534728493, 0.04301164951175451, 0.017205631127581, 0.08489041017102343, 0.005046359928590911, 0.006066823586089802, 0.003954339240278516, 0.043349529416965585, 0.07600378630948917, 0.016151404839807322, 0.07825690255101238, 0.05239440121554902, 0.042523999964552264, 0.026477416910763298, 0.0435768929310143, 0.018158273937712823, 0.033381249489528794, 0.04936328689966883, 0.04976013149800045, 0.03136983759967344, 0.031455655316157, 0.05555377222065415, 0.07032058055379561, 0.04371141589113644, 0.012593998407412852, 0.03223249309563211, 0.06006111750113113, 0.03407368429803422, 0.048462745400943925, 0.01674238678866199, 0.09114476599331413, 0.06059771656457867, 0.02846085958714996, 0.018644272948482206, 0.03444371997777905, 0.02254499095891203, 0.07307998569948332, 0.006767856705534671, 0.02309681804451559, 0.027261282616694058, 0.022629987648023025, 0.011105945666453667, 0.012967849150300026, 0.04821712590221848, 0.024931424064561725, 0.06294475562338318, 0.002725656298155497, 0.048151189261781316, 0.06754772005868809, 0.03469754975023014, 0.050319712542529614, 0.011878529031361853, 0.011897794336878827, 0.038690857256629636, 0.028673353006264994, 0.05528292818261044, 0.021180645329877734, 0.03418362393443074, 0.016958162620929734, 0.055048110961381874, 0.06642250543726341, 0.03540581138804555, 0.025308530079200864, 0.05836478673986026, 0.022964598710781763, 0.006908395302681518, 0.0902314375021628, 0.0431490630310561, 0.07008079306355544, 0.1323906366846391, 0.12141554988920689, 0.15288010079945835, 0.12378848184432302, 0.10271005611866713, 0.07566853572747537, 0.17711107486060687, 0.11311264256281511, 0.15115772107882158, 0.1291454615337508, 0.07511280197650194, 0.12055313188050475, 0.0645161477316703, 0.13988983285214218, 0.11945097387901374, 0.08519151687089886, 0.15076840482652187, 0.06922164559364319, 0.17503540909716062, 0.1216359380632639, 0.2181816188884633, 0.1984086198998349, 0.20520916927073682, 0.2327317845608507, 0.097275126326297, 0.08137429598718882, 0.17959673862372125, 0.09066525886633567, 0.1420234590768814, 0.10870170353778771, 0.07740798060383115, 0.19754172356000968, 0.15359130049390451, 0.21517019905149937, 0.1741991282573768, 0.09147920911865574, 0.12180948017963342, 0.10892920954419033, 0.05131564588685121, 0.07839803783489124, 0.11877850496343204, 0.24800319224596024, 0.14979481564036437, 0.14870320207306317, 0.19192979112267494, 0.1805890689470938, 0.11332906130701303, 0.15715831837483815, 0.0764281421101519, 0.19471616803535394, 0.10274412536195346, 0.1738775297999382, 0.13012077419885568, 0.10078324058226176, 0.08371285335826022, 0.06572676955589227, 0.17764524476868765, 0.10133096083466496, 0.191894208746297, 0.0894429933811937, 0.15079062006303243, 0.155763250376497, 0.1222568926002298, 0.056915768422186375, 0.11841422665332045, 0.1289492699184588, 0.0757007457848106, 0.11668985203972884, 0.07236417875226055, 0.17130177015704767, 0.04672714442546878, 0.09648320132068225, 0.14898977455283913, 0.13885322133345263, 0.12339539293731962, 0.11516070552170277, 0.11965169810823031, 0.13177964304174694, 0.0851067542763693, 0.12528071605733462, 0.21339046955108643, 0.12891793517129763, 0.14554828565035546, 0.17215866489069803, 0.15006983945412294, 0.08726783402796302, 0.2099411639251879, 0.21518552037222044, 0.21717251517942973, 0.16816381710980619, 0.2084615504635232, 0.13537168529416832, 0.12234416577432837, 0.08301785708005939, 0.16865465577159608, 0.2501169102532523, 0.17665409509624752, 0.15461930818855762, 0.14820293177451405, 0.13443043508699962, 0.12282973900437355, 0.10487879653062139, 0.08956988621503115, 0.15951560331242426, 0.14739483727940492, 0.09317573665508203, 0.11052276260618653, 0.23321316444448062, 0.094472193159163, 0.06339143522615943, 0.23623145105583326, 0.12393869592675141, 0.0770232512482575, 0.09137108456343412, 0.2631353374038424, 0.242226742208004, 0.16073759059820855, 0.17285281978547573, 0.15934640382017407, 0.1281034353056124, 0.1296214402786323, 0.1290354167244264, 0.22915183380246162, 0.11092534421810082, 0.15189903415739536, 0.09937458831284728, 0.07786980510822364, 0.16569506243935653, 0.12993433991713182, 0.16544093750417233, 0.16827604680189065, 0.09872833799038615, 0.2419313352022852, 0.25011064058967997, 0.0948218558249729, 0.1532657801040581, 0.09364292158612184, 0.13287346863320895, 0.12288342469504901, 0.142591460740992, 0.10659045539796352, 0.1516514095876898, 0.12677544727921486, 0.09779796469956636, 0.10499399820608751, 0.11593644746712276, 0.11453966956053462, 0.1636748465576342, 0.1263243979109185, 0.0944778114291174, 0.13747650092201574, 0.09669045984212842, 0.18489636853337288, 0.2090684457549027, 0.15700629938926014, 0.13478243191327366, 0.20494743117264339, 0.11101894133857318, 0.1068278748009886, 0.1032294746754425, 0.13672320491501264, 0.1031897532354508, 0.2520207166671753, 0.1660350491958005, 0.14798107796481677, 0.0924710441114647, 0.18349953634398325, 0.16668554714747838, 0.15058908159179346, 0.04307422061849918, 0.14926658969904694, 0.17112030275166035, 0.1247693584965808, 0.1238699739000627, 0.11876881548336574], [0.022220076161569784, 0.06724788221929755, 0.02285234526997166, 0.039404363970139196, 0.046150935880307636, 0.018803492886945605, 0.04061828686722687, 0.0156293026770332, 0.04367295991895454, 0.01748477534524032, 0.007454319557707224, 0.023353238124400377, 0.008408749459444411, 0.010577651023465608, 0.03996696788817644, 0.033044848790658374, 0.03933762665838003, 0.03252295358106494, 0.03994827424841268, 0.00766782060132495, 0.009215779502743056, 0.050520986385111294, 0.025152358459308743, 0.04831917078367301, 0.0015635854568764834, 0.013554686946528298, 0.017600094067997167, 0.013082867621311119, 0.041507466297064505, 0.03808071856786098, 0.049525636580905745, 0.008994421871778156, 0.017205824510061314, 0.029629089936081852, 0.028021314780094793, 0.06735691601144415, 0.05114254481824381, 0.01171014378113406, 0.022518485684746077, 0.08646407537162304, 0.02305354956271393, 0.023038676075105156, 0.028034785396552513, 0.05069211630948952, 0.06856126817209379, 0.058879021289093156, 0.004570980414947761, 0.016721967973613312, 0.022489312071619288, 0.02688957434812827, 0.09210221283137798, 0.08223550620355777, 0.044976361228951385, 0.04318551393225789, 0.061559444958610196, 0.043816805950232914, 0.029037672028477703, 0.06296341533639602, 0.09189179912209511, 0.012487959499204797, 0.03874004086745637, 0.026064407911949923, 0.04692566680854984, 0.03784182335117033, 0.06094738601573876, 0.016882977548188398, 0.009241884441248007, 0.02735813840159348, 0.019364658310743313, 0.06195859318333013, 0.04669940930658153, 0.016697009759289876, 0.050108898497585735, 0.04984025291300245, 0.036293121453906806, 0.034898864304912944, 0.057543392958385606, 0.05998780857771635, 0.03986794588022998, 0.013098671550064214, 0.0374744543140488, 0.034188126014279466, 0.030403203397457088, 0.0538113451828914, 0.038399222905614545, 0.009985009208321571, 0.04099907393434218, 0.0498045382222959, 0.06831088196486235, 0.0518231527613742, 0.08279704821429082, 0.055958369081573825, 0.013102613838522561, 0.05324296014649527, 0.03555469893451248, 0.045519348699599504, 0.05677305893706424, 0.04843456923429455, 0.03235969805557813, 0.050078055688313076, 0.04108783649280667, 0.12533147047672952, 0.06363685455705438, 0.031440259356583865, 0.057478287523346286, 0.05861904059669801, 0.04687333818791168, 0.02146787429228425, 0.014266358222812414, 0.03296969085931778, 0.02567487961745688, 0.030954540241509676, 0.008725116411889238, 0.010652360273525119, 0.0228458737422313, 0.01707638886624149, 0.020825086194755774, 0.0039047934613855822, 0.033356608490326574, 0.02249439260257142, 0.04706707350643618, 0.02625620092398354, 0.03829450120351144, 0.04599523584225348, 0.05882566808057683, 0.008763755588526172, 0.06469792726316623, 0.031833565394793234, 0.011764379933343401, 0.10884390412164585, 0.006666419961090598, 0.0366379699137594, 0.03264537826180458, 0.10160231377397265, 0.0208996012141662, 0.04357074201107025, 0.0574569475970098, 0.06466543222112314, 0.016480913319225823, 0.029675033542194536, 0.041544507523732524, 0.046950277273676226, 0.03571213262953928, 0.0034421841888355887, 0.010403287879723524, 0.01717873230310423, 0.09119123885674135, 0.01644777875792767, 0.02376947016455233, 0.01370648031921259, 0.035776121874472926, 0.03605332039296627, 0.029755660465785434, 0.016400620574131608, 0.07115761456745011, 0.022698480669142942, 0.022172804323158095, 0.05180099180766514, 0.018357741180807352, 0.049483689546052895, 0.013423829771844404, 0.01902710410234119, 0.04208857386506029, 0.019453108743099228, 0.043422675491975884, 0.02499073650687933, 0.02738761226646602, 0.04518744668790272, 0.05223349342122674, 0.05694771385086434, 0.03992360271513462, 0.038574457966855595, 0.03947959993300693, 0.029897986578622034, 0.02806569605932704, 0.039946828968822956, 0.01602755523552852, 0.08395103272050619, 0.019971270313752548, 0.030066415933626037, 0.050307719436075, 0.009669575241527386, 0.05326040867449982, 0.017183502404285327, 0.01754462213388511, 0.02792520708005343, 0.04052523936011961, 0.005849264054891786, 0.037037650788468976, 0.021745113522878716, 0.03555736896981086, 0.039495077316782305, 0.008854196672993047, 0.025385855929926038, 0.036260178578751426, 0.04000601079314947, 0.01673659379594028, 0.06667722748326403, 0.028054632545847977, 0.06518532575241157, 0.0329132503164666, 0.034725590209875784, 0.018575637435008372, 0.04066672408953309, 0.01648142052415226, 0.025888901436701417, 0.05134650905217443, 0.0442068889471037, 0.04303563233198864, 0.015182940289378166, 0.02325497437933726, 0.01607532410084137, 0.018633893059034432, 0.06131652942193406, 0.030603099813950912, 0.06327839807740279, 0.05069044032799346, 0.00929391450647797, 0.0875258401834539, 0.02988422928111894, 0.002550462797184342, 0.02548812812061182, 0.06768545588212353, 0.02243362130996372, 0.044780715834349394, 0.0332733081387622, 0.02359476775330092, 0.041431480553001165, 0.02096420792596681, 0.06774001009762287, 0.017233401869556735, 0.013322419320632304, 0.06139067294342177, 0.02532445190341345, 0.06299001390912704, 0.025433092145249248, 0.014715643400060279, 0.024803225050813386, 0.05118354190407055, 0.010430305447828556, 0.04594039664204631, 0.020801461301743984, 0.028740382088082175, 0.008781470441525536, 0.04809331701004079, 0.025925119939659323, 0.017948133338774954, 0.012177558565911437, 0.045063668329800875, 0.04950205070365753, 0.02262545164142336, 0.05588761484250426, 0.03388754857171859, 0.01174652173982135, 0.00903132654327367, 0.021518587999578034, 0.024598706114505018, 0.028015056990885308, 0.04509353404864669, 0.05187241779640317, 0.027149504150397012, 0.04407934471964836, 0.06179335633558886, 0.0421035796669977, 0.09022479464433023, 0.04394137480163148, 0.1276635274823223, 0.11035492696932384, 0.04517230857163668, 0.037504401457096846, 0.05714243304516588, 0.01373273623175919, 0.06484546113227095, 0.02378041493440313, 0.03420588666839259, 0.044206322370363135, 0.02770934303823326, 0.011110530866842185, 0.06867962503539664, 0.03266093706978219, 0.06026986201426812, 0.05137028831190296, 0.040795703418552876, 0.016277693777478168, 0.024924350336992314, 0.02757107456480818, 0.03785074608666556, 0.03379018558189273, 0.029033156377928596, 0.008980645066393273, 0.028180597483047416, 0.03746027293215905, 0.07510396066520895, 0.03357516801250832, 0.0469969774463347, 0.048217784081186564, 0.029410560947975943, 0.036390141783548255, 0.08369721312608037, 0.04276304106627192, 0.003931222400361938, 0.045248185750097036, 0.012176695978268981, 0.009850394645971912, 0.039433697038995366, 0.05664977251685091, 0.025446075912831084, 0.06641808817429201, 0.03275511773037059, 0.02672410510214312, 0.012319051777012646, 0.026571522932499647, 0.024814605779413666, 0.015559528921065586, 0.06640148442238569, 0.029757526437086717, 0.0267897296164717, 0.04564612278980868, 0.04878633535866227, 0.014740582954670702, 0.08202819339931011, 0.04932721258540239, 0.09514152724295855, 0.024748703065727438, 0.04001239241499986, 0.004966671927832067, 0.02315177089933838, 0.020272132741021257, 0.025660688057541847, 0.02944117644801736, 0.02385261614939996, 0.02468972989091916, 0.042323268949985504, 0.012240479118190706, 0.03327181196904608, 0.043390906482402763, 0.03471471329352685, 0.06365499179810286, 0.03838742318164025, 0.05806163086422852, 0.012645495822653174, 0.039425429089793136, 0.06860567150371415, 0.031468323564955165, 0.017853755903031145, 0.007243055135144719, 0.060658201176140986, 0.016525781447333947, 0.06506008175866944, 0.05631814531183668, 0.029851025169981376, 0.06520279124379158, 0.13771263110850537, 0.13913334773055144, 0.10366727904017482, 0.17083816789090633, 0.12360263110271522, 0.10482220671006612, 0.1407670157828501, 0.12110825494996139, 0.12905532494187355, 0.08414830320647784, 0.10606349831713097, 0.07886755014104502, 0.07624169425772769, 0.07891548864011254, 0.09156782579209123, 0.06664809118956327, 0.09613473287650517, 0.14247530911649975, 0.10222273226827383, 0.09425370488315821, 0.10812210571020842, 0.15391534167741025, 0.07373744542045252, 0.1413274449961526, 0.09137333051434585, 0.09295222721993923, 0.10939965822866984, 0.1506207420357636, 0.15388478046017035, 0.18962966597505979, 0.09358893734003816, 0.07307252181427819, 0.10087794371481452, 0.14690764913601534, 0.1153571821217026, 0.20938655654234545, 0.12100439838000707, 0.12308129907718726, 0.11658290135008947, 0.16043326764234475, 0.19536027418715612, 0.08324982106153454, 0.14743366305317196, 0.15067484841815063, 0.11040159660790648, 0.15427419170737267, 0.11625895516148635, 0.14244997261890344, 0.07445289274411541, 0.14791861203099999, 0.22664752389703477, 0.13658278887825354, 0.11710633683417525, 0.22072900219687394, 0.12684942116694792, 0.10203439808849778, 0.16030330104487284, 0.09334757564855473, 0.21825901259269032, 0.14306107482739858, 0.13559682321335587, 0.11674041646931853, 0.27408257712210926, 0.1268882876528161, 0.2489240456904684, 0.11438121806297984, 0.08796265388705901, 0.21234658413699695, 0.0842234306037426, 0.2623063033180577, 0.1421971640416554, 0.11281522030809096, 0.16258578428200313, 0.16737439589841024, 0.13368011106337818, 0.13451416630830082, 0.09848923582051482, 0.09781543019094638, 0.1204811664564269, 0.0610531424837453, 0.1520017779299191, 0.17457491452140467, 0.22373316170913832, 0.12775394905890736, 0.13877113216689654, 0.10666168800422124, 0.13078945688903332, 0.1837225572339126, 0.30172115404691013, 0.2170968178127493, 0.22443754891199724, 0.19814367911645345, 0.19457881897687912, 0.1128628398956997, 0.19858364122254507, 0.1260439729584115, 0.17862711208207266, 0.23392589762806892, 0.20053733353103909, 0.13332279452255794, 0.122046845299857, 0.15462677207376274, 0.175886264869145, 0.06315717779632125, 0.18425512579934938, 0.18065101919429644, 0.12554390622036798, 0.10087189796779837, 0.13672914888177598, 0.09453073037522179, 0.16425107206617082, 0.1145617626607418, 0.10768385351236377, 0.08126801704721791, 0.10463230511439697, 0.10370016084717852, 0.08150334656238556, 0.07725145614572934, 0.14661079006535666, 0.07294706747468029, 0.10721838527492114, 0.08419695416731493, 0.17440753350300447, 0.15114131410207066, 0.17911045971725667, 0.09677341074815818, 0.0864951726315277, 0.11762541612344128, 0.15947022289037704, 0.19017412247402327, 0.08411505499056407, 0.13517579223428453, 0.08505721443465777, 0.21499924893890107, 0.10097403105880533, 0.08828573155083827, 0.12415186448821, 0.08138104741062437, 0.13813976890274457, 0.09074683913162776, 0.12157682409243924, 0.21210839120405062, 0.12196326335625989, 0.07765323030097143, 0.14935967113290513, 0.08155300854040043, 0.2903470072363104, 0.10494065856827156, 0.16821961982973985, 0.15297922119498253, 0.0740263792020934, 0.15664421953260899, 0.10394927140857492, 0.129617681194629, 0.14989317607666763, 0.14156286950622285, 0.11333457101136446, 0.19060643070510455, 0.0779455771137561, 0.14996672927268914, 0.08692931969250951, 0.12995964927332743, 0.11906093837959425, 0.19884341156908444, 0.10985513164528779, 0.0756587308964559, 0.16360583954623767, 0.16664982906409673, 0.11873461731842586, 0.11522783977644784, 0.15286710006850107, 0.07933207521481173, 0.16128229136977876, 0.11794412402170044, 0.09012222729091134, 0.14326341396995954], [0.01923318875820509, 0.05525578338918941, 0.03913292960662927, 0.008161654995222176, 0.019530958762126308, 0.04861286788114479, 0.025769012780593972, 0.026663606919880425, 0.06095709585185562, 0.028134664054960012, 0.03933379632819976, 0.03197536564299038, 0.07876960361110312, 0.008021143963560462, 0.04631330591759511, 0.005450188348601971, 0.03556416789069772, 0.034010868918682845, 0.041412288189998696, 0.025582568320844854, 0.07557757810822555, 0.03709163503455264, 0.06557019760033914, 0.036256640018629174, 0.013503632275387645, 0.06556421970682484, 0.020429513849584118, 0.04794307917888675, 0.06501227896660566, 0.04154947440006903, 0.028176370209881237, 0.04167142749897071, 0.02359615875008915, 0.031188156455755234, 0.0402841185485678, 0.03111697473962392, 0.05748942228300231, 0.07392613243843828, 0.03679111187479325, 0.019983572153640643, 0.09035459839339767, 0.07344034207718712, 0.026283167601962174, 0.022231675717713575, 0.02296003556278135, 0.01306770830082574, 0.029863401648721526, 0.05371206533163786, 0.04382085680429425, 0.01351013348903507, 0.011462023880864893, 0.040141269963766844, 0.032993137636887174, 0.03548456555498498, 0.035087921124483855, 0.05874068156949111, 0.03545736987143755, 0.016937981293137585, 0.010003093014737325, 0.0291902915175472, 0.014535421106432165, 0.02076748705336026, 0.01581170815708382, 0.013788284501060843, 0.04690944642892905, 0.03246978357700365, 0.033650319158498726, 0.010568068412664746, 0.022448126692324877, 0.013929754811605173, 0.028186692423852425, 0.007339290060502077, 0.07866928220859595, 0.06744842324405909, 0.03259369085675903, 0.06330072187951633, 0.026673963060602546, 0.024609230192644254, 0.020013363233634403, 0.016901929031259248, 0.05101181147620082, 0.012958249576123697, 0.06247284130326339, 0.06077115690069539, 0.0269066004880837, 0.03830505920840161, 0.07523601036518812, 0.022242267649354677, 0.0213324268281992, 0.11411918140947819, 0.08314316214195319, 0.053504867878343375, 0.030584263681833233, 0.02719177688205881, 0.024435738966401135, 0.03956036256360156, 0.044716550170310905, 0.060751140117645264, 0.009122250235772558, 0.03547883532675249, 0.06157400632011039, 0.024682128602372747, 0.03868168007050242, 0.03919224035260933, 0.015482949458860924, 0.050688163843005896, 0.015126492961176803, 0.029971644947571412, 0.017833881612334932, 0.027408119291067123, 0.010277389947857176, 0.041549990086683204, 0.019989767178360904, 0.08308997856719152, 0.05896899503256593, 0.07884029338934592, 0.028717094766242162, 0.07059041357466153, 0.014206492774454611, 0.03407192349966083, 0.02907678617962769, 0.05247351500604834, 0.00622792264247047, 0.03548095914136086, 0.07169755880853959, 0.03374214530257242, 0.0352611511147448, 0.02819003420881927, 0.08476430443780762, 0.033616911486855576, 0.04730627406388521, 0.018223131707470332, 0.017666714332465614, 0.035914756756808074, 0.044789509648191075, 0.0401697582565248, 0.06431260079677616, 0.021506282767014842, 0.014378499705344439, 0.047471578765128336, 0.03408104979566165, 0.04630693108109491, 0.01956551315795098, 0.07256051964525666, 0.02392025082372129, 0.04368330418531384, 0.03046607305960996, 0.0387967053268637, 0.008944367191621234, 0.020495782972180417, 0.04342387989163399, 0.006238573521841317, 0.017554503300094178, 0.04245785976360951, 0.027551173132711222, 0.034576085196541886, 0.023651878349483013, 0.041255963899727376, 0.02911996136286429, 0.008271698956377804, 0.04740773540522371, 0.026908050856686065, 0.012292600785648184, 0.039590482733079364, 0.044387443722890954, 0.051793086874697886, 0.0827264737870012, 0.05352092880223479, 0.033009507294212065, 0.08577927747475249, 0.03784522620428886, 0.015561981825158, 0.0254207411115723, 0.012079775732542788, 0.022132969228550792, 0.032518230977335146, 0.030190628554139818, 0.04994097804384572, 0.04014178904305611, 0.034140123054385185, 0.03478625463321805, 0.019104460487142205, 0.04674494918435812, 0.04358518123626709, 0.0034377679860751542, 0.026673415143574988, 0.03773902868852019, 0.048270502859460454, 0.07101254378046308, 0.05300252804798739, 0.0397759161756507, 0.01387295125251902, 0.015839774061792662, 0.028609641960689, 0.01644837756508163, 0.0034697246529893683, 0.05481964143525277, 0.037465752102434635, 0.0461083849492882, 0.018977654166519642, 0.02797932703314083, 0.047484783056591234, 0.03568369183423264, 0.032429763581603765, 0.01713586246062602, 0.02570134078684662, 0.01774701725558511, 0.004309914066522781, 0.011414333047079188, 0.020991293347573707, 0.052718004743967734, 0.0856984910954322, 0.016339057091889635, 0.04995316453278065, 0.057012133965534825, 0.05438251221286399, 0.04940389043518475, 0.009496089104296905, 0.055508544468986135, 0.021678666284840022, 0.01303041771253837, 0.019241656875237823, 0.05568046149398599, 0.01683261837544186, 0.019543911995632306, 0.03633754853425281, 0.016103349293449094, 0.018444992302517806, 0.007662399106525949, 0.04374685916783554, 0.05053681321442127, 0.030449537161205496, 0.047755616916609664, 0.015305897620107447, 0.04338658082165888, 0.04799707021032061, 0.03409108193591237, 0.017794333198773007, 0.02291475352831185, 0.02972742323098438, 0.04779687523841858, 0.02070288034155965, 0.029626742204917327, 0.002008167008170858, 0.08934226485767535, 0.051382155889379125, 0.04629351305110114, 0.03450565665428128, 0.05569384220455374, 0.03729555516370705, 0.0317832791645612, 0.009837116563825734, 0.043139821384102106, 0.044138523151299784, 0.05831327914659466, 0.05908302962779999, 0.05191971168720296, 0.033565895831478496, 0.048744795444820604, 0.07340629997530154, 0.012365237959394497, 0.03576832550710865, 0.0468561067911131, 0.0416566218648638, 0.08875676377543382, 0.08200083486735821, 0.035969277045556476, 0.04819759427170668, 0.030540562633957182, 0.02923308332849826, 0.03371378253879292, 0.04140420683792659, 0.022025014307083826, 0.022131222000877773, 0.06066744282309498, 0.00617739001920979, 0.03423990162887743, 0.05983534175902605, 0.016759095713496208, 0.09339896789086716, 0.02967587492561766, 0.026503986645756022, 0.011370849130409104, 0.07912542737488236, 0.02597188118046948, 0.01585049321874976, 0.0624296118372253, 0.02246224700606295, 0.02714470012246498, 0.06548927551401512, 0.06485720657344375, 0.01653827666970236, 0.054553954263350794, 0.056989084130951335, 0.06370072505835976, 0.03965774251680289, 0.029193178684051548, 0.09095856919884682, 0.010322674526832998, 0.04428250828225698, 0.04238723783886858, 0.03821577078529766, 0.0026882537515900496, 0.014958689554727502, 0.01668141532822379, 0.034957869710134606, 0.03747924816395555, 0.03158910958362477, 0.04547866713255644, 0.029162254450576644, 0.04157887192975197, 0.04837570292875171, 0.06507254644696202, 0.008967386492128884, 0.015328179013782313, 0.032515835748719316, 0.015829682549727813, 0.04614638291033251, 0.05805067252367735, 0.04857289877587131, 0.041529247271163125, 0.08492781780660152, 0.039024730412555594, 0.0889653115134154, 0.04599297632064138, 0.03267899288662842, 0.02130516498748745, 0.04224350715854338, 0.014053106540814042, 0.01879302648428295, 0.08974965728287186, 0.037953177733080726, 0.018211355732221688, 0.043347191863826344, 0.029176032104130303, 0.04721505520865321, 0.029869277761983018, 0.022527905447142463, 0.02360987533549113, 0.041376030671277216, 0.02224806573108903, 0.009076008922420442, 0.11977549003703253, 0.07155478825526577, 0.03603568866050669, 0.01744134571137173, 0.034492197912186384, 0.041770734491625, 0.0086087646195665, 0.06373531677361045, 0.0537859951145947, 0.06540764775127172, 0.11160197933869702, 0.16148465765374048, 0.17814563720354012, 0.06688450636076075, 0.07802034488746099, 0.10639868104564291, 0.1385239961424044, 0.11016743417297091, 0.13932431462619985, 0.10640910334352936, 0.14967494564396994, 0.09926279288317476, 0.16830621446881974, 0.11985559788133417, 0.156225929835013, 0.10616508858012301, 0.1520147786608764, 0.10216551819550139, 0.13900074841720717, 0.09063429052808455, 0.10726751121027128, 0.16283566158797058, 0.22722402081957885, 0.0986501436148371, 0.08158827879066978, 0.13383727334439754, 0.14143534563481808, 0.13186759475086415, 0.15321623347699642, 0.07626969061259713, 0.08992612388517175, 0.1890740000775882, 0.1184357904962131, 0.09148479346185923, 0.09220580477267504, 0.14801812597683497, 0.0926230155995914, 0.13134736195206642, 0.1260674095579556, 0.21607695253832, 0.1647998033357518, 0.1363298310233014, 0.160496805661491, 0.1780783265296902, 0.16037996193127974, 0.05568988295271993, 0.14039568070854458, 0.09751442527132374, 0.08146186093134539, 0.10982761705028159, 0.11531915701925755, 0.15265891195407935, 0.12325694465211459, 0.12008828110992908, 0.12400133827967302, 0.1333852197442736, 0.20193860333945068, 0.05741239498768534, 0.06792107038199902, 0.09868345289890255, 0.062435589730739594, 0.078726991611932, 0.09524797581668411, 0.07803295206810747, 0.16816716907279833, 0.0911652170387762, 0.1874871373708759, 0.1057606070701565, 0.11970581806131772, 0.1691577352051224, 0.1649616067962987, 0.1747326467718397, 0.2375810029251235, 0.09772491361945868, 0.09696138530437436, 0.1631632854363748, 0.1294629887810775, 0.13826668209263257, 0.19844562719975198, 0.1326170095375606, 0.08155627229384013, 0.17195502296090126, 0.2180542442947626, 0.2792064393205302, 0.09783750972045319, 0.14780403460775102, 0.1437529091324125, 0.1221792817647968, 0.20735393704048224, 0.23104869201779366, 0.1531417846147503, 0.13686138178621018, 0.16532232958291257, 0.1384816826986415, 0.09062538814863988, 0.09745754368071045, 0.17653237948460238, 0.13399499202413218, 0.11151256199393954, 0.11706969594316823, 0.09222703613340855, 0.18140575369553907, 0.07900014266903911, 0.20157843695155211, 0.11759064798908574, 0.14726393430360726, 0.11288892956716673, 0.10614332796207496, 0.12905451069985116, 0.05706489006323474, 0.18403585042272294, 0.2646294986563069, 0.12383748564336981, 0.2169496299965041, 0.16398085228034429, 0.10376281677080051, 0.12420924140938691, 0.1614473925105163, 0.13541093175964697, 0.10145475276346717, 0.1665208259863513, 0.21885981463960238, 0.08239416126161814, 0.14392351997750147, 0.10912355554423162, 0.11296835209109954, 0.12184422117258821, 0.08238479747836079, 0.10132236379597868, 0.26308960414358545, 0.1583313425736768, 0.07744810916483402, 0.11200419454170124, 0.10602109666381564, 0.20803367985146387, 0.10978779383003712, 0.140018958066191, 0.09936077333986759, 0.07642740250698157, 0.1594464470233236, 0.1758539258901562, 0.1421869724456753, 0.10995145647653512, 0.1771192851343325, 0.09084876866212913, 0.13079240173101425, 0.08511235897562333, 0.1543022966278451, 0.15321712914322103, 0.10637102395828281, 0.09427003043570689, 0.13002298373196805, 0.1949987235878195, 0.16781825279550894, 0.17548074520059995, 0.13682991133204528, 0.06933717296591826, 0.1620370258710214, 0.10479422392589705, 0.09089950272547347, 0.1117218221936907, 0.08648012951016426, 0.08748609838741166, 0.08785478717514447, 0.1347950798060213, 0.177062613889575, 0.20138369740120002, 0.11662948956446988, 0.1398683368627514, 0.1809973298971142, 0.24285891971417836, 0.11348352980400835, 0.09178851930690662, 0.2685832136443683, 0.1626481009381158, 0.11426897480019502], [0.016851320496893356, 0.049045338960630555, 0.03552744896816356, 0.03137913692210402, 0.04029535848115172, 0.0164267560467124, 0.001443026853459222, 0.0062156407345485476, 0.029842892927782874, 0.0740575036033988, 0.07889921737036534, 0.08043777516910008, 0.012598861807159014, 0.024845301007319773, 0.026789665155644928, 0.038489071120108874, 0.03040469278182302, 0.04624781032492008, 0.03441348106467298, 0.025868363878024474, 0.033820370212197304, 0.05898434349468776, 0.01121497861043151, 0.04448344625000443, 0.06022492263998304, 0.01001366798300296, 0.0706902803587062, 0.009304269799031317, 0.04547213623300195, 0.06788510124066047, 0.009440810552665165, 0.015631192397060137, 0.11242370560233082, 0.0552839527704886, 0.003811093288407262, 0.059025571282420836, 0.03159984400761979, 0.014448407471978238, 0.06831840691821915, 0.02376318353760455, 0.09462272615305015, 0.031893880372600894, 0.018337488606838242, 0.08298696338066033, 0.026043079859976257, 0.047244992173675976, 0.051986286150557656, 0.056351620836981704, 0.023216501443779895, 0.021706823791776384, 0.04131836876539247, 0.01471064259697284, 0.03393153121162738, 0.018244860095105002, 0.01852717307130141, 0.034377576384161196, 0.02907233838258045, 0.02651228682537164, 0.04972286296210118, 0.06782723577427012, 0.009315050872308868, 0.017083503305912018, 0.03828058445027896, 0.07170262067977871, 0.08545661371733461, 0.04255936520972422, 0.030512427179408923, 0.05531651566603354, 0.0181114448434008, 0.031740327897880755, 0.02200311458935695, 0.01744959839353604, 0.08114630143557276, 0.04091066760676248, 0.03543853713199496, 0.010041677060403993, 0.07522367459854909, 0.02028735228148954, 0.04361735058150121, 0.0978956873129521, 0.05011772623817835, 0.028941421836082424, 0.02216805118535246, 0.04141214569764478, 0.03745049184986523, 0.055713377227740626, 0.032021244788276296, 0.017300013652337447, 0.06487467206482377, 0.08653550475303616, 0.05030524278325694, 0.06965093434389148, 0.05207986630765455, 0.04747471359691449, 0.004018428569127406, 0.02147296500126166, 0.05092787669439401, 0.05569989473692008, 0.007280967431142926, 0.011784072715922125, 0.025553559252460088, 0.024286444298923016, 0.018699688903455223, 0.05968856784914221, 0.08158724063209125, 0.07278140314987727, 0.030781717372259924, 0.061732003199202676, 0.047850347190563164, 0.005601686134468764, 0.08785911622856345, 0.03557806768055473, 0.09428955867354359, 0.03569622437602707, 0.06169278387512479, 0.041528663731047084, 0.041148209146090915, 0.057834816963544915, 0.01522494839238269, 0.04883132562307375, 0.061388711977217875, 0.02161529959578599, 0.029950247345758334, 0.09455163603914635, 0.03374515799805522, 0.04614878153162343, 0.031023574394306967, 0.061695403020296774, 0.002859635794136141, 0.014339394035882183, 0.03406259025047932, 0.012800827755459716, 0.017609417139153396, 0.024792066542431712, 0.03624280468959894, 0.03132639778777957, 0.03366583386170013, 0.033174737356603146, 0.09222495981625148, 0.007273755452063466, 0.03551442109580551, 0.01641438465698489, 0.02497587150095829, 0.03038825187832117, 0.016968936060688326, 0.03854107743661318, 0.03733635886705347, 0.02319271709503872, 0.04666631715372205, 0.022503371317205683, 0.07336016637938363, 0.048965906258672476, 0.00827111880893686, 0.051118548427309306, 0.005939626259662743, 0.033578876206385236, 0.0594730515565191, 0.04173782554322055, 0.010449201799929142, 0.036865889826523404, 0.07756306656769343, 0.027960507864398614, 0.04947302297555974, 0.033124413806945086, 0.018700189323031476, 0.025313910861898745, 0.03620290004515222, 0.010227234335616231, 0.03805499869797911, 0.06641497369855642, 0.06098910913403545, 0.06379918048956565, 0.007329507281870714, 0.050569969828107526, 0.06546446827373334, 0.038255346340260336, 0.021426207153126597, 0.05469067567693336, 0.01649468927644193, 0.03159452090039849, 0.020584593028096215, 0.042524410478238545, 0.0011478007197313542, 0.02377339718597276, 0.007991625145742936, 0.014299423234271151, 0.03282418580991881, 0.058587461576930115, 0.023394525283947587, 0.047918634954839945, 0.02712877151290221, 0.01973878894932568, 0.02927256388855832, 0.0319874062468963, 0.00935845760562058, 0.045312914598201, 0.06056373553084476, 0.02400404480951173, 0.022604359380368675, 0.029616306336330514, 0.027833576014797603, 0.04129499662667513, 0.06227679896567549, 0.010459088903319622, 0.0071462171617895365, 0.036042138135858943, 0.03895039350858756, 0.0014750193555041083, 0.026227727898263505, 0.02757684380880424, 0.07903024926781654, 0.016255943337455392, 0.02849253360182047, 0.01584803352930716, 0.00899218864339803, 0.014939880564010568, 0.03382440749555826, 0.03424863776724253, 0.017134074520851885, 0.046715039360736094, 0.01299100330964263, 0.01134473571021642, 0.025725425387333547, 0.013197164300696125, 0.03364917243431721, 0.020602416446698562, 0.014390757440456321, 0.01576690618614001, 0.03506080686513867, 0.045473812214498005, 0.014301253582483955, 0.023022823800731982, 0.06326351780444384, 0.04942903355030077, 0.04121401007952435, 0.07478289825043508, 0.04245868079098208, 0.07877471976514373, 0.022221209315050925, 0.03944538141201649, 0.03490914411044546, 0.061956530436873436, 0.04390105964349849, 0.02396227080108864, 0.039363916497677565, 0.02843652223236859, 0.03848247236705252, 0.023984623440940465, 0.08553253500057117, 0.01705084032645183, 0.05823720858565398, 0.00469162903027609, 0.08540296195341007, 0.029145603201219013, 0.04750878284020083, 0.07860134049717869, 0.03077178361958691, 0.03363092662766576, 0.03923566320112773, 0.01405811752192676, 0.04779833069603358, 0.01691058204908456, 0.05253094621002674, 0.04541612995256271, 0.05565357454387205, 0.08590742559837443, 0.02300464584758239, 0.036385364897016964, 0.018977455695026686, 0.03638980930138912, 0.02969150837244732, 0.05653268790670803, 0.01604526160684015, 0.07518976141831704, 0.07167581176119191, 0.04707869341863053, 0.010782438829275114, 0.030786765672798668, 0.00843650323804468, 0.022486533470717922, 0.02283951247643147, 0.012853973162626582, 0.02879068867436477, 0.0450939309916326, 0.01075655865549509, 0.019710410918508257, 0.06991294385599238, 0.0403317618849022, 0.05782467286501612, 0.018944578977035623, 0.018242790563298122, 0.011482358727205013, 0.03048158097746117, 0.04496998299977609, 0.016857356065884233, 0.024991847607972364, 0.04644293324755771, 0.00953136444357889, 0.04428799084520765, 0.06885421888104507, 0.024211467875699912, 0.04070630642984595, 0.08653770320649658, 0.03160658525303006, 0.044960106922579665, 0.01122359770150589, 0.02643640964691128, 0.014125659745851797, 0.060931182599493434, 0.029848487449011633, 0.007409287733025849, 0.0179809184545385, 0.020128759987918392, 0.023172805484916483, 0.028588641301861832, 0.004696012790580946, 0.006060707016981074, 0.06548048170017344, 0.014237072651407548, 0.026650723236213838, 0.05976239924452134, 0.01769190324869539, 0.032039032583790164, 0.030203480007393018, 0.02995316165366343, 0.045779610984027386, 0.03287852289421218, 0.039559507609478066, 0.050038259609469345, 0.032878726454717774, 0.01053925187859152, 0.06053225829132965, 0.020859135081991553, 0.029556072782725096, 0.07331197003700904, 0.003040905576199293, 0.06496880522796086, 0.04102309068132724, 0.027270076430535743, 0.09653962829283305, 0.03050330766875829, 0.04874816776386329, 0.02508791459591261, 0.009712682571262121, 0.00553277920698747, 0.03449681195031319, 0.06728767829814128, 0.028864679525473287, 0.007861178484745324, 0.007096179020923695, 0.020712997298687696, 0.014205335872247815, 0.10108974163553544, 0.16924978526575224, 0.09683306754699775, 0.08981240820139647, 0.14912282169929572, 0.12183469454092638, 0.07137453542756182, 0.17696307280233928, 0.15758983950529779, 0.1014994207237448, 0.15643730706402234, 0.14199080797178404, 0.08286917648677315, 0.18160281383565494, 0.11802470684051514, 0.08979353135717766, 0.11085312095071588, 0.22070129082671233, 0.1649322805127927, 0.1608608125575951, 0.12538662180304527, 0.09602145145514182, 0.1164728429700647, 0.12684879691473075, 0.10638812304075275, 0.08233104393418346, 0.26335624126451357, 0.1606751246643918, 0.13504871619599207, 0.11197533644735813, 0.0816825544461608, 0.1298026091286114, 0.17746634222567081, 0.09370688029697963, 0.1327724890517337, 0.1359981766768864, 0.12216079847088882, 0.0680782598044191, 0.13983082744692052, 0.07187152161662068, 0.14512439125350543, 0.1052198214456439, 0.11966236467872347, 0.13166438708347933, 0.08810827428741114, 0.1800501492938825, 0.1370540043073041, 0.11931643395551614, 0.20382180943020753, 0.078261509803789, 0.10452578868716955, 0.1288119615720851, 0.096082804591528, 0.1265752523073128, 0.08809299367879118, 0.09243089519441128, 0.13931876420974731, 0.1381916089781693, 0.1605673325913293, 0.20057576575449534, 0.1405241952410766, 0.1487317412559475, 0.1928348618426493, 0.12805664353072643, 0.11619743917669569, 0.16914109752646514, 0.1117400951417429, 0.10036846569606236, 0.16821435439799512, 0.08677626933370318, 0.13894257082470826, 0.138070761891348, 0.1562585945108107, 0.12068125286272594, 0.15395692230335303, 0.11966995070023195, 0.17624322857175553, 0.10641995990382773, 0.12921387143433094, 0.24917043532643998, 0.09108504812632288, 0.15425018513841288, 0.13555026214037622, 0.13019360814775738, 0.10453393789274351, 0.1321679822036198, 0.11980785615742207, 0.1358712227748973, 0.1352479476481676, 0.24722428832735333, 0.21216446533799171, 0.19274534950298922, 0.10701289094452347, 0.16676729704652513, 0.1027247260457703, 0.12183810078672, 0.2502144564475332, 0.12631137003856047, 0.21096197914864334, 0.22370698382811888, 0.0699616287435804, 0.1147860184844051, 0.08223214745521545, 0.11880091018974781, 0.1500815102564437, 0.14534129175756658, 0.12935474887490273, 0.17097083505775246, 0.08005264547786542, 0.10090046429208346, 0.1963837764092854, 0.19254766511065619, 0.16843809453504427, 0.11850899085402489, 0.14046924747526646, 0.1047327011557562, 0.1610700591866459, 0.13612473702856473, 0.16521470035825456, 0.19968722414757523, 0.17024816812149116, 0.12106586008199624, 0.13826414437166282, 0.18655259108969144, 0.1402471765343632, 0.19461873040667602, 0.15055873750575952, 0.20040180294641427, 0.10647414092506681, 0.11077401733824185, 0.08627344774348394, 0.07010421609239918, 0.09790737847132341, 0.1055130096418517, 0.13387945108115673, 0.10984935731227909, 0.16342746626053536, 0.07432231546512671, 0.2450632085757596, 0.07262127567082644, 0.07105362907584224, 0.06861261291695492, 0.13834810629487038, 0.1620264814368316, 0.10747732780873775, 0.07768128093864236, 0.1271163975553853, 0.1630737323846136, 0.16889649922294275, 0.13830615926001752, 0.13512136015508855, 0.14191189434911522, 0.08289738997284855, 0.10200106844838176, 0.09628250423286643, 0.08875184439654861, 0.11979256197810173, 0.11478885476078306, 0.16805389443678515, 0.16270139307848044, 0.16273109934159688, 0.13250714114734105, 0.07185083986925227, 0.19536319188773632, 0.11328885132180792, 0.1359150018543005, 0.09200478198805026, 0.0803630073953952, 0.1124822496037398, 0.11615952263985362, 0.18069160915911198, 0.22148596229297773, 0.09312644108597722, 0.07959996762552432, 0.15793601450111183, 0.13412727921136788], [0.06651646218129567, 0.019320758791374307, 0.05066340070750032, 0.026359881074833016, 0.07808186765760183, 0.024508433815624033, 0.010612476833297737, 0.067646867595613, 0.06620531316314425, 0.03422762353771499, 0.02034005748906306, 0.0725516104804618, 0.06592320544379097, 0.0073531058816505325, 0.012388891690144581, 0.03515469914834414, 0.041854065377265215, 0.02687002745057855, 0.04040913523307868, 0.024770171913717474, 0.02681342575566045, 0.03442636983735221, 0.028778223986072198, 0.04706844075449875, 0.01727135063681219, 0.024841782803248082, 0.050856362496103556, 0.017785992307056273, 0.11717756944043295, 0.02819957610751901, 0.02399797022475728, 0.05732959335935967, 0.030419420384402786, 0.019417521277708665, 0.0435965738392302, 0.011624296378743435, 0.01810416585898825, 0.07035205100796052, 0.042061710663672, 0.021937210179333175, 0.0343538310511836, 0.02946358167433313, 0.08476669288107327, 0.025240103215245262, 0.02667155595762389, 0.07477719177092824, 0.06202940509787627, 0.022674241701939275, 0.04517524323559233, 0.015566370250391108, 0.05362062934519989, 0.03215440728568605, 0.04570301455844726, 0.04742622887715697, 0.04329423899097102, 0.015482603406001414, 0.015632138953411152, 0.0563376667643232, 0.016996633860149553, 0.05270415923691221, 0.059434076505047936, 0.02818262799909072, 0.02854400726833514, 0.06308715298239674, 0.04545156644391162, 0.012817048983249282, 0.03293816612235137, 0.04733897605910897, 0.04593419822465096, 0.0352789728370096, 0.028291924723557065, 0.05283363389649561, 0.03353054076433182, 0.049005040765873024, 0.031125683736588274, 0.009587084891141524, 0.03622144440721188, 0.02699471843828048, 0.04615345324522682, 0.020091708583225096, 0.02153062860348395, 0.05429153423756361, 0.052442336321941445, 0.043266544584184885, 0.048466636799275875, 0.011216731775285942, 0.0027366379633479354, 0.03468872540231262, 0.021631102676370313, 0.023968594747462442, 0.005053005755014185, 0.006494845172190773, 0.04268678730087621, 0.010625821072608232, 0.028383152060476795, 0.0472562796037112, 0.07687592093965837, 0.07764219732156821, 0.03564154802422438, 0.012528821726196578, 0.03891849218468581, 0.021397691718967896, 0.056645202583500316, 0.03385002897786243, 0.024423272581771016, 0.061487940938345025, 0.04608889063820243, 0.02398336136580578, 0.04483760760298797, 0.03345580352470279, 0.029651237319090536, 0.008922787233521896, 0.05483111206974302, 0.04013385696868811, 0.01621273422746786, 0.030634431168437004, 0.02356495292458151, 0.043296064250171185, 0.03022186830639839, 0.008973247338352459, 0.03960044701982822, 0.04376490819933159, 0.023072557024923817, 0.02041562763042748, 0.035986749322286675, 0.034034315696252246, 0.03799644112586975, 0.02327284699172846, 0.0027575007947494407, 0.030783987071897303, 0.053875839936413934, 0.035461570003202984, 0.03143499731751425, 0.08792655582406692, 0.03742494500641312, 0.03088512271642685, 0.010257896484940179, 0.04054320357473833, 0.0743982842458146, 0.006581216318798917, 0.024649799801409245, 0.03485638462007046, 0.07706976482378584, 0.024846659773694615, 0.02623198740184307, 0.011260519336376871, 0.09400046204349824, 0.01743321686184832, 0.03525099005284054, 0.033023054245859385, 0.005624448439838099, 0.06230123979704721, 0.017490775291142718, 0.042591758471514495, 0.02871768848438348, 0.01603493939286896, 0.008714717014559677, 0.0840290438916002, 0.053951571229845285, 0.04430880829957979, 0.023896610663671578, 0.04486675746738911, 0.03130110539495945, 0.04864713729226163, 0.022056820636082972, 0.005023428413551301, 0.03867647231423429, 0.019180091696658304, 0.04896236091320004, 0.04218653735837766, 0.03346070254753743, 0.04176206620676177, 0.04038094210305384, 0.0030507962843070602, 0.07299128081649542, 0.015502689738890954, 0.016955465444230607, 0.03964999703956502, 0.06371539498546294, 0.06946172485394136, 0.06696586949484688, 0.028176492346184592, 0.017533918243965933, 0.10109858294682843, 0.03872902145875352, 0.06221664683627231, 0.009548328667213874, 0.012948031686911625, 0.028658842534891198, 0.039706152597708363, 0.11417969316244125, 0.018244955090007613, 0.026076989647533213, 0.05032793977963073, 0.07201113019670759, 0.060873961741370816, 0.031131227367690632, 0.01214977934224797, 0.01597245310300163, 0.05122074258646794, 0.010015497483046991, 0.02052974364986377, 0.029247529339045286, 0.049060490647596974, 0.02384986468989934, 0.03607371376295175, 0.06375544890761375, 0.04179219655426485, 0.027364774474075863, 0.019357791536354592, 0.051002712321600745, 0.051621875526117425, 0.044907703663089445, 0.016056747508368323, 0.033760492889476676, 0.030070982474301542, 0.013991887415094035, 0.0024916193921983775, 0.06704324284302336, 0.02339391120975571, 0.030073126644960473, 0.03573964383187039, 0.016062243642019372, 0.03843907326725977, 0.007818013479534005, 0.024795425290774022, 0.024196865802098597, 0.010959520353935659, 0.057079234293528965, 0.041974427311548164, 0.012942605951268758, 0.015967854331912737, 0.0335573564682688, 0.029949785941945653, 0.028081327809819152, 0.01843696692958474, 0.038638959505728314, 0.033089411578008106, 0.06119634051408086, 0.060012887232005596, 0.06453919078090362, 0.049354533797928264, 0.031923291472984214, 0.10603224499417202, 0.0648378479693617, 0.06142917302037988, 0.04277086118236184, 0.044732736623180766, 0.03085532145840781, 0.027031861445201293, 0.03988824425531285, 0.014138327146481191, 0.021091864111700227, 0.03366486355662346, 0.01253477671915399, 0.011458129089857851, 0.0477633284670966, 0.021431620166237866, 0.04307889911745276, 0.01969286230658846, 0.035263010300695896, 0.034644386531519036, 0.0710020943411759, 0.05760750773229769, 0.03719985797735197, 0.01000574863116656, 0.03870490971686585, 0.023792996669986417, 0.040193391631224325, 0.019757039844989777, 0.059972622963998995, 0.008378038116331612, 0.04416194957281862, 0.0364981543804918, 0.033423342409410646, 0.08196375292858907, 0.1296340881713799, 0.05317705064745886, 0.05577843516532864, 0.07280023249664477, 0.03300891357607075, 0.029114746821245978, 0.020971351203375628, 0.022657646431720684, 0.016965080285444856, 0.02470832344676767, 0.05701322640691485, 0.027518491493538022, 0.046865267013864856, 0.04096928285434842, 0.03327151680631297, 0.04390368218134556, 0.028279824747837017, 0.04426313950014966, 0.03983743216044136, 0.07257113193294831, 0.027995182700189095, 0.03788756000410233, 0.013816933097716953, 0.03038815688341856, 0.03689164023048111, 0.06132915695863111, 0.06317697066281523, 0.06042790639081171, 0.03296930409435715, 0.011219202490922595, 0.024522257270291448, 0.05052621110475489, 0.080243727724467, 0.06113268035863127, 0.03303774792168822, 0.04073638927989772, 0.020231303592611636, 0.03112505269902093, 0.07393749111465045, 0.04018473691706147, 0.05210475157946348, 0.06822391413152218, 0.039089683177215714, 0.04171950849039214, 0.0503843803224819, 0.02463049378379115, 0.04120531465326037, 0.010567401752008923, 0.0504548156500927, 0.027558058566812958, 0.021694242056193094, 0.06910099528197731, 0.0447724275290966, 0.05595791446311133, 0.016137601741190468, 0.029766924147095, 0.0651557891230498, 0.05617856726582561, 0.003068322207712169, 0.02438260119275323, 0.03651416441425681, 0.02800135567252125, 0.017327657168997184, 0.02393102935249252, 0.07993188660059657, 0.03811414659555469, 0.019755935529246926, 0.032557569045041285, 0.07192712077604872, 0.09645513711231095, 0.03546308992164476, 0.012261305054250573, 0.029266877765102044, 0.04612613881805113, 0.08460004468049322, 0.048584851170224805, 0.1626416277140379, 0.058837786716009886, 0.15099407200302395, 0.1333931993160929, 0.1784541399351188, 0.07737615052610636, 0.13205987800444874, 0.171836469322443, 0.15544577741197177, 0.21864447476608412, 0.08052475657314062, 0.13966977037489414, 0.20497626891093595, 0.14681006222963333, 0.2227427177131176, 0.17512303510946886, 0.08084260951727629, 0.11287453105407101, 0.19953836713518414, 0.16083775593766145, 0.12187854147383145, 0.12989782116242818, 0.137984710080283, 0.1375906305121524, 0.13459272709275993, 0.15773064909236773, 0.1034600001626781, 0.07742548680731229, 0.14212048958454812, 0.16532576297010693, 0.21374376916459628, 0.13765472493001393, 0.07838516602558748, 0.12610327691904136, 0.1402758378535509, 0.10128824705524103, 0.11771741190126964, 0.12821836556707109, 0.11565241270831653, 0.09183717026774373, 0.13577892844166073, 0.11792768990354878, 0.15464126558176108, 0.1317624489643744, 0.08667319986437048, 0.19249567575752735, 0.12551228648849896, 0.1042849901797516, 0.12712315576417105, 0.09792511537671089, 0.08338421170732804, 0.09043100822184767, 0.2121613576476063, 0.13905594045562403, 0.11216789111495018, 0.09422587816204343, 0.09801712472523962, 0.12721948059541838, 0.10310078372380563, 0.07947544966425214, 0.15518914189721855, 0.07735146542212792, 0.09520041729722704, 0.1360086803989751, 0.17255525503839764, 0.1477168428578547, 0.08865940078560795, 0.14364434352942876, 0.12470610546214239, 0.09027829713055066, 0.14479034846382483, 0.07183190874223198, 0.1863614884870393, 0.10846496945513145, 0.08183548945401396, 0.1488068550825119, 0.13626815219010624, 0.07156812146838222, 0.1410354578069278, 0.09239467499511582, 0.16047503825809273, 0.09894064481237105, 0.20443596504628658, 0.15168182152722562, 0.11650518194905349, 0.10561423349593367, 0.1953555787248271, 0.19509538768657617, 0.144798979429262, 0.12102026252874307, 0.08400969885821853, 0.14695256815424987, 0.12347863561340741, 0.15861571659999235, 0.18800802156329155, 0.18339420056768826, 0.16927105055323668, 0.13926308362611703, 0.10593919070171458, 0.10756873326109988, 0.18920887926859514, 0.13609218091836997, 0.12180528683321816, 0.1542105586933238, 0.15143573044666223, 0.1464971218790327, 0.07326445901500327, 0.17702552516545567, 0.2060235334294183, 0.11693949864378997, 0.10585843824914523, 0.12284978292882442, 0.12063580458717686, 0.12814403884112835, 0.10479682271501847, 0.1269476187548467, 0.08814332062112433, 0.13241310976445675, 0.13999788276851177, 0.13468198158911296, 0.1432962550648621, 0.13056378971253121, 0.057743336872330735, 0.10234447502131973, 0.16311487874814443, 0.15722953741039547, 0.14995436636464937, 0.12613757007888385, 0.07582934852689505, 0.12065784340458256, 0.1712927727827004, 0.1305497983204467, 0.11242139858326741, 0.20592923063252652, 0.1623096748122147, 0.11093375805233206, 0.0767601357240762, 0.09066726732999086, 0.16131073555776052, 0.11436244978436402, 0.0962055040789502, 0.16262813843786716, 0.12571771975074494, 0.08347843986536775, 0.09279393857078892, 0.14529302077633993, 0.25572882911988665, 0.08403000741132668, 0.11811576624001775, 0.10704453781779323, 0.10120722318866424, 0.13596074868525776, 0.18941777305943625, 0.13074730629367487, 0.08602240335728441, 0.09104156760232789, 0.0742093665259225, 0.18587348610162735, 0.15319955508623803, 0.15767811691122396, 0.10177125542291574, 0.09200959280133247, 0.08656481746584177, 0.14004483739180223, 0.1987722875284297, 0.08801989510123219, 0.09241011166679007, 0.09426253940910101, 0.3175210048045431, 0.262758913316897, 0.11818480039281504, 0.17603376481149877, 0.11444068487201418, 0.15895526909402438, 0.15317857478346142, 0.11456292974097387], [0.013467643626167305, 0.04050048640263932, 0.05519132595509291, 0.00213427422568202, 0.05174411700240203, 0.03497663459607533, 0.05102829309180379, 0.011683907376469245, 0.02716245568756546, 0.022263790780146207, 0.03706159628927708, 0.02622910193167627, 0.019747608208230565, 0.023894057675663914, 0.016129632347396443, 0.005993935778470976, 0.018220773798280528, 0.009912242264752942, 0.016003280645236373, 0.022778775110574703, 0.01292475454309689, 0.03884321890239205, 0.06063633877784014, 0.02866536325642041, 0.036247961555740664, 0.010472601080047233, 0.03216536562623722, 0.05760712775268725, 0.08215604975287404, 0.03608841761680586, 0.035734514107129405, 0.010382769828928369, 0.03344471626249807, 0.040126773063093424, 0.015450912427955439, 0.02240470045113138, 0.069237102621368, 0.013701688165643384, 0.041160327781523974, 0.04489374280508075, 0.08454444552106516, 0.022909169185108373, 0.03324891819751688, 0.024305657017976046, 0.0663223604538611, 0.006102344470231661, 0.022410900564864278, 0.03515392901109798, 0.03028126047658069, 0.020258419548294375, 0.03145194372960499, 0.04529227017025862, 0.021789893441434418, 0.009220298545967256, 0.046753617469221354, 0.0028570764448626763, 0.03747571638918348, 0.028756690677255392, 0.054350865339594226, 0.09262800961732864, 0.03088059349517737, 0.04776712487052594, 0.0412197063810059, 0.10534363373049668, 0.03154609724879265, 0.045701016272817335, 0.013472516355769975, 0.054651588667184114, 0.021987696577395712, 0.04555535516036408, 0.04345074987837246, 0.047036288372640095, 0.08134451508522034, 0.006753587538176882, 0.04058944573625922, 0.02356752796497728, 0.036831766300435574, 0.011476801525402282, 0.028043138162632073, 0.08309649928872075, 0.00399410690546834, 0.044590837987405915, 0.00934845260677061, 0.025298530169363533, 0.027560525041605746, 0.006301838854726936, 0.02478174602479807, 0.07746414973267488, 0.0010546188838946233, 0.02171406545676291, 0.04053329357079097, 0.06898181739130191, 0.07403247244656086, 0.013358384221126991, 0.10620283548321043, 0.03481261911136763, 0.021745524036564996, 0.005097024866180229, 0.0011636784391677274, 0.04050886631011963, 0.038167319992291074, 0.03725608138899718, 0.020939337921195796, 0.01571750035509467, 0.08039372467568942, 0.07151793023305279, 0.10229964421263762, 0.02493705420887896, 0.05262631430689778, 0.04581429769418069, 0.024419165748570646, 0.010508952745502549, 0.03302784809576614, 0.008806482938650464, 0.01936116215905973, 0.014746202920962657, 0.055581598941768916, 0.02718351232553167, 0.04649360624275037, 0.018746054897617017, 0.028508021163621118, 0.03260491721864257, 0.007581735711677798, 0.02375880189772163, 0.020917977638808743, 0.016054270855550255, 0.053340374026447535, 0.08682730195245572, 0.04148360561313374, 0.018091175306056227, 0.003507902001729235, 0.044722555205225945, 0.0090386284282431, 0.009042759010169123, 0.015268466235803706, 0.03606357644977314, 0.05172826303169131, 0.044553325178899934, 0.03427731604980571, 0.030961810744234493, 0.05485319159924984, 0.011481961784219103, 0.0516602432887469, 0.03278279517378126, 0.04716080294123717, 0.07299765226032053, 0.038986416932727606, 0.03161400164078389, 0.02579221867823175, 0.028728646824934652, 0.047204154543578625, 0.009406206963051642, 0.026912758193377937, 0.057661247705774646, 0.023366428845162903, 0.04812600204188909, 0.017564840781103288, 0.01746157623295273, 0.026284896169922183, 0.018277897965162992, 0.03712727508640715, 0.03756756288930774, 0.06073585272367511, 0.01841606805101037, 0.06145355956895011, 0.0514561162064118, 0.04815380162160311, 0.04129130878884878, 0.0861747751810721, 0.03409903775900602, 0.05887944198080471, 0.048884597407387834, 0.024974146325673376, 0.041015460555042536, 0.09048409680170671, 0.056812766806355545, 0.041695291575576575, 0.059260371540273936, 0.02686840744822153, 0.016420779849535654, 0.07050985789724759, 0.0072262138959818655, 0.027777778383876597, 0.07461113389581442, 0.023293942645458237, 0.045542999037674496, 0.013697512630772377, 0.030980039587510482, 0.04563534086836236, 0.04065102278920157, 0.05663524168942656, 0.03632691928318568, 0.07441015182329075, 0.03730781289881893, 0.07431139783667666, 0.05333609925583005, 0.021067552201982056, 0.0695142231083342, 0.04466568039996283, 0.013028293049761226, 0.026766773080453277, 0.030597973481885025, 0.01621534489095211, 0.06646680698863097, 0.009028140821361115, 0.03867155972069927, 0.005684064526576549, 0.04155155750257628, 0.020104325941896865, 0.03979813141216125, 0.07660697679966688, 0.06169327920568841, 0.007475889337781284, 0.005658875186262386, 0.007113098715698081, 0.06917317783726112, 0.03262686104114566, 0.0511519357429019, 0.037574606082801304, 0.051093761543078084, 0.009839462598652711, 0.09909944914813552, 0.019756078021600842, 0.02108681241848639, 0.026700315664389303, 0.04438176777745996, 0.050769557511167865, 0.05317469273826905, 0.07465028536639043, 0.03393474407494068, 0.0167375624046794, 0.0043772103215035585, 0.0680279057206852, 0.020022458995559385, 0.03406368608453444, 0.04302065706412707, 0.023266986145504882, 0.02763517407168235, 0.04584191746211477, 0.03746778431481548, 0.06934682173388344, 0.03608028198193226, 0.04630719231707709, 0.025915739193026508, 0.027713499065222483, 0.0790982927594866, 0.04224930524027773, 0.0325485784560442, 0.009498560668102332, 0.029654104129544327, 0.049672451202890704, 0.0610357244898166, 0.03726432219679866, 0.029377845382051807, 0.01323142777463155, 0.055533460274870904, 0.05684067155899746, 0.05332669476047158, 0.021297192201018333, 0.024235674612490193, 0.07721795687185866, 0.05435382714495063, 0.06799905441169228, 0.0202886533723878, 0.006785643652879766, 0.0793032239058188, 0.01939815758461399, 0.06284216112856354, 0.07421130713607584, 0.04784508175881846, 0.029125908722302744, 0.01672013253638787, 0.0928081131673285, 0.033552440482058694, 0.027279564046433995, 0.04278424528560468, 0.03305692671399031, 0.01851251332222351, 0.04862572951242328, 0.021096674924982444, 0.034834230451711586, 0.008135751920885273, 0.10022304885621582, 0.04752906085923314, 0.032858577357339006, 0.016713024882067527, 0.002904399173400764, 0.0158085784143103, 0.020536050632862107, 0.011829673661850393, 0.05007002522636737, 0.020898332353681326, 0.020054324696372663, 0.06154394043343408, 0.011976504399042045, 0.034204292111098766, 0.017695704741137366, 0.012929129397629626, 0.01502614950628153, 0.07310515934867517, 0.021976821357384324, 0.026599797486726726, 0.021062475063705018, 0.026048993292663778, 0.0274196526900466, 0.04859137189175401, 0.048613037514899454, 0.06374263138111148, 0.028311398678592274, 0.07376985903829336, 0.03514876535960606, 0.010359279794751533, 0.04945090951930199, 0.013930744624563625, 0.08418298991663115, 0.02293737927850868, 0.03631948932473149, 0.023299922235310078, 0.03662468759076936, 0.04458824598363467, 0.06291687461946692, 0.03374432339998228, 0.06142251659184694, 0.03700982067467911, 0.0034210781450383365, 0.005764866172934749, 0.007821545254306068, 0.03605546795630029, 0.05913174844213894, 0.033331787679344416, 0.024177327386236618, 0.01988652807527355, 0.009729616260821266, 0.04433009394311479, 0.03168773804126041, 0.03268391905086381, 0.024376384115644863, 0.031240084740732397, 0.006732047444009888, 0.07583590317517519, 0.04140798967065556, 0.020666334445455244, 0.011792671450945948, 0.050832023444984636, 0.018288167592670237, 0.017365405768422142, 0.03722088917025498, 0.05409184138157538, 0.05078014944280897, 0.029669211711734533, 0.11537911237350532, 0.036703485862485, 0.2587108819612435, 0.22013924670006546, 0.15724014969808714, 0.06556502716349703, 0.1332159795399223, 0.09868722555360623, 0.1565320169819253, 0.2326929180749825, 0.06659317735050406, 0.14146260917186737, 0.10304846188851766, 0.1929624942796571, 0.07776543285165514, 0.16681940853595734, 0.09635017453027622, 0.1308883194412504, 0.18298401257821492, 0.07823251600244216, 0.12450349490557398, 0.17117807322314807, 0.093139604665339, 0.12550319411924907, 0.14190817597721303, 0.13466720309640678, 0.11896054233823504, 0.1252555695495435, 0.06428842459406171, 0.2972846749637808, 0.1511012262531689, 0.10621977850262608, 0.21015928579228266, 0.1053048622395311, 0.10588443971105985, 0.09849093894341163, 0.15464007136012825, 0.14320504638765538, 0.10149147507867642, 0.08270737302622624, 0.09540158257420574, 0.1013191407546401, 0.14865913800895214, 0.14549941755831242, 0.15142286542270864, 0.14807748422026634, 0.17925534051443848, 0.194124648347497, 0.06332704903823988, 0.10403494324002947, 0.14532332415027277, 0.0928415988704988, 0.09344446366386754, 0.16226651998502867, 0.21151839143463544, 0.09455926277275596, 0.12768206505903176, 0.1464075552565711, 0.10884738500629153, 0.0875167071021029, 0.11136014945805073, 0.22053636610507965, 0.10009114843394075, 0.15301396218793734, 0.09139654319733381, 0.15879774040409497, 0.1395043706787484, 0.13588739904974187, 0.1187313332089356, 0.13790236307041986, 0.1404738343719925, 0.11166455383811678, 0.11359001230448484, 0.14172452368906566, 0.15080130020422594, 0.1262354962527752, 0.163519217765757, 0.08569025368030582, 0.1337758387838091, 0.09698157172117915, 0.10376024512307984, 0.2415721459048135, 0.14746053303991044, 0.14192789420485497, 0.08145069903028862, 0.09906895578439746, 0.14603346533008985, 0.19993155103709015, 0.23754696760858807, 0.13892002989138874, 0.08416958885001284, 0.1633836328983307, 0.12531008305294172, 0.17236963499869618, 0.1171022927654641, 0.0947444417646953, 0.18922747112810612, 0.19998051412403584, 0.10244229262960808, 0.11810942872294358, 0.11146672016807965, 0.1531467107789857, 0.14235052652657032, 0.11540029623678752, 0.07337083294987679, 0.0818613280675241, 0.16812619912837232, 0.15781047195196152, 0.28234287244932993, 0.10289774569017546, 0.0968888159841299, 0.17692868464759418, 0.07953579178346054, 0.05296707459326301, 0.09978695439973048, 0.026738929395963038, 0.10709542115884167, 0.07925019639411143, 0.11500808942530837, 0.13604438491165638, 0.1234183952744518, 0.16222921412970337, 0.13282553691949162, 0.09502842902605023, 0.12531042232045106, 0.1761221643537283, 0.09958285106612103, 0.11849125394863741, 0.19558963259415968, 0.14764048052685602, 0.0961999808038984, 0.18508258568389074, 0.19928232873124735, 0.15852051813687595, 0.09449786213891846, 0.1719653366931847, 0.09073649825794355, 0.14290164623941692, 0.1859937496483326, 0.17618445386844023, 0.27801034493105753, 0.1491408978721925, 0.12001665495336056, 0.07028345790292535, 0.17497237319392817, 0.09061766642012767, 0.09923074567424399, 0.13141919166914054, 0.12977963393288, 0.18439299054443836, 0.07793724470372711, 0.1438558836068426, 0.12253529551838126, 0.09714435905750309, 0.12164238414594106, 0.20726062490471772, 0.05726937337645462, 0.12830396954502377, 0.17178177939993994, 0.12231637297996453, 0.171095875490989, 0.1429654285311699, 0.10114617539303643, 0.19857195684952395, 0.13114115515989916, 0.23179806609238895, 0.20696415938436985, 0.13413197467369692, 0.10240123447562967, 0.1321427814130272, 0.15464203911168234, 0.11666568262236458, 0.15805061906576157, 0.1496776190719434, 0.15325965971818992, 0.10193837859800883, 0.22782860909189495, 0.18601306075496332], [0.0569497901680214, 0.01161023967766336, 0.04063821204804948, 0.03295083776382463, 0.05824687092431954, 0.08002521230706147, 0.05797586403787136, 0.03905051813593932, 0.038127384813768525, 0.020342834393626878, 0.044632048811763525, 0.03478750992300255, 0.008480031259490975, 0.028777419922075102, 0.05176071057628308, 0.07700584003967897, 0.03706859537799444, 0.0040384521375277215, 0.03028339786188943, 0.0101789913439591, 0.014918771339580417, 0.021791338721024137, 0.03853129974699446, 0.02673195575230888, 0.0031451433980172233, 0.01823166598166738, 0.04975067950519068, 0.06008566689810582, 0.012281410895021898, 0.04423979111015797, 0.013409820568215634, 0.04709158219130976, 0.024374043169830526, 0.023118670264791166, 0.03212371375411749, 0.019195122943658913, 0.03825801976823381, 0.021311566965388398, 0.04446686624682375, 0.024282016857926334, 0.032535296133054156, 0.06281194596418313, 0.008626889138083373, 0.030017384993178502, 0.0235517045283424, 0.020284103795087764, 0.031127967006926025, 0.02452698496303388, 0.020818660468129174, 0.03975095287231462, 0.034692277533135245, 0.016320141231907264, 0.026986694761684964, 0.09012819161372525, 0.029144609147416692, 0.0723960834688374, 0.010587030921929648, 0.04140230015452419, 0.02850841810660703, 0.011638966305846614, 0.010097606157484864, 0.020074948768264482, 0.02912311315802591, 0.011989390627214951, 0.027740362266610776, 0.018219627074099014, 0.009707162688885416, 0.04278643695371492, 0.0061913669924251735, 0.03107339922072632, 0.04311594034412077, 0.0487483102562172, 0.02850118831598333, 0.03948472287239773, 0.03984022093936801, 0.13859738649002143, 0.006135783524119428, 0.03898298693820834, 0.022914901109678403, 0.007546575723348984, 0.007646479826819683, 0.03568119143268891, 0.03493472488064851, 0.035076043368982415, 0.008361829611073648, 0.017549217512298907, 0.01973808157656874, 0.024611808625715118, 0.03461570146360567, 0.08908559541617121, 0.03800180494519217, 0.015034210502303072, 0.03371641864734037, 0.05425505958763616, 0.058489922167999406, 0.052789495193532536, 0.02319517678448132, 0.025637373594301086, 0.012123877964248615, 0.01615424790153546, 0.03931985243356653, 0.02402297254385693, 0.019221984448709657, 0.04080436831074102, 0.04562966153025627, 0.024868394946679473, 0.057365779631904194, 0.02669711976445147, 0.02164580992289952, 0.013645570775094842, 0.02479857369326055, 0.015708104341423938, 0.02029677034754838, 0.04185476087565933, 0.058044117875397205, 0.024699979162375842, 0.07074191008827516, 0.02898197787414704, 0.021835458764274205, 0.025894621486908624, 0.037994446232914925, 0.04609756910109094, 0.07299157937190362, 0.016616611841267774, 0.03594412035974009, 0.06998028845659324, 0.05126165485541735, 0.027946636912279894, 0.026281530636229684, 0.018423752460096563, 0.05622545064293912, 0.06699818811778512, 0.04590668362964477, 0.060594018548727036, 0.04016945291576641, 0.05217736500448414, 0.016553046680720787, 0.02100216856758509, 0.027212696116683737, 0.01624967367388308, 0.03923455040369715, 0.017412640287407806, 0.014544055464544466, 0.055621130391955376, 0.037669271895928044, 0.016854005799229656, 0.012123831314966083, 0.04703988121556384, 0.010705849189045174, 0.05274417244696191, 0.02993887849152088, 0.04924109970618572, 0.05523164789857609, 0.02584026743923979, 0.0369257332224931, 0.0801329297412719, 0.04383727056639535, 0.039562513519610674, 0.051345246977039745, 0.014826761991051691, 0.07983958548200981, 0.028695500389273678, 0.030799155722239187, 0.06578106592808451, 0.028217080614662597, 0.06510453937309128, 0.024494545900129845, 0.03741884158392038, 0.028367922341983234, 0.03221664251759648, 0.05859461333602667, 0.02207318690073277, 0.06780746326382671, 0.022366749987538372, 0.03818922649536814, 0.02148256796811308, 0.03612221883875983, 0.01550980078588639, 0.006831675044460488, 0.03801825941939439, 0.03440581701163735, 0.060717016591557434, 0.05417038180998393, 0.08104340159999472, 0.029251787146287303, 0.030158150475472212, 0.060483139141329696, 0.09860795909272772, 0.04496800846287182, 0.008880660386889108, 0.02998952773798789, 0.015154058446309395, 0.051966245618781874, 0.03803276649809309, 0.020832146351624812, 0.04501045422096338, 0.01564684959261545, 0.05197413698104875, 0.015572838385456374, 0.051392880135348866, 0.009270868912738348, 0.0348034487105906, 0.061510671861469746, 0.0417560272450958, 0.04466068638222558, 0.017473136773332953, 0.0508712020569614, 0.04764483928946512, 0.03630147761266146, 0.02287764105546687, 0.02025837205084307, 0.04172914368765695, 0.03548949171922036, 0.020638439870838608, 0.030547941702284982, 0.029339094247136797, 0.017102556569235663, 0.028896139801612923, 0.02306928818247148, 0.010444983856619468, 0.05904114366109882, 0.07749785256705113, 0.05164307974545019, 0.029901338541614156, 0.04538297333887645, 0.042650953866541386, 0.04352707828262022, 0.02704648726752826, 0.022955855787066475, 0.05382718558290175, 0.02559355380279677, 0.11193873626845223, 0.03793969184958509, 0.02032593378264989, 0.03185855583953006, 0.011366741449039961, 0.01599821198864707, 0.023155599533181106, 0.004533458276585276, 0.036683397833257914, 0.05782348542873349, 0.02037610126925366, 0.0345262264433716, 0.04239100031554699, 0.060168197112424035, 0.00765341699921659, 0.025934434529127817, 0.05289071226226432, 0.032040664460510015, 0.045650319528899024, 0.06229961809835263, 0.047539320308715105, 0.01682020118460059, 0.06797058308230979, 0.024531615964536155, 0.030613193022353307, 0.04886989016085863, 0.003221424516855872, 0.012550821527838707, 0.043318123423627446, 0.0173955751316888, 0.03533326242385166, 0.020262326213664243, 0.05784696274037872, 0.015441406152344175, 0.0303560553916863, 0.10834016650915146, 0.07005458804113524, 0.06312910001724958, 0.053880667713071616, 0.045135413229997666, 0.05947535179023232, 0.03765375380005155, 0.061424728616007736, 0.04502568733213203, 0.026064920205889002, 0.035313612049711604, 0.020779651489907076, 0.005524521011726132, 0.013685555995575019, 0.01681209438746529, 0.013593466919181603, 0.061426017832543166, 0.04620168012167726, 0.014030864162902747, 0.015721384968076433, 0.02934083468945963, 0.02032509070288922, 0.013227917204078819, 0.026465118463550295, 0.0764493802562356, 0.02901949068265302, 0.0627549761640174, 0.0420801871722298, 0.04743363169421043, 0.01896267380964543, 0.022133123595267534, 0.06994154410702841, 0.03545185338173594, 0.007269367026830358, 0.027273241796397736, 0.06715908912675721, 0.03467053048578756, 0.017147241492888758, 0.024772770702838898, 0.024064129085413048, 0.05092177666457636, 0.09968952355640275, 0.08963003155908414, 0.08509747191731419, 0.014053527232525604, 0.020735816431364844, 0.04550391881327544, 0.06876490331654038, 0.024774253301854645, 0.03964598350492971, 0.047408033960631916, 0.048960267632667503, 0.050414361392280886, 0.0341372528512563, 0.04456335731915065, 0.021076513953240852, 0.03447463403322867, 0.06229393197489636, 0.02622574318333396, 0.04763235424512199, 0.028924862188952308, 0.008790725659179901, 0.06298903681870018, 0.021123819718403474, 0.05703455276255097, 0.06572009277130876, 0.04638146136754325, 0.04374333757108875, 0.007627831988169679, 0.03126400649281485, 0.02115792628111584, 0.08058638790888445, 0.04771250280152474, 0.0018064966466876545, 0.004874869108399642, 0.05518783828509705, 0.05383373344583171, 0.039572691544890404, 0.08429478534630366, 0.013586552647341574, 0.035383518120007854, 0.025489190027916005, 0.041931645678622384, 0.06721058993467263, 0.023707548755088022, 0.042881876296762905, 0.16375485940703324, 0.08620287331619433, 0.1586028380053384, 0.09533393941819668, 0.11620339671415941, 0.13539175636001996, 0.18304680420884065, 0.1514571857239519, 0.15324493550828525, 0.24706477831516946, 0.11452308616467885, 0.14162401908210345, 0.06807952866490398, 0.13032651958721025, 0.09865543618798256, 0.1324782898383481, 0.1183528463755335, 0.10241493409765617, 0.09111333625125033, 0.16740043807242597, 0.08716522596244301, 0.0841508341420974, 0.12889258510300092, 0.12826390883752278, 0.10215450557214872, 0.10773010245923485, 0.16571555419691972, 0.11822331404047352, 0.0934741495709334, 0.1298691462725401, 0.07034042091774088, 0.19704532091106686, 0.13070430074419292, 0.10280541743018798, 0.15614461419837816, 0.11459814570844173, 0.11381994746625423, 0.09576856145369154, 0.10542839632502624, 0.17603428049811295, 0.07877953057842595, 0.10611119932894196, 0.08030876530600445, 0.1113388773852161, 0.15060400936220372, 0.12043514821146216, 0.11166964963610683, 0.08191197392131601, 0.13862558640539646, 0.10676112731120416, 0.11177579965442419, 0.14191665766494616, 0.17515928245016507, 0.190000553216253, 0.10668915510177612, 0.15376577898859978, 0.13936585454004152, 0.115645953054939, 0.07629259116947651, 0.10784949748111622, 0.06760066614619323, 0.14671776789639676, 0.09946460276842117, 0.08372799147452627, 0.14815532575760568, 0.10831271976764713, 0.14635510449962957, 0.12088629257466112, 0.13782977339412483, 0.11829598514097077, 0.17187449442488806, 0.1305934688342469, 0.14110789820551872, 0.10158655140548944, 0.16328791874860013, 0.18285035475024156, 0.10827039275318384, 0.11032351079796042, 0.09436374969248261, 0.11178637801536492, 0.13318772534174578, 0.14152633718081883, 0.19382343308201858, 0.16457265695290907, 0.07643886974879674, 0.11870003917387553, 0.15163572185805865, 0.15061825859759534, 0.11287438177636691, 0.16156543046236038, 0.1825874631426164, 0.12804038583167962, 0.14473806055528776, 0.12467079449977193, 0.18873680888542108, 0.2983044316726071, 0.16082859571490968, 0.14813534968665668, 0.10003252979367971, 0.11983674817851611, 0.13340047321149281, 0.09981069634003298, 0.08211120537349156, 0.06488549469837121, 0.13919422589242458, 0.19475884788802691, 0.20549906657210418, 0.109487535298935, 0.12072766465800149, 0.15475399738975934, 0.09091810815568481, 0.08965633157640696, 0.11677442464445319, 0.10279802818383489, 0.15725530817040376, 0.1019713282585144, 0.17226538487843104, 0.11815362849405833, 0.1387667352599757, 0.059642698881881576, 0.0994171460292169, 0.11340712676090853, 0.10385390331170388, 0.13593320016350063, 0.1343794906777995, 0.20279304177633353, 0.16444579804582254, 0.11611591997955527, 0.13557694213730948, 0.16131342255643435, 0.1498189036335264, 0.19534943119755813, 0.1452303919941187, 0.18794094159134797, 0.19079312283013547, 0.11238473055085965, 0.13870474430067198, 0.11221781093627214, 0.09994287496166569, 0.09294717891940049, 0.14440337994268962, 0.15308370201715402, 0.0862730202664222, 0.2010452305631978, 0.09396285763276474, 0.1338818666658231, 0.0826587967042412, 0.20607432856091432, 0.12115753016301564, 0.12275427233959947, 0.10583374635981661, 0.14217755437961646, 0.18791066535881587, 0.11465366344366755, 0.11139651214970009, 0.34870538860559464, 0.14012827005769524, 0.10086277845714774, 0.15036185378474848, 0.11997624140764986, 0.19816867634654045, 0.2110265213996172, 0.08612153053815876, 0.15531251313430922, 0.17060300122414315, 0.19020610861480236, 0.1287819838949612, 0.17448301373847894, 0.21134773987744535, 0.19198036912296498, 0.16226915270090103, 0.08935892967773335, 0.14782892327223504, 0.13592923751899175, 0.07905239665082522, 0.09931993231709514], [0.05714356619864702, 0.0030456135490177466, 0.053686501524810276, 0.014879679240818535, 0.06015886047056743, 0.0486017195507884, 0.012466429583063083, 0.0662064870287265, 0.029378571414521763, 0.037703765223601034, 0.011810230240891022, 0.035172537833984406, 0.054519776454461474, 0.06502382084727287, 0.04490088438615203, 0.024143838290391222, 0.033115019489611895, 0.040564285657767735, 0.03628667537122965, 0.08989533875137568, 0.0729714133111494, 0.04043804082487311, 0.056116189541561265, 0.021536855858617594, 0.028898351825773716, 0.04441112459504178, 0.04934077989310026, 0.029169860828135694, 0.007811053406580218, 0.014302781982613462, 0.019847108583365167, 0.026148563217637793, 0.01527088351680764, 0.053150021204991, 0.02492807719058224, 0.010287858046857374, 0.03304856376988547, 0.049081257211842706, 0.021652103335197483, 0.02726880248103823, 0.015807969429131066, 0.030378033140940324, 0.021082362925101603, 0.027974176952349286, 0.030439376099301235, 0.02353796249787722, 0.0685311412172658, 0.029362785297312906, 0.051634933932551315, 0.02290822093241981, 0.024013574833848646, 0.010152922876711403, 0.02354477159678936, 0.061080154962837696, 0.022678570755358254, 0.046835611640874825, 0.02198347439324217, 0.050190672145358155, 0.029073335829057863, 0.041464291113827906, 0.044041614779936414, 0.056263116121824296, 0.035011762353990755, 0.022090837292905365, 0.025148366977061545, 0.04331180286992874, 0.04846645698749593, 0.05832015949168375, 0.07021679183734314, 0.02947406504037125, 0.03568973758124879, 0.013689066566127752, 0.04685733833217195, 0.0238752130618585, 0.0218919145741633, 0.04856267325314028, 0.061809485112982135, 0.01197704128987555, 0.03364962366010461, 0.03778810712641903, 0.04357111181265541, 0.0164595360734633, 0.0673639727756381, 0.006277708029041865, 0.055786292600844584, 0.023563585676518933, 0.039783827893968136, 0.046068344597837756, 0.057085449674299786, 0.043920957682920356, 0.05106324443061437, 0.05617850280499884, 0.026346658123657107, 0.028564702586403916, 0.043110332252191644, 0.044642135234815736, 0.058383711081530364, 0.006083594427244472, 0.03219852563259857, 0.025218681864706532, 0.026840295742398927, 0.024256430998710648, 0.016708020686304996, 0.029413359904927865, 0.05739057330148561, 0.0037835155048274566, 0.05675380550591009, 0.032063992494451146, 0.041065410910440345, 0.06935242643313748, 0.10711509867438249, 0.03657779064295547, 0.0841112280530589, 0.05703577412558453, 0.05760089201586587, 0.009066118426354868, 0.019384157710841725, 0.013498309168166347, 0.03318058632846389, 0.04526365634852222, 0.01676515333487519, 0.025374003619487797, 0.030865716614893506, 0.048934137249099355, 0.030925783927419355, 0.025967082241550088, 0.007876496412791312, 0.010173845504011427, 0.04235692089423537, 0.01781633130407759, 0.08235122356563807, 0.016346685521836792, 0.03811923560819455, 0.029160232416221073, 0.05634993128478527, 0.03097226018352168, 0.045924091445548196, 0.058630039649350305, 0.026843055683587278, 0.04388203352157559, 0.011228009027295878, 0.027650512355778898, 0.0635086250092302, 0.03982417019350188, 0.01703630101733974, 0.020261064138529555, 0.045906782017222474, 0.02749138741221811, 0.04947462771087885, 0.13938169154737676, 0.07087767137480633, 0.04722520948520728, 0.029431232517319064, 0.036796489264816046, 0.004964792385830411, 0.05548550481242793, 0.03775761715535607, 0.04758874140679836, 0.03923346135499222, 0.0895687055640987, 0.05997053986149175, 0.09426704488162484, 0.01569250482134521, 0.05924350315971034, 0.018800627772829363, 0.026369994639285972, 0.017764469176264744, 0.03238709729963115, 0.04186498639839036, 0.03199217974075249, 0.020931979208918552, 0.027322679857856462, 0.031427105955247364, 0.06635818710284573, 0.03979498300967472, 0.033482965281499286, 0.04151305403294308, 0.03389388608879276, 0.02909663672159825, 0.030143697679575, 0.01421295412416969, 0.00752152590679803, 0.020141436718404293, 0.08811493071594409, 0.060189408117106984, 0.046643745686326704, 0.04158106020518711, 0.03071707334103329, 0.033148077715720446, 0.010747646946193916, 0.00637482844259856, 0.026648182122569, 0.06177011651120015, 0.05258970055729151, 0.028406456345692277, 0.03843707837430494, 0.011306460397983236, 0.03820258006453514, 0.020529434916430285, 0.04178115678951144, 0.03706433757075241, 0.03437790208097015, 0.04580519175423043, 0.048731889708765914, 0.013171044095153255, 0.05106029958863344, 0.04186022986790963, 0.041913335411144156, 0.040637994916843515, 0.026512415747025182, 0.03486579250810402, 0.06787927941020046, 0.07018627811755453, 0.018365395055817704, 0.053123585480664454, 0.03770983811201794, 0.018834551131086688, 0.017550800195229904, 0.02033159276470542, 0.012907052412629128, 0.035806818798716576, 0.055451170940484316, 0.0517106482626072, 0.037573693453201225, 0.009028414779874896, 0.03452930699235626, 0.027496513744284, 0.03166732431522437, 0.013364901549981108, 0.04967462930030056, 0.01473913767508098, 0.017830465188516036, 0.009483434426199113, 0.010659320346478905, 0.053144396149686406, 0.04287416135360088, 0.004099391367552536, 0.029709146890257086, 0.07873681001365185, 0.05937095917761326, 0.00424562838660287, 0.026739689355183924, 0.049883794505149126, 0.017259993656937565, 0.05455408657767943, 0.022721277749431983, 0.04173007667330759, 0.06041500065475702, 0.056461791175284555, 0.0318792681209743, 0.036739427862422805, 0.01804118593489485, 0.0703461884653994, 0.032330015541187355, 0.030520070876394, 0.08005022310784884, 0.03309751328613077, 0.06988438431705747, 0.030879015901259015, 0.0648386622113841, 0.011981457704678178, 0.013317682298033364, 0.06290554308465549, 0.05991802803639855, 0.011269470061441618, 0.08000267815909215, 0.029242491216531823, 0.04445846598329289, 0.034804554722670994, 0.03758523194119334, 0.039691357141626735, 0.034801474173686335, 0.11832966761929647, 0.03413405016596828, 0.02386506557065461, 0.020971559852893864, 0.0891301751668964, 0.028941727176840817, 0.023386143680129732, 0.02107462932222656, 0.04063672266368355, 0.018178104123632823, 0.019554833016757454, 0.05587047165525811, 0.07394688882465873, 0.04303265356325677, 0.024174838859055723, 0.026146000051604848, 0.044458778109401464, 0.03416834332581077, 0.04628861063559141, 0.024867741856724024, 0.016033887663590055, 0.01882283792032727, 0.08059994503855705, 0.0020607237862090445, 0.03472317123253431, 0.04577411485037633, 0.02415911041732345, 0.04754293350768941, 0.010040798357554843, 0.010569892823696136, 0.013808124016837349, 0.04648830009890454, 0.04178695487124579, 0.03724138092781816, 0.03232875007337757, 0.010572426303822016, 0.06781369900064808, 0.04233862080478242, 0.02005767835570233, 0.06171205426965441, 0.016020713906202997, 0.0865363868485604, 0.02796090650372207, 0.020731697723801647, 0.0801284106980477, 0.01721709158404597, 0.02967285205210958, 0.025068496620016437, 0.018948232888111045, 0.03807658289692231, 0.01361010714234518, 0.03682805471388357, 0.007368615495839289, 0.06945635764194386, 0.014163828188819545, 0.012135579300645207, 0.03757669597065874, 0.032665758061089685, 0.01526597940496036, 0.060729888400861194, 0.021643631825489656, 0.0462250556530697, 0.014855194304670607, 0.05764572282454797, 0.031144628434308937, 0.02855096903762647, 0.05583751181672726, 0.07554422811205898, 0.023691647286925997, 0.06255805851625544, 0.03313001172084894, 0.04485789240737047, 0.05751602764108351, 0.07647964291806732, 0.009803782682865858, 0.04069077137059399, 0.007835865735874643, 0.017543577189956392, 0.014602606251303638, 0.0714971467054316, 0.18439962661692075, 0.1366971084581954, 0.08032787963747978, 0.10033953974821738, 0.12512919918767043, 0.07002452893980912, 0.11573705316654273, 0.2361421287059784, 0.12041761486658029, 0.1967128658933299, 0.10614069524620261, 0.1578490398824215, 0.1179853653801339, 0.15814371407032013, 0.19654107439730847, 0.09581243552799736, 0.09564409098987069, 0.1025965100686465, 0.13172556380076067, 0.20197305934769766, 0.12109287934643881, 0.13637815628732952, 0.14923153657998356, 0.10607090791953461, 0.12715387982981546, 0.1559748583074127, 0.10676257259079389, 0.11858624885124819, 0.07873659288244587, 0.1764258901987757, 0.1872011348605156, 0.09946678765118122, 0.1021921710510339, 0.11925415801150457, 0.11728515795298985, 0.15048149307923658, 0.13701531424054078, 0.11331904613013778, 0.20347273030451365, 0.16964941525033542, 0.10088298523000308, 0.0964554628091199, 0.10944482151951108, 0.1309750633580344, 0.13577625501368726, 0.13328239454754762, 0.182100790685841, 0.07147014779703957, 0.11334406371627535, 0.1274544708430767, 0.07211527853671994, 0.15403650089034013, 0.09779082651117019, 0.18487468255417688, 0.15361466923994677, 0.09221484285912343, 0.0952886947031532, 0.16956755678568566, 0.2274828954998936, 0.13126857046570095, 0.06898417190781661, 0.14371672964521817, 0.1341415691588606, 0.14759157172271184, 0.1516250552875655, 0.14266991295984813, 0.22460252791643143, 0.11050203336136681, 0.17804685607552528, 0.1870628222823143, 0.13227042742073536, 0.10269250241773469, 0.16497126913496427, 0.08698014875075646, 0.08908545970916748, 0.16966652790350573, 0.15499537943729333, 0.15217184594699315, 0.14340503779905184, 0.2296680361032486, 0.19898449257016182, 0.12876331061124802, 0.10350403708538838, 0.15498410218528338, 0.2667749178196703, 0.12201112721647535, 0.12358186793114458, 0.1299823530550514, 0.14044836216739245, 0.1875837743282318, 0.16242508004818643, 0.2869035777236734, 0.08527484775653907, 0.16441366262733936, 0.12141340571854796, 0.11490644487951483, 0.2764461860060692, 0.1514386617179428, 0.07754851877689362, 0.12418262926595551, 0.12088219422314848, 0.10993369921509709, 0.08225204888731241, 0.08951888073767934, 0.11604223107653004, 0.0675564528043781, 0.1106400473841599, 0.11117910274437495, 0.1103061470868332, 0.19149195961654186, 0.17804676108062267, 0.07714086172303983, 0.18221318322632993, 0.12898490657763823, 0.10476213600486517, 0.1445059065840074, 0.15009981713124684, 0.05964107718318701, 0.16281248283173355, 0.20796383145664418, 0.11420513822564057, 0.08510211988219193, 0.1470647571342332, 0.1565697163875614, 0.09482363358672176, 0.13720605043428286, 0.12680260225066117, 0.10090465085314852, 0.1443971645619188, 0.13704008076872143, 0.2200763329331364, 0.08667655861271278, 0.16363767640931265, 0.1456600132265261, 0.15986848223422254, 0.11647098378411361, 0.19884681781487806, 0.15145003396485532, 0.13559581898152828, 0.08576458719159875, 0.1181045975536108, 0.11672924778291158, 0.1780647694000176, 0.08937545200543744, 0.0879037706181407, 0.10551347783101456, 0.09650171175599098, 0.12055636170719351, 0.17364149460835115, 0.20569402325366223, 0.09403794431792838, 0.09668733179569244, 0.16062489950231143, 0.12919367823217595, 0.06657858206225292, 0.11466694915933268, 0.10592248516955546, 0.123655855389578, 0.1117151996919087, 0.3622183049363749, 0.16575705339866026, 0.1290599661214011, 0.1269408469753606, 0.22121043636330537, 0.12346416924680982, 0.10442984383553267, 0.1168360627655472, 0.0727611556649208, 0.1764534522912332, 0.16620228093649658, 0.08586579747498035, 0.13270920887589455, 0.09825712256133556, 0.12151853793433734, 0.11374713387340307, 0.12271049326019627], [0.020392107910343578, 0.05623889242165855, 0.020532081203003014, 0.04062046157196164, 0.008968444158589202, 0.052455954519765716, 0.05023591686040163, 0.007339171316873814, 0.027448325883597136, 0.03356591279485396, 0.07085874024778605, 0.0502830716515226, 0.04028364357405475, 0.08837282152048179, 0.013199314408536469, 0.034842569647090774, 0.007057649682142905, 0.06546978120292936, 0.04412956309637853, 0.03217945879857455, 0.005694313373948846, 0.0629760700144938, 0.07198405664946352, 0.04038418550044298, 0.020849007946838225, 0.04081189665677292, 0.04580586689657398, 0.025622172713545815, 0.014330125247527446, 0.0574211005919746, 0.0017371254528240699, 0.019667683568383967, 0.03942389560065099, 0.028168193862906525, 0.039018840728593726, 0.06974691990762949, 0.07863364554941654, 0.0387940929670419, 0.029393139561372142, 0.05135589319148234, 0.011249305697024932, 0.07052336074411869, 0.011495937909265714, 0.08666843654853956, 0.04279886092990637, 0.05309523628758533, 0.03115796504010047, 0.04907621569665415, 0.03064815453918917, 0.018983581169907535, 0.04548770861167993, 0.05055325072524803, 0.09674897670213665, 0.05483982106670737, 0.08406853462968554, 0.06610895440514598, 0.08953874145767518, 0.07789592192109142, 0.028657719559435333, 0.029524792318365405, 0.04612853743934205, 0.021860910612823706, 0.04789591760241559, 0.03153070128921952, 0.04616268810683063, 0.03865433171657579, 0.028209445399365256, 0.03127989099760141, 0.021147173197407807, 0.05954159716410296, 0.045984735512839894, 0.030416333050067936, 0.020005711054961597, 0.045687102912259955, 0.019016278076118658, 0.07323907501995564, 0.03863215379949127, 0.025908823224848936, 0.036753103735723665, 0.024716588003294807, 0.046972947128649266, 0.020707462149273072, 0.00974862796387502, 0.07229620311409235, 0.012979075512183564, 0.05803858781499522, 0.10014597406344754, 0.028704779355653694, 0.04718332351850612, 0.037655409425497055, 0.01751523817490254, 0.021387793589383364, 0.001403738509647415, 0.0029821635273817393, 0.03727056811164532, 0.08052139103944812, 0.022953170484730175, 0.04632768068196518, 0.03284173611817615, 0.07584108718271766, 0.02847947519538658, 0.02289049929407026, 0.03342521855873721, 0.020301292783447673, 0.032493427129728455, 0.027317207472931062, 0.028127091604151895, 0.038644123157220225, 0.05269922628732664, 0.038309198272015364, 0.06742645228015524, 0.05868313501455954, 0.029726340967629637, 0.031186131028724567, 0.02860172345702137, 0.00616051146062091, 0.0032390246550286455, 0.05040463459278856, 0.062113353450383456, 0.051386875100433826, 0.011305987119807728, 0.01738570923251765, 0.07448203582316637, 0.012984329917734223, 0.04865125260714974, 0.03823690715112856, 0.04893553503123777, 0.011876011666442667, 0.04516342315556748, 0.01012361525291843, 0.01502459226841373, 0.012368895263145012, 0.02062100830620953, 0.032911160428609164, 0.008138531369955411, 0.01569197726036821, 0.026130061264016798, 0.018668913947684423, 0.0249332679834749, 0.057512818170445304, 0.02332335035316646, 0.001875659085011908, 0.014081814509284283, 0.0192409138793924, 0.04686088028496929, 0.04588810194815908, 0.029666925048721687, 0.04243895917066506, 0.007644349226861128, 0.04493064832474504, 0.009041210253989058, 0.023458448371716907, 0.07709013444504567, 0.04400869904618178, 0.025802427237587314, 0.037925825986479006, 0.012004892607884747, 0.03889565948130829, 0.056649803050926754, 0.06375601209167923, 0.07421730538564068, 0.07933437544852495, 0.0334156851417252, 0.04502592821206365, 0.02335198622729097, 0.03056117652782372, 0.03952264619458999, 0.04136883820007954, 0.07853339200041123, 0.04658937128260732, 0.01711989992431232, 0.08206862051572118, 0.0652620205655694, 0.03415993966960481, 0.039538530699376545, 0.03572055324912071, 0.0387233556913478, 0.06770317921681063, 0.018443857452699115, 0.01994070570383753, 0.01821122002521796, 0.02783090597949922, 0.06746147825781788, 0.03899291729820626, 0.017123240012941614, 0.01354411621910653, 0.042423695525420566, 0.0738262656543936, 0.007287734121616397, 0.05338794950928007, 0.021889051156384603, 0.03337751415425113, 0.057943694692637236, 0.042499589667256386, 0.05355607352352568, 0.0162879193002092, 0.034835556987673044, 0.016956562974623272, 0.03186667451102819, 0.015470801985689571, 0.031798325678599734, 0.011830402238826667, 0.04793834300445659, 0.029640709848276207, 0.022787455269800763, 0.036003956970359595, 0.046311555297247, 0.04367150446133954, 0.05007168085181287, 0.03603189564975245, 0.04436013608106545, 0.03586693021601864, 0.06024110570017781, 0.018379411892965436, 0.09490206544952733, 0.03436615324712225, 0.015680817055648992, 0.05982538765030248, 0.027421942745734538, 0.03314133986298527, 0.03759871782468898, 0.07728256697633437, 0.06215127677257572, 0.03969247333173241, 0.009225806553981133, 0.026704410623226846, 0.01482899606760059, 0.048544274776109626, 0.03390318541122334, 0.04344963708094188, 0.03688358262713466, 0.07291491848549672, 0.018809959325673323, 0.09772173129022121, 0.030038419578756605, 0.0135445080730798, 0.011451513373426028, 0.031459753667669635, 0.09022271832717316, 0.02011628681793809, 0.03471113741397858, 0.059168796454157145, 0.02648051272678588, 0.04622112354263663, 0.0509039854763874, 0.03716197536726083, 0.03799604079020875, 0.04224828065239957, 0.06629156853471484, 0.013766325411519833, 0.0609982218593359, 0.006108603955778692, 0.02627718461943524, 0.024724827114758745, 0.048087583389133215, 0.01933709452194827, 0.0616845464599984, 0.08156755633120026, 0.014224204234778881, 0.08194557497543947, 0.05229814763047865, 0.03676969052425452, 0.11344377443726573, 0.02584673896698015, 0.03190930008089968, 0.06730242964944669, 0.028296160478410975, 0.009349966588030969, 0.053768217497106106, 0.046924849173852375, 0.02903499181515404, 0.06622729091239826, 0.015228352941838759, 0.04043034963043673, 0.016158777122784938, 0.04180001327767968, 0.04288679567564811, 0.0706500160906996, 0.020065406869564737, 0.008482854813337326, 0.020756700042901293, 0.013251010295269745, 0.00837958517617413, 0.07251563455377306, 0.03627504528101001, 0.03305155271664262, 0.035617850188698084, 0.031209048548979417, 0.0460809755272099, 0.03971575386822224, 0.02030139965271311, 0.0501375835654991, 0.0122042351701696, 0.03439381033448236, 0.04548234139968242, 0.0327861369587481, 0.04402621882036328, 0.039696893987378905, 0.03368751644822104, 0.03581784838544471, 0.052344342294548235, 0.07662361447832414, 0.01706151368229517, 0.041117939698909006, 0.03932259710771697, 0.019047500865001763, 0.028939613540257727, 0.04715701671583312, 0.0166059554487999, 0.029746622379337038, 0.0041103658233104, 0.07296702997492892, 0.0496000583017511, 0.02904810450438942, 0.02546207237589572, 0.038666548739586554, 0.035059096956891675, 0.015627658925950527, 0.016949172031932642, 0.04482874254296933, 0.049147556868514845, 0.04557925316372088, 0.007238762552982995, 0.07596798001655511, 0.018674622123528804, 0.030564708302595785, 0.005429463344626129, 0.03649515525570937, 0.014663438612063016, 0.05071658088958689, 0.036634607772741995, 0.037525181592042954, 0.01852238939941994, 0.016356242687574456, 0.022554797486269047, 0.008545492925415081, 0.01730214255595846, 0.03377725948978748, 0.007519587841151016, 0.029724746410335814, 0.007685688124703509, 0.03027942164668015, 0.04988914475377117, 0.031597811795238934, 0.07489205417888505, 0.03507149039900728, 0.02499351341144315, 0.010087197430298796, 0.05056597325684769, 0.0664504271532808, 0.008054259865145599, 0.016338951918961744, 0.07594180213553564, 0.14679403523249285, 0.10704896186611482, 0.12133128941059113, 0.1136562983904566, 0.10617707150855235, 0.23372290709189006, 0.11940399211432252, 0.07655983897192137, 0.08577504341623612, 0.17169707108821186, 0.19736868355955395, 0.12852362490126065, 0.13592982105910778, 0.2189758848398924, 0.08372027653136424, 0.13453613727220468, 0.15892645849713258, 0.21876906736620835, 0.08166829842541899, 0.07186563193265881, 0.14674326724239758, 0.10894536546298436, 0.10772459275488343, 0.11903013288974762, 0.09282228776386806, 0.1443389326866184, 0.06089883004980428, 0.13480974973312446, 0.09410375542938709, 0.09765112293618065, 0.1268435993364879, 0.13482512533664703, 0.13623569107481412, 0.11554436279194695, 0.09838467357414109, 0.1267090594129903, 0.0826853613502213, 0.17873358779719897, 0.12060947742845331, 0.06053765264472791, 0.21033094158130033, 0.12284420537097113, 0.12411264516413212, 0.13698297526155198, 0.1369057579764298, 0.13601808489433356, 0.09198911461446967, 0.1310565418430737, 0.09540359782321112, 0.09407613226877791, 0.1549432815185615, 0.11604248891983714, 0.1804421389741557, 0.1967713963240385, 0.15878919086286, 0.13761265575885773, 0.13748723534601076, 0.08478948487234966, 0.05482543273163693, 0.10759932840509073, 0.13683801304016793, 0.20508313817637308, 0.05869936557220561, 0.17433183613632405, 0.09839653436626707, 0.12587215432098933, 0.13159787708095141, 0.11144442350736686, 0.09000244550406933, 0.15120112017861434, 0.10875608811953238, 0.1322106620562928, 0.15163127066833632, 0.10092857599790607, 0.12337217346898147, 0.10387245445911374, 0.10766370102230992, 0.1749422869512013, 0.14274390041828156, 0.0992342062028391, 0.1067263116793973, 0.08772912248969078, 0.1796993331185409, 0.1042650548209037, 0.1328238541526454, 0.22846146513308796, 0.10083253615136657, 0.10062840567635638, 0.12082453231726374, 0.14230742598218576, 0.09185519215783902, 0.11919025358344827, 0.11824462004005909, 0.08302108690674816, 0.08075952968959298, 0.18007487510996206, 0.17236329748162202, 0.08248940043683563, 0.13904147408902645, 0.14025005352284226, 0.19348449126950332, 0.12009377724358014, 0.10946174418287617, 0.10150615857647997, 0.08202148947332587, 0.13788349979690143, 0.2509289266807692, 0.1770826442433255, 0.15817266037421568, 0.12670455394046648, 0.22680294912840637, 0.10018743255308696, 0.1112178878060409, 0.0979280737893922, 0.11939555113869053, 0.07454319218439714, 0.20495051172162804, 0.07692219024258, 0.13640676332371576, 0.14995618483849935, 0.13660982171339647, 0.11811390705406666, 0.07628326131297009, 0.1591151590858187, 0.16310114519936697, 0.09115328160779816, 0.1653481681964227, 0.07483906059392861, 0.12810376100242138, 0.0863162497324603, 0.07941463935588088, 0.07852910365909338, 0.13813199289143085, 0.05732313370598214, 0.07503078066344772, 0.120673286861607, 0.08734511916658708, 0.0735266517315592, 0.13595247055803025, 0.1485251544841698, 0.07328976837119885, 0.06974032454724823, 0.08316386424537216, 0.1930894481816462, 0.15326189888375147, 0.10748333284365279, 0.1505347987903016, 0.04825454371582184, 0.10282244187380586, 0.10923228399561984, 0.09577460720070771, 0.11534837473716054, 0.12045990116894245, 0.16420090118689196, 0.09883372804948262, 0.05691805508519922, 0.09664463837231908, 0.0732035469263792, 0.14767496367650373, 0.15832921197371824, 0.1671074873634747, 0.11683699914387294, 0.13166117082749093, 0.12152471260300704, 0.09543123455452067, 0.1131830405709999, 0.1606872568705252, 0.20619594917765685, 0.10767920554748603, 0.10029159446379968, 0.13734542152711324, 0.1332326036478792, 0.13810236805251666, 0.1406508641583579, 0.1284805243568761], [0.02980780927464366, 0.03459227504208684, 0.022223541779177527, 0.05539459469062941, 0.01666221787620868, 0.03109590961996998, 0.02815117111562618, 0.019429772227470363, 0.059571174505565844, 0.03111936996823975, 0.06632657415632691, 0.05506729314635907, 0.04841350411464061, 0.0716563378061567, 0.022851274880979742, 0.07655482459813356, 0.04477761832198926, 0.021089730119066577, 0.05200761589886887, 0.050669100401656966, 0.017246288945898414, 0.01904566373143877, 0.04104478344587343, 0.037725152647388835, 0.028943464226488556, 0.03962586833430188, 0.027554611608918225, 0.049824768743876896, 0.053258135582187345, 0.02112248639709183, 0.035956886996115954, 0.03236179472878575, 0.0706333512706416, 0.039136284962296486, 0.007647677441127598, 0.025128360372036695, 0.016922329186594913, 0.029766920754419904, 0.08139640265809638, 0.028051185587953244, 0.032461356172072034, 0.020674275001510978, 0.08846668326961142, 0.024732633660148298, 0.02061484381556511, 0.04045016624565635, 0.02276283293031156, 0.044343125208147934, 0.028156039604384984, 0.004429919345836554, 0.040475899686238596, 0.023416268938620175, 0.012213194376922079, 0.017271956229316335, 0.008996910398959048, 0.05212122301704117, 0.040614032452659946, 0.04199434909969568, 0.02298072918451258, 0.020236151725319878, 0.022224423874701773, 0.017376576151166643, 0.03970611188560724, 0.03221399283834866, 0.03774662488805396, 0.03539219997557146, 0.039356092988912544, 0.021895397155146514, 0.030201152632279054, 0.030706254100160937, 0.03453515935689211, 0.11913797924561159, 0.017137567279860377, 0.018314487966043607, 0.013582487374411097, 0.050488660976822884, 0.026651561226961867, 0.024237504960702996, 0.06459686625748873, 0.03800925865237202, 0.014909495765875493, 0.05400373700207897, 0.0606407221140606, 0.09985001065901347, 0.05916228251797812, 0.03233951163877334, 0.03699807184083121, 0.016423448188496486, 0.009506452878537987, 0.0061232501341562185, 0.019804929150268435, 0.03788413679493325, 0.02474206020789487, 0.01320132880937308, 0.0730709611837353, 0.02276406447137041, 0.10830285386847598, 0.05563968153936522, 0.01222927141602018, 0.01351019031634288, 0.03991461891148772, 0.0849914847474013, 0.08831776518906866, 0.029384386459631578, 0.035115272871085575, 0.041125613929969926, 0.08928526113075869, 0.03012427461466619, 0.017137728431927304, 0.02908108809164592, 0.01876332700651671, 0.0905671427026391, 0.051806406517113955, 0.01277445734012872, 0.05530705688787358, 0.05643580328407032, 0.023615162819623947, 0.06014054002506392, 0.0697650367926274, 0.01487517885730735, 0.05204993952065706, 0.04730283389134066, 0.032849396778536696, 0.022116757330617735, 0.04762866979997073, 0.03602894402242132, 0.08363172771143061, 0.034351927760456286, 0.009672484460419841, 0.01607909505920751, 0.041189253729368956, 0.03689853075359549, 0.031113212262945514, 0.07391831571502344, 0.06039224259023156, 0.009402914371873652, 0.03094037582299539, 0.09159609356096812, 0.026165000728464553, 0.008721336123666592, 0.02769989104542349, 0.036310722652290545, 0.04136873981250184, 0.08402776824576513, 0.03046590681853039, 0.02969746251723596, 0.026429541176185012, 0.027809917195034877, 0.06722563305603606, 0.046324973327240775, 0.016366156084196906, 0.03631907541837011, 0.06123153612549816, 0.05747180751391819, 0.013977416807652583, 0.03075414170910205, 0.013132181001960166, 0.05595222833965506, 0.017825196364096234, 0.012275903735176792, 0.1131248561931508, 0.047025550555969985, 0.048678970762661526, 0.05164497625082731, 0.08710170829934732, 0.054580763181937594, 0.05831458871918065, 0.055487537024808783, 0.01888782630807587, 0.051396469585597515, 0.04629328574186989, 0.04957575657005821, 0.07207107876560517, 0.0482122438427593, 0.025193335189084922, 0.054133632353373935, 0.026237210425149118, 0.054746732847498994, 0.03815936756187251, 0.018896513252652118, 0.020309555643637265, 0.023825881869665215, 0.013531630326594626, 0.013261279922776988, 0.0569614406142916, 0.04699013442067163, 0.026313102870647396, 0.08271714393049479, 0.05486432296623077, 0.03484716332916703, 0.03866573449756418, 0.02244068485950785, 0.05690789402329496, 0.00814440833138568, 0.01956210012680718, 0.02653774376293378, 0.008554827870934137, 0.04234312627730625, 0.03068322122895292, 0.028137057587238293, 0.04983890262831535, 0.06254925113171339, 0.027277972881815264, 0.015906302724033594, 0.026388639085260884, 0.06283292626695973, 0.01568286623140531, 0.005744855327066034, 0.0452407727550183, 0.025905718927138617, 0.010326808501434113, 0.04409185690539224, 0.0031008019827173223, 0.047839890965925794, 0.03218064284218209, 0.05468961376962917, 0.025474988289975693, 0.03653005909706865, 0.015400042657607367, 0.030385093297809362, 0.017067087847473364, 0.018223360713039125, 0.06178732415927308, 0.0235105886988874, 0.027536940860695074, 0.009557426973645176, 0.022972808984507407, 0.05204535601660609, 0.035236197989434004, 0.014841737258913261, 0.05701678193041256, 0.01967818389779755, 0.10165733617863484, 0.04089081706479192, 0.03948588316727962, 0.032596462672310214, 0.016196878560419594, 0.07844788301736116, 0.043734251987189054, 0.029730208617235934, 0.04470228736421891, 0.019255772099963257, 0.05510834112231221, 0.032559258597237725, 0.046531468496790955, 0.03473969356023839, 0.07022941258869, 0.027722043517444814, 0.05249313484611256, 0.04289785918912717, 0.025804987010945166, 0.05508118615086589, 0.009634910583762186, 0.06395875835525137, 0.034352375593568595, 0.030655669314520698, 0.02396583480627409, 0.029603658443582908, 0.023805118698094572, 0.04023047356999346, 0.015546141425147653, 0.05450687411108187, 0.03969641562019076, 0.01371381273825786, 0.018001622254295007, 0.05014252330043486, 0.035394880188895125, 0.05987534818372556, 0.009049107553437352, 0.00958058876650674, 0.02538760655027415, 0.008634017148454274, 0.13819766151053564, 0.014610750367864966, 0.04795738948243005, 0.06400863746447222, 0.03406899222838027, 0.045515416589166434, 0.013624176565956856, 0.048870568695877276, 0.03339091861354453, 0.055442248204989095, 0.05896418421928372, 0.006520120601635426, 0.014655014599806495, 0.05786071664520672, 0.038329591642000845, 0.07594151036547762, 0.05755288566329649, 0.08957637979515962, 0.10782562661916018, 0.07049460443002836, 0.030198418136153902, 0.03734857928273933, 0.017284627870789597, 0.02522807618203972, 0.03395872689517481, 0.021994870388880372, 0.03805965344820704, 0.05514145363122225, 0.036716364457138946, 0.011756944037707788, 0.13077389129570552, 0.03417071819837604, 0.051558659811105044, 0.05750288441777229, 0.04748485430276819, 0.012545913175147558, 0.015453104096065675, 0.03776639061314719, 0.029890485373990874, 0.09971013745026928, 0.025020931315209185, 0.052286931446620395, 0.040405464358627796, 0.007765687403402158, 0.02723843464627862, 0.014871570747345686, 0.023324868575270687, 0.08191381275121655, 0.015226963641388076, 0.015934665487813096, 0.02846108011103102, 0.02911300298624805, 0.06831626274756022, 0.012852062238380313, 0.011405285630774285, 0.017264658585190773, 0.0352159165777266, 0.020562337079484547, 0.006801174471287855, 0.05928269534238747, 0.023966564231419137, 0.03630229864003403, 0.06582728773355484, 0.04262442314731223, 0.030661911836692264, 0.028376088510932665, 0.05094708602077194, 0.027303319557436874, 0.013508913822339048, 0.047065733399774344, 0.015788256290501783, 0.013822164602710732, 0.02646580887293177, 0.06737326192004339, 0.05597240797110966, 0.035723060436014614, 0.06453843760703291, 0.022447080052058612, 0.06202266045979091, 0.06837287292416606, 0.1301312100674425, 0.14110339273299488, 0.12617468594440392, 0.13844228695545877, 0.11142640161727156, 0.11438014597765037, 0.06894292376403298, 0.07306995016655751, 0.18787478442702973, 0.17161095142364502, 0.15190184329237255, 0.1438596426908459, 0.22120651443089756, 0.12048415201050894, 0.07848740089684725, 0.13864215623055184, 0.09521348588168621, 0.09588313887694053, 0.0747115977906755, 0.10440940636077098, 0.08330304534839732, 0.08211667436574187, 0.09481891776834216, 0.21898220878626617, 0.15627230091818742, 0.10445994364895991, 0.06739818451127835, 0.16169230294014725, 0.10946287055100713, 0.11971888664577689, 0.0938459053369505, 0.12879985650735243, 0.1582860028637307, 0.2172514559434993, 0.14426012762955256, 0.10838098039052316, 0.16922959206359728, 0.11675296936716352, 0.1365658255027873, 0.15006913377770356, 0.1370909030416182, 0.10042012935238225, 0.29650525535855976, 0.0733626362468515, 0.10144204380256788, 0.11067954490759543, 0.12273809606475489, 0.10204049811831542, 0.09137328301689454, 0.11358201916196517, 0.24940756974475725, 0.1704299205115863, 0.14854522555002145, 0.10544255735086543, 0.15950591383235796, 0.12329648967300143, 0.18197176046669483, 0.3107517494687012, 0.09414725630943264, 0.13516421642686638, 0.08417668632630791, 0.14425700636846678, 0.12894663720258645, 0.11511936916836671, 0.09643527639231511, 0.0961358728153365, 0.1855385476457221, 0.1211044822952577, 0.1952877930764641, 0.08754701726138592, 0.10819204909993069, 0.18626049533486366, 0.15018293767103127, 0.11759522131511144, 0.13554783298500947, 0.15443292818963528, 0.14771712784256252, 0.1513292004487344, 0.16344213618763856, 0.15166384034923144, 0.1214802549885852, 0.1891630103013345, 0.16589337108390673, 0.1779156138322183, 0.20963389612734318, 0.2337607422045299, 0.11913084105721541, 0.13822833129337855, 0.1421903244086674, 0.17558560600238188, 0.08416173819984708, 0.12913068304104464, 0.15502891263791493, 0.1280439142137766, 0.13139207740979536, 0.1530381180346012, 0.2116520899747099, 0.15023893038077013, 0.2575669533440045, 0.16524049825966358, 0.11279390752315521, 0.14328032306262425, 0.1739722668592419, 0.15168568917683192, 0.10427557211369276, 0.09805192000099591, 0.13989275055272238, 0.07663989253342152, 0.0809880399278232, 0.1352709906974009, 0.09409327884869916, 0.1942660550453833, 0.14894535765051842, 0.1688640381076506, 0.2415681289775031, 0.08378835394978523, 0.1262166736913579, 0.13167571861829075, 0.16282344795763493, 0.13830780131476267, 0.13859326099710806, 0.14989707086767468, 0.07773787754454783, 0.15018262554492268, 0.09660400769540242, 0.11326905166996376, 0.16454821612153733, 0.12431076381887708, 0.12863200051443918, 0.13326202492628778, 0.12379704495625836, 0.09505692071148328, 0.11461965526853289, 0.12952512901808533, 0.21145391703716346, 0.18550447161708558, 0.0694763201421925, 0.19319498751844677, 0.10896958916315011, 0.1621034544493471, 0.1105222197781716, 0.10998558000262294, 0.08183678545589958, 0.16954507013516767, 0.11589298051382814, 0.10888446015971047, 0.09315641197775092, 0.15181124529668263, 0.14225280391318457, 0.09897055463599307, 0.11905104533902236, 0.09705747943371534, 0.13436252730233328, 0.1472286776240383, 0.08693945022033793, 0.17398756103856222, 0.07681338715233973, 0.10332267146025385, 0.1608838013240269, 0.15104367291288717, 0.23662529992205755, 0.16846396028995514, 0.13388135097920895, 0.14594464509614877, 0.19968987043414796, 0.15914200193115643, 0.1617594507655927, 0.0794571495747992, 0.15563949915979589, 0.17492379008659295, 0.18124404522989476, 0.12688543780573777, 0.18562994631273405, 0.1396178895873683, 0.11825437737362725, 0.15428251054670128], [0.03461594234353729, 0.0184431873993682, 0.012737205767604922, 0.03528920853776591, 0.034986958506384065, 0.11318237560668162, 0.031283711149756394, 0.06514431509588446, 0.013077145874766367, 0.0655845757573843, 0.055758927283542495, 0.0629795373284391, 0.017341100644054155, 0.035521155555865595, 0.05026185725416456, 0.027457087467025434, 0.029492500836827924, 0.06490855810365506, 0.06068558006414345, 0.03837477189621755, 0.03292428329586983, 0.038763813341834714, 0.03255714835332973, 0.02056639132622097, 0.048020907145525725, 0.033183588845921416, 0.04430291861561792, 0.05787770037672349, 0.009438540004859013, 0.031008354853838682, 0.05983196943998337, 0.12287472587610994, 0.014156086104256766, 0.027346401442108408, 0.021023011467020427, 0.02674201673029789, 0.12000389849500996, 0.029545711552990333, 0.045470389005328925, 0.028539355910782303, 0.04531638530482139, 0.03941395506262779, 0.024794475341747915, 0.06302319427153893, 0.04073524255571621, 0.060568817758134434, 0.03768672042393258, 0.05372179552380528, 0.02603244043088385, 0.01692115532101265, 0.05223352734797767, 0.02916610852948257, 0.015793212988813008, 0.04145705114517893, 0.03559404378756881, 0.01874988692413483, 0.04752889461815357, 0.04871234790022884, 0.009063264338432677, 0.08287879811333758, 0.03355496123965297, 0.06599749824298279, 0.026606289370517646, 0.03295779274776578, 0.024985001189634204, 0.06245134531387261, 0.05196546869618552, 0.02910365616636617, 0.023622630097504174, 0.022033436623002802, 0.06136767060628959, 0.023970867839774916, 0.024353754972772937, 0.07177655385541064, 0.012033922032320073, 0.051684735010245016, 0.015075455253411616, 0.052560791572821994, 0.02002561079072101, 0.006968653029096978, 0.02983036038598844, 0.027167615946382284, 0.006187609604759408, 0.060372856844748767, 0.06468825813915048, 0.04160423556874905, 0.0573698440566659, 0.10586897589798484, 0.038420155710939846, 0.014528632363570588, 0.07071170170924493, 0.014762290986254811, 0.050470235358391485, 0.03515196465221899, 0.02817958646586963, 0.04560520373550909, 0.03152675221541098, 0.03872449902285423, 0.013761759719013103, 0.02273106561707599, 0.04847339161538652, 0.0415660544032497, 0.016971575561910868, 0.03325806824224336, 0.06243665503071887, 0.03129186714068055, 0.020573224173858762, 0.031755109783262014, 0.02083226339891553, 0.03692102079678859, 0.05609421179230724, 0.017485078989661167, 0.032495856285095215, 0.0027832556515932083, 0.0478621265584869, 0.019166580368099467, 0.02894774917513132, 0.060038176232150624, 0.027624890873474733, 0.026878921348335486, 0.09444802374179874, 0.04792173925255026, 0.009021095931529999, 0.03339524766696351, 0.015003812133467622, 0.020162657901112522, 0.0118807393591851, 0.025751667729179775, 0.007170776736789516, 0.019164965454755083, 0.021540123004732386, 0.04020703357777425, 0.021362038096413016, 0.06032945774495602, 0.04374684559713517, 0.07073419514511313, 0.026670166657173207, 0.025775974549885308, 0.008189647109247744, 0.011170587153173983, 0.05084355175495148, 0.018623051765773977, 0.12332194830690112, 0.03697960551029869, 0.011595524797615196, 0.0086742678457605, 0.0448332242667675, 0.026070302684924433, 0.05564165607626949, 0.07178559194185904, 0.026704486958416443, 0.023378025008631603, 0.06692903182868447, 0.06777595888291087, 0.0339633002212005, 0.043537239344524484, 0.015351905687046903, 0.05490976106375456, 0.042719628395778794, 0.03372189781761595, 0.06493515667638608, 0.044360193756542037, 0.04333105969375797, 0.033301945709224255, 0.025698024446942976, 0.014193363970012536, 0.008121461973392537, 0.027243564371019602, 0.027922358929312656, 0.03591871940131698, 0.06927603017538786, 0.037570568799440346, 0.010049460705236664, 0.0712179159745574, 0.017600854027218053, 0.027882327059549943, 0.04068185542044895, 0.018516304636640207, 0.022450216580182314, 0.05334339689995561, 0.023600735468789935, 0.05633769729839904, 0.04632291058078408, 0.0455383782141975, 0.02051071752794087, 0.07530591304280929, 0.034903787076473236, 0.014689333204712187, 0.04122690563755376, 0.03312336207766618, 0.10463970793145043, 0.019678362013239945, 0.0018903930488574716, 0.027750285841258507, 0.06266897863575391, 0.010059931348743183, 0.022389056826276437, 0.016753348521888256, 0.016909903514065912, 0.02726172875346882, 0.06329538180891957, 0.029101810551115444, 0.09200969458158527, 0.045362936199775765, 0.00654624801661287, 0.038791273654039414, 0.04048956538151417, 0.09366691458438124, 0.0688302055267351, 0.024313222683433975, 0.023922868272555724, 0.06109469596828733, 0.041973738598504236, 0.07228501407163483, 0.02711928728967905, 0.05503549021003502, 0.04341010223808033, 0.027148175918098007, 0.03205904258149011, 0.023597217264718244, 0.05531751989786114, 0.04767445055767894, 0.02963788714259863, 0.031715167819389274, 0.06882280949503183, 0.08319068673465933, 0.018561539173658406, 0.004514793898644192, 0.01646461321174034, 0.03723606460594705, 0.018903868572254266, 0.035572636007730446, 0.1202359167592866, 0.07436889689415693, 0.03668982016720942, 0.07100849292640175, 0.06611780250178916, 0.03957788573045816, 0.01681570758643959, 0.035474777687340975, 0.027749478384586315, 0.0335030872374773, 0.020026477619207332, 0.06545289925166539, 0.018050093403352157, 0.015392773851220096, 0.023603144268106137, 0.008514617885729032, 0.018448334087484648, 0.046026231321905337, 0.03499215608462691, 0.008547358896716364, 0.011844554782978125, 0.05089813989720174, 0.051275934624884806, 0.04270863612847669, 0.03088122114006962, 0.03578121427978788, 0.04276178238381233, 0.008362485245535416, 0.020218774443492293, 0.007710497061322842, 0.07390166446566582, 0.0589840720806803, 0.054715415063713274, 0.02825009643233248, 0.06543082650750875, 0.07038793193974666, 0.048373881062226634, 0.13836435042321682, 0.016698653510372554, 0.011691551921623093, 0.021992037505177513, 0.03514732686536653, 0.012946910407793309, 0.03625161207414099, 0.03666346586708512, 0.029716325790754387, 0.054270123065050156, 0.05928260713283505, 0.005195986230059394, 0.008976266819185444, 0.03335576032155326, 0.07324133454156773, 0.016378637735864947, 0.03680461472166436, 0.07419726146118981, 0.034677889198064804, 0.04130361062873687, 0.005423928195211504, 0.02736509677820972, 0.012428516438896102, 0.016593195597774217, 0.03987040217699749, 0.018122910388878415, 0.026305460869999867, 0.030164671197001423, 0.03133793966844678, 0.010392202313856354, 0.04448078978540642, 0.03145976723837001, 0.06783105592642512, 0.04553283458309514, 0.03431021482018488, 0.009574788988434842, 0.05549993385959949, 0.0316500929184258, 0.015383844330374683, 0.025033331542674984, 0.0686958623783929, 0.020507791345672946, 0.0406198271417192, 0.04328528572139995, 0.020807200011664202, 0.034819692838937044, 0.006187668552489153, 0.10331995053482906, 0.028645424504897425, 0.03989523655868002, 0.016186346000592624, 0.04323894177962627, 0.005113964492920786, 0.02129135510352041, 0.03432211293173688, 0.03094203144844089, 0.04831027179690344, 0.02423106227070093, 0.06619892136326858, 0.027269857602992227, 0.018315373454242945, 0.058938284537621906, 0.028255341508026634, 0.026344544487074018, 0.008734387744750296, 0.07251391107482569, 0.05229639022478035, 0.031531403572963815, 0.0571766583515065, 0.015777345447401916, 0.026124982429402213, 0.022830012986170392, 0.01695178778442953, 0.07582858178232398, 0.02479145416457738, 0.07981517857738904, 0.02237625965582473, 0.08736837256167616, 0.04764207425926413, 0.028048157625432526, 0.031184889309640442, 0.034437755654965124, 0.057892696000635624, 0.1439660776938711, 0.10610414256474801, 0.12846429379923002, 0.12922562366085394, 0.15704911494893686, 0.15815539844334126, 0.09747431706637144, 0.1006049487207617, 0.07446603596742664, 0.24787961744836398, 0.1635503896645137, 0.10540276805737189, 0.11267295865608112, 0.12103710376790591, 0.15574681625834533, 0.09176256534244333, 0.06962972333920853, 0.17734537300254616, 0.15737273544073105, 0.13280946921025003, 0.1538634201777833, 0.10249809534954173, 0.12500125462455408, 0.13027584659201757, 0.14917946580265248, 0.0928238280383604, 0.15346265025436878, 0.16728624062878744, 0.09208804502018861, 0.11177343835255929, 0.09318469331732818, 0.24966044617550714, 0.1913327481597662, 0.0962013378739357, 0.11644256673753262, 0.19993745429175241, 0.2555201660309519, 0.10652646954570498, 0.1090906805225781, 0.17126750413860592, 0.12368238610880715, 0.07988835179380008, 0.11274540584002223, 0.12535528705588408, 0.19086818237389835, 0.21384378522634506, 0.1148341673293284, 0.2144017174307789, 0.13992187327572278, 0.1540420920188938, 0.25120462902954643, 0.10407397257430212, 0.0856756583920547, 0.13735061910535606, 0.1956713960639068, 0.12907049698489054, 0.25798653225813595, 0.1510263295578105, 0.11333197900759322, 0.26486294184412273, 0.27811478504112785, 0.14715699718466826, 0.11308036465197802, 0.08829341935259954, 0.1250820138624736, 0.13409158826938697, 0.16804602343056882, 0.11615022671009813, 0.04858054247285638, 0.12742636592260428, 0.1441714023905141, 0.1380530928394624, 0.10562441830656358, 0.21912901662290096, 0.07282495831272431, 0.11482807408486094, 0.13164755941501685, 0.10950869202081646, 0.102651179635099, 0.1413999939603465, 0.08762714546173811, 0.09558518057955162, 0.10489778872579336, 0.1870521285704204, 0.18575094267725945, 0.09558146220764943, 0.20133328224931443, 0.19251666963100433, 0.09775986495826926, 0.1069264727245484, 0.1505836397409439, 0.23651594721845218, 0.17399533704987594, 0.14827352655785425, 0.20654786457972868, 0.1204137879290751, 0.15223910233804158, 0.13583021211837018, 0.11554975035999503, 0.10989801505846636, 0.12428507448307105, 0.13713750482669898, 0.07777379918843508, 0.1511640857372965, 0.12778848649135657, 0.22905434189098223, 0.21558743023446628, 0.13461004330643586, 0.16719637545091764, 0.1369793518845524, 0.17948714164750917, 0.10325314876224313, 0.11547152884304523, 0.06850196421146393, 0.19514352296079907, 0.09795243319656168, 0.12082417947905404, 0.12940439049686703, 0.16414561415357248, 0.12855007419628756, 0.18720638672155993, 0.14258981868624687, 0.07833257277629205, 0.14554087604795182, 0.12178915127047471, 0.10190841449158532, 0.13131651575011866, 0.22686432940619333, 0.16505190623658045, 0.13137344483818325, 0.10551806472774063, 0.09778132702090911, 0.05539999582937785, 0.36156897406492916, 0.13501594295459135, 0.204332936289055, 0.17334395700267383, 0.08792488662792103, 0.12799732599939617, 0.06471543346664735, 0.1458049618772098, 0.13689866050013474, 0.19335270619818143, 0.0797019921509283, 0.1073000333937151, 0.11881828068622521, 0.08972057527197258, 0.12229828323636736, 0.18472151005906717, 0.14404302356498583, 0.24554860538669995, 0.10795074847659894, 0.1090148270928434, 0.17453914215522154, 0.20147038703518255, 0.17899646583412374, 0.06455540098249912, 0.14063105093581335, 0.17263216019741126, 0.14154540401484283, 0.11967121277536664, 0.13555277271994523, 0.15120534066643032, 0.1302540520472186, 0.10656799588884626, 0.08735723101666995, 0.10558491399777786, 0.10755485043461833, 0.10453869442322425, 0.14683638938835689, 0.1318873129785061, 0.10954065780554499, 0.08729864630315985, 0.25672101016555515, 0.14021010138094425, 0.10944653821310826], [0.014101593805077885, 0.015125344540657741, 0.013395552673111004, 0.07907930056431464, 0.05477917699941567, 0.06010328166718994, 0.03698406009269612, 0.02702852983825973, 0.08863139764538833, 0.033189346215554645, 0.019635244505479932, 0.11315277112381798, 0.037848523884479485, 0.03211976468030896, 0.0570441268916641, 0.005496148069921348, 0.009209218069112726, 0.038516653568616936, 0.018848971696570516, 0.07766931836626359, 0.03867155972069927, 0.018805835529097488, 0.016222230325053846, 0.03491040618558015, 0.027958672427173172, 0.04080790687086327, 0.033571001807493825, 0.0075799146933215, 0.007907699693792632, 0.011509260096188103, 0.01985787693411112, 0.01292260189075023, 0.033233064226806164, 0.047967221454850266, 0.038529837504029274, 0.04457112993778927, 0.04988808623914208, 0.05115703493356705, 0.04087804364306586, 0.007446488415423248, 0.03482625427256737, 0.06364410131105355, 0.040796768718532155, 0.1338445200983967, 0.030832040921917984, 0.016565870992573242, 0.00752886850386858, 0.025715722336566875, 0.006141723250038922, 0.033811505152178664, 0.05647669180429407, 0.045963463440005264, 0.06699657998979092, 0.10128075602863516, 0.0484419245538967, 0.023714195005595684, 0.031301716076476235, 0.05266178472499762, 0.006762878803004111, 0.04518321941473654, 0.006195505207870156, 0.04339827537270529, 0.05653509670602424, 0.06906528398394585, 0.03876739261405809, 0.04513257695361972, 0.09568659442343883, 0.02703279273451439, 0.007851569580712488, 0.0626422172146184, 0.06563765076654297, 0.0303758855776063, 0.02561270715003567, 0.08835175300815276, 0.027445986634120345, 0.016111749556979964, 0.05029214705739703, 0.022602372969101583, 0.015625602964844023, 0.03250813776893275, 0.10688272757189614, 0.0164688506629318, 0.03326247871986457, 0.10242804339421646, 0.02176118971380804, 0.028705566456275325, 0.06061523633876017, 0.04278138865317617, 0.020003907848149538, 0.08224212191998959, 0.022224050680441514, 0.016376283219350234, 0.053641209312315495, 0.013944537545155202, 0.030595127027481794, 0.03009236989808934, 0.04345403738053782, 0.048862392348902564, 0.06298136258763926, 0.03051905646654112, 0.10585024154611997, 0.05209773552737065, 0.029374503597084965, 0.046032087079116275, 0.03974699362048081, 0.0626710888796619, 0.03116637548165662, 0.05301861272060445, 0.03899216751701065, 0.05284023943490215, 0.05658264844013112, 0.04027114835168634, 0.0405156075555299, 0.023808414681947658, 0.10175373564873423, 0.044367521934743435, 0.03299071187419551, 0.019442406549517597, 0.03161885316616722, 0.07759009940283638, 0.04388996559594359, 0.030013731082103083, 0.025941491293321763, 0.053924796238009415, 0.023243646237200925, 0.07428635989448854, 0.02628356624128563, 0.04896093938233597, 0.013706829764747193, 0.007196119171567261, 0.042076370412749906, 0.08811373649431126, 0.04369927689965282, 0.01922390979182507, 0.06684114797306911, 0.04222709000376718, 0.048239280070577345, 0.0512499365556453, 0.014685309492051601, 0.041822296367692094, 0.042389490575130494, 0.022001710021868348, 0.03234825116981353, 0.025780893928770508, 0.04821978575949158, 0.02595272274421794, 0.007986000938607114, 0.07350730669817754, 0.01219373059991215, 0.03574176764647875, 0.0423425495225404, 0.030062225979885886, 0.02253636168981237, 0.08100862668028899, 0.021386166801676154, 0.03970772001360144, 0.021314961336819187, 0.02255921474924045, 0.06076635287276336, 0.024804648278015, 0.0870394187846354, 0.018312878141711866, 0.017905127789293016, 0.050544711362038336, 0.041545562645686526, 0.034475773972059996, 0.025545432099274228, 0.07393120788037777, 0.03516327922365495, 0.043723829689302614, 0.02003666921518743, 0.07624845246651343, 0.026374210038089325, 0.03822189795651606, 0.030580501205154827, 0.042703516581760984, 0.035741601405399184, 0.038194315508008, 0.021632000038932477, 0.04743189125188759, 0.04703271249309182, 0.050901658101273436, 0.01878429713126804, 0.05228367108585579, 0.08548464399895497, 0.038457702446196756, 0.007105880799437208, 0.03516883981813278, 0.04471450777990477, 0.03022485046780535, 0.031860788219741414, 0.060418447612651756, 0.041917070746421814, 0.014160426183869796, 0.018868732332651104, 0.044801258482038975, 0.020910466256152307, 0.019341167428397706, 0.008229595010301896, 0.027823562534259896, 0.029635529233408824, 0.016620642339278544, 0.04485381780458348, 0.060426847876182625, 0.019300438363903334, 0.024831112840079834, 0.025218859980148927, 0.025047840317711234, 0.02166945517196187, 0.04919842663886292, 0.002613900732415329, 0.027111970985840474, 0.043926267219441276, 0.036197302131248374, 0.05848904685782535, 0.028363326963569437, 0.06367285083979368, 0.043168703227170875, 0.05391216870131237, 0.03857388121208974, 0.06348624013896499, 0.014458643172734549, 0.016433039280985082, 0.04770603297012193, 0.018646445956879427, 0.010901376688187676, 0.06456395730908428, 0.009310102655685373, 0.05934289496924196, 0.02433991794740515, 0.08218334043132407, 0.05469455350456493, 0.02490511386921363, 0.053709924553654025, 0.03929216481213059, 0.03977732752848949, 0.028638896998018026, 0.03702602409092443, 0.025360003745715533, 0.04065596930948751, 0.019990405001278435, 0.022635821352845857, 0.03936995206666844, 0.03674295285184469, 0.027876411930524876, 0.053747413613434346, 0.051064988265612295, 0.015839974229623164, 0.023831247385325174, 0.07714844774454832, 0.02193726446213467, 0.003637663130315819, 0.024314686622736708, 0.030357375142297575, 0.029343589541635344, 0.0903508664507951, 0.042763627999063046, 0.009128943135562752, 0.016032844415998886, 0.004154129211591291, 0.041073044429400137, 0.073335983391319, 0.06920097741697516, 0.08726330141403846, 0.024565949836479764, 0.08499142367924963, 0.016880516162408248, 0.09024635848722287, 0.05309705136876021, 0.03897858324593731, 0.0382463286098625, 0.022243804531171918, 0.03750023525208235, 0.027560735387461524, 0.07064095764820065, 0.015351753016667706, 0.07679448316672019, 0.028513754784528698, 0.05498310052124517, 0.022634545707010796, 0.03263140044042042, 0.08520954554634434, 0.018958112357982566, 0.03318284585007599, 0.04872952501422592, 0.028668888245842288, 0.03398351717208113, 0.03980039771912353, 0.07707102011357035, 0.012756386256244565, 0.025348037780661668, 0.020041873578780463, 0.009721383934707513, 0.06705829953508717, 0.06599189354372875, 0.03527914586343935, 0.04775371701855745, 0.053861193758036406, 0.05928603373467922, 0.019556554799367274, 0.012480480346961744, 0.02828268986195326, 0.06014833639242819, 0.010259576707280107, 0.02202623736645494, 0.022885277967101762, 0.047611811597432406, 0.0572410241833755, 0.09290907917810337, 0.01837368166473295, 0.028327312021117126, 0.0071016738823215875, 0.0711089703919632, 0.09348391368985176, 0.016598255772675787, 0.02759674015188856, 0.0524816676042974, 0.024940745439380407, 0.03200729410829289, 0.06532753990697009, 0.05887679569423199, 0.021741854858451655, 0.0388043829505997, 0.06139498842614038, 0.05334284728659051, 0.04464778403884598, 0.006430481884828103, 0.07488125868673835, 0.06516722243811403, 0.03238868846424988, 0.028526809798287492, 0.06332565804145165, 0.028216865179794173, 0.04051283234730363, 0.04281803972220846, 0.0171812818984368, 0.039245834441057274, 0.03286485041358641, 0.05033871152305177, 0.013528190154050077, 0.009924111538566649, 0.04323540661217911, 0.10554933162139994, 0.01859782213744308, 0.06125137648944344, 0.02802697885116296, 0.0040861204948409325, 0.037668301590851376, 0.02757978525811008, 0.03404636647818344, 0.02167861709105117, 0.03487726314259427, 0.17041488417557307, 0.13389106760067598, 0.0943387999598469, 0.18158859174166406, 0.22126081080308982, 0.1401549500546285, 0.11113402087773595, 0.16244273552937166, 0.1669128563787256, 0.23581903747149877, 0.18067521575306142, 0.1698159413146121, 0.15524900225656374, 0.08825209656996386, 0.23836115534816468, 0.14039691564227852, 0.14845150629324572, 0.08609234674700669, 0.11047546871538673, 0.11046451037483555, 0.16205222505543912, 0.10593752829091889, 0.08357291908136436, 0.11077989345150334, 0.10038728147212948, 0.13996531308761664, 0.12416932997959, 0.1231983599386045, 0.11951557041278907, 0.08106387978685753, 0.07991366793534585, 0.11478653417101928, 0.13978693980191434, 0.14350149833730289, 0.08639780964170184, 0.1233701514346259, 0.18068462024841989, 0.1132219477689692, 0.1854003029210227, 0.11772316587822777, 0.15541945025324821, 0.15304904244840145, 0.14868150252316678, 0.271631084382534, 0.10449828766286373, 0.11062391860676662, 0.1460450818496091, 0.15008531005254813, 0.07727287749626807, 0.12512117890375002, 0.22472108155488968, 0.113905008616192, 0.24622708612254687, 0.1325323147965329, 0.12076075002551079, 0.17811696231365204, 0.11725379606442791, 0.14170329911368235, 0.08624724272106375, 0.16825693925576551, 0.05757196606802089, 0.12941853116665566, 0.1210821992052453, 0.1598675051437957, 0.16163552312978677, 0.12890882923134736, 0.1711299650903259, 0.1250073750104223, 0.07117102241941861, 0.1494068293167012, 0.13568423209445818, 0.0798704723960587, 0.07185045988964182, 0.16264918659414562, 0.08506698533892632, 0.12094751000404358, 0.11489649755614144, 0.11819678332124438, 0.13659231550991535, 0.13686938849943026, 0.2788661947207791, 0.10603114576744181, 0.08629092680556433, 0.1718067494886262, 0.07938989996910095, 0.15540602883057936, 0.16498697043529578, 0.1864065567829779, 0.09822016275886979, 0.1402091242905174, 0.1728524805179664, 0.12906616793147155, 0.13300366593258722, 0.13935520154024872, 0.14084957992391928, 0.11645586602389812, 0.1804030689277819, 0.1456141306885651, 0.15868309512734413, 0.08351181021758489, 0.12577445884900434, 0.14309296597327503, 0.11265763055000987, 0.12303589151373931, 0.17814029034759316, 0.18444320213581833, 0.15211486257612705, 0.18586936060871395, 0.07663877973599093, 0.11185298301279545, 0.09426874800452165, 0.1511147426707404, 0.15237039886415005, 0.08549353280769927, 0.1435085822428976, 0.10644130661551442, 0.13186426992927278, 0.10985656335417714, 0.11516389463629041, 0.11385242215224675, 0.13069883175194263, 0.11340815134878669, 0.09582856430539063, 0.12110973415630204, 0.11886531673371792, 0.21611584616558893, 0.15750738392983163, 0.17035007051059178, 0.1410312916019133, 0.13562534882553987, 0.0991907799616456, 0.22950545911278042, 0.23279057283486637, 0.056203981794949086, 0.1515248492360115, 0.11801625229418278, 0.12290611490607262, 0.14910322560795716, 0.10214914514550141, 0.1289134839815753, 0.16385511974138872, 0.0875553089593138, 0.10499398463538714, 0.14672692811914853, 0.14837712528450148, 0.1446303499064275, 0.11543898630355086, 0.18461438295032295, 0.10613937210291624, 0.12722466460296086, 0.08986918801175696, 0.15162960147219046, 0.19894190771239145, 0.15274148966584886, 0.10609089077583381, 0.1404485792985984, 0.0820003327514444, 0.21873675552862032, 0.18201157690158912, 0.10155156613992793, 0.10887130336569888, 0.0795704038547618, 0.12453081272542477, 0.15669403757367814, 0.1735941328640495, 0.16955879011324473, 0.17454127275518008, 0.1823058303977762, 0.1533577080283846, 0.11176453597311463, 0.10927274503878184, 0.2561406727348055, 0.15271528464342865, 0.13638868715081895, 0.09095303235309464, 0.13357299752533436], [0.05394529478092279, 0.0224920923688582, 0.06527455989271402, 0.0272230573464185, 0.009385189340849007, 0.022727628837206533, 0.04523795344201582, 0.033762324934027026, 0.012805193280135947, 0.052002425105976205, 0.03870998176613024, 0.026183363582406725, 0.024500489866893207, 0.04047139421371477, 0.03458223950916103, 0.009592473307358367, 0.03574270063212939, 0.011562061995001776, 0.029269999026187828, 0.08268031983503274, 0.06884861418179103, 0.04501895626474704, 0.09055203851312399, 0.02063177326428039, 0.025140289017664533, 0.03946169678653989, 0.06044913096619504, 0.06604253939752068, 0.02387427498719522, 0.04422512796840497, 0.012860580397370671, 0.023133104400975362, 0.06888911593705416, 0.06086149026772805, 0.041882947220333984, 0.047177929165107865, 0.017389768568266715, 0.03205327842650669, 0.0379723192059568, 0.030431756151041815, 0.04210000039477434, 0.011194046653274978, 0.06785292511007615, 0.03775694201301251, 0.03671089207221355, 0.031197700050792525, 0.05582381898005094, 0.051498779095709324, 0.023747565357812812, 0.05666918879640954, 0.015026064689404197, 0.03529470467141696, 0.04111628068078842, 0.02426025115086564, 0.017174588150477836, 0.015947423642501235, 0.06445748159395796, 0.007998245951187397, 0.004206522717140615, 0.01678737366039838, 0.01976279042927282, 0.051174768446279426, 0.013116231188178062, 0.01452185888774693, 0.05441384356735008, 0.06848158780485392, 0.03657791617193392, 0.019220987002232244, 0.10552695353648492, 0.024299034516194036, 0.011167165640342449, 0.02349381531322641, 0.021046256380421773, 0.05804420608494963, 0.02314227310541485, 0.0021412194556822734, 0.00845422487639423, 0.07392955904028245, 0.04051463385777814, 0.07089322339743376, 0.07734492434454815, 0.050928928423672915, 0.02489685609803668, 0.026987346155302863, 0.04068172649879541, 0.07393694828663554, 0.009973798113475953, 0.030874015098171573, 0.007125441267687295, 0.06541509806577649, 0.024216536532289216, 0.003742034962799932, 0.062375451172036786, 0.043603501681770594, 0.047124949150851796, 0.05146512375878436, 0.017301788021411215, 0.029480460232922008, 0.016131898654358726, 0.053723240803394995, 0.027367096760177186, 0.010973972301664097, 0.0026034040077190313, 0.03443744692153164, 0.016428610143650855, 0.019970272867275134, 0.01903057311262403, 0.05495679032589708, 0.025257667094202976, 0.03193036520055362, 0.01804265326687268, 0.05954228926982198, 0.06645628291049174, 0.041631594100700955, 0.057303612253495624, 0.01959322113543749, 0.015673324332705567, 0.024983047008780495, 0.037877280198569806, 0.009699651306228978, 0.04903689119964838, 0.052186504871185334, 0.014793179596641233, 0.04480964856754456, 0.03173037378915718, 0.011400307728243726, 0.031988783672984154, 0.032109240602169714, 0.02994750945695809, 0.031247484165110757, 0.032351436891726086, 0.005861556564923376, 0.011445140233263373, 0.03721240069717169, 0.055084782386464734, 0.03637194686702319, 0.03338756325787731, 0.06292798902307238, 0.022603487462869713, 0.03565711361755218, 0.02199911292908447, 0.031279511017990966, 0.031105717843664542, 0.03354835230857134, 0.038433265007500134, 0.018388836744374464, 0.029901687987148762, 0.08757986514163868, 0.01875445176847279, 0.06479058121996266, 0.05923118096377168, 0.04188533905627472, 0.03377568189586912, 0.022177459073386023, 0.018332633688779812, 0.05837570436831031, 0.018192416123513664, 0.09760101312505347, 0.03874290089255997, 0.050477098740105114, 0.005925404589756259, 0.02242726513317653, 0.022672937218365923, 0.02285024181141385, 0.028188395546749234, 0.032858031136648994, 0.02543908530580146, 0.002429557398759893, 0.01957142828697605, 0.03282090509310365, 0.010407146199473312, 0.01818630930834583, 0.07230296132287808, 0.03873784241399594, 0.03578690379591925, 0.02132311393506825, 0.035542142643992386, 0.011350219121335872, 0.0026424710855021006, 0.023622753930145075, 0.05487326266510146, 0.0234368387277105, 0.05553716168339763, 0.028554371890744994, 0.008468840520695915, 0.07256573079419987, 0.01966606356602694, 0.0973169512248465, 0.016579333127343228, 0.03205712911273752, 0.009997779237372535, 0.02564292909976627, 0.03217010519334248, 0.04774649401328393, 0.028336177081135765, 0.03403468210516231, 0.03888645515378032, 0.0556372829180743, 0.06054239560450826, 0.022597088877643858, 0.023638015879052024, 0.015188192150422504, 0.03579098179138132, 0.04410432159368481, 0.01746603929703789, 0.04088080528059176, 0.04574743824611817, 0.05259997697014894, 0.012997893832757004, 0.07612600403704814, 0.028617295835699354, 0.036492322372006517, 0.0191539121193013, 0.03247201256453991, 0.05384932278788515, 0.05109749009300556, 0.05633017234504223, 0.04007212046001639, 0.033955103518175225, 0.04207955274198737, 0.0014377432921069808, 0.045136929755764346, 0.05060112815616386, 0.014562881418636866, 0.013780280332347112, 0.03455100654225264, 0.01864759946641113, 0.02439727620886905, 0.05828120479626315, 0.012798793846741319, 0.049656139221042395, 0.046968872525862286, 0.09664733215634312, 0.005120589963293501, 0.07280745210924319, 0.06486058567783662, 0.060478667595556805, 0.017338761394577365, 0.031484937494886775, 0.020160545960866978, 0.02118435691642974, 0.08128345371889216, 0.006667495015010769, 0.02291277050971985, 0.0602529054241521, 0.04805757178525839, 0.05330375009881599, 0.0443599596619606, 0.00937193924827235, 0.046199067761855464, 0.017928365917344178, 0.01168823303721313, 0.028366188685010587, 0.06754282103585345, 0.023330641211941838, 0.03572322667709418, 0.02213651287768568, 0.009681267248067473, 0.04248841419549925, 0.03410643718338438, 0.010714626887680163, 0.03345151857606002, 0.059842622439776144, 0.05746918158339603, 0.0073053522833756036, 0.07083718319024358, 0.01966489139678223, 0.019179384323901365, 0.017986139781506996, 0.03397252829745412, 0.05341956924114909, 0.019985701057261655, 0.039943850200091086, 0.03825891204178333, 0.019202362912307893, 0.026911207740860324, 0.0041448311614138734, 0.035884175183517594, 0.030873882783842937, 0.02306597862791802, 0.020069193094968796, 0.023235722644520656, 0.005075664583793176, 0.05397922831720539, 0.06243288916136537, 0.03379166478823338, 0.08979303602661405, 0.05260673178625958, 0.025982617300802043, 0.054303720726498535, 0.05696522005434547, 0.03347281100494521, 0.03940186696127057, 0.04852667697040098, 0.022859463102317283, 0.04080948446478162, 0.017085837466376166, 0.029002181254327297, 0.04221002484804817, 0.030737758481076786, 0.01076105225365609, 0.036494395296488485, 0.015410369960591197, 0.016462272265926003, 0.018244103528559208, 0.017233846309993948, 0.04143580960642014, 0.020366340543010404, 0.03640146653300949, 0.02607594639994204, 0.01964282034896314, 0.02131783153994807, 0.014800841953339321, 0.019908529573253224, 0.00450941184369315, 0.11194297711231879, 0.05396580010918634, 0.013974000383833689, 0.016416827383052026, 0.020929446576961448, 0.020301844093150327, 0.04608610525195088, 0.0026141789317729747, 0.04578366523076381, 0.015784936557923044, 0.08877578989735671, 0.026925545185804367, 0.02044921341751303, 0.023609751502850225, 0.06046831315117223, 0.033528416949723444, 0.050403487868607044, 0.02467515495871859, 0.0901720453319805, 0.10114410586122956, 0.04468852328136563, 0.015223972998293383, 0.06317461614630052, 0.022360727989247868, 0.034105904533394744, 0.05270769101168428, 0.03559073932202799, 0.01660336005235357, 0.026348159382385865, 0.03543784163360085, 0.05440413033855813, 0.030595035425254276, 0.026886707537674477, 0.014398080529645085, 0.01326940198695021, 0.02586395340040326, 0.09713996893593244, 0.13144042981522425, 0.10201604371624333, 0.12901173585227557, 0.14414362316685064, 0.1737164320158107, 0.0970707990761314, 0.11182832505021777, 0.159847868340356, 0.12081899547151156, 0.1713069270231894, 0.1207278546478067, 0.20648035034537315, 0.07494417923901762, 0.08460898098668881, 0.13927643719528401, 0.0857812791530575, 0.1450430349047695, 0.0876426635576146, 0.11955214345029422, 0.1746023001947573, 0.09212135430425406, 0.1465715571705784, 0.26640769466757774, 0.1225500332989863, 0.07432219332882337, 0.16189506277441978, 0.16862208609070095, 0.19306715152093343, 0.16908123716711998, 0.12641458878559725, 0.08462464157491922, 0.17241417403732026, 0.1018804113513657, 0.16332916010703358, 0.12327636432434831, 0.18227353213088854, 0.06671582934047494, 0.09149558216865573, 0.1880351629640375, 0.1178881720240627, 0.0972751806090985, 0.14780588022300176, 0.18482573303793157, 0.05785296777529376, 0.11392407545021602, 0.16615352141005651, 0.1821196132472583, 0.12169448206467287, 0.1529504648808922, 0.21084771385150297, 0.15666180716029235, 0.1419916764966079, 0.14856997850750173, 0.15137791926307337, 0.07832979756806578, 0.10441798304340669, 0.17885115077453, 0.07196733076125383, 0.19669188559055328, 0.1514837300138814, 0.16625956286277088, 0.09682808031461068, 0.15738830103405885, 0.1025069977289864, 0.14485111806009496, 0.19552747878645146, 0.07833272205399615, 0.11847342204834733, 0.14319114999047347, 0.16437924733119352, 0.13509138247796468, 0.11830469753061022, 0.090070984326303, 0.15914439037442207, 0.10051274259707757, 0.08958653067903859, 0.11789683013090066, 0.13102889832641396, 0.1335500359003033, 0.23620596528053284, 0.15833938999899796, 0.09626648402107613, 0.15337471211595194, 0.1639678379786866, 0.09283971932849713, 0.13998594055218355, 0.16270013100334577, 0.1239373931395156, 0.1661962012627295, 0.13020652745451244, 0.12053354935986654, 0.1039795069290059, 0.1934747067945344, 0.15014780312776566, 0.2145335025021008, 0.11416575605315821, 0.1094207199556487, 0.07023406055356775, 0.10667488551033394, 0.10694708661841494, 0.08702849437083517, 0.0767066196671554, 0.11660047540707247, 0.09452960400709084, 0.08897557774824755, 0.1261788114373173, 0.16551461283649715, 0.2462397611566952, 0.1245199968772275, 0.11160468669342143, 0.12412149326077529, 0.10661404127521174, 0.16385934022920473, 0.11633910371788911, 0.12893302579011234, 0.1149433571845293, 0.08472328699593033, 0.1598698664456606, 0.20778513247413294, 0.08596584067812987, 0.11309287683772189, 0.2454360771392073, 0.09351069546703782, 0.17326729611626693, 0.16399483010172844, 0.13532593846321106, 0.10831514892301389, 0.14078757539391518, 0.10146852023899555, 0.08537879932139601, 0.08570894732006959, 0.07588458127741303, 0.14318356396896498, 0.13615504040249757, 0.07914320499237094, 0.13617553216006073, 0.11317059623875789, 0.15890235693327018, 0.10647542335625206, 0.16454569197126798, 0.14945638951446327, 0.0926391240209341, 0.09862416250897305, 0.14090099930763245, 0.11807292353894029, 0.16044601052999496, 0.13640769970204147, 0.10392761935612985, 0.10618269656385694, 0.23139127077800886, 0.1975748903517212, 0.1188749655016831, 0.09546518166150365, 0.2134419839297022, 0.12326440853731972, 0.09524900718991246, 0.09601997903415135, 0.19628203686858925, 0.17234313142086777, 0.09847086787756, 0.09916177937494856, 0.12005054099219185, 0.07067141029983759, 0.14726151871894086, 0.0874992348253727, 0.11540219613483974, 0.13786394441766398, 0.07997557747044734, 0.16728805910263742, 0.22732797238443578, 0.15942630810397013, 0.09483233240566083, 0.17209478760404245, 0.12873099877365998, 0.09653482426490102, 0.13156458815293653], [0.012699763357107128, 0.024285224632226994, 0.018840640982879058, 0.05507080117240548, 0.03839554185313838, 0.029076355309890847, 0.06468671786465816, 0.08552345620202166, 0.018773430392944386, 0.03176161014874067, 0.04314091043280704, 0.050050385030252595, 0.024981788326320902, 0.014336693466507962, 0.02297119576750057, 0.030231184592204433, 0.02662336640059948, 0.02971361843602998, 0.02786919062158891, 0.0254311328753829, 0.044093380216509104, 0.056544402813805, 0.0453491144414459, 0.04863892701853599, 0.00807059305121324, 0.040476004859166484, 0.013716739768694555, 0.04839828796684742, 0.0657174668407866, 0.03745313474376287, 0.06688417387860161, 0.025032337488872663, 0.02814895909146539, 0.04378664506865399, 0.06975451271448817, 0.02592522171991212, 0.07811624902699675, 0.016358722733067613, 0.04319161056940045, 0.019591404357925057, 0.08785886517060654, 0.03547141554632357, 0.06919696727501494, 0.03546839267281549, 0.008668411240380789, 0.03175835657332625, 0.048738810765956125, 0.03281890002212354, 0.036444970805730136, 0.010907194277803813, 0.04911341977172664, 0.0075336428458935446, 0.04158903977700642, 0.033630916449640474, 0.04315780256209629, 0.062202234752476215, 0.03675004693546465, 0.02563466623957668, 0.031771550686763864, 0.041145345728312216, 0.03311665815168193, 0.023520651373213956, 0.0044518190635634315, 0.01421621787760939, 0.04236071390498962, 0.039110911145274124, 0.025195537035220435, 0.020562206461493458, 0.01931473848942135, 0.03006346769897001, 0.05392112536355853, 0.08606154125716005, 0.021695030853152275, 0.015199142009285944, 0.05396607830854399, 0.009605071158148348, 0.013401955499180725, 0.030644334387034178, 0.020806772534602454, 0.05583457715277161, 0.01696661886359964, 0.026811337564140558, 0.06109245001737561, 0.03889028548396059, 0.03569245172132339, 0.04655554970460279, 0.015864002850971053, 0.030445160610335212, 0.05656806332990527, 0.08444939633565289, 0.056534302820052416, 0.01916302993361439, 0.02640878309362701, 0.02036382657076631, 0.025862883011411344, 0.04863525275141001, 0.023025870422965715, 0.03184870011838419, 0.03852010391918676, 0.025703676643648317, 0.020097844236131226, 0.08204509570662465, 0.05242485386718597, 0.044445868980671675, 0.03760138446731227, 0.08754646086267062, 0.026852590796936835, 0.026427507267466614, 0.05596463195979595, 0.03892449721960085, 0.007863156414324684, 0.04162243048527411, 0.11834995581635407, 0.053595927277846, 0.0910415133195264, 0.05764404684305191, 0.0076377029763534665, 0.03231293342209288, 0.06968744631324496, 0.01518804456905595, 0.06692407852304832, 0.016114248262186135, 0.09191412970955883, 0.058367480523884296, 0.014119524941114443, 0.017927388826917325, 0.01739285420626402, 0.057862256919699054, 0.02608978681798492, 0.013760656251439025, 0.04622609041897314, 0.03910036671108433, 0.04737646851156439, 0.024133085206683193, 0.04546763076047812, 0.004289596607642514, 0.031194103815193688, 0.005396533616086734, 0.0861798438376614, 0.0414117317912834, 0.01914671286275344, 0.040032470266201665, 0.0038932541252246922, 0.05933407401399953, 0.02187089355928557, 0.051204980217984745, 0.0531436938659421, 0.023030805068888834, 0.019743601458945444, 0.04491025156208447, 0.03952372506526964, 0.07006629277020693, 0.08397187053092889, 0.02586043010731893, 0.0447565158829093, 0.027710706893620745, 0.02163082447701267, 0.06447485209043537, 0.040368714902017794, 0.06526530467505966, 0.015162553704742874, 0.04971435074029224, 0.020729470432602932, 0.1364065326218094, 0.02501495342169489, 0.034577181030597, 0.02944710005873016, 0.02628249245961862, 0.07328988372215203, 0.02494085400498339, 0.02109522116370499, 0.04695791079263602, 0.020591807551681995, 0.020361555174791386, 0.07499304054571049, 0.015137631113507917, 0.03440082299390009, 0.032352295238524675, 0.058268570474215915, 0.00816772788363908, 0.09307525240417037, 0.07835414340453488, 0.017546311686081544, 0.05350268978093352, 0.007914840426695133, 0.027417691723842706, 0.03693620301783085, 0.012934497457795908, 0.03920639120042324, 0.05035381231989179, 0.04812216492635863, 0.037419435302061696, 0.009567768695498151, 0.03268978498610003, 0.08121740512017693, 0.04148845713851707, 0.0437338279028024, 0.022444418498447964, 0.06367714596646172, 0.05249965896031686, 0.05285621554191623, 0.021276237343304923, 0.027232348187161342, 0.040806590512927086, 0.06311998729194913, 0.014486451234136308, 0.06325467649315085, 0.03067186933809093, 0.035363016184419394, 0.045766678106571944, 0.02988314701776419, 0.030311726698918, 0.02360620615737779, 0.015408044281814779, 0.03120500108759318, 0.04306851413899234, 0.04121240534420524, 0.038822459123496494, 0.06919670943170786, 0.019586976916928376, 0.02520671420331512, 0.057607385595994334, 0.030180158758802072, 0.03407996413963182, 0.010704858527917947, 0.039395268208214214, 0.025252807087131908, 0.03292110775198255, 0.04850012589512127, 0.055368016473948956, 0.051032588218471835, 0.030449550731905868, 0.007412438680018697, 0.013860025160413767, 0.06994440752480711, 0.08109953680208751, 0.010664070091609443, 0.021334177448547313, 0.09627579352153198, 0.06553690188697406, 0.08617652580142021, 0.05932722081031118, 0.046013060957193375, 0.033929305616766214, 0.052803015003779104, 0.036296751616256576, 0.02090629156945007, 0.04892075314585652, 0.053190675630633316, 0.0034118526132910377, 0.05788878085357802, 0.03312784380146435, 0.04534270228551967, 0.03645344231543796, 0.034310696580048115, 0.04954334295221737, 0.048612969661397595, 0.014905539906716772, 0.05476178614688771, 0.04392039789152997, 0.02076387724706105, 0.042476896063557694, 0.021832417231053114, 0.018998290112774287, 0.03150072021942053, 0.019544951850548387, 0.04669336695224047, 0.04692233859428337, 0.0410981637957905, 0.06835728018943753, 0.021802756769050444, 0.029370310250669718, 0.021615754214248488, 0.028442252460601072, 0.013827750642251755, 0.01540272287093103, 0.05052165474210467, 0.054670648715857945, 0.05133878732366221, 0.07210373665605273, 0.046571088156529834, 0.014940742303484252, 0.029708878868924718, 0.07284813706896134, 0.03281570412218571, 0.04182318185589143, 0.024216100573539734, 0.01976500584610871, 0.06475828973842518, 0.030920091018612896, 0.013023924980578678, 0.019658341837514724, 0.03815766104630061, 0.03310462094045111, 0.032273181448025365, 0.05693040442253862, 0.06127012441200869, 0.02916797450078385, 0.047801808188004155, 0.03553103841841221, 0.01253384373350335, 0.11637350544333458, 0.027813710205789124, 0.008770628300096308, 0.0591627982045923, 0.05958374097411122, 0.06893404174063887, 0.0018934394590490098, 0.06613657078040497, 0.021621133300608823, 0.05974762075181518, 0.053045540382819514, 0.0319138564435499, 0.045927694466497214, 0.01789857823002551, 0.004952807336979146, 0.019128005652289306, 0.011282665023048009, 0.045786494721791575, 0.056349826111857376, 0.03240679517122252, 0.0728020713265453, 0.06102792812245233, 0.03786282061732241, 0.04615560420123594, 0.02237262440446232, 0.027232363454199264, 0.03430863722626652, 0.07854122229452644, 0.008715707675686904, 0.03389375716713922, 0.058669150407825194, 0.007952617015689611, 0.05091290142653244, 0.0156266428197601, 0.014932810229116251, 0.028363484722961272, 0.08048412589622395, 0.06960452933396612, 0.030413120186754634, 0.024113000570131198, 0.04450600414669939, 0.03373062717063086, 0.03498363707746778, 0.08425975936864104, 0.026301552508292452, 0.006164939325701977, 0.02663811944824244, 0.023058808209108453, 0.07262111282242195, 0.030593118563826596, 0.014008598884434571, 0.08591980886246477, 0.07300839346966573, 0.15834747813642025, 0.116211132013372, 0.16310972188200268, 0.23458385946495192, 0.12258518141295228, 0.1002344007470778, 0.09879220170634133, 0.06925595910953623, 0.14958763175777026, 0.10871253295668534, 0.12780707835086755, 0.13870040167655262, 0.14800085047526018, 0.1524389444717339, 0.0982476162857243, 0.17148401109235628, 0.16198821206177982, 0.12664237299135753, 0.14507914653846196, 0.14349053321140154, 0.12838491877274855, 0.13141232489475183, 0.08723146455096346, 0.17850412082459244, 0.08578520108546529, 0.13807891788227217, 0.14299763180315495, 0.12924634612032346, 0.15131918527185917, 0.11542100512555667, 0.11699230223894119, 0.07509422368769135, 0.33689464522259577, 0.08731570467352867, 0.15952209010720253, 0.12321891954966954, 0.18448045370834215, 0.0876589755394629, 0.18824287610394613, 0.12963383032807282, 0.12584912484245642, 0.05526424811354705, 0.09298689357404198, 0.11798845949981894, 0.11311294790357351, 0.10613304815654244, 0.17807950718062265, 0.1179810498974153, 0.10493783586259399, 0.08891191080744777, 0.14347124924617155, 0.11537710390985012, 0.12672718986868858, 0.07784062810242176, 0.16977110372057982, 0.10575614909508399, 0.16758554242551327, 0.19359015274260724, 0.12643124003495487, 0.07869839136089597, 0.14607778723750794, 0.17707986224974903, 0.1033730459000383, 0.0808324586333973, 0.12080921099654265, 0.11138221541685717, 0.09557006960468632, 0.1454415928040232, 0.18424596557659761, 0.16846879145928792, 0.11914086980479104, 0.0888512022793293, 0.1534053547573941, 0.12118426444275038, 0.089719062138881, 0.0882108619968806, 0.08994920764650617, 0.1552468987980059, 0.16317287992153848, 0.10907863652599709, 0.23639961917485508, 0.13562404603830405, 0.10977910179644823, 0.1263354987438236, 0.08784268211041178, 0.10498679216418948, 0.11459806428423949, 0.10034217246408973, 0.15051577266837868, 0.12172851738120828, 0.1252776083669492, 0.2154864642236914, 0.07406669775290148, 0.09517361516399042, 0.09313215435083423, 0.12936426193586417, 0.1429887158530099, 0.08191105789904084, 0.10833429718124014, 0.10770506451704673, 0.10086207956607852, 0.12373084707983903, 0.10849462822079659, 0.16881635066654, 0.10103928577154875, 0.17450505255588464, 0.15321806552154676, 0.21624676271208695, 0.054647792263754776, 0.12876149213739804, 0.333912158118827, 0.15806722960301808, 0.1742451057902404, 0.09976245250020709, 0.1054444301075169, 0.14486829856676714, 0.1828456592879125, 0.15452841163745948, 0.10450469981878996, 0.20693952856319292, 0.22934996602790697, 0.24878470173903874, 0.1319997598017965, 0.20682731244180882, 0.09966607338615827, 0.14650286228529044, 0.21785968116351537, 0.11354822811803647, 0.18325652581240448, 0.15587807207235269, 0.12403069170457975, 0.10723760817199945, 0.12877906619438104, 0.08284176367201976, 0.15699167017425808, 0.10095430604581322, 0.17378906240420683, 0.07972690117146287, 0.074379705957004, 0.09981388545462064, 0.13575443332748754, 0.1337697183979409, 0.13807381529893192, 0.18382490745612554, 0.16283312386700086, 0.10071318184158631, 0.2051704384918724, 0.12551388783114298, 0.08381174305187804, 0.14288164302706718, 0.2681164358343397, 0.06364937352814845, 0.10390930569597653, 0.13113784390900815, 0.09670378626989466, 0.213143686364804, 0.1491014885583094, 0.1339692755469254, 0.14485263797853673, 0.18486168182321958, 0.19442875417215483, 0.2524689569004944, 0.08596609852143697, 0.12891284615865775, 0.22014175727963448, 0.18222648251269544, 0.18881864020867006, 0.07566076650151185, 0.06638374751699821, 0.08792365169418709, 0.05796854943037033, 0.19725653529167175, 0.15608737298420497, 0.1674389788614852], [0.04820161459169217, 0.002328425570989826, 0.011545839070874666, 0.05508914536663464, 0.01679662548537765, 0.010560504443544363, 0.04936882035274591, 0.00641882762179843, 0.008021624027086156, 0.05184551727558885, 0.01562010683119297, 0.06591128358351332, 0.058817898854613304, 0.04110651656187006, 0.034912221266755035, 0.06732715546552624, 0.049523146357387304, 0.011230036150664091, 0.010766075109131634, 0.03511714902041214, 0.018558526478175606, 0.0800924619127597, 0.008702356651026224, 0.05761575193277427, 0.011367531094167913, 0.07262407802045345, 0.014657168948490704, 0.10537211184522935, 0.025461051180692654, 0.04944683152383991, 0.057553096009152274, 0.030118293328476802, 0.07210451018597398, 0.02154019594724689, 0.04789635865017772, 0.014845028153753706, 0.06712901645473071, 0.03789933258667588, 0.019767955777102282, 0.023969030706211925, 0.07240003254264593, 0.044008278354470215, 0.013992047718992191, 0.020307810112301792, 0.012417149280996194, 0.03614693786948919, 0.04482530237042478, 0.07739351423723356, 0.03135378685380731, 0.05257809082312243, 0.04488434509507247, 0.06517166684248618, 0.039633030271423716, 0.04298089491203427, 0.0280611210369638, 0.04617456925500717, 0.025453163211100867, 0.02493348341834332, 0.025463529529848268, 0.01807892435629453, 0.05486482847481966, 0.05737637834889548, 0.019478034727009277, 0.024421596600274955, 0.04340908782822745, 0.030174910290432826, 0.03041292680427432, 0.010954114126174577, 0.019694287230127623, 0.06750769327793803, 0.015019895109747137, 0.06078151134507997, 0.024469433319089667, 0.04993950901553035, 0.008168901749221342, 0.06470527579741818, 0.05312255410743611, 0.03277017102975931, 0.04684494149738124, 0.018518000974186828, 0.04789518478459545, 0.03193110819639904, 0.044855120591819286, 0.041363664370562346, 0.03279401135763951, 0.02593035314099065, 0.01730486687405833, 0.11442487500607967, 0.0291783425158688, 0.02792641317604908, 0.09347795615238802, 0.027519970699878674, 0.054313376279813905, 0.003383470341629748, 0.04282099813488977, 0.03131057435114469, 0.0339446744349386, 0.0380283458424466, 0.02339620465811874, 0.03522200982219406, 0.07769167609512806, 0.042489689841334305, 0.02362911349960736, 0.03346313848825438, 0.049782099069229195, 0.017739678899358426, 0.013915496246357049, 0.05247555400377937, 0.038630935829132795, 0.06654353572853974, 0.051553984704826555, 0.06794811000249215, 0.009729363506526818, 0.0398036275458123, 0.05883018033845084, 0.02155410421879164, 0.03642797689618809, 0.08119514917156526, 0.015414212165134293, 0.0195522732433996, 0.04376398539170623, 0.041845872066915035, 0.03449829454932894, 0.02507228454175804, 0.05254488671198487, 0.04335236230066844, 0.025852333488208906, 0.055553907927657874, 0.038859988895377943, 0.03132703900337219, 0.025080996931397488, 0.019917861126097183, 0.004689674001253609, 0.036601664897586615, 0.05832532314317567, 0.0305142456532589, 0.04122284460546715, 0.03729203017428517, 0.08128860379968371, 0.0028564006663925412, 0.01230328092684171, 0.01918467180803418, 0.014168091085074204, 0.055206698165940385, 0.023248411249369383, 0.05339701134445412, 0.05972273208733116, 0.03257707692682743, 0.02866608589621527, 0.0302840153287564, 0.06881723193717854, 0.018900197697803378, 0.06728464524660792, 0.016250097758269737, 0.06625635256724698, 0.017483789773125733, 0.03837384569591709, 0.04150399219776903, 0.015480335402701582, 0.07597779163292476, 0.07367844680058104, 0.06142028421163559, 0.05213173691715513, 0.02756720352252679, 0.025033133071182028, 0.03796545243156808, 0.03757497927706156, 0.04564592262197818, 0.023193573745499765, 0.034699721062289815, 0.018610330930511867, 0.04960431271631803, 0.01970727269404701, 0.019978352523009692, 0.04008929757401347, 0.009958616740602468, 0.022965424827166965, 0.03333715149866683, 0.0350006988405117, 0.033871874412787814, 0.026167334888928702, 0.023681287753528783, 0.055696559737303426, 0.06078510079532862, 0.032623797455536466, 0.03060769010335207, 0.09870473175708737, 0.057800075970590115, 0.035406157440905056, 0.03127960940556867, 0.02282715805007943, 0.03198775229975581, 0.07834729698619672, 0.06997585762292147, 0.10049005917140416, 0.013941940452371324, 0.017863263874979954, 0.016924563263143812, 0.009578407276421785, 0.044824681510882716, 0.05037239400137748, 0.04662547952362469, 0.03953287510999611, 0.00735953839362732, 0.05355610066492643, 0.013410101312079599, 0.07114998783384051, 0.007923953151995582, 0.044620652816125324, 0.018212431210226247, 0.015200862095558217, 0.02963384985923767, 0.0615316793056471, 0.0290918428716915, 0.04947328081886683, 0.02498930479798998, 0.044774096725242477, 0.03565930528566241, 0.025766661656754355, 0.010877687334349113, 0.04659517275701676, 0.029046716900276284, 0.013777037783126746, 0.0738365590306265, 0.07219839229115418, 0.0892271174650107, 0.08913345927638666, 0.049860948231071234, 0.0385130064428917, 0.10449999078576054, 0.028901405233357633, 0.05960301136864083, 0.03405496012419462, 0.04378783929028681, 0.02026477063606892, 0.033985949720122983, 0.06071903184056282, 0.055116622642214806, 0.027750357087435465, 0.04748745648456471, 0.029739837029150555, 0.015768668680850948, 0.06165182071604899, 0.02477973247213023, 0.031076072648699795, 0.03259040674726878, 0.018826937968177453, 0.010018108146531242, 0.040728711656161716, 0.013153934834658034, 0.02693734660611621, 0.03995713252308113, 0.01459226877029453, 0.023836344879652773, 0.03706663780446563, 0.020952677919662425, 0.0706300875172019, 0.016568444336631467, 0.06832386912511927, 0.02356382316377546, 0.03656205541587301, 0.009335802169516683, 0.05257328340251531, 0.04566413110920361, 0.024085150100290775, 0.029454723399664675, 0.014487016114539333, 0.06056074319141252, 0.09012357079024826, 0.027047008043155074, 0.05109770383153643, 0.02471504603246493, 0.08098955984626498, 0.020727567141875625, 0.0392732302924352, 0.013294075216565813, 0.05354133574292064, 0.06334773078560829, 0.07632349843957595, 0.06553495449147054, 0.0495026647778494, 0.04771712701767683, 0.08817449930523123, 0.008085533544155104, 0.046266456467232535, 0.04192278061860374, 0.03147110216585653, 0.042831030275140486, 0.054612901993095875, 0.08578841734145369, 0.04876667480649693, 0.0835912734536188, 0.028418727651504532, 0.043036103913826604, 0.016639407225219265, 0.029972527043095658, 0.034871851825820546, 0.031959711840110164, 0.026920832760099853, 0.04069367550047381, 0.0365267715949033, 0.01817579540823187, 0.01934790867380798, 0.06917312355445963, 0.04125967548627939, 0.024676372929077064, 0.01386937452480197, 0.03084861413974847, 0.017583653164495314, 0.04763938047524009, 0.030023698761527027, 0.04355316795408726, 0.014509842032566667, 0.020109462451988032, 0.041790289870862446, 0.03545756325391786, 0.01898411551623472, 0.03332764522305556, 0.028947867918759584, 0.04404436284676194, 0.019656989856490066, 0.07754577071006809, 0.048734848121447225, 0.02565416055066245, 0.026024404879925505, 0.09153998550027609, 0.06251075105475527, 0.021922083937429955, 0.05554363151480045, 0.04404653076614652, 0.07979119236447982, 0.0503590302541852, 0.026216035043554645, 0.02683703538163432, 0.010699965442264718, 0.02998556848615408, 0.04551496536337903, 0.047193939198872874, 0.050886645513985834, 0.07125543217573847, 0.03882332764832037, 0.025651266598807912, 0.07253001271081821, 0.054154395524944575, 0.026390825664358478, 0.014671231586752194, 0.01839320481355701, 0.03579307167923876, 0.04616969398089817, 0.059484661290688176, 0.11889199673065118, 0.020924111595377326, 0.11727411140288625, 0.12117350287735462, 0.04434710481603231, 0.1204591683511223, 0.14132998271712235, 0.10621485912374087, 0.14554363090012754, 0.12122264238340513, 0.0725243469434125, 0.18275116650121553, 0.12351837062409946, 0.2522894436759608, 0.15389465993004187, 0.10596018457519156, 0.2209078911691904, 0.1551135666668415, 0.1415371937411172, 0.16181130441171782, 0.2087362485804728, 0.09340156667998858, 0.11810792237520218, 0.20421806031039783, 0.05428416873993618, 0.10900461514081274, 0.0983197513435568, 0.14980872560824665, 0.11511608505887644, 0.21307318657636642, 0.1828864256718329, 0.10360942714448486, 0.137608991669757, 0.10133872327527829, 0.14960080890783242, 0.07211716486407177, 0.1357714645564556, 0.09484759944358043, 0.1659794771777732, 0.11238809608455215, 0.13008785167975084, 0.11687925830483437, 0.18895931408873626, 0.12862076397453034, 0.10422206962747232, 0.11463207245937415, 0.05574547532679779, 0.13618994424385683, 0.12950254737266473, 0.1496470442840031, 0.13584323999072823, 0.23357251659035683, 0.10716592094727925, 0.19615361733095987, 0.14010102009134634, 0.2134125626512936, 0.1839782835117408, 0.15588925432946, 0.1378463567899806, 0.14439287622060093, 0.10744590485202414, 0.09471370412835053, 0.15971278558884347, 0.19848006963729858, 0.1165684349834919, 0.10447175694363457, 0.13786230236291885, 0.15018133632838726, 0.16136910314006464, 0.11120842224253075, 0.11211252944277865, 0.10069835585142885, 0.18725659831293992, 0.1321896817535162, 0.1506217462675912, 0.0860911864521248, 0.08795243514967815, 0.20563220871346338, 0.130958710664085, 0.1508778796664306, 0.09656801141266312, 0.10401943192950316, 0.11999415473214217, 0.08413904798882348, 0.1299155309264149, 0.08753511575715882, 0.1309201970164265, 0.1446699627808162, 0.12247574728514467, 0.17490746453404427, 0.07579960833702769, 0.12186252804739134, 0.16269003440226826, 0.10595675797334739, 0.2141830391649689, 0.12641654296645097, 0.06979118074689593, 0.11693649951900754, 0.21529852359422616, 0.09627779519983701, 0.12090877922517912, 0.14153579595897878, 0.22055867633649281, 0.10631657830838646, 0.0961280425212213, 0.23936123454145022, 0.29116648754903246, 0.1169004285974162, 0.12847729453018733, 0.18374401251120226, 0.10839230513998441, 0.1832311621734074, 0.16971025270010742, 0.11947985232940742, 0.07217496247696024, 0.16677541232534818, 0.09758931518133197, 0.16935183693255695, 0.08817141197089638, 0.15645884376551422, 0.08852794819644519, 0.07639705163559743, 0.10118812921323947, 0.12927594381783689, 0.12255946493574552, 0.08700064050831965, 0.08816307277551719, 0.1091788357922009, 0.08869192975440196, 0.18429585147116864, 0.09192434844693967, 0.09566048439592123, 0.0735016545014722, 0.09944678443883147, 0.057312819973698685, 0.15539092464106424, 0.1566126269421407, 0.14645513413207872, 0.1152682668928589, 0.10237291242395129, 0.13140271683888777, 0.16227910002427443, 0.10098665859550238, 0.14904512943966047, 0.08440278097987175, 0.15910032631031104, 0.09677625380988632, 0.09735112224838563, 0.1210707455341305, 0.10932265128940344, 0.09164528056446995, 0.15939305988805635, 0.16716751057122434, 0.1944328932357686, 0.20676559289651258, 0.09694046606974942, 0.1965965921325343, 0.14313302668077604, 0.1535425002553633, 0.178245001871671, 0.07455704786947795, 0.18756101626370633, 0.13775761798024178, 0.13846001029014587, 0.12308558741850512, 0.13282603903540544, 0.10085203724780253, 0.12374038728220121, 0.16763006789343698, 0.18713182929371083, 0.10389870697898523, 0.11409320708896432, 0.12737270737332956, 0.13288394521389688, 0.13143443156565937, 0.14238449398960384, 0.14268576353788376, 0.08760619908571243], [0.04289058868640235, 0.026762676425278187, 0.0643050487020186, 0.07535769883543253, 0.027564782848847762, 0.06931729867522206, 0.023650989468608583, 0.03331737559554832, 0.009498783736489713, 0.07021030504256487, 0.01460900653286704, 0.005477823383573974, 0.0348378877554621, 0.07766564070646252, 0.030946910115224973, 0.009594949960176433, 0.04327074132327523, 0.021311941855986203, 0.05069873541859644, 0.03435038070061377, 0.07361418274896485, 0.030288005114666054, 0.08718235897166388, 0.02883318192990763, 0.024378623281206404, 0.0738669845408627, 0.03976744127326778, 0.02188783827503877, 0.0044412568178293955, 0.07087202596345119, 0.019778646096321087, 0.029458645332072462, 0.06473234934466225, 0.009301725292711385, 0.05862390569278172, 0.07854760052370173, 0.013645356188395193, 0.05317942891269922, 0.03285443150837507, 0.019156390468456914, 0.031602174775408845, 0.07672839385590383, 0.025203080648290258, 0.03658074566296168, 0.0276125076093844, 0.014858286728018096, 0.02655632544441947, 0.025810902139970233, 0.007423346978612244, 0.01639306847937405, 0.03657127670677645, 0.007718414716821696, 0.04834314003320677, 0.07614009720938546, 0.018287204072943757, 0.010402356590410429, 0.015082715578111154, 0.02989178816122668, 0.04157282279006072, 0.02346944233535656, 0.021781525408316935, 0.03394470836168953, 0.032673279621771405, 0.036081204789557626, 0.01330770698509046, 0.05416948614375932, 0.010695504922685879, 0.07304821668991021, 0.011823443014041653, 0.019033502687567046, 0.013302204914257994, 0.023757487236123, 0.06625415411378656, 0.01440235530026257, 0.047213511541485786, 0.04109945301232593, 0.05588181336809482, 0.045037012081593275, 0.051789419392922094, 0.0941341198714716, 0.013083267956972122, 0.0547307669185102, 0.033948464053017754, 0.01186645110802991, 0.011527095389153277, 0.011355082521082034, 0.05214292595961264, 0.03478071439479079, 0.07204634616417543, 0.10222447610327176, 0.03428813868335315, 0.09125140455684491, 0.00769955653231591, 0.038163917139172554, 0.04722276675914015, 0.009792334100763713, 0.04656034694718463, 0.022557162180809037, 0.03227516616295491, 0.014704379718750715, 0.01860324023956699, 0.031984556399817975, 0.017800804726513367, 0.006001795758493245, 0.026967531236420785, 0.03907386991860611, 0.01856812944502703, 0.017009509062128406, 0.03406061232089996, 0.01583824396532561, 0.014321953989565372, 0.021619850869423578, 0.048587059801710505, 0.02313683125456529, 0.02759319819909121, 0.026523854151102047, 0.029648346759911095, 0.07387045185480799, 0.013405787525698543, 0.06024481050137963, 0.030513136248503412, 0.05661598825827241, 0.04702887198488627, 0.018007377927590693, 0.03904029939855848, 0.02070712797077639, 0.04454474849626422, 0.056664357627076764, 0.018860649284241453, 0.028216899106545106, 0.008891656895035079, 0.08021065592765808, 0.021655429853126407, 0.08436960061745984, 0.01847337881502296, 0.051189451944082975, 0.03425538919067808, 0.0811669628268906, 0.06402494944632053, 0.009601297655275889, 0.05599409395030566, 0.03598097498927798, 0.018784012146560208, 0.022435069982228533, 0.029155136618231024, 0.03126772825739213, 0.07107952875750405, 0.0205506883295519, 0.026704792299174836, 0.015929635846987367, 0.036560474429279566, 0.0790523084412728, 0.031877795699983835, 0.025850691433463777, 0.08300768584012985, 0.057367652388555665, 0.07281470564859253, 0.06091841935579266, 0.036442633252590895, 0.056972358242741654, 0.026302019001117775, 0.03435105584295733, 0.019378432571621876, 0.03083357441106013, 0.00568561752360048, 0.026868295489943454, 0.025920409210292355, 0.011315198232685881, 0.008385692839510739, 0.02329066362498062, 0.04522971941956452, 0.026728057568626742, 0.021962609441418732, 0.025316641965348805, 0.051412839242922406, 0.06112546753138304, 0.008302622341683932, 0.020892208575138023, 0.07679999287107162, 0.06769328617623874, 0.030900864728859494, 0.06484309304505587, 0.05371177356157984, 0.02358272036404482, 0.023433878618691648, 0.05169655509026987, 0.0164268544342901, 0.022262135154700706, 0.06150981690734625, 0.045382203201630285, 0.013339250381769878, 0.03544644545763731, 0.05867441583956991, 0.006067865137343428, 0.05881891665714128, 0.012928832538558968, 0.07053336913564376, 0.06310842505523137, 0.049647698245410404, 0.016681277924882512, 0.014795281358861496, 0.04852795261623604, 0.090419595262834, 0.058336831097091944, 0.04307250392490199, 0.030703288902129446, 0.02527709524812443, 0.0034352794588942614, 0.049098542891442776, 0.009857431902284068, 0.03439375265900578, 0.043898033377315314, 0.02153632660130305, 0.022547082543107014, 0.02467526013164648, 0.056667648521917205, 0.02482782703425203, 0.03762182533474905, 0.04553504321458084, 0.026976038369217088, 0.023893821884744933, 0.01912257058678993, 0.00405163734519322, 0.02056038798764348, 0.031767679644482474, 0.0406360441286649, 0.046231810469180346, 0.030746613363070146, 0.05029757194487112, 0.0365512701017516, 0.018174407804118733, 0.08107185935867683, 0.0169076762228672, 0.04472118117181318, 0.014742793282493949, 0.02875994425266981, 0.01774146344645747, 0.04491406832156437, 0.034861673800540824, 0.073021210996168, 0.03548850445076823, 0.018755357612722685, 0.03835433442145586, 0.015849950390734842, 0.05879027569400413, 0.007245129755964237, 0.053598634632570405, 0.044342477207205126, 0.0153435478319547, 0.0432808955998293, 0.14856323386941636, 0.03429044909509165, 0.06047181439186845, 0.028450891907726015, 0.02015365374141506, 0.09690872420157705, 0.007714268019688981, 0.05060591861339552, 0.023308156257761375, 0.022783212729596665, 0.03253305696749261, 0.024333212325083356, 0.05974114752773728, 0.05956360205475773, 0.03843499866447278, 0.08568957514528718, 0.060142806332026205, 0.04920997530488031, 0.013806242778498148, 0.049049827469778914, 0.024406093771436384, 0.007610818570745843, 0.03702848717304213, 0.02306910158534135, 0.01384581663712327, 0.03120293834113649, 0.033193817761327536, 0.022860360464879444, 0.12560798706752913, 0.04070363639454756, 0.018008994537272623, 0.02818518946878612, 0.00530521382877071, 0.019847671767430644, 0.026122346320854764, 0.008326543245597609, 0.014231154129707387, 0.06243352019893272, 0.017641128473249928, 0.016886365134269, 0.09200388632182564, 0.04958346472787006, 0.029297388092215573, 0.061655152322990556, 0.02795637728247259, 0.048600616931383095, 0.07231562957167625, 0.024391971761360765, 0.020419686966176544, 0.028012110452566828, 0.03548215336299368, 0.06681511936975376, 0.036664409030761035, 0.038232293113001754, 0.004311786823174251, 0.002990738725722102, 0.03260476794093847, 0.03403740981593728, 0.03529979707673192, 0.021885812848008106, 0.061762530489691665, 0.06928284945232527, 0.032511048684162755, 0.012133536910239075, 0.0260783755553088, 0.019064861183453883, 0.045790046852614195, 0.03202034233670149, 0.02385424293710717, 0.03420532009165202, 0.047048736097557206, 0.007277927594259381, 0.059653494374028275, 0.021423957809539776, 0.03723583390404071, 0.03851565272946443, 0.06674089442406382, 0.0312566511732127, 0.02339773645092334, 0.03715547500178218, 0.01583516680901604, 0.05901434152786221, 0.03524273228166359, 0.04131246890340533, 0.08199406308787209, 0.029703759322209016, 0.00319137835010354, 0.07262322985168014, 0.0409557392953762, 0.027367588698065708, 0.025684803192104613, 0.01919271414434271, 0.09196909783141953, 0.0495481503728245, 0.017452538146504333, 0.05557395863745894, 0.00845568033400923, 0.02394424212564315, 0.01910739006208522, 0.012391448918996113, 0.05873361801994698, 0.051801395536001237, 0.10418700972305876, 0.1137300958590848, 0.13924415249909672, 0.120026168014322, 0.1101840039981263, 0.2918336231793676, 0.12147365962820393, 0.10130448439823729, 0.10099846510482685, 0.2101493248982089, 0.08577145396598748, 0.08409043774008751, 0.20297623266066822, 0.1318239920905658, 0.06278589021946702, 0.13869538051741465, 0.15971320628055505, 0.07746545251991067, 0.14189955858247622, 0.11738473975232669, 0.2596239186823368, 0.07746267052633421, 0.15371859366340296, 0.11986436455377511, 0.15263145842722484, 0.1397788788058928, 0.11791985960943357, 0.12171702299799238, 0.16494977314557346, 0.14077122269996575, 0.047472830662237744, 0.09718633323375668, 0.12250700060810361, 0.1535468293087823, 0.09631862265190907, 0.11716813780367374, 0.08818745253873722, 0.135920877967562, 0.1072665001930935, 0.19867190505777085, 0.15220277357314313, 0.15921938206468308, 0.19466430081852845, 0.1265944548483406, 0.07301667159689323, 0.1378893487687622, 0.1184177143233163, 0.2375006643789155, 0.10939100690718208, 0.18591229830469402, 0.11374433830912624, 0.09701564096446548, 0.13982398781393254, 0.17016483045050076, 0.1125476603795375, 0.11698504191424165, 0.09728559612163476, 0.14339268846171244, 0.15854552893766335, 0.09910145761179072, 0.06296902003565005, 0.1473837907293013, 0.0883027288530554, 0.15152631487165177, 0.13769416138529778, 0.17243472007768496, 0.07476104263748441, 0.09961329693240778, 0.1361389455518552, 0.10607024974056653, 0.13494986721447536, 0.10674194512622696, 0.14202303838516983, 0.11723158082791738, 0.25164611105407986, 0.12124065070280007, 0.1936934936259474, 0.08932376799306699, 0.16178923845291138, 0.16078743578067847, 0.09438952723784105, 0.2330609011862959, 0.1266711564468486, 0.08993616620344774, 0.08151138720235654, 0.12398698047867843, 0.17074808558183058, 0.15131060858922346, 0.1871560394231762, 0.1447762077940362, 0.16092820465564728, 0.15939692753766263, 0.10884273704141378, 0.13007554305451258, 0.2129308163587536, 0.09955836273729801, 0.1751499186669077, 0.07450292113104037, 0.08404630582247462, 0.12529158618833336, 0.05090366656492863, 0.08202334187392678, 0.19913457094558648, 0.09165442043117114, 0.15781777298876218, 0.15647359511681966, 0.10816055150436503, 0.08137601946613618, 0.08894777138318334, 0.14740129693278245, 0.09634093288332224, 0.17381087051970617, 0.12706682378692286, 0.10051671881228685, 0.14913285044687136, 0.09665649237909488, 0.10591721973781075, 0.21320075115987233, 0.12667568906077317, 0.1662834065833262, 0.16260088847151824, 0.15986097763691628, 0.12031967512198857, 0.14028528306101049, 0.12340280253972326, 0.15139956453016826, 0.1797062541757311, 0.13514851512653486, 0.09812816698104143, 0.1689313216400998, 0.12057375934507165, 0.2325337337596076, 0.12212509395820753, 0.11550639197230339, 0.12329095282724925, 0.20292420259543828, 0.12820980245513575, 0.10373855914388384, 0.16195030909563812, 0.06660777263875518, 0.1472868145044361, 0.14261025616100856, 0.2616406876061644, 0.13443172430353506, 0.23585820251277514, 0.08099631805505071, 0.13907724645520958, 0.09455075394362211, 0.1421712032918419, 0.07646492549351283, 0.07187274297965424, 0.23625650256872177, 0.1313853734838111, 0.0903599045372435, 0.16974970272609166, 0.19397455640137196, 0.1203378327190876, 0.174048317064132, 0.1358959621616772, 0.12098393376384463, 0.1255360623555524, 0.18474192039242812, 0.1659353995429618, 0.12415157950350217, 0.08541265821882657, 0.08777350546526057, 0.2271504947649581, 0.150458585737007, 0.08679433872124978, 0.21114154665597848, 0.2230252189827817, 0.09703376463481359, 0.09792800593589034, 0.08457804657518864, 0.1432031329189028, 0.25795936371598926], [0.04904328639219914, 0.08292253648063966, 0.031000439742846147, 0.0327524544804224, 0.02479943712907178, 0.0688095237793667, 0.051817015412130525, 0.0255025215446949, 0.01890951907262206, 0.034497046044894626, 0.04089798578726394, 0.07139641818191324, 0.05249424764354314, 0.052458834900919876, 0.09084013769669191, 0.023113620267914872, 0.0276541255547532, 0.05374695220962167, 0.035513142057295354, 0.05768925763134446, 0.02477357815951109, 0.028493649791926146, 0.049859842218990834, 0.07401184498199395, 0.006992611676521067, 0.019748425842928033, 0.04962924887825336, 0.042024211425866397, 0.041660628614148924, 0.04091423670096057, 0.022298711584880948, 0.04889934875869325, 0.07328379726303474, 0.07078795547464065, 0.014026222135206419, 0.0062563290869418, 0.05491230557007449, 0.11187197520796742, 0.06837375501969031, 0.050928609512214146, 0.006229681320421929, 0.04257147027445691, 0.0015844674780964851, 0.02529404844556536, 0.02521481421510024, 0.0071876527508720756, 0.03255293804353901, 0.0271298554725945, 0.04533947924418109, 0.04500322782301477, 0.04947349116472261, 0.005158785547661994, 0.023987100093758533, 0.027431125020874397, 0.1129040066152811, 0.015037920392517532, 0.056175415470663986, 0.017587580185915743, 0.018975579545700123, 0.026374084509110877, 0.06319126739565815, 0.06686261682105915, 0.05033822297783835, 0.03706332316089954, 0.02633319259621203, 0.06088258592145784, 0.0783826486606683, 0.03493640086214457, 0.05988861354334014, 0.06296371389180422, 0.027260458196646402, 0.02118609396607748, 0.000715611179267788, 0.04099854128435254, 0.08817154767790011, 0.058004979975521564, 0.024837407948715345, 0.0818070045539311, 0.01409148024062493, 0.06663363160831587, 0.03800678878490414, 0.010827161920523005, 0.04154131840914488, 0.06514400975512606, 0.011314739373379519, 0.029422177467495203, 0.05285782706258552, 0.030332574687365974, 0.028639514464884996, 0.07610311705086913, 0.0457867322090481, 0.019911364153293625, 0.024325522826984525, 0.04347951637048807, 0.04037171741947532, 0.024504703569359014, 0.03938863552840693, 0.010300732400667454, 0.042869903546358855, 0.04846407872225557, 0.05541220267436334, 0.021158033150381277, 0.024422293795006614, 0.039015766964959245, 0.0242036918643862, 0.07588245746280466, 0.01163279587802078, 0.04908379493281245, 0.020567376898335557, 0.078198053208845, 0.0701370911140527, 0.04905588000214525, 0.03656931234789746, 0.06778868819986071, 0.007279070077597031, 0.03319416720686214, 0.06428825496030705, 0.02648086386865803, 0.038142801129392216, 0.04063226468861103, 0.00600726856750303, 0.019754232406350117, 0.011755239218473434, 0.023073700356430242, 0.047133926169148514, 0.023070083764780844, 0.049252505879849195, 0.0071632797730022246, 0.024139444776145474, 0.007676309922577015, 0.03413885758657541, 0.03190259276224034, 0.048916892281600406, 0.014958714999790703, 0.02295671752654016, 0.048851620605481524, 0.021183174569159746, 0.05035985467423286, 0.059474849674318514, 0.04289157595485449, 0.022188671864569187, 0.02018088674438851, 0.03642073692753911, 0.11961539648473263, 0.017362045323742286, 0.07495205024523394, 0.04169614313702498, 0.024471563919048225, 0.015564733284658619, 0.02979752268376095, 0.027909195349950875, 0.025940534558945468, 0.09037464231784854, 0.018467769026756287, 0.01712651564074414, 0.03747135680168867, 0.07562681939452887, 0.04744556373251336, 0.014577799011021852, 0.017732666239940693, 0.056450174655765295, 0.04674900003841945, 0.029882068147084544, 0.07518060798091547, 0.012873151106759906, 0.03457189185012664, 0.03875379137960928, 0.05842379893043211, 0.049298863392323256, 0.05502256751060486, 0.010179233072059495, 0.11097041251403944, 0.027776604518294334, 0.05339176966143506, 0.045572572986462286, 0.07660262739019734, 0.03575244778767228, 0.03837232917015042, 0.014701012488720673, 0.053636798834694285, 0.02420968163226332, 0.04289671585762075, 0.009705255157314241, 0.06211876815983227, 0.01617148608368422, 0.03800784390685814, 0.02136162419005164, 0.08479926934731857, 0.04366947903430887, 0.0357094150967896, 0.014055193035996385, 0.04966392880305648, 0.016634370799043348, 0.03315794700756669, 0.052263101296765466, 0.014995949608939034, 0.07909118171249117, 0.023851544064070498, 0.025216515641659498, 0.07576938638729708, 0.02637745513181601, 0.04885791741045458, 0.06801025023949997, 0.04610219331724303, 0.11232049364064421, 0.0438931207837803, 0.0190981619858316, 0.028317400320832218, 0.025940636339198266, 0.02565420465543866, 0.02169965167662927, 0.0264069052479629, 0.008204974367150238, 0.04577359237841197, 0.06926862057298422, 0.020298225805163383, 0.02542265797299998, 0.02690010012260505, 0.03253626643813082, 0.033702909015119076, 0.029763633252254555, 0.04680881968566349, 0.08742024656385183, 0.10553449884589229, 0.015892124734818935, 0.027214573962347846, 0.04362506891733833, 0.027152084279805422, 0.0029167455421494587, 0.12209626979061536, 0.1003502741722124, 0.07693169651819126, 0.02485811005213431, 0.02029862953349948, 0.05314558019329395, 0.02577955721478377, 0.04873423743993044, 0.037979104556143284, 0.038728027404951196, 0.041445661934890916, 0.018537405379382626, 0.007225730439781078, 0.03781963525606053, 0.018031689837308865, 0.04460966054882322, 0.048335326702467034, 0.037095187165375264, 0.01974116891090359, 0.029940680001995394, 0.012157625751569867, 0.05469262646511197, 0.015984905916931372, 0.006991226616914251, 0.04924630067710366, 0.01582635603179889, 0.05589786411396094, 0.03345374756359628, 0.05398777107309018, 0.00705001107417047, 0.08527044406426804, 0.03360967830355678, 0.03035934967920184, 0.040486226989222426, 0.01716257299163512, 0.012967475956039769, 0.04844935790502599, 0.016772858100011945, 0.03465528041124344, 0.02420128645774509, 0.052332427219620774, 0.041563238482922316, 0.028587654033409696, 0.022063051283891712, 0.030390643714261905, 0.013260577639032687, 0.040877232793718576, 0.05025225937632578, 0.02714460003854973, 0.019602590007707477, 0.04194879565121872, 0.021624911044325148, 0.02562405395188502, 0.08375505823642015, 0.07256308450762715, 0.0049664984773179245, 0.05933446077896016, 0.03792585652055485, 0.029106173531285355, 0.0521530361313905, 0.04456096887588501, 0.03964695381000638, 0.03158619188304458, 0.010557678345191692, 0.05443417926185897, 0.061188130240355215, 0.014307859120890498, 0.052055014962596555, 0.024376066900523644, 0.037010054769260545, 0.03947373399777072, 0.02578934168975268, 0.013704202986056251, 0.047948395500757864, 0.04063462259780083, 0.03376912385491388, 0.01882677342343543, 0.02556164569354483, 0.006152007296415312, 0.05369899674717869, 0.02223733639610665, 0.007841193083939808, 0.04687032209975379, 0.035976364343826256, 0.038596327150506635, 0.02318215060846082, 0.01850235226031925, 0.029266813304275274, 0.05693961214274168, 0.019925291084551384, 0.019993297256795422, 0.0479643444663712, 0.07430115195789508, 0.027417706990880624, 0.03213835653981992, 0.02513974449331207, 0.008350824621239943, 0.03635670018515416, 0.03764271403529814, 0.04864758851804903, 0.053963075791086466, 0.019763129696782147, 0.028304574312642217, 0.035342646563159566, 0.032478082060281716, 0.00983580359856465, 0.024820118876440183, 0.07155552107308592, 0.045785347997610054, 0.05881464188652379, 0.045979537934597046, 0.04142434575728007, 0.03661174114261355, 0.033063722242202075, 0.071235985362104, 0.0214979707130364, 0.10776066367647477, 0.04829942202195525, 0.02150955669847982, 0.061544625753802915, 0.07374042418918439, 0.05664041891161885, 0.013137459156236478, 0.20669095404446125, 0.11295474746397563, 0.08628795482218266, 0.09073117854339735, 0.18336669275803225, 0.13876600244215556, 0.18519774664725575, 0.15784062604819024, 0.0961101156260286, 0.09007964243314096, 0.11541559041610785, 0.1723017543554306, 0.16477704527122633, 0.12436609156429768, 0.12124977021345071, 0.12356109118887357, 0.1258542952792985, 0.17505724435406073, 0.13346667108791216, 0.17796768460954937, 0.1786094701715878, 0.08409056666174106, 0.16583256077553543, 0.1794488179896559, 0.12759832026703016, 0.14452381990849972, 0.13003753152276787, 0.10657445554222379, 0.15506752128047602, 0.11585096562547342, 0.08430051896721125, 0.16659807041287422, 0.18473212234675884, 0.19385814693357262, 0.13706804998219013, 0.1397594998457602, 0.11765723941581589, 0.13106707270656312, 0.17852294338600977, 0.08309143741748162, 0.13614269106515817, 0.1633384424660887, 0.07372228694813591, 0.254528880651508, 0.10067029842840773, 0.13079806071306976, 0.18922253139317036, 0.11105261024619852, 0.1254152695515326, 0.09566284569778613, 0.16314001168523515, 0.06898857560008764, 0.10401467539902244, 0.2325338694666113, 0.19184059090912342, 0.11066332792064973, 0.10745095993791308, 0.07248524975563798, 0.10561939714742558, 0.06632020949785199, 0.13722225385052816, 0.12903403251298837, 0.13131822565836565, 0.19132156590265886, 0.08310054335743189, 0.09003099147230387, 0.14777668964649948, 0.1251173791076456, 0.14761019072362355, 0.11800832700516496, 0.10644965259624378, 0.07631388359836169, 0.09501790494791099, 0.07182310135768992, 0.19344296492636204, 0.22555776951568468, 0.08726773903306041, 0.15305596350559167, 0.13754234596022538, 0.11453299277595111, 0.14463866874575615, 0.1532092581370047, 0.09482349787971803, 0.13524718768894672, 0.1456770444554942, 0.17403604915099485, 0.11542766833943979, 0.09445885316069637, 0.09818153376025812, 0.20864589485738957, 0.06383947868432317, 0.08263839315623045, 0.14616905019751616, 0.21480488936815942, 0.22473907630358422, 0.08630495890974998, 0.14487287189279283, 0.0669833349862269, 0.09472726804337331, 0.1313195148749011, 0.10064932491098132, 0.07647853690598692, 0.08813096449843474, 0.20672033461076872, 0.14037611175860676, 0.18434870934912137, 0.11615234373935632, 0.12818865930395468, 0.09834037202277354, 0.10506721213459969, 0.23983924889138766, 0.15340547689369746, 0.18318909300225122, 0.17852153203317098, 0.10627766432506697, 0.1283561760293586, 0.11262358166277409, 0.1500144845673016, 0.16187648448560918, 0.19593158710215772, 0.10897875617125205, 0.16328539459833077, 0.1596730234367507, 0.07900619520140545, 0.14487052416162832, 0.16388512455991336, 0.18223843829972403, 0.11277557350695133, 0.09165788095976625, 0.11946708230035645, 0.10627490947289125, 0.1402947282684701, 0.09813393452869994, 0.11681813587035451, 0.13423750043979712, 0.12503105588257313, 0.1053302665906293, 0.16117824481001922, 0.22600372987134115, 0.09488879330456257, 0.08081907792282955, 0.16847534610756806, 0.10250222084245511, 0.22299705977950776, 0.1077673743878092, 0.14674811198243073, 0.1309949851461819, 0.12717761498476776, 0.12681997274713858, 0.117091300498162, 0.08139582590333053, 0.08808484447321721, 0.281764597765037, 0.20164812249796732, 0.10905185474881104, 0.10473328469587223, 0.11293902580759355, 0.17671631675745758, 0.09611451931829963, 0.12349976519388811, 0.12706852012446948, 0.14322415393378052, 0.10267041610287768, 0.12414123862981796, 0.11125349053846938, 0.1139798645994493, 0.12739119066723756, 0.136726529736604, 0.14616687888545649, 0.2177446966192552, 0.14550169743597507, 0.24893460369535855, 0.17965004433478626, 0.13981994374522141, 0.11410660137023244, 0.07390630564519338], [0.041431592511279244, 0.02123750147542783, 0.03630991519561835, 0.026914781924071055, 0.05306607624515891, 0.04540871695748397, 0.018848069244995713, 0.061186189630201886, 0.06001927903188126, 0.03274904823462878, 0.06871703945632492, 0.046107031271925995, 0.018670535646378994, 0.015081110842792051, 0.04631626433027642, 0.045076007489115, 0.031768894222165854, 0.06720803864300251, 0.04050239987139191, 0.05626606435648032, 0.05686777564031737, 0.019886385582919632, 0.05395543887945158, 0.026947687479800413, 0.029457488429865668, 0.04706587249945317, 0.03231862633089934, 0.0420152242295444, 0.028113961951541047, 0.04919668619654008, 0.04839626932516694, 0.0351893078269703, 0.08975763685469117, 0.05648004715996129, 0.024999208016587154, 0.0652998217514583, 0.023353155003860593, 0.01598953182942101, 0.02133459983659642, 0.01606299342321498, 0.033675818504499536, 0.023467786709911058, 0.06615738144942693, 0.014097525139472314, 0.009144823399505444, 0.019251354836991856, 0.019297580035137277, 0.07869415730237961, 0.061104399019054005, 0.0023237163259182125, 0.10552100956972156, 0.022209854031513845, 0.006827094933084611, 0.030565369874238968, 0.08050929276006562, 0.052264275162347724, 0.014481151875640665, 0.027341875613534024, 0.07818257582506963, 0.0185654322683279, 0.022323308479306952, 0.03413071855902672, 0.05648731766268611, 0.03808906454859035, 0.04269516042300633, 0.04408509191125631, 0.034834196524960656, 0.005628803362404662, 0.07335394421326262, 0.03344450930931738, 0.06763202124940497, 0.029481020024312393, 0.041948761724467785, 0.05750665028712579, 0.05879647071872439, 0.031962951844824214, 0.05015318987092801, 0.01599092791522188, 0.02390343163694654, 0.010371134649696094, 0.006646697916689196, 0.03425782513139503, 0.03106342814862728, 0.03871745243668556, 0.011627588121752654, 0.0412807032865073, 0.03626979002729058, 0.009022033158024507, 0.015065075363963842, 0.03032399121938007, 0.00959008910493659, 0.036312670047794066, 0.066862793240164, 0.04016646057633417, 0.0037588287045114805, 0.016635205397116284, 0.01847153659244733, 0.011336413478212697, 0.029253330813454728, 0.035066068904208283, 0.00995479234760361, 0.047480104557637653, 0.03932544695479529, 0.01331452711019665, 0.008788675635254808, 0.037692840809800794, 0.01818745942520244, 0.048383370374462435, 0.03056880326143333, 0.03773893030094249, 0.048173153440334966, 0.019475607267980064, 0.04215290237750326, 0.03287027530106051, 0.04290199146739074, 0.03145929904920714, 0.01817848071056817, 0.054628552403301, 0.05388307651238782, 0.04216073267161846, 0.05476622037323458, 0.05127942229488066, 0.009567946810940546, 0.0357342630491725, 0.058977795631757805, 0.01231689318748457, 0.04770754610321351, 0.019449034140312245, 0.06844053643622569, 0.01720725791528821, 0.019388122051688175, 0.05798760947904416, 0.10613032723111765, 0.044214644602366855, 0.05864927611712899, 0.03967821052564042, 0.0432461037167481, 0.04108254052698612, 0.10714317645345416, 0.04026284308305808, 0.054738112060087066, 0.017829030086951594, 0.04488630945395146, 0.025825536443984935, 0.07479715427117688, 0.033058863931468556, 0.03888061296726976, 0.06837338182543005, 0.020501172236566032, 0.026428430075091974, 0.034615592898002694, 0.06056589327220406, 0.014815730707986014, 0.03399506923077362, 0.0213329034990498, 0.08338605732257877, 0.06913949535893542, 0.057412042149475644, 0.02770388083133314, 0.013110679923556745, 0.06504982909453766, 0.06853295969111578, 0.014942655772236841, 0.008788707017499422, 0.06386624010545866, 0.06187982205301523, 0.03378541548071163, 0.02795275899448565, 0.026004786736198833, 0.034498386151556454, 0.048510975670069456, 0.008228048798628151, 0.04123175037758691, 0.06871432531625032, 0.021777247245024358, 0.08822099252470902, 0.0378905353801591, 0.02213643823883363, 0.055066224453704696, 0.018092608711283122, 0.008583942960415567, 0.004920996767136135, 0.023510980552860668, 0.048826833721250296, 0.0752561017870903, 0.023415682005829046, 0.02629822090135089, 0.029925942221390348, 0.017874078026839664, 0.03684643962021385, 0.020641778263130357, 0.04763309384829231, 0.010431276601073998, 0.006838849704113922, 0.03891410206311515, 0.035418242149587185, 0.011592190646167313, 0.008549656585923262, 0.019657337605687122, 0.01462571885037635, 0.022209156836782182, 0.010878353146836162, 0.049673010994281085, 0.025721591664478183, 0.0709056473736252, 0.010109046257899275, 0.041473139210471084, 0.03551621921360493, 0.0713319234283907, 0.03924282853092466, 0.011702491602461253, 0.04428126995584794, 0.03600322754521455, 0.06128712171422584, 0.01991115041476275, 0.04357397183775902, 0.02645011605428798, 0.04808048252016306, 0.05482486615489636, 0.02029250405861863, 0.006911332511143493, 0.014482644652681691, 0.046731208850230486, 0.01421654611892466, 0.05215046448366983, 0.01276118349882641, 0.06806284348879542, 0.016697968190003718, 0.019342850195243955, 0.029263593655611788, 0.06208207977137395, 0.0672113091817924, 0.012328746346091586, 0.016206671517076235, 0.05367117002606392, 0.04376177676022053, 0.001996666263689154, 0.08118898128824574, 0.06674209543104682, 0.04140519071370363, 0.03685686870345047, 0.06572326831519604, 0.07440623667623315, 0.004121681666999523, 0.07044432498514652, 0.013887320079707673, 0.046525724697858095, 0.04932252051574843, 0.012839873204939067, 0.0424269389228097, 0.055228438427937884, 0.0278883473615029, 0.03624055873868721, 0.018688722081216316, 0.019667749725548283, 0.03265557664313486, 0.05616171924131257, 0.024210733361542225, 0.0448476838480149, 0.012479063905110317, 0.07640141461576734, 0.023565317637154033, 0.04498226448361363, 0.0926845587257828, 0.04608228509979589, 0.028052551139678274, 0.047025740545775206, 0.00815362622961402, 0.08347402938774653, 0.014060462708584964, 0.03315930747027908, 0.0114396797227008, 0.02098501520231366, 0.010739763217445995, 0.00863697556113558, 0.03622055213366236, 0.03772706950881651, 0.040895807689854076, 0.044545620413763184, 0.036011760123074055, 0.005823193043137768, 0.04189263670040028, 0.037037233489432504, 0.027053157266761576, 0.0185733134525695, 0.015248988888093402, 0.020310977174501334, 0.033438192148293765, 0.04196862244446363, 0.0269515330770186, 0.008976640861614473, 0.053389214977089844, 0.005573559585692627, 0.04376918975529926, 0.04852053962115731, 0.04652808599972299, 0.03525680849062545, 0.07943625748157501, 0.027316517063549588, 0.019023044766592126, 0.05958836179758821, 0.016647617498944913, 0.010733484224017178, 0.03860957215407065, 0.012605751482104617, 0.03765023898865495, 0.013055350481798607, 0.06816505121865443, 0.0451404683158866, 0.02678294256994767, 0.08825313472854239, 0.03486338370878782, 0.052839757675038915, 0.031091699310179268, 0.04793897743469902, 0.031088293064385653, 0.011931751621887088, 0.011910670387026454, 0.06255389231124095, 0.02826058997639588, 0.042675214886133156, 0.04470024836648788, 0.011299181413570685, 0.011745851686490434, 0.020234056748449802, 0.06905061405684267, 0.07430290257824318, 0.02837357623502612, 0.03037555648812226, 0.025886202563664744, 0.06680761477244751, 0.027950301001380597, 0.024659865868410895, 0.09009620547294617, 0.04285013782126563, 0.032008875094886334, 0.034432018641382456, 0.06968710704573564, 0.024966850377885357, 0.036672415743981085, 0.07220717253429548, 0.031534847138183456, 0.008985075051896274, 0.02875915715204818, 0.027597493325759257, 0.027680254241983806, 0.038162366686654944, 0.04113096757126706, 0.07278116566262074, 0.03668180666863918, 0.011475500434504023, 0.07186584227851459, 0.16547335790736334, 0.08301345338778836, 0.09285453174795423, 0.1092126811189311, 0.15557426480310305, 0.1345354180250849, 0.09921764994838408, 0.10307194598551307, 0.24919233843684196, 0.1230898621891226, 0.13902886690837996, 0.15699735629771436, 0.08572325762361288, 0.12483646560992513, 0.1540562326886824, 0.09453632828912564, 0.10611482270594154, 0.1124423924567444, 0.12140727176197938, 0.11732745782605239, 0.12924388982355595, 0.05514804220625332, 0.16501742308693274, 0.12198209948837757, 0.1813706462936742, 0.19216312574488775, 0.10830829571932554, 0.12711930168526514, 0.1803537258612258, 0.17942281652774128, 0.16883477967764648, 0.10156939125486783, 0.1404835238520588, 0.14897154910223825, 0.16614761815539428, 0.11092735268175602, 0.11197651709829058, 0.17137317918241024, 0.07326257947300162, 0.1564959189189332, 0.1367613657244614, 0.12522165636931146, 0.12552869346524986, 0.1480766021247421, 0.15417368710041046, 0.13039876999599592, 0.0933808238644685, 0.16029030031391553, 0.1418783204363925, 0.12935620093984262, 0.1605882586113044, 0.10273121962589876, 0.06527561162199293, 0.1748062949627638, 0.13390439402844223, 0.135856512135693, 0.19552217264260563, 0.11205498967319727, 0.1595290790178946, 0.10244003989334617, 0.0842099209715213, 0.15802980161138944, 0.16902084755046026, 0.11927371339074203, 0.11078305542469025, 0.17255258161042417, 0.13658403738268785, 0.08915047014930419, 0.22391969098576478, 0.0843979362398386, 0.09982681154672589, 0.09736776671239308, 0.07323124472584043, 0.15812741565917218, 0.16385867526488646, 0.07813416913683925, 0.13575764958347591, 0.06756318387176309, 0.09481431051556553, 0.10699429229966231, 0.11359307928276913, 0.08903644233942032, 0.1457819595400776, 0.10387225089860813, 0.08547510379659277, 0.10147521059427943, 0.08385269264025347, 0.22124506879065717, 0.08183844786669527, 0.1364781723490783, 0.11936490849724837, 0.16833798347839288, 0.2346724761383874, 0.09897404230598893, 0.14012248893933638, 0.10232898406684399, 0.09735370746680669, 0.12870925851166248, 0.13597058744302817, 0.20841591219816888, 0.09639231834028449, 0.12807501825903142, 0.10280919687024184, 0.118639364572508, 0.06305486150085926, 0.11921947130135127, 0.14251176001770155, 0.20075593037264688, 0.11026620851563555, 0.13642494806221553, 0.14621428134185926, 0.16664953050868853, 0.14735123461910657, 0.14326128337000096, 0.09007504196571452, 0.10359969016696725, 0.07972433630909238, 0.09847741574048996, 0.1646151061036757, 0.1845073779778821, 0.10568041780165263, 0.13471543336553232, 0.13759756514004298, 0.09018050666366305, 0.12860789895057678, 0.07107044317360435, 0.12265920958348683, 0.07395796251616307, 0.09682288273636784, 0.15524422537003243, 0.0654711654143674, 0.17717036525053637, 0.20812529564968177, 0.13693602063826152, 0.25903682304280146, 0.1471237896808556, 0.12728898972272873, 0.12771700961249216, 0.17732032148965768, 0.1131186747391309, 0.188266339844891, 0.0953938744163939, 0.1598743312060833, 0.10302744087363992, 0.18228244808103355, 0.10094935952552728, 0.14107378146478108, 0.16431015889559472, 0.13705675915947982, 0.14170439834041254, 0.16947860084474087, 0.09383145932640348, 0.1323716105627162, 0.11626960816127913, 0.12602246339832032, 0.19279021423842224, 0.15008566289075784, 0.24077855848840304, 0.13704719181571687, 0.11408555321395397, 0.1873092662010874, 0.12151613592037133, 0.11529293842613697, 0.14481062309018203, 0.17683846663151467, 0.08079589916659252, 0.13949378553245748, 0.1067013144493103, 0.2078625668904611, 0.10090910204287086, 0.17927056684025697, 0.16916635259985924, 0.13826654638562882, 0.11356943233736924, 0.1062486840944205, 0.16099759164665425], [0.06726709833102566, 0.0756176116743258, 0.01458034012466669, 0.027439555818481103, 0.07928100866930825, 0.025754276696326475, 0.04677641963852303, 0.052422360250992436, 0.05501794329445277, 0.04476542504770415, 0.02334154866236661, 0.04433120674054537, 0.03337520034983754, 0.023773860286122987, 0.04188181067417775, 0.014745285202349936, 0.03852644822161112, 0.058506994109068594, 0.0040524986605825165, 0.02268145283284996, 0.053758639975317886, 0.03032903273456863, 0.02390767417715064, 0.01387348135800234, 0.037778091949543784, 0.04503144470176526, 0.04456003249755927, 0.020365370237933736, 0.021572724916040897, 0.044676720164716244, 0.035418415176016946, 0.04335622316492455, 0.09732852024691445, 0.026248012702645998, 0.045046837268663306, 0.044362714514136314, 0.0038680321304127574, 0.029677934279399257, 0.0346217641739973, 0.06830254276948315, 0.0708902378433517, 0.04133440933323332, 0.018659238038318496, 0.021714755866144384, 0.002427398385147431, 0.016486624887745296, 0.013854564649851193, 0.05437035286532981, 0.020261091279930303, 0.021869821473956108, 0.04206134764743703, 0.026027799251356294, 0.01135526318103075, 0.01212227831794215, 0.009864598080249769, 0.026933899648221474, 0.02970130302544151, 0.03136351704597473, 0.044789526611566544, 0.008104611404373177, 0.0038117641899069504, 0.05657457048073411, 0.011400363707382764, 0.050993039804909907, 0.025474038340949585, 0.038807684023465426, 0.09913687035441399, 0.07064234185963869, 0.003946949993925435, 0.010130789912571865, 0.06926921089845044, 0.031480442200388224, 0.009603469815504338, 0.0784331588074565, 0.09346089099666902, 0.018437728585143174, 0.05616067769005895, 0.004512658209672996, 0.03911223428856049, 0.05868171009102038, 0.10178124345839024, 0.04549297743609973, 0.022743079079581157, 0.03537763522139617, 0.04018423140847257, 0.03293138416483998, 0.061061122055564604, 0.015616025443055799, 0.01938907539338938, 0.009500772692263126, 0.02405997984377401, 0.07374490930565766, 0.04360806143709591, 0.011645542158346091, 0.04026843760428684, 0.08566375010247741, 0.039435586759022305, 0.0740218058760677, 0.027440846731354083, 0.035018551096852334, 0.004132145949240241, 0.04644287896475621, 0.07192006401185479, 0.057001637028796334, 0.09273128264716693, 0.03780676005408168, 0.043408999618675025, 0.02220293806333627, 0.031733013290379725, 0.051865113366927416, 0.06457303610763379, 0.05998167462114777, 0.006711054842786065, 0.00942448924096035, 0.014873782771506479, 0.003134424241060125, 0.037313397242022414, 0.0130263236018696, 0.050861957017332315, 0.030939347842442136, 0.03962619063843574, 0.0295336302369833, 0.014375164705727781, 0.07781498626406703, 0.03804750767137323, 0.04498591500201395, 0.06616432964801788, 0.023258075284372483, 0.06529678869992495, 0.053060156027121205, 0.036238553667707105, 0.05531284139890756, 0.03590078232809901, 0.023845511887754713, 0.03681355442053505, 0.03998256062290498, 0.04437356089640941, 0.0008698474370508588, 0.0430780746974051, 0.011758219683542848, 0.013735776068642735, 0.07684200097407613, 0.0058942784921133095, 0.04543446396876659, 0.03219728052083935, 0.045563728282494206, 0.014109779481909104, 0.04043650394305587, 0.06319508754781314, 0.033794836939445565, 0.0344277777975159, 0.021689940144174864, 0.021947342403499142, 0.037399934205625734, 0.036214608166899, 0.055525514629802535, 0.023927331336640885, 0.044472925564540286, 0.046971708802240233, 0.05644874973222613, 0.014208589447662234, 0.055685988161712885, 0.06303664283560854, 0.04296783311292529, 0.026814365526661277, 0.020662755173231875, 0.04939292870195849, 0.026623766736260483, 0.02826916496269405, 0.09773954283446074, 0.03776301150875432, 0.044202522574258704, 0.02405148119266544, 0.05707495952291148, 0.015830637587766563, 0.06995282135903835, 0.015112913779116102, 0.05508023959451488, 0.010499421872996857, 0.009036735315541071, 0.05823019253356116, 0.025641147945342318, 0.02808251863877688, 0.0652006674291832, 0.05993334257176944, 0.07826709414699248, 0.004383267518798155, 0.01915393926070205, 0.028415318013035824, 0.027897812925013046, 0.02371847316888826, 0.021243996751893843, 0.044012671868715963, 0.059210607782006264, 0.018603494690198983, 0.0088053726857262, 0.04982759484222957, 0.006132972692804677, 0.039450402571154494, 0.04506271838077477, 0.037045145207749944, 0.07183705882302352, 0.10256180300244264, 0.11752150527068547, 0.04900991603998201, 0.0701712282108409, 0.015607068780809641, 0.010098975101884986, 0.06905193720012903, 0.0451008554414979, 0.04748331063560077, 0.037272257663841755, 0.016994387909237827, 0.015061016028214778, 0.038520819773631435, 0.04826868099293538, 0.05582089788679566, 0.023493129992857575, 0.018588222563266754, 0.039952905249914954, 0.04099087044596672, 0.0630657859146595, 0.01155556841487331, 0.013921213752057935, 0.05792588993374791, 0.02141958974035723, 0.04567522176408342, 0.014068673830479383, 0.02733773146090763, 0.04499449507732477, 0.030947154387831688, 0.054112940427980254, 0.0607447958152209, 0.030536335360791002, 0.02234157464200897, 0.027262448000588586, 0.016083093326804892, 0.06246720946260861, 0.031104411663753644, 0.051567304347242625, 0.029295020005000488, 0.026178695261478424, 0.03425816100622926, 0.030462924657123427, 0.012824324574986739, 0.034696674440056086, 0.04412145460290568, 0.017741475320820297, 0.07062670162745885, 0.02649869067993547, 0.07213699165731668, 0.050192707750414095, 0.06055058552218335, 0.02774347334967128, 0.029962603468447924, 0.02504176912563188, 0.014728148800453969, 0.029639240819960833, 0.02148330587494586, 0.05579611100256443, 0.06265594397804566, 0.008210727495939603, 0.039818901369082074, 0.02721108459601445, 0.0299171823342996, 0.02610884008130857, 0.04283322533592582, 0.01315172535500356, 0.022072421852499247, 0.017119526730052063, 0.10722352178501231, 0.017914265959656665, 0.009618053229392638, 0.042345643642225435, 0.021619862743786404, 0.0375668775689389, 0.01256307162943163, 0.026125016356153146, 0.06427110159503562, 0.039823786821216345, 0.007048730763407158, 0.03418101157460894, 0.019318782558132495, 0.014143698599322565, 0.03193452801289303, 0.01098526906155582, 0.06874258629977703, 0.033516800430204184, 0.0207118403964809, 0.007094944511274142, 0.019690470470647727, 0.02226840821094811, 0.059530530257948806, 0.015682175822023834, 0.026250379093523537, 0.030331505994711603, 0.022012078036953295, 0.11318683358175413, 0.027191632693367343, 0.041896361857652664, 0.008919935690106025, 0.04794664827308484, 0.02775959873438946, 0.02002334957277136, 0.030163178419960395, 0.0349866395949253, 0.05856032696153436, 0.09773019262190376, 0.06825347790228468, 0.03728014224075845, 0.04295473738706537, 0.03437675874946373, 0.039798586030623744, 0.023982289280476313, 0.00987197969308389, 0.04287989836718355, 0.05271177579249654, 0.022687987125079547, 0.06772536731192044, 0.02982024342886039, 0.04446144814469984, 0.04979126947000623, 0.04271059370200549, 0.036563687292592864, 0.03982536780780979, 0.027391546073236635, 0.036376130035413165, 0.029138492154223577, 0.01603079354390502, 0.025188799182485257, 0.013150482787750661, 0.03530976814883096, 0.07269208758537259, 0.022529055563999072, 0.06442510868821825, 0.04572399825389896, 0.02252292669644313, 0.04450815171003342, 0.043739693838038614, 0.01574837539478072, 0.028019065436507975, 0.04673245056931462, 0.03645890452233808, 0.01685686582433326, 0.03346159142841186, 0.08420908637344837, 0.025752222431557517, 0.01783006146017994, 0.019120490876957774, 0.017003241094893644, 0.03184615561206426, 0.03412714607215353, 0.223287024934377, 0.15299858658441476, 0.15690538766128675, 0.11243152232574564, 0.2036446575075388, 0.08626860978880099, 0.1314365350242172, 0.15936078876256943, 0.11282851280910627, 0.1743261907249689, 0.19002637825906277, 0.07468797798667635, 0.05799184353756053, 0.08615905352469001, 0.09411477483808994, 0.13171617287610257, 0.14042985173208372, 0.1414281531636204, 0.08571665547788143, 0.10443718558443443, 0.15916376933455467, 0.0831477286826287, 0.13362052211804049, 0.1511669491550752, 0.07780505929674421, 0.261474609375, 0.1747561376541853, 0.22280687998448098, 0.1512218697794846, 0.1264004481158086, 0.08972484325723988, 0.08254116587340832, 0.14250559891973222, 0.10260849299707583, 0.17760252420391354, 0.15042840449937753, 0.13698891922831535, 0.10113486421427556, 0.09415974813912596, 0.15831623838416167, 0.1578508447855711, 0.2149268492524113, 0.1073599276798112, 0.11893781141511031, 0.12970027247709887, 0.1402349221919264, 0.09909642966730253, 0.10504566186240741, 0.17998758836516313, 0.0916672447430236, 0.12722778586404665, 0.09881058321999651, 0.08559850896043436, 0.0994915473940117, 0.12794950285128184, 0.11290277846689735, 0.11460966723305838, 0.11556087833430086, 0.05662452083613191, 0.07766640745103359, 0.10097526599253927, 0.13614765794149467, 0.09144048512514148, 0.09740317945501634, 0.10002647047596318, 0.11406808772257396, 0.1594276108912059, 0.28933197313121384, 0.1495172269642353, 0.12879499819661888, 0.09929139313421079, 0.1163657158613205, 0.13993408690605844, 0.23594842052885465, 0.21467177436820098, 0.08815860801509448, 0.1439713974084173, 0.0904569486156106, 0.1366537364998034, 0.20618479406195028, 0.13432887196540833, 0.10177214430379015, 0.09217900263943843, 0.1270368325390986, 0.12374585627445153, 0.10727986054761068, 0.1382586889501129, 0.11136161509369101, 0.10888094534831387, 0.12490643614104815, 0.08884063748908894, 0.08724283679787602, 0.15565142780542374, 0.09276161316250052, 0.15887080505490303, 0.19492626961852821, 0.06671437049018485, 0.17071785006139958, 0.10960638070745127, 0.1278204454907349, 0.07210743467190436, 0.09323803295514413, 0.13422050992293016, 0.1874460724315473, 0.16629838863653795, 0.11982196968580995, 0.08713959090943847, 0.11737156260226454, 0.09025247887309108, 0.14515402966312, 0.24303227184074266, 0.15851795327450546, 0.12362541630864143, 0.16793823135750635, 0.12861380220523902, 0.16511707273977144, 0.20190808283431189, 0.14787758780377253, 0.14951531349548272, 0.13307569921016693, 0.1197331358811685, 0.1555556050900902, 0.1375016745712076, 0.1484904270619154, 0.09159473649093083, 0.11266040575823613, 0.1436089240014553, 0.10067073269081966, 0.1947141731423991, 0.17446527683309146, 0.17312560443367275, 0.2329948932996818, 0.15328997666282312, 0.1527788226625749, 0.09939109706985098, 0.13884240548525537, 0.1382467738751854, 0.1232840996235609, 0.09217219693320138, 0.11091619078069925, 0.12030729864324842, 0.10851414288793292, 0.14633769329105104, 0.20462900825909205, 0.1351319860134806, 0.16438470275274344, 0.13843221749578202, 0.12021980833794389, 0.10897986896868263, 0.09812250121363572, 0.06512860022485256, 0.13739998931331293, 0.11275715806654521, 0.12394109794071742, 0.1664094648190907, 0.1786693033895322, 0.1285475364753178, 0.11794241411345345, 0.18392379714974336, 0.24207320330398424, 0.12296627382082598, 0.12599121007536138, 0.19328255924795354, 0.17512850410171918, 0.14075208801243985, 0.09989801022623267, 0.08192186017653771, 0.10694526135921478, 0.07058363500982523, 0.15013848005660943, 0.09703177652720894, 0.09284128674439021, 0.1817578590874161, 0.13992033978658064, 0.04957056577716555, 0.14792500383087567], [0.034871716118816815, 0.015382236202380486, 0.017401934701151082, 0.026085481513291597, 0.018342833766447644, 0.015059431648946233, 0.029808833862521818, 0.07531989086419344, 0.014318459534219332, 0.005779614555649459, 0.042823844589293, 0.006597533813744251, 0.012352641804942062, 0.01989187832389559, 0.04416335414030722, 0.027875579028789486, 0.02251179363312466, 0.03763265475364668, 0.06335830914654902, 0.03047768279377903, 0.0741592635001455, 0.03407694465879883, 0.030480295153600828, 0.03840529240135636, 0.048783953700746806, 0.0329457317878093, 0.043779561163059304, 0.05611047288402915, 0.02225997232432876, 0.019776635936328342, 0.05395304025816066, 0.028049367114103267, 0.0240016495808959, 0.028884150087833405, 0.042607252818665335, 0.03637884417548776, 0.03719012099983437, 0.0516139570224498, 0.030144739230828624, 0.031600492008562596, 0.03234938432329467, 0.07240166781204087, 0.05918910500726529, 0.03231352035488401, 0.023670091925721084, 0.06260274683258363, 0.010953600984066725, 0.04163673400346722, 0.043224509339779615, 0.009740945251126374, 0.11408841663173266, 0.03045901968809111, 0.04624584935871618, 0.02972710771220071, 0.02993270382285118, 0.033117099199444056, 0.01641787402331829, 0.007714697193088276, 0.06490715353616647, 0.056180799646036964, 0.044793570680277686, 0.05121429989646588, 0.07409089431166649, 0.09241179443363633, 0.024777232070586512, 0.05375441948750189, 0.08183869892465216, 0.04454671964049339, 0.02786537555844656, 0.031938728144658465, 0.03537032400657024, 0.026930054051003287, 0.07601219335837023, 0.016751884582585523, 0.06272193150860922, 0.054548115469515324, 0.053754640011382956, 0.04324517412377255, 0.029643692009683167, 0.07779866071151835, 0.02692614568929587, 0.01687540000836764, 0.005989633442368358, 0.02682689467578062, 0.036283357334988456, 0.07395193033984729, 0.021097210967647176, 0.039097367586301904, 0.05908614410353558, 0.045264928601682186, 0.04597713592063103, 0.0689385404278125, 0.027414909730266248, 0.0485126109394644, 0.04309648335246103, 0.027198796326826726, 0.0331661742446678, 0.0272964290343225, 0.07215905083077294, 0.011972964142582245, 0.04152395809069276, 0.016627152882782475, 0.04025101282500795, 0.04956885586891856, 0.014218079608066805, 0.028369099600240588, 0.038203614830438576, 0.05870866828731128, 0.05562232800626329, 0.039332731028220484, 0.051161984846528084, 0.07199220585503749, 0.034977832210383246, 0.03489929178197469, 0.02850230111341391, 0.05085908342152834, 0.031484052006687434, 0.03141310777781265, 0.03669351479038596, 0.0868754575827292, 0.047281697525509765, 0.03811940863462431, 0.040790275138403685, 0.01701640128158033, 0.05830185261688062, 0.010209536445992333, 0.0489601692450898, 0.011902763757721653, 0.028332178813538382, 0.019210196599098187, 0.03522349920656, 0.050654114955770116, 0.1480503428195204, 0.04772112358893667, 0.06577398880784001, 0.04867869595597897, 0.05005244438403419, 0.042919575702399015, 0.04007854279396789, 0.011491231420742614, 0.05032632825896144, 0.03929848875850439, 0.0228079198859632, 0.054247185188744745, 0.01712876498433096, 0.012474923145159014, 0.029508636399571384, 0.021443331680659736, 0.01387917681131512, 0.036082456686667035, 0.013489779982981938, 0.020426479101713215, 0.02919687669990318, 0.045140787227345366, 0.015735556171940904, 0.03114068614585059, 0.01969447891627039, 0.07531294945095267, 0.028020229124064957, 0.034954446500965526, 0.019616435514762998, 0.036951721113707335, 0.04224567847060306, 0.010037217388993927, 0.007465618013936494, 0.03072860843635031, 0.005667537533944207, 0.038462771102786064, 0.025846062128299048, 0.047696930422846756, 0.017603537633216808, 0.0634642963164619, 0.03976887637483222, 0.016381053320531334, 0.026454127892585735, 0.010409639815666845, 0.028710648683565, 0.03889197503615703, 0.03139580513483711, 0.032625911092119556, 0.007342586044355163, 0.017278497306896106, 0.022525891894474626, 0.06376120288457189, 0.027559400369812335, 0.0804451983422041, 0.026656719789441143, 0.04216772836766072, 0.03153423984934177, 0.02374580455943942, 0.08980436756142549, 0.07473555686218397, 0.01138257930454399, 0.03568639579628195, 0.030578648804553916, 0.04367766895198396, 0.05918005335011652, 0.039505218022636006, 0.019793292274698615, 0.058277174298252375, 0.026866241225174496, 0.0060821945246841225, 0.013580165088309773, 0.023944135256377713, 0.0760202407836914, 0.06934412116450922, 0.051482935303023884, 0.035112864071769376, 0.03232291806489229, 0.007630982086993754, 0.0377736136184207, 0.049359174977455816, 0.014764621754043868, 0.06215678647692714, 0.04024779996169465, 0.0864794102630445, 0.14161502170775617, 0.06490832061639853, 0.023188306617417505, 0.038713846023061445, 0.009194476895832589, 0.03816581703722477, 0.06175444235226937, 0.02863302088475653, 0.04567488588924919, 0.0681429241916963, 0.018415255505325537, 0.04637236560561827, 0.04164391290396452, 0.022281497151457837, 0.04824900347739458, 0.025373827200382948, 0.07713799830526114, 0.015527415554970503, 0.08131590126348393, 0.03880823363683053, 0.023783839839909757, 0.007185489920500133, 0.007520430072742913, 0.09114103405071156, 0.033084695759628496, 0.044305941489126, 0.04704705672338605, 0.021718214698401943, 0.03617355340559568, 0.08006473018654756, 0.031338679271617105, 0.0060630678947615835, 0.013369916771937693, 0.0338442682155541, 0.04661698087251612, 0.058337306071605, 0.030184945823358636, 0.04747843536149178, 0.014683301028396403, 0.023699827026575804, 0.007450953175845955, 0.010183143130104457, 0.03676625035170998, 0.05012942757457495, 0.04562561746154513, 0.06033807513969285, 0.020446855508323227, 0.048349674325436354, 0.013903064636646636, 0.03305492842836039, 0.021052361499252062, 0.020965714273708205, 0.020285661032955562, 0.018000324556071843, 0.006981900577167315, 0.0338572723391865, 0.014313809873004044, 0.06539534591138363, 0.052457691569413455, 0.04959037899971008, 0.03992675790297134, 0.04112019922052111, 0.05148676563320415, 0.024129724762003337, 0.04912289212058697, 0.03745797609112092, 0.012243073666468263, 0.018418446316250732, 0.018881904393700615, 0.04824837583250233, 0.0437151037289628, 0.06243181707603591, 0.04144830143611346, 0.04827040786455784, 0.04820079356431961, 0.007597908593847283, 0.0342085431329906, 0.04084540271599378, 0.03251808848498123, 0.06521132721432618, 0.0633401447640998, 0.04739591532519885, 0.009848787366146488, 0.03584772767499089, 0.019428959681785533, 0.03495508771655815, 0.021122398187539408, 0.015667738293164542, 0.035753876103886535, 0.05167333562193172, 0.05757541981126581, 0.03849703033587762, 0.06053079265568938, 0.019557116287095205, 0.07184939458966255, 0.018772522852356945, 0.028849602477358918, 0.0645078153216413, 0.03579261027542608, 0.017038126276539903, 0.03669187952099102, 0.03510486414389951, 0.033319645295185704, 0.03367234440520406, 0.059374324711305757, 0.026149723512519683, 0.05341714687113251, 0.024980410900233046, 0.009725187123487038, 0.04474643285253218, 0.03449493919366172, 0.035348332686615844, 0.02666906573410545, 0.07838302864027874, 0.014839589695579239, 0.037269438350839276, 0.022335778256612163, 0.04822545831224748, 0.023155462129839828, 0.048677881713956594, 0.04517624746741993, 0.03852425655350089, 0.04114524055538433, 0.01200713007710874, 0.041316875988351445, 0.06081566879791873, 0.02046322007663548, 0.04881338176450559, 0.035774829265262396, 0.03997483550171767, 0.009038924439144986, 0.11001273497406926, 0.08491037267127208, 0.018076376457299505, 0.03216288218806897, 0.014625686619962965, 0.08043489818062101, 0.11868425644934177, 0.11301551706024579, 0.2038288526237011, 0.0628199933895043, 0.12428730007793222, 0.13077428484601633, 0.1384361529988902, 0.12960116565227509, 0.15898386255971023, 0.12638904872749532, 0.06452089747680084, 0.06962217802980117, 0.07907030997531754, 0.20719107506530626, 0.16853470435099943, 0.09198098576494626, 0.1784364708832332, 0.12757298376943382, 0.12141573987901211, 0.15473028937620775, 0.16376401962978498, 0.06942163700503962, 0.11301215831190348, 0.11844560211258275, 0.11904545421046869, 0.11210555410278694, 0.13996725369776997, 0.14109658024140767, 0.14962092068578514, 0.11694092356732913, 0.11981903841452939, 0.08644880154835326, 0.10732807724603585, 0.12171030550130776, 0.11755297572485038, 0.06142493217651333, 0.18613187223672867, 0.11300534582031624, 0.18187994110797132, 0.2517670531358038, 0.23349087525691303, 0.15994986572435924, 0.2631292034472738, 0.14387541184467928, 0.11443087325564452, 0.1489437970199755, 0.2286750679569585, 0.14443457898284706, 0.13876669454787458, 0.2445034986095769, 0.13340827636420727, 0.09893907739647798, 0.08599947565900427, 0.07402288474674736, 0.0916518352127501, 0.1193566575114216, 0.0817785875073501, 0.28513433837464874, 0.1130184754729271, 0.0875333651368107, 0.13516858619238648, 0.15958129907292978, 0.1917055081576109, 0.12124250988875117, 0.1600799680288349, 0.19663667998143605, 0.0666860823652574, 0.16972291416355542, 0.19933525446270192, 0.1132367601884263, 0.08072794388447489, 0.20582466838615282, 0.0957464004999825, 0.15385018874491962, 0.20027605683675834, 0.1856056276176657, 0.1659889088145324, 0.13958827831915446, 0.15397632840488637, 0.1344555951654911, 0.1270767439688955, 0.1133795782391514, 0.11019967815705708, 0.2203344205128295, 0.151365352794528, 0.0602868457457849, 0.17856908376727784, 0.15943161424781593, 0.14868788075234207, 0.08716082905552217, 0.28287419251033236, 0.16866271676761763, 0.15955976237143787, 0.12125295932803835, 0.10993091722152062, 0.13584891254348413, 0.09196269924619369, 0.15684198534914426, 0.10364861932716199, 0.22120783078883374, 0.16388192187462533, 0.1158426467861448, 0.16512066897537026, 0.07716287339904479, 0.09923812134989671, 0.1454719640314579, 0.12874018613781246, 0.12168036853628499, 0.20169936546257564, 0.15712451376020908, 0.15163937237645897, 0.10656840300985745, 0.1125655397772789, 0.11088995183152811, 0.15049376099237374, 0.19000611720340593, 0.12738215258078917, 0.13328323593097074, 0.25742158400160925, 0.10360205825418234, 0.12355868917490755, 0.08452134818903037, 0.09774579214198248, 0.0830769914069346, 0.17879977210291795, 0.08658095302858523, 0.08052515012345143, 0.1752113260860954, 0.14981848294181482, 0.16365640397582734, 0.12563663481601647, 0.2168903938893761, 0.12568660213478974, 0.20327994493501528, 0.11774835309812001, 0.14513584492462023, 0.14444221928715706, 0.06691688605185066, 0.07510084618947335, 0.19453946394579752, 0.13713260580386433, 0.13888102769851685, 0.19780053038682255, 0.11838836089840957, 0.1063334738303508, 0.16105061237301144, 0.11665834087346282, 0.058027188426681926, 0.09225929368819509, 0.13181969017854758, 0.07933517611984696, 0.1443254705518484, 0.18451284697013243, 0.08624063378998212, 0.15691281083439076, 0.1537853886506387, 0.16711349918373994, 0.11220595692949635, 0.25578560893024715, 0.06064046427075352, 0.08873346288289342, 0.1292780608470951, 0.11080989827002798, 0.107322879667793, 0.1101256160597716, 0.10850230245185749, 0.12629235748733791, 0.08213894388505391, 0.154890722196017, 0.10111062015805926, 0.21385811588593892, 0.11666420341602393, 0.0519482576554375, 0.11209126415529422, 0.0885540039411613], [0.025204943226916448, 0.03865180417363133, 0.013154939066485634, 0.06332465380962406, 0.015931863138186078, 0.049335867299565246, 0.04469349015770214, 0.01585369081502514, 0.03356072539463639, 0.01944857952184975, 0.05419698716806514, 0.03774300490372947, 0.04488584465746369, 0.10423880908638239, 0.030318142247519324, 0.013015562884642609, 0.03410970772217427, 0.028889459624354328, 0.005709667773252087, 0.011906024966655033, 0.0743385392374226, 0.02838085182676358, 0.03774005327639835, 0.04362465840365205, 0.07892004839543786, 0.01561683289972799, 0.015510150231420994, 0.002080776192347652, 0.05392550191442881, 0.016830214665138295, 0.010926584264130464, 0.03789768035390547, 0.08035935687699489, 0.03149603832779186, 0.019699169289586798, 0.06847505351262433, 0.027590472184653794, 0.02936370810493827, 0.015314559119620492, 0.018280301675466553, 0.03370550101889031, 0.038694765618337054, 0.0329295181935387, 0.02426610860441412, 0.026309784834406207, 0.022831241134554148, 0.06866718070315463, 0.03914056312558906, 0.05325447827843683, 0.041179801736559184, 0.06132760989878859, 0.029158946592360735, 0.04390070001993861, 0.026266453588115315, 0.055232346789645295, 0.08981639120195593, 0.028466389647551944, 0.026396991851340448, 0.04127130896917411, 0.07602369452693633, 0.0072082267808062685, 0.06093278394213744, 0.020118152789239372, 0.03150695256356682, 0.02023002625043903, 0.0290481655725411, 0.029404620373887674, 0.04333786539999502, 0.021516789881778613, 0.04508612444624305, 0.03673779259302786, 0.0076845507303785, 0.049866546144975085, 0.03971228316160185, 0.028438944602385163, 0.027376714994066527, 0.05332220625132322, 0.0853236819218312, 0.05284852095480476, 0.023125323300649012, 0.053117716152753146, 0.06859120513711657, 0.02715952950529754, 0.05031674395182303, 0.08533047405736786, 0.01730473286339215, 0.021443670948169062, 0.010974857789863433, 0.03763127393488373, 0.031228508933314254, 0.06407601599182401, 0.05055407514529569, 0.048313009685703685, 0.021118101364533817, 0.08752012691859688, 0.027910370911870683, 0.06867439353040286, 0.015486710239201784, 0.02844312268176249, 0.021030214116243378, 0.04327002546883055, 0.013662162652638341, 0.05918341888380902, 0.04760781841884766, 0.0160196333391858, 0.05567287207980241, 0.025217043202636496, 0.008246119882512306, 0.050737815642995496, 0.03704996280638235, 0.02020748022810689, 0.042477981719587526, 0.039480441316430054, 0.013349100165734333, 0.014737848458545548, 0.061308346289609156, 0.0593794205092958, 0.036475535415645154, 0.04503093580050128, 0.019066762777843645, 0.0660744101873466, 0.03339134609060628, 0.038045594202620645, 0.009461009692001556, 0.03033794868471367, 0.022596462929089154, 0.01581955371823694, 0.024534995068929026, 0.07108066869633538, 0.017957558190183978, 0.0406544188569699, 0.06641405089093105, 0.03734421969524451, 0.021621062054431865, 0.03001509154481547, 0.06361163341041122, 0.018892202858946154, 0.007172741095668503, 0.014355246310255356, 0.060438294761947224, 0.04028941112171326, 0.041340617928653955, 0.026237619242497852, 0.031150779354252985, 0.026629313760037934, 0.02224657804306064, 0.030296673399529288, 0.05227070088897433, 0.028831970744899342, 0.00542237053325932, 0.036221902418349466, 0.05424272721367223, 0.05618753071342196, 0.01627164294144937, 0.014624589089570301, 0.006138180873157191, 0.009605187357270291, 0.04960632796532341, 0.06932782275336129, 0.04347198802445616, 0.06444796174764633, 0.01965191780722567, 0.04747673563127007, 0.06705839452998978, 0.05951251515320369, 0.013330692358847176, 0.05588259029069117, 0.03527911872203861, 0.06624304649553128, 0.03841849330014416, 0.014921989291906357, 0.02167019816780729, 0.00697104910588158, 0.0306497457038079, 0.04315430471407516, 0.033037194915648015, 0.057116519792803695, 0.04405051376670599, 0.03878537039937718, 0.02982082696897643, 0.07399163142378841, 0.033972484192677906, 0.019987612829676697, 0.05554559926635452, 0.024149790738842318, 0.039387994312814305, 0.05825827031263283, 0.03746311938656228, 0.04096623283943959, 0.01603227444658322, 0.027584641872506057, 0.014157220105906683, 0.05141627263011677, 0.037365722469985485, 0.010735913379383939, 0.06212494961385216, 0.03413055571062224, 0.014502571529841848, 0.017697796325332353, 0.03195178655109235, 0.08638978935778141, 0.03724914676110659, 0.056311471919928274, 0.04094723385891744, 0.03424158439572368, 0.03973433215703283, 0.02547490008042327, 0.0646536053557481, 0.02576939615287951, 0.06383053559277739, 0.023471764621457884, 0.06533997066851173, 0.022594429020370756, 0.06200442143848964, 0.03520684456452727, 0.0312673414924315, 0.055266768871141334, 0.020551880854847174, 0.03230101495449032, 0.010369386573854302, 0.017316049131165658, 0.021974690757425766, 0.062430317513644695, 0.015297393879986234, 0.038001614955386946, 0.050045648855822425, 0.0484741515746074, 0.027766258555597494, 0.04082469043454953, 0.03243883898747819, 0.03593958096046533, 0.062194133044353554, 0.03773333917238882, 0.04896630998700857, 0.007661299031626965, 0.043637608244482956, 0.030717192084661553, 0.0150807851459831, 0.03573199674221022, 0.03501462237909436, 0.03344244995553579, 0.03270861094019242, 0.011800530582799442, 0.0550250068439969, 0.03130915621295571, 0.02449297678789922, 0.08688834296273333, 0.03075418242120317, 0.030357765299933295, 0.07215725949832372, 0.004499360619645033, 0.04918372278500881, 0.03341635689139366, 0.013668480661830731, 0.023070679179259708, 0.040023920724966695, 0.03928810717271907, 0.056204168392079215, 0.0528364023193717, 0.04300831790481295, 0.05703101759510381, 0.048886453200663836, 0.050253229681402445, 0.036799386609345675, 0.04211606810401593, 0.05625334521755576, 0.008138800239456552, 0.050213569309562445, 0.025955216360411475, 0.035513406685952625, 0.07419378057654415, 0.03756515069731644, 0.0543508789102946, 0.046053823948438675, 0.04976274385782225, 0.03152075057317104, 0.02608107103567038, 0.011507404302912099, 0.06264464636998517, 0.08119426707604102, 0.014029754758147257, 0.027277433446475437, 0.02429561809237514, 0.018604773728709136, 0.03151950885408691, 0.02497080114803144, 0.015529669987569963, 0.054494674051446576, 0.01097524625116161, 0.005368008427987141, 0.031143206903444867, 0.02025369185555194, 0.023297454064179744, 0.05043644770713789, 0.032189351839146445, 0.016378132227276052, 0.04194696360666837, 0.00922964621401791, 0.038305052423051426, 0.04184718503217612, 0.03049708889531238, 0.008116116813783134, 0.014442573767155409, 0.04346582692648683, 0.014229692734910973, 0.02388800514329757, 0.06868427978562457, 0.03652195738894599, 0.02552786991665406, 0.018448166150067533, 0.03844786708110145, 0.034757868120712895, 0.019649763458541462, 0.04044428334704467, 0.010043103680280703, 0.012830331306239324, 0.0299492600773062, 0.06586864444294147, 0.015609329998759287, 0.01835057245833533, 0.01078122340342296, 0.021566294100401655, 0.034561316881861, 0.05507354245388082, 0.04354749879400645, 0.05138928050707493, 0.020862656678738337, 0.05951701384037733, 0.03559979097917676, 0.0133796283043921, 0.0685093127457159, 0.033284361474215984, 0.016376680162336146, 0.025360261589022617, 0.024766612997544662, 0.01725615654140711, 0.014157464378513396, 0.0337755394035152, 0.04735302173399499, 0.09020762770835843, 0.02943279654053705, 0.03147414878809026, 0.04011995378615601, 0.04164559906348586, 0.03759001561307481, 0.0942583732040865, 0.05621541850268841, 0.036343163411532126, 0.04552230032693062, 0.027888009790331125, 0.09992531447538308, 0.032297951368881125, 0.13608872038977488, 0.2209588491490909, 0.17581113747188024, 0.17433069619749272, 0.13427548483014107, 0.2080228097204651, 0.1061863335115569, 0.13324451872280665, 0.14825580322316714, 0.11889469730002539, 0.17053502558597497, 0.2667037530669144, 0.10336209434483733, 0.16197591700724193, 0.14054278710058757, 0.09653927545462336, 0.1069595580920577, 0.22359071006732328, 0.12337483332625457, 0.09343678943280663, 0.22258094139397144, 0.11296338521476303, 0.10840823035687208, 0.07784649064498288, 0.2558439629418509, 0.1246481721422502, 0.11902870796620846, 0.08729222736188344, 0.1094440615602902, 0.08136622820581708, 0.08307630608656577, 0.09380441292056016, 0.14930709823966026, 0.16438242287508079, 0.08107066513704402, 0.19201637219105447, 0.11537107851888452, 0.1687793162252222, 0.06714004264878375, 0.12288369610905647, 0.18836555523531778, 0.08693853419806276, 0.14677697686212404, 0.07066748158207961, 0.13378581324858324, 0.1886350286326238, 0.26007389596530367, 0.11186869109847716, 0.12022178966019835, 0.09795142217938389, 0.15418793633580208, 0.07811424734869174, 0.14300300580050263, 0.12390782258340291, 0.0994915473940117, 0.19235289841890335, 0.13963374016540392, 0.10621497447469405, 0.12928624397941998, 0.1768553757241794, 0.08868025216673102, 0.14701679827911512, 0.07835454374019589, 0.13833781970398767, 0.17264533734747342, 0.1448175034352711, 0.1601298132113048, 0.10734848757939679, 0.17558376038713114, 0.08912103530019522, 0.19649120207343782, 0.10612677849297013, 0.15104855836502143, 0.18303843108671053, 0.07764485717884131, 0.07041552117360489, 0.14436650834977627, 0.14943329218242848, 0.1279238270861762, 0.14967470137136324, 0.2013524712196418, 0.18327682758016245, 0.14131395571998187, 0.11604713009936468, 0.16386759121503147, 0.13405660300382546, 0.15974713303148746, 0.11288349450166736, 0.1790209338068962, 0.1373702966208969, 0.17623429905091012, 0.11021163394408566, 0.1312487165310553, 0.09172681333231074, 0.18987910901861532, 0.22016602169190133, 0.16301343776285648, 0.10678265722734587, 0.1665167547762394, 0.1287340521812439, 0.1378963105380535, 0.12074722003723894, 0.08852324594876596, 0.09949107241949864, 0.10749912913888693, 0.19473115008856567, 0.1007281503240977, 0.0724119001201221, 0.16482258854167803, 0.14806999319366046, 0.14763868919440679, 0.1302669577832733, 0.17338542906301363, 0.09672914312354156, 0.19376354558127268, 0.11326234774397952, 0.14303389271455152, 0.09659980756363698, 0.0900106964898961, 0.0626490975597075, 0.12755165062844753, 0.09984019225729363, 0.0863073066409145, 0.07751829004181282, 0.20978801857147897, 0.07348603462534291, 0.0933394128722804, 0.12227737078709261, 0.1947237676275628, 0.1373503069792475, 0.1294385072376047, 0.12590488685028894, 0.10084401696388211, 0.1288365245397602, 0.1459159566355603, 0.16657661513558455, 0.07920741476118565, 0.11451315241200583, 0.07757206394204072, 0.13695136910038336, 0.12964265128331526, 0.13774161812450203, 0.1046100559511355, 0.08048684682164874, 0.1201712116599083, 0.10652596064444099, 0.12840402631887368, 0.11914190117801939, 0.15074503608047962, 0.11424655600317887, 0.09802559284227234, 0.11224823644650833, 0.1672537795134953, 0.1759325409574168, 0.1670866563384022, 0.09478975433324065, 0.1391658088458436, 0.08887182974389621, 0.1720099300146103, 0.09177338797599077, 0.1447813103773764, 0.14458821288176946, 0.10114550364336797, 0.15087676686900003, 0.16291296029729502, 0.08891970717481204, 0.1752089647842305, 0.13124024841402257, 0.11435145751706191, 0.17178610845335893, 0.11864197014697961, 0.12941948111568177, 0.11046697345695325, 0.10429986366736037, 0.16162799139107975, 0.08301139742668186], [0.040953927606876404, 0.0065001500437834436, 0.013373982893036944, 0.012325968593358994, 0.0040534223163766515, 0.05710709494139467, 0.0211816665250808, 0.02229213827688779, 0.06128903518297842, 0.03465860862550991, 0.025990985333919525, 0.02750451027947877, 0.04846633145851748, 0.052007324128810845, 0.0868412187056882, 0.004651164170354605, 0.004393063444045505, 0.06967456093324081, 0.024506544095597098, 0.02013226122861462, 0.044878499515886815, 0.038422829138913324, 0.03541137198252337, 0.04415692502100553, 0.021770911424287727, 0.0235943012604756, 0.0028255262628330714, 0.026710300307188715, 0.013878904549138886, 0.032269364688545465, 0.03404877867017474, 0.06144868090216603, 0.09440115732806069, 0.022622978381280388, 0.03716758006651487, 0.013511444757958608, 0.08423882656331573, 0.00350114654949201, 0.008338648310330297, 0.02044943394139409, 0.05099615428064551, 0.04290846808414374, 0.03024102674264993, 0.03351245780608483, 0.040745152559663565, 0.03543136501684785, 0.050592361483722925, 0.020453452565042034, 0.008443786463301097, 0.06380518552448068, 0.039327061868139675, 0.030283550532268624, 0.02895175592441644, 0.017544388039303676, 0.05676819384098053, 0.01408639716516648, 0.06337494682520628, 0.020645971609545604, 0.0230709081848285, 0.03126887837424874, 0.019141089503786395, 0.06210570636072329, 0.07696436797933918, 0.08349487398351942, 0.058327236611928256, 0.0519999179190823, 0.05940578159477029, 0.03450679320043751, 0.029841101595333645, 0.05070777689771993, 0.038029353466949294, 0.05498629302850791, 0.016421585609870296, 0.020761166499661546, 0.024724857648834586, 0.05366662384143897, 0.025650337005832365, 0.05179350417373436, 0.019733922156904424, 0.04632776549884251, 0.013271759896140014, 0.02847029800925936, 0.006824225578124502, 0.016429519380575845, 0.03273931125711117, 0.0442385663544493, 0.06514426759843316, 0.005677819459898663, 0.05436636647209525, 0.021083144936710596, 0.04955471859180501, 0.04535301601780312, 0.016252375939594846, 0.0050917195705031705, 0.05246245149256928, 0.03113447076507977, 0.033294461467968564, 0.008837810052292687, 0.02748852569077696, 0.028628009903643812, 0.08785464468279056, 0.015100925761674131, 0.06172327045351267, 0.020167003917906965, 0.015081979367615921, 0.04608630541978138, 0.0431460503355733, 0.06444979379219667, 0.034014390515429635, 0.039735824934073856, 0.050011732282915285, 0.018182112569255487, 0.011007892267246331, 0.026630155143461058, 0.010795408177987804, 0.029129403177648783, 0.05205794623387711, 0.04560928512364626, 0.06539495236107282, 0.09469602150576455, 0.03515900784571256, 0.042279255776000876, 0.018967250528346215, 0.059727278271956105, 0.052575478463300636, 0.024414823124451295, 0.024473726749420166, 0.047975696357233186, 0.030271004419773817, 0.036936776379921606, 0.0231738758739084, 0.018077584249632697, 0.005487935251689383, 0.03776876548571246, 0.029042655868189673, 0.07352151522146803, 0.015787983180156777, 0.04000125765534384, 0.00779149548283645, 0.011897884242768799, 0.02604359554659043, 0.02580373002482312, 0.027771980302142243, 0.027257241940658008, 0.011143560255212443, 0.013292479811103215, 0.031111838229532753, 0.043565228914043734, 0.01346708383477692, 0.034043740547661266, 0.05334126290732196, 0.0521444051659533, 0.052246483974158764, 0.05711166148207017, 0.08266886616391794, 0.05729466237659965, 0.051729633672428985, 0.03414530027657747, 0.06769919621625117, 0.06750523019582033, 0.02921835911859359, 0.03598664414935878, 0.039392520141388686, 0.03780517567481313, 0.051070640462317636, 0.03809655557519623, 0.07750402045037065, 0.06643720929111753, 0.04960275887112532, 0.04155766431774412, 0.04483077136267509, 0.071451861278287, 0.0065169022252251, 0.014449269211451923, 0.01156699494458735, 0.02327933717918183, 0.0379057006378259, 0.02580507691683514, 0.010260957526043057, 0.03659858774127705, 0.03536775235884956, 0.0188093181100807, 0.03756982919627002, 0.04585432108225567, 0.025008576888857142, 0.017431294911407998, 0.028280808623614054, 0.01825761146444295, 0.026036535389721394, 0.056003993776227744, 0.018543999043426344, 0.007846735866873391, 0.00961368770471641, 0.11419459379145078, 0.020569938368030956, 0.039823539155934534, 0.015571637378473367, 0.0067321789101697505, 0.011914834047534635, 0.0533790471298354, 0.012735015795832234, 0.06949528519596372, 0.029679267600710903, 0.030758257023990154, 0.018686481219317232, 0.07536758509065423, 0.08411086164414883, 0.03644036355295351, 0.07416088519884007, 0.047474408256156106, 0.0026116798024824156, 0.007343648799828121, 0.10367443079927138, 0.04469390406406351, 0.024533246144918457, 0.03908641942377601, 0.038559058614607365, 0.02509761255766664, 0.047580887363957505, 0.02521481760777533, 0.04976493213325739, 0.03317046597866075, 0.047842340477343114, 0.01162413607484528, 0.0318002018279263, 0.013689090314853405, 0.019034201578636254, 0.04948942995231066, 0.013984656776301563, 0.022162415952022587, 0.052688956659819396, 0.024131804471835494, 0.048717450483569076, 0.011841032338062567, 0.03187072536508952, 0.023550803773105145, 0.036245210096240044, 0.02719382436147758, 0.010616662546194025, 0.03245661321229168, 0.07830743983920131, 0.010078276391141117, 0.03555523497717721, 0.027920345376644815, 0.03216096871931638, 0.021568881015160253, 0.05063079031450408, 0.05248303145968488, 0.055733058135956526, 0.04736114040549312, 0.03127918192850692, 0.043657343435500345, 0.025125145812385848, 0.06591733611587967, 0.012306710921360977, 0.0439532152377069, 0.04647988287199821, 0.01693703473678657, 0.015602354658767581, 0.03381652291864157, 0.028151920896821787, 0.03515031920479877, 0.0412730222700962, 0.00814880947915039, 0.018090964960200445, 0.08341695102197783, 0.02591222438162991, 0.017350337201995508, 0.03514586462240134, 0.01780820415089173, 0.008774145655999226, 0.03428030499656286, 0.02792719518765807, 0.023855756070198755, 0.06023160620991673, 0.013924058510123618, 0.045734990521201065, 0.037046756728419235, 0.02150056271680764, 0.046307728359741826, 0.016240187754322375, 0.019136760450367416, 0.021644510528338805, 0.011886015817123865, 0.010035423512038375, 0.02273024458970342, 0.08752828290952103, 0.04704952659085393, 0.012285676335782876, 0.047082310010279925, 0.026553370424413254, 0.032830102635281425, 0.017017810938081572, 0.04129112219171865, 0.05448422800483448, 0.05017581901379994, 0.028378660158653344, 0.013330047750579459, 0.05165027221664786, 0.01778960380969303, 0.04280932733256902, 0.04197482764720917, 0.01076485459426684, 0.016904605851907815, 0.02302902052178979, 0.09139004961720534, 0.03912429524851697, 0.055911248217203786, 0.03507496449830277, 0.024062724517924444, 0.041924870506461175, 0.08629014649029289, 0.029475099806274687, 0.021519936587927595, 0.0560807259088116, 0.030770796351134777, 0.023302800920126692, 0.05457089049741626, 0.011986686665165638, 0.0616818866027253, 0.017802557043199028, 0.024249155406973193, 0.031236410473606417, 0.026433057683919157, 0.038490346765943935, 0.042641264386475086, 0.10429022847009556, 0.050150940527341197, 0.014745524385944009, 0.05264354231102126, 0.027910727142755474, 0.0373825331750725, 0.008984054704861981, 0.005836921078818185, 0.04590401020167129, 0.024427157194752778, 0.03354657793949757, 0.054594567976891994, 0.07220208352165562, 0.012796810828149319, 0.02212069453006344, 0.048466504484947236, 0.06784590227263314, 0.10232850230698075, 0.0444185986582722, 0.010861576368500079, 0.01931399210090084, 0.05221218742164118, 0.03350583869697792, 0.019429439745311226, 0.03355678989152823, 0.03629259219659226, 0.1034955961097564, 0.08408930458660636, 0.1157082018575498, 0.08359419793954917, 0.16013239164437565, 0.17956572957336903, 0.104006363345044, 0.08784935210964509, 0.115012187776821, 0.09309961181133986, 0.0955004044143217, 0.07716442724423749, 0.09797272139361926, 0.13462039775082044, 0.13319244794547558, 0.0586686957893627, 0.09910716409129755, 0.18307522125542164, 0.12403441007648196, 0.0775166004896164, 0.07762640781168427, 0.15235240411545548, 0.1168539896607399, 0.09833105573696749, 0.16845040316028254, 0.13171421869524888, 0.12440874427556992, 0.1256309486925602, 0.06505483668297529, 0.18208868562110833, 0.1654259961630617, 0.17782815066831453, 0.2112095087234463, 0.09702535080058233, 0.07527600321918726, 0.07632096750395638, 0.12248615601233073, 0.135735312210662, 0.0995778434776834, 0.1039396904941116, 0.12630606389471463, 0.16067425613956793, 0.11097864992916584, 0.10383093490132264, 0.17800687679222651, 0.13565880060195923, 0.1299519818276167, 0.06034336092748812, 0.04013369751295873, 0.1635058777672904, 0.09517432084040982, 0.15408538255308354, 0.1656058079430035, 0.09103842598519155, 0.1428686287254095, 0.09481621719896793, 0.10149747332824127, 0.06299667712301016, 0.12411333726985113, 0.13244456664792129, 0.11151315231940576, 0.13597066886723042, 0.12734614951269968, 0.23626920474427088, 0.12819729026939186, 0.1225638889840671, 0.15743973398847239, 0.08290638734719583, 0.12637739149587496, 0.11038989187883479, 0.11477604401963097, 0.15167005573000225, 0.10880685610962765, 0.11821240319737367, 0.12083545673106398, 0.096375490671822, 0.11983544539128031, 0.2284826354256698, 0.10696125442960433, 0.1198920759239367, 0.07391478054757629, 0.10833992223654475, 0.06329648782099996, 0.12921338288911752, 0.07756571285426617, 0.11911583186260291, 0.08867400285920926, 0.16705445306641714, 0.3016517806266035, 0.08219453625913177, 0.16649895001735004, 0.10644561531288282, 0.08546002674847841, 0.11004546071801867, 0.17718784431261675, 0.10758135401244674, 0.10415965119110686, 0.10201803860919816, 0.14759116460170063, 0.15549151067222866, 0.1766629567635911, 0.17862576858273574, 0.09585431470934834, 0.09112350749117987, 0.13240692152508668, 0.10320575309119054, 0.15911838891250746, 0.12255664223006793, 0.14838659763336182, 0.06235496619982379, 0.11243407361741577, 0.14419576179768356, 0.0984735277348331, 0.1639742162078619, 0.08348698940660272, 0.1265496579664094, 0.07987389899790287, 0.1721848834838186, 0.12436425951974732, 0.26359617124710766, 0.11186312032597405, 0.16298624207930906, 0.10209471985165562, 0.11062532317425523, 0.089957424705582, 0.08513918146491051, 0.09317938038813216, 0.13377264966922148, 0.23562117666006088, 0.16722806303628854, 0.1152887586504221, 0.11002632603049278, 0.11368378584406205, 0.11210742685943842, 0.08598521285291229, 0.18180348378207, 0.08999350919787373, 0.08005151910973446, 0.11866470107010432, 0.10398498949195657, 0.13559842455599988, 0.1811513030635459, 0.13148245827427932, 0.08789657136159283, 0.12401988942708288, 0.12243944566164698, 0.09486480030630316, 0.21312763222626277, 0.11698017003280775, 0.13955127101923737, 0.2167897400047098, 0.22865088496889385, 0.13637294513838633, 0.21401602455547877, 0.11540721729397774, 0.11454330650823456, 0.1279163360595703, 0.09480160834001643, 0.23574353009462357, 0.10090689001871006, 0.128669034955757, 0.08015388968799796, 0.15450615568884782, 0.16405470403177397, 0.08976106345653534, 0.1406747485910143, 0.20661837793886662, 0.17098413434411797, 0.20534149717007363, 0.11045126537127153, 0.15003379567393235, 0.15040975835706505, 0.12415674994034426, 0.0938971618722592, 0.06662945861795119, 0.12288237975112029], [0.05111031440485801, 0.04788073877404843, 0.020591917813622525, 0.02356426081886249, 0.02821945209455277, 0.0735934738601957, 0.03623747818970254, 0.01657426107807883, 0.028477439590330635, 0.05313955819500344, 0.038236747695399184, 0.056681178510189056, 0.037461596075445414, 0.030671184017722095, 0.1127247376633542, 0.015498713523681675, 0.02828372802053179, 0.08910855704120227, 0.008024209245507206, 0.07908851506986789, 0.054084241789366515, 0.02541651892741876, 0.028554080120686973, 0.02944400254637003, 0.02692506172960358, 0.042454819926725965, 0.047142845511968644, 0.05027603863605431, 0.0232973251425262, 0.06337468898189919, 0.02118277084082365, 0.06980296690016985, 0.036986913332449536, 0.11680086036877972, 0.03428932951231088, 0.008542914492344218, 0.061905701378626485, 0.010707417453107024, 0.015327780374458857, 0.03585709485092333, 0.02050808141939342, 0.013487846158178789, 0.04114000226504036, 0.07162372741316046, 0.05841780746621745, 0.012246049890693809, 0.02014520767677043, 0.03876586251759103, 0.0542432903977377, 0.05681645803685699, 0.044009197769420486, 0.05226761355463948, 0.0376060867149915, 0.04218619130551815, 0.013265214577716376, 0.018430727800088267, 0.014482588673542653, 0.024865295737981796, 0.015098684899775046, 0.0300085504672357, 0.0034119035034174366, 0.041027765787605724, 0.04821549402549863, 0.03691119900239365, 0.042519416460501294, 0.049159543189619265, 0.04629262077755161, 0.02504202357626387, 0.038015453677092276, 0.06257819065025874, 0.004051122082663434, 0.0020611741638276726, 0.03939167197261538, 0.021419655897521546, 0.035029519615428786, 0.04296758205496839, 0.04283653997949191, 0.037936173645513396, 0.04867154758955751, 0.0020070243127910154, 0.035258518398872445, 0.034414583684078286, 0.021874391407306706, 0.012028224034500974, 0.024077204455222403, 0.02036341605708003, 0.04057109136400478, 0.025078123335593512, 0.0356682958746595, 0.006155718458882932, 0.050972123962960074, 0.042931399175098965, 0.08929778688720294, 0.04862086441633957, 0.023572479574275867, 0.035961450144116364, 0.016816538791837435, 0.03572876691552145, 0.05160492232867649, 0.015187186222257358, 0.03555572691506573, 0.007023436250165105, 0.041886445068355115, 0.037908502987452915, 0.05928497522005013, 0.04986490069755486, 0.022736970568075776, 0.026856321043201854, 0.008829106144340975, 0.022603389075292007, 0.0034596795781648582, 0.01373472942837647, 0.01080129446927458, 0.03430360588910324, 0.05046773834952286, 0.015977063748453344, 0.04175104001270873, 0.042727054961557896, 0.057736789009400775, 0.04575863068125077, 0.05292339050876243, 0.06345891553376402, 0.07153528037347964, 0.03975511568465403, 0.013571544300897844, 0.09617444753114666, 0.019629521062597632, 0.04555831018037029, 0.03223823010921478, 0.05643819851268615, 0.055102366621473005, 0.032662114328039546, 0.04472206326733742, 0.07296050246804953, 0.06083338534725564, 0.051917957674179754, 0.012110532876769347, 0.02393220321807478, 0.011001775274053216, 0.036085764544882944, 0.012024835600251598, 0.05019564241436975, 0.02835648224156882, 0.021935727580317428, 0.05813591009271996, 0.018233442047078694, 0.026144751547170535, 0.01378757628013513, 0.011871648686272758, 0.01762495219840535, 0.03306819378797497, 0.06111906894615718, 0.050236245949885676, 0.050910709758422205, 0.048415190274161954, 0.0590148979265775, 0.03967307401554925, 0.04698064850111093, 0.03461992534409676, 0.06231102427201612, 0.008794418586018895, 0.03432445387755122, 0.05626487692019769, 0.018379844459039823, 0.04522376527477588, 0.04058203274118049, 0.020977648008348684, 0.0359064616662051, 0.029981636375721012, 0.025455780659935305, 0.008099481679632195, 0.01389361688468073, 0.07807512301951647, 0.08264147370521512, 0.05142813342224274, 0.10310443424220596, 0.034448534183736355, 0.019294438418000937, 0.022463342840118066, 0.048252257052809, 0.04593919563506331, 0.05408976845709341, 0.033341697683291774, 0.027403444184788635, 0.03768220816605857, 0.08106723174984966, 0.07881503153060164, 0.013578863997411515, 0.07495486616556134, 0.005313766338596386, 0.023499555719484175, 0.025301310466602445, 0.04837683268955775, 0.05967842375061341, 0.01731965724112732, 0.02365064002307398, 0.0059810376759352425, 0.0619706575359617, 0.026683879849900092, 0.02541393201266016, 0.07281095334993941, 0.05366772646084428, 0.045989471687270064, 0.04292775544204882, 0.041558678727597, 0.09047168639621564, 0.02769681388911392, 0.08729798812419176, 0.014173225898827826, 0.03064600358318005, 0.05621175102091261, 0.010345270591122764, 0.01902078863765512, 0.0403914051130414, 0.03155802250174539, 0.08318484454814877, 0.024708136849637543, 0.0323686988226005, 0.05311523949993508, 0.04178339256239789, 0.07268841671092169, 0.025357783239867007, 0.03058770385437778, 0.013913847406261733, 0.06863420390124832, 0.05305572519344943, 0.06758143646376473, 0.008990386284754744, 0.02889222126188023, 0.0798001354560256, 0.04010990807520492, 0.016626793259222592, 0.03818784567660519, 0.03654637447159205, 0.013096708039354001, 0.02387280765521739, 0.014488822714026486, 0.0339171632326075, 0.043044989329895804, 0.013836632665645863, 0.0019335661116721375, 0.08707565933998142, 0.06511470382767064, 0.023029358092961565, 0.04808529672612037, 0.03669278536524091, 0.029735172100897347, 0.007550055759825877, 0.023975851679486886, 0.006508688134739974, 0.06526456507188932, 0.030376194311039786, 0.02994676646111267, 0.009345927608332463, 0.05652484064921737, 0.09645187335887126, 0.04589048021339944, 0.01972456685533481, 0.040338750795594285, 0.027800651799355234, 0.06626817943262202, 0.0044629648494135055, 0.023674387052389126, 0.023106190309460675, 0.005308896153500038, 0.045415838182504685, 0.03261252020352653, 0.10846721540604319, 0.035290151701441834, 0.053097550091998916, 0.026730902326692427, 0.05665360963238137, 0.05340310458892158, 0.06065639627299138, 0.02180161513388157, 0.02293324191123247, 0.03894837825958218, 0.066279531323484, 0.0026049171408106175, 0.02865178237802216, 0.018776690753708993, 0.034827679196106534, 0.019671217039493576, 0.029551038052886724, 0.03614344002146806, 0.0356999257845538, 0.0327366344364626, 0.02887649621282305, 0.014315609687141009, 0.0680108405649662, 0.032412589860281775, 0.05857201133455549, 0.021039644056665044, 0.025493648002988527, 0.025539438938722014, 0.04438422407422747, 0.020030547132981674, 0.01799532544932195, 0.007621660712175071, 0.027834697293915918, 0.047155496797391346, 0.03735521874789681, 0.02808053731652243, 0.06865713159952845, 0.02835433298189725, 0.06821177514003855, 0.025531416958464042, 0.02518383230614875, 0.02645336284435221, 0.0648845447493451, 0.01539364576871906, 0.031144292559474707, 0.018201450817286968, 0.03368059878370591, 0.02959366701543331, 0.02483826968818903, 0.03936647457469787, 0.04646214596661074, 0.04453560523688793, 0.018377393251284957, 0.016037366851898174, 0.040822149320904694, 0.024461061893297092, 0.006870517357518631, 0.03281439794227481, 0.012106348860210605, 0.043880245581801446, 0.044691464730671475, 0.029523421677627733, 0.011764880352919655, 0.026711740497765795, 0.03339945458407913, 0.02829608414322138, 0.0607613113575748, 0.02575057528779975, 0.007666410096654934, 0.03698345958920462, 0.020134157733991742, 0.0402466193107622, 0.05385584011673927, 0.04676683533138462, 0.02247965651830392, 0.019745022989809513, 0.08604097486074481, 0.030828400581542934, 0.04110254713201097, 0.016759333200752735, 0.05185216013342142, 0.04691916983574629, 0.1227246882127864, 0.021049479421760355, 0.06216665916144848, 0.17995614505239896, 0.1493920643946954, 0.07194580084511212, 0.09747631195932627, 0.14370001054235867, 0.1680674787078585, 0.10067308720733438, 0.07015452946403197, 0.16646970515804632, 0.16328158123152597, 0.16203496312456472, 0.13024337190602506, 0.15959214206252778, 0.12697500442819937, 0.17040249412613256, 0.12206664495170116, 0.08616722308631454, 0.17265300479318413, 0.18288605926292284, 0.1714990609990699, 0.08802729113293545, 0.12739497689264162, 0.09326232450881175, 0.12782476097345352, 0.1141010509537799, 0.1375851072371006, 0.1781563851982355, 0.11893285810947418, 0.11235150269099645, 0.16357819602957793, 0.17025766761175223, 0.16487725132278033, 0.12471377290785313, 0.1300740638481719, 0.19250194542109966, 0.0706521263346076, 0.11288198815392596, 0.08023215191704886, 0.08719266591859715, 0.20282344014516898, 0.12332133762538433, 0.12728357501327991, 0.12018388669405665, 0.1565833142293351, 0.17924965439098223, 0.06390905566513538, 0.2321236271943365, 0.12160597395684038, 0.13503948811973843, 0.19646574343953813, 0.12254282725708825, 0.1137413934671453, 0.06761661850448165, 0.17056574965161936, 0.15178542025387287, 0.08097385176058326, 0.19991314916738442, 0.12655967314328465, 0.14325561081724508, 0.13090681630585874, 0.06623603722878865, 0.10705363018704311, 0.10315265094063111, 0.1941521018743515, 0.07774861196854285, 0.12006415240466595, 0.17359055019915104, 0.12629627941974572, 0.1367904341646603, 0.1336399960730757, 0.1370461197303874, 0.10687550795929772, 0.0912104956805706, 0.10579865931400231, 0.12589221181614058, 0.13634766292359146, 0.14531345825110162, 0.07689126940178019, 0.1318577831344945, 0.17133246708129132, 0.08991091113005366, 0.08926776171262775, 0.1665549155856882, 0.1574582579944815, 0.11971761099994183, 0.09540771653077432, 0.09438951366714068, 0.11511616648307868, 0.07142172075275864, 0.08619403879025153, 0.11790390046579496, 0.22708245127328805, 0.15365280290799482, 0.18674952909350395, 0.11309236115110771, 0.1567582812692438, 0.09648582725120441, 0.1406290696135589, 0.16176938451826572, 0.13367799403412, 0.09561393689364195, 0.14337656646966934, 0.10020181071013212, 0.11444182481084551, 0.13119623863271304, 0.17558912081377848, 0.09671201689967088, 0.1004720169252583, 0.0736559262233121, 0.2059252272759165, 0.2035177850297519, 0.15409394566501888, 0.08980987726577691, 0.14898601546883583, 0.1050835173310978, 0.13247165376586573, 0.18907762345458778, 0.1524470326091562, 0.14809792169502803, 0.17009154866848672, 0.12429259265107767, 0.1407167770500694, 0.15406767278909683, 0.10751739530158894, 0.1164510077131646, 0.13986033014953136, 0.10112862847745419, 0.14451707527041435, 0.13913083715098246, 0.12832139432430267, 0.11426760415945734, 0.1640011269067015, 0.11953997053205967, 0.1076986455757703, 0.10226133412548474, 0.1184723363923175, 0.10804312423403774, 0.07542794078056302, 0.14568225560443743, 0.12118351805422987, 0.11526239077959742, 0.2081215094242777, 0.11294148210436106, 0.070483238968466, 0.12380659872932093, 0.0893805410180773, 0.0777962247708014, 0.045277440787426064, 0.09372111596167088, 0.0873789441372667, 0.100864752994052, 0.14958115853369236, 0.1167920394135373, 0.14563307538628578, 0.1101351562621338, 0.15401248075067997, 0.15590380212025984, 0.1359438667339938, 0.0966619003031935, 0.10432686936110258, 0.12462204854403224, 0.13282233423420362, 0.16128814034163952, 0.1675041860767773, 0.23920481864895138, 0.16856726046119416, 0.11634271352418832, 0.13364288663225515, 0.13411950320005417, 0.1509950083813497, 0.07909591110157115, 0.11797294818929263, 0.20733351313642093, 0.1592172650354249, 0.10972666461020708, 0.22386660240590572], [0.04369767555700881, 0.026175495968865495, 0.12697218172252178, 0.0204243281457041, 0.05450300985415067, 0.014669379186151283, 0.06554246587412697, 0.04923602087157113, 0.04747809948665755, 0.0253074579938714, 0.06845895866198198, 0.005034585225595427, 0.026871206405173455, 0.02039385344167905, 0.042515918612480164, 0.10402294674089976, 0.01962991800558354, 0.027393608819693327, 0.004812556269046451, 0.021523877180048397, 0.027031925906028067, 0.02153555816039443, 0.02410891748565648, 0.052342079380261045, 0.04068593680858612, 0.027608701027929783, 0.05528766096436551, 0.0611885916441679, 0.08865297505898134, 0.026012903711359416, 0.022393565691475357, 0.061202576250902245, 0.017964835478258983, 0.0440581405003156, 0.02471381109873099, 0.0529566896148026, 0.047942800979529104, 0.020078680710867047, 0.027875343237870505, 0.01633318267496569, 0.024195155893851603, 0.023352917516604066, 0.03670697692515595, 0.017653521915365542, 0.047323732769915035, 0.044387111240731816, 0.04244588362053037, 0.0060007147673916605, 0.06490839525525059, 0.024518929056024978, 0.006120918518198388, 0.027698349074593613, 0.009420994785614312, 0.057730071512716155, 0.031209638874445642, 0.019415103996704732, 0.013298596804296332, 0.016254135041630695, 0.09751488667513643, 0.006062502166189785, 0.05962408666632005, 0.013766871632209845, 0.019751838874071836, 0.04813419535223927, 0.029607841611972878, 0.031122348736971617, 0.019218086265027523, 0.025436233762385588, 0.01610544935933181, 0.04684616286041481, 0.04507765293653522, 0.0609684002452663, 0.03823723624061261, 0.012604349459122335, 0.07648680824786425, 0.039685314787285667, 0.0381355272339923, 0.018608363178957785, 0.02886163629591465, 0.0474537773989141, 0.05317441114623632, 0.023549696064687202, 0.06159394846430846, 0.0327865881845355, 0.019235809599714618, 0.03003375804317849, 0.07015615116272654, 0.011218464584089816, 0.02904502734807985, 0.03453990231667246, 0.01475271855347923, 0.06338600694601025, 0.0030786049818353994, 0.029141535383782217, 0.06853640664901052, 0.040655355235295634, 0.06300680086548839, 0.05348665939111795, 0.04540370597637125, 0.05698546753930194, 0.042615822715950866, 0.014839951015476669, 0.04271166578733495, 0.028327196670163955, 0.024774556946275488, 0.010391444050973015, 0.03560289527688708, 0.04276380781084299, 0.02993993361347488, 0.02166518209768193, 0.06671700320605721, 0.04226627200841904, 0.05749362241476774, 0.07880023268184491, 0.015293790859037211, 0.026124244522569433, 0.030798012390732765, 0.025703104977895106, 0.043128428781139, 0.03028193222624915, 0.007439781944932682, 0.07868807762861252, 0.02085175092465111, 0.024037664523348212, 0.04430816029863698, 0.00917935319843569, 0.04538937870945249, 0.07609088306448289, 0.023093291358756166, 0.028096150407301526, 0.04766568049256291, 0.053655655322862525, 0.03136914888662951, 0.05214458158505814, 0.056472847903413434, 0.09718304912426642, 0.04099722153374127, 0.06764393632433244, 0.04454211578039186, 0.03277366887778044, 0.05758337902703455, 0.00556834674041186, 0.026929039641150405, 0.0348042527745877, 0.03079841611906886, 0.03315390633153064, 0.018141088342028003, 0.020304325834981034, 0.027437564318201373, 0.05962851071464164, 0.03513216160769973, 0.0074725534899958545, 0.006166449490202857, 0.04794495193553822, 0.020730639209172556, 0.02520489742580269, 0.02944840963131615, 0.03791347325646451, 0.015384317608550191, 0.10760399672601904, 0.02005070640838572, 0.03563402985621776, 0.03925146288903696, 0.012351315268980605, 0.07156419275062424, 0.022097900842449496, 0.01753987238875457, 0.028562918039304868, 0.044470004471285005, 0.07441756821104459, 0.006811831711924502, 0.0556937098902251, 0.021873563594583954, 0.023292999481782317, 0.06173914817294904, 0.01770709564776293, 0.024838619133723632, 0.026917407854593227, 0.05699836649000645, 0.026913433335721493, 0.06107341032475233, 0.0008857942292317082, 0.07480319323284285, 0.10317183991095849, 0.07207182515412569, 0.01623774502825524, 0.03547911013343504, 0.0157806923213814, 0.022791867443759526, 0.017147328006103635, 0.013010249107277818, 0.03724482788571289, 0.05952904426625796, 0.039068112548972876, 0.011029436602257192, 0.033543901118849, 0.008757043180854192, 0.026324865275195668, 0.031104903601642166, 0.04885707263435636, 0.015940103945987563, 0.044196836450802426, 0.055244916650865755, 0.009493914399562138, 0.11566294357180595, 0.015702923726556555, 0.03267643820228321, 0.022850972932896445, 0.02010614950475948, 0.020424541884234974, 0.04718858216490064, 0.0674084982435618, 0.14473571282412323, 0.06614249439111777, 0.030900494927274327, 0.08055437462670462, 0.015468411846086383, 0.05219738857288446, 0.036724968281175406, 0.0097412590735725, 0.03522889695263334, 0.05992276421082871, 0.030232765578797886, 0.037818444427102804, 0.010530691311162497, 0.013993424296911274, 0.061508242706102986, 0.037890766082065444, 0.04325718758627772, 0.04001385126528995, 0.03366924010749374, 0.021603399787896445, 0.01871504245458969, 0.017184618594391004, 0.07497839776000806, 0.025237774143793752, 0.04507031458030854, 0.04739324189722538, 0.06844659575394221, 0.09598939067551068, 0.028314594578530108, 0.01802229382363813, 0.058349743618496826, 0.055734082723834684, 0.015074929388772165, 0.018822463029729466, 0.026324298698455095, 0.010339015346419598, 0.044977094046771526, 0.04297035387051957, 0.032375528277563195, 0.01453534816391766, 0.02582541261134403, 0.0033857114155710277, 0.05703864432871342, 0.015173624003572124, 0.030735319147684743, 0.0034373184566252996, 0.06893619269664798, 0.04257668820875032, 0.03785465784104807, 0.013103358530705529, 0.013634430078257407, 0.02016822188826544, 0.030546394642442465, 0.059639496196593554, 0.030220168576176678, 0.03189698127763612, 0.038678317929485014, 0.04207432123699358, 0.04644427674689463, 0.0441268184222281, 0.05704725493810006, 0.047354619683963914, 0.07520530665559427, 0.052766954260213036, 0.048593831581196616, 0.023238158585237603, 0.03265070136902588, 0.029697167354502847, 0.011538823866950614, 0.030097994953393936, 0.04332137360636677, 0.048897448860641034, 0.018859365156718662, 0.02200744194643838, 0.0818457081913948, 0.0236741750101958, 0.023972133307584693, 0.006810091269601668, 0.010820682759263685, 0.007760455898408378, 0.060591039779995165, 0.04126354992123587, 0.016011738584243825, 0.04945991707167455, 0.01746712834574282, 0.07507468187915427, 0.0501479753293097, 0.0006609310637161668, 0.0031866775867196596, 0.017478451398866515, 0.03489530199606504, 0.04545753415940063, 0.05142526321911386, 0.02790233536091234, 0.02065320818551949, 0.042602180769400935, 0.029770174329834323, 0.10645541335855212, 0.04261367515261684, 0.03929229712645922, 0.03582738180245672, 0.02800452782373343, 0.057824231817254, 0.03458834971700396, 0.06352306423442704, 0.007864194572903216, 0.007842940311612827, 0.06306182327015059, 0.025384442880749702, 0.05417747250092881, 0.09232158998825721, 0.0430650705737727, 0.012714387483096548, 0.01047588518953749, 0.018396716232278516, 0.044105319040162225, 0.03189888456836343, 0.037058413960039616, 0.011442232710708464, 0.016137516924313138, 0.01886953130763556, 0.02563590117331062, 0.030394127991582667, 0.023732915786760192, 0.05520625711817827, 0.07033307238348893, 0.02653219673915633, 0.03471066922481571, 0.06602366255330187, 0.016472126290734326, 0.004620010931310909, 0.012883750671919967, 0.030291387611734014, 0.07804917584040336, 0.02361642659109618, 0.02705549312356327, 0.025310592825657556, 0.02546970928753061, 0.07832689343818597, 0.018570019165053964, 0.18712623816515717, 0.1649772673845291, 0.20189980470708438, 0.10289357948516097, 0.1387567472245012, 0.08985086078090326, 0.1999569825295891, 0.1816726215183735, 0.18821285771472113, 0.07202207496655838, 0.11525769531726837, 0.06886854275528874, 0.09846898155020815, 0.11290125176310539, 0.11205798201262951, 0.2506690206272261, 0.1742161594863449, 0.16555303148925304, 0.06883782547499452, 0.1049205603610192, 0.10109962789075715, 0.112478436236935, 0.14615066189851078, 0.11888974399438926, 0.1329412135694708, 0.1368469154196126, 0.17701192732368196, 0.1991546420114381, 0.23228739840643747, 0.10592912802738802, 0.10915565703596387, 0.12075643454279218, 0.11140479027692761, 0.11506706768912928, 0.09623540033187185, 0.2405537734074252, 0.17693651494170937, 0.10579357708671264, 0.08291836349027497, 0.13768695534339973, 0.06152733668152775, 0.13405641301402024, 0.09028021738465343, 0.14975181009088243, 0.11659416503139905, 0.1316292118281126, 0.13226271926292352, 0.06851609809590237, 0.1486158881868635, 0.10615774683122124, 0.20942531446261065, 0.10132216702082328, 0.16322835694466317, 0.1320985137884106, 0.09284672180988959, 0.12949903256126813, 0.070450309664011, 0.09049599830593381, 0.18652759385960443, 0.052254005534840484, 0.17428366015000002, 0.10450617223978043, 0.15487583513770783, 0.17902326796736034, 0.2126187173915761, 0.11559541576675006, 0.1249329261481762, 0.12058346239583832, 0.10331023391336203, 0.11115124888185944, 0.08022639115474053, 0.07170692259179694, 0.13151215096669538, 0.0755681125447154, 0.1626346930861473, 0.1616366087858166, 0.10321719997695514, 0.11193852592259645, 0.14946294416274342, 0.09629109448620252, 0.15230867931885378, 0.06768845500690596, 0.1903657814753907, 0.16081967976476463, 0.11325328930148057, 0.07940070224659783, 0.17714679294398852, 0.16010071762970515, 0.10124757566622325, 0.2014912452016558, 0.1933797797454255, 0.2137712226914508, 0.09304688964039087, 0.11755549987511975, 0.11627388293189661, 0.11971989087760448, 0.18828494527510234, 0.08041621132620744, 0.1088126575840371, 0.17073623836040497, 0.12670428252645902, 0.18282746097871236, 0.12945042231253215, 0.057321518792637756, 0.11114024982920714, 0.12779291053967817, 0.10546015176389899, 0.10052737859742981, 0.13897193782031536, 0.0819048493036202, 0.15477568336895534, 0.09189765487930604, 0.12917671485670976, 0.15029372886887618, 0.11113957807953868, 0.15606066584587097, 0.15022489827658447, 0.1595592466848237, 0.18246399691062315, 0.1000488960583295, 0.12838721222111157, 0.1968890271548714, 0.168763845626797, 0.13757898685123238, 0.08636156230100564, 0.05590147392026015, 0.12599910822297844, 0.10523371105747563, 0.15352371840604714, 0.09746593715889112, 0.16520015256745474, 0.12440091398145471, 0.10340093368930475, 0.18774542851107462, 0.16596788779965468, 0.1885261780449322, 0.14644874233220304, 0.13385947501020773, 0.1311532873660326, 0.15510432501988752, 0.1696015921022211, 0.10280119694237198, 0.1448329740336963, 0.16773902704673155, 0.0920919126697949, 0.11351993999310903, 0.10920827064130988, 0.11202964639025075, 0.13973257557622024, 0.17094612281237329, 0.11430162590529237, 0.0689229816198349, 0.1201429438910314, 0.11559948697686195, 0.07189639671040432, 0.13744090497493744, 0.11911914311349392, 0.11384128060724054, 0.14840590873999254, 0.24122251038040432, 0.1583200381802661, 0.22193361898618086, 0.11794269909816128, 0.09237404753054891, 0.13729816834841455, 0.11739807975079332, 0.1232087415243898, 0.11947370480213847, 0.10716841117079769, 0.2470098984028612, 0.08229609259537288, 0.2365250667291028, 0.15798995803509439, 0.06057221043322768, 0.19467728797878536, 0.14123314219926084]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.09478755587978022, 0.020740729024899856, 0.04176748091621058, 0.02186338387296668, 0.024101906522576298, 0.04558839303042207, 0.028677207085170915, 0.04021386303273695, 0.004306158375194562, 0.05906067868428571, 0.01390247346301164, 0.02351189318246075, 0.022951966085072075, 0.026146001747942398, 0.04111164289393595, 0.008930081484972366, 0.011483729367942681, 0.04604548475305949, 0.019859208559085215, 0.017453878253166164, 0.0654631315597466, 0.029742568132600615, 0.03615987413961973, 0.08287893382034131, 0.04899372958711215, 0.05725222679653338, 0.04628517385572195, 0.07335473131388426, 0.05956716436360564, 0.01640665783946003, 0.060311720839568546, 0.039308863558939526, 0.05763203677322183, 0.021521524359871234, 0.02261365870279925, 0.047129532654902766, 0.07181126092161451, 0.015357449318149259, 0.01737531746870705, 0.014950462317626392, 0.04074740868860057, 0.04501266285244908, 0.020217566651159098, 0.04774258904425161, 0.05995884191777025, 0.04711464559659362, 0.03047786939090916, 0.04179336702717202, 0.03305242463414158, 0.02342560388413923, 0.031271141288535934, 0.07223528424011809, 0.03921061847358942, 0.04700193075197084, 0.05664960966844644, 0.015132759232074022, 0.04139980314565556, 0.055029186619711776, 0.03657854042415108, 0.020260256681857363, 0.02621283066192908, 0.011925744890634502, 0.020264673944828764, 0.0053884505676770845, 0.014330686735255378, 0.07810489713613476, 0.03595994379637497, 0.01351979243502553, 0.001789517156014751, 0.07085686070578438, 0.04107695618378265, 0.0499033363136862, 0.007627042343041727, 0.0018618916094835314, 0.023799676847245013, 0.026243481785058975, 0.025558490505708114, 0.02160469748611961, 0.0250889985556049, 0.02738040452823043, 0.02527387729579849, 0.10573499915855271, 0.04332360937925322, 0.04030710731499961, 0.04438714516748275, 0.012067598573464369, 0.0117332300869748, 0.007684154635561364, 0.02576707556311573, 0.06931079152439322, 0.08824432055865016, 0.03911838520850454, 0.020536964958799735, 0.0885763888114265, 0.025878360395186713, 0.036465028300881386, 0.08511849293219191, 0.011464335988940937, 0.030450124093996625, 0.05297133918585522, 0.009458810390372361, 0.023686514169509922, 0.04904104383396251, 0.02967860602906772, 0.011473670086291219, 0.025194298708811402, 0.019283681941617812, 0.021898805097277676, 0.06434374555413212, 0.023995361257610575, 0.04574530764615961, 0.016365133192656294, 0.015165486672360982, 0.052514396740921905, 0.03994984844965594, 0.01734822186907487, 0.06108645176781075, 0.03353604368333306, 0.0628294318116137, 0.07926724119377987, 0.04683229699730873, 0.015903157714222158, 0.03539097182718771, 0.029179058370313475, 0.014813550914238607, 0.06942574892725263, 0.017230348461972814, 0.052868846471288374, 0.027110529098925844, 0.006617444151613329, 0.036081466025539806, 0.07917966946427311, 0.06695929449051619, 0.03164279866697533, 0.0287752112905894, 0.025459851870047193, 0.04060578825218337, 0.03737346116187317, 0.037235555704683065, 0.023722703834729533, 0.02316508375640426, 0.03753304581290909, 0.010162314649538269, 0.033876943069377115, 0.07689762727490493, 0.05985150446317025, 0.04110204162342208, 0.019685881877584115, 0.04319885393072452, 0.06714278393025909, 0.02865161613694259, 0.01715735505734171, 0.02548661838019533, 0.05711500665971211, 0.044188809381531816, 0.08072073784257684, 0.026800811789663773, 0.03956269333139062, 0.054941893089562654, 0.03089366547231163, 0.022934705850535204, 0.019549007793622356, 0.028815777506679296, 0.022234849565263306, 0.02205999957264534, 0.015082834321739418, 0.018285877536982298, 0.020332356116601398, 0.03812556973259364, 0.05674484884366393, 0.06603774894028902, 0.028644912210958343, 0.06389087771198579, 0.03516418167522975, 0.04596868815964886, 0.03641177687261786, 0.042394993494131734, 0.07243193047387259, 0.013365181445676302, 0.013422769560877765, 0.07049598864146642, 0.0410178388202829, 0.013827120452853186, 0.03974973150928106, 0.03960770734452775, 0.08049085017825876, 0.04289966069960168, 0.04116964406733002, 0.05276301197175469, 0.044619923390980275, 0.01715822358216558, 0.020101784828252027, 0.008896905363404324, 0.08172295442117111, 0.055119967819856744, 0.004904321344968463, 0.05192011880821415, 0.07336178129272801, 0.023639993808631386, 0.06109576805361679, 0.041048481461725066, 0.02121793252549001, 0.017485520037423288, 0.047011559163885455, 0.01955075332495783, 0.06200151052325964, 0.01906532428360411, 0.023602762592158148, 0.03787659827087607, 0.04885757814294525, 0.031012283571596657, 0.008837814293136554, 0.03586130516071405, 0.0208811501506716, 0.05727816719029631, 0.016556079732254148, 0.03794102517089673, 0.04516294139570423, 0.047844627140355964, 0.04715782417250531, 0.02639059835512723, 0.03307871786611421, 0.06397821873958622, 0.027434222533234527, 0.04425882401743105, 0.0038200028772865024, 0.016876020867909704, 0.00748523955033826, 0.1094348741961377, 0.02036170954150813, 0.06543252284505538, 0.014802994605685984, 0.025527510293094174, 0.025468515065897788, 0.02733120565036578, 0.006290201130988342, 0.0295451755103256, 0.039832244760223796, 0.03152348846197128, 0.03161808981427124, 0.1046318437105843, 0.06796392665377685, 0.046243742507483275, 0.02160847862251103, 0.020019476834152426, 0.007938328764534422, 0.035533141876970015, 0.03551036684906908, 0.030084068022136177, 0.013899911993316241, 0.031174948771617243, 0.044255478839789114, 0.03106781148484775, 0.030861621656055962, 0.02285242160516126, 0.03153257065319589, 0.0274225890503398, 0.061326924578419754, 0.0625333327001759, 0.013407408376224339, 0.02287559866506074, 0.0076542804350278205, 0.02274177289967026, 0.06754044616328818, 0.05210179995213236, 0.05461468993287001, 0.01989814459479281, 0.06269706998552595, 0.03712437774187752, 0.09790558713887419, 0.08006010936307055, 0.046531278506985733, 0.05165326116340501, 0.037394377003823004, 0.04137302136846951, 0.011026418817761754, 0.06641105176614863, 0.04190731680552874, 0.0995123309216329, 0.02350268715859524, 0.027662206906825304, 0.019225594255008867, 0.03458462455975158, 0.026556627392502766, 0.04049429137791906, 0.00784606920621757, 0.060171094456953664, 0.029987146080072438, 0.03006548973332558, 0.02022758182803435, 0.0192832375011806, 0.05253558738955429, 0.03728962476764407, 0.03602001110890082, 0.017900182965344617, 0.019584445981308818, 0.03033899362864239, 0.011989045422524214, 0.022676189097442796, 0.02614895167893597, 0.04930597443931869, 0.027637084147759845, 0.021533174806141427, 0.0771631176716515, 0.09351704655481236, 0.008458539510944059, 0.028897890421961035, 0.028246892050706914, 0.05821588223001786, 0.016564003324934413, 0.01819196150505117, 0.04801372824502843, 0.014122066054759281, 0.019768301829961792, 0.011212121129834225, 0.02867876771571381, 0.0006385069656451897, 0.02284771596480693, 0.008451459846193237, 0.024706274271011353, 0.0574072449068938, 0.0594350468101246, 0.02465880905011935, 0.0422262791544199, 0.02219050221278199, 0.0453515707382134, 0.11001728115869419, 0.0629625196701714, 0.011668192505437349, 0.04664319268028651, 0.03784674612273063, 0.06446189885692936, 0.07150969960327659, 0.01460752563018884, 0.006073740826520536, 0.03962017881817051, 0.016804289538413286, 0.03507002476336701, 0.019451157954920615, 0.052678371513528485, 0.05851451227707522, 0.03585415679429259, 0.03501033064510141, 0.042146391833999326, 0.03812460282019206, 0.058974857575127056, 0.007872564302358245, 0.04587796463498047, 0.03807368894506778, 0.06377231728817735, 0.08840568975678512, 0.017213283306253806, 0.15801758798105375, 0.15444624104670115, 0.10230398005140678, 0.14085278260920728, 0.11089291024420943, 0.09234539978206158, 0.13066604493984155, 0.10324311322931733, 0.15768849849700928, 0.16489771593894276, 0.17326583048062666, 0.16905619922493184, 0.09515541006944009, 0.1669603945421321, 0.08138366655579635, 0.10197426631514515, 0.2156727627984115, 0.20204801032585756, 0.13835865072906017, 0.11702917383185454, 0.14143586132143224, 0.1510413930352245, 0.18945939439748014, 0.16169683555407183, 0.09163525860224452, 0.15834746456571988, 0.14342202831591877, 0.1970047987997532, 0.1360936194126095, 0.07532587554305792, 0.1553444449922868, 0.19579571725002357, 0.21935393741088255, 0.1290636844933033, 0.13676460912185057, 0.13486331328749657, 0.19846953877380916, 0.0869393212986844, 0.14954713678785733, 0.09580803183572632, 0.12173224932381085, 0.10967521129974298, 0.14724796158926828, 0.14022747187742166, 0.10239354667386838, 0.09598825752202954, 0.06627387234142848, 0.12257439270615578, 0.1190948515598263, 0.12221732043794223, 0.1189746151545218, 0.12612276444477694, 0.2513622120022774, 0.14550338020282133, 0.13159228595239775, 0.07919032246406589, 0.11802219626094614, 0.09741398851786341, 0.08756194503179618, 0.06669376338166849, 0.13391056869711193, 0.06364220819835152, 0.11651605208005224, 0.1362177234675203, 0.1347658485174179, 0.19094677029975823, 0.223704405395048, 0.12019586962248598, 0.10703578471605267, 0.16213438207549707, 0.16371692929949078, 0.23469636057104382, 0.09175717098904507, 0.09219389648309775, 0.1015909415270601, 0.1885695228619235, 0.07352922337927989, 0.157519841832774, 0.13452770986727305, 0.16376900007682188, 0.19220573774405889, 0.16652506004486764, 0.14685253852180072, 0.056852440748895915, 0.10653666792703526, 0.08308455028704234, 0.1013413831325514, 0.14565001162035124, 0.1575376737330641, 0.1742214249180896, 0.1900906762374299, 0.09697913578046219, 0.07083529686289174, 0.2150674145668745, 0.17667142488062382, 0.16597913791026386, 0.15913010042692932, 0.11048570780881814, 0.12925739267042705, 0.20970575298581803, 0.09000741238040583, 0.07346037921628781, 0.2197949987437044, 0.10602577177009412, 0.1173879017255136, 0.11366104135023695, 0.14262327046266624, 0.11682279062058244, 0.17835064977407455, 0.11633721739053726, 0.143681975081563, 0.11944900612745966, 0.12375577645642416, 0.08758629086826529, 0.12842150538095407, 0.14097828444625649, 0.18141002846615656, 0.10917496814259461, 0.22702211593942984, 0.19695607998541423, 0.10627056006342173, 0.11948336714080401, 0.18106977029570512, 0.07867153494485787, 0.1244587523064443, 0.1404596394194024, 0.04818999128682273, 0.15737574813621386, 0.2052619457244873, 0.11048638634383678, 0.09896709410739796, 0.09635068343154021, 0.25845431429999216, 0.11673763447574206, 0.21616949114416326, 0.12260663669024195, 0.0759546739448394, 0.09167077991047076, 0.054092737047799995, 0.11609977084611144, 0.08086247023727212, 0.09529523578073297, 0.07779446057975292, 0.1667958362294095, 0.1713132102574621, 0.11461288348904677, 0.10249732860497066, 0.14403878950646945, 0.09946462990982191, 0.17918819268899305, 0.15422564931213856, 0.1075056634311165, 0.12341771673943315, 0.2033684937549489, 0.14766269576336655, 0.29747352483017103, 0.14827321443174565, 0.08019878156483173, 0.1432815987084593, 0.09887452836015395, 0.13153580469744547, 0.11497450194188527, 0.10438698077840464, 0.10705761997295277, 0.11018755952162401, 0.11498136871627399, 0.14128183387219906, 0.1301848686167172, 0.13767193257808685, 0.1693984522883381, 0.16453127988747188, 0.1297809910029173, 0.16707201355269977, 0.16281394846737385, 0.18558847425239428, 0.08371560821043593], [0.01011556273858462, 0.021998246100598147, 0.01345387869514525, 0.01121559607729848, 0.015621187398210168, 0.02325409567648811, 0.010087266131969435, 0.051498165021517446, 0.016372072909559523, 0.009532236361077853, 0.019384393501760702, 0.03747530248282211, 0.09593423934919493, 0.04566193265574319, 0.016028215110834156, 0.05069253360852599, 0.06823762732424907, 0.03705912981448429, 0.038692126117114506, 0.04917561089886086, 0.023650667164474726, 0.03735132734956486, 0.02754444206532623, 0.08230387539203678, 0.03406517207622528, 0.04578591457435063, 0.029890135928456272, 0.02024626698611038, 0.015238832915201783, 0.025148643480081643, 0.06261279593620982, 0.01796246230203126, 0.007862890089329864, 0.013611969720971371, 0.020171316007950475, 0.04824479316760387, 0.025272740749642253, 0.045216281033520184, 0.052133772522211075, 0.016360826191625426, 0.03627439049471702, 0.00836420278730137, 0.017567061286951815, 0.026673611918730394, 0.03258347551205328, 0.03284430776589683, 0.06688926967659167, 0.03018212311768106, 0.01648746457483087, 0.03741434968209692, 0.010281791943790657, 0.03879393690398761, 0.039137238303997686, 0.06583521980792284, 0.06512238484408174, 0.03221092925273946, 0.0477555965605591, 0.03624021607850279, 0.00279459630421895, 0.018575074250942895, 0.03004577150568366, 0.06403721057410751, 0.04439722141250968, 0.04755866534209677, 0.022787521426965083, 0.004543517558236739, 0.0482859904212611, 0.0402952668789242, 0.011392398554432605, 0.033582282452178855, 0.03083944713164653, 0.021743909123220613, 0.009926809563434549, 0.04275606572628021, 0.08427223084228379, 0.03645102673077157, 0.037174775930387635, 0.07394782520298447, 0.0898448693166886, 0.017645393065842133, 0.026238024667171494, 0.12801922910979815, 0.04657349356317094, 0.032086292547839027, 0.0323135237475591, 0.02294553696577038, 0.09389484128249542, 0.018681970657780766, 0.015473626387704695, 0.026584019851205603, 0.02992693966786776, 0.026873978220724633, 0.03320850804448128, 0.017168013146147132, 0.03454152740804212, 0.051671211807323356, 0.01771284792838352, 0.03420255845412612, 0.013185212754511406, 0.01752184540964663, 0.06881615985184908, 0.02203436621597835, 0.036178354040852616, 0.009154146470661675, 0.0225074544016804, 0.05150855339265295, 0.020420991449749896, 0.02899474451052291, 0.057243582260395796, 0.05788320329572473, 0.04931820842570492, 0.044210848198937516, 0.024702326893540363, 0.027741678624546955, 0.03512287246329444, 0.044456084325377426, 0.030640096935842718, 0.09055165853351355, 0.02040842328486698, 0.04766626064000385, 0.0366160294839314, 0.02496436015436692, 0.03259640499683363, 0.03395227063447237, 0.03759671614638396, 0.02788838976994157, 0.024479472244690572, 0.03128454914050443, 0.03883655568850892, 0.04623064338894827, 0.044517298362084796, 0.01451216940768063, 0.03777159158406513, 0.045335397856043916, 0.03863666605736528, 0.03446738388655441, 0.034085758828691075, 0.018726667455796684, 0.01317612886694925, 0.016197911629985486, 0.04386046289333275, 0.032650450311068974, 0.02047423948533833, 0.0021770547983968364, 0.009655030843402659, 0.004901199235713908, 0.019835771959541098, 0.04431477940774389, 0.06639146246016026, 0.05023748427629471, 0.032508877372103076, 0.029590762885553495, 0.07851741928607225, 0.033489211196345944, 0.014817639087725962, 0.06968513929418155, 0.028072293116045848, 0.023661547473498752, 0.06633710501981632, 0.06326391135475465, 0.04966128930183394, 0.025228646151455383, 0.042335146705486944, 0.020588138373568654, 0.032057855145207474, 0.017625457706994245, 0.049258283605532985, 0.04856038659012743, 0.05618578687842403, 0.03613838154290404, 0.02972875315962093, 0.009785555535927415, 0.052579834658120356, 0.037453592754900455, 0.02543044076966388, 0.02645435689815453, 0.0666584659899984, 0.06255029607564211, 0.01739413833378681, 0.030818704316126447, 0.006546703483244138, 0.03019759032343115, 0.05709847754665783, 0.054261329251208475, 0.03703689082924809, 0.021861624770930836, 0.04763544497213193, 0.04097925053377237, 0.035285941391651116, 0.008738299499132803, 0.013907222359973406, 0.029222426936030388, 0.047486021383000274, 0.0425363323385162, 0.023017015540972352, 0.04275127187637346, 0.03955810982733965, 0.02694344493959631, 0.015944577188098004, 0.02607274710732911, 0.04908757437286632, 0.03986235475167632, 0.04389562118532402, 0.018994972076533095, 0.06235302558967045, 0.04039870954251715, 0.035978498336459906, 0.04129314422607422, 0.07399456948041916, 0.03291811541255031, 0.035885315122348924, 0.041675932971494536, 0.021300679871014187, 0.03228318305420024, 0.034641614715967856, 0.030666766754750694, 0.014505847157644374, 0.04762487678921648, 0.030003508952047144, 0.047714965883642435, 0.03625866544565984, 0.019764401949942112, 0.056744631712457964, 0.03129837429150939, 0.037221221652414115, 0.03337886783161333, 0.05572596065966146, 0.009384498931467533, 0.022985053148918917, 0.04949226283601352, 0.016584720695391297, 0.028292667719402483, 0.07746057385312659, 0.03526053025520273, 0.035864775867334435, 0.019854253557111536, 0.032712638045528104, 0.03191329665215952, 0.026375329620870094, 0.019957501141886626, 0.0645909019346748, 0.037449850634272606, 0.012442029463792486, 0.011741640528530946, 0.0639247569654669, 0.05140197589727385, 0.029503591491707733, 0.023278763817091073, 0.004682399257684925, 0.038227489085069725, 0.05720166915229388, 0.025334874201299887, 0.028526518028229475, 0.039719699549355676, 0.021308330353349447, 0.0367938022661422, 0.04828984110749193, 0.08710381854325533, 0.02366658898868731, 0.012891333300753363, 0.0160704895388335, 0.029006018369857754, 0.042482996093375344, 0.07803168320762259, 0.04348198284528085, 0.047532395858849795, 0.03616943469803248, 0.003664234985730478, 0.10067047484751258, 0.03461455813209925, 0.049233500113976855, 0.019618980021082928, 0.03413357858413032, 0.029469970081533705, 0.019875525629946163, 0.02639025230226772, 0.04810218207005944, 0.04304536930950625, 0.01461923205559807, 0.03144294635525771, 0.07179684883781842, 0.038036501833370755, 0.029811191771711622, 0.05667087834860597, 0.024163451345105256, 0.024489711338121976, 0.05056768995044487, 0.027579542681840912, 0.01459437731786498, 0.06271995697170496, 0.03998580741296921, 0.014543136049594198, 0.003299660876759195, 0.024108751244576912, 0.09239005417163883, 0.03735430611829672, 0.03284941374191216, 0.021659085460539376, 0.05106407902868731, 0.03186392644420266, 0.0678395986823099, 0.05896409600973129, 0.031466081006718535, 0.006916110245843551, 0.051295218590114794, 0.054045107282165966, 0.05831944702991417, 0.0454944498570902, 0.048822189149047644, 0.02431436431860285, 0.046987053871686967, 0.03144936868920922, 0.030483660687293326, 0.011338592423791332, 0.02194650950176375, 0.04012658985863839, 0.020413454622030258, 0.0330212900548109, 0.05170848373589771, 0.045402616927666326, 0.02861166399504457, 0.033165234473666975, 0.009970977104135921, 0.05050107816766415, 0.03955395380035043, 0.0059029047926222634, 0.010907671796823186, 0.02860263269394636, 0.047332750500312874, 0.022086727067029903, 0.0252667933902038, 0.03668911449079003, 0.06410179353718247, 0.030530991897519146, 0.013284484124077218, 0.04610539260985596, 0.02184480897683118, 0.02257291437126696, 0.046965422175292454, 0.028714964166283607, 0.015601403013403927, 0.04605745071811335, 0.02996528028909649, 0.0036563402307885034, 0.03029693124283637, 0.05250161314117057, 0.019560054343725954, 0.023729702923446894, 0.13340104318090848, 0.0380372821486422, 0.007111806954656328, 0.03920320887118578, 0.19254739369664872, 0.12489099268402372, 0.1127247376633542, 0.11028450860508851, 0.10118478403559752, 0.18174256490809576, 0.10677335451224021, 0.14781741531831877, 0.12830052258712904, 0.10139918074543987, 0.08395227443959032, 0.099010248934584, 0.1868660199855055, 0.11950001839016165, 0.09072898687528712, 0.1312896321926798, 0.09407569122101579, 0.12412624300590583, 0.05277040121810777, 0.14962869669709886, 0.15500046844993318, 0.07313718620155539, 0.19060735351272992, 0.17992153976644787, 0.11243675383073942, 0.10462895315140486, 0.18768255545624665, 0.1511855681559869, 0.16882616228290967, 0.10435756628534623, 0.16604577004909515, 0.12096450052091054, 0.15604662017098495, 0.11501197064561502, 0.10295390124831881, 0.12029752773897988, 0.10929072621677603, 0.16131317828382763, 0.09610397488410984, 0.09101655001619033, 0.20327759720385075, 0.1470525570745979, 0.07267116835074765, 0.09717623663267919, 0.13617372725691113, 0.16328107911561215, 0.15834517111735685, 0.10340366140007973, 0.12905210868588515, 0.1205252440912383, 0.1271341344607728, 0.14247757542346204, 0.11710210277565888, 0.19871919894857065, 0.15736706288797514, 0.11611553999994483, 0.17263853842658655, 0.14641790970095567, 0.10718884864555937, 0.10886658754731927, 0.12846603084887775, 0.20809674289609703, 0.1538632030465773, 0.09902563810880695, 0.21902959767196858, 0.08015340114278452, 0.09034397253500563, 0.06366976350545883, 0.11691188226853098, 0.16224494257143565, 0.10718019053872142, 0.09780153379376445, 0.11203599069267511, 0.0883345114333289, 0.18014236220291682, 0.12193427634026323, 0.06633337307721376, 0.16151154121117933, 0.15462796629539557, 0.11871230708701269, 0.10638200944023472, 0.2039357897426401, 0.09660415018775634, 0.06582094343113047, 0.08769069705158472, 0.10868888601128544, 0.19329148876879895, 0.14064198892031396, 0.1768557285623891, 0.09560448490083218, 0.105594488126891, 0.10424338919775826, 0.18032653017767838, 0.10582066420465708, 0.1170272875045027, 0.2165738030203751, 0.10898417766605105, 0.09714096638240985, 0.08812195355338709, 0.2003170403518847, 0.17416487580963544, 0.12053988687694073, 0.15938312613538333, 0.1306225915572473, 0.1430691901062216, 0.13747925577419146, 0.06513362138399056, 0.13514280186167785, 0.11382501612284354, 0.12829057526375565, 0.13864842589412416, 0.13911969560597623, 0.11491032609982149, 0.09619618100779397, 0.13407804471041473, 0.08977365028113127, 0.09181570820510387, 0.10452783107757568, 0.20695236644574574, 0.09392396400549582, 0.18411601254982607, 0.09951756242662668, 0.16418946108647756, 0.11192458202796322, 0.1226721288902419, 0.12595906108617783, 0.11226194963923522, 0.06726836040616035, 0.11496884295982973, 0.1634308046528271, 0.1333830077201128, 0.09935558254697494, 0.15573967806994915, 0.1328318337244647, 0.12443446075277668, 0.0867901114480836, 0.1622039047735078, 0.07042552956512996, 0.07591584138572216, 0.14686262155217783, 0.10096356804881777, 0.15946471318602562, 0.11869865496243749, 0.1817623781306403, 0.10234285332262516, 0.12902218529156276, 0.07546422204801015, 0.16396471671760082, 0.15283773307289394, 0.13524230223681244, 0.13775360105293138, 0.07735861718122448, 0.22444578632712364, 0.16994925987507614, 0.08048439052488122, 0.11155692461345877, 0.13911878636905126, 0.1317372074616807, 0.15122150337057455, 0.11000150521951062, 0.10569496559245245, 0.10299969557672739, 0.10183045081794262, 0.06742949211703879, 0.07933763241661446, 0.07289712051195757, 0.08493279146828822, 0.14984628930687904, 0.21681602645133222, 0.1219299201454435, 0.13539512189371244, 0.08681543437497956, 0.3590439281293324, 0.10171269106545619, 0.14040379598736763, 0.10976720707757132], [0.09719976822712592, 0.0564935975042837, 0.07594372917498861, 0.012702014397031494, 0.044581148507339616, 0.038765967690518925, 0.03196443444383996, 0.015954110605110015, 0.034796832994158776, 0.019821743248030543, 0.06158803163894585, 0.047162567132285664, 0.035284262017479966, 0.004749464386674974, 0.03873268894052931, 0.0322063423560134, 0.017598789584423815, 0.044994057422237735, 0.03652856632002762, 0.06457236435796533, 0.046904160641133785, 0.04058863827958703, 0.07408875014100756, 0.046086729504168034, 0.033608657108353715, 0.04537407774478197, 0.056385690080268044, 0.11799220501312188, 0.030657559034547636, 0.030403512130890573, 0.03274129257936563, 0.04939316279653992, 0.012240547819861343, 0.026457639311307242, 0.03183818282559514, 0.03769135821078505, 0.04405910402004208, 0.06984797412795679, 0.05371368024498224, 0.046411506898169, 0.05385422520339489, 0.022324618051892946, 0.007506609162581819, 0.020394143515399525, 0.034763041950230084, 0.01696427961412285, 0.08165071079773562, 0.06709993444383144, 0.023400309794981564, 0.03902481183675783, 0.013139858625696173, 0.02225894095110042, 0.06072810385376215, 0.002477893476939893, 0.043784765526652336, 0.014564263933737363, 0.006240414048079401, 0.0242604462296835, 0.02900353153901441, 0.015806083101779222, 0.03344080790079065, 0.0735994992511613, 0.020402767695486546, 0.02706292986736766, 0.016706588977415646, 0.021117699332535267, 0.04796320792021496, 0.028042595334617153, 0.09711595558162246, 0.017821712086775472, 0.038574885443917344, 0.0507511658194874, 0.010411158885939844, 0.02338464920675116, 0.01815482189080545, 0.04181304454271283, 0.04878200969791838, 0.0669528551931892, 0.04669501579233578, 0.02146721611331616, 0.06959809682198934, 0.05484587699174881, 0.05212862922676972, 0.0633774913315262, 0.01758021638462586, 0.04547262817089047, 0.056618787215224335, 0.008652564055020255, 0.036151490839464326, 0.01334821807021009, 0.02848267448799951, 0.06069251469203404, 0.035184174709554226, 0.038955024510089836, 0.02928659938541906, 0.00365473040645676, 0.04836599648530994, 0.003636228452835764, 0.05351531731763056, 0.05712865199893713, 0.024019467910485606, 0.04488077600087438, 0.02562575877111937, 0.036881753975259404, 0.04408236080780625, 0.0759084928514702, 0.06380072076405797, 0.04363073129206896, 0.02740969179597284, 0.016391419639278735, 0.0247616987076721, 0.04559679329395294, 0.02122276708749788, 0.07303723120795828, 0.034481775614299943, 0.04315531912392803, 0.05629216759864773, 0.03410584685791816, 0.04360892656924469, 0.058254674077034, 0.05422178762299674, 0.07097947198365416, 0.08206970617175102, 0.01130830092422132, 0.022792104931016053, 0.06050310842692852, 0.029999481846711466, 0.0457906982462321, 0.05889527898813997, 0.072150684493993, 0.06361752987972327, 0.018487560196912715, 0.016055093579260365, 0.0407473476204489, 0.040017634098018916, 0.040684949540133984, 0.06795387076480047, 0.024461759088028754, 0.05396645489547934, 0.03457945751558457, 0.09309071621724538, 0.0377978610673121, 0.019590065947600772, 0.043636261352470944, 0.033683038117097955, 0.0855538681415575, 0.010873851915156203, 0.046650541214538474, 0.07262745712484632, 0.07874899650258677, 0.08394212355571133, 0.041968612266438346, 0.06081598770937749, 0.018006412711526667, 0.05534772149154118, 0.018619609896891882, 0.025526482312540923, 0.044130255202097554, 0.05038202580596719, 0.021362228086218238, 0.023250613095504895, 0.030935201993478195, 0.03872914359505687, 0.014267196213560445, 0.031175732479563782, 0.03678783455065318, 0.02262851353069501, 0.018086491718090007, 0.052793715681348524, 0.03991093107366136, 0.010032138554379344, 0.01669360520983381, 0.13409791221576078, 0.05624561331101826, 0.07136874752385275, 0.04588119446166924, 0.057884933560022285, 0.00940482784062624, 0.07267172474946294, 0.011028324652995383, 0.024369057633781006, 0.03440021231238331, 0.051102575712970326, 0.02360303230982806, 0.06948444220636572, 0.040930528326758316, 0.027806816289999654, 0.021802163050909127, 0.021958617959171534, 0.06056564221424716, 0.02566305105574429, 0.0525007446163467, 0.02970820033390607, 0.04378219727160675, 0.016674555339185253, 0.07694387622177601, 0.03642104905364769, 0.02698202644075666, 0.08170994011951344, 0.0489407902849572, 0.182337151574237, 0.014972362035353268, 0.009583000958498036, 0.10101640557071992, 0.03335600120148488, 0.011610416096768208, 0.033345120892460854, 0.015505858497428042, 0.02663423483526068, 0.013436450523191264, 0.021427387804059044, 0.03667611375983272, 0.006555397637254957, 0.030364482796617916, 0.014797798723780682, 0.032916870300791094, 0.06733241411192076, 0.03338673544515457, 0.04726219303639872, 0.010779274311581892, 0.0357626292056271, 0.00381302965771673, 0.04771770377244268, 0.03363304026424885, 0.009827263387186187, 0.016094438432316695, 0.02774085250816175, 0.03371596402887787, 0.04490548146090337, 0.05011435731181076, 0.04675687782998596, 0.10962056887469121, 0.008802276021534843, 0.04344908068222659, 0.027984965659145798, 0.07644996379635163, 0.038071856900517426, 0.0314274418300816, 0.05231004574203065, 0.0152451500762254, 0.0339505980456514, 0.011082681245170534, 0.036586231618587456, 0.04000229581392237, 0.018232263092483793, 0.015805221362305538, 0.04808996504704867, 0.030522242188453674, 0.019709086078884344, 0.05890427636248725, 0.013136628799007406, 0.02110817439721099, 0.03244602806600077, 0.01500442111864686, 0.05960698079849992, 0.010941744432784617, 0.08435692558331148, 0.044455972367099354, 0.021485300767900686, 0.039253264399511476, 0.04301607695275119, 0.006325283935958785, 0.054467939771711826, 0.03118732525035739, 0.025153824094949023, 0.019693710475361774, 0.024438203744856373, 0.046777807242636166, 0.06354956102690526, 0.04136002742286239, 0.05063209310173988, 0.04156541658033218, 0.02173079813032278, 0.008585981958146607, 0.01885281390111361, 0.04112865715952856, 0.038600815659654994, 0.0143414941017649, 0.04779110769076007, 0.04035694910479443, 0.014588932074340326, 0.023171724917899286, 0.021936423078711544, 0.03824900882318616, 0.06360824752066817, 0.08594374757792268, 0.03363706058423434, 0.02799055678769946, 0.04320013296923467, 0.05438465638352292, 0.02718049963004887, 0.021875075031337992, 0.03940705775416323, 0.039154374705893655, 0.04705022887459823, 0.03060146454455597, 0.024826870299875736, 0.08465847333094903, 0.045442759059369564, 0.019170824604641114, 0.04473898593070252, 0.03026685517813478, 0.043404755382133384, 0.07853571259017501, 0.04418738106531756, 0.028362297286678637, 0.021043389569967985, 0.04483093421107956, 0.02054236100853554, 0.028522467174168144, 0.035296587606093714, 0.017814502652202333, 0.038691922556608915, 0.0301901366162513, 0.013326101221277245, 0.03764709397884352, 0.026469060752008642, 0.02077587883520339, 0.04636153957939573, 0.01062650978565216, 0.05226274845855577, 0.03377412465800132, 0.0374828885043306, 0.056503599110458574, 0.03465600983638849, 0.024626933171280792, 0.054468329929347546, 0.03071565181016922, 0.02232284877183182, 0.02921414202345269, 0.04820674770910825, 0.0356703043383147, 0.06288210648511137, 0.01496756648910897, 0.09945488614695412, 0.025108750709997754, 0.028431333135813475, 0.02731004892848432, 0.03243153116532734, 0.040536584465631416, 0.08503463957458735, 0.07168834430298635, 0.05435006806094732, 0.02722990037208157, 0.025232356041669846, 0.08854489800121103, 0.08863211010715791, 0.050143449500735314, 0.020686213825164095, 0.029061112020696913, 0.016674511234409044, 0.04735990886443427, 0.11756109100367342, 0.08831623169992651, 0.2188873631613595, 0.08969680619026933, 0.14123198868972914, 0.13390116420175346, 0.10298727838588612, 0.08959531770753008, 0.117143914103508, 0.10440557263791561, 0.1907848311322076, 0.20124573766120843, 0.19175452552735806, 0.12196608606193747, 0.1403927087251629, 0.11955211630889348, 0.11309842725417443, 0.1553655881434679, 0.10431557853839227, 0.17447180433997087, 0.10232841409742832, 0.06676326572362866, 0.13108749661062444, 0.11659617349505424, 0.16497098415025643, 0.09309099441660301, 0.13625228804137024, 0.22919374012521335, 0.18088104256561824, 0.1632923970797232, 0.09618588084621088, 0.1093535449888025, 0.09874525386840105, 0.08964161415185247, 0.10675073215471846, 0.09040901011654309, 0.1468413019818919, 0.13244339956768922, 0.14136281024132455, 0.08140067742871386, 0.1090977576428226, 0.07952422954674278, 0.162276100899492, 0.2706698716751167, 0.12447659777743475, 0.14180810563266277, 0.2046285739966801, 0.1601336808609111, 0.09218310099095106, 0.07917595787772111, 0.19520855375698634, 0.08324055227317981, 0.10072597901203803, 0.16991297182227882, 0.13741246078695568, 0.14450144182358468, 0.08914612073983465, 0.14085823803075723, 0.125514579936862, 0.11866556959492819, 0.1061084173353655, 0.1493002586066723, 0.154865616400327, 0.08844794213239636, 0.1033753122070006, 0.16047302979443753, 0.13631526966180119, 0.15147671396178858, 0.11842133770031588, 0.07370970012353999, 0.11089777534029313, 0.15550559705921582, 0.08094587576176439, 0.14826264285615512, 0.06463039267276015, 0.09161165236894574, 0.10229394451848098, 0.1283323187381029, 0.14784881791898183, 0.06068447405206306, 0.13902235297220095, 0.1508195392255272, 0.10795776452869177, 0.11487344093620777, 0.18620588683656283, 0.11819672903844289, 0.14197168685495853, 0.1437179102961506, 0.13877855534000055, 0.12157233219061579, 0.08019848300942353, 0.12711110498223985, 0.10092604506228652, 0.16926696577242442, 0.13930201796548708, 0.10307578649371862, 0.11199747025966644, 0.0942700779331582, 0.09529378371579306, 0.11042249548648085, 0.0826897243303912, 0.07436150764780385, 0.1651042891400201, 0.09754990586744887, 0.10004586300679616, 0.15053084971649305, 0.13256959351045744, 0.08812856248446874, 0.11249310616403818, 0.2324905517910208, 0.08539477203573499, 0.14873284048267774, 0.09140657194490943, 0.12434462271630764, 0.13081582475985798, 0.1471232875649418, 0.11236918531358242, 0.10207164287567139, 0.14857194625905581, 0.14103007023887976, 0.13070535925882204, 0.2303928200687681, 0.13573584146797657, 0.09713775691177164, 0.13443910676453794, 0.11101123318076134, 0.19175468837576254, 0.24714878095047815, 0.28781710298998014, 0.10539280716329813, 0.15289835339146002, 0.11807380563446454, 0.06524237697677952, 0.13832446613482066, 0.12664135518882955, 0.06448043643363885, 0.12457408968891416, 0.11064415930637292, 0.12919422106019088, 0.14942242205142975, 0.17593351804784366, 0.10883712555680956, 0.10468747679676328, 0.10310015268623829, 0.17660449418638433, 0.15317298365490778, 0.10357121883758477, 0.13415028154850006, 0.234190933406353, 0.1212449526148183, 0.18030309357813426, 0.10088892241141625, 0.1927328101758446, 0.07863478548824787, 0.12254612493727889, 0.23077765798994473, 0.07842191548219749, 0.11952646768518857, 0.14249652012118272, 0.08680495779429163, 0.10512891810919557, 0.08120949340185948, 0.12285776250064373, 0.08940640677298818, 0.09662105249507086, 0.1722627385918583, 0.1294805221259594, 0.12406218930014543, 0.17868818023375102, 0.20738635744367326, 0.12041046310748373, 0.11636750719376973, 0.15455344957964762, 0.06654424140495913, 0.123891307041049, 0.13255313225090504], [0.03516463968636734, 0.04694284392254693, 0.06229624577930995, 0.007927259313873947, 0.02179941668042115, 0.05075965429257069, 0.042259418804730685, 0.019598478085494468, 0.012018864492087491, 0.024861855565437248, 0.024110517131962945, 0.027605773149324313, 0.06500023497002465, 0.020610336646703736, 0.021626673539036086, 0.011871889566204377, 0.03976664399462087, 0.058222979706312926, 0.010663785106901611, 0.024774297406630855, 0.03948743361979723, 0.026998516538047364, 0.05117494147270918, 0.046548245275127034, 0.012136372338448252, 0.061287956312298775, 0.009229468946744288, 0.016389290735657727, 0.0573230047843286, 0.015498506570500987, 0.011057371040806174, 0.007545789470896125, 0.013477876782417297, 0.019774235618699874, 0.030703153195125715, 0.07661097337092672, 0.022823439678177238, 0.03212816494383982, 0.0992032785766891, 0.03421051427721977, 0.08127887360751629, 0.010887906071729958, 0.03417085390537977, 0.08602747201387372, 0.06323723814317159, 0.07059411159051315, 0.014502184764881219, 0.03644287073984742, 0.04855017803077187, 0.038806788357240815, 0.01564585044980049, 0.03070867307750242, 0.026635727612301707, 0.026466670612405454, 0.09717164295060293, 0.06025999611509698, 0.015548329700582793, 0.028957757566656386, 0.01364645711146295, 0.05267328250088862, 0.050571048698787174, 0.009261578071995505, 0.06897852649646145, 0.04998986649193934, 0.03500724331076656, 0.014839598177266973, 0.03827813493886164, 0.024096871792737926, 0.018826978680278574, 0.0998558664162244, 0.014141616344984089, 0.01340375276881137, 0.011280821952303606, 0.014794870845175214, 0.012206503173469432, 0.045054280797817876, 0.06337546929717064, 0.015547013342646616, 0.018025873095861504, 0.03307012082742793, 0.02583341932456408, 0.03539402862744672, 0.021305896108970046, 0.03274600500507014, 0.020270712906494737, 0.03712900874337979, 0.048807800813977203, 0.019791650219953487, 0.06975861785135098, 0.03336467287902321, 0.044778490239488225, 0.07089605967381171, 0.041860891439552815, 0.041207082236983945, 0.024289587612396905, 0.045882934903992076, 0.040210378755416186, 0.03924962066646133, 0.05263028712943196, 0.03506065080208438, 0.03011599988011377, 0.030623822273420434, 0.014378226594999433, 0.02217985430200185, 0.03484423884323665, 0.033843759314290116, 0.029143587952213626, 0.08189604870442833, 0.013300905519697283, 0.021073043246620467, 0.037626636148031266, 0.049532218370586634, 0.08823117054998875, 0.006137233468637402, 0.016710809465231638, 0.02488535832214568, 0.08637646293001515, 0.04015663538926414, 0.01451415242627263, 0.03169739020190068, 0.05602703004011086, 0.0441244571203632, 0.07010154266442571, 0.022615731627281224, 0.045078989650521956, 0.08508846775761672, 0.01875999879225024, 0.06029756659907954, 0.0622561579304082, 0.06900978660477058, 0.009331205942934113, 0.031702150125056505, 0.03492433311683791, 0.03672668497477259, 0.017614256790173904, 0.021027350698464682, 0.04161981473277722, 0.02039779912281249, 0.07714748422482184, 0.005127602198626846, 0.02740947127209178, 0.02722649751896305, 0.023114739850695645, 0.03927504537361009, 0.03785451874136925, 0.054273173079958985, 0.018464656247358237, 0.022535369332347597, 0.02169510379566678, 0.04247024981305003, 0.025801801289032613, 0.034556366968899965, 0.05819024717701333, 0.04871727406446423, 0.015146000842962946, 0.1279940011778048, 0.02627042301797441, 0.016856579143287878, 0.03175887565261551, 0.016979110693292956, 0.017858704119654636, 0.012316615836295699, 0.04788936634681054, 0.051814769461218796, 0.020291867932038646, 0.035271573412631235, 0.046787554398179054, 0.07378767736788307, 0.017270461755937765, 0.07241642594869648, 0.006002089648973197, 0.09479455157582249, 0.07996919924127203, 0.029902240993188958, 0.034353725878255706, 0.016533599867086326, 0.08313313339437757, 0.042793188377150466, 0.04488047066011599, 0.023218796588480473, 0.008371111970128757, 0.029071768413164785, 0.0031125629029702395, 0.017353833353679095, 0.010625743889249861, 0.025709683374900903, 0.026545071941135184, 0.014656193554401398, 0.0618994181443538, 0.05715875859771456, 0.03798079750101481, 0.015492292886067714, 0.05204026361129113, 0.028832323583109037, 0.0215192563565714, 0.03131309850141406, 0.04948110093495675, 0.07261658699384757, 0.02362281160562166, 0.05179397914824741, 0.04855101941419499, 0.01967958846528615, 0.06404737502868686, 0.010164518192011331, 0.054595467035791705, 0.015135352932182806, 0.030846086596804004, 0.03463457491514938, 0.004632059592820171, 0.0641047926619649, 0.010779635631479323, 0.05370265065825411, 0.022229492531291077, 0.041981802987200875, 0.006235435297380069, 0.01851531397551298, 0.05666771298274398, 0.03949835464092238, 0.008803042766105915, 0.013172048326980854, 0.045751506063554964, 0.05215176727090563, 0.06683580790247236, 0.04259716978828822, 0.052536415202277045, 0.02341690506520016, 0.054638235098017116, 0.08889929005610091, 0.008982326136901975, 0.02801576945265489, 0.04355947832976069, 0.05368048291919487, 0.04454729639525924, 0.039117163845470974, 0.03541414040539946, 0.014094732967870576, 0.009878994897007942, 0.003538622462656349, 0.06369178875216416, 0.005706949816418013, 0.018712589550497274, 0.02897383545392326, 0.018024098726787736, 0.049610341499958716, 0.010596983334315675, 0.05012599079470549, 0.02802289915936334, 0.06644576561770268, 0.006672462315431663, 0.05374977830797434, 0.03923076757096818, 0.09583370760083199, 0.017855598125606775, 0.04938369384035468, 0.052158952956753116, 0.017846424332154647, 0.04604372734736119, 0.020019244435908537, 0.004674068968077856, 0.07712538433926446, 0.02629306573154671, 0.02684991736896336, 0.0255858337706221, 0.023434964274721484, 0.02564943625059511, 0.07027707288839988, 0.06705804169178009, 0.015460573070283447, 0.039549400830375295, 0.04528792415346418, 0.04004125050934298, 0.03128449825037803, 0.015388358284586241, 0.04865582932585052, 0.04541393489177738, 0.011836999295545476, 0.0101477778849325, 0.02647148142568767, 0.02486682922712394, 0.11651800626090594, 0.047178977501711676, 0.016105242406151125, 0.016684840233730416, 0.06231161459748234, 0.016450172290205956, 0.017271097882517746, 0.04045274128605213, 0.03807039126487715, 0.056850211761359654, 0.048515406503741226, 0.052172761144382615, 0.022164270048961043, 0.013605594036302395, 0.032672587516052384, 0.029172527470758984, 0.04043424442144377, 0.037283015836562426, 0.03431439459589975, 0.012402461542348777, 0.08838249742984772, 0.07365770398506097, 0.06564748952431337, 0.013109816487745514, 0.013862731666969401, 0.02585765320275511, 0.012725369572373373, 0.01589919506971325, 0.00796335143968463, 0.023454680806025863, 0.025136085493224006, 0.003853884251189551, 0.011142571290422763, 0.02611978485115937, 0.020588733788047518, 0.02198384758750243, 0.030964484172207967, 0.02234634304685252, 0.06756497520421233, 0.019272450490721633, 0.01745573235010462, 0.012823411097217883, 0.03848915593698621, 0.03189750714227557, 0.006370115168725273, 0.024721985749368156, 0.020959264798355953, 0.02358908671885729, 0.011049994516984692, 0.004435269594458597, 0.02500613925180265, 0.044907839370093176, 0.00822193774261645, 0.013382429805850344, 0.014224665638591562, 0.0204560564431761, 0.0393737891821989, 0.03776625490614346, 0.03240720907758389, 0.0651973629636424, 0.04414319825757827, 0.03998546814545989, 0.04384660381557686, 0.053411983219640594, 0.014553505761016692, 0.021049360678132092, 0.03528655546584299, 0.012381129249531244, 0.03807175851293972, 0.08643422661615269, 0.0548381484778864, 0.03804587579465338, 0.011022136413625308, 0.12623276854200022, 0.10550116242042609, 0.12236129199819905, 0.13139285093971662, 0.09497953379260642, 0.09164061224354164, 0.09061906420226608, 0.14731934347323009, 0.05615505602742944, 0.1740678453019687, 0.11211907730570861, 0.18766833336225577, 0.2802674780998911, 0.11957909486123494, 0.12567124010196754, 0.12303722144237586, 0.14285876282623836, 0.17507086933723517, 0.07309850970549242, 0.1279741201017584, 0.12200834522289888, 0.105192863249353, 0.15947761892208032, 0.1232668784047876, 0.14297133178583213, 0.13074877192931517, 0.18271839325981482, 0.0994526401960424, 0.13188487025243895, 0.09162446311009781, 0.2141072332326855, 0.12810171182666505, 0.1420491212712867, 0.14957307039627007, 0.09987955407372542, 0.21752574693943771, 0.07993610030306236, 0.075272719109697, 0.1552106107452086, 0.06781452002802066, 0.25867717234151705, 0.21843235114855425, 0.05393412270184074, 0.12174885986106736, 0.15041758865118027, 0.1612814228449549, 0.13946565347058432, 0.14376737549901009, 0.11414037884346076, 0.22848602810076304, 0.1144475516464029, 0.1934462354651519, 0.12944374552794866, 0.1808073129504919, 0.15464294834860734, 0.13368864703391278, 0.11385571983243738, 0.09333562664687634, 0.11074566814516272, 0.1185291704854795, 0.10835809340434414, 0.08422450947442225, 0.18994171065943583, 0.09008571532155786, 0.18072983782206262, 0.17265206841485842, 0.16534647185887608, 0.10265322881085531, 0.15052439006311552, 0.20046809581773622, 0.1351524099175419, 0.10823204873928002, 0.09466530422547034, 0.1030743412141289, 0.08883221008415733, 0.13489401021174022, 0.151423788230334, 0.15023120865225792, 0.19683379440435342, 0.08400473876723222, 0.11385858325021607, 0.08574564927922827, 0.15458903195602552, 0.17453877574631146, 0.08384498448244163, 0.12834677153400012, 0.17649663425981998, 0.10417565783219677, 0.10257282919649567, 0.14910197710352285, 0.1809054155434881, 0.15645648246364935, 0.09531272162816354, 0.205637107736298, 0.1652267375694854, 0.24260536474840982, 0.05450146618698325, 0.18941254833979265, 0.1400835681706667, 0.16198477867458547, 0.14690507070294448, 0.10339592610086713, 0.13215472362935543, 0.1652173466448273, 0.07415898530078785, 0.11348115493144308, 0.08240402037543909, 0.14283441698976926, 0.10438326919185263, 0.09319602485213961, 0.15430734492838383, 0.1877898589840957, 0.14485409004347666, 0.08013107734067099, 0.07564249355345964, 0.09131463044988257, 0.1715995113232306, 0.10660378182572977, 0.15103561191686563, 0.14183653624994413, 0.09558658514704023, 0.1096184654161334, 0.11027266816901309, 0.24693957503352845, 0.18192059892628873, 0.12815576392625058, 0.07157150057277509, 0.133689054154924, 0.11755202577582427, 0.14380625555557863, 0.12479244225791522, 0.14639621015105928, 0.108092290881489, 0.09212505232010569, 0.09029217317168202, 0.10377186842794929, 0.1682792223457779, 0.10267234992768083, 0.12519132585397788, 0.10365558109645333, 0.1273557711392641, 0.146773882742439, 0.05725331245256322, 0.12552308876599583, 0.12204058920698506, 0.12326914471174989, 0.10071999433317355, 0.09334594716450997, 0.0949021333030292, 0.1751407313027552, 0.12696530137743267, 0.14046951888927392, 0.09501981163131339, 0.17541327167834553, 0.11786305265767233, 0.23116713709064893, 0.12401507182845048, 0.08119302535695688, 0.10331599467567035, 0.08179532018090997, 0.1696023792028427, 0.10122194061321871, 0.15911068075469562, 0.20076521273170198, 0.19344873247402056, 0.14423595821218832, 0.1713473405689001, 0.12353905237146787, 0.16046473809650966, 0.11266347952187061, 0.10894973522850446, 0.12467987329832145, 0.1485920444663082, 0.09566967854542391, 0.15669463468449457, 0.08796032651194505], [0.00984425814489701, 0.05378603243402072, 0.010723571675563497, 0.01571092026175133, 0.0439458836668304, 0.06078536542398589, 0.06360879713403327, 0.031399384407060485, 0.016024986980482936, 0.06684638626341309, 0.04358247388154268, 0.011010932104129876, 0.026115170813032558, 0.035526746684419255, 0.02366286892044757, 0.010715395328588784, 0.02588230268364506, 0.05780762127999749, 0.04690145328640938, 0.031220074743032455, 0.03530084880601082, 0.049647440402103324, 0.05030328181705304, 0.026949913074661578, 0.03141234442591667, 0.022878528240003755, 0.01399055409378239, 0.04032208597553628, 0.038219933597637076, 0.02640411986171135, 0.015712070378607938, 0.042758705227502754, 0.03244815866595932, 0.03347937583125063, 0.029572846168386083, 0.029941918328404427, 0.015739089643050517, 0.017879521574026773, 0.011650217264624578, 0.04030901060572692, 0.06566388293036393, 0.05958707258105278, 0.035956666472234895, 0.04255406924390367, 0.028487651542361294, 0.036830090318939517, 0.014407708941559707, 0.07095556719494717, 0.08730241895786353, 0.012124278299909617, 0.029396803650472845, 0.040836391770946126, 0.010312935004809072, 0.02334347739815712, 0.024972207411857586, 0.022722595803705708, 0.02209480163375182, 0.049404389158423455, 0.021741208553846394, 0.03274186594145639, 0.03230715908908418, 0.024854998969073807, 0.03583666076883674, 0.020414061910871948, 0.03729647797133241, 0.021157117128106098, 0.010259252706808704, 0.015981233346142938, 0.030397853148835044, 0.026957887557468245, 0.03391794354787894, 0.022929448900478225, 0.009076891866113459, 0.03986228011282427, 0.04193292471713253, 0.050191829047564945, 0.05555613352251904, 0.025548439705744386, 0.05853290736143078, 0.038617314238633425, 0.05565836500110371, 0.042179989495447705, 0.037385271063872745, 0.029959682375192642, 0.021273516417880143, 0.013443447915571076, 0.017743631365842054, 0.04769356828182936, 0.0329635535100741, 0.026886727893725038, 0.052042044765715084, 0.018809633628864373, 0.061033851733165126, 0.03216249881578343, 0.023978173965588212, 0.015931116749665568, 0.009553980015750443, 0.03664470437381949, 0.05234449157225234, 0.032857495093984265, 0.04369596904143691, 0.028288160550541112, 0.01959200655775411, 0.05069695765684758, 0.11482044735125133, 0.08039305292602096, 0.05110835004597902, 0.026970457418688705, 0.024928201023223143, 0.056143497183386765, 0.06760893070272037, 0.032082547034536085, 0.06026919026459966, 0.02033757065821971, 0.050037716781454425, 0.007780744095465967, 0.03955266797649009, 0.08224432037345, 0.05286902967574341, 0.028171522077172995, 0.02371413224110646, 0.04821192493130054, 0.02074774168431759, 0.01601707865484059, 0.04970210657588073, 0.021992936564077224, 0.037203505103077204, 0.07613627027188029, 0.07852386536874942, 0.010215527910206999, 0.010055317310616374, 0.06728483523641314, 0.030877835250326564, 0.04224489136998143, 0.02063767991161772, 0.010312727203459611, 0.020588418269263845, 0.017728900370587195, 0.008715898513660898, 0.06353848733540092, 0.018358689433495914, 0.0378446019520717, 0.07472733301775795, 0.007546990477879132, 0.036070775706321, 0.06803030773465123, 0.037612173174108775, 0.016421234467998147, 0.03051583342520254, 0.04971906655867185, 0.0516714391165546, 0.054414803694401465, 0.06297220236488751, 0.04975572441305433, 0.04000814478578312, 0.037145290191152265, 0.029099812265485525, 0.06681718890156065, 0.0679254469328693, 0.014668817698423351, 0.06445489637553692, 0.039314471650868654, 0.05225764587521553, 0.03279414027929306, 0.02479969327604132, 0.007354402731704924, 0.05464621466983642, 0.04026259881045137, 0.04107875430158206, 0.03072190111769097, 0.056904501348201714, 0.035268974623509815, 0.05786100162991455, 0.0448762467796249, 0.04533463450414794, 0.020797956668372666, 0.016095551229747276, 0.048953051412744183, 0.054890107296939404, 0.04147710185497999, 0.12193251214921474, 0.06233607578490462, 0.09569125595901694, 0.0069323183270171285, 0.03326859571305769, 0.014979671553841658, 0.06454842564250741, 0.063562141066151, 0.03983669594994613, 0.018282591731154492, 0.024292065961552516, 0.02894588659650513, 0.01256209793167987, 0.02549084395702396, 0.12607456131705216, 0.03472755117607968, 0.013641264622232743, 0.036176576279103756, 0.022400583439905728, 0.010586150522742952, 0.003927603264206222, 0.027022943798718706, 0.03479186272514718, 0.04261331552905696, 0.027426646689751318, 0.025565710118306533, 0.020238217864451662, 0.027682732591139417, 0.023497436993888447, 0.059383301729602475, 0.019844292663037777, 0.07909841489578996, 0.05556709186307021, 0.05611269508621522, 0.022073965519666672, 0.00407034794833245, 0.020207987433033328, 0.05305397118042622, 0.04748526820912957, 0.08050034288316965, 0.010819630181816007, 0.03626195294782519, 0.035935506357678344, 0.03224406211770006, 0.045142860151827335, 0.03577089036947914, 0.05617911009384053, 0.04436652448826602, 0.04021811405462878, 0.03140828339383006, 0.04043820706595268, 0.04252982179501227, 0.0569814709680421, 0.01188292000110128, 0.012251808108495814, 0.010118313349916466, 0.02031780154045139, 0.019951039792171547, 0.020247425584654723, 0.018714893176885586, 0.05406117159873247, 0.024424960437629904, 0.04406910901889205, 0.06262952860976968, 0.06066982448101044, 0.01742886914871633, 0.017430141401876296, 0.021267183989818608, 0.08078395695026432, 0.07199886906892061, 0.0359285988711885, 0.04308656317048839, 0.03593607632709401, 0.03527809413416045, 0.037515468363251, 0.005400235448697848, 0.025376363225015144, 0.029925833655787364, 0.0565387811511755, 0.047455470343785625, 0.04036145796999335, 0.0462847463786602, 0.02447528059461287, 0.02941216907597014, 0.045429890642740896, 0.0548148068732449, 0.056318450652595074, 0.027575881985415305, 0.01636367943137884, 0.006944906423866216, 0.011758918574612056, 0.019252097832837274, 0.05978269422692912, 0.055011619348078966, 0.061854607691722255, 0.01991810879137899, 0.03024397836998105, 0.02941517498610275, 0.017381390357123952, 0.08068979664572648, 0.048661437417779646, 0.03925547981634736, 0.02909358331401433, 0.028515780211559365, 0.03968145053035446, 0.08784579658614737, 0.030530079267919064, 0.06472734854157482, 0.02967632275872997, 0.01935361006430217, 0.04771134929199304, 0.017836188631398336, 0.07112942822277546, 0.026703638789643134, 0.07078283932060003, 0.0019725292887804763, 0.017530718951353004, 0.07004093591656003, 0.016034299873613884, 0.026715983037969897, 0.0331367054688079, 0.004013036336151085, 0.06593055397804294, 0.0447559628768691, 0.06878903202180352, 0.00702584462539692, 0.043712175850357325, 0.011666132303486978, 0.05360079915927989, 0.013413776427374353, 0.048670550143080096, 0.013993123196996748, 0.03411304950714111, 0.0063416438393427855, 0.024796758612085665, 0.009210826197106923, 0.05688747690458383, 0.03902937159208315, 0.01793852019389825, 0.06987741576241595, 0.03470512559371335, 0.04580479820391961, 0.047786273128752194, 0.03677873539605311, 0.016293367936408946, 0.061941304111054966, 0.08908949020717825, 0.0517370534528579, 0.04624337609857321, 0.02286458943438317, 0.08433449321559497, 0.030651689706636325, 0.08111909896667514, 0.038743738883308, 0.02794570053395416, 0.00541191388453756, 0.040418784001043866, 0.017948956062485064, 0.03833058230312807, 0.049972954006599526, 0.03188130033335515, 0.04320849930601461, 0.05360087379813194, 0.013671220246968525, 0.036658760226730785, 0.051538836410535235, 0.08172608246760708, 0.01781166298314929, 0.030280497124684707, 0.04444056962217603, 0.03261414868757129, 0.1047046369473849, 0.1433059581156288, 0.1004308502056769, 0.12599252643329756, 0.148960516122835, 0.18242541540946278, 0.12195077831191675, 0.15554846690169402, 0.10651965705411774, 0.10067702949579273, 0.08819704023855073, 0.10568243305065803, 0.19098927373332636, 0.109428299191807, 0.13642569445073605, 0.08145911964987006, 0.05171216478837388, 0.10499843582510948, 0.12318786978721619, 0.18072455881961755, 0.11874123982020787, 0.08224776733134474, 0.098542256546872, 0.10159126043851886, 0.06293739351843085, 0.18193726374634675, 0.10268448213381426, 0.1035439892272864, 0.1017737795731851, 0.10138648535524096, 0.14244759774633817, 0.0819011377170682, 0.0867968900129199, 0.16511943404163631, 0.10016867784517151, 0.08946292195469141, 0.11674433840172631, 0.10317935129361493, 0.10876813211611339, 0.13773411352719578, 0.1551014208900077, 0.1562977052692856, 0.11685436964035034, 0.19954790733754635, 0.19619785781417573, 0.0789928687736392, 0.07538991567811795, 0.11749383461262498, 0.12877856407846722, 0.12531184724399022, 0.15967378339597157, 0.1753628429557596, 0.0774889841143574, 0.11873107536562852, 0.07021467480808496, 0.13505615293979645, 0.13119973987340927, 0.13790234949971947, 0.14918577617832593, 0.08383023313113622, 0.10004591728959765, 0.16484883427619934, 0.09397516625800303, 0.09371007619691746, 0.07423715932028634, 0.1016994799886431, 0.09125924842166049, 0.0726885184911745, 0.15672841215772287, 0.1609224642493895, 0.09594578122986214, 0.10363249733511891, 0.12419383866446358, 0.14142957808715956, 0.13163510151207447, 0.11160416422145707, 0.07483804279140063, 0.09092592487909965, 0.16105609493596212, 0.09638487481112991, 0.21049174081001962, 0.1118117348690118, 0.1319264101662806, 0.17413454529430183, 0.13752006287021296, 0.1041715798367347, 0.17169120854565076, 0.060949557327798436, 0.1835722074444805, 0.16333547048270702, 0.11485889314540795, 0.13463684543967247, 0.06646767551345484, 0.15571808708565577, 0.11971820811075823, 0.08882325342191116, 0.14334964220012936, 0.08056662218379122, 0.15237852771367344, 0.15038583321230753, 0.06270084264022963, 0.15229111883257115, 0.1435445174574852, 0.09713696981115, 0.12352017552724906, 0.1839442481952054, 0.27709236847502844, 0.09516083834958927, 0.09217967438910689, 0.10395550036004611, 0.19219921023717948, 0.16760722840470926, 0.12092952882604939, 0.15152772622449057, 0.08839813087667737, 0.14680516320679868, 0.09708734854523625, 0.1204292042446988, 0.12921256864709513, 0.20621910079249314, 0.10463024915329047, 0.15806693104760988, 0.1785766833594867, 0.14010275714099407, 0.11845594298626695, 0.20311670298022882, 0.09710184205323458, 0.16075914087040083, 0.14787586432482513, 0.13104122052235262, 0.1352743969431945, 0.16034148899572237, 0.152938631230167, 0.1337376915450607, 0.09160737759832825, 0.12877450643905572, 0.06742130219936371, 0.15458429578159535, 0.08625842497817107, 0.09454888118697063, 0.1491137564714466, 0.1776660079402583, 0.0824609494635037, 0.13748278415628842, 0.21466416120529175, 0.1260736385094268, 0.16693435236811638, 0.17644711477415903, 0.1344969586602279, 0.10022140680147068, 0.14262952655553818, 0.14965068123170308, 0.11733751371502876, 0.1508307350533349, 0.15888923406600952, 0.17018872845385755, 0.19170197977551393, 0.1347643014575754, 0.12261153571307659, 0.14140207027750357, 0.06926648997302566, 0.12365759243922574, 0.09115538506635598, 0.15655150450766087, 0.1017756387591362, 0.13187501792396816, 0.11762481901262488, 0.19143162428268365, 0.09753053369266645, 0.15793411460305962, 0.1747450775333813, 0.1548326395984207, 0.15571883347417625, 0.170211595083986, 0.1837630793452263, 0.12437504822654383, 0.22189059986599854], [0.09403174250785794, 0.030061974921928983, 0.018295076775497625, 0.02120507089421153, 0.04580377361604145, 0.015225933964497276, 0.006187604091662381, 0.03753752414403217, 0.04801547547270145, 0.033006681195859394, 0.056396200587706904, 0.012857895943203142, 0.017737867210858634, 0.02118039257558329, 0.09241317185972418, 0.0864419551300151, 0.057007791341415474, 0.07311266394598143, 0.022535800202084438, 0.014014251929308687, 0.03244185507563608, 0.03228027213897024, 0.07467457013470785, 0.02630061443362917, 0.025363501593736664, 0.03690443400825773, 0.008071118067683918, 0.05291607929393649, 0.01748030210312988, 0.016897520249975578, 0.08830495444791657, 0.01780201930419675, 0.02497593765812261, 0.051743903263871155, 0.03174316417425871, 0.03868960535952023, 0.024728633696213365, 0.036390477658382485, 0.03478723850899509, 0.01912940852344036, 0.0271051059077893, 0.06964708705033575, 0.02006070631822305, 0.042930293163018565, 0.041659410643790445, 0.037315514271280596, 0.010280985335287238, 0.07171478681266308, 0.018355269617001926, 0.01283060187207801, 0.023084102298266122, 0.047783993251089535, 0.023196464304679205, 0.03267977320189987, 0.04298654032338943, 0.037592119071632624, 0.044176968945456405, 0.051569529942103794, 0.024408188748306463, 0.0411863699555397, 0.02758611090082143, 0.03957081539556384, 0.025091364946482436, 0.0739081444750939, 0.029895879727389132, 0.03629021732402699, 0.020280879057411636, 0.0434096645829933, 0.029078126286289523, 0.034967294561543634, 0.08828920565013375, 0.0007279272259828368, 0.012620529126642006, 0.017693036402176534, 0.06755008136055299, 0.06666323609117951, 0.020679783009524857, 0.042658624704927206, 0.007743855539177145, 0.07321605232677289, 0.05289246627528753, 0.05904328104640756, 0.07405898280973945, 0.03361302348119872, 0.025964217127433846, 0.014139991253614426, 0.028025516608197774, 0.016766859850447093, 0.03410641682733383, 0.05609438481873699, 0.01881159798774336, 0.027415187929623892, 0.01345058695213603, 0.0739034286567143, 0.02130575361661613, 0.028371114849245975, 0.05403498014701264, 0.018067082223881568, 0.017788736981206706, 0.05108435704771962, 0.015368848706462553, 0.02203849849424192, 0.023933653586677144, 0.019359326721834283, 0.06609070181314435, 0.012373817186536533, 0.06067383462297065, 0.009656229305879345, 0.032523130000169785, 0.036047213577798436, 0.019137771467545202, 0.05624518583395651, 0.01153948628676257, 0.03159597635801349, 0.004276398253361029, 0.07300499400922231, 0.03528751220021929, 0.09085554722696543, 0.0473336393811873, 0.03915914480707475, 0.015124796623630183, 0.07951519824564457, 0.04197734501212835, 0.0223634217732719, 0.009922222666708487, 0.030610679050109217, 0.08196185981588704, 0.03696892876178026, 0.01011994861931141, 0.019988623846854483, 0.04702542502699154, 0.021872423655752624, 0.06734141827161823, 0.040263148423816474, 0.027025751237358366, 0.015896290939833437, 0.015827909876991595, 0.05380775573264275, 0.06179065576621464, 0.004798267593806875, 0.048183029517531395, 0.05171011561261756, 0.04616334967847381, 0.029708855120199065, 0.058669306470879486, 0.07793066969939641, 0.03150604332664183, 0.07503152026661805, 0.02250096251788948, 0.07191559925143208, 0.009759455686435103, 0.0419919301223542, 0.0016367022700641038, 0.06405471677758864, 0.015031723671459725, 0.039845496549138, 0.0053674287046305835, 0.03798414946400693, 0.011172419197724333, 0.10945085369582687, 0.018461102420198064, 0.0422295395151845, 0.02394794692684497, 0.03117497930569308, 0.045765653518693786, 0.010458522326579052, 0.024135399011096785, 0.01015462091059557, 0.061979709193110466, 0.01832296117208898, 0.03123411363256829, 0.02425956752683435, 0.02800680770139609, 0.031931583170912096, 0.03057049959897995, 0.04957836553720491, 0.02399218232104821, 0.019981482265783206, 0.028537130315921137, 0.0393332263587841, 0.01837753743997642, 0.02832816867157817, 0.023450282202767472, 0.0350941772173558, 0.0608666878459709, 0.0520690504594573, 0.019923269050195813, 0.04433778853022626, 0.040505863792662106, 0.013310984309230531, 0.05155263781281454, 0.0098941771180502, 0.015344786158363734, 0.026288000467632498, 0.05712610070726701, 0.04784279509580561, 0.013895135106784957, 0.012500687967985868, 0.06388657579996757, 0.021694886664460813, 0.04482628285352673, 0.0073697537383330715, 0.021100707119330764, 0.02322981260450823, 0.03802983183413744, 0.029951753693499734, 0.029583146329969168, 0.07123445865831204, 0.029245782111372267, 0.04238957539200783, 0.028362132741936615, 0.030409072725368396, 0.07330036030283996, 0.014247744310913342, 0.02338381460867822, 0.08444335737398692, 0.012841734935396483, 0.029742456174322536, 0.02715626744819539, 0.03208608559465834, 0.03182299381920269, 0.054565160269183774, 0.03298686118796468, 0.0749203423038125, 0.031108177533107143, 0.003710272314492613, 0.0662078983815653, 0.07523666854415621, 0.042868292025689564, 0.027646232496148775, 0.050672218270067654, 0.009079407534695097, 0.02509114102992628, 0.04106747026422194, 0.04325621049585087, 0.047607923591775556, 0.028089836638953005, 0.028898684307932854, 0.04770363434883101, 0.08028330667210476, 0.03022553239549909, 0.0447347790135869, 0.07965271015252386, 0.01607672866832997, 0.05876105797610112, 0.04291115847549268, 0.02170779918586569, 0.08546823702220406, 0.055498553040836535, 0.02479443802232189, 0.06111146256859813, 0.03036515454628638, 0.03280625891472612, 0.025688301040125743, 0.0921737439930439, 0.026866482105106115, 0.030195052602461407, 0.04476989320080195, 0.04993103411314743, 0.026504161368523325, 0.034331520819770436, 0.01340315820250128, 0.027334635644885044, 0.02339267627602177, 0.02559571832950626, 0.033545967257980785, 0.027570219610684683, 0.03146109038165637, 0.028198926410238658, 0.05771331848310573, 0.016107973509601185, 0.022440676377820115, 0.0629137669290815, 0.04873715514051063, 0.019203886223424758, 0.030313297507486174, 0.011861522399288203, 0.02961858282131808, 0.033358705163534196, 0.0277498380081462, 0.002138009136875293, 0.03380676219239831, 0.04489913037312882, 0.00852096897350358, 0.07168169465980359, 0.04440988966130784, 0.05851078711982284, 0.12591282571000711, 0.01763691137810903, 0.08988632102097784, 0.08602758736482688, 0.03178209172827857, 0.013560312850001668, 0.0012862046881179723, 0.020997323827551942, 0.02184441712285791, 0.06050825172236987, 0.03361261636018753, 0.10546593288225786, 0.016826299518080692, 0.05563589192128607, 0.061992275661655834, 0.02133435386765216, 0.006326952708020274, 0.0178505158983171, 0.01714111601800791, 0.03523458646876471, 0.052420972646879296, 0.02202722802758217, 0.05209435981565288, 0.015345249258513962, 0.013831577579756933, 0.0314516383888466, 0.06661173528326408, 0.04374403306948287, 0.02546237432397902, 0.04438605611877782, 0.02778217359445989, 0.05832277863685574, 0.03203033376485109, 0.057099495349185805, 0.0474196911922523, 0.006387925016627247, 0.0868653202695506, 0.027262794053448097, 0.041344488970935345, 0.019393775944731066, 0.03487380600667425, 0.03824111746091928, 0.062220358422824314, 0.03695015709048935, 0.04692343782101359, 0.05491210879491908, 0.04606130140434418, 0.05096485346023526, 0.05338312851797257, 0.09635481570980378, 0.029836416311029876, 0.026908775192818472, 0.015093936850982053, 0.05883433297276497, 0.026699180814570615, 0.043395082865442546, 0.03226206025906971, 0.049849253680024824, 0.01632817678286561, 0.01620091075476791, 0.02998496119731239, 0.01852521549777261, 0.01906106647636209, 0.010000872508888798, 0.028558626305311918, 0.14588745816477708, 0.12475580136690821, 0.0882143225254757, 0.09056043199130467, 0.14588920878512518, 0.13224642085177557, 0.0902140127228839, 0.14162673322217806, 0.19576975650021008, 0.12286669202148914, 0.22809494765741484, 0.19651548005640507, 0.11267838015088014, 0.07892793975770473, 0.1311940944620541, 0.07972529982881886, 0.1522293450044734, 0.14555588524256433, 0.17196129262447357, 0.08432737538324935, 0.12898449945662702, 0.1431238664580243, 0.1594662738165685, 0.14065671313021863, 0.09935330266931228, 0.2795481766973223, 0.18459336193544523, 0.19166029058396816, 0.11149409905608211, 0.08953718082713229, 0.14612645176904543, 0.17738117251013005, 0.10057043164436306, 0.16379516438714095, 0.08893173081534249, 0.14344588560717447, 0.19475903787783214, 0.1199475529470614, 0.08677303272166423, 0.17301064703081334, 0.06426395662128925, 0.11795785757047789, 0.21027881652116776, 0.11793550662696362, 0.1617230134350913, 0.09456418215164117, 0.08246538708252565, 0.14698937189366135, 0.09998242676790271, 0.08873079624027014, 0.16778955076422009, 0.1630420990820442, 0.09947886557451316, 0.1328557181571211, 0.16299176535436086, 0.1236186038170542, 0.12299085035920143, 0.1656595750578812, 0.0821145980485848, 0.12518254561083658, 0.12103060340242726, 0.17767875082790852, 0.20526324851172312, 0.11729710016931806, 0.09024212442870651, 0.20218306593596935, 0.2093537968716451, 0.16096009580152376, 0.10954959411174059, 0.15280042721756867, 0.19066124276391097, 0.15280149930289813, 0.12044434914631502, 0.15700560728354113, 0.1704295269612755, 0.13804325408169202, 0.10461036807724408, 0.1140101815440825, 0.11166435027761118, 0.1964861402021987, 0.12908835602658136, 0.13867193034717015, 0.17688339922044957, 0.16438546271196433, 0.16841665282845497, 0.07766417507082224, 0.10520399122365884, 0.10083537921309471, 0.10756782402417489, 0.14076294457273825, 0.13119532939578804, 0.12326077158961977, 0.14867458146597656, 0.2070831744266408, 0.10730037266122443, 0.07692896202206612, 0.192277567461133, 0.15103439055383205, 0.06790237674223525, 0.11880632489919662, 0.10203600621649198, 0.14508059860340186, 0.09527721389063767, 0.14774363142039093, 0.1303228690688099, 0.1135061928736312, 0.16829510006521428, 0.06621566082217864, 0.1824935810374362, 0.12779084779322147, 0.1077594965962427, 0.22425209172070026, 0.10038729504282985, 0.13397646801812307, 0.09990620692925793, 0.17357262330395834, 0.1531163938343525, 0.10609508412224905, 0.12894964989806923, 0.1273803205362388, 0.1563270315527916, 0.1473322356385844, 0.20409935739423546, 0.07052221401993718, 0.09124216290989093, 0.17600936469222817, 0.18718470074236393, 0.1674960029444524, 0.1120829860280667, 0.11578487631465707, 0.17592775050018514, 0.18489843127982958, 0.14917049556970596, 0.11214545874723367, 0.10494187993130513, 0.08295456333351986, 0.2447509467601776, 0.16301802465958254, 0.17126473571572984, 0.08322700871420757, 0.0814818370022944, 0.11982632588062968, 0.11282049931053605, 0.1413274857082537, 0.13340716356677668, 0.1807102281600237, 0.05374650776918445, 0.18562020254986628, 0.08346841790314231, 0.17955021826284273, 0.1146539891404765, 0.17859351102794918, 0.10124045783387763, 0.11185327478285347, 0.12830753863922187, 0.1881710056747709, 0.07525212557188102, 0.07050810049154929, 0.15513939170965127, 0.22281910718551703, 0.12649238961083548, 0.09683813620358706, 0.07546287854867322, 0.1104392349453909, 0.13072498249156134, 0.12024123647383281, 0.12756234434034142, 0.13968463029180253, 0.19127686401563032, 0.08777211446847234, 0.09327751012252909, 0.0979944955823677, 0.1079283296795828, 0.12091698949890477, 0.08647968167705194, 0.12185616338891642], [0.025491374910676053, 0.052766441966273954, 0.03610343359676855, 0.05350227587457214, 0.054202049039304256, 0.023972686313624893, 0.12968311911182745, 0.023311465812314833, 0.03803649165534547, 0.04720133523057614, 0.0383910601293402, 0.011247883317992091, 0.03749961778521538, 0.023451130371540785, 0.05937690314437662, 0.03857953680147018, 0.02947384790916528, 0.0241550697412874, 0.05278235361246126, 0.03562012328101056, 0.06785067237381424, 0.013180631794966757, 0.08520056174269744, 0.03023823457104819, 0.05220548688833203, 0.011176085831331355, 0.020522222089182054, 0.05344716526035752, 0.023126241019261733, 0.029547065230352536, 0.05494012211316398, 0.02412454753981105, 0.05638733892036336, 0.06431325897574425, 0.07741272356361151, 0.04047880042344332, 0.02150052709371916, 0.02157610741310886, 0.030014877806284597, 0.06329090347779648, 0.01633494008066399, 0.03024930486987744, 0.04913148237392306, 0.0812550705990621, 0.03932393042902861, 0.03651445957698992, 0.0012329194391246087, 0.013381435752048023, 0.03241291216441563, 0.02368955231005592, 0.044492338451423814, 0.053856440620230775, 0.045194530593497415, 0.034820982055472474, 0.04945549302335296, 0.03025983912604196, 0.007945020816155841, 0.020684341068512628, 0.009970713323647422, 0.028350765584036708, 0.038295152597129345, 0.053160314581223896, 0.023002128482663205, 0.01781925409367042, 0.021781740843185356, 0.0225907666276076, 0.04059439225654517, 0.0484957900563521, 0.015187688338171159, 0.024527478597259948, 0.01957039861008525, 0.035825973842293024, 0.031992468118135414, 0.03961386165714689, 0.033814422852758846, 0.017415498616173863, 0.05709656407790525, 0.025794133843321885, 0.024786924943327904, 0.026374934374221733, 0.019353864514934163, 0.09365043296877827, 0.0456212137692741, 0.017751736466639807, 0.046654089952686, 0.00831535759581519, 0.021594829890610914, 0.05629360270021217, 0.006571894519895847, 0.0315605262959642, 0.06798122251140219, 0.014847175717087728, 0.03418142208829522, 0.05292289178552372, 0.04841976699286273, 0.00762873952875712, 0.03735276923647948, 0.03580864405791674, 0.05662676339436855, 0.08499802582498107, 0.016641230788081884, 0.056256961809205155, 0.030904779875917093, 0.012941612745635211, 0.046101138195289035, 0.009950141838219548, 0.05903300124087504, 0.04612169780635408, 0.04037300663601075, 0.025577864376828074, 0.03636081210736718, 0.011651193506882658, 0.021702771241377507, 0.03444523311087063, 0.02472599589132837, 0.06991294385599238, 0.06850311772099563, 0.030346952844411135, 0.039670838242662806, 0.0437510457289006, 0.034437969393496, 0.028202573535963893, 0.03885786847344466, 0.04719353547053678, 0.018899290157215934, 0.04373104251655085, 0.025714441601719176, 0.03893655478688223, 0.0429836395861847, 0.008164777952645506, 0.0016952512544646326, 0.03570600885099598, 0.01695360116926687, 0.04763493946354304, 0.025527305036251034, 0.04792758822441101, 0.0338226297338094, 0.03768815213282194, 0.01312991215049156, 0.013127681466617754, 0.046162291163844724, 0.06326617087636675, 0.02320363133081368, 0.025981635121362548, 0.06044154494468655, 0.05454437674156257, 0.015945360896044543, 0.05046946522114532, 0.045170045657349486, 0.07339347566344909, 0.030533336236008575, 0.03444567076595766, 0.02401307950328503, 0.06696050906819956, 0.045330322414104424, 0.01512891024218074, 0.024718752530004297, 0.0320841483771801, 0.03817348787561059, 0.034982259651379924, 0.04853260058111378, 0.0208989973179996, 0.005776225697315697, 0.05547063471749425, 0.1004536896944046, 0.011286895688889282, 0.043364630213805606, 0.08789051204387631, 0.02890981567491378, 0.01754369423724711, 0.05468719818496278, 0.04931839502283505, 0.04002224813614573, 0.019797599275729487, 0.018372292364282266, 0.03662568164457168, 0.02474491684032338, 0.014656817806618554, 0.06507331319153309, 0.030491864175668786, 0.03169054039088743, 0.04186308989301324, 0.08582250694079058, 0.04958064880754266, 0.016766771640894667, 0.008912376809998282, 0.02388530796659844, 0.03239702765962907, 0.032109528979552646, 0.04306055831589869, 0.07424408037747655, 0.04273574360247169, 0.0213108392365809, 0.04973333954278912, 0.040923044085502625, 0.014190379264099258, 0.04059107761297907, 0.03031887506533946, 0.097020499275199, 0.05592382486377444, 0.021860038695324744, 0.01591321360319853, 0.01627670650902603, 0.0315199668652245, 0.043318530544638634, 0.03331023740715214, 0.04415336949750781, 0.0399466084449419, 0.037657336464950016, 0.09802272942449365, 0.015056359581649303, 0.026072314541254724, 0.033535168373159, 0.01850134802849165, 0.03497561340087226, 0.025944290250273686, 0.04299759026616812, 0.03942717631746616, 0.08970070776662656, 0.051260277429329495, 0.02836631251765149, 0.008882997091859579, 0.013139216561934777, 0.018685907857226472, 0.04725966210077916, 0.07708834989794663, 0.041641310722168, 0.03579918867243188, 0.06220323219895363, 0.04495635123125144, 0.02171395349848483, 0.017431271162682345, 0.05058784244049873, 0.009462679736316204, 0.02037544478662312, 0.016452085758958544, 0.011870059217991573, 0.06541617693645613, 0.05166446716923799, 0.020056467170694044, 0.036881421493100267, 0.02814612111874989, 0.05422190297394991, 0.09666156103568417, 0.007069032955249506, 0.06525578482874803, 0.020426940505525897, 0.013187426475009747, 0.029927455354481936, 0.01572014155265476, 0.006495702670820589, 0.04021207509296281, 0.053504572715610266, 0.05846972218049424, 0.012346219470990556, 0.02496462987203683, 0.01820952368767134, 0.014776109351909586, 0.009699404489115944, 0.033440546664808474, 0.03789433856893863, 0.04784055932291916, 0.028137288289144635, 0.022804915672168136, 0.012957335250186068, 0.06280316572104182, 0.03281732921355537, 0.038470119637038024, 0.041258250562740226, 0.03675830131396651, 0.04762250191665121, 0.021646218740248253, 0.024379664832460027, 0.08158639246331793, 0.012277154784117426, 0.03535202730979238, 0.007238880448442484, 0.019817831493648033, 0.017434112528072934, 0.03696322228227343, 0.017801047302782536, 0.06025321755026068, 0.06985752111566917, 0.01862332657245653, 0.0394137006119958, 0.03694984496438077, 0.025910126012084738, 0.046852636084492714, 0.04563945957592555, 0.03866635535710624, 0.02240239512840552, 0.039529350120574236, 0.012572912931708353, 0.020734712115621994, 0.016981261649302075, 0.03890282481110521, 0.015243850681664688, 0.09159609356096812, 0.020879501310576285, 0.047669164769883664, 0.017787939702559794, 0.05703144507216556, 0.02008873999251851, 0.0121497021588896, 0.03844173312453287, 0.03135331527196935, 0.042365361869867356, 0.02577005772452269, 0.06141819432377815, 0.011061418502192413, 0.03087230518992458, 0.02750663409408714, 0.0055284399755432135, 0.039633471319185834, 0.020976860907727053, 0.023762121630300368, 0.052465067245066166, 0.021657207614875267, 0.04181276634335518, 0.02223117190546223, 0.051702651727412424, 0.026341430011338422, 0.04315286961251071, 0.03615896490269473, 0.010041759332775005, 0.020734737560685192, 0.026721029642171094, 0.009637180283399565, 0.032643946552915235, 0.023035581955420117, 0.07743913893188749, 0.013659801350773444, 0.07094891755176441, 0.02208723427195634, 0.05873996910772153, 0.04116592908810292, 0.0544456634670496, 0.062211415331278525, 0.018283992905968, 0.035888494058911286, 0.04256106833262103, 0.02620354151752378, 0.054409477194505076, 0.07628141569771937, 0.02213299467361399, 0.026347192469984293, 0.0319202855628516, 0.013507541485263832, 0.03202233383698123, 0.045367258467844555, 0.03702927427366376, 0.03882222842159016, 0.11928416283002921, 0.1042935736477375, 0.167905471686806, 0.11978883003549916, 0.11586731831942286, 0.08400152251124382, 0.25714254326054026, 0.10931647662073374, 0.12918389375720704, 0.10389988762991768, 0.14059909193643502, 0.12532152315335615, 0.10005145413534981, 0.1159830085401024, 0.19182927294501237, 0.12790105545095035, 0.06744987530899899, 0.10636960582009383, 0.15977913274296693, 0.1642913499048778, 0.1606408722166504, 0.10730915968971592, 0.14221902643995626, 0.11110948505146162, 0.11738839027072702, 0.23343317263892718, 0.11581648247582571, 0.1908144559711218, 0.15776988198714598, 0.1182432086872203, 0.133095241018704, 0.12004435275282178, 0.12412237535629954, 0.18603219544248922, 0.2425957838339465, 0.1403976756014994, 0.056971964692430835, 0.10369028816265718, 0.1561863169606243, 0.09638218102710587, 0.09924300001668078, 0.1106531023979187, 0.19460286625794002, 0.11091040287699018, 0.0791311813518405, 0.11442539069269385, 0.11016064882278442, 0.10939048443521772, 0.11923082997756344, 0.17366465979388782, 0.08034188460026469, 0.1253996089633022, 0.11604354743446622, 0.16990880561726435, 0.08430029505065509, 0.10474521334150008, 0.1402299553155899, 0.09568094901208367, 0.13987508150083677, 0.16189267433115415, 0.06207825283386877, 0.1748658703374011, 0.07918585770364318, 0.07378123807055609, 0.20179620598043713, 0.13207924339388097, 0.15335948579013348, 0.2502676264515945, 0.13449900783598423, 0.12417458184063435, 0.10595894285610744, 0.11150357819029263, 0.12623095006815024, 0.09420650598726102, 0.14814654551446438, 0.055647114890494516, 0.16849914911602223, 0.16452962426202639, 0.20797734787421568, 0.11443149750786168, 0.1134321918444974, 0.14240684493311814, 0.09572892143790211, 0.10497973539999553, 0.08607589227280446, 0.10620329688702311, 0.12125636557383196, 0.09524484098489795, 0.1592327356338501, 0.11265345755964518, 0.11890456319919654, 0.09164017119577952, 0.12038193749529974, 0.16744006451751503, 0.17518670883561882, 0.10065192370010273, 0.2477269470691681, 0.16761889920703002, 0.14337641719196523, 0.17482802165406092, 0.07783471127705914, 0.11076751018741302, 0.08113265609634773, 0.12245171357478414, 0.11578518844076566, 0.1493107351873602, 0.13190867326089314, 0.1376507758562054, 0.10904288451586451, 0.10945100297353097, 0.13666529873652117, 0.21454046427139215, 0.09533586645764963, 0.11959689962012426, 0.13721100373991899, 0.0858729560194271, 0.11782926161374364, 0.08983355135257755, 0.08599979457046304, 0.17629652071212018, 0.06600013095885515, 0.13895774286772522, 0.13914490996726922, 0.09239125517862183, 0.15052994047956808, 0.16604616359940597, 0.10470241813787393, 0.10324674339166709, 0.11994401099426405, 0.10044614438499723, 0.09544835399304118, 0.18544925243726798, 0.11181679674025093, 0.10235751646437816, 0.07177210266568831, 0.11213072096662861, 0.06629543618432113, 0.13366412477833883, 0.09237597457000188, 0.0765419527888298, 0.18727315456739493, 0.10456659578319107, 0.13120192475616932, 0.11316676251590252, 0.15055606407778604, 0.15350900776684284, 0.1808756414268698, 0.14260516714836868, 0.1074843302901302, 0.11347478348761797, 0.1064453778256263, 0.11590925178357533, 0.16981060802936554, 0.21773815554167542, 0.12767956805016312, 0.12458162142762116, 0.17746537870594434, 0.08786250890365668, 0.16686341831726687, 0.10903973611337797, 0.10258442535996437, 0.1956317831895181, 0.06390281314296381, 0.14631744580609457, 0.147935276851058, 0.11984584054776601, 0.13669984973967075, 0.17044004425406456, 0.1552237064710685, 0.08756699333233492, 0.18245760511074746, 0.09977574500122241, 0.12589951285294124, 0.14378034908856663, 0.11864631277109895, 0.19685480184853077], [0.023044117925954715, 0.058847883317087374, 0.024032003844955137, 0.03258891736290284, 0.04247640412566917, 0.015730892940025245, 0.014461557480639644, 0.0576848675097738, 0.04714078615818705, 0.052433077711611986, 0.05400687522654023, 0.07237537458006825, 0.04786787714276995, 0.020447564577417712, 0.022477961877094846, 0.05573413361396108, 0.05261539328577263, 0.014375363177220737, 0.025949964499367133, 0.016469831146033745, 0.023315827096147195, 0.08075309717761618, 0.025264752696135213, 0.05221125782866563, 0.01597474655136466, 0.05613191119794335, 0.014383877095367228, 0.02989080428544964, 0.040961859681244404, 0.012393140167530094, 0.04532108076715043, 0.0645435673317739, 0.020286203860970478, 0.03755671989970973, 0.027301426444734846, 0.024359961871856024, 0.04510019386985472, 0.050051263733101745, 0.011780127882957458, 0.07206667507333414, 0.03812266221003873, 0.009137406163582844, 0.02418740532760109, 0.04386755697695272, 0.010735316268567528, 0.018461026085008467, 0.03524319029280117, 0.05632342431428177, 0.012585982364336295, 0.05465281003021768, 0.05841861492288964, 0.046545252935694795, 0.011798456810148699, 0.015969869580918124, 0.01998730918525585, 0.019994701824284027, 0.03857728745788336, 0.008913524382348572, 0.010207635699771345, 0.0275145865245057, 0.01187494891096971, 0.017020036532942737, 0.041230406878249984, 0.030318389912801127, 0.041087612576250515, 0.029659793645675694, 0.01876575107287083, 0.02533811590235148, 0.09251479604946715, 0.019694953890783445, 0.011082427642707313, 0.04630404052191547, 0.008440303882317883, 0.03187185851857066, 0.03193510137498379, 0.03533693329830255, 0.05290035085220422, 0.06399136874824762, 0.026347938858504807, 0.04735096577288849, 0.04413902526721358, 0.03683146774502737, 0.013050046882459095, 0.011333769736146289, 0.02501663958121623, 0.0741664966834443, 0.023794828714536767, 0.013637403757976634, 0.02678687807305583, 0.03126125503331423, 0.05050962092354894, 0.025807528124590005, 0.05986783680106912, 0.022979270334222486, 0.06916801418576922, 0.06368335456188236, 0.1021714418062142, 0.04506692529789039, 0.03562547013695751, 0.02587076080297785, 0.03773808213216918, 0.012040780325021063, 0.03622547829789775, 0.06378626118281058, 0.029140178313744918, 0.011898628934951765, 0.015393250522070696, 0.023837125194924216, 0.025521069299429655, 0.06930325978568622, 0.001946915015910885, 0.044852650724351406, 0.008430326024868658, 0.0016573724611329713, 0.02902129219312753, 0.011622593255846627, 0.06177415379456111, 0.0664197505850877, 0.03750137519091368, 0.029222301407051936, 0.04194376431405544, 0.0266500888059714, 0.03401355591735669, 0.01724079281224736, 0.039404302901987515, 0.02076894081463771, 0.04562552246664252, 0.06072908772953919, 0.010915309556626847, 0.020423787014026726, 0.02071651041374675, 0.055045254328953366, 0.010813350340218415, 0.014432599302381277, 0.01520574585135494, 0.004837480132534567, 0.028941235238952295, 0.017476922998737012, 0.006241788081492164, 0.026447133892881017, 0.016493690133626972, 0.039904081262648106, 0.05422008789277502, 0.07199559174478054, 0.050997433319155655, 0.022169476108891622, 0.03532211409349527, 0.07044165834252324, 0.032151391197528155, 0.06453758265290942, 0.052152537408151796, 0.1480130912469966, 0.027851869318900362, 0.04340859589033893, 0.0338463784594621, 0.009888259444518812, 0.08544452900865249, 0.09818329116595642, 0.013789826471890722, 0.026452385753925358, 0.05998254314597164, 0.02695779425890318, 0.055941948534122536, 0.02228109003044665, 0.0497813933928098, 0.02598497181731675, 0.03997571759724191, 0.02056797400915197, 0.02599007779333208, 0.04272485990077257, 0.026698648164580976, 0.040429185942879746, 0.03959150053560734, 0.04764452037800636, 0.07514562271535397, 0.0397664777535413, 0.008465760819880026, 0.06505081975566489, 0.024818771984428167, 0.04821201653352805, 0.01389676274266094, 0.0364933842793107, 0.021677441529131362, 0.01477289479225874, 0.02719383793217795, 0.023050681055922593, 0.03207133763602801, 0.03826139547995158, 0.09584751578846148, 0.04281663515471986, 0.03868775295891932, 0.035020274575799704, 0.01593457897459822, 0.03110766184649297, 0.009764900929959757, 0.07524593733251095, 0.05006003040554268, 0.023214381021846617, 0.012896075412364942, 0.0032918068339183393, 0.01090307641840939, 0.06901467205690485, 0.011314671519877655, 0.011840624368882604, 0.02269974274427763, 0.019361647311598063, 0.06631399411708117, 0.05828926579228469, 0.040656776766159704, 0.0400600662854101, 0.030905899458697865, 0.059964616250778945, 0.02204210151519094, 0.030354884918779135, 0.03071531593533499, 0.06241090462676116, 0.037875668677900515, 0.01357355700539691, 0.04802595544606447, 0.030227171057569127, 0.033758151943662336, 0.0015795650625867502, 0.014122089803484934, 0.0625767589413694, 0.03840091924316116, 0.02971947080056582, 0.013859434834947544, 0.038566298583256345, 0.03124196089005896, 0.0582497004153473, 0.010176670754195323, 0.04380769322493246, 0.029967156438423053, 0.015351001539134553, 0.024257945828139782, 0.013839515591306346, 0.023935904626601508, 0.0775322135803955, 0.02292168985253998, 0.028813233000359366, 0.05776575566934688, 0.05594525299966335, 0.046597771546138186, 0.02873444151399391, 0.017367602525545017, 0.012108978183407868, 0.004114080378453114, 0.013946985360234976, 0.02487960264885, 0.04217822191172412, 0.02068141658258225, 0.009555436321534216, 0.07275354250201158, 0.01729836650857968, 0.015931936080700586, 0.08278690411576203, 0.0587723148720605, 0.03588434820994735, 0.056288635823875666, 0.021354131467108215, 0.04617436908717666, 0.027229968225583434, 0.0275873797613063, 0.03425162671399968, 0.033120261172630956, 0.012949996893959386, 0.025954960213441933, 0.08116167025374514, 0.02025525757510747, 0.012135925353504717, 0.030708985203610997, 0.01539522675531251, 0.03447877648951752, 0.010821214561084551, 0.011692909839829164, 0.027961111760565212, 0.040794482055519304, 0.007675400685652026, 0.049797009876263995, 0.019823073176667094, 0.033505709775324376, 0.034856656034077914, 0.05973540033612933, 0.011684020182916095, 0.06032837887427636, 0.08645463694951364, 0.02234703515257154, 0.012243060943936663, 0.07987406863165752, 0.011411757158514644, 0.04604685878647225, 0.014015526726974972, 0.05931302585772105, 0.004223851229263735, 0.02388792541543288, 0.019827595612566386, 0.04352446931547352, 0.01987168172906552, 0.04963652616632836, 0.026333357140954052, 0.08271409730826106, 0.01612921165568488, 0.04805879993364215, 0.06187388487160206, 0.051603341342083046, 0.021530450488041555, 0.035418221793536625, 0.025245022594130466, 0.03021295235625335, 0.008575397660024464, 0.044520758890679905, 0.013843630058025675, 0.029842831859631196, 0.03901387724493231, 0.053892698138952255, 0.035232645858611376, 0.018206762050145438, 0.04390648453097258, 0.041427548442568095, 0.0307322284206748, 0.038878862346921644, 0.023071600290547525, 0.030341178511402438, 0.019819246239161918, 0.030621874877916913, 0.040527878861342154, 0.02721514562810106, 0.005287753002318952, 0.04875270037778786, 0.03908531341169562, 0.00813697837293148, 0.008359173994644411, 0.010020670464395412, 0.09584368206560612, 0.013030495744065514, 0.03605913543807609, 0.004721172020903656, 0.020000684806810956, 0.03350912280646818, 0.054214154104036946, 0.026166295034012625, 0.012337048222044749, 0.04984658703740154, 0.07629624847322702, 0.06578692847064563, 0.044547381212136576, 0.06473426281341485, 0.02620789940868105, 0.05934834360544171, 0.04195550636255315, 0.029956971627793143, 0.03981429072363036, 0.14039456791111402, 0.23612291259425028, 0.11203091525073562, 0.19522307440638542, 0.13909529548670563, 0.10316981787660293, 0.0984031907948, 0.1311157372381006, 0.11337477421121937, 0.12547895684838295, 0.13661991831447395, 0.16463034600019455, 0.19233684428036213, 0.0875463726531182, 0.12272854229169232, 0.18360606634191104, 0.0929455097232546, 0.11941357302878584, 0.1930469311773777, 0.19540371399905, 0.14864051900804043, 0.2145740246134145, 0.12570782671017305, 0.0922110905604703, 0.11301424141441073, 0.10360576305538416, 0.20606591472668306, 0.07665368036500045, 0.15579826278345926, 0.11240544622497899, 0.0871958007503833, 0.12802822648414544, 0.07364065240004233, 0.1081361174583435, 0.07131118061287062, 0.1500036958605051, 0.14419766169573578, 0.14253584801086358, 0.10225065398429121, 0.12215991637536458, 0.12192925518112523, 0.08999931745763336, 0.09963355798806463, 0.13048037061733858, 0.1319065290902342, 0.11247374755995614, 0.12411915910031114, 0.10462002363055944, 0.08463807656828846, 0.09422082307615451, 0.15052645280957222, 0.09294202205325876, 0.13528939256710665, 0.09357915965041944, 0.14433168593261922, 0.08639289026281663, 0.1548282562622002, 0.11373189397688423, 0.09019374488187687, 0.07758382973926407, 0.1364006565085479, 0.166230385856969, 0.06950812307851655, 0.14768816796796663, 0.1674166414886713, 0.20763186498412065, 0.20641138404607773, 0.07986131895865713, 0.21939203036682947, 0.056605596494461806, 0.14502251600580557, 0.08140350691974163, 0.11892434928034033, 0.1763966181980712, 0.11258254386484623, 0.07206772680261306, 0.22195434144565038, 0.14794781617820263, 0.10684586276433297, 0.21997509550835403, 0.172841841088874, 0.14348836189934186, 0.05834050875689302, 0.1175927785890443, 0.06087628233113459, 0.1885545543794121, 0.15292031078466348, 0.10103859366582972, 0.07527902270002024, 0.07578377811504261, 0.1028407962460603, 0.17000905238091946, 0.13283705844410829, 0.10953667480498552, 0.10178289908383574, 0.16042410741959298, 0.16336371111018316, 0.14368109298603876, 0.1776990390249661, 0.12995280964033945, 0.09637749235012702, 0.05529659048521093, 0.12302506209484168, 0.1396612072629588, 0.14158942736685276, 0.13016038707324437, 0.12571937537619046, 0.1776644065976143, 0.13536028590585503, 0.18736034631729126, 0.17718598512666567, 0.13948174832122667, 0.1949534924434764, 0.07513866094606263, 0.1227218790778092, 0.10063195441450391, 0.21889923752418586, 0.22938240000179835, 0.16854351173554147, 0.11908240722758429, 0.11164558199899537, 0.21135229963277066, 0.09985045170677559, 0.07164552874330964, 0.1567565713609968, 0.13670211604663304, 0.11915382982364722, 0.1060525942593813, 0.16063092489327702, 0.14724436535366944, 0.10464616079947778, 0.11753202256347452, 0.1492247512297971, 0.05431938810007913, 0.10660826694220304, 0.1468066152717386, 0.13718045609337942, 0.0966190779581666, 0.1359559582280261, 0.14678403362631798, 0.0981208998709917, 0.12856318349284784, 0.12057249726993696, 0.15897330455482006, 0.18351648614874908, 0.1018235772582037, 0.09533467223601681, 0.14952935917036875, 0.10245087609759398, 0.10623460449278355, 0.10497208152498518, 0.2910699727279799, 0.13475971456084931, 0.07886880543082952, 0.10989908035844564, 0.06762241319354091, 0.13846101452197346, 0.2932705975004605, 0.10359220592571156, 0.11312505975365639, 0.1759216979678188, 0.14592636536274636, 0.15165713642324719, 0.13161999732255936, 0.09493640610682112, 0.1093736228400043, 0.08789938049657003, 0.12332804155136858, 0.15585287128176006, 0.0859427840581962, 0.12089657916554383, 0.1707681566476822, 0.1351086308381387, 0.09253313006567103, 0.11826155627412455, 0.17951661720871925], [0.023203553299286535, 0.08362476594213929, 0.0316530513311071, 0.0676492288974779, 0.0534150434125747, 0.022645702519054924, 0.03363131678530148, 0.02785003388167492, 0.03949134876685483, 0.0106257617007941, 0.021925758204555938, 0.03173476051805275, 0.03951634938961693, 0.06231503441397633, 0.0654371233124818, 0.07463341698582683, 0.026751879236793945, 0.017427527345716953, 0.02424057193898729, 0.03493521003318684, 0.015089804572718484, 0.06577407701739243, 0.024559763293447237, 0.09116585486169372, 0.006922712391575, 0.018076586803155284, 0.022615955543837378, 0.024760590999254158, 0.11448841302522592, 0.07570676439042602, 0.010990891572354096, 0.051339387827153714, 0.03474510148433702, 0.009539761314434665, 0.06307018282158033, 0.03628220382545676, 0.03011007626940097, 0.018699095185313905, 0.057650900046740255, 0.09221166731523615, 0.03009426301079137, 0.012580083350517919, 0.010171233992358404, 0.015327649756467767, 0.036919382134718556, 0.03339205515970077, 0.057707489867295535, 0.07129928589399372, 0.04117711473788534, 0.056428322435489724, 0.026767295552417636, 0.05094666193638529, 0.013333025671142553, 0.07953173414404903, 0.06133756400751216, 0.02584036921949259, 0.02863393012168152, 0.03660795830988458, 0.005291956950843866, 0.01929781412971871, 0.0168523518701217, 0.04116058562483106, 0.055568822127367766, 0.03296499878966382, 0.009803548588284423, 0.042968399689665863, 0.014193519184898053, 0.02395340404473245, 0.009592897391745021, 0.0487419863098434, 0.017165570420079997, 0.014017764196198965, 0.06113106544528689, 0.013367951564889933, 0.028208495450339148, 0.038409753769103966, 0.03830020768301828, 0.055283586361578534, 0.026211064774543047, 0.029948459405984198, 0.0782848989058818, 0.020197641470336487, 0.06944708206823894, 0.01114428459134485, 0.05224932025053671, 0.04368606582283974, 0.024384782682838183, 0.027946977876126766, 0.030502089698399817, 0.03798782033845782, 0.040546569108430824, 0.03757166124082037, 0.02691845958387213, 0.007268177894210177, 0.06351258086838893, 0.0402431044993656, 0.04334074917382427, 0.025924700944285308, 0.031077378828610693, 0.0376982589119247, 0.06071394282792296, 0.027177575144118497, 0.03727306851318904, 0.05054236023819872, 0.022239046304353645, 0.009063520485402217, 0.06105363102895873, 0.03313052062211292, 0.022539532144687006, 0.011388629292404013, 0.025173544018928493, 0.03221907845831343, 0.0401485235031162, 0.057258530386856625, 0.011789581572104777, 0.050556029326149395, 0.015574711142107844, 0.004620194135765944, 0.022669301967003515, 0.043536174044545205, 0.025311771780252457, 0.04733311690922294, 0.05474021551864488, 0.018372056573363285, 0.02352522809191474, 0.036645365945462666, 0.021428261417895555, 0.04492041601666382, 0.03829324930640204, 0.028123732855809585, 0.023860895972965018, 0.03351309223632727, 0.03990264616108366, 0.012498835567384958, 0.04376970204923834, 0.11647300581846919, 0.008107767440378666, 0.06418495478906802, 0.04247917594122035, 0.047412970302892585, 0.02837605119150664, 0.0063309929599719384, 0.02220238675363362, 0.029382527273680483, 0.02287579035120351, 0.037696023139038255, 0.0667732876858541, 0.02431249665096402, 0.035544877140117545, 0.020908437436446548, 0.03666831060711827, 0.04057954930301223, 0.025457824746678983, 0.03861151276422398, 0.017998575632061278, 0.026066323077040057, 0.0032822628147966626, 0.021504393046987907, 0.03240644233301282, 0.027744720157768046, 0.018856854577149664, 0.08446174567299229, 0.05272845079057983, 0.10508541722915002, 0.06810453946569137, 0.03948282636702061, 0.05164162428783519, 0.010953774858665253, 0.030066738237759898, 0.022134784309725677, 0.05723878501781395, 0.03718301334551402, 0.011634133440176291, 0.017263739170240502, 0.030197844774063145, 0.011706495807240052, 0.08292927433337484, 0.04364822053217462, 0.03017084247299603, 0.022703471294205104, 0.0156440896514271, 0.02836352713139994, 0.04257356694766453, 0.06464933058513062, 0.04503917660830276, 0.025473999325186014, 0.039895290841481516, 0.03928262800244348, 0.042703672644815276, 0.03406662414116519, 0.1135782872193626, 0.01624697140817131, 0.015936244778069, 0.021460973591144596, 0.032368980414633236, 0.037686262412795, 0.04470084547730429, 0.05846896222127335, 0.03297619801014662, 0.03395319344209773, 0.007954929971934428, 0.031173527240753174, 0.014950915239751339, 0.029713866101311784, 0.047256836002426486, 0.014999885112047195, 0.022258929076737592, 0.044020719294037135, 0.0361067685963852, 0.024359661620110273, 0.02626159697371934, 0.06525626658861126, 0.040500588182892115, 0.04841398587450385, 0.01043800257944635, 0.053802843139107735, 0.005027229905993278, 0.029402245501322404, 0.03216432746765869, 0.03415932898808803, 0.01024623416430716, 0.07248767212565456, 0.017871090776420066, 0.018386719715116278, 0.03848128832344498, 0.0747049277914422, 0.046407730850790224, 0.04061929788440466, 0.022010663291439414, 0.03950040381667869, 0.04750199070466416, 0.04057224487353649, 0.04657185150842581, 0.07937902305275202, 0.04376698451648865, 0.027887824889538542, 0.028679059485771825, 0.05640048553634967, 0.07076711087886776, 0.03316706312554223, 0.04382432751091463, 0.03544642170891166, 0.037568828357117515, 0.1228778064250946, 0.03560456108035786, 0.015609804973272341, 0.020470134348475506, 0.0417444785790784, 0.010216869713206376, 0.031500462376113446, 0.03620168886014393, 0.008065102006574827, 0.07132888359150716, 0.029644852304565053, 0.0767425684524434, 0.03317334635981491, 0.07573596853762865, 0.0328268524525421, 0.051499640835183005, 0.05733192751982382, 0.0480778023068394, 0.041934397138123, 0.024691482207604816, 0.035514095398996554, 0.01964913072463657, 0.022901399959144846, 0.06560238051627364, 0.09803024080715009, 0.020964250334405472, 0.019717379473149776, 0.05096958963466542, 0.029125993539180075, 0.07152555018131222, 0.09547267947345972, 0.029887638919587647, 0.016995212329285483, 0.024471818369680216, 0.023839235438832214, 0.03666930126824549, 0.0810200192832521, 0.029397115776581422, 0.01834585833629327, 0.05991726129182747, 0.03525880677625537, 0.04878453045551266, 0.027183179843372533, 0.06293981588844742, 0.03973001667431422, 0.035205724981746504, 0.022951730294153094, 0.06762075756809541, 0.07111462258866855, 0.014518315238612039, 0.07077911416334765, 0.0110596678818443, 0.03786311238738043, 0.009464117382386965, 0.01776408071496657, 0.04252255129228745, 0.03065950303737606, 0.01642260850141091, 0.08717786028449025, 0.051089646228189976, 0.05574149571891342, 0.09461353878889765, 0.050268696887152534, 0.039549553500754495, 0.052290371619164944, 0.04379295205165233, 0.04193442088684865, 0.07051960844546556, 0.01055547480271863, 0.048752137193722386, 0.023600781269903694, 0.08610630421234028, 0.06353117272789989, 0.03558607439377478, 0.014388206148786204, 0.032516867121947665, 0.06032503369663443, 0.04984994239306875, 0.05792626312800816, 0.04612682413841997, 0.01418210961855948, 0.027383086437891637, 0.04212186957842537, 0.044212680243487866, 0.027576887913580452, 0.04206151728119169, 0.033388638735881875, 0.039455250703862736, 0.051469636016658375, 0.042993091578994475, 0.03834489599934646, 0.03838240202250225, 0.05916653693254505, 0.026976260589435697, 0.0659754051427756, 0.04133836519239204, 0.0966918711949672, 0.10102821886539459, 0.06269449155245509, 0.02700734936765262, 0.024309348248477494, 0.039013955276459455, 0.005878120876981744, 0.03643625841609069, 0.014566667644040925, 0.03145553996520383, 0.014451401507748025, 0.037322170699813535, 0.03358432823526008, 0.1142682284116745, 0.16925233655742236, 0.1880705010678087, 0.1938942042844636, 0.14139886759221554, 0.08666519315115043, 0.15570940183741705, 0.143646026296275, 0.14442988352051803, 0.09049257848943983, 0.09325068763324193, 0.1695565373769828, 0.14700321400804178, 0.17074155807495117, 0.1820662668240922, 0.11534572845058781, 0.10968110098370484, 0.11438447503106934, 0.13747005483933858, 0.10457958294344799, 0.17218491062521935, 0.19234934289540562, 0.08072438157562699, 0.1616498130772795, 0.10780080580817801, 0.07683415710926056, 0.16349108570388385, 0.11286097392439842, 0.25793105523501125, 0.10248466035617249, 0.11580626373844487, 0.1198921302067382, 0.07706589038882937, 0.06962785058255706, 0.16467487146811827, 0.11157938412257604, 0.13310160567717894, 0.1812520112310137, 0.14789801170783384, 0.226445483309882, 0.11164803829576288, 0.09633259368794304, 0.14682355150580406, 0.15029509950961384, 0.13097222708165646, 0.2484365047088691, 0.1363178752362728, 0.0760234502543296, 0.16605735942721367, 0.12488617508539132, 0.13013224144067082, 0.12474951813263552, 0.0821939187922648, 0.10834168642759323, 0.13086389218057903, 0.08274556776242596, 0.17775104194879532, 0.22960935639483587, 0.11860047094523907, 0.09876494495464222, 0.14257081970572472, 0.12601129471191339, 0.09082398856324808, 0.09822857659310102, 0.07598223603729691, 0.1580898655312402, 0.13422536823366368, 0.21937532483467034, 0.09903802815824747, 0.11023768290345158, 0.1142457824732576, 0.12024602693106447, 0.1905777829566172, 0.08151353815836565, 0.1108766593305128, 0.2521446985857827, 0.11433275709194796, 0.1377182900905609, 0.14281914995184966, 0.1969289928674698, 0.16432903573981353, 0.09365994602973972, 0.15851639264396258, 0.1565922573208809, 0.17168461318526948, 0.13987915271094867, 0.12098432731415544, 0.1147079598158598, 0.10107332108808414, 0.07606466447136231, 0.12260783091187477, 0.2585040373461587, 0.11595292229737554, 0.08207168070865528, 0.13911270669528417, 0.12117760122886725, 0.16201964180384362, 0.24216751967157635, 0.14312382574592317, 0.1205497392054115, 0.22166702257735388, 0.10236861051193305, 0.09117929664041315, 0.16520799643227033, 0.1312701175255435, 0.11689662880131177, 0.2092569563537836, 0.19604459032416344, 0.14622840844094753, 0.10715711356273719, 0.11674067431262561, 0.15642202645540237, 0.0918414518237114, 0.15542624917413506, 0.14819366298615932, 0.21027285898370401, 0.06664384356034653, 0.0898153055459261, 0.13876646384596825, 0.1702732874878815, 0.12144274557275431, 0.07079186383634806, 0.2553332432040146, 0.08780945425054856, 0.10154187665986163, 0.15755416213401727, 0.13911561082516397, 0.13854412149105752, 0.13849602692893573, 0.09917242558939116, 0.1335296391376427, 0.11183346834565912, 0.06478032855583088, 0.08442583759980542, 0.16900654403226717, 0.14498683863452502, 0.16317209282091685, 0.14451133486415657, 0.17914495643760475, 0.17755130838070596, 0.1469858842236655, 0.13412413080888136, 0.20256841954376015, 0.1150328695241894, 0.10057585313916206, 0.11950784868427686, 0.11513730963425976, 0.07828783696251256, 0.07540609873831272, 0.09714549221098423, 0.1085746953529971, 0.08983216035578932, 0.11116578988730907, 0.11209450755268335, 0.13161488116851874, 0.09798906051686831, 0.09563199271048818, 0.08821952688906874, 0.10984335227736405, 0.11535529579435076, 0.21499952035290854, 0.1794470130865063, 0.11222933924623898, 0.203134901289429, 0.16859793024403708, 0.10984069920544114, 0.17167869635990687, 0.094034219160676, 0.12312610952981881, 0.0661555358341762, 0.13398467829184874, 0.06491769797035626, 0.08042456409228699, 0.10269242099353246, 0.1410829552582332, 0.11434621922671795], [0.005159154076993997, 0.06577765968229089, 0.05182708826448236, 0.012769299625818218, 0.0525661078946931, 0.03855198149436286, 0.04027741801525865, 0.03977530549413391, 0.027123607861410295, 0.02964484891188996, 0.03643664518105132, 0.06024738893445049, 0.05597047075363142, 0.04537723971796887, 0.058675216510891914, 0.007068564766086638, 0.044516175386628935, 0.05065447457933, 0.021069586110700454, 0.04580167355015874, 0.025554358227444545, 0.01647661310354514, 0.0194090955691146, 0.03292312639366303, 0.03409901740295546, 0.03234090942091175, 0.03175570350140333, 0.03971215084727321, 0.03069255787080952, 0.02305959870240518, 0.061071551138801236, 0.08303227594920568, 0.016617519381855215, 0.07026676594146661, 0.027428641582706144, 0.021079433350158588, 0.014056186241629933, 0.015055865947423237, 0.033758579420724084, 0.007211333623022905, 0.0327329703473619, 0.040686598380229304, 0.013808604928531816, 0.040637642078633816, 0.009879025431083781, 0.03532093344256282, 0.056584161573222706, 0.033267652549381764, 0.011140834240775024, 0.019266341979216253, 0.04408035234415105, 0.02104645485191473, 0.03665942179837397, 0.04082079564354249, 0.030163385373141085, 0.041500005804534466, 0.04814526565106852, 0.015436120364548904, 0.010526903389420892, 0.02989620542419808, 0.03481510254953589, 0.019437146206785525, 0.033429418690502644, 0.05340644298121333, 0.044306162013007064, 0.058087516975189955, 0.01828639831260911, 0.004642016246050064, 0.03455690640423979, 0.030154167474912744, 0.06409206334501505, 0.05518188074763332, 0.055379110521503856, 0.013638162869028747, 0.07361896642084632, 0.022642275917210748, 0.021758877605732, 0.061048779503575394, 0.04036320519766637, 0.11918316967785358, 0.044054713898471425, 0.042943948680268865, 0.04206449265724846, 0.025085661859650697, 0.02215270441956818, 0.025461828103289008, 0.03360963419878057, 0.02214150519908539, 0.06203709289963756, 0.04910604748874903, 0.024968814736764346, 0.006563926398354981, 0.02577333165598767, 0.04950830679652946, 0.01951317096661244, 0.03398599721757429, 0.0497490137017199, 0.036633226953979046, 0.05623756927837219, 0.010767315980046988, 0.03327786450141242, 0.05728076597941773, 0.04804523941129446, 0.02427503982159708, 0.058811853107597144, 0.04085209646395274, 0.006688089400995523, 0.0435137382841536, 0.09587498967136655, 0.010016623003009175, 0.014622675620817711, 0.044787077100149224, 0.08591957816055842, 0.07333525735884905, 0.0681819806673697, 0.025440065788903406, 0.05646081069218261, 0.13053560336785658, 0.03485173326251762, 0.02467007273142891, 0.012907254276797175, 0.02444433091607477, 0.06709620928657906, 0.05404666452003377, 0.052710096418325386, 0.015053477504157593, 0.02008274513562875, 0.037584841783557615, 0.021765915710212927, 0.00850027789627867, 0.03215338609048298, 0.03457063316766705, 0.04741649189963937, 0.060036737737911086, 0.08727427332529, 0.018830040569550226, 0.03398722875863314, 0.02393155182445688, 0.014083923905023506, 0.052442685767476044, 0.04242866240175707, 0.02413473235044096, 0.043764463758894374, 0.025136241556278298, 0.03374910028651357, 0.0233332450900759, 0.04939265389527593, 0.03374478819647005, 0.017250463632600646, 0.04021946433931589, 0.05176393022494657, 0.03012251720896789, 0.016687659546732903, 0.020043636073491404, 0.026611807556556802, 0.03676177541326199, 0.0053210007941483384, 0.06021775731018611, 0.049222494275974374, 0.022606720682233572, 0.01689757453277707, 0.04924591391214302, 0.025631226067032133, 0.01525666651182941, 0.055228526637490304, 0.02269851289955633, 0.01065885046097849, 0.028302150246288096, 0.04263203970289656, 0.05330591801820057, 0.013932519841806164, 0.0028941363312437064, 0.007095187511627695, 0.044918217563203404, 0.027361507327961068, 0.036154062487185, 0.021315114007198384, 0.02060293552598783, 0.031195525346057754, 0.015591705051649894, 0.04326900766630258, 0.028373041888698936, 0.05227781532864485, 0.015527123784912484, 0.002315994809448187, 0.07070562882082802, 0.02503809655484344, 0.04298075920503054, 0.050723776753459654, 0.015427789650857449, 0.038726175004350286, 0.04336640119020428, 0.06093023943581751, 0.02780020226990538, 0.04138512982587729, 0.03317349903019411, 0.021158567496708462, 0.02550000248343817, 0.02397527153204594, 0.05303423598940883, 0.017205824510061314, 0.023404947581834028, 0.04696580894025309, 0.062194845506123135, 0.04496471417535629, 0.009585994994267821, 0.027566799794190695, 0.07624352630227804, 0.07968973102314131, 0.028231794646541988, 0.036336523946374655, 0.08487439674458333, 0.015480250585824251, 0.0412099694034883, 0.03307617335979428, 0.01559682799104069, 0.050414938147046735, 0.05565026329298105, 0.03259305303384151, 0.014484916048656617, 0.0390817069980715, 0.043394672351756265, 0.020369911333546042, 0.03583219600841403, 0.038670966002557955, 0.04924324048416955, 0.012773122322479529, 0.039470005447843244, 0.01950102179710354, 0.011905013949477246, 0.02074031681487603, 0.03797533868678978, 0.0015612367715220898, 0.03860080208895462, 0.03746757396895971, 0.042213661795748134, 0.028734906310481683, 0.028090277686715126, 0.05780111412916865, 0.07256176814969097, 0.027845723487968956, 0.038666928719197, 0.02620502750921462, 0.04678109474480152, 0.012195578759669192, 0.035864117688366344, 0.05994035862386227, 0.02445713147920157, 0.01033785505153771, 0.03112603657479797, 0.03104421203689916, 0.006163935093874378, 0.018750015845788375, 0.05480748887306877, 0.03194315558565514, 0.0372044143400022, 0.02294147084467113, 0.041301385033875704, 0.0358415496136461, 0.021176489302888513, 0.047590461493070634, 0.044943638877677064, 0.015723050771547214, 0.04738737935466426, 0.021826242562383413, 0.012383487158721047, 0.03628555239577379, 0.034390149638056755, 0.017223948180409412, 0.04350608101646815, 0.012697456338043724, 0.053583048683192046, 0.04939306780163731, 0.014083243673667312, 0.01975999486499599, 0.04660228719668729, 0.030513879244348834, 0.04654082549469812, 0.033921770485384126, 0.03880785365722009, 0.012616086418607404, 0.020078636606090834, 0.05811843103063958, 0.07583337223955564, 0.05781746003776789, 0.02806501922064594, 0.037604207172989845, 0.0401664978957602, 0.06885141653141805, 0.03356531568403755, 0.045908016950956414, 0.055467632200036726, 0.05699719262442418, 0.04383991006761789, 0.014065077594880546, 0.06627051359308617, 0.012119027287034052, 0.036795681808143854, 0.04611555706443531, 0.029714347861175026, 0.008701785833441784, 0.04965095521349992, 0.07370543213827269, 0.038997151356722624, 0.04821495119748371, 0.030421985246773278, 0.005034659016278705, 0.03156908601522446, 0.04260074906051159, 0.052866848185658455, 0.08318713121116161, 0.10278037270264966, 0.03643497937758054, 0.03539842214169247, 0.026286943649340953, 0.060404917624379904, 0.004588230047374964, 0.02003503733846758, 0.008812168213937963, 0.028321161101173078, 0.052464446385524104, 0.014904915654499615, 0.00875764198800815, 0.03417277755215764, 0.011009994029466594, 0.06865684661482062, 0.02571901323140732, 0.04104117024689913, 0.017627048871612976, 0.026691796657230173, 0.025748132561732615, 0.04159626956763012, 0.04613096998738391, 0.012378270072596414, 0.04544402113450425, 0.04369327186473778, 0.01156606026259916, 0.019138573835204755, 0.06755214410700969, 0.0452350018146847, 0.013953199044668248, 0.02205008447968534, 0.021643592809726084, 0.026329248611416136, 0.04052875077884112, 0.011433925745742661, 0.00984601300608899, 0.037229024805128574, 0.015769689876054014, 0.04310504307172128, 0.06072785958115544, 0.022187487820961645, 0.07915361371955701, 0.14607400101210388, 0.1487213053873607, 0.08051610525165286, 0.13372376800647803, 0.07498793796237026, 0.10085826619927372, 0.11938787012227944, 0.075429250353149, 0.15944015021835053, 0.0937560944418822, 0.1616611446120909, 0.11516854938651834, 0.14641781470605306, 0.1488919026617493, 0.1393688265234232, 0.16757376305758953, 0.10961028228380851, 0.16760859904544695, 0.0907498789685113, 0.11118833760597877, 0.09635638991104704, 0.1448747989322458, 0.11880557851067611, 0.09926393960735627, 0.12015310834561076, 0.19315926943506512, 0.17007879221013614, 0.14982989590082849, 0.19636513026697294, 0.14257265175027506, 0.17978539850030625, 0.12862558157316276, 0.07954577981893506, 0.11871218495070934, 0.12861852480896882, 0.2554820866457054, 0.06451116049928324, 0.06899017015738146, 0.1009435716218182, 0.13498331899089472, 0.161846968212298, 0.0976480356018458, 0.04647198472438114, 0.10119702480733395, 0.08410107038382973, 0.17478151486388274, 0.14698596564786776, 0.14575618878006935, 0.13365708158484527, 0.11817492092294352, 0.08660859654524497, 0.09650854460362877, 0.08589686080813408, 0.15855757971959455, 0.12765913057540143, 0.19715867697128228, 0.06395788983042751, 0.10692032519727945, 0.09334319231233426, 0.1393629911222628, 0.07217592599668674, 0.16310080593185766, 0.1356838114027466, 0.1710337216832808, 0.12301276704030377, 0.10829418219093766, 0.15673591675502913, 0.16858587946210588, 0.16697191606674874, 0.1737055347434112, 0.2448604894535882, 0.11363292964441435, 0.10722957431737866, 0.1395886040159634, 0.04860637430101633, 0.1306633036583662, 0.12204741526927267, 0.08963057438709907, 0.16081521500434193, 0.214523066633514, 0.20249342785349914, 0.18245057548795426, 0.1296556791556733, 0.08832001792533056, 0.11624975422663347, 0.12212585391742842, 0.12573950072484358, 0.2792184901024614, 0.11870831730110304, 0.11435282815779958, 0.11177596250282866, 0.06951579730957747, 0.1461118496954441, 0.16329901958150522, 0.14611072332731315, 0.0780002059681075, 0.15244536341301032, 0.22535380188907894, 0.12678705022803374, 0.10163725832743303, 0.13939839707953589, 0.11989126168191433, 0.1447587694440569, 0.17785446425633772, 0.1699726286211184, 0.12725944630801678, 0.19554330222308636, 0.16561719376061643, 0.07415878174028226, 0.1111054816948516, 0.13914465212396213, 0.12899788016719477, 0.160015860040273, 0.14986249272312435, 0.1501052182699953, 0.12185768330735819, 0.20766887228403771, 0.13958323001861572, 0.17682557446616037, 0.058667976542242935, 0.11941445512431008, 0.17001161724328995, 0.10408229141363076, 0.1216258414621864, 0.08081598380314452, 0.14265924638935498, 0.1362003529710429, 0.17853373209280626, 0.1160807582948889, 0.07369619727666889, 0.109484224048044, 0.17076347475605352, 0.16686059561158928, 0.16694767879588263, 0.2494051270186901, 0.07788124520863805, 0.056837611366063356, 0.1686434056609869, 0.258552077625479, 0.1698790450713464, 0.13307602490697587, 0.11803932248481683, 0.13743422819035395, 0.1830180614654507, 0.12004355208149978, 0.13187406797494206, 0.1684096096349614, 0.08872169708567006, 0.1521905328014067, 0.11477273276873998, 0.08880451907004629, 0.12606910589550221, 0.12245578478489604, 0.11907866171428136, 0.11469428054988384, 0.21310576982796192, 0.12848090433648654, 0.10900318343192339, 0.11697787658444472, 0.10243002471647092, 0.1631313128662961, 0.12411249588642802, 0.13893365487456322, 0.06234298327139445, 0.14177637733519077, 0.11049031506159476, 0.0866698275453278, 0.125031924407397, 0.1394434246633734, 0.09347282642764704, 0.1578778504793133, 0.13896249261285576, 0.11173385261957135, 0.061966443833495886, 0.09161772525736264], [0.01445690103407417, 0.010733598726801574, 0.05562738309215222, 0.02531373274645635, 0.07732397796852247, 0.04684406279453209, 0.038952625888798914, 0.026526035641187003, 0.07268932594784669, 0.09281585525189127, 0.036626936934356175, 0.010000700330627816, 0.026729275538985218, 0.03658717817493847, 0.05871129421783345, 0.014360503260312336, 0.04118659726477095, 0.01483150664716959, 0.04161722272900598, 0.03995616900335465, 0.03388170299253293, 0.06326391814010483, 0.033912657760083675, 0.06097309570759535, 0.036503789613821676, 0.05644365054156099, 0.0368717184423336, 0.07426849406744752, 0.04656186347295131, 0.037064232397824526, 0.02117380908956485, 0.027723514242097735, 0.08455866082970585, 0.09490859974175692, 0.02278452060584511, 0.022930337781352655, 0.012954871319899601, 0.06041166904781546, 0.07712016640497105, 0.09127323302839484, 0.011446013847099883, 0.042392954496400695, 0.022581092414579222, 0.06748774434838976, 0.052478682050215344, 0.03043323875005756, 0.02033247146755457, 0.06670473529292004, 0.018110730685293674, 0.02665929652617446, 0.03935080720111728, 0.01615026659731354, 0.06345519037651164, 0.039569251372345855, 0.03464192684207644, 0.011364332649723759, 0.04344625458387392, 0.05148467235267162, 0.008055099552231175, 0.019812028322901045, 0.05377729290298053, 0.03797866690105625, 0.029468541765319448, 0.027836690490533198, 0.0452251087741128, 0.058954691514372826, 0.08670868046049561, 0.014506751305556722, 0.04216076999104448, 0.03535087380026068, 0.04335030633956194, 0.021332800022459457, 0.07978775219193526, 0.047937063965946436, 0.013862104022077151, 0.05871569112475429, 0.06687958019652537, 0.006426108302548528, 0.04884753921734435, 0.07516941893845797, 0.06017400537218366, 0.04384310936023082, 0.0954504506662488, 0.06693261449358293, 0.008510827419481106, 0.03151179730359997, 0.057731903557266505, 0.01998009975068271, 0.023261983646079898, 0.02547667614583458, 0.06662747729569674, 0.030817557591944933, 0.0507646211689072, 0.020899892984224216, 0.0408405206565346, 0.06826076536838498, 0.04975310866055744, 0.02529630287816482, 0.0275067562303905, 0.011854054273239203, 0.059157743118703365, 0.07849888849471297, 0.0403331698450659, 0.028618367921028818, 0.022058169224432538, 0.05697478739810841, 0.026096472084256153, 0.05934953104172434, 0.02008729980194143, 0.07386009741042342, 0.054981607744204145, 0.03935744666627475, 0.023864604166841934, 0.021836556294666867, 0.016402791886191283, 0.023154264515531913, 0.03320794825309089, 0.07522293499537877, 0.01472059840203396, 0.07177056239119597, 0.016089736184637462, 0.03005060606769153, 0.012861071487090417, 0.04041338286229542, 0.01734533130989543, 0.07584531445588384, 0.061753119208983014, 0.033340184550200186, 0.03008839368288006, 0.11284764749663216, 0.03773804820541825, 0.024318924073928168, 0.0712942715202059, 0.05029022680329425, 0.03061744404424514, 0.07985914764659745, 0.03122405774359192, 0.046615125079240115, 0.031300219906760116, 0.031074389881853546, 0.027910489655498947, 0.018891376742560948, 0.0572156673297286, 0.022334487343739187, 0.007961936694170748, 0.057114457046347, 0.037690706817167144, 0.03689076492030706, 0.032988126655774455, 0.02543768922000059, 0.028175191255286336, 0.04853141653750624, 0.06257538830063172, 0.026458329720688716, 0.028898355218448808, 0.027579983729603033, 0.028064052308244363, 0.06098353157618216, 0.06648244043546063, 0.03444349606122289, 0.05339966780905213, 0.028629489109984467, 0.01711595763585397, 0.03893293480255774, 0.054423821424799304, 0.061758825688489845, 0.02724188838952354, 0.03317374669547592, 0.035356268153658936, 0.017595481726207902, 0.09674509548182998, 0.023918354318344166, 0.03036212149475302, 0.030952491065753356, 0.07092606449233634, 0.018064122114862715, 0.08152408937790565, 0.023230908438563347, 0.036736812109925916, 0.028378337854519486, 0.05619342379005892, 0.03705004423058458, 0.04324571016643729, 0.03043697408533522, 0.011562906771099992, 0.010056073877162166, 0.016906063005860363, 0.021590207370796373, 0.00799681424229805, 0.06661584042012691, 0.04976923743795071, 0.012091636524668761, 0.03956555335649422, 0.05310165522886174, 0.020946130056732466, 0.038803884227360995, 0.014695126197433897, 0.04663989160742078, 0.04259819776884147, 0.02782037850868489, 0.04401880243260946, 0.01014984741673938, 0.09009420379464116, 0.041725689944412024, 0.026274090499750206, 0.07720138026135308, 0.03142111109835761, 0.018380310951865146, 0.04568218353337475, 0.05759686830320528, 0.03603256739942091, 0.014966935451541628, 0.05439052910410932, 0.057602676562964916, 0.06312200932630471, 0.018073465542069504, 0.028386858558016162, 0.055324725939759185, 0.04412163102201053, 0.05007709895393678, 0.02231049773815487, 0.006696854801183301, 0.04915398259514144, 0.08685943058558873, 0.033683468986834796, 0.0326116313226521, 0.07983176875859499, 0.021164575924298594, 0.04005879742492523, 0.029485749413392374, 0.02405956933008773, 0.01665680486309741, 0.07972297923905508, 0.052768335078975985, 0.04047510240759168, 0.04385655453162534, 0.13727260114891188, 0.02222833562908428, 0.020213395357131958, 0.05853534330214773, 0.06040759105235338, 0.018890684636841928, 0.05908237823418208, 0.025383506502423967, 0.08687594612794262, 0.02570589036414666, 0.05981964724404471, 0.04445225399519716, 0.04618720696972949, 0.05121959586228643, 0.024043530458584428, 0.015683380221681933, 0.03950503142550588, 0.025972761579656174, 0.04009426784302507, 0.055823734163173606, 0.0036727662913368215, 0.012862182588183453, 0.04089576358507786, 0.020472568592854908, 0.029915743840060065, 0.04868450082306351, 0.08771675279630081, 0.021548348545495952, 0.010920504590363374, 0.060638896854860444, 0.04123492592147418, 0.02157391744133617, 0.03750051684411509, 0.008665454524037029, 0.06591808250440018, 0.0511770890360432, 0.019295347654925923, 0.03750344133004546, 0.059799562607492716, 0.014259143699226635, 0.055122312158346176, 0.06302505345749003, 0.04171520657837391, 0.028471977383430516, 0.030125665611454418, 0.0545406990817615, 0.038419745197253566, 0.035834336786397865, 0.02164539262386305, 0.02764994747537587, 0.05845267738082579, 0.022100216343200633, 0.06276636876698051, 0.05118355547477092, 0.09847159391002995, 0.018874169094488025, 0.026168147434613535, 0.035674721601286104, 0.017843927323286022, 0.035400861475084505, 0.00915873930456915, 0.08714079870177166, 0.027745678588481884, 0.03773092698039753, 0.011248738272115588, 0.014857124736798661, 0.015303459983052952, 0.034370841924101114, 0.02750550433328109, 0.03074740046369178, 0.03466458312634911, 0.01886936676289354, 0.05670322411294494, 0.02891399884330375, 0.054170897496598105, 0.043062794088785133, 0.05812004594398396, 0.018094907248658792, 0.08995698365781989, 0.018619352053584795, 0.01835153597806181, 0.041406055845852406, 0.06018921812730176, 0.041461973916739225, 0.01185758859251759, 0.05551344009914568, 0.07466737766351018, 0.021781143732368946, 0.020882846488218223, 0.025538955482521226, 0.014491599618590303, 0.029027884160833697, 0.06807492819747754, 0.017793215312329785, 0.05042332144720214, 0.018974956989820515, 0.02273215975479356, 0.034049745582576306, 0.014227208448573947, 0.06787758985800402, 0.030189990731222287, 0.06225271775786366, 0.023834657023793886, 0.006476051872596145, 0.0607310419103929, 0.011669010988303592, 0.060283676987247806, 0.03723527750532542, 0.034886257124266455, 0.008022804678018605, 0.0584113545981901, 0.07265517528035811, 0.059812956888760836, 0.003405350339432646, 0.03129695276064532, 0.03936250175216368, 0.12125104585928576, 0.11878689165626254, 0.1955204898757594, 0.11814862090562071, 0.21733646281063557, 0.1408274732530117, 0.10897033555167061, 0.07362755667418242, 0.20398137372519287, 0.15540121123194695, 0.15288968171392167, 0.1298651293452297, 0.07480655876653534, 0.21680160079683575, 0.13179089315235615, 0.05229856153684003, 0.17818170812513145, 0.12657831928559712, 0.1253733089459794, 0.173879633258496, 0.13436102095459188, 0.21250532061925956, 0.10140152847660439, 0.13101468980312347, 0.12959849222430161, 0.10008681938052177, 0.22580121430967534, 0.15401538488055977, 0.12085214869252273, 0.14395716174372605, 0.11208244320005178, 0.0969564455694386, 0.15744452444570406, 0.16867666744760104, 0.0970749177836946, 0.08667765105409281, 0.08691509759851865, 0.18584490620664187, 0.17516545711883477, 0.18500950746238232, 0.06323214913053171, 0.13191845773586205, 0.28267980579818996, 0.21148257835635118, 0.11817551803375993, 0.11258266600114958, 0.1665779993470226, 0.12796964177063533, 0.11211407650262117, 0.10450752252446753, 0.13720484264194965, 0.1359407590436084, 0.16237724332937173, 0.205507792532444, 0.12678984579231056, 0.05947801164750542, 0.11345589985804898, 0.128977184849126, 0.17045351995953492, 0.07954390706228358, 0.26221090129443575, 0.12028094434312411, 0.10460911957280976, 0.10759963374584913, 0.14640389116747038, 0.10879982648683445, 0.20062063048992837, 0.0796167952939868, 0.13989469116287573, 0.1375848493937935, 0.12507758981415204, 0.11003619871501412, 0.12228419684938022, 0.13411756258990082, 0.07399935993765082, 0.08055583347699471, 0.1470697782933712, 0.09643830265849829, 0.17325624956616334, 0.16273773541407927, 0.08015968437705721, 0.07970984280109406, 0.27386202609964777, 0.08738608911101307, 0.0740799902539168, 0.11694880814424582, 0.14989191400153296, 0.08750836112137352, 0.09350671925182853, 0.14563840867153235, 0.18692801094480924, 0.13307518352355274, 0.12508107748414787, 0.07374454289674759, 0.1558590323797294, 0.13081574333565577, 0.1130355881260974, 0.14415048994123936, 0.11145504258040871, 0.1275535776679005, 0.17739664310855524, 0.18929171482367174, 0.09176630407039608, 0.09850541209535939, 0.1765218757625137, 0.10990378260612488, 0.12565287894436292, 0.16699630261531898, 0.12270577065646648, 0.16416838578879833, 0.18712611602885382, 0.09546724440796034, 0.08489159082195588, 0.14699104108980723, 0.24507333231823786, 0.1754421501287392, 0.11781092759753976, 0.1066169725464923, 0.05455354374966451, 0.14664652171943868, 0.08781770523637533, 0.11019142717123032, 0.0756692278331944, 0.07477037249399082, 0.14360258648438112, 0.14262740952628, 0.16393362624304636, 0.17307953190590653, 0.1358946186623403, 0.20653772726655006, 0.10579714618091073, 0.13599812239408493, 0.24679564418537275, 0.09065245491053377, 0.2112318053841591, 0.12890033397291387, 0.11412351046289716, 0.09486745337822608, 0.18665819827999386, 0.2147717768592494, 0.1628986160670008, 0.14723139176411287, 0.10848309312547956, 0.09649804766689028, 0.07184832250433308, 0.12482683041266032, 0.12857276440731116, 0.08785585247512374, 0.05687581628028836, 0.11715886901531901, 0.22442882295165742, 0.11949575719024454, 0.24252711609005928, 0.12977029729102338, 0.09770218948168413, 0.10561953963977949, 0.21574384612696512, 0.11769105760114533, 0.20212013859833988, 0.16638532254312718, 0.14731787783758982, 0.16277923461581978, 0.1631149330309459, 0.17696455200867994, 0.2185301144740411, 0.17543315275439195, 0.113041613517063, 0.10084353520401887, 0.13103605008551053, 0.08968077240777866, 0.12649431665028843, 0.1792317410664899, 0.17799196259251662, 0.10744418815842696, 0.18469294373478207, 0.17402778459446772], [0.025796110076563697, 0.04066067834251693, 0.024956404331273267, 0.010071631836971002, 0.02295073284767568, 0.05811182888490813, 0.0540699925539749, 0.02096159726248256, 0.05264958805803742, 0.06994174088218383, 0.047957263953451595, 0.01288249368579792, 0.053687380227659426, 0.0662860113329121, 0.025365645764395595, 0.03536495679457273, 0.01763355771877936, 0.03850099976573672, 0.060696999808507304, 0.010104464450185853, 0.07422050128557853, 0.002327951444645545, 0.02591454836406878, 0.01766233947793288, 0.06338072115821497, 0.02969183406925627, 0.06136397937578814, 0.05427126639655658, 0.019813899383214966, 0.015001715460259999, 0.02732008955042277, 0.025285612558946013, 0.027974590858710662, 0.03329254460654088, 0.06518489148999963, 0.007709238378863249, 0.06581493839621544, 0.014551612648314663, 0.04663342177601797, 0.02904353796371392, 0.049001000089836974, 0.006420159670856914, 0.04782037969146456, 0.05358163733035326, 0.08642579921122108, 0.033795695286244154, 0.08317476830312184, 0.013251520892871278, 0.04999168835846441, 0.06356028188019991, 0.05214936186426452, 0.030115049931087663, 0.048669596801378896, 0.024884213294301714, 0.02793579901169453, 0.03786055091768503, 0.03599885438701936, 0.08592723203556878, 0.02755832319547023, 0.02100529152500842, 0.04025744872965983, 0.029954243917018175, 0.03879003532763038, 0.035368217155337334, 0.03757189194272671, 0.05414252116211823, 0.0931851818625416, 0.029181100760719607, 0.00663698002296899, 0.056692214882267375, 0.0389478659656431, 0.02221286333432155, 0.033450297213026454, 0.11674319846289498, 0.1486948018095323, 0.01733589797679867, 0.018575008093778576, 0.061230559035071304, 0.014747877206121172, 0.04643662287188428, 0.035979824872421365, 0.10240101055907351, 0.052294412295200994, 0.027048733218439987, 0.017062380510781492, 0.015603475937885898, 0.037471489116017304, 0.05720868520438671, 0.06122525967657566, 0.043174016156366894, 0.04872784564005477, 0.022202939759673815, 0.013547451218723186, 0.0254940110192235, 0.017943977311785732, 0.051116322832448144, 0.020496179915166328, 0.06033171048121793, 0.020600859208830764, 0.03159432073256799, 0.05933201126754284, 0.05535387919683542, 0.0164534631850464, 0.056716363943581066, 0.05277095761682306, 0.00575664232850873, 0.025318453653848598, 0.027105507939787846, 0.06162734595792634, 0.03549830588911261, 0.023487301377047385, 0.0332195410238845, 0.023697752405756285, 0.031367998769772906, 0.06413880083709955, 0.041699162617857964, 0.01637530273624829, 0.03400797835950341, 0.06680350285023451, 0.04195322648489049, 0.055210721878600974, 0.06652037054300308, 0.028511865064501762, 0.018989872885867953, 0.05784707809133189, 0.05522130363221679, 0.011478927884516972, 0.006115412630606443, 0.025865022093057632, 0.0462818354634302, 0.010916636092588305, 0.03325590371553387, 0.04741282781053867, 0.024211757949420383, 0.015428273107058235, 0.026420898336384977, 0.02688327754315521, 0.02169537520967424, 0.038645771997315545, 0.032232995211545906, 0.025623862265742252, 0.04974682881895985, 0.009629503507832331, 0.021988497248717716, 0.01182564570834594, 0.01587366688597415, 0.0073805916389184335, 0.044743016428713284, 0.017106412344479134, 0.041044790231223614, 0.02234022435732186, 0.019552454751517092, 0.010817367267528815, 0.021487680729478598, 0.015261377241196377, 0.04630643914320639, 0.08447011200977222, 0.030997318481760364, 0.01802523188026888, 0.008375417274822081, 0.03839246130415371, 0.02172784141397902, 0.0391596197815878, 0.040493198936539035, 0.055333777596907954, 0.017974801461345384, 0.03495462631274547, 0.029222423543355296, 0.05945192197603839, 0.01700055748889489, 0.025930556701496243, 0.06628602490361248, 0.01336512461836849, 0.007439964301218944, 0.038775619851159196, 0.05987240334174462, 0.024915142616789256, 0.02512336635429944, 0.016561799782461355, 0.02626344937432025, 0.024690359232148955, 0.022426228670935546, 0.010905304557776876, 0.003602958608618272, 0.01498480127858264, 0.03186120551877788, 0.040356301103851626, 0.06595352917377438, 0.03340523909511311, 0.03274207289463707, 0.016745521620448147, 0.029050801681088548, 0.02582751606990184, 0.07121250126510859, 0.026870809462187544, 0.007884019669810576, 0.014180208024169718, 0.041677205224654505, 0.004520536001239504, 0.06190027988382748, 0.01988295219572527, 0.05088573627706085, 0.0449687209246414, 0.045873635581561496, 0.015093139572335141, 0.05432468067322459, 0.013582617992402186, 0.027629979886114597, 0.037184760573187044, 0.04075257234009249, 0.047863782183932405, 0.02330414272312607, 0.03441387800765889, 0.07015374914876052, 0.04700062796473503, 0.02144691943457084, 0.021419194493708864, 0.07148746401071548, 0.05021710108433451, 0.026846867354054536, 0.019974403449201157, 0.026286475460178087, 0.004705764611052083, 0.03348403058147856, 0.045181414511586936, 0.022490491026214192, 0.009113324107602239, 0.02483484647901995, 0.0633131797824587, 0.08215640259108373, 0.017173443122633865, 0.030612897859620194, 0.03466221843180912, 0.06091604448322739, 0.011785566341131926, 0.027114734319703918, 0.03587002772837877, 0.037393369379320314, 0.008501333018232669, 0.02408260729030839, 0.021688866362507855, 0.04372285599155085, 0.04157244281045028, 0.007307217406508113, 0.057133449241518974, 0.030671374007527317, 0.046880869926618676, 0.04138953351814832, 0.0113008684212608, 0.07038555706718139, 0.0016136238097845177, 0.021528387741584862, 0.027618207303541045, 0.03361030934112413, 0.03002083534374833, 0.03535296368811812, 0.0533219178739403, 0.16390178937997135, 0.03598332950579269, 0.024764031171798706, 0.008824600671817149, 0.06158008599387748, 0.019915084221533368, 0.06828252598643303, 0.02877817988129599, 0.05029102747461625, 0.06709725423050777, 0.01828883425332606, 0.022112299355545213, 0.028829585694308792, 0.0689167594537139, 0.04699159666363682, 0.022526034386828542, 0.03152333579159208, 0.021995085823748792, 0.02589541706921799, 0.036316656441028626, 0.03941820947719472, 0.05612246259780867, 0.034100944442408423, 0.04541104772527303, 0.037850437353232076, 0.04448110869686518, 0.021370962528245788, 0.010494437185116112, 0.05179698845105512, 0.026787814451381564, 0.051890592356877666, 0.04487296606280974, 0.014932493013995034, 0.030746833886951208, 0.02340210452010589, 0.026340008480474353, 0.04994493729567953, 0.03340125270187855, 0.05051177187955805, 0.07635460927018098, 0.04380234297631042, 0.03159199675012912, 0.016177352018920437, 0.01653911466045039, 0.025731600056003247, 0.07362978226904358, 0.013888532112884735, 0.029410191146390777, 0.04906262803290572, 0.023953621175938418, 0.027265294454991817, 0.044624486538980684, 0.023382452449628284, 0.07833983310099159, 0.018903186644560525, 0.03204911561416728, 0.005930490633805415, 0.020847496510084187, 0.024216321097420793, 0.03501047992280551, 0.059565081261098385, 0.040651599543967416, 0.02330319277409996, 0.012857839964064104, 0.03258609126455017, 0.022634325183129737, 0.07971487753093243, 0.0251672641773309, 0.029067927904959236, 0.0586854148922222, 0.052510210179856846, 0.03937594013820801, 0.03180545708164573, 0.0408548309600779, 0.05575014364772609, 0.04173767965819154, 0.03886349692142435, 0.10801111773720809, 0.012652511026577225, 0.030289087378020798, 0.017044141489480222, 0.029134492190288644, 0.05851114674338272, 0.03603972255119255, 0.03574960133326905, 0.039520705584436655, 0.02710021536664239, 0.004291273013222963, 0.038563794789037535, 0.02091132799562599, 0.014078659321447569, 0.03321625691439424, 0.09806873409875802, 0.05718799667166812, 0.01159152907452413, 0.15723157301545143, 0.11527738640350954, 0.159204060743962, 0.072114844274308, 0.08495749692831721, 0.10453452821820974, 0.15229238090770586, 0.07908334463302578, 0.23335465256656918, 0.18482871859201364, 0.1950844768434763, 0.11976608554167406, 0.13642303459346294, 0.1996781046369246, 0.09898430175547089, 0.14999617769249848, 0.08214340186012642, 0.19713134558073112, 0.16153763766799653, 0.10100431407668761, 0.20724714919924736, 0.10142511435385261, 0.11367723119578191, 0.1425841325627906, 0.10699271131306887, 0.11222543766988174, 0.12484553083777428, 0.16623448420848164, 0.13042866624891758, 0.08580993368689503, 0.13341527884559973, 0.1447527033409902, 0.09384733026048966, 0.08098554970430476, 0.16360037055398735, 0.09741587484521524, 0.18860294749694212, 0.09674132961247649, 0.15523354522883892, 0.11506219580769539, 0.08871930864240442, 0.11122543311544827, 0.17831438886267797, 0.10263705932136093, 0.1668329249535288, 0.12505000058029378, 0.1056769233463066, 0.06916207021900586, 0.12185845683727946, 0.15498197158532484, 0.09026005132389919, 0.14037608461720602, 0.24256283417344093, 0.1053592875333769, 0.0991367142913597, 0.13648206714008534, 0.09816125234855072, 0.17938378719346865, 0.12283857353031635, 0.17028240699853214, 0.0772547402552196, 0.07593679454709802, 0.13068118984145777, 0.09672779962420464, 0.1846038249454328, 0.13307434214012964, 0.13719865440257958, 0.09915932307818107, 0.09021840284445456, 0.09051992345069136, 0.15537558974964277, 0.10879175192011253, 0.12224511323230607, 0.15216355424906525, 0.3154351610158171, 0.09011243603059224, 0.16403323518378393, 0.13906725841973508, 0.1035193923328604, 0.17043699084648065, 0.18072256392666272, 0.2630546731608254, 0.09035877816911254, 0.10384162182786635, 0.09806063239063535, 0.13668698471571716, 0.14387653821281024, 0.10497780157519238, 0.14924088679254055, 0.14914184782121861, 0.14130075142851897, 0.21957001010222094, 0.09251676380102124, 0.1590172600533281, 0.1391018908470869, 0.11628307029604912, 0.11736184598079749, 0.08672187796660832, 0.09974232715155397, 0.2027519904077053, 0.14448955389005796, 0.12681637651153974, 0.1288262786609786, 0.1608139257878065, 0.21855870793972695, 0.09088937898299523, 0.10890957274075065, 0.12367840989359788, 0.1337902508676052, 0.16339987702667713, 0.14147883972951344, 0.08729314338415861, 0.13950962253979274, 0.11696118462298598, 0.13693847693502903, 0.10606116415666682, 0.0782577439344355, 0.100245650857687, 0.12609968068344252, 0.11879934955920492, 0.24568865501454898, 0.06590991294277565, 0.12364679016172886, 0.1139038008238588, 0.1396825946867466, 0.08145355566271714, 0.11368749064526387, 0.06486231594213418, 0.08769400151712553, 0.1145569450621094, 0.11241534605090107, 0.1444010864943266, 0.12380112973707062, 0.20883034781685897, 0.24057089963129588, 0.07984299851315362, 0.11362207308411598, 0.1595411297998258, 0.2315436154603958, 0.0744383924507669, 0.1241640102650438, 0.16184544829385622, 0.11630856964204993, 0.08904999946909291, 0.11482394859194756, 0.10457397145884377, 0.11868724200342383, 0.14451001850622042, 0.20165629205959185, 0.11408049134271485, 0.2132269154701914, 0.13799862004816532, 0.11138532989259277, 0.13829064794949122, 0.18318798020482063, 0.13902219012379646, 0.1658390068582126, 0.07386816519179515, 0.170961430562394, 0.11351771439824786, 0.09729860363794224, 0.10232945904135704, 0.1600527044917856, 0.16628424796674932, 0.12539704410093172, 0.05850375071167946, 0.1033890593264784, 0.12725419444697245, 0.14264213373618467, 0.11001194108809743, 0.10506717820784875, 0.2973860480955669, 0.12834742292761803, 0.17833117581903934, 0.12354970537126064, 0.12101659843964235], [0.01377621166674154, 0.060740554971354346, 0.04589084322963442, 0.037957425362297466, 0.016047192038968205, 0.027650629403069615, 0.04825053357386163, 0.015670121647417545, 0.04471551540440746, 0.008492021821439266, 0.04545086416016732, 0.027184692976464118, 0.1543530374765396, 0.010255281580612063, 0.04700172719146524, 0.03550741182906287, 0.05772430396505764, 0.06857169725533042, 0.04531595443508454, 0.021519646514207125, 0.0419312351649361, 0.0063237330593567875, 0.02799544732884637, 0.022921720386615822, 0.02289322530850768, 0.012794929589810116, 0.05029904775853668, 0.01929961733653077, 0.058437946385570934, 0.03719831431018455, 0.03357579226472548, 0.04549405969945448, 0.012266656999210162, 0.029582192988267968, 0.08453240830983434, 0.026396883285737464, 0.08720800759536879, 0.047458503395318985, 0.03179119766822883, 0.02747745539194771, 0.02948789019137621, 0.02130647625641099, 0.04812734554122601, 0.037296294766877375, 0.05060006285618458, 0.05185651972091623, 0.07080160081386566, 0.14423905233187334, 0.03277325836409416, 0.0410273790226451, 0.04289007978513837, 0.04874025943822094, 0.005801929027906486, 0.011585209368994194, 0.04865595485482897, 0.016609443118795753, 0.01357000317823674, 0.04605228028127125, 0.023396976491702453, 0.03833929469276752, 0.03253019694238901, 0.013913166326736765, 0.01924534810573927, 0.02480136925753738, 0.026087817370093296, 0.028467136036072458, 0.03407966219154852, 0.04450359534738319, 0.03483378940394946, 0.01840616822508829, 0.06290229290191617, 0.05239215865731239, 0.012442216909091388, 0.05963820019470794, 0.011035749522436942, 0.01885079525943313, 0.05569497875070997, 0.047755620309284756, 0.027732073961357986, 0.04273974017373153, 0.06562882302595036, 0.023394611797162464, 0.021414906152391007, 0.07485785601394516, 0.04942574944081051, 0.03455515917656677, 0.05556020812530603, 0.025089724588074853, 0.015910699630954435, 0.01660923277293997, 0.08251714573374816, 0.0534557555136936, 0.07619034951286656, 0.026409493859059045, 0.02842226960430188, 0.04618639612038221, 0.05973879301122256, 0.08859572705945798, 0.013107790212546076, 0.025822070826377188, 0.03895131292353783, 0.02361953767415668, 0.02097531215154699, 0.05633911204391292, 0.02279407437890768, 0.030602546807910715, 0.0709438556805253, 0.06576155126094818, 0.018680550823254243, 0.04305820719205907, 0.023730646087122814, 0.024328857826601182, 0.027174913590507846, 0.061478339667831144, 0.02118045194739742, 0.016750671701239686, 0.022296659016449536, 0.021500165773821727, 0.018385632362748896, 0.03535832411476544, 0.0110122883259984, 0.03198784729465842, 0.05968534480780363, 0.009115643849197243, 0.03161070735326835, 0.01481712849012443, 0.030482887157372067, 0.09276223741471767, 0.03690245268600328, 0.035710755203451426, 0.023596131608688405, 0.00789030035957694, 0.04000768677464553, 0.00728169091910656, 0.023133365636957542, 0.00816732076262789, 0.05278802616521716, 0.011606583222081619, 0.0845806250082595, 0.03183281222092254, 0.012834263416672391, 0.047765679590936215, 0.022129814040714076, 0.08999688151691641, 0.037432191760412285, 0.029591003765485117, 0.051858304268015284, 0.028620332279907804, 0.019919747453449026, 0.015049713331141641, 0.03133449610322714, 0.08310062478163413, 0.0038988571281411816, 0.052306761632540395, 0.00861667379337762, 0.018598303897306323, 0.08336924322481666, 0.014800227879147445, 0.05225639058543103, 0.028313466514061605, 0.0206222042241799, 0.03494113364389964, 0.04472204291128686, 0.028085723020402447, 0.043166121401424916, 0.01841012917325965, 0.05442585702985525, 0.016393684249903475, 0.058716016821563244, 0.0328095328461911, 0.0429783198716385, 0.018170823442882726, 0.033484549660767825, 0.04345766415021249, 0.027347841632685492, 0.09360083884426526, 0.014160569524392486, 0.020587495461638485, 0.05672468617558479, 0.009785383357666433, 0.016967841922970753, 0.03183262223111732, 0.026380169271890606, 0.04528237034433654, 0.03280819613220436, 0.025860194316399947, 0.023981415666639805, 0.036171059789402146, 0.04213248186611703, 0.06970210266964776, 0.0677206175667899, 0.08689834456890821, 0.05841921203370605, 0.07818723057529756, 0.007695980652767632, 0.03957046934270433, 0.07299433422407933, 0.024108696961775422, 0.02798951354010829, 0.02134493731760553, 0.05324099239494119, 0.006968615285586566, 0.022257926541247537, 0.01122249593026936, 0.060486803230430396, 0.057789110844688754, 0.02574649729233767, 0.04561433003150991, 0.009984115238434501, 0.029102533190910305, 0.05821859637009246, 0.031203867934112037, 0.09510416710483176, 0.011358308106926935, 0.015940617936264192, 0.028156092190848928, 0.03972198621236852, 0.027035712131432126, 0.044576470008386035, 0.04968598458383765, 0.013570435744311129, 0.016303283029368947, 0.024011121929756234, 0.024168024671130946, 0.030909214102263962, 0.06254147512039968, 0.09376341583473341, 0.028017682921407477, 0.044824399918849976, 0.01539985606047724, 0.0659586860399161, 0.01830723273035671, 0.03389998611861041, 0.03277461543413145, 0.01802110469101795, 0.028344631627468125, 0.061176065887723646, 0.019221046374046376, 0.009866822826942163, 0.06047861331275531, 0.02997359573575003, 0.02088553348689207, 0.04017901686685426, 0.07381494769028255, 0.010814576792264623, 0.02999005020995225, 0.024118725709351044, 0.07458404677786998, 0.04273878683203033, 0.03152016024770481, 0.05108311872131058, 0.057151823969823976, 0.0856683234285031, 0.04172145927857075, 0.06240160869700568, 0.04223133424030883, 0.043095777676041634, 0.024876128549554517, 0.057651931419968605, 0.04773715737142733, 0.023526902377073253, 0.039473584720066617, 0.03472535272261926, 0.017027999141386578, 0.039045086463115046, 0.05585904173286898, 0.02077930882972266, 0.020632628218403885, 0.1415635480412415, 0.027679475623049905, 0.03114862161289368, 0.06197555655879634, 0.01334524354232209, 0.10149200433599097, 0.05396055503349219, 0.03837135207972356, 0.03732536659975137, 0.06849426283900227, 0.03621905257127114, 0.0589626846568925, 0.03337282547727227, 0.0036844133449319217, 0.009314999982182468, 0.02929496911487409, 0.012515543644050402, 0.03604874028159039, 0.023246026198778833, 0.02019163134640881, 0.05259665214855756, 0.03675371441724045, 0.011532270915008016, 0.01362479742549892, 0.07034238866929497, 0.051236440494124375, 0.0363791732649718, 0.04066853238535779, 0.012095836656434196, 0.03412568722186344, 0.04829468245484999, 0.018254430831543038, 0.02135446055659226, 0.06436716858297586, 0.004462584869803062, 0.13511229492723942, 0.04466401120381696, 0.00919101297456239, 0.04669567736397896, 0.056961657745497565, 0.07052023269768272, 0.05540948514161365, 0.01821395112866802, 0.009686141674007689, 0.05414308434618371, 0.012327791308052838, 0.0804027220500367, 0.021666264361036674, 0.07598594762384892, 0.029873562710625783, 0.06217346486768552, 0.03830587345042399, 0.04300930178058999, 0.05663662250818951, 0.08794179572058575, 0.041924799260284216, 0.0019768661877606064, 0.021826235777033225, 0.03988115695704307, 0.04350027275670852, 0.04979808535426855, 0.08172912908984081, 0.06263217489634242, 0.03131735630865608, 0.03608566615730524, 0.014945588739854949, 0.03602901187592319, 0.014966189063021114, 0.020008050304438387, 0.02936536373038377, 0.037135566784335036, 0.01289751475477325, 0.04238177223929337, 0.0456884362335716, 0.06925490738025733, 0.010583383796204413, 0.034370489085891416, 0.034999379089900425, 0.053421472531876395, 0.0005748463861112084, 0.010666450053187353, 0.04038135940209031, 0.0474227988826377, 0.03066726208531431, 0.12979585091982568, 0.1250061129352876, 0.10179422383329698, 0.16192746960691043, 0.09019710363021918, 0.1064704293385148, 0.10431085593466248, 0.1687684596649238, 0.16149213510964597, 0.09175327619803803, 0.10117314037467752, 0.1436713763645717, 0.1764823171709265, 0.09696273558906146, 0.23729183844157628, 0.1987883145255702, 0.12234806056533541, 0.20482118294707366, 0.16553134551005705, 0.11918971075543336, 0.1816537989569562, 0.1046016149755035, 0.111095344381673, 0.08791261871478387, 0.07922182005963155, 0.0831747343763709, 0.13977963876511368, 0.11114821583032608, 0.09365132184965269, 0.1166975059147392, 0.10673692396708898, 0.07541082812739269, 0.08154792631311075, 0.0946716485278947, 0.2570785166961806, 0.10673192316400153, 0.2614118041736739, 0.1876778599939176, 0.10373313086373465, 0.10237867318625961, 0.08262392000428267, 0.10789992620370217, 0.09341051655688457, 0.12570617108472756, 0.11544547309832913, 0.16225778045398848, 0.13611564465931483, 0.23065810011965887, 0.10418258567473718, 0.12805170379579067, 0.0914705985092691, 0.11154022586664983, 0.11836341795112405, 0.1379591700221811, 0.1970313430896827, 0.08236374253673212, 0.2448979988694191, 0.08553949676986251, 0.10779326728412084, 0.13181891664862633, 0.1277475165469306, 0.16274967763040746, 0.12513979790466173, 0.19420742961977208, 0.0663100111165217, 0.08666657057723828, 0.1379370226391724, 0.1451899241656065, 0.13372733710067614, 0.11019406667245285, 0.10286423284560442, 0.13290192639189108, 0.0954872001228588, 0.17157429696193763, 0.0980636722275189, 0.11698665682758604, 0.16397311698113168, 0.10966582037508488, 0.1367393269070557, 0.1980234155697482, 0.195988176922713, 0.17858042887278966, 0.12925938756338187, 0.15751738553600653, 0.16793952057404177, 0.09842991150383439, 0.12376866862177849, 0.07559469754674605, 0.10724969288068158, 0.11702878028154373, 0.10508150886744261, 0.11371657265616314, 0.2110415305942297, 0.07985195517539978, 0.11910612881183624, 0.13299422072512762, 0.08957165719142982, 0.28597387618252207, 0.10380028547453028, 0.16571476709629807, 0.19676980855209486, 0.08353524003177881, 0.10988532645361763, 0.12565370675708565, 0.22275252932948725, 0.16608653643301555, 0.12189956248870917, 0.16292691097727843, 0.12160605538104262, 0.13297466534589017, 0.13772495330444404, 0.03401896044878023, 0.0807164427159088, 0.10820036115390913, 0.10231095539139849, 0.1220692369554724, 0.17193252273968287, 0.11458652918892247, 0.10517146225486483, 0.07544033761535372, 0.18402986574385846, 0.08526778420699493, 0.19708002119192056, 0.08708815795502492, 0.1013318904276405, 0.08801633957773447, 0.11840959904449326, 0.23114770384771482, 0.12085863548730101, 0.13146582059562206, 0.09296719570245061, 0.17287555070860045, 0.11848411576024123, 0.21746341671262467, 0.18440668338111468, 0.07734532468020916, 0.16526781607951435, 0.11573049851826259, 0.15928595992071287, 0.09584708152604954, 0.06472582862313304, 0.23838468694261142, 0.2338809786098344, 0.2505267182631152, 0.1610281528638942, 0.11071015362228666, 0.14975311287811824, 0.14248408935964108, 0.07992750326437609, 0.11859482553388391, 0.12301477550395898, 0.25654117124421255, 0.10582385331924472, 0.21788402699998446, 0.16379375303430216, 0.13140099335994038, 0.1356082090309688, 0.12072052646960531, 0.1426766575979335, 0.1032746515369841, 0.055274517741054296, 0.06964303619627442, 0.11103327878351722, 0.09591825306415558, 0.1309701507644994, 0.14593671980713094, 0.15081972921533243, 0.07737392493124519, 0.11531702641929899, 0.08780621763850961, 0.1395610012114048, 0.09913306377295937, 0.15934826300612517, 0.21228276113314287, 0.12981703478310788, 0.1323742161371878], [0.07411684827612978, 0.015787942468055656, 0.027050892656136836, 0.0599515340956194, 0.04585534906280892, 0.06281433440744877, 0.01969300310260483, 0.052230955700256994, 0.0343980579636991, 0.025974542734080126, 0.005532288965436497, 0.003829352241674704, 0.030417194789541618, 0.055149155003683906, 0.025551947731790797, 0.053982366541666646, 0.06058966235390731, 0.021471984518159713, 0.013575298295888518, 0.01634235307574272, 0.09442361005182777, 0.03251784760504961, 0.08694261897887502, 0.04169734753668308, 0.07755473415766444, 0.06378465305481638, 0.021914072135197263, 0.01220154223431434, 0.07542815791176898, 0.0476834547173764, 0.03956322258870516, 0.0189546314733369, 0.04971977223509124, 0.016092499518500905, 0.009522071058329726, 0.01545217789576522, 0.06962534678833825, 0.04506199234830482, 0.05397918760510428, 0.06223988666066101, 0.02246301035795893, 0.013608286972157657, 0.05544375794540558, 0.0536421592613416, 0.02876696709011282, 0.05445829100374665, 0.01647621446422168, 0.02270747465081513, 0.061585480347275734, 0.036218811691339524, 0.02161182719282806, 0.06052581899400268, 0.04202011985970395, 0.042386148790163655, 0.019769835319103937, 0.03439199525330748, 0.0441231509404523, 0.017448821470939686, 0.011837911925145557, 0.04845399229920336, 0.06686039801154818, 0.03080748813226819, 0.0624250452965498, 0.04638311020763857, 0.05912706655051027, 0.033430623090160747, 0.01735690881365112, 0.033049299980380704, 0.0967621063547475, 0.01030038804414549, 0.058487560866134505, 0.0033830772154033184, 0.07108741333442074, 0.048458216179694445, 0.01873427552969328, 0.08859268043722425, 0.02560326024623854, 0.04476817989987986, 0.03739135413031493, 0.004930569623996104, 0.05898455384054354, 0.012138129744146551, 0.06792586762458086, 0.02123009865837438, 0.06682219648999826, 0.026731511311871663, 0.05098844273015857, 0.032305635777967315, 0.05345607442515237, 0.07091765744345528, 0.08565423025616578, 0.05244325573689171, 0.013703238618160998, 0.02542983856983483, 0.012883062807044812, 0.05416082125157118, 0.02958278331373419, 0.03075078296075974, 0.015507105305524809, 0.014763488600562726, 0.03515047187517796, 0.044579109509608576, 0.05596343434548803, 0.05761766540152686, 0.020909136327515756, 0.06736060045659542, 0.02627181401476264, 0.023290936735325625, 0.06910132776413645, 0.023190315081072704, 0.08285738354814903, 0.058735022587435584, 0.08368286211043596, 0.09205207587885005, 0.04122196929529309, 0.06783639599702188, 0.04357430092724306, 0.05328579945489764, 0.006942741473072341, 0.018279171914660504, 0.1121226463999067, 0.010795122345111199, 0.053025866259953806, 0.030346060570861613, 0.02056397234887949, 0.07574575979794775, 0.028998629123504673, 0.030779814081532613, 0.032985039321439605, 0.02276829004819904, 0.07612468767911196, 0.021434746516336287, 0.04357911174052528, 0.013233162279772972, 0.04388342791103891, 0.036658597378326316, 0.043484374681221585, 0.016239022370427847, 0.0422030834348074, 0.043146589770913124, 0.04278434706585748, 0.021343239283721362, 0.029626464005559683, 0.05654848420194217, 0.022083590538906198, 0.050119561675403795, 0.03429866276149239, 0.061103869761739454, 0.024468413820224147, 0.01770794890554888, 0.05081455795360463, 0.05068341409787536, 0.0034306808998475647, 0.05834623559245041, 0.03252793742077691, 0.035992245455937724, 0.06519561912864447, 0.05313889662336026, 0.026501732213156562, 0.023480375230844532, 0.03407984200332846, 0.026749947108328342, 0.026646423020533154, 0.03433920183618154, 0.008590072676140283, 0.029393936840019057, 0.029965578844504695, 0.030960775978331054, 0.05729791934468916, 0.08661175173308168, 0.08115177042782307, 0.036378128321043084, 0.03701088258198329, 0.08771698349820715, 0.008611393942763763, 0.04641517098726971, 0.020473630500159094, 0.08729915520442383, 0.013351490305337523, 0.0504950290279729, 0.07251674735120364, 0.015508501391325678, 0.014709180354007652, 0.06195732432284525, 0.015401864524132438, 0.012104744124891502, 0.02099366143478879, 0.04530075864334192, 0.02571068930306605, 0.04074718816471951, 0.04576381129611816, 0.07830780624811139, 0.11439493804105691, 0.052668587038559575, 0.018090663012117147, 0.025609931941809397, 0.07038043412779059, 0.015165618986689618, 0.05987230834684201, 0.03898270195350051, 0.01061202136666647, 0.024332379423347966, 0.05089264715622578, 0.014453265782711762, 0.031117307221783057, 0.02362079805295382, 0.02840003401174077, 0.05051699999187674, 0.03844058300767626, 0.004970185891059893, 0.01195284812378564, 0.024777013243042996, 0.013862939468318862, 0.05146958173385688, 0.04596623186288135, 0.043757580021130185, 0.019193816763748015, 0.006957334216817149, 0.05749912533376898, 0.041851181603435955, 0.022415752090247612, 0.03944485894005213, 0.03517461075846638, 0.007424440268161041, 0.06187725040529456, 0.028766885665910583, 0.014611735939979553, 0.01774237268338246, 0.09566725617540733, 0.05080006105293121, 0.014169208123348653, 0.04233024428997721, 0.014852100184985569, 0.01782397160838757, 0.05566104860710246, 0.05363979456680162, 0.022766249354130456, 0.009058705431276133, 0.02605053356715611, 0.021716416580602527, 0.09317735156842641, 0.02772303926758468, 0.04715490647192512, 0.0537443228864244, 0.008404747799171932, 0.04554012883454561, 0.03405746391841343, 0.014121273016956235, 0.049408450190510066, 0.06771753023245505, 0.03747223550453782, 0.07891620110188212, 0.04085274785757065, 0.06609446768249784, 0.03117612942254969, 0.010838532471098006, 0.01519633287430874, 0.012305195243763072, 0.04745117860979267, 0.04568375773461802, 0.018325631207387363, 0.025536299017923217, 0.05349202999579055, 0.03311363867084895, 0.03820684126445225, 0.09568799899092742, 0.06548299906509263, 0.031066132110676596, 0.016887657743479525, 0.06977933352547032, 0.0429479995343302, 0.012303610864494528, 0.035736888979694674, 0.04174344042049987, 0.048655300068535974, 0.09006172910864864, 0.04094833987099784, 0.026791895839518735, 0.03203252204028623, 0.06811203049229723, 0.02116520017651575, 0.028185464275468673, 0.04519987405676927, 0.022540516020464044, 0.04347506518076573, 0.03115621781242745, 0.09543822346521275, 0.019625295485769, 0.04221532081386872, 0.05721283105335065, 0.024538771116307805, 0.032523632116083584, 0.0411994249692985, 0.06382041185029916, 0.04168564620028649, 0.044670226584587774, 0.03580209619498678, 0.03736815501802734, 0.01928867256667997, 0.01607412309385836, 0.017890557946105088, 0.06593916458742959, 0.002860578745769869, 0.044872850711856566, 0.06801658775657415, 0.03719669600416507, 0.019208149119679416, 0.08536442116435085, 0.016726408985310366, 0.030855460558086634, 0.04986305168962904, 0.03307834467185395, 0.02037832177510219, 0.019090441953656927, 0.023248996485822966, 0.018117989313655665, 0.032280231426869116, 0.011223727471328207, 0.029057095093386512, 0.0360739885696343, 0.02142900780641607, 0.01951904029452375, 0.030746328378362314, 0.04537055954071028, 0.04572502962712731, 0.016012274626908556, 0.016665132184113775, 0.012922662958901907, 0.04380245154191341, 0.019855993999434367, 0.02859430367659245, 0.016488197392651012, 0.0965042087648596, 0.07162669939654213, 0.07220489944198302, 0.03191523726231285, 0.03252650910456266, 0.03022081996979458, 0.03543983313388058, 0.0776233815455011, 0.04858350767088788, 0.02968651774738516, 0.025550285320995108, 0.008560056831421596, 0.05479073245078325, 0.0728917329439095, 0.04666807455942035, 0.05525156968672361, 0.016901747523141757, 0.07371371705085039, 0.03322598710656166, 0.02119375971545066, 0.12123358036790575, 0.1489202111427273, 0.07333566447986023, 0.1621820016631058, 0.2024313418992928, 0.09933258699519293, 0.10248748306185007, 0.17950276152363845, 0.09162006620317698, 0.09268195993666138, 0.04574004899976509, 0.07221832765000206, 0.08865870189453874, 0.14196138669337544, 0.06567676152501788, 0.2128724352057491, 0.2516227965908391, 0.11366032888846737, 0.13648788897054537, 0.08039023022034339, 0.21850028607462132, 0.16607044158237322, 0.11721533669957093, 0.09130972464169775, 0.25967057475021904, 0.1814903670123645, 0.14460208213755063, 0.12225062293665749, 0.19142505606370314, 0.12769398013395922, 0.10285449586808681, 0.11063073109835386, 0.09090469351836614, 0.104739825773452, 0.060456533783248494, 0.0736275634595326, 0.14785261771508626, 0.13323504637394631, 0.12883408181369305, 0.15286882354744843, 0.12625055973018917, 0.10888754070869514, 0.13281810017568724, 0.11990431669567313, 0.19188039377331734, 0.16504623368382454, 0.13292065395840577, 0.13248872570693493, 0.13370334410241672, 0.10675457266292401, 0.114015256986022, 0.16957480353968485, 0.17816027998924255, 0.14564413550708974, 0.11471479944884777, 0.1683381734681981, 0.11503679145659719, 0.07096630161894218, 0.15819176792034081, 0.15267564462763922, 0.09530877933970519, 0.09506099192159516, 0.17041843969907078, 0.09340721209134374, 0.18871471578521387, 0.14434429311326571, 0.09861490729131869, 0.15992283288921627, 0.10455094876566104, 0.15669595104243073, 0.1751365243856396, 0.07724623821143593, 0.2058841080537864, 0.18022682624203817, 0.07607390611831631, 0.17696520340229782, 0.17783110908099584, 0.14157369892512048, 0.07069922345025198, 0.0625908656844071, 0.12986257805355958, 0.13766834991318838, 0.12130797494735036, 0.09044623454766614, 0.10233841570360319, 0.0789324723716293, 0.2286702367876257, 0.1437466801809413, 0.15683834840144428, 0.16744173371366092, 0.2537048134420599, 0.18891602355454648, 0.14966130709009512, 0.12183360888489655, 0.11431340527321611, 0.07086775797818388, 0.15384239916290554, 0.1679616408156497, 0.07949360726135117, 0.15915775751428946, 0.08466911276004144, 0.15407569307301724, 0.12924678038273538, 0.12597894216222422, 0.08376677653619222, 0.22027441087578023, 0.14660172483750752, 0.08365506253072194, 0.18688292907817022, 0.17742449018572057, 0.1378195003739425, 0.17944267046238693, 0.17433665373495646, 0.15764082462659904, 0.1507663692214659, 0.1805640310049057, 0.16078314743936062, 0.19297602426792893, 0.11148143080728394, 0.1896079664251634, 0.22436687270445482, 0.13426158843295916, 0.14363461333726132, 0.08570523573351757, 0.11406241516981806, 0.15642835040177616, 0.17143962133143628, 0.1534933607493128, 0.10639391094446182, 0.12574039639106818, 0.10517043766698667, 0.12142350231962544, 0.11123842706105538, 0.1755038018205336, 0.11616818074669157, 0.12792876682111196, 0.08711008820682764, 0.06894757172891072, 0.08876171708106995, 0.17251058029276983, 0.15205364514674458, 0.11652304099074431, 0.15015453419515065, 0.1852759953056063, 0.18859466936971458, 0.19720438309013844, 0.16406998464039393, 0.1660611592233181, 0.12036088933902127, 0.09197380007909876, 0.11104832869023085, 0.15034776739776134, 0.16281590264822754, 0.08007812446781568, 0.06674253647880894, 0.07994345562266451, 0.25317618037973133, 0.13639403400676592, 0.09567839093506336, 0.09881709715617554, 0.1047044876696808, 0.17150269794676984, 0.14671828358301095, 0.18486766650208405, 0.1758088304528168, 0.0958899310124772, 0.131334320509008, 0.07223217654973269, 0.09952692620988403, 0.16022913716733456, 0.13228482593383106, 0.11792360512273652, 0.11411536804267339, 0.14994980660932405, 0.14465746416577271, 0.1786960240985666], [0.009962281677871943, 0.03213431586378387, 0.010604751712110425, 0.02403070275405688, 0.02382424151125763, 0.0518254088903112, 0.01131373514155192, 0.058376756097589216, 0.06328432847346578, 0.012993646203540266, 0.05721816433859723, 0.024930163685764586, 0.04217807263402002, 0.03416118478136403, 0.027353907735752206, 0.07051377982965537, 0.062216972533081255, 0.0187180738097855, 0.09352298373622553, 0.017361967292215143, 0.0279928468433874, 0.009772778721526265, 0.02893688582948276, 0.01376893522683531, 0.08256272971630096, 0.01607649287741099, 0.03130164143762418, 0.01891499145754746, 0.009301320716206516, 0.010235487865949315, 0.03397776319512299, 0.015849811291056018, 0.04734295566699334, 0.025530480580138307, 0.04168302026976432, 0.05707757866808346, 0.033433123491704464, 0.08325543933148895, 0.045236789754458835, 0.00934777661625828, 0.02787558751047722, 0.04709995531343988, 0.010565171068135117, 0.017157000522794466, 0.02616072595784707, 0.044892436625169854, 0.009854460767071162, 0.02571326943247446, 0.004132855018334729, 0.08895500456648213, 0.04547266549031649, 0.004743892341918711, 0.04887097920956356, 0.07913678605109453, 0.11786405688949994, 0.022966269603265182, 0.03839191169078861, 0.0474536247285349, 0.04660651446985347, 0.03566040111971753, 0.030072146161858524, 0.038748753257095814, 0.0650806345843843, 0.06867243256419897, 0.03424435281859977, 0.015796609056581343, 0.015664689974593263, 0.05719988460519484, 0.013038361661269196, 0.05316819915814059, 0.038315620605966876, 0.026029546479029313, 0.06255949022514479, 0.0843923179698842, 0.020620931971019933, 0.06263015286198684, 0.01200826747143375, 0.03955393344429987, 0.019503869947844317, 0.03316534643194505, 0.021402382092284303, 0.023524217074736953, 0.034296684831913025, 0.0289197460349117, 0.023210667738957063, 0.01706658742789711, 0.044494509763483486, 0.020430287379505377, 0.03963172069883772, 0.042528960055538585, 0.03905439257089581, 0.01818782413777496, 0.023302560040195073, 0.08937830863786594, 0.005116125202870795, 0.03998235706239939, 0.019545492982225757, 0.037851648538240364, 0.03517301280849746, 0.01192820627641465, 0.02429454939972077, 0.04995642489354525, 0.06304861897868769, 0.014765235828235745, 0.02698513413114207, 0.07291254361293145, 0.04025064302342279, 0.055925293892089806, 0.04097236679600818, 0.050366538244166544, 0.04011005735290902, 0.05245354572044952, 0.02360041146831853, 0.06430736929178238, 0.014819420242149915, 0.006321248773019761, 0.043545157848192115, 0.10687062929251365, 0.040466468049479384, 0.07874089479446411, 0.07602600833134991, 0.03474117615925414, 0.05362387613526412, 0.054690411048276086, 0.10356578377208539, 0.005917617976332882, 0.044105950077729564, 0.09957219128097806, 0.026675525387482982, 0.05417687878278749, 0.03064715370003666, 0.035438038408756256, 0.07630847567426306, 0.051373813301324844, 0.09806772986693041, 0.03505568053307278, 0.025090723730889813, 0.05020813763673816, 0.013137968057500464, 0.03838928236759134, 0.031230347763214792, 0.03459876522954021, 0.02342868782579899, 0.0406680743742202, 0.0671853009345276, 0.047357313467987945, 0.04491650765495641, 0.03566704058487501, 0.04250884488491075, 0.011577972793020308, 0.015783018000157814, 0.008143049565010836, 0.008070432747315084, 0.04305369493418506, 0.03763366577082446, 0.0715671783047063, 0.03370881226978131, 0.05678439386455076, 0.06908883593444314, 0.06784917959677321, 0.034243335016071796, 0.017086200482611145, 0.04068735833945019, 0.029701096072260822, 0.019734434450843504, 0.034940227799649747, 0.04557301064154931, 0.033726817196501155, 0.08876496047845908, 0.042514086567929814, 0.028661940047251325, 0.07088470099759953, 0.039833846102867804, 0.03205734285126839, 0.012501810095272958, 0.05564020401132958, 0.012052076236744012, 0.023498914503891553, 0.02063626516610384, 0.025995241444823996, 0.04972797233079161, 0.044550929950284104, 0.025967363833582828, 0.04288056333150182, 0.01864447141997516, 0.054664514759289365, 0.04073175149304526, 0.04809902688222272, 0.08311868059848036, 0.03792702699346202, 0.03785166210894074, 0.02419943405714418, 0.006038242842935557, 0.04542692205203431, 0.06258175295910665, 0.05763638618269137, 0.02946662829656686, 0.02878891091261591, 0.03639153617301157, 0.02562814042903483, 0.06842794282627956, 0.031948770462934456, 0.041975214412169795, 0.05686520738527179, 0.10533336071031434, 0.05205698271415063, 0.0384487457839506, 0.012089115767074483, 0.03528522214453135, 0.04671623358236892, 0.02639716148509511, 0.022930463310331106, 0.061074523122182915, 0.049689828484718285, 0.020888792151319127, 0.0322262709295111, 0.05439143834103431, 0.006916173434417162, 0.023574136896058917, 0.03680888270693166, 0.12098488371287074, 0.03927545588729637, 0.009413306135684252, 0.03218188795394131, 0.10561417921313218, 0.032473725865461996, 0.08241191173770598, 0.014602022711187601, 0.06679730104016406, 0.03349941297035132, 0.07226551976054907, 0.04590652756659048, 0.047171561113957844, 0.05495217628777027, 0.028134772620562996, 0.013901023094409277, 0.018788195314950178, 0.03592505691839116, 0.05137944853465472, 0.07257067052913563, 0.02381071152298578, 0.03736292690570865, 0.030757276540888206, 0.05163864551910332, 0.037812965256827216, 0.06954237552625792, 0.04684802204636591, 0.013232257283691849, 0.007882809332971061, 0.06028631648847035, 0.007706457233455564, 0.0497732577579362, 0.024456892295607498, 0.020997780142351985, 0.046132975058364015, 0.02110834063829056, 0.057107128868145604, 0.0413952671390559, 0.03679543753553714, 0.0598637316642063, 0.02652071083762816, 0.010495032599594976, 0.05687581288761326, 0.014822913001158407, 0.01506914318140064, 0.03138663473406008, 0.05369012150913477, 0.03130400613216417, 0.036912773203636916, 0.04222569561430386, 0.07491071389189788, 0.03571234636807016, 0.018962918082252145, 0.0031513891008216888, 0.02254734717176429, 0.07181605137884617, 0.02379409589671663, 0.04153541176180754, 0.021546233212575316, 0.010017416888980992, 0.010887152897859258, 0.043525605861629756, 0.01746662792616657, 0.0804589997444834, 0.046154114816870005, 0.047125037360404215, 0.06917788008494036, 0.06443619595042296, 0.036354986884232075, 0.027717485458457043, 0.014217777659983506, 0.04307328763284853, 0.06520414152847868, 0.05025911258001413, 0.06753525537039552, 0.07564667332917452, 0.02115994322645877, 0.03768455928989819, 0.0334069015059088, 0.04512369153755052, 0.03116711847750204, 0.07243636809289455, 0.035132782467241795, 0.05516711921830263, 0.006339396616177899, 0.019569077163136432, 0.03165316328938518, 0.04068221165133374, 0.08845100911068064, 0.027943683588611226, 0.03206978039816022, 0.027896981719615202, 0.0335243728810123, 0.08230522567672388, 0.03686335549822875, 0.058597822806664875, 0.01894224651290902, 0.04346656652965716, 0.03375449124723673, 0.01391497122988637, 0.030506211798638105, 0.058941215808902464, 0.005541735445149243, 0.03087867663374969, 0.009770018780337912, 0.054263833045427284, 0.023797615797125866, 0.03737403452396393, 0.06866612897387572, 0.023278846937630857, 0.018606526045394794, 0.02940278493666223, 0.06065106298774481, 0.03787031164392829, 0.0456584110589964, 0.0422756290063262, 0.03230190044268966, 0.008980930899269879, 0.01271978862184499, 0.045735533349215984, 0.007007410101193402, 0.04150107788986393, 0.02169623355647283, 0.014918829015057002, 0.026313230095963393, 0.027212015885327543, 0.02792126139891999, 0.0399489154640053, 0.04830631933041981, 0.01291768844904644, 0.029868385488433496, 0.02293200358482344, 0.07294307768877063, 0.07461408552314554, 0.09968655835837126, 0.13238933389740332, 0.11407787219754287, 0.13096730091742106, 0.05922974246953215, 0.154585883553539, 0.12063444751713957, 0.19061447813042573, 0.1805927466068949, 0.10714480493749891, 0.16675937175750732, 0.12957740335592202, 0.14532317487256868, 0.1465571043746812, 0.10192809879247632, 0.13615337120635168, 0.16077594139746257, 0.1657006535679102, 0.08022365665861539, 0.0859903765044042, 0.14265455092702592, 0.05731694546661206, 0.10240730057869639, 0.182052506133914, 0.12656527784253868, 0.12409835521663938, 0.15658114291727543, 0.11347929574549198, 0.09436711522617511, 0.16766053411577428, 0.11147121885525328, 0.1402171581451382, 0.08337980801505701, 0.070406937705619, 0.1643796544522047, 0.20737859500305994, 0.22042329502957209, 0.144490137430174, 0.11778903805783816, 0.1732224313808339, 0.1350377510700907, 0.12391318301005022, 0.25233702255146845, 0.18784705948616776, 0.11076153229389872, 0.07966833681400333, 0.1438268965908459, 0.10674130051795926, 0.11340160348585673, 0.10544445724891764, 0.1597859723759549, 0.19407093551542076, 0.24173306726983615, 0.14220104526196206, 0.09636313454913241, 0.19571489015860216, 0.13783786153154715, 0.1095327732286283, 0.153136207056897, 0.14703262171575002, 0.17804942093789577, 0.19134942655052456, 0.09852778339492423, 0.08999171108007431, 0.11615239802215781, 0.172220628708601, 0.12193348923964159, 0.19492255124662602, 0.08519599520202194, 0.06341950621988092, 0.1265919849808727, 0.15146196261048317, 0.18088664726487227, 0.15421386994421482, 0.08421591922108616, 0.08831557352095842, 0.18427366337605885, 0.13920565242213861, 0.12855616744075501, 0.19346391808773789, 0.1376650793743985, 0.12113942684871809, 0.11938417889177799, 0.08701746817678213, 0.09844509033220154, 0.14799895057720797, 0.0796837124175259, 0.16052592838449137, 0.1863013838550874, 0.11953802992190633, 0.14719711217497075, 0.13790107385388442, 0.18869674817792007, 0.10080200207552739, 0.12856595191572393, 0.1668297086975404, 0.13663025918815816, 0.21388436162046023, 0.10307546758225986, 0.11323543025978974, 0.11028502429170267, 0.09752199772213187, 0.14011733207319463, 0.16136248063828262, 0.11440392184470381, 0.13652889962707246, 0.2154519675033433, 0.13166326071534837, 0.114477827878935, 0.1445776548768793, 0.1207689738699368, 0.1538754573890141, 0.15804018319717475, 0.10065617132931948, 0.19647061532097204, 0.13573814848703997, 0.16492685223264353, 0.13322044430034502, 0.15319523960351944, 0.19355029559561185, 0.08843177264290196, 0.1643895882048777, 0.17574712447822094, 0.20537883016679967, 0.10297095961868763, 0.1786323775138174, 0.0781270716605442, 0.20734920086605207, 0.07689656876027584, 0.16085629351437092, 0.17615938878485135, 0.13584889897278377, 0.2070642840117216, 0.1365683496530567, 0.20418843547148363, 0.23599097824522428, 0.08983686260346856, 0.12777821347117424, 0.06773382864360299, 0.13509815425745078, 0.13907983845898084, 0.09143943339586258, 0.1058106083156807, 0.21845299218382153, 0.07080689338701111, 0.14564030856958457, 0.09421634474503142, 0.09825191819774252, 0.06988557853869029, 0.09111121243664197, 0.15919420841549123, 0.14404672836618765, 0.1335968683872904, 0.24549027851649693, 0.12323534009712082, 0.12799754313060216, 0.20044281360294136, 0.18113059417477675, 0.11254215067518608, 0.13392895699611732, 0.059407708634223254, 0.17188836368066923, 0.12287206601883684, 0.11957545791353498, 0.185029944937144, 0.09846337006560393, 0.2688351401260921, 0.10733525614653315, 0.09905258951974766, 0.13302003219723701, 0.11173381190747023, 0.12598971729832037, 0.06476329732686281, 0.12228522822260857], [0.019630871347284744, 0.03919572802260518, 0.04102026458297457, 0.03945672991020339, 0.053840796995375834, 0.021132265783048103, 0.06661962664553098, 0.07836591598710843, 0.07043346842484814, 0.02839983214757272, 0.04315328351887209, 0.06990773270704917, 0.03285929321178368, 0.0686935485739793, 0.013493789276773376, 0.046304749591009955, 0.024367698867406164, 0.02208985511346587, 0.04609459711770926, 0.04813742178625294, 0.021886108010741215, 0.0573472488405449, 0.022615565386201655, 0.07882816796856267, 0.017092370062268207, 0.0395933257948075, 0.0371751932294241, 0.025755973033873097, 0.04811336432716676, 0.06757254765502044, 0.05356795806437731, 0.0651066360462989, 0.015380865561642816, 0.017862863539318954, 0.06345495288925511, 0.020064076940928186, 0.05561050453356334, 0.00681981594867206, 0.04750666581094265, 0.040432548083897145, 0.04161497338541916, 0.04322044152234282, 0.08085577309663806, 0.04995692361678396, 0.01357187847939453, 0.019154612706708055, 0.05822850976671491, 0.021011651094470705, 0.022662094228767922, 0.024145398920934116, 0.03955236942108188, 0.0671422275315438, 0.021358158572443893, 0.027649391076660583, 0.05131221589233194, 0.07419293919312102, 0.006054795280631099, 0.012617356975429823, 0.006179694493766874, 0.04490032798743673, 0.0149818089391504, 0.03874620535810079, 0.02694834056975586, 0.03135195480925696, 0.018303093666742955, 0.042584766168147326, 0.05044124834239483, 0.039465761211301596, 0.003934489970561117, 0.03856079227158001, 0.038698042942477126, 0.053853261683668406, 0.012076703665245856, 0.023978321546954767, 0.008655198467230158, 0.08442889779273953, 0.05117915517517498, 0.05763920210301876, 0.02372514147178403, 0.03739450931815164, 0.01742196675123913, 0.03746384881170733, 0.03370409305872662, 0.01618234603665769, 0.01034745292937649, 0.028669631241687706, 0.05431781729151096, 0.09408799306090389, 0.01187587680760771, 0.03017462869840009, 0.023648489067064862, 0.040609856069620164, 0.0659177703782916, 0.0671256577063884, 0.044162845239043236, 0.021656328912026117, 0.01649589028342494, 0.04708152969500848, 0.026240986472527896, 0.1036949564835855, 0.0298275682143867, 0.05881682676928384, 0.05599244171753526, 0.02476670459977218, 0.06932684566293444, 0.08503790332802705, 0.0527539196025048, 0.019959879407126988, 0.07592662330716848, 0.05329730401613882, 0.024861339878823076, 0.054946873536599536, 0.06971904568906341, 0.03297550929710269, 0.026019760307722857, 0.0014481157600779884, 0.0913238585261362, 0.04768579227051564, 0.04914273587720735, 0.057046142140669484, 0.02135897451080382, 0.04032214704368796, 0.03850711336625474, 0.0514589287340641, 0.04325941996648908, 0.04626035983008998, 0.020896200057385222, 0.023570428702182004, 0.04472367478800671, 0.024517222540453076, 0.024927296875310794, 0.04440921451896429, 0.017614216078072786, 0.026681272579090934, 0.04260512221870678, 0.002807152382696846, 0.025786829413846135, 0.029911536922944442, 0.02721027544300471, 0.11653809089745794, 0.04335131057138954, 0.0021376357305728432, 0.028029452111305933, 0.06409712521625416, 0.040003659669309855, 0.037982945064348836, 0.031134538618581634, 0.07537460114274706, 0.09378179056303841, 0.010727457136714032, 0.018647431528994014, 0.03823557382981692, 0.0625675715772169, 0.012108767837552088, 0.007719692907163075, 0.0253296715340444, 0.023624506246830736, 0.00925443903543055, 0.07532770080225808, 0.014503999846056104, 0.06799259475831475, 0.019354044326714108, 0.025352692530889596, 0.04403842905802386, 0.030764591148389236, 0.1288043348384755, 0.008958579107586826, 0.01689767461669232, 0.04659513543759074, 0.009647533879615366, 0.01620545015404267, 0.038950980441378694, 0.019466238395710076, 0.03102962692667331, 0.012128154431203646, 0.031100740789302757, 0.045208016476993046, 0.04616990093407886, 0.016699396506217972, 0.03419907417680536, 0.08000934815832547, 0.02444414940795728, 0.008551079813124878, 0.006466291146352887, 0.007695355552381703, 0.04883017889889223, 0.02355342631095222, 0.03364015470391937, 0.06940600355820996, 0.08971955068409443, 0.01226420494328652, 0.10253277527434485, 0.052559353078582456, 0.06345743632742337, 0.01983181949305747, 0.029327253811061382, 0.05816926687423672, 0.04808791587129235, 0.02431146358139813, 0.027697002182581594, 0.025787340011447668, 0.08631610045475618, 0.03079414813380156, 0.05459078514416303, 0.03956673061475158, 0.052728338832301755, 0.028010985780773417, 0.01913700472297413, 0.03747367739145245, 0.012041804912899221, 0.04464513435959816, 0.03422277540500675, 0.019701876644311205, 0.03391525994188019, 0.0035619174180153224, 0.019552341096901467, 0.024832240904548337, 0.021638888865709305, 0.04764292921338763, 0.021811737180022255, 0.0383130455655711, 0.015990027159984623, 0.03954609975750957, 0.009460950320187424, 0.03655264413516436, 0.009359143774158188, 0.012334580899083188, 0.04131497948297432, 0.0489863776601851, 0.027278544547568475, 0.019106426542358737, 0.059519456566444466, 0.022994890210351775, 0.0700651053339243, 0.036776357130812745, 0.00882745984875198, 0.020793508871325424, 0.03427368928013103, 0.004788133673303361, 0.052290992478707006, 0.05227063982082265, 0.02987890617389764, 0.048725226494882784, 0.06896224844136409, 0.018701610853895545, 0.04729351760553462, 0.04505425026374204, 0.025651356504697884, 0.017189293700669492, 0.04340134574366467, 0.02080318986970399, 0.05916901358536311, 0.029826055081295114, 0.045099047145673206, 0.023395514248737266, 0.03870335926434823, 0.02350349970428007, 0.026858660292678645, 0.012695929634251764, 0.03678368191633906, 0.016605561898489083, 0.01175598899966904, 0.016853885359263847, 0.009667871270461805, 0.022887154116428325, 0.044448678115648885, 0.05015752570969718, 0.02515427192806133, 0.04469966143369675, 0.04640866044376578, 0.02919607942125627, 0.021956689223381023, 0.039236514762576134, 0.049893840216100216, 0.026555122741098915, 0.026886507369843975, 0.006998175663673984, 0.027029510321361677, 0.04585377146889057, 0.047037133148738315, 0.025462644041648934, 0.06583060576979603, 0.08004754289452519, 0.04338000581732818, 0.11060985936118023, 0.043529388694358725, 0.03438704534034644, 0.05928517199520554, 0.055290134224508486, 0.06495964500520911, 0.017660641444048712, 0.05282829382589885, 0.027384784471775805, 0.006056175675309662, 0.02676502246010516, 0.048863196412899663, 0.03774609563073941, 0.020712451077997684, 0.041663729519184144, 0.03563463714505945, 0.1064985478296876, 0.04223899490066937, 0.051460034746144495, 0.009998605353757739, 0.047229016066661904, 0.031808931180941205, 0.024779359277869974, 0.044844511696802716, 0.0034944464402672437, 0.027464525907167366, 0.02700903213449887, 0.03433273879012891, 0.055874057712831667, 0.04675195166575057, 0.015494004490652254, 0.0557534040084907, 0.009370861225761473, 0.008540179996219064, 0.07913071994802781, 0.01839053308192108, 0.06415773196411984, 0.007104913887035633, 0.03116738310615931, 0.03147870854341558, 0.05379096877628139, 0.03150606707536748, 0.010262241653565849, 0.04343309100451214, 0.047599180668060265, 0.020594045020905987, 0.02884619283889021, 0.12226346081921033, 0.019161964633635113, 0.022487217094749212, 0.023376608566780175, 0.03198511279853327, 0.04048249165394476, 0.014979900559410453, 0.05519469827413559, 0.07733617124280759, 0.020924035260187726, 0.033745711004095416, 0.07023751429681267, 0.05246934201568365, 0.052001061250588725, 0.04409467961106982, 0.012654181070891874, 0.05361576085644109, 0.03498270069914205, 0.050850805294300826, 0.013770049720603441, 0.011591196592364992, 0.11131018892462764, 0.1215380390307733, 0.11279186513274908, 0.1374240501650742, 0.1832303207899843, 0.1521533897944859, 0.09905976163489477, 0.14581291430762836, 0.10980694208826337, 0.1514463291636535, 0.0955876572323697, 0.13739234900900296, 0.16932073288730212, 0.24681654306394712, 0.11644689579095159, 0.2134822481977088, 0.13706087108169282, 0.10981955605426005, 0.14741629255669458, 0.12279239243694715, 0.23728261036532267, 0.17307210873280252, 0.10225676758480923, 0.10175167968762772, 0.09106579130249363, 0.16824623197317123, 0.11258070503494569, 0.127435851842165, 0.20370301151914255, 0.1306576311056103, 0.11777307891419955, 0.09915393551013299, 0.09800612567258732, 0.06299544218927622, 0.09574496200574295, 0.1618755209658827, 0.1674932073801756, 0.10189894214272499, 0.06085598056337663, 0.14403581752308778, 0.13056976082069532, 0.20450442922966822, 0.18397554223026547, 0.0936540292043771, 0.09485558580074992, 0.1253607560481344, 0.11520346679857799, 0.05957304047686713, 0.07745973246970347, 0.0662504153858338, 0.1271770450153521, 0.20843765246016638, 0.1124515255380954, 0.13634216678994043, 0.14547940077526228, 0.2686539441347122, 0.08783227338322572, 0.13494709879159927, 0.11165482364594936, 0.14026879466005734, 0.05632480852571981, 0.1044591972604394, 0.05546128111226218, 0.09852787838982684, 0.13173525328082697, 0.1204397486788886, 0.145329444536141, 0.16098977492323943, 0.06698989641985723, 0.1099566879815289, 0.10736701837075607, 0.12893751769193582, 0.07224393556160585, 0.20629008912614413, 0.05190532335213252, 0.13368338160216808, 0.15115773464952195, 0.120341048975076, 0.10600085596420936, 0.1665012298950127, 0.06306837791843073, 0.11378383583256177, 0.12520881848675863, 0.15747644273298128, 0.13073186283665045, 0.07886602343725306, 0.09891123710466282, 0.22137405829770224, 0.18922584264406137, 0.18446118331381253, 0.13600038870104722, 0.12894895779235022, 0.1579387014997857, 0.18608349268989904, 0.09419641617153372, 0.145704253709742, 0.15359529027981417, 0.11540911719202995, 0.11907184922269412, 0.2027645975883518, 0.08914241593863283, 0.15023636551839964, 0.16148562117346696, 0.16943358683160373, 0.16523528711072036, 0.24963232768433435, 0.15191461332142353, 0.12069871835410595, 0.12773741994585308, 0.10407803021371365, 0.11299550706254584, 0.17803542954581125, 0.13677682275218622, 0.165704466934715, 0.1607470629470689, 0.136330034583807, 0.17580290005675384, 0.07235118480665342, 0.13388846202620439, 0.09310102994952883, 0.08914077388388769, 0.06701941269316844, 0.1346911960946662, 0.17740581690200738, 0.21736411989799567, 0.05568165571561881, 0.12849429861775466, 0.14428466345582688, 0.12584267875977925, 0.06803436537406274, 0.12985188434166567, 0.12077760483537402, 0.10581526306590863, 0.1268409937620163, 0.14545854260878904, 0.13966474921575614, 0.18347097001969814, 0.12206002244991915, 0.10245470303509917, 0.12594091705977917, 0.09466267150959798, 0.10035956331661769, 0.1641775867236512, 0.14078187569975853, 0.12972541898488998, 0.06774317207080977, 0.11118734015950135, 0.22860379463859967, 0.16061594284006528, 0.08449819657419409, 0.15645819237189634, 0.18089799237038406, 0.17462744670254843, 0.14052095184368746, 0.12316060625016689, 0.16499040382249014, 0.0756373977554696, 0.16136774607002735, 0.10982204627777849, 0.08289804136646645, 0.10156371870211192, 0.07850371966404573, 0.1515529134443828, 0.16365887384329522, 0.1186316292732954, 0.18103436433843204, 0.14907343792063849, 0.15556677377649716, 0.15187292412987777, 0.15674894462738717, 0.11187874020210334, 0.13382066280714103, 0.09490654378065042, 0.1565325055271387, 0.059920131494956355, 0.10970611178449222], [0.023200647473069172, 0.05151401899222817, 0.01764369333562042, 0.047004108849380694, 0.038078309768544774, 0.05370973117117371, 0.05259531204189573, 0.06063663733324834, 0.05635972593777946, 0.03687228841174926, 0.02120616163925401, 0.04592180817521044, 0.054614754393696785, 0.04982742181579981, 0.06318533699959517, 0.06023145014686244, 0.047976089907544, 0.012565166606301708, 0.00857196596916765, 0.027306048964549388, 0.005333828498675887, 0.05352828412183693, 0.015133741411513515, 0.020669275894761086, 0.048770634058330736, 0.03765885638339179, 0.02804836118593812, 0.06992672490222113, 0.013285360282420047, 0.0355009216416095, 0.022173065559140274, 0.05677884005542312, 0.017946755912687098, 0.012509714180071439, 0.009750054583751729, 0.024482210133490816, 0.013765908112483365, 0.008850962605460413, 0.07246413374585764, 0.06728000406708036, 0.06333193449037415, 0.06080640000956399, 0.013674693498095232, 0.027977098045604568, 0.0476598586621029, 0.02384888251045985, 0.01507435433034386, 0.01668943900481931, 0.009387987449632158, 0.07146770507097244, 0.060110216295080524, 0.017788236561630453, 0.01261899309299354, 0.02639846087965582, 0.05742709884153945, 0.016949428178902184, 0.03528501519135066, 0.016044203092211058, 0.053468050568231514, 0.011674880316214902, 0.021106262624795948, 0.038377014454454184, 0.049739331007003784, 0.023835433946390237, 0.015757986843319874, 0.03514338118423309, 0.03397002111056021, 0.03904250463736909, 0.015500455662342054, 0.022900131098659973, 0.023651354181181108, 0.04321718116157821, 0.013210779105845307, 0.04889123687254531, 0.009175639915546136, 0.04814931311245475, 0.042614095844328403, 0.03452921539012875, 0.0307602417389197, 0.011422988609410822, 0.045717535207846334, 0.06482115600790296, 0.03632278361224702, 0.012592740573122032, 0.02981399412133864, 0.029493912189666713, 0.06034311665488141, 0.02113579077246998, 0.010698885723416294, 0.025403095808412348, 0.03000493048291121, 0.025031548691913486, 0.02474493041102375, 0.003532577775851158, 0.018584962202502147, 0.01914602075703442, 0.04608870743374739, 0.04812465514987707, 0.06462885918361799, 0.04337569033460958, 0.06136047813509192, 0.03586677076028926, 0.016207697801291943, 0.0039000458366769764, 0.032365217937954834, 0.026990986495677913, 0.02627251629850694, 0.07216601260006428, 0.017501908354461193, 0.006145369103510997, 0.02148295134039862, 0.02513028571515211, 0.014777420620833124, 0.03279322086434279, 0.01990470433208559, 0.027528148743190935, 0.04090891020106418, 0.012764090173212546, 0.025366073241457343, 0.04672529881021806, 0.05736670922487974, 0.019784340701465095, 0.037440402034137926, 0.01040016661863774, 0.024321896057309847, 0.0355400765048606, 0.07324500541601862, 0.12732449067490442, 0.034235871130866666, 0.02596146397159568, 0.07023958382861954, 0.0354914323293737, 0.017617132082315426, 0.01649112527125648, 0.04288242930280311, 0.04107439810676234, 0.05504297445129071, 0.041381075579140864, 0.015852820593863726, 0.06668371427804232, 0.042806280710335286, 0.07728773741317646, 0.046562318091413805, 0.0058115854293906265, 0.0213195499298828, 0.010739265342376061, 0.047050303513450284, 0.033966346843434234, 0.033995025125997405, 0.02948629902675748, 0.021244256291538477, 0.05311776365020445, 0.016239470203540156, 0.051529537088104656, 0.031042010190763643, 0.025248571332277994, 0.04303448900048222, 0.05025895990963493, 0.02479664665380759, 0.04401773034727999, 0.02348253466854138, 0.02801395606781755, 0.046534796711057425, 0.08020744645701987, 0.04538883588143757, 0.04972161106499178, 0.034683069812932184, 0.02808196054372404, 0.022198171354830265, 0.04082003229164651, 0.04619211617058941, 0.0535112800342696, 0.04938708312277283, 0.03329505518610988, 0.019051661981003623, 0.021215596668688313, 0.017081873125529716, 0.06466140850846257, 0.03680163934560759, 0.1635717363762004, 0.04906899269138064, 0.05105457275307604, 0.012838796878765737, 0.023859532117577534, 0.026976903501365865, 0.0108796389706965, 0.05803868280989783, 0.02458903020513909, 0.05163156839885882, 0.03467656944745353, 0.05739183537662029, 0.06889638983245407, 0.0385417220448809, 0.07236111177397625, 0.037932204215654304, 0.04605817335790821, 0.027843087379421507, 0.08312776618238006, 0.007080018437201423, 0.03926647547632456, 0.02682952060630279, 0.07754441364003078, 0.024628258010904704, 0.016224941072453345, 0.034086932694273334, 0.00386792017213468, 0.018959435501268933, 0.023417585296556354, 0.022802707040682435, 0.03878000658005476, 0.03284834844193288, 0.07446862797119788, 0.027435430325567722, 0.09062665022377457, 0.09896600845136813, 0.07270659466407128, 0.06053522348936115, 0.0762842655447977, 0.019939860927739313, 0.05140500555613211, 0.041472033198390684, 0.023019677094583, 0.02032986080407032, 0.03868059780714767, 0.029800626981471266, 0.004313248642055052, 0.07484818688992943, 0.04685934340315206, 0.029609724546649625, 0.0718382734007069, 0.03645449743739196, 0.03215164904083524, 0.052296732884964774, 0.02341492204660816, 0.0634122866072825, 0.010182909883691795, 0.005904061270744673, 0.02820130467547902, 0.05963172697063003, 0.01515920683076339, 0.023772235194753324, 0.05194645953763809, 0.04931411685954247, 0.03712485950174076, 0.05846283505005496, 0.048988576113645516, 0.01851782455508198, 0.047259882624660215, 0.025265896027641635, 0.09279094623135668, 0.02360185674790825, 0.08003044381205525, 0.032182373106479645, 0.033473214733281305, 0.008998415050362902, 0.048407261592469046, 0.03826302396399634, 0.006305347304857735, 0.02891599034358348, 0.028755723764853816, 0.003095397027209401, 0.06766918461237635, 0.01681917150770979, 0.01216505910269916, 0.013424847574372376, 0.03793467069044709, 0.07873635539518935, 0.029358503741345236, 0.054216447552399974, 0.02909914051581706, 0.020440353446507027, 0.07295023623321738, 0.007646438266549791, 0.03108936854239021, 0.06799918333334581, 0.024240102053486874, 0.08808641867446047, 0.016995638110009686, 0.024415040255657265, 0.023850393947213888, 0.025645673773916702, 0.018136167266805257, 0.053318671083876064, 0.06767349330974476, 0.02104549472486334, 0.01992195099592209, 0.04883582091757229, 0.014084029077951397, 0.023970096006191204, 0.0652064960449934, 0.019531589799693654, 0.04214220527293427, 0.002690757969893249, 0.04822228276836021, 0.012082411841090237, 0.04152103021208729, 0.05399400002456137, 0.015337856619485786, 0.017987934506631324, 0.09880468675068446, 0.024772864001403962, 0.0808689095345991, 0.031386471885655604, 0.010243676935455628, 0.020906817434089522, 0.007762075900765402, 0.025158187075118934, 0.014814353281898158, 0.04260029783472419, 0.03222323787797775, 0.021966499143413136, 0.05384331775297012, 0.03215516385223184, 0.016753857423152243, 0.027015841233411005, 0.026258226351014206, 0.020682878825547438, 0.026079897170088122, 0.037087428117437024, 0.01105357548554561, 0.015940214207928096, 0.026154651373092617, 0.0505709876306355, 0.09425259208572762, 0.027085740518357073, 0.03751144465059042, 0.014010405483921724, 0.09172293211200408, 0.020912693547351018, 0.03605534242732184, 0.02281632523850671, 0.01184750216946538, 0.0395852953328618, 0.02446564200467297, 0.006709361473830151, 0.019692153237493973, 0.026945129402780106, 0.03632121280367885, 0.03422356929097857, 0.03122775915211865, 0.012883291812613606, 0.052956591227224896, 0.03530731524473854, 0.01951727271080017, 0.02199203920151506, 0.02430062907348786, 0.047286247102809806, 0.07874318824282714, 0.02149930573068559, 0.03873703495732375, 0.01687486226936536, 0.01756035566463002, 0.13715377609644616, 0.19033300823399, 0.14207580126821995, 0.23800663437162126, 0.15783556417695113, 0.09626281314662524, 0.14608579395072802, 0.12506491478000367, 0.1616743081914527, 0.13188139615314348, 0.14645631478301116, 0.1187869595097644, 0.15325520852846758, 0.09965421937938247, 0.19078278195645126, 0.167451925309641, 0.22857749462127686, 0.08532486257276364, 0.08767331298440695, 0.1639352004442896, 0.09732029640248843, 0.1949486205620425, 0.09337120902325426, 0.07956848360065903, 0.08712285145052842, 0.07911617894257818, 0.16478229713227066, 0.13899367808231286, 0.08912486902305058, 0.16317004364516052, 0.12602686030524118, 0.08943801971950702, 0.1444454084017447, 0.1152092343462365, 0.1186404637992382, 0.15266206035656588, 0.1392282476382596, 0.13009637407958508, 0.19646634055035456, 0.2076525738728898, 0.16001269806708607, 0.13688089645334653, 0.07367733400315046, 0.21185079216957092, 0.17462839665157454, 0.11603312513657979, 0.10221013865832772, 0.07147763203829527, 0.13700562476047448, 0.14359398266034468, 0.13973252129341873, 0.10902425194425241, 0.17185731391821588, 0.2440956990633692, 0.12131382391921111, 0.1028361754225833, 0.16015217772551946, 0.1076292178726622, 0.15719444357923099, 0.08466981165111065, 0.13198245715882095, 0.08998981796737228, 0.14526943489909172, 0.07950193967138018, 0.13735388964414597, 0.11743622698954173, 0.13499361915247782, 0.11081097714070763, 0.07875755282917193, 0.171294686251453, 0.1017715675490243, 0.11769625517938818, 0.1280139908194542, 0.1339891023401703, 0.05886836150395019, 0.19555751074637684, 0.11853010686380522, 0.11860919690557889, 0.10148243699222803, 0.15943739536617482, 0.09531090315431356, 0.21252655876534327, 0.16246307800923074, 0.08159006333776883, 0.111940256186894, 0.09891474513070923, 0.1114548390199031, 0.09227988722601108, 0.10757853809211936, 0.10307148458170039, 0.3090605687882219, 0.16350906688187802, 0.19061781652271748, 0.05838301897581134, 0.12868236138352326, 0.18921273334750108, 0.09718660464776413, 0.16903772950172424, 0.12072683684527874, 0.12950203168605054, 0.15532746804612024, 0.0698279437742063, 0.10500066820532084, 0.09195858732398067, 0.11480604883815561, 0.13948249470974716, 0.1205677610955068, 0.2025686502456665, 0.13642337386097225, 0.11126053373196296, 0.128213995801551, 0.04389290365257433, 0.05435380678890007, 0.19503335601517133, 0.08198820733066116, 0.10897045090262379, 0.12715773390872137, 0.2587732257587569, 0.1423287998352732, 0.1117121869964259, 0.16027431402887615, 0.1562802940607071, 0.0925941914319992, 0.17820384193743977, 0.12720924828733715, 0.12100927026144095, 0.15424904519958155, 0.22542272747627326, 0.07459912382598434, 0.18938323562698706, 0.12737582863441535, 0.07243165227451495, 0.0718645327059286, 0.10956985516739742, 0.16972048500818865, 0.17048842380089418, 0.07399842355932508, 0.0624710296147636, 0.13673250084476812, 0.17837438492902688, 0.1368771373693432, 0.11591409652360848, 0.1133933864267809, 0.10623237889792238, 0.05335435184783169, 0.12772420208368981, 0.17577421159616538, 0.16501802019774914, 0.10487047090594258, 0.1859380147819008, 0.036837659377072535, 0.25399536213704516, 0.07773363670068127, 0.12466490481581007, 0.09653299222035067, 0.1142762622662953, 0.13396770134568214, 0.09984083008021116, 0.09519114172352211, 0.11715215151863438, 0.09433565834271056, 0.111324064965759, 0.10382309103650705, 0.16404995428664343, 0.08226650168320962, 0.13671445181327208, 0.0809329632403595, 0.12435444790337767, 0.08853869619114058, 0.08061329860772405, 0.10999953068260636, 0.18967018808637345, 0.16621815865593298, 0.10305580363741942, 0.10423266155911343, 0.10710842867514916], [0.018537069504548396, 0.03050751458587391, 0.06872398765491587, 0.04610911098175815, 0.03373178746551275, 0.023927928447457295, 0.0765046537188547, 0.01661122257688216, 0.014901879210291165, 0.031210992551807846, 0.030494669917970896, 0.041612062470189164, 0.021947396686300635, 0.05683322463716779, 0.04079009532662375, 0.04084283785362329, 0.020845803565212657, 0.023319689656740854, 0.015504525176116397, 0.08050732500851154, 0.04143958904647401, 0.040490969949002774, 0.02298713455508862, 0.07704448939434119, 0.012137269701010414, 0.04022475012711116, 0.014292378344440033, 0.024959929320695143, 0.01890262515683259, 0.08145995424794299, 0.04916489343824131, 0.056063745569969924, 0.02334575727581978, 0.009514866712769228, 0.04117739632991808, 0.06468924880027771, 0.023363139646660005, 0.0734202235138842, 0.009412162804177828, 0.0372382494887071, 0.029416905250400305, 0.09790685599935905, 0.0012498269414728774, 0.028035888015957813, 0.043508432140307765, 0.04181810302127685, 0.004328616612058665, 0.036117774434387684, 0.03248756119449224, 0.03771978882806642, 0.03662236360833049, 0.012842674706397312, 0.05916266928293875, 0.02577093642737184, 0.04153694525094969, 0.019043935163478767, 0.015771959575691392, 0.025842067253376757, 0.027283869351127317, 0.04275927519691842, 0.05713796828474317, 0.05822328504707132, 0.037704070564359426, 0.0626501492889864, 0.011835470047247196, 0.020909930213487575, 0.0119734136720321, 0.035181650559284856, 0.005992301781329193, 0.019453261413478425, 0.033334464499992986, 0.01975375403916197, 0.02261603018268943, 0.028231316279353838, 0.050522994848766496, 0.034860642427312474, 0.09401904711765902, 0.01563066483608314, 0.012109120675761784, 0.0569709808166538, 0.031996027034308226, 0.044159442385924716, 0.05140224391860621, 0.02939485286229423, 0.0484568828583828, 0.04066877326528941, 0.05803328167114939, 0.08087797476244823, 0.030133492512894527, 0.011091725268800343, 0.014096436938936157, 0.053371522176478586, 0.022236123514760817, 0.016569950684372867, 0.04564329669145601, 0.020396421696724634, 0.07711228182805435, 0.0020927858380933423, 0.042891100980341434, 0.032847503665834665, 0.02445524345551218, 0.033074426132121255, 0.06577421950974635, 0.030324652791023254, 0.015594716050795146, 0.040996397113693614, 0.025424959903050746, 0.020657766244507263, 0.005960344902372786, 0.020807405268507342, 0.04527273514707174, 0.023154028724612932, 0.04789015005475708, 0.04663814777242286, 0.05252897506579757, 0.013100478149551367, 0.08806926530918904, 0.07747952533619744, 0.0576765825971961, 0.03962644848174282, 0.012514603024880801, 0.04132174447711025, 0.06942182699484484, 0.03865426725574902, 0.028990340818251883, 0.010920574140202786, 0.007032522682233581, 0.0358329627529851, 0.051365263760089874, 0.0744117870926857, 0.042919178759413104, 0.04405799800796168, 0.024432300490194132, 0.04861253200631056, 0.046086600582514486, 0.030097445340028832, 0.011623951174052698, 0.00794909117809896, 0.06184234656393528, 0.023537931963801384, 0.05612128533955131, 0.010139193568777825, 0.07986672009740557, 0.008586916640134794, 0.04719396634027362, 0.04241801618731447, 0.05165046559912818, 0.04864076245576143, 0.027214032830670476, 0.034032436154250584, 0.02497179520183376, 0.009104074827129287, 0.06255253524120365, 0.04577303597969668, 0.07632402769689049, 0.01862177611993892, 0.0135085245128721, 0.07129093991326434, 0.013251541248921837, 0.0378400829088475, 0.07637102981763226, 0.016891678063465015, 0.026231622689270546, 0.039139290872429094, 0.07834982113646609, 0.03430752442883594, 0.014824633087430681, 0.08009217014270169, 0.04541548534429499, 0.027921877169449414, 0.03253739959161196, 0.05585801375231572, 0.021067087405494282, 0.04109522234648466, 0.028059431484767368, 0.05885413262460913, 0.034255284017750194, 0.02503221365623176, 0.03507957514375448, 0.021525349601038864, 0.018297838413023522, 0.014358550775796175, 0.060431970815573416, 0.014645839110016823, 0.02182086686869817, 0.02946102020463773, 0.015806100065154687, 0.009034560610806304, 0.030743437819182873, 0.11825855714934212, 0.042366688405828815, 0.029749597755393813, 0.04928576088111315, 0.022318858985922167, 0.044997372065803835, 0.035636486152985265, 0.07231729876782213, 0.03255047156874623, 0.02120997670239636, 0.029048331813620668, 0.04488451812150223, 0.011144595021115882, 0.0744291575891631, 0.04354548693767615, 0.02903470683044621, 0.027913210580923727, 0.02223253745718726, 0.025055066715659838, 0.051553122965352874, 0.06760574158813272, 0.05648052891982453, 0.0739547869722758, 0.004190759500488639, 0.006187504855915904, 0.012270519559803818, 0.09772677280540977, 0.05351410273994718, 0.01050161523744464, 0.0355160326164748, 0.010953109046178204, 0.03611096872815064, 0.02665897591837815, 0.01249698655945914, 0.05031974307660546, 0.05324852752632328, 0.08195457234978676, 0.05570573353075555, 0.024606422754004598, 0.03459371692900147, 0.020918303335617696, 0.03695416044709938, 0.0037299854531218962, 0.051571538405758996, 0.04580100180049028, 0.009975087330011385, 0.05913586036435195, 0.017326542675229054, 0.05752269085496664, 0.05937450791576079, 0.02192782604002527, 0.034884720242449214, 0.015548450140548604, 0.052590033039450645, 0.013634303701110184, 0.008354296176029103, 0.018570363521575928, 0.02323899827232318, 0.023496865328135233, 0.03367660899779626, 0.015759423641221862, 0.018881397188774178, 0.06741442185427461, 0.03218182010043945, 0.03297627264899867, 0.01775769400410354, 0.014824074992377843, 0.03180033074957984, 0.024036097107455134, 0.03007728945729988, 0.00568600047180163, 0.06670071836560965, 0.012705995701253414, 0.04781284795275756, 0.010825371436242546, 0.023810591083019972, 0.009983733562486512, 0.027640989116792167, 0.0204886363020965, 0.07150349100785595, 0.00938498747668096, 0.04634031161133732, 0.0008456265994547201, 0.05546968476846814, 0.04730083221303565, 0.042634747057620964, 0.01978264097124338, 0.040563593552048714, 0.025285787281713316, 0.0631483161289777, 0.040727307088673115, 0.05024758427004729, 0.028427814931741784, 0.059152844095868726, 0.05432335752993822, 0.02635977929458022, 0.017643425314288055, 0.023114753421396017, 0.02857417832793934, 0.017626746923529675, 0.004381486364374203, 0.03280633355357817, 0.02724933361501566, 0.023286427870126705, 0.005305397881394518, 0.04408630648893969, 0.05322134541347623, 0.03481848843927894, 0.013646784504609448, 0.10343146097979375, 0.06707578538251774, 0.008430617794926678, 0.0352100947472666, 0.00647041663926627, 0.02337915137676256, 0.045141041677977355, 0.030599975160190036, 0.06695066352507897, 0.03611956576683691, 0.06809435465506145, 0.06046509010983365, 0.012932826565312487, 0.002584443618876061, 0.03739433629172189, 0.043448212157402716, 0.05303828345079507, 0.026250329899734685, 0.01964096285934959, 0.027593506932524697, 0.017228434993220226, 0.051608365893896134, 0.049155146282698424, 0.06307458651385137, 0.057934860166694434, 0.04787332917164479, 0.07405421949390854, 0.03634314305548157, 0.04124400132734861, 0.029152666750763143, 0.036753836553543806, 0.03134010758783136, 0.03122187964618206, 0.027270108660949127, 0.03377785660060389, 0.017436054834563817, 0.018562670630802, 0.02325700150270547, 0.043705183546990156, 0.03832322019817574, 0.006379735098952162, 0.0398257647507957, 0.03311892445864422, 0.03661641624889203, 0.024785369401797652, 0.05698204772280795, 0.04923865698011858, 0.04623787317957197, 0.05046502420944827, 0.022310440062678287, 0.03267591233764376, 0.08264243043959141, 0.016602381265589168, 0.07068205651428018, 0.1657623052597046, 0.19407637736627034, 0.12059564888477325, 0.06818375164376837, 0.12988619107220853, 0.14428855824683393, 0.1405827256717852, 0.088775945960411, 0.13572769904775278, 0.11815980316272803, 0.11827248068792479, 0.08255987986922264, 0.12364676302032811, 0.17935524801058428, 0.10593890571700675, 0.14393562504223414, 0.09667766945702688, 0.12674720665173872, 0.1548660642334393, 0.11704456300607749, 0.1299776711634227, 0.14756520385188715, 0.1588629340486867, 0.1318051288170474, 0.16060258927089827, 0.07420871513230459, 0.10085017127650124, 0.10807857768876211, 0.13563079067638942, 0.1114458552162562, 0.0931502440944314, 0.1589750958872693, 0.09484261221119336, 0.1123801843662347, 0.14016767937157834, 0.1339470331690141, 0.09234529800180878, 0.1506579393254859, 0.12842838572604315, 0.2646520531603268, 0.1792601038302694, 0.21207047466720852, 0.12199818076831953, 0.08725321838366133, 0.08807368935751063, 0.11642027007681982, 0.10220270869987351, 0.16015590966812202, 0.08849479497543403, 0.18842931038566998, 0.16547387359397753, 0.19293311371334962, 0.11566795116024357, 0.10629498732409307, 0.1483078875711986, 0.11732372588344983, 0.08488703106663056, 0.10052752787513392, 0.14897119626402855, 0.0848127586234893, 0.14547570954476083, 0.11974647587963513, 0.12699648684688977, 0.11583318800798484, 0.08548097312450409, 0.11122037802955934, 0.13904513817812714, 0.07180729827710561, 0.08968452470643179, 0.12330666769828115, 0.11959873166467462, 0.07146334209080253, 0.07198603118636779, 0.11114571203610726, 0.2872971551758902, 0.13227611354419164, 0.18235545844904014, 0.16028495345796856, 0.08655549439468554, 0.07982339563646487, 0.12666576887880052, 0.11690785177052021, 0.17016024355377468, 0.09485496154853276, 0.1651157428111349, 0.0951468673135553, 0.11426185018249921, 0.15305958688259125, 0.19145807357771055, 0.06243887384022985, 0.12407095597258636, 0.15601196060223238, 0.11024122485624892, 0.07511229307523795, 0.08733775706163474, 0.09496590202408177, 0.12188445829919406, 0.15350640219237122, 0.13758674929184572, 0.08292642448629652, 0.13221565607403005, 0.12258553425116198, 0.16620184667408466, 0.1311107567910637, 0.10122272771384035, 0.13794222021741526, 0.23744782007166318, 0.10150759028536932, 0.05873563326895237, 0.17073956318199635, 0.13369927289230482, 0.115934018311756, 0.13220838217863015, 0.06958901802343981, 0.08574721669512135, 0.06817568386239664, 0.15479138466928685, 0.12980039710445063, 0.19012027393494332, 0.12000384421220847, 0.10004718615008251, 0.17587287058787687, 0.23899724121604646, 0.11682862602174282, 0.17317570745944977, 0.1982866735862834, 0.09714427763330084, 0.1640476608382804, 0.15272738970816135, 0.11292901741606848, 0.24203373970729963, 0.11513604755912508, 0.13928778230079583, 0.12296902867300169, 0.14172501223427908, 0.09593794415039675, 0.10216889729989426, 0.11499861707644803, 0.15926157337214264, 0.11756874487868377, 0.1334316586809499, 0.1267842139516558, 0.1702598389238119, 0.20141499143626007, 0.13818238090191567, 0.19356476196220943, 0.1679901528571333, 0.1466297483337777, 0.135211103196655, 0.12422008439898491, 0.13221496396831103, 0.15196861113820756, 0.16251225822738238, 0.09369903643216405, 0.17187034179057392, 0.08259656825768096, 0.09011945208268506, 0.09862591991467135, 0.12025407435638563, 0.10140661070389406, 0.16464673940624508, 0.07643931758190904, 0.05392478605998414, 0.1599851766867297, 0.1105622329882213, 0.11756380514374801, 0.11719354215477194, 0.1802866187478815, 0.13968978715794428, 0.09105616967592921, 0.25715000714574543, 0.10741715532328401, 0.12245757611734526, 0.14346272684633732, 0.19068234520299093, 0.21289269626140594], [0.016841023727985363, 0.06890196060495717, 0.03903745972950544, 0.06883429030754737, 0.038409960722284656, 0.042217475162552934, 0.05265760834195784, 0.014170533811141337, 0.0705874619473304, 0.02136318482059453, 0.06347562106592314, 0.05253397247620991, 0.028254793590999076, 0.04329990475837674, 0.0192461860964873, 0.03226316627115011, 0.030651940764593225, 0.03812718803861311, 0.030126496816852262, 0.029576513650161878, 0.05956887427185263, 0.04177362165812935, 0.061704726091453006, 0.022821497371686355, 0.01381907896471343, 0.0533335615348603, 0.07722449116408825, 0.016959283900048052, 0.03947705203401191, 0.05374936779428806, 0.010137919619280313, 0.11007259533341442, 0.10259190281586987, 0.06450483655290944, 0.08194668777287006, 0.05705651694110461, 0.03618303932515638, 0.06005032879433461, 0.05278679462415831, 0.036106476826327186, 0.07523803239954369, 0.0754653959135924, 0.0557951712315636, 0.046469508071563075, 0.03121967101469636, 0.060239653635237894, 0.03000060821484242, 0.004780515845465873, 0.040403048773961406, 0.060830460861325264, 0.05443768389523029, 0.06081642197178943, 0.024791728971259933, 0.021107422919677835, 0.03775941527315548, 0.02127868346204715, 0.026279983576387167, 0.023835764732211828, 0.0077561904576474005, 0.02240473437788231, 0.0585500675120524, 0.037925527431070805, 0.049153561903429885, 0.03142878872209361, 0.0460117412065821, 0.051051760225423744, 0.010590163209209484, 0.021059726996879493, 0.03047677016417895, 0.06052659930927413, 0.03275121615401336, 0.006557899311051837, 0.02309973574509578, 0.03555959117199693, 0.031020497237997394, 0.0400601137828614, 0.037350343473787816, 0.018102364348513738, 0.0720126297590988, 0.036683492828160524, 0.03377922045599137, 0.0072605341972251025, 0.023253725874902945, 0.05012850137427449, 0.035738924584750614, 0.04029803530180028, 0.057897072551505904, 0.016796588165951625, 0.04613186226093343, 0.015592965430447032, 0.02094731410034001, 0.04357770378036158, 0.018011667965246097, 0.07361525483429432, 0.0386354514796819, 0.08042108320764133, 0.02904452183949096, 0.029454757326415608, 0.04637508653104305, 0.1306116400020463, 0.017154210047530274, 0.11097014788538218, 0.03703305371371763, 0.008659501227417161, 0.10361006496740238, 0.07721550057509116, 0.011975146480835974, 0.035280984693339894, 0.027592407705794488, 0.04694514415626015, 0.10115049766110522, 0.026604185911959836, 0.019280075527993695, 0.038936300336250236, 0.023048826958984137, 0.006607051539633955, 0.02099066400634391, 0.03493047385875668, 0.041341683228633234, 0.025602271281448857, 0.02012481091410986, 0.04040351357044918, 0.028203263945345367, 0.06635651790669986, 0.03628807993871825, 0.06129303175423827, 0.00058606310007495, 0.05630734981968999, 0.049217239022254944, 0.03679084724613598, 0.05233505315014294, 0.04798121963228498, 0.013950001448392868, 0.05854339751281908, 0.003938905113110585, 0.04120864286752684, 0.014090349631650107, 0.03586794123319643, 0.038813672095005, 0.06878838062818561, 0.026328156170036112, 0.03244012820401362, 0.06688156830413, 0.05485827721921461, 0.06111855325954301, 0.008288720855489373, 0.004878395370074681, 0.04994871673573341, 0.02984519994684628, 0.017170069107253636, 0.033571076446345875, 0.050334887978221686, 0.02364901323536677, 0.017011383515117422, 0.022033250025872673, 0.034580329433083534, 0.024387462896161845, 0.031049063562282493, 0.04070437599771789, 0.04151715238445571, 0.06340335708643709, 0.0317366400600544, 0.022828476104353155, 0.005917504745801645, 0.05682451564020344, 0.02359898654477937, 0.04655256075784564, 0.01763594276936991, 0.04262000588434083, 0.05501237930729985, 0.07743449775235993, 0.036417449425373755, 0.01408156514766493, 0.010794508270919323, 0.018049538700974414, 0.011475787963718176, 0.043065847496369054, 0.027471479194770967, 0.03252909093030861, 0.03518684135217752, 0.05271094797977379, 0.05212092785430806, 0.06450640396880251, 0.011408950568043759, 0.050638478116265366, 0.0431322930380702, 0.08492321733917509, 0.03096683868872268, 0.05525648228025862, 0.05145636387169361, 0.010864821462226766, 0.04154977974082742, 0.06685439297663313, 0.030041937782828296, 0.04049319215118885, 0.008041010620737714, 0.05486089975706168, 0.018574802836935436, 0.011481890538042145, 0.06857462852661099, 0.039379271745149574, 0.051087773471538506, 0.01305372454226017, 0.017016294412314892, 0.04049831848325474, 0.03089447632165892, 0.00863371859304607, 0.06402849139911787, 0.04400642256119421, 0.12434348277747631, 0.09481730964034796, 0.033798127834286006, 0.04113428560750825, 0.054984864712293656, 0.05915846236582313, 0.01137561074990247, 0.045471420378557274, 0.0559099861420691, 0.0214885831810534, 0.009432229629185582, 0.023534084670245647, 0.019344627956992815, 0.014764772728085518, 0.021419856065352048, 0.03231757799429553, 0.04115757292934826, 0.05846435496849673, 0.028110048500820994, 0.04331081899415169, 0.06468460762075015, 0.035699942747929266, 0.028355154009269815, 0.028277804409818988, 0.025974810755412494, 0.02171321219897696, 0.05225880617009742, 0.11677754590553896, 0.03426220168226531, 0.02095298156408327, 0.043971796919192584, 0.023276660358533263, 0.029224652530891553, 0.031204702532184974, 0.019384742947295308, 0.03591197815590671, 0.03398549510166049, 0.0531503197603992, 0.03674993158451148, 0.03018984484619328, 0.03056193309436951, 0.09784878018711295, 0.019653391924553683, 0.013002440865550722, 0.0329186209211392, 0.0454839088155755, 0.08494035713374615, 0.0029306432115845382, 0.02121588334973369, 0.05534956032144172, 0.019828101121155278, 0.06661385909787246, 0.08863022377980606, 0.04566649241106851, 0.014380852525521601, 0.05672317982784339, 0.0327414554277701, 0.05538755149713584, 0.028300101070531776, 0.07371644476162535, 0.052934772933700254, 0.027333612753344432, 0.035683854682637114, 0.04315921730761017, 0.0349049575493804, 0.060521863134843965, 0.11421196428792817, 0.03405843761616519, 0.022792742753933583, 0.0182628819852003, 0.024148625354947786, 0.06835333790097918, 0.034678903607917685, 0.016033451704840575, 0.04247518276263561, 0.008268786344810255, 0.03043037872495396, 0.024662946417395557, 0.06418144676302161, 0.0419663256034255, 0.05027148566607918, 0.026918975270486305, 0.04278395351554666, 0.06944989798856632, 0.02305090836515384, 0.0358458684890398, 0.03286678423838956, 0.04699006995984486, 0.032203268592378924, 0.027141991071403027, 0.05627706340913262, 0.02955644258431026, 0.0289807429404131, 0.004657661143158163, 0.07420847085969788, 0.021834118657612374, 0.08511613841567721, 0.061193422813500674, 0.04160015078793679, 0.054832564134682925, 0.010403820529713162, 0.016151808568143418, 0.0347957676941795, 0.059887242902602465, 0.06661662073539835, 0.028903668147644827, 0.06046651503337281, 0.00769122497045568, 0.005317752307746559, 0.04605132354689496, 0.01168728563269334, 0.031595647268529446, 0.03806866778592978, 0.022885944627757584, 0.0270355984768165, 0.045538917649537325, 0.03417840600013733, 0.020935622941968695, 0.043311555204646926, 0.06840522547385522, 0.03838857329849686, 0.08003889157303742, 0.04740418666707618, 0.059985236929995675, 0.07969628567142145, 0.024680925899052193, 0.012999468882169043, 0.07066079801214592, 0.029278901405632496, 0.08470771461725235, 0.00409736466826871, 0.03446061549974339, 0.0391500829719007, 0.05731008547757353, 0.05654355803770678, 0.0358695595392159, 0.02985303702631167, 0.0037923483344327125, 0.05725950747728348, 0.04104534323726382, 0.019048966500642042, 0.01151331773559962, 0.09904004340725285, 0.07362875089581523, 0.1460492887667247, 0.12697746072496685, 0.1268281287380627, 0.1872682419738599, 0.2054414182369198, 0.14695292099245957, 0.10546187524284635, 0.1281836652862174, 0.09964375636939492, 0.214695862361363, 0.1785789089543479, 0.148225961253047, 0.12095873297325202, 0.126562305859157, 0.13710598008973257, 0.1521848195365497, 0.09537215451044695, 0.16253013083977358, 0.0862456074516688, 0.11597254553011485, 0.18152588153524057, 0.1256398239306041, 0.20399429303194794, 0.08712509740144014, 0.1778578297900302, 0.100007688626647, 0.1342057857130255, 0.1296630480459758, 0.1622044068894216, 0.13189260555165155, 0.23741913161107472, 0.13087377165045055, 0.2936014240341527, 0.20859701319464616, 0.11277909510369812, 0.10558598608310733, 0.1274428814649582, 0.12422156360532556, 0.17186327145567962, 0.21469975715237005, 0.15045169182121754, 0.08490406229559865, 0.16993616414921625, 0.10281203993196998, 0.09452509174921683, 0.13251421148223536, 0.09599064596529518, 0.08182674992297377, 0.08537858219019004, 0.1946912793708699, 0.10837097199899809, 0.1469831700835909, 0.11964048870972224, 0.11419937067798205, 0.11255832695003067, 0.11576210467943124, 0.07935014460235834, 0.10945333713399512, 0.08717300197375671, 0.12502425696168626, 0.15931866530861172, 0.12821280157991818, 0.08367889946592705, 0.09303958860359021, 0.1364346104008811, 0.10302708125008003, 0.0964740410979305, 0.14698310223008904, 0.12125339359045029, 0.10468707646110229, 0.10926322519247021, 0.1495289656200579, 0.11935717319803578, 0.23851629559482845, 0.17492672135787352, 0.11186960712075233, 0.07260110282472201, 0.17869257714067185, 0.17523012150611195, 0.06907772831618786, 0.10335378907620907, 0.1534096702401127, 0.09226162784865924, 0.2101047858595848, 0.1420180443674326, 0.2002635853631156, 0.06313629927379744, 0.13595021782176836, 0.13502006844750472, 0.18156474802110875, 0.19540528820029326, 0.10620466074241058, 0.11692257598042488, 0.16225620625274523, 0.1293711287102529, 0.1682955478983266, 0.11811921319791249, 0.17802735497908934, 0.254427290388516, 0.17782502940722875, 0.210490953709398, 0.13774373515376023, 0.12133363714175564, 0.1848748725439821, 0.14696517533489636, 0.08203087361263377, 0.1338744434927191, 0.10195610193269593, 0.14083723058657988, 0.23449548706412315, 0.1412860272186143, 0.11014969048223325, 0.16908670615937027, 0.1360228753515652, 0.16766118550939219, 0.18440611341169902, 0.15405118438814366, 0.0938404838421515, 0.11390762776136398, 0.15026546109999928, 0.13964176044932433, 0.06154647136905363, 0.24648579795445713, 0.10656406717108828, 0.14736276971442358, 0.10615582657711846, 0.14918061931218418, 0.09129293089998619, 0.19917332886585168, 0.18086658976972103, 0.12446928316993372, 0.12136632895895413, 0.1538505551538297, 0.13922968613249914, 0.0952120813141976, 0.13244439022881643, 0.1615408267825842, 0.11213422220732484, 0.1450862982975585, 0.12342470565012523, 0.12244401898767267, 0.11575427438531603, 0.1567325105092355, 0.1092408946050065, 0.16555645130574703, 0.09498270933649369, 0.12725844207618917, 0.13445958495140076, 0.167579747736454, 0.08663159209702696, 0.10110414693398134, 0.18392571061849594, 0.11710531903164727, 0.10668460213180099, 0.09809531231543847, 0.13724645040929317, 0.159021222697837, 0.11536942289343902, 0.19206874152379377, 0.1843075765562909, 0.0842828159885747, 0.19343129412404128, 0.08924876951745578, 0.15047639049589634, 0.216603780697499, 0.21784502480711254, 0.1310013769460576, 0.1352153643965721, 0.13054669063006127, 0.1561194269784859, 0.13148882293275424, 0.1183507429169757, 0.08454630470701627, 0.10223882033356599, 0.22358832162405762], [0.06944301085812704, 0.047420675068029335, 0.0038327949587255716, 0.031969475959028514, 0.02347713352979294, 0.042782012905393324, 0.07136067295713083, 0.010104254952498844, 0.010057310507233654, 0.042817018527005396, 0.04755338294697659, 0.05464520365265863, 0.016879510234243104, 0.03886544770960297, 0.036092688994748254, 0.008344292873516679, 0.05529084668627807, 0.056579035241156816, 0.018547232262790203, 0.03726598460759435, 0.0434729719002332, 0.021520615122946243, 0.07494492562753813, 0.02930697239935398, 0.0654533470847777, 0.030983286377574717, 0.005929446113961083, 0.032781875758830986, 0.05975849088281393, 0.06201884030763592, 0.04026892614950027, 0.040235667755561214, 0.03838765727622168, 0.08168001672519104, 0.031196889201445237, 0.057815024097050936, 0.05659399015296783, 0.019455408976812447, 0.034301790807928355, 0.06605847818510872, 0.07569273907159056, 0.057066491405878744, 0.0792714481108955, 0.07529002175267253, 0.042104729783854315, 0.03869327623397112, 0.05804409073399646, 0.054779696078704934, 0.005247919179964811, 0.008671843779406377, 0.03668230539187789, 0.08122817347092287, 0.06758193179432835, 0.027220984421936528, 0.013558402773924172, 0.05025004395948989, 0.027537013803209578, 0.07910412816064698, 0.04709841843162264, 0.029979644875441278, 0.060948675232274194, 0.019925224927387068, 0.020519199215673974, 0.04917762954054134, 0.07397683257503168, 0.07605946010776929, 0.08382126289818968, 0.020922184555924365, 0.008932218870281108, 0.07207435608974525, 0.03908548304545028, 0.09376726991363935, 0.012824015841553254, 0.01641178926053856, 0.05320492147334984, 0.047018215592418394, 0.05136504662888391, 0.026263634275112833, 0.024871375411748886, 0.015847338030913045, 0.04292805399745703, 0.028061090502887964, 0.023213256350053207, 0.05693070297794683, 0.017090448111827885, 0.025109151045658758, 0.054040747694671154, 0.029496341345033476, 0.04263315250032714, 0.028446359293801442, 0.03883148363924452, 0.045483260814632685, 0.032580808869429996, 0.04584486230409571, 0.026525413085307394, 0.04326893642012562, 0.07159610425255128, 0.03595516690984368, 0.01205857829856021, 0.023271567953218306, 0.02130993508866855, 0.022248951219288365, 0.05725122256470578, 0.017389310557129126, 0.0608716615076576, 0.012939527946790414, 0.014492184855043888, 0.017140069377741644, 0.01829866792208382, 0.01804500269437475, 0.10269328951835632, 0.03350824410361903, 0.02884251517908914, 0.012271983499106551, 0.02146689041650721, 0.05134461254679731, 0.011743800814396568, 0.07564363349229097, 0.042488515975752046, 0.011896797738570188, 0.027318606951407025, 0.07417982311121055, 0.03291582874953747, 0.025441679005910243, 0.017927253119913594, 0.021667741871039783, 0.07404718987111535, 0.04129354116906013, 0.02486808960592108, 0.036085900251886675, 0.03964856193800058, 0.015929020076457943, 0.06125628908297845, 0.02103239221365324, 0.024426817927243452, 0.03415189224428364, 0.04556161464591112, 0.0853409981355071, 0.04549456520804337, 0.03666853113099933, 0.022589998186698983, 0.016754605508010303, 0.06927673585180726, 0.03694532931383167, 0.06810679220195327, 0.015289141197821923, 0.012035349500365555, 0.024105848811034645, 0.02895682118833065, 0.017979987165225402, 0.05411339843911784, 0.0562018172682396, 0.03462993712829692, 0.02619939566855984, 0.014247997065207787, 0.014642594016290136, 0.0325163480426584, 0.03295056974249227, 0.08219464482473475, 0.07696444261819124, 0.061908266240996976, 0.04421528581795948, 0.0355415353551507, 0.05258286092430353, 0.05603517585300973, 0.004606833781248757, 0.06609488158885922, 0.0460034596866795, 0.07736476470849343, 0.0068526528027307776, 0.012223708277036036, 0.012719060893037488, 0.04756365596715893, 0.043924509813742976, 0.00850313198420086, 0.011092942390990044, 0.008329991051661116, 0.03061148650678141, 0.016311357596090863, 0.03563550906255841, 0.042728547738598924, 0.008492480680745627, 0.03451832490307944, 0.04627677698486617, 0.025754317408427596, 0.0520767789733197, 0.05174557924536722, 0.07377631190632071, 0.025099027303180525, 0.06784324241536004, 0.011613439818445061, 0.025318049925512502, 0.03570230404979416, 0.05997529639197247, 0.01375831276111837, 0.03307342868564384, 0.03215546240764005, 0.010442166239954531, 0.0506776702989425, 0.07462752730186496, 0.02041077271236905, 0.033242662104644945, 0.030785883577274423, 0.021675989464191452, 0.012871555701297308, 0.07514919180955205, 0.05579004150682262, 0.01658450186784778, 0.09646775107830763, 0.04252783368740763, 0.009159919107332826, 0.04298563447913953, 0.019522631441109946, 0.001976368948817253, 0.004419817231662039, 0.03139161518109696, 0.04442829831636377, 0.039691971215818606, 0.015890367329120636, 0.031780605736587725, 0.06177262709076915, 0.016655145844976817, 0.03414648092750992, 0.03829126459147249, 0.034380555152893066, 0.023815166105383208, 0.01864670549652406, 0.03245469295818891, 0.0934034190805895, 0.029094058288527385, 0.037003204958247285, 0.08970999012568168, 0.008212537488101848, 0.041630379523017576, 0.03718772916389363, 0.0061397949383328, 0.044849017169326544, 0.021080556325614452, 0.023262165154197385, 0.007332541181572846, 0.03582848781453712, 0.029774998713816916, 0.0533821582128959, 0.020566265797242522, 0.029892453125544956, 0.03717428399249911, 0.08808436271335397, 0.04237355178754244, 0.0434739761320608, 0.03851488259221826, 0.053009303220148594, 0.0341675765812397, 0.05612866101520402, 0.0518870605821056, 0.009317123796790838, 0.028867617582104037, 0.06709848237889153, 0.027538084192201495, 0.05922634979443891, 0.0286661707130926, 0.040325828096164126, 0.027295601221599748, 0.03344684686245663, 0.007102388464513102, 0.02192597363942436, 0.023540422187319825, 0.033766606489994695, 0.04647753853350878, 0.05207665344434125, 0.05422265275514551, 0.021157782092424374, 0.05203221618596997, 0.08228936152798788, 0.04790506764714207, 0.06938819879932062, 0.0030270064224688603, 0.027949037229908363, 0.014276670258758324, 0.02942566853016615, 0.03326802235096693, 0.07660235597618989, 0.053267302590289285, 0.04579547852543848, 0.03631581166493041, 0.03514806307586176, 0.042494928131678274, 0.04166371255580868, 0.01836114573026342, 0.04756769325051989, 0.09025544407112257, 0.021299626445397735, 0.03185041681198137, 0.008504321964989816, 0.02551135267796261, 0.04934882731842143, 0.028236707240077, 0.013530520921839135, 0.042657108179160526, 0.03078313890312399, 0.026101043713944297, 0.017063674816329564, 0.018567856334682022, 0.05101824398817761, 0.051095647870429924, 0.029673476304326738, 0.040294690124158344, 0.10792243321027074, 0.025837816231484925, 0.029099371217723404, 0.02424176107160747, 0.021493003836699894, 0.052924113148557286, 0.011791682486156268, 0.025940271626625742, 0.020977290081126348, 0.053579584761921845, 0.04714231964732919, 0.019299932855314443, 0.06001005095562764, 0.06356479413807392, 0.0070948202545488516, 0.025241114232423048, 0.027259521818320667, 0.035504782505865605, 0.02164608472958207, 0.03420669751773987, 0.02016038480880005, 0.030798260056014572, 0.026898285041430166, 0.016607068246230483, 0.02657924635734941, 0.02671926036210997, 0.04339747470138328, 0.016142500764025108, 0.05008157389238477, 0.027467457178447927, 0.06527736902769123, 0.019450516739327992, 0.017230855666899254, 0.041925467617277584, 0.000503188264182037, 0.016478165252400295, 0.01297101451616202, 0.029229965460087572, 0.044668038309152634, 0.013638493654850339, 0.023618452018126845, 0.023894939771188155, 0.08652716555765697, 0.07369556623910155, 0.07478392283831324, 0.041494862509093115, 0.10162215413791792, 0.20436524812664303, 0.14172681713742868, 0.0947062945259469, 0.11249988472887448, 0.054687432279544215, 0.1362432770963226, 0.09683932363986969, 0.10718802761818681, 0.11835652403533459, 0.15849442168005876, 0.2236771011458976, 0.07138506629105125, 0.14669011080903666, 0.11254011507013015, 0.14553027733096055, 0.1044883606955409, 0.10953179613820144, 0.10661573761275836, 0.13392694853246212, 0.11945747424449239, 0.09602585514741284, 0.22161542677453586, 0.126905603866492, 0.16251303175730364, 0.18314861160303864, 0.16200095494943006, 0.11308058178318398, 0.16726915511701787, 0.13829747401177883, 0.1875613419605153, 0.17456929625145026, 0.11383872931557042, 0.11510155083877699, 0.09683233472917761, 0.1464578075600522, 0.20341680544827664, 0.07298269056315933, 0.06614009916250195, 0.11160479525902442, 0.2591713086834976, 0.09559326193162374, 0.18026460707187653, 0.1143863070756197, 0.12063113626624856, 0.17315426575286047, 0.13666122752640927, 0.1151400509157351, 0.1437106364007507, 0.08015030702309948, 0.10489436212394919, 0.2140013953404767, 0.15962317825428077, 0.05909899555678878, 0.13800904234605177, 0.1420789361000061, 0.07680267308439527, 0.12749483010598592, 0.25345049851707047, 0.06687600431697709, 0.12157303786703519, 0.0879878546776516, 0.08886650324399982, 0.09482816620064632, 0.1291550967310156, 0.18058163220328943, 0.19062525326652185, 0.11155438010713883, 0.12508609864328588, 0.2723694390484265, 0.17505169393760817, 0.16565876081585884, 0.1209665225552661, 0.06227998808026314, 0.13444106094539165, 0.16196976947997296, 0.08351689923022475, 0.22948371885078295, 0.12320049053856305, 0.09751992819032498, 0.1812171616724559, 0.06821723734693867, 0.10529764262693268, 0.12946605575936182, 0.13195604857589516, 0.11379028191523892, 0.12881806838725293, 0.08102407692266361, 0.1418950802513531, 0.1061873852408358, 0.10649408985461507, 0.11961618358535425, 0.14079767199499266, 0.1370708184050662, 0.12330240649836403, 0.17160907866699354, 0.13962804047124727, 0.13255514071456023, 0.1351320402962821, 0.06176046774323497, 0.10041353399200098, 0.09715497813054494, 0.15942187048494816, 0.19402216241828033, 0.16149175513003552, 0.18754996971360274, 0.11355134937912226, 0.17116881800549372, 0.13151958771049976, 0.13754633574613503, 0.18956432305276394, 0.10091419105551072, 0.09953563181417328, 0.16740837693214417, 0.11989138381821768, 0.18365897850266524, 0.07273020089737006, 0.14506292955151626, 0.09979496789830071, 0.09491587363715683, 0.09230023649122034, 0.14755592149283203, 0.07244771998375654, 0.16088865963476046, 0.10769500184272017, 0.10190939158201218, 0.12701323309115, 0.17890995261924608, 0.12567425279745034, 0.14128595936511243, 0.2289209147649152, 0.0956104424382959, 0.18700160485293182, 0.12068183640284197, 0.07513344301176922, 0.12308079696127347, 0.12652594995285782, 0.1511735173740557, 0.08518996981105634, 0.07022667130721466, 0.09509198740124702, 0.14874989885304654, 0.1505056353552001, 0.10906252131930419, 0.2150532603263855, 0.10430806037038565, 0.07851720215486628, 0.16060079793844903, 0.07116805043603693, 0.17604930326342583, 0.15448155200907163, 0.18271099722811154, 0.11159163167966263, 0.09383688760655266, 0.07767262283180441, 0.11799546198121139, 0.13364809778119835, 0.08918704318680934, 0.1628425419330597, 0.14302186907402106, 0.19551312098545687, 0.10381716742579426, 0.12467036023736, 0.11666014577661242, 0.12366730906069279, 0.10646956759904112, 0.13886766055864946, 0.07496123760938644, 0.1921639535576105, 0.0563697445073298, 0.11704494298568793, 0.07707374103899513, 0.142384209004896, 0.17159934847482614, 0.11675010594938483, 0.1389306014669793], [0.044349282913442166, 0.01585505297407508, 0.031734550172196965, 0.026586259016767144, 0.027547509043610523, 0.06567356562508003, 0.01811085282159703, 0.015453821646847894, 0.013332029072833913, 0.04513815111879792, 0.0036504768400586075, 0.01668455864169768, 0.05030083909098591, 0.06664421675460679, 0.05090836202725768, 0.05006915330886841, 0.03276550949418119, 0.010181565536186099, 0.026771672103287916, 0.034230836401028295, 0.021790069860539267, 0.0221797796631498, 0.0117228383231642, 0.07252926632229771, 0.041875690288309536, 0.022216205119288394, 0.04650981305167079, 0.007383131904394499, 0.0025515830160916914, 0.042888946631657224, 0.10694043697523219, 0.028082681487181356, 0.022567240122173513, 0.05613198244412031, 0.028875939814107757, 0.042466141283512115, 0.037848361036075015, 0.03839973859222872, 0.04713185324466654, 0.03122472610058529, 0.024926036496513655, 0.05672148009762168, 0.021910365637657896, 0.030319441642080034, 0.029121226830674068, 0.03965486552832382, 0.08104545077575104, 0.04139056149870157, 0.06748112863195793, 0.0331684812637312, 0.01040796553050833, 0.05139881731676204, 0.06122494076511689, 0.0385524123640997, 0.02125121806082981, 0.05877110707972731, 0.05816237295844725, 0.05458795226046017, 0.03928234641041074, 0.029615556555134908, 0.05098957249096461, 0.04061134884666119, 0.14683861498321804, 0.016418766296867813, 0.06331950372883252, 0.02295781166425773, 0.0676099688612989, 0.013752345045629357, 0.021773606904649308, 0.04379416662933571, 0.0658492451267583, 0.07598877711487667, 0.02586783462070993, 0.03910512663424015, 0.042539097368717194, 0.04367108037695289, 0.034722825179674795, 0.055909507774880955, 0.03464061048414026, 0.007546285649628511, 0.04586415644735098, 0.03370706843478339, 0.027732335197340165, 0.006618202414496669, 0.0329481439798006, 0.027556292679426924, 0.04670386728165405, 0.04570194586579289, 0.03396980058667915, 0.025299383427149484, 0.015131468319201043, 0.02459796142232205, 0.054158551551933796, 0.016111174498551657, 0.054659520741552114, 0.016522137714283805, 0.09882220652486597, 0.09449391306510993, 0.05086952607546534, 0.054116238108170886, 0.021619991665439944, 0.047094995222453556, 0.031922938634774516, 0.02334291930310428, 0.007421671845284956, 0.06593746146453278, 0.05081056138234479, 0.001770583272445947, 0.028744229381637912, 0.04119947925209999, 0.05943073811275618, 0.04324500449001789, 0.034816853169884, 0.06005707343241998, 0.057718210720590184, 0.03847232148317354, 0.030879908174808537, 0.011668687836000962, 0.03471297624387911, 0.047916334721126726, 0.01226158919078963, 0.013650550373962947, 0.018610463244840503, 0.07455710215227944, 0.013691098778508604, 0.032486818198646815, 0.02354054432362318, 0.029695691540837288, 0.045282570512167046, 0.03604874706694058, 0.05123675601290805, 0.018296372777383243, 0.011865721682884862, 0.04109370921339307, 0.038666776048817804, 0.0230784399235355, 0.03860284787203584, 0.02134105270462377, 0.044415582570114305, 0.014396207772993615, 0.02433954644948244, 0.029050438664853573, 0.019606578097279583, 0.035858791188469956, 0.09480700947876487, 0.07182876712509564, 0.03696587535419634, 0.03871924716180988, 0.0461982976246093, 0.031247429882309267, 0.014678982153002704, 0.04383399663493037, 0.039121150238705535, 0.030722114856221845, 0.011288080580665596, 0.018846048906977688, 0.012218735463518118, 0.01117527243747775, 0.05138162323938949, 0.037744867482355664, 0.03448575182950922, 0.02658060342738671, 0.03849582593621952, 0.03791561403444835, 0.03184241349143641, 0.05318579696384924, 0.055193042648690085, 0.04044922647465553, 0.03544463037646242, 0.07731957427625145, 0.07620727896158185, 0.014099597215785511, 0.05084799276664853, 0.00882410110040967, 0.03628687553906015, 0.054180773573794534, 0.01669825826372419, 0.03700239750157509, 0.02723537614968206, 0.007462341537965196, 0.03695487630154405, 0.014933705895340868, 0.03611705179459282, 0.033117916834141524, 0.04056866220863802, 0.06215922920299428, 0.05376066540234855, 0.03461610179926668, 0.024267094176528708, 0.04152497589322073, 0.04396357986011675, 0.03232179508943643, 0.02472276776097715, 0.07235034342323031, 0.024968553500782167, 0.038311800453811884, 0.08756887965968677, 0.01794446924967425, 0.021521488736782755, 0.03021389212725418, 0.02047820043350969, 0.024401245638728142, 0.027032407665891305, 0.02253932349516877, 0.033636775599526506, 0.049513925066483874, 0.059748150009129725, 0.04054068960249424, 0.0361299134258713, 0.05810341505067689, 0.05653885239735246, 0.033595785299049954, 0.027375430866543735, 0.0659472391541515, 0.0242758845976953, 0.05242221436596342, 0.02312610700859555, 0.06113533343055418, 0.075245611635702, 0.023682851776746765, 0.025653071501957517, 0.030854663279439722, 0.05811482122434037, 0.027693617989176085, 0.04738020384684205, 0.053833356858896356, 0.021657480725220273, 0.033397188277116845, 0.039550958068243096, 0.03857162847582783, 0.05421717697754502, 0.03589383752218314, 0.0804474985759173, 0.004737776620978755, 0.027600114167268788, 0.0369960701625262, 0.07651017020855631, 0.04248615467388715, 0.08269946130790881, 0.02674193530609565, 0.04610770980694464, 0.024939797186691846, 0.03892975247332028, 0.02638625064199524, 0.03911696707031556, 0.016383190705840076, 0.0707712567278317, 0.01297909247555903, 0.012268950447573193, 0.012620553723536432, 0.04821577901020646, 0.04702376940154603, 0.006812867325996714, 0.04860914611656751, 0.05473720282316208, 0.04250444458531482, 0.015261991315388253, 0.0090116320643574, 0.026652165123128464, 0.004796776513103396, 0.01275029216360833, 0.011302755596781415, 0.06707876415124961, 0.09347270429134369, 0.054989675525575876, 0.07571599925202982, 0.029309652612677643, 0.03037659464670079, 0.022828028271240846, 0.0491040017056678, 0.02854157132761819, 0.04875836953786867, 0.13511644756155355, 0.05611515138298273, 0.04118020885757037, 0.002796218851082293, 0.029985826329461167, 0.007586475278783057, 0.02768057145710502, 0.046708464356405396, 0.0334787414010082, 0.07406972401908465, 0.10781684637601886, 0.03264392280418958, 0.03644915058144501, 0.06554142093019825, 0.010712347010017505, 0.0182494775259069, 0.005305696436802724, 0.03164909886462348, 0.02694674940513713, 0.012612033020039755, 0.042448458660926135, 0.004681439130633537, 0.0696497740490096, 0.04918966335909707, 0.015323548012280037, 0.008889816368796995, 0.10758999854858432, 0.02199428854510188, 0.016184999108580605, 0.03904758007930858, 0.07443293024386678, 0.017093118147126267, 0.04575818624081356, 0.017940174123006206, 0.050046137401035855, 0.05598682005490575, 0.0262224845189069, 0.03564124607614108, 0.01660506656792547, 0.018197937702227916, 0.05394591564046485, 0.051563060110700984, 0.022360251318397265, 0.006297311753899391, 0.04260818919699107, 0.06636801228991576, 0.02503096515179745, 0.03003325592726469, 0.04747011312948806, 0.07152392848261765, 0.04149902192875743, 0.039613362933908186, 0.08307632644261632, 0.06749942872141089, 0.01893386321275362, 0.03312804736196995, 0.058521609753370285, 0.010294349930648292, 0.06293984981519835, 0.04607497049229486, 0.020127022938270654, 0.02308261800291283, 0.02948143732334886, 0.007853493227490356, 0.018241818561883907, 0.018358149998156086, 0.038713194629443545, 0.012428330689934748, 0.03185757874910321, 0.02984085732272693, 0.07388652634939977, 0.018354808213189244, 0.03241451350705964, 0.01925931914177324, 0.029770469492567436, 0.03562574494364006, 0.022939903428778052, 0.061061671668929715, 0.03382529637643269, 0.009543405047484806, 0.10702551848122052, 0.13784913878355706, 0.1347226665488311, 0.1040442188137344, 0.08903498348913022, 0.16797724712107862, 0.07225668523460627, 0.16673767220761093, 0.14668237550982408, 0.10521933290043048, 0.13291678630879947, 0.15393431351653167, 0.1458765473216772, 0.25687682894723757, 0.1764532487307276, 0.1122151714350496, 0.10640520176717214, 0.1321461605174201, 0.11862529175622122, 0.0700019472943885, 0.11456416467470781, 0.06932225876620837, 0.08680606380637203, 0.1493103823491505, 0.1898028552532196, 0.06953228571053062, 0.13441491020577295, 0.0954096842823284, 0.07911741387631212, 0.12299417518079281, 0.15894472465983459, 0.08734566877995219, 0.15205857131097997, 0.19279096062694276, 0.12609293604535715, 0.12381677675460066, 0.138773914160473, 0.19166691308575018, 0.099042377567717, 0.11465668970985071, 0.10723851740892444, 0.11839457627918039, 0.21254448566053594, 0.23492869096142904, 0.16059862662638935, 0.10967770152326141, 0.09716601110994816, 0.130548644810915, 0.12290291222078459, 0.1612652601408107, 0.055739507611308775, 0.10898077820560761, 0.11715554419372763, 0.1232984574245555, 0.14793660677969456, 0.09273585597319262, 0.19412021072847502, 0.09354992836181607, 0.08898740461362259, 0.12715237348207406, 0.11612090042659215, 0.12096099928021431, 0.34943036256091936, 0.13274717969553812, 0.11939651465841702, 0.10782911428915602, 0.11193747419331755, 0.0830485268629023, 0.10103032910930258, 0.0970449468919209, 0.23933393029229982, 0.12952987876321587, 0.10360859933176211, 0.11560350390417234, 0.11735472136310168, 0.11591332299368722, 0.13032919301518373, 0.2998814013387476, 0.10958078636654786, 0.09173849091998168, 0.1240171210042068, 0.07599734022681202, 0.1222742630967072, 0.06073532346636057, 0.12103543457176004, 0.11524518313152449, 0.14960017108491488, 0.21471335499414376, 0.13099370950034686, 0.12046925138149943, 0.09674751106649637, 0.10224466252007655, 0.11598721545721803, 0.11684242742402212, 0.10901189582156283, 0.09226336489830698, 0.20505468041769095, 0.12740554846823215, 0.1974131547446762, 0.11628796931888376, 0.09053484443575144, 0.09681575811867203, 0.09861903278423206, 0.12448402095053877, 0.07616081966885499, 0.13081638115857327, 0.2209267680134092, 0.07860805120851312, 0.09314157241689307, 0.14068290458193847, 0.130838311410376, 0.07750865484454803, 0.12480663721050535, 0.20296150845076355, 0.1753729802689382, 0.19668984998549732, 0.09269882831722498, 0.09415132751954453, 0.1735502587897437, 0.11199089525533573, 0.11384894805295126, 0.10439198836684227, 0.18056776294750826, 0.11087525476302419, 0.18163152943764413, 0.1326415589345353, 0.19734403916767665, 0.099151825266225, 0.09290245667632137, 0.09527078816401106, 0.11198932783944265, 0.13151272093611105, 0.13001085152583464, 0.18388100873146737, 0.07038455283535378, 0.14792019980294363, 0.14409159310162067, 0.11260499658861331, 0.11389810112970215, 0.1581593339464494, 0.10522739389645201, 0.17297936656645366, 0.1193168003644262, 0.10397145950368472, 0.2117477905537401, 0.16025230235287122, 0.13275430431323393, 0.1304090837282794, 0.07061556008245264, 0.14322650166494505, 0.12399709065045629, 0.12099153335605349, 0.15178430745644228, 0.13022365367838315, 0.11121501081756183, 0.18972352093883924, 0.07636832924825804, 0.13216187538845198, 0.13520826692027704, 0.10609263461083174, 0.09256124177149364, 0.06571157715682473, 0.10239244744713817, 0.09588819396282945, 0.24624385950820787, 0.12710788872625145, 0.16922402807644435, 0.07776214874216489, 0.09000984832112278, 0.127865893766284, 0.10929503491414444, 0.1730819610612733, 0.10409307333507709, 0.10721997983221497, 0.136908567111407, 0.10788446917597737], [0.08937142829277686, 0.020177687451775585, 0.024669465442587222, 0.02589349172610257, 0.023510525934398174, 0.053217521868646145, 0.00612864745614518, 0.05390774126031569, 0.0847202946564981, 0.02286977513826319, 0.044934699178806374, 0.0558058174460062, 0.03315654244007809, 0.04012178583070636, 0.008786604407110384, 0.030072488822042942, 0.021032439711104547, 0.015148915150868041, 0.0254618314959641, 0.04864964108648045, 0.013176778564229608, 0.0740744194814137, 0.02327562219995473, 0.013805386128037103, 0.02600789103390915, 0.020886091581944908, 0.02782878895024104, 0.022354136021541696, 0.022697646071070006, 0.017479104488821964, 0.037418325897306204, 0.008805432057540332, 0.04204102213095341, 0.0367419418346669, 0.06698139437607356, 0.07756828450198684, 0.008098799751938453, 0.019595662165167074, 0.03823888847338302, 0.03156553049172674, 0.016436270804011395, 0.12669160749231065, 0.0648269574823124, 0.05508917590071048, 0.09242712253970758, 0.017692342600119964, 0.04309073955352817, 0.037959572925631485, 0.02756478454518531, 0.02152163631814931, 0.02981729180152927, 0.034110752666102986, 0.030072702560573816, 0.0035285209846084137, 0.04752053167404873, 0.04208709805139473, 0.021380953956395388, 0.044992822488503795, 0.06653194635042123, 0.04904253661100354, 0.05189088073426059, 0.047253860626369715, 0.027202110970392823, 0.008777524760392095, 0.0095493574959359, 0.06101836756403957, 0.009854412421451082, 0.0545213201216289, 0.03585365128570369, 0.0562015628176076, 0.020229189956028546, 0.010694514261558652, 0.021454995697630302, 0.03234642591061337, 0.03410826922793474, 0.03866578878036567, 0.05146047240123153, 0.048598279378243854, 0.02382329325856907, 0.011323884329093354, 0.021717532770708203, 0.02649544388987124, 0.05208306899294257, 0.041970746259071996, 0.022304633499256203, 0.023201549924643974, 0.033996636646666696, 0.02196557803212532, 0.02536366953115378, 0.027391072795061127, 0.04723452237833824, 0.0338039564500962, 0.013059056979337973, 0.015450223714911511, 0.027102281505774175, 0.039633084554225206, 0.031601408030837774, 0.008934115375658231, 0.019776160961815288, 0.05505398368196828, 0.041490204366190095, 0.05930744829986777, 0.0315424569084176, 0.03275925000863416, 0.04495975747704506, 0.01342260162346065, 0.030734806853745664, 0.021420897616605674, 0.037464103262339316, 0.040493592486849854, 0.025236383147005523, 0.02560644766448864, 0.029413505789956877, 0.031820171113525114, 0.031264749488660266, 0.022454954450950027, 0.0413490792603365, 0.04644127083676202, 0.03080194110849074, 0.09729557058640889, 0.044564385299703906, 0.05125006547729884, 0.04474755243531295, 0.009917035266490919, 0.049747602348881106, 0.04042797815054655, 0.015837519629193202, 0.05166301510429808, 0.04054602628041591, 0.03877961302974394, 0.05763392988592386, 0.041569922052856, 0.032460999941187244, 0.06945149254586015, 0.05920760187187365, 0.07162758827741657, 0.030134795300130333, 0.12270848479654108, 0.0499076009062784, 0.056075182277709246, 0.03155780537053943, 0.030995075923523734, 0.0340426684623318, 0.09728105672236, 0.0765916554789458, 0.024064049357548356, 0.024405454252181307, 0.04749195856441345, 0.041226647794246674, 0.03595488531781094, 0.01696629316679069, 0.019251027443845357, 0.05176844248282058, 0.03720375616103411, 0.021824005093159418, 0.01548574332680021, 0.06259990377085549, 0.029718218903456415, 0.012634688456143652, 0.0187734490526574, 0.01976095838472247, 0.0539360497412937, 0.013980871399066277, 0.02930852963722178, 0.00456767764574449, 0.030732503227357353, 0.02367392904125154, 0.06570386899901287, 0.08990078738757543, 0.03350024078307407, 0.0356416396264519, 0.03562287474051118, 0.05015408553715263, 0.05515239161572286, 0.01673049885513527, 0.025337148989949907, 0.03391519548105342, 0.012148960859381726, 0.023641415339495455, 0.008850941401241081, 0.017180304808009948, 0.028567725459911993, 0.08024732396006584, 0.01013082723199789, 0.12507319290723118, 0.034537245852074454, 0.06125577339636428, 0.02369921125604638, 0.07035718751805169, 0.037388450000435114, 0.03477984926264201, 0.016267363081819246, 0.025855553136872392, 0.033390060266745944, 0.022573357115366628, 0.03314530250749417, 0.02110381141704108, 0.044867948296346834, 0.0323783883026668, 0.008013184747791715, 0.08050982880273036, 0.049787313610847504, 0.016315252387097905, 0.031776833081884046, 0.0033698765286577065, 0.04731691010030253, 0.05367387059543814, 0.01593790718886469, 0.01669484523258039, 0.030001205325658833, 0.054443298772509606, 0.05204626525353108, 0.0167463969306222, 0.02602412159155522, 0.02380588883534074, 0.04493002067985279, 0.02975613883297358, 0.0498497184765126, 0.02955259189807943, 0.014209891386729265, 0.015179651090875268, 0.013935299290876304, 0.035370815944458754, 0.05763598584703036, 0.010623335938102432, 0.03062955928700311, 0.006857701103269521, 0.051586798658328395, 0.05245979502797127, 0.017474120649109994, 0.054617672094276974, 0.0381358291820756, 0.02480622417559581, 0.015149812513430203, 0.01403656809790326, 0.03996438606243048, 0.02125041908584535, 0.02160976953538401, 0.03580343630164862, 0.003838039610335337, 0.01065626269805112, 0.059871270188263485, 0.03128931924168553, 0.019156526175460646, 0.05562781396188906, 0.026471045466938188, 0.030760706535407474, 0.02624251656899495, 0.0239384440439088, 0.023234236652829816, 0.03249364426093442, 0.021793730556964874, 0.10818787610956601, 0.03830836706661752, 0.031250004922705035, 0.008204847141834242, 0.04141008634386318, 0.0692584832598056, 0.04746835233111467, 0.015955722125779306, 0.07027412804641894, 0.004017455295460033, 0.0350037590334458, 0.10254895154918943, 0.053396329416760376, 0.021981691542480673, 0.09021716112537043, 0.046657913497516086, 0.051527630404702256, 0.02132704434916377, 0.06476942449808121, 0.023450869135558605, 0.044859327508934906, 0.028935413408492292, 0.051819183331515105, 0.05570337222889066, 0.03188523583646331, 0.029312197118997574, 0.021273660606571605, 0.04951182160792606, 0.056407986740980826, 0.014670602245522397, 0.042449788589562686, 0.021297950463901674, 0.03280266946447747, 0.06465499635253634, 0.05537786880241973, 0.01885369430030031, 0.029282450143780028, 0.03356773126870394, 0.02613106888851949, 0.02154151739419571, 0.021555317100137472, 0.03565851139969059, 0.028350796118112545, 0.03633694463808622, 0.04335606710187026, 0.06377885158040694, 0.026649133767932653, 0.012275864719413221, 0.05575506302661129, 0.03349458519369364, 0.03643027712990131, 0.021874852811119387, 0.01240948777246688, 0.024539873735713105, 0.04864006356469222, 0.024722338587577854, 0.017876900732517242, 0.04149979206600359, 0.028084676380136182, 0.06614811944642238, 0.025424949725025466, 0.022303748011056865, 0.02546337346679398, 0.029869817197322845, 0.005060992960352451, 0.04854177098189082, 0.04820628630529557, 0.053631577507725785, 0.07211546852652516, 0.05844836189810719, 0.044863754949931584, 0.05918708975825991, 0.026419283423040594, 0.0471818782389164, 0.021088237342025553, 0.03918817253517253, 0.020841125066259077, 0.01344541651529393, 0.029423371689128022, 0.016373884598059312, 0.051197309379598925, 0.03676685764055167, 0.07071360839264733, 0.02818425478679793, 0.04490037548488804, 0.006531590812041291, 0.04218148905783892, 0.024273004216541137, 0.05749518983066082, 0.01691525037001286, 0.014120268785128636, 0.017710339045152068, 0.030605915734278302, 0.05594144302553364, 0.06939610373228788, 0.036668470062847645, 0.03739330152581845, 0.03804635076916643, 0.03434576666248696, 0.025589224749377797, 0.16813902344022477, 0.13543899596801826, 0.13225074990519456, 0.07290696605507817, 0.12220585319612708, 0.11210033616849355, 0.11586902822766985, 0.2611894889601639, 0.16878660369132245, 0.13801898966942514, 0.22822462927017892, 0.13718315666275366, 0.14842360493327889, 0.15292678400874138, 0.0826707999887211, 0.10095212794840336, 0.13373184257319995, 0.08037996398551123, 0.0900381568021008, 0.13073144214493887, 0.09348958624260766, 0.21406293846666813, 0.11565906235149928, 0.13637343368359975, 0.11711160226591996, 0.11521612826202597, 0.15929912350007466, 0.12516537867486477, 0.1870966540383441, 0.08970825307603393, 0.1054876052907535, 0.12744780762919358, 0.12664492428302765, 0.1074144479685596, 0.09137257055512496, 0.18197883080158914, 0.08088008500635624, 0.1069029343447515, 0.13350050284394196, 0.17137206638497965, 0.14108917063900403, 0.19811486851956162, 0.22474850794034346, 0.1276780752731221, 0.11175819167069026, 0.10454570368996688, 0.09796775451728276, 0.12145531204129968, 0.1481225389455046, 0.1940861346998385, 0.1679970467729228, 0.23922476757849964, 0.12323924845882825, 0.11938320180135113, 0.10023603601647274, 0.17824049639914716, 0.1123025803161519, 0.1161475804235254, 0.11455733861242022, 0.1457049051033599, 0.1030352847384555, 0.06589420485709395, 0.13064230978488922, 0.07008099662406103, 0.07728472471769367, 0.18827298948807375, 0.07866242221955742, 0.14330450605068887, 0.13978774047323636, 0.15087143358375343, 0.10554268197821719, 0.11635021812149457, 0.14451567748827593, 0.1861959666545902, 0.12706739375633852, 0.16061066383762018, 0.17491226856197628, 0.15772786709879125, 0.08728609340531485, 0.10795667887266193, 0.17809269790138516, 0.1708088551781007, 0.17145886458456516, 0.11447492374905519, 0.16331763858241694, 0.08931534058813538, 0.18790309290800775, 0.24020815481032642, 0.1480388484363045, 0.09278561294611011, 0.1418013067117759, 0.12480282384370055, 0.09624813643417188, 0.07877131351935011, 0.08244055270084313, 0.23933270892926625, 0.12393891305795737, 0.10814185786460127, 0.11067341773637704, 0.1716206544744117, 0.11507109818714005, 0.14232570571558817, 0.1425775507731097, 0.098184003627726, 0.09199864803148167, 0.0719718158777271, 0.09212219568767718, 0.08341492220227208, 0.12391888270420687, 0.15060822985001973, 0.13351069443992206, 0.07046603132039309, 0.12343299734805312, 0.1397746040352753, 0.11014221981167793, 0.1036272794008255, 0.15368411051375525, 0.16213539987802505, 0.08184622387800898, 0.1832496997501169, 0.11174383386969566, 0.13626207251633915, 0.17716904889260018, 0.05724088169102158, 0.1500595121511391, 0.08214641455560923, 0.1133440840723259, 0.08924503078950302, 0.14731166245681898, 0.11003120469727687, 0.08105241254504238, 0.1833525520882436, 0.1545966858310359, 0.17627570325774805, 0.19816235240016664, 0.1307766597185816, 0.10499513814491884, 0.28664044184344156, 0.1411647322986807, 0.12590528040059976, 0.1111628111185772, 0.1568817610719374, 0.08671836994056191, 0.16123760305345058, 0.17384597792157105, 0.10254511782633406, 0.12263478232281548, 0.16835164917366846, 0.10687950453055756, 0.09590879428599562, 0.10450529692960636, 0.16050235607794353, 0.12254878479455199, 0.07301266824028321, 0.14410102473837988, 0.10303546115756035, 0.11196131112852267, 0.0767524072102138, 0.14180566290659563, 0.08623305455382381, 0.10071022342890501, 0.20658492616244725, 0.08734582484300647, 0.08935696871152946, 0.1038419950221266, 0.09074276792151587, 0.08264561276882887, 0.186659039663417, 0.11607952336115496, 0.14146955737045833, 0.17034100528274262, 0.13364572290863308, 0.2195932159998587, 0.13718778427158082, 0.16533606313169003, 0.14541564562491008], [0.04086122275995357, 0.019234313429998498, 0.01163381792139262, 0.03294669870021088, 0.05026176225926195, 0.01853774464689195, 0.03178192887987409, 0.008324451661402625, 0.03160106876332845, 0.00566741285313453, 0.026257116946258714, 0.031321244314312935, 0.058016107949827395, 0.01117592298292688, 0.037675239611417055, 0.036578618455678225, 0.0032271354492487653, 0.015557891955333096, 0.028395888162776828, 0.12490859388240746, 0.03026061604863831, 0.05367445074287908, 0.03739294868760875, 0.006496347279088306, 0.026654806320688555, 0.019398586758013283, 0.01699044562077948, 0.02079454024455377, 0.05264701980299183, 0.04169291331033621, 0.051887450739741325, 0.02832646045966872, 0.0582034650391766, 0.046430112328380346, 0.01912529151221471, 0.022958824377773062, 0.03795615989448769, 0.02773683558085135, 0.06342863251588174, 0.031429321372083256, 0.02205097336055977, 0.03280829791245716, 0.05472004267254046, 0.0401255279513342, 0.043334584683179855, 0.03748957885961447, 0.08198949654719659, 0.04409449640661478, 0.02953889566872801, 0.01751195576174983, 0.03495233964973262, 0.07745334745517798, 0.07915536433990512, 0.0556860322664891, 0.039887111101831706, 0.0672746164990323, 0.04053240468991654, 0.07646471514765706, 0.02202253765426576, 0.0798155924837504, 0.019495557893865874, 0.016498965743396963, 0.08954457007348537, 0.028436350902276378, 0.0432229113898107, 0.049081759327756505, 0.06323800488774266, 0.04370322936613645, 0.03238619484805635, 0.02563851183679487, 0.036418518118028126, 0.06341837985174996, 0.02057743109097438, 0.05693313891866377, 0.027434310742786953, 0.036736696758972745, 0.0600340710952878, 0.0223150761531932, 0.05126960050048573, 0.057704463601112366, 0.0336949633700507, 0.025883177993819118, 0.03318347688764334, 0.01139290745569659, 0.07034245652279683, 0.02035471554180341, 0.04823382464902742, 0.033755251206457615, 0.03164289026920285, 0.04439446995300906, 0.010567607857020838, 0.014097727851809135, 0.027530313269900422, 0.03608325396531394, 0.0412062510315861, 0.01687833806499839, 0.051080591178366115, 0.057386787076081545, 0.051038667892238924, 0.05119358082967145, 0.09862476640513965, 0.03094822647316115, 0.029454221283750873, 0.040116486472210715, 0.035975672238107236, 0.010868113205235983, 0.018151861781786596, 0.0142135385124545, 0.03149881014334304, 0.03148519194551876, 0.027168625267222524, 0.019144948671704957, 0.02933750647519316, 0.04646834438400609, 0.01187225682328322, 0.03820714321253555, 0.02693211001210979, 0.02202516867380057, 0.06898625501032386, 0.03393416732017483, 0.02654104313946196, 0.014496658097154327, 0.043155213951000145, 0.012960936574797546, 0.0028527495118656327, 0.03894066331642015, 0.027957091440579722, 0.028260871568428617, 0.03850164098132934, 0.02994915490437831, 0.050042184934552224, 0.029524554831108878, 0.044982064315783124, 0.05376371541725738, 0.04891392369089382, 0.027973003086767027, 0.025594471521409493, 0.023457018359165107, 0.033836424350738525, 0.027628383632483225, 0.058789434310581, 0.019653441118342534, 0.05440348233761532, 0.002892842237737828, 0.024413294724321792, 0.029054221497582536, 0.030850819378559078, 0.04082139953970909, 0.018420276664463536, 0.020475638963814293, 0.041092816939843554, 0.026507976431665674, 0.04382414769913469, 0.022194826177188327, 0.008711305679753423, 0.06097355032605784, 0.03990723645048482, 0.008718439627305737, 0.031574151279138665, 0.03346008847334555, 0.027260515872122984, 0.012549589986779859, 0.047939418482461145, 0.048213013980005465, 0.010882253875024617, 0.041576317245406766, 0.0243476990477315, 0.01683241481493626, 0.025344081921502948, 0.004588554471930755, 0.04252346731456263, 0.07203179837337562, 0.04214839690497943, 0.043220207427761385, 0.02953335882297584, 0.11006177269986697, 0.04389972292951175, 0.05473063121150647, 0.03943140019795724, 0.055915675658200464, 0.01221492379305086, 0.04219191474840045, 0.013781749360662485, 0.013631935613895101, 0.019703769757013236, 0.0663540887513331, 0.02755546147402908, 0.04371202996532832, 0.05968492411609207, 0.03614639164879918, 0.053956582210958004, 0.05483947501384786, 0.021118723920413425, 0.022617989452555776, 0.03359134089467781, 0.038445526135287116, 0.07783401238598994, 0.04514188306140048, 0.0407487521879375, 0.00945325318856963, 0.02541483616057251, 0.03065957428355302, 0.010105967405252159, 0.04393521370366216, 0.06324595053281103, 0.024044022396472946, 0.06376007651644093, 0.0051210204089459565, 0.010385342324817819, 0.08016749431512185, 0.01090036312650357, 0.07189488357731275, 0.024613109716613377, 0.06316103187522717, 0.04954588406586221, 0.011186621783833419, 0.006765642560951943, 0.061658307510827265, 0.014380771101319363, 0.03631580827225532, 0.0337153974521373, 0.026437402004376054, 0.01657200325280428, 0.021864630681063448, 0.05657535418868065, 0.03243408924234765, 0.015027437026479414, 0.03964364595179047, 0.02663401431137962, 0.03499680404950466, 0.03652540095416563, 0.01510007250388818, 0.04030868151624288, 0.059786147970174036, 0.051513275996382744, 0.07112282607704401, 0.04154264494510634, 0.013165039060238217, 0.05638610737930451, 0.062383417173155715, 0.0493195247836411, 0.009759365780545133, 0.013240659243560262, 0.08289834670722485, 0.002546107874617779, 0.04011885795210089, 0.0387622662819922, 0.05712285730987787, 0.05198954311864717, 0.03917276979024921, 0.06191582512110472, 0.04373590761263456, 0.08410283457487822, 0.010075859110137182, 0.046723612650696716, 0.017408190794023018, 0.030411037084247385, 0.015461538286347474, 0.07131198806954281, 0.03953198283644659, 0.05925353190728596, 0.04553718399256468, 0.029196554395769323, 0.038498373835214546, 0.037582860461303165, 0.027073871244543364, 0.03322666224890521, 0.049135841961417875, 0.06189641223422118, 0.022205616580322385, 0.01836248583692525, 0.023850677235584174, 0.0365011670759746, 0.027534087620941654, 0.04280746814661792, 0.020576180890202522, 0.07876651627676827, 0.020658239522682767, 0.06916971730866603, 0.06216065412653344, 0.011895103945529886, 0.07216865210128681, 0.037209048734179566, 0.046276254512901814, 0.041240252421370575, 0.033457330228494744, 0.053645443370831866, 0.04190287918650678, 0.031052015189613615, 0.019180090000320758, 0.03320959030783602, 0.07092647839869771, 0.01954275000441287, 0.006762996274379215, 0.06776719221046992, 0.04020767140069178, 0.008253160531499555, 0.07219474177275385, 0.03400232277012297, 0.021102703708623136, 0.006890548983522291, 0.0441110526610698, 0.05421112444517868, 0.024696021606879573, 0.04860051854380539, 0.028713162655809095, 0.04218530920999391, 0.021176959188388925, 0.04665369300970009, 0.03367122482242329, 0.027151268341445496, 0.058817512089652677, 0.015026855182700923, 0.004628436215820589, 0.019722680527982966, 0.021549478306302, 0.03613095836980002, 0.05568331473373941, 0.025205979689157436, 0.03770703576239092, 0.06922892627439328, 0.04580446911443557, 0.029831666565899338, 0.040268335824034045, 0.00584046430386869, 0.03056582110002637, 0.04921160039624997, 0.03354472214622157, 0.008089316376884068, 0.02419839589856565, 0.045287299901247025, 0.034025314929229875, 0.0710855337924191, 0.018622128958148614, 0.008695394033566117, 0.0393576230853796, 0.045031325958137, 0.013866401693251516, 0.02654729244698371, 0.014814785847972547, 0.02075118524953723, 0.013276652981793242, 0.0691162623198969, 0.049287450433309586, 0.0187764108580138, 0.022785836963781288, 0.015403981553390622, 0.051956664704318554, 0.015680620280493583, 0.03422113335026162, 0.03983408019744924, 0.05429604310276253, 0.13967780422951492, 0.18231855971472605, 0.12299607507884502, 0.08569474558212928, 0.0980803913303784, 0.1271464295153107, 0.0615470413384693, 0.10576958408845322, 0.13921034788446768, 0.2109305222651788, 0.07758788059332541, 0.11434896050819329, 0.14925459319991724, 0.11668583511241845, 0.10257941777152674, 0.1103240671966757, 0.1341002599469253, 0.12696851763342107, 0.11110951219286237, 0.15563398945544446, 0.13039739935525826, 0.18584310130349227, 0.11771889110761029, 0.1651771773717233, 0.19061260537377425, 0.08867567884070532, 0.07289660482534341, 0.17330286492194447, 0.14888925637517655, 0.08796763433409588, 0.1663816584540265, 0.12252301403454371, 0.09835323026137692, 0.1929076686501503, 0.0699436611362866, 0.11406683921813965, 0.13834183663129807, 0.12027413185153689, 0.09774825522410018, 0.09973328227975539, 0.10809093381145171, 0.1471540252012866, 0.11824946478009224, 0.1498311579759632, 0.0932927635897483, 0.09951450901904277, 0.14926131069660187, 0.15328728966414928, 0.09972353851688759, 0.11215309226619345, 0.09700240953160183, 0.10320169545177903, 0.12011862519596304, 0.09077714929091078, 0.17303510143288545, 0.09741101653448173, 0.13908465605761322, 0.11905166959123951, 0.0862228697431939, 0.1720214651099273, 0.07404438073613814, 0.11313785692410809, 0.23201253744108336, 0.11196226107754878, 0.1276970471122435, 0.12683621687548502, 0.15891071648469993, 0.15874632102038178, 0.06830255634018353, 0.14341571794024535, 0.20285930750625475, 0.11686887671904904, 0.14909539531384194, 0.17532563209533691, 0.11036722880921193, 0.06932315443243299, 0.23422027326055936, 0.13963873418314116, 0.14770466993962014, 0.07767349814197846, 0.09759489952453546, 0.10756396315991879, 0.17220817080565862, 0.11809098614113671, 0.15310968990836824, 0.1544254914458309, 0.14637152504708084, 0.10001285227813891, 0.08221097037728343, 0.09886389571641173, 0.10814919961350304, 0.0898479362949729, 0.1323636852736984, 0.13181971731994832, 0.11295750231615134, 0.10524048962231193, 0.2100398771997009, 0.2058022224477359, 0.14733803032764367, 0.15703904548926012, 0.2558712943324021, 0.09526870506150381, 0.12462301206375871, 0.17910359294286796, 0.1116000319431935, 0.14873692526349, 0.11504513743732657, 0.11807334423065186, 0.11145189417792217, 0.12701612365032944, 0.17914988260184014, 0.06626051877226148, 0.14425707422196865, 0.13045332421149525, 0.1386952448104109, 0.1840562064732824, 0.051900604141077826, 0.10250135910298143, 0.12236243193703038, 0.14714358933269978, 0.08725277055054903, 0.15859759971499443, 0.13152868007974966, 0.11711998895875045, 0.0983156394213438, 0.12591301569981234, 0.15416049637964793, 0.13726082178098814, 0.12578906092260564, 0.19005144334265164, 0.18729108146258763, 0.07952235000474112, 0.1070685036746519, 0.19266399315425328, 0.09713251183607749, 0.11226498269076858, 0.1847205058272396, 0.09507104102522135, 0.11776294160102095, 0.16119404110525334, 0.09789626406771795, 0.07658948416688613, 0.15748805925250053, 0.07992750326437609, 0.15129148747239793, 0.12008384349090712, 0.08901052230170794, 0.2262727418648345, 0.15012481436133385, 0.11490206154329435, 0.1236304510384798, 0.09640451839991979, 0.09473541724894728, 0.13199053172554287, 0.1431197409651109, 0.12258245370217732, 0.1853343221758093, 0.14289767002420767, 0.16969807978187287, 0.109787352782275, 0.10126432869583368, 0.15432641176240786, 0.1504414188010352, 0.1057180832805378, 0.1114266323191779, 0.10732344963720866, 0.1410268268414906, 0.1057245632899659, 0.06783095414617232, 0.11083169960017715, 0.2290310545691422, 0.2395423219672271, 0.1024667809584311, 0.14272039596523556, 0.10278691378022943, 0.3065562860241958], [0.0330552269837686, 0.0053588452366446805, 0.01981361100583204, 0.06769403935010944, 0.03569342541907515, 0.03529606852680445, 0.006146287246208105, 0.018255591126424924, 0.07472652556108576, 0.02744147607258388, 0.028934463459466184, 0.01703277263524277, 0.02696335994239364, 0.031449935265949795, 0.017117696381839256, 0.05652630289218255, 0.021564709721133113, 0.048541316363428316, 0.006787700886239431, 0.0704926841759256, 0.025873685288908224, 0.09414827411196061, 0.06326888501644135, 0.007821403610120927, 0.08584581461868115, 0.04135063989087939, 0.06740756186523608, 0.017573003557377627, 0.03481230019990887, 0.02002793307682233, 0.005195979444709207, 0.014181012088166816, 0.010759511979163756, 0.03173740680462547, 0.042693219812853, 0.06518147167350564, 0.044115100122456036, 0.06413060413407427, 0.07190027793071099, 0.019484643658090915, 0.019580300132344877, 0.047390500615750036, 0.01920550113676914, 0.021466863275106465, 0.015066264496584023, 0.03737336616697056, 0.042240243405103683, 0.027605389777038778, 0.023420691290604215, 0.07439339200833014, 0.019904502467917543, 0.00367369079529973, 0.040060171458337984, 0.07363865750708751, 0.03534661938569375, 0.04280636891988771, 0.016809424352166907, 0.07746293515499149, 0.04598485764914325, 0.00512832059757784, 0.03256498882547021, 0.041575767632041655, 0.005755716976377049, 0.03773875388183764, 0.04801171299602304, 0.029948873312345574, 0.04402250384113618, 0.02516253139557583, 0.05646765371784568, 0.014823847683146596, 0.03421598326947008, 0.03521196750391807, 0.011305779318458267, 0.009785542813395815, 0.030438782381159917, 0.01864801167643496, 0.02970223261841706, 0.016822906842987453, 0.04680638713762164, 0.015158222954986351, 0.034374397447598834, 0.0347179024081145, 0.038399877691907544, 0.011611229490621813, 0.05927358940243721, 0.03342205658555031, 0.013170408816742045, 0.037853877525776625, 0.04313789095197405, 0.02675359762672867, 0.03039212292060256, 0.041948724405041764, 0.024074279969292026, 0.10120160491870982, 0.013483766466379166, 0.021123733205188597, 0.041639767055000575, 0.02234866194027875, 0.038607438161437, 0.025875873564343368, 0.017922752736402408, 0.03783234760963491, 0.07036163192242384, 0.02363766304084233, 0.026956092832343917, 0.0033733595337253064, 0.007326521727788661, 0.04295118186356766, 0.02839160999948425, 0.06722690870187112, 0.03736408380791545, 0.007052745146211237, 0.004113460367079824, 0.012166210067724543, 0.031207935751548836, 0.06954070633011204, 0.1036497660513435, 0.04789393628016114, 0.04476934698011194, 0.037145028955170085, 0.03434527133192335, 0.07299471420368978, 0.022231877581881623, 0.025647125838856612, 0.03128932602703571, 0.030153505903269564, 0.08896748282547508, 0.07191921584308147, 0.03909487736278346, 0.016999590576493313, 0.03388418643070119, 0.019101483414747884, 0.02899223393095391, 0.04218390124983021, 0.10707362661404268, 0.10813451611569949, 0.03555444448388048, 0.11665140624557223, 0.024355366493442228, 0.041468199475535324, 0.01107040824302073, 0.02865379423435245, 0.07669032125600747, 0.04864543416936483, 0.03331318903448326, 0.01155808917246759, 0.00929511890613607, 0.013569680874102881, 0.07350510145936694, 0.029139730480632613, 0.011273476810726737, 0.0055709671578370035, 0.015590975626504846, 0.01084467999836696, 0.03873759474871414, 0.0054549932247027755, 0.047761082516184876, 0.07137237768620253, 0.03305116255900689, 0.010116975787760956, 0.0274129504603999, 0.021702962927520275, 0.037381549299295457, 0.05594531406781503, 0.0225567788085235, 0.06668807725821223, 0.04155168981690492, 0.02821058703453413, 0.048884902748146226, 0.029908809212169478, 0.04101269891751664, 0.02131309366918036, 0.0192206833578114, 0.023364052276260087, 0.012886414770036936, 0.02717800940653043, 0.015308489623878683, 0.0711553143337369, 0.06378493125417403, 0.03082071617245674, 0.012096359976567328, 0.016740702325478196, 0.028975799812802246, 0.06929118186235428, 0.017321848909237554, 0.037064117046871355, 0.032915021292865276, 0.03401774587109685, 0.06027714948036841, 0.03940238943323493, 0.015566589077934623, 0.004721072361072791, 0.024771132040768862, 0.05519598409799593, 0.017433038746405925, 0.06515530736318656, 0.05458076657461269, 0.07163461111485958, 0.04272154186453138, 0.01661780775923814, 0.021682174310886433, 0.03276076653440084, 0.047818503542138, 0.029711090893085514, 0.06010735287730183, 0.03580162461314883, 0.021856718962746005, 0.037640664859541824, 0.021155875409021974, 0.034081962425261736, 0.036071773152798414, 0.005472406977787614, 0.023483572827119912, 0.1292666071759803, 0.03668160650080868, 0.002289260529713439, 0.009044515567698648, 0.039186944386788776, 0.02337028631674392, 0.034539790358394384, 0.030859087327761308, 0.009583543786512954, 0.026906030518668037, 0.02464267348737589, 0.027954619876774292, 0.04669610484104071, 0.023937027602057372, 0.03726897016167641, 0.01647834845685533, 0.036802287346550396, 0.026179699493306022, 0.02881423383951187, 0.04010072410372751, 0.04395720502361655, 0.08770747043724571, 0.06177633189197097, 0.013734712465001004, 0.041166953675981076, 0.047338138068360944, 0.037351055935557397, 0.05585053290373512, 0.02306095407610493, 0.04487458776150431, 0.04423925167481814, 0.08482969485755477, 0.03587762392791254, 0.04283224485282387, 0.004079751171437758, 0.014259384579158254, 0.01702293218113482, 0.03627612075901457, 0.030549892490463595, 0.06666396212364946, 0.061196082670773776, 0.00986653275322169, 0.0446859787750457, 0.009591565766770924, 0.07040685628141675, 0.058303874651236196, 0.035936520767531226, 0.03479239876781191, 0.02835212435041155, 0.02145382692106068, 0.009415273887238331, 0.009191314922645688, 0.031682353865887435, 0.08427525710846696, 0.05586980329826474, 0.05567830375262669, 0.03224148029195411, 0.00818552924985332, 0.06997502302484852, 0.017840514292142222, 0.030443253926932812, 0.036164152302912304, 0.029042757648442472, 0.02885890519246459, 0.02715916818540011, 0.0592500985200916, 0.015807426601116146, 0.07712264984313931, 0.029194695209818225, 0.04172980186662503, 0.06036930810660124, 0.04778270064187901, 0.01888009100886328, 0.03334235925493496, 0.017436372049685036, 0.02829761423968843, 0.018665073439478874, 0.04037293878250888, 0.009596480904812259, 0.03306660262335624, 0.008396244059050722, 0.035319237105016194, 0.029855534035180296, 0.013271919351869395, 0.05720835272222757, 0.010451718316679555, 0.03265295749796288, 0.02410204053324248, 0.025642778125724623, 0.03992177067058427, 0.055438787676393986, 0.03938532427751592, 0.06292695764984403, 0.06428094035280602, 0.03604553420362728, 0.018234817776829004, 0.017900303405310427, 0.10183537698217801, 0.12608278516147817, 0.040958531466977935, 0.02051879039832524, 0.025456577938582216, 0.05408874386921525, 0.015619489364326, 0.03829674036907298, 0.01566766365431249, 0.019539554104475037, 0.01830752450041473, 0.02529569050031049, 0.037225655878760984, 0.041386731168521304, 0.02534871801201786, 0.026870955347216556, 0.02849024354613253, 0.01809827787136393, 0.04206956809918795, 0.00902987108565867, 0.00875758346436279, 0.01675312969434474, 0.06940510789198534, 0.046684084593185356, 0.010775221761183014, 0.04916555840255959, 0.018219484581745098, 0.03467449652297156, 0.044181830648865016, 0.036031108549130816, 0.020323206071874926, 0.04875206255487033, 0.055388202890753746, 0.048639751438583644, 0.0779347884069596, 0.07259050410773073, 0.02194738481193781, 0.03462520095386675, 0.038613701039659123, 0.04321740847080946, 0.05872044086988483, 0.0378559470575835, 0.09966337960213423, 0.21117626050753252, 0.14696693952594483, 0.1361885464617184, 0.10223575335528169, 0.13912747161728994, 0.09377418418547936, 0.13364580433283532, 0.19890199628259453, 0.11776381012584482, 0.13275619064058575, 0.11483939204897199, 0.14703266242785112, 0.1777451794062342, 0.09873918776533433, 0.16465418972074986, 0.12429485895803996, 0.09534842614084482, 0.06812773179262877, 0.22295465134084225, 0.10777351512972798, 0.185780689652477, 0.1411722776080881, 0.12354594628725733, 0.20748013098325047, 0.09364903518663985, 0.13438675100249903, 0.046062729720558436, 0.185860010396157, 0.1198723034134933, 0.09279431176504918, 0.14671090112200805, 0.09394675599677221, 0.12180083564349584, 0.14280053095093795, 0.09040963436876025, 0.11571044102311134, 0.18157835943358286, 0.1343362137143101, 0.13465918281248637, 0.0669830364308187, 0.14906373486987182, 0.09641205692397696, 0.1294769530317613, 0.1123530836775899, 0.20448526740074158, 0.14789440190153463, 0.13154644412653788, 0.09721198185746159, 0.1558878972594227, 0.1156395748257637, 0.0902675287798047, 0.11849719791540078, 0.19078271410294942, 0.09612247853406838, 0.13319320790469646, 0.16670158771531923, 0.1371322801070554, 0.08456637577286788, 0.09744267697845187, 0.11768998551581587, 0.287599076117788, 0.1227558601115431, 0.14779477939009666, 0.1438027543148824, 0.1878013126552105, 0.1489457240594285, 0.13823996138359818, 0.22738282515534333, 0.15137150032179697, 0.11130826867052487, 0.15448855449046406, 0.07373902640704598, 0.1387475598603487, 0.13811683441911424, 0.1716843010591609, 0.1579803228378296, 0.08018863068095275, 0.11840299011341163, 0.17255712779504911, 0.14771340947066033, 0.130188573417919, 0.1178848607731717, 0.08748260393206563, 0.1942016077893121, 0.17801233221377644, 0.1026671998468893, 0.20724208732800825, 0.13042516500822135, 0.09438555102263178, 0.1762738169303962, 0.1308996645467622, 0.11369531415402889, 0.25642335042357445, 0.12011478468775749, 0.15637665960405553, 0.08914627680288893, 0.07472915827695813, 0.18914074078202248, 0.08074279023068291, 0.06165920317705188, 0.16452365315386228, 0.19206975932632173, 0.11745595878788403, 0.12973347998091153, 0.15851058438420296, 0.11991715457822595, 0.1495093966701201, 0.142440242426736, 0.13990596841488565, 0.07257892830031258, 0.08267773461661168, 0.09117021784186363, 0.07653564919850656, 0.1580997042890106, 0.10667547583580017, 0.16891175269016198, 0.08209718005465609, 0.185508488544396, 0.07238346271749053, 0.1677785042141165, 0.17115123037781033, 0.05277639268232243, 0.11906233616173267, 0.258747577135052, 0.07453798782080412, 0.12710512030337537, 0.12350416210080896, 0.22324255374925478, 0.11058891298515455, 0.14470052399805614, 0.09137568503086056, 0.14665473199316434, 0.0690352859507714, 0.2307687827519008, 0.1923267748206854, 0.12095802729683262, 0.16200008642460617, 0.1505549784217562, 0.10930543685598032, 0.14585976036531584, 0.08399996866605111, 0.17636917824191706, 0.13082482213420527, 0.10322927111493689, 0.0858762129875166, 0.13118241008903297, 0.06247396767139435, 0.11688468658498355, 0.13611340549375328, 0.17097725399902888, 0.10956106813890593, 0.1412290438477482, 0.13080503605306149, 0.12151505026434149, 0.1341117543301412, 0.11592356887246881, 0.1511145391102348, 0.08333039030964885, 0.17067746365708963, 0.12481423680271421, 0.15257166592138155, 0.11893387591200215, 0.10880638792046479, 0.10073102052722659, 0.20195689664355346, 0.10949891433119774, 0.1424395910331181, 0.20810575384114469, 0.0964757442208273, 0.140994894983513, 0.16468737008316175, 0.0845951863697597, 0.09531769528985023, 0.1056446386501193, 0.1283563117363623], [0.02959343631352697, 0.03886187522272978, 0.018098829181066582, 0.013891957018391361, 0.05448180563481791, 0.026061620829360824, 0.06809474142002207, 0.055628821586391757, 0.035120609549007246, 0.03961367506001677, 0.021434802495475327, 0.033712652777986865, 0.07076517026871443, 0.01871345468264605, 0.05480881880170532, 0.02672111276271088, 0.017430809758869664, 0.013966264236452324, 0.033469754204686196, 0.020094451561037983, 0.05313433686803494, 0.09308188169130258, 0.04391138355380722, 0.07351042117391314, 0.006029940118813621, 0.017772279114329388, 0.006520019669551402, 0.017666999317173446, 0.0346159898409886, 0.07184412237256765, 0.05928337387740612, 0.02906767006165215, 0.003960859961807728, 0.0586309963837266, 0.04261324428288, 0.09117768172706876, 0.007543695342194821, 0.0084109267086855, 0.02074664754660002, 0.025707549382267252, 0.032858462006385834, 0.06144874875566789, 0.01488210161083511, 0.017936886620840857, 0.026764182773019587, 0.025072744249233177, 0.01223694734341864, 0.02653609661917601, 0.09870224153356892, 0.029390411850597178, 0.04166017738836152, 0.018005615432879755, 0.06910411654306309, 0.05546208178358419, 0.019507191376760602, 0.013880214969893652, 0.07135977050555603, 0.05828136085931744, 0.059907225758901665, 0.027176240126469305, 0.05668178579903074, 0.01608032320759126, 0.03646163562578814, 0.005804913309735379, 0.05884373068277325, 0.043601072526403835, 0.016864261856036525, 0.02728668018244207, 0.042983106936195066, 0.08300031016447715, 0.046022207609244754, 0.041716790957642455, 0.04193132337448852, 0.026194834216896976, 0.052593530887471776, 0.0429484507601176, 0.022693149080233913, 0.06172738916107586, 0.042134734602378945, 0.026549394209203974, 0.025863020414752618, 0.03582931562725987, 0.018131027364038994, 0.025827429556686963, 0.017727168409952095, 0.04402158103351082, 0.0424396410983588, 0.04500132113961237, 0.032644787936338356, 0.035914668547255654, 0.027441835696143762, 0.04691137007570692, 0.012820536653245134, 0.06587618975234882, 0.02037511400080153, 0.03952957403713039, 0.017920308313997727, 0.058479744142719677, 0.03782956561605845, 0.051079417312783856, 0.01953988828297172, 0.06215444553111281, 0.02490328691367592, 0.055530881841800044, 0.0387352538028998, 0.018322783056646585, 0.04420063963958195, 0.06685743959886686, 0.015546078660658427, 0.03761714683579547, 0.02660092555119523, 0.04570184747821518, 0.0436298050917685, 0.05229734017380646, 0.039424604669745476, 0.03274927554386003, 0.02335932119084256, 0.008113016756916685, 0.029653873427637985, 0.038570508893047056, 0.012709255213849247, 0.03081918946866478, 0.03233353374525905, 0.08329072315245867, 0.04319904052785464, 0.019365097662167888, 0.0036287522691834185, 0.033059043743248494, 0.0484443333532129, 0.012509878724813461, 0.018344962670068656, 0.09533946947859866, 0.009774477603579206, 0.007737790284279201, 0.0075135047747088325, 0.017023497061537843, 0.03982599884537714, 0.020444646876837527, 0.04537962816123452, 0.056977874732443264, 0.03239389622051801, 0.06459091550537518, 0.05045291914471558, 0.06689533577965838, 0.018939968331583908, 0.005076666695198843, 0.03393062197470239, 0.015302740735933185, 0.015238225626360093, 0.010559804704306381, 0.023056587703259926, 0.02443719781669123, 0.029575064977897064, 0.0401251276156732, 0.014383018748568637, 0.04641016000615699, 0.028891573260937418, 0.0324468151666224, 0.018060507219550864, 0.03146810304107411, 0.016219129420018623, 0.016891024973509566, 0.04066303285903164, 0.02592689939774573, 0.04930678868134107, 0.007878604960361761, 0.034588298826877556, 0.011919923908343273, 0.02643827222553747, 0.01796860134761248, 0.0036707595240191688, 0.03240405049707208, 0.10418014294867005, 0.006515313181028302, 0.08004049291568142, 0.04031334983717118, 0.010792077419215014, 0.05789046362042427, 0.026318373391404748, 0.045912152621895075, 0.06205848032342536, 0.05425668467900582, 0.040539800721619806, 0.031348891223647764, 0.04653083745922361, 0.15445835968213423, 0.015449312781648976, 0.03314879017749003, 0.05768783949315548, 0.08523965214512177, 0.0110660681634077, 0.008475818405193942, 0.056615584529936314, 0.031104214888598238, 0.01990700965481145, 0.013039645788791989, 0.07379571122250386, 0.05884903682661908, 0.026877326791041663, 0.01578187636498894, 0.03485283248924783, 0.021286983641662767, 0.029492768858160292, 0.026170289908934916, 0.05473832579861794, 0.04723613050633243, 0.0408891173345702, 0.034555613795029264, 0.04926402401179075, 0.06161336813654218, 0.10785891554717507, 0.05999764733548675, 0.06674469422016825, 0.05015971398513232, 0.04069923948762672, 0.010029330267570913, 0.05825510833944593, 0.044861196872911284, 0.03684783400967717, 0.03472310337903244, 0.037701410707086325, 0.059946397585528235, 0.009201274968550673, 0.020716868340969086, 0.06830795069358178, 0.04607410875282117, 0.07192406736846481, 0.04626774907644306, 0.03313580980258329, 0.02693505315775318, 0.0677531533209341, 0.04844273540324398, 0.01052252938305693, 0.06137843895703554, 0.022920224216899703, 0.021384076913818717, 0.05662350303360394, 0.08696884435734578, 0.03450820794595139, 0.03706087704215731, 0.03688897019518273, 0.03555358613708189, 0.02089525350103421, 0.010073805693536997, 0.02325034507417253, 0.04391844371067626, 0.03914503127868686, 0.022653414069541862, 0.029705723681088005, 0.06239701501492943, 0.016520164873717085, 0.021675561987129704, 0.005201752505464745, 0.0067529450503310984, 0.014529070018657615, 0.019124110861282264, 0.004865226277615875, 0.06413628347218037, 0.024096525739878416, 0.04232860223523208, 0.03320062346756458, 0.02341059299318918, 0.05240685911849141, 0.02766512630374304, 0.03180669201537967, 0.04582924582064152, 0.02141292143746146, 0.06242156441190413, 0.04034332412161997, 0.007742648595012724, 0.04393193977219718, 0.029322442997779165, 0.06164211766528232, 0.044343087888721905, 0.026249430840834975, 0.017665357262428318, 0.04031546347375427, 0.06983628296958548, 0.02969755751213857, 0.06123384314456156, 0.021436814351805618, 0.02749834069982171, 0.03206205188429781, 0.01617066335997411, 0.024281755621944155, 0.011983567948586174, 0.043348033247249465, 0.007725401083007455, 0.04066342980201755, 0.03208411784310426, 0.07683122583798, 0.018125339544245174, 0.10383338441273995, 0.039593234192579985, 0.05727348529866763, 0.020285744153495346, 0.05815479372228895, 0.03706705171082701, 0.06746924069843122, 0.044826591586960216, 0.08098022998975855, 0.011199090712969857, 0.02167052386461624, 0.00941078198541488, 0.003077981153702629, 0.031963548955640624, 0.01964476944080421, 0.10249056361083474, 0.044033014348575046, 0.03313780469553811, 0.005181448617284852, 0.02231104565518243, 0.06316941856805768, 0.04380974579336388, 0.04374602117708751, 0.04071206719215427, 0.02550529166390853, 0.043125633216862164, 0.09772242339594023, 0.013556878614638532, 0.045671761235488315, 0.007416429314097124, 0.03543129716334598, 0.020165670596595322, 0.009843513452714043, 0.012409237562678754, 0.029316539743116925, 0.05738477182707616, 0.011162370942266924, 0.01659753991823111, 0.039841747643159967, 0.05682433922109859, 0.023477476189977357, 0.0453614637787853, 0.06571424379944801, 0.024550345227388398, 0.013296678246531104, 0.07332060100244624, 0.04267365086291518, 0.06000759465886014, 0.04357120002220784, 0.03427429996164782, 0.06458776031753846, 0.0554114223590919, 0.04953879676759243, 0.03942318313888141, 0.03499161325661199, 0.006569533218030951, 0.025687364661800008, 0.05679122671218855, 0.018704201161329235, 0.009507679330584193, 0.08473295611994607, 0.08686297253838607, 0.14212671853601933, 0.11488769017159939, 0.12337956950068474, 0.11006153521261045, 0.2717881516686508, 0.15589267414595398, 0.1267186403274536, 0.2458594829908439, 0.1538147556462458, 0.11010415399713175, 0.1798141412436962, 0.17643866022782667, 0.12781828774937562, 0.10023955082786934, 0.11608560303492205, 0.07808864622243814, 0.09568090829998255, 0.1435100750199386, 0.11272233564938818, 0.1885402372905186, 0.08313638357711689, 0.10226664026933056, 0.09037072038544075, 0.07648216706833669, 0.10821124485560826, 0.10460681255374636, 0.08300407603383064, 0.12623556410627707, 0.1449065272297178, 0.10228194801935128, 0.15374711927558693, 0.10860322096518107, 0.2161314660417182, 0.14210245412375244, 0.13779514096677303, 0.09468296649200575, 0.17354749036686762, 0.141859199319567, 0.08980492396014077, 0.13006429294390337, 0.17879734294755117, 0.08054104141358819, 0.12132530473172665, 0.16333898529410362, 0.08607779217085668, 0.0378150822860854, 0.1848923516060625, 0.0898349287786654, 0.20976105358983788, 0.11485885243330683, 0.1304883501891579, 0.1278138772717544, 0.1569024021072047, 0.1301512811332941, 0.1424075641802379, 0.16239093616604805, 0.16842522951109068, 0.05277071334421635, 0.11388681030699185, 0.13960864794041428, 0.10506093568567719, 0.1603765014026846, 0.16739481980247156, 0.13526538599814686, 0.08114995873932328, 0.05978149321994611, 0.12398670906467096, 0.23822466124381336, 0.1037406829584922, 0.14511379253651413, 0.08656008807676178, 0.10469939865704093, 0.12129107942538601, 0.10509474030030624, 0.08104334731719323, 0.13549406587013177, 0.14746425141181263, 0.08752243393766028, 0.17310946887092932, 0.1517435953553234, 0.13188873790204525, 0.18328247299151762, 0.10165558555828673, 0.19270157042358602, 0.19494703279009887, 0.11256902744727475, 0.1044412771505969, 0.12655211426317692, 0.1255308783480099, 0.22790683060884476, 0.08736983819731645, 0.09897621361804859, 0.11869556084275246, 0.19378684647381306, 0.11609485825257641, 0.1650374670113836, 0.14352425640182837, 0.15951153210231236, 0.15054930586900028, 0.15529021647359642, 0.13965997232922486, 0.2011467936847891, 0.1470419583576066, 0.19660951143928937, 0.13525115033345564, 0.07643620989152364, 0.12613288818725518, 0.12155374033110482, 0.15422704709427698, 0.09606477591608252, 0.13253589746143135, 0.1319600383618048, 0.15367808512278966, 0.12416338601282664, 0.12314793121601854, 0.12540783280772821, 0.13419981460486138, 0.09766026280288186, 0.1269577017852238, 0.24236388770597322, 0.18946456483432225, 0.17004660250885145, 0.16282073381756032, 0.1695231670247657, 0.11171514540910721, 0.06914154453469173, 0.08600720417286668, 0.14776030981114932, 0.057323031925729344, 0.24050920722740038, 0.1199392205370324, 0.09212016686797142, 0.10256752305264984, 0.09080355787383658, 0.14722677772598608, 0.1424325614103249, 0.1509292447673423, 0.12568745708891324, 0.09324508971933808, 0.10784004548830645, 0.11997875198721886, 0.09122095190520797, 0.12561614305845328, 0.11801756865211896, 0.0966775608914239, 0.1283245834388903, 0.14775885774620942, 0.09348337086183683, 0.11802966014615127, 0.09432161945317473, 0.09810576175472566, 0.13085326632218702, 0.09947967981653554, 0.15093596226402692, 0.10188060812652111, 0.15413961107177393, 0.11660840069609028, 0.14794042014649936, 0.10478655648018632, 0.256691860301154, 0.08714879862964153, 0.15357220651847975, 0.1039684603789023, 0.09260146532739912, 0.08104460939232792, 0.08508029141064201, 0.15594736406845705, 0.11422864267868654, 0.07450206617691688, 0.08131909037807158, 0.17115564085543156, 0.1195420604199171, 0.1225772425532341, 0.09590143218104329], [0.01792019635571965, 0.023994770932144353, 0.025529754547668353, 0.01545873424038291, 0.03838424763775297, 0.018977833978299583, 0.07469462762985911, 0.0837992580075349, 0.03410574507766536, 0.024723020515271595, 0.05987431002514703, 0.016211811419842497, 0.037801118035401614, 0.02149052548754428, 0.037941432291907926, 0.11585838879857745, 0.007878165608937187, 0.019344280207795755, 0.017253783365179385, 0.07298659892486674, 0.008296454458364418, 0.041429251565464904, 0.018896082382915274, 0.04751235193439892, 0.0071300128973754385, 0.024543127311127524, 0.0466671449664448, 0.07317493988999299, 0.012551483947650661, 0.035177623453949175, 0.058391812789653025, 0.0652660849903311, 0.03672683425247669, 0.08587117825767823, 0.05915629105376346, 0.033025205201868496, 0.053651984448411634, 0.0397688356627311, 0.01316354373869087, 0.035948826000094414, 0.0078121831673862675, 0.025190582033246756, 0.019414327074108378, 0.046394061762839556, 0.08086633110152823, 0.07303412351757288, 0.0222894241368132, 0.027810812861259495, 0.04125563141756824, 0.03268073672162635, 0.013494619634002447, 0.02594822575338185, 0.030084705845053707, 0.009626886058997895, 0.03815600881353021, 0.042494273345385275, 0.010427642197880362, 0.07930037405874048, 0.03121546409758074, 0.07398823874869517, 0.05196839318211589, 0.003282895336659359, 0.019266542147046754, 0.06918227020651102, 0.07164983744067804, 0.03801355038636497, 0.0690486938027399, 0.0404597810868706, 0.007162002430829618, 0.059616785629519393, 0.03684105205216578, 0.05686665266486151, 0.019429838384634683, 0.017688985548115203, 0.03061139490455389, 0.036844604182988405, 0.04764715648655381, 0.03545662687559213, 0.017059647710993886, 0.03326865338853427, 0.006949149388154703, 0.024314211648223654, 0.026293267595714757, 0.01909736979619733, 0.02977989095130137, 0.007950900322092431, 0.033603958253349574, 0.01533449617480593, 0.03876485828576343, 0.07196211961231061, 0.02807176046605621, 0.08087097228105579, 0.03346721309104136, 0.01523140465308513, 0.023418882994779518, 0.02753791116577174, 0.011855119573218482, 0.019177993327113133, 0.043128988572529385, 0.03580699521782143, 0.01622059166298381, 0.00902112222476197, 0.022619341433580433, 0.02478718109029744, 0.04767417575099638, 0.039503514899739196, 0.013279312839066344, 0.05218860832974315, 0.04095515914793525, 0.013208539940283766, 0.01989106577821076, 0.023118071457637206, 0.020989439250635247, 0.035381204315594265, 0.07961792166211776, 0.012269623893579202, 0.07515467437250273, 0.039539877591388564, 0.02959398253421698, 0.053203618686114035, 0.05239514421139445, 0.03171350201591849, 0.006548484213583703, 0.03882211985598717, 0.029214094526001384, 0.0832695257184761, 0.015316565886938145, 0.018850735887619, 0.08441100482429777, 0.01502093326832567, 0.030809438920446804, 0.043372311230216704, 0.0057740628669437554, 0.0614175157887595, 0.04603392251634172, 0.023695262182237845, 0.012877883888514978, 0.007479443164941455, 0.05263389693573117, 0.01961529557593167, 0.015661349885963967, 0.03967102144711784, 0.05614971595683268, 0.02935213569019522, 0.022282788064330816, 0.011375424152772342, 0.027154501560809355, 0.0036607583419286777, 0.07852256936686379, 0.02352009667083621, 0.057977797862674506, 0.012451877551419395, 0.0521461625716516, 0.053570872372282405, 0.0029828397299362613, 0.12036428201411452, 0.032019202397870164, 0.05540312048313873, 0.07887852205229656, 0.012731892838408905, 0.006729123806248286, 0.040907213863517554, 0.025424501891913157, 0.05698787633861814, 0.033664497147713385, 0.05108237572546516, 0.02449928207456001, 0.0430778711368995, 0.021189985364409428, 0.011317298298568597, 0.041844918725213835, 0.038233490727309666, 0.017366991844028234, 0.03001441979514701, 0.05439018305124981, 0.035820626986346076, 0.04470850953033992, 0.0055732580616937154, 0.033347312560571093, 0.014705738485125559, 0.07114486489444971, 0.06797736843249627, 0.05570245620661548, 0.04195748768480761, 0.06070390050964696, 0.028310838887201886, 0.016157961184425012, 0.009574646496080925, 0.04421956058857696, 0.040358150111777444, 0.028558446493531977, 0.027408726579908813, 0.004484632592980883, 0.0591226357168385, 0.0446831662473934, 0.041008593780653815, 0.06247585399874619, 0.012997934544858123, 0.0688704155119402, 0.031143264578921453, 0.025361900251092653, 0.08110036461481027, 0.01490759926049837, 0.09346106741577387, 0.08011332007923297, 0.01594955424245979, 0.040926823525556495, 0.12329777888953686, 0.030332042037376335, 0.05778265119131122, 0.028661281868283237, 0.014297438519341605, 0.07565638995064156, 0.040359368082135916, 0.06788194605282374, 0.03666223432602627, 0.030446175020188093, 0.0299333959285702, 0.022497792063014846, 0.03016086122287171, 0.042985084865774424, 0.033245749438979795, 0.034066471470785994, 0.05694512863244329, 0.041000363150877614, 0.04397739822577153, 0.035171248617448976, 0.021088868379592896, 0.04117028867559774, 0.0461480453211282, 0.019191406268094267, 0.03724115701126201, 0.05232287005388311, 0.07552512056593384, 0.008553320675023963, 0.014558464155665465, 0.034586185190294466, 0.013258981385401316, 0.0353170250808554, 0.039190985062824826, 0.06830389305417027, 0.018212738247322183, 0.0030819510076461093, 0.01984296612707632, 0.038443256435649734, 0.04193010879680514, 0.022680014338610426, 0.014226413714433355, 0.03693874413147569, 0.050165583313043625, 0.026783911178686788, 0.01797131888036217, 0.028111763498080627, 0.029132419265806675, 0.008704739157110453, 0.009325024488914226, 0.045117377769201994, 0.030253097880631685, 0.08581926354340144, 0.025305400336427347, 0.004204923919002924, 0.003025238626703088, 0.03816735391904201, 0.01946714423995997, 0.0253882087501032, 0.022372487001121044, 0.0700643996575049, 0.02587373787537217, 0.05140684777870774, 0.07101683890713112, 0.05194599134847522, 0.04390235225270901, 0.03142386934320841, 0.034144238369273286, 0.056882920541933606, 0.061464422914598665, 0.0020047611864616294, 0.03106083275218095, 0.02547463884444109, 0.036755498964339495, 0.03576430857979825, 0.0169202002829739, 0.019830601522699, 0.06834854065839734, 0.06139053723641804, 0.042928556113370826, 0.025606866659862653, 0.03610753534095628, 0.04806953775031226, 0.03614344002146806, 0.03995274918686066, 0.044850160500832965, 0.021321546519175172, 0.06161460985562631, 0.028574191898639714, 0.030914001166820526, 0.029378625697323253, 0.03442309929856232, 0.017857886484957168, 0.03987600687625153, 0.06378355382808618, 0.027614706062844822, 0.0317352863826922, 0.02897400169500283, 0.04187682683446577, 0.041617748593645434, 0.03022001251312239, 0.04045100762907948, 0.06919646515910115, 0.0245015229364591, 0.007704495419082897, 0.007320176577195525, 0.020377008809841106, 0.014086879773198493, 0.00977541652641126, 0.0515936756107424, 0.017859903430300098, 0.05386728360982878, 0.028228866767936518, 0.021725910981850963, 0.027766221236171465, 0.0366334033730839, 0.010216043596821172, 0.03228345786088279, 0.01070007061519261, 0.029356932932777063, 0.008740232475767178, 0.02589453667003129, 0.0037717632783044663, 0.0547187195292541, 0.020513760757499507, 0.02713939397861915, 0.010032074941721345, 0.026091014966368675, 0.02706883821104254, 0.0310019698393132, 0.04752700489812663, 0.032381723302283456, 0.0167377880175731, 0.036255204917064736, 0.05588892441509025, 0.037094267750425, 0.012434925202147236, 0.046526416803577116, 0.012853323465346225, 0.006722710378068898, 0.012656305733669018, 0.026651491677122455, 0.012275973285016204, 0.041384485217609575, 0.027010431612974832, 0.00898208949781422, 0.16773610934615135, 0.12484620937279292, 0.17544413145099366, 0.08907224184700421, 0.15212871826120786, 0.13167829705136164, 0.17310227639973164, 0.1600783531154905, 0.09914069729191916, 0.14030160861355917, 0.12412788506065096, 0.06602858193218708, 0.15696581799004758, 0.1147297000778573, 0.10414569372577326, 0.18075317942670413, 0.08531604161752121, 0.21761641278862953, 0.09815867391547986, 0.15502138089920792, 0.10231567120977811, 0.12801465578377247, 0.11798863591892378, 0.09297218972018786, 0.07400640991649457, 0.17094031455261366, 0.15528740733861923, 0.2096802129277161, 0.13379177078604698, 0.09830831802849259, 0.18937011275972637, 0.1418488041630813, 0.1291586115424122, 0.1322674961494548, 0.10766361959810768, 0.12350756834660258, 0.1724697867674487, 0.1234607630010162, 0.17427777046603815, 0.2291824221611023, 0.15428949945739337, 0.13001135364174843, 0.08868040144443512, 0.17331589279430254, 0.12427401436226708, 0.18321618012019567, 0.0972084127632635, 0.1444462633558682, 0.09675510387335505, 0.09813158679753542, 0.2259888021009309, 0.10872737251754318, 0.12280954580221858, 0.1486288346350193, 0.21254572059426988, 0.09504100227994577, 0.10073304256158215, 0.27948710854564396, 0.06351102023784604, 0.09884682377534253, 0.13798594501401695, 0.08479329823915448, 0.08271187171339989, 0.13590303249657154, 0.10710217258227722, 0.12286346219480038, 0.19629058640982422, 0.1468679141253233, 0.20596216672233172, 0.1366688542600189, 0.09129037960831608, 0.1517804805189371, 0.11794544037963663, 0.11871085502207279, 0.11774190701544285, 0.16044936249298708, 0.1329385130000966, 0.12495349932994161, 0.13535192635442528, 0.08411379291542939, 0.1198648666696889, 0.15716171104993137, 0.1696058397314378, 0.14443578677518026, 0.08431104304535048, 0.09198037508342947, 0.14616404260907853, 0.1536011935344764, 0.14319015932934626, 0.1733947249927691, 0.1408758256584406, 0.13744351054940904, 0.14485537926001207, 0.18406884079532965, 0.16254300943442754, 0.1251450361950057, 0.11133089102804661, 0.1109058770484158, 0.22519336906926973, 0.12977025657892227, 0.12154525864337172, 0.14953507243522576, 0.05394495212073837, 0.11390739705945764, 0.08862672932446003, 0.16163564526609012, 0.1360292671514409, 0.107562042905816, 0.14877732523850032, 0.15721557315971169, 0.09733810116137777, 0.11183371261826583, 0.1370251937104123, 0.11312704107591084, 0.16699371061154775, 0.08495147153735161, 0.11278761750353233, 0.1834271095160927, 0.10156050244612352, 0.178913806698152, 0.16508686436074121, 0.2436165176331997, 0.12480105965265206, 0.14447944371828012, 0.1506813352129289, 0.11645959796650068, 0.10803191483552967, 0.08775675922100033, 0.09472899830767087, 0.1061475213084902, 0.07323759581361498, 0.0883096091981445, 0.10096986485379082, 0.18265477381646633, 0.12700441213590757, 0.10515127583806004, 0.11956304072269372, 0.13327119871973991, 0.1924758625349828, 0.12412798005555357, 0.10028544015118054, 0.14046436202313217, 0.15497587834085735, 0.08651372377893754, 0.10138406977057457, 0.15373293789369719, 0.08472492226532527, 0.11803620122373104, 0.19238899648189545, 0.10907373750316245, 0.10373549216559955, 0.07774121593683958, 0.1705294751695224, 0.11395125756306307, 0.05490057709227715, 0.1322253726954971, 0.17698410738791737, 0.07122362923941442, 0.12186730493392263, 0.10954329730676753, 0.10012953315994569, 0.18531940797609942, 0.19638901469962938, 0.13550846438322747, 0.10827020276337862, 0.16298237442970276, 0.07741925785584108, 0.21739259122737817, 0.09806029312312603, 0.16469617746770382, 0.12967589949922903, 0.15424483828246593, 0.04726441863125988, 0.08749927553747382, 0.18369636578219278, 0.13802969695201942], [0.06430895706372601, 0.02320656429843179, 0.06372037543249981, 0.014851647262860621, 0.03807521564885974, 0.013584920770621725, 0.03941262174131615, 0.011415787656525416, 0.07576256032500948, 0.010543034711320485, 0.04807928829853024, 0.018539705613095845, 0.038268720265477896, 0.03941187535279563, 0.018087255069985986, 0.02579642050633473, 0.006558604139302458, 0.008646430946620447, 0.0036938844215390937, 0.03543222336364644, 0.0344049891989146, 0.04680316409628306, 0.06072661786207131, 0.051601203956774304, 0.032619831418352466, 0.05764232336410454, 0.03306104542155351, 0.04759981170562761, 0.07543346405561481, 0.011790091321537537, 0.01809075122166957, 0.04290409831862364, 0.07688691999231066, 0.028193740706358637, 0.030663177304502045, 0.01884355189810906, 0.04345425111906869, 0.09810456753309284, 0.03512338814990861, 0.059977528772183826, 0.0476046869797366, 0.04649772495031357, 0.007567541607256446, 0.06913119009030716, 0.0629995201847383, 0.019892517843150666, 0.04988121267940317, 0.0692679759647165, 0.036629674823156426, 0.08150393688785178, 0.056362287407474856, 0.03730917336153133, 0.01406450423278979, 0.023407263082585165, 0.07106665694820029, 0.011859823517235262, 0.052615793621433635, 0.03761207139385598, 0.01443012264956321, 0.03691981978980558, 0.05504623820473041, 0.014091834775172174, 0.03596480210710849, 0.07753514485167605, 0.043950345034578016, 0.09330577789140598, 0.02678030646140022, 0.08199324206049953, 0.03473239930878792, 0.0039497222335610005, 0.018194882598306452, 0.04740995421473469, 0.04023258042122636, 0.015309561709208148, 0.013930439283805234, 0.018585328611412218, 0.03453907450394971, 0.026694607488544922, 0.05302438705361315, 0.028234749666548202, 0.07959956050451313, 0.09887741891933338, 0.060762498793857436, 0.04378877566861255, 0.03962158677833421, 0.016320624688108052, 0.022527913928830197, 0.11235844410423722, 0.003882061690092087, 0.08089671589966331, 0.09389850537159614, 0.031397216487675905, 0.0717984094683613, 0.030945498762386184, 0.034403733909130096, 0.04886811239910977, 0.04664542166782277, 0.056009422056376934, 0.022672893113589714, 0.023690695641562343, 0.055638751946389675, 0.024395827536604235, 0.015122206316196492, 0.05010376198749457, 0.007045886005341474, 0.02491566169607852, 0.050491884018161466, 0.03140341829774635, 0.026831496839544604, 0.01581163182189422, 0.05014244866158281, 0.01744003444244819, 0.01848502586861806, 0.0480955222488514, 0.027778555306472948, 0.060768015283559046, 0.066206941647189, 0.007239916062514696, 0.032358449551143816, 0.03703002405485936, 0.05006125516125134, 0.04733794468588062, 0.04008895152115396, 0.04062165579359446, 0.04477199326668467, 0.058281910472682545, 0.010968577100097068, 0.016595163349328295, 0.035169430143598995, 0.049129131250083447, 0.05539382455338325, 0.014787751316492046, 0.01578644969101463, 0.046408782580069134, 0.04876996570133737, 0.042766097866530926, 0.06682924646884203, 0.03326864321050899, 0.02307134583991553, 0.04629307539601411, 0.020214075588488152, 0.05864152046186583, 0.006977847602684051, 0.02012510777318052, 0.02665403957611748, 0.018776733162147657, 0.02284066259328808, 0.028984420600214174, 0.03619230132816093, 0.029732057625161748, 0.034094101416745355, 0.05090142061401691, 0.012404859315470924, 0.07527450365679604, 0.023513296053611805, 0.01181019885864641, 0.03494685369410685, 0.08204263940985713, 0.00887909297099603, 0.026074557099491358, 0.05768383613654545, 0.03491350709061537, 0.02356227271125785, 0.03301888464816979, 0.05592417430930904, 0.0655489255275045, 0.04053396192778434, 0.09068264293351344, 0.06465676054358482, 0.0196989182316299, 0.027957948091040765, 0.028409692957731228, 0.09806214552372694, 0.028083499121878828, 0.02098757158299642, 0.012166174444636064, 0.025523028569296002, 0.020725351725039736, 0.03205382803987179, 0.008446223252186818, 0.05363861730854426, 0.05692150204309395, 0.039597481821796725, 0.028723439068666527, 0.018590602524844662, 0.03120934371171253, 0.019193625077605247, 0.03450167365372181, 0.03529179375618696, 0.016035278660378287, 0.030762921952243363, 0.07157531393957989, 0.04963894175099475, 0.021542316369180168, 0.012680619339724737, 0.03492098793919597, 0.013941231383276837, 0.0029814031440764666, 0.02029263467660972, 0.027790411009586284, 0.02856680265228663, 0.03953512106090784, 0.04312940247889076, 0.006782448177026319, 0.058966362316693575, 0.018843745280589377, 0.05337583765919719, 0.028205689708037034, 0.035374018629746776, 0.03576330095529556, 0.04345308403883662, 0.04602360199870808, 0.02254074502603284, 0.03264257591217756, 0.029824504628777504, 0.04090173469324197, 0.01353044034580567, 0.06530046635972601, 0.0449224346583443, 0.024770251641582166, 0.038996279439223666, 0.04642755764403513, 0.025680323164643984, 0.035584961596344195, 0.06383401647742305, 0.07966347850326981, 0.07073617646736757, 0.01469638487989349, 0.01818242808803916, 0.01716720568947494, 0.03583585670483964, 0.039411227351852825, 0.06104366334953478, 0.021524309746122787, 0.029521528564925705, 0.08807571817721639, 0.040965289675763676, 0.013734935533388384, 0.0657690694289548, 0.06745873019099236, 0.01700870499813131, 0.07258772211415426, 0.030108301900327206, 0.04968559442620192, 0.07735170969473464, 0.017224409584222094, 0.020339989635561193, 0.07881742675921746, 0.04555833053642085, 0.03030933825565236, 0.058015415844108374, 0.002180869225412607, 0.025541055548403944, 0.01940257484758539, 0.02209382115064987, 0.005332353957263487, 0.03550174266898206, 0.03522084613463708, 0.0735784646655832, 0.02964778696852071, 0.0075706289415912965, 0.022042018394651156, 0.015613109438813158, 0.13262597977050714, 0.051918147663984976, 0.0060522168475602356, 0.05317644335861717, 0.08961713939372982, 0.04088841165815081, 0.04143031347276909, 0.011811150504010064, 0.015079065059710826, 0.033280772023967335, 0.01563787935966892, 0.08030955240662609, 0.05922146434230464, 0.06080526007073266, 0.10555970642183508, 0.0411442498942571, 0.05437235115095973, 0.02406399168207177, 0.05670162616297603, 0.04423075302370957, 0.01737753118920539, 0.02217545739508101, 0.044731142065886936, 0.041572330852172205, 0.013195192308298178, 0.02219978626817465, 0.021177853158275996, 0.06623387948742934, 0.03292407634268914, 0.06128053992454495, 0.085883140830057, 0.06801537996424095, 0.04414715750941208, 0.03709261891032968, 0.057924539649060795, 0.039991615672728846, 0.041315305179783275, 0.01161789015999862, 0.015179215132125785, 0.010416135092132857, 0.055167899533574066, 0.028042551229840944, 0.03997669468766876, 0.07652190207902874, 0.014712053949811628, 0.027860064325588088, 0.04100862092205456, 0.08062108818973814, 0.035198987129011323, 0.050750687452299256, 0.031542911526880095, 0.04333659653951015, 0.009220683614590337, 0.04433652984776667, 0.044253802858293056, 0.027700617077893445, 0.017209754924156835, 0.022965572408533523, 0.01746167122785534, 0.054506416099944284, 0.016128541602353965, 0.03440883309979524, 0.0380545033674155, 0.020157360238954425, 0.02956768251689417, 0.011515652744232543, 0.05977222443159137, 0.05162507821140545, 0.00676541101087683, 0.03937982475118978, 0.041354219163102765, 0.02337238298995154, 0.07178212462791375, 0.05695508274116686, 0.05295355139034135, 0.027190804880644594, 0.03238196078953998, 0.05094282142817974, 0.03858517882015024, 0.019634053676522205, 0.06135018475885902, 0.017563575313293507, 0.02145842569214957, 0.08754890358873776, 0.08974568106766258, 0.06270285110388484, 0.0610547981091908, 0.025547394761815667, 0.028489738037543635, 0.1421349695218461, 0.07246553831334625, 0.1587523464113474, 0.12678567958729609, 0.11887586116790771, 0.17339430430105754, 0.11686331273189612, 0.10923956467636994, 0.13539635682744638, 0.06653272666569267, 0.11757027836782591, 0.09487940916525466, 0.14076823714588368, 0.11546269431710243, 0.09194114897400141, 0.13067002115505083, 0.06605505158326455, 0.09750896984977381, 0.10404432737933737, 0.10881976184568234, 0.08836079109460115, 0.12679619688008512, 0.15441559840525898, 0.07809941457318408, 0.10471218904214245, 0.2748314083686897, 0.11917760569070067, 0.08953920286148787, 0.14803029889506952, 0.18134294849421295, 0.11323857866227627, 0.22266019428414957, 0.18119599137987408, 0.20049674356622355, 0.13866445289126464, 0.14672223265681947, 0.0992239671094077, 0.1737728997000626, 0.09522587593112673, 0.13938456853585585, 0.1166085906858955, 0.18473447007792337, 0.10192830913833209, 0.16351932633136, 0.13682700720216545, 0.07608356845698186, 0.14851204518760952, 0.1451913355184453, 0.12336921505630016, 0.17078456362443312, 0.20053084673626081, 0.16559218295982905, 0.09897898882627487, 0.06585698042597089, 0.15943949882473263, 0.12715459907693522, 0.18791475013962813, 0.08046144247055054, 0.10340413637459278, 0.13504065519997052, 0.20252497973186628, 0.092381436776902, 0.11360698246530124, 0.14966928666191442, 0.11904041948063032, 0.1719606276601553, 0.16090236604213715, 0.2442749680152961, 0.13378803884344442, 0.08732550271919795, 0.08618426788598299, 0.11129493545740843, 0.14472446271351405, 0.16261441845979008, 0.15628188183265074, 0.10732665910784688, 0.14889509177633695, 0.06371928977646998, 0.09361566483442273, 0.0995772938643183, 0.15672113826232298, 0.18763621151447296, 0.1677255513412612, 0.1386445311031171, 0.11763582485062735, 0.14741657754140242, 0.07260333520493337, 0.2651690425617354, 0.08598492786820446, 0.11953587218054704, 0.135005561368806, 0.1362032571009227, 0.10930589147444282, 0.09754640462675265, 0.10421336402318307, 0.11980925393956048, 0.13282648686851772, 0.17101808823645115, 0.12895902725202696, 0.14793425904853003, 0.22670940629073552, 0.14867232872971467, 0.12560601931597504, 0.1362853598381792, 0.10813394614628383, 0.08248965828014271, 0.13728109640734537, 0.13953999376722745, 0.09777381563825266, 0.18077698243515833, 0.11165344621986151, 0.16884825538311685, 0.18633696623146534, 0.1433966646769217, 0.15200480419610227, 0.14373836134161266, 0.20577274688652583, 0.1452695027525936, 0.15361597202718258, 0.12283029540308885, 0.09709182687635932, 0.14796393817024572, 0.18527161196938582, 0.1411917922752244, 0.1427265027804034, 0.1281604186764785, 0.12061231370483126, 0.097597830795816, 0.10938081531120197, 0.10739119457347052, 0.1610019342707736, 0.1503479438168662, 0.10094056571168558, 0.1273392148848091, 0.19982679880091123, 0.16559565705912455, 0.16450203502816813, 0.07889279842908893, 0.09557020531169005, 0.10869222440357719, 0.10458694504840033, 0.1633390938597066, 0.05291846434452704, 0.08758796006441116, 0.10203937853553466, 0.11575537361204624, 0.17563120355563505, 0.10227889461176735, 0.08796819073281117, 0.10638075415045023, 0.14737453551164695, 0.08795341224010501, 0.061750913970172405, 0.17531185783445835, 0.10060821925955159, 0.10788840467908553, 0.1353122049144336, 0.2558772382991654, 0.12933515278356417, 0.13244989993316786, 0.22078225362513745, 0.1169891809778554, 0.07813978062144347, 0.12490026147237845, 0.19196759909391403, 0.1083150946402124, 0.20269860327243805, 0.3224711077553885, 0.21885703264602593, 0.15289994116340364, 0.12948867811688355, 0.12301765249243804, 0.16097089807902062, 0.1166096492005246, 0.07996489732925381, 0.09884133442704167], [0.027380701387301087, 0.04305418687207358, 0.021303019120490978, 0.056070391820477586, 0.07034766088638987, 0.04788980060922248, 0.030455857714904205, 0.03292582696303725, 0.051199531581784995, 0.05874412174203566, 0.022015139926224947, 0.023262903061030165, 0.0400894841711436, 0.03235844615846872, 0.05689856755946364, 0.05178117519244552, 0.05011007575584309, 0.0070951438309358695, 0.011612312602145331, 0.05185497944642391, 0.017196472601166794, 0.047294138465076685, 0.004706329491455108, 0.02626064363201814, 0.04094816005921789, 0.012181483890994318, 0.026346483400889804, 0.026482899473713975, 0.0343326471879014, 0.04022746426718576, 0.1179015798760312, 0.04760317384664502, 0.021169424057006836, 0.019706109006490027, 0.0605517661731158, 0.009032628482340701, 0.06483553416494812, 0.017108587049213902, 0.020972518283607702, 0.024055781408346126, 0.032502943583364995, 0.024806575317467962, 0.05681988463870116, 0.01080561419283705, 0.013617252964260322, 0.029309371020644903, 0.05225038555051599, 0.01989372563548386, 0.08049779159149953, 0.04732252837025693, 0.020641457655334046, 0.028833259961434772, 0.02141962536344571, 0.057452509977987835, 0.0850850682971733, 0.0425421575616513, 0.0688402953424624, 0.038088358872170956, 0.033343533120517216, 0.03356298830892358, 0.0041597716543557385, 0.022958486806601286, 0.04242643002154572, 0.02772989756028567, 0.025558746652677655, 0.03624346965391721, 0.018790868742923652, 0.028389881431524242, 0.039881706570408175, 0.018810773567695702, 0.014460512536710926, 0.039667679662151, 0.07453863921442203, 0.009698369723212506, 0.07494995357202631, 0.043753668266747675, 0.023974959405937364, 0.062413272713976245, 0.016699963082958545, 0.019956571548911076, 0.031194056317742382, 0.10370259678789548, 0.045850643422454596, 0.04198599972629121, 0.040264050875391276, 0.004246100392525217, 0.0744964818337134, 0.005338074007470692, 0.06095717049070767, 0.010772124248822885, 0.024546340174440826, 0.0243621331839157, 0.033527483964072805, 0.027593496754499416, 0.03294606766264353, 0.03423480922356248, 0.06386520873223032, 0.12330037089330809, 0.01049359156084912, 0.05087267787062696, 0.047037689547453604, 0.023999449431097934, 0.07680866454860993, 0.025452109785484414, 0.06237289309501648, 0.014199005140523826, 0.09884522921804871, 0.09535411904965128, 0.004031437781772443, 0.045301352361483235, 0.010326811045940434, 0.04852212400042585, 0.01870003156363964, 0.011000611586496234, 0.049805539061448405, 0.0290691017705415, 0.035447873773851564, 0.041970203431057077, 0.03667042424370136, 0.07802812768412487, 0.13097309560648032, 0.018561001434656124, 0.04646833420598081, 0.025145113401647125, 0.04347508892949138, 0.0290226119437388, 0.048862802862588844, 0.024435199531061307, 0.03975912243393915, 0.036364516908569, 0.038036820744829516, 0.03183424732248698, 0.0665439564202513, 0.02737982098811439, 0.01773971112977181, 0.0386640686940934, 0.02604363625869155, 0.020644434727728367, 0.05491061941055315, 0.024484038785366074, 0.01496363607501345, 0.03174444321276886, 0.02833218390255102, 0.021510418437953507, 0.02109797771221825, 0.05366256280935236, 0.027505904668942094, 0.10659284384122916, 0.019750788841130476, 0.01477313058317772, 0.051628182509115765, 0.04175855478804026, 0.028275553369894624, 0.0648977015433567, 0.03355724111731563, 0.04978875210508704, 0.030306990524487834, 0.09063304202365023, 0.04171268921345472, 0.051688178575464656, 0.07968164288571902, 0.0434401375906808, 0.03788785177416035, 0.0347804056613573, 0.056245155299880674, 0.00469695553017248, 0.019039597628372054, 0.05522158522424953, 0.008835300320892461, 0.056037038431635926, 0.0052064331248402596, 0.03310072275676897, 0.009065260079556277, 0.027364095939057212, 0.06448630576155015, 0.06031478103250265, 0.027508165886891738, 0.0873343643865415, 0.0521590140249048, 0.010999545438348182, 0.07087972733591284, 0.037963223444031816, 0.008119855541735888, 0.03433160563664777, 0.03214381196136985, 0.053859042802027295, 0.05601750680112413, 0.016839235788211226, 0.032683338903422864, 0.019431811225201403, 0.03758672811090946, 0.029810669299747263, 0.054597319436392615, 0.028466851051364626, 0.042081194796732495, 0.09872501995414495, 0.05485615001193114, 0.008450327540880867, 0.029192551039159298, 0.0614347370075328, 0.04889607482722827, 0.04581115946971944, 0.020100470166653395, 0.024418041076777235, 0.06279971876314708, 0.03639420620830996, 0.10367641890687601, 0.0598001732890095, 0.04713852324389985, 0.045378464473677535, 0.013413213243308877, 0.01357021352409252, 0.04292862396687269, 0.04093499308718102, 0.009764916196997677, 0.03611681430733629, 0.03345672633232815, 0.07749163040093013, 0.04703731296051826, 0.04329227802476712, 0.008824768609234264, 0.058466587348708084, 0.03845101209091289, 0.027312622272542546, 0.032906787270413976, 0.049471285925912004, 0.0058179920722198275, 0.022524602677939192, 0.04614939560581531, 0.06986317331237452, 0.035334378613957336, 0.010316750067951424, 0.010649609662193273, 0.06550158413925342, 0.030274614226073027, 0.022797154927892343, 0.008178219731364931, 0.014940138407317656, 0.01934057879926903, 0.04715092007869056, 0.04011610649260027, 0.044011460683707676, 0.03216826297076685, 0.042154174630663226, 0.07062318003071205, 0.06093583056437118, 0.04492787311651877, 0.045213777239301374, 0.026039902619751434, 0.014327680825122764, 0.060148777440190315, 0.01552935955779893, 0.06006205387945686, 0.02515742033054786, 0.07071221061050892, 0.04879554986421551, 0.027165285178593228, 0.04671567379097853, 0.021518099454364607, 0.02365471123318587, 0.031519040664924045, 0.015884633708213056, 0.04722322816295283, 0.08048499442104783, 0.05528941158471363, 0.028748887524540936, 0.03711387401978884, 0.06080596574715205, 0.05003834442634668, 0.02716302396064358, 0.04015919685895954, 0.04448226899174707, 0.01356022124777415, 0.02378495772635298, 0.014285760931670666, 0.06224017843071904, 0.0165372520818242, 0.03074474060641868, 0.08351512825382607, 0.04038782584081803, 0.020095067331567407, 0.028231343420754586, 0.08884272737694637, 0.07113958589200463, 0.037708352120327096, 0.05216452372925622, 0.043536699909184656, 0.021232585489217724, 0.010555222048424184, 0.037495627999305725, 0.0385522630863956, 0.030906941009951488, 0.024926810026434914, 0.009602847259624727, 0.0179842042603663, 0.024652530904859304, 0.008660236589743622, 0.06211568082549742, 0.008727757609449327, 0.03927580872550607, 0.02634756057523191, 0.06084428940500532, 0.009438897083912576, 0.0634836277791432, 0.04244048926713211, 0.01530935475602746, 0.0523152433202735, 0.03673015568139298, 0.07683894756649222, 0.022862338394458805, 0.02733271030176963, 0.02484426793775388, 0.04489374280508075, 0.03154147303264056, 0.0328082775564066, 0.05153592888798032, 0.060676195924835544, 0.018092093024668948, 0.016742293490096927, 0.08752237965485879, 0.0263501763277288, 0.0438690260052681, 0.012239469797350466, 0.06848436979843037, 0.016567516439993466, 0.017153397501845444, 0.07370243301349026, 0.04733829413141523, 0.024204882693343928, 0.042775302194058895, 0.02931154233270458, 0.051921757470284186, 0.01408368132875434, 0.025086781442431465, 0.07671620736696891, 0.06761314440518618, 0.05014849440859897, 0.014883553675775017, 0.021622809282104884, 0.028542925004980395, 0.017232552004445876, 0.03430518687569669, 0.04298955301887222, 0.10379643818097455, 0.050024549809417555, 0.06328227251235928, 0.024679392409910048, 0.024574365367048552, 0.04627411712759307, 0.07342286301510674, 0.06546391866036824, 0.07331910822540522, 0.1518289279192686, 0.1752427422574588, 0.07642406411468983, 0.08120399048285824, 0.18883769347199372, 0.16217270573335035, 0.09999659457909209, 0.21850509010255337, 0.18130786823374884, 0.1687312080924, 0.12317600899509021, 0.06442067106919629, 0.11284014289932591, 0.10278599097260407, 0.1386094915547541, 0.15261011171553815, 0.13237729668617249, 0.06909776545528855, 0.06247877848467656, 0.18858234717377595, 0.09268288952963692, 0.10194775595196656, 0.056155561536018334, 0.11999494183276381, 0.2102384301168578, 0.09494414140603372, 0.1618063511060817, 0.11499279524598803, 0.12770525738596916, 0.0896912489884666, 0.15815454348921776, 0.14697247637169703, 0.12959147617220879, 0.09685930649616889, 0.1442560428487403, 0.08809401148131915, 0.17500650350536617, 0.11756186453359467, 0.0556040991629873, 0.11750930521105017, 0.1211407296359539, 0.18890646978148393, 0.12453237335596766, 0.07456915971956082, 0.09984310317252364, 0.1428239404090813, 0.1496484149247408, 0.08704660447048289, 0.17378602256732328, 0.11722860884453569, 0.06993067397602967, 0.06685226237667458, 0.11730171420744487, 0.15041655727795192, 0.15807611841176236, 0.15378427585320814, 0.14050922675856523, 0.09156600053289107, 0.12606175057590008, 0.11549173561590058, 0.04304247196497662, 0.11348309554159641, 0.11350113100239209, 0.20489883449460777, 0.09654430339911155, 0.11204923569623913, 0.11665395753724234, 0.1881555893591472, 0.19106288121214934, 0.14484860748052597, 0.13731191546789237, 0.10640007882778134, 0.17635418261800492, 0.07404749521187373, 0.14654233945267542, 0.13651239765541895, 0.13045635047767842, 0.15755140728184155, 0.1277826375194958, 0.14457586354443006, 0.09587520680257253, 0.12284799159637519, 0.08762371885989394, 0.0888847354799509, 0.1268366239964962, 0.12462181784212589, 0.2678298226424626, 0.19528517393129213, 0.15341621131769248, 0.0725739546386259, 0.14608827738889626, 0.08727061602153949, 0.099257853148239, 0.127237041081701, 0.061313604936003685, 0.11433401916708265, 0.13978543345417294, 0.21969993598759174, 0.10901904758065939, 0.13618822076490947, 0.1333200532410826, 0.1771724551383938, 0.12502161067511353, 0.19525257710899624, 0.1346694558326687, 0.13329969719052315, 0.23203910887241364, 0.24652623864156858, 0.10208013134875468, 0.1275759150407144, 0.0994190527126193, 0.1069687454562102, 0.08848520049027034, 0.09837003078843866, 0.11456495177532945, 0.15748465300670692, 0.09907348839832203, 0.06819702378873314, 0.1129817735137684, 0.2541568806128842, 0.24110292536871775, 0.2177157774567604, 0.09735085761972836, 0.07324968730764729, 0.14672216480331762, 0.136947827147586, 0.2121263723820448, 0.22088301607540675, 0.24086049837725504, 0.10887198190071753, 0.1221951459135328, 0.09014605744076626, 0.15213113384587423, 0.12406521556632859, 0.08504763352019445, 0.11392847235713686, 0.10791724241737809, 0.12884674327714102, 0.1502068221036877, 0.172566328729902, 0.08870579901018313, 0.15563179100198404, 0.10091390607080289, 0.14920698718300887, 0.0818125753264342, 0.1341236015515668, 0.09923076603029456, 0.16850144256438526, 0.08998543463115181, 0.11789129328514848, 0.22456067587648118, 0.15116804838180542, 0.09287916256913117, 0.152596133894154, 0.12129893686090197, 0.16522729396820068, 0.10931115012083735, 0.16262720205954143, 0.11586879752576351, 0.2867588054920946, 0.14803758636116982, 0.14169902434306486, 0.09606161394289561, 0.0680759052879044, 0.0955494964229209, 0.09250768500247172, 0.1337479238531419, 0.21053239862833703, 0.19131132002387727, 0.16552156103508814, 0.09282397053071431, 0.15502368791827134, 0.12803076420511517, 0.14089249047849858, 0.11227849232298986, 0.14378524811140128], [0.009716915781609714, 0.034083214322371144, 0.06320870574563742, 0.026846256672537754, 0.007902806608139403, 0.06179879818643842, 0.047668102862579484, 0.054416676451052935, 0.011917382794698434, 0.07599681096949748, 0.038493810687214136, 0.054816757661423514, 0.05952152609825134, 0.04437307235119598, 0.024783985190359608, 0.05934835039079189, 0.010478731643940722, 0.018503941728600433, 0.04266673998375024, 0.05426318843715957, 0.003731466779884483, 0.037298656068742275, 0.04342044311176453, 0.06524902661996228, 0.03995954810774752, 0.09926815330982208, 0.05327050527557731, 0.017680106917396188, 0.013423256409753646, 0.02277312461020691, 0.005367449060681143, 0.037257292574005466, 0.02040624858013221, 0.052361183533711095, 0.02558531129865774, 0.011011838796548545, 0.009857553190418651, 0.041251085232943296, 0.020213955148522342, 0.052643779798277786, 0.015108211531436868, 0.0732059082282441, 0.03377020611826863, 0.04545975296891161, 0.04925852109278951, 0.015992990661678568, 0.029878512623586824, 0.05260702016364251, 0.028607294229524474, 0.04248088924214244, 0.03127942280843854, 0.018204590738085762, 0.03802606596478394, 0.008006776832709355, 0.017812487403196946, 0.02869592447366033, 0.027409885178453157, 0.0038371291011571884, 0.04118189501709171, 0.02612566774977105, 0.06243923346378973, 0.05520118846158896, 0.01581259025260806, 0.035681829255606444, 0.05461686463760478, 0.04157076343627913, 0.016058764453711252, 0.037094725761562586, 0.05539151753431984, 0.09075585007667542, 0.008982913917861879, 0.01248118347887482, 0.053574726451188326, 0.012296807702763804, 0.04003095034775989, 0.03854419191234878, 0.04128280674506511, 0.029443568283958093, 0.026825315385524715, 0.04115300638867276, 0.029184585038040365, 0.022953859197774103, 0.049291358795017004, 0.02944938332906791, 0.03358022649107235, 0.06971792610628263, 0.026344364675294076, 0.07408950331487826, 0.019569684451978122, 0.057802661189011166, 0.03663364425301552, 0.04713003137814147, 0.0955955350239362, 0.00974643714393356, 0.028695266294692243, 0.025477174869073287, 0.030655268978859698, 0.02802074989969177, 0.019287953319560205, 0.04542227069448147, 0.020516271337068508, 0.049401678411023955, 0.14072223247161933, 0.05298859772405454, 0.05899054530475821, 0.020968109502324035, 0.0487071469293109, 0.0004004411254884742, 0.027223866499428238, 0.02168304453204785, 0.03415031125769019, 0.033054595946201255, 0.022666345250659754, 0.027553475062761987, 0.02811985502817801, 0.03036272878359471, 0.021071998302691748, 0.04823240311816335, 0.03699635514723403, 0.026541375621621097, 0.04331477824598551, 0.03127849321546299, 0.027563295160819377, 0.04078924037250025, 0.023137796470629315, 0.01976143166289798, 0.040987304744443724, 0.056455599543239386, 0.023185356686423932, 0.054549896623939276, 0.02420576987788081, 0.0918864319100976, 0.019522492341431122, 0.05819499692214387, 0.05609277329806771, 0.018004997966012785, 0.03414539187880499, 0.031766600773802826, 0.031355123567794047, 0.0638450901689274, 0.0754595740831324, 0.07498609234711953, 0.039791200176945755, 0.015929732538227524, 0.037336294406226704, 0.03032909380272031, 0.029655647796711752, 0.04627525367374931, 0.024966024261500155, 0.026368744438514113, 0.04543702543846198, 0.025484038250786916, 0.05874060693063906, 0.028693949936756065, 0.03974189782249076, 0.03654098690354398, 0.05554620994787131, 0.07813994346984796, 0.02014066488482058, 0.07287129546914782, 0.015620968570666654, 0.030409842862614563, 0.05521339869924954, 0.04064745030232838, 0.05524032975413969, 0.009740058914758265, 0.03758650080167821, 0.016908587156129733, 0.038816606758960655, 0.03588313702493906, 0.04321621764185173, 0.015632003246407424, 0.07278978984270777, 0.048866846931299994, 0.03650561487302184, 0.012454778288624116, 0.08779355617506163, 0.04596263223460742, 0.04179785892899547, 0.03802891241918717, 0.05206230242869683, 0.024859207582526972, 0.015336165370951806, 0.030501166890774454, 0.010201757890172303, 0.006284538332173335, 0.05097574394728456, 0.03577986399510077, 0.0747430750301906, 0.031172733354781355, 0.048223066476306746, 0.026467622257769108, 0.015126565903691309, 0.020121136646983877, 0.04315204179978796, 0.043441121466457844, 0.026592825539410114, 0.0573323414261852, 0.05997009202837944, 0.018696854323414818, 0.04218217437820775, 0.05719225787158523, 0.04354953779173749, 0.0229262241628021, 0.05921261624566146, 0.027730286021583846, 0.05630626416366015, 0.0382802655388202, 0.012276908815173166, 0.07641625417662518, 0.006321846307920558, 0.01949970713550491, 0.029003385653985397, 0.02958245761692524, 0.012743844384593623, 0.04310042903359447, 0.027579625802380697, 0.009333415422588587, 0.016861600302425877, 0.03525560748364244, 0.053686990070023706, 0.02013472600706986, 0.023079914040863514, 0.03263429778495005, 0.04709554483581867, 0.012058290769346058, 0.012813394224005086, 0.01765417500532099, 0.01246865772243057, 0.02162887029615896, 0.03368337738460728, 0.009817069246699768, 0.05710972087191684, 0.01028599716456873, 0.031775014608034065, 0.043272566582475386, 0.03542808090735759, 0.027030531516564742, 0.047322626757834635, 0.0350467815463032, 0.030530177655496767, 0.01661828951910138, 0.011517880035431256, 0.013355704855972102, 0.024305706211764897, 0.016934552994955863, 0.033268948551267385, 0.02914274317611541, 0.0585587527602911, 0.014428411044978669, 0.028662584655519043, 0.011397370519781751, 0.011089022154919803, 0.018727125466934273, 0.02661190594413451, 0.05085163649969867, 0.062164162152579854, 0.010202603514439293, 0.03671011854229229, 0.074570984978761, 0.09928658910627876, 0.0618146216230733, 0.024179591996861354, 0.02977971113952143, 0.042283964809030294, 0.06214763982487576, 0.015300080878660083, 0.038447785656899214, 0.022689522310559238, 0.025344697692032372, 0.015713471553421447, 0.007953762891702354, 0.022259208972432783, 0.01579733339271375, 0.051690682369683466, 0.022351464289905768, 0.010509345447644591, 0.07215932903013059, 0.04822090534227235, 0.03084504504555038, 0.058612452021666935, 0.03643917611667088, 0.005188583837090326, 0.05173099074246628, 0.024445392823378955, 0.043335331071700366, 0.03445981143574629, 0.023542970086314847, 0.07873496439840112, 0.04738261603883334, 0.06537087115326098, 0.02419574621931783, 0.0411703565290996, 0.03417173260822892, 0.03745118056290916, 0.043583057421658716, 0.116146074075784, 0.02584223179811878, 0.04518313459785921, 0.026706821118880595, 0.03260081208177975, 0.02587398893332907, 0.054855091497302055, 0.07103305589407682, 0.020219904204298342, 0.007290292198636702, 0.06721633034093039, 0.06972403970680066, 0.06033327789711101, 0.050433628394135406, 0.07904059692685093, 0.02253584091418556, 0.02290837190646146, 0.049018438439816236, 0.00878302428671824, 0.05775785752172981, 0.015189019963145256, 0.05713914893567562, 0.018644142330491116, 0.03620693054316299, 0.015387348963746002, 0.03877253590949944, 0.024764087150937746, 0.01400385846916054, 0.035230698463107855, 0.06376031400369746, 0.028637472074478865, 0.05014997700761471, 0.026582705189606974, 0.011068107161138738, 0.027582263607265692, 0.029915560635605028, 0.030075959528663328, 0.04170816677755543, 0.03696424687015159, 0.06466617182429348, 0.010683129292114504, 0.0345499242788979, 0.06773003563284874, 0.029989921288298707, 0.03256235271692276, 0.05630872385310275, 0.015381515258923173, 0.008586124450500523, 0.009814694374134498, 0.06072812420981271, 0.028025190911388824, 0.03820683108642697, 0.04298894912270563, 0.01970438043853002, 0.016211994624297534, 0.0325603713946683, 0.11394109310848372, 0.1440769096038171, 0.12746623664030007, 0.09269157477787562, 0.18506575801542827, 0.09339341747441463, 0.10388480379645314, 0.1998572921646493, 0.08701957163533994, 0.1967508095715727, 0.1178758226867233, 0.20660410156207426, 0.22597181158406393, 0.11974237752812249, 0.10524093067007405, 0.08691577613353729, 0.13860968154455933, 0.15188600628503732, 0.15133342093655042, 0.11123857633875948, 0.09576452417033059, 0.07968161574431828, 0.11833947923566614, 0.10974193164812666, 0.1282185148447752, 0.2126714259918247, 0.14083111020071165, 0.0819723771086761, 0.1482626564268555, 0.07213873549231462, 0.07934720654572759, 0.12022177608949797, 0.10922715427087885, 0.09605010598897934, 0.10837450038109507, 0.09862220832811934, 0.13519203636263097, 0.11521964307342257, 0.1550702897033521, 0.2085779192192214, 0.07343969746891942, 0.16278865268187864, 0.09091023714946848, 0.12430878249662262, 0.12179448455572128, 0.06331165307866675, 0.10223797216479268, 0.20057861560157367, 0.21550284405904158, 0.14241124184003898, 0.14745467049734934, 0.07368769523288522, 0.09401018545031548, 0.12489291972347669, 0.12068677613777773, 0.08506683606122221, 0.10405333832438503, 0.07326933089643717, 0.09661238760288272, 0.11749052336173398, 0.20583705843559333, 0.07219829051090138, 0.16070660868925707, 0.1450125551117318, 0.18719753862491675, 0.1389895390186991, 0.07496816545192685, 0.11209453469408409, 0.09353119400995118, 0.14995074298764977, 0.09641532746276685, 0.0973949148984892, 0.1587253407176052, 0.1149642967752048, 0.12350247933396272, 0.23665257702980722, 0.15604139545134135, 0.1552794956203018, 0.17170282506517, 0.1484226007014513, 0.1575805028634412, 0.07096150437636034, 0.1753294047500406, 0.2813506099794592, 0.2999582929270608, 0.22194420413247176, 0.09003753254988364, 0.18248043102877481, 0.10357548003750187, 0.10284984111785889, 0.09494237721498523, 0.12781442009976932, 0.1830552994672741, 0.054764937942049334, 0.10311547400695936, 0.11867616831191949, 0.1550566375787769, 0.1207969430834055, 0.09771706296929292, 0.13276872996773037, 0.09501786423580987, 0.09013716863202197, 0.24588301458529063, 0.1490530954407794, 0.20307806719626698, 0.07359697510089193, 0.15417862683534622, 0.09289991217000143, 0.15902404540351459, 0.12456571656678404, 0.1311082054993936, 0.08618957402982882, 0.0785609744489193, 0.08133985354964222, 0.1265954047973667, 0.15133454730468138, 0.09945048924003329, 0.1489164384880236, 0.16098228389663355, 0.13747715231563362, 0.17961876387042658, 0.10950582860303776, 0.12407837914569037, 0.13739897151078495, 0.11512817655290876, 0.15526891047401087, 0.09291365928947926, 0.14846916177443095, 0.11156056156115872, 0.12768769689968654, 0.09648370343659605, 0.224330747500062, 0.11636608227023057, 0.14910714754036494, 0.19927684616829666, 0.10198919408555542, 0.15083722184811318, 0.1838111603366477, 0.06756491413606064, 0.16476720651345594, 0.17399232435439313, 0.12419682421854564, 0.14831077813037805, 0.06883439208780016, 0.0888565219938755, 0.14113018129553112, 0.08573699117239032, 0.13478672025459154, 0.1044589394171323, 0.18945304330970558, 0.1591855910207544, 0.17573606435741695, 0.13929368555545807, 0.10252994578331709, 0.0904980610523905, 0.10786574160946266, 0.12770812080374785, 0.1802991037922246, 0.09159008852605309, 0.1637226561350482, 0.22009138283985002, 0.14163929969072342, 0.17476490432662622, 0.1397738712174552, 0.11617890159998621, 0.08129790651478938, 0.08371280586080891, 0.07549134987805571, 0.19417103300137178, 0.10809374294642891, 0.081853246715452, 0.11546008874263082, 0.15097534443650926, 0.1482894585600921, 0.1025084497939263, 0.07810571137815714], [0.06187982883836542, 0.04452435173360365, 0.07944865431636572, 0.022922475256824067, 0.06723097312663283, 0.049377156155450005, 0.03401824798701065, 0.04134755934189473, 0.03277310569371496, 0.025662355557350174, 0.023323353745841553, 0.04136663296126893, 0.019567770983225534, 0.03901179753510015, 0.01989179350701826, 0.06646264756896667, 0.0701899557773556, 0.036757748307926316, 0.030926326755434275, 0.011841738862650735, 0.029187512916645834, 0.020030976306380968, 0.014615113348034876, 0.031124866101890802, 0.03212408694837775, 0.037719256178076775, 0.026623851553137814, 0.07279403068657432, 0.016250971372106245, 0.026221561711281538, 0.026817483395071964, 0.054286791277783256, 0.03251680266112089, 0.03830567328259349, 0.024062794067763855, 0.06453594059816428, 0.08083415497094393, 0.006273708489191319, 0.03756093020950045, 0.07061511224934033, 0.020799802283623388, 0.03437516079949481, 0.032218834185706716, 0.028652966421629702, 0.033633874862321785, 0.07472054088222128, 0.03366015452359404, 0.0013852102627944468, 0.04824632665674601, 0.017271062259429266, 0.033224460402769704, 0.031597832151289494, 0.043025006473596604, 0.034368653648665974, 0.02929672652057239, 0.015925941223810827, 0.07319965213537216, 0.020290302212483118, 0.002020486447561, 0.05364864266344479, 0.03590418518121753, 0.08313029711799962, 0.04156614939815231, 0.04873948251562459, 0.01733604386182768, 0.009002531213419778, 0.04569336239780698, 0.022963134771479026, 0.026338456331619194, 0.06969419095133032, 0.03651548416486808, 0.06063834045614515, 0.019158631330356002, 0.02195180716392185, 0.05026688859132784, 0.011048515310644038, 0.06563586621944394, 0.026518870311390077, 0.0006176626349250519, 0.07466488065464155, 0.03479653104607548, 0.05747971923223563, 0.017327974384118403, 0.07515329694641487, 0.027333566952230673, 0.05860752585743155, 0.03427935844021184, 0.0369571595718818, 0.005520319607707539, 0.033115165374640904, 0.0483005992802126, 0.032339813586856635, 0.01676778605074755, 0.016296353490490998, 0.038373743915664296, 0.00629426767617198, 0.06130627675780228, 0.053300320104296715, 0.011770569869051022, 0.03584588205974017, 0.014981464582628437, 0.03284687262826732, 0.038689286448061466, 0.033662760098065646, 0.011207619898154266, 0.01588654039161546, 0.017240355157160332, 0.00780636812227645, 0.03998788373012628, 0.022169338705550348, 0.01992558455094695, 0.037810495389359336, 0.017449233680963516, 0.0582731980830431, 0.04490020924380847, 0.00297543966943132, 0.029520297023866857, 0.08604223015052931, 0.07984633012009518, 0.049326751181589704, 0.06430223278169121, 0.05467874024595533, 0.04049120404358421, 0.03881651854940823, 0.018174641898700168, 0.015052553000194686, 0.019822535437664816, 0.06670823653361627, 0.08775312905865056, 0.018985855958557556, 0.04199919383972883, 0.014952267220775996, 0.010649498552083969, 0.02471849977570985, 0.051140868836747747, 0.03297962800466588, 0.007647991263573723, 0.04664806116904531, 0.039202845854950805, 0.04031576542183757, 0.01779370385754321, 0.044379084171461206, 0.024000141536816955, 0.02889606516276087, 0.1217250975647143, 0.029087089733885865, 0.03490465220862201, 0.04490232966574175, 0.04059150169736572, 0.04258048800485475, 0.03367309079372457, 0.01671407152233379, 0.021752953995019197, 0.029307189530559948, 0.03555366077593394, 0.08613242102520806, 0.0212056120258889, 0.03286321175151637, 0.023720766617251293, 0.059540647215076854, 0.014824621213067855, 0.04808807532702174, 0.05284384245585118, 0.013430662619482194, 0.013992786473993744, 0.03300935462383287, 0.050444681729589186, 0.014872654707037976, 0.0424322111399046, 0.03929708419101579, 0.007993521651120057, 0.06463798547961883, 0.08012629366878952, 0.04689909537721958, 0.01932800724171102, 0.021328016350577985, 0.04249107405277235, 0.07014810373740536, 0.03137713185112391, 0.030255113129637072, 0.03814626844333751, 0.0507576933263668, 0.027565519059342996, 0.021331129129976034, 0.019050866398694258, 0.09586485914353814, 0.024133091992033378, 0.06685882381030492, 0.022970047346981506, 0.041030317079275846, 0.007563151485685791, 0.04332125486273851, 0.02711379454870309, 0.041144053119101694, 0.035457865202001164, 0.06961288888539587, 0.05765220961932625, 0.018991725286468863, 0.019552040845155716, 0.015158580882208688, 0.007446758133093161, 0.03278020317001002, 0.032554447783955505, 0.01095803436224482, 0.031436690262385776, 0.05929914303123951, 0.05347853732694473, 0.05599656042509845, 0.09969305193849973, 0.01857811917683908, 0.05506729653903416, 0.01943317847326398, 0.07493376372648136, 0.03979754447937012, 0.04952346866152116, 0.06828735715576581, 0.07939789989697081, 0.05423316326258438, 0.04753610405272671, 0.03941456913681967, 0.031993017731500525, 0.04787085251882672, 0.075314890061106, 0.012871851712199194, 0.04986993203471814, 0.05383038826818977, 0.031429674210292954, 0.020305827093709792, 0.03811837386872087, 0.02655957732349634, 0.07258405802505356, 0.0174703259420182, 0.05172530461901, 0.012257966661958821, 0.021519632943506752, 0.03990025771781802, 0.0242175729945302, 0.023118264840117524, 0.052431693500173945, 0.026859469445688382, 0.04363179998472333, 0.019605614577553103, 0.020161404307665567, 0.003811239173436271, 0.017387256292360168, 0.05365229318184512, 0.04608090428103294, 0.04695887091968741, 0.032830960982080014, 0.019385697985334054, 0.026607032366363064, 0.015085039560550025, 0.05242846367348518, 0.07164181037140743, 0.0322345049519624, 0.03048729763499328, 0.04619974968954921, 0.0039841103883061025, 0.028597102633544376, 0.029935838654637337, 0.015818863308855464, 0.0696176386305264, 0.054392001525099785, 0.013263750638413643, 0.08663843851536512, 0.017741521121934056, 0.06344184359269482, 0.03118129985939179, 0.012596324934358043, 0.06252526491880417, 0.02947014310796346, 0.029606250447354147, 0.047524012558694394, 0.03845765834142055, 0.044493814265089374, 0.017605568149260113, 0.043917663395404816, 0.027635235139834027, 0.0349112339983029, 0.04096235501180802, 0.05814515173967395, 0.028078374486150484, 0.022463861919407333, 0.02645488785180662, 0.04751156822645238, 0.0661393663446818, 0.024301840258496146, 0.03659853006580046, 0.03827692036117826, 0.02209684911317059, 0.059460729360580444, 0.07912551558443479, 0.04865656553634575, 0.037301387172192335, 0.06685422334287848, 0.030338769712086235, 0.030720499942877462, 0.08172107487916946, 0.05040146583425147, 0.02536317759326526, 0.03798234795353242, 0.07737762294709682, 0.061090835104031224, 0.03188858101410525, 0.014777369730706726, 0.018150039915261523, 0.03999588705067124, 0.010187464550004473, 0.01706465021041887, 0.015891673509031534, 0.019169910278703486, 0.06260776799172163, 0.03396010432126267, 0.005501407988569034, 0.01412993875731315, 0.036111810111573765, 0.03534033954409616, 0.005253747795775, 0.010444431698748043, 0.04599112052736538, 0.002555422464086275, 0.0189281245028334, 0.028826932622385875, 0.08943956677934953, 0.07677675983203308, 0.06369419755148036, 0.07129817988191332, 0.021959184535912106, 0.02790595025622419, 0.04174884155924831, 0.001969743478444538, 0.08950800382133041, 0.02665186996039535, 0.008686417863438172, 0.025319673320544616, 0.05249872597466622, 0.07409970169620854, 0.010605420069103795, 0.020811888688643063, 0.03258566039481333, 0.016103549461279596, 0.03125757737351315, 0.019098133148093308, 0.018944064986758997, 0.018338859247575914, 0.08647002612373658, 0.07484286039003304, 0.044092637220663686, 0.04674049460196069, 0.05358552533601012, 0.027641547211845006, 0.03338454377704433, 0.17846787348389626, 0.16703371703624725, 0.16417586324470385, 0.07447139639407396, 0.14469158090651035, 0.0997474365202444, 0.12875681024576935, 0.109595673424857, 0.13354851598186152, 0.17298868963760988, 0.08700004339750324, 0.10706035446907793, 0.12056358131979193, 0.08040674576269728, 0.11957087101680891, 0.11013735471559422, 0.14977656304836273, 0.14906913600862026, 0.1613054701260158, 0.1972481214574405, 0.12910531940204756, 0.10687982344201633, 0.14714899047144822, 0.07067646538572651, 0.21241331127073082, 0.1352843035544668, 0.12003683458481516, 0.08655712966408048, 0.10524745817695345, 0.13788419190262044, 0.11922850938779966, 0.13293763090457233, 0.1393296071993453, 0.08444797819746391, 0.10580883733928204, 0.10331067496112414, 0.14924518870455877, 0.11074940008776528, 0.1407330483198166, 0.2006963278566088, 0.18581518637282507, 0.13012244339500154, 0.10255586582102946, 0.16777927774403775, 0.10318351749862943, 0.0897137424243348, 0.12715628184378147, 0.046015469756509574, 0.11856996401080064, 0.10348927894873278, 0.10416607013238327, 0.14576199703982898, 0.13625182663755758, 0.101275619518544, 0.14280986759279454, 0.11197577070977006, 0.1760176835315568, 0.07304026425949164, 0.08935287714536701, 0.1446617796484913, 0.11487814996923719, 0.1307357440569571, 0.12241865534867559, 0.17651689531547682, 0.16319012828171253, 0.10696078624044146, 0.1431027233068432, 0.12831684813967772, 0.09888904900955302, 0.19619035321686948, 0.1627608056047133, 0.16100911317127092, 0.18541242155645574, 0.0984659959961261, 0.20957324866737637, 0.11429072863289289, 0.22343869108174527, 0.18354771233030728, 0.16431144811213017, 0.24928247502871922, 0.1783662832209042, 0.11835079719977719, 0.094195771563266, 0.14967835188976356, 0.15384933379079613, 0.18002142012119293, 0.1137750284480197, 0.11289454105177096, 0.16333420840757235, 0.11681270759020533, 0.15709112983729157, 0.08768841038857188, 0.05884373068277325, 0.14096239315611975, 0.1150283504809652, 0.07559764238872699, 0.11947742317404066, 0.15628854504653386, 0.11683638846235615, 0.15042373617844923, 0.07814630134297268, 0.12526487904999936, 0.18724346187497887, 0.129105699381658, 0.12461295617478234, 0.09678028430789709, 0.11039915388183934, 0.08748837826507432, 0.14382647589913436, 0.14989981214915002, 0.08889331894793681, 0.18253433385065623, 0.09433064396892275, 0.12673097609409265, 0.16036804685635225, 0.11376540682145528, 0.13126848904149874, 0.21251556649804115, 0.19952148518392018, 0.14478033328694956, 0.1133359077253512, 0.1119556725025177, 0.10162298873599086, 0.1399408858269453, 0.17972428963652679, 0.1388301918549197, 0.10916305306766715, 0.11882545958672251, 0.22081216344875948, 0.136875128905688, 0.2039425615221262, 0.12941116227635316, 0.13965689178024018, 0.12325060713504042, 0.07633475533553533, 0.19210615594472202, 0.14473245585603373, 0.07904936359929186, 0.14333262454186166, 0.11081348772027663, 0.07307264395058155, 0.08344225359282323, 0.08319636607276541, 0.13237565463142736, 0.1815726597394262, 0.0886455179591264, 0.08210217407239334, 0.26212917853678974, 0.25208721309900284, 0.16325488766389235, 0.14778613485395908, 0.0886729307738798, 0.17546657738941057, 0.09939569753727742, 0.09663239081523248, 0.15695007597761496, 0.12362761476210185, 0.09252935741096735, 0.07192148893539395, 0.16425362335784094, 0.184410442465118, 0.13508771838886396, 0.10138618001448256, 0.1140634465430464, 0.10347775742411613, 0.06232842869524445, 0.1912531695727791, 0.08157244178333453, 0.12604940123856068, 0.16800128083143914, 0.16943278616028173, 0.2797922321728298, 0.12377326908920493, 0.1545011888125113, 0.13168747084481375, 0.08125029371253081], [0.07533509683396135, 0.04783231172976749, 0.013968910523025053, 0.008271540348817195, 0.006437924565813903, 0.04216254436011825, 0.006393081458684589, 0.03213653128061976, 0.05787706933915615, 0.01599869205217276, 0.015430508879944682, 0.025805224498201693, 0.03311817128477352, 0.016313065808000307, 0.05111670959740877, 0.05979371363563197, 0.021673017480809773, 0.029776640768562044, 0.042044435162097216, 0.024830680274005448, 0.08749382690127407, 0.04131104058719107, 0.014705606170796921, 0.032618555772517405, 0.01906340742217643, 0.015854058920272758, 0.028476903547665904, 0.007854181940534284, 0.02279452221201999, 0.023394296278378794, 0.05587860729013171, 0.027431381167843938, 0.0756881996723158, 0.02936970635450312, 0.01717339053616992, 0.012469879085464137, 0.053848922452224154, 0.039939304015466144, 0.022742117256192223, 0.037162779431257925, 0.05683393031358719, 0.047319356219044754, 0.036186225047068935, 0.058104337858302255, 0.019055536415960108, 0.01853422135380762, 0.04425765015184879, 0.019649498829884187, 0.044167106438960345, 0.022214352718687484, 0.026049407199025154, 0.027426117432436774, 0.0020248224983723567, 0.01784616818518511, 0.03992515316765223, 0.04760546390233295, 0.01413846794249756, 0.020043839633996998, 0.046495736842708926, 0.002894611517798954, 0.050431792956909964, 0.015000697657732027, 0.025727174311344112, 0.028930280291076218, 0.05586837498205049, 0.04534857839878116, 0.007434392680547067, 0.04413439426571131, 0.014117102571097868, 0.07237781730613538, 0.07454193010926247, 0.0357366752411638, 0.043976909680558104, 0.05064480884798935, 0.06241515904132809, 0.08231044361101729, 0.05041994573548436, 0.05690438260457345, 0.029718700663319657, 0.017104678687506487, 0.047863300424069166, 0.07800946797111205, 0.021971705203343714, 0.01996845269708761, 0.03487432847863861, 0.026722541078925133, 0.050604972057044506, 0.07349986995437316, 0.02894982209961329, 0.020165059915078536, 0.011530521142828678, 0.036139290779829025, 0.016670619836077094, 0.03287138809849109, 0.039652555116585324, 0.028022944960477095, 0.024949030351958106, 0.07013565940516335, 0.035549871157854795, 0.03783869191205927, 0.008520202228932508, 0.035650820205254216, 0.07378217444888183, 0.02938414557969996, 0.027779067600412027, 0.05714374940310206, 0.013007279668402458, 0.022763508072655116, 0.048855233804455826, 0.05403484444000891, 0.02900590980425477, 0.041845034076167006, 0.09980607551655599, 0.00801886323772903, 0.06261880775647503, 0.014972114370071461, 0.033738582993724515, 0.006657729199754873, 0.07979002528424774, 0.0764716701315982, 0.03838032231267009, 0.026385828253946135, 0.03814775104235325, 0.02921434219128319, 0.05372656901766147, 0.04501505129571472, 0.028251977670671682, 0.021018061554059386, 0.03238257825640695, 0.025612749558474337, 0.022298582663227404, 0.024471674180988754, 0.023091978393495083, 0.01870668290315994, 0.05616433160113437, 0.05894821829029492, 0.025931554147973657, 0.02188178913534752, 0.04423643236181565, 0.10170588535921914, 0.03046974732673594, 0.006989607886810387, 0.07543149630406074, 0.030627493147871325, 0.016656957533476607, 0.030355468458895172, 0.05004485157717552, 0.011525875722457255, 0.025142056601388112, 0.04498250536354525, 0.029552985448390245, 0.036526832663054974, 0.020505772703992467, 0.07178451307117939, 0.03169383807107806, 0.050315695615219216, 0.010008483975460487, 0.01934321830049157, 0.050887188342000754, 0.03095995495095849, 0.052092052796589475, 0.005078435127091194, 0.049992502600486786, 0.041643173300794194, 0.021944243194801465, 0.0533192580166672, 0.03764826784442578, 0.0995143393852881, 0.006083801804509546, 0.06914203986525536, 0.035628689785621, 0.02928993438503572, 0.04931429327864732, 0.04726553482136556, 0.0012310292950132862, 0.0021602180121200426, 0.028806250875017474, 0.017372985004580448, 0.053250162795718224, 0.03941213319610272, 0.06041629665664264, 0.042544037103652954, 0.011370703245380094, 0.059665205888450146, 0.03184087321694408, 0.03650677516790373, 0.0488586604063, 0.020590041664295962, 0.09146782330104283, 0.051375719984727244, 0.061134872026741505, 0.09869163603122745, 0.04128012992441654, 0.02257313659148557, 0.060241343187434335, 0.01870629783453686, 0.08361221982964448, 0.014412855629676154, 0.0487101087346673, 0.10456726074750934, 0.0136522551931973, 0.027384379047102163, 0.024881551740691066, 0.06248797941952944, 0.017121180659160018, 0.020139843857448016, 0.05397749126755765, 0.024568419703947644, 0.037843869134251557, 0.03943654688607369, 0.03320209928123014, 0.017191159671970775, 0.040235878101416996, 0.007160626701079309, 0.008987216678048884, 0.018315068113484552, 0.02809830305964819, 0.038512497541627715, 0.025716153206303716, 0.010526468278840184, 0.013792499899864197, 0.09034142124333552, 0.07657720946839877, 0.00850084871386311, 0.024976470308112245, 0.07651196154100554, 0.013323013886942394, 0.031987643734152825, 0.025936639767938426, 0.0027938102638082845, 0.03922406703765903, 0.011231164215132594, 0.050875721100185595, 0.025627132804532136, 0.04652719711884856, 0.029523608274757862, 0.033067260802324326, 0.022077432833611965, 0.012577210602882718, 0.05828286720705884, 0.075455156820161, 0.018246659909241965, 0.036224219615438154, 0.040202779163207324, 0.027382394332172613, 0.05370671847569091, 0.03092925463403974, 0.0481678133697382, 0.04182629293895193, 0.01894283853471279, 0.07339147398514406, 0.04296444043783205, 0.01915304020180234, 0.016559435087921362, 0.0365779772400856, 0.07923708031220095, 0.031187834151621376, 0.07255405320652894, 0.028845266638589755, 0.01692863616959325, 0.07414106519094535, 0.01616829357642148, 0.12286856477814061, 0.044361143705568144, 0.009361288792985891, 0.0634519944765738, 0.011435215810446866, 0.021086213611332432, 0.05010765338582652, 0.03579202334263495, 0.0789787145331502, 0.059177230644438944, 0.07455091391290937, 0.016787829975198423, 0.031670421827584505, 0.06714470418436186, 0.07377365883439779, 0.022618813872603432, 0.0214258034247905, 0.034564689200903685, 0.027891678968444467, 0.02153927313962153, 0.004395068939109998, 0.09223617600010973, 0.11325650555746895, 0.05614549546901669, 0.02985865529626608, 0.014825976586767604, 0.045806324907711575, 0.041318633394049745, 0.06763161412839379, 0.05887386442295142, 0.039453859707074504, 0.033368923900915046, 0.06302829006952898, 0.10435069951095752, 0.06977222926382508, 0.04062091279774904, 0.06362638476171664, 0.03537939262709447, 0.028313291791294302, 0.031664040205734115, 0.06124856735446623, 0.013372709791708206, 0.041430092948888025, 0.06761982797511987, 0.044727382981883626, 0.04856955359822937, 0.07596494017967156, 0.09239521103778056, 0.03208678448572755, 0.028176728137103573, 0.04551341491086142, 0.046191905824733634, 0.052451075852981636, 0.11828641779720783, 0.028450846106612256, 0.023209571904901947, 0.026163451972284486, 0.020849058836964623, 0.03284725260787776, 0.019612299843824336, 0.07395374881369726, 0.02440116082185081, 0.019218055730951682, 0.03727105665685875, 0.03489885073421257, 0.07551522074001175, 0.02494547313212284, 0.05559894568952067, 0.04738279924328838, 0.006287598949191826, 0.025865281632702266, 0.04584245350477951, 0.032590820653630156, 0.06854169922215597, 0.035967658739537, 0.03319298655592969, 0.04216218473655837, 0.05989799089729786, 0.028180823095941117, 0.01866966542521758, 0.0494634556317968, 0.12315409231398787, 0.03942059792046036, 0.09897531795182399, 0.06369032311652388, 0.06636360859764473, 0.02421659929677844, 0.030658760041530644, 0.035595102302197895, 0.0347077617022608, 0.11741654947400093, 0.16862699868423597, 0.162190049088427, 0.14910030790737697, 0.15548746660351753, 0.14645182288118772, 0.11630783682422978, 0.16324166980172905, 0.11095414802964244, 0.07574966815965516, 0.13912858441472054, 0.09872626845857926, 0.1474902257323265, 0.08730184898844787, 0.18881718814373016, 0.13564833759197167, 0.08968449756503105, 0.09042072841631514, 0.19705059991351195, 0.12443298154643603, 0.2335056130375181, 0.14672669741724217, 0.17091121897101402, 0.15178698088441575, 0.10550449402736765, 0.05957215838134289, 0.1269105300307274, 0.10430601119462933, 0.16212847882083484, 0.049211457903896055, 0.14577343714024338, 0.12972582610590117, 0.1288926936686039, 0.1200246616665806, 0.10145532273288284, 0.08394979100142207, 0.16531098447740078, 0.09545755492789404, 0.14453222017203057, 0.07396963331848383, 0.1378321482666901, 0.18033377693167754, 0.08717091887124948, 0.19607616934393132, 0.13327201296176228, 0.15450208447873592, 0.09492832475474902, 0.0895115729155285, 0.14767026821417467, 0.16075893730989524, 0.08403622957744769, 0.09393929211156708, 0.07050910472337689, 0.06747858412563801, 0.1611519040805953, 0.13545712642371655, 0.11647296510636806, 0.08848786713289362, 0.20641814225486346, 0.1447016910782882, 0.15411023050546646, 0.16983670448618277, 0.17061875680727617, 0.12209792541606085, 0.13507049717009068, 0.10793681815266609, 0.13481026541973862, 0.10321793279477529, 0.14951253150190624, 0.17613242380321026, 0.10986013923372541, 0.1335513793996402, 0.1149543494518314, 0.2098450833665473, 0.19108897766896657, 0.16860771471900599, 0.1498704044414418, 0.19406526296266488, 0.09450150587196861, 0.1729108073881694, 0.07773369776883296, 0.16751440481415816, 0.0933526171637433, 0.11831867535199438, 0.1449316737375089, 0.07987550034054688, 0.2547826256070818, 0.18247654980846814, 0.09269869261022125, 0.1019386975094676, 0.12440134824386664, 0.10585013298051697, 0.11146425708596196, 0.1306627065475498, 0.19076505862176418, 0.11369416742984738, 0.13700779607253416, 0.1299845650792122, 0.11875334488494055, 0.1700835283845663, 0.161700662491577, 0.1277252198862178, 0.16981187010450022, 0.0923445855400392, 0.1391077126775469, 0.10902140888252429, 0.09120863649461951, 0.12681345881095954, 0.2117953287171466, 0.13131175243428775, 0.1409871732550008, 0.09193310833403043, 0.15433171790625366, 0.09935447653489453, 0.18236077816358634, 0.1289628270481314, 0.11137785922203745, 0.10295837957944189, 0.13907664934439318, 0.1455596714679684, 0.19109627870576723, 0.1705229069505419, 0.30050521929349217, 0.16908049077859946, 0.16518829177532876, 0.08098287627633129, 0.16198522650769778, 0.08297112637332507, 0.2147389900471483, 0.13308958203664847, 0.10159487703016826, 0.13100654738289969, 0.18904204107820988, 0.1736215999616044, 0.14131672414285795, 0.1661841640514987, 0.12647788253213677, 0.1298989611012595, 0.14166108066482203, 0.22536909606839928, 0.07346634353910174, 0.11218351099107947, 0.19911373992051395, 0.13637624281857694, 0.09359133256865398, 0.11650223710707255, 0.14592241628893785, 0.1077254612797073, 0.10753249270575387, 0.0918515348540885, 0.11490845334317003, 0.15353861903505667, 0.08573423632021461, 0.13037666332508835, 0.08429878870291369, 0.11559095100632735, 0.06809751662824835, 0.1482786698532956, 0.12693370878696442, 0.2914072589150497, 0.14640485468719686, 0.09189992797161851, 0.14527589455246925, 0.20995191191988333, 0.07243511958846025, 0.11848149661506925, 0.12376264323081289, 0.19932931049593858, 0.15177810564637184, 0.14959738909133843, 0.13357064979416983, 0.10337238093572003, 0.17838106171361037, 0.09409990813583136, 0.19234760584575789, 0.12029120379260608], [0.01724266047988619, 0.027328075907592262, 0.015280455949583223, 0.010220687320855047, 0.028524509564574276, 0.07122217038912432, 0.04901493041376982, 0.029487740913672105, 0.04684848005750349, 0.0276776961649635, 0.046883207479757924, 0.04218379607690232, 0.016667140647768974, 0.0719230156391859, 0.03334814376596894, 0.01871172950736114, 0.06531398956264768, 0.030425008120281354, 0.035414669662714005, 0.035022425531808815, 0.01721179222555033, 0.02508992305956781, 0.025079845118203332, 0.03684262625340905, 0.050201654234634976, 0.024585608692307557, 0.04153369167553527, 0.009236130464289869, 0.08942664068724428, 0.009536562021821737, 0.058864426000842025, 0.034425172223044295, 0.006403506725161735, 0.03107733472383448, 0.014410012567948018, 0.020330999046564102, 0.0288615616570626, 0.0538776143054877, 0.03233798832765647, 0.019015838724694083, 0.01451889708239053, 0.045036669421408854, 0.0399510257079133, 0.006642842565530113, 0.04551501286083034, 0.08762626336621386, 0.0440222459978291, 0.029494438054306165, 0.03248511507575001, 0.040898484510502646, 0.02076674914652748, 0.017505440129233257, 0.038334531376936605, 0.09997993654438428, 0.02390600667734231, 0.04943695544664349, 0.005731152736448816, 0.01567183494833963, 0.03282025709216084, 0.007818999051648592, 0.016489685080679398, 0.03986531655703272, 0.03810703554855926, 0.03385081607848406, 0.021705858575712358, 0.04799983184784651, 0.06390190390603882, 0.03200508547680719, 0.05068858453471746, 0.03265308302694133, 0.014981235577059644, 0.04639389552175999, 0.02947299295504178, 0.07337052760911839, 0.05097323676039066, 0.034898636995681694, 0.03111805021762848, 0.05663640537698354, 0.052987586706876755, 0.11643595780645098, 0.05073499293731792, 0.010758071788586676, 0.22328592570764677, 0.22035240169082368, 0.1545323742819684, 0.05403940758800932, 0.019632191097896014, 0.038426031824201345, 0.03689559608963983, 0.02995505815904055, 0.12939425318368844, 0.03750768556658711, 0.037153877051813264, 0.04178184889523046, 0.04346678366086312, 0.03361575458464878, 0.03552886710635253, 0.019415509421378374, 0.021273823454976082, 0.00770400687386947, 0.018946994561702013, 0.027227793520848666, 0.06857348858777966, 0.0795328469414796, 0.029911313006388288, 0.05015300327379789, 0.06696165579238109, 0.04543293387229953, 0.053709395296339474, 0.06891647446900606, 0.04711976514330932, 0.016876360135419027, 0.01816708980394261, 0.036130273049431186, 0.028472482892019407, 0.058215027275894365, 0.012036126422961908, 0.09128263073840312, 0.025810981867834926, 0.08747184915202004, 0.05381015435393367, 0.017724958082128848, 0.0526443735164191, 0.0069493079957153115, 0.03305203447650586, 0.0328336819075048, 0.028082396502473524, 0.027535610932058523, 0.0015876469447643363, 0.05896353282566581, 0.03392436248915536, 0.06613343594861881, 0.04648517883781876, 0.023447210135470544, 0.023632492604000226, 0.03217549615406564, 0.024057913704642227, 0.006921429536305368, 0.07498026373130934, 0.008705170026847293, 0.0170133037692202, 0.02796288952231407, 0.019993036020813242, 0.02310612245595881, 0.0660464952566794, 0.0341062302302037, 0.04334795182304723, 0.031921629062188525, 0.025496806583500335, 0.014981781797749656, 0.042851871478238275, 0.02027076549295868, 0.04100150987505913, 0.03677537325503571, 0.05551887516464506, 0.03920004350532379, 0.06155373847910336, 0.02499622415884265, 0.051649247628769705, 0.03194712840818933, 0.05182442840720926, 0.01948138838633895, 0.06307181809097528, 0.027560331659125428, 0.03676315962470003, 0.03675594001210161, 0.08037829478936535, 0.0718950532110674, 0.051812299593750916, 0.012890048325061798, 0.020293796667829156, 0.027514382964000106, 0.01691509091428348, 0.05847517081669398, 0.06443534099629947, 0.025754183397761414, 0.04805488817925964, 0.02137266395480505, 0.00809334941940116, 0.018951752788520286, 0.02686428195530815, 0.03262977195637567, 0.030429601802357605, 0.02383783596035625, 0.03876632052872862, 0.02228406540650342, 0.04937171769727554, 0.016092786199546287, 0.02218133520468005, 0.03581153800977128, 0.023558359260537794, 0.030030558750565563, 0.05269450707627194, 0.028064491659668938, 0.05320649567459311, 0.04172273153173072, 0.04268738101901753, 0.040634015308959145, 0.037847288950745545, 0.013636262970976532, 0.03135380042450769, 0.04192836156913212, 0.013746094041770058, 0.0228821465279907, 0.011162772974265473, 0.04040013107338122, 0.03381038556939789, 0.034783153728182824, 0.017284843305658017, 0.02921439308140959, 0.06328068474041564, 0.01970231599573578, 0.0018819584344912852, 0.055135926963495355, 0.0298482533544302, 0.017080261604860425, 0.01782249579472201, 0.03899830825892942, 0.05039906042761036, 0.02872024316872869, 0.014185808482579887, 0.047006880664931874, 0.07646969559469394, 0.07094771654478141, 0.014836417544367058, 0.0514454224945179, 0.008804039364414555, 0.013934326441293316, 0.08837626847837653, 0.07971175626984664, 0.08616803054298673, 0.04959514570821609, 0.018580129336831824, 0.06279059925249644, 0.056603068951517344, 0.06874325804944549, 0.015493427735886403, 0.023555422900244594, 0.019088223144145947, 0.011617120022752454, 0.04527035688183137, 0.03237362837951098, 0.0405740429913359, 0.03117454165060605, 0.034134077307369025, 0.0472203308184232, 0.0774545416768108, 0.02174901170656085, 0.033462928142398596, 0.04802004540605204, 0.05195183353498578, 0.04557458484279258, 0.04208167655659573, 0.0892260182382805, 0.030286101823938743, 0.07067610576216664, 0.03370778428922806, 0.036501038154321055, 0.25340050405689646, 0.21767437324992248, 0.2431790525359767, 0.09296885132789612, 0.016677330547411526, 0.02854108956775495, 0.024135110633713857, 0.02923037936644895, 0.1316885022180421, 0.050102113147399256, 0.015989603075597967, 0.004931831699130791, 0.03241150081157684, 0.04130921532799091, 0.07006552602563586, 0.0775640911555716, 0.010582086946150022, 0.015091796072998216, 0.05445974985403674, 0.013408214136558985, 0.018313521053642035, 0.03359612456655928, 0.045102338040513654, 0.016486947191879153, 0.07521224128348486, 0.009660165657156279, 0.03907261123614652, 0.034232858435383866, 0.045290085287498574, 0.02089345029422215, 0.06074105030191796, 0.030142679877047027, 0.02252470445819199, 0.03352127876132727, 0.020377811177500656, 0.09175119988088097, 0.020995162693517547, 0.03989004237311227, 0.026751433100019182, 0.02688937248396022, 0.029140497225203683, 0.03594844941315906, 0.023430601294551576, 0.05058871435799769, 0.037862281181982586, 0.04615971273077386, 0.010279897134751081, 0.07136699011815445, 0.028273444822324172, 0.03328782200281109, 0.03380286061604108, 0.10120707391096012, 0.02015801502524742, 0.03481918054499796, 0.013593467767350376, 0.023022286061729704, 0.06598573244575943, 0.014692792036969746, 0.013561174589475351, 0.019726531214213798, 0.009370134345122745, 0.06537322566977569, 0.07055027822830848, 0.07876709981688432, 0.02932308760604688, 0.05081134169761624, 0.077055834499853, 0.03789833514019847, 0.03357808571308851, 0.03798152692615986, 0.022056567881788527, 0.04502362458567534, 0.038408780071352205, 0.01925065933859774, 0.04815475496330431, 0.0432206484755235, 0.022919805221525685, 0.048732022023094554, 0.05581651794325028, 0.01300426188390702, 0.05633958701842597, 0.027452091752950634, 0.020138429111934135, 0.06326152291148901, 0.032066927158406804, 0.08660833191658769, 0.053053119618977816, 0.03640241308936051, 0.019723247104723538, 0.013015730822059726, 0.035573887904839854, 0.06015185798917498, 0.029425960300224166, 0.0356571034395269, 0.1558735937412296, 0.18099756059902056, 0.07342329727751867, 0.1055491077048438, 0.0648836422977703, 0.13768221916896956, 0.13106034163917812, 0.12524440086313657, 0.11513553187251091, 0.08004280672009502, 0.09987149986305408, 0.12818730223391736, 0.0877720805417214, 0.15469014724450453, 0.09539192023554019, 0.09218143179480519, 0.18788850440510682, 0.1456167498337371, 0.1538878202970539, 0.15825089546186583, 0.10979590910886015, 0.1101381146748151, 0.15470002671437605, 0.0726438369601965, 0.10530708104904209, 0.10696746981037514, 0.15658631335411752, 0.07715226111135312, 0.2002706556980099, 0.15132320219916956, 0.11614029295742512, 0.08173940889537334, 0.0736474377502288, 0.1564093107091529, 0.12014740865145411, 0.09361929499677249, 0.11025204070444618, 0.12075944723827498, 0.155644669596638, 0.09256434267652885, 0.11105981628809657, 0.160253822271313, 0.1633857363568885, 0.08979216750179018, 0.14331339485943317, 0.2085807147834982, 0.1994176014725651, 0.12595948177788938, 0.1233833014432873, 0.1627704408019781, 0.09155753920120852, 0.06309506470071417, 0.10597575016851936, 0.20786078912871225, 0.1866667749626296, 0.1260469313710928, 0.04208073000024472, 0.10761383548378944, 0.17052623177213327, 0.12955031623797758, 0.08683050463774375, 0.13145062141120434, 0.1506436900900943, 0.07452911936811038, 0.1289197943572487, 0.23119151006851876, 0.11808378009923867, 0.14107238368264266, 0.10091528349689075, 0.20563233084976673, 0.2595582907753331, 0.12276804660047803, 0.10457570172314133, 0.24532694156680787, 0.16780259220727853, 0.13990581913718156, 0.1380181075739009, 0.18497811843241962, 0.1808869865323816, 0.1337346788495779, 0.1120487471510257, 0.24096672981977463, 0.6702302385653768, 0.4188585542142391, 0.5309946898903165, 0.17055435026330606, 0.10991779435425997, 0.13419897322143826, 0.14811735493796213, 0.2151188610919884, 0.2896791659295559, 0.16041269446057932, 0.2392781547137669, 0.12025761630918298, 0.14526498370936938, 0.1603873036801815, 0.1493014528283051, 0.1408738171947854, 0.09187635566507067, 0.10405578105045216, 0.1380468231758901, 0.08798787503370217, 0.09166616587234394, 0.1525845309453351, 0.1418078342186553, 0.1810417060873338, 0.2171229278402669, 0.18222260129238876, 0.16868394134300096, 0.210108504231487, 0.12138098531535693, 0.10220418790621416, 0.11116796798471894, 0.14821814452963217, 0.08564327870096479, 0.11203581427357026, 0.12163402459451131, 0.2074721921235323, 0.12331148529691355, 0.16390913112887315, 0.16695089505187102, 0.10024974242384944, 0.11523210097636495, 0.16850898787379265, 0.09809058971170868, 0.11008471396884748, 0.09470745482082878, 0.1274274515786341, 0.07626010291278362, 0.21121626693223203, 0.14117637595960073, 0.147430026105472, 0.11430596852941172, 0.1192552572382348, 0.09592234463031803, 0.14212899841368198, 0.08630035844232355, 0.1370009971516473, 0.1201310423868043, 0.15713095984288625, 0.07104734584156956, 0.11360194095011268, 0.06179275922477245, 0.14002358567501816, 0.11263177836579935, 0.14225593874497072, 0.05586480928052749, 0.11835883105439798, 0.12072873674333096, 0.07645952435476439, 0.11022282298654318, 0.0987218376249075, 0.11269163872514452, 0.22256912131394657, 0.1602711927677904, 0.05692537647805043, 0.10092546830752067, 0.11172847862222365, 0.1304259928209441, 0.10060431089784418, 0.11576392315328121, 0.08792582979159695, 0.20853129029273987, 0.12858598226947443, 0.12139371463230678, 0.13111697217183454, 0.14363635038690908, 0.19494031529341424, 0.15989459226174013, 0.10299414516027484, 0.060543861240148544, 0.21128982012825354, 0.14430568447070463, 0.13765522704592772, 0.2022319340280124, 0.06921572198293038], [0.0354647251910397, 0.02992590150928923, 0.018648110064012662, 0.03388614061155489, 0.0278919385080891, 0.05432981039796557, 0.08631336595863104, 0.025517781797264303, 0.030720041931739876, 0.037320379367364306, 0.0630538369129811, 0.08611730326499258, 0.07036173370267663, 0.06922367441334895, 0.0758308277332357, 0.05267938931605645, 0.09452280508620398, 0.11704604221241814, 0.0987908107095531, 0.06847080588340759, 0.13302152497427805, 0.061607539520731995, 0.0744335680667843, 0.07648290667150702, 0.052452677195625644, 0.05071845703891345, 0.0545457677383508, 0.035760088091982264, 0.1617984122463635, 0.06009215369288411, 0.05339065347132938, 0.10116236523858138, 0.037960645010960956, 0.014604009122454693, 0.05628218295584832, 0.07907308518354382, 0.07809940778783389, 0.04944265853347523, 0.04979559513075011, 0.12843304047627108, 0.05460534989833832, 0.01958760795449572, 0.07653167976864747, 0.06853264756500721, 0.01544411011439349, 0.021596483819718872, 0.060885686826493056, 0.05338819717456188, 0.028952017160398618, 0.03980340702193124, 0.10472318809479475, 0.0712901595979929, 0.05319267391626324, 0.10507939183818442, 0.09195881124053683, 0.11549512829099383, 0.015328967810741492, 0.017289789825943962, 0.03106183359133346, 0.06992158160677978, 0.07298879059297697, 0.05151046686140554, 0.06402912243668522, 0.015507488677810346, 0.09174765114273344, 0.08467579632997513, 0.09516934717872313, 0.057445005380681584, 0.08150063242231097, 0.16069751632000717, 0.1527709923684597, 0.21425249400947774, 0.3060324841312, 0.11748304590582848, 0.19192843405263765, 0.23640708306006022, 0.5457032663481576, 1.6978695158447539, 4.873048731258937, 12.940958210400172, 20.049379655293055, 20.90086923326765, 27.73502356665475, 26.330822161265782, 25.123662982668193, 18.464674472808838, 8.365382705415998, 7.951221432004656, 4.968487015792301, 2.477233644042696, 3.321423053741455, 1.894942900964192, 2.827309076275144, 4.348349434988839, 4.087157096181597, 1.18987575173378, 0.6905047563569886, 0.2701992669275829, 0.11843116288738591, 0.11023085684116397, 0.024665312808273093, 0.04039293520950845, 0.1516080240585974, 0.06265268022460596, 0.07534620445221663, 0.09306287592543022, 0.0611855789486851, 0.01692997118724244, 0.028185007960668633, 0.07696738746017218, 0.08106573897280864, 0.069776884014053, 0.04787738002570612, 0.058247861585446765, 0.023779614263081124, 0.0830378331510084, 0.08888538008821861, 0.08568424864539079, 0.16692687491221087, 0.08649751357734203, 0.05517689351524625, 0.06616274866142444, 0.034923467984689135, 0.1231912760330098, 0.025648399788354124, 0.1258040972586189, 0.024837638650621687, 0.0031878669313820346, 0.012401780462823808, 0.03363401396200061, 0.0629469065793923, 0.09264243527182511, 0.014132550268966173, 0.07496739870735578, 0.021013601882649318, 0.06860706928585257, 0.023116575287921087, 0.037938022653439214, 0.0078121857118925876, 0.012052156812777477, 0.012431448558345437, 0.0282379370847983, 0.05273319375036018, 0.024492020053522925, 0.044062849533345015, 0.09423159142690045, 0.029751819957579886, 0.018586076696270278, 0.022892634983041456, 0.06957194608237062, 0.06446954594658953, 0.020856553256245594, 0.018747788554589664, 0.032329581278775416, 0.05508918607873576, 0.06921677371220929, 0.1464205017047269, 0.012926457665993698, 0.1200593076646328, 0.06698427136455264, 0.007956535555422306, 0.03411663217203958, 0.015900005919060538, 0.01437752940026777, 0.03594959953001567, 0.04286663640024407, 0.009905404328102512, 0.03367216459342411, 0.005896681354248098, 0.023651433909045796, 0.021757719007187655, 0.041820131840982606, 0.08089026981698615, 0.0354694410094193, 0.04614136175119451, 0.06634587169225727, 0.02829112744491015, 0.016108275457684482, 0.01820521499030292, 0.06386942243469612, 0.02409658850436764, 0.02480004950692611, 0.05395820390965257, 0.06514266625578914, 0.03255483115624104, 0.045146093371191194, 0.05964493804744311, 0.05520557179780943, 0.040937225467392375, 0.028144275503499166, 0.08036880886980466, 0.06596707951809679, 0.13754131458699703, 0.06367361758436475, 0.12951664733035223, 0.044002500628786426, 0.1283924233700548, 0.05337445005508406, 0.06063129047730139, 0.02085912151129118, 0.023089898683662926, 0.05990776180156639, 0.05245336590866957, 0.028199460756565844, 0.049462105347109694, 0.04307094329435911, 0.01392037236863481, 0.0697154833802155, 0.016278553820614303, 0.03399737285716193, 0.08303657107587371, 0.07397640509796993, 0.005236411226048533, 0.006319965917750129, 0.09058241652590887, 0.06504947625632797, 0.07730436152113335, 0.045735387464186976, 0.03539718381528344, 0.06517724440033947, 0.005847331502341798, 0.06810672434845141, 0.03374992809923632, 0.011194412214016276, 0.04230535223281809, 0.047286074076380046, 0.02877705351316503, 0.08945049797849995, 0.022057170081617575, 0.043434271655444584, 0.03943295404314995, 0.18809803601886543, 0.05285731816132154, 0.02980462016005601, 0.03097005494471107, 0.021487869022946273, 0.06765192268150193, 0.06313770384128604, 0.045417412383747954, 0.04527472325467637, 0.00919831994854446, 0.17426943805600914, 0.08453971613198519, 0.11200544304613556, 0.18689630978873797, 0.13614737295678683, 0.12820218929222651, 0.22086935038013117, 0.2937351225742272, 0.16428715655846254, 0.08752313961407968, 0.2647571989468166, 0.6870733233434814, 1.714707606605121, 5.426217836993081, 14.264087166104998, 22.64718430382865, 22.19675690787179, 29.133857488632202, 28.86432991709028, 26.531772749764578, 18.81747099331447, 9.105521321296692, 7.396877646446228, 4.835057718413217, 2.8368396162986755, 3.077768836702619, 2.6057112642696927, 2.955222589629037, 4.306919063840594, 4.742474709238325, 1.4510132649115153, 0.5592461739267621, 0.08375741275293486, 0.07796798912542206, 0.006179125796604369, 0.027828554855659604, 0.02536178659647703, 0.22093195202095167, 0.06387702881225518, 0.1252126589949642, 0.05897128848092897, 0.12485433822231633, 0.030489896424114704, 0.021547549570511495, 0.048875715383993726, 0.06595513051641838, 0.05530911284898009, 0.031196777243167162, 0.05232510582676955, 0.05388293062735881, 0.06852818958993469, 0.14050534553825855, 0.055584221479615996, 0.056442072947642634, 0.022266336982803683, 0.038162529535059414, 0.14535632809357985, 0.041352889234466214, 0.029486417770385742, 0.03260045585089496, 0.10891555741961513, 0.06469201722315379, 0.020828048000112176, 0.03230562899261713, 0.14184678212872573, 0.06877563095518521, 0.020188379467331936, 0.04810667397188289, 0.03048747744677322, 0.028182320961994783, 0.0791814811527729, 0.07863254632268633, 0.018380416124793034, 0.05114037350618413, 0.05897629606936659, 0.05682248342782259, 0.049679541893835576, 0.12232832876699311, 0.12081694629575525, 0.030720191209443977, 0.018982593901455402, 0.09697108156979084, 0.06924067171556608, 0.03695798059925437, 0.0725573848134705, 0.03523557712989194, 0.12205706403723784, 0.13537685573101044, 0.07368788522269044, 0.052173002024314234, 0.09582781791687012, 0.09962018406284706, 0.08912885202361004, 0.06518914590456656, 0.030971941272062913, 0.01775753285203661, 0.01214322299763028, 0.04229851259983011, 0.011129346642909306, 0.03344720648601651, 0.031548221063401015, 0.0529811372315245, 0.04285313016069787, 0.08179276888923985, 0.08027357647993735, 0.03698796845440354, 0.013183402762349163, 0.08184599996145282, 0.04543193981849721, 0.028511159388082366, 0.06591114787650959, 0.11504050982849938, 0.10547079797834158, 0.16411396728030272, 0.23316349568111555, 0.1799006408878735, 0.2973206101783684, 0.1934711919831378, 0.16703313349613122, 0.1856652708458049, 0.1638893721891301, 0.1657057697219508, 0.1764024400285312, 0.17402485332318715, 0.1742428666246789, 0.2905979837690081, 0.20979065128735133, 0.21725786131407532, 0.17303337795393808, 0.2814819472176688, 0.17450051994196006, 0.2887540784265314, 0.1873699679438557, 0.2259026010121618, 0.22730079027158873, 0.09427792179797377, 0.21334561838635377, 0.15362069463091238, 0.17430116635348114, 0.2617788373359612, 0.14389711139457567, 0.12765888630279473, 0.2347940153309277, 0.17899968209011213, 0.10345029032656125, 0.14938556402921677, 0.24250944703817368, 0.1816153803042003, 0.21633197313972882, 0.18706156020717962, 0.2424818713750158, 0.14467779307493142, 0.1613252019243581, 0.2606131141739232, 0.18723488519234316, 0.16328544888113225, 0.1486170824084963, 0.19601683824190072, 0.14731740286307676, 0.27235749683209826, 0.2732557143483843, 0.2607613876461983, 0.14564196419503006, 0.16699862320508274, 0.1712032604430403, 0.2764963704560484, 0.26651368183749063, 0.17699124557631357, 0.15510997043124267, 0.181135479626911, 0.15167137208793843, 0.23624556458422116, 0.23588572389313153, 0.15385801903903484, 0.11306718750191586, 0.2236411523606096, 0.26323139082108227, 0.21442733891308308, 0.2589084713586739, 0.4091183197285448, 0.31146874385220663, 0.2756997974855559, 0.34109217141355785, 0.5163187916789735, 0.3432699702680111, 0.29591216146945953, 0.31159891401018414, 1.095629083258765, 3.423672092812402, 8.68833237034934, 21.41371750831604, 32.92915984562465, 33.591833863939556, 41.30790914808001, 41.37412895475115, 37.36994464056832, 29.176385675157817, 14.349260790007454, 13.436413407325745, 8.361387491226196, 5.372404907430921, 5.726023052419935, 4.445275936807905, 4.932300363268171, 7.681990027427673, 8.019357204437256, 3.0957566371985843, 1.1037040842430932, 0.4964856473462922, 0.26515262201428413, 0.12737322305994375, 0.13539923381592545, 0.09660030967955079, 0.31672310190541403, 0.15296897531620093, 0.20030025339552335, 0.2841017980660711, 0.21205591330570833, 0.18439185060560703, 0.12052413129380771, 0.17982361359255655, 0.1652736650513751, 0.17007784226111003, 0.12686907154108795, 0.1491020992398262, 0.25364320246236666, 0.1639948436724288, 0.1971022228577307, 0.15221681924802916, 0.2723846925156457, 0.11328060033598117, 0.2163974924811295, 0.22683384961315564, 0.129413048603705, 0.26943026962024824, 0.1881507717605148, 0.299642909850393, 0.18800845582570347, 0.10120638859059129, 0.10213106897260461, 0.25321759815726963, 0.1142640079238585, 0.1500179993786982, 0.1683476593877588, 0.1240755021572113, 0.12949509705815995, 0.18498115826930317, 0.15822740457952023, 0.21539693831333093, 0.23798690257327898, 0.1443125241036926, 0.2211474683135748, 0.1709212748599904, 0.20176825033766882, 0.18275883394692624, 0.24052557349205017, 0.29325222277215546, 0.18047103099524975, 0.13404220449072973, 0.1806691089378936, 0.17463676977370465, 0.1582224512738841, 0.19110370187887124, 0.3028424195945263, 0.16563893402261393, 0.16261417418718338, 0.182238546865327, 0.236934630466359, 0.3491090898002897, 0.20326619781553745, 0.1568640513079507, 0.16751445909695967, 0.15743662629808697, 0.12613602301904134, 0.13964116333850793, 0.1412603785949094, 0.1046145207115582, 0.11781712940761022, 0.1643971335142851, 0.17651255269135746, 0.22311523343835557, 0.1661403849720955, 0.15103553049266338, 0.2021646233541625, 0.17064141987689904, 0.1779715386884553, 0.1891539722148861], [0.04692136489653161, 0.005782413088516998, 0.08833734092435666, 0.05171886192900794, 0.04694141560633268, 0.06426614828939949, 0.020003400643223097, 0.05903351014213903, 0.03838812207270946, 0.05590639669182045, 0.10881300363689661, 0.011561419083071607, 0.07598381702389036, 0.03820226454575147, 0.03634704802451389, 0.07560590015990393, 0.041920884113226614, 0.07548451024506773, 0.015467280388942786, 0.06622490246913262, 0.03938718007079192, 0.0681288174486586, 0.07164892820375306, 0.06233548545943839, 0.08673088212630578, 0.14215536628450665, 0.03614154690876603, 0.08650650416633912, 0.028631087059953382, 0.03561488499066659, 0.07441053180290119, 0.056932962499558926, 0.038794252422771285, 0.025692406176988567, 0.0637514116242528, 0.009624503552913666, 0.09551373084208795, 0.02970242260822228, 0.09382309977497373, 0.036862259664173634, 0.04876274608873895, 0.09868571242051465, 0.029850343242287636, 0.062097842139857154, 0.04792474516268287, 0.12702692592782633, 0.04981433626796518, 0.03440949467143842, 0.021976770467257926, 0.0792883164914591, 0.10308162868022919, 0.03344832946147237, 0.030157285343323435, 0.008577299254414226, 0.0728362084233335, 0.016559161977576356, 0.031115746591240168, 0.04769467429390975, 0.02669927241679813, 0.051705644066844664, 0.03165242707888995, 0.11592716510806765, 0.07155878482652561, 0.10990259516984224, 0.2497341622199331, 0.6707408768790108, 1.630409130028316, 2.256662428379059, 3.8150313326290677, 3.8155680809702193, 4.776313739163535, 6.082391381263733, 7.920162115778242, 8.690219674791608, 18.822871480669292, 28.693868024008616, 52.16878080368042, 62.1149777003697, 78.5326954977853, 92.8651407786778, 87.75108596256801, 87.72920608520508, 86.82168797084263, 88.59913444519043, 88.67866352626255, 88.43294048309326, 77.99155589512416, 80.25766222817558, 58.876047134399414, 57.20662777764456, 60.49892398289272, 62.12922150748116, 62.29654802594866, 65.1039537702288, 57.51074000767299, 35.8706762450082, 37.48435020446777, 17.56844891820635, 13.768084798540388, 8.544747846467153, 7.5617358173642835, 3.6430247681481496, 1.3524041048118045, 0.37206240956272396, 0.1400508899241686, 0.06715546574975763, 0.025940195291436145, 0.01935494677828891, 0.04896330746955105, 0.03229068765150649, 0.04408482388992395, 0.07683033695710556, 0.050546916600848944, 0.07437353807368449, 0.05664112458803824, 0.010220532954138304, 0.045435111969709396, 0.04652556524212871, 0.08347902340548378, 0.0967447901410716, 0.035234494866537194, 0.024317449956600155, 0.06111301641379084, 0.05467185311551605, 0.07294940842049462, 0.05894267465919256, 0.08698775512831551, 0.015265078649723103, 0.1003053415832775, 0.04507372082610216, 0.0318943282057132, 0.10771468614361115, 0.05344161484390497, 0.054730329263423166, 0.07654949131288699, 0.08151258142398936, 0.015410325855814984, 0.059531948396137783, 0.030594506167939732, 0.05113208520093134, 0.08112502257738795, 0.18472700619271823, 0.061820993066898415, 0.048158188350498676, 0.01739641821144947, 0.056685439710106166, 0.06164202267037971, 0.1647888653512512, 0.08811056773577418, 0.06153402703681162, 0.037554107539887936, 0.06522439579878535, 0.04256583843380213, 0.0705518727856023, 0.011694219412415155, 0.023359187180176377, 0.0318964893397476, 0.05245323359434094, 0.030754053499549627, 0.043601594998368194, 0.044621327958468876, 0.06589249494884696, 0.0438775585831276, 0.0596470550767013, 0.0875863383657166, 0.003362865777619715, 0.1255709526262113, 0.05973989223795278, 0.1031849899196199, 0.024082899060366408, 0.01741444519055741, 0.0060313943041754615, 0.03793981398588844, 0.03133574800033655, 0.08380203321576118, 0.011092204484157264, 0.07438340397285563, 0.026728206846330847, 0.07838504388928413, 0.022766110254451632, 0.012210971326567233, 0.015667129307985306, 0.021785557602665255, 0.031486396345176866, 0.062029520448829444, 0.07206206103520733, 0.030183015391230583, 0.0337761941898082, 0.043691110730703385, 0.034380158209907155, 0.0313801004418305, 0.054304826738578935, 0.05182549370718854, 0.10147865076682397, 0.05118119417290602, 0.04198643738137824, 0.03355714272973793, 0.08810597405369792, 0.0320095977346812, 0.0934369997786624, 0.069411207921803, 0.1376946499305112, 0.05453648537929569, 0.061938752819384844, 0.0627281197479793, 0.05401675808908684, 0.032921830391777415, 0.03823413533557739, 0.030713982614023343, 0.0575122685570802, 0.0679049619606563, 0.07559977298868553, 0.01718629796856216, 0.002076368259232757, 0.01382102890472327, 0.04591974542875375, 0.10098056535103492, 0.05983715344752584, 0.029144666822893277, 0.05844428390264511, 0.047097427770495415, 0.03880601143464446, 0.06241036179874625, 0.0363876074552536, 0.028641241336507455, 0.1108640521498663, 0.023715256912899867, 0.05818173156252929, 0.034134847444615195, 0.0705674858763814, 0.09755728154310159, 0.053934305906295776, 0.07327469810843468, 0.028648189535098414, 0.038659502153417895, 0.08086812921932765, 0.06299323016511542, 0.07453576901129313, 0.06857405855719532, 0.10936672892421484, 0.30499380986605373, 0.43104357751352446, 1.2815003437655312, 2.1236213615962436, 2.8754620466913496, 4.164689004421234, 4.9153541411672315, 6.805532532078879, 8.475409167153494, 9.591701541628156, 19.83667618887765, 31.05148560660226, 56.91767651694161, 70.47336878095354, 87.1260677065168, 104.34625380379813, 100.78706686837333, 101.3567635672433, 100.76911272321428, 102.39502593449184, 99.88095923832485, 101.21200479779924, 85.37687955583844, 87.18040261949811, 66.12389373779297, 64.27605506352016, 68.29113415309361, 69.71409743172782, 69.01849937438965, 74.74671936035156, 67.41504274095807, 43.48541900089809, 42.970988273620605, 22.00321309907096, 17.209324325834, 10.480321424348013, 8.204339095524379, 3.9281050137111118, 1.39373513843332, 0.33673660084605217, 0.07508362497070006, 0.07777776861829416, 0.04926749811108623, 0.02075670173923884, 0.0307785655770983, 0.038389760734779496, 0.0057841832167468965, 0.030942540349704877, 0.0672242556299482, 0.15858800522983074, 0.04655063371839268, 0.018526613279911022, 0.020542800359960114, 0.0430577932856977, 0.06671101174184255, 0.04870598324175392, 0.011648623555499529, 0.04898514272645116, 0.05741164181381464, 0.08862603043339082, 0.01836166311321514, 0.04063497882868562, 0.024577196554413865, 0.013732370671017893, 0.06133773364126682, 0.01436431662711714, 0.06048518153173583, 0.0420859106151121, 0.03086060724620308, 0.01535630937931793, 0.10971616767346859, 0.020275688264518976, 0.04897744474666459, 0.02889697439968586, 0.03699374957276242, 0.07374454968209777, 0.04546538820224149, 0.0987087283283472, 0.07226840353437833, 0.11535407443131719, 0.08362316459949527, 0.030486412146793943, 0.042456485730196745, 0.10422480412359748, 0.04932161467149854, 0.043360362228538306, 0.05928863252380064, 0.10720336929495845, 0.0691741481423378, 0.06887836794235877, 0.06553430309785263, 0.12042775217975889, 0.038877203328801055, 0.07795114788625922, 0.06858343591115304, 0.04746889515912958, 0.07765557124678578, 0.04745967047555106, 0.04734700312837958, 0.01962479845886784, 0.1272792731012617, 0.058301940826433044, 0.13697962329855987, 0.11045513302087784, 0.060871953277715614, 0.05393049932484116, 0.054869836063257287, 0.10186291871858494, 0.017726450859169875, 0.04562348686158657, 0.02565274919782366, 0.019896928320771883, 0.15921396735523427, 0.12436154537967273, 0.15123751679701464, 0.07929171595190253, 0.10386888536491565, 0.11885530155684267, 0.23242565670183726, 0.15549730536128792, 0.17622319821800503, 0.17707095987030438, 0.17991037108004093, 0.1906620298645326, 0.14917139123593057, 0.12312126478978566, 0.12825781559305532, 0.13826042599976063, 0.17066554858216218, 0.19828664644488267, 0.12132064998149872, 0.2524436339735985, 0.1179573554545641, 0.1627973515008177, 0.12652878622923577, 0.24450121873191424, 0.16160797460802964, 0.3119645358196327, 0.1323352682271174, 0.17305712667959078, 0.19481618409710272, 0.12284305186143943, 0.2093918491154909, 0.14573130011558533, 0.11281197012535163, 0.21237375267914363, 0.16144116355904511, 0.20866741798818111, 0.16914637652891024, 0.08119930859122958, 0.1360698299748557, 0.17355890332588128, 0.1693797925753253, 0.12374899110623769, 0.16958186030387878, 0.12740466637270792, 0.1371371927005904, 0.18152915207403048, 0.18903015314468316, 0.2623098859829562, 0.11516819654830865, 0.1350537102137293, 0.19504489111048834, 0.12960797814386232, 0.09705952182412148, 0.09722948806094271, 0.1317202712276152, 0.14640064777008124, 0.15398289662386688, 0.1353178774671895, 0.14770654269627162, 0.1914727027927126, 0.12732592916914395, 0.1369975773351533, 0.17861598410776683, 0.32671379723719185, 0.8673620862620217, 1.5727602520159312, 3.1184062446866716, 4.332897509847369, 5.3729972413608005, 5.846949500697, 8.06705571923937, 10.729637554713658, 12.969005482537405, 14.576768262045723, 27.65568729809352, 43.305856704711914, 72.85300173078264, 88.0957305090768, 107.97965444837297, 123.08191844395229, 119.09267970493862, 119.68005262102399, 115.65953309195382, 121.138979775565, 117.57929256984166, 116.48665360042027, 105.72738892691476, 108.71354402814592, 86.27100154331752, 85.6663623537336, 85.37767859867641, 91.17606844220842, 88.73761204310826, 91.47462558746338, 86.34126867566789, 59.68326105390276, 53.70250184195382, 32.24183014460972, 25.144323451178415, 14.757416214261736, 12.839886239596776, 6.5548953754561285, 2.356847418206079, 0.957984943475042, 0.37583772412368227, 0.2065274678170681, 0.15384081139096192, 0.1268557044012206, 0.12204406330628054, 0.13395829685032368, 0.13552510206188473, 0.19844460939722403, 0.32314790572438923, 0.20063224700944765, 0.15161768639726297, 0.07669901328959636, 0.11233267334422894, 0.10722780334097998, 0.2130714359560183, 0.25397788307496477, 0.13855501876345702, 0.14005337336233684, 0.11615982119526182, 0.157357196988804, 0.18176868850631372, 0.12206709278481347, 0.18037761029388222, 0.14648589890982422, 0.20664200452821596, 0.08456875064543315, 0.17475423775613308, 0.18171188155455248, 0.25062198457973345, 0.10042736253568105, 0.1733374566371952, 0.2083109835428851, 0.13037510269454547, 0.11956438422203064, 0.1478323702301298, 0.202021791732737, 0.25794500591499464, 0.30864649957844187, 0.15225301230592386, 0.21384914565299237, 0.24884178010480745, 0.1997668705880642, 0.18954449625951902, 0.2696062001798834, 0.31447066419890946, 0.15509072717811379, 0.12047396041452885, 0.20407871635896818, 0.17148006201854774, 0.10096930166972534, 0.14866143145731517, 0.18110470127846512, 0.14933380537799426, 0.19696194252797536, 0.1346448114407914, 0.18241191256259168, 0.22923977194087847, 0.18048648802297457, 0.1781846529671124, 0.10982290801725217, 0.2255091592669487, 0.10149097974811282, 0.18493869554783615, 0.23614894119756563, 0.25338918609278543, 0.17016411120338099, 0.11217754666826554, 0.31928009326968876, 0.06991118645029408, 0.13823415312383855, 0.12663105502724648, 0.079614182934165], [0.1049579612112471, 0.09320239629596472, 0.02003529857444976, 0.018057591215308224, 0.0343007153299238, 0.08679290701236043, 0.06065900184746299, 0.09099108459694044, 0.015166143154991525, 0.028616125362792184, 0.02255739288271538, 0.03423764889261552, 0.031381820528102775, 0.01660165692945676, 0.01622999446200473, 0.002945358303674896, 0.05081153168742146, 0.011186896590515971, 0.031012741582734243, 0.045807257893362215, 0.024070118853290166, 0.05373434842165027, 0.09885407731469188, 0.03015849313565663, 0.03661372585754309, 0.017942735592701604, 0.03765924654102751, 0.05795777429427419, 0.03517617478168436, 0.04567160177975893, 0.04965730630127447, 0.04919223500681775, 0.028197437025872723, 0.05447030446625181, 0.07884350285998412, 0.04532921640202403, 0.04022677216146674, 0.08925392638359751, 0.06716992533100502, 0.055134430793779235, 0.059877254867127964, 0.0638427763645138, 0.03496862788285528, 0.018337466554450135, 0.04660080120499645, 0.05736282800457307, 0.016274893124188696, 0.010424353847546237, 0.05670883899022426, 0.04948493805048721, 0.024881928327626417, 0.03453590235273753, 0.023273678197126304, 0.04810121176498277, 0.027819116433550204, 0.046310042164155414, 0.10291164887270757, 0.06778184178152255, 0.04539167555049062, 0.03877502952569297, 0.07346993298935038, 0.30979762066687855, 1.0272317762885774, 4.005359428269522, 12.127649852207728, 24.725288016455515, 25.119606971740723, 27.67831584385463, 35.71927499771118, 45.235489572797505, 58.45747375488281, 62.26581614358084, 68.24093341827393, 73.0550970349993, 80.60963017599923, 80.28179332188198, 84.89404923575265, 88.82752868107387, 71.52948801858085, 77.43787479400635, 76.72110557556152, 76.19953210013253, 70.91835226331438, 68.68184525626046, 81.36158507210868, 87.49269635336739, 92.32411929539272, 91.24122864859444, 107.20816816602434, 92.6361837387085, 102.29856409345354, 101.10233443123954, 87.1906373160226, 96.09443419320243, 86.52635478973389, 88.08027076721191, 85.14430250440324, 85.86269760131836, 88.77008792332241, 66.73134694780622, 63.982563155038015, 48.610177516937256, 35.836918422154014, 26.651167120252335, 12.103163531848363, 4.6986285362924844, 1.385399254305022, 0.0821502414931144, 0.027657377433830073, 0.007392990170046687, 0.07214191103620188, 0.13245102630129882, 0.10575126364294972, 0.05854335680071797, 0.05195632204413414, 0.0815384675349508, 0.013474493437180561, 0.06150078560624804, 0.09247440285980701, 0.12467580208820955, 0.04776590350749237, 0.057336276929293356, 0.057231307561908445, 0.09303358356867518, 0.10647861925618989, 0.05757214927247592, 0.05645282094233802, 0.07245118729770184, 0.0430586448471461, 0.023689827116738473, 0.04531031580907958, 0.08614158124795981, 0.05425249133259058, 0.028750790815268244, 0.03595049858891538, 0.08192711203758206, 0.06549152146492686, 0.037887848381485255, 0.045187626499682665, 0.019072762723746042, 0.053099422848650386, 0.0946726527597223, 0.03718213124998978, 0.03180149443713682, 0.0064787142743755665, 0.022226315291066254, 0.013932167003596467, 0.08712908040199961, 0.07125804453556027, 0.07395698542573623, 0.10918535651373011, 0.1331366587962423, 0.11229631743792977, 0.082264004674341, 0.02917587264840092, 0.01681868126615882, 0.059058500586875846, 0.04301059778247561, 0.06150076525019748, 0.022448649164289236, 0.11163395869412593, 0.0329305733154927, 0.04676148169008749, 0.09746149275451899, 0.041737065583999665, 0.02748988615348935, 0.029312081768044403, 0.11759812544499125, 0.06011357504342284, 0.09640859639538185, 0.08271892847759382, 0.019420713784971406, 0.12028424202331475, 0.046572960913181305, 0.06465615664741822, 0.11063666827976704, 0.10533224112753357, 0.0188669274295015, 0.028123824458037103, 0.03486181290021964, 0.05508778490392225, 0.07202922672565494, 0.03296248821009483, 0.05633757855477078, 0.003671866384268339, 0.02736944958035435, 0.021764234639704227, 0.0451811838096806, 0.0620110167988709, 0.02435566844152553, 0.04734757649047034, 0.019833895810214535, 0.042544077815754075, 0.05779286314334188, 0.03032998607626983, 0.047320906671562364, 0.025929070709805404, 0.060371452277260165, 0.11417533696762153, 0.029604784811713865, 0.08151429133223635, 0.04513602051883936, 0.021063270646014383, 0.0554303433080869, 0.06446613291544573, 0.04742637136951089, 0.04495505862204092, 0.05907188129744359, 0.01795745810626873, 0.04526658422712769, 0.043455377487199645, 0.03292124345898628, 0.04409802818138685, 0.04214899740847094, 0.051790450766150437, 0.08143740652927331, 0.03203950755830322, 0.03727656975388527, 0.030527436374021426, 0.024841082215841328, 0.06864233953612191, 0.029041746631264687, 0.06357039883732796, 0.020025721052661538, 0.04707957551415477, 0.06742308674646275, 0.015406249556690454, 0.07640246634504624, 0.05068880505859852, 0.0434633333102933, 0.038011996541172266, 0.02040316633481, 0.08994430183832135, 0.07133798274610724, 0.04870425297745636, 0.08006026542612485, 0.02500863965334637, 0.15970315039157867, 0.772710630936282, 3.849845281669072, 10.94803159577506, 22.149264233452932, 25.65288816179548, 27.943132536751882, 39.59876693998064, 49.498959813799175, 64.97901821136475, 71.4933990750994, 77.76288373129708, 86.61913408551897, 96.36702592032296, 95.34819071633476, 105.92768464769635, 107.54894951411656, 90.65445327758789, 95.61774608067104, 89.55977848597935, 90.21340247562954, 85.88345881870815, 83.9739270891462, 95.51432909284318, 101.50960309164864, 107.25098991394043, 108.91804340907505, 120.53884996686662, 111.44654151371547, 117.49833215985979, 118.56847981044224, 102.15378447941372, 109.35516847882951, 102.51893315996442, 99.3940920148577, 101.63385077885219, 99.17195810590471, 100.71533366612026, 81.43497889382499, 78.15063490186418, 60.84071976797921, 43.465408188956125, 29.709791932787212, 12.898023554256984, 5.480394678456443, 1.2884170583316257, 0.04849886042731149, 0.05525201412716082, 0.05025841368894492, 0.0354643248553787, 0.066540088770645, 0.02552488266623446, 0.03946531337818929, 0.03764357238209673, 0.1077218921855092, 0.06338224107665674, 0.06303890914257083, 0.06636947114020586, 0.02598830681693341, 0.042458901314863136, 0.034604461531021764, 0.02346524389992867, 0.0781795292028359, 0.08512399585119315, 0.043189785310200283, 0.02304682697701667, 0.01392540879481073, 0.02990649880043098, 0.05153889747868691, 0.043639966153672764, 0.050167866583381376, 0.06564880588224956, 0.04233779299205967, 0.06387863694024937, 0.034546881049339256, 0.07647506280669145, 0.02751153820593442, 0.06384871354592697, 0.0446404965727457, 0.08531116973608732, 0.009897752997598477, 0.023407919565215707, 0.03521651368854301, 0.027382625034078956, 0.033746179193258286, 0.015352775908208318, 0.062096871834780486, 0.023399792412029843, 0.08675469192011015, 0.08571542054414749, 0.10314646948661123, 0.04419738267149244, 0.06565156073442527, 0.06574549033705678, 0.039837645898972235, 0.056322867915566475, 0.03469707477571709, 0.04297527324940477, 0.04010983682902796, 0.080340222189469, 0.05273630144074559, 0.04508664691820741, 0.06704050156154803, 0.03155663489763226, 0.03292346566117235, 0.05668336000027401, 0.08609611940171037, 0.0795617186065231, 0.07025377199585948, 0.06313838237630469, 0.06079719228936093, 0.03608634129964879, 0.04445779762629952, 0.10223692722086396, 0.023133581071825962, 0.21978216086115154, 0.25832593547446386, 0.11384398117661476, 0.23227808890598162, 0.11599634853856904, 0.20159141054110868, 0.1942827877189432, 0.17235060887677328, 0.12311020466898169, 0.15397366854761327, 0.11275197405900274, 0.10109065765781061, 0.1087694349033492, 0.10546021961740085, 0.17557639149682863, 0.10660028058503355, 0.12003196270338126, 0.11980385280081204, 0.1682299335620233, 0.12591913608568056, 0.12139769084751606, 0.18968610651791096, 0.17240147186177118, 0.19664315320551395, 0.18913000635802746, 0.20664630644023418, 0.1711622904986143, 0.20314727776816913, 0.12885658203491143, 0.13592441992035934, 0.12135517384324755, 0.3438451779740197, 0.18531662598252296, 0.12753266521862575, 0.11503098319683756, 0.1631250296320234, 0.09676724286483866, 0.22341165824660233, 0.22611715378505842, 0.2418335990181991, 0.1837399820131915, 0.15475660296423094, 0.10714760728712593, 0.10760724012340818, 0.1104889376355069, 0.19522638565727643, 0.17549941848431314, 0.1529642798538719, 0.14820814292345727, 0.14291278778442315, 0.12719304487109184, 0.1038011336433036, 0.154435683041811, 0.20263775225196565, 0.16918617939310415, 0.1456259371978896, 0.243953532406262, 0.17158682271838188, 0.11470392931784902, 0.292059629623379, 0.15885257960430213, 0.5621415642755372, 1.8544883174555642, 7.338474563189915, 17.417473248073033, 32.01686831883022, 39.542198181152344, 41.34962960651943, 51.42448282241821, 63.58418818882534, 79.59931346348354, 88.1871896471296, 93.64978000095913, 102.14044393811906, 111.40438679286412, 109.77279690333775, 115.08743926456997, 118.48146057128906, 98.16606044769287, 102.53473336356026, 100.86796474456787, 104.3056137902396, 93.9390890938895, 94.30837890080043, 106.97907216208321, 113.55841868264335, 119.47366333007812, 118.28585488455636, 133.57276725769043, 121.735413142613, 129.45255497523715, 129.8465873173305, 113.38908413478306, 125.66730145045689, 115.94304043906075, 118.13652420043945, 114.42276069096157, 114.07942240578788, 116.96655872889927, 98.98021561758858, 96.92905180794853, 77.8681697845459, 58.03741346086775, 42.348301138196675, 22.580071653638566, 10.236347590173994, 3.5080351659229825, 0.4645454298172678, 0.11052676596279655, 0.25294593987720354, 0.15013339104396956, 0.21373703809721128, 0.22059333590524538, 0.10374750223542963, 0.21642607237611497, 0.3413822315633297, 0.17913111432322434, 0.1264992699559246, 0.14419008924492768, 0.20253483206033707, 0.18854181149176188, 0.29103536744202885, 0.16136965953877994, 0.22288571218294756, 0.18236821490739072, 0.1901453390185322, 0.28348346267427715, 0.18901841448886053, 0.20081794847335133, 0.11290879707251276, 0.15076296297567232, 0.14298119768500328, 0.16923112555273942, 0.1430941466242075, 0.1417483538389206, 0.16274476503687246, 0.187357062207801, 0.12052320848618235, 0.15688022758279527, 0.1556678619235754, 0.1703834951456104, 0.22127147737358296, 0.12099603882857732, 0.16565916793687002, 0.12640388150300297, 0.08461601060948201, 0.11246218532323837, 0.15047469415834971, 0.13600182719528675, 0.15001240825014456, 0.15965228740658077, 0.3405655739562852, 0.22037357198340551, 0.14621749759784766, 0.15810705960861274, 0.13193076636110032, 0.13785809544580324, 0.1857357570635421, 0.1378740817308426, 0.156174700441105, 0.34331326080220087, 0.13850229659250804, 0.12157439493707248, 0.23417302008186067, 0.16515330650976726, 0.27195498985903604, 0.21354372347039835, 0.1205181601856436, 0.192814546504191, 0.17806498653122357, 0.16418351711971418, 0.21004858958934033, 0.2085508592426777, 0.17031884432903358, 0.15732006755258354, 0.21113809969808373], [0.0598123258511935, 0.028249275404959917, 0.06926235090941191, 0.03464086493477225, 0.05629631684028676, 0.038001964400921545, 0.05357944566224303, 0.009891726758464106, 0.006370484970310437, 0.03997042163142136, 0.04334084077605179, 0.03788429285798754, 0.015265397561181868, 0.043280871851103644, 0.0015318627785226063, 0.03736726613715291, 0.050402534526905844, 0.09621815875704799, 0.023707206094903604, 0.10479715519717761, 0.06492913807077066, 0.0282622354238161, 0.09857008326798677, 0.07595963403582573, 0.07139293729726758, 0.05270512614931379, 0.0109436485716807, 0.051390254204826694, 0.05396122678316065, 0.011888029369791704, 0.036279615214360614, 0.07972932354147945, 0.061991793901792595, 0.06861401069909334, 0.06709470293883767, 0.03776676720008254, 0.03646957448550633, 0.06518673031990017, 0.06709122205419199, 0.11427928853247847, 0.04081714512514217, 0.0959771838305252, 0.05498067136587841, 0.06172205587582929, 0.0238763920164534, 0.007536405331588217, 0.10161031370184251, 0.03410694608464837, 0.04429145137380276, 0.030222051510853425, 0.12943991859044346, 0.08129126365695681, 0.14653053294335092, 0.029303542404834713, 0.08029181550123862, 0.044100548938981125, 0.03324822948447295, 0.07813501052026238, 0.22046513349882194, 0.46409439401967184, 5.1181095242500305, 13.354186688150678, 24.601391213280813, 32.94189936774117, 39.47440460750035, 54.658719880240305, 72.2812831061227, 63.12377275739397, 75.52702290671212, 64.3564179284232, 67.58002076830182, 66.07299123491559, 68.94696072169712, 72.50514016832624, 74.32440784999302, 65.35998794010708, 71.25222710200718, 61.40410055433001, 53.36100482940674, 50.522325243268696, 72.59325722285679, 57.54227440697806, 45.06376484462193, 36.837525027138845, 47.42615583964756, 52.39202642440796, 63.8823492867606, 61.64410523005894, 68.83612305777413, 53.84324107851301, 53.543679918561665, 59.94873782566616, 76.53633907863072, 71.95312663487026, 67.51388781411308, 69.48605060577393, 72.20056588309151, 77.75376074654716, 77.48556722913469, 90.03898879459926, 83.22871194566999, 86.87079089028495, 82.77098546709333, 73.73559665679932, 66.0077268055507, 51.8706579208374, 34.11631168637957, 18.77015723500933, 6.365517445972987, 0.997850232890674, 0.7090183943510056, 0.42343844845891, 0.048024126794189215, 0.04376780893653631, 0.051225872311208925, 0.04780912618818028, 0.09060616525156157, 0.07859607506543398, 0.15366338805428573, 0.08406725898385048, 0.08048936418656792, 0.07496267610362597, 0.06505052798560687, 0.07418102411819355, 0.08977620157280139, 0.0268778848860945, 0.10259935313037463, 0.03621911024674773, 0.013844261943761791, 0.0839944046788982, 0.07972971030644008, 0.07521305552550725, 0.04396286739834717, 0.031601072156003544, 0.02188901722963367, 0.04206820763647556, 0.006306087332112449, 0.03349350293033889, 0.07323069511247532, 0.022125315353540436, 0.06726715939917735, 0.027150861220434308, 0.08280229328998498, 0.07620134856551886, 0.03325501483465944, 0.035763365416122336, 0.08961626408355576, 0.03193600721923368, 0.04794850745903594, 0.11250222567468882, 0.15650510628308567, 0.027332493170563663, 0.05975702524717365, 0.09795461129397154, 0.04335805181679981, 0.10550844988652638, 0.0375106507646186, 0.06277770030179194, 0.05746230123830693, 0.12829314012612614, 0.048713932279497385, 0.043648987276745696, 0.02485279712293829, 0.028264493249090653, 0.01315293908451817, 0.027279884654230306, 0.03417943398069058, 0.017854716030082533, 0.06978250228400741, 0.0752651398735387, 0.04580036737024784, 0.012968123956982578, 0.05358060595712491, 0.023448000628767268, 0.02679842334639813, 0.01910018062751208, 0.039001643258546076, 0.08342807899628367, 0.057306665661079545, 0.07023319202874388, 0.04326562177655952, 0.03773748502135277, 0.019529985064374547, 0.027086001754339253, 0.0646688723936677, 0.05579104573865022, 0.06815057128135647, 0.02255329622754029, 0.04318669458319034, 0.0264978221551116, 0.0342819368732827, 0.06658555061689445, 0.015577150475499886, 0.004038148917191262, 0.020271673033546125, 0.08071506528982095, 0.08260958934468882, 0.046434896000261815, 0.044996920840016434, 0.023854777283434356, 0.057452469265886714, 0.015831227913232784, 0.030340289630528008, 0.09716471510806254, 0.048609895897763114, 0.08666886402560131, 0.048629278250570805, 0.08093788261924471, 0.02329184257957552, 0.07539083170039312, 0.04534520607973848, 0.09928613448781626, 0.01835435868373939, 0.03580985185024994, 0.04638293718120881, 0.0756934176066092, 0.03149881014334304, 0.06642220688185521, 0.06375257870448486, 0.016255500593355725, 0.03220108710229397, 0.016970623916547214, 0.06996131661747183, 0.006798307660834065, 0.10585110328559365, 0.015527724288403988, 0.0792992544759597, 0.057944461437208314, 0.11406094953417778, 0.027559666694807153, 0.15029640229684965, 0.04736611406717982, 0.04549824965319463, 0.039058606273361614, 0.17954814194568566, 0.3391605450638703, 3.3277661076613834, 11.907510944775172, 24.522800139018468, 34.13559293746948, 44.024474143981934, 63.58438968658447, 82.21613012041364, 75.68757493155343, 86.10744094848633, 77.86937182290214, 81.24370193481445, 85.43734277997697, 87.90193830217633, 85.01496873583112, 91.0817049571446, 79.07141712733677, 83.6688038962228, 82.02358164106096, 68.28165681021554, 65.89080946786063, 90.14073126656669, 78.55071912493024, 65.57645211900983, 58.09788710730416, 72.18357753753662, 79.53141566685268, 77.7843189239502, 76.62423379080636, 83.90466049739292, 68.93192481994629, 74.79580838339669, 77.69511795043945, 92.75697817121232, 89.18724387032645, 86.26803466251918, 84.1628416606358, 85.31222656794957, 95.23351069859096, 88.77621623447963, 98.4990598133632, 96.22622067587716, 98.97658865792411, 95.35901600973946, 87.95370932987758, 74.74267550877163, 57.870434352329795, 40.60262530190604, 21.732896906988962, 8.058651873043605, 1.2900002705199378, 0.8567357393247741, 0.1150141962404762, 0.015099740021729043, 0.10001762916467019, 0.061147221364080906, 0.021852293218086873, 0.11579201450305325, 0.14321846781032427, 0.08464662610952343, 0.06871926505118608, 0.04974568888012852, 0.02333452073591096, 0.02527287306397089, 0.0403753882939262, 0.05611291221742119, 0.007158893044106662, 0.02849836561030575, 0.03913157592926707, 0.0037494712825199322, 0.10742497883204903, 0.06315889448991843, 0.044197861038680585, 0.05612846084737352, 0.04937396364818726, 0.07609676596309457, 0.03048413566180638, 0.05872966894613845, 0.010169434178221439, 0.025051475569073643, 0.021623106141175543, 0.016455288444246565, 0.06097906003040927, 0.022344488949914063, 0.015745858029861535, 0.03794165620846408, 0.009298343643812197, 0.10019577853381634, 0.04325190858383264, 0.03035229630768299, 0.11136050229626042, 0.10244645883462258, 0.10473031949784074, 0.04600871154772384, 0.03320471842640212, 0.07777545481388058, 0.047071402559855154, 0.062055752612650394, 0.0195944696398718, 0.058884456354592524, 0.009760015477825488, 0.049524255762142796, 0.06935978175273963, 0.014408229717186518, 0.05414864494066153, 0.05097720279757466, 0.05008973666865911, 0.022978734291557754, 0.01603028124996594, 0.020422601274081638, 0.08096636073397738, 0.022038545991693224, 0.021699247948293175, 0.042132753280124495, 0.05402704807264464, 0.02307085899103965, 0.01028425248140203, 0.12921186297067574, 0.15518616991383688, 0.16925359863255704, 0.10738785618117877, 0.29197462275624275, 0.10867533566696302, 0.15555673145822116, 0.1859023781227214, 0.15690324349062784, 0.18938964099756309, 0.1644835788756609, 0.08192970404135329, 0.17378201921071323, 0.10536871917013611, 0.1266557401312249, 0.1441952868231705, 0.1391898968390056, 0.15680324099957943, 0.11497234420052596, 0.18686816415616445, 0.15619933126228197, 0.09695647271083933, 0.1716411190905741, 0.16692101236964973, 0.18933339044451714, 0.17891873286238738, 0.15648850931652955, 0.11049661186656781, 0.10904770889984709, 0.1788251900247165, 0.20513630818043435, 0.22331284997718676, 0.22198516050619738, 0.16562581115535327, 0.34836134420973913, 0.12018854144428458, 0.12993025513631956, 0.13881377130746841, 0.2408477690603052, 0.1402230885412012, 0.1504358955259834, 0.14133435248264245, 0.1474775778395789, 0.18155110946723393, 0.2463642316205161, 0.12178281375340053, 0.22631914008940968, 0.10582234697150332, 0.15859833253281458, 0.1413786065365587, 0.21079549379646778, 0.2293935822589057, 0.1772758774459362, 0.08788733649998903, 0.22894067370465823, 0.1229376532137394, 0.12784065226359026, 0.16355935989746026, 0.29738018555300577, 0.9324129670858383, 8.79103890487126, 23.33446536745344, 37.903601033346995, 52.6820581299918, 60.44242818014962, 80.34388242449079, 95.22761167798723, 89.01670728410993, 102.90799754006522, 90.9066937310355, 93.86598709651402, 92.07451220921108, 94.91592938559396, 96.11449364253453, 95.59873580932617, 86.3410393851144, 90.18319865635463, 80.16050556727818, 75.19512135641915, 71.46697507585797, 99.57990768977574, 81.87181908743722, 65.05564294542584, 55.01273059844971, 71.65415259769985, 77.26042475019182, 86.59735843113491, 86.39675004141671, 96.65463965279716, 77.9442525591169, 76.44194780077252, 82.77503626687187, 100.94278294699532, 95.35456221444267, 92.40524646214077, 95.00983428955078, 96.64128521510533, 104.29287774222237, 100.44964844839913, 110.86319855281285, 106.77585819789341, 111.70159598759243, 109.54862717219761, 102.0095329284668, 91.11591788700649, 74.16962282998222, 54.667450291769846, 32.83885758263724, 14.285347785268511, 3.416384083884103, 1.8917074288640703, 0.41084918113691465, 0.09303328501326696, 0.2403827282999243, 0.10814254997032029, 0.1740374197917325, 0.31944866850972176, 0.27104062320930616, 0.2584772216422217, 0.24028314650058746, 0.2940834824528013, 0.25244811230472153, 0.12613381099488052, 0.19715647851782186, 0.22264774995190756, 0.19137371810419218, 0.1329644601792097, 0.13323272578418255, 0.06692700979432889, 0.19961871925209249, 0.20267793509577, 0.11625107058456965, 0.17981928453913756, 0.1575201539588826, 0.12255825714341231, 0.09719341713935137, 0.12812972175223486, 0.1274902160678591, 0.14612244841243538, 0.10343742530260767, 0.17831987142562866, 0.1400200572929212, 0.11212495341897011, 0.15496833303145, 0.12157269859952585, 0.2137361288602863, 0.23395635027970585, 0.17429493740200996, 0.12548750638961792, 0.23226522388202803, 0.18653887111161435, 0.2822810986212322, 0.1306684740952083, 0.21232606523803302, 0.15408939948039396, 0.21504780490483555, 0.26364084599273546, 0.1894125754811934, 0.18552151641675405, 0.14188776564385208, 0.123518899881414, 0.1741813099277871, 0.1506511132631983, 0.14699546513812883, 0.15651803916054113, 0.21222424427313463, 0.12065884763641016, 0.18476325353341444, 0.08906638608979327, 0.23332007442201885, 0.15092871551002773, 0.12230736203491688, 0.23102062780942234, 0.10878086821841342, 0.23500794385160717, 0.13003553662981304], [0.06582411897501775, 0.03841139921652419, 0.035107381508818696, 0.0300492659610297, 0.09166679012456111, 0.0059546019516087, 0.02493102372890072, 0.050783664254205566, 0.013380068503985447, 0.057976936123200824, 0.051723550605986796, 0.03885301694806133, 0.04416002931871584, 0.037032483744301965, 0.043313560275627036, 0.04804915116567697, 0.06695967447012663, 0.03341725595029337, 0.08417142767991338, 0.0668906606733799, 0.05500057619065046, 0.0605020634829998, 0.07592007544423852, 0.11507295737309114, 0.012790518264020128, 0.041922420995043855, 0.06314951035061053, 0.03417384285213692, 0.0693206913503153, 0.03571158301617418, 0.07951014315975563, 0.11055265885910817, 0.07243937400302716, 0.05757780825453145, 0.0792869594214218, 0.07111131812312774, 0.06799832159387213, 0.07094126367675406, 0.11510387142854077, 0.07335118936108691, 0.06879077585680143, 0.0361875481903553, 0.14783827348479203, 0.07000027809824262, 0.04055926449862974, 0.10287858386124883, 0.028489588759839535, 0.003418115703555356, 0.035642640465604405, 0.12261382916143962, 0.05025673770744886, 0.05457440530881286, 0.0712113341848765, 0.018501541410971965, 0.04743129414107118, 0.05871022891785417, 0.2806810587644577, 2.195212994303022, 7.661511949130467, 17.859234503337316, 37.241913659232004, 60.89034380231585, 63.71127074105399, 62.000012806483674, 64.1137729372297, 70.29719025748116, 60.86789417266846, 58.3305093220302, 60.02259717668806, 54.584533963884624, 36.9133437701634, 34.385029792785645, 31.555275167737687, 44.66699838638306, 34.461769172123496, 28.430208206176758, 52.829366888318745, 40.23332159859793, 25.61684090750558, 31.32896191733224, 14.152687566620962, 11.730034845215933, 16.832207373210363, 23.292602470942906, 18.135540042604717, 15.160363095147268, 24.228910446166992, 28.156721898487636, 27.39529139654977, 23.573799542018346, 25.40838279042925, 28.165118796484812, 25.45511637415205, 29.539060797010148, 28.580956322806223, 32.39070919581822, 45.464137417929514, 34.15435307366507, 63.84817804609026, 63.0923182623727, 65.16484083448137, 66.01375089372907, 63.76213155473982, 78.46600668770927, 71.77529444013322, 74.24944373539516, 73.62142385755266, 75.14894362858364, 50.27273900168282, 43.28320557730538, 29.43924297605242, 9.064169117382594, 0.60492683414902, 0.23321582430175372, 0.16591402568987437, 0.01082156231028161, 0.0414643453966294, 0.05082548915275505, 0.11073389556258917, 0.07298300268926791, 0.026358171166586022, 0.09858566921736513, 0.11236732612763133, 0.022844316504363502, 0.03562646758343492, 0.04038620753479855, 0.043116171046027114, 0.02038906128810985, 0.0910037053482873, 0.029906909314117262, 0.04232110442327602, 0.027420125968222107, 0.06911020978753056, 0.054303500202617476, 0.02434162955198969, 0.02972381003201008, 0.04084691245641027, 0.06415480069283928, 0.015905664901116064, 0.06289089351360287, 0.03140964046386736, 0.02364944919411625, 0.08933020729039397, 0.09266218742621796, 0.060752585397234986, 0.0822667663118669, 0.1531624256500176, 0.02343372255563736, 0.07758633353348289, 0.04087835576917444, 0.03884487792051264, 0.052479543789689026, 0.06493818294256926, 0.11191711135740791, 0.01854639087936708, 0.16819588467478752, 0.07448380001421485, 0.029276743664273193, 0.05480490704732282, 0.0698283916073186, 0.04059368997280087, 0.04680663819557854, 0.07770575569676501, 0.07077557221055031, 0.0228522994688579, 0.05727052688598633, 0.01513167527238173, 0.029361831955611706, 0.04639161903677242, 0.017361504192064916, 0.05145574979750173, 0.04288993729278445, 0.027378949070615426, 0.053726932033896446, 0.0665757322151746, 0.11485102213919163, 0.04767218764339175, 0.13494158908724785, 0.021352389328447834, 0.06354027866785016, 0.03732165840587445, 0.024587366098005856, 0.07881623932293483, 0.014874513892989074, 0.02798227357145931, 0.042189492378383875, 0.04588364397308656, 0.09340388726975236, 0.028576956928840706, 0.011641797493211925, 0.008497037043395852, 0.06603648686515433, 0.10868099464901856, 0.07364008921597685, 0.04428670162867222, 0.08322662873459713, 0.06267402015094246, 0.029602409939148595, 0.0883218567552311, 0.08640388253011874, 0.08856110141745635, 0.026334787153505852, 0.08535228217286722, 0.07844920616064753, 0.04268359818628856, 0.07340675459376403, 0.07463832279401166, 0.06983077326523406, 0.06500219593622855, 0.05322630550446255, 0.039697433422718725, 0.12720460710780962, 0.07819058253828969, 0.047838625498116016, 0.05485373781993985, 0.060199660781238756, 0.09081579186022282, 0.10215664974280766, 0.08417881692626647, 0.08375583176634141, 0.05301012424752116, 0.13565014249512128, 0.05193099911723818, 0.022340763792661682, 0.02709032571874559, 0.05984246637672186, 0.05147890141233802, 0.09142370495413031, 0.08479903864541224, 0.03839079210800784, 0.10493754409253597, 0.03127225747864161, 0.18484482701335633, 1.6565876624413898, 7.0773473637444635, 17.570750508989605, 40.958970614842, 66.19279902321952, 71.06707845415387, 72.73625114985875, 73.4703700201852, 80.97179113115583, 74.9873354775565, 67.21913828168596, 73.93625368390764, 66.18655259268624, 57.417682783944265, 53.42599480492728, 52.33560357775007, 62.69479097638811, 55.15362964357649, 52.856179986681255, 68.85001945495605, 49.15209184374128, 45.446402141026084, 47.82640681947981, 34.056842054639546, 30.858072076525005, 31.070280483790807, 37.1110964502607, 38.240064076014924, 29.74949393953596, 53.45748404094151, 52.416101932525635, 51.060501439230784, 50.10499906539917, 39.62295709337507, 49.765999930245535, 52.63951431001936, 50.3525390625, 51.150591782161165, 55.965988704136436, 65.02850328172956, 51.87653957094465, 77.90829563140869, 79.13517379760742, 83.85320908682687, 77.46224212646484, 74.48462636130196, 86.03942503247941, 83.15286540985107, 84.95508916037423, 83.50115081242153, 85.37269674028668, 58.423997334071565, 50.00316626685006, 33.160795416150776, 10.217532736914498, 1.2084485036986214, 0.15974212544304983, 0.15562556205051287, 0.061756376177072525, 0.055949001905641386, 0.06017463640975101, 0.16816735906260355, 0.13088537459926947, 0.023921382280864885, 0.06479351249124322, 0.0557261438641165, 0.06680521954383169, 0.050310029847813506, 0.07564672761197601, 0.05731954425573349, 0.07452213724276849, 0.04786948187808905, 0.028365932538041046, 0.047398785528327735, 0.05786496427442346, 0.03729008277878165, 0.038918207199977975, 0.08425908083362238, 0.19695314871413366, 0.030764407943934202, 0.01719135475078864, 0.08172342261033398, 0.010567027709579893, 0.018296997029600397, 0.02500982878596655, 0.044372634696108956, 0.04325205446886165, 0.042811990582517216, 0.12319175100752286, 0.18088569731584617, 0.13186881611389772, 0.10110095103404351, 0.07847231706338269, 0.030038636709962572, 0.13250024723155157, 0.02710153002824102, 0.04785681362929089, 0.009370977424883416, 0.0546825739688107, 0.06317032101963248, 0.07299316035849707, 0.040143258071371486, 0.040871841832995415, 0.015274903836793132, 0.0854868967352169, 0.033154757892979045, 0.09584582623626504, 0.05101402350036161, 0.06716940964439086, 0.02999087462999991, 0.049786495976150036, 0.0221489792623158, 0.06310894074184553, 0.050490231785391054, 0.030633060527699332, 0.05352758523076773, 0.04627926381570952, 0.051330838285918744, 0.045651350902127366, 0.13300669219877037, 0.2515871056488582, 0.11570643766650132, 0.15967801745448792, 0.20740477288407938, 0.15404678748122283, 0.1484602458242859, 0.11700917061950479, 0.1439981045467513, 0.1829697090600218, 0.15961836065564836, 0.14205422385462693, 0.1677979374570506, 0.15532294900289603, 0.11505631969443389, 0.12637625155704363, 0.17226248074855122, 0.20403178887707846, 0.23034931240337236, 0.22677926825625555, 0.12650923084999832, 0.08287342411598989, 0.1701974815555981, 0.23097665874021395, 0.19826331841094152, 0.16085845125573023, 0.1537959330848285, 0.16118440590798855, 0.11403405240603856, 0.17406566041920865, 0.13119876278298243, 0.18778508209756442, 0.12251986563205719, 0.15986538811453752, 0.15270578515316757, 0.23886766816888536, 0.18232014748666966, 0.11951144491987568, 0.19463834006871494, 0.13059987420482294, 0.17108306474983692, 0.30264515589390484, 0.22386686024921282, 0.17599246917026384, 0.15298782501901897, 0.3658302282648427, 0.19017704017460346, 0.10389223375490733, 0.156705966219306, 0.24462186225822993, 0.12056990526616573, 0.19473030870514257, 0.1970782977129732, 0.13346144636826857, 0.2619342218552317, 0.1945985643459218, 0.5110843554139137, 4.013783250536237, 13.586436305727277, 29.85018375941685, 56.46482767377581, 80.0701025554112, 85.68738065447126, 84.66264642987932, 86.60516125815255, 92.717269216265, 84.64284406389508, 82.01656396048409, 81.78461224692208, 74.90360273633684, 55.37756661006382, 50.47927073069981, 47.70176655905587, 64.94901588984898, 49.8741694859096, 43.67029666900635, 68.8789587020874, 56.03504337583269, 42.03654588971819, 49.26204013824463, 30.881647314344132, 24.40520187786647, 28.872412409101212, 38.921741417476106, 27.934747798102244, 22.96213572365897, 40.77815416881016, 46.69459738050188, 52.10299178532192, 42.156020164489746, 39.889854771750315, 45.55589532852173, 42.33112519127982, 44.7591940334865, 45.33328546796526, 50.74215929848807, 62.36075632912772, 53.494097573416575, 85.62329047066825, 83.84330790383476, 85.72573471069336, 86.94100243704659, 84.29485743386405, 100.20757320949009, 92.62462193625313, 95.68092605045864, 95.1088878086635, 100.37000124795097, 77.72947679247174, 68.1938315800258, 47.905960219247, 19.25656761441912, 3.1518194803169797, 0.23787662706204823, 0.28807643907410757, 0.21076234057545662, 0.14214883877762727, 0.20776540067579063, 0.2918991968035698, 0.22609370361481393, 0.19017630735678331, 0.1521983766662223, 0.21430399481739315, 0.1394821825836386, 0.20655425637960434, 0.15073208963232382, 0.17843619946922573, 0.2997822266604219, 0.20190479872482164, 0.16324158837752684, 0.12315684716616358, 0.17505391953246935, 0.14401736137058052, 0.13708092857684406, 0.13558618378426346, 0.3564342553062098, 0.14728046341666154, 0.11740399657615594, 0.09173112881502934, 0.12989316641220025, 0.13249804877809115, 0.08940872057740178, 0.1707615748580013, 0.1489204689860344, 0.12305799818464688, 0.19981994559722288, 0.252161227698837, 0.24221957687820705, 0.18736927583813667, 0.18576152782355035, 0.156263371397342, 0.21235098104391778, 0.222245012276939, 0.1292179019323417, 0.13988648088915007, 0.2326786145567894, 0.11119788459369115, 0.20894791079419, 0.15335512959531375, 0.1272366882434913, 0.1524751918124301, 0.1850340161472559, 0.23723698567066873, 0.2028139949377094, 0.12455106021038123, 0.15002601966261864, 0.18580612114497594, 0.23403345899922506, 0.14526731786983355, 0.2406059391796589, 0.19553578405507974, 0.10340172078992639, 0.13901966597352708, 0.14892862497695855, 0.1891175213136843, 0.16476979851722717], [0.008031852094323506, 0.031320022951279364, 0.07342001316802842, 0.0700914596340486, 0.0037925353556472275, 0.050778856833598444, 0.016019585841734494, 0.02024626189709774, 0.06871949575309243, 0.03177921813247459, 0.015066659743232387, 0.02769288177868085, 0.025963967765814493, 0.026747685890378695, 0.06066879310778209, 0.043022987831916125, 0.039845523690538745, 0.039450124371796846, 0.13062838624630654, 0.05247314859713827, 0.05073564772361091, 0.07620036468974181, 0.04217077838256955, 0.04736138128542474, 0.055495150187718015, 0.005774292720681322, 0.021210419446496025, 0.04655356498967324, 0.018004936897861104, 0.024780874107299105, 0.0499777885686074, 0.042845978401601315, 0.05285822739824653, 0.02434186195023358, 0.009646847711077758, 0.053416308880384476, 0.03833888417908123, 0.03745514999276825, 0.04613566884238805, 0.07932858754481588, 0.011977295740507543, 0.07680314127355814, 0.04708539395193968, 0.06022543154124703, 0.12168800884059497, 0.03545481179441724, 0.02485621185041964, 0.01859788490193231, 0.042361748670893054, 0.0665581581581916, 0.026100086979568005, 0.028185350620853047, 0.04832035143460546, 0.05397420037271721, 0.7006281188556126, 3.864170730113983, 20.888086284909928, 32.10983869007656, 46.14324740001133, 66.42257595062256, 66.12337957109723, 63.019313539777485, 68.01181656973702, 58.422315870012554, 67.15660449436733, 55.87548841748919, 40.21634020124163, 50.31516817637852, 41.41797208786011, 23.77760236603873, 20.417140858513967, 23.76394394465855, 24.746523448399135, 25.3359443460192, 29.55811275754656, 37.08759069442749, 54.420233385903494, 63.71245193481445, 47.527172224862234, 46.46358019965035, 44.66430595942906, 43.74183184759957, 58.5627806527274, 57.647240843091694, 52.3335851260594, 58.46029472351074, 41.843170574733186, 46.79651703153338, 32.61004645483834, 34.818427153996055, 54.54788221631731, 42.22390406472342, 37.56500141961234, 35.03917489733015, 29.367311750139507, 22.748132944107056, 23.461177928107126, 29.709642546517507, 27.407999651772634, 29.719060829707555, 24.952429839542933, 42.20824629919869, 39.30629989079067, 46.125446115221294, 50.037712710244314, 59.21600859505789, 70.65576594216483, 70.10435690198625, 81.36753967830113, 80.13904258183071, 72.9810014452253, 62.8371456691197, 36.71351705278669, 10.032227754592896, 4.314390982900347, 0.7616869338921138, 0.08624511890645538, 0.03115271996440632, 0.016359883027949502, 0.00915068424572902, 0.08032768964767456, 0.03013055445626378, 0.06691126099654607, 0.02634923316405288, 0.04726090381986328, 0.039922354210700305, 0.01631110144912132, 0.026122381943943243, 0.0459627441928855, 0.042395705955901315, 0.017281898463677083, 0.03470280500394957, 0.03294926356258137, 0.012596571751471077, 0.006745346306291009, 0.03381224814802408, 0.03807695948385766, 0.042937010659703186, 0.02454844193666109, 0.04677209397777915, 0.0038995276055564837, 0.06429223117551633, 0.03903167861114655, 0.04459060389282448, 0.024525953589805534, 0.07770841555403811, 0.025253704449694072, 0.02821517562759774, 0.016220608626359274, 0.03729596907006843, 0.012550160804364299, 0.0388745197228023, 0.05533564017553415, 0.026256835354225974, 0.09390578605234623, 0.035275220538356473, 0.06088341373418059, 0.06994423110570226, 0.025133837845974734, 0.060483417340687344, 0.09093696464385305, 0.05340479074844292, 0.014067060613472546, 0.016995543115107075, 0.04691276107249515, 0.04471818883238094, 0.025590780290908048, 0.05141571962407657, 0.029451473216925348, 0.04305268391700728, 0.04576229137767639, 0.04305094686735954, 0.03409256792760321, 0.04828663842220392, 0.0436541543209127, 0.0465690966562501, 0.030394368871514286, 0.029314124158450534, 0.01741962580542479, 0.06924542146069662, 0.06695282126643828, 0.0320619602820703, 0.019207999841975312, 0.03752102217237864, 0.05904507916420698, 0.06715959124267101, 0.02912230909402881, 0.03830569024596896, 0.013681673927099576, 0.03034900880551764, 0.022498801383855085, 0.04624029554958854, 0.007040859757190836, 0.01282563414757273, 0.04150120681151748, 0.05218450319288032, 0.028888608062905923, 0.02093684091232717, 0.08170937693544797, 0.02852506935596466, 0.031582497259868045, 0.049693740239100795, 0.024718647357076406, 0.028736086961414133, 0.026013872320098535, 0.053649853848453076, 0.01460883520277483, 0.032399005589208434, 0.03230570363146918, 0.034100578033498356, 0.006789537171633648, 0.009915366918513817, 0.01214820344466716, 0.033059243911079, 0.055914372870964665, 0.06184567817087684, 0.04129843679921968, 0.06837030127644539, 0.047897678400788984, 0.05738946728940521, 0.05512617302260228, 0.021439272344910672, 0.05381639348343015, 0.04991427429818681, 0.024545707440535938, 0.04090596875175834, 0.06260508777839796, 0.02085656513060842, 0.04157731808455927, 0.032642579304852655, 0.41915588825941086, 3.6953486118997847, 20.199132442474365, 34.20924384253365, 49.89092854091099, 71.75261551993233, 73.07547610146659, 74.37543542044503, 75.23248182024274, 69.88355009896415, 76.90901265825543, 68.36488928113664, 49.00678069250924, 58.53083978380476, 47.88023451396397, 35.71132278442383, 29.00649353436061, 35.737500122615266, 35.34106717790876, 37.07019240515572, 28.767697845186504, 35.476359026772634, 50.7436010496957, 52.11665194375174, 36.310149805886404, 43.171680041721885, 30.951459339686803, 30.86750078201294, 38.293943881988525, 41.57163149969918, 31.581726959773473, 44.021806035723, 39.876663616725374, 40.28298732212612, 35.312659467969624, 38.823657172066824, 50.59841844013759, 40.93281412124634, 31.96939822605678, 34.70678697313581, 34.850225584847585, 34.5159581729344, 34.02894156319754, 37.94003391265869, 45.12967545645577, 44.510618754795615, 37.32855422156197, 53.747255189078196, 52.85557549340384, 54.819025244031636, 58.9264771597726, 69.97767039707729, 81.07185908726284, 78.66353007725307, 89.89451490129743, 89.75382777622768, 84.3600662776402, 71.59431471143449, 39.91021646772112, 12.446332454681396, 5.249398776463099, 0.795903392136097, 0.07903139599199806, 0.017152462819857255, 0.007236598874442279, 0.03231192919026528, 0.09585930872708559, 0.09760771026568753, 0.0208548433479986, 0.06479453707912139, 0.08553923892655543, 0.03248947127056973, 0.042598537036350796, 0.029420569339501004, 0.06240940506436995, 0.04199260526469775, 0.0715034706518054, 0.03299649977790458, 0.025732860434800386, 0.022897518738838177, 0.06120765847819192, 0.02195073677492993, 0.003831847130121397, 0.05956208213631596, 0.01829828285346074, 0.043382774240204265, 0.026677737411643778, 0.09628538122134549, 0.02178855672744768, 0.052339334706110616, 0.03335857963455575, 0.011043600172602704, 0.06501860969832965, 0.039342349262109826, 0.015358662199495094, 0.06271232345274516, 0.03940009937754699, 0.017014876274125915, 0.07517762242683343, 0.04675984302801745, 0.0576596667191812, 0.07742661317544323, 0.0162759448534676, 0.02715410801049854, 0.0262325997796974, 0.050804841332137585, 0.019705483057935323, 0.014144367804484708, 0.06674284860491753, 0.03517854626157454, 0.052089732206825695, 0.06344501235123191, 0.0486958493212504, 0.04130502537425075, 0.06264994572848082, 0.029782303143292665, 0.04255893773266247, 0.02330371524606432, 0.04213497887498566, 0.030430782453290055, 0.024394019240779535, 0.0036935447299453828, 0.12681679720325129, 0.17115760860698565, 0.11714118639273302, 0.19333781913987227, 0.18135674989649228, 0.0894917936197349, 0.09188280853309802, 0.10955387566770826, 0.11585491469928197, 0.09933450724929571, 0.08200850909841911, 0.20126043472971233, 0.1616315876266786, 0.17385074123740196, 0.1997717288987977, 0.11212219178144421, 0.1404682703848396, 0.25717082460011753, 0.2648583549473967, 0.171237743592688, 0.16450974318597997, 0.1631593092211655, 0.18781085285757268, 0.23069159260817937, 0.15710048004984856, 0.1291962566652468, 0.1655581747846944, 0.10598497824477297, 0.09926853328943253, 0.1770946000303541, 0.16007132349269731, 0.12889168943677629, 0.1073758393259985, 0.1789709257760218, 0.07578886034233229, 0.14906365344566957, 0.1953537059681756, 0.09093037606882197, 0.12478861532041005, 0.15960823691317014, 0.09491881847913776, 0.14044627227953502, 0.1747061431940113, 0.23127320568476403, 0.17573064964796814, 0.10369810488607202, 0.14474570085959776, 0.1404827367514372, 0.20472599805465766, 0.16615118724959238, 0.24283403104969434, 0.1385320978505271, 0.09618784181241478, 0.13869968242943287, 1.3866722945656096, 9.054207137652806, 33.43497480664934, 49.81455741609846, 65.52013002123151, 88.602691922869, 86.8147953578404, 83.90394483293805, 88.68716812133789, 82.07514422280448, 91.92926706586564, 79.50139250074113, 62.25219072614397, 72.76562813350132, 62.63804503849575, 40.877252851213726, 31.19977753502982, 36.591246128082275, 37.77420473098755, 41.51378427233015, 44.55123792375837, 52.99831581115723, 73.9646440233503, 86.162262235369, 64.81825774056571, 67.00264630998883, 62.56895909990583, 66.26362201145717, 84.25516237531389, 82.44505936758858, 72.58298083714077, 81.523512840271, 56.726941517421174, 65.00093977791923, 51.14888947350638, 48.31356239318848, 72.1719879422869, 57.074900354657856, 52.63649879183088, 48.60872881753104, 41.5105915750776, 32.954763957432334, 35.855091435568674, 42.90469551086426, 41.052177224840435, 42.32356207711356, 36.05899674551827, 59.34030491965157, 57.07645327704293, 64.80984347207206, 70.15587779453823, 80.37426689692906, 90.1932179587228, 90.78269617898124, 103.35865075247628, 101.25420120784214, 96.05959592546735, 86.2827787399292, 59.07546738215855, 24.95320803778512, 11.434593098504202, 2.7247923144272397, 0.22889502186860355, 0.08533073868602514, 0.10779495005096708, 0.10581469988184315, 0.1983345238757985, 0.22258987091481686, 0.18710877267377718, 0.10066374378012759, 0.1831518957125289, 0.08966776489147119, 0.11174172362578766, 0.14560969306954316, 0.13760141921894892, 0.08352643943258695, 0.18009907166872705, 0.06650576168405158, 0.10092724606926952, 0.07084909147982087, 0.1354328484407493, 0.13250192999839783, 0.12283770500549249, 0.14644693742905343, 0.09162986424884625, 0.1994474163012845, 0.1367352692676442, 0.1383375482899802, 0.12155011695410524, 0.14748547598719597, 0.14362751586096628, 0.18849417833345278, 0.17106017097830772, 0.18549555566694054, 0.15717316472104617, 0.09347440062889031, 0.13033876035894665, 0.10425403541220085, 0.21631058571594103, 0.08186767915529863, 0.23069026267954282, 0.1908485862825598, 0.1861528932516064, 0.208171368177448, 0.09632469554032598, 0.11044077521988324, 0.14777103066444397, 0.11900390072592668, 0.1440567435430629, 0.12136856812451567, 0.10061465855687857, 0.08742011764219829, 0.09706691785582475, 0.10462940776986734, 0.11434366793504783, 0.13677511284393923, 0.14379002499793256, 0.12431099452078342, 0.10421645135751792, 0.12915669807365962, 0.17814266522015842, 0.16081441433301993], [0.0776372372305819, 0.03878112277016044, 0.015950857029695596, 0.032048742419907024, 0.0466097103697913, 0.02462933348890926, 0.05878891183861664, 0.013053203766633357, 0.09446532638477427, 0.030017595339034284, 0.030211225484630892, 0.06009234368268933, 0.04482699192262121, 0.011297859966621866, 0.029409309050866535, 0.02042878612077662, 0.056961637389447005, 0.02701371911514018, 0.06946008958454643, 0.011042173552725996, 0.04655149206519127, 0.0760015674999782, 0.03570392235581364, 0.04813655326142907, 0.026017887551071386, 0.04195456998422742, 0.06413731484540872, 0.03965849908334868, 0.03190593793988228, 0.014843486182923828, 0.014485620028738464, 0.041031043111745796, 0.11060203585241522, 0.040750499415610514, 0.05093066547332065, 0.01886532099784485, 0.08037771124924932, 0.013326096132264605, 0.02913738614214318, 0.028410273105172173, 0.027663219620340636, 0.010819098379995142, 0.028316708215113198, 0.007049664173142186, 0.04022961522319487, 0.059750714871500216, 0.02427089906164578, 0.041052613739988635, 0.07855486084840127, 0.019002042411427413, 0.01846627116070262, 0.026197170073698674, 0.628900290599891, 4.763280655656542, 30.243646349225724, 50.37351219994681, 58.2910088130406, 69.0544285093035, 65.75154672350202, 70.90160710471017, 59.98704324449812, 47.19047294344221, 48.15133237838745, 33.576742376599995, 38.27810198920113, 40.336245264325825, 44.514770303453716, 30.508101735796245, 37.09831523895264, 32.164406367710654, 54.321370942252024, 67.43008559090751, 71.1106367111206, 63.134056091308594, 70.95428834642682, 90.22112192426408, 63.52715737479073, 57.63514402934483, 89.1470832824707, 78.90903772626604, 80.60163974761963, 102.72226524353027, 92.34559617723737, 83.1270181110927, 104.55537373679024, 95.01757458278111, 111.38447325570243, 83.96513761792863, 78.5441391808646, 117.10459164210728, 81.6460234778268, 89.28000232151577, 86.99236352103097, 78.95799473353794, 87.19623061588833, 88.3753329685756, 82.72808728899274, 60.098318644932334, 35.45003925051008, 43.324523040226524, 42.304617813655305, 30.110258306775773, 25.77541616984776, 38.917395319257466, 47.682256017412456, 33.7784937449864, 49.020541599818635, 59.16279929024832, 66.61886256081718, 65.36151654379708, 72.51527064187187, 78.02672072819301, 72.67371041434151, 64.07071495056152, 52.731147153036936, 31.473123141697474, 9.860245074544634, 0.6938889633331979, 0.22527919017842837, 0.11494048019605023, 0.0351291658755924, 0.022931959480047226, 0.07863505690225533, 0.009747524496300944, 0.06538322727595057, 0.02688539626875094, 0.04073580573978169, 0.049452242840613635, 0.01437869987317494, 0.030716873173202788, 0.09301500527986459, 0.029971197114459107, 0.029268838731305938, 0.03277840165953551, 0.06965713615396193, 0.08062171244195529, 0.027667750537927662, 0.03313609817996621, 0.006986465845589659, 0.026383249820875268, 0.01824818830937147, 0.05763730899031673, 0.16802452744117805, 0.0029496899016001926, 0.06709617535982813, 0.0384828862734139, 0.027168106187933257, 0.040774658654949496, 0.04605882475152612, 0.043553334195166826, 0.01733411173336208, 0.038433621238384924, 0.027085192601329515, 0.027313996305955306, 0.057152441436690946, 0.08014224602707795, 0.07737451525671141, 0.0527300724892744, 0.031979959325066636, 0.02739636367186904, 0.03171248082071543, 0.0067454981285014325, 0.017187232650550346, 0.019068771241498843, 0.04477034103391426, 0.08719114600015537, 0.030259798413940837, 0.05912879681480782, 0.03666730298261557, 0.06578046203191791, 0.03860590127961976, 0.06280901469290257, 0.004391353959882898, 0.12339368302907262, 0.023759005458227227, 0.08001904442374196, 0.05526501825079322, 0.025150068403620805, 0.06815012344824416, 0.012728003984583276, 0.04162879853642412, 0.015762840065040758, 0.017859177397830144, 0.08364035189151764, 0.024079482636547515, 0.041478621773421764, 0.03735942905768752, 0.10308000698153462, 0.11536408960819244, 0.08308824151754379, 0.029898637972239937, 0.015996863400297504, 0.035792393144220114, 0.026785129149045264, 0.013265890568228704, 0.0662117592458214, 0.012983346890125955, 0.023068718213055815, 0.03230616503528186, 0.04953421665621655, 0.03571182728878089, 0.041082055374447785, 0.056669226115835566, 0.028035798110067844, 0.0723645044490695, 0.03263890164505158, 0.02004503894464246, 0.11050292224224124, 0.06762642333550112, 0.04912698368674942, 0.04399181370224271, 0.016553955917645777, 0.10676740376012665, 0.020035994072843875, 0.07964722080422298, 0.05012389751417296, 0.03780290597517576, 0.044092973095497916, 0.018638881987759044, 0.03360673346157585, 0.03890610892059548, 0.06204275866704328, 0.054865245773856125, 0.01927058960843299, 0.03226875739970377, 0.06314594125641243, 0.06319879913436514, 0.016577623219096234, 0.46053295369659153, 4.679348587989807, 32.216055801936555, 54.097833497183665, 67.38627025059291, 79.0308118547712, 75.82038279942104, 81.50576714106968, 69.93118000030518, 58.16492680140904, 56.033407075064524, 45.9419025012425, 48.079536642347065, 43.927591936928884, 46.9670536177499, 37.59817559378487, 40.55394622257778, 25.377828087125504, 36.409991945539204, 43.59884139469692, 50.79114062445504, 47.623429094042095, 49.82779720851353, 64.3876153400966, 56.22192212513515, 54.26618834904262, 63.58150618416922, 62.291732924325125, 65.93405505589077, 66.51104736328125, 66.99554525102887, 57.90768017087664, 66.43437399183, 65.01849092755998, 64.32868766784668, 63.14905725206648, 62.288536752973286, 69.01699161529541, 59.51426696777344, 60.55019474029541, 61.173503739493235, 59.49917548043387, 60.99067578996931, 58.317127091544016, 61.98303140912737, 53.32898753029959, 32.17600985935756, 43.46230929238455, 38.019014086042134, 46.16842072350638, 33.31600080217634, 45.92225299562727, 52.51594407217843, 45.06061383656093, 61.009915351867676, 66.73167351314, 75.99366392408098, 76.56931522914341, 81.60692596435547, 87.07075309753418, 84.79759434291294, 72.71304416656494, 63.81393732343401, 36.50947972706386, 12.189783249582563, 0.6051113956740924, 0.14892574798847946, 0.13393842934497766, 0.021171245923531905, 0.06381859337644917, 0.050797207813177786, 0.03954537372503962, 0.1039110291749239, 0.06518818917019026, 0.0522783920834107, 0.062251543892281394, 0.05404444231784769, 0.007397642375768295, 0.11685039342514106, 0.01985519502444991, 0.03338305778535349, 0.019428532204723785, 0.06807739127959524, 0.02264688316998737, 0.03709725669718214, 0.029906953418893472, 0.008123860594683459, 0.022223212689693485, 0.028642147180757353, 0.05576546836112227, 0.013247911086572068, 0.09010817483067513, 0.019199228080521737, 0.06369539177311317, 0.03469419439456292, 0.049441169149109294, 0.028913337271660566, 0.0911893118172884, 0.029599234395261322, 0.031219806721700088, 0.040251535296972306, 0.07739587553909846, 0.06386955814169985, 0.017682101810351014, 0.04301487933844328, 0.05579536122136882, 0.0130808566131496, 0.016838818489174758, 0.035420450781072886, 0.0527341403067112, 0.03736796842089721, 0.019986800283991864, 0.015672655975712196, 0.03260281715275986, 0.03848269289093358, 0.01681085436471871, 0.0301205053526376, 0.05003426982355969, 0.06319687209491219, 0.035382530851555724, 0.04806726126532469, 0.03618146512391312, 0.039544145576655865, 0.08336407278797456, 0.172357584216765, 0.11471174604126386, 0.10526216881615774, 0.09186575694807939, 0.12715272632028374, 0.1335731739444392, 0.1285022103360721, 0.13450492466134684, 0.18429669285459177, 0.06208269723824092, 0.14720287972262927, 0.32977447871650967, 0.15984580559389933, 0.23863544634410314, 0.16537446821374552, 0.12734399177134037, 0.11355753761849233, 0.12685668149164744, 0.14149008984012262, 0.1346226776284831, 0.14213682870779717, 0.21320053402866634, 0.08538200879203421, 0.11036590566592556, 0.13822442293167114, 0.1498911811837128, 0.13006438793880598, 0.21170063236994402, 0.11869097394602639, 0.07591320188449961, 0.14106322345989092, 0.18511834447937353, 0.19805705733597279, 0.14213357173970767, 0.10293445443468434, 0.1483346489923341, 0.24504355820161955, 0.09685773229492561, 0.1946157719939947, 0.18706571284149373, 0.17381061267639908, 0.10848890138523919, 0.15319240332714149, 0.10415066060210977, 0.1718323031174285, 0.20655041587139877, 0.1617395289774452, 0.07850889688623802, 0.18940783930676325, 0.09081832958119256, 0.17174977968846047, 0.08177367491381508, 1.5584037538085664, 11.621956484658376, 47.06245585850307, 71.30606869288853, 80.78792095184326, 91.60913576398576, 88.24697194780622, 88.10190050942558, 77.190963608878, 64.1120775767735, 67.52533149719238, 53.734460081372944, 58.286812101091655, 59.15640694754464, 64.73280879429409, 48.319391931806294, 57.77152674538748, 51.92073706218174, 78.08894184657505, 90.56625979287284, 93.81798199244908, 86.65469496590751, 97.43592984335763, 118.49513462611607, 86.5355681010655, 78.32551411220005, 117.80085672651018, 108.54668303898403, 110.25564111982072, 141.31007276262557, 124.27477128165108, 113.03003597259521, 140.30423763820102, 122.51131847926548, 147.19170897347587, 116.08756296975272, 106.55608667646135, 148.04794938223702, 104.46400492531913, 115.59385177067348, 117.26766586303711, 103.04345267159599, 110.29453018733433, 112.93933418818882, 110.20696204049247, 83.78761114392961, 54.430652209690635, 61.99496146610805, 61.58488573346819, 43.75285169056484, 38.15551839556013, 53.46004792622158, 62.99373027256557, 49.91174534388951, 66.72787979670933, 78.91235201699394, 88.02959060668945, 84.35518864222935, 93.70164135524205, 97.20862647465297, 94.45037923540387, 88.11758259364537, 80.73321778433663, 53.366462639399934, 22.3404369694846, 3.280702267374311, 0.30692082217761446, 0.24104489705392293, 0.12350724264979362, 0.1850188441042389, 0.163493311298745, 0.13836574820535524, 0.17124869514788899, 0.2085306253284216, 0.2230077806328024, 0.1252795354064022, 0.10799124344651188, 0.15704140679112502, 0.23047220866594995, 0.12817888839968614, 0.12402519557092871, 0.18256942768182072, 0.3103128730186394, 0.09903196205518075, 0.1038713145202824, 0.18964246314551148, 0.11412269622087479, 0.1157653887889215, 0.07217565458267927, 0.09239145195377724, 0.20632370375096798, 0.13385093903967313, 0.16325828033898557, 0.11453436341668878, 0.1191680519176381, 0.10159489060086863, 0.13932051483009542, 0.13810063100286893, 0.20804689771362714, 0.15212896253381455, 0.15536577813327312, 0.14519233975027288, 0.16632539433028015, 0.2534068280032703, 0.18443467973598413, 0.13603701602135385, 0.08322183149201529, 0.12112417338149888, 0.1264492483543498, 0.08502148278057575, 0.16054396384528705, 0.09393123111554555, 0.1173338767673288, 0.11896160085286413, 0.18839843704232148, 0.14240308584911482, 0.07243583205022983, 0.17187059963388102, 0.17253917375845568, 0.18731929494866303, 0.108039677276143, 0.21070952340960503, 0.22613039878862246, 0.2368892500443118], [0.10531512847436325, 0.05937304228012051, 0.15584840652133736, 0.0305319180978196, 0.06816216744482517, 0.044098506548574994, 0.05121833039447665, 0.057955046583499224, 0.04752060292022569, 0.04340603442064353, 0.009316306162093366, 0.05499731582988586, 0.03929439040699175, 0.09053849495415177, 0.08450973166951112, 0.2673336778368269, 0.08014513658625738, 0.0823907618011747, 0.15909569870148385, 0.22227660486740725, 0.06690497097692319, 0.21726305889231817, 0.12314144442124025, 0.03564597885789616, 0.10301144780325037, 0.1220181839806693, 0.11890423750238759, 0.15431008620985917, 0.14289457590452262, 0.1247895924108369, 0.10698617023548909, 0.07362075775329556, 0.029650792878653322, 0.07262460049241781, 0.19356928100543364, 0.11446781270205975, 0.11693614668079785, 0.16073057454611572, 0.1809206690107073, 0.06706533594323055, 0.228462957910129, 0.11193878376590354, 0.1857587051178728, 0.21270381925361498, 0.1211615606610264, 0.1369391826114484, 0.16539038664528302, 0.08835069449352366, 0.17794394945459707, 0.21395282580384187, 1.053959650652749, 9.687102913856506, 28.25090820448739, 49.77789872033255, 72.14235387529645, 65.97358335767473, 70.28268241882324, 52.45985473905291, 38.88725055967058, 34.54395246505737, 33.47275563648769, 32.66939101900373, 29.64052186693464, 30.574429239545548, 29.81022466932024, 36.62508385522025, 31.522660323551722, 32.32917594909668, 35.579536301749094, 50.619290828704834, 56.5660525049482, 61.15619577680315, 59.321169580732075, 37.49952507019043, 19.382944924490793, 13.009287663868495, 13.251253468649727, 11.042401160512652, 12.055641327585493, 14.136892574174063, 12.119400603430611, 12.913371256419591, 16.234405211039952, 16.652078798839025, 10.227954166276113, 17.236851351601736, 15.032893180847168, 9.950472644397191, 12.959463000297546, 19.453851291111537, 20.9964417048863, 20.7556049823761, 16.285196542739868, 23.1749746799469, 40.42445611953735, 54.71902329581124, 46.719392027173726, 60.18054362705776, 87.59365367889404, 90.92243834904262, 79.79181330544608, 57.07151310784476, 41.66793005807059, 23.521766219820293, 21.54102761404855, 21.3843092577798, 23.15766498020717, 22.22532442637852, 33.560792786734446, 36.02277231216431, 48.53929199491228, 60.4553587777274, 62.33598600115095, 64.20136192866734, 69.04340171813965, 62.49497468130929, 61.78554276057652, 27.967546769550868, 8.190692833491735, 1.0911815847669328, 0.229571738413402, 0.055516517255455256, 0.11386722778635365, 0.2588496559432575, 0.18578389233776502, 0.2224967216274568, 0.2158971814704793, 0.16044466703065804, 0.09422963046069656, 0.19037963716047152, 0.0867830818252904, 0.09341067261993885, 0.18291241356304713, 0.1468978782317468, 0.04776460411293166, 0.14447398829673017, 0.0038065852713771164, 0.0976378507912159, 0.06143023832035916, 0.09510889649391174, 0.26675686878817423, 0.15493809751101903, 0.12235658296516963, 0.08960781632257359, 0.147172087803483, 0.15747435284512384, 0.07678876311651298, 0.1392735873482057, 0.13976686873606273, 0.23633583688310214, 0.06632350039269243, 0.2168842192207064, 0.1286737575594868, 0.1297013717038291, 0.07280456833541393, 0.07751173539353268, 0.13105557832334722, 0.15412378763513906, 0.1195908606584583, 0.11508161547992911, 0.09847843354301793, 0.09381956460752658, 0.10422504161085401, 0.060621892767293115, 0.12209727402244296, 0.06969725114426442, 0.06439700376774583, 0.1768953957195793, 0.1107435646866049, 0.049327931832522154, 0.10056406020053796, 0.05704156881464379, 0.05600863156308021, 0.10542028783155338, 0.05902327104870762, 0.12064275278576783, 0.12256937154701777, 0.10446786215262753, 0.15578311788184301, 0.0681961416932089, 0.0371473325815584, 0.06866883632860013, 0.09522916004061699, 0.03945454842011843, 0.04540508340245911, 0.045401246286928654, 0.01376399803640587, 0.0954309224284121, 0.06275623823915209, 0.06912080850452185, 0.08017455786466599, 0.11691637417035443, 0.060753216434802325, 0.09344094885247094, 0.12198623855199132, 0.23176921478339604, 0.20508606944765362, 0.14983015374413558, 0.1182965279689857, 0.05232302272426231, 0.1393030629094158, 0.10628126734601599, 0.06647739213492189, 0.10183609622929778, 0.08844708039292268, 0.0473171238388334, 0.13424358011356421, 0.04417665681934782, 0.044125427425439866, 0.049803364356713634, 0.1226852788989033, 0.10659253171512059, 0.1537829459245716, 0.10061505889253956, 0.15242470880704267, 0.06923119258135557, 0.1277030182204076, 0.17239763135356562, 0.15272794610687665, 0.2883729860186577, 0.12886028683611325, 0.11649675454412188, 0.17297328689268657, 0.17817075656993048, 0.31708158552646637, 0.0447902492513614, 0.8198449845824922, 10.71417954989842, 29.942028522491455, 57.84381580352783, 83.56036336081368, 76.2770253590175, 77.57689435141427, 62.49939373561314, 49.088953563145225, 45.99369784763881, 47.55929027284895, 38.92421497617449, 36.36111831665039, 32.257209982190815, 42.16124520983015, 44.8337516784668, 41.35417372839791, 35.79998527254377, 35.82377243041992, 48.96329539162772, 51.634283678872244, 51.11393656049456, 47.01855019160679, 34.90496349334717, 21.6158892427172, 14.635402372905187, 14.294205001422338, 14.666980198451451, 16.68635426248823, 18.347566059657506, 16.527624402727398, 17.25358956200736, 19.72804978915623, 19.00603641782488, 12.967295357159205, 14.411920513425555, 14.390052795410156, 12.21253686291831, 14.1224342414311, 16.821290016174316, 18.41867392403739, 17.318916525159562, 17.013649157115392, 19.694278069904872, 30.21089948926653, 40.16187674658639, 44.05807563236782, 47.75303384235927, 67.91009494236538, 68.37110791887555, 72.20344243730817, 46.929140772138325, 35.34461423328945, 37.33309139524187, 34.04374817439488, 36.010508741651265, 35.34352684020996, 34.45394550051008, 47.813215664454866, 46.64651584625244, 61.56900215148926, 70.84461103166852, 71.88659068516323, 74.14817374093192, 78.45563997541154, 76.44390024457658, 72.48863124847412, 36.919041293007986, 11.251929300171987, 1.844784940992083, 0.2241817954927683, 0.03409163494195257, 0.07631593277411801, 0.05366371292620897, 0.11633336331163134, 0.08971049902694565, 0.040878538973629475, 0.1079515287918704, 0.0732556584158114, 0.09509220453245298, 0.1761957039790494, 0.07770348260445253, 0.11849797144532204, 0.09632105180727583, 0.0847422791911023, 0.11251165052609784, 0.04923545768750565, 0.035999353110258064, 0.08254104373710495, 0.023524551253233637, 0.11505382268556527, 0.1703062235776867, 0.12020844966173172, 0.08970766275056771, 0.13344653216855867, 0.11866840587130614, 0.06834821496158838, 0.15068495858992847, 0.10587067902088165, 0.12253385702414171, 0.05181434198415705, 0.15080991759896278, 0.11199675779789686, 0.10995319352618285, 0.1607181302138737, 0.11877212673425674, 0.12227503662662846, 0.1201759749757392, 0.1192967700106757, 0.04296364655186023, 0.06288165865199906, 0.0543085586811815, 0.03598845583785858, 0.0756382459242429, 0.0800857376307249, 0.04806387537558164, 0.085054493509233, 0.07766500288354498, 0.09417439771017858, 0.08515151723154954, 0.11781588090317589, 0.013107774945508157, 0.06657347269356251, 0.0788986406155995, 0.16010482955191815, 0.06908508363579001, 0.26328263378569056, 0.3394279421440193, 0.39178112574986046, 0.13379167579114437, 0.26130494847893715, 0.2448412190590586, 0.2180115237299885, 0.23698500490614346, 0.18177544671509946, 0.2922990439193589, 0.20486963034740516, 0.3457129406077521, 0.19141561085624353, 0.2357763440481254, 0.2727180974824088, 0.4547351433762482, 0.32179506974560873, 0.21763698597039494, 0.4020904339849949, 0.4538757652044296, 0.6469246777040618, 0.4153970485287053, 0.3428317723529679, 0.1347696618842227, 0.24550276356084005, 0.2483036746936185, 0.4424534152661051, 0.4426687279982226, 0.24365676833050592, 0.16038693727127143, 0.31654141736882074, 0.23328807471053942, 0.22526302747428417, 0.187509881864701, 0.3499719692128045, 0.27100628933736254, 0.32038841236914906, 0.3529641186552388, 0.2402767954128129, 0.20800545279468807, 0.385886230639049, 0.3507758160786969, 0.29974466296178953, 0.40617904173476355, 0.26360146382025307, 0.3703947333352906, 0.4007396878940718, 0.27791841700673103, 0.4558552418436323, 0.31829863307731493, 2.3035034920488084, 17.529905523572648, 44.55410058157784, 74.56271716526577, 94.85975319998605, 82.78665365491594, 87.20113604409354, 68.15261486598423, 53.46370962687901, 48.290365832192556, 47.30554206030709, 45.934460980551584, 44.79683937345232, 47.22765622820173, 50.31145783833095, 55.01878942762102, 48.592483929225374, 50.08558232443673, 51.71197496141706, 68.79268292018345, 76.63353048052106, 81.35223974500383, 76.7572501046317, 51.92618097577776, 29.89078208378383, 20.05262098993574, 19.103165285927908, 18.654824086597987, 19.544870955603464, 23.32661737714495, 20.292601346969604, 21.261895895004272, 25.288008723940166, 26.02690100669861, 16.6494836466653, 25.242011649268015, 20.968066998890468, 16.15390338216509, 19.87800928524562, 28.48407758985247, 27.861320972442627, 28.27239203453064, 21.317123651504517, 31.240594727652415, 51.50098596300398, 73.03853947775704, 62.44548961094448, 81.44686031341553, 117.13861002240861, 119.75188309805733, 108.09733608790806, 76.88796656472343, 56.910467760903494, 36.88703441619873, 37.43563291004726, 35.861136368342805, 36.9153413772583, 35.55773285457066, 50.089952741350444, 52.127487659454346, 66.44836071559361, 78.01373454502651, 83.63812065124512, 82.38827174050468, 85.01355130331856, 83.08645452771867, 82.98948546818325, 53.660402706691194, 22.01654495511736, 3.935602988515581, 0.408465460475002, 0.6691172240035874, 0.3731394074857235, 0.3115875689046723, 0.35458025336265564, 0.4027512999517577, 0.39008077127592905, 0.28780312516859596, 0.3302003544356142, 0.32997776780809673, 0.3064336068928242, 0.1727044784596988, 0.22366195624428137, 0.26160456240177155, 0.2137616824890886, 0.34275034815073013, 0.13509781498994144, 0.44610075812254635, 0.34779444177235874, 0.29882750074778286, 0.4976842116032328, 0.3405714364988463, 0.4626484087535313, 0.20108269926692757, 0.3193797564932278, 0.3483674781663077, 0.3175202448453222, 0.2816791837768895, 0.37362369149923325, 0.4241901566939694, 0.1446588619479111, 0.5090333340423447, 0.1903659850358963, 0.19899230929357664, 0.29506838960306986, 0.29184616250651224, 0.2550937474838325, 0.30463714471885134, 0.304357072604554, 0.22323906607925892, 0.3683161363005638, 0.2563833439988749, 0.21162682133061544, 0.2278446496597358, 0.2731603394661631, 0.20512003691068717, 0.1848616546818188, 0.24788176161902292, 0.2562610719885145, 0.18995985468583448, 0.26049784464495523, 0.2333272397518158, 0.1683604565582105, 0.23017047771385737, 0.28626627049275805, 0.24152562554393495], [0.026903021215860332, 0.07076850187565599, 0.04153064166062644, 0.040075981324272494, 0.10040381737053394, 0.032645310408302715, 0.05438362840296967, 0.027694998807939034, 0.05751657046909843, 0.033611557845558436, 0.04255761119670101, 0.01692937407642603, 0.09773961747331278, 0.020609741232224872, 0.008045937633141875, 0.046693587476121526, 0.05201048270932265, 0.06074963376990386, 0.03190519155136176, 0.0137623508926481, 0.07130191182451588, 0.026135348748149614, 0.09164397099188396, 0.0983523888779538, 0.08930555611316647, 0.06435477853353534, 0.03731306815253837, 0.09098815332565989, 0.04861024534329772, 0.04406452890751617, 0.04317700510312404, 0.09652783535420895, 0.059510805244956694, 0.23115617196474755, 0.05966416094452143, 0.09373660691614662, 0.11634100361594132, 0.08449210332972662, 0.03485282909657274, 0.06785844838512795, 0.00928471950880651, 0.11157584216977869, 0.004154588494982038, 0.053278562878923755, 0.08267345306064401, 0.06850207277706691, 0.12081807266388621, 0.05147469788789749, 1.3647687499012267, 8.318199225834437, 35.69293090275356, 56.24022020612444, 67.9482752936227, 76.12251826695034, 57.13622862952096, 53.08679417201451, 38.34716360909598, 29.38943828855242, 21.044483286993845, 19.248099497386388, 21.493269171033585, 39.256859983716694, 24.95350159917559, 29.252920082637242, 18.49416262762887, 24.96474552154541, 24.744211435317993, 23.975646870476858, 24.555249963487896, 19.027579307556152, 14.69458191735404, 9.099352189472743, 5.775056924138751, 2.15443879365921, 0.9700001158884594, 0.31803519864167484, 0.22193004989198276, 0.05792978472475495, 0.044352797724838765, 0.038950444398713965, 0.2944112148668085, 0.12968150419848307, 0.024712649107511555, 0.09650485337312732, 0.13996524523411477, 0.08612600208393165, 0.05765942244657448, 0.0862418958651168, 0.3168295504791396, 0.19044257806880133, 0.12902544225965226, 0.11060857692999498, 0.37083898378270014, 0.6016279597367559, 0.9884917693478721, 1.4615556363548552, 3.50349343248776, 8.457421149526324, 13.995508023670741, 30.28315728051322, 47.050803729466026, 72.9036818913051, 68.40801674979073, 56.16545411518642, 58.49311106545584, 54.86703034809658, 40.43423570905413, 31.909615925380162, 19.248801265444072, 19.661241122654506, 22.812063319342478, 31.818021297454834, 41.96047701154436, 55.45482363019671, 58.622625487191335, 66.43736866542271, 66.92280455998012, 61.7243013381958, 59.914913994925364, 39.480501651763916, 12.05962872505188, 1.8323242153440202, 0.2569284790328571, 0.37888638196246965, 0.07340656460395881, 0.1377877720764705, 0.13121787032910756, 0.06019915866532496, 0.0997773599145668, 0.1194213761815003, 0.018200899507584314, 0.07841318952185766, 0.006064754902451698, 0.08691067355019705, 0.009910133717182492, 0.011366440349125435, 0.06686882541647979, 0.05858494421201093, 0.070080413083945, 0.06724105615700994, 0.13289619955633367, 0.04020741355738469, 0.0805187922503267, 0.05040796280705503, 0.028033942316791842, 0.054130714652793746, 0.05616784980520606, 0.09481114175702844, 0.030352394695260694, 0.033422233004655154, 0.05058583736951862, 0.05141191643529704, 0.02600956871174276, 0.04586573064859424, 0.01541286357678473, 0.018164988041722348, 0.0485838469383972, 0.01778780060288097, 0.025073989360992397, 0.03164470535037773, 0.016410376211362224, 0.05591605563781091, 0.0748208894261292, 0.06650410605860607, 0.053705995835896046, 0.09167701564729214, 0.04091026048575129, 0.08100191596895456, 0.04772965955947127, 0.06808006470756871, 0.07768605782517365, 0.04696445865556598, 0.03656394174322486, 0.06719714137060301, 0.03223715802388532, 0.008211302554367908, 0.03249165615332978, 0.03960777859070471, 0.05426038608753255, 0.09964799721326147, 0.014377297002023883, 0.043917588756552765, 0.07595244834997825, 0.0033559947623871267, 0.0788114352950028, 0.028027779522484968, 0.045455800502427986, 0.04917194341708507, 0.016426681407860348, 0.027329985983669758, 0.022603205870836973, 0.04605630060125675, 0.06892378907650709, 0.1780551749148539, 0.02400437729167087, 0.05425963291366186, 0.023594489553943276, 0.016993526169764142, 0.06265550293028355, 0.11562038585543633, 0.021823331647153412, 0.10078210742878062, 0.07645769231021404, 0.05802845050181661, 0.04701802899528827, 0.016657829450975572, 0.06846163208995547, 0.0718098088566746, 0.10642889621002333, 0.13634797504970006, 0.06270757370761462, 0.04961714720619576, 0.12271745502948761, 0.023911175417846868, 0.04724439845553466, 0.07038798622254815, 0.03511617532266038, 0.10570732171514205, 0.08863923472485372, 0.07515678461641073, 0.06014970703316586, 0.07131356905613627, 0.05430578686563032, 0.11539678142539092, 1.6782304325274058, 9.555151411465236, 40.01633977890015, 63.27704307011196, 76.87679386138916, 82.4806271961757, 65.34361103602818, 62.15529114859444, 51.432980469294954, 38.66041966847011, 34.045881271362305, 28.992157663617814, 27.583450351442607, 40.952508790152415, 28.160409654889786, 36.811163561684744, 31.601609230041504, 32.97911044529506, 30.31217643192836, 32.283415113176616, 30.77374873842512, 23.98379189627511, 17.49816962650844, 12.049209901264735, 6.906734781605857, 3.1274128471102034, 1.4764221757650375, 0.6446777497019086, 0.4815254701035363, 0.3299133341227259, 0.16490030794271401, 0.08417926475937877, 0.16168532760015555, 0.15044128309403146, 0.05289931269362569, 0.085498689673841, 0.08065729481833321, 0.0903314874906625, 0.15404190202908857, 0.05837677645363978, 0.12457497178443841, 0.07854403142950364, 0.07757601301584925, 0.12070459446736745, 0.1762766396360738, 0.5775654252086366, 0.8561435139604977, 1.891481178147452, 3.3344867527484894, 7.858550701822553, 14.029859048979622, 29.99009963444301, 42.47334439413888, 60.75912012372698, 55.733515875680105, 40.71375131607056, 47.342909472329275, 46.94974218096052, 37.55668789999825, 38.43511390686035, 30.258741310664586, 33.7900972366333, 35.03858430044991, 43.98711020605904, 55.16390950339181, 64.80241584777832, 69.11955397469657, 73.12129947117397, 76.99744932992118, 71.83045618874687, 73.28408186776298, 52.478375162397114, 17.865498304367065, 3.24433148758752, 0.04874447314068675, 0.2435483927173274, 0.03833178331011108, 0.026100125995331576, 0.06511954856770379, 0.024451245187914798, 0.0919540072126048, 0.08914565255067178, 0.028686815141034976, 0.07831149069326264, 0.04603014986163803, 0.08786757756024599, 0.04310967746589865, 0.05905839880662305, 0.10189390741288662, 0.07591192623866455, 0.12583820042865618, 0.03700690636677401, 0.052641177616481266, 0.03497809683904052, 0.035211577346282344, 0.04583149177155324, 0.06790050398558378, 0.10351290553808212, 0.03217317895697696, 0.039332503718989234, 0.05497926340571471, 0.06599790536399398, 0.03036002821422049, 0.03863558718668563, 0.0547934703395835, 0.01911587344615587, 0.0471447759440967, 0.06717847487223999, 0.07666170743427106, 0.07448600525302546, 0.05717446668339627, 0.03253745048173836, 0.11355211612369333, 0.06110452115535736, 0.0774211577538933, 0.07974342349916697, 0.0678246369851487, 0.061164259378399165, 0.07178303386483874, 0.014610947143020374, 0.09617062737899167, 0.06229658504681928, 0.024536576055522476, 0.0781403641615595, 0.020896047387006025, 0.03175367128902248, 0.022261456619682055, 0.026998014422133565, 0.17771541886031628, 0.18717414273747376, 0.12956342553453787, 0.2784083735729967, 0.183236386893051, 0.1504828365785735, 0.19684794864484242, 0.14787876845470496, 0.15756446229560034, 0.15021457097360066, 0.17295934978340352, 0.14835036386336597, 0.1295719343636717, 0.10667884136949267, 0.15013951142983778, 0.1811115544821535, 0.15597626966025147, 0.27112370303698946, 0.10766302927264146, 0.10920593648084573, 0.20944434058453354, 0.12354893184133939, 0.18299471986080917, 0.2061864361166954, 0.18979856691190175, 0.2501711387719427, 0.27813948371580666, 0.19761229120194912, 0.09352048672735691, 0.11851941315191132, 0.20946050328867777, 0.29658480680414606, 0.2819736679749829, 0.37192491122654503, 0.1417547863508974, 0.21177536621689796, 0.15739581920206547, 0.15507247458611215, 0.1561627717954772, 0.17187822636749062, 0.12698172192488397, 0.12553262896835804, 0.16232587822846004, 0.2543434506016118, 0.27006833681038445, 0.2613920723753316, 0.25215683079191614, 0.19570058664040907, 3.482234767505101, 18.56384437424796, 55.22747162410191, 80.68212073189872, 87.62176609039307, 94.18671594347272, 72.70548452649797, 69.79277883257184, 54.90339721952166, 44.53836291176932, 33.18428380148751, 27.992261511938914, 31.97288622174944, 56.47550358091082, 43.70040321350098, 50.451099259512766, 33.268627984183176, 41.699408871786936, 42.285590171813965, 40.14907816478184, 37.20739153453282, 28.108685527529033, 21.311884709766932, 13.083646416664124, 8.267314093453543, 3.58421391248703, 1.9839983965669359, 1.0527670575039727, 0.49982523385967526, 0.6299358978867531, 0.5278195259826524, 0.426502522613321, 0.5356418948088373, 0.7440155478460448, 0.24475162529519626, 0.18338922012065137, 0.5979370549321175, 0.276291832860027, 0.3236616924405098, 0.41411803715995377, 0.5402407337512288, 0.5248713727508272, 0.27204740632857594, 0.26643103627221926, 0.7988019308873585, 1.3833447588341576, 1.4669521067823683, 2.154672209705625, 4.982781197343554, 11.238018138068062, 19.709961891174316, 40.602305684770855, 60.75891167776925, 98.83155196053642, 92.12401812417167, 78.82188647133964, 79.20416940961564, 73.39168861934117, 59.00463744572231, 49.34478970936367, 33.76802280970982, 35.59455483300345, 35.024601050785606, 48.31681415012905, 59.750227791922434, 72.09739208221436, 77.73151956285749, 86.7624545778547, 83.79641451154436, 79.9031651360648, 86.3132882799421, 69.80930164882115, 29.69007294518607, 7.539618832724435, 0.3770388668136937, 0.496497101017407, 0.143168500491551, 0.189401135380779, 0.2461849626685892, 0.21444541508597986, 0.2560998520680836, 0.24541227413075312, 0.1586592649774892, 0.1383710272078003, 0.16493393613823823, 0.2323743323130267, 0.2752407006919384, 0.09346480614372663, 0.1931135497455086, 0.20792816765606403, 0.2550495070006166, 0.14670958476407187, 0.23502010319914135, 0.1222674370344196, 0.1376964005508593, 0.24635942759258406, 0.14456312065677984, 0.23997568871293748, 0.11602195645017283, 0.14044510519930295, 0.1806651327226843, 0.11070838264588799, 0.1407237931021622, 0.13508196441190584, 0.11704837637288229, 0.11189876377050366, 0.15343074553779193, 0.15546747696186813, 0.1482556810868638, 0.08745323015110833, 0.19755582351769718, 0.15401990392378398, 0.23112441652587482, 0.13569647286619457, 0.1386192353176219, 0.14763815993709223, 0.15939710395676748, 0.204732851258346, 0.1418544360037361, 0.14499853657824652, 0.23807671346834727, 0.21664487277822836, 0.2578992726547377, 0.16573641236339295, 0.1702094373426267, 0.16857362511966908, 0.10767220306609358, 0.16041288445038454], [0.09998889320663043, 0.013008555314237518, 0.04037602272416864, 0.029963142903787748, 0.03559792161520038, 0.07108754904142447, 0.05574648973665067, 0.05059852597436734, 0.05450091318094304, 0.08875568490475416, 0.05648950254544616, 0.04081724012004478, 0.061006499986563406, 0.045692096929997206, 0.08585635226752077, 0.015994232380762696, 0.03293436632624694, 0.08352029190531798, 0.01756576867774129, 0.03910742686795337, 0.012722999788820744, 0.020872001802282672, 0.04515119595453143, 0.019926889034520303, 0.05139673760692988, 0.06068464368581772, 0.0756858858679022, 0.09732143634131976, 0.0462314304895699, 0.03421524027362466, 0.028918494137802293, 0.024661828530952334, 0.04267453635111451, 0.023923209236402596, 0.09775158004569155, 0.04331055775816951, 0.07117213521684919, 0.07594257566545691, 0.030410036245094876, 0.02725329965219966, 0.0634013961202332, 0.10333207595561232, 0.03403293487748929, 0.0756152028750096, 0.028799543556358134, 0.039382494786488156, 1.634496950677463, 10.829761096409388, 34.688377720969065, 67.28408309391567, 73.1882175718035, 72.49922030312675, 66.39981365203857, 57.40139620644705, 41.84847552435738, 37.38119377408709, 22.15526052883693, 11.09517707143511, 21.068011624472483, 41.7581524167742, 52.38081203188215, 43.00231422696795, 51.78312104088919, 33.99230023792812, 44.14612667901175, 25.374070848737443, 16.10171719959804, 9.39780945437295, 3.995551177433559, 3.0288839169910977, 1.3632731501545226, 0.550733165017196, 0.18652874736913613, 0.04048176562147481, 0.05620189529976674, 0.01659733466138797, 0.03915007279387542, 0.0686089081157531, 0.07464252971112728, 0.05296404832707984, 0.0957542307940977, 0.04020468584660973, 0.12174805918974535, 0.029306368503187383, 0.17307421219136032, 0.10287858386124883, 0.11100514672164406, 0.13556447066366673, 0.05905916555119412, 0.005854624905623496, 0.03265718477112906, 0.10568623963211264, 0.094920501245984, 0.0417835859448782, 0.034996420677219114, 0.14993665660066263, 0.30941422123994144, 0.3188962595803397, 0.9115246193749564, 1.2035635943923677, 8.500987223216466, 14.035257799284798, 25.829804931368145, 56.080210140773225, 59.086792945861816, 88.02556759970528, 82.67979730878557, 62.74269185747419, 55.57231419427054, 28.30019004004342, 20.103087493351527, 16.15978329522269, 16.37588790484837, 29.336156027657644, 36.475919927869526, 61.454162325177876, 70.69468975067139, 75.65926797049386, 71.86031954629081, 75.52139486585344, 64.88562052590507, 56.12839242390224, 22.72604635783604, 1.0419674941471644, 0.26546089404395645, 0.17031636089086533, 0.016108825071049587, 0.07161721347698144, 0.2188829391130379, 0.04239444727344172, 0.07339388278446027, 0.061480124214930196, 0.07234053180686065, 0.11599572428635188, 0.02382800738061113, 0.11266442947089672, 0.049264940034065924, 0.027664888816486512, 0.041101926272468906, 0.09534991891788584, 0.09474633487739734, 0.0392206200797643, 0.012248424763259078, 0.010817339277959295, 0.08061658271721431, 0.03089598606207541, 0.10466853209904262, 0.10268944222480059, 0.03470918323312487, 0.06846309094024555, 0.01165186780105744, 0.03459694336301514, 0.03190985308693988, 0.12482776679098606, 0.06430413267974343, 0.07936100116265671, 0.06753792879836899, 0.018809065355786254, 0.08929691836237907, 0.02216738452469664, 0.029827195020126443, 0.03747225586058838, 0.03209797692086015, 0.09584023510771138, 0.07190040685236454, 0.0448145475903792, 0.1276649795472622, 0.0647605899721384, 0.01798906596377492, 0.05169507249125412, 0.02454384825458484, 0.06574847589113883, 0.059551985535238466, 0.048205163329839706, 0.045483355809535296, 0.06274445208587817, 0.07122758509857313, 0.060285936508859904, 0.05059220542066863, 0.03295334155804344, 0.053282213397324085, 0.03728912604440536, 0.11677845514246396, 0.03608507922451411, 0.05472412745335272, 0.043547624322984896, 0.01110718144835638, 0.03177575421120439, 0.07312447045530591, 0.05174606439790555, 0.030847002619079182, 0.09433137678674289, 0.02024117118812033, 0.054304114276809354, 0.04170379022668515, 0.04005411553329655, 0.058624109253287315, 0.017253165898312415, 0.05115111471552934, 0.03208254364186099, 0.06462532401617084, 0.04511897232649582, 0.032474434934556484, 0.09926495740988425, 0.025513422209769487, 0.07523704852376666, 0.06638528100614037, 0.01670893161956753, 0.025269887509888837, 0.03199437480153782, 0.045818443543144634, 0.06006151105144194, 0.08007945439645223, 0.08379081703190293, 0.04096299283472555, 0.06104732743863549, 0.01886045590176114, 0.057280379214457104, 0.10646820374365364, 0.024538900037961345, 0.04079956428280898, 0.12302825120942933, 1.7779559727225984, 11.403798682349068, 41.084111145564485, 73.98161847250802, 84.04421506609235, 80.18829836164201, 78.3043429510934, 67.0749979019165, 55.796150411878315, 47.658322947365896, 29.993618897029332, 23.197535480771744, 24.962935515812465, 32.82162605013166, 37.26029511860439, 41.510574204581125, 47.66598333631243, 31.590394837515696, 29.653396878923687, 24.960415056773595, 18.49460904938834, 11.49046095779964, 5.887487028326307, 4.368952146598271, 2.4664641533579146, 0.9426194365535463, 0.22499696032277175, 0.06614090661917414, 0.02953389147296548, 0.043397980209972174, 0.0796055994661791, 0.019538456574082375, 0.028612800541200807, 0.02618370284991605, 0.06129328959754535, 0.06753267015197448, 0.06011110517595496, 0.18381866493395396, 0.22748149771775517, 0.30372304948312895, 0.4930599683097431, 0.23152515930788858, 0.03588779856051717, 0.16616162311817917, 0.20063319695847376, 0.07089156777198825, 0.1434778038944517, 0.04504389921203256, 0.06146504716681583, 0.1538214867136308, 0.2410922045154231, 0.3041755509163652, 0.4459376925868647, 1.5216439834662845, 7.525283830506461, 14.604752131870814, 25.5343953200749, 44.58215740748814, 51.97812223434448, 66.57852131979806, 71.13911737714494, 61.19799613952637, 49.65992178235735, 28.095610754830496, 26.68390703201294, 26.5283351285117, 28.035107578550065, 45.431939465659006, 46.302121434892925, 72.41856561388288, 78.61053616659981, 81.64959485190255, 79.54076099395752, 85.99123232705253, 77.70804854801723, 68.69114889417375, 31.215129579816544, 1.8319175285952431, 0.2474461964198521, 0.1630030833184719, 0.03706471076501267, 0.050217518383370977, 0.22691736370325089, 0.07294191739388875, 0.028709006628819873, 0.08048120819564376, 0.016893985082528422, 0.0319147113976734, 0.021118776506877372, 0.06816365343651601, 0.01022341672796756, 0.030355787370353937, 0.0499705078878573, 0.08849901546325002, 0.018143941581781422, 0.0541251676290163, 0.01713387944203402, 0.03089847628559385, 0.0493462794194264, 0.021186563851577894, 0.09316436440816947, 0.023728184701342667, 0.03600949042343667, 0.10735866560467652, 0.04007679556629487, 0.03589356950085078, 0.016901111396561776, 0.036086907876389365, 0.022346086899882982, 0.055121392743395906, 0.05027538724243641, 0.008292232274210878, 0.09178787469863892, 0.05748385829584939, 0.03249783082199948, 0.030167422656502043, 0.03427143993654421, 0.03151592618918844, 0.055904642678797245, 0.06046034036470311, 0.04000331361645034, 0.0348037472659988, 0.044158092101237605, 0.038805607706308365, 0.04079514701983758, 0.05062598628657205, 0.09088802869830813, 0.07120853862059967, 0.0545410485272961, 0.029393675604036877, 0.19043675623834133, 0.16374751765813145, 0.14296004096312181, 0.10799613568399634, 0.09527072709585939, 0.1453927382826805, 0.21265835740736552, 0.2079107700181859, 0.18183696269989014, 0.13363671196358545, 0.13516899331339768, 0.1347661470728261, 0.12054072826036386, 0.13789048870759352, 0.21006861994309084, 0.13999590144625731, 0.12392109472836767, 0.18361343523221357, 0.11521259987992899, 0.10081110801547766, 0.10627640903528247, 0.18392398713954858, 0.11320068926683494, 0.12339818850159645, 0.16307112681014196, 0.24472814798355103, 0.17711764307958738, 0.18162702396512032, 0.09265419428369828, 0.12886610866657325, 0.15446913481823035, 0.08787113308374371, 0.1107040603778192, 0.11411402454333645, 0.18585170512752874, 0.15057643369904586, 0.29416173111115185, 0.23792073183826037, 0.16222487150558404, 0.10970313980111054, 0.16400401746588095, 0.2925085483917168, 0.18445544290755475, 0.2150588243135384, 0.0828996223530599, 0.1845816775624241, 4.11101199899401, 20.232153756277903, 55.936514445713584, 91.3398027420044, 91.45569174630302, 90.2530766895839, 82.43347672053746, 73.1984383719308, 58.49202019827706, 50.12491260256086, 34.08947079522269, 22.375704288482666, 31.820939540863037, 54.834759439740864, 71.743346623012, 61.98123182569231, 71.97668102809361, 49.26024055480957, 59.08228356497628, 36.66929871695382, 22.650597606386455, 14.158883622714452, 7.129933501992907, 5.423419884272984, 3.2712327412196567, 1.536758269582476, 0.47225831023284365, 0.32657559322459356, 0.19659135384219034, 0.1831952269588198, 0.13339984895927565, 0.12815501753773006, 0.16411138884723186, 0.2028708290308714, 0.1861328086150544, 0.2474132739007473, 0.1943776197731495, 0.2233375215104648, 0.312956092613084, 0.38291147883449284, 0.5459558985063008, 0.18389919346996716, 0.18741137215069362, 0.2642010987869331, 0.3769329610679831, 0.38616993970104624, 0.3654441689806325, 0.11051571941269295, 0.3272197129470961, 0.3846806910421167, 0.5739399854625974, 0.7022892268640655, 1.6195968644959586, 2.0959677483354295, 12.14684772491455, 19.655906643186295, 34.218637807028635, 73.201815196446, 77.37978090558732, 113.36764894212995, 107.12559577396938, 81.53182983398438, 78.11530331202916, 43.7450384412493, 34.603036471775596, 31.52794442858015, 29.241580622536794, 45.12521818705967, 52.92029448917934, 80.89666025979179, 90.76925141470772, 95.75094304765973, 87.91443116324288, 93.31486988067627, 91.4560877936227, 88.93436418260846, 44.00602667672293, 5.734011309487479, 0.32658202573657036, 0.3447316704051835, 0.14693245637629712, 0.12093993755323545, 0.4487878925033978, 0.15295916369983129, 0.17313741094299726, 0.2546865721898419, 0.09171382617205381, 0.2681172772177628, 0.17638268108878816, 0.21170262726289885, 0.14459860803825514, 0.1558629000293357, 0.0762595600847687, 0.16066292460475648, 0.15801031408565386, 0.14983488991856575, 0.2039977807019438, 0.23845707305840083, 0.14742644344057354, 0.0928285913541913, 0.19230651376502855, 0.14836595659809454, 0.19903302139469556, 0.1584902283336435, 0.09020353614219598, 0.1397025707576956, 0.08895128619457994, 0.2958984279206821, 0.10359102527477912, 0.1723936822797571, 0.12513065125261033, 0.1321991133902754, 0.21032601541706494, 0.15284256424222672, 0.16511819910790237, 0.1296841911971569, 0.1770615010921444, 0.1555570571550301, 0.14510790285255226, 0.11273155015494142, 0.25162133095519884, 0.08590198374752488, 0.20091341835047516, 0.13714529440871306, 0.13121303915977478, 0.09273795943175044, 0.11932269004838807, 0.2692658741559301, 0.13776970947427408, 0.16838864290288516], [0.04413116783169763, 0.05809310810374362, 0.034712915175727437, 0.10504017929945673, 0.03431922237255743, 0.03972968079947999, 0.07640842388250998, 0.02244074423132198, 0.05861227560256209, 0.04491945928228753, 0.054087987302669456, 0.05510966765827366, 0.031933262545083246, 0.09203832875937223, 0.03006639557757548, 0.013814160433997, 0.08348070617233004, 0.016912770324519703, 0.019127082844663943, 0.06353118629860026, 0.017877672566100955, 0.033490123825946023, 0.03991932455184204, 0.018504554106454765, 0.054714000318199396, 0.040924482579742155, 0.04146639117971063, 0.06086279305496386, 0.08560840878635645, 0.05208437856552856, 0.08728967607021332, 0.014327404322102666, 0.02863959249641214, 0.046092846497361145, 0.0383619950818164, 0.05079208826646209, 0.04754641099965998, 0.02978188923693129, 0.04191921491708074, 0.15300351274865015, 0.050920076934354644, 0.08802613762340375, 0.02047571020999125, 0.047894183945442946, 0.7331490537949971, 12.689786042485919, 40.25818920135498, 61.59547478812081, 71.93331037248883, 63.3834547315325, 60.98758384159633, 63.08140959058489, 52.052478381565635, 37.18282617841448, 17.960402011871338, 15.642112970352173, 26.882074866976055, 32.15785074234009, 68.53813566480363, 78.85528646196637, 54.0390100479126, 45.82312652042934, 24.60824040004185, 19.840676614216395, 10.571746689932686, 2.2542212222303664, 0.4584166301148278, 0.27244155375020845, 0.2572301828435489, 0.12484739002372537, 0.031203929002263715, 0.08687319127576691, 0.024160854252321378, 0.06642211867230279, 0.028962486955736364, 0.16634539754262992, 0.0721993897376316, 0.037125008779444864, 0.019478623356137956, 0.07564465129481894, 0.06945015583187342, 0.16005864845854895, 0.020946913764679005, 0.17835941644651548, 0.1512762882879802, 0.22916551306843758, 0.33440968713590075, 0.04393920348957181, 0.14497526282710688, 0.04790452142645206, 0.01605490019678005, 0.03708551125600934, 0.025210759968363812, 0.09314827634287731, 0.174569540524057, 0.022371316528213874, 0.07553391437977552, 0.037253774369933775, 0.038825081661343575, 0.07413945706295115, 0.04926884161042316, 0.575279142175402, 1.502870710832732, 2.4201576667172566, 8.784414666039602, 14.60172619138445, 29.35019486291068, 55.35184785297939, 69.11354378291539, 84.80163819449288, 74.79120867592948, 43.55146510260445, 27.262203863688878, 13.266952923366002, 21.59432029724121, 31.30192300251552, 46.464407035282676, 56.03648860113961, 59.36619390760149, 69.07657241821289, 63.43843582698277, 72.27817031315395, 75.37934589385986, 51.66346958705357, 22.737290280205862, 4.357868032796042, 0.3887733428605965, 0.08706478242363248, 0.03920799932841744, 0.11162197576569659, 0.04800593187766416, 0.05987770948559046, 0.06617821247449943, 0.033840593948428116, 0.04784520050244672, 0.051369104268295426, 0.024058532867846743, 0.10832298600247928, 0.06357166091246264, 0.014502581707867128, 0.02182397455908358, 0.027238487232742564, 0.007573060641464378, 0.06932158023118973, 0.07312197344643728, 0.06208316542740379, 0.058085651003888676, 0.0353985544560211, 0.12024361134639808, 0.0871367207063096, 0.05656320841184684, 0.06395022917006697, 0.02255777795133846, 0.036348367775125165, 0.07276253309100866, 0.015976269862481525, 0.011053119170745569, 0.03269089778353061, 0.03718065204364913, 0.04354258620047143, 0.019922799164695398, 0.04104612355253526, 0.051279561394559484, 0.017175507565428103, 0.0647367937490344, 0.08691342161702258, 0.03623651806265116, 0.04078184434079698, 0.06333997513034514, 0.006614629503539098, 0.03148026917395847, 0.04689823703042098, 0.046085311365979056, 0.08046630078128406, 0.02764401538297534, 0.01946043692130063, 0.054254431942743916, 0.012270851193794181, 0.10396041295358113, 0.04691260161676577, 0.026959890932110802, 0.07162532875580446, 0.040926172131938596, 0.05446375321064677, 0.04510661620380623, 0.0781202930957079, 0.13114708555596216, 0.06011077269379582, 0.022806011506223252, 0.058255474748356004, 0.014447572873905301, 0.03584723234442728, 0.03561681881546974, 0.018908290924238305, 0.02757095412484237, 0.01809960271098784, 0.03465714638254472, 0.06327304443610565, 0.024712606699072888, 0.07425915742559092, 0.03208965468885643, 0.03707360296643206, 0.05589630687609315, 0.02757543754497809, 0.08497685553239924, 0.06677329447120428, 0.05983711952077491, 0.02964473356093679, 0.014343283737876585, 0.04308816112045731, 0.04274798437420811, 0.025920414299304997, 0.09786659173135247, 0.07589527498930693, 0.03215690090187958, 0.05920880966420684, 0.049692827609500716, 0.07135408438209977, 0.05100849683263472, 0.08013337757438421, 1.3961803615093231, 14.204713940620422, 45.681741101401194, 70.90724904196603, 83.4589752469744, 76.29981545039585, 71.11959988730294, 71.22816549028668, 57.73833172661917, 49.709222725459504, 28.26291642870222, 28.671058825084142, 31.79152434212821, 24.592857088361466, 45.45491368430001, 60.474556650434224, 50.1547794342041, 47.475415093558176, 31.17041792188372, 21.195457220077515, 12.212391819272723, 3.5896083201680864, 0.7334339842200279, 0.6809816530772618, 0.39683613021458897, 0.2004692086151668, 0.07215394146208252, 0.06344316673598119, 0.048940050681786876, 0.034794644718723636, 0.06805094198456832, 0.14339416766805307, 0.11309314146637917, 0.1563453519982951, 0.15853529662958213, 0.11318617540278605, 0.08401841124785797, 0.43103996770722525, 0.14399039638893946, 0.24215883442333766, 0.7610332061137471, 0.6304698235222271, 1.0883505195379257, 0.5622604978936059, 0.6743444406560489, 0.27372558627809795, 0.0670162167932306, 0.16833102170910152, 0.10865643168134348, 0.15992305002042226, 0.2338628481541361, 0.08994052239826747, 0.038049838439162285, 0.03980369200663907, 0.06176832517875092, 0.1507251685751336, 0.038999471946486404, 0.6201044140117509, 1.4931552835873194, 3.1727220501218523, 9.243913803781782, 15.632475818906512, 27.951454741614207, 37.89253602709089, 54.82717548097883, 56.090319769723074, 53.23746238436018, 36.971958773476736, 31.043759209769114, 21.87916690962655, 36.08300971984863, 45.652860913957866, 58.10068723133632, 70.37346063341413, 68.27459049224854, 81.51232624053955, 72.62347493852887, 81.71979250226701, 86.60705116816929, 65.0509112221854, 28.450510842459543, 5.627807225499835, 0.1965521073767117, 0.21031241757529123, 0.01165286185485976, 0.09860006094511066, 0.060989624820649624, 0.05384088520492826, 0.03439954395538994, 0.05883360015494483, 0.04339847893321088, 0.011022658885589667, 0.08726361354014703, 0.052481545467994044, 0.022343225178441832, 0.03209014662674495, 0.01215564612565296, 0.04768482196543898, 0.06004171818494797, 0.08429668524435588, 0.07208734325000218, 0.048058715116764815, 0.004869475179085774, 0.06604005595935242, 0.07612537299948079, 0.06308829970657825, 0.01786536054818758, 0.059333334410829205, 0.021323117327743342, 0.0521667425387672, 0.02459637025770332, 0.034377820656767914, 0.02987811907327601, 0.051772564583058865, 0.03234740639371531, 0.08089665483151164, 0.046296295044677596, 0.07084288288440023, 0.009294649020635655, 0.010517649868104075, 0.012899485899002423, 0.03188441480909075, 0.07108124545110123, 0.02889828397227185, 0.07392257012959037, 0.0464292811229825, 0.027964445063844323, 0.011152026675907629, 0.0568110331493829, 0.08401703382177012, 0.01664174477835851, 0.04453783422442419, 0.13837344279246672, 0.17580493566180977, 0.18140479017581257, 0.22452191795621598, 0.1076228871409382, 0.12156629322894982, 0.16413836739957333, 0.1872754344450576, 0.1256554438067334, 0.21052912808954716, 0.1865946195487465, 0.1628658699670008, 0.14070088575993264, 0.12851888872683048, 0.15815461134271963, 0.2044094478977578, 0.2746577305453164, 0.07354075168924672, 0.20938034116157464, 0.15087893818105969, 0.07566605228930712, 0.1103989299652832, 0.13697692272918566, 0.2138338243322713, 0.09182978780674082, 0.2250320270125355, 0.18370019271969795, 0.16275488877935068, 0.18076672298567636, 0.1513782992426838, 0.22472120369119303, 0.0843727829466973, 0.1707146880882127, 0.12168540326612336, 0.07375092112592288, 0.17919191106089524, 0.24220011649387224, 0.19144632135118755, 0.16301640974623816, 0.20215730874666146, 0.1756106982273715, 0.17117370345762797, 0.15621550753712654, 0.21604302578738757, 3.589980265923909, 25.213656050818308, 60.6856290272304, 85.16928822653634, 90.97215965815953, 79.50631182534354, 77.02485997336251, 80.08960614885602, 66.35754776000977, 51.30626617159162, 27.03770409311567, 27.14227795600891, 41.917318275996614, 44.682201044900076, 91.46717017037528, 103.36192335401262, 75.9504530770438, 62.98322459629604, 34.84716142926897, 29.060046775000437, 15.40737155505589, 3.503677559750421, 1.067694067955017, 0.7698257714509964, 0.6735531059759003, 0.5812999191028732, 0.2251946854272059, 0.16408784368208476, 0.13365679660013743, 0.1567558656845774, 0.2625226745648043, 0.29555340643439976, 0.1960422968758004, 0.2259333657899073, 0.1912181843072176, 0.1507054774888924, 0.1282840206154755, 0.36700200395924704, 0.17621726782194205, 0.27358656802347725, 0.7293982207775116, 0.48085133199180874, 0.7424395552703312, 0.2644724313701902, 0.4342304936477116, 0.2299919958625521, 0.2773859570068972, 0.2814661780638354, 0.3347810357809067, 0.5059480081711496, 0.4445773927228791, 0.3218099432332175, 0.18484157004526683, 0.1657712754926511, 0.35150990954467226, 0.3611461653241089, 0.3092905107353415, 1.68065459387643, 2.482098251581192, 4.346459090709686, 13.144080979483467, 21.253974948610576, 38.420529638017925, 76.59708023071289, 94.0471544265747, 112.09846319471086, 94.15311445508684, 61.42535509381975, 40.04156868798392, 23.27371379307338, 38.4232394354684, 47.97195420946394, 63.00347859518868, 73.8365956715175, 77.31635080065045, 89.4955632346017, 79.92202254704067, 87.20631940024239, 100.1917313167027, 78.45255497523716, 40.308066844940186, 8.593543308121816, 0.4097268299332687, 0.34581333664911135, 0.13686751574277878, 0.23442274811012404, 0.16354991469000066, 0.1507287240986313, 0.20272524255727017, 0.21200538958821977, 0.11030884087085724, 0.1559907631682498, 0.17985188136143343, 0.22599162480660848, 0.11637754951204572, 0.10453284545136349, 0.0710701174767954, 0.13278376630374364, 0.14474488661757537, 0.17551056002931936, 0.1477656973791974, 0.20380464249423572, 0.11776781348245484, 0.21978193015924521, 0.21858757281942026, 0.15699655562639236, 0.12566012569836207, 0.22893117421439715, 0.07938778972519295, 0.11505413481167384, 0.14451932800667627, 0.11449481839580194, 0.09545518684067897, 0.1095125868118235, 0.10066603044314043, 0.15571713713662966, 0.08538145239331893, 0.18218084424734116, 0.1620553463165249, 0.13969175490949834, 0.19854147705648625, 0.19333104736038617, 0.1710989967520748, 0.1501730853425605, 0.1815012235726629, 0.13636153217937264, 0.15187375194260053, 0.13567200489342213, 0.18138058004634722, 0.18468081152864865, 0.13999020175210067, 0.17366556903081282], [0.023387990991718004, 0.04572925690029349, 0.12156990303524903, 0.06199097287442003, 0.03238008124753833, 0.01722343927914543, 0.06360836965697152, 0.04495158452274544, 0.03238855954259634, 0.049348515192312856, 0.04161052558837192, 0.014026902366562613, 0.03863582467394216, 0.056167354474642446, 0.06582281618778195, 0.038320896215736866, 0.044465739878692796, 0.05634866581697549, 0.028720484048660313, 0.0054631958649094614, 0.025070666235738566, 0.031386980786919594, 0.03421548115355628, 0.09484688698181085, 0.02101097595212715, 0.027279670915699432, 0.02960522925215108, 0.03911493146525962, 0.0425642947666347, 0.10094019251742534, 0.03955498517357877, 0.0417525633238256, 0.040685217561466355, 0.0926617124517049, 0.07600396272859403, 0.07147983049175569, 0.08082650788128376, 0.0698509868234396, 0.025969411313001598, 0.22893114707299642, 0.06313543074897357, 0.17412239951746805, 3.8602276274136136, 22.242938109806605, 41.236012663160054, 62.7051785332816, 66.83675112043107, 64.11523900713239, 60.27684565952846, 47.30134187425886, 48.6630220413208, 58.43707384381975, 58.008161544799805, 17.180732488632202, 29.879109110151017, 41.549907956804546, 50.2911239351545, 76.41420364379883, 68.33222579956055, 46.185388224465505, 29.285521030426025, 14.524574262755257, 4.5441210099628995, 0.5775932180030006, 0.04106088847454105, 0.20777749216982297, 0.05894885611321245, 0.18364320934883185, 0.04288642926673804, 0.09286008894975696, 0.1489010900259018, 0.0818034897425345, 0.19446504222495214, 0.1240681739790099, 0.032861101507608376, 0.08689813422305243, 0.0999309259599873, 0.0897054575117571, 0.05242165457457304, 0.02031803224235773, 0.15175333911819117, 0.11175411367522818, 0.17778309594307626, 0.42175826004573275, 0.40448107570409775, 0.7241807750293187, 1.1888941015516008, 1.1938534868615014, 0.7575261028749602, 0.20236612111330032, 0.24196393202458108, 0.11461820320359298, 0.1678290143609047, 0.04078151864398803, 0.04368081056912031, 0.1211570959006037, 0.06344613871936287, 0.15368427336215973, 0.19101252034306526, 0.054006512210305245, 0.0901596959946411, 0.021717856771179607, 0.2066903162215437, 0.24178232891219004, 0.3167027729962553, 0.49758693682295935, 2.396891189473016, 9.543038095746722, 20.830376284463064, 38.344724791390554, 74.69785962785993, 65.6143684387207, 64.3569529397147, 49.324629511152, 26.427935395921978, 15.522980894361224, 17.909614154270717, 23.642088174819946, 51.599434988839285, 55.23685169219971, 59.65086855207171, 63.803521973746165, 63.298262868608745, 68.92278099060059, 69.55018942696708, 58.45652879987444, 22.26261019706726, 1.469165108033589, 0.40055808478168076, 0.025882004128236855, 0.0337567168420979, 0.047945162281394005, 0.0171119525829064, 0.05789169855415821, 0.06668934611869709, 0.03549755271524191, 0.05183139017650059, 0.02973158604332379, 0.012005365886060255, 0.06744648941925593, 0.04864774118842823, 0.025198198588831083, 0.024776380509138107, 0.05901250269796167, 0.12077569136662142, 0.05448718981019088, 0.04759483125859073, 0.080389415978321, 0.06696132331022195, 0.03329043096995779, 0.046844066187207184, 0.030096098448016813, 0.0315307080745697, 0.08898080925324134, 0.012543172741840993, 0.030336706965629543, 0.015600129063906414, 0.06522730671401535, 0.015615061923329319, 0.022631660236843994, 0.04011783336422273, 0.07108767117772784, 0.046286938046770434, 0.028770084958523512, 0.009293433594783502, 0.008077205374969967, 0.06038566080055066, 0.030829007870384624, 0.07938672442521368, 0.016524994346712316, 0.037803818604775836, 0.06264955217817, 0.04066016265590276, 0.1516751583133425, 0.12824705402765954, 0.05821412482431956, 0.038928066313798936, 0.05951048633349793, 0.07493432691054684, 0.0316154503130487, 0.04652853722551039, 0.051941496053976674, 0.02599052053743175, 0.061152025392012935, 0.05147312368665423, 0.044588683638721704, 0.037661804618047814, 0.05322968800153051, 0.04655387372310672, 0.057297254380370886, 0.06188361506376948, 0.03239950431244714, 0.07406175123261553, 0.015410934840994222, 0.07520134401108537, 0.0815642247242587, 0.015846464417076538, 0.011683599491204535, 0.06520988193473645, 0.09511196347219603, 0.007443507102185062, 0.03891046850809029, 0.04716955943565283, 0.023570006314132894, 0.03311057169256466, 0.08617598297340529, 0.046177103583301814, 0.059215642511844635, 0.059063738877219815, 0.04031152118529592, 0.04432737301769001, 0.1029660538105028, 0.08034149104995386, 0.04438107227906585, 0.04163728022415723, 0.2030865488840001, 0.061989412243877134, 0.06020341307989188, 4.539831365857806, 25.57008821623666, 45.82737534386771, 71.8849161693028, 74.41278893607003, 71.46066611153739, 67.30724838801792, 59.61640548706055, 53.612237794058665, 67.71899863651821, 65.7015266418457, 27.36838276045663, 30.154091017586843, 34.80375950677054, 42.29000922611782, 52.992190974099294, 64.15141827719552, 48.65348563875471, 32.1727546283177, 17.85909727641514, 5.673148129667554, 1.030400806239673, 0.2986038013228348, 0.2088698928377458, 0.18371008576026984, 0.19778786892337458, 0.051343428503189764, 0.40672151691147257, 0.5743152967521122, 0.36189095250197817, 0.5211728683539799, 0.6240110929523195, 0.6655573035989488, 0.578387972499643, 0.7026947736740112, 0.28612489093627247, 0.26034536425556454, 0.5217447919504983, 0.3712542743555137, 0.6346566017184938, 0.8757021501660347, 1.4912978346858705, 1.360945069364139, 2.2984202333859036, 3.150967240333557, 3.602683309997831, 1.0848476503576552, 1.969723105430603, 1.7791557312011719, 0.6228799479348319, 0.4587100286568914, 0.02758278607923005, 0.28802625462412834, 0.2722975143364498, 0.3303798133773463, 0.5368348136544228, 0.3986753129533359, 0.32763530207531794, 0.23653155352388108, 0.06197812142116683, 0.13973729817995004, 0.1959560550749302, 0.5314958287136895, 0.3651881712887968, 2.3601095974445343, 9.828826189041138, 20.360250745500835, 39.78381136485508, 62.89127213614327, 55.3017235483442, 49.54433849879673, 36.5736984525408, 31.83547169821603, 22.170666422162736, 29.35787957055228, 37.64465209415981, 67.2643710545131, 66.53854138510567, 67.82718208857945, 70.77582386561802, 70.99328163691929, 77.50199971880231, 81.66691671098981, 70.16574423653739, 28.66950069155012, 2.844738198178155, 0.3630077397184712, 0.02983542564990265, 0.04368204889552934, 0.06818742251821927, 0.07579206302762032, 0.04583051468112639, 0.12725148030689784, 0.05274853203445673, 0.10109554989529507, 0.06810236815363169, 0.012489654988582646, 0.05082564860848444, 0.04454335749947599, 0.04551580335412707, 0.06767894194594451, 0.017011992500296662, 0.035477522361491404, 0.04951653742630567, 0.06179883211318936, 0.023380730667018464, 0.06553257283355508, 0.03891792900062033, 0.05107945802488497, 0.03290204770330872, 0.051494249874459844, 0.04259343784568565, 0.035945555461304526, 0.033116817607411315, 0.03529988189360925, 0.03186526655086449, 0.025447346469653503, 0.042651435626404624, 0.0053432541982536864, 0.0608777818935258, 0.033449007996491024, 0.06445815334362642, 0.03690355530540858, 0.005095448544515031, 0.026212262388850962, 0.1162716844784362, 0.058908354357949326, 0.06303926198078053, 0.03754038077646068, 0.03449249307491949, 0.02666930661403707, 0.08267995342612267, 0.12877886263387545, 0.06132450220840318, 0.10747596395335027, 0.11299509315618447, 0.20992870602224553, 0.17006709426641464, 0.1539683352623667, 0.11397736759058066, 0.1305790567504508, 0.17077384277113847, 0.16470596194267273, 0.16177063302270003, 0.1973179698522602, 0.16449890019638197, 0.21966885908373765, 0.15259621531835624, 0.12550187776131289, 0.15962334110268525, 0.13370202774448053, 0.13714082964829036, 0.13142375142446586, 0.20268774671213968, 0.13856549534414495, 0.09018779412976333, 0.09851839925561633, 0.17948841729334422, 0.1111212440633348, 0.11282260276909385, 0.1381957751831838, 0.1615909705204623, 0.15140886045992374, 0.2775321677327156, 0.1475015301257372, 0.12183553592434951, 0.12315068606819425, 0.15578843759638922, 0.13400580787232944, 0.29240123129316736, 0.15217237520430768, 0.12220255551593644, 0.1466383250164134, 0.2630881113665444, 0.20657659375241824, 0.23346921641911778, 7.321485349110194, 38.41575622558594, 63.97698375156948, 85.19303022112165, 83.59621606554303, 79.8083986554827, 76.75982788630894, 63.884308678763254, 58.761012758527485, 72.5821123123169, 68.19616617475236, 27.10673792021615, 43.33871473584856, 57.50501816613333, 68.1231267111642, 102.19774573189872, 91.18814441135952, 63.271595682416645, 42.322259289877756, 21.891437428338186, 7.173708890165601, 1.0049303386892592, 0.3026182044829641, 0.40643715645585743, 0.28146129261170116, 0.4801029350076403, 0.20139800091939314, 0.47350697751556126, 0.49175609541790827, 0.47494243191821234, 0.5244365132280758, 0.516863791005952, 0.273415034370763, 0.325115087309054, 0.37680963054299355, 0.28007322709475246, 0.17078012600541115, 0.39539891162088936, 0.3146497703024319, 0.28686365272317615, 0.8587180386696542, 1.3662806344883782, 1.7669152851615633, 1.9527351941381181, 3.6096610384328023, 2.7976176866463254, 1.5677510350942612, 0.9153437401567186, 0.5367871533547128, 0.4905696362257004, 0.36179457338792936, 0.13895037397742271, 0.21756975672074727, 0.3517522822533335, 0.3475600214941161, 0.5708429345062801, 0.472904167004994, 0.2959477981286389, 0.5174309919987405, 0.4001204568360533, 0.35746364721230095, 0.5230254318032945, 0.9503592955214637, 1.111227571964264, 4.055571888174329, 12.58338827746255, 31.287647928510392, 54.910109179360525, 97.34182344164167, 90.09340708596366, 85.96685109819684, 66.18724046434674, 39.88700948442732, 26.36411792891366, 30.649226597377233, 39.06306430271694, 67.978166443961, 70.18860380990165, 77.37146391187395, 84.01724215916225, 81.61269296918596, 85.951050894601, 91.30053847176688, 82.86568246568952, 37.97494861057827, 4.703754569802966, 0.5778419417994363, 0.13247491073395523, 0.20651715408478463, 0.27348470634647776, 0.1817679014056921, 0.1808760892599821, 0.27276852620499475, 0.140241748254214, 0.28245700203946655, 0.14939475139336927, 0.08601837964462382, 0.16926159177507671, 0.15391414745577744, 0.11444801305021558, 0.21153380775025912, 0.235299713909626, 0.16501283619020665, 0.14359303271131857, 0.16913340293935367, 0.13212123114083493, 0.17568516066031797, 0.1271340801779713, 0.10207023830818278, 0.13320797282670224, 0.10462638828903437, 0.1183667563434158, 0.09826259155358587, 0.10372694940971476, 0.09521643750901733, 0.09540483275694506, 0.12355387157627515, 0.15812447081719125, 0.1195455752313137, 0.15594561344810895, 0.176006446991648, 0.1432186442294291, 0.07425533727343593, 0.12443542427250318, 0.14627670656357492, 0.18867450580000877, 0.1925152718488659, 0.15610831257488045, 0.1687295524669545, 0.12080323988837854, 0.0954593869724444, 0.3200618198939732, 0.22293593734502792, 0.292206953146628], [0.027720947683389698, 0.04498069367504545, 0.0321614606572049, 0.0652684937896473, 0.05044648663273879, 0.1055214438321335, 0.03400425998760121, 0.0432309927418828, 0.04265579182122435, 0.028396351262927055, 0.11096841762108461, 0.04992705789793815, 0.023221330916775123, 0.08616609671818358, 0.02234502668891634, 0.09299439138599805, 0.010814945745681013, 0.041532765475234816, 0.022022960042314868, 0.07166835466133696, 0.006433664214065564, 0.044232473109981844, 0.02111741265148989, 0.06125715760780232, 0.06775551462279898, 0.04755885872457709, 0.06842099462768861, 0.020597700628318956, 0.04681255841361625, 0.021694574538352232, 0.07729181540863854, 0.06903038692793675, 0.028117522564051405, 0.046740168905151744, 0.05016905741233911, 0.05253860008503709, 0.02212125601779137, 0.05877091708992209, 0.08440856209823064, 0.04737945406564644, 0.07363714437399592, 2.420334194387708, 17.536197117396764, 43.54132073266165, 74.63231727055141, 66.67419106619698, 68.35409178052629, 63.13184656415667, 42.722649233681814, 59.65061146872384, 109.82096876416887, 48.5403550692967, 21.974178314208984, 28.296708992549352, 55.62512397766113, 83.19000353131975, 60.19701085771833, 51.47139358520508, 26.14581421443394, 15.763864517211914, 3.4281862505844662, 0.5887701553957803, 0.08225637794073139, 0.14648352403725895, 0.08892689964600972, 0.0811090770044497, 0.016489350902182714, 0.08897420032215969, 0.011900346476717718, 0.13559153064021043, 0.2446711781833853, 0.1996934259576457, 0.39039675146341324, 0.41333237503256115, 0.6916558231626238, 0.4508028158119747, 0.3816341502325875, 0.5074317742671285, 0.6440689680831773, 0.7879796773195267, 0.4141832579459463, 0.7926673229251588, 1.9198554498808724, 0.38495427636163576, 0.45831490414483206, 2.0107680686882565, 3.0111553711550574, 2.869253179856709, 0.9806677720376423, 0.6117227694817952, 0.12247213747884546, 0.1606671858046736, 0.11351806723645755, 0.17825252003967762, 0.17616143796060765, 0.18432897755077907, 0.1495701391249895, 0.03221021679096988, 0.07128991532538619, 0.07609267439693213, 0.1014208531539355, 0.14417665425155843, 0.16120530478656292, 0.5470882920282227, 0.12838866428605147, 0.047109963704964945, 0.09236177283206157, 0.052233540918678045, 0.538189386682851, 3.633958888905389, 14.159070355551583, 38.451664515904014, 56.05608599526541, 70.76309476579938, 64.62722396850586, 40.99929795946394, 26.26088159424918, 16.892253705433436, 9.930069259234838, 20.153557470866613, 41.83738272530692, 58.80087457384382, 64.04435348510742, 63.99113028390067, 60.88107490539551, 63.046342032296316, 68.60499123164585, 46.03816284452166, 2.4060048375810896, 0.22324788703450135, 0.25963086688092774, 0.039159199089876244, 0.1459895505436829, 0.007050726928615144, 0.06939992388444287, 0.02447281581615763, 0.06112735385873488, 0.04136206981326852, 0.053993002578083954, 0.04159997436883194, 0.015136146818154624, 0.07063497975468636, 0.01648609902310584, 0.031601971214903254, 0.05034217544432197, 0.02528481019128646, 0.03412604684542332, 0.0398157292178699, 0.0484592950503741, 0.021737086453608105, 0.024820565013214946, 0.034241031389683485, 0.051466436724045446, 0.0695676373850022, 0.027069467552272335, 0.058493172350738726, 0.025414812411846857, 0.026114957074501684, 0.061785634607076645, 0.03272936732641288, 0.03674494095944932, 0.028422622442511574, 0.009303285923254277, 0.047221684495785406, 0.024051399768463204, 0.052200669289699624, 0.149438367624368, 0.024495551828294992, 0.02374836602913482, 0.06624909224254744, 0.07337961997836828, 0.04083903466484376, 0.030897685792297125, 0.004154483322054148, 0.004576911659179521, 0.05758500072572913, 0.04957163446981992, 0.02035795893919255, 0.016866355136569058, 0.014769037320677723, 0.0945530134652342, 0.07963372474270207, 0.03343080629461578, 0.08161695368055787, 0.030998410923140388, 0.08546762634068727, 0.023106336194489683, 0.0254648696365101, 0.03389040859682219, 0.013988155472491468, 0.028602876966553073, 0.03780833764800003, 0.10189724580517837, 0.05153062952948468, 0.019535460841975043, 0.01778252499311098, 0.03400929132476449, 0.038042822387069464, 0.03580910206905433, 0.03595555367480431, 0.04709388921037316, 0.032245398831686804, 0.02859105010117803, 0.03748242370784283, 0.06375517749360629, 0.02217176616457956, 0.016020774974354675, 0.04726595890575221, 0.04714757490104862, 0.04812061447384102, 0.13910589420369693, 0.04399395448022655, 0.07613933725016457, 0.049001895756061585, 0.03472455883664744, 0.05635892187378236, 0.11530948110989162, 3.3032129108905792, 23.554436649594987, 55.578466824122835, 83.44491904122489, 73.69449806213379, 74.69797079903739, 71.96236773899624, 56.35181174959455, 56.8862498147147, 97.74750791277204, 62.33298437935965, 32.31319856643677, 31.60241174697876, 44.2681439944676, 63.14380441393171, 49.16201734542847, 49.89900582177298, 30.78454623903547, 18.903519221714564, 5.085011780261993, 0.7833375749843461, 0.019945197605660984, 0.09166985031749521, 0.2190510936613594, 0.17286815467689717, 0.23893397461090768, 0.06413304686014142, 0.22347377134220942, 0.0715868626055973, 0.6872290607009615, 1.4384069527898515, 1.1230914039271218, 1.5113702033247267, 2.521186862673078, 2.9580450781754086, 1.8708717354706355, 2.305510435785566, 3.179843519415174, 2.527033120393753, 1.5731705214296068, 2.7461135131972174, 3.5396848618984222, 2.0985275081225803, 4.731619451727186, 4.816242430891309, 5.2637841531208585, 6.041497324194227, 3.235385681901659, 2.33883073925972, 2.851485550403595, 0.9133483043738774, 0.911567394222532, 1.1142589407307761, 0.6822196809308869, 0.6445144127522195, 0.8791562733905656, 0.577550334589822, 0.35338771449668066, 0.6708323433995247, 0.3837343789637089, 0.10039316437074117, 0.05020171869546175, 0.6852131603019578, 0.15319096483290195, 0.07215622133974518, 0.10789658102606024, 0.057209886211369715, 0.5426509444202695, 3.806870673383985, 15.973924194063459, 37.53423132215227, 52.995963845934185, 58.74221788133894, 52.643843037741526, 29.97310781478882, 28.914589711597987, 28.146092891693115, 24.0727253641401, 33.74271747044155, 55.71103497913906, 66.61228956495012, 73.33773585728237, 72.441529410226, 71.28830214909145, 74.3178904397147, 82.29519367218018, 62.207722255161826, 8.239146964890615, 0.09817176964133978, 0.3350599950977734, 0.017039361210273843, 0.08299880381673574, 0.06660851224192552, 0.04886646355901446, 0.06378523659493242, 0.038716818006443124, 0.07173884766442434, 0.05104957873533879, 0.06200009238507066, 0.07337361494345324, 0.021704462489911487, 0.06861968325184924, 0.023965724544333558, 0.08113856613636017, 0.06570893765560218, 0.05662613914215139, 0.03596893438537206, 0.04444567559819136, 0.0128205663391522, 0.02813103558894779, 0.04405644416276898, 0.07303440850228071, 0.0409663821171437, 0.05406372967575278, 0.02186637112338628, 0.05865864668573652, 0.012271690032710987, 0.03365358969728861, 0.02264981104859284, 0.060467146070940156, 0.060511759748416286, 0.04184688308409282, 0.009415742924569972, 0.012152718247047492, 0.06068129850817578, 0.08720515774829046, 0.01729616296610662, 0.0660666273906827, 0.036799138944063864, 0.042524597075368674, 0.07143398188054562, 0.1057680370286107, 0.007827884467717792, 0.0901070348918438, 0.01815863186493516, 0.11398293157773358, 0.12255882711282798, 0.12461066272641931, 0.06190185408507075, 0.15028459578752518, 0.23048067678298267, 0.14331927097269467, 0.18829012928264482, 0.11600932212812559, 0.2189325535936015, 0.2048082229282175, 0.09449600973831755, 0.14115627775234835, 0.09592362027615309, 0.11264962383678981, 0.17065062081175192, 0.16456511164350168, 0.12472745217382908, 0.0662053878019963, 0.12268757234726634, 0.1465161344302552, 0.13562996286366666, 0.16307071968913078, 0.13386026211082935, 0.16376058624259063, 0.12672332221908228, 0.16017133955444607, 0.08507907004760844, 0.17125283421150275, 0.1012858586119754, 0.12340046837925911, 0.1340811795422009, 0.22700638749769755, 0.14491100556084088, 0.28723681984203203, 0.08539570841406073, 0.23643786140850612, 0.17396550865045615, 0.12604231733296598, 0.10873686522245407, 0.33575001092893736, 5.796626303877149, 36.68423734392439, 67.14362525939941, 92.48615823473249, 82.45752443586076, 85.68294075557164, 80.6021956035069, 58.22310406821114, 70.63822868892125, 115.86039161682129, 59.79151398794991, 32.56234359741211, 43.529651233128135, 74.66253498622349, 105.3332245690482, 80.73444761548723, 69.4734604699271, 40.29538638251168, 25.291003397532872, 6.232154590742929, 1.1192921506507056, 0.3275922829551356, 0.29806642872946604, 0.5312508504305566, 0.24272207277161734, 0.41048852620380266, 0.38337649245347294, 0.44728523599249975, 0.5093236384647233, 0.623009955244405, 0.7619865206735474, 1.5054381787776947, 1.1736241323607308, 2.051684924534389, 2.181059730904443, 1.6252464013440269, 1.939262637070247, 1.8156573325395584, 2.1417969805853705, 1.439954121197973, 2.0626135723931447, 3.8659772617476325, 2.805594652891159, 3.946464325700487, 6.69939923286438, 6.1431377444948465, 7.253321783883231, 3.823676194463457, 2.0062044050012315, 1.2267888167074747, 0.20814833869891508, 0.24594714971525328, 0.8096927436334747, 0.4592758182968412, 0.5098034984299115, 0.48046326424394337, 0.36842847455825123, 0.29576923485313145, 0.5972932066236223, 0.5910160520247051, 0.7320824510284832, 0.33355880422251566, 0.8885607687490327, 0.4847747300352369, 0.2501991758389132, 0.3082138385091509, 0.24102494812437467, 0.9270047715732029, 6.40397789648601, 23.349871260779246, 50.81735965183803, 79.13052545275006, 97.4969002859933, 82.94498225620815, 58.431466647556846, 39.757161549159456, 29.606284618377686, 20.50764114516122, 31.675569329942974, 57.20335865020752, 73.5175552368164, 83.33909102848598, 81.64821910858154, 81.67207922254289, 81.77726105281285, 97.20543725149972, 79.86469296046666, 17.156674351011002, 0.2871580012142658, 0.46046846572841915, 0.1483241045581443, 0.23180097022226878, 0.17458381690084934, 0.14425263660294668, 0.18881785310804844, 0.23143518556441578, 0.1739207524806261, 0.12608936695115908, 0.12161217576691083, 0.1888407061674765, 0.15416584323559487, 0.24153911482010568, 0.19132141662495478, 0.14878119288810662, 0.143588391531791, 0.11963772028684616, 0.13923792354762554, 0.11391970568469592, 0.1010583865323237, 0.12491669559053012, 0.1288945935666561, 0.15954870225063392, 0.1466772457850831, 0.10035828767078263, 0.08263700215944222, 0.14352551847696304, 0.1302131363855941, 0.17912393542272703, 0.09219180659524032, 0.15431155184549944, 0.23867292861853326, 0.08902737032622099, 0.0981165843882731, 0.18218606896698475, 0.12627699545451573, 0.23382626154593059, 0.16480890927570208, 0.10989421526236193, 0.21576686203479767, 0.13766364088015898, 0.10894806603235857, 0.20025575506900037, 0.10832162893244199, 0.17574450533304894, 0.15577006286808423], [0.014039317861066332, 0.03154198532657964, 0.030144746016178812, 0.036689613214028735, 0.03346333187073469, 0.07713960643325533, 0.05551304654883487, 0.11023783218115568, 0.09896847831883601, 0.03769347524004323, 0.006841110073894794, 0.04603741018633757, 0.033417147384690385, 0.04415368840896657, 0.1094555084460548, 0.03238375212198921, 0.049994351608412604, 0.030405110080859492, 0.04956139876906361, 0.05871245451271534, 0.03968919940026743, 0.038380498731774945, 0.02709180492508624, 0.0649346409897719, 0.03883206378668547, 0.03453955626381295, 0.052021000002111704, 0.03589292489258306, 0.09524386389447109, 0.06956644994871956, 0.023222864405917268, 0.04457335892532553, 0.05550362848277603, 0.0549353418339576, 0.04397539994014161, 0.06200963258743286, 0.09789720723139388, 0.043408348225057125, 0.12907948078853743, 0.2344688070671899, 3.3356403708457947, 52.40246956689017, 41.56443664005825, 35.32230356761387, 71.38959993634904, 71.91218090057373, 52.44685465948922, 31.643003123147146, 18.617856195994786, 73.37837587084088, 94.32994610922677, 38.40085928780692, 38.52986996514456, 43.958619117736816, 69.25905990600586, 57.736754485539024, 37.194638116019114, 18.258255652018956, 5.236938485077449, 0.22758231445082597, 0.09197849554142781, 0.0717691917504583, 0.2304694673844746, 0.11834887016032423, 0.08626212977937289, 0.2085988045270954, 0.05673491169831582, 0.14274315402976104, 0.17238231003284454, 0.48352193725960596, 1.798558575766427, 2.5017798926149095, 2.037075468472072, 2.9731263603482927, 5.407696545124054, 4.167691928999765, 2.06761605824743, 1.1755892783403397, 1.949095857994897, 2.830886095762253, 1.9347083100250788, 3.8272145645959035, 2.2454482529844557, 2.2672510487692694, 3.2158673235348294, 3.867382969175066, 4.174961481775556, 5.341273503644126, 1.550418536577906, 6.038809674126761, 12.630491852760315, 1.3814548488174165, 4.9356498292514255, 0.7549544008714812, 1.075462045414107, 0.8502593668443816, 0.35783285168664797, 1.3622768436159407, 0.8875722789338657, 0.5912797035915511, 0.12761273235082626, 0.08678948719586645, 0.13582038693130016, 0.08769142308405467, 0.13773699051567487, 0.1297080892005137, 0.07629844014133726, 0.1694413357015167, 0.09307500813156366, 0.19538451145802224, 1.6157639558826173, 6.041591124875205, 22.997531584330968, 41.18222665786743, 57.58293873923165, 52.92881645475115, 40.86453069959368, 36.02772985185896, 38.9046106338501, 19.277601548603602, 15.655252013887678, 31.730414935520717, 53.39034707205636, 51.08881882258824, 66.4127095086234, 65.8211259841919, 56.01110683168684, 62.39849199567522, 51.518776825496126, 18.458315134048462, 0.8784921233143125, 0.2688642628490925, 0.11606023939592497, 0.07320788276514836, 0.06897627376019955, 0.1222727567489658, 0.030874425611857857, 0.009942443858432983, 0.012198364994089519, 0.09355543128081731, 0.031798508883054764, 0.04245412103565676, 0.05723549412297351, 0.005314812130693878, 0.06763816877667393, 0.04357126448303461, 0.042357165166842084, 0.018394738302699158, 0.04248478403314948, 0.01623866953221815, 0.03526464896276593, 0.09939656606210129, 0.03207108997074621, 0.07343308175248758, 0.025360731474523033, 0.04863493723262634, 0.015298065629654696, 0.10808579730136053, 0.037847740176532946, 0.02442756261942642, 0.020035478386229703, 0.044791253483189006, 0.03792832299534764, 0.021137229266709516, 0.03306738633130278, 0.024363671762070487, 0.09471818245947361, 0.05096766259521246, 0.06261846848896571, 0.030970132976238216, 0.015295923155333315, 0.026760367709877234, 0.03980544601966228, 0.0354241589749498, 0.038690372104091306, 0.031184455047228506, 0.010687131800555756, 0.0584645720997027, 0.026252955830256854, 0.02083675530073898, 0.032006747887602875, 0.033732577958809476, 0.07764641102403402, 0.06716626124190432, 0.025912868989897624, 0.04605994772698198, 0.027058409127805914, 0.03705326387924807, 0.02237298063534711, 0.052217300183006694, 0.03268733208200761, 0.06586914655885526, 0.03551539479355727, 0.047362066605793576, 0.05623633095196315, 0.03287303354591131, 0.020935205642932227, 0.008288045713145818, 0.028302813514268825, 0.0735690805262753, 0.03047009677227054, 0.05079540291002818, 0.030622343067079782, 0.008824574378585177, 0.08952164916055542, 0.03777468909642526, 0.04738271442641105, 0.04493610713897007, 0.03664110813822065, 0.0814803781520043, 0.05751705901431186, 0.11668841354548931, 0.11274081215794597, 0.04032648627513221, 0.10226558175470148, 0.10283024502652031, 5.411985754966736, 58.51979909624372, 47.938859939575195, 39.54947294507708, 77.2493701662336, 80.30971118382045, 62.4037309374128, 43.53368813650948, 28.640144552503312, 72.2666849408831, 104.24217673710415, 41.21080807277134, 24.638015168053762, 33.91450473240444, 53.579087938581196, 55.51351506369454, 38.923096316201345, 23.410706213542394, 6.428043850830623, 0.4044990433113915, 0.06991368345916271, 0.23745058849453926, 0.15283577889204025, 0.06751760667456047, 0.025444052182137966, 0.1281316487916878, 0.19944595066564424, 0.20978628152183124, 0.24050513601728848, 0.13641825770693167, 0.918680938226836, 1.3491769922631127, 0.8533330761960575, 4.376742380005973, 8.04058916228158, 9.8218606199537, 8.896040950502668, 6.607645230633872, 7.124333688191005, 7.4720675774983, 7.206929964678628, 6.500330737658909, 5.738589303834098, 5.7536104406629285, 5.362247943878174, 6.500834916319166, 6.758327773639134, 6.822672000953129, 3.17711808851787, 12.294692363057818, 9.924601026943751, 5.872957476547786, 10.410153303827558, 2.6939777050699507, 2.7845355314867835, 2.3504418304988315, 2.2570272088050842, 3.8048118352890015, 3.6419855781963895, 2.11049730011395, 0.7246016295892852, 0.2230875627802951, 0.1422668903001717, 0.3897756205073425, 0.0745392973933901, 0.10461069377405302, 0.12395879413400378, 0.16664650424250535, 0.07359371134745223, 0.1884144368980612, 1.4071983588593346, 6.5721703342029025, 20.82252308300563, 38.61142792020525, 47.720894949776785, 45.708272797720774, 32.39726482118879, 23.52428320475987, 27.31943096433367, 21.152527775083268, 25.65895915031433, 52.02932003566197, 67.5838839667184, 60.20910767146519, 74.96675491333008, 76.54122366224016, 65.38106182643345, 75.28751850128174, 71.25697272164481, 27.884441103254044, 2.7630132692200795, 0.25088308485490934, 0.021373732647459422, 0.054991711130631823, 0.1421596139137234, 0.04042421228119305, 0.033377958594688346, 0.02466959606057831, 0.015992349446085945, 0.0673977095367653, 0.09430141268031937, 0.026657908922061324, 0.020725823306877698, 0.014678948226251771, 0.08958030851291758, 0.04283251965950642, 0.010828945619453276, 0.03248214987771852, 0.07775010474558387, 0.0459871952022825, 0.0957874111565096, 0.08046334915395294, 0.033835786527820995, 0.04691359567056809, 0.023908169507714253, 0.06584102806768247, 0.03140429360792041, 0.08918155383850847, 0.014592423137011272, 0.08335189986974001, 0.03799083981929081, 0.0409327437435942, 0.023432445213464752, 0.0720910005537527, 0.04443169099145702, 0.05768976653260844, 0.046977937753711424, 0.10913287861538784, 0.04893072082528046, 0.02989528261657272, 0.04597314274204629, 0.011760625938352729, 0.05235354322940111, 0.011650613359441715, 0.037445714963333945, 0.031226670103413717, 0.1301408452647073, 0.1280825092856373, 0.12584228520946844, 0.17904773594013282, 0.13462189052786144, 0.2358420533793313, 0.20469539612531662, 0.18909964870129312, 0.1927475750978504, 0.16660458434905323, 0.11884137801826, 0.1234939976462296, 0.20182648221296923, 0.29277887674314634, 0.168380486911961, 0.23498848346727236, 0.23003379361970083, 0.17208868078887463, 0.1676966728908675, 0.12425132415124349, 0.1565664051366704, 0.18557376361318997, 0.1082889846126948, 0.17827489812459263, 0.11631173161523682, 0.09686209527509552, 0.19124134949275426, 0.06554623852883067, 0.30269232764840126, 0.09757050619061504, 0.12877962259309633, 0.10309403908572026, 0.15577315698776925, 0.19655524220849785, 0.11948880899165358, 0.2483146669609206, 0.23281011464340345, 0.09325716085731983, 0.2701312777187143, 0.41340302409870283, 9.831671476364136, 75.8860502243042, 57.3887574332101, 49.75709581375122, 87.82629326411656, 88.27925327845982, 67.72243799482072, 45.49569613592965, 31.342278139931814, 82.09676006862095, 96.53603390284947, 52.04053790228707, 59.067539487566265, 59.815408842904226, 88.38806206839425, 75.70106138501848, 53.96813494818551, 28.757977315357753, 8.336872509547643, 0.536833293735981, 0.2845633918685572, 0.37613595383507864, 0.6441364416054317, 0.3684211735214506, 0.285565045263086, 0.7881362832018307, 1.2145041844674518, 1.7714401909283228, 1.5821480282715388, 3.615947421107973, 6.485386899539402, 8.311178939683096, 8.940007414136614, 10.116389547075544, 15.666852031435285, 12.744179146630422, 8.50529510634286, 5.450119640145983, 7.892153058733259, 10.374477778162275, 7.019017670835767, 8.539316960743495, 7.159868078572409, 8.306815470967974, 8.811031477791921, 11.26361356462751, 11.540593947683062, 14.295883859906878, 2.619173616170883, 17.275981869016373, 27.079971722194127, 9.126875741141182, 12.412498201642718, 2.41598179936409, 4.483679064682551, 3.2556038541453223, 2.902529839958463, 4.240387456757682, 3.970193292413439, 2.353370279073715, 0.7671618429677827, 0.4329956684793745, 0.803614752633231, 0.8411907191787447, 1.043452997292791, 0.4261122021291937, 0.5302857565028327, 0.5104597774999482, 0.5649015190345901, 0.7070403290646416, 2.4953341356345584, 9.89340535231999, 32.47394514083862, 56.84837865829468, 80.62397820608956, 76.32091018131801, 63.30366856711251, 51.5904301234654, 55.85719381059919, 30.091918536594935, 28.304393700190953, 48.92974601473127, 71.20200552259172, 67.29499176570347, 85.445326260158, 85.47065244402204, 75.36768681662423, 84.52188982282365, 90.6173290525164, 44.223237786974224, 3.985583552292415, 0.5555360530103955, 0.23603771573730878, 0.19463588377194746, 0.2526709703462464, 0.19558527639933995, 0.19104294585330145, 0.11705011342253004, 0.10873659380844661, 0.24473615469677107, 0.17636430636048317, 0.12257611618510314, 0.14443463326564857, 0.10993043546165739, 0.18528930816267217, 0.2435014923768384, 0.1621016359754971, 0.12251362310988562, 0.19171450553195818, 0.13359609485736915, 0.21125400704996927, 0.19400502262370928, 0.14798369710998877, 0.17980318968849524, 0.06909331426556621, 0.17977534261132988, 0.11307433926101242, 0.2136883871363742, 0.14244622710560048, 0.11212688045842306, 0.15992953681520053, 0.10283525261495795, 0.12766867077776364, 0.12626266479492188, 0.093810010834464, 0.1662766890866416, 0.13269732094236783, 0.30223019101790016, 0.15097435377538204, 0.17752380057104997, 0.1287448951708419, 0.25152495184115, 0.1846482554184539, 0.07279872614890337, 0.15772931916373117, 0.07877119816839695], [0.05205227368112121, 0.03379972917693002, 0.023029224082295383, 0.055863258828009875, 0.0986319724470377, 0.06280217505991459, 0.044016176502087286, 0.06906370978270258, 0.03760731825605035, 0.07881688393120255, 0.06181888282299042, 0.07064939183848244, 0.07158202465091433, 0.01589245212796543, 0.05752756952175072, 0.019991936794083034, 0.0796781891424741, 0.060220105041350634, 0.015309619384684732, 0.0888526611296194, 0.054682662178363116, 0.040793213195034435, 0.054301573163164515, 0.08304151759615966, 0.007201170864781099, 0.03479763366548078, 0.014610821614041924, 0.05418246312599097, 0.03021326448236193, 0.02565371271755014, 0.07028235867619514, 0.06595769537878887, 0.050780892438654385, 0.048960196386490545, 0.08889608737081289, 0.05349844893706696, 0.05198854906484485, 0.08582334153886352, 1.2330209165811539, 21.881692579814366, 59.15016746520996, 70.23980508531842, 74.98721735818046, 61.521886416843955, 50.167970589229036, 38.178426606314524, 22.52708990233285, 21.623563528060913, 25.68995680127825, 15.752356563295637, 27.93222733906337, 48.76206166403634, 50.585908208574565, 62.657166481018066, 42.21367284229824, 26.512352534702845, 6.804687457425254, 1.0619853628533227, 0.04300139684762273, 0.040652515566242595, 0.19613650467778954, 0.26123592789684025, 0.027218729989337068, 0.06491674802133016, 0.47116885440690176, 0.24602689115064486, 0.49693771451711655, 0.1393585806446416, 0.3351103966789586, 0.13676443270274571, 0.6053165846637317, 2.014379612037114, 1.5476808377674647, 2.3451138649668013, 2.667818171637399, 5.0051674246788025, 2.829301255089896, 6.056048154830933, 10.081094435283116, 6.325466726507459, 4.091620445251465, 6.01422130210059, 5.359836484704699, 2.1841618844441006, 7.1962540575436185, 4.984624641282218, 4.448905936309269, 6.551333120891026, 3.8972919242722646, 3.036023191043309, 8.02763511453356, 5.072725193841117, 9.317828740392413, 1.9549794622829981, 2.454658946820668, 1.6313816606998444, 3.0024123660155704, 2.4619289338588715, 1.8468023070267268, 0.8875473088451794, 0.5712253025599888, 0.08027268759906292, 0.20608960916953428, 0.1199457480439118, 0.08526823204010725, 0.11491342021950654, 0.09595562677298274, 0.11824163448597703, 0.048931626669530354, 0.0347027914332492, 0.1068626700767449, 0.1169797493410962, 1.7407932068620409, 6.845275359494345, 33.09715339115688, 41.74792466844831, 54.465143067496165, 60.2333151953561, 38.65456233705793, 56.48921932492937, 39.956036363329204, 18.058991738728114, 15.703293595995222, 32.84542710440499, 50.29561594554356, 56.11938755852835, 70.13243457249233, 59.65792792184012, 61.32212570735386, 67.09392479487828, 48.10908385685512, 4.6442567110061646, 0.40796817573053495, 0.06126867913241897, 0.028818752882736068, 0.09803345706313848, 0.04681449902376958, 0.05097660907943334, 0.014122161049661892, 0.02742012087920947, 0.04467108832406146, 0.01223978107529027, 0.01140890731143632, 0.029815948302192346, 0.011855211175445999, 0.04660536435299686, 0.020390598169927086, 0.007280608655751816, 0.01366009481716901, 0.07573775308472769, 0.03910983905994466, 0.025231238155226623, 0.02484902277189706, 0.02953327400609851, 0.0843181608776961, 0.02106928076994206, 0.02845302250768457, 0.03719968495092221, 0.018023722139852386, 0.0547601339141173, 0.016426045281280364, 0.010552833605158542, 0.07831841175045286, 0.07590115788791861, 0.06037656843130078, 0.01985187189919608, 0.05227170172812683, 0.07192044399146523, 0.023830344933750372, 0.04240307823887893, 0.009653460034834487, 0.013544385936776442, 0.03912382027400391, 0.03732017580685871, 0.01667249937807875, 0.040521992570055385, 0.07352818522070136, 0.012861924744876367, 0.02477743223841701, 0.06465870115373816, 0.031476014759391546, 0.04706325674695628, 0.0518218499741384, 0.04032087818320308, 0.04945132681833846, 0.0641583087188857, 0.06883599343044416, 0.07250956845070634, 0.02372607954644731, 0.02129202346051378, 0.05042636128408568, 0.036193224135786295, 0.0812733503324645, 0.04365297366998025, 0.029676092056823627, 0.055209354630538394, 0.03691973836560335, 0.015454527323267289, 0.022370732988097837, 0.07745513878762722, 0.0496471486320453, 0.05380765055971486, 0.02974358932780368, 0.048482595942914486, 0.05537273229232856, 0.028673410681741576, 0.07552797719836235, 0.053882913663983345, 0.011682357772120407, 0.04616669824879084, 0.08679350412317685, 0.035488266963511705, 0.042763967266572375, 0.035194895562848875, 2.4384349031107764, 29.109566586358206, 68.13040842328752, 82.06326975141252, 82.68774604797363, 72.1213355745588, 58.97127914428711, 50.50238391331264, 32.451967988695415, 31.660995483398438, 28.185461384909495, 27.077183757509502, 34.499004568372456, 45.228284290858674, 47.28968627112252, 45.19073969977242, 43.079727581569124, 27.477217606135778, 8.751311710902623, 1.2569831907749176, 0.09077641647309065, 0.03230596147477627, 0.2995918025927884, 0.628697001508304, 0.05298255876238857, 0.19403855582433088, 0.33362747196640286, 0.6481572229947362, 0.35724420898727005, 0.16801905844892773, 0.23875136726668902, 0.47300350453172413, 0.2830343267747334, 0.3534435714994158, 0.044831019027956893, 2.9559951424598694, 8.145650267601013, 11.629254698753357, 12.916044575827462, 9.523922732898168, 11.32898221697126, 12.038865770612444, 8.73100299494607, 9.995711496898107, 9.336731314659119, 9.056995102337428, 7.493374228477478, 7.395970906530108, 9.089433635984149, 7.28564350094114, 8.005155955042158, 11.622490627425057, 12.590654356139046, 11.061883040836879, 17.338988133839198, 4.490782294954572, 1.8709776954991477, 0.3750070886952536, 0.9600709229707718, 2.185121387243271, 2.761220851114818, 3.4440114242689948, 0.9973480084112712, 0.24826030273522648, 0.12294224011046545, 0.18848374246486596, 0.14349239239735262, 0.17274827110980237, 0.25176113631044117, 0.2768940734011786, 0.02205413533374667, 0.1397790280835969, 0.11913910561374255, 0.048420408208455355, 1.458617199744497, 6.9566337040492465, 31.601261820111954, 41.78994737352644, 47.03923845291138, 43.06648431505476, 46.00228929519653, 45.98233754294259, 32.94005114691598, 25.81330817086356, 34.47298356464931, 49.2204030581883, 65.53008678981236, 63.25532994951521, 78.12470422472272, 70.50132833208356, 72.40572534288678, 82.03980568477085, 63.76396587916783, 8.837790727615356, 0.3160866903407233, 0.03646624966391495, 0.009244612152022975, 0.1342787689396313, 0.042891399535749636, 0.060628047079912255, 0.049331938581807275, 0.04669137545196073, 0.060880726735506735, 0.09151624355997358, 0.01015712640115193, 0.08079299503671271, 0.06113776258592095, 0.03667669729994876, 0.018926582532003522, 0.006947806312902165, 0.012694780365563929, 0.0207828287301319, 0.07369093863027436, 0.03721986458237682, 0.013439742266200483, 0.03177973381908877, 0.05778014061174222, 0.028574520988123756, 0.011637449780079936, 0.028768866988165036, 0.03659831971994468, 0.06713732172335897, 0.09801131646547999, 0.023280836741573045, 0.034840866524193964, 0.03944114735350013, 0.07287603842892817, 0.037649777584842274, 0.020510591998962418, 0.05186963241015162, 0.010801700742116995, 0.019604337235380496, 0.05152519107131021, 0.02773971596200551, 0.04911995067128113, 0.04430179564016206, 0.01985893544874021, 0.0720103227400354, 0.09679348859935999, 0.10247447554554258, 0.10937508847564459, 0.1506858949682542, 0.18802429283303873, 0.07255659771284886, 0.1416455829249961, 0.15634145720728806, 0.09675699020070688, 0.1810776005898203, 0.11545052139886788, 0.23981474020651408, 0.30447999600853237, 0.09622557514480182, 0.0857991042679974, 0.12199396028050355, 0.25151086545416285, 0.11145327160401003, 0.10729087995631353, 0.22114175504871778, 0.15810425047363552, 0.1199841531259673, 0.09084724195833717, 0.19887880395565713, 0.09120113868266344, 0.09321274395499911, 0.18291416418339523, 0.1149002837815455, 0.12712532707623073, 0.10356144114796605, 0.16408850864640304, 0.12624956906906196, 0.10967335211379187, 0.1411738246679306, 0.1943949902696269, 0.16783771317984375, 0.11582337639161519, 0.26857479981013704, 4.293441295623779, 41.08062662397112, 84.86850765773228, 87.21885395050049, 91.57902921949113, 83.16811670575822, 67.79597078050885, 55.259395122528076, 35.57680218560355, 34.78966508592878, 39.67352608272007, 25.76713912827628, 39.52469219480242, 70.4260584967477, 66.74056720733643, 82.65907778058732, 61.126193455287385, 38.61551693507603, 12.041167361395699, 1.6247767465455192, 0.388017264860017, 0.2520532863480704, 0.7085142699735505, 1.3918777980974741, 0.23406499730689184, 0.6049418162022318, 1.505195643220629, 2.8751878099782124, 1.7788056071315492, 0.9893697393792016, 1.1231746737446104, 1.5424592665263583, 4.376892634800502, 9.736151116234915, 5.919097423553467, 12.000523005213056, 16.65022189276559, 19.598446777888707, 16.404304300035747, 19.63536603110177, 23.56389488492693, 17.83952420098441, 13.995606166975838, 15.718093258993965, 15.075113909585134, 12.700123224939619, 20.624468156269618, 17.211759669440134, 15.617168937410627, 15.330310821533203, 15.587255205426898, 23.401880264282227, 14.338528428758893, 26.473840406962804, 25.936371190207346, 7.124357572623661, 7.573253325053623, 7.2506936277662, 11.96810531616211, 5.729313892977578, 5.916425841195243, 4.515069288866861, 2.0897845029830933, 0.4091306690658842, 0.6107545271515846, 0.5412463769316673, 0.3852455850158419, 0.31421762491975513, 0.39156421167509897, 0.2934521734714508, 0.2540740179164069, 0.20544088897960527, 0.36236532990421566, 0.33965324291161125, 3.1707229231085097, 11.004747135298592, 46.278341225215364, 58.475518226623535, 76.88924503326416, 82.36471734728131, 58.06393820898873, 81.55060386657715, 54.64247499193464, 28.558157546179636, 29.502141543797084, 46.015831334250315, 69.10093975067139, 72.24978692190987, 90.27879197256905, 81.05402306147984, 79.6246257509504, 92.58693490709577, 81.8736881528582, 12.800871235983712, 0.4250499962696007, 0.246194489300251, 0.16788743622601032, 0.2937264101845877, 0.1728352592991931, 0.1634113306977919, 0.1744806660073144, 0.14115302078425884, 0.15186533810836927, 0.21028580543185982, 0.15463745221495628, 0.1490232398999589, 0.09769230322646243, 0.1323979648628405, 0.1784807520785502, 0.1666726821235248, 0.08332862611860037, 0.2641126721033028, 0.22920589947274753, 0.1223339606076479, 0.09861632542950766, 0.1344002267079694, 0.24982554731624468, 0.0828005223135863, 0.1725659216088908, 0.1714205952095134, 0.10963992069342307, 0.10941075906157494, 0.12101079017988273, 0.08551692869514227, 0.13170276502413408, 0.13762670143374375, 0.14129714162221976, 0.13521761713283403, 0.18186014145612717, 0.10064997630459921, 0.15357633201139315, 0.08771388259317194, 0.16277500055730343, 0.11329104298991816, 0.11529753889356341, 0.07618989489440407, 0.23718924394675664, 0.15864683421594755], [0.01207471131679735, 0.02504861893664513, 0.04154065005215151, 0.11315280505056892, 0.027598482290548936, 0.05097278553460326, 0.051921441951500516, 0.028134792976613556, 0.026406604996217147, 0.06466704713446753, 0.06870327876614672, 0.057287340983748436, 0.022551104559430053, 0.056813045005713186, 0.044775518256106546, 0.02198497056295829, 0.007430834612543029, 0.05692778527736664, 0.0493272532975035, 0.03197137585708073, 0.048949550172047954, 0.09617080379809652, 0.010997931373172572, 0.024935941411448375, 0.02058023852961404, 0.0324490746882345, 0.09316775029791252, 0.025632411806977222, 0.03770301883508052, 0.07012727949768305, 0.055240109230258634, 0.03377641810636435, 0.019098406258438314, 0.07214504586798803, 0.08627728146633931, 0.0261595300398767, 0.5417878478765488, 8.87156765801566, 57.438305037362234, 76.81855406079973, 69.47802543640137, 67.62536471230644, 59.37444836752755, 68.85147857666016, 55.91846997397286, 32.98713214056832, 29.456238269805908, 18.049137456076487, 20.556050981794083, 40.68417630876814, 56.72282470975603, 51.264111450740266, 42.516982555389404, 30.96330601828439, 10.378862959997994, 1.6182917973824908, 0.0782350537234119, 0.05195821854951126, 0.04324301977508834, 0.040899583737232854, 0.0215391374326178, 0.14743698787476334, 0.06430717930197716, 0.15305376505213125, 0.09379579552582332, 0.28618810325860977, 0.04478880736444678, 0.37616846923317226, 0.07385057077876159, 3.6794559104101996, 3.3547659388610294, 0.14798383281699248, 0.14683721720107965, 2.610369380031313, 8.622281057494027, 12.106243320873805, 19.43317345210484, 10.60354425225939, 7.768828613417489, 7.748640622411456, 10.14840771470751, 6.7418405669076105, 4.83502471446991, 6.064782908984593, 3.784382394381932, 4.785193971225193, 6.841995375497, 4.208448324884687, 5.639118458543505, 14.161490934235708, 7.910748175212315, 4.284335681370326, 10.636962481907435, 5.296022057533264, 1.1257056636469704, 1.0731570890971591, 1.4838163618530547, 3.363573649099895, 3.556371829339436, 3.2775056617600575, 1.6881432320390428, 0.4794994188206536, 0.28258589655160904, 0.10495841582970959, 0.12142712569662503, 0.24485088139772415, 0.28655380649226053, 0.17900949370648178, 0.09561181986438376, 0.1505521150039775, 0.19239575469068118, 0.0075517970503174835, 0.05022863957232662, 0.018929361132904887, 0.6789832317403385, 11.8087066922869, 30.881244318825857, 43.42760304042271, 35.15644659314837, 69.1205197743007, 86.15896184103829, 39.75825589043753, 21.444640466145106, 19.557150159563335, 20.91467704091753, 43.44439336231777, 35.79262713023594, 47.21485417229788, 62.585544449942454, 60.99185003553118, 68.79289831433977, 51.589950697762625, 25.48629641532898, 1.8815860748291016, 0.4133059935910361, 0.047738762106746435, 0.06701198273471423, 0.04105172825178929, 0.038849810870098214, 0.047268958030534644, 0.05533354350232652, 0.040647932062191625, 0.054256016322012456, 0.03673389440934573, 0.09333149436861277, 0.018947664615032927, 0.033272931551826854, 0.05361450556665659, 0.046096978775624714, 0.029621449631771872, 0.06329116810645376, 0.02203921434868659, 0.055970945728144476, 0.04008904651605657, 0.08812735469213553, 0.048651669906186204, 0.03854481277189084, 0.01434394870219486, 0.05011846244867359, 0.015346950685073222, 0.010447938876625682, 0.010901388562550502, 0.016433665229539787, 0.02470182647396411, 0.03689195914193988, 0.06914474721997976, 0.0341304776790951, 0.03314926854467817, 0.00799824171034353, 0.03280434883864863, 0.02178440409313355, 0.028284343791061213, 0.023683330143934915, 0.025896085426211357, 0.07050084695219994, 0.03912927569555385, 0.04125888838565775, 0.06227009503969124, 0.0373372986380543, 0.12622948443250998, 0.03150597886581506, 0.04795226315036416, 0.0850188432793532, 0.032461525805826695, 0.013724126470541316, 0.01700528009262468, 0.03588402929848858, 0.03973201156726905, 0.03131735970133117, 0.009244322078302503, 0.024395791913515756, 0.0776369318898235, 0.030117987987718413, 0.04891635963161077, 0.09095434871103082, 0.04358451287927372, 0.11723125513110842, 0.04843636056674378, 0.05625925525756819, 0.0028857453975693454, 0.045301681450967274, 0.044015986512282064, 0.026740742780800377, 0.03879334318584629, 0.03976254564310823, 0.07210402164076056, 0.07515039960188524, 0.020560323526816707, 0.0327900046083544, 0.031514491087624004, 0.1270746269396373, 0.03495016833767295, 0.2885718510619232, 13.77277570111411, 70.2065440586635, 87.47703511374337, 79.18149743761334, 76.93367876325334, 69.09418610164097, 74.90285233088902, 59.829110690525596, 37.14913088934762, 35.02616439546858, 19.979383502687725, 20.185698100498744, 35.36048739297049, 57.91289826801845, 57.06528752190726, 50.09594556263515, 36.936481271471294, 13.826674614633832, 2.2446340109620775, 0.08294159652931349, 0.036393900867551565, 0.1331324383084263, 0.03551802072407944, 0.07296847525451865, 0.059838883711823394, 0.13493959419429302, 0.0755330187135509, 0.2920680163162095, 0.09640316811523267, 0.0769867053521531, 0.5266561369810785, 0.043029179463961294, 5.698667126042502, 4.488885002476828, 0.21648297432277883, 0.1089871089373316, 1.1056845379727227, 5.517463317939213, 9.332523311887469, 4.7944250873156955, 10.296922854014806, 8.372897182192121, 11.252565928867885, 10.149343984467642, 12.540241701262337, 9.690956558500018, 6.879295476845332, 6.346312190805163, 5.194969628538404, 4.455188844885145, 6.86195581299918, 6.3923657195908685, 4.145944935934884, 4.476135492324829, 3.4483963889735083, 5.109176746436527, 2.3818652757576535, 0.6308344953826496, 0.6906308010220528, 0.219822601548263, 0.46640000173023766, 0.32219125277229715, 0.7513607708471162, 1.371499817286219, 0.4459483320159571, 0.19281924196652003, 0.3550750682396548, 0.24755036511591502, 0.3338211530021259, 0.19815406070223876, 0.16502438485622406, 0.15292446341897759, 0.15493551907794817, 0.20745309814810753, 0.029915713305984224, 0.060976461241287847, 0.06594694738409349, 0.7573925129004887, 11.668560658182416, 34.176034927368164, 46.1357398714338, 19.863166196005686, 58.21406446184431, 76.42660617828369, 27.983588423047745, 17.34070781299046, 24.02344526563372, 31.699047292981827, 55.20701960154942, 50.73751442773001, 53.55076013292585, 71.3401426587786, 69.40119920458112, 79.20324529920305, 66.53323296138218, 36.26699454443795, 3.4015855065413882, 0.34606995859316414, 0.044111246043550115, 0.06565441058150359, 0.026422596370269145, 0.03176538958879454, 0.1346370354294777, 0.06562226159232003, 0.008411611180885561, 0.014811191308711256, 0.03265507791989616, 0.13074246155364172, 0.028779055191470043, 0.019779926831168786, 0.05077513846169625, 0.05395484176863517, 0.07299859542399645, 0.015017218289098569, 0.05850552847342832, 0.05823168531060219, 0.03131992795637675, 0.06464968342334032, 0.04613928543403745, 0.06233243883720466, 0.07097856953207936, 0.03376357683113643, 0.028491295275411437, 0.019735004420259168, 0.008215025167113968, 0.01871310862978654, 0.04810324397736362, 0.05161526659503579, 0.013519377680495381, 0.012827805459632404, 0.023105886665039828, 0.03029601861323629, 0.02695550081054015, 0.031211182541613067, 0.03873991873115301, 0.028800079599022865, 0.031697251102221866, 0.045625084811555486, 0.045004591678402255, 0.13600033441824572, 0.25882826851946966, 0.0971434973180294, 0.2532822218324457, 0.12768171222082206, 0.12839443183371, 0.194478463647621, 0.11146129867328064, 0.0987953297527773, 0.10124079031603676, 0.1425651064408677, 0.14380355498620442, 0.21136627745415482, 0.11591676995158195, 0.11434327438473701, 0.2006607319095305, 0.18094611407390662, 0.12810217323047773, 0.13665699346789292, 0.2020160648971796, 0.19230108548487934, 0.1970412361302546, 0.22574956422405584, 0.12062257315431323, 0.060275629561926634, 0.1571655651288373, 0.16608758137694427, 0.14810197933443955, 0.10423625779471227, 0.208773296592491, 0.17142815408962114, 0.12305499905986444, 0.15267502037542208, 0.16616592503019742, 0.23313993694526808, 0.09855466016701289, 0.5513248475534576, 24.023964643478394, 88.08300835745675, 100.17363125937325, 86.03438064030239, 82.56104564666748, 76.26778425489152, 85.23877021244594, 73.99226311274937, 51.70269911629813, 43.81399931226458, 28.976939371653966, 33.73781204223633, 54.06818553379604, 75.59776946476528, 68.87661715916225, 58.50655582972935, 46.13908542905535, 17.086606979370117, 3.1921255460807254, 0.27895489281841684, 0.18466170398252352, 0.28387489595583504, 0.20956518767135485, 0.1895305455795356, 0.4292761023555483, 0.26132742155875477, 0.4026021850960595, 0.7139533524002347, 1.436212733387947, 0.3989274022834641, 0.5783679421458925, 0.179012994947178, 9.473922627312795, 5.388585524899619, 0.40968799058880123, 0.2612547640289579, 6.314902859074729, 21.865230560302734, 26.712834119796753, 38.55028377260481, 27.128925255366735, 20.66299418040684, 19.928098848887853, 25.19381720679147, 19.83795813151768, 17.73950140816825, 18.752712045397075, 14.964265823364258, 15.874309607914515, 16.79501714025225, 18.257194314684185, 15.06640260560172, 33.3898914200919, 21.479749713625225, 15.2881178855896, 22.590841361454554, 12.369408079556056, 4.657381423882075, 4.061289387089865, 7.709834064756121, 7.084109698023115, 7.3596735170909335, 8.863122991153173, 6.04766081060682, 1.5760963644300188, 0.5957621059247425, 0.6457662827202252, 0.6218130737543106, 1.1763597684247153, 1.2541096763951438, 0.500475324690342, 0.5286871822816985, 0.4943756748523031, 0.3935525364109448, 0.28579867844070705, 0.16298674419522285, 0.17119739790047916, 1.45388862490654, 17.72661771093096, 46.377884592328755, 60.32745633806501, 47.389799390520366, 81.94521985735211, 109.4786240713937, 58.44155543191092, 29.40374115535191, 30.987742832728795, 33.19011681420462, 57.84017147336687, 51.29340853009905, 63.8591423034668, 81.94078690665108, 80.09386539459229, 85.365234375, 81.79751505170549, 45.17441838128226, 5.236423449856894, 0.5638203141944749, 0.13655756094626018, 0.16127607598900795, 0.12255177034863404, 0.14646158021475586, 0.23795821411269052, 0.15090921441359179, 0.07580897212028503, 0.12468600725489003, 0.1010198796700154, 0.22062009732638085, 0.15216649909104618, 0.1685447466692754, 0.11385939749223845, 0.1497157255985907, 0.1947030858801944, 0.17430230629231247, 0.08096083745892559, 0.12282804266682693, 0.11622401060802595, 0.18881720171443053, 0.10292487352022103, 0.15174043338213647, 0.18951439644609178, 0.1680578435105937, 0.1799224354326725, 0.12052136287093163, 0.06596773091171469, 0.16114515944250993, 0.13878586994750158, 0.21566125484449522, 0.10980761383793183, 0.08173965316798006, 0.1668369011687381, 0.10275280382484198, 0.2582791436995779, 0.19892095455101558, 0.1545102268989597, 0.18527485536677496, 0.157246039382049, 0.1391316106809037, 0.11376701494944946], [0.06892492222998824, 0.04104188270866871, 0.03196544206834265, 0.03413342252107603, 0.04811295720615557, 0.05423479853197932, 0.04138804752645748, 0.03209299308114818, 0.022990269386874776, 0.059090697073510716, 0.027496189743812596, 0.0897713771888188, 0.002730438273699422, 0.041375243570655584, 0.060907807068101, 0.041448030022106, 0.05574163821126733, 0.043361559842846224, 0.008209128697801913, 0.026456677487918308, 0.0030281618403803024, 0.0064035202958621085, 0.06994187658918755, 0.10215054292763982, 0.03693484594779355, 0.04852748781974826, 0.042096723070634265, 0.02050694148056209, 0.02200550303262259, 0.02972469891288451, 0.0774876813271216, 0.030860413863722767, 0.02030090262581195, 0.05622140657422798, 0.05723826254584959, 9.88143881729671, 48.544676848820274, 72.43300397055489, 69.33489254542759, 64.66964272090367, 64.04924501691545, 55.02110317775181, 69.62524386814663, 58.248454570770264, 37.281719888959614, 36.94666385650635, 41.202199254717144, 56.35140527997698, 70.05403109959194, 56.44296864100865, 37.38832957404, 36.721966062273296, 17.021346024104528, 4.566143759659358, 0.16808239290756838, 0.0863775960834963, 0.0469378397267844, 0.04671898843454463, 0.10197956567364079, 0.06897879791046892, 0.11825116111763886, 0.06292248610407114, 0.095949268899858, 0.08087492135486432, 0.28060823838625637, 0.6037192046642303, 0.1072350229535784, 0.29822566732764244, 0.11267416644841433, 0.47476205016885487, 0.29780600698930876, 0.3273110166192055, 0.2442305918250765, 0.5786327879343713, 2.3208613949162618, 4.579609368528638, 6.275670289993286, 6.036992720195225, 7.29118686062949, 11.759949445724487, 5.091940437044416, 9.15654194355011, 8.03867667061942, 6.863346321242196, 3.9236512184143066, 3.581917315721512, 5.6690908159528455, 5.266875667231424, 6.133926170212882, 4.206423793520246, 10.720125470842634, 4.330021824155535, 7.725839240210397, 2.9530962237289975, 0.22763855143317155, 0.2063914622579302, 0.0639520679999675, 0.8255018496087619, 1.186493607504027, 3.985303887299129, 1.7222550873245512, 0.6981687822512218, 0.3288451571549688, 0.17016921378672123, 0.0855919678828546, 0.21261992518390926, 0.3106894056711878, 0.4941979529602187, 0.1359421568257468, 0.0789228303890143, 0.052965663240424225, 0.18710006028413773, 0.08214618385370288, 0.04234706178041441, 0.197781734966806, 0.008856054162606597, 2.1946250029972623, 19.224418299538748, 69.63774367741176, 67.31589889526367, 50.878149441310335, 46.04856429781233, 59.14427539280483, 30.414057867867605, 32.34882892881121, 27.90372061729431, 17.17060375213623, 46.77358797618321, 50.948340143476216, 56.964236395699636, 61.70166410718645, 74.83240454537528, 77.17402390071324, 56.96247155325753, 8.16289222240448, 0.3291366829403809, 0.019834431852879267, 0.02015116691057171, 0.01821432262659073, 0.024070654895954897, 0.017762598115950823, 0.018401335359417965, 0.037896771116980484, 0.060791648658258576, 0.03153032470228417, 0.003881504019123635, 0.029136493868593658, 0.03332150787381189, 0.04821903597829597, 0.05248441906379802, 0.0300589045509696, 0.02331856668128499, 0.043165032352719984, 0.03649379140032189, 0.02706060927760388, 0.11694157496094704, 0.0275640602090529, 0.013450154386061643, 0.07009388878941536, 0.006195321579330734, 0.0731039447709918, 0.06032058250691209, 0.06514432188123465, 0.04882160221625652, 0.03455102350562811, 0.01845426787622273, 0.06840333236115319, 0.018518094272751893, 0.05547563891325678, 0.06246678198554686, 0.028712093963154724, 0.05535532786910023, 0.03936306493622916, 0.07141133238162313, 0.04574037130389895, 0.022019353628690754, 0.06626053912831203, 0.011868727593017476, 0.03079307944114719, 0.022336706153250167, 0.029603882360139062, 0.027856206854007075, 0.042146860023162196, 0.018681066509868418, 0.04009763337671757, 0.01880762686154672, 0.05178081217621054, 0.026096679037436843, 0.012373166641087403, 0.08126912305929831, 0.01986095409042069, 0.04658286752445357, 0.0364226470036166, 0.01328091842255422, 0.012261129483314497, 0.01794614183849522, 0.02855905717504876, 0.013175607243153666, 0.07693255147231476, 0.02577640541962215, 0.0897972293730293, 0.039968457272542376, 0.00921819084656558, 0.04182519031954663, 0.012994775964346315, 0.04343359651310103, 0.031657329494399686, 0.004030748220559741, 0.06582390862916197, 0.06379590316542558, 0.021584046272827045, 12.43190278325762, 56.90034423555647, 85.51717063358852, 79.26975345611572, 73.29585211617606, 75.03915514264787, 60.40414360591343, 76.32308496747697, 72.65470014299665, 53.168859345572336, 38.579268183027, 33.08201674052647, 36.14158650806972, 49.649582862854004, 56.88983508518764, 43.414470945085796, 40.02997561863491, 22.049713918140956, 5.240932830742427, 0.248048301254, 0.13863041757472924, 0.05714440758207014, 0.03247630090585776, 0.15144384572548525, 0.1133294819987246, 0.21234396499182495, 0.28276530121053967, 0.1473922317049333, 0.40823288581201006, 0.6551018932035991, 0.9857363743441445, 0.9475135739360536, 1.4687700378043311, 0.6264329201408795, 0.9798335539443153, 0.42386508413723534, 0.23013269688401902, 0.49133002970899853, 0.5493078614984239, 1.716965228319168, 1.9556640769754137, 4.1596680624144415, 6.2813248208590915, 3.3068704860551015, 7.895600233759199, 7.536472167287554, 11.311206119401113, 7.320679358073643, 5.576887786388397, 2.1514295722757066, 1.5425871568066734, 1.154786263193403, 1.9489002227783203, 1.839325828211648, 1.6448483552251543, 1.2429306762559074, 0.2828900973711695, 2.086719044617244, 1.4958503161157881, 0.6962267607450485, 0.17321827874651977, 0.1931873879262379, 0.43469170747058733, 1.1884485483169556, 1.881649911403656, 0.8980585762432644, 0.35509357867496355, 0.18098989315330982, 0.05887816633496966, 0.27195021297250477, 1.5145230570009776, 1.1641446181706019, 2.6321033452238356, 0.8995540674243654, 0.4242283989276205, 0.20908326495970997, 0.1343597045966557, 0.05752265014286552, 0.07814046594181231, 0.10102885668831212, 0.02560224074737302, 2.071830140692847, 18.37876868247986, 58.98538398742676, 63.99489620753697, 58.273280484335764, 44.579093251909526, 46.618177618299214, 27.70186502592904, 36.542417662484304, 35.3421893119812, 28.615089348384313, 60.92392444610596, 60.15638474055699, 68.31854479653495, 70.29975414276123, 82.67788655417306, 88.67572443825858, 72.98650441850934, 14.17566352231162, 0.26140132759298595, 0.03477216824623091, 0.017124822695872614, 0.06358219177595206, 0.029197450061993938, 0.010982744911286448, 0.02628498607581215, 0.05511528932090316, 0.0911581331331815, 0.03416512028447219, 0.12184621606554304, 0.008789874097731496, 0.10510959343186446, 0.03894440543704799, 0.03382628703755992, 0.04202906295124974, 0.04383576421865395, 0.05919729492494038, 0.015349149138533642, 0.029645011760294437, 0.08302771619388036, 0.01974701788276434, 0.08023000096103974, 0.029607261464531933, 0.04009523814810174, 0.0667549129575491, 0.04235960450023413, 0.09417561228786196, 0.006320900599738317, 0.05181000614538789, 0.03728369437158108, 0.03929837340755122, 0.05883837025612593, 0.05439872580713459, 0.037504890002310276, 0.031599609913038354, 0.024256266453968625, 0.019648270681500435, 0.016916337722380246, 0.057812459234680445, 0.029579210826861005, 0.16215712656932219, 0.10257895636771407, 0.08352383385811533, 0.15987697749265603, 0.15743635488407953, 0.11425176715212208, 0.11701776087284088, 0.08778628227966172, 0.12657716577606543, 0.13487682970506804, 0.15107575404856885, 0.13097779106880936, 0.12016624478357178, 0.11698365770280361, 0.11396124559853758, 0.09025102002280098, 0.16806773655116558, 0.10063470248132944, 0.11833097040653229, 0.0901015048314418, 0.12063739235912051, 0.06501487775572709, 0.1962365885930402, 0.17674807219633035, 0.12202792774353709, 0.17951274955911295, 0.09809170250913926, 0.11896629631519318, 0.06704196041183812, 0.10480158603084938, 0.15324144783828939, 0.16167850153786795, 0.08827471214213542, 0.20053920628769056, 0.15942252187856606, 20.65050826753889, 76.36419745853969, 101.55234146118164, 88.32290186200822, 82.80733149392265, 85.00251061575753, 72.40695517403739, 84.22323540278843, 76.11127608163017, 57.76077093396868, 52.581354413713726, 56.16312994275774, 74.85780715942383, 87.44209957122803, 70.61547333853585, 53.04773834773472, 53.41787583487374, 29.865719931466238, 7.516776629856654, 0.5659882064376558, 0.3056312528039728, 0.17723374042127812, 0.19290618944380963, 0.5242521688342094, 0.4206636202122484, 0.2672622688114643, 0.2686792127788067, 0.17743959437523568, 0.36986056342720985, 1.3409152584416526, 1.5623403425727571, 0.5849160764898572, 1.67860389820167, 1.471021362713405, 1.4047394565173557, 1.0119291288512093, 0.9583141143832887, 0.636980014187949, 1.4082363545894623, 9.80438676902226, 14.36906315599169, 20.94711991718837, 20.90391254425049, 20.731288024357386, 28.48669879777091, 17.124226263591222, 20.164735385349818, 20.04588644845145, 16.151433297566005, 13.516389778682164, 12.312751599720546, 18.165040356772288, 17.4239559173584, 21.308403662272863, 14.51594546863011, 22.780865907669067, 13.804169399397713, 19.06056935446603, 8.237617492675781, 1.631577404482024, 0.48440593268190113, 0.6293488293886185, 2.116986700466701, 5.347314528056553, 7.351363471576145, 4.6486731597355435, 1.831791375364576, 1.1823446644204003, 0.22794322722724505, 0.4160134568810463, 0.9309009739330837, 1.0967664165156228, 1.967952617577144, 0.35231375641056467, 0.13328595007104532, 0.2603129031402724, 0.46878415665456225, 0.41270158173782484, 0.30371501562850817, 0.4277378906096731, 0.08792650832661561, 3.528539299964905, 27.2885879107884, 96.62126745496477, 77.86292389460972, 63.639238766261506, 66.14049993242536, 84.98811394827706, 48.899726322719026, 48.06068965366909, 40.10155596051897, 28.51197460719517, 63.12798336574009, 66.47675800323486, 77.88858359200614, 79.82590811593192, 91.48318576812744, 100.12636266435895, 85.47120829990932, 18.516304799488612, 0.4167495588106768, 0.14029915231679166, 0.11545466046248164, 0.20647555988814148, 0.1354917317096676, 0.11018883516745907, 0.17186746480209486, 0.08890047749238354, 0.1905234730137246, 0.11500906651573521, 0.2218926761831556, 0.15238650728549274, 0.1489041977162872, 0.1889112873801163, 0.10621956137142011, 0.13492200656660966, 0.1043492474460176, 0.20553682026054176, 0.17884679457971028, 0.28267654883010046, 0.170394541695714, 0.11091894563287497, 0.18968157390398638, 0.22637119729604038, 0.08618685988975422, 0.12278179371995585, 0.12912761606276035, 0.12175574020615645, 0.08331396976219756, 0.12886772357991763, 0.19909847288259439, 0.19335793091782502, 0.12096047002289977, 0.21307377011648246, 0.1251198761165142, 0.10335587217871632, 0.2025880699179002, 0.20891359049294675, 0.13931267096527986, 0.23440681610788616, 0.11492309612887246], [0.04666714835911989, 0.05041589827409812, 0.02742034988477826, 0.031273315993270705, 0.06691158669335501, 0.06710914894938469, 0.03458656856258001, 0.03752317312838776, 0.016574349287631254, 0.0761607586007033, 0.12026962637901306, 0.060860974581113884, 0.00564410220665325, 0.1265360601246357, 0.07511976374579327, 0.13850146877978528, 0.09024965616741351, 0.06808254814573697, 0.0576510289683938, 0.05212381162813731, 0.03125762826363955, 0.040090851419206174, 0.02110888176996793, 0.043397793612842045, 0.030657128164810792, 0.043337821295218806, 0.055316101759672165, 0.03436207525166018, 0.04626176439757858, 0.06120098847895861, 0.07162788004747458, 0.020707721688917706, 0.061983950036977015, 0.1812891542379345, 13.34290541921343, 68.95345728737968, 77.92172649928501, 63.92842973981585, 67.67191069466728, 61.43719482421875, 45.15454305921282, 42.97500433240618, 28.91852934019906, 19.043226650782994, 18.81302067211696, 31.246337413787842, 63.37089933667864, 62.32165881565639, 45.760624000004356, 38.36415890284947, 32.9230489049639, 14.850529023579188, 1.922844043799809, 0.013458968555953885, 0.021550136485270092, 0.046416487345205884, 0.09243215048419577, 0.15371328751955712, 0.12072872317263059, 0.18724564675773891, 0.06022401340305805, 0.1901603075010436, 0.22429676646632807, 0.1102061445957848, 0.1340522060969046, 0.2464223685009139, 0.19884274660476617, 0.45097711788756506, 0.41993894481233185, 0.8067915450249399, 0.20804060090865406, 0.23368078363793238, 0.05009412339755467, 0.3588563267673765, 1.967218062707356, 3.3126400964600697, 1.9443686945097787, 3.675085493496486, 3.522606841155461, 3.0369874707290103, 5.457007476261683, 8.087757876941136, 4.767279343945639, 2.5332500210830142, 2.3335008195468356, 5.489698316369738, 7.792029517037528, 12.03519799028124, 21.293044669287546, 16.150325059890747, 5.958051196166447, 0.7099000013300351, 1.8197653463908603, 0.33992747962474823, 0.1737016670938049, 0.29347654644932064, 0.26082324289849823, 0.2308005110493728, 0.41845645436218804, 0.32212600484490395, 0.3841712198087147, 0.20285492417003426, 0.2655731237360409, 0.5465740167668888, 0.22964417881199292, 1.8952436276844569, 0.7047765191112245, 0.1317132551755224, 0.38381797447800636, 0.9405609241553715, 0.1060714168207986, 0.03261616054390158, 0.025688467281205312, 0.046294144088668485, 0.03823044749775103, 0.12274485427354064, 0.037241353786417415, 0.058825308457016945, 4.046641715935298, 15.68494861466544, 33.6047123500279, 37.08828551428658, 37.04311874934605, 78.30400943756104, 73.57770579201835, 58.40876688276018, 15.96742936543056, 9.702596528189522, 37.59991611753191, 56.70533956800188, 61.44857597351074, 48.80526556287493, 59.40971047537667, 68.25983251844133, 67.70988259996686, 22.32770960671561, 0.5216021367481777, 0.1380324653748955, 0.037584858746933084, 0.13874793983995914, 0.049192282504269054, 0.05760069524071046, 0.020555249781214764, 0.10728800975318466, 0.06313621784959521, 0.06360634083726577, 0.05925800345305886, 0.03800791854571019, 0.08187659510544368, 0.05497581305514489, 0.04645079068307366, 0.10733304412237235, 0.09120228540684495, 0.0449736945863281, 0.08981216392878975, 0.11254478339105844, 0.020730839377003055, 0.03950785073850836, 0.07191441860049963, 0.028354176918842962, 0.020482154596330862, 0.0522820595651865, 0.07039542296635252, 0.07407266886106559, 0.04552617136921201, 0.09712193347513676, 0.023973894105958085, 0.043692888492452245, 0.025118138241980757, 0.043401030224881, 0.06794593869043247, 0.07823241422218935, 0.06144662494105952, 0.04105731598766787, 0.01510308011035834, 0.031010532951248542, 0.03494897411604013, 0.050573969792042456, 0.0241365457352783, 0.03063922162566866, 0.016086594567501118, 0.034164906545941315, 0.04182367040110486, 0.04565612778865865, 0.03901352101404752, 0.0274173168332449, 0.0640935425513557, 0.07750829522098814, 0.03372588421085051, 0.07331030762621335, 0.05775455305618899, 0.06389769698892321, 0.08285585005900689, 0.06347227588828121, 0.02667722342136715, 0.01447103831118771, 0.014756604862798537, 0.038902919806007824, 0.03237369962568794, 0.04643579166648643, 0.04667559272742697, 0.04167699148612363, 0.04007664628859077, 0.03680914733558893, 0.05496560788846441, 0.1154274647789342, 0.07874247578105756, 0.03731560926618321, 0.03428534311907632, 0.105189443432859, 18.46896324838911, 84.08258301871163, 89.69126619611467, 73.71723951612199, 75.27828434535435, 69.01458059038434, 56.34096213749477, 56.020605019160676, 44.5941812651498, 34.81774623053414, 28.652154513767787, 46.55192307063511, 59.29777499607631, 58.27648360388619, 45.88458333696638, 37.279413087027415, 32.8634854725429, 16.1069335596902, 1.5826587208679743, 0.03772925439157656, 0.13638362527957984, 0.050044885503926446, 0.125852748219456, 0.20052928610571794, 0.1438768096268177, 0.5848051767264093, 1.1445011922291346, 1.6550576473985399, 1.8892256191798618, 1.6987705017839159, 1.4291082003286906, 2.200684049299785, 2.721455442053931, 4.8041039279529025, 1.1644534873110908, 1.0787192306348254, 0.41248027075614246, 0.28754148206540514, 0.2520652285643986, 0.3698286994227341, 0.21083573092307362, 0.23876472083585604, 0.36198646309120314, 0.5432697683572769, 1.2607749530247279, 1.5296552564416612, 2.569850091423307, 4.518176002161844, 1.297032498887607, 0.9406677527087075, 1.557732166988509, 4.62625002009528, 8.449204904692513, 12.767451269286019, 21.683066163744243, 16.409588405064174, 7.117061529840742, 1.779322053704943, 1.0148153454065323, 0.9073615627629417, 0.37911830523184364, 0.5133275921855653, 0.504492849111557, 0.3053612501493522, 0.5262420134884971, 0.2053330833358424, 0.4912294979606356, 0.6547655026827539, 0.22228529011564596, 1.2263224188770567, 0.22595016631696904, 0.7511227950453758, 3.849436640739441, 2.2531998370374953, 3.2246624401637485, 2.118614533117839, 0.38633219099470545, 0.2568058270428862, 0.05040894329015698, 0.09662243670650891, 0.007816649624146521, 0.11876539566687175, 0.03770811802574566, 0.13346360410962785, 4.676497220993042, 20.4159631388528, 37.10686847141811, 40.402280943734304, 42.80457544326782, 68.38708877563477, 70.42707293374198, 57.10446841376168, 16.568695204598562, 23.20032344545637, 50.154035976954866, 68.42207990373883, 67.65681225912911, 58.11426401138306, 66.84524876730782, 76.95125075748989, 83.11745738983154, 34.33307463782174, 0.42670060055596487, 0.14782831259071827, 0.05095984587179763, 0.1289492156356573, 0.02590496575326792, 0.11225452646613121, 0.03006324717508895, 0.038896840132240734, 0.056002127804926465, 0.050041139990623505, 0.09123678891254322, 0.08520166096942765, 0.027452768591631736, 0.04430949701262372, 0.07044028091643538, 0.0621248274775488, 0.08183559123426676, 0.01706154252003346, 0.07838935258665256, 0.022398763269718205, 0.01868670174319829, 0.017734954599291086, 0.02594743186741003, 0.022248589899390936, 0.019707240463633622, 0.04647544525297625, 0.013191016773427171, 0.07268064748495817, 0.03161262421469603, 0.04734299637909446, 0.0757202740226473, 0.05929410830140114, 0.05432572222447821, 0.05898490667875324, 0.06757564177470547, 0.06009581099663462, 0.023630752161677395, 0.052725044544786215, 0.06119512593639748, 0.056404638170663796, 0.19846548113439763, 0.13325743802956172, 0.14690291296158517, 0.11365667837006704, 0.14596439046519144, 0.2516840004495212, 0.18175069375761918, 0.21915413598929132, 0.08026588189282588, 0.12207178824714252, 0.15565393838499272, 0.2044969924858638, 0.08230257260480098, 0.13653974261667046, 0.12258358007030827, 0.17500415577420167, 0.14231009941015924, 0.12585747082318577, 0.11016852661435093, 0.15943645898784908, 0.10674822836049966, 0.1610665443752493, 0.14552058785089425, 0.16733227244445256, 0.08811264405293123, 0.161201342142054, 0.14975075157625334, 0.18013610611004488, 0.1964678197566952, 0.18677956105342933, 0.16268004636679376, 0.11775189505091735, 0.14764928791139806, 0.31572636110442026, 32.93092468806675, 100.70455006190709, 95.40012850080217, 81.89795126233781, 85.28313446044922, 80.25397968292236, 63.13737733023507, 60.292882101876394, 44.996541023254395, 32.15142018454415, 34.202583994184224, 47.20461252757481, 81.25471482958112, 79.65685149601528, 64.75989287240165, 55.3031131880624, 47.092173303876606, 23.994002274104528, 3.3465787896088193, 0.2775119202477591, 0.26266402697988916, 0.19918494538537093, 0.3655333013406822, 0.5718145966529846, 0.2490387452500207, 0.910308413207531, 0.9195056025471006, 0.9998039794819695, 1.4205836291824068, 0.5632835115705217, 1.2114087619951792, 1.515454875571387, 1.1613343975373676, 4.666946053504944, 2.7617439201899936, 1.476912458028112, 0.40087341357554707, 0.3923971269811903, 0.3242399128420012, 0.8932456459317888, 5.178760349750519, 5.844103344849177, 6.068349071911403, 11.518428325653076, 14.15253210067749, 19.625193868364605, 17.982670988355363, 19.586987461362565, 16.42656285422189, 11.969732931682042, 8.189178126198904, 9.477391515459333, 9.183536563600812, 14.393368823187691, 23.747276953288488, 17.578006165368215, 6.53174397775105, 2.325116732290813, 3.998970125402723, 3.1953508130141666, 0.4327450176434857, 1.072925410100392, 0.6034974051373345, 0.6887009388634137, 1.0165507665702274, 0.823467167360442, 1.077340990304947, 1.0821201567138945, 0.5196498557925224, 1.804965683392116, 1.0131091283900397, 5.114444349493299, 4.269887336662837, 0.6989241274339812, 1.388579140816416, 2.232978407825742, 0.2622302531131676, 0.25006330598677906, 0.15814655034669808, 0.2914205310600144, 0.13583543683801377, 0.34148330613970757, 0.13067758003515856, 0.28054828303200857, 6.219630462782724, 27.642173051834106, 52.819153036390034, 53.367664677756174, 51.448304721287315, 90.19464928763253, 87.60297816140312, 70.36529650006975, 25.839852026530675, 19.246400662830897, 55.543284620557515, 72.85969979422433, 75.88678673335484, 66.63123730250767, 76.55306339263916, 83.68642452784947, 93.67125688280377, 40.11162737437657, 0.8828271478414536, 0.27387404974017826, 0.19271325479660714, 0.3166894465684891, 0.10595375206321478, 0.145951349022133, 0.10070613186274256, 0.15642224358660833, 0.10776277392038278, 0.1314646942274911, 0.16571738624147006, 0.20732934693140642, 0.21839018698249543, 0.19704153468566282, 0.13160734942981175, 0.174282275938562, 0.154331256502441, 0.07083799064691577, 0.19271976873278618, 0.1427438189940793, 0.11009070543306214, 0.15015884967786924, 0.16082954566393579, 0.2636463828384876, 0.1600897932159049, 0.21588910690375737, 0.10002864178802286, 0.244923647493124, 0.11726526330624308, 0.22706010032977375, 0.22607213977192128, 0.08327124241207327, 0.09717892363135304, 0.13076102627175196, 0.20505933516791888, 0.12155182686235223, 0.11117472619350467, 0.0977922242933086, 0.1822622548788786, 0.13568872399628162], [0.056901288484888415, 0.052387093393398185, 0.02448039505231593, 0.0430902713643653, 0.10349548754415341, 0.042271920812449286, 0.11167319837425436, 0.051251615929816446, 0.03280906804970332, 0.1850564078028713, 0.13279511140925543, 0.11067315989306994, 0.07829766893493277, 0.04291574197954365, 0.1016535431678806, 0.3954518102109432, 0.16697855213923113, 0.17893296852707863, 0.15165002537625177, 0.017919974135501043, 0.04205315772976194, 0.02796065035675253, 0.09011664973305804, 0.1956636064818927, 0.045264738611876965, 0.03969394914539797, 0.046311036217957735, 0.010966867191850074, 0.092080017950918, 0.06187503159578357, 0.08281846277947937, 0.072715571682368, 0.23364243283867836, 21.763576677867345, 84.91936152321952, 68.412581716265, 73.55440153394426, 74.96118245806012, 64.81444317953927, 52.265666484832764, 33.05948373249599, 17.845284257616314, 12.952532172203064, 26.607634919030325, 34.410943099430625, 22.6226258959089, 39.12000479016985, 37.941982882363455, 35.950010776519775, 25.574305772781372, 4.83986804315022, 0.39339403063058853, 0.05999165587127209, 0.06921338782246624, 0.1583142163498061, 0.31227022941623417, 0.051830463976200135, 0.20672508435589926, 0.14975399497364247, 0.5725248328277043, 1.1892222953694207, 1.5210049663271223, 1.2498318659407752, 2.9178523549011777, 1.3248653539589472, 2.956158207995551, 3.2931323775223325, 3.6618222509111678, 1.0593547097274234, 0.2137304563075304, 3.0860096173627034, 2.6190572338444844, 1.1135686806270053, 1.1405942418745585, 1.4686425817864281, 1.1180706790515353, 0.6321985679013389, 2.276280232838222, 1.201665650521006, 3.7493773698806763, 4.767894693783351, 8.386891722679138, 5.2409827709198, 7.922464575086321, 17.533275399889263, 48.29792199816023, 65.18592861720494, 71.95821271623883, 71.61834853036063, 74.94204017094204, 66.22284303392682, 46.57420941761562, 12.837291955947876, 2.775590160063335, 2.463425402130399, 3.2554794379643033, 3.366011598280498, 3.3944030233791898, 2.996377855539322, 1.6768726025308882, 0.28437307636652676, 0.2861593062324183, 0.15200936395142758, 1.719222524336406, 0.9907693671328681, 2.4151755911963324, 3.0328928104468753, 8.144185066223145, 8.863899452345711, 3.383453748055867, 0.45411637372204233, 0.42278697341680527, 0.2672538821186338, 0.16240073421171733, 0.23190180052603993, 0.18605069230709756, 0.5416016578674316, 0.25724948037947926, 0.40924295304077013, 1.8002088814973831, 10.39849509511675, 30.995920862470353, 65.2154793058123, 102.62923581259591, 65.65581444331578, 30.050392627716064, 34.77368770326887, 28.79185673168727, 14.874074731554304, 25.489028794424875, 37.28877578462873, 49.95975392205374, 56.97877550125122, 59.1959421975272, 59.67702851976667, 69.76096997942243, 20.137706892830984, 0.22145890231643403, 0.19610115300331796, 0.07069716748914548, 0.12865625135600567, 0.07330594464604344, 0.14040163824600832, 0.21636005091880048, 0.1801412222640855, 0.11227042454161815, 0.08757394831627607, 0.0869674262191568, 0.1954050167862858, 0.10718287075204508, 0.31383791672331945, 0.40162878589970724, 0.3413262388535908, 0.4013008363544941, 0.23238573170134, 0.2368734808904784, 0.19928884266742639, 0.1083658490596073, 0.019440917165151665, 0.02770440499963505, 0.03271210878821356, 0.01487078025404896, 0.20256430762154715, 0.29119357466697693, 0.3450480305722782, 0.24303493169801577, 0.20484945071595057, 0.047016556574297805, 0.09747437134917293, 0.05274799938446709, 0.048025497434926886, 0.07517936626183135, 0.14227530413440295, 0.14453395722167833, 0.11199637103293623, 0.11851653616343226, 0.06693659070879221, 0.020596857548558285, 0.061529569061739106, 0.04010974183412535, 0.08929193791534219, 0.12866077039922985, 0.10548274019466979, 0.02637451877152281, 0.025728970732805983, 0.04892408136012299, 0.07275361714086362, 0.0038898877433634228, 0.024853409500792623, 0.04478336551359721, 0.08448054787835904, 0.2803227108504091, 0.25412916924272266, 0.3062435899462019, 0.1979140221540417, 0.09668113677097218, 0.04597407572769693, 0.011533206445164979, 0.09926052657621247, 0.06190296009715114, 0.02185999119787344, 0.0296150578318962, 0.13907027111521789, 0.03085244107725365, 0.07800555282405444, 0.005178383335338107, 0.07966336993766682, 0.10171672834881715, 0.14691938779183797, 26.417561735425675, 94.51094668252128, 76.18718515123639, 80.41922174181256, 80.39627879006522, 74.32535975319999, 62.95322227478027, 41.82084948675973, 28.272617850984844, 18.28614398411342, 26.37403474535261, 37.19916139330183, 25.91937415940421, 50.30809838431222, 41.59806244713919, 36.55724164417812, 27.87910314968654, 5.955012662070138, 0.3215252027979919, 0.11542025873703615, 0.1186947873128312, 0.1701800296349185, 0.31366803869605064, 0.2996534949966839, 0.5858471351010459, 0.7374783786279815, 1.3695673495531082, 3.0698587468692233, 4.338011818272727, 5.169230895383017, 7.275278959955488, 5.336343322481428, 4.56977983883449, 7.377083965710231, 6.054847419261932, 1.8406438146318709, 0.9366574479000909, 4.663738591330392, 3.5749732426234653, 1.9197794539587838, 1.4063844425337655, 2.19216707774571, 1.4202989701713835, 1.5582336315086909, 1.2055296088968004, 1.164143749645778, 0.6692589563982827, 0.4511571196573121, 1.8169255959136146, 3.559004762342998, 8.578781860215322, 20.769249507359095, 50.82289041791643, 68.83916636875698, 78.66400255475725, 80.3959105355399, 85.86359391893659, 69.8070295878819, 47.7101217678615, 15.829660483769008, 4.735510008675711, 4.1748833145414075, 5.5919957756996155, 4.615238428115845, 4.208874770573207, 3.761691314833505, 2.474909254482814, 1.2149494120052882, 1.0379736913102013, 0.6885779883180345, 2.206274309328624, 1.7997916638851166, 4.803172435079302, 5.6175603696278165, 3.082766111407961, 9.539977414267403, 6.773151755332947, 3.365857652255467, 1.3593922555446625, 0.5972636224968093, 0.40327086778623716, 0.26917112352592604, 0.33522615475314005, 0.5873969633664403, 0.18990820460021496, 0.14400235217596802, 1.4461985975503922, 10.851601021630422, 31.894718987601145, 56.31110920224871, 94.71893405914307, 58.36087989807129, 28.723642792020524, 24.264592920030864, 21.48602393695286, 26.241987705230713, 44.66747086388724, 50.187640939440044, 57.132386275700156, 66.24882234845842, 68.22379221235002, 67.40496785300118, 82.84247548239571, 33.27935947690691, 0.13828355047319615, 0.1980677374771663, 0.12261556621108737, 0.07127260589706046, 0.12063271046749183, 0.07810198622090475, 0.37402134016156197, 0.09544827935418912, 0.06561372562178544, 0.062113204172679355, 0.12398627480225903, 0.11606853109385286, 0.15249554786298955, 0.19190438677157673, 0.27905526171837536, 0.19586350289838655, 0.28838058561086655, 0.26440745485680445, 0.211152118231569, 0.262855590986354, 0.029955794369535785, 0.014070344722962804, 0.04211515547441585, 0.008717229290466224, 0.04083598804261003, 0.20617125050297805, 0.2678675763309002, 0.43309047339218004, 0.2185377547783511, 0.18500150074916227, 0.1419859089489494, 0.1363015225423234, 0.03324897248031838, 0.035799918097576926, 0.11100254114717245, 0.11025385917829615, 0.13991409726440907, 0.13183134741016797, 0.09507007072014467, 0.21869649126061372, 0.17694817217332975, 0.11205735097506217, 0.29670433753303116, 0.2503327929547855, 0.1951963265559503, 0.22537973549749168, 0.12769570361290658, 0.15489088504442147, 0.19738705828785896, 0.231089784098523, 0.16114939350102628, 0.22541434078344277, 0.12577017050768646, 0.2753734492829868, 0.3882892759782927, 0.33312307617494036, 0.45840903052261894, 0.28542290574737955, 0.17833990177937917, 0.15879710258117744, 0.06005829479545355, 0.17109004008982862, 0.16049840700413498, 0.19545524194836617, 0.1439984031021595, 0.2312794482069356, 0.10725172848573752, 0.15889251817549976, 0.21659467475754873, 0.14097927510738373, 0.21231089319501603, 0.2707299627363682, 39.410467284066335, 107.5153341293335, 83.68175533839634, 90.5709776197161, 95.28153664725167, 81.97594479152134, 69.47082015446254, 50.26241397857666, 30.36560113089425, 25.985828467777797, 40.815879413059776, 53.76870775222778, 34.49625308173043, 55.136012486049104, 52.82998180389404, 51.46083927154541, 38.284320626940044, 8.598600728171212, 0.8321254370468003, 0.27658721272434506, 0.23884174813117298, 0.43416264014584677, 0.5033886826464108, 0.4693479378308569, 0.9092037039143699, 0.6786899960466793, 1.2539884086166109, 4.195558113711221, 4.795523771217891, 4.069243337426867, 6.329009873526437, 7.112991188253675, 7.021618902683258, 11.546703151294164, 13.574792861938477, 2.413036414555141, 1.723993874021939, 6.958358594349452, 6.573329814842769, 2.6369998710496083, 3.735104032925197, 4.035107272011893, 2.0297359994479587, 3.7780656133379256, 3.67254809822355, 4.013120566095624, 6.582363775798252, 13.650218163217817, 19.2311806338174, 13.725988268852234, 13.56685107094901, 19.54142986025129, 46.76539952414376, 63.07352338518415, 69.41261509486607, 70.99408762795585, 78.4911869594029, 64.72873714991978, 48.18931123188564, 17.072307586669922, 4.661056152411869, 4.886625511305673, 6.630801405225482, 6.478457808494568, 5.998369421277728, 5.293749562331608, 4.008409687450953, 1.1829159366233009, 1.2251083297388894, 0.7480921862380845, 3.1420529186725616, 2.4074930548667908, 8.382299831935338, 12.966855015073504, 14.103711451802935, 18.43912247249058, 9.509227292878286, 2.3380584035600935, 1.0123230048588343, 0.4750389467392649, 0.38665034249424934, 0.40141732724649565, 0.7404981308749744, 0.9574548176356724, 0.3980965497238295, 0.7099743144852775, 2.4602435614381517, 16.533299343926565, 45.707584926060264, 83.18716866629464, 110.59066935947963, 74.07805946895054, 42.30529873711722, 50.80021844591413, 40.52393000466483, 26.86034437588283, 39.42078535897391, 49.99327898025513, 65.699601990836, 74.29579516819545, 80.86616461617606, 75.71551363808769, 95.62840461730957, 44.29744107382638, 0.6436478963920048, 0.46013033815792626, 0.3006853296288422, 0.313463311110224, 0.19416291772254876, 0.2272459375006812, 0.4766482689550945, 0.2788966473724161, 0.15782284843070166, 0.1751950548163482, 0.19323829162333692, 0.2581837416759559, 0.22579092771879264, 0.4881731591054371, 0.4137081748672894, 0.39857087284326553, 0.5810231853808675, 0.4894874542951584, 0.33417464260544094, 0.45214142969676424, 0.1591616387345961, 0.14485422575048038, 0.11982716726405279, 0.12396317747022424, 0.0925684410280415, 0.3198595621756145, 0.3574702154312815, 0.48899478358881815, 0.24766582463468823, 0.2729403312717165, 0.13720530404576234, 0.23981444165110588, 0.12217088150126593, 0.09330830204167537, 0.22709579127175467, 0.29135427890079363, 0.24426747698869022, 0.3619327502591269, 0.2183680667408875], [0.047591414834771834, 0.08914388157427311, 0.11320077747638736, 0.018516280887914554, 0.05775982527328389, 0.14256829555545533, 0.15582133297409329, 0.14330302684434823, 0.19946743308433465, 0.34675017637865885, 0.3654743773596627, 0.15806584539158003, 0.02950489427894354, 0.052709947140621285, 0.053114947729877064, 0.095613210861172, 0.029637999100876705, 0.04591438500210643, 0.04904248911355223, 0.07907828276178666, 0.02376740741809564, 0.1413984876126051, 0.2586894402546542, 0.4815929979085922, 0.33232270340834347, 0.1113456559500524, 0.12719962666077272, 0.1265889722853899, 0.2673763169773987, 0.1004560442109193, 0.0833444291991847, 0.10779854628656592, 20.394345555986675, 78.00910009656633, 76.26979228428432, 79.50514452798026, 68.4683062689645, 51.647481782095774, 34.41639396122524, 26.684912783758982, 21.232895851135254, 24.402439968926565, 41.501218455178396, 44.552912439618794, 30.695001329694474, 48.12489448274885, 35.76148183005196, 33.051569734300884, 12.53972840309143, 1.1050391154629844, 0.05843636539897748, 0.06843797835920538, 0.2746217410479273, 0.12522743748767035, 0.1674770853881325, 0.1672621119235243, 0.18737451412848063, 0.3671794001545225, 0.23998879800949777, 0.45441251354558126, 5.492949639047895, 5.654240344251905, 7.086688348225184, 9.901941214288984, 3.0805333512169972, 4.359519098486219, 8.22932481765747, 9.110630852835518, 5.047130635806492, 4.347367133413043, 6.490091264247894, 13.020601936749049, 17.259948900767736, 15.991680315562657, 17.4870160307203, 18.5749580178942, 12.996807830674307, 14.90847178867885, 12.951234596116201, 15.330845832824707, 17.116845539637975, 20.75587248802185, 21.96635464259556, 41.73929500579834, 75.154967716762, 83.37707683018276, 72.90804536002022, 69.49151188986642, 65.62545081547329, 72.91034521375383, 83.94174998147147, 78.32834897722516, 48.069725785936626, 30.850036484854563, 28.49998722757612, 27.68076855795724, 28.319356645856583, 29.93631362915039, 29.15325164794922, 25.5976117679051, 14.046611155782427, 10.321040051324026, 6.906159818172455, 5.040152907371521, 2.756331490618842, 1.0865645068032401, 3.8875609721456255, 8.180271404130117, 9.226642319134303, 2.844777498926435, 0.9339315827403749, 0.14659914640443666, 0.29807071707078386, 0.2548980037016528, 0.263194668505873, 0.6345961306776319, 0.14587646589747497, 0.34104003278272493, 0.15125133176999433, 0.025766982264550667, 0.3256622850894928, 4.096730845315116, 23.091429540089198, 30.657984801701136, 46.215178625924246, 60.84461075919015, 45.44361938749041, 37.584602287837434, 24.59229949542454, 12.469396131379263, 13.671180878366743, 22.121831008366176, 34.51471791948591, 40.98163216454642, 57.01387085233416, 60.404977389744346, 56.12633923121861, 30.712750502995082, 0.8302230419857162, 0.29580899700522423, 0.14133239830178873, 0.21915602231664316, 0.13340808637440205, 0.12065457286579268, 0.05724240160946335, 0.09042062663606235, 0.0955043670588306, 0.04747858124652079, 0.2072630404893841, 0.1237697135657072, 0.12668965331145696, 0.22239424926894052, 0.24968514485018595, 0.048290896229445934, 0.07122044012482677, 0.03809541902904, 0.03939653706869908, 0.12841743417084217, 0.06209642400166818, 0.20900637337139674, 0.03775999881327152, 0.06495528881038938, 0.12251487161431994, 0.18317299815160887, 0.13944095479590551, 0.20448131832693303, 0.11309554348034517, 0.2233293383781399, 0.15176267576004776, 0.2633208488779408, 0.0990034228722964, 0.04605259580005493, 0.12018945068120956, 0.09257751304124083, 0.0522547485306859, 0.13213936159653322, 0.020760635546009456, 0.06880993768572807, 0.09035045254443373, 0.09710064104625157, 0.021962081880441735, 0.1745689298425402, 0.06852814887783357, 0.10371790453791618, 0.0778970890013235, 0.1999770535954407, 0.20714545037065232, 0.06669427906828267, 0.03551792912185192, 0.029665476376456872, 0.005079992364958993, 0.04414756123774818, 0.04795916045882872, 0.046777749567159584, 0.029261693757559572, 0.1176934324737106, 0.046524228528141975, 0.04818577079900673, 0.20109648709850653, 0.3637738600373268, 0.16100426843123777, 0.06028808067951884, 0.07537868592355933, 0.035906885750591755, 0.07560729794204235, 0.08789009135216475, 0.06294274037437779, 0.042922415371452055, 27.16488218307495, 90.32838821411133, 86.57321344103131, 87.09150736672538, 76.31677600315639, 66.53688771384103, 52.987758023398264, 38.92470135007586, 28.062537329537527, 29.471475669315883, 38.95554787772042, 41.971350942339214, 34.981932163238525, 40.118665899549214, 39.70326437268938, 38.405934946877615, 16.520370483398438, 1.3244805974619729, 0.052829488047531674, 0.052305750615362606, 0.20395579295498983, 0.2874287638281073, 0.4339291426752295, 0.3749509874199118, 1.0760720755372728, 1.3296547255345752, 1.8140804171562195, 2.9956118166446686, 5.842464438506535, 7.9457497256142755, 5.232930243015289, 3.784615159034729, 6.780684905392783, 5.726282741342272, 7.457923650741577, 7.214694576604026, 6.198805408818381, 6.207392079489572, 7.634061353547232, 15.377091305596487, 18.76832812173026, 19.530625411442347, 20.83865680013384, 21.885415077209473, 17.904566287994385, 18.66018635886056, 15.580470289502825, 17.57689619064331, 20.527658905301774, 23.67550901004246, 25.50520941189357, 47.94809409550258, 82.55991309029716, 96.26394244602749, 86.36172417231968, 83.70589338030133, 78.4244773047311, 88.51974432809013, 95.12947532108852, 88.58398737226213, 55.95534406389509, 34.8353842326573, 32.24625267301287, 32.33029808316912, 33.195095198495046, 34.001308577401296, 33.007219382694785, 27.164668525968278, 15.62473031452724, 11.242445877620153, 7.994141323225839, 6.1184108427592685, 3.45741753918784, 2.412508351462228, 1.5493658844913756, 5.396933785506657, 5.482915137495313, 4.039091629641397, 4.729445534093039, 1.9433075743062156, 1.6571163769279207, 1.0451213249138422, 1.308735436626843, 0.7632022382957595, 1.3463063005890166, 1.2011384559529168, 0.15850557679576532, 0.04278878468487944, 0.0787183063636933, 3.4917079848902564, 22.019746337618145, 37.18359048025948, 44.96341896057129, 43.27542706898281, 40.967996324811665, 30.612317766462052, 25.71555049078805, 17.475445543016704, 29.058709246771677, 40.857763154166086, 49.68451145717076, 50.78783328192574, 65.43383339473179, 69.23645046779087, 68.81951686314174, 44.99843788146973, 2.5981303453445435, 0.35489598927753313, 0.0885045930211033, 0.2096620417599167, 0.18855504292462552, 0.24943813096199716, 0.07896401746464626, 0.07201867550611496, 0.11392616533807345, 0.30860524464930805, 0.33551496639847755, 0.15871214999684266, 0.06930999085307121, 0.34719993653041975, 0.2731577610330922, 0.12389780740652766, 0.1135488184435027, 0.05850195259388004, 0.04302935927574124, 0.12918635005397455, 0.1531214557055916, 0.05789272992738655, 0.06176840660295316, 0.053605406412056515, 0.14361622503825597, 0.16706011204847268, 0.20525589319212095, 0.15226255250828608, 0.1282041570437806, 0.1337299562458481, 0.24223575315305165, 0.22789070861680166, 0.1587972790002823, 0.06618890618639332, 0.04293076474485653, 0.04370915976219943, 0.07865062249558312, 0.14258858375251293, 0.15667164591806276, 0.26097317199621883, 0.32149409875273705, 0.2594100987272603, 0.10795943372483764, 0.3087803881083216, 0.38051264041236466, 0.2603097547377859, 0.30542945648942676, 0.34129377773829866, 0.385303151926824, 0.24364102631807327, 0.16060242642249378, 0.11872775054403714, 0.1459441158388342, 0.2446845317525523, 0.19780145319444792, 0.21611923884068215, 0.0909669626770275, 0.17851481453648635, 0.16884659975767136, 0.18631699016051634, 0.4158995715635163, 0.5145916757839066, 0.4193344786763191, 0.2767097018659115, 0.2502511516213417, 0.17319385148584843, 0.3817388888980661, 0.15996551274188928, 0.21745370009115764, 0.1239275543817452, 41.59608221054077, 105.53412478310722, 93.92851393563407, 99.93143790108817, 86.230820110866, 68.74121066502163, 51.287419182913645, 41.6858286176409, 37.059665884290425, 39.61008555548531, 59.631761005946565, 65.69086810520717, 47.141984939575195, 70.18746430533272, 53.52198416846139, 50.02294084003994, 21.13535530226571, 2.222359389066696, 0.29451904765197207, 0.2047755175403186, 0.5475368308169501, 0.5284838931901115, 0.6691252035754067, 0.4051298366061279, 1.0296476866517748, 0.9042039322001594, 1.8302262936319624, 2.4290828449385504, 13.104360733713422, 11.807084287915911, 17.122046266283306, 18.656095606940134, 8.185060450008937, 12.296118480818611, 21.719405242374965, 23.759321655545914, 8.092362795557294, 8.00136831828526, 10.622166293007986, 20.008565936769756, 23.79523515701294, 22.472793204443796, 23.448902198246547, 26.091404608317784, 19.387984105518886, 19.583396979740687, 15.645844152995519, 18.296255350112915, 19.554039103644236, 27.24994203022548, 27.729459796633037, 48.20220708847046, 82.33753599439348, 90.98811272212437, 83.93871361868722, 85.2470177241734, 80.34021377563477, 89.67466000148228, 98.31792722429547, 90.0388011932373, 64.09932763235909, 40.75374514716012, 39.156323024204795, 34.89250884737287, 36.491782665252686, 39.26183489390782, 38.788207462855745, 32.86477436338152, 22.078262329101562, 16.432208265577042, 11.146612848554339, 11.233281203678676, 7.131561551775251, 4.502066603728703, 12.044433883258275, 19.557521888187953, 18.46206021308899, 10.514272928237915, 5.702303205217634, 2.294629773923329, 1.3272419635738646, 0.8154454720871789, 1.4344661299671446, 1.644924025450434, 2.540285940681185, 1.3353836238384247, 0.39079825420464787, 0.1812097384993519, 0.47046730348042076, 6.402091026306152, 32.989313874925884, 42.808094705854145, 62.184466634477886, 81.25215094430106, 64.42802606310163, 55.856947149549214, 36.43339000429426, 19.92422522817339, 25.446538822991506, 35.818432739802766, 49.9723926952907, 59.54417201450893, 77.06738294873918, 79.27843870435441, 82.88843781607491, 56.95382104601179, 3.998260974884033, 0.5602766786302839, 0.24175760309611047, 0.39062973324741634, 0.3500886229532105, 0.23647387804729597, 0.21665517293981143, 0.15183578112295695, 0.2444900364748069, 0.41817934066057205, 0.5599487562264714, 0.3404357023537159, 0.4111577517219952, 0.6482031462447984, 0.7391690707632473, 0.45881647723061697, 0.44365140955363, 0.24407474590199335, 0.22451843028622015, 0.23016111393060001, 0.35599480888673235, 0.2811134212783405, 0.12045688847345964, 0.2712032544825758, 0.3905466805611338, 0.540620604796069, 0.37839946523308754, 0.5031884876745087, 0.32809312322310036, 0.40701999089547564, 0.5445673444441387, 0.5093669018575123, 0.20843644466783318, 0.17794200884444372, 0.26431346418602125, 0.2798093312552997, 0.29723223777753965, 0.242388803511858], [0.10680505566831146, 0.022569418219583373, 0.009624820768034883, 0.08099869292761598, 0.08597058363791023, 0.1072371331974864, 0.07147093489766121, 0.13912827228861196, 0.1750147680618933, 0.08026710325585944, 0.0494912178920848, 0.03425507367189441, 0.04450315429962107, 0.018347973669213907, 0.056821411342493126, 0.02469248983210751, 0.04225575132295489, 0.014928822139544147, 0.075160869397223, 0.06409055021192346, 0.063312535174191, 0.25987057973231587, 0.20644379087856837, 0.2967730595597199, 0.09401796146162919, 0.0635231388732791, 0.10610591354114668, 0.3193969369999, 0.17943070110465797, 0.2773681522480079, 0.0525069192850164, 19.718876429966517, 78.59403419494629, 66.68751771109444, 74.86998040335519, 76.64924035753522, 62.47228186471121, 26.31406831741333, 14.129864471299307, 26.789889642170497, 27.7552775655474, 24.78633141517639, 56.759803022657124, 28.116625581468853, 40.23872034890311, 40.1767771584647, 21.228858947753906, 5.507905202252524, 0.47074197445596966, 0.15948536779199327, 0.05467539506831339, 0.06913621803479535, 0.07359843395118203, 0.14409425295889378, 0.07472108371023621, 0.3497902846762112, 0.9138877668551036, 2.1891706671033586, 2.433261534997395, 2.311883670943124, 1.398925768477576, 6.018134440694537, 6.26005334513528, 6.079780161380768, 5.330221090997968, 8.656536545072283, 11.939177359853472, 10.514344147273473, 17.47576516015189, 20.88078372819083, 27.675809281212942, 33.49811656134469, 43.4611246245248, 51.88238648005894, 52.83227123532976, 51.47693477358137, 53.7819162777492, 52.31814622879028, 54.52666241782052, 62.95550128391811, 61.53893034798758, 50.51377895900181, 48.80296918324062, 53.27658421652657, 61.57020418984549, 48.91832317624773, 49.00184747150966, 53.724777766636436, 51.06808539799282, 57.45971243722098, 52.71152891431536, 44.623818806239534, 36.370981284550254, 43.92016083853585, 44.85087203979492, 53.17125994818551, 56.700486251286094, 63.2559483391898, 62.63687079293387, 59.75937162126814, 51.19596699305943, 49.75409419195992, 36.236832414354595, 27.407322202410015, 24.602874653679983, 14.445962343897138, 8.87657036100115, 2.336656604494367, 4.984019713742392, 4.274001104491098, 6.730607066835676, 2.0625293254852295, 1.7480691650084086, 1.0158956817218234, 0.33972804461206707, 0.2767407244869641, 0.8432908122028623, 0.2784759285194533, 0.5527998741183962, 0.36554749629327227, 0.31879190089447157, 0.056898520062012334, 0.40278446674346924, 7.494298338890076, 27.852613142558507, 49.42702858788626, 49.00769090652466, 44.907916750226704, 40.05913373402187, 44.7734135219029, 19.374068600790842, 13.382010749408177, 11.434898819242205, 36.20679535184588, 60.95144626072475, 50.987837178366526, 62.184035846165244, 65.71493666512626, 43.779282638004844, 3.459410152265004, 0.49924690489258083, 0.09877461407865797, 0.06610012666455337, 0.06451100443622895, 0.038058313341545205, 0.06344896821039063, 0.09326233129416193, 0.046236058098397086, 0.04793076376829829, 0.06167476877037968, 0.054804879905922074, 0.039507908413984945, 0.06424134783446789, 0.019610523778413023, 0.02081278944388032, 0.04104181146249175, 0.06791345721908978, 0.07800435181707144, 0.02508560418417411, 0.030277375863598924, 0.014663587889767118, 0.12206794773893696, 0.049436850273715596, 0.05529613247407334, 0.023126006924680302, 0.0901277641366635, 0.13278228709740297, 0.13552423353706086, 0.10029101770903383, 0.041759572590568235, 0.04420025965997151, 0.019097971996026378, 0.047315671773893495, 0.11232109075146061, 0.0385582884773612, 0.05462214703272496, 0.02995110229988183, 0.08157323566930634, 0.04997413805020707, 0.043222151430589814, 0.059531127368765216, 0.15489264923546994, 0.0869593991498862, 0.1952156512332814, 0.10802229999431542, 0.09735552594065666, 0.054427994415163994, 0.0275869030904557, 0.04106740580339517, 0.06413014951561179, 0.03673424385488033, 0.04988295990707619, 0.04424964343862874, 0.032808050247175355, 0.05242864687794021, 0.04543607209676078, 0.12287658506206103, 0.07798755807535988, 0.18601087587220327, 0.22531042993068695, 0.06620666344783135, 0.17665102811796324, 0.11979539825447968, 0.2268998846411705, 0.1944382536624159, 0.21590163266020163, 0.07716414904487984, 25.989255666732788, 92.99774020058769, 77.26241193498883, 82.70069054194859, 84.08400739942277, 74.88826806204659, 39.9063914843968, 26.491382871355327, 36.89979478291103, 32.07115459442139, 21.758763313293457, 51.04976647240775, 33.2912026814052, 37.96186515263149, 44.40876858575003, 23.744240590504237, 6.446548640727997, 0.42695860671145575, 0.024178011010267904, 0.0978037661739758, 0.28538911470345085, 0.27918163208024843, 0.3061708781336035, 0.6241567337087223, 1.6378262234585625, 2.0576471303190504, 2.991632887295314, 2.6942332684993744, 2.9501562672001973, 2.7852516302040646, 3.5494870330606187, 2.345621083463941, 1.7053319896970476, 1.8735695907047816, 4.787228490625109, 6.002541380269187, 8.930088860648018, 17.31218719482422, 21.917764152799332, 30.05473177773612, 35.29487207957676, 47.42349467958723, 55.24371651240757, 56.531599862234934, 58.763687814985005, 58.11936398914882, 56.965351581573486, 58.777605056762695, 67.91381917681012, 65.22787489209855, 56.907698903764995, 55.695641245160786, 59.87356526511056, 70.81146812438965, 59.646442549569265, 54.925322260175435, 57.625013555799214, 58.04263850620815, 63.64397048950195, 64.05407401493618, 52.52258655003139, 45.16286352702549, 47.809960433415, 50.92212111609322, 56.895848751068115, 61.29744570595877, 67.00407069069999, 66.36252267020089, 65.11761392865861, 52.98482240949358, 48.687260832105366, 39.090520109449116, 30.646641867501394, 26.014715603419713, 14.462668418884277, 8.56677884714944, 3.8152297905513217, 4.00653714793069, 7.7642949138368875, 7.616372976984296, 8.068093606403895, 5.175909851278577, 3.2800434912954057, 2.3168498958860124, 1.3659061917236872, 4.255356916359492, 1.9226193130016327, 1.346382513642311, 0.5668131421719278, 0.12245416987155165, 0.058874861869428835, 0.3021351961152894, 8.74428881917681, 29.122102873665945, 50.46114635467529, 43.79045534133911, 43.106023039136616, 33.7378328868321, 32.39307158333914, 22.404902356011526, 21.902420793260845, 24.237571375710623, 43.15370505196707, 69.07229232788086, 57.94697223390852, 73.64556884765625, 77.2766557421003, 62.74533912113735, 7.177731462887355, 0.2848208551960332, 0.04807707966704454, 0.0921834334731102, 0.07671571203640529, 0.032760003182504854, 0.0579468770218747, 0.018358582564230477, 0.15726137427347048, 0.019279249411608492, 0.1143151694642646, 0.06617653649300337, 0.04404927544029696, 0.08087614271789789, 0.05547997475202594, 0.0451065788843802, 0.018773255670177083, 0.07419662363827229, 0.10417157305138451, 0.0425248854527516, 0.01529307839726763, 0.005250334764631199, 0.05538261854755027, 0.08874513368521418, 0.039218913564192395, 0.05072960536926985, 0.10158694495580026, 0.0721242284136159, 0.1495850533246994, 0.09076567526374545, 0.10132026033742086, 0.05386542781655278, 0.07304818276315928, 0.039331981247024875, 0.06709094385483436, 0.03478337425206389, 0.05705532950482198, 0.19700397098703043, 0.25069779051201685, 0.24248159996100835, 0.1022667759763343, 0.15720181246953352, 0.2652995384165219, 0.22906251145260675, 0.36963322705456186, 0.3431750296482018, 0.21117659977504186, 0.20759170928171702, 0.1494043187371322, 0.2451453927372183, 0.08567861001938581, 0.1838506239333323, 0.08940960267292601, 0.10877719055861235, 0.10809911694377661, 0.13186169149620192, 0.1189856617046254, 0.16479873125042233, 0.2726054878107139, 0.3165282537894589, 0.37077047888721737, 0.18802659985210213, 0.28911101498774117, 0.21930597855576447, 0.3212828300893307, 0.24145839629428728, 0.2495021846677576, 0.2198081487523658, 37.93905769075666, 108.50543853214809, 82.78296416146415, 95.46294716426304, 92.50254208700997, 82.03576183319092, 40.37526287351336, 25.801723786762782, 42.7361877986363, 44.708645888737266, 37.84254026412964, 70.3415197644915, 40.73245586667742, 57.114550249917166, 55.8398163659232, 33.01839208602905, 10.675464187349592, 1.2071660182305743, 0.1968150804085391, 0.1814543368028743, 0.27558075530188425, 0.40400208426373346, 0.40177515947393005, 0.8316164272172111, 1.9893400413649422, 4.3236933180264066, 6.818917802401951, 7.143772576536451, 9.095429062843323, 11.46719057219369, 16.748802934374126, 19.595142909458705, 15.84259455544608, 16.47216214452471, 21.02836867741176, 21.604370866503032, 20.577579975128174, 29.256474086216517, 29.27010645185198, 37.67950078419277, 41.63215030942644, 54.73026548113142, 60.047409193856375, 65.08178206852504, 62.89368316105434, 63.93028490883963, 66.79628481183732, 63.4102817262922, 69.87193965911865, 67.25788838522774, 60.308258465358186, 60.05801909310477, 65.25317328316825, 73.82088579450334, 65.40902832576207, 61.07342883518764, 65.90431676592145, 61.59851809910366, 72.07565811702183, 73.4131168637957, 59.365304538181846, 51.657473291669575, 54.968171800885884, 55.40888908931187, 55.74452529634748, 63.7734432220459, 72.98634460994175, 69.71436841147286, 69.10466398511613, 57.93970789228167, 57.95352438517979, 45.92017548424857, 38.670289584568565, 34.754184109824045, 21.60602801186698, 15.042787415640694, 9.861916984830584, 13.766843676567078, 16.15959916796003, 20.235004254749843, 7.9474711418151855, 5.721478062016623, 2.795542346579688, 2.772618068116052, 1.2963191143104007, 4.870255555425372, 3.0652820553098405, 2.590278229543141, 0.8874823323317936, 0.6008456902844566, 0.23866820601480349, 0.9859302725110735, 14.813328368323189, 44.24973821640015, 69.80051912580217, 65.29004737309047, 62.83590888977051, 56.496671267918174, 61.61898054395403, 27.47533985546657, 21.309008155550274, 22.301641702651978, 51.823316369737896, 76.28666251046317, 69.31430503300258, 81.43561812809536, 86.14126477922711, 77.7805460521153, 10.0093777350017, 0.6203480352248464, 0.1666298122810466, 0.3544159936053412, 0.3404583925647395, 0.1307102989937578, 0.16859748241092476, 0.19088384296212876, 0.24122335176382745, 0.2246430500277451, 0.28533700321401867, 0.28798646533063477, 0.21361601459128515, 0.18064331103648457, 0.23575718221919878, 0.14109463963125432, 0.17925326419728144, 0.16978738856102737, 0.21472905629447528, 0.26031407022050446, 0.18596552259155683, 0.17899675081883157, 0.192312607009496, 0.3145326280168125, 0.1823266614228487, 0.13245167769491673, 0.2763720085578305, 0.38207172389541355, 0.28432357045156614, 0.28017508877175196, 0.2626803661031382, 0.2317385178591524, 0.17437813936599664, 0.09898043410586459, 0.23328533342906407, 0.1690672729164362, 0.15966948148395332], [0.027174369066155384, 0.012950575345062783, 0.1423251221754721, 0.06839129514992237, 0.15009138972631522, 0.1753596674118723, 0.0531394258806748, 0.03717816521280578, 0.17389416747859546, 0.025264952863965715, 0.10020614654890128, 0.11739641055464745, 0.10220986724432025, 0.12642407470515796, 0.014987310161814094, 0.006604529509786516, 0.03163258332226958, 0.03543518856167793, 0.09770982300064393, 0.13494328542479447, 0.15357521921396255, 0.20688622285212788, 0.3138939365744591, 0.2570229582488537, 0.16820781332041534, 0.16502103289323194, 0.18289701081812382, 0.107380514432277, 0.2111714564796005, 0.15885762790484087, 12.29972893851144, 79.06980514526367, 75.62784126826695, 88.66579546247209, 70.27298273359025, 65.87764263153076, 28.800470760890416, 26.14765896115984, 28.0978741305215, 23.14611186300005, 28.008523770741053, 51.086261885506765, 60.63940961020333, 47.65579032897949, 41.273331437792095, 10.098424979618617, 4.114912109715598, 0.2045123138065849, 0.05719070402639253, 0.11603554072124617, 0.13606075117630617, 0.1516767596559865, 0.09980287961661816, 0.07899068389087915, 0.5090564585157803, 0.6597957270486015, 1.018604502081871, 2.843743520123618, 2.019732330526624, 3.493841298988887, 1.576229140162468, 3.9740121960639954, 3.9923372013228278, 3.075104202542986, 11.353806393487112, 14.216853312083654, 18.912510190691265, 30.712465626852854, 43.07665647779192, 51.38289090565273, 58.171965326581685, 61.7405948638916, 65.66789736066545, 63.01905645642962, 57.267393248421804, 56.7470635005406, 57.836332593645366, 63.39791393280029, 64.00880650111607, 69.28022411891392, 63.13714109148298, 66.64332021985734, 59.14449078696114, 31.468728406088694, 44.39120006561279, 46.562585081372944, 54.480234554835725, 52.66063335963658, 59.046548979622976, 64.47818510872978, 51.539503301892964, 25.930360998426163, 28.76513569695609, 48.53656135286604, 57.84577866962978, 68.47679001944405, 67.27987248556954, 64.01384394509452, 66.68253585270473, 62.227093832833425, 66.40080029623849, 62.2969788142613, 61.172996520996094, 56.41333457401821, 46.761039529527935, 33.252136434827534, 20.281371320996964, 13.47579232284001, 6.0712885941777905, 2.6343584699290137, 4.871134068284716, 5.564183005264827, 3.161348283290863, 3.0055064857006073, 2.308642770562853, 0.9208724434886659, 1.3938383843217577, 2.0777196075235094, 0.4770360652889524, 0.02803189823004816, 0.19439931932304585, 0.11181810631283692, 0.21810399448232992, 0.048147915330316336, 3.399260465587888, 18.342429603849137, 38.016620431627544, 51.764927182878765, 54.828405312129426, 46.64246504647391, 51.12938935416085, 37.634896823338096, 21.553951263427734, 24.030989272253855, 35.00322839191982, 55.20753376824515, 54.905443464006694, 56.38567726952689, 60.7167569569179, 47.18546329225813, 4.633210378033774, 0.3032755692090307, 0.037536462236727984, 0.08758911357394286, 0.07816014345735312, 0.05201034700231893, 0.04961315402761102, 0.07560605622295823, 0.06593822820910386, 0.011765718343667686, 0.10706102621874639, 0.12760209292173386, 0.032259726098605564, 0.018455144882734333, 0.02762183916222836, 0.04536947049200535, 0.03133435361087322, 0.07180661295673677, 0.03159498569688626, 0.2193359290914876, 0.06393135232584816, 0.06723621820232697, 0.08208559067653758, 0.04991159747753825, 0.030245491503072635, 0.044017255372766934, 0.08981178394917931, 0.023868588863738945, 0.036758155428937504, 0.05191254296473094, 0.0075864235404878855, 0.026496295451319644, 0.0516167186599757, 0.02268156818380313, 0.07040757552853652, 0.035757336632481644, 0.032746649613337855, 0.005366233210744602, 0.12824756971427373, 0.0011128950760134362, 0.17761624418199062, 0.06339281265224729, 0.0712797169440559, 0.08470680538032736, 0.18987743982246943, 0.04334783647209406, 0.09376738526459251, 0.10772815506373133, 0.1353310274758509, 0.09546133436794792, 0.049068310763686895, 0.02207329376999821, 0.07416311079370123, 0.0877326305157372, 0.09006200730800629, 0.01986018056049943, 0.18005447834730148, 0.15840817987918854, 0.17736901316259587, 0.14174876095993177, 0.10047768947801419, 0.08879696697528873, 0.12165903539529868, 0.15373379284782068, 0.14911762412105287, 0.10359728815300123, 18.059467690331594, 92.46790531703404, 84.60854080745152, 95.7404373713902, 79.91800648825509, 74.25324440002441, 43.049673148563926, 34.08647264753069, 19.96671519960676, 27.956480026245117, 39.60827554975237, 38.571152687072754, 57.108553954533164, 40.23604529244559, 37.6629501751491, 11.300738658223834, 3.8374162571770802, 0.24417535907455853, 0.06259418372064829, 0.09851975632565362, 0.5452331230044365, 0.41129449009895325, 0.6556087860039302, 1.804791109902518, 1.9553650873047965, 0.8821804768272808, 0.8804858763303075, 1.1023333349398203, 0.45796554003443035, 0.40763859770127703, 1.2037452246461595, 2.621945947408676, 4.111421508448465, 3.862588712147304, 8.184866768973214, 12.15339205946241, 20.11594339779445, 31.39726618358067, 45.69123581477574, 53.6511025428772, 60.98743792942592, 67.1915261404855, 67.97834709712437, 65.45389979226249, 61.559893063136506, 60.01765005929129, 64.46421228136334, 70.70855835505894, 68.2872292654855, 69.03153419494629, 63.59147684914725, 70.13443565368652, 61.446220534188406, 38.97036491121565, 52.18271541595459, 52.892557280404226, 61.69107505253383, 58.721421922956196, 67.67394651685441, 71.44688783373151, 59.5322836467198, 32.78140640258789, 33.44778381075178, 52.10425983156477, 60.630745206560405, 70.15124334607805, 72.64586898258754, 69.47529479435512, 69.26390280042375, 66.76427446092877, 70.23353781018938, 64.78550393240792, 66.00924846104213, 61.19887161254883, 49.96226222174508, 35.60736731120518, 22.35477110317775, 15.684630734579903, 7.199285209178925, 3.727895276887076, 3.8732455117361884, 5.140054106712341, 7.344729678971427, 8.330603497368948, 3.1866084592682973, 2.790285600083215, 2.2383576163223813, 3.251370881284986, 2.0964940743786946, 0.8333122762186187, 0.22113594678895815, 0.11777297034859657, 0.07216173782944679, 0.014432178610669715, 3.6835575188909258, 20.28787136077881, 39.04551315307617, 47.86969062260219, 45.70787327630179, 40.43127925055367, 44.287466934749055, 33.51913138798305, 21.40965802328927, 36.465549741472515, 49.017223834991455, 68.97493416922433, 63.02907575879778, 67.22734410422188, 73.05856418609619, 67.0124432700021, 11.198268362454005, 0.36962731022919926, 0.02916799485683441, 0.058811927746449194, 0.06923731975257397, 0.12813630354191574, 0.06907567235508136, 0.07243394572287798, 0.022857286701244966, 0.04234675304698093, 0.030009486845561435, 0.1091549445741943, 0.04924480111471244, 0.016781137923577, 0.0597386233774679, 0.06529022048094443, 0.08480517260198082, 0.0759726008400321, 0.08139982925994055, 0.12493064627051353, 0.028175727297951068, 0.04365503641643694, 0.06003067163484437, 0.005951596041476088, 0.06144636709775243, 0.03477353210161839, 0.07434946365122284, 0.019360213906371167, 0.043079391055341275, 0.05888786938573633, 0.012909123640773552, 0.01866005058400333, 0.07336885841297251, 0.05508342531642743, 0.043298327164458375, 0.05679599681336965, 0.11225610745272466, 0.10428556014916726, 0.1795409901865891, 0.23087650697146142, 0.29430235070841654, 0.26563704173479763, 0.18767089822462626, 0.18944939279130527, 0.32532497176102226, 0.1915957076208932, 0.20827727392315865, 0.14686978688197477, 0.3225873272333826, 0.26898240936653955, 0.13664444057004793, 0.19346621153610094, 0.18851456152541296, 0.1881476640701294, 0.21206941615257943, 0.20098855931844029, 0.23565488627978734, 0.3706789309425013, 0.3683359223817076, 0.3725776619144848, 0.2523191092269761, 0.2868005489664418, 0.3108854480087757, 0.2081790491938591, 0.4139106497168541, 0.3365285348679338, 28.125124965395244, 107.04189082554409, 91.61739717211042, 108.27040181841168, 88.21098722730363, 85.92652375357491, 41.42849166052682, 38.29313441685268, 41.666005407060894, 35.37257725851876, 39.6271572794233, 62.727892194475444, 71.38266563415527, 64.94862679072789, 57.639167036329, 17.191436188561575, 6.385526520865304, 0.4554082229733467, 0.19876727993999208, 0.15569796173700265, 0.8041080747331891, 0.4134709861661707, 1.2639863235609872, 2.2801182440349033, 3.1288954189845493, 3.2636726668902805, 4.053980316434588, 8.019351124763489, 8.642225861549377, 10.810375622340612, 6.599224882466452, 9.208528365407672, 8.69533268042973, 6.375553684575217, 18.463547127587454, 19.088911056518555, 25.807848623820714, 39.435428687504356, 53.532976218632285, 58.4077524457659, 63.71422372545515, 69.81820229121617, 72.92524909973145, 70.27553272247314, 63.42861107417515, 62.73547962733677, 62.34446975163051, 68.93598951612199, 70.20289625440324, 71.59675352913993, 66.1311754499163, 72.74854251316616, 64.21306269509452, 43.644029004233225, 57.30433682032994, 59.28255149296352, 67.3032670702253, 66.45257132393974, 73.10253933497837, 81.33877413613456, 69.85138688768659, 38.99580226625715, 37.51490838187081, 58.745344570704866, 61.98226015908377, 72.13068090166364, 76.40262794494629, 71.72355815342495, 72.31905351366315, 68.66616317204067, 71.40840870993478, 66.75507504599435, 67.11729853493827, 61.90166800362723, 51.251246861049104, 38.11943640027727, 23.127541065216064, 18.802464621407644, 10.477035794939313, 8.371174028941564, 15.392544099262782, 13.772436107907977, 13.385735852377755, 11.397662554468427, 7.262255864483969, 4.935543434960501, 3.3853052258491516, 5.527917316981724, 2.727642595767975, 1.6525645468916212, 0.8955576047301292, 0.41592980708394733, 0.34177646040916443, 0.1128961288237146, 6.105485890592847, 29.955806800297328, 55.5684301512582, 72.11066314152309, 75.07343060629708, 65.62485327039445, 71.65395109994071, 53.53735705784389, 32.37110832759312, 36.01750210353306, 51.159047739846365, 73.69828483036586, 72.96431882040841, 78.80529417310441, 81.40554632459367, 80.17882796696254, 14.87654481615339, 0.6280677009906087, 0.17772869100528105, 0.23334922428642, 0.19099240856511251, 0.16987992716687067, 0.13684653544000216, 0.1639541858541114, 0.21287571931523935, 0.15583581291139126, 0.18567639882011072, 0.22591850587299891, 0.11367799794035298, 0.10545806866139174, 0.19890380118574413, 0.15950307755598, 0.15585603325494699, 0.20527250372937747, 0.17815615449632916, 0.29565923075590816, 0.12910601150776657, 0.22340749204158783, 0.15853422454425267, 0.10296575525509459, 0.14961186902863638, 0.32523887923785616, 0.19371706593249524, 0.1527847530586379, 0.2321833111345768, 0.18628450190382345, 0.08091039516563926, 0.12768502347171307, 0.15444240053849562, 0.11680516228079796, 0.16806739728365624, 0.1861102676817349], [0.0035182123413375977, 0.018575717162873064, 0.10347011033445597, 0.10308253113180399, 0.12792576769632952, 0.1223424965781825, 0.11403920927218028, 0.06893458456865378, 0.03279339389077254, 0.006271720805671066, 0.10419168482933726, 0.07265983003058604, 0.07469851563551597, 0.0019589895465677337, 0.06177152107868876, 0.010105119236478848, 0.029512331022747924, 0.0059549704809407035, 0.04330867821616786, 0.10872009862214327, 0.050273623051387925, 0.11946552166981356, 0.14246950085674012, 0.14557921327650547, 0.05204753750669105, 0.18136922137013503, 0.09494242471243654, 0.21941443559314522, 0.13700662899230207, 17.229934419904435, 75.01312024252755, 75.66541712624687, 83.81580693381173, 64.42104312351772, 53.35538026264736, 33.12950767789568, 23.75566690308707, 26.603184597832815, 40.703537464141846, 46.847700936453684, 34.7426118850708, 45.02014405386788, 45.72303771972656, 36.39017915725708, 10.161385212625776, 1.155301189848355, 0.054821734715785296, 0.02931505035875099, 0.08699282378490482, 0.29506418268595425, 0.26172640014972004, 0.49426662070410593, 0.23488838598132133, 0.9123674141509193, 0.6370999791792461, 0.5814462655356952, 0.42695990949869156, 0.30616287142038345, 2.8560833036899567, 12.264589292662484, 25.05066520827157, 27.919195992606028, 34.71509007045201, 41.87412827355521, 42.72620323726109, 50.243903977530344, 54.88204887935093, 57.40677063805716, 60.88502148219517, 60.56140913282122, 65.40845162527901, 66.41170896802629, 70.72336496625627, 64.70415442330497, 69.70890712738037, 67.17700440543038, 66.55030468532017, 66.00505174909318, 71.82547433035714, 73.5665261404855, 75.84239469255719, 74.93420955113002, 79.10903467450822, 67.84653976985386, 29.415758064814977, 49.24148736681257, 50.59342268535069, 55.62767744064331, 61.09327983856201, 53.665429728371755, 30.633183206830704, 29.672705922807964, 46.97833054406302, 60.5774108341762, 71.08723517826625, 67.90932369232178, 64.40624346051897, 61.449778011866975, 59.71482672010149, 59.08292279924665, 62.54600919995989, 63.6473125730242, 66.72409302847726, 69.8047227859497, 64.95648520333427, 61.17993082318987, 51.711325304848806, 37.84888049534389, 23.9464088508061, 17.360657828194753, 6.707281964165824, 10.837593453271047, 7.628553169114249, 4.592221217496054, 2.8723486023289815, 1.618363993508475, 2.6830946547644476, 0.40133544164044516, 0.9385641855852944, 0.6349204161337444, 0.2912787715239184, 0.07347566661025796, 0.08736955321260861, 0.254383809864521, 0.17262313568166324, 2.6810616552829742, 11.074538316045489, 31.63924762180873, 49.00033623831612, 53.37061766215733, 55.009152276175364, 54.10884639195034, 40.06138495036534, 16.121359757014684, 15.672037124633789, 24.744272232055664, 49.57035950251988, 57.382542269570486, 61.35893726348877, 64.16486304146903, 62.426319531032014, 7.0590614421027045, 0.42740863827722414, 0.03811562580189534, 0.03745459359405296, 0.046178284234234264, 0.03194149656753455, 0.08485307038894721, 0.08925417744155441, 0.05117877519556454, 0.05572357221639582, 0.05983990829970155, 0.012124953442253172, 0.013642150958600854, 0.07481282843010766, 0.04373592457601002, 0.07673300110868045, 0.06530698029590504, 0.11913283595017024, 0.11711669127855982, 0.08687188170318093, 0.011890381341800094, 0.008187906666924911, 0.12610065777386936, 0.04172361023457987, 0.05250271236790078, 0.07163791558040039, 0.05352768701102052, 0.09975108025329453, 0.036501187432025156, 0.054521625462387285, 0.024034585670701096, 0.021596186960648214, 0.03485935999612723, 0.01806971663609147, 0.0605092423834971, 0.01626101538671979, 0.05017449926318867, 0.058987057634762356, 0.05647121263401849, 0.09465743321925402, 0.0823054156665291, 0.03952121448570064, 0.05609752982854843, 0.05285376603049891, 0.0343718020511525, 0.024810719470094358, 0.10037744271435908, 0.04952444914462311, 0.05329367385378905, 0.05110527288966945, 0.016989870562351177, 0.03391341432662947, 0.0358887892216444, 0.07537074027849094, 0.08911612949201039, 0.08729509077966213, 0.07491754673953567, 0.10023066201912505, 0.16021320516509668, 0.013808282624397959, 0.18517293940697396, 0.052602321308638365, 0.2092402372509241, 0.15614985248872212, 22.19575810432434, 87.92130987984794, 83.3865750176566, 93.05488913399833, 72.86960097721645, 67.40122972215924, 52.340286663600374, 29.000889812197002, 24.600293397903442, 43.317296913691926, 43.93501608712332, 37.609334400721956, 53.63411767142159, 47.489075251988, 33.04228694098336, 11.115731579916817, 1.350511263523783, 0.04600200762173959, 0.020399017093170966, 0.29757256380149294, 0.37537708027022226, 0.38753040241343634, 1.3688771980149406, 1.4077854816402708, 1.626893775803702, 0.8116361764924866, 0.3779920185250895, 0.3728117564959185, 0.8681982042534011, 3.75943705865315, 13.15552466256278, 28.11675759724208, 31.95246546609061, 37.37021214621407, 45.741537298474995, 47.527293818337576, 54.47286599023001, 57.740537779671804, 62.58149365016392, 64.41002328055245, 64.1204501560756, 66.13958971840995, 66.97939068930489, 71.10801724025181, 67.92848682403564, 70.51573889596122, 68.11835329873222, 68.71692671094621, 70.2900058201381, 74.8311608178275, 76.83677918570382, 79.8605101449149, 78.38164860861642, 82.74666677202497, 69.77966063363212, 38.9274389403207, 55.22407395499093, 55.69040577752249, 59.76557636260986, 67.62954057965959, 60.118892260960166, 38.217624868665425, 35.58028670719692, 46.836750575474326, 62.561482838221956, 73.44935866764614, 70.46303680964878, 68.82531860896519, 65.30445793696812, 63.07064683096749, 62.80583013807024, 66.74329090118408, 66.83078261784145, 70.32220377240861, 71.64400822775704, 67.8726441519601, 64.1151556287493, 53.926699365888325, 39.910383224487305, 25.993633031845093, 15.080606460571289, 5.530169401850019, 3.5537050238677432, 3.236455270222255, 4.0315854038511, 2.1023620452199663, 2.7543816523892537, 4.214396417140961, 2.9588052545275008, 3.8805945345333646, 1.8108468992369515, 0.8478429136531693, 0.3067340893404824, 0.0859584514317768, 0.07925310052399125, 0.05362919245713523, 2.4604513560022627, 12.499455775533404, 31.77583530970982, 47.44602073941912, 50.43588270459856, 45.98666974476406, 40.656689235142295, 35.586626938411165, 20.753562211990356, 24.855069943836757, 42.870656285967144, 65.66773060389927, 65.86243997301374, 72.68754427773612, 73.80995627811977, 80.58133711133684, 13.669299653598241, 0.28172195862446514, 0.05069280841520854, 0.05630158566470657, 0.01593579524861915, 0.03368636293868933, 0.12146406514304024, 0.061390924001378674, 0.0422621736569064, 0.14877290119017872, 0.024443284275808504, 0.018524745612272193, 0.01217931427527219, 0.06144562070923192, 0.06188709594841514, 0.08250158014042036, 0.09688195599509136, 0.07913441796387945, 0.10413491858967713, 0.13480067093457493, 0.007667336296955389, 0.04387513282043593, 0.07766908766435725, 0.017798631718116145, 0.08065866545907088, 0.12214197590947151, 0.015107354880975825, 0.03178568457120231, 0.03695789238970194, 0.01900003055509712, 0.07484237184481961, 0.05411219743213483, 0.0323542901314795, 0.02859016800565379, 0.08022639794009072, 0.11418144378278937, 0.1895431527601821, 0.13189667676176342, 0.20618780675743306, 0.25285325199365616, 0.2166118145521198, 0.21808068001908915, 0.13978498562106065, 0.16708873265555926, 0.19301478218819412, 0.34524960975561825, 0.2527318485081196, 0.19230446458927222, 0.15843971818685532, 0.1345845168190343, 0.06605178104447466, 0.14131820334919862, 0.12156249343284539, 0.2149301062205008, 0.2879481688141823, 0.15266489663294383, 0.23682153224945068, 0.21363798555518898, 0.22690052246408804, 0.1949231212160417, 0.2554594235760825, 0.14012395457497664, 0.2515249789825508, 0.4222678398447377, 33.47249507904053, 101.97826603480748, 93.9483163016183, 104.29428127833775, 81.59709426334926, 71.06716878073556, 49.3681252343314, 36.27013165610177, 41.05941029957363, 59.093025479997905, 64.32569994245256, 48.56893301010132, 57.85693052836827, 59.37508760179792, 49.60568414415632, 15.318735122680664, 2.0656397300107137, 0.22251892329326697, 0.1241579848740782, 0.40314455170716557, 0.6085908146841186, 1.3184001637356622, 2.6185378559998105, 1.7295029269797462, 3.5470039205891744, 2.884235667330878, 2.426367836339133, 3.5504719402108873, 3.2112828152520314, 5.14894780090877, 16.4129478590829, 32.20692934308733, 37.135838985443115, 40.19345283508301, 51.74636159624372, 50.6745776448931, 58.34127902984619, 60.54526151929583, 63.098675864083425, 65.54023810795375, 65.50048746381486, 67.91620935712541, 68.3477063860212, 72.16772174835205, 68.8783403124128, 73.03730964660645, 69.08766174316406, 71.19354261670793, 69.82177366529191, 73.62457833971295, 79.07168115888322, 81.7580075945173, 78.98442568097795, 83.3862692969186, 74.25470352172852, 43.943465096609934, 63.47581713540213, 65.33953939165387, 66.77915055411202, 74.14135060991559, 66.48594352177211, 45.385115555354524, 42.089029107775005, 51.07456111907959, 66.61310945238385, 74.42220374516079, 74.28062725067139, 72.24801513126918, 68.38251686096191, 65.21291542053223, 65.66538906097412, 68.22747475760323, 71.01996271950858, 73.37965433938163, 74.46735313960484, 71.7089877809797, 66.72017424447196, 56.46224641799927, 41.936596052987234, 28.136584281921387, 23.429905823298864, 11.917472055980138, 20.31592297554016, 18.102921724319458, 13.728345445224218, 10.755761044366018, 7.142721661499568, 9.29004202570234, 5.11075268472944, 5.906624104295458, 2.9516082235745023, 1.4433773032256534, 0.41514927468129564, 0.27597324709807125, 0.6017082440001624, 0.3188733250967094, 3.947929961340768, 19.319139616830007, 46.36448499134609, 66.04834597451347, 70.03367287772042, 73.47817284720284, 74.47878292628697, 57.15285219464983, 26.12792260306222, 27.180020570755005, 39.32713059016636, 68.74042551858085, 74.27279663085938, 82.21575491768974, 80.30315208435059, 93.10183811187744, 16.75510147639683, 0.41631885192223955, 0.09111683070659637, 0.20112318066614016, 0.10616164162222828, 0.10649645115647997, 0.19485503701227053, 0.1556728830827134, 0.11026275477239064, 0.22275375069252082, 0.11073135105626923, 0.1069463538005948, 0.159370451101235, 0.2033929888691221, 0.10783661888646227, 0.10016755826239075, 0.1512587685137987, 0.22650048535849365, 0.21611689110951765, 0.18969586385147913, 0.22029893313135418, 0.12821631639131478, 0.1805088525371892, 0.12339323519596032, 0.1416667667882783, 0.18564335416470254, 0.09362874698958226, 0.16457191056438855, 0.11845347311879907, 0.17799027982567037, 0.17285189697785036, 0.13956937433353492, 0.09345907930816923, 0.1386261699455125, 0.1374846433422395], [0.02007400899726365, 0.049140221904963255, 0.0827801866190774, 0.0491448664771659, 0.06932648603937455, 0.10877503960260324, 0.037091373798570464, 0.05403452892122524, 0.042888108640909195, 0.04017173618610416, 0.04748310028974499, 0.050985613239130805, 0.07083150385213749, 0.049410529900342226, 0.03657708835921117, 0.00826284068170935, 0.05888163364891495, 0.10353668819048575, 0.05408357682504824, 0.034959063931767426, 0.08007049094885588, 0.0659215362476451, 0.05712589036141123, 0.04194575581433518, 0.09770362119057349, 0.10379132881228413, 0.0701863866831575, 0.3424191416374275, 17.80545197214399, 78.61080714634487, 70.48088673182896, 78.46773678915841, 66.43834836142403, 61.89540072849819, 29.360929829733713, 20.2574017729078, 23.728235415049962, 37.9181227684021, 28.076473678861344, 35.46745491027832, 56.26634543282645, 40.62847260066441, 22.42107949938093, 3.808802272592272, 0.044970675105495114, 0.07650785640414272, 0.11371928679623775, 0.0870018754420536, 0.3836951053568295, 0.5821348428726196, 0.40900576433965136, 0.6511934772133827, 1.2174171081611087, 1.629573283450944, 0.948158779314586, 0.7025375706808907, 5.285092541149684, 23.817782061440603, 46.79435961587088, 61.99512822287423, 68.15238557543073, 66.02570179530552, 67.49328640529087, 68.4139713559832, 66.84847967965263, 68.04331275394985, 66.69113772256034, 67.56538786206926, 66.25752844129289, 64.74930381774902, 65.08415835244315, 65.2780408859253, 64.80448641095842, 68.74909687042236, 67.78143514905656, 67.52261475154332, 62.89925561632429, 66.45887334006173, 68.95241505759103, 71.6227536882673, 64.91476821899414, 68.10818808419364, 66.10409832000732, 76.04361452375139, 53.59713935852051, 32.98116711207798, 54.71224185398647, 51.65018810544695, 59.52443218231201, 42.35175091879708, 32.30155685969761, 48.10169097355434, 59.05381679534912, 68.13992745535714, 67.56765297480992, 65.56575189317975, 59.087529454912456, 54.29138946533203, 53.21882731573922, 56.94116837637765, 61.34688908713204, 64.37948594774518, 65.13534573146275, 64.27008656093052, 64.80521597181047, 66.91303539276123, 63.9718142918178, 56.26996544429234, 44.442661898476736, 29.949713230133057, 14.750290836606707, 7.897377235548837, 4.673752248287201, 6.550572727407728, 1.5920619134392058, 2.2908180356025696, 0.9980001619883946, 2.4485888268266405, 2.291835295302527, 0.6840701273509434, 0.17895633727312088, 0.08363149700952427, 0.20889729208179883, 0.11867281634892736, 0.09120457885520798, 0.08665450622460671, 0.7294872445719582, 7.201421780245645, 21.270711421966553, 40.84448514665876, 61.54167488643101, 55.0832965033395, 33.443173680986675, 31.458264419010707, 20.69416206223624, 25.03975132533482, 18.94565483501979, 26.430549655641826, 48.923127855573384, 59.47853238242013, 62.81565489087786, 51.889584813799175, 7.083129567759378, 0.285157815686294, 0.04000685217657259, 0.073732587109719, 0.058894919364580085, 0.01515803805419377, 0.02344171909083213, 0.11428931728005409, 0.04671662713267973, 0.09339896110551697, 0.04377760698220559, 0.086249726159232, 0.07172448307807956, 0.0631099653297237, 0.04401844280904957, 0.10068965703248978, 0.026485123372237598, 0.15076657278197153, 0.06625508370676211, 0.03770547513184803, 0.04165148874744773, 0.019071222449253713, 0.034790770283767154, 0.03336643028472151, 0.02988158299454621, 0.05757920603666987, 0.12452887211527143, 0.02211243166987385, 0.026860453321465423, 0.01801960512862674, 0.07163351867347956, 0.014101948339625128, 0.03060680122247764, 0.04164922922583563, 0.04600253009370395, 0.030533343021358763, 0.03581357022215213, 0.13653265871107578, 0.059714365750551224, 0.03841721086895891, 0.10510434835617032, 0.045790148632867, 0.017643705209983245, 0.025918945270989622, 0.04148944101429411, 0.07928016050053494, 0.039667723766927204, 0.0646368387554373, 0.009280540581260408, 0.059636897407472134, 0.08010789858443396, 0.05403587581323726, 0.05673461653558271, 0.033744340363357744, 0.08188317010977439, 0.06585178284772805, 0.0809603760551129, 0.057512221059628894, 0.05537284764328173, 0.07963770774326154, 0.12632551070834908, 0.13210847468248435, 23.07885503768921, 92.89683151245117, 79.6896539415632, 88.4563489641462, 75.22578375680106, 75.90588733128139, 39.76307446616036, 26.519971234457834, 22.054108653749736, 27.016885553087505, 32.742736203329905, 44.131615366254536, 47.217421531677246, 38.05129541669573, 27.64428530420576, 4.267985701560974, 0.0840731215264116, 0.054555881302803755, 0.03880855594096439, 0.016806487991873707, 0.5209767445921898, 1.2305914355175835, 0.9291133327143533, 1.9926523779119765, 1.2078723460435867, 0.7769295988338334, 0.8744186876075608, 0.43522167046155247, 6.629051761967795, 27.22074396269662, 51.52469669069563, 67.31735106876918, 71.95992892129081, 70.648102079119, 70.879289490836, 71.309084211077, 67.9976908820016, 67.3973387309483, 69.27961962563651, 70.32947158813477, 67.4529173714774, 65.2337600163051, 66.69787747519356, 66.60113770621163, 65.38673850468227, 68.46318544660295, 69.89627225058419, 70.73427363804409, 66.96667548588344, 69.21231937408447, 69.85341576167515, 74.22365897042411, 69.39000565665108, 71.4966299874442, 69.2113744190761, 77.3293856212071, 57.16139847891671, 39.66222136361258, 61.28626605442592, 59.30691187722342, 66.25836222512382, 49.0651455606733, 40.09756769452776, 50.060777255467, 60.03303337097168, 72.8443442753383, 68.81272847311837, 68.46456813812256, 62.90375804901123, 57.93600450243269, 57.64045245306832, 60.965168952941895, 65.24751050131661, 66.53212124960763, 67.56790310995919, 66.27836608886719, 66.420394216265, 68.71373053959438, 64.99909155709403, 57.58475916726248, 47.835297039576936, 33.18691022055489, 16.967709405081614, 10.252369267599923, 3.815153794629233, 2.360939472913742, 1.4154191634484699, 2.022119905267443, 2.2844228701932088, 3.698390620095389, 4.461988959993635, 2.2370426697390418, 1.75076539175851, 0.9785689818007606, 0.5125764267785209, 0.2502367938203471, 0.07601264119148254, 0.04651950253173709, 0.3445864910525935, 8.114899277687073, 22.579326459339686, 39.941434723990305, 44.25492852074759, 45.31264931815011, 26.135820967810496, 19.974964448383876, 14.055683766092573, 18.56668097632272, 29.038109574999126, 38.60717909676688, 59.01858248029436, 68.12530844552177, 71.4053098133632, 69.4879891531808, 15.275095224380493, 0.21330459415912628, 0.03313882249806609, 0.058307911934597154, 0.03660367336124182, 0.05750447218971593, 0.07487581683588879, 0.06895403816763844, 0.07749736402183771, 0.03638345482093947, 0.019480480845751505, 0.06235688645392656, 0.031492886532630236, 0.02075603338224547, 0.06386497803032398, 0.028789491060056856, 0.04627065659899797, 0.15210737154952117, 0.08710653268332992, 0.12010381956185613, 0.08349010388233832, 0.02826719551480242, 0.042583266605756113, 0.06592081700052534, 0.03154420413609062, 0.03373253385403326, 0.10684298577585391, 0.011832291958853602, 0.053124057062502415, 0.07885799636798245, 0.01555451624361532, 0.058331314607390335, 0.05011690521080579, 0.043502746016851494, 0.11465732753276825, 0.10926613610770021, 0.2644282451697758, 0.23752598730581148, 0.17503318350229943, 0.16093541069754533, 0.20515825200293744, 0.1353098571832691, 0.2033823901521308, 0.20480670300977571, 0.17679931516093866, 0.253837806305715, 0.19417749265474932, 0.252837672829628, 0.14717170782387257, 0.2034926928047623, 0.17759305185505322, 0.23566202446818352, 0.1792467909732035, 0.13089486051883015, 0.1749427890671151, 0.2642478905618191, 0.1548749937542847, 0.14206900234733308, 0.20636356089796337, 0.17808910166578634, 0.22848125121423177, 0.8964129931160382, 36.75764853613717, 108.50662667410714, 88.18416718074253, 99.05970995766776, 83.97073786599296, 80.33512769426618, 41.56955746241978, 30.73066643306187, 37.55618415560041, 55.04662043707711, 40.92822483607701, 48.258824484688894, 73.88888086591447, 55.69535984311785, 34.694895131247385, 5.940221684319632, 0.19999039359390736, 0.17177198135427066, 0.15053326530115946, 0.3862303564591067, 0.971872438277517, 1.920226309980665, 2.587845491511481, 3.2384693792888095, 3.7046470386641364, 5.582915348666055, 4.60209504195622, 2.540087482758931, 8.276251213891165, 31.02867467062814, 56.9127710887364, 71.66132313864571, 75.7751361301967, 75.20117323739188, 72.72839968545097, 71.72523266928536, 70.56972639901298, 70.09808267865861, 72.7647179194859, 70.47508498600551, 67.69619464874268, 65.77865164620536, 68.51060690198625, 68.39081995827812, 66.54230730874198, 70.98539543151855, 73.39145238058907, 72.84344795772007, 68.89053440093994, 72.65855639321464, 73.68025425502232, 74.15269007001604, 70.8606266294207, 74.1425040108817, 71.96687017168317, 80.91357912336076, 60.61779376438686, 46.18504776273455, 67.5943410055978, 65.2926390511649, 73.19770881107875, 54.93723494665963, 46.87439244134085, 52.351546219417024, 61.28489031110491, 74.08252021244594, 72.02859796796525, 71.92437498910087, 66.55161094665527, 60.19699001312256, 59.59105151040213, 63.0970777784075, 67.7939419065203, 69.83343274252755, 70.20077705383301, 67.78499262673515, 66.88163648332868, 70.04462323869977, 67.679032598223, 58.98072869437081, 51.38067443030221, 34.737359046936035, 18.738742692129954, 15.18979219027928, 10.825895292418343, 14.073789034570966, 7.064524897507258, 8.350259951182775, 7.8016484294618875, 8.46022822175707, 8.167747276169912, 3.578582831791469, 1.5638743745429176, 1.1334960056202752, 0.7360035691942487, 0.3929120536361422, 0.31003252949033466, 0.23113217896648816, 1.0482857951096125, 12.702038322176252, 33.87846095221383, 58.10445315497262, 81.35171168191093, 76.22335747310093, 48.67144673211234, 45.72242627825056, 32.682477951049805, 36.01762022290911, 31.900166375296457, 41.674728870391846, 64.1620351246425, 79.33328778403146, 78.98931721278599, 82.55090822492326, 16.86679376874651, 0.4352426507643291, 0.1116269901394844, 0.15278704650700092, 0.11773176970226423, 0.1066683851448553, 0.19561970526618616, 0.2447122974055154, 0.277146895549127, 0.27402661155377117, 0.1776465339852231, 0.26129069924354553, 0.13677545211144856, 0.15796144599361078, 0.1915638843285186, 0.27240640563624247, 0.13184190541505814, 0.24279440460460527, 0.1796125349189554, 0.16315086824553354, 0.12752678910536425, 0.16475445005510533, 0.1955458399440561, 0.17545341381004878, 0.11575791133301598, 0.22636282417391027, 0.25577146826045855, 0.12240881659090519, 0.14304616062768868, 0.17241589751626762, 0.1563017357672964, 0.1257794392960412, 0.0913873558331813, 0.15547591793750012], [0.06183620582201651, 0.05572933976405433, 0.03620941058865615, 0.029661188035139015, 0.025562631265659417, 0.042378739187760014, 0.04033898489017572, 0.0550520159304142, 0.032420355693570206, 0.031027560787541524, 0.01273672400774168, 0.08125439884939364, 0.04308760811441711, 0.04990682737635715, 0.004930616273278636, 0.023143591159688573, 0.035903031671685834, 0.0678818646286215, 0.03465226771576064, 0.03224678982847503, 0.047134526672640016, 0.06817457106496606, 0.018461389101243446, 0.08165083293403898, 0.024018059950321913, 0.1541963501700333, 0.08512765315494367, 13.303801826068334, 85.9356050491333, 79.76163033076695, 76.04962471553257, 63.9788111277989, 45.15514407839094, 21.903560297829763, 21.991250038146973, 34.085395676749094, 45.79947485242571, 34.131385803222656, 54.209584849221365, 59.530970437186106, 47.449772766658235, 24.89165047236851, 3.6035820160593306, 0.15598532131740026, 0.014044209250382014, 0.046684155839362314, 0.020853613503277302, 0.024635521728279333, 0.1281490871416671, 0.4710596374103001, 0.07595662134034292, 1.2362380410943712, 0.7608899538006101, 0.9230576519455228, 0.45929134317806786, 12.366395166942052, 45.641479764665874, 68.2535513469151, 67.40409237997872, 67.28364535740444, 71.1368522644043, 67.22534302302769, 65.86603913988385, 76.61454800197056, 66.45129980359758, 64.68863909585136, 68.53621796199253, 65.26282433101109, 69.44301346370152, 68.5529214314052, 65.45922906058175, 62.87923090798514, 66.20099789755685, 68.49495261056083, 66.23756626674107, 62.43061351776123, 63.034773281642366, 63.849081311907085, 63.08834389277867, 65.0777312687465, 66.52962684631348, 62.64536149161202, 64.88069425310407, 65.69119467054094, 70.38275732312883, 39.35291188103812, 25.71258360998971, 55.77256127766201, 45.49925708770752, 34.40259483882359, 45.81635202680315, 62.91680676596505, 70.04713153839111, 64.85432583945138, 65.25322192055839, 60.698281696864534, 52.06355728421892, 52.55354772295271, 56.04238762174334, 63.19781276157924, 63.968027523585725, 66.42818314688546, 66.42568874359131, 65.68479537963867, 64.36397062029157, 64.16027723039899, 61.05967835017613, 58.30557223728725, 58.215377671378, 51.08427817480904, 36.220893246786936, 21.9134475844247, 15.694165400096349, 13.405860441071646, 8.42686470917293, 6.87976621729987, 4.178063418184008, 3.256877762930734, 2.088284126349858, 1.4263974257877894, 0.5629928814513343, 0.7903351166418621, 0.31638673852596966, 0.24264968665582792, 0.3287383828844343, 0.10180035778986556, 0.014380014534773571, 0.1593343530382429, 3.6378542227404456, 16.2500855582101, 34.373221329280305, 48.22558430262974, 56.60781465257917, 47.08470399039132, 54.6843934740339, 92.25328935895647, 82.31209863935197, 34.58763231549944, 36.89744629178728, 59.151911463056294, 60.11798204694475, 70.65083272116524, 47.183333669389995, 2.8702372184821536, 0.1567579691431352, 0.0378198014971401, 0.12789341514664038, 0.11533417978457042, 0.03449944466618555, 0.06006254242467029, 0.035326049596603425, 0.036634964003626785, 0.028479169854628186, 0.06627005897462368, 0.036353226085858684, 0.017179597435253005, 0.06267044427139418, 0.028680134963776385, 0.09077005859996591, 0.1671853153301137, 0.07020829657890967, 0.06359490073685135, 0.09478677556450878, 0.03924499645030924, 0.08601404380585466, 0.08274722338787147, 0.030087175712521588, 0.04416825994849205, 0.03308475682778018, 0.033423980232328176, 0.015070917550474405, 0.06834985023098332, 0.0560303243276264, 0.060338862240314484, 0.03691190128613796, 0.05897006033254521, 0.07282094138541392, 0.018674730689131787, 0.08868340735456773, 0.024945249215566685, 0.010657819935918918, 0.04320015671796032, 0.004770151223056018, 0.04535984208009072, 0.011101635272747703, 0.044157739263027906, 0.048791007072265656, 0.024897556685443436, 0.022384585280503546, 0.05666552809998393, 0.022321244036512713, 0.035483890412641425, 0.06298665516078472, 0.07026324434471981, 0.04971206746995449, 0.06710405315139464, 0.09223786555230618, 0.024900055390649607, 0.03381412090467555, 0.06328079330601863, 0.03315129057903375, 0.171500920185021, 0.06545143361602511, 17.31656108583723, 100.91150215693882, 89.5797198159354, 84.62351417541504, 79.4922000340053, 63.720866203308105, 38.72585085460118, 35.213744912828716, 38.44210726874215, 43.28273657390049, 49.6896253313337, 50.34848478862217, 43.08371932165963, 45.470397744859966, 30.33887141091483, 4.11158435685294, 0.08955156576952764, 0.021079068637586067, 0.018067842183102454, 0.02835571549699775, 0.11100558776940618, 0.6945955082774162, 1.1331690060240882, 1.887240388563701, 0.9068518472569329, 0.8025372933064188, 0.32807656696864534, 1.0139125138521194, 14.313365527561732, 49.931492124285015, 69.46045344216483, 70.82201548985073, 69.91681112561906, 72.94762229919434, 70.30124800545829, 66.9268136705671, 76.34467302049909, 69.16378620692662, 65.8632390158517, 71.49287796020508, 68.10972363608224, 70.63385827200753, 67.65654822758266, 67.48291969299316, 63.42376817975725, 67.70820113590786, 69.61845547812325, 70.05417701176235, 66.05418246132987, 64.70933777945382, 66.85849898202079, 66.2121775490897, 68.72475038255963, 69.7597609928676, 66.45849118913922, 68.95755672454834, 68.68083776746477, 72.55847454071045, 42.26305716378348, 32.829814502171104, 59.03825977870396, 50.62831653867449, 41.741143226623535, 46.70652743748256, 63.692406381879536, 70.20642593928746, 66.98649869646344, 68.19274766104562, 63.663925715855186, 56.18170942578997, 56.64246531895229, 59.31250517708914, 65.99515056610107, 68.44409874507359, 69.9074102129255, 68.69708265577043, 67.91581330980573, 65.36491421290806, 65.97091524941581, 61.937159402029856, 60.37441226414272, 59.74704551696777, 51.60438558033535, 39.777690001896445, 24.65006160736084, 17.939366340637207, 15.422337974820818, 10.110999482018606, 7.828293034008571, 6.272675616400583, 3.6038792686803, 3.394700710262571, 2.576392254659108, 1.7708097504717963, 2.305645057133266, 1.2820261269807816, 0.9836917583431516, 0.7570332693202155, 0.19892421151910508, 0.03294407955503889, 0.13641924836805888, 3.3471168407372067, 16.63504007884434, 34.842738900865825, 41.57390703473772, 43.0007335117885, 39.89871025085449, 44.91930832181658, 77.70650604793003, 68.12894930158342, 36.010498319353374, 45.07002517155239, 67.44196701049805, 71.06955201285226, 79.35475076947893, 66.06970473698208, 7.895838209560939, 0.12853005741323742, 0.045647120236286094, 0.10439032595604658, 0.07165884160037551, 0.03134583103071366, 0.031016083367701088, 0.0041992059892176515, 0.02579633060044476, 0.06086706782558134, 0.035393994700695784, 0.0171722947021148, 0.03542840999684163, 0.14697886817157269, 0.04357707952814443, 0.01714771137838917, 0.11179517861455679, 0.029717363949332918, 0.0776734845712781, 0.0827488179451653, 0.015529094929141658, 0.022989502642303705, 0.020582884816186767, 0.049829915431993346, 0.06747578856136117, 0.015708099252411296, 0.039099226772253, 0.03278198093175888, 0.03321244694026453, 0.043446848302015235, 0.05218721054760473, 0.036555012222379446, 0.06631092035344668, 0.1582659725099802, 0.16861196234822273, 0.17222973464855126, 0.14291905744799546, 0.19069838577083179, 0.22903053888252803, 0.17984744374241146, 0.18237935645239695, 0.10172750348491327, 0.14025544109089033, 0.2052910141646862, 0.1725827899894544, 0.060706092177757194, 0.1821690784501178, 0.10283760034612247, 0.10578536681298699, 0.14645916463008948, 0.1871538002576147, 0.16680610924959183, 0.1319528730320079, 0.1875572164676019, 0.11869196460715362, 0.18774560493017944, 0.2108154020139149, 0.12024998957557337, 0.2751903533935547, 0.19386274740099907, 25.715632132121495, 114.0951600755964, 98.44816425868443, 97.77987262180874, 84.81855010986328, 64.83844225747245, 34.28227635792324, 32.14374589920044, 50.063421045030864, 66.87268720354352, 49.66614042009626, 72.98208536420549, 76.46885122571672, 62.247417313711985, 37.70473664147513, 6.221433086054666, 0.3734041718500001, 0.1688704706196274, 0.14369880275002547, 0.12824917105691774, 0.20812042376824788, 1.6599566702331816, 2.441023758479527, 3.484477298600333, 4.497372227055686, 3.7739318694387163, 3.9442456790379117, 2.929059147834778, 16.994515555245535, 52.714690344674246, 74.33879062107631, 72.11013507843018, 71.48319911956787, 75.36349705287388, 70.54320512499127, 67.161315373012, 78.40865625653947, 70.24414770943778, 67.85553768702916, 73.34743554251534, 70.55127893175397, 72.69807079860142, 71.11538233075822, 68.09582029070172, 63.67258317129952, 68.04612677437919, 72.01167215619768, 74.0760931287493, 68.5805891581944, 70.09092603410993, 69.48917729513985, 70.32672010149274, 73.43798446655273, 72.87037917545864, 68.85003335135323, 71.42699514116559, 71.23419652666364, 75.64230046953473, 46.65479115077427, 38.6688791002546, 63.728272983006065, 56.42806475503104, 49.39768634523664, 52.09315313611712, 64.17437512534005, 74.23658261980329, 69.63998099735805, 70.29436928885323, 67.17778955187116, 60.129766191755024, 60.373439516339985, 61.9143762588501, 68.77341556549072, 71.38447911398751, 71.47561863490513, 70.76702744620187, 68.91496426718575, 68.11315604618618, 67.66648415156773, 64.91558810642788, 61.332443782261436, 61.97556904384068, 54.409679072243826, 42.57754305430821, 25.650801965168544, 19.07280513218471, 17.453527450561523, 10.392329437392098, 10.420752780778066, 9.829587885311671, 8.614334055355616, 9.546617286545889, 8.088741047041756, 4.7985071539878845, 3.1502969563007355, 1.6166325892720903, 1.9262026292937142, 0.6629445095147405, 0.38678830223424093, 0.16884953102895192, 0.3634314169841153, 6.000036120414734, 25.83685040473938, 50.946109771728516, 65.23236342838833, 77.25889614650181, 63.39426612854004, 66.51032475062779, 100.34946932111467, 89.90027495792934, 44.59030417033604, 53.103299617767334, 75.02040890284947, 80.83657223837716, 88.10442270551408, 79.65330791473389, 9.167615635054451, 0.25050381092088564, 0.09714326661612306, 0.2440261627946581, 0.1464184389582702, 0.1330722522522722, 0.1100303293871028, 0.14487501606345177, 0.09817400202155113, 0.20386134088039398, 0.13442040633942398, 0.17247533718390123, 0.2030052061059645, 0.2156378318156515, 0.1794198988271611, 0.25609225247587475, 0.2591856122016907, 0.14157246399138654, 0.1532153513814722, 0.13832332619598933, 0.1040685646502035, 0.26123959198594093, 0.1464164847774165, 0.15527651006621973, 0.1223229140575443, 0.12043018133512565, 0.11534202364938599, 0.14406183255570276, 0.20145632778959616, 0.14707934563713415, 0.22373852213578566, 0.1817732211202383, 0.21020291559398174], [0.06308914787535157, 0.026514174849061028, 0.025744994337271367, 0.029031124165547744, 0.029677645902016332, 0.060128740301089625, 0.030360126601798192, 0.06419547208185707, 0.055078536471618075, 0.06895658945930855, 0.051621237703199895, 0.02863857808655926, 0.0403693662956357, 0.0396195817073541, 0.054530436239604435, 0.0729844072567565, 0.05232173690040197, 0.035722826341433186, 0.03198855297107782, 0.015901888853737285, 0.07384722560111966, 0.07025947169001613, 0.036752184320773394, 0.04564817875091519, 0.02330280770547688, 0.0744124384863036, 7.811958687646048, 69.43609305790493, 70.8836738041469, 77.05038070678711, 55.34951325825283, 27.028813873018535, 37.28570120675223, 43.08256939479283, 27.83341179575239, 15.528621094567434, 25.6896493434906, 26.80572806085859, 37.272878306252615, 48.35514388765608, 23.115433829171316, 2.65340695636613, 0.2367616311780044, 0.08729475151215281, 0.08214349685502903, 0.025872216260592853, 0.2106072274701936, 0.12540089817983763, 0.2669607007077762, 0.16117228727255548, 0.783899401979787, 0.7234321066311428, 0.634305554841246, 0.9824117698839733, 24.43547865322658, 62.49437713623047, 71.94744995662144, 66.15969780513218, 67.25868047986711, 66.17686680385044, 68.88243280138288, 68.63847460065568, 62.6876551764352, 66.10566166469029, 66.03925773075649, 68.64690276554653, 61.24812044416155, 64.14421994345528, 62.254956109183176, 64.30418137141636, 64.21288204193115, 62.40837928227016, 63.109848567417686, 64.5229801450457, 58.36003221784319, 56.63058737346104, 54.00298016411917, 55.07349259512765, 58.470550264631, 61.4482980455671, 59.19863115038191, 54.32851716450283, 57.386638232639854, 61.86409214564732, 75.40879930768693, 66.56654957362584, 22.23497894832066, 33.58011225291661, 32.01153557641165, 40.57847683770316, 62.2896762575422, 62.758714403424946, 65.96579442705426, 63.11494854518345, 63.41792474474226, 54.58258499417986, 50.859833989824565, 52.52997595923287, 62.98260620662144, 65.24277182987758, 68.25444071633476, 67.3293228149414, 63.17084680284773, 59.68334443228585, 56.27352292197091, 56.32391473225185, 56.531867367880686, 54.022226674216135, 55.25915540967669, 56.702185085841585, 55.335679394858225, 53.290206159864155, 43.500145707811626, 41.97498485020229, 40.39877210344587, 31.572722094399587, 15.515284027372088, 12.773726361138479, 4.209587395191193, 1.5318122378417423, 2.165454511131559, 1.4565307859863554, 0.4226994966822011, 0.6502819604107312, 0.041478550527244806, 0.07886721765888588, 0.10406494127320391, 0.15692321956157684, 0.1152052174189261, 0.43571748957037926, 3.793276522840772, 21.49557249886649, 44.12210675648281, 48.96629006522042, 56.03389344896589, 81.60455662863595, 120.17595945085797, 88.64433942522321, 37.435490471976145, 41.053455693381174, 67.03908266339982, 59.11725384848458, 68.40454959869385, 46.389811175210134, 1.8746469957487923, 0.11477109071399484, 0.03232618181833199, 0.059309762104281356, 0.09084552526473999, 0.05197359076035874, 0.07291048086647477, 0.009173556813038886, 0.03019645038459982, 0.11003066865461213, 0.04389709360631449, 0.09347891288676433, 0.06779554818889924, 0.04390474748132484, 0.05088737154645579, 0.024978258247886385, 0.06197750395429986, 0.04162958902972085, 0.01416107248847506, 0.05442942951672843, 0.04921989548685295, 0.05099043083776321, 0.06291643357170479, 0.0744893504306674, 0.0865142937483532, 0.07306655749146428, 0.05446592113003135, 0.13214476273528167, 0.10307810029813222, 0.01198580626597894, 0.04635955825714128, 0.044936117316995344, 0.04899881859975202, 0.02828442182258836, 0.05900017371667283, 0.06589499195771557, 0.0452441857861621, 0.03820398463202374, 0.02808202330821327, 0.021103631605261138, 0.042756109831056426, 0.05951455754360982, 0.035414785013667176, 0.029537735373846123, 0.01398748457099178, 0.042428967742515464, 0.04352882211761815, 0.07285018624471766, 0.022533564429197992, 0.025621485696839433, 0.021599979971402457, 0.07426089447523866, 0.011782693593496723, 0.11602502342845712, 0.15999364480376244, 0.03915335351069059, 0.021957065810316374, 0.03287132363766432, 8.918586117880684, 82.19283281053815, 79.53623076847622, 86.34185927254813, 62.42106669289725, 38.06652586800711, 48.455444608415874, 37.51564141682216, 21.461243186678203, 25.421593053000315, 40.18240172522408, 33.26366697038923, 43.784757818494526, 50.68515975134713, 25.185479368482316, 2.7445529912199293, 0.23514375942093985, 0.06985333455460412, 0.0531807452706354, 0.08575041938040938, 0.3610191707100187, 0.8438385256699154, 1.1918276527098246, 1.0515874922275543, 1.0531800410577228, 0.6128604827182633, 0.189766920038632, 1.947078057697841, 27.1562751020704, 65.21761240277971, 74.52528721945626, 69.0625023160662, 70.22351850782121, 70.1488948549543, 70.20460551125663, 73.04575865609306, 64.87565680912563, 66.25474916185651, 69.3075235911778, 70.08844552721295, 64.73223904200962, 66.59676728929792, 65.94227477482387, 67.19596603938511, 66.14718409946987, 65.66826561519078, 64.44268676212856, 66.79281071254185, 61.359611238752095, 59.28592136928013, 57.78752497264317, 59.03290271759033, 62.2384888785226, 63.38433715275356, 62.812236377171104, 57.570560523441856, 59.45133018493652, 66.63514913831438, 76.39797265189034, 69.19678320203508, 25.93778167452131, 41.117177622658865, 37.271686690194265, 43.206358500889365, 62.603588921683176, 65.17789649963379, 67.76985250200543, 66.7299781526838, 64.4537274496896, 56.67663655962263, 52.40371676853725, 56.35462229592459, 64.63311604091099, 69.32421316419328, 70.68417017800468, 68.78167697361538, 65.16503538404191, 60.54444858006069, 59.112362316676546, 58.39862946101597, 56.94778653553554, 54.68099233082363, 56.42777293069022, 60.30436747414725, 56.941279547555105, 53.660548618861604, 45.132750034332275, 42.65182624544416, 42.72800629479544, 34.47546754564558, 19.966694355010986, 12.580694113458906, 4.524709045886993, 2.067423028605325, 3.7999159608568465, 3.5801357541765486, 2.4068594660077776, 1.5644946098327637, 0.8173673546739987, 0.46474269351788927, 0.067163011059165, 0.1145915367773601, 0.15171017072030477, 0.35312409007123535, 4.514865619795663, 23.78581861087254, 41.546906335013254, 51.0425820350647, 60.846625736781526, 92.4889166695731, 123.88589450291225, 90.69496822357178, 47.4908435685294, 49.35629940032959, 72.36257702963692, 65.3540402821132, 76.89630440303257, 63.49911444527762, 4.446857954774584, 0.17296055757573672, 0.04915968228929809, 0.14053963869810104, 0.08043888796653066, 0.05239268791462694, 0.047255231267107387, 0.03566283366775938, 0.026986779578562294, 0.04130688116752675, 0.034596716053783894, 0.06797437609306403, 0.03331714828631707, 0.04177277009668095, 0.060280589652912955, 0.03698976657220295, 0.05853084461497409, 0.05189465678163937, 0.02487572482121842, 0.05092303195436086, 0.0641836587871824, 0.07348121702671051, 0.05597609920161111, 0.06705269483583313, 0.08059528350297894, 0.02848980249837041, 0.030319431464054754, 0.03559694452477353, 0.08907427066670996, 0.049109239996011765, 0.06071764762912478, 0.06417976399617535, 0.2519117168017796, 0.13204752866710934, 0.11682052431362015, 0.14841348119080067, 0.1289832509521927, 0.09223544996763978, 0.1269417562122856, 0.21390329274748052, 0.16835838024105343, 0.1515289611582245, 0.26441809428589685, 0.1024113107206566, 0.06742905785462686, 0.10973302248333182, 0.14327178709208965, 0.21872845025999205, 0.1767673154494592, 0.06446803281349794, 0.09651945544672863, 0.163352352433971, 0.1270387460078512, 0.2123231746788536, 0.2091277361448322, 0.22701490989753179, 0.14610142739755766, 0.1529840523643153, 11.895652106830052, 95.93466036660331, 87.69947474343437, 98.65474115099225, 75.09834684644426, 40.0140711920602, 49.60630600793021, 57.599732535226, 44.12831497192383, 27.7356367451804, 36.9980388368879, 37.30980450766427, 53.36547599520002, 65.40728432791573, 34.218120166233604, 4.996317156723567, 0.5322218611836433, 0.18574349236275467, 0.2920542556260313, 0.2875351038362299, 0.802645913192204, 0.5950993129185268, 1.2026186393839973, 3.879206197602408, 4.7526321070534845, 4.638444108622415, 3.3631756475993564, 3.003838049513953, 28.469640970230103, 67.86624486105782, 77.21326732635498, 71.94667870657784, 73.86188016619, 73.54742554255894, 74.28980582101005, 74.34783022744315, 66.38434001377651, 66.76444121769497, 73.1007536479405, 72.7955401284354, 68.40156882149833, 71.64852455684117, 69.25794124603271, 72.01283250536237, 71.08572047097343, 66.01506410326276, 66.01456383296421, 69.72020489828927, 65.26884841918945, 63.81533391135079, 61.02429117475237, 63.54734883989607, 64.60526071275983, 65.98274803161621, 65.3928529194423, 60.48872402736119, 62.48017501831055, 68.98186152321952, 79.40194988250732, 74.46848569597516, 33.784691538129536, 45.90549046652657, 41.86604751859392, 48.42364270346505, 66.28541851043701, 68.28627041407994, 70.71405438014439, 70.59859616415841, 68.1896001270839, 59.998959405081614, 55.5449869292123, 57.380190304347444, 68.71426555088588, 71.25338050297329, 71.82908739362443, 70.88778713771275, 67.41677979060582, 62.71394715990339, 60.06996999468122, 58.014362812042236, 57.39925616128104, 55.26843472889492, 57.264805044446675, 62.75650487627302, 59.24283558981759, 58.685360772269114, 45.71322338921683, 44.41475098473685, 45.45405558177403, 36.54415471213204, 19.657258067812236, 19.063746418271744, 9.192765508379255, 7.497060247829982, 9.246423840522766, 6.1963288102831156, 3.7704642840794156, 1.7931536372218813, 0.8635238579341343, 0.6077694073319435, 0.4072237413908754, 0.221802308889372, 0.2859226603593145, 0.737962038389274, 7.618073548589434, 34.111593859536306, 57.2958356993539, 63.34801197052002, 66.28193051474435, 88.25358663286481, 121.56548799787248, 95.46898514883858, 48.57130234582083, 56.53061669213431, 80.19364847455705, 78.43075847625732, 85.22672203608921, 73.88698400769914, 4.160066281046186, 0.25542183273604935, 0.13407260285956518, 0.2188408292297806, 0.243883344743933, 0.156707676127553, 0.16559789622468607, 0.10662522353231907, 0.07535262339349304, 0.180041871166655, 0.0956096892644252, 0.2974749633244106, 0.14960280380078725, 0.15793209256870405, 0.16774183618170874, 0.18640222772955894, 0.16444464453629085, 0.11199730741126196, 0.07905143313109875, 0.12897786338414463, 0.1596490168677909, 0.1315580335046564, 0.16981595488531248, 0.181055466777512, 0.14142774604260921, 0.19644195400178432, 0.1287991644016334, 0.21429301612079144, 0.20529204553791455, 0.11413944246513502, 0.16799680250031607, 0.13052280619740486], [0.05100392011393394, 0.020951843321589485, 0.03633818635717034, 0.017708617262542248, 0.05613748536312154, 0.05621760677812355, 0.078860635869205, 0.060003123113087246, 0.06399994543088333, 0.016925469107393707, 0.04517330941078918, 0.066449524701706, 0.038717343871082575, 0.007345581776462495, 0.061078411127839766, 0.049763880403978486, 0.03772338167099016, 0.04795085179752537, 0.022551596497318575, 0.05291720226939235, 0.07295943716807024, 0.051080686173268726, 0.04650032373943499, 0.08739382441022567, 0.04999909456819296, 0.9066201139773641, 46.29091051646641, 76.36311353955949, 78.99557753971645, 69.3480246407645, 66.25910568237305, 43.32645811353411, 91.73215362003872, 156.1586788722447, 85.6934255872454, 36.59617934908186, 28.345434972218104, 68.40787778581891, 47.13117354256766, 17.887086357389176, 4.045913892132895, 0.14695931279233523, 0.053492504970303605, 0.11328340947095837, 0.2402687615581921, 0.3990533926657268, 0.2227045161915677, 0.31813879736832207, 0.29545358036245617, 0.47738988058907644, 1.0933762384312493, 0.4620985782572201, 2.8244147172995975, 36.32188183920724, 69.30471651894706, 71.34227575574602, 66.04619203295026, 65.42217431749616, 60.21605587005615, 66.54601069859096, 69.36405413491386, 70.1769516808646, 65.77917276109967, 61.434137616838726, 66.77571119580949, 59.121193477085654, 59.29025704520089, 57.03501074654715, 57.16323280334473, 55.89549922943115, 63.13149915422712, 65.04129491533551, 64.72891085488456, 60.88836356571743, 59.34294523511614, 57.76561035428728, 50.72010571616036, 48.35950040817261, 53.47328424453735, 53.82538420813424, 53.54965189525059, 49.50858654294695, 58.05013561248779, 64.12996223994664, 70.5023775100708, 52.71732023784092, 37.911052976335796, 24.779371057237896, 29.553905623299734, 46.91491086142403, 51.73691552025931, 62.75442041669573, 62.42930725642613, 62.14944771357945, 55.953641755240305, 53.01984480449131, 48.474037987845286, 54.326832226344514, 63.06834697723389, 67.88210759844098, 55.16429165431431, 63.377798897879465, 58.209294523511616, 57.55750138419015, 61.20930780683245, 65.67599201202393, 62.97619996752058, 62.310076168605256, 62.27705832890102, 62.052784374782014, 58.27629600252424, 56.30023874555315, 56.6754275730678, 61.57515825544085, 64.89913477216447, 61.890627316066194, 53.955218247004915, 30.514320373535156, 12.792527318000793, 2.1063540024416785, 1.4446853016104018, 3.3309972371373857, 2.268998737846102, 0.359295121793236, 0.901717617043427, 0.08505608128117663, 0.12205639907291957, 0.08536535754267659, 0.1894251283790384, 0.11904571205377579, 0.20878907931702478, 0.9633573123386928, 8.052496637616839, 27.917846305029734, 36.733166558401926, 45.929176875523154, 63.07349559238979, 59.821780341012136, 26.524167946406774, 29.662009171077184, 44.7485111781529, 54.055275780814036, 57.522996629987446, 65.93223462785993, 31.94112253189087, 0.38132867376719204, 0.10730170937521116, 0.09193494716393096, 0.07602850534021854, 0.015191500008638417, 0.06465568167290517, 0.09207716131848948, 0.02266552931229983, 0.049256261571177413, 0.03328824608719774, 0.03155802250174539, 0.049509660473891666, 0.07329399564436503, 0.034757318507347784, 0.12006257820342268, 0.04217617952131799, 0.07940229680389166, 0.055861464102885554, 0.06665541936776467, 0.038761343474366834, 0.07683906970279557, 0.005178490628687931, 0.04688027960115245, 0.0604292702461992, 0.03063586287732635, 0.031833008996077945, 0.041124915038900714, 0.053739050669329505, 0.061115411642406664, 0.03376141908977713, 0.09155160201979534, 0.04930318905306714, 0.04680997658787029, 0.03085721457110984, 0.06079481063144548, 0.06962656136602163, 0.0834086796801005, 0.08380248104887349, 0.052198613328593116, 0.029208320192992687, 0.013377802197023161, 0.061846037794436724, 0.022442566097847054, 0.1006650940648147, 0.04336459967972977, 0.0337781008732106, 0.0493563726278288, 0.012695418188481458, 0.08538428866969687, 0.08964147844484874, 0.028385643980332782, 0.07003772644592182, 0.015971866170210496, 0.03668544361633914, 0.062637799951647, 0.043987681423979144, 1.3952515827757972, 59.12856551579067, 91.68903309958321, 89.20323167528424, 81.2149989264352, 72.65865366799491, 44.57182196208409, 90.10111263820103, 124.98669760567802, 61.0184268951416, 18.452992813927786, 26.882628985813685, 49.537633487156455, 44.18070786339896, 21.766256945473806, 4.598000815936497, 0.05991668453706162, 0.039613722557468076, 0.1851506834583623, 0.5378508791327477, 1.032197566969054, 1.4488665972437178, 2.1918947952134267, 1.3495434011731828, 1.2459056994744708, 0.1861806453338691, 0.20443608718258993, 3.772636030401502, 39.47139951160976, 74.55544240134103, 74.04867553710938, 68.86399228232247, 68.48845604487828, 61.690665108816965, 68.30201503208706, 70.55592727661133, 72.55015059879848, 67.21827670506069, 63.53614139556885, 71.35060664585659, 63.49172156197684, 63.4001373563494, 60.60040937151228, 60.19722625187465, 60.20573779514858, 66.84099646977016, 68.27640397208077, 68.03292519705636, 64.81786864144462, 62.54326466151646, 61.16217817578997, 53.69916670663016, 51.99636820384434, 57.42847333635603, 56.87694617680141, 55.24473442350115, 52.098544938223704, 59.90752805982317, 66.93353952680314, 71.86800425393241, 59.21810695103237, 43.19051660810198, 28.82200149127415, 33.64440393447876, 50.253072125571116, 58.387998717171804, 64.38969979967389, 65.29245144980294, 63.22295134408133, 58.13616820744106, 54.68017591748919, 49.7145346232823, 56.14283772877285, 68.07968657357353, 70.44677802494594, 59.12779426574707, 65.15739931379045, 58.54743208203997, 58.68040670667376, 62.96814700535366, 67.28709861210415, 63.710207666669575, 62.95754405430385, 62.79144736698696, 63.950636182512554, 59.71076897212437, 56.841156005859375, 57.1358117376055, 62.433747155325754, 67.54694734300885, 65.0801214490618, 56.59627022062029, 35.15176350729806, 14.71996716090611, 2.3282258340290616, 1.0303755104541779, 2.2726011616843085, 3.3313020893505643, 2.743524657828467, 2.3875749579497745, 0.7206486474190439, 0.3705818461520331, 0.09972159790673427, 0.16818567950810703, 0.11853720434010029, 0.15498092664139612, 0.8062058878796441, 9.100032244409833, 29.819913932255336, 41.9679011617388, 50.32792854309082, 72.4393059866769, 65.02990681784493, 32.13980279650007, 41.88943862915039, 53.66150747026716, 62.002528054373606, 64.795745577131, 74.72875826699394, 47.31549882888794, 0.7322369398815292, 0.14757288486829825, 0.017445595036926012, 0.10473055019974709, 0.06113506880189691, 0.039362098023827584, 0.1083260936928647, 0.013672978500835598, 0.04489721351170114, 0.00902228506415018, 0.04108748026192188, 0.04961285207952772, 0.039148573231484206, 0.02029355239522244, 0.022810016559170823, 0.013101070171355136, 0.06869034588869129, 0.026585921445595365, 0.03873140990201916, 0.017011844918930104, 0.07355613407811948, 0.04938560391643217, 0.04508487254913364, 0.08607078968946423, 0.03179236474846091, 0.026508980663493276, 0.03585350200799959, 0.06318317247288567, 0.036791101696767976, 0.03696687619334885, 0.06743564642965794, 0.11354925949126482, 0.10813949656273637, 0.16640737493123325, 0.20358653419784137, 0.19300459059221403, 0.13409952712910517, 0.15993885988635675, 0.15716633865875856, 0.21674792867686066, 0.06820139355425324, 0.08805435789482934, 0.18606963700481824, 0.13492762483656406, 0.15056989262146608, 0.10608540142753295, 0.15424669746841702, 0.14826276499245847, 0.15378124958702497, 0.25189597478934694, 0.09034374861844949, 0.1536026998822178, 0.14326657594314643, 0.19524489609258516, 0.13467127430651868, 0.14004384673067502, 2.4139344692230225, 73.26536342075893, 97.97628429957798, 101.70603561401367, 86.74247850690568, 85.40241418566022, 55.97057798930577, 96.8316867010934, 152.00554602486747, 101.16258226122174, 54.44231128692627, 42.672229630606516, 89.17688410622733, 64.63943195343018, 30.159924030303955, 7.008479859147753, 0.43100034126213616, 0.19876901698963984, 0.3520572158907141, 0.8756578554000173, 1.6080968358686991, 1.4971982666424342, 1.862940366779055, 2.2844864896365573, 2.8567983167512074, 3.997085426534925, 2.2253790327480862, 4.297796079090663, 41.99302237374442, 77.14424392155239, 78.14950234549386, 73.02897875649589, 70.77740110669816, 64.44807161603654, 71.97080285208565, 74.52039568764823, 76.45698370252336, 68.42591530936105, 66.35709612710136, 74.60648386819022, 65.72083568572998, 66.28368146078927, 62.04199382237026, 62.321290561131065, 62.243241446358816, 70.52973951612199, 71.35176004682268, 70.57641751425606, 67.65180260794503, 65.58521379743303, 63.550392150878906, 57.73088673182896, 55.13274335861206, 60.62226145608084, 61.17374692644392, 58.78749234335763, 55.076511587415425, 63.96162823268345, 70.12290164402553, 73.36643886566162, 63.26398740495954, 48.05406107221331, 34.99800334657942, 38.052566937037874, 51.36302253178188, 59.59534549713135, 65.96289008004325, 67.7381339754377, 67.11214297158378, 61.25570787702288, 57.193579060690745, 52.85592985153198, 59.62004634312221, 70.26967539106096, 72.14285414559501, 61.945219312395366, 67.82659149169922, 59.656920433044434, 60.644183022635325, 63.84378678458077, 69.31587532588414, 67.17563561030796, 68.00816181727818, 66.0493951525007, 67.80353042057583, 61.069537843976704, 58.3075316292899, 59.14974362509591, 65.55215426853725, 70.39315182822091, 69.76156057630266, 59.295794759477886, 36.596571922302246, 17.269195216042654, 5.617093103272574, 4.561468056270054, 10.54901305266789, 6.494924604892731, 4.976173026221139, 2.767553265605654, 0.8203769560371126, 0.4101412519812584, 0.24184434701289448, 0.30564683196800096, 0.3014304967863219, 0.3898814448288509, 1.5905269043786185, 14.758439336504255, 42.9558481488909, 53.05166755403791, 57.172602449144634, 69.76817526136125, 64.56332833426339, 34.941413743155344, 42.80564546585083, 56.519708020346506, 73.057785987854, 73.65303121294293, 83.93415560041154, 51.96941614151001, 0.8252526372671127, 0.2883728774530547, 0.2788575366139412, 0.22805412699069294, 0.18650095457477228, 0.11153394263237715, 0.19576219762010233, 0.08406584763101169, 0.1208339910954237, 0.15747268364897796, 0.23120323515364102, 0.26000297548515455, 0.14611609732466085, 0.22249830939940043, 0.16256199484424932, 0.27840704364436014, 0.10768565163016319, 0.2250155657529831, 0.10366879217326641, 0.17944628026868614, 0.17714538159114973, 0.12423330226114818, 0.11190654656716756, 0.11488953578685011, 0.12334640270897321, 0.09493973771376268, 0.16958802140184812, 0.12237726471253804, 0.1304285576833146, 0.09470320719161204, 0.15524246117898396], [0.04744730756751128, 0.02757616527378559, 0.03640294234667506, 0.07208791321941785, 0.0610615291765758, 0.04818554688245058, 0.06998708737748009, 0.08506888523697853, 0.04358791573239224, 0.07265402855617659, 0.06574502893324409, 0.01625284243242017, 0.09687057017747845, 0.02166626096836158, 0.03933492608900581, 0.03326273995584675, 0.07195931047733341, 0.029547825189573423, 0.021701855219102333, 0.03586070465722254, 0.06604213906185967, 0.04322485878531422, 0.01953348800140832, 0.012313749874010682, 0.08423174944307123, 34.298969405038015, 80.448550088065, 72.14414651053292, 68.36878722054618, 54.16609607424055, 43.662243706839426, 31.030529839651926, 46.99142789840698, 58.567547116960796, 50.8993171283177, 56.00838313783918, 63.67361150469099, 47.46968630381993, 20.359397854123795, 4.697093852928706, 0.02564344139370535, 0.04672470169940165, 0.08117231646818773, 0.09903650145445551, 0.6945612015468734, 0.2015691138803959, 0.14165855651455267, 3.8535608308655873, 1.217310062476567, 1.0682259308440345, 0.7020991827760423, 6.513557067939213, 47.711077145167756, 69.90603446960449, 65.19470419202531, 66.70688928876604, 61.66690921783447, 56.79538474764143, 58.7930509022304, 59.81910528455462, 64.15461444854736, 65.68464946746826, 64.97262586866105, 60.391421454293386, 63.58039447239467, 59.89754349844796, 52.60057660511562, 44.809294019426616, 48.553237029484336, 50.73556893212454, 56.9840144429888, 57.78337689808437, 62.66510827200753, 61.19341032845633, 62.17266164507185, 58.90943322862898, 55.68370771408081, 48.09177589416504, 48.57560328074864, 46.062050751277376, 46.39310114724295, 50.30380092348371, 52.016111510140554, 59.128732272556846, 63.14342226300921, 65.27038397107805, 63.211577142987935, 18.31591875212533, 27.15991074698312, 55.20041881288801, 60.517475673130576, 67.19188744681222, 56.03032207489014, 59.4033111844744, 49.16271563938686, 51.60413544518607, 47.44195604324341, 51.75876065662929, 58.17985153198242, 64.77185767037528, 57.75024093900408, 48.55520684378487, 59.34591211591448, 63.3321144921439, 62.250571795872276, 61.63578128814697, 59.31877940041678, 59.15869985307966, 57.48729331152779, 58.71097183227539, 64.85436752864292, 54.592878750392366, 53.6036011832101, 60.736357825142996, 63.75040994371687, 63.64031573704311, 67.17698356083461, 62.84531675066267, 42.647327286856516, 17.676832130977086, 2.735316012586866, 2.161840145077024, 1.4953937977552414, 2.4510341584682465, 1.438811685357775, 0.48541412715400967, 0.10408910390521799, 0.044197901750781705, 0.0878447312861681, 0.060609692707657814, 0.08379643530185733, 0.06157067471316882, 0.1786153462848493, 2.025498466832297, 22.879709243774414, 36.833314418792725, 40.27580983298165, 44.92152827126639, 52.4275039264134, 25.929593222481863, 29.603512287139893, 42.711594649723594, 54.154926845005576, 62.8067820412772, 73.46093436649868, 9.652229905128479, 0.48787644931248253, 0.09397023330841746, 0.10011518892965146, 0.012366349908656307, 0.06517569734049694, 0.04075145614998681, 0.068899735010096, 0.020772672757240276, 0.0696356605206217, 0.039868872080530436, 0.06508801704538719, 0.016091719203229462, 0.045563497580587864, 0.04724816093221307, 0.03058503721175449, 0.06052402087620326, 0.07933654676058463, 0.07442681664334876, 0.048056771113936386, 0.025128360372036695, 0.07049255525427205, 0.0732977818697691, 0.015530416376090475, 0.037963973225227425, 0.0025420387849278215, 0.0562249112075993, 0.009353380467343544, 0.04758197980533753, 0.02916974208450743, 0.07038340611117226, 0.06360829501811947, 0.04212776604773743, 0.02463934018409678, 0.02873406492705856, 0.04569364398983972, 0.030327377109123126, 0.04757857695221901, 0.07507853595806019, 0.021018548402935266, 0.011671845568343997, 0.03381958311157567, 0.03923321368971041, 0.011632529553025961, 0.011727502403248633, 0.01596642771203603, 0.05024242740390556, 0.023869029911501066, 0.03186369913497141, 0.026888139246563827, 0.0498645308959697, 0.036021303718111346, 0.06822717109961168, 0.025384695635044148, 0.0658481933974794, 0.20742743595370225, 40.5442395891462, 92.44879082271031, 79.37381662641252, 77.49052129473004, 61.840954644339426, 60.85734680720738, 40.23602097375052, 58.76206193651472, 83.30217524937221, 55.1605361529759, 53.53308391571045, 56.01615469796317, 50.16859245300293, 23.639334951128276, 6.5383912324905396, 0.03657331909718258, 0.050067646961127005, 0.17520638635115965, 0.17803779084767613, 1.7142893033368247, 1.896152104650225, 1.8978841602802277, 2.7166822467531477, 4.987875095435551, 0.6293336844870022, 0.16042437883360045, 6.937195684228625, 51.67327002116612, 72.85676765441895, 69.15440613882882, 69.25220203399658, 64.82412896837506, 60.740130696977886, 60.87336240495954, 62.44639982495989, 68.23559025355748, 68.6818174634661, 67.19433321271623, 61.8923157283238, 67.45127759660993, 62.36005456107003, 55.73524250302996, 46.655677046094624, 52.91583374568394, 54.16626630510603, 60.94636712755476, 61.730992453438894, 65.25841917310441, 64.32780524662563, 64.6986722946167, 61.987415722438264, 57.89202240535191, 51.13157108851841, 50.95940167563302, 47.588521344321116, 50.23930079596383, 52.074278354644775, 54.38914367130825, 60.3353078024728, 66.61782033102853, 67.42297063555036, 67.83945260729108, 21.933809280395508, 29.62152201788766, 58.932959829057964, 63.39448152269636, 69.17545918055943, 58.52223791394915, 62.63033948625837, 50.846740109579905, 52.31750699451992, 50.49110698699951, 54.06308555603027, 62.75211361476353, 66.12859766823905, 60.75640337807791, 51.34996339253017, 60.048291615077424, 62.54168742043631, 64.57858657836914, 63.87263570513044, 61.483365603855674, 62.834345545087544, 61.864467348371235, 62.40232045309884, 67.33720207214355, 55.80273730414254, 55.77546909877232, 64.27647195543561, 66.5717259815761, 65.20270156860352, 69.57124246869768, 65.78992857251848, 45.948722158159526, 20.224392618451798, 3.0300136506557465, 0.8372926712036133, 1.112089257155146, 3.0956686990601674, 2.5412708478314534, 1.7776929182665688, 0.8301645794085094, 0.23097839578986168, 0.15057863215250628, 0.02505957897353385, 0.021841116049992185, 0.04731145467875259, 0.19129962208015577, 1.6271000504493713, 25.377814190728323, 34.83850744792393, 40.47455957957676, 38.357238497052876, 42.71155643463135, 31.439125605991908, 35.90704659053257, 49.947955880846294, 61.536790302821565, 71.78849601745605, 87.7671571459089, 19.015169824872697, 0.683054007589817, 0.12694926080959185, 0.1202002258173057, 0.05478058156690427, 0.040609038434922695, 0.04297516468380179, 0.05060427655865039, 0.020315555589539663, 0.023957929873306836, 0.012191505005050982, 0.07258341341678586, 0.06007787731609174, 0.030019281498555626, 0.034569774820868454, 0.02043738485580044, 0.052812463603913784, 0.045974092691072395, 0.05050447423543249, 0.07122673014444963, 0.07382298833025353, 0.04914548733670797, 0.040793308189937046, 0.022122419705348353, 0.028718621470034122, 0.015642344120091627, 0.05301410046273044, 0.05578971241733857, 0.007824197478060211, 0.04204743767955473, 0.0476834547173764, 0.15950587312025682, 0.20889874414673873, 0.145679256479655, 0.13239397507693085, 0.14826003728168352, 0.08895181545189448, 0.19739473930427007, 0.15549833673451627, 0.09437687934509345, 0.11277081019112042, 0.08791035919317178, 0.2199106618229832, 0.15450954836394104, 0.10661250100071941, 0.1755830411400114, 0.11679072305560112, 0.1403206211647817, 0.09827495446162564, 0.10013673241649355, 0.1573239080607891, 0.10497208152498518, 0.1738281731626817, 0.18610729569835321, 0.1757189788456474, 0.362309744315488, 52.54542875289917, 103.79280199323381, 91.99965231759208, 87.63217449188232, 73.20090498243059, 60.799864360264365, 43.52430806841169, 55.49000930786133, 65.94641590118408, 61.275572776794434, 72.45276464734758, 86.5930574962071, 63.496960503714426, 31.481294223240443, 7.872389776366098, 0.22423216993255274, 0.1221824980207852, 0.3504011833242008, 0.39343563839793205, 3.119077831506729, 2.7846775352954865, 1.643674978188106, 10.467229281152997, 3.9284902044704983, 4.319451877049037, 2.1811559200286865, 8.963428054537092, 53.957886355263845, 77.49845613752092, 71.14719813210624, 71.824508530753, 67.32032489776611, 63.63695975712368, 63.985391071864534, 65.72770050593785, 69.65693460191999, 72.3887300491333, 69.33033452715192, 63.45281859806606, 70.40269865308488, 66.13048063005719, 59.9580067225865, 49.16238212585449, 54.1679026058742, 56.35461187362671, 63.54832853589739, 63.84421757289341, 68.87799290248326, 68.60835415976388, 68.04707867758614, 65.35672228676933, 60.81499753679548, 54.95346941266741, 55.40390375682286, 50.91359567642212, 53.15413611275809, 54.41162804194859, 56.795561926705496, 65.15150029318673, 69.86793054853166, 70.0242372240339, 71.47301306043352, 27.620501620428904, 33.79220254080636, 60.19325883047921, 64.91890239715576, 72.06702845437187, 62.18301446097237, 63.99705709729876, 54.65675354003906, 55.8343620300293, 52.48239469528198, 56.50635705675398, 65.86787346431187, 69.21117986951555, 62.14425046103341, 53.00722687585013, 61.31145327431815, 67.40831688472203, 68.45882197788784, 68.13948971884591, 66.03120476858956, 65.4411290032523, 65.63689449855259, 66.9098322732108, 70.13980661119733, 58.02300984518868, 56.90096262523106, 67.09992109026227, 70.01128578186035, 68.77492332458496, 74.289534841265, 68.4011241367885, 49.749629974365234, 21.525043283190044, 5.462553007262094, 6.319403988974435, 5.578830242156982, 7.174586534500122, 4.769805014133453, 1.382000825234822, 0.5697630867362022, 0.21919412884329045, 0.17814722497548374, 0.24052161084754126, 0.15149811495627674, 0.1774238795042038, 0.4970055137361799, 3.6694917593683516, 36.93485539300101, 55.39025054659162, 55.64134454727173, 58.44148594992501, 68.84465544564384, 33.74706356866019, 43.30270569665091, 58.22619949068342, 71.38805048806327, 79.17149203164237, 98.60500594547817, 23.003074509756907, 0.790245387170996, 0.2417380070047719, 0.15681994653173856, 0.1084678600143109, 0.09227230120450258, 0.13519058429769107, 0.16484050186617033, 0.07281469886324235, 0.1391806551920516, 0.0774858221411705, 0.1249000850532736, 0.13759862365467207, 0.16678164127681935, 0.13291708486420767, 0.16590022428759507, 0.1514710278383323, 0.21758418237524374, 0.1585913843342236, 0.15524309900190147, 0.1537469428564821, 0.1275740015719618, 0.14181892148086003, 0.1655509416013956, 0.12019614103649344, 0.10645447698022638, 0.147249807204519, 0.1530612696494375, 0.11237001991165535, 0.09285115942891155, 0.08444893493184022], [0.018038853470768248, 0.027369396993890405, 0.01737833864587758, 0.04582020094884293, 0.05262564255722931, 0.12004296854138374, 0.0665891400671431, 0.0430644700702812, 0.01587681528846068, 0.06143459451517888, 0.033332330507359335, 0.031182344803320508, 0.03600970755464264, 0.0577736741730145, 0.06231682574642556, 0.0373317244728761, 0.040756209287792444, 0.06280991714447737, 0.022912175095240985, 0.010255093287144388, 0.007399273404319371, 0.06193070539406367, 0.040386604477784464, 0.14858185287032807, 10.8208361353193, 71.19263935089111, 70.55592727661133, 76.3155322756086, 66.79647241319928, 59.68370573861258, 22.53713004929679, 26.449174301964895, 21.28792905807495, 14.67605801991054, 30.15164177758353, 36.19919054848807, 34.180016245160786, 14.282790848187037, 2.306158572435379, 0.0882085006950157, 0.031522141569959264, 0.200688294001988, 0.21370317919978074, 0.22386071272194386, 0.0466003228378083, 0.7650130039879254, 0.8870552352496556, 0.9904564810650689, 1.6427936426230838, 0.6175750525934356, 14.21557571206774, 58.73126752035958, 70.00815214429582, 65.60431439535958, 66.32029151916504, 60.99418463025774, 56.729894501822336, 57.149381569453645, 55.29435150963919, 55.93767132077898, 63.15094716208321, 64.8003591809954, 62.620146478925435, 59.20409938267299, 63.05116408211844, 59.307842935834614, 50.97015053885323, 44.82976688657488, 46.56880371911185, 44.123096874782014, 49.36149317877633, 50.078453472682405, 55.92785699026925, 57.281595366341726, 60.91586453574044, 58.403923988342285, 53.98422350202288, 47.181207520621165, 45.93967907769339, 45.47704369681222, 48.99719565255301, 45.30598599570138, 52.03548656191145, 56.16662836074829, 65.76289313180106, 61.03385884421212, 70.93930803026471, 24.279213666915894, 20.972294977733068, 62.00063814435686, 55.99655730383736, 62.22158391135079, 55.656905038016184, 54.932791573660715, 48.52899476460048, 50.16520868028913, 45.665930475507466, 51.299140793936594, 58.16802222388131, 65.39941896711076, 58.69448375701904, 53.5451147215707, 60.3308470589774, 60.148297037397114, 57.824670042310444, 56.49588959557669, 55.065450055258616, 53.748839378356934, 54.75832578114101, 54.236269405909944, 61.64795453207833, 57.21480580738613, 54.70049939836775, 65.72261442456926, 61.27235576084682, 60.92831570761544, 60.06664180755615, 62.813834462847026, 58.386199133736746, 54.578370911734446, 23.98590762274606, 1.4020938213382448, 1.6765165073531014, 0.7114730083516666, 2.8522889358656744, 1.6332090369292667, 0.28350124029176577, 0.09193755273840257, 0.09712102423821177, 0.15812497293310507, 0.10688039341143199, 0.059681891064558706, 0.03844648965501359, 0.12521065053130898, 1.0946928134986331, 27.552233832223074, 49.76580885478428, 47.67349433898926, 54.835787773132324, 40.02387162617275, 19.31571762902396, 37.96986600330898, 50.84846673692976, 56.29545838492257, 71.23459952218192, 38.196881021772114, 1.012411702956472, 0.11469603117023196, 0.07361325315598931, 0.017851993408320204, 0.1003421385373388, 0.03207307468567576, 0.03177550993859768, 0.033088122361472676, 0.1140641522194658, 0.019452760993902172, 0.08911822616521801, 0.027353166436244334, 0.07093664285327707, 0.04796716717204877, 0.04551686526143125, 0.03833289610754166, 0.024577778398192356, 0.032309232013566155, 0.03423415782994457, 0.07954714367432253, 0.011705384706147015, 0.07911667427314178, 0.0344814940222672, 0.02004296432382294, 0.05997544566967657, 0.022213713199432408, 0.022611232940107584, 0.0034828602427816285, 0.07915319981319563, 0.028350987804255316, 0.02936024757634316, 0.02120700471901468, 0.026706872009006993, 0.03854216309264302, 0.03038453689909407, 0.050212280093027015, 0.020371858729049563, 0.03299132255571229, 0.029279579940651144, 0.044606715706842284, 0.04515228161056127, 0.03948693489655852, 0.012510651406565947, 0.02485889376008085, 0.059466917599950514, 0.032118821516633034, 0.033093096023159366, 0.05375226174614259, 0.04293832362496427, 0.03431400104558893, 0.054164166429213116, 0.0681371023612363, 0.13170303643814155, 0.18819330233548368, 14.510132431983948, 84.92208521706718, 79.44866262163434, 88.40042986188615, 76.09485054016113, 71.1207810810634, 39.792979512895855, 37.4315299987793, 23.43230468886239, 25.389831100191387, 41.360687664576936, 38.87356260844639, 35.56526470184326, 15.406874758856636, 2.6426780692168643, 0.03066953857030187, 0.00680307055258059, 0.0707189959606954, 0.4030873647757939, 0.8323522305914334, 1.6923991122416087, 2.195743662970407, 2.4605275690555573, 0.802292423588889, 1.2620651466505868, 0.430776017584971, 15.990450484412056, 61.61026055472237, 72.57681778499058, 67.96053191593715, 68.28361620221818, 62.49576677594866, 59.329090527125764, 59.66161741529192, 57.02269853864397, 58.603434562683105, 64.2095399584089, 67.4227066040039, 62.80029937199184, 60.53791727338518, 65.40417153494698, 62.966069493974956, 52.99051645823887, 46.31049401419503, 49.30134957177298, 47.01991898672921, 52.01333917890276, 53.095642702920095, 59.68070411682129, 58.554950032915386, 64.20795576913017, 62.07714475904192, 56.64087765557425, 49.45811482838222, 49.870059626443044, 47.25590760367257, 49.904362882886616, 48.48641620363508, 54.646772452763145, 57.68129743848528, 67.01929419381278, 62.89302308218819, 74.083249773298, 26.65504421506609, 22.840101037706646, 64.94672993251255, 59.223985127040315, 65.43772438594273, 57.844218799046104, 56.956534317561555, 50.21356119428362, 52.913839612688335, 45.98574563435146, 53.10916042327881, 59.11076423100063, 68.50374208177838, 60.156509808131624, 55.1324828011649, 62.66461494990757, 62.60349859510149, 60.80948066711426, 60.24355684007917, 56.768762724740164, 55.89693750653948, 59.218530791146414, 57.63029766082764, 64.04301943097795, 60.247357504708425, 56.51196077891758, 68.73257405417306, 64.00839655739921, 62.9043972832816, 62.286535671779085, 67.42308180672782, 65.60646138872418, 61.44628306797573, 27.743083477020264, 2.4504264082227434, 0.6776932009628841, 0.6810904358114515, 1.2930322906800678, 3.6869456342288425, 2.437802399907793, 0.7936223202518055, 0.15545615899775708, 0.2545540678714003, 0.10122903808951378, 0.07817574297743184, 0.0656538541827883, 0.08255223277956247, 0.8704049086996487, 29.419200897216797, 43.276403290884836, 41.130882944379536, 48.945045948028564, 40.48785843167986, 28.29501015799386, 48.97766079221453, 57.51756313868931, 63.78169073377337, 77.59744712284633, 54.20230313709804, 1.5930130566869463, 0.1776995411408799, 0.01280756900086999, 0.03741478733718395, 0.01928499321054135, 0.025425056594290903, 0.05807894029255424, 0.03718008885958365, 0.04863315268552729, 0.011359260600459362, 0.09104114691061632, 0.05269906683159726, 0.034678540591682704, 0.03214624450941171, 0.007332522521859833, 0.03443074638822249, 0.0712267505005002, 0.01832747512630054, 0.02923158715878214, 0.04298008745536208, 0.06882409871156726, 0.021969199712787355, 0.0619899822132928, 0.010004117602615483, 0.020170684970383133, 0.04033699678257108, 0.03538087183343513, 0.01660972640716604, 0.017376304737159183, 0.09370483112122331, 0.1007895509579352, 0.11742955020495824, 0.14219206145831517, 0.07561798486858606, 0.0874784445124013, 0.21573499803032192, 0.11287662772727863, 0.15266443522913115, 0.07268737176699297, 0.10283374626721654, 0.15039503414716038, 0.09238660721374409, 0.12666137197187968, 0.09236711968800851, 0.18992066250315734, 0.2104286506239857, 0.11938706945095744, 0.11836408291544233, 0.09454858263156243, 0.18274306479309285, 0.14744143906448567, 0.14416876967464173, 0.28791502916387146, 0.23334990282143864, 20.11261694771903, 98.52314226967948, 88.44787216186523, 99.07196657998222, 86.32760156903947, 78.55433913639614, 35.36827284949166, 37.40531097139631, 35.35789571489607, 22.75214900289263, 46.362779208592, 52.55996438435146, 48.969322953905376, 22.187686034611293, 3.738244184425899, 0.17054030458842004, 0.12142841491316046, 0.34770658505814417, 0.6018480764968055, 1.4868087555680956, 2.643076939242227, 1.7468737491539545, 5.707310685089656, 5.188069633075169, 5.011560635907309, 2.49152825985636, 18.32328384263175, 65.76112134116036, 75.622880254473, 71.57567964281354, 70.74168041774205, 66.75133691515241, 61.29756382533482, 62.83092703138079, 59.46591445377895, 61.9228322165353, 67.36093017033168, 71.31832531520298, 64.08573000771659, 63.288667406354634, 67.96558325631278, 66.58257211957658, 55.96703093392508, 48.81390217372349, 52.86031763894217, 50.35185466493879, 53.56335721697126, 55.53025674819946, 61.47634792327881, 62.518383162362234, 67.62175859723772, 65.56380639757428, 58.97226578848702, 51.667377948760986, 51.68916055134365, 51.27055243083409, 52.784742082868306, 49.77130487986973, 56.65389857973371, 60.69832338605608, 69.86885465894426, 67.68131160736084, 74.8924091884068, 30.723645278385707, 27.6494426046099, 69.28487941196987, 61.826898438589915, 66.13972173418317, 62.50221470424107, 59.199305125645225, 53.68097284861973, 55.58596740450178, 49.07077012743269, 56.317015171051025, 63.47694274357387, 70.91273811885289, 62.13523864746094, 55.992093086242676, 65.39904376438686, 66.45139013017926, 64.0381417955671, 63.29307951245989, 59.5711727142334, 59.57200649806431, 61.789475440979004, 60.505496978759766, 67.79135717664445, 61.616555622645784, 57.48247126170567, 70.24756622314453, 67.04589189801897, 66.40323216574532, 65.63006441933769, 69.73998641967773, 69.0533584867205, 64.85360322679792, 27.836701767785208, 3.3048730960914066, 4.732600450515747, 4.147855690547398, 7.717543959617615, 5.974037264074598, 1.892998056752341, 0.4939112854855401, 0.22711981141141482, 0.28857155250651495, 0.3730736981545176, 0.34178197011351585, 0.2103688581181424, 0.23893560309495243, 2.1308433626379286, 40.49277775628226, 67.67094489506313, 64.07874011993408, 68.5963476725987, 50.52488565444946, 30.99006700515747, 52.894443716321675, 67.34071091243199, 71.82287570408413, 87.36860847473145, 61.45785876682827, 2.0347321884972707, 0.30057988528694424, 0.13299606634037836, 0.1754963786474296, 0.17690299531178816, 0.10676220618188381, 0.10444152820855379, 0.16271998493799142, 0.23944084026983806, 0.20373877031462534, 0.18409590077187332, 0.10095121871147837, 0.12850685151559965, 0.17227301161204064, 0.17679071133690222, 0.1313964743167162, 0.1456981333238738, 0.08555695547589234, 0.10543471348604985, 0.21900606607752188, 0.23779987118073873, 0.17157638684979507, 0.15014530611889704, 0.08506002356963498, 0.12045127020350524, 0.1455609199724027, 0.10601251998117991, 0.11644218675792217, 0.14434636943042278, 0.15259559106613907], [0.05758399649390152, 0.06714192219078541, 0.014480378345719405, 0.04697933214317475, 0.04522400954738259, 0.09794308976935488, 0.006967533446316208, 0.03173149337193795, 0.023558038652741482, 0.036552206480077336, 0.03680338318060551, 0.016533228369163613, 0.056398819732878885, 0.009076011466926761, 0.036128797235765626, 0.016789826564490795, 0.04099476523697376, 0.034590154620153565, 0.02962763447846685, 0.03196269739419222, 0.012497315648943186, 0.016679566320297972, 0.05944175073610885, 0.22001666256359645, 46.722779273986816, 78.65181541442871, 77.67847006661552, 63.43186977931431, 52.546752384730745, 35.946158000401084, 19.849667583193096, 20.777470963341848, 41.25276824406215, 50.99484096254621, 38.19282327379499, 39.51323808942522, 13.573284234319415, 1.3363171794584818, 0.02983028574713639, 0.1708663949476821, 0.06915526451276881, 0.00696833963073524, 0.37322989691581043, 0.7785214419875826, 0.47534255044800894, 1.9725182354450226, 1.0659197803054536, 0.5743143739444869, 3.014721534081868, 24.692508152553014, 69.81758390154157, 67.06438105446952, 68.04559176308769, 61.52341502053397, 58.0894068309239, 59.485716819763184, 62.842697279793875, 60.534109660557334, 52.54367085865566, 52.948226247514995, 59.28590052468436, 62.991819517953054, 61.60793290819441, 56.39464739390782, 63.54463904244559, 57.278027466365266, 49.598430224827354, 44.22497483662197, 43.898472036634175, 43.62069000516619, 45.607909543173655, 42.680178369794575, 44.21573025839669, 46.83524629047939, 50.22320876802717, 49.76870625359671, 46.72516598020281, 43.66310180936541, 47.0109349659511, 45.2784537587847, 46.0200697353908, 43.72515269688198, 49.18891034807478, 52.69638531548636, 63.522529874529155, 55.55655567986624, 71.63239083971295, 27.823251792362758, 26.639358656747, 62.740009852818076, 56.63082013811384, 60.518844468253, 49.97391782488142, 52.22707271575928, 45.27380888802664, 47.98636824744088, 45.454114641462056, 50.02976049695696, 54.99737507956368, 63.11441353389195, 58.527560234069824, 64.72143459320068, 62.26903315952846, 55.70895746776036, 53.9126501083374, 48.42738083430699, 47.05460091999599, 46.95557171957833, 48.246373312813894, 56.06167582103184, 60.26371356419155, 60.426808629717144, 54.01813071114676, 62.11777087620327, 61.17435141972133, 58.02505956377302, 57.757105759211946, 63.82672200884138, 62.004952975681846, 61.06434753962925, 59.655412673950195, 40.048350129808696, 4.554989729608808, 1.7240088560751505, 0.8358786585075515, 2.9632792430264607, 3.0060718953609467, 0.3422289347009999, 0.264955005475453, 0.06138831842690706, 0.05438608130706208, 0.0638933340087533, 0.20944128717694963, 0.035268940696758885, 0.062436865376574655, 0.9433049197707857, 30.9267897605896, 50.911028317042756, 48.933494567871094, 40.034311294555664, 19.483162266867502, 28.045114721570695, 50.073068618774414, 57.97369153159005, 56.7724278994969, 69.2119094303676, 20.351626293999807, 0.5529141394155366, 0.05580469786322542, 0.10079502673553568, 0.01746327257049935, 0.04725808111418571, 0.04961446360019701, 0.042248908297291825, 0.05125062187601413, 0.013722732929246766, 0.04945938442168491, 0.03142261405342391, 0.014724276061835033, 0.09395403667752232, 0.05200527495305453, 0.046949731052986214, 0.029896592189158713, 0.044528819886701446, 0.008541511621193161, 0.01602352473751775, 0.02826765861495265, 0.07195340043732099, 0.043622568515794616, 0.07399742611284767, 0.0639305312984756, 0.028452642528074126, 0.07248517511678593, 0.06639288059834923, 0.03783111267590097, 0.029527190939656327, 0.05785653686949185, 0.07540850075227873, 0.013960656992691969, 0.020948766165279915, 0.025532629839809876, 0.06480400942798172, 0.012427956647505718, 0.04180047128881727, 0.022948982227327566, 0.0147730644260134, 0.04915010476750987, 0.05435813584231904, 0.040934921841004064, 0.037251888042581935, 0.053161420593304295, 0.014508486658866917, 0.11365808293755565, 0.05366559246821063, 0.025445448267938833, 0.009180383723495262, 0.016822866130886332, 0.02666776633954474, 0.01730927056632936, 0.35994388269526617, 55.99496269226074, 88.92176709856305, 86.46673229762486, 72.46983637128557, 61.12873649597168, 43.70720897402082, 24.202335323606217, 28.88783914702279, 38.778862135750906, 37.229316575186594, 44.06993620736258, 39.34176002229963, 15.341648544584002, 1.2551932696785246, 0.05013272525476558, 0.08322305285504886, 0.027170111258913363, 0.4521907184805189, 1.2920380468879427, 1.8527740665844508, 1.4255896977015903, 2.29790780373982, 0.8692718095013073, 0.5378298716885703, 2.5836025306156705, 27.662588596343994, 71.52316515786308, 70.09328842163086, 68.65857573917934, 64.37960406712124, 59.56910909925188, 62.935094424656455, 64.55269064222063, 64.68511635916573, 55.64371040889195, 55.54669271196638, 62.27736404963902, 66.08690152849469, 63.530555043901714, 57.75007765633719, 66.08838149479458, 60.56923280443464, 52.2169839314052, 46.256614208221436, 46.68915694100516, 45.537284578595845, 49.4050965990339, 45.40543556213379, 47.5222042628697, 50.13791268212454, 53.98423739842006, 51.764190673828125, 49.74109411239624, 45.54625122887747, 50.04212829044887, 47.26727138246809, 47.602223191942485, 46.87365940638951, 52.645309107644216, 55.04172543116978, 65.21603516169957, 59.774067061288015, 72.90919181278774, 30.591806684221538, 27.88147943360465, 65.17313698359898, 58.325958251953125, 64.41015529632568, 54.76281779153006, 54.87810230255127, 46.77641936710903, 49.124215670994346, 47.485771383558, 52.67253909792219, 57.410658155168804, 64.78176580156598, 58.5050550188337, 65.69555119105748, 63.767412185668945, 58.30983148302351, 57.02996635437012, 50.85099935531616, 49.4828017779759, 50.2266446522304, 49.085976260049, 60.19499588012695, 63.00491687229702, 62.459490231105256, 55.39822013037545, 65.13533878326416, 64.49100453513009, 61.193716049194336, 61.18150806427002, 67.37534768240792, 64.52690587724958, 65.12687587738037, 64.11464146205357, 44.78410332543509, 5.609146969658988, 0.33489847662193434, 1.2521114179066248, 0.5627883981381143, 2.1638375350407193, 1.8324375578335352, 0.6137828560812133, 0.40423210763505524, 0.2483644714312894, 0.09219178623918976, 0.3800766138093812, 0.09731142116444451, 0.04642759157078607, 0.9591290077992848, 32.7913944380624, 50.17000988551548, 44.51605919429234, 33.408505644117085, 20.668021202087402, 35.62651307242257, 55.30282483782087, 65.63685975755963, 63.44322313581194, 79.18766048976353, 31.6752427646092, 0.4935328800763403, 0.0170491219365171, 0.08777472004294395, 0.05706503934093884, 0.04160043916531971, 0.01287993900145271, 0.03155275367732559, 0.016372307004140954, 0.13403813328061784, 0.0294983871281147, 0.0030146320641506463, 0.022057672197531377, 0.034564217619065724, 0.03531368329588856, 0.046910596545785666, 0.08584674421165671, 0.033972711501909156, 0.011336961395240255, 0.009993072748849434, 0.03927544231659599, 0.0590056087821722, 0.023591885675809214, 0.07373488734343223, 0.032225270090358596, 0.04942591568189008, 0.08920348409031119, 0.06726389564573765, 0.05340591372389879, 0.01952106911422951, 0.0985030440081443, 0.1490298488310405, 0.10347317731274025, 0.11719267362994806, 0.1448669686381306, 0.18766485926296028, 0.0668956818325179, 0.20167153195611068, 0.0999169209972024, 0.10123267503721373, 0.25256305613688057, 0.14688835160008498, 0.1366389308656965, 0.09117646036403519, 0.27439022489956444, 0.1306004441742386, 0.2414762553359781, 0.10155069082975388, 0.14345176172043594, 0.11141180632902042, 0.09002870480929102, 0.09074682556092739, 0.18182390768613133, 0.6690144666603633, 64.59087794167655, 97.93548447745187, 97.46720368521554, 83.93728228977749, 71.4119244984218, 51.11460706165859, 29.72118697847639, 29.13104694230216, 56.592851706913535, 71.20583398001534, 55.5203903062003, 56.71140534537179, 21.379907573972428, 2.427942906107221, 0.15003024015043462, 0.27703493727105005, 0.1706260307026761, 0.7745882730398859, 1.9162766933441162, 3.262733140162059, 2.606670332806451, 8.443299804415021, 5.433214672974177, 4.951822195734296, 10.476686647960118, 30.11550419671195, 77.6780184337071, 71.88242871420724, 73.48324503217424, 67.4044884272984, 63.047036852155415, 64.99839673723493, 67.07774244035993, 65.86749131338937, 58.31578608921596, 57.78684752328055, 64.40688964298793, 67.61610276358468, 65.61276340484619, 59.142427171979634, 70.6989073072161, 63.37376199449812, 55.667709486825125, 49.789908681597026, 47.86108875274658, 48.95903614589146, 52.49057272502354, 48.67832892281668, 49.047160148620605, 53.346594265529085, 55.71495376314436, 54.5732535634722, 51.75626277923584, 48.56754337038313, 53.38002552304949, 49.375424316951204, 50.10792425700596, 47.6298040662493, 55.42573152269636, 57.77455963407244, 68.16366250174386, 63.04268033163888, 74.3035979952131, 33.37479645865304, 32.21930061067854, 66.14443261282784, 62.20344911302839, 66.75228881835938, 57.30875934873308, 56.916224343436106, 50.965318066733225, 52.766860893794465, 51.19634566988264, 54.94980076381138, 60.42256328037807, 68.29786695752824, 59.578621183122905, 66.28862857818604, 66.34288011278424, 60.92516817365374, 60.52184609004429, 54.48261431285313, 52.56253521783011, 52.94139616830008, 51.34004831314087, 62.486442293439595, 67.5893452508109, 64.97662803104946, 58.306475503104075, 66.67129366738456, 67.70328181130546, 64.46439293452671, 64.11916473933628, 71.06993416377476, 66.27060495104108, 68.78116975511823, 68.1125237601144, 44.99228177751814, 6.190505351339068, 5.131032739366804, 4.646372437477112, 9.378362315041677, 6.97090573821749, 1.9647171454770225, 0.7471702471375465, 0.2873832476990563, 0.2366897878902299, 0.24018785304256848, 0.5533374909843717, 0.17238952964544296, 0.11200158896722964, 2.1152780950069427, 47.93164423533848, 67.53044537135533, 61.51388904026577, 52.451989378247944, 28.828791618347168, 40.357544967106406, 63.16986015864781, 76.78031812395368, 74.19971547807965, 90.59443473815918, 35.20639024462019, 0.7652262268321854, 0.13141822814941406, 0.16902953279869898, 0.19687133096158504, 0.15321718342602253, 0.18938349347029412, 0.1369276475161314, 0.13689747984920228, 0.20571846408503397, 0.15143688395619392, 0.15015996247529984, 0.09484056303543703, 0.1892351114324161, 0.10986567607947759, 0.12696094518261297, 0.17977314415786946, 0.12357079423964024, 0.07806867015148912, 0.07010649597006184, 0.1920372439282281, 0.23582245728799275, 0.10245489981025457, 0.17932769948882715, 0.1867466521050249, 0.11552015266248158, 0.19249511935881206, 0.15712831355631351, 0.10998382259692464, 0.11018543570701565], [0.061757631466857026, 0.054368391899125915, 0.04263064531343324, 0.04021181046430554, 0.03511679957487753, 0.016850923553907445, 0.022194266385797943, 0.00613881233480892, 0.05202548511858497, 0.08380921211625848, 0.06624820336167302, 0.05599959347663181, 0.05550588121903794, 0.0312732142130179, 0.07146011226411376, 0.05518523610330053, 0.012073629053442605, 0.0012338340831255274, 0.029990253770457845, 0.11037520838103124, 0.05465689141835485, 0.058986453738595755, 0.18209663805152687, 5.7160853913852145, 67.9461283002581, 75.22245556967599, 64.59448405674526, 64.3273675101144, 69.75946222032819, 39.621331214904785, 42.116074970790315, 37.71475594384329, 40.52239792687552, 46.64748511995588, 41.38067068372454, 9.207436629704066, 0.25013669633439606, 0.041688574078891955, 0.1044209957388895, 0.042527334964168925, 0.3468897103198937, 0.1246479685817446, 1.3145076526062829, 0.16380712017416954, 0.869841561785766, 2.160358875989914, 1.6107208664928163, 2.7481304449694495, 37.55763632910592, 70.34715475354875, 66.77464812142509, 67.57767922537667, 62.04832363128662, 55.56753035954067, 61.8141484941755, 66.34290095738002, 63.96185752323696, 63.35270895276751, 52.72865969794137, 51.3168899672372, 62.342413084847585, 61.94000121525356, 59.891623633248464, 57.1434234891619, 63.88739367893764, 56.2059760093689, 49.06381498064314, 42.96863630839756, 47.14681393759591, 48.51303127833775, 54.585795061928884, 47.49149669919695, 45.017969267708914, 41.374709129333496, 42.72291326522827, 41.409849643707275, 44.78551033564976, 41.96964863368443, 45.64027425221035, 42.534672669001985, 46.70467226845877, 44.26995747429984, 48.98741258893694, 46.48891333171299, 58.52618449074881, 53.54753269468035, 66.06047752925328, 39.830857617514475, 33.13430888312203, 65.06320258549282, 54.55171067374093, 58.65428147997175, 49.19995450973511, 51.532430035727366, 43.81718853541783, 45.39130640029907, 45.15731191635132, 48.09306478500366, 54.576877049037385, 61.82981668199812, 59.976766858782085, 62.43258680616106, 60.43047033037458, 53.20524706159319, 48.02147054672241, 43.83973543984549, 42.61789124352591, 43.29194641113281, 44.231144836970735, 51.2786158152989, 59.53796032496861, 58.547265325273784, 54.4160019329616, 61.987478256225586, 61.90188339778355, 59.967831475394114, 51.25990431649344, 56.27201863697597, 63.721171924046104, 62.36404282706124, 62.533064705984934, 65.93517371586391, 58.36069229670933, 11.006835068975176, 0.3477178487394537, 3.3539482227393558, 3.8582074386732916, 2.4472278484276364, 0.23618167372686522, 0.5944301688245365, 0.10490536117660147, 0.04058049585936325, 0.0892537296084421, 0.13747236185840198, 0.02942981437913009, 0.12600871627884253, 2.8574358139719283, 37.3649697303772, 43.457647051130024, 54.89473281587873, 37.74169063568115, 20.672447204589844, 42.0283192225865, 42.704934801374165, 59.25626645769392, 60.5460536139352, 57.21103988374983, 6.309389897755214, 0.15302302741578647, 0.044766537845134735, 0.03757935922060694, 0.04301042475604585, 0.13854139378028257, 0.02541496168955096, 0.02117037570237049, 0.020008623666529144, 0.024798843410930464, 0.015135263026292835, 0.07510102939392839, 0.019353825499170592, 0.04929806950635143, 0.053165379845138104, 0.05244669590943626, 0.049234059905367236, 0.0407565349846014, 0.008685541705095341, 0.03128756183598723, 0.06083324285490172, 0.036930845983858616, 0.09720974947725024, 0.08570615175579276, 0.0020614228893204457, 0.04130642315638917, 0.011884260107763112, 0.05343834769779018, 0.04358954760911209, 0.0458232814978276, 0.05039614611970527, 0.1712900043598243, 0.05938360707036086, 0.03198668360710144, 0.025814966564731937, 0.05306767758780292, 0.06685693748295307, 0.016939346844862615, 0.04117166610168559, 0.01724340008305652, 0.07128097223384039, 0.04633388588471072, 0.03129314278651561, 0.05102019477635622, 0.046331707787300856, 0.005280024912540934, 0.02138590726203152, 0.025413633457251956, 0.019988176013742174, 0.08449514995196036, 0.024477541812562516, 0.16026412243289606, 8.355699522154671, 82.85428047180176, 82.86336871555874, 75.3406513759068, 70.41992323739188, 79.88369628361293, 46.444128717694966, 26.25784002031599, 23.528455598013743, 34.03691809517996, 40.55580139160156, 41.10274274008614, 11.499828866549901, 0.12672600921775612, 0.045135881419160535, 0.021554687758907676, 0.049511227889784744, 1.197583800980023, 1.6622872480324336, 2.2739723452499936, 1.4433423451014926, 1.3090856692620685, 2.0590441524982452, 0.50666991514819, 3.745860278606415, 39.42091737474714, 73.4324814932687, 69.99957806723458, 69.62714767456055, 63.66786534445626, 57.592082568577354, 65.18836048671177, 66.89337893894741, 67.01568113054547, 65.14567075456891, 55.59237016950335, 54.50155510221209, 62.91998904091971, 64.88591929844448, 61.137400899614605, 58.464720726013184, 65.41414219992501, 59.314547947474885, 51.15554584775652, 44.86821126937866, 49.98950958251953, 50.77638612474714, 56.76839099611555, 51.17772102355957, 47.80855342320034, 42.16036626270839, 45.38778018951416, 44.40590245383126, 46.348993982587544, 44.36259433201381, 47.238797664642334, 45.14957162312099, 49.27960171018328, 47.07556363514492, 51.02478422437395, 49.32715170724051, 61.75613103594099, 55.666722842625205, 69.31764016832624, 42.65416431427002, 34.79507425853184, 65.8451736995152, 57.22348410742623, 61.534407070704866, 50.57853616986956, 53.17476531437465, 46.45619426454817, 48.51021030970982, 46.91077320916312, 50.51173618861607, 58.0648067338126, 63.69923646109444, 60.309314591544016, 63.19904954092843, 62.78684765951974, 57.13290391649519, 50.82095534460885, 46.663052558898926, 44.18558202471052, 44.82386786597115, 46.35937459128243, 55.44340079171317, 62.07091222490583, 61.39701339176723, 57.03941590445382, 65.20443861825126, 64.05968121119908, 62.619826861790244, 54.63119806562151, 60.39008740016392, 67.77723148890904, 64.94896725245884, 65.71891103472028, 69.63065651484898, 63.66141741616385, 14.832472392490931, 0.6609363172735486, 0.9872353396245411, 0.9451616087130138, 2.1914379511560713, 2.110333583184651, 1.4372775448220116, 0.3322612824184554, 0.5707162927303995, 0.14555935934185982, 0.44360613769718577, 0.0705854534836752, 0.14159390569797584, 3.1424454918929507, 40.61257512228829, 44.63154172897339, 45.63467053004673, 31.68698869432722, 30.61488859994071, 52.17399890082223, 48.15592861175537, 66.6048480442592, 65.3859533582415, 68.95535414559501, 12.194536685943604, 0.14445578998753003, 0.0712771520816854, 0.049376793139215024, 0.022455627896956036, 0.08737401118768112, 0.03884809756917613, 0.0495114993037922, 0.01206674870835351, 0.05992469125028167, 0.008632067208444434, 0.014495716629815953, 0.02757886584315981, 0.0769448804536036, 0.053041038302970786, 0.111957830243877, 0.02596337065499808, 0.03130020633605974, 0.024010473928813423, 0.024817964527755976, 0.041120898111590316, 0.0470922132288771, 0.09781449381262064, 0.04748694758330073, 0.04537203535437584, 0.05252510402351618, 0.07598353882453271, 0.04575006417664034, 0.0332402227712529, 0.13687526461269173, 0.1234609665615218, 0.21886096814913408, 0.1842066648283175, 0.12000593410006591, 0.13840260622756823, 0.11238976528069802, 0.177181194669434, 0.08831444715282746, 0.1179465124649661, 0.10513473993965558, 0.11841193320495741, 0.16297670187694685, 0.1097959837477122, 0.095535091124475, 0.09394856768527202, 0.07358066311904363, 0.1362467919077192, 0.12539480493537017, 0.15889283030160836, 0.21554275548883847, 0.19497825897165708, 0.35649412923625534, 11.595885106495448, 94.780001776559, 92.2192918232509, 84.60183579581124, 81.31851318904332, 84.25858088902065, 53.422263622283936, 55.783636706215994, 54.888448170253206, 57.82901266642979, 66.7030816759382, 61.493426595415386, 14.387007747377668, 0.509449303150177, 0.20075227985424654, 0.30389393174222534, 0.11355345962303025, 1.559021926351956, 2.2519541553088596, 4.457422690732138, 2.639454322201865, 5.438801024641309, 10.672109944479805, 6.5299192070961, 4.307271684919085, 41.439629622868125, 76.48813942500523, 71.56292969839913, 73.21087564740861, 66.26032161712646, 59.18588120596749, 66.81220313480922, 69.95249012538365, 69.97756617409843, 70.54961136409214, 58.34986700330462, 57.13402257646833, 66.81478786468506, 67.1474050794329, 61.50981739589146, 61.658043316432405, 69.1654051371983, 63.529450280325754, 53.114243030548096, 47.905074323926655, 52.579467977796284, 51.297424588884624, 61.018301827566965, 52.45510911941528, 49.57743624278477, 43.84439768110003, 47.93599033355713, 46.573851585388184, 50.15173264912197, 47.53769179752895, 50.610921723502024, 48.0414605140686, 51.46540423801967, 49.09486995424543, 52.80063608714512, 51.896171706063406, 63.79614993504116, 59.23088468824114, 69.91968073163713, 46.06670257023403, 39.201402936662944, 69.26829406193325, 59.60215473175049, 64.86854185376848, 54.038989203316824, 55.86344371523176, 48.56202302660261, 50.94948312214443, 49.86192328589303, 52.51487752369472, 59.86443533216204, 66.02797385624477, 61.489799635750906, 66.67112691061837, 67.03822108677456, 59.184720856802805, 54.987988063267295, 48.70363078798567, 46.47899825232369, 47.97887461526053, 48.41372067587716, 58.363012995038716, 66.84171213422502, 63.44036742619106, 58.45308249337332, 67.28299222673688, 67.20622158050537, 66.26111371176583, 57.098169871738975, 63.179101262773784, 72.67233467102051, 68.66271686553955, 69.28524071829659, 72.04938697814941, 67.13085447038922, 13.869749971798488, 2.3766009296689714, 7.037553293364389, 10.332947526659284, 8.645740781511579, 3.5427924437182288, 1.9092726920332228, 0.22405264313731874, 0.6782644188829831, 0.5940428610358919, 0.4267759179430348, 0.24731846898794174, 0.3169448200081076, 4.897373071738651, 55.40547752380371, 59.7922157560076, 70.28773375919887, 53.13451439993722, 31.84557090486799, 56.64901052202497, 56.99475983210972, 74.89512593405587, 75.06837231772286, 79.60803345271519, 13.938233154160635, 0.5241564682551793, 0.18671701369541033, 0.1826980100678546, 0.11896755839032785, 0.29280536675027435, 0.11714058928191662, 0.09399900997855834, 0.1314003826784236, 0.19972652489585535, 0.11588972354573862, 0.1329401686255421, 0.08557527592139584, 0.11405724473297596, 0.10467053377734763, 0.30885315420372145, 0.141570333391428, 0.15985146457595484, 0.08976215589791536, 0.07819261814334563, 0.17991387232073716, 0.13139769567974977, 0.27748315036296844, 0.18610466298248085, 0.10988392867147923, 0.22415018933159964, 0.1448890074555363, 0.11607158450143677, 0.12919650093785354], [0.052583444464419565, 0.09402007849088737, 0.04105009976774454, 0.0330063792477761, 0.049850698959614546, 0.03482215592105474, 0.028010103685249175, 0.03999865886622241, 0.03789659809055073, 0.016914576924006854, 0.03520576908652272, 0.0019955613118197236, 0.07380685955286026, 0.03066664461844734, 0.009610623270938439, 0.023586818715557456, 0.03888436865859798, 0.033963089875344715, 0.06057309252875192, 0.046460958530328104, 0.028553601753498827, 0.03600492049008608, 0.03356666596872466, 45.86831412996565, 78.75248091561454, 70.04533890315464, 70.53315108163017, 60.642751693725586, 31.430641855512345, 21.271672010421753, 38.99786935533796, 43.536349296569824, 49.94717768260411, 41.25341442653111, 16.481757606778825, 0.27185543520109995, 0.24171368830970355, 0.05774295689272029, 0.03325346777481692, 0.1928813007793256, 0.161456878430077, 0.6975575579064233, 1.1445870676210947, 1.0585945333753313, 0.9136018050568444, 1.462250456213951, 9.703902789524623, 54.66173192432949, 74.62134606497628, 60.02557100568499, 66.88244942256382, 59.01244027273995, 56.54562132699149, 60.65222903660366, 67.51185199192592, 66.18706675938198, 65.1188576562064, 60.42563438415527, 48.48933097294399, 52.01165076664516, 60.597095080784385, 61.929731777736116, 59.88109016418457, 55.20490387507847, 62.476930209568565, 57.18643978663853, 48.866979462759836, 43.15848193849836, 47.5331198828561, 54.09616592952183, 60.297975131443565, 57.14994089944022, 54.35796363013131, 43.805286271231516, 44.56656912394932, 47.748173577444895, 45.01815686907087, 40.76922920772007, 45.580769879477366, 43.58580310004098, 45.69540473393032, 44.2870500428336, 47.70624119894845, 43.671797479902, 52.66752597263881, 51.224475451878135, 67.87511771065849, 41.02880348478045, 37.16884292875017, 64.74220275878906, 54.33115400586809, 56.0071359361921, 45.90675156457083, 47.11701658793858, 43.518325669424875, 45.626072134290425, 43.25125776018415, 44.615143980298726, 47.72225332260132, 57.969213417598176, 59.781543322971885, 59.81600638798305, 55.65001589911324, 50.84537826265608, 43.546340806143625, 42.75453799111502, 41.37274626323155, 43.84557540076119, 43.137164865221294, 52.316277163369314, 59.964016914367676, 58.28932040078299, 53.23543698447091, 58.351006507873535, 60.847105162484304, 59.564710889543804, 57.218088831220356, 48.38821383884975, 51.64928483963013, 56.39127056939261, 59.81884125300816, 61.03003733498709, 62.834387234279085, 70.5075261252267, 33.599244117736816, 2.80828794836998, 1.5237488533769334, 2.9853393392903462, 1.7000504902430942, 1.0236656133617674, 0.6210708650095123, 0.01603570783377758, 0.5093048566154071, 0.06943775899708271, 0.09088057159845318, 0.04376206174492836, 0.18011569577668393, 10.082576138632637, 42.937577860695974, 35.76758929661342, 32.67565482003348, 24.82012571607317, 27.981615134647914, 48.23919929776873, 53.21557903289795, 56.27563170024327, 61.16502693721226, 43.184357030051096, 1.767130462186677, 0.016643929661118557, 0.08897890256983892, 0.02160657533178372, 0.01486388803459704, 0.033382050160850794, 0.026093966593699794, 0.02714317511501057, 0.027772853915978755, 0.03725111451266067, 0.018448486757863845, 0.05809445160308054, 0.03677222824522427, 0.026530152652412653, 0.02894333191215992, 0.03050043068027922, 0.029536860063672066, 0.07507072601999555, 0.052923305691885095, 0.07167005778423377, 0.0464937928398805, 0.03958503748955471, 0.025452691629262905, 0.02082007351730551, 0.04436906220923577, 0.048445174736636024, 0.03237233916297555, 0.10156254483652966, 0.010823441004114491, 0.011849171365611255, 0.00223393617696794, 0.057570364725376875, 0.03799503655838115, 0.05334240623882838, 0.03309906373864838, 0.07934933036033597, 0.03819248007078256, 0.06735068027462278, 0.04764546014900718, 0.0575533334964088, 0.020431091443502476, 0.041551004496536086, 0.04082775741283383, 0.02013266326061317, 0.0210321106216205, 0.030366504830973487, 0.041705055694494925, 0.04771179373243025, 0.05879998553012099, 0.09411332277315003, 0.05258007214537688, 57.45441443579537, 89.48800359453473, 78.98695482526506, 79.40807819366455, 67.48403140476772, 46.09986284800938, 32.340567520686555, 46.054411206926616, 43.754144055502756, 43.9367218698774, 43.25882087435041, 18.913357870919363, 0.21459725765245302, 0.06776024401187897, 0.09533115742462021, 0.5170837449175971, 0.5387995253716196, 1.5189383115087236, 2.085274253572736, 1.6717145421675272, 1.3837086707353592, 0.42291437515190666, 1.2163948544434138, 11.94568087373461, 56.994144916534424, 76.83181122371128, 62.43046760559082, 69.22511100769043, 60.85313619886126, 59.260748045785085, 63.09129687717983, 68.64983490535191, 67.08082744053432, 66.45922074999127, 62.13790675571987, 52.48179020200457, 54.689667156764436, 63.22438962118966, 63.94703006744385, 59.725401878356934, 57.57714394160679, 63.9361491884504, 58.31251348767962, 50.34696313313076, 45.22069338389805, 50.943156787327354, 57.01678214754377, 63.25740051269531, 61.12469959259033, 56.23728459221976, 47.121001379830496, 45.781326157706125, 49.70840631212507, 46.3258912222726, 43.548039640699116, 47.435195446014404, 45.34172058105469, 48.56176594325474, 47.36134304319109, 50.802330698285786, 43.82880939756121, 53.347907475062776, 53.73966080801827, 69.10404559544155, 42.58960165296282, 37.898702553340364, 66.44287163870675, 56.80464669636318, 58.03981406348092, 47.71528080531529, 49.568785735539024, 46.79769127709525, 47.543611662728445, 45.79609455381121, 47.19534363065447, 50.52701180321829, 61.06311770847866, 62.41579301016671, 62.37850202832903, 58.32879311697823, 51.85968671526228, 45.63129023143223, 45.012104988098145, 44.35709135872977, 45.82208776473999, 45.24995919636318, 56.50368200029646, 62.565137590680806, 60.74447332109724, 55.90156848090035, 59.136465617588584, 64.46641486031669, 64.41149629865373, 59.89798123495919, 51.972362177712576, 54.63940388815743, 59.282940592084614, 62.76039586748396, 63.758699144635884, 68.52935314178467, 75.75131075722831, 39.162729263305664, 4.260426930018833, 0.4896728843450546, 0.8019302487373352, 2.338682221514838, 2.307685439075742, 2.120527676173619, 0.16623201434101376, 1.023613827569144, 0.2956813509975161, 0.12646766379475594, 0.01734660186671785, 0.06209329595523221, 10.470713802746364, 44.80904041017805, 39.148752961839946, 30.763291699545725, 25.940990005220684, 36.50261838095528, 54.240987232753206, 58.89341068267822, 63.01661763872419, 69.06591388157436, 55.72547680991036, 4.639892373766218, 0.11998933713350977, 0.04467697122267314, 0.07517457580459969, 0.03222425228783062, 0.03717895231342741, 0.011420355045369692, 0.024779484806848422, 0.021532743936404586, 0.05168487071724875, 0.02116090165717261, 0.10117454494216613, 0.013815902572657381, 0.016748795551913123, 0.008208340749011507, 0.048974676323788505, 0.011054101350185062, 0.036946336938334365, 0.018718620030475513, 0.026553275429510644, 0.01674939605540463, 0.06924092955887318, 0.07569508680275508, 0.04597988398745656, 0.05555396560313446, 0.031161900543208634, 0.028123308771422932, 0.08848385020558323, 0.13505224457808904, 0.1007673628628254, 0.22348173734332832, 0.12011582963168621, 0.136179616940873, 0.2643090401376997, 0.10870865173637867, 0.15745847512568745, 0.1490133875714881, 0.1142141627413886, 0.09548907966486045, 0.156953862203019, 0.124039105538811, 0.13334169850817748, 0.13024202840668814, 0.12566441403967993, 0.15425280428358487, 0.09015343990176916, 0.17160697520843574, 0.16753434017300606, 0.13739690876432828, 0.23909011908939906, 0.15540380323571817, 71.16763973236084, 100.98686926705497, 90.09242738996232, 90.16706493922642, 78.91379029410226, 43.579963139125276, 29.694057737077983, 50.94753415243966, 63.33959770202637, 68.6649055480957, 57.56016949244908, 25.086917434419902, 0.7047441122787339, 0.3653324549751622, 0.26723298324005945, 0.9613994402544839, 1.5728848853281565, 2.4313344955444336, 2.8150476770741597, 4.129773003714425, 5.068435115473611, 5.264223626681736, 3.339711146695273, 13.671685491289411, 61.93017646244594, 82.26453127179826, 63.39869907924107, 72.87759835379464, 62.98920004708426, 62.06814684186663, 65.31719398498535, 70.10295336587089, 70.3239894594465, 68.89897646222795, 65.19552407945905, 53.77510356903076, 57.02761786324637, 64.68136433192662, 66.87566798073905, 59.70427935464041, 58.42525495801653, 68.44044399261475, 61.614457266671316, 51.658800397600444, 47.40690238135201, 52.636338983263286, 60.58454663412911, 66.18769904545375, 62.629700251988, 60.481365885053364, 50.10365458897182, 48.04729005268642, 51.549724102020264, 48.91714893068586, 44.72621440887451, 49.828050817762104, 49.39017881665911, 50.25949573516846, 49.142541544778005, 53.298926149095806, 46.81554119927542, 56.01771804264614, 56.95810113634382, 71.75973047528947, 44.917890889304026, 41.470166955675396, 67.46027551378522, 61.56375626155308, 60.63988208770752, 51.620401178087505, 51.236283915383474, 49.23689808164324, 49.675822734832764, 48.04774863379342, 50.36840874808175, 53.24486221585955, 63.94286114828927, 66.05562768663678, 64.9257116317749, 60.30046953473772, 54.99458885192871, 47.61302069255284, 47.48528848375593, 47.03364862714495, 49.08058098384312, 47.85015228816441, 58.2681040763855, 66.67260687691825, 63.00206811087472, 56.392903396061485, 61.21325438363211, 66.22997883387974, 66.64022827148438, 62.70553289140974, 53.439953735896516, 56.776284149714876, 62.171320642743794, 65.9842141015189, 67.48815168653215, 69.35752282823834, 77.98257187434605, 40.53121171678816, 3.9077285528182983, 4.002742562975202, 8.258717434746877, 5.790643904890333, 3.5997887338910783, 2.802034569638116, 0.13483290134796075, 1.058390538607325, 0.47789943324668066, 0.39268574863672256, 0.10416345777256147, 0.2816726969821112, 15.88004013470241, 58.57088920048305, 49.96182795933315, 46.036658559526714, 34.653306688581196, 38.159996509552, 62.473991121564595, 68.48291138240269, 73.98089585985456, 77.11105932508195, 63.859955242701936, 5.7453750882829935, 0.19614216365984508, 0.14371356767203125, 0.12499944972140448, 0.16245002299547195, 0.17373399250209332, 0.14822710119187832, 0.0856718382398997, 0.13742589578032494, 0.15904178230890206, 0.0918099203013948, 0.13628009440643446, 0.13888306330357278, 0.16007008855896337, 0.10862676613032818, 0.10708633557494197, 0.0805028738187892, 0.19329798913427762, 0.09054386216614928, 0.10457849050206797, 0.10050180461257696, 0.15353689555610928, 0.11725133976766042, 0.16264229267835617, 0.20280860736966133, 0.18283959318484577, 0.09756280481815338, 0.16666095703840256], [0.03334869337933404, 0.06298133544623852, 0.007841619712832783, 0.05911352977688823, 0.051942116913518736, 0.07085000071674585, 0.06060156385813441, 0.03795188173119511, 0.05195985042623111, 0.10024864319711924, 0.05143013170787266, 0.024681807994576435, 0.037814427499792407, 0.06110980694315263, 0.047553949523717165, 0.035581894618059905, 0.03209168350856219, 0.04736553391973887, 0.048381982770349295, 0.047219886377985985, 0.04201373823785356, 0.16771512904337474, 6.466387050492423, 70.20764882223946, 68.77175494602749, 66.30350467136928, 44.35664667401995, 37.38598803111485, 18.710784878049576, 21.619510991232737, 12.848811200686864, 36.33549336024693, 39.842554909842356, 21.341626473835536, 0.4810313337615558, 0.018257809935935905, 0.015551406856892365, 0.2763960286974907, 0.28583572645272526, 0.3751603833266667, 1.2259037899119514, 0.5036493486591748, 1.198992765375546, 0.923364132642746, 1.8626290006296975, 31.836006709507533, 63.682192529950825, 64.18737520490373, 62.848109926496235, 64.84220818110875, 57.10656329563686, 54.838136264256065, 59.84908676147461, 65.39536816733224, 67.44927651541573, 63.22695350646973, 64.89090115683419, 54.05725254331316, 46.08853728430611, 53.300194195338655, 60.4397531236921, 61.0643127986363, 59.44430555616106, 55.62679501942226, 63.05144201006208, 54.3717314856393, 46.611899920872276, 40.94446625028338, 51.48313256672451, 57.824207987104145, 59.22959927150181, 58.16102886199951, 56.44866268975394, 45.979342869349885, 43.16345337459019, 45.95344345910208, 45.55231005804879, 45.621295247759136, 47.23607744489397, 45.494476727076936, 49.17962408065796, 46.21625212260655, 50.01040628978184, 49.01889487675258, 55.33913959775652, 51.582953861781526, 66.02122715541294, 40.73336260659354, 38.95947708402361, 66.37263229915074, 50.74553959710257, 54.04537459782192, 44.51118850708008, 46.073772362300325, 40.52537522997175, 43.59363719395229, 40.5201849256243, 44.282203674316406, 43.29023715427944, 48.16019827978951, 51.07652051108224, 54.03201668603079, 48.5986921446664, 43.47028235026768, 43.33027614865984, 42.52788775307791, 41.20356110164097, 42.82466615949358, 41.79807676587786, 50.04070390973772, 57.034948212759836, 59.37505286080496, 54.48792273657662, 57.11968149457659, 57.94412694658552, 61.67022350856236, 60.32328741891043, 55.93902621950422, 47.30917944226946, 49.52103076662336, 53.34679576328823, 60.68437835148403, 60.297419275556294, 59.234018325805664, 72.7625709261213, 56.78539323806763, 13.337189657347542, 0.31898414343595505, 1.6358285077980586, 1.3807593775647027, 1.1338201825107848, 0.4012610199195998, 0.037329295317509344, 0.22102212932493004, 0.13238281996122428, 0.22612220208559716, 0.015589289466983505, 0.06724220288119145, 19.222059386117117, 37.262733936309814, 41.12429257801601, 38.14204931259155, 26.97270369529724, 35.63081748144967, 42.08944599969046, 50.05899504252842, 54.73432322910854, 53.88393667766026, 20.77457356452942, 0.6663233424936021, 0.021744923533073494, 0.01721553604251572, 0.02098156824441893, 0.01978123640375478, 0.046698598457234244, 0.051030864739524465, 0.06635055358388595, 0.06956725062004157, 0.06713327086929764, 0.10769246412175042, 0.019916663511789272, 0.10828692186623812, 0.03140444288562451, 0.026932081174371496, 0.07595132198184729, 0.042068584223410914, 0.0332473507816238, 0.027391953194247823, 0.03610876348934003, 0.012788387664061571, 0.01608523240845118, 0.03665007497849209, 0.02760514211175697, 0.022664480975696018, 0.039761337850775035, 0.024293287324586084, 0.02243812508615, 0.023039106944841996, 0.025971375671880584, 0.03526671849457281, 0.02549733584081488, 0.05091097777975457, 0.022386717576799647, 0.0203203307797334, 0.027113022715119377, 0.057172098596181185, 0.023169811449146697, 0.028898487532777444, 0.02951401039691908, 0.02067616641787546, 0.030787691873099123, 0.02746401191689074, 0.02857116563245654, 0.03603373108697789, 0.056936083760644705, 0.0286639111914805, 0.043537317376051626, 0.29395008246813503, 8.437093326023646, 83.35649626595634, 76.66034357888358, 76.83097743988037, 51.638494287218364, 51.27501317432949, 28.05591743332999, 30.375415461403982, 19.525554963520594, 27.384902102606638, 44.07563373020717, 25.725729601723806, 0.45816665781395777, 0.011082412375669395, 0.12813215090760163, 0.687990702688694, 0.8487321202244077, 1.3449224148477827, 3.755083577973502, 1.9913901942116874, 0.5564970757280077, 0.04762822535953351, 3.366580047777721, 32.9737777028765, 68.9813404083252, 67.99860109601701, 65.09179442269462, 68.1607164655413, 58.52717113494873, 57.81005103247506, 61.987110001700266, 67.19094944000244, 70.38893427167619, 64.0158589226859, 68.53022861480713, 57.06182731900896, 48.47409009933472, 55.37860883985247, 63.06677668435233, 63.51856940133231, 60.13829857962472, 57.65369919368199, 64.79077761513847, 57.39357253483364, 48.30923366546631, 42.908294677734375, 55.32642786843436, 62.21747752598354, 63.86538873400007, 62.75787367139544, 60.38734980991909, 49.62877300807408, 46.913934639522004, 47.00819042750767, 48.717502866472515, 48.20108495439802, 50.88709872109549, 48.292370387486045, 52.06120531899588, 48.85856866836548, 52.0663400377546, 51.87422929491316, 56.46697119304112, 52.78257424490792, 68.40482752663749, 42.984415667397634, 40.92626196997506, 68.46759060450962, 54.10570233208792, 56.07487392425537, 47.18639087677002, 47.964123589651926, 43.331849915640696, 45.016162736075266, 42.635233947208945, 46.63387359891619, 45.299854210444856, 49.86776672090803, 53.669424942561555, 55.875477995191304, 51.222675868443076, 45.28425203050886, 44.20345973968506, 44.81670774732317, 44.40069130488804, 43.91131925582886, 44.39693580354963, 52.29696811948504, 59.214431353977744, 61.46184703281948, 58.1612685748509, 58.30644771030971, 60.5549681527274, 63.918660572596956, 63.01491533006941, 58.90125519888741, 50.79243993759155, 52.62312698364258, 55.54176296506609, 63.692274366106304, 63.37086459568569, 62.62543405805315, 74.52086816515241, 61.417107582092285, 17.21541789599827, 0.9718582161835262, 0.630013685141291, 1.879785840000425, 2.116859244448798, 1.9058494014399392, 0.5431447550654411, 0.6030593429292951, 0.5633618416530746, 0.2506895938089916, 0.019329778218109692, 0.1025888290522354, 19.715935604912893, 39.183612074170796, 36.14355979646955, 35.224900245666504, 33.8405168397086, 45.732198919568745, 50.59413834980556, 57.255800179072786, 60.45595632280622, 64.246823992048, 27.91858455113002, 1.486477630478995, 0.038823755125382116, 0.04377315579248326, 0.07660473763410534, 0.010766154836996325, 0.0469944159766393, 0.09943523577281407, 0.024537914465846758, 0.007654015806370548, 0.07874554275934185, 0.04110232660812991, 0.07022902582372938, 0.058933419441538196, 0.037906799864556105, 0.012158539229338723, 0.06723773812076875, 0.04604605472247515, 0.013352306243697447, 0.033506761504603286, 0.04588270420208573, 0.02860137401148677, 0.0632738247513771, 0.04654286109975406, 0.055401817695902925, 0.007679323466228587, 0.07084501348435879, 0.013875447413218873, 0.09519779136670486, 0.13925849672939095, 0.244908801146916, 0.10525536989527089, 0.08739077778799192, 0.1495122600878988, 0.1677841224840709, 0.11253202693270785, 0.35053466473306927, 0.21297391690313816, 0.11080321470009429, 0.11051766680819647, 0.13062381292028086, 0.10756757975156818, 0.16186919701950891, 0.12924844957888126, 0.11534659697541169, 0.09703865687229804, 0.13299628347158432, 0.09371964354068041, 0.15827529558113643, 0.5632184807743345, 12.239858048302786, 97.32471697671073, 85.25197178976876, 86.88024738856724, 61.11991228376116, 55.14250905173165, 28.044605766023906, 31.26518440246582, 20.17790743282863, 52.890431131635395, 56.32379313877651, 33.17052984237671, 0.9056776016950607, 0.07516440456467015, 0.21661740568067345, 1.5683638879231043, 1.3041148845638548, 2.08621312890734, 4.163592491831098, 4.511822743075235, 4.768183044024876, 4.442561796733311, 4.559768787452152, 35.4682365826198, 73.89673927852085, 71.34618759155273, 66.23240375518799, 70.81943770817348, 61.46087428501674, 59.3452798298427, 64.85857813698905, 68.42176723480225, 71.33313192640031, 68.10488768986293, 70.83549499511719, 60.43839127676827, 49.192346232278005, 57.16226700374058, 65.85763181958879, 64.93914249965123, 60.69852488381522, 59.44190842764718, 69.16455050877163, 60.611554282052175, 50.22420236042568, 44.665650435856406, 56.7939429964338, 65.36162076677594, 65.56694003513881, 63.787152017865864, 61.92568097795759, 52.029076848711284, 49.61406714575631, 49.80256829942976, 50.59817525318691, 52.03696652821132, 51.495813029153005, 51.05523123059954, 55.04193040302822, 50.91534662246704, 53.6908358165196, 55.42560992922102, 59.81774343763079, 56.99759817123413, 70.75595896584647, 45.6526073047093, 43.964476449149, 71.63918617793492, 55.611953667231965, 57.3121292250497, 50.5817288671221, 51.480523518153596, 44.28594527925764, 46.628047534397666, 44.292671135493684, 48.600238118852886, 47.61883633477347, 53.777875900268555, 56.419077260153635, 58.905813217163086, 53.553848607199534, 46.32644360406058, 47.45243740081787, 48.73126029968262, 46.56550679888044, 45.640632084437776, 46.74373851503645, 55.75561809539795, 61.97418635232108, 64.33239800589425, 59.3682644707816, 60.77264131818499, 62.698959895542686, 68.00866903577531, 64.62395831516811, 61.88561071668352, 53.53851045880999, 56.26271152496338, 59.14458111354283, 67.06372792380196, 67.63266032082694, 64.30746786934989, 78.48043114798409, 63.591601916721885, 17.093348469052994, 2.340657029833112, 5.054807960987091, 7.213680573872157, 4.379197699683053, 2.2738666023526872, 0.4790533770407949, 1.1449617275169917, 0.8845739141106606, 0.5123031128730092, 0.09841741967414107, 0.389082130576883, 28.575222321919032, 52.59231172289167, 55.83776664733887, 53.467385223933626, 36.8477076121739, 48.302215984889436, 58.47956207820347, 66.3745013645717, 69.8818894795009, 76.05787917545864, 32.009221826280864, 1.5202763825654984, 0.09594593050756625, 0.18254106491804123, 0.1142473431038005, 0.10367298551968165, 0.14886159928781645, 0.15376975520380906, 0.1438095396650689, 0.1823485509625503, 0.1935654676386288, 0.18326844088733196, 0.17360987487648213, 0.18904862286789076, 0.06681107530104262, 0.08596292297754969, 0.16627839899488858, 0.12152745388448238, 0.08079923755888428, 0.1180939038417169, 0.09763790507401739, 0.1159397451473134, 0.10205538517662457, 0.1371715808553355, 0.11427998063819748, 0.06719528218465191, 0.18237787724605628, 0.05648108531853982], [0.030623024994773523, 0.03711323619687131, 0.0328464315805052, 0.051168196834623814, 0.05648307003346937, 0.03360106430149504, 0.06820863352290221, 0.04255452046969107, 0.0427086293431265, 0.028077829961798022, 0.03414368875590818, 0.03796979505568743, 0.05523454524310572, 0.019830501438783746, 0.0172782496416143, 0.04707385207127247, 0.062272123859397004, 0.05206385288121445, 0.0902298768716199, 0.04419029537322266, 0.057869035484535356, 0.10582500682877642, 34.641581603458945, 78.5062506539481, 76.7635451725551, 69.40184538705009, 57.03556660243443, 24.26852560043335, 30.395106656210764, 25.951528685433523, 43.11340550013951, 57.596303599221365, 29.12105369567871, 3.3385186621121, 0.04896054243935006, 0.12746485242886202, 0.011188161210156977, 0.30167984483497484, 0.2598154826888016, 0.14032167967941078, 0.5614036438720567, 0.8101861742990357, 0.37554058006831575, 4.294261617319925, 40.342307567596436, 68.12647574288505, 64.36468628474644, 65.12486784798759, 64.48420919690813, 55.62456464767456, 59.145949908665244, 61.80326761518206, 65.3638025011335, 66.7335981641497, 60.39889076777867, 64.2534178325108, 60.22898646763393, 50.81074496677944, 46.97005523954119, 55.62904970986502, 59.351394244602744, 61.737141609191895, 56.92974206379482, 58.364486013139995, 61.255603654044016, 54.083058152879985, 43.83656358718872, 39.15294967378889, 48.328250885009766, 59.123277936662944, 56.12515803745815, 57.23336444582258, 58.4116712297712, 51.65740033558437, 46.20745570319039, 44.87118509837559, 48.24467100415911, 48.39758695874895, 50.11134277071272, 50.08205611365182, 51.379757268088206, 52.598238536289756, 55.48396437508719, 54.20567648751395, 59.21227046421596, 53.15585231781006, 69.1560389654977, 36.96496888569423, 36.54082652500698, 66.94851984296525, 52.21977710723877, 50.63690103803362, 40.62761797223772, 45.91163962227957, 41.3054529598781, 44.674498966761995, 42.47394888741629, 43.18339123044695, 41.811090741838726, 42.42409208842686, 41.37753357206072, 43.38638285228184, 41.62343726839338, 43.97280386516026, 41.68373720986502, 42.66805028915405, 42.16332966940743, 44.23008176258632, 40.91575629370553, 47.190066473824636, 53.63225902829851, 58.265029498508994, 56.67342301777431, 58.515991483415874, 53.719486713409424, 60.03095585959298, 61.07394995008196, 59.40611130850655, 50.26628065109253, 47.28659432274954, 48.09180021286011, 52.29919849123274, 55.97204058510916, 64.87223829541887, 58.84621851784842, 66.39355332510812, 62.15835530417306, 27.69347333908081, 1.2774657202618462, 2.453922654901232, 2.709443526608603, 0.8801741302013397, 1.2118133859974998, 0.29203026262777193, 0.09956655944032328, 0.08431465963699988, 0.2827376169817788, 0.025956286749403392, 1.8029201988662993, 28.307205983570643, 30.03263303211757, 32.31312561035156, 18.50261684826442, 17.498510088239396, 25.418570586613246, 40.10219519478934, 51.98408031463623, 53.53575897216797, 46.392468861171174, 10.134458337511335, 0.49832165454115185, 0.03141808822484953, 0.02229377524262028, 0.029344983931098665, 0.020830577239394188, 0.026690702519512603, 0.016170490333544354, 0.06451488565653563, 0.056691519383873255, 0.029521769444857324, 0.027517551722537194, 0.04256646947136947, 0.040055367430405955, 0.04388768571828093, 0.009056073563572551, 0.02882251196673938, 0.03309836484757917, 0.02938778592007501, 0.07479946807559047, 0.018853840185329318, 0.04926753543051226, 0.01852812132398997, 0.03746203373053244, 0.06011888797261885, 0.04498342138582042, 0.0178332437894174, 0.03825015215469258, 0.03516176948323846, 0.041563984871442826, 0.06619740823017699, 0.02353236967298601, 0.01881483629611986, 0.0175757787656039, 0.08090263951037611, 0.017203230809952532, 0.04865424494658198, 0.05506001925095916, 0.012550852061914546, 0.0685181404863085, 0.016730911065159098, 0.008737833006307483, 0.026183818200869218, 0.01030773573022868, 0.13069796322711877, 0.08461071125098638, 0.011393283194463168, 0.04980287241882511, 0.09278606077922241, 42.35171617780413, 89.7943983078003, 82.82834284646171, 78.01091357639858, 63.55082293919155, 33.182522433144705, 31.671247550419398, 29.654473849705287, 32.079985754830496, 53.93205295290266, 36.19545241764614, 4.070053671087537, 0.08545813363577638, 0.1480483343558652, 0.25141388922929764, 1.1071763379233224, 0.8423177387033189, 1.6284354073660714, 2.5591659333024706, 1.9180621632507868, 0.4128493666648865, 5.815911897591182, 43.83924559184483, 70.11296572004045, 67.17805358341762, 67.39699132101876, 68.07130009787423, 57.50803368432181, 62.57864488874163, 64.0313811983381, 68.26379299163818, 69.30718312944684, 63.24763829367501, 64.07568986075265, 63.54499340057373, 52.74370949608939, 49.80561508451189, 56.26301029750279, 62.41507734571184, 63.4153539112636, 58.25807087762015, 58.29360743931362, 63.282879556928364, 55.94953884397234, 46.573278359004426, 41.98131118501936, 51.56669160297939, 61.36214733123779, 59.1625074659075, 58.91229588644845, 61.190908976963584, 54.37913131713867, 46.928091594151084, 47.1620374407087, 51.28716557366507, 50.98846251623971, 54.24247762135097, 53.58173867634365, 53.410997118268696, 54.43216691698347, 59.69448239462716, 55.71575975418091, 61.02074759347098, 56.3049704687936, 69.27433899470738, 38.25102833339146, 39.01993683406285, 68.22033895765031, 53.566952909742085, 52.85303592681885, 44.87290825162615, 47.3714040347508, 42.33574226924351, 46.97631904057094, 45.08576284136091, 44.95535557610648, 43.731975827898296, 43.742874077388215, 43.70290456499372, 44.93801287242344, 43.955454213278635, 44.35827950068882, 44.137521335056846, 44.6138585635594, 43.831018924713135, 47.055650097983225, 44.36950431551252, 48.74321467535836, 56.515924726213726, 60.687657901218955, 59.79047870635986, 58.131558077675955, 55.59661551884243, 63.621110916137695, 64.2307458605085, 61.86045823778425, 53.55914313452584, 50.35996321269444, 51.924843447549, 53.248245988573345, 59.527093342372346, 65.63256577083042, 62.58109760284424, 67.74861880711147, 69.87001500810895, 32.84676463263375, 2.0470309342656816, 0.6852815566318375, 1.7650560992104667, 1.8348687759467532, 3.07880476968629, 0.8659998050757817, 0.6558793314865657, 0.8091144689491817, 0.3877608871885708, 0.03909167128482035, 1.6109819667679923, 31.76614257267543, 37.32391629900251, 30.939213139670237, 21.167256219046457, 25.414115054266794, 33.64138841629028, 45.56029353822981, 59.82338537488665, 63.50789696829659, 66.09207793644497, 18.46811556816101, 0.5094420835375786, 0.015382775637720312, 0.06422132426606757, 0.041506981144526174, 0.021970434646521295, 0.05165569031877177, 0.0566833158954978, 0.03428371124235647, 0.030125736857631376, 0.023112414171919227, 0.05846962718559163, 0.03494123542415244, 0.013443018742171782, 0.055902583325015645, 0.03177169657179287, 0.019256389566830227, 0.04609321290627122, 0.03356821981391736, 0.014260254800319672, 0.027849701399515783, 0.03241119207814336, 0.09833254851400852, 0.056380584104252715, 0.034106745916817865, 0.07156331065510001, 0.04069741422842656, 0.15171243702726706, 0.11460729236049311, 0.06718252572630133, 0.23779007313506945, 0.13457793502935342, 0.08352620194533042, 0.22317588089832238, 0.22620989595140728, 0.06912905949034862, 0.18032775154071196, 0.07764262479862996, 0.12721813709608146, 0.11637065559625626, 0.09986607836825506, 0.09828223514237575, 0.13065771252981254, 0.16191031624163899, 0.23528253340295383, 0.15832970051893167, 0.13784437546772615, 0.13516348360904626, 0.17679459255720886, 52.6940507207598, 100.02920600346157, 96.68405832563127, 88.60079506465367, 76.97627122061593, 37.58605446134295, 39.69911977222988, 37.44086837768555, 62.1500244140625, 82.09400163378034, 44.98510428837368, 6.442614657538278, 0.2355625783758504, 0.4219016209244728, 0.6167064734867641, 2.2060986501829962, 1.114873530609267, 1.7803469129971095, 3.351216060774667, 5.321999200752803, 3.2737516803400855, 6.3771548100880215, 45.51263584409441, 75.297926902771, 67.02438722337995, 70.27324676513672, 71.42233289991105, 60.21925204140799, 63.02549743652344, 67.03317669459751, 69.56628840310233, 70.15254265921456, 65.90902069636753, 67.48948574066162, 66.44512285505022, 54.73167596544538, 53.002328395843506, 59.762970788138254, 64.21765545436314, 67.07790224892753, 58.205768312726704, 59.76864051818848, 66.05426583971295, 58.31413241795131, 47.57440955298287, 43.45442656108311, 53.96243742534092, 63.66219561440604, 61.19912869589669, 60.015364101954866, 63.939359256199424, 57.864441531045095, 49.653331415993826, 50.694324425288606, 54.0393921988351, 53.66014214924404, 56.45534685679844, 56.77530792781285, 54.41662727083479, 58.125186579568044, 62.741878918239046, 58.02608789716448, 62.85208429609026, 59.722316878182546, 71.31920773642403, 40.995094299316406, 42.93610484259469, 72.27288273402623, 57.79109982081822, 54.90212222508022, 47.10589599609375, 50.11304160526821, 45.08196912493025, 48.80915655408587, 47.33787202835083, 48.0167874608721, 46.57718324661255, 44.33617033277239, 47.2096951348441, 45.99194342749459, 46.72399173464094, 46.696101665496826, 46.39025933401925, 47.533210209437776, 47.072447368076865, 49.193829672677175, 46.35000147138323, 51.68667309624808, 60.20962183816092, 64.87912396022251, 63.962858063834055, 61.5277715410505, 56.41014882496425, 63.53115258898054, 67.67191069466728, 64.95594324384416, 55.1040438243321, 52.03334651674543, 54.56805631092617, 56.13469444002424, 61.875459398542134, 69.74227237701416, 65.1381528036935, 70.67173290252686, 72.8193724496024, 33.64345897947039, 2.1702539793082645, 7.32224530833108, 9.398757014955793, 3.8570331931114197, 4.8219282286507745, 0.9137682361262185, 0.7325443433863776, 0.684914767742157, 0.6712159599576677, 0.10310889900262867, 3.2200067128453935, 42.48059136526925, 44.260799748556956, 44.92569719042097, 27.438443183898926, 27.662373202187673, 38.672304562159944, 54.945225375039236, 67.89915152958461, 72.05268737248012, 77.27211162022182, 19.87485306603568, 0.5915534517594746, 0.0938672927607383, 0.19424478975789888, 0.19667110884828226, 0.06936795131436416, 0.20573307972933563, 0.19642823402370724, 0.14433524145611695, 0.17941763252019882, 0.12566906878990786, 0.12342219507055623, 0.17423731620822633, 0.10842456269477095, 0.11356749851256609, 0.08805087701018367, 0.21975124680570193, 0.14000004050987108, 0.09139407332986593, 0.07733371494604008, 0.14763088604169233, 0.2493427289383752, 0.1952016462704965, 0.17231528434370244, 0.18499961442181043, 0.13905458338558674, 0.10364972533924238], [0.031192709425730363, 0.017869090794452598, 0.02152647257649473, 0.08184855125312294, 0.028700070322624276, 0.02061106776818633, 0.005883890969146575, 0.027577335746692758, 0.00825067370065621, 0.024828914386619414, 0.00210775898553298, 0.036817418677466254, 0.014282303795750653, 0.039821503550878594, 0.06284402709986482, 0.08991993564580168, 0.027538443815761378, 0.044009323298398934, 0.06750670940216098, 0.029703905207238028, 0.1693955481584583, 2.559275584561484, 66.1679800578526, 69.69945062909807, 70.54021739959717, 60.20032514844622, 38.233108929225374, 24.36666022028242, 29.350976535252162, 46.842580114092144, 43.50921310697283, 33.32557889393398, 13.88146116052355, 0.01892517626817737, 0.03920149557026369, 0.10711150922413383, 0.26716529258659905, 0.13222028368285724, 0.24727222004107066, 1.1183711886405945, 3.4400750526360104, 0.9537012704781124, 4.587089538574219, 38.58069256373814, 64.02450248173305, 64.85197734832764, 66.1343994140625, 59.908466066632954, 59.52711418696812, 61.445720263889854, 60.044067110334126, 64.76590306418282, 70.42725358690534, 59.244607380458284, 64.65850475856236, 62.09482792445591, 54.02514839172363, 45.70280109133039, 48.35170452935355, 54.222008228302, 59.02008329119001, 60.05043166024344, 58.1208404813494, 56.81207084655762, 58.357155663626536, 50.41635479245867, 45.30992562430245, 41.53342682974679, 49.69910614831107, 57.34505326407296, 59.38457884107317, 58.4647832598005, 58.798449652535574, 52.02505036762783, 52.451235498700825, 47.688172408512656, 51.480693749019075, 49.63210119519915, 53.23953989573887, 53.452585560934885, 55.05399594988142, 53.48333828789847, 58.92085606711251, 55.31597430365426, 62.19473607199532, 53.95632301058088, 63.32319300515311, 35.59187282834734, 36.27123294557844, 63.56897858210972, 48.808513845716206, 50.26483889988491, 43.16104234967913, 45.31522362572806, 42.88090140478951, 48.47437497547695, 46.34934139251709, 47.75362096514021, 45.28817081451416, 42.70824909210205, 40.27691459655762, 42.50120319638933, 40.86937359401158, 41.63332108088902, 42.15178523744856, 43.46297631944929, 41.182306562151226, 43.79628835405622, 40.68972791944231, 42.71671894618443, 46.95442874091012, 54.1065673828125, 55.99241965157645, 59.45053809029715, 54.40519053595406, 56.464063371930806, 59.0682829448155, 59.89810630253383, 55.566317898886545, 49.59996577671596, 47.31188229152134, 48.53210408346993, 52.56256301062447, 58.66077109745571, 62.560836655753, 62.81045763833182, 59.94141442435128, 60.21708420344761, 27.17292298589434, 1.3532956455435072, 1.2522476677383696, 2.2956685296126773, 1.7657865285873413, 0.4220555940909045, 0.5415166510002953, 0.3189550207129547, 0.17386044428816863, 0.19985598937741347, 0.021571228746324778, 8.998525142669678, 33.567549909864155, 43.44954892567226, 32.908099855695454, 17.82553574017116, 20.127361025129044, 37.841105461120605, 47.63014800207955, 53.31039415087019, 51.70346689224243, 51.67516687938145, 8.235216890062604, 0.23814907244273595, 0.0037473690962152822, 0.09675833370004382, 0.03273154203114765, 0.035504768935165236, 0.016862528199063878, 0.06124733920608248, 0.10009792699877705, 0.01922322786413133, 0.020250073567565, 0.04704873270488211, 0.011773912502186639, 0.04581910511478782, 0.018710336814235364, 0.032532035772289546, 0.03734314421723996, 0.05799563654831477, 0.02184497012889811, 0.06667260665978704, 0.03183054930663534, 0.08499577308871917, 0.02389517895478223, 0.026740669838285873, 0.03271423599549702, 0.01724024150254471, 0.055786781146058013, 0.02503541125250714, 0.053098184522241354, 0.05121335334011486, 0.03985528102410691, 0.017446122597903013, 0.027077204547822475, 0.007944834219025714, 0.026354683496590172, 0.0245272003979023, 0.0706870641027178, 0.041801808002804, 0.04895154506500278, 0.03365328435653022, 0.03619446585487042, 0.029867167518075024, 0.05863951878356082, 0.03363545584891524, 0.057974540894584994, 0.03882805025205016, 0.07799579549048628, 3.719900505883353, 81.16137272971017, 79.17480632237026, 79.61177853175572, 67.16840253557477, 50.10417570386614, 33.940946102142334, 33.095708165849956, 31.524279253823416, 44.30917658124651, 42.1802659034729, 15.499000923974172, 0.022381126448245983, 0.08870956487953663, 0.21054725854524545, 0.7685233099120004, 0.9498743329729352, 1.1348175747053963, 2.8025120411600386, 1.3810601042849677, 0.7263299939887864, 6.002643866198404, 41.512262616838726, 67.52982698168073, 66.4908697945731, 68.59078911372593, 62.70136397225516, 61.150324548993794, 63.18609809875488, 64.33796351296562, 67.44840799059186, 70.51112529209682, 60.0032742364066, 66.84755556924003, 62.44453075953892, 56.2829863684518, 49.39689425059727, 49.9764678137643, 57.62888370241438, 60.84374918256487, 62.00156920296805, 57.221010548727854, 59.178863525390625, 61.36358560834612, 53.27578864778791, 45.70908226285662, 44.66878407342093, 51.99774742126465, 60.231856073652, 61.64619663783482, 58.901818002973286, 60.98082324436733, 55.03761209760393, 55.60541193825858, 49.972997188568115, 53.704179831913535, 52.828480992998394, 56.16977936880929, 56.30840287889753, 58.02588292530605, 56.19035645893642, 60.08914702279227, 60.19650363922119, 64.85114356449672, 57.28012234824044, 63.64945261819022, 37.482543672834126, 38.186323234013145, 66.15664754595075, 51.375890595572336, 52.05721705300467, 44.32458768572126, 47.29071113041469, 46.127575738089426, 50.49065882819039, 49.02962984357561, 51.80766555241176, 46.21246535437447, 44.71886668886457, 42.17710099901472, 44.401618889399934, 43.83608416148594, 44.10725845609392, 44.30389595031738, 45.89518281391689, 44.2641453061785, 46.182643686022075, 41.886878217969624, 45.493524823869976, 49.38682631083897, 55.817338943481445, 58.65951347351074, 61.68180615561349, 56.8343710899353, 58.54560470581055, 61.858207021440776, 63.49322237287249, 57.97892352512905, 52.6464729309082, 49.390234402247835, 53.03337642124721, 55.99208961214338, 60.45014068058559, 63.3404940196446, 67.27880941118512, 62.972628593444824, 63.78669343675886, 32.62790332521711, 1.9904137551784515, 0.4189322974000658, 1.1809931312288557, 1.4730086560760225, 1.8870740660599299, 1.5841814620154244, 0.908744959958962, 0.7493289113044739, 0.1506953944585153, 0.05006891242893679, 8.928660137312752, 36.74294267381941, 39.42818866457258, 32.11868722098214, 22.3979263646262, 28.110162019729614, 44.072486196245464, 54.7609417779105, 61.05241748264858, 60.63496276310512, 71.98400442940849, 14.337924804006304, 0.4629262281315667, 0.004004346422984132, 0.10105405747890472, 0.032232174184173346, 0.016867915767111948, 0.028444625636828796, 0.03157078574544617, 0.03689553841416325, 0.03268946607464126, 0.014316259384421366, 0.08269796174551759, 0.03299485433048435, 0.09551178344658443, 0.0310505156272224, 0.012461690864126598, 0.023723602893629243, 0.025701206776180437, 0.021867080192480768, 0.019920682135437216, 0.021992132500080124, 0.0520698002406529, 0.03748346525909645, 0.02755382450829659, 0.032777254935353994, 0.020821681645299708, 0.12608570286205836, 0.1467760811958994, 0.09274171173040356, 0.1799147137041603, 0.1435110249689647, 0.05682149615937045, 0.08691312306161438, 0.13541466370224953, 0.09940977713891438, 0.1413766930678061, 0.14501175444040978, 0.1267660834959575, 0.09426110091486148, 0.1037991726770997, 0.19377794409436838, 0.27459245547652245, 0.1353249070899827, 0.18206224989678177, 0.17893946889255727, 0.1716193381164755, 0.3648465424776077, 5.390377725873675, 93.09275681631905, 87.57402501787458, 87.75558144705636, 78.0447860445295, 54.16035338810512, 36.16414730889456, 40.461493492126465, 62.68315274374825, 59.793403897966655, 49.28624766213553, 22.546162707465037, 0.14303618616291455, 0.41342188737222124, 0.3264727001743657, 1.2209248627935136, 1.617736592888832, 1.6259122341871262, 4.404702799660819, 8.513035399573189, 5.033774895327432, 6.4410339423588345, 44.57359027862549, 71.67373262132917, 69.38654545375279, 72.22607272011894, 64.50979246412004, 61.40109198434012, 64.29259872436523, 64.95519978659493, 69.76984282902309, 71.00371783120292, 64.39555018288749, 69.59413678305489, 65.46568393707275, 59.11226504189627, 51.867788314819336, 51.794279847826274, 59.72201810564314, 63.60640157972063, 64.55708190373012, 56.76188748223441, 60.524326596941265, 64.00643021719796, 55.99293034417288, 50.14372137614659, 47.12421492167881, 54.815241949898855, 64.27016299111503, 63.173862321036204, 61.09347438812256, 63.962573187691824, 57.33725043705532, 57.33375549316406, 52.50851992198399, 56.55587339401245, 56.23729848861694, 58.40225642068045, 59.387934820992605, 60.89297716958182, 60.05089718954903, 63.31867667606899, 60.60536343710763, 66.29664679936, 58.93494701385498, 65.17375537327358, 41.92867163249424, 43.58882556642805, 67.46754332951137, 53.581085545676096, 55.58107934679304, 48.51756845201765, 48.30485282625471, 48.557183606284006, 53.414252349308555, 51.81729228155953, 53.40409755706787, 49.26441294806344, 46.86955649512154, 43.90049048832485, 48.335212979997905, 46.31342267990112, 45.928808620997835, 46.63944605418614, 47.317697933741975, 46.216061047145296, 49.97662762233189, 44.46211685453142, 47.55400616782052, 52.282706941877095, 59.39382689339774, 62.65077413831438, 64.0516004562378, 56.56466286523001, 58.53050627027239, 61.695765086582725, 65.13642965044293, 60.79625129699707, 54.85850838252476, 52.41917303630284, 55.207075187138145, 58.93195234026228, 64.93479987553188, 66.24097783224923, 70.54002979823521, 63.177815846034456, 67.9608793258667, 34.28004251207624, 2.687550404242107, 4.271130195685795, 8.985479031290327, 4.569220508847918, 2.3558132222720554, 1.3407340624502726, 2.501424014568329, 0.9555629534380776, 0.36194121837615967, 0.14666068953062805, 13.17856228351593, 49.82472610473633, 58.22931923185076, 46.08131463187081, 25.2516279561179, 29.494609696524485, 52.36204147338867, 63.02116870880127, 69.32362256731305, 70.66682747432164, 79.59625625610352, 13.388572454452515, 0.6106319565858159, 0.18721959101302282, 0.2376530904855047, 0.16479510787342275, 0.16022108974201338, 0.17510499964867318, 0.1315445713698864, 0.17047859861382417, 0.09412695454167468, 0.0794204001181892, 0.16916700399347714, 0.07302258163690567, 0.14552085926490171, 0.13889372987406595, 0.08742828720382281, 0.18545128804232391, 0.0872111152857542, 0.12711661468659127, 0.133080286106893, 0.09529569718454566, 0.18189474674207823, 0.17400129458733968, 0.13083353452384472, 0.08407505535121475, 0.14319142140448093], [0.046850939746946096, 0.02773792971856892, 0.0544646895889725, 0.03273435795147504, 0.06723875592329673, 0.018821670840095197, 0.02308650261589459, 0.0413717185812337, 0.06998498391892229, 0.0568845761673791, 0.0441108524932393, 0.00970352319667914, 0.020231851509639194, 0.04175626812502742, 0.04447090353018471, 0.015926066752789274, 0.051769928474511416, 0.03571059574772205, 0.05355049596567239, 0.1842019965073892, 0.2600747916315283, 14.75822741644723, 73.50283895220075, 66.94289180210659, 67.10629953656877, 49.70935821533203, 39.163142681121826, 19.580409254346574, 31.15054259981428, 51.176300116947715, 46.74338068280901, 34.65851436342512, 2.2390891313552856, 0.12654114913727554, 0.05898233503103256, 0.12286049021141869, 0.06077060728733029, 0.281357042491436, 0.4129700916154044, 2.5500357832227434, 2.507456136601312, 3.2904254027775357, 27.199711765561783, 53.003801413944785, 65.31225381578717, 66.11705671037946, 67.14036655426025, 61.94849191393171, 64.62873867579869, 62.343323298863, 65.12148407527378, 61.9109924861363, 59.648026738848, 61.620606422424316, 63.64807687486921, 55.57354402542114, 48.14913327353341, 43.96030405589512, 52.231915610177175, 54.83236231122698, 60.32195336478097, 59.49613911764962, 58.35626629420689, 56.275364194597515, 57.77140515191214, 48.84875086375645, 41.51807131086077, 39.602181979588096, 49.48040464946202, 55.90370852606637, 60.22367109571184, 53.92140136446272, 58.61027159009661, 53.46822943006243, 52.70805134092058, 50.85625914164952, 51.95195531845093, 51.80360433033535, 56.231159755161826, 55.25505597250802, 55.942288398742676, 56.64601584843227, 57.751376969473704, 55.96428986958095, 59.67030266353062, 47.58358812332153, 61.58988148825509, 32.77594859259469, 36.72681243079049, 63.532966068812776, 48.5918481690543, 49.399652685437886, 41.72361639567784, 42.08907774516514, 43.20650093896048, 48.1380752154759, 52.22654465266636, 55.76632874352591, 53.30766003472464, 48.332993030548096, 42.41434376580374, 40.28616959708077, 38.779820987156455, 45.14985302516392, 47.364348139081685, 48.66973400115967, 46.01550824301583, 41.50566530227661, 41.21918065207345, 42.39668491908482, 43.00068487439837, 49.17747361319405, 52.186568192073274, 57.20170497894287, 59.29537786756243, 54.506099224090576, 59.29267501831055, 59.10299614497593, 58.840632166181294, 51.118418148585725, 46.277622086661204, 47.18839543206351, 52.73088659558977, 57.07960775920323, 58.55943856920515, 59.64535863058907, 66.59331403459821, 61.20925222124372, 57.797314984457834, 28.25154917580741, 0.14575036694960936, 1.683112410562379, 2.4788929607187, 1.9911897821085793, 0.9679011085203716, 0.7645729333162308, 0.28906264901161194, 0.0674085525263633, 0.05160450842231512, 0.1530324047697442, 23.33288986342294, 38.51845407485962, 39.75193650381905, 40.55091680799212, 20.86877724102565, 26.0533058983939, 34.91956165858677, 51.48835066386631, 63.68784836360386, 63.44596767425537, 44.176778657095774, 2.966490830693926, 0.3166405106229441, 0.111587933663811, 0.11398439721337386, 0.08058306308729307, 0.03806277810196791, 0.03165754662560565, 0.04239563470972436, 0.009485820324958434, 0.026418450521305203, 0.023921207558097582, 0.05611542958234038, 0.03653917521504419, 0.03456225326018674, 0.04556724987924099, 0.023941449954041412, 0.04615823013175811, 0.012928042893431016, 0.02826213533990085, 0.03586118980976088, 0.10041002596595458, 0.041304116137325764, 0.022992800322494338, 0.03847581593851958, 0.02719064033590257, 0.03396096606073635, 0.018904947442933917, 0.050176846994353194, 0.05673351052350231, 0.07851068821868726, 0.025574580267337815, 0.048435464900519164, 0.02778121855642114, 0.08957048332584755, 0.045051132395331345, 0.036969719255076985, 0.016533026504995565, 0.042739251628518105, 0.07543988299689122, 0.04708655085414648, 0.05802971936230149, 0.07283797939973218, 0.012517037269260203, 0.05512136560199516, 0.14826058010969842, 0.2586267979017326, 20.582044192722865, 86.03388037000383, 74.03484167371477, 75.39646625518799, 60.187255586896626, 48.316623074667795, 25.76586413383484, 26.495690754481725, 41.64991337912423, 44.9627171925136, 36.43511315754482, 2.5692518949508667, 0.1286726990448577, 0.20675939108644212, 0.9002573554004941, 0.9190731857504163, 2.0769978633948734, 2.583564532654626, 2.092913797923497, 2.2387035063334872, 3.833229967526027, 29.242188589913503, 56.617146083286826, 68.42329583849225, 70.10491275787354, 68.91515186854771, 64.30990668705532, 68.00126920427594, 64.64946515219552, 66.21223313467843, 63.44446686335972, 61.18726117270333, 65.11018630436489, 65.66285296848842, 59.1033296585083, 50.340615953717915, 46.7751339503697, 55.66725785391671, 56.543373584747314, 63.684756415230886, 60.53845228467669, 57.62612526757376, 56.96792588915144, 60.029830251421245, 50.46611084256853, 44.775445869990754, 41.756345885140554, 52.040808882032124, 57.5228020804269, 62.17088290623256, 55.01830652781895, 60.979530879429404, 56.09388072150094, 55.39714315959385, 53.981166294642854, 54.72275447845459, 54.92944949013846, 58.41995348249163, 57.7994133404323, 58.64372021811349, 60.00963878631592, 61.22361414773123, 58.7436283656529, 60.78465475354876, 48.72844280515398, 60.698927879333496, 34.192620277404785, 39.99327175957816, 65.05307906014579, 50.33967447280884, 51.16778857367379, 42.78100367954799, 45.339841093335835, 46.901855196271626, 51.92207111631121, 54.34071125302996, 58.599369866507395, 55.77171359743391, 49.21821437563215, 44.574146134512766, 42.92369188581194, 41.909748213631765, 46.98331240245274, 50.09371519088745, 53.16822011130196, 48.29734877177647, 44.9212920325143, 44.16073874064854, 44.204606192452566, 45.744125502450125, 52.09766599110195, 54.190744808741975, 59.41732570103237, 60.951293400355745, 54.89023038319179, 60.36626202719552, 61.348987443106516, 61.513972418648855, 54.318730626787456, 48.77776459285191, 49.18908405303955, 54.86287879943848, 59.23364312308175, 60.42278562273298, 61.79726437159947, 67.36705153329032, 64.17486844744, 61.596072333199636, 32.07351003374372, 0.8195484376379422, 0.3247532924371106, 0.8088698163628578, 1.7502340716975076, 2.6693563291004727, 2.074348428419658, 1.1039087304047175, 0.3802735518131937, 0.13975617502416882, 0.3832782134413719, 23.941209861210414, 39.204036303928916, 32.67250728607178, 43.846985885075156, 27.780388355255127, 38.778448717934744, 43.25553090231759, 56.323310238974436, 68.9440563746861, 69.5382524217878, 61.16509641919817, 3.700868087155478, 0.1938165527369295, 0.11627327225037984, 0.06576290833098547, 0.030211157631129026, 0.041931218201560636, 0.007346681851361479, 0.026402118183406334, 0.039913468794631105, 0.067423968841987, 0.06298626161047391, 0.056480220186391046, 0.027039164178339497, 0.023405029006036263, 0.04819776390546134, 0.02399270479301257, 0.013109933535036231, 0.036190584634563754, 0.05497971802417721, 0.033226387442222664, 0.07514997891017369, 0.05764559390289443, 0.01825616109584059, 0.05135412221508367, 0.008762229732902986, 0.14731464801090105, 0.10795413436634199, 0.23757106917245047, 0.10033259154962641, 0.16274141307388032, 0.15308036362486227, 0.1094806617391961, 0.1478268876671791, 0.18213937218700135, 0.20460570736655168, 0.06682446279696055, 0.10711176706744091, 0.1461288673537118, 0.1349417655063527, 0.12273665757051536, 0.18629352641957148, 0.1776656008192471, 0.17189993948808738, 0.1495173898126398, 0.28305050304957796, 0.45146921862448963, 27.57245830127171, 99.64016941615513, 84.31351334708077, 86.92445877620152, 66.0321705681937, 54.565197127205984, 29.66129698072161, 42.892491000039236, 71.78964941842216, 61.85858222416469, 51.25281367983137, 3.4061396164553503, 0.26136797081146923, 0.38691255556685583, 1.8352593949862888, 1.6562944267477309, 3.074380938495908, 4.595324456691742, 8.17060559136527, 9.225782479558672, 5.213985111032214, 34.251582690647666, 59.131511551993235, 70.29779475075858, 70.72859001159668, 70.66522938864571, 66.351989201137, 69.97308458600725, 67.89066083090646, 69.07467555999756, 65.18686662401471, 60.83889239174979, 68.29378141675676, 69.46118995121547, 62.55618136269705, 51.598114831107004, 49.79629060200283, 58.216590132032124, 59.646991457257954, 65.82314096178327, 62.72279221670968, 58.41741739000593, 58.41446440560477, 63.002401624407085, 53.12405041285923, 46.823132106236045, 44.125928265707834, 55.22206939969744, 60.13988971710205, 66.0484640938895, 55.66952644075666, 63.30050713675362, 58.45715413774763, 58.153288568769185, 56.74931819098336, 57.26505170549665, 56.90102515901838, 60.171337263924734, 61.458240917750764, 59.64657456534249, 62.271298272269114, 63.76264572143555, 59.54898016793387, 60.62002413613455, 48.880174091884065, 59.40982164655413, 36.54639203207833, 43.35566486631121, 67.3695181437901, 53.18907165527344, 53.244327204568044, 46.077649457114084, 47.39986038208008, 48.91657223020281, 54.07790606362479, 57.94141020093645, 61.26790196555001, 57.37863738196236, 51.69126238141741, 47.139532225472585, 44.83750023160662, 42.69722924913679, 49.0039701461792, 52.89198405402047, 55.49744388035366, 52.31118760790144, 46.972136225019185, 46.32585995537894, 46.693311963762554, 48.1354592187064, 55.05524662562779, 58.13387182780674, 62.282832281930105, 62.392328943525044, 55.80284847532, 63.15952123914446, 64.29173714773995, 63.59572219848633, 57.52481705801827, 51.010450090680806, 51.2537065233503, 57.950741631644114, 63.96292059762137, 63.141157150268555, 64.69872788020542, 71.9146614074707, 66.32505103519985, 64.18916089194161, 32.698031493595664, 1.4441612554447991, 5.477390451090677, 8.720406992094857, 5.078000179358891, 4.16595835345132, 2.6982412934303284, 1.703706436923572, 0.623533621430397, 0.2169202494301966, 0.6359605831759316, 34.17170967374529, 54.72691297531128, 52.84942633765084, 51.28127350125994, 28.9637325831822, 40.80951486315046, 46.49964829853603, 65.87366131373814, 77.9149728502546, 82.47285911015102, 70.52208260127476, 4.250208735466003, 0.33380807084696634, 0.30027666155781063, 0.20385074216340268, 0.13035528947200092, 0.14294230405773434, 0.08483358964856182, 0.1999316324612924, 0.09878750624401228, 0.19354671293071338, 0.13490198978355952, 0.15358998413596833, 0.10431033346269812, 0.13412296372864926, 0.14548142280961784, 0.09683833976409265, 0.10570323014897959, 0.05800105804311378, 0.11006534179406506, 0.15397388567881926, 0.19639043962316854, 0.16823722102812358, 0.14872627226369722, 0.07790384042475905, 0.19364481552370957], [0.012068223673850298, 0.03515379669676934, 0.07130195932196719, 0.0193968700644161, 0.043608186966074367, 0.026037870407370583, 0.012497063742817512, 0.025755767777029957, 0.017180893437138627, 0.05053294895749007, 0.06763736132000174, 0.02805709053895303, 0.022122372207897048, 0.024059903508584415, 0.02781523351690599, 0.038856809958815575, 0.02081999378944082, 0.025067733268120458, 0.01348014987472977, 0.024518956197425723, 0.18152214959263802, 46.19462238039289, 75.63510908399309, 64.41458129882812, 52.6140387398856, 31.849548748561315, 27.459425006593975, 29.281400748661586, 50.71427617754255, 37.134741170065745, 53.18551417759487, 13.34299053464617, 0.033657559127147706, 0.05810748626078878, 0.06748475200895752, 0.479547133403165, 0.7273396540965352, 0.330942943160023, 1.4353433400392532, 1.6658808780567986, 1.897440778357642, 18.650196586336406, 52.18133619853428, 65.1442185810634, 67.30658136095319, 63.94069331032889, 66.55382047380719, 62.13345990862165, 63.11528205871582, 63.97460746765137, 60.71007973807198, 58.249844210488455, 56.71192298616682, 64.2082267488752, 58.6506336757115, 50.25918654033116, 43.34226526532854, 46.38705621446882, 57.80966540745327, 57.97228799547468, 62.25421265193394, 55.44886554990496, 57.911150796072825, 58.03073276792254, 55.84462799344744, 43.44931616101946, 40.839221886226106, 41.13861976351057, 47.73045914513724, 55.973131452287944, 57.96926205498831, 56.25816740308489, 58.222499574933735, 56.433432238442556, 55.552279063633506, 55.929260526384624, 56.74046618597848, 54.93707166399275, 58.35081890651158, 55.110040119716096, 59.67841815948486, 57.8673597744533, 57.36076314108712, 54.14757217679705, 51.979393754686626, 43.953908239092144, 56.44326046534947, 29.47029447555542, 32.3239300591605, 62.480800356183735, 48.17777027402605, 53.0752705846514, 44.17354079655239, 45.43230424608503, 41.08096708570208, 48.34412751879011, 51.716974190303254, 59.1656619480678, 55.89942496163504, 55.762138979775564, 49.291312898908345, 44.464614731924875, 45.21462065832955, 50.64886583600725, 52.91193233217512, 56.36298792702811, 51.83083432061331, 43.60698468344552, 39.74209785461426, 42.2478996685573, 41.23318822043282, 43.31820017950875, 49.93049505778721, 54.77038090569632, 58.26926442555019, 53.427099568503245, 54.512710435049875, 61.18147332327706, 56.72609731129238, 55.206262247903005, 46.513061795915874, 46.926455293382915, 49.22538144247872, 53.16581950868879, 56.73180178233555, 59.72515869140625, 59.02503735678536, 63.178107670375276, 59.94233853476388, 57.70682512010847, 22.496217318943568, 0.22068909076707705, 0.7993772200175694, 1.9290422712053572, 2.7795117667743137, 0.3824308046272823, 0.5103526775326047, 0.20650895738175937, 0.14233076758682728, 0.03260182649163263, 3.2161048650741577, 34.21837724958147, 39.74081938607352, 38.41330698558262, 26.367611135755265, 15.653407267161779, 23.61170196533203, 46.13355466297695, 47.99651261738369, 55.510346685137065, 59.96075126102993, 26.82595774105617, 1.1153677212340491, 0.01741019416866558, 0.07575698276715619, 0.04746580782479473, 0.07160843323384013, 0.030065354026321853, 0.0831927087690149, 0.07545424758323602, 0.043947685177304914, 0.058233008453888555, 0.06883032766303845, 0.0413572148952101, 0.03896805577512298, 0.03519449183451278, 0.06359919586351939, 0.020872415708644048, 0.03033166884311608, 0.014039776720372694, 0.03867050459874528, 0.02255137258076242, 0.004983921136174883, 0.04295528021508029, 0.04108319870595421, 0.07056881580501795, 0.016663062652306895, 0.03577505657449365, 0.016939470677503517, 0.06794785894453526, 0.017715633314635073, 0.01615694847090968, 0.018510472628154924, 0.038850228169134686, 0.03329843429050275, 0.020649918987016593, 0.011887477211920279, 0.10883567349186965, 0.014565051034358996, 0.05857614361281906, 0.06210236796843154, 0.011938602281069117, 0.0833724866222058, 0.06044213527015277, 0.06630450141217027, 0.054310906412346024, 0.358160176979644, 56.81317213603428, 86.9126329421997, 73.75346742357526, 60.603459630693706, 41.440067359379356, 43.470970221928184, 30.993683542524064, 38.33372231892177, 39.851816858564106, 51.91470602580479, 14.563550182751246, 0.03938474752275007, 0.052410682663321495, 0.4772645958832332, 1.3443079335348946, 1.7435286257948195, 1.3758978098630905, 2.7618592168603624, 1.180082048688616, 1.8335323333740234, 21.45389720371791, 56.812258447919575, 68.10374818529401, 69.55779075622559, 65.7092113494873, 67.93519878387451, 64.520596912929, 65.8374125616891, 65.81228787558419, 62.640942437308176, 60.986590249197825, 58.21072237832205, 64.11584350040981, 61.19578661237444, 51.385142121996196, 45.625728198460166, 48.62894460133144, 58.01138203484671, 61.233598709106445, 64.04445770808628, 56.01497003010341, 60.06664180755615, 59.024141039167134, 57.4710762160165, 46.796464920043945, 43.34674685341971, 43.08450099400112, 49.29914699281965, 58.64249038696289, 59.04643086024693, 57.608070373535156, 58.36358969552176, 58.83921473366873, 57.53261293683733, 59.60867214202881, 59.44623020717076, 57.539140769413535, 60.576181003025596, 58.05339779172625, 61.72287000928606, 57.98438480922154, 57.38401528767177, 54.0655973298209, 53.28591912133353, 46.428547382354736, 57.70110675266811, 33.183922495160786, 34.915517807006836, 65.62703500475202, 52.31508207321167, 55.58941718510219, 46.13090739931379, 47.55050080163138, 43.263142653873985, 50.611015524183, 53.92144305365426, 62.77363913399832, 59.4528101512364, 57.95629671641758, 51.36364786965506, 47.62712900979178, 46.43496404375349, 53.68333523614066, 56.72200829642159, 60.87252862112862, 54.511209624154226, 46.32469265801566, 41.88086802618844, 43.8514084134783, 43.09516995293753, 45.5983418737139, 53.35044356754848, 58.134319986615864, 60.806270599365234, 53.054655279432026, 56.9342167036874, 61.30037089756557, 58.85075569152832, 56.58439227512905, 50.13363953999111, 49.03173514774868, 52.07846117019653, 54.39392055783953, 60.174373626708984, 64.30987194606236, 60.886911392211914, 65.33736460549491, 62.41274969918387, 60.54507391793387, 26.902790921075002, 0.936596542596817, 0.3502676747739315, 0.8713855275085994, 2.4540516308375766, 1.6410843857697077, 1.3590755696807588, 1.0232629435403007, 0.26666950061917305, 0.08558436150529555, 3.0487249323299954, 35.762506689344136, 33.983455181121826, 33.45988409859793, 27.74128041948591, 22.6869957447052, 35.339396136147634, 51.330379894801546, 56.134371348789756, 61.352100236075266, 68.97325270516532, 40.4755323273795, 1.27645942568779, 0.05423153817121472, 0.08388858035738979, 0.03320203821307846, 0.07246999628841877, 0.027681568903582435, 0.1560940904808896, 0.02738563433688666, 0.06899257217134748, 0.016989251399146657, 0.04736208696184414, 0.040658222045749426, 0.08528664748051337, 0.0257172660037343, 0.07330433651804924, 0.013079334150201507, 0.042630241585097144, 0.025142853880035024, 0.0504277590662241, 0.0355181394677077, 0.027313558650868278, 0.0665884886735252, 0.03459824615025094, 0.02262954829659845, 0.15182588808238506, 0.2500115744769573, 0.14509843050369195, 0.23973668153796876, 0.13750140315720014, 0.10678311863115855, 0.1007462264969945, 0.1089897280825036, 0.0828279894111412, 0.21816769534988062, 0.218215192801186, 0.12133081443607807, 0.11708258810852255, 0.1104459660127759, 0.22921298337834223, 0.058559098813150606, 0.19727049954235554, 0.171008914442999, 0.1703264574919428, 0.13008147345057555, 0.5773844463484628, 66.29161630358014, 95.6265425000872, 83.08056245531354, 70.1880271094186, 47.45819050925118, 40.0529602595738, 40.123536586761475, 71.02120644705636, 50.72700527736119, 72.20573534284318, 19.516548361097062, 0.10448720040065901, 0.18266245483287744, 0.6820985760007585, 2.5792392790317535, 2.1057953238487244, 2.931094970021929, 5.7678455625261575, 7.204302242824009, 4.6477477465357095, 24.302722896848405, 61.18131351470947, 70.96725368499756, 71.9960526057652, 67.51809842245919, 71.45668479374477, 67.34440735408238, 67.54500184740338, 68.80199350629533, 64.43676689692906, 61.60443101610456, 59.89653600965227, 67.10347161974225, 63.52169609069824, 54.50094018663679, 48.54819958550589, 52.48164081573486, 61.308743476867676, 63.71773951394217, 67.74273368290493, 57.8144075529916, 61.67268317086356, 63.001234327043804, 61.58899906703404, 49.64960370744978, 45.91132695334298, 45.920502049582346, 53.25369337626866, 61.29129655020577, 62.94309180123465, 58.22555678231375, 59.702028138296946, 60.79302733285086, 59.880555152893066, 62.93833923339844, 61.504779951913015, 60.06642641339983, 64.66479287828717, 58.93129226139614, 63.01533222198486, 60.18678310939244, 58.66795553479876, 56.22312068939209, 55.26351540429251, 46.89021348953247, 58.91875076293945, 36.71832173211234, 38.95080920628139, 65.23239816938127, 54.73211717605591, 57.955845083509175, 49.87142842156546, 50.846653257097515, 47.05884974343436, 52.86270087105887, 56.12404979978289, 64.88921969277519, 61.917023522513254, 60.15737138475691, 53.412803649902344, 50.843832288469585, 49.920517444610596, 55.80409915106637, 58.507966314043315, 61.38636180332729, 56.51735952922276, 48.205066272190635, 44.74415118353707, 46.03587341308594, 44.638121673039024, 47.76074634279524, 56.835583550589426, 61.39829880850655, 63.68491622379848, 54.238586630140034, 56.22380856105259, 64.30698149544853, 63.55916772569929, 58.98402908870152, 52.77485479627337, 51.39233003343855, 55.680230140686035, 56.910012653895784, 63.47773483821324, 65.67959117889404, 63.905806405203684, 68.2795376096453, 65.27110658373151, 65.03453431810651, 26.35879213469369, 1.258109341774668, 3.113299535853522, 7.908622894968305, 9.08058944770268, 2.6135683740888322, 2.1761734102453505, 2.085993392126901, 0.5028392864125115, 0.22511879807072027, 5.6690321905272345, 50.571372577122276, 57.70098515919277, 49.50774233681815, 34.922566754477366, 22.520640236990793, 35.009620734623496, 59.139501980372835, 64.56537805284772, 69.76727894374302, 80.42330728258405, 44.18848637172154, 1.4893808918339866, 0.12154684641531535, 0.15401508632515157, 0.15387424959668092, 0.2011370634926217, 0.1175484973937273, 0.24517087851251873, 0.14191919538591588, 0.1985316247280155, 0.13992093689739704, 0.15953506369675907, 0.1467498761734792, 0.13165414120469773, 0.08281803530241762, 0.15359077123658998, 0.10768125472324235, 0.18644595252616064, 0.13281203407262052, 0.12090556296919074, 0.08773124630429915, 0.09307266718574933, 0.13191372156143188, 0.11736046176935945, 0.15798877738416195], [0.015042190074122377, 0.04547318456960576, 0.012560654348427696, 0.0617154198033469, 0.04799876654786723, 0.014107918599620461, 0.019905788291777884, 0.04707095811941794, 0.06495446099766664, 0.0527136044443718, 0.04976807375039373, 0.06650319682168108, 0.06238774622657469, 0.030335109015660625, 0.17305005634469645, 0.03725636298102992, 0.040571189751582484, 0.035466075475726805, 0.060380659997463226, 0.17419889755547047, 5.832535028457642, 68.07197407313755, 65.09802000863212, 65.49110739571708, 47.51765319279262, 35.92594916479928, 18.042182309286936, 35.81604950768607, 34.46486806869507, 34.586666515895296, 37.82870292663574, 1.798880038516862, 0.015475930014093007, 0.13437509377087864, 0.2168612711663757, 0.31425225734710693, 1.0774556355816978, 1.42400909108775, 1.7832675448485782, 0.755693678344999, 11.05937213557107, 53.67093270165579, 66.89947945731026, 65.20967755998883, 63.182276589529856, 62.40169511522566, 65.05721323830741, 62.14083194732666, 64.37426785060337, 58.85383374350411, 63.47952052525112, 55.64895282472883, 55.8637181690761, 63.71935149601528, 53.8638459614345, 45.14070919581822, 44.549455710819785, 53.984873158591135, 55.84409645625523, 60.540508951459614, 56.395210197993684, 55.08764607565743, 55.985891819000244, 53.65262072426932, 50.25680678231375, 41.78730705806187, 40.64220571517944, 41.02348116465977, 43.56999247414725, 54.629520075661794, 56.41488749640328, 56.62107528959002, 55.97196762902396, 53.49686295645577, 54.99989380155291, 54.788161345890586, 58.037910257067, 55.8744809286935, 57.963175433022634, 55.54838112422398, 55.27388906478882, 49.92522137505667, 51.76893629346575, 45.37357112339565, 50.309109347207205, 44.505386761256624, 52.562764508383616, 30.43928677695138, 28.771397760936193, 61.22918660300118, 50.52092170715332, 55.43275267737252, 46.749488149370464, 44.5032501901899, 39.64619534356253, 45.406536851610454, 49.74297707421439, 57.85531159809658, 56.702400479997905, 57.47103105272566, 52.951262610299246, 53.93725020544869, 49.51856068202427, 54.59894105366298, 56.796096937997, 54.49698666163853, 55.93115043640137, 47.72408069883074, 39.92347015653338, 42.6613313811166, 39.92909819739205, 43.622350624629426, 47.205380303519114, 53.19761446544102, 56.55639450890677, 54.55185658591134, 50.9674859046936, 59.80056054251534, 57.86567483629499, 55.86814764567784, 47.83107948303223, 48.421572140284944, 46.26283284596035, 54.28289876665388, 53.919118881225586, 59.333328928266255, 61.00194576808384, 62.19304765973772, 59.61643327985491, 62.80125822339739, 56.978640011378694, 27.45303440093994, 0.5268663742712566, 1.1364057809114456, 2.613697784287589, 1.5469904690980911, 0.5049495303205082, 0.5189423337578773, 0.1029386409957494, 0.06301815275635038, 0.056686918916446824, 8.223494410514832, 33.5040294783456, 39.322409289223806, 33.781603063855854, 25.47245212963649, 18.24634643963405, 32.73639597211565, 47.446086747305735, 57.09900712966919, 53.16655601773943, 60.635289328438894, 13.880153162138802, 0.47691745736769264, 0.11246469590280737, 0.03491196342344795, 0.029981422637190138, 0.029255189999405826, 0.0570240422551121, 0.0418881074791508, 0.05967469859336104, 0.05006544850766659, 0.04546469270384737, 0.049506814019488435, 0.05684280555163111, 0.041197969511683495, 0.051516139414161444, 0.010790558348942016, 0.020740825716140013, 0.031609547058386464, 0.052840958682021925, 0.03052846435457468, 0.0678031002836568, 0.06281211559793778, 0.08198146947792598, 0.05119381831692798, 0.030504447607589618, 0.08007322544498102, 0.035946580049182685, 0.04342320474929043, 0.015105974062212875, 0.009489170591613012, 0.031744073411183696, 0.056682861277035305, 0.07607485606734242, 0.04999941347965172, 0.03259595716372132, 0.03238017624244094, 0.03388817621661084, 0.012553813019102173, 0.03704561339691281, 0.10364376101642847, 0.026806947442569902, 0.07918477883296353, 0.17256410313504084, 0.23308171864066804, 8.668871334620885, 79.79876845223563, 73.07574013301304, 71.86914375850132, 54.915803228105815, 40.88054282324654, 22.892834390912736, 32.14161627633231, 31.246153286525182, 35.25891167776925, 42.09619964872088, 2.8707915544509888, 0.02894269748191748, 0.48338633882147924, 1.692944871527808, 1.2923028383936201, 2.7259270421096256, 1.6572729285274233, 0.9154757559299469, 0.5429003738931247, 11.6520882163729, 56.54542677743094, 70.40440096173967, 67.9346707207816, 66.00378717694963, 64.41334451947893, 64.4824721472604, 64.98801612854004, 65.12044184548515, 62.12772764478411, 64.41881969996861, 56.58588266372681, 58.32552746364048, 68.30878257751465, 55.62928594861712, 47.12312405450003, 44.97225706917899, 55.90205832890102, 58.86371408190046, 64.44808551243374, 57.88047449929373, 56.16429376602173, 59.01068237849644, 57.09527594702584, 52.94365085874285, 43.278150762830464, 42.254000186920166, 41.86555767059326, 45.11751610892159, 55.45823866980416, 59.47218172890799, 57.89804649353027, 54.768824509211946, 54.89641080583845, 55.80463068825858, 55.52176257542202, 59.78770637512207, 56.526023932865684, 59.9611542565482, 57.001461369650706, 55.99337155478341, 49.8581087248666, 52.80800117765154, 49.79044369288853, 52.494856289454866, 47.12264462879726, 54.69665009634835, 31.31107030596052, 30.39197996684483, 62.23308318001883, 52.34275327410017, 58.39223711831229, 48.27073022297451, 46.98185675484793, 42.45532424109322, 47.66261693409511, 52.490551880427766, 58.94161033630371, 57.31090634209769, 60.938480922154014, 55.60173634120396, 56.25472109658377, 52.38430002757481, 58.27578183582851, 58.61847046443394, 58.1686440876552, 59.56549603598458, 50.51871565410069, 42.14128998347691, 45.02961792264666, 42.049292360033306, 46.61830963407244, 50.43319375174386, 56.251552718026296, 59.35899557386126, 56.674538203648154, 52.531000818525044, 61.26947920663016, 61.236350195748464, 57.65430021286011, 50.29421935762678, 50.11491414478847, 47.86143268857683, 55.13362577983311, 56.25046532494681, 60.127681732177734, 62.75134931291853, 64.23542199816022, 62.779343605041504, 64.7196489061628, 60.67173263004848, 32.7878543308803, 1.0067761710711887, 0.5616803233112607, 0.9589357610259737, 1.602573452251298, 2.37793150969914, 1.7962859719991684, 0.5876412902559552, 0.09150620124169759, 0.007526586929868374, 8.519210611070905, 36.72579104559762, 34.7128701210022, 28.05639338493347, 32.052363191332134, 24.09033383641924, 42.7602459362575, 57.520318099430625, 63.99440288543701, 58.842681884765625, 72.57329504830497, 22.50358588354928, 0.4556107521057129, 0.06333158843751464, 0.12073218370122568, 0.05147392096530114, 0.03650165222851293, 0.01868676790036261, 0.024206716434231827, 0.04757132680554475, 0.041407273816210885, 0.022976454413895096, 0.01587355662403362, 0.13324556366673537, 0.026900888919564228, 0.09922719015074627, 0.013332928979902394, 0.02424034632609359, 0.07439679146877357, 0.0056303788359010854, 0.017346954704927545, 0.04234780138358474, 0.04365984383704407, 0.030769113584288528, 0.029657873391572918, 0.10972246447844164, 0.15970063981200966, 0.12429111344473702, 0.16528708647404397, 0.1710764965308564, 0.06735330620514494, 0.1281241849064827, 0.1425227794264044, 0.15567190599228653, 0.1241663715669087, 0.11149992088654212, 0.08135243358888797, 0.15696534301553453, 0.052551326009311845, 0.2946108670106956, 0.1606634267206703, 0.19093596802226134, 0.12001972193164484, 0.2936528298471655, 0.4263037389942578, 10.646449378558568, 92.3717839377267, 80.99978542327881, 84.15243325914655, 64.33857495444161, 51.10035283224923, 27.278323684419902, 51.08273914882115, 47.72271885190691, 47.91221707207816, 56.10095746176583, 3.605900977339063, 0.17788089998066425, 0.671571675155844, 2.1752597221306393, 2.292678632906505, 4.92666493994849, 4.785003330026354, 7.575733831950596, 3.8109292898859297, 14.899400915418353, 60.38013063158308, 73.29613699231828, 72.23031806945801, 68.51053047180176, 66.05252879006522, 66.92400659833635, 66.65905094146729, 68.5377118246896, 64.65099375588554, 67.59122821262905, 59.34555775778634, 60.62582588195801, 68.46940408434186, 58.56182180132185, 50.97001504898071, 47.758634090423584, 59.470958845955984, 61.421477999006, 66.78693948473249, 59.62936387743269, 58.07089335577828, 60.88677242824009, 59.18551295144217, 55.25782830374581, 44.38995286396572, 45.668244225638254, 45.95481225422451, 47.394395623888286, 58.992867197309224, 61.328670910426546, 60.3095577784947, 54.443711348942344, 54.164001192365376, 56.656441620418, 57.956803934914724, 61.35310077667236, 58.690676144191194, 61.841038022722515, 58.69410160609654, 56.65731361934117, 51.33568137032645, 54.40352644239153, 51.6166422026498, 55.62889684949602, 49.06894275120327, 54.62379823412214, 35.523575510297505, 35.02565370287214, 64.1186158316476, 53.29772758483887, 58.568978445870535, 51.341312885284424, 48.32177168982369, 45.36292995725359, 49.955717018672395, 56.593761920928955, 61.219097818647114, 60.014815194266184, 63.23605564662388, 58.75747612544468, 58.66687856401716, 54.31529821668352, 60.12062236240932, 62.978298323495046, 60.841678619384766, 59.69034126826695, 53.46194478443691, 43.978855746132986, 47.70599453789847, 43.87059933798653, 49.548851353781565, 52.6281817981175, 60.14666421072823, 61.00990840366909, 58.069430759974885, 52.73437111718314, 63.38845048631941, 64.0315271105085, 60.36031436920166, 53.07279702595302, 53.12533235549927, 51.88045488085066, 59.085118430001394, 59.012308256966726, 63.58973285130092, 65.73571872711182, 67.47240012032645, 64.1546630859375, 66.26995182037354, 62.87837627955845, 31.61556121281215, 0.9179957807064056, 3.469295918941498, 8.868272474833898, 4.869243289743151, 2.939459515469415, 2.9899019173213413, 0.8677343034318515, 0.18953328686101095, 0.13833758900208132, 13.595786843981061, 49.31421416146414, 51.74010474341256, 44.48969772883824, 37.41726882117135, 25.222527163369314, 46.067109039851594, 61.110810143607004, 72.63211849757603, 66.96031093597412, 83.29642214093889, 25.16641524859837, 0.7818351898874555, 0.17718819715082645, 0.1417586947126048, 0.16575161154781068, 0.12742305467171328, 0.157630198768207, 0.13627955157841953, 0.1196809701089348, 0.15176178009382316, 0.136162260015096, 0.1816460500870432, 0.2640108104263033, 0.13886349435363496, 0.21573241959725106, 0.17372853708054337, 0.06230361466961248, 0.15721243832792553, 0.16143949436289923, 0.16431767706360134, 0.136162151449493, 0.11559624357947282, 0.18845764600804873, 0.2009003904781171], [0.064566311825599, 0.008569816709496081, 0.005538275340638522, 0.049066814593970776, 0.009176644147373736, 0.017811308448602046, 0.008906046078274292, 0.017046124508072222, 0.0172331932200385, 0.01019399460139019, 0.049657930553491623, 0.06825910974293947, 0.027936457190662622, 0.025920945252957087, 0.035071517540408034, 0.016311452590993473, 0.0880941404029727, 0.06155759934335947, 0.10912377946078777, 0.14205074975533144, 24.770428725651332, 76.06696047101701, 64.28413581848145, 63.48636450086321, 39.555146149226594, 31.177171570914133, 25.910449198314122, 45.02879456111363, 36.270208086286274, 55.309206758226665, 19.54617026873997, 0.07135002674268824, 0.07685409246810845, 1.0419080001967294, 0.6155434101819992, 0.34342025220394135, 1.6125886291265488, 0.4693896270224026, 1.5561151908976691, 2.838217530931745, 50.743767806461875, 67.53479494367326, 64.29864365713937, 63.60686016082764, 63.65783214569092, 63.689370019095286, 64.60229383196149, 61.5339206968035, 61.33725193568638, 61.56019878387451, 64.49958556038993, 54.20276171820504, 58.18389538356236, 60.890607833862305, 47.3792450768607, 42.40368870326451, 50.779637881687705, 55.36089440754482, 59.34357752118792, 56.768067904881065, 53.88033751079014, 57.631607396262034, 54.0843505178179, 50.79124484743391, 44.64962788990566, 39.43528624943325, 40.79567057745797, 42.178563594818115, 41.78348902293614, 50.225501673562185, 54.67173385620117, 58.1807895387922, 52.78141736984253, 49.92504072189331, 52.49530792236328, 51.33291251318795, 53.66515180042812, 51.37674522399902, 51.59103809084211, 49.83524567740304, 53.719545773097444, 48.84054504122053, 48.4023186819894, 49.746124608176096, 56.02955082484654, 50.699855191367014, 55.91046217509678, 31.581768648965017, 26.400100912366593, 57.50510849271502, 51.28904506138393, 56.35227033070156, 52.50888122831072, 51.60397563661848, 39.86604676927839, 39.3653039932251, 42.43959699358259, 54.724533217293875, 55.27709565843855, 59.094345637730186, 51.82518890925816, 55.65619632175991, 52.165132999420166, 56.47570855276925, 47.631412574223106, 48.3721878187997, 58.090105124882285, 46.873683725084575, 40.068628447396414, 40.37370647702898, 39.603109564099995, 45.352410384586875, 50.892077105385916, 52.92787844794137, 57.39051880155291, 52.87554461615426, 51.10705784388951, 57.859028884342735, 56.88728857040405, 56.05406754357474, 53.21556166240147, 44.935004302433555, 43.0411650793893, 49.03194011960711, 55.99145385197231, 59.33572605678013, 56.74605253764561, 59.66016524178641, 61.05828871045794, 60.64919267381941, 60.721856934683665, 58.50527736118862, 37.570139612470356, 0.9241579643317631, 0.9270567744970322, 1.7724920830556323, 1.8817319869995117, 0.241662363920893, 0.27717892240200726, 0.21679404191672802, 0.08093353999512536, 0.4842555693217686, 18.50061055592128, 39.12287439618792, 36.51040383747646, 21.75453359740121, 29.35113286972046, 22.60784707750593, 34.076786858694895, 40.20792245864868, 54.786490304129465, 55.316495418548584, 53.66936935697283, 3.1757145524024963, 0.26011805502431734, 0.07685977180621453, 0.0522321058171136, 0.05836537706532648, 0.12560365801411016, 0.07626868638076953, 0.10948645642825536, 0.018380387287054743, 0.06626406072505883, 0.012303243607415684, 0.006061225672185953, 0.02489576196031911, 0.004493521825809563, 0.06667918166411774, 0.009931417664379945, 0.040853487460740974, 0.14995192363858223, 0.00882572534361056, 0.023466892740023986, 0.07759236570979867, 0.007024303078651428, 0.03620573292885508, 0.04694504576868244, 0.050433889630117586, 0.0314087142635669, 0.008048301479513091, 0.02590897080621549, 0.023582314939371178, 0.02505499716582043, 0.016263186698779464, 0.008932025487800794, 0.027903366734140685, 0.03746688864859087, 0.05202835192903876, 0.02813458432709532, 0.039217308828873296, 0.028522372179265534, 0.01466132327914238, 0.13591348193585873, 0.052951851660119634, 0.12882349666740212, 0.13997493471418107, 31.847950662885392, 83.93455164773124, 70.7724609375, 71.44519942147392, 46.944412912641255, 40.67531040736607, 30.547807216644287, 35.08896221433367, 30.56209966114589, 51.29477385112217, 21.681231839316233, 0.036253963197980604, 0.02549092368488865, 1.5354325750044413, 1.6603658539908273, 0.6486741038305419, 3.367535425083978, 1.6877260144267763, 0.6286484726837703, 3.6960230214255194, 53.33144719260079, 69.85445799146379, 66.42179775238037, 67.40396036420549, 66.50376565115792, 65.06342492784772, 66.86681597573417, 64.13264424460274, 62.223828179495676, 64.43662098475865, 65.06990064893449, 58.66055570329939, 61.461423192705425, 63.79490620749337, 49.11590215138027, 44.10780388968331, 52.514286926814485, 58.196575845990864, 61.44907624380929, 57.739474705287385, 54.62325974873134, 60.49859741755894, 56.05239302771432, 55.25980854034424, 47.73098373413086, 41.81576687949044, 42.5078387260437, 44.33642046792166, 43.414780139923096, 52.536462102617534, 59.045242718287874, 59.68802056993757, 53.91636044638497, 50.234555176326204, 54.37206499917166, 51.28897557939802, 55.058425426483154, 50.41044882365635, 53.34086200169155, 49.8409605707441, 54.73853383745466, 50.264835425785606, 51.68649591718401, 51.23163209642683, 57.09513350895473, 51.29752533776419, 58.31920460292271, 34.71324184962681, 29.354342937469482, 57.75456966672625, 53.00365202767508, 59.556616238185335, 56.14642647334507, 53.852402278355186, 42.831864493233816, 41.27564866202218, 45.290894508361816, 55.90294769832066, 56.803416865212576, 59.19802665710449, 54.58684771401541, 57.27822896412441, 56.09122998373849, 56.97540215083531, 49.990180083683555, 53.40711654935564, 59.27524198804583, 51.013681003025596, 41.502347537449424, 42.719425269535606, 41.050916126796174, 46.17572328022548, 51.53865909576416, 56.1062867300851, 59.68451172964913, 53.12941789627075, 51.13506950650896, 59.65730953216553, 60.410654067993164, 59.18909822191511, 55.48539570399693, 47.14125190462385, 45.81633465630667, 51.56108093261719, 58.75569043840681, 61.98643602643694, 58.34227957044329, 61.2437778200422, 63.24382373264858, 63.39220946175711, 64.50894478389195, 63.28081594194685, 43.53601925713675, 2.1028888055256436, 0.5107836829764503, 0.7648973273379462, 1.9195933725152696, 1.3268568813800812, 0.9301008454390934, 1.0876097764287675, 0.042827311903238297, 0.23843801979507717, 22.922958305903844, 37.27528585706438, 27.7831381048475, 20.455018963132584, 28.837040867124283, 33.247505460466655, 41.6975154876709, 47.505358355385916, 62.29812526702881, 63.40725231170654, 65.11784321921212, 6.456914484500885, 0.3241319443498339, 0.14502911136618682, 0.055350669726197205, 0.03116957816694464, 0.07708094708089318, 0.033319808143590174, 0.05619394965469837, 0.03313336707651615, 0.062403379673404355, 0.0427224850282073, 0.029104032753301517, 0.0446079642112766, 0.036585305418287, 0.03393402143514582, 0.01707181384387825, 0.07979478860007864, 0.07663302575903279, 0.03798975416326097, 0.003923170734196901, 0.026010364294052124, 0.03079574947644557, 0.004490452303018953, 0.1733022542404277, 0.1162815232362066, 0.10044121143541165, 0.11199962800102574, 0.10823769415063517, 0.1346682073282344, 0.12569536880723067, 0.10498038679361343, 0.11986523307859898, 0.10906610398420266, 0.13965687820953981, 0.12272175694150583, 0.08280068516199078, 0.09630888567439147, 0.13945554329880647, 0.09589686564036778, 0.1997486044253622, 0.14473132948790277, 0.26108952718121664, 0.25182364295635906, 39.8136191368103, 95.76577745165143, 79.43915748596191, 81.39503370012555, 54.666790212903706, 46.318449701581685, 36.26333979197911, 62.858184814453125, 47.42751768657139, 76.98516491481236, 28.70371014731271, 0.2686215101608208, 0.1373601457370179, 2.5329612365790775, 2.429641523531505, 1.472724431327411, 5.441210312502725, 5.03055831364223, 6.35435950756073, 3.9015424847602844, 57.143868173871724, 71.04463577270508, 70.07301357814244, 68.09481280190604, 69.55345508030483, 67.71289116995675, 70.7364136832101, 66.98425442831856, 65.6281258719308, 66.32360580989292, 67.13002068655831, 59.122944423130576, 63.95519420078823, 66.21583230154855, 52.484576429639546, 47.167116573878694, 55.586478097098215, 59.83708027430943, 63.917347363063264, 59.713715008326936, 55.13650928224836, 63.16915839059012, 58.46473462241036, 57.55906472887312, 49.90178162711007, 42.741489274161204, 44.822860377175466, 47.52311795098441, 45.20012671606881, 56.3098064150129, 61.43611785343715, 62.189997400556294, 53.541835171835764, 49.937623909541536, 54.33978019441877, 53.41330392020089, 57.675523485456196, 52.491983209337505, 55.64549957002912, 52.0552715573992, 54.54462003707886, 50.078686237335205, 53.63643142155239, 52.724577631269185, 59.06712259565081, 53.53112799780709, 57.162673473358154, 39.60409620829991, 32.5097770009722, 58.51722131456648, 56.80530677522932, 60.579252106802805, 58.428423336574006, 55.65823561804635, 45.079822131565635, 43.94098458971296, 48.287277357918875, 59.23913219996861, 59.56702463967459, 62.5339332308088, 55.15397357940674, 60.09175259726388, 58.231014592306956, 58.16652141298567, 52.721582957676475, 54.54188939503261, 64.16493252345494, 52.50337478092739, 43.62759304046631, 45.04135343006679, 43.30759028026036, 48.737725598471506, 54.75360100609915, 59.237971850803916, 62.882649421691895, 54.62814085824149, 52.2063045501709, 60.68396840776716, 63.39806679316929, 61.533316203526084, 58.766036306108745, 49.678018365587505, 47.70418105806623, 54.14424746377127, 61.602992738996235, 65.53848716190883, 60.360925810677664, 62.536907059805735, 66.60272884368896, 66.32166726248605, 67.24566650390625, 65.79330539703369, 42.23042147500174, 1.5495100596121378, 2.567502034561975, 8.390920809337072, 3.5195483309882025, 2.6090570390224457, 1.6081023727144514, 0.8987748378089496, 0.1570470929145813, 0.9387463586671012, 30.617167609078543, 55.704003402165, 52.65063142776489, 30.234499045780726, 39.342044898441856, 34.09385163443429, 49.06960283006941, 54.59883335658482, 70.52527182442802, 70.74203477587018, 76.2624202455793, 6.934625285012381, 0.39285098548446384, 0.23101253967200006, 0.14018100579934462, 0.13424336298235826, 0.24352711385914258, 0.1744852393333401, 0.18329395380403313, 0.09524442029318639, 0.17960714735090733, 0.15503942993070396, 0.1232783727880035, 0.09467531940234558, 0.259881571999618, 0.22076401460383618, 0.10267380877797093, 0.14785818170223916, 0.21105370351246425, 0.13916898438973085, 0.10101316895868097, 0.09673358074256352, 0.08383773772844247, 0.16498066005962236], [0.05448423479018467, 0.05747390418712582, 0.03312637138047388, 0.042599395383149385, 0.028796164451965263, 0.03169710860986795, 0.021555020241066813, 0.015657767221065502, 0.051708100363612175, 0.02345145776468728, 0.03405274810003383, 0.02673508719141994, 0.026144017033012848, 0.01904343644024006, 0.06583204426403556, 0.13608094437846116, 0.013722032341840011, 0.04543474895347442, 0.050101085166846, 0.3329508639872074, 48.6973009790693, 73.00928061349052, 69.36344964163644, 61.76064041682652, 48.92479542323521, 28.268897090639385, 27.914646659578594, 54.73439271109444, 48.17517859595162, 39.71298142841884, 3.125951554094042, 0.10614410827734641, 0.03577465623883264, 0.33919596459184376, 0.4245586283504963, 0.14034882108015673, 1.7884289707456316, 0.7052139299256461, 0.1990807902600084, 36.0201667376927, 70.66727910723004, 59.79107625143868, 64.73634542737688, 57.771297454833984, 60.892768723624094, 60.8927617754255, 61.339294706072124, 60.34063012259347, 61.75353240966797, 59.448467527117046, 63.03970650264195, 57.191324370247976, 60.20427867344448, 56.33935015542166, 43.75210475921631, 45.46677425929478, 54.8441846711295, 57.35712923322405, 57.88820437022618, 54.98067855834961, 57.520971230098176, 54.750071321214946, 52.930595193590435, 44.23956952776228, 40.887671675000874, 39.2616160256522, 40.72091490881783, 41.3635642187936, 40.56659541811262, 48.376641614096506, 55.81553588594709, 55.970466818128315, 52.53631271634783, 49.931578976767405, 54.15511097226824, 53.53260101590838, 52.20979601996285, 53.050055571964805, 54.689889499119346, 48.647256578717915, 51.60407638549805, 47.21472910472325, 54.648214203970774, 55.73498889378139, 55.732331207820344, 50.92635256903512, 57.36390372685024, 34.38640901020595, 30.492357117789133, 55.654299463544575, 52.43674155644008, 56.89441742215838, 52.53252942221505, 53.56244352885655, 43.65668167386736, 40.356179646083284, 40.590222767421174, 45.61907182421003, 54.72694424220494, 55.242010729653494, 55.72216599328177, 47.040367535182405, 44.516587257385254, 47.55292919703892, 50.38225998197283, 55.90632799693516, 52.144267559051514, 46.2063752583095, 39.4983480998448, 41.30287865230015, 40.611001355307444, 47.10024363654, 50.70267963409424, 52.35337012154715, 55.70734201158796, 53.881171294621055, 51.11147689819336, 57.00518907819475, 58.1739490372794, 56.934317452566965, 53.87369850703648, 46.71186365400042, 45.27068567276001, 45.507758208683555, 51.448221342904226, 54.6811660357884, 55.9539474759783, 60.084470885140554, 61.18396772657122, 59.44145679473877, 62.86238847460066, 58.445126805986675, 60.396340778895784, 47.18262495313372, 2.672031602689198, 0.8720651481832776, 3.527949354478291, 0.6857575625181198, 0.5272945570094245, 0.25822266244462555, 0.21442758318568977, 0.09590048901736736, 5.53565457037517, 30.56819670540946, 36.880596910204204, 53.113291127341135, 52.02844108854021, 22.712384462356567, 23.944699593952723, 42.82770947047642, 47.77666119166783, 58.64226804460798, 54.96417658669608, 42.43762023108346, 1.4552956351212092, 0.03008437336289457, 0.01595832091490073, 0.04877640499866434, 0.04793430232842054, 0.05942938782806907, 0.00891918845341674, 0.0338558134888964, 0.04628799656139953, 0.024355685404900993, 0.02819096719446991, 0.02816749327549977, 0.11286382377147675, 0.0875842756192599, 0.051374169532209635, 0.053365252512906275, 0.04446746675031526, 0.04387277830392122, 0.010643863318754094, 0.05485124420374632, 0.020333362044766545, 0.021755909015025412, 0.04735290299036673, 0.03837806957640818, 0.052042071907115836, 0.023005823105839745, 0.019609563651361635, 0.024359198519960046, 0.010753959866373666, 0.031423835416457484, 0.013234310700292034, 0.00675313122337684, 0.09452678130141326, 0.04613317183351942, 0.027841888068776046, 0.026001969119533896, 0.03129314278651561, 0.07930487274591412, 0.05112052635688867, 0.060004168057015965, 0.03549390898219176, 0.5834795364311763, 59.8854466847011, 81.6138116291591, 74.43953950064522, 69.70564147404262, 57.42898750305176, 33.79426962988717, 24.388147524424962, 46.49959618704659, 52.03967979976109, 44.97613416399275, 4.582407755511148, 0.11052168373550687, 0.08796258603355714, 0.8846901878714561, 0.6860697971923011, 2.3185348340443204, 3.163366734981537, 0.35991693128432545, 0.7617432251572609, 39.58626365661621, 74.96597671508789, 62.4413206917899, 68.24047483716691, 60.592286927359446, 62.26260607583182, 62.073615074157715, 65.05312074933732, 62.160849707467214, 65.9128838947841, 61.08674158368792, 64.26854406084333, 58.60507433755057, 62.11099638257708, 57.704129219055176, 45.69775322505406, 47.33954654421125, 59.228737694876536, 59.85960633414132, 60.77849170139858, 55.96576983588082, 58.91872991834368, 56.23219156265259, 54.8524842943464, 46.12274326596941, 41.79343884331839, 41.79214995247977, 43.53747143064226, 42.71887983594622, 41.91760662623814, 49.576668466840474, 58.86372103009905, 57.75738368715559, 53.43225860595703, 51.72899457386562, 54.761792932237896, 55.08720486504691, 54.695694719042095, 56.149400302342, 55.24259785243443, 48.80194779804775, 50.71430049623762, 47.778929778507774, 57.38368872233799, 57.599141938345774, 57.91314492906843, 54.16400466646467, 57.6918100629534, 37.321338517325266, 33.68525586809431, 54.52773938860212, 54.07831948144095, 59.51155022212437, 54.152415071214946, 56.613449641636436, 45.96968139920916, 42.705747740609304, 42.62282793862479, 47.71003144127982, 56.11065714699881, 54.71010875701904, 56.57096140725272, 47.556705542973106, 45.215009757450645, 46.33092519215175, 51.56664991378784, 58.86220632280622, 55.46714278629848, 47.6992061478751, 42.44718442644392, 43.54588917323521, 44.17120967592512, 49.276700837271555, 53.174747943878174, 56.03797204153878, 57.97864212308611, 54.99103137425014, 52.388430731637136, 58.64600617544991, 58.35838549477713, 58.67297213418143, 56.11646236692156, 48.83106075014387, 46.86491857256208, 48.22606372833252, 54.239736557006836, 55.71103497913906, 58.82112857273647, 60.58289991106306, 62.41976043156215, 61.550526891435894, 64.896730695452, 61.363272939409526, 62.22956739153181, 52.31435251235962, 4.214544066361018, 0.9350963830947876, 0.46685293742588585, 1.6701078798089708, 1.6455495804548264, 0.6442940245781625, 0.18125087129218237, 0.12509871939463274, 5.760878256389073, 39.10475696836199, 32.88674109322684, 38.59028107779366, 39.37166506903512, 25.867950541632517, 33.460815157209126, 51.28940289361136, 53.80368845803397, 65.32106413160051, 59.10676901681082, 54.88562025342669, 2.1938887110778262, 0.02942286618053913, 0.0447290521780295, 0.008230134445641722, 0.011066655944367605, 0.0660358015447855, 0.005815601084447865, 0.03585127302046333, 0.02305550713624273, 0.04587017505296639, 0.036406884635133405, 0.028607640282383988, 0.02622808582548584, 0.05291410136435713, 0.037311656799699576, 0.05108101187007768, 0.035857963375747204, 0.02072679021927927, 0.04551920620724559, 0.035867876772369654, 0.040563037153333426, 0.024789213302678297, 0.17882095596620015, 0.13149773888289928, 0.11931119566517216, 0.1422794974808182, 0.11012718347566468, 0.08962537680885621, 0.10960940018828426, 0.10556335015488522, 0.11465362273156643, 0.1318733894399234, 0.15823304999087537, 0.09539769456854888, 0.14628802452768597, 0.08033899404108524, 0.21070925199559756, 0.16654206413243497, 0.16675937175750732, 0.18815303806747707, 0.10042032612753765, 1.1754320753472192, 69.521500314985, 90.35094206673759, 86.71100316728864, 77.34059306553432, 66.9657096862793, 37.36420890263149, 39.32239191872733, 67.61757578168596, 63.31134632655552, 60.03229686192104, 6.11137101479939, 0.3564302383788994, 0.4372979061944144, 1.5677627601793833, 1.3446137628384998, 4.418620475700923, 5.408744854586465, 5.718399141516004, 1.1936264761856623, 42.364969866616384, 77.24433272225517, 66.07997417449951, 70.63615812574113, 62.51788984026228, 65.11687047140938, 64.9951171875, 67.20295592716762, 65.3943120411464, 67.89168221609933, 64.73474734170097, 66.14114611489433, 61.45956802368164, 65.97693933759416, 61.12998717171805, 47.7725374358041, 48.995416913713726, 60.175902230399, 61.288975851876394, 64.07575934273856, 58.07496500015259, 60.066600118364605, 60.99956948416573, 57.29323359898159, 48.764066219329834, 43.27261304855347, 43.77660410744803, 45.7506811278207, 46.224541323525564, 43.666110379355295, 52.18675231933594, 60.36976391928536, 59.21697439466204, 52.307807309286936, 52.8347031048366, 57.3939859526498, 57.829679693494526, 57.18636335645403, 57.67048256737845, 56.92477410180228, 49.2952629498073, 51.52070842470442, 49.696274757385254, 57.33276537486485, 60.005546297345845, 59.03377819061279, 57.95653990336827, 59.81507532937186, 40.445474420275005, 35.4743892124721, 55.8106860433306, 57.52989271708897, 60.95881829942976, 56.8004777772086, 58.711909839085166, 48.628913334437776, 46.009459836142405, 44.56795528956822, 49.09604072570801, 59.78690733228411, 58.02033478873116, 59.100967270987375, 47.35819550922939, 45.997984886169434, 48.60415342875889, 52.76663160324097, 62.01480552128383, 57.387652669634136, 50.50398894718715, 44.453817231314524, 44.84847838538033, 46.668222018650596, 51.71674142565046, 56.23050662449428, 56.51191561562674, 60.501654624938965, 55.808900356292725, 51.03124604906355, 60.84964125497, 62.107966967991416, 62.3845191683088, 58.27788366590227, 51.08372579302107, 48.83209950583321, 49.81822953905378, 58.02642488479614, 59.28922871180943, 62.17159162248884, 64.80756446293422, 64.91860362461635, 64.25035367693219, 67.71714346749442, 62.2909060886928, 65.57349913460868, 54.12541437149048, 4.240484731537955, 3.842205737318311, 9.029385566711426, 3.280906153576715, 2.2690929727894917, 0.3720152106668268, 0.5881267956324986, 0.1949397860360997, 8.327072943959918, 48.89477225712368, 49.657729625701904, 65.53783403124127, 63.890242440359934, 32.392463615962434, 34.70025219236101, 55.834077153887065, 61.189658301217214, 73.80657250540597, 68.556305204119, 62.59848894391741, 2.0826554340975623, 0.1447784062474966, 0.12351267092994281, 0.11979037709534168, 0.17985729607088224, 0.13870684775922978, 0.13406212627887726, 0.12058587798050471, 0.2049530494425978, 0.15746099927595683, 0.15048576784985407, 0.09423333526189838, 0.1667792121214526, 0.2285102925130299, 0.13874363792794092, 0.13328850136271544, 0.1279967560299805, 0.09247765304254633, 0.11991141417196818, 0.22172558014946325, 0.10407269014311687, 0.11945416299360138], [0.09978541412523814, 0.05428891848506672, 0.02321892890280911, 0.02033334338505353, 0.07465921488723584, 0.08949712690498147, 0.03191927115299872, 0.021648200062502707, 0.004533232239607189, 0.03200104819344623, 0.049344372736024, 0.030324096392307962, 0.03589436677949769, 0.0961852769500443, 0.01800509974626558, 0.03307989173169647, 0.05840602131294353, 0.042567762080579996, 0.18015167170337268, 9.234243648392813, 74.45064272199357, 60.42626667022705, 71.74414566584996, 44.58241449083601, 28.07819162096296, 20.11115435191563, 47.75241545268467, 40.600231647491455, 39.39253398350307, 22.31619644165039, 0.10289207313741956, 0.02610882481427065, 0.06458620647234575, 0.1268932002463511, 0.1582982979182686, 0.9958613110440118, 1.5795192207608904, 1.1940136211259025, 13.30393384184156, 70.70007460457938, 60.17319243294852, 65.99138464246477, 54.99139615467617, 58.51959759848458, 55.19957460675921, 60.66400623321533, 58.6044351032802, 60.598512513296946, 58.48989404950823, 59.96748406546456, 57.99237176350185, 58.73843111310686, 56.36898422241211, 48.48258427211216, 41.13952302932739, 50.33344541277204, 59.81546442849295, 60.01282800946917, 56.652168478284565, 56.20633384159633, 54.84367050443377, 55.0929023878915, 49.08252647944859, 46.539114066532676, 43.08442456381661, 43.32216412680489, 39.89105333600725, 42.362388610839844, 41.54002414430891, 46.016439301627024, 53.57141712733677, 57.451579570770264, 54.239462103162495, 49.650381905691965, 55.04997294289725, 53.18804679598127, 53.963768005371094, 53.22917665754046, 54.2505271094186, 51.981467791966026, 49.26024750300816, 52.514391149793354, 57.71470437731062, 50.63006401062012, 54.71777956826346, 49.29149355207171, 60.520192418779644, 36.00064924785069, 33.70225463594709, 57.51143135343279, 47.74645389829363, 54.98150191988264, 52.466438157217844, 49.02241761343819, 41.22358233588082, 40.42283024106707, 39.218898500714985, 42.324024132319856, 44.769300188337056, 53.710054533822195, 52.928521156311035, 56.22263778959002, 49.041087423052105, 47.78883443559919, 52.88847173963274, 55.34958274023873, 50.10146590641567, 42.84034129551479, 40.56881536756243, 39.73444788796561, 41.733451570783345, 49.978896209171836, 51.23748247964041, 54.492849009377615, 54.82341650554112, 50.82654864447457, 51.32427242824009, 53.856904711042134, 54.248567717415945, 56.227678707667756, 55.22592217581612, 46.71734230858939, 42.32742180143084, 43.97729934964861, 47.211529459272114, 52.84736967086792, 52.35958181108747, 56.034685543605256, 56.67806094033377, 60.61403478894915, 59.867534228733604, 63.01315743582589, 59.44654287610735, 59.19059208461216, 44.77862467084612, 1.0343682276351112, 1.329061631645475, 0.2014778916324888, 0.7565443984099797, 1.5698598133666175, 0.11629706168813364, 0.03226957842707634, 0.2543023856622832, 14.098309227398463, 26.170660972595215, 37.60218470437186, 52.26898772375924, 41.6028983933585, 17.971889121191843, 33.53466408593314, 42.199804237910676, 49.75952073505947, 49.278927734919954, 65.35291467394147, 18.223815168653214, 0.5800473977412496, 0.16074225891913685, 0.10495929792523384, 0.0447162516149027, 0.08779143914580345, 0.0845209885654705, 0.053771773020603826, 0.047170855437538455, 0.022408926027960012, 0.05253982484074576, 0.06147810896592481, 0.02162921634901847, 0.02968425483309797, 0.1061233247497252, 0.048180257701980214, 0.031070043865059103, 0.008200088066847196, 0.06555043187524591, 0.03301053527476532, 0.06751380687845604, 0.03175734216347337, 0.07175843018506255, 0.05862886578376804, 0.02105099255485194, 0.04373129018183265, 0.05407742590510419, 0.04585571547171899, 0.08203683793544769, 0.047211377548852136, 0.020359507695372616, 0.01322045162253614, 0.016312624760238186, 0.030196871076311384, 0.021780453322987472, 0.10381360511694636, 0.014401262858882546, 0.03237039516014712, 0.07571683385010276, 0.054229991111372194, 0.15111532621085644, 14.34078746182578, 85.24332128252301, 66.77543326786586, 80.47228513445172, 53.42860385349819, 44.69219255447388, 30.404288700648717, 38.4021030153547, 46.01092938014439, 44.897358962467735, 23.57678379331316, 0.15493706613779068, 0.048682767166090865, 0.17816321126052312, 1.4503760933876038, 1.8567199919904982, 2.647113625492368, 1.1269629618951251, 0.8071706018277577, 15.230036156518118, 72.87860584259033, 62.27866336277553, 68.22313908168248, 58.01002713612148, 60.718820571899414, 58.05399881090437, 62.841703687395366, 61.87629318237305, 62.43633188520159, 59.24391256059919, 62.12633105686733, 61.12259428841727, 59.39405618395124, 58.46256678444998, 52.21904059818813, 43.822837420872276, 53.00552804129464, 59.56073651994978, 61.85127966744559, 58.06812102454049, 57.188767433166504, 57.9526697567531, 57.80036524363926, 51.638984135219026, 47.3875412259783, 45.40833643504551, 43.88550322396414, 42.02412945883614, 43.234571661267964, 41.86500876290457, 47.944870131356375, 55.13378211430141, 60.94343498774937, 55.23490619659424, 52.22956017085484, 56.066206046513145, 54.569630077907014, 54.767761434827534, 54.94024699074881, 55.321168082101, 52.611297675541465, 49.9380373273577, 53.187466621398926, 58.53797558375767, 52.91601439884731, 57.6953501701355, 51.47221347263881, 60.68708120073591, 38.33121749332973, 35.253610202244346, 60.2467599596296, 50.14992959158761, 56.60775906699044, 52.97876010622297, 52.02205569403512, 43.55273314884731, 41.145098958696636, 41.808825629098074, 44.67322049822126, 47.15171241760254, 55.81109946114676, 55.523384979793, 57.57185983657837, 49.282909052712576, 47.69826814106533, 53.85322911398751, 58.45509052276611, 51.48557833262852, 43.86246647153582, 41.653675828661235, 42.098214626312256, 43.92297485896519, 51.74308552060808, 53.87758255004883, 57.18458114351545, 56.236176354544504, 51.3205759865897, 51.60533748354231, 54.42283548627581, 55.72368764877319, 58.66579464503697, 58.01183714185442, 49.865001337868826, 44.18677364076887, 45.0069112096514, 48.482559953417095, 54.843489851270405, 53.78593233653477, 59.347913197108674, 59.0778923034668, 63.7345472063337, 62.04072230202811, 64.73153032575334, 61.484164646693635, 62.72249344417027, 50.285725184849326, 1.7545928720917021, 1.1197775474616458, 0.9455457138163703, 2.5290528748716627, 1.7036360864128386, 0.17181008788091795, 0.06260672304779291, 0.20508927213294165, 20.74839448928833, 31.833571365901403, 44.60029567990984, 53.206897258758545, 35.49517822265625, 26.82600290434701, 43.98416069575718, 49.57420880453927, 55.270936080387656, 55.69591222490583, 71.1865040915353, 24.813882759639196, 0.4018401631287166, 0.13734356234116213, 0.0443031289614737, 0.10006724364523377, 0.06867278540240866, 0.021484684997371266, 0.049482590319322686, 0.0025183021456801464, 0.05246430389317019, 0.030723074983273233, 0.05954350384750536, 0.064640102508877, 0.003554490004067442, 0.0645847747634564, 0.04123982494430883, 0.021175931207835674, 0.00920632157275187, 0.020114766899496317, 0.04401218671617763, 0.08646910331611123, 0.06411811908973114, 0.24583828555686132, 0.20877740851470403, 0.18935286439955235, 0.08052645291068725, 0.18441178596445493, 0.10823901050857135, 0.12417703813740186, 0.07266377910439457, 0.08015264118356363, 0.10790502200169222, 0.15086247692150728, 0.16664592070238932, 0.12265793393765177, 0.23538216948509216, 0.10956270340830088, 0.1290222124329635, 0.17329233405845507, 0.13813561626843043, 0.3848216634775911, 18.474367209843226, 95.77443490709577, 73.9711753300258, 90.30546610695976, 59.93893391745431, 42.647855349949424, 31.238680498940603, 63.08767686571394, 54.4361378124782, 56.08336114883423, 33.38093866620745, 0.4251402685684817, 0.13376829347440175, 0.7437590073261942, 1.7257606706448962, 3.0774112216063907, 4.490628566060748, 5.071493625640869, 3.6803209611347745, 15.8179076058524, 77.5111574445452, 65.0732774734497, 72.37371499197823, 60.466753823416575, 62.90335505349295, 60.38700934818813, 65.98615959712437, 64.8893656049456, 65.24685737064907, 61.03187165941511, 66.20104653494698, 63.37294905526297, 63.433683259146555, 60.39104625156948, 55.50587551934378, 45.48708036967686, 57.35812629972185, 63.22782897949219, 64.6007443836757, 58.462413924080984, 57.10412447793143, 59.90962641579764, 61.945552825927734, 54.437822750636506, 51.52476617268154, 48.64874349321638, 46.67094223839896, 42.24034002849034, 47.7018256187439, 45.69678742544991, 51.96246446881975, 58.14391892296927, 63.100107192993164, 56.515177794865195, 52.72243063790457, 59.90335219247, 57.20662430354527, 57.370174476078574, 58.452269554138184, 56.71603284563337, 52.88678332737514, 50.67366395677839, 55.94953536987305, 60.589764731270925, 56.18447828292847, 59.574049268450054, 52.908027444567, 63.89205592019217, 42.74257319314139, 38.318724632263184, 61.05487019675118, 52.39567075456892, 59.915094648088726, 57.24793134416853, 53.61877257483346, 46.34693731580462, 44.389674936022075, 44.257898875645225, 48.00953006744385, 49.15414503642491, 57.40077434267317, 57.02692651748657, 58.37254592350551, 50.35137871333531, 48.62552956172398, 56.025347164699006, 61.092133385794504, 54.46863106318882, 45.498850618089946, 44.11923715046474, 44.05418116705758, 46.85596581867763, 54.08000094549996, 57.38607195445469, 58.284178733825684, 57.63419212613787, 51.881514481135774, 52.66756418773106, 56.35456671033587, 60.86234256199428, 59.79110404423305, 59.92305728367397, 51.29021235874721, 47.62075751168387, 47.330465248652864, 52.23928764888218, 57.4124299458095, 57.00282669067383, 62.049602099827354, 62.83167743682861, 65.30998870304653, 66.67246791294643, 67.8950034550258, 66.1767417362758, 65.4000026157924, 51.505158356257844, 1.414450649704252, 4.8740332041467935, 5.558319594178881, 2.5770154212202345, 4.09372444663729, 0.23411303758621216, 0.28791654908231323, 0.4371546267398766, 25.65958969933646, 40.61397518430437, 48.95749364580427, 60.642161096845356, 52.68990959439959, 27.094444819859095, 45.905598163604736, 55.39360305241176, 63.68491622379848, 60.719661303928916, 80.42440509796143, 29.357691969190324, 0.8162381095545632, 0.2422356174460479, 0.2728273959032127, 0.1409025735088757, 0.19342744004513535, 0.12111742874341351, 0.10964227520993777, 0.17092522393379891, 0.16389372838394983, 0.1361164181892361, 0.21597103322190897, 0.10982907590057168, 0.11607064812311105, 0.20615610560136183, 0.18778615418289388, 0.19074789168579237, 0.11291022199605193, 0.11454865336418152, 0.10704730624066931, 0.16276555534984383, 0.20573620099042142], [0.01997074275277555, 0.06469453458807298, 0.0301291397107499, 0.033383641325469525, 0.006368202972225845, 0.022885242344013283, 0.01853717298113874, 0.059190624925707064, 0.029509660987449542, 0.06464907952717372, 0.0831149418705276, 0.0037899043361124185, 0.014512664738244243, 0.03786051020558391, 0.026652789375345622, 0.05354328992377434, 0.019657685354884182, 0.02337724469336016, 0.143534176583801, 40.17565502439226, 69.02259186335972, 62.19000434875488, 57.67547484806606, 39.282766342163086, 19.280050788606914, 18.276628426143102, 40.71016604559762, 20.391495057514735, 38.34887981414795, 7.446660620825631, 0.07928350567817688, 0.09296233060636691, 0.09104567273919072, 0.24763876465814455, 0.9655915924480983, 0.8749655325497899, 0.9714239537715912, 1.8534428306988306, 56.20525687081473, 67.77858638763428, 64.23923655918666, 57.256752082279746, 56.66040209361485, 52.77038363048008, 53.71017960139683, 54.46084908076695, 58.43969331468855, 56.896970885140554, 58.60594286237444, 55.69390766961234, 55.11546318871634, 52.10501023701259, 48.54296064376831, 45.059053965977256, 43.132714544023784, 49.81293501172747, 58.29326697758266, 53.84260879244123, 55.75623301097325, 54.896723474775044, 55.4490635735648, 54.50019325528826, 50.52627876826695, 49.273810386657715, 49.6038567679269, 48.18827942439488, 42.47284064974104, 39.836867809295654, 39.851882866450715, 41.664313520704, 51.75427906853812, 54.23873601640974, 54.88110392434256, 53.30942487716675, 54.072493416922434, 48.82398053577968, 49.99698237010411, 48.51502193723406, 57.09342425210135, 51.145755835941856, 48.69828067507063, 52.101699420383994, 55.64520079748971, 49.40462064743042, 53.210961954934255, 48.451372964041575, 57.17153590066092, 35.72790813446045, 34.175736154828755, 57.01916537966047, 45.645606994628906, 50.28433901923043, 43.65316241128104, 45.528682708740234, 43.76999984468733, 44.83702775410244, 41.689716134752544, 43.15570960726057, 45.469084535326274, 48.09247071402413, 48.933914933885845, 55.73763963154384, 49.57051931108747, 49.45485264914376, 52.74792010443551, 51.18027448654175, 46.29709093911307, 41.70295245306832, 39.91290889467512, 39.411144733428955, 40.827774729047505, 48.72684471947806, 52.90140233721052, 53.86182056154524, 54.167068822043284, 51.30845138004848, 49.41814879008702, 52.196274825504844, 53.17795106342861, 56.023537158966064, 54.18569346836635, 44.560604095458984, 43.355258396693635, 42.12855393545968, 41.29420035226004, 45.47253084182739, 51.3002142906189, 52.26034763881138, 55.866104875292095, 58.115163803100586, 58.11160632542202, 58.62591893332345, 61.02167865208217, 61.227949823652, 60.38792651040213, 32.86267253330776, 0.1596502653722252, 0.8484022979225431, 2.6248715732778822, 1.3862611566271101, 0.24389648118189403, 0.06675322340535265, 0.05546474842620747, 3.396765410900116, 22.18505961554391, 22.8062424659729, 28.653707436152867, 60.01556559971401, 27.28079203196934, 18.52946468761989, 35.746477195194785, 41.09097596577236, 54.20137207848685, 53.77606936863491, 43.042898654937744, 1.3928495688097817, 0.12896165996789932, 0.0894099622964859, 0.01028639156304832, 0.05743935318397624, 0.013657816635843898, 0.038386235745357614, 0.029520276667816297, 0.04867952376870172, 0.028237127931788564, 0.049752216387007914, 0.02450787402423365, 0.02763099259962993, 0.03415982431865164, 0.042458969168365, 0.06880401407501527, 0.03456606323431645, 0.024314225218924027, 0.023670597434309975, 0.028116884741133878, 0.02910125075972506, 0.028796815845583166, 0.06368425022810698, 0.026077942989234413, 0.02997321236346449, 0.017931770466800247, 0.00523294645660956, 0.03143569281590836, 0.03709494289276855, 0.05735717580786773, 0.017893221196053282, 0.07757391634264163, 0.027367156131991317, 0.03632838831150106, 0.07347448595932551, 0.07525176594832114, 0.011909687359418188, 0.0415371895235564, 0.052560621939067326, 0.36830783103193554, 49.69976275307791, 79.42551817212785, 68.00149154663086, 67.06939765385219, 43.54934590203421, 24.662486723491124, 19.158099481037684, 36.02956765038626, 29.028587068830216, 43.03699616023472, 9.446671792439052, 0.09453180246055126, 0.07811483767415796, 0.5152988721217427, 0.8848973853247506, 3.2520148924418857, 2.223194258553641, 0.9345219624894006, 2.2989472108227864, 61.690123149326865, 70.7758377620152, 65.48568780081612, 59.970944268362864, 59.83978312356131, 54.74132006508963, 57.157768045152935, 58.33205182211739, 60.76339326586042, 58.82403986794608, 60.39690358298165, 58.30309173039028, 56.576269830976216, 54.28972537176949, 49.82990946088518, 46.68719407490322, 45.990567684173584, 52.44360637664795, 60.813878876822336, 56.08883285522461, 59.131879806518555, 57.23120355606079, 58.55538082122803, 55.85007538114275, 53.07450975690569, 51.76978397369385, 51.57754816327776, 50.260701247623985, 46.06740781239101, 42.46749401092529, 41.60650103432791, 43.906069891793386, 53.08534894670759, 56.47675078255789, 55.19110475267683, 53.14049332482474, 56.53037003108433, 50.46429736273629, 51.91779102597918, 51.72265781675066, 59.46364934103829, 52.726703780038015, 50.36494507108416, 54.27704838344029, 57.30734191622053, 52.749334062848774, 55.57882465635027, 49.94044140407017, 59.17239475250244, 38.784142766680034, 35.66752134050642, 59.30312510899135, 48.49345472880772, 52.58033997671944, 46.19900321960449, 48.316984380994526, 45.74868699482509, 46.9139415877206, 44.35878324508667, 47.30087634495327, 46.03320530482701, 50.87488726207188, 51.159572328839985, 57.845010893685476, 51.05397708075387, 51.153037548065186, 53.73062814985003, 53.125870840890066, 48.669456073216026, 43.81663267953055, 41.48771115711757, 40.62352548326765, 43.157172203063965, 51.442228521619526, 55.75563199179513, 55.23826912471226, 55.28650351933071, 51.596176283700125, 49.529643058776855, 53.68964072636196, 56.207414286477224, 58.49837779998779, 56.93479687826974, 46.66939279011318, 45.43934971945626, 45.05768864495413, 44.9447352545602, 46.259306635175435, 53.96343101773943, 55.154091698782786, 58.64406762804304, 60.711934907095774, 60.08155264173235, 61.54574653080532, 64.62769644601005, 63.768801825387136, 63.676342146737234, 37.849773338862825, 0.19766650614993914, 0.47095666293587, 1.580296116215842, 2.449501646416528, 1.022739657333919, 0.13472320937684604, 0.008604249817186167, 2.975714781454631, 30.663856029510498, 20.386806760515483, 31.450947965894425, 58.83196776253836, 21.37398770877293, 26.736560480935232, 46.132564544677734, 47.32853364944458, 60.580273491995676, 59.34466144016811, 55.491162708827424, 3.626970955303737, 0.14561664126813412, 0.03553780001987304, 0.05136963013293488, 0.04554253763386181, 0.019619517760085206, 0.0912702406889626, 0.01090989145450294, 0.04587115892874343, 0.057785501038389545, 0.04692723761711802, 0.043110298325440714, 0.013682761279466962, 0.03976704433028187, 0.04053878291909184, 0.045057178142347505, 0.026894380072397844, 0.04503516307366746, 0.006533420736169708, 0.028490908510450805, 0.06082270520606211, 0.0866864448679345, 0.137278463691473, 0.09659910188721758, 0.16689505161983625, 0.1133715986673321, 0.12019352189132146, 0.1339172726230962, 0.16442635123218807, 0.12892484265778745, 0.16799368123923028, 0.13615721171455725, 0.0713308716991118, 0.11994789221457072, 0.27852676436305046, 0.17855150971029485, 0.10704327574265854, 0.09227410610765219, 0.10705143851893288, 0.6900156683155468, 61.2425479888916, 88.36863490513393, 78.5530537196568, 75.39470141274589, 51.4125770841326, 30.191489696502686, 28.571178470339092, 51.60425009046282, 34.17309931346348, 55.119336809430806, 12.099597368921552, 0.1723019579159362, 0.3392612396606377, 0.457089795597962, 1.6406050686325346, 4.329659215041569, 4.307455377919333, 6.335182913712092, 2.79312133363315, 65.00339249202183, 72.16205201830182, 69.65359946659633, 62.17826884133475, 63.55565888541085, 57.20459542955671, 59.00785446166992, 59.164918490818565, 63.488032068525044, 61.04191875457764, 62.12216213771275, 60.6667994090489, 58.25395406995501, 55.388440540858674, 51.9596643447876, 48.489841665540425, 49.60099411010742, 55.329255785260884, 63.01046848297119, 58.39010402134487, 59.82246126447405, 55.92734629767281, 60.00669275011335, 58.75006239754813, 55.58347647530692, 53.651443004608154, 53.661587374550955, 51.305237838200156, 48.23417575018746, 44.50075231279646, 43.46528312138149, 45.78193065098354, 55.1347896030971, 59.35661928994315, 57.38725662231445, 55.76557486397879, 58.7782929284232, 53.56752961022513, 55.56640475136893, 53.96545989172799, 63.63633441925049, 53.97348853519985, 51.181650229862754, 56.26931231362479, 60.16379846845354, 55.209795406886506, 57.79384435926165, 53.40306574957711, 60.02575165884835, 42.589751039232524, 38.31628928865705, 60.78661414555141, 51.885332516261506, 55.79958282198225, 49.64248527799334, 50.9209121295384, 48.999669211251394, 49.945256505693706, 47.72294119426182, 48.73082603727068, 50.76083605630057, 52.71758426938738, 53.6205096244812, 60.20337540762765, 52.74014507021223, 51.7129407610212, 57.11368172509329, 56.86509949820382, 51.37925699778965, 46.21778767449515, 43.687059198107036, 42.13739204406738, 44.88507802145821, 53.9145747593471, 57.62196677071707, 57.05131469454084, 56.280714307512554, 50.72466026033674, 51.09588514055525, 53.6931391443525, 58.25785548346383, 60.41754668099539, 58.250865595681326, 49.77049194063459, 48.60054383959089, 47.50519159861973, 46.371641635894775, 48.33835703986031, 55.97722394125802, 57.37275573185512, 61.74842548370361, 64.32818044934953, 62.55005999973842, 63.06686006273542, 67.93956920078823, 66.72202246529716, 66.41002750396729, 39.174683638981406, 0.2954657125685896, 5.374195805617741, 7.576989718845912, 4.686247714928218, 1.1198209737028395, 0.19721882231533527, 0.21824332486305917, 5.048043021133967, 34.567774363926475, 32.50958939961025, 37.429855482918875, 71.33347238813127, 36.515938077654155, 28.72670521054949, 50.0174343926566, 54.889427866254536, 70.14501081194196, 66.32928248814174, 64.72537422180176, 4.340412420885904, 0.3583795337804726, 0.2100662857826267, 0.16891040919082506, 0.11008126701095275, 0.07538137970758335, 0.14461124236030237, 0.11426406220666, 0.12382585555315018, 0.13508317220423902, 0.14121212118438312, 0.1852679614509855, 0.10709286986717156, 0.1352975485580308, 0.1367673368326255, 0.26819028758576935, 0.1062822647924934, 0.18167148157954216, 0.1810241320303508, 0.12028671189078263, 0.15148424570049557], [0.04383660899475217, 0.16176162207765238, 0.0264196803660265, 0.018778526190934435, 0.018813192545037185, 0.025214848141851168, 0.006204995368274727, 0.022853748141122714, 0.03825574328324624, 0.040403401612171104, 0.03306188001962645, 0.062142387963831425, 0.010687220858276954, 0.03428341947229845, 0.031678577818508656, 0.0980567443849785, 0.07762142736464739, 0.07284095138311386, 3.1625077639307295, 67.02299063546317, 62.99832303183419, 69.48036003112793, 46.85803985595703, 34.39712313243321, 24.19363096782139, 50.58306292125157, 54.94475984573364, 47.584877014160156, 28.475831815174647, 0.3347334840467998, 0.010037944269632655, 0.03898528717192156, 0.2960031394447599, 0.6843431698424476, 1.87454212137631, 0.7149341340575899, 1.6687559123550142, 26.06053897312709, 75.30326311928886, 58.764563288007466, 64.93966361454555, 56.297730445861816, 57.153335094451904, 51.97878926140921, 51.557064873831614, 51.52707992281233, 55.08756617137364, 55.00902720860073, 57.71381500789097, 52.78730944224766, 50.773186479296, 47.0805698122297, 46.28674159731184, 41.06840821674892, 41.24182135718209, 46.87840502602713, 55.95929064069475, 56.192288058144705, 54.839432103293284, 52.27006122044155, 54.90271282196045, 53.60638393674578, 53.796827111925396, 52.71866818836757, 55.180460112435476, 52.952315262385774, 48.3151604788644, 39.925648416791645, 39.98052181516375, 38.631060055324006, 50.177420139312744, 54.10601152692522, 54.798906735011506, 52.805037770952495, 54.64146055494036, 43.40707458768572, 46.67922796521868, 49.192370550973074, 54.3731141771589, 49.86259726115635, 52.02463000161307, 54.24779994147164, 53.3678731237139, 47.236261572156636, 49.78466626576015, 48.55739900044033, 59.051683698381694, 36.15894658224923, 31.26356199809483, 54.54565184456961, 50.9857805115836, 52.796592235565186, 47.576507908957346, 52.53758771078927, 50.7969388961792, 51.34502322333199, 47.70853410448347, 47.53101110458374, 46.48121820177351, 49.195921080453054, 50.100159645080566, 53.13770709718977, 48.397632122039795, 51.30108976364136, 52.14477825164795, 50.815285614558626, 45.799384525844026, 39.69999871935163, 39.9924761908395, 39.67443629673549, 38.66448089054653, 47.266864912850515, 53.40067556926182, 54.92256382533482, 51.369251591818674, 50.38486903054373, 50.64758389336722, 53.57291446413313, 54.39936099733625, 56.21999747412545, 52.54851027897426, 42.66676139831543, 41.88449845995222, 42.38175324031285, 43.695984159197124, 46.02421086175101, 46.607741424015586, 47.2712596484593, 49.01740448815482, 55.62654488427298, 54.15138326372419, 59.290194511413574, 56.73439693450928, 60.0303235735212, 58.55496392931257, 55.71794843673706, 13.222082325390407, 0.7285811017666544, 2.2718401168073927, 2.1497539707592557, 0.3453386606914656, 0.23944887412445887, 0.02179214108868369, 0.6421923030700002, 13.694790857178823, 42.002840178353445, 69.76497909000942, 78.70376014709473, 99.51002270834786, 34.54990359715053, 22.081477607999528, 30.318468025752477, 44.984802041734966, 49.00071491513933, 60.10775429861886, 21.544565984180995, 0.1798434539565018, 0.03185083071834274, 0.037733247570161305, 0.03252658374341471, 0.05825414481971945, 0.02029137938682522, 0.017268996120297482, 0.0454908332654408, 0.0680583312309214, 0.022985852123903375, 0.04947937745600939, 0.01620834580223475, 0.016580988752788732, 0.01686313039889293, 0.028915942846132175, 0.0077525314575593385, 0.02184140951638775, 0.06263073640210287, 0.054881337231823375, 0.03258442546107939, 0.032409516096647294, 0.050180714643959484, 0.04441920594711389, 0.046430841753525395, 0.035529087630233595, 0.02105428514602993, 0.03148670847128544, 0.050763888351087055, 0.12422985530325345, 0.1039370306368385, 0.05153104004317096, 0.02374855432260249, 0.05166158339540873, 0.06650888294513736, 0.014918214940865124, 0.05931147201252835, 0.03356099680864385, 0.05869197632585253, 5.00264436006546, 78.6011630467006, 71.0839695249285, 76.31760283878872, 58.20404168537685, 44.19760240827288, 30.377725737435476, 43.037763936179026, 53.653603894369944, 47.74903167997088, 27.826428856168473, 0.4299997735236372, 0.1264949409025056, 0.13980144688061305, 1.203354605606624, 2.126463609082358, 5.630044545446124, 0.8231814226933888, 0.7882468572684697, 29.332306725638254, 77.01653603145054, 61.33327061789376, 66.21719414847237, 59.41975062234061, 58.724069186619346, 54.46483039855957, 53.43989815030779, 54.241157463618684, 58.30586406162807, 58.24314962114607, 59.43106228964669, 55.88236713409424, 52.669780663081575, 50.45652232851301, 46.40996095112392, 42.72155141830444, 43.8265824999128, 49.966445037296836, 58.983633041381836, 58.5594733101981, 55.70895746776036, 52.41288491657802, 56.71111004693167, 56.50183725357056, 55.60617276600429, 56.36417606898716, 58.05494029181344, 55.21295683724539, 50.44120849881853, 41.11393281391689, 41.15036916732788, 40.99808202471052, 52.51515545163836, 55.52611214773995, 56.37381322043282, 55.12485020501273, 56.53517471040998, 45.1363457271031, 47.96062517166138, 51.51837730407715, 56.97303281511579, 52.326199190957205, 54.95146138327462, 56.877738271440776, 56.050513539995464, 49.63218457358224, 51.18363741465977, 50.7364513533456, 60.19056292942592, 38.85364212308611, 33.68614523751395, 58.57324463980538, 51.1477951322283, 55.1896664755685, 49.20431797845023, 54.536487170628135, 53.38305493763515, 54.059107712336946, 49.1025025503976, 48.07533993039812, 49.15846334184919, 52.08087566920689, 53.71391773223877, 56.62683882032122, 49.74933467592512, 52.174530438014436, 53.902696813855854, 52.89483976364136, 47.30306155341012, 41.27391161237444, 41.46175963538033, 41.701927593776155, 39.97814553124564, 50.074819564819336, 56.21672487258911, 57.932610307421, 53.0708897454398, 51.53399338041033, 51.2798421723502, 56.27740349088396, 56.60845388684954, 58.741641180855886, 53.29789434160505, 45.82045841217041, 43.583169732775005, 44.856750215802876, 46.67118195125035, 50.02824926376343, 47.93464238303048, 48.97993632725307, 51.808078970227925, 56.72678518295288, 57.04314708709717, 60.44007274082729, 61.12231636047363, 62.49883093152727, 59.54354667663574, 60.50412123543875, 15.798527342932564, 0.47953481120722635, 0.7497297355106899, 1.7039357274770737, 1.9723427934306008, 0.5614720944847379, 0.10621477091418845, 0.2891444260520594, 15.093347719737462, 40.8135552406311, 61.00314780644008, 77.80232865469796, 83.1394762311663, 31.67684085028512, 33.30994544710432, 37.33397729056222, 50.82666328975132, 55.55922031402588, 67.91388171059745, 27.767923286982946, 0.2507488163454192, 0.025154165058795894, 0.07204073467957121, 0.04683974731181349, 0.029474624831761633, 0.013951378874480724, 0.0682617560295122, 0.03183969256601163, 0.04954064577551825, 0.012889685308826821, 0.02163983372572277, 0.013758483243041804, 0.06080747888024364, 0.0020377112710515833, 0.016112752092470015, 0.011849162035754748, 0.024810731344457184, 0.045171460402863364, 0.02030195265875331, 0.1127795090100595, 0.14589439279266767, 0.2313096294445651, 0.09658537512379033, 0.11707707840417113, 0.17361530315663132, 0.08432548227054731, 0.14631604802395615, 0.08997835072555713, 0.22869113566620008, 0.16166213527321815, 0.18956391593175276, 0.14679117181471416, 0.10329675820789166, 0.19651322732014315, 0.13946892400937422, 0.19371094554662704, 0.1840110703238419, 0.20868953822978906, 6.711717954703739, 89.09369332449776, 78.51774297441754, 86.46780232020787, 61.67307226998465, 49.782661710466655, 32.777550152369905, 67.56164278302873, 70.35166413443429, 64.44384711129325, 40.12832389559065, 0.7705729199307305, 0.3578387956534113, 0.300132296447243, 1.3258234454052789, 3.5739444749695912, 9.744501113891602, 5.767115133149283, 3.796751490661076, 31.743196146828787, 80.0760224206107, 65.76031535012382, 70.16939898899624, 62.31653104509626, 62.67473152705601, 58.35630798339844, 54.18241391863142, 57.203421183994834, 60.47746794564383, 60.384250913347515, 63.08196544647217, 59.22421441759382, 56.333847182137625, 52.36395570210048, 49.74187578473772, 45.27041469301496, 45.77046264920916, 51.98853758403233, 60.350920404706685, 62.91329097747803, 58.34170981815883, 51.98485851287842, 56.30777754102434, 59.11648954663958, 58.395752906799316, 58.464748518807546, 62.59391008104597, 56.5298558643886, 53.76018578665597, 43.612171513693674, 43.22162021909441, 44.1840568951198, 53.68920646395002, 57.78295305797032, 57.98384632383074, 57.894746099199565, 60.1931129183088, 46.914973395211355, 50.83929511478969, 53.11109202248709, 60.34739071982247, 52.235021454947336, 57.56965725762503, 60.166946002415244, 57.90979242324829, 52.05503184454781, 54.946965898786274, 54.05040161950247, 62.67027773175921, 42.02767651421683, 35.79189756938389, 58.32849434443882, 54.86211797169277, 56.2271853855678, 51.95865338189261, 58.26157624380929, 56.85863419941494, 57.056091581072124, 53.14310237339565, 51.924006189618794, 52.44112586975098, 53.96093314034598, 56.49679980959211, 56.59245565959385, 51.55014099393572, 53.92895405633109, 57.29078088487898, 55.53657266071865, 49.50940990447998, 43.698471614292686, 44.57919747488839, 44.97972290856497, 40.51026289803641, 52.57222100666591, 59.126745087759836, 59.66803755078997, 55.4750463621957, 52.19206074305943, 51.78562239238194, 57.72798238481794, 58.832426343645366, 61.30868789127895, 58.21306392124721, 47.12301983152117, 47.215378761291504, 46.216307708195274, 49.19183553968157, 51.611948694501606, 50.744952474321636, 52.884598118918284, 54.295037269592285, 60.20815576825823, 59.36906351361956, 63.67734963553292, 63.21106992449079, 62.9493590763637, 63.390757288251606, 62.392474855695454, 16.904545068740845, 1.2330249335084642, 6.890876386846815, 5.706518590450287, 2.413577071258, 0.9744726930345807, 0.24167930015495845, 1.2255561628511973, 20.49850426401411, 60.76440075465611, 76.84653445652553, 80.7016521181379, 102.13603183201381, 44.891150747026714, 32.69827468054635, 42.55612175805228, 60.00239181518555, 62.25421960013253, 75.40154538835797, 32.16261373247419, 0.4128349817224911, 0.20528306173426764, 0.12902975774237088, 0.16370922114167893, 0.11320963235838072, 0.09637224048908268, 0.2638633783374514, 0.09268054858382259, 0.18364371146474565, 0.14092761145106383, 0.159135691555483, 0.14637289568781853, 0.2017839244965996, 0.12398149791572775, 0.15610524559659616, 0.10723061926130738, 0.10473074018955231, 0.10713000608874218, 0.09985288086214236, 0.15609930162983282], [0.028676070539014678, 0.013158956841964806, 0.03287450596690178, 0.03201674610110266, 0.08692486171743699, 0.06330773114625897, 0.026939202399392213, 0.0444512802974454, 0.054868784333978377, 0.03889187325590423, 0.0301999753740217, 0.045649912407887835, 0.023585183446162512, 0.0324723687954247, 0.05236234722126808, 0.0875465694282736, 0.054812157193997076, 0.01052186357056988, 15.137246438435145, 74.18925843920026, 63.17031179155622, 64.94402708326066, 51.63452339172363, 22.217829057148524, 17.299901042665752, 40.111516203199116, 39.986684867313926, 40.41344322477068, 6.785447027002062, 0.11480083768921238, 0.07074359285512141, 0.1869214020137276, 0.8235654735139438, 0.9700264973299844, 3.154085461582456, 1.7878533559186118, 3.4416227638721466, 67.00386919294084, 64.64130101885114, 62.39157853807722, 57.93044594355992, 56.78990956715175, 53.61010469709124, 52.07924631663731, 49.33767127990723, 49.11076395852225, 51.41063853672573, 52.80223764692034, 53.00382225854056, 50.15932355608259, 47.12254735401699, 43.349109240940635, 42.2631196975708, 41.80997903006417, 41.72346700940813, 44.70397669928414, 53.54814761025565, 57.053030899592805, 55.90289906093052, 49.220670563834055, 54.06597948074341, 55.021620818546836, 53.86127165385655, 53.80459519795009, 51.85325615746634, 54.93630736214774, 51.566507475716726, 38.6212283543178, 40.361832005637034, 39.376560074942454, 44.01188400813511, 54.15162297657558, 55.98724324362618, 53.21083688735962, 47.41040079934256, 38.04960353033883, 44.64057091304234, 49.567066056387766, 53.66679852349417, 50.95327336447579, 53.11918667384556, 52.419735840388704, 51.47860581534249, 43.95810147694179, 47.0936393737793, 48.28791659218924, 58.8171819959368, 40.10439082554409, 34.37025792258126, 56.314486026763916, 47.75545528956822, 55.288970129830496, 48.91186135155814, 52.02254901613508, 52.144406523023335, 54.76569087164742, 52.717056206294465, 51.585267611912315, 47.71916832242693, 52.1837090083531, 51.05962249210903, 52.70643588474819, 48.802680832999094, 50.162457193647114, 52.640573910304475, 51.43928943361555, 44.74295956747872, 41.85241515295846, 39.040962082999094, 39.08795969826834, 38.41872658048357, 43.887486934661865, 51.57351473399571, 53.68111528669085, 52.56383453096662, 48.90653903143746, 53.49787391935076, 55.29155485970633, 53.085258620125906, 51.97033330372402, 46.49649729047503, 40.58249637058803, 42.69572149004255, 43.25674336297171, 44.22194194793701, 45.812589577266145, 46.891613551548545, 45.19373437336513, 47.06999117987496, 46.636975969587056, 48.797004154750276, 48.817567348480225, 55.22608198438372, 57.277308327811106, 60.27444158281599, 60.74230548313686, 42.16810655593872, 1.380176054579871, 0.2554278038442135, 2.291795777423041, 0.47227041529757635, 0.5311300711972373, 0.1746234840580395, 0.013549943138579172, 4.779072608266558, 18.453593833105906, 45.34102576119559, 62.49269567217146, 52.31369243349348, 45.72536884035383, 14.875120435442243, 30.006764888763428, 38.6785683631897, 52.1422769001552, 49.83709389822823, 40.29331929343087, 0.5571025460958481, 0.030199656462562934, 0.11657052487134933, 0.015072140609845519, 0.04196454105632646, 0.03402140656752246, 0.08720960215266262, 0.015818786973665868, 0.019823122370455946, 0.025468571045036827, 0.05019257204341037, 0.0896519889522876, 0.02422474680601486, 0.012299005308055451, 0.050121322473777194, 0.053219801746308804, 0.03306915391502636, 0.037942816503345966, 0.00993071707697319, 0.01993968620497201, 0.04696835683924811, 0.031996250950864384, 0.048479919122265916, 0.03948586620390415, 0.059308357536792755, 0.03505844895594886, 0.045943748605038436, 0.055580587924591134, 0.04202963970601559, 0.02435751914578889, 0.02944760556731905, 0.02776447740117354, 0.04635412997699209, 0.011283416500581163, 0.041194827894547155, 0.05876666946070535, 0.0329415689754699, 0.054626706788050275, 20.37258379799979, 85.47872625078473, 67.75526823316301, 73.13600880759103, 54.24067803791591, 31.75860377720424, 19.166338307516916, 35.69921554837908, 46.683959688459126, 42.21544810703823, 8.589125122342791, 0.09868346646960292, 0.09081125924629824, 0.6200802038822855, 2.0948547337736403, 3.6404402554035187, 3.7071970275470187, 2.122290564434869, 5.054100547518049, 69.82572024209159, 66.22237055642265, 64.79879583631242, 60.68419769832066, 59.607143538338796, 55.98111840656826, 54.892460754939485, 51.15544509887695, 51.245393003736226, 52.69146599088396, 54.97888592311314, 54.71917268208095, 51.33117198944092, 48.50963013512747, 44.78795262745449, 43.849181515829905, 43.46949372972761, 43.38611882073538, 46.65896354402815, 54.78103249413626, 59.125070571899414, 58.79892907823835, 50.720487867082866, 54.71119267599923, 55.07578897476196, 54.75772476196289, 53.54572268894741, 54.14429610116141, 56.70718431472778, 52.74579048156738, 41.50370938437325, 41.30923972811018, 41.02813645771572, 46.358700616019114, 55.92379576819283, 57.25256926672799, 56.88308491025652, 49.88052708762032, 40.66576010840279, 47.10950558526175, 52.32991647720337, 56.465623242514475, 51.12596736635481, 54.35845347813198, 55.54660585948399, 55.044046129499165, 46.55182926995413, 49.32507766996111, 51.81470060348511, 61.04501070295061, 42.98416205814907, 35.964605467660085, 56.54734100614275, 50.32682030541556, 56.71104403904506, 51.383554458618164, 55.91115699495588, 53.45962756020682, 57.1037596975054, 54.76374537604195, 53.6394921030317, 50.122119426727295, 52.46803971699306, 54.365141119275776, 53.67083542687552, 47.99402863638741, 51.304678508213584, 54.29190015792847, 54.008052349090576, 46.20418657575335, 43.707295826503206, 42.37557629176548, 40.8708188193185, 42.05443402699062, 46.273137024470735, 53.839961528778076, 55.83430297034127, 52.651843888419016, 49.37461832591465, 55.63843672616141, 56.306106499263215, 54.53328405107771, 55.335352829524446, 49.87336696897234, 42.1475259917123, 45.65098490033831, 44.55087661743164, 47.58077410289219, 49.3795029095241, 50.08992494855608, 48.12381403786795, 48.06898580278669, 47.86152648925781, 50.106840338025776, 51.44344098227364, 56.55693299429757, 58.732747486659456, 64.44338158198765, 62.03441333770752, 46.78972864151001, 1.9432923751217979, 0.216441027287926, 1.2248585202864237, 1.601064064673015, 1.2049898207187653, 0.20905921767864907, 0.05520537502265402, 2.7046807536057065, 24.873661586216517, 49.58062546593802, 67.76661464146206, 55.66914081573486, 48.598316941942485, 16.888833454677037, 39.678553104400635, 44.354044573647634, 58.94016511099679, 54.804572990962434, 49.07767316273281, 1.0362276307174136, 0.03192196154434766, 0.010650911601260304, 0.031618432474455664, 0.030183005213205303, 0.036569074860640934, 0.05330290871539286, 0.029262318009776727, 0.045431050937622786, 0.043131909665784667, 0.04994832657809768, 0.04048082245779889, 0.061760773083993366, 0.03254984053117888, 0.03857534006237984, 0.00913335446135274, 0.031684131627636294, 0.05725639300154788, 0.01411961145432932, 0.02386105033968176, 0.1335962169936725, 0.12485720164009503, 0.1328508598463876, 0.09395996707358531, 0.2350045783179147, 0.08887052017131022, 0.14484195783734322, 0.16890172394258635, 0.20116264426282474, 0.18662018674824918, 0.11148342570023877, 0.1130196764799101, 0.09581043384969234, 0.15738876243787153, 0.08680640985923153, 0.3074718468955585, 0.1239451284387282, 0.10030321776866913, 26.29528907367161, 96.57335267748151, 77.71349593571254, 82.87780012403215, 66.12745816367013, 34.10996798106602, 24.721310172762188, 52.21636206763131, 50.56833968843733, 56.1225038255964, 11.535647698811122, 0.23103148436972074, 0.2188348581216165, 1.1888549093689238, 3.7595834050859724, 4.743194282054901, 11.33377386842455, 8.199894854000636, 4.899422790322985, 75.1262160709926, 66.61841787610734, 70.31497069767543, 62.0272011075701, 62.806080273219514, 58.22357654571533, 58.05363055637905, 53.83383321762085, 54.51159872327532, 54.71247809273856, 57.45913921083723, 56.943586349487305, 54.37066493715559, 51.03442832401821, 47.429834910801475, 45.64136164528983, 45.03459978103638, 46.189932346343994, 48.92933259691511, 57.80973836353847, 62.20923696245466, 60.74299335479736, 51.607442787715364, 55.182791233062744, 57.78124032701765, 54.946125166756765, 56.29880741664341, 55.52846411296299, 59.636819294520784, 54.87168911525181, 44.057703903743196, 43.01282685143607, 44.65725006375994, 49.405662877219065, 58.774269921439036, 60.75553485325405, 58.8729829788208, 52.53531217575073, 42.555364404405864, 50.06536306653704, 55.93904359000069, 58.195964404514854, 53.47554588317871, 57.325549670628135, 58.80225726536342, 57.74136461530413, 49.19739062445504, 51.49329778126308, 54.421914849962505, 62.95429924556187, 45.9001646723066, 40.99098096575056, 56.42940575735909, 52.05758530752999, 59.799997738429475, 53.17614800589425, 55.703965187072754, 56.61124011448452, 59.62843976702009, 56.996802602495464, 56.258778844560894, 53.49933304105486, 55.66641364778791, 56.1950569152832, 56.45492649078369, 49.537953104291645, 52.204320839473176, 56.99625369480678, 55.106729303087505, 49.7061516216823, 46.26725884846279, 43.14424507958548, 43.2212450163705, 42.869384765625, 47.95504229409354, 57.41809967585972, 59.445653506687705, 55.53758362361363, 50.601805686950684, 57.80641712461199, 59.37573378426688, 57.13229942321777, 58.25307164873396, 52.87832042149135, 45.3973513330732, 47.95502839769636, 47.598683084760395, 50.86404807226998, 51.70862592969622, 52.65290696280343, 49.33024018151419, 51.61199038369315, 51.209950242723735, 53.568724700382774, 53.85625505447388, 60.11704404013497, 62.190108571733745, 66.2716680254255, 65.34212412152971, 48.05105945042202, 2.129926634686334, 1.5946495745863234, 8.65585388456072, 3.4566669166088104, 1.3797259415899004, 0.3481085220617907, 0.22467115494821752, 6.234714567661285, 29.586676801953995, 54.52462312153408, 68.30416897365025, 57.57831471306937, 56.028390475681846, 22.872484854289464, 43.86825432096209, 51.045924118586946, 66.42174911499023, 63.758073806762695, 58.125103201184956, 1.7001498277698244, 0.2525323320712362, 0.26052365611706463, 0.11857980276857104, 0.14430643085922512, 0.1365621614136866, 0.15889046899974346, 0.08852790748434407, 0.08426505194178649, 0.21495424849646433, 0.18307045793959073, 0.14368128297584398, 0.11551234950976712, 0.09930575093520538, 0.10871323863310473, 0.12457755021750927, 0.1651851162314415, 0.13399534486234188, 0.08553657228393213, 0.0911464826869113], [0.061339104282004495, 0.07264555365379367, 0.03470102045685053, 0.03684062457510403, 0.08082164957055024, 0.03883764812988894, 0.006346917328690844, 0.011168148667950715, 0.08028386985617024, 0.04381356594551887, 0.052673333391015015, 0.06203854496457747, 0.06145932711660862, 0.018273263570985625, 0.1333092102514846, 0.035702358332595656, 0.032736922813845534, 0.18370711377688817, 44.49915770121983, 64.04111562456403, 60.11518887111119, 56.25174726758684, 51.24477808816092, 30.46339007786342, 39.13161175591605, 38.572490215301514, 30.141723224094935, 30.985595839364187, 0.43422172697527067, 0.04331500894789185, 0.027013264496677687, 0.20300178628947052, 0.9090370014309883, 2.880707936627524, 3.0729973784514835, 0.3801113005195345, 28.229139498301915, 75.2602537700108, 58.81493772779192, 66.27079255240304, 57.16950355257307, 57.756970269339426, 47.404341970171245, 48.32756648744856, 44.30671344484602, 46.61360570362636, 44.18900401251656, 46.69157838821411, 44.85909523282732, 48.454169613974436, 42.04247965131487, 41.357515811920166, 39.764141014644075, 40.61618818555559, 41.013538292476106, 45.73638868331909, 50.96259437288557, 55.933405126844136, 53.66194520677839, 53.244455746241975, 54.14236797605242, 55.24135759898594, 54.10715103149414, 52.171803270067485, 52.35795940671648, 55.65949671609061, 50.89446381160191, 42.310440404074534, 40.3616999898638, 39.48988519396101, 40.8688941683088, 47.222789015088765, 49.34135382516043, 46.98521620886666, 39.663100310734336, 41.37158243996756, 48.20911012377058, 53.57391847882952, 53.64482831954956, 52.42629146575928, 53.204385484967915, 51.05238594327654, 49.809210777282715, 41.924659047807964, 45.916041306086946, 49.840776443481445, 55.91755281175886, 41.627571446555, 29.243362835475377, 53.665221282414024, 51.0154458454677, 54.46255138942173, 50.189082690647666, 53.599717140197754, 48.937903199877056, 47.91830716814314, 50.08028779711042, 54.45187895638602, 52.84008795874459, 54.438378606523784, 50.29044301169259, 50.3692182132176, 45.40297589983259, 48.26974010467529, 52.00020708356585, 51.576617104666575, 48.47650807244437, 41.21472338267735, 39.550560338156565, 40.37256349836077, 37.92371259416853, 41.96335703986031, 48.48676013946533, 54.56652423313686, 50.680431502205984, 50.408631869724815, 54.06687232426235, 51.79437364850725, 51.06146029063633, 48.385788917541504, 41.92839370455061, 42.31082602909633, 40.16441978727068, 44.34962551934378, 45.3934394972665, 48.91342469624111, 47.92844806398664, 50.36602899006435, 47.78384910311018, 50.11081123352051, 49.6151510647365, 54.789832387651714, 54.85962356839861, 56.81266144343785, 60.88311072758266, 57.48952368327549, 58.65691484723772, 18.190413440976823, 0.28004741562264307, 0.6307138789977346, 2.304009190627507, 0.41607894908104626, 0.1627097933420113, 0.0895636844049607, 0.07881048534597669, 14.409294962882996, 28.067018917628697, 41.158602782658164, 60.584894044058665, 70.87689236232212, 48.196551254817415, 18.509584154401505, 38.444660731724326, 42.72779437473842, 47.418954031808035, 51.96396180561611, 8.962063602038793, 0.2867114980305944, 0.07696575897612742, 0.10150115777339254, 0.03539272923288601, 0.05166154607598271, 0.015711441037378142, 0.03254437493160367, 0.08266953112823622, 0.026171801345688955, 0.01668258580113096, 0.029375470509486537, 0.04614928025486214, 0.023715463866080557, 0.009109277494384773, 0.01260979809532208, 0.06685005035251379, 0.15614469562258038, 0.045552763156592846, 0.04955707310831972, 0.011390653871265905, 0.05219855226044144, 0.01661433365994266, 0.021337816092584814, 0.03704007315848555, 0.03496969996818474, 0.02438617028695132, 0.03661887254565954, 0.024288442584552934, 0.024813245316701274, 0.049250707762049775, 0.03646310465410352, 0.03818652931866901, 0.047416298517159054, 0.04611023395721402, 0.038246155583432744, 0.06397665132369314, 0.2644814694566386, 54.87291199820382, 71.78079046521867, 66.8587213243757, 65.4505924497332, 58.42111383165632, 34.38017995016915, 24.348579270499094, 33.739507402692524, 32.27236747741699, 34.473991053445, 0.5524351479751723, 0.08443635489259448, 0.1520388259419373, 0.9833201382841382, 2.8057429535048346, 4.247213193348475, 1.8378085153443473, 0.2551460218216692, 31.04211596080235, 77.84130804879325, 63.438338552202495, 69.74252946036202, 59.152238028390066, 60.92336859021868, 50.52282203946795, 51.255936895098, 46.787050110953196, 49.20282064165388, 46.88700342178345, 48.88464873177664, 45.43390233176095, 50.42275060926165, 45.66841098240444, 44.26226929255894, 41.57601581301008, 43.734359060014995, 42.583723476954866, 46.441887923649375, 53.4612569127764, 58.386414527893066, 55.06175013950893, 54.346968105861116, 55.532059805733816, 55.917632716042654, 55.6435992377145, 52.98656988143921, 54.60910626820156, 58.57771233149937, 53.43388448442732, 43.99958569662911, 41.27626357759748, 41.699474879673545, 42.091130937848774, 48.33577925818307, 52.1292907169887, 49.31068447657994, 42.11198248182024, 44.27173621313912, 50.304488795144216, 56.46104437964303, 54.07077373777117, 52.97726624352591, 55.765303884233745, 53.40206173488072, 51.489167077200754, 43.607616969517295, 47.82964815412249, 51.22729294640677, 57.13384539740426, 43.9946038382394, 31.289006301334926, 54.52340371268136, 51.68824686322893, 56.11813688278198, 51.13322475978306, 54.920409883771626, 49.75172138214111, 48.82656179155622, 52.788865838732036, 55.36591100692749, 54.574716159275596, 55.39803600311279, 50.569555623190745, 52.9947235924857, 45.783493995666504, 48.87659576960972, 54.91984013148716, 54.709493841443745, 49.916605608803884, 43.171405587877544, 41.069387912750244, 42.21715388979231, 39.59423671449934, 43.839679854256765, 50.68680647441319, 57.61471632548741, 51.63801138741629, 50.724886076790945, 56.16911928994315, 55.20081833430699, 52.43636287961687, 50.66162967681885, 43.227720737457275, 44.752902439662385, 43.080286911555696, 45.4725204195295, 49.10384355272566, 49.9422653062003, 49.50087751661028, 52.05118254252842, 50.76095764977591, 52.23610884802682, 52.86820037024361, 58.08091613224575, 57.60742766516549, 59.25241020747593, 63.36734185900007, 59.61789240155901, 62.228413990565706, 20.715117829186575, 0.26595551893115044, 0.5114274770021439, 1.6097911106688636, 1.7276157311030795, 0.9208730948822839, 0.17526056058704853, 0.24083951807447843, 14.005426577159337, 34.38284805842808, 44.672629901341026, 67.24882098606655, 68.26100676400321, 51.69751923424857, 29.637989248548234, 43.64584248406546, 49.88851056780134, 52.9885709626334, 62.546398299080984, 14.24561277457646, 0.4209476006882531, 0.09740357300532715, 0.09922374997820173, 0.035783752000757625, 0.04691885092428752, 0.015580834920651146, 0.049144615419209, 0.03211093693971634, 0.029847927657621245, 0.0094097802980936, 0.04496414420594062, 0.049942067092550654, 0.06019252937819276, 0.03318235730486257, 0.042009076702275445, 0.0754369313695601, 0.08901840687862464, 0.04054800081732018, 0.01858911822949137, 0.11152567807585001, 0.1656917104763644, 0.09608739148825407, 0.08058026073766605, 0.11956191435456276, 0.15201290590422495, 0.06741811308477606, 0.0821789570951036, 0.14876606155719074, 0.15865731079663548, 0.19267182344836847, 0.16863776024963173, 0.11365099224661078, 0.10825008420007569, 0.2318997106381825, 0.11707068660429545, 0.23926151703510964, 0.7052405827811786, 64.90627752031598, 80.33393955230713, 75.88924639565604, 73.03148705618722, 66.38377026149205, 40.21317529678345, 51.72910574504307, 54.021385942186626, 43.362908363342285, 45.72704335621425, 0.9133009697709764, 0.13068120341215814, 0.33210812349404606, 1.5036488005093165, 4.006957513945443, 10.021921839032855, 9.670037269592285, 2.5751313737460544, 31.55275297164917, 78.61988149370465, 64.77239268166679, 71.41179943084717, 62.71375955854143, 62.42051778520857, 53.5839238848005, 55.399168559483115, 48.50220251083374, 52.04127441133772, 48.972599029541016, 51.81276205607823, 48.443080289023264, 54.525477749960764, 47.22536332266671, 46.007146086011616, 43.00110176631382, 45.630220208849224, 44.31560366494315, 49.977954728262766, 55.34266233444214, 60.73412050519671, 59.01695660182408, 57.481112888881135, 57.16077314104353, 57.27168376105172, 57.57021311351231, 53.038069929395405, 54.668947628566194, 61.84808349609375, 56.355421338762554, 46.79936579295567, 44.24006979806082, 42.93416282108852, 43.73648868288313, 51.18445382799421, 53.24207946232387, 51.96215179988316, 42.62247705459595, 47.52638013022286, 53.39070837838309, 60.08961950029646, 55.698399680001394, 54.34950419834682, 58.60345540727888, 56.160475730895996, 55.55870962142944, 46.586518151419504, 51.042262417929514, 55.694241183144705, 61.32014547075544, 47.280962807791575, 34.52844408580235, 55.56633874348232, 53.827833448137554, 60.24005494798933, 54.22354030609131, 57.24871301651001, 52.28962387357439, 49.23147848674229, 54.85070555550711, 58.25604895183018, 58.083090918404714, 59.00793089185442, 53.20961747850691, 52.91291897637503, 47.35510008675711, 49.9591772215707, 56.843719891139436, 56.904895305633545, 54.147561754499165, 46.32521029881069, 43.67345462526594, 45.55440493992397, 40.42007180622646, 46.90204974583217, 53.70672982079642, 60.82145241328648, 52.77040100097656, 51.90345341818673, 60.257689476013184, 57.393586431230815, 56.60841914585659, 53.81416981560843, 46.11618069240025, 47.5182820047651, 45.077859265463694, 50.02806166240147, 50.728273323604036, 53.59319625582014, 52.43792969839913, 54.269989013671875, 53.510543959481375, 54.286633423396516, 54.653738021850586, 58.702425548008506, 59.60185595921108, 60.7289718900408, 65.48557662963867, 60.91249465942383, 64.2219147000994, 24.34054888997759, 0.6430574080773762, 3.8445081966263905, 7.816621797425406, 2.9806438769612993, 0.4821629673242569, 0.24722466830696377, 0.48191885756594793, 21.33591158049447, 41.294374057224815, 49.216605867658345, 66.79329708644322, 75.44083050319126, 59.01574761526925, 27.89365267753601, 49.38327578135899, 57.469537190028596, 61.39328220912388, 71.32364068712506, 17.158262014389038, 0.7449079028197697, 0.14808847648756845, 0.15165267166282448, 0.13161241130105086, 0.17952114982264383, 0.12469250762036868, 0.1030488893655794, 0.18357887065836362, 0.08264745159872941, 0.14513945473091944, 0.16174460441938468, 0.16802030695336206, 0.14747517582561287, 0.2348564134112426, 0.18627405246453627, 0.26456772482820917, 0.18804144619831017, 0.12194345013371535, 0.11521593827222075], [0.06733772704111678, 0.01611368847079575, 0.048018779938242266, 0.05573310563340783, 0.0393847848421761, 0.0032385471360092716, 0.032052582928112576, 0.039125821952308924, 0.0058100765371429065, 0.018081482433314835, 0.03575354701440249, 0.048015818132885864, 0.05019133371700134, 0.03547701346022742, 0.048689216641443114, 0.04334810449342642, 0.13910900189408235, 6.651015886238643, 57.95023441314697, 60.526556968688965, 62.421295983450754, 58.71587726048061, 32.80624968664986, 21.839873109545024, 40.59008032935006, 32.057921750204905, 39.927652972085134, 13.214491418429784, 0.061147682767893584, 0.08888111210295133, 0.41975185913699015, 0.27071793909583775, 1.8420034902436393, 3.1091078179223195, 3.0266915432044437, 2.2327026511941637, 68.72995458330426, 62.69162259783064, 66.34032317570278, 59.62106772831508, 57.50582068307059, 50.353487491607666, 49.5568904195513, 45.02762031555176, 45.31961488723755, 44.87841122491019, 43.34446784428188, 40.95177228110177, 43.95203569957188, 40.79178653444563, 40.835011277879985, 39.60700402941023, 41.766764708927695, 41.34968866620745, 43.26022788456508, 42.15176439285278, 54.733642305646626, 55.61790132522583, 56.20133113861084, 54.81006554194859, 53.498909200940815, 52.1176837512425, 55.18310737609863, 52.9289311000279, 51.702810287475586, 52.981806891305105, 53.13313518251692, 41.151616368974956, 39.59980569566999, 38.58362122944423, 40.76146112169538, 37.950188704899375, 40.35605110440935, 38.80802025113787, 40.432047026497976, 41.05811446053641, 52.52762746810913, 51.26396206447056, 54.76359598977225, 52.59095682416643, 52.519313948495046, 50.04209007535662, 45.60652685165405, 40.24308034351894, 47.415823868342805, 47.804478304726736, 56.3527740750994, 41.20209503173828, 36.23307343891689, 53.88470097950527, 47.380606923784526, 52.69867822102138, 51.014650276729036, 53.997230529785156, 51.55234357288906, 49.49391542162214, 47.54467821121216, 47.2467394556318, 48.96713774544852, 50.704496588025776, 50.72585187639509, 51.11615303584507, 51.32768399374825, 45.57153919764927, 50.55185508728027, 52.16984735216413, 47.509429999760215, 42.42146219526018, 37.85827445983887, 40.22515746525356, 40.078387192317415, 40.40653671537127, 44.39438581466675, 52.779715061187744, 51.949054445539204, 49.51128939219883, 53.198903356279644, 53.41695867265974, 48.357627868652344, 43.48183373042515, 41.65145240511213, 42.42821931838989, 42.172185148511616, 44.427038873944966, 46.57309423174177, 51.02873427527291, 49.683677673339844, 51.14866713115147, 50.852416787828716, 50.67340339933123, 54.872602803366526, 55.64302601133074, 58.099759646824424, 57.78505488804409, 56.12948676518032, 57.80368995666504, 48.02548313140869, 51.4499305997576, 3.7800028579575673, 0.8505382718784469, 0.5226887698684419, 1.8833268157073428, 1.0407126929078783, 0.010900820289472384, 0.05071593288864408, 2.6670141347817014, 30.350436687469482, 29.08952624457223, 56.68470689228603, 70.36186408996582, 33.1575471333095, 16.78981293950762, 26.393345526286534, 43.9501006262643, 47.0063977922712, 55.62126425334385, 26.977192231587, 0.20489574037492275, 0.028626768184559684, 0.027869792821417962, 0.031331720895000865, 0.09092719373958451, 0.036710752972534726, 0.06500403476612908, 0.022211821783067923, 0.01038377745343106, 0.023267381392153244, 0.07028638917420592, 0.06004260028047221, 0.05709767687533583, 0.016280638619459102, 0.07424438571823494, 0.043519583863339255, 0.03381457891581314, 0.0808080178020256, 0.08183196785726718, 0.016496036168453947, 0.004286240403806525, 0.034716297672795396, 0.022920823024053658, 0.14377777065549577, 0.022922561770038943, 0.05493670568934508, 0.057369592998708994, 0.01149272674228996, 0.026927663911400095, 0.01875642969805215, 0.06133958604186773, 0.07282136207712547, 0.06684603342520339, 0.058421953315181394, 0.026300478726625443, 0.21022218598851136, 9.182557736124311, 70.73163332257951, 67.61110700879777, 70.46391923086983, 65.07132502964565, 41.94260624476841, 24.247390917369298, 40.41225855691092, 34.85457863126482, 46.83012546811785, 19.824091264179774, 0.01172053808945098, 0.17107629297035082, 0.28783390351704186, 1.2772426179477145, 2.7722721781049455, 4.142052207674299, 2.045165342944009, 3.210634244339807, 68.90053285871232, 65.03666741507394, 69.42933246067592, 63.55474172319685, 59.80293682643345, 53.398869037628174, 51.108565602983745, 47.083939688546316, 46.60525049482073, 47.3939995765686, 45.66634389332363, 42.42593683515276, 46.12852764129639, 43.15482023784092, 43.631953035082134, 42.16093601499285, 44.391561371939524, 42.16567121233259, 44.21702609743391, 41.9115686416626, 55.15087120873587, 56.80396924700056, 57.076818057468955, 55.84448902947562, 55.489029611860005, 53.10811471939087, 56.90501342500959, 55.62753847667149, 52.612944398607524, 55.737900188991, 54.02161175864083, 42.32515321459089, 40.89520352227347, 41.31502410343715, 41.67593438284737, 40.71352549961635, 42.11643280301775, 40.420898641858784, 42.4050783429827, 43.70314080374581, 54.2971008845738, 53.58214514596121, 56.04172059467861, 53.631498200552805, 53.66429369790213, 51.08073806762695, 47.43838119506836, 40.23097310747419, 50.445988859449116, 50.59389516285488, 57.05109582628523, 42.190861906324116, 39.01402391706194, 55.73554474966866, 49.86168704714094, 54.541316168648855, 53.02684511457171, 54.38056264604841, 52.865056310381206, 50.710958412715364, 48.537381240299766, 48.955704484667095, 51.148132119859966, 52.541558606284006, 53.64165646689278, 52.7252550806318, 54.035546370915, 45.23489202771868, 51.763426371983115, 55.354262351989746, 49.64989900588989, 44.059555598667686, 39.38246604374477, 41.41631841659546, 41.869135992867605, 41.463666915893555, 45.80325467245919, 54.76282821382795, 54.8499482018607, 51.91574478149414, 56.51188434873308, 55.83156190599714, 50.478443895067485, 45.64974464688982, 43.403965268816265, 43.0967298235212, 42.71793140683855, 46.01795400891985, 48.85175595964704, 53.24664442879813, 52.0844783101763, 53.21075003487723, 52.08811221803938, 53.5986783845084, 58.136387075696675, 59.603092738560264, 60.00235707419259, 61.648489543369834, 59.73768629346575, 59.860238620213096, 53.51457391466413, 57.237491675785606, 4.913599721023014, 0.5607426421982902, 0.03329372186479824, 2.0621530371052876, 2.2296754079205647, 0.163000029910888, 0.07232711716954197, 1.5926236318690437, 38.22437504359654, 28.717700345175608, 63.29776954650879, 79.48145811898368, 37.55752168382917, 19.955671037946427, 32.939432757241384, 48.00937373297555, 53.64801754270281, 61.492474692208425, 35.94961125510079, 0.20696740278175899, 0.051338885711239915, 0.0061379531398415565, 0.037507746634738784, 0.11007242569965975, 0.057035312721771855, 0.03901541412674955, 0.03172558333192553, 0.06425633667302982, 0.08833515604159661, 0.03352876978793314, 0.0838823514059186, 0.04754780199644821, 0.028130219650587866, 0.010691215733199247, 0.03638338018208742, 0.06914426546011652, 0.06149412239236491, 0.04052324785983988, 0.1385309850530965, 0.12506804961178983, 0.16112411128623144, 0.13714480586349964, 0.18891804558890207, 0.12528450228273869, 0.13321950792201928, 0.2451901217656476, 0.12622963371021406, 0.16428455098399095, 0.0788328227187906, 0.2789256343884127, 0.12884913172040666, 0.07931823988578149, 0.1816940632249628, 0.15335485818130629, 0.3893462706889425, 11.988742334502083, 81.42377144949776, 77.17858191898891, 78.53405039651054, 73.86500685555595, 47.28745589937483, 29.73618813923427, 54.01489979880196, 44.263002327510286, 58.715196337018696, 22.769946813583374, 0.42074767713035854, 0.21279666998556682, 0.7746039064867156, 1.3518837498767036, 6.789850013596671, 11.084019133022853, 10.007172550473895, 3.08892069544111, 74.74503789629254, 67.38558237893241, 72.67752497536796, 66.47585473741803, 62.70135702405657, 55.191229820251465, 54.24482611247471, 49.65499898365566, 49.234570435115266, 49.1666830607823, 47.77209275109427, 45.073666027614046, 50.60923678534371, 45.22287859235491, 46.97357797622681, 44.34486252920968, 46.636006695883616, 45.42108290536063, 46.98906203678676, 44.9447317804609, 58.75517627171108, 59.73877716064453, 60.74671064104353, 60.23550387791225, 57.41633135931832, 55.40550184249878, 61.00976249149868, 56.37145778111049, 54.70611006872994, 57.48582376752581, 58.131780420030864, 44.44680997303554, 43.186396326337544, 43.60460145132882, 45.22986848013741, 42.0093332699367, 44.18284790856497, 42.33845206669399, 45.36037996837071, 45.52933931350708, 58.318343026297434, 55.65978854043143, 57.324573448726106, 57.00801004682268, 56.70220940453665, 54.64268691199166, 51.25036791392735, 43.465706961495535, 52.74995592662266, 52.47239623750959, 59.368340900966096, 45.20994799477713, 41.02985266276768, 57.606010232652935, 51.712457861219136, 57.675075326647075, 55.63600138255528, 58.108347620282856, 56.31889465876988, 52.05708156313215, 50.20625168936593, 49.59606783730643, 52.877257347106934, 53.78121450969151, 55.625648566654746, 54.9444054876055, 56.73780155181885, 46.03964975902012, 53.440495695386616, 56.900358131953645, 54.007631983075825, 47.24545751299177, 41.42811645780291, 43.54880394254412, 45.14167499542236, 44.01699440819876, 48.71626261302403, 58.569701058524, 57.36331312997, 53.304731369018555, 57.405401842934744, 57.68241262435913, 52.340425627572195, 48.56695624760219, 44.887721811022075, 45.27723782403128, 45.28219188962664, 48.70993627820696, 51.2621659551348, 55.355377537863596, 54.20437717437744, 55.85837153026036, 55.05760901314871, 55.30458620616368, 59.57822513580322, 62.46887724740164, 61.17871488843645, 64.45523520878383, 60.98799378531319, 61.654124532427105, 55.23211302076067, 58.14367226191929, 5.327105692454746, 1.435371458530426, 6.0356230565479825, 4.952044538089207, 2.8971649621214186, 0.20934726936476572, 0.2932964361139706, 3.7735154117856706, 42.089689186641145, 41.716907909938264, 63.88148076193673, 74.77078792027065, 40.530197279793875, 22.466737849371775, 39.14737721851894, 57.27995559147426, 62.24345684051514, 69.46858283451625, 43.81570162091936, 0.44824908141578945, 0.11793166611875806, 0.1223484134035451, 0.11555131099053792, 0.16916480554001673, 0.10114325769245625, 0.14920385235122272, 0.12795214913785458, 0.09683297933744532, 0.18343306705355644, 0.1200530787131616, 0.19531156894351753, 0.17871758794145925, 0.06751899088599853, 0.132297120988369, 0.2041285615414381, 0.1926094117973532, 0.16476855001279286, 0.23890819028019905], [0.052721621335617135, 0.03172479623130389, 0.06292256752827338, 0.04976640794692295, 0.044912141282111406, 0.07340655103325844, 0.04098914696701935, 0.06318826827087573, 0.08116329873778991, 0.0378938025262739, 0.0549024600269539, 0.019264282625434653, 0.009019626055045851, 0.062423226822699816, 0.07625422679952212, 0.09994396740304572, 0.09726754709013871, 27.091908727373394, 71.04932580675397, 57.916090965270996, 66.59774003710065, 40.857717990875244, 39.28690052032471, 32.29880884715489, 37.61205114637102, 34.46504177365984, 25.411978483200073, 4.111938714981079, 0.22529923410287925, 0.12230851554444858, 0.18240550719201565, 0.513780907860824, 3.33062116588865, 1.4252211174794605, 2.3054893740585873, 24.30488726070949, 72.23302091870988, 60.034409114292686, 65.90772138323102, 55.53230994088309, 55.50600406101772, 46.977871962956016, 47.598825522831504, 45.438463824135916, 48.971980639866416, 45.675119468144004, 46.35685586929321, 41.62762008394514, 40.95766435350691, 42.22411251068115, 40.76524094172886, 39.851379122052876, 42.03295714514596, 38.644445759909495, 40.3006010055542, 42.4277537890843, 53.145575932094026, 53.277247769492014, 53.84608636583601, 50.8964718409947, 51.00419323784964, 49.34046445574079, 54.12098489488874, 53.99093893596104, 53.86091729572841, 51.60820014136178, 50.31483466284615, 39.86814512525286, 39.23434434618269, 38.40989889417376, 40.46289702824184, 39.02740267344883, 39.87552758625576, 38.65716096333095, 40.228325843811035, 43.31133883340018, 53.31958314350673, 51.14508186067854, 53.301437922886436, 53.25279358455113, 52.57096338272095, 46.88617311205183, 41.7354804447719, 38.9977581841605, 44.534895760672434, 46.21127026421683, 56.127881731305806, 44.08809185028076, 39.90397351128714, 54.93084955215454, 48.43768848691668, 49.681148529052734, 48.330582005637034, 49.85117442267281, 50.48665319170271, 51.993713991982595, 52.59084217888968, 48.03466864994594, 45.617873259953086, 49.85937329701015, 52.53099039622715, 50.3427004132952, 53.25303677150181, 49.341673442295615, 45.3402475629534, 50.54508754185268, 50.45964901787894, 40.675511905125205, 37.77529559816633, 38.416388511657715, 39.27300064904349, 38.68723276683262, 41.927462645939414, 48.99287039893014, 53.96161753790719, 51.64303840909685, 53.21417202268328, 49.8778589793614, 48.85506330217634, 40.43392998831612, 41.55328478131975, 40.69207293646676, 40.639138085501536, 44.568452085767476, 50.3322503226144, 49.70229884556362, 53.70275545120239, 50.93074383054461, 51.57627664293562, 52.718414579119, 58.17006499426705, 55.82238333565848, 57.88159315926688, 57.543823855263845, 58.30807358877999, 54.26307555607387, 55.43586547034127, 48.55810076849801, 43.83101545061384, 0.7057113232357162, 0.27754419137324604, 0.4198029935359955, 1.6654074234621865, 0.47672393918037415, 0.03961932386404701, 0.10406811681709119, 17.829680340630667, 38.44382694789341, 17.50679234095982, 18.702471358435496, 27.742067302976334, 24.724412543433054, 25.533537217548915, 46.61069788251604, 49.39306926727295, 53.366302830832346, 46.214945861271445, 4.238671251705714, 0.2356140384716647, 0.016562756516837647, 0.02622440646934722, 0.012413743883371353, 0.028964247754109756, 0.037841792817094495, 0.012767900147342255, 0.07470707196210112, 0.020682349568232894, 0.05651849295411791, 0.051034888452185054, 0.0277687402974282, 0.0632240202810083, 0.01759286258103592, 0.0407155650401754, 0.06341477004545075, 0.08211942921791758, 0.025538068297984343, 0.052742011312927516, 0.035212330520153046, 0.051203836886478324, 0.03074271178671292, 0.02466643917640405, 0.027716109728706733, 0.0863499864935875, 0.054917910269328525, 0.03998890492532935, 0.04966319598523634, 0.04699290284354772, 0.05831329271729503, 0.049898905480014424, 0.06423410108046872, 0.04452756798959204, 0.09779689939958708, 0.01645110357951905, 34.60266126905169, 79.82003688812256, 64.38664259229387, 72.25863197871617, 52.775177887507844, 42.91191816329956, 35.5182740347726, 43.278640610831125, 36.024624007088796, 32.638898849487305, 5.8380736112594604, 0.22181427824710095, 0.1348022994186197, 1.0213680395058222, 2.4022682266575948, 4.496872825281961, 2.570913165807724, 1.1307259542601449, 25.89894645554679, 76.58793640136719, 60.616758482796804, 68.03233460017613, 57.285323074885774, 57.001596859523225, 48.17082207543509, 51.144359248025076, 47.47073548180716, 51.953622886112754, 47.638829776218955, 48.27558353969029, 42.978037221091135, 44.251673289707725, 44.00954246520996, 43.95697586877005, 42.764275891440256, 42.95543473107474, 41.0183881350926, 43.516352381025044, 43.24663373402187, 55.465284143175396, 55.564070156642366, 56.60069622312273, 53.52814722061157, 54.51279033933367, 52.61090510232108, 55.445568629673545, 54.088939802987234, 56.48621770313808, 53.85089451926095, 52.817214488983154, 42.008113861083984, 42.201030594961985, 40.63785266876221, 41.46527542386736, 41.00106280190604, 42.860418115343364, 40.622226170131135, 42.06206314904349, 46.07720129830496, 56.316157068525044, 52.27829483577183, 54.94762945175171, 54.133137294224326, 53.36522586005074, 48.99462134497506, 44.90627350125994, 39.82826941353934, 46.79671158109392, 49.368083545139854, 57.53314447402954, 45.91501644679478, 42.387541089739116, 56.82596376964024, 51.578736305236816, 52.11647823878697, 51.16471746989659, 52.500123023986816, 53.31374665669033, 53.584288665226524, 53.44129473822457, 49.2150216783796, 48.25360986164638, 53.1769574710301, 54.315558774130686, 52.239409242357524, 55.50920718056815, 49.07927124840872, 45.57911968231201, 53.88356147493635, 53.810598441532676, 43.346142360142295, 39.06138283865792, 39.19995771135603, 41.37581736700875, 41.65313386917114, 42.89276545388358, 52.38267762320382, 55.5375280380249, 51.43426241193499, 55.15291745322091, 52.709743227277485, 49.92376225335257, 42.88355909075056, 43.28784349986485, 42.062445299965994, 41.864890643528526, 46.23280620574951, 53.5327365057809, 52.57801580429077, 54.74107340403965, 52.25014073508126, 55.48930753980364, 53.85767248698643, 60.640153067452566, 57.78309202194214, 60.00666495731899, 59.638056073869976, 59.403276443481445, 53.96861089978899, 57.991902760096956, 52.8035751751491, 49.234626020704, 0.9642451618398938, 0.43657713915620533, 0.951886379293033, 3.6736802203314642, 1.3027211193527495, 0.13541307593030588, 0.16608161026878016, 17.759437526975358, 46.651053019932334, 19.800879069737025, 18.37377119064331, 24.473848342895508, 27.75529841014317, 31.02561398914882, 52.176264013562886, 54.31335966927664, 58.66198008401053, 53.803285462515696, 6.53987033026559, 0.35031281092337196, 0.02084510976315609, 0.0705962557611721, 0.10295907168516091, 0.04948531463742256, 0.030548063838588338, 0.026944812187658887, 0.04070149900923882, 0.05953392293304205, 0.09684110818696873, 0.058313136654240746, 0.07219960008348737, 0.023052623362413475, 0.033935931511223316, 0.02591964925107147, 0.046892578048365455, 0.022693500222106065, 0.021728703153452704, 0.2349493998501982, 0.17405184544622898, 0.1399972585162946, 0.13503723538347653, 0.11658823463533606, 0.09725358283945493, 0.1291226763278246, 0.1692173784332616, 0.1393986956349441, 0.10954436260674681, 0.19466792419552803, 0.15450226089784078, 0.16673852716173443, 0.16615135009799684, 0.1198044770530292, 0.1588082712675844, 0.10293049179017544, 39.278062411717, 90.10908222198486, 72.96276937212262, 80.17928654806954, 55.491850580487935, 49.67278637204851, 43.44087757383074, 49.268519333430696, 49.10931178501674, 40.85005065373012, 7.073503707136426, 0.43024882301688194, 0.4471860070313726, 1.016447194984981, 5.238971267427717, 10.719514897891454, 10.03061750956944, 5.414388528891972, 28.040303094046457, 77.15096977778843, 62.577852794102256, 70.37336335863385, 61.53833975110735, 59.44706399100167, 51.69682094029018, 54.23137092590332, 50.53043031692505, 57.216389996664866, 51.20841121673584, 51.72560385295323, 45.8767283984593, 46.635106904166086, 46.45958498546055, 45.65589727674212, 44.736848626817974, 47.0883344241551, 42.92974029268537, 45.97658790860857, 46.62293018613543, 57.02568973813738, 57.54615497589111, 58.29205104282924, 55.43658808299473, 56.30042634691511, 53.245425019945415, 59.03555692945208, 56.67294706617083, 58.2516542162214, 57.61838844844273, 55.504277433667866, 43.4858706338065, 44.314255714416504, 42.27385466439383, 43.57981375285557, 42.43541070393154, 44.27956335885184, 42.8248850277492, 45.02188457761492, 47.315999099186485, 59.959375517708914, 53.705458300454275, 56.56487478528704, 57.04886198043823, 56.77833039419991, 52.67981733594622, 45.77540281840733, 43.51513992037092, 48.18577459880284, 50.617560727255686, 59.64792251586914, 48.64742680958339, 44.339279651641846, 58.3160640171596, 53.679433822631836, 52.89723341805594, 54.53234951836722, 54.19558770315987, 55.41675097601754, 55.91912657873971, 55.44234119142805, 50.42913600376674, 48.03104863848005, 55.89587095805577, 57.115286758967805, 54.88844469615391, 58.83302388872419, 52.169975893838064, 45.617445945739746, 56.91698169708252, 56.17973961148943, 45.0299688066755, 40.873813492911204, 41.82036311285836, 44.29876470565796, 43.92395108086722, 45.44275781086513, 53.76421921593802, 59.4408939906529, 53.75989048821585, 57.59283644812447, 54.42122350420271, 52.251790932246614, 45.884416580200195, 44.83156647000994, 45.339660440172466, 45.51908029828753, 49.53958593096052, 55.33703429358346, 54.86056504930769, 57.045776980263845, 56.33716147286551, 58.40142958504813, 57.85216753823416, 63.30578081948416, 59.93983718327114, 63.06405993870327, 62.25869424002511, 60.943052836826865, 57.6432386807033, 60.44825771876744, 54.424718448093955, 49.646299839019775, 1.0350122387920107, 2.288084787981851, 8.256969094276428, 4.259396425315312, 1.4487517348357608, 0.3158905394375324, 0.4226369357534817, 23.490931851523264, 52.995508738926475, 26.159906898226055, 24.08581403323582, 40.09929779597691, 34.03759901864188, 36.60677882603237, 58.00398915154593, 62.24711159297398, 64.9167970929827, 62.7526764188494, 7.663424440792628, 0.526071945471423, 0.19885274821094104, 0.2359283630337034, 0.17099337599107198, 0.11135611896003995, 0.1734874400177172, 0.12544346946690763, 0.15942985005676746, 0.1633673616285835, 0.18707887642085552, 0.17580684913056238, 0.12366622340466295, 0.09901543972747666, 0.13071802072227, 0.12614827736147813, 0.16464782506227493, 0.12208373046347074, 0.1111795302214367], [0.027283608115145137, 0.09425611368247441, 0.04190268919670156, 0.01855039084330201, 0.01943905119385038, 0.025650118178288852, 0.050188646718327484, 0.02925127824502332, 0.04641032285456147, 0.017283674529088393, 0.010654437438850957, 0.07982739220772471, 0.011193811710524772, 0.027635900104152303, 0.04934627602675131, 0.044150529828454764, 0.9143612214497158, 51.31918287277222, 64.1380568913051, 61.10844775608608, 46.48435183933803, 31.02310916355678, 21.682873351233347, 28.69900447981698, 47.17940446308681, 42.25345822743007, 33.3933481488909, 2.1522524995463233, 0.13105477765202522, 0.153392652581845, 0.29565149545669556, 0.7811233795114926, 0.5299907837595258, 2.2819295525550842, 0.9664437238659177, 54.19837045669556, 69.54319953918457, 61.16663197108677, 59.941344942365376, 53.82467201777867, 47.679612227848594, 47.889124734061106, 46.60817916052682, 45.77693142209734, 45.56368773324149, 45.72223172869001, 43.16922732761928, 44.63468926293509, 42.048878942217144, 40.338816097804475, 41.30308015005929, 40.11900288718087, 40.25928701673235, 40.066992146628245, 37.982893875667024, 39.54598494938442, 48.029954297201975, 51.180323123931885, 53.37853166035244, 48.61092792238508, 46.65453059332711, 46.47724730627877, 52.1787862096514, 52.52462584631783, 54.292945861816406, 53.5411889893668, 51.1769254548209, 41.84133972440447, 40.817578247615266, 38.9567950793675, 37.79756457465035, 38.732753889901296, 39.44386032649449, 39.30683490208217, 41.04292917251587, 46.074140616825645, 51.024367332458496, 54.07995925630842, 52.54006126948765, 50.040276595524375, 49.730859415871755, 41.643111092703684, 39.33406489236014, 37.6194475037711, 45.38358347756522, 46.74898093087332, 54.35030671528408, 41.99871642248971, 39.89381871904646, 53.838134152548655, 52.15376227242606, 49.31027453286307, 42.483551297869, 46.59155559539795, 45.168293544224326, 47.28021935054234, 49.98591388974871, 49.32347958428519, 49.153088910239084, 53.597101143428254, 48.81828301293509, 49.708357674734934, 47.70378501074654, 51.33492054258074, 43.471477440425325, 47.34924970354353, 51.89607095718384, 44.373690605163574, 40.12616300582886, 39.811955043247764, 37.14101539339338, 39.38524532318115, 38.474937507084434, 45.74228422982352, 53.78064823150635, 51.467763151441304, 53.05980736868722, 50.78259434018816, 49.4097831589835, 39.75154740469796, 41.157414640699116, 40.38281209128243, 40.849546909332275, 45.8479037966047, 52.283940247126985, 49.29548181806292, 53.635073048727854, 54.79325784955706, 54.790638378688264, 55.5467517716544, 56.08871126174927, 55.308143683842246, 58.83098111833845, 56.039316517966135, 54.484882899693076, 56.516081060682026, 59.824233055114746, 57.64168923241751, 55.02447305406843, 31.579135281699045, 0.13163225166499615, 1.3449103640658515, 2.0517815479210446, 0.5432263421160834, 0.10902733927858727, 0.14289159035044058, 3.0029727816581726, 39.38879585266113, 35.05172681808472, 42.67074966430664, 34.45158658708845, 22.791574818747385, 21.898715666362218, 35.846110888889854, 44.003337723868235, 47.88434437343052, 53.66423463821411, 18.024144785744802, 0.13463347990597996, 0.014012160345113702, 0.049833918788603375, 0.02324583281629852, 0.061727674145783694, 0.0395038168478225, 0.011039246522289301, 0.07706035354307719, 0.03689048332827432, 0.04877183845798884, 0.004428000788071326, 0.038621707752879174, 0.0625422690063715, 0.09314069710671902, 0.03587234831814255, 0.046823455686015744, 0.037822559741990905, 0.033646577037870884, 0.032581721499030075, 0.04906014120206237, 0.07866189296224288, 0.04393872172970857, 0.054346224160066674, 0.04349396577371018, 0.01734412182122469, 0.018887437846777693, 0.05068010284698435, 0.008346157996649188, 0.010151476748952908, 0.02273973899095186, 0.07186379310275827, 0.012195915482672197, 0.05061803385615349, 0.03828048945537635, 1.683079189487866, 61.596739360264365, 71.68894222804478, 67.69413798195976, 57.11986562183925, 34.40801790782383, 31.750387532370432, 34.441713196890696, 44.85612140383039, 44.74781288419451, 34.45240300042288, 1.691669117127146, 0.1565379338072879, 0.2638734477971281, 1.414244375058583, 1.9242580022130693, 3.4152172207832336, 1.397041721003396, 1.5418662812028612, 58.41742433820452, 71.2485931941441, 64.11482211521694, 62.88754790169852, 56.06500400815691, 51.35297891071865, 48.968902587890625, 48.45549324580601, 47.429296425410676, 48.62496675763811, 48.39682265690395, 45.45495189939226, 46.24848134177071, 44.064530508858816, 42.390292576381135, 44.20229244232178, 42.38180187770298, 42.95403814315796, 41.13212319782802, 40.477932929992676, 42.719915117536274, 50.74722106116158, 53.590086936950684, 55.685097353799, 49.75125585283552, 48.97314098903111, 49.73043210165841, 53.61619826725551, 53.842146737234934, 55.204657214028494, 54.76977293831961, 53.434739112854004, 45.58509513310024, 41.93381677355085, 41.09869194030762, 40.015624114445274, 40.489432198660715, 40.69163519995553, 40.743531295231406, 43.594370228903635, 47.84867579596383, 54.271524565560476, 55.25178337097168, 52.65813200814383, 51.84218767711094, 52.08029202052525, 44.3661344391959, 41.47371401105608, 40.33459506716047, 48.22303083964756, 49.243495396205354, 57.34789507729666, 44.949574674878804, 43.479488713400706, 55.33088861192976, 52.62967218671526, 50.2656900542123, 43.894355228969026, 48.68303632736206, 45.92249270847866, 50.5321604183742, 51.56291873114449, 52.12043176378523, 50.17498132160732, 56.38822031021118, 50.46456834248134, 51.34774691717965, 50.27518824168614, 53.572952679225374, 43.746664319719585, 49.0077360698155, 56.054880482809885, 46.218670095716206, 41.23203134536743, 41.93602282660348, 38.806498595646445, 41.5822240284511, 40.374908515385215, 47.862395014081685, 55.21432910646711, 53.249378544943674, 53.75692360741751, 53.07563883917672, 50.51705156053816, 42.73528453281948, 43.27964809962681, 43.05982099260603, 43.069395610264365, 49.824680941445486, 53.976424149104524, 52.12363140923636, 56.723109585898264, 57.36960819789341, 55.76453610828945, 57.37862001146589, 56.48597799028669, 57.54189225605556, 60.153320584978374, 56.98710639136178, 57.665771688733784, 57.910473346710205, 61.91004058292934, 60.890823228018625, 57.889336926596506, 38.615308489118306, 0.16778640236173356, 0.5042358743292945, 2.9064028092793057, 2.312105579035623, 0.4227569278861795, 0.12163384817540646, 2.0472938801561082, 43.48085403442383, 36.31918593815395, 30.436024597712926, 32.76239613124302, 26.542118617466517, 27.543699707303727, 41.50011716570173, 49.833956786564414, 51.430305412837434, 60.19418294089181, 24.967585597719463, 0.14767679572105408, 0.032963207457214594, 0.07025851495563984, 0.05653594148212245, 0.060795889502125125, 0.0429285221866199, 0.027911997699577893, 0.038098516541400125, 0.05538870161399245, 0.04206626024097204, 0.033895222802779505, 0.008829079002940228, 0.03612913650327495, 0.05541625352842467, 0.06036058893161161, 0.0335043934173882, 0.06561943210129227, 0.050170071822191985, 0.13245990153934273, 0.1442761139145919, 0.15216134222490446, 0.1617480513772794, 0.10080456693789788, 0.12482184996562344, 0.13854636065661907, 0.11522071515875203, 0.22483530613992894, 0.08560089740370001, 0.10865961401058094, 0.18058278571282113, 0.09672264954341309, 0.11452073843351432, 0.14793234557977744, 0.08255095713372741, 1.950872642653329, 70.12585462842668, 78.96247632162911, 77.89985357012067, 63.02031408037458, 43.44048500061035, 29.956286226000103, 39.47225414003645, 58.079790524074006, 55.93892894472395, 48.39676707131522, 3.2360457607678006, 0.20248189275818212, 0.27854304920349804, 1.7226147651672363, 6.185685038566589, 9.74855625629425, 8.688405326434545, 2.179147239242281, 61.93231650761196, 74.53326375143868, 66.74096325465611, 64.49176188877651, 58.55023915427071, 53.65385750361851, 52.268848759787424, 52.32173497336251, 52.36495624269758, 50.65880870819092, 52.615449224199565, 48.62947266442435, 50.692618642534526, 46.250680446624756, 45.49568223953247, 46.19985089983259, 44.93525096348354, 44.90673903056553, 44.50468151909964, 41.837278502328054, 44.30982623781477, 52.706491470336914, 56.50705187661307, 58.269017764500205, 52.41739082336426, 50.877284390585764, 51.540677547454834, 56.07835149765015, 55.74184676579067, 57.26586811883109, 57.91524675914219, 55.251092025211875, 48.81061914988926, 45.290293489183696, 42.1537515776498, 41.33439220700945, 42.947079522269114, 43.42109257834298, 43.32681941986084, 45.21239028658186, 48.70250170571463, 55.21183817727225, 58.12097944532122, 54.670253889901296, 53.33018262045724, 54.95521688461304, 46.62266615458897, 43.69342374801636, 41.3425737108503, 50.06693683351789, 51.002577781677246, 59.75068637302944, 47.65259415762765, 45.69024222237723, 56.959431716373985, 55.678548676627024, 53.745907238551546, 48.22831841877529, 52.397564138684956, 48.468264034816194, 53.19212538855416, 54.53762320109776, 53.80426863261631, 53.19547094617571, 60.42136124202183, 54.17326314108712, 54.72593675340925, 51.493606976100374, 55.708234855106895, 43.7994567326137, 50.541015897478374, 58.43558692932129, 48.447426387241904, 42.26328298023769, 45.05534362792969, 40.739636829921174, 44.28043188367571, 42.978103228977744, 51.31256818771362, 58.25462109701974, 55.41840464728219, 55.79120676858084, 55.707550457545686, 53.51707179205758, 45.33305617741176, 45.22682516915457, 46.17392717088972, 45.248976026262554, 52.21862718037197, 56.92212683813912, 53.81597982134138, 59.49199104309082, 58.04294075284685, 59.718252182006836, 60.242340905325754, 59.34852463858468, 60.40005806514195, 62.44910267421177, 57.936994620731895, 59.54563113621303, 61.424500465393066, 64.9305475779942, 63.23338059016636, 62.090096201215474, 38.643469538007466, 0.19636608021599905, 5.076381249087198, 11.974021707262311, 2.2541243817125047, 0.37381501123309135, 0.1772805457668645, 4.758595398494175, 51.22770289012364, 48.26651266642979, 57.839976923806326, 45.29362515040806, 30.502167974199565, 31.698536600385392, 49.17909949166434, 57.72205557141985, 59.454436029706685, 66.97476318904332, 31.0287024634225, 0.2850619794002601, 0.07583081416253533, 0.13288727003548825, 0.159642543643713, 0.15952359645494393, 0.21924279337482794, 0.1922103382114853, 0.19725646743816988, 0.2059049933616604, 0.18342345899769238, 0.20457445404359273, 0.1336926503905228, 0.10844934279365198, 0.2165291825575488, 0.1755189738635506, 0.09554336246635232, 0.13422208412417344, 0.18261821434966155], [0.02537036667178784, 0.028145035462720052, 0.03201579275940146, 0.04960909978087459, 0.06776981814099209, 0.04106664923684938, 0.05926023583327021, 0.0620122245912041, 0.05062581665281739, 0.03677308659202286, 0.0430987089473222, 0.0678203689998814, 0.07948263535009963, 0.08841636311262846, 0.10874466158981834, 0.2909966366631644, 8.713777542114258, 64.00269903455461, 58.32695879255022, 63.18519483293806, 53.82935162952968, 66.87130451202393, 15.327644450323922, 42.65949010848999, 41.487898758479524, 41.18021862847464, 24.408924375261577, 0.120839460087674, 0.0331747102152024, 0.20816726982593536, 1.2612181178161075, 1.9789585641452243, 1.763137093612126, 2.591767315353666, 9.446482454027448, 72.4827252796718, 56.19573436464582, 63.16892215183803, 51.931989669799805, 50.00606019156319, 47.14196062088013, 45.13601221357073, 43.62159674508231, 47.75971800940377, 45.72488594055176, 44.50776651927403, 45.73064947128296, 42.10618768419538, 40.94858305794852, 42.69354322978428, 40.410719530923025, 40.4998197555542, 40.65844018118722, 41.829510416303364, 40.72789090020316, 39.01534407479422, 42.44141047341483, 48.016603333609446, 45.55130951745169, 44.646709646497456, 44.042928559439524, 47.814768586839946, 50.14927646092006, 52.331320013318745, 54.64713723318917, 52.831868239811485, 50.84068822860718, 45.891138962336946, 40.72216558456421, 37.923288754054475, 38.051813057490754, 38.273568289620535, 40.70706020082746, 38.07541608810425, 41.80537237439837, 48.07810183933803, 55.32161276681082, 50.76712417602539, 52.81175320489066, 51.132241589682444, 47.63837466921125, 39.49191754204886, 39.86878088542393, 38.34368256160191, 46.10279498781477, 46.183560848236084, 58.02793959208897, 39.538619858878, 37.75678907121931, 56.91404260907854, 46.233733790261404, 46.07093749727522, 40.711614745003835, 42.82739332744053, 41.56535380227225, 49.98355845042637, 47.75679629189627, 50.588086468832834, 50.15637404578072, 51.34708683831351, 45.37681940623692, 46.86089903967721, 46.66616187776838, 51.56909915379116, 48.44599505833217, 51.02148035594395, 50.72496598107474, 44.624979155404226, 37.30935287475586, 40.42152745383126, 37.039335455213276, 39.70631463187081, 37.851652826581685, 41.92426994868687, 49.09752069200788, 51.68333101272583, 50.7525121143886, 50.41645206723894, 51.024238790784565, 43.21781260626656, 39.21909652437483, 41.05259411675589, 38.540514605385916, 45.99222135543823, 50.086676665714805, 53.86920649664742, 50.224980558667866, 56.388678891318186, 56.084420749119346, 54.29818132945469, 54.28047731944493, 60.024257796151296, 50.62483549118042, 55.55507571356637, 55.824440002441406, 58.21926866258894, 54.988168716430664, 57.84086281912667, 55.197976521083284, 58.66197313581194, 28.11741246495928, 0.257357828851257, 4.715573021343776, 1.4268895536661148, 0.44063011024679455, 0.055775785486080816, 0.06946154843483653, 20.106684923171997, 48.99963447025844, 26.54859607560294, 30.62673875263759, 24.791467870984757, 18.581925324031285, 27.630051919392177, 42.75920718056815, 46.00495392935616, 53.01023891993931, 41.91547352927071, 1.6276074860777174, 0.030531429552606175, 0.05128330012251224, 0.05399606955636825, 0.0759971027395555, 0.0255151473850544, 0.04462911754048296, 0.06215434375086001, 0.028770451367433583, 0.030031054081129174, 0.04482498685164111, 0.03359024506062269, 0.01975308737850615, 0.02665397341895316, 0.03490911018369453, 0.03871744565133538, 0.049138841086200306, 0.03171693201043776, 0.05347951441737158, 0.030792797849114453, 0.0041535206504964405, 0.043729481886007955, 0.0625450781413487, 0.024986436291198646, 0.04848806493516479, 0.02722594790559794, 0.04118645816509213, 0.07699399281825338, 0.09584348529045071, 0.08596026312027659, 0.11795856324689728, 0.045397544878401926, 0.06717411867742028, 0.2538154146500996, 13.59237093584878, 75.9059498650687, 62.86354187556675, 68.92899268014091, 57.150496755327495, 69.70982428959438, 16.06583149092538, 37.54997941425869, 41.50500522341047, 47.691636085510254, 26.998207058225358, 0.1842190277363573, 0.07271639270974056, 0.7088615713374955, 1.548927930848939, 2.6460168957710266, 1.5978110049452101, 2.814086437225342, 10.91249850818089, 76.01250049046108, 59.16272980826241, 65.65493897029332, 54.606983593532014, 51.966581276484895, 48.3939391544887, 47.425318581717356, 45.322567871638704, 48.95991856711251, 47.57379463740757, 46.78131784711565, 48.15187781197684, 45.03050034386771, 43.640384674072266, 45.14552082334246, 42.03057391302926, 42.39468731198992, 42.584494726998464, 42.30007716587612, 45.29746750422886, 42.26362691606794, 45.1007535798209, 49.264753409794395, 48.33446952274868, 47.20546020780291, 44.68298619134085, 49.902730056217735, 53.33437933240618, 54.226701736450195, 56.5165570122855, 54.69837324959891, 54.48101275307791, 48.120979172842844, 43.391882351466585, 40.594607080732075, 40.209642137799946, 41.392861298152376, 41.3081453868321, 40.548641272953574, 44.58614567347935, 50.13043294634138, 57.32893691744123, 53.85837772914341, 53.69519928523472, 52.72861800874983, 52.54415028435843, 42.20810038702828, 42.272899287087576, 40.58032853262765, 49.56275469916207, 50.19072593961443, 59.23523426055908, 42.4343615259443, 40.36124835695539, 57.66817923954555, 49.12175600869315, 48.817549977983745, 42.12065730776106, 45.206901209695, 43.06326035090855, 50.24665199007307, 49.64999280657087, 52.769904204777305, 50.99059908730643, 53.176874092647004, 45.98769807815552, 48.25455134255545, 48.844234534672324, 54.26001140049526, 50.101194926670615, 52.485010692051475, 51.51543126787458, 45.57537112917219, 39.42037194115775, 42.49174322400774, 39.296662739345, 41.941848891122, 41.48015151705061, 43.65618487766811, 52.99343817574637, 54.05703714915684, 54.508697850363596, 53.53574854987008, 52.04391820090157, 45.30524253845215, 39.42384604045323, 42.32044233594622, 41.28287478855678, 48.40009525844029, 52.55186973299299, 55.79768943786621, 53.18885973521641, 57.586656025477815, 57.40627384185791, 57.33239017214094, 56.66108301707676, 60.43609142303467, 50.82339416231428, 57.89271722521101, 57.32016134262085, 60.45476123264858, 55.500296115875244, 60.72148173195975, 57.731508595602854, 62.4946620123727, 34.086125237601145, 0.2032155112496444, 0.613668156521661, 2.3666263563292365, 1.6216533141476768, 0.16732845907764776, 0.2769345412296908, 21.014805793762207, 55.64344637734549, 30.45813376562936, 27.154176746095928, 19.56939114843096, 24.281357186181204, 32.838357312338694, 48.422551836286274, 51.82925360543387, 59.067456109183176, 52.32765136446272, 3.5628336540290286, 0.09962367173284292, 0.032101719041488, 0.0476192958386881, 0.053822262811341455, 0.025833526193829517, 0.04392496103953038, 0.0274601171258837, 0.03750006901100278, 0.06927294284105301, 0.06087063013442925, 0.0690460746575679, 0.08547141935144152, 0.05133787469406213, 0.05285748100972601, 0.03467544986467276, 0.021217705216258764, 0.0368360207150025, 0.08591929317585059, 0.10313437799257891, 0.2192836683243513, 0.16347022753741058, 0.13890194014779159, 0.164435226470232, 0.14491924297596726, 0.2925613655575684, 0.18505433148571424, 0.17059939141784394, 0.14727354235947132, 0.1830937045493296, 0.2422770352235862, 0.1483109409787825, 0.19626767906759465, 0.3683402378644262, 17.305497816630773, 87.23700959341866, 71.85414259774345, 78.30962358202252, 62.46907179696219, 77.21838120051792, 22.124624184199742, 53.530249050685335, 54.206326144082205, 58.77172688075474, 31.612813200269425, 0.26385572446244104, 0.1087562238265361, 0.8574035263487271, 5.496570084776197, 5.532571741512843, 8.209073424339294, 6.558681275163378, 12.84891368661608, 77.684542792184, 61.025555746895925, 69.90813977377755, 56.82147175925118, 55.53082650048392, 50.93364470345633, 50.13929884774344, 46.80198526382446, 52.12556995664324, 51.38127544948033, 49.2041130065918, 51.70166730880737, 48.77674320765904, 46.20004892349243, 48.382575375693186, 44.011588709695, 45.460913453783306, 44.80329772404262, 46.45123325075422, 46.31290851320539, 43.05128860473633, 47.257064478737966, 51.83551740646362, 50.17071165357317, 49.03241607121059, 47.19260604040963, 51.09742764064244, 55.26120512826102, 56.777656418936594, 58.42836080278669, 58.03177152361189, 58.626071793692454, 49.53818934304373, 45.2632337297712, 41.28343064444405, 41.77488020488194, 43.23894207818167, 44.05568545205252, 42.111367566244944, 46.15378434317452, 53.966495173318044, 59.374052320207866, 56.77323041643415, 56.14223323549543, 55.539751461574006, 54.27917800630842, 43.447106633867534, 43.77865035193307, 43.462389196668354, 51.32695095879691, 52.289884431021555, 61.468816076006206, 45.07471867970058, 44.412218366350444, 61.246119362967356, 52.434007440294536, 51.60828351974487, 45.00154720033918, 46.90165022441319, 46.871043409620015, 54.60573639188494, 53.7448719569615, 55.39889063153948, 54.2821865762983, 56.65998520169939, 49.00486993789673, 51.87890543256487, 50.112232140132356, 56.71860020501273, 49.948866094861714, 53.9353220803397, 54.34025614602225, 48.05407496861049, 41.6238819531032, 45.23646232060024, 41.29890775680542, 44.000593185424805, 43.18307508741106, 46.78332587650844, 54.202028683253694, 55.31824289049421, 54.47306053979056, 55.275351660592214, 56.29302304131644, 48.369762897491455, 42.885980537959504, 44.81581490380423, 43.37312568937029, 50.93950203486851, 56.472140652792795, 58.52036190032959, 55.365681716373985, 62.27198614392962, 58.862088203430176, 59.02717045375279, 58.63230432782854, 60.088466099330354, 51.55564396721976, 61.79909174782889, 59.50648498535156, 64.83341176169259, 58.68023994990757, 62.98926952907017, 59.243460927690776, 65.99299662453788, 33.2229505266462, 1.0270683850560869, 14.61827506337847, 7.0524576136044095, 1.0122269243001938, 0.21437906793185643, 0.3970704419272286, 25.10618826321193, 64.08791174207414, 38.739090647016255, 43.71543564115252, 33.632557255881174, 27.107526540756226, 37.38472693307059, 55.71501282283238, 59.435655048915315, 66.320631980896, 59.965517725263325, 4.862296828201838, 0.2190520436103855, 0.1521831639111042, 0.17454625320221695, 0.21102939838809626, 0.18569351147328103, 0.14780984286751064, 0.13042530071522507, 0.12931229972413608, 0.2078327384910413, 0.10656439965324742, 0.113495851999947, 0.14962951093912125, 0.10484253561922482, 0.15358360590679304, 0.13114536207701477, 0.16319527157715388, 0.10841099877974816], [0.027790706172319393, 0.0438810225043978, 0.028320655592584183, 0.054304487471069605, 0.11573488185448305, 0.047992995607533624, 0.019266878021880984, 0.018882340352450098, 0.06885628841285195, 0.06435932471816029, 0.025878955809665576, 0.013902934018655546, 0.0127741401250075, 0.03953954850190452, 0.07820119482598134, 0.03201853743355189, 42.67282370158604, 63.36837019239153, 59.6706292288644, 62.15621525900704, 53.86515917096819, 24.93021818569728, 36.49989468710763, 56.62676239013672, 30.74637978417533, 52.39056382860456, 9.205380831445966, 0.2692697010934353, 0.10453838908246585, 0.44161626590149744, 0.812745771237782, 0.5013036259583065, 2.214850340570722, 1.013187187058585, 30.04676914215088, 73.3383264541626, 60.22724941798619, 60.394652366638184, 52.87569052832467, 49.92583976473127, 44.67490196228027, 44.39733532496861, 43.67410775593349, 42.788900307246614, 43.53274665560041, 44.14690487725394, 42.5225167955671, 43.35996232713972, 40.7165653364999, 39.64401708330427, 42.28338759286063, 39.154721464429585, 41.655124528067454, 41.44469485964094, 40.71768052237374, 39.25451496669224, 39.8120106288365, 39.73820686340332, 41.557196617126465, 42.12872069222586, 43.26012713568551, 48.62214926310948, 50.771730831691194, 53.11604608808245, 53.29373584474836, 54.13102156775338, 51.40123067583357, 47.961761202131, 42.99306270054409, 37.938098839351106, 38.22328070231846, 37.81141233444214, 38.48210457393101, 39.379064900534495, 44.083662373679026, 46.63460315976824, 52.03087990624564, 47.958745683942524, 53.13845750263759, 48.7705454145159, 44.48877361842564, 36.865481104169575, 39.16709620612008, 39.4240266936166, 48.878555161612375, 46.199305466243196, 59.243349756513325, 36.963381222316194, 36.37189844676426, 54.577460697719026, 47.091151918683735, 44.85951559884207, 37.713540009089876, 40.3411784853254, 37.69565534591675, 41.5483272416251, 46.30039133344378, 53.4953829901559, 49.77606439590454, 49.65877185549055, 43.38704987934658, 41.31350244794573, 47.1120069367545, 50.666479519435335, 49.59541818073818, 49.51517343521118, 50.779304368155344, 43.32035412107195, 38.214022227696006, 39.97849294117519, 38.15634870529175, 38.97253622327532, 39.006902013506206, 40.1283586365836, 46.689591203417095, 51.09088243756975, 51.12633214678083, 51.6609856060573, 49.86372981752668, 41.853186403002056, 38.67525407246181, 40.74337148666382, 39.03813764027187, 45.732344831739155, 49.74055215290615, 52.0784090587071, 55.73442956379482, 52.94684355599539, 52.53628144945417, 57.554190567561555, 56.53709588732038, 50.936986786978586, 57.25595998764038, 57.74516180583409, 56.846214294433594, 51.34977926526751, 54.09946979795183, 54.57849945340838, 61.457282066345215, 53.97477742603847, 58.156734875270296, 17.036150898252213, 2.161619322640555, 3.0604317784309387, 1.245937617761748, 0.0007805769845227977, 0.16846287463392529, 2.60837350998606, 45.71236528669085, 27.354305710111344, 34.21930135999407, 54.51286676951817, 16.902385916028702, 18.997509241104126, 31.871452944619314, 43.400921957833425, 48.79045895167759, 50.759564535958425, 10.07913156918117, 0.13065706113619463, 0.03823080712131091, 0.035104263640408, 0.09043660613575152, 0.030958377357040132, 0.01921235942947013, 0.06764444522559643, 0.06025494781455823, 0.032181979556168826, 0.041863042395561934, 0.07521956267633609, 0.03048070566728711, 0.028170599269547632, 0.07059920060315303, 0.012733060766809752, 0.036469530380730114, 0.08498757638569389, 0.007821447714897138, 0.00598930986598134, 0.024803586370710815, 0.0395216351774122, 0.09303366499287741, 0.09642091180597033, 0.013279197488113173, 0.04238462208637169, 0.07070828189275094, 0.08630250261298247, 0.04886447545140982, 0.012079831711681826, 0.04327528411522508, 0.02433166526524084, 0.024827021273917387, 0.08251141211284058, 51.87886721747262, 71.97172696249825, 64.58162988935197, 67.73992661067417, 59.608720779418945, 38.29220335824149, 32.88949605396816, 48.037371499197825, 32.064189025333945, 60.40788868495396, 8.620550956044879, 0.2939858819757189, 0.07415380129324538, 1.6567099073103495, 1.7253907876355308, 2.9597925501210347, 3.58231640287808, 1.2000308696712767, 34.13836179460798, 75.63116945539201, 63.54985019138881, 62.71683761051723, 54.568601744515554, 51.75065210887364, 47.34081111635481, 46.81399175098964, 45.711600984845845, 45.339615276881624, 46.34903914587838, 46.393653529030935, 45.190562520708355, 44.71854359763009, 43.33649826049805, 43.19260801587786, 44.37254415239607, 41.70353957584926, 43.1440018926348, 44.13821962901524, 43.41259145736694, 42.29614448547363, 42.1715007509504, 40.870454038892476, 43.21322332109724, 44.70204510007586, 44.92402614865984, 51.27350194113595, 54.030894551958355, 54.689667156764436, 55.03940125874111, 54.1366218158177, 52.896663665771484, 49.347530773707796, 44.03024809701102, 40.78298316683088, 41.117153303963796, 39.03027922766549, 40.11096034731184, 41.78053256443569, 45.774009704589844, 49.224433013371055, 54.37433706011091, 50.411831515175955, 54.88488721847534, 52.35012183870588, 46.81906393596104, 38.58668538502285, 41.08770336423601, 42.175912857055664, 51.42650474820818, 48.58497987474714, 60.286649567740305, 38.65113687515259, 37.998895577022004, 58.531395639692036, 48.870835712977815, 45.59828976222447, 40.755159105573384, 41.385854039873394, 40.74926355906895, 43.762461049216135, 48.58430937358311, 54.16877807889666, 51.39271565846035, 50.62201452255249, 45.94234718595232, 43.016366958618164, 47.47754124232701, 52.67989376613072, 51.53438942773001, 49.91469832829067, 52.205390862056184, 45.982483455113, 40.37245232718331, 42.69564505985805, 39.62403059005737, 40.88129670279366, 41.285945892333984, 42.92466115951538, 49.59513677869524, 54.234480244772776, 52.72417116165161, 53.02773100989205, 52.51981769289289, 44.23543187550136, 40.938907691410606, 42.90714475086757, 42.10781703676496, 47.52327428545271, 51.91425439289638, 56.2638510295323, 57.821755273001536, 55.62244544710432, 53.93966817855835, 59.539690426417756, 55.29295492172241, 51.70496422903878, 59.312998499189106, 58.453110286167686, 60.0549966267177, 54.38090310777937, 57.3607805115836, 56.623698234558105, 63.700501033238, 56.671811035701204, 62.085850851876394, 21.223800659179688, 1.4492206296750476, 2.795795738697052, 2.992488601378032, 0.2704451408769403, 0.17051842861941882, 2.319987876074655, 50.236528464726035, 33.36716038840157, 31.058861119406565, 42.574909687042236, 21.218005861554825, 22.083487374441965, 36.41943802152361, 46.78153324127197, 55.809800148010254, 58.07853984832764, 14.721954345703125, 0.13341492600739002, 0.044377533718943596, 0.0532903897442988, 0.02987674843253834, 0.03176985774189234, 0.04733156645670533, 0.049400535079517534, 0.08454742428979703, 0.02344465714746288, 0.02400065552709358, 0.06292668623583657, 0.028264706987621527, 0.017532849551311562, 0.016661312031958784, 0.02722389024815389, 0.00625248221747045, 0.10100315378180572, 0.16757715573268278, 0.135421666183642, 0.124539226559656, 0.24084035945790155, 0.18695070115583284, 0.19358488731086254, 0.18724974510925158, 0.06316224645291056, 0.08616239191698176, 0.18477678352168628, 0.11102223223341362, 0.10377486076738153, 0.12694125409637178, 0.10357573788080897, 0.20447479082005365, 0.22542989280607018, 60.361947195870535, 81.86498900822231, 74.65380110059465, 76.132613999503, 68.92651217324394, 35.345399379730225, 47.59302377700806, 72.06844588688442, 44.76212269919259, 67.46855081830705, 11.415454285485403, 0.4715019336768559, 0.22564720043114253, 2.009633775268282, 4.706049646650042, 3.9226706538881575, 12.04211231640407, 2.6118895156042914, 38.174945558820454, 78.02867317199707, 66.68022210257394, 65.3467377253941, 58.79306479862758, 54.594070366450715, 48.49112360818045, 48.995427336011616, 47.918929031917024, 48.2964837210519, 48.30863264628819, 49.150309630802695, 47.98622580936977, 48.48941087722778, 45.42586326599121, 45.41269295556204, 47.02963604245867, 44.0319504056658, 45.845458030700684, 46.05407074519566, 45.99579620361328, 44.800803320748464, 44.8530398777553, 43.19716950825283, 44.53302322115217, 48.34869943346296, 47.30393702643258, 52.597870281764436, 56.18588876724243, 56.76188053403582, 57.23057474408831, 55.17610011781965, 53.986742224012104, 52.90787805829729, 46.92315489905221, 42.65070063727242, 42.141939640045166, 41.091778482709614, 41.78266218730381, 43.797059604099815, 48.60666172845023, 51.921845299857004, 56.23103468758719, 52.362715448652, 56.049770082746235, 54.05046762738909, 48.44194425855364, 42.62276540483747, 43.32937288284302, 43.61313731329781, 52.77639729636056, 50.84661156790597, 63.62317453111921, 42.67551612854004, 41.52481453759329, 61.021602221897666, 52.60519715717861, 47.80989442552839, 43.29615354537964, 44.07406691142491, 41.88146904536656, 45.64758723122733, 52.04763896124703, 57.56119087764195, 53.626439911978586, 52.764786856515066, 48.82228170122419, 46.47052492414202, 51.235735007694785, 56.696980885096956, 53.22317688805716, 52.961132526397705, 55.57418325969151, 48.2807286807469, 43.83496897561209, 44.182764530181885, 41.06367996760777, 43.57035378047398, 42.67554044723511, 44.639170851026265, 52.81151001793997, 56.73060669217791, 54.50536618913923, 55.06350455965315, 54.731043679373606, 45.73204953329903, 43.86573907307216, 45.483981473105295, 44.50390679495675, 49.44908217021397, 54.72824008124215, 58.35598141806466, 59.57591833387102, 58.644644328526084, 57.91472217014858, 60.85474818093436, 57.130506787981304, 53.83549036298479, 63.64489459991455, 61.496796471732004, 62.353731700352256, 56.17888150896345, 60.491114207676475, 59.78229372841971, 66.4974775314331, 57.19557319368635, 67.39766529628209, 19.916366815567017, 3.9520532829420905, 13.580217667988368, 4.1234071510178705, 0.17018966483218329, 0.24008504141654285, 3.378860120262418, 57.2641658101763, 39.62698704855782, 48.93615920203072, 68.98013142177037, 24.771154812404088, 28.317362512860978, 44.66671003614153, 55.62481130872454, 62.305393082754954, 66.08111367906842, 17.824839183262416, 0.39862301147409845, 0.14641781470605306, 0.1327775102108717, 0.18422461886491093, 0.1083084721384304, 0.15755226223596505, 0.19996755410517963, 0.2218469429228987, 0.1654004425342594, 0.1497707955007042, 0.18904091471007892, 0.156708368233272, 0.08536758992288794, 0.18771634650017532, 0.09589733382953064, 0.07750864127384764, 0.29469492392880575], [0.06354426166840962, 0.02200319431722164, 0.05299765955922859, 0.0492793114057609, 0.0026689776319212145, 0.08898813743144274, 0.0012126155509447146, 0.1014357130708439, 0.06924353513334479, 0.024975438934883902, 0.06061622021453721, 0.10647416806646756, 0.0314033436588943, 0.04783672220738871, 0.04011531939197864, 3.8965836422783986, 55.396597726004465, 58.980680056980674, 63.4778390611921, 53.0194730758667, 33.330008370535715, 16.382184709821427, 23.339676516396658, 51.98966319220406, 42.52585193089077, 48.867733342306956, 1.7247730493545532, 0.024957925946052586, 0.043747785368136, 0.7458228394389153, 0.5781163956437791, 2.209816804953984, 3.8586755735533576, 0.7124047726392746, 55.32240833554949, 65.51797607966832, 61.078841481889995, 58.88149452209473, 59.09590898241316, 55.21006291253226, 49.63567951747349, 44.36876433236258, 44.042386599949424, 42.191744327545166, 42.182051590510774, 40.95324182510376, 43.55565486635481, 42.003920623234336, 40.63045283726284, 39.678716387067524, 42.31190299987793, 40.227450370788574, 42.65197910581316, 41.78229740687779, 44.32145752225603, 39.85162230900356, 38.79854985645839, 40.30202538626534, 40.20523350579398, 39.8489750453404, 45.04139859335763, 48.529234477451865, 50.184142521449495, 51.03744036810738, 53.51168693814959, 53.31031772068569, 53.490529673440115, 50.69510957172939, 44.873787198747905, 39.94232756750924, 38.82448053359985, 37.52158907481602, 39.50325700214931, 39.59734950746809, 43.51605708258492, 48.627756459372385, 51.31390919004168, 48.98661354609898, 53.19451904296875, 46.64880180358887, 42.06006901604788, 35.65300307955061, 43.29054634911673, 45.573925903865266, 52.32547310420445, 47.13690233230591, 57.234945161002024, 31.67358214514596, 34.09780168533325, 55.381461075374055, 47.579474789755686, 46.32101011276245, 38.46776696613857, 40.06505012512207, 36.66437939235142, 37.387888363429475, 42.15260165078299, 48.94631746837071, 48.02191175733294, 46.624462263924734, 41.35884986604963, 40.85078021458217, 45.685368061065674, 51.28674520765032, 51.34691660744803, 50.19900471823556, 51.594751902988975, 43.95897347586495, 36.5702417237418, 39.40229967662266, 37.62274789810181, 38.4545236996242, 38.908116000039236, 45.7861898967198, 46.188733782087056, 50.904983384268625, 51.98112733023507, 50.85492508752005, 51.19267354692732, 43.22389228003365, 37.58507823944092, 39.11918837683541, 38.537846497126985, 46.186965465545654, 50.738897119249614, 54.853557791028706, 54.013496262686594, 55.579884256635395, 54.49637869426182, 52.610654967171804, 48.83382960728237, 54.70609269823347, 56.27698312486921, 54.67630577087402, 52.43242672511509, 49.722333976200645, 44.533916064671104, 54.01670980453491, 55.782135895320344, 58.90759890420096, 56.6530613218035, 50.13869088036673, 3.776624296392713, 1.4693769195250102, 4.36027775491987, 0.13534124621323176, 0.1631390753069094, 0.035605768872691054, 24.381287915366038, 42.632440771375386, 24.723580496651785, 33.85659497124808, 12.843394211360387, 25.174350091389247, 25.157464231763566, 39.938655444553916, 47.627563272203716, 51.85340206963675, 30.21312986101423, 1.2446651203291756, 0.10140269555683647, 0.01639976562000811, 0.036600338361625157, 0.022421991219744086, 0.04174261260777712, 0.01837609724939934, 0.01188062146372561, 0.03874310106039047, 0.047504073807171414, 0.028286296275577376, 0.0313890876381525, 0.13624780971024716, 0.05949127022176981, 0.01914729131385684, 0.07055624255112239, 0.048388303324048004, 0.047803640232554505, 0.05631079338490963, 0.024236217440505112, 0.04537332117823618, 0.04727457290781396, 0.08329094706901483, 0.01396417519676366, 0.06750562374613114, 0.032805648233209334, 0.10657955812556402, 0.049150637417499504, 0.09495375624724797, 0.042867881512003284, 0.19238215684890747, 0.11488660451556955, 5.858432701655796, 67.22969954354423, 64.12731497628349, 69.64269079480852, 60.596949168613975, 42.44190379551479, 26.441505227770122, 27.92848399707249, 43.79506547110421, 45.95938416889736, 53.61488158362252, 1.6173394599131174, 0.023959804326295853, 0.10537169115351779, 0.9348241005625043, 1.9487855775015694, 3.1598086059093475, 2.340686993939536, 1.707507101552827, 56.886371408190044, 66.74871049608502, 62.312382970537456, 61.51292324066162, 60.93291541508266, 56.05919878823416, 51.332033566066194, 46.58151197433472, 45.334928716932026, 45.64426946640015, 44.99650280816214, 44.33869252886091, 45.64259842463902, 44.842127731868196, 42.89346374784197, 41.11961644036429, 43.945205620356965, 42.644600118909565, 44.95900338036673, 43.94742556980678, 45.91012144088745, 42.03353384562901, 40.914613315037315, 41.75101661682129, 43.58264166968209, 43.376842975616455, 48.6431884084429, 50.27684538705008, 51.90979017530169, 53.82819822856358, 55.56224972861153, 54.36728116444179, 54.35181794847761, 52.75946453639439, 47.55082736696516, 41.927174295697895, 41.53365959439959, 39.910365853990825, 41.75679751804897, 41.01309013366699, 45.085609980991904, 50.46239703042166, 53.622090339660645, 51.57508850097656, 54.79006167820522, 49.74690628051758, 42.484360763004844, 36.389213357652935, 44.16944483348301, 47.87151105063302, 55.11208636420113, 50.65337521689278, 59.756418636866975, 33.90180342538016, 37.24128137316023, 57.08907467978341, 48.89790589468819, 48.56789425441197, 39.44493382317679, 42.98384244101388, 39.06573935917446, 41.20784814017159, 44.17042800358364, 51.134934016636436, 50.18105057307652, 49.71811989375523, 42.515849999019075, 42.3573511668614, 46.147871426173616, 53.842122418539866, 51.81857769829886, 50.991026401519775, 53.00935302461897, 46.108829498291016, 38.74852630070278, 41.327002797807964, 40.20649112973894, 40.59267200742449, 40.959359713963096, 46.87957579748971, 48.639839376722065, 52.31084367207119, 51.85003914151873, 54.192923069000244, 54.02777828489031, 46.627498626708984, 39.370747906821116, 41.860172816685264, 40.69564083644322, 48.80300392423357, 52.903677872249055, 57.485358238220215, 56.5813559123448, 58.74906880514962, 56.84311192376273, 54.58728545052664, 50.27783203125, 58.2870830808367, 57.92410223824637, 56.59691640308925, 54.94712918145316, 52.36732905251639, 45.93160874502999, 56.43405062811715, 55.9366568837847, 61.35594258989607, 58.377152579171316, 56.27305391856602, 4.742546796798706, 1.3383280315569468, 2.5834431563104903, 1.2522391996213367, 0.19113992207816669, 0.12709950203342096, 24.730822256633214, 49.57356262207031, 28.427321229662212, 33.08795050212315, 12.303932598658971, 29.41383341380528, 32.94790261132376, 46.405392510550364, 52.833858898707796, 59.4838547025408, 37.961020946502686, 1.4601063941206252, 0.018781937525740693, 0.0739535316824913, 0.02860822042982493, 0.014885017615077751, 0.02493135112204722, 0.007920029523250247, 0.02388569982057171, 0.04073486936145595, 0.046077409825686894, 0.02651421556116215, 0.005599796838526214, 0.050992069499833245, 0.03909756096878222, 0.05641797138378024, 0.05472497562212603, 0.011489538475871086, 0.10645925386675767, 0.19227211203958305, 0.11202763792659555, 0.18052245037896292, 0.138889984360763, 0.15629215485283307, 0.08612988330423832, 0.15865748721574033, 0.12239311529057366, 0.13438995368778706, 0.13639863447419234, 0.1296411177941731, 0.18260620427983149, 0.37043112995369093, 0.30053985172084396, 7.319946323122297, 77.18899726867676, 71.78488990238735, 79.2548634665353, 65.93933568681989, 45.83401434762137, 25.54028218133109, 31.659022194998606, 66.18833827972412, 57.579607078007285, 60.343638692583355, 2.3816650807857513, 0.10647192211555583, 0.1716088479650872, 3.63241400037493, 4.8594658715384345, 6.278631091117859, 9.290575299944196, 2.170993311064584, 62.0262769971575, 68.66688578469413, 66.15601525987897, 62.688780784606934, 66.17496994563511, 59.149417059762136, 55.119479247501914, 49.18421336582729, 48.15208625793457, 47.74027347564697, 47.423258440835134, 45.735523632594514, 47.24296310969761, 46.97807693481445, 45.369159017290386, 44.1467068535941, 46.134555203574045, 44.833723885672434, 46.91551188060215, 45.85586295809065, 48.25813661302839, 44.772093364170615, 41.695517880576, 44.55708135877337, 44.854012625558035, 44.67981086458479, 52.06017003740583, 52.79177018574306, 54.531248228890554, 56.561803681509836, 56.95778846740723, 54.966361795152935, 55.986902781895225, 55.44887944630214, 49.195914132254465, 45.43705333982195, 44.482252734048025, 42.00878088814871, 43.098414761679514, 44.42084802900042, 47.24569027764456, 52.910375935690745, 57.055921350206646, 53.15008531297956, 57.12591750281197, 51.243683746882844, 44.866387367248535, 38.55546018055507, 47.65097522735596, 48.94760635920933, 57.54473754337856, 53.14113255909511, 61.67646993909563, 36.99969250815255, 39.75431973593575, 60.417831557137625, 53.01132978711809, 50.9502717426845, 43.299544266292024, 45.218730517796104, 40.64985220772879, 43.51862791606358, 47.23849194390433, 53.62537336349487, 53.90764045715332, 52.311451639447895, 45.36673409598214, 44.264655998774934, 49.88121148518154, 55.84698690686907, 53.58735629490444, 52.861651693071636, 56.91936492919922, 47.7615384374346, 40.67025906699044, 45.29295812334333, 41.71537235804966, 42.58688490731375, 42.60934495925903, 49.78389501571655, 50.78547784260341, 54.61167710168021, 55.16212034225464, 55.13559212003435, 56.844577993665425, 48.13173845836094, 41.99969611849104, 44.533679825919016, 42.03795289993286, 51.184224537440706, 56.02284581320626, 60.463793890816824, 59.64346177237374, 60.563465799604145, 58.53015191214425, 55.99434430258614, 52.25335775102888, 60.04434503827776, 61.11759158543178, 60.54762390681675, 58.72030326298305, 54.91368750163487, 47.77853373118809, 58.85386848449707, 58.736478669302805, 63.74806840079171, 60.481914792742046, 59.01849215371268, 4.80583359513964, 3.917447779859815, 14.209661058017186, 0.875235806618418, 0.29193526772516115, 0.2327841403228896, 30.750524384634836, 57.20971972601754, 39.340665681021555, 47.87803888320923, 19.735770974840435, 34.32932261058262, 36.99716683796474, 53.5944504056658, 60.36702632904053, 65.79645987919399, 45.195742402757915, 1.903547159263066, 0.2708971809063639, 0.18891378438898496, 0.1544020819876875, 0.12415137594299656, 0.18648370621459825, 0.07072682625481061, 0.16397475903587683, 0.06449495708303792, 0.13487133357141698, 0.14248760417103767, 0.08586023348782744, 0.1953941330845867, 0.07876055195395436, 0.12618871804858955, 0.21988506748207978, 0.12278168515435287], [0.037008290578212054, 0.03974638293896403, 0.02094924622880561, 0.05333379902211683, 0.04729063043903027, 0.02664378860832325, 0.08758306104157652, 0.055873104371130466, 0.05373348668217659, 0.009978286622624313, 0.004951596576055246, 0.004756766271644405, 0.029259692079254558, 0.10121933503874711, 0.14748848868267878, 13.548863921846662, 64.78881127493722, 56.868431159428184, 56.64984777995518, 40.689686230250764, 28.593558618000575, 17.99101230076381, 36.72062158584595, 32.02175637653896, 45.711034706660676, 31.813685621534074, 0.10523440316319466, 0.06572626743997846, 0.4103685069297041, 1.148894082222666, 1.4434219236884798, 1.8857751871858324, 2.109843518052782, 16.045485428401403, 73.69292776925224, 61.97440869467599, 67.22480801173619, 56.79664931978498, 58.92611585344587, 55.92770760399954, 54.07731894084385, 46.10111352375576, 45.46339396068028, 42.75540999003819, 43.6299033164978, 40.3779170853751, 41.47630916322981, 42.14929778235299, 42.89790712084089, 38.65040384020124, 40.409844057900564, 41.71602896281651, 44.8727901322501, 42.26235539572579, 44.23653316497803, 40.215138162885395, 39.6932624408177, 38.904367446899414, 40.46560682569231, 41.4200565474374, 46.703286102839876, 47.62778214045933, 50.03607988357544, 53.46789591653006, 52.834338324410574, 52.78872340066092, 54.323806285858154, 50.927304472242085, 45.113041469029014, 38.545023986271445, 37.99753720419747, 36.843535218920024, 37.08607251303536, 38.3210939679827, 43.3826447214399, 49.91792229243687, 49.33628511428833, 49.85659749167306, 53.50006260190691, 43.52206727436611, 38.337762696402415, 36.461297443934846, 45.15502943311419, 48.26060322352818, 53.23299469266619, 48.152534416743684, 53.51145417349679, 29.50316640308925, 33.4220198903765, 55.13591521126883, 44.96721267700195, 45.6299283845084, 36.485348633357454, 41.77522414071219, 37.73730979646955, 38.50169154575893, 36.69779327937535, 42.8128160067967, 42.53515556880406, 42.35641663415091, 39.48880474908011, 39.03993374960763, 45.11913503919329, 49.17141130992344, 48.94708524431501, 50.876811913081575, 50.635257789066856, 43.676279067993164, 38.126023292541504, 38.076673712049214, 37.3825695174081, 39.30151605606079, 40.77083771569388, 45.725886481148855, 45.96455362864903, 50.418727602277485, 51.28283337184361, 50.41553143092564, 50.72216585704258, 44.38444989068167, 37.49180909565517, 40.15753064836775, 39.598297936575754, 46.65773023877825, 52.26395027978079, 53.16221686771938, 55.4898807661874, 52.21883562632969, 51.233216285705566, 51.79745170048305, 54.82679680415562, 55.33382075173514, 53.587971210479736, 53.252321107046946, 46.67204005377633, 44.2989627293178, 44.085024220602854, 52.994317122868125, 54.171442713056294, 59.43724618639265, 54.85326944078718, 59.34894847869873, 27.576604638780864, 0.3876552257154669, 1.3392711409500666, 2.5402553251811435, 0.12709989558373178, 0.07348209912223475, 2.9457530634743825, 48.80385855266026, 28.667089666639054, 36.066528592790874, 34.62098019463675, 15.004641805376325, 16.324563298906597, 31.044923033033097, 44.371734687260215, 51.0075318472726, 40.46885163443429, 8.790241599082947, 0.1413837362612997, 0.04905777311484728, 0.038985521266502995, 0.0279595104179212, 0.016838185755269866, 0.025322304340079427, 0.050379284524491856, 0.066254934429058, 0.02700054196507803, 0.03912180502499853, 0.02082032457526241, 0.021984822981591736, 0.05058864989717092, 0.059601823932358196, 0.052149395791015456, 0.03461891771959407, 0.021917566590543305, 0.06759166877184596, 0.016921438609382937, 0.04674567521682807, 0.07729003764688969, 0.048012839364154, 0.037400012237152884, 0.04559514784653272, 0.033653613446014266, 0.09976306318172387, 0.009474358172155917, 0.033278617675283124, 0.08440371735819749, 0.1517754050769976, 0.08561777935496398, 18.26273897715977, 76.67134257725307, 63.62182658059256, 64.02832399095807, 50.33006164005825, 40.27175555910383, 20.112128836768015, 29.317225660596574, 36.784882000514436, 54.107891014644075, 36.012103353227886, 0.16068648334060395, 0.003045305875795228, 0.8500851190515927, 2.271597581250327, 3.346632203885487, 3.072513827255794, 1.459813375558172, 18.0694557258061, 74.81549263000488, 62.308429445539204, 70.34847491128104, 60.78882367270333, 62.00098555428641, 58.497015953063965, 57.81884050369263, 48.64260475976126, 46.3329610143389, 43.53600536073957, 46.058663504464285, 42.38688448497227, 43.490748269217356, 43.25305386951992, 45.38652951376778, 40.98027726582119, 43.23324108123779, 43.285158021109446, 45.571945667266846, 44.761341026851106, 46.424986430576865, 42.57835251944405, 41.1624937738691, 40.62680155890328, 42.84333944320679, 44.0815292767116, 48.7208171572004, 50.799891880580354, 52.33639914648873, 54.45010021754673, 54.54107992989676, 55.020925998687744, 57.08309228079659, 53.69136387961251, 45.979926518031526, 41.01730421611241, 39.95154782703945, 38.747074127197266, 39.51605558395386, 40.16556624003819, 45.62619720186506, 50.24071128027779, 51.32818078994751, 50.47707857404436, 56.26873213904244, 45.06933382579258, 41.2194481577192, 37.552334853581016, 48.25011839185442, 50.104394572121755, 54.551675932747976, 50.28613860266549, 55.37979350771223, 31.427014895847865, 35.32171644483294, 56.93639496394566, 47.16417053767613, 47.026630946568076, 38.69931221008301, 43.67350326265608, 38.53667572566441, 40.36664015906197, 39.12061970574515, 44.192300932747976, 44.10286372048514, 43.61476666586739, 41.77074950081961, 41.42903014591762, 46.748091561453684, 50.762187480926514, 49.63631527764456, 52.20398037774222, 52.60993930271694, 46.6605338369097, 39.547367640904014, 41.67950575692313, 39.25642919540405, 41.4388027872358, 42.58378601074219, 46.70876475742885, 46.936471121651785, 52.801539352961946, 53.26482786451067, 52.233246190207346, 53.60112067631313, 46.335934843335835, 39.45934438705444, 41.88799687794277, 41.55931581769671, 48.170613629477366, 54.02736834117344, 55.05029950823103, 56.89111007962908, 54.91266959054129, 54.31360633032662, 51.772875922066824, 57.15530490875244, 55.428232874189106, 55.5306111063276, 55.19897358758109, 48.45711217607771, 46.92020538875035, 46.54349490574428, 54.09090961728777, 56.79419313158308, 61.54288387298584, 57.98200157710484, 62.55289486476353, 32.86278370448521, 0.1137553509324789, 0.9257919852222715, 4.498245094503675, 0.30254636119518963, 0.15695025239671978, 2.3953780020986284, 50.76630776269095, 36.740212031773154, 29.992924077170237, 27.210703815732682, 16.694970028741018, 21.65347899709429, 37.64462430136544, 47.754218510219026, 56.89157560893467, 49.84101963043213, 13.359890290669032, 0.0979523246309587, 0.052984272063310654, 0.03884501023484128, 0.04253073442461235, 0.04367592850966113, 0.015244408776717526, 0.051319449075630734, 0.04734191072306462, 0.029156235844961235, 0.05060810010348048, 0.031194185239395926, 0.06762336314256702, 0.07938282963420663, 0.041591577497976165, 0.04535587943558182, 0.047388980697308264, 0.07726088099713836, 0.2625527743782316, 0.09885666253311293, 0.11236055434814521, 0.1807940136641264, 0.14086258065487656, 0.22278390478874954, 0.15545793675950595, 0.14869999938777514, 0.19009211473166943, 0.06366554980299302, 0.13142110513789312, 0.16313319919364794, 0.36327901801892687, 0.218001535694514, 23.35189492361886, 84.67736966269356, 71.36520481109619, 73.43956170763288, 55.11408049719674, 39.750275884355815, 26.73778510093689, 48.962881973811555, 47.572057587759836, 60.856957708086284, 39.6013308252607, 0.3225937326039587, 0.20031797673021043, 1.1566859441144126, 4.092203659670694, 4.272507241794041, 12.343285458428518, 4.125717427049365, 20.323145627975464, 76.59463446480888, 64.93120765686035, 71.8052898134504, 62.93676894051688, 64.49215793609619, 60.91013922010149, 60.49061393737793, 49.70949370520455, 49.04512432643345, 46.51915536608015, 49.79100997107369, 45.317648547036306, 46.66687754222325, 46.92981474740164, 48.22028977530343, 41.96866198948452, 45.36528887067522, 46.500516823359895, 47.79039083208357, 45.399498326437815, 48.78972939082554, 45.130151408059255, 44.24346399307251, 42.59112678255354, 45.42600222996303, 46.013899735042024, 52.11383792332241, 54.05464696884155, 55.653337138039724, 58.18539272035871, 57.20333085741316, 57.92196566717965, 59.550168309892925, 54.07626281465803, 47.39568451472691, 44.02594716208321, 41.74123007910592, 40.76040152141026, 39.66624437059675, 43.12987273080008, 47.791023118155344, 53.98734324319022, 54.83099351610456, 53.390541621616904, 59.0778158732823, 48.1436059815543, 43.066602434430806, 42.01174776894705, 51.521031515938894, 50.83116224833897, 56.39189938136509, 53.706333773476736, 56.665637561253135, 33.22605637141636, 38.59472097669329, 58.25800486973354, 49.78210585457938, 51.10512971878052, 40.74228409358433, 46.93084308079311, 41.938961914607454, 42.66932528359549, 42.035812854766846, 46.81480121612549, 47.084898539951865, 46.90502010072981, 44.2928900037493, 43.933320726667134, 49.77157585961478, 52.232728549412315, 51.54009737287249, 54.84952088764736, 55.603087765829905, 48.495956080300466, 42.261545930589946, 43.615489278520855, 40.892174107687815, 43.066908155168804, 44.45636722019741, 49.87629563467843, 49.10865865434919, 55.16465990883963, 55.49224662780762, 55.031191962105886, 55.03485713686262, 48.72643824986049, 41.10965619768415, 44.506717341286794, 43.120847020830425, 50.57255029678345, 58.295865603855674, 57.445781299046104, 59.30270821707589, 55.915600367954795, 56.22014686039516, 54.087199279240195, 58.1805602482387, 58.16098369870867, 58.97252982003348, 57.627320357731406, 51.586434909275596, 47.972610814230784, 49.35261338097708, 58.68099730355399, 60.1712121963501, 63.91420677730015, 61.2309444972447, 61.676678385053364, 33.90437773295811, 1.3439832138163703, 9.420048901012965, 7.358489717755999, 0.28883251707468716, 0.1712424119136163, 4.023406505584717, 58.902186257498606, 43.12922307423183, 50.21018436976841, 46.698012420109336, 21.46194495473589, 26.08522765977042, 42.66694205147879, 57.66229411533901, 63.36321462903704, 58.4092879976545, 15.80139000075204, 0.2468928104000432, 0.12539799404995783, 0.16760406643152237, 0.11130777333996125, 0.1647923665919474, 0.16101507070873464, 0.22047460584768228, 0.18304413078086718, 0.1747942441808326, 0.15202832221984863, 0.12070956134370395, 0.19263940304517746, 0.19807053304144315, 0.14206164702773094, 0.10330893112612621, 0.17091022830988678], [0.03409918364403503, 0.017424107529222965, 0.0417163668732558, 0.010176173727294164, 0.023368062418220297, 0.06781249799366508, 0.02536327767718051, 0.07048298112515892, 0.03948280601097005, 0.011182921223475464, 0.03686595768002527, 0.033668222304965766, 0.08561007119715214, 0.06365122592874936, 0.07098192149507147, 35.090859072549, 65.30642427716936, 55.68543086733137, 52.87891796657017, 27.39475985935756, 12.685265370777675, 25.44115744318281, 48.83871419089181, 33.05883755002703, 58.79237692696707, 13.250937325613839, 0.2658890224993229, 0.1360061155366046, 0.7100710464375359, 0.3962043326880251, 2.2248828879424503, 3.634833927665438, 0.5444136698331151, 62.76521791730608, 61.77327919006348, 66.19406359536308, 61.84685366494315, 62.52041898454939, 58.41990484510149, 56.45231744221279, 56.59344230379377, 53.286638259887695, 49.54418911252703, 43.582711151668, 42.14693539483206, 43.15511901038033, 41.7740603174482, 41.13787283216204, 41.70123277391706, 41.793932165418354, 39.55292967387608, 41.41897957665579, 42.92744738715035, 43.16016687665667, 44.77394853319441, 41.99909509931292, 40.18434027263096, 38.42951018469674, 40.097640650612966, 41.34415790012905, 44.746933937072754, 47.24079874583653, 47.629157883780344, 48.0601372718811, 49.99168784277779, 50.9353609085083, 54.042352131434846, 50.91435303006853, 44.48631048202515, 40.64650665010725, 36.820178849356516, 37.96780238832746, 39.50916297095162, 38.2006573677063, 43.32360240391323, 47.42446742738996, 49.919273717062815, 49.465413911002024, 48.714365754808696, 38.20268971579415, 37.166984285627095, 38.398747035435264, 49.96912356785366, 47.781358173915315, 52.30938107626778, 47.27209343229021, 51.72743122918265, 32.02667222704206, 34.53238024030413, 54.418159348624094, 45.671707902635845, 45.80116673878261, 36.88594702311924, 41.52825389589582, 37.332528591156006, 38.00497872488839, 35.65041487557547, 36.20845249720982, 36.25186831610543, 38.88353674752371, 37.78320264816284, 38.28370918546404, 43.51132883344378, 49.55084548677717, 48.942072119031636, 51.621095997946604, 48.85885354450771, 44.95016527175903, 38.569943700517925, 38.09373153959002, 37.18786014829363, 37.89940432139805, 41.09002753666469, 47.29507807322911, 46.01265948159354, 50.806530884334016, 51.000236238752095, 51.0150602204459, 51.24727943965367, 40.95745938164847, 37.185341426304404, 39.88469573429653, 39.78547545841762, 46.03690869467599, 51.65320709773472, 52.781559807913645, 51.6949588230678, 51.48753077643258, 52.783866609845845, 53.540077277592246, 53.76380579812186, 53.89532824925014, 50.37936953135899, 43.275079659053254, 42.43214505059378, 46.04820646558489, 46.24317986624581, 51.322163649967735, 54.42306825092861, 56.68915721348354, 55.910542079380576, 54.1963346345084, 54.832633290972026, 5.165073701313563, 0.6814921285424913, 3.2512831602777754, 0.6488233815346445, 0.20734677171068533, 0.0648501565946, 26.465156895773752, 44.551686082567485, 34.39654295785086, 29.99700266974313, 61.607800892421174, 28.11465403011867, 21.642915998186382, 46.85340540749686, 39.14265591757638, 54.12107522147042, 23.403325489589147, 1.1887974781649453, 0.08651919277118784, 0.026643300063109825, 0.016964495048991272, 0.01725311161551092, 0.019701092936364666, 0.0857856489185776, 0.02930864498817495, 0.07555203126477343, 0.02134016721642443, 0.023644119301544766, 0.05917939517114844, 0.03454806170027171, 0.07219489783580814, 0.05160770092957786, 0.031781206240079234, 0.07264480047992297, 0.02451837944265987, 0.0363127548646714, 0.01467648514413408, 0.0331730036996305, 0.02765976757343326, 0.05877006213579859, 0.019861116938825165, 0.07463334913232497, 0.023531373922846148, 0.0557763961675976, 0.040711476866688044, 0.054831746499985456, 0.04180562136960881, 0.035610522010496685, 43.724968569619314, 71.4297605242048, 62.22472449711391, 58.84870597294399, 37.886991364615305, 21.436278309140885, 22.124919482639857, 42.299139159066335, 36.03145061220442, 67.81999765123639, 14.965004069464547, 0.4338430772934641, 0.028068257529022436, 1.273673523749624, 2.6030709488051276, 4.07746479340962, 2.060748415333884, 1.2071981536490577, 65.68125179835728, 61.85526098523821, 65.33972699301583, 64.05731882367814, 63.13155473981585, 59.92870616912842, 58.18611880711147, 58.08644689832415, 56.52208430426461, 51.321882247924805, 44.01193959372384, 43.600269249507356, 44.00667633329119, 45.47739110674177, 43.21341439655849, 44.25767305919102, 43.49505615234375, 41.62050860268729, 44.37240866252354, 45.7851858820234, 44.60858835492815, 46.754456111363, 43.96184655598232, 42.885758195604595, 41.25070462908064, 41.56257104873657, 43.34198038918631, 47.241028036390034, 49.28535829271589, 51.285650866372244, 51.61022554125105, 52.44770581381661, 53.7075114931379, 54.50499793461391, 53.100905963352744, 46.97183050428118, 41.598767689296174, 40.233530044555664, 39.174079145704, 41.35976702826363, 40.171267236982075, 45.33231272016253, 48.32994277136666, 49.69851207733154, 50.30906765801566, 50.776834283556255, 41.72895956039429, 39.42512450899397, 40.01109388896397, 52.25738770621163, 51.24253382001604, 54.43041249683925, 48.947755745479036, 54.47473158155169, 34.571033069065635, 36.77969169616699, 58.0081650188991, 47.996655055454795, 47.50688348497663, 38.62956966672625, 42.156989438193186, 40.26519298553467, 39.72498096738543, 37.97050871167864, 37.96570750645229, 39.63602665492466, 41.10840204783848, 38.11098739079067, 39.68137059892927, 45.20219727924892, 51.57416091646467, 51.810719285692485, 53.05999149594988, 51.298480715070454, 46.860040937151226, 40.51223618643624, 39.31067030770438, 38.942210810525076, 38.608728545052664, 43.96721403939383, 50.15890319006783, 48.42773519243513, 51.70493643624442, 51.8519846371242, 54.20990099225725, 53.95388766697475, 43.600345679691856, 39.00666230065482, 41.924815382276265, 40.24827759606497, 47.77027232306344, 53.88570499420166, 55.98655537196568, 52.96781669344221, 53.122560024261475, 52.54574489593506, 54.47959879466465, 55.654872689928325, 57.0765505518232, 51.308694566999165, 45.88668516704014, 44.52497373308454, 47.496475083487375, 48.769847120557515, 54.190102100372314, 58.04911075319563, 59.36352579934256, 58.56788757869175, 57.20246580668858, 59.10566425323486, 6.258971163204738, 0.5951645065631185, 4.1006483265331815, 2.2029804289340973, 0.08790414381240096, 0.07155516144952603, 27.253159046173096, 52.33117757524763, 35.44308410372053, 31.622637953077042, 57.60550301415579, 33.27326243264334, 27.432825565338135, 54.03019973209926, 45.372049467904226, 61.147322927202495, 30.628976072583878, 1.2554588211434228, 0.03810410427727869, 0.02110689875137593, 0.056480834260582924, 0.015585313251774226, 0.041905026749840806, 0.052510915856276236, 0.05000185959839395, 0.11062311793544463, 0.058338032104074955, 0.07332199878458466, 0.054722566822809834, 0.043795198002564054, 0.01908693223127297, 0.05912284606269427, 0.037664837669581175, 0.19215610969279492, 0.10591065830418042, 0.22040919507188456, 0.1092272831925324, 0.08760057403040783, 0.18428006874663488, 0.1341025126831872, 0.12399128239069666, 0.2142311880098922, 0.12135623235787664, 0.18913996725210122, 0.10090670681425504, 0.13100542101476872, 0.19519521375851973, 0.2363137709242957, 52.13932738985334, 80.86973599025181, 69.309371812003, 69.47136211395264, 40.37940052577427, 18.99280183655875, 38.69944075175694, 65.79625838143485, 45.78293466567993, 75.83195849827358, 16.606714010238647, 0.44939610415271347, 0.14018183361206735, 1.7526017789329802, 1.8126054448740823, 5.647231783185687, 7.967283061572483, 0.965887976544244, 72.71610137394497, 62.81712096078055, 71.31198855808803, 64.89856501988002, 65.34065110342843, 62.081709725516184, 61.49389212472098, 61.1540835244315, 59.601105553763254, 55.390903677259175, 47.07799203055245, 46.70456804547991, 46.794595854622976, 47.13763536725725, 45.10031931740897, 47.09339966092791, 46.75446653366089, 43.17036683218819, 45.93563870021275, 47.73596906661987, 46.780626501355854, 49.90916756221226, 46.4530918938773, 45.86221708570208, 43.668045452662874, 43.64079809188843, 45.98799685069493, 48.975357464381624, 52.835575103759766, 52.42349134172712, 53.838655267442974, 54.44421509334019, 57.045846462249756, 57.47880956104824, 54.50083596365792, 49.18999079295567, 44.81810780933925, 41.950454235076904, 41.807908466884065, 43.85569545200893, 42.245485169546946, 47.85708311625889, 51.854100363595144, 53.32390144893101, 54.00845534460885, 53.76087365831648, 43.50792421613421, 41.71245411464146, 43.71709278651646, 54.295030321393696, 53.51658889225551, 56.139860425676616, 50.37226847239903, 54.75748157501221, 37.108508246285574, 40.07728590284075, 59.75277083260672, 51.64551544189453, 49.95313228879656, 40.902599879673545, 44.93487228666033, 43.03937591825213, 41.809496130262104, 40.193477153778076, 39.33976241520473, 41.648367404937744, 43.14333486557007, 40.57172318867275, 41.770693915230886, 47.801382882254465, 53.17558172770909, 54.23724562781197, 55.107184410095215, 53.94451454707554, 49.548080103737966, 43.87515735626221, 41.183814321245464, 41.61238268443516, 40.00888783591134, 45.60688468388149, 53.80694368907383, 51.02449240003313, 55.012602056775776, 54.8217385155814, 55.64638546534947, 56.198531014578684, 45.20249605178833, 40.78472369057791, 43.242176464625764, 43.51502180099487, 49.558773381369456, 56.25361980710711, 59.06626101902553, 55.24962248120989, 54.89918661117554, 55.66464185714722, 56.31832490648542, 59.616377694266184, 59.03811386653355, 54.999796526772634, 49.03031424113682, 47.03259597505842, 51.13051496233259, 51.494201047079905, 55.41513204574585, 59.98477118355887, 60.74625205993652, 59.83034746987479, 57.050817898341585, 61.88829272133963, 6.447720280715397, 1.8295436331204005, 11.278738055910383, 1.1128537761313575, 0.4109455331095627, 0.1417224473719086, 32.05774457114083, 57.63507802145821, 49.50171824863979, 41.930433000837056, 67.31562096732003, 36.13178607395717, 33.22746685573033, 61.108468600681846, 52.6777537209647, 69.48584910801479, 35.59493350982666, 1.6527360805443354, 0.14472282065876893, 0.12807148987693445, 0.1782404285456453, 0.11400868876704148, 0.1446475304130997, 0.24871687537857465, 0.07911203987896442, 0.24593458324670792, 0.09179107059857675, 0.16510059790951864, 0.14759340376726218, 0.17402203061750957, 0.20967183980558599, 0.1617030780762434, 0.1513458245566913], [0.1056261146441102, 0.04144725649218474, 0.06505880611283438, 0.06723824702203274, 0.03384273811908705, 0.02178425481542945, 0.04125241855425494, 0.05261584111888494, 0.053415318219257255, 0.032944123659815104, 0.04020032286643982, 0.019329735809671025, 0.15700518659182958, 0.04919733419748289, 2.2516223788261414, 53.71253851481846, 61.643139430454795, 57.2389612197876, 49.221236842019216, 30.449698652539933, 22.33476029123579, 31.88676677431379, 36.68387256349836, 36.57342747279576, 57.90789903913225, 1.8955795296600886, 0.08140983086611543, 0.030084780483905758, 0.4549749105104378, 2.30807432106563, 6.6776604907853265, 1.9431825067315782, 27.105551515306743, 74.32417855943952, 55.188544341496055, 63.16211291721889, 59.51620551518032, 64.00218486785889, 59.0279347555978, 59.857528822762625, 57.35331467219761, 55.213526589529856, 52.6812173979623, 48.364652497427805, 43.309528827667236, 42.363462107522146, 41.122298445020405, 42.84813370023455, 41.34480060849871, 42.984561579568044, 38.1242549760001, 40.43069560187203, 43.54625047956194, 42.630662032536094, 43.695299761635916, 42.352407523563926, 40.25397859300886, 40.24380990437099, 41.97501959119524, 42.782084124428884, 42.3017794745309, 44.57183238438198, 45.231852190835134, 45.36275625228882, 48.970379080091206, 52.90900714056832, 53.62163175855364, 50.989334515162874, 43.927953243255615, 39.105069637298584, 37.50399971008301, 37.31826046534947, 38.683949742998394, 39.349542004721506, 43.09593425478254, 46.7927302633013, 46.879231861659456, 45.98589154652187, 41.662875243595664, 36.725540910448345, 37.883861201150076, 39.371922152382986, 51.566583905901226, 46.705026626586914, 52.53389474323818, 48.40997907093593, 53.628281184605186, 35.88148764201573, 33.5942622593471, 55.04056160790579, 45.62517581667219, 45.12159122739519, 37.798314980098176, 41.41458831514631, 39.77174234390259, 39.12790489196777, 36.37288856506348, 38.1523882320949, 36.49554511478969, 37.98638881955828, 38.19299350466047, 38.988763741084504, 40.29315601076399, 49.21650511877877, 49.39481673921858, 49.88874680655343, 48.608992849077495, 43.179482868739534, 38.12205239704677, 37.27771077837263, 37.65443515777588, 38.284845215933665, 41.28281225476946, 45.69769416536604, 45.58599145071847, 49.229915142059326, 51.13449975422451, 50.556048325129915, 44.23511225836617, 40.04039791652134, 39.465382371629985, 39.671188013894216, 38.85504565920149, 43.10152408054897, 52.61868013654436, 51.57078756604876, 52.22018705095564, 51.564381326947895, 52.464989457811626, 53.5361967086792, 52.20062787192208, 48.295722893306184, 41.867593492780415, 40.35022503989083, 44.11520372118269, 43.99773400170462, 51.41062464032854, 53.50538144792829, 57.9923335484096, 51.85293306623186, 57.67858416693551, 53.774926389966694, 54.56023958751133, 29.231703758239746, 0.4427989252976009, 3.37053986958095, 1.0908413401671817, 0.017234986248825277, 0.04307150308574949, 3.961164108344487, 52.278607504708425, 36.14620706013271, 25.179776634488785, 26.044075216565812, 16.900457790919713, 25.301729679107666, 35.67689446040562, 48.97701460974557, 47.097881249019075, 35.72504547664097, 2.396143389599664, 0.06486171204596758, 0.03343607172636049, 0.033695051579603126, 0.05012236063235572, 0.013551721748496805, 0.05581311169745667, 0.032533925492316484, 0.01844294821577413, 0.04772988686870251, 0.015938551797132407, 0.07708989695778914, 0.04471859595339213, 0.02139343391172588, 0.06708658766001463, 0.05000110642452325, 0.04177346220239997, 0.05503892020455428, 0.034257380690957816, 0.05077509774959513, 0.018349960080481002, 0.0364425823624645, 0.08154741062649659, 0.04616516815232379, 0.10873134873275246, 0.010302413471176155, 0.05259325608078923, 0.030417679942079952, 0.17811143903860024, 0.01958173353757177, 4.049724110535212, 65.25798838479179, 68.33370576586042, 65.0801214490618, 56.01918411254883, 35.21789993558611, 20.7585631779262, 23.807241644178117, 39.89602477209908, 44.70750985826765, 65.35979339054653, 1.909897812775203, 0.11356360372155905, 0.23911503489528382, 1.2940407565661838, 5.660231862749372, 6.91273672240121, 1.3730528482369013, 31.031169073922293, 77.56866768428257, 57.01194967542376, 65.67391450064522, 62.18382740020752, 64.97760077885219, 59.428408077784944, 63.18825898851667, 59.899607113429475, 58.64301150185721, 53.24837105614798, 50.12599304744175, 44.285306044987266, 44.12912791115897, 42.44293907710484, 45.83584172385079, 44.06640304837908, 44.01388508932931, 41.191627570560996, 42.275685514722554, 45.19232388905117, 45.24204172406878, 44.73081759044102, 44.2072673525129, 42.70611946923392, 42.67553349903652, 44.025846413203645, 45.27793264389038, 45.97776215417044, 48.04312113353184, 48.18035152980259, 47.84245368412563, 49.35671976634434, 54.96575730187552, 55.30209527696882, 53.02971472058977, 44.9632556779044, 40.707247802189414, 38.8900055204119, 38.32041999271938, 40.33948312486921, 41.1681843485151, 44.48164129257202, 46.52686786651611, 49.96167509896414, 49.66908645629883, 44.40346016202654, 37.93260628836495, 38.939226559230256, 42.7128974369594, 52.9917254447937, 48.633106572287424, 54.11203908920288, 50.19071551731655, 56.20884908948626, 37.556125095912385, 36.378624303000315, 55.81521279471261, 47.934270654405864, 47.86045299257551, 40.09468766621181, 42.135446548461914, 41.21350744792393, 40.62725666591099, 38.3283235686166, 40.42813866479056, 38.33836371558053, 40.32946034840175, 39.9214517048427, 42.08127491814749, 43.02591725758144, 50.7077830859593, 49.968880380902974, 51.63342905044556, 50.83031109401158, 47.42816039494106, 39.43764516285488, 39.12762001582554, 38.85635192053658, 40.182610171181814, 43.0828195299421, 49.30653640202114, 48.14306402206421, 51.427682467869346, 53.31776966367449, 54.38484968457903, 45.59024027415684, 41.12920495441982, 41.3219757761274, 41.883233887808665, 41.64218003409249, 45.56531361171177, 54.32405642100743, 53.73876101630074, 53.35345213753836, 54.13214717592512, 56.61744832992554, 55.52803679874965, 54.89574030467442, 50.614677224840435, 44.09765951974051, 41.38178586959839, 46.078729901994976, 45.476880414145334, 54.03118290219988, 56.238587379455566, 61.18341881888253, 55.19590943200247, 58.92682456970215, 57.201562540871755, 56.97867475237165, 31.36670105797904, 0.15359320039195673, 1.6780332773923874, 3.7861068504197255, 0.2798312343657017, 0.19782760393406662, 3.7819587758609226, 55.658447538103374, 40.52822746549334, 22.552621058055333, 30.362318107060023, 19.90875506401062, 30.787124020712717, 42.12090744291033, 54.847648348127095, 54.28890895843506, 44.883170740945, 5.044546340193067, 0.08711875309901577, 0.03876757581851312, 0.02696391294843384, 0.09734691533127002, 0.011943050078116357, 0.043616750078009706, 0.006642280229633408, 0.08514381585908787, 0.049182481065924676, 0.05631930221404348, 0.023575945191883614, 0.08391682777021613, 0.010444089038563626, 0.06415741305266108, 0.015061820092211877, 0.2616047795329775, 0.16556942489530357, 0.24389487983925, 0.10050447804055043, 0.1806857194751501, 0.08840699932937111, 0.08801654992359025, 0.09803925853754793, 0.21218963898718357, 0.11021565087139606, 0.21321823022195271, 0.21130857483616897, 0.3526751441614968, 0.2717267578201634, 5.1828515359333585, 75.12671634129116, 75.90681838989258, 72.49457195826939, 64.76358931405204, 42.487706320626394, 31.153540747506277, 44.3766644341605, 52.364212785448345, 51.234261989593506, 70.2505886895316, 2.847503364086151, 0.19212748908570834, 0.3310075125523976, 3.210925200155803, 6.668522306850978, 15.242798260280065, 4.654005033629281, 31.95251410348075, 80.361544745309, 57.9155455316816, 69.7520832334246, 63.4045147214617, 67.68165901729039, 60.74209703717913, 65.22071129935128, 64.60135582515171, 60.682849747794016, 55.80127123423985, 53.2322929246085, 46.95025634765625, 46.40131739207676, 45.41115045547485, 47.477110454014365, 45.578334535871235, 47.72099917275565, 42.82082380567278, 45.1094457762582, 48.283771991729736, 47.33440487725394, 49.44103615624564, 47.41240882873535, 44.66421215874808, 45.25204365594046, 46.27656943457467, 48.888397284916465, 46.84593261991228, 49.56700699669974, 50.301598344530376, 49.47912270682198, 52.247351033346995, 55.917625767844065, 57.589108739580425, 55.45400374276297, 47.3736378805978, 43.449517658778596, 41.011109897068565, 41.42861325400216, 43.80401822498867, 43.04590722492763, 47.02820471354893, 51.16604110172817, 50.9195294380188, 51.55650554384504, 45.95175504684448, 40.816959857940674, 41.494169507707866, 45.8851774079459, 56.622805391039165, 50.95227629797799, 55.265645027160645, 53.060724530901226, 56.476521492004395, 39.926443985530305, 37.95116145270211, 58.86192839486258, 50.69220869881766, 49.467703342437744, 43.05032280513218, 45.76157242911202, 44.09072869164603, 42.24134751728603, 40.07330111094883, 41.5766897882734, 39.935320309230256, 42.0660514150347, 42.068038599831716, 44.806796142033164, 43.84828519821167, 52.94377245221819, 53.998557635716026, 53.33650895527431, 53.78664452689034, 50.482397420065745, 41.11995342799595, 40.17288964135306, 40.929381711142405, 42.24857364382063, 45.414082595280235, 51.887066091809956, 49.035351685115266, 53.9389386177063, 55.64048991884504, 56.782217911311555, 47.77031748635428, 43.29029621396746, 44.546926566532676, 44.954730238233296, 43.04677922385079, 48.39604098456246, 56.50258418491909, 56.89455986022949, 56.84389359610421, 56.24143614087786, 56.643420696258545, 59.136305809020996, 56.51781811032976, 53.24915967668806, 46.47017404011318, 43.20209578105381, 47.61249262945992, 48.41901172910418, 54.85582290376936, 59.80284649985177, 62.79228809901646, 58.499218532017295, 59.05865274156843, 58.51722131456648, 58.52108451298305, 32.50580610547747, 0.7188584006258419, 10.141164217676435, 6.210635585444314, 0.13906069020075457, 0.2620231370840754, 5.161411132131304, 61.42469501495361, 48.13022027696882, 35.45148794991629, 32.58965349197388, 24.033287388937815, 35.48541252953665, 49.42084469114031, 62.09487656184605, 60.56912163325718, 51.70360238211495, 6.989387946469443, 0.27782752045563286, 0.1608478253973382, 0.15690504839377745, 0.14740660307662828, 0.13179415012044565, 0.21189655257122858, 0.1701103983713048, 0.2177175280771085, 0.11998628372592585, 0.08149837290069886, 0.12143715444420065, 0.10457427001425199, 0.16938581796629087, 0.22687916218170098, 0.09616426950586693], [0.07236080643321786, 0.05071351730397769, 0.0319412183681769, 0.03360825677269271, 0.04799261223524809, 0.03647991535919053, 0.08821363041975669, 0.03226632824433701, 0.019861188185002123, 0.06542482147259371, 0.0380573633925191, 0.03777897065239293, 0.11830015134598527, 0.09820141483630453, 8.076046688216072, 67.71113327571324, 53.324881144932334, 58.329738071986604, 39.99501575742449, 21.887287616729736, 18.31339134488787, 49.07991395677839, 35.91907392229353, 56.46342413766043, 40.42632171085903, 0.2931085361966065, 0.034567457623779774, 0.4223441614636353, 0.8297923079558781, 9.39171848978315, 4.4361260277884345, 0.41363019762294634, 66.0970458984375, 59.14162812914167, 60.131232261657715, 55.932383741651265, 61.64785725729806, 56.49531636919294, 60.01834487915039, 54.829701151166645, 59.20392567770821, 54.58638218470982, 55.51564121246338, 49.86177042552403, 48.37104484013149, 43.13557720184326, 41.82460846219744, 38.73719031470162, 39.615251541137695, 40.602736473083496, 41.347670214516775, 39.44957174573626, 39.4240996497018, 39.57203027180263, 42.22094413212368, 39.84495898655483, 42.00142274584089, 38.490873200552805, 40.371281555720735, 41.119185652051655, 41.55118989944458, 40.7468386377607, 41.93949692589896, 45.853055885859895, 50.07827281951904, 52.07705763408116, 52.45024538040161, 47.24340432030814, 41.198315211704795, 38.154319831303184, 38.34843512943813, 36.4140635899135, 37.67318834577288, 38.60056093760899, 40.104929310934885, 44.17772708620344, 45.46740307126726, 43.00021587099348, 37.79746729987008, 35.68100431987217, 38.08539022718157, 39.08219616753714, 50.924097878592356, 49.5275342805045, 53.242218426295686, 45.92865923472813, 55.75161940710885, 38.52432182856968, 35.71663815634591, 55.720018999917166, 47.41010897500174, 44.912606784275596, 38.413848945072715, 41.89583444595337, 39.13559307370867, 42.08130965914045, 38.822938033512656, 37.41915873118809, 36.720955099378315, 37.729927335466655, 35.57961968013218, 36.68519272123064, 36.556265422276084, 47.014898913247244, 50.20837436403547, 50.64561407906668, 47.079576219831196, 42.91842515127999, 38.302715982709614, 36.679304122924805, 36.40006644385201, 38.30222266060965, 39.533426080431255, 42.783911500658306, 45.53845535005842, 44.88722154072353, 44.16519948414394, 42.64676100867135, 38.28630781173706, 38.9651711327689, 39.16492141996111, 38.86612456185477, 37.265367303575786, 40.733195849827354, 51.393174239567344, 53.84986965996878, 53.456785746983115, 52.74433135986328, 52.191244329724995, 49.9921429497855, 45.00116852351597, 39.91418736321585, 39.86489336831229, 42.630338941301616, 47.022538457598, 51.97619758333479, 51.35879455293928, 54.82544885362898, 52.066430364336284, 58.168783051627024, 57.49577011380877, 50.21828596932547, 61.72347450256348, 47.69803885051182, 4.396190387862069, 2.7438764103821347, 5.477774773325239, 0.1455042894397463, 0.08750821184366941, 0.05493230538974915, 28.33800561087472, 55.59105348587036, 37.399842739105225, 25.619343996047974, 23.832423652921403, 13.597760132380895, 27.232493366513932, 42.541200501578196, 44.696076597486226, 51.68603733607701, 15.881311655044556, 0.07783057221344539, 0.01233997185980635, 0.032512429502925703, 0.05391577850761158, 0.04214020698730435, 0.024133409207154597, 0.012991404493472405, 0.02823755710518786, 0.05005273615409221, 0.03079085045361093, 0.029146651537822824, 0.03381357129131045, 0.02248392959258386, 0.01663891868000584, 0.01053301359726382, 0.055630202405154705, 0.04599987702178104, 0.022445090248116424, 0.0604683267218726, 0.08601139751928193, 0.016511963081679175, 0.060123800566153865, 0.04339475038328341, 0.02686481290896024, 0.02093031001277268, 0.045453741148646386, 0.0646804685571364, 0.06968047097325325, 0.20198284382266657, 11.149130702018738, 79.75308404650006, 58.62865652356829, 65.1154808316912, 46.09689596721104, 28.72513144356864, 16.103534153529576, 40.51324020113264, 41.39984423773629, 61.24104717799595, 43.11746324811663, 0.08880418658788715, 0.030530533886381557, 0.3022630863956043, 1.693593225308827, 5.674932513918195, 0.6390893895711217, 1.3064739065510886, 68.10487379346574, 61.47300583975655, 61.07051059177944, 58.14033365249634, 62.72494615827288, 58.83801964351109, 59.733239446367534, 55.794656549181255, 60.214471680777415, 57.5311781338283, 57.172724042619976, 51.066615853990825, 48.79211957114083, 44.957311494009836, 44.415494441986084, 41.138008322034565, 42.803866727011545, 42.00655746459961, 43.52854299545288, 42.52322898592268, 41.45176465170724, 41.47266483306885, 43.11661556788853, 41.39574827466692, 43.80198587690081, 41.448096002851216, 43.07945660182408, 43.43861940928868, 45.01752805709839, 42.716802324567524, 42.38141972678048, 47.776230403355186, 53.649942193712505, 53.984640393938335, 53.74549382073538, 49.44274193899972, 43.413157735552105, 39.390126432691304, 39.86329180853707, 37.90766225542341, 40.19402606146676, 41.219548906598774, 42.8604667527335, 45.47386837005615, 48.48697205952236, 44.68747820172991, 40.23907470703125, 38.33683511189052, 39.961653981889995, 42.117492403302876, 53.18013974598476, 50.36664390563965, 53.46337958744594, 47.61568185261318, 58.78191293988909, 39.14754050118582, 36.01707131522042, 56.743123871939524, 48.74125180925642, 46.62888479232788, 40.38622713088989, 43.92615018572126, 41.35928412846157, 42.995967047555105, 40.19335208620344, 39.58255679266793, 38.100752694266184, 39.98697321755545, 37.82482583182198, 40.14652817589896, 38.889883926936555, 49.678258078438894, 52.95476450238909, 52.733558177948, 49.357727255140034, 43.63634429659162, 40.49058212552752, 38.69084235600063, 38.46081876754761, 39.082946572984966, 41.620018754686626, 44.7669551713126, 48.27107415880476, 47.13953569957188, 46.40786954334804, 45.12377643585205, 40.91248369216919, 41.321982724326, 40.15112440926688, 41.68893793651036, 39.55882174628121, 42.17816407339913, 52.71322080067226, 55.09277037211827, 54.81178174700056, 54.49557270322527, 53.92412158421108, 52.57313469478062, 46.76285648345947, 43.50972727366856, 41.4572502544948, 45.786752700805664, 50.0797632081168, 53.475316592625205, 54.184477533612935, 57.51821974345616, 55.313573701041086, 58.208564962659565, 59.07345935276577, 53.252988134111675, 61.8925450188773, 52.24269226619175, 5.573931327887943, 1.435831993818283, 2.0049239822796414, 1.0602693749325616, 0.09457693860999175, 0.06800614510263715, 30.00456578390939, 61.04353073665074, 35.248815945216585, 26.47969773837498, 25.963340623038157, 17.804732833589824, 32.280378750392366, 47.865129130227224, 49.34154142652239, 60.207474844796316, 22.341093574251445, 0.0612686180642673, 0.010280904759253775, 0.05427753606012889, 0.04141332634857722, 0.05132077561159219, 0.04319548161168184, 0.015509709183658873, 0.018083290729139532, 0.01196841202077589, 0.0106639666150191, 0.033635788331074376, 0.10799098560320479, 0.06678592879325151, 0.017347305846799697, 0.03642870971400823, 0.15180037516568387, 0.1052811745820301, 0.11423761291163308, 0.2400901982826846, 0.1928269365536315, 0.10379266552627087, 0.1664707636726754, 0.09605196517493043, 0.16646833451730864, 0.12995502166450024, 0.1230745001563004, 0.12154527221407209, 0.3216678580003125, 0.33508909067937304, 15.369432653699603, 88.37079579489571, 65.69020107814244, 75.5251191002982, 54.499821526663645, 32.12300205230713, 26.684164115360804, 67.65797955649239, 50.46333851133074, 70.35390840257917, 48.43550327845982, 0.8146941438317299, 0.19619728784476007, 0.5120361500552723, 2.0599771652902876, 22.575555324554443, 16.190919910158428, 1.0011172975812639, 73.79462160382951, 63.84348801204136, 67.25289957863944, 61.240262031555176, 66.69759259905133, 59.57061685834612, 63.96444225311279, 56.407637051173616, 64.24018846239362, 58.59026772635323, 59.880305017743794, 52.40377582822527, 51.566448416028706, 47.26112222671509, 47.74484191622053, 42.40590865271432, 44.29316445759365, 44.55092178072248, 45.4064291545323, 44.99373047692435, 44.39944410324097, 42.30718169893537, 45.586189474378315, 44.04023265838623, 46.71986103057861, 43.40329129355294, 45.2359551021031, 45.82410274233137, 45.21154260635376, 44.23228434153965, 43.591736861637656, 51.43129205703735, 55.084741728646414, 55.83899647848946, 57.30789777210781, 50.3670642716544, 45.55377612795149, 41.370258808135986, 42.26153898239136, 41.014000347682405, 42.46351964133126, 43.412706102643696, 44.56037480490548, 47.255230154309956, 50.19286251068115, 47.385383810315815, 43.32537766865322, 40.59359264373779, 42.34661620003836, 43.0488497870309, 57.113282203674316, 54.45230279650007, 57.382858412606375, 51.59234087807791, 60.886140142168315, 41.537352561950684, 40.553445952279226, 58.437428201947895, 50.811537061418804, 48.29202645165579, 42.18474054336548, 46.86290012087141, 44.66326372964041, 45.59185573032924, 42.76517915725708, 41.589814935411724, 41.257030963897705, 42.7169760295323, 39.92426919937134, 42.38752371924264, 40.02739436285836, 51.765253748212544, 54.6254414830889, 55.64678151266915, 52.66316597802298, 45.42939642497471, 43.22350665501186, 40.9960218838283, 39.43699550628662, 42.97096742902483, 44.06973123550415, 48.218420709882466, 49.75358349936349, 48.58373267310006, 48.63139731543404, 47.47129828589303, 43.43333183016096, 43.332002776009695, 42.67902496882847, 43.590955189296174, 41.26813071114676, 44.05938189370291, 56.612035683223176, 59.29977607727051, 58.687271526881624, 56.6718874658857, 57.32518836430141, 55.10038907187325, 49.64864138194493, 45.857704230717246, 43.73883022580828, 49.03166913986206, 53.10139581135341, 55.52954455784389, 56.54628487995693, 60.33863598959786, 56.78374651500157, 61.0344911302839, 59.07238933018276, 56.79697241101946, 62.67812919616699, 52.85219866888863, 6.306693996701922, 6.692901364394596, 15.917197363717214, 0.5771509217364448, 0.219755033031106, 0.4246294674064432, 36.276878356933594, 67.79435185023716, 51.40698031016758, 36.60478121893746, 33.42322540283203, 20.898051738739014, 39.88713107790266, 56.94989531380789, 58.791091510227744, 65.49651309422084, 25.507420676095144, 0.23033313612852777, 0.06683736853301525, 0.09330746744360242, 0.09803431201726198, 0.11154650910092251, 0.1061085666130696, 0.11101186421832868, 0.10918370088828461, 0.10453083698770829, 0.12568760636661733, 0.10510594291346413, 0.22099618214581693, 0.20028989895113877, 0.11875977739691734, 0.1168250704982451], [0.04962377988600305, 0.035061264876276255, 0.015021296284560646, 0.048502090254000256, 0.012751196311520678, 0.021444251095610004, 0.04771132215059229, 0.0909497414582542, 0.06282309429453951, 0.05636565972651754, 0.039608161962990246, 0.07033565081655979, 0.07128846326044627, 0.01173506976504411, 22.70595564161028, 63.71901798248291, 54.12041514260428, 47.990464210510254, 29.58380719593593, 21.909132753099712, 31.194062641688756, 38.997004304613384, 29.581337111336843, 66.73332023620605, 16.78869080543518, 0.09100461458521229, 0.025691088122714843, 1.097980939916202, 2.3509835728577206, 10.505980253219604, 0.3567493126860687, 16.92809077671596, 77.40315464564732, 55.58743347440447, 60.4684978212629, 47.176163128444124, 60.48123386928013, 54.70270892551967, 60.6441969190325, 56.27257101876395, 56.908504894801546, 53.955520493643625, 55.71881696156093, 52.463016169411794, 51.09914384569441, 43.796229294368196, 43.12522438594273, 40.412699767521445, 39.9284485408238, 38.50949089867728, 42.881599698747905, 39.84780427387783, 39.179304191044395, 38.955040659223286, 39.71214069638933, 37.19314077922276, 41.21884366444179, 37.658777781895225, 39.985013825552805, 38.75576284953526, 39.874342918395996, 39.668700558798655, 39.09978553227016, 42.957585198538645, 51.5224107333592, 50.774457999638145, 50.35614170346941, 44.69720915385655, 38.99785198484148, 36.2854767526899, 37.98004164014544, 36.039552211761475, 37.178869179316926, 36.3127692767552, 39.69377660751343, 40.198980127062114, 42.185748032161165, 36.700409276144846, 36.869827202388215, 36.09861189978463, 38.9072961126055, 37.86042840140206, 46.54934181485857, 44.34001963479178, 49.20052426201956, 43.848410265786306, 52.98289775848389, 40.459916251046316, 35.96981314250401, 54.41132926940918, 45.714387212480815, 44.70335136141096, 41.75771468026297, 45.10336262839181, 43.25748682022095, 43.38423933301653, 40.64090640204293, 40.04587657111031, 37.124819142477854, 35.99842929840088, 36.29948779514858, 35.6281806400844, 35.39308486665998, 37.592321736471995, 45.076351506369456, 46.67614991324288, 43.32014567511422, 40.70219646181379, 38.6613507270813, 37.08333144869123, 37.549169949122835, 36.70958437238421, 38.49814101627895, 37.82233490262713, 40.21978650774275, 38.47862352643694, 39.15698310307094, 38.79802179336548, 39.34842334474836, 38.06313862119402, 40.796636377062114, 39.19888768877302, 38.7919351713998, 39.398676191057476, 43.7111486026219, 48.96198565619332, 47.76005152293614, 46.23813894816807, 45.6088718686785, 41.712759835379465, 39.383292879377095, 40.007487773895264, 42.790293421064106, 49.00547443117414, 52.23279455729893, 50.93462439945766, 53.82611376898629, 52.967955657414024, 57.17284911019461, 56.355852127075195, 49.54806620734078, 56.34359897886004, 56.21344879695347, 55.3625932421003, 25.236293281827653, 0.5321504792996815, 2.7363899435315813, 1.6562771648168564, 0.11301071303231375, 0.10987567768565246, 9.92852589062282, 57.202385902404785, 37.327338286808555, 39.47751045227051, 13.832111580031258, 15.25043433053153, 28.934845447540283, 43.05936588559832, 49.38594388961792, 47.34607090268816, 38.42502164840698, 0.78689841819661, 0.06217748179499592, 0.05205124570056796, 0.06419853227479116, 0.017658841629911746, 0.015981742247406925, 0.02267580233248217, 0.03456521506554314, 0.019807967290814434, 0.02829909005335399, 0.03261668301586594, 0.02685649406963161, 0.04482525487297347, 0.015058320547853197, 0.07255121693015099, 0.03836146582450185, 0.0722865882728781, 0.017177193724949445, 0.025479727857080952, 0.029804606589355638, 0.06687348016670772, 0.0058658699272200465, 0.017511770860957246, 0.05048354482278228, 0.03837307555867093, 0.055742856181625805, 0.02927047060802579, 0.0751088054052421, 0.028583002675856863, 32.84689664840698, 71.51835700443813, 59.29305716923305, 55.371247223445344, 33.938847746167866, 22.088564770562307, 26.367197717939103, 42.10208477292742, 34.629707132067, 73.65834658486503, 18.275690419333323, 0.15340827245797428, 0.12035741523972579, 2.720661176102502, 5.726514637470245, 14.287539073399135, 0.4629917474729674, 18.827842916761124, 81.19403621128627, 57.46455880573818, 62.917835099356516, 49.4120899609157, 62.912352970668245, 56.86658293860299, 62.20349775041853, 57.90804147720337, 60.12921033586775, 56.83369711467198, 57.70871155602591, 54.67284904207502, 53.40686641420637, 45.43369041170393, 44.64246082305908, 43.26680782863072, 43.35794040134975, 40.46865708487374, 44.636005946568076, 40.373765536717, 41.72250120980399, 40.126427037375315, 42.005497864314485, 38.893253803253174, 43.2479921068464, 39.94590241568429, 42.406224795750205, 41.430676868983674, 42.22928197043282, 41.29449912479946, 41.39975043705532, 46.17410434995379, 54.29109764099121, 52.25099188940865, 53.17961515699114, 46.928306988307405, 40.48666681562151, 39.739916120256694, 38.70566633769444, 38.97010782786778, 39.00671441214425, 38.216259547642295, 40.6053455216544, 41.28625161307198, 43.980870723724365, 39.72466482434954, 38.64831938062395, 39.23204796654837, 42.08493314470564, 39.84639378956386, 49.194496699741904, 46.81931059701102, 50.894804273332866, 46.687044688633506, 55.92792647225516, 42.35212959562029, 39.69490221568516, 55.54128353936331, 47.81112425667899, 46.53861379623413, 44.27856281825474, 46.30407040459769, 44.481814997536794, 45.42858695983887, 42.93730340685163, 42.386384214673726, 39.27907337461199, 39.06587832314627, 38.18990503038679, 37.31494964872088, 37.22420270102364, 39.508009569985525, 46.131657804761616, 46.962874276297434, 46.061397620609824, 42.16485479899815, 40.1004581451416, 38.846409048352925, 38.443743569510325, 39.19239807128906, 41.40663957595825, 39.32129757744925, 41.848760400499614, 40.69325065612793, 41.00752115249634, 39.90716273444039, 41.004095690590994, 39.217269148145405, 41.568824427468435, 40.46859107698713, 40.96050616673061, 40.069170406886506, 45.74563673564366, 50.92916658946446, 49.303736277988975, 47.73967593056815, 46.77693700790405, 42.010549204690115, 41.50684997013637, 42.27658183234078, 44.54812513078962, 49.55849892752511, 54.50972965785435, 53.35576936176845, 56.434853145054404, 56.08266632897513, 57.955132893153596, 58.71764210292271, 51.54464496885027, 57.09007522038051, 58.56134237561907, 57.02939312798636, 30.910475390298025, 0.11203356153730835, 3.304262740271432, 5.211740842887333, 0.19411323538848332, 0.08838844818196126, 9.007697633334569, 62.30651869092669, 39.633497510637554, 41.25678777694702, 20.11702731677464, 19.139023201806204, 35.55576651436942, 48.91057593481881, 53.91327197211129, 53.4035382270813, 47.64760535103934, 2.5523857942649295, 0.03588061287466969, 0.031138117890805006, 0.003396996725184311, 0.011208134736599666, 0.014879392559773155, 0.024300198203751018, 0.032664709724485874, 0.03381180031491177, 0.01089069654699415, 0.005052332733092564, 0.018252634410081164, 0.0214226160065404, 0.04468376335820981, 0.012084083581742431, 0.15164315860186303, 0.19863811401384218, 0.09315512276121549, 0.11118027660995722, 0.09209019597619772, 0.1463373675942421, 0.1431233507714101, 0.11078152872089829, 0.15736498657081807, 0.13020808808505535, 0.08391279048685517, 0.19033858579184326, 0.12059555388987064, 0.06982134841382504, 39.623981952667236, 81.04339926583427, 68.01720837184361, 63.33569976261684, 41.70907381602696, 30.190912996019634, 43.83637945992606, 51.84561661311558, 41.88193110057286, 77.47562435695103, 20.573836633137294, 0.24177969619631767, 0.2601692165647234, 3.007278493472508, 5.579436472484043, 29.202774933406285, 3.8406562890325273, 21.401853459221975, 83.60341439928327, 58.59773703983852, 65.00517817905971, 52.723882811410085, 65.82876900264195, 59.04809842790876, 64.95966747828892, 60.24448095049177, 60.71691676548549, 58.18642105375017, 60.97554261343819, 58.27965545654297, 55.54501819610596, 47.0669652393886, 46.25735419137137, 43.93066998890468, 44.5676599911281, 42.94544669560024, 47.1658103125436, 43.19532823562622, 42.246683733803884, 41.83465208326067, 44.55656371797834, 41.02625002179827, 45.037538869040354, 42.49221222741263, 44.568476404462544, 42.35787228175572, 44.79859379359654, 43.58120686667306, 42.98611797605242, 47.31369924545288, 57.305101122174946, 54.419086933135986, 54.6698647907802, 49.357633454459055, 42.428684847695486, 41.130014419555664, 41.278459208352224, 39.96115371159145, 40.253450529915945, 39.07395907810756, 43.40598719460623, 43.9722341128758, 47.57571928841727, 40.99529232297625, 40.261812686920166, 41.3695570400783, 43.65129334586007, 43.277428150177, 51.68360199247088, 49.348628589085166, 53.26234040941511, 48.06731823512486, 58.680233001708984, 45.61654615402222, 42.315988540649414, 57.35337373188564, 50.23626095908028, 48.37957375390189, 47.4883839062282, 49.445090430123464, 47.708169324057444, 47.41170358657837, 44.64559098652431, 44.448526178087505, 42.01514891215733, 41.07614850997925, 40.65600136348179, 38.845328603472026, 38.77434580666678, 40.2264289855957, 49.39380925042288, 50.665298325674875, 48.20056731360299, 45.21667037691389, 42.480563572474885, 41.48470606122698, 41.04964460645403, 40.397573539188926, 42.806472301483154, 41.160117489951, 45.43682057516915, 43.61088262285505, 42.85949053083147, 42.782806737082346, 42.11704077039446, 40.76377487182617, 44.77394853319441, 42.8683876991272, 41.80115829195295, 43.056458064488, 47.7590787751334, 54.481460911887034, 52.41470187050955, 50.43628222601754, 48.485537256513325, 45.96791655676705, 44.122044222695486, 43.83735915592739, 48.38998562949044, 52.73336362838745, 56.96411827632359, 55.74630403518677, 60.12060151781355, 58.08666576657976, 61.34679181235177, 58.125391551426475, 55.76820823124477, 59.175570079258506, 60.56735679081508, 57.43027639389038, 34.331493922642295, 0.8205572835036686, 10.039858613695417, 6.092570057937077, 0.13887880210365566, 0.14981404532279285, 12.736698542322431, 69.3142841884068, 50.969038827078684, 53.9550792830331, 20.76705387660435, 23.60932568141392, 41.64450420652117, 57.14194004876273, 62.666365895952495, 58.640204429626465, 54.245017187935964, 3.1952713429927826, 0.13540411926805973, 0.1562571017337697, 0.1045285299686449, 0.15366998341466698, 0.15052884125283786, 0.12639472128025123, 0.08567428096596684, 0.08304049300828151, 0.13823446524994715, 0.10909095872193575, 0.13492579279201372, 0.17768288989152226, 0.11586605624428817, 0.1608937079352992], [0.03404458871643458, 0.038615858781018426, 0.09920260682702065, 0.029985208862594197, 0.059253430127033165, 0.03218352661601134, 0.02032145545152681, 0.018319385292540704, 0.07476970752967255, 0.026294388874833072, 0.042045948295188804, 0.060730485511677604, 0.14177147831235612, 4.351245965276446, 58.36326313018799, 58.96560246603829, 58.8053422655378, 48.04197468076433, 28.998268604278564, 21.325932230268204, 29.97275345666068, 31.25034999847412, 45.57933855056763, 61.66579055786133, 5.263836698872702, 0.17013914111469472, 0.21252687089145184, 9.269156609262739, 9.438746503421239, 4.46504008769989, 0.20199790730008058, 42.31558901923043, 70.71092074257987, 55.88979475838797, 56.4214083807809, 44.51013238089425, 51.142959186008994, 53.24107892172677, 59.08900942121233, 54.719843183244976, 57.031772886003765, 54.69447878428868, 55.589820180620464, 52.07804080418178, 53.8741431917463, 49.939638887132915, 46.01436526434762, 40.06509876251221, 42.583723476954866, 37.94222954341343, 40.14064999989101, 38.187490531376426, 42.67492205756051, 38.9822359085083, 41.86722176415579, 38.47200189317976, 40.880984033857075, 37.75177594593593, 39.83504390716553, 39.11869852883475, 39.842270033700125, 39.1723872593471, 38.32021849496024, 39.27509205681937, 43.77078151702881, 48.49602556228638, 46.6617671421596, 38.885975565229145, 36.74723318644932, 37.08716338021414, 37.565772669655935, 36.2440550667899, 38.36252607618059, 36.41566514968872, 36.94354411533901, 37.08124698911394, 38.277632985796245, 35.687653745923726, 37.8069064276559, 36.29306765965053, 37.366845743996755, 38.178777490343364, 44.48577199663435, 43.204291411808555, 48.2117052759443, 44.89390223366873, 53.48851816994803, 36.452501024518696, 34.44236980165754, 55.32911682128906, 45.13441412789481, 45.31282302311489, 43.16285930361067, 46.40795986992972, 44.90178149087088, 45.439662388392854, 43.83841528211321, 41.745284352983745, 39.68356622968401, 37.0386962209429, 35.995938369206016, 36.743026052202495, 36.426876068115234, 37.470912388392854, 36.101335593632285, 39.10152605601719, 38.93262229646955, 37.8731575012207, 37.549770968300955, 36.25806958334786, 36.846800872257774, 38.1349447795323, 38.19262525013515, 38.18876205171858, 37.14605631147112, 39.12007427215576, 38.04155056817191, 38.28076662336077, 39.186662333352224, 38.00100435529436, 38.7447395324707, 39.85948766980852, 38.69913155691964, 38.85092190333775, 40.99680355616978, 41.95047507967268, 40.81706755501883, 40.72142907551357, 39.62824467250279, 37.75226926803589, 41.0647360937936, 41.654714584350586, 49.13778897694179, 49.49553435189383, 51.61145884650094, 53.102271284375874, 55.40119743347168, 54.75502191271101, 54.62447568348476, 51.40795653206961, 55.78817735399519, 56.30400466918945, 58.17252465656826, 54.818431173052105, 45.317888259887695, 8.712395719119481, 0.12152632751635142, 3.170605020863669, 0.2982597569269793, 0.08176516608468123, 0.5402157093797411, 39.035525117601665, 53.37367139543806, 36.668697697775706, 37.36123159953526, 21.284451484680176, 12.333165407180786, 27.87130379676819, 47.2881646156311, 44.45213576725551, 54.49400241034371, 10.983149528503418, 0.2663612285895007, 0.05950672046414443, 0.015696988241480928, 0.023825880173327665, 0.04851776102025594, 0.07049924560955592, 0.05889664962887764, 0.016284055043277994, 0.01705924907167043, 0.03945508785545826, 0.08919779118150473, 0.005188485449512622, 0.024228560172819665, 0.08696119726768561, 0.012179678987844713, 0.05603300454095006, 0.06951372777777058, 0.07576406667275087, 0.05189542691888554, 0.035299691903804026, 0.013051113030607147, 0.04235847813210317, 0.1192976792476007, 0.029243088327348232, 0.04487350210547447, 0.07928387887243714, 0.1415074739073004, 6.118967567171369, 67.67457880292619, 65.79447964259556, 65.17397076742989, 53.424792766571045, 37.637203625270296, 30.547202723366873, 34.63108287538801, 34.59461872918265, 48.94444840294974, 67.46012960161481, 5.60192301443645, 0.3010030197245734, 0.3232681692710945, 13.625670177595955, 10.632856965065002, 3.276917887585504, 0.29983249253460337, 44.6119304384504, 73.67894799368722, 57.44236625943865, 59.37713732038225, 46.379993370601106, 51.986467020852224, 55.4342291695731, 60.79706423623221, 56.79562793459211, 58.0794153213501, 56.544096197400776, 60.30017076219831, 53.1934038570949, 55.37332126072475, 50.95180034637451, 47.53179625102452, 41.26922505242484, 44.334784167153494, 40.99146386555263, 43.291237694876536, 39.25993456159319, 44.204658303942, 40.69513014384678, 42.37019491195679, 40.43176909855434, 42.738480704171316, 40.09776224408831, 40.30594069617135, 41.11052819660732, 40.83097784859793, 40.9026380947658, 41.39860051018851, 40.2075194631304, 48.95528759275164, 50.287972927093506, 48.45967953545706, 41.011617115565706, 40.49067940030779, 38.36734465190342, 40.22172852924892, 37.87410593032837, 41.100043364933555, 39.49941117422921, 40.351079668317524, 39.10250922611782, 39.98714344842093, 37.94136796678816, 39.88454287392752, 38.48010696683611, 40.542578969682964, 40.676258836473735, 44.74680539539882, 45.23115389687674, 49.7360497202192, 47.549083369118826, 56.88950157165527, 38.052327224186485, 35.93672582081386, 56.28789527075631, 46.27809109006609, 47.10520117623465, 44.891133376530235, 49.04779590879168, 46.977375166756765, 47.78340441840035, 45.44672870635986, 44.36027710778372, 42.22671113695417, 39.74843461172921, 39.12561546053205, 37.93060173307146, 39.65800380706787, 38.37506757463728, 37.849029881613596, 40.86025408336094, 41.86058276040213, 40.1610985483442, 38.67472948346819, 39.46534415653774, 38.94133881160191, 38.84578023638044, 39.05862092971802, 40.06796489443098, 39.50732169832502, 41.32933044433594, 40.41102525166103, 40.76553971426827, 40.724691254752024, 39.34492492675781, 40.38425384249006, 40.334452629089355, 41.163355350494385, 41.12565442493984, 42.897069862910676, 44.01320416586739, 42.855675969805034, 41.83468682425362, 41.5109737260001, 39.16756173542568, 42.67122214181082, 44.04538822174072, 51.088335922786165, 53.10100671223232, 52.52218355451311, 56.02138669150216, 56.94009140559605, 56.851248264312744, 55.29200301851545, 53.033772468566895, 57.78119516372681, 56.80105447769165, 59.324178150721956, 54.43422358376639, 47.61746406555176, 12.872752955981664, 0.8624615435089383, 2.8897225729056766, 0.5656355310763631, 0.05641978307228003, 0.22237195260822773, 42.15421710695539, 59.0389198575701, 35.20510482788086, 27.565030676977976, 24.17268041202, 21.05799232210432, 31.879905428205216, 52.36630071912493, 50.69907699312483, 62.32156154087612, 16.87661852155413, 0.13312749857349054, 0.038068138528615236, 0.029977144473897557, 0.08449195405202252, 0.032421383674123457, 0.05920500986810241, 0.04031787905842066, 0.0189854318741709, 0.03163957901831184, 0.033190710070942125, 0.03729020491508501, 0.03765362487839801, 0.03376308150057282, 0.023493801742526035, 0.14178522543183394, 0.13626382313668728, 0.19544718095234462, 0.10150506613509995, 0.23978141056639807, 0.18465486434953554, 0.15248477272689342, 0.16683425488216536, 0.21403385645576886, 0.16507846409721033, 0.18559167693768228, 0.1981635737632002, 0.2657790998263018, 7.0127182602882385, 78.14398547581264, 73.64219202314104, 73.7076301574707, 59.89687647138323, 41.96917268208095, 31.714784962790354, 44.10998909814017, 42.89596509933472, 58.30539853232247, 75.55259922572544, 7.408654843057905, 0.3682553124214922, 0.35256980838520185, 14.19826774937766, 21.114543710436138, 11.643077271325247, 0.6467203572392464, 49.112320355006624, 75.03584085191999, 61.47342273167202, 61.38585458483015, 48.79487453188215, 52.953096934727256, 57.56054469517299, 63.46296296800886, 57.91874170303345, 59.83867141178676, 58.84958144596645, 61.15481308528355, 54.95914609091622, 57.424936703273225, 54.28547307423183, 51.169629846300396, 43.998157841818674, 46.60456609725952, 42.42671503339495, 44.31072950363159, 41.81351218904768, 46.14000259126936, 42.75815452848162, 45.67931965419224, 41.83761548995972, 45.53972339630127, 42.32612248829433, 42.83746821539742, 43.337457111903596, 43.317692961011616, 42.02628340039934, 42.091766698019846, 42.05599389757429, 49.56608288628714, 53.01276806422642, 50.770549637930735, 42.80014944076538, 40.969462394714355, 41.02881738117763, 42.49032231739589, 40.17299039023263, 44.31418970652989, 41.491011551448274, 42.107431411743164, 41.812435218266074, 41.600869519369944, 40.044900349208284, 42.21717473438808, 41.45427642549787, 41.742630141122, 43.312443596976145, 47.65561662401472, 47.188374587467735, 53.50632987703596, 49.44753967012678, 59.271149499075754, 41.06962762560163, 39.67835508074079, 58.21662139892578, 48.099113191877095, 49.64992332458496, 48.67417390005929, 51.82442113331386, 48.50594411577497, 49.459608691079275, 47.530337129320415, 46.50601979664394, 44.86301749093192, 42.27329880850655, 42.05173117773873, 39.53000061852591, 41.67760195050921, 41.0389860698155, 39.75442048481533, 42.71008341653006, 45.12759447097778, 40.9359199660165, 41.28691864013672, 40.671464579445974, 41.184467451913015, 41.35619912828718, 42.46104260853359, 42.35851846422468, 41.172419275556294, 43.72523954936436, 41.99599967684065, 42.78311940601894, 44.847255502428325, 40.60452216012137, 42.96523863928658, 43.470063482012065, 44.405395235334126, 42.91032007762364, 44.79359456471035, 46.13888045719692, 45.1520972933088, 43.84938301358904, 44.082237992967876, 41.10360084261213, 46.02283511843, 46.08921125956944, 54.565919739859446, 55.81907946722848, 55.87807314736502, 57.679664611816406, 59.68311514173235, 58.00890152794974, 58.78874996730259, 56.26002604620797, 62.51395715985979, 57.115648065294536, 63.02746377672468, 54.355226039886475, 52.259440898895264, 13.988740478243146, 3.7305368951388767, 7.654560276440211, 0.5341717536960329, 0.15160397998988628, 0.8660069161227771, 48.95122984477452, 64.60335690634591, 48.90624025889805, 47.778245380946565, 29.65410212108067, 20.970973082951136, 39.418030398232595, 61.123073714120046, 57.38628734861101, 68.3617000579834, 19.824457781655447, 0.47819532879761284, 0.1452686885105712, 0.25883907079696655, 0.15481782039361341, 0.11579022317060403, 0.1825139778000968, 0.15172296789075645, 0.06944064277091197, 0.11689885439617292, 0.20610113069415092, 0.1969549943293844, 0.16876600336815628, 0.1265881580433675, 0.16094231818403515], [0.01983551581257156, 0.017023061102788364, 0.01362565831680383, 0.057713555970362256, 0.04892499738239816, 0.031873924657702446, 0.041815416022603, 0.04216965879978878, 0.03895297533433352, 0.06219417375645467, 0.023542549394603287, 0.05470469081774354, 0.05921900804553713, 11.832047428403582, 65.55811582292829, 50.250473499298096, 56.05226101194109, 46.79674979618618, 16.327410323279246, 15.393999746867589, 39.307255268096924, 32.36841590063912, 56.005735874176025, 42.03674043927874, 0.7613124911274228, 0.19605532474815845, 0.7804621064237186, 4.769228747912815, 2.259906802858625, 0.7590032464691571, 3.8029049890381947, 71.96876008169991, 56.77760430744716, 62.09188188825335, 54.66890593937465, 49.98963465009417, 43.79224797657558, 53.81962067740304, 56.41259111676897, 57.994629928043906, 57.22131974356515, 51.86110414777483, 53.43284920283726, 57.009194714682444, 53.568220955984934, 54.160516670772004, 49.25975070680891, 43.928887775966096, 39.458736419677734, 40.771890367780415, 37.47415372303554, 38.67304107121059, 40.240860394069124, 38.87650169645037, 40.440801756722585, 39.205683026994976, 40.4384845324925, 40.02580322538103, 40.028394903455464, 37.62347051075527, 39.18661022186279, 39.95055423464094, 39.00596053259713, 38.018920285361155, 37.92582484654018, 38.42604650769915, 39.08085169110979, 37.435250759124756, 39.43329906463623, 37.74206236430577, 37.605783871241975, 37.0551495552063, 36.73429216657366, 36.60465962546212, 36.337282521384104, 35.013556889125276, 36.612031664167134, 34.99625934873308, 38.97576366152082, 35.5268098967416, 38.11871031352452, 38.58213778904506, 41.79608263288225, 42.262324128832134, 48.64104488917759, 45.634371757507324, 55.41818230492728, 31.53765106201172, 30.866698265075684, 54.652132987976074, 43.04729339054653, 46.619251114981516, 43.74183879579817, 48.26686702455793, 44.88835409709385, 47.54693637575422, 45.01656225749424, 45.88199165889195, 40.828341007232666, 40.33701304027012, 34.867651666913716, 36.844726834978374, 36.17682082312447, 37.61169678824288, 36.96745981488909, 37.32334654671805, 38.56493404933384, 37.316978522709434, 36.99602733339582, 37.045328276497976, 36.359037331172395, 38.5830271584647, 37.74360833849226, 39.27362946101597, 38.01481737409319, 38.72269984654018, 38.880726201193674, 39.53932857513428, 37.834501198359895, 37.79127645492554, 37.90972587040493, 40.02500418254307, 37.682874134608674, 41.56381130218506, 38.79749025617327, 39.46054295131138, 40.29487221581595, 38.50685405731201, 38.784059388296946, 40.22888169969831, 40.20731101717268, 46.54491581235613, 51.029578481401714, 56.47365883418492, 55.997939995356965, 51.6483086177281, 51.36868183953421, 50.138704776763916, 52.30127600261143, 55.21261984961373, 54.9693147795541, 58.486906324114116, 55.85323681150164, 56.9327506337847, 55.87023557935442, 28.20520990235465, 0.5620876614536557, 5.058665948254721, 0.9184375341449464, 0.19135304992752417, 0.10103707374738795, 15.03603550365993, 57.2398818561009, 48.16287333624703, 53.76267671585083, 36.48420565468924, 19.517552375793457, 21.10599742616926, 37.58617952891758, 42.39779315676008, 48.85588318961007, 31.8167393548148, 0.31603335748825756, 0.04374789732641407, 0.011221832662288631, 0.0624955790117383, 0.011710047089893903, 0.0469951216530587, 0.04012749570288828, 0.02744735048950783, 0.1008566716419799, 0.03834714873560837, 0.020691954231421863, 0.029880826428000416, 0.010379099802646254, 0.03599350753107241, 0.012833862232842615, 0.06086507971797671, 0.02007529991013663, 0.035986803605088165, 0.008858206814953258, 0.036597122105636766, 0.010694463371432253, 0.03387327558760132, 0.04881811793893576, 0.06254765657441956, 0.0559431698971561, 0.019588557903521826, 0.045556132082960436, 16.141955954687937, 75.91219629560197, 56.91760703495571, 62.30147429874965, 52.86121048246111, 25.74664715358189, 14.858297109603882, 29.77683857509068, 35.77869946616036, 62.25576210021973, 46.536404269082205, 0.6000933849385807, 0.12211461737751961, 1.4235201116119112, 8.674415997096471, 3.1051095638956343, 0.881534891469138, 5.192173412867954, 74.91261454990932, 58.32360281263079, 64.37156500135148, 56.31192214148385, 52.71230363845825, 44.342048508780344, 56.17755092893328, 58.497669083731516, 59.65931756155831, 58.00768559319632, 51.89295469011579, 56.47780343464443, 59.62808540889195, 55.74955926622663, 55.80339738300869, 50.473684379032676, 46.681746687207905, 41.342611925942556, 42.537125383104595, 39.9096223967416, 40.78322287968227, 41.277792181287495, 41.40003531319754, 42.07309341430664, 42.233846936907085, 41.22643804550171, 40.8755818094526, 41.465150356292725, 40.4771477835519, 40.49577242987496, 40.97113691057478, 39.71357202529907, 39.1985194342477, 38.0379444531032, 41.236631052834646, 40.182259287152974, 38.46702350888933, 41.10667889458792, 39.35595519202096, 39.696535042354036, 38.314187458583284, 38.93128476824079, 38.57553352628435, 40.279541015625, 38.57609633037022, 38.09252255303519, 37.435275077819824, 40.69475494112287, 38.374035767146516, 39.93441704341343, 40.82749680110386, 45.03961985451834, 44.49033348900931, 49.078861304691856, 47.21509388514927, 56.90393992832729, 33.41206659589495, 32.56751305716378, 57.991603987557546, 44.74511003494263, 48.911166531699045, 44.38341460909162, 51.53586939402989, 47.92487668991089, 49.942623138427734, 46.526902607509065, 47.1610438483102, 42.045998913901194, 42.39201920373099, 37.030448709215435, 40.372705936431885, 36.96362440926688, 38.61889028549194, 38.62107201984951, 38.72731692450387, 38.483205863407676, 39.92684350694929, 38.575356347220286, 39.40030901772635, 39.00814921515328, 41.40132072993687, 38.19958734512329, 39.37664692742484, 38.672144753592356, 39.98694542476109, 39.27152068274361, 40.10615914208548, 39.77068969181606, 39.564401149749756, 39.48294046946934, 41.658032349177766, 40.08434527260916, 42.18348291942051, 39.97115911756243, 41.42640025275094, 41.62590387889317, 41.535688468388145, 40.49270132609776, 41.89931549344744, 42.77135610580444, 49.31135150364467, 53.03366824558803, 57.33463096618652, 57.967379093170166, 54.073900427137104, 53.111772945949006, 53.49501126153128, 54.30084596361433, 56.665338788713726, 56.73202065059117, 60.036347661699565, 56.874865191323416, 58.36035878317696, 56.8926317351205, 31.944263117653982, 0.6669276729226112, 3.8515632237706865, 1.1738191161836897, 0.17258668478046144, 0.1520044513578926, 14.925599098205566, 63.74724851335798, 47.37554168701172, 45.054999692099436, 34.01099436623709, 23.174111366271973, 30.9287109375, 42.071929591042654, 48.70477376665388, 54.555775369916645, 43.22668545586722, 0.952146936740194, 0.05316462667126741, 0.06580089272132941, 0.0936907786609871, 0.013753318743381118, 0.02048487212908055, 0.036895579126264365, 0.01168473858186709, 0.08539303498608725, 0.043991983335997374, 0.009447869861365428, 0.02305716785070087, 0.030053004688982452, 0.01276918766754014, 0.15794754959642887, 0.15829745653484548, 0.08982922229915857, 0.10870158818683454, 0.0850245226174593, 0.15098052844405174, 0.07868147548288107, 0.16596463083156518, 0.12149876542389393, 0.16810174472630024, 0.1452698963029044, 0.1570443380624056, 0.21075479526604923, 20.697203636169434, 85.62857110159737, 63.90884971618652, 70.37064661298479, 60.28261266435896, 25.198621886117117, 22.706146717071533, 48.911388874053955, 45.111276626586914, 68.61990901402065, 50.53265374047415, 1.2652504614421298, 0.26915321020143373, 1.5156283634049552, 9.460194723946707, 8.490867171968732, 6.044216241155352, 5.770150193146296, 78.91585390908378, 60.67710358755929, 66.75198309762138, 60.27319785526821, 55.96396330424717, 47.28581959860665, 58.57669789450509, 63.117713928222656, 61.96906552995954, 59.54813943590437, 54.67918232509068, 58.2168402671814, 63.31985786982945, 58.434315408979145, 58.692906515938894, 53.40510504586356, 49.16297967093331, 45.63589688709804, 45.00651863643101, 40.499805859157014, 42.90944113050188, 44.52546010698591, 43.94089426313128, 45.56392397199358, 42.691580363682334, 43.88815743582589, 43.78543526785714, 43.452672140938894, 41.95624555860247, 42.81915276391165, 42.986249991825645, 41.39719697407314, 40.97232157843453, 39.441209588732036, 41.9337021282741, 42.55852236066546, 40.6146422113691, 43.029478209359304, 42.443665163857595, 43.22312102999006, 41.28179086957659, 40.17675978796822, 41.997045380728586, 41.19663722174508, 40.52632365907942, 40.86934927531651, 39.31217459269932, 44.96582303728376, 40.52688646316528, 41.8965813773019, 43.8445713860648, 45.98170525687081, 46.96081413541521, 52.06001370293753, 50.92962169647217, 59.88500199999128, 37.00181518282209, 35.20479563304356, 58.98564107077462, 48.21573175702776, 50.784560680389404, 48.02276985985892, 52.9350038255964, 48.296230111803325, 51.622864314488, 49.05550493512835, 49.973358494894846, 44.24641350337437, 44.14389978136335, 38.85496922901699, 42.08533614022391, 40.37349108287266, 41.48059967585972, 41.722244126456125, 41.639046396527974, 41.362994466509136, 41.98851646695818, 41.270013672964915, 40.02038363048008, 41.48740543637957, 43.2978697504316, 41.343494347163606, 41.795012610299246, 41.38922739028931, 41.509514604296, 41.576019287109375, 41.70776060649327, 41.20559344972883, 41.04991558619908, 41.0920911516462, 44.030838693891255, 40.835775579724995, 44.405829497746055, 41.84783629008702, 43.36009781701224, 43.353021076747346, 43.23328971862793, 43.49941267286028, 44.557491302490234, 45.05139357703072, 53.763357639312744, 55.2749000276838, 60.55913707188198, 58.243490082877024, 55.07186324255807, 55.48229333332607, 55.18940244402204, 56.73498058319092, 59.48641858782087, 56.57506084442139, 63.25290502820696, 58.92496245247977, 61.436006682259695, 55.77798087256295, 34.85147278649466, 2.8660646080970764, 12.673026118959699, 1.397316174847739, 0.39033210064683643, 0.18326172339064734, 18.705168996538433, 68.184298651559, 61.6449042728969, 68.87881278991699, 44.72400835582188, 27.185407161712646, 32.69211857659476, 49.30401420593262, 55.42118740081787, 62.582209314618794, 49.27170508248465, 1.2872226195675986, 0.199401479480522, 0.13722542939441545, 0.1316553218556302, 0.08272946612643343, 0.16495666706136294, 0.20757482733045304, 0.23107181649122918, 0.2674640922674111, 0.11666896673185484, 0.06494139919855765, 0.1471341848373413, 0.08734878325568778, 0.11815086007118225], [0.03943981742486358, 0.0864661041913288, 0.012279873165035886, 0.017741892619856765, 0.08556279087705271, 0.050819996411779096, 0.04172333203522222, 0.029853685027254478, 0.04405038823772754, 0.05087105956460748, 0.057717145420610905, 0.1192623818559306, 0.06867777942014591, 25.839935404913767, 72.82923889160156, 50.756743567330496, 60.74879510062081, 33.83008759362357, 21.466836486543926, 43.93129185267857, 47.76969909667969, 35.92097078050886, 66.25679888044084, 21.76869923727853, 0.08128933661750384, 0.11259629098432404, 0.47036541466202053, 5.760296779019492, 2.9185200333595276, 0.9324688783713749, 29.370087555476598, 72.11484595707485, 56.32244866234915, 62.36156232016427, 53.84694446836199, 50.804394313267295, 41.84253134046282, 44.98092494692121, 49.63120835168021, 55.36457347869873, 55.91394669669015, 57.58964375087193, 53.080704075949534, 56.495834009987966, 53.855688776288716, 51.26597009386335, 52.180043833596365, 48.73642628533499, 42.554224899836946, 39.59201329095023, 40.39470393317086, 39.63629763466971, 36.90561389923096, 38.79051773888724, 40.324075494493755, 40.20487567356655, 37.89932441711426, 38.42376055036272, 38.4380703653608, 39.009584018162315, 37.46425601414272, 38.67106430871146, 38.53951753888811, 39.022215843200684, 38.84682246616909, 37.902982643672395, 38.69233969279698, 38.51545592716762, 37.08193138667515, 37.79049825668335, 38.263913767678396, 36.77440064293997, 37.595504011426655, 36.94224827630179, 36.21852738516671, 36.50816651753017, 36.98198849814278, 35.89651312146868, 36.68839931488037, 36.21670000893729, 40.54214818137032, 39.35388115474156, 42.04107958929879, 41.973581314086914, 47.747433594294954, 45.30159820829119, 55.4889566557748, 33.51050172533308, 34.27258709498814, 55.617373262132915, 42.90507071358817, 48.415864195142476, 46.271448612213135, 49.58595126015799, 46.19499410901751, 49.421879972730366, 45.792276518685476, 45.174536500658306, 43.548724038260325, 41.5165878704616, 37.21799101148333, 37.48078230449131, 35.831578731536865, 37.61346510478428, 35.20486511502947, 36.0058708190918, 36.06978382383074, 38.11900561196463, 37.17580502373831, 38.79557950156075, 37.38718312127249, 39.474276065826416, 36.734372070857454, 38.2821249961853, 38.41120515550886, 37.099239349365234, 37.64223064695086, 37.69587768827166, 36.55122797829764, 38.71938208171299, 39.98200525556292, 38.53458431788853, 38.99824455806187, 39.469617298671174, 37.275588103703086, 39.97156211308071, 38.1422438621521, 37.96801430838448, 36.60431568963187, 40.430956159319194, 45.52324226924351, 53.049833229609895, 53.24909019470215, 50.02266638619559, 46.020201751164024, 49.5056266103472, 48.31051560810634, 53.53934076854161, 53.225685187748496, 56.73565803255354, 54.2072502544948, 57.859716756003245, 55.35995987483433, 57.05296836580549, 58.34809521266392, 49.799580574035645, 1.3200216995818275, 1.2934149844305856, 1.0333318603890282, 0.19956122019461223, 0.0897392485556858, 2.291689383132117, 46.25968531199864, 49.152418409075054, 28.98952603340149, 60.410869462149485, 42.7667042868478, 11.147240792001996, 24.639048712594168, 39.655992303575786, 44.86773879187447, 47.156958307538716, 3.885548165866307, 0.1650011789585863, 0.05479786046115415, 0.09040982435856547, 0.011135199855613922, 0.05110622283869556, 0.06011797195034368, 0.008783053124456533, 0.05575560585462621, 0.021678228629752994, 0.03697173450408237, 0.03839452065793531, 0.021497853665745685, 0.04348814394325018, 0.031150158494710922, 0.05053926272583859, 0.012491968792996236, 0.018460832702528154, 0.04726050687687738, 0.019966422181044306, 0.044813848699309995, 0.016416479633854966, 0.054861378124249835, 0.02977016754448414, 0.01637828489765525, 0.07537295230265174, 0.015375187919874276, 34.884869303022114, 81.24434116908482, 56.29592044012887, 62.35360663277762, 39.384981291634695, 25.651739971978323, 36.52598864691598, 44.73968349184309, 38.815246377672466, 72.2383918762207, 22.49390009471348, 0.15598681409444126, 0.21245899024818624, 1.8721558494227273, 8.65269158567701, 2.2882537160600935, 0.10411528178623744, 30.70061547415597, 73.55472115107945, 58.38560158865792, 65.0473745891026, 53.56251995904105, 52.32651533399309, 43.50233786446707, 47.13149663380214, 52.49205616542271, 58.231285572052, 56.48025614874703, 61.01992770603725, 53.70540966306414, 58.246422222682405, 55.7652621950422, 54.84107535226004, 53.545291900634766, 51.28174597876412, 44.89278357369559, 42.37937695639474, 40.998283522469656, 42.4937720979963, 40.140104566301616, 41.475739410945344, 42.17073992320469, 41.027497223445344, 40.66235201699393, 39.108911991119385, 40.53222615378243, 41.0728793825422, 38.93847267968314, 39.371501786368235, 39.58077457972935, 40.38633482796805, 40.401381152016775, 39.43940653119768, 40.68304375239781, 39.75570937565395, 39.18269143785749, 39.91488913127354, 39.90054110118321, 38.657574381147114, 39.85293551853725, 38.56013284410749, 38.02413143430437, 37.91856745311192, 38.69535868508475, 37.89423138754708, 39.25158282688686, 40.52123410361153, 43.22552858080183, 41.36438758032662, 43.090834277016775, 43.58115128108433, 48.48169142859322, 48.7140565599714, 55.76148237500872, 35.842921665736604, 37.1632148878915, 56.55359785897391, 44.84728676932198, 51.59424121039254, 47.64796665736607, 50.51581825528826, 48.51045002256121, 49.46054669788906, 48.78712034225464, 47.58815656389509, 46.461610385349815, 43.69196810041155, 38.22866555622646, 38.68107666288103, 37.80984551565987, 40.274948256356375, 38.97748334067208, 39.767639432634624, 37.02536610194615, 40.96454307011196, 39.58919579642159, 39.52433783667428, 37.793228898729595, 39.03966971806118, 37.472114426749094, 40.21875817435128, 40.25132785524641, 40.25480890274048, 39.97881603240967, 39.69222021102905, 39.13678468976702, 40.344829763684956, 41.873509883880615, 39.99757964270455, 39.551734583718435, 41.29806007657732, 39.11892434528896, 40.812200341905864, 40.42645025253296, 40.46568325587681, 38.15078319822039, 41.734532015664236, 47.70493841171265, 55.92466081891741, 54.920347349984304, 52.19587530408587, 47.32453496115548, 49.986855370657786, 49.393691131046836, 56.15341636112758, 54.51897423607962, 57.354106766836985, 55.6825647354126, 58.776840754917686, 58.353751046316965, 59.83368260519845, 59.489267349243164, 52.622935908181326, 2.1851233414241245, 1.037735824074064, 3.3984998549733842, 0.7686396379555974, 0.02712587925738522, 1.7179216912814548, 51.17427471705845, 56.05968516213553, 30.478172370365687, 50.96442174911499, 42.192626748766216, 17.374986750738962, 28.969848734991892, 44.41135678972517, 49.7249812398638, 58.66432162693569, 6.313726007938385, 0.14175786689988204, 0.09304324590734073, 0.0797047537884542, 0.02200950469289507, 0.07069171885294573, 0.08694563845970801, 0.052169561851769686, 0.08536551360573087, 0.034002994519791434, 0.03403496369719505, 0.019041672249191573, 0.05336670457784619, 0.01713523481573377, 0.16897724489016192, 0.22277819152389253, 0.12890405234481606, 0.07495838097695794, 0.21921440346964768, 0.16311334525900228, 0.08969634478645665, 0.13133141637912818, 0.12154964197959219, 0.168378885569317, 0.09110095298716, 0.14764201401599816, 0.2810385381536824, 43.452880586896626, 87.9111933026995, 64.77305276053292, 72.27034664154053, 45.164701325552805, 29.062638453074864, 56.048345702035085, 63.75751100267683, 47.61444159916469, 76.81785229274205, 27.691465309688024, 0.36074634534972055, 0.36344794609716957, 2.456499133791242, 12.424674919673375, 10.282389828136989, 2.0793691532952443, 35.55817059108189, 74.18755613054547, 61.854065895080566, 65.57274178096226, 58.78494235447475, 55.0473986353193, 47.42662831715175, 49.61319167273385, 55.032442637852256, 60.06277860913958, 59.7563977922712, 61.847298349652974, 55.17424842289516, 60.04173251560756, 59.124375752040315, 56.91028710774013, 56.365961756025044, 53.359844480242046, 47.59199891771589, 44.04780272075108, 44.412940979003906, 43.34439141409737, 41.52701711654663, 42.56979581287929, 45.23060846328735, 44.69049719401768, 43.655434472220286, 41.232896396092, 41.82735994883946, 42.06997019904, 40.363065310886924, 40.945442472185405, 43.12821558543614, 43.385760988507954, 41.98307255336216, 42.389059271131245, 41.81224414280483, 41.30919803891863, 40.72408676147461, 42.694019181387766, 42.07690797533308, 41.478793144226074, 42.660556656973704, 40.55180965151106, 39.085458346775596, 39.75744642530169, 41.054484026772634, 40.18307570048741, 41.86136095864432, 42.79730415344238, 46.15468760899135, 43.63650063105992, 45.12816769736153, 46.696237155369346, 52.98556586674282, 51.423523971012656, 59.01785291944231, 38.464675017765586, 39.42185190745762, 58.98398045131138, 47.566335746220176, 52.7729822567531, 49.481526783534456, 53.903718199048726, 51.81283848626273, 53.14325870786394, 49.98613623210362, 49.73735250745501, 48.52074030467442, 45.86058078493391, 39.58767761502947, 41.27323068891253, 39.87980072838919, 41.280595779418945, 41.42749111992972, 40.79585817881993, 39.990405627659385, 44.304976395198274, 42.26214347566877, 42.65439707892281, 41.43379661015102, 42.417296750204905, 39.835547651563374, 42.517823287418906, 43.35940299715315, 42.545049803597585, 41.753146239689414, 40.49241297585623, 39.57441350391933, 42.20651619774954, 43.649438176836284, 42.782351630074636, 42.067402839660645, 43.960488183157786, 41.25436632973807, 44.111976282937185, 42.022545269557405, 43.261763436453684, 40.249969482421875, 44.728076526096885, 49.99764244897025, 60.09790175301688, 57.86943728583199, 54.48825625010899, 50.35618339266096, 51.36386326381138, 50.249674456460134, 57.65955652509417, 55.835140228271484, 60.99822848183768, 57.284193992614746, 63.05233137948172, 59.40294292994908, 61.567112241472515, 63.1263644354684, 56.58483348573957, 2.4733326647962843, 6.01723986012595, 5.463126667908259, 0.8818079339606422, 0.12571070369865212, 3.247144856623241, 56.687729358673096, 60.81030055454799, 41.079327310834614, 67.84969425201416, 52.00304194859096, 18.649923869541713, 36.96293306350708, 53.523648262023926, 56.645796980176655, 66.77092388698033, 8.137242078781128, 0.3789867508624281, 0.14114858316523687, 0.2751535496541432, 0.09892156440764666, 0.11142387746700219, 0.13130765408277512, 0.13722456086959156, 0.1841619357998882, 0.09495408872940711, 0.11839509196579456, 0.13471767253109387, 0.17225197702646255, 0.13230136861758574], [0.061503913652684004, 0.04075684032535978, 0.06190682774675744, 0.01866878672236843, 0.07874153261738163, 0.041971825129751644, 0.08590716096971716, 0.10508667251893453, 0.025445899493726234, 0.047814825882336924, 0.07821950848613467, 0.03874980498637472, 0.31426018263612476, 40.655591419764924, 61.95512744358608, 49.22740684236799, 49.75202710287911, 21.464918783732823, 27.28466044153486, 45.09532356262207, 28.463000229426793, 44.051117011478965, 60.57627827780587, 9.35374571595873, 0.10902249453855412, 0.09498806297779083, 1.1419981036867415, 4.145547151565552, 1.8326575117451804, 8.338348133223397, 58.535689626421245, 66.02037947518485, 59.05074569157192, 62.607917649405344, 53.77302605765206, 49.74728843144008, 44.58533273424421, 42.87586048671177, 44.31050368717739, 51.923370429447715, 54.41906261444092, 54.90629461833409, 55.573922702244346, 56.16953270775931, 52.16022409711565, 54.80909974234444, 51.457747323172434, 47.83628715787615, 44.03928075517927, 39.359873976026265, 39.418964930943076, 39.50860711506435, 39.74905300140381, 39.04972376142229, 38.99702514920916, 38.97752502986363, 39.00402545928955, 38.13619198117937, 38.88813992909023, 38.41824715478079, 39.51445402417864, 38.4515255519322, 37.94847597394671, 37.611297266823904, 37.456731115068706, 37.45178747177124, 38.619578157152446, 36.61253540856497, 38.44704743794033, 39.24798018591744, 38.05006905964443, 36.47912999561855, 36.48327112197876, 37.01269606181553, 36.940924644470215, 37.492608138493125, 36.76890114375523, 36.53705365317208, 38.306395053863525, 38.411712374006, 39.64292621612549, 39.50008167539324, 43.16300174168178, 43.848059381757466, 48.25095564978463, 46.50365046092442, 52.410029206957134, 33.3094208581107, 38.352357387542725, 51.872016293661936, 42.35099356515067, 47.10472869873047, 46.60267618724278, 47.927301611219136, 45.65930189405169, 48.090254238673616, 44.4510692187718, 44.55077934265137, 43.07379729407174, 43.67995466504778, 40.593585695539204, 38.083232811519075, 35.55365078789847, 36.759045124053955, 38.704915932246614, 37.571028981889995, 35.37273359298706, 36.75671400342669, 35.908120087214876, 37.28861597606114, 36.55519887379238, 39.25911120006016, 38.64531775883266, 38.239456108638215, 38.39629084723336, 37.576379094805034, 37.1110964502607, 37.55000720705305, 38.64830548422677, 39.646695613861084, 38.72112955365862, 39.81355312892369, 36.69424622399466, 37.98996366773333, 36.84804459980556, 38.310570921216694, 37.274045603615896, 37.32973888942173, 38.522317273276194, 42.078276770455496, 50.96471357345581, 51.789958068302695, 50.73304673603603, 48.753956590379985, 40.5273346219744, 50.09812034879412, 52.85346671513149, 55.74125964300973, 52.76697901317051, 55.81071731022426, 52.717949049813406, 55.40001276561192, 51.09341505595616, 55.37970665522984, 53.06263528551374, 61.781888008117676, 17.280972412654332, 2.0150709577969144, 0.17355130373367242, 0.48729584046772545, 0.05381668186081307, 0.08265383661325489, 19.97515204974583, 61.216645104544504, 38.43745197568621, 63.04165199824742, 58.17182636260986, 19.23119453021458, 23.263850825173513, 34.79262154442923, 45.05348151070731, 44.44121319907052, 7.294991867882865, 0.19699619497571672, 0.05820419785699674, 0.057324531488120556, 0.08574319298246078, 0.02256848014492009, 0.06379456645143883, 0.04742737560133849, 0.06933384814432689, 0.04206088624362435, 0.046262449717947414, 0.014450512626873595, 0.040454101748764515, 0.04347028150888426, 0.02188176877929696, 0.03742543015895145, 0.018020670428606014, 0.019037819866623198, 0.047254345778908045, 0.03484422527253628, 0.04882503221077578, 0.10343653642173324, 0.04054126635726009, 0.08725486722375665, 0.07297618341233049, 0.15340558545930044, 0.8778525633471352, 53.34355442864554, 68.67491790226528, 56.524439743586946, 55.59158502306257, 29.759634835379465, 33.65815789358956, 37.97486523219517, 29.40155942099435, 49.9064473424639, 67.76792785099575, 10.229562674249921, 0.17997811601630279, 0.15716990775295667, 3.362595473017011, 3.9084346635001044, 0.4718013033270836, 10.63224812916347, 59.80048411233084, 68.59099061148507, 60.251936367579866, 63.33504663194929, 55.175589425223215, 52.339987891060964, 46.70617307935442, 44.91613299506051, 46.933709212711875, 54.661592960357666, 55.9487224306379, 57.07200295584542, 57.249609334128245, 57.69287313733782, 53.71606125150408, 56.73611313956124, 53.38913461140224, 49.75666502543858, 46.70635025841849, 41.26157855987549, 40.65460130146572, 41.53713716779436, 42.54675906045096, 41.8477737562997, 41.652776036943706, 41.11980404172625, 40.879052434648784, 39.23664419991629, 40.443692207336426, 40.894592080797466, 41.95933403287615, 40.678798403058735, 40.446964808872764, 38.67517416817801, 38.68232386452811, 39.32430614743914, 40.48515905652727, 37.802438735961914, 38.52861928939819, 40.43036208833967, 39.407201630728586, 38.015901293073384, 38.77068410600935, 38.68893507548741, 38.981440339769634, 38.129702363695415, 39.4749048777989, 38.267849922180176, 40.40684243610927, 41.30598102297102, 42.6436447416033, 43.16556562696184, 43.38852637154715, 45.56833607809884, 49.344202586582725, 48.013987336839946, 55.3382363319397, 35.19273356028965, 39.39634159633091, 52.800914015088765, 44.682576247623985, 49.852352142333984, 47.67697191238403, 50.20294434683663, 47.76628405707223, 49.38015604019165, 46.40925223486764, 48.11073405402047, 47.74075290134975, 46.0824784551348, 42.485475948878694, 39.95790195465088, 37.905761923108784, 38.784288678850444, 40.22968769073486, 40.415777819497244, 38.699909755161826, 38.81454113551548, 39.18326466424124, 39.225096293858115, 38.55173247201102, 41.27298402786255, 39.63998017992292, 40.04847519738333, 39.62526042120797, 39.57316977637154, 39.93821423394339, 39.84386464527675, 38.98936128616333, 40.740682533809114, 39.62356506075178, 41.01670319693429, 38.44119010652815, 39.824434007917134, 38.33220761162894, 40.44943489347185, 39.18884754180908, 39.32647051130022, 40.002300943647114, 44.751634393419536, 52.85071175439017, 56.23820175443377, 52.0540452003479, 49.6212272644043, 41.898179462977815, 48.849862575531006, 55.58960131236485, 57.11342811584473, 53.75402968270438, 56.615422930036274, 54.80127954483032, 57.15806334359305, 53.11619894845145, 57.5621462549482, 55.437209946768625, 63.57949120657784, 20.61132911273411, 1.0563135700566428, 2.5175186480794634, 1.749229948435511, 0.0730754734416093, 0.13050110664750847, 18.4239684513637, 68.31658540453229, 38.72312716075352, 61.00258500235421, 50.34083134787423, 20.466922964368546, 31.287300518580846, 40.03330727985927, 49.52323681967599, 52.253500189099995, 12.810015933854238, 0.28584061190485954, 0.053818520690713606, 0.0641686428072197, 0.06765814484762293, 0.027462855014683943, 0.04702698565753443, 0.04930436970399959, 0.04274649838251727, 0.019887225270005207, 0.09230017542306866, 0.017867396153243523, 0.0251252458963011, 0.05293856255177941, 0.16612931128059114, 0.11537468832518373, 0.2334734776190349, 0.10744555201381445, 0.18149929653320993, 0.08879003234739814, 0.1688595733472279, 0.2590248536850725, 0.08091507027191774, 0.13712373056582042, 0.18475702458194324, 0.22666665858456067, 1.5807741305657794, 62.99605791909354, 76.59664249420166, 64.3317448752267, 65.33862917763847, 32.17505100795201, 36.658157280513215, 57.40261908939907, 41.53171757289341, 55.27070678983416, 72.98744937351772, 11.729720439229693, 0.3529684884207589, 0.5346071560467992, 7.27050381047385, 8.089493189539228, 3.925518546785627, 13.04829658780779, 60.2622891834804, 70.18257972172329, 62.578832490103586, 66.66977896009172, 56.65841490881783, 55.28777503967285, 49.51162985392979, 46.94107430321829, 48.84878560474941, 56.643848010471885, 58.29945087432861, 60.369347027369905, 59.386830057416645, 59.07795483725411, 55.65067597797939, 59.344348771231516, 55.80779906681606, 53.14217478888375, 49.28138044902256, 43.361126150403706, 42.00882952553885, 43.76205805369786, 43.82001992634365, 43.147541999816895, 43.65727227074759, 42.388673646109446, 43.24957282202584, 41.58190093721662, 44.060302530016216, 42.548419679914204, 43.22380542755127, 41.62325314113072, 40.85208647591727, 40.66045863287789, 39.82951314108712, 42.17460312162127, 40.59910256522042, 39.88550172533308, 41.12646041597639, 42.92446313585554, 41.50213214329311, 38.27455145972115, 40.68685483932495, 41.1100036076137, 40.380234309605186, 41.28206532342093, 41.186475481305806, 40.789281708853586, 41.787432125636506, 43.87468487875802, 44.66951016017369, 44.495416096278596, 46.30666903087071, 47.925644465855186, 51.96025841576712, 50.70604256221226, 55.74491439546858, 38.765156814030235, 42.11139188494001, 54.25028739656721, 46.122326374053955, 51.5278650692531, 51.47356142316546, 52.91712611062186, 51.34199380874634, 52.20699937002999, 47.40964344569615, 50.12366540091378, 49.37982252665928, 47.670423235212056, 45.95048700060163, 42.037456103733604, 39.59499059404646, 40.209871428353445, 44.099320139203755, 42.447368553706575, 40.74319430759975, 40.936256953648154, 40.822063309805735, 42.14631700515747, 41.10912813459124, 44.030828271593364, 42.18027285167149, 41.83353342328753, 41.655666487557546, 41.69839790889195, 41.4732415335519, 41.48083244051252, 41.09998083114624, 42.3011645589556, 42.31420285361153, 43.40906177248274, 40.21112905229841, 42.354293959481375, 40.53998729160854, 42.283807958875386, 42.71244927815029, 41.770589692252024, 42.13597113745553, 47.57504183905465, 56.488097190856934, 57.67587089538574, 53.169081687927246, 49.53476388113839, 44.335548468998496, 50.13169057028634, 56.597458362579346, 61.37022113800049, 57.92021819523403, 60.928614480154856, 58.00380849838257, 60.85854884556362, 56.30754130227225, 59.89142213548933, 58.01378263745989, 66.59723281860352, 22.092370646340505, 4.824144269738879, 6.437510337148394, 1.6034136414527893, 0.18432848900556564, 0.25976236696754185, 24.170686279024395, 73.22791263035366, 50.40860060283116, 71.15618910108293, 63.43503815787179, 27.398235695702688, 34.933927059173584, 49.45499856131417, 56.2174196924482, 63.43084144592285, 18.227959769112722, 0.444317486669336, 0.15972001877214226, 0.2189010695687362, 0.186996407274689, 0.08469833726329462, 0.1240918141390596, 0.15618232717471464, 0.1580000003533704, 0.11259573458560876, 0.211080546357802, 0.13038791343569756, 0.12546568470341818, 0.20496092044881412], [0.04736832609134061, 0.0589278961664864, 0.06055589166602918, 0.03109726669000728, 0.08477695233055524, 0.012554013186932673, 0.03323988689641867, 0.022386893995904496, 0.05970002830560718, 0.1224565040320158, 0.16713808929281576, 0.2081174382141658, 7.2965109177998135, 58.24902432305472, 57.72345910753523, 50.616890226091655, 33.35832922799246, 12.150301848139081, 26.498525619506836, 83.87958444867814, 37.381159033094136, 53.39679152624947, 53.268468720572336, 1.8884619687284743, 0.2784176016492503, 0.3542812908334391, 3.21542198743139, 3.45116394332477, 2.2125239968299866, 42.894287109375, 60.95904064178467, 61.564131464277, 58.444751603262766, 57.52520268304007, 48.04096024377005, 46.84449781690325, 43.2318549156189, 41.79285519463675, 40.265318053109304, 43.0643755367824, 50.254433972494944, 53.094159262520925, 53.95355067934309, 55.440030915396555, 51.75433118002755, 48.5437388420105, 53.327094146183555, 52.93713344846453, 45.60648168836321, 40.45512546811785, 40.38131822858538, 38.516810825892854, 40.41948815754482, 40.67608513150896, 38.11101170948574, 39.12224905831473, 39.88428579057966, 37.74039479664394, 38.3529896736145, 37.09651912961687, 38.267943722861155, 38.30708987372262, 37.95137684685843, 38.22166872024536, 37.35360247748238, 35.85509490966797, 39.49459259850638, 36.891918999808176, 38.26436192648751, 39.437454087393625, 37.8579409463065, 36.94440916606358, 37.271231583186555, 36.45623568126133, 36.90821599960327, 35.98860107149397, 37.48574679238455, 36.2499749319894, 38.215599468776155, 38.74409335000174, 41.1576578276498, 40.491745948791504, 45.40048497063773, 43.938191413879395, 50.98031227929251, 45.990765707833425, 55.47280556815011, 30.52984959738595, 36.27046169553484, 55.09621320452009, 46.575362818581716, 49.848930154527935, 46.213059425354004, 50.12340136936733, 45.32654571533203, 45.96325431551252, 44.29707281930106, 43.449535029275076, 43.76546267100743, 43.17504644393921, 42.122241497039795, 41.176973819732666, 36.326648303440635, 35.557489667619976, 36.5411183493478, 37.464971678597585, 36.73567485809326, 37.329724993024556, 36.535952363695415, 37.64592708860125, 34.50376408440726, 37.171931403023855, 37.09417758669172, 38.954731464385986, 37.01313727242606, 37.96511343547276, 38.03719752175467, 39.41266638892037, 37.711851596832275, 37.948173727308, 37.86281163351876, 37.54763787133353, 36.843441418239046, 37.491374833243235, 37.852966036115376, 37.80319261550903, 36.38697256360735, 39.79441431590489, 39.28948872429984, 45.870259625571116, 51.344571590423584, 54.41891322817121, 50.62265028272356, 51.32852125167847, 55.989939144679475, 51.64972257614136, 51.93021093096052, 53.55186489650181, 54.07323687417166, 50.872903551374165, 53.709901673453196, 49.70932000023978, 51.710210118974956, 53.34872388839722, 55.531535216740195, 58.47410079411098, 44.72263608660017, 0.7890846037438938, 3.4019839423043385, 1.1844794984374727, 0.05715304533285754, 0.023597307170608213, 4.04140841960907, 50.58188172749111, 42.36252062661307, 54.21681792395455, 68.35748944963727, 22.24297285079956, 12.200091770717076, 32.0692994253976, 41.04358925138201, 46.073602131434846, 13.066621593066625, 0.13394350478691713, 0.04016653860786131, 0.03117108790736113, 0.03144575209755983, 0.023000817213739668, 0.026331377515037144, 0.035322029276617935, 0.04421805084816047, 0.06383325651820217, 0.04065661731043032, 0.004651114976565752, 0.060304345163915835, 0.006485311755178762, 0.023383044471432055, 0.022955621692485044, 0.01845801169318812, 0.021601684790636812, 0.09064493674252715, 0.025497866794466972, 0.06647896633616515, 0.036179510943059406, 0.02453076440308775, 0.028426759809787785, 0.15609319481466497, 0.20317190858934606, 11.75695390360696, 69.03489712306431, 63.52965177808489, 57.37757083347866, 40.118116991860525, 19.30094575881958, 29.853400775364467, 73.0916028703962, 39.25041900362287, 59.643176896231516, 58.10686765398298, 1.9915413175310408, 0.25759368762373924, 0.5154399531228202, 5.508484942572458, 4.135023236274719, 3.005554037434714, 44.690080302102224, 60.966475214277, 65.38305595942906, 59.223331996372764, 60.30011517660958, 49.54442882537842, 49.2489914212908, 46.48359795979091, 43.11234242575509, 41.93737077713013, 45.49639442988804, 51.80712359292166, 55.80170202255249, 54.952420234680176, 57.074545996529714, 53.200001171657014, 51.99197346823556, 55.07128654207502, 53.45401341574532, 47.56492873600551, 42.230160917554585, 41.91073833193098, 40.877999782562256, 41.79817404065813, 42.14376354217529, 40.6299386705671, 42.83976806913103, 39.741399560655864, 40.632936818259104, 40.96875367845808, 38.86511012486049, 40.96299014772688, 40.688650948660715, 38.41982786996024, 40.89562736238752, 40.40278468813215, 38.25839342389788, 41.67992959703718, 38.11381878171648, 39.44907494953701, 40.50123371396746, 39.300060408455984, 38.62016180583409, 39.274848869868684, 37.1027238709586, 38.55157266344343, 38.79594080788748, 38.70272377559117, 38.073397636413574, 41.48873949050903, 40.803661005837576, 41.512425899505615, 42.476731640951975, 47.35470403943743, 46.29836245945522, 53.10675287246704, 49.21842629568917, 55.25681039265224, 32.86521209989275, 40.23184163229806, 56.71867316109793, 47.33160127912249, 52.35758420399257, 48.15254831314087, 52.10654926300049, 47.894422735486714, 49.45967469896589, 47.65229538508824, 46.44245420183454, 46.15136637006487, 47.3154501914978, 43.589113916669575, 43.344686712537495, 38.00821311133248, 37.48054606573922, 38.75914314814976, 39.913350105285645, 39.00949716567993, 39.56616946629116, 38.25601713997977, 40.79960673195975, 37.266600608825684, 38.67992326191494, 39.50651570728847, 41.479675565447124, 39.86545269829886, 39.99997329711914, 40.14453404290335, 40.23937347957066, 39.49927568435669, 39.81744064603533, 40.26927157810756, 40.12256383895874, 38.760150636945454, 38.415711062295095, 39.442727770124165, 40.51859378814697, 37.73173039300101, 40.77864054271153, 40.595051765441895, 47.526477405003135, 52.429883684430806, 54.159926073891775, 48.654131821223665, 52.20301110403878, 55.76066596167428, 54.38245950426374, 54.20169864382063, 54.88863229751587, 56.28545297895159, 52.604634353092735, 55.36664056777954, 52.06056261062622, 54.3668851171221, 55.41788700648716, 57.804165908268516, 58.21083354949951, 49.218019826071604, 1.8986517190933228, 0.8733660898038319, 2.5779901232038225, 0.307267743561949, 0.017103791502969604, 3.254992412669318, 55.59902654375349, 46.07316786902291, 49.961591720581055, 60.77892248971121, 23.649703400475637, 17.82817952973502, 37.18123851503645, 46.807047026497976, 55.09760284423828, 28.358278717313492, 0.07147620032940592, 0.07007248779492718, 0.014735375198402574, 0.0672196890892727, 0.024738333354304944, 0.06886945199221373, 0.03377609919490559, 0.03550572906221662, 0.008342752599024346, 0.06970016884484462, 0.029439381722893034, 0.07359764685056039, 0.06096083457980837, 0.13606255607945578, 0.14783298091164657, 0.13175016748053686, 0.1506393610366753, 0.24685136548110417, 0.20919914517019475, 0.08957383528883968, 0.22583898156881332, 0.1942165084183216, 0.21291348657437734, 0.377332618193967, 0.4939335957169533, 14.87469138417925, 80.67092718396867, 71.42618220193046, 65.73056316375732, 47.08875131607056, 21.848249162946427, 33.832488196236746, 91.53628390175956, 52.33215727124895, 64.41995225633893, 64.5046785899571, 2.7370363431317464, 0.36983125071440426, 1.3676387901817049, 11.743415338652474, 11.04317501613072, 4.28976309299469, 47.59774855204991, 65.39784172603062, 66.66454001835415, 61.793977873665945, 64.62075519561768, 51.683251108442036, 51.80605009623936, 48.05526658466884, 45.95744909558977, 43.68602391651699, 47.500598839351106, 54.50891671861921, 56.78996862683977, 57.67487382888794, 58.42811066763741, 55.5493677684239, 55.28395005634853, 55.904497146606445, 56.23483535221645, 48.894984177180696, 44.49859489713396, 43.788614068712505, 42.053304944719585, 44.03605331693377, 45.09114074707031, 41.25061082839966, 44.37221411296299, 42.31181614739554, 42.28844935553414, 42.61786345073155, 40.47887441090175, 42.73420408793858, 41.67051478794643, 39.95108229773385, 42.591064248766216, 41.09719112941197, 38.796072823660715, 42.84925583430699, 41.94155011858259, 40.86129283905029, 43.46168742861067, 42.02501882825579, 40.36981895991734, 40.62554393495832, 38.63271025248936, 40.62634992599487, 40.09441321236746, 42.25886392593384, 40.70208529063633, 43.67667511531285, 42.985513482775005, 44.73468426295689, 44.93230840138027, 50.804832049778526, 48.95864357267107, 55.64124379839216, 50.47656093324934, 57.52140201841082, 36.62868997028896, 42.35988031114851, 59.41843046460833, 50.94745772225516, 53.38744967324393, 50.03193180901663, 55.84538882119315, 49.76394673756191, 52.14584132603237, 49.82873174122402, 47.82096290588379, 47.881662368774414, 48.91575929096767, 45.645561831338064, 46.52598891939436, 41.01631409781319, 38.74616043908255, 40.60298660823277, 41.33268295015608, 40.63083151408604, 40.87379264831543, 42.64812980379377, 42.180036612919395, 38.786150796072825, 40.53021117619106, 41.218117577689036, 44.41987875529698, 41.076624461582725, 41.34363678523472, 42.596577644348145, 41.92634746006557, 40.519590854644775, 41.63505118233817, 42.32149498803275, 42.45473711831229, 41.27780955178397, 40.6170289175851, 42.267052377973286, 43.263135705675396, 40.01390096119472, 42.602441923958914, 43.57628754207066, 49.39173173904419, 55.78825725827898, 57.51397786821638, 53.26822900772095, 54.26170676095145, 58.23129252025059, 57.08279698235648, 56.34299101148333, 58.11443771634783, 59.65084770747593, 54.59890978676932, 59.846939768110005, 54.4646497453962, 57.9677334512983, 57.742903641292024, 61.37466103690011, 61.511887959071565, 50.929190908159526, 1.6981943441288812, 7.85276198387146, 5.254822713988168, 0.20640880561300687, 0.1457386961472886, 5.966497165816171, 60.16848155430385, 54.029633453914094, 62.22026375361851, 74.50426891871861, 33.02372482844761, 21.820819411958965, 45.45779023851667, 54.88020413262503, 61.94349615914481, 37.18922546931675, 0.3335163822131497, 0.1670340970158577, 0.11937294235186917, 0.09149712244314806, 0.15283489679651602, 0.09194766969553061, 0.18880709154265268, 0.14492012507149152, 0.1323909352400473, 0.10867317792560373, 0.07243844441005162, 0.14842630550265312, 0.11274915813867535], [0.012367013176637036, 0.04444579773449472, 0.02952984401157924, 0.05105142095791442, 0.011495140630618801, 0.029926987165319066, 0.06021064626319068, 0.09076517993318182, 0.06483414316815989, 0.004179519567904728, 0.17469698297125952, 0.1667169497481414, 18.923769746507915, 67.41089466639927, 52.19237688609532, 48.84311587469918, 29.614855221339635, 25.45395949908665, 28.856270006724767, 35.78877782821655, 35.16553831100464, 60.9102087020874, 31.371074948992046, 0.09024497427578483, 0.025478106158386384, 0.6824117334825652, 1.9919560381344386, 0.5540346992867333, 6.847229540348053, 47.43499047415597, 57.113153662000386, 63.535342352730886, 58.04646348953247, 52.989130292619976, 44.30168642316546, 46.90211575371878, 46.31064340046474, 44.42084108080183, 39.40556532996041, 41.66102007457188, 39.11318513325283, 44.729956013815745, 50.44315052032471, 53.57203551701137, 53.58952413286482, 51.085619177137104, 52.8447710445949, 51.86989361899239, 46.099105494362966, 38.266752106802805, 38.72901575905936, 39.09420265470232, 39.19146006447928, 39.91699096134731, 38.68547139848982, 39.64208548409598, 40.26160076686314, 38.163300377982004, 37.91117109571184, 38.328038692474365, 38.60217291968209, 36.50480011531285, 40.013894012996126, 38.61989777428763, 38.91312565122332, 38.42360768999372, 38.52276195798601, 39.29095826830183, 39.060642855507986, 37.198772294180735, 39.19825192860195, 36.837292262486045, 38.53819390705654, 36.96340901511056, 37.489384174346924, 36.239215646471294, 36.953872612544465, 35.85451820918492, 38.80440718787057, 40.62562383924212, 42.74335486548287, 44.50678334917341, 45.61854028701782, 45.24401501246861, 49.71474654333932, 47.59324959346226, 52.24650682721819, 27.810917002814158, 37.51893833705357, 50.11030054092407, 46.29415879930769, 48.889616693769185, 47.63829476492745, 50.48674004418509, 47.101688861846924, 48.74430206843785, 44.899151597704204, 45.653538363320486, 43.332166058676584, 41.259560108184814, 43.78857585362026, 44.11077077048165, 35.49269771575928, 36.826265471322195, 37.30838360105242, 40.36603913988386, 37.863433497292654, 38.02606650761196, 36.4504964692252, 37.469866684504915, 37.48976632526943, 39.003900391714915, 37.9006793158395, 38.67348575592041, 38.149786131722585, 37.14523294993809, 39.07059267589024, 37.392244883946006, 38.72013596126011, 38.170616831098286, 37.080263819013325, 37.579853194100515, 36.11136531829834, 35.7813606262207, 39.35478094645909, 37.09817974908011, 40.23779623849051, 38.29295376368931, 40.84642716816494, 47.26860196249825, 54.13950531823294, 40.238108907427105, 36.99019084657942, 53.245459760938374, 51.68223319734846, 52.633886269160676, 50.93037210191999, 49.637277603149414, 47.364459310259136, 47.132809843335835, 47.99821145193917, 48.63372496196202, 47.147995131356375, 50.534877164023264, 53.905722754342214, 54.74266801561628, 56.01490749631609, 13.12605995791299, 0.8330617068069321, 2.7988459978784834, 0.6651299893856049, 0.1292695248765605, 0.06414834782481194, 27.42275936262948, 56.383050850459504, 47.78363023485456, 49.91954122270857, 20.250097479139054, 24.95564338139125, 37.704740115574424, 44.40585034234183, 46.227595056806294, 32.25862046650478, 0.47266982815095354, 0.11932045088282653, 0.04078476882672735, 0.012973900834497596, 0.03915114827187998, 0.04427889508328267, 0.03990770124697259, 0.0642184472775885, 0.04386531441871609, 0.0005675062275258824, 0.015546921740419098, 0.03155995632654854, 0.014595595288223453, 0.022894402566765035, 0.036642149689474275, 0.03784290900720017, 0.020955900961001004, 0.05907416117510625, 0.027466934706483568, 0.042356812328632386, 0.05104528021599565, 0.037026536384863515, 0.08696247969887086, 0.18712440612060682, 0.09928552380629949, 25.295111519949778, 76.83908598763603, 56.955856868198936, 55.59215130124773, 37.71072598866054, 27.24351842062814, 19.990208796092443, 40.77066053662981, 41.40634427751814, 66.44356645856584, 33.49078968593052, 0.04105897839846356, 0.013337258881490146, 1.962334999016353, 1.9362419077328272, 1.1494270307677132, 7.030279832226889, 51.52053819383894, 60.39631298610142, 65.42923368726457, 60.43142223358154, 55.57238367625645, 46.13436412811279, 49.99772930145264, 47.36622762680054, 46.402984959738596, 42.11443172182356, 43.70541286468506, 40.79861313956124, 47.62103196552822, 52.847039631434846, 55.04697479520525, 55.44269207545689, 54.76928309031895, 55.34843976157052, 55.42903886522566, 50.009965079171316, 39.971885204315186, 40.623049531664165, 40.53251797812325, 40.629035404750276, 41.974831989833284, 39.97980267660958, 40.16973863329206, 41.68612739018032, 40.160358565194265, 40.600009305136545, 40.29714775085449, 40.63712658200945, 38.77172286169869, 41.30534873689924, 40.54289511271885, 38.60787391662598, 39.54115942546299, 40.57810163497925, 39.94879634039742, 39.980323791503906, 38.64663096836635, 39.6151716368539, 40.61946078709194, 40.847702162606375, 39.317031383514404, 38.99732739584786, 38.268242495400564, 38.89710310527256, 37.337183884211946, 39.746631554194856, 42.0815806388855, 44.46387822287423, 45.729228564671104, 48.72422177450997, 47.53147315979004, 52.20213563101632, 51.21770095825195, 53.19424111502511, 31.609700407300675, 40.87029423032488, 51.24970088686262, 48.00290148598807, 49.992118631090435, 48.44001613344465, 52.19305780955723, 49.256822041102815, 50.77429471697126, 48.574324812207905, 47.12776892525809, 45.654934951237266, 44.315662724631174, 45.016239166259766, 45.17272302082607, 38.232372420174734, 39.150038378579275, 40.35749980381557, 41.5089761189052, 39.33395719528198, 39.134311131068635, 39.04008660997663, 38.670814173562185, 38.371933937072754, 41.449562072753906, 40.15257658277239, 40.438289982931956, 40.69361891065325, 39.562910761152, 40.66609362193516, 39.68221827915737, 40.641726289476665, 40.3782262802124, 39.76454053606306, 39.74337632315499, 38.25505134037563, 39.22072240284511, 40.08935144969395, 38.98658895492554, 41.40929378782, 40.24205895832607, 42.48474986212594, 48.693340505872456, 57.05921132223946, 41.30248260498047, 40.1209831237793, 55.936809744153706, 54.18416486467634, 54.39285748345511, 52.912203311920166, 51.187646525246755, 48.331235136304585, 49.59735325404576, 50.942121505737305, 48.9573894228254, 48.304383822849815, 52.49159411021641, 57.818649428231375, 56.123181274959016, 59.35374273572649, 16.121057510375977, 0.3179551043680736, 2.749271252325603, 1.4349408873489924, 0.04480647641633238, 0.1371843780257872, 29.612322602953228, 64.16821902138847, 45.928447314671104, 51.81067759650094, 17.12472653388977, 26.233323301587784, 44.48260014397757, 50.20997244971139, 51.10046052932739, 45.743732929229736, 2.258572531597955, 0.19254564307630062, 0.017429624018924575, 0.10284513887017965, 0.06799359220479216, 0.0649545763486198, 0.02031054630476449, 0.031914443376341035, 0.017473150344033326, 0.007008785406859326, 0.062191588538033624, 0.0323124720182802, 0.04256112600809761, 0.13221100132380212, 0.1270361268626792, 0.2063285077789, 0.1283068736749036, 0.12125224008091859, 0.14059818269951002, 0.1846755596676043, 0.17346028504627092, 0.1260490891124521, 0.17234237146164688, 0.25518372122730526, 0.26801365134971483, 31.323698656899587, 84.92931134360177, 66.17285074506486, 65.95742879595075, 40.25653900418963, 35.96299001148769, 36.653133732931956, 46.803298473358154, 47.57253006526402, 73.0411103112357, 37.0268634387425, 0.35250754601189066, 0.08370739793671028, 1.3977158048323222, 5.439536665167127, 2.238029965332576, 9.07264505113874, 56.70631231580462, 62.997086252485005, 67.11969566345215, 62.731845719473704, 58.275552545275005, 48.16396767752511, 52.51476287841797, 50.3475467818124, 48.556169169289724, 43.42439644677298, 45.849890981401714, 43.028776441301616, 49.51241847446987, 55.501609325408936, 56.46618604660034, 58.499399185180664, 56.35459450313023, 56.90498563221523, 57.24184819630214, 52.256157875061035, 42.461542878832134, 42.575799056461875, 43.80363259996687, 43.980276652744834, 44.41345167160034, 42.534158502306255, 42.47289276123047, 44.720395292554585, 42.34472976412092, 41.76762628555298, 41.29771614074707, 42.67664868491036, 38.897481782095774, 42.7882193837847, 41.93050595692226, 40.55780594689505, 41.67348166874477, 42.35103872844151, 41.714840820857454, 40.53209413800921, 40.44434881210327, 43.97416918618338, 42.05631351470947, 42.21403762272426, 41.80684886659895, 40.72536175591605, 39.87632315499442, 40.44022158214024, 39.56385224206107, 41.73003305707659, 45.125332832336426, 46.93664482661656, 48.54059478214809, 49.8992212159293, 49.871897424970356, 53.59886251177107, 54.08506270817348, 54.136646134512766, 35.26516853060041, 40.89414044788906, 52.55522918701172, 50.95547594342913, 52.37094906398228, 50.118732179914204, 55.86440256663731, 51.09640972954886, 51.49610832759312, 50.976105145045686, 49.9099110194615, 48.84167759759085, 46.67842197418213, 48.62178795678275, 48.7848413331168, 40.45008455004011, 41.5425637108939, 42.50360379900251, 43.49610880443028, 41.19515378134591, 40.54209606988089, 42.27889558247158, 41.98669603892735, 39.8918628011431, 43.75559275490897, 42.62387364251273, 42.156464849199565, 42.28159843172346, 40.7456887108939, 42.736420563289094, 42.49082258769444, 42.18531724384853, 41.63550628934588, 41.674298082079204, 41.7931261743818, 40.21492624282837, 41.48362561634609, 43.661642687661306, 39.93979147502354, 44.208094188145225, 43.177408831460134, 45.07791485105242, 51.191530568259104, 59.62609822409493, 45.5361659186227, 43.770385469709126, 58.352875573294504, 58.82384531838553, 57.37504168919155, 55.39294992174421, 54.250944001334055, 52.57687282562256, 51.84024912970406, 53.98434509549822, 52.40266064235142, 52.257478032793315, 54.369442054203574, 59.53578553880964, 58.791890553065706, 61.40972859518868, 15.985241072518484, 3.4613890860761916, 8.678643107414246, 1.4831162222794123, 0.2662829527897494, 0.32078196267996517, 32.781006881168906, 70.23230797903878, 56.95954983575003, 56.71984393256051, 28.787376880645752, 36.990694590977256, 51.32638120651245, 59.7454891204834, 56.38246372767857, 56.76906844547817, 3.8735308221408298, 0.37851831742695397, 0.15826046280562878, 0.21945383133632795, 0.16831320337951183, 0.1034316848963499, 0.10024455163095679, 0.11155733851982014, 0.11740992697221891, 0.1722209815468107, 0.15080645707036766, 0.16131277116281645, 0.09922533775014536], [0.0578024440578052, 0.015487840000007833, 0.024330677996788706, 0.059215215034782887, 0.011613842698612382, 0.010651234753562935, 0.086097306837993, 0.015210400601582868, 0.08102428048316922, 0.03687890752085617, 0.08388780682746853, 0.0658801184701068, 31.84143325260707, 68.34387098039899, 50.033606324877056, 40.28382805415562, 20.88265974181039, 21.509486266544886, 44.97789205823626, 31.567945207868302, 44.88636343819754, 62.420892987932476, 13.46856359073094, 0.21701034530997276, 0.14055801342640603, 0.5512378322226661, 1.6338898518255778, 0.3202693430440766, 17.953858545848302, 59.354534830365864, 61.83143561226981, 59.25184045519148, 56.091282095227925, 45.90807867050171, 44.15751477650234, 46.992654255458284, 45.78904908043997, 46.45999492917742, 42.486052649361746, 39.5784330368042, 40.783601556505474, 39.53036887305123, 42.46980428695679, 48.16018090929304, 50.80533232007708, 55.576014110020225, 52.13100344794137, 51.39133991513933, 42.47307341439383, 37.55490916115897, 38.092786584581646, 37.79289538519723, 39.11342484610421, 38.589565413338796, 40.70041772297451, 38.44500119345528, 39.27249690464565, 39.34696422304426, 38.23521423339844, 37.44924095698765, 38.73049572535923, 37.595365047454834, 38.280617237091064, 36.458459104810444, 38.66347687585013, 37.910795892987935, 39.48344768796648, 38.540907178606304, 37.68213415145874, 37.471721853528706, 38.1058144569397, 37.63415684018816, 37.923306124550955, 39.325066975184846, 37.013408252171104, 36.198603425707134, 37.47159331185477, 36.912756647382466, 40.333862032209126, 41.78491340364729, 45.257192271096365, 43.573918206351145, 47.581479345049175, 45.75592354365757, 51.03039142063686, 46.62252719061715, 53.71180547986712, 27.85150490488325, 34.6450765473502, 53.43038606643677, 45.46082660130092, 51.073664801461355, 45.93073674610683, 49.83224752971104, 45.039671966007774, 47.82889427457537, 46.877199513571604, 45.38789136069161, 42.21188020706177, 43.731385231018066, 43.732660225459504, 44.15319299697876, 38.45101833343506, 35.90499687194824, 38.29177256992885, 39.03868654796055, 38.71155146190098, 37.225303990500315, 36.45388719013759, 38.31090790884835, 37.99069670268467, 37.697246483394075, 38.50148657390049, 37.68033456802368, 38.82596049989973, 37.696569034031455, 39.12240539278303, 38.02980463845389, 38.784497124808176, 37.67022146497454, 38.39803831917899, 37.22702019555228, 38.745590686798096, 36.99847657339913, 37.269202709198, 38.67316613878523, 38.804518359048025, 38.52164329801287, 37.9284199987139, 45.96985510417393, 51.03599166870117, 45.673490115574424, 47.9035769871303, 51.14721843174526, 50.82142782211304, 49.845080852508545, 45.65757874080113, 46.15547275543213, 45.27019929885864, 45.72163070951189, 46.66873618534633, 42.53125762939453, 47.19156033652169, 49.76470061710903, 53.1749563898359, 55.18663706098284, 57.65701001031058, 38.632439272744314, 1.9415251442364283, 1.2606966772249766, 1.8014483749866486, 0.10339770386261599, 0.07525521969156605, 6.130177617073059, 51.01495599746704, 39.88690178734915, 27.857794761657715, 24.110758066177368, 14.831958225795201, 27.416565043585642, 41.80675506591797, 45.27722045353481, 42.623230934143066, 6.288644748074668, 0.2748752145894936, 0.033812085299619606, 0.04815037841243403, 0.043479024432599545, 0.03299790095271809, 0.05284779152965971, 0.06360059364565782, 0.014857184108612793, 0.014866205231685723, 0.013816559055287923, 0.01986200751603714, 0.0843015910525407, 0.05069074906142695, 0.029060494553829943, 0.018324855981128554, 0.01265619123088462, 0.039743265070553334, 0.027167675318196416, 0.04768271172153098, 0.015511492034420371, 0.029220479540526867, 0.03151042327018721, 0.10167655907571316, 0.06690139509737492, 41.195296219417024, 75.82301616668701, 55.04278155735561, 45.727241379874094, 26.006513254983084, 29.999781949179514, 37.612704277038574, 32.51196568352835, 50.955892835344585, 66.91271577562604, 15.101306881223406, 0.33309075076665196, 0.1016388868114778, 1.8913274492536272, 5.566139357430594, 0.9641451729195458, 20.81805886541094, 63.28627722603934, 63.334039143153596, 61.15107495444161, 57.1328135899135, 48.81100130081177, 46.959014551980154, 49.40003831045968, 48.3635790007455, 49.02508224759783, 44.552749156951904, 40.8018718447004, 43.53647436414446, 42.122620173863, 43.88089656829834, 50.6537504196167, 52.811537810734336, 56.03933041436331, 54.315041133335654, 54.20732321058001, 45.00938476834978, 40.96029077257429, 41.14534214564732, 39.619649750845774, 41.68676315035139, 39.71288415363857, 42.43929474694388, 40.47462558746338, 40.84831012998308, 40.50921024594988, 39.92834779194423, 37.73553105763027, 40.21448850631714, 38.97095203399658, 40.11250284739903, 39.39464623587472, 39.65712138584682, 38.8690949167524, 39.377581460135325, 39.38683646065848, 40.35421330588204, 39.70872565678188, 39.088220255715505, 39.46485778263637, 39.52263552801949, 39.185196263449534, 38.88116046360561, 37.41189786366054, 38.67708839688982, 39.10578530175345, 43.17849275044033, 43.21365410940987, 47.736365113939556, 44.832754611968994, 48.328619139535085, 48.84755229949951, 53.99070617130825, 46.9118640763419, 55.12429434912545, 28.877904960087367, 36.22411721093314, 53.43363434927804, 49.06281444004604, 53.62445272718157, 48.65998567853655, 50.91492625645229, 46.67110552106585, 48.990844999040874, 48.5498879977635, 47.33503021512713, 44.08249160221645, 47.05479894365583, 45.6990316935948, 46.63210180827549, 39.983092648642405, 38.83499663216727, 39.25512988226754, 39.72359480176653, 39.81952510561262, 38.75719765254429, 39.137458665030344, 40.44757277624947, 40.21993589401245, 38.869734151022776, 40.52116114752633, 39.06663220269339, 39.56205265862601, 40.04492119380406, 40.50030960355486, 38.988534450531006, 41.08918333053589, 39.30327047620501, 38.99812991278512, 39.9086183820452, 39.955515248434885, 39.69936295918056, 38.52640976224627, 40.433391502925325, 41.159728390829905, 40.98027031762259, 40.82688883372715, 48.32257420676095, 51.907156808035715, 49.71865143094744, 52.353238105773926, 50.740356240953716, 52.33900819505964, 51.78940568651472, 48.741891043526785, 47.91422857557024, 46.96955496924264, 48.3181586265564, 47.44554826191494, 44.059229033333914, 47.83385876246861, 51.204676559993196, 55.41100134168352, 57.26135526384626, 59.19039058685303, 42.96777473177229, 2.7858385358537947, 1.7096946984529495, 3.1249460194792067, 0.09665586134152752, 0.28018287835376604, 5.637722304889134, 58.6123491014753, 44.526269572121755, 31.31090702329363, 29.583866255623953, 26.31579668181283, 33.22808524540493, 47.31595046179635, 48.80129814147949, 55.620426995413645, 11.585249151502337, 0.345454853028059, 0.0724450261997325, 0.08770050866795437, 0.04433916595631412, 0.014214233162679842, 0.024801282744322504, 0.015930168496977006, 0.05351032329989331, 0.03280560073575803, 0.0436311621618058, 0.005326766221384917, 0.04216293451775398, 0.14012388672147477, 0.18389884063175746, 0.14234826021960803, 0.15446221376104013, 0.10217839000480515, 0.11759785403098379, 0.11806875733392579, 0.16813413798809052, 0.22178784252277442, 0.12089191084461552, 0.11813872786504881, 0.19264295856867517, 49.36945234026228, 86.1572664805821, 62.130527768816265, 54.42632348196847, 31.20550979886736, 31.790666239602224, 59.728799547467915, 44.118049008505686, 59.10544885907854, 74.58957195281982, 17.865267276763916, 0.4200272900717599, 0.2677824880395617, 1.5463778334004539, 8.513460976736885, 2.9662730480943407, 23.21659091540745, 65.65304211207798, 65.72679724012102, 63.50753566196987, 60.26062856401716, 50.707331453050884, 48.95056629180908, 52.28837319782802, 50.35099308831351, 50.68151542118618, 46.80398981911795, 43.723408699035645, 46.19275678907122, 45.20841939108712, 47.11155877794538, 54.745937143053325, 54.44035884312221, 60.23675455365862, 56.55902092797415, 55.9694766998291, 45.8454441343035, 42.636529786246165, 43.32365451540266, 41.405774525233674, 43.839394978114534, 41.91261434555054, 45.21563509532383, 42.94527646473476, 42.479844433920725, 43.83231476375035, 40.8123323576791, 39.837795393807546, 41.44361094066075, 41.29326581954956, 41.52042327608381, 39.87304013116019, 41.5057486806597, 41.6660783631461, 42.47927468163626, 43.04278400966099, 41.563849517277305, 41.40533331462315, 41.521489824567524, 41.924881390162874, 41.250402382441926, 42.05949926376343, 41.07576635905674, 38.52780982426235, 41.46491411754063, 42.291541303907124, 44.98269326346261, 46.04863725389753, 49.69529158728463, 46.468436990465435, 51.79858078275408, 50.571542807987754, 56.01148203441075, 50.23791810444423, 55.15589823041643, 31.832331112452916, 38.90535061700003, 54.69677168982369, 51.57719727924892, 55.51445654460362, 50.86892918178013, 54.31852912902832, 48.645446572984966, 49.5472845349993, 51.089211395808626, 49.5356011390686, 46.402408259255544, 49.64607402256557, 47.281442233494346, 47.41856145858765, 40.873271533421104, 39.760222230638774, 42.835814544132774, 42.691611630576, 42.399151529584614, 40.901005268096924, 40.17406736101423, 42.68181814466204, 41.37805468695504, 40.505440848214285, 41.88686432157244, 41.811469418661936, 42.648723874773296, 41.77401515415737, 43.263170446668354, 41.63898386274065, 44.03937802995954, 40.61796345029558, 42.39521190098354, 41.46897186551775, 43.30413007736206, 41.53152649743216, 40.92796080453055, 42.849134240831646, 43.28677347728184, 42.91466964994158, 42.38550179345267, 50.229722704206196, 55.909263610839844, 50.45277030127389, 52.61035966873169, 53.56277356828962, 55.28114993231637, 55.36050878252302, 49.789127009255544, 51.53068951198033, 50.54444483348301, 51.611354623522075, 52.28117833818708, 46.6191851070949, 52.17067418779646, 53.649726799556184, 58.311644962855745, 59.46713733673096, 61.677407945905415, 43.46747180393764, 3.1586413085460663, 5.6168021474565775, 4.418249181338719, 0.382838712739093, 0.3895553680402892, 7.66338448865073, 64.25760759626115, 49.97582857949393, 39.34730121067592, 35.220064299447195, 24.75226787158421, 38.76168271473476, 57.11295216424124, 57.91541699000767, 63.592143876211985, 14.228808556284223, 0.5753714229379381, 0.13465181392218384, 0.24608809500932693, 0.13978143009756291, 0.1565023921430111, 0.12269891745277814, 0.14449353010526725, 0.1504261517631156, 0.06992948653974704, 0.15090530605188437, 0.10263135962720428, 0.1587452625057527], [0.04802039824426174, 0.051162507318492444, 0.02774585161491164, 0.01752648489283664, 0.03095227393454739, 0.05032229097560048, 0.06562345581395285, 0.0335385814043028, 0.021793379415092722, 0.030368465797177384, 0.08669133710541896, 0.4409171577010836, 49.56017344338553, 62.1142064503261, 52.261355127607075, 42.27613367353167, 26.56369972229004, 15.824654306684222, 26.814373356955393, 35.62676320757185, 46.403447014944895, 55.049934727805, 2.8547622774328505, 0.200531253857272, 0.11562158007706914, 3.6322570145130157, 0.8558865934610367, 3.936406808240073, 48.58458730152675, 68.0371219090053, 58.994402749197825, 58.269601413181846, 47.62746599742344, 45.819631576538086, 45.793846811567036, 46.64998994554792, 50.071130071367534, 51.46204825810024, 47.34068257468087, 44.17233180999756, 39.74933787754604, 39.34651606423514, 40.352528367723735, 39.78804281779698, 45.12574625015259, 44.784117221832275, 45.62569693156651, 41.700805459703716, 39.155364172799246, 39.20831639426095, 38.32763222285679, 39.53519787107195, 37.33220897402082, 38.89304883139474, 38.91912194660732, 36.73936782564436, 39.04950489316668, 37.882530621119905, 39.497034890311106, 36.87436090196882, 38.44428552900042, 38.42887442452567, 37.013967582157676, 39.30548695155552, 38.11485406330654, 37.71184464863369, 38.75490127290998, 36.10557746887207, 39.23070696422032, 37.92920861925398, 37.71780967712402, 38.41859456471035, 39.62750816345215, 35.92212765557425, 36.27785457883562, 35.661917618342805, 37.08706610543387, 38.14678798403059, 42.49167374202183, 44.098357813698904, 47.54263891492571, 45.79685190745762, 50.02577223096575, 48.40051909855434, 52.72847209657942, 45.31998661586216, 54.204759325299946, 25.94715826851981, 27.84004385130746, 49.582859311785015, 42.11981310163225, 47.03221729823521, 44.27907003675188, 46.70577703203474, 44.28573335920061, 49.6225335257394, 45.20888144629342, 47.84884602682931, 43.068547930036274, 44.679619789123535, 44.95865249633789, 46.60570560182844, 40.7022659437997, 36.81574937275478, 36.202456201825825, 36.890525885990684, 39.09517887660435, 37.5424336705889, 35.09907531738281, 39.63129145758492, 38.714299474443706, 37.464808395930696, 36.876268182482036, 37.726001603262766, 37.06316082818167, 38.705662863595144, 36.272566999707905, 39.021392481667654, 37.55318948200771, 37.956063406808035, 39.561448165348594, 36.921507903507774, 37.247163023267476, 36.540239402226035, 37.4994660105024, 38.72785193579537, 37.891115120479036, 38.50098977770124, 38.60023784637451, 43.26842328480312, 49.05373314448765, 53.84133032390049, 52.47080857413155, 50.18208238056728, 47.42936590739659, 45.79082087108067, 41.720107555389404, 43.05523518153599, 42.754326071058, 41.697272300720215, 40.96316385269165, 42.07847479411534, 45.637543610164094, 50.86715391704014, 51.541407108306885, 53.950715814317974, 56.15934317452567, 51.63919258117676, 14.917626040322439, 0.6729271709918976, 1.1601243253265108, 0.09441900279905115, 0.08932223450392485, 1.1275939451796668, 35.97841501235962, 48.916499274117605, 35.59158795220511, 20.857785190854752, 9.64697446141924, 21.148051398141043, 39.782682282584055, 45.427110467638286, 51.96870047705514, 20.460330860955374, 0.24389121575014933, 0.0749585981081639, 0.06954656208732299, 0.030689107520239692, 0.02891890804416367, 0.01505558774806559, 0.05783322240625109, 0.04936687295724239, 0.08869583133075919, 0.019541379363675202, 0.020109079079702497, 0.001880645045145814, 0.053105994460306, 0.0285816286424441, 0.0698891883449895, 0.017001517615946274, 0.030978662161422626, 0.03558353328012994, 0.03907012779797826, 0.03742423593731863, 0.006632400759761887, 0.04285380869571652, 0.04254107190562146, 0.8935343761529241, 60.30560425349644, 68.21442604064941, 59.159130641392295, 48.455385548727854, 29.409532478877477, 18.928159270967754, 26.558719600949967, 40.65799897057669, 52.37588575908116, 62.132681710379465, 2.7335707119532993, 0.1446666515299252, 0.2545698641666344, 4.1232651472091675, 2.574084367070879, 3.3984510004520416, 53.21567283357893, 67.54031181335449, 63.598265239170615, 59.65327262878418, 51.9458270072937, 46.93540457316807, 48.72874852589199, 48.26594638824463, 54.29389776502337, 51.64291334152222, 51.13151897702898, 45.88345078059605, 41.35489634105137, 41.20796625954764, 41.933792454855784, 41.536074093409944, 48.12341104234968, 47.01925195966448, 48.081430026463096, 42.634275095803396, 41.79264327457973, 40.480632305145264, 39.65680871691023, 41.55546304157802, 39.79218047005789, 39.82706042698452, 41.335726261138916, 38.4341585295541, 41.03339276994978, 40.12400211606707, 41.18188272203718, 38.06837061473301, 39.70738465445382, 39.35301610401699, 38.117723669324604, 39.70627294267927, 40.17589473724365, 39.49454743521554, 39.279344354357036, 38.239421367645264, 40.40754073006766, 39.77666514260428, 39.288623673575266, 39.58007975987026, 41.159412247794016, 37.18891627447945, 38.498863628932405, 37.22570351191929, 38.98556409563337, 40.4748409816197, 44.2410112789699, 45.47743974413191, 48.96419865744454, 47.539804049900596, 51.427776268550325, 50.165896551949636, 53.347247396196636, 48.278967312404085, 55.143509592328755, 27.04145438330514, 27.944544758115494, 50.94616535731724, 43.91545690808977, 49.624037810734336, 45.18517419270107, 49.02020461218697, 45.63544178009033, 51.18229988643101, 47.90201016834804, 48.34227234976632, 44.620459352220806, 47.3980781691415, 47.88714797156197, 47.10719183513096, 42.3478217124939, 37.48629222597395, 37.64108419418335, 38.618959767477854, 41.34630836759295, 39.563063621520996, 38.921268939971924, 40.360459736415315, 40.50974873134068, 39.467157636369976, 39.2354108946664, 39.863562788282124, 38.33436155319214, 40.63644565854754, 37.90784985678536, 39.343010698046, 40.10816022327968, 40.21237277984619, 39.99489416394915, 39.856385299137656, 39.43853453227452, 38.58340583528791, 38.955766745976035, 40.94843019757952, 39.9548100062779, 39.603606360299246, 40.67789166314261, 43.67948566164289, 51.72677115031651, 55.48867872783116, 53.438925402505056, 52.393343108040945, 49.32705790655953, 47.78599262237549, 44.66278430393764, 44.31155286516462, 44.379805019923616, 43.58003609521048, 43.62572397504534, 42.6295051574707, 46.041529246738975, 53.5538763999939, 52.93004281180245, 56.60654313223702, 58.08203131811959, 53.9975015095302, 16.926841838019236, 0.5946556595819337, 2.0972564220428467, 0.29183305320995195, 0.018360163550823927, 0.49084170162677765, 37.911799907684326, 53.95001752035958, 37.559091976710725, 26.05449751445225, 16.93842795916966, 28.959299632481166, 44.584613595690044, 51.30327149799892, 59.190293312072754, 29.916910784585134, 0.20016058374728474, 0.023102414262081896, 0.012145537650212646, 0.09408198124063866, 0.0531267270978008, 0.042184722277202776, 0.020868510739611726, 0.01113809720014355, 0.012628992154662098, 0.0782967054152063, 0.053362131251820495, 0.00680148193246818, 0.16558816603251866, 0.1462197910462107, 0.11158065976841108, 0.08630951187972512, 0.09144804400524922, 0.22917813381978444, 0.1044046226888895, 0.14085199550858565, 0.06759741596345391, 0.1104993260066424, 0.11624094684209142, 1.7541010699101856, 71.02290180751255, 74.58184555598667, 67.69247041429792, 55.20386511938912, 34.977412360055105, 22.60019711085728, 35.26596409933907, 48.78961821964809, 57.025196416037424, 66.02847412654332, 3.865467003413609, 0.4305043321635042, 0.24986281245946884, 8.895757811410085, 6.082039628710065, 5.32335844210216, 53.09753261293684, 71.88956451416016, 66.43991865430559, 62.304260526384624, 53.366858686719624, 49.622279916490825, 50.59157446452549, 50.552713189806255, 55.928944383348735, 55.89164297921317, 53.14249093191964, 48.48919895717076, 43.74314158303397, 43.693969181605745, 45.78402553285871, 43.884030205862864, 49.33306115014212, 49.201597758701865, 49.68983725139073, 44.53127922330584, 42.080812862941194, 43.701094559260774, 42.365932192121235, 45.03918906620571, 40.74194710595267, 41.535914284842356, 43.61504111971174, 39.82534074783325, 43.394918714250835, 43.58343723842076, 43.877040318080354, 40.37904616764614, 41.70875072479248, 41.709122453417095, 40.034568377903526, 42.598422391074045, 41.54529087884085, 41.613338061741416, 41.28939914703369, 39.45535612106323, 42.13283749989101, 41.93733603613717, 41.0283796446664, 41.818542684827534, 43.16315460205078, 39.26486778259277, 41.16463034493582, 39.99129499707903, 40.48376594270979, 41.47171292986189, 46.71401064736502, 47.71820947102138, 51.03894117900303, 49.568469592503135, 54.49571166719709, 53.43122679846627, 56.38546187537057, 50.41119922910418, 56.63219935553414, 29.214638982500347, 30.116827828543528, 50.11174924033028, 45.785700048719136, 49.676534925188335, 46.63396739959717, 49.802238259996685, 47.08930022375924, 52.58350140707833, 49.02389063153948, 51.404729093824116, 47.42321327754429, 49.40118476322719, 49.14927087511335, 49.96875531332833, 45.1684707232884, 39.68463625226702, 40.86170278276716, 41.4576358795166, 44.38695124217442, 41.806570938655305, 40.4203462600708, 43.4630458014352, 42.609327588762554, 40.51576239722115, 41.001934800829204, 42.15822621754238, 40.35364702769688, 43.2516816002982, 39.51380436761038, 41.437374932425364, 41.7285669871739, 41.5050608089992, 42.42116689682007, 42.18675204685756, 42.87543317249843, 40.28860146658761, 42.30948502676827, 43.41296666009085, 41.52166700363159, 41.97218472617013, 42.370201860155376, 47.006161553519114, 54.54648215430123, 57.773680686950684, 57.740718432835166, 55.859347752162385, 51.089374678475515, 50.791661739349365, 46.566135610852925, 48.62728745596749, 48.81260633468628, 46.59603023529053, 46.44906541279384, 45.598869936806814, 49.57745361328125, 56.8392139843532, 55.10933835165841, 59.13569436754499, 60.649505342756, 54.4798697744097, 18.959471327917917, 4.195417846952166, 4.287005960941315, 0.1652873714587518, 0.1225241268319743, 1.380730933376721, 45.764723437173025, 58.8285561970302, 48.36668484551566, 25.901461703436716, 15.451275484902517, 31.654742104666575, 52.75270046506609, 58.68937683105469, 66.55687768118722, 36.41281986236572, 0.40743015174354824, 0.175851116755179, 0.2182177169514554, 0.21263781136700086, 0.12750598522169249, 0.14124329308313982, 0.1740698537656239, 0.12647443557424204, 0.18988611150000775, 0.11593146702008587, 0.11275702914489166, 0.11160997926656689], [0.021398519531690648, 0.022976233890014033, 0.051608016448361535, 0.02261842371496771, 0.02804155378336353, 0.007217882334121636, 0.08997009295438017, 0.11670024719621454, 0.016142617811315825, 0.12580370370830807, 0.14168675642992767, 5.466006696224213, 60.87529400416783, 57.261657510484966, 48.27169949667794, 38.47116810934884, 15.599372863769531, 24.81446467127119, 37.9974434035165, 33.87850611550467, 59.95752034868513, 40.77150126865932, 0.6441053918429783, 0.04961420575688992, 0.16563209438962595, 2.2996070725577216, 2.261970634971346, 17.0754360130855, 66.69682134900773, 55.02278116771153, 61.12265682220459, 51.03559562138149, 49.42319318226406, 46.44798844201224, 50.64439467021397, 48.12725339617048, 52.23340947287423, 51.49464225769043, 52.230953284672324, 47.90289258956909, 43.98931278501238, 38.31668186187744, 40.06983743395124, 38.51789474487305, 38.83169971193586, 40.89335182734898, 42.005866118839805, 39.58037505831037, 40.934193338666645, 37.39295012610299, 39.342510427747456, 37.71965094975063, 38.7263719694955, 37.121827942984446, 38.50370304925101, 37.778189522879465, 38.92042473384312, 38.203082289014546, 38.47246742248535, 36.55644260134016, 37.81679718835013, 36.76761225291661, 38.08401795795986, 35.28940037318638, 40.138190337589805, 36.41266005379813, 38.859614099775044, 36.11157029015677, 39.72104828698294, 37.45218699319022, 38.841409819466726, 36.00463056564331, 37.996908392224995, 34.61482409068516, 37.50488907950265, 35.65310730252947, 36.658011368342805, 39.13017347880772, 45.82040977478027, 43.83963469096592, 50.35619381495884, 44.39230482918875, 50.22560589654105, 46.43813937050955, 52.5116639818464, 45.82682296207973, 52.869385038103374, 25.10123246056693, 21.15044505255563, 49.3791937146868, 40.8553660256522, 49.1968069757734, 44.88620710372925, 49.75186729431152, 47.35792105538504, 50.36791542598179, 47.40494646344866, 44.761667592184885, 42.38912180491856, 45.770486967904226, 43.79314776829311, 45.545337540762766, 41.870532580784385, 36.355625765664236, 37.28420386995588, 38.06451089041573, 39.17527770996094, 39.04888997759138, 36.87824494498116, 37.24003069741385, 38.064701965876985, 36.22957502092634, 37.6318222454616, 38.15845053536551, 36.79837540217808, 37.917896951947895, 38.1349447795323, 38.73995917184012, 36.50872932161604, 37.414145605904714, 36.90005881445748, 37.564657483782085, 36.5650166784014, 39.03130408695766, 38.58934307098389, 38.259147303445, 37.08330365589687, 38.35134295054844, 39.605055059705464, 40.2833069392613, 42.02054418836321, 43.14924430847168, 45.49053709847586, 44.58476645605904, 43.010485308510916, 40.751410552433555, 39.84758540562221, 40.79670933314732, 40.696033409663606, 39.42985623223441, 41.125400815691265, 41.51098762239729, 46.407862595149446, 50.61957917894636, 52.50618880135672, 53.126152242933, 55.772293772016255, 57.084982190813335, 37.09807205200195, 2.10943227154868, 1.822699440377099, 0.19700380813862595, 0.07094806259764092, 0.10859520746661083, 17.017095463616506, 55.761885370527, 35.95448194231306, 42.325903620038716, 23.27762562888009, 21.89699251311166, 39.644750118255615, 46.90030574798584, 53.92470175879342, 27.85168034689767, 0.23785884944455965, 0.04634037607216409, 0.03878235091854419, 0.047968863509595394, 0.016175073837595325, 0.07236492514078106, 0.028451619636533514, 0.006686400696967861, 0.06467084693057196, 0.045449049078992436, 0.060693295007305484, 0.024473224633506367, 0.0455344596744648, 0.03897702940074461, 0.058641934368227205, 0.0760449937411717, 0.030884189730776206, 0.059770487381943634, 0.02491053706035018, 0.029534644646836177, 0.07263355036931378, 0.14093925511198385, 0.16847560395087513, 7.753814424787249, 70.59840856279645, 62.742351395743235, 57.37851578848702, 43.73755523136684, 24.299194949013845, 24.618692227772303, 34.52935082571847, 41.141326086861746, 67.05397265298026, 44.13658332824707, 0.6338276490569115, 0.008494031981432011, 0.5185468292662075, 2.7015727375234877, 1.4753852656909396, 17.622653552464076, 70.14411449432373, 58.1666464805603, 63.10972349984305, 51.901580878666465, 51.492245129176546, 48.41422094617571, 52.95774875368391, 50.296581745147705, 54.866325105939595, 54.784054960523335, 53.474527972085134, 49.84378501347133, 46.23974745614188, 39.22237607410976, 41.087310791015625, 41.14013794490269, 41.358036926814485, 42.61721726826259, 43.09203978947231, 42.40473788125174, 43.719104290008545, 39.79130847113473, 41.12648126057216, 39.96911287307739, 39.81955984660557, 39.082835401807515, 41.69941234588623, 39.172137124197825, 40.66563504082816, 39.586746556418284, 40.34153979165213, 39.002639293670654, 39.47155932017735, 39.54065568106515, 40.684568881988525, 37.585262366703574, 41.536633423396516, 38.890571798597065, 40.139590399605886, 37.820326873234336, 41.91699865886143, 38.51037679399763, 41.16840321677071, 38.109576906476704, 39.032721519470215, 36.47794532775879, 39.888756956372944, 37.36982652119228, 38.94044944218227, 40.478471415383474, 48.0975706917899, 45.200647830963135, 52.977426052093506, 47.63936478751046, 51.80587639127459, 48.472141129629954, 54.31816782270159, 46.89151280266898, 55.78328929628645, 26.553227049963816, 23.825659581593104, 49.04845946175711, 41.53376381737845, 52.290124143872944, 47.59892279761178, 51.17553581510271, 48.94411488941738, 50.70997176851545, 50.08730547768729, 47.61427484239851, 43.742283480507986, 46.91062034879412, 46.118261677878245, 48.87124218259539, 43.0121876171657, 38.27450629643032, 39.091416427067344, 40.3571697643825, 40.531826632363455, 40.67753383091518, 38.920504638126914, 40.23868908200945, 40.09864466530936, 37.828960009983604, 39.891022069113596, 39.75255141939436, 38.32452637808663, 39.89453090940203, 39.93109580448696, 40.07377358845302, 39.090954371861045, 38.53699534279959, 39.36455706187657, 39.61790575299944, 39.09502254213606, 40.847170625414165, 40.34382227488926, 40.26089552470616, 39.99138184956142, 39.25369160515921, 40.3047525542123, 41.9615261895316, 44.28144632066999, 44.74658652714321, 47.406228406088694, 45.85921893801008, 45.755016803741455, 42.938675676073345, 42.91799088886806, 42.92014830453055, 43.27885947908674, 41.55846813746861, 44.08680643354143, 43.67736298697335, 50.58793708256313, 51.98614392961775, 56.81250510896955, 54.38137558528355, 58.6801426751273, 57.79317733219692, 40.757886273520334, 3.178178991590227, 1.6693406466926848, 0.6410152348024505, 0.053132962834622176, 0.04219468995662672, 17.965621846062795, 61.63542693001883, 40.71300785882132, 34.684896673474995, 20.581483125686646, 27.352539130619594, 45.240137917654856, 54.62023033414568, 58.863262448992046, 38.80363941192627, 0.29678820446133614, 0.06655728963336774, 0.05054057229842458, 0.05871320768658604, 0.003505344984919897, 0.05425488316853132, 0.040640861727297306, 0.017265883340899433, 0.03867417547319617, 0.039591120555996895, 0.010136252119471984, 0.032197205881987295, 0.05544119308303509, 0.11060738949371235, 0.13990309142640658, 0.18550103822989122, 0.13852748381240026, 0.1505001120801483, 0.19557463697024755, 0.20713736223323004, 0.12501998219106877, 0.3875168045716626, 0.33499770558306147, 10.51208598273141, 79.8486634663173, 70.09262834276471, 63.23048319135393, 51.2109820502145, 25.805522714342388, 34.02287578582764, 52.38601623262678, 46.806842054639546, 73.41720240456718, 48.38662617547171, 1.0957159357411521, 0.1406089849770069, 0.72217415698937, 8.952142442975726, 9.316981060164315, 21.490939787455968, 71.83909279959542, 60.63690825871059, 66.31780406406948, 54.99321658270699, 54.500241892678396, 50.771348680768696, 56.662774903433665, 52.17505155290876, 56.7895621572222, 57.040527616228374, 56.045111315590994, 52.03992298671177, 47.99897575378418, 42.62245968409947, 43.55659287316458, 42.60428319658552, 43.15809283937727, 44.984374727521626, 45.42413663864136, 44.32234341757638, 44.760774748665945, 40.10225078037807, 42.71711499350411, 41.988707542419434, 42.05110583986555, 40.21076774597168, 44.42163664954049, 42.11746113640921, 43.55074596405029, 41.2116870198931, 41.89049822943551, 41.67741434914725, 41.822239126477925, 40.18152277810233, 43.05417210715157, 38.58366639273507, 44.80455534798758, 40.65800939287458, 41.64225993837629, 38.789006505693706, 44.27561330795288, 39.695051601954866, 44.087681906563894, 40.542426109313965, 41.72359902518136, 38.337394441877095, 40.559876510075156, 40.034901891435894, 40.56789820534842, 43.67884642737252, 49.956540380205425, 47.01436390195574, 54.60920006888253, 48.64684316090175, 55.560314655303955, 52.116724899836946, 56.93033960887364, 49.33309589113508, 56.22173799787249, 28.713034629821777, 26.108290467943462, 48.69725581577846, 42.12773404802595, 53.05990464346749, 50.18314892905099, 52.72446993419102, 53.28123256138393, 53.92212050301688, 52.111784730638774, 49.22682319368635, 46.29231057848249, 49.910296644483296, 47.473184721810476, 50.65148878097534, 45.41163682937622, 41.375692299434114, 41.52007239205496, 42.353960445949006, 42.79707486288888, 43.28852442332676, 41.57359783990042, 40.68478080204555, 42.14064032690865, 39.835221086229595, 43.08903816768101, 41.41901084354946, 40.435990129198345, 42.19107730048043, 42.252471583230154, 42.87766007014683, 41.27534294128418, 40.975479534694124, 40.854563508714946, 40.97500358309065, 40.90205097198486, 43.99794939586094, 42.27981274468558, 42.11510222298758, 41.183505126408164, 42.2976313999721, 43.97111545290266, 44.58885547092983, 48.46067312785557, 46.404638631003245, 50.792450359889436, 48.81454140799386, 49.68888534818377, 45.749680587223594, 44.74688877378191, 46.592281682150706, 45.033415113176616, 44.932853834969656, 47.58423777988979, 46.64440359388079, 52.61045346941267, 55.986173221043174, 60.62486008235386, 57.69025019236973, 60.73935944693429, 60.32514953613281, 42.48561143875122, 3.9820677638053894, 10.377218842506409, 1.704066983291081, 0.12826010904141835, 0.2585164952491011, 22.408954892839702, 68.26145144871303, 47.43071733202253, 54.058096749441965, 31.376119341169083, 34.31701735087803, 52.03174843106951, 62.75764438084194, 65.94783333369664, 47.64158126286098, 0.8603238867861884, 0.20748279084052357, 0.152085970555033, 0.12757033748286112, 0.11593506325568471, 0.16574270916836603, 0.12979874147900514, 0.16120525050376142, 0.15233307943812438, 0.1271755522383111, 0.1566239313355514, 0.06424109677651099], [0.05418121122888156, 0.07405651972762176, 0.038014035538903306, 0.05259266236264791, 0.05570526194891759, 0.03254624090290495, 0.03572234458156994, 0.1896880335573639, 0.022038471352841173, 0.10927538454000439, 0.05284966767898627, 14.17493917260851, 67.54941395350865, 51.08237784249442, 52.0800974709647, 32.95515305655343, 16.87139173916408, 25.179616825921194, 38.14254263469151, 40.29610899516514, 59.827721050807405, 24.425737278802053, 0.06389906084431068, 0.03706571499684027, 0.5640793517231941, 2.032173297234944, 1.9266143100602287, 33.630097593579976, 66.97627789633614, 58.76163114820208, 59.53217247554234, 53.08162471226284, 56.187382629939485, 51.10771097455706, 53.53783300944737, 53.19714893613543, 55.78135422297886, 55.39246007374355, 53.1046267236982, 51.78899226869856, 49.28207874298096, 42.7025272505624, 37.95145327704293, 38.368074212755474, 37.67786795752389, 38.09433603286743, 40.488032136644634, 37.72109964915684, 40.20720679419381, 38.615735803331646, 39.41851329803467, 37.64225149154663, 36.90313686643328, 37.95841189793178, 38.60499736240932, 36.76822369439261, 38.678238323756624, 36.12807921000889, 38.43851157597133, 37.40464741843087, 37.7529536655971, 37.7289719581604, 37.646552426474436, 37.17467246736799, 38.46568945475987, 37.55348825454712, 37.865132331848145, 37.92105490820748, 39.27258028302874, 37.49967098236084, 39.127314295087544, 36.0862580026899, 37.346925258636475, 35.45786987032209, 36.772618430001394, 35.753519194466726, 38.46599864959717, 39.2680014201573, 45.9071615082877, 46.05786793572562, 51.99631609235491, 49.000621114458355, 50.413443497249055, 48.33097110475813, 51.651727131434846, 44.80453797749111, 54.65108380998884, 28.793411391122, 18.927813598087855, 52.18729427882603, 44.29016630990164, 52.76304633276803, 45.66627441133772, 47.96582242420742, 45.26233046395438, 47.20818737574986, 45.28585706438337, 43.30938638959612, 41.07061079570225, 45.38519893373762, 45.29748487472534, 46.784903117588584, 41.83087921142578, 37.97696706226894, 35.24935443060738, 37.808723381587434, 37.82685817990984, 39.17036880765642, 38.98872552599226, 37.9677711214338, 38.763899190085276, 37.21773740223476, 37.51504734584263, 37.42709009987967, 36.56882776532854, 37.57491649900164, 35.48587111064366, 36.16365398679461, 36.49935620171683, 37.944873332977295, 37.61289535249983, 37.77659838540213, 38.50403656278338, 38.409502846854075, 37.70043223244803, 37.73864385059902, 37.625575814928325, 39.29938990729195, 39.69488831928798, 39.654397691999165, 40.232929025377544, 39.045165743146626, 38.67420489447457, 38.548206261226106, 38.46780865533011, 38.292991978781565, 38.11583028520857, 40.83497306278774, 38.46669694355556, 38.4392272404262, 38.846238817487446, 42.279055391039165, 44.531532832554404, 48.34033032826015, 53.189617088862825, 52.846858978271484, 54.30729389190674, 55.74453224454607, 50.992971897125244, 12.726768698011126, 0.7378970075930867, 1.2831029891967773, 0.056327770331076214, 0.023680197008486305, 4.9147500821522305, 55.43660197939192, 41.107675961085725, 44.23534502301897, 42.44887978690011, 22.806006227220806, 32.562871660505024, 45.22585242135184, 50.136047090802876, 40.83345488139561, 2.971488973924092, 0.27073720949036734, 0.03597284953242966, 0.03649970483300941, 0.03228596165510161, 0.048312351506735594, 0.017644804436713457, 0.03153346631942051, 0.036495206145835776, 0.07948775150414024, 0.04271099743034158, 0.04207877242671592, 0.007413150293619505, 0.13763659447431564, 0.034274123542542966, 0.07564319244452886, 0.034061460489673276, 0.014084823812091989, 0.0022117092781367576, 0.03746871390779104, 0.02956704469397664, 0.15152833690600737, 0.07491561291473252, 19.840761729649135, 76.96047101702008, 57.652222701481406, 58.632116726466585, 39.00226409094674, 20.015863282339915, 23.547743797302246, 40.53157302311489, 46.2093699319022, 66.23435619899205, 26.939267226627894, 0.0871229125186801, 0.056217973187033615, 1.3413051175219672, 3.6166068485804965, 0.9576132148504257, 37.72257614135742, 69.16151414598737, 60.06024946485247, 61.15509101322719, 55.14353043692452, 57.2026047706604, 54.24546882084438, 55.371403557913645, 55.84718145642962, 58.189888204847065, 55.93476349966866, 55.0634628704616, 52.53191103254046, 51.29879685810634, 45.07814414160592, 41.03694329942976, 40.746463435036794, 40.739261627197266, 40.6966552734375, 41.637965951647075, 39.81367472239903, 41.64064448220389, 40.47889525549752, 41.51392323630196, 39.504264490945, 38.319874559129985, 40.49725587027413, 41.55758919034685, 38.263267585209434, 39.5723603112357, 39.47993189947945, 40.26877130780901, 39.48921121869768, 38.95962994439261, 39.19450337546212, 39.88865620749337, 39.39564330237252, 39.753913266318186, 39.211401394435335, 38.996688161577495, 39.56749309812273, 39.57258265359061, 40.02397584915161, 41.762554100581575, 38.23174360820225, 38.73256628853934, 37.24104513440813, 38.45371770858765, 37.082181521824424, 40.69498423167637, 41.992859091077534, 48.734981060028076, 48.00206075395857, 51.15814099993025, 50.773499148232595, 52.131739956992014, 50.00010558537075, 52.75785255432129, 46.61037826538086, 55.7983842577253, 30.220244816371373, 20.680574859891617, 54.33665697915213, 45.116491249629426, 53.13615417480469, 48.869953291756765, 51.681534903390066, 46.35771744591849, 49.26287739617484, 46.10351412636893, 44.60680614198957, 45.44755206789289, 46.69875587735857, 48.892274379730225, 48.27946063450405, 43.93413019180298, 39.906137875148225, 37.48132078988211, 39.6339248248509, 39.058276993887766, 41.03627627236502, 39.300532885960166, 39.91855430603027, 40.5606929234096, 39.44149446487427, 38.51766545431954, 37.55913366590227, 37.99654361179897, 39.27933740615845, 38.10559906278338, 38.8762446131025, 38.98839201245989, 39.88756186621529, 39.51172685623169, 39.66150222505842, 38.991706303187776, 40.94950022016253, 40.351809229169575, 39.877188205718994, 39.65606525966099, 40.22424725123814, 42.12252984728132, 40.97899532318115, 40.75603805269514, 41.77813196182251, 40.73396015167236, 41.121704374040874, 40.86539575031826, 40.40721069063459, 41.04118864876883, 41.677171162196565, 40.610223157065256, 41.40979405811855, 41.64984737123762, 44.729004110608784, 47.208176953451975, 51.99476316996983, 53.75003099441528, 55.84807082584926, 56.87304128919329, 58.256590911320274, 52.84901639393398, 15.964313098362513, 0.16535857692360878, 1.8046679965087344, 0.13107267740581716, 0.061532127138759406, 5.110307565757206, 60.31482451302664, 46.1460405758449, 41.27019780022757, 31.717418330056326, 26.958975791931152, 37.649380343300955, 51.72889035088675, 53.43863010406494, 54.05302109037127, 6.796589766229902, 0.35826296146426884, 0.06538845199559416, 0.042725463796939166, 0.0379960645389344, 0.038327834236302545, 0.043037732397871356, 0.042475121694483926, 0.05891034246555396, 0.08721572932388101, 0.04224434854196651, 0.056523229128548076, 0.11874983007354395, 0.24076593773705618, 0.14521384931036405, 0.12276174979550497, 0.08877589846295969, 0.13508128587688717, 0.1042805186339787, 0.3548221103847027, 0.13630746650908673, 0.2518954591027328, 0.16502514481544495, 24.459976264408656, 85.01838030133928, 64.77062089102608, 65.79433373042515, 43.80787794930594, 25.33578974860055, 36.18765306472778, 51.31482287815639, 51.714333874838694, 68.85532787867955, 30.526531832558767, 0.2503439209290913, 0.12125628414962973, 1.7002834720270974, 10.75394582748413, 4.0983628034591675, 38.41372387749808, 72.22208445412772, 63.84482901436942, 65.10206386021206, 57.768535545894075, 60.96895572117397, 55.373185770852224, 58.17511633464268, 59.609089033944265, 59.68665177481515, 58.77313041687012, 56.757395471845356, 56.75720092228481, 54.539033685411724, 48.30671146937779, 42.84883894239153, 42.69868837084089, 43.827923502240864, 41.95197936466762, 43.36315502439226, 41.526780877794536, 44.56930671419416, 41.88579082489014, 44.39513274601528, 40.921860286167686, 40.173838070460725, 42.204424789973665, 43.582714625767295, 40.185184478759766, 43.39577681677682, 42.34854432514736, 42.50670269557408, 41.47649676459176, 41.21985462733677, 41.19310406276158, 40.60225009918213, 40.99223858969552, 42.417595522744314, 41.917019503457205, 40.11514663696289, 42.120518343789236, 42.884267807006836, 41.470021043504985, 44.3931108202253, 39.575292451041086, 39.88815941129412, 38.77985225405012, 40.89416824068342, 38.785344805036274, 43.080596106392996, 42.940100056784495, 50.05564948490688, 49.99984850202288, 53.592609133039204, 54.697212900434224, 53.00813708986555, 52.94758701324463, 55.766196727752686, 50.808493750435964, 56.28331640788487, 32.76713480268206, 23.160612753459386, 55.65349694660732, 48.36647987365723, 56.343074389866416, 51.012371267591206, 51.67808164869036, 48.31462894167219, 50.81690107073103, 50.125694274902344, 47.09995181219918, 46.80546631131853, 49.14896515437535, 48.69458075932094, 49.89274549484253, 45.24478278841291, 41.81227193559919, 39.11079147883824, 42.55703892026629, 40.859468936920166, 43.938844544546946, 42.47898285729544, 42.04102052961077, 43.20226948601859, 40.56640781675066, 40.38392032895769, 39.7104036467416, 39.49692719323294, 41.84368126732962, 39.84953090122768, 41.41885798318045, 40.25512851987566, 42.31041261128017, 42.65739522661482, 42.204348359789165, 43.10676302228655, 42.84501395906721, 42.97657115118844, 43.06325340270996, 41.82166937419346, 43.13096707207816, 44.22283826555525, 43.93141344615391, 43.66082280022757, 42.54553965159825, 43.18898453031267, 43.87290961401803, 44.01061943599156, 42.833313192640034, 42.709590094430105, 44.83723272596087, 43.274541173662456, 44.34705468586513, 44.04145554133824, 48.71295527049473, 48.52793863841465, 51.99692753383091, 58.17730501719883, 58.30448137010847, 59.04833466666085, 60.93988445826939, 55.95515646253313, 17.11372058732169, 3.5448126324585507, 5.355208984443119, 0.233055445764746, 0.186276590185506, 6.464600494929722, 66.21109363010952, 52.13960184369768, 62.66620608738491, 53.71226406097412, 34.691028458731516, 42.96459245681763, 60.4130859375, 60.5914739881243, 62.057689802987234, 7.971980912344796, 0.6954060047864914, 0.22171297296881676, 0.11315018590539694, 0.14890056076858724, 0.1883520388177463, 0.15910051630011626, 0.151081508025527, 0.13969145635409014, 0.1562886671828372, 0.10705332484628473, 0.0933067821232336], [0.04194951489833849, 0.003948274409464959, 0.0375471491632717, 0.025517127010971308, 0.014880361168512275, 0.027087620060358728, 0.0158649069988834, 0.02311615798888462, 0.10595928212361676, 0.10393587034195662, 0.08340264071843453, 25.157780374799454, 65.45925685337612, 48.578163691929404, 43.699159485953196, 21.632384266172135, 26.99751397541591, 39.85878242765154, 38.83339507239205, 47.65809713091169, 63.85294451032366, 8.861326881817408, 0.0758929747555937, 0.0418100929153817, 0.6430803154196058, 1.2539454166378294, 3.3455860657351355, 53.84060423714774, 61.60620280674526, 58.332176889692036, 58.05033016204834, 58.2895496913365, 56.220004422324045, 55.24379641669137, 57.19157450539725, 56.11150482722691, 54.325188977377756, 52.758894784109934, 52.61254835128784, 53.28483867645264, 49.59185375486101, 46.411284582955496, 42.40595729010445, 36.97740963527134, 40.797108854566304, 41.2350538117545, 39.42069503239223, 38.99247407913208, 37.52280500956944, 37.749107837677, 39.34379931858608, 37.51921279089791, 39.001961844308035, 37.216705594744, 37.742986474718364, 37.83533845629011, 38.5437524659293, 37.85038825443813, 36.634842600141255, 37.667327540261404, 37.98163972582136, 36.20998110089983, 37.55241823196411, 36.52049609592983, 37.45128720147269, 38.75904587336949, 38.412230014801025, 37.48938070024763, 39.22548539297921, 38.29423223223005, 37.78237233843122, 37.158802781786235, 36.08834593636649, 35.37246608734131, 36.89283616202218, 35.212157249450684, 38.01404959814889, 41.26707805906023, 45.324284076690674, 47.11780520847866, 48.982750347682405, 47.92459528786795, 50.58667598451887, 48.2529810496739, 48.04905489512852, 46.88174016135079, 54.05551201956612, 36.01129041399275, 24.73876404762268, 56.390092849731445, 44.651302405766074, 47.59153686250959, 44.22085802895682, 46.92203276497977, 42.69092723301479, 45.19587789263044, 41.81374495370047, 43.68210513251168, 42.79428516115461, 47.67908763885498, 46.69872808456421, 45.84064987727574, 42.68088361195156, 37.30597605024065, 35.247249126434326, 36.052434171949116, 37.10068110057286, 38.691359996795654, 38.98189197267805, 39.753353936331614, 35.7237148966108, 37.724577222551616, 38.63616003308977, 37.78563104357038, 37.05753626142229, 38.596562249319895, 37.00330557141985, 37.40415409633091, 37.56578309195382, 37.34664733069283, 36.53051887239729, 39.229084559849326, 37.43672030312674, 38.929082189287456, 36.16756582260132, 37.465176650456016, 37.2092501776559, 37.746099267687114, 38.1271766935076, 39.63610308510916, 38.57273687635149, 39.74563796179635, 37.88487911224365, 38.821642194475444, 37.03671598434448, 38.9169054712568, 35.88833161762783, 38.225309576307026, 37.35113934108189, 39.16312878472464, 39.27946594783238, 42.947416509900776, 44.82055010114397, 51.852762835366384, 49.69978359767369, 53.88670900889805, 53.1468266078404, 58.38772773742676, 57.474081311907085, 27.127401862825664, 0.7939339578151703, 0.5684765843408448, 0.17750926635095052, 0.03692363994196057, 0.9521201210362571, 44.21235343388149, 50.783952713012695, 40.53967114857265, 39.92632934025356, 15.889159645353045, 29.771363394601003, 41.365996088300435, 49.8224401473999, 53.168053354535786, 13.04078471660614, 0.3396986504750592, 0.1132877113829766, 0.04484646587765642, 0.017083907034248114, 0.07440327826355185, 0.048828441849244494, 0.038735077383794954, 0.06980551819183997, 0.022614218494189636, 0.07204483303108386, 0.028575263983969177, 0.02801470415267561, 0.022444136906415224, 0.058116062943424494, 0.017108902567997575, 0.020710381546190808, 0.11267649382352829, 0.015879163019625202, 0.005948560445436409, 0.011593941266515424, 0.056337422491716485, 0.031807601252304654, 31.28846434184483, 72.6351409639631, 54.338710171835764, 49.65977587018694, 28.948333638054983, 29.487883840288433, 32.145302295684814, 38.5301513671875, 51.56403739111764, 69.04649366651262, 9.994168996810913, 0.1317872969167573, 0.13861611405653612, 2.678457166467394, 2.6435663529804776, 4.073593778269632, 57.158514976501465, 64.16523129599435, 61.29353387015206, 59.88371658325195, 60.38085324423653, 58.30155617850167, 58.71065221514021, 58.785595485142295, 58.30594049181257, 55.656046935490195, 56.7567458152771, 55.17834786006382, 55.001940046037944, 51.04282522201538, 48.01491492135184, 43.42031785420009, 37.92479303904942, 42.76879569462368, 41.90825087683541, 41.65009750638689, 41.74515233721052, 39.986976691654746, 38.820398466927664, 40.683231353759766, 40.011347498212544, 40.59321396691458, 38.763485772269114, 39.42143848964146, 39.46511834008353, 40.061280727386475, 38.65864092963082, 38.71635266712734, 39.478003774370464, 38.42338187353951, 38.64608900887625, 39.824989863804404, 38.11790084838867, 37.93752213886806, 40.12920979091099, 40.02839142935616, 39.023365770067485, 40.64757319859096, 40.01970270701817, 40.793131010872976, 37.16895062582833, 37.624547481536865, 38.00826869692121, 38.52071571350098, 37.54577228001186, 40.55113220214844, 41.29483263833182, 47.35806696755545, 48.76828724997384, 49.60765395845686, 50.15697506495884, 52.256064074380056, 49.906864234379356, 50.49136407034737, 49.015139375414165, 55.467761175973074, 37.81529637745449, 25.5524571623121, 57.444881507328574, 46.853679861341206, 49.87494421005249, 46.04713991710118, 48.00086566380092, 44.677649974823, 47.55744205202375, 43.37052011489868, 46.52571793964931, 44.61450822012765, 49.03995139258248, 47.49079493113926, 47.689767020089285, 45.007345472063335, 38.88319281169346, 36.92882783072335, 38.77348075594221, 38.892774377550396, 39.83309841156006, 41.673853397369385, 41.517595359257285, 37.95880447115217, 39.66143274307251, 39.557317461286274, 38.964736870356965, 38.734133107321604, 39.566628047398154, 37.331052098955425, 39.114390645708355, 39.44987746647426, 39.646052905491416, 38.35234349114554, 40.61731031962803, 40.44008261816842, 40.627944537571494, 37.67053065981184, 40.56279475348336, 39.361638818468364, 39.38204915182931, 40.53484215055193, 40.878017153058735, 40.45164442062378, 41.5862261908395, 39.098586968013215, 40.07282863344465, 39.69244602748326, 42.048427309308735, 38.00140387671334, 38.78054012571062, 39.366526876177105, 40.74612297330584, 41.13138321467808, 45.740265778132844, 47.51977934156145, 52.77405227933611, 52.97568205424717, 55.487382888793945, 56.074446610042024, 59.55692890712193, 59.41353893280029, 32.10579831259591, 1.499190662588392, 0.9603906486715589, 0.5200679419296128, 0.025921372730018835, 0.9690923988819122, 48.17122507095337, 54.52579041889736, 43.04482330594744, 38.89126661845616, 26.762897627694265, 35.279068401881624, 48.343394483838765, 54.46966634477888, 62.06744507380894, 18.14875030517578, 0.2773989848792553, 0.08276604594928877, 0.009572012083871024, 0.028044904050018107, 0.0598704084487898, 0.028510745481720993, 0.0859724021117602, 0.034107868892273734, 0.09156821255705186, 0.07587320903050047, 0.03543462198493736, 0.06251812673040799, 0.09321484741355691, 0.18683174039636338, 0.10217381667877946, 0.08580539428762027, 0.2573910227843693, 0.19949549729270594, 0.21272223469402107, 0.2930521092244557, 0.21521369314619473, 0.12241571050669466, 37.1470707484654, 82.23217351096017, 62.58756637573242, 58.47353799002511, 30.392574037824357, 36.428376879010884, 49.70044715063912, 51.754174845559255, 58.971772466387065, 73.91685431344169, 12.170257074492318, 0.29650343688470976, 0.16532083680587156, 2.934556258576257, 8.120869517326355, 5.153141473020826, 60.31823607853481, 65.07038702283586, 62.770109449114116, 62.18716948372977, 62.4605324608939, 59.969297545296804, 61.101582935878206, 61.85124492645264, 60.9949836730957, 58.19889654432024, 59.571659088134766, 58.8480806350708, 57.590679032461985, 53.65595933369228, 49.894499914986746, 45.72541052954537, 39.478879247392925, 46.03255912235805, 44.55763374056135, 44.471337114061626, 43.31511170523507, 42.41990579877581, 41.01048108509609, 42.62914385114397, 41.81218160901751, 41.69374261583601, 41.491442339760916, 40.81177650179182, 41.170591899326865, 42.7863781111581, 41.810302121298655, 42.07030371257237, 42.69727093832833, 40.65224586214338, 41.5906035559518, 42.26887280600411, 40.82032626015799, 41.07492562702724, 42.40717322485787, 41.61852836608887, 41.83042063031878, 43.19132259913853, 41.43109723499843, 41.1492783001491, 40.23612172263009, 39.0404930795942, 40.229517459869385, 40.74758209500994, 38.4677391733442, 41.69659832545689, 43.82150684084211, 49.98286363056728, 50.84822007587978, 51.218260288238525, 52.103450366428916, 54.35647324153355, 52.95523003169468, 52.42999485560826, 49.543063504355295, 56.88575996671404, 40.15838875089373, 27.912346805844987, 59.94751494271414, 48.63950933728899, 52.34524767739432, 47.39877993719918, 51.24956539699009, 47.425599983760286, 48.744927406311035, 46.33038323266165, 48.76932600566319, 46.625261306762695, 52.301734583718435, 51.07050337110247, 49.46984338760376, 47.20322983605521, 42.27799926485334, 38.781460762023926, 39.12180437360491, 42.13415765762329, 41.940532207489014, 43.19063820157732, 44.680804456983296, 39.58184807641165, 42.68731416974749, 41.93468182427542, 41.3641756602696, 41.5655448777335, 42.4458121572222, 40.4739168712071, 40.90166187286377, 41.64716189248221, 42.47120087487357, 41.03392778124128, 43.71635627746582, 41.811115060533794, 43.94131810324532, 39.14853061948504, 41.59500176565987, 42.25324283327375, 39.63529709407261, 42.07020991189139, 43.30573858533587, 42.624505928584504, 44.25095067705427, 41.47274473735264, 41.9382358278547, 41.58213717596871, 44.815905230385916, 40.27955143792288, 42.39397512163435, 40.36035551343645, 45.28924431119646, 44.337719781058176, 48.88185903004238, 49.266375814165386, 55.53987305504935, 54.40114321027483, 58.90659141540527, 56.44812420436314, 64.11519731794084, 60.99831880841936, 31.876142978668213, 2.7061481262956346, 2.6015356140477315, 0.7057308107614517, 0.16509822303695337, 1.1656681192772729, 53.93563822337559, 59.2876375743321, 56.46547385624477, 52.415139607020784, 26.423658779689244, 40.31530686787197, 57.18928854806082, 62.79861095973423, 71.79558318001884, 23.19068976811, 0.6223801661814962, 0.28109786925571306, 0.08933843792017017, 0.12389039780412402, 0.1976995508053473, 0.2469623466687543, 0.15488838803555283, 0.18383659182914666, 0.1890562360308, 0.20290342585316726, 0.1672453928206648], [0.022953526715614965, 0.027554440278826014, 0.03825003680373941, 0.02173314755782485, 0.017189634664516364, 0.04723447488088693, 0.031129744768674885, 0.05471922843051808, 0.041141864843666553, 0.02716045400926045, 0.1840001866221428, 31.685508728027344, 64.61210468837193, 47.21362781524658, 35.98981353214809, 14.343138558523995, 26.9104026726314, 32.53605508804321, 40.153782095227925, 52.54984433310372, 50.756615025656565, 2.9067235120705197, 0.02231160205389772, 0.16369269202862466, 1.7725535311869212, 2.6457092208521704, 9.115867188998632, 59.26721681867327, 57.91874517713274, 64.1817124230521, 57.246479170663015, 61.59092371804373, 56.87989221300398, 57.701221397944856, 56.02293961388724, 55.61222464697701, 53.64732619694301, 54.35215493610927, 51.3446341242109, 50.14699745178223, 48.95829268864223, 46.43600974764143, 41.369744641440256, 38.18683740070888, 37.28405795778547, 40.81289516176496, 38.658345631190706, 38.847444329942974, 39.42116403579712, 37.97287457329886, 38.36387055260794, 35.83314207621983, 37.55707352502005, 38.08893380846296, 36.64931222370693, 38.78192976542881, 35.748714515141074, 36.22108779634748, 37.07123810904366, 36.89281184332711, 36.01030376979283, 38.036172662462505, 37.812197480882915, 36.264764172690256, 36.899120807647705, 37.89227546964373, 37.920707498277935, 38.161344460078645, 38.71068641117641, 37.685448442186626, 37.1675887789045, 36.37524747848511, 34.80667775017874, 36.32469585963658, 37.74026278087071, 40.8257771219526, 40.84811905452183, 41.64667204448155, 47.058686460767476, 47.95328787394932, 49.166047300611226, 50.996737820761545, 48.21980340140206, 47.33816385269165, 51.31407247270857, 46.59319884436471, 50.451200008392334, 43.94165856497628, 31.110965660640172, 52.051460470472065, 45.85154117856707, 46.12352841241019, 42.286625453404014, 44.998007093157085, 42.189315932137625, 46.540708678109304, 44.21904107502529, 45.03593036106655, 45.694167954581125, 49.15537486757551, 46.735991273607524, 48.21902520315987, 44.952628408159526, 37.43033143452236, 37.502780301230295, 37.493945666721885, 36.59016220910208, 39.41339247567313, 38.82205213819231, 37.98425572259085, 35.50698321206229, 37.57708433696202, 37.084224292210166, 36.099139962877544, 36.43469973972866, 38.20406893321446, 36.87932538986206, 36.54737867627825, 37.55016701562064, 35.638241631644114, 36.55881888525826, 38.04766150883266, 40.20004320144653, 39.48328440529959, 35.69137798036848, 36.82676921572004, 38.10974018914359, 39.75395495550973, 36.965979848589214, 37.222910336085725, 37.18159634726388, 39.09788867405483, 37.120841298784526, 38.310477120535715, 38.11707401275635, 37.99920129776001, 36.43199689047677, 38.702303409576416, 36.52087477275303, 38.195508752550396, 40.3965938431876, 40.827920641217915, 40.678110531398225, 45.49449062347412, 51.401407854897634, 52.22780227661133, 54.661016259874614, 55.032682350703645, 56.80909006936209, 46.358759675707134, 3.8253211804798672, 0.595522555921759, 0.7347797091518129, 0.03220156207680702, 0.42761540146810667, 30.12102801459176, 54.988658564431326, 44.524056570870535, 36.707722255161826, 14.975587912968226, 20.384239401136124, 39.79582132611956, 44.56315755844116, 53.099860259464805, 20.830174786703928, 0.16004172579518386, 0.056012604385614395, 0.008639626088552177, 0.00617795914045668, 0.026000593389783586, 0.021177461304302727, 0.031636878448937616, 0.027615427006302134, 0.04279142079342689, 0.054017005754368644, 0.026259963400661945, 0.01123177320031183, 0.035107490074421675, 0.024451938989971365, 0.024930625089577267, 0.04511905375069805, 0.060451254780803404, 0.02044956455938518, 0.025698475672730377, 0.03390202172366636, 0.046361600647547414, 0.2591868064233235, 39.3960462978908, 72.00792012895856, 52.83079126902989, 43.14752810341971, 17.734159980501445, 27.91507397379194, 32.21337032318115, 45.44398069381714, 56.13207496915545, 55.446117537362234, 3.0791111418179105, 0.16152287274599075, 0.1131455854379705, 3.5042983378682817, 1.661222979426384, 10.40783086844853, 61.59797613961356, 57.246194294520784, 66.57608945029122, 58.469883237566265, 62.69894599914551, 57.60669810431344, 60.025980949401855, 58.196120738983154, 56.49307904924665, 55.764268602643696, 54.89904069900513, 54.58062212807791, 51.97870240892683, 50.216607979365754, 47.30886329923357, 44.71273490360805, 40.36717169625418, 38.80973993028913, 42.85517569950649, 39.94500262396676, 42.19764682224819, 40.852506841932026, 40.24468885149275, 40.48492629187447, 38.98209694453648, 38.91083969388689, 40.14198752811977, 39.93753678458077, 38.90766784123012, 37.867043086460654, 37.99506711959839, 39.512150696345735, 38.789913245609824, 37.80684389386858, 38.59913655689785, 38.610111236572266, 38.85634497233799, 39.214618410382954, 40.439137663160054, 39.61227076394217, 40.617185252053396, 39.71818215506417, 39.53012568610055, 39.275349140167236, 38.127798557281494, 37.05516345160348, 37.87474863869803, 39.382743971688406, 43.4825632912772, 44.073806353977744, 44.2602265221732, 46.79954992021833, 50.779293945857454, 50.11916644232613, 51.290907178606304, 51.76811988013131, 49.382285663059776, 51.28791945321219, 49.07632521220616, 52.252735887254985, 43.743860721588135, 32.410532406398225, 54.67182765688215, 48.893285342625205, 48.575721400124685, 44.65259824480329, 45.91491569791521, 44.71496180125645, 48.31496592930385, 46.45446763719831, 47.44638204574585, 47.855293955121724, 50.10515539986746, 47.93721669060843, 51.57466813496181, 45.650081634521484, 38.744663102286204, 38.5747275352478, 39.280612400599885, 39.69537121909005, 41.662868295397075, 39.10545526232038, 38.953803879874094, 38.47164058685303, 39.61486939021519, 39.64348554611206, 37.7883825302124, 38.4105589730399, 39.482290812901084, 37.84345742634365, 39.352171897888184, 38.022453444344656, 38.3532988684518, 38.335754667009624, 41.00994259970528, 40.53497764042446, 41.300891467503135, 38.52884857995169, 39.02907371520996, 40.319566113608225, 39.12184953689575, 38.30626303809029, 38.41104882104056, 39.79697125298636, 40.13051952634539, 38.52819892338344, 40.57954338618687, 40.72428478513445, 39.511070251464844, 38.67190851484026, 41.62223175593785, 38.83263424464634, 40.668053013937815, 41.438285146440776, 43.757374967847554, 41.991201945713584, 47.45866993495396, 52.693731103624614, 55.415865080697195, 56.079626492091585, 58.475087438310894, 57.51608664648873, 47.87249422073364, 5.3116185920579095, 0.784500421157905, 0.8530206786734718, 0.031101951974311044, 0.2896453206028257, 32.09425735473633, 60.33018003191267, 47.07998616354806, 38.3637489591326, 20.332417998995098, 28.943497691835674, 44.49523196901594, 50.52313123430525, 60.62828554425921, 31.554201671055385, 0.20904696333621228, 0.05365492929039257, 0.04405990469136408, 0.060046203301421235, 0.019601597650242702, 0.08441466891339847, 0.031133792230061123, 0.0292413987751518, 0.03365231065877846, 0.02829965154108192, 0.011857664079538413, 0.13248720578849316, 0.08582071560834136, 0.22050165225352558, 0.15551603292780264, 0.09819914852934224, 0.08634946402162313, 0.18208024464547634, 0.13545460227344716, 0.08109340284551893, 0.09339701371001345, 0.570839731820992, 47.68044253758022, 80.29912907736642, 60.52101230621338, 49.72592272077288, 20.89515781402588, 35.987972259521484, 44.06962701252529, 52.96093797683716, 63.76334054129464, 59.36634676797049, 4.306866952351161, 0.23919846756117685, 0.21971946422542843, 7.7362276656287055, 8.07946607044765, 11.143156119755336, 60.777192388262065, 57.690639291490825, 68.38738059997559, 60.73831026894705, 65.36460849217006, 60.87198666163853, 62.13754544939314, 59.672845704214915, 59.661860602242605, 58.192535468510215, 58.046484334128245, 57.61747823442732, 55.523242541721885, 52.99672467367989, 50.25435406821114, 45.51362943649292, 41.85828638076782, 41.561056341443745, 45.830804279872346, 41.96033804757254, 44.00129495348249, 43.09792838777815, 40.8439918245588, 42.7292673928397, 39.89842537471226, 42.41123097283499, 42.247131892613, 40.801302092415945, 41.874024050576345, 39.428508281707764, 40.127900055476594, 43.49421542031424, 42.10329723358154, 39.69387040819441, 41.64800609861101, 41.1504351752145, 40.81630325317383, 41.02596514565604, 42.56310469763619, 41.760778835841585, 42.761246476854595, 41.70916066850935, 41.69948877607073, 40.18574380874634, 41.05276434762137, 39.929049560001914, 40.363881724221365, 41.62613664354597, 46.22559397561209, 44.85078171321324, 44.88618973323277, 50.21866117204939, 52.606770924159456, 52.421726499285015, 53.26615844454084, 53.156116349356516, 51.96114083698818, 54.013777664729524, 51.09340810775757, 56.3466214452471, 47.639576707567485, 34.71884904588972, 55.27222497122628, 51.62882586887905, 49.12149545124599, 46.728918007441926, 48.14901862825666, 48.36386735098702, 50.5757360458374, 48.5579513822283, 49.89977012361799, 51.07041651862008, 52.74445295333862, 52.22438376290457, 52.493039335523335, 47.34406982149397, 40.63500738143921, 41.926778248378206, 40.857401847839355, 40.974881989615305, 44.89589636666434, 41.41834034238543, 41.20820944649832, 39.92656557900565, 41.36706958498274, 41.68769073486328, 39.7782632282802, 40.42585270745413, 42.21514586039952, 41.3268985748291, 40.88789749145508, 40.68687220982143, 39.69252593176705, 40.37398440497262, 43.307631969451904, 45.1001421383449, 44.210119588034495, 39.74484934125628, 40.94410841805594, 42.51172276905605, 42.103846141270225, 40.55253226416451, 40.550743103027344, 40.46394273212978, 42.27686670848301, 41.027566705431255, 42.40514782496861, 43.21262230191912, 41.87956176485334, 41.644997528621126, 42.312920910971506, 41.54380049024309, 44.31025355202811, 44.44029256275722, 46.8738192149571, 45.30816078186035, 49.74225793566023, 56.15953772408621, 57.5220308303833, 59.00791699545724, 60.81815896715437, 59.93766239711216, 51.880176952907014, 5.886866901602064, 1.8157249689102173, 2.2273154088429044, 0.244013460619109, 0.7259696104696819, 38.26430286679949, 64.27995995112828, 57.557167870657786, 47.396469661167686, 20.815055506569998, 31.35868283680507, 52.014912945883616, 58.88384996141706, 67.8648065839495, 38.631480421338765, 0.22740343904920987, 0.12634133414498397, 0.1176471970975399, 0.14812281035951205, 0.12100841530731746, 0.16775901668838092, 0.14792689015822752, 0.10763841880751507, 0.09448702593467065, 0.18870351995740617, 0.18995031448347227], [0.058965039173407216, 0.04876572825014591, 0.05772982045475926, 0.04289644444361329, 0.028566344641149044, 0.05500438616478017, 0.07962164681937013, 0.03748773324436375, 0.049074590605284484, 0.05350083398765751, 0.12233583336429936, 36.76650748934065, 55.378726959228516, 47.238474573407856, 39.363184792654856, 22.14942577907017, 34.312921387808665, 42.06078815460205, 39.12829051698957, 58.35992799486433, 39.8227664402553, 0.6951859423092434, 0.014521258384255427, 0.36862381121941973, 2.5340755539281026, 0.624075363789286, 23.942867006574357, 67.41532066890171, 56.699614252362935, 61.454537527901785, 57.97407020841326, 59.12571675436837, 55.12514550345284, 56.16097252709525, 53.81291219166347, 54.53761625289917, 53.90962764195034, 51.23860113961356, 45.86320720400129, 46.21230207170759, 43.82244832175118, 42.412631034851074, 37.78391831261771, 39.83784750529698, 39.427889892033164, 38.81067098890032, 37.981028284345356, 37.27889544623238, 38.4833413532802, 39.60587494713919, 39.373447281973704, 38.668833936963765, 35.29114784513201, 36.042838709695, 36.52721847806658, 37.02100958142962, 36.78473261424473, 35.14786556788853, 35.16903672899519, 36.79094082968575, 35.39232056481497, 37.83950390134539, 36.65436008998326, 36.52502979551043, 37.071498666490825, 37.61592129298619, 37.14216532026018, 39.66353457314627, 38.55386209487915, 39.697539057050435, 36.71507344927107, 36.32674905232021, 36.04855012893677, 37.14721318653652, 40.01352228437151, 44.6222311428615, 44.526561396462576, 43.7966878754752, 47.17507920946394, 48.21960537774222, 48.24202721459525, 48.472158500126426, 45.056257316044395, 47.92958756855556, 48.08984429495675, 45.67857272284371, 48.9834486416408, 46.586862087249756, 37.89615951265608, 49.924668993268696, 44.85747977665493, 46.1037677356175, 44.04800769260952, 45.44772229875837, 46.11543723515102, 46.160364287240164, 46.766966342926025, 47.738508633204866, 48.579004423958914, 46.143146651131765, 45.426853384290425, 46.8997985294887, 43.52884871619088, 37.043928214481895, 36.30194745744978, 37.66298491614205, 37.36231551851545, 37.68463550295149, 36.54123646872384, 37.227815764290945, 36.42492709841047, 36.499043532780235, 37.39597954068865, 34.965923513684956, 35.8027332850865, 37.64815746034895, 35.67424372264317, 38.02005631583077, 37.44142770767212, 38.38268280029297, 37.110568387167795, 39.328898906707764, 39.02164956501552, 39.06900153841291, 37.32743556158883, 38.798063482557026, 37.25624431882586, 39.52420929500035, 37.79466370173863, 38.30549873624529, 38.5874879019601, 36.66549457822527, 37.767444133758545, 38.05568320410592, 38.40492398398263, 37.04745095116751, 39.72741631099156, 39.845434938158306, 38.68186180932181, 40.71728794915335, 42.18414299828665, 41.64623430797032, 41.389244760785786, 41.13954734802246, 45.78506081444876, 53.92755746841431, 52.40492228099278, 56.92054612295968, 58.64638832637242, 54.090999943869456, 12.687825781958443, 0.14470714649983815, 0.9167803887810025, 0.032787487243435214, 0.07130240036972932, 13.19890660899026, 61.38943985530308, 42.55859184265137, 44.650666645595, 29.62234537942069, 11.671498009136744, 32.75439875466483, 47.48148781912667, 53.19735390799386, 35.853239740644185, 0.9540258816310337, 0.10134949841137443, 0.11507781568382468, 0.010470082866959274, 0.0473793251439929, 0.032236564305744, 0.02113970591952758, 0.026074462104588747, 0.016868512877928357, 0.03375567529084427, 0.045016920659691095, 0.0298762157825487, 0.014121161058678158, 0.04973238280841282, 0.018181009949850183, 0.032469233963638544, 0.03675141079085214, 0.15284432843327522, 0.017013273235144358, 0.03300252177619508, 0.044421160127967596, 0.39072958646076067, 47.452423504420686, 60.38598796299526, 54.60605253492083, 46.19956949778965, 22.142976113728114, 27.560597726276942, 38.789485931396484, 44.06408929824829, 63.87780516488211, 44.672080993652344, 0.5198269805737904, 0.006220830255188048, 0.26520853329982075, 3.2790759546416144, 0.6704938358494213, 26.485666240964616, 67.10322843279157, 60.0154196875436, 62.84287793295724, 58.9431528363909, 59.91431644984654, 55.476112910679404, 57.06241791588919, 55.0076618875776, 56.473700523376465, 56.05296972819737, 53.00936344691685, 48.770274434770855, 46.43636757986886, 45.912782600947786, 44.722236565181184, 41.639741216387065, 41.66082899911063, 40.828938552311485, 39.91745301655361, 39.240601199013845, 38.71395901271275, 40.478968211582725, 41.90148333140782, 40.49138811656407, 39.806632723127095, 38.361146858760286, 38.19423375810896, 37.82579510552542, 39.25535569872175, 39.34357350213187, 37.23330136707851, 36.61937938417707, 37.836147921425955, 36.33723735809326, 39.6582852091108, 39.1147450038365, 38.6368270601545, 38.96505996159145, 39.872359207698274, 38.534768445151194, 40.34436770847866, 40.08756228855678, 40.29255499158587, 38.59356757572719, 37.50443049839565, 38.58889838627407, 39.78545808792114, 42.70401416506086, 46.72649656023298, 46.108607155936106, 44.85293565477644, 47.49784735270909, 50.77537863595145, 51.260279519217356, 50.3105719430106, 47.037188734327046, 49.69798401423863, 49.082120009831016, 47.71443312508719, 50.30548933574131, 49.17836645671299, 39.55333614349365, 52.47126368113926, 47.57704986844744, 47.885126045772004, 45.90200594493321, 48.23552370071411, 48.08070393971035, 48.551479135240825, 49.6192296573094, 48.63379791804722, 50.10106291089739, 48.50933831078665, 46.97398097174508, 48.320566177368164, 44.18509912490845, 39.04878575461251, 37.363055501665386, 38.83745976856777, 38.82844795499529, 40.74317346300398, 39.01957205363682, 38.8253629548209, 38.58489622388567, 38.319085938589915, 38.297956466674805, 37.89522497994559, 38.37346601486206, 37.6201388495309, 37.67652695519583, 38.955759797777446, 38.62859691892351, 40.956316402980256, 39.70988253184727, 42.406078883579795, 40.420374052865164, 39.495919704437256, 39.82851954868862, 40.128921440669465, 38.561188970293315, 41.693405628204346, 41.132192679813926, 41.01605701446533, 39.76601355416434, 38.226765223911826, 40.761384691510884, 39.618885449000764, 40.66696562085833, 39.5255502973284, 41.19364949635097, 42.23432983670916, 41.585218702043804, 41.0772567476545, 43.945865699223106, 44.00259774071829, 43.83969027655465, 43.540705817086355, 46.59645060130528, 56.519353662218364, 54.28655351911272, 59.84530694144112, 60.41771343776158, 57.52943066188267, 15.397322722843715, 0.22126013226807117, 1.051735358578818, 0.0939280962837594, 0.05029770765187485, 14.314963613237653, 66.13957582201276, 46.62826987675258, 40.4735347202846, 26.112148455211095, 17.156252247946604, 37.68349947248186, 53.72319705145699, 56.77953590665545, 47.76628058297293, 1.6380592052425658, 0.08665612792330128, 0.020438713088099445, 0.024042312488225952, 0.043982090295425484, 0.009762686361292643, 0.01873384296361889, 0.041572612444204946, 0.08245274597512824, 0.06931993139109441, 0.024354900000616908, 0.17626282466309412, 0.1281038967094251, 0.10917284432798624, 0.13653132878243923, 0.13248609299106257, 0.10493394785693713, 0.24728733780128614, 0.13793907181492873, 0.19762317490364822, 0.29010341316461563, 1.1738388751234328, 60.07669585091727, 69.08570235116142, 61.569995743887766, 53.14832394463675, 33.715609073638916, 45.14289093017578, 54.141172885894775, 51.797969341278076, 69.22477749415806, 50.38290616444179, 1.1808785945177078, 0.10934519900807313, 0.6619682333299092, 13.158095496041433, 4.5003434504781445, 28.47081868989127, 69.11274474007743, 62.001138414655415, 65.94428975241524, 62.24736172812325, 62.18469592503139, 57.85558605194092, 58.818800926208496, 58.05905362537929, 58.37637438092913, 58.76527200426374, 55.40529687064034, 51.42101567132132, 50.528627259390696, 48.265008381434846, 47.9996462549482, 42.125448090689524, 43.37047495160784, 44.1650778906686, 43.00306115831648, 43.301382064819336, 41.29075057165963, 41.73165546144758, 43.70823730741228, 43.68365805489676, 42.81639085497175, 40.44689185278756, 39.90671457563128, 40.60845136642456, 42.634514808654785, 42.11901405879429, 38.92607361929757, 39.22236565181187, 40.56514324460711, 38.60768978936331, 42.966107164110454, 40.27677910668509, 40.75960942677089, 41.59825004850115, 41.62015077045986, 40.48323787961687, 43.0662202835083, 41.79038858413696, 43.644713401794434, 39.65901129586356, 40.904555797576904, 40.66526678630284, 40.31533466066633, 44.587993894304546, 48.778865882328574, 48.56098427091326, 47.20291716711861, 50.692198276519775, 51.963478905814036, 52.41343035016741, 51.99121611458914, 49.84998975481306, 50.22373683112008, 50.87716974530901, 49.30360426221575, 51.68442187990461, 51.14352546419416, 42.427430697849815, 53.63555594852993, 50.40698167255947, 50.07470839364188, 48.17040865761893, 49.07373353413173, 49.46834257670811, 51.31918634687151, 51.98630721228463, 50.75864042554583, 52.73802586964199, 49.75923238481794, 49.38330704825265, 49.929477146693635, 47.27981635502407, 40.85810361589704, 39.831517696380615, 41.13307510103498, 41.79112161908831, 41.7576973097665, 40.639506340026855, 41.24430186407906, 41.45047576086861, 39.74185814176287, 40.60985490253994, 39.73713684082031, 39.814195837293354, 40.389888831547324, 40.524392059871126, 41.674239022391184, 41.49697310583932, 42.105923652648926, 41.974825041634695, 44.90648889541626, 42.934961863926475, 43.11829703194754, 41.550165040152415, 42.186633927481516, 40.68801866258894, 44.93710265840803, 42.304850578308105, 42.19460698536464, 42.67568983350481, 39.77378511428833, 43.0488497870309, 40.638245241982595, 43.21883051736014, 42.30980116980416, 45.05941179820469, 45.01016296659197, 43.89772163118635, 44.065885407584055, 48.43147332327706, 46.25532184328352, 47.528982230595176, 44.6212340763637, 50.77512502670288, 58.44724600655692, 58.21310213633946, 61.32473128182547, 64.70449488503593, 58.39113235473633, 16.67313357761928, 1.334593374814306, 2.5569707368101393, 0.22147119737097196, 0.11815195929791246, 17.56977776118687, 73.63476439884731, 52.50198514120919, 58.91897310529436, 39.20000287464687, 20.485156774520874, 43.98682880401611, 61.633099283490864, 63.30045849936349, 60.37960951668875, 3.132104835339955, 0.20434253077421868, 0.2498637895498957, 0.11088157192404781, 0.22225052198129042, 0.08656639166708503, 0.14195818400808743, 0.11672803999057837, 0.12770501311336244, 0.15181731139974936, 0.11124551775200026], [0.029450472377772843, 0.019615587345989685, 0.0598545443000538, 0.012782170586953205, 0.02964439768610256, 0.022602698665910533, 0.027956512989476323, 0.09199019348514931, 0.07186574049826179, 0.08245309202798776, 0.9233731435877937, 46.388824531010215, 57.65504019601004, 45.41701820918492, 33.62989262172154, 25.667686087744578, 42.326341356549946, 40.97473955154419, 46.66640159061977, 60.35915402003697, 23.807792288916453, 0.03580778231844306, 0.042150395190609355, 0.3328398827995573, 1.7921674272843768, 1.4542179043803896, 46.54587813786098, 62.936004638671875, 58.63490990230015, 59.29430089678083, 56.65755680629185, 55.95811292103359, 57.73159197398594, 56.81395033427647, 53.595381464277, 52.68848173958914, 49.50168003354754, 41.94218587875366, 39.944933141980854, 37.368930203574045, 39.25067956107003, 38.35635954993111, 37.715325696127756, 38.201237542288645, 38.3673654964992, 38.51540034157889, 38.40714740753174, 38.26177372251238, 37.93232141222273, 37.08371359961373, 37.117461000170024, 38.24637304033552, 37.866966656276155, 36.10108545848301, 35.19178165708269, 35.812318325042725, 35.14776481900896, 34.78815385273525, 34.89484691619873, 34.98631647654942, 33.597048486982075, 36.383151054382324, 36.72952222824097, 36.409717491694856, 37.61195387159075, 36.559173243386404, 37.72495589937483, 36.91004337583269, 38.6664993422372, 38.0979699407305, 36.91509124210903, 35.3468793460301, 36.934254373822895, 39.01550040926252, 41.759903362819124, 44.357379708971294, 45.92378854751587, 46.245962619781494, 49.76046569006783, 50.276268686567036, 50.88199526923043, 46.738197326660156, 49.61710350854056, 48.53808648245675, 45.972526686532156, 45.633478913988384, 47.86829056058611, 47.502450534275596, 39.32291650772095, 48.08896882193429, 47.98014266150338, 46.10526507241385, 45.23394012451172, 47.79585559027535, 46.255815165383474, 46.87944378171648, 46.294172695704866, 46.8966440473284, 45.29954501560756, 44.393850803375244, 46.51543460573469, 48.35402522768293, 39.634303501674104, 38.132610184805735, 36.085969652448384, 36.10706785746983, 37.711295740945, 38.349484307425364, 39.170775277274, 36.00816372462681, 35.255795410701204, 36.384902000427246, 34.93702942984444, 35.52562870298113, 36.180631910051616, 36.26020268031529, 36.4743982723781, 38.32044431141445, 38.6186123575483, 39.85791390282767, 38.30177450180054, 38.46445962360927, 37.80043765476772, 36.40597588675362, 36.661363874162944, 37.00863831383841, 38.372594015938894, 38.667058672223774, 37.306347778865266, 38.114662987845286, 37.13644347872053, 37.508919034685405, 39.06772654397147, 40.53873661586216, 42.2205411366054, 42.98406825746809, 44.07094022205898, 44.47658995219639, 44.761177744184224, 46.36717047010149, 46.00034727369036, 45.57172679901123, 44.42444372177124, 42.672330379486084, 41.44967671803066, 47.463794231414795, 51.22571570532662, 53.99444777624947, 55.450088432856965, 60.9225070135934, 26.56647379057748, 0.016179195937833617, 0.28884296651397434, 0.07949563608105693, 0.008586568042768963, 5.020426971571786, 58.179663930620464, 44.615314211164204, 42.35329341888428, 31.40294633592878, 17.383651154381887, 28.309695175715856, 45.54496233803885, 51.60374634606497, 41.042977809906006, 1.8629381954669952, 0.046177985678826056, 0.03359721361526421, 0.045846131164580584, 0.00897195388097316, 0.016105503642133305, 0.03586753071951015, 0.027646950046930994, 0.08296221042318003, 0.042329012748918364, 0.01062887956920479, 0.05320626836536186, 0.03530890640935727, 0.025839627919984714, 0.06374832428991795, 0.03552114198516522, 0.05843226704746485, 0.01392664881755731, 0.04564067076093384, 0.07102960893618208, 0.0942761983190264, 2.596609775509153, 57.303940773010254, 62.43453924996512, 54.43535961423601, 41.04548610959734, 22.8133522101811, 34.57050153187343, 41.845946380070274, 48.7615509714399, 65.797682762146, 26.25541683605739, 0.05182175497923579, 0.0251427911155458, 0.6361363508871624, 2.6534636276108876, 1.6916388273239136, 49.98192909785679, 65.10181372506278, 61.86167417253767, 60.265304701668875, 58.027241298130576, 57.99474457332066, 58.275055749075754, 57.72918094907488, 55.821188245500835, 55.82494374683925, 51.96122768947056, 45.8522881099156, 43.427022865840364, 40.32975217274257, 40.56469161169869, 40.68119205747332, 39.103499344417024, 39.00038807732718, 38.121385369982036, 39.64973545074463, 40.22679724012102, 40.11064420427595, 40.47189841951643, 38.973859855106895, 37.10428721564156, 40.20670999799456, 36.659418378557476, 39.094755036490305, 37.42608608518328, 38.13691806793213, 37.453771182468955, 38.13224540437971, 38.40077590942383, 36.360291481018066, 36.501489298684255, 38.247001852308, 38.4698166847229, 39.610002177102224, 39.14153725760323, 38.76712662833077, 39.739693777901785, 39.414573669433594, 39.871382985796245, 39.486452783857075, 38.531381198338096, 37.82416922705514, 37.7235871042524, 41.27488088607788, 42.98857763835362, 46.317532539367676, 46.70113910947527, 49.202164036887034, 50.291249002729145, 51.16189302716936, 52.58985900878906, 48.380060127803254, 50.16194650105068, 51.31511470249721, 47.67200742449079, 48.41893877301897, 50.00030708312988, 48.620363576071604, 40.7287802696228, 49.224596296037944, 50.15577302660261, 47.74779837472098, 47.72076988220215, 49.40976578848702, 49.66408027921404, 49.44638279506138, 47.815529414585654, 48.43001767567226, 47.01648310252598, 45.57857772282192, 48.51733916146414, 50.18281194141933, 41.85233524867466, 39.17081001826695, 37.57399933678763, 39.296579360961914, 39.15392242159162, 39.44201905386788, 39.99701336451939, 38.78776625224522, 37.78750010899135, 38.83708803994315, 36.40023667471749, 37.50588614600045, 38.018301895686555, 37.40082938330514, 38.732462065560476, 40.37300818307059, 41.700892312186106, 41.465869494846885, 40.360331194741384, 40.9639698437282, 39.53305435180664, 38.71797507149832, 38.164912360055105, 38.56322479248047, 40.59526021139962, 39.82436105183193, 40.14378711155483, 40.11639036451067, 37.75885616030012, 40.11649111339024, 40.2320431300572, 42.92045055116926, 44.79668998718262, 44.71010501044137, 44.83293179103306, 47.12645918982369, 46.81257431847708, 48.36053221566336, 49.69133806228638, 48.81143208912441, 46.51044579914638, 45.24330629621233, 44.862520694732666, 49.52194445473807, 54.847023010253906, 55.009864466530935, 56.76747383390154, 63.731670652117046, 29.821435587746755, 0.49463520092623575, 0.9599901501621518, 0.04862058282430683, 0.03477537093151893, 4.552664688655308, 63.21892138889858, 48.85193313871111, 43.611646924700054, 32.95390932900565, 22.636840173176356, 34.572742325919016, 52.68403836659023, 55.328199659075054, 54.456895555768696, 4.8800894277436395, 0.186385128647089, 0.12881289795041084, 0.01180464674585632, 0.018929330598829047, 0.039345792827329466, 0.046907621169728894, 0.011135900443020676, 0.03384523852063077, 0.014706649418388094, 0.04097787310768451, 0.2709553449281624, 0.11702272774917738, 0.10254905332944222, 0.21512272874159472, 0.1154089407729251, 0.12931718517627033, 0.11217880874340024, 0.25579985816563877, 0.186128900253347, 0.3784719599144799, 4.381439362253461, 68.84284196581159, 68.57989433833531, 63.79205744607108, 46.9854177066258, 32.81293385369437, 51.527548926217214, 50.386696406773154, 56.88185855320522, 69.6407869883946, 30.281729425702775, 0.14722346647509507, 0.12499499853168215, 0.7577191867998668, 7.950086270059858, 3.356065469128745, 51.726416792188374, 66.80556760515485, 65.30937031337193, 63.36767537253243, 60.29912853240967, 61.3156430380685, 62.236724036080496, 61.20133127485003, 58.118377344948904, 56.88860872813633, 53.17886822564261, 46.540854590279714, 46.18043415887015, 41.1279855455671, 42.38183314459664, 42.643946988242014, 41.091170515332905, 41.48482070650373, 40.81644916534424, 42.91075781413487, 42.18347944532122, 41.584791387830464, 43.217360973358154, 40.7166382925851, 38.55464376722063, 43.35339975357056, 39.5473051071167, 40.97267941066197, 39.868572439466206, 40.484450340270996, 39.155756746019634, 39.77615792410714, 40.201776776994976, 39.85017013549805, 37.68666090284075, 40.20039061137608, 41.55524417332241, 40.554345743996755, 41.539086137499126, 40.04737390790667, 41.88011762074062, 40.38498340334211, 42.50358642850603, 41.39792306082589, 40.80695445196969, 39.82130037035261, 40.773870604378835, 44.14881215776716, 46.52160460608346, 48.05033336366926, 48.7681691305978, 51.91763121741158, 53.93596131461007, 55.73802178246634, 54.27758686883109, 50.20875998905727, 53.51039457321167, 54.476906367710654, 49.55859620230538, 49.72199351446969, 51.17285033634731, 51.60333292824881, 43.17200313295637, 51.62282262529646, 53.86203942980085, 50.23366928100586, 49.82665770394461, 51.97969947542463, 50.499420506613596, 51.30724934169224, 48.68754570824759, 50.001894746507915, 48.72091095788138, 47.96254634857178, 51.681739875248496, 52.65461621965681, 44.48209292548043, 43.27053206307547, 39.22306047167097, 40.23832082748413, 41.463812828063965, 41.65902246747698, 42.83458471298218, 39.503962244306294, 39.59009558813912, 40.31126996449062, 38.807572092328755, 39.508558477674214, 40.450286047799246, 39.43921545573643, 40.92323950358799, 41.66983386448452, 43.933584758213584, 44.21582405907767, 43.57974427086966, 42.94046483721052, 42.67607545852661, 40.28801086970738, 39.774997574942454, 40.22970853533064, 43.9076714515686, 42.39753259931292, 40.679739883967805, 40.46417549678257, 39.69059780665806, 42.12812314714704, 43.91492189679827, 45.93980414526803, 47.91882480893816, 46.741987568991526, 48.12096527644566, 49.336083616529194, 49.37107474463326, 50.35141692842756, 50.96484211512974, 51.81538847514561, 48.913101605006624, 48.378576687404085, 46.60282557351248, 52.75218629837036, 56.7412235396249, 57.31314018794468, 60.04542200905936, 67.13544028145927, 32.89475236620222, 1.476258350270135, 1.9691453192915236, 0.5635941720434597, 0.09575747419148684, 6.77142208814621, 69.45869554792131, 54.042907987322124, 56.53794356754848, 42.78163596561977, 26.842253003801616, 40.7450008392334, 61.65334633418492, 63.30667018890381, 64.9171861921038, 7.684261219842093, 0.30806415368403706, 0.22576986599181378, 0.15822402547512734, 0.13804775955421583, 0.1485225489096982, 0.1348901018500328, 0.10640689131936856, 0.20785244314798287, 0.08834172426057713, 0.10624881980142423], [0.06167350669524499, 0.0709291925387723, 0.0232497581413814, 0.09406021383724042, 0.055477158831698556, 0.031782536168715785, 0.04377110322405185, 0.03400875188942466, 0.03781888886754002, 0.16934007113533361, 8.687430841582161, 59.842548506600515, 50.961371489933555, 36.85661520276751, 44.49335248129708, 42.59342316218785, 38.4087107522147, 38.1929726600647, 44.28730365208217, 64.62740462166923, 22.134942259107316, 0.16408675802605494, 0.0568686645211918, 0.47775048123938696, 1.436053793345179, 5.61432945728302, 66.88260923113141, 58.42545645577567, 58.93734414236886, 52.8877352305821, 54.47205305099487, 52.54568931034633, 54.890265124184744, 52.21835272652762, 51.38850852421352, 44.95343439919608, 39.78548240661621, 39.13221277509417, 39.80857821873256, 37.57551751817976, 37.60221249716622, 38.356130259377615, 38.03632204873221, 36.76143183026995, 37.0097222328186, 37.977338790893555, 37.574878283909385, 37.47354228155953, 37.58650956835066, 38.72264773505074, 36.560865129743306, 36.89808552605765, 35.81569514955793, 35.91222299848284, 36.9452360016959, 36.25794104167393, 36.09714930398123, 37.0087251663208, 35.8745880808149, 35.238074030194966, 34.78636121749878, 35.16555915560041, 37.467955929892405, 35.995879309517996, 38.432998180389404, 36.977454798562185, 38.87803030014038, 38.867656639644075, 39.07229845864432, 38.89608519417899, 38.27309233801705, 35.94745036533901, 36.237888540540425, 38.66345255715506, 38.96255166190011, 42.60905313491821, 47.001617431640625, 50.6002562386649, 49.59367070879255, 48.12627370016915, 45.92990296227591, 47.61461877822876, 50.05694532394409, 46.5839056287493, 43.340208598545615, 41.80550786427089, 50.398275579724995, 49.01842587334769, 36.97749301365444, 48.94967344829014, 46.90767431259155, 45.56876686641148, 45.61850207192557, 48.84899057660784, 46.8464606830052, 45.574929918561665, 44.944214139665874, 46.86357409613473, 43.93295247214181, 44.163469382694785, 46.12555728639875, 45.45259298597063, 38.25237628391811, 35.889245305742534, 36.543696131025044, 36.90927559988839, 38.709960324423655, 38.26381301879883, 37.54269075393677, 36.670316628047395, 36.61933422088623, 36.43045091629028, 36.14077009473528, 35.34053911481585, 36.09338338034493, 38.17880875723702, 37.60574565614973, 39.917321000780376, 38.977754320417134, 39.93977410452706, 40.35310506820679, 38.03021805627005, 37.28521135875157, 37.63883992603847, 38.90058415276663, 38.19909749712263, 37.256560461861746, 38.37653711863926, 38.41527679988316, 37.34732478005545, 40.48413072313581, 42.06542260306222, 44.9881580216544, 45.88750852857317, 47.80628831045968, 46.74225507463728, 47.65185764857701, 48.62427888597761, 47.75364875793457, 48.67901679447719, 48.954161984579905, 48.2723456791469, 51.25088555472237, 46.31971079962594, 47.721273626599995, 46.55280549185616, 48.30095836094448, 54.013763768332346, 57.096978255680625, 56.3594582421439, 37.55692761284964, 1.4541712211711066, 0.45632511377334595, 0.16508835713778222, 0.10834008508494922, 1.0707979585443224, 43.79578460965838, 55.947499547685894, 40.568443638937815, 32.87008626120431, 16.466471569878713, 22.045117684773036, 42.562156268528526, 47.377056394304546, 46.51704658780779, 8.703100766454424, 0.09099892846175603, 0.03066401868792517, 0.12987940572202206, 0.06145108970148223, 0.03428886132314801, 0.0644260857786451, 0.0479149403316634, 0.04363420878403953, 0.031193007981138568, 0.022673349428389753, 0.07013588332171951, 0.037278415369135995, 0.004447261004575661, 0.010029026623150068, 0.06115744010146175, 0.06693541005785976, 0.07942481059581041, 0.005634037411904761, 0.19335855517004216, 0.28734188420431955, 13.511432238987513, 69.70969922201974, 56.08779757363455, 42.60592297145298, 50.72470889772688, 53.604271684374126, 38.41549219403948, 40.25283908843994, 47.21872431891305, 71.33231203896659, 22.916315828050884, 0.05273343802296689, 0.07524496024208409, 0.9099930844136647, 2.839529654809407, 7.30394983291626, 69.80998257228306, 59.46519878932408, 61.707410267421174, 54.79438345772879, 56.443326473236084, 54.791360991341726, 56.8811811038426, 55.39544432503836, 52.95795719964163, 46.67500693457467, 42.415879317692344, 40.49517141069685, 41.37873213631766, 40.43377365384783, 40.88797392163958, 40.58257974897112, 40.13053689684187, 39.2822938646589, 39.412395409175325, 40.344398975372314, 39.50082860674177, 39.314561298915315, 39.43905912126814, 40.781082834516255, 38.558666774204795, 39.00682558332171, 39.16637706756592, 39.620052746364046, 39.64177976335798, 38.57109015328543, 37.99880525044033, 38.311779907771516, 37.61066150665283, 36.639258180345806, 36.79474496841431, 37.03225176674979, 38.272317613874165, 37.58671454020909, 38.234345708574565, 38.969169821058, 40.71054472242083, 40.7938814163208, 40.71340390614101, 41.61352913720267, 39.266420704977854, 38.61299473898751, 37.465597016470774, 40.50700766699654, 40.75671550205776, 44.06767456872122, 49.12010581152779, 51.58087635040283, 51.5649927684239, 49.309079442705425, 48.43545811516898, 48.47119270052229, 50.74203423091343, 48.21726383481707, 45.5949581010001, 44.7687999180385, 51.441505908966064, 50.730580125536235, 37.30049392155239, 51.58725479670933, 49.578419412885395, 47.826455456869944, 46.91754422869001, 49.411058153424946, 48.55476910727364, 48.06903444017683, 46.1558757509504, 47.68335730688912, 45.99830797740391, 45.61883211135864, 47.97228077479771, 46.89989927836827, 40.304533685956685, 37.73336321966988, 38.04502119336809, 38.47036559241158, 39.2131210735866, 41.0047036579677, 40.29428161893572, 39.33157743726458, 37.59998907361712, 39.032207352774485, 36.628022943224224, 36.950151852199006, 37.393314906529014, 38.772970063345774, 41.517015184674946, 43.40731430053711, 40.7580634525844, 41.268606662750244, 42.18571676526751, 39.84365272521973, 40.08435916900635, 39.29373754773821, 40.753658294677734, 39.81296600614275, 39.894013268607004, 39.69555534635271, 41.11200468880789, 39.617179666246685, 42.14700835091727, 45.00186334337507, 46.102089745657786, 48.55423757008144, 49.39288861410958, 48.07523570741926, 49.469923291887554, 50.8641106060573, 50.25905452455793, 50.380178996494834, 51.27954339981079, 51.23262568882534, 53.27166141782488, 48.607561520167756, 49.43855217524937, 49.59107208251953, 50.86484711510794, 56.31692484446934, 59.91506685529436, 59.33719212668282, 41.061935969761436, 1.7197268115622657, 0.8464596793055534, 0.08417176016207252, 0.04206279971237693, 1.1686500906944275, 47.25453880855015, 62.20156615121024, 45.08604424340384, 27.74360285486494, 18.170449529375347, 27.688057218279155, 46.939431054251536, 51.596989222935264, 55.60051345825195, 15.936414343970162, 0.13388576145683015, 0.05813052252467189, 0.06950228767735617, 0.039300761850816865, 0.011356001936032303, 0.042244246761713705, 0.07152382670236485, 0.03365599849660482, 0.044452532194554806, 0.024024709593504667, 0.1714530698955059, 0.15113721575055802, 0.09266966488212347, 0.25437526032328606, 0.16466904963765824, 0.13283901262496198, 0.18102634405451162, 0.1423559140946184, 0.3695431447454861, 0.3218743497771876, 17.483929293496267, 79.02615656171525, 63.393883977617534, 51.93707227706909, 52.42383180345808, 52.19171680722918, 46.385291372026714, 47.19057021822248, 54.97744417190552, 76.207015310015, 28.347785200391495, 0.3345770952957017, 0.20973913690873555, 1.7380015509469169, 8.037921922547476, 7.4371737241744995, 72.71270370483398, 62.089846066066194, 65.99050222124372, 57.77535172871181, 58.8855870110648, 57.96192823137556, 58.884690693446565, 57.13118076324463, 54.76852921077183, 48.83996834073748, 44.53320387431553, 43.76915216445923, 43.50400195802961, 42.681627069200786, 41.1540412902832, 42.64091757365635, 42.05313471385411, 40.50586468832833, 40.56541769845145, 42.4555743762425, 40.55994599206107, 42.29174280166626, 41.73760311944144, 43.258549894605366, 39.30555990764073, 42.42133712768555, 40.85142987115042, 41.48077685492379, 42.25281204496111, 40.718149525778635, 40.73489121028355, 40.61487150192261, 40.08522769383022, 38.29898132596697, 37.92198944091797, 38.81450292042324, 41.27373443331037, 41.04300907679966, 40.92221811839512, 40.925438608442036, 43.49547304425921, 43.75899389811924, 42.85179540089199, 42.27650192805699, 41.65179981504168, 40.1866192817688, 39.52575874328613, 43.354521887642996, 42.289877210344585, 46.20495087759835, 51.33142212459019, 54.73098461968558, 53.59326573780605, 49.712550912584575, 48.493152482169016, 50.14269651685442, 53.590149470738, 50.75806719916207, 49.57950333186558, 46.108158997126985, 55.49115228652954, 53.337033544267925, 41.530508586338584, 53.07717439106533, 52.467244148254395, 49.55899919782366, 49.08692816325596, 53.24462945120675, 50.05583013807024, 48.74145678111485, 47.60515533174787, 49.290934222085134, 47.89048310688564, 48.91869143077305, 48.6894599369594, 49.20532546724592, 42.378991331372944, 39.54737458910261, 38.45453412192208, 40.68124764306204, 41.7228798866272, 42.86954110009329, 42.538369110652376, 40.26856633595058, 40.366393498011995, 41.89606721060616, 38.95029156548636, 38.93611029216221, 40.118683270045686, 42.34984711238316, 44.51800121579851, 45.817581857953755, 42.508655139378135, 44.4038006237575, 45.01436315264021, 42.03825167247227, 42.829644543784006, 40.783962862832205, 43.437476430620464, 44.109325545174734, 41.88413715362549, 42.029364926474436, 42.70748131615775, 42.049455642700195, 44.48409400667463, 46.07797949654715, 47.36011668613979, 51.09890413284302, 52.32388891492571, 51.58017110824585, 52.31706925800869, 54.143976484026226, 52.69516243253435, 53.70557989392962, 53.35345908573696, 53.294114521571565, 57.53458275113787, 50.66170958110264, 52.46922091075352, 52.94952208655221, 54.97938619341169, 59.863907269069124, 62.31029156276158, 61.64953177315848, 42.522530691964285, 2.0838670262268613, 2.662594646215439, 0.9094543276088578, 0.19393897402499402, 1.6051378803593772, 52.20418882369995, 65.47996943337577, 54.75505665370396, 43.789583342415945, 25.89176549230303, 33.18559006282261, 57.12450354439871, 59.69615691048758, 63.65036283220564, 20.994298185620988, 0.2001395220203059, 0.0986998938024044, 0.15205314303083078, 0.12376375602824347, 0.14835264374102863, 0.16602508830172674, 0.163336379719632, 0.14948811781193527, 0.12076627330056258, 0.1432454599333661], [0.03983148480100291, 0.03065580841419952, 0.0352763604771878, 0.06721786383007254, 0.028215189198298112, 0.024824139196425676, 0.06798389593937568, 0.021018292255965725, 0.05121667816170624, 0.08310366461851768, 14.695681469781057, 61.810062953404014, 43.98524808883667, 43.09800829206194, 18.51044225692749, 13.779262713023595, 44.23138107572283, 46.19619962147304, 51.71914897646223, 59.61506448473249, 15.105923959187098, 0.049654683763427396, 0.06124671495386532, 0.7408701309135982, 1.4976636873824256, 18.24228869165693, 68.87640176500592, 54.84891292027065, 59.233066422598704, 49.91323920658657, 47.489999362400596, 44.78149427686419, 44.88961866923741, 41.55405255726406, 41.93407038279942, 36.397676263536724, 39.078958306993755, 38.25379024233137, 38.665696825299946, 34.69475269317627, 36.24192196982247, 34.28221729823521, 37.528926372528076, 34.93228728430611, 36.60185602733067, 36.1303061076573, 38.40772410801479, 37.7312023299081, 38.02700104032244, 36.625031743730815, 39.5193316595895, 38.756704330444336, 36.1566606249128, 36.22544779096331, 36.61733661379133, 35.539514677865164, 36.98529584067208, 35.563579763684956, 36.324685437338694, 35.721276078905376, 34.56936550140381, 35.32303312846592, 35.09172064917428, 37.89449194499424, 37.656283378601074, 39.16658551352364, 37.70997558321272, 38.37614801951817, 38.821326051439556, 39.00297628130232, 38.00419010434832, 36.479262011391775, 36.51994024004255, 36.726708207811626, 36.313974789210725, 38.448235579899375, 43.517964363098145, 48.47577503749302, 50.948190757206504, 48.79969310760498, 50.600888524736675, 48.82092680249895, 47.61762734821865, 43.6119943346296, 39.702322891780305, 44.57521963119507, 48.21102087838309, 47.75391278948103, 35.87200335093907, 45.94902787889753, 46.50015204293387, 43.58107485089983, 44.96075432641165, 47.22820513589041, 47.23854405539376, 45.99797098977225, 45.88927684511457, 44.55811316626412, 44.28759200232369, 45.01822635105678, 48.028092179979595, 45.03201505116054, 37.31856271198818, 35.644613129752024, 37.38578653335571, 37.49595717021397, 37.09286437715803, 37.31333071844918, 38.42335755484444, 37.47844770976475, 35.54404142924717, 35.80171537399292, 36.19098820005144, 36.199676922389436, 35.3481057030814, 36.04377671650478, 39.97338948931013, 40.09578895568848, 39.05152334485735, 38.89585937772478, 38.33437892368862, 37.36541788918631, 35.9119485446385, 37.55132736478533, 37.00989941188267, 37.99493162972586, 38.09144558225359, 37.80127491269793, 38.245622634887695, 40.63110249383109, 46.133287157331196, 48.84693043572562, 49.47003446306501, 50.672253472464426, 50.79547282627651, 50.74814864567348, 51.013458660670686, 50.5874194417681, 50.453242778778076, 51.88542979104178, 50.73889364515032, 51.758607796260286, 49.451316016060964, 48.128670828683035, 48.85141202381679, 50.20157902581351, 48.73584611075265, 49.66678312846592, 55.142522948128835, 60.16769640786307, 49.547795227595735, 5.018281715256827, 0.9053624357495988, 0.2035190335341862, 0.04996062163263559, 0.24439729430845805, 31.24340874808175, 62.18690545218331, 42.60020112991333, 56.20657008034842, 29.123952831540787, 24.050202778407506, 40.53715590068272, 45.267465182713096, 57.33815022877285, 22.636909655162267, 0.0288750136138073, 0.07410863121705395, 0.034533354453742504, 0.04151262316320624, 0.015411905146070888, 0.14921768089490278, 0.024001973581367304, 0.054345382776643546, 0.008083633646102888, 0.05209824103595955, 0.07108082475938968, 0.030405323819390366, 0.04758164732317839, 0.034258581697940826, 0.010219689874377633, 0.019411472138017416, 0.05654824332201055, 0.032182257755526474, 0.02543677489406296, 0.09844947366842202, 22.41909752573286, 69.3001376560756, 50.81650502341134, 46.42332581111363, 24.577048199517385, 19.62814858981541, 40.14099740982056, 48.01292078835623, 55.6777982711792, 64.87681715829032, 17.99005171230861, 0.03274533325540168, 0.050813109281339815, 3.3428539037704468, 0.39061035428728375, 20.741203103746685, 71.09189741952079, 58.16373865944998, 60.04476193019322, 51.47247403008597, 49.342135497501914, 46.12710673468453, 47.43839161736624, 44.34713806424822, 43.540980270930696, 38.31788042613438, 42.13144438607352, 39.67042023794991, 40.23331117630005, 37.72262477874756, 37.7626359803336, 36.30588361195156, 38.60291985103062, 38.14471742085048, 37.56662382398333, 39.17065715789795, 40.15831926890782, 38.818084716796875, 39.009139333452495, 38.30146878106253, 41.165790694100515, 40.004649434770855, 39.09328201838902, 39.44857815333775, 38.65434694290161, 36.71764428274972, 39.533478191920686, 37.69482503618513, 38.42582763944353, 38.47786617279053, 37.16778332846505, 36.17052575520107, 38.346798828669954, 38.75135769162859, 38.70074701309204, 40.593773296901155, 38.932650089263916, 40.737347398485454, 40.5814402444022, 39.986538955143516, 39.58168479374477, 38.64606121608189, 38.27286652156285, 37.37028510229928, 39.43895142418997, 41.49395063945225, 46.13330452782767, 49.0956585747855, 50.93288040161133, 50.824898447309224, 50.9303686278207, 51.40594155447823, 48.93266773223877, 46.4211162839617, 42.47234385354178, 45.704166412353516, 49.31802872249058, 49.930960587092805, 37.62647213254656, 46.54581560407366, 48.5897741317749, 47.08783415385655, 46.81646530968802, 48.74843277250017, 49.9972950390407, 47.40357766832624, 46.56051451819283, 47.2105393409729, 47.43938173566546, 47.153921944754465, 49.34868764877319, 47.076856000082834, 39.76197665078299, 36.38465881347656, 40.2190534727914, 37.882068565913606, 39.127932684762136, 39.56140647615705, 39.36039161682129, 39.21211358479091, 38.61710112435477, 38.37892035075596, 38.95762191499983, 37.39161607197353, 38.08708906173706, 37.67615522657122, 41.64230857576643, 42.20576926640102, 40.50726475034441, 40.17073222569057, 40.41089670998709, 38.03150347300938, 37.123294012887136, 38.48126384190151, 39.50957291466849, 39.95844391414097, 39.75129726954869, 39.58854613985334, 40.075858048030305, 42.266680649348665, 48.64310850415911, 51.217770440237864, 50.263959952763145, 52.50796406609671, 52.762935161590576, 53.72973530633109, 54.346023150852744, 52.86296142850603, 53.05517292022705, 53.40546635219029, 52.836464473179404, 53.1965583392552, 51.587661266326904, 52.472861766815186, 52.24166393280029, 52.861898354121614, 50.44219166891915, 52.51821265901838, 57.725616523197715, 60.532928466796875, 53.97943271909441, 5.711807038102831, 1.2534021543604987, 0.4306556454726628, 0.21909256572169916, 0.18710912551198686, 33.55499798910958, 66.73131915501186, 47.04496029445103, 46.74021577835083, 32.06756932394845, 32.41464226586478, 47.00113453183855, 50.7466721534729, 64.45191396985734, 30.518200942448207, 0.1454506173197712, 0.02144038853501635, 0.028813307639211416, 0.03832374606281519, 0.017148698646841303, 0.06783634171422039, 0.020206677860447338, 0.02015706677255886, 0.016207636733140265, 0.058773298747837543, 0.14523146407944815, 0.15653496182390622, 0.15392885809498175, 0.14910192282072135, 0.13625193520316056, 0.11386083598647799, 0.12669295099164757, 0.08422174783689634, 0.1235399344669921, 0.16813979697014603, 29.150972638811382, 78.64217131478446, 55.860428197043284, 57.643502712249756, 27.203594071524485, 20.37135222979954, 51.0252115385873, 57.93738371985299, 61.286953926086426, 69.60690757206508, 21.466492550713674, 0.2094120287469455, 0.12332056409546308, 5.0786711147853305, 6.708683328969138, 21.30705050059727, 74.34244537353516, 59.396467208862305, 62.35018811907087, 54.13602427073887, 52.16907957621983, 48.138078689575195, 49.20868839536394, 46.64742953436715, 45.865687710898264, 40.107604367392405, 44.317368507385254, 41.262672901153564, 42.93975264685494, 39.732505866459434, 40.578511578696116, 37.44665970121111, 41.12262153625488, 39.03777633394514, 39.96783093043736, 42.539922033037456, 43.382168769836426, 41.08706065586635, 41.179159028189524, 40.05743489946638, 44.5745803969247, 43.33764818736485, 39.41030747549874, 41.88594715935843, 42.2336871283395, 38.22860997063773, 41.72033337184361, 39.551717213221956, 41.060188497815815, 41.179065227508545, 39.15748684746878, 39.76282780511038, 38.63853979110718, 41.882417474474224, 41.6093567439488, 44.49613176073347, 41.2056108202253, 43.5052422114781, 41.51626130512783, 42.440722601754324, 42.09407697405134, 40.86770602634975, 40.593130588531494, 40.60078402927944, 40.14888708932059, 43.26384094783238, 47.48568105697632, 51.98383712768555, 53.14277580806187, 52.70191608156477, 53.31188453946795, 53.9529253414699, 50.92417778287615, 48.93539490018572, 44.46807493482317, 48.927467005593435, 52.6842155456543, 51.77446011134556, 39.80369363512312, 48.30212218420846, 51.357144355773926, 48.55998373031616, 48.52566310337612, 51.90984923498971, 50.98736470086234, 48.028377056121826, 49.19522278649466, 49.563661439078196, 49.58698306764875, 48.66589512143816, 52.88853427342006, 48.94650159563337, 41.70238617488316, 39.39731434413365, 42.14923872266497, 40.19293172018868, 40.18126916885376, 40.24888208934239, 42.91540615899222, 41.53792231423514, 40.141518524714876, 40.42290667125157, 41.08684178761074, 41.36037499564034, 39.10414205278669, 39.89184890474592, 44.59139156341553, 45.89129877090454, 42.495992047446116, 42.06618343080793, 42.65309429168701, 41.020955494471956, 39.47268145424979, 41.284163679395405, 41.16842753546578, 43.45403051376343, 42.00081825256348, 41.15887723650251, 42.279048442840576, 43.834621565682546, 50.02543176923479, 53.44489737919399, 53.240307671683176, 55.6897109576634, 54.781987871442524, 54.83910206386021, 56.004096099308555, 55.16101557867867, 55.19769164494106, 54.671386446271626, 54.12535183770316, 55.8426581791469, 52.89253990990775, 52.94641276768276, 53.12798309326172, 55.22272947856358, 51.37765196391514, 54.73825590951102, 60.37130641937256, 66.16156687055314, 56.58881827763149, 6.602614734854017, 2.3383358972413197, 1.0686888545751572, 0.2973161047058446, 0.355567738945995, 38.50101409639631, 73.0225169318063, 54.130479608263286, 73.11022404261998, 40.239342212677, 37.21145623070853, 55.10463442121233, 59.52153478349958, 72.62351662772042, 39.99339682715279, 0.5959315225481987, 0.1357735815857138, 0.13918908259698323, 0.11461129571710314, 0.09485696322683777, 0.21247906131403788, 0.05987121590546199, 0.14685884889747414, 0.1409793429608856, 0.13976711300866945], [0.07121487613767385, 0.049974782658474784, 0.01285793156629162, 0.02980139372604234, 0.011335991090163589, 0.07435056287795305, 0.02422859749224569, 0.13890858979097434, 0.018834166062463607, 0.24364330619573593, 22.757785728999547, 56.72170604978289, 44.67860535212925, 44.03353806904384, 24.31112153189523, 32.379560811179026, 40.10393571853638, 46.04908888680594, 49.75205142157418, 59.28843661717006, 9.343617847987584, 0.18199861688273294, 0.11047916673123837, 0.45216854395610945, 1.8264731807368142, 26.806950943810598, 71.20281846182687, 52.573534216199604, 62.114595549447195, 48.21359518596104, 46.75981317247663, 41.5942166192191, 43.34398147038051, 39.754906858716694, 40.93652793339321, 38.49224894387381, 39.17075443267822, 36.675169944763184, 39.56953934260777, 38.094356877463206, 42.65470279966082, 42.342127663748606, 43.39923701967512, 42.63844748905727, 41.563481262751985, 37.408958775656565, 36.68514060974121, 34.588400091443745, 36.90409919193813, 37.577622822352815, 37.53308834348406, 36.11220952442714, 34.9661180632455, 35.09867927006313, 35.464234420231406, 35.487681116376606, 34.37521546227591, 34.7649051802499, 36.88004452841622, 36.00182349341256, 36.422710623059956, 34.61289596557617, 35.664293902260916, 37.31344536372593, 36.600310053144185, 37.336839948381694, 39.95246498925345, 37.44563831601824, 39.02523830958775, 38.00877938951765, 39.033947876521516, 36.45453684670584, 38.027810505458284, 38.48140627997262, 37.983967372349326, 37.00370509283883, 40.723020212990896, 44.6299193246024, 48.41232408796038, 47.583657605307444, 48.50889015197754, 46.55497680391584, 42.095272064208984, 39.20421348299299, 39.31827858516148, 45.63289873940604, 47.43677963529314, 48.66677406855992, 35.851652077266145, 45.037170614515034, 48.132238728659495, 44.20245572498867, 44.608188833509175, 43.55639484950474, 46.871779918670654, 46.72929321016584, 46.597993101392476, 46.30999026979719, 45.184722559792654, 47.939818790980745, 46.7365471294948, 42.837207657950266, 38.85760954448155, 36.91792263303484, 38.616850989205496, 37.325229508536204, 38.11032383782523, 36.56225824356079, 38.03094066892351, 36.84031472887312, 37.93355471747262, 36.496462277003694, 37.10171985626221, 34.81261151177542, 35.44753442491804, 37.21137980052403, 40.13207244873047, 39.49076066698347, 38.97503410066877, 37.19250501905169, 35.01319210869925, 36.272334235055105, 37.316464356013704, 37.01175805500576, 38.86563123975481, 37.19422469820295, 38.8649468421936, 38.13665056228638, 39.79493890489851, 47.69958482469831, 50.52444096973964, 48.56424992425101, 53.121934686388286, 53.27276965550014, 49.47431802749634, 51.18179266793387, 54.08212014607021, 51.1124392236982, 50.82378326143537, 51.46863167626517, 52.47621079853603, 51.9969344820295, 52.94666290283203, 51.697689465114046, 55.83605739048549, 53.98478978020804, 55.636470385960166, 51.93789563860212, 55.83239916392735, 53.79972103663853, 54.06746639524187, 8.821141106741768, 0.6121196310435022, 0.1091720572273646, 0.022239115854193057, 0.04985669381650431, 19.226978710719518, 62.67915058135986, 45.68641723905291, 34.30300978251866, 16.7339893749782, 19.206934894834244, 35.028023038591655, 45.9352947643825, 52.67263637270246, 37.14917605263846, 1.111086870942797, 0.07123562573854413, 0.027381542770724212, 0.06710743225578751, 0.038314249965229204, 0.011258489668502339, 0.007714888879231044, 0.03953861212357879, 0.042851722200534174, 0.03313456469082406, 0.033842368317501884, 0.0982514296525291, 0.039340778453541655, 0.021987990043791275, 0.05649864919749754, 0.013126690805490528, 0.044146377194140635, 0.18107769558472292, 0.023970406435962235, 0.42464776071054594, 30.836761951446533, 65.54115527016776, 49.04141746248518, 50.70263794490269, 26.714875153132848, 32.78127786091396, 44.25135019847325, 47.429664679935996, 55.92045021057129, 63.10499177660261, 11.108534983226232, 0.25255225385938374, 0.16932583547064237, 1.4379237272909708, 1.3310512048857552, 28.740627663476126, 72.39735971178327, 55.13925034659249, 63.31218705858503, 49.541517530168804, 48.62785720825195, 42.30668837683541, 45.29108905792236, 42.28776843207223, 43.34122650963919, 40.66960941042219, 40.60231958116804, 38.8836270741054, 41.4800056048802, 39.988418442862375, 44.39825596128191, 43.713993889944895, 44.97014134270804, 44.204039914267405, 42.62242146900722, 38.695132868630544, 38.12190301077706, 38.07508952277047, 37.574673312050955, 39.21805082048689, 39.30879429408482, 38.29581642150879, 37.33332763399397, 37.260343755994526, 38.33128350121634, 38.20294679914202, 37.34620264598301, 36.37842975343977, 39.1750762122018, 38.3443078994751, 37.43983309609549, 36.51186295918056, 38.22232532501221, 38.471956729888916, 38.98183986118862, 38.643459115709575, 41.67769227709089, 39.1372606413705, 39.750362736838206, 39.44765404292515, 39.50597027369908, 37.584244455610005, 38.53780828203474, 39.21277366365705, 39.80881445748465, 38.208911827632356, 43.00815071378435, 45.671784332820344, 49.890598501477925, 50.986221722194124, 49.51233857018607, 47.862686838422505, 45.415395804813926, 41.859867095947266, 39.5943409374782, 46.99127851213728, 50.04202059337071, 50.95169264929635, 37.87581866128104, 48.419251441955566, 49.939065660749165, 46.878460611615864, 45.431022303445, 45.52706030436924, 48.25019134793963, 48.13219009126936, 50.18526118142264, 48.85190882001604, 47.36048494066511, 49.4174678666251, 48.08413634981428, 44.72469275338309, 39.75142581122262, 37.579905305589946, 41.44828360421317, 40.23192848478045, 40.28832353864397, 38.71260758808681, 38.97199773788452, 37.98633670806885, 38.86451257978167, 38.12899364743914, 39.42654888970511, 37.16871091297695, 36.65553433554513, 38.489389760153635, 42.01695544379098, 43.02566712243216, 40.77774422509329, 38.49767548697335, 37.226134300231934, 39.51349517277309, 38.45852586201259, 38.842035157339915, 40.615031310490195, 38.09089320046561, 39.800400188991, 40.06649187632969, 41.015167645045686, 49.381514413016184, 52.550150053841726, 51.21340697152274, 53.606373514447895, 53.250990527016775, 52.65844815117972, 53.21708679199219, 56.266310691833496, 52.58814975193569, 53.268562521253315, 54.26961381094796, 54.36105557850429, 54.064749649592805, 55.042878832135884, 53.71678039005825, 57.74581841060093, 56.61380052566528, 57.78459978103638, 54.82081093106951, 58.515991483415874, 56.40643501281738, 56.04906831468855, 10.673159990991865, 0.5673306201185498, 0.921893828681537, 0.12835238980395453, 0.057874592686338086, 20.20534760611398, 68.07286344255719, 50.61615024294172, 41.20078877040318, 20.499780995505198, 27.92999175616673, 39.31657975060599, 51.848844051361084, 57.60820238930838, 46.6756010055542, 2.09206394638334, 0.030979201596762453, 0.06816442018108708, 0.05163362775264042, 0.013981879871737744, 0.04958678615678634, 0.024127638266820992, 0.010163888850781535, 0.048243191824959855, 0.06391005989696298, 0.14057496323117188, 0.15213511006108352, 0.14570633002689906, 0.09507256094366312, 0.16485624387860298, 0.20086332889539854, 0.09819672615932566, 0.23850546617593082, 0.08655318737562213, 0.5568613676088197, 38.54671934672764, 74.3052099772862, 57.79381309236799, 61.321125166756765, 34.17358916146414, 44.765534264700754, 48.66537400654384, 57.50623410088675, 58.586779730660574, 69.25938647133964, 12.756572995867048, 0.32835492917469566, 0.42906920345766203, 4.454144878046853, 4.764500064509256, 31.664566857474192, 74.00697244916643, 56.9342931338719, 66.44210733686174, 53.059397424970356, 50.78480734143938, 44.76928629193987, 46.8258627482823, 44.165185587746755, 44.26510068348476, 43.929151807512554, 43.109281744275776, 39.98988103866577, 43.01208339418684, 42.36030762536185, 48.10439034870693, 46.0993834223066, 46.614894594464985, 48.78507062367031, 44.30295099530901, 40.26517561503819, 40.661810057503835, 38.482639585222515, 40.1617933682033, 43.33179433005196, 40.701084750039236, 40.11810656956264, 39.54540824890137, 38.8334367615836, 41.148048468998496, 41.048928941999165, 39.513717515128, 39.17921386446272, 41.82018593379429, 39.99136447906494, 39.46130725315639, 38.26131166730608, 40.73923036030361, 40.719236918858115, 40.55166026524135, 41.515236445835654, 43.699083055768696, 41.22557299477713, 41.17474692208426, 40.71126733507429, 42.683812277657644, 40.45936039515904, 40.9357636315482, 42.42886897495815, 42.25730405535017, 40.001880577632356, 45.95233869552612, 49.16325412477766, 51.897450174604145, 53.66810825892857, 51.86280993052891, 49.903838293892996, 48.7471786226545, 43.398768016270225, 42.650745800563264, 49.25046443939209, 52.478819847106934, 53.787523474012104, 40.879629135131836, 50.64150421960013, 51.83561815534319, 49.694551604134695, 48.06091547012329, 46.677063601357595, 51.93877805982317, 51.080859661102295, 51.61927556991577, 50.55777495247977, 51.16377946308681, 52.004382950919016, 52.13543292454311, 47.91961342947823, 43.67795705795288, 40.45743227005005, 43.242384910583496, 42.4363626071385, 42.00566809517996, 39.952454566955566, 41.58095250810896, 40.839023862566265, 40.94007498877389, 40.586022581372944, 41.52203178405762, 37.37893213544573, 38.962593351091655, 41.782999174935476, 45.98628411974226, 45.64581891468593, 42.74400452205113, 40.8397673198155, 38.52483599526541, 40.239463806152344, 40.91375173841204, 41.21950026920864, 42.07958650588989, 40.911972999572754, 43.96076263700213, 41.63414791652134, 44.15335627964565, 52.93276650565011, 53.58569914954049, 53.05315099443708, 56.12065213067191, 55.98009007317679, 53.4415031841823, 55.39292212894985, 56.27181019101824, 56.01945856639317, 52.40510293415615, 56.6168646812439, 56.778101103646414, 54.97823626654488, 58.24787787028721, 55.827285289764404, 61.728095054626465, 58.73895917619978, 59.62207521711077, 57.8314653805324, 60.471777370997835, 58.91590200151716, 59.761692319597515, 11.723137021064758, 2.451619109937123, 1.0532647222280502, 0.19851827115884849, 0.14269112396453107, 23.01399186679295, 74.14307376316616, 57.67045477458409, 49.14423343113491, 24.108961956841604, 30.92692177636283, 47.33733006886074, 61.22211333683559, 65.69912256513322, 57.027767249516074, 3.4716025037424902, 0.23470602290970938, 0.14533833334488527, 0.1563493689256055, 0.11705338396131992, 0.12643353348331793, 0.08891317288258246, 0.18077501468360424, 0.142372673909579, 0.15586215364081518], [0.0028122600550497217, 0.07230911563549723, 0.06279306233461414, 0.02057970079061176, 0.057427064914788516, 0.035978925813521655, 0.036220307861055644, 0.06321120275450604, 0.02910789701023272, 0.1118408100945609, 33.492394719805034, 54.072569847106934, 43.40513604027884, 27.953975200653076, 18.306983368737356, 24.610206740243093, 26.75979699407305, 47.16176298686436, 54.7458051272801, 57.36133984157017, 9.25562846660614, 0.17235819489828177, 0.383170842060021, 1.6816811902182442, 0.8046810839857373, 42.41976683480399, 67.33387388501848, 55.17885160446167, 59.48250675201416, 47.15647888183594, 45.06552621296474, 42.07387161254883, 42.9198043687003, 40.83719996043614, 40.938667978559224, 39.32593897410801, 44.3370110648019, 46.39457763944353, 47.99708236966814, 47.07450403485979, 47.909076486315044, 48.538451262882774, 51.94470834732056, 52.79675899233137, 51.16388716016497, 46.3157433782305, 40.59448896135603, 35.25990179606846, 36.35931873321533, 36.264246531895225, 37.483881201062886, 36.25199338368007, 36.7092786516462, 36.16587741034371, 35.24321222305298, 36.10406970977783, 37.23552131652832, 34.81227452414376, 37.932095595768516, 34.784419195992605, 35.847674233572825, 35.99420826775687, 36.3521203994751, 36.598663330078125, 37.539703028542654, 39.62368665422712, 38.42472287586757, 38.36456189836775, 38.22304098946707, 38.97515222004482, 39.58288335800171, 37.525160448891775, 37.96559286117554, 37.443970748356406, 37.80318914140974, 36.99165691648211, 39.33395024708339, 37.29849978855678, 38.95507540021624, 41.48758608954293, 41.74242169516427, 38.39800010408674, 38.74750491550991, 37.788479804992676, 43.755214078085764, 46.17915569032942, 47.098756722041536, 49.72476584570748, 35.57087884630476, 44.88917051042829, 47.31277513504028, 45.905553000313894, 46.28889553887503, 43.62236104692732, 44.667245047433035, 45.416389397212434, 45.949691431862966, 43.15961102076939, 45.82053484235491, 45.48158434459141, 46.978104727608816, 41.252434730529785, 37.01067066192627, 36.53394086020333, 38.486266544886995, 37.18368428094046, 37.889555249895366, 37.756750856127056, 36.641863754817415, 35.35000603539603, 37.69977910178048, 36.443485736846924, 37.51400511605399, 36.29470048631941, 36.98418412889753, 37.46243906021118, 39.1885279246739, 39.46116828918457, 38.02006326402937, 36.3168374470302, 36.43679462160383, 37.66881445475987, 37.45081124986921, 38.22218983513968, 38.271476881844656, 37.33869859150478, 37.75297451019287, 39.200596945626394, 45.246585845947266, 50.66846670423235, 50.69438695907593, 50.324228627341135, 50.89374467304775, 47.50427096230643, 50.83787073407854, 49.40115349633353, 51.35295111792428, 52.653865814208984, 51.578392369406565, 52.546752384730745, 53.10193082264492, 52.69304323196411, 54.336101123264854, 54.37575101852417, 59.241404260907856, 55.82303646632603, 57.23523351124355, 53.614516803196494, 55.82066018240792, 57.05635561261858, 58.30539158412388, 12.194170168467931, 0.40739595357860836, 0.2615111959832055, 1.1579483449459076, 0.10932875131922108, 10.226338710103716, 58.46919536590576, 51.18355403627668, 40.69884743009295, 28.776867730276926, 15.482577119554792, 22.291413954326085, 41.98026895523071, 49.11982093538557, 49.29013517924717, 7.262182908398764, 0.19220785477331706, 0.07144025832946811, 0.1047133696930749, 0.10163835755416326, 0.04214764033843364, 0.056658467943114896, 0.04179888012419854, 0.024822990775906613, 0.0480068139731884, 0.020720814022102525, 0.061198980015303404, 0.08328772402767624, 0.014990814795185412, 0.03727475467271038, 0.03852628537320665, 0.02205351447420461, 0.09418642135070902, 0.01613461279443332, 0.4971228731530053, 43.208682673318044, 60.85985510689871, 50.704656396593364, 36.29684053148542, 24.717200313295635, 29.856791496276855, 31.2703503881182, 52.362076214381624, 58.782948221479145, 62.10224860055106, 9.766704082489014, 0.1398080015288932, 0.26477478657449993, 2.950240514108113, 2.0832132441656928, 45.54127631868635, 66.00683048793248, 57.86596666063581, 60.43675150190081, 50.112360681806294, 46.59765263966152, 44.46124485560826, 42.39361728940691, 42.7204327583313, 42.62395702089582, 41.22584397452218, 46.717985016959055, 49.027590547289165, 50.851180008479524, 49.727687563214985, 50.55605179922921, 48.92583417892456, 55.06512001582554, 54.75730439594814, 52.36506741387503, 48.84297343662807, 42.31948001044137, 37.30588919775826, 36.8623092515128, 37.97608811514718, 38.56131403786795, 38.624355043683735, 38.66023901530674, 37.68579585211617, 37.18597718647548, 37.73510026931763, 39.1464079448155, 36.873652185712544, 40.438050270080566, 37.99432713644845, 38.60528571265084, 37.892400537218364, 38.47621250152588, 38.583492687770296, 39.157122067042756, 40.120003427777974, 39.36670405524117, 40.97860622406006, 40.7556802204677, 40.11087349482945, 40.38696711403983, 38.92402390071324, 38.205618381500244, 39.67418616158621, 39.34245484215872, 39.95716197150094, 40.456424781254356, 38.80756514413016, 41.08668545314244, 42.74916703360421, 43.9287349155971, 39.964801515851704, 38.71308353969029, 40.71543278012957, 45.065613065447124, 47.70887109211513, 49.36360195704869, 53.18557671138218, 37.415851388658794, 46.33847093582153, 49.82798480987549, 46.59737123761858, 48.25778920309884, 45.56393092019217, 47.932043756757466, 47.27627624784197, 49.02463756288801, 47.38830205372402, 47.799006598336355, 47.17281757082258, 48.73759010859898, 42.19069514955793, 38.986620221819194, 38.307406016758506, 40.35150350843157, 38.95134769167219, 39.68129069464547, 39.65312964575631, 38.051205090114046, 37.30788680485317, 40.65940598079136, 37.2541355405535, 40.41038949148995, 37.22721127101353, 38.657650811331614, 38.5252355166844, 41.183428696223665, 41.556005001068115, 40.52785573686872, 37.63286100115095, 38.67069605418614, 39.750147342681885, 39.47962270464216, 39.305153438023154, 39.5580609185355, 38.88159472601754, 41.062279905591694, 38.98305927004133, 45.57370703560965, 51.99664960588728, 51.25538451331002, 51.034185137067524, 49.87038271767752, 48.25615290233067, 52.41670642580305, 52.85873692376273, 55.04251752580915, 54.22000714710781, 54.23370552062988, 54.71863419669015, 54.97222260066441, 54.439090796879356, 54.89611203329903, 55.75608709880284, 59.2700377873012, 58.32117789132254, 59.335746901375906, 56.37976435252598, 57.1997629574367, 59.66804449898856, 58.71057578495571, 14.804476363318306, 0.9721743592194149, 3.529733521597726, 1.9919675460883548, 0.18849484329777105, 11.292750835418701, 63.991762569972444, 56.21114894321987, 43.774978228977744, 29.35475982938494, 23.27592158317566, 29.38209056854248, 48.23700714111328, 56.400699274880544, 57.60836567197527, 10.044703245162964, 0.1491084231862, 0.05865679428513561, 0.0359927102524255, 0.06996198158179011, 0.02945189390863691, 0.05155693293948259, 0.015512928832322359, 0.029008678227130855, 0.016124007292091846, 0.06999202032706567, 0.148917252730046, 0.19574352433638914, 0.10463497175702027, 0.19174206762441567, 0.12386313426707472, 0.12515730410814285, 0.22055478154548577, 0.08406841927873236, 1.0695103704929352, 51.93356343678066, 69.87430204663957, 58.9609124319894, 42.95853362764631, 28.394638640539988, 33.441304615565706, 36.884672028677805, 59.81693049839565, 63.03080586024693, 69.0883218220302, 11.984221662793841, 0.4667277070028441, 0.5882796017186982, 10.892548492976598, 4.081621987479074, 50.308011531829834, 70.15867791857038, 59.503997530256, 63.291891370500835, 52.30908577782767, 49.476134981427876, 46.341698374067036, 45.79136283057076, 46.25079509190151, 44.61018991470337, 44.165185587746755, 49.782626969473704, 50.66530874797276, 52.013721329825266, 51.16077436719622, 51.691988468170166, 51.908115659441265, 57.59900297437395, 57.73175525665283, 54.387896469661165, 50.12750080653599, 44.90212542670113, 40.19767386572701, 38.59045130865914, 39.97388628550938, 41.8672182900565, 40.164954798562185, 41.471633025578086, 39.929136412484304, 40.16477067129952, 40.0288256917681, 41.92576381138393, 38.99502059391567, 43.63972112110683, 38.55371618270874, 40.2296598979405, 39.57575103214809, 39.841919149671284, 39.77313198362078, 40.49910756519863, 42.402913979121614, 41.07526956285749, 44.1469361441476, 41.738853795187815, 42.180185999189106, 43.13105739865984, 39.829527037484304, 40.23740713936942, 42.390094552721294, 42.14871065957205, 41.20984922136579, 42.68854052679879, 40.634326457977295, 44.60103218896048, 44.15996054240635, 46.139894894191194, 42.77099479947771, 41.908813680921284, 43.03723587308611, 47.06414427076067, 49.63156270980835, 50.72803708485195, 55.566488129752024, 39.38116325650896, 49.86021750313895, 51.639678955078125, 48.64266381944929, 49.36491864068167, 48.75931017739432, 49.89393711090088, 50.89306722368513, 50.554710796901155, 48.772212982177734, 49.39824220112392, 49.21519538334438, 50.57751131057739, 45.023503507886616, 42.482724462236675, 39.05765513011387, 41.569613048008506, 40.84474570410592, 42.46037210736956, 41.25752081189837, 40.4866737638201, 38.59158386502947, 42.27378518240792, 40.68677493504116, 41.10294076374599, 39.76620462962559, 40.596528257642476, 42.26294599260603, 43.6967693056379, 44.11364732469831, 43.582047598702566, 39.34770768029349, 41.08571965353829, 41.93925721304757, 41.16382435389927, 41.34391123907906, 42.37389482770647, 40.425606046404155, 42.29381683894566, 41.877661432538716, 48.42210367747715, 53.63167537961687, 54.57864883967808, 53.998411723545615, 51.396870681217735, 50.04736375808716, 53.044816630227224, 54.926110880715505, 54.66749198096139, 55.163746220724924, 56.69460112707955, 55.75901576450893, 57.724741050175254, 56.1446407863072, 57.478816509246826, 57.680956976754324, 61.75438008989607, 60.77665737697056, 62.42735481262207, 58.37617288316999, 59.21725927080427, 61.63283525194441, 62.616783550807405, 14.261545862470355, 1.7924381898982185, 2.7391134202480316, 2.1698848562581197, 0.21077847613820008, 12.760140895843506, 69.7397015435355, 60.59143924713135, 55.618627411978586, 40.074367659432546, 23.446114233561925, 35.0838622365679, 57.10818917410714, 64.1166078022548, 69.57626601627895, 13.10883971623012, 0.4056112164897578, 0.2825470029243401, 0.1942906722958599, 0.133974608832172, 0.17120862086968763, 0.10763322801462241, 0.12244966439902782, 0.10130601788737945, 0.13623270552073205], [0.015524721770946468, 0.0399587033316493, 0.04281485400029591, 0.04100869895358171, 0.021652975252696445, 0.037793806820575676, 0.01822175088870738, 0.09616583013640982, 0.02764317230321467, 1.059671829853739, 43.5879396711077, 48.55069746289934, 49.97054100036621, 42.831065450395855, 16.299938883100236, 29.150302137647355, 42.48995753696987, 45.63890545708792, 56.71722098759243, 49.839609146118164, 6.90094302381788, 0.29128441693527357, 0.4672989249229431, 1.571560493537358, 3.523380913904735, 62.411770003182546, 61.362876892089844, 58.97999913351876, 54.07732588904244, 44.71954761232649, 41.803364345005576, 41.967261927468435, 41.92402328763689, 45.19814647947039, 49.27772569656372, 50.509290422712056, 51.890098980494905, 52.35639953613281, 51.16964374269758, 51.1366536957877, 49.25549840927124, 48.81067473547799, 49.80085556847708, 46.36842809404646, 48.54640695026943, 50.23303699493408, 44.17573990140642, 37.52384723935808, 34.406954833439414, 35.63126911435808, 35.74179063524519, 34.968296323503765, 36.06171349116734, 35.61297450746809, 35.908061027526855, 35.64329992021833, 35.431435448782786, 34.82814073562622, 35.094659737178254, 35.09164421898978, 36.38812943867275, 35.662244183676584, 36.40925543648856, 39.06646544592721, 35.94838489804949, 38.42049837112427, 37.97422252382551, 38.89460175377982, 38.465884004320415, 37.64988061359951, 39.55946445465088, 37.25340597970145, 35.28925446101597, 37.215579986572266, 36.719822543007986, 37.67379631314959, 38.75164951596941, 38.37349380765642, 36.51881810597011, 39.07040507452828, 34.535534722464426, 37.099169867379324, 37.73813315800258, 43.312391485486714, 47.013561385018484, 49.09590523583548, 49.000166007450645, 47.383163860866, 30.757719244275773, 44.41718632834298, 47.2129225730896, 47.67071853365217, 47.86034182139805, 45.49445588248116, 46.35927036830357, 45.76732553754534, 43.087850025721956, 42.600117751530235, 45.8105502809797, 44.50938197544643, 45.03966154370989, 39.16593585695539, 36.973021847861155, 35.84599276951381, 36.86178118841988, 36.39891651698521, 38.994311877659385, 38.610649721963064, 37.652989932468955, 36.993626730782644, 36.97592619487217, 38.88225827898298, 37.69076381410871, 36.07680150440761, 36.78078951154436, 36.163608823503765, 35.72466679981777, 36.39274999073574, 36.89095320020403, 38.08769702911377, 36.801502091544016, 36.14105844497681, 37.12995386123657, 36.886898926326204, 38.689584732055664, 37.61636945179531, 37.951699938092915, 39.54473427363804, 46.46653665815081, 50.26374108450753, 49.25538723809378, 49.198262623378206, 49.734451634543284, 51.20886284964425, 50.74197169712612, 50.748245920453755, 50.6382211957659, 52.15887267248971, 53.276031834738596, 52.4489495413644, 52.81913219179426, 52.96684047154018, 52.83044038500105, 57.50765153339931, 57.3121257509504, 51.620015553065706, 56.920091015951975, 58.22564710889544, 60.88431971413748, 56.84046813419887, 59.52701691218785, 11.895885740007673, 0.27699069678783417, 2.184070472206388, 0.8368826189211437, 0.12491510781858649, 4.025807108197894, 53.51362201145717, 53.3299046925136, 41.548150062561035, 30.996789387294225, 11.00998260293688, 18.87157835279192, 41.747660636901855, 45.01457159859793, 49.021931239536826, 12.774232711110797, 0.33346899332744734, 0.04436919452356441, 0.022240220169935907, 0.0229178154175835, 0.02530304412357509, 0.0479785495969866, 0.062437482843441625, 0.11611841698842389, 0.056758029386401176, 0.04939511019204344, 0.10577058153493063, 0.027378141613943235, 0.042618679348379374, 0.012399385234207978, 0.05040884490257927, 0.0690932667681149, 0.07725357317498752, 0.10218839161098003, 1.7884694657155444, 53.07134485244751, 55.80913312094552, 56.14898688452584, 49.64938136509487, 21.668339456830704, 28.612282276153564, 45.92086335590908, 51.12417820521763, 61.24443095070975, 55.457411834171836, 7.324212517057147, 0.5315181389451027, 0.31315370915191515, 2.679701545408794, 6.298689237662724, 65.21873106275285, 62.20258058820452, 59.48894773210798, 55.37586430140904, 47.15647888183594, 43.752452169145855, 43.47789062772478, 43.62421274185181, 47.41468436377389, 49.74106284550258, 51.69535139628819, 52.98238706588745, 53.82547453471592, 54.056654998234336, 52.688245500837056, 51.785386153629844, 50.87498453685215, 50.57632316861834, 49.15529843739101, 48.43365158353533, 52.51608651024954, 46.76861654009138, 38.44247899736677, 37.711910656520296, 39.03403125490461, 36.95637396403721, 36.600462913513184, 37.689676421029226, 37.9378000668117, 37.76437997817993, 37.21651799338204, 38.32726396833147, 38.75624227523804, 38.15136684690203, 37.46184498923165, 38.9586433001927, 37.474994455065044, 39.0937614440918, 40.83875635692051, 37.94097539356777, 40.04240942001343, 39.82155050550188, 40.41274493081229, 39.680130345480784, 39.00489051001412, 40.745949268341064, 38.31463214329311, 39.783658504486084, 38.42610556738717, 39.01798439025879, 39.599677153996055, 40.61537177222115, 38.68948745727539, 38.70757361820766, 40.28920943396432, 36.75672442572457, 38.512961523873464, 39.24931424004691, 45.176860673086985, 49.51967239379883, 50.58543225697109, 51.230589866638184, 49.71771689823696, 32.491767270224436, 47.472024372645784, 50.33989334106445, 48.772994654519216, 49.60797010149275, 47.871663911002024, 47.4847708429609, 46.887524536677766, 45.637682574135916, 45.72410774230957, 49.64721352713448, 46.884224142347065, 48.48584645135062, 41.456308773585725, 37.72339950289045, 37.26683684757778, 40.0322059903826, 38.48635687146868, 40.485673223223, 40.50393656321934, 40.56042889186314, 38.54087938581194, 38.89734976632254, 40.269254207611084, 39.82852302278791, 38.5083965573992, 38.14886202130999, 38.068363666534424, 38.647318840026855, 39.71076842716762, 39.28742510931832, 39.83464091164725, 38.132738726479666, 38.51217290333339, 38.45797348022461, 38.83005993706839, 40.13401794433594, 39.27595363344465, 40.01730210440499, 41.25292457853045, 46.30750976290022, 53.91411965233939, 50.338024275643484, 50.91850805282593, 52.43881211962019, 52.352647508893696, 52.688836097717285, 51.43820551463536, 52.117034094674246, 54.685466970716206, 54.707228728703086, 55.6259195463998, 54.4514342716762, 55.710301944187705, 55.41689688818795, 59.08735574994768, 56.2282623563494, 53.57605504989624, 57.03382955278669, 61.854767663138254, 60.45987510681152, 59.73082842145647, 57.554440702710835, 14.358950052942548, 1.1490988369498933, 4.438919203622, 2.1548250700746263, 0.15464563534728118, 4.999439937727792, 56.92204693385533, 58.0303749356951, 48.08257300513131, 34.52778400693621, 16.044797556740896, 24.14170186860221, 48.73973362786429, 51.028105463300435, 57.11822237287249, 18.099680389676774, 0.3471999636718205, 0.0665855777582952, 0.024532920448109508, 0.016281184840149114, 0.023760345564889054, 0.08075165189802647, 0.092247792519629, 0.006479802050827337, 0.026401580444404056, 0.14296613420758927, 0.1412807482161692, 0.1739168441189187, 0.14260231730129036, 0.15414653212896415, 0.13993980017091545, 0.1665971747466496, 0.1389134752431086, 0.16384270255054745, 3.3695597393172125, 62.83384527478899, 64.43300792149135, 65.39174815586635, 58.5007540839059, 24.72873953410557, 38.936686992645264, 56.75792006083897, 56.4697504724775, 66.72095244271415, 58.756336620875764, 9.441271305084229, 0.8404081240296364, 1.6253220715693064, 6.379162405218397, 6.952417016029358, 70.84202630179269, 64.3068494796753, 63.9629761832101, 58.2445045198713, 50.59029599598476, 45.4929689679827, 45.651384421757285, 45.026751790727886, 49.216949803488596, 53.27186638968331, 55.11802012579781, 55.412957259586875, 58.25810561861311, 56.449166434151785, 56.48088843481881, 55.41404465266636, 52.04625626972744, 53.75299440111433, 51.545086179460796, 50.21247380120413, 54.886895247868125, 48.326791763305664, 40.73407827104841, 39.085406235286165, 40.68862315586635, 38.748213631766184, 37.86077928543091, 40.81319740840367, 40.050347736903596, 40.48058019365583, 38.94967317581177, 41.6697678565979, 39.79529673712594, 39.70373337609427, 40.03812238148281, 41.300662176949636, 38.99479825156075, 39.763807501111714, 42.989150864737375, 40.288643155779155, 42.50223500388009, 42.43910019738333, 42.28358561652047, 42.39818920407976, 41.052649702344624, 42.05741827828543, 38.764719077519004, 41.03473377227783, 40.097578116825645, 41.7076598576137, 40.538323198046, 42.766975266592844, 42.588097367967876, 41.70054490225655, 42.799878461020334, 38.06133208956037, 41.76926606042044, 42.04210097449166, 46.67341579709734, 52.192512375967844, 53.66238989148821, 53.83868653433663, 49.31868185315813, 36.154656069619314, 49.02209799630301, 50.887779644557405, 51.270559379032676, 51.75250727789742, 50.22177743911743, 50.51887198856899, 49.17987074170794, 49.763172013419016, 46.934904302869526, 51.32140629632132, 49.62113346372332, 50.57800810677664, 43.15377800805228, 39.57452814919608, 40.275069849831716, 41.22243935721261, 39.71630614144461, 43.60279491969517, 42.528749329703196, 42.654803548540386, 41.55230508531843, 40.500973156520296, 43.652818475450786, 42.165219579424175, 40.280367851257324, 40.13498026984078, 39.46595559801374, 39.680679253169465, 40.16299193246024, 42.35364777701241, 42.77588980538504, 41.52666623251778, 39.12116513933454, 40.16036898749215, 40.56693587984358, 42.44875124522618, 40.68802908488682, 41.8582307951791, 44.581768308367046, 51.58516338893345, 54.821029799325125, 53.0079460144043, 53.7085919380188, 53.468069621494834, 55.60103804724557, 53.98954929624285, 55.659107616969514, 53.17389678955078, 56.00679547446114, 56.81112241744995, 57.046676771981375, 58.435795375279014, 56.30645738329206, 56.151804379054475, 59.86596393585205, 58.107934202466694, 54.54748616899763, 59.98353440420968, 64.14286504473004, 64.39091573442731, 61.99332169124058, 61.80320508139474, 15.459255490984235, 1.9835741221904755, 5.743257624762399, 1.143310770392418, 0.18684581321265015, 6.274513849190303, 63.6123422895159, 62.797798020499094, 57.38582876750401, 40.141039099012104, 19.078094448362076, 29.976505483899796, 58.00818238939558, 61.33450739724295, 66.62651947566441, 24.163183961595806, 0.4516012615391186, 0.15237687208822795, 0.15660898999444076, 0.07604753824749164, 0.0979811827253018, 0.2171423068003995, 0.21344571587230476, 0.22726889912571224, 0.14785425976983138], [0.06277293020061084, 0.020938119950837324, 0.030114038913909878, 0.037476262609873495, 0.050747338881982226, 0.0945851963811687, 0.08118457759597472, 0.12216349904026304, 0.22706905699201993, 5.227436823504312, 51.39528996603829, 46.80912453787667, 48.19371291569301, 28.07991303716387, 19.39027874810355, 37.15801068714687, 34.138420854296, 48.60103021349226, 59.594150406973704, 48.21901478086199, 4.21043073279517, 0.18371380413217203, 0.30066768771835733, 2.4294239580631256, 10.040980747767858, 66.16899449484688, 52.6108842577253, 57.20470312663487, 47.26393624714443, 44.3251748085022, 43.402860505240305, 44.990760122026714, 47.73661872318813, 51.85406214850289, 50.640420300619944, 54.195789200919016, 51.67663294928414, 52.08719852992466, 50.252050740378245, 49.8684789112636, 50.56690488542829, 49.55292994635445, 47.59199891771589, 46.42121703284127, 45.133246830531526, 47.281185150146484, 46.31334972381592, 38.40037291390555, 36.138716902051655, 36.93879849570138, 36.340798309871126, 37.1817353112357, 34.52426821844918, 35.755172865731375, 36.689309528895784, 33.92001117978777, 34.79058224814278, 36.79051698957171, 35.32969297681536, 35.208325317927766, 34.49882738930838, 35.91842426572527, 36.34214973449707, 37.128876890454976, 36.26707444872175, 39.179939951215474, 38.04776920591082, 38.19792325156075, 37.42379665374756, 38.78669275556292, 38.864700181143625, 38.57386595862252, 37.84809534890311, 36.62841551644461, 36.952844279153005, 38.056718485695974, 38.619731017521445, 39.3228748185294, 36.87384326117379, 37.97900983265468, 36.899482113974436, 37.214680194854736, 37.07599067687988, 45.04109634671892, 48.73480388096401, 48.59429740905762, 44.49553074155535, 43.72020557948521, 31.638215814317974, 38.01029062271118, 48.24281930923462, 47.367075307028635, 47.09097473961966, 46.06999601636614, 46.33835629054478, 43.3781909261431, 42.14012616021292, 43.85060937064034, 46.00497129985264, 44.31321695872715, 42.87705557686942, 36.57133606501988, 36.933069705963135, 36.63458204269409, 37.27447639192854, 38.090153217315674, 38.32933453151158, 36.35124492645264, 36.67182786124093, 38.90250185557774, 38.14391837801252, 37.1038737978254, 36.44002553394863, 36.97024951662336, 38.04276997702462, 35.59415531158447, 36.50925391060965, 36.478181566510884, 36.94879000527518, 36.26933608736311, 35.970195293426514, 37.04695415496826, 39.9561892236982, 35.49957990646362, 36.015876225062776, 35.78838872909546, 39.47106947217669, 38.40682084219796, 44.76385280064174, 50.39338057381766, 50.79538597379412, 53.294885771615164, 50.85124601636614, 49.70166308539254, 48.851002080099924, 48.957702091761995, 50.77634790965489, 50.381450516836985, 51.105143615177695, 51.01486914498465, 52.238123825618196, 51.011718136923655, 54.05838162558419, 44.908337116241455, 28.639526162828716, 50.54664741243635, 50.37416533061436, 54.56194189616612, 53.01973015921456, 55.22238554273333, 50.40222910472325, 13.652731674058096, 1.0867350633655275, 7.065095952578953, 3.078390049082892, 0.22043469441788538, 1.417536409837859, 45.483380453927175, 58.95839023590088, 44.783627373831614, 36.65368958881923, 27.26983298574175, 26.527252946581157, 39.84619229180472, 48.04650490624564, 46.41549866540091, 27.028760024479457, 1.1643389505999429, 0.09195144235023431, 0.030076858587563038, 0.007747454319282302, 0.04598977363535336, 0.010332900049564029, 0.08454063893961054, 0.05055581219494343, 0.025409085576289465, 0.08412298027958189, 0.04548364418691822, 0.033376292791217566, 0.0412863758392632, 0.06044780782290867, 0.11385468845920903, 0.060577421582170894, 0.1768938350890364, 0.13400586215513094, 7.731713942119053, 61.0924460547311, 52.751151016780305, 55.953554902757915, 35.49147135870797, 21.185203416006907, 33.697178976876394, 41.178102902003694, 52.07905871527535, 64.82096753801618, 50.92572028296334, 4.663775069372995, 0.39572208427957123, 0.7028778152806419, 1.8205512527908598, 13.592647995267596, 70.36970860617501, 55.98463766915457, 60.40349047524588, 48.76427813938686, 46.859467710767476, 45.94761739458357, 45.541057450430735, 49.41769715717861, 53.18376670564924, 53.041988713400706, 55.00837060383388, 53.68999855858939, 53.57160472869873, 51.7272436278207, 52.70747116633824, 49.99691983631679, 49.39372934613909, 48.43073681422642, 48.25968606131417, 48.05548545292446, 49.6867800440107, 47.36942727225167, 40.06165593011038, 38.009769507816856, 38.090344292776926, 36.75188500540597, 39.01872089930943, 36.67610795157296, 37.57911321095058, 38.32349457059588, 36.927743911743164, 37.89463785716465, 37.90197515487671, 36.90394980566842, 37.0556845664978, 37.1910354750497, 37.19123697280884, 37.79190526689802, 37.702728612082346, 37.454003947121755, 40.689113003867014, 40.06337560926165, 39.71342958722796, 39.55340562547956, 39.92956025259835, 40.63374628339495, 39.08003527777535, 38.385191099984304, 38.360118525368826, 38.52381461007254, 39.860408306121826, 39.831733090536936, 40.032581193106516, 38.02982548304966, 39.35975933074951, 38.4141720363072, 40.0381293296814, 39.012825352805, 47.12326996667044, 49.93369470323835, 51.43612800325666, 46.52182000023978, 44.42064305714199, 33.94398941312517, 40.11566775185721, 49.19268321990967, 48.24297911780221, 48.031135490962434, 48.644803864615305, 47.438950947352815, 45.907772949763704, 45.29708187920706, 44.64098085675921, 47.333168097904746, 46.05142000743321, 45.284564699445454, 39.50978830882481, 39.351185253688264, 38.34897708892822, 39.28949567249843, 38.8760917527335, 40.82695484161377, 38.39263609477452, 39.45682913916451, 39.5758934702192, 39.75802659988403, 39.15680939810616, 38.33997917175293, 38.10976798193795, 39.618270533425466, 37.93750129427229, 38.54116426195417, 38.52501664842878, 39.496767384665354, 38.447481700352256, 37.94211837223598, 39.57888466971261, 40.64087166104998, 37.76577656609671, 38.75723934173584, 37.500053133283345, 40.83344098499843, 40.54752261298043, 47.83219814300537, 51.26750564575195, 51.66942419324602, 54.80664702824184, 51.98678663798741, 51.634533814021516, 51.65600027356829, 51.53972217014858, 52.32675157274519, 52.116818700517925, 51.5387806892395, 54.49659408841814, 53.93030200685774, 52.76486676079886, 55.989331177302766, 47.016298975263325, 30.102622236524308, 51.57010316848755, 51.95353603363037, 54.95512655803135, 52.59715461730957, 56.39489752905709, 52.87706627164568, 14.696664639881678, 1.9997972973755427, 5.016999338354383, 2.1041522920131683, 0.13754626789263316, 1.5136035063437052, 49.82858235495431, 62.61731161390032, 50.92549794060843, 31.436509609222412, 24.503072466169083, 33.29018129621233, 47.62349510192871, 55.179035731724326, 54.46684537615095, 36.843406677246094, 1.4013898819684982, 0.0383682206406125, 0.04234501599733319, 0.04729345314470785, 0.03968443947711161, 0.040578429720231464, 0.11060726057205882, 0.027609868108161857, 0.03652957394453032, 0.13695533174489224, 0.09697840296264205, 0.14394812365727766, 0.15257862769067287, 0.1389847078493663, 0.22096142758216175, 0.2329577910048621, 0.20417683252266475, 0.2604277655482292, 9.709468296595983, 71.39221245901925, 62.10154683249337, 66.60871124267578, 39.6972576550075, 25.940842356000626, 46.37317023958479, 45.84446791240147, 58.87365000588553, 70.44552734919957, 55.52654988425118, 6.362792015075684, 0.45345976895519663, 1.780971382345472, 5.972017075334277, 17.246547562735422, 75.18426827022007, 56.30655813217163, 63.150648389543804, 50.2770607812064, 48.38768924985613, 48.88216127668108, 48.28222254344395, 51.86614506585257, 55.97381237574986, 54.04752506528582, 58.772776058741975, 56.420188971928184, 55.570973191942485, 53.32831008093697, 52.027141775403706, 51.93869120734078, 49.77329553876604, 49.999845027923584, 48.33080782209124, 47.41409376689366, 53.2115421295166, 49.1134911264692, 42.478652817862375, 40.179386207035606, 39.64410046168736, 39.32104744229998, 41.68642963681902, 37.183131899152485, 39.72658947535923, 41.428964138031006, 37.58953898293631, 39.31222670418875, 41.65128912244524, 40.50498921530587, 39.48877348218645, 37.993194580078125, 39.10868617466518, 40.77299165725708, 40.33242375510079, 38.76332596370152, 41.859523160117014, 42.28682347706386, 39.65820183072771, 41.769526617867605, 42.54705088479178, 41.608707087380544, 41.96140112195696, 41.519148281642366, 42.06463745662144, 40.99765818459647, 41.0954714502607, 43.14404705592564, 42.88270793642317, 39.923074109213694, 40.81172439030239, 41.96097380774361, 42.60157339913504, 40.6771308353969, 48.977125780923025, 53.216690744672505, 51.863939012799946, 48.7793105670384, 44.29524891717093, 35.97023698261806, 41.96041795185634, 49.92692020961216, 51.30224663870675, 50.35974781853812, 51.53645304271153, 51.90913009643555, 49.5109280858721, 47.33970635277884, 47.18170084272112, 50.28718083245413, 49.068348680223735, 47.76391124725342, 40.78131212506975, 41.512286935533794, 41.12612342834473, 40.39153208051409, 42.52702270235334, 42.30000768389021, 38.61864709854126, 42.0567512512207, 43.6716376713344, 42.46515941619873, 41.37741197858538, 40.5058890070234, 40.14216123308454, 42.467021533421104, 40.6098826953343, 41.04227604184832, 40.37994943346296, 41.445375783102854, 42.10055269513811, 39.068932056427, 42.173974309648784, 44.826219831194194, 39.78732367924282, 40.69077362333025, 39.17117827279227, 43.24192632947649, 41.61548852920532, 49.47869539260864, 52.83230945042202, 54.54065261568342, 56.91636330740792, 54.99078818729946, 54.65897348948887, 53.98140600749424, 52.745595932006836, 54.20612812042236, 54.666126659938264, 55.83138472693307, 57.43023123059954, 55.08177832194737, 54.80825553621565, 57.00875002997262, 47.931880474090576, 34.09761755807059, 52.31395993913923, 54.61688825062343, 57.675891739981516, 56.036408696855815, 57.80399220330374, 51.62102999005999, 17.010220221110753, 2.4340662232467105, 16.661559615816387, 6.025778327669416, 0.39030566492250984, 2.242772328002112, 55.509815147944856, 69.32961886269706, 57.21218981061663, 46.117806570870535, 36.805737018585205, 38.27587856565203, 53.94866262163435, 64.17329120635986, 63.856772967747276, 44.119153772081646, 2.040695914200374, 0.1432213040867022, 0.09851380557354007, 0.10802206929240908, 0.11658280635518686, 0.10818282102367707, 0.1456225716641971, 0.15987184776791505, 0.1032039617587413], [0.03079815149041159, 0.06522516254335642, 0.010386567080526479, 0.03486365173012018, 0.02112911398788648, 0.007981269005020815, 0.0038635567678803845, 0.13803888431617192, 0.09115987018282924, 6.332330243928092, 54.36280999864851, 47.686952999659944, 40.89646462031773, 22.12791415623256, 23.653669084821427, 47.2734865461077, 38.23491546085903, 50.21851525987898, 56.38996778215681, 47.68334341049194, 2.547447579247611, 0.18828238041273185, 0.2492302278322833, 0.8650082754237312, 18.12475643839155, 64.8851272038051, 54.99425186429705, 54.92938348225185, 44.035049302237375, 44.63266038894653, 45.68596560614449, 50.05472884859358, 49.52508504050118, 53.775562150137766, 53.31861734390259, 53.596955231257844, 47.98129953656878, 48.56019565037319, 49.29936933517456, 50.163683550698416, 51.05666255950928, 48.66428313936506, 49.26908213751656, 51.90129600252424, 48.09791462762015, 50.29038047790527, 42.01448883329119, 37.931581429072786, 35.72576461519514, 36.67980786732265, 35.78185394832066, 34.77283307484218, 34.23914194107056, 34.8335394859314, 35.96396623338972, 35.09935671942574, 35.73123632158552, 33.017613887786865, 34.707516533987864, 36.775432450430735, 35.0492011478969, 36.14945534297398, 36.65889378956386, 37.78104175840105, 37.23601116452898, 37.26009709494454, 37.25823497772217, 37.090046882629395, 36.466723987034385, 39.35347121102469, 38.613095487867085, 38.27117116110665, 38.82389688491821, 34.9206942149571, 35.78818723133632, 36.576873779296875, 36.22693123136248, 37.52901669910976, 37.520838669368196, 38.672964641026084, 36.03209332057408, 35.70731367383684, 35.99777964183262, 41.439921447208945, 48.11294705527169, 51.503796509334016, 46.967668533325195, 45.81536190850394, 32.036517824445454, 39.20172255379813, 47.11496686935425, 43.838255473545615, 47.2743307522365, 45.881672041756765, 46.655572823115754, 44.427396706172395, 45.273398944309776, 44.23243372780936, 43.86612122399466, 41.64125592367989, 40.38264880861555, 36.66917712347848, 37.887856415339876, 35.935492515563965, 38.8987706729344, 38.567570890699116, 37.597407817840576, 38.828871795109336, 38.704634530203684, 36.907191140311106, 36.23168727329799, 37.67156594140189, 35.98271942138672, 36.88377571105957, 37.02114854540144, 35.28242785590035, 36.471646785736084, 36.60871737343924, 36.113727705819265, 35.118387835366384, 35.299874782562256, 36.64048801149641, 37.57929733821324, 35.83157525743757, 38.91757944652012, 36.23951094491141, 38.146107060568674, 36.84391042164394, 43.85549048015049, 47.62901544570923, 49.90484230858939, 50.32720940453665, 48.61112247194563, 47.41816193716866, 47.027617590767996, 48.34003850391933, 49.26209919793265, 50.871607712336946, 51.412514550345286, 48.22038010188511, 50.189846992492676, 49.4859493119376, 55.510381426130024, 45.463862964085166, 39.79391751970564, 51.88809095110212, 55.746918950762065, 54.72738545281546, 55.43966613497053, 53.99015726361956, 55.30912337984358, 12.27117531640189, 1.051977351307869, 2.8377411450658525, 3.2757571041584015, 0.05526471630270992, 0.2576528287359646, 35.33369166510445, 62.254011154174805, 44.89803988592965, 54.02756983893258, 28.258983748299734, 13.042967319488525, 27.524376767022268, 40.98713166373116, 54.27089575358799, 39.799385751996724, 1.3383030614682605, 0.09199674134807927, 0.11041119787842035, 0.007984523428604007, 0.029466299207082818, 0.05552432380084481, 0.04134217516652175, 0.013980593199708631, 0.01767955221501844, 0.012397180843566145, 0.09375581624252455, 0.027326634020677636, 0.032553012682391066, 0.05675341534827437, 0.026653639240456477, 0.02664219235469188, 0.017844958696514368, 0.1437640506774187, 7.776017393384661, 63.483717237200054, 53.373640128544395, 50.713112354278564, 26.994769436972483, 24.030270133699688, 44.73923533303397, 40.056212016514365, 55.227975368499756, 62.21148817879813, 50.99572685786656, 2.394406122820718, 0.38090719495500835, 0.35955676489642685, 1.960083782672882, 22.597459520612443, 68.55797277178083, 56.02336345400129, 56.97908122198922, 45.53983804157802, 46.463389124189106, 48.72356864384243, 52.49213259560721, 52.09076642990112, 56.28270844050816, 54.27793427876064, 54.084989752088276, 49.90492221287319, 48.37515469959804, 50.06271580287388, 50.65703691755022, 51.6468425478254, 49.89123773574829, 51.083791800907676, 52.92513043539864, 51.269986152648926, 51.09971012387957, 44.590971197400776, 39.10249185562134, 37.94269854681832, 37.173501695905415, 37.736045224326, 37.721196923937114, 36.58255393164498, 36.82067911965506, 38.00239746911185, 37.90781511579241, 37.89107690538679, 36.35174867085048, 36.657789025987896, 37.747197083064485, 36.649875027792795, 37.634983675820486, 37.14616053444998, 39.223202909742085, 38.67743580681937, 39.45966400418963, 38.51447623116629, 39.69476325171334, 39.01670592171805, 41.028219836098806, 40.5430896622794, 38.93515144075666, 40.241051469530376, 37.79519523893084, 39.134689807891846, 38.72620521272932, 39.262595721653526, 38.33450746536255, 39.392982142312185, 40.57896668570382, 38.858544077192036, 38.62743656975882, 37.42767027446202, 44.137993812561035, 50.34222446169172, 51.35929134913853, 48.82044390269688, 49.858904293605256, 33.98819385256086, 41.43941422871181, 49.38531160354614, 46.3533296585083, 48.228794370378765, 47.679598331451416, 47.68481642859322, 47.5195882661002, 46.94335331235613, 45.34126547404698, 44.69582298823765, 44.37110240118844, 42.0934933253697, 37.5066191809518, 38.44404929024832, 38.817056383405415, 39.984937395368306, 39.81147561754499, 40.25574343545096, 40.21308497020176, 41.202782903398784, 38.85616431917463, 39.21940919331142, 40.10794135502407, 38.83948516845703, 38.829413754599436, 39.56389740535191, 37.10230350494385, 38.35893733160836, 38.517627239227295, 38.25715317044939, 38.14153861999512, 37.673744201660156, 38.2617633002145, 38.38967268807547, 38.55100291115897, 39.5004221371242, 40.17098930903843, 39.5007243837629, 37.95825556346348, 45.33903857639858, 49.08141476767403, 51.1531000818525, 50.592227595193044, 50.24480029514858, 49.53980827331543, 48.65937076296125, 51.52458551951817, 49.9248183795384, 53.28143058504377, 53.1512838772365, 51.0954578263419, 52.20943818773542, 50.61003582818167, 56.77270235334124, 47.51853213991438, 42.81709262302944, 53.11535126822335, 57.45705475125994, 57.31010382516043, 56.53495931625366, 55.231293133326936, 55.65369497026716, 13.986881835120064, 1.583870095866067, 4.302623774324145, 3.5152332825320105, 0.025384185037442615, 0.19026716319578035, 38.665481431143625, 66.45448207855225, 52.02633578436715, 48.78083222252982, 29.230682373046875, 20.5835953780583, 31.776415484292166, 49.65471063341413, 60.44197654724121, 49.88343143463135, 2.3094485444681983, 0.09218745040042059, 0.07488136725234133, 0.02777326782234013, 0.009140280607555593, 0.030848817700254064, 0.004359296572926853, 0.013539916087341095, 0.030030823379222835, 0.10278262543891158, 0.22509933768638543, 0.06727492183979068, 0.09320384836090462, 0.28895896886076244, 0.10126985875623566, 0.14542072106684956, 0.2662028856575489, 0.19274211967630045, 12.022889256477356, 75.99966021946499, 60.3774972643171, 59.84750952039446, 32.26015254429409, 33.10238538469587, 55.31435884748186, 51.980766023908345, 59.31133093152727, 66.51764815194267, 57.52057865687779, 3.1260507830551694, 0.5384240512337003, 0.9307702609470913, 2.6596045323780606, 27.53844860621861, 73.00428485870361, 60.14314842224121, 59.69601794651577, 48.47100509916033, 49.38268518447876, 51.077378613608225, 54.96386391775948, 54.03480986186436, 59.062008721487864, 57.86717912128994, 55.84256090436663, 50.81518486567906, 48.523620332990376, 49.65507541384016, 51.04282522201538, 54.24409307752337, 51.96623386655535, 52.22447061538696, 55.50009461811611, 52.69960927963257, 53.44491127559117, 46.232104437691824, 41.4613288470677, 39.3746006829398, 40.54422916684832, 40.46904270989554, 40.06300040653774, 39.51146282468523, 38.479596274239675, 41.95538398197719, 38.73948669433594, 39.224137442452566, 37.25011600766863, 39.74094097954886, 40.8463750566755, 37.44744484765189, 38.84172248840332, 39.449981689453125, 41.78950616291591, 40.82081263405936, 40.097355774470735, 40.30292865208217, 41.1147665977478, 40.545212336948936, 44.609568050929475, 41.827974864414756, 40.98393201828003, 42.679302896772114, 39.309374468667166, 41.020225933619905, 41.21544599533081, 41.6710706438337, 41.93661689758301, 41.7641487121582, 44.13566616603306, 41.579003538404194, 39.99859060559954, 39.47284473691668, 45.458752564021516, 52.802678857530864, 53.379945618765696, 50.48639610835484, 51.5709855897086, 36.8698410987854, 43.36319323948452, 52.20065566471645, 49.022275175367085, 50.072835854121614, 49.29107666015625, 50.655428409576416, 49.20035055705479, 49.877692222595215, 49.41748871122088, 46.9321562903268, 46.69113022940499, 45.07092496326992, 40.139229093279155, 40.9053235735212, 40.48494018827166, 43.16475963592529, 42.680143628801616, 42.24532536097935, 42.70668922151838, 43.7268966947283, 40.86118514197213, 40.982274872916086, 42.83889259610857, 39.74752787181309, 40.37487377439226, 41.340878350394114, 38.96606397628784, 41.42823110307966, 40.257977281297954, 40.37895236696516, 39.606427328927175, 39.71399586541312, 40.479440689086914, 41.441602911267964, 40.07159185409546, 42.887397970472065, 41.21010283061436, 41.972587721688406, 40.609420640128, 47.70149210521153, 49.65969249180385, 54.02244554247175, 53.24510540281023, 53.167622566223145, 52.71431861604963, 51.97803538186209, 52.31042678015572, 52.24694108963013, 56.37755135127476, 53.81852286202567, 51.335938453674316, 52.84576463699341, 52.81358405521938, 59.03173542022705, 49.75712360654558, 44.769459996904644, 56.555668422154014, 59.410683223179404, 58.82536697387695, 59.03682844979422, 57.4474766595023, 56.40113353729248, 15.884594678878784, 3.0020530138696944, 9.858717339379446, 8.666475943156652, 0.10383034457585641, 0.5708361491560936, 42.97034556525094, 72.48089790344238, 57.28921406609671, 68.54702935900006, 38.7823223386492, 25.3308322089059, 41.617093563079834, 57.91315187726702, 67.86646025521415, 59.792382512773784, 4.5073941349983215, 0.23171810752579144, 0.2076681258955172, 0.12302777623491627, 0.19332787181649888, 0.1831200724201543, 0.1367376169988087, 0.16017496293144567, 0.16484175037060464], [0.019495111757091114, 0.07799439092299768, 0.013475596056585866, 0.024718903504045944, 0.05985586065798998, 0.047391470920826705, 0.10544223165405647, 0.028726319449820688, 0.05769090647143977, 6.301004724843161, 46.54629502977644, 48.76412180491856, 45.62105553490775, 28.987611804689678, 23.53063038417271, 29.019226108278545, 39.80863380432129, 50.65325014931815, 58.02690431049892, 39.178129945482524, 1.4604058180536543, 0.09237900762153523, 0.18878817398633274, 1.113156565598079, 25.832697119031632, 68.50907829829625, 51.654530729566304, 53.694490568978445, 47.93871055330549, 55.22427545275007, 49.963512897491455, 52.94400174277169, 52.659629344940186, 54.032447474343435, 50.63963515417916, 47.802213191986084, 47.940395491463796, 50.617182050432476, 51.76020588193621, 51.95317472730364, 50.809164251599995, 50.71928582872663, 48.91164943150112, 49.55544866834368, 47.334470885140554, 44.07901750292097, 39.870267799922395, 37.00344453539167, 34.627518449510845, 37.47723177501133, 33.893413475581575, 35.233175550188335, 35.22310413633074, 35.52803972789219, 36.11638191768101, 35.7581466947283, 36.203758989061626, 37.72676937920706, 35.11135973249163, 35.35610655375889, 35.92077623094831, 37.3960941859654, 36.15972825459072, 37.30881091526577, 36.222658089229036, 39.19966241291591, 36.40647268295288, 39.386301449366975, 36.83436359677996, 38.14901140757969, 37.55010100773403, 38.90662213734218, 39.23618561880929, 38.31173127038138, 36.1219231060573, 35.57406112125942, 34.65977198737008, 36.9015075138637, 34.7169382912772, 36.09744112832205, 35.002186162131174, 37.56119728088379, 35.64159066336495, 38.80756861822945, 41.47843531199864, 49.31905705588204, 46.85834905079433, 50.050226415906636, 37.357882567814414, 43.44385140282767, 48.240738323756624, 46.095117228371755, 46.875997475215364, 46.5592360496521, 46.006107330322266, 42.89403002602713, 42.96512746810913, 42.53874431337629, 41.04162291118077, 38.43909869875227, 36.86011362075806, 36.549011502947124, 37.002596855163574, 37.68352379117693, 38.47326299122402, 36.33230413709368, 38.16542305265154, 37.7348883492606, 36.98733166285923, 37.0327033996582, 36.949585574013845, 36.756644521440776, 37.61980881009783, 34.79431343078613, 36.67506572178432, 35.959442956107004, 36.09055198941912, 36.48788472584316, 36.970423221588135, 35.70110545839582, 36.4193685395377, 36.16981356484549, 36.879096099308555, 36.34262568610055, 38.32749673298427, 39.00901426587786, 39.42487784794399, 36.794348921094624, 39.33144194739205, 45.331951413835796, 44.836732455662315, 45.42555059705462, 44.424454144069124, 43.65570545196533, 44.88374744142805, 44.69349186761038, 48.75232376371111, 51.445431641169954, 50.45551483971732, 51.06085579735892, 51.28308350699288, 52.81480346407209, 53.8818278993879, 53.38096005575997, 57.525883606501985, 56.49732787268502, 55.107705524989534, 54.33427027293614, 57.515138217381065, 56.81210558755057, 61.94096006665911, 20.687208652496338, 1.5354375690221786, 3.1199244260787964, 0.6910440559898103, 0.05087895092687436, 0.02912213946027415, 22.53283953666687, 62.4286402293614, 52.62058046885899, 41.45882054737636, 22.666356120790752, 22.736790009907313, 20.928271191460745, 45.269591331481934, 54.26400661468506, 52.57331187384469, 6.0026920693261285, 0.15453210286796093, 0.08371656494481222, 0.03506648959591985, 0.08140597678720951, 0.03371172657768641, 0.04290982176150594, 0.029674938547291925, 0.02928405148642404, 0.03970973186993173, 0.005261370712625129, 0.07804515891309295, 0.019247398977833133, 0.019957762377868806, 0.02192366662036095, 0.0716029235294887, 0.08197199712906565, 0.06502257234283856, 10.673992906297956, 58.74500410897391, 53.731253487723215, 53.72581999642508, 32.76098912102835, 26.343195165906632, 31.47134092875889, 43.8810007912772, 55.10306760243007, 61.47315175192696, 42.85123954500471, 1.5827734747103281, 0.2298433966934681, 1.6693284873451506, 1.3096943965979984, 27.113696541104996, 70.84472220284599, 53.75834798812866, 56.29778950554984, 49.693564959934776, 56.774602685655864, 51.462916782924104, 55.114354951041086, 52.32662303107125, 55.99804769243513, 51.68537725721087, 47.59476430075509, 46.66601249149868, 52.1826285634722, 53.35158307211739, 54.17846734183175, 52.877583912440706, 52.092062268938335, 51.984750815800254, 51.37164177213396, 49.34441450663975, 45.13561269215175, 39.614247526441304, 38.602350098746165, 37.356107303074424, 39.41404908043997, 36.7986672265189, 37.71981770651681, 36.50827768870762, 38.27819231578282, 37.64710133416312, 36.41621058327811, 38.07841076169695, 38.824379784720286, 38.533097403390066, 37.61316285814558, 37.74143702643258, 39.32052285330636, 37.49966056006295, 38.60989236831665, 37.38030093056815, 40.14623635155814, 38.91655806132725, 40.346337522779194, 38.761609758649556, 39.842836311885286, 41.194740363529746, 38.995350633348735, 40.67937510354178, 39.710195200783865, 38.59255313873291, 38.27791786193848, 36.44174868719918, 39.95272207260132, 36.84854487010411, 38.109611647469656, 37.77766145978655, 39.305077007838655, 37.15022523062569, 39.909354891095845, 44.41229827063424, 50.968361377716064, 49.25555746895926, 51.75097867420742, 39.11619022914341, 44.762567383902415, 50.09535149165562, 48.285210268838064, 48.97404425484793, 49.18059682846069, 46.6266439982823, 44.24239049639021, 44.98112644468035, 42.67864976610456, 43.10009969983782, 40.68763998576573, 38.489045824323384, 38.03042302812849, 39.09567567280361, 39.495506286621094, 41.047733851841514, 38.613679136548726, 40.179104804992676, 39.54562364305769, 39.81481770106724, 39.30810294832502, 39.50843688419887, 38.20273487908499, 38.962909494127544, 37.765283243996755, 38.864064420972554, 37.1225505556379, 38.39161123548235, 37.4395204271589, 38.58216905593872, 37.9291912487575, 38.377756527491975, 38.61405781337193, 39.70840603964669, 38.43494020189558, 39.93993043899536, 39.95013386862618, 41.89918000357491, 38.8825501033238, 41.715803146362305, 46.94256469181606, 48.62912178039551, 47.073229040418354, 46.732715197971885, 45.531496729169575, 47.5895288331168, 48.74260670798165, 49.36070803233555, 53.76663718904768, 52.54054764338902, 51.31234584535871, 52.76965406962803, 54.38570083890642, 55.9179801259722, 53.312165941510884, 58.879965918404714, 58.003540992736816, 57.68577207837786, 56.04301643371582, 59.46452481406075, 57.42958852222988, 64.5002247946603, 22.08946803637913, 0.688645353274686, 3.1831152524266924, 2.024361784969057, 0.16261331923305988, 0.08905963466635772, 24.280228103910172, 67.40598228999546, 56.47914791107178, 46.383585589272634, 25.640662806374685, 25.8739173071725, 28.187255757195608, 54.6414292880467, 61.316803387233186, 60.70095675332205, 9.777483344078064, 0.1855780248131071, 0.08334927393921784, 0.04410211296219911, 0.10741033604634659, 0.037401264134262285, 0.04803032860425966, 0.03539646117548857, 0.02020187213617776, 0.17785860331995146, 0.1235939051423754, 0.21568916977516242, 0.15665150699870928, 0.15688055327960423, 0.2881664128175804, 0.12020812396492277, 0.17006758281162807, 0.16675487985568388, 16.619387524468557, 70.20837143489292, 62.43681131090437, 62.1132823399135, 40.243615354810444, 33.51660919189453, 38.33429901940482, 52.87874773570469, 59.11809458051409, 65.82584381103516, 46.514357634953086, 1.9855550101825168, 0.3064229131809303, 2.024252785103662, 2.1613980659416745, 30.892649786812918, 73.08263969421387, 56.21322298049927, 58.46597834995815, 52.21358626229422, 58.67281927381243, 53.825571809496196, 58.35184723990304, 55.44789627620152, 56.487190450940815, 53.1778016771589, 50.44905301502773, 48.39966447012765, 53.01467187064034, 56.37293774741036, 55.80173676354544, 56.304425035204204, 54.65060785838536, 53.05368947982788, 53.782565934317454, 51.73158277784075, 47.88827010563442, 42.55339806420462, 42.00888511112758, 37.71778188432966, 42.25614718028477, 38.80294459206717, 40.4689211164202, 38.86200080599104, 41.64475781576974, 40.14515938077654, 38.82583195822579, 39.46408305849348, 41.62133196422032, 40.74791213444301, 39.19873135430472, 39.07366725376674, 41.76179674693516, 40.07037591934204, 40.63096700395857, 39.393798555646626, 42.42869874409267, 40.42786421094622, 41.80904797145298, 39.89718164716448, 41.53530284336635, 42.678615025111604, 41.416391372680664, 43.37983417510986, 43.17801332473755, 40.83955887385777, 40.01401560647147, 37.626169885907856, 41.07435587474278, 38.96006073270525, 39.051860332489014, 39.62189054489136, 43.12488392421177, 39.38208736692156, 41.88148641586304, 45.761231967381065, 52.133056640625, 52.48163039343697, 53.78223589488438, 41.30378539221627, 48.42364270346505, 52.164684840611045, 51.40204014096941, 50.46711138316563, 51.71747446060181, 48.83046667916434, 46.045253481183735, 47.2194573538644, 46.48166288648333, 45.49144383839199, 43.16261959075928, 40.322876930236816, 40.04546662739345, 40.50835561752319, 41.54004498890468, 43.310668332236155, 40.70237711497715, 44.304736682346885, 40.97112648827689, 41.200708866119385, 41.505008697509766, 41.770693915230886, 40.141758237566265, 41.12065519605364, 39.502958229609895, 39.970631054469514, 38.93965039934431, 40.16387087958199, 40.65971517562866, 40.302852221897666, 39.76149375098092, 40.693452153887065, 41.67893600463867, 41.845004899161204, 40.136442865644185, 42.56687756947109, 43.31277016230992, 42.02665165492466, 40.72690078190395, 43.49656391143799, 48.70664978027344, 48.901150703430176, 50.13465050288609, 50.240686961582725, 48.047422068459646, 51.029717445373535, 50.51377895900181, 52.94713538033621, 56.08227375575474, 55.1593792779105, 53.686712060655864, 54.16680131639753, 56.478699752262656, 57.57877329417637, 55.83496652330671, 62.11949402945382, 61.631376130240305, 61.313211168561665, 58.88869980403355, 60.874272618974956, 61.19514042990548, 65.73831735338483, 25.013671261923655, 5.700414163725717, 9.141973308154515, 2.7208776559148515, 0.20794035414499895, 0.13703501889748232, 26.743760551725114, 73.9217597416469, 61.50416851043701, 54.04352290289742, 31.36103480202811, 34.505400385175435, 34.789606026240754, 63.403840746198384, 69.5108209337507, 69.75517518179757, 14.787774630955287, 0.36355776020458763, 0.14025940373539925, 0.16898929567209311, 0.1757480472858463, 0.09723393925066505, 0.09387353528290987, 0.11683371503438268, 0.1042342357603567], [0.02914331653820617, 0.07451809317405735, 0.018428568362391422, 0.0379552472648876, 0.014443588177008288, 0.08751452900469303, 0.03931968619248696, 0.09768206413303103, 0.03529407363384962, 12.919050540242877, 58.94343771253313, 42.31334475108555, 47.00800282614571, 27.782234839030675, 20.07701437813895, 36.78017112186977, 39.399214676448274, 51.90991871697562, 56.34997047696795, 39.21724830354963, 0.962607775415693, 0.13656430558434554, 0.3682857650731291, 0.7488995886274746, 20.281986236572266, 70.96273735591343, 53.65681743621826, 57.58995294570923, 51.76412466594151, 54.856274536677766, 50.52615022659302, 54.1270124571664, 51.45154605593, 53.56448629924229, 48.897746086120605, 47.45130137034825, 51.167305673871724, 52.57748426709856, 49.13390493392944, 51.73415361131941, 47.109602860042024, 48.13640764781407, 46.04116446631295, 45.42515107563564, 43.674059118543354, 41.50592238562447, 37.19709777832031, 37.75752905436924, 35.67542144230434, 35.728092261723106, 34.82576445170811, 36.21314947945731, 34.656631401606965, 34.386805057525635, 34.715482643672395, 35.61606992994036, 34.919752734048025, 37.150492736271445, 36.778003283909385, 37.64777878352574, 36.957002776009695, 35.5564717565264, 37.35093436922346, 37.320848669324604, 37.422163827078684, 37.064911774226594, 37.21297441210066, 38.278671741485596, 37.263015338352744, 37.525400161743164, 39.389570576804026, 39.84255838394165, 39.523858410971506, 37.849182741982595, 35.795493262154714, 38.3680533681597, 35.68274136951992, 35.749325956617085, 35.61314126423427, 37.417275769369944, 33.879624775477815, 37.650193282536094, 38.14366824286324, 38.18711185455322, 38.124515533447266, 46.199982915605815, 44.97796501432146, 50.89528022493635, 39.32038041523525, 43.65059157780239, 48.55857672010149, 45.29330553327288, 44.552287101745605, 40.87990011487688, 40.93495764051165, 39.62390899658203, 39.20955317361014, 36.428060735974995, 38.36032697132656, 36.39801672526768, 37.147268772125244, 36.25163555145264, 36.25110054016113, 36.54067366463797, 37.521533489227295, 38.74007729121617, 37.59316941670009, 36.34092685154506, 37.878535406930105, 38.13987452643258, 37.82906075886318, 35.74727971213204, 38.72562156404768, 35.711878640311106, 37.6021534374782, 35.570764201028005, 37.191952637263704, 35.915478229522705, 35.81891563960484, 37.522714682987754, 37.036854948316304, 35.85881914411272, 37.79689754758562, 36.709084102085654, 36.99708693368094, 37.17126785005842, 38.2742839540754, 38.023704120091026, 36.98990249633789, 40.68424579075405, 42.41017484664917, 39.7681223324367, 39.087765148707796, 39.60865422657558, 41.228560720171245, 45.807486125401084, 50.08389738627842, 49.140620367867605, 51.441762992313926, 51.94339861188616, 52.28483656474522, 51.012506757463726, 54.05955239704677, 52.1390494619097, 51.245399951934814, 50.64557238987514, 52.961886405944824, 52.11288602011544, 54.6580354826791, 54.77177749361311, 62.475450243268696, 30.452286856515066, 0.5433620491198131, 1.8243051256452287, 2.199742134128298, 0.08464214099305016, 0.2718207213495459, 12.776808755738394, 63.15597765786307, 52.52767610549927, 48.3130829674857, 37.550809723990305, 31.36991807392665, 32.25446891784668, 42.36439664023263, 45.45372554234096, 56.643990448543, 16.17680811882019, 0.21861851401627064, 0.09800270585609333, 0.02023716952784785, 0.07823881280741521, 0.05968906996505601, 0.03947401898247855, 0.012644246470050087, 0.07767864822277001, 0.027236609387078455, 0.023940013156139424, 0.030713460142058984, 0.1258997299841472, 0.015093037792082344, 0.045975755101868084, 0.0484122047200799, 0.0686676488923175, 0.039080088692052026, 17.018182856695994, 69.86709676470075, 49.68065173285348, 55.01767076764788, 31.76385314123971, 19.14719602039882, 31.335434164319718, 43.31396177836827, 56.515056201389854, 61.897130829947336, 43.241526808057515, 0.9748663519109998, 0.25516390800476074, 2.6494321525096893, 2.5153814256191254, 21.157443625586374, 72.5782699584961, 54.86879171643938, 60.72151647295271, 54.50368125098092, 57.45144060679844, 52.255358832223074, 56.08569574356079, 52.63047122955322, 54.98551450456892, 50.25990915298462, 47.76303924833025, 52.88506364822388, 54.98824167251587, 51.21954223087856, 53.31541075025286, 48.10905606406075, 50.98935535975865, 47.67890698569161, 47.16126619066511, 44.87961326326643, 43.14422076089041, 39.90549864087786, 38.81411382130214, 37.19776480538504, 36.33019535882132, 37.95443058013916, 37.56515080588204, 37.059561661311555, 36.08871766499111, 36.34280981336321, 38.906656878335134, 37.02713789258684, 38.23160464423043, 38.13660887309483, 39.47168091365269, 38.45265463420323, 38.776124545506065, 39.06116049630301, 39.85139649254935, 39.066576617104666, 39.74114942550659, 38.387713296072825, 40.42951440811157, 40.2211275100708, 40.83332633972168, 40.1381173815046, 41.342337472098215, 40.2518698147365, 39.572349888937815, 37.92922946384975, 39.17610454559326, 37.368266650608604, 37.27591119493757, 37.33517238071987, 40.03258466720581, 38.48705169132778, 38.80707877022879, 39.07432385853359, 42.07909318378994, 39.62770618711199, 47.43437903267996, 45.97921085357666, 52.43012339728219, 42.53103528703962, 45.15733970914568, 49.33893585205078, 46.84993825639997, 46.59839262281145, 44.458986691066194, 43.58535841533116, 41.578075953892295, 40.37480081830706, 39.761459009987966, 41.25628055844988, 38.98985808236258, 38.394154276166645, 38.462642669677734, 38.963555676596506, 38.736895016261506, 39.86793320519583, 40.55349111557007, 40.245963845934185, 37.38832957404, 39.82097380501883, 39.938783986227854, 38.59622873578753, 38.497105734688894, 39.52147170475551, 37.707536765507285, 37.8355746950422, 37.239898681640625, 37.97252368927002, 37.741343225751606, 37.7870762688773, 39.86751283918108, 39.00649206978934, 37.61392368589129, 38.42432682854788, 38.918705054691856, 38.09165750231062, 38.55986533846174, 40.197368144989014, 40.19167409624372, 37.607302052634104, 41.4225127356393, 43.81976284299578, 41.34261540004185, 40.507584367479595, 41.57458101000105, 43.898110730307444, 46.69868292127337, 50.98978614807129, 50.627343790871755, 52.50913483755929, 54.134638105119976, 53.73339353288923, 52.53972428185599, 54.63626677649361, 54.29822301864624, 53.22886051450457, 52.58903912135533, 55.47944804600307, 53.82436282294137, 56.53704377583095, 56.50073596409389, 63.56961781638009, 31.837695121765137, 0.2557631087090288, 1.790803951876504, 3.251862032072885, 0.2230726485805852, 0.31649142290864674, 13.996020453316824, 67.7142391204834, 58.55790301731655, 51.21928514753069, 31.504181589399064, 33.80375392096383, 39.737953254154746, 50.703013147626606, 54.26472575323922, 64.26099831717355, 20.65190311840602, 0.11333928004439388, 0.0919761953077146, 0.03074958534645183, 0.09675913437136582, 0.024482335662469268, 0.05326944676094821, 0.04042651930025645, 0.01729588646308652, 0.07766768988221884, 0.13215271516570024, 0.09185238302286182, 0.3513317805315767, 0.0802748589111226, 0.3784188713346209, 0.17065210001809256, 0.16194497581039155, 0.1317113552774702, 21.549190010343278, 79.29280063084194, 57.674946784973145, 62.24030235835484, 36.93108252116612, 26.580988577433995, 47.07931566238403, 54.706964697156636, 60.416289057050435, 67.0943625313895, 48.021147455487935, 1.3070342136280877, 0.3115453097437109, 2.4953821216310774, 2.4947133575166975, 24.279739992959158, 74.4407067980085, 59.83983176095145, 62.46579919542585, 56.73734297071184, 60.28138978140694, 53.71985844203404, 56.97435644694737, 55.79313141959054, 56.505943638937815, 50.966561794281006, 48.44163506371634, 54.639535903930664, 56.95754875455584, 51.990840911865234, 55.37040301731655, 49.97018664223807, 52.76309149605887, 50.84552417482649, 49.433678013937815, 49.07338612420218, 45.62730196544102, 42.69439091001238, 41.458480085645405, 40.062465395246235, 40.0512683732169, 41.093320982796804, 40.388509614127024, 40.72379493713379, 38.858662196568076, 38.590406145368306, 40.49281597137451, 38.996781962258474, 40.326288495744976, 40.98019388743809, 41.736324650900706, 39.49239696775164, 39.14848893029349, 40.51374741962978, 41.284813335963655, 41.80207545416695, 41.37852021626064, 40.762465136391775, 42.50686945234026, 40.73421376092093, 41.47661140986851, 42.857023920331685, 44.24267884663173, 42.42346327645438, 41.7353310585022, 40.142102173396516, 42.48572955812727, 39.82072366986956, 39.03076212746756, 39.95207936423165, 41.925242696489605, 39.82407964978899, 41.24670941489083, 42.75504520961216, 45.272207328251426, 42.566040311540874, 49.90895216805594, 48.67017868586949, 55.24184397288731, 46.97526291438511, 47.26029191698347, 51.100272927965435, 50.087218625204905, 48.56260667528425, 46.633699893951416, 45.30590609141758, 45.06590141568865, 42.96548530033657, 40.37171234403338, 42.53752143042428, 40.80452605656215, 40.02453170503889, 39.49088226045881, 41.08273887634277, 41.125393867492676, 41.62811688014439, 42.623074599674766, 41.979191984449116, 39.9942375591823, 42.903191225869314, 42.06564147131783, 41.68891709191458, 40.8745812688555, 42.74221188681466, 40.47078323364258, 40.32686172212873, 38.46404273169381, 40.50948469979422, 40.19866050992693, 40.17010341371809, 40.9901819229126, 43.784611906324116, 39.634612696511404, 41.14388997214181, 41.08346496309553, 40.649873052324565, 41.30224289212908, 43.48253549848284, 43.31628942489624, 39.39703641619001, 43.3718889100211, 45.71335540499006, 45.260235582079204, 43.56810256413051, 43.78044646126883, 45.619526931217735, 49.497639656066895, 56.329105036599294, 52.960541929517476, 55.67698185784476, 55.75514561789376, 56.51172454016549, 54.705908570970806, 57.5968142918178, 56.4965739931379, 56.5760509627206, 56.554685252053396, 59.09210136958531, 56.06621299471174, 59.861148834228516, 60.216590881347656, 67.76682308741978, 34.29104151044573, 2.08321932383946, 8.755319084439959, 5.280291335923331, 1.3451466028179442, 0.323755465980087, 16.25851719720023, 75.37464196341378, 62.26391928536551, 62.49879619053432, 49.60037572043282, 42.94390072141375, 46.70252874919346, 59.92321709224156, 62.00940677097866, 75.73132078988212, 25.833963428224834, 0.41446124017238617, 0.1736099970127855, 0.12634600246591227, 0.24595222515719278, 0.18183025877390588, 0.20015617326966353, 0.09163429508251802, 0.10914862062782049], [0.04859116833124842, 0.05927752490554537, 0.051576121909809966, 0.061157955788075924, 0.061361292377114296, 0.04386904975399375, 0.04017520010737436, 0.08091867329286677, 0.038997063147170205, 14.423592618533544, 58.442451749529155, 43.40413549968174, 44.800428118024556, 24.6618127482278, 25.22771746771676, 34.43321555001395, 37.40681873049055, 52.60977602005005, 56.37337548392159, 34.102342333112446, 0.48244958051613396, 0.09315575379878283, 3.3707083633967807, 1.521814974290984, 6.228267507893698, 70.43992710113525, 51.61786508560181, 60.800260407584055, 52.31012800761631, 60.051362718854634, 49.71265513556344, 55.10067047391619, 53.172732966286794, 52.82606649398804, 46.51286029815674, 50.39875153132847, 50.21627099173409, 50.041350092206685, 46.64168684823172, 49.287897859300884, 43.85132850919451, 44.682141985212056, 42.526484216962544, 44.26035853794643, 40.77336685998099, 41.253153869083945, 36.454126902988975, 37.763886656079976, 35.20731088093349, 36.21422297613961, 33.23920236315046, 34.426156180245535, 32.535714626312256, 35.32787602288382, 33.87245076043265, 35.1004684312003, 36.98155076163155, 35.481736932482036, 33.89404923575265, 37.3216164452689, 35.74480962753296, 36.94158124923706, 36.996225357055664, 36.285393374306814, 37.51656552723476, 38.68500239508492, 35.88092483792986, 37.67106914520264, 39.484958921160015, 39.251329217638286, 38.115778173719136, 38.92830746514456, 37.39405836377825, 37.830582414354595, 36.42882851191929, 36.038377966199604, 35.545167037418906, 36.672897883823936, 34.70456007548741, 35.93820926121303, 35.24069350106375, 36.599924428122385, 36.56449556350708, 40.76153407778059, 37.81698826381138, 42.66049064908709, 44.73904773167202, 48.982253551483154, 41.81135824748448, 40.051358699798584, 49.00644023077828, 44.29007945741926, 39.49187237875802, 36.715163775852744, 37.041795117514475, 36.73914548328945, 36.794484410967144, 35.011944907052175, 35.8154102734157, 36.42296423230852, 37.232179233006065, 36.392395632607595, 36.30794722693307, 37.24012449809483, 37.63842303412301, 36.693273476191926, 37.107059546879356, 38.90614965983799, 38.62157923834664, 36.82290254320417, 36.480394567762104, 35.991814613342285, 36.37615074430193, 35.591608796800884, 36.56892851420811, 36.36536019189017, 36.384255817958284, 36.833745207105366, 36.00738900048392, 37.02130487986973, 35.88018832887922, 36.072799342019216, 37.457193170275005, 35.82748276846749, 37.074740001133506, 36.14720760072981, 37.89273405075073, 36.241001333509175, 37.33784048897879, 38.45983559744698, 37.078238419124055, 38.051229408809114, 37.44857045582363, 36.77481753485543, 39.200683798108784, 39.35633386884417, 42.12637220110212, 44.38862228393555, 46.04900550842285, 46.59296260561262, 47.505434785570415, 47.747659410749165, 46.755157879420686, 49.23570646558489, 45.45547301428658, 45.54782152175903, 44.10484048298427, 48.08303853443691, 51.86828511101859, 56.864342144557405, 58.08885792323521, 42.32357944761004, 0.7381982228585652, 0.6919790772455079, 2.368113270827702, 0.3187790901533195, 0.11358450260013342, 7.0966134156499585, 58.67172840663365, 56.96110623223441, 50.960628032684326, 46.52048594611031, 43.330818108149934, 34.19556283950806, 57.654922076633994, 45.19791024071829, 55.450397627694265, 18.43750180516924, 0.5920375457831791, 0.05838527171207326, 0.01778664200433663, 0.09187547356954642, 0.030757775264126912, 0.03984441089310816, 0.1183021462389401, 0.014396833721548319, 0.0315195156394371, 0.019419731605531912, 0.018831238183858137, 0.041763311318520985, 0.02274404768832028, 0.036933834930615764, 0.04156105699283736, 0.03099704367507781, 0.03042226005345583, 19.418582235063823, 66.3629048211234, 51.09052113124302, 52.82734843662807, 30.869505337306432, 28.10107203892299, 33.220716680799214, 41.824382645743235, 57.39399637494768, 60.410063471112935, 36.9835970061166, 0.2988757038755076, 0.14453539571591786, 5.592373583997999, 5.573128810950688, 8.210390976497106, 69.6955874306815, 53.35991396222796, 63.24775641305106, 55.059266158512656, 62.12842246464321, 51.79142761230469, 56.15560851778303, 54.30794007437569, 54.24749074663435, 46.264597688402446, 50.18838439668928, 52.20387615476336, 52.16029705320086, 48.84421369007656, 49.117569719042095, 46.09743445260184, 47.312802927834646, 44.673686027526855, 45.423566886356895, 42.79185676574707, 44.362903526851106, 39.12563630512783, 39.26339129039219, 37.378404072352815, 37.35210861478533, 34.949852330344065, 36.67640325001308, 35.54900591714041, 36.91017539160592, 35.50080973761422, 36.5219725881304, 36.718116760253906, 37.50898156847273, 38.007872649601524, 38.35126304626465, 37.04629060200283, 37.90075922012329, 37.40114205224173, 39.033913135528564, 38.44219759532383, 39.31868852887835, 37.29199627467564, 39.18324729374477, 39.413427216666086, 39.944238322121755, 40.62637424468994, 40.93113265718733, 39.667515890938894, 39.02563435690743, 37.59291580745152, 38.96359041758946, 36.75749567576817, 37.92279543195452, 36.865401199885774, 38.45647961752755, 38.9873046193804, 39.182573318481445, 38.37930250167847, 41.80394104548863, 39.736428124564036, 42.66622986112322, 46.96314525604248, 51.4077341897147, 44.854578903743196, 42.66879374640328, 50.30264057431902, 45.732636656079976, 41.91845778056553, 40.14187288284302, 39.99479341506958, 37.82284212112427, 38.34956421170916, 38.03217397417341, 38.373184612819124, 38.81549998692104, 38.700371810368125, 37.50483001981463, 38.95406791142055, 37.98134790148054, 39.41657475062779, 37.82651424407959, 38.57843092509678, 41.21767289297921, 38.652814865112305, 38.44595309666225, 38.43401261738369, 38.508796078818186, 39.60357856750488, 38.08999340874808, 37.58283049719674, 37.96932404381888, 37.31982033593314, 37.29724563871111, 38.599880014147075, 39.37889119556972, 38.17777000154768, 38.33797114236014, 40.109601974487305, 38.53055783680507, 39.34505346843174, 38.83667114802769, 39.62787641797747, 38.08177021571568, 39.29105206898281, 40.33077008383614, 38.15976027079991, 40.217281682150706, 39.14603621619088, 39.248678479875835, 40.67639432634626, 40.729124205453054, 44.16182960782732, 45.1759261403765, 48.01214953831264, 48.83180768149239, 50.576569829668315, 50.177163055964876, 50.603862353733604, 51.04613256454468, 49.92264706747872, 46.97223697389875, 47.651864596775596, 52.23753670283726, 54.10029663358416, 57.5913599559239, 59.848843574523926, 45.48487431662423, 0.9198843879359109, 0.5452640099184853, 3.0563036799430847, 0.6456795388034412, 0.16164491405444487, 7.24394953250885, 63.8770478112357, 61.83848108564104, 56.826338972364155, 45.64989055906023, 45.241395541599815, 38.05540875026158, 65.49349757603237, 52.307223660605295, 63.13994121551514, 25.757774693625315, 0.871311431484563, 0.08374053758702107, 0.019517611978309493, 0.043705553348575316, 0.08149355530206646, 0.07080149224826268, 0.07577351188021046, 0.029366018516676765, 0.09818483822579895, 0.11411436381084578, 0.12566324695944786, 0.17556351290217467, 0.10556921948279653, 0.07751026297254221, 0.08330353389361075, 0.0732201642489859, 0.13755153332437786, 25.38800893511091, 77.304094178336, 58.032153674534385, 61.936283929007395, 33.71507753644671, 37.01505844933646, 45.773839473724365, 50.307688440595356, 61.41544001443045, 65.61197131020683, 40.88784885406494, 0.8624385818839073, 0.21791595885796206, 7.782803177833557, 4.0758063452584405, 7.5776923554284235, 73.87517207009452, 54.538186005183626, 66.11126886095319, 55.063744272504536, 63.75786536080496, 54.43318830217634, 57.377233845846995, 55.47376094545637, 54.404586042676655, 47.7736039842878, 52.75039366313389, 55.21517678669521, 54.724293504442485, 49.552176066807334, 52.14852680478777, 47.88954510007586, 48.83570214680263, 47.68631029129028, 48.26969494138445, 45.007182189396445, 45.107392583574565, 41.39336156845093, 42.99261106763567, 39.80374574661255, 39.089873926980154, 36.478431701660156, 38.940932341984336, 37.67433132444109, 39.42250503812517, 38.6491288457598, 38.72355100086757, 40.59886980056763, 40.1909966468811, 39.12486505508423, 41.234956536974224, 39.629999092647004, 40.01738200868879, 40.08067314965384, 39.89869635445731, 39.96226889746529, 41.861743109566824, 38.39101716450283, 41.091608251844136, 41.853519916534424, 41.93629380634853, 42.26232065473284, 42.515096119471956, 40.63415970121111, 40.36783872331892, 39.47833033970424, 40.04482044492449, 40.85016529900687, 40.344854082380024, 37.229969705854145, 40.655421188899446, 41.16331018720354, 40.31214543751308, 41.08710929325649, 46.02432550702776, 41.99998794283186, 45.538010665348594, 48.90756736482893, 53.75635732923235, 47.42210156576974, 45.31962530953543, 51.26580681119646, 49.005689825330464, 44.30617495945522, 42.32006365912301, 41.7065828868321, 40.263244015829905, 39.542549065181184, 40.33583879470825, 40.09270395551409, 41.45981413977486, 40.823470320020405, 39.360749449048726, 40.93041351863316, 40.18949931008475, 42.09145402908325, 42.19265454156058, 40.02785989216396, 44.578603403908865, 41.07905980518886, 40.308365617479595, 39.75471230915615, 39.94752829415457, 40.836050033569336, 39.86434098652431, 39.50805473327637, 39.986643178122385, 40.2814621925354, 39.36279569353376, 39.7965578351702, 41.575692721775596, 39.86939927509853, 40.4749174118042, 40.68401650020054, 40.60849305561611, 41.266445772988455, 40.20899248123169, 40.33262177876064, 39.51336663109915, 40.91373436791556, 43.30329976763044, 40.23647608075823, 42.068775108882356, 41.187872069222585, 41.977190903254915, 42.7146657535008, 42.870204653058735, 47.59910345077515, 47.11115230832781, 51.604486329214915, 50.72024120603289, 52.0105425289699, 52.36978871481759, 53.094579628535676, 54.5862466948373, 50.67244802202497, 48.59666327067784, 48.375825200762065, 55.76010315758841, 56.782509735652376, 61.542133467538015, 61.49890872410366, 47.665371894836426, 1.4157101192644663, 3.2117678863661627, 7.475922090666635, 1.3114769352333886, 0.152327135471361, 9.055300610406057, 71.43522875649589, 66.96379198346818, 65.53861222948346, 59.01189136505127, 57.357511384146555, 49.007148947034565, 74.84312561580113, 60.93175506591797, 71.64756570543561, 34.844229289463584, 1.183321320584842, 0.1394413212048156, 0.10711078997701406, 0.13074339793196746, 0.14392528416854994, 0.13409806149346487, 0.18323133859251226, 0.08901608628886086], [0.028968590378229107, 0.017419481616733328, 0.037574008971984894, 0.0392292544378766, 0.044175415100263696, 0.0063871960155665874, 0.01333351930536862, 0.06427118980458804, 0.17806278807776316, 17.480410030909947, 60.503996167864116, 43.15542125701904, 43.78774554388863, 22.968743460518972, 22.343178033828735, 28.637752635138376, 39.493654591696604, 53.78299324853079, 54.72220209666661, 32.13864592143467, 0.04830965433003647, 0.10719323876713004, 3.016898491552898, 4.827611420835767, 0.5527386974011148, 47.69113234111241, 60.99778379712786, 54.09148284367153, 59.71369416373116, 45.215173040117534, 47.29084314618792, 53.96763120378767, 49.25564432144165, 48.78134291512625, 50.330256189618794, 51.94925594329834, 47.81253126689366, 49.47220230102539, 45.52019548416138, 44.614028794424875, 40.857110023498535, 40.674202169690815, 41.082353251320974, 43.13171747752598, 41.552753244127544, 40.67227404458182, 36.35332938602993, 35.99905463627407, 35.28929615020752, 34.9071695463998, 33.91205549240112, 33.755644593920024, 34.337438106536865, 34.05804756709507, 33.50756958552769, 33.69074494498116, 35.24508476257324, 36.68763848713466, 34.072840281895225, 35.52256107330322, 36.60054976599557, 35.96124253954206, 35.44042641775948, 36.69614308220999, 37.416778973170686, 36.58162634713309, 36.05064153671265, 37.803029332842144, 38.125543866838726, 37.5664883341108, 39.531643867492676, 37.94057934624808, 38.33341659818377, 38.48963294710432, 36.24560798917498, 37.009249755314414, 36.891564641680034, 36.931645325251985, 37.33317129952567, 36.9307142666408, 35.29969065529959, 36.40165063313076, 35.45075838906424, 38.80934388296944, 36.671560355595176, 40.311325550079346, 44.56534276689802, 49.71348197119576, 38.52591296604702, 42.839205265045166, 47.86411469323294, 41.2681758744376, 39.46579578944615, 36.70128127506801, 37.77989877973284, 35.4663154057094, 34.96883480889456, 35.444880213056294, 38.08511577333723, 35.01103121893746, 35.93338373729161, 35.59637178693499, 36.59293801443917, 36.85530546733311, 37.559109347207205, 37.464242117745535, 38.28403575079781, 35.442924295152935, 37.36867659432547, 36.802613803318565, 36.103427001408164, 35.49040133612496, 35.849380016326904, 37.66776180267334, 36.75898953846523, 38.12524856839861, 37.31476552145821, 36.343407358442036, 36.30334057126726, 36.56356450489589, 37.13201052801949, 36.73886408124651, 38.40417357853481, 36.9643018586295, 36.14497375488281, 36.67568758555821, 35.84141738074166, 37.941684109824045, 36.60245704650879, 37.42374801635742, 37.44892828805106, 38.012086732046946, 36.820564474378315, 38.29583379200527, 36.51268284661429, 39.10201242991856, 37.35071897506714, 38.33610555103847, 38.7471991947719, 42.48794255937849, 40.507344654628206, 41.119091851370676, 40.67204475402832, 41.42524685178484, 39.15136201041085, 44.40498529161726, 48.21715613773891, 53.91415786743164, 54.16973693030221, 58.42048849378313, 58.67520945412772, 48.05350521632603, 2.15429179583277, 0.41370969478573116, 2.438499825341361, 0.17320388023342403, 0.2399459145963192, 2.665584760052817, 50.44304282324654, 61.29868943350655, 47.46730307170323, 49.11028800691877, 44.01545885631016, 25.328794649669103, 43.95418964113508, 43.05187572751726, 56.79818834577288, 23.995355435780116, 1.4768300567354475, 0.04497249697202018, 0.07354443613439798, 0.03433458101270454, 0.02518617664463818, 0.04634340573102236, 0.07124317783330168, 0.014170527025791151, 0.03732129878231457, 0.025208780342446904, 0.028625390758471828, 0.03045899254669036, 0.04279882021780525, 0.0029364648300023483, 0.041362317478550334, 0.04714858252555132, 0.06289830311600651, 24.101622922079905, 68.35519654410226, 50.63088042395455, 49.69274854660034, 28.14643509047372, 27.799574068614415, 34.39706754684448, 43.90541328702654, 57.13923372541155, 60.94544301714216, 34.25722115380423, 0.17051290534436703, 0.09298253059387207, 7.547081198011126, 9.715810264859881, 0.4965611547231674, 48.99227632795061, 63.92225973946707, 57.359644481113975, 61.77386283874512, 47.328280040196006, 47.497263704027446, 53.77856377192906, 49.64224903924124, 49.641342299325125, 50.96480042593819, 52.67238276345389, 49.30697761263166, 51.83084126881191, 46.11785173416138, 45.12485340663365, 43.19962222235543, 43.948189871651785, 42.38674552100045, 43.67836005347115, 43.96912131990705, 42.13557856423514, 37.63322925567627, 38.01828105109078, 39.09457785742623, 35.784080845969065, 35.23066030229841, 36.35346140180315, 35.54545191356114, 36.326297419411794, 36.309996945517405, 35.69783633095877, 37.8659348487854, 38.131925787244526, 35.818613392966135, 37.085596561431885, 37.6492656980242, 38.82050963810512, 36.97199004037039, 38.50150741849627, 39.438412938799175, 37.62307446343558, 37.62331417628697, 39.02034330368042, 40.18571949005127, 39.87496130807059, 40.889790875571116, 38.46509190968105, 39.9077707018171, 39.62695230756487, 38.68794495718819, 39.103433336530415, 38.5167031288147, 38.91148240225655, 37.3429091998509, 38.27293947764805, 37.139000415802, 39.35127558026995, 37.33249732426235, 40.99502829142979, 38.226963247571675, 41.29803575788225, 45.70751544407436, 52.28361715589251, 40.82328619275774, 44.43217706680298, 49.23604692731585, 44.09907695225307, 42.759179387773784, 40.10771206447056, 38.707851546151296, 37.6305958884103, 37.00560542515346, 37.66505547932216, 38.52341856275286, 38.09541647774832, 38.49220378058297, 36.77872589656285, 39.22740656988961, 38.506437165396555, 39.47850751876831, 39.337604999542236, 38.71168000357491, 38.42865208217076, 37.91553109032767, 38.32503707068307, 38.358694144657676, 36.35285343442644, 37.8240511076791, 41.17373595918928, 38.938007150377544, 39.4885059765407, 39.29280996322632, 38.1791353225708, 38.1304840360369, 39.07412930897304, 38.457094533102854, 38.456597736903596, 39.143639087677, 38.43966497693743, 38.506718567439485, 36.80361434391567, 38.26851347514561, 40.73893506186349, 38.975173064640586, 38.25856712886265, 38.42744309561593, 39.660004888262065, 38.87243005207607, 40.128431592668804, 38.96401425770351, 40.49241644995553, 39.187159129551475, 40.21435996464321, 42.41758162634713, 44.14828756877354, 42.234163079942974, 42.5335887500218, 43.25295312064034, 43.61163650240217, 41.04095935821533, 46.65691382544381, 50.59526743207659, 56.20622614451817, 57.17914070401873, 59.50700610024588, 59.42410019465855, 49.31269598007202, 2.8659113134656633, 0.7175504022410938, 3.239575445652008, 0.6054646681462015, 0.27859695202537943, 2.9849016027791158, 54.31661490031651, 66.19560609545026, 55.22949702399117, 49.12452139173235, 54.89027207238333, 35.34574678965977, 48.18331493650164, 51.740316663469585, 63.23128918239048, 31.554903439113072, 1.9544702896050044, 0.06765351723879576, 0.09599491395056248, 0.054774125306201835, 0.057490501153681955, 0.057786308495061736, 0.02862050530633756, 0.06054907238909176, 0.17431812972894736, 0.08432993346026965, 0.14599966071546078, 0.08332631909953696, 0.16121190014694417, 0.13916252473635332, 0.12647980957158975, 0.1830383903746094, 0.18743920565715858, 30.99091468538557, 76.62878486088344, 56.01807587487357, 59.43281323569161, 31.810256685529435, 29.086376973560878, 39.5898107119969, 52.34535537447248, 60.134199142456055, 66.04649775368827, 39.086069788251606, 0.24688806065491267, 0.16113215871155262, 8.587144885744367, 11.45988540990012, 0.827862988625254, 52.36676624843052, 64.69899191175188, 58.5044435773577, 63.92421913146973, 49.57462222235543, 48.81986025401524, 55.72757863998413, 49.990635190691265, 49.306842122759136, 52.217227118355886, 54.17398227964129, 52.22020789555141, 53.719309534345356, 49.90592622756958, 47.95554256439209, 44.37672001974923, 47.455108983176096, 45.391393252781455, 47.4371200970241, 45.963188307625906, 45.08080530166626, 40.77507611683437, 41.56482226508004, 40.70784534726824, 37.405595847538535, 37.966516971588135, 38.644265106746126, 39.39264515468052, 39.12932579857962, 38.38635492324829, 37.32254402978079, 40.193664755140034, 41.135392325265066, 37.81333698545183, 39.21067878178188, 40.50116075788225, 40.46986607142857, 38.64376483644758, 40.774308340890066, 41.46421582358224, 41.04286663872855, 38.9365028653826, 41.35177312578474, 41.49336004257202, 41.89222138268607, 42.14942979812622, 41.918655804225374, 41.3673996244158, 41.197707244328086, 40.64065279279436, 41.17643186024257, 39.369410378592356, 41.39355264391218, 40.932407651628765, 41.14247601372855, 39.37034491130284, 42.420683997017996, 39.08532633100237, 42.61472633906773, 40.67166607720511, 42.86199535642351, 48.90716436931065, 55.39746625082833, 43.96565416881016, 48.43650729315621, 51.400858947208945, 46.80917664936611, 45.78514071873256, 40.79725129263741, 39.85170221328735, 40.039817741939, 40.05954367773873, 40.41078553880964, 41.01787396839687, 40.549217973436626, 39.884091241019114, 37.99049520492554, 42.210573945726665, 42.66862004143851, 41.00286933353969, 41.11381122044155, 42.023841108594624, 39.92095838274275, 40.656133379255024, 40.99998235702515, 40.19592291968209, 38.01868404660906, 40.00092172622681, 42.71253265653338, 40.095667362213135, 41.597277300698416, 41.35845034463065, 39.958989347730366, 39.55081394740513, 41.4009177344186, 41.97637448992048, 40.48159463065011, 43.86617333548409, 41.02832405907767, 40.494473116738455, 39.84644590105329, 40.76501512527466, 41.74641343525478, 41.27314383643014, 41.221814019339426, 40.575937271118164, 41.93041910443987, 40.97804341997419, 44.12463590076992, 41.654877867017476, 42.32087312425886, 40.84128897530692, 42.81966693060738, 44.401980195726665, 47.16164139338902, 44.274157660348074, 45.09079681124006, 44.503079959324424, 46.58878673825945, 44.59516096115112, 50.06366770608084, 53.42819390978132, 59.43493938446045, 59.1686566216605, 62.23601531982422, 61.037061963762554, 52.799781458718435, 3.220091611146927, 2.4665620795318057, 8.952174578394208, 1.3466279804706573, 0.4605007639953068, 3.53517005273274, 60.18813105991909, 71.97543730054582, 60.635615893772666, 60.07903739384243, 56.52592665808541, 40.16038983208792, 59.69667802538191, 60.07808549063546, 73.25266906193325, 42.88593537466866, 2.9015405901840756, 0.1255651850785528, 0.40203140143837246, 0.16895089059003762, 0.22267499991825648, 0.16038385672228678, 0.14609982605491365, 0.08119376496012722], [0.030590241575347524, 0.03654738888144493, 0.05182415360052671, 0.01572773096683834, 0.016690801163869243, 0.03804579437045114, 0.06806648043649537, 0.059722861008984704, 0.18687049831662858, 16.623964650290354, 56.15695646830967, 42.01089661461966, 43.37557145527431, 29.843384947095597, 31.949779987335205, 31.036296844482422, 42.352511746542795, 55.9772413117545, 54.61896576200213, 29.068652118955338, 0.07654212242258446, 0.16260094275431974, 7.430342776434762, 14.800489834376744, 0.36816615292004173, 13.118584564753942, 62.89174461364746, 53.73558221544538, 44.4078757422311, 35.79850878034319, 58.808156285967144, 51.04592064448765, 54.42901938302176, 48.808006627219065, 52.6494710786002, 51.500496115003315, 50.04818364552089, 47.7510918208531, 42.93522936957223, 40.789458887917654, 38.338662488119944, 39.45549161093575, 41.296604428972515, 39.65778146471296, 41.2496554510934, 38.314395904541016, 35.43643815176827, 32.3470675604684, 34.366988795144216, 33.77452284949166, 33.308225767953054, 33.74486793790545, 34.0106816973005, 32.548593112400596, 34.099365030016216, 34.51845257622855, 33.47440235955374, 34.456453800201416, 35.93227202551705, 35.05947058541434, 35.262219020298545, 34.03987455368042, 35.639700753348215, 34.61668273380825, 36.96595205579485, 36.57205867767334, 37.35317516326904, 37.43834270749773, 38.69982637677874, 36.47800438744681, 37.19731317247663, 35.81091826302664, 36.364304065704346, 36.16326141357422, 36.701892716544016, 36.85708768027169, 35.45867933545794, 37.45675890786307, 35.54699093954903, 35.70249162401472, 35.07300220217024, 34.1872284752982, 36.41551228931972, 39.03503179550171, 36.52894163131714, 41.65210553577968, 46.514778000967844, 50.0593181337629, 45.48557955878121, 39.66991649355207, 50.42288957323347, 44.85713931492397, 42.003389086042134, 38.7070768220084, 37.63686663763863, 36.75672442572457, 34.89486081259591, 35.27899544579642, 37.13128096716744, 35.53132275172642, 36.27868141446795, 34.20225395475115, 36.01335402897426, 37.097085407802034, 37.16883945465088, 35.624960150037495, 35.720709800720215, 37.08451611655099, 37.279319286346436, 37.736743518284385, 36.38688571112496, 36.56883471352713, 34.73277670996529, 36.63156999860491, 35.99460431507656, 36.516007559640066, 37.53282083783831, 37.38270500728062, 37.211084502083914, 37.7134462084089, 35.28819833483015, 36.125046321323936, 36.80219691140311, 36.449704374585835, 37.1177910396031, 36.79299054827009, 37.15832683018276, 35.39097261428833, 37.01066023962838, 36.38283838544573, 37.05951302392142, 38.30862889971052, 36.36768783841814, 37.22478634970528, 36.18154559816633, 38.326579570770264, 37.8068299974714, 39.021479334150044, 39.03705372129168, 39.471764292035786, 38.13550410951887, 38.80339969907488, 38.50944920948574, 42.38416426522391, 46.91205167770386, 52.33774709701538, 52.67202145712716, 53.96006114142281, 53.00528138024466, 62.991381781441824, 65.52453517913818, 52.62019484383719, 3.7242014408111572, 0.14620645104774407, 0.800224737397262, 0.6816877094762666, 0.1496282217225858, 1.5249266816037041, 42.949205671037944, 64.63976546696254, 50.39703185217721, 66.80178778512138, 29.4482513155256, 10.732338666915894, 31.70124987193516, 40.78421994618007, 57.61133255277361, 35.13660601207188, 2.054971856730325, 0.060890775839132924, 0.050229881291410754, 0.047623953981591124, 0.05341893481090665, 0.012145664027359868, 0.04697759170085192, 0.010627116226325077, 0.040546365547925234, 0.05287553682657225, 0.05379376094788313, 0.03716606354074819, 0.10024712327867746, 0.06142888803567205, 0.013946708857214876, 0.00893575743040336, 0.2479046689612525, 22.854523760931833, 63.723978996276855, 48.691461018153596, 48.622552258627756, 31.294179235185894, 30.163797651018413, 35.74430935723441, 48.03735760280064, 59.15840802873884, 59.26982239314488, 31.793803351266043, 0.10895201510616712, 0.11115175778312342, 9.123794215066091, 17.02629314150129, 0.6266039109655789, 14.237898537090846, 62.908100673130576, 52.953885555267334, 44.755389894757954, 36.77972991125924, 59.40823745727539, 51.57568604605538, 55.467101097106934, 50.176047870091026, 53.09095614297049, 53.35576588766915, 51.09431484767369, 48.4082350730896, 46.54199062074934, 43.06238835198538, 40.531534808022634, 42.34838799067906, 43.75437682015555, 41.72081279754639, 43.37862171445574, 39.74632235935756, 36.82787050519671, 32.950324058532715, 36.45237248284476, 35.66688558033535, 36.027007239205496, 35.3486441884722, 36.460748536246165, 34.89420073372977, 36.44546944754464, 36.483121735709055, 36.26476069859096, 36.44816882269723, 37.62785482406616, 38.00007677078247, 37.21622964314052, 35.73211874280657, 37.112649372645784, 37.35828903743199, 38.2227144241333, 38.36899137496948, 38.99198770523071, 39.43028702054705, 38.86291102000645, 38.53511585508074, 38.89504296439034, 37.804450239454, 38.34104919433594, 38.16656603131975, 37.72997944695609, 36.749380179813926, 36.8876736504691, 39.22471066883632, 37.30413825171334, 37.064269065856934, 38.294148853846956, 36.509146213531494, 37.91453749792916, 39.33749382836478, 39.40399156297956, 42.627028124673025, 48.715119634355815, 52.44093132019043, 47.040443965366904, 40.946616717747276, 50.58246190207345, 45.22870118277413, 45.59945705958775, 40.8471463067191, 38.58037642070225, 37.96452283859253, 37.24180596215384, 38.50837571280343, 39.331893580300466, 37.89993585859026, 38.96146774291992, 36.26333284378052, 37.73787954875401, 37.78182690484183, 38.64654411588396, 36.863917759486604, 38.56699766431536, 39.35251930781773, 38.38987765993391, 38.465592179979595, 39.13948406491961, 38.89623458044869, 38.15993397576468, 37.370396273476736, 38.430253641945974, 37.233596665518625, 39.71751165390015, 38.52071918760027, 38.245261328560964, 40.33213540485927, 37.95415612629482, 37.49089888163975, 39.59814507620675, 38.4243928364345, 38.617365155901226, 38.30420289720808, 40.04410130637032, 37.42171914236886, 39.03090456553868, 37.416136264801025, 38.318547453199116, 39.61173922674996, 38.30251448495047, 39.99358442851475, 38.50084386553083, 39.66977405548096, 40.12546818596976, 40.32827568054199, 41.511526107788086, 40.95318971361433, 39.89871719905308, 41.4236626625061, 41.309854643685476, 45.1574786731175, 49.70451184681484, 54.99476603099278, 54.353058201926096, 57.78243541717529, 56.46156896863665, 63.95488153185163, 64.53461837768555, 53.281597341809956, 5.110089131764003, 0.7761091685720852, 2.8965276820319037, 1.363543912768364, 0.10171746116663728, 1.4215927464621407, 48.08652305603027, 68.47316305977958, 55.886779240199495, 65.31708976200649, 40.56963178089687, 24.173654896872385, 40.39692040852138, 48.68717050552368, 65.53615256718227, 44.43573801858084, 2.6050917889390672, 0.07097917342824595, 0.09984359850308724, 0.01690713339485228, 0.05586311972833105, 0.04074554950264948, 0.042915551989738426, 0.031101745021130358, 0.12260549675141062, 0.14831209448831423, 0.11485605686903, 0.13846249372831412, 0.16625603448067391, 0.17763641024274485, 0.16986561007797718, 0.25833703630736893, 0.3780920074454376, 31.77855552945818, 73.07637936728341, 56.36454779761178, 58.91055883680071, 36.67458629608154, 40.09182848249163, 42.91054241997855, 54.45933089937483, 64.8771367754255, 64.98282582419259, 35.879847867148264, 0.15297660204981053, 0.22741820397121565, 12.00259964806693, 26.734191145215714, 0.5709453661526952, 17.448285034724645, 66.24020658220563, 53.57873010635376, 45.79038313456944, 36.623350279671804, 60.50438526698521, 53.49710961750576, 57.48084885733468, 49.0587671143668, 54.24595519474575, 55.701557636260986, 54.55159602846418, 49.99995967320034, 47.805927004132954, 45.22061695371355, 42.41369410923549, 44.9245159966605, 45.39786549976894, 43.66382442201887, 47.397181851523264, 42.53022582190377, 38.226181575230186, 34.84270415987287, 38.80304534094674, 38.81052507672991, 39.0154378754752, 36.80407639912197, 39.58851139886038, 36.18414075034005, 38.29293291909354, 38.73343481336321, 38.31103297642299, 39.210004806518555, 39.64840487071446, 38.69811017172677, 39.508506366184776, 39.09562703541347, 37.87737853186471, 38.885735852377756, 41.17695992333548, 39.68155125209263, 42.19711875915527, 41.72732673372541, 40.681970255715505, 40.644891193934846, 41.80466365814209, 39.34350402014596, 40.38636262076241, 39.1683156149728, 39.14054019110543, 39.11797244208199, 38.98310095923287, 41.0167692048209, 39.609342098236084, 39.261001110076904, 40.82916784286499, 37.40677009310041, 40.81903736931937, 42.57000425883702, 40.90366642815726, 44.84010580607823, 52.01032713481358, 54.50040864944458, 50.19085448128836, 43.84561014175415, 52.80896002905709, 47.890066214970176, 47.989185741969514, 43.523147719247, 41.22683409282139, 40.149620124271934, 38.76140478679112, 40.35861151559012, 40.72882890701294, 39.69050400597708, 40.29773139953613, 38.6293751171657, 39.593632221221924, 40.67222193309239, 41.124441964285715, 39.380214827401296, 40.24343817574637, 41.562074252537315, 40.30012852805001, 41.84128761291504, 40.7091064453125, 41.90930005482265, 39.23309367043631, 40.50518029076712, 39.32328128814697, 40.80670084272112, 41.8697578566415, 40.76703357696533, 39.41577570778983, 41.99500955854143, 39.22220931734358, 38.35548407690865, 41.499373708452495, 41.67794936043875, 42.5134528705052, 40.68435001373291, 42.75205053601946, 39.069088390895296, 41.632410866873606, 39.84016472952706, 39.910080977848594, 42.418450151171, 39.50148868560791, 41.27796936035156, 40.24678373336792, 43.19736753191267, 41.87041098730904, 42.699369294302805, 43.98108264378139, 43.814256395612446, 42.69778857912336, 43.092515741075786, 42.43783562523978, 47.703684261866975, 51.21576241084507, 57.84215865816389, 56.48799991607666, 61.33579281398228, 57.80074392046247, 65.87114606584821, 65.78233419145856, 56.47653191430228, 5.7537190062659125, 1.3075926750898361, 4.903878322669438, 2.525281088692801, 0.1723125566329275, 2.027750334569386, 51.44099869046892, 73.27523681095668, 63.081499917166575, 76.09054960523332, 36.510768617902485, 22.871767452784947, 47.6023656300136, 59.222671917506624, 74.62721034458706, 56.167000089372905, 3.8246624044009616, 0.20621775729315622, 0.17427300715020724, 0.06933561233537537, 0.16249480630670274, 0.09986057544925384, 0.10457463642316205, 0.08563335173364196], [0.1013202467667205, 0.059954193952892504, 0.04555054773975696, 0.008907095263046878, 0.0062679082870350355, 0.05339109112641641, 0.049191807529756, 0.006173566050295318, 0.187045492497938, 22.044942242758616, 58.216503279549734, 39.017595291137695, 52.72289964130947, 21.12826987675258, 28.42620951788766, 33.76581328255789, 42.8813738822937, 54.3388352394104, 54.44245719909668, 25.826257875987462, 0.27442933565803934, 0.5702046773263386, 9.198210290500096, 13.851872256823949, 0.46124769534383503, 1.231576451233455, 49.74426596505301, 53.14921678815569, 52.352070808410645, 59.14177404131208, 53.793474606105256, 52.05462537493025, 53.08017601285662, 53.360237053462434, 49.758957930973594, 50.28048276901245, 47.51332099097115, 46.573792525700156, 42.52512584413801, 37.97479575020926, 38.448398862566265, 40.53973020826067, 38.277177878788535, 38.088944230760845, 37.06824343545096, 35.228065150124685, 34.56041274751936, 34.542865071977886, 35.13268027986799, 34.43449401855469, 33.683598722730366, 34.71180009841919, 33.933751242501394, 33.71865585872105, 34.72243084226336, 34.84086288724627, 34.03086968830654, 36.539502893175396, 37.2838773046221, 36.12211070741926, 36.45663520268032, 34.21162012645176, 35.695585114615305, 36.74678155354091, 36.02902569089617, 36.64714091164725, 36.35129008974348, 36.49847378049578, 36.93972955431257, 36.576495102473665, 36.23738827024187, 36.53859267915998, 34.99353218078613, 35.90338141577584, 35.854191643851145, 37.189631938934326, 37.62339060647147, 37.71917152404785, 35.70369018827166, 36.74043437412807, 32.693393571036204, 36.02660076958792, 34.38066284997122, 35.628785133361816, 39.24020515169416, 45.37335572923933, 46.61131974628994, 47.304972308022634, 35.474583762032644, 44.4718964440482, 47.78299447468349, 45.98819834845406, 47.77231509344918, 41.76333577292306, 38.93134035382952, 36.62762689590454, 36.562425000326975, 34.16483790533883, 36.1973249571664, 34.566016469682964, 36.9337923186166, 35.960780484335764, 34.096853256225586, 35.493236201150076, 36.87930801936558, 36.1110839162554, 36.85780681882586, 37.90421942302159, 37.43535498210362, 38.743582657405305, 37.20063441140311, 37.02619988577706, 37.18852717535836, 36.18775033950806, 37.76991074425833, 36.07474831172398, 36.05095420564924, 36.039541789463584, 35.91442905153547, 38.113245555332725, 36.80676882607596, 37.001551151275635, 35.84412022999355, 36.8553923198155, 36.10397938319615, 36.747622285570415, 35.88283906664167, 36.51857839311872, 35.42065879276821, 36.52405704770769, 35.305138042994905, 37.645023822784424, 37.347498485020225, 39.176698616572786, 38.29772022792271, 37.012366022382466, 39.423210280282156, 39.841953890664236, 40.94394860948835, 40.30610745293753, 40.75504446029663, 44.32158606392996, 46.57965333121163, 52.9597533089774, 49.97309446334839, 53.514035429273335, 51.48050267355782, 63.29465675354004, 63.296949659075054, 52.01718500682286, 56.28282655988421, 57.13575962611607, 8.717612947736468, 0.3354380748101643, 1.6018819979258945, 0.46999764868191307, 0.09884201296206031, 0.7416220562798637, 41.10427829197475, 61.71943065098354, 55.695887906210764, 56.373646463666645, 36.356000968388145, 14.25169505391802, 24.006908552987234, 40.097279344286235, 54.30641494478498, 44.457041195460725, 2.385553683553423, 0.07845345378986426, 0.02521843759209982, 0.06264560988971166, 0.03782389984865274, 0.0404590279129999, 0.11800859841917243, 0.017527806339785457, 0.05660975930680122, 0.07496232326541628, 0.04555331276995795, 0.07280510437807866, 0.02241207443044654, 0.024661482478092824, 0.06886202203375952, 0.07490877328174454, 0.23093548523528235, 31.888792174203054, 67.00196538652692, 45.59874139513288, 57.87768479755947, 25.99118205479213, 32.91627441133772, 38.73162133353097, 48.077750955309185, 58.98336900983538, 58.511148588997976, 27.62090114184788, 0.2865482425051076, 0.472663368497576, 7.039155721664429, 11.465446574347359, 0.8467413527624947, 1.508976331778935, 52.53960963657924, 51.64806195667812, 53.03010034561157, 60.974104336329866, 55.55227558953421, 53.21635723114014, 53.11702230998448, 55.275118895939414, 52.04613120215279, 52.102140630994526, 50.47555691855294, 47.62755284990583, 44.73145682471139, 39.67105252402169, 40.837488310677664, 41.35475737707955, 40.58647421428135, 41.42980139596121, 39.103440284729004, 36.72112185614449, 36.13164710998535, 36.39385822841099, 36.91079030718122, 35.974235670907156, 35.59089660644531, 35.280923570905415, 36.985830851963584, 35.99629967553275, 37.59760236740112, 35.49847861698696, 36.31027487346104, 39.538967268807546, 38.42515366418021, 36.37254115513393, 37.199870109558105, 37.24377230235508, 36.333422797066824, 37.32478134972708, 38.42619241986956, 37.71710096086775, 35.99909632546561, 37.928941113608225, 38.90127897262573, 38.25986296789986, 38.03555079868862, 37.83601590565273, 36.47513478142874, 38.09041377476284, 35.68545811516898, 37.98552029473441, 37.18669979912894, 38.333955083574565, 38.08703000204903, 37.96751056398664, 36.09124680927822, 38.52779245376587, 36.1001752444676, 38.18326255253383, 41.7010486466544, 45.97534418106079, 47.90153769084385, 49.418312072753906, 40.14779274804251, 46.296059131622314, 49.944912569863455, 50.62827484948294, 49.02102797372, 44.05805131367275, 41.12864909853254, 38.32156644548689, 36.93784311839512, 35.97905772072928, 37.553245067596436, 37.52376733507429, 39.1856826373509, 38.52604150772095, 37.52528551646641, 37.45369822638375, 37.88235344205584, 37.313688550676616, 37.86411094665527, 38.650369099208284, 39.63172571999686, 40.07630968093872, 37.98001732145037, 38.88287666865757, 38.85368381227766, 38.44805492673601, 39.14208269119263, 38.65067829404558, 36.380552428109304, 38.402950695582796, 38.225177560533794, 38.911107199532644, 37.710889271327424, 38.94499008996146, 37.20190245764596, 39.36962924684797, 38.416027205330984, 38.24933992113386, 37.01743820735386, 38.282847608838765, 37.48261315482003, 39.80437455858503, 37.30215801511492, 38.40312787464687, 38.57369920185634, 40.87457084655762, 40.49849264962332, 39.5463809967041, 41.253643717084614, 41.230481897081646, 42.46414497920445, 41.836892877306255, 42.63236434119088, 46.262909276144846, 48.38667828696114, 53.39341817583357, 52.76949773515974, 54.95575884410313, 53.431806973048616, 63.30687863486153, 62.854856627328054, 57.12396158490862, 54.30741548538208, 59.10006400517055, 9.489465747560773, 0.28363578021526337, 6.036785577024732, 4.398774249213083, 0.11340375444186584, 0.8054247040833745, 44.11387314115252, 67.41368784223283, 59.43683624267578, 61.399639810834614, 40.08786106109619, 18.22265829358782, 29.80413109915597, 46.905867780957905, 61.97010775974819, 53.24142633165632, 3.8992439338139127, 0.04347022044073258, 0.030915666970291307, 0.06217206708554711, 0.05168942368722387, 0.011775510452155556, 0.06717781669327191, 0.06752973209534373, 0.27841475180217196, 0.18740366399288177, 0.14185690587120398, 0.2534892292959349, 0.0762337079005582, 0.1886858916176217, 0.22199385932513646, 0.1787064599671534, 0.5497055373021534, 42.19105992998396, 73.36809253692627, 55.57048681804112, 66.40845721108573, 31.743543556758336, 37.172521999904085, 45.72857195990426, 55.72704015459333, 62.5599889755249, 62.84703295571463, 31.22744526181902, 0.30342161708644455, 1.3159847962004798, 18.638737269810267, 26.59149251665388, 2.528908048357282, 2.3892166869980946, 55.35066665921892, 52.57670954295567, 54.82771744046892, 59.480769702366416, 58.900393622262136, 55.76655803407942, 57.563528946467805, 56.169178349631174, 53.22081797463553, 54.47052444730486, 53.206056526729036, 50.37991149084908, 47.542625018528526, 41.67598649433681, 43.19958053316389, 43.84128141403198, 42.64238364355904, 44.43916348048619, 40.58045012610299, 37.70699828011649, 39.51931081499372, 38.85466350827898, 38.365409578595845, 39.4851256779262, 37.65163850784302, 38.71218722207205, 39.31039585386004, 37.02645696912493, 40.30677448000227, 38.74288783754621, 38.50423111234392, 40.35074268068586, 42.00819723946707, 38.03301470620291, 39.45202793393816, 38.00939083099365, 37.94881296157837, 39.84820032119751, 39.9660313470023, 38.96189158303397, 38.715473720005576, 39.6366902078901, 39.68675545283726, 40.32281787054879, 40.4164274760655, 39.84171765191214, 38.255773953029085, 39.908229282924104, 38.22352041516985, 41.18441881452288, 41.41010325295584, 41.08669934953962, 38.43116038186209, 41.13542706625802, 38.915043354034424, 41.00404705320086, 39.33582626070295, 38.96396909441267, 43.54815081187657, 48.07156011036464, 50.815243925367085, 50.89274065835135, 42.76670776094709, 49.52979939324515, 53.079425607408794, 53.41556903294155, 52.544386523110525, 45.281066281454905, 42.387395177568706, 40.975257192339214, 39.02253546033587, 37.83439350128174, 39.648429189409526, 37.57808835165841, 41.52327898570469, 39.970349652426584, 39.57825585774013, 39.24769183567592, 41.364297253744944, 40.62770135062081, 41.83659757886614, 40.92135306767055, 41.69268648965018, 42.50271790368216, 39.70856932231358, 38.91007191794259, 41.2151437486921, 39.31325503758022, 41.49215453011649, 40.042902742113384, 38.719058990478516, 38.48340041296822, 39.9479729788644, 41.12756517955235, 40.42240640095302, 41.415105955941335, 40.85639435904366, 40.843182359422954, 41.281280176980154, 39.392759799957275, 40.827694824763704, 40.18873153414045, 39.62784515108381, 41.15106398718697, 39.68984045301165, 41.1649603843689, 40.38263143811907, 44.32426806858608, 43.390555245535715, 40.542863845825195, 44.223675523485454, 43.66752086366926, 44.565415722983225, 45.264602524893625, 44.78138310568673, 51.01713078362601, 49.839293003082275, 56.067682538713726, 55.03662197930472, 57.73891884940011, 57.86536911555699, 64.9948045185634, 62.36878844669887, 59.17927346910749, 55.08009685788836, 60.32812336512974, 10.591480442455836, 0.8953637065632003, 7.192292715821948, 3.811646257128034, 0.17348077680383409, 1.2703548903976167, 48.36166477203369, 72.35917936052594, 65.96557208469936, 68.27840505327497, 43.305693422045024, 22.519945417131694, 38.46150663920811, 58.54011562892369, 70.33178533826555, 65.85412297930036, 5.500247418880463, 0.3017606719263962, 0.11852370149322919, 0.1694399786314794, 0.10757300124636718, 0.0928555495504822, 0.20291497451918467, 0.1692261586764029], [0.03503153147175908, 0.026217173286048428, 0.038381431717425585, 0.047861481950219185, 0.18140750431588717, 0.0285107929791723, 0.01092081077929054, 0.03705971674727542, 0.6430587651474136, 36.82502521787371, 57.37917934145246, 45.55997044699532, 49.37610176631382, 25.717099939073833, 22.2832168170384, 32.24512011664254, 50.8033937726702, 55.38252762385777, 57.271235602242605, 21.941388028008596, 0.3989601619541645, 0.42813239086951527, 8.949458701269966, 15.640278645924159, 0.5951069667935371, 1.8078433232648032, 46.60653591156006, 54.02728843688965, 56.2513929094587, 53.401141098567415, 50.406936509268625, 51.838623251233784, 51.44957276753017, 50.61105721337454, 50.97913455963135, 50.47384418760027, 51.02332162857056, 46.795554706028526, 39.76774018151419, 39.18404286248343, 37.59024769919259, 38.29064696175711, 35.129932267325266, 35.87337909426008, 34.4161125591823, 32.27183246612549, 33.82489728927612, 34.72390733446394, 34.190108503614155, 33.56569821493966, 33.05302538190569, 33.002880232674734, 32.6706451688494, 32.85283735820225, 33.80314595358712, 35.01251465933663, 33.27762590135847, 35.16680288314819, 35.16892555781773, 35.78062759126936, 35.314264501844136, 35.72422211510794, 36.70131254196167, 36.03980582101004, 36.126863275255474, 36.44759907041277, 36.71350315638951, 35.643643856048584, 36.168941565922324, 36.73437901905605, 36.039406299591064, 34.988671915871755, 35.0631913457598, 36.03788117000035, 35.586265632084434, 37.55470418930054, 35.851721559252056, 37.525504384722026, 35.10133000782558, 35.994215215955464, 36.04000037057059, 34.68493488856724, 34.730164187295095, 35.92622014454433, 42.8277268409729, 48.95133406775338, 47.19106701442173, 47.12025792258126, 38.39162860597883, 37.40119416373116, 45.46486350468227, 46.88180269513811, 46.84398365020752, 42.55932140350342, 37.21271732875279, 33.579914229256765, 34.557272161756245, 35.894109044756206, 33.8144645690918, 35.095785345349995, 35.333007267543245, 37.614823477608816, 35.478631087711875, 37.192442485264365, 36.77569300787789, 34.939638478415354, 34.36751685823713, 36.60038995742798, 36.20176485606602, 37.97434759140015, 37.43565028054373, 37.52786329814366, 36.28008495058332, 35.358965737479075, 37.563028131212505, 36.7733028275626, 36.074581554957796, 36.24085194723946, 36.53718566894531, 38.83292259488787, 36.03116921016148, 36.47743810926165, 35.77235228674752, 37.26568692071097, 35.178107602255686, 34.99752739497593, 36.72426591600691, 34.93682445798601, 34.84548691340855, 37.49717657906668, 36.87767519269671, 39.2301094191415, 39.82420124326433, 40.209794998168945, 40.306753635406494, 40.74166917800903, 42.34546627317156, 43.95037855420794, 44.130145822252544, 45.80750349589756, 48.46466486794608, 50.18123122623989, 51.1604061126709, 50.101281779153005, 56.258591243198936, 53.79415552956717, 56.102986335754395, 71.56647327968052, 49.623916217258994, 51.98016153063093, 33.367514746529714, 49.849753516060964, 14.59472588130406, 0.9672077000141144, 2.3419737134660994, 1.9924519658088684, 0.05287817632779479, 0.06589385201888424, 36.719607148851665, 60.02263191768101, 59.22968264988491, 47.611426080976216, 49.55245746885027, 28.796364375523158, 19.871865340641566, 41.19007464817592, 52.56165279660906, 50.95822048187256, 5.559992807252066, 0.004845988537584032, 0.032639006817979474, 0.04942436183669737, 0.034418288485280106, 0.10050162819347211, 0.006533536087122879, 0.014568285950060402, 0.02463982703297266, 0.019478550413623452, 0.08785866161010095, 0.028760761887367283, 0.06289119885436126, 0.05338133718552334, 0.08324230289352791, 0.07276283843176705, 1.0885702563183648, 44.09942088808332, 64.08461829594204, 52.20803812571934, 56.03928525107247, 26.76651590211051, 23.555492775780813, 41.9272437776838, 54.25259419849941, 59.90433883666992, 61.48424802507673, 24.796058893203735, 0.4078069015273026, 0.7109492336000715, 12.468782084328787, 19.58618494442531, 0.3408062367566994, 2.2453555379595076, 46.07643699645996, 52.822668824877056, 58.96355274745396, 53.74511514391218, 53.32501663480486, 53.512920243399485, 53.44782951899937, 53.03943525041853, 53.68119171687535, 52.45165239061628, 52.175822802952354, 47.774163314274375, 42.878865582602366, 41.201198714120046, 40.93875483104161, 39.766096932547434, 37.149259431021555, 38.96852363858904, 35.84795216151646, 34.59791564941406, 36.240785939352854, 36.27786847523281, 36.893468448093955, 35.992981910705566, 35.0648068019322, 35.907321044376914, 35.502376556396484, 36.0748872756958, 35.48097610473633, 37.16591426304409, 36.09673588616507, 38.126454080854145, 37.179348605019705, 36.7690817969186, 36.10236740112305, 35.8357823916844, 38.0352520261492, 37.29696076256888, 37.5166871207101, 37.3174718448094, 38.22475719451904, 37.510617869240896, 38.505620752062114, 38.45270674569266, 38.3964923449925, 37.85190296173096, 35.693716049194336, 38.26132903780256, 36.64722776412964, 39.126602104731965, 37.64356122698103, 38.475670542035786, 36.749397550310405, 38.71122489656721, 37.98863656180245, 37.40499482836042, 36.531432560511995, 37.94187865938459, 44.767361640930176, 50.55919238499233, 47.63637706211635, 48.97154985155378, 38.662316526685444, 41.73976053510393, 47.48763002668108, 49.238847051348, 48.50838640757969, 45.603553022657124, 40.000911303928916, 36.60042469842093, 37.75265836715698, 38.439136913844514, 36.60646963119507, 37.07088375091553, 38.31647341591971, 38.52380418777466, 36.30149582454136, 38.43729216711861, 38.93171208245413, 38.425306524549214, 36.85429450443813, 39.112135955265586, 38.33770363671439, 38.849441937037874, 39.99981696265084, 39.55933938707624, 38.417434215545654, 37.88219363348824, 39.07383748463222, 37.46388775961739, 38.46309082848685, 37.01747989654541, 37.564813818250386, 39.98071983882359, 38.545993259974885, 37.22895874295916, 37.0259428024292, 39.16690165655953, 37.27320487158639, 37.39221361705235, 37.91215426581246, 37.930622577667236, 36.91566446849278, 39.9537330354963, 39.476669720241, 40.4870593888419, 40.76873935971941, 41.79191371372768, 41.38210548673357, 41.722122532980784, 42.41513933454241, 43.84520019803728, 45.361602851322715, 49.03908634185791, 49.504532269069124, 52.41488599777222, 53.743565695626394, 53.58875635692051, 57.51355402810233, 57.67308814185006, 55.336561816079275, 68.2593947819301, 52.10142149244036, 55.62580490112305, 35.732038838522776, 50.28516238076346, 15.458776065281459, 0.5795534242476735, 6.3800608941486905, 6.611832823072161, 0.03263359550120575, 0.1691624578088522, 38.681490080697195, 67.32208279200962, 63.940338952200754, 56.506457805633545, 43.49510478973389, 27.68534220967974, 27.761746338435582, 48.34784827913557, 61.21314321245466, 58.9330848966326, 8.16739899771554, 0.09417504910379648, 0.05713361208992345, 0.011298455381100731, 0.040659134675349505, 0.040466108425919495, 0.04000922704913786, 0.03764870210683771, 0.14048425666987896, 0.12596652497138294, 0.14215601767812455, 0.14025736813034329, 0.22155368008783885, 0.0999196283519268, 0.18800697661936283, 0.16060500485556467, 1.6389898295913423, 53.58451795578003, 71.30828516823905, 61.06475748334612, 62.392989022391184, 34.314317975725444, 28.81755117007664, 44.57537596566336, 63.14413792746407, 64.48821830749512, 68.6845758983067, 26.96465073313032, 0.46102747001818245, 0.8020667699830872, 20.861396517072404, 28.913196597780498, 3.1707633095128194, 2.828407325914928, 54.24272428240095, 55.06794793265206, 61.902856145586284, 54.97866358075823, 56.43703487941197, 54.966834272657124, 55.82464844839913, 53.884429999760215, 55.83510201317923, 52.622300148010254, 56.36916487557547, 51.04285648890904, 44.34608541216169, 42.43940591812134, 43.25850820541382, 42.46005596433367, 40.57155295780727, 41.36147975921631, 37.11244787488665, 36.78016764777047, 38.582551206861226, 38.74745280402047, 39.378189427512034, 37.32454163687569, 37.92722143445696, 38.43422801154, 37.30743864604405, 38.33770711081368, 37.235149587903706, 38.88036836896624, 37.05693524224417, 39.58039590290615, 40.55553388595581, 39.184261730739046, 38.07566622325352, 37.135092054094585, 39.50321183885847, 39.309176445007324, 38.783996854509624, 38.369568075452534, 40.15362923485892, 38.83122376033238, 39.96871335165841, 39.41862446921212, 40.528088501521516, 38.22346830368042, 36.85374212265015, 39.546863896506174, 38.525482177734375, 41.13299867085048, 38.70466232299805, 40.88635151726859, 39.57272856576102, 41.509167194366455, 39.77560554231916, 40.0983042035784, 37.93794597898211, 40.658575671059744, 46.793720381600515, 52.56118726730347, 51.22781753540039, 49.71075480324881, 39.072604179382324, 44.24384961809431, 48.168015003204346, 50.58648143495832, 51.67675106866019, 48.41286257335118, 41.52375146320888, 37.98514856610979, 39.473699365343364, 40.152562686375205, 38.55383777618408, 38.71509851728167, 40.27876281738281, 41.340124470846995, 39.69750779015677, 41.14239610944475, 40.65184981482369, 38.82257672718593, 39.2762211390904, 40.91976193019322, 39.66247149876186, 42.03772013528006, 41.39936481203352, 41.91424022402082, 39.268703188214985, 39.58171953473772, 40.56859302520752, 40.275455474853516, 40.02392373766218, 39.837381975991384, 39.07752002988543, 42.38542883736746, 40.182672704969136, 40.056170327322825, 39.10469443457467, 41.58395412990025, 39.69430814470564, 39.27244826725551, 40.21930708203997, 40.12149729047503, 37.31507819039481, 40.92520931788853, 40.973877974918906, 42.940725394657676, 43.642621994018555, 43.692847047533306, 43.70055954796927, 43.439783232552664, 44.97272607258388, 47.60841056278774, 49.42084469114031, 50.60395615441458, 52.448824473789756, 56.26841252190726, 56.092550141470774, 55.96167387281145, 59.44247123173305, 58.5853761945452, 55.63665451322283, 73.18838432856968, 55.04344163622175, 57.64330121449062, 38.79518345424107, 52.037987913404194, 18.606525421142578, 1.476272246667317, 8.219285539218358, 5.350640543869563, 0.10573482273944787, 0.32360588972057613, 43.15163101468767, 70.81847190856934, 70.51202160971505, 60.11923967088972, 58.19657932009016, 40.4875978742327, 32.82235213688442, 58.63186659131731, 69.69430896214077, 71.73925413404191, 11.710233347756521, 0.1991315446794033, 0.17116001062095165, 0.10552754386195115, 0.13435396419039794, 0.15049148111471108, 0.17631136705832823, 0.1560590916446277], [0.010707079033766474, 0.03274765045249036, 0.0555664947522538, 0.032867876679769585, 0.07655493994908673, 0.043247352221182415, 0.020267203184110776, 0.09361111864979778, 1.450160590665681, 40.33974715641567, 53.927289962768555, 47.4162129674639, 39.84610891342163, 29.033683572496685, 42.826649870191304, 26.29033500807626, 51.355160645076204, 52.11894832338606, 55.30916159493582, 20.81733798980713, 0.17817703980420316, 0.4766808386359896, 4.5716536811419894, 6.6830609781401495, 1.0558212250471115, 11.25474418912615, 68.48837266649518, 53.81279754638672, 55.31608894893101, 50.08893483025687, 52.19441965648106, 45.07642446245466, 45.64232744489397, 47.39049073628017, 50.89207363128662, 51.411072799137656, 47.55966547557286, 43.59394986288888, 38.45501702172415, 35.503714084625244, 36.12969814028059, 35.02347891671317, 35.85190568651472, 33.25673614229475, 34.531622886657715, 34.366988795144216, 33.014303071158274, 34.85211896896362, 34.17695903778076, 32.823060853140696, 34.69294963564192, 35.295080525534495, 34.44963761738369, 34.00825677599226, 33.040320600782124, 35.129570960998535, 34.53388452529907, 34.183420862470356, 35.784233706338064, 34.76348774773734, 35.4216628074646, 34.111687660217285, 35.866410051073345, 34.58590568814959, 35.90891565595354, 35.452408586229595, 35.90259626933506, 36.36293527058193, 35.46242094039917, 36.53147424970354, 35.46576302392142, 37.65792315346854, 34.626396315438406, 35.29622350420271, 33.83063302721296, 36.06180034364973, 35.221023150852744, 34.66276318686349, 35.34244292122977, 35.0183059828622, 36.51938438415527, 34.46337768009731, 35.02286747523716, 37.86879750660488, 42.922048636845176, 46.77458504268101, 49.740788391658235, 50.280427183423726, 44.52349724088396, 35.912177835192, 48.18385689599173, 45.076855250767295, 47.75134195600237, 40.81568833759853, 38.06304829461234, 34.93309327534267, 36.805368764059885, 33.04710899080549, 36.064659527369905, 35.825516428266255, 35.347167696271626, 35.6197316305978, 35.25277641841343, 34.997648988451274, 35.14422818592617, 36.036877155303955, 35.2149851662772, 36.033962385995046, 36.25637769699097, 37.49814237867083, 36.55576515197754, 36.96192904881069, 35.55797256742205, 37.618759632110596, 37.460160051073345, 35.70717123576573, 36.776168959481375, 35.7164957182748, 36.38443299702236, 37.00162410736084, 36.152196407318115, 36.4061530658177, 35.65242290496826, 37.399919169289724, 36.376487731933594, 34.69153915132795, 34.049233777182444, 35.51246881484985, 35.23863683428083, 36.430478709084646, 39.293174743652344, 41.68809025628226, 43.17234012058803, 44.93544551304409, 48.26676974977766, 47.90597758974348, 47.32900960104806, 48.18748732975551, 49.90987280436924, 51.896564279283794, 52.673279081072124, 50.010420186179026, 52.34744678224836, 55.661390100206646, 54.02896295275007, 52.438277108328684, 49.24552427019392, 30.86354030881609, 46.46356282915388, 55.28555509022304, 32.26326533726284, 37.757205963134766, 18.520935773849487, 0.9102304631045887, 7.777876905032566, 8.639287642070226, 0.15169893418039593, 0.046828972175717354, 31.27736806869507, 63.41033731188093, 60.026932852608816, 51.59233045578003, 49.95836080823626, 22.07319709232875, 13.879447051456996, 27.882387910570415, 50.339566775730674, 47.37492677143642, 5.669223265988486, 0.0414853290920811, 0.04197838317070689, 0.03853232433487262, 0.08815822125013385, 0.0868115531546729, 0.028170212504587004, 0.044432155787944794, 0.08004653866269759, 0.03475466204274978, 0.02312016473816974, 0.05711093544960022, 0.05770042631775141, 0.040787228516169956, 0.14582145027816296, 0.054023723251053264, 1.5567115417548587, 49.272601400102886, 61.20554188319615, 54.00113541739327, 46.87299237932478, 33.886444432394846, 36.51761954171317, 30.726108414786204, 57.00721100398472, 56.4818229675293, 61.58136994498116, 21.81416130065918, 0.08736534629549299, 0.26326805885349003, 6.974956103733607, 7.51334421975272, 1.9579029168401445, 13.428664428847176, 67.7250783102853, 55.17020457131522, 56.73275021144322, 53.08094378880092, 53.73437670298985, 47.99653346197945, 48.62852423531668, 51.09542308534895, 51.878547600337434, 53.33516795294625, 49.60062238148281, 45.82359899793352, 39.81919159208025, 39.18287556512015, 38.48437316077096, 36.90094123567854, 36.708500453404014, 35.68917540141514, 35.77754953929356, 36.188212394714355, 36.7743832724435, 35.96779816491263, 36.30372619628906, 36.416481563023154, 35.735648427690776, 37.173800468444824, 36.19002934864589, 36.05407394681658, 34.439569677625386, 34.83152103424072, 36.630545139312744, 36.57906593595232, 37.78670801435198, 36.531099046979634, 36.58071960721697, 36.03452171598162, 38.60775579724993, 36.609912463596885, 37.4645756312779, 36.7666950907026, 36.883195536477224, 37.86512885774885, 38.84514447620937, 37.164521149226594, 37.54344115938459, 39.03577525275094, 36.12823207037789, 38.17200994491577, 36.219510555267334, 37.51859440122332, 37.35559661047799, 37.882155418395996, 37.991290773664204, 37.30341911315918, 38.84755550112043, 36.5425705228533, 37.6040746143886, 39.53553485870361, 46.4274183000837, 50.657217570713584, 51.610232489449636, 51.99317898069109, 45.027658530644004, 40.5730641910008, 49.529420716421946, 47.07732152938843, 49.32774577822004, 44.82941252844674, 40.197823251996724, 35.86167137963431, 38.351697308676584, 34.92049271719796, 37.35552365439278, 37.56923982075283, 38.22776576450893, 35.74261747087751, 37.49184036254883, 36.735264914376394, 36.10590056010655, 38.575158323560444, 36.38046210152762, 37.45330565316336, 37.97053303037371, 39.4944987978254, 40.00487525122506, 38.22565003803798, 37.50097376959664, 39.40385954720633, 38.50323404584612, 38.08829804829189, 38.122087138039724, 37.51571784700666, 38.27096618924822, 39.18995230538504, 37.625662667410715, 37.47799607685634, 36.7395658493042, 38.77207374572754, 37.33924055099487, 37.3399909564427, 37.27552556991577, 38.20048018864223, 36.89634500231062, 37.71453707558768, 41.21108947481428, 43.04990243911743, 45.60113157544817, 48.4176880972726, 48.81911679676601, 50.027919224330354, 50.07558734076363, 49.602925709315706, 52.89046587262835, 52.286462443215505, 54.37303079877581, 52.024824551173616, 55.413996015276226, 57.55065393447876, 56.43926525115967, 55.01469693865095, 50.017253739493235, 34.13048253740583, 48.25366197313581, 55.79145342963082, 37.10355070659092, 37.882624421800884, 20.744925601141794, 0.8882758383240018, 5.295564779213496, 13.599190592765808, 0.048452509700187614, 0.026796766024615084, 33.95398787089756, 67.79392106192452, 65.39192186083112, 57.48358644757952, 50.431022439684185, 22.04448366165161, 17.497797897883824, 36.39147847039359, 55.75906440189907, 57.21012966973441, 8.390408379690987, 0.07321025085236345, 0.010131424342814301, 0.02301070516529892, 0.061515611596405506, 0.08171998243778944, 0.049292631048176966, 0.024005993901352798, 0.14990240415292128, 0.10258195549249649, 0.1672913839242288, 0.17778932489454746, 0.17576197082442896, 0.2018505566354309, 0.20097726849573, 0.20157025381922722, 2.4335833234446387, 59.35601479666573, 69.38275173732212, 62.58794852665493, 52.98861265182495, 38.13845361982073, 53.22434765951974, 36.348385742732454, 63.731448309762136, 60.010194642203196, 66.56175531659807, 25.38529392651149, 0.2635121414703982, 1.4008882003171104, 10.96568523134504, 13.533000315938677, 3.2406815120152066, 14.303722296442304, 69.1444285256522, 55.98254973547799, 58.48184108734131, 53.342383657182964, 56.081453868321006, 51.24405894960676, 50.2164238521031, 52.28465938568115, 54.71722718647548, 56.59751047406878, 52.29505736487252, 48.515188694000244, 41.89763055528913, 39.671882833753315, 41.372847012111116, 39.336607933044434, 39.8660432951791, 37.80419315610613, 38.669553075517925, 39.19216878073556, 39.02171557290213, 38.899010385785786, 39.03213439668928, 37.69129882540022, 38.50007608958653, 40.450595242636545, 37.54126984732491, 37.99030065536499, 37.82960966655186, 36.661065101623535, 39.63099615914481, 38.10010651179722, 40.40135683332171, 38.11052533558437, 37.901346342904226, 37.54970496041434, 39.33315815244402, 38.05575616019112, 39.98564958572388, 38.05824361528669, 38.91773925508772, 39.71168906348092, 40.06701646532331, 39.904286180223735, 39.08134501320975, 40.94996574946812, 37.49851758139474, 39.9980069569179, 38.55455344063895, 40.344965253557476, 38.74658080509731, 39.17510747909546, 39.01914473942348, 39.496690954480854, 40.70907865251814, 38.46224662235805, 38.883005210331504, 41.964527811322895, 48.36793204716274, 52.16831874847412, 54.935320717947825, 53.068690640585764, 45.01560688018799, 44.344605445861816, 52.06446055003575, 49.455742018563406, 52.54900360107422, 45.729520389011924, 42.93469088418143, 39.118834018707275, 42.58629431043352, 36.80377762658255, 39.720638343266074, 39.24437059674944, 40.0547320502145, 37.71944597789219, 39.97170107705252, 38.86081613813128, 38.88471099308559, 40.48910910742623, 37.73010104043143, 38.27397128513881, 40.18210642678397, 41.00314378738403, 41.88386617388044, 40.708894525255474, 39.70305592673165, 42.46125105449131, 40.87188884190151, 39.39714758736746, 40.30423838751656, 39.13074670519148, 40.78042622974941, 41.121516772678916, 39.1802248273577, 40.326872144426616, 40.236472606658936, 40.3929043497358, 39.75647715159825, 38.77669429779053, 38.669990812029155, 39.236314160483225, 38.52388409205845, 40.0548814364842, 43.992137227739605, 46.82321548461914, 47.33749335152762, 48.493030888693674, 51.81722279957363, 53.580859729221885, 50.87477609089443, 52.52152000154768, 54.803502968379426, 56.91593599319458, 57.7115603174482, 56.05000284739903, 57.6005037852696, 59.260893957955496, 57.44391223362514, 53.93113579068865, 51.713767596653526, 40.65098128999983, 49.30721385138375, 57.01574339185442, 41.198179721832275, 42.79388563973563, 23.858307429722377, 1.5070397385529108, 16.99094765526908, 19.144223928451538, 0.5246159721698079, 0.159765344911388, 37.70632430485317, 74.69279439108712, 69.35987826756069, 66.05962290082658, 61.23295947483608, 31.966347966875347, 24.16981601715088, 45.92763784953526, 65.25545229230607, 68.03005559103829, 11.899530938693456, 0.28469315490552355, 0.15422921840633663, 0.16420067048498563, 0.12475034594535828, 0.1340049664889063, 0.1453881242445537, 0.0595117551939828], [0.061099065733807426, 0.0379389827804906, 0.05276198059852634, 0.07241020378257547, 0.04032004697780524, 0.08886948201273169, 0.13396778276988439, 0.015353386589725102, 1.1254241530384337, 42.04968840735299, 55.44600984028408, 47.26786892754691, 42.154345648629324, 17.050577095576696, 33.48968492235456, 34.46821710041591, 50.93384967531477, 53.38748441423689, 56.62906224387032, 19.979760442461284, 0.11514055303164891, 0.9813876705510276, 10.149997115135193, 12.715166074889046, 0.35013541472809656, 28.111688886369976, 32.696318762642996, 37.99259008680071, 58.38874912261963, 50.439693791525706, 49.606285163334434, 42.93620559147426, 39.00254201889038, 41.382709980010986, 43.456292152404785, 46.434498514447895, 42.11606107439314, 37.68055691037859, 35.212886810302734, 35.02912780216762, 33.902581623622346, 34.65046834945679, 35.43760197503226, 33.025083201272146, 34.47628048488072, 33.959622859954834, 31.86812128339495, 34.09719024385725, 34.48458358219692, 36.42357914788382, 33.98789855412075, 34.75004645756313, 35.252745151519775, 35.182874066489084, 34.28536830629621, 34.94743088313511, 34.391529832567485, 34.24004520688738, 34.71216140474592, 36.5245121547154, 34.52432032993862, 35.40720360619681, 35.75396735327584, 35.338725634983604, 36.17627886363438, 35.43071631022862, 36.23829501015799, 35.211684771946494, 35.19793081283569, 33.741873264312744, 36.18862581253052, 36.166575704302105, 35.99759898866926, 34.215379101889475, 34.838531766619, 36.49732037952968, 34.354082516261506, 36.35173824855259, 37.642803873334614, 33.46531411579677, 36.81889690671648, 36.56091724123274, 34.95964581625802, 36.23654406411307, 41.25466857637678, 45.20706449236189, 47.305385725838796, 46.82232958929879, 44.99695791516985, 46.0339035987854, 47.63771111624581, 43.02513211114066, 43.76021678107125, 37.16160290581839, 36.515364851270405, 35.486204624176025, 36.132345403943745, 33.743905612400596, 33.802715165274485, 37.31810065678188, 36.656604358128135, 35.06141260692051, 34.79461220332554, 34.40654836382185, 35.22317361831665, 36.235529627118794, 35.89484902790615, 35.81916230065482, 36.378092765808105, 38.241540568215505, 37.98166404451643, 36.33948162623814, 35.300079754420686, 36.347392150333945, 35.148855686187744, 36.343699182782856, 36.28915582384382, 35.57967873982021, 36.58536100387573, 37.54654005595616, 36.683094365256174, 37.04957709993635, 35.38268688746861, 35.842932088034495, 35.72674778529576, 35.9164058140346, 35.344791412353516, 35.289466381073, 35.36130380630493, 35.53745453698294, 39.7929482460022, 44.02369941983904, 45.91186891283308, 47.386488573891775, 48.67417390005929, 50.57498911448887, 50.02000870023455, 49.49189002173287, 50.13366733278547, 51.93796164648873, 51.34653098242623, 52.233510221753804, 50.81365278788975, 50.7287596975054, 50.438304151807515, 55.818950925554546, 51.60724823815482, 52.309238638196675, 60.108706201825825, 57.296367236546104, 44.138928345271516, 45.15774965286255, 19.50058487483433, 0.10331448154257876, 5.436191976070404, 11.309100815228053, 0.16852867896003382, 0.08852008397557906, 24.310471875326975, 64.06204359872001, 56.271660804748535, 55.77854367664882, 36.231225218091694, 23.295411280223302, 27.669773033687047, 31.781275749206543, 47.484107289995464, 50.860890116010395, 10.412216050284249, 0.15063716258321488, 0.06113147935164826, 0.03208030108362436, 0.04311152308114937, 0.016127148909228187, 0.09209565139774765, 0.021344075578131845, 0.05701484810560942, 0.018409072354968106, 0.11597846235547747, 0.015398592289005007, 0.09061174959476505, 0.04395289293357304, 0.1508465449192694, 0.02247769046308739, 2.2864211286817278, 51.90112229755947, 64.54458209446499, 54.7840028490339, 49.13710110528128, 24.612263407026017, 40.59115035193307, 36.46853051866804, 55.80829586301531, 56.37497704369681, 61.12039170946394, 20.367575883865356, 0.09473570223365511, 0.051935599584664614, 9.588395067623683, 7.518643958227975, 0.5372166388801166, 33.81929704121181, 33.57245186397007, 41.23732239859444, 59.4408939906529, 54.48169367653983, 52.480414458683555, 44.21932247706822, 39.85038552965437, 44.97865636008126, 46.956836291721885, 47.93590348107474, 44.20856319155012, 40.65674482073103, 37.42175735746111, 36.52101721082415, 36.71595587049212, 35.59669140407017, 36.552124295915874, 36.22998496464321, 36.264864921569824, 37.22835424968174, 34.26404775891985, 35.754057679857524, 35.96206242697579, 38.83232157570975, 36.90505804334368, 35.266773564474924, 37.61419119153704, 35.75117070334298, 35.53564453125, 35.83013698032924, 35.94958346230643, 35.910701342991416, 36.4436559677124, 36.17429167883736, 36.61915704182216, 38.601665701184956, 37.51199361256191, 35.802740233285085, 37.467955929892405, 36.52348034722464, 37.26186541148594, 37.69276142120361, 36.808797700064524, 36.37538644245693, 37.25291960580008, 37.65652309145246, 36.3467390196664, 35.82245227268764, 36.28997571127755, 37.92547743661063, 36.44143601826259, 37.93504163197109, 38.04438543319702, 35.529953956604004, 37.9177371433803, 38.60113416399275, 37.187728132520405, 38.39737129211426, 43.912688050951274, 47.60138593401228, 48.11891903196062, 49.14670351573399, 49.361767632620676, 48.21326167242867, 49.08139739717756, 44.853925773075645, 45.964550154549734, 40.1996054649353, 39.37287058149065, 37.23537540435791, 37.53854962757656, 37.49250044141497, 36.115631512233186, 38.6326060295105, 37.46484661102295, 36.73745012283325, 35.99396855490548, 36.75113112585885, 35.81613288606916, 37.511364800589426, 37.33058309555054, 36.97138554709298, 37.90387896129063, 40.03669452667236, 39.32079383305141, 37.46944284439087, 37.34817940848214, 37.493115356990266, 37.17663533346993, 38.09114680971418, 39.312049525124685, 38.287117276872905, 38.22192580359322, 38.594998904636924, 37.430644103458945, 38.71519579206194, 37.49497747421265, 37.831628118242534, 36.55508075441633, 36.58632680347988, 37.52963508878435, 37.28921004704067, 37.33691985266549, 38.09899132592337, 40.393602643694194, 44.56641626358032, 47.437081881931846, 50.5445316859654, 51.3149653162275, 52.15740312848772, 52.306775501796174, 51.76261690684727, 52.37461771283831, 54.76785176140921, 52.65759352275303, 54.569331305367605, 51.250955036708284, 51.959466321127756, 51.51431955610003, 56.71091897147042, 51.63711854389736, 53.4089161327907, 62.29797240665981, 58.399935722351074, 48.34274482727051, 46.55734961373465, 21.36704819543021, 0.19063049155686582, 0.961071137871061, 13.259332486561366, 0.21770847641995975, 0.042094551758574586, 24.98819395474025, 69.15082086835588, 62.21993024008614, 60.77435057503836, 38.55249677385603, 27.62005172457014, 36.18782329559326, 40.22220795495169, 53.30528027670724, 58.33348315102713, 13.529909236090523, 0.22558823573802197, 0.07472483600888934, 0.0833649548834988, 0.04139547748491168, 0.03946083504706621, 0.05065109208226204, 0.03257679872746978, 0.20879304196153367, 0.19825015483157976, 0.1711055649710553, 0.10083692627293722, 0.18755052611231804, 0.22814279794692993, 0.19748883854065621, 0.1493695913148778, 3.305980465241841, 62.80416257040841, 72.53312056405204, 63.234610421316965, 54.82416691098894, 24.560978753226145, 41.183730942862375, 44.80934265681675, 61.10393142700195, 62.693213735307964, 66.82507119859967, 23.43396357127598, 0.2891300139682633, 2.6398225767271857, 15.799093621117727, 20.784005744116648, 0.937218189239502, 35.58125250680106, 36.18054853166853, 43.508007594517295, 63.04131153651646, 56.095558711460654, 54.08739035470145, 46.58695936203003, 42.74070412772042, 45.96131229400635, 47.86657435553414, 49.85347427640642, 46.640008858272004, 41.61644390651158, 39.396609101976665, 39.411297593797954, 39.23226683480399, 37.526480606624055, 39.714937346322195, 37.373901639665874, 39.53412437438965, 39.16207265853882, 36.61537374768938, 37.888645035879954, 37.788135869162424, 41.78577150617327, 38.768846307482036, 38.49791519982474, 39.45980644226074, 39.88780852726528, 39.018460341862266, 38.71281950814383, 38.55256625584194, 36.99113580158779, 38.75782299041748, 39.77930893216814, 39.36997665677752, 40.23268583842686, 39.43342065811157, 38.696411337171284, 40.32769203186035, 38.82219805036272, 40.3772292137146, 39.156812872205464, 38.62111718314034, 36.005738803318565, 39.0353479385376, 39.26902975354876, 38.21698563439505, 37.72168329783848, 39.71909931727818, 39.87173734392439, 38.62751647404262, 38.98581075668335, 42.04463011877877, 36.91865219388689, 42.64196675164359, 40.627353940691265, 39.54373720714024, 40.43759516307286, 45.70985698699951, 47.353929315294536, 52.059082644326345, 51.762825352805, 50.50254372188023, 52.07046379361834, 51.575939655303955, 47.131753717150005, 49.1158778326852, 41.12744358607701, 41.80538279669625, 38.51912110192435, 39.976703780038015, 39.7177027293614, 37.50149835859026, 40.51068326405117, 40.470137051173616, 39.84586572647095, 38.215797492435996, 39.346880844661165, 38.37074926921299, 40.44396666118077, 41.129576683044434, 39.03633458273751, 39.5196339062282, 42.80413770675659, 41.90452316829136, 38.5153933933803, 38.405875887189595, 38.819189480372835, 38.96242659432547, 39.458145822797505, 42.03539596285139, 38.774067878723145, 40.92752654211861, 41.15311023167202, 38.74587903703962, 41.466401032039094, 39.64775174004691, 39.81096839904785, 38.05006558554513, 39.302728516714915, 40.26990039008004, 39.114776270730154, 39.80755335944039, 39.79099232809884, 43.12613112585885, 46.45574263163975, 49.66708190100533, 52.6949713570731, 54.01273543494088, 54.58085489273071, 54.63018362862723, 52.460271630968364, 56.3518499646868, 56.439442430223735, 54.12455974306379, 56.26679359163557, 53.66299785886492, 53.75219883237566, 53.12737512588501, 57.53588553837368, 55.228069169180735, 55.175217696598594, 63.45739051273891, 61.061519622802734, 51.31378064836775, 49.10547290529524, 25.69500466755458, 0.3079797439277172, 10.357333098139081, 20.22217093195234, 0.36221749069435255, 0.12088405340909958, 28.488986492156982, 76.39035047803605, 65.61956569126674, 68.18203353881836, 47.104409081595286, 34.441789627075195, 42.143447399139404, 50.34696660723005, 61.897540773664204, 69.24883215767997, 18.174887691225322, 0.5408448470490319, 0.12273821820105825, 0.1890135154660259, 0.2319057360291481, 0.09220558085611888, 0.165333552552121, 0.05545243980096919], [0.051513432059437037, 0.027345940038295727, 0.09840705165905611, 0.07884648162871599, 0.05259593629411288, 0.019199161923357418, 0.1198062819561788, 0.033984609613461156, 2.2871973727430617, 47.93763010842459, 51.9862551007952, 42.934319155556814, 32.0709878376552, 14.957854373114449, 35.30511025020054, 33.28993463516235, 54.90147604261126, 49.56170552117484, 61.49044581821987, 15.776767321995326, 0.06591090360390288, 0.10051838800843273, 6.365295972142901, 2.4763505714280263, 0.09308428370526858, 39.727902684892925, 27.452876329421997, 38.36171661104475, 52.673803670065745, 55.978696959359304, 48.816445214407786, 47.15595776694161, 38.6845611844744, 37.679994106292725, 37.27018935339791, 39.2756096976144, 33.702522141592844, 37.301939146859304, 36.10833937781197, 35.5460181917463, 33.61412715911865, 34.71390887669155, 33.33746378762381, 34.643151896340505, 33.56036894662039, 32.719702925000874, 32.14125149590628, 34.99310834067208, 32.53490516117641, 35.45531293324062, 32.94277136666434, 34.73322834287371, 33.348674706050325, 34.75292648587908, 34.08169228690011, 35.25383949279785, 35.255163124629426, 33.33558429990496, 35.99601827348982, 36.05122518539429, 34.43250335965838, 36.90057645525251, 36.38216093608311, 35.214498792375835, 36.57338925770351, 36.08616072790963, 35.28409194946289, 36.02987684522356, 37.00358349936349, 37.22848973955427, 35.25659792763846, 36.39350734438215, 36.178933075496126, 35.390204838344026, 34.37591028213501, 34.564199515751426, 35.267200878688264, 35.99873849323818, 34.80902624130249, 33.603795187813894, 35.5351060458592, 36.641863754817415, 36.46419831684658, 37.208701269967214, 37.45907613209316, 40.717034339904785, 42.73022971834455, 47.9267110143389, 47.50512211663382, 46.46130813871111, 44.102936676570344, 44.566951274871826, 38.73125655310494, 36.40481901168823, 37.03279720033918, 36.78680665152413, 35.83781473977225, 34.73708111899239, 34.41505295889718, 35.83400365284511, 35.45995085580008, 34.11900758743286, 33.94562918799264, 35.00550740105765, 32.427048274448936, 35.208582401275635, 34.788449151175364, 35.79030295780727, 36.82354872567313, 37.345139571598594, 36.477855001177105, 37.062476430620464, 36.746267386845176, 37.01975890568325, 35.84866782597133, 35.173209122249055, 36.182963030678884, 36.693811961582725, 35.59766067777361, 35.64536700929914, 36.953236852373394, 35.58087730407715, 35.48895263671875, 33.87232221875872, 35.065529414585654, 35.60287530081612, 36.83869232450213, 35.297376905168804, 35.80100318363735, 36.203713825770784, 40.37231683731079, 44.051863942827495, 48.51565074920654, 47.09896516799927, 47.21719224112374, 51.71894400460379, 50.60737814222063, 49.78619834354946, 52.27755832672119, 51.06819656917027, 52.11662415095738, 48.00737959997994, 47.33286932536534, 50.29556383405413, 55.277342319488525, 54.70901094164167, 55.558650561741416, 56.499415806361604, 55.330843448638916, 56.79380055836269, 55.43497610092163, 56.62909698486328, 29.496645518711635, 0.18083545858306543, 1.8182155724082674, 14.438111748014178, 0.09713694266974926, 0.08459415499653135, 18.825614282063075, 62.28618131365095, 56.006343841552734, 58.94483430044991, 40.04301391329084, 25.093513011932373, 11.128121955054146, 31.43303550992693, 48.751291956220356, 54.68218394688198, 11.300842881202698, 0.09549264197370835, 0.06656580524785177, 0.013615391233802905, 0.05397503497079015, 0.03855112993291446, 0.03559934653873954, 0.040955685012574704, 0.11955166847578116, 0.012535413693902748, 0.033074948604085615, 0.03288660763895937, 0.08890013143952404, 0.02619453226881368, 0.07454375536846262, 0.10560263054711477, 3.9164042472839355, 57.808505058288574, 58.95224802834647, 49.75358697346279, 36.37166220801217, 19.663164036614553, 32.15878874914986, 33.957955292293, 61.09660107748849, 54.098486627851216, 67.16831915719169, 16.73827120235988, 0.09667984755443675, 0.16701167821884155, 8.07107959474836, 2.213955977133342, 0.14199269429913589, 42.73327302932739, 26.55018547603062, 43.75509595870972, 55.24995946884155, 58.11047724315098, 52.04414054325649, 48.851860182625906, 40.475118909563335, 39.52820450919015, 38.09275879178728, 41.01730074201311, 37.150235652923584, 39.774087360927034, 38.44709954942976, 37.401326179504395, 36.33063309533255, 37.80289731706892, 35.36951310294015, 37.190893036978586, 35.999815464019775, 35.063531807490754, 35.524166107177734, 36.243342876434326, 36.08813749040876, 36.68682902199881, 34.50976732798985, 37.230181625911165, 36.61417170933315, 36.25355672836304, 35.56787027631487, 36.77382741655622, 35.98578357696533, 36.2264518056597, 36.88492911202567, 37.61040442330496, 35.28616598674229, 37.32150179999215, 37.49568271636963, 35.79810578482491, 36.85035834993635, 37.954374994550435, 36.92603465488979, 38.07163279397147, 38.10956648417881, 38.68106276648385, 36.4518062046596, 38.15749863215855, 36.20077473776681, 36.1545865876334, 36.198415824345176, 36.83499240875244, 36.31929363523211, 37.05863060270037, 37.53248732430594, 37.000984873090474, 36.839324610573904, 38.829771586826865, 38.72379418781826, 37.85384150913784, 40.98209769385201, 42.16583102090018, 44.5951783316476, 51.00166409356253, 47.56628016063145, 48.98776694706508, 47.10533319200788, 46.98568868637085, 41.00914703096662, 39.043550286974224, 38.361112117767334, 39.07815926415579, 38.130946091243196, 36.77606821060181, 37.29901395525251, 37.24609647478376, 36.67882817132132, 36.87282187598092, 36.9012747492109, 35.64812544413975, 34.384223801749094, 36.97889307567051, 38.09600012642996, 37.611794063023154, 38.26271172932216, 38.987822260175435, 37.417293139866416, 39.67102125712803, 38.012017250061035, 38.24504940850394, 38.18087237221854, 37.15294197627476, 39.27223287309919, 38.15839147567749, 37.98723649978638, 38.45124762398856, 38.81198072433472, 36.55474376678467, 37.39798757008144, 35.64183732441494, 37.40344190597534, 36.49386017663138, 39.05921152659825, 37.929274627140586, 39.2294145992824, 39.83036082131522, 41.722695759364534, 46.43306371143886, 50.5195494379316, 49.43732581819807, 49.62246751785278, 52.48095294407436, 52.661797182900564, 53.592171396527974, 53.98147201538086, 54.07587024143764, 54.28619221278599, 49.290788309914724, 49.53692824499947, 51.29424578802926, 57.789810929979595, 56.17635236467634, 56.75505740301949, 58.745240347726, 56.814169202532085, 58.41775785173689, 58.268649509974885, 58.143272740500315, 32.461685044424875, 0.10909309610724449, 0.964344933629036, 8.36133451121194, 0.24171488253133638, 0.09523208452654736, 22.037195001329692, 66.4735826764788, 60.505351066589355, 63.69006483895438, 47.1405987739563, 27.558952740260533, 16.86596519606454, 39.99506439481463, 55.42328923089163, 63.55718748910086, 16.022235018866404, 0.12738255970180035, 0.05143733435709562, 0.03918913605489901, 0.02021378551476768, 0.028798047386642014, 0.05122416918831212, 0.011337855365127325, 0.2809522013579096, 0.09739213969026293, 0.21519507414528302, 0.09397297458989279, 0.19396084999399527, 0.11249600350856781, 0.34283559929047314, 0.20559982902237348, 5.23569084916796, 69.03167315891811, 64.90066337585449, 57.61501857212612, 43.25304692132132, 21.877150194985525, 41.36887264251709, 43.75024611609322, 64.87445477076939, 59.245336941310335, 73.8841005052839, 18.344776357923234, 0.20054273466978753, 0.5907679796218872, 22.505357674189977, 5.893725207873753, 0.20411869564226695, 49.534322670527864, 28.58305467878069, 48.40843309674944, 56.120686871664866, 61.116042137145996, 53.49556711741856, 51.78057452610561, 42.260215350559776, 41.82284361975533, 40.4884420803615, 42.7673921585083, 38.10927465983799, 42.8615437235151, 40.83934695380074, 39.08570500782558, 38.23308113643101, 39.881475244249614, 37.23758145741054, 39.91704307283674, 38.67492750712803, 37.70425721577236, 37.716027464185444, 38.717797892434255, 38.242019993918284, 38.82911498206002, 36.83264739172799, 38.92230074746268, 38.016081946236746, 39.31691326413836, 37.5163049697876, 38.769593238830566, 38.92303030831473, 38.07901872907366, 39.64777953284127, 40.45089748927525, 36.43344211578369, 40.94668272563389, 38.86800404957363, 38.32711805616106, 39.4245617049081, 40.32265111378261, 39.04841750008719, 39.66829408918108, 40.32983207702637, 40.57489851542881, 38.51957620893206, 40.89836842673165, 39.84183577128819, 39.13188968385969, 37.46758420126778, 38.80031817299979, 38.385312693459646, 38.589794703892295, 39.43726996013096, 39.570112568991526, 39.09817355019705, 41.0295295715332, 41.83794552939278, 40.66401611055647, 43.780623640332905, 45.08375481196812, 46.75495638166155, 51.94416291373116, 50.60055501120431, 51.698005608149934, 49.852789878845215, 48.838686398097444, 43.579455920628135, 40.869338853018625, 40.61978735242571, 42.19066040856497, 40.87144415719168, 40.507858821323936, 39.20871244158064, 41.16907719203404, 40.49814523969378, 39.5918083190918, 38.8568765095302, 39.06558649880545, 35.34890474591936, 38.732837268284385, 39.6559853553772, 39.24753202710833, 40.14781706673758, 40.949069431849885, 40.11937461580549, 41.60401010513306, 40.47449357169015, 40.10216392789568, 40.098265988486155, 38.51424694061279, 40.66904313223702, 40.62159388405936, 39.6784210886274, 39.923633439200266, 41.71620961597988, 38.98525142669678, 38.63690001623971, 36.22656992503575, 39.38104861123221, 39.87908853803362, 41.71945442472185, 40.15965679713658, 40.96410533360073, 40.34682042258126, 43.21196917125157, 49.25156225476946, 52.91584069388253, 51.55760335922241, 52.30471188681466, 56.168052741459434, 55.258210454668315, 55.88867262431553, 57.00036702837263, 56.11395059313093, 55.84339121409825, 49.42733778272356, 49.361104079655235, 52.96268197468349, 60.12844603402274, 58.435427120753694, 59.31642396109444, 61.69866248539516, 61.456260681152344, 61.9973794392177, 62.51996735164097, 61.0719210760934, 36.85332523073469, 0.22898068012935774, 4.588936022349766, 25.53289450917925, 0.8237615429929325, 0.2622919997998646, 23.78803161212376, 73.91798686981201, 64.46374675205776, 73.7448377609253, 51.21954223087856, 31.38655206135341, 20.674557719911846, 49.567423888615195, 65.11237498692104, 74.08005360194615, 22.623645544052124, 0.4466026026223387, 0.21012499263244017, 0.13733809334891184, 0.20423898633037293, 0.09163589642516204, 0.13313026699636663, 0.13904774375259876], [0.12344453244337014, 0.05925609676965645, 0.07433938740619592, 0.04149343419287886, 0.03890420223719307, 0.0691065728398306, 0.043530155438929796, 0.09788440327559199, 2.833207445485251, 48.633387974330354, 50.58639458247593, 38.78495223181588, 34.26994677952358, 18.024249008723668, 56.54918227876936, 43.25614929199219, 52.124680587223594, 52.34608146122524, 61.59631552015032, 15.661547081811086, 0.06583240388759545, 0.07922369960163321, 8.159205334527151, 3.6476257784026007, 0.6845366880297661, 53.086029870169504, 35.234606879098074, 56.97119501658848, 51.04108122416905, 52.50047043391636, 45.345962456294465, 48.4851724760873, 38.8786278452192, 40.67399024963379, 37.32294355119978, 38.69095352717808, 35.80251094273159, 36.77907330649239, 32.97221088409424, 36.14328881672451, 32.96118061883109, 35.05670520237514, 33.47691413334438, 32.083122866494314, 33.32523495810372, 34.8039436340332, 32.66632686342512, 34.822877475193565, 32.09136690412249, 35.64685044969831, 33.17511565344674, 34.83216026851109, 33.904537541525706, 35.035131045750205, 33.05436291013445, 34.29035016468593, 32.75343642915998, 34.546603202819824, 34.74118055616106, 34.650277273995535, 33.331999029432026, 36.35073075975691, 35.4409510067531, 35.31280190604073, 35.17828130722046, 35.81725154604231, 35.29787370136806, 36.90328972680228, 34.87145927974156, 38.96610566547939, 36.645653997148784, 36.10838801520211, 34.46913773672921, 34.52653680528913, 33.826870577675955, 34.93170016152518, 34.262859616960796, 34.95117596217564, 34.65943152563912, 33.18288721357073, 36.50052349908011, 38.69737018857683, 36.49045555932181, 37.53380053383963, 36.87284966877529, 38.13406583241054, 41.53404174532209, 47.197250911167686, 48.08800302233015, 47.959909507206504, 45.93222713470459, 43.9297319820949, 39.84750550133841, 37.731059891836985, 36.38969278335571, 37.05384676797049, 34.60607978275844, 34.29080874579293, 34.96425594602312, 36.51118203571865, 36.19503205163138, 34.68620293481009, 34.364039284842356, 35.140399728502544, 34.18131555829729, 35.391420773097444, 34.699036257607595, 37.238484723227366, 36.10769666944231, 37.53248037610735, 36.847780568259104, 37.07340594700405, 35.87194081715175, 35.55990069253104, 35.230073179517476, 38.07461357116699, 35.66582598005022, 37.34296825953892, 35.997387068612234, 36.60379804883684, 36.819577830178396, 36.522917543138774, 36.5405763898577, 37.53465516226632, 34.80990866252354, 34.7817337172372, 33.802489348820274, 35.55811847959246, 35.14949492045811, 35.972262382507324, 37.8936824798584, 45.39069495882307, 47.26676068987165, 47.80728885105678, 49.58432885578701, 45.45397220339094, 47.65683255876814, 48.93968193871634, 47.74429995673043, 48.13213103158133, 46.98304837090628, 49.42638240541731, 50.41362067631313, 54.83537782941546, 53.452960763658794, 53.46892772402082, 51.02449934823172, 52.73027515411377, 52.32494156701224, 55.50283568246024, 54.755181721278596, 64.0268440246582, 42.12351301738194, 0.035518628012921126, 0.5532811454364231, 9.407022765704564, 0.7082343878490585, 0.23618151087846073, 19.57866178240095, 61.75064195905413, 52.847449575151714, 57.11253874642508, 30.71468210220337, 34.909333910260884, 30.193313598632812, 35.277209758758545, 47.242438520704, 53.56215865271432, 14.19327199459076, 0.2503023131617478, 0.025932819615783434, 0.014460071488948805, 0.024327918055600355, 0.013120948702895215, 0.06347582462642874, 0.06984755343624524, 0.05643843939261777, 0.02773816042047526, 0.04638621111267379, 0.05940037367067166, 0.03406701429880091, 0.05232405749016574, 0.1354473962315491, 0.16380640092704976, 3.832880820546831, 56.02754626955305, 56.748133523123606, 46.918315478733604, 42.397650718688965, 20.128757613045828, 45.60903862544468, 42.19285603931972, 57.32367365700858, 55.53154216493879, 65.15194497789655, 17.59766956738063, 0.13704094929354532, 0.06627827603369951, 5.420657541070666, 0.6817236446908542, 1.1449311120169503, 52.1942390033177, 38.05245923995972, 57.83751378740583, 53.07668801716396, 54.107891014644075, 48.27857821328299, 49.614553519657676, 39.89284944534302, 42.422400202069966, 37.9626989364624, 40.51673167092459, 37.68856470925467, 39.224884373801096, 34.83020782470703, 38.66783687046596, 34.88930572782244, 36.42105000359671, 36.67836264201573, 35.98535278865269, 35.36972154889788, 37.05757795061384, 34.80128594807216, 37.09668241228376, 34.59664412907192, 37.25371170043945, 34.99731200081961, 36.21657146726336, 34.92220197405134, 35.94329881668091, 34.824687480926514, 35.50540944508144, 35.56797449929373, 35.601068769182476, 37.234548568725586, 35.490637574877056, 34.68697418485369, 36.91046026774815, 37.652236052921836, 38.238306181771414, 36.63775389535086, 36.596526759011404, 37.48162303652082, 37.73480497087751, 35.96532460621425, 38.92744588851929, 36.63195562362671, 37.87109041213989, 37.45146438053676, 36.56811210087368, 36.8948198727199, 35.13732515062605, 36.35823481423514, 36.63012477329799, 36.727958883558, 36.393493447984966, 37.82163313456944, 39.80784865788051, 39.20765284129551, 40.70009810583932, 39.01946088245937, 40.481869084494456, 43.59054524557931, 49.49618053436279, 50.95985678264073, 48.92950630187988, 48.16628837585449, 46.561528955187114, 40.56951366152082, 39.37700128555298, 38.62236091068813, 39.381489821842735, 37.92157254900251, 36.120123522622244, 37.063223361968994, 37.70377779006958, 38.32133020673479, 36.83024678911482, 36.89295775549752, 36.95862170628139, 36.27390105383736, 37.185171195438926, 36.04976258959089, 38.26240948268345, 37.5568060193743, 38.34556899751936, 39.239416531154085, 37.690663065229145, 36.62102958134243, 37.3215400150844, 37.888370582035606, 39.70638063975743, 37.2000264440264, 38.34306764602661, 37.45294087273734, 38.1030455998012, 39.94953979764666, 38.2829726764134, 37.67925064904349, 39.19326312201363, 37.12196690695626, 36.67485727582659, 36.87580265317644, 37.201054777417866, 37.985183307102744, 38.44210032054356, 38.64683941432408, 46.420313767024446, 49.988988467625205, 51.35088402884347, 49.90711784362793, 47.127619538988384, 49.049911635262625, 50.10863644736153, 49.03549412318638, 48.405066694532124, 49.811705180576865, 50.51817716870989, 51.93385526112148, 55.08685050691877, 54.80193267549787, 56.1809937613351, 53.70603500093733, 54.30001565388271, 56.719628538404194, 57.93815844399588, 58.94647407531738, 68.52045944758824, 43.87691872460501, 0.07721016728984458, 0.08110978946621929, 3.7443798780441284, 0.3370415616248335, 0.3017272337206772, 21.779192754200526, 67.82792554582868, 57.13342155729021, 64.79202829088483, 33.749273095812114, 25.169345651354107, 29.821505069732666, 44.36625255857195, 54.78435720716204, 63.14124747685024, 19.345442022596085, 0.3114773748176438, 0.024141183522130762, 0.036175843461283615, 0.07054644450545311, 0.028760046032922607, 0.03165447286197117, 0.014964857438047017, 0.184558349528483, 0.14516684040427208, 0.17277619961116994, 0.16793354946587766, 0.3942112039242472, 0.1614272535911628, 0.2473404806639467, 0.18675825505384377, 5.5522942032132825, 65.94735390799386, 63.693448611668174, 53.216603892190115, 47.655297006879536, 25.986321789877756, 63.00873143332345, 53.555203505924766, 63.72737666538784, 58.96831921168736, 71.52099731990269, 19.12749787739345, 0.2411861409034048, 0.49366207314389093, 19.99894094467163, 6.335739203861781, 0.9304888589041573, 59.423238618033274, 39.18597098759243, 60.06473800114223, 53.87008891786848, 55.28586775915963, 48.8551709992545, 53.23954336983817, 41.37063748495919, 44.801147256578716, 40.03034387316023, 42.3109267779759, 38.8552645274571, 41.73472656522478, 36.75997618266514, 41.96692841393607, 35.87694699423653, 39.3900500025068, 37.84454829352242, 36.80199541364397, 38.69004678726196, 39.44977324349539, 36.417304924556184, 40.815149852207725, 35.94187443596976, 40.967610699789866, 36.15822744369507, 38.869893959590364, 36.56677804674421, 37.753947257995605, 35.59146635872977, 37.92830882753645, 37.1735885483878, 38.60079370226179, 38.86235169001988, 39.69246687207903, 36.856809752328054, 38.7698781149728, 40.17825712476458, 38.75352552958897, 38.29613951274327, 38.751753738948274, 39.44512142453875, 39.79053027289254, 37.93547242028372, 42.14922135216849, 39.905780042920796, 39.473553453172954, 39.16028697150094, 37.49329948425293, 37.59316941670009, 38.23231683458601, 37.94385889598301, 38.62014790943691, 38.26830850328718, 37.74013771329607, 40.189704281943186, 43.09800134386335, 41.36816392626081, 42.31039524078369, 40.4062032018389, 43.72499288831438, 46.0101546560015, 52.31800726481846, 52.42746223722185, 51.59341090066092, 49.84734943934849, 49.922883306230815, 42.85150357655117, 42.77313831874302, 41.269318853105815, 42.078189917973106, 39.80835935047695, 38.6140057018825, 40.129446029663086, 39.80830723898751, 40.609055859701975, 38.81338426045009, 39.147491863795686, 38.85693556921822, 38.294621331351145, 39.44057035446167, 38.12374080930437, 41.172916071755544, 39.85668754577637, 40.30856711523873, 41.79092012132917, 40.73573541641235, 38.616646017347065, 39.39970799854824, 39.900006089891704, 41.64580699375698, 39.441456249782014, 41.46167973109654, 40.649014949798584, 41.332335540226524, 41.11698307309832, 40.574068205697195, 40.875314303806846, 42.57606656210763, 38.99888031823294, 39.52934053965977, 39.34003686904907, 40.05775799070086, 39.78311307089669, 40.33693313598633, 41.912947859082905, 49.657180718013215, 52.312049184526714, 52.5490939276559, 52.00891317640032, 49.402101925441194, 49.61402545656477, 51.64881236212594, 49.911470890045166, 50.40748541695731, 50.560866900852744, 53.60378878457205, 54.86190605163574, 58.8234075818743, 57.292417185647146, 57.944859981536865, 56.467183113098145, 56.68734720775059, 57.41623408453805, 61.87768282209124, 60.89287294660296, 70.21230411529541, 46.83440555844988, 0.42099764943122864, 1.6776256135531833, 17.539791073117936, 1.932315958397729, 0.4053606470780713, 24.492495570863994, 74.41852814810616, 62.08249487195696, 70.63247558048793, 39.426423822130474, 47.27037027903965, 43.39866726739066, 53.29259981427874, 62.792413166591096, 74.46479620252336, 26.935770545686992, 0.41637479034917696, 0.08515543916395732, 0.20499735777931555, 0.1992341120328222, 0.0849771269464067, 0.10326392389833927, 0.11555561290255614], [0.086902666836977, 0.027131604396605065, 0.07506138937813894, 0.03258523970310177, 0.03662541023056422, 0.03425162332132459, 0.06373863480985165, 0.033704069310000966, 2.4185689176831926, 52.65398393358503, 51.170067582811626, 44.90517915998186, 26.834677730287822, 27.85170292854309, 39.217352526528494, 38.395634242466514, 56.57729121616909, 47.317499910082134, 60.38709967476981, 17.04363063403538, 0.040335327586425204, 0.10319721033530575, 2.0134537645748685, 0.19057383388280869, 2.452642015048436, 60.824176107134136, 47.286278179713655, 49.0091986656189, 51.15629277910505, 55.23211996895926, 46.322410174778526, 46.19343076433454, 38.19323321751186, 41.08944388798305, 39.082956995282856, 39.760875361306326, 36.87900577272688, 35.73757307870047, 34.922118595668245, 35.61148411887032, 34.98784160614014, 35.05259881700788, 32.68849161693028, 34.47548491614205, 33.401668616703574, 34.687613419124055, 34.93086290359497, 33.71915265492031, 33.545287881578716, 36.7238073348999, 33.473495619637625, 33.13352026258196, 33.49528169631958, 34.348430156707764, 33.89504630225045, 34.05723810195923, 35.0195358140128, 34.14863123212542, 35.86318261282784, 33.60203034537179, 35.65006399154663, 34.89819942201887, 33.423298358917236, 35.00561509813581, 35.250375815800254, 33.73653704779488, 35.582041127341135, 35.71181263242449, 35.64328254972185, 37.11535569599697, 35.34919309616089, 36.77385868344988, 35.51908349990845, 34.97722823279244, 33.54504816872733, 34.93482685089111, 34.563796520233154, 34.40883779525757, 33.283702101026265, 34.52819047655378, 37.27927759715489, 37.215423652103965, 37.7219021660941, 36.55222504479544, 36.85941880089896, 37.9250397000994, 41.564794472285676, 46.27213648387364, 48.141910621098106, 47.667977469308035, 46.95830583572388, 43.843984263283865, 41.17827660696847, 36.67823757444109, 37.37731320517403, 39.62135205950056, 35.75607960564749, 33.368355478559224, 35.31237459182739, 34.37703936440604, 34.9329890523638, 33.63785873140608, 32.99873215811593, 34.279083660670686, 32.4993234361921, 35.6932817867824, 36.14548444747925, 36.36281367710659, 35.7085782459804, 38.95262616021292, 37.51217426572527, 35.80052375793457, 35.919629778180806, 36.15587895257132, 34.83588102885655, 35.1872410093035, 34.47964688709804, 35.47995124544416, 35.04089110238211, 36.83251537595476, 35.783024719783235, 36.33842550005232, 35.61336708068848, 35.4056750025068, 36.699721404484336, 34.89378384181431, 36.220521518162315, 33.65873806817191, 34.91066796439034, 37.51831299918038, 35.62399435043335, 39.157344409397666, 47.38794074739729, 48.787992341177805, 47.94942814963204, 46.987734930855886, 48.464209760938374, 46.62153359821865, 47.21204710006714, 50.15169790812901, 53.48725707190377, 52.69421052932739, 52.24402979442051, 51.296500478472026, 51.16636419296265, 48.56735576902117, 46.94339500154768, 45.40313570840018, 46.74382536751883, 52.7337839944022, 56.973161356789724, 59.73635918753487, 51.35729374204363, 0.1805312441928046, 0.30171705569539753, 3.074243711573737, 0.35462859219738413, 0.09076372786824193, 16.991242953709193, 63.74535860334124, 54.65467255456107, 58.01757287979126, 60.38239574432373, 82.0098658970424, 25.974124227251323, 24.19568416050502, 42.45094687598092, 59.71277700151716, 19.605957780565532, 0.1773555510278259, 0.044694908295891116, 0.06182214657643011, 0.0544538974895009, 0.05692596001816647, 0.011179581983014941, 0.02102052972518972, 0.05880621448159218, 0.025737208147932376, 0.06566139949219567, 0.08055411678339754, 0.032051945105195045, 0.03471498470753431, 0.14111344862197125, 0.0601498902376209, 4.400898660932269, 62.40867110661098, 57.43252413613455, 51.152606759752544, 31.987147399357386, 30.586904730115617, 42.39346790313721, 38.7493531363351, 60.07665416172573, 53.511812005724224, 63.981868335178916, 18.92863174847194, 0.09097537651125874, 0.060184488738221784, 2.9077963573592047, 1.127331324986049, 3.057482268129076, 59.46451786586216, 49.00454337256295, 50.78984131131853, 50.532500880105154, 57.25570985249111, 48.32833078929356, 47.562896387917654, 40.27137688228062, 42.09987524577549, 41.18493298121861, 43.22458709989275, 39.00090224402291, 39.17058767591204, 35.969166960035054, 37.26225798470633, 35.45651844569615, 36.58552776064192, 35.461885929107666, 36.17407628468105, 34.453622409275596, 37.417275769369944, 35.106760025024414, 36.19354166303362, 35.54923868179321, 37.485962186540874, 35.118036951337544, 36.358825411115376, 35.83449002674648, 37.17160831178938, 36.0684289251055, 35.8804349899292, 35.595906257629395, 35.75379364831107, 35.925646918160574, 35.79333584649222, 37.030028343200684, 36.66638742174421, 35.118697030203684, 36.72534983498709, 36.91254472732544, 36.826609407152446, 36.568581104278564, 38.178100040980745, 36.362990856170654, 39.22122614724295, 35.779536724090576, 38.1493900844029, 36.855402742113384, 35.07223442622593, 35.4226598739624, 35.18008436475481, 36.40777547018868, 35.55305324281965, 34.77822835104806, 36.3352814401899, 38.248391492026194, 40.23927967888968, 39.916188444410054, 39.273820536477224, 39.76972736631121, 40.25734152112688, 42.76832669121878, 47.8977370262146, 49.633754866463796, 48.338985851832796, 49.27182667595999, 44.76771947315761, 42.946752956935335, 38.0180378641401, 39.49343572344099, 41.23571389062064, 38.37417125701904, 35.251286029815674, 36.339415618351524, 35.44998019082205, 37.451843057359966, 35.45707082748413, 34.83440453665597, 36.27255310331072, 34.801331111363, 36.85453769138881, 37.091401781354634, 38.27735505785261, 38.04604952675955, 40.22350031988961, 38.512266704014365, 38.09982163565499, 37.36464663914272, 37.2048728125436, 36.76759488242013, 36.278851645333425, 36.19853394372122, 37.86730364390782, 36.09836176463536, 38.83608055114746, 37.93274872643607, 37.12962729590279, 37.12787287575858, 37.387742451259065, 36.40934576307024, 36.7211913381304, 37.2566751071385, 35.91879252025059, 37.58579042979649, 37.94614485331944, 36.38959550857544, 41.72935560771397, 50.01203216825213, 49.19806112561907, 50.13598108291626, 49.33727870668684, 48.741512366703574, 48.61269276482718, 48.02443395342146, 51.7917993409293, 54.825410638536724, 55.14358949661255, 52.89952632359096, 55.04388632093157, 53.73932729448591, 51.51294033867972, 49.08262722832816, 48.42125252314976, 49.85426984514509, 54.861624649592805, 59.641648292541504, 62.59571661267962, 52.84274217060634, 0.43089796389852253, 1.3250629433563776, 6.493706498827253, 0.15847117507031985, 0.15655928051897458, 18.82404398918152, 68.21784455435616, 58.314528465270996, 65.00820064544678, 44.369625908987864, 70.29931640625, 33.55594989231655, 29.942143167768204, 50.47836399078369, 66.37284769330705, 25.765553201947892, 0.16556778284055845, 0.04846683696710637, 0.025163362600973675, 0.06507187469729356, 0.015525961793693048, 0.03460672105263386, 0.050946234459323544, 0.1304778600377696, 0.14394610162292207, 0.16817183739372663, 0.08457567848797355, 0.12995807507208415, 0.16437615321150847, 0.14349041107509816, 0.24613206407853536, 6.073845965521676, 72.50556400844029, 62.466410636901855, 58.37350477491106, 38.11194971629551, 37.530941350119456, 49.32853439876011, 48.425758429935996, 66.89393479483468, 56.453919001988, 68.70805386134556, 20.483673334121704, 0.1547656681920801, 0.25920015999249046, 8.736882039478846, 2.223076356308801, 3.227837984051023, 63.905403409685405, 50.66526705878121, 55.91778905051095, 54.01477820532662, 60.53991140638079, 50.0029091835022, 50.351736545562744, 42.50603566850935, 44.746009826660156, 43.48876803261893, 45.66952616827828, 40.79343673161098, 41.89226654597691, 38.292262417929514, 40.00312777927944, 37.78333466393607, 39.187906060900005, 38.4582896232605, 38.48235123498099, 37.49007552010672, 38.79252576828003, 39.20563786370413, 37.25214488165719, 38.285137040274485, 40.26188564300537, 37.29389313289097, 38.25685439790998, 39.06231737136841, 40.03537089484078, 37.669248717171804, 37.5946980203901, 40.039612770080566, 37.845830236162456, 39.431673186165945, 37.17652416229248, 39.62479836600167, 38.767901352473665, 36.6587096623012, 39.77199942725045, 38.49506296430315, 37.722544874463765, 37.82225152424404, 40.462386335645405, 37.8836874961853, 40.5691419328962, 38.42207908630371, 41.350115980420796, 38.94059535435268, 37.39899505887713, 37.631929942539756, 37.43033143452236, 38.750648975372314, 36.43500893456595, 37.923615319388254, 38.32191385541643, 40.4901304926191, 42.492663860321045, 40.658346380506245, 42.68441677093506, 41.9519932610648, 42.23101554598127, 44.56604453495571, 49.541055474962505, 51.432862349918906, 51.84870856148856, 51.62379537309919, 47.63973651613508, 46.459373065403526, 41.62114436285836, 42.27268736703055, 44.560201099940706, 40.89708648409162, 35.96323667253767, 37.844079290117534, 38.17243031093052, 39.90328911372593, 37.22748572485787, 36.40058061054775, 39.5732045173645, 35.86611475263323, 39.057752404894146, 39.369966234479634, 38.96556370598929, 38.92169278008597, 42.392085211617605, 41.13751152583531, 40.20436845506941, 39.268477371760774, 38.99664647238595, 38.937836919512065, 39.5768141065325, 38.14528717313494, 39.8956287247794, 38.507472446986604, 40.967770508357454, 39.474797180720735, 40.52629239218575, 39.76190022059849, 38.84190661566598, 39.267629691532676, 38.95985576084682, 39.20934125355312, 37.51429346629551, 39.11311217716762, 40.07145289012364, 38.73908717291695, 43.74946444375174, 53.62649202346802, 51.82650211879185, 51.72483607700893, 49.61893435886928, 51.887872082846506, 48.87921176637922, 50.000591959272114, 54.11576679774693, 58.696234703063965, 57.63767317363194, 56.96183231898716, 56.84942436218262, 57.4460904938834, 53.37243809018816, 52.46366582598005, 51.183137144361226, 53.20044585636684, 56.699749742235454, 62.409101894923616, 63.5065073285784, 57.03989880425589, 0.5804782403366906, 2.3456267288752963, 11.705897671835762, 0.835373611322471, 0.2821348064712116, 21.78976443835667, 76.36130005972726, 65.99476146697998, 70.84419413975307, 74.3720030103411, 95.39832196916852, 38.365322726113455, 41.39688777923584, 58.24321215493338, 77.01489625658307, 34.11788892745972, 0.3101476090294974, 0.15368575256850037, 0.14027017887149537, 0.16286713204213552, 0.10169587696769408, 0.1234902385622263, 0.08352920785546303], [0.004160178351282541, 0.02533428217949612, 0.0533451102008777, 0.06151660904288292, 0.08362091186323337, 0.03372577564524753, 0.2583489513822964, 0.17381948791444302, 5.825564682483673, 57.61508805411202, 52.100365366254536, 44.24497870036534, 33.56324897493635, 21.56951870237078, 29.072266919272288, 38.16292864935738, 50.876728534698486, 49.58474227360317, 59.16061060769217, 21.217767885753087, 0.18838402495852538, 0.07095081066446644, 1.6484960509198052, 0.3898463509976864, 7.630602887698582, 68.03492627825055, 53.5720876285008, 57.18144055775234, 51.00515903745379, 51.475162982940674, 42.91685833249773, 44.503055640629356, 37.49941042491368, 41.334096908569336, 38.453946999141145, 37.87488065447126, 36.2037798336574, 37.15801068714687, 34.84322874886649, 37.66685158865792, 35.250379289899556, 36.273133277893066, 33.794995716639924, 35.64522457122803, 33.300294399261475, 34.63234397343227, 34.23215552738735, 35.622351101466585, 32.38085317611694, 35.15939957754952, 33.40394415174212, 34.97803769792829, 34.32182550430298, 34.766364301954, 32.660268034253804, 34.185501847948345, 32.91227224894932, 34.402587890625, 33.75319535391671, 34.07113797324044, 33.765413761138916, 34.72161790302822, 33.31025811604091, 33.92992973327637, 34.465413502284456, 35.351169858660015, 33.04996122632708, 34.942501136234824, 33.945097650800435, 36.9785977772304, 35.3984488759722, 38.53268051147461, 36.52239295414516, 34.91258219310215, 33.85445840018136, 33.50806985582624, 33.90127188818795, 34.50231191090175, 34.204195976257324, 33.572059290749685, 35.30620806557791, 39.156503677368164, 38.22299582617623, 37.23166854040963, 37.72455985205514, 38.17953136989048, 41.91788108008248, 47.96779571260725, 46.27428000313895, 47.89103201457432, 46.6192615372794, 45.389329637799946, 40.61367293766567, 38.858842849731445, 37.774680682591026, 37.653240067618235, 35.523259367261616, 32.55971370424543, 34.928834029606406, 35.76532070977347, 35.63196740831648, 33.693159443991526, 33.34453705378941, 34.07371228081839, 32.89817087990897, 33.02218580245972, 34.41402115140642, 35.08371632439749, 38.20638615744454, 37.35476630074637, 37.78155592509678, 37.08474888120379, 35.643018518175396, 36.31351620810372, 34.62076480048043, 35.52329063415527, 34.230324677058626, 34.14757163184029, 34.955032212393625, 35.381613390786306, 34.88282653263637, 35.05123349598476, 35.37173305238996, 34.55536488124302, 33.854517459869385, 34.578752517700195, 34.67926515851702, 33.96713733673096, 36.000492913382395, 35.81939159120832, 35.852656091962544, 34.6610608782087, 40.43374586105347, 46.912100315093994, 50.88072722298758, 50.38776642935616, 50.75803593226841, 50.77440936224801, 51.10066202708653, 49.5794164793832, 49.92479753494263, 48.72675439289638, 47.85443932669503, 43.736794403621126, 40.65206520898001, 39.46974236624581, 39.14424358095442, 40.522119998931885, 44.32602596282959, 49.87426676068987, 57.73937048230852, 58.991915294102256, 57.02758659635271, 0.5399412555353982, 0.5078132195132119, 1.4634445692811693, 0.1888754471604313, 0.11791634479803698, 19.540656873158046, 62.12098094395229, 55.75601414271763, 59.960535866873606, 58.017131669180735, 52.344035216740195, 20.189318111964635, 31.826741286686488, 43.69840213230678, 60.85328211103167, 25.681038788386754, 0.1435265498501914, 0.051141353989286084, 0.040742234859083376, 0.03452449617907405, 0.02988325558336718, 0.0367915427445301, 0.05830801371484995, 0.10756266715803317, 0.0442416808301849, 0.040278381534985135, 0.051670607911156755, 0.09818438360733645, 0.028117658271055137, 0.2497418975191457, 0.1658891641667911, 7.581671067646571, 64.23028033120292, 56.975513322012766, 51.8012558392116, 44.70759323665074, 25.338407482419694, 26.81558755465916, 44.623210838862825, 55.426266533987864, 53.92449331283569, 63.31315285818917, 22.087480851582118, 0.09303682696606431, 0.11335371248424053, 2.3665138823645453, 0.6846226177045277, 7.881821087428501, 69.683671270098, 54.64417035239083, 60.585262298583984, 51.64949675968715, 52.95642512185233, 44.02387659890311, 46.45987680980137, 39.0084410394941, 42.272736004420686, 40.08568974903652, 39.416314193180625, 37.97893687656948, 39.58939034598214, 36.58390883037022, 40.19418239593506, 36.785278047834126, 38.28307689939226, 35.565858772822786, 36.52257013320923, 35.98330307006836, 37.83092982428414, 35.14582974570138, 36.881420271737234, 34.73447901862008, 37.12579189028059, 35.942840235573904, 36.7936749458313, 35.79194620677403, 36.947355202266145, 33.17623431341988, 35.7928911617824, 34.65720462799072, 36.86329589571272, 34.82921075820923, 36.46764809744698, 34.30672359466553, 36.304924760546, 34.76721545628139, 36.48820434297834, 35.24937874930245, 36.69208880833217, 34.85502331597464, 38.83569145202637, 36.17207520348685, 39.66304472514561, 37.43295785358974, 39.27508858272007, 38.17320850917271, 36.14856597355434, 35.01954623631069, 36.861972263881135, 36.141510077885215, 35.63236345563616, 35.59578466415405, 35.862800461905344, 36.76398181915283, 41.66179827281407, 39.8588901247297, 39.899696895054404, 40.525086879730225, 40.67853784561157, 43.61650371551514, 49.752589906964985, 46.630389077322825, 48.96175636563982, 49.207618372780935, 47.05527489525931, 42.067333357674734, 39.28075136457171, 39.19612577983311, 40.2490245274135, 37.97525780541556, 34.808508600507466, 36.14061723436628, 36.89654997416905, 37.47761740003313, 36.12112406321934, 35.502522468566895, 36.40938050406319, 36.49880381992885, 35.87061023712158, 36.37347568784441, 37.29366731643677, 38.67090450014387, 38.181376116616384, 40.6129537991115, 37.5233712877546, 37.81163467679705, 37.161168643406455, 36.12587315695626, 37.00453887666975, 37.25089768001011, 37.93625061852591, 37.67190987723214, 36.45447083881923, 37.124013151441304, 36.447988169533865, 37.24351521900722, 37.06784043993269, 36.02393960952759, 36.77885096413748, 37.09612308229719, 35.67322581154959, 36.93813146863665, 38.63165760040283, 38.16920634678432, 36.979167529514854, 41.81270967211042, 47.934836932591026, 52.594396182468955, 53.418935435158865, 53.04889522280012, 52.39156436920166, 52.251419203622, 51.33795690536499, 52.72291701180594, 51.371301310403005, 50.57315479006086, 46.11211947032383, 43.75805589130947, 40.25590671811785, 41.21796471732003, 41.44798830577305, 47.24808740615845, 51.59313644681658, 60.35140677860805, 60.20617553165981, 61.90895666394915, 0.8798947366220611, 1.1005316887583052, 3.078263895852225, 0.09978639800101519, 0.10344427172094584, 21.083806616919382, 66.89685303824288, 61.02406883239746, 64.51455892835344, 70.71431146349225, 68.60865293230329, 24.77497979572841, 37.23837007795061, 50.70750863211495, 68.6296295438494, 31.77818727493286, 0.25381606604371754, 0.10837331973016262, 0.019063836595575725, 0.08086150671754565, 0.02553570699611945, 0.01009091325769467, 0.013048220775090158, 0.20818716447268212, 0.08455099338399512, 0.13777270859905652, 0.16257378778287343, 0.33543495354907854, 0.1244920412344592, 0.5708228498697281, 0.2923010523830141, 8.952257088252477, 74.10162081037248, 63.402562277657644, 59.36890370505196, 46.1096111706325, 30.10596432004656, 39.05384404318673, 52.295731340135845, 61.010061264038086, 58.41587488991873, 68.13660621643066, 26.026605708258494, 0.20806797301130636, 0.43038577852504595, 6.804604513304574, 1.5126268501792635, 8.864932128361293, 72.33956459590367, 56.77205964497158, 61.41988686152867, 53.47308274677822, 54.74673965999058, 45.492152554648264, 49.17103263310024, 40.68899835859026, 46.23166670118059, 43.41658319745745, 42.0463741166251, 39.67885535103934, 41.695351123809814, 38.28442137581961, 43.09137623650687, 38.32245928900582, 40.31455298832485, 37.997610160282676, 40.19890022277832, 38.15678991590227, 37.98834821156093, 38.90052856717791, 38.52306767872402, 36.077343463897705, 39.15067413875035, 38.23193120956421, 40.54205438068935, 37.373286724090576, 39.25109645298549, 35.72045966557094, 37.966593401772634, 35.731524671827046, 38.29106732777187, 36.23961864198957, 39.02431072507586, 37.264748913901194, 39.05364949362618, 36.29719488961356, 37.28885221481323, 36.66179118837629, 38.52145569665091, 35.5300303867885, 39.4742100579398, 37.101004191807334, 40.539038862500874, 39.300282750810894, 42.32028252737862, 40.9057856287275, 38.78079373495919, 37.1612937109811, 37.77521916798183, 37.524851254054475, 37.80945989063808, 38.49855443409511, 38.09239748546055, 38.20420094898769, 44.926259994506836, 42.263911792210166, 42.113358225141255, 42.340282917022705, 43.5068541935512, 46.64017908913748, 53.15190921510969, 50.55001034055437, 51.263090065547395, 49.48871469497681, 51.3247275352478, 45.318899222782676, 42.329461097717285, 41.937693868364605, 42.543121678488596, 39.624520438058035, 36.48207950592041, 40.496634006500244, 38.39517566135952, 40.24458115441458, 37.63763788768223, 36.841384751456125, 39.25282308033535, 37.89912986755371, 36.21439320700509, 37.47672455651419, 37.85779850823538, 42.028840337480815, 41.62018551145281, 42.4488068308149, 38.43401261738369, 39.453626019614084, 39.23680748258318, 37.75598308018276, 40.29180111203875, 39.138556480407715, 38.11253336497715, 39.25102002280099, 37.02146468843733, 39.47391823359898, 38.00655944006783, 39.45287561416626, 38.471004826681956, 37.70377084187099, 39.80140767778669, 40.558427810668945, 38.62353515625, 39.62971421650478, 39.098218713487896, 39.77685274396624, 38.33335753849575, 44.28645944595337, 50.45963512148176, 56.614015919821604, 55.653833934238975, 56.32478673117501, 56.0329589162554, 55.40059641429356, 53.339871883392334, 56.277337482997346, 53.67187418256487, 53.1283027103969, 49.09419250488281, 45.29750919342041, 42.89530154636928, 43.13526105880737, 42.98687880379813, 49.37971135548183, 53.45772722789219, 65.40329606192452, 63.94465378352574, 64.21210384368896, 1.5136296706540244, 1.5579561378274644, 5.663327285221644, 1.0075118115970065, 0.2109127039355891, 22.85992772238595, 72.25412954602922, 65.8554014478411, 71.51816245487758, 69.6817535672869, 57.5731452533177, 32.21115732192993, 45.71267795562744, 60.43993377685547, 75.45592199053083, 39.899259158543174, 0.5191517025232315, 0.22687623091042042, 0.13609500362404756, 0.16317700541445188, 0.19303756739412034, 0.1487688978335687, 0.12236673384904861], [0.009033981311534132, 0.02846545326922621, 0.03785657470247575, 0.0797983780503273, 0.028260623903146813, 0.030217657996607677, 0.15306019756410802, 0.17814661429396697, 8.311457736151558, 59.389248030526296, 45.01669774736677, 39.63595717293875, 15.49319222995213, 38.361146858760286, 59.12395886012486, 38.33911412102835, 53.59329353060041, 49.26796347754342, 58.131644930158345, 23.437802450997488, 0.05879161919334105, 0.07023716824395315, 0.2845944959138121, 0.8398160615137645, 13.565660323415484, 69.56044496808732, 47.14229066031319, 58.043354170663015, 46.300836018153596, 46.79531151907784, 42.96093075616019, 40.69970900671822, 35.456045968191965, 40.14891835621425, 35.13530669893537, 38.50482170922415, 35.137940066201345, 36.51666416440691, 35.00961031232561, 36.33045939036778, 33.10734639848982, 33.03650256565639, 32.414913245609824, 34.84504222869873, 33.35312155314854, 34.90694372994559, 30.67408377783639, 34.206547941480366, 33.15690789903913, 34.41402115140642, 32.460705348423545, 33.661663259778706, 33.641252926417756, 34.24601023537772, 32.015218121664866, 34.56743042809622, 32.70998239517212, 33.86024277550833, 33.86722224099295, 34.995154585157124, 34.688325609479634, 33.82194430487496, 34.82459715434483, 33.298150879996165, 33.945886271340505, 34.18726669039045, 34.12063346590315, 36.92305735179356, 34.685726983206614, 37.265777247292654, 36.312637260981965, 35.08282000677926, 35.960968085697715, 37.22037424360003, 34.95315967287336, 34.241816997528076, 33.5148651940482, 35.20279107775007, 34.26502398082188, 33.85043886729649, 36.575595310756135, 39.26295355388096, 39.66220399311611, 38.628006322043284, 37.588024275643484, 39.12361090523856, 42.64108433042254, 46.5470141683306, 45.49214908054897, 47.73378733226231, 46.04572248458862, 44.44388825552804, 41.2047700881958, 39.99394573484148, 39.190153803144185, 38.04204041617257, 36.96432270322527, 33.59294557571411, 34.00195128577096, 34.90606130872454, 34.69889381953648, 34.94734055655343, 33.41164970397949, 33.70058706828526, 34.11856985092163, 34.9248422895159, 35.45049088341849, 35.69676283427647, 36.814047064099995, 36.16854551860264, 35.191396032060894, 36.21705436706543, 35.73107303891863, 35.42145088740757, 35.29088033948626, 36.2411333492824, 35.26435906546456, 36.978132247924805, 34.68068259102957, 34.57131447110857, 35.21941464287894, 35.249778270721436, 35.511030537741526, 36.1572025844029, 35.59557621819632, 34.609828335898264, 32.76212862559727, 34.493001324789866, 33.75406387874058, 35.489306994846885, 35.49641500200544, 35.17565141405378, 36.103444371904644, 38.62475803920201, 41.47791419710432, 45.82600654874529, 48.82944876807076, 48.66765996388027, 49.91824190957205, 47.74634967531477, 46.87091139384678, 42.00120040348598, 38.6099305834089, 36.04956109183175, 40.18478495734078, 42.19572564533779, 44.10526084899902, 42.9793712752206, 44.10605294363839, 48.92521578924996, 56.64951079232352, 55.85027340480259, 60.940155438014436, 1.798699168222291, 1.5341802707740237, 3.976022396768842, 0.38705271376030786, 0.11240102896200758, 15.960474218641009, 63.403986658368794, 54.253000668116975, 61.57700647626604, 35.14824424471174, 21.521431956972393, 22.742577859333583, 34.85098988669259, 42.03259236471993, 58.11879423686436, 28.157376766204834, 0.2615276165306568, 0.03492509646873389, 0.01958976060684238, 0.04241306288167834, 0.04345486519326057, 0.034737515462828536, 0.04609918062176023, 0.04527004475572279, 0.096325787981706, 0.055366089434495995, 0.043110763121928485, 0.06994459751461234, 0.028684280812740326, 0.13642775719719274, 0.2993270382285118, 8.976171919277736, 65.95826952798026, 51.53425741195679, 44.97898987361363, 20.729608297348022, 25.96611816542489, 55.638881410871235, 42.455345085689, 55.37021541595459, 54.23110342025757, 62.382295744759695, 25.47306878226144, 0.057815845124423504, 0.13150472779359135, 3.2294067570141385, 0.3797564267047814, 14.569141745567322, 71.87036664145333, 49.16436931065151, 61.21275411333357, 48.78127343314034, 49.31971713474819, 44.18976484026228, 43.57290029525757, 38.829205308641704, 42.57459701810564, 37.31013454709734, 40.85020351409912, 36.9009690284729, 39.178421769823345, 36.81435278483799, 37.93445798328945, 34.43747826984951, 35.95008373260498, 35.61230748040335, 37.415080138615195, 34.35614960534232, 36.29632636478969, 34.11253534044538, 36.830107825142996, 36.24256815229143, 36.07591560908726, 34.44649703162057, 35.963128975459504, 34.58677421297346, 36.15777233668736, 34.312073707580566, 36.70703785760062, 34.518991061619346, 36.08417354311262, 34.84771033695766, 36.042838709695, 34.642165252140586, 35.71428619112287, 36.14127383913313, 34.74903549466814, 34.71872050421578, 36.46772105353219, 35.76328141348702, 36.51618821280343, 35.626259463174, 38.63915123258318, 36.60491323471069, 36.269280501774375, 36.792170660836355, 36.685623509543284, 37.406103066035676, 35.952522550310405, 34.49159778867449, 36.37717907769339, 36.46158232007708, 37.18562977654593, 38.82380655833653, 42.64839036124093, 40.44186135700771, 41.30250692367554, 39.90745803288051, 41.04671246664864, 43.61344303403582, 49.67706298828125, 47.971394879477366, 48.91052729742867, 47.7640780040196, 46.194948945726665, 41.946792534419465, 42.0446857043675, 41.55160679136004, 41.86210094179426, 38.354021481105256, 36.35166529246739, 35.84740325382778, 38.21415771756853, 37.67495666231428, 37.084311144692556, 34.99968481063843, 35.71354620797293, 36.48961482729231, 37.4875567981175, 37.329724993024556, 36.69509737832205, 38.764107636043, 37.746537004198345, 37.24254247120449, 37.370729787009104, 36.80931881495884, 35.346066406794954, 37.43903752735683, 37.161425726754324, 36.70891039712088, 38.20555584771292, 35.96092987060547, 36.08657414572579, 37.583650384630474, 37.69335201808384, 36.54728487559727, 37.58928189958845, 36.7121239389692, 36.580570220947266, 35.530384744916645, 35.851867471422466, 36.259059701647075, 37.09775938306536, 36.47417593002319, 37.26657976422991, 38.01983049937657, 39.60116754259382, 45.25958939961025, 48.89245850699288, 49.865352221897666, 50.96069404057094, 50.678100381578716, 50.323481695992605, 49.108901841299875, 44.194017137799946, 39.84133202689034, 37.62708704812186, 41.78079659598214, 42.4295985358102, 45.64424514770508, 45.40050234113421, 46.99380070822579, 50.46399859019688, 60.055795669555664, 56.749186175210134, 65.70070675441197, 2.220951944589615, 1.2911180619682585, 3.860931132520948, 0.2676056889551026, 0.12342223578265735, 17.62511842591422, 68.26553004128593, 58.809754371643066, 66.51329163142613, 44.052628244672505, 29.039457525525773, 30.66557570866176, 45.435642855507986, 48.030287810734336, 65.8816170011248, 32.469022342136924, 0.35353731789759224, 0.06951685582420655, 0.0747245035267302, 0.03281886609537261, 0.07263478530304772, 0.02969140319951943, 0.013984710210934281, 0.14073683454522065, 0.18720983367945465, 0.19059264287352562, 0.1937549960400377, 0.12833516858518124, 0.10677335451224021, 0.32825067905443056, 0.3464114245559488, 11.372442330632891, 74.65602452414376, 56.02852596555437, 53.75856685638428, 24.94970961979457, 47.006161553519114, 69.46947915213448, 47.38358422688076, 61.81609398978097, 57.57730375017439, 67.73247814178467, 28.453111205782207, 0.12708354288978235, 0.3446427008935383, 4.862589955329895, 1.6812835144145148, 17.3238844871521, 73.65212794712612, 49.69905056272234, 63.35318143027169, 51.61978626251221, 51.17766196387154, 46.979226861681255, 44.374204771859304, 39.67207390921456, 45.39818511690412, 38.54117121015276, 42.60909482410976, 39.230012144361226, 41.104778562273296, 39.495179721287315, 39.96266494478498, 37.73009409223284, 36.377946853637695, 38.140816007341655, 40.765817642211914, 36.27618701117379, 38.403183460235596, 35.63136986323765, 39.935584340776714, 39.41055761064802, 39.0045222554888, 36.830809593200684, 38.02470118658883, 36.64316654205322, 38.36956112725394, 35.87306295122419, 39.08372824532645, 36.058614594595774, 38.06454563140869, 36.78745978219168, 38.649691649845664, 36.81825419834682, 35.6017427444458, 38.184405531202046, 35.612224102020264, 37.90661655153547, 38.21078436715262, 36.94775472368513, 39.71970728465489, 38.17422642026629, 40.885844298771445, 39.908976214272634, 38.56947469711304, 37.93021958214896, 40.31093297685896, 39.37617792401995, 37.075813497815815, 37.11572742462158, 38.49403463091169, 37.86111627306257, 39.378592423030305, 40.14128576006208, 44.656878335135325, 43.867618560791016, 43.40352405820574, 41.874024050576345, 43.43124737058367, 46.024481841496055, 51.6562990461077, 49.917411599840435, 51.85323878696987, 49.49566984176636, 49.44746323994228, 45.14804301943098, 45.155293464660645, 44.51882110323225, 43.766911370413645, 40.56312131881714, 38.847576345716206, 37.35438067572457, 39.43167666026524, 38.77398450034005, 39.45554024832589, 37.24205262320382, 37.43192604609898, 38.19654403414045, 39.617242200034006, 39.69986322947911, 39.331678186144146, 41.40091078622, 39.775348458971294, 39.09155191693987, 40.771219866616384, 38.8644118309021, 38.40342664718628, 39.16872903278896, 39.89046621322632, 38.73656497682844, 40.90902696337019, 37.602268082754954, 38.03409167698452, 38.942895208086284, 38.59191737856184, 39.12074824741909, 39.948327336992534, 38.954679352896555, 39.174047878810335, 37.66147715704781, 38.582283701215474, 38.60177339826311, 39.74255296162197, 37.823088782174246, 38.97197689328875, 39.46908923557827, 41.07596785681588, 46.147520542144775, 49.38590914862496, 52.445360796792166, 52.90639809199742, 53.00456918988909, 53.195783615112305, 52.17516619818551, 46.906732831682476, 42.778158392224995, 39.16364642551967, 45.64363718032837, 47.03047677448818, 47.679546219961985, 47.97047424316406, 49.012856892177034, 52.57380519594465, 64.14565127236503, 58.07328701019287, 67.69237313951764, 3.0976072464670454, 3.116145257438932, 10.623275399208069, 0.8771949272070612, 0.15953966416418552, 18.522589445114136, 75.34174224308559, 62.60419341496059, 73.17297322409493, 45.93240431376866, 33.47403063092913, 35.421426568712505, 51.20022971289498, 56.562481130872456, 75.02684988294328, 41.54845230919974, 0.47695040702819824, 0.20365611117865356, 0.20821309808109487, 0.10343775778476681, 0.137166505413396, 0.13655168483299868, 0.20151070558599063], [0.04424722785396235, 0.05188865174672433, 0.09847968883280243, 0.01338130428588816, 0.1319731476583651, 0.040948244876095226, 0.17549279598253115, 0.13095193888459886, 8.753928576196943, 55.87256669998169, 48.44247579574585, 33.24975667681013, 35.3015319279262, 72.0965166091919, 73.62537043435233, 45.670964445386616, 47.475123269217356, 51.639258589063374, 56.95837559018816, 23.584399018968853, 0.10998599390898432, 0.03971568601472037, 1.3429008147546222, 0.024745195039681027, 16.69105645588466, 69.46226692199707, 48.721063818250386, 55.554082121167866, 42.20629038129534, 46.74656990596226, 37.987542220524375, 39.81583908626011, 34.03555972235543, 39.91385384968349, 35.76920822688511, 38.30582530157906, 35.50977291379656, 36.45959166118077, 33.88105263028826, 37.080552169254844, 32.9903039932251, 36.35323905944824, 32.47682516915457, 34.68658855983189, 33.0343416758946, 35.03391858509609, 32.10786887577602, 33.78774874550955, 32.37568024226597, 33.24828713280814, 31.410228048052105, 34.96635430199759, 32.6522776058742, 34.4253362928118, 32.854772431509836, 33.789492743355886, 32.62424509865897, 33.513586725507466, 34.21630668640137, 35.663185664585654, 33.16002764020647, 35.3017577443804, 34.62625387736729, 34.45674215044294, 32.46384940828596, 34.560239042554585, 33.40591049194336, 36.081793785095215, 35.165364606039866, 33.948432786124094, 35.3181277002607, 36.3890882900783, 36.57723161152431, 36.28313173566546, 33.360886165073936, 33.91343470982143, 33.904846736363, 33.85785606929234, 32.752116271427695, 34.93673413140433, 35.71955639975411, 40.10006557192121, 39.70297602244786, 40.115671225956504, 38.0520875113351, 40.715019362313406, 42.424474239349365, 48.37320920399257, 46.07698243004935, 45.31274311883109, 45.736187185559956, 44.190258162362234, 39.726943833487375, 40.4547815322876, 39.20454352242606, 40.84497846875872, 35.65871797289167, 35.58274289539882, 34.51621525628226, 35.931639739445274, 35.297422068459646, 34.51334912436349, 34.52358382088797, 33.43942512784685, 33.59398433140346, 35.70170995167324, 35.238793168749126, 36.62338849476406, 36.02327605656215, 36.32195826939174, 35.44371291569301, 35.25523260661534, 34.67702089037214, 35.40672765459333, 34.0192106110709, 34.70559883117676, 33.404680660792756, 34.79837812696184, 34.47559608731951, 35.01586716515677, 33.86613484791347, 37.26010056904384, 35.432119846343994, 34.76637125015259, 33.64952475684029, 35.08542210715157, 34.19554546901158, 34.65087134497506, 34.80175495147705, 36.55587632315499, 36.955349104745046, 37.62789303915841, 36.44187375477382, 37.48274169649397, 37.29148210797991, 36.72574588230678, 38.85421187537057, 40.73506491524832, 40.958063874925884, 39.00186456952776, 38.86380386352539, 35.245790004730225, 37.02061006001064, 43.6089197567531, 50.89791011810303, 50.103063992091585, 52.25183262143816, 50.88397550582886, 50.37648950304304, 50.769503934042795, 57.39171389171055, 55.52431256430489, 64.16770485469273, 3.557117675031934, 1.6985341544662202, 2.348983577319554, 0.07586127359952245, 0.07460026376481567, 13.215881926672798, 63.75066007886614, 53.664074829646516, 62.90437643868582, 51.62742233276367, 33.56921747752598, 13.988789984158107, 33.80850648880005, 41.507075786590576, 57.55632366452898, 22.083341462271555, 0.41382111023579327, 0.04381621562476669, 0.02365512683588479, 0.05578089824744633, 0.07498925432030644, 0.02418482519819268, 0.03585254866629839, 0.053992741342101774, 0.016129844389589768, 0.057880034537187645, 0.065248361655644, 0.14868583157658577, 0.08859520458749362, 0.1742466799914837, 0.210250480898789, 10.052951625415258, 63.58314595903669, 53.075489452907014, 41.60986743654524, 36.322361264910015, 67.09676660810197, 73.59031677246094, 47.389875820704866, 52.01803963524954, 53.68931763512747, 61.23666981288365, 25.6698956148965, 0.04096150005768452, 0.07408302330545016, 2.31069552898407, 0.34063247750912395, 18.41677185467311, 72.148850440979, 51.22333247320992, 57.8214738709586, 44.88051652908325, 48.81134871074131, 38.6109276499067, 41.38574634279524, 36.62593500954764, 41.321336541857036, 38.14768082754952, 39.78716387067522, 36.93474769592285, 38.04864815303257, 36.08528872898647, 38.26507759094238, 34.91436093194144, 37.93893609728132, 32.96115977423531, 36.49070222037179, 36.815203939165386, 36.44610868181501, 33.90106691632952, 36.42611871446882, 33.878596442086355, 35.7008900642395, 34.067955698285786, 35.756649357931956, 35.72476407459804, 36.33031347819737, 34.38569334575108, 36.29788276127407, 34.407041685921804, 35.354463304792134, 35.043527943747385, 36.622141293116975, 33.910843031747, 37.25068228585379, 35.33132927758353, 38.06562607628958, 33.592674595969065, 36.46638005120413, 34.399103369031636, 37.44542987006051, 36.07483516420637, 37.32428455352783, 36.14928163800921, 38.4107847894941, 37.89964056015015, 37.77365582329886, 33.7278413772583, 35.475400175367085, 35.98164245060512, 34.87495769773211, 33.982895851135254, 35.52543762751988, 38.49784919193813, 42.04968840735299, 43.4222286088126, 42.525772026606965, 38.877964292253765, 42.49679456438337, 44.53117152622768, 49.67836577551705, 47.25707490103585, 47.2761754989624, 47.33315420150757, 46.04303353173392, 41.69826589311872, 41.67447873524257, 39.69085489000593, 42.18008872440883, 38.01021766662598, 36.982787540980745, 36.243134430476594, 36.828124114445274, 36.782762799944194, 35.58404220853533, 35.121337345668245, 34.72153452464512, 35.57094832829067, 37.01116745812552, 37.38268763678414, 38.83666072572981, 37.56785365513393, 37.7621739251273, 38.42599092211042, 35.933793681008474, 35.7204909324646, 37.92183310644967, 35.71482467651367, 36.38935579572405, 35.51546001434326, 37.003170081547324, 36.588887214660645, 36.936474323272705, 35.86679220199585, 38.68528379712786, 37.05382244927542, 36.32184362411499, 35.90801933833531, 37.325948647090364, 35.663797106061665, 37.51370286941528, 36.37034205027989, 37.80376584189278, 38.138363293239046, 39.30007777895246, 38.915380341666086, 38.08260747364589, 39.120452948978965, 38.82452917098999, 42.17278616768973, 43.41799020767212, 43.19679430552891, 40.56696367263794, 41.19398995808193, 38.20043502535139, 40.27697713034493, 44.770620346069336, 52.10703216280256, 50.13392094203404, 55.228427001408164, 53.20632055827549, 54.953681332724436, 51.386444909232004, 61.3259402683803, 57.06915419442313, 68.58127008165631, 4.081256338528224, 0.8026568783181054, 4.806089375700269, 0.5794129403574126, 0.036207269810672314, 14.420393841607229, 68.04302787780762, 57.92854561124529, 67.16816629682268, 51.85568455287388, 34.669099943978445, 13.003701312201363, 37.298878465379985, 48.530134269169395, 64.96772044045585, 28.439011573791504, 0.3513090360377516, 0.04485093403075423, 0.03698019922844001, 0.12407451149608408, 0.03880357549392751, 0.06123849789478949, 0.02323748853190669, 0.19378470230315412, 0.1151706799864769, 0.12303106034440653, 0.1973340239908014, 0.18259396350809506, 0.21355069881039007, 0.35085612748350414, 0.4252387104289872, 11.93243326459612, 71.58251667022705, 60.1230959211077, 46.64425768171038, 46.47791085924421, 78.91936274937221, 74.5527742930821, 55.36793293271746, 58.143349170684814, 59.58570834568569, 66.22690773010254, 27.91958509172712, 0.2499041488128049, 0.28230867428439005, 6.5657966647829324, 1.0501511693000793, 19.650942155293055, 74.6743608202253, 53.51729760851179, 60.21298476627895, 46.718714577811106, 51.444785458701, 42.64746625082833, 43.662618909563335, 38.91335494177682, 43.465491567339214, 39.6814991406032, 42.794510977608816, 39.60178245816912, 39.98336015428816, 39.125796113695415, 40.961520603724885, 36.16457462310791, 41.451559679848806, 36.168566363198416, 38.94928755078997, 39.2704576083592, 39.281307220458984, 35.926452909197124, 38.594547271728516, 36.56147657121931, 37.303509439740864, 36.49782064982823, 37.708002294812886, 37.441931452069966, 39.264027050563264, 37.09853410720825, 38.26295491627285, 35.54856123243059, 37.248688152858186, 36.81770529065813, 38.42264189038958, 36.39242342540196, 40.03965793337141, 37.1720529964992, 40.424859115055625, 34.967611925942556, 38.74459362030029, 35.873226233891074, 39.66865539550781, 37.53267839976719, 38.17671734946114, 39.00026648385184, 41.13286318097796, 40.245057106018066, 38.527326924460276, 35.49424021584647, 38.876171657017295, 38.4532139641898, 36.48203434262957, 36.20494018282209, 39.09979942866734, 41.061275890895296, 44.569119112832205, 46.42585495540074, 43.943009989602224, 41.71145357404436, 43.90456560679844, 47.01878295625959, 52.407295090811594, 49.72543287277222, 47.62404400961739, 50.789122172764365, 48.79238707678658, 42.5980715070452, 45.00979471206665, 43.15385791233608, 45.656282901763916, 40.253690242767334, 38.16899790082659, 38.64796502249581, 39.417523179735454, 40.239877223968506, 38.40604611805507, 37.19579151698521, 37.4797956602914, 38.48588786806379, 39.87861258643014, 38.2239442552839, 40.91456120354788, 39.161238874707905, 39.41246836526053, 39.281487873622346, 38.77193478175572, 36.882750851767405, 39.40235526221139, 38.38760559899466, 37.51881674357823, 37.24354648590088, 39.002819946834016, 39.03718226296561, 38.7424327305385, 36.101043769291465, 41.49490949085781, 39.63284437997, 38.64398717880249, 40.48316144943237, 40.76350041798183, 38.23976877757481, 38.56856795719692, 38.30734348297119, 39.52344151905605, 39.82835626602173, 42.30036899021694, 40.018132414136616, 40.051101616450715, 42.056615761348176, 41.33396141869681, 44.513147899082725, 45.070191928318565, 45.72516734259469, 42.11295175552368, 43.58488941192627, 40.59915467670986, 41.842844009399414, 48.572771889822825, 55.16916234152657, 51.80311795643398, 58.33275359017508, 56.16036108561924, 56.78347206115723, 54.86525855745588, 65.78648921421596, 60.147963523864746, 71.19732938494, 5.835568785667419, 2.9282077763761793, 6.917887074606759, 0.5949417842285973, 0.20557023132486002, 16.277188743863785, 72.93624809810093, 62.0856146131243, 71.68692725045341, 63.39275142124721, 44.95670005253383, 21.907348803111486, 51.20774071557181, 58.67841952187674, 74.3073639188494, 36.946410247257774, 0.6525303540485246, 0.11527202597686223, 0.09547714423388243, 0.24106424887265476, 0.1504011002502271, 0.2777373838637556, 0.11874037129538399], [0.04649335179211838, 0.04076693353376218, 0.02201557588497443, 0.08010191390556948, 0.027255525247060826, 0.08861829513417822, 0.20467105028884752, 0.1656228798840727, 9.528969730649676, 56.31501061575753, 53.37858377184187, 33.50369943891253, 28.2070928641728, 59.62199183872768, 83.4890262058803, 47.59787014552525, 47.043403897966655, 52.24054527282715, 54.962373529161724, 29.741579941340856, 0.038454431907406876, 0.0406265548164291, 2.7124953057084764, 0.27799121024353163, 17.16730683190482, 68.66057682037354, 47.17293916429792, 53.66891424996512, 40.221429756709504, 43.43709427969796, 35.92854084287371, 40.59114340373448, 39.29027387074062, 45.19903932298933, 40.962045192718506, 41.5044389452253, 34.802658217293875, 35.70411055428641, 35.42837824140276, 35.48324816567557, 35.053595883505686, 36.38612835747855, 32.50379807608468, 35.591952732631135, 32.23101874760219, 35.09520517076765, 31.52757269995553, 35.632068157196045, 33.1334889956883, 35.07891511917114, 31.961355686187744, 35.26145124435425, 32.69957399368286, 33.33559124810355, 31.712808200291224, 34.5468533379691, 33.487791538238525, 34.26477037157331, 34.48335027694702, 36.322131974356516, 33.689153807503835, 35.74779387882778, 32.93065370832171, 33.489942005702424, 32.93852949142456, 35.6966620853969, 33.540031569344656, 36.68954576764788, 33.7964756829398, 34.98983573913574, 36.120186056409565, 38.5940956388201, 38.21189260482788, 37.97128343582153, 35.333368573869976, 34.38177456174578, 33.30152423041207, 34.20782988412039, 32.73439836502075, 33.18973813738142, 34.93056065695626, 38.56587553024292, 38.89854833057949, 42.67349420275007, 39.986403465270996, 40.904118061065674, 42.07806485039847, 49.98778990336827, 45.68348509924752, 44.773833887917654, 43.93352222442627, 42.01424217224121, 39.888173307691304, 40.232998507363455, 40.216371468135286, 38.31193971633911, 35.093186719076975, 32.682717663901194, 36.70638820103237, 34.29248673575265, 35.900445801871165, 34.53450986317226, 33.30729123524257, 33.385017258780344, 32.83767638887678, 35.020897660936626, 36.551585810525076, 35.93944951466152, 35.22871480669294, 35.89048555919102, 34.84973921094622, 37.45063059670584, 35.33801344462803, 35.106082575661794, 35.22011293683733, 34.732686383383616, 35.081301825387136, 34.83172948019845, 34.421261174338206, 34.77407680238996, 35.92166560036795, 37.20964969907488, 36.28045320510864, 37.022802216666086, 36.1455956186567, 34.76884133475167, 35.39152847017561, 34.899363245282856, 33.64345897947039, 36.46624803543091, 34.99427563803536, 33.90938738414219, 35.339705330984934, 34.39229760851179, 37.86493083408901, 37.597671849387034, 37.68880442210606, 35.52852610179356, 36.900732789720806, 37.44936602456229, 40.18597309929984, 38.10661349977766, 46.6828236579895, 50.851114000592915, 54.38684729167393, 52.82053920200893, 56.296691690172466, 54.80531644821167, 58.56040436880929, 51.99626398086548, 57.641505105154856, 53.203930377960205, 66.70160170963833, 4.065294589315142, 0.9417691507509777, 2.7268014294760565, 0.1012968033818262, 0.04806933758248176, 9.795208198683602, 64.65856729234967, 55.425366742270334, 61.024235589163645, 48.71492508479527, 34.539040088653564, 25.729629278182983, 38.15243686948504, 39.42990139552525, 55.92950023923601, 28.14793242727007, 0.24885201241288865, 0.010192798683419824, 0.10666314685451132, 0.0053769142001069015, 0.058865599866424284, 0.017656320872317468, 0.06574650135423456, 0.03254442582173007, 0.037459523150963445, 0.027558029729074666, 0.0351335831385638, 0.06811605420495782, 0.11197402687477213, 0.32385322930557386, 0.27913087766085354, 11.14536738395691, 65.26474898202079, 60.08879266466413, 39.51105635506766, 37.13256638390677, 65.23451736995152, 81.44752734048026, 53.6344233921596, 51.740618910108296, 58.08505378450666, 59.616231782095774, 30.993704387119838, 0.11056651454418898, 0.12284104339778423, 3.414546936750412, 0.25207657366991043, 19.042662109647477, 71.53024537222726, 49.547152519226074, 56.309597969055176, 42.19919279643467, 45.492934226989746, 37.54820762361799, 43.90639993122646, 39.862096718379426, 46.55859681538173, 41.40758800506592, 43.58099842071533, 35.5087445804051, 37.642248017447336, 35.48515544618879, 36.93536261149815, 36.61150360107422, 38.28413649967739, 33.088975361415315, 38.087908949170796, 33.883863176618306, 35.74045658111572, 34.66620601926531, 37.82736887250628, 35.74282591683524, 37.533435753413606, 34.64496885027204, 37.30553831372942, 35.004329681396484, 36.112845284598215, 34.225832666669575, 36.881402901240754, 33.91654402869088, 35.95915807996477, 36.44309663772583, 36.03831195831299, 35.018695081983296, 36.16118042809622, 34.47186490467617, 34.72878149577549, 34.86417409351894, 38.03903532028198, 35.88822044645037, 37.37364455631801, 34.29754849842617, 36.80798476082938, 37.78265026637486, 40.17110742841448, 40.09259973253523, 38.45896707262312, 37.893550464085166, 36.558780670166016, 35.33586297716413, 35.28366116115025, 34.41798162460327, 35.65262787682669, 37.169780935559956, 40.87607513155256, 42.92852783203125, 43.68264709200178, 42.58040918622698, 42.270915576389854, 43.93834774834769, 49.66200276783535, 50.04545995167324, 46.849809714726035, 45.81815161023821, 45.066231455121724, 41.759357929229736, 43.785939012254985, 41.957760265895296, 40.41602448054722, 37.41344036374773, 36.27963331767491, 38.182397501809255, 36.05399056843349, 36.6963654245649, 37.18879468100411, 35.21728154591152, 34.744915212903706, 36.59277473177229, 37.24586023603167, 36.46655028206961, 36.21522699083601, 36.08917972019741, 37.715777329036165, 37.31865998676845, 38.05302204404558, 36.3053868157523, 37.09444161823818, 36.664494037628174, 34.92492914199829, 36.90402276175362, 35.417275020054404, 34.89814036233084, 36.111438274383545, 36.157827922276084, 39.41859320231846, 38.30518954140799, 37.088493960244314, 37.32968330383301, 36.19601174763271, 37.10814346585955, 37.398272446223665, 37.17328977584839, 37.20753744670323, 37.43064757755825, 36.206590379987446, 36.837841170174734, 35.80106919152396, 38.72032356262207, 37.89986637660435, 40.11428158623831, 37.94431400299072, 38.59965072359358, 38.678721223558696, 42.27808959143502, 40.31280204227993, 47.52240923472813, 53.26392112459455, 57.91259254728045, 55.774274008614675, 59.555803298950195, 56.36721937997, 61.66825022016253, 53.705159527914866, 60.207843099321636, 54.9451767376491, 69.01088414873395, 5.102170790944781, 0.890689740223544, 3.280956093754087, 0.6045007684401104, 0.1001260115631989, 11.126707128116063, 68.60078757149833, 59.123423848833355, 66.62050928388322, 50.2315605027335, 33.41101394380842, 32.27037681852068, 48.05597530092512, 45.465672969818115, 62.86531366620745, 32.52391311100551, 0.4085596411355904, 0.04530269925349525, 0.058960113009171825, 0.08656181834105935, 0.005289915408606508, 0.02201589479643319, 0.06140242516994476, 0.16013530934495585, 0.26275812621627537, 0.22282391121344908, 0.18451568324651035, 0.1755767986178398, 0.19908969263945306, 0.49122374398367746, 0.3071551338902542, 12.925632221358162, 73.50704261234829, 66.52671555110386, 46.69546937942505, 40.311127526419504, 63.957007680620464, 80.71087237766811, 56.49299567086356, 56.469389166150776, 62.82594517299107, 63.47966643742153, 33.91970198495047, 0.2766265948968274, 0.5441695600748062, 8.176891105515615, 0.6347311320049422, 20.595033849988663, 74.15180764879499, 52.08013221195766, 57.44834518432617, 43.282851219177246, 47.983707087380544, 39.521284103393555, 45.194908618927, 42.57687602724348, 49.226896149771555, 44.704049655369346, 45.59234210423061, 37.266645772116526, 39.2177277292524, 39.37080001831055, 39.55852992194039, 38.790986742292134, 41.447286537715364, 36.724050521850586, 39.681794439043315, 36.17194318771362, 37.82469729014805, 37.4850241797311, 41.068342208862305, 37.053843293871196, 40.657154764447895, 36.377106121608186, 39.46489947182791, 36.259653772626606, 38.48796885354178, 35.69029058728899, 38.994245869772776, 36.77370582308088, 38.373667512621196, 37.783821037837434, 40.17428275517055, 37.057734285082134, 38.37984446116856, 35.477877208164756, 36.46678304672241, 36.55762032100132, 38.9610265323094, 37.94815288271223, 41.23823608670916, 36.37730414526803, 38.69085625239781, 39.33908149174282, 42.7892233984811, 41.077878611428396, 41.878071376255576, 39.600201742989675, 38.6019401550293, 37.40823268890381, 36.70754507609776, 36.3606527873448, 37.50293663569859, 38.64102724620274, 43.096896580287385, 44.63684320449829, 45.871347018650596, 44.66416004725865, 46.274509293692454, 45.90558079310826, 54.71315554210118, 51.34614188330514, 48.96766580854143, 48.700594425201416, 47.88093628202166, 44.21339218957083, 47.043789522988455, 44.66182197843279, 43.50772966657366, 40.74970129558018, 36.216321332114084, 40.26648187637329, 37.18033872331892, 39.95295136315482, 38.891308307647705, 37.76110390254429, 37.78959151676723, 38.49102258682251, 39.31604821341378, 40.30233110700335, 38.18302978788103, 38.330130100250244, 39.632288524082725, 39.43096446990967, 41.38914401190621, 39.56703799111502, 38.586306708199636, 38.7833228792463, 36.52834061213902, 38.90300212587629, 37.30147014345442, 37.66355814252581, 38.724690505436485, 38.40313829694475, 42.23845706667219, 40.90919372013637, 40.64631904874529, 40.24885082244873, 39.016796248299734, 40.129136834825786, 39.471531527382986, 39.19342640468052, 40.914074829646516, 38.94978434698922, 38.670445919036865, 38.533465657915386, 38.09729943956648, 42.698820386614116, 41.56578459058489, 41.97808722087315, 38.25056280408587, 40.830963952200754, 40.54793950489589, 44.54942096982683, 42.53443990434919, 50.99678993225098, 55.25643171582903, 60.55115359170096, 56.95171226773943, 61.42477144513811, 59.96825531550816, 65.95419788360596, 57.82417324611119, 62.749827657427105, 56.68599230902535, 73.05650751931327, 6.861588426998683, 1.7786068235124861, 9.687776020595006, 1.2512790454285485, 0.22694698854216508, 12.164509177207947, 76.29258237566266, 65.40962587084088, 71.0283283506121, 61.06063025338309, 45.63401045118059, 37.82355431147984, 56.06611571993147, 54.38691329956055, 72.22944954463414, 41.809322425297324, 0.5248261551771845, 0.18511993225131715, 0.1974165067076683, 0.17791699804365635, 0.2059016821107694, 0.0920006429244365, 0.1957393174192735], [0.05615007897306766, 0.03965646687096783, 0.0317369928982641, 0.09020948010895934, 0.11960709121610437, 0.08163348957896233, 0.12002401027296271, 0.0657626437023282, 4.979966742651803, 56.34821605682373, 51.131744793483186, 39.424110071999685, 28.5199841431209, 39.71753249849592, 53.16913727351597, 30.574394498552593, 54.010650975363596, 47.9606807572501, 55.370514188494, 27.049212047031947, 0.050992123782634735, 0.1346683566059385, 1.1822181854929243, 0.17788619255380972, 17.537558964320592, 66.3386069706508, 49.07637732369559, 52.97395542689732, 41.55888850348336, 45.308480398995535, 41.089541162763325, 48.901449475969585, 44.99847262246268, 49.7287506375994, 44.55319036756243, 48.14180987221854, 41.511077948978965, 35.895394461495535, 33.89502198355538, 36.770176138196675, 34.872914927346365, 35.83419820240566, 33.793838841574534, 33.874816622052876, 33.41618340356009, 36.9823637008667, 33.87669958387102, 34.95684569222586, 34.37495837892805, 34.61162791933332, 33.199107783181326, 33.290657247815815, 33.682275090898784, 32.64797667094639, 32.57639980316162, 33.18841103145054, 33.313773904527935, 34.252423422677175, 32.580912658146445, 34.72388301576887, 33.77123635155814, 34.34352125440325, 33.65111242021833, 33.67147759028843, 33.48694385801043, 34.011512007032124, 33.55201373781477, 34.65742002214704, 35.013067041124614, 34.185863154275076, 36.463996819087434, 37.59489951814924, 35.79034117289952, 36.042220320020405, 34.74628053392683, 34.2799209186009, 34.00424419130598, 34.35230030332293, 33.88810852595738, 32.426784242902485, 36.02305024010794, 38.99909918648856, 41.74034070968628, 42.36569595336914, 40.05223764692034, 42.98688922609602, 44.92826107570103, 47.91022293908255, 45.33912195478167, 40.13815907069615, 42.938616616385325, 45.20722082683018, 40.37679147720337, 41.08024099894932, 39.85795906611851, 38.91447707584926, 33.29521179199219, 34.31661435535976, 34.65166343961443, 33.952223028455464, 33.928623471941265, 34.97167314801897, 32.67773927961077, 33.59615911756243, 36.03727320262364, 37.65740551267351, 38.55950403213501, 38.642712184361045, 36.20365129198347, 36.23361887250628, 36.69640016555786, 34.93910346712385, 33.381070681980674, 34.31607239586966, 34.784273283822195, 34.46931144169399, 35.340639863695415, 35.35573482513428, 33.18797329493931, 33.69719982147217, 35.403864996773855, 35.63838406971523, 35.493347372327534, 34.649926389966694, 34.735274587358745, 35.32609033584595, 35.875241211482454, 34.50140169688633, 36.80807161331177, 34.79181555339268, 35.2231354032244, 36.35984679630825, 36.267439229147776, 37.023802757263184, 37.43795708247593, 36.254849093300955, 37.75214420046125, 37.41007743562971, 39.94660070964268, 39.702229091099326, 40.599717480795725, 40.18447923660278, 53.24062728881836, 50.97076892852783, 56.25191749845232, 45.14278323309762, 47.71499940327236, 53.666475432259695, 57.906596251896445, 54.998375620160786, 59.189383098057334, 57.38050992148263, 63.785727637154714, 3.403242651905332, 0.13948275255305426, 3.900409494127546, 0.5863940343260765, 0.19231369266552584, 9.23743200302124, 62.386395181928364, 57.26825482504708, 62.48586559295654, 53.41237980978829, 41.28038733346121, 8.781940238816397, 21.398563487189158, 44.09326478413173, 57.22990424292428, 26.919537816728862, 0.1768281121871301, 0.04788235029471772, 0.03508140040295465, 0.021496270982814685, 0.06647063392613616, 0.026709742212135876, 0.05799791642597743, 0.012607966898940504, 0.04284351871215871, 0.0913073361984321, 0.054657536026622565, 0.09601018777383225, 0.06730829219200782, 0.1153875533491373, 0.09970838682992117, 6.482235891478402, 63.48409938812256, 56.33344766071865, 44.25007520403181, 24.70111002240862, 48.57858753204346, 71.10229887281145, 37.503072125571116, 58.894063813345774, 52.51184810910906, 61.4433022907802, 30.037934507642472, 0.09808753630412476, 0.05177298188209534, 0.7989311239549092, 0.23359840948666843, 19.242073672158376, 69.61638491494315, 51.16243151256016, 54.49631616047451, 43.89495277404785, 45.70270381655012, 42.956417901175364, 50.19953972952706, 44.88182973861694, 52.53115020479475, 47.357135908944265, 48.72015013013567, 43.09743159157889, 38.056315490177695, 36.700433594839915, 38.93756941386631, 36.387500626700266, 38.67330857685634, 35.44954592841012, 35.51433093207223, 35.16642073222569, 38.20359992980957, 34.79245478766305, 37.1224741254534, 36.37522663388933, 36.21887479509626, 34.15393965584891, 35.81209250858852, 36.45701387950352, 34.963272775922505, 34.10521541322981, 34.38542236600603, 34.58627394267491, 36.427202633449006, 34.525456360408235, 35.54334313528878, 35.857287066323416, 36.17047364371163, 34.446608202798025, 34.861280168805806, 33.94567435128348, 35.47217621122088, 35.74363190787179, 37.345271587371826, 36.49575703484671, 35.60347284589495, 37.22482803889683, 38.482142789023264, 37.98138959067208, 39.70745413643973, 36.46304838997977, 35.1265241759164, 35.27234254564558, 35.56962469645909, 35.43343652997698, 34.40639550345284, 37.73303665433611, 41.86901787349156, 42.6814603124346, 43.91917766843523, 42.56621401650565, 44.736601965767996, 46.258552755628315, 49.78728921072823, 46.48962204796927, 42.7377997807094, 45.722457545144216, 47.40711430140904, 42.58241721561977, 42.83080836704799, 41.60616752079555, 41.33337777001517, 34.83973033087594, 36.68383434840611, 35.23774399076189, 36.0024106161935, 36.387823717934744, 36.01660578591483, 34.28361736025129, 35.773825304848806, 36.64176648003714, 39.342156069619314, 39.80219629832676, 39.61394875390189, 38.468482630593435, 37.77227660587856, 37.519664423806326, 35.43052870886666, 36.40448202405657, 36.46691158839634, 36.829763889312744, 35.82754877635411, 36.057912826538086, 37.051467009953086, 35.822087492261616, 35.93279314041138, 35.02270071847098, 37.25755058016096, 38.08777693339756, 37.44195924486433, 36.95493916102818, 37.05227300098964, 37.582358019692556, 36.71328428813389, 38.80473722730364, 37.65878473009382, 36.99413742337908, 38.04850571496146, 38.11213036945888, 38.419560364314485, 38.87216254643032, 38.02443020684378, 41.072062969207764, 38.7561172076634, 41.97209439958845, 41.364349365234375, 43.09718145642962, 40.98128128051758, 56.25202866962978, 52.723281792231965, 59.367687770298545, 46.942714078085764, 50.076671259743826, 54.337063448769705, 62.11002363477434, 55.62162555967058, 60.93994699205671, 60.65002645765032, 67.884247643607, 6.496154870305743, 0.26130424280251774, 1.5301030895539691, 0.36494954409343855, 0.16736837050744466, 10.262636968067714, 68.17997687203544, 60.62632615225655, 67.17497553144182, 57.41349996839251, 40.96408101490566, 12.356447952134268, 29.388889380863734, 51.506718226841514, 66.15651553017753, 33.54659414291382, 0.22103552360619816, 0.06190618313848972, 0.06072724211428847, 0.04368934993232999, 0.026820594478132467, 0.04381496372765728, 0.07162838216338839, 0.12350767691220556, 0.12807239911385945, 0.21025551562862738, 0.16478833609393664, 0.23223954811692238, 0.14743559009262494, 0.19276054868740694, 0.19652514239507063, 7.660863161087036, 72.6887046269008, 65.52143628256661, 51.88789987564087, 39.93871797834124, 49.50994144167219, 62.12149511064802, 43.04267283848354, 63.26030485970633, 56.21809366771153, 65.22906303405762, 32.947888714926584, 0.15914429537951946, 0.36056767350861, 6.672162728650229, 0.40803016668983866, 21.089320012501307, 73.40782233646938, 52.99079786028181, 57.500870091574534, 45.53162179674421, 49.319164752960205, 44.0034384727478, 54.39134625026158, 47.36544248035976, 55.42455380303519, 48.80831582205636, 52.15607254845755, 45.18110949652535, 39.80814395632063, 37.383955683027, 41.33533021381923, 38.97249800818307, 40.66281754629952, 37.42145511082241, 37.83243063517979, 36.89863790784563, 40.63644913264683, 37.54247535978045, 39.96809843608311, 38.62075587681362, 38.83138009480068, 36.66631099155971, 38.40359687805176, 38.24837759562901, 37.2963284764971, 36.33969702039446, 36.23666565758841, 37.26396376746041, 38.473662512642996, 35.5930609703064, 37.811134406498496, 37.848119667598176, 37.7634836605617, 36.01165519441877, 36.99218150547573, 35.755610602242605, 36.233858585357666, 37.47976786749703, 39.793563161577495, 40.08379289082119, 37.263334955487935, 38.821419852120535, 41.66368818283081, 39.475981848580496, 40.3875264440264, 38.3490708896092, 37.337434019361226, 37.39173766544887, 38.01625565120152, 37.0104135785784, 36.05745424543108, 40.0112259047372, 44.39696707044329, 46.58854702540806, 46.3318840435573, 45.906567437308176, 46.39435182298933, 47.65676307678223, 52.52206196103777, 48.65500034604754, 44.865477153233115, 47.09495258331299, 49.21026563644409, 44.26950931549072, 47.04039185387747, 44.5588253566197, 42.98051425388881, 36.83220965521676, 39.76326901572091, 38.10371610096523, 39.66831840787615, 37.99008526120867, 38.97688579559326, 35.4931389263698, 37.35153538840157, 38.784879275730674, 41.92300190244402, 42.69949088777815, 43.06603963034493, 40.16068513052804, 39.54370594024658, 39.51676082611084, 38.923103264399934, 38.491526331220356, 38.22373580932617, 39.333710534232004, 37.77207163402012, 37.86175550733294, 39.451746531895225, 37.35273395265852, 36.62948553902762, 36.92469712666103, 40.3416405405317, 39.177984033312114, 39.781952721732004, 38.11452054977417, 39.0184394972665, 40.50738286972046, 38.032184396471294, 41.43966783796038, 39.135725089481895, 38.77057988303048, 39.34421968460083, 40.17691959653582, 41.84716578892299, 41.48639447348458, 41.502100876399446, 43.147851194654194, 41.01013714926583, 43.7528030531747, 43.27110528945923, 45.495814255305696, 42.84103611537388, 58.03937980106899, 54.04442964281355, 61.480023520333425, 48.05295630863735, 49.760674136025564, 54.9715382031032, 62.81703063419887, 59.859238079616, 63.78284413473946, 62.74878542763846, 70.56282683781215, 9.16080640043531, 0.7579274699091911, 11.825122679982867, 1.7590030240161079, 0.3451185982142176, 12.901295287268502, 72.67729568481445, 66.43811212267194, 72.63326495034354, 67.96507603781563, 53.32279321125576, 16.586258513586863, 37.22327511651175, 60.90981960296631, 76.29175554003034, 41.58054951259068, 0.40826111286878586, 0.16571176797151566, 0.1742866457040821, 0.1173729875258037, 0.21117829611258848, 0.09294569971305983, 0.24678345769643784], [0.03671296838937061, 0.0312970647189234, 0.02246845051247094, 0.03081658050151808, 0.04375422127278788, 0.03607043643881168, 0.08135650479899985, 0.033056648514632664, 2.2283938995429446, 50.23838710784912, 56.05495343889509, 46.18980380467006, 31.55927038192749, 15.68290410723005, 24.488621950149536, 32.09641824449812, 54.46693917683193, 50.352525166102815, 57.74464763913836, 25.24892336981637, 0.017340003113661493, 0.18674008388604435, 1.6543922488178526, 0.31888524017163683, 12.503827929496765, 65.71930013384137, 48.58619580950056, 54.939385414123535, 45.18275621959141, 49.22100060326712, 45.540894167763845, 50.506973198481965, 47.97746760504586, 49.646463121686665, 48.350478172302246, 48.96396936689104, 46.223641531808035, 38.75002711159842, 34.71577794211251, 36.0301512990679, 34.066795349121094, 36.73176997048514, 34.296516690935405, 33.351050989968435, 32.559380190713064, 35.158888884953086, 32.70464617865426, 35.23158441271101, 32.375315461839946, 33.954779965536936, 33.270872252328054, 33.472397804260254, 31.20873028891427, 32.528165408543174, 32.441007205418174, 33.33544881003243, 31.700572422572545, 32.49577290671212, 33.05884449822562, 33.79206705093384, 33.127753257751465, 34.44586821964809, 33.12070778438023, 31.805907113211497, 33.37478951045445, 33.12171874727522, 33.533889361790244, 34.56582192012242, 34.50838116237095, 34.939773968287874, 34.98506580080305, 36.538679531642366, 34.94587796075003, 35.26804508481707, 33.494906493595664, 35.43786253247942, 33.74430513381958, 34.99285125732422, 33.95152473449707, 33.30367122377668, 36.57940639768328, 38.23092024666922, 39.93604292188372, 44.95039108821324, 45.79581662586757, 43.57075677599226, 44.805312701633994, 44.10596261705671, 47.240830012730186, 39.72564452035086, 44.539165428706575, 47.16225630896432, 41.7379401070731, 42.00025544847761, 39.03602886199951, 37.92095068522862, 34.80707032339913, 33.35889203207833, 33.19882638113839, 35.67152350289481, 32.45632103511265, 34.849332741328645, 34.20383814402989, 33.827541078839985, 34.39684520448957, 37.33417878832136, 37.082973616463796, 37.511892863682334, 35.953714166368755, 35.046209948403494, 36.72531509399414, 34.0149895804269, 34.195114680698936, 33.918864727020264, 33.589012895311626, 33.31220013754708, 34.24843168258667, 35.5423321723938, 34.557414599827354, 33.14949764524187, 34.77566793986729, 35.62459536961147, 35.61625405720302, 34.39885670798165, 34.588014466421946, 34.48131792885916, 33.2329489844186, 35.6686122076852, 35.41542679922921, 35.67634555271694, 35.338267053876606, 36.36728484289986, 36.94735172816685, 33.76174858638218, 37.42563445227486, 38.557912894657676, 36.82162407466343, 37.73039286477225, 40.153215817042756, 40.148035934993196, 40.719702448163716, 39.84550094604492, 47.564741134643555, 52.78834124973842, 54.40028510774885, 54.8747741154262, 54.31513840811593, 52.3022209576198, 57.16651235307966, 53.30986608777727, 57.161697251456125, 52.33754212515694, 54.7024553162711, 9.76917850971222, 0.351403433829546, 1.512123431478228, 0.08213415342782225, 0.1311779860407114, 9.298116700989858, 64.75580038343156, 54.59782239368984, 65.8425542286464, 49.957054546901155, 40.11008834838867, 24.967470952442714, 31.245090212140763, 40.9051707131522, 57.83982406343733, 19.140416315623693, 0.16243261178689344, 0.07015509264809744, 0.024309317714401653, 0.04741212891946946, 0.016562922757917216, 0.05247571345950876, 0.040280739444174936, 0.052643664447324615, 0.022454537151913558, 0.023395018918173652, 0.031063234766146967, 0.06877244184059755, 0.02655248493621392, 0.06662227971745388, 0.03291550644540361, 2.727152530636106, 56.59436641420637, 62.00725282941546, 52.511320046016145, 37.77310691561018, 22.87437650135585, 36.480884415762766, 36.65370348521641, 57.63761411394392, 54.25318826947893, 60.80321339198521, 27.737898383821758, 0.028479800892195532, 0.27455282903143335, 1.6144867901291167, 0.4706448625241007, 13.57220813206264, 69.32041249956403, 50.75897741317749, 56.419796398707796, 45.754690238407676, 51.25820895603725, 47.85905987875802, 52.09034258978707, 49.40282801219395, 51.730960914066856, 50.024559770311626, 50.81703656060355, 48.43673658370972, 40.790282249450684, 36.298872879573274, 37.786190373556956, 36.230217729296, 38.867020879473, 36.062550749097554, 35.73845897402082, 34.89168895993914, 35.90690067836216, 34.30419097627912, 36.773441791534424, 34.748677662440706, 36.60172748565674, 34.309714794158936, 35.76194041115897, 34.21348919187273, 34.33250835963658, 35.09163727079119, 34.65250417164394, 33.81824786322457, 34.255015100751606, 33.747782707214355, 36.523803438459126, 34.66563279288155, 35.96634946550642, 34.73077910287039, 34.35068832124983, 34.58938673564366, 34.9947863306318, 35.44344541004726, 36.73669276918684, 35.90261363983154, 36.79157658985683, 36.634113039289204, 38.01464366912842, 35.67510529926845, 37.24091311863491, 36.186239106314524, 35.89345243998936, 35.33149603434971, 37.36649138586861, 35.99735232761928, 34.49289015361241, 38.520208495003835, 42.4984621320452, 41.755001408713206, 45.93143851416451, 47.122870445251465, 47.95912088666643, 45.89638832637242, 46.865109648023335, 47.9131863457816, 42.34256887435913, 44.75515365600586, 45.58646045412336, 44.37199177060808, 45.22985805783953, 41.83575684683663, 40.51569638933454, 36.92923777444022, 34.62388106754848, 35.62759351730347, 37.11479984010969, 34.44433266775948, 37.104120458875386, 35.37018360410418, 36.34701694761004, 36.63533592224121, 37.939332144601, 38.904134682246614, 39.93249586650303, 38.97177192143032, 36.93391738619123, 37.901294231414795, 35.43552793775286, 35.895283290318076, 36.508322851998464, 35.810525689806255, 34.93926327569144, 35.56524038314819, 36.60809898376465, 36.19452483313424, 36.09337990624564, 36.92383207593645, 37.269164494105745, 37.18460839135306, 37.23903710501534, 37.73271356310163, 35.88505206789289, 36.40494407926287, 38.33695323126656, 36.598044940403526, 37.89293554850987, 37.674369539533345, 38.6630391393389, 37.597783020564485, 35.98438351494925, 40.6818972996303, 40.596208640507285, 37.962813581739155, 38.532892431531636, 42.11096109662737, 42.6468756539481, 43.139756543295725, 41.889594963618684, 49.15142829077584, 55.28101791654314, 54.51447180339268, 57.65474142347063, 56.76574720655169, 51.999588693891255, 59.08891214643206, 55.705587591443745, 59.701222147260395, 54.72994933809553, 60.64937332698277, 14.065356527056013, 0.2293131894298962, 2.1681554062025885, 0.4709395638534001, 0.22044092336935656, 10.697961585862295, 69.30448028019497, 58.20368037905012, 69.54428345816476, 57.181624685014995, 38.13895736421858, 24.496148586273193, 39.75048780441284, 46.432695456913535, 66.10370227268764, 23.940454244613647, 0.1037671390388693, 0.08325844524162156, 0.06462269130029849, 0.05823954953146832, 0.016200615592034798, 0.014810114134369152, 0.01270515177332397, 0.08534635177680425, 0.15078707811023506, 0.10653920564800501, 0.11465804677988801, 0.2566380931862763, 0.10579332602875573, 0.12757037819496223, 0.12165223647441183, 3.405482360294887, 63.62729481288365, 70.19828959873745, 60.02570302145821, 44.195893151419504, 24.411858252116613, 34.610908780779155, 42.728617736271445, 63.75623253413609, 59.85438128880092, 67.12759576525006, 30.7051283291408, 0.11062451571758304, 0.4763597015823637, 6.488225672926221, 0.6391266275729451, 15.532350540161133, 73.42233712332589, 53.359125341687886, 57.97053010123116, 48.210041182381765, 54.17386416026524, 49.76075751440865, 53.01730523790632, 51.26222848892212, 53.8780654498509, 52.6439403125218, 52.568611417497905, 51.50254583358765, 42.475091866084504, 37.92636680603027, 38.18015670776367, 37.8591707774571, 40.89659663609096, 37.81409781319754, 39.49792773383004, 37.176534584590364, 38.515782492501394, 36.72626004900251, 39.96704230989729, 35.825704029628206, 37.94489417757307, 37.28625011444092, 37.02344492503575, 36.42833866391863, 36.94930417197091, 36.86185414450509, 38.80115543093, 35.84045158113752, 36.23762450899397, 35.575763429914204, 38.506239141736714, 36.81919567925589, 38.328174182346885, 36.141579559871126, 36.410113539014546, 37.256233896527974, 36.152703625815256, 38.420522689819336, 38.75854560307094, 37.48168557030814, 38.32273721694946, 37.78742715290615, 39.96825129645211, 38.003648144858225, 38.48017644882202, 37.83070748192923, 39.64443050112043, 37.4268399647304, 40.61437470572335, 36.72088214329311, 36.70771183286394, 40.92886059624808, 42.48936346599034, 44.79335832595825, 49.99757991518293, 48.56776918683733, 50.06353221620832, 48.30779538835798, 48.823355197906494, 50.234377997262136, 43.665964467184885, 48.46926804951259, 49.11318193163191, 47.18140207018171, 47.502474852970664, 43.65638290132795, 41.23302493776594, 40.010951450892854, 36.97255284445626, 36.5622478212629, 39.71137292044503, 36.7836834362575, 40.10318531308855, 38.599080971309114, 37.15441499437605, 38.179559162684846, 40.50244617462158, 40.519959109170095, 42.44109780447823, 40.50462096078055, 38.972977433885845, 41.73734256199428, 37.49139220373971, 38.35881226403372, 39.01460756574358, 38.25594070979527, 35.91144480024065, 36.64225285393851, 37.909510476248606, 38.74178307397025, 37.97301006317139, 38.73038802828108, 39.76050015858242, 39.32590075901577, 39.36609608786446, 39.229272161211284, 38.442260129111155, 38.32503012248448, 40.18168953486851, 38.02534736905779, 39.86304862158639, 40.079509326389854, 40.368787152426584, 40.112930161612375, 37.680490902491975, 43.638428756168906, 42.378699507032124, 40.89200735092163, 42.394913128444124, 44.50872189658028, 44.93773147038051, 45.1119818687439, 43.76938145501273, 50.93700415747506, 58.61480876377651, 58.06512287684849, 58.89708627973284, 56.88234492710659, 55.61823831285749, 60.15194484165737, 57.9924065044948, 61.48660346439907, 56.26462575367519, 64.30509853363037, 18.359772307532175, 0.48337423375674654, 6.525479308196476, 1.109898403286934, 0.30879526159593035, 11.413030232701983, 76.32381452832902, 63.201995577131, 76.83661242893764, 63.04662690843855, 52.50440658841814, 38.34916469029018, 47.80682332175118, 53.679346970149446, 75.20881625584194, 32.08389064243862, 0.3112312565956797, 0.17706194892525673, 0.14585334142403944, 0.17609156242438725, 0.16955988933997496, 0.18766276937510284, 0.16588851277317318], [0.022827792480321865, 0.017746983328834176, 0.025421110913157463, 0.007004718861675688, 0.039578041793512445, 0.02104871946253947, 0.010847681667655706, 0.010656099001477872, 0.5326169314129012, 36.26428822108677, 58.12001017161778, 39.58155277797154, 30.270831176212855, 21.0908625125885, 31.259427819933208, 34.634480544498985, 53.135799816676546, 50.766828877585276, 55.545865876334055, 27.779804706573486, 0.11849570513835975, 0.13309366681746074, 0.61849031490939, 0.3179771160440785, 6.1678455386843, 60.97943360464913, 51.19610595703125, 58.450247628348215, 48.071518421173096, 53.644737992967876, 49.39255510057722, 52.36852066857474, 44.61261831011091, 45.96583209718977, 51.18529456002371, 48.83977031707764, 47.89242165429251, 43.00105660302298, 35.78896542957851, 36.62230804988316, 35.53582518441336, 35.77044153213501, 34.9784129006522, 35.89401871817452, 34.70506729398455, 36.47024672372, 35.537020274571006, 35.00437137058803, 34.0615668296814, 32.89889349256243, 33.68133708408901, 33.01191636494228, 32.7368198122297, 31.806660992758616, 32.12795959200178, 31.861190455300466, 31.86420249938965, 33.97630895887102, 33.42349985667637, 33.40784903935024, 32.25713355200631, 34.264297894069124, 32.08410603659493, 34.828752177102224, 32.76796511241368, 34.82825190680367, 32.86872441428048, 35.1368214062282, 34.04671852929251, 34.461915084293906, 34.570887156895225, 36.6024466242109, 36.79271262032645, 37.06361940928868, 36.2745680809021, 33.17770038332258, 33.836723123277935, 35.371201515197754, 34.87823029926845, 32.87329632895333, 34.782268728528706, 38.321514333997456, 44.24240091868809, 48.24432359422956, 43.70479794910976, 44.41165208816528, 44.28185626438686, 46.115645681108745, 45.14753580093384, 43.94357279368809, 45.11684908185686, 45.07788705825806, 43.540115220206125, 39.71203647341047, 38.945056097848074, 36.47419677461897, 33.71619272232056, 34.46697684696743, 33.6076340675354, 34.643092836652485, 34.02489423751831, 35.33229855128697, 35.084935733250205, 34.92413704735892, 35.28880630220686, 37.344052178519114, 36.97534602028983, 37.40680830819266, 35.6135790007455, 34.83412313461304, 34.25281252179827, 34.70076635905674, 32.76001984732491, 33.95478343963623, 32.73486042022705, 33.75184392929077, 33.685036999838694, 34.06576006753104, 34.8302321434021, 34.42788628169468, 32.81672409602574, 34.71612535204206, 35.205914293016704, 34.391126837049214, 35.130033016204834, 32.03786924907139, 33.7927097593035, 33.622249603271484, 35.732862200055806, 34.360179560525076, 35.24581779752459, 35.227370330265586, 35.570851053510395, 34.48970093045916, 36.49168886457171, 36.937554768153596, 38.69175257001604, 38.50276851654053, 39.296846866607666, 39.305806568690706, 39.45267064230782, 38.963173525674, 42.80713932854788, 45.85423707962036, 51.388477257319856, 53.93961954116821, 57.41223192214966, 54.53059162412371, 54.17445823124477, 47.53611108234951, 57.820563656943186, 50.90820387431553, 50.36894375937325, 15.5318763256073, 0.34375213725226267, 0.07727646016116653, 0.3383650577494076, 0.06634361217064516, 9.348836813654218, 64.39036682673863, 53.194251537323, 65.05103628976005, 50.78282710484096, 38.33888830457415, 12.133297869137355, 24.34149558203561, 45.623087882995605, 53.19094072069441, 15.971719878060476, 0.20064247931752885, 0.029775670463485376, 0.020743621280416846, 0.01453436937715326, 0.03680952392252428, 0.027660922779302512, 0.05708409260426249, 0.030933621006884744, 0.06427184798355613, 0.028667202086320946, 0.04607250062482698, 0.06554933943386589, 0.029248292690941265, 0.09171064384281635, 0.07383131395493235, 0.8073401270168168, 41.96810613359724, 66.05595425197056, 46.35139805930001, 36.03083222252982, 19.997759750911168, 36.520381450653076, 42.32491002764021, 57.137472357068745, 54.598239285605295, 59.418076106480186, 30.383746351514542, 0.06987420629177775, 0.018700793219198073, 1.5107975197689874, 0.4434938537222998, 6.975788150514875, 66.27699729374477, 52.07870435714722, 62.47650636945452, 49.55136660167149, 55.08778503962925, 51.669604846409385, 52.819288526262554, 45.226793902260916, 47.95431968144008, 52.13844149453299, 51.11292559759957, 48.37370252609253, 45.53503336225237, 36.63681936264038, 37.90169375283377, 37.35399505070278, 36.95240306854248, 36.56372083936419, 37.3445976121085, 35.8147953578404, 38.09306451252529, 36.56059067589896, 35.649313586098806, 35.590111460004536, 35.36312076023647, 35.307514326913015, 35.90468072891235, 34.80752543040684, 33.847777707236155, 33.86996677943638, 34.84792225701468, 34.29632214137486, 35.738323484148296, 35.056517601013184, 35.891305446624756, 35.8626024382455, 35.531934193202424, 33.91657876968384, 35.94195086615426, 34.300668239593506, 36.286637101854595, 34.064109870365684, 35.98435224805559, 35.56691142490932, 37.09445551463536, 37.20545646122524, 38.620151383536204, 37.977397850581575, 39.712255341666086, 36.47964416231428, 35.28767721993582, 35.70198787961687, 37.124117374420166, 36.08884620666504, 35.13763781956264, 38.16900484902518, 41.419855049678254, 44.76905700138637, 49.79596403666905, 46.56997101647513, 45.80295589991978, 44.06229666301182, 47.71455124446324, 45.74043253489903, 43.94683844702584, 47.05893659591675, 48.05399853842599, 43.841993604387554, 42.127807004111155, 42.82952989850725, 39.81093365805489, 34.88195105961391, 36.27786152703421, 35.88061216899327, 36.24744578770229, 35.81413875307356, 36.69064705712454, 35.694230215890066, 35.90457303183419, 38.12814596721104, 38.954446588243755, 38.00609391076224, 38.37195825576782, 36.55412885120937, 36.541524818965364, 35.943177223205566, 36.21167993545532, 34.20369570595877, 34.743970257895334, 34.60766397203718, 36.301850182669504, 35.63851261138916, 36.120415346963064, 36.069651808057515, 35.4724645614624, 34.791287490299766, 36.731964520045686, 36.57231228692191, 36.23310470581055, 35.59393644332886, 34.57319743292672, 37.41574369158064, 37.20312186649868, 36.8208840915135, 37.50339521680559, 36.52336917604719, 37.01803575243269, 38.42404890060425, 35.8918126651219, 39.09630101067679, 38.720017841884065, 40.760630811963765, 40.53236164365496, 42.23583064760481, 40.80534594399588, 40.413627352033345, 40.74220418930054, 43.35076986040388, 48.71234382901873, 53.599998542240684, 55.24460588182722, 57.492250851222444, 56.65750469480242, 55.96450873783657, 51.33832515989031, 60.04647813524519, 53.91882358278547, 55.3062607220241, 21.89048205103193, 0.3065806861434664, 0.8538684674671718, 0.6361543727772576, 0.1255105087267501, 10.017028570175171, 69.72607612609863, 56.637942041669575, 70.286865234375, 56.62913867405483, 45.2761504309518, 18.832017047064646, 33.075263091496055, 51.94218962533133, 62.563782691955566, 20.14080057825361, 0.13218689975993975, 0.09166269177304846, 0.020861735567450523, 0.03957419449995671, 0.037190728288676055, 0.03413506118314607, 0.059119256612445624, 0.0695428844275219, 0.24013981276324817, 0.07830712092774254, 0.099118387060506, 0.08386786468327045, 0.09504808618554048, 0.1630068424024752, 0.2003946511873177, 0.9276373833417892, 48.81846366609846, 73.15308053152901, 52.99785375595093, 42.59220722743443, 30.33755820138114, 40.098050594329834, 46.49213382175991, 63.80530071258545, 59.09187207903181, 65.18961116245815, 34.359227657318115, 0.15979654395154544, 0.2146506176463195, 3.6104068841253008, 0.7583547298397336, 8.321880034038, 68.50920336587089, 54.300526346479145, 63.9382266998291, 50.37743445805141, 58.439123562404085, 53.654093742370605, 54.02714947291783, 46.943641662597656, 50.00337471280779, 54.42348861694336, 52.87593371527535, 51.68115970066616, 47.80347776412964, 38.202488218035015, 40.407589367457796, 39.9408232825143, 40.23236274719238, 38.28686714172363, 39.41942351205008, 38.58194323948452, 41.79523842675345, 37.64955057416643, 38.82456043788365, 39.854464122227256, 37.37739658355713, 37.944786480494905, 38.16369642530169, 38.028178759983604, 36.087640694209504, 36.1199254989624, 37.54785326548985, 36.39192662920271, 37.33457483564104, 36.70915010997227, 37.96455757958548, 36.996809005737305, 37.00883633749825, 35.318405628204346, 39.01763350622994, 35.85713073185512, 39.336496761866975, 35.166771616254536, 37.727130685533794, 36.96963807514736, 38.68405744007656, 38.40507684435163, 39.305747509002686, 40.47707830156599, 41.30485888889858, 38.84278208868844, 36.85506575448172, 37.48596566064017, 39.38854571751186, 37.787381989615305, 37.25916951043265, 40.0560348374503, 43.685752936771934, 47.898317200796946, 49.94717768260411, 49.3683579989842, 48.19847590582711, 47.209462370191304, 48.66913645608084, 47.89519051143101, 44.00573485238211, 49.38445350102016, 51.73667928150722, 45.589712211063926, 44.51941517421177, 44.070318358285085, 41.46207577841622, 39.442769459315706, 39.40939031328474, 37.5561146736145, 37.40494966506958, 37.30553136553083, 38.752278327941895, 39.26947096415928, 39.401007311684744, 40.51316377094814, 40.381623949323384, 40.08244146619524, 39.307891028267996, 38.04813398633684, 38.61441217150007, 37.70666824068342, 38.05541222436087, 36.91935396194458, 36.148534706660676, 36.012985774448936, 38.36892189298357, 36.71926668712071, 37.344531604221885, 38.243572916303364, 38.31837722233364, 36.356893811907085, 37.614990234375, 37.78236539023263, 38.92744241441999, 38.778733594076975, 35.13675192424229, 38.906347683497835, 40.24796492712838, 39.9297582762582, 38.64165953227452, 39.4258644921439, 39.28371129717146, 39.43792309079851, 37.931366034916465, 41.75375073296683, 42.00088426045009, 42.8373361996242, 42.553863593510215, 42.84739719118391, 41.90688208171299, 42.928659847804475, 43.16415861674717, 46.17691489628383, 51.2100544657026, 54.08995076588222, 58.73519325256348, 60.32786628178188, 57.64309624263218, 57.647942611149375, 52.68120697566441, 62.71314811706543, 54.5398188318525, 57.478396143232075, 26.787937198366436, 0.6899659995521817, 3.7130278689520697, 1.4892094667468752, 0.2656221411057881, 11.319834913526263, 76.01103442055839, 62.486407552446636, 75.75816862923759, 61.184016363961355, 50.47903101784842, 22.031914370400564, 40.224191665649414, 61.66837528773716, 72.44354438781738, 27.234574351991924, 0.29751898667642046, 0.14415392332843371, 0.13960199829723152, 0.145272501877376, 0.15154687448271684, 0.1674372282411371, 0.1393286979624203], [0.025592091559831585, 0.12296503888709204, 0.006901560758706182, 0.010334199444124741, 0.018964563529672365, 0.09804886659341198, 0.05206144068922315, 0.10296345502138138, 0.01894887749637876, 22.51655295916966, 58.92887428828648, 43.622677189963206, 34.81184720993042, 16.603757551738195, 19.598684753690446, 33.31521912983486, 50.79799154826573, 49.44926282337734, 56.451772008623394, 30.85968405859811, 0.08050672111234494, 0.3293975389429501, 0.6606030208723885, 0.8086081732596669, 2.763184802872794, 55.82986307144165, 51.800891058785574, 56.79351568222046, 51.40152597427368, 53.03372383117676, 48.297953265053884, 48.48971312386649, 44.334888390132356, 46.051503385816304, 50.586182662418906, 48.812800884246826, 47.0416008404323, 45.55411311558315, 39.11753470557076, 35.135643686567036, 36.58386366707938, 34.409921714237754, 35.91794484002249, 35.28395298549107, 34.086424010140554, 33.46185391289847, 33.456500325884136, 32.90697424752371, 32.49441105978829, 33.953800269535606, 33.62636988503592, 32.440861293247764, 31.382615906851633, 32.419672761644634, 31.986994538988384, 31.58645520891462, 32.61208227702549, 33.66876431873867, 34.78854990005493, 31.586903367723735, 33.43007632664272, 33.97276190349034, 32.29692588533674, 33.043923241751536, 31.868885585239955, 33.85717861992972, 34.49732310431344, 34.08436386925833, 35.125641754695344, 33.5361510004316, 35.18325621741158, 37.55705962862287, 38.99917214257376, 37.5287561416626, 35.100972175598145, 33.91189915793282, 34.34374359675816, 33.99669844763619, 34.68253428595406, 33.34738234111241, 34.9095493044172, 39.05974653788975, 47.23679658344814, 41.281280176980154, 41.27934510367257, 46.33037281036377, 44.47229249136788, 45.021141120365684, 47.50219692502703, 41.340999943869456, 42.537177494594026, 45.036312511989046, 41.75175659997122, 41.69378430502755, 39.95270817620413, 37.248413699013845, 33.06857892445156, 32.78200394766671, 34.08598279953003, 35.02424669265747, 34.256436007363455, 35.183388233184814, 31.897324562072754, 34.038377216884065, 37.53742749350411, 37.35969257354736, 39.429668630872456, 37.779888357434956, 33.35010256086077, 33.12366076878139, 35.2591097014291, 34.008451325552805, 34.55800519670759, 33.451389925820486, 33.392615113939556, 33.914987632206504, 34.922386101314, 33.15937103543963, 33.935450077056885, 33.43527357918875, 35.25269651412964, 34.18130166190011, 35.15141609736851, 34.382809843335835, 35.03572164263044, 32.98095519202096, 35.0880902154105, 34.87566988808768, 34.407479422433035, 35.294479506356375, 36.125588280814036, 35.393831798008506, 37.04511635644095, 36.94008043834141, 38.42780440194266, 36.67460019247872, 37.95719943727766, 34.78669820513044, 37.556958879743306, 38.74665723528181, 39.752881458827424, 39.7284620148795, 41.50481414794922, 43.203811986105784, 47.18184675489153, 48.283831051417756, 51.61429371152605, 50.502564566476, 54.74222680500576, 56.06683833258492, 57.830433573041645, 53.02610165732247, 55.512379033224924, 19.83583198274885, 0.8308453943048204, 0.7769007203834397, 0.09435984133077518, 0.2716041329715933, 9.692971536091395, 61.17774908883231, 53.61825145993914, 63.33959075382778, 51.50580106462751, 31.805139337267192, 19.011895486286708, 25.775867802756174, 39.76705925805228, 51.85076870237078, 17.929661444255284, 0.0655560569305505, 0.02269120168473039, 0.05254593165591359, 0.007699654919893614, 0.015585058801142233, 0.027243571156369786, 0.02334544345337365, 0.04263403120317629, 0.018820676786292876, 0.016738208709284663, 0.021190209280965582, 0.023749151433418905, 0.007404533747051443, 0.03357599921790617, 0.16266243159770966, 0.03346465840669615, 27.070878267288208, 65.88304138183594, 49.680377279009136, 41.43512371608189, 20.19202790941511, 27.250014986310685, 38.611542565482004, 55.927203859601704, 53.62790598188128, 60.398494720458984, 33.65317256110055, 0.08720633839922291, 0.13242830894887447, 1.906025494847979, 0.5649130269885063, 2.9029078653880527, 59.966261182512554, 52.083967617579866, 59.19137028285435, 52.98916155951363, 54.7486434664045, 49.568035330091206, 49.63733318873814, 44.840890952519004, 48.156703335898264, 50.975170612335205, 49.55464267730713, 48.24471616744995, 48.18295363017491, 40.97508001327515, 36.3963873726981, 37.88540717533657, 36.52119786398751, 37.22680132729666, 36.326349530901226, 35.90760939461844, 36.05124602999006, 35.864405495779856, 35.354008197784424, 34.44175836018154, 34.95206185749599, 35.52291543143136, 34.719505650656565, 33.45049013410296, 33.75082949229649, 33.1620808328901, 34.72768368039812, 34.709496770586284, 34.92689895629883, 35.86693811416626, 34.95007119859968, 36.45954997198922, 34.69698306492397, 34.886592456272666, 34.2358033316476, 32.822647435324534, 34.95764820916312, 35.85518871034895, 35.01866381508963, 37.12366574151175, 34.9068603515625, 35.60393490110125, 42.05920743942261, 39.75371176855904, 36.95083277566092, 36.492734568459646, 35.892736775534495, 34.86796086175101, 35.40122468130929, 34.80190086364746, 33.683365958077566, 36.98659862790789, 39.74662460599627, 47.06559991836548, 43.86036811556135, 43.31180088860648, 47.04973370688302, 47.57128981181553, 48.52203266961234, 47.65486969266619, 42.43222842897688, 45.07556288582938, 45.48706994737898, 44.57682466506958, 43.523418698992046, 41.31551742553711, 39.44217191423689, 35.05290106364659, 33.91317067827497, 36.49797003609793, 36.443134852818076, 36.55920103618077, 36.767699105399, 33.90975563866751, 36.88732624053955, 38.152315276009695, 39.86148527690342, 40.6943484715053, 40.70766816820417, 36.691456522260395, 35.10138211931501, 36.9045855658395, 35.255618231637136, 35.31300687789917, 34.86477858679635, 34.42010429927281, 34.86444507326399, 35.76265607561384, 35.107044901166645, 35.98336212975638, 34.718671866825645, 36.002163955143516, 35.6703770501273, 35.84708016259329, 36.04024703162057, 37.07196419579642, 34.67180279323033, 37.093562671116416, 36.86485229219709, 36.92186573573521, 38.209005628313335, 36.75166266305106, 38.68190697261265, 38.46503632409232, 37.26860863821847, 40.95714323861258, 38.2738253729684, 39.31471415928432, 37.7904565674918, 39.838490213666645, 39.385349546160015, 41.841325828007285, 42.14640038354056, 44.278076444353374, 44.11725343976702, 49.787118979862754, 50.01205996104649, 54.23021057673863, 52.068945612226216, 57.48650469098772, 57.00026280539376, 60.6746369770595, 54.270298208509175, 59.77381692613874, 21.5552453654153, 0.7932495059711593, 1.357570958989007, 1.0329216995409556, 0.30813830399087494, 11.19603191103254, 69.01394135611397, 57.315509523664204, 68.3934463773455, 57.807820660727366, 36.50453608376639, 19.72527050971985, 29.989151205335343, 46.079431670052664, 60.0543851852417, 22.59879878589085, 0.1167911844594138, 0.020248874256919538, 0.0164752763895584, 0.028065190550738146, 0.03815543884411454, 0.042215497232973576, 0.06635058751063687, 0.1474398784339428, 0.18727637082338333, 0.11435425308133874, 0.08957692262317453, 0.09245349719588246, 0.16432203325842107, 0.13911806712193148, 0.258089615298169, 0.09513111851577248, 30.94191598892212, 75.04156616755894, 56.68939692633492, 49.079590865543906, 24.98678868157523, 27.82773859160287, 42.505705629076274, 62.30570575169155, 57.40340770993914, 65.39865466526577, 37.447486536843435, 0.17451037227043084, 0.42501701946769443, 5.527353210108621, 1.677446914570672, 3.607154041528702, 63.85793331691197, 54.77135712759835, 60.38342407771519, 55.01874426433018, 56.28003338405064, 51.01478576660156, 51.31278705596924, 44.25693655014038, 48.54492003577096, 52.872438771384104, 50.270984581538606, 50.73781320026943, 48.86604840414864, 43.596058641161235, 38.67532008034842, 39.412020206451416, 38.686214855739046, 41.22053902489798, 38.39625610624041, 37.032421997615266, 38.70857763290405, 38.53270483016968, 37.415768010275706, 36.085573605128694, 38.22792904717581, 38.380518436431885, 36.5531074660165, 35.796667507716585, 36.90860162462507, 35.974166188921245, 36.17451402119228, 35.15700592313494, 36.12245116915022, 37.03743164879935, 36.131469930921284, 37.79972546441214, 37.36918381282261, 36.30329540797642, 36.30839885984148, 34.93019240243094, 36.930092402866904, 38.076183864048545, 37.68772745132446, 38.30021810531616, 36.26804372242519, 37.67379978724888, 42.03310305731637, 42.77836683818272, 39.069474015917095, 37.43979835510254, 38.86547143118722, 37.12058768953596, 37.627590792519705, 36.703622817993164, 35.86341190338135, 38.787540435791016, 42.27771438871111, 48.06264557157244, 46.41328566414969, 45.68806048801967, 48.78083569662911, 48.545013836451936, 48.868025166647776, 49.821522985185894, 44.607862268175396, 45.164100306374685, 47.63312183107649, 45.25912734440395, 45.86001450674874, 44.724751813071116, 41.42646973473685, 35.314393043518066, 35.663710253579275, 38.89682517732893, 38.30583572387695, 37.7220585005624, 39.970787388937815, 35.793916021074565, 37.687842096601216, 41.13437441417149, 42.14913102558681, 42.68493093763079, 40.98249026707241, 36.93516458783831, 36.38463796888079, 38.60411146708897, 38.03124986376081, 36.08892263684954, 37.329328945704866, 36.26547983714512, 37.65752363204956, 38.123622689928325, 36.567313058035715, 37.22385876519339, 37.183833667210166, 38.815625054495676, 38.61429405212402, 39.09315000261579, 39.14882244382586, 41.45934861046927, 36.24655294418335, 39.45105518613543, 40.314205578395296, 39.73552138464791, 40.38310391562325, 39.804829665592735, 39.3244868006025, 40.352330344063894, 40.29887090410505, 42.665135519845144, 40.99326344898769, 41.59973348890032, 38.28310816628592, 40.662925243377686, 43.863331522260395, 43.491199902125764, 44.0406426021031, 46.02282469613211, 46.39788498197283, 52.42033338546753, 52.15645817347935, 55.12904691696167, 55.52931179319109, 58.95398507799421, 58.125898769923616, 64.0042415346418, 56.78421204430716, 60.26839665004185, 27.904811484473093, 1.0834081790276935, 3.7336570705686296, 1.365534137402262, 0.5380999829087938, 12.213411467415945, 74.02065345219204, 62.984676769801546, 75.397536277771, 63.67353507450649, 43.62933703831264, 28.184884684426443, 39.29780919211251, 55.32960319519043, 68.56804071153913, 29.36640501022339, 0.2626685867352145, 0.10769697637962443, 0.1202191026615245, 0.09427714148270232, 0.14064585656992026, 0.11469654685684613, 0.14417484934840882], [0.10292388964444399, 0.029011395759880543, 0.034515922889113426, 0.07766320476574556, 0.039300480258784125, 0.06017782552433865, 0.06174267655504601, 0.02025803447967129, 0.0703549279964396, 11.91577843257359, 59.00222642081124, 40.44131244931902, 30.075993265424454, 15.190504380634852, 30.394067900521414, 37.11300025667463, 40.47620977674212, 49.88171175548008, 53.7961357661656, 34.82404824665615, 0.18357623794249125, 0.1605992644493069, 0.3397983951228005, 0.012212526868097484, 2.601526928799493, 48.38246767861502, 52.72235073362078, 57.69329350335257, 50.72432327270508, 57.50483751296997, 42.67225047520229, 44.9999942779541, 45.60242394038609, 50.444356032780235, 48.92207520348685, 48.01826047897339, 49.30734934125628, 45.4022011756897, 41.05533518110003, 37.310728618076865, 35.48432166235787, 34.99203484398978, 34.90057570593697, 32.72794696262905, 32.681998525347026, 32.188297748565674, 32.33201428822109, 33.6063278062003, 32.81900657926287, 32.8794698034014, 31.83877556664603, 31.065868377685547, 32.1283278465271, 31.913416590009415, 31.33318989617484, 31.932822908673966, 31.53110933303833, 33.05139602933611, 35.238150460379465, 35.691305024283274, 33.52019446236746, 34.221302441188264, 33.35677283150809, 33.05153151920864, 33.619067328316824, 33.574425152369905, 33.93560641152518, 34.554819447653635, 33.846360274723594, 33.54298455374581, 35.505256584712434, 38.946654183524, 39.93300308500017, 38.10457420349121, 37.0324706350054, 34.37947470801217, 33.392837456294465, 33.85876628330776, 34.14742224557059, 35.01705183301653, 35.613460881369456, 40.04975714002337, 41.303576946258545, 40.69025945663452, 42.86104345321655, 45.03636462347848, 44.5077873638698, 47.05392347063337, 44.687259333474294, 40.600745814187185, 43.624330861227854, 44.37964173725673, 42.58645411900112, 39.732148034232004, 39.826904092516216, 35.82328953061785, 33.36942202704293, 32.36630712236677, 34.83122226170131, 33.373149735586985, 33.97571836199079, 33.46174621582031, 34.08046245574951, 35.83955526351929, 38.136838163648335, 38.394237654549734, 38.74482985905239, 37.80269234521048, 34.99681173052107, 32.9548716545105, 34.34335797173636, 33.082534381321494, 32.84986700330462, 34.40477657318115, 34.28923497881208, 33.8748722076416, 34.9585097857884, 32.629327705928254, 34.56392853600638, 34.48222119467599, 34.849075657980784, 35.16652842930385, 33.598386015210835, 34.094296319144114, 33.2750620160784, 34.62710850579398, 32.956976958683555, 33.037114007132395, 34.509517192840576, 33.253883906773154, 35.07782425199236, 36.4471161706107, 35.418588229588096, 36.09544352122715, 37.343829836164204, 37.055941649845664, 37.51014191763741, 38.55626964569092, 38.73268788201468, 38.47958237784249, 40.11212764467512, 43.53443506785801, 46.68916041510445, 48.47318683351789, 49.34193399974278, 46.11774056298392, 49.82711281095232, 48.767821720668245, 56.78557389123099, 52.7487747328622, 60.61978094918387, 53.97675766263689, 57.970738547188894, 18.63487580844334, 0.685339096401419, 0.703434485409941, 0.5530033803411892, 0.10134563076176814, 8.964970554624285, 64.90870938982282, 51.32732268742153, 66.94782502310616, 52.14124161856515, 47.01928670065743, 22.234376192092896, 27.747000523975917, 47.00664792742048, 48.25317907333374, 11.197354674339294, 0.03194843798077532, 0.04464859488819327, 0.017420781011294042, 0.014936974737793207, 0.025645551637613347, 0.028051129608814205, 0.050859039316752126, 0.03975234726177795, 0.02610799191253526, 0.031217944143073897, 0.06058639860046761, 0.0019540423901552068, 0.036497910107885084, 0.0366814979352057, 0.0895721185952425, 0.06606626776712281, 14.47496325629098, 66.26435852050781, 47.75449991226196, 37.720453466687886, 15.925265959330968, 26.350219794682094, 42.950320856911794, 47.57459020614624, 54.36889662061419, 59.54025323050362, 37.66010141372681, 0.1757515078144414, 0.13303268008998462, 1.9709223210811615, 0.5760606516684804, 3.1886308193206787, 53.35937547683716, 54.477361474718364, 59.70096506391253, 54.17019551140921, 56.48246914999825, 43.32427290507725, 46.01393100193569, 47.12040730885097, 50.78483166013445, 50.744229861668174, 50.73751095363072, 50.47716195242745, 47.669582503182546, 43.015415055411204, 39.844559465135845, 37.572873728615896, 36.68082577841622, 35.914269242967876, 35.05326236997332, 35.98893458502633, 34.42489160810198, 33.909123352595735, 34.738901547023225, 34.64895016806466, 33.881938525608604, 34.385311194828574, 34.85390813010079, 35.090150356292725, 33.692259652274, 33.16506855828421, 34.60255357197353, 33.21331337520054, 35.83459077562605, 34.6597580909729, 35.66316829408918, 34.64540311268398, 36.31779282433646, 35.47110966273716, 34.1812287058149, 33.95372036525181, 35.39482886450631, 35.556621142796104, 34.304027693612234, 35.72511148452759, 36.31703894478934, 37.24063866479056, 39.88498061043875, 41.54314041137695, 39.898376737322124, 37.820139271872385, 36.40805687223162, 34.973983424050466, 36.38956076758248, 35.50884185518537, 35.128507886614116, 37.074552399771555, 40.89277860096523, 45.162856578826904, 42.67191348757063, 44.29200758252825, 47.27750607899257, 46.2511042867388, 48.37797219412667, 45.820083209446494, 40.88962064470564, 43.6765569959368, 45.67256947926113, 43.83772741045271, 40.42132943017142, 41.55661991664341, 38.176300457545686, 35.38895068849836, 34.72225366319929, 35.49511568886893, 36.27588823863438, 35.21271310533796, 34.748017583574565, 35.225681918007986, 37.91103907993862, 39.06065675190517, 40.57898753029959, 39.30600459235055, 40.33094726290022, 35.713521889277864, 35.706327029636924, 36.66586978094918, 36.505630425044465, 36.000253200531006, 35.63034152984619, 35.96822200502668, 36.66506378991263, 36.56476654325213, 35.13329519544329, 36.6689304624285, 35.60291351590838, 34.91004957471575, 36.68316732134138, 35.371486391339985, 36.59041929244995, 35.015057700020925, 36.44090795516968, 34.608397006988525, 36.03193003790719, 38.063826492854524, 35.30153887612479, 38.66057252883911, 37.60225766045706, 36.95280606406075, 37.44038200378418, 39.358063970293315, 38.22757468904768, 39.43087066922869, 40.91637815747942, 40.951522145952495, 39.51389469419207, 42.21004588263375, 46.52739245550973, 48.45745611190796, 49.13133062635149, 50.6681991985866, 48.035808154514854, 52.38277837208339, 52.02919496808733, 59.569213322230745, 55.137249265398296, 61.17879131862095, 55.88744279316494, 60.5150785446167, 20.992253678185598, 0.6873713902064732, 1.9748830114092146, 0.6830952082361493, 0.21341299691370555, 10.058706470898219, 70.18841620853969, 58.22478205817086, 69.17246450696672, 57.74963297162737, 47.603522505079, 21.22762737955366, 34.95293385641915, 52.45767647879464, 59.09475558144705, 14.65607500076294, 0.052081711922905276, 0.04125097327466522, 0.015390588968460048, 0.05058627502460565, 0.013898380200511642, 0.03899740920002971, 0.013265065300012273, 0.17441824078559875, 0.12966399799500192, 0.17254032726798738, 0.2179275346653802, 0.13406418902533396, 0.1731172041701419, 0.21498003282717296, 0.14857353403099946, 0.1856224959982293, 16.379466227122716, 75.19219616481236, 53.20720992769514, 46.57335826328823, 23.469722475324357, 37.88815171377999, 48.70636143003191, 52.550844873700825, 58.321421078273225, 64.11565589904785, 42.76625612803868, 0.5199421143957547, 0.3744435789329665, 5.314356616565159, 1.5003438464232852, 4.543132628713336, 59.21744687216622, 55.02272210802351, 61.518252508980886, 54.39674847466605, 59.16860103607178, 43.88164349964687, 46.816194329942974, 47.81304890768868, 51.82391391481672, 51.46896171569824, 52.423512186322895, 53.33649853297642, 49.41585241045271, 44.66571644374302, 40.93838310241699, 39.660998480660574, 38.62711347852434, 38.94360045024327, 36.1402177129473, 38.08719675881522, 36.02402646200997, 36.207900115421836, 37.885643414088655, 37.18814502443586, 37.24487706593105, 35.629410471235005, 36.39229488372803, 37.16556337901524, 37.22307709285191, 34.98046261923653, 36.29997764314924, 35.01168782370431, 37.143395151410786, 38.48167725971767, 38.32515171595982, 36.21081141063145, 38.7375933102199, 36.15311704363142, 36.31233501434326, 36.6973694392613, 36.76129634039742, 37.41258226122175, 36.393785272325786, 36.439157009124756, 37.43081086022513, 38.499989237104145, 42.4739419392177, 42.71303987503052, 40.70708104542324, 41.18465852737427, 38.243503434317454, 36.208799907139365, 38.35395894731794, 36.829148973737446, 37.77196741104126, 38.85748100280762, 44.381913798195974, 46.69883925574166, 42.33702768598284, 46.754643712724956, 48.36922788619995, 49.26768207550049, 51.72933850969587, 48.618167945316856, 42.8430233001709, 45.27433695111956, 48.498929909297395, 47.52338545663016, 42.85107626233782, 43.56714718682425, 41.006909711020334, 37.619204316820415, 36.60591377530779, 39.13745519093105, 36.91579648426601, 37.8969064440046, 36.57045364379883, 37.92825671604702, 39.05040468488421, 41.10862439019339, 42.844777720315115, 40.79659468787057, 42.34135641370501, 37.31910467147827, 38.12386587687901, 37.84292241505214, 37.78048937661307, 36.689969607761924, 38.08918046951294, 39.50115169797625, 38.20294679914202, 39.30153342655727, 36.30688762664795, 39.09862865720476, 37.217223235539024, 38.41633987426758, 39.06813996178763, 37.19055257524763, 38.46835061482021, 37.12367616380964, 39.24285241535732, 37.08311952863421, 38.55640860966274, 40.59327302660261, 37.474292687007356, 39.936167989458355, 39.99460233960833, 39.14664765766689, 40.11792939049857, 42.90376097815377, 41.57339286804199, 41.373121465955464, 43.02155378886631, 42.487150464739116, 41.6603113583156, 44.035365445273264, 50.13317748478481, 50.67716932296753, 52.84932558877127, 53.770090443747385, 49.76607288633074, 55.9323524747576, 53.134549140930176, 61.096997124808176, 58.807051522391184, 64.4609466280256, 57.39531305858067, 62.76324462890625, 24.688426085880824, 0.9519569469349725, 3.501299104520253, 1.6545280643871851, 0.21734706152762684, 11.417780194963727, 76.56859956468854, 62.3726863861084, 77.25762462615967, 64.85737609863281, 57.582292556762695, 31.09308794566563, 44.15735844203404, 61.07094138009207, 68.36598014831543, 19.52161012377058, 0.12168863309281212, 0.08880299915160451, 0.1224757337144443, 0.10672513781381504, 0.1178923382290772, 0.1662854150469814, 0.12808339138116154], [0.052939766951437504, 0.04067583681483354, 0.052914627228996584, 0.06721949909946748, 0.060331004804798534, 0.07381859820868288, 0.02636526694654354, 0.07999222193445478, 0.022283698997593353, 4.655738174915314, 49.863163539341514, 45.658443791525706, 42.602570465632844, 30.84686115809849, 31.547298635755265, 30.19537373951503, 43.89087070737566, 53.316008295331685, 52.04920230593, 42.99498735155378, 0.665629825421742, 0.15700263530015945, 0.3310882853610175, 0.23146878661853926, 2.6756162217685153, 46.98262105669294, 51.01320505142212, 52.50471578325544, 53.64070108958653, 53.62004409517561, 48.497456891196116, 42.17133746828352, 49.03452137538365, 50.669936248234336, 49.60932500021798, 49.42508309228079, 46.24673039572579, 44.499161175319124, 40.68067789077759, 36.57414313725063, 34.844680922372, 35.27422898156302, 34.081185068402974, 34.12046323503767, 32.170899459293906, 32.75106361934117, 33.245910848890034, 32.919265610831125, 32.07856832231794, 34.022847993033274, 33.09192487171718, 31.606611933026993, 33.23850406919207, 31.8867598261152, 32.33179889406477, 30.941787447248185, 32.51385906764439, 33.181640011923655, 32.428840909685405, 34.08261292321341, 34.206210953848704, 34.62238373075213, 31.723491055624827, 33.49723414012364, 32.5880241394043, 33.578885895865305, 32.649918692452566, 33.14352914265224, 34.21698760986328, 36.86283384050642, 33.86635371616909, 38.42970126015799, 38.162021909441265, 37.36397613797869, 36.89796045848301, 34.27793025970459, 34.04333823067801, 32.658166204180034, 31.782397883278982, 36.47366871152605, 32.997127124241416, 40.49577242987496, 36.47147308077131, 41.38518006461007, 43.82181256158011, 43.372976303100586, 45.56801298686436, 42.556660243443076, 43.56888771057129, 40.597983905247276, 42.470426150730674, 43.00392968314034, 41.46985081263951, 40.2971442767552, 39.06628131866455, 37.50722714832851, 33.9312116759164, 32.73327970504761, 34.61865602220808, 32.52854755946568, 33.437222548893516, 35.29574407849993, 35.065779549734934, 36.338164942605154, 35.99725157873971, 37.50571591513497, 39.13566255569458, 38.08787073407854, 33.44587653023856, 33.20114360536848, 35.25944668906075, 32.823085171835764, 33.62850298200335, 32.6292200088501, 32.879845006125315, 33.14792735236031, 33.43712180001395, 34.79690510886056, 34.27758979797363, 32.61779022216797, 34.652069909232004, 34.07540416717529, 34.973983424050466, 33.67409358705793, 34.09038100923811, 32.98444666181292, 34.793149607522146, 33.53264563424246, 34.97131878989083, 35.75359909875052, 34.856329577309744, 35.17447369439261, 35.76241288866316, 36.093824590955464, 36.89733164651053, 35.612293584006174, 38.72017765045166, 36.24760212217058, 38.03311892918178, 37.613819462912424, 44.03102282115391, 48.665794372558594, 52.25671373094831, 50.380755696977886, 50.2317168372018, 49.45012092590332, 53.26763841084072, 51.66312565122332, 55.34211342675345, 53.03464446749006, 57.16576542173113, 54.239614963531494, 61.29397160666329, 19.487338134220668, 0.28772859488214764, 1.744901329278946, 1.143637335726193, 0.1631774939596653, 11.87848310811179, 63.270178249904085, 51.02590635844639, 64.91164152962821, 52.674335207257954, 40.72685561861311, 27.542787756238663, 31.42639650617327, 46.38487448011126, 48.7369578225272, 8.477570925440107, 0.015487134323588439, 0.01876492495648563, 0.06317564751952887, 0.036320137325674295, 0.03237385908141732, 0.008427781518548727, 0.024145929874586206, 0.01682032840991659, 0.05896231146263225, 0.08100952234651361, 0.009823834240835692, 0.05734496217753206, 0.009445770643651485, 0.04069615215329187, 0.023775722864749174, 0.055819187978548665, 5.251163184642792, 59.59954915727888, 49.69925206048148, 47.85756949016026, 28.41220542362758, 28.3631146635328, 38.87803030014038, 47.38444580350603, 56.83682727813721, 56.392674105507986, 46.7156399999346, 0.6764719464949199, 0.07579100451299123, 1.1556177671466554, 0.3653768040239811, 3.3666879619870866, 50.828921454293386, 51.89473342895508, 56.279508795057026, 55.051067284175325, 55.11573416846139, 49.039016859872, 43.685662610190256, 49.65451260975429, 50.954725537981304, 50.35895572389875, 51.8595164843968, 47.06442219870431, 46.44964211327689, 42.55285957881382, 38.33488266808646, 37.411710262298584, 37.79769311632429, 35.18485082898821, 35.930878911699565, 34.118007046835764, 35.255437578473774, 35.92882571901594, 34.66083853585379, 32.99866962432861, 35.73184776306152, 35.969827038901194, 32.85325077601841, 35.95580904824393, 35.46718740463257, 33.79730946677071, 34.15184824807303, 34.22540535245623, 34.945617403302876, 33.952712876456125, 35.867980343954905, 36.65413079942976, 35.497009072984966, 34.343656744275776, 33.79068783351353, 35.336884362357004, 34.41692549841744, 33.93299388885498, 35.11514302662441, 35.96369525364467, 38.17857946668352, 35.4541734286717, 40.740300382886616, 40.07492698941912, 38.35758243288313, 38.04841191428048, 34.99672487803868, 35.028023038591655, 34.36350774765015, 34.9160076550075, 37.189475604466026, 36.0071770804269, 40.56982980455671, 39.53363452638899, 44.31546122687203, 42.85090603147234, 45.241937501089915, 46.53743955067226, 45.26348039082119, 45.53029121671404, 41.77401515415737, 44.576220171792166, 43.532027517046245, 44.66601869038173, 41.91550479616438, 40.17863927568708, 39.57421548025948, 35.6718361718314, 34.58119133540562, 36.381351470947266, 34.159776142665315, 35.203385148729595, 36.39686679840088, 36.44520889009748, 38.239094802311485, 38.13863427298409, 38.08092948368618, 40.6357022012983, 40.833020618983674, 35.6390962600708, 34.650930404663086, 36.38857412338257, 34.760037967136924, 35.292516640254426, 34.44477735246931, 34.8450665473938, 34.34596354620797, 33.94691113063267, 36.42302329199654, 35.79338100978306, 34.028010504586355, 36.113529682159424, 36.34656531470162, 36.531408241816926, 35.86569786071777, 37.41307558332171, 34.94624621527535, 36.40624686649868, 35.208634512765066, 37.57538202830723, 37.48636170795986, 37.111819062914165, 36.85765743255615, 38.17124216897147, 37.94392490386963, 38.6123937198094, 38.384058543613975, 39.50905179977417, 37.88834626334054, 39.68816246305193, 39.66554260253906, 45.09057099478585, 49.163893359048025, 54.2775764465332, 51.67268637248448, 52.79975714002337, 51.272216524396626, 55.881866863795686, 53.78811059679304, 57.531758308410645, 54.07379273005894, 60.15825380597796, 56.33344766071865, 64.01589366367885, 22.123505524226598, 0.29321091356022017, 2.501924501998084, 0.5080152601003647, 0.30249604103820665, 13.140610354287283, 67.0061343056815, 54.940715994153706, 71.0787375313895, 55.21788658414568, 44.89021274021694, 26.99413193975176, 36.091139112200054, 54.33026463644845, 56.87992000579834, 11.057490910802569, 0.05539731900872929, 0.06570742452251059, 0.051157051896942515, 0.04858845079849873, 0.013900578653972064, 0.02080387349373528, 0.0326967263993408, 0.2363908253610134, 0.14905183336564473, 0.18056209039475235, 0.11008909051971776, 0.25072892169867245, 0.17885343065219267, 0.1732835673860141, 0.2540562402989183, 0.15725994934993132, 6.961486152240208, 67.79472705296108, 58.649799891880576, 55.96315731321062, 40.45417356491089, 42.339073930467876, 42.67853512082781, 57.81142677579607, 61.55962208339146, 61.47641045706612, 51.796433789389475, 0.9692912910665784, 0.3999916708895138, 4.372439273766108, 0.9407995513507298, 4.45702360357557, 54.739926951272146, 51.87082815170288, 56.98291662761143, 56.70253944396973, 57.1462653023856, 48.81961011886597, 46.25588812146868, 49.932582991463796, 53.14448159081595, 52.238836015973774, 54.39298949922834, 50.35878201893398, 48.36141463688442, 44.03170721871512, 40.44872965131487, 39.343830585479736, 39.556424617767334, 35.83641815185547, 37.890979630606516, 36.50229181562151, 37.57065030506679, 38.16109432492937, 37.57953357696533, 36.29958506992885, 38.37615149361746, 39.52599498203823, 34.24722269603184, 38.303633144923616, 36.143010888780864, 36.903168133326936, 35.54067850112915, 36.96087987082345, 36.827620370047434, 34.66294036592756, 38.029596192496165, 38.325207301548545, 37.77517747879028, 35.61184889929635, 36.52422380447388, 37.498312609536306, 36.96355492728097, 35.847201756068635, 36.91615431649344, 37.49742671421596, 40.35903188160488, 37.768618379320415, 41.45391164507185, 41.13908529281616, 41.06265163421631, 40.27832160677229, 35.61680991309029, 37.12779297147478, 35.119906016758506, 35.374435901641846, 39.99858365740095, 37.011320318494526, 43.435145309993196, 43.33019624437605, 43.44624505724226, 45.96840640476772, 48.37421669278826, 48.52483974184309, 46.313158648354666, 47.44551352092198, 43.6214473588126, 45.59285627092634, 46.63777848652431, 46.19470228467669, 43.79122311728341, 43.19976118632725, 41.63043063027518, 37.70955521719796, 36.63110099520002, 38.35289239883423, 35.45580278124128, 38.20486102785383, 38.25128541673933, 38.514319896698, 39.31889350073678, 40.23092794418335, 39.80002498626709, 43.81718853541783, 41.66612352643694, 37.93484708241054, 36.62618514469692, 39.07497351510184, 36.47848728724888, 36.748539447784424, 35.227387700762065, 36.47108745574951, 36.059847899845664, 36.35509075437273, 38.92019544328962, 38.99657351630074, 34.99708271026611, 38.786140373774934, 37.23802266802107, 39.707030296325684, 38.30662781851632, 38.943777629307334, 37.06195878982544, 39.73041098458426, 37.65356663295201, 38.528518540518625, 40.882064478737966, 39.60693107332502, 40.05490575517927, 39.540905816214426, 40.31732531956264, 40.36308962958199, 39.998844214848106, 42.95176955631801, 38.459307534354075, 43.17662021092006, 41.00530815124512, 48.2918701171875, 52.88986137935093, 56.91662039075579, 53.724923678806846, 55.63979857308524, 53.498787607465474, 57.3593943459647, 55.810050283159526, 61.81356484549386, 58.024368218013215, 63.27732099805559, 57.90785040174212, 65.98745891026088, 24.45671582221985, 0.35413860848971773, 5.204248947756631, 3.4496709491525377, 0.43417113540428026, 14.585491725376674, 73.86159529004777, 59.55176639556885, 77.83438069479806, 62.86384759630476, 53.79011515208653, 39.31460646220616, 46.61778851917812, 60.31350435529436, 70.39526408059257, 19.219307899475098, 0.16023319480674608, 0.1704022227121251, 0.22833191922732762, 0.18138652401311056, 0.10701160172798804, 0.12525624808456215, 0.09286441121782575], [0.03405802031712873, 0.09354146024478333, 0.02951734878921083, 0.03169481855418001, 0.017110926298690692, 0.05106600606814027, 0.13122954113142832, 0.04967950118173446, 0.0169777841573315, 1.0964847973414829, 42.05970076152256, 52.783282961164204, 42.47313594818115, 29.511479922703334, 20.61647251674107, 28.242903879710607, 43.79939767292568, 51.70654147011893, 50.63096032823835, 48.606901441301616, 2.9606445729732513, 0.3654055196259703, 0.10071744982685361, 0.268658666738442, 5.283493586948939, 51.74650056021554, 55.72287123543875, 55.28744152614048, 54.70697859355381, 52.20388657706124, 52.74286181586129, 45.053144523075645, 46.35530294690813, 50.99180112566267, 49.13594423021589, 48.60985442570278, 46.10517474583217, 42.915642397744314, 41.37937484468733, 36.34660005569458, 35.298842975071494, 34.99407066617693, 33.000573430742534, 33.69931902204241, 33.6299273627145, 33.99122674124581, 33.72175128119332, 34.22669076919556, 33.085456098829, 32.38213511875698, 32.59258215767996, 32.46967199870518, 32.47779791695731, 31.591395378112793, 32.49378572191511, 32.00933299745832, 32.86826235907418, 32.78104509626116, 34.5687575340271, 34.73091459274292, 35.889554500579834, 33.54194927215576, 31.903195789882115, 31.60494089126587, 33.23319217136928, 33.8978533744812, 35.522613184792654, 34.06321702684675, 34.64951297215053, 35.31266989026751, 34.33865056719099, 39.50490719931466, 37.18759264264788, 38.08632823399135, 37.40302848815918, 34.793524810246055, 32.80857038497925, 32.403361865452354, 32.626412936619346, 32.692768233163015, 33.50013153893607, 37.050223282405305, 37.04885796138218, 33.967015743255615, 43.124800545828684, 45.31467819213867, 42.55158111027309, 44.37480231693813, 40.652016571589876, 40.48527717590332, 43.03370271410261, 41.040816920144216, 40.00503853389195, 38.99340513774327, 38.44279514040266, 35.60933365140642, 32.98655891418457, 33.589620862688335, 34.24730607441494, 34.55978046144758, 33.742008754185264, 34.984829562050955, 35.97606652123587, 35.7380907194955, 38.658953598567415, 37.2266971043178, 39.328075545174734, 38.70351587023054, 33.758156367710654, 34.11444956915719, 34.23621327536446, 34.80149091993059, 33.424514293670654, 33.2124240057809, 32.36891617093767, 32.61208575112479, 34.162888935634065, 33.264545917510986, 35.164110456194194, 32.90230505807059, 33.42545230048043, 32.59866183144705, 33.85129002162388, 33.085872990744456, 32.79911388669695, 32.91663224356515, 34.459934847695486, 32.998603616442, 35.191378661564414, 35.02185998644148, 35.81907892227173, 33.85876280920846, 38.12216704232352, 35.580547264644075, 38.38550724302019, 37.47032873971121, 38.01502929415022, 37.46055262429373, 39.829485348292756, 36.64434426171439, 41.826533113207134, 48.071817193712505, 52.12995774405343, 48.887831006731304, 53.090824127197266, 51.96739074162075, 53.44433804920742, 51.08422606331961, 56.2278003011431, 50.465384755815776, 57.70669310433524, 50.59178638458252, 62.44184875488281, 21.10998569216047, 0.35949572388614925, 1.1071835032531192, 0.5381799957581929, 0.13274504909557955, 13.819193141801016, 64.72094127110073, 51.49734858104161, 64.85665348597935, 49.67872708184378, 49.826591696058, 32.77592774799892, 27.155330147062028, 47.70942347390311, 50.02565063749041, 7.96754709311894, 0.15101376308926515, 0.0599552524675216, 0.05331609943615539, 0.06584732487265553, 0.04372810785259519, 0.030269236836050237, 0.042074328022343774, 0.039704021997749805, 0.030095043326062814, 0.05019543206851397, 0.07482293181653533, 0.06219464873096772, 0.006169545730309827, 0.06264717052025454, 0.025058340647124817, 0.06685916986316442, 1.8774382174015045, 49.862117835453574, 57.277864183698384, 48.510859966278076, 33.667725563049316, 24.17226525715419, 33.19427531106131, 46.84133638654436, 55.82569415228707, 52.88409090042114, 54.60565996170044, 3.169021700109754, 0.21346364276749746, 0.40771741632904324, 0.4422698851142611, 6.4409336277416775, 56.33838088171822, 56.193180901663645, 57.46175520760672, 55.42009653363909, 55.23084497451782, 53.77893202645438, 46.666481494903564, 47.927127906254356, 52.45228467668806, 51.54492637089321, 49.853074754987446, 47.077352796282085, 44.5952547618321, 43.075586455208914, 38.05441863196236, 36.79575593130929, 38.06159264700753, 35.260537556239534, 35.72899552753994, 35.427481923784526, 36.18024281093052, 35.792029585157124, 36.31078209195818, 34.729493686131065, 33.58720636367798, 34.138827323913574, 34.073726177215576, 33.32368203571865, 33.04855421611241, 33.16439805712019, 33.53136369160244, 35.526080335889546, 35.35245180130005, 35.17787831170218, 36.30639430454799, 36.73479243687221, 34.66812719617571, 34.56746516908918, 33.555328028542654, 34.38508537837437, 34.726047379629954, 37.27114125660488, 35.480715547289165, 36.38318926947457, 36.34915004457746, 36.22087240219116, 40.95233161108834, 40.586894580296104, 39.424777099064414, 37.713609491075786, 37.0994929586138, 35.28909812654768, 34.18701655524117, 34.627167565482004, 36.331699643816265, 34.828376974378315, 38.3994140625, 38.47152941567557, 36.182570457458496, 46.15602166312081, 44.74849380765642, 45.22553627831595, 46.635593278067454, 43.056610924857004, 41.6015956061227, 43.94020291737148, 42.469390869140625, 41.12850318636213, 40.607742650168284, 39.88720750808716, 38.12951476233346, 34.40273380279541, 35.4367265020098, 35.41134820665632, 35.37582901545933, 35.888939585004536, 36.91865914208548, 36.94803612572806, 36.9032758304051, 39.091496331351145, 38.57181624003819, 40.9771158354623, 39.996513094220845, 36.021080425807405, 36.67937013081142, 36.83109099524361, 35.77220984867641, 34.21185983930315, 35.469931943076, 34.9180816922869, 33.9839380809239, 34.19741106033325, 35.40820762089321, 34.86064440863473, 35.003548009055, 35.31096410751343, 35.20177664075579, 35.7462374823434, 34.742907183510916, 34.706967626299175, 34.604030064174104, 36.84100954873221, 35.742259638650076, 37.286830289023264, 36.46516064235142, 37.072193486349924, 36.276492731911794, 40.09323896680559, 36.84506729670933, 39.684625829969136, 38.82184369223458, 40.84904316493443, 40.208909102848594, 41.88384880338396, 38.40639352798462, 44.46569517680577, 51.466383934020996, 53.69888877868652, 52.92005477632795, 57.02203498567854, 54.304393018995015, 54.65557582037789, 53.286193575177876, 57.981226852961946, 52.504879065922324, 59.95353208269392, 55.03065000261579, 65.73998492104667, 24.23449158668518, 0.2809025597359453, 1.6242363069738661, 0.9364052500043596, 0.07751712974693094, 14.281898873192922, 70.08888326372418, 54.6091479573931, 71.5296756199428, 52.20397342954363, 50.68067121505737, 39.24274124417986, 33.427602767944336, 54.80109541756766, 60.03918947492327, 13.530400821140834, 0.1660728571670396, 0.06366196035274438, 0.03352722612076572, 0.05015232473877924, 0.016356699002374495, 0.01432068004006786, 0.036259001320494075, 0.20899633105312074, 0.14640303621334688, 0.17112958511071547, 0.13513210814978394, 0.1247050469475133, 0.0856316282546946, 0.1818514290664877, 0.18888003405715736, 0.11634491197764874, 2.2002823565687453, 58.245164598737446, 64.69132110050747, 56.66155202048165, 41.08132839202881, 28.338386024747575, 40.299902711595806, 54.49521834509713, 61.344818523951936, 59.08099120003836, 60.31971604483468, 3.7092089653015137, 0.45958468743732994, 2.61622736283711, 1.2249271337475096, 9.373990161078316, 59.0920318875994, 59.10908971514021, 59.56895623888288, 58.32998125893729, 54.50737769263131, 54.88146175657, 46.848197732652935, 48.83632748467581, 54.03404556001936, 53.71014486040388, 51.39217369897025, 49.91906179700579, 45.52751541137695, 44.333335467747276, 39.40817437853132, 40.447815963200156, 39.885685852595735, 36.8357150214059, 38.30242068426949, 38.28399406160627, 38.51987845557076, 37.664774077279226, 39.4176412991115, 36.89639711380005, 37.146959577287944, 37.26585367747715, 38.00502388817923, 37.11954893384661, 35.87498760223389, 35.72415263312203, 37.19667741230556, 38.9333553314209, 37.83619655881609, 38.16041687556675, 38.40114763804844, 40.67860037939889, 37.12044872556414, 36.597909450531006, 34.70958709716797, 36.389067445482524, 36.48196138654436, 39.531831468854634, 38.12946612494332, 37.744376114436555, 39.9729517527989, 36.955870219639365, 42.99790906906128, 40.96926089695522, 41.211152008601594, 41.85813352039882, 38.807485239846365, 35.25251586096627, 34.63952841077532, 36.20048291342599, 36.00423799242292, 36.51971442358834, 41.356202602386475, 40.1928448677063, 39.56964009148734, 45.00658811841692, 45.23908873966762, 48.03174345833914, 47.89502375466483, 44.30582060132708, 43.72062941959926, 45.702544007982524, 44.67589208057949, 44.65940053122384, 42.106660161699565, 42.186640875680105, 41.19470909663609, 36.41262183870588, 37.57181065423148, 36.97864294052124, 37.66913407189505, 37.89574956893921, 39.208264282771516, 38.70103188923427, 38.18066045216152, 40.54210649217878, 41.2438884462629, 43.702494621276855, 42.64076123918806, 39.19327007021223, 39.881100041525706, 37.13402550561087, 39.625166620527, 35.51997981752668, 36.737787110464915, 35.25463506153652, 36.28058869498116, 36.83599294934954, 37.49299028941563, 37.022458280835835, 36.09184782845633, 36.20758397238595, 36.92600686209542, 38.66537373406546, 37.541016238076345, 37.27204104832241, 36.52973025185721, 39.57282584054129, 37.53135476793562, 39.99541180474417, 39.809811523982454, 40.16374233790806, 37.975931780678884, 42.602872712271555, 39.364272185734336, 43.13448633466448, 41.216418743133545, 42.98844562258039, 41.32821525846209, 43.940995012010845, 40.28765998567854, 45.77458987917219, 51.847395351954866, 56.725537981305806, 55.093993255070274, 58.53484194619315, 56.292550563812256, 57.281689167022705, 54.673095703125, 60.576285226004465, 54.75435141154698, 60.668647629874094, 57.40261214120047, 67.56707627432687, 26.805799279894146, 0.45786538826567785, 3.8860888225691657, 2.577231901032584, 0.2975520177611283, 16.676202944346837, 75.38213212149483, 59.86801365443638, 75.97594601767403, 61.57169805254255, 62.639705657958984, 43.70025382723127, 41.71861021859305, 62.738654954092844, 72.73832866123745, 19.43862083980015, 0.339738629758358, 0.11231157769049917, 0.14370492313589367, 0.27487689735633986, 0.15730173353637966, 0.10817370829837662, 0.10956758886043515], [0.01459602446162275, 0.02839447002458785, 0.007264698705902057, 0.03647481956120048, 0.031081565389675752, 0.028133298503234982, 0.03888436865859798, 0.023337104257994463, 0.0680503991565534, 0.44972033532602446, 35.420141151973176, 52.099159853799, 40.0050003187997, 28.230209520884923, 23.684654576437815, 27.71130415371486, 43.69450419289725, 56.44863837105887, 48.95791053771973, 53.71053048542568, 5.432297076497759, 0.20994884494159902, 0.36172468428100857, 0.6083379111119679, 12.208590286118643, 58.67677279881069, 51.95559270041329, 55.16775533131191, 50.97223152433123, 52.09389311926705, 50.582451479775564, 55.06552995954241, 50.635163988385884, 50.85909053257534, 47.75309290204729, 49.408577646527974, 45.90548351832798, 43.06989588056292, 39.15653494426182, 36.57749564307076, 33.343359334128245, 35.141257831028526, 33.75364351272583, 34.91788714272635, 33.55461236408779, 31.32946913582938, 32.66738646371024, 33.34781312942505, 32.07146726335798, 33.161837645939414, 31.634050369262695, 32.73141411372593, 30.359097617013113, 30.370850494929723, 30.624720300946915, 33.038013798849924, 32.26789631162371, 34.207670075552805, 33.234015532902305, 33.47692802974156, 32.66346420560564, 34.05767931256975, 32.23307194028582, 34.446830545152935, 32.58150325502668, 33.333805561065674, 33.54820959908621, 33.523498330797466, 35.27370091847011, 34.45764194216047, 36.06671619415283, 39.59545612335205, 40.0604955809457, 38.58542776107788, 36.76201547895159, 35.25018126623971, 32.52485459191458, 32.43705368041992, 32.67132609231131, 33.01651954650879, 33.73825672694615, 35.56757150377546, 36.97681903839111, 38.20430864606585, 33.11495467594692, 43.11354446411133, 46.56398514338902, 42.82752186911446, 39.592708110809326, 37.565334933144705, 41.29842138290405, 38.408061095646445, 39.57923902784075, 38.27942909513201, 37.76234415599278, 36.29059757505144, 32.851725646427695, 33.006885869162424, 33.241220814841135, 33.56695236478533, 34.28500699996948, 34.10095269339425, 33.908977440425325, 35.11521945680891, 36.41292755944388, 38.46608550207955, 39.86882257461548, 38.663087776729036, 35.16879006794521, 34.78540931429182, 34.275199617658345, 34.90889964784895, 32.6748696735927, 34.502197265625, 32.182270186288015, 32.72121415819441, 34.13706942967006, 32.53962298801967, 34.618096692221506, 34.053684098379954, 35.42531061172485, 33.172791481018066, 34.48681395394461, 32.88662297385079, 32.96291766847883, 32.919435841696604, 33.97437735966274, 32.381787708827424, 34.256804261888774, 35.400081702641074, 33.896606172834126, 33.89763103212629, 36.45798315320696, 34.551790033067974, 36.15919671739851, 35.8673689024789, 36.14014823096139, 36.56805998938424, 39.112393038613455, 37.921402318137034, 43.97157750810896, 49.13000004632132, 52.34849943433489, 48.21991804667881, 56.44800955908639, 50.415038108825684, 54.902775355747764, 52.29190635681152, 54.24065024512154, 51.07249402999878, 58.531993184770855, 52.50429194314139, 63.99401378631592, 19.03924880708967, 0.1667319182306528, 0.04882528666140778, 0.08957837468811444, 0.1622210717094796, 15.224356004170009, 64.53809247698102, 53.165016991751536, 61.77399485451834, 47.55493722643171, 32.474282128470286, 24.36293945993696, 26.582633563450404, 49.24763304846627, 54.222161088671, 7.0502893413816174, 0.068021384999156, 0.03571240743622184, 0.04915426079449909, 0.08947002621633665, 0.010537396085315516, 0.044724275291498215, 0.0410205529603575, 0.012014800067325788, 0.09862317184784583, 0.02009159492860947, 0.044952008607132096, 0.006213907077575901, 0.03648211041997586, 0.04315831485603537, 0.02553473669104278, 0.06342766899615526, 0.638379696224417, 41.158981459481375, 57.8742732320513, 46.51876974105835, 33.98651238850185, 21.911649738039287, 36.363359110695974, 46.96449668066842, 58.46326160430908, 52.91631317138672, 56.22684144973755, 5.995661360876901, 0.42214885194386753, 0.5444884172507695, 0.4565724804997444, 12.7585688659123, 61.326975549970356, 53.52978352137974, 56.39444242204939, 52.07884332111904, 54.35796363013131, 52.56199325834002, 55.75141096115112, 50.74072102137974, 50.21584367752075, 49.569810594831196, 49.38801792689732, 47.38274002075195, 46.12630074364798, 41.20044136047363, 38.01525511060442, 35.16974891935076, 35.635250432150706, 35.895978110177175, 36.08419438770839, 36.04150118146624, 34.4746858733041, 34.59406287329537, 35.13368776866368, 33.25206000464303, 33.801839692252024, 32.85020399093628, 34.08645180293492, 33.7272229875837, 32.87512023108346, 32.26158734730312, 34.897647040230886, 34.347599846976145, 35.087398869650706, 35.64997713906424, 35.47474009650094, 34.692657811301096, 34.77832909992763, 33.38318640845162, 35.163221086774556, 35.29508399963379, 34.43681124278477, 33.44193690163748, 35.499847412109375, 36.219277790614534, 36.701701641082764, 36.1683474949428, 40.77304376874651, 41.17380544117519, 38.61339773450579, 36.710362570626394, 36.68608903884888, 35.01919535228184, 34.414229597364155, 34.18468543461391, 36.08489268166678, 34.63421303885323, 36.843406677246094, 39.31778873716082, 38.97300522668021, 37.22279569080898, 46.672595909663606, 47.30682052884783, 45.18297161374773, 41.89461851119995, 38.8431989806039, 42.46541649954659, 40.83459786006382, 41.20975889478411, 39.84430585588728, 40.83249255589077, 37.15234790529524, 35.28024959564209, 34.70989976610456, 35.43606989724295, 34.63158661978585, 35.06773199353899, 36.91647045952933, 36.04722302300589, 36.745683738163535, 38.197961466653005, 39.363799708230154, 41.668579714638845, 41.03457396371024, 35.97890486036028, 36.8211863381522, 36.583964415958945, 36.85749762398856, 35.04485852377755, 35.916360650743755, 33.632849080221995, 34.891299860818044, 36.07896934236799, 34.876489775521414, 35.70975596564156, 34.800292355673655, 34.99480717522757, 35.658513001033235, 35.58549785614014, 34.425197328839985, 34.78731312070574, 35.56712334496634, 36.468433243887766, 35.430650302342, 35.70028904506138, 36.52398061752319, 36.74603462219238, 36.586205210004536, 37.90325014931815, 38.5706524167742, 39.31832374845232, 37.705771923065186, 37.60674272264753, 37.278700896671836, 41.120787211826865, 38.88260916301182, 47.19294997623989, 51.172245843069895, 53.27553851263863, 50.10384566443307, 58.984994888305664, 52.79610586166382, 57.98193209511893, 54.352644784109934, 56.66997671127319, 52.42368589128767, 59.51271751948765, 52.73653200694493, 66.03583226885114, 20.692541394914898, 0.12296627382082598, 0.5139993961368288, 0.21614799515477248, 0.2043368446507624, 16.708463430404663, 69.94420787266323, 55.788132190704346, 66.34339427947998, 55.19661814825875, 42.42572838919503, 29.220496313912527, 33.447926248822895, 55.2506890296936, 62.63789912632534, 9.913165160587855, 0.09421082825532981, 0.06199344274188791, 0.02882755348192794, 0.03947811394131609, 0.02079491683148912, 0.03435599897056818, 0.03988078376278281, 0.17142044593180927, 0.2533247252660138, 0.10486608078437192, 0.15337414214653627, 0.0991093557594078, 0.17484114452132157, 0.13894870478127683, 0.15457451130662644, 0.18995160370000772, 0.9340806433132717, 47.486038889203755, 65.66013622283936, 53.629191398620605, 41.00346687861851, 30.93906375340053, 37.81381641115461, 55.863600049700054, 66.26993792397636, 57.01455872399466, 61.57656873975481, 6.849584111145564, 0.5780249291232654, 2.365715056657791, 1.0024273587124688, 16.764055967330933, 63.731163433619905, 55.826958724430625, 57.7617541040693, 55.0354060445513, 55.507181780678884, 55.31862851551601, 56.128548758370535, 53.08894116537911, 54.16142341068813, 51.16060413633074, 52.043365819113596, 49.70237874984741, 47.626868452344624, 43.289462430136545, 41.0492068699428, 37.39987400599888, 38.00521843773978, 36.670403480529785, 39.039881638118196, 37.94011729104178, 36.28430945532662, 36.50725630351475, 36.76060846873692, 37.00461530685425, 37.9073600087847, 35.68773365020752, 35.938056400844026, 35.70559746878487, 35.189134393419536, 35.97966916220528, 36.38150085721697, 35.88105337960379, 37.59096336364746, 36.83811214991978, 36.45717021397182, 36.49773727144514, 37.386644635881694, 35.238671575273784, 39.13561739240374, 37.04914631162371, 35.80030836377825, 36.49370731626238, 38.274151938302175, 37.83322620391846, 37.18238149370466, 37.96206317629133, 42.249171188899446, 43.29506267820086, 41.50866344996861, 37.80112205232893, 37.95180416107178, 35.90401370184762, 34.84326001576015, 35.2033816746303, 37.60256685529436, 37.10014956338065, 38.84170511790684, 40.426721232278005, 41.442117077963694, 41.73786020278931, 48.16126830237252, 46.56311314446585, 47.87620803288051, 42.40404653549194, 40.463987895420615, 44.3930343900408, 42.52707828794207, 42.257488182612825, 41.15294694900513, 42.206015927451, 39.711567470005576, 37.10811914716448, 37.342329025268555, 36.1313031741551, 36.92318936756679, 38.65377719061715, 38.20625761577061, 38.901991162981304, 38.70249448503767, 38.76401383536202, 41.22988782610212, 44.12620619365147, 43.69694301060268, 38.3612128666469, 37.69076034000942, 38.433203152247835, 39.101658071790425, 36.34237207685198, 38.36481550761631, 35.569433620997835, 37.65527241570609, 37.94069399152483, 36.55530309677124, 38.106002058301655, 37.105256489345, 37.93629925591605, 36.88670437676566, 38.82634265082223, 36.99626704624721, 36.488659449986045, 36.75703362056187, 39.14709234237671, 37.058095591408865, 39.01821715491158, 40.40931599480765, 37.86676863261631, 38.2565313066755, 40.92995146342686, 39.58415140424456, 41.15805387496948, 39.689819608415874, 38.82562698636736, 40.445929527282715, 42.44993243898664, 41.343622888837544, 49.188788754599436, 51.87879426138741, 55.5879476411002, 52.72535930361067, 61.30396311623709, 56.81925180980137, 60.43960721152169, 55.682286807468955, 58.273134572165354, 54.509066104888916, 62.532369886125835, 55.62676722662789, 69.28562981741769, 23.594359261648997, 0.29686094341533525, 1.4483194266046797, 2.6833595548357283, 0.29587755618350847, 18.43081590107509, 76.56461824689592, 60.82230704171317, 71.00604547773088, 60.025980949401855, 45.77846697398594, 34.07510192053658, 42.12905420575823, 64.20239721025739, 72.61910452161516, 15.003759384155273, 0.20320067847413675, 0.1432130259594747, 0.13134497350880078, 0.16047617819692406, 0.08999054399984223, 0.1730836166867188, 0.11868393075253282], [0.025669956845896583, 0.0393961265550128, 0.03522290888109377, 0.025388288477967893, 0.05750431612666164, 0.035287013476980586, 0.13185521827212401, 0.04143062559887767, 0.04453625323783074, 0.09994729900998728, 26.44452943120684, 54.997868401663645, 40.6866637638637, 33.283993925367085, 22.937014511653356, 26.1677896295275, 38.50733348301479, 56.16202517918178, 47.271537576402935, 58.400442940848215, 12.288176689829145, 0.34643373478736195, 0.22089083279882157, 0.31630249161805424, 23.90667036601475, 62.75933974129813, 52.15366152354649, 55.151784896850586, 49.13312326158796, 50.8060062953404, 48.22675507409232, 48.638637338365825, 50.964776107243125, 50.89596462249756, 47.70224251065935, 47.0844156401498, 45.392233984810964, 41.84660645893642, 35.83845049994332, 35.746640477861675, 34.20493943350655, 34.06892844608852, 34.1709314755031, 32.67717300142561, 31.509340626852854, 31.21071399961199, 31.408699444362096, 31.44475017275129, 31.86959777559553, 32.639388697487966, 31.348295279911586, 31.035341467176163, 30.963514464242117, 30.50853599820818, 32.27967003413609, 31.18048586164202, 33.07759421212332, 33.04908922740391, 33.286394527980256, 33.780564308166504, 32.27786002840315, 32.31108978816441, 32.81326389312744, 32.50579220908028, 32.165094239371165, 34.86655385153634, 32.825134890420095, 34.812271050044465, 35.09526770455496, 32.91754593167986, 34.182020800454275, 39.148561886378694, 40.796938623700825, 39.0348025049482, 36.672779764447895, 35.93017366954258, 36.3810179574149, 34.62680278505598, 34.16500118800572, 34.235907554626465, 34.075508390154155, 33.214741230010986, 34.704952648707796, 37.25800568716866, 37.95134557996477, 34.38161127907889, 41.365388120923726, 47.30676146915981, 37.87401212964739, 38.923989159720286, 38.651974133082796, 39.50553253718785, 40.111752441951204, 39.14495924540928, 36.05923645836966, 34.545154503413606, 33.75245189666748, 34.12656722749983, 34.05645990371704, 35.14822687421526, 34.93497276306152, 33.70289734431675, 34.961195264543804, 36.08158881323678, 35.646575995853965, 37.47765908922468, 41.26224211284092, 37.96136488233294, 34.01007720402309, 33.33930853434971, 34.992462158203125, 32.69027382986886, 35.2233646937779, 32.95857504435948, 32.84152569089617, 32.8454201562064, 34.55010162081037, 35.24685307911464, 33.30400473730904, 33.52914374215262, 34.330698353903635, 34.766617911202566, 34.70086710793631, 31.85759128843035, 33.26816592897688, 32.72476121357509, 34.04349456514631, 34.062320709228516, 34.96669476372855, 32.12798738479614, 34.97842679704939, 34.87646198272705, 34.69105972562517, 36.0445236478533, 36.02171618597848, 35.31949649538313, 36.91698462622506, 36.848638670785085, 41.22310985837664, 43.37876762662615, 48.65957920891898, 49.70706530979702, 51.13616732188633, 47.2781001499721, 53.24618584769112, 52.19568075452532, 55.0935138293675, 51.01717594691685, 54.01286397661482, 50.1358699117388, 58.03261225564139, 52.467098236083984, 64.43535641261509, 16.357937233788626, 0.22032350966972963, 1.0062516906431742, 0.4694452126111303, 0.06801953938390527, 17.453720263072423, 67.037109375, 50.74395540782383, 64.93627289363316, 43.04028960636684, 32.33329275676182, 25.855207545416697, 33.648103850228445, 48.83274221420288, 56.26430613654, 10.008117505482264, 0.12410098793251173, 0.04678466383899961, 0.09006786306521722, 0.025796763166519146, 0.017400772709931647, 0.04696184629574418, 0.06044925310249839, 0.04004246508702636, 0.009130143294376987, 0.037414023985287974, 0.0575638779305986, 0.03147931922493236, 0.0565485690188195, 0.0845757599121758, 0.019852838811597655, 0.0346108194041465, 0.14782008874629224, 31.019252913338796, 62.66415636880057, 46.75678375789097, 41.546451228005544, 22.573590721402848, 27.958939688546316, 45.601159368242534, 59.298539297921316, 51.488128321511404, 60.89747960226876, 12.923837849072047, 0.6566516671861921, 0.32787411926048143, 0.34008997519101414, 25.567447900772095, 64.80643190656389, 54.763533455984934, 57.980549403599326, 50.09026541028704, 51.121523993355886, 50.20771081107003, 50.789810044424875, 51.806654589516775, 51.439115728650776, 49.16292061124529, 50.47390324728829, 47.152573994227815, 43.87357316698347, 38.88965463638306, 37.629664829799104, 35.830463545663015, 36.92590611321585, 36.37422956739153, 34.72233009338379, 34.02662781306675, 33.69451434271676, 32.960322516305105, 34.020892075129915, 35.0782585144043, 34.994254793439595, 34.38259097508022, 33.677077838352744, 32.7964631489345, 32.537604536329, 34.116273471287315, 32.85178818021502, 34.18485566547939, 34.44573620387486, 35.25659097943987, 34.92948021207537, 33.412740571158274, 34.75628593989781, 34.820820808410645, 33.48605796269008, 33.78732490539551, 35.23630918775286, 34.69978666305542, 36.36840350287301, 36.3281386920384, 34.2872964314052, 34.03273180552891, 38.924982752118794, 41.847276960100444, 41.360524381910054, 37.5721789087568, 37.27880164555141, 37.054340090070454, 34.98476702826363, 34.99580076762608, 35.57763596943447, 34.2477959224156, 35.98613793509347, 37.16526460647583, 37.835769244602744, 39.15492296218872, 36.76686879566738, 45.57203599384853, 46.818984031677246, 39.54663808005196, 39.767854826790945, 41.129062516348704, 40.839152404240195, 42.35795566013881, 41.08547299248831, 38.59600291933332, 36.79648201806204, 35.37240702765328, 36.646658011845176, 36.46972213472639, 37.39122002465384, 37.76502616064889, 35.40415334701538, 36.664382866450715, 38.09963403429304, 37.940054757254465, 39.03629289354597, 42.573141370500835, 40.59225164140974, 36.815391540527344, 35.6194224357605, 37.02737760543823, 34.530886377607075, 35.891013622283936, 35.896054540361675, 34.72287900107247, 33.69669260297503, 35.38093941552298, 35.5409494808742, 34.86708191462925, 35.01605476651873, 35.68010105405535, 34.83278560638428, 36.352975027901785, 34.79278482709612, 35.74874578203474, 34.92450530188424, 35.22423321860177, 35.237532070704866, 37.943619183131624, 34.90197924205235, 36.392326150621685, 36.880291189466206, 36.61326844351632, 37.24167047228132, 38.527316502162385, 37.384424686431885, 38.787394523620605, 38.34074694769723, 42.3734119279044, 44.615081446511404, 49.42816114425659, 51.948727880205425, 53.65637969970703, 50.47545269557408, 55.557167121342246, 53.33592183249337, 56.321045126233784, 52.182340213230674, 53.83915901184082, 52.42845582962036, 60.33566216060093, 55.16805410385132, 66.60214519500732, 17.8057507446834, 0.06066073211176055, 1.4571261597531182, 0.7393689943211419, 0.1364632174372673, 18.261604683739797, 69.71781471797398, 55.58605425698416, 68.96070425851005, 49.36948708125523, 35.98114912850516, 25.116030386516027, 38.48912225450788, 55.221774101257324, 65.09096063886369, 13.453079530170985, 0.16064292139240674, 0.041254152211227586, 0.03961577173322439, 0.12600182236305305, 0.013386098983963686, 0.03983923027824078, 0.09895081605230059, 0.09707544704100915, 0.10502724642200129, 0.11942934218261923, 0.08080241988812174, 0.15317884619746888, 0.13404440294419015, 0.1863104762243373, 0.11708587221801281, 0.1800646970846823, 0.2385939471423626, 34.49055903298514, 71.5534315109253, 53.40330893652779, 46.86046130316598, 31.459925038473948, 37.042232854025706, 49.2988030569894, 63.47926344190325, 54.56560359682356, 68.19937624250139, 14.551547169685364, 0.7471978770835059, 0.46985629626682823, 0.47686811430113657, 28.62232416016715, 66.70157391684396, 56.59851796286446, 58.58222171238491, 52.03956862858364, 53.864141259874614, 51.765090465545654, 51.249457699911936, 54.47017008917672, 54.640772683279856, 51.81780992235456, 51.80000516346523, 48.37401866912842, 45.622066497802734, 40.90352399008614, 40.502112661089214, 37.577984128679546, 38.00776147842407, 38.33828728539603, 36.51128625869751, 35.716850076402935, 36.97254589625767, 35.23714297158377, 35.6852878843035, 37.19076796940395, 38.213945797511506, 36.371154989515034, 35.35332032612392, 35.32861253193447, 35.09935324532645, 36.13584382193429, 34.34314605167934, 36.45192084993635, 37.44163267953055, 36.17608778817313, 37.376576696123394, 34.979719161987305, 36.161962100437705, 35.87969848087856, 34.78591305868966, 34.62826885495867, 37.87253563744681, 37.021687030792236, 38.48800706863403, 37.25318711144583, 35.47869709559849, 37.750712871551514, 41.55872174671718, 44.746624742235454, 43.50423124858311, 39.55895376205444, 38.115493297576904, 40.23370722361973, 37.75884573800223, 36.21032503673008, 37.857131481170654, 36.25652708326067, 38.22150543757847, 38.59485994066511, 41.62374298913138, 40.65040806361607, 40.48975876399449, 47.627125535692485, 47.16635227203369, 40.399015290396555, 40.8678206716265, 43.458505153656006, 43.37968478884016, 44.515242780957905, 44.53694200515747, 39.92667327608381, 38.60268708637783, 37.28008358819144, 39.03884288242885, 38.80435855048043, 40.18897819519043, 41.22062240328108, 37.647372313908164, 39.023838247571675, 39.45585639136178, 38.46222925186157, 40.47206517628261, 44.653251375470845, 42.589090960366384, 39.32396221160889, 36.28282948902675, 38.79979705810547, 36.42462485177176, 37.86523308072771, 36.640922273908345, 34.89075790132795, 35.05883482524327, 37.487129483904155, 37.95433677945818, 36.3463533946446, 36.87192208426339, 38.646870681217735, 38.782436983925955, 37.6009201322283, 36.9108841078622, 38.174601622990195, 36.472299916403635, 38.8739412852696, 38.10707555498396, 41.06454154423305, 36.90413045883179, 38.48330313818795, 38.80478239059448, 38.31828689575195, 40.56242649895804, 40.1309676851545, 38.988034180232454, 40.10903222220284, 40.87403583526611, 45.47912468229021, 47.158851691654746, 52.77225617000035, 53.131821972983225, 57.45849650246756, 52.396841526031494, 56.89980227606637, 55.578751700265066, 58.573849133082796, 55.161130223955425, 56.354452065059114, 54.415321009499685, 63.54014355795724, 58.50589575086321, 67.7138569695609, 20.457645382199967, 0.2238927667162248, 2.4558942062514166, 2.2360881609576087, 0.18779648148587771, 20.77295810835702, 78.47613716125488, 60.50198119027274, 75.5979084287371, 55.13049909046718, 45.93976593017578, 33.07135820388794, 48.12426219667707, 62.544960021972656, 75.35294273921421, 18.46314934321812, 0.24430487783891813, 0.1299441379628011, 0.21270863685224736, 0.1889620553702116, 0.11833409166761807, 0.10884866743747677, 0.2088023243205888], [0.010232835642195173, 0.12227327243557998, 0.03401351859793067, 0.041821421057518036, 0.06280293501913548, 0.04584299633279443, 0.1091360609446253, 0.06738807433950049, 0.10024993919900485, 0.04055335106594222, 18.845942974090576, 57.5257168497358, 43.33113772528512, 34.7815773827689, 18.68510433605739, 34.79678004128592, 41.103527886526926, 56.92365544182913, 50.03143848691668, 55.15757622037615, 22.589674064091273, 0.1846116009567465, 0.11624820716679096, 0.08735065601233925, 29.80599669047764, 58.67550127846854, 51.029856409345356, 50.863308089120046, 48.19370249339512, 49.30132872717721, 47.16539689472744, 49.16495295933315, 49.45492907932827, 49.714618001665386, 48.2632018498012, 48.039369106292725, 43.47673027856009, 37.578668526240754, 34.20449474879673, 34.83295931134905, 35.33705459322248, 34.71398183277675, 33.21443550927298, 33.008206026894705, 31.236411912100657, 33.122503893715994, 33.3716002873012, 31.31419004712786, 32.116807733263286, 32.83695377622332, 31.669920444488525, 32.43311057771955, 30.125787530626567, 32.39345373426165, 31.070645264216832, 31.515461989811488, 32.304697445460725, 32.48628166743687, 32.86099454334804, 33.93515477861677, 34.402754647391184, 33.8411317552839, 34.61189195087978, 32.64430454799107, 34.68062700544085, 34.86093623297555, 34.14158228465489, 34.14960050582886, 35.74011959348406, 36.08279779979161, 35.90666791370937, 38.2669084412711, 39.58881711959839, 39.14088760103498, 38.51145723887852, 36.81728492464338, 35.89474480492728, 34.29126385280064, 33.2489333152771, 33.51456642150879, 31.963023253849574, 34.21301324026925, 34.278962067195344, 36.81605509349278, 37.16922855377197, 38.99590648923601, 34.25118664332798, 37.814994130815776, 42.20157255445208, 37.42320605686733, 41.68883718763079, 39.77524423599243, 39.584140981946675, 38.47554200036185, 36.6821528843471, 32.97885683604649, 33.65947110312325, 33.435096400124685, 33.645807470594136, 34.94201476233346, 34.11575583049229, 35.329071113041465, 36.95953886849539, 36.03430979592459, 37.88406269890921, 38.80535561697823, 39.47504384177071, 38.42049837112427, 34.80022634778704, 35.466933795383994, 34.82882513318743, 33.614359923771445, 33.9000038419451, 34.11729138238089, 32.28710808072771, 32.98235525403704, 33.53698478426252, 34.04393230165754, 34.19258901051113, 33.78145367758614, 35.171218463352744, 33.92127922603062, 33.13468408584595, 33.477945940835134, 33.058910506112234, 32.86252662113735, 33.650299480983186, 35.00237028939383, 32.54945816312517, 32.84805004937308, 34.80810907908848, 34.04815680640084, 34.665379183632986, 35.23733057294573, 36.515448229653494, 36.10414266586304, 35.322102069854736, 35.53983776909964, 44.48275300434658, 45.428670338221956, 50.677832875932964, 49.481200218200684, 48.65609468732561, 51.30179500579834, 54.24254362923758, 49.76920999799456, 54.17384678976876, 49.017282894679475, 52.518712929316926, 52.41143274307251, 58.08669703347342, 50.78639847891671, 64.42408643450055, 17.19909484045846, 0.28040275084120886, 0.16627872469169752, 0.1485858697976385, 0.13877565121012075, 20.431367295128958, 62.50447981698172, 51.868034975869314, 63.29820728302002, 47.281219891139436, 32.398320947374614, 30.455080032348633, 41.42109530312674, 51.94385371889387, 51.703692708696636, 4.78056777375085, 0.1726112613188369, 0.008876096390719925, 0.02555021407481815, 0.04056802438572049, 0.04268006980419159, 0.03894069045782089, 0.031876299530267715, 0.023999032132061462, 0.06423012486525945, 0.014551746658980846, 0.049453552413199625, 0.04334294084193451, 0.027040947029100995, 0.022898358425923755, 0.0935396214148828, 0.02305212803184986, 0.0237653684203646, 22.045395612716675, 66.17983368464878, 49.47045830317906, 37.60154547010149, 18.93302127293178, 35.94219752720424, 45.9933990750994, 61.05566923958914, 54.0295535496303, 60.025904519217356, 23.485939570835658, 0.28995163845164434, 0.10107066123081104, 0.04453860775434545, 35.13244751521519, 60.55931772504534, 53.252904755728586, 53.43052850450788, 49.17103263310024, 49.07966034752982, 49.683635984148296, 51.093592235020225, 51.62129749570574, 52.164024761744905, 49.185922622680664, 50.255934783390586, 46.270239625658306, 40.173949241638184, 36.18250444957188, 35.89599200657436, 37.23559774671282, 36.80619559969221, 35.138600145067485, 34.23638003213065, 34.18177761350359, 34.34876367024013, 35.30260195050921, 33.81139693941389, 34.14335754939488, 35.47498328345162, 32.76622806276594, 32.81242663519723, 32.91211244038173, 34.36694710595267, 33.000917366572786, 34.24032660893032, 35.02985388892037, 34.10689687728882, 33.86829226357596, 34.69038575036185, 35.32826859610421, 35.60793706348964, 35.982184410095215, 33.695636476789204, 34.880127157483784, 35.55968529837472, 34.95345497131348, 37.52316631589617, 36.441977977752686, 38.032451902117046, 35.9022592817034, 40.121882915496826, 41.43426561355591, 40.210368224552695, 38.38603530611311, 39.09490442276001, 37.52997555051531, 36.58935274396624, 35.479179995400564, 35.13808945247105, 34.792187282017295, 34.94272347858974, 36.226139136723106, 38.033876282828196, 38.11266885484968, 40.90303066798619, 37.50436101640974, 44.56271982192993, 44.916035720280235, 38.45201192583357, 42.990290369306294, 40.396114417484824, 41.16438020978655, 40.17930630275181, 38.81753233500889, 36.04880026408604, 35.873837675367085, 35.44145475115095, 35.77473899296352, 36.14349726268223, 36.91307626451765, 37.70209632601057, 39.26981837408883, 36.37804760251726, 38.503220149448936, 40.08458151136126, 42.61592490332467, 39.98967259270804, 37.49704456329346, 37.316433089120046, 35.80256305422102, 34.37154333932059, 35.37225416728428, 34.26290825435093, 34.338775634765625, 34.25574813570295, 33.53663042613438, 35.94000884464809, 35.6817512512207, 35.43556267874581, 36.48065512520926, 35.094051769801546, 35.325899260384695, 35.20491375241961, 34.44354404721941, 34.4808280808585, 36.8107362474714, 36.12495946884155, 35.421478680201936, 34.62206411361694, 35.63506283078875, 35.81283943993704, 36.18000657217843, 36.22178956440517, 39.50235373633248, 38.65069566454206, 38.29591022218977, 37.94384847368513, 47.13268477576119, 47.960555689675466, 52.22176776613508, 52.174110071999685, 52.90401138578142, 52.90782247270857, 56.05899381637573, 52.47598498208182, 55.555298055921284, 50.78206975119454, 54.99469307490757, 52.8916540145874, 59.90995992933001, 53.32070875167847, 66.01838534218925, 18.273166486195155, 0.1829846775425332, 1.727473401597568, 1.0880632549524307, 0.07199247048369475, 22.23756888934544, 69.0629608971732, 55.396913869040354, 68.61467702048165, 49.33056674684797, 40.102751050676616, 32.690332889556885, 45.51909072058541, 59.54856327601841, 61.86225087302071, 7.272732445171901, 0.09728714318147727, 0.04397282489974584, 0.04133087755846126, 0.02188988745079509, 0.023111342086589763, 0.024192579157118286, 0.008719251324821795, 0.10472360878650631, 0.258533485765968, 0.18320684347833904, 0.1388953583581107, 0.13141904239143642, 0.15444951158549103, 0.22575922656272138, 0.14676245621272496, 0.16047870234719344, 0.20230000466108322, 26.204618556158884, 75.83730861118862, 54.92460312162127, 46.12186779294695, 27.107008899961198, 46.5854411806379, 52.366870471409385, 65.44370678492955, 57.81373010362898, 64.37000860486711, 27.43013140133449, 0.46550362982920235, 0.18971702057336057, 0.3223071465534823, 37.00745364597866, 61.75524166652134, 54.34162841524397, 54.13759456362043, 52.275348799569265, 52.26412051064627, 51.47593423298427, 54.740587030138286, 53.245511872427805, 54.1603672845023, 51.21880919592721, 52.84773097719465, 47.24348769869123, 40.66697951725551, 37.78837558201381, 39.0080623626709, 39.753089904785156, 38.97184140341622, 38.06913491657802, 36.92953307288033, 35.93642010007586, 36.9284074647086, 38.36461748395647, 36.09859800338745, 36.38988038471767, 37.80462394441877, 34.90646777834211, 35.043552262442454, 35.05102505002703, 36.68405669076102, 35.67920126233782, 36.667599882398335, 37.32795320238386, 36.63220228467669, 36.28467770985195, 36.9894369670323, 36.947209290095735, 37.45357663290841, 38.722178731645855, 35.887136527470176, 37.3591228212629, 37.76538399287632, 37.436303411211284, 38.11261674336025, 37.785881178719656, 41.45616633551461, 39.20671830858503, 42.02012382234846, 43.951455524989534, 41.89011607851301, 40.00698750359671, 40.98995958055769, 38.564232281276155, 37.922955240522114, 37.687084742954795, 37.07495539528983, 35.175463812691824, 38.41307769502912, 37.74840954371861, 40.80958087103707, 39.685807023729595, 40.835018226078574, 40.56773839678083, 45.130957399095806, 44.13772978101458, 40.73213972364153, 45.325176920209614, 43.335810388837544, 43.96089812687465, 43.805001395089285, 40.55444996697562, 38.15172815322876, 37.879709652491975, 38.11529874801636, 37.4917847769601, 38.869466645377024, 37.287775244031636, 39.91997173854283, 40.75531196594238, 39.608886991228374, 42.52506678444998, 42.14384344645909, 44.44910635266985, 41.4818434034075, 40.00812005996704, 40.302150453839985, 38.26642901556832, 36.78814417975289, 37.27130453927176, 36.88270568847656, 35.52538551603045, 37.47962542942592, 37.01768486840384, 37.802337987082346, 37.08636433737618, 37.017552852630615, 38.12832662037441, 36.92057337079729, 36.835819244384766, 37.64175122124808, 38.497578212193076, 36.070673193250386, 39.199381010872976, 39.87347786767142, 37.48548970903669, 36.4868494442531, 37.72725575310843, 38.90220308303833, 38.77875791277204, 38.66721153259277, 41.86813545227051, 39.98098734446934, 39.99817718778338, 40.21545778002058, 49.18696485246931, 50.51074259621756, 55.383597646440776, 53.98591538837978, 54.06459331512451, 54.88900750023978, 59.20837252480643, 55.324770723070415, 58.720296314784456, 54.00306701660156, 57.480504921504426, 56.51470531736101, 62.17726830073765, 54.648950713021414, 65.99066202981132, 20.736923013414653, 0.4286820856588227, 2.6462435807500566, 1.7586127306733812, 0.2106360923498869, 25.458859716142925, 75.3305973325457, 60.95933246612549, 74.76602145603725, 58.44031865256173, 45.5440799168178, 39.23876340048653, 56.518582412174766, 66.07054546901158, 70.87431458064488, 10.114087087767464, 0.3485182486474514, 0.12086182460188866, 0.09087118745914527, 0.1127423592177885, 0.11826608888804913, 0.11867805463927132, 0.06664027446614844], [0.025097841563235437, 0.06368070827530962, 0.0075857416127941436, 0.016433700852628266, 0.03238407442612307, 0.008824928064963647, 0.06157613013471876, 0.03958587548030274, 0.05175308384267347, 0.024671256775036454, 9.777168938091823, 52.74326828547886, 42.21290506635393, 41.387615408216206, 38.318029812404085, 28.665191071374075, 37.65369864872524, 55.98974459511893, 49.35990898949759, 54.072972842625205, 30.396374702453613, 0.041155523753591945, 0.09409880890910115, 0.14369095888520989, 31.88913263593401, 56.86921977996826, 53.165041310446604, 50.61507674625942, 47.79479251589094, 47.69591270174299, 45.81682103020804, 47.80505847930908, 46.872644969395225, 45.58747489111764, 45.1377284186227, 42.34950317655291, 37.6193710735866, 34.88466433116368, 34.42484991891043, 35.513584000723704, 34.55726868765694, 33.69881875174386, 34.05222150257656, 35.033845629010884, 33.427474226270405, 36.30319465909685, 34.628126416887554, 33.92571217673165, 33.22024072919573, 32.90122808728899, 32.863989216940745, 31.16669716153826, 34.0248247555324, 31.22063602719988, 30.804786341530935, 32.50402389253889, 32.915388516017366, 32.49738488878523, 34.296377726963584, 34.081529004233225, 32.569903237479075, 33.47248813084194, 33.1927501814706, 31.236887863704137, 34.330191135406494, 33.855177538735525, 33.97937658854893, 34.523639406476704, 35.79676825659615, 33.94602176121303, 34.89213711874825, 37.81660958698818, 37.54888507298061, 40.04789502280099, 39.87484666279384, 38.13534082685198, 35.84103175571987, 34.2228136743818, 33.56832463400704, 34.22826453617641, 34.33634376525879, 33.33773824146816, 34.43611989702497, 33.28404951095581, 38.955141408102854, 37.96601322719029, 39.51526001521519, 36.39568560464041, 38.02201223373413, 40.79112645557949, 39.9146911076137, 38.637532302311485, 36.74491943631853, 36.417374406542095, 35.31394141060965, 35.36262048993792, 33.64445604596819, 34.42282451902117, 33.304855891636436, 33.66900403159005, 35.150099413735525, 36.75351088387625, 36.53361429486956, 36.845317431858604, 38.01980965478079, 38.96205139160156, 40.345152854919434, 38.17657143729073, 33.70532921382359, 33.83917236328125, 34.848137651171, 35.982545716421946, 34.946412972041536, 33.275520597185405, 33.913111618586946, 33.37220130647932, 32.84836966650826, 33.56455176217215, 33.881118638174875, 33.72706665311541, 33.70846285138811, 33.42338868549892, 33.34761163166591, 32.18103340693882, 33.69460466929844, 33.16071203776768, 32.85877806799752, 33.03127752031599, 32.793913160051616, 33.79585034506661, 35.184864725385395, 34.448109013693674, 34.923449175698416, 35.549961294446675, 34.262498310634065, 34.55306155341012, 37.577862535204204, 36.55954844611031, 42.52799545015608, 45.57946361814226, 49.61403587886265, 47.119750704084126, 51.26656069074358, 48.838936533246724, 52.5513208253043, 47.246909686497276, 49.47644417626517, 47.52555676868984, 56.0714693069458, 49.79806586674282, 58.40778718675886, 50.26502650124686, 65.26817444392613, 23.44420174189976, 0.06075640554938998, 1.175078151481492, 0.5642695586596216, 0.08001611315246139, 19.253729275294713, 61.51930168696812, 52.84767539160592, 62.64063671657017, 44.960809912000386, 33.963103907448904, 41.48316356113979, 43.40629638944353, 50.955833775656565, 49.314043930598665, 3.449821855340685, 0.08110307875488486, 0.05567422236448952, 0.0613066703081131, 0.009530893709909703, 0.10532551006014858, 0.04449638591281005, 0.04176452250352927, 0.04015167529827782, 0.04894110580374088, 0.027208244926961403, 0.0580391509990607, 0.095894545050604, 0.0587892850328769, 0.02323479305154511, 0.07226257491856813, 0.059271825211388726, 0.04076675711465733, 12.219777754374913, 61.82102026258196, 48.738993644714355, 48.66687829153878, 35.00937754767281, 29.81412955692836, 42.79856177738735, 59.084048407418386, 52.98353699275425, 59.466713496616904, 31.670264380318777, 0.021985184301489165, 0.02130443725867995, 0.33403111887829645, 36.394667693546836, 58.60593591417585, 54.511678627559114, 52.10234212875366, 50.26389047077724, 48.99383967263358, 47.37902968270438, 49.64347539629255, 49.41811057499477, 47.70240579332624, 47.214263575417654, 43.747932365962434, 38.774119990212576, 36.37213468551636, 36.42460748127529, 37.20299332482474, 35.05414131709507, 35.73607574190412, 35.36042138508388, 36.36834096908569, 36.641127245766775, 37.934058461870464, 37.784175395965576, 35.22468137741089, 35.73495708193098, 34.499070576259065, 33.23717696326119, 33.18372099740164, 35.11889852796282, 32.80513102667672, 32.8445759500776, 34.88605049678257, 35.127111298697336, 34.7501437323434, 35.051834515162874, 34.06944956098284, 33.95836871010916, 35.8626823425293, 34.734093393598286, 33.286703722817556, 34.85218497685024, 34.830690724509104, 35.17896223068237, 35.65353809084211, 37.03759840556553, 36.63122606277466, 36.420289175851, 39.15834494999477, 39.892863341740195, 40.051351751599995, 40.51468890053885, 37.39291191101074, 36.46926007952009, 35.22031790869576, 35.46539824349539, 34.99008934838431, 35.609378814697266, 35.10418571744646, 35.873674392700195, 35.530881541115896, 39.58414445604597, 39.38696847643171, 41.09128168651036, 37.95168604169573, 42.19712570735386, 42.77914503642491, 40.636914661952424, 40.92902387891497, 39.137642792293, 38.982169900621685, 36.87607363292149, 36.005037035260884, 35.459228243146626, 35.06846850258963, 34.42839697429112, 34.4718371118818, 36.79338659558977, 38.346166542598176, 37.778342383248464, 37.947378158569336, 40.00890520640782, 41.75236456734793, 41.95085028239659, 40.1831556047712, 35.96975755691528, 35.07801880155291, 35.6619245665414, 36.93862131663731, 35.3704719543457, 35.2211377961295, 34.926037379673545, 34.09417472566877, 35.38066496167864, 34.202688217163086, 35.94343430655343, 35.11081429890224, 36.27424846376692, 35.087527411324636, 35.18399620056152, 34.03940207617623, 35.89468921933855, 35.42198937279837, 35.78831229891096, 35.87806912830898, 36.11607272284371, 34.81292418071202, 37.232849734170095, 36.36173670632498, 36.90800060544695, 36.501763752528596, 36.68812486103603, 37.769459111349924, 38.94127975191389, 37.39705998556954, 45.81321491513933, 47.47657544272286, 51.424889292035786, 49.26833520616804, 52.50614363806588, 50.0406448500497, 54.460744857788086, 49.87946401323591, 52.06458909170968, 48.87448351723807, 58.013341426849365, 51.70345299584525, 61.43843160356794, 52.0592702456883, 61.246501513889854, 24.46177932194301, 0.03556001525638359, 1.587089825953756, 0.32324599474668503, 0.07400398076112781, 22.120118277413503, 67.68575150626046, 56.48613779885428, 67.69238008771623, 49.719658919743125, 33.72787959235055, 41.9848130771092, 51.00939743859427, 56.78081784929548, 59.1999443599156, 4.041526538985116, 0.06273170919822794, 0.03891850236271109, 0.05417393394080656, 0.0736188782112939, 0.028248647760067667, 0.08538446508880172, 0.0341220434888133, 0.13835080686424459, 0.12607032725853579, 0.11723031875278268, 0.1977758588535445, 0.1950275341847113, 0.15820877200790814, 0.16271288746169635, 0.20939062775245734, 0.13772388121911458, 0.10133020087544407, 14.185244219643728, 72.16127382005963, 54.20485312598092, 55.10071216310774, 48.642660345349995, 39.38291767665318, 47.64612191064017, 64.25079141344342, 56.431132384708945, 65.15758691515241, 36.00251136507307, 0.08333788133625473, 0.1852220653423241, 1.0130909979343414, 39.28113351549421, 60.05374595097133, 58.710450717381065, 54.286296435764854, 53.4098402432033, 51.359656129564556, 49.446136134011404, 51.8542115347726, 51.303959369659424, 51.114801611219136, 48.25185891560146, 46.15113707951137, 40.97860622406006, 38.10600553240095, 38.54633719580514, 39.304545470646445, 38.248297691345215, 37.60291426522391, 37.53072248186384, 39.70375074659075, 38.288138662065776, 39.39019938877651, 38.65094927379063, 37.21525342123849, 37.03359971727644, 37.78048242841448, 36.690605367933, 35.21295281818935, 37.32940884998867, 35.36772394180298, 34.492191859654014, 38.24719640186855, 37.48473235539028, 36.81032977785383, 37.77045270374843, 37.02350745882307, 34.73929412024361, 38.14029141834804, 37.124263286590576, 34.70366723196847, 37.80601358413696, 37.12559386662075, 37.625085966927664, 38.438469886779785, 39.301811354500906, 37.91052491324288, 37.64109114238194, 41.641335827963694, 41.02464846202305, 43.170797620500835, 42.38006482805525, 40.66751452854702, 39.937119892665315, 37.89563839776175, 37.48318985530308, 36.32558522905622, 36.908733640398296, 37.84101166043963, 38.75556482587542, 37.35976900373186, 41.77400125776018, 42.795977047511506, 42.45258665084839, 42.03098038264683, 42.54195785522461, 42.327678884778706, 44.04703841890608, 41.977534839085166, 40.60401841572353, 41.732704639434814, 38.81070920399257, 39.60644122532436, 37.47005081176758, 37.91483974456787, 36.01633480616978, 37.15949412754604, 40.04569591794695, 39.676982811519075, 38.607304164341514, 40.73335565839495, 40.6408542905535, 43.32351902553013, 43.75857700620379, 42.964033126831055, 37.54154430116926, 37.01988397325788, 38.00345706939697, 40.217014176504954, 38.11299194608416, 36.3714850289481, 37.537740162440706, 35.50181722640991, 36.66478933606829, 36.07159730366298, 37.6272850717817, 37.3279254095895, 38.00977645601545, 37.10137939453125, 37.78800385338919, 36.055870056152344, 37.64286988122122, 38.49359689440046, 38.03858021327427, 37.697618212018696, 37.17942156110491, 37.996974400111604, 38.80101646695818, 39.11296626499721, 39.28264822278704, 38.76645612716675, 38.36117812565395, 39.83044072559902, 40.89360891069685, 40.25168221337454, 47.556465830121724, 48.31190872192383, 54.482534408569336, 51.07565198625837, 53.2850957598005, 52.675724846976145, 56.221932547433035, 51.539923667907715, 54.58105639048985, 49.710115568978445, 60.35222666604178, 54.469774041857036, 63.49117265428816, 53.163609981536865, 63.14556230817522, 27.278961181640625, 0.1452588633235012, 4.030391182218279, 0.9659602812358311, 0.21661629288324288, 24.42657106263297, 72.69103227342877, 62.33327620370047, 73.3470881325858, 56.39270189830235, 47.092822960444856, 48.81153283800398, 60.04886136736189, 63.26266029902867, 69.24287060328892, 5.9956101179122925, 0.1804718452372721, 0.13595067922558102, 0.10581807220088583, 0.09372511253293071, 0.17707060703209468, 0.11240225032504116, 0.17028307196285042], [0.03378336630495531, 0.05613183995176639, 0.032204096405101676, 0.00621171880214076, 0.03933547570237091, 0.07029670969183956, 0.050964904350361655, 0.08607956314725534, 0.06068880989083222, 0.11131285556725093, 5.74080273934773, 45.42742313657488, 51.48934078216553, 39.72072866984776, 31.494527067456925, 32.863019943237305, 36.47412381853376, 54.57797139031546, 52.051502159663606, 50.62004470825195, 37.96557201657976, 0.3753229060343334, 0.046493806410580873, 0.14772047980555467, 23.304192066192627, 57.01957184927804, 52.23931891577584, 54.49698666163853, 46.94746317182268, 47.5541729245867, 45.37066330228533, 46.45434256962368, 42.95397213527134, 43.08347960880825, 38.31605304990496, 36.86652333395821, 35.61805016653878, 36.218909536089214, 33.857175145830425, 34.09647805350167, 35.320479665483745, 37.91139343806675, 38.36115380695888, 40.459718227386475, 39.88091938836234, 40.42744037083217, 38.73609249932425, 39.19658783503941, 33.99817841393607, 34.058030196598594, 31.350640296936035, 31.661947386605398, 32.885872568402974, 32.601218768528526, 31.849024159567698, 32.066582679748535, 31.88507488795689, 32.93241855076381, 34.51670857838222, 33.12851408549717, 32.816970757075715, 33.17865923472813, 32.45761687414986, 32.88756792885916, 31.88158689226423, 34.11347334725516, 35.493639196668354, 36.20435306004116, 34.17141784940447, 33.860888957977295, 34.14871808460781, 38.541344915117534, 38.32472092764718, 37.887074742998394, 40.14259549549648, 37.36523028782436, 35.23367234638759, 35.083983830043245, 33.16352605819702, 34.5719884463719, 33.127280780247276, 32.60904591424124, 33.65741791043963, 33.78339917319161, 34.169371604919434, 37.8577880859375, 36.74352632250105, 39.74136481966291, 32.620520864214214, 37.64178248814174, 38.426911558423726, 39.328120708465576, 37.33397381646292, 37.03687926701137, 36.12043966565813, 33.21364688873291, 33.603485992976594, 33.32370982851301, 33.362227167402, 35.694984095437185, 32.993764196123394, 37.59664699009487, 36.52732270104544, 35.04871129989624, 37.33189977918352, 38.21921600614275, 39.74272666658674, 37.898129326956614, 33.26919426236834, 35.028255803244456, 35.0249901499067, 33.231948443821494, 33.91489035742623, 35.061388288225444, 32.52961758204869, 32.996863092694966, 33.021848814828054, 34.64815807342529, 33.035700048719136, 34.092864990234375, 33.84821891784668, 34.36459861482893, 33.25324467250279, 31.760900156838552, 33.73265995298113, 31.529914242880686, 32.99953120095389, 32.73645155770438, 32.864492961338584, 32.76854181289673, 35.28659330095564, 35.805568150111604, 35.353615624564036, 35.3685507774353, 37.30943972723824, 35.99848140989031, 35.32344307218279, 35.465321813310894, 37.89678137642996, 41.87418385914394, 46.38016012736729, 49.784169469560894, 51.01693275996617, 48.447454180036274, 47.926485197884695, 48.81544119971139, 48.063524518694194, 48.912504059927805, 55.110512597220286, 52.11756215776716, 58.06134653091431, 53.40839154379708, 47.72677659988403, 18.297347954341344, 0.11997976978974682, 2.1876685534204756, 0.37786198407411575, 0.24257040662424906, 21.37996142251151, 60.69927528926304, 51.82319825036185, 59.154259954180034, 47.945290497371126, 52.888947691236226, 43.49777637209211, 49.001830101013184, 48.42692225319998, 40.416653292519705, 0.9562206438609532, 0.04246719640546611, 0.014464410720393062, 0.11853911780885287, 0.0317389504717929, 0.04833987627976707, 0.04289245805037873, 0.03485298515962703, 0.05394398860101189, 0.008162579499185085, 0.025572405562603047, 0.04567398004499929, 0.03415029429431472, 0.06134249695709773, 0.12740138226321765, 0.03839556560186403, 0.07981339403028999, 0.0801411128735968, 6.990842291287013, 53.43040691103254, 55.758202825273784, 47.34205831800188, 40.454805850982666, 36.87873131888253, 41.31100109645298, 57.99187496730259, 55.10975176947457, 55.14130701337542, 41.25098950522286, 0.34453014550464495, 0.04635706803362284, 0.18247207147734507, 24.22590708732605, 58.585605485098704, 52.94424145562308, 55.10071563720703, 49.67138978413173, 49.64801604407174, 46.71312822614397, 49.75951031276158, 44.792253562382285, 43.94941970280239, 40.6262526512146, 37.85038825443813, 36.573913846697124, 37.727432932172505, 35.044469424656455, 35.65188441957746, 36.590825762067524, 39.138136114392964, 39.657131808144705, 41.18671519415719, 40.38577202388218, 42.03496864863804, 40.12445027487618, 40.57908133098057, 36.33095966066633, 36.913072790418354, 33.81737586430141, 33.4757398877825, 34.817169530051096, 34.60121604374477, 34.14959355763027, 34.32653290884835, 33.88107347488403, 33.193344252450125, 33.80394499642508, 34.803036894117085, 34.16258668899536, 34.14290591648647, 33.41095488412039, 35.79165438243321, 34.184994629451204, 35.50643083027431, 35.33621038709368, 36.57455308096749, 35.031212261744905, 35.674893379211426, 36.00344589778355, 39.652261120932444, 40.67124918528965, 40.222701277051655, 42.08259160178048, 39.47230972562517, 36.629568917410715, 35.44016238621303, 35.42820801053728, 34.77485500063215, 34.686018807547434, 34.64719574792044, 34.92671830313546, 35.38247149331229, 35.98983437674386, 38.5774963923863, 38.75677381243025, 40.350471700940815, 35.267451013837544, 40.97286353792463, 41.868097237178254, 39.38589497974941, 38.44162784303938, 38.12916040420532, 36.533878326416016, 36.048015117645264, 35.09003571101597, 35.78211450576782, 34.949390275137766, 36.58596897125244, 35.88113328388759, 39.36513376235962, 38.06253065381731, 37.259919915880474, 39.55891554696219, 39.81415067400251, 42.23835631779262, 39.31181328637259, 35.228749547685894, 35.6194953918457, 36.075943401881624, 35.84355047770909, 35.7798285484314, 36.83795581545149, 34.47747557503836, 34.994150570460725, 34.46408987045288, 35.041057859148296, 34.27737440381731, 36.44023397990635, 34.909368651253835, 35.49217660086495, 34.73355490820748, 33.83396816253662, 36.10377788543701, 33.7493634223938, 34.816353116716655, 33.84491504941668, 34.50130442210606, 34.9490532875061, 37.24117715018136, 37.18835347039359, 36.071649415152415, 37.40485239028931, 39.8199246270316, 37.43533761160714, 36.562407629830496, 37.63926376615252, 40.1086049079895, 44.82980857576643, 48.71316371645246, 50.28590931211199, 51.64103037970406, 50.09561204910278, 50.178201811654226, 51.190227781023296, 49.98978056226458, 49.268314361572266, 55.76829855782645, 53.46478312356131, 59.074793406895225, 54.47678130013602, 47.9609169960022, 20.19436076709202, 0.19974190049937793, 1.5858175456523895, 0.3483775747673852, 0.24293458993945802, 22.68910104887826, 68.6973397391183, 56.788599831717356, 63.882439613342285, 54.420629433223176, 52.58410937445504, 47.11691236495972, 55.424706663404194, 56.210725103105815, 48.46714537484305, 1.6710870329822813, 0.03682766794892294, 0.034064055886119604, 0.03672077493476016, 0.051934184839150736, 0.029277808964252472, 0.006508694071921387, 0.0346543440329177, 0.12409384974411555, 0.1416355406067201, 0.19867160650236265, 0.12352850793727807, 0.10559729047651802, 0.1260586293148143, 0.15836068242788315, 0.13139081533466065, 0.1854826227894851, 0.1767235906528575, 7.64194929599762, 61.219653674534385, 64.45736135755266, 55.54128353936331, 41.02544750486101, 43.04489973613194, 47.614306109292166, 62.13438401903425, 61.057190895080566, 59.29154941013881, 46.9862619127546, 0.4240623749792576, 0.14265442879072257, 0.39680858169283184, 26.16934950011117, 60.274851526532856, 55.99235364368984, 58.04277747017996, 52.477305139814106, 52.52085644858224, 49.55769293648856, 51.637295722961426, 46.52123287745884, 47.13972677503313, 41.61638832092285, 40.650029386792866, 38.39957734516689, 40.48978655678885, 36.107133865356445, 37.873209612710134, 38.982694489615305, 42.77352394376482, 42.32200915472848, 44.0842946597508, 42.728551728384836, 45.42457437515259, 41.78854383741106, 42.099698066711426, 38.833638259342735, 40.28898709160941, 36.279021876198904, 36.39266661235264, 37.60523496355329, 37.67421667916434, 37.968017782483784, 35.63027899605887, 36.137146609170095, 35.13294083731515, 36.139220646449495, 37.12456553322928, 35.88318995067051, 35.11003262656075, 34.31654487337385, 37.07724830082485, 34.429362773895264, 38.555039814540315, 39.032499177115305, 38.83897794995989, 38.0250312260219, 37.589045660836355, 38.34079558508736, 42.07518482208252, 43.89649527413504, 41.30281959261213, 45.184757300785606, 40.827149391174316, 38.216603483472554, 37.909955160958425, 36.43590872628348, 36.55430950437273, 36.47520773751395, 35.93872342790876, 39.11768061774117, 38.6947785105024, 37.66922787257603, 40.95427710669381, 40.876523290361675, 43.111887318747385, 37.07754012516567, 40.59231070109776, 44.18079471588135, 42.17191416876656, 40.71083654676165, 40.357211453574045, 41.169494083949495, 36.771940980638774, 37.3969383920942, 36.68122182573591, 36.707155976976665, 38.68293878010341, 37.094042096819194, 41.15441649300711, 39.97709287915911, 39.56637096405029, 40.22377129963466, 40.12936612537929, 44.28209250313895, 40.98343869618007, 37.69623899459839, 37.78924410683768, 38.03933409282139, 37.265624386923655, 37.23674072538103, 38.015953404562815, 35.38636943272182, 36.802467891148154, 36.30236782346453, 36.99099683761597, 35.73986598423549, 38.8402008329119, 37.20954547609602, 38.2526889528547, 37.449810709272114, 35.69725268227713, 38.82199307850429, 36.12473017828805, 35.92603601728167, 36.47795922415597, 38.37979929787772, 36.714076382773264, 39.64200905391148, 40.1514127595084, 39.871511527470176, 38.92983954293387, 41.013176986149375, 40.28566585268293, 39.07753740038191, 39.34880896977016, 41.14645038332258, 45.86153268814087, 50.24151727131435, 52.81836094175066, 54.52211134774344, 53.529161657605854, 53.229895796094624, 53.593613147735596, 50.706449031829834, 52.26041712079729, 58.32666002001081, 57.832215785980225, 60.84005274091448, 56.26312494277954, 53.26884739739554, 23.6634521484375, 0.19770238708172524, 6.0955690741539, 2.8599658267838612, 0.3743962714714663, 24.495479822158813, 74.24929782322475, 60.2210168838501, 69.96439933776855, 60.68924903869629, 65.30179677690778, 51.381077425820486, 64.37001555306571, 62.59145736694336, 61.60080405644008, 3.1068713665008545, 0.17849428206682205, 0.13468249727572712, 0.14510517514177732, 0.13207810345504964, 0.15393139581595147, 0.12101141443209988, 0.13938857189246587], [0.023408070539257357, 0.04383637150749564, 0.105603729773845, 0.045301091125501056, 0.05801888315805367, 0.06538035707282168, 0.035733031508113654, 0.043425722114209614, 0.025897332234308124, 0.03060258412733674, 2.0815936625003815, 45.52315541676113, 53.106978688921245, 36.823013714381624, 23.56073866571699, 16.644154378346034, 35.0800198827471, 48.60990653719221, 52.598196847098215, 48.76773139408657, 47.007012707846506, 1.6448401042393275, 0.1042883557134441, 0.11880882190806524, 8.417971883501325, 56.3001241002764, 53.03762871878487, 53.29436813082014, 47.29207992553711, 50.89686441421509, 48.23248038973127, 47.73181751796177, 44.69384969983782, 39.938363620213096, 35.28588111060006, 38.54634414400373, 36.608154569353374, 35.028530257088796, 33.67892605917794, 37.72314936774117, 38.906587396349224, 43.19261148997715, 43.91376849583217, 43.939640113285606, 43.115007059914724, 43.90995740890503, 44.52571719033377, 41.14542204993111, 37.27186734335763, 34.540797982897075, 32.20847879137312, 32.17062153135027, 31.02364764894758, 32.049354621342246, 30.540497711726598, 31.81193814958845, 31.975012370518275, 32.706497873578755, 33.57600934164864, 32.46031624930245, 33.178878102983745, 33.614293915884836, 33.23580469403948, 32.65343100684029, 32.36381619317191, 34.71161944525582, 34.35083423342024, 35.26758650371006, 32.949278354644775, 33.12479679925101, 32.2310847554888, 35.2247439111982, 34.77983338492257, 39.2335661479405, 39.305455684661865, 37.98467261450631, 35.03746216637747, 35.031264373234336, 33.646995612553184, 34.97757911682129, 35.66160842350551, 33.71981968198504, 33.31515659604754, 33.81651081357683, 33.44107532501221, 34.98500674111502, 36.313175746372764, 38.98377840859549, 36.56703860419137, 37.323815550122944, 38.71362897327968, 37.86194658279419, 36.455784048352925, 35.68945680345808, 32.99512256894793, 33.63494396209717, 33.21582514899117, 33.476375647953574, 33.0254236630031, 34.82021631513323, 36.31913382666451, 36.288568701062886, 35.098436083112446, 35.99176945005144, 36.84861435209002, 37.394423144204275, 38.896189417157856, 37.69357436043875, 33.77268157686506, 35.3291266986302, 34.09869105475289, 35.49057156699044, 34.08603491101946, 35.00085210800171, 33.531850065503804, 33.61929661887032, 34.424655369349885, 33.65091092245919, 33.72720561708723, 33.37229858125959, 33.853291102818076, 33.287832805088584, 33.157894543239046, 33.53098848887852, 32.78879581178938, 32.37818854195731, 31.938204288482666, 32.067336559295654, 33.108920165470664, 33.068155084337505, 34.59787048612322, 33.50007595334734, 34.7721278326852, 36.03292710440499, 36.939055579049246, 35.70492696762085, 36.84138127735683, 36.44641440255301, 37.863683632441926, 37.59098073414394, 42.390917914254324, 43.40287092753819, 48.61740711757115, 46.68720102310181, 48.351367541721885, 44.53188024248396, 46.430055141448975, 46.67176212583269, 54.606830733163015, 51.66034289768764, 60.2253942489624, 50.427774156842915, 61.21307373046875, 30.667079993656703, 0.07379078505826847, 0.5839035393936294, 0.48860454452889307, 0.15484421540583881, 19.798620905194962, 62.71285629272461, 52.09010635103498, 59.55870764596121, 42.359175068991526, 33.31790460859026, 30.41805308205741, 57.11246231624058, 45.68090384347098, 41.71108184541975, 1.75290304848126, 0.05453909434644239, 0.025785991423098103, 0.03694140398874879, 0.03407593024894595, 0.06350340707493679, 0.05031143441530211, 0.01555889957983579, 0.04873296518677047, 0.039373137788580995, 0.06520490827304976, 0.023760214946897965, 0.04740105862064021, 0.037904703191348484, 0.0876179580975856, 0.027277423268450156, 0.029970450725938593, 0.08448242063501052, 3.102166784661157, 54.30233982631138, 58.738278252737864, 43.639502252851216, 26.901861599513463, 27.12453920500619, 43.47776556015015, 54.11106981549944, 58.13003989628383, 53.349415234157014, 51.80044289997646, 1.7203848276819502, 0.06749109631138188, 0.0227353013719299, 9.652309809412275, 56.963899408067974, 53.210517270224436, 55.609448841639924, 49.687957763671875, 51.20637539454869, 49.524609088897705, 50.53573179244995, 44.80955457687378, 41.567650181906565, 37.922646045684814, 40.48044122968401, 37.88442400523594, 36.82657814025879, 36.04633017948696, 40.16288423538208, 41.02598251615252, 44.32198905944824, 46.185183252607075, 46.2161340032305, 43.907115595681326, 44.01019212177822, 45.923468930380686, 45.23224476405552, 38.661708559308735, 36.104559557778494, 33.91931288582938, 34.80682366234915, 33.34993232999529, 34.61843020575387, 33.37317752838135, 33.99931444440569, 33.52021530696324, 34.20265695026943, 34.90042979376656, 34.98433971405029, 33.17075565883091, 34.6397750718253, 35.34683418273926, 34.341725145067485, 34.796269348689485, 34.12741143362862, 36.1299204826355, 37.83476522990635, 34.92084012712751, 34.29678767068045, 35.003190176827566, 38.67665066037859, 37.58830220358712, 39.906763213021414, 38.592796325683594, 39.28786631992885, 35.804602350507466, 36.607966967991416, 36.029029164995464, 35.98384850365775, 35.36032063620431, 34.408424377441406, 34.39553199495588, 36.246882983616416, 35.14134120941162, 37.68741478238787, 38.64427205494472, 39.99625253677368, 37.90070710863386, 39.11746869768415, 40.26074266433716, 40.40862464904785, 38.07948425837925, 36.59725284576416, 35.01696498053414, 35.236288343157085, 34.3570111819676, 34.662266390664236, 35.101257051740376, 35.3779308455331, 36.66443497794015, 37.05892242704119, 37.11594976697649, 37.92579010554722, 39.49803195680891, 41.12109293256487, 40.58808619635445, 39.960351194654194, 35.71139226640974, 36.52454342160906, 36.33527796609061, 36.6008311680385, 35.18436098098755, 36.32949359076363, 35.022304671151296, 35.158023834228516, 35.59072290148054, 34.11532504217965, 35.13169363566807, 34.62373515537807, 35.64092711039952, 35.257796491895405, 35.58786371776036, 36.822193826947895, 35.564684527260916, 34.13195555550711, 34.56559262956892, 34.4700722694397, 35.01243822915213, 36.84650904791695, 36.703365734645296, 35.55618340628487, 37.12942232404436, 37.890694754464285, 38.99085862295968, 36.955286570957725, 38.26603991644723, 37.31590155192784, 38.73609249932425, 39.36198970249721, 45.35054479326521, 46.48604025159563, 50.45965944017683, 48.60182578223092, 49.637878622327534, 46.707187516348704, 48.67949969427926, 49.36633259909493, 56.572246823992046, 54.66289574759347, 60.703075953892295, 52.82981852122715, 62.04716328212193, 32.15539802823748, 0.08251389555100884, 1.0521673411130905, 0.3202146259801728, 0.14634336584380694, 21.840052025658743, 68.50524289267403, 56.62380245753697, 65.88258280072893, 51.301704679216655, 43.11942264011928, 35.1978474344526, 63.52309962681362, 51.393931593213765, 49.628488131931846, 1.4637641864163535, 0.004100530882299478, 0.019663105153345635, 0.025456167424895933, 0.04006674646266869, 0.029070353667650903, 0.05428367340937257, 0.0314668002538383, 0.11674937313156468, 0.10180660031203713, 0.25250158086419106, 0.12108274203326021, 0.1552711632102728, 0.15057340743286268, 0.256446257765804, 0.10575091080474001, 0.11977113384221282, 0.19508899588670048, 3.423236961875643, 60.16217258998326, 66.66332408360073, 48.82277154922485, 32.17189999989101, 26.38338007245745, 46.82375744410923, 57.95609869275774, 61.605959619794575, 57.15153203691755, 55.86181436266218, 2.148469639675958, 0.21524550286786898, 0.13418438471853733, 11.228915997913905, 60.35325499943325, 55.35056243624006, 57.36845827102661, 50.461997509002686, 54.649551732199534, 51.96988861901419, 53.639172485896516, 47.467935357775005, 43.081554957798545, 39.40006930487496, 42.74780866077968, 40.83888142449515, 39.731300354003906, 37.07097060339791, 43.98001956939697, 42.31733996527535, 47.258478437151226, 48.10703761237008, 48.837908199855256, 47.293104784829275, 46.43665593011038, 48.03021138054984, 48.010068552834646, 41.45913669041225, 38.77595084054129, 35.42739159720284, 36.8786792073931, 34.120647362300325, 36.86566523143223, 35.14932121549334, 35.88386392593384, 35.120378494262695, 36.09172623498099, 38.002602440970286, 37.17785474232265, 35.40592513765608, 36.95371627807617, 37.41917610168457, 35.669859409332275, 35.02135624204363, 36.83723667689732, 38.107106821877615, 39.684024810791016, 36.26789433615548, 36.08325638089861, 35.626127447400776, 39.933381761823384, 36.644035066877095, 42.81844752175467, 40.72381230763027, 40.73540537697928, 37.33074637821743, 38.667548520224436, 38.152085985456196, 38.16227899278913, 39.49187237875802, 36.097889287131174, 36.60396827970232, 38.28536285672869, 37.05692829404558, 38.838887623378206, 40.29039410182408, 42.65662745067051, 40.21065310069493, 41.030620438711985, 42.37415191105434, 43.9046767779759, 40.91606896264212, 38.666732106889995, 38.1795209475926, 37.69299071175711, 36.256829329899375, 37.69267109462193, 36.563752106257844, 37.60235493523734, 39.9758699962071, 39.488516398838584, 39.29125356674194, 39.6812663759504, 39.14642184121268, 42.00918388366699, 43.439467089516775, 43.01974378313337, 37.85597113200596, 39.555962562561035, 39.37657397133963, 38.748324802943635, 37.77755376270839, 39.040857860020225, 36.59588057654244, 36.81554440089634, 36.66252074922834, 37.0845091683524, 36.729914801461355, 37.45311805180141, 36.75031818662371, 37.1506803376334, 37.6040746143886, 38.45910951069423, 37.007846219199045, 36.85266515186855, 36.36982440948486, 37.83381680079869, 36.88257714680263, 38.42237785884312, 39.09446668624878, 37.37089654377529, 40.22175979614258, 38.86912965774536, 42.01821306773594, 39.63651997702462, 39.82065418788365, 40.64328963415963, 41.20417601721627, 41.654120513371055, 46.79049989155361, 48.364728927612305, 54.43677357264927, 51.93355648858206, 52.016754218510215, 48.69169725690569, 49.64323568344116, 51.84635312216622, 58.34068843296596, 56.67925255639212, 64.31811945778983, 55.54894740240914, 65.44506863185337, 35.103914737701416, 0.3882561634693827, 2.7529885385717665, 1.588712990283966, 0.29575721121260096, 23.40966919490269, 75.58428995949882, 60.47020707811628, 71.75229590279716, 55.51188571112496, 45.863662311008994, 40.00207165309361, 71.25349167415074, 58.846017020089285, 61.441829272678916, 3.2852676681109836, 0.1989809913294656, 0.11773859576455184, 0.07598735219133751, 0.12107398893151965, 0.1630248235804694, 0.1512518474566085, 0.10289483477494546], [0.028770224058202336, 0.031058315387261764, 0.053870157205632756, 0.04475409351289272, 0.016286199213936925, 0.045117381161877086, 0.03332781485681023, 0.0512371325998434, 0.056961657745497565, 0.043436015490442514, 0.49486432863133295, 35.98880951745169, 54.43171180997576, 41.20933852876936, 34.82307202475411, 21.26357388496399, 36.6683919770377, 46.601807662418906, 57.23518834795271, 46.125112601688926, 52.85554422651018, 5.782319962978363, 0.3056802158909184, 0.11558412494403975, 1.1781547921044486, 37.03045218331473, 55.14295721054077, 52.640282085963655, 52.226068701062886, 51.22336026600429, 50.162422452654155, 50.25246068409511, 46.10616486413138, 39.51343958718436, 39.311524936131065, 37.19537115097046, 35.447666440691265, 35.69761398860386, 40.31721067428589, 45.164176736559185, 45.02035597392491, 47.18730456488473, 46.08533069065639, 47.800139154706685, 46.115947927747456, 43.03329971858433, 40.93728181294033, 41.919215134211946, 37.67498792920794, 33.562206745147705, 31.69544117791312, 33.098709787641255, 31.81206669126238, 33.20548970358712, 31.750099182128906, 31.17861679622105, 30.645418984549387, 32.4771135193961, 31.39335434777396, 33.80521651676723, 33.072098187037874, 33.62666170937674, 32.265276840754915, 32.936010769435335, 32.89642688206264, 34.29460941042219, 35.999839782714844, 35.416006973811555, 34.58341475895473, 33.89301742826189, 32.200516155787874, 38.704540729522705, 38.149254594530376, 37.507908071790425, 40.285752705165315, 38.27992936543056, 34.73768561226981, 34.896566595349995, 35.19429690497262, 33.67245033809117, 35.76746770313808, 32.7232152393886, 33.17131846291678, 34.435119356427876, 34.81067296436855, 35.74462897436959, 37.68479878561837, 39.6961007799421, 37.97321850912911, 35.31882946831839, 36.48953144890921, 36.198870931352886, 35.39182029451643, 34.26883506774902, 34.19569138118199, 32.409358160836355, 33.48228856495449, 32.629713330950054, 32.34211002077375, 33.95968886784145, 32.91685458592006, 36.10419477735247, 37.53355387278965, 37.82442283630371, 38.87329510280064, 39.48968022210257, 37.82019485746111, 38.44319813592093, 33.520847593035015, 32.57593079975673, 36.11596849986485, 35.36611543382917, 34.0164452280317, 34.3351834160941, 33.16973427363804, 33.86410249982561, 33.78211375645229, 34.27832978112357, 34.00939975466047, 34.01009110042027, 34.53246361868722, 34.060270990644185, 32.2673647744315, 32.784230845315115, 32.66364138466971, 32.426860673086985, 33.45851877757481, 33.050360747746055, 32.73162950788225, 32.36150591714041, 33.694153036390034, 34.35823406491961, 34.29730878557478, 35.56516742706299, 35.09587219783238, 35.155963693346294, 35.51553297042847, 33.95278583254133, 35.50156014306204, 35.86717782701765, 39.21612616947719, 40.96591533933367, 45.130922658102854, 43.7084561756679, 45.99503884996687, 42.717514514923096, 44.268130098070415, 46.257753712790354, 52.810241971697124, 53.48463412693569, 56.360833985464915, 52.313800130571636, 61.08988911764962, 36.63391848972866, 0.07971144414373807, 0.9742245120661599, 0.036440560328108926, 0.05838449139680181, 21.62935832568577, 63.46714578356062, 50.39243561880929, 59.48416042327881, 41.7787572996957, 30.815837451389857, 25.666819299970353, 50.33809723172869, 51.832415035792756, 35.71994897297451, 0.8164712541869709, 0.11968274787068367, 0.08591365454984562, 0.05665918040488448, 0.012920252463248159, 0.05219293059781194, 0.051262187505406995, 0.028617380652576685, 0.048649295033620935, 0.030624378672135726, 0.036724649369716644, 0.026454112625547817, 0.027207079543066875, 0.00785312766674906, 0.044702070233012946, 0.03954913280904293, 0.0724427734634706, 0.023720624124897376, 0.9050278908440045, 43.4568202154977, 60.551160539899556, 45.44306353160313, 37.14692483629499, 23.28089475631714, 42.738049915858674, 51.67433309555054, 61.194091251918245, 50.872431073869976, 58.20771728243147, 5.634802324431283, 0.2896331883966923, 0.0939191531922136, 1.3572129096303667, 38.990778718675884, 56.196585518973215, 55.619912828717915, 52.18970877783639, 54.193937505994526, 52.657854080200195, 51.95660366330828, 47.05939517702375, 40.36444452830723, 40.211080414908274, 40.411747864314485, 35.7799779347011, 38.41167763301304, 41.687402384621755, 46.79303250994001, 46.276652812957764, 49.07909059524536, 46.45535700661795, 47.80119528089251, 47.21293994358608, 45.186181681496755, 42.92732926777431, 42.7054420198713, 39.12667506081717, 35.23411703109741, 34.55112648010254, 34.41974299294608, 32.965519768851145, 35.538013866969514, 33.69941629682268, 33.60439273289272, 32.937709603990825, 33.95825753893171, 34.05423648016793, 35.413109574999126, 34.26768514088222, 34.57426745550973, 34.367211137499126, 34.522051743098665, 34.168840067727224, 36.93452187946865, 36.15277658190046, 36.393382276807515, 35.56236730303083, 35.98114912850516, 34.2491786139352, 39.609446321214946, 40.33739519119263, 39.03164107458932, 41.066438402448384, 39.18535259791783, 36.512328488486155, 36.369129589625764, 35.64056927817208, 34.50637660707746, 35.98508528300694, 34.31621135984148, 34.6044921193804, 36.01162045342581, 35.49795750209263, 37.78060402188982, 39.25612694876534, 41.74397461754935, 38.23852505002703, 38.41627039228167, 38.14656564167568, 37.20798907961164, 36.60058103288923, 35.56272166115897, 35.19417878559658, 34.57062659944807, 34.47122567040579, 33.90377671377999, 34.52738448551723, 36.840276513780864, 35.85687017440796, 36.99607597078596, 37.90250669206892, 38.85136658804757, 40.69066940035139, 40.28766693387713, 39.4378536088126, 38.333701474326, 35.97278349740164, 36.05914613178798, 37.433760370527, 37.504597255161826, 36.20367908477783, 38.301816190992085, 34.71873787471226, 34.531261580330984, 35.2163713318961, 35.84347057342529, 35.286899021693635, 36.0080942426409, 35.47897154944283, 35.533125809260774, 34.465962409973145, 34.797874382564, 34.58352593013218, 34.82757098334176, 35.539028303963796, 35.08879198346819, 33.92090402330671, 34.749817167009624, 37.53308834348406, 36.160068716321675, 36.154690810612266, 37.44543334415981, 36.37068598611014, 36.24533353533064, 38.00593410219465, 35.90491349356515, 36.419743742261616, 37.99570982796805, 41.16137511389596, 41.37067917415074, 46.118751525878906, 45.19409915379116, 47.75614316122872, 44.82064042772566, 46.8712066922869, 49.681568895067485, 54.67438459396362, 54.89819996697562, 57.63266352244786, 55.79237754004342, 62.83047539847237, 39.62593787057059, 0.25100209989718025, 0.6237902705158506, 0.07860257543091263, 0.20271372103265353, 23.71652248927525, 68.43753964560372, 56.829886027744834, 64.79307746887207, 47.015715326581685, 37.874599252428325, 29.856617791312082, 57.30832161222185, 58.866409982953755, 43.33417061397007, 1.2942041477986743, 0.09521796421280929, 0.03941413487440773, 0.04869477723592094, 0.04374559030735067, 0.05520875412704689, 0.044969161972403526, 0.048677769755678515, 0.10259418947888271, 0.07503669748881034, 0.1121897670839514, 0.13292370736598969, 0.12428098970225879, 0.1307426651141473, 0.14962888668690408, 0.1268560029566288, 0.16950073465704918, 0.14976159456585134, 1.161512336560658, 49.171953269413535, 67.61079433986119, 53.158277239118306, 45.92124898093087, 32.76868772506714, 48.64821195602417, 55.03630583626883, 65.42428656986782, 53.719608306884766, 62.456565039498464, 6.829966306686401, 0.5498364131365503, 0.17826820776930877, 1.8209943090166365, 42.03186975206648, 56.765677724565776, 57.175527640751426, 54.730168206351145, 57.521874495915, 55.47230877195086, 53.57203899111067, 49.602411542619976, 42.397178241184776, 43.27608367374965, 42.543813024248394, 39.104461669921875, 39.551494870867046, 43.81766448702131, 50.02653653281075, 47.5479542868478, 50.55100393295288, 49.36549881526402, 49.917925766536165, 46.24380867821829, 44.60345711026873, 46.70755229677473, 46.02853611537388, 41.801613398960654, 36.94515609741211, 35.06317744936262, 37.020957469940186, 35.67221137455532, 39.24779953275408, 36.50789206368582, 36.43157652446202, 35.59185545785086, 36.343087741306846, 34.04256003243582, 37.03228998184204, 36.17287424632481, 35.15583167757307, 36.721392835889546, 35.76233993257795, 35.94183622087751, 37.90431669780186, 39.763498306274414, 38.5779584475926, 37.10066720417568, 37.61116872514997, 34.399454253060476, 41.80046694619315, 42.61631400244576, 40.5752146584647, 43.47513566698347, 41.916950021471294, 37.31633928843907, 37.822411332811626, 38.20489229474749, 35.961284228733604, 39.60627099445888, 36.47628123419625, 37.03527423313686, 40.039129870278494, 37.450137274605886, 38.634867668151855, 41.71423632758004, 43.703599384852815, 41.102256366184776, 41.130750928606304, 40.958623204912456, 38.80552932194301, 38.823125634874614, 38.003853116716655, 37.722603934151785, 37.87005513054984, 37.300226415906636, 35.64818797792707, 36.67120252336775, 38.576033796582905, 37.45678322655814, 39.47471032823835, 41.34631184169224, 40.26211493355887, 42.1110896383013, 42.670006207057405, 41.621811389923096, 41.079035486493794, 36.2941654750279, 36.44567094530378, 40.684127671378, 39.695524079459055, 37.35585021972656, 40.12389441898891, 35.29836702346802, 37.001398290906636, 37.63153389522007, 37.50728620801653, 38.17652974809919, 37.77772746767317, 37.15128483091082, 38.0243364061628, 36.24634102412632, 37.60034690584455, 37.03391238621303, 37.56035654885428, 37.734096254621235, 38.13900600160871, 36.10442406790597, 36.430648939950125, 39.77318409511021, 38.138689858572825, 38.891763414655415, 40.17572798047747, 38.03820153645107, 39.16366032191685, 39.3221070425851, 37.918160983494346, 38.07032653263637, 39.95840917314802, 42.97708879198347, 44.85516950062343, 48.888835021427695, 47.889260223933626, 50.714946678706575, 47.25864519391741, 48.5203720501491, 54.12960066114153, 57.440973145621165, 57.06234148570469, 59.61449473244803, 58.935593196323936, 65.50512886047363, 41.40981490271432, 0.6035170012286731, 1.9337711717401231, 2.189942568540573, 0.31748808228543823, 27.63243341445923, 75.40265015193394, 61.37977491106306, 72.00432096208844, 54.002948897225515, 44.80380841663906, 37.08415133612496, 64.48630755288261, 67.3073456627982, 52.25617871965681, 1.7064363190105982, 0.15325086590434822, 0.12526022429977143, 0.12791921304804937, 0.12387749206806932, 0.09501118745122637, 0.13676938600838184, 0.13548652056072438], [0.02314027990879757, 0.06435201011065926, 0.04504035047388502, 0.059092264489403794, 0.039740930910089185, 0.016255468362942338, 0.051077113686395545, 0.052346964832395315, 0.02308644663675555, 0.011851254468118506, 0.08800976457340376, 24.997831106185913, 57.06520414352417, 45.06729800360543, 28.8803767817361, 26.04735824040004, 35.83437885556902, 41.98431975500924, 57.14508063452584, 44.593576771872385, 54.656875133514404, 13.647324238504682, 0.23768992136631692, 0.35433489509991234, 0.03756043487893684, 15.557744468961443, 49.87116091591971, 54.227302755628315, 53.21711458478655, 52.438148566654746, 52.245266573769705, 49.05001933234078, 46.350477422986714, 40.19618000302996, 36.79265703473772, 35.861591475350515, 39.55534764698574, 40.515421935490195, 46.29973125457764, 48.527393204825266, 44.803992543901714, 44.620827606746126, 44.36902141571045, 43.7542656489781, 42.91428402491978, 40.995042187826975, 43.57027735028948, 40.4501679284232, 34.07205513545445, 31.957443850381033, 31.942783151354107, 33.41719436645508, 32.76545333862305, 31.071308817182267, 33.552816254752024, 32.026251861027305, 31.615971156529017, 32.241868359701975, 33.24563986914498, 33.284945828574045, 32.771189076559885, 33.2393239566258, 33.32098266056606, 33.23623548235212, 33.506614208221436, 33.246192250932964, 34.480352129255024, 35.052126339503694, 34.87099722453526, 35.436997481754844, 35.102882930210654, 37.40723214830671, 38.06214850289481, 36.37651205062866, 38.45377329417637, 36.82436861310686, 34.793191296713694, 35.379337855747764, 35.00218963623047, 35.216489451272146, 34.6461500440325, 34.27432067053658, 33.05211169379098, 32.0853601864406, 34.79692595345633, 35.393626826150076, 36.640894481113975, 37.2269263948713, 36.504900864192415, 34.99941383089338, 38.7719486781529, 36.21426119123186, 34.518004417419434, 33.46732561928885, 32.5050174849374, 32.47859695979527, 32.91873059953962, 33.032945087977815, 33.46835742677961, 34.820959772382466, 35.478116921016145, 35.75025701522827, 36.10154403959002, 35.3637113571167, 36.83380774089268, 37.29658555984497, 37.11839553288051, 38.41918168749128, 33.7033246585301, 34.653150354112896, 33.78370836802891, 33.99787269319807, 36.20134449005127, 34.615883690970286, 33.46456718444824, 32.233249119349885, 32.022951466696604, 34.36075973510742, 33.38514232635498, 33.689324038369314, 33.7142402785165, 35.60746806008475, 33.81526708602905, 33.17252050127302, 32.28259522574288, 32.857075759342735, 32.87518971306937, 32.59558377947126, 32.360658236912315, 34.59270797457014, 34.7385367665972, 35.25024727412632, 37.374255997794016, 37.11995887756348, 38.077959128788535, 39.08101149967739, 38.812157903398784, 36.94733435767037, 35.86172349112374, 33.44115175519671, 35.1646454674857, 36.18831314359392, 39.94250474657331, 39.04952226366316, 41.50240312303816, 40.603851658957346, 42.63416045052664, 42.40003742490496, 44.11597844532558, 45.79475702558245, 51.273244857788086, 49.90016617093767, 58.02390268870762, 41.87681027821132, 0.2998997489256518, 0.21362289493637426, 0.1638548890394824, 0.21029850760740892, 21.32019649233137, 62.144368580409456, 52.0610385622297, 56.245146478925435, 39.376157079424175, 32.18163790021624, 22.42380666732788, 49.14756161825997, 52.34223910740444, 25.024206468037196, 0.43561226235968725, 0.040995124860533645, 0.031218412332236767, 0.0608223591532026, 0.009595019510015845, 0.0378699045229171, 0.11435172893106937, 0.06803133910787956, 0.024114744405129125, 0.03587999540780272, 0.017520736004891138, 0.0460122433224959, 0.04715745776359524, 0.07489012713943209, 0.023303798366604105, 0.0926152328029275, 0.034484374403421364, 0.10992899696741786, 0.020298371690192392, 30.006889956338064, 62.192040170942036, 49.85582276753017, 34.52221155166626, 26.511006321225846, 44.56431095940726, 47.382861614227295, 59.82289900098528, 48.85295104980469, 60.045102391924175, 13.837922011102949, 0.28165008819528986, 0.3019797573132174, 0.18742338222052368, 17.37200423649379, 52.96850109100342, 52.88713421140398, 54.95497369766235, 53.26254538127354, 52.416306904384065, 50.85966375895909, 48.30724648066929, 41.41309445244925, 39.32521636145455, 37.15005152566092, 40.409159660339355, 42.10105643953596, 47.23274230957031, 50.3157240322658, 47.1109299659729, 45.99896458217076, 45.90918343407767, 43.63567726952689, 45.482480662209646, 43.81194959368025, 45.99628952571324, 42.30199834278652, 36.33456577573504, 34.96531554630825, 34.44604539871216, 33.87257930210659, 34.684038570949006, 34.095738070351736, 36.20999499729702, 33.81313746316092, 34.61719690050398, 35.202818870544434, 35.23699358531407, 35.80988645553589, 35.371628829411094, 34.772666318076, 35.00703253064837, 34.74456780297415, 34.75462532043457, 35.29525770459856, 35.068454606192454, 36.3504250390189, 38.03214618137905, 37.170833587646484, 37.027929987226216, 38.62757900782994, 39.20195879255022, 38.66373743329729, 39.93294055121285, 38.77945968082973, 35.63017477308001, 35.89324746813093, 38.205799034663606, 36.23595346723284, 35.37618337358747, 36.520690645490376, 33.837914739336284, 35.3056035723005, 34.936741079602925, 36.42516333716256, 39.74819837297712, 39.75009870529175, 38.16657645361764, 36.999167919158936, 40.168067591530935, 37.964887619018555, 36.221799986703054, 35.32294627598354, 34.80747331891741, 34.764189515795024, 34.9469757761274, 35.15770074299404, 35.7275607245309, 35.84850801740374, 37.50318677084786, 36.21849611827305, 37.978506088256836, 37.090630531311035, 38.60504599979946, 39.981240953717915, 39.76434598650251, 40.78141982214791, 34.22967849458967, 36.15207828794207, 35.40466056551252, 35.50560399464199, 37.64263711656843, 35.251053265162874, 34.46233892440796, 33.478203024183, 33.6730374608721, 36.67657000677926, 35.380651065281455, 36.21463986805507, 35.26858009610857, 36.84127010617937, 36.87363828931536, 34.688815457480295, 35.28155238287789, 32.84768874304635, 34.78618056433541, 35.004715306418284, 34.741038118089946, 37.034874711717876, 37.66299533843994, 36.969874313899446, 39.42368275778634, 40.7599081993103, 40.81581687927246, 39.92746884482247, 40.97682401112148, 38.27766077859061, 37.37998478753226, 35.74684892381941, 38.038264070238384, 39.218356541224885, 41.14654070990426, 41.02135501589094, 44.56172970363072, 43.218990325927734, 44.94241108213152, 44.53957884652274, 47.5474887575422, 49.333227906908306, 52.77355548313686, 51.30811439241682, 61.29160227094378, 44.0526247705732, 0.4026632803891386, 0.785399507199015, 0.11679290793836117, 0.21573201247623988, 24.084375756127493, 69.22212328229631, 56.599396909986226, 62.58453696114676, 46.31307874407087, 34.37782103674752, 26.792920793805802, 55.92756864002773, 59.842617988586426, 31.854850224086217, 0.5199252324444907, 0.08943143792982612, 0.07609831980828728, 0.035366666702819724, 0.05531947747138994, 0.06991755789411919, 0.08684336287634713, 0.03914292442745396, 0.18552351130970887, 0.16371706500649452, 0.10977777186781168, 0.06436958416764225, 0.13232266104647092, 0.13917517262910092, 0.15385284860219273, 0.221411635567035, 0.13019108399748802, 0.25646810659340447, 0.1800119477723326, 34.20665216445923, 70.79888493674142, 57.468422004154746, 40.772470542362754, 37.33188240868704, 46.78796032496861, 52.80053881236485, 66.13312094552177, 52.665434564862935, 65.66860607692173, 16.618107318878174, 0.47404871987445013, 0.5639362622584615, 0.17456765419670514, 18.537640980311803, 53.33893387658255, 58.78578308650425, 57.45560605185372, 55.913981437683105, 55.670658997126985, 52.50317675726754, 50.352295875549316, 45.257338183266775, 40.024580342429026, 38.8584155355181, 44.72377906526838, 44.2113424709865, 50.51886851446969, 52.21400315420968, 45.593742166246685, 47.91312033789498, 47.22093037196568, 45.41400963919503, 47.85083668572562, 45.73151452200753, 47.92887190410069, 42.794903550829204, 37.47360481534685, 36.345283372061594, 37.14270380565098, 37.46471112115042, 38.43521465573992, 35.321681703839985, 39.039753096444265, 37.16280494417463, 36.854787826538086, 37.47501529966082, 37.327800342014854, 37.76414721352713, 36.68890305927822, 37.72541100638253, 35.80885464804513, 36.51845679964338, 36.57199614388602, 37.116648060934885, 37.9181991985866, 37.138795443943565, 39.002614974975586, 40.388144833701, 38.91604042053223, 42.085238865443635, 40.88855757032122, 40.382798194885254, 42.206088883536204, 38.42330196925572, 37.456508772713796, 38.487760407584055, 38.98440374646868, 37.86058473587036, 38.42117929458618, 38.68572848183768, 35.44231980187552, 37.62648255484444, 38.160093784332275, 39.4570758002145, 40.21930708203997, 41.548646858760286, 38.87401076725551, 38.176814624241416, 44.175441128867014, 42.0776583807809, 39.72988639559065, 35.566973958696636, 36.44085931777954, 36.5062175478254, 35.93399517876761, 36.32188531330654, 38.48008959633963, 37.30536460876465, 39.15044832229614, 38.13518449238369, 38.28124952316284, 39.52806901931763, 39.209556647709434, 41.170831612178254, 41.36389773232596, 43.166750294821604, 36.5667085647583, 38.722991670881, 36.89913470404488, 37.16169670649937, 40.563315868377686, 36.73813452039446, 36.20232418605259, 34.018748555864605, 35.41573599406651, 38.967505727495464, 36.53871079853603, 38.21444606781006, 37.078776904514854, 40.03549943651472, 38.506649085453574, 37.952530247824534, 37.76933751787458, 34.72190277917044, 37.76319183622088, 37.8921469279698, 35.39507205145699, 40.48740332467215, 39.61512994766235, 39.41613354001726, 41.43121188027518, 43.095190797533306, 43.017079148973735, 42.52742917197091, 43.019246986934114, 41.74506548472813, 39.35722323826381, 36.04505171094622, 39.32026924405779, 42.20178100040981, 43.16100066048758, 44.754900046757285, 45.99350677217756, 44.868378026144846, 47.379592486790244, 46.73671736036028, 47.98705611910139, 50.61596264157976, 55.30768162863595, 54.935654231480186, 62.76281384059361, 48.94252027784075, 0.8108192746128354, 1.319356192435537, 1.5891709199973514, 0.3453822226396629, 26.395727021353586, 74.81467274257115, 61.18193885258266, 68.99110957554409, 52.21092857633318, 43.7255939074925, 33.00965472630092, 62.10105351039341, 67.23072787693569, 40.76515408924648, 0.6829095610550472, 0.15581452048250607, 0.21024448264922413, 0.10843556853277342, 0.15574787477297442, 0.11756778135895729, 0.25335506935204777, 0.13806811560477528], [0.012056174588256648, 0.03378766143162336, 0.017733455036899874, 0.03685689584485122, 0.03535928424181683, 0.040032541512378624, 0.021962472038077455, 0.06640628845031772, 0.08589196178529944, 0.036274845113179514, 0.024983136914670467, 13.34141937323979, 53.79065711157662, 44.62306145259312, 33.43649646214077, 21.501217910221644, 32.484363964625764, 45.76607486179897, 56.85175200871059, 44.66963175364903, 54.21966668537685, 21.131710972104752, 0.10964464329715286, 0.09472625024084534, 0.025761258821668367, 1.2229879349470139, 36.1408291544233, 49.65728841509138, 51.79364061355591, 50.9221384865897, 48.79533658708845, 50.536721910749165, 45.69973693575178, 36.794623374938965, 36.80851977212088, 40.311992577144075, 42.08775063923427, 47.19338771275112, 46.686203956604004, 44.71442331586565, 43.55119412285941, 43.12689195360456, 43.01077018465315, 44.27589470999581, 44.0949010848999, 46.453689438956125, 41.65149409430367, 35.69604022162301, 30.92914867401123, 32.5117746080671, 31.356709548405238, 32.499399866376606, 31.132143769945415, 33.14061437334333, 32.37448862620762, 31.889445304870605, 32.13071455274309, 33.31876618521554, 32.95003918239048, 31.825334276471818, 32.86273854119437, 33.86886896405901, 31.52012423106602, 32.670978682381765, 33.17870787211827, 34.6953432900565, 34.92927524021694, 37.190163476126536, 36.88746520451137, 36.99917834145682, 34.11529377528599, 37.939453738076345, 38.705200808388845, 36.33046286446707, 37.73820611408779, 39.432927336011616, 35.42259734017508, 34.650878293173655, 34.75289521898542, 34.92366109575544, 34.83677734647478, 33.97292171205793, 33.831980977739605, 33.31183188302176, 33.62922559465681, 35.27412823268345, 36.54964031491961, 38.59154912403652, 36.8669193812779, 34.784332343510215, 37.13275398526873, 34.616568088531494, 33.738895961216514, 33.64683927808489, 31.853703771318706, 32.987899916512625, 31.6614089012146, 32.47231231416975, 31.62242603302002, 32.983758790152415, 33.95431096213204, 35.26699938092913, 36.003734248025076, 36.84802375520979, 36.16255964551653, 35.35584599631173, 36.59097514833723, 38.28500502450125, 33.27746261869158, 33.90821661267962, 34.00491469247, 35.06004728589739, 36.059028012411936, 35.458126953669954, 32.53702088764736, 32.72202014923096, 32.96661411012922, 34.070481368473594, 34.01615687779018, 33.568130084446494, 33.366760866982595, 33.922373567308696, 32.70610530035836, 33.49854734965733, 33.59688867841448, 33.1749141556876, 34.256290095193044, 32.69253199441092, 33.42376388822283, 35.33169753210885, 36.97645078386579, 37.86464595794678, 40.68560068947928, 41.536289487566265, 43.511790888650076, 41.94165781566075, 43.46445975984846, 44.770318099430625, 42.26428004673549, 38.26322589601789, 36.54777124949864, 34.971555028642925, 35.21257414136614, 38.02051142283848, 38.603062289101736, 37.819298539842876, 41.72624976294381, 39.8877147265843, 43.46509204592024, 39.782869883946006, 48.03242438180106, 51.78847810200283, 59.145498275756836, 40.387814794267925, 0.16306481643446855, 0.30978510848113466, 0.24415693006345204, 0.23480058354990824, 24.5447963987078, 61.794999258858816, 51.92174802507673, 55.49673168999808, 41.26270416804722, 39.94192804609026, 25.222098112106323, 39.872428689684185, 53.944535391671316, 17.624039718082972, 0.2408689936356885, 0.042059345969132016, 0.051647771815104146, 0.031545245687344244, 0.07805340311356954, 0.03801959613338113, 0.07261354037161384, 0.052749363239854574, 0.034566653559782674, 0.07015996452953134, 0.03373992310038634, 0.08107287037585463, 0.038037214295140336, 0.05030680341379983, 0.0023247557567499045, 0.010142591332883706, 0.03562818088435701, 0.05994358845055103, 0.011575077992996998, 16.577008724212646, 61.08718626839774, 50.15498440606253, 37.04377882821219, 26.369242225374492, 36.02552727290562, 49.35035869053432, 62.14101260049002, 49.53627858843122, 59.98705019269671, 22.914417232785905, 0.2042767671602113, 0.21082636713981628, 0.05117898214874523, 1.3917225492852074, 39.80937726157052, 51.365746225629536, 54.07553672790527, 52.47963626044137, 52.25428533554077, 52.10744905471802, 47.32931532178606, 38.215033190590994, 38.97481523241316, 41.57325042997088, 43.55513375146048, 49.06428745814732, 49.706540720803396, 45.95652845927647, 44.052541392190115, 43.83986745561872, 45.47286435535976, 46.704133783067974, 46.57071794782366, 48.18704959324428, 43.779678685324534, 36.9903576033456, 32.334512165614534, 34.08562844140189, 32.92426483971732, 34.071214403424946, 32.55198383331299, 34.15330042157854, 34.58654144832066, 34.85761846814837, 32.99002259118216, 36.22101484026228, 34.367165974208284, 33.92575734002249, 35.175748688834055, 34.823256152016775, 34.44887678963797, 34.58122260229928, 34.6113360949925, 36.12265614100865, 35.39955363954817, 37.62525272369385, 36.61421339852469, 37.67380673544747, 35.445807797568186, 39.50098146711077, 41.54370321546282, 36.73952416011265, 40.24035317557198, 40.22300699778965, 37.4060057912554, 35.01045451845442, 36.55976036616734, 37.52919387817383, 36.76478086199079, 35.63376351765224, 36.017762660980225, 35.385282039642334, 35.428604057856965, 38.737648895808626, 38.026396547045024, 39.013950960976736, 36.867308480399, 36.53345448630196, 38.64252805709839, 37.71550634929112, 35.850057465689524, 35.92898205348423, 33.85214812414986, 34.93157509395054, 34.244988850184846, 33.809652941567556, 33.25688205446516, 35.06732899802071, 35.218674659729004, 36.86380311420986, 38.066237517765586, 38.129420961652485, 37.65280927930559, 37.64556578227452, 38.92778287615095, 39.73954439163208, 34.9204614503043, 36.1355311529977, 35.71521724973406, 36.35177993774414, 36.695958954947336, 35.64744799477713, 35.0982415335519, 34.40791368484497, 34.50490706307547, 35.90638998576573, 35.12232051576887, 35.40828405107771, 34.690889494759695, 35.65358672823225, 35.28933089120047, 34.80191476004464, 36.18992165156773, 35.87546007973807, 36.33002512795584, 34.4388609613691, 36.54170199802944, 36.700777530670166, 38.35187448774065, 41.05302490506853, 42.5043055670602, 42.70206866945539, 45.79098762784685, 44.19227661405291, 45.95472887584141, 46.31745958328247, 44.18858017240252, 39.71231440135411, 38.245938777923584, 36.61714553833008, 37.845917088644846, 39.155937399183, 41.70823655809675, 40.989844935280935, 42.969966888427734, 42.836401666913716, 45.51640524183001, 42.29120084217617, 50.15911511012486, 54.344987869262695, 62.31713553837368, 41.50599534170968, 0.4096240997314453, 0.4077040356184755, 0.24959910660982132, 0.07943756026881081, 26.57724870954241, 67.21164117540631, 55.20581061499459, 59.02749701908657, 44.0693039212908, 37.737646784101216, 27.976859092712402, 46.88580485752651, 62.81811455317906, 23.713284628731863, 0.41969885198133333, 0.16299027257731982, 0.05920312354075057, 0.05095035316688674, 0.10651693612869297, 0.006545136491435447, 0.03621158868606601, 0.05931111238896847, 0.13779842507626328, 0.16269472986459732, 0.10229322527136121, 0.14973412746829645, 0.24831409699150495, 0.19142407897327626, 0.06867706695837633, 0.14792832865246705, 0.15792058461478778, 0.1156116598950965, 0.11677249760500022, 18.717707020895823, 69.73690141950334, 56.970402921949116, 46.0102345602853, 29.6267957006182, 42.79794338771275, 56.23011752537319, 65.52450043814522, 52.90530375071934, 64.2044677734375, 26.072347436632427, 0.22458215829517159, 0.26009069649236544, 0.10919465922883578, 1.7800049313477107, 40.12395000457764, 53.20863430840628, 55.33042655672346, 54.60048355375017, 52.76697901317051, 55.12406505857195, 49.12751953942435, 39.68387195042202, 41.14363636289324, 43.45790760857718, 45.33196531023298, 51.582370213099885, 49.74341481072562, 47.84265865598406, 46.542998109545024, 47.74019009726388, 47.873001439230784, 48.7209734916687, 47.273330211639404, 51.338113239833284, 45.50844955444336, 39.112778663635254, 33.32666628701346, 37.0204884665353, 34.67919567653111, 35.72775527409145, 34.6572219984872, 37.49672147205898, 37.80092750276838, 36.574480124882285, 35.76313550131661, 38.90248795918056, 36.855197770254954, 35.1278304372515, 36.509806292397634, 36.99034718104771, 36.26551110403878, 37.65155512945992, 35.646669796534944, 38.18504129137312, 37.67210095269339, 40.51263223375593, 38.46217366627285, 40.438828468322754, 37.108577728271484, 42.17722954068865, 44.94793142591204, 39.546905585697715, 41.51907532555716, 42.19701453617641, 38.8254393850054, 37.03091076442173, 38.525680201394216, 39.526085308619905, 38.290101528167725, 38.06705740519932, 39.76466907773699, 37.2059463092259, 38.562415327344624, 41.055453300476074, 41.031777313777376, 40.99356916972569, 39.05116203853062, 38.92430182865688, 42.7992843900408, 39.76762901033674, 37.67218780517578, 39.215004035404746, 35.177506583077566, 37.91646562303816, 36.03263528006417, 35.61115755353655, 34.37958587918963, 36.214125701359336, 36.62990937914167, 39.59783240727016, 39.14367730276925, 40.28117731639317, 39.495627880096436, 39.56371327808925, 40.592178685324534, 42.839212213243755, 36.84802722930908, 37.97498682567051, 37.838739599500386, 38.17849956239973, 38.5399101121085, 38.18810197285244, 36.568101678575786, 35.36302695955549, 35.91099664143154, 38.54817499433245, 37.02601228441511, 37.14143228530884, 37.42788914271763, 37.550483158656526, 36.94941186904907, 37.706602232796804, 38.831032684871126, 38.522060189928325, 39.03493104662214, 36.896067074366975, 38.192611353737966, 39.696406500680105, 41.85120269230434, 43.03638471875872, 44.90030499867031, 45.48276553835188, 48.933925356183735, 45.6840374810355, 48.20408657618931, 49.69026109150478, 47.46552433286394, 42.49104493004935, 40.42506061281477, 37.6261316708156, 39.62880400248936, 42.356128283909385, 42.986885751996724, 41.76364496776036, 45.59663609095982, 44.97304916381836, 48.0454557282584, 43.89900704792568, 51.967602661677766, 57.34670346123831, 65.00651918138776, 44.96485376358032, 0.640818405364241, 0.694069290799754, 0.8159098071711404, 0.4450728589934962, 31.04075411387852, 72.10636915479387, 61.90590640476772, 64.05408791133335, 54.21882595334734, 52.279566356113975, 37.453395979745046, 52.51618378502982, 69.51044573102678, 29.293497562408447, 0.5670202853424209, 0.21004723251930305, 0.16234563716820308, 0.14340810477733612, 0.19040377943643502, 0.11507231955017362, 0.11911811174026557, 0.12428674367921692], [0.04643683321774006, 0.04202019110588091, 0.01385005408831473, 0.10571507058505501, 0.020426243310794234, 0.024501349910029342, 0.05236895275967462, 0.015801172204581753, 0.04946894498009767, 0.057098151849848885, 0.09755911358765193, 9.288497788565499, 50.76290314538138, 43.44691208430699, 30.113586493900844, 16.736869403294154, 36.940796102796284, 40.40109974997384, 55.099398953574045, 47.15221963609968, 54.52090236118862, 28.2140462739127, 0.056470995502812524, 0.30230868394885746, 0.9541990437677929, 0.11055552906223706, 12.803892833845955, 51.37428208759853, 46.098375933510916, 50.62629113878523, 50.42357744489397, 50.344680649893625, 41.413483551570344, 37.72583832059588, 37.315634046282085, 41.687197412763325, 48.09742477961949, 47.86832530157906, 44.740562438964844, 43.805671896253315, 42.518868991306846, 45.04516451699393, 44.15135172435215, 43.40311411448887, 42.24249744415283, 41.874263763427734, 33.90009069442749, 33.294926915849956, 32.23220688956124, 32.80857038497925, 32.264703614371165, 31.59182964052473, 30.42898259844099, 32.80792767660958, 32.86441305705479, 32.09014402117048, 31.769498552594865, 33.10642923627581, 32.136161940438406, 32.33897985730852, 33.10931273869106, 32.53696877615792, 33.15743596213204, 33.205941336495535, 32.11566822869437, 35.056656564985005, 35.177454471588135, 37.02337891714913, 36.059969493321006, 36.726656096322195, 32.64021553312029, 35.721824986594065, 39.99806949070522, 36.78920030593872, 38.54402691977364, 39.31468636648995, 34.99778100422451, 35.08982726505825, 33.51054341452462, 34.63315691266741, 32.60214982713972, 34.414160115378245, 32.94338975633894, 33.99737589699881, 32.954843861716135, 36.32804489135742, 36.51351663044521, 37.994969844818115, 37.27366345269339, 34.519602503095356, 33.91689838681902, 35.01209429332188, 34.90933738436018, 34.67284154891968, 30.62494264330183, 32.809939180101665, 32.36657115391323, 32.41888066700527, 33.29030983788626, 33.32053797585623, 33.51301349912371, 36.91660942350115, 36.50948320116316, 36.51997150693621, 37.680807045527864, 37.03974887302944, 36.02223382677351, 36.8542354447501, 33.119874000549316, 33.16733367102486, 32.036201681409565, 35.668400287628174, 34.864125456128804, 35.02371168136597, 33.85128307342529, 33.637744086129324, 33.157766001565115, 33.85491003308977, 33.57423060280936, 33.92832817350115, 35.032098157065256, 33.53311116354806, 33.77974442073277, 31.806692259652273, 33.24804741995675, 33.45833812441145, 34.204025745391846, 33.91645022800991, 35.54531294958932, 36.96439913340977, 38.229019914354595, 38.7802483013698, 41.754237106868196, 41.18490866252354, 43.727157252175466, 44.827696323394775, 45.79329442977905, 46.59347677230835, 47.41758871078491, 46.12478256225586, 45.91110461098807, 41.22286319732666, 40.43127230235508, 37.2829601424081, 37.34093243735177, 35.08504343032837, 38.83741807937622, 38.55180890219552, 45.40928833825247, 41.91230862481253, 53.32985952922276, 49.17984989711216, 59.68498420715332, 32.42086090360369, 0.016805030837921158, 0.2855304128357342, 0.34418121565665516, 0.003903375323196607, 31.312234129224503, 59.585312298366, 53.52915818350655, 56.50559275490897, 45.50794233594622, 24.84897116252354, 17.473479202815465, 41.49740389415196, 44.05666167395455, 11.043360011918203, 0.20146866355623516, 0.13900405966809817, 0.013550027955456503, 0.027652091646034802, 0.08755807738218989, 0.05643500600542341, 0.038562033990664144, 0.061577473634055684, 0.0364207912103406, 0.021609433660549775, 0.06041765372667994, 0.05836047125714166, 0.02637459001769977, 0.04302231268957257, 0.09304750710725784, 0.015751997075442756, 0.08232450285660368, 0.057731381085302146, 0.10740130474524838, 10.697945083890643, 59.2645834514073, 50.80736814226423, 35.702898093632285, 19.18761716570173, 40.01304633276803, 46.91665138517107, 59.73628970554897, 51.064986501421245, 59.61899716513497, 30.652815341949463, 0.01957724672476096, 0.042422474162386994, 1.7331685359988893, 0.09038513246923685, 13.90296757221222, 52.45968450818743, 47.7328006880624, 51.866200651441304, 51.477452414376394, 52.578766209738596, 44.258576325007844, 40.02055386134556, 38.835354464394705, 44.33869252886091, 48.955009664808, 51.42495877402169, 46.47515589850289, 44.71748399734497, 44.50476837158203, 45.41921731403896, 46.01121078218733, 46.5301057270595, 44.68834672655378, 44.953896454402376, 36.068005084991455, 34.22133023398263, 34.412134715488975, 34.39163405554635, 33.14589500427246, 33.89806529453823, 33.615131173815044, 34.80883516584124, 34.5834390776498, 33.17012684685843, 33.98888519832066, 36.22789355686733, 34.78000361578805, 34.41089793613979, 34.460372584206716, 34.46035173961094, 34.509892395564485, 34.594761167253765, 34.324222632816856, 35.04210008893694, 36.356438704899375, 37.57954747336251, 35.195314816066194, 38.40915543692452, 34.55329779216221, 37.0307822227478, 42.590025493076865, 38.874681268419536, 39.83110775266375, 41.24159901482718, 36.95704793930054, 37.42463738577706, 35.884666442871094, 36.6637783731733, 34.60980749130249, 35.641267572130474, 34.601424489702495, 36.097743374960764, 35.43713297162737, 38.437215736934114, 38.672210761478965, 39.92859097889492, 38.45331123897007, 36.73527186257498, 35.74710600716727, 37.461105006081716, 35.87480000087193, 36.31563193457467, 33.63137953622, 34.93912778581892, 35.59552410670689, 34.295839241572786, 34.525765555245535, 35.49746070589338, 36.44737672805786, 36.877682140895296, 37.925602504185264, 37.91939776284354, 38.87088060379028, 37.386474405016216, 37.613854203905376, 39.51973465510777, 35.2136024747576, 35.19489445005144, 36.05915655408587, 37.3365272794451, 36.33477769579206, 37.20131880896432, 33.8036253792899, 36.28267662865775, 35.78762790134975, 34.041069643838064, 34.32313871383667, 36.59680816105434, 36.24947466169085, 36.26518453870501, 35.09173801967076, 34.961761542728965, 35.248610973358154, 34.40490164075579, 36.089346476963584, 34.947260652269634, 36.54802138464791, 38.94191551208496, 39.488679681505474, 42.13635328837803, 43.14890732084002, 45.14467314311436, 46.385499817984446, 46.487784249441965, 47.380318573543, 49.05389642715454, 49.1316363470895, 47.18353169304984, 47.904421193259104, 42.76241030011858, 42.183837277548655, 38.18241139820644, 39.91877664838518, 37.79137372970581, 41.16696146556309, 40.2971408026559, 48.19889279774257, 42.06418234961373, 57.093601431165425, 52.2689425604684, 62.58875451769148, 35.025330611637656, 0.020749565247180204, 0.7575185032827514, 0.2030401099473238, 0.12665476304079804, 33.15468794958932, 65.34832191467285, 56.7647362436567, 61.75176061902727, 50.978582177843364, 36.456760270254954, 23.964340414319718, 47.275181906563894, 52.40594366618565, 14.865191459655762, 0.22639208260391439, 0.2111055842999901, 0.016191321358616863, 0.052104982281369824, 0.07468096193458353, 0.0418951913847455, 0.03228467583124127, 0.0752003262085574, 0.18512662260660104, 0.18111057739172662, 0.1834583356976509, 0.2128496499998229, 0.08220572530158929, 0.14050837180444173, 0.19829617307654449, 0.10982866877956049, 0.12607100579355443, 0.1196708327957562, 0.22834988683462143, 12.938085998807635, 67.34450462886265, 55.85399069104876, 42.80098669869559, 25.86916995048523, 48.55078778948103, 51.68061774117606, 63.45138726915632, 56.51132154464722, 63.58268737792969, 36.267644201006206, 0.26040925511292046, 1.4552163822310311, 2.762361441339765, 0.17643476543681963, 15.848483153751918, 53.93610027858189, 48.28969880512783, 52.38545690264021, 56.028261934007915, 54.03912469318935, 45.81188780920846, 41.79760428837368, 41.775693144117085, 45.14983218056815, 52.15004498617989, 53.631626742226736, 47.90339285986764, 48.35396269389561, 48.14593710218157, 48.05582938875471, 47.1378299168178, 46.93111753463745, 47.304732595171245, 48.43818180901663, 38.13677910396031, 35.40571321759905, 37.190444878169465, 36.48718990598406, 35.40458413532802, 35.32465205873762, 35.1700233731951, 36.88522788456508, 37.215503556387766, 36.425135544368196, 36.98544175284249, 38.59484257016863, 36.61243118558611, 36.11626032420567, 36.7945226260594, 35.04674843379429, 37.283932890210835, 36.15571914400373, 35.517280442374094, 38.040692465645925, 39.190925053187776, 40.75626386914934, 38.217117650168284, 41.42754323141915, 36.77680124555315, 38.83077907562256, 43.25377648217337, 41.08810635975429, 41.229880877903526, 42.81448357445853, 38.334347656794954, 38.65162672315325, 36.905207429613384, 38.03599895749773, 35.243827138628276, 38.066425119127544, 36.029981068202424, 37.00613348824637, 37.770626408713206, 40.79958241326468, 40.17062452861241, 43.31127282551357, 40.72164099557059, 38.515612261635916, 37.44663190841675, 38.43846641268049, 39.74373068128313, 38.54773030962263, 34.41340970993042, 37.2561366217477, 37.0992671421596, 35.87179490498134, 37.25912782124111, 37.37846660614014, 37.670124190194265, 39.929129464285715, 40.03363731929234, 40.38347564424787, 40.47643559319632, 40.0646436555045, 39.979295458112446, 41.99436685017177, 36.74600682939802, 37.33361598423549, 36.510997908455984, 40.19662816183907, 37.75878667831421, 39.247872488839285, 36.60643836430141, 37.76450851985386, 37.98528405598232, 37.028134959084646, 36.49039997373308, 39.18651989528111, 38.12895195824759, 38.69116544723511, 37.836432797568186, 36.011606557028635, 37.12684106826782, 37.350930895124165, 38.2446220942906, 37.75146327699934, 38.72171320234026, 41.61464779717581, 42.13828836168562, 43.26565442766462, 46.83421795708792, 47.56483146122524, 47.45174258095877, 50.61768926892962, 49.48618902478899, 50.6632798739842, 50.92680420194353, 50.11098493848528, 51.36910915374756, 45.44376182556152, 44.41882610321045, 40.895630836486816, 40.849845681871685, 39.66388545717512, 42.59636572429112, 42.59368371963501, 50.56106145041329, 44.26979071753365, 58.57257761274065, 54.49257802963257, 64.6566217967442, 37.12333917617798, 0.1587269284895488, 1.0485717569078719, 0.6884593803967748, 0.18596221134066582, 38.33485834939139, 70.47607857840401, 63.525712149483816, 66.48888955797467, 58.27849858147757, 36.70491518293108, 29.151976653507777, 54.089085715157644, 59.580274854387554, 20.47085564477103, 0.4629596663372857, 0.32192157581448555, 0.08313932841909782, 0.09990141647202627, 0.16078027045088156, 0.2006426150245326, 0.1153378981564726, 0.16838168113359384], [0.03438925736450723, 0.06370094218956572, 0.020331889623776078, 0.05944311459149633, 0.008466794737614691, 0.04041011571618063, 0.07691937432225261, 0.02909518126398325, 0.02200632745267025, 0.04512799344956875, 0.04401096874581916, 5.092998734542301, 49.53505570547921, 44.99658966064453, 41.10429913657052, 23.610221999032156, 29.734874929700577, 44.02028438023159, 50.98719099589756, 48.95175790786743, 48.634367670331685, 41.59132269450596, 0.3405723050236702, 0.5004629482116018, 1.3971947985036033, 0.10263534941311393, 2.2410852185317447, 40.36183895383562, 50.06240660803658, 50.18914869853428, 51.74555213110787, 48.04296479906355, 42.36704737799508, 36.59876407895769, 39.944606576647075, 44.55207518168858, 49.37075860159737, 47.11184365408761, 46.25998755863735, 45.17611721583775, 42.882207666124614, 41.86313622338431, 42.175902434757774, 41.53428840637207, 38.8767865725926, 34.33690309524536, 32.93287713187081, 31.95617233003889, 31.59671422413417, 32.517996719905305, 33.068679673331125, 31.627213341849192, 30.745306287493023, 31.936442920139857, 31.843830381120952, 30.835059642791748, 31.937686647687638, 32.37876524244036, 31.91261407307216, 33.10245834078108, 31.700040885380336, 33.1955155645098, 31.250968388148717, 31.50473049708775, 32.67284427370344, 33.58538940974644, 33.39134706769671, 34.64082077571324, 34.42047255379813, 34.02440786361694, 33.45037201472691, 37.51455054964338, 39.977867603302, 36.74238681793213, 38.447655405317036, 39.670319489070344, 36.41965341567993, 36.1470582144601, 33.742363112313406, 34.91065059389387, 34.0887725012643, 34.54099948065621, 31.753083433423722, 34.43974338259016, 34.02863236836025, 34.61890268325806, 35.463008063180105, 36.6500244140625, 35.65948574883597, 34.48883935383388, 36.24152592250279, 34.860234464917866, 34.60809128625052, 33.196158272879465, 32.63633149010794, 33.06583438600813, 34.25749213354928, 33.4360031400408, 33.469278063092915, 34.81392124720982, 35.21474892752511, 35.979071617126465, 37.038063934871126, 37.53634010042463, 37.51741320746285, 35.924437931605745, 36.284778458731516, 35.91468266078404, 33.710564681461875, 33.54269272940499, 35.20489638192313, 34.504834106990266, 34.64660862513951, 33.57802084514073, 33.90127188818795, 33.2354016985212, 33.06678281511579, 33.50457491193499, 33.32319218771798, 33.13380513872419, 34.16881227493286, 33.428551197052, 33.20507281167166, 32.70872477122715, 32.871448108128135, 33.52596494129726, 32.29953840800694, 34.01833861214774, 33.99005249568394, 36.08601481573922, 38.13913106918335, 40.43949896948678, 40.29744304929461, 42.11737428392683, 43.747393880571636, 42.53009033203125, 46.242189747946604, 46.48634944643293, 47.94255985532488, 49.35193245751517, 49.55636235645839, 47.71502372196743, 50.301459380558555, 48.77527366365705, 49.948480469839915, 45.82769496100289, 42.450498717171804, 36.507586342947825, 40.90331207002912, 41.555456093379426, 54.87336015701294, 49.791784695216585, 61.10057544708252, 21.716189963477, 0.07216951384076051, 0.45085196888872553, 0.47548895116363254, 0.13619880591120037, 34.42270639964512, 57.54898289271763, 49.93274280003139, 55.72496264321463, 38.02730328696114, 27.72051225389753, 26.757090670721873, 38.50802482877459, 50.51543957846505, 8.358029774257115, 0.21725954408092157, 0.06854134638394628, 0.08504888880997896, 0.06748778506049088, 0.08761297765054873, 0.09231303366167204, 0.047665052847670655, 0.042116475225027115, 0.05226868224729385, 0.06235143781772681, 0.0513131895900837, 0.04130513733252883, 0.022356700883912187, 0.020830667145284157, 0.028519997306700264, 0.09114455564745835, 0.04957557336560317, 0.042505818618727584, 0.0840486739096897, 6.876152719770159, 57.17806373323713, 49.9547164780753, 43.41608987535749, 27.10955194064549, 37.86115796225411, 48.44318798610142, 55.52901649475098, 52.548451219286235, 53.60730457305908, 42.5860024860927, 0.21744399704039097, 0.19787628203630447, 1.765428587794304, 0.23862038286668913, 3.021452167204448, 44.14326054709298, 49.136520930698936, 51.26039069039481, 53.26246200289045, 49.68725599561419, 43.434655461992534, 38.782207693372456, 40.57617003577096, 46.57665865761893, 49.57122802734375, 48.236298424857004, 47.83253165653774, 46.17945793696812, 45.274729524339946, 43.84540516989571, 44.379992621285574, 42.9056578363691, 41.44425017493111, 36.7829920904977, 34.53661169324602, 32.69053438731602, 34.085395676749094, 35.725149699619834, 34.79056487764631, 34.07742609296526, 32.72652605601719, 33.95076390675136, 34.98167855398995, 33.27790035520281, 33.55701296670096, 33.97659730911255, 34.33552735192435, 34.689937591552734, 34.29098245075771, 35.553699425288606, 33.22730704716274, 33.694100924900596, 35.46878201620919, 35.03274433953421, 35.48602744511196, 37.431689807346885, 36.006270340510774, 36.287238121032715, 35.2563408442906, 39.726933411189485, 41.18816041946411, 39.68827016013009, 41.06401695523943, 41.353200980595176, 37.744761739458355, 36.73305538722447, 35.0316777910505, 36.286612783159526, 35.2797771181379, 34.93465314592634, 33.13742515019008, 37.15368890762329, 36.294648374829976, 35.94103022984096, 38.49121713638306, 38.572326932634624, 37.82298108509609, 36.46020310265677, 38.230333123888286, 36.924631118774414, 36.246532099587576, 35.36546925136021, 35.580411774771555, 35.04081814629691, 36.743550641196116, 34.334273202078684, 36.40488154547555, 35.32705613545009, 37.48197044645037, 36.20409597669329, 38.55363975252424, 39.44688974108015, 40.027401311056956, 37.88000842503139, 37.23909616470337, 38.86188963481358, 34.97243397576468, 35.80860103879656, 35.86983898707798, 36.31907476697649, 35.10787868499756, 34.80400269372122, 34.97416407721383, 34.198922293526785, 35.307719298771445, 35.04544564655849, 35.424574102674214, 35.375405175345286, 35.07129641941616, 35.58350372314453, 34.93177659170968, 35.48163965770176, 35.05185883385794, 35.23932818004063, 34.12387480054583, 36.39837108339582, 36.45116349628994, 37.89600665228707, 39.53335312434605, 41.22155346189226, 42.86455576760428, 42.769754546029226, 45.01102801731655, 45.071908133370535, 47.86894021715437, 48.478366715567454, 50.969115257263184, 51.41968509129116, 51.09412724631173, 48.92735930851528, 52.00581080572945, 50.2736040524074, 51.65626083101545, 46.72886937005179, 42.53409596851894, 38.788954394204275, 42.239242213112966, 43.25996037891933, 57.46445458275931, 53.558034896850586, 64.24576091766357, 24.324806009020122, 0.035639027266630104, 0.9831437191792897, 0.14293486731392996, 0.04761945529441748, 38.7289080619812, 62.91595213753836, 54.65438073022025, 59.57698140825544, 45.99164465495518, 30.68882785524641, 25.512048176356725, 44.98127235685076, 58.637605803353445, 11.844370927129473, 0.24356543751699583, 0.05452047534553068, 0.09371317710195269, 0.03441743013848152, 0.07923609643642392, 0.11413944246513502, 0.07181496572281633, 0.043513222597539425, 0.14731021039187908, 0.13126060446458204, 0.16380968503654003, 0.15662883035838604, 0.06519819756171533, 0.17426281555422715, 0.10953082583312478, 0.1889164306755577, 0.10093768193785634, 0.1871996285127742, 0.17269975585596903, 7.322033388274057, 63.88325950077602, 56.15126241956438, 51.81056989942278, 34.34305225099836, 41.65296711240496, 53.75324106216431, 60.12843213762556, 57.76777124404907, 57.77947895867484, 49.55084548677717, 0.8400528430938721, 1.2437820477145058, 6.345491869109018, 0.22959079167672566, 4.127590835094452, 45.05204323359898, 51.35953801018851, 52.850795132773264, 57.28204699925014, 51.351398195539204, 46.84053039550781, 41.078125272478374, 42.908739362444194, 47.55365875789097, 53.747647762298584, 50.27720321927752, 50.199577944619314, 49.83877188818795, 46.95674596514021, 44.60206052235195, 47.343576499394004, 45.9355205808367, 43.92437144688198, 37.27766214098249, 36.37649468013218, 34.6833506992885, 35.38879087993077, 37.191577434539795, 37.757341453007285, 35.86548594066075, 35.28597838538033, 34.649308000292095, 38.76601491655622, 34.3478604044233, 35.696238245282856, 35.393130029950825, 36.08804368972778, 38.004151889256065, 36.13316181727818, 36.66777011326381, 35.871478761945454, 34.19662938799177, 38.234738281794954, 36.27241761343819, 37.46237652642386, 38.053626537323, 36.92467280796596, 37.1094115121024, 36.54135806219918, 40.68287352153233, 44.91543470110212, 40.44526250021798, 42.304214818137034, 43.742366858891074, 39.28998899459839, 39.76930005209786, 36.738360336848665, 38.468406200408936, 36.92913702556065, 37.43550436837332, 36.21383735111782, 39.31948062351772, 37.78757306507656, 38.34905699321202, 40.37928588049752, 41.14847578321184, 38.42626190185547, 38.52781329836164, 41.9085704939706, 37.4739522252764, 39.061473165239605, 36.19011272702898, 37.22538389478411, 37.533453123910085, 38.11544118608747, 35.93055234636579, 38.91848966053554, 39.37224871771676, 39.44695227486746, 38.10560253688267, 40.96329239436558, 41.37705762045724, 42.074205126081196, 40.75363745008196, 39.547395433698384, 40.56319774900164, 37.38866308757237, 37.032884052821565, 37.582153047834126, 36.798232964106965, 37.46175466264997, 36.39171123504639, 36.2748772757394, 35.20194339752197, 36.61395631517683, 37.64969648633684, 39.335381575993125, 36.72025680541992, 37.031247752053396, 36.839713709695, 36.65934542247227, 37.22458137784685, 37.61189481190273, 38.410221985408235, 36.177922112601145, 39.42950882230486, 38.28204509190151, 40.6064259665353, 42.17513118471418, 44.406301975250244, 44.92690617697579, 44.334527083805625, 47.38496344430106, 46.369883741651265, 51.4433228628976, 50.52011571611677, 53.90083817073277, 54.10139444896153, 54.260574204581125, 51.21310125078474, 56.157668658665244, 52.53225496837071, 55.783473423549104, 50.69060019084385, 45.68837315695626, 40.13621704918997, 43.60432004928589, 45.931014674050466, 60.252005849565776, 55.783688817705425, 65.99293409075055, 25.073413610458374, 0.13735141977667809, 1.2009852698871066, 0.8464759098631995, 0.21223341806658677, 41.53680712836129, 67.73588275909424, 59.552475111825125, 65.40686048780168, 50.13716227667672, 39.25951419557844, 37.49325779506138, 50.44838598796299, 67.48480960300991, 16.68138803754534, 0.4626778843147414, 0.20973777983869824, 0.22266752246235097, 0.13236934425575392, 0.30708871888262884, 0.2430042890565736, 0.18593291219856056, 0.08841022915605988], [0.04446457279846072, 0.06959623085068804, 0.05352623833875571, 0.02966915742893304, 0.0517540202209992, 0.033579459746501276, 0.06305826774665288, 0.04637508653104305, 0.027018236462026834, 0.07886818796396255, 0.06721751777721302, 2.367652301277433, 42.14465985979353, 49.06148386001587, 37.806743144989014, 24.926356724330358, 32.94429997035435, 41.47806010927473, 49.48481675556728, 51.44394472667149, 45.82582936968122, 50.87144442967006, 3.382349635873522, 0.14715905993112496, 0.8506068853395325, 0.12068471339132104, 0.9499335012265614, 32.81485503060477, 52.36473042624337, 49.4916398865836, 51.23903887612479, 44.807987758091514, 38.76886020387922, 37.4199994632176, 44.9935428755624, 48.17218392235892, 49.63957745688302, 46.56946727207729, 44.50838838304792, 43.219497544424875, 41.11618055616106, 39.18755865097046, 39.58269575663975, 35.44393178394863, 32.7729434967041, 30.50472491128104, 31.71722378049578, 32.85552283695766, 31.707159314836773, 32.20735665730068, 31.30142273221697, 31.668596812656947, 33.501382214682444, 32.74485192980085, 32.91624314444405, 31.814585413251603, 32.62440490722656, 32.076202460697715, 34.716743741716655, 33.94390950884138, 32.29774577277047, 32.72886412484305, 34.085746560777935, 34.023667880467, 34.42077827453613, 32.7786340713501, 34.05994095121111, 35.9607492174421, 35.055610861097065, 34.993500913892476, 34.03314174924578, 37.05969367708479, 41.604187284197124, 36.636145387377056, 38.21652705328805, 38.454565388815745, 37.66988795144217, 36.61260836465018, 36.058819566454204, 34.4108110836574, 34.8067124911717, 33.663528851100374, 33.02321066175188, 33.97725738797869, 34.24628816332136, 34.90285471507481, 36.38679885864258, 38.213285718645366, 37.032533168792725, 34.15493324824742, 36.29950516564505, 36.04120935712542, 35.86335284369332, 35.019369057246614, 31.956821986607142, 32.09984370640346, 31.986772196633474, 33.97092757906233, 32.51478665215628, 33.28624514171055, 33.24918692452567, 36.01936074665615, 38.0889060156686, 38.56653560910906, 36.56030579975673, 35.56418425696236, 36.11155639375959, 35.465665749141145, 32.720567975725444, 34.36796154294695, 33.98690843582153, 34.07555702754429, 33.277528626578196, 33.68128497259957, 33.91123560496739, 33.67905460085188, 33.61577040808541, 34.04566240310669, 34.855874470302034, 33.55847208840506, 33.75191341127668, 32.192525727408274, 33.57309457233974, 31.824139186314174, 32.53484957558768, 33.4303195135934, 33.347559520176475, 33.26387194224766, 33.868545872824534, 32.82230697359358, 37.52104711532593, 36.624962261744905, 39.79162114007132, 40.89374787466866, 44.1040483883449, 43.7881624358041, 46.04503461292812, 45.950282028743196, 48.25752517155239, 49.38145187922886, 49.485855511256624, 48.67521960394723, 49.76531205858503, 43.399400302342, 42.9779086794172, 48.85819346564156, 49.94960955211094, 40.057111808231895, 40.47234657832554, 41.31472185679844, 54.54424830845424, 50.401096548352925, 59.844744137355256, 12.859964796475001, 0.25153928250074387, 1.1212173444884164, 0.24564102185623987, 0.28386336086051805, 41.007868562425884, 53.75809437888009, 52.41611235482352, 49.92574943814959, 35.37530790056501, 40.79014328547886, 40.11231872013637, 41.260348728724885, 47.22215672901699, 4.353226636137281, 0.18290197769446032, 0.07518560878400292, 0.05437086855194398, 0.038449861974056275, 0.004406585798798395, 0.04217934149450489, 0.07173400970974139, 0.07558475700872284, 0.030441845966769115, 0.05904579162597656, 0.025957289284893444, 0.027511098854509846, 0.04277573984914592, 0.06565658189356327, 0.05699154042771884, 0.02077762097386377, 0.03699314906927092, 0.008717266609892249, 0.06728737974273306, 2.8319452617849623, 49.45631524494716, 54.749598843710764, 45.26088176454817, 29.378251688820974, 39.12048421587263, 49.215626171657014, 54.11296319961548, 54.556793281010215, 50.99650853020804, 53.34123373031616, 3.2900493315287997, 0.4462775300656046, 1.6624944997685296, 0.7220015376806259, 0.6842254304460117, 36.456666469573975, 53.75468976157052, 50.128570829119, 53.82450178691319, 45.870728628976, 40.740008558545796, 39.67131655556815, 46.07760081972395, 50.69691957746233, 50.66377319608416, 47.13996648788452, 48.01323345729283, 46.31069898605347, 42.58635337012154, 41.893454687935964, 40.7032595361982, 37.893960407802034, 34.847342082432334, 33.0853761945452, 33.743502616882324, 35.12417915889195, 33.4489198412214, 35.01523835318429, 33.45638220650809, 34.579645361219136, 33.62052992412022, 33.90082720347813, 34.24597202028547, 34.7816538129534, 33.7486686025347, 33.97338376726423, 35.91070481709072, 34.826428004673545, 34.39081416811262, 35.27610846928188, 34.967997550964355, 35.01404673712594, 35.01325811658587, 34.21604265485491, 35.59439502443586, 37.62934173856463, 36.599014214106965, 36.61738872528076, 35.42265639986311, 38.825415066310335, 42.474786145346506, 39.020492689950125, 39.35621574946812, 39.328273568834575, 38.65569141932896, 38.16615261350359, 35.42800651277815, 34.561250005449565, 34.98488514763968, 35.62766647338867, 35.575565406254356, 35.0095408303397, 36.84743663242885, 38.22757468904768, 37.78071171896798, 40.39212615149361, 39.1978246143886, 37.19929688317435, 38.02896738052368, 37.52815164838518, 36.97439759118216, 36.615453651973176, 33.37096800122942, 34.0907701083592, 33.31936373029436, 35.98037093026297, 34.92340748650687, 35.69385501316616, 35.687532152448384, 37.968719550541465, 38.02670226778303, 39.06191437585013, 38.81799439021519, 36.83780295508248, 38.45526368277413, 38.18260942186628, 33.560011114392964, 35.25359283174787, 37.350545270102366, 37.34831837245396, 34.954292229243684, 34.79979903357369, 34.926631450653076, 35.68666362762451, 35.25701829365322, 35.138763427734375, 35.54618842261178, 36.404871123177664, 34.95538657052176, 34.07156181335449, 34.46531275340489, 34.51233468736921, 35.62688480104719, 33.46931627818516, 35.15083939688546, 35.327726636614116, 35.56844697679792, 36.239629064287456, 40.20525087629046, 38.57531465802874, 41.25464078358242, 42.444849831717356, 45.59374564034598, 45.5242532321385, 48.761220932006836, 47.26269599369594, 50.48236962727138, 50.402708530426025, 51.24906860079084, 50.00649445397513, 52.4384890283857, 46.20111199787685, 46.59554386138916, 51.194848333086284, 51.07910524095808, 42.04521376746041, 42.54561260768345, 42.30865124293736, 57.41889524459839, 52.246253217969624, 62.76507200513567, 15.128910337175641, 0.2183502484112978, 1.478449746966362, 0.34195089819175856, 0.32844436009015354, 44.18205581392561, 59.51289817265102, 57.18498761313302, 55.57213701520647, 41.58496161869594, 40.26438699449812, 42.878643240247456, 46.766365323747905, 54.51572247913906, 6.504417146955218, 0.2938659441258226, 0.06587952814464058, 0.06339562857257468, 0.05808903010828154, 0.024104313625554954, 0.016523784858041575, 0.017916003009304404, 0.04822118354162999, 0.14221126399934292, 0.15664356813899108, 0.08832602296024561, 0.1499343631522996, 0.17605534222509178, 0.24852457855428967, 0.21896949304001673, 0.07724696424390588, 0.17470345619533742, 0.2392446350838457, 0.140452202675598, 3.159771693604333, 55.429594721112935, 61.62788813454764, 50.74246849332537, 35.678304944719585, 43.21545021874564, 54.258986541203086, 57.475891317640034, 60.44985580444336, 55.346046107155935, 60.617995262145996, 4.579244588102613, 0.9030928175364221, 4.714636751583644, 1.4747516768319267, 1.9523067942687442, 38.5016324860709, 55.05959619794573, 53.46261875970023, 55.95865140642439, 48.34127875736782, 42.22014856338501, 41.94549669538225, 49.757408482687815, 52.00969137464251, 54.52784708568028, 49.179089069366455, 49.11717367172241, 47.732307365962434, 45.147403785160606, 43.87757532937186, 43.73544645309448, 39.09575210298811, 36.47502361025129, 35.09379121235439, 36.80713708060128, 37.49221556527274, 35.71889284678868, 36.78417328425816, 36.11652782985142, 36.28742919649397, 36.93567180633545, 35.2828551701137, 36.31637191772461, 37.11638055528913, 36.53307580947876, 35.77855702808925, 38.04637609209333, 37.5013941356114, 35.29536540167672, 36.384109905787874, 37.138187476566856, 37.26632962908064, 38.30574539729527, 35.014904839651926, 37.866539342062815, 41.30114507675171, 39.08410692214966, 38.08076967511858, 38.556248801095144, 40.56160313742501, 42.699438776288716, 39.810551507132395, 40.68356139319283, 40.04392760140555, 40.30525629861014, 40.08595378058297, 37.98865393229893, 37.19574287959507, 35.61224842071533, 38.06363889149257, 37.50852298736572, 37.01129599979946, 39.237325123378206, 40.385285649980815, 40.196906089782715, 42.59061261585781, 40.053415366581504, 39.27041939326695, 40.177603994097026, 39.70982347215925, 39.71840797151838, 39.690702029636924, 35.59836939402989, 37.259398800986155, 36.082617146628245, 39.02052395684378, 36.37030036108834, 36.79703439985003, 36.8383275440761, 39.67598921912057, 40.66054548536028, 42.33004822049822, 41.335597719464985, 38.718690735953196, 40.15330266952515, 38.2663699558803, 35.82745497567313, 37.7944517816816, 38.0216509274074, 38.07350533349173, 36.87333951677595, 36.97996309825352, 37.259030546460835, 37.37839017595564, 37.66495473044259, 37.8484844480242, 38.696960244859966, 38.27531923566546, 36.44275270189558, 36.2460491997855, 38.15904113224575, 36.89745323998587, 37.90861415863037, 38.00772673743111, 37.151993547167095, 37.827625955854145, 37.6388920375279, 38.56717831747872, 42.95985378537859, 40.840583733149934, 43.39227145058768, 45.357840401785715, 46.4801481791905, 48.46496016638619, 51.16892807824271, 49.05784995215279, 50.14453431538173, 53.329477378300254, 52.03162336349487, 53.4789331299918, 55.65433420453753, 48.978456360953196, 48.53250707898821, 53.22734580721174, 52.25907611846924, 44.284593854631694, 44.1101975440979, 45.565633228846956, 60.21233858380999, 55.207915919167654, 63.88530921936035, 16.630657502583094, 0.26985115132161547, 2.865533939429692, 0.7423192645822252, 0.5797355973294803, 48.622354234967915, 63.90058135986328, 63.04422977992466, 59.43813555581229, 50.120910440172466, 54.62883220400129, 51.817313126155305, 55.39962019239153, 64.40105315617153, 10.202160716056824, 0.7395200633576938, 0.14997056978089468, 0.12609791649239405, 0.15016935339995793, 0.11425925817872797, 0.11361909431538411, 0.135280381622059, 0.12285637828920569], [0.0411292406996446, 0.03557125858164259, 0.08866919204592705, 0.054102487596017976, 0.04015930542456252, 0.08538872628871884, 0.028299614221655896, 0.06425375823995896, 0.03438592915024076, 0.06748640763440303, 0.03320231641243611, 0.4259632501219, 31.664910793304443, 52.17464508329119, 41.220980235508506, 30.079092161996023, 27.941786323274883, 41.69488559450422, 47.50651523045131, 52.294341700417654, 45.351468903677805, 54.38984543936593, 9.979609046663557, 0.4357860487486635, 0.7194706563438688, 0.6487538452659334, 0.3572988174855709, 28.477358681815012, 57.08391564232962, 48.86621516091483, 51.37803411483765, 41.63093090057373, 37.849106311798096, 40.9656582559858, 47.172657762254985, 46.344356060028076, 49.985601220812114, 45.687504632132395, 44.571933133261545, 42.37440552030291, 38.73978199277605, 36.226594243730815, 34.15617002759661, 32.18347569874355, 31.345429147992814, 32.14875207628523, 33.826377255576, 32.04820122037615, 31.27177824292864, 31.654036862509592, 32.236653736659456, 32.488463401794434, 34.150396074567524, 32.18825953347342, 33.853172983442036, 33.333541529519216, 32.53427634920393, 33.06035573141915, 32.921923296792166, 33.27147674560547, 33.22883217675345, 32.51919528416225, 33.89154093606131, 32.16533742632185, 32.83476161956787, 35.13277060644967, 34.5159581729344, 33.79061140332903, 34.783647945949006, 34.89249842507498, 33.686777523585725, 37.75954403196062, 40.573519298008506, 37.709190436771934, 37.99191958563668, 38.14820889064244, 36.232392515454976, 32.24740259987967, 35.27057422910418, 34.552443163735525, 33.578833784375874, 32.78139598029, 32.37420722416469, 33.68573529379708, 35.72980499267578, 35.547199385506765, 37.82667057854788, 37.27656779970442, 36.66910416739327, 35.56201294490269, 38.65373202732631, 34.473806926182334, 35.37899391991751, 35.89225387573242, 34.145525387355256, 33.0907541002546, 32.54443808964321, 33.3148751940046, 33.6359931400844, 34.61284385408674, 34.74290023531233, 35.163287094661165, 36.19996179853167, 38.02417312349592, 37.80749355043684, 34.2368038722447, 37.400572299957275, 34.2874492917742, 32.399067878723145, 32.907335553850444, 34.588879517146516, 33.31286021641323, 32.296029567718506, 32.20493868419102, 32.90796783992222, 33.5296995980399, 33.054349013737266, 31.88080174582345, 33.73834357942854, 33.47978721346174, 32.97709199360439, 32.5251464162554, 32.36009543282645, 34.26825489316668, 33.237232548849924, 32.47091572625296, 34.19586508614676, 33.005471910749165, 33.11170639310564, 32.77189779281616, 34.33878605706351, 34.30087668555123, 35.74052606310163, 38.11596577508109, 39.89974900654384, 41.23477240971157, 44.763501916612896, 43.7590251650129, 48.79605572564261, 47.27120058877127, 50.562291281563894, 46.37774910245623, 47.368857519967214, 44.66556358337402, 46.896675314222065, 48.0350855418614, 54.531324659075054, 42.70418439592634, 37.90610933303833, 41.66478252410889, 53.79137625013079, 49.34964997427804, 54.42535768236433, 5.3619978087288995, 0.08018787072173186, 0.8784236184188298, 0.23688384890556335, 0.8532175081116813, 45.46471759251186, 53.31721033368792, 55.63378143310547, 49.672154085976736, 32.94189936774117, 16.96324518748692, 22.523226703916276, 40.06954213551113, 40.70152596064976, 3.022165660347257, 0.16855510111365998, 0.10485259829355137, 0.06389730343861239, 0.0018670762531525853, 0.07282400157834802, 0.04973760413538132, 0.025637566976781403, 0.029459337437791482, 0.06476563148732696, 0.10090342270476477, 0.03808558705661978, 0.05277436046994158, 0.055488619288163524, 0.10272561492664473, 0.04304628533178142, 0.03463747225967901, 0.027442302188969085, 0.0558528534934989, 0.0850694009235927, 0.9912301195519311, 38.702251298086985, 56.12494959150042, 44.93809972490583, 31.632643359048025, 31.689604691096715, 46.41578354154314, 53.55429676600865, 58.173712798527305, 49.62650442123413, 59.26280471256801, 10.091488940375191, 0.402044809290341, 0.7760582513042859, 0.9520557416336877, 0.6387990851487432, 30.134545734950475, 58.93864345550537, 49.11645105906895, 54.63962623051235, 43.800422532217844, 40.63431256158011, 42.63684245518276, 47.519230433872764, 47.96994618007115, 50.31874302455357, 48.087071963718955, 46.629694257463726, 43.867608138493125, 41.97898701259068, 39.29091657911028, 36.831153529030935, 33.31673731122698, 33.14657940183367, 33.62181534085955, 34.56559262956892, 33.43505818503243, 33.19018977028983, 33.26766218457903, 33.9756349836077, 35.39714956283569, 36.52848999840872, 34.67372049604143, 34.60228606632778, 35.77625370025635, 34.21107816696167, 35.21594054358346, 34.6878149168832, 34.23078325816563, 35.45056731360299, 34.874089172908235, 35.31051594870431, 33.18472153799874, 36.078938075474326, 35.46429000582014, 36.57330240522112, 37.02202749252319, 36.29740333557129, 36.095933369227815, 35.01628058297293, 38.31939860752651, 41.153065068381174, 38.766803537096294, 41.191509451184956, 39.59063754762922, 37.4953943661281, 34.12900257110596, 37.3269943509783, 35.50080278941563, 34.923886912209646, 33.31650454657418, 35.318482058388845, 35.330040386744905, 37.68707432065691, 36.80985382625035, 38.30109010423933, 39.70264598301479, 38.58940213067191, 37.14852639607021, 40.94700581686837, 36.79216023853847, 36.928817408425466, 35.821819986615864, 36.77775314876011, 34.7771235874721, 35.17996971947806, 35.54497248785836, 35.107479163578574, 37.11796127046858, 36.13834864752633, 37.90047434398106, 37.64925527572632, 38.73126350130354, 38.76344060897827, 36.02229983466012, 40.335574763161794, 36.392173290252686, 34.65910496030535, 35.81854738507952, 35.38145705631801, 35.42821495873587, 34.72320556640625, 33.97712189810616, 34.96944625037057, 35.41950191770281, 34.52389996392386, 33.30704110009329, 35.96893419538225, 34.61255897794451, 36.41579369136265, 33.88215044566563, 34.82324225561959, 33.9917756489345, 35.39737885338919, 34.07490389687674, 36.568195479256765, 34.84203018460955, 35.27496896471296, 35.272544043404714, 36.12951053891863, 36.14468887874058, 39.01754665374756, 40.7988736970084, 41.37340634209769, 43.34316158294678, 46.55975021634783, 45.730757168361116, 50.753199986049104, 49.193391936165945, 52.121717180524556, 47.74241352081299, 48.7513336454119, 44.904908180236816, 46.67495482308524, 49.13643407821655, 57.01254027230399, 44.203209604535786, 40.671603543417795, 42.26243877410889, 57.54319851739066, 51.42377758026123, 56.83538205283028, 5.882604616028922, 0.13440843698169502, 5.010534908090319, 0.34215679285781725, 0.8159579017332622, 49.122596740722656, 57.99562699454171, 60.90745721544538, 53.323863233838765, 42.07744993482317, 23.335967915398733, 26.89691969326564, 46.114582606724326, 48.51660960061209, 5.136155298777989, 0.23559905641845294, 0.10250321150358234, 0.08922273412879024, 0.05291530915669032, 0.08893488600317921, 0.059719515831342766, 0.024858568063271896, 0.04307949962094426, 0.09220490232110023, 0.20882349461317062, 0.1777519647564207, 0.12835635244846344, 0.17231794420097554, 0.17077684189592088, 0.10155512166342565, 0.27267779250230106, 0.10909676019634519, 0.1756144030285733, 0.17390391124146326, 1.1745969887290681, 44.646997996738975, 65.57206085750035, 52.53964785167149, 41.48031827381679, 37.70689058303833, 53.074228354862754, 56.09761537824358, 60.949966294424875, 53.82965735026768, 64.74676077706474, 12.196595089776174, 0.8675245004040855, 3.8994176387786865, 2.28846281341144, 0.9350641391107014, 30.675879887172155, 59.306119782584055, 53.014546803065706, 55.15048558371407, 45.87635319573538, 42.31659650802612, 44.80793217250279, 49.42142139162336, 49.58513484682356, 53.238188471112935, 49.83296666826521, 49.28120674405779, 45.551330362047466, 43.46339668546404, 40.36428819383894, 38.71689462661743, 35.95432908194405, 36.40057713644845, 35.30384915215628, 36.123590673719136, 36.247362409319194, 35.32985625948225, 36.53180776323591, 36.47486727578299, 37.34755059650966, 38.362665040152415, 35.58311809812273, 37.09097794124058, 38.081985609872, 37.915881974356516, 37.859782218933105, 36.403432846069336, 36.864657742636545, 37.538949148995535, 36.16939319883074, 38.0975148337228, 35.29518474851336, 37.082688740321565, 37.91737583705357, 38.0154253414699, 37.445068563733784, 37.54437221799578, 37.80643742425101, 37.223956039973665, 40.474107946668354, 43.16636119570051, 40.255809443337576, 41.98606027875628, 40.87914276123047, 40.107580048697336, 35.02792228971209, 39.715312549046104, 36.52762147358486, 35.38494157791138, 34.94057648522513, 36.65332480839321, 37.274712630680625, 38.990479946136475, 39.63842378343855, 41.47912665775844, 41.431350844247, 41.59069388253348, 40.70547948564802, 43.653683526175364, 39.75936760221209, 37.736521175929475, 39.02802801132202, 39.376139708927695, 37.59073059899466, 36.44253730773926, 39.91570554460798, 37.23081391198294, 39.4563775062561, 38.6318347794669, 38.79603460856846, 39.834331716809956, 41.22848081588745, 41.49372134889875, 37.96039908272879, 42.89992904663086, 37.626468658447266, 36.84171479088919, 36.93606090545654, 36.76425279889788, 37.455803530556814, 35.60155166898455, 36.557064465114046, 37.353581632886616, 37.07619912283761, 35.45141499383109, 35.504169191632954, 37.75627837862287, 36.706426416124614, 37.74385152544294, 35.533959593091694, 36.43608243124825, 36.755623136247905, 36.95390387943813, 36.13868563515799, 38.28295530591692, 37.50872448512486, 37.968719550541465, 37.30379778998238, 37.946655545915874, 39.05320828301566, 39.77313545772007, 42.01968608583723, 43.064827169690815, 45.959217412131174, 49.7806328364781, 47.40524871008736, 53.59120559692383, 50.64713226045881, 54.66286448069981, 48.77334206444876, 50.04023838043213, 44.09985862459455, 46.41609273638044, 51.48388992037092, 58.2476555279323, 46.449899196624756, 42.08333158493042, 45.49370200293404, 59.88121523175921, 54.011179038456504, 59.67204666137695, 7.263249022620065, 0.17529447376728058, 5.234344635690961, 0.8674288541078568, 1.1875862117324556, 54.73745339257376, 65.4687967300415, 65.61925302233014, 60.43193640027727, 47.821018491472515, 26.822832788739884, 35.61775834219796, 52.80835206168038, 57.90500511441912, 7.931720444134303, 0.34299538071666447, 0.24762228982789175, 0.22002985328435898, 0.07609748521021434, 0.20239586808851787, 0.173863077004041, 0.16689957066306046, 0.11353923752903938], [0.0464536303521267, 0.013580452617523926, 0.09565426222980022, 0.013647010965671922, 0.05935361582253661, 0.05511494666071875, 0.02298824565618166, 0.0445394864571946, 0.007172178759771798, 0.04069268483934658, 0.0809141949617437, 0.044893037128661356, 20.441369227000646, 54.243971484048025, 36.675916876111714, 29.33779580252511, 22.575569220951625, 35.774596554892405, 41.484403814588276, 53.9061153275626, 44.794063568115234, 52.446191106523784, 21.56742034639631, 0.11448496606733118, 0.585165451679911, 0.15333488211035728, 0.2774966396391392, 26.540046317236765, 56.054647718157085, 50.99255153111049, 47.85144117900303, 39.740405968257356, 38.88934196744646, 45.079547677721294, 46.25129188810076, 48.11051171166556, 48.66545391082764, 46.99170235225132, 43.73108993257795, 40.0641816002982, 38.1104280608041, 33.40725844247, 32.70019585745675, 31.91255153928484, 32.61911037990025, 30.40674488885062, 31.326189586094447, 31.587243829454692, 32.715530531747, 33.53126294272286, 34.152814047677175, 32.90120029449463, 33.89082874570574, 33.61113943372454, 32.638641766139436, 32.67318820953369, 34.24649313517979, 33.67344045639038, 32.05670928955078, 33.03259072984968, 33.16119841166905, 34.30529921395438, 34.07412569863455, 34.43403196334839, 33.59359523228237, 33.11772353308541, 33.842194829668315, 36.38585390363421, 35.12212249210903, 34.848766463143484, 32.83593239103045, 35.642295905521934, 37.48197392054966, 36.01556703022548, 36.9903576033456, 37.575847557612825, 38.03643321990967, 34.487887450626914, 35.46296637398856, 34.1927627154759, 35.18065064293997, 33.77678101403372, 32.84431191853115, 33.80222531727382, 34.67963688714163, 35.90941245215279, 36.54320975712368, 36.338894503457205, 36.644042015075684, 36.33646610804966, 36.46103341238839, 36.1073214667184, 34.71622610092163, 32.62758718218122, 33.34958839416504, 32.165531975882395, 31.550665037972585, 32.782584122249055, 32.54508079801287, 33.57520335061209, 33.613237789699006, 33.379674094063894, 35.3580972126552, 37.17921658924648, 35.813218116760254, 35.93866784232003, 35.62604406901768, 34.47422729219709, 32.798832484654014, 33.236228534153526, 34.65558222361973, 36.10872500283377, 34.589539596012656, 34.500460215977256, 33.35870443071638, 33.43853923252651, 33.07226841790335, 33.087794167654856, 33.35117605754307, 32.59183175223214, 33.58713688169207, 33.79302590233939, 33.643782070704866, 33.23294203622, 33.11283894947597, 31.34219823564802, 34.02221918106079, 32.348276547023225, 34.348843574523926, 34.20401184899466, 34.38181972503662, 32.91242510931832, 33.631886754717144, 33.49258579526629, 36.95677695955549, 38.21995251519339, 40.36594533920288, 41.36100728171212, 45.28835146767752, 45.8967079435076, 49.022563525608604, 49.724480969565256, 51.34770522798811, 52.418116910117014, 51.55895825794765, 47.04035016468593, 52.19941888536726, 48.52327639716012, 41.26554945537022, 39.0002977507455, 52.377258028302876, 53.0161692074367, 48.321955817086355, 1.5425482903208052, 0.15904372291905539, 1.47152293579919, 0.4239741654268333, 1.1855147800275256, 48.15406649453299, 52.03822067805699, 49.46307584217617, 46.91450439180647, 31.894451481955393, 21.612865039280482, 39.57441002982003, 43.92522954940796, 39.32334729603359, 1.5685506207602364, 0.2113394346088171, 0.030216250036443983, 0.08224501926451921, 0.0316072162905974, 0.03673463061984096, 0.015119719485353147, 0.02933979992355619, 0.08369993405150515, 0.019682921768565263, 0.062264490340437205, 0.08278013233627592, 0.03981551547933902, 0.04698541520961693, 0.06241838886801686, 0.0318766082637012, 0.027292692002707293, 0.05415280775300094, 0.05221587186679244, 0.05368571781686374, 0.09151270839252643, 27.686926398958477, 62.30367687770298, 44.382702418736045, 33.224079608917236, 30.602079595838273, 43.72867195946829, 45.009419509342735, 59.47347409384591, 47.740360328129356, 56.62488637651716, 23.14397529193333, 0.10254850371607713, 0.7835794048649924, 1.2972678691148758, 0.2702792254941804, 28.206149646214076, 56.267748968941824, 51.5523852620806, 49.06751142229353, 41.30980600629534, 40.23821313040597, 47.93061590194702, 47.75844301496233, 49.838306358882356, 49.47719805581229, 48.120746408190044, 45.070768628801616, 42.40559598377773, 39.81055498123169, 34.85538809640067, 34.83086442947388, 34.62315150669643, 34.04806995391846, 33.1682299886431, 33.18044144766671, 32.338406630924766, 34.69479785646711, 34.19918632507324, 35.32510369164603, 34.79105819974627, 35.04919419969831, 35.66791043962751, 34.88117633547102, 34.608108656747, 35.070949009486604, 35.47168288912092, 33.58977024895804, 35.05533988135201, 34.53114693505423, 35.895533425467356, 35.101701736450195, 36.34232691356114, 34.92967823573521, 35.40404564993722, 34.4638466835022, 37.46265098026821, 35.81106070109776, 36.31604882649013, 34.23638698032924, 36.455183029174805, 39.840838704790386, 38.30606501443045, 38.32737166540963, 39.30171407972063, 38.420977796827046, 35.715839113507954, 37.13111768450056, 36.56452683040074, 36.139092104775564, 35.53936876569475, 33.50407116753714, 35.753460134778706, 36.50595004217965, 37.56746455601284, 38.99228995186942, 37.69216040202549, 38.07992546898978, 37.63006782531738, 39.15296357018607, 38.269520963941304, 37.47561284473964, 34.93493454796927, 34.98317241668701, 34.38707256317139, 33.40775523866926, 33.647537572043284, 34.132824080330984, 35.21973078591483, 35.728127002716064, 35.283143520355225, 35.48373801367623, 38.17116921288626, 38.80690853936331, 37.81001574652535, 37.67280966894967, 37.28843879699707, 34.62403392791748, 35.04980911527361, 36.463691098349436, 36.42578867503575, 36.2235300881522, 36.49684790202549, 34.64232506070818, 35.07260962894985, 35.109831128801616, 35.13912125996181, 34.780997208186555, 33.47716079439436, 36.46052966799055, 35.31050900050572, 35.98692308153425, 35.294687952314106, 35.23602431161063, 33.503258228302, 35.25967945371355, 34.06218521935599, 36.65514523642403, 35.74997908728463, 36.796784264700754, 34.9618171283177, 35.27673380715506, 35.63621275765555, 39.99859755379813, 40.121761322021484, 42.31648881094796, 43.49557031903948, 46.693228585379465, 48.95680577414376, 50.19035768508911, 50.83772134780884, 54.299185344151084, 53.4024577822004, 52.606437410627095, 47.74842718669346, 53.465926102229524, 51.018183435712544, 42.922451632363455, 41.93577963965279, 55.83329895564488, 53.881695883614675, 51.188462938581196, 2.007529773882457, 0.3463275304862431, 4.1622501867158075, 0.42463679558464457, 1.4136131746428353, 52.35046230043684, 58.946286473955425, 57.381659848349436, 53.16649695805141, 40.686625548771445, 23.441394669669016, 43.32218844549996, 50.06817708696638, 46.86074617930821, 2.040596033845629, 0.25028203853539055, 0.14722121373883315, 0.06487112332667623, 0.01657588786578604, 0.007763721348185624, 0.06549679368202176, 0.01608609584426241, 0.05920586482222591, 0.09846018773636647, 0.10067441035062075, 0.29908911670957294, 0.07360134486641202, 0.1094743310074721, 0.17954107161079133, 0.15684075041541032, 0.14613371209374496, 0.17529849069459097, 0.16503111592360906, 0.12772683479956218, 0.20298897554831846, 31.613358633858816, 69.86424105507987, 50.044205801827566, 39.97016552516392, 33.04353414263044, 47.69082662037441, 49.76297051565987, 62.637322425842285, 53.349192891802105, 62.813688550676616, 27.535026618412562, 0.3546430857053825, 4.289864710399082, 2.3656779272215704, 0.7972175787602152, 32.141289710998535, 56.63788298198155, 54.272271496909006, 50.99499729701451, 43.65393018722534, 41.39434821265084, 51.03230912344796, 49.54569687162127, 50.645075593675884, 51.26260021754673, 49.40568372181484, 46.67495134898594, 43.180889878954204, 40.56334713527134, 35.93166058404105, 36.8336409841265, 36.110844203404014, 35.478641510009766, 35.25293622698103, 34.65949058532715, 35.862251554216655, 36.83712550571987, 35.446603366306846, 38.09357173102242, 35.25219971793038, 38.87513290132795, 39.298781939915244, 36.40339463097708, 37.16982609885079, 37.91711875370571, 38.72792141778128, 36.031672954559326, 37.37936987195696, 37.189777851104736, 38.21580791473389, 38.035015787397114, 37.91414492470877, 35.23261274610247, 36.745530877794536, 36.26198836735317, 39.55644198826381, 37.164135524204795, 38.49968351636614, 36.56683015823364, 38.7991612979344, 42.121039458683555, 38.51591798237392, 39.25344494410923, 40.984057085854666, 40.6593017578125, 37.78799343109131, 37.707168510981965, 37.12837314605713, 37.984971387045725, 37.22047846657889, 36.68563045774187, 38.12919167109898, 37.75823082242693, 41.05614464623587, 41.79211868558611, 40.637508732931956, 40.53120824268886, 40.32417624337332, 40.38659191131592, 39.77353497913906, 41.115523951394216, 36.72506843294416, 37.253284386226106, 36.7856775692531, 35.786352906908306, 36.04042421068464, 36.41097511563982, 37.77576807567051, 39.00319514955793, 38.0156581061227, 38.21765960965838, 40.17432444436209, 40.29157182148525, 40.780926500047954, 39.72978912081037, 38.345301491873606, 36.78731039592198, 37.1253194127764, 38.92385366984776, 39.055025236947195, 37.82377665383475, 39.05312837873186, 36.63452993120466, 36.38341161182949, 36.87194292885916, 37.60076379776001, 36.262113434927805, 34.616165093013215, 37.979489258357454, 36.73346880504063, 38.55211809703282, 37.90148878097534, 37.62938690185547, 34.540499210357666, 37.523023877825054, 36.44699110303606, 39.97068664005825, 39.520981856754844, 37.97556005205427, 37.489735058375764, 36.98446553094046, 37.471985885075156, 42.31072180611746, 43.20286703109741, 45.29266977310181, 45.11025176729475, 48.659200532095774, 51.13927664075579, 53.13110283442906, 54.079500675201416, 55.16988842827933, 55.329728262765066, 54.16337585449219, 47.33144841875349, 55.46138620376587, 54.667082037244526, 44.16448381968907, 43.58932931082589, 58.75958142961775, 57.438881737845286, 52.19336353029524, 2.939958700111934, 0.46110493157591137, 3.121149914605277, 0.5393748145018304, 1.8894401448113578, 57.792402608054026, 62.58771228790283, 61.75832666669573, 58.17069033214024, 45.83346891403198, 31.592364651816233, 52.252075808388845, 56.88708012444632, 57.979639189583914, 3.3961856705801825, 0.4479911024016993, 0.2164733526962144, 0.18383127211460046, 0.12139906148825373, 0.12485000916889735, 0.14655342671488011, 0.16253923677972384, 0.18813072783606394], [0.08849322755954095, 0.030575171312583343, 0.0637190251478127, 0.04633940915976252, 0.04923609551042318, 0.07665233686566353, 0.029214752704969475, 0.05172670579382351, 0.031065117700823715, 0.02804060553067497, 0.0528859523391085, 0.019087364797347357, 12.545347758701869, 49.71913085665022, 42.6576384135655, 33.2078138760158, 19.93248837334769, 34.34945501599993, 46.73750945499965, 53.802917207990376, 45.15961871828352, 52.586850438799175, 29.326932294028147, 0.15063362063041755, 0.36546799913048744, 0.47465370169707705, 0.08085326930241925, 18.445553030286515, 57.8489922114781, 47.234621797289165, 48.465231146131245, 40.66366522652762, 45.38960756574358, 44.895733083997456, 49.66560888290405, 45.614802156175884, 46.280401366097585, 46.735407624925884, 44.45973709651402, 39.43272583825247, 35.25500679016113, 32.154202938079834, 33.25943899154663, 31.077221734183176, 32.37940100261143, 32.65531396865845, 33.73584222793579, 32.39854676382882, 33.239445550101145, 34.50618553161621, 34.41738755362374, 35.989514759608674, 38.20053230013166, 37.516020093645366, 35.924139159066335, 35.8311653137207, 34.51067406790597, 33.46877431869507, 33.457118715558735, 32.90792267663138, 33.13411085946219, 33.97418975830078, 33.700180598667686, 33.92509726115635, 34.26404081072126, 32.735979080200195, 34.57820013591221, 36.395070689065115, 36.163101605006624, 35.225098269326345, 33.83502776282174, 37.32141842160906, 37.25792578288487, 37.06769105366298, 37.728537695748464, 37.922465392521445, 36.964197635650635, 35.43192182268415, 37.54440695898873, 35.08974041257586, 33.428356647491455, 33.281086104256765, 33.42806134905134, 34.20308426448277, 36.85941532679966, 35.0134665625436, 35.590479714529856, 37.24073593957083, 37.326834542410715, 35.22227382659912, 36.59381696156093, 35.062666756766184, 34.34424386705671, 32.041972160339355, 33.51345470973423, 31.962529931749614, 31.809825897216797, 32.544983523232595, 32.46786199297224, 34.88336501802717, 32.58982719693865, 35.392150333949495, 35.764803068978445, 35.771834645952495, 35.451741559164866, 34.613583837236675, 36.62410068511963, 35.75208439145769, 33.64232989719936, 34.02998726708548, 34.10172046933855, 33.25919927869524, 34.47180584498814, 32.063528946467805, 33.39453976494925, 33.43660415921892, 33.210384709494456, 34.55479165485927, 33.155879565647666, 35.021953787122456, 34.14312825884138, 32.95243978500366, 32.816467012677876, 33.64227778570992, 32.99725219181606, 33.04722711018154, 33.62510183879307, 32.79288135256086, 32.64694833755493, 33.822920526777, 32.148759024483816, 34.413430554526194, 34.15567323139736, 33.60872493471418, 34.310176849365234, 34.82330478940691, 35.55587421144758, 36.010498319353374, 39.99348020553589, 42.78692701884678, 45.07832479476929, 44.740340096609934, 47.18873936789376, 45.76105826241629, 50.53936570031302, 50.62756265912737, 47.62116398130144, 49.84153379712786, 43.79263360159737, 42.118656226566856, 50.28548199789864, 54.64470188958304, 38.975027152470176, 0.10914933987494026, 1.868463316134044, 12.189023290361677, 0.36346946922796114, 2.519218785422189, 47.80732706614903, 49.8375802721296, 47.35882084710257, 42.294772216251914, 35.435437611171174, 23.714691638946533, 26.41622941834586, 48.48842770712716, 27.26452282496861, 0.24062735374484742, 0.017757962025435906, 0.030554601523493017, 0.020126900801967298, 0.04772418038919568, 0.030406026103134667, 0.05627513636967965, 0.05164360221741455, 0.04435737444353955, 0.036434385659439225, 0.036854744888842106, 0.04852108584184732, 0.029933087195136716, 0.03346435645861285, 0.014373721122475607, 0.025043365379263247, 0.03209728481514113, 0.03081410045602492, 0.02914473128372005, 0.013310549198649824, 0.03278499362724168, 16.817626578467234, 56.641259806496755, 45.28087868009295, 34.712685993739534, 21.850550753729685, 42.84576783861433, 48.73016248430525, 58.53976127079555, 49.536261217934744, 56.76032066345215, 31.117496967315674, 0.09274109426353659, 0.346832523388522, 0.398890028574637, 0.3390866390296391, 20.633742264338903, 58.424032075064524, 49.35978044782366, 50.00205455507551, 42.151507309504915, 47.34260722569057, 47.726675851004465, 49.994751998356406, 46.52040951592581, 48.72342620577131, 47.740485395704, 45.8671225139073, 42.558459826878135, 37.1129481451852, 34.27386556352888, 34.81859391076224, 32.02852739606585, 34.00877789088658, 33.37180525915963, 35.15018279211861, 35.40602241243635, 34.787730012621196, 34.94673606327602, 36.443906102861675, 38.51517799922398, 38.978747912815635, 38.400171416146414, 38.30747202464512, 38.15393420628139, 37.62719127110073, 34.6624435697283, 35.61282859529768, 34.67831672940935, 35.46512031555176, 35.58026933670044, 35.77576732635498, 36.122826371874126, 36.55912460599627, 33.7893259865897, 35.758070264543804, 36.850337505340576, 36.413139479500906, 36.74219226837158, 35.03573553902762, 38.850258350372314, 38.52432877676827, 37.8397262437003, 39.42179979596819, 38.35476841245379, 37.97827679770333, 36.52410568509783, 36.518081596919465, 36.89490672520229, 34.43496649605887, 33.98111016409737, 33.904270035879954, 35.85468149185181, 38.005096844264436, 37.02477897916521, 37.8534072467259, 39.153672286442344, 38.50003787449428, 36.298369135175435, 38.36779628481184, 37.05138710566929, 37.20325040817261, 35.13081121444702, 35.68653508595058, 34.680779865809846, 33.8414374760219, 35.115181241716655, 34.55562196459089, 35.745191778455464, 35.91894885471889, 37.281375953129356, 38.00966528483799, 36.76727179118565, 38.61579138892037, 37.494039467402864, 38.54901920046125, 37.223014559064595, 35.24947254998343, 35.51577615737915, 36.39076975413731, 34.436575004032676, 35.1506587437221, 34.442578247615266, 35.394759382520405, 35.55209786551339, 34.42383895601545, 34.75897141865322, 34.939072200230186, 35.653986249651226, 35.649046080453054, 34.85027422223772, 34.17154291697911, 35.20187738963536, 34.22336605616978, 34.43861777441842, 35.355404785701204, 34.56900766917637, 35.29244368416922, 35.34168904168265, 34.79774931498936, 35.284189224243164, 35.72658450262887, 35.68450968606131, 36.34365054539272, 35.944222927093506, 37.312236377171104, 39.0404166494097, 42.857513768332346, 45.43111263002668, 46.25611393792288, 46.799800055367605, 49.081261907305034, 47.798019954136436, 53.00285298483712, 51.00524588993618, 50.57757384436471, 52.3728563444955, 46.31591360909598, 44.27161809376308, 52.17866809027535, 55.179000990731375, 42.19668449674334, 0.12575938180088997, 1.501655101776123, 6.467274248600006, 0.45368455403617447, 2.60390972665378, 54.01440300260271, 55.30821663992745, 50.472579615456716, 47.18847533634731, 38.30794102805001, 21.42491626739502, 35.797390120370046, 53.19692311968122, 35.9955666405814, 0.4612161027533667, 0.04233817297167011, 0.019553611653723886, 0.022699618911636726, 0.013768752870549048, 0.04725695474605475, 0.032981073284255605, 0.03641729675499456, 0.0615877059421369, 0.16243441669004305, 0.11699834120060716, 0.10476704859840018, 0.1581190696784428, 0.17588357787047113, 0.2199316014136587, 0.12526610041303293, 0.16627796473247664, 0.07294737960078887, 0.05752803771091359, 0.13352745425488266, 0.1186481990984508, 18.479086773736135, 66.36772687094552, 52.392717770167756, 44.50551182883126, 28.152907337461198, 45.66091735022408, 55.868033000401084, 62.79136398860386, 54.12627942221505, 61.37015165601458, 35.426939964294434, 0.2767908546541418, 1.9839391197477068, 2.074378175394876, 0.6660983945642198, 21.721190929412842, 61.61948081425258, 50.37588153566633, 52.008857590811594, 45.20630366461617, 51.286946705409456, 50.940089157649446, 52.41530983788626, 48.7726229258946, 50.125291279384065, 49.305212770189556, 49.352665492466514, 44.473515374319895, 39.3005085672651, 37.06024258477347, 36.98376028878348, 33.8704948425293, 36.18410948344639, 35.05872712816511, 38.067463874816895, 37.340442589351106, 36.446883405957905, 38.37598473685128, 38.243399211338584, 41.06983259746006, 42.4136871610369, 41.61891399111067, 40.75015640258789, 40.62312943594796, 40.609639508383616, 37.04727724620274, 36.67724050794329, 36.87502792903355, 35.68453400475638, 38.98748527254377, 37.26296670096261, 39.14525801794869, 39.904192379542756, 35.957264695848735, 38.45587165015084, 40.377517563956125, 39.23658514022827, 39.32631417683193, 36.872939995356965, 39.989002091544016, 40.67096430914742, 39.853383677346365, 41.02706643513271, 39.982269287109375, 39.93471581595284, 37.74853808539254, 39.89586843763079, 37.812951360430034, 34.568528243473594, 35.582923548562185, 36.08917277199881, 39.42310605730329, 40.7057991027832, 39.13484614236014, 39.80418348312378, 41.317751271384104, 40.803070408957346, 37.048114504132954, 39.92855623790196, 39.597328662872314, 38.53994137900216, 37.552421706063406, 37.965314933231895, 37.6574888910566, 35.373105321611675, 37.35686813082014, 35.5295718056815, 39.042667865753174, 36.89727258682251, 39.66352762494768, 39.39326701845442, 39.477343695504324, 40.789667333875386, 38.47460399355207, 39.81940351213728, 41.28361129760742, 37.84886659894671, 38.00674704142979, 38.300110408238, 37.18369122913906, 36.86886487688337, 36.01519530160086, 37.39470107214791, 36.66042934145246, 36.16662086759295, 38.11177601133074, 36.70545366832188, 39.20019047600882, 38.05196591785976, 37.606916427612305, 35.546007769448416, 37.585839067186626, 35.760738372802734, 35.77757038388933, 39.2790664264134, 37.14789410999843, 37.495568071092876, 37.0560701915196, 35.76561253411429, 36.74142449242728, 37.13413667678833, 37.76766995021275, 37.76307371684483, 37.234333174569265, 39.85207741601126, 39.488450390951975, 45.14290482657296, 47.877649784088135, 47.733644894191194, 48.94913148880005, 52.761764390128, 49.54998738425118, 55.941711698259624, 52.206137793404714, 52.360533714294434, 53.430306162152974, 50.472534452165874, 46.071621894836426, 55.653705392565044, 55.64873048237392, 45.56353139877319, 0.24155830379043305, 3.12072976572173, 26.83292852129255, 0.6651627219149044, 3.1109727578503743, 59.86571380070278, 59.65250137874058, 57.55914115905762, 55.17168453761509, 48.22360406603132, 33.736429350716726, 40.74152326583862, 62.402077266148154, 43.87404564448765, 1.2762956001928873, 0.15779147297143936, 0.1817717690552984, 0.12446150715862002, 0.19577643328479358, 0.17713292368820735, 0.12141617414142404, 0.12700623060975755, 0.12807729813669408], [0.04211114193978054, 0.01899484315487955, 0.03448098512100322, 0.132705476933292, 0.05986755181636129, 0.05829411053231784, 0.06486147455871105, 0.03735788878319519, 0.12159750583980765, 0.03177470248192549, 0.052569660025515726, 0.009269641612523367, 7.236194040094103, 49.74804925918579, 42.62544393539429, 32.472326210566926, 28.808251006262644, 29.4942136492048, 46.96203007016863, 50.53882721492222, 47.90022448131016, 47.18577596119472, 40.92821441377912, 1.0266776574509484, 0.25015675382954733, 0.39561064168810844, 0.10011529070990426, 8.886564476149422, 49.6307567187718, 51.70811523709978, 46.453321184430806, 44.418093068259104, 46.40700101852417, 52.20482805797032, 47.800257274082725, 42.287424496241975, 48.34613902228219, 47.57143919808524, 43.699989795684814, 38.61168152945382, 34.210438932691304, 32.253256457192556, 32.225908347538535, 33.57739550726754, 33.02256447928292, 33.857991559164866, 34.206374236515586, 35.09717845916748, 35.80324050358364, 39.51405102866036, 39.89610815048218, 41.621234689440044, 41.148451464516775, 41.76639992850167, 40.211646693093435, 40.45110593523298, 37.841258321489605, 35.287267276218955, 33.39820841380528, 33.40794284003121, 32.815153803144185, 31.82552535193307, 32.48039306913103, 32.89339051927839, 34.36519615990775, 31.538536957332067, 34.54119750431606, 34.878970282418386, 35.08564444950649, 34.638784953526084, 34.79643610545567, 38.433616570064, 36.036748613630024, 36.80745669773647, 38.4608986718314, 36.78744241169521, 36.47607626233782, 34.451051575796946, 35.3047593661717, 33.20217541285923, 35.24313579286848, 32.00094652175903, 32.76943465641567, 33.87488957813808, 37.59229394367763, 34.17605924606323, 36.78504875728062, 36.83473879950387, 38.24870763506208, 36.70913273947579, 36.198401927948, 37.613148961748394, 35.011368206569124, 33.971841267177034, 32.97948217391968, 32.51626661845616, 32.237192222050254, 33.88677099772862, 34.26002475193569, 33.2160370690482, 32.874331610543386, 34.419423375810894, 35.084869725363596, 36.21042231151036, 36.61937938417707, 34.46289825439453, 37.42450189590454, 35.169814927237375, 32.074284757886616, 34.22792060034615, 33.747574261256624, 35.41802542550223, 32.95361055646624, 32.6299843106951, 33.047352177756174, 33.2712960924421, 34.6438432421003, 33.1571615082877, 33.65341922215053, 32.438453742435996, 33.16890743800572, 32.30315841947283, 33.92928007670811, 33.40467718669346, 33.37671763556344, 32.03069870812552, 32.831197193690706, 33.76515320369175, 33.521740436553955, 32.1735189301627, 33.888219697134836, 32.58093350274222, 33.79341152736119, 34.6313225882394, 35.435051986149375, 34.05025168827602, 34.06654173987252, 33.0183538709368, 35.76534502846854, 37.688088757651194, 39.19792536326817, 42.90948281969343, 44.91311400277274, 46.63088934762137, 48.52765028817313, 50.888981682913645, 49.310055664607454, 51.42782143184117, 48.84466879708426, 50.47421244212559, 46.087845938546316, 59.006409236363, 21.62319701058524, 0.09935302446995463, 0.8097676538995334, 0.979273355432919, 0.07806976937821933, 2.4113823090280806, 56.06903396333967, 45.988260882241384, 56.99697978155953, 41.647707326071604, 34.396348408290315, 31.783554758344376, 36.64711659295218, 48.34609385899135, 18.599417413984025, 0.06211196245359523, 0.09047131320195538, 0.03551496731649552, 0.011291251883709004, 0.054559138270893266, 0.042529262003621886, 0.03400942024641803, 0.026842735075790967, 0.007789505678894264, 0.0324347677773663, 0.04010111765403833, 0.032594254040824513, 0.06478894595056772, 0.03505804183493767, 0.02067193405569664, 0.055951129112924845, 0.038894974160939455, 0.011697524726124746, 0.02225373828384493, 0.026321784726211002, 0.020581420876884034, 9.392579197883606, 58.65733173915318, 46.66196516581944, 36.60679619652884, 26.831917558397564, 38.88657658440726, 49.46118940625872, 55.11461203438895, 53.22413226536342, 52.05188431058611, 43.13883590698242, 1.067046474133219, 0.9038193385515894, 0.8634191464100565, 0.07012413788054671, 9.61618091378893, 52.10385683604649, 52.84303399494716, 49.03181505203247, 46.12168713978359, 47.86141184398106, 50.68248816898891, 49.60734823771885, 43.92442355837141, 50.383319582257954, 48.35207278387887, 46.20617723464966, 40.26492200578962, 35.098449979509624, 34.074188232421875, 34.67185837881905, 34.40084736687796, 33.63516630445208, 34.89220660073416, 34.56298705509731, 35.28640569959368, 39.298868792397634, 40.95560073852539, 42.78341817855835, 42.626197814941406, 42.95948205675398, 42.821153845105854, 41.73945481436593, 41.4521016393389, 38.83294691358294, 37.908694062914165, 35.8777425629752, 35.55505779811314, 33.80244418552944, 34.47697877883911, 35.68288728169033, 35.646721908024375, 35.050635950905935, 34.20211499077933, 36.88479709625244, 36.36043044498989, 35.569642066955566, 35.93188292639596, 36.26705707822527, 40.1214417048863, 38.703286579677034, 37.25643539428711, 39.65258073806763, 39.51596873147147, 36.47731304168701, 35.93669802801949, 37.0328562600272, 35.12602390561785, 35.461302280426025, 33.7889403615679, 34.86586945397513, 36.520405769348145, 38.63524981907436, 37.292430537087576, 37.783581324986045, 36.81221968787057, 39.653025422777446, 39.511337757110596, 37.66176550728934, 39.132786001477925, 39.0481812613351, 34.91467707497733, 34.694697107587544, 34.80705295290266, 33.91413995197841, 35.898343971797395, 35.320094040461946, 35.87509877341134, 34.89823416301182, 35.64304631096976, 37.93521186283657, 37.74775641305106, 39.03192247663225, 35.34860944747925, 39.008840560913086, 37.07311412266323, 34.69231734957014, 36.17627191543579, 37.14838743209839, 36.644455432891846, 33.70416191646031, 34.00441094807216, 34.62306465421404, 33.80014780589512, 35.737600871494834, 34.85264703205654, 35.156846114567344, 35.402218273707796, 33.85901294435774, 35.137286935533794, 35.36431932449341, 34.45952490397862, 34.446469238826204, 34.38326147624424, 34.551036153520855, 35.59906421388899, 34.934493337358745, 34.16681466783796, 35.915349687848774, 34.55526760646275, 36.182956082480295, 35.88014663968767, 36.53332941872733, 35.43563216073172, 36.416707379477366, 34.64080687931606, 37.92141621453421, 39.091350419180735, 43.28340360096523, 45.47957978929792, 46.67701843806675, 47.91376999446324, 50.28425564084734, 51.76956510543823, 51.664598669324604, 53.31518840789795, 50.889950956617085, 49.94504805973598, 49.19743578774588, 59.19321155548096, 24.881704126085552, 0.12836393846997193, 5.150469890662602, 2.617114995207105, 0.39753892964550425, 3.2120822923524037, 58.54958602360317, 50.760849952697754, 60.807437896728516, 49.04349149976458, 39.86863497325352, 31.805761201041086, 39.276992389133994, 56.036992345537456, 24.125767912183488, 0.060759336820670536, 0.024923668409298574, 0.011895239652533616, 0.02963243850639888, 0.07022899189697844, 0.05133319280243345, 0.1377698044691767, 0.027465986453795006, 0.030618380422570875, 0.14088057540357113, 0.13702961775873387, 0.11344091101948704, 0.17450516112148762, 0.18869957088359765, 0.23339297622442245, 0.15648811576621874, 0.12157333642244339, 0.1730757863926036, 0.07274244166910648, 0.10000549017318658, 0.18118984385260514, 10.531606946672712, 66.93121188027519, 54.296579769679475, 43.6288298198155, 37.92487989153181, 41.43432467324393, 54.976540906088694, 58.34177235194615, 58.14624309539795, 57.131743567330496, 49.20522124426705, 1.3893433340958186, 1.8997462775026048, 3.11606513602393, 0.26528651054416386, 11.91977972643716, 51.79680551801409, 55.618950503213064, 49.87618098940168, 48.778205803462434, 50.754162311553955, 53.40428863252912, 50.02694647652762, 46.21980612618582, 50.66199098314558, 51.73230191639492, 48.23836898803711, 42.42059019633702, 37.304298060280935, 37.4295289175851, 35.21529088701521, 36.62021664210728, 35.426717621939524, 37.33266060692923, 38.13028253827776, 38.260526520865305, 40.6998792375837, 45.40129096167428, 45.53795855385916, 44.595539637974326, 45.067878178187776, 46.24830068860735, 43.87773513793945, 44.864285537174766, 41.5230462210519, 39.728340421404155, 37.141988141196116, 38.40589325768607, 36.18113565444946, 36.47136538369315, 37.13447366441999, 37.34270770209176, 37.371021611349924, 35.45666088376726, 37.93454483577183, 38.75938980919974, 36.96060194287981, 38.160573210035054, 38.22092873709542, 42.571230615888325, 40.72479895183018, 39.328068596976145, 40.47782175881522, 40.225563934871126, 39.01350975036621, 37.25697387967791, 39.17583009174892, 36.80234282357352, 38.01885775157383, 35.797869546072825, 36.493057659694124, 38.16410289491926, 41.76989139829363, 39.547659465244834, 40.53966767447335, 40.02085958208357, 41.189209597451345, 42.298718793051584, 40.537677015577046, 42.61147458212716, 42.34267309733799, 37.393710953848704, 37.049177578517366, 37.629751682281494, 35.79367978232247, 38.20952674320766, 37.54195771898542, 37.98949466432844, 37.37000022615705, 37.610904693603516, 40.28927196775164, 39.30359009334019, 40.56032119478498, 37.583497524261475, 40.584511348179404, 39.46977710723877, 35.715436117989675, 38.68830278941563, 38.34855672291347, 38.32745156969343, 34.91793230601719, 35.081531115940635, 35.72767536980765, 35.69446645464216, 39.22735793249947, 37.034805229731965, 38.27354049682617, 35.81323201315743, 35.024559361594065, 37.03707381657192, 37.853949206215994, 36.98549386433193, 36.676990372794016, 36.181538649967735, 36.531005246298655, 37.98252214704241, 37.25916256223406, 35.54330144609724, 38.18956456865583, 36.64486190250942, 37.263463497161865, 37.54890939167568, 38.866920130593435, 37.48488174165998, 37.772606645311626, 36.93819052832467, 39.641790185655864, 41.5107479095459, 44.228118896484375, 48.846913065229145, 48.615826402391704, 49.695083141326904, 53.66289363588606, 54.833567823682515, 52.6799875668117, 55.02234690529959, 53.50643062591553, 54.041143144880024, 51.30061033793858, 61.45034081595284, 26.3694680418287, 0.19278287248952047, 6.018629934106555, 6.999690387930189, 0.6304152693067278, 3.5944987663200925, 67.29843807220459, 55.77301638466971, 66.90470450265067, 52.94074303763253, 46.843000480106895, 42.26177522114345, 49.49216447557722, 62.22901848384312, 32.64579841068813, 0.25620912334748674, 0.20373031576829298, 0.11303510636623416, 0.12346847115882806, 0.12091127623404775, 0.14406145257609232, 0.22141171699123724, 0.16276681742497853, 0.13944009984178202], [0.028364709478669932, 0.04203742589535458, 0.033081459147589545, 0.022762447861688476, 0.02760307936530028, 0.04902791078867657, 0.014650251283975584, 0.05949823199106114, 0.05146206695852535, 0.015250663173251917, 0.04071934108755418, 0.034147960133850574, 2.4605056388037543, 39.304691382816856, 48.36220325742449, 29.14295789173671, 25.08087944984436, 29.38808686392648, 47.29351472854614, 48.73779855455671, 50.63954135349819, 47.78368582044329, 44.90986224583217, 2.771834875856127, 0.2373548336327076, 0.3678559809923172, 0.13949339198214666, 1.2780981148992265, 32.75350591114589, 50.736385345458984, 47.332740783691406, 51.49714013508388, 48.69288887296404, 48.363964625767295, 45.02385439191546, 50.199425084250315, 48.66342156273978, 46.630541937691824, 43.334462438310894, 34.531383173806326, 32.60259798594883, 32.39431183678763, 32.062267848423545, 33.005232197897776, 33.393164021628245, 35.09326662336077, 36.97356728145054, 40.796198640550884, 42.949428013392854, 44.258149010794504, 43.30630138942173, 42.461494241442, 42.83995567049299, 42.815709931509836, 42.64545127323696, 42.162485463278635, 40.75238677433559, 38.51306922095162, 35.94173894609724, 34.39730378559658, 34.03570910862514, 32.93921736308506, 32.79800912312099, 32.86526768548148, 34.14220067432949, 33.89713076182774, 34.39795344216483, 34.42355407987322, 34.50720691680908, 34.729674339294434, 34.668346064431326, 37.32832145690918, 37.811023235321045, 36.16792018072945, 38.469458852495464, 37.31903518949236, 38.251031807490754, 37.54174927302769, 36.12112406321934, 34.9842598097665, 34.8771151133946, 32.346873010907856, 32.69149671282087, 34.043213163103374, 36.89063010896955, 38.996559619903564, 38.14072915485927, 37.7438827923366, 41.138282775878906, 39.13703482491629, 35.40085642678397, 37.71753174918038, 35.38290922982352, 36.222546918051584, 33.05619376046317, 33.76900250571114, 32.6245299748012, 32.730114800589426, 32.444557734898154, 33.316938808986116, 34.56189618791853, 35.00405870165144, 36.70773615155901, 37.46869938714163, 34.70260763168335, 35.05716378348214, 37.17424167905535, 37.1789664540972, 33.54700756072998, 34.015962328229634, 34.7717422076634, 34.61802026203701, 33.21033954620361, 31.700162478855678, 33.44550827571324, 34.54855217252459, 34.0869277545384, 35.45104673930577, 33.93753801073347, 33.707771505628315, 34.55498620441982, 33.007785660879954, 33.17357662745884, 35.54706736973354, 34.629741873059956, 34.63832637241909, 33.377857140132356, 33.81571871893746, 34.46516336713518, 34.330663612910676, 33.54941858564104, 33.76578548976353, 33.336008140019004, 32.23019538606916, 32.834542751312256, 32.23526757104056, 33.33029672077724, 34.43975380488804, 34.709111145564485, 34.96150098528181, 34.36481400898525, 37.142894881112234, 39.35610110419137, 43.20430530820574, 45.992089339665, 49.26191507066999, 50.45075184958321, 51.98998280933925, 48.192184312003, 52.94388362339565, 48.22293356486729, 53.86585051672799, 5.8830210736819675, 0.16556016967764922, 2.6902790921075, 1.7429662559713637, 0.22157326260847704, 3.9603094799177985, 54.39037697655814, 49.69157430103847, 48.40447609765189, 35.17452927998134, 19.66452588353838, 28.169365882873535, 40.74701929092407, 44.20065614155361, 13.400890742029462, 0.12358980679086276, 0.06321842236710445, 0.10733898808913571, 0.04582796338945627, 0.022200843086466193, 0.01487799986664738, 0.038170634635857174, 0.0536142477233495, 0.07769563195428678, 0.053984911047986577, 0.0281641396161701, 0.0408175284974277, 0.021256707409130673, 0.03320035544623222, 0.015027859414528524, 0.06162096094340086, 0.0522899407494281, 0.007094124332070351, 0.0160850475076586, 0.09003771575433867, 0.08223938742386443, 3.7988737310682024, 46.978455611637656, 52.51221636363438, 37.15548154285976, 29.633914130074636, 34.94350515093122, 52.37841142926897, 52.99256270272391, 54.452521664755686, 52.43732867922102, 49.83100380216326, 2.9482639687401906, 0.5541126493896756, 0.9207313082047871, 1.0194244980812073, 2.3445256565298354, 35.18289838518415, 54.61272975376674, 49.36627353940691, 52.724087783268516, 50.77988454273769, 50.28550284249442, 46.15519482748849, 51.61475229263306, 50.707473891122, 48.04296132496425, 44.85894932065691, 36.083562101636616, 34.15151820863996, 34.24135841642107, 33.80950355529785, 34.54227794919695, 34.99747180938721, 35.509279591696604, 38.43353319168091, 40.912334305899485, 44.39731100627354, 45.25987774985177, 45.97065762111119, 43.78989948545183, 45.150860513959614, 43.89308718272618, 43.72829328264509, 44.56032269341605, 43.00518383298601, 40.63174867630005, 37.65110697065081, 36.285386426108225, 35.4243517603193, 35.60541486740112, 35.78845821108137, 34.0189083644322, 35.86178602491106, 34.51632642745972, 34.57824182510376, 35.22749539784023, 36.18742030007498, 36.99782344273159, 35.30328982216971, 38.500277587345664, 39.55612931932722, 37.55138989857265, 39.06021901539394, 38.46667262486049, 39.16970872879028, 36.79692322867257, 37.036959171295166, 36.089054652622764, 35.0163813318525, 33.672766481127056, 34.184987681252615, 36.75899648666382, 37.852090563092915, 39.75606025968279, 40.13630737577166, 40.608385358537944, 40.69975069590977, 39.902083601270405, 38.645012038094656, 40.47859648295811, 37.545518670763286, 36.10910020555769, 34.993799686431885, 35.63953399658203, 33.66638108662197, 34.73822757175991, 34.6552973474775, 35.891843932015554, 34.84338855743408, 36.93473032542637, 37.33569349561419, 38.60935040882656, 37.33570739201137, 37.79725885391235, 38.132231507982524, 39.03839124952044, 34.42390843800136, 36.06736585072109, 36.297931398664204, 35.66064262390137, 34.5939655985151, 33.08423668997628, 35.60079778943743, 35.644859790802, 34.641651085444856, 35.80055502482823, 35.527494294302805, 36.3509635244097, 35.47908272062029, 35.76023810250418, 34.94625316347395, 36.17047364371163, 36.81109407969883, 37.0257100377764, 35.59030600956508, 35.258807454790386, 35.57990803037371, 36.686464241572786, 34.10141822269985, 34.669092995779856, 35.065984521593364, 34.97486237117222, 35.86455488204956, 34.51619093758719, 34.87072624479021, 36.73708881650652, 35.95067432948521, 36.78694561549595, 37.38830525534493, 39.60218892778669, 41.31887340545654, 46.14368513652256, 48.291102341243196, 51.89188119343349, 51.768092087336946, 55.03918239048549, 50.9385153906686, 57.91296080180577, 51.73503950663975, 57.714443819863455, 7.577293702534266, 0.11335845544402089, 5.400508633681706, 1.1555463309798921, 0.16897845268249512, 3.9044164334024702, 60.14879035949707, 54.82356589181082, 53.9061153275626, 39.876889433179585, 29.395486695425852, 33.88703155517578, 47.1519729750497, 49.81700665610177, 18.6275280884334, 0.07620364201388188, 0.1448244380631617, 0.09812695918870823, 0.03378308471292257, 0.06381306331604719, 0.03400083338575704, 0.03314193018845149, 0.030289786269090006, 0.032961660397372076, 0.17257995371307644, 0.1333295798727444, 0.15484102629125118, 0.08225493944649186, 0.12875284760126046, 0.13438770095152514, 0.17509818715708597, 0.1860984611724104, 0.12147593950586659, 0.07967622139092002, 0.2133146771895034, 0.12730175975177968, 3.975896894931793, 53.478755950927734, 60.77644198281424, 42.80061149597168, 34.51336996895926, 39.56997013092041, 57.78769520350865, 58.42522716522217, 60.073548316955566, 55.73949132646833, 53.59946700504848, 4.026405521801539, 1.04000104538032, 2.7256556281021664, 0.9402410898889814, 2.167016987289701, 37.258582387651714, 54.9942101751055, 51.649753843035015, 54.98507329395839, 52.176726068769185, 50.584285804203574, 49.48519195829119, 53.35260098321097, 52.46645205361502, 50.42362608228411, 46.022946289607454, 38.239893845149446, 36.31793178830828, 36.37155103683472, 35.031024660382954, 35.852336474827354, 37.046603270939414, 39.22635391780308, 40.89545713152204, 43.17677654538836, 47.56721469334194, 47.85618332454136, 47.55900192260742, 45.85029397691999, 46.58418355669294, 46.64319460732596, 45.630084718976704, 47.517517702920095, 45.178833961486816, 43.01270873206002, 39.562351431165425, 38.39841004780361, 36.44927358627319, 37.72422286442348, 37.9768454687936, 35.75091709409441, 39.19782114028931, 38.39015906197684, 36.86305618286133, 36.59396982192993, 37.83114174434117, 38.70517996379307, 37.8317358153207, 38.68460634776524, 41.62986435209002, 38.76454189845494, 40.870606899261475, 40.321692262377056, 41.14905595779419, 39.89150149481637, 39.75994430269514, 38.54178612572806, 36.54243155888149, 34.030393736703054, 35.89622477122715, 38.56505911690848, 39.921486445835654, 42.85666608810425, 42.82983214514596, 40.96541506903512, 44.02343191419329, 40.869835649217876, 39.59599460874285, 41.74792119434902, 40.30075734002249, 39.81978218896048, 37.907141140529085, 38.364447253090994, 37.19048309326172, 37.24734020233154, 36.64998967306954, 36.688607760838096, 38.09485714776175, 39.297729287828716, 40.392977305821006, 41.03047105244228, 36.662385259355815, 39.13703482491629, 41.23561314174107, 41.30079419272286, 37.5093081338065, 37.07265901565552, 38.48056207384382, 37.72477177211216, 36.61398410797119, 34.726210662296836, 37.04433815819876, 37.40602663585118, 36.60573312214443, 38.6459014075143, 37.28508281707764, 37.37565605981009, 37.20128059387207, 37.53311613627842, 36.1702686718532, 41.39077683857509, 37.76730169568743, 39.231700556618826, 37.81064803259713, 38.49298545292446, 38.2033428464617, 38.335671288626536, 36.181976386478965, 35.90428120749337, 37.4854862349374, 36.0405319077628, 36.33372156960623, 35.56382295063564, 37.49698550360543, 37.28852564947945, 37.69254602704729, 38.7293701171875, 37.65489026478359, 41.91889204297747, 43.36201204572405, 48.55889981133597, 49.60850511278425, 53.38711963381086, 54.222584928785054, 53.98151370457241, 51.858741760253906, 59.93240261077881, 51.34414775030953, 58.4154441016061, 8.071830000196185, 0.17482437113566057, 9.116411754063197, 8.622574618884496, 0.3665260523557663, 4.126806991440909, 66.17715167999268, 58.93667711530413, 58.741495268685476, 45.38448674338204, 31.40394687652588, 37.632923534938264, 52.930011544908794, 58.08045755113874, 26.29373962538583, 0.23201318883470126, 0.32749698949711664, 0.1425100908215557, 0.11068385360496384, 0.15254582730787142, 0.09961361584386655, 0.10655274242162704, 0.13964000982897623, 0.17059160183582986], [0.015787455619179776, 0.0754497285400118, 0.05625968951998012, 0.01832797554587679, 0.02902372134849429, 0.036407569955502234, 0.10769170416252953, 0.05462897988036275, 0.03464529237576893, 0.05696644141737904, 0.07414050879223005, 0.08021977543830872, 0.7916363839592252, 31.13872718811035, 49.14913885934012, 31.366412707737513, 26.272782121385845, 22.195278678621563, 46.15960693359375, 50.176760060446604, 51.49954421179635, 45.59185573032924, 50.48038591657366, 5.567320551191058, 0.37473407334515024, 0.22837873814361437, 0.5325475037097931, 0.24952454918197223, 6.001498281955719, 44.7675735609872, 51.38246011734009, 51.821763447352815, 45.90557731900896, 48.951271533966064, 49.40286275318691, 49.48783227375576, 44.79947621481759, 45.67610263824463, 35.87489380155291, 33.63568047114781, 33.76746000562395, 31.55774872643607, 31.736362593514578, 33.56221716744559, 34.121668747493196, 37.834657532828196, 40.0870099067688, 43.15617861066546, 43.7608699117388, 44.66958311625889, 45.32402351924351, 44.97652326311384, 45.02174908774239, 44.60372461591448, 44.51795605250767, 42.96298394884382, 41.88488061087472, 41.52774667739868, 38.92850201470511, 35.75470386232649, 32.230240549360005, 32.75530896868025, 33.23444284711565, 33.321920667375835, 34.76015261241368, 33.49077926363264, 34.85109410967146, 34.42995684487479, 35.309237480163574, 34.56318507875715, 33.204148701259065, 36.16125338418143, 37.61760623114449, 36.93726641791207, 37.79996517726353, 37.13743012292044, 35.91020802089146, 35.55786139624459, 35.3169777733939, 33.608752727508545, 34.00916004180908, 32.64463806152344, 33.75700644084385, 33.73584917613438, 38.76269367762974, 38.873590401240754, 38.50380727222988, 38.02214772360665, 38.98452533994402, 42.53717054639544, 37.7078355380467, 36.730581828526084, 36.15209565843855, 35.159284932272776, 34.16300705501011, 32.83707536969866, 32.54233973366873, 33.208599022456575, 32.96333108629499, 33.609499658857075, 34.385578700474326, 36.07235813140869, 35.547515528542654, 36.90312991823469, 34.8573613848005, 36.589050497327534, 35.52746302740914, 37.64510025296892, 32.866045883723665, 32.93486779076712, 34.24667031424386, 34.326195921216694, 32.67687770298549, 32.97182525907244, 31.99629122870309, 33.35463626044137, 34.75554595674787, 34.43026256561279, 33.512985706329346, 32.80674300874983, 33.59994241169521, 33.26838479723249, 33.87886394773211, 33.56509024756295, 33.1465550831386, 33.22398580823626, 34.17084462302071, 33.35060283115932, 34.42691700799124, 33.24635205950056, 33.35482038770403, 33.134896005902974, 34.155985900333945, 33.61404030663626, 33.732441084725515, 32.24165643964495, 32.69932038443429, 32.33447047642299, 33.72685125895909, 35.84436689104353, 35.40417071751186, 35.57004158837454, 35.87550176892962, 40.52570874350411, 45.329516070229666, 47.038713863917756, 49.06187295913696, 51.94445473807198, 51.83582660130092, 52.82205738340105, 54.624694551740376, 36.09765304837908, 0.47610772081783836, 0.1773726772516966, 2.2112088331154416, 0.873969877404826, 0.3086051903665066, 4.713554569653102, 53.24241297585623, 49.494912488119944, 53.24050569534302, 37.863245895930696, 18.452607188905986, 26.235814230782644, 42.13191686357771, 44.43895156042916, 7.744912913867405, 0.2455628274806908, 0.03625850938260555, 0.06489477705742631, 0.025345934322103858, 0.048114707826503685, 0.06089904039566006, 0.06342236285230943, 0.004474516484021608, 0.0110816939767184, 0.016578261042013764, 0.05645907364253487, 0.05969795198845012, 0.03293876662584288, 0.08363739347883634, 0.0704441349953413, 0.058015680472765646, 0.03231290628069213, 0.03138377131628139, 0.08180619031190872, 0.07953391224145889, 0.026861116589446152, 1.1181017288139887, 37.85241365432739, 55.976452691214426, 36.061171531677246, 26.98918308530535, 28.962111915860856, 53.01028755732945, 53.5427245412554, 56.42923205239432, 49.34875365665981, 55.194617067064556, 5.934098150048937, 0.9009369760751724, 1.18443064391613, 1.8138985697712218, 0.17132398539355823, 7.737414070538112, 48.08002996444702, 51.53035947254726, 54.0640652520316, 48.518652370997835, 50.88866206577846, 51.99481528145926, 50.704211711883545, 47.78984539849417, 46.99572535923549, 38.22477803911482, 33.68006903784615, 35.528692858559744, 33.23674270084926, 33.54083408628191, 34.126779147556846, 35.86214733123779, 38.85869346346174, 41.877369608197895, 44.987855775015696, 45.24248988287789, 46.475760391780305, 45.147129331316265, 46.18552371433803, 45.504294531685964, 46.41609968457903, 46.923203536442344, 45.080697604588096, 45.021280084337505, 41.667721612112864, 41.11928292683193, 37.103748730250764, 34.56361239297049, 34.91077218736921, 35.040842464991975, 36.008955819266184, 35.770274775368826, 35.70801196779524, 35.70395074571882, 37.5133033479963, 38.275114263807026, 35.703207288469585, 35.798522676740376, 38.7452780178615, 41.06473956789289, 38.14734731401716, 39.659046036856516, 39.1333453314645, 39.26041398729597, 37.60137176513672, 36.973998069763184, 35.217910357883994, 35.92023079735892, 34.3292670249939, 35.088965688432964, 36.393312794821604, 41.30407721655709, 39.355319431849885, 40.698305470602854, 40.4961302621024, 41.18910884857178, 43.24480635779244, 41.19649478367397, 38.75548492159162, 38.3447664805821, 36.78017112186977, 35.01276479448591, 34.54513365881783, 34.124868392944336, 34.42727484021868, 34.68097788946969, 36.448724678584504, 35.125179699489046, 36.29706982203892, 37.21206419808524, 37.194999422345845, 36.78164413997105, 37.794420514787944, 38.91327851159232, 39.63267067500523, 36.472299916403635, 34.34171124867031, 36.11853585924421, 34.785902636391775, 35.29552173614502, 34.96511057444981, 35.63506283078875, 34.68125581741333, 35.65118612561907, 35.62184388296944, 34.97203098024641, 35.225664547511506, 34.90028388159615, 34.704438482012065, 34.98105321611677, 35.753380230494905, 35.59178944996425, 34.60352979387556, 35.75906038284302, 34.46437474659511, 36.06137997763497, 35.77894960130964, 33.89687715257917, 35.88824129104614, 35.716721534729004, 34.67972721372332, 35.21793467657906, 33.959442206791465, 34.56782994951521, 34.16796112060547, 35.26211827141898, 36.38757358278547, 36.02043424333845, 38.11999225616455, 38.13713346208845, 43.00870656967163, 46.03188514709473, 48.381338596343994, 49.90907376153128, 54.62079313823155, 53.58297198159354, 54.52302156175886, 57.02418545314244, 38.395345892224995, 0.7078870864851134, 0.3461572453379631, 5.464988785130637, 2.388340779713222, 0.44217931425997187, 6.135699263640812, 57.908680711473735, 53.28803832190377, 57.18076310838972, 45.723666531699045, 25.423755679811748, 28.83105673108782, 46.42214809145246, 52.10760538918631, 11.606184073856898, 0.26463261991739273, 0.14949465888951505, 0.04542302047567708, 0.040028263349086046, 0.08750005585274526, 0.06080873417002814, 0.046070478590471406, 0.051988582991595776, 0.03882989925997598, 0.07325205539486238, 0.23945508950522967, 0.1405817757227591, 0.0769277678004333, 0.18565122517091887, 0.11895366199314594, 0.20357354703758443, 0.11727093585899898, 0.11424500894333635, 0.11380662103848797, 0.22528087294527463, 0.1502861428473677, 1.815119281411171, 43.1206351007734, 63.611633573259624, 43.736724921635215, 37.17311954498291, 31.101064477648052, 59.01235689435686, 57.40081603186471, 61.97241456168038, 55.816216809409006, 61.738746643066406, 7.783537949834551, 1.2373131662607193, 3.5444936667169844, 3.1744697391986847, 0.5346868431993893, 7.81976672581264, 50.20370864868164, 53.23465878622872, 54.03813804898943, 50.0364168712071, 53.66746555055891, 51.73898260934012, 53.56103651864188, 49.425531251089915, 48.76010922023228, 39.434115477970664, 37.59552138192313, 38.22357252665928, 34.96739305768694, 36.01125219890049, 36.10344089780535, 38.291251455034526, 41.32206610270909, 45.66087566103254, 47.265760149274556, 46.73540415082659, 49.06359263828823, 48.932945660182405, 48.41497482572283, 49.468415532793315, 48.77293906893049, 46.9264691897801, 46.550981589726035, 46.510438850947786, 45.070563656943186, 43.830744470868794, 39.78196661812918, 37.04611342293875, 37.67196198872158, 36.31201539720808, 37.70784248624529, 38.623590741838726, 37.5116149357387, 38.50699996948242, 38.68950482777187, 39.09543595995222, 37.68144975389753, 37.196020807538716, 40.10721179417202, 41.990072863442556, 40.37404693875994, 40.97500705718994, 39.41951731273106, 40.55920253481184, 38.78760644367763, 39.49839326313564, 36.504362378801616, 36.58625037329537, 35.244049480983186, 36.98815849849156, 36.7922887802124, 44.60045548847744, 41.33494111469814, 41.75970186505999, 41.33887726919991, 42.44060100827898, 45.30492639541626, 43.34255708966936, 40.71855252129691, 39.768799781799316, 39.214291845049175, 36.89129713603428, 36.30325371878487, 35.39147983278547, 35.438904762268066, 35.98393188204084, 37.616539682660786, 37.5257579939706, 40.82646499361311, 39.52636323656355, 38.93912581035069, 38.3037234715053, 40.08185086931501, 40.41024357931954, 41.697341782706125, 37.68320764814104, 36.05382381166731, 38.196999141148154, 36.87465967450823, 36.23572417667934, 35.26651995522635, 36.939038208552766, 37.3273035458156, 37.63219744818551, 36.906006472451345, 36.92573935644967, 35.9492951120649, 36.73069647380284, 37.452141829899375, 37.62976210457938, 38.41741337094988, 36.60038995742798, 35.55813932418823, 38.460422720227925, 37.122366428375244, 37.51795516695295, 36.73872511727469, 36.91046026774815, 37.07382978711809, 37.28417607716152, 36.13631282533918, 37.43808562414986, 35.94687019075666, 35.574940068381174, 36.330799852098735, 37.49111427579607, 40.462014607020784, 38.820214339665, 40.13760321480887, 39.90253176007952, 43.07788978304182, 48.43591322217669, 49.73773118427822, 50.261774744306294, 57.224019118717735, 53.1835686819894, 57.174877984183176, 56.043395110539024, 41.27579804829189, 1.1556655360119683, 0.35644527471491266, 10.729819076401846, 4.505455153329032, 0.7121960552675384, 7.084791490009852, 63.47187750680106, 57.06750052315848, 62.73057419913155, 48.52417966297695, 30.560095105852398, 36.988492012023926, 52.36030442374093, 62.43791607448033, 18.075769901275635, 0.33512771289263454, 0.37004200369119644, 0.3146704249083996, 0.13690331525036267, 0.20634281129709311, 0.2160387510167701, 0.17718403094581195, 0.31594425226960865, 0.11113298271915742], [0.03666775420840297, 0.033162985130080154, 0.12488131677465779, 0.005431261462425547, 0.052373380200671296, 0.04190133212666426, 0.0342175269366375, 0.05437289058629956, 0.06127380207180977, 0.026072299274216806, 0.033479779559586725, 0.030873808144990886, 0.3009092461849962, 22.120366675513132, 48.42701605388096, 34.881506374904085, 21.45497417449951, 24.521740538733347, 38.60660934448242, 49.55799518312727, 49.948841776166645, 43.576832975660054, 51.1668575150626, 16.942807061331614, 0.770586870610714, 0.3767200910619327, 2.144072949886322, 0.061692960294229646, 0.15562985039183072, 19.015673569270543, 51.33484411239624, 47.77515343257359, 52.585512910570415, 49.38189656393868, 46.93697139195034, 45.63010556357247, 43.20032051631382, 37.65580742699759, 33.554258005959646, 34.103839669908794, 33.86350842884609, 33.33760969979422, 33.56260626656668, 35.27650451660156, 37.55264057431902, 41.003685746874126, 42.44042035511562, 44.35347134726388, 42.78973756517683, 43.62812457765852, 43.69468137196132, 43.96181181498936, 44.16827058792114, 45.17529385430472, 44.80363123757498, 44.86537293025425, 44.45655482155936, 42.312507493155344, 42.38476875850132, 36.98032440458025, 32.93302651814052, 32.57731349127633, 34.72437286376953, 34.74603387287685, 33.47487483705793, 32.597008160182405, 33.14278221130371, 34.70680086953299, 35.70894997460501, 33.48405688149588, 34.81300408499581, 37.34664038249424, 35.80930628095354, 35.61444057737078, 35.27810607637678, 36.56468663896833, 35.690995829445974, 34.38415084566389, 34.60690661839077, 35.394467558179585, 34.3286486353193, 31.815321922302246, 32.59866530554635, 35.635333810533794, 38.878197056906565, 39.909139496939524, 40.67304529462542, 41.89030020577567, 38.305700234004426, 42.41078281402588, 39.68361834117344, 37.336676665714805, 37.474025181361604, 35.36118221282959, 34.18841661725725, 33.11441619055611, 32.652722290584016, 33.98231567655291, 33.355362347194124, 33.51338870184762, 33.0887564931597, 33.461343220302034, 35.57263674054827, 35.9486836705889, 36.422356264931814, 35.17184380122593, 35.97933217457363, 38.29376670292446, 33.354549407958984, 32.40126003537859, 34.46354443686349, 33.40630306516375, 33.90693467003958, 33.78488608769008, 33.301030908312114, 33.56440585000174, 33.05591583251953, 32.69675302505493, 33.63091400691441, 31.6465744972229, 33.420494760785786, 32.363628591809956, 33.73034272875105, 33.15460457120623, 37.10488476072039, 36.42073038646153, 36.88855954578945, 34.05814136777605, 33.28457062585013, 32.76093700953892, 33.181768553597585, 32.626583167484824, 33.420029231480186, 32.58925397055489, 34.20168767656599, 33.70784098761422, 34.643280438014436, 34.16302442550659, 32.77959639685494, 33.71353503635952, 33.313464709690635, 35.05358893530709, 34.087469714028494, 33.87320463997977, 41.87706388745989, 44.62232494354248, 47.23763384137835, 47.51420341219221, 53.50840391431536, 51.83029236112322, 52.297728947230745, 20.474816117967876, 0.08837931510061026, 0.5031285594616617, 3.541816873209817, 0.11474473641387054, 0.36408997593181475, 6.394129693508148, 52.988452843257356, 49.15496839795794, 51.42017493929182, 39.64759193147932, 20.301347391945974, 21.380204609462194, 40.09376702989851, 43.54744904381888, 6.116140518869672, 0.19256450634981903, 0.018157836282625794, 0.024694299824269753, 0.024927106885505573, 0.03226364463833826, 0.04113877072398152, 0.023855947756341526, 0.03339347329788974, 0.03621489993695702, 0.04094042136733021, 0.052309642013694556, 0.03479920447404895, 0.03491211948650224, 0.04490601071821792, 0.03455702175519296, 0.06212296150624752, 0.004019582502743495, 0.030883789395115206, 0.00873063799060349, 0.0171022631028401, 0.08569890500179358, 0.5034146298255239, 29.126754692622594, 55.39723348617554, 38.20731026785714, 23.118418080466135, 26.706275020326885, 49.10574041094099, 51.45125075748989, 55.30715356554304, 47.63946901048933, 57.813889912196565, 16.069248267582484, 0.5360886422651154, 1.5670684831483024, 2.551827549934387, 1.6633105874061584, 0.06721232019897018, 23.223176070622035, 51.778253827776226, 48.72785915647234, 52.96615259987967, 52.398154735565186, 47.965415954589844, 47.779308455330984, 44.23038748332432, 38.369397844587056, 35.15977825437273, 36.037624086652485, 33.749495438167024, 34.80085515975952, 35.885034697396414, 37.08014222553798, 38.84222970690046, 43.260391167231965, 43.83000796181815, 45.805061204092844, 44.890098094940186, 46.04077884129116, 46.0316732270377, 45.57019124712263, 46.39190605708531, 44.90119089399065, 47.636119978768484, 46.86289317267281, 46.978490352630615, 45.28799016135079, 43.39827816826956, 37.69586031777518, 34.78705951145717, 34.73947129930769, 35.889735153743196, 36.05140583855765, 35.322616236550466, 33.82613059452602, 33.93988650185721, 35.85934720720564, 36.1899459702628, 35.25085871560233, 35.50014965874808, 39.07728726523263, 37.60502651759556, 36.67137622833252, 37.176124640873496, 37.021402154650005, 38.17253800800869, 35.75306061335972, 37.13874680655343, 36.95091962814331, 34.45353903089251, 33.406848498753135, 35.08763510840279, 38.71921532494681, 41.34533214569092, 41.000281129564556, 41.75714840207781, 44.24193886348179, 40.823915004730225, 42.655480997903005, 41.00994259970528, 39.717303207942415, 41.160551752362935, 38.408154896327424, 35.336276394980295, 35.27234254564558, 33.47725459507534, 34.24391187940325, 34.68407678604126, 35.39762551443917, 35.81362458637783, 36.39237478801182, 37.43012298856463, 36.32450131007603, 38.2028807912554, 37.54042216709682, 39.68584523882185, 38.66777433667864, 35.94145059585571, 33.81807763235909, 36.438007082257954, 34.811301776341026, 35.11537231717791, 35.85124213354928, 35.9722832271031, 34.236216749463765, 34.7793539592198, 33.801652090890066, 34.06634371621268, 33.6256229536874, 33.8764841897147, 34.465052195957725, 35.32983888898577, 35.45196737561907, 38.097084045410156, 38.48671122959682, 38.06714425768171, 35.9360032081604, 34.696729455675396, 34.24149738039289, 34.521666118076865, 35.80530411856515, 34.72159358433315, 34.793750626700266, 36.34912919998169, 37.059123924800325, 35.83730057307652, 35.15913554600307, 34.95048461641584, 36.34515135628836, 36.543824672698975, 36.445476395743235, 35.84790352412632, 37.0255571774074, 43.73711749485561, 46.10342379978725, 49.93671716962542, 51.7771212714059, 55.275942257472444, 51.88713904789516, 50.9634941646031, 24.45414846284049, 0.09538515524140426, 2.5504841591630663, 4.883284296308245, 1.3277208464486259, 0.21197155783218996, 7.1241061346871515, 60.214367457798545, 54.08829014641898, 57.06055579866682, 44.73280824933733, 25.865414449146815, 24.82904199191502, 46.250009945460725, 51.393323625837056, 8.663324066570826, 0.1641611118933984, 0.08107896362032209, 0.0555480250290462, 0.012964966224639543, 0.05769464519939252, 0.03242240147665143, 0.026611195178702474, 0.046132262596594434, 0.09594930961195912, 0.12136809315000262, 0.19748155107455595, 0.1998063748968499, 0.1281771920621395, 0.10142490400799684, 0.09744134026446513, 0.1863505912146398, 0.16223476454615593, 0.10221418951238904, 0.19502180734915392, 0.06573492554681641, 0.19922158627637795, 0.6830528133681842, 33.223023482731406, 64.29511397225517, 44.988015583583284, 31.53373227800642, 35.44192375455584, 51.55310787473406, 57.98998853138515, 57.631426743098665, 51.20351273672921, 62.000964709690635, 21.850849526269094, 1.372694581747055, 3.2468400044100623, 5.810215677533831, 0.8986557413424764, 0.5532882564834186, 22.811048882348196, 52.039745807647705, 51.66596051624843, 55.87746517998831, 54.875618321555, 50.64420706885201, 48.79507950374058, 46.14046464647566, 40.159990310668945, 37.27306243351528, 38.139419419424875, 35.07407917295183, 36.60731383732387, 38.2960387638637, 38.96984379632132, 41.21486234664917, 44.62370763506208, 46.84410176958357, 47.78296668188912, 47.51390463965279, 48.80576235907418, 48.14175081253052, 47.46237679890224, 47.46515607833862, 47.195354052952354, 49.19632060187203, 49.64583778381348, 48.513997077941895, 46.419747488839285, 47.94914674758911, 40.02379519598824, 36.73525101797921, 36.22770595550537, 37.73557274682181, 39.451482500348774, 36.81702784129551, 35.31257608958653, 36.64973258972168, 38.370304584503174, 39.255220208849224, 37.22076334272112, 37.33447756086077, 41.284187998090474, 39.77107184273856, 37.61582054410662, 37.666264465876985, 38.65283918380737, 40.118492194584434, 36.29244926997593, 38.65046637398856, 38.81448554992676, 36.63939367021833, 36.04571873801095, 37.93527092252459, 41.37004688807896, 44.05085645403181, 43.47458675929478, 44.12291969571795, 45.454611437661306, 44.92215360913958, 45.835563795907156, 42.2894846371242, 42.90159314019339, 42.19914763314383, 39.96932826723371, 37.720769609723774, 38.07519721984863, 35.99488224302019, 37.533244677952354, 36.88294540132795, 38.78553935459682, 36.67845296859741, 36.82670668193272, 39.881416184561594, 38.564840248652864, 40.380654675619944, 39.055772168295725, 41.23262889044625, 42.047089781079976, 36.95757947649275, 35.98761095319475, 37.87462704522269, 35.41818870816912, 36.87633419036865, 37.71032994134085, 37.08104201725551, 37.25553560256958, 36.37833595275879, 34.362399509974885, 35.99935688291277, 35.2919225692749, 37.00933313369751, 35.763222353799, 37.93778964451381, 37.5491977419172, 41.026691232408794, 40.636452606746126, 39.45512335641043, 38.70721231188093, 37.08506849833897, 36.19579635347639, 35.182471070970806, 37.6052280153547, 37.62893179484776, 36.401080880846294, 38.019107886723106, 38.79504796436855, 37.77118573869978, 38.011673314230784, 36.851477009909495, 37.805895464760916, 37.246339661734446, 39.52337898526873, 37.49354267120361, 37.195041111537385, 45.48699699129377, 47.81987203870501, 50.95118195669991, 53.805522782461985, 58.738347734723774, 55.01060792378017, 50.36866235733032, 27.747867311750138, 0.12898751215210982, 2.01668923667499, 9.070690870285034, 3.108338087797165, 0.542894782764571, 8.193664056914193, 64.81656238010952, 59.478581019810264, 60.93709823063442, 50.9835536139352, 30.201898097991943, 30.884833063398087, 52.217675277165, 60.93538897378104, 11.812440480504717, 0.33784869260021616, 0.2301909423300198, 0.16461281265531266, 0.13902798481285572, 0.1848336040441479, 0.15298128394143923, 0.11359476204961538, 0.2667107826897076, 0.1143347926970039], [0.0666488782901849, 0.01947870647667774, 0.03592845977150968, 0.005601698432915977, 0.046942450372236114, 0.06186806982649224, 0.024049024895897934, 0.032983994377510886, 0.05435172029371772, 0.028438562926437174, 0.05146770219185522, 0.04606065001072628, 0.22282206559819834, 16.14720184462411, 48.09276948656355, 35.74771744864327, 23.876575980867656, 18.158020939145768, 29.237293584006174, 51.25567633765084, 49.02063192640032, 45.84673997334072, 48.83846058164324, 24.507428986685618, 0.3576567582786083, 0.9120068677834102, 0.9555885749203819, 0.7441554889082909, 0.14179336785205773, 8.226512534277779, 50.198507922036306, 51.5193361554827, 49.24465227127075, 45.459763526916504, 45.46484613418579, 40.14547552381243, 37.03330789293562, 32.876516819000244, 33.829434462956016, 32.60353251865932, 33.21078423091343, 32.27238137381417, 33.26471267427717, 36.994432721819194, 38.788242203848704, 39.49840715953282, 40.96883358274187, 42.98741381508963, 43.92013651984078, 43.514757769448416, 45.12344987051827, 44.29920939036778, 45.812297752925325, 44.94794879640852, 44.95247554779053, 44.4885755947658, 44.83840697152274, 45.675928933279856, 43.9945968900408, 39.17508316040039, 33.698200362069265, 33.43409238542829, 33.32915374210903, 33.983548981802805, 32.94110727310181, 32.60633611679077, 34.1340400150844, 32.780381543295725, 35.80784021105085, 36.153447083064485, 34.80053554262434, 35.7223356791905, 36.69303028924124, 35.52555227279663, 35.98643670763288, 36.206590379987446, 36.12733575275966, 35.98990385872977, 34.56705175127302, 36.04087584359305, 33.55356318610055, 32.467368670872276, 32.122543471200125, 37.407662936619346, 40.61819968904768, 42.46840769904, 40.43727902003697, 44.32953480311802, 40.05026435852051, 39.36244133540562, 41.944513525281636, 37.80884844916207, 39.18316044126238, 35.33643620354788, 35.68457569394793, 32.71826464789254, 33.63285602842058, 32.341700077056885, 33.25259849003383, 34.47162519182478, 35.89884076799665, 34.407420362745015, 36.122774260384695, 35.832297870091026, 34.71951607295445, 34.10166488374983, 35.81404495239258, 35.36056382315499, 35.97987413406372, 33.25587803976876, 34.83513062340872, 34.66772072655814, 34.32293026787894, 31.493957315172466, 32.98082317624773, 33.47026818139212, 33.18654544012887, 33.54578815187727, 33.66510261808123, 31.824684619903564, 31.8661618913923, 32.233405453818186, 35.03402280807495, 38.2486138343811, 41.066181319100515, 41.82388932364327, 42.15280662264143, 40.921165466308594, 36.89086634772164, 33.29715381349836, 33.23962620326451, 32.52287435531616, 35.65174545560564, 33.64842694146292, 36.53763730185372, 35.65536894117083, 37.14113351276943, 35.3625614302499, 36.41707910810198, 32.37355409349714, 33.47423907688686, 34.294150829315186, 34.29147924695696, 34.104002952575684, 36.639345032828196, 39.01301295416695, 44.60889754976545, 46.04867546898978, 49.860721247536794, 52.751477582114084, 52.47517204284668, 9.864479133061, 0.11674880316214901, 1.3507413140365054, 2.8663255998066495, 1.8144876467330115, 0.39929524968777386, 10.671591435159955, 55.0293367930821, 47.005115849631174, 49.87007352284023, 36.16056203842163, 21.25977669443403, 29.825378690447124, 43.35323647090367, 38.71027994155884, 2.68274615917887, 0.18583909794688225, 0.058588716866714616, 0.02411812181318445, 0.01957806266312088, 0.1647436749190092, 0.038067666946777275, 0.061455106628792625, 0.03436675714328885, 0.027821353902774196, 0.07042071196649756, 0.06422006897628307, 0.036740387989474196, 0.032651987192886214, 0.05186042129727347, 0.005306922888848931, 0.005452516147800322, 0.04009237812299814, 0.0665343144376363, 0.028898494318127632, 0.029114329522209506, 0.07602171320468187, 0.14324883903775895, 22.413676193782262, 55.463140623910085, 39.84085954938616, 24.730502639498027, 25.051759549549647, 40.89989703042166, 53.48632948739188, 56.375112533569336, 47.78583281380789, 54.92600665773664, 25.4790928704398, 0.29866419093949453, 0.8004262351563999, 0.9589359781571797, 2.798994298492159, 0.10216929085020508, 10.329772199903216, 50.44404683794294, 52.73708438873291, 50.29759618214199, 48.20651497159685, 46.459717001233784, 43.68780265535627, 39.259653159550254, 35.286617619650706, 35.081916740962434, 34.99395602090018, 32.600523948669434, 33.18566649300711, 34.70574474334717, 38.686902727399556, 41.33346462249756, 41.78000797544207, 42.96237598146711, 44.79421642848423, 45.16802256447928, 45.38493490219116, 46.13532992771694, 45.63434396471296, 46.56717784064156, 46.246271814618794, 46.9169362613133, 46.56306798117501, 45.579936095646445, 47.53048651559012, 45.11040462766375, 40.666635581425254, 36.02289737973894, 35.50164352144514, 34.858431407383506, 35.24498053959438, 35.529585702078684, 34.69950526101248, 36.01825598308018, 35.34471845626831, 37.71985592160906, 36.70112146650042, 36.767129353114534, 36.43249021257673, 38.34625686917986, 37.37090696607317, 37.42862565176827, 37.204928398132324, 37.699150289808, 37.432874475206646, 36.42102915900094, 35.93095881598336, 34.61835030147007, 33.97389793395996, 34.6907296861921, 40.588301590510774, 40.93240417752947, 42.79135649544852, 42.129443304879324, 44.07049206324986, 42.35063920702253, 40.39778198514666, 44.10628918239048, 39.170268058776855, 39.90054110118321, 38.27873774937221, 38.135028157915386, 34.0240604536874, 34.58782339096069, 34.295186110905235, 34.968306745801655, 34.90273312159947, 35.82981736319405, 36.12368100030081, 37.92005784170968, 38.23986257825579, 37.667945929935996, 36.08698408944266, 38.54611832754952, 37.75378744942801, 37.98142433166504, 34.97868388039725, 34.598388126918245, 36.54067366463797, 36.9317113331386, 33.788728441510884, 34.83248683384487, 35.078119550432476, 33.96261405944824, 34.50971869059971, 35.085939747946604, 34.165060247693745, 33.21973698479788, 33.97943564823696, 35.473822934286936, 40.449007579258506, 42.91650744846889, 42.482776573726106, 44.680279867989675, 42.49253184454781, 38.941251959119526, 35.992019585200715, 34.36779478618077, 34.81171519415719, 36.84205525262015, 35.33460187911987, 38.529126507895334, 37.70208937781197, 39.75729356493269, 37.1470707484654, 38.26953486033848, 35.46517242704119, 35.86785527638027, 35.09935671942574, 36.47003827776228, 35.992954117911204, 38.27487107685634, 41.75606795719692, 45.967034135546, 47.30525371006557, 51.65344681058611, 53.67078331538609, 53.5415746143886, 12.715444871357509, 0.22524776043636457, 4.931259436266763, 4.976431846618652, 2.3693669864109586, 0.6720071317894118, 11.604863047599792, 60.875551087515696, 54.02133730479649, 55.03843198503767, 41.87903022766113, 20.928264243262156, 30.758716310773575, 47.80659750529698, 45.25258561543056, 4.060036974293845, 0.2480384489255292, 0.04164874407329729, 0.07761278282850981, 0.0489158914424479, 0.06001915011022772, 0.015897083129467707, 0.11223653850278684, 0.06757138057478837, 0.034426831241164885, 0.17475495700325283, 0.15198845150215284, 0.1696659850754908, 0.15280270709523133, 0.1857473871537617, 0.1126949635467359, 0.068599625756698, 0.1695188515420471, 0.13850870196308407, 0.0840942578922425, 0.13026731062148297, 0.2479241836283888, 0.3538499596927847, 26.660170248576573, 63.52740750994001, 45.068649428231375, 32.62528732844761, 24.99797875540597, 38.088360582079204, 60.657516615731375, 58.406605992998394, 54.65348788670131, 58.04394824164254, 28.76973714147295, 0.5410196376698357, 3.3325638387884413, 4.259038158825465, 3.3109332280499593, 0.17502440325915813, 12.409093584333148, 52.21421160016741, 55.90764815466744, 52.82316214697701, 50.25074100494385, 47.990095955984934, 44.549910817827495, 40.478249073028564, 35.93317181723458, 37.24939686911446, 37.51744100025722, 34.85388381140572, 34.31138236182076, 36.14933374949864, 41.05459867204939, 42.540391036442344, 43.87960420336042, 44.3609163420541, 47.28152213777815, 46.87662976128714, 46.79908439091274, 50.637581961495535, 47.00551537105015, 47.37207801001412, 48.52610778808594, 48.82495675768171, 49.43790251868111, 47.894808360508506, 50.17527314594814, 48.93812206813267, 43.70567342213222, 38.19195474897112, 38.22054311207363, 37.035611220768516, 36.66461910520281, 37.55613899230957, 35.98992122922625, 37.52831840515137, 36.34997688020979, 39.392005920410156, 38.51845407485962, 37.61948224476406, 38.3479939188276, 41.17977046966553, 38.52767086029053, 40.385876246861045, 38.57847956248692, 40.04413257326399, 38.53272220066616, 37.67853498458862, 37.784071172986714, 35.27700131280081, 35.70709827968052, 37.363288266318186, 40.79244661331177, 43.91213914326259, 45.0781580380031, 42.96033321108137, 45.0872289112636, 44.390036242348806, 43.83504887989589, 44.12350334439959, 41.62118257795061, 43.54226916176932, 41.212989807128906, 40.30314057213919, 37.124569007328574, 37.34283971786499, 35.91467571258545, 36.55461522511074, 37.738598687308176, 38.75324065344674, 38.1701408794948, 40.308212757110596, 39.146411418914795, 37.200366905757356, 37.62263672692435, 41.130820410592214, 38.99189043045044, 39.92479726246425, 36.981741837092805, 37.0865832056318, 38.122378962380544, 38.410291467394146, 34.878515175410676, 35.544823101588655, 37.46804278237479, 36.46542467389788, 36.38063580649239, 37.04426172801426, 36.44263110842024, 35.817317553928916, 35.66721909386771, 37.96454020908901, 41.86138875143868, 45.71358469554356, 44.883049147469656, 47.60825422831944, 43.92124475751604, 41.25675998415266, 38.341354915073936, 36.03205510548183, 36.50174290793282, 39.84895767484392, 37.5660332271031, 40.24096461704799, 39.990270137786865, 41.96296794073922, 38.93860469545637, 39.88092286246163, 37.2552125113351, 38.357846464429585, 38.98245130266462, 37.291923318590435, 36.88391467503139, 40.939070974077495, 43.75557191031319, 48.37971271787371, 49.3872640473502, 54.69886309759957, 55.537562779017854, 54.279233591897146, 15.606465237481252, 0.4397109667105334, 6.001969022410257, 10.808206915855408, 8.438001802989415, 0.8141158691474369, 14.299378803798131, 66.0186493737357, 57.218960830143516, 59.63558251517159, 48.959015301295686, 29.45353889465332, 40.07476370675223, 54.03099530083792, 52.15432160241263, 5.553864061832428, 0.3995360753365925, 0.1113653809630445, 0.22343608550727367, 0.13947512581944466, 0.2639148655746664, 0.10302200580814055, 0.32070414828402655, 0.21783863300723688, 0.13044234551489353], [0.03553608332627586, 0.035436182615480254, 0.022314134685854827, 0.06583104681755815, 0.06002662078078304, 0.0248762116700943, 0.052240702855799875, 0.042157200896846395, 0.018873185218710984, 0.04545286583847233, 0.03393803157710603, 0.05554800806567073, 0.14915905546929153, 16.97826371874128, 49.186283929007395, 36.618959018162315, 20.94203904696873, 33.889505113874165, 32.60649939945766, 36.385791369846885, 50.789869104112896, 45.16081728254046, 48.002383845193044, 31.346467903682164, 0.18419602539922508, 1.3253052617822374, 2.1236372121742795, 6.938709957259042, 0.21598642239613192, 9.757592388561793, 55.14858872549874, 49.99902861458914, 48.49037667683193, 44.55801241738455, 39.917251518794465, 36.57809318814959, 34.56137159892491, 33.335796219961985, 32.69790642602103, 32.28611101422991, 32.74966703142439, 31.460609436035156, 34.94832372665405, 36.194437980651855, 40.51124954223633, 40.21683004924229, 39.40621498652867, 41.18020820617676, 42.6999842098781, 42.994132723127095, 44.06274829592024, 44.62518760136196, 44.092879159109934, 44.46935340336391, 44.3390851020813, 44.28357594353812, 42.55134834562029, 44.982745374952046, 44.65409558159964, 37.79801273345947, 34.26503092902047, 33.40356200081961, 34.18687064307076, 33.36241476876395, 33.772556509290425, 32.65617554528372, 32.429917880467, 33.33310031890869, 35.85703693117414, 33.03900044304984, 34.22023589270455, 34.305333954947336, 35.87694699423653, 35.45321805136544, 35.994378498622346, 35.90400675364903, 35.443799768175396, 34.50435815538679, 34.62777900695801, 34.66323219026838, 33.33274596078055, 33.278265135628835, 33.21643659046718, 38.983215604509624, 41.29023987906319, 43.20427404131208, 44.12882913861956, 44.2255619594029, 43.548491273607524, 36.1834910937718, 43.58541400091988, 40.35041264125279, 41.74300881794521, 40.227502482278005, 37.56130150386265, 33.61518675940377, 32.09745700018746, 32.433009828839985, 33.62689099993025, 32.312062535967144, 34.39083848680769, 34.9867125238691, 36.026329789842876, 35.077254499707905, 36.38948433739798, 33.96947887965611, 34.52701275689261, 36.6962160382952, 35.86091750008719, 33.57710368292672, 33.939573832920615, 35.22555685043335, 34.185116222926546, 31.947681631360734, 32.85590846197945, 32.71565907342093, 33.30559587478638, 35.893396854400635, 34.70299325670515, 31.78279045649937, 30.997049944741384, 35.41457217080252, 38.276809624263215, 41.22935976300921, 43.801013129098074, 47.003152983529226, 48.413932595934185, 44.08202607291085, 44.2257912499564, 38.24587624413626, 34.8181596483503, 35.56723799024309, 36.39876018251692, 35.68384960719517, 36.94052859715053, 37.86144283839634, 40.1836176599775, 38.970757484436035, 37.85066270828247, 35.68908854893276, 37.04585633959089, 33.39486633028303, 32.91381822313581, 33.50667674200875, 36.36084386280605, 36.8232673236302, 39.418200629098074, 45.10034016200474, 47.430897985185894, 51.78678968974522, 49.10129008974348, 12.878518223762512, 0.29895378968545366, 5.205809252602713, 4.120818078517914, 0.16660710849932261, 0.2708630641656262, 17.726200819015503, 55.54365634918213, 46.75974021639143, 46.987397943224224, 28.254595960889542, 29.328415734427317, 26.40315464564732, 45.73858778817313, 25.62764883041382, 0.29551383427211214, 0.07743250964475529, 0.09720704212252583, 0.048845279695732255, 0.05460604878940752, 0.06318912322499923, 0.10970534503992115, 0.02866261518959488, 0.043647915191416226, 0.023162491752633026, 0.01874432124064437, 0.044363874809018204, 0.005237756421723003, 0.000736347898574812, 0.03386898046093328, 0.05528225643294198, 0.04221554812309997, 0.06769961690796272, 0.017229383245908787, 0.01072788461377578, 0.014433304978800672, 0.06493808794766665, 0.0531183437976454, 19.987837723323278, 54.54106950759888, 41.52666275841849, 26.06740379333496, 24.145271505628312, 31.670938355582102, 45.11578253337315, 55.26588126591274, 50.98085771288191, 52.609088148389546, 34.67514487675258, 0.03505022171884775, 0.27758707478642464, 3.8681572590555464, 6.336936465331486, 0.05041853777532067, 10.370706643377032, 56.142354828970774, 51.82063783918108, 50.00172104154314, 46.86387981687273, 42.031901018960134, 38.36692428588867, 35.07298483167376, 35.049437386649, 34.80329050336565, 33.55801003319876, 33.82604374204363, 33.15351022992815, 37.32234948022025, 38.54624686922346, 42.32336057935442, 42.31814595631191, 42.41275610242571, 42.780437401362825, 43.936947686331614, 45.62963656016758, 45.51635660443987, 46.53685590199062, 46.651039123535156, 46.387511321476524, 45.80557884488787, 46.75727013179234, 44.43912179129464, 47.62197692053658, 45.984779834747314, 40.229062352861675, 35.90654632023403, 34.81969172613961, 35.22560896192278, 34.74177810123989, 35.55891057423183, 35.11514302662441, 34.61688075746809, 34.91340555463518, 36.80756439481463, 36.44886016845703, 34.486483914511545, 34.77518156596592, 37.04627670560564, 37.10674687794277, 36.678633621760774, 37.78110081808907, 36.55186373846871, 35.841379165649414, 36.39803409576416, 34.946892397744314, 35.42334427152361, 35.08239964076451, 33.44144357953753, 41.546006543295725, 43.467166083199636, 45.06803103855678, 44.72893810272217, 44.70275729043143, 45.739074162074495, 39.824117864881245, 45.808799334934776, 43.36425631386893, 41.63796247754778, 41.17755052021572, 39.06728533336094, 35.18003920146397, 33.88488803591047, 33.99750096457345, 34.59084933144705, 33.21306324005127, 37.23414209910801, 35.6676880972726, 38.031430516924175, 36.51662942341396, 38.400240898132324, 35.692402839660645, 37.91865430559431, 37.96884461811611, 35.54576110839844, 35.14603819165911, 35.91222994668143, 36.62544863564627, 35.90468072891235, 34.8024080821446, 34.21541384288243, 34.38048219680786, 34.593441009521484, 37.27976744515555, 37.18767254693167, 33.63859871455601, 33.754762172698975, 37.167574882507324, 40.42814908708845, 42.66026483263288, 44.18701335362026, 48.06437567302159, 48.98039838245937, 44.58942869731358, 45.49803420475551, 40.03426613126482, 36.50028726032802, 36.34042658124651, 37.65408079964774, 37.22425481251308, 38.89448363440377, 40.23776844569615, 40.35782289505005, 40.4827549798148, 38.99316889899117, 37.68659489495413, 38.97757019315447, 35.45038318634033, 35.889530181884766, 34.92923355102539, 37.67627682004656, 37.82286991391863, 42.88074507032122, 46.90412725721087, 50.838652406420024, 52.88510881151472, 49.58784464427403, 14.376343999590192, 0.17296279674129827, 6.949978198323931, 6.260063333170755, 2.5595919447285786, 0.23609468553747448, 19.14939512525286, 61.13987445831299, 52.031213419778005, 52.118868419102256, 33.979029178619385, 24.541700976235525, 30.57965428488595, 52.99717630658831, 32.53421381541661, 0.4836544958608491, 0.048473608746592484, 0.10963504202663898, 0.05946924497506448, 0.021381101537761942, 0.01390168212154614, 0.034523329098841975, 0.05079560647053378, 0.017557290382683277, 0.08154654210167271, 0.1430257638650281, 0.1292931107538087, 0.09130376031888382, 0.15949862636625767, 0.1854337818388428, 0.19100980620299066, 0.13089563404875143, 0.1357026882469654, 0.1054520093436752, 0.09439705897654806, 0.12099093624523707, 0.23361284871186527, 0.26296828208225115, 23.44102815219334, 63.74860341208321, 49.64095320020403, 31.341277599334717, 41.0734143938337, 42.58563770566668, 46.37747117451259, 58.84056963239397, 53.88045910426548, 57.193568638392854, 38.98864909580776, 0.23276001161762647, 2.910461860043662, 7.7642488820212225, 17.22768494061061, 0.29151685589126175, 13.176222477640424, 56.89775603158133, 53.457386766161235, 51.63307121821812, 49.307314600263325, 43.01934078761509, 40.57480818884713, 37.40390396118164, 37.29762084143502, 36.122791630881174, 35.553716795785085, 36.97847965785435, 34.33132716587612, 39.655273165021626, 39.58102124077933, 44.426952021462576, 44.436307770865305, 43.2140188898359, 43.60854802812849, 46.45357826777867, 48.01372330529349, 48.11100850786482, 49.1349332673209, 48.60919087273734, 49.461846011025564, 49.26985338756016, 47.68462882723127, 46.47339800425938, 50.071800572531565, 49.081324441092356, 42.27537284578596, 38.83218608583723, 37.132965905325754, 37.85499838420323, 35.42937183380127, 38.356481143406455, 36.96094935280936, 36.041466440473286, 34.999184540339876, 39.197921889168875, 37.87684004647391, 36.49984952381679, 36.665737765175955, 39.49661105019705, 38.71438980102539, 38.05801085063389, 39.15184491021292, 37.11230543681553, 38.70210886001587, 38.1018921988351, 36.028473309108186, 37.02100263323103, 35.99570560455322, 35.76309381212507, 43.25866106578282, 45.74408728735787, 46.62406621660505, 47.64634425299508, 46.73271867207119, 47.862804957798545, 42.49506793703352, 46.61055544444493, 44.457075936453684, 44.73614338466099, 43.42532403128487, 43.05820901053292, 37.75925915581839, 36.18888289587838, 36.0416818346296, 38.04552493776594, 35.30906030109951, 38.426994936806814, 37.625377791268484, 42.15688521521432, 36.671588148389546, 40.38362503051758, 36.507937226976665, 39.99325091498238, 39.463898931230815, 37.947009904044016, 37.55278301239014, 36.87651831763131, 39.07928139822823, 36.776373931339805, 36.15719911030361, 36.58217178072248, 36.03601557867867, 36.586639472416465, 39.183473110198975, 39.07866995675223, 35.82425880432129, 34.66932576043265, 39.68684230531965, 43.407008579799104, 45.84119531086513, 48.048905508858816, 49.296020303453716, 49.8940760748727, 48.05156666891915, 48.64973708561489, 40.59793874195644, 39.38682951245989, 38.33274957111904, 40.36422913415091, 39.75873531614031, 40.852333136967246, 42.107500893729075, 44.27447727748326, 42.52422605242048, 41.13627127238682, 39.40595095498221, 40.930753980364116, 37.59381559916905, 37.27121421269008, 36.10956226076399, 40.01824358531407, 39.51141766139439, 45.09072732925415, 49.81160790579659, 52.93717513765608, 53.68971020834786, 51.767251355307444, 19.139811822346278, 0.8826743417552539, 14.991843223571777, 12.249966808727809, 2.982568745102201, 0.4188995377293655, 21.803372485297068, 65.6201284953526, 55.8515761920384, 56.32350131443569, 43.34922041211809, 39.03259645189558, 36.47158077784947, 58.35374409811837, 39.31279993057251, 0.8868369098220552, 0.18473698065749236, 0.24900213150041445, 0.17788521546338285, 0.20133885980716773, 0.1259264371224812, 0.3112360606236117, 0.09656402841210365, 0.16749204029994352, 0.21947786504668848], [0.04888500452839902, 0.043666327239147255, 0.05582653312012553, 0.04409159566941006, 0.013683111573170339, 0.04313385706128819, 0.10447276796081237, 0.02048404262002025, 0.030683730130216906, 0.032541182424340925, 0.015515103537057127, 0.02032251566249345, 0.014918489747547677, 14.246823498180934, 48.06355578558785, 37.57533686501639, 43.570788042885916, 85.42476654052734, 66.83429145812988, 29.84944725036621, 45.713581221444265, 48.113037381853374, 45.101754120418, 39.90270546504429, 0.7872365457671029, 0.44677096073116573, 0.5701307441507066, 1.3304989316633768, 0.1933779748422759, 14.026894773755755, 55.18823167255947, 49.02619743347168, 48.62385851996285, 41.500436782836914, 36.67913041796003, 33.1361015183585, 33.98465027127947, 33.314965520586284, 32.993910108293804, 32.271870681217735, 32.483224460056846, 33.5383813721793, 35.24407727377755, 37.3821039881025, 39.16432040078299, 40.94775969641549, 42.20499801635742, 42.08454057148525, 44.5990241595677, 43.74274206161499, 45.211820534297395, 45.23420763015747, 45.000477177756174, 41.994686467306956, 46.057190486363, 42.85712814331055, 43.471640723092214, 43.25681979315621, 45.657422406332834, 37.50259617396763, 32.043087346213206, 33.2623085975647, 33.08395528793335, 32.71355724334717, 33.42165510995047, 33.81867865153721, 34.09510578427996, 34.08071953909737, 34.242588247571675, 35.498225007738384, 34.20126731055123, 35.29376384190151, 36.745193890162874, 34.414458887917654, 35.84004858561924, 35.067982128688264, 35.425876889910015, 34.05013009480068, 35.49680757522583, 35.49715151105608, 34.92579766682216, 31.84448003768921, 33.179486070360454, 39.38019050870623, 42.21377011707851, 41.99656595502581, 45.416306018829346, 45.36887066704886, 48.51815904889788, 41.02117436272757, 42.21028559548514, 44.79006140572684, 42.136520045144216, 41.69999599456787, 40.05189371109009, 34.101157665252686, 32.59732430321829, 33.34182378223964, 32.62813261577061, 33.06380551201956, 34.560006277901785, 33.56420087814331, 34.95061663218907, 34.75563628332955, 34.69399186543056, 34.30340930393764, 34.98998165130615, 37.818739209856304, 36.14140932900565, 32.67960834503174, 34.0425808770316, 34.78737218039376, 35.06886107581002, 34.09119047437395, 34.35001087188721, 32.74691207068307, 33.186371735164094, 32.61060231072562, 32.604109219142366, 31.962324959891184, 32.43305499213082, 34.17840773718697, 39.534704548971995, 40.086620807647705, 43.74229390280587, 45.35341092518398, 46.85575042452131, 48.99276270185198, 45.268451826913015, 42.84670237132481, 40.09220368521554, 37.71593018940517, 38.16863659449986, 38.518999508449006, 39.31273739678519, 40.177927085331504, 41.912722042628694, 41.94920703342983, 41.312015533447266, 39.09863907950265, 39.64870364325387, 38.10045392172677, 34.397095339638845, 33.90453059332711, 35.18286711829049, 35.314264501844136, 37.446517263139995, 44.595042841775076, 51.301114082336426, 51.41562386921474, 46.919124943869456, 9.194343617984227, 0.08406824285962752, 2.561468175479344, 3.53486259494509, 1.2231089855943407, 0.15911803607429775, 27.1329482623509, 56.72435678754534, 46.28310074125017, 46.2884647505624, 26.05690506526402, 22.888140882764542, 27.904669046401978, 45.19312640598842, 15.003603049686976, 0.05299156292208603, 0.018867168309433118, 0.037159206944384744, 0.020212486120206968, 0.05489159328863025, 0.05449628896479096, 0.010626777806984527, 0.03916144843346306, 0.0866158636552947, 0.003914591931139252, 0.03409942791664174, 0.032778455942337, 0.02401740855670401, 0.05638953737382378, 0.05313156165980867, 0.02925325956727777, 0.06736707368067332, 0.030718722181128602, 0.09064368823809282, 0.07825980668089219, 0.022366317421463982, 0.04007473960518837, 0.053944684099406004, 18.03669670649937, 58.61586488996233, 42.009590353284565, 42.80991513388497, 66.11620208195278, 53.913508210863384, 33.683623041425435, 49.172787053244456, 52.239245959690635, 49.267748083387104, 43.55331679752895, 0.7401348703673908, 0.26885514333844185, 1.4201197283608573, 3.5155574594225203, 0.1709416037691491, 14.33868042060307, 57.787264415196006, 50.70442363194057, 51.73305927004133, 42.460987022944856, 39.64086954934256, 34.904789788382395, 36.365579060145784, 34.59641483851841, 35.445762634277344, 32.8845454624721, 34.988175119672505, 34.50337151118687, 36.980866364070344, 37.31287908554077, 41.78125865118844, 41.91567850112915, 43.05997732707432, 43.29435396194458, 46.07743753705706, 45.97967638288225, 47.98116404669625, 46.31404454367501, 46.926986830575125, 45.35013484954834, 48.3786426952907, 44.93088749476841, 47.74383442742484, 45.11079372678484, 47.96207387106759, 39.38700321742466, 34.683274269104004, 35.12846967152187, 34.968372753688264, 33.651661327907014, 35.43361718314034, 34.357007707868306, 35.741255623953684, 35.202269962855745, 36.316590785980225, 37.627660274505615, 36.29532582419259, 36.98316969190325, 37.57690020969936, 36.741758005959646, 36.977079595838276, 35.236444677625386, 37.34688356944493, 36.363557134355815, 37.00976392201015, 36.92592000961304, 36.440126282828196, 34.46177959442139, 33.62837444032942, 39.21547998700823, 43.32655886241368, 45.07595198495047, 45.553550311497276, 47.2780202456883, 49.68113463265555, 39.52049895695278, 44.05444867270333, 47.71225486482893, 44.51496137891497, 43.337696824754985, 41.62850250516619, 36.46449361528669, 34.35937704358782, 34.49616622924805, 35.520323753356934, 34.82974229540144, 36.11206361225673, 35.22120380401611, 36.151379993983674, 36.36808041163853, 37.19151142665318, 36.3125330380031, 37.0875837462289, 39.60285248075213, 36.76816463470459, 34.46884938648769, 35.899031843457905, 35.87968111038208, 35.28195537839617, 35.826836585998535, 35.10841717038836, 33.54309919902256, 34.72123922620501, 34.78054904937744, 34.811319146837505, 34.06496449879238, 33.99996757507324, 37.8003751209804, 40.809612137930735, 41.648051261901855, 46.96492052078247, 46.28543186187744, 47.702749729156494, 48.671610014779226, 45.67353180476597, 43.44443505150931, 42.23003237588065, 39.44666392462594, 39.32048463821411, 39.64420468466622, 39.83653082166399, 41.062356335776194, 42.48196016039167, 42.099979468754356, 43.80494928359985, 41.17869349888393, 41.67046267645699, 39.42626748766218, 36.83245631626674, 35.33780499867031, 38.220994744982036, 35.72021995271955, 40.3883741242545, 47.605488845280235, 53.027932507651194, 54.21498359952654, 48.919990743909565, 10.819463866097585, 0.35597553849220276, 6.110694868224008, 6.118845105171204, 1.9862672005380904, 0.1864773958389248, 29.14533417565482, 60.255306243896484, 50.78530413763863, 51.81752157211304, 32.235830375126426, 24.960983072008403, 30.96311146872384, 53.2698027747018, 20.71569105557033, 0.03796138122145619, 0.05147787003910967, 0.05133326065593532, 0.046612224342035394, 0.040563244106514115, 0.03997164299445493, 0.04421696179945554, 0.08132850165878024, 0.048546066108558855, 0.03974595206922718, 0.11902546456881932, 0.08891843152897698, 0.10290230544550077, 0.1303781018193279, 0.11248936743608542, 0.12455321795174054, 0.1779171744627612, 0.14190885451223167, 0.2266740139041628, 0.17852336407772132, 0.09069252240338496, 0.1297655611165932, 0.20049222452299936, 20.26941520827157, 63.7881942476545, 48.782906259809224, 54.164873191288535, 83.21826185498918, 72.19678606305803, 39.56007242202759, 54.13193525586809, 57.185182162693565, 52.92047166824341, 49.238471848624094, 1.0052393163953508, 2.2247526092188696, 3.1168798123087202, 6.619194005216871, 0.6472628595573562, 17.485454423086985, 58.77761895315987, 52.315884590148926, 54.810183661324636, 44.00581128256661, 41.288322176252095, 36.28083883013044, 37.74439001083374, 36.29068790163313, 36.43813214983259, 35.4679343359811, 36.699540751320974, 37.494091578892295, 37.98538133076259, 40.58829811641148, 44.41524083273751, 43.79725415366036, 44.936720507485525, 46.559343746730256, 48.29757111413138, 48.347063132694785, 51.080567836761475, 49.22025714601789, 50.060162339891704, 46.333120822906494, 51.86827121462141, 46.83874818256923, 49.9903051512582, 47.59063012259347, 50.276807171957834, 41.92933171136038, 35.8783609526498, 37.96762868336269, 36.49827228273664, 34.73235286985125, 37.93883187430245, 37.04855918884277, 37.957546847207205, 36.918294361659456, 38.605299609048025, 38.593911511557444, 37.332226344517295, 38.899684361049104, 39.90131235122681, 37.36813810893467, 38.688889912196565, 37.214190346854075, 38.33858953203474, 36.77312217439924, 38.3065687588283, 39.413458483559744, 37.903944969177246, 34.8717337335859, 35.417122159685405, 42.2806395803179, 44.920916829790386, 45.81991645268032, 47.68474694660732, 49.39053317478725, 50.98068053381783, 44.979948725019185, 45.53688505717686, 48.55406733921596, 46.301659379686626, 45.44254241670881, 45.101028033665244, 37.89408547537667, 37.342850140162874, 37.3255352292742, 36.7614665712629, 36.91291298185076, 38.12739903586251, 36.44601488113403, 39.56926141466413, 38.411344119480674, 39.34051282065255, 37.96586384092058, 38.35113797869001, 42.7931421824864, 38.781474658421104, 37.039703709738596, 38.307715211595806, 37.954065799713135, 37.46614245006016, 37.84402370452881, 37.19052478245327, 34.48929793494088, 36.375733852386475, 36.778604303087505, 36.770672934395925, 35.380234173366, 35.41053874152047, 38.91871200289045, 43.6890081678118, 43.6707934652056, 48.55095107214791, 49.28452450888497, 47.81646742139544, 49.32504292896816, 48.28366429465157, 47.27140556062971, 44.49263334274292, 41.73180832181658, 42.29568937846592, 43.30234439032418, 41.781018938337056, 44.2867443220956, 45.748996189662385, 44.96240104947771, 45.19365446908133, 43.78104748044695, 43.59714950834002, 41.66033567701067, 39.47567960194179, 38.1554628099714, 40.07103252410889, 37.198334557669504, 41.09389073508126, 49.65075363431658, 56.39121845790318, 56.034685543605256, 50.769486563546316, 13.181043658937726, 0.3736311825258391, 8.893576077052526, 12.49631084714617, 5.729590952396393, 0.48882770112582613, 33.99163668496268, 64.87192562648228, 55.14178991317749, 56.84096145629883, 36.54799011775425, 34.09414693287441, 38.25825445992606, 61.994516781398225, 26.44396836417062, 0.21083965285548142, 0.1230950869087662, 0.13909731752106122, 0.1293552645615169, 0.23478180170059204, 0.1208677278565509, 0.12220810593238898, 0.22238997449832304, 0.2586392015218735, 0.15368305199912616], [0.01727273654458778, 0.012716132166263248, 0.05424738535657525, 0.048437768526907475, 0.02965551208970802, 0.08160178163754088, 0.01865138908449028, 0.007271309333321239, 0.05225141013839415, 0.0076164750082950506, 0.029872561871473278, 0.029180286518697227, 0.011768692871555686, 6.560847810336521, 43.751312664576936, 37.33675309589931, 44.142819336482454, 73.79180758340019, 58.27362789426531, 43.11946432931082, 45.487177644457134, 50.875922543661936, 41.74381480898176, 49.854221207754954, 4.836617588996887, 0.3054823822208813, 2.941623227936881, 4.1822327716009955, 0.10863136659775462, 9.452847003936768, 55.28465529850551, 46.45091015951974, 48.866746698107036, 41.07998044150216, 36.128777503967285, 34.94811528069632, 36.40310975483486, 33.08252395902361, 33.48825706754412, 32.99660948344639, 34.12787348883492, 33.892315660204204, 37.1950306892395, 37.149464402879985, 41.098115239824565, 43.34916830062866, 43.34720196042742, 44.27324397223336, 45.54990945543562, 44.43005439213344, 45.780673027038574, 42.779864174979075, 47.01373856408255, 43.48030512673514, 46.220768451690674, 44.377842153821675, 46.168709073747905, 44.492046219961985, 46.89186021259853, 37.95377050127302, 32.85921927860805, 33.635565825871055, 35.27397537231445, 33.17846468516758, 33.68774332318987, 34.05796071461269, 33.42542798178536, 35.488271713256836, 35.598289489746094, 34.3135085105896, 35.78218398775373, 35.97073725291661, 35.27161645889282, 34.9223061970302, 35.41001067842756, 35.17446674619402, 34.704108442579, 34.72264276232038, 35.74845395769392, 34.55389533724104, 33.630677768162315, 33.169994831085205, 31.269690309252056, 38.22414575304304, 43.33489670072283, 41.018818923405235, 45.579130104609895, 45.242708751133506, 47.46944311686924, 44.13027088982718, 41.13643455505371, 49.1020439692906, 43.78459453582764, 43.29771341596331, 38.411062717437744, 35.11405563354492, 31.750331946781703, 31.15684461593628, 33.37962545667376, 33.2497775214059, 33.90458965301514, 33.54727159227644, 34.12935692923409, 34.45453609739031, 34.4358662877764, 35.869352613176616, 35.90389558247158, 35.22368778501238, 36.13627808434622, 33.82764877591814, 32.68374947139195, 34.33422803878784, 34.299636432102744, 34.904428482055664, 33.74391256059919, 32.99768645422799, 34.02924033573696, 32.193296977451865, 35.072116306849885, 31.246042115347727, 34.73943655831473, 34.057286739349365, 36.88239649363926, 40.68995720999581, 45.28680549349104, 44.988060746874126, 45.09930835451399, 47.090248652866904, 46.085744108472554, 42.8058191708156, 46.53200258527483, 42.38277115140642, 42.12639651979719, 41.70230279650007, 41.126001834869385, 42.14544153213501, 43.386556557246614, 43.179760796683176, 43.79795592171805, 41.82977097375052, 41.875121865953716, 39.91666439601353, 39.763317653111045, 32.89195571626936, 35.251567431858604, 34.88331985473633, 41.400990690503804, 45.1027581351144, 51.75054441179548, 50.25862373624529, 40.167786189488, 3.0573281049728394, 0.10273748250412089, 3.7029047778674533, 4.90652254649571, 2.3519977927207947, 0.22879573862467492, 37.39922087533133, 50.1750681740897, 49.0689879144941, 41.17940221514021, 22.300191266196116, 19.665945053100586, 26.965201377868652, 44.18850374221802, 8.36343286718641, 0.18192807638219424, 0.038876769066389115, 0.026961979123630693, 0.06142341225807156, 0.0909494904002973, 0.04630638146772981, 0.01539572378221367, 0.02736062862511192, 0.019115639351574436, 0.03869068083752479, 0.018857241342110292, 0.07019933991666351, 0.062439409882894585, 0.03820841207302042, 0.06930313764938287, 0.03650073281356266, 0.04002978666020291, 0.039608667471579144, 0.025127366318234375, 0.04710123774462512, 0.0239214009405779, 0.0797739779310567, 0.03259101742878556, 9.618486847196307, 52.26128217152187, 42.822995117732454, 53.30064582824707, 76.36523968832833, 61.12661034720284, 44.531824656895225, 48.8477155821664, 56.77558585575649, 46.59915345055716, 52.37955093383789, 3.9660308871950423, 0.08635391521134547, 1.7513618511813027, 6.2593346408435275, 0.3103125201804297, 10.78342877115522, 58.44716957637242, 50.16816513878958, 51.40553508486067, 42.25028984887259, 38.62133257729666, 35.37386614935738, 37.65340335028512, 34.66623728615897, 35.6802156993321, 33.96885354178292, 35.90599741254534, 35.92023427145821, 38.72941875457764, 39.08280413491385, 43.05827154432024, 44.304531710488455, 45.10617317472185, 46.350143909454346, 45.96425485610962, 45.76663419178554, 47.6158937726702, 44.8684891973223, 47.9943447794233, 46.26456989560808, 46.652435711451936, 45.25196722575596, 48.497463839394705, 45.622434752328054, 48.06512607846941, 39.76693419047764, 33.76781783785139, 35.6297960962568, 35.709808077131, 34.06389100211007, 36.37354516983032, 35.78314978735787, 34.61077676500593, 36.61485263279506, 38.09556933811733, 35.973968165261404, 36.81137548174177, 36.962113176073345, 36.46424000603812, 36.01566777910505, 37.18644271578108, 36.58460712432861, 35.856470652988975, 35.02690437861851, 37.687609331948416, 36.59416437149048, 36.2044677053179, 34.11223656790597, 33.42061982836042, 40.05075420652117, 45.47568184988839, 42.74674211229597, 47.827984060559956, 46.61055891854422, 49.50724901471819, 44.491643224443706, 43.065195424216135, 51.019520963941304, 46.741480350494385, 45.47823531287057, 41.35635893685477, 35.752900804792134, 33.82461936133248, 32.69127089636666, 34.1424230166844, 34.550042561122346, 35.94938196454729, 35.88208518709455, 35.71614830834525, 36.235196113586426, 37.450255393981934, 36.44557367052351, 37.91518368039812, 38.316925048828125, 37.939394678388325, 34.87400926862444, 34.18212154933384, 36.332609857831685, 35.54151575905936, 35.73764256068638, 35.175964082990376, 33.83485753195626, 34.54207297733852, 34.55789055143084, 36.042373180389404, 33.71801315035139, 35.61391598837716, 36.83067410332816, 39.3422394480024, 41.40496506009783, 46.439532484327046, 46.960643904549734, 45.78705147334507, 46.72874430247715, 48.40378475189209, 43.48876803261893, 46.780310358319966, 44.597735268729075, 45.677634716033936, 42.95020273753575, 43.659652028764995, 43.807798045022146, 44.68356984002249, 43.83873837334769, 45.97166163580758, 44.71590675626482, 45.11414623260498, 42.91666030883789, 41.07127087456839, 34.98093509674072, 37.69257034574236, 37.43445519038609, 43.632897990090505, 47.39632027489798, 53.65547295979091, 52.80677482060024, 42.81602260044643, 3.448706235204424, 0.6342334129980632, 8.007595641272408, 4.826762872082846, 1.3608260814632689, 0.24273702768342836, 38.79753541946411, 55.319146156311035, 54.0034213747297, 45.892132554735454, 30.51888186591012, 24.709758792604717, 31.147739001682826, 51.47960983003889, 10.608568668365479, 0.17825290001928806, 0.05064315661521895, 0.03297004709020257, 0.05855497332023723, 0.05171940475702286, 0.04916085954755545, 0.02158452633635274, 0.07644588580088955, 0.056351044082215855, 0.01904488171982978, 0.09492375821407352, 0.12742065265774727, 0.13593250805778162, 0.112364876616214, 0.10668136551976204, 0.14705966812159332, 0.1336455193481275, 0.16458520985075406, 0.13092227333358356, 0.1112929405644536, 0.16915449180773326, 0.2990304370011602, 0.15840045815067633, 11.086428420884268, 60.282411166599815, 49.81151063101632, 53.1914826801845, 77.7531840460641, 62.774354798453196, 51.652585233960835, 55.04984440122332, 60.110832350594656, 50.763274874006, 59.16368171146938, 6.142645725182124, 0.907078640801566, 8.491052167756216, 13.646850892475673, 0.5584083731685365, 12.538265807288033, 58.64771543230329, 50.53788225991385, 53.705732754298616, 44.97660664149693, 40.158524240766255, 37.40044028418404, 39.70773206438337, 36.92181709834507, 37.85146175112043, 35.565122263772146, 37.816355977739605, 37.74922595705305, 40.90723432813372, 40.11617497035435, 43.85613318852016, 47.27632141113281, 47.37875870295933, 48.395325320107595, 50.072220938546316, 48.65877669198172, 49.965955189296174, 47.879786355154856, 50.26865346091134, 47.85939686638968, 50.81467069898333, 48.780436175210134, 50.70697709492275, 47.009892736162456, 51.41941063744681, 42.019362994602744, 36.40140744618007, 36.93696417127337, 39.27677352087838, 35.303001471928184, 37.576681341443745, 37.510718618120464, 36.49482250213623, 39.13198348454067, 38.85783188683646, 37.30798755373274, 38.79335955211094, 38.55362933022635, 38.41536365236555, 38.10607154028756, 38.41921642848423, 39.26625394821167, 37.45910392488752, 37.59083482197353, 39.1058999470302, 38.23727090018136, 36.98246444974627, 36.93840939658028, 34.97802380153111, 42.55763993944441, 47.56336191722325, 42.88468817302159, 49.747159889766145, 48.15378509249006, 50.51745455605643, 47.765286990574424, 45.614055224827354, 52.50279460634504, 47.33986963544573, 49.254025391169954, 44.123458181108745, 37.09048114504133, 35.26621423448835, 35.413578578404014, 35.71873998641968, 37.4005514553615, 36.50937550408499, 36.16528681346348, 36.68021781103951, 37.67134359904698, 39.12102270126343, 38.47615691593715, 40.126416615077424, 38.60533087594168, 39.22958830424717, 37.62480803898403, 35.163245405469624, 38.253338609422954, 37.7476487159729, 37.00520590373448, 36.97318860462734, 35.931789125714985, 36.15674747739519, 35.75934873308454, 38.642646176474436, 34.50679349899292, 39.560110637119834, 38.02574341637747, 41.29799754279, 43.073050362723215, 48.89136069161551, 49.47867454801287, 50.20907265799386, 48.165037700108115, 48.9483185495649, 46.19340991973877, 48.90555933543614, 47.1553497995649, 48.23416532788958, 46.476635864802766, 45.85975047520229, 44.39659881591797, 47.89441926138741, 46.062745571136475, 47.734468255724224, 46.51335709435599, 45.61844301223755, 44.01490647452218, 44.53694200515747, 36.56041349683489, 39.7127035004752, 39.53606639589582, 45.933269364493235, 48.57668719972883, 56.8982424054827, 52.31259461811611, 45.490874086107524, 5.22017639023917, 0.437077029475144, 11.056434784616743, 13.828070334025792, 6.143629763807569, 0.3858264924160072, 45.31446279798235, 58.65749849591936, 58.34092467171805, 50.50583716801235, 33.44507053920201, 30.229544980185374, 37.198925154549734, 58.84019442967006, 13.970277377537318, 0.34047019907406395, 0.2146337628364563, 0.14669363919113362, 0.15826118205274853, 0.15257295513791697, 0.2045279879655157, 0.03330807966579284, 0.14615074332271302, 0.10766701905855111, 0.21495073368506773], [0.06058694821383272, 0.044397028030029366, 0.07642565188663346, 0.028974334177161967, 0.06042395731700318, 0.0035601706144266893, 0.01720510865561664, 0.05151885694691113, 0.012122269836254418, 0.04313168574922851, 0.038363151984023194, 0.023570303173203553, 0.1050439587395106, 3.7288428374699185, 42.54226010186331, 44.68891995293753, 27.688104118619645, 52.074559756687705, 56.99910593032837, 37.64378704343523, 42.35056277683803, 51.35338538033621, 43.663355418613975, 54.331529208592, 15.525720221655709, 0.0982192535219448, 0.9965325721672603, 5.191811672278813, 1.6992337512118476, 6.486204615661076, 61.75036403111049, 46.23777764184134, 51.23829889297485, 37.89985248020717, 38.512586321149556, 34.959711824144634, 38.60425043106079, 34.072756903512136, 36.255877426692415, 33.09470067705427, 34.38148621150425, 36.15638269696917, 38.77484955106463, 41.95956679752895, 44.2881235395159, 42.91531235831124, 45.39890078135899, 44.02173655373709, 46.82230527060372, 44.57318033490862, 45.51140948704311, 43.19678388323103, 44.49799040385655, 44.3078043120248, 46.17353459766933, 43.69932276862008, 45.51216336659023, 43.894681794302805, 44.86832244055611, 38.04664012363979, 32.8555645261492, 35.88295718601772, 35.295938628060476, 34.91117170878819, 34.944939953940256, 33.99004207338606, 35.179528508867534, 34.314842564719065, 36.36649969645909, 35.69218397140503, 36.204950605119976, 34.75735943658011, 36.97497429166521, 34.916143144880024, 34.63721118654524, 32.369124616895405, 36.06115416118077, 33.981825828552246, 36.81945971080235, 35.79159532274519, 33.90244960784912, 31.466835021972656, 31.74332468850272, 37.23802614212036, 43.34456859316145, 41.53071008409773, 43.44950723648071, 45.91929306302752, 46.46512269973755, 44.821349143981934, 44.612260477883474, 45.104887757982524, 45.27695642198835, 42.8188922064645, 40.92633145196097, 34.88804462977818, 32.452575956072124, 31.976415906633648, 32.12837995801653, 33.49332577841622, 33.67768233163016, 33.60691840308053, 34.031790324619834, 34.22517258780343, 34.259993485042024, 34.554089886801584, 34.866988113948274, 34.75242274148123, 36.462430000305176, 33.0447917665754, 33.13772392272949, 34.555924211229595, 34.242484024592805, 31.597082478659495, 33.750165939331055, 32.12605925968715, 32.773923192705425, 34.34059258869716, 33.391055243355886, 33.07896300724575, 32.75394017355782, 31.955397605895996, 33.30537005833217, 38.482563155038015, 44.80278008324759, 46.4622391973223, 45.09441334860665, 43.15521975925991, 47.743473121098106, 43.66402244567871, 46.81322397504534, 45.2776060785566, 44.01916919435774, 42.932589054107666, 44.94844906670706, 44.07472699029105, 45.293361118861604, 43.30195876530239, 46.992081029074534, 44.92675679070609, 45.869874000549316, 42.69576665333339, 44.76168496268136, 37.82723685673305, 34.93489980697632, 33.69454213551113, 43.064163616725374, 44.953972884586875, 52.89517675127302, 47.815744808741975, 41.02813645771572, 1.0510688743421008, 1.029720968433789, 4.313342239175524, 3.0435463530676703, 0.4506224883454186, 0.3866021665079253, 42.61302750451224, 49.6333657673427, 48.03516892024449, 39.80525003160749, 21.10540509223938, 16.213477236883982, 35.00304773875645, 34.75586557388306, 2.9949447895799364, 0.12220246052103383, 0.06908886986119406, 0.05252089710640056, 0.029193979355373552, 0.04742758933986936, 0.0372989444461252, 0.05265265164364662, 0.035956479875104766, 0.036836933344602585, 0.023055902382891093, 0.01547607929179711, 0.07069353054144553, 0.06048305771712746, 0.05151971529370972, 0.06515908001789025, 0.015104428698707904, 0.0421117153018713, 0.018592443051082746, 0.016308161696153026, 0.043557768421513696, 0.03140928762565766, 0.02435355819761753, 0.036437897078160725, 5.140186556747981, 50.74070017678397, 48.21211174556187, 32.573221002306255, 65.55566310882568, 61.12896578652518, 44.07897581372942, 46.55463981628418, 54.276016575949534, 46.621026379721506, 58.57405757904053, 16.34256955555507, 0.02820967440493405, 1.0822856106928416, 7.895724432809012, 2.1848362939698354, 7.341816646712167, 62.52865954807827, 49.0536184992109, 53.385973181043354, 39.7393741607666, 39.27440765925816, 35.84965099607195, 40.62735741479056, 34.821543421064106, 38.393845081329346, 34.39568485532488, 36.2150011743818, 37.18977090290615, 41.05523443222046, 43.82392828805106, 45.550385407039094, 44.35280432019915, 48.36260277884347, 45.205237116132466, 48.43132741110665, 46.09334543773106, 47.15676375797817, 43.7646358353751, 46.64533117839268, 46.374083927699495, 47.228139128003804, 44.67156335285732, 48.284901074000764, 44.908139092581614, 46.39520992551531, 39.33192137309483, 35.81209945678711, 36.58189385277884, 37.70080396107265, 36.95756210599627, 36.88338661193848, 36.32885435649327, 37.08076408931187, 36.15251949855259, 38.693263803209575, 36.05614798409598, 37.85128457205636, 36.25467191423689, 39.67200442722866, 34.79850319453648, 36.75887141908918, 34.875874859946116, 37.164677483694895, 35.49310418537685, 37.360234533037456, 35.650651114327566, 34.781546115875244, 33.50895227704729, 34.78106321607317, 38.280916009630474, 43.577534743717735, 43.60516078131539, 45.29725211007254, 47.829585620335166, 48.840215001787456, 46.48403569630214, 47.84608064379011, 47.94118758610317, 47.02723543984549, 44.235063620976035, 42.73666722433907, 36.96798440388271, 33.07548195975167, 33.375404426029746, 34.892415046691895, 35.62239279065813, 35.64949771336147, 35.380678858075825, 35.63989877700806, 35.53482116971697, 36.24160235268729, 36.1960951260158, 37.92708247048514, 36.90648589815412, 38.18333898271833, 36.46578598022461, 35.08744403294155, 35.516199997493196, 36.25449473517281, 34.32006066186087, 34.979128565107075, 34.69606590270996, 35.027369907924104, 35.91615220478603, 33.816538606371196, 34.3521648134504, 34.85793113708496, 35.00072356632778, 36.21438973290579, 40.84494720186506, 47.000811440604075, 47.79427834919521, 47.83917760848999, 44.915292263031006, 48.106238569532124, 46.38467993055071, 49.01602874483381, 46.84237514223371, 47.07376405170986, 44.54241371154785, 46.15562214170183, 44.49859489713396, 48.67784949711391, 45.59633037022182, 47.72577953338623, 46.06243985039847, 47.85713870184762, 44.94570452826363, 45.86570508139474, 40.22660616465977, 36.95699235371181, 35.659517015729634, 44.95230531692505, 46.49669531413487, 56.89237117767334, 47.55539928163801, 42.30268621444702, 1.7214461650167192, 2.1353783650057654, 10.068118674414498, 4.8481051325798035, 1.2504489528281348, 0.5134843609162739, 46.47057703563145, 54.286588260105674, 51.592222758701865, 45.79184920447213, 26.55865706716265, 19.00373135294233, 37.92831577573504, 41.08223165784563, 3.8672201207705905, 0.1363134104758501, 0.04755148983427456, 0.07970135432801076, 0.03307336761749216, 0.05429024502102818, 0.05901725922844239, 0.04946296030123319, 0.012689298650782024, 0.03697644692978688, 0.045278899637716155, 0.10129299001502139, 0.14664212481251784, 0.16533402752663406, 0.15854818879493646, 0.13553207740187645, 0.041834248762045584, 0.15085090111408914, 0.19025340250560216, 0.10013563318976335, 0.13669784127601556, 0.18012533097394876, 0.12848828679748944, 0.20506271427231176, 5.676663483892169, 57.7829669543675, 56.04208884920393, 38.59388024466378, 60.737344469342915, 62.66263471330915, 46.73426464625767, 50.66854313441685, 61.63692774091448, 51.001108237675254, 64.24289131164551, 19.193729843412125, 0.18850245646068028, 1.8828580294336592, 10.244607261248998, 2.5113931596279144, 9.145864299365453, 64.27672209058488, 50.656053747449604, 55.082813603537424, 41.29479789733887, 42.203903675079346, 37.76504700524466, 43.205854756491526, 37.49756915228707, 40.00566387176514, 36.231405871255056, 38.25359916687012, 39.03018890108381, 43.62550163269043, 46.5038971219744, 47.017824104854036, 47.128220558166504, 50.63374308177403, 47.91915832247053, 50.801976340157644, 47.56419917515346, 48.984782695770264, 45.687452520642964, 48.993857043130056, 47.838058948516846, 50.1612343106951, 45.49712746483939, 51.14280979973929, 47.35656268256051, 48.726823874882285, 40.98629787990025, 37.77045965194702, 40.53522777557373, 40.75198377881731, 38.767394133976524, 38.42086662564959, 38.03185435703823, 38.980189664023264, 37.44169521331787, 40.87116275514875, 36.93782574789864, 39.172710350581575, 37.968601431165425, 41.310309750693186, 37.8546370778765, 38.64341047831944, 35.591737338474815, 38.36995022637503, 37.3312258039202, 38.284133025578086, 38.194258076804026, 37.0552259853908, 35.653395652770996, 36.77293804713658, 38.649941784994944, 45.91589886801583, 45.61240502766201, 45.7226243019104, 48.5498810495649, 48.66701030731201, 48.126954623631065, 48.56736271721976, 48.92440979821341, 48.49803706577846, 46.858300413404194, 44.78140047618321, 40.06875351497105, 35.74481310163225, 36.28061301367623, 36.75050578798567, 37.83884729657854, 36.48507765361241, 36.95143379483904, 37.44973775318691, 37.10250500270298, 38.02009105682373, 37.79859638214111, 38.48525905609131, 38.64992788859776, 39.284746578761506, 37.93582330431257, 37.277491910117014, 36.83641331536429, 37.15335539409092, 35.23252589362008, 35.95540952682495, 36.23176370348249, 36.89225598743984, 38.734178270612446, 35.99392339161464, 37.193505559648784, 36.42934267861502, 36.09204237801688, 36.63885865892683, 42.7998228754316, 49.81900078909737, 49.66006074632917, 52.03056723730904, 46.31859908785139, 49.88863563537598, 48.76933642796108, 51.67920725686209, 50.64492620740618, 47.51735094615391, 47.504399503980366, 49.2263229233878, 46.859259264809744, 49.099236897059846, 47.59458017349243, 49.104451520102366, 49.10662978036063, 49.21700191497803, 45.74408033915928, 49.108207021440776, 41.38142803737095, 39.32645661490304, 36.64665453774588, 48.25607647214617, 47.675165380750386, 58.36440263475691, 47.81627982003348, 45.72578573226929, 2.729198123727526, 2.8617628046444485, 15.604564905166626, 10.907035487038748, 2.879946891750608, 0.6102954032165664, 50.68139035361153, 57.894565446036204, 57.134067739759175, 50.30596876144409, 31.411774022238596, 24.1644572189876, 45.26186146054949, 47.680626664842876, 5.912042830671583, 0.29643200071794645, 0.2848007162766797, 0.24833581011210168, 0.1296053725693907, 0.23777110129594803, 0.14258295191185816, 0.2556642054447106, 0.12104646755116326, 0.07906743977218866, 0.15970997645386628], [0.02279016262452517, 0.02350931305305234, 0.042445975222757885, 0.0831660016306809, 0.03121991189462798, 0.02642993811917092, 0.025384671886318495, 0.044316038090203486, 0.01358750683721155, 0.017259389760770967, 0.0467551475656884, 0.07799144608101674, 0.017502561444416642, 0.40884397444980486, 29.38013812473842, 50.12451655524117, 31.776318209511892, 20.65552486692156, 20.123662846429006, 35.61008405685425, 45.49818011692592, 54.89578546796526, 46.68650272914341, 50.73028482709612, 23.503940616335186, 0.1653899795242718, 1.408979486141886, 11.710360152380806, 4.770233196871621, 6.812761698450361, 57.90189926964896, 45.00422920499529, 51.832223960331504, 39.42269958768572, 39.1666966847011, 37.83662734712873, 40.36133868353707, 37.143787724631174, 35.14467634473528, 33.13082436152867, 38.050923688071116, 40.815802982875276, 43.78781502587454, 42.50043542044503, 43.93356391361782, 43.71700593403408, 48.029002393995015, 45.122894014631, 45.192191873277935, 41.954751695905415, 43.90470804486956, 44.87087937763759, 45.965717451913015, 43.15651559829712, 45.28143106188093, 44.11485978535244, 44.46976334708077, 45.75089999607631, 44.3189492225647, 38.92390578133719, 32.82241119657244, 34.82099798747471, 35.335682324000764, 33.79158067703247, 34.12911721638271, 32.1101895741054, 33.669518198285786, 35.69139882496425, 35.38965245655605, 34.70931959152222, 35.365396295275005, 36.702646596091135, 36.22281789779663, 35.40028320040022, 34.347811767033164, 36.918002537318635, 35.27329792295183, 34.20258746828352, 34.85887609209333, 34.19137307575771, 35.00037268229893, 32.16718912124634, 32.79133537837437, 38.151929650987896, 41.73152344567435, 40.78954226630074, 41.684126308986116, 44.27965715953282, 46.436721937997, 46.199159554072786, 46.40169606889997, 45.70083475112915, 43.3265380178179, 41.43662452697754, 39.904876777103965, 34.60208109446934, 32.11767625808716, 31.923988274165563, 33.85365240914481, 33.66795137950352, 34.905672209603445, 33.6831054006304, 35.06104435239519, 33.916926179613384, 34.714179856436594, 34.82655654634748, 35.895693234034944, 34.549323422568186, 35.49238157272339, 32.661219937460764, 32.54214171000889, 33.62740516662598, 34.159856046949116, 33.86095149176461, 33.89912836892264, 32.390372208186555, 33.1890606880188, 34.0557233946664, 32.61007077353341, 31.891158035823278, 33.17507743835449, 33.104428155081614, 33.550262791769846, 33.80438968113491, 41.80944749287197, 44.05851684297834, 45.78813191822597, 41.14385870524815, 42.48216165815081, 45.89150374276297, 44.84678997312273, 46.64034932000296, 45.112426553453716, 43.93455055781773, 45.91114630017962, 45.60096134458269, 46.78250251497541, 46.0809394291469, 47.00083923339844, 45.28828198569161, 47.10824796131679, 47.68766519001552, 45.763976505824495, 40.19760090964181, 36.839119638715474, 33.43645477294922, 40.10131624766758, 47.02393504551479, 50.76995209285191, 49.88224329267229, 32.611269337790354, 0.34943473232643946, 1.4996961440358842, 8.011346799986702, 2.3459932463509694, 0.7804786626781736, 3.0478357800415585, 47.18734972817557, 45.242614950452534, 51.816197940281455, 33.899100576128276, 24.256322826657975, 24.31733669553484, 42.04413679667881, 27.37686824798584, 0.39532402849623133, 0.07135166201208319, 0.018466011621057987, 0.046948591114154885, 0.06931524949946574, 0.04797506531966584, 0.05102011674482908, 0.027119646913238933, 0.11710226562406335, 0.023254830190645795, 0.04127580765634775, 0.05371636724365609, 0.08865301577108246, 0.061841288049306185, 0.028700277275804962, 0.037050743121653795, 0.05738079561186688, 0.024187052489391396, 0.04701225805495467, 0.04900690334449921, 0.024139790829004984, 0.05614756500082357, 0.029621870323483433, 0.06376135894762618, 0.9174429646560124, 36.021243708474294, 55.311197417122976, 32.25361428941999, 28.400485549654277, 40.93478740964617, 42.166935784476145, 48.92416313716343, 60.6114570072719, 49.891112668173655, 56.50413710730416, 25.17320363862174, 0.2049562656985862, 1.0726620299475533, 14.94059157371521, 6.678780887808118, 7.749835712569101, 62.83948026384626, 46.0249855858939, 54.0681334223066, 42.01013578687395, 42.33142743791853, 39.3368684904916, 44.01771354675293, 36.7339517048427, 36.69113343102591, 34.03889833177839, 39.0298866544451, 43.52930729729788, 46.88524552753994, 44.645233154296875, 46.38537127631051, 45.23513521466936, 48.558013916015625, 46.411430495125906, 46.73787076132638, 42.72310781478882, 45.484724930354524, 47.26038571766445, 46.60509416035244, 45.63422237123762, 46.0023136138916, 45.43923854827881, 45.57916831970215, 46.41134711674282, 46.24306174686977, 39.669353689466206, 36.10376746313912, 35.84415149688721, 37.13993494851248, 35.655476638248985, 35.57664932523455, 34.230213505881174, 35.23863683428083, 36.692158290318076, 37.409094265529085, 35.66773326056344, 37.28168167386736, 37.67708281108311, 36.561910833631245, 35.55533572605678, 35.56376041684832, 37.55410317012242, 36.96217570986067, 35.606717654636924, 36.689156668526785, 36.04280744280134, 35.65795019694737, 33.68381759098598, 33.76731409345354, 40.28264338629586, 43.07626390457153, 42.321314334869385, 43.754244804382324, 45.325562545231406, 51.32923691613333, 47.56803805487496, 48.84640237263271, 46.75165251323155, 45.9683438709804, 43.21903896331787, 41.85160916192191, 36.221629755837576, 33.67664705004011, 34.887784072331016, 35.25729274749756, 34.49332094192505, 35.847681181771414, 35.65100547245571, 36.42854710987636, 36.402557373046875, 37.517538275037495, 35.89438002450125, 36.881781578063965, 37.185574190957205, 37.444234779902864, 34.42379379272461, 33.510626792907715, 36.26027911049979, 36.63345990862165, 34.72643300465175, 34.61079066140311, 35.19483191626412, 35.276403767721995, 34.27163519178118, 34.44441604614258, 35.04130104609898, 33.79293210165841, 34.98315852028983, 36.63602031980242, 36.17822435923985, 43.11720616476876, 45.71791689736502, 47.15935543605259, 44.19222102846418, 44.83604458400181, 45.452613830566406, 48.425904342106406, 47.69737529754639, 48.343651567186626, 45.50766440800258, 48.71714850834438, 47.51603773662022, 48.84375510896955, 48.919973373413086, 49.48317698069981, 47.59255477360317, 48.06444862910679, 48.32896654946463, 48.23371369498116, 42.49957036972046, 39.71896035330636, 34.99979598181588, 42.516451018197195, 47.75828668049404, 52.79194041660854, 48.414988722120015, 36.824764660426546, 0.5100242665835789, 3.044225105217525, 7.2867903879710605, 5.466482647827693, 0.7219962179660797, 3.330271367515836, 50.87767696380615, 53.68890421731131, 55.16389560699463, 43.03165299551827, 27.87574369566781, 22.41371440887451, 48.24858283996582, 33.8243761743818, 0.84257829615048, 0.12981589484427655, 0.09602985171867268, 0.02375261196201401, 0.06814324310315506, 0.04060986964032054, 0.005701368017720857, 0.02980173977890185, 0.05862241970109088, 0.014529580616259148, 0.04909428169152566, 0.1309772753821952, 0.1514963371945279, 0.16422792045133455, 0.12444336313222136, 0.1836328413337469, 0.09797548981649534, 0.15536868226315292, 0.31212152168154716, 0.16039740028125898, 0.13758491724729538, 0.19506813772022724, 0.13619157272790158, 0.1407936414969819, 1.179008117743901, 39.12224211011614, 63.036941119602744, 41.19279834202358, 32.13738829748971, 30.687056064605713, 46.37664086478097, 52.92756230490548, 64.1902517591204, 54.67933171136038, 59.58611134120396, 28.225283248083933, 0.4780448025890759, 4.258146618093763, 22.340247631072998, 8.471261961119515, 8.753285867827278, 62.94796248844692, 47.90832608086722, 57.603772912706646, 43.95780965260097, 44.484920842306956, 41.930620602199006, 44.88235780170986, 40.300013882773264, 38.86367532185146, 35.70721639905657, 41.74774054118565, 44.90457814080374, 48.616441317967, 45.84328324454171, 47.563393184116904, 48.28371293204171, 50.621264117104666, 48.042850153786794, 48.37815632138933, 44.97929212025234, 47.737935406821116, 48.857665402548655, 48.70058052880423, 47.664882046835764, 48.53888552529471, 47.61330904279436, 47.47304923193795, 48.3964752469744, 48.13197469711304, 42.55959933144705, 37.38227421896798, 38.18285608291626, 39.27538735525948, 37.46432202202933, 38.61616659164429, 35.81485789162772, 36.340909481048584, 39.69385303769793, 39.59415333611624, 37.54211057935442, 37.1224741254534, 40.23958192552839, 39.14903783798218, 38.573726994650706, 36.52780907494681, 38.2477696282523, 38.24107156481062, 37.0841235433306, 39.281890869140625, 36.340148653302876, 38.58009154456002, 35.256750788007466, 36.008577142442974, 41.45287636348179, 45.51432773045131, 44.95229489462716, 45.12557601928711, 46.58246040344238, 52.069261755262104, 49.37943342753819, 49.85306085859026, 49.80049078805106, 47.84950263159615, 46.37541798182896, 44.14146096365792, 38.41327919278826, 36.70840317862374, 36.45713547297886, 37.955309527260916, 36.69154337474278, 37.53994274139404, 37.15708310263497, 37.46389818191528, 38.48148618425642, 38.63496841703142, 38.15427466801235, 38.55452912194388, 39.184810638427734, 38.81059455871582, 35.57726771490914, 35.343321868351524, 38.2330880846296, 39.42929342814854, 37.5157595361982, 37.08916793550764, 35.89321967533657, 36.74598945890154, 37.58222600391933, 35.522460324423655, 36.36638157708304, 36.817159857068745, 36.421147278376985, 38.11884232929775, 37.447288513183594, 46.413754667554585, 47.30219302858625, 49.82183565412249, 46.795460905347554, 45.47488975524902, 47.311232634953086, 49.4582815851484, 49.74289716993059, 49.79953193664551, 48.481684480394634, 51.963683877672466, 50.24272973196847, 51.73873594829014, 50.87765959330967, 50.93733072280884, 48.82878868920462, 49.952972480228965, 51.45130286897932, 51.31110559191023, 43.881476742880686, 42.28382185527256, 36.783200536455425, 45.30629866463797, 50.6164733341762, 55.79993718011038, 48.51697438103812, 38.87915243421282, 1.1692588180303574, 3.85593581199646, 21.173212562288555, 10.38057655947549, 1.549743258527347, 3.8436761498451233, 56.750412532261436, 56.63389471599034, 61.33472279139927, 45.23728568213326, 34.97463308061872, 34.927315848214285, 54.22304350989205, 40.98896598815918, 1.1943756874118532, 0.23099994606205396, 0.2827342785894871, 0.16723467196737016, 0.19705714099109173, 0.1000437324068376, 0.13665285440427916, 0.14007573787655148, 0.16057635710707732, 0.10682218867753233, 0.09497373910354716], [0.06938011066189834, 0.01671355583571962, 0.0364333441081856, 0.02408399828709662, 0.047545674789164744, 0.029220435435750654, 0.06144940693463598, 0.021391934349334667, 0.0602825777605176, 0.06624198119555201, 0.015627589376111115, 0.06505229217665535, 0.06659342840846096, 0.07235972077718802, 8.114935755729675, 47.71113273075649, 42.952978542872835, 28.412717853273662, 15.948149851390294, 33.792039258139475, 41.3852356501988, 52.82089703423636, 43.481785093035015, 49.68178081512451, 34.12415967668806, 2.179348085607801, 1.2747962006500788, 8.744155934878759, 4.933170625141688, 3.7998942477362494, 55.08510998317173, 48.20060552869524, 47.945523262023926, 41.163494314466206, 42.53506524222237, 40.460155963897705, 41.26619563783918, 37.572151115962434, 36.10307959147862, 36.51733466557094, 42.55114337376186, 43.871933392116, 44.9747097832816, 45.45846421377999, 46.22818217958723, 44.812121936253135, 46.179103578839985, 43.99203300476074, 43.44594281060355, 45.686379023960654, 45.77528469903128, 46.08487210954939, 46.34485633032662, 44.72998033251081, 45.105085781642366, 43.97229317256382, 45.667865548815044, 42.0525232723781, 43.00589949744088, 36.04006290435791, 34.71462801524571, 34.35341201509748, 34.645750522613525, 35.897409439086914, 33.63784483500889, 34.54309436253139, 34.21303408486502, 34.79836770466396, 36.02226856776646, 38.85208920070103, 38.452036244528635, 36.39858300345284, 36.247886998312815, 34.944217341286794, 34.91407258169991, 34.2579402923584, 34.89145619528634, 34.8210049356733, 37.08796937125069, 34.71256440026419, 33.00393288476126, 30.714251313890728, 34.3489408493042, 36.199263504573274, 39.405381202697754, 39.13919224057879, 39.35975585665022, 45.257560525621685, 47.819621903555735, 46.388508387974326, 47.124628339494976, 44.84072766985212, 42.315384047372, 40.5209527015686, 39.50138446262905, 34.062244279044016, 33.983309268951416, 32.40771491186959, 32.985353401729036, 33.548272132873535, 33.762377398354666, 33.653797898973735, 33.477744443076, 34.735076563698904, 34.99679783412388, 33.24246801648821, 35.028057779584614, 35.74326365334647, 34.74136815752302, 34.381468841007774, 34.79811756951468, 32.836050510406494, 33.72060482842581, 33.181483677455354, 33.264827319553916, 33.11722673688616, 33.62337521144322, 33.00186579568045, 33.41489451272147, 31.167131423950195, 30.90678242274693, 31.546770572662354, 31.742744513920375, 32.99395179748535, 33.91710683277675, 41.33753279277256, 43.864797592163086, 43.215182713099885, 42.2006380217416, 43.23075362614223, 43.05382817132132, 41.929779870169504, 42.488574845450266, 45.69299718311855, 47.01466267449515, 46.19797141211373, 45.605515888759065, 46.414654459272114, 48.782941000802175, 45.097505296979634, 45.81930848530361, 45.413940157209126, 46.82391725267683, 44.448018959590364, 40.21821968896048, 33.34122276306152, 38.83124113082886, 44.020968777792795, 49.786007268088206, 49.53141137531826, 28.53130623272487, 0.19313849269279412, 3.1740222317831854, 4.853491723537445, 2.8298123819487433, 0.5981724251593862, 3.821098412786211, 54.18018702098301, 44.8834729875837, 46.216731548309326, 33.91162122998919, 22.119032621383667, 29.64558015550886, 43.929530484335764, 15.969347068241664, 0.055052171993468485, 0.018906199340043322, 0.02507328029189791, 0.02925047418102622, 0.04967925690912774, 0.021466876845806837, 0.04437968806762781, 0.0182435064177428, 0.044698887903775485, 0.03057195505659495, 0.03934645779164774, 0.041259387108896456, 0.018687256445576037, 0.02340010114546333, 0.030724588116364818, 0.06766725757292338, 0.03196253454578774, 0.029777061460273604, 0.03607106069102883, 0.017309823572369556, 0.024360706564038992, 0.05770387327564614, 0.061693034933081696, 0.040458664896764925, 0.07424794124173266, 12.602132780211312, 54.41722134181431, 42.12675782612392, 27.947763511112758, 17.84480309486389, 43.526100703648154, 46.43023579461234, 55.57090023585728, 48.59486716134207, 54.541239738464355, 35.37228543417794, 2.404946105820792, 1.305096100483622, 10.01721009186336, 10.640306302479335, 3.6579607895442416, 58.11782496316092, 47.747513498578755, 51.95800025122506, 41.55826316561018, 44.82643175125122, 41.29366881506783, 43.91894142968314, 39.19668858391898, 37.157329763684956, 36.36990083966936, 44.02584293910435, 44.710129329136436, 46.333464758736746, 45.53907373973301, 46.34761129106794, 47.12642444883074, 47.12409332820347, 45.9940139906747, 45.24045058659145, 46.739319460732595, 46.60202305657523, 49.06612525667463, 48.99253341129848, 48.06898580278669, 47.657645498003276, 45.934822286878315, 47.53117438725063, 44.489319052015034, 44.202386243002756, 38.33108895165579, 35.30059739521572, 35.57390478679112, 37.017636231013704, 37.17471415655953, 35.7919670513698, 34.29559258052281, 34.70978512082781, 37.459267207554404, 38.56270367758614, 40.1029942376273, 38.469896589006694, 38.15190880639212, 37.96610355377197, 36.39414657865252, 36.91616473879133, 35.129939215523855, 35.86203268596104, 36.11051068987165, 37.21473230634417, 35.867900439671104, 36.36735085078648, 32.31354597636631, 34.585867473057334, 39.18847581318447, 41.96187359946114, 40.39467961447579, 40.1476468358721, 46.003241198403494, 50.705934865134104, 46.76935999734061, 48.29480920519148, 45.963393279484336, 45.31595318658011, 41.50377886635916, 40.09591402326311, 36.07554735456194, 35.64325475692749, 34.53142138889858, 34.95307976858956, 36.61842748097011, 35.417928150721956, 35.74396889550345, 35.09950263159615, 35.42434481212071, 35.94787767955235, 35.72582367488316, 36.46972213472639, 36.471483503069194, 36.23399060113089, 36.18437351499285, 35.21953623635428, 34.71224478312901, 35.40011644363403, 35.00610842023577, 35.00543791907174, 35.61186279569353, 35.45779691423689, 35.64002731868199, 34.528940882001606, 32.671381677900044, 34.20674249104091, 34.06161894117083, 34.66936050142561, 34.43216289792742, 35.56080395834786, 43.181626388004844, 45.8403719493321, 45.18902349472046, 45.141932078770225, 43.14829240526472, 43.79250853402274, 44.667304107121055, 44.61745078223092, 46.63451978138515, 47.64618444442749, 46.728772095271516, 49.093921525137766, 47.91889429092407, 50.85718672616141, 47.15788241795131, 48.22656052453177, 47.77954469408308, 48.59662158148629, 45.822237151009695, 41.76149102619716, 35.62350450243269, 40.175099168504985, 45.744194984436035, 52.460358483450754, 50.29041174479893, 31.53403799874442, 0.19103571267000266, 2.995019699845995, 8.170733264514379, 6.109772929123469, 0.7663453753505434, 4.835990948336465, 58.79809529440743, 48.96042231151036, 50.379571029118125, 40.09080014910017, 27.71727786745344, 32.42905977794102, 48.14710439954485, 20.739688396453857, 0.06276419745492083, 0.06220587170017617, 0.013211554332104112, 0.01051560154051653, 0.048452940569924455, 0.019590898849336163, 0.046663396060466766, 0.019295234000310302, 0.09948945072080408, 0.013543017840545093, 0.03218337733830724, 0.14842376778168337, 0.1281697688890355, 0.11664795928767749, 0.09760268910654954, 0.12635782254593714, 0.0988661688087242, 0.16769604863865034, 0.13197131561381475, 0.13201233984104224, 0.1893812950168337, 0.14699690363236836, 0.17232508238937172, 0.18289743150983537, 0.2423342221549579, 13.474983726228986, 65.1693571635655, 51.484268597194124, 39.08464888163975, 23.777883768081665, 46.18481499808175, 50.362019879477366, 62.394969258989605, 51.987401553562705, 59.27809769766671, 41.282676764896934, 3.0442563721111844, 2.5128008212362016, 15.769584621701922, 9.817692569323949, 5.347067432744162, 60.27300330570766, 50.52085222516741, 53.54052196230207, 43.915321418217246, 46.585250105176655, 44.27947303227016, 46.03576224190848, 41.78904758180891, 39.71807793208531, 39.298371996198384, 46.89716863632202, 46.5182659966605, 48.267408984048025, 48.55632550375802, 47.97080428259713, 48.962881973811555, 48.08111388342721, 47.56806237357003, 47.117975439344136, 48.90877635138375, 48.60843004499163, 50.646534715379985, 51.35892309461321, 50.04234021050589, 49.51603501183646, 46.67324556623186, 48.33307988303048, 46.22361026491438, 46.904391288757324, 40.478172642844065, 38.213462897709434, 37.926512718200684, 38.66686759676252, 39.54228850773403, 36.63797276360648, 38.00984941210066, 35.78096110480172, 39.04690626689366, 39.60931430544172, 41.11102499280657, 41.69147055489676, 38.95958825520107, 39.78368629728045, 38.27637536185128, 38.08293751307896, 37.32410042626517, 38.035651547568186, 37.753346238817485, 39.79737772260393, 37.118517126355854, 37.4600419316973, 35.12119490759713, 37.8029911177499, 40.7659774507795, 43.71816280909947, 42.58902842657906, 41.57399736131941, 47.63147163391113, 52.43294784000942, 48.64184740611485, 50.67222567967006, 47.58154535293579, 46.29724727358137, 43.52450609207153, 42.07927731105259, 38.19475834710257, 39.32927410943167, 36.56060109819685, 37.7079883984157, 38.164526735033306, 37.55943591254098, 37.591849258967805, 35.94997256142752, 37.93024042674473, 37.806135177612305, 37.50467021124703, 39.56501259122576, 38.883272715977256, 38.277289049965994, 39.25413976396833, 37.49382059914725, 35.5844521522522, 36.726485865456716, 36.055477482931956, 38.42057132720947, 36.08767543520246, 36.38727133614676, 36.70665223257882, 37.53614207676479, 35.162164960588726, 35.871496132441926, 36.153381075177876, 36.58779634748186, 35.969139167240684, 37.974656786237446, 44.35357557024275, 47.06117391586304, 47.282008511679514, 46.67318650654384, 45.01225437436785, 43.64928184236799, 44.873512744903564, 46.92780671800886, 46.96618856702532, 50.221878187997, 48.39553376606533, 49.863559586661204, 48.686083112444194, 52.74112129211426, 48.40067890712193, 50.22665507452828, 50.32725804192679, 50.653086866651265, 47.40275778089251, 44.261939253125874, 36.52396672112601, 43.52379390171596, 47.00712040492466, 55.629181725638254, 50.97985022408621, 35.00095633098057, 0.30000315766249386, 5.814782381057739, 14.918965305600848, 12.505822931017194, 2.409550807305745, 5.1963240930012295, 65.9023573739188, 52.31400510243007, 54.85514892850603, 44.146946566445486, 32.0102710042681, 40.05159841264997, 55.211553301130024, 26.650305543627056, 0.23177095183304378, 0.2042478344270161, 0.13000973872840405, 0.11834811020110335, 0.09997961084757533, 0.11421075649559498, 0.12179292392517839, 0.06878864525684289, 0.14547773157911642, 0.0981838543500219, 0.08942520897835493], [0.06451594417116471, 0.01007998121037547, 0.016052118203203593, 0.048498833285910745, 0.050263594303812296, 0.05642644967883825, 0.053453350107052496, 0.009257321112922259, 0.017745787410863807, 0.01662301381916872, 0.06126412616244384, 0.030540681377585446, 0.022730424401483366, 0.09709063944007669, 0.6123028897813388, 33.10362563814436, 48.22008827754429, 28.35905691555568, 28.809829984392437, 31.84943757738386, 38.96774891444615, 48.71547746658325, 49.57400730678013, 43.716064453125, 42.666841302599224, 5.4857804008892606, 0.5478290894201824, 4.1088576231684, 5.521964882101331, 0.7758119702339172, 41.99302932194301, 53.41654872894287, 47.21049765178135, 46.932826791490825, 42.31508527483259, 42.837874685014995, 40.967384883335654, 37.10457556588309, 34.1543357031686, 41.97914334705898, 45.784730775015696, 44.509666851588655, 48.41423831667219, 48.37341070175171, 44.766194343566895, 44.37971469334194, 44.066020897456575, 44.40471431187221, 45.5270985194615, 44.74335561479841, 43.93062482561384, 43.402721541268484, 42.97784614562988, 42.44160849707467, 42.948545592171804, 43.101569243839805, 41.536563941410606, 41.58155700138637, 38.689841815403526, 34.43664796011788, 33.34423133305141, 33.65775489807129, 33.37994507380894, 35.00303384235927, 34.66569185256958, 34.643940516880576, 35.15831218447004, 35.5237318447658, 36.952330112457275, 36.18520382472447, 36.49179308755057, 36.31262336458479, 35.2109899520874, 36.026062284197124, 34.68225635801043, 33.34192453111921, 34.01417316709246, 35.96346596309117, 37.09591811043875, 35.920880453927175, 32.87161486489432, 31.177053451538086, 32.19391189302717, 35.212442125592915, 37.12403399603707, 39.519998686654226, 39.95887817655291, 43.360473019736155, 47.99816976274763, 48.195609773908345, 45.74530669621059, 47.13916744504656, 43.592414311000276, 36.98692866734096, 36.824111529758994, 33.59023577826363, 32.546519075121196, 31.959010669163295, 33.363741874694824, 34.38841009140015, 33.986137185777935, 35.332854407174246, 35.40279150009155, 35.42207275118147, 36.17601483208792, 33.724739006587434, 33.780609471457346, 34.99767330714634, 36.255120073046, 34.44760874339512, 33.864147663116455, 34.54879188537598, 34.146741322108674, 33.881271498543875, 33.55461236408779, 34.58752114432198, 34.76954657690865, 32.27599791118077, 32.97578920636858, 32.140268325805664, 31.544856343950542, 31.776606559753418, 32.99794006347656, 32.04755851200649, 33.240466935294016, 35.54849869864327, 40.96762807028634, 44.36679104396275, 43.59524917602539, 43.09353017807007, 44.24109813145229, 43.40737336022513, 45.4333291053772, 45.44694062641689, 45.4993508883885, 43.43463461739676, 44.14682844706944, 44.28352383204869, 48.33964245659964, 45.828379358564106, 43.84152112688337, 45.34390231541225, 47.943466595241, 45.207620348249165, 43.7815442766462, 38.54886286599295, 37.4370572907584, 44.917828355516704, 48.84034354346139, 50.47319105693272, 22.53932568005153, 1.8440770932606287, 2.5875623524188995, 3.909254550933838, 4.633071414061955, 0.5274670134697641, 6.408847280911036, 51.26298931666783, 42.33172621045794, 41.316372053963796, 27.469023942947388, 19.94319554737636, 20.599760362080165, 45.55536726542881, 9.087140730449132, 0.08747366084051983, 0.04088930053902524, 0.023376062346090163, 0.033207452922527275, 0.01606875248918576, 0.015779584612963454, 0.03797017842797296, 0.023689810153363005, 0.04921223482649241, 0.0081367807496073, 0.03396738839468785, 0.010534259557191814, 0.018557271188391105, 0.035381404483424764, 0.030583866738847325, 0.09056794337396111, 0.06323991157114506, 0.0324859734225486, 0.07133178772138697, 0.059051593100386005, 0.0784803916301046, 0.0381938167847693, 0.03509341386545982, 0.016554966934823563, 0.06182896585336753, 1.3258655688592365, 41.39629370825631, 53.50232424054827, 31.54636410304478, 27.952962500708445, 36.70979976654053, 44.39865548270089, 58.35910810743059, 52.04187543051583, 51.03213194438389, 45.60791301727295, 5.747500802789416, 0.8139021034751619, 4.08745847429548, 9.690718582698278, 1.8197439589670725, 46.47560405731201, 55.72832557133266, 48.731076172419954, 49.483336789267405, 43.51247181211199, 46.31615679604666, 42.702134677342, 38.52608667101179, 35.14746952056885, 42.992329665592735, 45.92569930212838, 46.881840910230366, 48.58947535923549, 48.727827889578684, 45.74373640332903, 44.824163164411274, 43.92879050118582, 47.04056208474295, 47.624759674072266, 45.827066149030415, 44.28604255403791, 45.1212021282741, 46.715025084359304, 44.73794296809605, 45.35726717540196, 44.195524896894185, 45.64155272075108, 43.82011720112392, 41.129552364349365, 35.37930658885411, 35.04552902494158, 35.072279589516775, 35.168407917022705, 36.41858686719622, 35.98157296861921, 36.1728811945234, 36.635982104710166, 36.834023135049, 37.31897265570504, 37.656644684927805, 38.32664557865688, 36.92789329801287, 36.227441923958914, 36.70472410746983, 36.17284992762974, 35.373765400477815, 35.39493656158447, 36.707680565970286, 36.02389792033604, 36.285747732434956, 33.37385150364467, 32.926578589848106, 35.44296251024519, 37.19598606654576, 39.61330951963152, 40.13295486995152, 41.00981405803135, 43.473954473223, 48.90330464499337, 50.09473310198103, 47.81304543358939, 47.626927512032644, 43.72142498833792, 39.14490713391985, 37.85390404292515, 35.04567493711199, 34.16286809103829, 33.98334400994437, 34.42073311124529, 35.10778488431658, 36.40959937231881, 36.60276624134609, 36.34060723440987, 38.15674475261143, 37.600166252681184, 35.82195895058768, 36.09990079062325, 37.0606038911002, 37.26483576638358, 35.63478490284511, 34.608344895499094, 37.64377314703805, 36.3707971572876, 35.761269909994944, 34.63922963823591, 34.95536225182669, 35.84383882795061, 33.62346206392561, 35.50265448434012, 33.45455830437796, 35.02337121963501, 33.56119578225272, 34.237846102033345, 34.42415509905134, 34.10441289629255, 37.05255787713187, 43.524645056043354, 45.228656019483296, 45.67590461458479, 43.910836356026785, 46.68413686752319, 43.75101389203753, 45.707338265010286, 46.873916489737375, 46.86662088121687, 44.730897494724815, 46.64857251303536, 46.07051713126046, 48.241075311388286, 47.91458640779768, 46.788394587380544, 46.55907276698521, 50.101656981876914, 47.50596284866333, 46.10164506094796, 39.813132762908936, 39.38998746871948, 47.48042474474226, 49.82363871165684, 49.945812361580984, 24.30091462816511, 2.179676822253636, 2.827913135290146, 6.593536913394928, 4.950037811483655, 0.3800808478678976, 6.671187375273023, 57.044276169368196, 47.44262307030814, 46.99248055049351, 32.19299473081316, 14.72763102395194, 24.006877286093577, 52.603168283190044, 12.20927381515503, 0.043053542263805866, 0.042361996336174865, 0.041604917496442795, 0.06031750195792743, 0.034725067737911425, 0.014227818281921958, 0.022329126917091862, 0.011256916315427848, 0.019876858951257806, 0.02758636195877833, 0.01426208854120757, 0.1330624677773033, 0.14901095841612133, 0.10458724360380854, 0.14311957811670645, 0.1438416072300502, 0.16363819209592684, 0.16378056231353963, 0.1428389631743942, 0.15831631980836391, 0.13023483593549046, 0.1332498248666525, 0.14601171149739198, 0.10165669835571732, 0.18298405329031603, 1.6002239840371268, 47.23913812637329, 62.90698201315743, 39.65229933602469, 37.760627950940815, 42.04840299061367, 50.76575190680367, 55.74861431121826, 57.29584264755249, 53.83990246909005, 53.937879017421174, 7.379914488111224, 1.014269151857921, 11.55085643700191, 14.912446158272878, 2.3722174848828996, 46.66992432730538, 58.75102819715227, 52.4915315764291, 52.09119027001517, 45.074336528778076, 47.6138197353908, 44.952499866485596, 40.394926275525776, 36.70440101623535, 46.79007952553885, 49.00535978589739, 48.40730748857771, 51.934716837746755, 52.376365184783936, 45.89164618083409, 44.64089053017752, 45.14844601494925, 49.26292950766427, 49.817030974796836, 48.63734149932861, 46.29108769553048, 47.0051714352199, 48.74470853805542, 46.03194768088204, 45.39900847843715, 47.14287083489554, 46.885766642434255, 46.48373344966343, 42.16564689363752, 38.55365364892142, 38.15101596287319, 37.347199712480815, 37.00812414714268, 37.37666702270508, 38.04909283774239, 38.034637110573904, 37.319483348301475, 38.24455261230469, 39.42954008919852, 38.6016274860927, 39.55286019189017, 37.37270654950823, 37.85792357581002, 39.252562522888184, 37.626923765454976, 36.29597200666155, 36.8821394102914, 37.43216923304966, 40.517120770045686, 37.67859057017735, 34.896094117845806, 33.96219021933419, 37.13066952569144, 39.544942719595774, 42.583792958940776, 42.96439095905849, 41.9594486781529, 44.69848762239729, 52.5022873878479, 52.51472118922642, 49.27649239131382, 51.09690652574812, 46.594432149614605, 40.471860204424175, 40.53474487577166, 38.69475071770804, 36.24640703201294, 36.382782799857004, 37.0128767149789, 37.22518934522356, 38.88866451808384, 39.88277455738613, 38.242871148245676, 41.246646881103516, 40.002231461661204, 37.59775870186942, 37.81473357336861, 39.35837663922991, 40.442017691476, 36.57341357639858, 36.41512666429792, 38.348549774714876, 36.63178539276123, 37.1765832219805, 36.90939024516514, 37.69595759255545, 38.487416471753804, 35.177075794764924, 37.56764868327549, 35.48565919058663, 36.357512201581685, 34.19584771565029, 36.90264007023403, 36.19114800861904, 36.80349275044033, 39.68735647201538, 46.57956647872925, 48.225452286856516, 48.112092426845, 45.88446174349104, 49.55655690601894, 45.57160867963518, 47.80938025883266, 47.46515955243792, 48.234575271606445, 44.816943986075266, 46.707607882363455, 45.70574712753296, 51.45947395052229, 49.131778785160606, 46.91647073200771, 47.74443544660296, 52.15380048751831, 48.68841770717076, 48.20725148064749, 42.12688636779785, 42.91454805646624, 48.40250628335135, 52.403949533190044, 51.46243388312203, 28.734412499836512, 3.59916513306754, 6.691221637385232, 11.83013493674142, 13.069293175424848, 1.2820061509098326, 8.019057563373021, 61.795805249895366, 52.75056389399937, 52.972399030412944, 37.97362845284598, 29.508832659040177, 30.145176478794642, 59.5984582901001, 15.079213346753802, 0.12103493245584623, 0.14757855742105416, 0.2365344576537609, 0.16963739160980496, 0.07941372333360569, 0.09768362476357392, 0.11289770981030804, 0.10185779577919415, 0.11338091495313815, 0.12084529548883438, 0.11996071652642318], [0.03605436533689499, 0.04804643363292728, 0.03967590011390192, 0.006222134314677013, 0.07709824293851852, 0.007986828751329864, 0.03175412590748497, 0.029461264477244446, 0.05025793532175677, 0.07464881294539996, 0.014205436804331839, 0.09993684278534991, 0.0651061407157353, 0.07427478408707039, 0.025383119737463336, 10.11912453174591, 47.9293270111084, 35.45303392410278, 22.323669229234966, 31.109666347503662, 37.48584059306553, 37.04909420013428, 50.83694314956665, 43.37885100500924, 51.40624032701765, 10.945090770721436, 0.435224710298436, 1.1678392142057419, 34.42728526251656, 1.6803605982235499, 19.697526352746145, 60.2686676297869, 43.72700786590576, 49.33801868983677, 47.13254233769008, 45.189989294324604, 39.533186367579866, 38.65793221337454, 39.83594717298235, 45.284856523786274, 45.22509159360613, 48.049916471753804, 43.597566400255474, 42.733575275966096, 41.09866067341396, 41.52152109146118, 43.299735341753276, 46.01258305140904, 44.144844736371724, 43.736012731279644, 40.88841165815081, 41.078246865953716, 39.69192838668823, 38.2510005405971, 38.6495144707816, 39.35211978639875, 35.734710420881, 36.04701110294887, 34.593225615365164, 33.08202716282436, 32.14340891156878, 33.22274208068848, 34.46214784894671, 34.475592613220215, 34.8618985584804, 34.03421177182879, 32.75827932357788, 35.44827093396868, 34.70293072291783, 35.57837247848511, 33.24236379350935, 35.152517386845176, 34.20424113954817, 34.877049105507986, 34.60205330167498, 34.722239766802105, 34.27632522583008, 36.38181005205427, 36.10522311074393, 36.520190375191824, 32.65746791022164, 31.935668195996964, 31.714920452662877, 33.64983742577689, 36.52191352844238, 37.083150795527864, 37.95306178501674, 45.14493717466082, 47.1992380959647, 46.265334197453086, 47.29918098449707, 48.09991223471505, 40.645610332489014, 37.384629658290315, 36.517789772578645, 34.51476308277675, 34.20625959123884, 33.521799496241975, 31.95992088317871, 33.55646058491298, 33.208446162087576, 35.222002846854075, 33.64725617000035, 34.5264117377145, 33.38149104799543, 34.30346141542707, 33.888886724199565, 33.875191824776785, 33.62219054358346, 34.52829817363194, 33.94608776909964, 35.602055413382395, 33.50375155040196, 34.47978932516915, 34.021055357796804, 32.84531593322754, 34.77887800761631, 33.390770367213655, 33.462381975991384, 32.570031779153005, 33.40947144372122, 32.45949636186872, 31.96263415472848, 32.60023559842791, 32.5729569707598, 33.290976864951, 34.86891276495797, 40.42601599012102, 44.042681898389546, 43.554932253701345, 44.04578079496111, 46.80858257838658, 45.20018230165754, 43.93276834487915, 46.48820808955601, 44.66940246309553, 46.34543650490897, 45.77881785801479, 46.742835249219624, 44.064315114702495, 45.88882521220616, 41.58925213132586, 48.896116733551025, 46.839665344783235, 47.23177303586687, 39.779868262154714, 41.04222740445818, 43.29304770060948, 53.38097047805786, 43.46051665714809, 26.36256500652858, 6.968200283391135, 1.72977814078331, 5.2594137362071445, 1.562715436731066, 0.16545040985303267, 7.138047695159912, 55.05209561756679, 44.03032800129482, 38.77054166793823, 27.593077080590383, 38.03938273021153, 31.052975995200022, 35.57834121159145, 1.2566551055227007, 0.02657267983470644, 0.02352089394948312, 0.03056484740227461, 0.01832859979809395, 0.025990220285685997, 0.05540553946048021, 0.02604381607047149, 0.05168266208576305, 0.050665287034852166, 0.007155855751729437, 0.02801504511652248, 0.04707543305786593, 0.01761540860336806, 0.0324532917833754, 0.019079934838893156, 0.02680150728805789, 0.02825098531320691, 0.05119036118100796, 0.032324312454355617, 0.06746860966086388, 0.007004684510840369, 0.08408626474972282, 0.029913335040743862, 0.047870177376483164, 0.04830232954451016, 0.017391261345307742, 14.785952465874807, 54.39100578853062, 35.01144116265433, 22.616322142737253, 38.72295345578875, 42.88770716530936, 40.26466492244175, 61.44613020760672, 45.16057409558977, 54.72860138756888, 9.831245030675616, 0.2316569308085101, 3.0176801638943807, 34.41552543640137, 3.256328420979636, 21.666117770331248, 63.79706709725516, 44.80398906980242, 52.05163417543684, 48.402818952287944, 47.51327930177961, 41.134377888270784, 40.475942271096365, 40.895140988486155, 48.75613832473755, 46.50101014545986, 50.410803181784495, 45.406119959695, 43.661865030016216, 41.08673061643328, 43.338527134486604, 45.94925022125244, 48.807780810764854, 45.37643378121512, 45.02877719061715, 43.368397440229145, 43.49100187846592, 41.631809847695486, 40.682870047433035, 41.36679513113839, 40.994948387145996, 39.46103627341134, 40.25798075539725, 37.01982838766915, 35.65282590048653, 34.24131325313023, 35.8227927344186, 36.8609995160784, 36.94175842830113, 37.348391328539165, 37.45355231421334, 33.70737893240792, 36.01154054914202, 35.997008391789024, 36.68513366154262, 34.846442290714805, 36.22212307793753, 34.921229226248606, 35.34558003289359, 35.10072204044887, 36.721761090414866, 35.8043452671596, 36.79827812739781, 37.77680335726057, 38.05096190316336, 34.63073546545846, 32.365549768720356, 34.62399918692452, 36.139401299612864, 37.42144468852452, 38.68077789034162, 40.49649156842913, 45.332757404872346, 48.78877748761858, 47.271589687892366, 48.49189485822405, 49.1407002721514, 43.05142756870815, 38.20801551001412, 39.833789757319856, 36.39058910097395, 35.6546949659075, 35.15745060784476, 33.70829956872122, 35.4045980317252, 35.970032010759624, 36.8968174798148, 35.40336125237601, 35.77896697180611, 35.987680435180664, 35.79566696711949, 35.791025570460725, 36.08545895985195, 35.35506432397025, 35.02109221049717, 35.336352825164795, 35.82850067956107, 35.133875370025635, 35.58039093017578, 34.57488931928362, 34.094786167144775, 35.54432283129011, 34.6083379473005, 35.60095412390572, 34.41781486783709, 35.01790993554251, 34.2351884160723, 34.64263078144619, 33.400272028786794, 34.464454650878906, 35.19755561011178, 36.76076480320522, 41.585673809051514, 45.81228733062744, 45.18549728393555, 46.21358401434762, 47.81534876142229, 48.064632756369456, 44.95997960226876, 47.87727805546352, 45.164093358176096, 47.506758417402, 48.00789724077497, 48.843713419778005, 45.27511167526245, 47.432082653045654, 43.941012382507324, 50.79133864811489, 48.554015227726524, 50.62687826156616, 41.542952810014995, 44.21317679541451, 44.896407059260774, 54.54382446834019, 44.70367792674473, 29.62047631399972, 8.618246759687151, 4.330575508730752, 7.008559329169137, 3.503834545612335, 0.260801801191909, 8.17347606590816, 59.89980861118862, 46.12943090711321, 43.728956835610525, 32.393887996673584, 36.20724351065499, 33.20982885360718, 44.03619575500488, 2.2912677143301283, 0.043881371949932406, 0.0054673862427340025, 0.027791907179302404, 0.028465161499168192, 0.0628082479483315, 0.07005368558956043, 0.03598875778594187, 0.00436958994915975, 0.057018960027822425, 0.01957429340109229, 0.039034779516181776, 0.1263182232422488, 0.12235472377921854, 0.1617675931858165, 0.10070137533226184, 0.17813032945351942, 0.10940277270440545, 0.16909526927130564, 0.1412754827844245, 0.1923378485121897, 0.11062713486275502, 0.1571331854377474, 0.20304450685424463, 0.17515734184001172, 0.2201007737645081, 0.09751820471137762, 16.996837990624563, 64.83005578177315, 43.53273275920323, 32.66487468991961, 41.171321460178916, 47.759287221091135, 46.0290607043675, 62.96761894226074, 49.79988282067435, 61.75117697034563, 13.815533178193228, 0.9926688309226717, 7.453227537018912, 51.26955883843558, 4.519764968327113, 24.63427530016218, 63.79694202968052, 48.060317925044465, 53.918962546757285, 51.614304133823936, 49.280411175319124, 44.46691458565848, 43.341400214603965, 44.73024088995797, 48.800280230385916, 49.319480895996094, 52.08399888447353, 46.889942509787424, 42.412016119275776, 41.51239463261196, 45.00674792698452, 48.86774376460484, 51.38709109170096, 47.10007340567452, 47.2074682371957, 45.04300710133144, 45.38942343848092, 44.36580439976284, 41.76215805326189, 44.791089739118306, 44.01254408700125, 40.63430561338152, 40.94588368279593, 38.916061265128, 37.25879430770874, 36.704960346221924, 37.40005465916225, 38.45670543398176, 38.90058067866734, 39.66316979272025, 39.26282153810774, 36.01060601643154, 37.69979647227696, 38.135643073490684, 38.04776573181152, 36.59369189398629, 38.044475759778706, 36.390422344207764, 38.33264882223946, 36.184112957545686, 36.94152218954903, 36.12126650129046, 37.70602900641305, 39.55135243279593, 40.565296104976106, 37.66301270893642, 35.57185159410749, 35.961586475372314, 40.370715277535574, 41.057409218379426, 40.60406010491507, 41.57462269919259, 47.09934731892177, 50.40198591777256, 49.56360237939017, 50.120257309504915, 51.00066702706473, 44.838191577366416, 39.57932588032314, 40.4215795653207, 37.91901213782174, 38.15491042818342, 37.48799453462873, 37.000734737941194, 38.32886552810669, 38.36134488242013, 38.539118017469136, 36.0867200578962, 38.02686207635062, 36.77883359364101, 39.27896915163313, 37.723712171827046, 37.64267185756138, 37.37280035018921, 36.89172445024763, 35.89544309888567, 37.468470096588135, 36.29354361125401, 37.79511186054775, 36.15740755626133, 35.248027324676514, 37.152816908700125, 36.45423807416643, 38.17233998434884, 36.77082232066563, 38.32212577547346, 36.53260680607387, 35.399293082101, 35.28412321635655, 36.70410571779524, 37.47049897057669, 38.5270003591265, 43.6627266066415, 47.84373215266636, 48.126673221588135, 48.242197445460725, 50.461552824292866, 50.244744709559846, 47.8766006061009, 50.31647443771362, 48.32983160018921, 50.0065152985709, 49.45506109510149, 49.83078840800694, 45.95243944440569, 48.949555328914094, 44.609703540802, 53.78851011821202, 50.474466051374165, 50.9203006880624, 43.08299323490688, 47.149541105542866, 46.679523263658794, 57.31257043566023, 44.85498537336077, 33.511526584625244, 11.001887083053589, 6.3194469809532166, 12.17264291218349, 10.505414843559265, 0.46699390986136025, 8.936194590159825, 67.00038814544678, 50.57551370348249, 49.41599137442452, 39.026134627205984, 49.80616399220058, 40.77257476534162, 51.75539772851126, 3.7296727129391263, 0.2036690576268094, 0.12560473009943962, 0.1442528808755534, 0.11054811267448322, 0.2351811874125685, 0.17542327328452043, 0.1888058701796191, 0.11014640637274299, 0.127129411857043, 0.08924442689333643, 0.11995241125779492], [0.04423698876053095, 0.06695901629115854, 0.04925941336633904, 0.0062757178010152915, 0.03816131156470094, 0.03714298317208886, 0.029200639176581587, 0.028622154146432877, 0.03496759311695184, 0.028957550613475696, 0.059201569695557864, 0.02085200198260801, 0.040224465142403326, 0.03939666599035263, 0.021685546629929116, 1.4034302639109748, 36.43837881088257, 42.688676016671316, 28.310417788369314, 22.492559092385427, 43.38073396682739, 39.410467284066335, 42.5292079108102, 43.094145093645366, 47.94380358287266, 20.31164809635707, 0.13301319256424904, 2.8403054646083286, 14.347516792161123, 0.3136629903955119, 12.410434586661202, 57.12030683244978, 45.34159551348005, 53.14203235081264, 48.68041685649327, 47.50592810767037, 44.75866249629429, 45.70504535947527, 42.87578405652727, 44.66028642654419, 46.84487301962716, 47.88946519579206, 38.12473440170288, 42.058040142059326, 40.227888107299805, 45.47684914725167, 44.63698216847011, 46.32307720184326, 44.26454482759748, 42.67102064405169, 37.694050312042236, 38.62408058983939, 36.71138742991856, 36.46862779344831, 33.94578552246094, 35.03568342753819, 33.4532972063337, 34.00869451250349, 32.986715248652864, 33.74388824190412, 33.08476822716849, 32.8029909815107, 32.47863170078823, 34.4689952986581, 34.67377955572945, 34.94846616472517, 33.58917270387922, 34.620684896196636, 35.57842806407383, 36.35675137383597, 35.13577570234026, 36.69048030035836, 35.98146179744175, 34.89959600993565, 35.950886249542236, 35.01632227216448, 35.41219588688442, 36.944954599652974, 34.56924738202776, 35.33437606266567, 32.545198917388916, 32.51793418611799, 33.5727402142116, 32.90354183741978, 34.753805433000835, 37.99549443381173, 41.01082502092634, 45.71077067511422, 46.8635949407305, 47.4213650567191, 45.77636514391218, 47.03166839054653, 41.72509636197771, 39.15942192077637, 38.03507137298584, 38.37809351512364, 37.672437940325054, 37.727936676570344, 35.34529168265206, 34.016080447605674, 34.13594729559762, 34.905731269291465, 33.51768963677542, 34.73656695229666, 34.83335188456944, 34.93371513911656, 34.03700494766235, 34.94973421096802, 33.64425802230835, 33.95484249932425, 33.961450236184255, 35.0338317326137, 34.060604504176546, 33.85956532614571, 33.87022386278425, 34.25295148577009, 32.44943537030901, 31.59957688195365, 32.89127131870815, 32.523888792310444, 32.61512558800833, 32.776983874184744, 32.25949593952724, 33.435516766139436, 32.4373003414699, 32.21284573418753, 32.65051276343209, 32.49845143726894, 35.237924643925254, 38.90570150102888, 41.39145081383841, 39.709955487932476, 41.879864011492046, 42.0689731325422, 42.70287118639265, 43.09335994720459, 44.84953798566546, 42.43364586148943, 46.44350685392107, 46.125362736838206, 47.28318970543997, 42.80502012797764, 44.295537267412456, 45.34935317720686, 47.63878461292812, 43.19017267227173, 44.98941911969866, 44.114481108529226, 49.823583126068115, 42.56869452340262, 25.000900472913468, 0.4232363535889557, 6.431935710566385, 5.075075422014509, 3.0826701394149234, 0.17284667225820677, 10.017139741352626, 54.020545210157124, 45.43421500069754, 40.73933458328247, 21.550112383706228, 18.907307726996287, 38.59581184387207, 22.606382744652883, 0.23190720166478837, 0.08338116508509431, 0.019585565564089587, 0.05457572845209922, 0.010916508019103535, 0.044622152378516536, 0.028565605037978718, 0.02848881183724318, 0.06759717847619738, 0.05783680507114955, 0.0363468919614596, 0.02327276047851358, 0.019067580412541116, 0.05805280990898609, 0.056264463013836315, 0.06838866243405001, 0.024727198594648923, 0.02222990643765245, 0.01679372814084802, 0.06450231918799025, 0.04730416042730212, 0.046200041459607225, 0.0487422882579267, 0.0045378988641979435, 0.04649935343435832, 0.07562009511249405, 0.07070991037679569, 2.2552951531750813, 44.80024746486119, 47.779635020664756, 28.011574029922485, 28.562107597078594, 49.40545443126133, 40.871558802468435, 48.18236998149327, 45.998182909829275, 54.066250460488455, 20.93451588494437, 0.20736985547201975, 2.2511928933007375, 22.274672269821167, 0.6749629388962473, 14.742357730865479, 58.76938533782959, 47.74695416859218, 55.943393162318635, 49.13237633023943, 49.95183644975935, 45.80276135035923, 46.58726508276803, 45.25523982729231, 46.3965995652335, 49.86645351137434, 49.35901614597866, 41.04273809705462, 42.46943603243147, 42.74520308630807, 46.67811972754342, 46.15037277766636, 47.54715871810913, 43.5059300831386, 44.51546164921352, 40.235597133636475, 39.932266575949534, 39.3879759652274, 38.17775610515049, 36.45661783218384, 37.757848671504426, 34.55186646325247, 35.24462965556553, 35.17483500071934, 34.26819930757795, 33.78426769801548, 34.461793490818565, 34.62128244127546, 35.88177251815796, 36.1344507081168, 36.34031193596976, 35.11467054912022, 36.06430516924177, 36.678352219717844, 37.096196038382395, 36.7537054334368, 39.077509607587544, 35.90908241271973, 36.83265086582729, 36.80286741256714, 36.38354015350342, 36.13156720570156, 38.91316039221627, 37.005761759621755, 37.23542404174805, 33.60907234464373, 34.58086477007185, 34.42192472730364, 35.42461231776646, 35.827941349574495, 38.37168032782418, 43.200605392456055, 46.87899562290737, 46.90301207133702, 47.03254038946969, 47.81622423444475, 49.58495419366019, 42.574093273707796, 40.216500009809224, 39.56612777709961, 39.1766881942749, 39.64963470186506, 39.127140590122764, 36.523657526288716, 34.67202860968453, 36.536605494362966, 35.24731860842024, 35.58151306424822, 36.11321701322283, 37.36090850830078, 36.39421953473772, 34.58118438720703, 35.77883495603289, 35.14037193570818, 34.57410069874355, 36.16011387961251, 36.74253273010254, 35.67350026539394, 35.17044373920986, 36.29676410130092, 35.68557970864432, 33.72528444017683, 33.866968631744385, 35.3605568749564, 34.654942989349365, 33.30753442219326, 34.56779520852225, 34.82683447429112, 34.43781525748116, 33.219115121024, 34.12067515509469, 34.5012766293117, 34.31889336449759, 37.816331659044536, 40.285686697278706, 43.5960864339556, 42.44995675768171, 43.689758573259624, 42.77870382581438, 45.976914473942344, 44.50822510038103, 46.86303908484322, 45.305419717516216, 47.48061582020351, 47.52410112108503, 48.573286056518555, 43.15773153305054, 46.360184056418284, 47.36005762645176, 50.89153514589582, 45.55783387592861, 46.47144903455462, 46.06608418055943, 52.36037737982613, 43.45370742252895, 26.41595322745187, 1.4238311520644595, 8.853922707693917, 6.765023231506348, 2.3380831565175737, 0.21617756571088517, 10.339346817561559, 60.390330587114605, 48.117386954171316, 48.300878456660676, 27.932798828397477, 22.860778876713344, 45.6731253351484, 29.14447954722813, 0.24569063633680344, 0.05382225602599127, 0.04091326978855899, 0.03914482093283108, 0.08794322742947511, 0.0212763747466462, 0.019464957660862377, 0.038550414078469784, 0.05810272294495787, 0.09605157162461962, 0.06068061997315713, 0.0270855267798262, 0.08653871422367436, 0.17371603846549988, 0.1487271407885211, 0.18185752231095517, 0.10919361428490706, 0.18775137247783796, 0.13640497199126653, 0.09877466157610927, 0.21175332739949226, 0.2011740165097373, 0.09746795240789652, 0.137557287301336, 0.14834530199212687, 0.13486952866826737, 0.2376867729638304, 2.525869297129767, 51.86959832055228, 55.5493677684239, 37.76433481488909, 31.32696431023734, 53.271904604775564, 47.06599596568516, 52.58640922818865, 51.14745119639805, 56.343786580221995, 25.856253249304636, 0.2728031857737473, 8.97773700101035, 23.181156839643204, 0.9216788687876293, 16.74671847479684, 60.05533014025007, 49.32457045146397, 57.80421107155936, 52.24215725490025, 51.43969937733242, 48.063430718013215, 48.60407699857439, 48.12653078351702, 48.08068309511457, 52.68366316386631, 51.28959744317191, 41.38763277871268, 44.644322940281455, 43.711162499019075, 48.777615206582205, 49.38060072490147, 49.22328656060355, 46.99743809018816, 47.299253940582275, 42.45054040636335, 43.36414514269148, 40.99811329160418, 39.836475236075266, 38.72029229572841, 40.087065492357524, 36.12756504331316, 37.43442392349243, 37.095647130693706, 36.27976185934884, 35.49646363939558, 36.27076741627285, 35.92796414239066, 37.21564252035958, 38.15554966245379, 37.83153779166085, 36.81685413633074, 36.877466746738975, 38.2545336995806, 37.097901821136475, 37.983453205653596, 41.850389753069194, 38.59939364024571, 39.53345039912632, 38.789100306374685, 37.75750820977347, 37.766613824026926, 40.12470735822405, 38.52450942993164, 38.16864006859915, 36.668180056980674, 36.3688759803772, 37.09523023877825, 36.92721584865025, 38.916432993752615, 41.177599157605854, 46.01548739842006, 47.701078687395366, 47.255546297345845, 49.27739913122994, 49.4860292162214, 51.77205950873238, 43.687007086617605, 42.33508219037737, 43.163071223667686, 42.66130011422293, 41.67288064956665, 40.57823365075247, 38.88588176454817, 37.24914673396519, 39.925106457301546, 38.551423277173726, 37.089438915252686, 38.00734806060791, 37.585780007498606, 38.384378160749165, 37.334012031555176, 38.47548641477312, 37.38652651650565, 36.092761516571045, 39.33697618756975, 39.027576378413606, 37.25836699349539, 38.177801268441335, 37.223862239292686, 37.494925362723215, 35.20317322867257, 34.64079993111746, 37.68006011417934, 36.32969161442348, 35.56894724709647, 36.27143096923828, 36.10500076838902, 37.39274862834385, 35.79652506964547, 35.055541379111155, 35.838839599064414, 37.027026721409385, 37.90190914699009, 42.46827915736607, 45.07539612906319, 44.288839203970774, 47.37270334788731, 45.58305583681379, 49.257353578295024, 47.99669327054705, 48.92113024847848, 47.283919266292024, 50.84999186652047, 49.65390116827828, 50.34794977733067, 43.33181517464774, 46.57572759900774, 48.705927167619976, 51.789384841918945, 46.73874276024954, 49.83388730457851, 47.832879066467285, 55.42049605505807, 44.39839839935303, 30.146996906825475, 1.5916895334209715, 15.395856652941022, 15.33916630063738, 7.314856767654419, 0.578398231949125, 12.811026896749224, 64.8619202205113, 52.081497532980784, 52.240437575748985, 30.544197627476283, 27.124688591275895, 50.559831619262695, 35.58042914526803, 0.5390842386654445, 0.20019882598093577, 0.16392670518585614, 0.16195306394781384, 0.2119645689214979, 0.0855932706700904, 0.09094408926154886, 0.10867734413061823, 0.15481855321143353, 0.23723717566047395, 0.14460048079490662, 0.08148486326847758], [0.013906877155282667, 0.01443517773545214, 0.03863147526447262, 0.029291803749012094, 0.012825510314931827, 0.03917464593957577, 0.04749649457101311, 0.0011358807678334415, 0.05629250008080687, 0.06969327492905514, 0.051358023791440895, 0.03047478205657431, 0.05950328707695007, 0.05305191861199481, 0.02128617788132812, 0.051699907053261995, 18.961757285254343, 50.08151762826102, 31.342375414712087, 27.10557062285287, 36.9377111026219, 37.64369671685355, 55.19513818195888, 42.26579475402832, 49.502475602286204, 28.532878262656077, 0.15072489716112614, 1.5131555646657944, 5.279562643596104, 3.4115175221647536, 9.29681043965476, 47.48664338248116, 49.49911962236677, 51.066410882132395, 48.9630035672869, 48.94158921922956, 46.19076265607561, 46.779500893184114, 46.23113863808768, 50.43620579583304, 46.126040186200825, 43.768016133989605, 44.562146595546174, 44.95558834075928, 43.44617210115705, 44.20936223438808, 43.60210357393537, 46.70645100729806, 43.661298751831055, 43.11141831534249, 39.97353540148054, 38.49578210285732, 36.433598450251985, 36.118768623897004, 33.92802940096174, 33.33992692402431, 33.288141999925884, 33.61904648372105, 33.2988144329616, 33.50943170275007, 31.223144326891216, 34.16873237064907, 33.84344203131539, 34.429407937186106, 34.4115753855024, 35.21734407969883, 35.14562824794224, 34.93117209843227, 36.2877071244376, 36.02690301622663, 33.37916340146746, 36.294766494206016, 36.49240452902657, 35.41654198510306, 34.557254791259766, 35.04564714431763, 35.68561097553798, 36.24708795547485, 35.490859917231965, 36.2964688028608, 34.128898348127095, 32.39560767582485, 32.26339387893677, 31.712276663099015, 33.606359073093955, 38.52875477927071, 45.42819786071777, 47.787653241838726, 57.05049480710711, 46.33489261354719, 42.79255853380476, 47.81612695966448, 42.89534323556082, 39.02096169335501, 38.22734887259347, 40.7140222958156, 40.89546755381993, 39.27864258629935, 37.9587071963719, 35.77488143103463, 32.203896454402376, 33.59400865009853, 32.47222893578665, 34.16629007884434, 35.2328177179609, 36.37123836789812, 32.79729693276541, 35.78099584579468, 32.60639517647879, 34.38272646495274, 32.99024840763637, 35.666506903512136, 32.73813302176339, 34.045356682368684, 32.463501998356406, 33.11606291362217, 34.065749645233154, 32.63686302730015, 32.214384760175435, 33.4924989427839, 32.07997185843331, 32.387551239558626, 32.838829789842876, 33.650521823338096, 33.13147054399763, 33.786029066358296, 32.1918934413365, 32.23443031311035, 29.97569601876395, 31.19394452231271, 31.82213463102068, 34.76919221878052, 33.681615012032644, 33.90985638754708, 36.17974601473127, 39.62141806738717, 39.38189629146031, 41.01350702558245, 41.853735310690745, 42.83108976909092, 45.621458530426025, 45.99610192435128, 43.35318088531494, 44.203525747571675, 47.53377301352364, 45.65317358289446, 46.098108427865164, 46.94730683735439, 50.79199872698103, 40.998144558497835, 6.046165210860116, 4.069841316768101, 14.343485099928719, 4.778188015733447, 1.3054907364504678, 0.21629134246281215, 18.112996612276348, 53.5312773840768, 41.893343516758506, 31.337963308606827, 21.83838098389762, 37.549889087677, 42.44868871143886, 9.69548417840685, 0.2469590354178633, 0.06488011391567332, 0.02668433277202504, 0.02904686957065548, 0.054654696357569525, 0.1319708949221032, 0.02620515812720571, 0.0063164994519736084, 0.04977843837280359, 0.010831087245605886, 0.06430223278169121, 0.07682201133242675, 0.009732044568019254, 0.012096321808972528, 0.04497843076075826, 0.07150851895234414, 0.023078039587874497, 0.07301376068166324, 0.029122994414397647, 0.012172282107972672, 0.01181090877590967, 0.03478638694754668, 0.08124122169933148, 0.018719059381900088, 0.018717990689245716, 0.03279470685603363, 0.06852521082120282, 0.15994153331433023, 24.19994166919163, 57.15802165440151, 33.80628306525094, 28.07679155894688, 47.69572162628174, 41.237614222935264, 54.035421303340364, 45.99820375442505, 54.01077256883894, 30.215328965868267, 0.0723304623471839, 2.119938382080623, 11.733450753348214, 3.4314972843442644, 10.669290712901525, 51.76381547110421, 50.841525486537385, 53.13578244618007, 50.10961266926357, 50.51971966879708, 46.515438079833984, 48.853576387677876, 48.296532358442036, 51.06512893949236, 47.18751995904105, 43.27140753609793, 44.314978327069966, 45.99098457608904, 43.99293279647827, 45.292607239314485, 45.635900361197336, 48.261013167245046, 44.98269673756191, 43.21013137272426, 43.13355527605329, 41.30079419272286, 36.704713685171946, 37.62085798808506, 35.34504154750279, 34.80657352719988, 34.82538577488491, 36.461238384246826, 35.39469337463379, 35.570413316999165, 34.49249758039202, 35.4220484324864, 36.132265499659944, 36.51064355032784, 35.60378551483154, 36.370237827301025, 35.92043229511806, 36.93539387839181, 36.111222880227224, 36.29051072256905, 35.45201601300921, 38.35064813068935, 36.52391113553728, 36.870515074048726, 36.98422581808907, 36.90575633730207, 36.3912422316415, 36.3824006489345, 37.50342648369925, 37.360467297690256, 36.27530458995274, 34.665316649845664, 33.5735844203404, 33.57237195968628, 35.809462615421836, 40.80971983500889, 44.44303362710135, 48.88962711606707, 49.758565357753206, 45.97588961465018, 46.14181954520089, 50.0755352292742, 44.102714334215435, 39.89262362888881, 38.81401307242257, 41.21623114177159, 40.01765993663243, 42.158486774989534, 39.721086502075195, 37.637898445129395, 34.29214627402169, 34.987428188323975, 34.73138359614781, 35.61861297062465, 37.06918839045933, 37.5106143951416, 34.184362343379426, 36.15391261237008, 33.88070522035871, 35.80482121876308, 35.746914931706016, 36.93850667136056, 34.13669075284685, 35.71832309450422, 34.92091308321272, 36.2850216456822, 35.03748648507254, 35.10532522201538, 34.3144291469029, 34.620254107883994, 33.747473512377056, 35.225681918007986, 34.83537381035941, 34.55464921678816, 34.34059953689575, 33.29633392606463, 33.260078225817, 33.91103063310896, 31.331748144967214, 33.40317637579781, 34.16292020252773, 36.77929564884731, 36.26458699362618, 37.205133369990754, 38.34610400881086, 42.09700911385672, 41.26874910082136, 43.99699401855469, 43.165909562792095, 45.64852523803711, 46.45325517654419, 47.85924400602068, 44.41292708260672, 45.73635394232613, 50.51180567060198, 49.19353437423706, 47.719328130994526, 49.44619171960013, 52.27814892360142, 44.63676677431379, 8.898915767669678, 6.999028137751988, 15.94679147856576, 8.71743403162275, 1.4875325624431883, 0.164588846798454, 18.696992703846522, 59.133929525102886, 44.8101555960519, 38.80765199661255, 22.069452013288224, 32.62762539727347, 49.19335719517299, 12.658919538770403, 0.31436470417039736, 0.06402454232530934, 0.09250025504401752, 0.020447866525501013, 0.04700107919052243, 0.030801591662956134, 0.043794991049383364, 0.04236758067937834, 0.010562998907906669, 0.0736116993107966, 0.026170907375801886, 0.05921036350939955, 0.10048003720917872, 0.18938271994037287, 0.140347776136228, 0.11400769810591425, 0.10992441685604197, 0.23460380839450018, 0.12887218834034034, 0.0810574269188302, 0.0997898585296103, 0.18607282611940587, 0.1721991462899106, 0.13994947608028138, 0.1893095060118607, 0.1494581401348114, 0.16277392847197397, 0.2312701658478805, 29.18017939158848, 63.811366489955354, 40.558889865875244, 36.48582805906023, 47.944355964660645, 47.01998152051653, 63.53635678972517, 50.97092178889683, 59.135791642325266, 35.16107756750924, 0.27724246042115347, 3.9526820949145725, 15.288088355745588, 8.536532470158168, 16.623624188559397, 51.24305146081107, 51.150178364345, 56.29973152705601, 52.958610330309185, 52.34907266071865, 48.1724305834089, 50.88385738645281, 50.474532059260774, 53.479339599609375, 48.27062947409493, 43.889647824423655, 44.96699380874634, 47.17389106750488, 44.66543156760079, 47.43509122303554, 46.03344849177769, 51.18403346197945, 47.20244468961443, 46.21603672845023, 44.49074343272618, 44.98129667554583, 39.03575440815517, 40.74867296218872, 36.96179355893816, 38.30767352240426, 37.78272322246006, 38.78895786830357, 37.04981333868844, 38.050930636269705, 36.01142937796456, 37.166768891470774, 38.57717330115182, 38.70311982291085, 39.42936985833304, 38.19007873535156, 38.2958059992109, 38.85376719066075, 38.2254763330732, 38.79976231711251, 35.12112889971052, 40.8141701562064, 39.2487062726702, 38.599810532161165, 37.8554048538208, 37.79054341997419, 37.045119830540244, 38.75237560272217, 38.87511553083147, 39.294057164873394, 37.54486901419503, 36.358231340135845, 36.18686097008841, 36.078079972948345, 37.05564635140555, 42.06777804238455, 47.30898836680821, 51.741595132010325, 52.12182487760271, 43.729335512433735, 45.5429230417524, 51.885725089481895, 46.883793354034424, 41.451000349862234, 41.188275064740864, 44.11901133401053, 44.451923847198486, 43.3474451473781, 43.016926288604736, 39.09342793055943, 37.39330448423113, 37.60411630358015, 37.02367421558925, 37.036726406642366, 39.23929146357945, 39.44811609813145, 35.107472215379985, 39.1126640183585, 35.103115694863455, 36.9938907623291, 37.38415370668684, 38.38013628550938, 34.870469161442344, 37.19688933236258, 35.52043839863369, 37.63592168263027, 36.97610684803554, 36.444291727883474, 36.332978112357004, 36.316875662122456, 34.90741968154907, 35.77689640862601, 37.71116372517177, 36.57722813742501, 37.67938961301531, 36.23559216090611, 35.14220626013619, 35.900445801871165, 32.88012988226754, 34.50008501325335, 36.06357560838972, 39.361767360142295, 38.43937315259661, 38.439404419490266, 41.285980633326936, 44.341259888240266, 43.13596977506365, 45.81622348512922, 44.313852718898225, 48.185583523341585, 48.5220604624067, 48.520344257354736, 43.48935168130057, 45.63574055262974, 51.585448265075684, 50.0742324420384, 49.28490318570818, 51.106877190726145, 53.42237826756069, 47.439791679382324, 10.379525644438607, 7.736802629062107, 25.90649046216692, 15.122066361563546, 5.19905994619642, 0.6706398565854345, 22.31521327154977, 62.56534603663853, 49.69358580453055, 41.87145669119698, 30.872420106615337, 46.49269315174648, 56.9187639100211, 17.634512390409196, 0.38133909606507843, 0.19699243589171342, 0.14176545292139053, 0.13240694866648742, 0.24290435441902705, 0.23435522030506814, 0.09223281725176743, 0.10002552052693707, 0.15549449622631073, 0.1340364505137716, 0.13404466078749724, 0.16449902233268532], [0.05563501321843692, 0.09927020927092858, 0.04141826947618808, 0.012506567473922457, 0.02717292378656566, 0.03504004369356802, 0.1522193569689989, 0.03737240264724408, 0.044997908108468564, 0.04565439073901091, 0.05567089415022305, 0.047505590332938094, 0.012275617902300187, 0.021021075945879732, 0.006018803238735667, 0.03983029397204518, 4.494827449321747, 42.36730098724365, 42.069838183266775, 25.455715656280518, 29.384522438049316, 36.77787126813616, 43.9377258845738, 47.284204142434255, 43.4286869594029, 39.491031646728516, 1.5254523562533515, 1.5230426341295242, 4.896336053098951, 6.489347372736249, 30.184819425855363, 20.475371973855154, 50.01821953909737, 46.50830922807966, 49.59161751610892, 48.076858111790244, 49.82101924078805, 48.322376183101106, 49.073483398982454, 44.305389813014436, 44.440577438899446, 44.72164249420166, 47.44486733845302, 45.780638286045615, 46.473255566188264, 44.94157382420131, 46.62572683606829, 45.11677612577166, 46.169970171792166, 42.26358870097569, 40.69482789720808, 38.24092565264021, 38.78081457955496, 36.460800647735596, 35.410535267421174, 32.90870434897286, 32.57243932996477, 33.29301963533674, 32.5484367779323, 32.66302299499512, 33.331790583474294, 32.758289745875764, 34.04041998726981, 35.57802506855556, 35.88848795209612, 33.95608970097133, 35.55590200424194, 33.67391640799386, 35.41449574061802, 35.521334716251914, 35.55711793899536, 36.590506144932334, 35.25611850193569, 36.43955305644444, 36.966796261923655, 34.68755783353533, 35.94762059620449, 35.18823112760271, 36.030891282217844, 35.57327250071934, 35.38344771521432, 32.19706984928676, 33.48561675207955, 32.524805954524446, 37.68550055367606, 40.20182541438511, 45.315272263118196, 46.033976554870605, 55.03672620228359, 55.912737710135325, 44.14870793478829, 47.32149165017264, 42.64978347505842, 41.88905995232718, 42.00515740258353, 43.500882216862266, 42.558101994650706, 43.881174496241975, 43.33142260142735, 38.82455696378435, 35.04970489229475, 32.15970938546317, 33.216763155800955, 33.603854247501914, 32.97115475790841, 32.93534026827131, 33.497498171670095, 33.244031361171174, 32.74810716084072, 32.27653292247227, 33.33298914773123, 35.49135323933193, 32.74259723935808, 33.68832697187151, 32.64174066271101, 33.50936916896275, 33.40454517092024, 32.95842218399048, 31.536278792790004, 30.868803569248744, 32.04417821339199, 32.11538335255214, 31.62027903965541, 32.18792254584176, 32.84521171024868, 31.61302512032645, 31.856948580060685, 30.752306597573416, 32.297426155635286, 30.371246542249406, 30.72770302636283, 29.952211107526505, 31.222717012677872, 31.296340124947683, 31.12027277265276, 31.447091715676443, 33.644733973911826, 33.871238299778526, 38.58586549758911, 41.09533943448748, 44.70872231892177, 44.13353654316494, 46.607314109802246, 41.62438222340175, 46.82284723009382, 48.79135526929583, 48.093314920152935, 47.19499274662563, 48.63991233280727, 22.534633908952983, 4.029770186969212, 16.591705901282175, 2.325188602719988, 5.516906159264701, 1.0949191727808543, 0.07093644607812166, 24.640011038099015, 54.62466328484671, 37.2814940725054, 30.417108127049037, 28.098970208849224, 38.97207416806902, 35.84421055657523, 3.0729370159762244, 0.22239228151738644, 0.057589295852397165, 0.03943651635199785, 0.0423393841566784, 0.049545711039432457, 0.06603886852306978, 0.033091898408851454, 0.10712324787995645, 0.030671631850834404, 0.11592890215771538, 0.06081712764820882, 0.04236266469316823, 0.018783974827134182, 0.15960335146103585, 0.049802149779030254, 0.010964100465311535, 0.015402132545464804, 0.06710541022143193, 0.0935729510549988, 0.004424391405856503, 0.0330255546474031, 0.0307656123435923, 0.05697829542415483, 0.029235203750431538, 0.07471870883767094, 0.028302433534658382, 0.08408600012106554, 0.031151678413152695, 8.308827842984881, 50.418658120291575, 42.37095921380179, 24.83868088041033, 39.305841309683665, 45.31739493778774, 49.25223275593349, 51.5074269430978, 46.55594260351998, 44.154586110796245, 0.9393669196537563, 0.8150734177657536, 6.284647362572806, 11.561698232378278, 34.46427747181484, 24.129191637039185, 50.63260357720511, 48.638731139046804, 51.613515513283865, 49.34800672531128, 52.20463350840977, 49.640157631465364, 50.54904801504952, 45.21754584993635, 45.264772755759104, 45.27620601654053, 48.34980419703892, 47.70617519106184, 47.72879505157471, 45.21671206610543, 46.83422837938581, 47.010208879198345, 47.02133641924177, 45.77931465421404, 44.395480155944824, 40.98024947302682, 39.36708968026297, 38.54132407052176, 36.6442608833313, 36.398190430232454, 34.761667319706504, 34.69540582384382, 35.58782202856881, 34.908844062260215, 35.01021827970232, 34.43856913702828, 36.75320863723755, 36.859519549778526, 37.59960344859532, 35.18001140866961, 36.69138009207589, 35.19997010912214, 37.22468907492501, 37.08781998498099, 37.91447843824114, 36.91282612936837, 36.353919982910156, 37.03894288199288, 38.000524929591585, 34.835304328373496, 37.51743752615792, 37.95791857583182, 37.738004616328645, 37.10577065604073, 34.88084282193865, 35.698937620435444, 36.218815735408235, 34.82957901273455, 39.610749108450754, 39.561090333121165, 48.14980724879673, 47.44053513663155, 57.55079984664917, 51.26372235161917, 46.05914640426636, 49.63211161749703, 44.57279123578753, 44.6139349937439, 42.52763761792864, 43.945229939052034, 42.8249579838344, 45.04830162865775, 43.2925682749067, 40.50262335368565, 35.87399748393467, 35.194991724831716, 35.25616019112723, 35.674764837537495, 35.28676700592041, 35.49656091417585, 35.05740002223423, 34.405388014657156, 34.35426664352417, 34.12527486256191, 37.55803237642561, 35.9260881287711, 34.416835171835764, 35.446276800973074, 34.797401905059814, 34.26649699892317, 34.24255003247942, 34.746277059827534, 33.19434131894793, 34.48104000091553, 33.62225655147007, 34.23577553885323, 33.670390197208945, 34.46170663833618, 34.95871475764683, 33.87606034960066, 34.070175647735596, 33.75295564106533, 32.45272534234183, 33.61507558822632, 32.143193517412456, 30.57380042757307, 33.157328265053884, 32.54762731279646, 32.41249527250017, 33.56214421136038, 34.92697538648333, 36.68238912309919, 41.51663303375244, 44.47470004217965, 46.83258860451834, 46.43915728160313, 47.691174030303955, 43.29900925500052, 47.398706981113975, 47.98108066831316, 49.861509868076865, 49.30324990408761, 50.46097264971052, 26.788440942764282, 6.475844851561955, 20.7371175629752, 3.887357303074428, 5.547983714512416, 1.2046718320676257, 0.12623255141079426, 26.25250554084778, 58.20048073359898, 42.58538062231881, 34.68964924131121, 27.706820828574045, 42.629539898463655, 42.83073193686349, 4.563456543854304, 0.24203487964613096, 0.11356411940817322, 0.05144187714904547, 0.07059969593371664, 0.0451901676133275, 0.0462590434721538, 0.060568573485527716, 0.03227866401097604, 0.026121625377397453, 0.02950772037729621, 0.0336961202722575, 0.017575488691883426, 0.08584035919713122, 0.24239656595247133, 0.18295999243855476, 0.14047357652868542, 0.09629157624606575, 0.1248027967022998, 0.4041813260742596, 0.10900939202734403, 0.108015080381717, 0.09158865003181355, 0.30831513021673473, 0.09095691357340131, 0.2778560732092176, 0.10912519759897675, 0.14650483003684453, 0.13127528796238558, 8.423958625112261, 59.14258698054722, 50.30778571537563, 33.71737044198172, 40.356179646083284, 48.02936717442104, 52.18748882838658, 55.991738728114534, 51.34887252535139, 50.162662165505544, 2.0580733588763644, 4.0947423577308655, 9.854246173586164, 12.874773144721985, 39.35018471309117, 24.64858511516026, 52.11217382975987, 48.85174553734915, 51.738096714019775, 51.78594200951712, 53.21919904436384, 50.730795519692556, 50.909339904785156, 46.52122245516096, 46.454846314021516, 47.71306432996477, 50.4468469619751, 50.507195540836875, 49.569689001355854, 46.85520151683262, 48.84391144343785, 48.81587893622262, 49.247372491019114, 47.828189032418386, 45.99177667072841, 43.54504149300711, 44.19814436776297, 40.257310254233225, 38.613095487867085, 37.58754137584141, 37.39705303737095, 36.69224166870117, 36.989767006465364, 37.36933319909232, 38.00026089804513, 37.154755456107004, 37.07758181435721, 39.66626868929182, 38.70684405735561, 37.29282658440726, 38.388811111450195, 36.84083236966814, 37.64864036015102, 39.22673259462629, 40.49191617965698, 38.97672946112496, 38.59342861175537, 38.45974179676601, 39.901618071964805, 37.01338740757534, 38.64327846254621, 38.7900904246739, 38.53715167726789, 39.460650648389546, 36.5381167275565, 36.43190656389509, 36.97269180842808, 38.470678261348176, 40.57270983287266, 41.9746652330671, 48.39827135631016, 49.60332523073469, 56.371947629111155, 48.448680537087576, 49.9029141834804, 50.83369834082467, 46.731113638196675, 45.09575087683541, 46.0495787348066, 46.57143013817923, 46.891332149505615, 47.93944706235613, 47.37203632082258, 43.498061248234336, 39.301338876996724, 36.79502637045724, 37.158083643232075, 38.066477230616975, 36.68332365580967, 36.8370977129255, 35.81988491330828, 37.284513064793174, 36.11783756528582, 35.98663125719343, 39.84314898082188, 39.07182945523943, 35.96414341245379, 37.72002962657383, 36.51160934993199, 36.92952959878104, 36.61331360680716, 35.92530298233032, 33.483348165239605, 34.87183100836617, 35.84834473473685, 36.630159514290945, 35.797542980739046, 34.8437568119594, 35.96423026493618, 35.60757228306362, 36.80385405676705, 34.74836846760341, 34.749893597194124, 34.111541748046875, 33.49176590783255, 33.673965045383994, 35.217302390507285, 35.14872367041451, 34.1581711087908, 35.81478493554251, 36.22359609603882, 37.45478561946324, 42.06245919636318, 45.38887800489153, 50.03558308737618, 47.27151673180716, 48.742637974875315, 42.94210808617728, 47.54515763691494, 48.55588429314749, 53.31634875706264, 51.499818665640696, 51.27675717217581, 30.132961545671733, 9.159883158547537, 25.581113270350865, 8.329973816871643, 13.402670349393572, 4.138565514768873, 0.199936056509614, 31.114891392844065, 62.36052009037563, 46.70444992610386, 41.01302759987967, 37.701175689697266, 46.94334636415754, 49.74843488420759, 6.438668949263437, 0.4316698381943362, 0.2152333842324359, 0.10007197981966393, 0.10821095308555023, 0.1312952097505331, 0.08872722036072186, 0.19174408965877124, 0.1222169811704329, 0.19425530705068791, 0.20861590360956533, 0.08825099734323365, 0.1445463608418192], [0.01851147516364498, 0.10158718244305678, 0.028154190596459166, 0.023315345336283957, 0.021283261877085482, 0.07122713726546083, 0.026205066524978195, 0.016218895325437188, 0.048433035745152404, 0.0533303995616734, 0.02040751913695463, 0.013046690678623105, 0.040872367697634866, 0.04750594995649798, 0.06682799796440772, 0.09987980513168232, 0.34153395199349945, 25.868733951023646, 44.28984669276646, 32.00110980442592, 23.639979396547588, 30.01291057041713, 44.086337430136545, 48.00260271344866, 43.0488532611302, 43.56586177008492, 3.7763481054987227, 1.759555840066501, 1.393549274121012, 0.35663591591375216, 5.866127831595285, 15.412777253559657, 41.039701734270366, 49.99295241492135, 50.21170255116054, 46.23009640829903, 44.84063734327044, 45.302633489881245, 43.7315102985927, 45.857301235198975, 48.731069224221365, 48.48066656930106, 47.477284158979145, 46.42095994949341, 45.636953013283865, 44.091472148895264, 43.89500835963658, 44.12270777566092, 44.44479846954346, 43.67870398930141, 41.50835772923061, 40.29574768883841, 39.08782073429653, 37.239203861781526, 35.50269964763096, 33.16096217291695, 31.67989805766514, 33.48156247820173, 32.95946093967983, 32.07315220151629, 31.684862545558385, 35.43010834285191, 35.776139054979595, 34.514849935259136, 35.4830709866115, 34.98613234928676, 34.19108819961548, 35.927800859723774, 35.9223986353193, 35.82213960375105, 36.07723576681954, 35.98832661764962, 33.84971625464303, 35.69751671382359, 37.0090343611581, 35.23567342758179, 35.890506403786794, 35.24768686294556, 34.006144523620605, 35.471078395843506, 35.2036109651838, 35.88289812632969, 30.95348126547677, 33.75133671079363, 35.409774439675466, 44.42936304637364, 45.466485909053254, 46.72364085061209, 37.77332578386579, 54.33517353875296, 53.15564734595162, 45.09913812364851, 47.59218651907784, 44.08671610695975, 45.61670248849051, 43.103052684238975, 44.7146942956107, 45.05681317193167, 45.17018345424107, 41.258573463984895, 38.8813967023577, 33.36134474618094, 34.4598445211138, 33.78384385790144, 35.40589387076241, 32.939665521894185, 34.096088954380576, 32.834497588021414, 35.433603286743164, 32.84155000959124, 34.14886747087751, 34.056908062526155, 34.71102884837559, 32.365188462393625, 33.077142579214915, 32.35243156978062, 32.68723051888602, 31.942175183977398, 31.96920715059553, 31.685053621019634, 31.05036347252982, 32.03711884362357, 31.63937963758196, 30.972043378012522, 32.65956974029541, 30.055124350956508, 30.990094797951834, 31.135534490857804, 30.72702557700021, 30.999485288347515, 33.153676986694336, 36.67696257999965, 37.41660874230521, 37.059999397822786, 35.89743028368269, 35.579828126089915, 34.26078905378069, 32.21185908998762, 32.72570269448416, 32.57139015197754, 40.55535323279244, 43.455451420375276, 46.852922507694785, 44.53334978648594, 44.00970227377755, 45.58660636629377, 53.00204004560198, 45.8402955191476, 40.196444034576416, 4.609510941164834, 17.28569371359689, 24.89898255893162, 2.2886067714009966, 7.501170107296534, 0.9930124410561153, 0.4488680139183998, 38.169293199266704, 49.81354645320347, 36.27773298536028, 21.590960843222483, 25.26768003191267, 39.39421544756208, 22.845647437231882, 0.2870208014334951, 0.1047261736488768, 0.05273014373545136, 0.03404964380232351, 0.05963551319603409, 0.0207835310138762, 0.07061274416212525, 0.036581800784915686, 0.033085798379033804, 0.030156447352575402, 0.05457055801525712, 0.04360290796362928, 0.014100934777941023, 0.04277262198073523, 0.04975148017651268, 0.04112869108627949, 0.013010442489758134, 0.023114356478410106, 0.08296149117606026, 0.018476712118302072, 0.056419956098709784, 0.03336376024942313, 0.011641911995996321, 0.005856667296029627, 0.07011991739273071, 0.011300317111558147, 0.030085404736122916, 0.006822423643565604, 0.041671125550887415, 0.7787767882858003, 34.91625779015677, 48.210273947034565, 32.85872943060738, 28.72518355505807, 35.843480995723176, 47.405533586229595, 53.196315152304514, 44.846678801945274, 48.90492010116577, 3.6246650218963623, 0.9379767371075494, 4.921845929963248, 1.6312821060419083, 9.51260324886867, 18.48522550719125, 42.70291634968349, 49.98489597865513, 50.37958492551531, 46.570096084049766, 46.237739426749094, 45.61764744349888, 44.54419592448643, 44.675777435302734, 47.24034711292812, 49.547520773751394, 47.79051242555891, 46.40955448150635, 45.55696187700544, 45.133667196546284, 45.61392320905413, 45.79265866960798, 46.82643944876534, 45.62284122194563, 43.91376849583217, 41.08386448451451, 39.53617409297398, 38.74331862585885, 36.12888520104544, 36.75130483082363, 33.77934489931379, 33.742064339774, 34.52920491354806, 34.70591497421265, 33.98963212966919, 35.27163035529, 37.17345305851528, 37.23735564095633, 36.841315269470215, 36.484056268419536, 35.41092436654227, 37.54696042197091, 37.104916027614046, 36.7370262827192, 37.122119767325266, 37.98735809326172, 35.94773524148123, 37.4516658782959, 37.410372734069824, 36.26077938079834, 36.51534400667463, 36.50674213681902, 36.649513721466064, 36.54028109141758, 34.132730279650005, 36.8600823538644, 34.81510591506958, 36.017463888440815, 38.58336762019566, 45.1185896056039, 46.253122738429475, 48.29929774148123, 42.27346903937203, 57.03070286342076, 50.187342166900635, 48.1991012437003, 48.87636647905622, 42.74494252886091, 46.788884435381206, 44.643287658691406, 44.72823633466448, 45.755906173161094, 44.69068826947893, 43.03673560278756, 39.01156425476074, 34.98565639768328, 36.40389142717634, 35.15122849600655, 36.26324599129813, 35.79108463014875, 37.535620961870464, 33.53570631572178, 36.27969932556152, 34.395087310246055, 35.194647789001465, 35.24721438544137, 35.03675692422049, 34.316239152635845, 33.741925375802175, 33.533368246895925, 34.377484049115864, 33.464973654065815, 33.59127800805228, 33.458508355276926, 33.26640803473336, 34.727944237845286, 33.66820151465279, 32.648657594408306, 33.46634244918823, 33.06060586656843, 34.104937485286165, 32.404160908290315, 33.739549091884065, 33.19084984915597, 34.87071929659162, 36.18509612764631, 37.93646253858294, 38.166173458099365, 37.03760187966483, 35.8056515284947, 35.20884990692139, 33.40086957386562, 34.93527848379952, 35.5322642326355, 43.60274280820574, 46.43572834559849, 50.26674965449742, 46.04378393718174, 44.70784684589931, 45.2735344341823, 53.43481206893921, 48.724089758736746, 43.618438788822715, 7.561687179974147, 20.201477459498815, 32.250890595572336, 2.636649638414383, 1.3355432152748108, 0.24373200429337366, 0.4713094468627657, 43.24140174048287, 53.93944583620344, 39.98616375241961, 33.537321771894185, 26.92217639514378, 44.12240552902222, 28.022333315440587, 0.36541553480284555, 0.028748860383140187, 0.014874334081209131, 0.05998800535287176, 0.07364957513553755, 0.04887821239286235, 0.09653445107064076, 0.046597730834037066, 0.08670494173254285, 0.048072974530181715, 0.09605054703674146, 0.00860534904391638, 0.021170791305069412, 0.10851674846240453, 0.23921724941049302, 0.13664803680564674, 0.1328029009912695, 0.11436972367976393, 0.19795607775449753, 0.12887217476963997, 0.136606456179704, 0.1520930001778262, 0.13696176425686904, 0.10783682244696788, 0.16733599081635475, 0.15603106814835752, 0.07458312397024461, 0.14443865019295896, 0.15301968902349472, 0.7657286684427942, 38.606928961617605, 56.65908193588257, 42.32613638469151, 32.69279255185808, 40.32730988093785, 53.15940632138933, 56.27549968447004, 49.63878536224365, 53.11211688177926, 5.163215492452894, 3.3699603463922227, 8.34994467667171, 0.7624688776476043, 9.194973298481532, 22.141930409840175, 43.92882524217878, 50.63743257522583, 51.34072576250349, 47.060871669224326, 46.7075696672712, 44.82697371074131, 43.623319898332866, 46.95061417988369, 48.38198477881295, 51.30980627877371, 49.04083728790283, 48.09040709904262, 47.45314959117344, 46.42554228646414, 47.29466812951224, 48.072185448237825, 49.641575063977925, 49.03379528863089, 46.78584459849766, 43.41080229622977, 43.83113356998989, 42.360887799944194, 39.50330563953945, 37.72083561761038, 34.933430262974326, 35.84259162630354, 38.0422488621303, 37.28119877406529, 35.27893986020769, 38.04702574866158, 38.77119827270508, 39.84710945401873, 39.08173063823155, 38.61266122545515, 37.138566153390066, 40.095656939915244, 37.69885499136788, 38.651692731039866, 40.0455777985709, 39.88660996300833, 37.367839336395264, 39.320720876966206, 41.11225134985787, 37.27899619511196, 38.341407026563374, 37.47611311503819, 38.067439556121826, 39.3758339881897, 37.254931109292166, 38.3586802482605, 34.741062436785015, 37.12852948052542, 40.90149859019688, 46.731909206935335, 50.338524545942036, 48.71380295072283, 47.820195129939485, 56.15055022920881, 50.06080504826137, 50.51161806924002, 50.10986280441284, 45.43074437550136, 47.010003907339915, 48.36786951337542, 47.51532902036394, 50.09270770209176, 46.37791238512312, 44.521287713732036, 41.82555341720581, 38.09800468172346, 35.818019321986604, 37.99412563868931, 36.93930918829781, 36.87346111025129, 37.91697978973389, 35.98031881877354, 40.03478724615914, 35.87394189834595, 36.633494649614605, 37.49517897197178, 37.40834386008126, 36.468662534441265, 34.89544793537685, 35.90897471564156, 36.689517974853516, 34.857806069510325, 34.42316845485142, 34.57637970788138, 33.464216300419395, 37.285638672964915, 35.507754462105886, 34.70478241784232, 35.73919200897217, 34.207892417907715, 35.62864964348929, 33.778316565922324, 34.883187838963096, 34.8525983946664, 37.07393748419625, 39.30722400120327, 42.64335291726248, 41.39560236249651, 39.78997789110456, 39.46097026552473, 38.376196656908306, 36.091792242867605, 36.59216676439558, 36.09812899998256, 44.32412215641567, 47.49500553948538, 52.91244649887085, 45.98413365227835, 46.34412676947457, 44.43905578340803, 51.21318810326712, 48.045379298073904, 47.157479422433035, 11.056711844035558, 21.145074095044816, 33.24093246459961, 8.128459555762154, 15.822753974369594, 3.1111243154321397, 0.9947391769715718, 46.24940892628261, 59.68731880187988, 44.680682863507954, 34.29036406108311, 34.137191023145405, 51.61361278806414, 35.23552404131208, 1.0619253260748727, 0.21880359122795717, 0.16769484084631714, 0.11550496704876423, 0.15041806362569332, 0.1292930157589061, 0.2119296650801386, 0.17158518066363676, 0.18224188525761875, 0.08183686688010182, 0.19316142717642443, 0.12286186085215636, 0.09914584058736052], [0.09209335116403443, 0.027574686067444936, 0.035478859075478146, 0.04055491169648511, 0.015357320396495717, 0.004445219886422689, 0.051966615420367034, 0.07101618751351323, 0.092729138476508, 0.03210266899051411, 0.020548221854759113, 0.03919583998088326, 0.01752509898506105, 0.10249589689608131, 0.07447299773671798, 0.06098211343799319, 0.02366208690883858, 6.90534861598696, 51.9942490032741, 37.49256992340088, 21.473869800567627, 34.49426589693342, 38.11039679391043, 51.06381572995867, 39.0602502822876, 48.233828340257915, 7.535324845995222, 0.4177518907402243, 4.43457657950265, 2.575376732008798, 0.3867571981889861, 11.61766597202846, 46.43820537839617, 46.74125105994088, 48.696453298841206, 48.69155134473528, 43.442357540130615, 42.21382917676653, 45.60124274662563, 46.07518284661429, 47.52761343547276, 48.624212878090994, 46.638098103659495, 45.56328126362392, 46.687868050166536, 44.19117532457624, 47.046509742736816, 44.6804153578622, 47.1159257207598, 44.1570839881897, 42.94304609298706, 41.521969250270296, 39.67808410099575, 36.380323137555806, 35.100673403058735, 34.225394930158345, 32.30601760319301, 32.68415594100952, 32.067989689963206, 33.102079663957866, 34.583803858075825, 33.509348324366975, 34.15961980819702, 33.54842151914324, 35.15532793317522, 36.17001853670393, 36.56602416719709, 38.61809819085257, 37.248413699013845, 36.776537214006694, 36.0531359400068, 35.06140913282122, 35.81092173712594, 35.22320488521031, 36.63701391220093, 35.94277770178658, 35.49616139275687, 34.824961934770855, 35.11952386583601, 33.72080980028425, 35.27845001220703, 35.63639688491821, 31.119970526014054, 33.04608760561262, 33.28938225337437, 44.38966451372419, 45.160188470567974, 49.61318819863455, 39.44125822612217, 36.88539811543056, 58.61305086953299, 46.916679177965435, 46.798761299678254, 48.840617997305735, 52.53231750215803, 45.283946309770855, 48.35788147790091, 44.973764828273225, 47.16113764899117, 43.638307162693565, 41.05729109900338, 34.52935777391706, 33.97433567047119, 32.88940225328718, 34.47833367756435, 34.0551050049918, 33.988006251198904, 33.9342827796936, 33.53971542630877, 33.32276834760393, 33.817327226911274, 33.75110394614083, 34.78619793483189, 32.196725913456504, 34.34264578138079, 32.886386735098704, 32.89691325596401, 32.4442172731672, 32.188478401729036, 32.400294235774446, 32.69236176354544, 30.798790046146937, 32.30321053096226, 31.28615059171404, 33.31989179338728, 31.825243949890137, 32.99602583476475, 31.972990444728307, 33.419112069266184, 32.927162238529746, 37.88636950084141, 39.30117906842913, 44.05703340257917, 44.202521732875276, 43.09902620315552, 42.75875554765974, 42.640587534223286, 39.97878476551601, 37.91417619160244, 36.22520112991333, 34.93655000414167, 40.301292351314, 42.386314732687815, 45.1839964730399, 42.96583618436541, 43.96957295281546, 39.843812533787315, 46.7147193636213, 17.456720147814067, 1.1344431319407053, 6.379704364708491, 6.728817905698504, 1.6273074107510703, 1.599320826785905, 0.8394431929503168, 0.879704801099641, 41.47775786263602, 44.16942398888724, 26.318443945475988, 20.134057351521083, 23.613525867462158, 42.616557189396445, 11.80261138507298, 0.2951869975243296, 0.09327662124165467, 0.052115011028945446, 0.07124101330659219, 0.01809053069778851, 0.0218500201257744, 0.06525460417781558, 0.05584963384483542, 0.07629215690706458, 0.015114827247868692, 0.06259640253015927, 0.061099377859916, 0.020885737047397664, 0.05388303240761161, 0.0358674560806581, 0.07162894534745387, 0.03078420420310327, 0.03694226233554738, 0.013705070662711347, 0.03931376936712435, 0.06149043794721365, 0.06787579174020461, 0.006771481354787413, 0.05349608424252697, 0.04573088538433824, 0.01827032721069242, 0.044647068184401305, 0.036739801056683064, 0.0880710498562881, 0.10722251076783453, 14.027514031955175, 58.680823598589214, 38.44489002227783, 22.292384965079172, 44.74080910001482, 46.085632937295095, 54.64099155153547, 45.051834787641255, 51.95891046524048, 7.742218749863761, 0.6874066197446415, 3.7637775114604404, 3.8017264008522034, 0.11862321543906416, 15.470878090177264, 46.18574605669294, 46.397478512355256, 51.300245557512554, 48.92356211798531, 43.30908414295742, 42.22073221206665, 45.58732203074864, 46.42806100845337, 49.21478196552822, 48.80973325456892, 47.66160944529942, 47.74850361687796, 47.67104509898594, 45.538003717150005, 48.26859712600708, 46.16541562761579, 47.917087759290425, 45.19102457591465, 44.85918208530971, 43.079335008348735, 39.752144949776785, 37.28671564374651, 35.95906775338309, 36.122920172555105, 34.586016859327046, 33.91792324611119, 33.41315051487514, 34.40071882520403, 35.54320069721767, 36.34556824820382, 35.479103565216064, 35.03743437358311, 36.98295429774693, 36.66222892488752, 36.29311629704067, 37.82698672158377, 37.95054306302752, 36.62552853993007, 36.66717604228428, 36.99560349328177, 36.93582814080374, 36.93091923849923, 36.60773072923933, 37.83425801140921, 37.68921436582293, 35.52676125935146, 35.511259828295024, 35.09471879686628, 36.47388410568237, 35.75511728014265, 33.49430547441755, 35.79230056490217, 35.40656437192644, 46.52391488211495, 46.52768427985055, 51.741629873003276, 41.56582280567714, 44.725325039454866, 59.91720690046038, 47.30026837757656, 49.45254932131086, 50.696349825177876, 49.92026730946132, 47.33100373404366, 48.17557464327131, 46.5100462777274, 48.65168605531965, 45.235531261989046, 43.26842328480312, 34.894009658268516, 35.437497752053396, 36.10901682717459, 35.70791816711426, 35.08442851475307, 38.038910252707346, 36.59288937704903, 35.89965718133109, 34.638211727142334, 36.02324826376778, 34.31668036324637, 35.050986834934776, 34.25122138432094, 35.789034911564414, 33.60065112795149, 34.97809328351702, 33.71237121309553, 33.419678347451345, 33.21393871307373, 35.594405446733745, 32.54747792652675, 34.062918254307334, 32.75861978530884, 35.03963000433785, 33.453165190560476, 35.10563441685268, 33.03266716003418, 34.358796869005474, 34.45733274732317, 39.56542253494263, 41.41346270697457, 45.96511990683419, 46.32690565926688, 45.38377455302647, 45.34344373430525, 43.64867040089199, 41.44672720772879, 39.43051978519985, 37.611710684640066, 37.47428226470947, 42.67698219844273, 44.76341159003121, 48.068645341055735, 44.342194420950754, 44.046836921146934, 42.30459696905953, 46.623579842703684, 22.969700574874878, 1.3374742716550827, 10.364335145269122, 7.203031591006687, 0.7008334706936563, 0.24716313875147275, 0.33955507246511324, 0.7992473755564008, 47.305111271994456, 48.603649684361045, 34.61997617994036, 26.278219086783274, 26.34098390170506, 48.99610478537423, 15.245709555489675, 0.24949955195188522, 0.0697280362780605, 0.049017403673912795, 0.08240978113774743, 0.031868964566716125, 0.027201257712606872, 0.085941576265863, 0.029741848885480846, 0.011392949864135256, 0.07811175712517329, 0.022976598602586558, 0.04026076337322593, 0.0365788321942091, 0.2109090941292899, 0.14943428284355573, 0.12728888115712575, 0.13694489587630543, 0.09124461920665843, 0.06139724116240229, 0.11566510131316525, 0.16571730481726782, 0.2185989993491343, 0.08742500987968274, 0.16203653732580797, 0.14848251534359796, 0.16782285326293536, 0.16725676506757736, 0.14544506690331868, 0.22570170036384038, 0.1903188947056021, 17.477344138281687, 66.97404752458844, 46.06397887638637, 30.35934427806309, 45.52351324898856, 48.05142075674874, 58.74665083203997, 46.63796956198556, 57.94932419913155, 9.30106360571725, 1.0072167302880968, 11.376815353121076, 6.285356513091496, 1.1108485694442476, 17.06685151372637, 47.87589883804321, 46.552826336451936, 52.40611042295183, 48.84370299748012, 43.08256244659424, 43.19566174915859, 46.17487907409668, 46.60307918276106, 52.36252784729004, 50.309821537562776, 50.00497279848371, 48.80412605830601, 48.99440247671944, 46.0674911907741, 50.069254057747976, 46.11039284297398, 49.88415057318551, 47.179491315569194, 47.493970257895334, 45.95062249047415, 43.771121978759766, 41.01207569667271, 39.728726046425955, 37.03443350110735, 37.57903330666678, 36.8020475251334, 36.1576646396092, 37.26168475832258, 38.56365210669381, 38.3011074747358, 36.25761795043945, 37.119621889931814, 40.48242494038173, 38.240682465689524, 39.74833038875035, 40.4033648627145, 39.66861718041556, 38.88844217572893, 38.81327656337193, 39.42080967766898, 39.51997089385986, 39.34600189753941, 40.91952221734183, 39.19520514351981, 39.37603896004813, 37.95522962297712, 38.94257211685181, 36.24095964431763, 38.42432682854788, 39.506595611572266, 34.02195514951433, 37.221419947487966, 37.13507815769741, 47.560197012765066, 47.28514214924404, 53.1011769430978, 44.9150664465768, 47.19953686850411, 55.76914971215384, 47.3133796283177, 50.90886742728097, 52.96153204781668, 51.975620882851736, 51.03461939947945, 50.93535396030971, 47.50002213886806, 50.16826936176845, 47.74122885295323, 46.034112044743125, 37.965745721544536, 36.47179617200579, 37.15070465632847, 37.95774139676775, 36.69805383682251, 39.00573124204363, 38.32111481257847, 37.652399335588726, 35.61327675410679, 36.8814480645316, 35.87926421846662, 38.23168454851423, 36.17519147055489, 38.24080753326416, 35.0039336340768, 35.654080050332205, 35.32572208132063, 34.049053124019075, 35.41237654004778, 37.14121341705322, 34.30500391551426, 36.37069640840803, 34.61251381465367, 37.166814054761616, 35.68719516481672, 36.527857712336946, 34.75802993774414, 36.47929675238473, 36.4338937486921, 41.24251965114048, 42.86851971490042, 48.997490950993125, 48.97539915357317, 46.78430209841047, 47.2900892666408, 46.923359870910645, 42.90131868634905, 42.095991202763145, 39.54923323222569, 39.27731895446777, 44.256519658224924, 46.041470187050955, 48.179350989205496, 44.1669921193804, 46.358314990997314, 41.624107769557405, 46.36367900030953, 27.017102684293473, 3.4671013738427843, 10.015225512640816, 10.411817397390093, 7.559162378311157, 5.320048928260803, 1.8900915384292603, 1.2372605119432722, 50.21903984887259, 53.577705247061594, 35.44911166599819, 29.493994780949183, 32.647618838718955, 55.99675185339791, 19.548954759325298, 0.49480342332805904, 0.1061812648549676, 0.12810130470565387, 0.1817859232957874, 0.11143351944961719, 0.1141047150428806, 0.20308907303426946, 0.1793302372097969, 0.14270402970058577, 0.16585132905415126, 0.17631440689521177, 0.15172021303858074, 0.16407799135361398], [0.04837905149906874, 0.07685230113565922, 0.04970282243032541, 0.015997058479115367, 0.06268362142145634, 0.037646798816110404, 0.009789441845246723, 0.06344111077487469, 0.04156631563923188, 0.03084236822490181, 0.0048573467897118205, 0.05365037971309253, 0.04990291901464973, 0.03230078425258398, 0.02106349286623299, 0.06411908939480782, 0.17673382296093873, 0.7897177040576935, 30.874007769993373, 43.13913120542254, 23.322967835835048, 19.610336882727488, 32.73872014454433, 45.94762086868286, 46.66443525041853, 48.11471537181309, 14.435929145131793, 0.28401793113776613, 2.757153332233429, 3.017497990812574, 0.2446776106953621, 5.913429864815303, 43.61083051136562, 48.887084075382774, 47.75021982192993, 46.52262599127633, 49.990565708705354, 46.16459574018206, 46.53538983208792, 44.52128076553345, 46.560903617313926, 45.28810828072684, 48.72651815414429, 45.84753554207938, 44.51942559650966, 43.264695576259065, 41.4770039830889, 43.303251130240305, 44.60807418823242, 43.24055406025478, 43.56653227124895, 40.302414485386436, 39.20048230034964, 36.1073978969029, 34.6735954284668, 32.18675177437918, 32.383632455553325, 32.08052771432059, 33.010874135153635, 32.470071520124165, 34.12409366880144, 33.36310958862305, 34.77493837901524, 33.62656443459647, 37.64490570340838, 35.89070095334734, 37.330836704799104, 36.57897908346993, 37.13602311270577, 34.91449989591326, 36.943488529750276, 34.14544548307146, 35.87029756818499, 34.222931793757844, 37.226005758558, 34.24105616978237, 35.938553197043284, 34.85995306287493, 36.47285924639021, 34.7214025088719, 37.4587321962629, 33.9764791897365, 34.048841203962056, 31.985462461199077, 34.44504138401577, 38.56749793461391, 48.6913811138698, 45.94961847577776, 48.856842041015625, 30.290751661573136, 51.45509658540998, 55.91862978254046, 44.21422944750105, 42.98022937774658, 53.309025355747764, 50.977460043770925, 45.246141161237446, 47.85539470400129, 46.123570101601736, 48.251862389700754, 43.016634464263916, 36.44211694172451, 34.11374780109951, 34.57318353652954, 33.76417350769043, 36.29105268205915, 33.128027711595806, 35.59567696707589, 34.503392355782644, 34.11114222662789, 34.23271138327462, 34.72739880425589, 33.91255576269967, 33.06289529800415, 32.514585154397146, 33.61302586964199, 32.32920026779175, 32.75747333254133, 32.76928527014596, 31.693297658647808, 31.351946558271134, 32.250098500932964, 31.944221428462438, 31.399819646562847, 30.642285346984863, 31.673648153032573, 31.693485260009766, 32.43205792563302, 32.18211037772042, 34.09186097553798, 37.553106103624614, 40.84834139687674, 45.34875563212803, 44.81589480808803, 44.96659081322806, 43.56169979912894, 46.16851452418736, 44.6090851511274, 43.10541507175991, 39.25103044509888, 38.59344250815255, 41.23188543319702, 43.94606719698225, 45.446412563323975, 45.68276596069336, 45.46933467047555, 42.328870500837056, 31.60871376310076, 1.4751731285027094, 1.2365218315805708, 1.6737633922270365, 2.4339016377925873, 0.973068831222398, 0.4632677212357521, 0.14248768559523992, 1.6263721180813653, 50.401068755558555, 39.0209721156529, 24.397056852068218, 21.087160859789165, 26.945077657699585, 35.706809929439, 3.722807458468846, 0.06890568576220955, 0.0848157238215208, 0.02712314306492252, 0.028517320486051694, 0.03621644021144935, 0.03381684861545052, 0.010961031790689697, 0.04957701185984271, 0.03854163722800357, 0.028958039158689122, 0.04320238231282149, 0.0809438062299575, 0.02266405689130936, 0.07153505645692348, 0.04646680410951376, 0.04517944336735776, 0.06198787875473499, 0.030819087688411986, 0.04646367945575288, 0.037898867790188105, 0.06585414414959294, 0.006403246337348329, 0.032257405508841784, 0.045352534257939885, 0.061677896816815646, 0.046024249999650886, 0.045303822228951116, 0.014342013181054165, 0.09573311478431736, 0.11299590061285666, 2.7128205682550157, 44.69173397336687, 45.18566056660244, 24.597244875771658, 29.737932137080602, 40.72280134473528, 50.38331610815865, 49.743935925619944, 53.408930029187886, 15.351928404399327, 0.29638938871877535, 2.979303743158068, 4.711972551686423, 0.45085723432047026, 8.035140906061445, 46.6092700277056, 48.12299762453352, 47.502520016261506, 47.61740847996303, 49.80957555770874, 45.57326235089983, 47.56334802082607, 45.36048766544887, 47.62199081693377, 46.82663747242519, 48.11865847451346, 46.134784494127544, 45.75520093100411, 43.816851547786165, 44.53896393094744, 45.872649805886404, 46.17040096010481, 45.64787210736956, 44.084774085453574, 43.292113167899, 40.35072878428868, 38.75966426304409, 35.51802737372262, 34.13127810614449, 34.825469153267996, 34.22678109577724, 35.280673435756135, 33.73915999276297, 36.03443486349923, 35.58013037272862, 35.603358200618196, 36.409672328404014, 38.49346487862723, 36.87711933680943, 39.5503762108939, 37.73247037615095, 38.219236850738525, 36.37383699417114, 37.889263425554546, 36.299963746752056, 36.99349471500942, 36.397050925663535, 38.518047605242046, 35.237316676548545, 36.813008308410645, 36.463381903512136, 37.093614782605854, 36.31308889389038, 39.71022299357823, 35.754863670894075, 34.963057381766184, 35.73251479012625, 36.25471012932913, 41.05293805258614, 49.172443117414204, 47.19891847882952, 49.852049895695274, 34.19882501874651, 55.10134097508022, 56.17804077693394, 47.47633572987148, 47.31790290560041, 52.28591353552682, 47.45222200666155, 49.252990109579905, 46.94920022147042, 46.38241829190935, 48.02545533861433, 44.80905083247593, 37.64138296672276, 34.31276852743966, 34.841279779161724, 35.60213531766619, 35.94749205453055, 34.9985522542681, 37.381423064640586, 36.10645294189453, 35.67432015282767, 36.13593414851597, 35.653624943324495, 37.71062871388027, 33.781387669699534, 34.73657390049526, 34.86302416665213, 33.744093213762554, 33.36853265762329, 34.306007930210654, 33.35971539361136, 34.09637035642351, 33.76599393572126, 32.95042828151158, 33.274947370801655, 32.95884949820382, 32.590713092258994, 33.78513274874006, 34.59856183188302, 33.54792124884469, 36.67211968558175, 39.317580291203086, 42.95755393164498, 46.51608426230294, 46.40593099594116, 46.37552915300642, 44.52878829411098, 47.5748542376927, 45.62230273655483, 44.966451849256245, 41.03820787157331, 41.109562397003174, 44.484979901994976, 44.777436528887065, 47.323332922799246, 45.76848241261074, 45.24532127380371, 42.847160952431814, 32.8737827028547, 3.7439981613840376, 2.8449898532458713, 1.0665624886751175, 1.5132531651428767, 0.320280416735581, 0.2622266975896699, 0.08008481482309954, 1.5778828114271164, 55.45482015609741, 45.49774932861328, 32.330200808388845, 24.236487456730433, 27.45860685620989, 42.7954489844186, 5.656539763723101, 0.1568714744810547, 0.06536450649478606, 0.025651024022538747, 0.029554485010781457, 0.09979965657527957, 0.023085917379441004, 0.02543362140256379, 0.04985395932037916, 0.023992457127730762, 0.058478543135736666, 0.06863556097128562, 0.06587427628359624, 0.05547957780904003, 0.30367530775921686, 0.22146386919277056, 0.21619197779468127, 0.1168111605303628, 0.1627633161842823, 0.11388074420392513, 0.08265914275710072, 0.17508342223508017, 0.12247726720358644, 0.16258787416986056, 0.11708072892257146, 0.10012848143066679, 0.16790589237851755, 0.08986193447240762, 0.1385328306683472, 0.2520799663450037, 0.19861579021172865, 4.0453345860753736, 49.047983510153635, 53.21971321105957, 32.17427975790841, 27.396401371274674, 44.2696795463562, 53.85039077486311, 54.84066193444388, 57.14161695752825, 18.53073968206133, 0.4752407159124102, 9.112722260611397, 8.424395493098668, 0.4951498018843787, 10.6361061164311, 48.98970202037266, 48.236041341509136, 48.55261516571045, 45.92880514689854, 51.66343832015991, 45.834518092019216, 49.47144494737898, 47.53389113289969, 50.516825744083945, 48.4734856060573, 51.20151512963431, 46.59275068555559, 47.93761273792812, 44.179495402744834, 45.27444812229702, 46.83287695475987, 47.35669469833374, 47.106927803584504, 47.474633421216694, 46.40985672814505, 42.34962477002825, 41.03962530408587, 39.21837738582066, 36.258194650922505, 36.45084040505545, 36.635467938014436, 38.03556816918509, 35.921050684792654, 38.01597772325788, 37.76792355946132, 38.005173274448936, 36.514583178928916, 41.19175263813564, 38.482340812683105, 41.366107259477886, 39.02345609664917, 39.66306209564209, 38.95152139663696, 39.39968715395246, 38.26541805267334, 37.95697709492275, 37.886313915252686, 40.21960585457938, 36.21821471623012, 39.25561973026821, 38.39768048695156, 39.13235521316528, 38.774564674922395, 41.488440717969624, 40.61377021244594, 36.33038990838187, 36.942321232386995, 38.12249708175659, 43.07362706320626, 50.042722361428396, 48.13683843612671, 52.1231415612357, 39.97801004137312, 52.486351694379536, 53.212650367191856, 48.542449951171875, 49.54410573414394, 53.789100715092246, 48.27338443483625, 52.33718081883022, 50.490596294403076, 49.51384285518101, 50.568113871983115, 48.34831033434187, 41.011179379054475, 37.876888683864046, 36.16080869947161, 38.34977960586548, 37.99127687726702, 36.249731745038716, 39.70773206438337, 38.00339453560965, 37.38069697788784, 36.93615123203823, 37.66439192635672, 38.23192078726632, 34.57977042879377, 36.23896551132202, 35.95649344580514, 34.77025529316494, 35.263730253492085, 35.92727279663086, 34.58509622301374, 36.24992976869856, 35.948374475751606, 34.86247525896345, 35.28072207314627, 33.805602141789024, 34.21875245230538, 34.20124299185616, 35.047821930476594, 35.096351623535156, 38.37782253537859, 40.043830326625276, 44.98371812275478, 47.97693954195295, 48.00834539958409, 48.386827673230854, 47.098833152226035, 50.481942313058035, 47.37684794834682, 47.45376798084804, 43.06588676997593, 42.59587240219116, 47.840372698647634, 46.751041071755544, 48.52715001787458, 44.39911753790719, 45.76327473776681, 42.09439311708723, 37.72975710460118, 5.276052500520434, 3.7977359635489325, 5.719961183411734, 6.79314215694155, 4.683807594435556, 0.6886968133705003, 0.3039095923304558, 1.9989954318319048, 60.82571165902274, 48.00224488122122, 34.770039899008616, 28.826158251081193, 35.69242715835571, 52.410338401794434, 9.721397485051837, 0.2646922767162323, 0.17019062835190976, 0.13887584369097436, 0.09313465814505305, 0.25186459933008465, 0.21787262761167117, 0.1470445232199771, 0.24894418460982187, 0.12718351823943003, 0.167532263855849, 0.17015763797930308, 0.2370589923645769, 0.08529774831341845], [0.08483181867216315, 0.03864426564957414, 0.022371487858306085, 0.007787088397890329, 0.0606079420873097, 0.030473245174757073, 0.041209552104451826, 0.057900851991559775, 0.045499141926744154, 0.029989286858056272, 0.023147267123152102, 0.06312162934669427, 0.024834439358008758, 0.045176193184618435, 0.015074683419827904, 0.02523478350069906, 0.025077349805672253, 0.08365299299891506, 14.58622476032802, 47.57211664744786, 28.594071047646658, 31.73761326926095, 27.823852811540874, 41.16227143151419, 46.60950626645769, 45.82151801245553, 24.619543382099696, 0.014321224564420325, 2.6172211723668233, 2.7929152761186873, 0.14051278228206293, 2.798226305416652, 35.62680837086269, 52.12728616169521, 47.97785323006766, 47.121748311179026, 46.52771207264492, 47.75942618506295, 51.31262724740164, 48.39592981338501, 46.71016829354422, 47.358198983328684, 47.76565524509975, 48.79049369267055, 45.90755408150809, 42.83843748910086, 40.39469698497227, 42.56228133610317, 47.44686494554792, 45.88597297668457, 41.970923628125874, 40.86948129108974, 39.06653492791312, 34.2199683870588, 33.822719029017854, 33.21930967058454, 33.16585023062569, 31.643204620906285, 32.42820514951433, 31.965333529881068, 33.52480459213257, 34.457197257450645, 34.129009519304546, 36.38363742828369, 35.58340644836426, 33.88571834564209, 36.319609778267996, 36.754438468388145, 36.38310241699219, 34.9518221446446, 35.58792972564697, 35.55330685206822, 36.266330991472515, 34.201072760990684, 36.29241452898298, 35.29236377988543, 35.016565459115164, 36.68835762568882, 38.85511861528669, 38.7468170438494, 35.99888787950788, 36.55657114301409, 37.15148285457066, 32.800635542188374, 33.300735609872, 35.22438260487148, 45.69348355701992, 47.74227108274187, 49.486053534916465, 35.224069935934885, 36.8541624886649, 57.70705441066197, 42.93210962840489, 45.96779843739101, 38.84353944233486, 57.27515091214861, 45.733321053641184, 47.291492802756174, 46.07412324632917, 45.25172403880528, 43.06249257496425, 36.89064400536673, 32.92848934446062, 35.229847363063264, 32.11909021650042, 34.624398708343506, 34.084607056209016, 34.6565271786281, 35.568328857421875, 34.655835832868306, 36.19562612261091, 35.9291627066476, 33.69764450618199, 35.12393249784197, 32.32853671482631, 32.26442916052682, 33.51750898361206, 34.65185798917498, 33.33470187868391, 33.74340534210205, 31.67733417238508, 32.19239023753575, 32.246756417410715, 32.695366859436035, 32.12957157407488, 32.73354721069336, 30.639801365988596, 30.413380418504985, 30.458588872637065, 31.82874584197998, 32.777696064540315, 39.132160663604736, 40.34507295063564, 43.90369708197457, 43.30144459860665, 44.38818107332502, 43.67175579071045, 43.187271799360005, 43.378746782030376, 42.69540187290737, 44.02510643005371, 43.53907299041748, 45.06489045279366, 44.70624876022339, 45.16303375789097, 45.03792449406215, 45.7503719329834, 15.2332010609763, 0.16912718755858286, 8.09971833229065, 3.421501866408757, 2.211072474718094, 0.39738794203315464, 0.05329878322247948, 0.02859432403264301, 3.667898450578962, 52.53393643242972, 27.80063019480024, 22.755289588655742, 16.024345534188406, 34.10902302605765, 27.385385002408707, 0.09912728943995067, 0.0374404664949647, 0.02095831824200494, 0.06422365842653172, 0.04548968654125929, 0.063426495130573, 0.01741481838481767, 0.009669480246624776, 0.029409434579844986, 0.06175670865923166, 0.03556336382670062, 0.02016915487391608, 0.003271511639468372, 0.026807829538094144, 0.016976880009419153, 0.02445633759322975, 0.020526596943714788, 0.04856524829353605, 0.01869442516804806, 0.09390390651034457, 0.003153565077809617, 0.05657505563327244, 0.040685831635658226, 0.013026895267622811, 0.03399965952017477, 0.04664551666272538, 0.06512435259563581, 0.04761588620021939, 0.026114614414317266, 0.09264759213796683, 0.03755454519497497, 0.09280214205916439, 20.5324809551239, 53.561429091862266, 26.844453845705303, 25.846845388412476, 37.47622776031494, 44.423804487500874, 50.952352728162495, 50.90066507884434, 25.666680335998535, 0.027070716056706648, 0.5278582839029176, 3.3555202526705603, 0.14852752935673508, 4.109229786055429, 39.090200492313926, 50.12588882446289, 49.25087785720825, 47.79852369853428, 48.44710677010672, 47.759492192949565, 50.78154516220093, 49.23820781707764, 47.44581576756069, 47.95877695083618, 49.13711847577776, 50.46781662532261, 46.835670130593435, 42.771401269095286, 41.27299097606114, 43.894612312316895, 48.28300074168614, 46.49603523526873, 44.61542885644095, 42.21991579873221, 41.172711099897114, 37.53629841123308, 35.73697553362165, 33.70208787918091, 34.6935714994158, 32.84015689577375, 34.62143530164446, 34.184893880571636, 35.57984897068569, 36.661954471043174, 36.246111733572825, 37.20421968187605, 37.046974999564036, 35.12472111838204, 38.114909648895264, 37.75104291098458, 37.482456820351736, 36.66606433050973, 36.86436244419643, 37.45801305770874, 39.10138709204537, 36.02118812288557, 36.97587060928345, 35.9821948323931, 36.66794034412929, 38.45940480913435, 39.57109226499285, 39.976352896009175, 39.25471993855068, 39.152404240199495, 37.905657700129915, 33.98961475917271, 36.696129185812815, 37.534644739968435, 47.5819205556597, 48.17547042029244, 50.7269948550633, 35.73028441837856, 44.516844340733115, 61.03911863054548, 44.58395004272461, 47.05346141542707, 44.153154781886506, 54.577443327222554, 46.949068205697195, 48.572240352630615, 45.96840293066842, 47.83060005732945, 44.91628238133022, 36.89781107221331, 34.736980370112825, 37.31474815096174, 34.560648986271445, 35.93533270699637, 34.85455431256975, 35.51210750852312, 37.03295006070818, 36.987015519823345, 38.05414417811802, 37.32596254348755, 34.85486698150635, 36.98361785071236, 32.438693455287385, 34.36636345727103, 35.08172219140189, 34.016768319266184, 34.5198005267552, 35.397545610155376, 33.66062102999006, 34.63880232402256, 34.078235558101106, 34.904563971928184, 33.301555497305735, 33.95693390710013, 31.08085216794695, 33.13993344988142, 32.602111612047466, 32.90017543520246, 35.05233131136213, 41.63453701564244, 42.61759941918509, 45.119704791477744, 44.732450417109895, 47.08717407499041, 44.123732634953086, 43.32810831069946, 46.02817480904715, 44.01591396331787, 45.52834572110857, 45.56739807128906, 47.10180350712368, 47.04918132509504, 46.0687974521092, 45.2740729195731, 46.12931626183646, 18.832461731774465, 0.5159502657396453, 12.977998188563756, 2.701764030115945, 1.9413883515766688, 0.4451803389404501, 0.0758186276736004, 0.04564572584682277, 4.230803719588688, 58.48396723611014, 31.43891716003418, 33.96959352493286, 16.457381589072092, 35.61007016045706, 36.64145728519985, 0.4119551389345101, 0.0376142698473164, 0.04319396847859025, 0.08247169745819909, 0.026183748651029806, 0.031374875722186904, 0.008691279566846788, 0.01620456127316824, 0.04001931347219007, 0.04238128708675504, 0.034955566083746295, 0.0307037129865161, 0.01727537943848542, 0.019073334389499257, 0.13300188817083836, 0.07449354377708264, 0.15033309747065815, 0.11176548592214074, 0.1214992811105081, 0.20927093417516776, 0.21325750382883207, 0.18095296727759497, 0.13085767679980823, 0.11339834651776723, 0.07778521893279892, 0.13781700336507388, 0.11764773992555481, 0.1962199102022818, 0.09587618389299937, 0.2000226511486939, 0.10352147543536765, 0.24844787695578166, 23.819124800818308, 61.17392757960728, 38.42943722861153, 41.894243308476035, 38.03489071982247, 49.39027956553868, 54.36971303394863, 54.90763562066214, 31.263033935001918, 0.1486348057431834, 8.1557868208204, 9.158509152276174, 0.20386898118470395, 5.026130139827728, 41.21815231868199, 52.450995785849436, 50.00186000551496, 47.368110588618684, 50.07260308946882, 49.54919181551252, 53.82374095916748, 51.55410841533116, 48.925194944654194, 49.99174690246582, 49.35731383732387, 51.360111236572266, 46.982054778507774, 43.279078347342356, 41.16771534511021, 46.98728329794747, 49.40780292238508, 49.879252093178884, 46.46015126364571, 44.142701217106406, 43.613269329071045, 38.940227099827354, 38.764111110142295, 36.4032278742109, 37.13758993148804, 34.686272416796, 36.96052551269531, 37.070564133780344, 38.325353213718955, 39.1932179587228, 37.605794293539866, 40.617998191288535, 38.175682067871094, 36.67530196053641, 40.64485992704119, 39.70983042035784, 38.38331161226545, 39.969439438411165, 37.98671885899135, 39.50474044254848, 40.820937701633994, 37.574708053043906, 40.41323477881295, 38.4479854447501, 37.973169871738975, 41.410509722573416, 43.17665842601231, 42.616584982190815, 40.12046895708357, 42.16061987195696, 39.803853443690706, 34.142898968287874, 37.311260155269075, 38.39712463106428, 47.68158899034773, 49.65178196770804, 51.288371086120605, 38.94355181285313, 45.714790207999094, 54.87487833840506, 46.2581011227199, 48.96402495247977, 48.612182072230745, 53.79391929081508, 49.56762886047363, 50.92333705084664, 50.021558148520334, 48.532124928065706, 46.80911064147949, 39.38331024987357, 37.89432518822806, 39.05490711757115, 35.299093110220774, 38.64280251094273, 36.31868914195469, 37.17367192677089, 38.2074943951198, 38.37939282826015, 39.581549303872244, 39.353339195251465, 35.99867248535156, 39.59190559387207, 33.61581904547555, 36.61958088193621, 36.06074769156319, 37.30246720995222, 36.57037026541573, 37.795897006988525, 35.265033040727886, 35.48435640335083, 35.884947844914024, 37.41253709793091, 34.89844955716814, 36.98988512584141, 32.65680088315691, 34.21768242972237, 33.84942790440151, 35.918795994349885, 35.974072388240266, 43.62201016289847, 43.604215826307026, 47.61886412756783, 47.02623837334769, 48.477380071367534, 44.572541100638254, 45.15804842540196, 47.040728841509136, 47.514498710632324, 47.67474154063633, 50.137683391571045, 48.91572454997471, 47.459559304373606, 44.74114956174578, 46.708500725882395, 47.35587133680071, 23.25125026702881, 0.6578402434076581, 14.156950286456517, 7.815310324941363, 5.995632699557713, 1.6849410895790373, 0.3175638610763209, 0.2980652345078332, 4.836528999464853, 63.63427775246756, 35.5650805745806, 33.2319449697222, 22.953155176980154, 42.942226205553325, 43.48826428822109, 1.4244133893932616, 0.14747608506253787, 0.17654470168054104, 0.17041435491825851, 0.19457700050302915, 0.11671244725584984, 0.07259638022099223, 0.07575272156723908, 0.08971652441791125, 0.11781411671212741, 0.14922357057886465, 0.07649613810437066, 0.06321700422891549, 0.1633199727428811], [0.042598798272332976, 0.026773595750065785, 0.03818065659808261, 0.02982473872335894, 0.05822219939104148, 0.04032099353415625, 0.051677420402743986, 0.028663768699126582, 0.06654575453805071, 0.04294779258114951, 0.13381955000971044, 0.046438380277582576, 0.030381853293095316, 0.004572161914048982, 0.014234061652262295, 0.1427277105727366, 0.04477002551513059, 0.14132572151720524, 3.9319412878581455, 42.316665990012034, 39.6331535748073, 26.51900369780404, 27.30966874531337, 40.374352659497944, 42.54223230906895, 44.69178261075701, 31.104951994759695, 0.34186000164066044, 0.7824825122952461, 1.7415718393666404, 0.2787056533353669, 0.9002814026815551, 23.33066122872489, 48.851943561008994, 48.70811237607683, 48.35095412390572, 47.75567068372454, 49.653418268476216, 46.41769082205636, 46.85919673102242, 46.888448647090364, 50.24172919137137, 46.26710598809378, 46.75136763708932, 43.67684187207903, 44.97344173703875, 46.60661234174456, 46.41776030404227, 43.66881670270647, 43.892152650015696, 41.087918758392334, 38.62079756600516, 34.67300483158657, 33.29407228742327, 32.32369729450771, 33.73832620893206, 32.46846301215035, 35.00355495725359, 33.47545153754098, 33.957958766392295, 32.29548760822841, 34.32350696836199, 34.6969552721296, 36.52041271754673, 36.33832475117275, 36.058889048440115, 34.51540231704712, 36.92245980671474, 35.71858017785208, 35.628482886723106, 34.769591740199495, 35.79908548082624, 34.890115192958284, 35.01934126445225, 33.976051875523154, 36.41955614089966, 35.573209966932026, 41.06556987762451, 40.44958427974156, 40.43120629446847, 39.31252895082746, 40.89115619659424, 42.4581104687282, 35.86946031025478, 33.218614850725444, 37.51313311713082, 42.55983209609985, 50.148498262677876, 46.825619561331614, 46.52906002317156, 29.93078981127058, 45.35122224262783, 45.81838437489101, 44.78668458121163, 40.229736328125, 43.01170819146292, 52.32092898232596, 43.044357776641846, 47.89997434616089, 44.60384620938982, 47.22847958973476, 35.53781236921038, 32.5495901788984, 33.07977942058018, 33.59918505804879, 34.012078285217285, 34.735899925231934, 32.98987667901175, 34.458847454616, 33.80606419699532, 34.60095201219831, 33.78158221926008, 34.56863246645246, 33.75358097893851, 35.78699908937727, 33.91347639901297, 33.77838952200753, 34.19173090798514, 31.78042459487915, 32.50755705152239, 33.833335876464844, 31.633643899645122, 33.11006314413888, 34.017855712345664, 35.0783314704895, 31.519988741193497, 32.51167385918753, 32.03490931647164, 32.06154523577009, 31.029612677437918, 30.3863137108939, 31.868513856615337, 37.03942230769566, 40.22512967245919, 42.07261746270316, 43.06938518796648, 45.13062041146414, 45.01096200942993, 44.87739678791591, 46.89383002689907, 43.84117371695382, 45.34282534463065, 44.69910601207188, 42.82522201538086, 42.769101415361675, 46.807158197675435, 33.89073494502476, 4.206174961158207, 0.18899633495935372, 1.5557268517357963, 1.880862376519612, 0.7470698782375881, 0.14567700374339307, 0.06685910879501275, 0.17650215753487178, 8.329556924956185, 53.44437626429966, 24.83751358304705, 20.795098543167114, 19.89906406402588, 40.16492353166853, 14.79237607547215, 0.11216572658824069, 0.0307682755935405, 0.0707168857167874, 0.060798868270856996, 0.05085109706435885, 0.09404016991278955, 0.010318164813465305, 0.011610299049477493, 0.04665820187489901, 0.019288407938022698, 0.022009562368371656, 0.06544687386069979, 0.031875081559909244, 0.053788044290351014, 0.009007460770330258, 0.024052029109693, 0.05321011905159269, 0.03830752229051931, 0.03788334630163653, 0.03471812632467065, 0.007413042576185295, 0.05687901896557637, 0.04396449927506702, 0.05352526803367904, 0.08011684167597975, 0.08360164825405393, 0.018526767646627765, 0.04847667572487678, 0.06525848539812223, 0.05117890750989318, 0.013219825673981436, 0.013243054472176092, 6.56262046950204, 50.48561443601336, 42.3920122555324, 27.02937494005476, 33.219566753932405, 44.64137690407889, 46.06517049244472, 49.17617082595825, 35.20435094833374, 0.15020512576614106, 0.7314787719930921, 1.2483395231621606, 0.6497832100306238, 0.970215835741588, 27.394992624010357, 48.8218161719186, 48.90869297300066, 49.06579869134085, 50.214902196611675, 49.16996261051723, 47.89383213860648, 47.332285676683696, 48.91202116012573, 49.630211285182405, 46.827651909419465, 48.41212259020124, 44.34296219689505, 46.393882819584434, 48.462931292397634, 48.70212650299072, 47.20672825404576, 46.03934056418282, 42.38469927651541, 41.29694489070347, 37.668355873652864, 34.76855993270874, 33.2018175806318, 36.54025329862322, 33.76790469033377, 36.10093607221331, 35.75988721847534, 35.46680177961077, 34.46582344600132, 35.93634714399065, 36.69709498541695, 37.220947469983784, 37.394430092402864, 38.43846641268049, 36.49866485595703, 38.21665906906128, 36.65895632335118, 38.00588199070522, 36.24942602430071, 37.464026723589214, 35.37903560910906, 36.17105381829398, 35.413255487169536, 37.980375153677805, 36.98673759187971, 42.03662926810128, 41.82759618759155, 42.29988956451416, 42.20481736319405, 42.37334244591849, 41.398649147578645, 37.12339128766741, 36.548118659428184, 38.224062374659944, 45.562847001211985, 50.266926833561485, 49.020774364471436, 45.88091121401106, 33.135625566755024, 52.43622044154576, 47.5456474849156, 46.9742762701852, 40.00141504832676, 46.96200227737427, 51.47781719480242, 45.977432114737375, 48.167420932224815, 45.484151703970774, 47.244870390210835, 38.35995176860264, 33.85314171654837, 34.79512984412057, 35.73326519557408, 36.60480553763253, 34.78867149353027, 37.12517350060599, 35.08594669614519, 36.037314891815186, 35.971327849796836, 36.1040940284729, 36.59190273284912, 35.987895829336985, 36.50365366254534, 35.493482862200054, 34.61668620790754, 35.44679791586739, 33.78946842466082, 33.30193417412894, 34.445965494428364, 34.17249482018607, 34.645879064287456, 36.17031383514404, 37.047704560416086, 33.549085072108674, 34.98417295728411, 33.33226653507778, 33.09707348687308, 32.40269136428833, 33.3593784059797, 35.21279648372105, 38.74542045593262, 42.13316059112549, 44.372978414808, 45.13523054122925, 46.98830815723964, 45.19701739719936, 46.009379931858604, 47.86912781851632, 45.30001054491316, 46.454373836517334, 45.42736407688686, 43.56485775538853, 42.7784606388637, 45.92082166671753, 36.44063350132534, 5.4367469634328565, 0.5657319916146142, 4.899609523160117, 2.874275858913149, 0.19031736121645995, 0.09846399431782109, 0.015488778074671115, 0.22419365628489427, 9.013416869299752, 57.40730912344796, 30.57747949872698, 27.30500476700919, 17.45355871745518, 44.615005016326904, 19.951340573174612, 0.09551643819681235, 0.027594819897785783, 0.058084395714104176, 0.0660494061719094, 0.057786810610975535, 0.05031828083364027, 0.04168224334716797, 0.05030071695468255, 0.046862495198313675, 0.06680077513945953, 0.0334376730690045, 0.052561256369309764, 0.062236711116773744, 0.047928643346365006, 0.14271780396146433, 0.15631692138101372, 0.11584000049957208, 0.19438802850033554, 0.11966586591941969, 0.1072773431826915, 0.1197010547454868, 0.12935598380863667, 0.13859319314360619, 0.12211414240300655, 0.23605505909238542, 0.2017217164060899, 0.10304256541920559, 0.1985841297677585, 0.17877113792513097, 0.2608809455164841, 0.16157931328884192, 0.19351203979126044, 7.935225810323443, 55.09681074959891, 51.4925890650068, 35.29263823372977, 38.69038030079433, 50.18638678959438, 52.512893812997, 54.03205142702375, 41.70880283628191, 0.6647332363895008, 3.260690152645111, 8.271478669983999, 1.7969444223812647, 2.2655550369194577, 28.33515337535313, 50.47737734658377, 48.58154746464321, 48.90330811909267, 49.92738226481846, 53.38882194246565, 48.148771967206685, 50.346970081329346, 49.992865562438965, 51.99366535459246, 47.17585045950753, 50.31872565405709, 45.390476090567454, 47.6402576310294, 49.28341974530901, 49.14222540174212, 50.14485045841762, 47.914034026009695, 46.057676860264365, 43.06803723743984, 38.70408909661429, 36.16030148097447, 36.28124182564871, 40.71492903573172, 35.96978187561035, 39.407833916800364, 38.22230795451573, 39.079336983816965, 37.44671876089913, 38.9150607245309, 38.44776657649449, 39.6582921573094, 39.829818861825125, 41.54427644184658, 38.12581137248448, 40.73784419468471, 39.92864309038435, 40.0236736025129, 38.54103224618094, 38.39667647225516, 37.134279114859446, 38.04337099620274, 37.53662150246756, 40.97371816635132, 39.257877894810264, 44.24351610456194, 43.83833885192871, 43.68906375340053, 44.28531994138445, 43.98254871368408, 45.12940100261143, 38.12833704267229, 37.52193648474557, 39.760128429957796, 47.70190552302769, 51.464591298784526, 49.753180503845215, 47.381687368665425, 37.47240277699062, 47.92190286091396, 46.77877480643136, 47.37613228389195, 45.75017738342285, 49.43109328406197, 50.86064692905971, 48.53426149913243, 50.4798196383885, 48.9685378074646, 48.7554817199707, 40.8368421282087, 36.08317300251552, 38.21139580862862, 36.18595423017229, 39.71505199159895, 37.163579668317524, 36.93761730194092, 36.263913018362864, 38.59180620738438, 37.96319573266165, 37.26948411124093, 37.47504309245518, 37.21526036943708, 37.572967529296875, 37.470526763371055, 36.95358773640224, 37.28504460198538, 35.07272774832589, 34.89274856022426, 36.93679394040789, 34.962602274758474, 36.9104220526559, 37.86693886348179, 39.32032135554722, 34.32051576886858, 35.382221358163015, 34.98841135842459, 35.338051659720286, 34.69175801958357, 34.57573699951172, 36.0736539704459, 39.86751978737967, 43.76719624655587, 45.60914632252285, 46.844192096165244, 49.33601066044399, 47.16168655667986, 47.12031350816999, 49.127971172332764, 45.314021587371826, 48.97463485172817, 46.7345495223999, 43.829903738839285, 43.61551012311663, 46.56884888240269, 38.722487926483154, 8.93348045008523, 0.6784371467573302, 3.9994356547083174, 5.808879017829895, 1.254549149956022, 0.28600310747112545, 0.1602032714124237, 0.28379029620970997, 10.85919713973999, 63.627774238586426, 32.90035261426653, 31.424312046595983, 26.830163138253347, 51.93250036239624, 25.76586934498378, 0.3192541189491749, 0.15776431799999305, 0.13169260056955473, 0.16946462302335671, 0.09845558048358985, 0.358248522239072, 0.07965823342757565, 0.22062937968543597, 0.07923690389309611, 0.14838547126523086, 0.0683583454894168, 0.17864277267030307, 0.144425880163908, 0.12843788521630423], [0.05676720657252839, 0.05443462709497128, 0.010523156179780406, 0.0025562468841339326, 0.03807003503399236, 0.06828127748199872, 0.051546039059758186, 0.05125499164153423, 0.027920545544475317, 0.06678925361484289, 0.0433486201800406, 0.009902150752688093, 0.002128491410985589, 0.05337405989744833, 0.0410337538591453, 0.024327248002269437, 0.07135927517499242, 0.0450498533568212, 0.5145752280950546, 22.986727135522024, 40.84032317570278, 24.735402856554302, 30.161028793879918, 29.55484015601022, 38.269392422267366, 44.54327528817313, 36.90770183290754, 1.4694012382200785, 0.24743900394865445, 0.36884544789791107, 0.8319408212389264, 0.2707924150994846, 13.067953910146441, 45.997307436806814, 47.90739849635533, 49.06782409123012, 45.28807353973389, 47.848512513296946, 48.37920549937657, 48.47071327481951, 46.066827637808665, 44.77175637653896, 45.8741888318743, 46.96243306568691, 43.99624013900757, 44.86187103816441, 44.91087320872715, 46.53269740513393, 45.00458008902413, 40.63733502796718, 37.457863671439036, 36.91141217095511, 34.0378908429827, 33.4109514100211, 32.94584941864014, 33.655204909188406, 33.51359019960676, 32.93643808364868, 33.53335782459804, 33.33717196328299, 34.258357184273855, 33.32871947969709, 34.61741576875959, 33.985675130571636, 34.77999666758946, 36.67588560921805, 35.55303239822388, 36.37463256290981, 36.98291608265468, 35.18429149900164, 35.072432449885774, 36.61191007069179, 35.25624009541103, 34.04509265082223, 34.857333592006135, 34.37857839039394, 36.20834827423096, 42.75986378533499, 45.8853302683149, 41.994307790483745, 41.48408072335379, 43.97744526181902, 46.99861928394863, 38.74563237598964, 36.41239602225167, 35.44027355739048, 41.306783539908274, 48.43695892606463, 47.874380656651084, 46.371881348746165, 34.46725130081177, 34.63587365831648, 48.444101674216135, 43.74900933674404, 46.224225180489675, 35.15909385681152, 48.57720831462315, 44.82496220724923, 45.949778284345356, 43.913709436144146, 43.94792931420462, 35.79263407843453, 31.824900014059885, 34.54609945842198, 34.35956464494978, 32.704653126852854, 32.245168754032676, 33.69058861051287, 33.97513123920986, 33.44491420473371, 35.394029821668354, 34.531640257154194, 34.378495012010845, 33.78228398731777, 34.55521549497332, 34.27275037765503, 34.85747255597796, 33.63790736879621, 34.04636764526367, 32.58198268072945, 33.600296769823345, 33.468753474099294, 36.08077587400164, 36.133081912994385, 36.63313681738717, 36.04398168836321, 34.094546454293386, 33.31357588086809, 32.01122638157436, 31.30489683151245, 31.117872170039586, 30.77257101876395, 31.55758544376918, 34.73197071892874, 37.10421773365566, 42.026001998356406, 41.75621734346662, 43.391420296260286, 45.650647912706646, 45.6516102382115, 43.265296595437185, 42.934739521571565, 43.387379918779644, 45.190701484680176, 44.593205043247764, 42.461407388959614, 18.62050519670759, 0.9014352921928678, 0.40651752214346615, 5.438811881201608, 1.1288124855075563, 0.16905594138162477, 0.20938452093728951, 0.026419152805049504, 0.39713178149291445, 16.630403893334524, 50.250473499298096, 23.57385860170637, 28.374801533562795, 31.024429321289062, 46.28183964320591, 5.1323072995458325, 0.18741310920034135, 0.05451602415580835, 0.010465567216410168, 0.01574750178094421, 0.008433427778072655, 0.0534602779495929, 0.054231585668666024, 0.04539695116026061, 0.0678137397127492, 0.02381178530465279, 0.0518205946843539, 0.03879463579505682, 0.03721695705982191, 0.006871364254038781, 0.016477853126291717, 0.057875800478671274, 0.05915329871433122, 0.06831310755972352, 0.04012820137930768, 0.04100269731134176, 0.0418340418088649, 0.00972426007501781, 0.007011731097009033, 0.06666883400508336, 0.012848041070226048, 0.05716890948159354, 0.015189428780493992, 0.045328758390886445, 0.06772000009992293, 0.016116584118987833, 0.023508712549560835, 0.04102447150009019, 1.0467561057635715, 30.17180892399379, 49.66471951348441, 24.728015184402466, 33.37481035505022, 36.961762292044504, 41.561775479997905, 48.28365734645298, 40.708561011723106, 1.8993148377963474, 0.7478530704975128, 1.484908966081483, 0.7506693708045142, 0.3046638789985861, 15.24721384048462, 49.012335777282715, 48.26287875856672, 48.86363043103899, 47.48558725629534, 51.0646390914917, 48.835858481270925, 49.33275542940412, 46.87780400684902, 47.23638663973127, 46.707343850817, 47.072388308388845, 46.322573457445415, 46.66633210863386, 47.241688115256174, 46.955286843436106, 44.854912417275564, 43.83471884046282, 39.8263829776219, 38.589735644204275, 35.83026204790388, 35.08098220825195, 35.600057806287495, 36.80925628117153, 34.8435309955052, 35.40812771660941, 35.266995906829834, 36.63581187384469, 35.857585838862825, 36.37451791763306, 37.77665744509016, 36.33239793777466, 36.60081032344273, 38.45315490450178, 36.65939058576311, 37.78732292992728, 38.18177911213466, 37.20632151194981, 36.43880612509591, 37.23229040418352, 36.753100940159385, 35.4164377621242, 35.23675387246268, 36.421182019369944, 36.49017415727888, 43.3577493258885, 45.7180871282305, 44.283864293779644, 42.817724909101216, 44.95713084084647, 47.729872022356304, 39.84859984261649, 38.20014667510986, 37.51644393375942, 43.64703062602452, 50.58470964431763, 48.68574265071324, 47.963692801339285, 37.00576523372105, 41.680593150002615, 52.4807688168117, 43.61895990371704, 47.027343136923655, 37.46423169544765, 50.62192072187151, 45.62298713411604, 46.87650121961321, 45.241562298366, 47.44664260319301, 37.25347546168736, 33.99949509756905, 35.386456285204204, 35.31278453554426, 35.99296801430838, 34.39747749056135, 34.879011971609934, 35.452057702200754, 34.96793849127633, 36.19036981037685, 35.67494201660156, 35.39764288493565, 34.84350667681013, 35.81720985685076, 34.58405746732439, 36.72893510546003, 35.117067677634104, 35.01420654569353, 34.569730281829834, 34.985764094761436, 34.91282538005284, 37.555680411202566, 37.99647760391235, 38.45507608141218, 38.14137533732823, 36.25669731412615, 34.30553545270647, 33.51281547546387, 32.68256132943289, 34.49907405035836, 33.39723914010184, 33.124046393803184, 37.87765645980835, 40.577986989702495, 43.81208160945347, 44.22549595151629, 44.95329543522426, 46.5500123160226, 45.53968170710972, 43.547462940216064, 43.55953890936715, 43.456497124263215, 44.797989300319124, 45.02317346845354, 43.90082400185721, 22.013998440333776, 1.0562504934413093, 1.8289156896727425, 9.280620268413, 2.882935485669545, 0.13652311850871357, 0.2660795822739601, 0.12622066347726754, 0.5765101675476346, 17.67758079937526, 54.811906814575195, 29.93214123589652, 30.574780123574392, 28.0677067892892, 54.78866856438773, 7.290566733905247, 0.28333581345421927, 0.0426127421669662, 0.04132363758981228, 0.017656702548265457, 0.0694188346554126, 0.023705116207046167, 0.08451913616486958, 0.03861504793167114, 0.027738207917926565, 0.07438103588564055, 0.031545676557081084, 0.04689831506194813, 0.023186886782890985, 0.06256436210657869, 0.17590112478605338, 0.11287989148071834, 0.1711311185998576, 0.20586072573704378, 0.11511574579136712, 0.11458241726670947, 0.17274459345000132, 0.11027663759887218, 0.13721293077937194, 0.18895319370286806, 0.13530446961522102, 0.07658157244856868, 0.12222122879964964, 0.14511167550725595, 0.17629768779235228, 0.10269755750362362, 0.12287095322140626, 0.30190492847136086, 1.3592426521437508, 35.53365734645298, 54.906329359327046, 33.44772475106375, 39.38219506399972, 38.09448194503784, 48.012667179107666, 52.938304219927105, 51.12431716918945, 2.4404590002128055, 1.2273446725947517, 6.8152691296168735, 3.2506322009222846, 0.7096356440867696, 16.501770155770437, 50.19540902546474, 47.38603694098336, 49.421671526772634, 47.1982410294669, 52.21072360447475, 49.29424156461443, 50.35789612361363, 47.66914129257202, 48.18555573054722, 49.48516763959612, 49.03116192136492, 46.78493438448225, 48.10154158728463, 49.09657226290022, 49.853210244859966, 47.79619952610561, 45.21824761799404, 40.97099794660296, 42.1326915877206, 36.8194979258946, 37.29130145481655, 36.376786504473, 39.74043376105172, 37.55193533216204, 36.468825817108154, 37.10623618534633, 38.79855333055769, 38.889088358197895, 38.83751882825579, 40.45151587894985, 38.47085544041225, 37.97565037863595, 41.12924664361136, 38.61038221631731, 40.31684241976057, 41.056380884987966, 38.28028719765799, 39.352498463221956, 39.0620950290135, 38.618977137974326, 36.872373717171804, 38.246657916477744, 39.51455477305821, 38.77962643759591, 46.29355430603027, 49.789331981113975, 45.73026384626116, 46.137744426727295, 46.25093752997262, 50.04538352148873, 41.44558422906058, 38.724923270089285, 39.38287598746163, 44.77232960292271, 52.28679943084717, 51.00641318729946, 49.33035135269165, 38.838303974696565, 42.684336866651265, 48.1069472857884, 47.30604233060564, 48.65123789651053, 42.23425688062395, 50.11831876209804, 47.95074135916573, 50.183037757873535, 47.97639410836356, 48.36824124200003, 39.513008798871724, 35.23045185634068, 37.71884148461478, 37.625874587467735, 37.297756331307546, 35.17897612707955, 36.70860467638288, 37.97892645427159, 36.2777156148638, 39.54435907091413, 38.240408011845176, 36.98898533412388, 37.17557920728411, 38.70532587596348, 36.13326951435634, 37.99355241230556, 37.07858582905361, 36.843226024082725, 36.89365257535662, 36.81862940107073, 36.26755734852382, 40.033557415008545, 41.002237047467915, 40.50787271772112, 40.12727124350411, 38.024451051439556, 36.832140173230854, 36.16531113215855, 34.60827193941389, 35.777177810668945, 34.31810474395752, 34.87164340700422, 39.733304909297395, 40.74605696541922, 46.627352714538574, 45.36789097104754, 47.56085361753191, 48.29777261189052, 47.78320639474051, 44.49779238019671, 43.641996656145366, 44.86177723748343, 45.51947634560721, 44.924800872802734, 44.37431246893746, 24.104879890169414, 1.7430560397250312, 1.1599844928298677, 11.145299639020648, 3.0890898406505585, 0.21778890996107034, 0.9454065327133451, 0.30749700697404997, 0.8133449990834508, 18.71147448675973, 61.86885860988072, 30.66939721788679, 40.290727615356445, 37.31478984015328, 61.78677259172712, 10.479850683893476, 0.3438744092626231, 0.11110265220382384, 0.14358841867319175, 0.13253962940403394, 0.11502209438809327, 0.12310400285891124, 0.15522414073348045, 0.1598751318774053, 0.11869115036513124, 0.1855073757469654, 0.10161608124950103, 0.1690615460808788, 0.18954312561878137, 0.11210083149905715], [0.012675162221837257, 0.004146512656006962, 0.02403375955431589, 0.032557575830391476, 0.027817448933741877, 0.05324444953086121, 0.03691867645829916, 0.003665120473929814, 0.02033531622562025, 0.04186860638271485, 0.019441780600962893, 0.030842968728393316, 0.046676118592066426, 0.026700388606903807, 0.038901579699345996, 0.033479219768196344, 0.1094882884728057, 0.011918367518644248, 0.031780310573854616, 8.095353126525879, 41.521927561078755, 29.69730601991926, 23.074201481682913, 29.597964150565012, 34.75052240916661, 41.13434662137713, 40.945744718824116, 3.200544157198497, 0.574484007699149, 0.8150355283703122, 0.365006432469402, 0.11371046584099531, 3.4753910090242113, 34.15820584978376, 49.851872716631206, 49.25543587548392, 46.55475098746163, 47.906342370169504, 46.51391642434256, 45.53008624485561, 46.6702230998448, 45.698847566332134, 44.64442368916103, 48.35645014899117, 45.37957089287894, 44.193947655814036, 43.503199441092356, 42.58065584727696, 40.35646799632481, 38.57246937070574, 34.771401745932444, 34.766718660082134, 32.68635504586356, 33.759935106549946, 34.39461830684117, 34.58462027141026, 33.94139078685215, 33.539354119982036, 33.66941744940621, 33.807610171181814, 34.78624309812273, 33.83392647334507, 36.053889819553916, 34.48254081181118, 36.38835525512695, 37.008812018803184, 36.159988812037874, 35.450007983616416, 35.901456764766145, 35.048791204180034, 36.577380997794016, 35.261565889631, 35.51863881519863, 35.32911627633231, 35.553716795785085, 35.091779708862305, 38.90520123073033, 44.390883922576904, 44.86197873524257, 44.09786796569824, 44.34733608790806, 44.165856088910786, 42.23211683545794, 41.26008469717843, 37.862234933035715, 36.38820934295654, 39.6449099268232, 47.48837695802961, 47.687745094299316, 47.041534832545686, 39.00971950803484, 28.95733850342887, 45.007807527269634, 41.680363859449116, 44.58343587602888, 40.41023663112095, 39.222379548209055, 45.91718428475516, 45.91543333871024, 44.320616790226524, 44.57823862348284, 37.53364419937134, 33.19423362186977, 32.83895833151681, 33.023599760872976, 33.19811766488211, 34.976759229387554, 33.47234569277082, 34.09661701747349, 34.313178471156526, 35.268614837101524, 34.471142292022705, 32.386814730507986, 31.5667952810015, 34.05205127171108, 33.4380841255188, 34.39113031114851, 34.7932573046003, 35.48677090236119, 33.05314350128174, 32.453305516924175, 32.401485851832796, 34.78393629619053, 37.83901752744402, 36.10007796968733, 38.098626545497346, 34.88068996156965, 33.64228820800781, 32.20066901615688, 31.437183584485734, 31.704859461103165, 29.995706830705913, 32.20742613928658, 33.557301316942485, 34.59282956804548, 37.51027045931135, 40.236191204616, 41.74995354243687, 42.94913966315133, 44.149270738874165, 44.60611827032906, 42.599818978990825, 43.30756943566458, 43.72209201540266, 46.807269368852886, 35.46236188071114, 4.64802828005382, 0.04703191860712, 2.5429746764046803, 10.424883484840393, 0.867106631398201, 0.18981462105044297, 0.08323185345424072, 0.396441711378949, 0.3399691959576947, 25.39111304283142, 44.3122615814209, 21.054037060056412, 22.47059062549046, 34.32164832523891, 33.20203297478812, 0.37569262619529453, 0.010393540724180639, 0.045833846288067956, 0.05988667971853699, 0.02367596125363239, 0.043374357013297934, 0.06581690614776951, 0.033488983887114694, 0.03262238271002259, 0.026644141446532946, 0.08627485909632274, 0.06025270186364651, 0.03851228719577193, 0.03381250938400626, 0.00941858089728547, 0.06326454917767219, 0.01990558473127229, 0.025503101692135845, 0.008871852154178279, 0.09481201028185231, 0.04653546506805079, 0.09393482056579419, 0.06171934852110488, 0.022524146363139153, 0.036857737228274345, 0.015962982450478842, 0.03993130748027137, 0.058890556384410174, 0.007650375465995499, 0.08128977087991578, 0.03758444484057171, 0.07991934727345194, 0.035679176183683534, 0.1129199250468186, 11.713903733662196, 48.72032036100115, 30.520830835614884, 27.639821086611065, 36.07352542877197, 37.89302240099226, 47.38190623692104, 44.65793446132115, 3.598183265754155, 0.6644626909068653, 0.20247841865888663, 0.2565061588372503, 0.06954247730651072, 4.292321767125811, 37.027954305921284, 51.63228954587664, 49.40005220685686, 46.47647953033447, 50.68680647441319, 46.99554123197283, 47.09078713825771, 46.70683315822056, 46.9315379006522, 46.71352079936436, 49.37159933362688, 47.06756625856672, 46.7649861063276, 46.29556233542306, 44.998444829668315, 42.033599853515625, 39.97599853788103, 36.495871680123464, 36.102631432669504, 34.428223269326345, 36.56403350830078, 36.19211033412388, 36.21957308905465, 35.07289450509207, 36.5262839453561, 35.31962503705706, 35.97940513065883, 35.73963669368199, 35.91721180507115, 37.28244597571236, 34.262269020080566, 36.81586054393223, 39.950255462101524, 37.5661096572876, 36.6963654245649, 37.28720201764788, 35.74359021868025, 37.35095868791853, 35.48419312068394, 36.561910833631245, 36.733986445835654, 37.05501406533377, 36.88414396558489, 39.31575986317226, 46.80296148572649, 46.84341389792306, 44.78256777354649, 44.38989380427769, 45.76998322350638, 45.04426819937569, 42.66102566037859, 40.773280007498606, 37.649210112435476, 41.69961731774466, 47.51499898093087, 48.8428692136492, 48.79972784859793, 40.24406698771885, 33.64331654139927, 50.53018365587507, 43.33406639099121, 45.65144348144531, 40.57443298612322, 41.84868744441441, 49.013457911355154, 45.984522751399446, 44.87580565043858, 45.4973532812936, 40.55250794546944, 34.39994410106114, 35.85302782058716, 35.288632597242085, 34.00648498535156, 35.28058310917446, 34.63355990818569, 36.53130749293736, 35.782725947243826, 36.30647073473249, 35.958543164389475, 33.56828989301409, 34.51461369650704, 35.4148188318525, 34.50865561621529, 36.43134723390852, 36.73393086024693, 35.501973560878206, 34.4052733693804, 34.1403420312064, 34.85445703778948, 36.63924775804792, 39.31771230697632, 38.07394307000296, 39.489239011492046, 36.74253967830113, 35.70805713108608, 33.87066854749407, 33.24035576411656, 32.978544167109895, 32.97169671739851, 33.98292016983032, 36.21279512132917, 35.388968058994834, 39.378394399370464, 40.77394356046404, 43.21293497085571, 44.43731525966099, 46.746153014046804, 45.513667651585166, 44.338841915130615, 43.91514771325247, 45.58590807233538, 47.056737491062705, 38.096489974430625, 5.607438147068024, 0.161270620567458, 3.0624289512634277, 10.076585922922407, 1.483292315687452, 0.1445442980953625, 0.14202349978898252, 1.0536422048296248, 0.41023090002792223, 27.68496526990618, 51.34772607258388, 30.905517850603374, 24.66361059461321, 36.67638240541731, 42.874182496752056, 0.6027847262365478, 0.07296774922204868, 0.035696594177612236, 0.05740492431713002, 0.04335820109450391, 0.044512830208987, 0.05427739017509988, 0.03587460444707956, 0.02874748974240252, 0.029430319887718985, 0.047492715130959234, 0.016595870722085238, 0.04454514883192522, 0.018576516137857522, 0.0497182896360755, 0.08677604541714702, 0.1900587443794523, 0.10336971429309674, 0.08959894108452968, 0.12867659383586474, 0.11881023326090404, 0.19080307015350886, 0.14621890895068645, 0.10103936041040079, 0.12515389786234923, 0.10526039783975907, 0.137016304901668, 0.1461664717644453, 0.10736614306058202, 0.1537694295070001, 0.10867030772247485, 0.18951537353651865, 0.21849839974726948, 0.12566400691866875, 12.521288752555847, 58.87392793382917, 39.17609064919608, 32.794969286237446, 38.10818031855992, 43.85215881892613, 48.558785166059224, 54.137493814740864, 4.211441261427743, 1.322282144001552, 2.050462910107204, 1.5771537934030806, 0.5814658073442323, 4.4235619476863315, 39.04917137963431, 50.77194275174822, 49.30778707776751, 46.84555394308907, 51.90376608712332, 47.662266050066265, 47.23360388619559, 48.82976838520595, 50.39385305132185, 49.71885987690517, 51.15581682750157, 48.86267505373274, 48.62545313153948, 48.126270226069856, 47.21142871039254, 44.56398786817278, 41.97247307641165, 39.18822915213448, 37.186182158333914, 35.794294697897776, 37.333230359213694, 38.66685022626604, 39.09817702429635, 37.94843428475516, 38.04246425628662, 38.41154214314052, 38.382668903895784, 38.920153754098074, 38.82604387828282, 39.84098809106009, 36.82078334263393, 38.35054390771048, 41.784927300044465, 40.54690074920654, 39.25417797906058, 38.44547019686018, 37.29069001334054, 39.44665002822876, 37.35111502238682, 39.102971281324116, 38.367150102342876, 37.70863805498396, 39.91805403573172, 43.79479796545846, 47.495943546295166, 47.44151135853359, 47.17014946256365, 48.24734953471592, 45.95832109451294, 45.38885021209717, 44.04625327246529, 42.411112853458945, 39.394524642399375, 43.65446867261614, 50.90279122761318, 51.52976540156773, 50.48954364231655, 39.99272632598877, 34.96538850239345, 45.39596516745431, 44.73236703872681, 45.515838963644846, 43.449173722948345, 43.25866106578282, 49.22498886925833, 49.43352515356881, 46.68311200823103, 48.572632925851, 42.89149740764073, 36.79265356063843, 36.45870576586042, 36.52163560049874, 35.462862151009695, 37.898521900177, 35.69891677583967, 38.40783180509295, 36.94973496028355, 39.463985783713206, 36.99124002456665, 33.450566564287456, 34.21844325746809, 37.259610721043174, 35.368964195251465, 37.08767754690987, 37.48247766494751, 38.175581318991526, 37.00626202992031, 36.27885511943272, 36.960723536355154, 38.79751457486834, 41.278417519160676, 39.85769156047276, 42.39772367477417, 38.72569104603359, 36.701378549848286, 36.28986801419939, 35.79234920229231, 34.74108675548008, 33.660495962415425, 35.83331230708531, 37.82240785871233, 38.08973979949951, 42.258398396628245, 42.28631278446743, 45.624390670231406, 46.38389131001064, 47.235667501177105, 46.75052343096052, 45.869314670562744, 43.83223833356585, 45.9616562298366, 46.87757124219622, 39.77597379684448, 6.5366489716938565, 0.1558798226927008, 5.35905350957598, 19.081400053841726, 2.721868642738887, 0.21484378299542836, 0.31348271721175736, 2.816848563296454, 0.9384151250123978, 30.887779099600657, 54.37121384484427, 30.863001823425293, 33.23929268973214, 44.02868822642735, 48.67442056110927, 1.7453453625951494, 0.21510166701461586, 0.18670475935297354, 0.15897371167583124, 0.11036465037614107, 0.18713984957763127, 0.13961252916072095, 0.13854811127696717, 0.14599742154989923, 0.08396806394947426, 0.12052797180201326, 0.15663609068308557, 0.20586927527827875, 0.17518634242670877, 0.1690006407776049], [0.025376101989032965, 0.017480244427653294, 0.05559575318225792, 0.02718300512060523, 0.034874844165252786, 0.05293855576642922, 0.015036135845418488, 0.012744547516506697, 0.06767627530332122, 0.0204732488242111, 0.10082704001771552, 0.041478676056223254, 0.03019621629001839, 0.021665928486202444, 0.027424514393455217, 0.061063578352332115, 0.021252380052049245, 0.07302877666162592, 0.02749575548140066, 1.1723846388714654, 30.971035889216832, 44.522698198046, 23.790241139275686, 26.452063015529088, 31.905606814793178, 36.93701975686209, 42.41513933454241, 2.4158712795802524, 0.5958992785641125, 0.2358595867242132, 0.19795180298388004, 0.07718094957194158, 0.12432618013450078, 15.026184695107595, 43.31388882228306, 48.51676593508039, 48.042540958949495, 47.903451919555664, 49.41935430254255, 46.54576696668352, 49.082731451307026, 48.24887466430664, 46.40570865358625, 42.8365649495806, 42.56503282274519, 41.18205295290266, 37.91540254865374, 37.20810372488839, 35.719080448150635, 35.90711954661778, 34.4369397844587, 34.541544914245605, 33.5791186605181, 33.707299028124126, 34.81180899483817, 33.97237280436924, 35.88075113296509, 34.56223317555019, 34.35266508374895, 34.53531585420881, 33.95658649717058, 34.08237668446132, 35.84142780303955, 35.239995207105366, 35.968308857509065, 35.292089326041086, 35.82984168188912, 35.799686500004356, 37.123481614249094, 34.68989937646048, 36.44204051154, 35.33904872621809, 35.60724571772984, 34.92764588764736, 36.73898914882115, 34.27895164489746, 39.07344838551113, 45.84152882439749, 46.58354432242257, 45.427718435014995, 44.218978541237966, 43.37162140437535, 41.57818365097046, 43.4032496043614, 39.21704680579049, 37.98457186562674, 40.68814025606428, 45.73628446034023, 50.118812084198, 46.4633161681039, 39.676621505192344, 32.81724868501936, 40.26267426354544, 47.10132755552019, 43.215561389923096, 44.627122674669536, 40.60449436732701, 45.592029435294016, 45.67262506484985, 43.379535402570454, 43.87511566707066, 35.675501346588135, 31.28670644760132, 33.97512429101126, 33.093366622924805, 34.865918091365266, 34.479219572884695, 33.12014845439366, 33.96220064163208, 34.37125151497977, 33.101513385772705, 32.2223995072501, 33.53482389450073, 33.478314195360454, 34.91970409665789, 35.629254136766704, 32.86858892440796, 33.50168446132115, 34.34328848975045, 33.30828135354178, 33.30194459642683, 32.058307375226704, 33.768019335610525, 37.56175661087036, 38.25450243268694, 36.821085589272634, 36.07006522587368, 34.184713227408274, 32.343468393598286, 31.453994750976562, 32.64441224506923, 31.429658685411724, 33.74858522415161, 32.28406824384417, 37.605134214673726, 36.16214622770037, 38.21228865214756, 38.230888979775564, 40.87553664616176, 42.13803475243704, 45.01311247689383, 42.011372566223145, 44.184977531433105, 39.523198332105366, 47.478312492370605, 19.504741634641373, 1.3693848507744926, 0.289007090564285, 4.049578198364802, 7.737921289035252, 1.566341745001929, 0.06952600247625794, 0.092223996296525, 1.167157530784607, 0.4330387961651598, 34.62302643912179, 34.08688259124756, 23.94818237849644, 22.381398337227957, 35.03184107371739, 11.264411738940648, 0.10168334442589964, 0.02221417799592018, 0.021922681048246365, 0.04058749155540552, 0.01548933277704886, 0.06048974807241133, 0.05092541021960122, 0.05532282943438206, 0.08098107137318168, 0.004069676198663988, 0.08274418355098792, 0.06352161895483732, 0.023924394976347685, 0.040015408503157754, 0.052411262810762436, 0.020094872252749543, 0.05591815909636872, 0.0948208990905966, 0.015133736322500875, 0.05940137790249927, 0.02308227025371577, 0.03922836894967726, 0.02669962525500783, 0.03425469369228397, 0.07962232535438878, 0.1800812804805381, 0.0498932464979589, 0.051134056345160515, 0.12038003759724752, 0.015390767083902444, 0.12731720320880413, 0.02941498838897262, 0.040267735320542536, 0.047704692863460095, 2.444765580551965, 38.834600584847585, 44.97343478884016, 21.64879764829363, 36.12520612989153, 39.511045932769775, 40.11162390027727, 50.0202762058803, 3.1121422265257155, 0.6709119219865117, 0.04398202583459871, 0.21090187451669148, 0.03250405977347067, 0.07894998536046062, 16.83974095753261, 46.104952403477256, 50.370406355176655, 48.40741865975516, 47.71254668916975, 47.721999713352744, 47.83047498975481, 50.023041588919504, 50.442445278167725, 47.67556142807007, 45.607371057782856, 44.56850419725691, 43.34972415651594, 41.4065249306815, 38.78654684339251, 38.88794190543038, 38.05621821539742, 35.90807144982474, 36.05287190846035, 34.65634652546474, 35.45475707735334, 37.1191702570234, 36.05899327141898, 36.92095899581909, 35.225414412362234, 36.05965682438442, 35.73130580357143, 36.92435666493007, 34.952107020786826, 37.52105058942522, 36.526099818093435, 37.33354997634888, 37.36499752317156, 35.88497911180769, 38.51073462622506, 37.620413303375244, 37.15613119942801, 37.76530408859253, 37.00551162447248, 37.66733796255929, 36.734135832105366, 38.839221136910574, 35.43796328135899, 41.070701122283936, 47.00573423930577, 48.01426526478359, 47.79948254993984, 46.60870374952044, 47.33219882420131, 43.94267300197056, 44.442953722817556, 42.57198796953474, 40.37076391492571, 42.021645477839876, 47.83676658357893, 50.256535802568706, 48.24794013159615, 41.62251663208008, 35.64953940255301, 45.62598875590733, 46.47526706968035, 45.07076515470232, 45.53918143681118, 42.236761706215994, 48.36862686702183, 47.4915314401899, 44.65884467533657, 44.47200761522566, 36.83743470055716, 33.994061606270925, 35.32336664199829, 34.78848736626761, 36.633418219430105, 34.92005845478603, 34.70331634793963, 35.020098618098665, 36.160478660038535, 35.70693499701363, 33.725572790418354, 34.56950099127633, 35.86523927961077, 34.90892049244472, 35.81956877027239, 35.0322927066258, 36.41984796524048, 34.69621876307896, 35.322331360408235, 33.79407508032662, 35.06581081662859, 36.11124719892229, 38.78397600991385, 39.32627943583897, 39.47302539008004, 38.091105120522634, 36.02257081440517, 33.968051024845664, 34.432107312338694, 34.16600867680141, 33.743315015520366, 33.98792634691511, 34.771693570273264, 38.4599780355181, 37.38790225982666, 40.53681891305106, 41.1286039352417, 42.158118520464214, 44.95268051964896, 46.85777929850987, 42.51480082103184, 44.54000268663679, 40.61057751519339, 47.63746445519583, 22.289511884961808, 0.46973611414432526, 1.305156028696469, 9.485323752675738, 5.788245039326804, 1.1510176254170281, 0.05366363828735692, 0.22015650863093988, 1.993162201983588, 0.5885676262634141, 37.64455829347883, 40.13437230246407, 30.7122745513916, 24.577426876340592, 40.546403953007285, 16.79461588178362, 0.05691443170819964, 0.023910454474389553, 0.03749081040067332, 0.062283462179558616, 0.032941976096481085, 0.04578438787055867, 0.025647806070212806, 0.11171869414725474, 0.032250562483178716, 0.02122947440615722, 0.05617550368021641, 0.048646323050239255, 0.02631434628606907, 0.02470516486625586, 0.02007950173823961, 0.11126822831907443, 0.148793650791049, 0.22061214489596231, 0.10803768916853837, 0.11941064175750528, 0.11329737372164216, 0.10024210890488965, 0.14258641244045325, 0.10125934146344662, 0.13562904005604132, 0.21064100494342192, 0.15128243581524917, 0.1870477180927992, 0.13462639600038528, 0.12356494526777949, 0.2397655871297632, 0.14277619868516922, 0.12704874761402607, 0.14958983021123068, 2.5085984638759067, 44.12159258978707, 54.019412653786794, 32.85903515134539, 34.91799831390381, 40.896186692374094, 44.3312475340707, 57.0844714982169, 3.969866292817252, 1.42052261531353, 0.6718868953841073, 0.46353039571217125, 0.8400425836443901, 0.2837635619299752, 17.77726834160941, 47.64591693878174, 51.03270864486694, 48.004666328430176, 47.46035139901297, 48.665203775678364, 46.526610783168245, 52.47324391773769, 52.787785393851145, 49.018286909375874, 47.169263567243306, 47.14004291806902, 44.2045783996582, 41.212027481624055, 41.5173591205052, 39.61952468327114, 39.502742835453574, 38.726028033665244, 39.92490495954241, 36.642551626477925, 37.406273296901155, 39.034951891217915, 36.91801643371582, 39.477020604269846, 36.73144687925066, 37.38632154464722, 38.053546633039204, 38.299113341740195, 39.394972801208496, 39.77243021556309, 38.474246161324636, 39.753756931849885, 38.924082960401265, 37.69601665224348, 40.46725007465908, 39.92776761736189, 39.08701474325997, 38.80692938395909, 39.175472259521484, 39.56699630192348, 38.206115177699495, 40.984425340379985, 37.991659028189524, 42.32818957737514, 48.59283481325422, 50.00543137959072, 49.92697579520089, 46.790513787950786, 45.855133397238596, 46.11256415503365, 46.921268463134766, 42.38258007594517, 42.09831884929112, 44.073518003736226, 50.34909275599888, 51.19891997746059, 50.608538491385325, 40.05857787813459, 36.96362788336617, 40.94858305794852, 49.187965393066406, 46.224763665880474, 46.56843893868582, 46.336560181209016, 48.70848063060215, 49.63217415128435, 46.26138414655413, 47.15211888722011, 38.073911803109304, 34.7363098689488, 37.700463499341694, 35.46259117126465, 39.39463928767613, 38.61833790370396, 34.97018623352051, 36.85028886795044, 38.26362541743687, 36.14793021338326, 34.909059456416536, 36.145672048841206, 37.81748158591134, 37.85100317001343, 38.928095545087544, 36.88573857716152, 37.95741135733468, 36.36069447653634, 36.2714969771249, 34.872098514011924, 35.914269242967876, 38.28024203436715, 40.51971244812012, 41.136444977351594, 42.079555238996235, 39.92759043829781, 37.140400477818076, 35.82382106781006, 35.8859657560076, 37.22213561194283, 35.176321915217805, 36.265320028577534, 35.752369267599924, 41.175504275730674, 40.462851864951, 42.51093067441668, 42.71503053392683, 43.006385871342246, 46.38456875937325, 49.12862082890102, 44.010866097041536, 45.0348117010934, 39.7754214150565, 49.479699407305034, 24.200400250298635, 2.5521000495978763, 1.1167539954185486, 10.392748066357203, 15.698747737067086, 5.346374784197126, 0.30102940116609844, 0.5880784296563694, 4.222350801740374, 1.5879103647811073, 42.635181835719514, 43.732430934906006, 34.80485037394932, 29.678754329681396, 48.16545111792428, 22.810197728020803, 0.18683216108807496, 0.11194455131356205, 0.10416556801646948, 0.12300162549529757, 0.127445785594838, 0.1349992509931326, 0.17049914465418883, 0.1855299166802849, 0.25003312474914957, 0.13684869318136147, 0.14379108351256165, 0.2899150789848396, 0.12132123352161475, 0.225674871089203, 0.10702692304870912], [0.07156929533396449, 0.10667795927396842, 0.017890222071270858, 0.04889360835243549, 0.023166198250172392, 0.05016441284013646, 0.08168442041746207, 0.02375684941320547, 0.07046920686428036, 0.06010390591940709, 0.01956634775602392, 0.005988794603451554, 0.04783362130235348, 0.0193354219331273, 0.058045970275998116, 0.06634374109229871, 0.019111040580485548, 0.0575341580967818, 0.07335792721382209, 0.08431370290262358, 15.696618114198957, 46.32721485410418, 31.668885162898473, 24.774835620607647, 31.929209845406668, 32.9478748185294, 44.90673555646624, 4.9954321299280435, 0.38216595883880344, 0.04167145803304655, 0.08376889356545039, 0.13467397487589292, 0.1364658230117389, 2.0232038242476325, 24.961276633398874, 46.098622594560894, 47.1679607800075, 49.516316413879395, 48.2189279283796, 46.45530489512852, 47.988817487444194, 48.36005973815918, 44.7050119808742, 43.64500870023455, 40.52107082094465, 36.37651552472796, 35.06878464562552, 34.58633647646223, 33.09579154423305, 34.41507032939366, 35.414162227085654, 35.40939923695156, 35.791428565979004, 37.69055536815098, 39.11001328059605, 36.06967960085188, 35.06237145832607, 36.8910539490836, 34.53941529137747, 34.597359793526785, 33.225656849997385, 35.699733189174104, 34.79807240622384, 37.223202160426546, 35.633294514247346, 35.90680340358189, 34.607222761426655, 35.04492800576346, 34.939544677734375, 35.18327358790806, 35.21594401768276, 35.14045531409127, 35.76324667249407, 33.466352871486116, 35.3451110294887, 34.63968127114432, 40.65937123979841, 46.234824657440186, 47.16672052655901, 45.58979558944702, 45.36157853262765, 45.80861520767212, 41.30221857343401, 44.31022923333304, 41.27451957975115, 42.28014278411865, 39.552446774074006, 45.481459277016775, 44.33534002304077, 48.064368724823, 42.112225668770925, 36.36792060307094, 37.16150215693882, 44.997715268816265, 42.77279090881348, 46.83031306947981, 41.86461271558489, 43.46721124649048, 44.98179694584438, 42.34311778204781, 40.14082023075649, 33.586344787052695, 31.62195008141654, 33.59175395965576, 32.948764187949045, 33.741359097617014, 32.68103272574288, 32.92517157963344, 32.68197768075125, 35.17470645904541, 32.397070271628245, 33.796093532017295, 33.99167142595564, 34.820091247558594, 33.78658492224557, 34.92111458097185, 35.03446054458618, 33.57354620524815, 33.3775931085859, 34.51667383738926, 33.29848786762783, 33.808252879551475, 32.40999044690813, 37.15950107574463, 36.686995778764995, 37.15993881225586, 34.96649326596941, 34.42598942347935, 32.23357915878296, 33.03189243589129, 32.09971863882882, 32.11427164077759, 33.006517614637104, 33.08592162813459, 35.02466358457293, 36.684688976832796, 38.582849979400635, 38.369620186941965, 38.64015872137887, 40.27585847037179, 43.730061599186485, 43.11686222893851, 43.75001335144043, 43.90633044924055, 39.11419609614781, 7.878658788544791, 0.12671100002314362, 0.9842078792197364, 3.2612818351813724, 2.5073384514876773, 0.9158800542354584, 0.08365148665117365, 0.11295238616211073, 0.5541794172355107, 2.905039442437036, 41.98552874156407, 27.57168010302952, 21.002879210880824, 21.87841476712908, 34.654710224696565, 3.1735150132860457, 0.24591634422540665, 0.005080771407977278, 0.08903709373303823, 0.03899293765425682, 0.03278392154191222, 0.06052060105970927, 0.09842481570584433, 0.026104098817865764, 0.038231940274792056, 0.025744612661323378, 0.05769393952297313, 0.021322949390326227, 0.015092796912150723, 0.08264025234218154, 0.014773610646703413, 0.03356265921943954, 0.032946834407214604, 0.016296129573934844, 0.004656546649390033, 0.07415808963456325, 0.005590826605579683, 0.06551437452435493, 0.015232429240963288, 0.025096811886344637, 0.011344830705119031, 0.09966713868613754, 0.009004092692131442, 0.026459793659991453, 0.05926043260842562, 0.00549835161239441, 0.016496578996468867, 0.03142207461808409, 0.03456011926755309, 0.009996680858811098, 0.16947333541299614, 21.005648068019322, 54.65869556154524, 31.39636639186314, 25.113002708980016, 38.0659213747297, 36.234456130436485, 48.5315968649728, 4.227798189435687, 0.5345371312328747, 0.061585595698228905, 0.10552721137979201, 0.08740435527371508, 0.06441750231065921, 2.2120285034179688, 27.9006564617157, 48.50717742102486, 47.335561752319336, 50.34819991247994, 49.64768253053938, 46.81623601913452, 49.941302980695454, 49.865008286067415, 46.975429671151296, 45.09040076392037, 41.5374880518232, 38.360966205596924, 37.31287213734218, 36.614501748766216, 35.41708047049386, 35.95069169998169, 36.489267417362754, 36.58627816608974, 38.09760863440377, 40.44679805210659, 40.08478648321969, 37.06266403198242, 37.127476828438894, 38.1928197996957, 36.55467428479876, 35.96339300700596, 35.67588349751064, 37.57513189315796, 36.272712911878315, 38.93863943644932, 36.4190628187997, 37.542878355298726, 36.52081223896572, 37.09252738952637, 37.52677590506417, 37.485441071646555, 36.997597626277376, 36.50032547542027, 36.98288481576102, 37.70930160794939, 37.47543566567557, 36.07151392527989, 42.378699507032124, 48.93194164548601, 50.35699980599539, 45.85041904449463, 48.78749901907784, 46.488357475825715, 44.200034277779714, 45.68556955882481, 42.954541887555806, 43.609941141945974, 41.042015484401155, 46.931781087602886, 46.76390218734741, 48.54766110011509, 43.98269809995379, 38.26755462374006, 42.11854158129011, 48.79381840569632, 44.73884275981358, 46.7247873033796, 41.86665548597063, 46.67842544828142, 46.99386671611241, 42.61609166009085, 42.02245841707502, 34.86485154288155, 33.436228956495015, 34.605207783835276, 34.03084536961147, 36.26699454443795, 35.10239655630929, 34.74868113654, 34.13678455352783, 35.702984946114675, 34.28420448303223, 35.47720670700073, 35.3690892628261, 35.51788493565151, 35.30778530665806, 36.10635914121355, 35.0040864944458, 35.64412328175136, 35.3612516948155, 34.4618421282087, 35.79349912915911, 34.272204944065635, 35.33268417630877, 39.15724713461739, 38.162452697753906, 39.125118664332796, 37.04770108631679, 36.76353018624442, 34.50297893796648, 34.21147768838065, 33.93949045453753, 35.13027620315552, 35.140674182346885, 34.97361169542585, 36.39899294716971, 37.934103625161306, 40.40438624790737, 40.245672021593364, 42.119941643306184, 43.128392764500205, 46.26817601067679, 44.55255460739136, 45.54507350921631, 43.38658435004098, 41.292907987322124, 9.338159169469561, 0.39255764122520176, 2.4080013590199605, 7.778924345970154, 6.4108253461974005, 0.8464464885847909, 0.08773289514439446, 0.0682699866592884, 1.0039458658014024, 4.605148775236947, 43.603750297001426, 34.82935667037964, 25.858334234782628, 22.075017520359584, 42.23936380658831, 4.140127556664603, 0.3156439055289541, 0.008945217904900866, 0.037101232912391424, 0.012502213823609054, 0.06262787976967436, 0.09742356943232672, 0.0182094677085323, 0.0407491525235985, 0.017221507150679827, 0.015368770674935408, 0.0816169808219586, 0.06972724917743887, 0.010693429453697587, 0.07325279499803271, 0.032266128076506514, 0.17732129858008452, 0.20239049409117016, 0.07779024687728711, 0.12826230749487877, 0.2399722688964435, 0.07195415361119167, 0.18152715718107565, 0.1188941951841116, 0.2124342644321067, 0.18420173866408213, 0.1568479293159076, 0.10350728726812772, 0.1632244757243565, 0.14108885851289543, 0.18207542704684393, 0.12885089591145515, 0.10438472125679255, 0.1284474389893668, 0.14534198386328562, 0.1816093549132347, 25.088086468832834, 59.872870445251465, 40.269236837114605, 32.16008806228638, 40.112721715654644, 40.42576585497175, 55.50676836286272, 6.86650254045214, 1.0619446507522037, 0.20579730985420092, 0.2926536463201046, 0.29825557715126444, 0.30215259375316755, 3.3085213346140723, 28.91543218067714, 50.20425755637032, 47.11896903174264, 51.04171003614153, 49.93489326749529, 49.028261048453196, 51.47318622044155, 51.62710271562849, 48.603990146092, 47.14292294638497, 45.23493024281093, 41.494770526885986, 39.52049895695278, 38.64456387928554, 37.62031602859497, 38.76267630713326, 39.002604552677695, 38.92234591075352, 39.34497356414795, 42.30487142290388, 43.51571314675467, 39.809273038591655, 38.2643723487854, 42.36544929231916, 38.45070219039917, 38.13184240886143, 36.31156723839896, 41.178790773664204, 38.27899135862078, 42.05980151040213, 39.03862748827253, 38.79742424828665, 38.68154566628592, 37.89273405075073, 38.96852363858904, 40.12354006086077, 37.77069936479841, 37.903712204524446, 39.71150493621826, 39.01569495882307, 39.43087414332798, 39.19398920876639, 43.22066831588745, 50.95931134905134, 50.52336399895804, 47.971318449292866, 48.36180721010481, 46.37969807216099, 45.27929449081421, 49.96200861249651, 44.67007991245815, 46.082012925829204, 41.7811405318124, 48.6900748525347, 49.17712272916521, 52.295012201581685, 42.17401947293963, 39.85156324931553, 39.867234911237446, 47.36057526724679, 46.00119495391846, 49.42564589636666, 44.893450600760325, 47.35756669725691, 50.70935337884085, 44.59101288659232, 44.6933285849435, 35.288462366376606, 35.64612783704485, 37.13196536472866, 35.669609274183, 37.48384646006993, 37.28055259159633, 35.62355661392212, 34.341322149549214, 38.26627615519932, 36.32179151262556, 37.421614919389995, 36.86615507943289, 37.54264906474522, 36.40457929883684, 38.11801896776472, 37.41994735172817, 36.451239926474436, 36.15572261810303, 38.33253765106201, 37.06584283283779, 37.10735484531948, 35.38467059816633, 42.07921825136457, 40.27918665749686, 41.07648549761091, 38.73362588882446, 39.205992221832275, 35.391431195395334, 36.65103885105678, 34.81912544795445, 37.72464323043823, 36.57180854252407, 37.7912278175354, 38.27687563214983, 40.4025936126709, 43.975913184029714, 41.41891009466988, 43.31697729655674, 45.202551637377056, 46.64220101492745, 47.607111249651226, 46.488211563655305, 44.25618267059326, 41.97345277241298, 11.575578127588544, 0.40068958486829487, 2.231678226164409, 7.985431756292071, 12.717121124267578, 3.6322320444243292, 0.29532286737646374, 0.43544683552214075, 1.9782120670591081, 6.237641496317727, 49.484587465013774, 37.91498218263899, 30.011798858642578, 29.77867637361799, 49.05910757609776, 6.916417530604771, 0.5184384265116283, 0.09939392656087875, 0.13441212821219647, 0.07650932882513319, 0.1271726888205324, 0.26198769041470116, 0.16830069119376795, 0.24248461265649113, 0.08497268932738475, 0.12499448284506798, 0.20033487225217478, 0.13019150468919957, 0.1403013914823532, 0.15963556830372128, 0.08223933992641312], [0.008470070365417217, 0.08127252251974174, 0.04377926939300128, 0.09651511960795947, 0.03279314283281565, 0.047252177859523466, 0.05149248907608645, 0.023753636549892168, 0.04549706560958709, 0.026272847084328532, 0.05478984356990882, 0.018737250905750052, 0.023290809510009627, 0.049474098453564305, 0.04275247288335647, 0.04961336776614189, 0.021435374161228538, 0.0386358043178916, 0.11111572078828301, 0.04614363145083189, 4.714719695704324, 39.417061124529155, 40.258699893951416, 31.178168637411936, 39.64000449861799, 27.496771574020386, 44.537598609924316, 12.627911465508596, 0.40920386942369597, 0.15216892824641295, 0.08070642753903355, 0.22563008777797222, 0.06874609432582345, 0.05388319186334099, 3.7133991633142744, 29.74542576926095, 45.566817896706716, 48.74890872410366, 47.1227662222726, 47.703024183000835, 46.41657216208321, 46.954463481903076, 44.22430433545794, 41.85158831732613, 36.66242694854736, 34.71701124736241, 34.64666073662894, 35.74750552858625, 35.44067307880947, 37.11015149525234, 37.18032482692173, 39.99569320678711, 44.145984240940635, 46.19631774084908, 44.71896743774414, 45.46336269378662, 38.28299004690987, 36.250270230429514, 35.79546199526106, 34.86288520268032, 34.86626202719552, 34.95793308530535, 35.53314317975725, 34.025189535958425, 37.678708689553396, 36.428633962358745, 35.250969886779785, 34.549622195107595, 36.17328419004168, 35.931195054735454, 33.87152665002005, 35.950226170676096, 35.19438375745501, 34.74681554521833, 34.52922575814383, 34.72228840419224, 41.19836732319423, 48.4438932282584, 45.52970061983381, 47.262108870915, 46.47441244125366, 45.8785731451852, 43.33153377260481, 47.351500919886995, 42.81241648537772, 41.30008895056588, 40.63143253326416, 47.3977689743042, 47.35312679835728, 51.3269613810948, 43.6732531275068, 41.2868526322501, 38.16674321038382, 45.5803599357605, 44.43317413330078, 46.569967542375835, 43.6860134942191, 42.41446188517979, 43.418038845062256, 40.55795880726406, 35.92888477870396, 33.22560821260725, 31.030981472560338, 33.586945806230815, 33.660999706813264, 33.317685740334646, 33.177259172712056, 33.20414522715977, 32.123641286577495, 35.42436565671648, 33.410562310900005, 33.11429807118007, 33.52882412501744, 32.68441302435738, 32.88652569907052, 35.16140760694231, 34.0830854007176, 32.456428732190815, 35.13531017303467, 33.73321580886841, 32.678326402391704, 32.925772598811555, 32.4418375151498, 37.408058983939036, 36.67464188167027, 37.79511880874634, 34.26845986502511, 33.511064529418945, 32.397841521671836, 32.29530348096575, 30.589753491537913, 31.002330575670513, 31.584402016230992, 32.5518205506461, 32.8411921773638, 34.13976533072335, 35.75279310771397, 38.61740337099348, 37.00698464257376, 39.156666960035054, 41.33152607509068, 44.91806806836809, 42.54536247253418, 46.75051300866263, 27.032859461648123, 0.8896390423178673, 0.1969520766288042, 2.3871617572648183, 8.15283817904336, 5.610260418483189, 1.0959089653832572, 0.05838327681911843, 0.07518123223313264, 0.4013206224356379, 10.421471050807408, 43.79106330871582, 18.89615934235709, 20.552451814923966, 30.21359191622053, 25.460784367152623, 0.21796235708253725, 0.040049535421920676, 0.07339437811502389, 0.029132395517081022, 0.005492783384397626, 0.07249263900199107, 0.08061551063188485, 0.04625569490183677, 0.0237195842699813, 0.09307362392012562, 0.07507139098431383, 0.07690263486334256, 0.041956483452980003, 0.060233601102871556, 0.02931068737858108, 0.024918189239022986, 0.049891872464546135, 0.025707615539431572, 0.0384077283420733, 0.015471215892050947, 0.04978121697370495, 0.022111323961455907, 0.03378356647278581, 0.08862149781946625, 0.02804426961977567, 0.07875096425414085, 0.030814548289137225, 0.018076471452202116, 0.03223648627421685, 0.03737237550584333, 0.042594906874001026, 0.045310325987104855, 0.04233118745365313, 0.04777935207156198, 0.023421220547918762, 0.06892012498740639, 7.4187748943056375, 45.960245745522634, 44.490399496895925, 27.88422223499843, 42.12241172790527, 33.70702110018049, 50.12769883019583, 13.184965917042323, 0.5377173434410776, 0.12500327665890965, 0.1382530571094581, 0.22489560076168605, 0.12261813107345786, 0.03350131965375372, 4.4591167484010965, 32.961600984845845, 47.16862780707223, 48.75895234516689, 47.13749292918614, 49.98895372663225, 48.12286908285958, 49.15212658473423, 45.68134157998221, 42.99239567347935, 38.47383969170706, 35.965154375348774, 35.96808304105486, 37.07493107659476, 36.6287386076791, 37.2503730910165, 38.402009214673726, 41.85548278263637, 43.27359274455479, 47.58664533070156, 45.333229882376536, 46.056811809539795, 39.2148129599435, 37.88770008087158, 37.51135090419224, 36.677827630724224, 36.60557331357683, 36.376942838941304, 37.44606910433088, 35.332107475825715, 38.16948080062866, 38.16347060884748, 36.32127039773123, 36.83936282566616, 37.806725774492534, 37.47767298562186, 35.02902357918875, 37.28735835211617, 35.895300660814556, 34.84608793258667, 37.06887224742344, 36.27641977582659, 42.91134146281651, 48.1974128314427, 47.70730079923357, 47.086930888039724, 47.68859624862671, 47.00807925633022, 45.329721042088096, 48.805699825286865, 44.32449735913958, 43.892076219831196, 42.59044933319092, 48.176717621939524, 48.778285707746235, 51.541021483285085, 45.83290958404541, 40.73378644670759, 43.423149245125906, 47.85859087535313, 44.54529026576451, 47.3980781691415, 45.516207218170166, 44.965138639722554, 45.19712162017822, 42.913544041769846, 38.25605188097273, 35.583746910095215, 33.62603637150356, 35.11819328580584, 34.72874675478254, 35.10380356652396, 34.72558185032436, 34.498643262045725, 34.26446117673601, 35.61971426010132, 34.68204096385411, 35.20744637080601, 33.62967722756522, 35.60608536856515, 33.93504013334002, 35.48764984948294, 34.46124805722918, 34.31032623563494, 36.836246558598106, 34.14367369243077, 35.2789363861084, 35.093666144779746, 34.42834486280169, 37.83023500442505, 38.25178221293858, 38.618282318115234, 36.80419799259731, 36.220987047467915, 34.193787574768066, 33.935123511723106, 33.70920978273664, 33.617524828229634, 34.01972477776663, 35.35729122161865, 34.85829244341169, 36.78691782270159, 37.47307675225394, 40.54308271408081, 37.99361842019217, 40.941155433654785, 43.1962627683367, 46.543453216552734, 43.67743246895926, 45.72716147559029, 30.440891810825892, 1.6088115232331412, 1.3444693705865314, 5.940522193908691, 9.491692645209175, 6.996606256280627, 1.8156551612274987, 0.013155179098248482, 0.0977635019059692, 0.7056377157568932, 12.740449701036725, 48.12841027123587, 27.385343313217163, 20.889712163380214, 29.79221841267177, 34.876121520996094, 0.4160861686936447, 0.07052560669503041, 0.05687494436278939, 0.029014466130839925, 0.0326448150777391, 0.03802773516092982, 0.11466837408287184, 0.049750279169529676, 0.018581540689670613, 0.00316496955513555, 0.06227867850767715, 0.09722353730882917, 0.007084277940780989, 0.03388871565195067, 0.016340945115579025, 0.07100828936589615, 0.16861566714942455, 0.1778085274355752, 0.09658558546964612, 0.19619127602449485, 0.15052090239311966, 0.1395526688013758, 0.10414606013468333, 0.17488218231924943, 0.17766637434916838, 0.16131476605577127, 0.1948650386184454, 0.11031150751348053, 0.12056780180760793, 0.19538909835474833, 0.11129738496882574, 0.12621514020221575, 0.19401741267314979, 0.23185346169131144, 0.27055766912443296, 0.1844064255378076, 7.692320261682783, 51.191721643720356, 51.073817661830354, 41.150525501796174, 48.8076696395874, 37.15654114314488, 55.50544820513044, 15.996861934661865, 0.794267091367926, 0.22583163981991156, 0.20308224697198185, 0.6945885057960237, 0.32328347702111515, 0.3421897425183228, 5.121706085545676, 34.61474766050066, 47.6919834954398, 50.08395644596645, 47.944647789001465, 50.05616365160261, 51.055512632642476, 51.09912647519793, 48.71449429648263, 45.93393291745867, 40.833597319466726, 37.63733564104353, 37.91678524017334, 41.167711871010916, 39.06684759684971, 39.78491612843105, 40.139597347804475, 45.235764026641846, 47.78681598390852, 50.25088344301496, 46.79756620952061, 50.27527162006923, 40.83559145246233, 39.63996975762503, 39.19981527328491, 40.03627763475691, 38.75854907717024, 40.633881773267476, 39.57068232127598, 36.57157230377197, 40.976139613560264, 39.945850304194856, 38.679457732609336, 39.151761531829834, 40.12390831538609, 38.847444329942974, 37.57400975908552, 38.948950563158306, 38.23994943073818, 37.02794735772269, 38.628478799547466, 37.33412320273263, 44.41731834411621, 52.16618912560599, 48.9688435282026, 49.25671781812395, 48.94359377452305, 47.213158811841694, 46.29373148509434, 51.77533558436802, 44.920180320739746, 45.410886423928396, 43.7294362613133, 51.87797089985439, 50.06936175482613, 54.35782814025879, 44.93267665590559, 42.10483973366873, 41.4756212915693, 46.87910679408482, 48.57819495882307, 48.919209071568076, 48.37039865766253, 46.029963970184326, 47.40876797267369, 44.729705878666465, 38.47325256892613, 38.41854245322091, 35.44373723438808, 36.096235615866526, 37.89831345421927, 37.550361565181184, 37.57871716363089, 38.14303248269217, 35.55021142959595, 37.97262791224888, 37.996682575770784, 36.458063057490754, 37.2211628641401, 37.09573745727539, 35.07729271480015, 39.03867959976196, 37.039769717625205, 36.18791709627424, 39.18326466424124, 36.99139983313424, 36.93940993717739, 36.62962450299944, 36.055279459272114, 40.163342816489084, 40.05143165588379, 40.94424043382917, 38.03606843948364, 37.23160948072161, 35.18791151046753, 35.16885607583182, 35.30466903959002, 34.49424505233765, 35.76384769167219, 36.86491135188511, 37.198445728846956, 38.74807814189366, 39.19126551491873, 42.266440936497276, 40.39316143308367, 43.28096825735909, 44.524577685764854, 48.91795144762312, 44.49892841066633, 46.59878519603184, 32.03676795959473, 2.706238452877317, 1.286979649748121, 7.124496102333069, 15.845446790967669, 11.573594416890826, 4.375884277479989, 0.17462062064026082, 0.2222899312951735, 2.0511271144662584, 14.799367700304304, 54.94189371381487, 27.417867830821447, 28.85531289236886, 39.691751207624165, 42.312566552843364, 1.0034272479159492, 0.13309566171041556, 0.13458257620888098, 0.0801758063691003, 0.09409783181867429, 0.10959669801273517, 0.23985781360949787, 0.19597619399428368, 0.16709369953189576, 0.1885678536657776, 0.24280756818396704, 0.32980446996433394, 0.07806492463818618, 0.10233024614197866, 0.09653464784579617, 0.13402773812413216], [0.021190056610586386, 0.04197206600968327, 0.04492098937875458, 0.027694866493610398, 0.055424626650554795, 0.025318765779957175, 0.011072827220362211, 0.06607974347259317, 0.00935625406314752, 0.040368460451385806, 0.05038890615105629, 0.022450421837025454, 0.027958521453131522, 0.0274732705272202, 0.025270942631842833, 0.005083925323560834, 0.021600336202287247, 0.07990861963480711, 0.007681161447960351, 0.09325144759246282, 0.5903788805007935, 15.706606149673462, 43.51233284814017, 28.39952322414943, 26.020317588533672, 27.294909034456524, 37.13530050005232, 23.434576749801636, 0.1776097302458116, 0.2195488940924406, 0.23581732756325177, 0.12521624165986264, 0.013209591669562672, 0.12799177558294364, 0.41090099407093866, 6.816856358732496, 30.230416979108536, 47.972336360386436, 48.9763753754752, 48.45002153941563, 48.75620780672346, 47.38944155829293, 42.807663917541504, 40.38865205219814, 37.26645122255598, 36.17773103713989, 35.58270468030657, 36.657584054129465, 39.066746847970144, 40.53141321454729, 44.170219557625906, 44.92710420063564, 47.31976849692208, 48.284619671957834, 46.43854584012713, 47.159160886492046, 44.5362228666033, 37.36738770348685, 35.80129500797817, 36.58431529998779, 34.72093003136771, 35.505934034075054, 35.38198511941092, 36.221355301993235, 35.39893524987357, 36.53257206508091, 35.17485237121582, 35.89069400514875, 35.55361257280622, 36.939552375248496, 36.09531150545393, 35.38916260855538, 36.04781709398542, 34.994477135794504, 34.79504646573748, 35.81695277350289, 40.17602327891758, 51.37119361332485, 46.62416696548462, 45.664342812129426, 42.86504561560494, 48.57226814542498, 45.85088457380022, 46.5935879434858, 44.457197529929026, 44.999396732875276, 43.28127745219639, 46.26683848244803, 44.38526630401611, 46.58060870851789, 43.02520159312657, 45.552136353084016, 38.424587385995046, 41.53631380626133, 47.65713480540684, 43.873329980032786, 42.92620365960257, 40.44270208903721, 40.1234393119812, 38.10649190630232, 36.41289281845093, 32.13760369164603, 32.32413155691964, 32.580408913748606, 34.10410022735596, 32.942667143685476, 33.669010979788645, 33.68884808676583, 32.078964369637625, 35.607551438467844, 34.29234429768154, 34.651812825884136, 34.46195329938616, 33.31875228881836, 33.30089194434029, 34.82918643951416, 34.732300758361816, 35.50415529523577, 34.54297276905605, 32.494887011391775, 32.15011044910976, 33.338085651397705, 32.30896363939558, 34.71845647266933, 36.453939301627024, 36.63610369818551, 34.47484915597098, 33.242839745112825, 31.017620086669922, 30.612974371228898, 29.87298427309309, 29.539998803819927, 30.188713891165598, 31.381052562168666, 32.73483610153198, 34.92251811708723, 34.03451749256679, 37.53677436283657, 38.12473440170288, 39.979611601148335, 42.44021190915789, 44.395403725760325, 42.35490192685808, 43.09611143384661, 11.089281524930682, 0.15649046349738324, 1.9629933408328464, 3.1905094385147095, 7.194274255207606, 4.95149302482605, 0.5493359257067952, 0.10413262514131409, 0.2071628344378301, 1.1443021914788654, 22.49141958781651, 32.86826583317348, 22.975672551563807, 22.29283138683864, 32.02260405676705, 16.194772686277116, 0.3244251257606915, 0.0352566795689719, 0.05518433365172573, 0.05487209219219429, 0.0677867883018085, 0.04233485493542893, 0.012565572879144123, 0.08237034468246357, 0.019546006972502385, 0.037644444299595695, 0.01836381746189935, 0.08894746604242496, 0.02763858201381351, 0.06306224396186215, 0.026120521061654602, 0.030103782857103006, 0.027013610549537197, 0.03314889535041792, 0.056986743185136995, 0.0007570255641309943, 0.03625914381284799, 0.040823835480426035, 0.017789105086454322, 0.029491591599902937, 0.1138158423293914, 0.06417398287781648, 0.0811092262821538, 0.021529249481058547, 0.056831718289426396, 0.009858950124388295, 0.034469524664538245, 0.07087197846599988, 0.07731135721717562, 0.0318293143729014, 0.030493665686143295, 0.07247544492461852, 1.651850836617606, 25.155457939420426, 50.49279192515782, 28.33028268814087, 35.130814688546316, 36.66567523138863, 41.90730939592634, 23.467017889022827, 0.31047748561416355, 0.2658727105174746, 0.5950266825301307, 0.07071855491293327, 0.09665505388485533, 0.28036847125206676, 0.7380070931145123, 7.678000024386814, 32.85920538221087, 47.47361203602382, 48.32448148727417, 49.73189469746181, 49.03697756358555, 48.59912640707833, 43.62131186894008, 40.64482518604824, 37.75614636284964, 36.70540850503104, 38.01521689551217, 39.77254138674055, 41.09999820164272, 42.0070264680045, 43.65928724833897, 46.87350307192121, 49.12460824421474, 48.71583877290998, 47.68770687920706, 49.51306813103812, 44.28282553809029, 39.055171149117605, 37.2864933013916, 38.32709721156529, 37.14703948157174, 36.4803216116769, 36.17784915651594, 36.9990428515843, 37.46453741618565, 38.338638169424875, 36.32840272358486, 37.90394149507795, 36.671518666403635, 38.458835056849885, 36.91978127615792, 36.7244986806597, 35.97105687005179, 37.37195266996111, 37.06731237683977, 36.38391883032662, 43.65300955091204, 50.749479225703645, 48.82202809197562, 45.04170431409563, 46.643809522901265, 49.479185240609304, 47.76463038580758, 47.89829635620117, 46.40035159247262, 46.69652550561087, 45.47689431054251, 46.513937268938335, 46.74253647668021, 48.30162191390991, 44.92134761810303, 43.87743289130074, 43.24012674604143, 46.75426851000105, 47.60520396913801, 45.786898612976074, 43.23762886864798, 42.37597928728376, 41.592114789145334, 39.4796713420323, 38.26654713494437, 34.091461454119, 33.6004079410008, 33.98046398162842, 35.757076672145296, 34.775365693228586, 34.422452790396555, 36.06979077202933, 35.20096022742135, 36.359277044023784, 33.91820812225342, 35.47441005706787, 34.688221386500764, 34.45721115384783, 35.85866280964443, 35.793426173073904, 35.22904484612601, 36.466536385672434, 36.07891723087856, 34.21242264338902, 34.04972015108381, 34.65448440824236, 33.49634824480329, 35.608194146837505, 37.4459787777492, 39.0265063558306, 36.10188102722168, 34.931158202035085, 33.10198238917759, 32.25102955954415, 31.234084265572683, 32.578546796526226, 31.744644846235, 33.6627402305603, 35.37702063151768, 36.47467620032174, 36.171894550323486, 39.389511517116, 40.58663749694824, 42.70406627655029, 43.50781651905605, 46.58058091572353, 43.51539700371878, 44.39687326976231, 13.787045563970294, 0.28830616389002117, 4.28159635407584, 8.174012814249311, 9.68452947480338, 9.577304874147687, 2.923675379582814, 0.36180743841188295, 0.15458454005420208, 2.0122219792434146, 25.363139595304215, 40.417021547045024, 25.706915616989136, 21.565846579415457, 37.442820821489605, 21.605079582759313, 0.2885480751948697, 0.022123152523168495, 0.0518097483020808, 0.03615313967955964, 0.15346246026456356, 0.0027692063719898996, 0.035806615238210986, 0.012852264950717134, 0.03285974783024617, 0.047807623233113966, 0.05194919403376324, 0.06069657911679574, 0.020073043781199625, 0.11472978150205952, 0.01573242642916739, 0.06854129210114479, 0.14397131598421506, 0.13042962976864406, 0.21975877854440892, 0.0976920182417546, 0.09705258719623089, 0.08662821977798428, 0.07086738478392363, 0.09249588527849742, 0.12834754506392138, 0.08237238028751952, 0.1754237211176327, 0.11038410397512571, 0.1310583060341222, 0.10693655575492553, 0.12108295916446618, 0.1820296123623848, 0.17107033543288708, 0.21356825929667267, 0.0513107807907675, 0.14876574943108217, 2.253208956548146, 28.15906170436314, 56.97794171742031, 38.24987840652466, 34.738918917519705, 37.704295430864605, 46.34830263682774, 28.85245370864868, 0.29909321506108555, 0.752303771674633, 1.3981671120439256, 0.33644743636250496, 0.20128479413688183, 0.37312811666301315, 0.7474750993507249, 9.077500104904175, 33.647023405347554, 49.46339545931135, 50.348436151232036, 51.84605434962681, 51.711794308253694, 50.67713458197457, 46.931933947971885, 44.07085336957659, 41.20387029647827, 39.77147136415754, 41.23669706072126, 41.09351553235735, 43.549366746629985, 44.6358357157026, 46.405958788735525, 49.4150116784232, 51.503727027348106, 51.13891880852835, 50.464519705091206, 51.52476269858224, 47.41724477495466, 42.302981512887136, 38.36231415612357, 39.02518967219761, 38.332402161189485, 38.989785126277376, 37.59495162963867, 39.26706688744681, 39.65726729801723, 40.06332002367292, 38.164182799203054, 40.114396231515066, 38.77503020422799, 40.975086961473735, 38.70512090410505, 38.95436320986067, 37.690687383924214, 37.56017589569092, 38.26266656603132, 37.86498294557844, 46.778927666800364, 54.83715309415545, 49.523855209350586, 46.953355244227815, 46.37619270597185, 50.400075163160054, 46.961133752550396, 50.529450620923726, 48.149508476257324, 48.44149957384382, 46.07281698499407, 49.66932269505092, 48.05664580208914, 48.39507518495832, 43.26486928122384, 43.38655308314732, 41.97514465876988, 46.327353818076, 50.24912902287075, 48.103528772081646, 46.85390567779541, 43.32655886241368, 43.69886071341378, 40.757191453661235, 41.59042290278843, 35.87698173522949, 35.986780643463135, 36.44385051727295, 37.892848696027485, 36.610506534576416, 36.51386751447405, 37.22260114124843, 36.13811240877424, 38.64722156524658, 36.2840176309858, 37.421847684042795, 37.626895972660606, 36.06572607585362, 36.75810364314488, 37.037619250161306, 36.56137582233974, 38.68871620723179, 37.09383017676217, 35.14376265662057, 36.098163740975515, 36.383425508226665, 34.849718366350444, 38.41296999795096, 38.876498222351074, 41.06659821101597, 39.15991176877703, 36.96501404898507, 33.84115259987967, 33.0246558870588, 32.34070995875767, 33.848430837903706, 32.750813484191895, 34.738557611192974, 37.89417927605765, 38.490716866084504, 38.42249597821917, 41.09036799839565, 42.34397241047451, 43.93302542822701, 44.77195092609951, 49.08165100642613, 43.91318484715053, 44.169413566589355, 15.740322283336095, 0.25866311309593065, 5.789776248591287, 10.30354448727199, 13.271735889571053, 10.619255866323199, 1.6167838211570467, 0.7787175114665712, 0.5732123787914003, 3.8435597675187245, 29.599569184439524, 42.649717467171804, 32.83206571851458, 30.997703075408936, 43.91717658724104, 28.321368149348668, 0.27307069141949925, 0.07204440555402211, 0.14090934528836183, 0.168081687231149, 0.2539601054574762, 0.2222761841756957, 0.10272222225155149, 0.12449581388916288, 0.09997119022799389, 0.12802490166255406, 0.17898030312997953, 0.22276580147445202, 0.10772424670202391, 0.26029243852411, 0.16112453197794302, 0.16724702130470956], [0.028156928485259414, 0.024823752431465045, 0.06669214846832411, 0.04978508801598634, 0.018425523436495235, 0.03730020312858479, 0.023514736244188886, 0.0537122451434178, 0.0029162069549784064, 0.013836254382372966, 0.04604436517027872, 0.016501756218661155, 0.04109812308368938, 0.07237337968711342, 0.08080077104802642, 0.031236569929335798, 0.04020549330328192, 0.07439847423561982, 0.031497975545270104, 0.049509341562432904, 0.025146472168021967, 6.26473947082247, 41.826533113207134, 38.71185370853969, 16.696126903806412, 30.213564123426163, 32.01602758680071, 37.22928878239223, 0.36790771250213894, 0.28319223544427324, 1.3646543217556817, 0.027067113035757626, 0.04084906680509448, 0.14668097772768565, 0.3332289547792503, 0.5966389360172408, 8.269462823867798, 35.027012075696675, 50.13663421358381, 49.80588606425694, 48.915686334882466, 46.504470348358154, 45.235555580684114, 40.854365485055105, 37.374193464006694, 37.95694930212838, 39.81584256035941, 39.85176822117397, 41.71652575901577, 42.11754104069301, 44.427285534994944, 45.60494613647461, 48.20371832166399, 45.6678203855242, 47.54105819974627, 46.31535427910941, 44.718369892665315, 41.27621841430664, 36.695271083286826, 35.70345394951956, 35.515154293605256, 35.3324305670602, 34.568719318934846, 34.53988082068307, 35.94288192476545, 34.86107519694737, 37.37539202826363, 35.232508523123606, 35.612859862191335, 36.332307611192974, 34.37440252304077, 35.144679818834575, 35.11154038565499, 36.13497529711042, 35.27907187598092, 35.54825203759329, 39.304580211639404, 46.08543143953596, 45.20221812384469, 48.84914343697684, 41.20344645636422, 44.17616721561977, 49.76070540291922, 44.62066084997994, 46.63722610473633, 44.8520428112575, 45.730253423963276, 46.70822279793875, 46.8280097416469, 46.30348675591605, 40.626342977796284, 49.397873946598594, 35.83790506635393, 42.257335322243826, 47.33135461807251, 43.42696033205305, 41.625059672764365, 39.0669344493321, 38.66105195454189, 36.36820547921317, 34.34569951466152, 32.29175989968436, 32.67897605895996, 31.592993463788712, 34.671705518450054, 32.848425252096995, 35.63476753234863, 35.03035415921892, 33.27564566476004, 32.66925205503191, 33.910658904484336, 34.91476392745972, 32.9906062398638, 32.80450568880354, 32.896086420331685, 33.664602347782676, 38.935161863054546, 40.77115733282906, 41.98605680465698, 37.08627053669521, 33.702212946755544, 33.407602378300254, 31.818288803100586, 32.12259905678885, 33.47385345186506, 35.185462270464214, 33.0950585092817, 32.120153290884836, 30.898531436920166, 30.531843730381556, 29.8434613772801, 30.34812641143799, 29.59907933643886, 30.46396677834647, 31.973396914345876, 33.5396146774292, 35.817567689078196, 37.07761655535017, 38.542230810437886, 39.203230312892366, 41.80195386069161, 44.03402096884591, 45.914085388183594, 32.644308022090364, 2.7486176873956407, 0.7257235465305192, 2.8664458904947554, 7.753819635936192, 9.676603317260742, 8.554675085203987, 1.0005575333322798, 0.18245087404336247, 0.026513269004811133, 4.845128698008401, 31.29266800199236, 26.094208206449235, 20.988826479230607, 18.770829473223003, 34.96883828299386, 2.9285462839262824, 0.06870170456490346, 0.025937879790685008, 0.09045799355953932, 0.024741731118410826, 0.005885957532362747, 0.01921724827427949, 0.047531462873199155, 0.034550772447671206, 0.09552496738199677, 0.023020538834056685, 0.01893475209362805, 0.02920943299042327, 0.09445816105497734, 0.07499282341450453, 0.029904286776270186, 0.060991456865199974, 0.008218725727471923, 0.03607531849827085, 0.10937103762158326, 0.014847118041611143, 0.007399616064503789, 0.09061778177108083, 0.015185101423412561, 0.03214229204292808, 0.01755020478075104, 0.05212183030588286, 0.033921146233166964, 0.050019498116203716, 0.024343644800995077, 0.07736059171812874, 0.019021429853247743, 0.030495830212852786, 0.04074557664405022, 0.029371670713382106, 0.03731689169736845, 0.02931399523679699, 0.04891717726630824, 10.627332278660365, 50.752248082842144, 38.40596621377127, 17.423783949443273, 39.144403389522004, 37.915795121874126, 40.55410950524466, 0.33461113061223713, 0.31823200093848364, 2.422241909163339, 0.13728395982512406, 0.01432924993735339, 0.2927489126367228, 0.4277984159333365, 0.5922520714146751, 10.834497162273951, 37.30137286867414, 48.72215815952846, 50.3605294908796, 50.47499411446707, 47.90117638451712, 45.762065751211985, 40.27720294679914, 39.92884806224278, 39.38894523893084, 41.93050248282296, 41.76757417406355, 43.32158047812325, 44.100949491773335, 45.8752692767552, 45.98843111310686, 50.431821482522146, 45.99906185695103, 48.03681216921125, 48.41741016932896, 47.2395897592817, 41.82922206606184, 38.78433731624058, 36.95155886241368, 36.596064703805105, 36.733541761125835, 36.79662445613316, 37.27487938744681, 37.635292870657786, 37.723402976989746, 39.68479953493391, 37.53873722893851, 37.415896551949636, 37.831200804029194, 35.30887269973755, 36.82593195778983, 36.63891077041626, 37.21830020632063, 39.10583393914359, 35.55679137366158, 41.809023652757915, 47.4756235395159, 45.629028592790874, 50.1397122655596, 41.338015692574636, 47.60833413260323, 48.901671818324495, 49.0149587222508, 47.85460608346121, 46.52835130691528, 47.634990896497456, 47.381524085998535, 47.09030423845564, 49.2228627204895, 44.40934876033238, 47.87702792031424, 40.29363196236746, 43.80207967758179, 47.19653524671282, 44.19399281910488, 44.38840341567993, 39.012550898960654, 40.74571302958897, 37.66109153202602, 36.4255941254752, 34.03759554454258, 33.20220667975289, 35.31969451904297, 36.50481401171003, 35.30945634841919, 34.8880272592817, 35.657227584293906, 33.48979956763131, 33.496615750449045, 35.33138486317226, 35.645238467625205, 34.6420783996582, 34.23051922661917, 34.71373864582607, 35.41955055509295, 39.63551248822893, 43.92493077686855, 41.72471073695591, 36.737418855939595, 34.17137963431222, 36.092608656202046, 33.640902042388916, 34.80794579642159, 35.578935282570974, 36.83578450339181, 34.7157883644104, 34.16234697614397, 33.642854486192974, 31.901288509368896, 30.901751926967076, 33.02989830289568, 31.0671329498291, 32.10696908405849, 33.56865814753941, 36.017453466142925, 37.47209358215332, 39.08321407863072, 38.93228530883789, 41.73054722377232, 43.872530937194824, 45.69592237472534, 44.91866908754621, 35.558903626033235, 3.8415908217430115, 2.4835226322923387, 7.559143270765032, 7.424774663788932, 8.131548030035836, 7.62062440599714, 3.475345194339752, 0.09518716550831284, 0.19632357678243093, 5.37696726833071, 33.71578277860369, 30.59223747253418, 26.401082345417567, 22.231461422783987, 41.402807644435335, 5.352802736418588, 0.24032735984240258, 0.03920191626197525, 0.0681110466165202, 0.059959472955337594, 0.0036489136650093962, 0.027054984222299287, 0.01140187175146171, 0.025036474856148874, 0.03889882145449519, 0.03150701702439359, 0.02070492782097842, 0.03891501808539033, 0.029601843362408023, 0.03376930705936892, 0.03996624524838158, 0.06845574919134378, 0.08017534496528761, 0.15842540109796183, 0.1765510934804167, 0.10201708866017205, 0.09297615236469678, 0.11852404076073851, 0.15318146534264088, 0.14486458019486495, 0.07579143877540316, 0.164607221526759, 0.11705612524279527, 0.145568899544222, 0.17854222735123976, 0.15181344375014305, 0.16903401112982205, 0.17481895642621176, 0.10473379359713622, 0.23479447673474038, 0.09815195641879525, 0.14622509719005652, 0.10661581225161042, 13.678697092192513, 55.45076240812029, 47.171122210366384, 25.474223920277186, 41.25003065381731, 40.65007107598441, 45.678774220602854, 0.884982283626284, 0.9705620514495032, 4.723888712269919, 0.29297711753419464, 0.09922924611185278, 0.7641031156693185, 0.4693194936428751, 0.8651253634265491, 11.017926130975995, 38.365520749773296, 50.68661887305123, 51.379757268088206, 53.83931187220982, 50.95044544764927, 48.499454498291016, 44.42719520841326, 42.63773877280099, 40.67444883074079, 45.459669726235525, 43.49880123138428, 45.060940401894705, 45.89366463252476, 49.47868149621146, 49.6827118737357, 52.678469385419575, 48.62626954487392, 51.34174714769636, 49.28745664869036, 48.41790696552822, 44.55428123474121, 41.29941497530256, 38.11965526853289, 39.51534686769758, 38.79178231103079, 40.0950802394322, 39.561448165348594, 39.453608649117605, 40.0970014163426, 41.68814236777169, 38.96158586229597, 39.59845079694475, 40.31846135003226, 37.76093714577811, 38.201390402657644, 38.664665017809185, 38.52203239713396, 40.346372263772146, 39.27470643179757, 43.13699810845511, 50.29368087223598, 47.82768528802054, 51.625959736960276, 43.73713833945138, 47.28419372013637, 49.43267747334072, 49.78597252709525, 47.852344444819856, 47.38635655811855, 48.591601508004324, 49.0908191544669, 49.09228869846889, 48.83171388081142, 45.23870311464582, 46.15232522147042, 42.14243296214512, 45.61197771344866, 49.41717604228428, 46.24117183685303, 45.106423309871126, 41.41962228502546, 42.56596735545567, 40.38161352702549, 37.474250997815815, 36.58874477658953, 35.1008505821228, 36.279914719717844, 37.23634467806135, 36.553437505449565, 37.17889697211129, 38.42065123149327, 34.770543643406455, 34.19860962459019, 37.785408701215474, 38.31128658567156, 36.376300130571636, 36.360298429216655, 35.928460938589915, 35.98236853735787, 42.16766881942749, 45.80842065811157, 45.23089681352888, 38.99735171454293, 35.95204312460763, 36.5871536391122, 33.51821075166975, 36.77819435937064, 36.69150168555123, 38.23353624343872, 36.30306264332363, 35.86020530973162, 33.65464905330113, 32.44916091646467, 32.64609023502895, 33.79088585717337, 34.48826960154942, 34.23503902980259, 35.847517899104524, 37.65273979731968, 39.405794620513916, 41.86210788999285, 41.455186639513286, 44.547013419015066, 45.323075090135845, 47.04496029445103, 46.372378144945415, 36.92347076960972, 4.782691316945212, 2.3937073945999146, 7.87302553653717, 13.350808995110647, 18.487888404301234, 18.179013184138707, 3.741468148572104, 0.22204077323632582, 0.27351095208099907, 8.548851626259939, 40.439412117004395, 37.11920152391706, 31.823093482426234, 27.007072959627422, 50.418150901794434, 7.452669944081988, 0.36772225531084196, 0.0950350243864315, 0.1383571308106184, 0.1715406144836119, 0.13578700300838265, 0.22782081950988087, 0.0914287736107196, 0.1065532648935914, 0.29708244438682285, 0.18182245562119143, 0.07091191025184733, 0.27319033071398735, 0.24304396978446416, 0.13918361360473291, 0.19073018192180566, 0.16124457839344228], [0.049946202763489315, 0.02817148475774697, 0.039529475649552684, 0.02907666065064924, 0.006559749167146427, 0.008478040607380015, 0.06219377342079367, 0.027453947546226636, 0.050503887302641354, 0.04407255597678678, 0.028432030330545137, 0.016460857520412122, 0.036626774085951705, 0.02791920374147594, 0.03748192837727921, 0.02493576838501862, 0.03392241509365184, 0.04329827627433198, 0.020643698517233133, 0.015084126930949944, 0.09776063848819051, 0.8741062358021736, 21.431470155715942, 40.8454578944615, 24.517151253564016, 34.77761690957205, 26.110932520457677, 36.69818932669503, 6.545485777514322, 0.10525771084108523, 2.2429475528853278, 0.25982389652303284, 0.21886163311345236, 0.5030484923294612, 0.3399878149586064, 0.22635447819318089, 1.2371647570814406, 15.106976611273629, 47.41803339549473, 48.059220109667095, 50.07635511670794, 45.48107712609427, 45.73328978674752, 39.61411551066807, 40.10692344393049, 38.55239255087716, 40.61299548830305, 42.19980771200997, 42.1627390725272, 45.34287745612008, 47.88856192997524, 48.85061992917742, 47.24588482720511, 44.15609039579119, 47.613434110369, 45.3124999318804, 46.9888014793396, 40.92644262313843, 39.84084217888968, 36.08987801415579, 35.734196254185264, 35.80143744604928, 34.87126473018101, 35.329560961042134, 35.27340909412929, 34.51429060527256, 38.329685415540425, 36.93171828133719, 35.65052604675293, 36.28948238917759, 35.675723688943044, 33.16078151975359, 36.8447059903826, 36.216081619262695, 34.43795422145298, 34.311781883239746, 36.66684947695051, 42.55404077257429, 46.35491732188633, 48.293589796338765, 45.31460523605347, 36.81426245825631, 50.49563026428223, 43.67846080235073, 44.23726272583008, 47.11683593477522, 46.49840457098824, 45.02884667260306, 44.27812508174351, 48.33447994504656, 42.25961433138166, 44.42770937510899, 38.90842866897583, 42.941093649183, 46.72037867137364, 43.295569896698, 39.7450612613133, 40.027922425951274, 37.6890093939645, 34.97381666728428, 34.37075819287981, 31.44281162534441, 31.7550984110151, 33.44729743685041, 33.36842843464443, 31.903049877711705, 35.83723109109061, 34.303558690207346, 34.29515136991228, 32.729367869240896, 34.64918640681675, 34.69558647700718, 33.54188673836844, 33.03358432224819, 33.65014662061419, 34.96643073218209, 42.63974332809448, 44.010042735508506, 43.91563408715384, 43.48795509338379, 39.305445262363975, 32.86247798374721, 33.94662625449044, 31.27179561342512, 31.36071171079363, 33.134708404541016, 31.901990277426584, 31.71141161237444, 32.95165811266218, 31.238246236528667, 31.97303213391985, 31.047862121037074, 31.665331159319194, 31.43116991860526, 30.819867406572612, 31.32715538569859, 34.821633747645784, 35.55859790529524, 40.134118693215505, 39.47049624579293, 43.26917369025094, 44.001166411808555, 46.1792425428118, 18.958851201193674, 0.15712352309908184, 2.3734423220157623, 6.666037457329886, 7.217578079019274, 5.889657471861158, 7.598163485527039, 7.630113908222743, 0.25212822375552996, 0.0343756188106324, 12.994942239352635, 39.7824912071228, 22.163297857557023, 19.650780609675817, 25.149256672177994, 21.772145543779644, 0.14930548332631588, 0.044268822230930836, 0.04417933703267148, 0.031556675609733374, 0.022232062482674207, 0.030406511255673, 0.026731365426842655, 0.032757353503257036, 0.0365028735915465, 0.0422118195731725, 0.043121171849114556, 0.055994531605392694, 0.032665422186255455, 0.056026297222290716, 0.06341378616967372, 0.016770646075851152, 0.056396448252988715, 0.040554206020065715, 0.04885301160226975, 0.006330361498320209, 0.04764601994039757, 0.01873714742915971, 0.0566597673376756, 0.061868673722658835, 0.02021726979208844, 0.08579574551965509, 0.016412425387118543, 0.018127593976844634, 0.041943465758647235, 0.06346572124000106, 0.043251559138298035, 0.007326626900716552, 0.020279348960944583, 0.0338340257294476, 0.04522300870823009, 0.004452947552116322, 0.05528270426605429, 0.0956116027331778, 1.6543525138071604, 30.023958206176758, 45.97157825742449, 20.35508128574916, 40.16565309252058, 35.44570704868862, 40.46101406642369, 5.416206785610743, 0.45644746720790863, 3.2210541537829807, 0.24583234159009798, 0.3221880772284099, 1.6931539688791548, 1.7322443170206887, 0.6861549126250404, 1.1040894921336855, 17.893047911780222, 48.627822467258994, 49.35321092605591, 51.09747280393328, 47.488977977207725, 46.987992014203755, 42.168419224875315, 43.36159862790789, 40.12355048315865, 40.72107471738543, 42.59698758806501, 44.39673777988979, 46.04387078966413, 48.99341583251953, 49.03044278281075, 47.95066145488194, 44.700377532414024, 47.8300963129316, 46.790701389312744, 48.86329344340733, 43.18439871924264, 40.98206990105765, 36.85491289411272, 39.762667996542795, 36.914340836661204, 37.07369082314627, 37.03106015069144, 36.07359838485718, 35.609326703207834, 39.29698930467878, 37.64348827089582, 37.73895304543631, 37.377539021628245, 36.92575325284685, 35.88617767606463, 37.75966215133667, 37.58834736687796, 36.821148123059956, 35.64255993706839, 39.29626669202532, 45.988604818071636, 47.57817547661917, 48.71588741030012, 45.285061495644705, 42.151114736284526, 50.61526434762137, 43.88985627038138, 47.86927720478603, 47.56623499734061, 48.8985208102635, 47.80037191935948, 46.96739755358015, 49.34457084110805, 42.68721342086792, 49.076519761766704, 38.39625263214111, 45.80337279183524, 48.75624254771641, 44.476242542266846, 42.75637926374163, 40.91760104043143, 38.580682141440256, 36.26038333347866, 35.19159058162144, 32.54910727909633, 32.570855140686035, 34.29304953983852, 35.07927642549787, 33.59391484941755, 36.72624615260533, 35.45726885114397, 34.60054554258074, 34.079076290130615, 35.164933817727224, 36.04497528076172, 34.01542731693813, 34.296363830566406, 35.62943131583077, 36.7503251348223, 43.975673471178325, 46.30408430099487, 45.373609338487896, 44.06466252463204, 40.79801212038313, 35.45384686333792, 35.78989996228899, 32.287830693381174, 32.089768818446565, 34.3683089528765, 32.462188788822715, 32.87164265768868, 33.14845541545323, 32.374679701668875, 33.24125208173479, 32.50568103790283, 33.96346173967634, 33.058764593941824, 32.19549608230591, 34.457805224827354, 36.524324553353445, 37.174220834459575, 41.13819244929722, 42.028986249651226, 44.963269574301584, 45.61984307425362, 47.53048651559012, 21.0945884840829, 0.88338881198849, 4.557769009045192, 8.73410883971623, 8.188376477786473, 7.8896569183894565, 7.201171210833958, 5.024908993925367, 0.1990717657442604, 0.07347598552171673, 13.960143429892403, 41.13708768572126, 27.532035418919154, 21.95438289642334, 28.097749062946864, 29.598843097686768, 0.3738057017326355, 0.08707477045910698, 0.034949883352965117, 0.010657330542536718, 0.022143230374370302, 0.008454292729896094, 0.06104132240372045, 0.033283387776464224, 0.030771715766085044, 0.03564564637573702, 0.0460876998092447, 0.023564196358035718, 0.005529175337869674, 0.04963779841948833, 0.07318282446690969, 0.04866961715742946, 0.03712161610435162, 0.14234256052545138, 0.1708363222756556, 0.10259967882718359, 0.1330691445618868, 0.1405372502548354, 0.10079825656222445, 0.1453044337353536, 0.09985197841056756, 0.18620161206594535, 0.0845676717747535, 0.12626300406243118, 0.1601445238505091, 0.19936314225196838, 0.12970781778650625, 0.0826322388436113, 0.09610153894339289, 0.1398466508835554, 0.10913933148341519, 0.08302289180989776, 0.18376971541770867, 0.23875703981944493, 1.3328185443367278, 33.045431000845774, 51.30833673477173, 32.57761573791504, 44.696521282196045, 36.12911101749965, 48.54634094238281, 7.9006289924894055, 0.8343719307865415, 4.973694256373814, 0.4392806126603058, 0.6382766674671854, 2.21421240908759, 2.056675902434758, 0.6083392681820052, 1.5962864181825092, 17.670229605266027, 49.2969583102635, 50.02871479306902, 54.295919690813335, 48.97843551635742, 49.825229849134175, 43.65545184271676, 46.66368831907, 42.400968483516145, 43.463990756443565, 45.37832021713257, 46.63873038973127, 48.663077626909526, 51.749957289014546, 51.27417939049857, 50.0478709765843, 45.55950491768973, 50.845968859536306, 49.393691131046836, 52.055146489824565, 45.10471405301775, 43.77358858925955, 38.22994749886649, 42.32658106940133, 40.37156295776367, 38.87799555914742, 38.372670446123394, 37.64705269677298, 37.53678478513445, 42.26732683181763, 39.39403479439871, 41.18808398927961, 40.468928064618794, 39.50200285230364, 36.86654070445469, 42.0195505959647, 39.833084515162874, 37.67527280535017, 37.64305053438459, 39.51526696341378, 47.209000314985005, 50.41193573815482, 50.00254440307617, 48.51665128980364, 42.329923152923584, 49.59748526981899, 44.316159520830425, 48.975128173828125, 49.35270718165806, 49.66985075814383, 48.643174512045725, 49.171199389866416, 51.454394817352295, 44.503965854644775, 50.39460693086897, 40.65037679672241, 47.17424195153372, 49.28776584352766, 45.628583908081055, 44.04735108784267, 43.76531328473772, 40.983911173684255, 38.72872393471854, 38.835809571402415, 33.968867438180105, 34.22791712624686, 36.89184604372297, 35.98550564902169, 34.72427906308855, 39.65085758481707, 36.9980423109872, 36.773726667676655, 36.3271416255406, 38.187052794865195, 38.00309576307024, 36.24791826520647, 36.17627191543579, 37.386877400534495, 37.76792008536202, 46.47847366333008, 47.60854952675955, 46.052208627973286, 45.99612971714565, 42.97354173660278, 37.19842141015189, 36.565169538770405, 34.688384669167654, 34.24582263401577, 36.575338227408274, 32.73427677154541, 33.397134917122976, 35.705746855054585, 35.12230314527239, 35.594481876918245, 34.22192430496216, 35.89860452924456, 35.079147883823936, 34.046781063079834, 36.06732416152954, 38.21323013305664, 39.678903988429475, 45.27063703536987, 44.70188181740897, 46.74895313807896, 47.43356956754412, 46.87841197422573, 22.56491068431309, 1.0679594022887093, 5.9887891582080295, 12.371580260140554, 15.25619786126273, 15.005265406199864, 16.769711800983973, 14.783920117786952, 0.48092944494315554, 0.20904739759862423, 16.79276418685913, 50.33100659506661, 32.25362818581717, 28.11623648234776, 35.47565378461565, 34.912394591740195, 0.5260736282382692, 0.16357996022062643, 0.21770460877035344, 0.14951991396290915, 0.1805825550109148, 0.11966233753732272, 0.17705536713557585, 0.1645087796662535, 0.10624600388109684, 0.1707595121115446, 0.10708470709089722, 0.09095258451998234, 0.13315020235521452, 0.1303057971277407, 0.18408543776188577, 0.1710638486381088, 0.13479178212583065], [0.08878223598003387, 0.07960661048335688, 0.02956581993826798, 0.04157879389822483, 0.06302951821791274, 0.03615198277735284, 0.05171987973153591, 0.037944702830697806, 0.019094659048797827, 0.03849822116483535, 0.02625088969112507, 0.01896857876064522, 0.018683202198839614, 0.034233862667211463, 0.03419076551550201, 0.026143883022346666, 0.09287396499088832, 0.04596749733069113, 0.03603435194651995, 0.02226451172360352, 0.02955462411046028, 0.011887684165100967, 2.8239020705223083, 34.825323241097585, 31.767146587371826, 27.070536068507604, 32.006463391440256, 36.131838185446604, 21.664005517959595, 0.06476848811975547, 1.2586602036442076, 0.221783934161067, 0.052530844429773946, 0.7499482237866947, 1.2274368447916848, 0.5976239517331123, 0.05306691084323185, 2.5916546242577687, 30.095277990613663, 49.21810667855399, 49.64862053734915, 49.14184325081961, 48.3166196005685, 45.455639771052766, 41.74973814828055, 40.54088013512747, 43.31734902518136, 40.72682087762015, 44.02838945388794, 47.07786348887852, 49.160634653908865, 47.404084886823384, 47.72678354808262, 47.5053722517831, 47.87261234010969, 46.0932412147522, 44.048441955021445, 45.19694791521345, 40.99011244092669, 35.64948034286499, 33.70903607777187, 34.84056411470686, 36.26126575469971, 33.851224013737266, 35.98213577270508, 34.15284184047154, 36.86898994445801, 37.538674695151194, 36.25900411605835, 36.1814900125776, 35.68919972011021, 34.47311558042254, 36.67576054164341, 37.31244134902954, 36.02724347795759, 33.30908039637974, 35.12982109614781, 37.22453621455601, 45.233825479234966, 44.177351883479524, 49.63934816632952, 37.55670179639544, 46.10440002168928, 46.46782207489014, 44.42938389096941, 47.721846852983745, 46.09257418768746, 46.92855364935738, 49.05790206364223, 44.43601942062378, 42.455893993377686, 26.032365764890397, 45.7966365133013, 53.326812744140625, 45.79899890082223, 42.459090164729524, 39.45758649281093, 38.88227217538016, 34.85661792755127, 34.196917738233296, 32.411081314086914, 34.232322284153526, 34.452086857386995, 32.215697969709126, 32.49205214636666, 34.27070413316999, 34.065346649714876, 33.188834871564595, 33.73236118044172, 34.2200482913426, 33.7177734375, 34.506129946027485, 32.99965279442923, 32.30068138667515, 34.06580523082188, 33.91060331889561, 42.44521113804409, 44.87032699584961, 45.4473922593253, 44.45879561560494, 44.590985093797954, 38.984768526894705, 34.09222575596401, 31.919180120740617, 31.133481298174175, 30.726424557822092, 33.075780732291086, 31.154638562883648, 33.123910903930664, 33.823525020054404, 37.307282311575754, 36.31812981196812, 39.7592772756304, 36.084958689553396, 36.304938656943186, 33.57691955566406, 36.91324996948242, 35.87006827763149, 38.741824763161794, 38.71186760493687, 46.38050058909825, 45.06437281199864, 39.87358903884888, 4.737209277493613, 0.12606265981282505, 4.829648111547742, 8.463655420712062, 5.938004774706704, 6.586006368909564, 5.962803329740252, 3.9374329703194753, 0.010348837988983308, 0.4356313156230109, 34.280532360076904, 29.082451241356985, 23.050813845225743, 27.25264835357666, 31.368656975882395, 10.397342562675476, 0.08055873760687453, 0.10789088811725378, 0.10768685942249638, 0.020213948363172154, 0.06281939627868788, 0.05794547923973628, 0.014696749592466014, 0.032170329109898636, 0.036122286692261696, 0.003108295553829521, 0.057397636851029735, 0.07095518042998654, 0.023827537495110716, 0.02981972774224622, 0.00969188886561564, 0.05670421816674726, 0.025845415823693787, 0.03225917987791555, 0.06721979765487568, 0.033450185254748376, 0.0659888604921954, 0.03984421072527766, 0.04552015954894679, 0.028506131443594183, 0.0479153915574508, 0.0324591645039618, 0.023128831326695423, 0.08515455028308289, 0.02875132007258279, 0.04550166268433843, 0.035442245325871875, 0.05860361071037395, 0.07917609358472483, 0.046319975916828425, 0.023481318394520452, 0.024928195934210504, 0.1308212937521083, 0.01702299664196159, 0.07509212022913353, 6.004824732031141, 45.32991211754935, 32.39070224761963, 27.966389894485474, 38.29315873554775, 40.447249685014995, 21.319168158939906, 0.024000426521524787, 2.02231228351593, 0.38820277633411543, 0.1154030646596636, 0.8341132189546312, 3.397278057677405, 1.9261268505028315, 0.07985774307910885, 3.240302835191999, 33.99215085165841, 49.71955122266497, 50.889356885637554, 49.17845330919538, 49.43047489438738, 46.74380799702236, 44.091294969831196, 41.61423437935965, 43.98281274523054, 42.18868017196655, 46.81239366531372, 47.9559941973005, 50.22137444359915, 49.12444148744856, 48.158770424979075, 49.550188882010325, 48.58493818555559, 46.69050489153181, 46.380180971963064, 45.071901185171946, 43.81460727964129, 36.87101534434727, 36.77406365530831, 35.89304944447109, 36.27519341877529, 35.827343804495676, 36.77087443215506, 36.46582766941616, 38.36465917314802, 39.136034284319194, 37.21783120291573, 37.84342963354928, 37.146223068237305, 36.33521543230329, 39.10308592660086, 37.653385979788645, 37.67394569941929, 34.8774208341326, 35.9396892275129, 40.57787234442574, 47.2591941016061, 47.21721655981881, 49.02013513020107, 41.655100209372385, 51.85249532972063, 44.564609731946675, 47.54453924724034, 48.787262780325754, 47.416946002415244, 49.3213221686227, 49.07202427727835, 45.97399970463344, 42.522169385637554, 31.951829705919536, 46.94157109941755, 49.47769832611084, 50.011403356279644, 45.184781619480674, 40.05190065928868, 40.285478251320974, 37.76465095792498, 36.560340540749685, 34.852379526410786, 35.0312192099435, 36.81608288628714, 34.77541780471802, 34.51382507596697, 35.83109930583409, 35.913230487278526, 33.112265723092214, 35.49690137590681, 35.76542493275234, 35.11693218776158, 37.52473660877773, 34.03876631600516, 34.5997326033456, 34.7705888066973, 35.830539975847515, 44.594038827078684, 46.65212304251534, 46.635343142918174, 47.230171476091655, 45.59439182281494, 39.42377308436802, 34.811972277505056, 33.201946122305735, 31.270381655011857, 33.26506355830601, 33.68153510774885, 32.100590637751985, 34.394041606358115, 35.16377346856253, 37.574294635227744, 37.21920347213745, 40.41691037586757, 36.355299200330464, 37.96362999507359, 35.16027505057198, 38.07899441037859, 37.13927834374564, 39.99826404026577, 39.36558192116873, 48.95409945079258, 46.05538395472935, 40.88693516595023, 6.436875011239733, 1.709422958748681, 7.4310653890882215, 9.105662022318159, 7.461938841002328, 7.350742476327079, 7.666586739676339, 2.5662137951169695, 0.1288294813462666, 0.462002551981381, 33.41097225461687, 39.03645617621285, 29.676940849849156, 26.885934591293335, 37.56208317620413, 14.556890334401812, 0.03706176931570683, 0.06986896121608359, 0.053878160526177714, 0.07030804801200118, 0.03453168865027172, 0.07349948997476272, 0.037186823319643736, 0.040909201971122196, 0.044557291216083934, 0.015837448383016244, 0.030035858109061207, 0.028363401602421488, 0.0711568138961281, 0.04010520243485059, 0.09087144530245236, 0.05428588543353336, 0.053595564261611016, 0.12873433716595173, 0.14513174657310757, 0.11355756475989308, 0.11622120147304875, 0.07336967944034509, 0.11857603011386735, 0.11989261875195162, 0.10427515820733138, 0.15525508193033083, 0.13853045579578194, 0.14313378663999693, 0.1734596879354545, 0.10341012105345726, 0.11814146914652415, 0.12958903344614164, 0.11915623183761324, 0.2178335982773985, 0.16971527385924542, 0.13423341565898486, 0.26493592507072855, 0.12037304868655545, 0.1590908132493496, 5.993317212377276, 51.45666340419224, 39.473862648010254, 36.88623884746006, 41.22460372107369, 46.01597029822213, 26.45782307216099, 0.3400143321071352, 3.181153689111982, 0.5190851518086025, 0.28134265754904064, 1.9318641083581107, 4.681531625134604, 1.5385860800743103, 0.1199363571192537, 3.945743884359087, 33.53758927753994, 52.12219660622733, 51.45724010467529, 51.27735819135393, 51.08095693588257, 50.964922019413535, 47.311069352286204, 44.16333736692156, 46.826126779828755, 44.257857186453684, 48.06388235092163, 50.307163851601736, 50.78535277502877, 50.32958568845476, 50.03909887586321, 51.86778136662075, 51.30348341805594, 48.079415048871724, 47.683746406010215, 49.55667849949428, 45.73785475322178, 38.87304844175066, 37.472440992082866, 39.71957179478237, 39.414538928440635, 37.65865618841988, 38.76405552455357, 36.743762561253135, 42.25559479849679, 42.136374132973806, 39.67912285668509, 40.77607665743147, 38.98279871259417, 39.25219774246216, 40.162613255637034, 40.42222574778965, 38.31378446306501, 37.14239113671439, 37.877566133226665, 42.769094467163086, 49.565273421151296, 48.757076331547324, 51.83523947851998, 44.66912453515189, 47.86433703558785, 45.678301743098665, 47.60427291052682, 49.6003930909293, 48.905875478472026, 50.8713367325919, 50.07754673276629, 44.60996757234846, 44.34242371150425, 37.50052213668823, 48.174831186022075, 50.672812802451, 51.301319054194856, 46.09522492544991, 42.25365277699062, 40.883659090314595, 39.16538347516741, 38.04830074310303, 36.0904130254473, 37.11550508226667, 38.49738713673183, 35.61208861214774, 35.90222454071045, 37.533831800733296, 39.2406394141061, 35.22394486836025, 37.76302855355399, 37.69306366784232, 36.35902343477522, 38.277719838278635, 35.96184703281948, 35.33437606266567, 36.961692810058594, 37.00223902293614, 46.69908939089094, 48.42603983197893, 47.29842363085066, 49.78531244822911, 48.55131237847464, 41.78142193385533, 37.882301330566406, 34.554663113185335, 33.60249934877668, 33.68151078905378, 37.567659105573384, 33.86670112609863, 37.79961429323469, 37.79362842014858, 40.20946495873587, 39.17471490587507, 42.38453599384853, 38.1972770690918, 40.08044038500105, 36.80157504762922, 40.1202118737357, 38.36996759687151, 42.13140269688198, 40.6815116746085, 51.645706517355784, 46.559899602617534, 40.852875096457346, 7.015630858285086, 2.3768143696444373, 9.208187903676714, 20.529785054070608, 15.533337184361049, 13.193810973848615, 14.09831270149776, 9.576088070869446, 0.3926534503698349, 0.9698203312499183, 42.02998679024832, 38.962440490722656, 34.14677258900234, 34.17840426308768, 45.89408847263881, 18.851025581359863, 0.1895134329263653, 0.22569271656019346, 0.24593325331807137, 0.1407946321581091, 0.10624080630285399, 0.11967501257147108, 0.1052310104881014, 0.1051416542114956, 0.12558526971510478, 0.09352968766220979, 0.10552632249891758, 0.14175961752023014, 0.1477698500135115, 0.13700504122035845, 0.20981232369584696, 0.11445519195071288, 0.08982425542282206], [0.04969404897253428, 0.07055184564420156, 0.03649283805862069, 0.029289995453187397, 0.039394708416823826, 0.03156234137713909, 0.07167464468095984, 0.009074578061699867, 0.029110539904130355, 0.08240419000919376, 0.028008120666657175, 0.02428022213280201, 0.020470412547833154, 0.08076130066599164, 0.018284632425223078, 0.010580041163068796, 0.024477662252528325, 0.07539824808814696, 0.06417588956121888, 0.02367295534349978, 0.04580143267022712, 0.027503327932208776, 0.3107997626066208, 13.61013834817069, 39.93442051751273, 28.62604144641331, 31.67180688040597, 31.65808071408953, 32.053169182368684, 2.466487169265747, 0.4422043114900589, 0.05954416202647345, 0.1726352407463959, 0.16058790577309473, 4.310327589511871, 1.363070241042546, 0.5823025767292295, 0.2538739586515086, 8.786949021475655, 41.28414978299822, 50.7598911012922, 50.84838335854666, 47.152153628213064, 47.40921613148281, 44.407931327819824, 43.01043667112078, 38.642132009778706, 42.25397934232439, 43.67588302067348, 47.64919301441738, 48.99802596228463, 47.78729540961129, 45.6368522644043, 47.42375176293509, 46.33857863289969, 45.02148853029524, 45.47585902895246, 45.26673214776175, 43.02350275857108, 38.2269424029759, 34.90792342594692, 35.925382886614116, 36.41355984551566, 34.039287430899485, 34.01575040817261, 36.45223699297224, 35.15303502764021, 35.694845131465364, 34.99620376314436, 36.00529759270804, 35.58377122879028, 36.90904630933489, 35.16493034362793, 34.73747369221279, 34.78139672960554, 32.72082505907331, 34.25374705450875, 35.09276982716152, 42.55833823340279, 43.14258098602295, 46.62811354228428, 42.55811241694859, 37.7497991834368, 52.536010469709126, 39.228674616132466, 47.01963758468628, 43.04958282198225, 45.407318523951936, 40.488848549979075, 42.89698995862688, 30.613676139286586, 31.86336871555873, 40.2005295753479, 49.690462589263916, 44.35684469767979, 42.43333666665213, 41.55153383527483, 37.86350992747715, 35.47014386313302, 35.40227385929653, 37.49720089776175, 36.59325763157436, 33.16779572623116, 32.563059261866975, 33.7060900415693, 33.27107375008719, 33.20239428111485, 33.95107657568795, 33.94531304495675, 33.2903584752764, 35.05067764009748, 34.323065757751465, 34.25453567504883, 33.605792794908794, 31.98968349184309, 34.36278860909598, 42.421052251543315, 47.30657039369856, 45.90880823135376, 45.088879108428955, 43.23821946552822, 43.815969126565115, 40.09420824050903, 33.54268230710711, 31.694562230791362, 31.367791925157817, 31.542740617479595, 32.46463108062744, 32.8012296131679, 35.936305454799104, 39.95754064832415, 40.81300285884312, 43.735894611903596, 42.89394664764404, 40.46365090778896, 40.17454331261771, 38.361824308122905, 37.365473474775044, 38.942690236227854, 39.84730747767857, 43.27365180424282, 45.71952887943813, 24.856285878590175, 0.6005503918443407, 1.8495418514524187, 5.920388051441737, 7.3607452767235895, 5.937893603529249, 9.467848164694649, 3.462046776499067, 2.037300850663866, 0.19489722831973008, 6.321587894644056, 46.596054553985596, 17.349735260009766, 28.262294564928325, 29.794216019766672, 23.803654636655533, 1.9495822318962641, 0.19462092886013643, 0.07561258372983762, 0.08250715091292347, 0.03053613180028541, 0.031083774021161453, 0.040340884788227935, 0.04414148156398109, 0.02928203284474356, 0.023617461356999617, 0.05814684129187039, 0.07037840530808483, 0.06009542423167399, 0.0757660683510559, 0.06919818863804851, 0.05089505256286689, 0.04796426643484405, 0.022162777271920016, 0.03936338045501283, 0.1060238718720419, 0.015273402578064373, 0.03941263870469161, 0.05791865675044911, 0.034621187419231446, 0.04199793176459415, 0.043117741854595285, 0.05239284737035632, 0.0055490356337811264, 0.012964136715579246, 0.06663766889167683, 0.004971737615830664, 0.028002175003556267, 0.04367695649021438, 0.0303625828985657, 0.116337244531938, 0.05226782729317035, 0.0861759286906038, 0.02819298583615039, 0.09345257894269057, 0.013147394605247038, 0.42681025181497845, 21.69902617590768, 44.81745120457241, 25.13226137842451, 38.52950518471854, 38.663258007594514, 34.33912999289376, 2.19068689431463, 1.0715111259903227, 0.05600318631955555, 0.14887717845184462, 2.1523879894188473, 4.087262187685285, 4.082919129303523, 1.8355831376143863, 0.16077960548656328, 11.186355675969805, 41.97862918036324, 49.802471024649485, 53.01302514757429, 48.7830764906747, 48.19175699778965, 45.48931074142456, 43.30507503237043, 41.46027619498116, 43.85569545200893, 44.188173702784944, 49.25553662436349, 50.06165967668806, 48.5929286139352, 45.94276407786778, 48.66927889415196, 47.90688780375889, 48.338506426130024, 47.61002254486084, 46.1753237588065, 44.25144747325352, 39.60200480052403, 36.51946081433977, 37.087594168526785, 37.54685967309134, 35.87074225289481, 36.04647609165737, 37.70563643319266, 36.433907645089285, 37.16686964035034, 35.832221439906526, 38.055544240134104, 36.66009930201939, 37.39773048673357, 36.94995035443987, 35.78662736075265, 36.79099294117519, 35.002408504486084, 36.63023247037615, 37.77589661734444, 45.03941488265991, 44.53045586177281, 49.55391311645508, 41.86927843093872, 45.02984373910086, 51.11239753450666, 40.74809973580496, 49.12566089630127, 43.699020521981375, 48.13943011420113, 42.716055393218994, 43.02427748271397, 31.98995794568743, 32.38444539478847, 42.76638119561331, 53.540462902614046, 47.9432373046875, 44.13905341284615, 42.10421092169625, 38.384798526763916, 37.53738580431257, 36.83398839405605, 38.90366220474243, 37.721652030944824, 35.7124205998012, 33.59403991699219, 35.19732979365757, 34.967775208609446, 35.09748765400478, 35.94465718950544, 35.961867877415244, 35.83676903588431, 34.891539573669434, 35.09411430358887, 36.49824448994228, 34.93377767290388, 34.45975072043282, 34.93257563454764, 44.33604179109846, 46.79666641780308, 45.37090996333531, 44.51988417761666, 45.9023220879691, 44.64543465205601, 41.97736808231899, 34.6851989201137, 33.77911908285958, 32.959731919424875, 32.34729337692261, 33.70092058181763, 33.36412749971662, 37.65838868277413, 42.75396476473127, 42.2658816065107, 47.66132109505789, 44.73473637444632, 42.356420108250205, 41.85049050194876, 40.269973346165244, 39.53561476298741, 41.91950348445347, 41.13210582733154, 46.95193086351667, 46.42875930241176, 28.63879312787737, 0.757310437304633, 3.533552642379488, 7.0467731186321805, 8.605583667755127, 8.40683913230896, 10.298347234725952, 5.992120819432395, 0.9207605123519897, 0.06927208788692951, 5.478346696921757, 49.06193896702358, 23.097373723983765, 28.477422952651978, 32.89985581806728, 33.39269849232265, 4.267109794276101, 0.29883005203945295, 0.018961761180045347, 0.037598633007811647, 0.10278043377080134, 0.024149534591872777, 0.013144271647823709, 0.0512606777649905, 0.07989072666636535, 0.07197584637573787, 0.07961842377803155, 0.07683600272451128, 0.01649802427605859, 0.02797046027678464, 0.011406773318802672, 0.03801097873864429, 0.04656933414350663, 0.03861420315557292, 0.12250387934701783, 0.2852468123393399, 0.07692685856350831, 0.12333859955625874, 0.1594289815319436, 0.1109847431736333, 0.17732102716607706, 0.08118817383157355, 0.12369487115315028, 0.09766828987215247, 0.17197201347776822, 0.135972582335983, 0.050576643220015934, 0.17141748751912797, 0.12998095527291298, 0.09232443983533553, 0.17828875380967343, 0.17898662707635335, 0.17019175472004072, 0.09029382879712752, 0.12830101113234246, 0.08278874973101275, 0.6249857949359077, 23.785908937454224, 55.28586775915963, 35.31419154575893, 42.281886781964985, 39.57985046931675, 40.53813212258475, 3.5656939234052385, 1.9758631416729517, 0.12395890269960676, 0.27572788883532795, 2.8690414769308905, 10.07656420980181, 4.314301090581076, 3.3981973912034715, 0.5238920567291123, 11.010126778057643, 42.907231603349956, 49.87365879331316, 56.392552512032644, 50.59250552313668, 51.49298163822719, 48.56420128686087, 46.666241782052175, 43.701963084084646, 45.38463265555245, 46.24770661762783, 53.5934602873666, 53.00058439799717, 51.31531967435564, 47.63244785581316, 50.03599303109305, 49.102530343191965, 49.88082586015974, 50.0337244442531, 50.1088205746242, 47.575760977608816, 42.71960244859968, 38.48298699515206, 38.70846993582589, 39.70081860678536, 37.79533767700195, 37.84852613721575, 40.21004165921892, 39.01480906350272, 39.53909233638218, 37.27245099203927, 40.61929750442505, 38.43026059014456, 40.44277851922171, 39.41690131596157, 38.66344560895647, 37.88749163491385, 36.21894427708217, 37.62468991960798, 38.354407106127056, 46.22477756227766, 45.92386497770037, 50.121897084372385, 46.079945836748394, 45.85259730475289, 48.2935585294451, 44.312754903520855, 50.42494624001639, 44.062574590955464, 48.7200528553554, 44.84190886361258, 43.75462000710623, 32.308324405125205, 36.14328881672451, 49.36969205311367, 53.7338034766061, 48.449014050619944, 45.97229044778006, 44.0596216065543, 42.17480114528111, 39.60985973903111, 39.62841837746756, 42.56777041299002, 40.234329087393625, 35.134306158338276, 35.0819480078561, 36.814877373831614, 37.45779766355242, 36.622193404606406, 37.142596108572825, 37.104711055755615, 38.03723226274763, 36.208355222429546, 36.609123843056814, 37.357927731105256, 36.14601598467146, 35.04273932320731, 37.529190404074534, 45.49617208753313, 48.960877418518066, 47.056379658835276, 45.32904359272548, 45.78042984008789, 45.94648136411394, 44.218686716897146, 38.08803749084473, 34.91825539725167, 34.10838726588658, 34.4702216557094, 35.54159218924386, 36.15492010116577, 39.46901627949306, 45.51613426208496, 44.32434449877058, 47.24553394317627, 47.08472483498709, 44.26676825114659, 44.180183274405344, 43.38158859525408, 40.70247786385672, 44.10678597858974, 42.60141706466675, 47.70817627225603, 46.96087319510323, 29.630155154636928, 1.439700729080609, 6.103896490165165, 11.940190059798104, 13.247985209737505, 14.139419981411525, 18.222416843686783, 12.754280090332031, 5.766283520630427, 0.45632305102688925, 8.414477808134896, 56.547379221235005, 26.310404879706248, 36.763870647975374, 37.587503160749165, 42.342141560145784, 5.606783713613238, 0.5704383105039597, 0.17556355361427578, 0.13932122050651483, 0.1660113004701478, 0.14597023943705217, 0.13378263770469598, 0.2772445503090109, 0.14113700735781873, 0.23651152317013058, 0.19435183544244083, 0.11200510377862624, 0.20445504545101098, 0.09087732141571385, 0.10964439902454615, 0.0831823678953307, 0.0977019044969763, 0.13953661466283457], [0.06986176874488592, 0.0308980488085321, 0.07615466535623584, 0.022876009178747023, 0.01802718945379768, 0.06543143718902554, 0.052489949124200005, 0.014455956174060702, 0.048631429206579924, 0.030901275242545774, 0.03893677870343838, 0.026382674762446965, 0.015310906904882618, 0.01538793250386204, 0.056050785551113744, 0.06950500181743077, 0.029300268473369733, 0.035751016078782935, 0.05637099301176412, 0.028957947556461607, 0.04052872024476528, 0.046578402764030864, 0.16011055638747557, 0.960242999451501, 30.493496622358048, 27.190965720585414, 26.33045390674046, 31.901983329227992, 38.01679413659232, 10.961452909878322, 0.43392056599259377, 0.41396281548908775, 0.48649924035583225, 0.678695587175233, 3.961206231798444, 2.6038593522139957, 1.9952201715537479, 0.15099970384367875, 1.4840758336441857, 21.071520464760916, 50.558973516736714, 49.78975234712873, 50.923806054251536, 48.716259138924734, 45.483286653246196, 42.50827646255493, 39.87998138155256, 42.171375683375764, 43.756259781973704, 46.586587633405415, 47.226982252938406, 48.21933439799717, 47.38719034194946, 46.2267404283796, 46.17865194593157, 47.55618442807879, 44.18801736831665, 45.76098878043038, 41.07443230492728, 40.45878022057669, 35.622927801949636, 36.588133335113525, 35.05377306256975, 36.06705665588379, 35.21061474936349, 35.84845243181501, 35.32162264415196, 36.364029611860005, 35.13152340480259, 36.83230345589774, 34.39065088544573, 35.096351623535156, 33.39760044642857, 36.73193325315203, 33.741470268794465, 34.93256868634905, 34.68026917321341, 38.68747247968401, 39.21891587121146, 46.50298343385969, 42.50527136666434, 48.02679634094238, 33.377513204302105, 47.87611075810024, 51.29248789378575, 39.836395331791465, 44.712675843920024, 41.7501654624939, 43.77391862869263, 42.8313364301409, 28.407174927847727, 46.85578516551426, 40.317283630371094, 37.133643354688374, 45.207662037440706, 42.168846539088655, 42.70719644001552, 38.239157336098806, 37.33592626026699, 36.352804797036306, 36.4787791115897, 35.4244316646031, 34.32240220478603, 34.70312179837908, 34.45742654800415, 32.916726044246126, 33.94437503814697, 32.46654183523995, 33.393018109457834, 32.66659089497158, 34.36398369925362, 33.52899088178362, 32.20786387579781, 33.94310004370553, 32.50626468658447, 32.46428714479719, 39.64834581102644, 45.057038988385884, 44.68497685023716, 46.35898201806204, 45.28924778529576, 43.88028165272304, 42.38366052082607, 41.34040934698922, 35.48526661736624, 31.129625047956193, 30.760797296251567, 31.787800107683452, 32.8621757371085, 36.6369618007115, 39.896559783390586, 42.232888085501536, 35.88135215214321, 43.923176356724326, 42.217452662331716, 41.89178712027413, 40.65602568217686, 38.8292886870248, 40.12959541593279, 42.27246502467564, 43.06098828996931, 44.33491965702602, 10.135940909385681, 0.06432465157870736, 2.5087593580995287, 7.419302957398551, 5.37576870407377, 5.906917665685926, 3.9338776639529636, 4.143835723400116, 0.8378958074109895, 0.2029460378523384, 21.271279437201365, 40.56787388665335, 44.213076046534944, 40.99142565046038, 35.27418034417288, 14.345921312059675, 0.019756332472232834, 0.1767982430756092, 0.014537242972957236, 0.00232579730800353, 0.03673976034458194, 0.08847215904721192, 0.015001104778743215, 0.06542209376181875, 0.029281184675970247, 0.05899800918996334, 0.035572391735123735, 0.04678920663094946, 0.0634715227144105, 0.04710050831948008, 0.07960413383053881, 0.016276094131171703, 0.035079561573054106, 0.009624642652592488, 0.010955090368432658, 0.01784873813656824, 0.034913510483290465, 0.03306391562468239, 0.035672628320753574, 0.009337188077292271, 0.018364553672394583, 0.05845144244709185, 0.060999952123633454, 0.019947099200050746, 0.047197854345930476, 0.0518259652890265, 0.04064423404633999, 0.019189089071005583, 0.009435634178641652, 0.05667607931952391, 0.037310157237308364, 0.004490277156167264, 0.044631370276744874, 0.06345672386565379, 0.05138513805078609, 0.027011927782690952, 0.17122614064386912, 2.7891037549291338, 41.55945130756923, 28.302437782287598, 27.858892577035085, 38.991956438337056, 41.98157869066511, 10.055575438908168, 1.0205121082918984, 0.7246648690530232, 0.5505905640976769, 1.2785054530416216, 6.122561088630131, 4.471681697028024, 5.726707884243556, 0.5510218409555299, 1.0278469089950835, 24.773439032690867, 50.98002740315029, 50.81495904922485, 52.069775921957834, 51.142017705099924, 47.97438955307007, 44.36101014273507, 41.54911238806588, 44.886075087956016, 45.34540312630789, 47.84510094778878, 49.42140749522618, 49.39191239220755, 48.73696477072579, 49.2045715876988, 48.01230239868164, 47.253058842250276, 45.40539387294224, 48.65330498559134, 43.26828779493059, 41.19040468760899, 37.09709235600063, 38.0309476171221, 36.76855720792498, 37.63932977403913, 36.10283293042864, 37.64388084411621, 36.34497765132359, 38.87769331250872, 36.2150046484811, 37.07462535585676, 36.33676488058907, 37.47853456224714, 34.325629643031526, 37.58844811575753, 35.31716537475586, 34.928851400102886, 38.025420325142996, 40.945664814540315, 42.6979900768825, 48.06100927080427, 44.21771396909441, 49.79145812988281, 36.08238090787615, 55.35235159737723, 45.498051575251985, 41.011780398232595, 45.87275750296456, 43.042745794568745, 42.41592100688389, 43.22781106403896, 30.170631204332622, 47.01604189191546, 41.39461919239589, 39.98723724910191, 47.499483653477256, 43.15976735523769, 44.56248358317784, 39.051415647779194, 38.00026089804513, 38.47961017063686, 38.61236245291573, 37.45621347427368, 36.526415961129324, 34.958607060568674, 35.5876761163984, 34.59088754653931, 34.4647673198155, 34.50213820593697, 35.89393186569214, 33.734386580330984, 34.999552794865195, 34.816669259752544, 33.97359568732125, 34.88594627380371, 34.96148361478533, 34.492021628788535, 41.28055756432669, 45.77725798743111, 45.88193607330322, 45.41696957179478, 45.47873558316912, 46.21108266285488, 44.89666414260864, 41.80432667051043, 35.579209736415315, 32.72430958066668, 32.49631486620222, 33.3898914200919, 35.125857148851665, 37.488706724984304, 42.21588931764875, 43.12236867632185, 38.69522666931152, 45.53559616633824, 44.50810350690569, 44.04384224755423, 41.96629612786429, 41.33287749971662, 42.18322236197335, 44.09918812343052, 44.43435532706124, 46.05935485022408, 11.392145684787206, 0.6342189737728664, 4.200926465647561, 9.79891766820635, 9.532729574612208, 4.215237583432879, 6.684081060545785, 5.163558125495911, 0.314478833760534, 0.17729296295770577, 23.981995786939347, 45.111106395721436, 34.74637433460781, 37.78647872379848, 40.12415845053536, 22.84889050892421, 0.5506861018283027, 0.15032350298549446, 0.0380426527533148, 0.07752521788435322, 0.05216695288462298, 0.059947462885507515, 0.0396694845653006, 0.08678494779659168, 0.02390934506963406, 0.030267727095633745, 0.04927326565874474, 0.00994266607865159, 0.049497311136552265, 0.02011793735437095, 0.07280409336090088, 0.026446065200226646, 0.012344969270218695, 0.03539677669427224, 0.12860827893018723, 0.10678607704383986, 0.15581122280231544, 0.12250904978385993, 0.1143695879727602, 0.13507040217518806, 0.17230505203562124, 0.16585629593048776, 0.152341506843056, 0.12710594811609813, 0.08727611894054071, 0.08855200226285628, 0.07885359946106162, 0.09943334944546223, 0.1527074407786131, 0.24206932208367757, 0.13743741730494158, 0.1608423021222864, 0.12621945568493434, 0.1568217242934874, 0.10189932890768562, 0.10556216950395278, 0.24729721727115767, 3.2760975658893585, 47.38435547692435, 36.5810809135437, 36.75061348506382, 40.16851575034005, 50.840198380606516, 13.367373500551496, 2.223449387720653, 1.135261390890394, 0.7741125385676111, 3.1631235480308533, 13.012178114482335, 9.580957889556885, 3.5965756263051714, 0.26120143117649214, 1.7690001790012633, 25.156248297010148, 52.19357892445156, 51.58552469526018, 55.01923411233084, 53.11503859928676, 49.98965549468994, 47.68393748147147, 42.91736555099487, 47.52352442060198, 46.49904727935791, 49.76536764417376, 49.851177896772114, 52.050293173108784, 50.32824468612671, 50.16685887745449, 48.98507104601179, 48.98019341060093, 46.7755195753915, 50.13329560416085, 44.840755462646484, 44.59711340495518, 40.08304943357195, 40.14459310259138, 38.11332198551723, 39.85886928013393, 37.77580281666347, 39.10555253710066, 38.95226832798549, 41.63100038255964, 38.885398864746094, 40.44354282106672, 38.224475792476106, 37.22835424968174, 37.04156582696097, 40.60580062866211, 37.84429815837315, 37.040586130959646, 40.30801125935146, 42.255285603659495, 43.704183033534456, 51.877366406576975, 45.56846809387207, 51.09363392421177, 41.138824735369, 55.46683359146118, 44.65699645451137, 43.234331948416575, 47.89197696958269, 43.043850558144705, 41.82439654214041, 43.50038889476231, 31.986588069370814, 48.625081402914866, 44.033642292022705, 43.72619840076992, 48.8504045350211, 46.15526778357369, 45.66131339754377, 41.768136978149414, 40.94771453312465, 40.92920453207833, 41.15205063138689, 40.120937960488455, 36.906538009643555, 38.20083802086966, 36.3839362008231, 35.32960959843227, 37.402681078229634, 35.9536828994751, 36.6066746030535, 35.44237538746425, 37.214318888528005, 36.52135419845581, 34.322235448019846, 37.16718578338623, 36.36575276511056, 35.80023193359375, 43.095774446214946, 48.116803305489675, 47.37264428819929, 47.19282143456595, 46.86323710850307, 46.92356831686837, 46.50096845626831, 44.143757343292236, 38.104706219264436, 34.680060727255686, 33.81241832460676, 34.654282910483225, 36.784371307918, 38.98931959697178, 43.81445441927229, 44.704657622746055, 40.22067240306309, 47.05387135914394, 47.5632437978472, 46.646741662706646, 45.612120151519775, 42.145719460078645, 44.624360765729634, 45.33247252873012, 45.51868077686855, 46.417742933545796, 12.885938031332833, 0.6579249788607869, 7.448398538998195, 17.14250523703439, 13.593123946871076, 14.115695357322693, 11.480004787445068, 10.187947307314191, 2.3975408460412706, 0.41286923417023247, 25.81423228127616, 50.05280419758388, 49.847481455121724, 47.58632571356637, 45.37161520549229, 30.679169859204972, 1.0250548188175475, 0.2464092592043536, 0.11048686810370002, 0.1296159170035805, 0.2025734135614974, 0.15449373849800654, 0.08192931049104248, 0.16454991245908396, 0.08766467523361955, 0.13220224822206156, 0.1289003204022135, 0.12230836626674448, 0.17893883106963976, 0.05550964369571634, 0.09081508618380342, 0.08941933286509343, 0.08753648639789649, 0.13209210841783456], [0.10020614654890128, 0.030173807671027522, 0.04874942983899798, 0.034332416485995054, 0.07745256713990654, 0.005971120886637696, 0.015040610783866473, 0.029609646515122483, 0.028676962812564204, 0.009426315348329288, 0.05082588270306587, 0.005735347355117223, 0.04051994000162397, 0.0447390944963055, 0.08264827262610197, 0.03204458300024271, 0.08292213614497866, 0.06772540802402155, 0.05184817713286195, 0.062356492903615744, 0.07294902844088418, 0.06598272653562681, 0.00609742890810594, 0.04868093851421561, 8.156265377998352, 36.86608212334769, 23.861826692308696, 33.18424211229597, 36.42695597239903, 23.218084778104508, 0.3296994056020464, 0.19243316911160946, 0.3622118452829974, 2.2639187361512865, 2.487701973744801, 4.333067740712847, 7.032980944429125, 0.96439747938088, 0.03617706482431718, 4.822316024984632, 35.18464238303048, 52.36390011651175, 50.217122146061485, 48.45371798106602, 46.47358560562134, 44.322402477264404, 39.74090623855591, 42.984252384730745, 45.524722235543386, 47.157858099256245, 48.69100591114589, 47.342388357434956, 45.791383675166536, 46.80973597935268, 45.57911620821272, 45.107753889901296, 46.68163899012974, 46.750228132520405, 43.924746649605886, 38.35927431924002, 36.807675565992085, 36.276433672223774, 35.0519700050354, 36.882716110774446, 35.14095211029053, 36.52042661394392, 36.85505533218384, 36.49546521050589, 35.18049430847168, 35.96238899230957, 36.0658198765346, 33.94372190747942, 34.805392333439414, 34.26460708890642, 35.673743452344624, 33.905076026916504, 39.088157721928184, 41.8719847542899, 43.121764183044434, 45.93211596352713, 44.41975368772234, 44.02721173422677, 44.81744078227452, 33.30091973713466, 51.10808270318167, 50.14289454051426, 45.96884066717965, 41.85416609900338, 39.09656156812395, 32.46622221810477, 48.96065507616316, 51.75815616335188, 44.50298615864345, 47.40314340591431, 43.52019126074654, 40.43704278128487, 38.88722276687622, 36.88635696683611, 36.46573386873518, 36.19490698405674, 36.581195558820454, 36.2276816368103, 37.04457092285156, 36.749380179813926, 33.77214309147426, 33.46319144112723, 33.26857934679304, 32.57427018029349, 34.84244360242571, 33.492172377450125, 32.61460099901472, 33.129802976335796, 32.65293768474034, 31.52040215900966, 32.38467468534197, 32.83064481190273, 35.92889172690255, 42.68476070676531, 41.67639296395438, 45.624414988926475, 43.181918212345664, 43.216700894492014, 43.78538315636771, 42.47203813280378, 41.158741746629985, 34.96851519175938, 33.38643816539219, 31.249554429735454, 30.759841918945312, 34.12979119164603, 40.94364288875035, 41.79877853393555, 43.535894189562114, 39.30221782411848, 44.35106379645211, 44.27934101649693, 42.45947231565203, 39.85788263593401, 42.611755984170095, 41.06567757470267, 44.062720503125874, 32.19453028270176, 2.630783621753965, 0.19578985470746244, 3.022299196038927, 5.140031090804508, 8.580281802586146, 5.099651200430734, 6.954284344400678, 4.8506620696612766, 0.5022368015987533, 0.9659485561507088, 21.567998783929006, 32.235135555267334, 30.265387262616837, 42.16042879649571, 37.83139535358974, 8.97378955568586, 0.02381158004780965, 0.06669126637279987, 0.02373311765092824, 0.04531398329085537, 0.016790420282632113, 0.03819078712591103, 0.06969511375895568, 0.02468311078181224, 0.049883478986365457, 0.0679704270192555, 0.031201469312821115, 0.01845683782760586, 0.023380866374022195, 0.04325863625854254, 0.03868579538539052, 0.005113142193295062, 0.06405272188463382, 0.04200197583330529, 0.04462920914271048, 0.01434968741211508, 0.03287342370354703, 0.026006603513711264, 0.09454234689474106, 0.007408758475711303, 0.036946428540561876, 0.07287040658827339, 0.033364038448780775, 0.04277604518990431, 0.06884811206587724, 0.007633418027710701, 0.07730470078864268, 0.06231175030448607, 0.06768381382737841, 0.006864281196612865, 0.040250707484249554, 0.05129418721688645, 0.03044419709060873, 0.04894503791417394, 0.011566217173822224, 0.08118898128824574, 0.08007201765264783, 0.10280801621930939, 14.53221207005637, 42.16542107718331, 23.257085016795568, 36.13153593880789, 42.38218402862549, 24.71798893383571, 0.8522049167326519, 0.2591260368270533, 0.38394252636602944, 1.090846985578537, 4.759252003261021, 6.2432838678359985, 6.671229498726981, 3.367766018424715, 0.5165687096970422, 5.507818349770137, 39.17134850365775, 51.74139016015189, 51.1305045400347, 50.17800726209368, 46.831744398389546, 45.13295153209141, 42.57932179314749, 44.938488824026926, 46.49063301086426, 47.9478474344526, 49.93184648241316, 49.06370380946568, 47.4883074760437, 46.67150156838553, 46.00391864776611, 47.7606212752206, 48.34325204576765, 48.74554927008492, 45.24713822773525, 41.086265087127686, 38.09104258673531, 36.57586281640189, 36.30348995753697, 37.81761360168457, 37.13663802828108, 38.34273760659354, 38.64276776994978, 37.644707679748535, 36.6746175629752, 37.023941721235005, 37.31212173189436, 34.75716836111886, 37.52406958171299, 36.14318459374564, 36.389307158333914, 35.86039291109358, 40.65408018657139, 43.76946483339582, 45.306663445064, 47.72519588470459, 46.77317803246634, 47.161988803318565, 45.62181288855416, 39.62929037639073, 59.567344256809776, 46.64708907263619, 43.667600767953054, 41.14846188681466, 39.97683926991054, 35.613905566079275, 52.623672417231965, 53.461399350847515, 46.30439696993147, 48.08836432865688, 44.96031311580113, 42.26333161762783, 41.639310428074424, 38.33645990916661, 37.97598041806902, 37.74594988141741, 37.32466670445034, 38.21347679410662, 39.81613785879952, 37.75378050122942, 33.11329058238438, 34.728767599378315, 35.10825041362217, 34.09378562654768, 35.896808419908794, 33.504682609013145, 34.13840000970023, 34.80199466432844, 34.14005020686558, 34.21008457456316, 34.86157546724592, 34.75096361977713, 37.995185238974436, 43.87107528959002, 43.347181115831646, 47.97491761616298, 44.540502956935335, 44.516107831682476, 46.01511566979544, 43.3550568989345, 41.56952272142683, 36.34315027509417, 34.13159424918038, 31.73576157433646, 32.39561114992414, 36.335687909807476, 42.23085573741368, 44.79230219977242, 44.24997445515224, 40.43782097952706, 46.62916619437081, 46.00801461083548, 43.226219926561626, 42.9453945841108, 42.530215399605886, 44.01352725710188, 45.42227799551827, 35.68189716339111, 2.5753076842853, 0.8137338810733387, 4.399931124278477, 7.658797809055873, 10.185934935297285, 8.653057234627859, 7.756743959018162, 4.434641284602029, 0.31206533898200306, 1.0204970176730837, 26.478113549096243, 39.862412861415315, 41.69275944573538, 46.06192568370274, 42.012032645089285, 13.758280021803719, 0.11524404319269316, 0.04002291988581419, 0.02380918142651873, 0.06577548158488103, 0.09361184468226773, 0.0101646589880277, 0.06619464659265109, 0.034001254077468596, 0.07946303925876107, 0.006151238431422306, 0.09910736086645297, 0.0077404993353411555, 0.03672697674483061, 0.049280173145234585, 0.024804704257154038, 0.0073062394679124865, 0.07752505503594875, 0.029657944637749876, 0.10358059619154249, 0.1669154212410961, 0.14847779273986816, 0.09179250230746609, 0.24168459272810391, 0.1029715295881033, 0.07187532141272511, 0.15934500603803567, 0.058993558000241, 0.1801437192729541, 0.17118525212364538, 0.11383976068879877, 0.17264526949397155, 0.1184738427400589, 0.1969981084444693, 0.13423870823213033, 0.1510144823363849, 0.22053599969616958, 0.14470398452665123, 0.14564303628035954, 0.15403283680123941, 0.17036927305161953, 0.14832974996949944, 0.26560007514698164, 17.88515649523054, 50.77585111345564, 32.356645652226035, 41.89596993582589, 46.572489738464355, 32.42493602207729, 1.7256920571838106, 0.47271716275385445, 0.6873622706958226, 6.025930753776005, 6.652533633368356, 9.567090153694153, 13.04547040803092, 3.6612594468252997, 0.28773410458649906, 6.052554513726916, 38.084896905081614, 53.75407484599522, 52.519345215388704, 53.066512380327495, 48.40088735307966, 48.140017236982075, 44.44162661688668, 47.59368732997349, 51.11731685910906, 50.48015315192086, 51.090027809143066, 49.647175312042236, 48.092363016945974, 49.37195021765572, 46.40052877153669, 51.431834016527446, 50.579116344451904, 50.50389167240688, 47.28499971117292, 42.82848766871861, 40.65281561442784, 39.41874606268746, 38.41425541469029, 41.222772870744976, 38.312895093645366, 39.663228852408274, 40.04787417820522, 39.630488940647666, 38.11778967721121, 40.1009202003479, 37.99501500810896, 37.30211632592337, 39.285003662109375, 37.94216006142752, 39.10860627038138, 38.6264568737575, 43.03443227495466, 46.836792264665874, 45.774798325129915, 49.41783612115042, 49.193940843854634, 47.63014800207955, 48.79627806799752, 45.86278683798653, 59.166558265686035, 46.12707894189017, 43.729050636291504, 43.11178656986782, 40.4290315083095, 39.60728890555245, 53.075569357190815, 52.84575421469552, 50.315164702279226, 49.0377870287214, 45.97667476109096, 43.90638256072998, 43.97912325177874, 39.3615345954895, 40.16580247879028, 40.74498346873692, 39.689135210854666, 38.8065368107387, 41.80996860776629, 40.69075277873448, 36.33027178900582, 36.71354831968035, 37.03329052243914, 35.55830608095442, 36.94762618201119, 35.92005014419556, 34.651923997061594, 36.72216408593314, 37.56165586199079, 35.73789964403425, 34.92636741910662, 36.077941008976524, 39.66140147617885, 45.411716733660015, 45.48535026822771, 49.17412805557251, 45.08712816238403, 45.74181522641863, 47.445864404950825, 46.21458455494472, 44.903004373822895, 38.804897035871235, 35.670741830553325, 33.87208945410592, 33.81934220450265, 36.737245150974815, 44.271552085876465, 46.05041946683611, 45.68665000370571, 42.022479261670796, 47.491114548274446, 47.5939930507115, 45.983803612845286, 42.9717560495649, 46.13503810337612, 45.29110990251814, 45.78102738516671, 36.70563084738595, 4.253073130335126, 1.552924013563565, 7.367529324122837, 11.567777037620544, 15.753296307155065, 13.422492691448756, 15.704358407429286, 13.547952839306422, 1.0151545043502535, 1.5458470561674662, 29.80878291811262, 42.627114977155415, 39.33062205995832, 47.37465926579067, 48.385559626988, 18.359226873942784, 0.20803362556866237, 0.14926614186593465, 0.09844046272337437, 0.15083553908126696, 0.15398291019456728, 0.18914051008011612, 0.22754914765911444, 0.12014910498900072, 0.17080472968518734, 0.18456278714750493, 0.12875220977834292, 0.07925546861120633, 0.18270254268177918, 0.10888517940683023, 0.14278340472706727, 0.07025408412196807, 0.13279950831617626, 0.13846252086971486], [0.030968121119907925, 0.014925426071775811, 0.02664807694964111, 0.04749359044113329, 0.042530059282268794, 0.018167345950912153, 0.019782182960105792, 0.03002365126407572, 0.0710494832268783, 0.016250136774033308, 0.029581687479679073, 0.054119189735502005, 0.023686563363298774, 0.006587586066286478, 0.09025997668504715, 0.03940340045041271, 0.06921416135238749, 0.061349601218742986, 0.050995451996901205, 0.025642778125724623, 0.03246498294174671, 0.019602600185732757, 0.03490528663886445, 0.02078579562450094, 0.4466101750731468, 23.76475167274475, 28.591347353799, 28.266897746494838, 29.0606495312282, 34.12936387743269, 5.110058733395167, 0.15305213656808647, 0.05632280006206461, 1.4253502019814082, 4.557888431208474, 3.6556665812219893, 8.91868165561131, 4.39150469643729, 1.9395768259252821, 0.5743240905659539, 17.957653999328613, 50.7120075907026, 54.07134001595633, 50.164583342415945, 47.60961607524327, 42.18414647238595, 42.959495953151155, 42.45377826690674, 44.704942498888286, 45.7838796206883, 47.868749141693115, 49.663423674447195, 50.17089925493513, 45.88280807222639, 45.20804418836321, 46.5918995312282, 47.29504680633545, 44.36946957451956, 42.29260090419224, 36.217693601335796, 35.808020864214214, 35.43486091068813, 35.84235538755144, 36.2961630821228, 35.564976351601736, 35.03419303894043, 34.63177422114781, 36.21455301557268, 36.90810482842581, 33.73862845557076, 35.29058156694685, 36.131598472595215, 34.344931738717214, 34.07926736559187, 35.019216196877615, 36.2531224659511, 39.71555226189749, 44.70335830960955, 45.7463767187936, 45.325666768210276, 48.42205504008702, 46.3695467540196, 45.61315195901053, 43.85352413994925, 35.5780667577471, 41.93522030966622, 47.18529653549194, 46.00015272412981, 43.794822284153526, 52.95721026829311, 53.23034742900303, 46.01635592324393, 46.455471651894705, 43.996511118752615, 43.28149632045201, 39.533888135637554, 37.88100201742989, 33.932472773960654, 37.304513454437256, 37.11556414195469, 37.528717926570344, 37.82905381066458, 38.487819467272075, 36.889250891549246, 34.223303522382466, 34.17814370564052, 33.15065452030727, 33.19937181472778, 33.23910508837019, 32.51121875217983, 33.612438746861045, 32.94101347242083, 32.82260227203369, 32.25689383915493, 32.64316156932286, 32.640125206538606, 32.622435092926025, 37.618981974465505, 43.23567989894322, 43.0885066304888, 45.58118677139282, 44.42009762355259, 42.68477807726179, 43.492454051971436, 40.730215072631836, 39.658264364515034, 35.621607644217356, 31.341722284044536, 31.94971397944859, 31.064770562308176, 40.00715773446219, 42.855488368443076, 43.91073213304792, 43.47172062737601, 41.744075366428916, 43.906257493155344, 43.20644882747105, 44.0772248676845, 42.40962593896048, 45.37017692838396, 39.842690399714876, 25.688772133418492, 0.598520920744964, 1.0314270768846785, 2.3958830492837087, 7.489064608301435, 12.462304626192365, 4.007174210888999, 4.710105657577515, 2.0793415776320865, 0.3161404031727995, 7.99529732976641, 38.051281520298545, 23.19316680090768, 20.865900686808995, 43.517571789877756, 29.647119181496755, 3.496986661638532, 0.038506713030593734, 0.08254147799951689, 0.031318682844617536, 0.12647337705961295, 0.04193664987438491, 0.04094733903184533, 0.039823820747967274, 0.021948504394718578, 0.017371378572923795, 0.07144964246877603, 0.03342550693612013, 0.05637428051392947, 0.07471178099513054, 0.04475286536450897, 0.06545509770512581, 0.06225414268140282, 0.020120797379474555, 0.054288267091448815, 0.017029932966189723, 0.015757069124707153, 0.02049292633975191, 0.007545211019792727, 0.07517907449177333, 0.015695171463968496, 0.09265876760972397, 0.02620522428437003, 0.055164455968354426, 0.03483835594462497, 0.0009774976538860106, 0.023551999691075513, 0.02536684337870351, 0.06274084227957896, 0.033258580536182435, 0.04577681541975055, 0.02344111180199044, 0.10772567162556307, 0.006927243309162025, 0.02220341643052442, 0.019562463143042157, 0.03353034059650131, 0.01932256369452391, 0.02297049687643136, 1.1991332492658069, 35.61252287455967, 29.62239749091012, 30.399032388414653, 39.17578492845808, 37.21807786396572, 4.779525543962206, 0.12285811533885342, 0.16895869374275208, 1.4407175545181548, 3.1719416805676053, 7.014269011361258, 8.565593310764857, 8.47427487373352, 1.75153968163899, 0.5847515996013368, 21.111324957438878, 52.67913293838501, 53.11733150482178, 51.94907876423427, 47.99847200938633, 44.0440993309021, 42.97910724367414, 44.30717202595302, 45.823925563267295, 46.945733070373535, 48.16250160762242, 51.62665108272007, 51.066838196345735, 46.59443909781319, 45.30776473454067, 48.924121447971885, 48.10808331625802, 45.53656196594238, 44.06587151118687, 37.19884525026594, 38.35840579441616, 37.26022911071777, 37.280062743595664, 37.46843188149588, 37.48398889814104, 36.78456585747855, 35.828980105263845, 39.02649245943342, 38.09225852148873, 36.02978651864188, 37.332903793879915, 37.43479912621634, 35.44757611410958, 35.814520903996055, 36.36875786100115, 37.37306438173567, 40.12860529763358, 45.154463154929026, 46.20113631657192, 46.60652548926217, 51.02876206806728, 48.977646895817344, 48.12951503481184, 43.8441093308585, 39.59417765481131, 47.011820861271445, 48.84851809910366, 45.972311292375835, 42.87133026123047, 52.697000231061665, 56.20399924686977, 47.80542325973511, 48.297560691833496, 45.4457003729684, 45.6705892426627, 41.01878765651158, 39.296485560280935, 37.300636359623496, 39.19240501948765, 38.80682168688093, 38.828777994428364, 39.464944635118755, 40.55719450541905, 39.04378999982561, 35.64622163772583, 34.34835720062256, 34.71228994641985, 34.85331753322056, 35.30547155652727, 35.40483774457659, 35.262990270342144, 34.8190907069615, 33.84333086013794, 33.89510536193848, 33.67297145298549, 34.88068996156965, 35.04331602369036, 39.914517402648926, 43.67015075683594, 45.30930723462786, 46.18633665357317, 44.7811017036438, 44.11045115334647, 45.45504222597395, 43.131540298461914, 41.06881468636649, 36.45271641867501, 33.64049557277134, 33.62975713184902, 33.2756005014692, 41.164102281842915, 44.28367321831839, 45.87397691181728, 44.966733251299175, 42.83969858714512, 44.766170024871826, 43.79421779087612, 46.19878782544817, 43.685165813991, 45.31796816417149, 41.398444175720215, 26.81076897893633, 1.1537295941795622, 1.4620458100523268, 4.23301454952785, 6.698362648487091, 13.026782359395709, 8.518289106232778, 5.466755364622388, 0.2692889986293656, 0.33203774584191187, 7.221779133592333, 36.46484797341483, 29.771432876586914, 24.367963007518224, 44.239670276641846, 39.014190673828125, 7.42166360786983, 0.03500004744689379, 0.047298776251929145, 0.08540647676480667, 0.04381936741992831, 0.06275479295956236, 0.12224729811506611, 0.040386808038290055, 0.041807466984859536, 0.0233781267888844, 0.012544769843641137, 0.05432318450350847, 0.050125868658402135, 0.07806202050830637, 0.021446712481390153, 0.03911221393250993, 0.04219042197135942, 0.03086828486993909, 0.016641525950814997, 0.058345387423677106, 0.12181152935538973, 0.057695445870714526, 0.14787509079490388, 0.16044531842427595, 0.14737605543008872, 0.17083188465663365, 0.1249393993722541, 0.23958599248102733, 0.11819484271109104, 0.10013452717768294, 0.16394726479692118, 0.13531405052968434, 0.12475812195667199, 0.1643343690250601, 0.12866344382720335, 0.08272567990102939, 0.1733663622289896, 0.13037318922579288, 0.12893557708178247, 0.14158266915806703, 0.13746891490050725, 0.15832235877002987, 0.140792881537761, 1.7488991490432193, 39.88700601032802, 36.972257546016145, 37.25497279848371, 37.82248428889683, 44.74786499568394, 8.502098066466194, 0.2748061940073967, 0.29344036696212633, 3.739444919994899, 10.661444459642683, 11.374373061316353, 18.23766119139535, 9.986528583935328, 4.076763893876757, 0.8319955925856317, 21.40616134234837, 52.00765207835606, 56.407209736960276, 54.62330143792288, 50.58272245952061, 46.34880985532488, 46.46972240720476, 46.414637088775635, 47.87946673801967, 49.69562857491629, 51.61966814313616, 52.88987180164882, 53.400824955531526, 46.57548788615635, 47.67235483442034, 50.45890556062971, 51.45813642229353, 47.681005341666086, 46.14321265901838, 37.58308063234602, 40.34011888504028, 39.21820715495518, 38.76416322163173, 39.46802268709455, 39.22154229027884, 38.11716086523873, 37.55335276467459, 40.217264311654226, 39.2924347605024, 37.14188739231655, 39.527433259146555, 39.48745679855347, 37.82556928907122, 37.209121635981965, 39.00426517214094, 39.81997326442173, 42.231633935655864, 48.377291270664756, 47.90728037697928, 48.62363270350865, 51.80668238231114, 50.08810452052525, 49.66214173180716, 47.65223632540022, 46.1189842905317, 49.22961636951992, 48.70896700450352, 47.09704746518816, 46.27360602787563, 50.054596832820344, 50.29265601294381, 49.661339214869905, 49.831736837114605, 48.00137288229806, 47.58439758845738, 42.58934109551566, 41.685498578207834, 38.46120439256941, 41.123257296425955, 41.580066612788606, 40.855140209198, 42.03924526487078, 41.98436491830008, 41.78977714266096, 37.49949380329677, 36.686405181884766, 35.38226999555315, 36.77643646512713, 37.08509281703404, 37.08132341929844, 36.971906661987305, 35.66471079417637, 34.65142372676304, 34.73962068557739, 35.761311599186485, 36.590224742889404, 36.93223244803292, 40.89109018870762, 46.19765179497855, 47.64363445554461, 47.56169434956142, 45.499493326459614, 44.40274797167097, 45.27852324077061, 43.48687812260219, 42.80848033087594, 39.43599149159023, 35.08349050794329, 34.61726985658918, 34.59108904429844, 43.85297870635986, 47.03120633534023, 46.3149790763855, 45.218629768916536, 43.48770495823452, 46.19724532536098, 44.87284919193813, 48.534278869628906, 46.312779971531455, 46.51698752811977, 43.57639523914882, 29.519852502005442, 1.2514473221131732, 2.7393993820462907, 6.3186448982783725, 18.356166192463466, 23.15562047277178, 13.516224758965627, 13.586088027272906, 4.557828068733215, 0.8073175453713962, 10.929052591323853, 46.92045552389962, 32.92664112363543, 30.17592920575823, 49.38735784803118, 45.438988413129536, 9.22376663344247, 0.17247376298265799, 0.17655432330710547, 0.15601972304284573, 0.1589231336755412, 0.15328057216746466, 0.25731244842920986, 0.1327994947454759, 0.12184145274971213, 0.10654934296118361, 0.16976741249007837, 0.08008477411099843, 0.1402871829590627, 0.17095469949500902, 0.0942664545561586, 0.10085942649415561, 0.19431431245590958, 0.07536634337157011, 0.14234061991529806], [0.08362990245223045, 0.044519710554076095, 0.02026357302176101, 0.009478021413087845, 0.03805643040686846, 0.04638623486139944, 0.06881714372762612, 0.03776597670678582, 0.0760553888976574, 0.024403919066701616, 0.07803726076547589, 0.04092775990388223, 0.08557053974696568, 0.023056487619344677, 0.05174052415947829, 0.046975400032741685, 0.015725761518946717, 0.01712750460553382, 0.011238210801301258, 0.021264814206265976, 0.05966914139155831, 0.004214090927104864, 0.03892436829794731, 0.038525382921631844, 0.04830869759566017, 6.879457456724984, 37.28975200653076, 25.279764686311992, 27.476423774446758, 38.530227797372, 17.613308225359233, 0.05480221326329878, 0.028747374391449348, 0.2961696519383362, 2.9920454365866522, 5.34430639232908, 4.136862337589264, 6.4492297768592834, 5.681966262204306, 0.9079538966928209, 2.7330602364880696, 34.23769324166434, 51.639661584581646, 51.82421268735613, 50.481341293879915, 47.05621290206909, 42.951359612601145, 44.42130313600813, 44.54877131325858, 47.79245444706508, 49.31541967391968, 49.88705492019653, 46.64797496795654, 44.63963638033186, 47.728339944567, 49.00507490975516, 46.43559980392456, 43.45161254065377, 38.064649854387554, 36.386444500514436, 36.41108281271798, 35.763090338025776, 36.20996025630406, 36.85374559674944, 37.590668065207346, 33.87236043385097, 34.22314371381487, 36.78834915161133, 35.56135981423514, 34.331358432769775, 35.26051671164376, 33.94078629357474, 33.72901562282017, 34.24444341659546, 34.43383393968855, 34.39257901055472, 41.23902818134853, 46.449176583971294, 45.57331098828997, 43.599789823804585, 46.42473976952689, 46.519947460719514, 45.47891623633248, 44.08645902361189, 45.41499975749424, 39.55336046218872, 40.59173400061471, 45.23451335089547, 51.898263113839285, 48.28468567984444, 46.80655370439802, 47.52287476403372, 44.06504120145525, 43.868004185812815, 40.11868674414498, 37.08640602656773, 35.87306295122419, 37.60808719907488, 35.662150382995605, 39.33339786529541, 40.19683313369751, 44.429137229919434, 43.54983575003487, 41.50757605688912, 35.592056955610005, 33.16194881711687, 33.03615515572684, 33.88576698303223, 34.19176912307739, 31.937012672424316, 32.08971323285784, 32.45089101791382, 32.3230858530317, 31.129642418452672, 32.32653563363211, 33.06974622181484, 33.245163917541504, 33.7760306085859, 39.715503624507356, 42.99021046502249, 43.35722126279558, 44.92696523666382, 42.83884048461914, 44.14277764729091, 45.26510974339077, 41.748706340789795, 38.501701968056814, 34.85092735290527, 32.67820828301566, 31.245944840567454, 33.19695731571743, 38.839780466897146, 42.689575808388845, 44.004727363586426, 44.383174896240234, 42.68403114591326, 44.971322536468506, 42.05362803595406, 45.118839740753174, 40.29981933321272, 41.528229577200754, 13.577263815062386, 0.29752661341003006, 1.3480049180133002, 3.682638619627271, 6.134268368993487, 12.149153658321925, 8.138295599392482, 5.329990931919642, 0.7784760072827339, 0.20762403469000543, 21.692696366991314, 36.290135519845144, 26.737194504056657, 29.741524355752126, 30.370534351893834, 15.37538378579276, 0.7014264017343521, 0.021787986758032014, 0.05861534258084638, 0.04810057733474033, 0.08089202043733426, 0.04412435194743531, 0.04956206712605698, 0.03898349923214742, 0.03606031269633344, 0.06564486359379121, 0.03454613805349384, 0.020741271852914776, 0.030889482303921665, 0.020785098429769278, 0.017639728994773965, 0.04116811736353806, 0.013754887855611742, 0.04566129483282566, 0.05170845320182187, 0.06192769269858088, 0.04381277545222214, 0.014742956130898424, 0.02317776218322771, 0.04037105245515704, 0.027037206604810696, 0.06805224477180413, 0.047641368582844734, 0.02093143298822854, 0.028424177984041826, 0.01929857239260205, 0.04140801002670612, 0.10522612503596715, 0.05040299253804343, 0.031894294278962274, 0.026880229224583933, 0.051847471456442557, 0.028637580640081848, 0.020700186557535614, 0.013563354383222759, 0.03273966070264578, 0.03745180820780141, 0.022030644451401064, 0.1764594233993973, 0.0915197990834713, 10.686525719506399, 42.67474487849644, 25.935830967766897, 32.319677761622835, 43.95199053628104, 19.399683134896414, 0.040005993829774, 0.2146525446857725, 0.27558425654258045, 2.1807140580245425, 5.489527216979435, 5.69976624420711, 8.911624891417366, 9.895155429840088, 3.0894628720624104, 3.9424500039645602, 38.71666186196463, 52.589970179966514, 52.73764371871948, 51.49148430143084, 48.07820953641619, 44.097225257328574, 45.63234635761806, 46.20776489802769, 50.729926994868684, 50.84718132019043, 50.82895966938564, 46.95399795259748, 46.32616567611694, 48.59006248201643, 50.75092445101057, 48.07591315678188, 45.24585975919451, 39.547437122889924, 38.640707629067556, 37.296846117292134, 35.94588007245745, 38.49028607777187, 38.49558407919747, 37.97236040660313, 36.143167223249165, 36.370005062648225, 38.89375754765102, 36.56305381229946, 35.70151540211269, 37.23732089996338, 36.02155985151018, 35.80397006443569, 36.06678220203945, 36.72640943527222, 35.94948966162545, 43.14347035544259, 49.07459511075701, 46.39780855178833, 47.297176429203574, 47.375461782727925, 48.241478306906565, 45.76707540239607, 45.893994671957834, 45.268906933920725, 38.98902777263096, 44.47822625296456, 47.47407409123012, 52.289352893829346, 49.94457905633109, 46.21314975193569, 48.56291587012154, 46.171300751822336, 47.16675179345267, 42.660136290958945, 39.28872094835554, 39.09605087552752, 39.184039388384136, 37.22466823032924, 40.301274980817524, 41.48793002537319, 44.1443236214774, 43.550961358206614, 42.05446181978498, 36.32186794281006, 35.44986554554531, 34.01632710865566, 35.124536991119385, 34.75247137887137, 34.1191326550075, 33.5901072365897, 33.5119434765407, 34.078235558101106, 32.21369341441563, 34.387378283909385, 35.61638607297625, 34.259753772190635, 35.30426604407174, 42.37058401107788, 44.24324859891619, 46.65506213051932, 45.808531829289024, 42.78316109521048, 44.73954452787127, 47.206863743918284, 44.23971543993269, 39.734969002859934, 35.48769848687308, 33.6690457207816, 33.74984632219587, 36.3849367414202, 41.441585540771484, 43.65230778285435, 44.339870248522075, 44.94244582312447, 44.176323550088064, 46.45544385910034, 43.23967511313302, 46.62754378999983, 41.053344522203716, 42.59090791429792, 15.17940810748509, 0.7037298381328583, 3.809388961110796, 4.287734219006129, 6.947860300540924, 11.358606730188642, 8.601482493536812, 4.800958565303257, 0.5202086972338813, 0.19169222244194575, 23.79418076787676, 39.4810540335519, 31.218155520302908, 30.24425084250314, 40.238306931086946, 26.48243532861982, 2.295725852251053, 0.044294918687748056, 0.014825593214482069, 0.03783494300608124, 0.07233576849102974, 0.09677964648497955, 0.0350928710374449, 0.03657826901014362, 0.04621482673766358, 0.040728782902338674, 0.026232126501521895, 0.01365739170328847, 0.013144987502268382, 0.028099756820925643, 0.03904316960168736, 0.029068365560046265, 0.07442887938980546, 0.01588227240634816, 0.04578800106953297, 0.1441993173211813, 0.17144742448415073, 0.13056578460548604, 0.06416762500469174, 0.1350278987416199, 0.14907100876527174, 0.2194086816161871, 0.11766208415584904, 0.1645050612943513, 0.14961242542735168, 0.22114556841552258, 0.21495268786592142, 0.15355277327554567, 0.1694412407066141, 0.16681026188390596, 0.14734050019511155, 0.09589877910912037, 0.07128259393253497, 0.2013177437973874, 0.1907326653599739, 0.11798387260309287, 0.24037388020328113, 0.1405245887913874, 0.3278490677475929, 0.15705641598573752, 12.392120003700256, 50.868863173893516, 31.662513664790563, 35.9878819329398, 48.855813707624165, 27.66025573866708, 0.16148779248552664, 0.6640722347157342, 1.2121889144182205, 7.8840705667223245, 14.32704826763698, 10.22504721369062, 11.64955733503614, 8.400037714413234, 1.897133320569992, 4.101280612604959, 38.006528173174175, 51.98575483049665, 54.58495085580008, 52.568482875823975, 50.54434755870274, 45.3002815246582, 49.68064825875418, 48.77544042042324, 52.9134817804609, 52.811273779187886, 52.981216294424875, 49.16598129272461, 46.40347133363996, 51.23896939413888, 52.86622013364519, 50.25298874718802, 46.71823862620762, 42.05038670131138, 39.46410737718855, 39.42969989776611, 38.720549379076274, 40.16735887527466, 40.51423379353115, 41.173260007585796, 38.22954797744751, 38.70040307726179, 40.108504159109934, 38.83970403671265, 38.458098547799246, 39.714270319257466, 37.232009002140586, 38.19801357814244, 38.070712157658164, 38.2573025567191, 38.0285678591047, 45.34912736075265, 51.232055936540874, 47.05509771619524, 47.22776392527989, 48.21246957778931, 48.879670347486226, 47.50319399152483, 47.940419810158865, 46.51715775898525, 43.552357946123394, 46.38417271205357, 49.74244901112148, 51.07276848384312, 44.690604891095845, 49.40464844022478, 49.805490016937256, 47.60716336114066, 47.99416412625994, 44.697129249572754, 40.35465104239327, 41.04522902624947, 41.49000058855329, 40.1354319027492, 43.24867303030831, 43.869230542864116, 47.46258871895926, 46.42800542286464, 44.32851341792515, 38.14916426794869, 37.31872252055577, 36.59633220945086, 37.03294311250959, 36.6859952381679, 35.071345056806294, 34.908632142203196, 35.57652773175921, 35.94959735870361, 33.47572946548462, 36.1545136315482, 36.72221967152187, 37.36714799063546, 37.10067415237427, 43.810848304203574, 45.80480064664568, 48.19497748783657, 48.18547582626343, 44.16842344829014, 45.73594052450997, 48.83098431995937, 44.93125574929373, 41.18244205202375, 38.22450705936977, 35.244014739990234, 34.855773721422466, 37.18629332951137, 42.49390411376953, 47.40480749947684, 45.12974146434239, 45.98295593261719, 45.79636900765555, 49.71517038345337, 45.49970524651663, 46.55280201775687, 43.81000062397548, 44.084252970559255, 16.791044507707866, 0.9897268116474152, 6.427571373326438, 7.696704574993678, 12.437922528811864, 21.784627982548304, 17.575471809932164, 15.843706267220632, 2.201666785137994, 0.3668471894093922, 28.736441373825073, 45.519326959337505, 38.34908478600638, 38.082051617758616, 45.24513714654105, 30.314455441066197, 3.506179996899196, 0.12128520331212453, 0.1047447519376874, 0.16584751568734646, 0.18680700100958347, 0.23416734752910479, 0.11799418633537632, 0.14894201925822667, 0.1032003994498934, 0.1321098996060235, 0.14006348353411469, 0.09265695592122418, 0.11729866079986095, 0.17523730040660926, 0.12935466745070048, 0.10191054509154387, 0.14670678919979505, 0.19813700233186993, 0.15460143557616643], [0.01708112164799656, 0.03419324556099517, 0.07359012868255377, 0.0346969662101141, 0.0739639743364283, 0.06010553440345185, 0.06196345149406365, 0.019807460085887994, 0.09145490399428777, 0.007391788314894906, 0.10035262190337692, 0.004399499772781772, 0.02779317264711218, 0.022826750929068242, 0.04132855696869748, 0.05815917027315923, 0.01727511141715305, 0.048933916725218296, 0.04605398340416806, 0.03329521803451436, 0.01862775062077812, 0.044746802654117346, 0.04426786210387945, 0.08799896908125707, 0.0947601023529257, 0.4464349230485303, 21.843008484159196, 32.937556743621826, 22.32938759667533, 33.92610822405134, 25.52345711844308, 4.127485743590763, 0.22257141476230963, 0.37559445574879646, 1.225946456193924, 3.601567038467952, 5.921965292521885, 10.806432519640241, 2.056361062186105, 1.3001102251665932, 0.30637544287102564, 12.0857652425766, 53.63928713117327, 52.61204808098929, 50.98489809036255, 47.75981181008475, 45.64039931978498, 45.44158009120396, 47.11222927910941, 47.242629596165244, 49.54695102146694, 47.730969837733674, 47.58155230113438, 50.09680366516113, 48.190558433532715, 47.366995402744834, 46.13600042888096, 39.90718705313546, 35.01199007034302, 34.86457361493792, 39.70033918108259, 35.997223785945344, 34.483207838875906, 34.294133458818706, 36.57155493327549, 36.939055579049246, 35.918597970690044, 36.54928248269217, 35.57711138044085, 34.86098139626639, 34.946055139814106, 34.25140898568289, 35.31827013833182, 35.16952657699585, 34.27299703870501, 34.86641836166382, 40.968698092869346, 47.04656185422625, 44.941994190216064, 42.94703435897827, 43.538089820316856, 47.232401847839355, 44.920135157448904, 44.802595955984934, 46.44649805341448, 48.64745807647705, 46.52464096886771, 48.07349518367222, 44.01283938544137, 41.67504848752703, 48.78031458173479, 49.47682632718767, 44.455318042210166, 43.16882085800171, 40.09397894995553, 39.06854295730591, 38.40473290852138, 40.814962250845774, 42.17585727146694, 44.2821307182312, 43.127708366939, 46.92658036095755, 44.97188186645508, 45.272815295628135, 40.083653926849365, 33.05750002179827, 32.27368416104998, 32.82729925428118, 32.72778715406145, 33.05795860290527, 32.75470447540283, 32.10680232729231, 34.25201347896031, 32.33306694030762, 31.940931456429617, 31.514120987483434, 33.36865772519793, 33.035682678222656, 36.4579518863133, 37.19136898858206, 44.7209198815482, 44.60706669943673, 44.72218097959246, 43.98294128690447, 43.29084512165615, 43.22318703787667, 41.95706197193691, 38.293808392116, 33.9270601272583, 32.200269494737896, 32.81198195048741, 35.14400931767055, 37.98965794699532, 39.24197346823556, 40.57208449499947, 40.88742501395089, 42.02734994888306, 43.67349631445748, 43.257288796561106, 41.142003536224365, 36.36537756238665, 3.8408703804016113, 0.5323317838566644, 1.7774856665304728, 4.036429166793823, 4.998401182038443, 5.601652468953814, 4.294903457164764, 1.8219077800001418, 0.13304782499160084, 1.0051229340689523, 22.36978268623352, 34.88173566545759, 20.28005463736398, 27.10787395068577, 20.10284604345049, 6.014359831809998, 0.236998195626906, 0.03434995661622711, 0.02241388611894633, 0.030119015968271663, 0.035312451754829714, 0.016103485000452826, 0.08182012742119175, 0.06234383822551795, 0.0098825682320499, 0.01843206281773746, 0.07690943378422942, 0.06427353075040237, 0.038015806515301974, 0.038383246798600466, 0.02194688269602401, 0.011906475344273661, 0.035385075357875655, 0.014087907753751745, 0.004352940820224051, 0.02972908564178007, 0.04474165935867599, 0.056407613546720574, 0.04339346116674798, 0.06710586483989443, 0.07629390074206249, 0.027727485368294374, 0.031181442351745706, 0.0931296573419656, 0.02238817303441465, 0.034221201203763485, 0.04912470720176186, 0.009703313698992133, 0.045339981360094886, 0.015709837998396585, 0.024189384953518, 0.04304916910561068, 0.0242691569229854, 0.017926720469923954, 0.02291161021483796, 0.029589392244815826, 0.020613279792347124, 0.06067304752234902, 0.033456136006861925, 0.0911524605804256, 1.2489550901310784, 29.952148573739187, 34.73555946350098, 23.073266948972428, 43.27404090336391, 31.17738001687186, 3.9835694432258606, 0.1295092920107501, 0.26356750992791994, 0.6913653558918408, 7.134517576013293, 7.273058141980853, 9.483589308602468, 6.816766032150813, 3.9959910852568488, 0.7865067135010446, 14.956845147269112, 53.09628888538906, 53.02332237788609, 52.300490856170654, 49.16298661913191, 44.958457946777344, 46.970256737300325, 47.38010317938668, 50.24497400011335, 50.1598550932748, 49.16505370821272, 47.181565352848594, 51.81401968002319, 49.56702784129551, 49.10713699885777, 48.20833887372698, 40.5136536189488, 38.32043388911656, 36.610454423086985, 39.48296478816441, 38.03719057355608, 36.28072418485369, 37.50390938350132, 38.059789589473176, 37.630575043814524, 37.54240240369524, 37.88016128540039, 36.81190701893398, 36.31175831386021, 36.50793375287737, 36.53401034218924, 36.868600845336914, 36.26260675702776, 35.245369638715474, 35.771775586264475, 41.631243569510325, 48.15277760369437, 46.53916270392281, 44.49402298246111, 45.122390270233154, 47.0763453074864, 47.38395248140608, 44.95771448952811, 47.6853792326791, 50.43545191628592, 46.951864855630056, 48.13502148219517, 45.12087556294033, 41.4889166695731, 48.93705204554966, 50.59616027559553, 46.46641159057617, 44.32089124407087, 40.68606274468558, 39.85687862123762, 39.448918615068706, 41.19279834202358, 42.390198775700156, 44.22892141342163, 45.39572198050362, 48.14638178689139, 47.31685025351388, 48.44202763693673, 41.19231196812221, 34.35660818644932, 34.53062234606062, 34.410505362919395, 33.53319801603045, 34.245134762355256, 34.25607122693743, 33.70141390391758, 34.67310210636684, 34.39689384187971, 34.39708144324166, 34.17990507398333, 35.37094790594918, 34.2712356703622, 38.605650493076865, 39.72997324807303, 45.10628434589931, 45.70398228509085, 44.60835906437465, 43.65215144838606, 44.861926623753135, 45.304433073316304, 42.366720812661306, 39.790151596069336, 35.627676895686555, 33.06002221788679, 34.497844219207764, 36.2199969291687, 41.06672327859061, 40.93025371006557, 42.57160234451294, 42.39551762172154, 45.049802439553396, 44.159998757498606, 45.48094858442034, 41.2422764641898, 40.55395317077637, 4.002846351691654, 1.3573831404958452, 5.001949105943952, 4.762253190789904, 6.241622814110347, 8.842918498175484, 4.842389804976327, 1.3275285767657417, 0.10801544679062706, 1.1277146701301848, 25.83378972326006, 39.14724520274571, 26.58029896872384, 30.19591917310442, 27.603257928575786, 12.167890344347272, 0.2409718595445156, 0.024369971959718635, 0.05760262906551361, 0.018632364658904926, 0.026990886411762664, 0.05838744302413293, 0.0734693765906351, 0.04808457408632551, 0.04580112054411854, 0.08264260007334606, 0.06388285064271518, 0.060921608470380306, 0.06839635702116148, 0.015004645035203015, 0.005892999029518771, 0.01756976355266358, 0.02350938769190439, 0.044897885261369605, 0.03376467605786664, 0.09771670334573303, 0.1385078334382602, 0.14454101398587227, 0.13584053942135402, 0.12445252335497312, 0.16291324528200285, 0.08835232297756843, 0.09518054979188101, 0.27940527722239494, 0.11295389250985213, 0.2284372007208211, 0.15445669048598834, 0.10192704706319741, 0.11129947485668318, 0.09125609323382378, 0.11992836397673402, 0.07053220205541168, 0.11175744528216974, 0.12254418432712555, 0.18292085453867912, 0.11491093678133828, 0.16555945043052944, 0.11431594299418585, 0.20222635647015913, 0.1337172676409994, 1.0902936267001289, 33.78237778799874, 44.32160690852574, 30.43592037473406, 43.72040360314505, 37.32929767881121, 7.19820476429803, 0.40349527288760456, 1.057193819965635, 3.8719053779329573, 10.654161010469709, 13.56721932547433, 20.290035724639893, 4.5746639881815225, 2.6705444710595265, 1.0168895998171397, 14.26555323600769, 55.216347558157786, 56.896470614842, 54.70534576688494, 51.76925591060093, 49.02482863834926, 48.11395454406738, 49.769849232264924, 51.04640007019043, 55.447576659066335, 50.06097180502755, 48.48895229612078, 53.699507168361116, 51.808266571589876, 50.85215275628226, 51.27646882193429, 42.27344124657767, 39.801272187914165, 37.63392060143607, 43.455048424857004, 39.62650414875576, 36.944697516305105, 39.01860972813198, 40.427346570151194, 40.30989074707031, 38.06837408883231, 37.951554025922505, 38.99481562205723, 38.554987703050884, 38.9679399899074, 39.280570711408345, 39.71043838773455, 38.19689491816929, 36.75041198730469, 37.59165470940726, 44.20386273520333, 50.62451934814453, 48.90764379501343, 46.812688963753835, 45.88763359614781, 48.76014048712594, 48.04606022153582, 45.96307713644845, 49.98439570835659, 52.73103250776018, 47.2989308493478, 49.91783891405378, 48.244420869009836, 44.16239241191319, 50.06100654602051, 53.78342056274414, 46.62558092389788, 46.71865899222237, 43.069920199257986, 41.12196840558733, 41.259549685886924, 43.919789109911235, 45.13612338474819, 48.00415563583374, 45.42611687523978, 51.4307917867388, 47.5865341595241, 47.882089682987754, 43.739170687539236, 36.45600986480713, 36.155437741960796, 35.94131858008248, 35.813690594264436, 35.59968260356358, 35.97122710091727, 36.077864578792024, 37.101031984601704, 37.17083011354719, 36.22202580315726, 36.674183300563264, 36.79910148893084, 36.86923313140869, 40.375672817230225, 41.0312214578901, 47.67197615759713, 48.18974896839687, 47.15822982788086, 44.72194821493966, 44.84963526044573, 46.19690138953072, 44.461269174303325, 42.25036627905709, 36.49096972601754, 35.42524112973894, 35.89274372373308, 38.962867804935996, 42.51356404168265, 43.11251613071987, 44.49911948612758, 43.595304761614116, 45.92190211159842, 47.79646703175136, 46.40471158708845, 43.99291890008109, 39.06658009120396, 4.9974961791719705, 2.1766291686466763, 5.959215887955256, 10.339576976639883, 14.059333307402474, 13.554529309272766, 12.248877678598676, 7.274248455251966, 0.35021949878760744, 1.5744039352451051, 31.631958961486816, 43.92185272489275, 29.66103642327445, 37.808733803885325, 34.414281708853586, 13.178207056862966, 0.41901670715638567, 0.13029912034315722, 0.15492509678006172, 0.12356774083205632, 0.09849850460886955, 0.1660130646611963, 0.16785211169293948, 0.16296652385166713, 0.15175597183406353, 0.16609125903674535, 0.22192517801054887, 0.18856432528368064, 0.22048052267304488, 0.14119148014911584, 0.11788297444581985, 0.10259965168578283, 0.16562847101262637, 0.10341548826545477, 0.3025108059602124], [0.015208675426297953, 0.10692409106663295, 0.02012842580942171, 0.021016880903126936, 0.019699803719829236, 0.016565650468692183, 0.00979413221856313, 0.03347303152882627, 0.08645994309335947, 0.05646539419623358, 0.004893343496535505, 0.054551694741738696, 0.03202076302841306, 0.04146733773606164, 0.0041741850104049915, 0.0432522274952914, 0.07098046264478139, 0.02073163495931242, 0.07472771978271858, 0.03139543194057686, 0.05591153320191162, 0.047021492916558466, 0.03132971582402076, 0.011858946510723658, 0.0382487882993051, 0.050004041088478904, 4.275118027414594, 29.234670639038086, 23.847209419522965, 30.976521492004395, 37.231727600097656, 13.8086770432336, 0.14270590245723724, 0.03701806487515569, 0.4237958464239325, 5.268863720553262, 4.027784739221845, 8.316547291619436, 11.626738582338605, 5.751539877482823, 0.40701065425361904, 1.105554693511554, 32.85177428381783, 54.72433866773333, 50.919251510075156, 51.107829093933105, 47.994237082345144, 45.12641675131661, 49.691678524017334, 47.855690002441406, 50.69044733047485, 48.68180997031075, 50.58243758337838, 48.696745123182026, 46.41103097370693, 46.30702338899885, 40.17232683726719, 37.4314535685948, 37.89231021063668, 37.85143395832607, 38.865290778023855, 39.13154574802944, 38.460686751774375, 39.44883523668562, 36.428481101989746, 34.53618785313198, 35.979679584503174, 35.09479522705078, 33.95103488649641, 34.27283028193882, 35.003231866019114, 34.73535449164254, 35.037945066179546, 33.892916679382324, 33.27087572642735, 34.84470871516636, 40.994528021131245, 46.20920664923531, 45.40056834902082, 44.89076164790562, 45.40792301722935, 45.55815349306379, 46.300492082323345, 47.6973614011492, 46.88028103964669, 44.10475015640259, 46.46305561065674, 46.325557708740234, 46.42938116618565, 44.533019747052876, 46.34837906701224, 48.13976015363421, 46.31348173958914, 45.62154538290841, 40.96746131352016, 39.207183837890625, 42.67213582992554, 45.51655462809971, 45.885014125279014, 46.44546972002302, 47.34667887006487, 47.697389193943565, 46.62058169501168, 46.30955253328596, 40.348324707576204, 32.048350606645855, 32.70060927527291, 34.188607692718506, 33.561220100947786, 33.802267006465364, 32.25562926701137, 32.613405908857075, 32.388822759900776, 31.826074259621755, 32.46708379473005, 31.451979773385183, 31.781817708696636, 32.678885732378276, 34.088567529405864, 34.657694475991384, 38.71586629322597, 41.460811206272666, 42.81860038212368, 44.425253186907085, 42.65640163421631, 42.2826441356114, 43.22431264604841, 43.16370350973946, 40.99226638248989, 37.549041407448904, 35.614694186619346, 38.13207169941494, 38.26841620036534, 39.82349252700806, 41.608269350869314, 40.169988768441335, 40.302602086748394, 41.2193717275347, 43.43433237075806, 42.5797004699707, 26.695866618837627, 0.7495533164058412, 0.9704313384635108, 2.9212267909731184, 2.564701476267406, 5.83801759140832, 5.077655375003815, 3.516429675476892, 1.706746165241514, 0.04817824245297483, 2.4000343808106015, 31.062109402247838, 24.221347332000732, 18.64798879623413, 30.502883638654435, 14.108440569468907, 0.5873191761119025, 0.0404242903127202, 0.02873046529878463, 0.03763230191543698, 0.061984289304486344, 0.017759161336081367, 0.05645702785945364, 0.035690232911812406, 0.07356357760727406, 0.03099808861900653, 0.07019263599067926, 0.04016610434544938, 0.040438010290797265, 0.0738888197977628, 0.08075019983308655, 0.030555283451186757, 0.03281655229095902, 0.05128190912572401, 0.005692934251523444, 0.037170134750860076, 0.0195717030936586, 0.09067477192729712, 0.004319176069527332, 0.019304514663027864, 0.025692909989239912, 0.03497804255623903, 0.03363257886043616, 0.049590270434107096, 0.047099996025541, 0.08549819434327738, 0.022380193462595344, 0.04415606328153184, 0.04652670857363513, 0.04883467758606587, 0.05470890112753425, 0.042520916022892506, 0.03166548887799893, 0.013530028135781842, 0.048599724657833576, 0.029503866298390285, 0.09190532232501678, 0.07860849225627524, 0.03626272987042155, 0.07168196607381105, 0.0739588038995862, 0.033590567364756546, 6.908322444983891, 38.51557404654366, 22.985825606754847, 33.53329529081072, 39.39035224914551, 16.909064871924265, 0.1590462334986244, 0.0495678787784917, 0.5412378002490316, 4.289125595773969, 7.77894605909075, 7.808931878634861, 14.837157215390887, 8.729472654206411, 1.1275678894349506, 1.562668319259371, 37.245095934186665, 56.45009054456438, 52.7510780606951, 53.28576626096453, 50.06707232339041, 47.01095233644758, 51.51500047956194, 49.08302674974714, 51.664289474487305, 49.31375905445644, 50.6572835786002, 49.77972262246268, 47.74781574521746, 46.939660344805034, 43.10267400741577, 38.85338156563895, 38.125696727207725, 39.771679810115266, 39.603675842285156, 39.99656173161098, 39.36985853740147, 39.05776630129133, 38.521313258579795, 37.91802201952253, 36.79761804853167, 37.52631384985787, 36.90332446779524, 36.613824299403596, 36.816558837890625, 35.879677636282786, 36.80923196247646, 36.95795815331595, 36.124924727848594, 36.31744541440691, 43.13738373347691, 47.04897287913731, 46.87915195737566, 46.91748864310128, 45.78147554397583, 47.23917634146554, 47.84805045809065, 48.572549547467915, 46.996496609279085, 44.84242997850691, 49.72184412819998, 49.379336152757915, 47.53163644245693, 45.14455154963902, 48.153712136404856, 50.0963659286499, 48.39019407544817, 46.87925270625523, 43.9831497328622, 41.637014048440115, 44.83068404878889, 46.235502106802805, 47.27710655757359, 47.30663987568447, 49.24214397157942, 48.90029954910278, 47.386325291224885, 48.42878784452166, 42.62181697572981, 33.45252595629011, 34.55996458871024, 35.23985276903425, 34.81373364584786, 34.79220117841448, 34.160686356680735, 34.915681089673726, 34.86802339553833, 32.595962456294465, 35.08300065994263, 34.41986806052071, 34.137705189841135, 33.12994541440691, 36.15327337809971, 37.35567651476179, 41.86889280591692, 44.37611552647182, 44.80186986923218, 44.51220989227295, 43.02434001650129, 43.002852712358745, 44.49207053865705, 44.14730787277222, 41.880173206329346, 38.32302556719099, 36.075036661965505, 38.677588667188374, 39.17503799710955, 41.761362484523225, 42.83488001142229, 41.372280733925955, 42.9929723739624, 42.969956466129844, 44.51713963917324, 43.43015997750418, 29.90275730405535, 0.9985131344624928, 2.87785114135061, 3.1939431514058794, 6.656968321119036, 12.662726283073425, 7.829640984535217, 4.085250684193202, 0.963869741984776, 0.15265214017459325, 3.3441975116729736, 32.257953439440044, 34.68540736607143, 18.71143627166748, 35.918966225215364, 18.99061141695295, 1.5078820990664619, 0.007274203285175774, 0.10737481473812036, 0.04683869558253458, 0.04307317228189536, 0.04612129407801798, 0.0610465674794146, 0.02310409702892814, 0.0256987640501133, 0.03604046554703798, 0.060961737031383176, 0.09354913447584425, 0.06894702211554561, 0.025525893683412244, 0.05060629520033087, 0.045999853273055384, 0.02019565336273185, 0.07399396558425256, 0.04362238870401468, 0.018065150095415965, 0.09583794844469853, 0.18379393911787442, 0.15462483146360942, 0.15043365636042186, 0.10220758058130741, 0.06557441808815513, 0.18907051240759237, 0.21802441589534283, 0.11520006055278437, 0.12056195283574717, 0.07885742639856679, 0.13973879095699104, 0.21832018930997166, 0.12355906915451799, 0.1466744230794055, 0.09609153055186782, 0.18476500415376254, 0.15738614329269954, 0.17808121708886965, 0.11868817838174955, 0.15937218815088272, 0.2214859758636781, 0.1385825401438134, 0.11671968043914863, 0.16958424874714442, 0.1097254500325237, 7.280600411551339, 44.27366781234741, 33.53993082046509, 40.8014931678772, 47.12767859867641, 23.693122693470546, 0.29666652956179207, 0.3575175500341824, 1.4063597981418883, 12.062289885112218, 13.024129884583608, 14.5534987449646, 17.271746941975184, 11.844844273158483, 0.9054739326238632, 1.7645284703799655, 35.22112042563302, 58.470855985369, 53.808010237557546, 56.04166153499058, 51.29079253332955, 49.44620214189802, 53.97179664884295, 51.58940873827253, 52.644544805799214, 49.259945256369456, 51.61788593019758, 52.538101877485005, 49.806302956172395, 50.31935099193028, 44.68440014975411, 41.427848952157156, 41.94189058031355, 43.51050894601004, 42.161464078085764, 42.48814753123692, 41.29352985109602, 43.29129328046526, 40.65577902112688, 39.443155084337505, 40.06174973079136, 38.55980975287301, 37.46294627870832, 38.47029263632638, 38.11568784713745, 37.62784787586757, 38.800127097538535, 38.263628891536165, 37.32721321923392, 37.979207856314524, 45.84633002962385, 49.988088675907676, 48.30546079363142, 48.88706323078701, 46.193475927625386, 49.573006766183035, 49.12910025460379, 50.94600902284895, 48.84784064974104, 46.18237270627703, 52.1170723097665, 51.593185084206716, 48.72198445456368, 44.517024993896484, 49.282332352229524, 52.7752126285008, 50.855039732796804, 48.73376859937395, 45.16215133666992, 43.681698662894114, 46.54243877955845, 47.24073968614851, 49.30307272502354, 48.49921131134033, 51.612254415239605, 50.74052994591849, 48.90422875540597, 50.87543964385986, 43.93945598602295, 34.339658055986675, 35.48431124005999, 38.172569274902344, 34.75119638442993, 37.57545498439244, 35.88033076695034, 37.079190322331016, 36.92335959843227, 33.82182271139962, 35.98607192720686, 35.28852490016392, 34.896993909563335, 35.05100073133196, 37.769149916512625, 38.29349224908011, 42.225623743874685, 45.27972527912685, 47.2637278011867, 46.08012648991176, 43.05514138085501, 44.3462313243321, 47.34944077900478, 46.610006536756245, 45.88430193492344, 40.17184393746512, 37.82337018421718, 42.06407117843628, 42.579933234623496, 43.24470908301217, 44.675777435302734, 43.382391112191335, 45.20576170512608, 44.61859723499843, 47.57898146765572, 42.060055119650706, 31.04045534133911, 1.2652582781655448, 4.1579214589936395, 9.125356691224233, 8.999605587550572, 15.30838578087943, 11.667208365031652, 11.675862346376691, 3.9802377820014954, 0.20012630415814264, 4.368255155427115, 39.83041640690395, 32.09131131853376, 26.369825874056133, 43.45090382439749, 22.777551616941178, 1.153235512120383, 0.16110717505216599, 0.1658146610217435, 0.11936581773417336, 0.17404545364635332, 0.10475175441907984, 0.18582402089876787, 0.09513307269662619, 0.1240729915776423, 0.0905836107475417, 0.15095471697194235, 0.16186827421188354, 0.14829909375735692, 0.1455961223691702, 0.16637974498527391, 0.22588533908128738, 0.09365267891969, 0.1465131760175739, 0.11851798822837216, 0.10670499889446156], [0.041809448307113986, 0.03047536898936544, 0.06884367444685527, 0.026894770230033567, 0.03437940842871155, 0.05170491124902453, 0.014122431615500577, 0.016903040132352283, 0.04306108757321324, 0.07048980040209633, 0.03536920103111437, 0.022277880559808443, 0.016475980369640247, 0.03535641064601285, 0.03559105823348675, 0.02674416090095682, 0.043434444681874344, 0.0799187637333359, 0.05057998161230769, 0.04023122335118907, 0.007983483573687928, 0.029958745996866907, 0.05025447479316166, 0.05493586091324687, 0.032295009919575283, 0.050087331262017996, 0.18301400382603916, 11.231158529009138, 34.93581002099173, 23.956626176834106, 37.39710514886038, 24.85486149787903, 0.90536211005279, 0.06480871846101113, 0.15954822727612086, 5.548501355307443, 5.389940423624856, 4.970884578568595, 11.012946878160749, 11.186680504253932, 1.207584212933268, 0.05425795693216579, 10.174030065536499, 48.86644445146833, 52.248810155051096, 51.42040770394461, 49.72942113876343, 48.99769939695086, 48.97843551635742, 52.26703527995518, 49.76423508780343, 52.06624971117292, 50.98756619862148, 47.53497852597918, 45.365754399980815, 38.827739238739014, 35.73431437356131, 35.30910546439034, 36.390689849853516, 40.95452029364449, 45.675001348767964, 45.83811725888933, 46.09099694660732, 46.870140143803184, 42.567353521074565, 36.41923999786377, 35.05038581575666, 35.888953481401714, 35.260155405317036, 34.10381187711443, 35.09150872911726, 36.800188882010325, 34.10861655644008, 34.23747089930943, 34.56901114327567, 34.461803913116455, 40.15229170663016, 42.69136149542672, 44.78920330320086, 45.692340578351704, 46.441099303109304, 46.46327447891235, 46.38549286978585, 46.067994935171946, 43.79732710974557, 47.58657932281494, 45.26451914651053, 45.49430302211216, 45.60407413755144, 41.815096378326416, 46.01332998275757, 48.02188049043928, 45.96504347664969, 43.331186362675254, 41.12547377177647, 45.99410431725638, 46.8239415713719, 49.050050599234446, 57.878032207489014, 47.09637348992484, 46.75438315527779, 46.506238664899556, 46.89157881055559, 47.47034985678536, 38.777052130017964, 31.734361512320383, 34.98738649913243, 33.437538691929404, 32.6995392526899, 33.246914863586426, 31.544710431780132, 32.67981679098946, 31.85572222300938, 32.42119789123535, 32.29421956198556, 33.442350319453645, 32.80361631938389, 33.3490777015686, 34.71373864582607, 37.50980493000576, 38.057833671569824, 41.236631052834646, 43.31314883913313, 42.57083804266793, 44.06860910143171, 43.31652218954903, 43.63092122759138, 42.98295307159424, 41.96744952883039, 41.58908190046038, 41.205089705330984, 40.71913616997855, 41.963110378810335, 41.64143310274397, 41.6766813141959, 43.14449521473476, 42.67880610057286, 42.9205756187439, 41.38620144980294, 39.247340951647075, 13.556626796722412, 0.0397843469732574, 2.5668758281639645, 2.6316156685352325, 3.5240401242460524, 3.4532594765935625, 2.264838069677353, 2.238905655486243, 0.06349333082990986, 0.05980417664561953, 8.52703775678362, 37.878997462136404, 21.727760451180593, 26.543233803340367, 25.644439152308873, 3.518029932464872, 0.0559072753946696, 0.025451361700626354, 0.04679338301398924, 0.053372665507985015, 0.011858650499821773, 0.06008951419166156, 0.10068739072552749, 0.037140930603657446, 0.06150246837309428, 0.028720945452472994, 0.05026088694908789, 0.04054359033969896, 0.050074089651129076, 0.03525154305888074, 0.015508016238787344, 0.014991871613476957, 0.07636737929923193, 0.07965908159634896, 0.012374085207868899, 0.04402127908542752, 0.03398680467424648, 0.02301572123542428, 0.06326189610574927, 0.05223122711426445, 0.04211766944665994, 0.024609635617317896, 0.02695121755823493, 0.022063770531011478, 0.03411947862644281, 0.06040979629116399, 0.018337900816862072, 0.03485848468595317, 0.03911421900349004, 0.02719976832824094, 0.06513494452727692, 0.01328004989773035, 0.027335943521133492, 0.06121734117290803, 0.0446828134091837, 0.019352975634059737, 0.013090481632389128, 0.006885186012368649, 0.04260257092703666, 0.017743122464578067, 0.01616904166127954, 0.050412953432117186, 0.3425749604191099, 17.909476927348546, 38.867743492126465, 26.30212262698582, 43.32117053440639, 28.307548182351248, 1.2460908038275582, 0.13115517369338445, 0.3091779553464481, 1.083219166312899, 6.460204022271292, 6.7851565054484775, 8.520845174789429, 5.65493733542306, 2.267823189496994, 0.09106526883052928, 11.837892600468226, 51.96102271761213, 53.769746507917134, 54.34456055504935, 51.607811042240684, 50.451912198747905, 49.868037700653076, 53.83873517172677, 49.95561626979283, 52.74576268877302, 51.549828324999126, 48.44269118990217, 48.95453371320452, 42.412752628326416, 37.80201836994716, 37.322307791028706, 38.53354556219918, 42.14549016952515, 46.120610169001985, 47.45681824002947, 48.292835916791645, 49.4143967628479, 43.965622901916504, 36.97970254080636, 37.76029096330915, 38.05328260149275, 36.1312267439706, 35.76455293382917, 37.01728882108416, 37.116363184792654, 35.69081865038191, 36.18344593048096, 35.73812893458775, 35.66817099707467, 41.294957705906455, 44.25704424721854, 47.25378145490374, 47.52185685294015, 48.473815645490376, 48.619651385716026, 46.64819731031145, 47.39506959915161, 44.985427379608154, 47.8937418120248, 46.68093722207205, 46.96890878677368, 46.16559975487845, 43.137467111860005, 47.701103006090435, 50.08888619286673, 46.80754382269723, 43.86019441059658, 42.72580371584211, 46.87418746948242, 47.26017032350813, 49.96792500359671, 53.25171661376953, 49.21614728655134, 47.25402116775513, 48.2672769682748, 49.52867725917271, 47.7179593358721, 40.5802138873509, 32.94362252099173, 34.8260041645595, 34.88547727039882, 35.037601130349294, 35.91874040876116, 33.447634424482075, 33.269920349121094, 33.38506589617048, 35.39893177577427, 33.66554730279105, 33.8281420980181, 33.850265162331716, 35.53345237459455, 36.330660888126914, 38.99580921445574, 38.9226724760873, 43.616767747061594, 43.11414895738874, 44.799448422023225, 44.82313483101981, 42.633674076625276, 44.16270160675049, 45.08668000357491, 43.32920265197754, 43.580821241651265, 41.79142733982631, 42.58633599962507, 43.38088682719639, 42.43390989303589, 42.80360269546509, 46.13044881820679, 44.52488688060215, 43.68454047611782, 43.67046342577253, 41.529421193259104, 15.831213406154088, 0.17154252795236452, 2.8661464665617262, 4.275209656783512, 5.4142156924520215, 10.32441166469029, 5.473673599106925, 1.3300961532763071, 0.21864636109343596, 0.015737164299935102, 9.113324148314339, 43.543665749686106, 23.5819410937173, 25.902153049196514, 33.55149262292044, 5.996217216764178, 0.038316981068679264, 0.046817538860653124, 0.012941419363154896, 0.03333155019208789, 0.05427628755569458, 0.040537147649696896, 0.09357335139065981, 0.0705595538020134, 0.043765176220663955, 0.03860773332417011, 0.05003192548507026, 0.057880258453743796, 0.036386620186801465, 0.031538792819316895, 0.04200249491259456, 0.029917616596711532, 0.026002712115379314, 0.0375762651009219, 0.0388424385871206, 0.018137515855154822, 0.11385380636368479, 0.08484032071594681, 0.17568114373300756, 0.13092168979346752, 0.0946799334404724, 0.13231253730399267, 0.12374050941850458, 0.08534794633409806, 0.1392927220357316, 0.24586773397667067, 0.13136862723955087, 0.09249716770968266, 0.15094634384981223, 0.11514239864689962, 0.18628588611526148, 0.15540358610451221, 0.09418028060879026, 0.17017571415219987, 0.21983177534171514, 0.15817342033343657, 0.07185252263609852, 0.10025248370532479, 0.0861927427883659, 0.18220368373606885, 0.16383815636592253, 0.11875741609505244, 0.36588527102555546, 19.42340428488595, 48.98107583182198, 35.48808411189488, 46.36095878056118, 35.55135440826416, 2.29086971282959, 0.4157051848513739, 0.8365777667079652, 11.261929494994027, 15.21924386705671, 12.788394008363996, 20.131564685276576, 23.299052136284963, 4.380691562380109, 0.17327125876077584, 11.926474315779549, 53.638821601867676, 55.244654519217356, 55.00408703940255, 53.10497760772705, 51.903613226754324, 52.308620248522075, 55.13707208633423, 51.068752425057546, 55.05929742540632, 54.94569090434483, 51.6065707887922, 49.8156031199864, 43.293551445007324, 39.714784485953196, 38.166704995291575, 39.293570790972026, 45.442921093532014, 48.55077736718314, 49.25204515457153, 50.290588923863, 51.58589989798409, 47.10647964477539, 40.5750617980957, 39.319105420793804, 39.91052566255842, 37.74345200402396, 37.93244995389666, 38.167003767830984, 40.52511467252459, 37.48377350398472, 39.48554604394095, 38.524769987378804, 37.68114055906023, 44.73674092973982, 45.674230098724365, 48.83889136995588, 51.154375076293945, 49.85216106687273, 50.82622902733939, 47.15861545290266, 48.37949384961809, 46.25359869003296, 49.143503870282856, 47.36484840938023, 47.844659737178254, 47.1411337852478, 44.01342303412301, 47.13646112169538, 52.988049847739084, 49.159203324999126, 45.81947871616909, 46.42125177383423, 49.07684285300118, 49.3246989931379, 52.38813543319702, 54.83323778424944, 52.66212027413504, 48.120437213352744, 49.428612777165, 51.400747776031494, 50.59924874986921, 41.9244019644601, 34.69375215257917, 36.89933967590332, 38.199135712214876, 35.57681608200073, 37.053353445870535, 34.86802339553833, 35.9501497404916, 34.893436431884766, 36.25977189200265, 36.13221338817051, 36.234817436763215, 36.27621132986886, 38.2896603175572, 38.369481222970144, 41.53994771412441, 41.696011202675955, 45.629518440791536, 44.11532531465803, 46.45752484457833, 45.85831567219326, 45.223913873944966, 45.33038112095424, 46.568039417266846, 45.75458601542881, 45.4438556262425, 44.54175363268171, 44.702753816332134, 46.01223911557879, 44.44289813722883, 45.09891925539289, 48.23624978746687, 45.67268759863717, 47.616338457380024, 44.67771945680891, 42.234284673418315, 16.450122458594187, 0.14419231483978884, 6.159347891807556, 7.14034103495734, 10.400280782154628, 15.424524920327322, 10.412870918001447, 5.015964925289154, 0.6906663562570299, 0.1855392668928419, 13.807878868920461, 48.25885575158255, 29.442383561815532, 34.946412972041536, 39.271496364048545, 5.062255127089364, 0.16366579490048544, 0.1701534582035882, 0.18923408005918774, 0.1014491616349135, 0.11556614376604557, 0.2643754008625235, 0.24475995770522527, 0.15566121228039265, 0.16342848406306335, 0.1095254382650767, 0.11271113982158047, 0.14703373451318058, 0.15398837918681757, 0.07720710031156029, 0.11245143732854299, 0.08364505413919687, 0.12453419182981763, 0.1871839000710419, 0.07054969468819243, 0.13882735557854176], [0.01570853860383587, 0.08188821162496294, 0.09845530906958239, 0.030272405594587326, 0.002285430199533169, 0.0057998421086397555, 0.028080479641045843, 0.0339034568252308, 0.0357857231449868, 0.04515180324337312, 0.02298033393786422, 0.018655324587598443, 0.05607455802549209, 0.03600153120766793, 0.06297485543681042, 0.06781224693570818, 0.017720194766297936, 0.07678570970892906, 0.03483930928632617, 0.0393906575627625, 0.01543582689815334, 0.031322143373212645, 0.07627409430486815, 0.006818045820442161, 0.06749238552791731, 0.04856181151366659, 0.057123101582484584, 1.0453726542847497, 25.442467178617203, 26.999799932752335, 21.876660346984863, 40.199202469417024, 6.932423140321459, 0.022390386754912988, 0.21820183923201902, 0.7452087381056377, 5.9764821614537915, 4.2249242407935, 9.664804407528468, 9.512082133974348, 1.8943979016372134, 0.07469687358077083, 1.5277006413255418, 29.698591436658585, 53.031319754464285, 51.77905287061419, 53.160507610866, 51.90769876752581, 51.04655640465872, 51.60399995531355, 51.19374009541103, 48.7406507900783, 48.081867762974326, 46.43304286684309, 39.966868604932515, 35.614343302590505, 35.02828707013811, 37.32397188459124, 41.53262778690883, 45.64283118929182, 47.91686541693551, 47.89250155857631, 48.781388078417095, 49.15198067256382, 44.30968379974365, 40.39022929327828, 34.71030970982143, 35.45128297805786, 34.720516613551546, 35.49570281164986, 35.30027777808053, 34.53745242527553, 35.594412394932334, 35.455900056021555, 33.95210490907942, 32.35383857999529, 36.95325074877058, 41.29059771129063, 44.18680490766253, 47.27626582554409, 47.6377979687282, 47.015371390751426, 48.66943522862026, 48.62938928604126, 46.860871246882844, 47.38340009961809, 45.015568665095735, 44.96760525022234, 43.20791489737374, 45.54235328946795, 43.06303800855364, 47.50734206608364, 47.45240265982491, 45.775614738464355, 45.17199693407331, 47.188444069453645, 43.4970120702471, 51.52374478748867, 60.30762617928641, 40.32428741455078, 47.77363525118147, 45.90002918243408, 45.91634007862636, 42.914391721997944, 35.22849593843733, 31.98888792310442, 32.652962003435405, 33.42451081957136, 34.09177412305559, 34.559509481702534, 33.09109456198556, 31.85305064065116, 32.47912849698748, 33.38398197719029, 31.15988792691912, 32.14021968841553, 33.09879316602434, 34.30041810444423, 33.80628306525094, 38.91319860730852, 41.50459180559431, 40.73068060193743, 42.52693932397025, 43.1262457711356, 43.34980058670044, 42.46367597579956, 43.63581623349871, 42.86144297463553, 45.16081728254046, 44.25145442145211, 41.95670413970947, 43.647277287074495, 43.6565705026899, 44.44002505711147, 44.35304055895124, 44.6751903125218, 43.19698190689087, 43.209728377205984, 44.48484788622175, 29.612364292144775, 3.327824515955789, 0.316107019249882, 2.3058326584952216, 1.115020854132516, 4.9886215925216675, 13.073797345161438, 6.25192699262074, 2.0987733006477356, 0.2221869703914438, 0.10673568224800484, 18.680259704589844, 35.573498317173545, 20.60839523587908, 34.58188615526472, 13.631835835320608, 0.20849907345005445, 0.04727985530293413, 0.0433608202396759, 0.06653953237192971, 0.0679381966058697, 0.04264164436608553, 0.03351711934166295, 0.029979003659848655, 0.044535964860447814, 0.020861282645325576, 0.10513562203517982, 0.019313927640074065, 0.030073621975524083, 0.03870690121714558, 0.08289006179464714, 0.031771666037717035, 0.017780991503968835, 0.00709660692206983, 0.015187751102660383, 0.02048507229691105, 0.03147190622985363, 0.015928317792713642, 0.11676730002675738, 0.058466159871646335, 0.03774831783292549, 0.03780620704804148, 0.00971508543339691, 0.05649292575461524, 0.03677312730412398, 0.04744723971400942, 0.05725655584995236, 0.011615499172226658, 0.08249168709984847, 0.0582827382854053, 0.04420908400788903, 0.04213367608774986, 0.04627438175625034, 0.026367417902552655, 0.014020978755849813, 0.029115018235253434, 0.055413515639624426, 0.07819715754262038, 0.06092152026082788, 0.028817070115889822, 0.039590615047408004, 0.01256954315717199, 0.01822553711411144, 0.03437743728448238, 2.420844669852938, 35.85159649167742, 28.969400576182775, 30.469327313559397, 45.719574042728965, 7.900777510234287, 0.046357766924692054, 0.18410145118832588, 0.735363303550652, 3.5623147104467665, 5.684736856392451, 6.28839157308851, 3.630643729652677, 4.117825576237269, 0.5497575945087841, 1.255524286202022, 34.52601221629551, 52.98399557386126, 55.75660126549857, 54.150785718645366, 53.78941338402884, 51.92726142065865, 53.1091673714774, 51.42960711887905, 51.676612104688374, 50.38992731911795, 48.97437082018171, 40.80369574683053, 38.71659585407802, 37.085940497262136, 39.27115590231759, 41.78685542515346, 47.128623553684776, 49.29675333840506, 50.55416188921247, 49.43689850398472, 49.874409198760986, 46.037148407527376, 42.32996484211513, 35.61534036908831, 37.082914556775776, 36.74441221782139, 36.3927777835301, 36.66821827207293, 36.988516330718994, 37.17042364392962, 37.89364773886544, 35.27053253991263, 34.49960906164986, 38.59057985033308, 43.33276012965611, 46.34876816613333, 47.91306127820696, 48.308681283678325, 48.12544339043753, 50.21831028802054, 48.968808787209646, 47.817881379808696, 47.73361362729754, 47.310068811689106, 48.34315824508667, 45.436174392700195, 44.582358905247276, 45.27751227787563, 49.89469793864659, 48.690328461783274, 47.74303191048758, 45.47251694543021, 49.2765896660941, 47.6826833316258, 50.7147729737418, 58.26898302350725, 43.230996813092915, 46.9481440952846, 47.51739958354405, 47.966506821768625, 44.43420941489083, 37.78135442733765, 33.074613434927805, 34.188562529427664, 35.4742294039045, 36.631292070661274, 36.54121562412807, 33.73157950810024, 34.91524682726179, 35.13569579805647, 35.321045943668906, 32.47725248336792, 33.644681862422395, 34.645896434783936, 35.60045037950788, 34.91127593176705, 39.31986624853951, 42.57772370747158, 42.71966845648629, 43.78151648385184, 45.300917284829275, 44.59255886077881, 44.20785100119454, 43.41606903076172, 43.81874145780291, 45.84101465770176, 44.64795684814453, 43.47125857216971, 45.13843018668038, 44.96869959150042, 45.40825653076172, 45.021641390664236, 45.87190634863717, 44.099292346409385, 44.552596296582905, 43.71854148592268, 32.82694837025234, 4.840188094547816, 0.8324922802192825, 2.7190995684691837, 3.304863542318344, 6.76054642030171, 9.584736841065542, 4.387721402304513, 0.2089005626205887, 0.178292377186673, 0.06485190042959792, 21.14660790988377, 46.15882526125227, 21.875036205564225, 36.34465108598982, 18.99999495915004, 0.3645335207028048, 0.06800427913133587, 0.03134907103542771, 0.07476442852722746, 0.028768537898680994, 0.06630174655999456, 0.033166411731924327, 0.024309728228087937, 0.0634618875171457, 0.0219059704270746, 0.04241879989526101, 0.03360101341136864, 0.05993678952966418, 0.018463992979377508, 0.020270414351086532, 0.02319894265383482, 0.018997352038111006, 0.016981868938143765, 0.04842275593961988, 0.0178894485413496, 0.08881670555898122, 0.08557030225970916, 0.2366925020303045, 0.21851135976612568, 0.2434360273182392, 0.07138198574206658, 0.15611679426261357, 0.11862415181738989, 0.11686677326049123, 0.11161447795374052, 0.1302854817892824, 0.13384792634419032, 0.13431086364601338, 0.20566662400960922, 0.11094725411385298, 0.10185778899384396, 0.08519993749048028, 0.14061634029660905, 0.2026646358094045, 0.17759962007403374, 0.11008724490446703, 0.24164746329188347, 0.1313104225056512, 0.12806466381464685, 0.09122700443757431, 0.19723068310746125, 0.12164798884519509, 0.1026784906695996, 2.5624661105019704, 39.58882059369768, 39.2108142716544, 31.905165604182653, 51.545840059007915, 12.486823950495038, 0.1255576397691454, 0.466144112604005, 2.753505745104381, 11.640513386045184, 11.826698184013367, 17.44629090172904, 15.910652160644531, 6.9106583424976895, 0.43423022223370417, 2.0479934769017354, 34.05513974598476, 56.10707882472447, 56.821562085832866, 56.38414519173758, 55.2601455279759, 52.270075116838726, 53.847816467285156, 55.150110380990164, 52.27691214425223, 53.14519725527082, 51.14973367963518, 42.86677919115339, 39.38504729952131, 38.70487771715437, 40.36491700581142, 45.64880664008004, 48.71655443736485, 51.96318013327462, 52.56688479014805, 51.66740574155535, 53.949732644217356, 47.26488815035139, 43.63960994992937, 37.68018170765468, 38.892791748046875, 38.711374282836914, 38.75956698826381, 39.700488567352295, 38.625897543770925, 40.344253063201904, 40.173417704445974, 37.97119658333914, 35.575798170907156, 39.82579585484096, 45.82293891906738, 47.125031335013254, 49.08726862498692, 50.95123059409005, 49.28792565209525, 52.25637674331665, 50.602465765816824, 50.143384388514924, 51.118880203792024, 49.32474415642874, 49.75315618515015, 46.86143057686942, 45.07802949632917, 45.0673952783857, 52.0884040423802, 51.194764954703196, 49.18107278006417, 48.77593374252319, 49.56898375919887, 48.617163930620464, 50.487629413604736, 60.637005533490864, 44.11624942507063, 47.693984576633994, 50.499597685677664, 49.23682859965733, 47.44428368977138, 38.586973735264365, 34.57050848007202, 36.316959040505544, 36.580431256975444, 37.69293165206909, 37.43220397404262, 36.06426695414952, 36.4146020753043, 36.462221554347444, 37.19678858348301, 33.34061132158552, 35.116939135960166, 37.21464197976248, 38.280318464551655, 35.96923296792166, 41.905964919498985, 45.04728719166347, 44.27651309967041, 46.373545442308696, 45.89006199155535, 46.75460202353341, 44.515388693128315, 45.18040425436837, 44.82131092888968, 46.20603132247925, 46.46407004765102, 44.95125961303711, 47.31747211728777, 46.95338303702218, 47.57892935616629, 45.63357966286795, 46.01611968449184, 47.339202608381, 45.93701444353376, 46.12731518064226, 33.25542293276106, 5.235020348003932, 1.0707743998084749, 5.692959180900028, 5.215103771005358, 13.758696045194354, 28.045951979500906, 19.108713422502788, 4.383648020880563, 0.4633437714406422, 0.3197141928332192, 28.69926851136344, 46.11179985318865, 29.54102713721139, 44.5975615637643, 21.29563808441162, 0.2936891178999628, 0.2067780236580542, 0.22355847965393746, 0.1656531968287059, 0.08055859511452061, 0.13481349524642738, 0.1826527789235115, 0.12444332242012024, 0.1295995507389307, 0.08269562079970326, 0.27729090782148497, 0.2078517239008631, 0.10306813940405846, 0.11779840184109551, 0.24707161794815743, 0.07936561520078353, 0.07192317170224019, 0.07731761331004755, 0.13343070873192378, 0.13113625613706453, 0.09975759418947355], [0.048688806127756834, 0.03324876891981278, 0.02801705358017768, 0.043862620634692054, 0.01801637699827552, 0.02456631454905229, 0.07843789498188666, 0.019760554656386375, 0.005478431096500052, 0.017047101598499075, 0.07364100523825202, 0.060258700113211355, 0.021267742084871446, 0.022037188921655928, 0.08869571597980601, 0.0688947681337595, 0.01425110814826829, 0.011594032868742943, 0.04573946885232415, 0.022995677310973406, 0.022451295450861965, 0.002045180881395936, 0.053167347596692185, 0.05181908155126231, 0.028927043679037263, 0.08170352117823702, 0.05305901269561478, 0.04292360280773469, 9.25131016118186, 34.61434119088309, 21.090464728219168, 33.01565102168492, 23.399358068193706, 0.4633362261312348, 0.0980498640398894, 0.06335212769252913, 3.5506571531295776, 3.947314177240644, 2.4332637063094547, 3.688550668103354, 3.261972095285143, 0.5752955355814525, 0.1368084153426545, 14.391702124050685, 42.701728207724436, 52.582837854112896, 51.73004027775356, 52.49616255078997, 48.8238068308149, 51.966077532087056, 50.83505323954991, 48.740897451128276, 47.66750151770455, 41.61354303359985, 36.87090069907052, 35.871350220271516, 38.075318813323975, 43.0369371005467, 48.51909705570766, 49.41582114355904, 48.65019219262259, 46.802311829158235, 47.468116010938374, 48.15165894372122, 45.353973729269846, 39.16791261945452, 35.05941847392491, 36.53155415398734, 34.058822291237966, 35.26650258472988, 35.426606450762065, 35.253043924059185, 34.82974229540144, 35.98258740561349, 33.43911593300955, 34.71053900037493, 32.8793169430324, 37.98160151072911, 39.59519904000418, 44.167252676827566, 45.33401155471802, 47.12453801291329, 46.27239009312221, 47.00884703227452, 47.56418180465698, 49.134085587092805, 49.27738176073347, 47.09968083245413, 44.73839112690517, 43.61096600123814, 42.30948502676827, 46.87312092099871, 47.11063119343349, 46.4185836655753, 45.67345190048218, 48.79976953778948, 47.792214734213694, 48.7992171560015, 39.76869208472115, 45.513983794621055, 47.82843916756766, 44.97506761550903, 44.92993559156145, 37.02960450308663, 32.89665617261614, 32.1905072757176, 33.77957418986729, 33.460589340754915, 33.52905341557094, 34.36669002260481, 32.96417529242379, 33.551666327885215, 33.73861108507429, 31.91249942779541, 33.79082679748535, 33.73901060649327, 33.67739398138863, 33.91579014914376, 36.13232455934797, 40.234276975904194, 41.50986548832485, 43.77742746898106, 44.39692538125174, 43.34380776541573, 43.07428019387381, 44.142666476113455, 44.47792053222656, 43.17689119066511, 43.82939304624285, 43.345534392765586, 44.42005940846035, 43.77791036878313, 43.64370591299874, 43.67461150033133, 43.419581345149446, 44.80865478515625, 42.60249056134905, 44.79986531393868, 39.56149680273873, 13.354621819087438, 0.18897682029221738, 0.9544672008071626, 1.6050708953823363, 3.739924345697675, 2.8990151371274675, 3.6677877136639188, 1.7522095314093997, 0.3420793855828898, 0.11157805419393949, 2.032582155295781, 30.26278168814523, 27.97503866468157, 22.574572154453822, 33.50112860543387, 3.752098458153861, 0.08225529228470155, 0.03276847129953759, 0.058546396637601514, 0.008007593619238054, 0.02901446952351502, 0.025898290665021965, 0.06315772740968637, 0.031825297445591004, 0.04870741495064326, 0.024318420261676823, 0.045243727775024514, 0.027519799369786466, 0.014616872450070722, 0.029231716080435684, 0.03037387372127601, 0.025572632871834294, 0.0914674840335335, 0.05478647125086614, 0.06271214703364031, 0.00764761891748224, 0.028079757001250982, 0.0881693424390895, 0.002364619689095499, 0.0247988993900695, 0.021605077465730052, 0.013947463727423122, 0.0345798951706716, 0.05876670338745628, 0.013447580193834645, 0.0271627881697246, 0.05789899280560868, 0.029570688427026783, 0.0398616117558309, 0.044713262668145556, 0.011526377838371056, 0.07019824747528348, 0.015827027781467353, 0.051797035948506424, 0.037769019936344454, 0.05410744768700429, 0.01423296072919454, 0.05993596850229161, 0.04657790743346725, 0.032009869148688655, 0.048566177886511595, 0.0485153725769903, 0.05471074674278498, 0.017696315422654152, 0.15117545798420906, 14.365388427461896, 39.34677314758301, 21.12365800993783, 45.05411032267979, 27.45010052408491, 0.5264484509825706, 0.035875323694199324, 0.2799883559346199, 1.9928975190435136, 6.75445111308779, 6.21501772744315, 6.66721647977829, 4.19858318567276, 3.7203378081321716, 0.13749224293444837, 16.430108172552927, 44.57590750285557, 54.55608456475394, 52.6915910584586, 53.383416243961875, 49.35230418613979, 52.42818137577602, 52.526550497327534, 50.97607735225132, 49.860412052699495, 43.53364644731794, 38.026097774505615, 37.86234610421317, 39.18231276103428, 42.64054584503174, 49.13158770969936, 51.149487018585205, 49.53205060958862, 48.395401750292095, 50.87802784783499, 50.65056814466204, 46.15335355486189, 41.8659849848066, 37.470554556165425, 37.856016295296804, 36.037321840013774, 37.6165257862636, 36.99165691648211, 37.00758218765259, 34.985618182591026, 36.79258407865252, 34.9435954775129, 36.32141630990164, 34.744182177952354, 41.53513956069946, 41.93757574898856, 47.280747413635254, 47.365685667310444, 47.48059150150844, 47.57034485680716, 49.21163443156651, 49.072208404541016, 50.412175451006206, 49.77729770115444, 49.031585761478965, 46.30687747682844, 43.98767648424421, 45.38406637736729, 48.20891210011074, 48.173889705113, 48.97471475601196, 48.1177065713065, 51.24337455204555, 49.48972913197109, 49.225027084350586, 44.206096581050325, 46.16840335300991, 50.21769189834595, 46.33956527709961, 47.33233431407383, 39.73812001092093, 34.37158155441284, 35.18851252964565, 35.001251629420686, 35.858641965048655, 35.395648751940044, 34.7107127053397, 34.9124710219247, 34.19227981567383, 34.965784549713135, 34.534683568137034, 35.62099272864205, 34.679973874773296, 35.029874733516145, 35.01548154013497, 37.472586904253276, 40.688616207667756, 43.271900858197895, 45.344135080065044, 45.30746248790196, 45.040926115853445, 44.57661621911185, 44.93894393103463, 45.80365071977888, 44.71932874407087, 44.74685055868966, 45.24812139783587, 45.11499391283308, 45.878114564078196, 44.55144984381539, 45.173584597451345, 44.275547300066265, 45.45979479381016, 44.48939895629883, 43.8260474886213, 41.2003093447004, 15.427849633353096, 0.9429453504937035, 1.4443851177181517, 2.7969860519681657, 3.638674761567797, 6.64647958108357, 4.551427909306117, 1.6366956212690897, 0.1919540148228407, 0.037456714015986235, 1.9465378352573939, 36.47892154966082, 34.888718605041504, 20.317901475088938, 39.822092464991975, 5.820713537079947, 0.1631000731140375, 0.04142854588904551, 0.029918393519307886, 0.026429485197045972, 0.06334266891436917, 0.0374444834222751, 0.06640282792172261, 0.01115842186845839, 0.0464322938184653, 0.046694296545216014, 0.022101195129965032, 0.052978528264377794, 0.06425694735454661, 0.0368135781692607, 0.04580880495320473, 0.04552272780399237, 0.07358666136860847, 0.07415676649127688, 0.017317190766334534, 0.01983579231559166, 0.04070210290540542, 0.2213553035897868, 0.14852788219494478, 0.0823605941342456, 0.13947849135313714, 0.1072341747848051, 0.10994575678237847, 0.12747938664896147, 0.08504004749868598, 0.07290588039904833, 0.12477572315505572, 0.15210724941321782, 0.10347374728215591, 0.1506308793489422, 0.23850641612495693, 0.11919973950300898, 0.14056565373071603, 0.10910276523126022, 0.09013007115572691, 0.11301282327622175, 0.09974936355969735, 0.2897784763148853, 0.1579671592584678, 0.191338271434818, 0.08443274508629527, 0.12096307559737138, 0.20260515542966978, 0.2270928600004741, 0.14333213599664824, 16.537080901009695, 46.684789998190745, 29.201284544808523, 41.182084219796316, 35.21197312218802, 1.329076070870672, 0.23140101454087666, 0.38992948510817116, 10.860639759472438, 14.931393895830427, 7.1275220428194315, 7.602044922964914, 10.724326525415693, 2.933351831776755, 0.26243652775883675, 17.884380034038, 44.219301632472444, 55.26293870380947, 51.352707930973594, 53.31195054735456, 50.88734885624477, 54.21073477608817, 54.1327725137983, 52.193703992026194, 51.898468085697715, 45.58317395618984, 39.991968972342356, 38.97833449499947, 41.21053014482771, 46.53620971952166, 52.27369165420532, 54.111167090279714, 52.1106139591762, 50.010263851710725, 51.66422346660069, 52.412808486393516, 49.08301632744925, 44.04127141407558, 37.88873883656093, 40.726073946271626, 37.91375929968697, 39.392183099474224, 39.73493078776768, 40.10772596086775, 37.714210510253906, 39.6071013041905, 37.17488786152431, 37.380429472242085, 35.735707487378804, 43.02840123857771, 42.63143675667899, 48.689866406576975, 48.70364815848214, 50.33137484959194, 49.539950711386545, 50.63152660642351, 50.68880408150809, 51.28625535964966, 51.30252456665039, 50.520977292742046, 49.23136384146554, 47.09590448651995, 45.17125000272478, 48.609500067574636, 50.3319411277771, 50.72185666220528, 50.87513739722115, 52.21824502944946, 49.99018703188215, 51.20116424560547, 47.32906518663679, 48.29566730771746, 51.816816329956055, 47.4254332269941, 48.84841387612479, 41.4943015234811, 35.725104536329, 36.00824710300991, 36.83155305044991, 37.61633818490164, 37.630439553942, 38.1750602040972, 36.38367564337594, 37.210556438991, 36.3065436908177, 35.032466411590576, 38.29102216448103, 36.09390449523926, 37.37532254627773, 36.43836144038609, 38.88428020477295, 43.517946992601665, 44.09664855684553, 45.8990147454398, 46.76832818984985, 45.68452385493687, 46.01989950452532, 47.27433770043509, 47.10726826531546, 46.09383181163243, 46.97191040856497, 45.239870412009104, 47.05377755846296, 47.34016145978655, 45.548679624285015, 45.56754398345947, 44.91570568084717, 47.62301567622593, 44.57390989576067, 45.93344306945801, 41.341993536267964, 16.115961006709508, 0.6770785568015916, 1.7712972100291933, 5.090811789035797, 7.862730911799839, 11.229168738637652, 10.69947976725442, 6.706337009157453, 1.032017348068101, 0.35016024910977905, 4.175962890897479, 41.82170064108712, 37.1051800591605, 30.682675225394114, 45.08707257679531, 6.909404192652021, 0.33685073043618885, 0.13518012128770351, 0.1528922330055918, 0.10014130574251924, 0.13362194704157965, 0.11108178046665021, 0.12249394559434482, 0.0719817496304001, 0.14020482237849916, 0.15325932045068058, 0.15410763850169523, 0.14871582282441004, 0.13670442306569644, 0.13864959297435625, 0.16295165036405834, 0.14057663242731774, 0.19327778236142226, 0.13041288352438382, 0.1234021782875061, 0.09500270576349326, 0.10130542756191321], [0.04575448143961174, 0.03307784255594015, 0.017532595100679567, 0.0315583176644785, 0.07086629912789379, 0.026442029613203237, 0.011563755788042076, 0.012399330103237714, 0.06073792904083218, 0.04635410962094154, 0.09373172824936253, 0.02824345018182482, 0.032440498005598783, 0.03252858202904463, 0.060022013528006415, 0.029860924995903457, 0.016160749963351657, 0.031040171360863105, 0.03335370436044676, 0.009019745646842887, 0.06132911624652999, 0.03941296100882547, 0.04177712629150067, 0.0308236983338637, 0.03350782680458256, 0.00930614594835788, 0.0750274829832571, 0.03966334382338183, 1.145299909370286, 29.57595225742885, 25.63284260886056, 26.213955198015483, 47.17969281332833, 5.453050911426544, 0.007703844873633767, 0.1718320045620203, 0.8145756444760731, 4.84111350774765, 6.568362287112644, 1.4293801571641649, 7.126463311059134, 4.803666191441672, 0.2617891782096454, 4.634445854595729, 27.292225292750768, 50.14075102124895, 52.801282269614084, 52.48963124411446, 51.58181435721261, 50.83934027808053, 48.38964169366019, 48.33175277709961, 43.24634190968105, 39.0452630179269, 36.21047442299979, 40.04469537734985, 46.47412756511143, 48.97462442943028, 48.76337834766933, 48.9799085344587, 49.214684690747944, 49.45253195081438, 48.820732252938406, 43.95498868397304, 41.93180527005877, 38.202936376844136, 36.96343680790493, 35.82229593821934, 35.54762322562081, 34.87583317075457, 34.36717987060547, 34.94389425005232, 36.219983032771516, 34.367819104875835, 34.70378187724522, 35.915314946855815, 35.30316475459507, 34.21384702410017, 38.13615724018642, 40.14156716210501, 43.80125631604876, 44.92830623899187, 45.63121380124773, 45.83398655482701, 48.21098961148943, 46.34104871749878, 46.76624025617327, 47.51370661599295, 48.58957263401577, 45.27990593229021, 40.83072076525007, 42.179970605032786, 47.2386656488691, 47.09545980181013, 46.46765531812395, 46.74626418522426, 44.08612898417881, 38.61911957604544, 37.183541842869346, 51.88185146876744, 46.01899971280779, 45.57260922023228, 38.979435784476145, 33.91872923714774, 32.320125920431956, 32.992256437029155, 34.427271366119385, 34.17888716288975, 33.257153034210205, 33.41875771113804, 35.12976898465838, 35.54291582107544, 34.88338933672224, 34.41292333602905, 32.819732666015625, 33.01017236709595, 33.07616983141218, 34.28317614964077, 36.35018880026681, 41.04893936429705, 43.342404229300364, 44.28853348323277, 43.72341564723423, 43.52329363141741, 42.396605014801025, 44.4463027545384, 44.25304903302874, 42.66250910077776, 43.091716698237825, 44.7052377973284, 43.89475475038801, 45.29627241407122, 42.69518300465175, 45.9275336265564, 41.49325234549386, 41.80843652997698, 43.91353225708008, 42.337093693869456, 24.855347871780396, 2.5751771884305135, 0.7642597215516227, 1.0962386791195189, 1.360123444880758, 3.271745605128152, 5.302493870258331, 4.261713215282985, 1.055402704647609, 0.029575034443821226, 0.035992560974721394, 6.309737741947174, 39.59252398354666, 25.175687619618007, 31.0167133467538, 20.26960802078247, 0.27263086502041134, 0.03814737106274281, 0.05790421073990209, 0.02381360886751541, 0.0222724285309336, 0.015402088440688593, 0.019004205241799355, 0.016434459115511606, 0.019039589146684324, 0.06112386618873902, 0.024380014277994633, 0.030020842129098516, 0.03815176796966365, 0.024613677989691496, 0.06908979266881943, 0.028496017879141227, 0.05571805572669421, 0.05475907200681312, 0.032190427317151, 0.016843734475384866, 0.042878755035677125, 0.025575028100450124, 0.029700566814946275, 0.013845764898828097, 0.04108402991135206, 0.02028148464991578, 0.03516417828255466, 0.053820264525711536, 0.05193511103945119, 0.02420833643658885, 0.037962999527475665, 0.0830141862056085, 0.036044967626886706, 0.01573479451638247, 0.0301865709147283, 0.0827849635056087, 0.05811213422566652, 0.0603216817336423, 0.009710265290258186, 0.057487807369657924, 0.022516568823318397, 0.054138029260294776, 0.09082533206258502, 0.058556350746325085, 0.05384024398933564, 0.018865668747041906, 0.03737495733158929, 0.013639733677596917, 0.0390091614265527, 0.018327934833775674, 1.8312759058816093, 36.60468394415719, 25.197468485151017, 26.127450125558035, 47.69598913192749, 5.897996178695133, 0.06371122199509825, 0.3565971308520862, 0.6169554686972073, 2.5017994344234467, 4.558750876358577, 3.582698553800583, 4.596364515168326, 8.901253836495535, 0.970275872520038, 4.76799761397498, 30.561050483158656, 50.93331813812256, 52.47463355745588, 52.42208085741316, 51.622211183820454, 52.26491607938494, 51.420445919036865, 49.69337388447353, 45.34778983252389, 40.990435532161165, 37.78357090268816, 40.1251346724374, 45.09033475603376, 52.22123622894287, 49.29442916597639, 49.607900619506836, 50.62596109935215, 51.29314449855259, 50.04224640982491, 45.68839052745274, 43.93569701058524, 39.903841495513916, 38.95040968486241, 38.7871652330671, 37.395100593566895, 36.96679973602295, 37.48692103794643, 36.97167042323521, 38.002387046813965, 36.09983825683594, 36.88352905000959, 37.527286597660606, 37.47824968610491, 37.4208401952471, 39.97523076193673, 42.63673823220389, 44.11008984701974, 45.625290461948936, 48.03180251802717, 47.476297514779226, 48.90297113146101, 49.50707530975342, 48.97770248140608, 48.24892677579607, 49.29353979655674, 47.664555481501985, 41.90723296574184, 44.182180881500244, 50.43720633643014, 50.18390628269741, 48.78028678894043, 47.80585057394845, 45.934818812779014, 41.147020135607036, 38.29078245162964, 52.00242703301566, 47.10483292170933, 47.02966730935233, 41.11431843893868, 35.251758507319856, 33.50129883629935, 34.315374101911274, 35.63768924985613, 35.161966936928884, 33.986567974090576, 34.511598178318565, 36.09330695016043, 36.245423861912315, 36.62712662560599, 34.656864166259766, 34.04827492577689, 35.51275021689278, 33.59855624607631, 35.14425597872053, 38.03740249361311, 42.202145780835835, 45.35090262549264, 44.813924993787495, 45.593380859919954, 44.16818720953805, 43.09163679395403, 46.12992422921317, 45.02101952689034, 45.000699520111084, 45.03525985990252, 45.020088468279155, 46.371193477085654, 45.93273435320173, 44.7282988684518, 45.71188586098807, 44.36854893820626, 42.84453105926514, 45.201168945857454, 44.119633197784424, 27.86626808983939, 3.8724894608770097, 1.5010549511228288, 2.480099775961467, 2.543198972940445, 6.113707346575601, 6.715545543602534, 2.976284750870296, 1.3180614390543528, 0.10653039826346294, 0.018862647569871376, 7.472836221967425, 44.209459509168354, 24.695320435932704, 32.51645074571882, 27.15801909991673, 0.4018622562289238, 0.080004564486444, 0.10327007142560822, 0.01759153095606182, 0.025003158786733235, 0.04246337625331112, 0.021265993160860877, 0.0074994183877216914, 0.08646438071238143, 0.04633168064590011, 0.0287866072862276, 0.020768878050148487, 0.021260899059208374, 0.02268691673608763, 0.031241994816809893, 0.06338134541043214, 0.09345037370387997, 0.027693446659083878, 0.0363630071681525, 0.023675564310646484, 0.02612540651378887, 0.019526578818580935, 0.10499482601881027, 0.09730428976139852, 0.1218383586300271, 0.0732102237109627, 0.24356969871691295, 0.19889206252992153, 0.07033883993114744, 0.06649233347603253, 0.17056363262236118, 0.1370819192379713, 0.17791907436081342, 0.11594780614333493, 0.14318207119192394, 0.18218526829566273, 0.16775255703500339, 0.14532324272607053, 0.07391744040484939, 0.15349133871495724, 0.10393327155283519, 0.15525676469717706, 0.16129640489816666, 0.16650425616119588, 0.15216325569365705, 0.10624153912067413, 0.11282216850668192, 0.07138060831597873, 0.12628450005182199, 0.16141383216849395, 2.4352732556206838, 42.82576397487095, 35.77328681945801, 31.3887129511152, 57.0521901675633, 10.081410578319005, 0.18835864774882793, 1.3347898785557066, 2.3685774973460605, 9.694028530802045, 14.099935105868749, 4.000147410801478, 14.064569643565587, 11.177476746695381, 0.3202056964593274, 5.490150383540562, 29.54112093789237, 52.78532920564924, 53.3593442099435, 53.432244709559846, 54.05833993639265, 53.46599211011614, 53.29236704962594, 51.792626176561626, 46.78368370873587, 41.75615133558001, 39.317229407174246, 43.55077028274536, 49.39093964440482, 54.0115681375776, 51.837542806352886, 51.91067607062203, 52.47226422173636, 53.99651486533028, 51.984153270721436, 48.500465461185996, 46.076756613595144, 41.904088905879426, 42.159379618508474, 40.42519957678658, 39.26929725919451, 38.58911030633109, 38.223093100956504, 39.83954981395176, 39.96806369509016, 38.18630586351667, 37.992148876190186, 40.41216128213065, 39.49617678778512, 38.06071022578648, 41.30723864691598, 44.283874716077534, 47.09844752720424, 46.145828655787874, 49.64798130307879, 49.116371154785156, 49.43282685961042, 52.45149258204869, 50.04470259802682, 51.64714479446411, 50.670408725738525, 48.442993436540874, 43.24804074423653, 44.440671239580425, 51.7586738041469, 50.61426728112357, 48.833499567849294, 49.27214281899588, 46.32943480355399, 43.86651379721505, 44.901972566332134, 54.64080395017351, 50.85656486238752, 48.79487453188215, 43.79651417051043, 37.18139484950474, 36.4818571635655, 35.87683234895979, 38.638407775333945, 37.18948950086321, 36.646098681858604, 35.6523152078901, 38.734692437308176, 38.53978851863316, 38.70960596629551, 35.857217584337505, 36.62173134940011, 37.35870245524815, 35.1322147505624, 36.865095479147776, 41.122065680367605, 43.51833609172276, 46.61930670057024, 46.80688721793038, 46.8708245413644, 45.62718037196568, 44.462846415383474, 47.217230456215994, 46.71408360345023, 45.84132732663836, 46.76472207478115, 47.43147815976824, 47.73198080062866, 49.35741458620344, 46.290879249572754, 48.08525848388672, 44.07348326274327, 45.943344252450125, 45.79246759414673, 44.99778127670288, 27.531505618776592, 3.7995320728846957, 1.9451275680746352, 5.122060009411403, 6.009054447923388, 9.48251668044499, 13.392280186925616, 13.004238060542516, 4.160820594855717, 0.4085568998541151, 0.17083107041461126, 10.932820252009801, 50.895645005362375, 31.910119669778005, 42.076157569885254, 30.3485016141619, 0.5128968581557274, 0.1572549281907933, 0.17599621468356677, 0.12616122380963393, 0.06965335671390806, 0.1445730679801532, 0.17865859610693796, 0.07914640089230877, 0.14926888314741, 0.2140960374048778, 0.16148464408304009, 0.10833072808704206, 0.11589049707565989, 0.09706640216921057, 0.15364438907376357, 0.13151266665330955, 0.1130287620638098, 0.12690972935940537, 0.10365159809589386, 0.13422247767448425, 0.24856640345283917, 0.09266626542168004], [0.0834211850804942, 0.02277254785544106, 0.048743190709501505, 0.016691981814801693, 0.0171156930071967, 0.010901658280220414, 0.01646821623268936, 0.012025360616722276, 0.07743102365306445, 0.07245929579117469, 0.043522033374756575, 0.04050785190026675, 0.03029237488018615, 0.036419698768960576, 0.015549188047381384, 0.02851705246471933, 0.06645236097808395, 0.009666403938483979, 0.015414822846651077, 0.020807749625029306, 0.029543170439345495, 0.048117856228990216, 0.027867205906659365, 0.04068409458601049, 0.059707200420754294, 0.041190037437315495, 0.02518029883503914, 0.024913612520322204, 0.02810176698091839, 14.79197655405317, 33.14615208762032, 36.746190956660676, 51.427915232522146, 19.182836805071148, 0.5758369522435325, 0.2931558707995074, 0.32898338830896784, 3.142011663743428, 4.577496681894575, 4.052142952169691, 3.5919793929372514, 11.63263760294233, 1.7747355912412917, 1.3732533689056123, 12.798051135880606, 40.35254921231951, 52.805572782244, 54.05872208731515, 52.67040947505406, 51.11994675227574, 49.671219553266255, 44.97059644971575, 40.47780786241804, 38.96546295710972, 42.53608315331595, 47.10518033163888, 51.09952252251761, 49.83672564370291, 50.42654085159302, 50.538865430014475, 48.632651465279714, 48.71893766948155, 43.429089954921174, 45.01804222379412, 42.95964533942086, 44.07575184958321, 44.48018911906651, 42.16764450073242, 38.312499046325684, 34.198460238320486, 35.39777490070888, 34.19208526611328, 36.11937311717442, 35.10299062728882, 35.355484689985005, 34.39855446134295, 36.20896666390555, 34.278458322797505, 35.39955363954817, 37.21711206436157, 41.00633301053728, 40.21919938496181, 42.4266733442034, 46.30397660391671, 46.7669802393232, 45.61601461683001, 48.20480918884277, 45.84961305345808, 49.871682030814036, 43.642826965876985, 42.16610894884382, 43.59955358505249, 40.70452063424246, 42.37416580745152, 45.23374210085188, 41.45030900410244, 44.3620662689209, 36.54066324234009, 43.01816306795393, 49.45861509868077, 45.48082004274641, 43.82953895841326, 34.167707511356895, 33.558954988207134, 31.718133994511195, 34.52928829193115, 32.832645893096924, 32.99616827283587, 33.17772470201765, 35.07578842980521, 33.72926228387015, 35.087027141026084, 33.290184770311626, 34.10594497408186, 32.710486139569966, 33.339277267456055, 34.014454569135395, 33.58822080067226, 37.11911467143467, 40.848688806806294, 44.624162742069785, 44.662888526916504, 44.36925418036324, 43.42870780399868, 42.84090757369995, 44.433639662606375, 44.50304174423218, 40.1883875983102, 39.5589085987636, 37.5786372593471, 41.29692752020699, 38.64030115944998, 39.35378040586199, 40.08584955760411, 44.09304591587612, 42.19656637736729, 41.93454286030361, 29.271718433925084, 7.032705187797546, 0.04545496251167996, 1.7949692883661814, 1.6255383342504501, 1.893699824810028, 3.2855212773595537, 3.7041333062308173, 1.0115223335368293, 0.9406648214374269, 0.09548813650118453, 0.04272839846089482, 17.077129636492046, 38.94677577699934, 18.393233094896587, 31.810958453587123, 7.846396565437317, 0.1273067266281162, 0.04539498340870653, 0.017782229830377867, 0.029597470204212835, 0.019310680850009834, 0.0627491543335574, 0.059232497321707864, 0.054355465807020664, 0.040517537987657955, 0.05347115147326674, 0.0444794428933944, 0.03735637904277869, 0.04136827501601406, 0.049059252321187935, 0.10826080505337034, 0.04252199828624725, 0.027507388964295387, 0.053484515220459015, 0.03156368826915111, 0.025613950565457344, 0.0027410365666063236, 0.019950963456981947, 0.008593325403385928, 0.022957187412040572, 0.03988618829420634, 0.02932846499606967, 0.05725986710084336, 0.04928159128342356, 0.059122554292636256, 0.0050857225931914786, 0.04804684075393847, 0.07434602347867829, 0.02058853192387947, 0.04113899124786258, 0.0348357775115541, 0.14657063436295303, 0.06669458440904107, 0.09172916784882545, 0.0819869316848261, 0.048759947131787024, 0.03134846713926111, 0.011718094515215074, 0.03411414873387132, 0.02727596102548497, 0.008176075560706002, 0.0432070438483996, 0.04083877682153668, 0.02167119731062225, 0.027679190638342073, 0.042795145950679264, 0.03409128549641796, 20.772094794682094, 36.19767584119524, 30.010541234697612, 59.348642757960725, 22.39326933452061, 0.31859919694917543, 0.06681478688759462, 0.6689216430698122, 1.592360360281808, 4.987701390470777, 4.867887956755502, 8.111252341951642, 10.099577512059893, 4.244816064834595, 1.5032611127410616, 15.702176673071724, 42.8331082207816, 53.45996454783848, 53.86329705374581, 54.57195425033569, 51.15478849411011, 51.69306196485247, 47.13989005770002, 42.38456378664289, 41.42965200969151, 44.248272146497456, 48.08259037562779, 52.34243713106428, 50.67706857408796, 51.078921113695415, 51.193708828517366, 50.8219176701137, 49.667936529432026, 46.764520577022004, 45.064285959516255, 44.43982008525303, 45.06237867900303, 45.37515878677368, 42.606815814971924, 38.00280393872942, 36.27721187046596, 36.83957821982247, 36.29882771628243, 38.7714136668614, 36.88964693886893, 37.57627139772688, 36.7134302003043, 37.70585877554757, 37.17284509113857, 38.260755811418804, 39.755636419568745, 42.7150548526219, 44.978103978293284, 45.90627908706665, 48.09929384504046, 49.33609056472778, 46.64300005776541, 47.622821126665386, 47.563695430755615, 52.253979614802766, 45.96930619648525, 43.42397608075823, 45.243601594652446, 41.966139793395996, 43.75304971422468, 46.47559016091483, 42.79390301023211, 46.189675262996126, 38.20972129276821, 43.128281593322754, 50.32665007455008, 46.15199518203735, 46.588585240500315, 37.5767890385219, 35.266749245779856, 34.44794225692749, 35.739883354731965, 34.000808307102744, 34.155867780957905, 35.21899427686419, 36.46713740485055, 35.40997246333531, 35.96376126153128, 34.22266428811209, 35.78268773215157, 35.87504666192191, 35.430327211107524, 35.48311962400164, 35.85002967289516, 38.129695415496826, 41.45023257391793, 44.00862877709525, 45.65567146028791, 44.40349490301949, 45.28170204162598, 44.3941148349217, 45.661049365997314, 45.841573987688335, 41.60275942938668, 41.99635403496878, 40.46887942722866, 42.130523749760215, 41.523622921534944, 41.64473349707467, 42.45429590770176, 45.42453268596104, 43.48035029002598, 44.29794134412493, 32.597616127559114, 9.64858991759164, 0.4573106723172324, 3.2429253458976746, 2.543650822980063, 3.528932958841324, 6.128473137106214, 6.710383466311863, 0.46707403127636227, 0.5443830000502723, 0.03868227039596864, 0.06250660520579134, 18.39225513594491, 47.57063668114798, 19.17760307448251, 36.559517179216655, 11.600052288600377, 0.24009869354111807, 0.034393888366009505, 0.026231268154723302, 0.07433899385588509, 0.03408204384946397, 0.030064410862645934, 0.06358059043330805, 0.027834386864144887, 0.0201741658550288, 0.03743290761485696, 0.02397465067250388, 0.02575123855578048, 0.03660803634141173, 0.06739262730947562, 0.03699987335130572, 0.008423968151743923, 0.028717454389802048, 0.057212729273097854, 0.10213848536035844, 0.03627578488418034, 0.004298943851608783, 0.08255084856812443, 0.16958686789231642, 0.08588348009756633, 0.11942406318017415, 0.14725856030625956, 0.09882414034966912, 0.13286714468683514, 0.13211730920842715, 0.13935739999370916, 0.10874898385788713, 0.1791946930544717, 0.10130390764347144, 0.1314062045088836, 0.08750929749969925, 0.3006124278264386, 0.11732756639165537, 0.16564645219062055, 0.11621132200317723, 0.09872499959809439, 0.1018096740756716, 0.09217390684144837, 0.15998441672750882, 0.11931909381278924, 0.0758531176085983, 0.17905731685459614, 0.1707119196653366, 0.09144440027219908, 0.05902011586087091, 0.13133514832173074, 0.1439300746257816, 22.764304876327515, 46.41856976917812, 44.29584298815046, 58.67456327165876, 29.46864775248936, 1.2782345818621772, 0.37694908306002617, 0.9756713658571243, 8.237885866846357, 9.969375218663897, 9.329314112663269, 7.243325063160487, 18.781260456357682, 6.110872915812901, 2.068510855947222, 14.951059034892491, 41.69028588703701, 54.184074538094656, 56.06817238671439, 55.128459794180735, 54.94538170950753, 53.06241294315883, 48.750124658857075, 43.462879044669016, 43.29799134390694, 47.252690587724956, 51.28809315817696, 55.11525821685791, 53.059352261679514, 52.37532990319388, 52.178477014814106, 51.63011128561837, 52.74534232275826, 48.594304357256206, 48.99747010639736, 46.40982893535069, 48.42256573268345, 47.865042277744834, 46.26522650037493, 41.842305524008616, 38.30086776188442, 40.27975640978132, 38.45096969604492, 40.994937964848106, 38.20160232271467, 39.81261164801461, 38.560973576136995, 40.158638886043, 39.43664114815848, 40.60069717679705, 41.959191594805034, 44.983259541647776, 45.50829321997506, 45.84672260284424, 50.028221470969065, 52.32356234959194, 49.56498507090977, 50.30107028143746, 49.76404053824288, 52.42916454587664, 47.756396770477295, 46.420716762542725, 44.87536791392735, 42.3471268926348, 45.93530171258109, 49.37000124795096, 45.617546694619314, 46.76034818376814, 40.91982446398054, 46.34869173594883, 52.1316739491054, 49.32913541793823, 47.80551358631679, 37.32422201974051, 36.88049963542393, 36.11085115160261, 37.20323651177542, 35.88661541257586, 35.45487172263009, 37.5080783026559, 38.71790558951241, 36.625042166028706, 38.275652749197825, 35.795552321842735, 37.04130526951381, 37.063421385628835, 37.47623470851353, 38.57279246194022, 38.24264880589077, 40.3780004637582, 42.52406276975359, 47.20790249960763, 47.72193717956543, 46.475426878247944, 46.599886485508506, 44.60282482419695, 46.53583451679775, 47.6094388961792, 43.09287704740252, 42.47565467017037, 41.531978130340576, 44.594407081604004, 42.487008026668, 43.15269408907209, 43.29923159735543, 47.891573974064414, 44.29048940113613, 44.50931944165911, 32.589479787009104, 8.693340284483773, 0.1884934048035315, 5.656604034560067, 4.9289456861359735, 4.760264703205653, 9.689738018172127, 11.824503421783447, 5.949278226920536, 2.110700752053942, 0.31542929847325596, 0.1399456491427762, 25.766565901892527, 49.930522850581575, 25.7663539818355, 45.117933000837056, 13.18866583279201, 0.3545656512890543, 0.13811692941401685, 0.17186912042754038, 0.12577295250126294, 0.07171269013945546, 0.1575805435755423, 0.14318659023514815, 0.1070987256243825, 0.0998451727043305, 0.11846435682049819, 0.12936316270913395, 0.06240533385425806, 0.13654230747904095, 0.16443338085498127, 0.2769561729260853, 0.15550057590007782, 0.26988133255924496, 0.23419940152338573, 0.17412511365754263, 0.12557686945157392, 0.08202313831342117, 0.13716513477265835], [0.04057308625695961, 0.03887248411774635, 0.03138659741463406, 0.012140080532325166, 0.055396844034216235, 0.02702945434222264, 0.059935982072991986, 0.019553180783987045, 0.030068298868302788, 0.03017972449639014, 0.04447519526417766, 0.05258981930091977, 0.0389838622483824, 0.02538197470961937, 0.011349332784967763, 0.011889526387676597, 0.004798732814379036, 0.034042994159140756, 0.029173284037304775, 0.0442967032348471, 0.074249881851886, 0.036153414486242194, 0.02962231815659574, 0.011742732121742197, 0.04982317418658307, 0.016677878464439085, 0.10629088218723025, 0.03683624463155866, 0.10157095188541071, 1.7718229932444436, 29.91392305919102, 28.886783020836965, 30.08708953857422, 36.86759335654122, 4.303851868425097, 0.15019398422113486, 0.07818880477654082, 1.1639353036880493, 1.5464555663721902, 2.619334727525711, 3.1848922542163303, 7.7244739191872736, 5.354684395449502, 0.5300477264182908, 3.4250786687646593, 23.28900851522173, 42.31562376022339, 54.398478576115195, 52.24722943987165, 52.469620432172505, 46.92345714569092, 43.60617869240897, 40.69075972693307, 44.85340813228062, 50.18678978511265, 51.43808044706072, 50.6814146723066, 52.94416502543858, 51.86226102284023, 48.71461588995797, 45.78519977842058, 43.566570486341206, 43.72388117653983, 44.93418788909912, 47.573992661067415, 48.351770537240164, 47.20741612570626, 47.55246366773333, 41.279609135219026, 34.63354253768921, 35.39817442212786, 34.7866530418396, 36.64191239220755, 37.329912594386506, 35.455736773354666, 34.62137624195644, 34.74431766782488, 35.881331307547434, 35.93700722285679, 35.94791242054531, 37.10317202976772, 40.79365907396589, 39.695729051317485, 43.15296854291643, 41.421605995723176, 38.865308148520334, 42.77505602155413, 45.27626160212925, 47.70968403135027, 46.556025981903076, 40.75850466319493, 43.661211899348665, 45.94452544621059, 45.2777658871242, 45.36882550375802, 45.80160100119454, 46.8899564061846, 46.18246303285871, 48.01855230331421, 46.740743841443745, 43.529755456107004, 37.978968143463135, 32.44896984100342, 33.61369637080601, 33.36303315843855, 33.228863443647114, 31.695305688040598, 33.226386410849436, 32.217796325683594, 33.253300258091514, 37.8476437159947, 40.5001289503915, 39.89960309437343, 36.2153103692191, 33.45617723464966, 33.02571201324463, 33.60787378038679, 33.69062335150582, 35.43502071925572, 40.857829162052695, 44.17413486753191, 44.45499495097569, 43.79296016693115, 43.30001674379621, 45.735429831913535, 44.4951868057251, 42.69626692363194, 38.69075550351824, 38.58738715308053, 40.79800864628383, 39.39184263774327, 39.38092354365757, 40.329383918217246, 41.440136841365266, 43.18652834211077, 40.42158303941999, 33.62950004850115, 10.656051789011274, 0.3260090436254229, 0.42635766895753996, 1.8482058431421007, 0.7964330294302532, 1.9203207620552607, 7.313508817127772, 5.969683349132538, 0.44949951288955553, 0.4624142327478954, 0.025445858781625117, 0.6339920173798288, 32.323992592947825, 25.06821288381304, 21.84660243988037, 29.526550565447124, 0.7329134664365223, 0.03264174809945481, 0.06347969906138522, 0.02274430892430246, 0.04919973621144891, 0.08185034937092237, 0.039476515991347175, 0.018160292579393302, 0.07363248962376799, 0.04382515871631248, 0.0441792284670685, 0.014172327688096889, 0.03765722789934703, 0.07125126597072397, 0.026106029249993817, 0.05869817813592298, 0.07413744859929595, 0.038265571862991364, 0.02471481533055859, 0.03191137300538165, 0.03901667959455933, 0.04328333154054625, 0.05766340544713395, 0.07572704580213342, 0.01877732857662652, 0.05898809579334088, 0.03771191782185009, 0.016544317327705876, 0.010737619046787066, 0.023006601724773645, 0.018490101310557554, 0.03816892812028527, 0.03857359622738191, 0.07068835331925324, 0.04746714114610638, 0.0824738551995584, 0.06409114053738968, 0.05183483713439532, 0.029055256263485978, 0.024590850375326614, 0.025080442229019742, 0.03592133176113878, 0.06683468831969158, 0.058949507506830354, 0.040788836644164154, 0.050735827535390854, 0.02265086617054684, 0.02245089172252587, 0.032857077794947794, 0.03769808927817004, 0.015011613589844533, 0.20256464688905648, 3.841761486870902, 37.13174302237374, 32.63923931121826, 41.348931312561035, 44.23230866023472, 3.7139263578823636, 0.10170460971338408, 0.2533913574048451, 0.9781310281583241, 2.8144470921584537, 6.277754315308162, 6.814606010913849, 12.472909314291817, 5.476930132934025, 1.1488234060151237, 5.14272221497127, 25.477583374295914, 45.51824998855591, 54.93644632611956, 54.07801028660366, 53.310338565281455, 49.013666357312886, 45.45008121218, 42.879216466631206, 44.19654975618635, 51.120349747794016, 52.429161071777344, 51.98354182924543, 52.95360762732369, 52.70985092435564, 48.7964517729623, 48.87597737993513, 45.996484075273784, 45.051080908094136, 45.32066059112549, 48.166514192308696, 50.80876473018101, 49.015396458762034, 48.33749546323504, 42.80727481842041, 36.436273506709504, 37.258891582489014, 35.877283981868196, 37.56124244417463, 38.166156087602886, 36.79524523871285, 37.53103167670113, 36.22269977842058, 37.976001262664795, 36.72209807804653, 37.094240120479036, 38.74509041649954, 41.73673112051827, 43.35131181989397, 45.47893360682896, 43.44338239942278, 42.025150844029014, 45.33161442620413, 46.895525387355256, 50.3387017250061, 47.24789980479649, 42.21005630493164, 42.621024881090435, 46.67228671482631, 46.15378086907523, 47.53840051378523, 47.29698187964303, 47.12541001183646, 47.243300097329275, 48.74295064381191, 47.80001408713204, 45.690624373299734, 40.60678379876273, 34.3829904964992, 34.64296776907784, 34.497375215802876, 34.2663962500436, 32.12092106682913, 34.92132650102888, 34.51258134841919, 35.65950311933245, 38.47540998458862, 40.59291172027588, 39.41428184509277, 36.76795618874686, 35.51028708049229, 35.85631084442139, 34.22132328578404, 35.33876732417515, 35.80546045303345, 42.51381070273263, 46.16014889308384, 45.705253805433, 43.05641290119716, 42.69762182235718, 46.49010147367205, 45.513486998421804, 43.53080463409424, 41.92366198131016, 41.01791565758841, 41.413563455854145, 39.99273327418736, 39.62456212724958, 40.898236410958425, 41.91158601215908, 44.810193811144146, 41.87954439435686, 37.62502690723964, 13.537292565618243, 1.0038049476487296, 1.8515071059976305, 4.213832744530269, 4.037782762731824, 6.005637237003871, 5.444666172776904, 3.141100364071982, 0.8198601294841085, 0.3054168628794806, 0.02122552363601114, 0.5078689136675426, 37.1830415725708, 31.954640252249582, 21.951808588845388, 36.62369074140276, 1.9152511826583316, 0.15633328764566354, 0.02091086489547576, 0.03080058064577835, 0.025451066537893245, 0.04872137920132705, 0.13470064130212578, 0.03504087829164096, 0.05295281857252121, 0.036977797214473994, 0.01850966686782028, 0.03914668011878218, 0.03842492241944585, 0.04587139641599996, 0.011828308958294136, 0.06897737298692976, 0.030169370052005564, 0.03906013976250376, 0.022393211156928113, 0.01053279307338276, 0.01756464739862297, 0.040957537413175614, 0.028248050649251257, 0.15590327286294528, 0.11188966461590358, 0.19767874692167553, 0.1900854922298874, 0.08063020091503859, 0.09735811794442789, 0.12912605543221745, 0.05838597060314246, 0.12643031722732953, 0.1294303648173809, 0.1310906314424106, 0.10859620491308825, 0.12077609848763261, 0.23737152559416635, 0.12918318808078766, 0.11891048002455916, 0.09242974847022976, 0.16781894490122795, 0.12984239842210496, 0.2730101932372366, 0.22780331330639975, 0.08920504472085408, 0.14252045883664063, 0.12516502583665506, 0.18316286083843025, 0.10585396670337234, 0.22592246851750783, 0.10266943901245083, 0.2059787501181875, 4.693335311753409, 45.23041391372681, 38.77414778300694, 40.31454951422555, 48.74482665743147, 7.333361557551792, 0.21014169816459927, 1.3853181557995933, 4.233629030840738, 12.653709258352007, 7.996957080704825, 6.071806234972818, 12.979778664452688, 9.808862277439662, 1.4626689766134535, 4.491893138204302, 26.312338215964182, 46.21937881197248, 57.512574332101, 56.309108121054514, 55.08283792223249, 50.54782165799822, 45.7938676561628, 44.46611901691982, 47.27224281855992, 54.273376260484966, 55.13360493523734, 54.16013451984951, 55.65002979551043, 56.09880699430193, 50.93145602090018, 49.953257356371196, 48.12218468529837, 46.71678645270211, 47.493800027029856, 51.58674757821219, 52.43288878032139, 51.351457255227224, 50.11606754575457, 45.136762619018555, 37.93199832098824, 39.7597462790353, 39.39207192829677, 40.90549380438668, 40.67015136991228, 39.854550974709646, 39.44983925138201, 37.51318870271955, 39.595091342926025, 38.74431916645595, 39.39695998600551, 41.187819957733154, 43.89023494720459, 43.97739315032959, 47.45187112263271, 44.90305648531233, 42.62721572603498, 47.76556839261736, 47.9095003264291, 50.92886781692505, 48.78448697498867, 45.22367763519287, 43.41864333833967, 47.185570989336284, 50.11126981462751, 49.155593735831125, 48.92624759674072, 50.2075058392116, 49.676305634634836, 50.816914967128206, 49.81228188105992, 47.16735281263079, 41.59947987965175, 35.66613517488752, 36.86877107620239, 35.37967136928013, 35.43169948032924, 34.06243882860456, 35.831088883536204, 35.35058273587908, 37.35148327691214, 41.85131386348179, 43.59048618589129, 43.77072940553938, 38.839558124542236, 36.31432219914028, 37.27298600333077, 35.89717320033482, 36.35690770830427, 37.82712915965489, 45.13072810854231, 47.18264579772949, 46.39811774662563, 43.508024965013774, 43.30396332059588, 47.276870318821494, 46.56888362339565, 45.65478556496756, 43.502306597573416, 42.6969895362854, 44.802929469517295, 42.42699990953718, 42.21287727355957, 42.968914236341206, 43.527886390686035, 46.067727429526194, 43.86999831880842, 36.86165264674595, 12.907751032284327, 0.8040629657251495, 2.9973069599696567, 8.137684157916478, 5.569125780037471, 7.019468869481768, 15.11414020402091, 13.411042928695679, 1.9744513545717512, 1.1235188267060687, 0.14988113886543683, 1.615412311894553, 42.025960309164866, 33.48095103672573, 30.519048622676305, 42.74763148171561, 2.3989128981317793, 0.24623788840004376, 0.13407951034605503, 0.10291241561727864, 0.09957418617393289, 0.14812878146767616, 0.3086836832974638, 0.09987548286361353, 0.1983763894864491, 0.12831260051046098, 0.13229188269802503, 0.10867341541286026, 0.21926195520375455, 0.16011343337595463, 0.1678466834127903, 0.22230616185281957, 0.21409360824951104, 0.05714651782597814, 0.13358644608940395, 0.0771990596715893, 0.16395620788846696, 0.12261442627225604, 0.10780882609209844], [0.028184801007487943, 0.04058567986690572, 0.03435266397095152, 0.02288381233146148, 0.06034256025616612, 0.0401978733550225, 0.02989575419841068, 0.042781422579927106, 0.006124899398335921, 0.059513363321977, 0.039761137682944536, 0.07686926451112543, 0.04672347694369299, 0.013779555148045932, 0.04640833135428173, 0.06091065691517932, 0.07921117384518896, 0.04225493708093252, 0.03743034275248647, 0.03173961882878627, 0.02967154247952359, 0.050318277440965176, 0.10096498618700675, 0.0017448264012013429, 0.06325646782560007, 0.03561193336333547, 0.021744984601225172, 0.04657638072967529, 0.10781685316136905, 0.11551886344594614, 16.217239686420985, 36.06850535529, 24.55842876434326, 42.49763877051217, 20.691584280558995, 0.1062101297346609, 0.26299754051225527, 0.6738485129816192, 0.876595753644194, 5.058703729084559, 8.958466172218323, 9.57960820198059, 1.7210351356438227, 1.1109969786235263, 0.19306427453245434, 4.173287834439959, 30.446554592677526, 52.05624083110264, 53.460096563611714, 52.06058692932129, 52.40703453336443, 46.55527557645525, 47.672118595668245, 50.03782735552107, 50.38486555644444, 51.27373817988804, 52.058943680354524, 49.051919664655415, 49.359492097582134, 47.06671857833862, 43.9691595349993, 40.477787017822266, 45.34962068285261, 46.96761989593506, 51.10056127820696, 48.524158818381174, 50.09301342282976, 47.90876381737845, 46.65677833557129, 35.254982471466064, 34.90373018809727, 35.87409823281424, 35.56260354178292, 35.652509757450645, 36.440049852643696, 35.04663378851754, 35.09180402755737, 35.33539397375924, 36.00608273914882, 37.08110455104283, 35.24218388966152, 35.02589341572353, 36.52898679460798, 37.82948807307652, 39.59737730026245, 40.738917691367014, 45.02819354193551, 45.46503373554775, 49.67028154645647, 45.18144301005772, 44.20237929480416, 46.446279185158865, 43.74053600856236, 49.037085260663716, 47.224470479147776, 49.201622077396934, 46.27852535247803, 47.394437313079834, 47.1369822365897, 46.073251247406006, 42.216525077819824, 36.49510390417916, 33.879016808101106, 35.05030243737357, 32.25525753838675, 34.786177090236116, 32.874057156699045, 34.66952725819179, 34.39446892057146, 37.55284207207816, 46.07178865160261, 46.13839408329555, 45.1301930972508, 42.0322345324925, 37.82974515642439, 33.88761172975813, 34.818857942308696, 34.08028180258614, 36.742727279663086, 40.98484918049404, 43.97928653444563, 45.27318355015346, 43.84304278237479, 43.798150471278596, 43.821954999651226, 44.281112807137625, 41.22257832118443, 39.13457863671439, 42.46733767645699, 42.02057892935616, 45.09035907472883, 41.43692329951695, 42.79949631009783, 42.9071239062718, 42.57145643234253, 32.631558077675955, 13.881887606212072, 0.6152971833944321, 0.15504933654197625, 2.186952671834401, 2.080875392471041, 3.74782748733248, 6.974062825952258, 2.1744003168174197, 1.0465276837348938, 0.219096161957298, 0.1061715210920998, 0.02843013552150556, 4.242119295256479, 40.208627700805664, 22.154319047927856, 28.616883720670426, 15.597627128873553, 0.06205417841140713, 0.026911467280504957, 0.01496673358737358, 0.017558798426762223, 0.0454259721030082, 0.05881317625088351, 0.04191184263410313, 0.0324882838342871, 0.025800393328868916, 0.046573371426867585, 0.02652776929815965, 0.024497636627139788, 0.019943328241684606, 0.03262928341116224, 0.0857601970700281, 0.07956230893198933, 0.053585664435688934, 0.054853347662304125, 0.0632501778059772, 0.02500100274171148, 0.01828523462505213, 0.04215097873072539, 0.061217259748705795, 0.012621653798435415, 0.03570447536185384, 0.03434054872819355, 0.04004111819501434, 0.03172345951731716, 0.027579978640590395, 0.040816466590123515, 0.05067507829517126, 0.00917391134758613, 0.04026652413553425, 0.021026565294180597, 0.10087242722511292, 0.023983944905921817, 0.03948964225128293, 0.048579582345805, 0.013659636806031423, 0.03504294443077274, 0.03224200276391847, 0.055986653813826184, 0.016428907002721514, 0.025929757726511786, 0.05735986280654158, 0.0364209404880447, 0.017648434599063227, 0.05797203031501599, 0.022670993215537498, 0.010885680476868791, 0.022383611582751786, 0.06597526943577187, 0.05745921390397208, 22.45707811628069, 38.96419143676758, 26.437278985977173, 52.60485322134835, 19.590741225651332, 0.056073553793664486, 0.2494335440652711, 0.4612431355885097, 0.32484937299575123, 3.2472816492830003, 10.154574240956988, 12.04732780797141, 4.613832286425999, 2.9836511441639493, 1.1124330844197954, 5.459220911775317, 32.18734237125942, 53.590517725263325, 55.70795692716326, 53.41017375673567, 51.782995973314556, 47.52406638009207, 48.47052219935826, 51.25122949055263, 51.572097301483154, 52.385394368852886, 53.04070677076067, 49.02408518110003, 52.53352648871285, 48.53308030537197, 44.19678252083914, 41.7695300919669, 46.35511881964547, 49.718769550323486, 52.13865341459002, 50.96311201368059, 51.551405566079275, 49.42329740524292, 47.645079680851524, 36.90317508152553, 36.77270875658308, 38.094732080187114, 36.74982486452375, 37.85970231464931, 37.89483935492379, 36.72816038131714, 35.932157380240305, 36.315218516758506, 37.3851820400783, 37.67391790662493, 36.78655999047415, 37.74278497695923, 39.84526123319353, 39.673956871032715, 40.82180275235857, 41.86974743434361, 44.433837686266216, 47.92613083975655, 51.11781712940761, 47.19380807876587, 45.490658691951204, 46.33876970836094, 44.80038642883301, 48.52980422973633, 48.78143671580723, 49.642370632716585, 48.595572403499055, 49.920979499816895, 48.37409509931292, 47.32848501205444, 43.812102454049246, 39.07859352656773, 35.37507166181292, 36.228918416159495, 33.81350919178554, 36.54960904802595, 34.42351933888027, 35.54524694170271, 36.37334714617048, 37.99827718734741, 45.83858626229422, 47.07814489092146, 45.47587987354824, 44.68318421500069, 38.545635427747456, 35.432095527648926, 36.429078647068565, 34.96439838409424, 38.745375292641775, 41.796287604740684, 44.7063946723938, 46.75980622427804, 43.99101161956787, 44.25221177509853, 45.92810685294015, 45.42253507886614, 42.14768580027989, 39.786437783922466, 42.59792906897408, 44.69598279680525, 45.25162328992571, 42.30665710994175, 45.59487124851772, 44.814790044512065, 44.94479431424822, 35.273204122270855, 17.216053656169347, 1.5661384016275406, 1.5916431759084975, 2.6780543880803243, 3.472567000559398, 5.468878907816751, 5.014134509222848, 5.416013104575021, 1.2422335765191486, 0.11027164358113493, 0.017886702170861617, 0.041306789565299235, 5.16644857610975, 45.892632825034006, 23.423478739602224, 30.152367864336284, 21.571712596075876, 0.07383434022111551, 0.04151092004030943, 0.016394774994945953, 0.010625798172051353, 0.019556839784075106, 0.027670902333089283, 0.008337616088933178, 0.05353589728474617, 0.037896099367312024, 0.031399872952273915, 0.027044463536835144, 0.02149991980487747, 0.029591105545737913, 0.035030975073043785, 0.045418453935001574, 0.030231428864811147, 0.020799524084265743, 0.016827398744810904, 0.06999499231044735, 0.014434234571776219, 0.012741658653664802, 0.05551657493093184, 0.09172290497060333, 0.12184536111141954, 0.11733589880168438, 0.08632681452270065, 0.09720195310988597, 0.1448380494756358, 0.08079957004104342, 0.115802884634052, 0.1480001447988408, 0.13338865313146794, 0.1698774980115039, 0.1262164701308523, 0.23831151372620038, 0.12655185641986982, 0.15884291726563657, 0.1388969732714551, 0.0886764998680779, 0.10387741455010005, 0.07680498010345868, 0.1674532416675772, 0.0708598123331155, 0.09950785259050982, 0.1843523598675217, 0.10086537724626915, 0.08772159753633396, 0.1271794606000185, 0.09161889233759471, 0.19095660905752862, 0.1321589034050703, 0.1751218137464353, 0.22920315819127218, 28.401565994535172, 48.56718553815569, 32.75469752720424, 54.30018935884748, 29.470641885484966, 0.16032221860119275, 0.8667681781308991, 2.324247338942119, 3.93641288791384, 12.888720784868513, 15.589895520891462, 18.573964425495692, 7.2071948647499084, 4.903503554207938, 1.0961520437683379, 4.483284754412515, 32.55111183438982, 55.483387674604145, 55.69479009083339, 55.42140974317278, 56.34928607940674, 49.87060853413173, 53.821284770965576, 53.87814882823399, 53.460277216775076, 53.93879270553589, 55.048472132001606, 51.046327114105225, 54.834655216761995, 50.78938620431082, 46.706871373312815, 43.92584446498326, 50.11357314246041, 53.581161975860596, 55.778338704790386, 54.86810384477888, 53.23920290810721, 53.048447063991, 49.506668840135845, 39.47655160086495, 38.82261494227818, 40.153472900390625, 39.88623823438372, 39.73234258379255, 40.289636748177664, 39.342500005449565, 37.25251661028181, 37.273986543927876, 39.44603511265346, 40.23230716160366, 37.69010026114327, 38.85783188683646, 41.152773244040354, 41.217353275844026, 41.696250915527344, 44.413076468876426, 46.287474632263184, 51.44220767702375, 52.01904017584664, 50.912254674094065, 48.754727840423584, 46.760560103825156, 45.62740618841988, 50.873494148254395, 48.77827875954764, 53.09389523097447, 50.48991884504046, 51.466842515128, 51.37534168788365, 50.779596192496165, 45.8842567716326, 40.51701307296753, 36.38386671883719, 37.66070243290493, 35.38027238845825, 39.58348090308053, 35.76661307471139, 38.360632692064556, 38.91300753184727, 40.864416054316926, 49.0890543120248, 48.23657635280064, 47.69539506094796, 46.75090905598232, 40.56918709618704, 37.73744528634207, 38.72281796591622, 36.5078330039978, 40.62383815220424, 42.982435430799214, 46.01888159343174, 47.102512223379954, 45.512819971357075, 45.76641532352993, 45.79731048856463, 47.409316880362375, 43.92429501669747, 41.64498710632324, 44.625500270298545, 46.73638732092721, 48.8953663281032, 44.02612086704799, 45.94834348133632, 44.430030073438374, 45.37078142166138, 34.447483675820486, 15.943409442901611, 1.2662504592112132, 0.8279207455260413, 5.166900643280574, 8.207019363130842, 8.210187741688319, 12.49370961529868, 9.052918246814183, 7.074651462691171, 0.8208627871104649, 0.29600759063448223, 0.12642286691282476, 7.5351077147892545, 51.81568029948643, 29.539425577436173, 38.88823025567191, 25.231174196515763, 0.23544258624315262, 0.19642283288495882, 0.09418350365012884, 0.11515022894101483, 0.10190733562090568, 0.2382891492119857, 0.15747835620173387, 0.1175055732684476, 0.19642676838806697, 0.11312441514538867, 0.13638537589992794, 0.10784100900803294, 0.1587792435394866, 0.1194328705647162, 0.15708965063095093, 0.10379292336957795, 0.0938949566334486, 0.11709359394652502, 0.1486372756106513, 0.17351083590516023, 0.1285376027226448, 0.14684458609138215, 0.19683165023369448], [0.027293474014316286, 0.07950689297701631, 0.007623338390008679, 0.04194244795611926, 0.023450914936672364, 0.03960568531017218, 0.037997479284448285, 0.06967104612184422, 0.09289642450000558, 0.01234080221703542, 0.04192336755139487, 0.014437525466616665, 0.0405529609083065, 0.025537961428718906, 0.03604052322251456, 0.02233390719629824, 0.007029015928440328, 0.09489285094397408, 0.08180019884769406, 0.04537239158526063, 0.02029125894685941, 0.030443328565784862, 0.01440259618019419, 0.02981872690309371, 0.022338663726778965, 0.05427292202200208, 0.0705958961376122, 0.007539936258191509, 0.06950408579515559, 0.14594726424132073, 1.819100707769394, 33.652776513780864, 28.976027420588903, 29.971005984715053, 40.36949239458357, 3.4233268541949133, 0.15140660772366182, 0.061602260518286905, 0.36968270582812174, 2.4848983756133487, 8.959530983652387, 18.693192039217266, 6.464346885681152, 1.4434109585625785, 1.0420121146099908, 0.1614889052829572, 10.9301677771977, 39.51977287020002, 54.44247109549386, 53.64420645577567, 50.97767891202654, 51.23468582970755, 48.91553347451346, 49.63826772144863, 51.91106169564383, 53.36943646839687, 48.521268367767334, 50.797630241939, 48.199302741459434, 43.68547848292759, 39.49287639345442, 45.5448511668614, 49.01516369410923, 48.569478443690706, 49.62899535042899, 50.57884189060756, 49.12282950537545, 50.44090625217983, 43.98822886603219, 35.474146025521414, 36.82353482927595, 37.10669824055263, 35.66034732546125, 37.41852644511631, 36.5517213003976, 37.18507392065865, 35.272297382354736, 38.1553863797869, 36.2023936680385, 35.98338644845145, 36.317233494349885, 37.53139645712716, 35.54462160382952, 39.504167216164724, 40.761874539511545, 45.31177037102835, 45.60475853511265, 49.40237290518624, 47.66899190630232, 45.15864249638149, 37.551890168871196, 38.05318880081177, 47.907301221575054, 47.21400996616909, 47.74084322793143, 48.31470537185669, 46.596363748822895, 46.31639303479876, 45.564306122916086, 44.567104135240825, 38.59405394962856, 33.66764913286482, 34.69789675303868, 33.76381567546299, 34.25114148003714, 33.07524919509888, 33.9924704687936, 34.08357524871826, 34.03794295447213, 43.06917674200875, 47.817238671439036, 46.6876665524074, 47.260330132075715, 44.96661860602242, 38.05253219604492, 34.36405665533883, 33.02396106719971, 34.82171712602888, 34.031939710889546, 39.62593787057059, 43.240772928510395, 44.32396582194737, 45.4768317767552, 42.504753725869314, 44.441529342106406, 44.25683580126081, 41.66359438214983, 41.65702486038208, 43.53528274808611, 42.825218541281565, 40.78118010929653, 45.00136307307652, 45.153295857565745, 43.66063172476632, 35.44967099598476, 15.144185951777867, 2.230328538588115, 0.4364190404968602, 2.253522276878357, 1.7911832800933292, 1.939991980791092, 4.067039021423884, 33.020896911621094, 7.323393498148237, 2.106633016041347, 0.40740322747400826, 0.14558209026498453, 0.05648214722584401, 16.759319032941544, 38.54709454945156, 17.5530777658735, 36.54400185176304, 5.872476748057774, 0.045828377295817645, 0.027543490419962575, 0.023873041749798825, 0.03329372525747333, 0.08393845946661063, 0.023669572846431817, 0.03752568710063185, 0.02196326931672437, 0.054798572922923734, 0.05126458273402282, 0.04961435503459402, 0.08136399582560573, 0.08401482179760933, 0.06494781813983407, 0.07062199937977962, 0.05207275865333421, 0.02030852427040892, 0.03369816266266363, 0.06007457285055092, 0.04261811616431389, 0.10511240935219185, 0.019887031887524893, 0.034842369479260275, 0.04961930155487997, 0.1002736132858055, 0.04426391303007092, 0.01609807538001665, 0.05440171475389174, 0.04269775242677756, 0.02823143163030701, 0.06525231072945253, 0.03312820681769933, 0.050672652532479594, 0.046500656221594126, 0.016810450636382614, 0.05848504350121532, 0.021611813622127687, 0.019937947458986725, 0.011602774944289454, 0.09208547337246792, 0.05145443004689046, 0.01934845998351063, 0.06586564531815903, 0.023827491693996956, 0.060971290804445744, 0.04190806319404926, 0.04775644472933241, 0.029545128012874296, 0.06639337592891284, 0.023170099826529622, 0.03116028562986425, 0.022548750042915344, 0.13440223517162458, 3.7055555156299045, 42.78996338163103, 29.21528516496931, 37.13802766799927, 47.28902619225638, 1.926397395985467, 0.05859012143420322, 0.15413773831512245, 0.18070091865956783, 0.4784419355647904, 7.901140553610666, 10.700606243950979, 1.9637965091637202, 5.171152940818241, 2.310413041285106, 0.4630698061415127, 13.396805201257978, 41.502055713108604, 55.421670300619944, 55.08356400898525, 52.54800306047712, 52.71295329502651, 49.9488730430603, 50.36029325212751, 53.20368024281093, 52.63470268249512, 51.50856644766671, 52.005967140197754, 50.74369832447597, 45.26793418611799, 41.906482560294016, 47.31023209435599, 49.61637394768851, 51.06125184467861, 50.51956333432879, 51.64704057148525, 50.31160722460066, 51.8799580846514, 46.442996161324636, 37.9354133605957, 39.237429346357075, 37.66484008516584, 37.63519212177822, 39.30570234571184, 38.55960825511387, 38.35175289426531, 37.265402044568745, 39.124253613608225, 37.42134741374424, 36.54712854112898, 38.04236698150635, 38.30332395008632, 37.02093315124512, 41.23370238712856, 42.75769247327532, 46.55890253611973, 47.43328469140189, 50.241836888449534, 50.083511761256624, 46.297705854688374, 39.94116027014596, 40.596371923174175, 48.22066150392805, 48.003884656088694, 49.27127776827131, 50.11816242762974, 47.632142135075156, 49.038422788892476, 47.36997965403965, 46.44580670765468, 41.249474797930034, 36.34877136775425, 35.44174657549177, 35.18549701145717, 35.5423321723938, 34.00536979947771, 35.36876269749233, 34.78170245034354, 35.25942931856428, 44.13162578855242, 50.01460994992937, 47.96602044786726, 47.45884016581944, 45.15755162920271, 40.62741300037929, 36.91734593255179, 34.50670664651053, 35.37089579445975, 35.916763646262034, 41.46377113887242, 44.940510749816895, 45.922068868364605, 45.60962227412632, 43.73892750058855, 44.88926083700997, 44.9057628086635, 42.285881996154785, 43.13390268598284, 44.54105533872332, 44.97388989584786, 41.91207586015974, 46.58426693507603, 43.464789799281526, 45.20756128856114, 37.082681792122976, 18.515120131628855, 2.191598193986075, 0.7956333351986749, 4.8134110399654935, 3.016636631318501, 6.1028512205396375, 5.69394017968859, 26.068214995520457, 11.152438913072858, 0.5535647187914167, 0.0928567573428154, 0.049099268923912726, 0.030311417965484515, 16.925050939832413, 44.72555085590908, 19.218500171388897, 39.703233105795725, 9.16576828275408, 0.11862514247851712, 0.05026608452733074, 0.022938230839957083, 0.04989503104505794, 0.0550699394329318, 0.08988621245537486, 0.015656420329053487, 0.037633764158402166, 0.04226744926667639, 0.0297844439212765, 0.03230200222294245, 0.03243538185155817, 0.03779231743620975, 0.055793983795280964, 0.05115477201927986, 0.019013974449730346, 0.058234596225832186, 0.07155574498964207, 0.031431299301662614, 0.03373741252081735, 0.04674279144299882, 0.005943925627174654, 0.08221350131290299, 0.17223544791340828, 0.203142324462533, 0.09472407892878566, 0.09388083631971053, 0.12007020493703228, 0.1817756231342043, 0.13944113121501037, 0.15002872023199285, 0.12473001703619957, 0.10369453579187393, 0.12739368767610618, 0.10216682776808739, 0.16542309203318187, 0.08565418954406466, 0.0809888948819467, 0.18258983801518167, 0.2298041230865887, 0.15887936816683837, 0.12455667848033564, 0.1799190156161785, 0.1140147005873067, 0.15566642342933587, 0.1136351145271744, 0.15738595330289432, 0.16575314503695282, 0.17876652388700418, 0.16190475225448608, 0.10467212154929127, 0.1727755210761513, 0.24771310495478766, 5.3955471856253485, 50.961757114955354, 38.81576401846749, 38.204725537981304, 52.717271600450786, 5.574828079768589, 0.23383999509470804, 0.7848109730652401, 0.9111883917025158, 9.246143307004656, 14.665442909513201, 28.38042262622288, 13.697582295962743, 4.45446058682033, 3.243714834962572, 0.6553346035735947, 12.176359329904828, 43.015800680433, 57.23985406330654, 59.510980469839915, 53.68620136805943, 56.199302264622276, 51.1636335509164, 51.929682867867605, 54.325400897434776, 56.04720619746617, 52.61872182573591, 54.33748728888375, 52.10348163332258, 46.959778853825156, 43.124362809317454, 50.45664392198835, 52.63869789668492, 52.94434567860195, 52.98392261777605, 52.43035616193499, 51.67563588278634, 54.47909852436611, 47.10422148023333, 40.820638929094585, 41.387493814740864, 40.12609004974365, 39.804246016911094, 42.156412737710134, 40.77109479904175, 40.10970967156546, 39.602737835475374, 42.795462880815776, 39.14272887366158, 39.63254560743059, 39.880335739680696, 40.045098372868125, 38.45716054098946, 44.824583530426025, 45.36789444514683, 50.342234883989605, 49.37761647360665, 53.399591650281636, 51.723818165915354, 48.71279198782784, 41.70464781352452, 41.673697062901084, 49.115724972316194, 49.403439453669954, 51.26128005981445, 53.69701623916626, 51.87776245389666, 50.18946484157017, 48.729585783822195, 48.11694574356079, 42.92247247695923, 37.67874343054635, 37.43262781415667, 36.036536693573, 37.15012795584542, 34.16064466748919, 37.20650911331177, 36.084767614092144, 36.236471108027864, 46.7702875818525, 51.25079870223999, 49.53093889781407, 51.121378081185476, 47.52180821555001, 42.74974373408726, 38.594185965401785, 36.473859786987305, 38.04019914354597, 35.81536511012486, 42.54348298481533, 46.7710588318961, 47.44297048023769, 48.98803792681013, 42.95583772659302, 46.684480803353445, 47.00300012316023, 45.30999163218907, 44.79712772369385, 47.78253936767578, 46.24859946114676, 43.10776008878435, 48.195394379752024, 46.228991644723074, 45.25274542399815, 37.907432964869905, 17.694148778915405, 3.6657896723066057, 1.1127520501613617, 6.336269872529166, 6.145416753632682, 7.689339484487261, 11.562115124293737, 46.94331162316458, 16.419340201786586, 2.472065704209464, 1.0626828968524933, 0.20795023361487047, 0.29441246337124277, 24.169836861746653, 49.111344133104595, 24.869351966040476, 48.534303188323975, 10.656696234430585, 0.23574540285127504, 0.14330059768898146, 0.1303212270140648, 0.12550218988742146, 0.16105125019592897, 0.2589720365192209, 0.23355509181107792, 0.19910780952445098, 0.11091625184885093, 0.11410544786070075, 0.1631853242537805, 0.1733220267508711, 0.19463037406759603, 0.160808158240148, 0.115473957998412, 0.1017914011276194, 0.12058776430785656, 0.15317058164094174, 0.11153313517570496, 0.12268996079053197, 0.16791607040379727, 0.1168778876640967, 0.1302749237843922], [0.038445149548351765, 0.01313599182425865, 0.07246944667505366, 0.020183629722201397, 0.023988764200891768, 0.053832101569111855, 0.09127790134932313, 0.034463651943951845, 0.10502173671764986, 0.048765972522752624, 0.029232957799519812, 0.058834923298231194, 0.022816603437864354, 0.0060212968549292, 0.007843393233737775, 0.08972538608525481, 0.013888729736208916, 0.04654774655188833, 0.020380077484462942, 0.024887175099658113, 0.058387381955981255, 0.0725548267364502, 0.05482390942052007, 0.11919010430574417, 0.025208807483847653, 0.05515358244468059, 0.04021794102819903, 0.010414651644948338, 0.09591727597372872, 0.026134485312338387, 0.083168261152293, 20.561652966908046, 37.711344378335134, 23.75027162688119, 40.49027987888881, 22.606730154582433, 0.047593365622950454, 0.022530818058710014, 0.036478212236293724, 0.34222727907555445, 8.24559576170785, 6.635652550629207, 3.3298223401818956, 2.7785652918475012, 1.0968914840902602, 0.2449456320277282, 1.269138087119375, 17.938037497656687, 47.00364977972848, 54.22637169701712, 53.029520171029226, 51.030961172921316, 54.388000692640034, 51.14566898345947, 51.46518536976406, 52.21876267024449, 51.51126234872, 48.73904575620379, 44.445277895246235, 40.75146961212158, 46.77312592097691, 48.43995359965733, 49.11806304114205, 51.008699144635884, 52.53670528956822, 49.10648734228951, 48.94589362825666, 48.75001001358032, 44.28514971051897, 37.62167092732021, 38.470549719674246, 37.39614282335554, 38.11927659170968, 38.553188119615825, 37.83303165435791, 37.46590968540737, 36.5671706199646, 36.979897090366904, 37.11576911381313, 35.191757338387625, 36.628460679735454, 36.70324761526925, 35.91639886583601, 41.512286935533794, 44.449950558798655, 47.31591919490269, 46.569984912872314, 48.87457731791905, 47.51721545628139, 52.84936032976423, 42.58524513244629, 48.712246554238455, 53.39372737067086, 46.00253248214722, 46.36678484507969, 46.103580134255544, 44.50222185679844, 42.36463982718331, 44.005488191332134, 40.339194774627686, 35.424188477652415, 33.927157402038574, 33.90913030079433, 34.95254128319876, 32.81241273880005, 34.60263695035662, 35.0198450088501, 36.21424382073538, 40.96491132463728, 46.624962534223286, 49.438065801348, 47.24750375747681, 46.5306442124503, 45.49817664282662, 40.4789890561785, 35.3913825580052, 34.04997028623308, 33.4121082850865, 35.93653474535261, 40.27450704574585, 43.50180285317557, 44.24258157185146, 46.44114446640015, 44.85232073920113, 42.301821163722444, 44.69490235192435, 43.29077911376953, 41.13574668339321, 42.101403849465505, 45.91455091748919, 42.2722670010158, 43.84384529931204, 43.54001794542585, 38.00574997493199, 21.5390682220459, 4.183683208056858, 0.13852007420999662, 0.4993044989449637, 3.8211427075522284, 2.1348105669021606, 3.3728948746408736, 3.17703948702131, 8.50616102559226, 6.167990148067474, 0.3834535468901907, 0.06883779154824358, 0.017200567560004335, 1.770631160054888, 33.76752601351057, 24.96623417309352, 20.871681588036672, 25.19084164074489, 0.7869669773748943, 0.09405170500810657, 0.05850472101675613, 0.09574456845543214, 0.03022241113441331, 0.029840199143758843, 0.066357651060181, 0.03054716477968863, 0.06067508991275515, 0.056836223761950216, 0.033685212821832726, 0.10568359334553991, 0.03790987702086568, 0.03917695635131427, 0.04414543742313981, 0.022450101229229143, 0.015887139198769416, 0.047974105192614455, 0.06842051965317555, 0.03591189333902938, 0.05100130096876195, 0.040472323806690316, 0.02882180629031999, 0.016373170439952185, 0.06566720096660511, 0.013189856478545283, 0.06390955099569899, 0.07034948614559003, 0.028998025227338076, 0.019966763144891177, 0.014977781833814723, 0.06411632775728192, 0.0796956614192043, 0.024149012119908417, 0.04959603798176561, 0.038924398832023144, 0.021074644589264478, 0.03528427898085543, 0.04538337028186236, 0.01252765634230205, 0.012995659756208104, 0.04370179087189691, 0.006055763465285833, 0.05389962258881756, 0.021850093068288903, 0.007166379829868674, 0.03203644736536911, 0.09703837867294039, 0.014486983884125948, 0.05498848469661815, 0.021772790966289382, 0.034636359462248426, 0.05392054521611758, 0.12407280158783708, 0.13259611065898622, 25.57043562616621, 40.51237167630877, 26.032219852719987, 53.268843923296245, 20.993040561676025, 0.042905543598213365, 0.11090679985604115, 0.049693007421280654, 0.05298253840633801, 1.053646873150553, 6.163220643997192, 5.313649637358529, 4.771459553922925, 4.303311211722238, 0.8313771486282349, 1.706251866051129, 23.10843699319022, 50.16666432789394, 54.32002646582467, 52.39797755650112, 54.85426650728498, 54.487439836774556, 52.3584805216108, 51.9798002243042, 53.80500166756766, 52.62304013116019, 51.49050807952881, 46.317445686885286, 43.08194753101894, 46.8240909576416, 49.90800026484898, 50.13875688825335, 51.648485796792166, 51.111334460122244, 51.215585231781006, 49.38752460479736, 50.26625285829817, 44.94898060389927, 38.517790521894185, 40.77495452335903, 39.93872840063912, 39.390699659075054, 41.37214871815273, 39.01280450820923, 38.401269231523784, 38.131571429116384, 38.384951387132915, 38.788037231990266, 36.678241048540386, 38.384812423161094, 38.82856260027204, 37.94529022489275, 43.61148016793387, 45.73553058079311, 49.15535749707903, 47.48241540363857, 50.001946857997346, 49.62120641980852, 52.599072320120676, 41.62984698159354, 49.06335987363543, 54.088099070957725, 46.65035472597395, 47.62625701086861, 47.590175015585764, 46.05566535677229, 44.55235310963222, 46.92072650364467, 43.62951421737671, 37.39474970953805, 36.16048560823713, 36.40249136516026, 37.605537210192, 35.39976208550589, 35.46626329421997, 36.48518187659127, 36.44429520198277, 41.47127171925136, 45.695599283490864, 50.12087222508022, 48.5545710836138, 47.46311330795288, 48.18493734087263, 41.36926521573748, 36.44574390138899, 34.86198541096279, 34.51308856691633, 37.768243176596506, 40.70097010476248, 43.75789955684117, 46.14587034497942, 47.06255660738264, 43.499270234789165, 44.28267962591988, 45.73466205596924, 44.826744420187815, 41.50257682800293, 45.20354175567627, 45.43406561442784, 44.15877587454659, 45.2052058492388, 45.453530992780415, 39.705796991075786, 24.84778128351484, 5.886711869921003, 0.6579924523830414, 2.2159653093133653, 6.40190646478108, 2.396475817476, 6.203997884477888, 7.971334729875837, 14.419642567634583, 7.774738056319101, 0.8334653537188257, 0.056938987890524526, 0.02522477850184909, 1.8243522431169237, 35.99707439967564, 30.841125420161656, 19.693062135151454, 34.72389691216605, 1.260928139090538, 0.04506555126447763, 0.03154395307813372, 0.03660563432744571, 0.01859218011876302, 0.03967968973198107, 0.013279042273227657, 0.02849748351478151, 0.05125743436760136, 0.02846359069060002, 0.046342876473707814, 0.04173638026363083, 0.017248792740117227, 0.06038179315094437, 0.10438438877463341, 0.037542416381516626, 0.058165080313171656, 0.04811305898640837, 0.03250679087692073, 0.06897531702582325, 0.03607436515656965, 0.02798380027525127, 0.0913196380383202, 0.050446866612349234, 0.16946885708187306, 0.18560197709926538, 0.1755248499768121, 0.13657901622354984, 0.1540327960891383, 0.19469539129308291, 0.2542121947876045, 0.1220406706311873, 0.24999444825308664, 0.15449263927127632, 0.12262577137776784, 0.18834357070071356, 0.1287114569651229, 0.14279088218297276, 0.09134105260350875, 0.10287935739117009, 0.04971255262249282, 0.0852650972083211, 0.12514612185103552, 0.11214904819748231, 0.17062098240213736, 0.2105650090213333, 0.09626442805996963, 0.1586247139743396, 0.09121409191616944, 0.14385604645524705, 0.15820067029978546, 0.13364999767925057, 0.1371686224426542, 0.24153572214501245, 0.4139658553259713, 29.957192965916224, 50.64200448989868, 31.721882547651017, 51.61226831163679, 30.491353103092738, 0.1416981015354395, 0.2396087369748524, 0.16211566807968275, 1.230849495955876, 13.420802542141505, 13.16482743195125, 9.651558535439626, 8.890149746622358, 4.506880402565002, 0.5382506719657353, 2.0920337651457106, 20.565809726715088, 49.50468165533883, 55.64775773457119, 55.194172382354736, 56.674256801605225, 58.89036737169538, 54.25016580309187, 52.7432404926845, 54.402928897312705, 55.88916594641549, 53.0721195765904, 47.9566125869751, 44.7722601209368, 50.77689334324428, 52.00424746104649, 52.379641260419575, 54.439632756369456, 53.946275915418354, 50.96086079733712, 52.67329297746931, 53.28875051225935, 48.927046639578684, 42.1394487108503, 43.276059355054585, 40.8818039212908, 43.02172401973179, 42.64421796798706, 41.983201095036094, 42.014183112553184, 40.244258063180105, 41.37069654464722, 40.605745043073384, 37.705473150525776, 41.356424944741384, 41.398496287209646, 40.13169724600655, 46.58604914801461, 47.69082314627511, 50.528995513916016, 49.41467121669224, 52.050251483917236, 52.529569489615305, 54.01198155539376, 44.042886870247976, 49.12947545732771, 56.2282588822501, 48.30246959413801, 49.8197477204459, 49.789873940604075, 47.321481227874756, 44.74620090212141, 47.682064941951204, 45.17391811098371, 38.91293110166277, 39.254827635628835, 37.322015966687886, 38.898503167288645, 36.536542960575645, 37.967639105660574, 38.46355288369315, 38.92215830939156, 44.45863233293806, 47.606065545763286, 52.77327755519322, 49.860947063991, 48.83077587400164, 50.957820960453574, 43.396186760493684, 38.27959585189819, 37.420166219983784, 36.944405691964285, 39.68971538543701, 42.83916704995291, 46.32260472433907, 48.134083475385395, 48.581655161721365, 45.91735104152134, 42.671937806265696, 47.23895399911063, 46.142906938280376, 43.09632682800293, 45.24073893683297, 47.63876724243164, 43.192166805267334, 45.57117789132254, 44.184967109135215, 38.966074398585725, 23.480916023254395, 5.6509108543396, 0.4683790983898299, 3.709813892841339, 9.393334814480372, 6.170095017978123, 8.636691621371678, 7.847172158105033, 13.402005059378487, 10.591351900781904, 2.1811092368194034, 0.1336686573922634, 0.11384372333330767, 3.1055486031941006, 42.63472325461251, 33.61215387071882, 28.764852557863506, 38.20766462598528, 1.526966086455754, 0.2050502970814705, 0.14137201117617743, 0.17840124134506496, 0.15201490079717977, 0.0805931461176702, 0.18070159719458648, 0.07882700767368078, 0.17466821308646882, 0.17281290835567883, 0.13013563411576407, 0.19067500345408916, 0.12589032548878873, 0.13947328020419392, 0.3240738888936383, 0.12149975608502116, 0.1074660030592765, 0.1017367315611669, 0.1363526705120291, 0.1400652884372643, 0.1878459466887372, 0.14835075741367681, 0.1766927715923105, 0.09367515878485781], [0.06412573903799057, 0.05000953043677977, 0.040382472199520895, 0.010967901957753514, 0.09286666395408766, 0.038404909029070816, 0.01690344725336347, 0.06663720748786416, 0.04641603611941848, 0.02248568021293197, 0.024701044462355118, 0.0037900786347953336, 0.0633830213919282, 0.02696702572783189, 0.041982586695147414, 0.019839352928102016, 0.09471930882760457, 0.08301181811839342, 0.04878562628956778, 0.02588199564654912, 0.016796206490003636, 0.05248837831563183, 0.01590897954468216, 0.02731894112990371, 0.0020914508204441518, 0.04140462074428797, 0.03959140893337982, 0.07579560498041765, 0.08697457797825336, 0.06080993517701115, 0.12893043378634111, 3.7287863833563666, 35.781756673540386, 28.900533505848475, 28.526522397994995, 41.136344228472026, 7.4453170129231045, 0.08106660071228232, 0.1865909147475447, 0.09216834285429545, 1.1032679762159074, 2.2549245102064948, 2.229339505944933, 11.118410110473633, 3.8748449001993452, 0.27345392799803186, 0.014581724336104733, 2.3122920947415486, 23.052550894873484, 47.59706762858799, 53.105005400521414, 52.956449440547395, 52.57258231299264, 52.36726999282837, 53.65397562299456, 51.19641167776925, 51.828795024326865, 46.00126443590437, 42.442473547799246, 45.57607289722988, 50.35882370812552, 48.07635089329311, 51.808944020952495, 51.15968697411673, 48.2303056035723, 48.43603828975132, 51.04386050360543, 49.24465227127075, 41.999348708561485, 35.67551176888602, 38.64906631197248, 36.395737716129844, 39.3630736214774, 40.11236735752651, 41.25097908292498, 38.25202539988926, 37.857784611838206, 38.431129114968435, 38.19951786313738, 35.15441077096121, 37.32153654098511, 36.36327920641218, 36.95577641895839, 40.509074756077354, 45.758358887263704, 47.70306587219238, 48.44407735552107, 49.32236787251064, 50.34868628638131, 48.91111789430891, 51.159923212868826, 49.395056452069966, 47.47931998116629, 48.35071441105434, 45.64697578975132, 43.612463338034495, 41.715177808489116, 41.42371824809483, 38.22716474533081, 35.720452717372346, 34.90216684341431, 34.12107120241438, 35.7094224521092, 34.42168501445225, 35.046692848205566, 36.39810357775007, 35.10559967585972, 40.265172140938894, 45.61846733093262, 48.794714723314556, 47.55629907335554, 47.530611583164756, 47.25923579079764, 45.47848197392055, 42.69109051568167, 36.81770181655884, 33.40321111679077, 34.104405948093955, 36.313787187848774, 41.92380094528198, 43.827176570892334, 44.720454352242605, 46.85692467008318, 44.609380449567524, 43.59926176071167, 44.4705102784293, 44.53260285513741, 42.36775956835066, 44.77824599402291, 45.69534567424229, 42.676190103803364, 43.96365656171526, 40.71241726194109, 26.63799159867423, 7.22666415146419, 0.4468229365135942, 0.21201256848871708, 1.3804708101919718, 5.474487841129303, 0.71757900927748, 7.637471182005746, 7.971261773790632, 2.5104382165840695, 0.8997060049857412, 0.11700136746679034, 0.02177152380214206, 0.1287746557167598, 13.487851790019445, 37.87751749583653, 20.0619124685015, 29.64473942347935, 10.926629407065255, 0.021832050822143043, 0.003825647016388497, 0.0465330494833844, 0.049243413510599306, 0.035519323511315246, 0.08818504373942103, 0.03222791976960642, 0.04899680335074663, 0.03168742930782693, 0.024448777016784464, 0.030615391475813727, 0.04088919536609735, 0.0454696494021586, 0.07146211394241878, 0.01533152419142425, 0.041478771051125865, 0.005364325679173427, 0.05126270319202116, 0.020367928314954042, 0.01832633009845657, 0.03479465489674892, 0.050817485832210095, 0.02855367978502597, 0.0563691948939647, 0.041093980627400536, 0.044152650250388045, 0.021445504689056958, 0.07491447976125137, 0.02729707194625267, 0.05837625398167542, 0.016587845349152173, 0.038049468637577126, 0.02100405659127448, 0.014012715895660222, 0.05564581210325871, 0.028176088617848496, 0.03719646190958364, 0.015319978918081947, 0.03303234339026468, 0.03776948134015713, 0.030009938071348836, 0.014101052673400512, 0.0078054147805752495, 0.07272442656436137, 0.05247697553464344, 0.020297145238146186, 0.028952916219298328, 0.007488861231000296, 0.012628981976636817, 0.027230399095320275, 0.03516080935618707, 0.07591129520109721, 0.03480859200603195, 0.034967973096562285, 0.10891819013548748, 6.840306963239398, 45.44352558680943, 26.06670376232692, 34.45075280325753, 50.25742169788906, 5.642302470547812, 0.028938694125307456, 0.1381716329072203, 0.02738581584500415, 0.2946576045027801, 1.0174537066902434, 3.6564208950315202, 9.533480848584857, 6.106468192168644, 1.8861814396721976, 0.23748858645558357, 3.8115264007023404, 27.27263832092285, 49.540249483925955, 55.341074671064106, 53.648615087781636, 54.1693617275783, 55.10052456174578, 54.16171176092965, 53.575398445129395, 53.41304683685303, 48.61295332227434, 43.831171785082134, 46.32121508462088, 51.53193323952811, 51.129239967891145, 51.51063701084682, 52.71662541798183, 48.988468715122764, 50.425269331250874, 51.87159245354788, 50.95135566166469, 44.42071948732649, 37.99684238433838, 40.715387616838726, 38.37688452856881, 41.13847732543945, 42.43668222427368, 42.728781018938335, 40.516332149505615, 40.3617833682469, 39.150038378579275, 38.31055702481951, 38.64611332757132, 38.475316183907644, 37.77710560389927, 37.786985942295615, 41.64833613804409, 46.90335600716727, 47.64650058746338, 51.42221423557827, 52.09683568137032, 53.062524114336284, 48.82818767002651, 52.94129889351981, 50.717983041490825, 49.18139239719936, 50.89861536026001, 47.540516240256174, 45.05208492279053, 43.67882905687605, 42.72137771333967, 40.86798742839268, 37.700282846178325, 36.74535717282976, 36.10527522223336, 36.820383821214946, 36.80262769971575, 35.081027371542795, 37.59479182107108, 35.122528961726594, 39.303739479609895, 46.29726116997855, 49.74788250241961, 48.7806897844587, 48.66123982838222, 48.7749297278268, 48.124359471457346, 44.53519453321184, 37.98999146052769, 35.2035345349993, 36.61678075790405, 37.6330555507115, 43.46554020472935, 45.18918330328805, 45.6366194997515, 47.592335905347554, 45.003256457192556, 44.00913946969168, 46.21271548952375, 45.53084012440273, 44.78275537490845, 45.409298760550364, 45.96652691704886, 44.29767383847918, 44.58969620295933, 41.67574330738613, 27.533680404935563, 9.341228536197118, 1.049772818173681, 1.8147295308964593, 3.046381000961576, 5.773518766675677, 3.820013625281198, 4.6981708237103055, 9.172768592834473, 3.7203295571463446, 0.32494474787797245, 0.01062487281991967, 0.012403582821467092, 0.13811401171343668, 13.603262237140111, 45.002321924482075, 20.144194773265294, 31.253858838762554, 15.768764734268188, 0.054951918444463184, 0.030017032154968808, 0.07182926924100944, 0.048735631829393763, 0.05625699573595609, 0.030858751452927078, 0.0688936078388776, 0.08242890225457293, 0.031085293939603225, 0.01893333395543907, 0.0815473495583449, 0.05936205679816859, 0.0180175406858325, 0.005964107379051191, 0.04440344697130578, 0.009487728704698384, 0.0066444430600053495, 0.029733777711434022, 0.02882620319724083, 0.05625474299969418, 0.03394193315346326, 0.02214051453795816, 0.06425427392657314, 0.007582019000048084, 0.11373208396668945, 0.19592049983995302, 0.16493878087827138, 0.1489226674394948, 0.1281676654304777, 0.10621034686586686, 0.07178010259355817, 0.2269513311662844, 0.11443536515746798, 0.18189077052686894, 0.111657212089215, 0.11413279282195227, 0.1559279036841222, 0.12335359518017087, 0.11475689576140471, 0.08072881240929876, 0.16211606162999356, 0.1442662887275219, 0.11616534447031361, 0.17153549832957132, 0.16583090515008994, 0.08865325325833899, 0.10920561756938696, 0.07403866068593093, 0.08389130128281456, 0.08870819423879896, 0.08414043220026152, 0.19990755803883076, 0.14133877653096402, 0.1371917604867901, 0.2547120579651424, 8.602166891098022, 52.48660182952881, 37.393314906529014, 37.73779617037092, 52.84519835880825, 12.774286559649877, 0.1541093076978411, 0.402652559535844, 0.24195901943104609, 3.8127397298812866, 4.64782417672021, 6.520750624792917, 21.47027931894575, 8.942691155842372, 1.1766383477619715, 0.17906634137034416, 3.1779590376785825, 26.411518539701188, 49.95770420346941, 56.29894290651594, 55.81079026630947, 53.66369962692261, 54.348521028246196, 56.908352034432546, 55.72136695044381, 56.65411744798933, 48.9799884387425, 45.92756141935076, 49.098969391414094, 55.14125837598528, 51.73908683231899, 54.191276345934185, 52.9277012688773, 50.006261689322336, 51.740684917994905, 54.406694820949006, 52.8002678326198, 46.269416264125276, 40.634093693324495, 43.070271083286826, 40.46401916231428, 43.230903012411936, 43.91873298372541, 46.640807901109966, 43.634242466517854, 42.60123641150338, 41.9578401701791, 41.867652552468435, 38.71060650689261, 41.895427976335796, 39.28739036832537, 40.79170315606253, 44.80603878838675, 50.01104552405221, 50.753245149339946, 53.014418261391775, 54.161864621298655, 53.67653642381941, 50.37303624834333, 51.43979665211269, 51.305342061179026, 51.89182908194405, 52.13472073418753, 49.02834790093558, 46.099720409938264, 45.44742005211966, 44.70578670501709, 42.48987415858677, 40.13030760628836, 38.059754848480225, 37.51224374771118, 39.42029203687395, 38.09201880863735, 38.43059062957764, 38.448982511247905, 37.894929681505474, 41.85787296295166, 48.85756465366909, 51.47515950884138, 50.799044200352256, 49.639327321733745, 50.36320454733712, 49.13712542397635, 45.627246379852295, 39.49671874727522, 37.03672988074166, 38.548480715070454, 39.39176620755877, 45.03605195454189, 46.82511234283447, 48.02604940959385, 49.80190474646432, 46.131296498434885, 44.66126264844622, 46.95771523884365, 47.38365370886666, 46.44047743933541, 48.56075498035976, 48.2702716418675, 44.64658110482352, 45.25717837469918, 41.66695383616856, 28.85319369179862, 8.902699930327278, 0.6867661912526403, 1.8733277065413338, 4.639583613191332, 10.667828117098127, 5.485683560371399, 16.830650976725988, 21.076549223491124, 8.625985315867833, 2.660225961889539, 0.23048887348600797, 0.19656248896249703, 0.5044387291584695, 18.590963193348475, 48.6159792627607, 26.930540289197648, 40.07587194442749, 18.34956019265311, 0.14503908583096095, 0.11541573969381196, 0.1450275643063443, 0.16879237123898097, 0.12675476553184645, 0.1530249137431383, 0.1910334870751415, 0.15604476098503384, 0.17878127523830958, 0.14770346214728697, 0.09698012644158942, 0.12948261201381683, 0.15220243430563382, 0.21400353951113565, 0.18203741551509925, 0.12863086057560785, 0.08345551216708762, 0.1929741786526782, 0.16437841951847076, 0.11389001299227987, 0.07037168781140021, 0.12572603859007359, 0.27148623072675293, 0.16733038611710072], [0.03071443723248584, 0.05250427299844367, 0.012805258589131492, 0.03968668542802334, 0.02028252450483186, 0.016402077728084156, 0.009716266084329357, 0.019760259493653263, 0.08147511272025959, 0.066285862055208, 0.02417272691881018, 0.003617935996901776, 0.06843478924461774, 0.024371612318126217, 0.0329673193794276, 0.048200613752539666, 0.01701904078280287, 0.048517503176948855, 0.0561089936776885, 0.030856363009661436, 0.05145024687850049, 0.0542070464497166, 0.0074114590450855234, 0.04498420170109187, 0.06089114224804299, 0.04558139733437981, 0.03874297892408712, 0.03155558995370354, 0.07074146904051304, 0.024553032226062248, 0.07956424954214267, 0.32780542437519344, 14.063565628869192, 41.18008313860212, 24.61321531023298, 37.0489239692688, 36.47077131271362, 4.2257219808442255, 0.1720491221972874, 0.16199404746294022, 0.10057018058640615, 1.4623277549232756, 0.6309943582330431, 0.3850418616618429, 7.1504689029284885, 7.494303550039019, 0.6327252739242145, 0.21254498777644976, 1.8969563586371285, 17.680252381733485, 39.08365528924124, 48.96235391071865, 52.30068193163191, 53.72846378598894, 51.95091656276158, 50.857030391693115, 48.71616186414446, 43.598007610866, 45.0876145362854, 50.94749593734741, 49.499244689941406, 52.196570123944966, 50.319024426596506, 47.48397527422224, 48.115990366254536, 51.49137313025338, 47.16447973251343, 45.351013796670095, 38.892652784075054, 37.220655645642964, 37.91393300465175, 39.23570271900722, 40.181932721819194, 44.70160736356463, 43.77952235085623, 41.02654184613909, 37.84744569233486, 37.32556997026716, 37.5765562738691, 38.2345541545323, 35.195377349853516, 35.556339740753174, 35.08461959021432, 38.091893741062705, 41.452167647225515, 45.08324064527239, 49.00087472370693, 48.99641398021153, 47.82826893670218, 50.45567464828491, 48.82697868347168, 51.61240380150931, 48.170766489846365, 46.93811437061855, 41.799883297511506, 40.2421110698155, 37.78979648862566, 35.742464610508506, 34.032822132110596, 33.26117951529366, 35.52590315682547, 36.08122055871146, 35.56776605333601, 34.75923892429897, 37.31085021155221, 35.71766996383667, 40.56620979309082, 45.913571221487864, 46.221748147692, 46.99811206545149, 48.81171349116734, 47.049132687704905, 48.47060905184065, 46.38731677191598, 45.33637741633824, 38.5562870161874, 33.31432628631592, 36.08694934844971, 39.00909764426095, 41.77055842535836, 44.508982454027446, 42.93551424571446, 44.776390824999126, 43.46186113357544, 44.803728512355256, 44.78387403488159, 46.18060091563633, 43.5572737966265, 43.45841482707432, 42.84398562567574, 45.880403995513916, 41.27412353243147, 30.645703860691615, 13.543487753186907, 2.704781936747687, 0.9616097318274635, 2.61972838640213, 2.0682411789894104, 6.342344769409724, 2.5094945643629347, 1.922069102525711, 10.295968345233373, 3.0513876123087744, 0.16609609020607813, 0.02107521964769278, 0.09875099427465882, 6.3973840560231885, 35.141695567539756, 26.081574644361222, 23.046860320227488, 26.481247186660767, 2.0304950901440213, 0.16340166835912637, 0.07418639811554126, 0.1034630196435111, 0.022358129200126444, 0.037572102288582494, 0.010237605743376272, 0.014387858399589146, 0.030929492121296268, 0.04609882439087544, 0.07215516282511608, 0.039985817590994496, 0.03958856587165168, 0.09970504165227924, 0.03807359395016517, 0.04605313862806984, 0.013273717469668813, 0.028755679660077606, 0.04147517481552703, 0.08511658624878951, 0.02346917601036174, 0.07713318070662872, 0.0805145242650594, 0.07892902541373457, 0.029734707304409573, 0.013497071689926088, 0.008225017443432339, 0.042854175104626586, 0.0447137919254601, 0.02079397875682584, 0.04357693025044032, 0.0027707551281699644, 0.03970543335058859, 0.017980976130015085, 0.04743714989828212, 0.05202541387240801, 0.007170596076840801, 0.007128045993990132, 0.014089244467738484, 0.013649373963874365, 0.03836909255811146, 0.027518420247361064, 0.047562644949981144, 0.006232221161813608, 0.012402786390988954, 0.0655041015041726, 0.03962453840566533, 0.050262617213385444, 0.008904581290802785, 0.0497992626125259, 0.022805770626291633, 0.06777642028672354, 0.052516340743750334, 0.0470075693779758, 0.03429334643962128, 0.03907476558483072, 0.487779717360224, 21.797685384750366, 43.749648571014404, 22.808505841663905, 47.10038260051182, 37.101230008261545, 3.520727570567812, 0.14939329932842935, 0.12475398289305822, 0.0982956565650446, 0.16409055782215937, 0.1915516706981829, 2.67354131596429, 9.323506287166051, 5.261049168450492, 1.5845270263297218, 0.5556680687836238, 3.379710623196193, 22.89896443911961, 44.410589013780864, 52.290252685546875, 52.8503052847726, 55.78869499479021, 54.63924060549055, 51.9529002734593, 51.48129824229649, 45.76595326832363, 46.42897122246878, 52.55384649549212, 52.02633578436715, 52.570754936763215, 52.22989368438721, 47.84107794080462, 47.93216535023281, 52.03483690534319, 49.811729499271934, 48.358124664851594, 39.64410393578665, 38.92848464420864, 39.51453740256173, 41.44452115467617, 42.980250222342356, 45.07907172611782, 45.80114589418684, 41.8946532521929, 38.75928558622088, 38.07726083483015, 38.74838733673096, 38.950948170253206, 38.103865487234934, 37.82765374864851, 38.11890486308506, 39.61172880445208, 43.47808517728533, 46.800470556531636, 48.51051950454712, 50.957212993076865, 50.82089975902012, 52.22652380807059, 49.22390495027815, 52.361374446323936, 50.06736762183053, 47.948368549346924, 46.344286578042166, 41.622290815625874, 40.035555022103445, 38.823288917541504, 36.37842280524117, 34.34703356879098, 36.62740107945034, 36.901351179395405, 38.42274611336844, 36.67065708977835, 39.07574476514544, 37.489658628191265, 41.09440837587629, 45.480712345668245, 48.129417760031565, 49.0198016166687, 48.9044372013637, 47.03981167929513, 48.834743295397075, 47.84868969236101, 45.986899035317556, 39.630874565669465, 34.26552077702114, 36.87343679155622, 40.66275501251221, 43.54848779950823, 45.56815889903477, 44.695201124463765, 46.088394846235005, 43.643744128090994, 45.74750232696533, 45.28917482921055, 46.09473507744925, 43.75667667388916, 44.722069808415, 44.529253823416575, 45.83212096350533, 42.81156185695103, 33.60073103223528, 15.936855554580688, 3.8575959971972873, 1.358173823782376, 3.198055399315698, 2.6526600250176022, 4.013074100017548, 5.3653885296412875, 6.518104663916996, 4.001099748270852, 1.007355151431901, 0.17629673784332617, 0.05270413888086166, 0.08743767812848091, 4.753168421132224, 37.861995220184326, 33.59174006325858, 23.215979473931448, 32.89273044041225, 3.828227264540536, 0.2281106896698475, 0.034056517362062416, 0.06079308036714792, 0.024069321574643254, 0.03642256557941437, 0.01647468776042972, 0.03449665249458381, 0.032393095549196005, 0.059455287509730885, 0.014471888176298566, 0.023387105503518666, 0.01869370083191565, 0.0706637224980763, 0.014375017124361225, 0.009199580327341599, 0.010471595151882087, 0.036343726595597606, 0.037978361560297866, 0.0782487058479871, 0.011735527776181698, 0.06568936870566436, 0.028102683003193567, 0.01182821735606662, 0.056036003665732484, 0.10995349886694125, 0.1255365644714662, 0.1775963223938431, 0.09624495410493442, 0.09332684640373502, 0.09693161797310625, 0.12915797371949467, 0.0807425934555275, 0.23530582072479383, 0.2565915999667985, 0.1558094314698662, 0.11496485317392008, 0.0941015909026776, 0.07511828453945261, 0.16291207820177078, 0.13539422622748784, 0.08979220142854111, 0.11400955729186535, 0.14738858118653297, 0.11779982676463467, 0.18839047104120255, 0.10388928212757621, 0.11784074242625918, 0.1844235381909779, 0.14368178509175777, 0.09444796267364707, 0.1549190713890961, 0.1194372403302363, 0.20580357951777323, 0.07614537621183054, 0.12776313642305986, 0.5630250168698174, 25.515206132616314, 54.563706738608225, 33.1167368888855, 49.0087366104126, 45.470071179526194, 6.904781035014561, 0.335348372480699, 0.3339141937238829, 0.26108404461826595, 3.400271645614079, 5.9079234174319675, 4.034236575875964, 16.891477244240896, 17.34638101713998, 2.2412152801241194, 0.6778016580002648, 2.709298700094223, 20.12755036354065, 43.17590454646519, 50.70305483681815, 52.63936839784895, 56.74894993645804, 56.215769495282856, 53.702800614493235, 52.53981808253697, 48.01888929094587, 49.58403703144619, 55.47245121002197, 53.375665528433665, 55.612134320395334, 55.9971479007176, 49.129190581185476, 50.26489101137434, 54.89123092378889, 51.938267367226736, 50.05900546482631, 41.31149441855294, 41.338349206107004, 42.96267475400652, 43.53569964000157, 45.824245180402485, 49.21695327758789, 48.707358496529714, 44.9061484336853, 42.72109978539603, 41.29931770052229, 40.33274337223598, 41.161732946123394, 39.52358395712716, 40.24671425138201, 39.302249091012136, 40.94764157703945, 44.97276428767613, 47.82663263593401, 50.98074654170445, 52.31143079485212, 51.59614154270717, 53.85310752051217, 50.609351430620464, 54.45817749840872, 51.34237595966884, 49.24032701764788, 47.079583168029785, 43.77135474341256, 41.47451652799334, 40.257987703595845, 37.955660411289756, 34.967705726623535, 40.0513448034014, 38.711297852652415, 39.50024495806013, 39.45725992747715, 40.498770577566965, 40.21449892861502, 44.154742445264546, 47.874029772622244, 49.49247367041451, 49.30444846834455, 50.22212137494768, 48.057507378714426, 50.62656211853027, 51.72636120659964, 48.68455798285348, 41.051166261945454, 36.33670929500035, 39.075939314705984, 41.69572632653372, 45.34293304170881, 48.592845235552105, 44.20996672766549, 48.03476939882551, 46.11663927350725, 46.786747864314485, 46.348066398075645, 48.191475595746724, 46.127290861947195, 46.39666209902082, 45.78794084276472, 47.72882979256766, 42.95399297986712, 32.43186337607247, 14.673033816473824, 3.7252067582947865, 1.9574278337614877, 6.405392289161682, 4.315953893320901, 11.132399439811707, 6.170463706765856, 11.207341841288976, 23.42778488567897, 6.5176651903561185, 0.5158637932368687, 0.12476254600499358, 0.32218919002584046, 9.575678127152578, 44.67692041397095, 35.10216726575579, 31.834471157618932, 37.62654161453247, 4.1023949299539835, 0.30109893743480953, 0.16748373503131525, 0.19502956978976727, 0.1584119118217911, 0.15656731437359536, 0.1418701915868691, 0.1388083565980196, 0.1360942300941263, 0.24133232448782238, 0.2036637786243643, 0.15265538357198238, 0.18578310523714336, 0.18831360659429006, 0.11665705165692739, 0.15387981358383382, 0.07883092960608856, 0.10606727775718484, 0.12810127756425313, 0.19404999592474528, 0.11862845372940813, 0.13636588837419236, 0.20635435996311052, 0.10678809907819543, 0.12443466431328229], [0.0420756681290056, 0.030094154445188384, 0.038425000450972996, 0.017742108054725186, 0.03506981781018632, 0.04377914386402283, 0.029068233245717626, 0.03560414378132139, 0.03092802648565599, 0.01254201414329665, 0.01850216735952667, 0.021113572143284336, 0.002337255432004375, 0.021899502292009335, 0.01667496415653399, 0.0393502915145031, 0.09786252052124057, 0.040187501947262456, 0.006840397188040827, 0.043359201933656416, 0.1358958264546735, 0.059535877113895755, 0.01963202146414135, 0.02668919786810875, 0.04354363453707524, 0.08219222245471818, 0.07503695533211742, 0.03817135727565203, 0.026557607875604714, 0.07680101067359958, 0.00959050894847938, 0.134979763467397, 2.0421276773725237, 28.41915535926819, 36.43572807312012, 27.86516853741237, 36.29972750799996, 29.791693823678152, 6.490361375468118, 0.2881023862532207, 0.073816929012537, 0.06405163622860398, 0.8235344780342919, 1.350939011999539, 7.423900059291294, 1.4136093748467309, 2.171953465257372, 0.7168013538633073, 0.050957213155925274, 2.039829126426152, 12.563013553619385, 29.632778099605016, 46.04390205655779, 53.440356731414795, 51.986998558044434, 51.50112840107509, 47.89204297746931, 45.02016837256295, 47.84387459073748, 51.87354837145124, 52.42138951165335, 50.81143978663853, 46.502840995788574, 51.19518879481724, 50.90243339538574, 50.36295788628714, 48.168237345559255, 43.14881352015904, 37.08377613340105, 40.2272002356393, 39.412534373147146, 40.57469354357038, 42.80496801648821, 45.89423785890852, 46.81759091785976, 45.115254470280235, 40.478617327553884, 36.81210504259382, 37.60128491265433, 38.33505637305123, 37.97723109381539, 36.76683405467442, 38.27432564326695, 37.717364992414204, 40.02353811264038, 42.574489321027485, 44.67234155109951, 48.13081782204764, 51.65380464281355, 46.56643785749163, 50.17450189590454, 52.709767545972554, 49.687047549656455, 46.38781009401594, 42.44669805254255, 37.61636945179531, 38.72326612472534, 37.23981530325753, 35.88196359361921, 34.83579765047346, 35.58013037272862, 37.30751160212925, 33.88768815994263, 35.743020466395784, 38.75172247205462, 42.00561250959124, 47.6573224067688, 47.68129021780831, 49.20431450435093, 48.63621241705758, 47.59509086608887, 47.05725165775844, 50.53912946156093, 49.19044589996338, 45.36039386476789, 42.54878446034023, 32.95261001586914, 34.7793539592198, 40.84522860390799, 43.389054434640066, 45.468219484601704, 44.05610234396798, 46.20127528054373, 42.99601568494524, 43.851331983293804, 45.23573623384748, 45.6528365952628, 44.132581165858674, 43.18393666403634, 44.39730405807495, 43.71803426742554, 36.68125309262957, 19.082548243658884, 4.364416709968022, 0.4637179427913257, 0.6683169326611927, 2.6225717195442746, 2.8511218556335995, 2.178772036518369, 5.543030083179474, 3.2017650859696523, 1.9999749107020242, 0.28089794569781845, 0.017151982756331563, 0.12699344701000623, 4.3258077417101175, 27.443831511906215, 33.52059050968715, 20.023233583995275, 30.050601073673793, 11.495638234274727, 0.07107304196272578, 0.003971573181583413, 0.0196077977639756, 0.029017662030777762, 0.003888608704853271, 0.08204620171870504, 0.038314752081143, 0.032371039768414836, 0.005848529116649712, 0.019285458007029126, 0.07972444487469536, 0.009504156885668635, 0.02254962026407676, 0.01677484281494149, 0.01761683352690722, 0.11088284756988287, 0.06617313703255993, 0.04019877241392221, 0.09757775294461421, 0.04925740829535893, 0.014523767267486878, 0.05575491374890719, 0.03217478029962097, 0.07914053834974766, 0.02035486651584506, 0.07297083655638353, 0.05099425438259329, 0.05177178426778742, 0.07454615059707846, 0.01653035307702209, 0.042087908900742016, 0.04169758502393961, 0.044175265822559595, 0.04073142579623631, 0.03778539298634444, 0.06090220236884696, 0.03599727340042591, 0.01692879562532263, 0.011091794818639755, 0.00775433296803385, 0.02477651791247938, 0.06987065076828003, 0.06130758633038827, 0.041180649905332496, 0.016943306096696427, 0.07025658113083669, 0.061192357513521395, 0.013707152917049825, 0.06646401142435414, 0.03364161355420947, 0.012971183301747909, 0.05420184887147375, 0.04478685657626816, 0.027974248198526244, 0.026525455493746058, 0.012110007860298668, 0.030635747526373183, 3.7919038193566457, 38.89517150606428, 34.228782176971436, 29.30469458443778, 50.03181021554129, 30.993443829672678, 4.952728067125593, 0.31127340719103813, 0.05270674106265817, 0.04221894419086831, 0.3886474881853376, 0.8265173722590718, 6.4009749719074795, 5.595115951129368, 1.8839059046336581, 1.5255590762410844, 0.4789272780929293, 3.69014093705586, 16.516583715166362, 34.91221046447754, 48.66664900098528, 55.210111549922395, 53.09961359841483, 53.27684129987444, 50.03119877406529, 47.22893122264317, 48.57711451394217, 52.349600723811555, 53.92098099844796, 52.42011799131121, 47.14166184834072, 49.53397873469761, 52.1837020601545, 52.862176282065256, 50.56035968235561, 44.600632667541504, 38.927897521427695, 41.16785083498274, 40.636463029044016, 41.87258924756731, 45.19452994210379, 48.70996059690203, 48.898051806858604, 47.469179085322786, 42.36777693884713, 39.0851526260376, 39.23677274159023, 39.4988831111363, 39.71563911437988, 38.87734590257917, 39.85649299621582, 39.43180520193917, 42.280177525111604, 43.90210941859654, 46.86483866827828, 50.60410206658499, 53.1418308530535, 49.87107406343733, 50.55642352785383, 54.06524297169277, 50.99988535472325, 47.691490173339844, 44.273712975638254, 39.69230011531285, 40.392702851976665, 39.178362710135325, 37.50967638833182, 36.67955078397478, 36.41711732319423, 38.992408071245464, 36.33475685119629, 37.75474630083357, 38.51364244733538, 40.66401611055647, 48.3131559235709, 49.95870474406651, 49.66497312273298, 48.67173855645316, 49.54764584132603, 47.84424631936209, 51.91168703351702, 49.23605040141514, 46.91135685784476, 43.69880860192435, 34.432444299970356, 37.472319398607524, 41.3706305367606, 45.29494530814034, 46.2123715536935, 45.41685492651803, 46.02022954395839, 45.12705945968628, 45.10537413188389, 45.84102507999965, 46.37868710926601, 44.84241260801043, 44.565982001168386, 44.909219537462505, 44.4558322089059, 37.96462706157139, 20.166055543082102, 6.311436576502664, 1.1397323395524706, 2.384225926228932, 3.1780993044376373, 2.0548387553010667, 4.386527614934104, 6.329351203782218, 2.792397201061249, 0.30127345664160593, 0.11545892166239874, 0.009405452092843396, 0.13536598560001167, 3.6125106683799197, 30.509241240365164, 42.010319914136616, 19.994770288467407, 32.27724511282784, 17.427786111831665, 0.07546431025756256, 0.02737816366633134, 0.007764982575151537, 0.017367594043857286, 0.03512328636965581, 0.014470709221703666, 0.006930581277369389, 0.05793594582272427, 0.030830025672912598, 0.07607757020741701, 0.03477879414068801, 0.014253686581339155, 0.01932594449525433, 0.06500022818467446, 0.05326741115589227, 0.023230100981891155, 0.018397973218400563, 0.045781945144491534, 0.008310003954518055, 0.049850624320762496, 0.03527127146454794, 0.0636742961193834, 0.058141487650573254, 0.05861264879682234, 0.05178647794361625, 0.20703193146203244, 0.17944176122546196, 0.15655653923749924, 0.14619670728487627, 0.08750305497752768, 0.14186899736523628, 0.1618118608104331, 0.211177224027259, 0.17588948112513336, 0.14572979376784392, 0.11315027411494936, 0.08844175389302628, 0.1080262762095247, 0.15331892296671867, 0.0893536846020392, 0.12097372859716415, 0.1834429329527276, 0.09498974574463707, 0.13268251530826092, 0.11173968123538153, 0.2712970551635538, 0.14443417186183588, 0.11170373245009355, 0.10548211594245263, 0.12368151758398328, 0.16909897407250746, 0.2777818686195782, 0.11685446463525295, 0.10472830424883536, 0.15757364965975285, 0.10670711592371974, 0.32989612647465294, 4.837180393082755, 43.21524524688721, 45.94868046896798, 38.30085733958653, 46.67168569564819, 38.27593067714146, 9.765327470643179, 0.683755884213107, 0.27728860080242157, 0.2831726393529347, 2.5603469099317278, 6.222873100212642, 20.84885675566537, 9.511607050895691, 5.506142096860068, 3.867104606969016, 0.5290479457804135, 3.340358631951468, 13.869127239499774, 33.32350833075387, 46.97637810025896, 55.929382119859966, 54.87663275854928, 55.94976813452584, 50.83706474304199, 49.902208941323416, 50.63222490038191, 56.337988308497835, 55.619621004377095, 53.017975739070344, 48.11967291150774, 52.79400403159005, 52.74609620230538, 56.45176158632551, 53.21665947777884, 47.450175762176514, 40.84151826586042, 46.03823927470616, 43.93733331135341, 46.265358516148154, 47.812041418892996, 50.7519736289978, 51.07822281973702, 49.765305110386436, 43.931048665727886, 39.90024927684239, 40.94185025351388, 41.62335736410958, 43.0358601297651, 41.07732275554112, 42.760780947549, 42.02815593991961, 44.433709144592285, 46.895174503326416, 48.28161110196795, 52.941625458853586, 56.83159875869751, 49.2801193509783, 51.97144848959786, 58.257115500313894, 53.82534946714129, 49.92836890901838, 46.84766272136143, 42.5156033379691, 43.63695921216692, 41.261370113917756, 39.43130145754133, 37.96250786100115, 38.954971177237375, 39.555834020887104, 38.27407203401838, 40.403809547424316, 41.28200626373291, 43.846426555088584, 51.6888096673148, 50.891271114349365, 51.611243452344624, 49.72590882437569, 48.703714166368755, 48.041880880083355, 53.12690264838082, 52.59957259041922, 48.01094402585711, 46.65290471485683, 36.219930921282085, 37.93578508922032, 43.60557072503226, 47.500487668173655, 47.95821067265102, 46.612337657383506, 48.47891909735543, 45.33015530450003, 45.45302724838257, 46.148951871054514, 47.3494998386928, 47.80290106364659, 47.072687080928254, 46.939309460776194, 45.771702902657644, 39.06379038946969, 21.512764079230173, 5.799204954079219, 1.2727366025958742, 3.419403293303081, 5.9330910955156595, 6.858358383178711, 8.013530271393911, 14.205063956124441, 9.193242328507559, 4.039902397564479, 0.7416382868375097, 0.1217731378440346, 0.3809048607945442, 6.765543043613434, 35.288160119737896, 43.02704981395176, 27.974281311035156, 40.18961048126221, 17.786733525139944, 0.13693967115666184, 0.1661163376910346, 0.1241092389183385, 0.13461133252297128, 0.06334257391946656, 0.25664349432502476, 0.07819352738027062, 0.17895819645907196, 0.06981294815029417, 0.1605085036052125, 0.14368067229432718, 0.3573753833770752, 0.12191033762480531, 0.1189986624355827, 0.12455134519508906, 0.21123257891408034, 0.22048998145120485, 0.15385921326066765, 0.1734720915555954, 0.12960800528526306, 0.06292920360075575, 0.18212824421269552, 0.10256467320557151, 0.146663742938212, 0.0834115498832294], [0.02651312990513231, 0.07167534357202904, 0.06710173256163086, 0.05113821576482483, 0.061091133659439426, 0.041197525071246285, 0.02361531718634069, 0.05940460094383784, 0.037928092293441296, 0.04970728040539792, 0.04293541270973427, 0.03253138777134674, 0.03562815374295626, 0.0286846438289753, 0.03597499370308859, 0.04127567194934402, 0.08003596030175686, 0.03153253333376987, 0.06114375405013561, 0.04815862261291061, 0.05422392840098057, 0.05237662699073553, 0.10227980384869234, 0.051988169085234404, 0.051678875860358985, 0.06180276083094733, 0.007792168928842459, 0.04547007687922035, 0.0413756880110928, 0.004929715518041381, 0.04848377320117184, 0.03574125874521477, 0.06356925889849663, 8.301943046706063, 38.90608365195138, 30.3478866985866, 27.802577427455358, 36.80101571764265, 34.21736281258719, 9.391701119286672, 0.37867959163018633, 0.03649045640070524, 0.04504766847406115, 0.5328570242438997, 2.7250491806438992, 4.104496760027749, 0.8991248533129692, 1.3212631472519465, 0.3233901155846459, 0.21183963705386433, 1.6722696380955833, 9.336690493992396, 26.603830780301774, 52.249553612300325, 53.33905894415719, 52.232891832079204, 50.11652960096087, 47.005921840667725, 50.35071516036987, 53.23071220942906, 52.29118027005877, 50.700147015707834, 47.63230889184134, 49.459257807050435, 51.584815979003906, 50.69688136237008, 45.978536878313335, 41.58702870777675, 38.48720455169678, 39.58298410688128, 38.860857827322825, 42.03548976353237, 43.888841833387104, 47.42379345212664, 47.1351444380624, 46.538384505680625, 42.10521493639265, 38.17711687088013, 38.0764548437936, 37.86389207839966, 36.90285893848964, 36.690640108925955, 40.12804249354771, 42.35071563720703, 45.67254516056606, 47.18224280221121, 46.34669412885393, 48.39905302865164, 49.817572934286936, 51.8058624948774, 48.002873693193706, 50.14082397733416, 50.328001499176025, 48.28645747048514, 44.4181694984436, 40.160299505506245, 36.86204521996634, 36.81190701893398, 36.46885013580322, 36.88310520989554, 36.949234689985005, 36.32010310036795, 34.31768785204206, 36.30417782919747, 42.37215082986014, 49.1806697845459, 50.175696986062185, 48.89986181259155, 49.43063817705427, 48.73906660079956, 48.081457819257466, 48.05636092594692, 47.77504573549543, 49.41650554112026, 47.51376914978027, 42.583834648132324, 35.177881785801475, 38.061828885759624, 43.25791760853359, 45.713522161756245, 45.131891931806294, 44.96358919143677, 45.47394132614136, 45.08669737407139, 43.76254095349993, 44.467664991106304, 47.334008829934255, 43.897193568093435, 43.72879007884434, 44.147245338984895, 41.75543567112514, 22.85988255909511, 7.941156966345651, 2.092737704515457, 0.4723416886159352, 1.6380062252283096, 2.6343289400850023, 1.0582191135202135, 1.853881435734885, 4.427816850798471, 2.8807713389396667, 0.11142262896256787, 0.023511804972908328, 0.01767501111940614, 3.8563401103019714, 21.153243439538137, 32.79564673560006, 23.989963633673533, 27.407240561076573, 23.533899511609757, 0.9912453187363488, 0.018357639400554553, 0.09314580647540943, 0.06738413883639233, 0.02313554034169231, 0.03355716987113867, 0.060528655270380635, 0.045515677825148614, 0.016147250509155647, 0.00909427338878491, 0.038922434473144155, 0.008904568568271185, 0.0871463016207729, 0.05440618969233973, 0.044617100685302696, 0.05197302079094308, 0.0664655856255974, 0.0566546002935086, 0.047323994005897214, 0.010594064785566713, 0.03459799509229405, 0.026285550956215178, 0.05587108912212508, 0.03030205757490226, 0.049371934828481505, 0.024190903175622225, 0.00978711701463908, 0.06123404670506716, 0.04054748173803091, 0.02339543791354767, 0.01687124907039106, 0.012962464126758277, 0.025677008521077887, 0.05488561539511595, 0.04102637139814241, 0.005326234843648438, 0.0411046404125435, 0.043801878179822645, 0.05984820678297963, 0.033311038078474145, 0.024595810466312935, 0.027482629221464907, 0.04832037518333111, 0.027638787270656655, 0.01340109545604459, 0.04343985260597297, 0.045156885470662794, 0.017543746823711053, 0.09373712260276079, 0.015309714379587343, 0.015285348187067678, 0.06898540684155055, 0.03155853140300938, 0.020905753830447793, 0.024393201606082063, 0.036073981784284115, 0.0712815693446568, 0.030632517699684416, 0.2327902199966567, 13.57575171334403, 46.52696514129639, 29.91098049708775, 30.247874328068324, 48.52002811431885, 37.01089300428118, 7.351470300129481, 0.15380579898399965, 0.030395196684237038, 0.036963992419519594, 0.44079434286270824, 1.9662207790783472, 5.7140777962548395, 3.6215031572750638, 1.9970260517937797, 1.1602077037096024, 0.9877248619283948, 2.7849072601114, 11.670837061745779, 29.51039252962385, 55.419860294886995, 55.538215909685405, 54.21068613869803, 51.2339562688555, 49.052510261535645, 52.3674749646868, 55.03929703576224, 52.08547190257481, 49.99039200374058, 48.580678939819336, 51.74620873587472, 53.42238868985857, 51.631525244031636, 48.23847321101597, 43.68820217677525, 39.75417034966605, 40.206261839185444, 42.624429498400005, 43.95296675818307, 45.51750305720738, 48.084980555943076, 49.61314303534371, 48.64568975993565, 42.234903063092915, 39.90215308325631, 38.7324412209647, 39.22328976222447, 39.18809713636126, 39.61270155225481, 41.709191935403005, 43.011892318725586, 46.77634293692452, 47.57455893925258, 46.53851999555315, 51.48136077608381, 51.667711462293354, 52.75085571834019, 49.11290052958897, 53.08510575975691, 51.23850733893258, 49.17621946334839, 45.55400889260428, 40.792477880205425, 38.96577215194702, 38.2155682018825, 36.6388795035226, 37.92093331473214, 40.47297886439732, 37.31806244168963, 36.51264463152204, 39.140279633658274, 43.23322023664202, 49.88399771281651, 50.904476165771484, 50.67945875440325, 51.818282399858745, 48.90614993231637, 48.930201121738975, 48.53760705675398, 48.14292853219168, 50.79808187484741, 48.332975660051616, 44.797964981624055, 36.60604231698172, 38.305286816188264, 44.89451714924404, 47.15047563825335, 46.74268238885062, 45.61243976865496, 46.52145869391305, 46.64455992834908, 45.31214557375227, 45.28394283567156, 47.4484942981175, 44.7251478603908, 45.70262391226632, 44.281637396131245, 42.04521376746041, 26.122317143848964, 10.898343290601458, 2.222320088318416, 1.165947350008147, 1.91291115965162, 3.60231396981648, 3.0539352127483914, 4.285825201443263, 3.760815841811044, 1.3618500722306115, 0.33865104668906754, 0.1611691660114697, 0.024956217734143138, 3.0871643211160387, 22.35278739248003, 40.05744184766497, 25.79431700706482, 27.639508417674474, 30.093304702213832, 2.447596320084163, 0.13224638013967446, 0.02980041324294039, 0.05698994587042502, 0.08132795883076531, 0.02778150693380407, 0.03068655283589448, 0.037103275302797556, 0.05423734982364944, 0.015264072721557958, 0.0354059844144753, 0.006146552723034152, 0.08782456522541386, 0.06943880394101143, 0.027413099738104, 0.0084582808194682, 0.05426953613225903, 0.02353379120385008, 0.03901851503178477, 0.043335236076797755, 0.013540140852066023, 0.039694179847304306, 0.04056476402495589, 0.037983816981847794, 0.02471815372285034, 0.04082153524671282, 0.12729656217353685, 0.2003696539572307, 0.14467069559863635, 0.1332731121884925, 0.12999426812997886, 0.07675880579543964, 0.162393772442426, 0.17830410227179527, 0.11492076196840831, 0.11624846501009804, 0.13791430528674806, 0.17908767451133045, 0.15994257825825894, 0.10113212293280022, 0.10520034749060869, 0.178821023819702, 0.12066986704511301, 0.16367028680230888, 0.10460184567740985, 0.08922588931662695, 0.18103524643395627, 0.17023139473583015, 0.2232558530356203, 0.1346977236015456, 0.12218660994299821, 0.15596830365913256, 0.07369120325893164, 0.09294683965189116, 0.08307338160063539, 0.1533476657101086, 0.1350449706826891, 0.08262477495840617, 0.29649005617414204, 14.403448922293526, 54.982432978493826, 39.17466974258423, 36.201657158987864, 44.74137885229928, 43.87719317844936, 13.238615563937596, 0.7096133338553565, 0.17811047551887377, 0.2856477993939604, 0.9201878287962505, 8.67711363519941, 13.000722272055489, 4.966031261852809, 2.719052016735077, 2.264709310872214, 1.3365921761308397, 2.13816784960883, 11.323582598141261, 29.908694539751323, 56.58193956102644, 56.46508475712368, 55.06822238649641, 53.533295835767476, 51.91748183114188, 54.72893837520054, 57.59694978169033, 54.31428377968924, 51.807630811418804, 48.47742870875767, 51.31963103158133, 54.96317604609898, 53.60477542877197, 50.343266691480366, 45.79462848390852, 42.48298154558454, 43.97157055991036, 44.54603024891445, 46.23697165080479, 47.2719475201198, 50.215555327279226, 52.02579729897635, 51.89634541102818, 44.58379718235561, 41.82313544409615, 41.78965554918562, 40.83714437484741, 40.76143332890102, 41.31128249849592, 43.918184076036724, 45.76841293062483, 50.50144590650286, 49.67282806124006, 48.42000879560198, 52.59296832765852, 52.70199598584856, 54.46327747617449, 51.15792213167463, 53.58522319793701, 53.53970554896763, 51.18920292173113, 48.2512127331325, 43.3250858443124, 40.101858207157676, 38.896547249385286, 40.0935446875436, 40.34865822110857, 42.48123059953962, 39.30165154593331, 39.3188796043396, 40.71618665967669, 47.098610809871126, 53.80637393678938, 53.51892696108137, 52.07610920497349, 51.82368115016392, 49.734187602996826, 50.04184341430664, 48.88745927810669, 48.49758890696934, 51.7306204523359, 51.32386595862252, 46.264476094927105, 38.983629022325786, 40.04595300129482, 46.16468606676374, 49.177689007350374, 47.992958613804404, 46.48872920445034, 48.8726179259164, 48.36459343773978, 45.802017893110005, 45.469094957624165, 49.66385098866054, 45.76472691127232, 47.08623954227993, 46.108235427311485, 42.91084814071655, 24.972127982548304, 9.965611032077245, 2.5635821649006436, 2.4754683673381805, 4.52214298929487, 6.269129429544721, 5.311949065753391, 7.542113236018589, 11.709416934422084, 7.733657700674875, 1.1308546044996806, 0.3228919080325535, 0.12205810898116656, 5.456303971154349, 29.668401513780864, 42.34480619430542, 32.29312869480678, 36.27599940981184, 33.6562089238848, 2.393830290862492, 0.1452434334371771, 0.232602808624506, 0.12523427712065832, 0.220005439594388, 0.14586019462772778, 0.29010259892259327, 0.12268130268369402, 0.10610649708126273, 0.13342127709516458, 0.15325739341122763, 0.055358533947063346, 0.1587602717003652, 0.13245482609740325, 0.098887556232512, 0.14285881710903986, 0.17155495871390614, 0.14429049885698728, 0.15162814940725053, 0.1161338740161487, 0.13567637465894222, 0.17407064086624555, 0.16638287981706007, 0.1295534646404641, 0.11854612029024533, 0.16774809227458068], [0.012178806222176977, 0.027786992889429842, 0.025192900926672986, 0.03971844086689608, 0.04092956819970693, 0.01627843507698604, 0.06292422315371887, 0.05455592880025506, 0.014254631441352623, 0.01298638163799686, 0.06548781666372504, 0.06525480095297098, 0.04712786006608179, 0.04573445447853633, 0.020747488930023143, 0.031018604125295366, 0.03831020250384297, 0.08213949349841901, 0.062034161628357, 0.04167999739625624, 0.06029967005763735, 0.027635669402245964, 0.026843567977526357, 0.07382510535951171, 0.04130002796383841, 0.05459740086059485, 0.018165427393146923, 0.07358397436993462, 0.018271646961303692, 0.06646442533071552, 0.011177419152643, 0.031630795382495434, 0.04029257309490016, 0.4629684058683259, 15.82870510646275, 42.16743605477469, 29.405120372772217, 25.304590599877493, 36.89156811577933, 36.79343523297991, 9.453158804348536, 0.7577019248689923, 0.07698215916752815, 0.27682396716305185, 0.9977363475731441, 4.845563394682748, 1.495476416179112, 0.8989939774785722, 0.7043723836541176, 0.6402132606932095, 0.2527127138205937, 1.8881325806890215, 15.541061844144549, 42.68586547034127, 57.42095538548061, 55.5872597694397, 52.716851234436035, 51.190981660570415, 51.38839735303606, 53.872948101588655, 51.86960179465157, 49.95780495234898, 50.21324505124773, 50.84832082475935, 51.71450410570417, 50.01401240485055, 45.401332650865825, 43.0589142526899, 40.58655064446585, 40.958056926727295, 43.2517580304827, 43.259491375514436, 44.43410171781267, 48.6259742464338, 48.60371221814837, 46.95604419708252, 45.14810902731759, 41.88465826851981, 39.25967747824532, 38.413661343710764, 38.20193583624703, 38.17042922973633, 38.919142791203086, 44.8915433202471, 52.02699933733259, 49.7997716494969, 50.94994865145002, 49.81099993841988, 52.618040902274, 46.40439544405256, 42.92580761228289, 51.30149623325893, 49.68237836020333, 48.11864457811628, 47.884594508579795, 44.92680195399693, 42.31636026927403, 40.126135213034495, 37.39639643260411, 35.73427963256836, 34.46740068708147, 35.39469337463379, 34.705991404397146, 41.74022259031023, 47.21251957757132, 51.11953680855887, 49.23642560413906, 49.13581221444266, 48.6749382019043, 49.564509119306294, 48.47953053883144, 48.958150250571116, 47.875704288482666, 48.66195201873779, 46.52420323235648, 43.83302000590733, 36.35508033207485, 38.07864352634975, 43.24367380142212, 44.99923692430769, 47.73035839625767, 46.091789041246685, 45.21235901968819, 45.106656074523926, 45.365768296378, 45.06058604376656, 46.23560632978167, 47.36795425415039, 45.72849552971976, 43.927216734204976, 25.285083532333374, 10.367766686848231, 1.2892522535153796, 0.27868160605430603, 0.7309743762016296, 1.6799099424055643, 2.4336141560758864, 1.1781159256185805, 2.7667351152215685, 2.6783633657864163, 0.7763886707169669, 0.03240651697186487, 0.051321077559675486, 3.178316218512399, 24.41473306928362, 33.81521150044033, 32.54493835994175, 24.7234172139849, 30.9759031023298, 6.3502344489097595, 0.07341338388089623, 0.01823347936650472, 0.007559672297377671, 0.03137205640918442, 0.04351497661056263, 0.05381592868694237, 0.05248996608757547, 0.029675410129129887, 0.009765490407257207, 0.054512651836765666, 0.05111253660704408, 0.01863993880605059, 0.014839377653385912, 0.03501940944365092, 0.018826781905123165, 0.021918976247044544, 0.0509006199426949, 0.026959627999791076, 0.0364921289895262, 0.038146108987608125, 0.0634410564920732, 0.008973152343449848, 0.07888623021010842, 0.02720292012340256, 0.03159850050828286, 0.060543508401938846, 0.009802055811243398, 0.059449391040418825, 0.021305957177121724, 0.05123901553452015, 0.01592729490117303, 0.013917162049827831, 0.026362216931634715, 0.058593541250697205, 0.10105818297181811, 0.039644005575350354, 0.005280002011984054, 0.039024075626262596, 0.014754762640222907, 0.05806515246097531, 0.052401295131338496, 0.038986006419041326, 0.011134944556813155, 0.025378497217648795, 0.0630615179293922, 0.01811619458853134, 0.016393597736688595, 0.0564055881196899, 0.04762555193156004, 0.018900715080755096, 0.04236104299447366, 0.05844830761530569, 0.0778622937255672, 0.02021548694132694, 0.02119075719799314, 0.08430976061416523, 0.03622967503698809, 0.06931548698672227, 0.0788169585700546, 1.031216025352478, 24.08777689933777, 44.59679378782, 28.270941598074778, 29.450655392238072, 50.21270309175764, 40.057139601026265, 8.557153855051313, 0.4811136264886175, 0.01534367844994579, 0.12721205742231437, 0.36733027920126915, 2.6637172145502905, 6.729240443025317, 2.1780837305954526, 0.9797026238271168, 1.4102074716772353, 0.5784242334110397, 2.7374397729124342, 17.89193967410496, 44.91264499936785, 57.78662518092564, 57.13572488512312, 54.31158093043736, 51.99981451034546, 52.35712562288557, 54.91014392035348, 53.95721238000052, 49.03303793498448, 49.65078837530953, 52.33170216424124, 53.15368447984968, 51.35782527923584, 46.45189332962036, 44.2150354385376, 42.26801470347813, 42.62530844552176, 45.46005882535662, 45.62113543919155, 47.15462371281215, 49.801810945783345, 48.89026982443673, 49.775175026484895, 47.59735597882952, 43.711093017033164, 41.59314659663609, 40.331211294446675, 40.18153320040022, 40.702755791800364, 41.153579235076904, 45.61592081614903, 53.023850440979004, 50.2891332762582, 53.70649010794503, 51.94276285171509, 55.416327135903494, 49.031679562159944, 45.59526382173811, 53.63513905661446, 52.141422271728516, 51.62708534513201, 48.82299736567906, 45.78954587663923, 42.69533239092146, 41.43412664958409, 38.70113958631243, 39.44706344604492, 37.71432515553066, 38.135035106113975, 37.55984238215855, 41.36064944948469, 48.64847946166992, 52.8126425743103, 51.65823064531599, 50.549899169376914, 50.73521457399641, 50.38056462151663, 48.82535627910069, 48.60796798978533, 48.69132552828108, 49.91222129549299, 48.34638915743147, 46.03778069359915, 37.837554931640625, 38.75479704993111, 44.425409521375386, 45.69286516734532, 48.00696965626308, 46.55988918031965, 46.90236588886806, 45.00489623206002, 45.217000416346956, 45.947478430611746, 47.90300376074654, 47.29898643493652, 46.86599554334368, 43.577124800000874, 29.28305789402553, 12.362435562270027, 2.220302070890154, 1.1273733398744037, 1.4967909285000391, 2.7724719388144354, 4.642879664897919, 5.1957456554685315, 3.620685658284596, 0.36535126396587914, 0.16915656812489033, 0.022469765174069574, 0.07549751097602503, 2.306086702006204, 24.839085612978252, 36.01342003686087, 31.41890982219151, 25.6687422139304, 35.214825357709614, 10.465852669307164, 0.06665512759770666, 0.0422681481577456, 0.03765255279306855, 0.05836091909025397, 0.05011726144169058, 0.015803460563932146, 0.03600000789655106, 0.04835064123783793, 0.03902919856565339, 0.020786855835467577, 0.017464093597871915, 0.037471173597233634, 0.03489301533305219, 0.025624111627361605, 0.13228911427514894, 0.03653084619769028, 0.033229135509048185, 0.020888788758644035, 0.018718143359624913, 0.016873116738029888, 0.043336454047156234, 0.06121951927031789, 0.08467152834470783, 0.04097707922171269, 0.052514542625950913, 0.05983006275658097, 0.05705530236342123, 0.14625588910920279, 0.08753019637827363, 0.17804807743855885, 0.1830348348511117, 0.05438877169841102, 0.11092480817543608, 0.12465184980205127, 0.14478411951235362, 0.13504157800759586, 0.1254564837685653, 0.10762267000973225, 0.1185940248625619, 0.16639072368187563, 0.15835707262158394, 0.1995899493673018, 0.08292390033602715, 0.15217449223356588, 0.17102731631270476, 0.15734548547438212, 0.14074503124824592, 0.19441663553672178, 0.08287043856190783, 0.17010942128087791, 0.09441807320607559, 0.1747282634356192, 0.11054951724197183, 0.10215812216379813, 0.09004675384078707, 0.16696080166314328, 0.18395999020763806, 0.1760482583194971, 0.1636423718716417, 0.786461604493005, 25.570070845740183, 54.60703917912075, 40.1579510143825, 34.18751335144043, 47.22791678564889, 47.310082708086284, 13.605043581553868, 1.36287645144122, 0.20953236014715262, 0.614459111222199, 2.7492009018148695, 8.856559549059186, 8.911568437303815, 6.276221368994031, 2.975802719593048, 1.4570999954427992, 0.835507906973362, 2.5777905796255385, 18.233506168637955, 45.80960532597133, 60.820514406476704, 59.889893531799316, 56.67455210004534, 55.96438019616263, 55.31521347590855, 57.97235400336129, 54.74552372523716, 49.49893549510411, 52.47307021277291, 53.32740681512015, 54.7468820980617, 54.73278420312064, 49.01784917286464, 48.069152559552876, 44.202316761016846, 45.88708816255842, 47.92903866086687, 47.54140560967581, 49.1101837839399, 53.06498725073678, 52.43722445624215, 49.953889642442974, 49.49243198122297, 46.14508867263794, 44.342409815107075, 42.550563199179514, 42.70065123694283, 42.43254804611206, 43.691773550851, 48.46578352791922, 56.48253863198416, 52.91243607657296, 56.04437828063965, 54.97820847375052, 57.70270831244332, 49.18824332101004, 46.52246618270874, 54.86079781396048, 54.0832005909511, 51.97796242577689, 51.85292959213257, 49.8825490134103, 46.253869669778005, 45.518590450286865, 41.06443384715489, 40.06065886361258, 40.006709575653076, 39.024883951459614, 40.04512963976179, 44.343952315194265, 51.527156352996826, 55.38876363209316, 52.05549389975411, 50.33076340811593, 49.1978040422712, 51.98796088354928, 49.83413743972778, 50.007658277239116, 49.56305347170149, 50.81445530482701, 50.10709047317505, 46.793650899614605, 39.2122733933585, 41.896935735430034, 46.749060835157124, 47.60254280907767, 49.25664833613804, 47.30746323721749, 47.80534682955061, 46.917478220803396, 45.954749720437185, 47.21361739294869, 47.702423163822715, 49.93571662902832, 49.01817921229771, 45.77627829142979, 28.464813709259033, 12.931898627962385, 1.8271990503583635, 1.6231700841869627, 1.995486157281058, 4.460640140942164, 5.606983474322727, 7.967540144920349, 8.818689261163984, 8.662032570157733, 1.9303166142531802, 0.15287788877529757, 0.21897080939795288, 5.250939973763057, 32.09436852591378, 43.53571353639875, 40.27298191615513, 33.62270818437849, 44.16942746298653, 10.948981761932373, 0.20442487778408186, 0.14860622584819794, 0.11633621315870966, 0.17574986575969628, 0.19938584603369236, 0.1660949366965464, 0.16259916499257088, 0.0939182982380901, 0.08665861136146955, 0.15567742926733835, 0.14270012133887836, 0.14165570666747435, 0.14212165666478022, 0.14615374244749546, 0.1692507080733776, 0.12886443947042736, 0.2034112007490226, 0.12343242737863745, 0.10190205661846058, 0.09420504035162074, 0.18503333761223725, 0.15988803761346, 0.1471893633050578, 0.09279607595609767, 0.16378265220139707, 0.29923188047749655], [0.06989579049072095, 0.07480655876653534, 0.030882255905973058, 0.018172972702554295, 0.027230560247387205, 0.010237262235023081, 0.04383765733135598, 0.04189015326223203, 0.05268641893884965, 0.026113542328987802, 0.0711711241996714, 0.057658126444688866, 0.05678531667217612, 0.007812429136330528, 0.011959610573415245, 0.016285912532891546, 0.04184913921302982, 0.01283977651369891, 0.06317666532205683, 0.046412958963108916, 0.09482236472623688, 0.01593985628070576, 0.034637048175292354, 0.07231786873723779, 0.02426255477725395, 0.007811250181735626, 0.0693885109254292, 0.012361676498715366, 0.05366802162357739, 0.007000023399346641, 0.06991035185222115, 0.030364041748855795, 0.026607565016352704, 0.09049750465367522, 1.4721196123531886, 21.88314822741917, 39.171991212027415, 27.951762199401855, 28.003649609429495, 36.87500361033848, 32.95469447544643, 13.072883657046727, 1.482343778014183, 0.039433004933276346, 0.5013099770460809, 2.012421957084111, 5.901318286146436, 1.5809139630624225, 0.533533225102084, 1.1564339633498872, 0.11571148596704006, 0.28325569203921724, 8.447086572647095, 27.176266806466238, 48.662587778908865, 56.0110581942967, 52.443738392421174, 53.77321713311331, 50.936917304992676, 54.746385301862446, 52.8389310836792, 49.715020997183665, 49.46740109579903, 53.75218146187918, 52.6057391166687, 50.27328096117292, 45.27928406851632, 42.625947679792134, 43.64351136343819, 43.66997010367257, 42.253784792763845, 44.669381618499756, 44.47583954674857, 44.86801324571882, 47.263700008392334, 46.117747511182515, 44.39252369744437, 42.22370604106358, 40.36890527180263, 40.196794918605256, 37.02649865831648, 37.52551480701992, 37.49100310461861, 49.184182098933626, 52.43339252471924, 53.07974522454398, 52.08925519670759, 51.90619100843157, 49.51809515271868, 49.83004147665841, 41.29309906278338, 53.53665181568691, 50.267364570072715, 50.39956447056362, 48.690825257982524, 48.00517702102661, 43.84959493364607, 42.877475942884175, 40.22388594491141, 36.67148739950997, 37.10446092060634, 35.6259572165353, 38.2651366506304, 45.96862874712263, 50.18462542125157, 49.33896017074585, 49.16524478367397, 49.13822671345302, 49.67216450827462, 51.34106969833374, 50.397733620234895, 50.00435093470982, 49.513863699776785, 48.37209749221802, 46.33808878489903, 41.572649410792756, 37.80781316757202, 36.56895978110177, 43.208158084324424, 47.348961353302, 48.32651730946132, 46.40391949244908, 47.16479934964861, 45.35428292410714, 46.07039901188442, 46.977357796260286, 47.04456772123064, 45.2924404825483, 43.19258369718279, 28.898607117789133, 12.571304491588048, 1.1103344027485167, 0.3309014710996832, 1.0708810112306049, 1.3798565460102898, 1.3541958715234483, 3.7794952051980153, 2.8057976705687384, 2.5717619316918507, 0.23623869780983242, 0.04980577315602984, 0.15730150283447333, 4.15532283272062, 25.94100390161787, 33.009613037109375, 38.24836022513253, 27.82026580401829, 28.412980147770472, 15.83884252820696, 0.14886565692722797, 0.033927453216165304, 0.020996509585529566, 0.021805211369480406, 0.000499678064703143, 0.03053460848916854, 0.04096162219398788, 0.02470259152219764, 0.03316808092807021, 0.046059306511389356, 0.02963930188811251, 0.03404116889994059, 0.06202430251453604, 0.0329053725249001, 0.06387050809072596, 0.03781743680260011, 0.01328368260458644, 0.0629394698355879, 0.013330129174781697, 0.051162361433463435, 0.014661733792828662, 0.06565477020506348, 0.030479748932910816, 0.04108960068385516, 0.034010064854685745, 0.008211285590992441, 0.03017436746241791, 0.04245715747986521, 0.004986931287151362, 0.047044559714517424, 0.019266224931925535, 0.01378295715299568, 0.07335462953363146, 0.03769666774730597, 0.03874120116233826, 0.033273718652448485, 0.030526147157485996, 0.026997569981696348, 0.038926570144082816, 0.030996219255030155, 0.02642754458689264, 0.007562463620810637, 0.020275769688721215, 0.02128329241116132, 0.02489117845626814, 0.12214231517698083, 0.05870073621294328, 0.055533595981874635, 0.02068781347147056, 0.07734107705099241, 0.018472050582723956, 0.014640351458053504, 0.09632493981293269, 0.04538055096885987, 0.017978584294074347, 0.011892908036575785, 0.014353304003764476, 0.02636395737395755, 0.06972301511892251, 0.05197166372090578, 0.08115894254297018, 3.215448260307312, 30.93061821801322, 42.570407254355295, 25.264461278915405, 27.9379700251988, 46.96110248565674, 37.87122590201241, 12.341991356440953, 1.0617952644824982, 0.07035723501550299, 0.31263414131743567, 0.2352825062615531, 2.6901716121605466, 3.8538500496319363, 3.7478379096303667, 2.685724113668714, 0.5285957157611847, 0.9226904830762318, 9.092238971165248, 29.757098742893763, 52.260719367435996, 58.03940759386335, 54.80841187068394, 53.67964226858956, 54.58157055718558, 56.21394211905343, 53.464797019958496, 51.122389044080464, 51.253536292484824, 55.03961665289742, 52.943491050175254, 52.30187702178955, 47.4694813319615, 45.65586600984846, 45.4475485937936, 45.17391116278512, 45.81355537687029, 46.257659912109375, 47.441104888916016, 47.97360093252999, 49.040712220328196, 47.11000238146101, 45.422187668936594, 43.657723903656006, 43.44868040084839, 40.850370270865305, 39.22025339944022, 38.94571965081351, 39.520839418683735, 50.450585092817036, 53.342435768672395, 53.361567633492605, 52.442015239170615, 52.15686811719622, 51.72976234980992, 51.401175090244834, 43.84714221954346, 53.598449093954905, 52.494564465114046, 50.56729051045009, 50.080958298274446, 49.821060929979595, 44.93833596365792, 45.06756550925118, 40.138562066214426, 37.743726457868306, 38.18796648297991, 37.13593626022339, 38.384753363473074, 46.771253381456646, 51.75862864085606, 50.178055899483816, 49.24641016551426, 49.9617098399571, 49.8859293120248, 50.95864084788731, 50.41824817657471, 50.108768463134766, 49.68808283124651, 49.419521059308735, 47.33154916763306, 43.17150633675711, 39.57804046358381, 38.79560382025582, 45.69658940179007, 47.88470567975725, 48.40310730252947, 47.03728253500802, 48.92876631872994, 45.80607911518642, 46.52088199343, 47.49103464399065, 48.31649800709316, 45.597660950251985, 44.181812626974924, 33.53103017807007, 14.832798957824707, 3.030595996550151, 0.738940811582974, 1.5258055201598575, 2.330638595989772, 2.475686149937766, 5.221799663134983, 3.5825925937720706, 1.0491500858749663, 0.32592352107167244, 0.11921822279691696, 0.10017031989991665, 3.27933412364551, 27.080663067953928, 40.66239718028477, 40.39593376432146, 30.14383200236729, 31.473105771201, 22.82694114957537, 0.5456850816096578, 0.02537237343910549, 0.01289707625151745, 0.009607502858021429, 0.006303695920256099, 0.04434373588966472, 0.06012753929410662, 0.03793450105669243, 0.018104881713432924, 0.07723265394036259, 0.050346857335950644, 0.058075866528919766, 0.08122593430536133, 0.06550848484039307, 0.05505777669272252, 0.0649997599955116, 0.04757783395637359, 0.03514656012079545, 0.03166015220007726, 0.05342001707426139, 0.004450910250722829, 0.05754135735332966, 0.017485752435667173, 0.03462581502805863, 0.04738953370334847, 0.0034409944200888276, 0.10964489435510975, 0.17750151748103754, 0.18512198142707348, 0.12815995727266583, 0.056120837506439, 0.11474199513239519, 0.10501222365668841, 0.09051513977880989, 0.1247523408383131, 0.16202057818216936, 0.1077158192970923, 0.1258562630308526, 0.1402808047298874, 0.16891456182513917, 0.11855362488755158, 0.14963639128421033, 0.13681339578969137, 0.19619078747928143, 0.1487478632479906, 0.14517608205122606, 0.19032878774617398, 0.2331802419253758, 0.07270014858139412, 0.157741939915078, 0.12376001051494054, 0.13853964315993444, 0.18641041086188384, 0.14312997327319213, 0.07335945391761405, 0.08394101754363094, 0.12250286154448986, 0.09624703720744167, 0.11300990557564156, 0.2150064685514995, 0.2336081261081355, 2.556204046521868, 32.65568222318377, 51.94005305426461, 37.36180135181972, 35.43811961582729, 47.3069942338126, 42.61995138440813, 17.355382408414567, 2.2232305194650377, 0.15032784560961382, 1.0072640648909976, 5.135977251189096, 11.846128821372986, 7.56485208443233, 3.230604452746255, 3.9352812000683377, 0.9718731982367379, 0.6595831555979592, 10.432947737830025, 30.339635712759836, 52.45246185575213, 59.196657861982075, 55.62814991814749, 56.437100887298584, 56.279130118233816, 58.002801009586875, 55.49384471348354, 52.05299949645996, 51.4032039642334, 56.99122667312622, 55.408499990190776, 54.11015612738473, 48.629976408822195, 47.30350971221924, 48.23996359961373, 48.66985559463501, 47.480567182813374, 48.7097521509443, 50.7907897404262, 48.63282864434378, 52.27018976211548, 49.87000751495361, 48.72516672951834, 46.16109037399292, 46.373913696834016, 44.34898975917271, 41.36200087411063, 41.97518982206072, 40.85863167898995, 52.921051842825754, 57.14060946873256, 56.13059152875628, 53.80478974751064, 53.391486576625276, 50.44002383095877, 52.86195741380964, 47.02175331115723, 54.605149269104004, 53.83488934380667, 52.34932279586792, 52.56580434526716, 52.04545375279018, 48.85609858376639, 47.55313416889736, 43.49383674349104, 41.08624076843262, 40.01685047149658, 39.85818835667202, 41.28066873550415, 49.48704712731497, 54.5395131111145, 52.53788300922939, 51.06504208700997, 50.77215467180525, 52.07704373768398, 53.15835019520351, 52.08037887300764, 51.93427562713623, 50.85247584751674, 52.269338607788086, 49.36996303285871, 44.866908482142854, 40.19641624178205, 41.875875745500835, 47.32343714577811, 50.14284937722342, 49.55348580224173, 47.434868880680625, 49.66196455274309, 46.64071062632969, 46.64960432052612, 48.57739244188581, 47.758609771728516, 47.1373678616115, 43.820127623421804, 32.88271113804409, 14.744683640343801, 1.7262190346206938, 1.516778615968568, 2.1146508029529025, 4.546139895915985, 4.971357924597604, 7.510137626102992, 10.683030775615148, 8.373378344944545, 1.635452762246132, 0.25755742671234266, 0.2943508523915495, 6.097352155617305, 33.89357328414917, 42.3970809664045, 45.535422461373464, 36.76354060854231, 36.415908336639404, 25.921918937138148, 0.48959075446639744, 0.18538480518119677, 0.1267699104334627, 0.15410892771823065, 0.0900751030338662, 0.07865615255598511, 0.2551394264612879, 0.14900884138686316, 0.19402913775827202, 0.13962985894509725, 0.10197703473802124, 0.16494130502854074, 0.20104068437857286, 0.13853426916258677, 0.16463665637586797, 0.24685565382242203, 0.09687325039080211, 0.10368065975074257, 0.15773154475859233, 0.13430124201944896, 0.14901933153825148, 0.14082010436270917, 0.14616763884467737, 0.11566149150686604, 0.2079176910753761, 0.14370102834488663, 0.2199337998671191], [0.043498779979667494, 0.03894487701888595, 0.024812566781682626, 0.04033204347693494, 0.029924547831927027, 0.015618985552074654, 0.04193747768710766, 0.01028653999258365, 0.04895337710955313, 0.04402031895837613, 0.10652193014643022, 0.07103692354368311, 0.035778852977922986, 0.03867565128686173, 0.03697882180235215, 0.07113440866981234, 0.06497198755719832, 0.03106323137347187, 0.029733981271939616, 0.018887210537546446, 0.054939443578145335, 0.0528637133538723, 0.09601383829223258, 0.17379507422447205, 0.06776686651366097, 0.07560338279498474, 0.011450984116111482, 0.0226289206517062, 0.02416260656900704, 0.05536587908864021, 0.021957235444071035, 0.03946433968043753, 0.05543565623728292, 0.06338925712874957, 0.011279369887363697, 2.5148924461432864, 23.750077077320643, 40.160059792654856, 27.09315071787153, 27.846186058861868, 34.232193742479595, 32.71369273321969, 17.462530578885758, 2.0845846448625838, 0.08661552438778536, 0.0841758381575346, 2.785275948899133, 0.6472789272665977, 3.868165944303785, 2.4925676669393266, 0.47049417346715927, 0.4329829120210239, 0.746622696518898, 10.211896879332405, 31.75435495376587, 54.046666962759836, 58.13380929401943, 54.480244977133616, 54.572881834847585, 54.43116290228707, 52.10671949386597, 50.184580257960725, 51.05198642185756, 51.47982522419521, 52.89828954424177, 50.80171230861119, 48.20615019117083, 46.00088228498186, 42.8886729649135, 44.388653550829204, 43.584267548152376, 43.91344540459769, 43.26384789603097, 41.496722970690044, 44.31562450953892, 43.621124267578125, 43.54575368336269, 42.84124803543091, 40.89692667552403, 40.512267453329905, 37.80440507616316, 38.564173221588135, 38.47730336870466, 45.024101052965435, 52.18821838923863, 51.16990430014474, 55.5175450188773, 54.26115437916347, 50.78080865315029, 45.54264858790806, 38.97564206804548, 51.28885746002197, 52.946287700108115, 52.53322076797485, 51.424743379865376, 48.20749814169747, 45.494990893772666, 42.22876780373709, 42.15567970275879, 37.89046893801008, 36.475068773542134, 35.60467141015189, 38.98832947867257, 47.16713741847447, 50.85598121370588, 51.4268730027335, 49.6167699950082, 48.96235738481794, 50.45469495228359, 50.705042021615164, 49.946448121752056, 48.35630423682076, 48.087759835379465, 45.25538226536342, 43.754963942936485, 41.222328186035156, 37.394621167864116, 37.11685650689261, 44.19815479006086, 47.40263271331787, 49.47581189019339, 48.33623783929007, 46.84542192731585, 47.359143938337056, 46.96912418093, 44.57060602733067, 45.31883668899536, 43.775648730141775, 32.68935319355556, 13.130786470004491, 1.7326713055372238, 0.2287476169211524, 0.07409407664090395, 1.494040418948446, 1.3841153574841363, 1.5285867537770952, 6.0600972175598145, 3.782983200890677, 0.48553202939885004, 0.05670594164569463, 0.014454714454976576, 5.1006321992192944, 26.26983608518328, 39.069922174726216, 25.927185671670095, 44.10364191872733, 33.16516930716378, 22.063702378954204, 1.6370607273919242, 0.06237765641084739, 0.06278221934501614, 0.03382339647838047, 0.027748558969636048, 0.023738664674705694, 0.03573357094345348, 0.031032907643488476, 0.03396341896482876, 0.014108129793645015, 0.06956920480089528, 0.053356387452887635, 0.05847622933132308, 0.03825940737234695, 0.06741167378744908, 0.05756040383130312, 0.055808202496596744, 0.06137930069650922, 0.08674150119934763, 0.1031262491430555, 0.03999067929440311, 0.042919328037117205, 0.033331913208322864, 0.020839148833017265, 0.010595714473830802, 0.03662769689357706, 0.06405536817120654, 0.031099115697933093, 0.0684357120522431, 0.026807532679023485, 0.03536498054329838, 0.013166904183370727, 0.02517436843897615, 0.020586906832509806, 0.0061411452230199105, 0.026424784645704285, 0.014631330334980572, 0.0801647123215454, 0.0911035178495305, 0.06502593109118086, 0.016510544943490198, 0.03617170439766986, 0.0630276861733624, 0.03278951945581606, 0.04860276788739221, 0.028376380280990685, 0.01189251194175865, 0.030308004934340715, 0.013965637439728847, 0.022962050811786736, 0.033070941854800494, 0.07731771509030036, 0.03032702427091343, 0.05355898443875568, 0.0425690648678158, 0.04118597979790398, 0.019872904788436632, 0.04204790247604251, 0.01819287922366389, 0.07256708786423717, 0.01347184884694538, 0.005749170385700251, 0.05242359179205128, 5.276913642883301, 35.246304171425955, 41.31222745350429, 28.229347944259644, 30.993492467062815, 42.8560129574367, 43.160208565848215, 15.58937440599714, 1.1893512713057655, 0.07059044071606227, 0.06451130977698735, 0.42192428399409565, 1.8534441334860665, 3.633851191827229, 2.9678648369652882, 2.497542142868042, 0.7062555083206722, 1.3651079088449478, 13.682908569063459, 34.64702899115426, 56.860510213034495, 59.653439385550364, 57.717772006988525, 55.345375605991904, 55.57968275887625, 53.66679852349417, 51.05456420353481, 52.02756214141846, 53.2324457849775, 54.55625132152012, 52.04702751977103, 50.39576728003365, 48.784448759896414, 46.20004197529384, 47.80106673921858, 46.21379940850394, 45.329026222229004, 45.61439568655831, 44.06541640417916, 45.78189243589129, 46.76845325742449, 46.89367716653006, 45.16218260356358, 42.69640588760376, 42.43361112049648, 38.877151353018625, 40.69430678231375, 39.135461057935444, 48.553768566676546, 53.34299857275826, 54.10617480959211, 56.964913845062256, 54.89263098580496, 50.737938267844065, 47.14527143750872, 40.838339465005056, 51.53227022715977, 53.36196020671299, 53.83850588117327, 53.39981746673584, 50.74465717588152, 46.897721018110005, 44.312456130981445, 42.68990584782192, 38.83355835505894, 38.85273885726929, 37.595469270433696, 41.070211274283274, 49.35546909059797, 51.59810093470982, 51.40555245535714, 50.22428573880877, 50.22161763054984, 51.424673897879465, 52.699956689562114, 51.94401005336216, 50.0607042993818, 50.15915332521711, 47.00359072004046, 45.09456273487636, 43.09825842721121, 39.24635083334786, 38.529630252293174, 46.40537861415318, 48.32597882407052, 50.36693572998047, 47.73928335734776, 47.284165927342, 47.93898153305054, 46.73845788410732, 44.95883662360055, 46.89574078151158, 45.911007336207796, 35.69695738383702, 15.184099878583636, 4.078954313482557, 0.791380549115794, 0.8012413457036018, 2.7050075360706876, 2.5275040779794966, 4.47280296257564, 2.516590629305158, 1.4896342839513506, 0.07728739814566714, 0.04939699651939528, 0.023764728901109526, 3.6447752799306596, 24.37270862715585, 44.98453801018851, 29.68194702693394, 44.90352201461792, 35.24228116444179, 27.92606254986354, 4.138281941413879, 0.033552291204354594, 0.010806990770756133, 0.07292318982737404, 0.010632491920010319, 0.042702807512666495, 0.04025677019464118, 0.007527162836465452, 0.043599070848098824, 0.013225535546163363, 0.060828085988759995, 0.048934941313096454, 0.06409074698707887, 0.09175000565924815, 0.024285088925223266, 0.032130478748253415, 0.05685449331732733, 0.06838847922959498, 0.07613113376178912, 0.07262873277068138, 0.012827493333523827, 0.06970702204853296, 0.0808309997831072, 0.019716689063768302, 0.011596853878082973, 0.02182760981044599, 0.031110793285604035, 0.014310354433421577, 0.10340184971157994, 0.1215932582105909, 0.10089554491319827, 0.12518227419682912, 0.11599390581250191, 0.081947122035282, 0.09590067900717258, 0.11156861577183008, 0.1669801670525755, 0.15520094840654305, 0.19113891784633907, 0.14979583344289235, 0.16704337937491281, 0.12249186927718775, 0.14802831757281507, 0.15495002615664685, 0.19913241320422717, 0.08670859903629337, 0.09742314195526497, 0.11407301388680935, 0.19246219683970722, 0.09083270095288754, 0.23651334164398058, 0.20109865841056618, 0.18720767593809537, 0.1819144513990198, 0.12163676587598664, 0.1307701457824026, 0.19897584803402424, 0.1453948010291372, 0.0874977759750826, 0.1370348831904786, 0.21846017108431884, 0.1890290267765522, 0.12613896786102227, 4.730314927441733, 36.8294164793832, 51.80770376750401, 37.44238655907767, 37.143033845084055, 41.52549198695591, 42.536458356039866, 22.30174592563084, 3.5802026305879866, 0.49472102203539436, 0.2651446967252663, 5.089476432119097, 9.138669439724513, 10.68219178063529, 7.826761824744088, 3.346793532371521, 1.671282668198858, 1.4851515016385486, 11.510540383202688, 34.804853848048616, 59.363178389413015, 63.27490302494594, 59.765020506722585, 57.43500116893223, 58.16944660459246, 53.970945494515554, 51.67183869225638, 52.65250049318586, 52.92774295806885, 56.30437292371477, 55.81215558733259, 52.740054743630544, 51.13292251314436, 49.220017433166504, 49.89044564110892, 48.54498256955828, 48.40214845112392, 47.772124017987935, 45.09213433946882, 48.713875906808035, 47.82751158305577, 48.750645773751394, 47.43293380737305, 44.01550054550171, 43.731169836861746, 42.670846939086914, 41.95935140337263, 42.14518444878714, 48.99064350128174, 55.99242312567574, 56.09318937574114, 60.127494130815776, 56.87059204918997, 52.33902209145682, 45.27563279015677, 43.34915093013218, 51.72390849249703, 56.226417609623496, 57.260799407958984, 55.774478980473106, 51.95293154035296, 49.7513496535165, 45.89674268450056, 46.41136448723929, 42.05160958426339, 40.78948320661272, 39.005067689078196, 41.73957640784127, 53.179917403629844, 52.88647413253784, 52.72643280029297, 50.17744098390852, 50.05669171469552, 51.969951152801514, 54.21166236060006, 52.50163425718035, 51.61192437580654, 52.13603046962193, 48.13603939328875, 46.96162707465035, 43.77245255878994, 42.29621744155884, 40.392188685280935, 48.36275911331177, 50.774485792432515, 52.933065278189524, 50.461629254477366, 48.288899762289866, 48.291946547372, 47.60759762355259, 44.672657694135395, 47.470148359026226, 44.854321820395334, 35.992981910705566, 14.659839187349592, 2.964707314968109, 0.9058819221598762, 0.8474047971623284, 3.990486374923161, 4.646545273917062, 6.003036439418793, 13.25074451310294, 11.200715865407672, 1.687426807624953, 0.1890373049037797, 0.18162710538932256, 6.953417122364044, 34.094021865299766, 48.829188210623606, 33.79922022138323, 48.49725191933768, 41.724266052246094, 34.17488500050136, 3.4712153588022505, 0.17654152613665375, 0.1250285453030041, 0.1489903988050563, 0.10790831968188286, 0.10088615398854017, 0.2028996396277632, 0.10367135025028672, 0.11093759856053761, 0.11651386719729219, 0.20388677237289293, 0.15733553815100873, 0.14713185067687715, 0.16537507889526232, 0.12914607221526758, 0.12429713883570262, 0.10830489625888211, 0.2565521092287132, 0.15584232684757027, 0.22725729617689336, 0.17506649957171508, 0.20640373017106736, 0.1747498001371111, 0.07980463414319924, 0.13254775825355733, 0.07368521179471697, 0.1547230426222086, 0.0911388016705002], [0.009036797231861522, 0.02860234092388834, 0.03593317558988929, 0.09690989806715931, 0.03730100719258189, 0.019051144598051906, 0.03808893562693681, 0.03549300653061696, 0.025845290294715335, 0.04127243533730507, 0.03053032693320087, 0.03058929501899651, 0.06320975068956614, 0.04668946198320814, 0.08209500874259643, 0.033957854977675846, 0.05763560586741992, 0.055293279234319925, 0.10475297578211341, 0.024399226997047663, 0.05983889728252377, 0.027824553195387125, 0.0432314948577966, 0.012733472128664809, 0.06678438851875917, 0.018340138286086063, 0.07836461319987263, 0.0397867591652487, 0.015490806894376874, 0.03888800221362284, 0.020185080090803758, 0.005445295262948743, 0.026079432373600345, 0.08879237329321248, 0.04650556881512914, 0.0434827597678772, 2.020089077098029, 24.22638303892953, 38.91640520095825, 29.554979119982036, 26.853974614824565, 32.681508677346365, 42.37043115070888, 20.30034164019993, 4.115560029234205, 0.2892686522432736, 0.06698706692882947, 1.0768957627671105, 3.6737592560904364, 1.249806895852089, 0.9787621200084686, 1.1202668526342936, 0.38238151584352764, 0.8341684245637485, 12.172459653445653, 34.21570219312395, 54.28113045011248, 55.82780987875802, 54.794119426182334, 57.51912995747158, 54.53481960296631, 50.03176852634975, 48.63529178074428, 52.14847469329834, 54.10788754054478, 52.42328984396798, 50.27635553904942, 48.05146592003958, 46.7737512588501, 45.84686851501465, 46.0458197593689, 44.75980200086321, 42.82885592324393, 39.32787752151489, 40.604379722050254, 43.43395716803414, 41.6595435823713, 40.727838788713726, 40.55003091267177, 40.027793884277344, 38.845345973968506, 37.122074604034424, 37.28880705152239, 39.536993980407715, 45.47392048154558, 51.38824449266706, 50.44136830738613, 53.073391096932546, 54.72525930404663, 35.87994514192854, 32.44320631027222, 51.89874948774065, 51.82091576712472, 51.044989585876465, 50.66541644505092, 48.541122845241, 45.98726034164429, 41.86695425851004, 39.90006514957973, 37.831440516880576, 38.29198448998587, 37.4422093800136, 42.6728514943804, 51.48070069721767, 51.27956077030727, 50.45691837583269, 50.71682964052473, 49.923869950430735, 51.41868107659476, 52.21189437593733, 49.18261528015137, 47.880196298871724, 48.42242329461234, 45.62242433003017, 45.56615434374128, 41.10811022349766, 38.80901036943708, 36.89641101019723, 43.69734253202166, 48.22683150427682, 47.40470675059727, 49.307776655469624, 49.2737443787711, 48.225056239536826, 47.10425969532558, 47.44786548614502, 43.73390742710659, 28.113721234457834, 10.864533356257848, 1.1281297164303916, 0.6173923366836139, 1.0653514393738337, 0.7382439832602228, 1.5500962053026472, 1.6253092608281543, 2.376468696764537, 1.285462879708835, 0.3459395170211792, 0.01612069604120084, 0.09697330037930182, 5.069890763078417, 29.089133671351842, 35.930013860974995, 23.857258251735143, 23.776895386832102, 33.49414913994925, 25.440301077706472, 5.541818925312587, 0.03871101653203368, 0.04278673890179821, 0.036068648499037535, 0.05869743174740246, 0.04870855488947459, 0.03383177299318569, 0.0374140579120389, 0.009075148031115532, 0.03754141554236412, 0.030862340903175727, 0.05457650876737066, 0.029570155777037144, 0.022574171357389008, 0.027516394820330397, 0.03276097348758152, 0.01783465514225619, 0.042090127710253, 0.02402016510521727, 0.0329101867308574, 0.038630881546331305, 0.05130084703809448, 0.042828808072954416, 0.02910881642518299, 0.02196098435004907, 0.02793532912619412, 0.021502206467890313, 0.01841766430464174, 0.01111091423912772, 0.031818956535841735, 0.01696364179120532, 0.01905843715316483, 0.04760755379019039, 0.026662997934701185, 0.011055063173573996, 0.030920321720519235, 0.047906645241060426, 0.030819182683314596, 0.05395511318264263, 0.056096657911049466, 0.02594384750617402, 0.06365845232669796, 0.013046446406016392, 0.12048077290611607, 0.023756589873560836, 0.018219443869643977, 0.06187860068998166, 0.0983733216832791, 0.03523899016103574, 0.014888456091284752, 0.06852109211363963, 0.0447054595154311, 0.04689946857147983, 0.05085369924615536, 0.025250277847849896, 0.026805795629375746, 0.03759367630950042, 0.019979655310245495, 0.010956573815617179, 0.03240827437756317, 0.007245209483828927, 0.027076651541782275, 0.01833546317980758, 0.0562913296078997, 0.06432227670614209, 5.195585412638528, 34.00158650534493, 41.10238490785871, 31.44258233479091, 27.53199894087655, 38.137060506003245, 51.67226600646973, 20.152779272624425, 2.9434032695634023, 0.19488729456705706, 0.062229152236665995, 0.4260430729814938, 1.5760591264281953, 2.5139772381101335, 3.0666853742940083, 2.133117594889232, 0.7180342791335923, 1.3318836859294345, 14.038278528622218, 38.55400800704956, 56.93241712025234, 56.890144280024934, 56.07691669464111, 56.61493655613491, 52.47841337748936, 51.20555550711495, 50.37501648494175, 52.18652650288173, 55.492062500544954, 53.5472617149353, 51.552725723811555, 51.54337692260742, 49.80657393591744, 47.84411082948957, 46.08573716027396, 45.94437605994088, 43.79983193533761, 41.297625814165386, 42.71173708779471, 45.11226674488613, 44.153557777404785, 43.17194059916905, 43.759723458971294, 42.315550804138184, 38.55751684733799, 40.263209274836946, 41.335663727351594, 42.570268290383474, 49.71896757398333, 51.488128321511404, 52.91862344741821, 55.47397633961269, 56.29848779950823, 36.973820890699116, 34.568292004721506, 52.989936283656526, 52.89437076023647, 52.50053644180298, 53.02393381936209, 50.354533195495605, 47.409983907427105, 42.49973017828805, 41.24480560847691, 40.49606772831508, 40.01790312358311, 38.12490463256836, 43.9054445539202, 52.42041328975132, 52.62901905604771, 50.87445994785854, 51.39771836144583, 51.00849764687674, 52.15023258754185, 53.44009269986834, 50.627652985709055, 49.22942181995937, 48.571931157793315, 46.433039392743794, 45.936302253178184, 42.29658222198486, 40.513288838522776, 36.978149618421284, 45.22928830555507, 49.30224936349051, 48.448534624917166, 51.0351231438773, 48.34792470932007, 46.9816517829895, 48.23881714684622, 47.97661297661917, 45.191507475716726, 31.824823583875382, 15.095190729413714, 2.6624205069882527, 1.2496133233819688, 1.8430055507591792, 1.9208944227014269, 2.9093623076166426, 3.9671256627355302, 4.552659043243953, 1.0748438728707177, 0.20228538901678153, 0.018938906424279724, 0.13032490467386587, 3.710522174835205, 26.878046648842947, 45.29848541532244, 31.2010976927621, 25.53038099833897, 38.702595233917236, 33.00008705684117, 10.161515491349356, 0.04508919481720243, 0.01257373480724969, 0.09567715600132942, 0.103729541413486, 0.006466032878961414, 0.02481152692676655, 0.021561668187912022, 0.03173533048746841, 0.07313348818570375, 0.02371072260263775, 0.05135054633553539, 0.023930079403466413, 0.049835452277745516, 0.056736587679811885, 0.017391620968867625, 0.03999124926381877, 0.0028003644880040413, 0.02406933005633099, 0.03309989155137113, 0.029435771916593825, 0.03403175422655685, 0.05165654866557036, 0.01476484227792493, 0.01246631083943482, 0.08736947178840637, 0.015411991659285766, 0.06890318196799074, 0.03580989256235106, 0.1527065858244896, 0.12751666536288603, 0.1550480473254408, 0.1662665789148637, 0.15059772612793104, 0.08839279080608062, 0.11551619001797267, 0.15188232862523623, 0.13831735508782522, 0.11141460189329726, 0.1508591520999159, 0.12833378437374318, 0.21926913410425186, 0.14185102975794248, 0.2268376358385597, 0.1812364999204874, 0.11069781785564763, 0.24793164751359395, 0.2180180512368679, 0.12947782155658516, 0.10940633501325335, 0.14266592317393847, 0.13105635185326847, 0.16727344345833572, 0.1711639054119587, 0.12734158975737436, 0.16083890944719315, 0.20356374899191515, 0.058627196587622166, 0.07184954386736665, 0.08918780314603023, 0.09680496941187552, 0.1478591723633664, 0.13332518296582357, 0.22299008443951607, 0.12112299273056643, 3.992910861968994, 35.2326648575919, 52.60415840148926, 41.16199697766985, 38.034449509211946, 38.784445013318745, 51.69802645274571, 25.877144745418004, 6.003646143845149, 0.5920282091413225, 0.28481716396553175, 3.5443601310253143, 11.017843621117727, 6.254931654248919, 3.7360168525150845, 4.091061549527304, 2.1759521535464694, 1.5624150357076099, 12.823690857206072, 36.626275471278596, 56.325623989105225, 60.17187227521624, 57.42645835876465, 60.20649514879499, 54.249602999006, 53.15030418123518, 51.870095116751536, 54.02633653368269, 57.245562008449006, 56.12099606650216, 54.77921206610543, 54.66569239752633, 50.68076154163906, 49.49513135637556, 50.32521179744175, 48.90860264641898, 46.238288334437776, 42.59850924355643, 45.30572196415493, 48.20166860307966, 46.56670536313738, 46.40595531463623, 47.30621950966971, 45.08662094388689, 41.021521772657124, 43.40756096158709, 43.161084038870676, 45.05038608823504, 50.73285218647548, 54.937137671879356, 53.2193032673427, 55.47791249411446, 56.817813532693044, 40.57123681477138, 37.75562524795532, 52.59009872164045, 51.98092235837664, 53.53620365687779, 55.82620137078421, 51.590020179748535, 49.93263162885393, 46.17946835926601, 43.920688901628765, 40.81447240284511, 41.823482854025706, 40.60564429419381, 45.513841356549946, 55.4897244317191, 55.11494207382202, 51.31940868922642, 50.65212106704712, 51.58664682933262, 54.58254677908761, 55.75561809539795, 52.900057860783164, 50.87604413713728, 50.47863149642944, 48.527896949223106, 49.23582805906023, 43.57717343739101, 42.00212451389858, 38.80474417550223, 47.31370619365147, 51.56073352268764, 50.32275908333914, 50.93141433170864, 49.488026823316304, 48.4756430217198, 48.272588866097585, 47.33409915651594, 45.227026666913716, 30.0423709324428, 13.041338835443769, 2.0405402311256955, 1.6663431503943034, 3.0530577855450765, 2.9002388886043002, 4.26344679083143, 5.242599095617022, 9.764053344726562, 5.615189731121063, 1.0683271139860153, 0.19080106168985367, 0.4734696309481348, 6.991016864776611, 36.529271670750205, 46.14758655003139, 33.33081088747297, 33.28321920122419, 42.29226739065987, 37.65000220707485, 10.305146047047206, 0.240775572934321, 0.11172218860260077, 0.18951887477721485, 0.15759673342108727, 0.14351983235350677, 0.1526276993432215, 0.12083610812468187, 0.12307735000337873, 0.18606865991439137, 0.09388941300234624, 0.20790106696741922, 0.15080716274678707, 0.09388023242354393, 0.10058850781725985, 0.10519362999392406, 0.11079498407031808, 0.10141547237123762, 0.11770863165812832, 0.10913054445492369, 0.13269053559218133, 0.12295819925410406, 0.20092191360890865, 0.09894150655184474, 0.08185708722365753, 0.13594305249197142, 0.04628034607906427, 0.08547618266727243, 0.1488943589585168], [0.07128161684210811, 0.032287624065897295, 0.03220683768657701, 0.012632486610008138, 0.022701106599665115, 0.06418698360877377, 0.025887440890073776, 0.022009738787476505, 0.025351009764043347, 0.10814495876963649, 0.0990108528307506, 0.018802921221192394, 0.058354642641331465, 0.050347400163965564, 0.06138053563024316, 0.05013264383056334, 0.03422272451488035, 0.016683020063542893, 0.02967334059732301, 0.008675540098920465, 0.04596357200560825, 0.04963441252974527, 0.028108927221702676, 0.026461783463933637, 0.027236969010638337, 0.06295591073908977, 0.03714199929631182, 0.0323579542205802, 0.06356682295777968, 0.02713904792575964, 0.03807948702680213, 0.01693222053082926, 0.04131430434063077, 0.061583214040313444, 0.03395329522235053, 0.08528812668685402, 0.057672660664788315, 1.8412470051220484, 25.872723954064504, 40.98930644989014, 38.51445191247122, 25.95725747517177, 23.807488305228098, 44.48463944026402, 22.642820835113525, 3.237063671861376, 0.048717314776565344, 0.10821180803967373, 0.2691804330263819, 2.3265361189842224, 5.089516818523407, 0.5285447442105838, 0.752417222729751, 0.17582838583205426, 1.2338120341300964, 14.988402128219604, 39.52338940756661, 54.15908186776297, 56.14611380440848, 57.14575808388846, 55.331736292157856, 50.643877029418945, 50.30698667253767, 51.579771586826865, 54.9754569871085, 53.23163284574236, 50.246262890951975, 51.531186308179585, 49.27073580878121, 48.80180883407593, 47.435838154384065, 46.587167807987754, 46.17257227216448, 40.01745843887329, 40.95402349744524, 41.070107051304404, 41.788512570517405, 43.12468242645264, 39.72726345062256, 40.642473220825195, 39.10216876438686, 39.60588189533779, 37.2758868762425, 38.76055710656302, 41.582765987941194, 46.24049438749041, 51.03626264844622, 54.935998167310444, 54.145400864737375, 56.4116461617606, 35.76887123925345, 52.55840103966849, 53.65985032490322, 53.232174805232454, 52.60511377879551, 50.620155879429404, 46.090392453329905, 41.27078839710781, 40.27680342538016, 39.03228030885969, 38.22808885574341, 37.533248152051655, 43.67697736195156, 50.16078267778669, 51.34516218730381, 50.98719446999686, 50.65971892220633, 51.03895507540022, 52.70664780480521, 49.528159618377686, 46.813494954790386, 47.60580151421683, 47.3862419128418, 44.87493712561471, 42.86956194468907, 41.3352815764291, 40.66855328423636, 39.16398341315133, 41.02997773034232, 46.79038872037615, 46.682611737932476, 50.35185466493879, 50.492121423993794, 47.236490862710134, 48.717554977961946, 37.500240734645296, 23.792339495250157, 9.96282046181815, 1.9870853509221758, 0.159552379910435, 1.5897641224520547, 0.609358644911221, 2.213427479778017, 2.5545683971473148, 3.1340184126581465, 5.54185323204313, 0.5619444634233202, 0.026075325540399978, 0.10128843025969607, 4.362751313618251, 27.93117642402649, 31.871512004307338, 20.479843139648438, 23.44534993171692, 26.75169713156564, 21.377579927444458, 6.6778758849416455, 0.08354467845388822, 0.01927885246862258, 0.0554201551047819, 0.04325836145185998, 0.047541508584150245, 0.07944082402225051, 0.039755780648972304, 0.11816730776003428, 0.022943267266133, 0.0675075032881328, 0.018139597261324525, 0.08035458677581378, 0.03032100566529802, 0.04540728524859462, 0.023264278790780475, 0.058218080683478286, 0.04384863263528262, 0.01324731482392443, 0.024967011529952288, 0.03928876195901206, 0.03299061009394271, 0.011797675646708479, 0.022369674473468746, 0.022114523254068832, 0.04397041949310473, 0.03149675418223653, 0.04109407222962805, 0.06894333767039434, 0.0333861145856125, 0.024117575592494438, 0.03922120022720524, 0.03508972942030855, 0.017897210981962935, 0.05765900854021311, 0.05684671052066343, 0.03227320180407592, 0.04558172303118876, 0.06620905867644719, 0.08425009024462529, 0.03415350037227784, 0.014376155366855008, 0.016061853484383652, 0.07888524633433137, 0.022527103079482913, 0.087509724976761, 0.042323143421007056, 0.04128967012677874, 0.029485528889511312, 0.03779804087909205, 0.009314278190556382, 0.012660732326496924, 0.03821767068334988, 0.03792362753301859, 0.08001728023269347, 0.017761276669002006, 0.06019124016165733, 0.019148253137245774, 0.027543018838124614, 0.014215630944818258, 0.046784409388367615, 0.05649896471628121, 0.030600446742027998, 0.0360366894996592, 0.011493032083048351, 0.11135329625436238, 0.026730172901547382, 4.255831565175738, 35.11293002537319, 44.25556428091866, 37.369451318468364, 24.281886986323766, 34.5586062158857, 54.31879663467407, 22.167560577392578, 2.774866896016257, 0.15521024433629854, 0.06163307957883392, 0.015246186538466384, 2.071515951837812, 4.130806982517242, 2.3149463066032956, 1.4748127992664064, 0.05893264591161694, 1.9511696781430925, 17.116473811013357, 44.671070030757356, 55.43405546460833, 57.84394781930106, 58.155063833509175, 56.86996323721749, 53.04580674852644, 52.487077781132285, 52.222233295440674, 55.73936973299299, 55.64434616906302, 53.99015031542097, 53.07613216127668, 50.29386847359793, 49.50642565318516, 50.169978618621826, 48.083806310381206, 46.71959005083357, 42.315001896449495, 42.60047558375767, 42.76460940497262, 44.1041248185294, 44.23104061399187, 42.03266532080514, 42.678590706416536, 42.6101405279977, 40.56128004619053, 38.61402307237898, 41.32007196971348, 43.61287328175136, 50.08813231331961, 53.37466498783657, 57.259013720921104, 56.86414064679827, 55.06915691920689, 37.358045850481304, 50.7953269141061, 54.37135280881609, 54.7965339251927, 52.439451353890554, 53.025472845349995, 48.40480266298567, 43.660774162837434, 41.839696475437705, 39.63560976300921, 39.665949072156636, 39.12148475646973, 45.08283764975411, 51.54907097135271, 52.91165787833077, 51.841058594839915, 51.891954149518696, 51.76356881005423, 52.008624826158794, 50.839020660945344, 49.71881471361433, 50.00909308024815, 49.89237724031721, 45.70258569717407, 43.79296364103045, 43.61647244862148, 42.543000085013254, 40.24428585597447, 42.75608743940081, 49.539700576237266, 49.94643422535488, 50.42111430849348, 48.857759203229634, 48.11468063082014, 48.15922553198678, 40.47583457401821, 28.293570143835886, 13.895134346825735, 3.750810435840062, 0.9404698376144681, 2.6841310220105306, 2.1983040741511752, 2.874368573938097, 5.598250022956303, 3.796533925192697, 0.5353112582649503, 0.14019505147423061, 0.029745370482227633, 0.07452173690710749, 3.4185041529791693, 28.966838427952357, 42.541627815791536, 24.96134090423584, 24.209907123020717, 29.937324592045375, 29.65913609095982, 11.622582691056387, 0.2534324494855744, 0.04248273825006826, 0.10706449353269168, 0.036388608294406107, 0.05250617289649589, 0.035700071669582806, 0.038486004141824584, 0.03195099945047072, 0.00944232877476939, 0.03479691441836102, 0.051820686286581416, 0.023219417448022535, 0.05829759141696351, 0.0124008432363293, 0.03465931090925421, 0.018531215443675007, 0.021023447425769906, 0.06688427565885441, 0.04548674848462854, 0.007815589413179882, 0.05446521206093686, 0.02392801665700972, 0.03758985615734543, 0.03988802373143179, 0.028973496186413934, 0.056851823282028945, 0.03695007905896221, 0.01651296392083168, 0.05612463390986834, 0.123881264722773, 0.14838289283216, 0.09824876300990582, 0.09854689772639956, 0.10539460528109755, 0.09159122167953423, 0.12489823943802289, 0.12284033772136484, 0.1343341509678534, 0.20197229938847677, 0.1693245598248073, 0.08182139628167663, 0.1244690931801285, 0.1195391020072358, 0.08193139359354973, 0.2875918022223881, 0.07931663175778729, 0.08860629863504853, 0.17206958681344986, 0.099873644033713, 0.16179807297885418, 0.1152972403381552, 0.17974429284887655, 0.18709115790469305, 0.16662240267864295, 0.12989636909748825, 0.15393663410629543, 0.1005267339891621, 0.10368792007544211, 0.0865772550127336, 0.1503515536231654, 0.1252470471497093, 0.1564230713993311, 0.149044165919934, 0.08099126296916179, 0.18043201523167746, 0.15687697061470576, 3.3044262400695255, 35.44325433458601, 54.96204348972866, 50.492500100817, 34.8504444531032, 31.528774738311768, 54.31250851494925, 29.662954126085552, 5.418899212564741, 0.29218572857124464, 0.3803075871297291, 1.7211736653532301, 7.856846656118121, 11.660673584256854, 3.5281287048544203, 1.45708110502788, 0.44952584004827906, 1.7017839572259357, 18.026335205350602, 44.913061891283306, 58.849428585597444, 59.79924038478306, 60.09455966949463, 58.81978757040841, 53.72583736692156, 54.59468528202602, 55.30619818823678, 58.73287950243269, 56.76810611997332, 55.54226670946394, 56.96685586656843, 53.26545320238386, 53.48290055138724, 52.49307755061558, 51.549331528799875, 50.83916309901646, 44.90316765648978, 46.841534410204204, 45.52204023088728, 47.57372862952096, 47.92834036690848, 43.79191793714251, 46.19451468331473, 44.42397819246565, 42.16998256955828, 41.32161099570138, 42.29353196280343, 46.60512890134539, 50.87658609662737, 57.06654167175293, 59.507721764700754, 59.65093803405762, 58.837706974574495, 40.2501779283796, 52.93669918605259, 54.4229188646589, 57.25924301147461, 55.300684792654856, 54.80446876798357, 50.92614759717669, 45.5743601662772, 45.11404200962612, 41.764732360839844, 42.44063227517264, 40.92891270773751, 46.55408048629761, 53.44886132649013, 54.234066826956614, 51.48648854664394, 51.98003993715559, 52.574989863804404, 54.55174888883318, 52.739592688424246, 50.076740741729736, 52.734360694885254, 52.15287290300642, 48.18264096123831, 46.72534315926688, 46.02427339553833, 45.72783892495291, 42.097158500126426, 44.82907206671578, 50.402048451559885, 50.33062791824341, 52.48046309607369, 48.80034623827253, 48.01755176271711, 49.56023250307356, 39.710111822400776, 26.158677067075455, 12.416672331946236, 3.254302803959165, 0.9982789584568569, 3.307141900062561, 3.290633414472852, 4.591155971799578, 9.51159576007298, 8.171692984444753, 10.421827145985194, 2.051102578639984, 0.1466008834540844, 0.2726755669074399, 6.338520220347813, 34.726759569985525, 40.12572526931763, 28.514918906348093, 33.10598455156599, 37.40689516067505, 32.65447323662894, 11.268902012280055, 0.31177899720413343, 0.07291379890271596, 0.18110691330262593, 0.14100336310054573, 0.23185172464166368, 0.12025236444813864, 0.1431256170783724, 0.17226402780839375, 0.0586969635582396, 0.1724014040082693, 0.11553176918200084, 0.14614064672163554, 0.12243765432919775, 0.140280316184674, 0.07866679198507752, 0.1744750884494611, 0.1107282026537827, 0.13832673244178295, 0.12995567305811814, 0.15978684090077877, 0.16340244188904762, 0.18606475155268395, 0.12169578485190868, 0.12164796170379434, 0.09785680725638356, 0.13513137533196382, 0.12280590885451861, 0.14679327527327196, 0.15697512749050344], [0.03733241318592003, 0.07143111846276692, 0.053195242171308825, 0.032998996786773205, 0.06618207333875553, 0.06590654062373297, 0.010790208903407412, 0.0162953747037266, 0.04353345311912043, 0.06244240900767701, 0.043407072579222064, 0.0763092627748847, 0.04736646351271442, 0.04681203933432698, 0.029664648563734124, 0.05924345566225903, 0.011594827602883535, 0.017360915562936237, 0.02315894471082304, 0.02018779931989099, 0.04096178164971726, 0.08517674516354289, 0.06379806769213506, 0.1054300723065223, 0.04371798411011696, 0.06509076511221272, 0.034516235015222003, 0.008504589138153409, 0.0896656953596643, 0.04256894612418754, 0.02603476950233536, 0.019778727520523325, 0.05345470717708979, 0.03065122151747346, 0.07168225105851889, 0.03246677766687103, 0.047391477706176896, 0.07863279059529305, 2.1828571430274417, 17.75360104015895, 37.05840826034546, 32.87658977508545, 22.388645308358328, 28.604601042611257, 43.282034805842805, 27.16082443509783, 3.2925228902271817, 0.28233215159603525, 0.03355106984132102, 0.6167965829372406, 1.0855195628745216, 1.5667494088411331, 3.962700528757913, 0.03462986248944487, 0.011699510289223065, 0.5162383445671627, 9.478377291134425, 30.804834978921072, 50.415149280003135, 54.99433524268014, 57.76992171151297, 53.352288314274375, 50.54869713102068, 52.16355923243931, 51.96668897356306, 53.82493952342442, 53.895623547690256, 54.219986302512034, 52.775848388671875, 52.10721281596592, 51.17078672136579, 51.15924228940691, 48.09774439675467, 39.633560044424875, 41.50137826374599, 42.62301901408604, 43.12660012926374, 41.923536913735525, 42.57585464205061, 43.77933127539498, 40.413471017565044, 39.78712912968227, 39.95805481501988, 39.43744713919503, 40.776392800467356, 42.173751967293875, 47.78571816853115, 55.35506139482771, 55.17127806799752, 53.09397166115897, 35.787304810115266, 53.024861403873985, 55.85132953098842, 52.23245062146868, 51.628780705588206, 50.19668401990618, 43.225035258701865, 39.51392943518502, 39.63064527511597, 41.283048493521555, 43.358002935137065, 43.436653069087434, 46.56435687201363, 52.12160948344639, 53.905038356781006, 53.57084390095302, 52.37544802256993, 50.93289777210781, 51.62761688232422, 49.87073360170637, 50.08693374906267, 47.6298040662493, 47.06230994633266, 45.31121104104178, 44.83015945979527, 45.08734008244106, 44.18930625915527, 44.37950624738421, 44.53483670098441, 47.87018394470215, 46.5284867967878, 48.864690031324116, 49.23010969161987, 46.480450425829204, 36.11557592664446, 20.532710245677404, 7.45276461328779, 1.1447166949510574, 0.5586812528116363, 0.9753895295517785, 2.5883583554199765, 2.6631214065211157, 3.312857661928449, 3.5351542021547044, 3.5983437257153645, 0.30621406010219027, 0.05206534565825548, 0.18461453222802707, 6.403247901371547, 30.435340200151714, 32.483088970184326, 18.187215532575333, 26.00352552958897, 29.810985497065953, 17.883926664079937, 3.1908637966428484, 0.05864563238407884, 0.05694014818540641, 0.019874448455604057, 0.1094005878216454, 0.06469399176005806, 0.03849159187770315, 0.04625535563432744, 0.06133109756878444, 0.1067671323461192, 0.04094905572544251, 0.03154374612495303, 0.037204980916742764, 0.05570053255983761, 0.10668723484767334, 0.010981939150951803, 0.04967163356819323, 0.08804445128355708, 0.044812501807297976, 0.018909468182495663, 0.019473413903532282, 0.05007977577458535, 0.049670693797192404, 0.020720327173226645, 0.06567856642816748, 0.05049917148426175, 0.03116820752620697, 0.09342547825404576, 0.03368977936250823, 0.0904900814805712, 0.03886237733864358, 0.052437525508659225, 0.016837357942547117, 0.04389209958857723, 0.022426303309787596, 0.008648055189821337, 0.030956022840525423, 0.02079116283649845, 0.04920982602717621, 0.021077039817880307, 0.03538316188912306, 0.056958495772310665, 0.04977613813909037, 0.034749152338398356, 0.056195320295436044, 0.025130156793498566, 0.03524128021672368, 0.06424263705100332, 0.014163502492010593, 0.052729458415082524, 0.04433180385136178, 0.022849797370976636, 0.043866552745125124, 0.046254256407597234, 0.06006670862968479, 0.04479371995798179, 0.01931309643467622, 0.07149746561689035, 0.010899427596346607, 0.14915127945797785, 0.010944070111561035, 0.032792165742388794, 0.033227639339332066, 0.026131258878324713, 0.017927748450477208, 0.06959568123732295, 0.04399696039035916, 0.01782384268673403, 0.07155037099229437, 4.7200793623924255, 29.43658181599208, 44.05103710719517, 30.676578181130544, 17.459153754370554, 39.30444472176688, 55.23887709208897, 24.573251008987427, 2.681091836520604, 0.3112796497132097, 0.10857873263635806, 0.16194382230085985, 1.2766068577766418, 1.7903187721967697, 4.634761129106794, 0.31493527069687843, 0.14411912805267743, 1.5231282923902785, 12.92075719152178, 35.03634698050362, 55.054336411612375, 57.09209714617048, 58.025875977107454, 52.92386238915579, 53.397607939583914, 52.875655787331716, 53.51895475387573, 55.68943302971976, 54.79193421772548, 55.2711375781468, 54.62340566090175, 53.84802838734218, 52.95698792593819, 53.04847833088466, 48.43598617826189, 41.92147329875401, 42.24906349182129, 43.28291375296456, 44.337365422930034, 43.246175152914866, 44.35770280020577, 45.03985956736973, 42.74250718525478, 41.02817814690726, 41.6939753804888, 41.73582785470145, 42.83837148121425, 44.78069870812552, 48.679214818137034, 56.8296845299857, 56.381338119506836, 55.10937309265137, 37.519886766161235, 52.39192567552839, 55.64548914773123, 53.587762764522004, 54.75836399623326, 52.08685111999512, 43.44703367778233, 42.10831730706351, 40.46440826143537, 42.517472403390066, 42.84683091299874, 43.273981843675884, 47.59989554541451, 53.64718723297119, 54.777666091918945, 53.05842120306832, 51.94648013796125, 53.213730812072754, 52.173793928963796, 50.17372717176165, 50.122115952628, 49.09375824247088, 47.94885492324829, 48.157818521772114, 46.704658372061594, 45.107548918042866, 45.03233119419643, 44.233604499271934, 45.05099058151245, 50.58194426127842, 48.55736773354666, 49.58413083212716, 49.725026403154644, 48.23527009146554, 40.25305795669556, 24.89305921963283, 9.385376521519252, 2.196549436875752, 1.4432412705251148, 1.836655114378248, 4.303319028445652, 2.9274823410170416, 5.083659487111228, 5.810397199222019, 1.5588158688374927, 0.33396842224257334, 0.09764796096299376, 0.195880547698055, 5.070571686540331, 32.604355880192344, 41.0994736126491, 21.866766112191335, 25.778594970703125, 33.33535153525216, 25.055871146065847, 7.473149759428842, 0.4851619835410799, 0.0729872706745352, 0.01728183909186295, 0.046173473420952044, 0.09114611627800123, 0.01303825733651008, 0.03979959026245134, 0.03643476224637457, 0.02503309744809355, 0.047720071859657764, 0.034078277980110476, 0.030329070053994656, 0.03441666339391044, 0.0809207156832729, 0.029137701660926853, 0.02385288756340742, 0.03306214804095881, 0.03718034331021564, 0.006799378897994757, 0.011046620501604463, 0.011052239619727646, 0.02272745411443923, 0.07246446622801678, 0.08113800973764487, 0.006561651609704963, 0.03766232369733708, 0.1338573308395488, 0.03900187396045242, 0.04193193405600531, 0.05217147871319737, 0.23549624479242734, 0.08093790297529527, 0.11915102068867002, 0.0761860136740974, 0.1462337960089956, 0.1250255461782217, 0.057728110546512265, 0.11381481095616307, 0.10437847873462097, 0.12241634832961218, 0.12593751081398555, 0.18363303132355213, 0.13987310017858232, 0.1035802365679826, 0.09262379591486283, 0.1405584341181176, 0.1734557252909456, 0.09296239167451859, 0.10053081198462419, 0.11959855524556977, 0.09868958685547113, 0.14728069411856787, 0.17270225286483765, 0.19422733783721924, 0.16707900246339186, 0.10762608304087605, 0.11823628763003008, 0.09536018515271799, 0.2838813013264111, 0.15387859222080025, 0.14185605091708048, 0.19176361789660795, 0.12644221873155662, 0.13396152667701244, 0.19595472514629364, 0.16899020490901812, 0.0890774190691965, 0.14358445602868283, 3.919863147394998, 30.535283088684082, 53.6591728755406, 42.57622289657593, 29.120242493493215, 35.77142470223563, 54.090020247868125, 34.327505656651084, 5.1063101802553446, 0.7031341386692864, 0.3747354575565883, 2.6036398325647627, 6.043496668338776, 7.942123634474618, 8.129132662500654, 0.3405683423791613, 0.3431465583188193, 0.6397419774106571, 11.057198217936925, 32.67477934701102, 54.726582935878206, 56.816347462790354, 60.59818594796317, 53.98743009567261, 55.26891415459769, 55.84962027413504, 54.3712729045323, 57.360589436122346, 57.21571602140154, 57.74059336526053, 59.16056891850063, 57.10992969785418, 57.89812639781407, 55.957577909742085, 52.49684694835118, 44.0490916115897, 45.77818209784371, 46.46503584725516, 46.90877560206822, 45.2682329586574, 47.04978929247175, 48.818352494921, 45.14024019241333, 45.02674136843, 44.78371770041329, 43.79754945210048, 44.54789931433541, 46.585993562425884, 49.93099880218506, 60.91352994101388, 59.48787076132638, 54.89667483738491, 41.58855383736746, 53.44929906300136, 56.459036350250244, 54.52103785106114, 56.670612471444265, 55.134761810302734, 44.618520804813926, 42.69006218229021, 43.72406530380249, 45.48652103969029, 46.959796224321636, 47.1301452091762, 50.66699021203177, 56.0414148739406, 57.27008220127651, 54.94891486849104, 53.379146575927734, 54.0801294871739, 54.35364532470703, 53.21120861598423, 53.81666769300188, 51.092324188777376, 49.76759454182216, 50.50406885147095, 49.02653442110334, 48.213094915662495, 49.00030844552176, 48.00271388462612, 48.495542662484304, 52.5308792250497, 50.64377975463867, 52.05830792018345, 51.1343468938555, 48.781089305877686, 38.2081857408796, 23.483618872506277, 8.905843990189688, 1.7643948261226927, 2.1026849193232398, 1.6009816633803504, 6.967169344425201, 7.003228323800223, 9.961021746907916, 7.1847847529820035, 8.826668398720876, 2.5408244260719846, 0.39695487384285244, 0.5031521181975092, 8.304979409490313, 36.418927328927175, 41.189240864345, 25.875397273472377, 34.44849811281477, 40.506316321236746, 27.73401607785906, 6.650659356798444, 0.32626865112355774, 0.16721432948751108, 0.12710959863449844, 0.2186263714517866, 0.1857367612953697, 0.13650713222367422, 0.15368250917111123, 0.12018594944051333, 0.1533705730523382, 0.1135092598519155, 0.17957935455654347, 0.12386774830520153, 0.22172667937619345, 0.13537494226225785, 0.18993883367095674, 0.14988820920033114, 0.13472388791186468, 0.1053120479253786, 0.09321342249001775, 0.10389068669506482, 0.17221312411129475, 0.09541370799498898, 0.2206287554332188, 0.16589470101254328, 0.09719402782086815, 0.11039843463471957, 0.282806501856872, 0.22309516237250396, 0.20028593630662986, 0.19653331195669516], [0.0376255640627018, 0.0513455726738487, 0.07065463012882642, 0.0247701583430171, 0.09251833121691432, 0.04370229298781071, 0.0474617094732821, 0.06715226306446961, 0.030818901091281856, 0.05328101578301617, 0.04403743161154645, 0.0752307992162449, 0.05593445411484156, 0.03567759519709008, 0.032542322363172255, 0.07820003453109946, 0.03455323213711381, 0.050632734317332506, 0.0405964346469513, 0.025130533380433917, 0.00835327073998217, 0.08618206264717237, 0.009797681804879435, 0.03559008453573499, 0.04877469509041735, 0.045427902535136254, 0.026070472318679094, 0.03775666720632996, 0.013145724560932388, 0.022864597916070904, 0.03719058918899723, 0.09293062266494546, 0.01707984091314886, 0.036783013559345684, 0.006082528703180807, 0.06603626973394837, 0.03138796466269663, 0.0743509903550148, 0.07767060758279902, 1.6339100450277328, 18.607261930193218, 39.4415465763637, 36.16214622770037, 22.729409285954066, 22.156596320016043, 41.76802928107125, 28.923714433397564, 5.434082329273224, 0.4686344989708492, 0.27063038093703135, 0.6815863634858812, 2.0141854967389787, 7.205608069896698, 0.11528915220073291, 0.17815358963395866, 0.2991433452282633, 0.2867987033511911, 6.1366572465215405, 22.26459390776498, 35.971223626817974, 48.526232855660574, 54.78929042816162, 54.63538088117327, 51.7543728692191, 51.2464074407305, 51.34006220953805, 56.72206735610962, 55.671096733638215, 57.567833355494905, 55.95235286440168, 53.90690047400338, 51.49971791676113, 48.753143651144846, 43.832491942814414, 46.11878279277256, 43.767630508967805, 46.714820112500874, 46.65736893245152, 45.45253045218331, 47.355961663382395, 47.58191360746111, 47.70773506164551, 46.07098960876465, 41.055797236306326, 41.38803924833025, 44.61980969565255, 52.77556003843035, 57.88590104239327, 55.11827720914568, 55.42625263759068, 35.45900590079171, 51.89911426816668, 57.730160645076204, 54.673012324741904, 54.87997831617083, 49.67228610174996, 43.62681136812483, 40.16782440458025, 47.14163058144705, 49.717584882463726, 51.240914889744346, 48.685568945748464, 49.94246332986014, 52.07842295510428, 55.27035590580532, 54.38883100237165, 52.646372182028635, 52.7317863873073, 51.959970065525596, 50.45460115160261, 50.17713526317051, 49.474957261766704, 48.70942905970982, 44.73093918391636, 45.59015689577375, 46.3791561126709, 47.1180032321385, 47.38228838784354, 48.11330836159842, 47.25120367322649, 48.52374192646572, 50.05357892172677, 45.589969294411794, 30.474472454616002, 15.657734257834298, 4.732062833649771, 0.2625084253294127, 0.02555469240594123, 2.110014183180673, 2.1975206647600447, 3.6717143143926347, 1.0187812468835284, 1.7672392449208667, 7.431220855031695, 1.0631727448531558, 0.05732911838484662, 0.26768138632178307, 7.326857175145831, 28.20132064819336, 24.54305934906006, 18.31277642931257, 25.696984904153005, 26.202601841517858, 15.1682562487466, 1.9493088637079512, 0.16811562755278178, 0.09050753340125084, 0.058369889323200495, 0.04971885960549116, 0.11649252048560552, 0.04621077588360224, 0.02499125897884369, 0.04031249827572277, 0.059984748384782245, 0.02679422151829515, 0.05108836718967982, 0.04601478782881584, 0.11610426274793488, 0.03346191712522081, 0.015117459963741047, 0.045252372311162095, 0.03519623227683561, 0.017176216634522592, 0.01189526085675295, 0.029052830500794307, 0.024609279386433106, 0.06790346918361527, 0.019439902755298784, 0.048995103620524914, 0.017454660264775157, 0.023620689487350837, 0.04714967496693134, 0.003737816171321486, 0.006610921733746571, 0.030910045307661806, 0.016221924984295453, 0.09832465715174164, 0.03009526724261897, 0.030337969040764228, 0.023792097611086707, 0.04353740558560405, 0.05030623683705926, 0.020513168735695735, 0.058885189172412665, 0.017094449772100364, 0.03473562913547669, 0.019976467891995395, 0.07258470941867147, 0.04877094957711441, 0.012645575550517865, 0.03453870809503964, 0.03934062917583755, 0.008191877793121551, 0.026653976811628257, 0.06320266678397145, 0.03111169234450374, 0.04991021665877529, 0.034352490944521766, 0.05596163962036371, 0.016887791754145707, 0.029775762065712894, 0.003558386067327644, 0.026031380219917213, 0.014783028712762254, 0.0670796733881746, 0.05207816997010793, 0.03149966849014163, 0.03253847506961652, 0.03547959867864847, 0.02451483240084989, 0.029246555641293526, 0.08663807889180523, 0.08762058402810778, 0.023862156351762157, 0.06490015105477401, 3.2074065889631, 28.954194443566458, 44.11492926733834, 34.09328188214983, 18.322679349354335, 32.967586857931956, 52.71370717457363, 28.095904316220963, 3.9283964037895203, 0.19827304860310896, 0.10888955595770053, 0.5595549887844494, 1.7679941015584129, 11.397136228425161, 1.0027748772076197, 0.5212972845349992, 0.15922303258308343, 0.9190914247717176, 9.863609739712306, 26.7340087550027, 41.42099108014788, 52.267177718026296, 55.529930182865684, 53.814545018332346, 53.77763966151646, 52.71367938177926, 53.12654481615339, 58.42665849413191, 57.63848263876778, 57.933728967394146, 56.14584977286202, 55.1746757371085, 53.69466774804251, 51.94769607271467, 44.41395889009748, 47.37249837602888, 46.87726204735892, 48.995955399104524, 48.5501902444022, 47.875471523829866, 49.43521703992571, 49.012756143297466, 47.0083259173802, 45.55731623513358, 43.959227085113525, 43.24959019252232, 46.31054959978376, 54.88996287754604, 58.04000513894217, 56.29495464052473, 56.09078877312796, 37.412429400852744, 51.66102729524885, 57.190431526729036, 56.8657352583749, 54.899492331913535, 51.807092326028005, 45.80223328726632, 40.739278997693745, 47.04596083504813, 50.240902355739046, 51.519978863852366, 49.22019113813128, 51.22008071626936, 53.591254234313965, 56.50851794651577, 54.90272671835763, 54.16273314612252, 52.70820420128958, 52.5477112361363, 52.756657464163645, 51.91711705071585, 51.395105838775635, 51.07397747039795, 46.35123825073242, 47.44407524381365, 48.45381872994559, 48.45255763190133, 49.67987353461129, 48.446158340999055, 49.80296087265015, 49.01413536071777, 50.83225311551775, 47.25170741762434, 35.0173054422651, 19.236541169030325, 6.5052496279988965, 1.1263800731727054, 0.8967836903674262, 2.9225554168224335, 3.773678260190146, 4.832519888877869, 6.031861041273389, 5.320099736963, 2.756723629576819, 0.06185127608478069, 0.0319890143748905, 0.44393652996846605, 5.535554690020425, 28.060925347464426, 34.960073130471365, 20.68601529938834, 23.21564769744873, 30.844992092677526, 21.699611561638967, 4.800268956593104, 0.12649004187967094, 0.04280986676790884, 0.05913369583764246, 0.030121109248804193, 0.03844566523496594, 0.023302317463925908, 0.05397986274744783, 0.06379966224942889, 0.0305582249004926, 0.034229021319853406, 0.08602032025477716, 0.03521418970610414, 0.07447444301630769, 0.05299601750448346, 0.03814142370330436, 0.04966358614287206, 0.05711454525589943, 0.036482483614236116, 0.0527212379633316, 0.01678261373724256, 0.021992485338289822, 0.0636541707707303, 0.038969297494207106, 0.07479349696742636, 0.026816358723278557, 0.058399520947464874, 0.06582221907696553, 0.024076274862246852, 0.020078258322817937, 0.026586801844782064, 0.007298038524043347, 0.15786360124392168, 0.17927243959690842, 0.15939721252237046, 0.17401477029281004, 0.17128547174589975, 0.12746641305940493, 0.09456659095095736, 0.1829393514032875, 0.12410408205219678, 0.09380623139441013, 0.09255306542451892, 0.15901401665593895, 0.14935109445026942, 0.1160515405769859, 0.0950247310101986, 0.22145936372024672, 0.1821446783308472, 0.13076000846922398, 0.16222082743687288, 0.12608936695115908, 0.0765733825308936, 0.17722869212073938, 0.14297517229403767, 0.1291889284870454, 0.1639105560524123, 0.09093655752284185, 0.11213458861623492, 0.07883320269840104, 0.10437647027096578, 0.2091217650366681, 0.13692460767924786, 0.22245030983218125, 0.10085109408412661, 0.10854709254843847, 0.09726021212658711, 0.14560813243900025, 0.1271915520940508, 0.1562001590750047, 0.20719809111739906, 2.8568582449640547, 28.35940432548523, 54.546520369393484, 45.98331723894392, 31.26659836087908, 28.076536212648662, 51.415102754320415, 36.40882812227522, 7.5746316739491055, 0.6603887666549001, 0.4291819216949599, 3.071826389857701, 5.017874377114432, 14.552478228296552, 0.5653685682586261, 0.6705881793584142, 0.9341418743133545, 1.422159458909716, 8.120520370347158, 24.56905255998884, 38.340045179639546, 49.89505924497332, 55.683582646506174, 56.39474466868809, 55.3813533782959, 56.66234064102173, 53.66460984093802, 61.653686795915874, 57.99365023204258, 60.489717619759695, 59.1356109891619, 59.48557785579136, 56.12022134235927, 55.06992816925049, 48.14938688278198, 51.716255051749094, 48.87502200262887, 52.35461732319423, 51.063263348170686, 51.03316027777535, 51.49333252225603, 51.49076863697597, 51.04032734462193, 50.48370368140084, 46.13156052998134, 46.39889594486782, 48.15699168613979, 59.395883560180664, 62.1119760785784, 58.42834690638951, 59.12904494149344, 41.2571108681815, 52.18852758407593, 58.39442580086844, 58.92505972726004, 57.63658578055245, 52.800604820251465, 48.018660000392366, 43.97103554861886, 51.33381577900478, 53.717530795506065, 53.96239226205008, 52.88751636232649, 54.29929651532854, 55.14191150665283, 57.822432722364155, 55.723430565425325, 54.307849747794016, 54.723265171051025, 54.234546252659385, 53.846572739737375, 53.338961669376914, 54.19975662231445, 54.77716929571969, 47.919005462101524, 49.21729026521955, 51.30694362095424, 50.20608145850045, 50.747283594948904, 49.95354570661272, 50.40092979158674, 51.93374408994402, 52.75946453639439, 45.27810287475586, 32.638131073543, 17.589321306773595, 5.824914591653006, 0.6450391645942415, 0.8811590373516083, 6.010613015719822, 6.077917175633567, 6.201323696545192, 3.8010302782058716, 6.839854896068573, 15.868384531566075, 3.169930611337934, 0.25562020923410145, 0.6894172547119004, 9.905518668038503, 35.330641405923025, 32.549812521253315, 25.780708960124425, 34.56500203268868, 38.28964294706072, 22.9462799344744, 3.540925983871732, 0.24736626499465533, 0.1729956106948001, 0.15094403683074883, 0.12057610707623617, 0.17197364196181297, 0.18049188916172298, 0.14524210350854055, 0.2501417446349348, 0.1359481822167124, 0.10770661836223942, 0.13052497750946454, 0.12180348193006856, 0.1405624917575291, 0.18494461237319879, 0.147271493183715, 0.20583088376692363, 0.13989899307489395, 0.11031898496938602, 0.14553996681102685, 0.11124044909541096, 0.08195584799562182, 0.1346880341214793, 0.16205863042601518, 0.21919825433620385, 0.10975803328411919, 0.2435166101370539, 0.12090328309152808, 0.2156520810510431, 0.15371431889278547, 0.13642569445073605, 0.12540085746773652], [0.04537372490657227, 0.04027919577700751, 0.03315792325884104, 0.010364122838447136, 0.017513182213796035, 0.026123932396460856, 0.03971296848197069, 0.024146515111039792, 0.048268392615552456, 0.011987326184420713, 0.041877023609621186, 0.04834108407210026, 0.05692351729209934, 0.042560559431357045, 0.03578317863866687, 0.016617901057803204, 0.021033362518729906, 0.019867566414177418, 0.025577134951683025, 0.008073573516282653, 0.023727602857564176, 0.039365972458784065, 0.03693957194419844, 0.06866848349039044, 0.03130204177328518, 0.04663281109450119, 0.0617294790489333, 0.01066574692127428, 0.021678313446630324, 0.03754842480910676, 0.05484737655414002, 0.014080558371331011, 0.015350845476080264, 0.033148936062519035, 0.03766967223158904, 0.028016534500888417, 0.033807070925831795, 0.05926186431731496, 0.05028294272986906, 0.04883065387340529, 1.4432978332042694, 17.228058406284877, 37.84583371026175, 34.54556097303118, 27.61605303628104, 30.243886062077113, 35.07346078327724, 33.29615674700056, 8.855875151497976, 0.455216116138867, 0.1300213552479233, 0.5970436685851642, 3.2663283986704688, 2.8062380126544406, 0.10197275318205357, 0.2894693086189883, 0.5350783850465501, 0.13305995719773428, 3.699601777962276, 11.541608384677343, 23.11564401217869, 38.57724625723702, 46.50572797230312, 53.11574731554304, 52.025939737047466, 52.4959853717259, 54.055942807878765, 57.486449105399, 56.45646899087088, 56.50740623474121, 54.81968184879848, 54.681690624782014, 49.79048885617937, 47.26661130360195, 48.52127531596592, 51.43332787922451, 51.288885252816335, 51.04189763750349, 50.32819952283587, 50.757188252040315, 50.67969846725464, 52.93206821169172, 53.40830816541399, 52.19575023651123, 43.679145199911936, 44.56730563299996, 49.36713859013149, 55.62977927071707, 56.2174266406468, 54.68253135681152, 32.90203407832554, 54.67080627168928, 56.974029881613596, 53.98533868789673, 52.09340327126639, 47.73514223098755, 40.461073126111714, 48.08084985188076, 54.192735467638286, 55.30207443237305, 55.32281480516706, 53.608728953770225, 54.26269687925066, 55.48228638512747, 55.04073531287057, 56.07226834978376, 54.52607876913888, 53.205524989536826, 53.71333755765642, 52.13722555977957, 52.42470727648054, 49.401632922036306, 49.48927749906267, 49.341784613473074, 50.181543895176475, 49.80443041665213, 47.273073128291536, 50.73098659515381, 48.20779691423689, 50.29408386775425, 49.82523332323347, 47.78877885001046, 30.12588827950614, 10.843419517789568, 1.819861644080707, 0.27440260137830463, 0.9808868574244636, 1.040574706026486, 1.271414382117135, 3.4541458061763217, 4.454067579337528, 7.6266467571258545, 6.7372082897595, 3.215869711978095, 0.07289876935205289, 0.3240599382136549, 10.94747747693743, 29.631756714412145, 43.595106737954275, 36.7086672101702, 20.7885741846902, 29.645093781607493, 11.79480595248086, 1.4391302168369293, 0.10022492161286728, 0.02260252563948078, 0.06617975953434195, 0.037640271309231005, 0.04374860639550856, 0.04219246096909046, 0.025713593432945863, 0.008128615428826638, 0.0767204753522362, 0.028344014160601155, 0.038294087297150066, 0.021357832875634943, 0.03406762498031769, 0.07839167317641632, 0.02703808870033494, 0.01953098420718951, 0.04397414465035711, 0.06783047917165927, 0.0731935113934534, 0.05431339663586446, 0.012185559341950076, 0.017258390617956008, 0.030522245581128767, 0.021650600380131176, 0.05327764007129839, 0.0170295173634908, 0.11125005715127502, 0.043160265644213984, 0.035276913483228, 0.04078243127358811, 0.015270084541823183, 0.0346038915616061, 0.005931985955352762, 0.0029856675246264786, 0.04437641413616283, 0.03819174046761223, 0.09113696284059968, 0.02684915571340493, 0.04632572650111147, 0.006794153754266777, 0.011075128302244204, 0.014272712703262056, 0.016047870573986853, 0.04123707348480821, 0.03531530499458313, 0.04221234204513686, 0.03256680729932018, 0.028546809617962157, 0.05963447503745556, 0.01018469188628452, 0.07128399171467338, 0.04833382035472563, 0.011075502344673234, 0.05856207758188248, 0.07619605599237339, 0.05167372238689235, 0.02521691088830786, 0.06440785354269402, 0.012434350143718933, 0.0834868469142488, 0.04794462284605418, 0.021256359659933617, 0.039078738407364914, 0.012150580013569976, 0.11615376866289548, 0.06739503610879183, 0.04281630267256072, 0.045011115792606554, 0.02956507694242256, 0.06835330397422824, 0.03747224907523819, 0.01671698922291398, 3.6028865448066165, 27.114045688084193, 42.37238359451294, 30.75928258895874, 19.31683455194746, 34.515621185302734, 48.485398292541504, 34.18338959557669, 8.999536974089485, 0.27520894525306566, 0.1280484196863004, 0.3304574377834797, 2.6330198560442244, 2.0649657547473907, 0.3355064168572426, 1.036712376134736, 0.2967724624489035, 0.49599873061691013, 5.753908344677516, 16.80536995615278, 27.12164875439235, 43.210808822086875, 49.50704404285976, 53.881199087415425, 54.11195223672049, 51.982874802180696, 54.199721881321494, 59.21610586983817, 59.0962563923427, 58.743357385907856, 56.73387234551566, 56.83296755381993, 52.00989982060024, 46.9323091506958, 49.62128632409232, 52.65615177154541, 52.68524040494646, 52.305354595184326, 51.460755893162315, 53.49129397528512, 50.8994665145874, 54.36753824778965, 54.19428839002337, 51.636350767953054, 44.55990580150059, 46.6917381967817, 50.66279697418213, 55.984998975481304, 57.83797584261213, 56.058344159807476, 35.47258268083845, 54.40011487688337, 56.22250577381679, 56.080842426845, 54.01308284487043, 50.40819065911429, 42.247190952301025, 47.246284348624094, 54.67757381711687, 56.12047495160784, 55.93777901785714, 55.751299789973665, 53.85765511648995, 56.06245401927403, 55.60140282767159, 56.708195277622764, 55.27968386241368, 53.77804265703474, 54.395476954323904, 51.73471641540527, 53.9335572378976, 50.64173003605434, 50.818356718335835, 50.75292205810547, 50.388061727796284, 51.49408292770386, 49.09498807362148, 50.93760865075247, 49.98802614212036, 51.31698029381888, 50.807062421526226, 49.207232747759136, 33.811212812151226, 13.945817981447492, 3.487184056213924, 1.7641750893422534, 1.6731712754283632, 2.152268350124359, 6.400725705283029, 5.5243164130619595, 5.421110042503901, 7.031856204782214, 1.1966649017163684, 0.5245070265872138, 0.07092114511345114, 0.22163742487984045, 8.40201621396201, 36.59043318884713, 48.73525898797171, 25.604276827403478, 19.077463899339946, 35.50854308264596, 19.091106687273296, 3.6646545103618076, 0.027833945816382766, 0.024555366386526396, 0.0677390465778964, 0.012924751150421798, 0.03455325249316437, 0.0601618867367506, 0.04127719186778579, 0.04661526417891894, 0.0438306209232126, 0.03222916488136564, 0.028769487847707102, 0.06055213258202587, 0.01628658937157265, 0.10080506905381169, 0.0182223191617855, 0.027794285444542766, 0.05421249508591635, 0.04340690973081759, 0.07607501891574689, 0.019993924901687672, 0.13716115855744906, 0.020958433592958108, 0.04977878781833819, 0.03901231322171433, 0.05728229946855988, 0.018067704779761176, 0.04012831333758576, 0.05148623637588961, 0.036103484486894946, 0.02969884333599891, 0.05585778983575957, 0.03401096052091036, 0.12699626971568378, 0.16005433297583035, 0.0917361703302179, 0.06601379665413074, 0.18309793860784598, 0.0673504156459655, 0.12818876786955766, 0.08552828058600426, 0.11211347939180476, 0.09001871677381651, 0.12898125605923788, 0.153964671173266, 0.18024570308625698, 0.10092638432979584, 0.13668178713747434, 0.11447766503053051, 0.13910734626863683, 0.14530280525130884, 0.13841148146561214, 0.17754383092480047, 0.12678580172359943, 0.176192596288664, 0.14588861167430878, 0.2004241267485278, 0.1075510506385139, 0.08837118625108685, 0.12515126514647687, 0.15275557605283602, 0.20134993349867208, 0.1785011895533119, 0.17891675154013292, 0.13646051686789307, 0.16718501677470549, 0.17229077565882886, 0.09347328104610954, 0.11229475680738688, 0.1408799375806536, 0.2201656417122909, 0.13645234730626854, 0.10645539978785173, 2.858687141111919, 26.435185841151647, 51.103146008082796, 44.164292744227815, 35.97116109303066, 37.319271428244456, 43.96775252478463, 40.246273040771484, 12.658177818570818, 0.6468545443245343, 0.3017568178474903, 1.8307046336787087, 9.539245247840881, 12.973680751664297, 0.17653757706284523, 0.8010953792503902, 1.7164700606039591, 0.3576196017009871, 5.120613047054835, 14.297992638179235, 25.6613267489842, 42.24748625074114, 48.232893807547434, 55.3515282358442, 54.83448845999581, 57.02892412458147, 57.08894266401018, 63.51946571895054, 61.06582750592913, 60.74948992047991, 59.47558634621756, 59.08463205610003, 53.30656916754586, 50.68807452065604, 53.30172627312796, 57.16803400857108, 55.51795148849487, 56.38579191480364, 55.387026582445415, 56.976232460566926, 54.350080898829866, 58.85716193062918, 58.99452086857387, 55.9293578011649, 48.018625259399414, 49.34227793557303, 52.83130890982491, 60.19639941624233, 59.81308814457485, 56.645189012799946, 38.515542779650005, 55.6748001234872, 56.42758532932827, 58.45796707698277, 55.70076901572091, 51.05138192858015, 43.54849474770682, 51.40613610403878, 57.8485301562718, 58.85088075910296, 58.23158087049212, 59.32544272286551, 57.80129977634975, 60.4176925931658, 59.127856799534385, 58.146753787994385, 56.971299239567344, 55.00411830629621, 56.68605136871338, 53.23786537987845, 56.447460651397705, 51.545874800000874, 52.56781932285854, 53.04612636566162, 53.501573835100444, 52.849433285849436, 49.29675333840506, 53.476834774017334, 51.9273795400347, 53.43430485044207, 52.02819790158953, 50.638037068503245, 33.19056844711304, 12.71591648033687, 3.0476937762328555, 1.140337484223502, 2.882327518292836, 2.4905707112380435, 4.531109205314091, 5.047315197331565, 12.294372745922633, 18.88563629559108, 13.544262477329799, 6.703714498451777, 0.40219913529498236, 0.608731461422784, 14.151570643697466, 37.53910548346383, 52.31928225925991, 42.288900988442556, 29.29551601409912, 41.8868191582816, 19.56834023339408, 2.6712918366704668, 0.2563749573060444, 0.0769147602841258, 0.1298451939863818, 0.13445197178849153, 0.1265366572354521, 0.11876558565667697, 0.11822290691946234, 0.12970428940440926, 0.1649016107299498, 0.22906508988567761, 0.2270706719053643, 0.07260853278317622, 0.11565075708287102, 0.2521337334598814, 0.17150303721427917, 0.09481659039322819, 0.17807652162654058, 0.17858770276818955, 0.15020959052656377, 0.10939228255301714, 0.12325040357453482, 0.10034954135439225, 0.08400093218577759, 0.08037990291735955, 0.18706275442881243, 0.1484110520354339, 0.24271523313862936, 0.14176058103995665, 0.1487052919609206, 0.12022530447159495, 0.18277294747531414, 0.11880667773740632], [0.021075664088129997, 0.00987210267755602, 0.04997497943363019, 0.042324748156326156, 0.03521460361246552, 0.019042635768918053, 0.03859829150938562, 0.05479529220610857, 0.021126192894631197, 0.022377457270132642, 0.04559047274025423, 0.025664861047906534, 0.05665568255686334, 0.0814193371417267, 0.007021193267844085, 0.03652224237365382, 0.10126868489065341, 0.03896045957558921, 0.03147366024287684, 0.06979175750166178, 0.0067551350221037865, 0.009256915688248617, 0.023975164662780504, 0.03317480181742992, 0.02895231910848192, 0.07424706593155861, 0.03970225441402622, 0.034388276881405284, 0.007786737256018179, 0.027845536890838827, 0.11538150081677095, 0.024429839104413986, 0.025142426402973275, 0.016002980393490622, 0.025755647337064147, 0.027502902151484574, 0.03596722786980016, 0.060612427203782966, 0.08574767131358385, 0.0177338672469237, 0.08508744316973857, 0.591807766684464, 16.350106613976614, 39.82713338306972, 38.62372623171125, 27.786047663007462, 27.486344064985, 36.86237178530012, 33.20560087476458, 15.989562852042061, 2.126188720975603, 0.01491589774377644, 0.6254090379391397, 0.7288932278752327, 6.187472462654114, 1.0804173052310944, 2.2970188685825894, 0.9220167249441147, 0.20333254496966088, 0.7493939421006611, 2.703888224703925, 10.661372372082301, 25.050031185150146, 36.69770990099226, 46.493245533534456, 51.66119057791573, 50.308147021702354, 57.81464031764439, 57.33515555518014, 59.90164988381522, 56.65366581508091, 55.361762932368684, 52.72230209623064, 51.74843563352312, 54.287175382886616, 54.89583757945469, 53.21833746773856, 55.34380183901106, 53.87485885620117, 55.805940423692974, 54.793084144592285, 57.46904386792864, 57.6451598576137, 56.49640028817313, 53.65734549931118, 49.139369692121235, 51.86568995884487, 58.8630678994315, 54.00896256310599, 57.79797158922468, 24.4918407031468, 51.99975545065743, 63.22056116376604, 52.63613053730556, 56.302059173583984, 47.29851048333304, 47.46098368508475, 53.189943654196604, 56.04964848927089, 55.69584969111851, 56.628867694309776, 55.28907435280936, 55.08164630617414, 52.562642914908274, 54.16944510596139, 54.49869244439261, 54.95437615258353, 52.96701070240566, 54.3200820514134, 53.14412028448922, 54.53142193385533, 52.054271016802105, 53.39479739325387, 48.074356760297505, 50.753981658390586, 49.52574859346662, 53.16529144559588, 50.3318646975926, 52.84555966513497, 50.24331685474941, 45.644575187138145, 26.85555533000401, 9.87232972894396, 0.7708605102130345, 0.1768688785710505, 0.9407156301396233, 0.27467016130685806, 2.1321596120085036, 10.097450494766235, 8.266459465026855, 2.2932748751980916, 9.023586426462446, 2.0381070588316237, 0.01791623710388584, 0.8105283187968391, 13.779648338045392, 39.07589415141514, 24.35971028464181, 26.811067751475743, 47.97470569610596, 31.204821927206858, 14.895087821143013, 0.7100016187344278, 0.009823047988382834, 0.03428838974131005, 0.027774445080597485, 0.03521845429869635, 0.002433971269056201, 0.03578860013346587, 0.09699265898338386, 0.020395595580339432, 0.030153153065059866, 0.08695777745119163, 0.024947222056133405, 0.013026662021210151, 0.08433234225958586, 0.010767648462206125, 0.03897701243736914, 0.050533166088696034, 0.024282147475917424, 0.0528577388530331, 0.04191163907359753, 0.038680004089006355, 0.03145656794575708, 0.033537790911006074, 0.05446437407018883, 0.03637571952172688, 0.030120681771742444, 0.027128367784566114, 0.03796612418123654, 0.024830978829413652, 0.046843489432441335, 0.003303531282914004, 0.011360241931730082, 0.01643372460135392, 0.0365925860990371, 0.08351525717547961, 0.013112071768513747, 0.053940365224012306, 0.028215109470433423, 0.034729691954063516, 0.12199119185762745, 0.01900846474537892, 0.04083697531106217, 0.011940572577129518, 0.006076967684618596, 0.008969574767564024, 0.03821488190442324, 0.05302611053256052, 0.039919063315859864, 0.018132408182801943, 0.045874365006706545, 0.04103770632562893, 0.027511256613901684, 0.029657503589987755, 0.06257819743560893, 0.01006039953790605, 0.04131076578050852, 0.033871555501329045, 0.017972677646737014, 0.04428890008213265, 0.07388970189328704, 0.04866343231073447, 0.04765467804723552, 0.01723583272126104, 0.03949605779988425, 0.044001920481345484, 0.06159519696874278, 0.012851619494280644, 0.012344333991807486, 0.016007416316175034, 0.030841377563774586, 0.004672466777265072, 0.028787112794816494, 0.020066723227500916, 0.0298546281909304, 0.07677462923207454, 2.222312271595001, 24.637829303741455, 45.60403592245919, 35.85019295556204, 24.533517735345022, 26.672574520111084, 48.62899323872158, 41.00566250937325, 12.666869146483284, 1.2927062681743076, 0.07223753019102983, 0.2306896112859249, 1.3642729307923998, 4.767186846051898, 1.8200272066252572, 4.448844271046775, 1.067092614514487, 0.09484378607677561, 1.1542657996926988, 4.835182785987854, 14.893071106501989, 29.188364369528635, 42.22272981916155, 50.45225266047886, 55.68209225790841, 51.52252885273525, 57.976338795253206, 58.52846349988665, 61.44621358598982, 57.659313338143484, 56.395828587668284, 54.38111850193569, 54.83654512677874, 56.1935213633946, 55.69007921218872, 56.05250767299107, 56.68529054096767, 55.10571139199393, 56.7030223437718, 57.05500418799264, 58.929916518075125, 59.10384382520403, 59.03122820172991, 53.75845915930611, 50.572143827165874, 54.037300791059224, 59.8177364894322, 57.486386571611675, 58.38710239955357, 28.729258673531668, 53.541157722473145, 62.99033260345459, 56.05735056740897, 56.414335114615305, 50.433690547943115, 48.549196652003694, 54.94748701368059, 58.00568103790283, 57.076168400900706, 59.0984867640904, 57.79273959568569, 56.24707112993513, 55.34956536974226, 55.03303670883179, 54.40438107081822, 56.55827052252633, 54.467140674591064, 53.465398039136616, 54.5348995072501, 55.68815803527832, 53.400696413857595, 55.44159426007952, 51.80555330004011, 52.21946096420288, 51.64375407355172, 53.20602525983538, 52.12249885286604, 52.91006326675415, 51.122302191598074, 48.375703607286724, 31.869733265468053, 13.63844530923026, 2.43696796468326, 0.6742200244750295, 2.0492450211729323, 3.1871363052300046, 6.210257342883518, 13.19928789138794, 3.515418929713113, 2.5689991542271207, 0.7093282948647226, 0.39789385774305885, 0.05354002617033465, 0.43170550199491636, 10.209254826818194, 43.79064294270107, 31.611343656267437, 34.37917593547276, 50.21695538929531, 31.833946568625315, 23.13115586553301, 2.341368134532656, 0.013337164734756308, 0.006501027050295046, 0.019167299615219235, 0.08187696829970394, 0.04697717100914035, 0.02621853374876082, 0.07054187117942742, 0.03035484081400292, 0.028962948359549046, 0.050934987741389444, 0.02629714203067124, 0.007263528232994888, 0.058557755313813686, 0.04316161932157619, 0.026985135827479616, 0.03180587777335729, 0.017417169508657286, 0.05909983015486172, 0.05581717612221837, 0.027509390642600398, 0.03550403951002019, 0.05129860447985785, 0.05252546364707606, 0.020999727537855506, 0.025248964882588813, 0.05542043669681464, 0.038580758164503744, 0.03987664469916906, 0.06815342791378498, 0.021070478384249976, 0.031476275995373726, 0.020443949682105864, 0.028739628914211477, 0.09198109433054924, 0.07948469809655632, 0.1499170469386237, 0.11231736559420824, 0.0979119585826993, 0.2143422913338457, 0.1016415941662022, 0.09915447833814792, 0.12738120263176306, 0.08662666593279157, 0.15154154119747026, 0.12186529647026743, 0.11553774029016495, 0.13688223995268345, 0.10040448233485222, 0.09920505633843796, 0.16286699633513177, 0.10414866570915494, 0.09331950465483324, 0.10508881668959345, 0.16909579852862017, 0.16757761713649544, 0.07979944335030657, 0.11610655619629792, 0.1285382541162627, 0.13359530775674752, 0.11523087961333138, 0.09185660351067781, 0.10539130760090691, 0.11987695816372122, 0.2251621021756104, 0.1023543273497905, 0.12440862213926655, 0.14878839893000467, 0.08048363735101052, 0.1452025720583541, 0.13095073109226568, 0.11730680322008473, 0.18823843848492416, 0.17267264159662382, 0.1686090582183429, 1.7806594733680998, 24.798224994114467, 52.9444568497794, 50.4269368989127, 38.287152017865864, 34.21181467601231, 45.27933618000576, 43.48679821831839, 20.971176317759923, 3.149598010948726, 0.11383663942771298, 1.7613026606185096, 4.920546616826739, 17.443395239966257, 2.6232055255344937, 3.110394754580089, 1.3746532137904848, 0.3363244043929236, 1.2175821278776442, 3.7315074716295515, 13.538564085960388, 27.911618982042583, 41.65044839041573, 49.82123463494437, 54.76588889530727, 55.26393577030727, 58.297943115234375, 61.85788740430559, 65.5133694240025, 60.28778212411063, 59.02550983428955, 58.27484730311802, 58.521550042288645, 58.96034267970494, 60.23300947461809, 58.03188616888863, 58.45957905905587, 57.29051685333252, 60.662567956107004, 59.3600378036499, 59.76549298422677, 61.81790746961321, 61.38977336883545, 58.874608857291086, 54.50515079498291, 57.27871881212507, 62.663399015154155, 58.66587802342006, 58.892041887555806, 32.70370817184448, 53.212247371673584, 65.78191729954311, 58.32924474988665, 59.770884786333355, 52.88928467886788, 51.71996538979666, 56.93673195157732, 61.15971851348877, 58.301417214529856, 60.539077622549875, 58.498120716639924, 56.45218890053885, 56.58921432495117, 55.47634220123291, 54.76367589405605, 55.85592923845564, 53.94399690628052, 52.79724884033203, 55.68943650381905, 58.78365693773542, 55.06637763977051, 58.994771003723145, 52.39588267462594, 53.4031526020595, 54.656541619982036, 55.91350201198033, 52.82191494532994, 54.7238974571228, 51.732618059430806, 48.32786178588867, 31.2687349319458, 12.74209121295384, 1.4740458918469292, 0.7919401505163738, 1.9176064048494612, 3.269259452819824, 7.404577987534659, 24.110143150602067, 16.45190814563206, 9.599093556404114, 14.690711770738874, 3.461700669356755, 0.11046385219586746, 1.016640876020704, 17.386897700173513, 46.90117427280971, 31.610155514308385, 34.82782111849104, 53.94898223876953, 41.302548612867085, 25.98939289365496, 2.274564027786255, 0.08049621060490608, 0.14533715269395284, 0.16104814250554356, 0.18174369127622672, 0.13348324091306754, 0.09212943565632616, 0.14514541226838315, 0.08267901704779693, 0.14486763360244886, 0.16180492618254252, 0.15741293185523578, 0.11445205711892673, 0.1501132792660168, 0.17239856773189136, 0.14316852763295174, 0.1702106451349599, 0.179759627740298, 0.2561337245362145, 0.12344701588153839, 0.14355407123054775, 0.10887309469814811, 0.10912730784288474, 0.09716822991945914, 0.10923015339566128, 0.09722977304565054, 0.13826646496142658, 0.14138161923204148, 0.10754006515656199, 0.15880599138992174, 0.08838575439793722, 0.10666041235838618, 0.08608483536435024, 0.19807350502482482], [0.06047923756497247, 0.025237638436790024, 0.016395283896209936, 0.06921190861612558, 0.07984568551182747, 0.055119333389614306, 0.03512464004701801, 0.009469856940475958, 0.017352503425042545, 0.06055947433092764, 0.0035032247750288142, 0.019532716167824607, 0.052920574588435035, 0.021681295608037283, 0.03616163833066821, 0.03753352418009724, 0.02684378850140742, 0.0233287769369781, 0.018779265794104764, 0.041006368185792647, 0.009115111199207604, 0.049864971943731816, 0.041497481654265096, 0.05694211593696049, 0.024649165371166806, 0.021197011594527533, 0.03455113546390619, 0.07229796051979065, 0.034383937649961026, 0.03436369355767965, 0.043529948485749106, 0.03692251696650471, 0.015050227321418268, 0.05177835927211812, 0.05388869478234223, 0.06599665007420949, 0.05874815902539662, 0.05397599170516644, 0.0161613555558558, 0.06289514792816979, 0.03966649901121855, 0.09421722005520548, 0.5211012693388122, 13.42250050817217, 39.38370629719326, 37.814556394304546, 32.74906601224627, 26.852155923843384, 28.463689838136943, 33.925649642944336, 18.717152902058192, 3.2913994533675055, 0.2582612575164863, 0.038523143756070306, 2.3814616288457597, 4.1395226291247775, 10.579678058624268, 12.790496706962585, 1.4687248745134898, 0.1556294568415199, 0.10962644498795271, 0.4110214204660484, 2.9126933174473897, 10.967943395887103, 25.339767592293875, 39.161627973829, 48.92393732070923, 53.82674605505807, 54.744238308497835, 55.74124574661255, 54.89617804118565, 56.85444790976388, 56.09862634113857, 56.68571785518101, 57.35251562935965, 59.374524797712056, 54.83866432734898, 57.13683312279837, 57.83787856783186, 56.816691398620605, 56.541709491184776, 58.67595291137695, 57.84165491376604, 58.25032016209194, 56.2111941065107, 51.77294887815203, 52.55230746950422, 57.85418251582554, 57.47182662146432, 49.56134768894741, 23.159129313060216, 49.707680225372314, 60.36790180206299, 55.24366092681885, 55.470113141196116, 49.2082645552499, 48.6647868837629, 54.636621134621755, 54.55602897916521, 56.123841353825156, 56.556064469473704, 58.413859912327354, 58.144387926374165, 58.455417088099885, 54.60078580038888, 57.52881227220808, 57.608153751918245, 54.20998437064034, 54.048372745513916, 54.43482460294451, 53.79500668389456, 52.56689868654524, 52.41049473626273, 55.76289633342198, 52.412019865853445, 55.38321202141898, 54.20009708404541, 53.46424116407122, 49.10569524765015, 39.43880203792027, 19.183184215000697, 4.867590487003326, 0.23893294323767933, 0.2901523762515613, 0.7261725195816585, 3.989199221134186, 1.7276500378336226, 5.70840893472944, 16.3374730518886, 13.977793591363088, 1.756463457431112, 0.885606590126242, 0.1977914108761719, 1.1233958218778883, 14.413485595158168, 37.17502335139683, 25.279533658708843, 25.423034804207937, 23.788191420691355, 26.130432639803203, 22.086984055382864, 1.9662589941705977, 0.08103722014597484, 0.0635984359042985, 0.038954705598631074, 0.04556904460436531, 0.01867076804462288, 0.05736067026321377, 0.012002102980789329, 0.0168224318684744, 0.04507503718403833, 0.025665700734992112, 0.06755523144134454, 0.05577487285648074, 0.02765927733188229, 0.03487414527418358, 0.010476942007829036, 0.04051312751003674, 0.038654039946517775, 0.06077028837587152, 0.04603445855900645, 0.05425079160236886, 0.06745558857385602, 0.03384982202468174, 0.030401825971369232, 0.014863608138901847, 0.04321948478796652, 0.021055270718144517, 0.03446042890261326, 0.0373092853198094, 0.044658871301050694, 0.015072905658079045, 0.041922312429440875, 0.04593841192711677, 0.04149251477792859, 0.08136636391282082, 0.03483005067599671, 0.015391070728323289, 0.06789559817739896, 0.043559692068291564, 0.025961821898818016, 0.023170564623017396, 0.04438295860641769, 0.016122879227623343, 0.035817655002964396, 0.05471828865951725, 0.03557199139946273, 0.023269537437175, 0.03906745437000479, 0.016443977265485694, 0.03988237492740154, 0.028740538151136467, 0.016682626513232077, 0.03822471387684345, 0.06660107549812112, 0.022136119327374866, 0.012629875098355114, 0.029752423853746483, 0.035148816249732456, 0.00950965132298214, 0.06708464026451111, 0.057075604131179195, 0.05808191906128611, 0.056928809865244796, 0.03123771326084222, 0.06813169443713767, 0.05363069541220154, 0.0410620182353471, 0.030623954587749073, 0.025613787717052867, 0.031596132421067784, 0.0706328966521791, 0.09786477325750248, 0.08886108174920082, 0.021901005247075642, 0.04570226138457656, 0.02270970872736403, 0.030785388246710812, 1.3278559020587375, 21.4194358757564, 46.6689897945949, 38.200042452131, 29.66321120943342, 26.358606270381383, 38.80485882077898, 50.65725925990513, 19.330256734575542, 1.814504148704665, 0.24441724323800632, 0.06639151674296175, 0.6127582139202526, 1.2999839633703232, 10.265581267220632, 15.929184743336268, 2.9109458455017636, 0.6176312895757812, 0.16868888107793673, 1.785080916115216, 4.837618563856397, 15.320234196526663, 29.94065625326974, 44.16609580176217, 51.99080964497158, 56.052247115543906, 55.90120717457363, 56.5767388343811, 56.58493423461914, 59.172749110630576, 56.2115067754473, 57.66988154820034, 58.3546473639352, 59.585159437997, 55.74726636069161, 57.539870330265586, 58.037059102739605, 59.41324710845947, 57.55987071990967, 59.551745550973074, 59.112001010349815, 59.132539885384695, 57.255970409938264, 52.600329944065635, 53.75058685030256, 59.55808925628662, 58.27001135689871, 52.07079383305141, 22.409581967762538, 50.88182156426566, 62.653914724077495, 57.16718632834298, 58.414360182625906, 50.321345124925884, 51.83403049196516, 55.7182228905814, 56.01222201756069, 57.9110153062003, 57.360391412462505, 59.25135408129011, 59.81192084721157, 58.24100957598005, 55.619158949170796, 56.20506232125418, 58.94378512246268, 54.801032883780344, 54.13414478302002, 53.04782520021711, 54.79793398720877, 52.662825516292024, 52.231571674346924, 54.153401715414866, 53.351416315351216, 54.450815882001606, 54.78132431847708, 53.79518733705793, 51.25727094922747, 42.138628823416575, 25.470035893576487, 8.167289563587733, 1.3793431392737796, 1.1166288192783083, 2.442133081810815, 4.033718500818525, 5.054764100483485, 8.034487775393895, 15.52875484739031, 14.676761525017874, 0.47593032462256296, 0.5814716156039919, 0.17027403387640203, 0.8636184728571347, 13.458155189241682, 46.18915067400251, 33.969854082380024, 22.35244345664978, 21.94065499305725, 33.76391295024327, 28.37351437977382, 4.277238096509661, 0.08070382196456194, 0.07727856361972434, 0.02308850090152451, 0.015607759190191115, 0.032417621197445054, 0.050520463913146935, 0.028887091537139246, 0.025048829282500913, 0.016542361450514624, 0.011542747495695949, 0.042035529389977455, 0.08702133582638842, 0.06665873740400587, 0.023891893148954426, 0.007338117891257363, 0.0647033623286656, 0.040591335456286154, 0.04972053897966232, 0.0368047436433179, 0.03208990913948842, 0.08661902562848159, 0.028576495525028025, 0.016041122543226396, 0.022983034507238438, 0.0284978397456663, 0.07387977492596422, 0.013331580391552831, 0.02266201958991587, 0.047279451574598036, 0.03557047826637115, 0.03605642129800149, 0.04079407832718321, 0.029186993837356567, 0.05124022671952844, 0.0937977632773774, 0.10113131547612803, 0.20878165614392075, 0.19967363987650188, 0.23834720466818127, 0.10389978584966489, 0.1505839382963521, 0.09372765703925065, 0.09556789150727646, 0.1635240489350898, 0.11269919760525227, 0.09329935216477939, 0.17328853426235064, 0.17350163497030735, 0.167350226481046, 0.1383991999817746, 0.12537858794842446, 0.10399117094597646, 0.1673754272716386, 0.10913591845227139, 0.11954664731664316, 0.10480826960078307, 0.11315707303583622, 0.17785947184477532, 0.21670537096049103, 0.13531083427369595, 0.10266335255333356, 0.13842195804630006, 0.16591268219053745, 0.18739462590643338, 0.193154207563826, 0.13634862644331797, 0.10514387302100658, 0.1323582162814481, 0.10664977292929377, 0.1810842909451042, 0.22651082623217786, 0.1522206190441336, 0.08424907244209733, 0.1576246754931552, 0.115640022658876, 0.1544006299227476, 1.1063908657857349, 20.778403759002686, 52.27880205426897, 51.6893481527056, 44.889806270599365, 35.86532265799386, 36.32162128176008, 45.27021666935512, 24.24548363685608, 4.61506689446313, 0.3384350554219314, 0.3729045529450689, 6.1004610402243475, 13.200191157204763, 18.658004624503, 17.241008111408778, 1.9095521398953028, 0.5776187852025032, 0.29842974351985113, 1.1073293068579264, 3.9316898499216353, 12.168247308049883, 28.89623604501997, 44.0091290473938, 55.18304136821202, 59.128030504499165, 56.24966628210885, 59.12642547062465, 58.53315353393555, 62.33572891780308, 59.254598890032085, 61.12332384926932, 60.06227139064244, 62.19869654519217, 58.00841515404837, 61.223565510341096, 62.06520080566406, 62.41592502593994, 59.041608810424805, 64.25124304635185, 60.376489775521414, 62.54851055145264, 60.724601473127095, 54.97435222353254, 55.96996307373047, 60.99321188245501, 61.03278882162911, 51.53809629167829, 30.304595947265625, 51.31478813716343, 62.39291954040527, 60.11073507581438, 60.23118209838867, 52.96934182303292, 53.07121283667428, 57.39081757409232, 55.704986572265625, 59.772204944065635, 58.751716068812776, 61.72013241904122, 61.76606001172747, 60.11354214804513, 57.01943288530622, 57.841922419411794, 59.21278463091169, 56.662774903433665, 55.61223159517561, 55.77652522495815, 54.0623698915754, 53.41561072213309, 52.763199193137034, 58.271772725241526, 53.60054397583008, 56.24762698582241, 55.702103069850374, 55.72927400044033, 52.603109223502024, 42.800597599574495, 22.782430989401682, 6.671962533678327, 0.8979579902120999, 1.0431635613952364, 2.053954814161573, 9.318322931017194, 5.153580946581704, 13.188524263245718, 22.871614592415945, 18.29276040622166, 3.632902111325945, 2.3475895949772427, 0.5385230630636215, 1.5877883370433534, 18.809965201786586, 45.83703681400844, 32.73174067905971, 33.40609809330532, 32.028353691101074, 37.53500952039446, 31.746854373386928, 4.020744911261967, 0.16046221394624027, 0.1569803657808474, 0.10527423995413951, 0.08226939902773925, 0.0876070676105363, 0.15561773175639765, 0.16950879565307073, 0.20455725996622018, 0.14938838673489435, 0.12748397354568752, 0.19151973884020532, 0.1381888948380947, 0.20876515417226724, 0.15971127924110207, 0.1656917647591659, 0.19698476844600268, 0.1961580549499818, 0.1692315326737506, 0.14858356277857507, 0.1244087985583714, 0.1941374319472483, 0.05599973936166082, 0.09582485271883862, 0.08924914271171604, 0.09643349184521607, 0.13001602196267673, 0.07730142346450261, 0.10476772713341884, 0.19808995271367685, 0.12115098908543587, 0.13932261828865322, 0.14106322345989092, 0.07552273890801839, 0.14260086523635046], [0.031988261201019795, 0.03918865429503577, 0.0402461171948484, 0.0687915493867227, 0.04413956470255341, 0.026133652410602996, 0.0670965892661895, 0.04238666108410273, 0.05759387596377304, 0.030191975446151834, 0.051719058704163344, 0.05176905994968755, 0.019064367549227815, 0.015418490328426872, 0.038190183229744434, 0.0498785833562059, 0.019793056483779634, 0.05219361252550568, 0.021699227592242614, 0.03495405295065471, 0.014845786416637046, 0.024899960395746996, 0.011153219201202904, 0.035644866060465574, 0.007808704827246922, 0.11392422472792012, 0.1043451287384544, 0.07424475212714501, 0.07670316592391048, 0.05829318772469248, 0.04069671533735735, 0.061999759902911525, 0.015778792423329184, 0.012044161125751478, 0.03490093044404473, 0.04828052482168589, 0.029504931598369564, 0.006089789027880345, 0.030437890107610395, 0.009134171247881438, 0.0916293892743332, 0.043389600302491865, 0.05674313215006675, 0.30262705257960726, 9.319504124777657, 32.83628327505929, 33.906559467315674, 32.84074749265398, 17.79300253731864, 23.827073540006364, 43.590579986572266, 30.050729615347727, 8.303609745843069, 0.7665061610085624, 0.195706734167678, 0.3479056672326156, 2.706562412636621, 6.92175201007298, 3.962738743850163, 0.3468640888375895, 0.13864732666739396, 0.10831628886184522, 0.12915584311953612, 0.6306257237281118, 3.2561792518411363, 10.78045059953417, 26.031354801995413, 38.020806721278596, 50.69361570903233, 53.90073047365461, 59.01109232221331, 60.53043406350272, 57.529580048152376, 57.22010728291103, 56.94660881587437, 58.00031355449131, 60.14467702593122, 59.37235695975167, 57.58440480913435, 57.463704177311485, 60.93310301644461, 56.406247411455425, 59.712763105119976, 60.74389662061419, 63.02437877655029, 57.746721676417756, 60.824467931474956, 56.59075682503836, 60.197921071733745, 38.49412495749337, 41.048772607530864, 42.67783682686942, 62.324264390128, 59.06792858668736, 57.6969621522086, 53.96221855708531, 51.96468441826956, 54.638042041233604, 55.487827573503765, 57.934868471963064, 60.039349283490864, 55.07662623269217, 56.52090311050415, 56.98977797372, 57.86588328225272, 56.11432579585484, 55.39996760232108, 54.45308446884155, 54.67925180707659, 56.05814961024693, 54.653223855154856, 50.90705394744873, 51.280206952776226, 47.73494073322841, 46.974175521305625, 42.685330459049766, 39.6246976171221, 30.12149006979806, 20.70562137876238, 7.912959439413888, 1.9063937493732996, 0.13544377285454953, 0.25129264859216555, 1.650782008256231, 1.8651353461401803, 1.6402844744069236, 5.6125863279615125, 8.83344202382224, 7.176765663283212, 0.8155186995863914, 0.8983333557844162, 0.09241026094449417, 1.803383122597422, 20.2887989452907, 35.920143944876536, 21.32176157406398, 20.077591078622, 31.331588336399623, 35.5190418107169, 17.42128607204982, 1.6234419324568339, 0.04331852375928845, 0.04664038015263421, 0.03725788629214678, 0.08080314592059169, 0.020190925669989417, 0.025805840268731117, 0.04391093232801982, 0.007904482589635466, 0.049845725297927856, 0.036278404029352326, 0.057296860830060074, 0.03746905656797545, 0.07098752619432551, 0.04987446464864271, 0.010034019792718547, 0.009510650465797101, 0.024708219970177327, 0.019708475397367562, 0.04955684919176357, 0.041389309601592164, 0.04710286622866988, 0.049546454035277875, 0.004744637882270451, 0.024046612703906636, 0.006298153137322515, 0.038249582185276916, 0.06867267683680568, 0.05082754172118647, 0.03798238527295845, 0.02752789598889649, 0.06835400965064764, 0.015048894000106623, 0.06782361239727054, 0.011367494622910661, 0.07298302304531847, 0.06978538605783667, 0.0300408317707479, 0.016802544007077813, 0.04880875415567841, 0.018587257347202728, 0.04766689846292138, 0.07540985782231603, 0.10567491488265139, 0.1086641534098557, 0.019539396345083202, 0.04931082596470203, 0.023038335111258284, 0.0072359542661745635, 0.039469798494662554, 0.03394579062504428, 0.07182649403278317, 0.042266981077513525, 0.04677629750221968, 0.06952211447060108, 0.01179358662505235, 0.04609418999669807, 0.018954663703750287, 0.01263465961840536, 0.06591508337961775, 0.035742615815252066, 0.02032947912812233, 0.036152905584978204, 0.057102806600076814, 0.01924509704778237, 0.0479027945548296, 0.07902116368391685, 0.010636936324382467, 0.029858068363474946, 0.09622177534869739, 0.014427323692611285, 0.02248491855737354, 0.06050026536520038, 0.03475025495780366, 0.06375574746302196, 0.00613795907702297, 0.09828452180538859, 0.047715807267065556, 0.07693657518497535, 1.0490263210875648, 16.669709852763585, 42.30540990829468, 37.5248373576573, 29.222504343305314, 14.347977110317775, 29.396643570491246, 53.180897099631174, 30.99594865526472, 5.520456688744681, 0.3678265597139086, 0.11524962075054646, 0.38724511915019577, 0.5643564654248101, 6.637487743582044, 5.751661905220576, 2.21960985660553, 0.17170370716069425, 0.8613993376493454, 0.34041678479739595, 1.2621818546737944, 5.859815827437809, 16.396190541131155, 33.000041893550325, 44.566965171269004, 52.76279272351946, 57.005164759499685, 60.42803151266915, 61.79290090288435, 59.155607904706685, 60.14729649680001, 58.98196547372, 59.387128829956055, 61.39354624067034, 59.69879722595215, 58.69426141466413, 58.6809139251709, 61.236572538103374, 58.66660063607352, 61.577145440237864, 62.896865436008994, 63.10538782392229, 59.564703941345215, 60.53570774623326, 58.70039667401995, 61.6410619190761, 42.73020192555019, 36.49280057634626, 45.99583441870553, 62.728218759809224, 60.93770967211042, 58.62100655691964, 55.965432848249165, 53.741311005183626, 56.45877231870379, 58.43577453068325, 60.14879035949707, 59.613994462149485, 57.085016931806294, 56.88022920063564, 57.91707760947091, 56.80154779979161, 55.980413164411274, 55.19283485412598, 55.434534890311106, 55.46452331542969, 58.20932231630598, 54.877515179770334, 51.998480456215994, 54.80062294006348, 52.56901788711548, 50.357781478336875, 47.45202398300171, 42.620587144579204, 36.69623340879168, 26.895464045660837, 14.114623597690038, 3.2122444893632616, 0.3597459676010268, 1.5936179842267717, 3.3629771896771024, 3.4698472150734494, 5.250738476003919, 8.676652448517935, 6.036146777016776, 2.837898782321385, 1.7613554235015596, 0.43291324004530907, 0.10812199714460544, 1.5418984166213443, 20.295465741838726, 44.39523696899414, 28.750907523291453, 18.871557508196148, 30.873069763183594, 37.153546469552175, 23.296352761132376, 3.7320954629353116, 0.008220394923617797, 0.010131485410965979, 0.013877931699555899, 0.03200682591913002, 0.017855045119566575, 0.011674393467339022, 0.02116012473457626, 0.06624036628220763, 0.023384851070919206, 0.04143322778067418, 0.024371924444234798, 0.05615742750731962, 0.06588556032095637, 0.09831905923783779, 0.032226918930453916, 0.03900865591796381, 0.009175731517773653, 0.026173730081479465, 0.036493482666888406, 0.009575932319941265, 0.03574943169951439, 0.02452039808434035, 0.06227255812180894, 0.016719891656456248, 0.019772837836561457, 0.08670271613768168, 0.03198584222367831, 0.0878692331856915, 0.051946116877453666, 0.006986388662231288, 0.00996000858555947, 0.04499019316530653, 0.03862263056050454, 0.07293779190097537, 0.028412235767713616, 0.13318657183221408, 0.12192175058381897, 0.12879111697631224, 0.08410150464624166, 0.12799353977399214, 0.10069965863866465, 0.1328954260264124, 0.19269236948873314, 0.17112868944449083, 0.12454833249960627, 0.1544543427548238, 0.11677473677056176, 0.10762952321342059, 0.0687977783381939, 0.07660908025822469, 0.125959576772792, 0.13779628090560436, 0.18164526298642159, 0.13528751981045517, 0.13706727645226888, 0.12749271307672772, 0.13040996582380363, 0.08595784075026001, 0.09024743735790253, 0.14235732544745716, 0.23840037467224257, 0.34354314846651895, 0.13565227309507982, 0.13597719637410982, 0.1391695679298469, 0.18410820939711162, 0.12680959116135324, 0.07234385662845202, 0.14511619455048017, 0.1511217180107321, 0.18134737254253455, 0.09027060254343919, 0.07076711087886776, 0.11101387268198387, 0.20984922243016108, 0.18522676080465317, 0.3014173874897616, 0.18343309419495718, 0.7705685773066112, 15.169357538223267, 46.672946793692454, 47.27576902934483, 42.53457192012242, 24.780279534203665, 29.965878214154923, 53.83916596003941, 37.32962424414498, 10.988167864935738, 1.1302358891282762, 0.7874587252736092, 1.1896301763398307, 8.821917567934308, 11.922713603292193, 6.2329323547227045, 1.2162144184112549, 0.8620662018656731, 0.6043887830206326, 0.2987671654139246, 1.1871660628489085, 4.307347680841174, 13.492547903742109, 30.034220695495605, 44.161256381443565, 59.631170409066335, 57.242560386657715, 62.67333493913923, 64.98454202924455, 62.35152217320034, 62.904515402657644, 60.12272766658238, 59.28853389195034, 62.436568123953684, 61.572531836373464, 59.42727552141462, 57.39494480405535, 62.24531895773751, 58.61532293047224, 61.08833966936384, 64.4130665915353, 67.95232609340123, 62.380204336983816, 65.98146956307548, 61.238323484148296, 62.257158688136506, 46.19545269012451, 41.53722402027675, 50.69923332759312, 63.518319266183035, 63.0021584374564, 61.057413237435476, 56.73101316179548, 56.01917369025094, 57.1518759727478, 59.54871613638741, 60.78320952824184, 62.33680588858468, 54.951819215502056, 55.944595200674875, 57.203706060137065, 57.49062497275216, 55.21521152768816, 55.46064969471523, 55.38557093484061, 54.45621810640608, 57.505921431950156, 56.548699378967285, 51.67158160890852, 55.20764493942261, 50.22773551940918, 50.5841120992388, 44.79238210405622, 42.420531136649, 32.49374055862427, 23.38699722290039, 10.066365991319929, 2.7737295627593994, 0.5182840462241853, 1.3548000391040529, 4.329774294580732, 6.071156144142151, 7.873406818934849, 11.640665377889361, 16.528406075068883, 15.258509874343872, 3.223197021654674, 2.0503126553126743, 0.23288114368915558, 2.5732045514242987, 26.507256031036377, 43.98392098290579, 28.813290187290736, 28.505535364151, 40.6794376373291, 46.06492383139474, 26.680151530674525, 3.440516480377742, 0.23034453551684106, 0.10067165549844503, 0.08595645653882197, 0.15566574489431723, 0.12813684636993067, 0.13498103911323206, 0.17937554977834225, 0.10782314996634211, 0.1271030982690198, 0.1381609799074275, 0.11171631248933928, 0.16727287348892006, 0.19714579837662832, 0.1482698353273528, 0.10071526494409357, 0.07478621628667627, 0.09437647900943245, 0.08382247069052287, 0.1132073321246675, 0.12521845368402346, 0.1278695985674858, 0.22321488309119428, 0.09145979623177222, 0.19223526758807047, 0.11456093484801905, 0.1316031560833965, 0.13946222008338996, 0.17448123597673007, 0.22345235677702086, 0.10883031306522233, 0.24541580251285008, 0.1783739235252142, 0.14312852120825223, 0.13406739171062196, 0.20980504980044706], [0.02395690358909113, 0.10827561068747725, 0.09115469974598714, 0.015485422719003899, 0.06510436973933663, 0.03474337122003947, 0.16735235708100454, 0.0622310589200684, 0.015523357915558984, 0.013732449550713812, 0.02673539422851588, 0.05124588570158396, 0.0565572067696069, 0.055077410103487115, 0.022997159909989153, 0.010348798973219735, 0.06697818490543536, 0.023735119329233254, 0.012130190036259592, 0.022043460281565785, 0.045013941890959225, 0.06685584504157305, 0.07626612151839904, 0.034128374220537286, 0.0633090678602457, 0.03837988805025816, 0.018197606916406324, 0.028301115480384657, 0.04189575456881097, 0.07742837058114153, 0.033503935406250615, 0.052259650946195634, 0.024323066530217017, 0.023783254603456174, 0.013856643511514579, 0.06355296727269888, 0.03517868536125336, 0.052133806448962004, 0.03152170391487224, 0.034360497657741816, 0.07268295450402157, 0.04164027256358947, 0.03265640784853271, 0.06932252339486565, 0.14901897870004177, 4.498130449226924, 28.93042639323643, 33.36612858091082, 32.8554151398795, 25.056319304874965, 17.939276014055523, 29.02324911526271, 34.43805149623326, 13.099553448813301, 1.2640445147241866, 0.42298401998622076, 0.4556110235197203, 7.425367866243635, 7.41058383669172, 3.479393171412604, 0.2944950817951134, 0.9654377549886703, 0.44078867030995234, 0.07106479097689901, 0.04593407269567251, 0.3461066537669727, 3.716868485723223, 11.491846254893712, 25.729705708367483, 38.82413312367031, 47.64252969196865, 53.70259911673409, 58.656060218811035, 58.02917637143816, 58.28603390284947, 60.415747097560335, 58.10724980490548, 55.89919914518084, 57.78528070449829, 58.86313043321882, 56.49952350343977, 57.15043422154018, 59.88803836277553, 62.75197465079171, 63.13941315242222, 60.454955782209126, 57.450662408556255, 57.908225604466026, 55.83004025050572, 28.93763862337385, 35.666916847229004, 34.6568363734654, 53.13954489571707, 60.89146246228899, 61.837341581072124, 57.80324179785592, 54.60348170144217, 56.58503498349871, 56.94313471657889, 60.188151904514854, 60.3453687940325, 60.457200050354004, 59.02931744711739, 58.203788076128276, 53.76325341633388, 56.37618603025164, 56.621759687151226, 47.47983414786202, 44.84233965192522, 38.74741458892822, 35.86672272000994, 27.686321905681066, 24.092989785330637, 23.03059458732605, 19.251597915376934, 14.476875747953143, 8.510110207966395, 4.043673098087311, 0.8103026651910373, 0.1495231437895979, 0.14236720491732868, 0.5310305165393012, 1.0469014751059669, 3.3221130967140198, 4.4340702295303345, 5.224294934953962, 7.183977459158216, 5.501010417938232, 2.1354063749313354, 1.7562063740832465, 0.10177068545350007, 6.488093222890582, 26.672645739146642, 35.68396077837263, 24.139513186046056, 22.791222197668894, 32.98141377312796, 28.98238328524998, 11.220975943974086, 0.6089876762458256, 0.05852241721004248, 0.07181452467505421, 0.040758699511310885, 0.05354008384581123, 0.029512351378798485, 0.1004907377064228, 0.04156541318765708, 0.021684679801442792, 0.09957984515598842, 0.04394513727830989, 0.08527666623038904, 0.010248138303203242, 0.08520898914762906, 0.10151704227817909, 0.07601475143539053, 0.1383596956729889, 0.01080550901990916, 0.029146502260118723, 0.04604855173134378, 0.03184867636965854, 0.008942552958615124, 0.021948953924168433, 0.04703414420198117, 0.06150209517883403, 0.0653243236509817, 0.05928088365388768, 0.03212596309770431, 0.05724738884185042, 0.052133959119341204, 0.08287082532686846, 0.06214396216507469, 0.007077331014443189, 0.016717676239620363, 0.02672621195337602, 0.05395210048715983, 0.06777568068355322, 0.18974017218819686, 0.06011559029242822, 0.06053027018372502, 0.01684051482672138, 0.00804050765665514, 0.029652546891676526, 0.02048856166324445, 0.013812010326156659, 0.021263781136700084, 0.10177343352032558, 0.036414497798042636, 0.01376446198472487, 0.02412552971925054, 0.048654234768556695, 0.05411837549347963, 0.026403624531147734, 0.058488015484597, 0.018361895511459028, 0.02144736726768315, 0.00693647689851267, 0.03660420261855636, 0.025036547798663378, 0.0701839846691915, 0.04349534319979804, 0.019204535920705115, 0.03497836146769779, 0.05337396490254572, 0.029988523506160294, 0.005306673951313964, 0.01751212539550449, 0.020183660256277238, 0.0583121527784637, 0.02634233924826341, 0.005315920263196209, 0.018734864158821956, 0.0862922499488507, 0.011526526267906385, 0.02559038165158459, 0.024467312897156392, 0.046797413512000015, 0.09530474205634423, 0.01162944476319743, 0.023261688483346785, 0.15695825910993985, 0.469066535787923, 10.616925614220754, 37.06612423488072, 39.61539050510952, 25.007391827447073, 17.11654155594962, 27.586818490709575, 47.216090951647075, 44.045964922223774, 11.801986915724617, 0.7345545983740261, 0.20673921145498753, 0.05018596989767892, 2.2892737984657288, 2.9099157750606537, 4.2366836326462884, 0.8116067009312766, 2.2939781631742204, 1.5821150243282318, 0.47423154434987475, 0.5198301289762769, 1.193175386105265, 5.053248090403421, 16.633725132261002, 32.181293964385986, 45.08259446280343, 53.91348041806902, 56.55029746464321, 59.820988246372764, 59.43972669328962, 56.848865032196045, 59.75705092293875, 56.002261774880544, 56.86430392946516, 57.96499238695417, 57.80958897726876, 56.738194125039236, 56.57532835006714, 59.67074040004185, 62.57362134116036, 65.13250391823905, 61.4574418749128, 60.543656485421316, 58.956243242536274, 57.92701700755528, 34.11549179894583, 39.03807510648455, 40.4187342779977, 56.396033559526714, 62.304760796683176, 61.56673009055001, 58.52969333103725, 54.60841492244175, 56.194938795907156, 58.27067838396345, 60.97676549639021, 61.383825710841585, 60.38532093593052, 58.23537458692278, 58.493430682591026, 54.60862684249878, 57.055132729666575, 57.840421608516145, 50.72246462958199, 49.01469121660505, 42.88842977796282, 39.98764024462019, 32.92559889384678, 29.84727246420724, 28.409089156559535, 24.762410504477366, 19.537389482770646, 14.364318404878889, 8.839250717844282, 2.4192724227905273, 0.9905122837850026, 0.6940737419894764, 2.0746734738349915, 4.671711214951106, 6.469531544617244, 6.426026701927185, 3.158128010375159, 3.7259406617709567, 0.33723985669868334, 0.6833190162267003, 0.28475183461393627, 0.22816698093499455, 3.981782019138336, 27.81595618384225, 43.272988251277376, 28.70858257157462, 18.320113727024623, 31.127193178449357, 36.26133523668562, 18.52950985091073, 1.6442353938307082, 0.03557730093598366, 0.036121519947690625, 0.032642769294657877, 0.03755897942132183, 0.056111412655029974, 0.040950042993894646, 0.02162414090707898, 0.04558560085882034, 0.0338509450001376, 0.08689954557589122, 0.07023520727774926, 0.022903508506715298, 0.07239083839314324, 0.04841573310217687, 0.12082753144204617, 0.07819792428719145, 0.06813193870974438, 0.009231480803074581, 0.04699632266004171, 0.03326099951352392, 0.007363200786390475, 0.042391967227948565, 0.015021621981369597, 0.039899104208286316, 0.01573030261455902, 0.04770703041659934, 0.018519329206485833, 0.02309981208028538, 0.059176545324070115, 0.044115096729780943, 0.03938097147537129, 0.02305693375611944, 0.021906011139175723, 0.02200630709661969, 0.07834088483027049, 0.08235169854015112, 0.24900582273091587, 0.18962761679930346, 0.14277237174766405, 0.0933326818048954, 0.1693646748151098, 0.15420890306787832, 0.25934525792087826, 0.13049605834696973, 0.1437564239438091, 0.14024541234331472, 0.20346498143460068, 0.14979549417538301, 0.13319005950220994, 0.10186492039688996, 0.10781816951930523, 0.17578197403677873, 0.16576208812849863, 0.0905011280306748, 0.12356646518622126, 0.16352452390960284, 0.17553918063640594, 0.15001627589975083, 0.20375453946845873, 0.11622173073036329, 0.09854438036148037, 0.21853120013007096, 0.09358834701457194, 0.09394081203000886, 0.09032552316784859, 0.20623622701636382, 0.15130336183522428, 0.1422016288020781, 0.08175173787666218, 0.1519235021301678, 0.1304952712463481, 0.11271556386990206, 0.18236654571124486, 0.13136114978364535, 0.177796476653644, 0.14194675747837338, 0.23566959691899164, 0.09245644203786339, 0.10528399728770767, 0.20241226149456842, 0.36369148588606287, 8.818326217787606, 43.17364985602242, 47.778478145599365, 42.277356556483674, 35.24780150822231, 26.752244302204677, 36.581271989004954, 43.80755138397217, 17.342884336199077, 1.859312104327338, 0.8497297838330269, 1.7939299898488181, 15.257745572498866, 15.124076128005981, 9.3628956249782, 1.3182961578880037, 3.8516096898487637, 1.649720128093447, 0.4982121118477413, 0.39768592747194426, 0.9191891338144029, 4.789939156600407, 15.145302874701363, 29.3551732472011, 46.0528895514352, 52.991197381700786, 56.592844758714946, 59.76540265764509, 58.967200551714214, 56.559382234300884, 61.46796839577811, 55.293806076049805, 57.50188452856881, 59.27028097425188, 59.10977758680071, 56.623781612941194, 58.06843369347708, 61.774015699114116, 64.5260373524257, 64.63024643489292, 64.10651901790074, 60.888808250427246, 60.91786561693464, 57.64982557296753, 38.83346455437796, 37.828491006578716, 42.99214901242937, 54.92493316105434, 64.0361476625715, 66.41965770721436, 60.288886887686594, 56.35238150187901, 59.86185755048479, 59.28718594142369, 63.476713453020366, 61.95293181283133, 61.7752594266619, 59.273636954171316, 58.43229348318917, 55.27470547812325, 58.266248907361714, 57.80267899377005, 49.837284973689485, 47.611954144069124, 41.2870089667184, 37.728805201394216, 30.228033746991837, 25.79883507319859, 26.76718466622489, 21.001988104411534, 17.000695977892192, 12.0147077526365, 6.508439719676971, 1.9163146913051605, 0.8241022218550954, 0.6993657723069191, 1.4476061505930764, 4.141577993120466, 7.3097958735057285, 12.761005078043256, 11.524541003363472, 16.7057067326137, 10.96195752280099, 7.229063451290131, 2.4719803716455186, 0.46815089349235806, 8.469088912010193, 33.57979610988072, 44.37815134865897, 32.58775315965925, 30.359959193638392, 42.49581486838204, 41.442829268319265, 18.747012785502843, 1.4852733122450965, 0.2283476340983595, 0.1669280148510422, 0.14829948730766773, 0.10604059776025158, 0.15521324346108095, 0.24343309604695865, 0.11610431703073637, 0.14153169760746614, 0.24947186772312435, 0.14908072538673878, 0.2609400052045073, 0.16275365384561674, 0.21581441376890453, 0.19091546269399778, 0.30715279972979, 0.21852697964225495, 0.11295089338506971, 0.05716196806835277, 0.18707291888339178, 0.14820242965860025, 0.0960951064314161, 0.17062343869890484, 0.13267948904207774, 0.12376694514283113, 0.14986485402498925, 0.13209301765475953, 0.10662721163992371, 0.08169873750635556, 0.12477564173085348, 0.14482437020965985, 0.20403913062598023, 0.14959880044417723, 0.08917132153042726, 0.08877758122980595, 0.15691281083439076, 0.16699913889169693], [0.027955552862424935, 0.03608323021658829, 0.004839956361268247, 0.024760377260723283, 0.04378758483965482, 0.10783513968012162, 0.04736762380759631, 0.03900191127987845, 0.048890758505357165, 0.037740660565240045, 0.007490379453104521, 0.0798736818666969, 0.03354526836691158, 0.04577569244429469, 0.10936146349247013, 0.02870297784517918, 0.06375028525612184, 0.08057411999574729, 0.0196454530648355, 0.1132208960396903, 0.09780515717076403, 0.014545887509094817, 0.055509833685521565, 0.020468453277966807, 0.0372427142491298, 0.05172129786972489, 0.04773016506806016, 0.04940117968778525, 0.048119403288832734, 0.03418477065861225, 0.015787521776344095, 0.07331488773758922, 0.014242088721532906, 0.02239690238742956, 0.048779220918991735, 0.05122637103444763, 0.021054990822449327, 0.033432434778660536, 0.05000223279265421, 0.0948783370799252, 0.01096497492731682, 0.024554694636857936, 0.05976615832852466, 0.01679276462112154, 0.02830474733907197, 0.03771900851279497, 2.6947593774114336, 12.596718396459307, 36.14601598467146, 31.353138174329484, 18.352322101593018, 19.702124323163712, 24.850020340510778, 41.32636703763689, 20.982771124158585, 4.462155282497406, 0.11074591920311962, 0.1517617665231228, 1.1419027830873216, 3.2805926161152974, 0.09242321417800017, 1.8961751205580575, 2.6129664863858904, 0.4725752132279532, 0.3959163081433092, 0.3824544719287327, 0.226822219522936, 0.5816351154020855, 5.067217877932957, 12.848941479410444, 23.596791131155832, 36.75285427910941, 46.80001197542463, 51.78343718392508, 56.5416955947876, 59.34735039302281, 56.948293754032676, 57.71119901112148, 59.02320998055594, 59.68775653839111, 62.04240376608712, 58.49762739453997, 61.74516677856445, 65.34023421151298, 65.48267923082624, 65.79634870801652, 61.786869866507395, 59.735754694257466, 46.9774238041469, 24.45566143308367, 34.34705441338675, 30.392369065965923, 52.599020208631245, 66.23021507263184, 63.357558795383994, 59.087571144104004, 59.173013142177034, 56.10829823357718, 58.01721504756382, 61.36380100250244, 60.90447643824986, 58.92920780181885, 57.701607022966655, 55.428455216544016, 51.76653569085257, 44.456388064793174, 33.36100775854928, 22.17554232052394, 14.709709882736206, 11.62231171131134, 9.220242159707205, 6.132543044430869, 4.424020094530923, 3.4496394651276723, 1.8284021743706294, 0.7436807858092445, 0.14260865481836454, 0.27569757189069477, 0.5806448342544692, 1.0026575177907944, 1.0452746195452554, 1.949035061257226, 5.636102071830204, 7.785517317908151, 4.131319846425738, 3.036911257675716, 4.196599909237452, 0.6682940253189632, 0.1483046713152102, 0.8129502545510019, 13.695283310753958, 29.756567205701554, 28.3955888066973, 16.218271493911743, 24.93659142085484, 33.87385082244873, 25.21911038671221, 4.529168052332742, 0.0826766218191811, 0.053077248324240954, 0.025464240295280303, 0.10342245682009629, 0.03776341523709042, 0.059805282657699924, 0.06101999604808433, 0.06893705443612166, 0.02534939654703651, 0.037114501664681096, 0.05871603039226361, 0.0702008530497551, 0.05527747276106051, 0.053554706275463104, 0.027614945246438895, 0.019584719091653824, 0.045161550398916006, 0.0348535483436925, 0.06451407141451325, 0.0419188349374703, 0.02288274872781975, 0.01941970955314381, 0.03859613716070141, 0.01374999137728342, 0.01801947451063565, 0.015269560373521276, 0.05730460291462285, 0.05356862302869558, 0.021829019466947232, 0.06185992740626846, 0.05410704735134329, 0.042986547108739614, 0.05317680637485214, 0.041693961646940024, 0.05283271448154535, 0.039964861036943536, 0.06383434895958219, 0.0444031348451972, 0.07179392435188804, 0.09065603079008204, 0.03141245977686984, 0.06296361211155142, 0.015550501012642468, 0.02808177564293146, 0.06634843655462776, 0.024260580240349685, 0.07281229006392614, 0.010072652184005295, 0.019364127357091223, 0.04750813144658293, 0.027007822645828128, 0.03566044183181865, 0.015272266031908137, 0.02647665186252977, 0.046400100724505525, 0.03791122730555279, 0.08295175419854266, 0.02304979387138571, 0.037271321285516024, 0.01968542386644653, 0.019596220260219913, 0.02084296559249716, 0.01067549322864839, 0.02337330749391445, 0.01848441518710128, 0.04505617391051991, 0.0822357911882656, 0.08744768652000598, 0.052917432971298695, 0.014656799146905541, 0.025979796291462014, 0.02525220319096531, 0.045080638490617275, 0.04580015702439206, 0.04055905754544905, 0.012427408730478158, 0.01639739074744284, 0.031974510688866885, 0.04688285803422332, 0.03249753226659127, 0.041972764900752475, 0.058535173668393066, 0.03501032725242632, 0.07677818475557224, 6.245501211711338, 21.43074754306248, 43.159899371010916, 30.824755464281353, 13.10216770853315, 19.23616075515747, 40.673806122371126, 54.12372248513358, 21.77609212057931, 3.076328388282231, 0.06552288335348878, 0.26802890481693403, 0.3808750052537237, 0.8545689327376229, 1.4664472767284937, 2.0430302917957306, 2.6622487562043324, 1.4310517417533057, 1.5445960547242845, 0.6669698506593704, 0.6355183954749788, 1.2521188003676278, 7.1673217586108615, 17.85908685411726, 30.91727420261928, 42.173536573137554, 51.58964497702462, 54.2977158001491, 59.451948574611116, 61.83842550005232, 59.46262795584542, 57.20503316606794, 59.17262404305594, 60.57813344682966, 61.070566177368164, 57.70898600987026, 60.74821145193917, 65.74260439191545, 64.95694378444126, 67.72739900861467, 63.20787375313895, 61.66726357596261, 50.07716110774449, 29.27012034824916, 33.74726506641933, 33.963020529065815, 55.32407590321132, 63.3125900541033, 64.36754199436733, 61.24698093959263, 60.31728417532784, 59.22623634338379, 60.3267754146031, 63.63852310180664, 61.20735536302839, 61.16445023672921, 59.00563103812081, 57.65660006659371, 53.35280595506941, 49.76853602273123, 41.237402302878245, 27.7365209034511, 18.98082661628723, 15.972571032387869, 13.53574572290693, 10.27639787537711, 7.905008963176182, 6.948466096605573, 3.3877288443701605, 2.3173783932413374, 1.0928350389003754, 1.1497672753674644, 2.341909659760339, 2.975182810000011, 3.233108626944678, 4.092155456542969, 5.369091485227857, 5.94106719323567, 4.904913604259491, 1.703479209116527, 0.29102320809449467, 0.20317891107073852, 0.06633076071739197, 0.7428058013319969, 10.589120660509382, 37.723496777670725, 40.44550221306937, 19.733014277049474, 22.12620837347848, 33.850511823381694, 32.69983802522932, 11.039726104055132, 0.515093845980508, 0.017146238957398703, 0.0460215290742261, 0.028219686189134206, 0.07569986368928637, 0.01818319483261023, 0.03805694609348263, 0.03946578835270234, 0.013479132072201796, 0.018963123339095285, 0.09768889019531862, 0.042041290152285776, 0.036382637186242, 0.054426284506917, 0.022344022457088743, 0.015980673554752554, 0.07525299409670488, 0.03486622337784086, 0.08796374632843904, 0.06573668295251471, 0.049168340396136045, 0.04866027712289776, 0.025789867554392134, 0.030099050075347935, 0.03218167082273534, 0.054022155835160186, 0.06590791804982082, 0.02722946780600718, 0.0504265512738909, 0.035370836300509315, 0.09233663989497082, 0.02003399917988905, 0.0645307090931705, 0.0451414216575878, 0.05219128175771662, 0.006819978797076536, 0.0438368430893336, 0.08317759100879941, 0.12831162342003413, 0.16106898710131645, 0.1261425640966211, 0.1648783776909113, 0.1230444817670754, 0.14932902849146298, 0.22380277940205165, 0.13160281681588717, 0.14270915942532675, 0.12516554152326925, 0.11882866227201053, 0.16320230119994708, 0.1633413601666689, 0.16811284555920533, 0.1742281966975757, 0.20128241926431656, 0.14231206716171332, 0.14597551843949727, 0.1653207146695682, 0.27787667353238377, 0.20588131248950958, 0.1367394219019583, 0.15137646719813347, 0.13199886413557188, 0.0717358553249921, 0.16802241041191987, 0.14655643941036292, 0.17193092139703886, 0.14128883635359152, 0.09954789294196026, 0.21220148620860918, 0.14502090109246119, 0.12110623291560582, 0.12866976777357714, 0.10408456450594322, 0.1683010711733784, 0.17499989457428455, 0.1291680974619729, 0.19988072876419338, 0.24114276894501277, 0.16514060433421815, 0.12482054717838764, 0.1644883829035929, 0.15915353702647345, 0.13748608183647903, 0.15812383299427374, 5.164128312042781, 25.687286955969675, 53.46696833201817, 41.86751011439732, 27.493061235972814, 26.864207574299403, 31.262950556618826, 51.836222648620605, 27.573182650974818, 5.838889156069074, 0.2341551881815706, 0.333888653665781, 2.860877560717719, 10.174201164926801, 2.0801165189061845, 4.571178598063333, 6.229279773575919, 1.1934408290045602, 1.4538693002292087, 1.1849059441259928, 0.4515550940164498, 0.8605972549745015, 6.531420886516571, 15.286351306097847, 28.26448151043483, 43.29308591570173, 52.62822001320975, 55.22830193383353, 58.96406691414969, 61.82334096091134, 57.89553124564034, 58.37242085593087, 58.02694252559117, 60.592036792210166, 62.49380043574742, 57.397060530526296, 61.339808872767854, 65.88295105525425, 67.86655752999442, 68.38726942879813, 62.54940686907087, 63.38265568869454, 52.25669636045183, 32.61864832469395, 37.226478236062185, 38.71785347802298, 60.288407461983816, 63.21240397862026, 66.36744894300188, 62.80787985665457, 63.737819807870046, 60.547325134277344, 62.157479831150596, 64.17973913465227, 62.41301373073033, 60.44100379943848, 58.50966167449951, 55.83061000279018, 51.191134520939414, 48.08740200315203, 36.02837603432791, 24.070632219314575, 16.300357512065343, 13.100556594984871, 11.094779287065778, 7.801919409206935, 6.147935909884317, 4.399420865944453, 2.817284345626831, 1.374265417456627, 0.43626096897891586, 1.2507636845111847, 2.126645565032959, 4.30491624559675, 3.7994074395724704, 5.70213861976351, 11.487478443554469, 16.785871573856898, 12.746782984052386, 8.972904528890338, 10.182298421859741, 2.0511703235762457, 0.2669183872640133, 1.636494449206761, 16.089985166277202, 37.77745301382882, 35.09641415732247, 24.040285961968557, 33.98038755144392, 43.009540353502544, 38.03140619822911, 10.51222928932735, 0.3714185341128281, 0.08518203773668834, 0.08459202439657279, 0.15705724379846028, 0.14313263313046523, 0.1239095867744514, 0.13592992962471076, 0.11638512196285383, 0.1407763117126056, 0.10450516122260264, 0.20399953132229193, 0.1411428970417806, 0.0841044019907713, 0.17392915274415696, 0.11961342873317854, 0.13203504362276622, 0.24025635793805122, 0.12776579628033297, 0.2012005607996668, 0.10400015474962336, 0.1075496935684766, 0.11300366305347, 0.17985473120851175, 0.09216101467609406, 0.10019336294914995, 0.1594506267990385, 0.2002868726849556, 0.12700566064034188, 0.09000603495431797, 0.19858661320592674, 0.13526121979313238, 0.08506851204271827, 0.17052574322691985, 0.11361209861934185, 0.09722948806094271, 0.15855213786874497, 0.1354584970644542, 0.193785462262375], [0.02641062192352755, 0.037298489827662706, 0.0521468614627208, 0.06121453203793083, 0.02111255094808127, 0.02555796124839357, 0.048232233484408686, 0.03942620940506458, 0.018603839046720947, 0.05293713762824025, 0.024602566978761127, 0.04141008634386318, 0.04917561089886086, 0.017516554532838718, 0.10093607380986214, 0.052625557740351984, 0.06885585415044002, 0.0208920185853328, 0.04117970334898148, 0.03421932505443692, 0.053142353759280274, 0.04720752686262131, 0.013152487858730768, 0.028882497855062996, 0.08074175885745458, 0.043442135876310725, 0.017586263827979565, 0.06660083122551441, 0.0356696529446968, 0.12447790056467056, 0.059902414945619445, 0.0333298877812922, 0.04008794728932636, 0.03617237275466323, 0.0350603895661022, 0.03774703200906515, 0.039172929245978594, 0.08572850269930703, 0.11725478672555514, 0.04919876590637224, 0.06257254523890358, 0.014981461189953344, 0.038846598006784916, 0.03713304941941585, 0.028453410968982747, 0.053803141694515944, 0.061085522174835205, 1.6627402922936847, 20.963594096047537, 37.52312462670462, 37.10651411328997, 32.04266003199986, 21.580726146697998, 24.869214739118302, 34.980969837733674, 32.246172768729075, 12.515237740107946, 1.4952423487390791, 0.03618062374048999, 0.69145047132458, 1.2364280308995927, 1.8435852910791124, 1.0787984835250037, 1.477166827235903, 1.6712062380143573, 0.640640846320561, 0.2291730855192457, 0.3784891132797514, 0.2167683932930231, 0.5495945289731026, 3.43708450453622, 8.392706496374947, 16.893761464527675, 22.89201102937971, 25.075487647737774, 23.412311247416906, 23.098233563559397, 25.3710674898965, 30.06093304497855, 35.76187440327236, 46.588123185294016, 55.90075901576451, 57.48922838483538, 60.0676840373448, 60.48372132437569, 56.05661405835833, 47.493567262377056, 37.50896072387695, 34.99540819440569, 27.909013407570974, 46.72775765827724, 32.29761028289795, 33.39169447762625, 64.70529392787388, 57.6416266986302, 63.34489222935268, 59.89262417384556, 58.62288951873779, 58.51734638214111, 62.98537853785923, 62.24143491472517, 62.12237058367048, 58.41307476588658, 51.29201194218227, 32.726630278996055, 18.51763711656843, 9.608310341835022, 2.9447412320545743, 1.5948060176202228, 0.7899209388664791, 0.4094886098589216, 0.5647506128464426, 0.19093542519424642, 0.5167149475642613, 0.47322090715169907, 0.5124506535274642, 0.6774025165608951, 0.37131352403334206, 2.936651791845049, 2.401467881032399, 1.4320954914603914, 3.67115672145571, 4.58899985892432, 3.3565288271222795, 3.4597910004002705, 0.29712782480887, 0.17640037728207453, 0.3326447904109955, 4.37752274956022, 23.21967417853219, 28.05610850879124, 26.469020094190324, 17.215270246778214, 25.582541125161306, 31.52174663543701, 19.422051123210363, 2.9937879145145416, 0.016028868200789605, 0.06767361544604812, 0.08045571563499314, 0.05185706254893115, 0.06729968836797134, 0.042362970033926625, 0.0905759297311306, 0.06261682643422059, 0.033195748193455596, 0.028436216891610196, 0.03579515478174601, 0.028474430287522928, 0.03050238825380802, 0.04782162141054869, 0.014374387783131428, 0.018928126199170947, 0.07104292857859816, 0.013345837260463407, 0.047209654069904766, 0.08236843799906117, 0.010087106676240052, 0.021889436225007688, 0.035116904747805426, 0.054264023035232506, 0.012057374747070883, 0.02964124928361603, 0.05330776363345129, 0.0324177976165499, 0.04746945155784488, 0.034778739857886515, 0.03448727174795099, 0.024101331464147994, 0.03943803287776453, 0.06139617586242301, 0.0018904539049669567, 0.018064186575689485, 0.06949547518576894, 0.07185248870934759, 0.042638044737811596, 0.026586781488731503, 0.04537384704287563, 0.050554522978408, 0.020594141712146144, 0.06783504571233477, 0.05254858133516141, 0.05275700693683965, 0.07963104452937841, 0.06591105288160698, 0.08495727301176105, 0.08012677542865276, 0.03914386419845479, 0.042862293776124716, 0.03262165667755263, 0.05755161001746144, 0.04974390433302947, 0.024365625942924192, 0.014797871666295188, 0.04176307383126446, 0.07430890082780804, 0.035053366728659184, 0.07063584149416004, 0.041468053590506315, 0.032606884970196655, 0.03969397289412362, 0.024828237547938312, 0.02070858851740403, 0.015206454920449426, 0.05639862635039857, 0.03519598121887871, 0.026971105419631516, 0.010386723991749542, 0.053885081583367925, 0.04971893424434321, 0.03405689394899777, 0.049935532800321064, 0.04278285428881645, 0.05064231862447091, 0.0400246196160359, 0.0924878107117755, 0.03707256141517844, 0.06747565285435744, 0.0332519207149744, 0.027308115103681172, 0.0556906971947423, 0.008036217618999737, 0.17795263470283576, 3.1008781109537398, 30.901477473122732, 45.171020712171284, 35.86502388545445, 19.805768864495413, 13.023944888796125, 32.96953930173601, 48.163443088531494, 40.525156361716135, 9.51412924698421, 0.29383834132126396, 0.1369518440748964, 0.2912802371595587, 0.31579188044582096, 1.0035502527441298, 1.536643190043313, 2.3419404923915863, 3.0604995233672003, 1.8010324601616179, 1.5795224777289798, 1.403789073228836, 0.2741180509328842, 1.7699250493730818, 6.006570901189532, 13.664312584059578, 23.591010229928152, 29.756400448935374, 30.50855336870466, 31.38842112677438, 31.659098625183105, 34.383066926683696, 38.15805448804583, 42.205335003989084, 52.13187892096383, 57.194916588919504, 57.857246671404155, 61.39410209655762, 59.663799149649485, 56.665012223379954, 51.83828626360212, 43.34939759118216, 39.992208685193745, 30.136043071746826, 49.51128939219883, 35.09864452907017, 39.583849157605854, 64.6132094519479, 58.066866874694824, 61.89374705723354, 61.41803864070347, 59.31232452392578, 60.42894172668457, 62.63976124354771, 63.72708484104702, 62.26596205575125, 58.89509909493582, 53.50543703351702, 36.61525215421404, 25.570630175726755, 12.902462584631783, 6.183003033910479, 3.537686820541109, 2.174299350806645, 1.5282252303191592, 1.2644579325403487, 1.135181378040995, 1.27341904597623, 0.9674944217715944, 1.274962414588247, 2.438733675650188, 2.4398849053042273, 4.783358344009944, 3.4851365089416504, 5.054012826510838, 3.485544715608869, 2.771709374019078, 1.547879187124116, 0.61912851780653, 0.5413022339344025, 0.12664430003081048, 0.16712622850068978, 2.8383148057120184, 23.33760247911726, 44.645653520311626, 29.705577850341797, 13.73918376650129, 20.914913279669626, 35.93417930603027, 27.4103707245418, 6.94727144071034, 0.20560004615357944, 0.024627277527802756, 0.055876992376787324, 0.052152147250516076, 0.08258624774004732, 0.0266638206584113, 0.05195053414042507, 0.04129880660080484, 0.041092382677431614, 0.03926487074100545, 0.007725547816205237, 0.051267646319632015, 0.04371298669970461, 0.023859756034133688, 0.028615331476820365, 0.03977509854095323, 0.03475579519623092, 0.03138547783185329, 0.06935585982033185, 0.06372828715081726, 0.01424863828080041, 0.02165874619303005, 0.028343452672873224, 0.06728629408670322, 0.0664534941315651, 0.07846465640302215, 0.019155074110520736, 0.03932317386248282, 0.06123867431389434, 0.029246942406254153, 0.06067937146872282, 0.07404104234384638, 0.0405398550044213, 0.09934756226305451, 0.006076659799353885, 0.040897510812750885, 0.043445572656180174, 0.015205742458679845, 0.023413793982139657, 0.08139478095940181, 0.1437728852033615, 0.12755283127937997, 0.15777085907757282, 0.22856408676930837, 0.18661820542599472, 0.144815861380526, 0.10463879190917526, 0.13758632860013417, 0.14354960647012505, 0.09079780389687844, 0.12676577136984893, 0.17756643971162184, 0.11054494391594614, 0.2593631441039698, 0.18061200343072414, 0.1575423963367939, 0.17709327010171755, 0.120028678593891, 0.1728601208222764, 0.10521546525082418, 0.13317974576992647, 0.11967373692563602, 0.08450960953320776, 0.1671528677855219, 0.15319295972585678, 0.0688144431582519, 0.13367576843925885, 0.14500825319971355, 0.1887731376503195, 0.12166750351233141, 0.14279374560075148, 0.09547531218933207, 0.15723060949572495, 0.07701775511460644, 0.26328401799712864, 0.21363107806869916, 0.20010642308209622, 0.2651171482035092, 0.27271163782903124, 0.11154581020985331, 0.10704287540699754, 0.14974182205540792, 0.07979191161159958, 0.16259400812642916, 0.17381061267639908, 0.1931573831077133, 3.11788187282426, 33.08236762455532, 55.715148312704905, 49.217179094042095, 43.1862747328622, 30.883221081324987, 32.826781613486155, 42.95501436505999, 42.412023067474365, 16.57564514023917, 1.8762615833963667, 0.4352644181677273, 1.4382857935769218, 2.956633508205414, 7.231665551662445, 6.322730004787445, 4.630663428987775, 5.231867602893284, 2.7317772081920078, 1.4783955727304732, 1.1797922870942523, 0.31408487632870674, 1.1071702582495553, 4.583474738257272, 10.808473552976336, 20.485017810549053, 28.081092493874685, 29.473438535417827, 28.40508873122079, 29.080667291368755, 32.11407709121704, 35.794249534606934, 40.67045014245169, 54.35824850627354, 61.71974331992013, 62.455064228602815, 60.635789598737446, 61.17888164520264, 55.52687297548567, 55.740700313023154, 48.50103868756975, 42.619242668151855, 35.52224840436663, 52.90363965715681, 40.64860153198242, 39.73655319213867, 62.615755217415945, 57.90884746823992, 65.35515199388776, 62.160335540771484, 61.094704219273154, 62.22166728973389, 64.08507687704903, 64.8124976839338, 62.97849982125418, 59.969075202941895, 52.278614452907014, 35.57959188733782, 22.6864173071725, 12.167060903140477, 4.4895363960947305, 3.060244394200189, 1.431764149240085, 0.8510735545839582, 0.8970204719475338, 0.6514021945851189, 0.9037443740027291, 1.029506008539881, 1.068221805351121, 2.521988728216716, 1.3691154995134898, 5.312325571264539, 4.096655283655439, 7.384827733039856, 10.909553340503148, 12.072672230856758, 9.722131388528005, 9.858319555010114, 2.9646241537162235, 0.3826224229165486, 0.6365800042237554, 5.904686425413404, 28.17468820299421, 38.41533585957119, 32.47374711717878, 23.826396090643748, 33.17461538314819, 45.293955189841135, 30.98574522563389, 6.3055479781968256, 0.23741302479590687, 0.1497844069131783, 0.22382540175957338, 0.12783196701535157, 0.2056405818355935, 0.09791739364819867, 0.33088426345161026, 0.28110804728099276, 0.13741457781621388, 0.09571951694254364, 0.1378733217716217, 0.18472476702715668, 0.12181929179600307, 0.1344375325632947, 0.10639354453555175, 0.08757726635251727, 0.12116103140371186, 0.12612269659127506, 0.20607420642461094, 0.12521518314523356, 0.16369821530367645, 0.054269841473017416, 0.08235439910952534, 0.13559177491281713, 0.2650155579405171, 0.17777297220059804, 0.1103731184931738, 0.08712623734027147, 0.18133366613515786, 0.1356952650738614, 0.17029333141233238, 0.12746109334485872, 0.0785302978807262, 0.16453460470906325, 0.10503479851675884, 0.09632501445178475, 0.1563663458717721, 0.1226302089967898, 0.11830795449869973], [0.062238821360681734, 0.032226206468684335, 0.08964162772255284, 0.01244895560999534, 0.029659827572426627, 0.023549463666443313, 0.06149931318525757, 0.04309448167415602, 0.06982552140418972, 0.04524355135591967, 0.053024275095335076, 0.0305874426183956, 0.033375244454613755, 0.06788364239037037, 0.09844097162463836, 0.022429025931549922, 0.03275017121008464, 0.02087810352843787, 0.016515415128586546, 0.032003077013151984, 0.05568004758762462, 0.030027220358273814, 0.03155988847304668, 0.04572536889463663, 0.035388607132647715, 0.07027701860559837, 0.025822452502325177, 0.05634182618398752, 0.09864291721688849, 0.09289613272994757, 0.006716650212183595, 0.01606759219430387, 0.042369477184755464, 0.039536776686353345, 0.018572840174393992, 0.05675932538828679, 0.04915590624191931, 0.046160978198583634, 0.07400467286684684, 0.027539912844076753, 0.06060599469180618, 0.01358316166858588, 0.10780771329466786, 0.0673688378717218, 0.00884708053698497, 0.040574168520314355, 0.020933068257623484, 0.04721641906404069, 1.4264988260609763, 13.332264253071376, 28.399092435836792, 43.98985127040318, 36.59312214170183, 25.284277541296824, 22.371224437441143, 26.803631441933767, 35.55145515714373, 24.152377775737218, 4.096822474684034, 0.5870392939874104, 0.3109010271728039, 0.5260583204882485, 1.0070744007825851, 2.858604848384857, 1.8898865665708269, 0.12780460848339967, 3.032802483865193, 1.6906369839395796, 0.17968952150217124, 0.08527568235461201, 0.11338905058801174, 0.2899223800216402, 1.0381071184362685, 1.3755322694778442, 1.4647794919354575, 2.150818347930908, 1.4361781009605952, 0.8898361974528858, 1.812420557652201, 4.94446188211441, 12.551278046199254, 24.20912023953029, 42.64184168406895, 54.9387183870588, 57.27364662715367, 57.77599791118077, 55.435938426426475, 48.059657846178325, 37.98835168566023, 40.97378070013863, 44.82477460588728, 35.51941006524222, 44.074125971112935, 60.00545597076416, 61.38522924695696, 66.35594967433384, 65.60510648999895, 63.68421445574079, 63.95631286076137, 61.72910949162075, 58.054158619471956, 54.893860816955566, 42.305604457855225, 27.716348545891897, 11.538099544388906, 4.266628631523677, 0.5695691885692733, 0.4803945965000561, 0.2718119275357042, 0.4019329052950655, 0.567399722124849, 1.3040699384042194, 2.102591335773468, 0.9393670282193592, 1.0147819072008133, 0.8395733088254929, 3.528992235660553, 5.652757772377559, 4.880437706198011, 4.717585827623095, 4.811066457203456, 1.5775813247476305, 0.4325572262917246, 0.7159105730908257, 0.3828598830316748, 0.2170684686196702, 2.0929146664483205, 14.703868184770856, 29.53661503110613, 24.779746259961808, 24.28768699509757, 22.669451543263026, 35.838370595659526, 33.313627992357524, 13.319339735167366, 1.2240073659590311, 0.0747741519340447, 0.06750638370535203, 0.045193404225366454, 0.03961868264845439, 0.03506490182397621, 0.11054045879947287, 0.055347005637096505, 0.04962181213444897, 0.10294539920453515, 0.10679727287164756, 0.060167070744293075, 0.11554833900715623, 0.024467601274539317, 0.023628518085128496, 0.02948339150420257, 0.05237215883763773, 0.016172680305317044, 0.09913279235895191, 0.04665644446920071, 0.026586097864700214, 0.059667078645101616, 0.02080678440896528, 0.04938894909407411, 0.023021626186424067, 0.011049490704733347, 0.03627913345449737, 0.007353642772484038, 0.03278222520436559, 0.04470190399193338, 0.06582185945340566, 0.04906237018959863, 0.011712283710949123, 0.03398264864725726, 0.02414750068315438, 0.03382998166073646, 0.017935105466416905, 0.07314601394214801, 0.027850513945200613, 0.031459638316716464, 0.06479898148349353, 0.09051793534308672, 0.021539681956970265, 0.01612913701683283, 0.048696605887796195, 0.031773633789271116, 0.032124548352190425, 0.02777917786235256, 0.03981016183804188, 0.09407387274716582, 0.04863924253731966, 0.008675968424150986, 0.026955984266740934, 0.04725681225370083, 0.1512613333761692, 0.009611367114952632, 0.03233614271240575, 0.011100069553192173, 0.024456195100875835, 0.005440919136162847, 0.03031120422695364, 0.014912442304193974, 0.027929799065792134, 0.027352818687047278, 0.07538752723485231, 0.08202684989997319, 0.007531438455251711, 0.029488443197416406, 0.06360452914876596, 0.0061579694988072985, 0.04760351311415434, 0.017130111876342977, 0.026692658396703855, 0.04659411084971257, 0.07127947945679937, 0.07884613557585649, 0.06645785032638482, 0.0057287002564407885, 0.06902679069233791, 0.04843495599925518, 0.013291412814786392, 0.06237205171159335, 0.05590502265840769, 0.08973152682717357, 0.03159720789907234, 0.013709851790086498, 0.01783151861413249, 0.011229053971224597, 0.03744385238470776, 2.825103674616132, 21.846248081752233, 42.87931374141148, 46.3368797983442, 28.48072682108198, 17.998841183526174, 24.217539719172887, 38.0725291115897, 48.01400818143572, 27.530249731881277, 4.79243312563215, 0.12435300940913813, 0.36370733646409853, 0.4100873220179762, 0.9275971055030823, 1.0887566634586878, 3.596409086670194, 2.5842024641377583, 2.4914138317108154, 1.9930314889975955, 1.9468398647648948, 0.208494472982628, 0.29249231783407076, 0.5184897780418396, 1.6822677701711655, 3.1423814381871904, 3.8731360776083807, 4.817193031311035, 3.2740113692624226, 3.147668583052499, 5.014914444514683, 9.52760180405208, 18.897462129592896, 34.427323477608816, 50.308518750326975, 59.19968727656773, 63.79584421430315, 61.66173280988421, 56.94162000928606, 52.98322432381766, 43.96460499082293, 46.68636723927089, 50.135522501809255, 39.902305943625315, 45.37190008163452, 64.9194026674543, 62.797540937151226, 69.36264365059989, 65.37935256958008, 63.49083914075579, 63.10078116825649, 62.31587096623012, 60.24065944126674, 58.35414014543806, 47.495505809783936, 31.90590558733259, 17.265253850391932, 6.879132628440857, 2.9850646683147977, 1.2687321603298187, 0.4934195918696267, 1.7015352334295, 1.9591266683169772, 2.9807502712522234, 4.064906358718872, 3.365697409425463, 4.299556578908648, 5.06514253786632, 3.607053292649133, 6.374164044857025, 6.246192557471139, 4.98908451625279, 1.9955198126179832, 1.723699335541044, 0.4128366102065359, 0.5158059277704784, 0.41833917636956486, 0.16555869047130856, 0.6329756804874965, 12.477666224752154, 37.00193330219814, 37.996161460876465, 22.24144424710955, 19.756931713649205, 26.409376757485525, 37.88383688245501, 21.862762212753296, 3.302653146641595, 0.17804004358393805, 0.03361180551084025, 0.08899817974971873, 0.1090428913012147, 0.12908950953611306, 0.024243767838925123, 0.004704439347343785, 0.059607130076204023, 0.023035790604938353, 0.08989003939288003, 0.027244208979287317, 0.013359664955974689, 0.053123514234487496, 0.05839563972715821, 0.039899362051593404, 0.03661192434706858, 0.017920265905559063, 0.06185257208666631, 0.03174410055258444, 0.010776283668487199, 0.06188308580645493, 0.03247163937027965, 0.06932863699538366, 0.038967336528003216, 0.04201261865507279, 0.01613591388533158, 0.055345916588391574, 0.015672070739258612, 0.053205827317599735, 0.03799103320177112, 0.027052721308012093, 0.13121035216110094, 0.012073121000347393, 0.06277972233614751, 0.0225830601661333, 0.04249957609655602, 0.0916429464040058, 0.007667847742725695, 0.036853900112743886, 0.062150788227362294, 0.13649506787104265, 0.11534302788121359, 0.17822604360324995, 0.17274939747793333, 0.11248100109930549, 0.12756724336317607, 0.0904885276353785, 0.1829552969762257, 0.23702088583792957, 0.11721682947661195, 0.12875242690954888, 0.14616970159113407, 0.14939928400729383, 0.2439781225153378, 0.18922764754721097, 0.19419847295752593, 0.1661713533103466, 0.18388547349189008, 0.09449579939246178, 0.12127104907163552, 0.11207040598882095, 0.07397603868905987, 0.10186292550393514, 0.17703483466591152, 0.1492909219648157, 0.10981931856700353, 0.14349163243813173, 0.18403652895774159, 0.14777591611657823, 0.1505078338086605, 0.22866562274949892, 0.09214625653943845, 0.17999490297266416, 0.13687677096043313, 0.1252246554940939, 0.13023756364626543, 0.19835543632507324, 0.17550153551357134, 0.14248384508703435, 0.11779412707047802, 0.199247058480978, 0.11285825299897365, 0.2199986542442015, 0.14372325715209755, 0.12059453608734266, 0.11579776848001139, 0.07407745253294706, 0.09296028821596078, 2.2535400816372464, 22.7508271081107, 51.803225653512136, 59.914427621024, 48.65443059376308, 36.67710501807076, 29.829467705317906, 34.827320848192485, 45.46546452386038, 31.030884197780065, 6.480246101106916, 0.987523689866066, 0.8199004073228154, 1.8804448332105363, 4.454079304422651, 10.010747398648943, 7.870223675455366, 4.5709788373538425, 7.689206600189209, 3.990501574107579, 1.4307775050401688, 0.29704583063721657, 0.27909605524369646, 0.6112217935068267, 1.5843096779925483, 1.970370590686798, 2.0471464480672563, 3.186063025678907, 2.0418280363082886, 2.025835020201547, 3.629856846162251, 6.539204605988093, 16.6349549634116, 30.705163070133754, 48.178089891161235, 61.84845869881766, 65.27794361114502, 65.8080494744437, 64.63105242592948, 56.231399468013215, 52.21706730978829, 54.08385372161865, 55.113187653677805, 45.14861624581473, 52.90234381811959, 63.80473790849958, 60.807917322431294, 67.96310274941581, 67.53571905408586, 64.73911081041608, 64.0445202418736, 61.05812195369175, 58.50479098728725, 56.592493874686106, 42.28009067262922, 29.609025682721818, 14.231845787593297, 5.267496228218079, 1.6182100474834442, 0.8473188674875668, 0.4723406029599053, 1.0422398852450507, 1.3698663392237254, 3.797440665108817, 5.540845308985029, 3.547761057104383, 1.9934099486895969, 3.899522296019963, 8.810576370784215, 9.767144424574715, 11.382691792079381, 10.900437303951808, 10.663271835872106, 6.359536349773407, 6.248086375849588, 3.477036429303033, 1.3890642119305474, 0.46485706738063265, 2.562369704246521, 18.67492175102234, 38.45100791113717, 32.243959767477854, 30.585445608411515, 32.85365377153669, 43.06713397162301, 46.75967073440552, 24.828925609588623, 3.2166846053940907, 0.28214816004037857, 0.09246866245354925, 0.26175728706376894, 0.20386161229440145, 0.2140893606202943, 0.1351212923015867, 0.11836406934474196, 0.21849971610520566, 0.09486138727515936, 0.2227512943957533, 0.11614950746297836, 0.23318979569843837, 0.18179654915417942, 0.17074064883802617, 0.30207130525793346, 0.10777333871062313, 0.09835475696516888, 0.14767227667782987, 0.14580292627215385, 0.09355637444449322, 0.11977519148162433, 0.07216068610016789, 0.13969144278338977, 0.12123226400996957, 0.071853486155825, 0.12548391015401908, 0.17260933427938394, 0.16337452695838042, 0.1175280192068645, 0.15243380117629254, 0.1806384255843503, 0.2259628413511174, 0.1477534837488617, 0.10102017144007341, 0.14925937008644852, 0.07308451152805771, 0.17956023343971797, 0.13251788914203644, 0.1940769880477871, 0.20917082311851637], [0.08502966591290065, 0.07434826942959002, 0.013929962612954634, 0.016417103886072124, 0.06392403093299695, 0.02694353145281119, 0.08622805375073637, 0.07752906517790896, 0.07786076702177525, 0.024623839051595757, 0.03543220300759588, 0.03793855530342885, 0.0805559963253992, 0.033320652919688394, 0.057875393357660086, 0.05242277415735381, 0.06618027522095613, 0.0594051234158022, 0.028776788884507756, 0.05298493702762893, 0.05403640167787671, 0.020774482749402523, 0.06255454370485884, 0.03096410758527262, 0.024000792930434858, 0.019131605280563235, 0.03026239381038717, 0.06200678952570472, 0.1158383855862277, 0.012582208861463835, 0.01323269069793501, 0.05350695776620081, 0.05362957582942077, 0.11261796339281968, 0.07923792169562408, 0.13226421203996452, 0.011346355712573444, 0.07373325207403728, 0.01975969970226288, 0.05375141018469419, 0.032911126501858234, 0.03256490061591778, 0.08505846293909208, 0.09937172489506857, 0.02140808687545359, 0.06944982334971428, 0.056363406990255625, 0.06677495688199997, 0.08299285984997239, 0.5361504160932132, 6.717522740364075, 22.23401141166687, 45.85952465874808, 36.125793252672466, 31.50386197226388, 20.37241530418396, 22.871753556387766, 27.463920491082327, 32.9026073047093, 14.182496207101003, 3.514557353087834, 0.34305883731160847, 0.27162484186036245, 0.5594204760023526, 4.647139344896589, 2.7443388998508453, 1.7362696038825172, 1.947019215141024, 3.0091367023331776, 0.7145974178399358, 0.3224817200430802, 0.16120283491909504, 0.08487356893186059, 0.08629888602133308, 0.16471236731324876, 0.2785676935953753, 0.0590326687587159, 0.08757721885506596, 0.15311435822929653, 0.10871777803237949, 0.17118791198091848, 1.338147486959185, 3.3945185371807645, 6.253078656537192, 5.295827942235129, 15.648573057992117, 15.129151787076678, 6.060032946722848, 7.584875055721827, 17.54391656603132, 27.390451976231166, 20.889993565423147, 11.37012597492763, 11.848070842879158, 26.56917142868042, 34.060983180999756, 41.57625552586147, 47.22991091864449, 50.434590339660645, 44.44640350341797, 39.333686215536936, 28.468873194285802, 18.60006707055228, 6.117136716842651, 3.0441801590578894, 1.0493633087192262, 0.39595579888139454, 0.8165029010602406, 0.8199888882892472, 1.8737385187830244, 4.408968993595668, 2.7470628108297075, 3.3898415310042243, 6.185482672282627, 8.903323531150818, 5.747687969888959, 2.9640092381409238, 7.371679135731288, 5.7144621184894016, 3.799309730529785, 2.319913617202214, 1.5732067823410034, 0.38224209046789576, 0.30816867521830965, 0.7425105028918811, 11.074124029704503, 26.99437686375209, 29.994553429739817, 16.572607040405273, 17.909905978611537, 32.73676075254168, 38.515886715480256, 32.13866676603045, 10.819414360182625, 0.7659704983234406, 0.03984506228672607, 0.03232925218929138, 0.061026387847959995, 0.09443569476050989, 0.043250432770167074, 0.02454880325655852, 0.022073629644832442, 0.04793968311111842, 0.055659084248223474, 0.056596219140504084, 0.06514411153537886, 0.07882145047187805, 0.0908911024619426, 0.07839527619736535, 0.041805930103042295, 0.025964844772326093, 0.03710717687915478, 0.04111538162188871, 0.024121141294017434, 0.01217860181350261, 0.06733443614627634, 0.0221514898418848, 0.040712898397552114, 0.03738190892285534, 0.05847006144800356, 0.03510707277538521, 0.1010826373738902, 0.06160599246088948, 0.09209901693144015, 0.050686498039535115, 0.02826402845260288, 0.03401117765211633, 0.02686116239055991, 0.06007292401045561, 0.02278977755590209, 0.017484061187133193, 0.008843456311816615, 0.026011894390519177, 0.07440507638135127, 0.02557720280518489, 0.10536073959831681, 0.03674110045124378, 0.06668279825576715, 0.05649974503155265, 0.036670227468545945, 0.05164626207468765, 0.0652414813105549, 0.09105863954339709, 0.03948867873155645, 0.034632546095443625, 0.0974186636241419, 0.0548482382936137, 0.012284418501492058, 0.09522946538137537, 0.04385543834151966, 0.06471345892974309, 0.013050888265882219, 0.04301531020818012, 0.030238770613712922, 0.04176704326112356, 0.024825898298461522, 0.025550648337230086, 0.043727497171078406, 0.07873214169272355, 0.04031028625156198, 0.02411711758135685, 0.016470243356057575, 0.022818158979394605, 0.10946954055024044, 0.12377339122550828, 0.030169865382569175, 0.022783182195520828, 0.0487185938150755, 0.08124716566609484, 0.06063017089452062, 0.04097157969538655, 0.0731360734041248, 0.024521180095949342, 0.040521113867206235, 0.041340204022292576, 0.06741254231227295, 0.009846102063810187, 0.04590870227132525, 0.06646882223763637, 0.04498224073488798, 0.02980611632977213, 0.0200057076622865, 0.06139185359435422, 0.072583236997681, 0.13121770748070308, 1.0965782723256519, 12.840578453881399, 35.704037598201204, 50.31264598029, 33.74856090545654, 23.7278984274183, 18.102516991751536, 31.774456092289515, 42.68855789729527, 37.05794620513916, 13.888314689908709, 1.9982485004833765, 0.17365768445389612, 0.3865126541682652, 0.2636747456022671, 0.4550056888588837, 0.6544763924820083, 1.9276886752673557, 2.300060659646988, 1.989328533411026, 1.7684750471796309, 1.1551156512328555, 0.4148038189326014, 0.23186676097767694, 0.5579895270722253, 1.4131801064525331, 0.8196609116026333, 0.4584482769880976, 1.000789646591459, 0.4101218187383243, 1.3043624141386576, 0.7967315848384584, 2.71725395321846, 6.252295681408473, 11.935935156685964, 11.093797854014806, 26.73363528932844, 27.59699239049639, 11.040708405630928, 13.876502752304077, 26.41962535040719, 35.95371069226946, 30.645797661372594, 19.844631876264298, 18.285179921558925, 34.06816414424351, 39.75625133514404, 46.07678440638951, 51.129677704402376, 53.60973644256592, 47.28552777426583, 43.259508746010916, 33.28619303022112, 22.926974364689418, 9.299973607063293, 3.8235789196831838, 1.7818013663802827, 1.4194423875638416, 1.8353571040289742, 2.284256547689438, 4.131183053765978, 6.475874815668378, 5.614018091133662, 6.867761467184339, 6.168492155415671, 14.90385297366551, 9.427383593150548, 3.1784121905054366, 5.386458941868373, 3.1383189133235385, 2.1544151263577596, 0.7161337839705604, 0.4418021844966071, 0.3292351248008864, 0.06487326071198497, 0.19880351370998792, 6.386956981250218, 32.15878874914986, 46.33500031062535, 27.863893542970928, 13.652080280440194, 25.263439893722534, 37.72195427758353, 41.96235302516392, 18.569083315985544, 1.9769314272063119, 0.04495583554463727, 0.015849597552525144, 0.09870138657944542, 0.08358148897864989, 0.08680782799742051, 0.041956673442785225, 0.055880900738494735, 0.09584509341844491, 0.011059171703111912, 0.07366322047476258, 0.049918097843016894, 0.0262742177250662, 0.07063458620437554, 0.013433477691640812, 0.041815490661455054, 0.025569384385432516, 0.06752928426223141, 0.033160518655287366, 0.04911680905414479, 0.02022089316908802, 0.01967075902835599, 0.03507859126797744, 0.07001690220619951, 0.046094173033322604, 0.06457988931132214, 0.035581110910113366, 0.02528122583005045, 0.03710848305906568, 0.0483600898379726, 0.014757739712617226, 0.06602660739528281, 0.03835353035745876, 0.055066187134278674, 0.06870003536875759, 0.052258229415331564, 0.025914595861520087, 0.0070702742502492455, 0.03173475034002747, 0.03802028823910015, 0.0168434664540525, 0.043219810484775474, 0.1448591383440154, 0.1524900110172374, 0.13517617221389497, 0.18865367477493628, 0.11867202924830572, 0.17536110590611184, 0.23207469124879154, 0.24365079722234181, 0.19623871919299873, 0.12481425037341458, 0.19784934419606412, 0.06934355119509356, 0.19838337839714118, 0.09091570614171879, 0.26695505529642105, 0.131988170423678, 0.13241446683449404, 0.12711688610059874, 0.06773422897926398, 0.11407309531101159, 0.19155418127775192, 0.10702283826789685, 0.18247781188360282, 0.17356490157544613, 0.1299696508795023, 0.12603238358029298, 0.1481243981314557, 0.1783715079405478, 0.2531969706927027, 0.08622562459536962, 0.0623177078419498, 0.16100227353828295, 0.19161792285740376, 0.15449472915913376, 0.21101349352725915, 0.1849013761218105, 0.10966307909360953, 0.2737169824540615, 0.13765292002686433, 0.15729733662945883, 0.13099039824945585, 0.15754644040550503, 0.20324981798018726, 0.20163501320140703, 0.12874527515045234, 0.09614436128841979, 0.21152787735419615, 0.26847586940441814, 0.21817962399550847, 0.921634031193597, 13.456324338912964, 40.75839696611677, 62.56265708378383, 47.494619914463584, 44.74012470245361, 29.272284712110245, 31.896966729845317, 35.34612546648298, 42.0134778703962, 18.98527867453439, 5.217820950916835, 0.7364955342241696, 1.1387067203010832, 1.4553030175822121, 10.880878124918256, 9.725382276943751, 4.208251169749668, 5.526255394731249, 5.9124966348920545, 2.469894609280995, 1.1850844259772981, 0.623102453138147, 0.32411886219467434, 0.374869454652071, 0.9115758623395647, 0.48307453840970993, 0.290675445326737, 0.6331817922847611, 0.25682156905531883, 0.4983314254454204, 0.388170776622636, 2.1712288984230588, 4.1282074877194, 7.194764971733093, 6.64107084274292, 20.5644565650395, 23.021834645952495, 6.622089666979654, 10.939956920487539, 25.116459437779017, 35.88595880780901, 29.93474681036813, 15.8921525818961, 13.264177986553737, 29.286483355930873, 35.41946370261056, 43.028800759996685, 48.078928674970356, 50.52978413445609, 46.36897700173514, 41.851866245269775, 29.532317570277623, 21.99815133639744, 7.769015346254621, 4.54443975857326, 1.9727182132857186, 0.669971689581871, 1.5966856139046806, 2.8509392482893805, 5.164141774177551, 8.407452310834612, 6.808683105877467, 8.789802994046893, 12.313211917877197, 17.482994760785783, 14.237300992012024, 8.148714423179626, 16.69935781615121, 13.29489597252437, 11.083866272653852, 9.003522634506226, 4.69404229096004, 1.3994062798363822, 0.5001387170382908, 1.0979975504534585, 13.661210213388715, 35.50943940026419, 40.0524183000837, 23.69106776373727, 25.704931906291417, 42.394152300698416, 50.06089537484305, 46.976662976401194, 18.461855241230555, 1.7828406648976463, 0.19433808832296304, 0.10490603292626993, 0.12842139681535109, 0.2017539061073746, 0.23902850810970577, 0.20869877987674304, 0.2078685922814267, 0.2635917200573853, 0.13113389483519963, 0.127049181876438, 0.16202519222029618, 0.19252474419772625, 0.17063243607325213, 0.2027693066213812, 0.11483366521341459, 0.1061958669285689, 0.1693269211266722, 0.20243573880621366, 0.08793369401246309, 0.17172343895903655, 0.0973714240161436, 0.11524645877735955, 0.24366640352777072, 0.1012649190212999, 0.13658401024128708, 0.10602379044783966, 0.1355556904205254, 0.16337842174938746, 0.18657792758728775, 0.13292890494423254, 0.11042065665658031, 0.12702858155327185, 0.22196268742637976, 0.2101579558636461, 0.08087352357272591, 0.1689177645104272, 0.058799062722495625, 0.10440404593412365, 0.2769295743533543, 0.07703643518366984, 0.14366833652768815], [0.07246237634015934, 0.014144478066425239, 0.03755999043849962, 0.02371799310536257, 0.025141864915245345, 0.08807635600013392, 0.07496601449591772, 0.08498064854315349, 0.05634754623419472, 0.06285669534866299, 0.07693165580609015, 0.018186085391789675, 0.06777851017458097, 0.0344071469402739, 0.030087006078766923, 0.041563947552016804, 0.04185929009690881, 0.01387505471107683, 0.029760701980973994, 0.018385299880589758, 0.05201415019109845, 0.040423662667827945, 0.06259572399514061, 0.004179575971128153, 0.06022687003548656, 0.02216129467290427, 0.024484963289328983, 0.043126291395830255, 0.06171641046447413, 0.06192382504897458, 0.005023278711762811, 0.04115202251289572, 0.013745613978244364, 0.054169418290257454, 0.07563589819307838, 0.039651961398444006, 0.03661699300365789, 0.020718474772625735, 0.0455852683766612, 0.023624972739656056, 0.03140910781387772, 0.028934524527617862, 0.0315480785710471, 0.033581047518444915, 0.04461336535002504, 0.0824186292343906, 0.023419853299856186, 0.045779013873210976, 0.032009367032774856, 0.06387823660458837, 0.23424985738737242, 1.942509182861873, 19.047944477626256, 39.77225998469761, 38.697578634534565, 28.925974334989274, 29.031724180494034, 26.041421004704066, 24.031513861247472, 29.386283806392125, 29.587969166891916, 10.689985922404698, 3.258077847106116, 0.4953956486923354, 0.704352678997176, 0.46899314544030596, 0.5730943136981556, 0.9876424606357301, 2.84727081656456, 1.4969154532466615, 1.018129744700023, 0.6570419062461171, 0.34836951377136366, 1.3928602082388741, 1.1766267312424523, 1.9895860510213035, 1.8859284818172455, 3.6127731800079346, 0.6211362757853099, 1.8576651641300745, 0.5197212376764843, 0.0940374829141157, 0.3043291169617857, 0.0189355290162244, 0.2772229457540171, 0.35095285943576265, 1.4080079325607844, 0.07568323958132948, 0.053078598608928065, 1.2480602924312865, 3.275173455476761, 1.2544708741562707, 0.08833675059889044, 0.34746214960302624, 1.3441742892776216, 4.645945991788592, 9.422592810222081, 16.29574564525059, 13.808817744255066, 12.728557859148298, 7.3716548170362195, 3.3339654207229614, 1.3210696833474296, 0.18794854118355683, 0.19495980281914982, 0.6070078196270126, 3.5283514814717427, 3.583272648709161, 1.619025917989867, 5.28064352273941, 6.610929557255336, 5.929526235376086, 5.950280938829694, 5.561831474304199, 21.514134611402238, 11.775985888072423, 1.2299416703837258, 3.342315201248441, 1.675504024539675, 1.176195617233004, 0.1333294441657407, 0.009508414692910654, 0.6705777027777263, 8.285273449761526, 29.909740243639263, 35.409215109688894, 25.851403406688146, 18.091132368360245, 21.24345885004316, 31.6890766280038, 31.95288930620466, 24.315691709518433, 5.84994330576488, 0.11088762445641415, 0.05107219430751034, 0.09170713581676994, 0.016450328353260244, 0.05310137024415391, 0.09611347437437091, 0.03987543012148567, 0.042864254742328606, 0.06186576280742884, 0.014072095343310918, 0.0735897079908422, 0.023011407449043224, 0.0628989545096244, 0.013320792532925094, 0.055447184547249756, 0.04613281899530973, 0.021804649881752472, 0.02113941584580711, 0.04738779665370073, 0.03850530846310513, 0.024869899598083327, 0.058011901032711775, 0.03461065994841712, 0.10417107093547072, 0.05185467071299042, 0.03292182021375213, 0.019953988026827574, 0.07385515767548766, 0.04451890988275409, 0.01665478791775448, 0.030543127496327673, 0.05028015055826732, 0.032292709685862064, 0.017198399640619755, 0.05515266302973032, 0.020439690178526298, 0.05435324360483459, 0.05800478998571634, 0.05048761942556926, 0.03222619629065905, 0.06737257659967456, 0.07165854304496731, 0.07031949489776577, 0.05765782788928066, 0.020346983635265912, 0.02632220202524747, 0.022882579094065086, 0.05858662019350699, 0.046084242673324685, 0.048180725891143084, 0.036841014732739756, 0.030590648696358715, 0.02792198912772749, 0.05094726583255189, 0.04841811815276742, 0.031608234093125374, 0.03536182874813676, 0.053807352004306655, 0.03500537055411509, 0.07603529747575521, 0.07160445701863084, 0.025346884271129966, 0.08077746337013585, 0.0346278370624142, 0.03645667553480182, 0.006676867704040238, 0.06153155716934374, 0.07711009015994412, 0.04962922512952771, 0.026201131021870033, 0.10439110627131802, 0.08696940075606108, 0.036376258957066705, 0.07204241066106729, 0.03561173319550497, 0.05435302986630371, 0.10516004929585115, 0.0449132506868669, 0.12258018739521503, 0.031173981859215667, 0.03051769600382873, 0.024027527210169604, 0.02538628679966288, 0.014681029632421476, 0.037397993595472405, 0.049915081754859, 0.021931875197749053, 0.125532045428242, 0.0270961696015937, 0.021999403002804944, 0.03186812996864319, 0.04863360391131469, 0.06068397193614926, 0.2610757393496377, 5.530426050935473, 32.50686223166329, 47.9438522202628, 42.295494828905376, 25.649309839521134, 23.953428268432617, 23.30034623827253, 35.74621663774763, 43.86799723761422, 34.683010237557546, 12.632673587117877, 1.8357894122600555, 0.23689636109130724, 0.29151549882122446, 0.20182215315955027, 0.3220061484192099, 0.6228549235633442, 2.1324004105159213, 1.2570363879203796, 1.5676901297909873, 1.513511876974787, 1.305549687572888, 1.9760848326342446, 3.228521078824997, 3.9015607237815857, 2.9944050014019012, 5.221410129751478, 3.0043628556387763, 3.1285008915833066, 1.490159958600998, 0.33305600977369715, 0.3627330958843231, 0.10873967435743127, 0.11770519827093397, 1.7262736431189944, 2.1543161145278384, 0.015703446198520914, 0.23523115473134176, 2.832646595580237, 6.7616225225584845, 3.5142138515199934, 0.15414754993149213, 0.5599090212157795, 3.5596007875033786, 7.648231336048671, 13.9569559437888, 21.536486966269358, 19.008890390396118, 18.299138852528163, 11.369282637323652, 6.211944452353886, 3.018482029438019, 0.5084723755717278, 0.6297452566879136, 1.2809825944049018, 7.1006516218185425, 5.306004447596414, 4.093248929296221, 8.445771626063756, 6.963915416172572, 6.183662244251796, 5.824600185666766, 4.074608215263911, 17.056217295782908, 11.509150743484497, 2.120833614042827, 0.5328809086765561, 0.15145467514438288, 0.6772268574152673, 0.5076009194765772, 0.10044116393796035, 0.7720611372164318, 4.686599033219474, 23.611714124679565, 48.70724037715367, 37.333025387355256, 18.92829302379063, 11.97925283227648, 27.579019137791224, 35.21014922005789, 35.48318910598755, 11.413573060716901, 0.518293165734836, 0.03642507276630827, 0.058733136260083744, 0.025313642840566378, 0.04974731057882309, 0.028150738549551794, 0.0638258604864989, 0.05744262372276612, 0.07242600007780961, 0.03583344790552344, 0.046001013567937274, 0.016847756491707902, 0.05125602301476257, 0.017635698496763195, 0.0302456102467009, 0.0995193130469748, 0.049322673186127625, 0.04931790308494653, 0.014830610980944974, 0.04885413457772561, 0.05073382585708584, 0.04686159613941397, 0.007203812062341187, 0.029578298197260926, 0.024236979096063545, 0.07433937383549553, 0.017803388248596872, 0.02210858776899321, 0.02341901870178325, 0.11453665686505181, 0.04810959845781326, 0.013604298034416777, 0.033034765760281255, 0.06423739197530917, 0.10967399672205959, 0.017541366862133145, 0.06722603339169707, 0.12287297525576182, 0.05406829960910337, 0.04591466659413917, 0.049089189286210706, 0.04640196330313172, 0.06653267238289118, 0.1320280275706734, 0.1393845278237547, 0.17566097767225333, 0.09429116001618759, 0.12361698890370981, 0.1193733766142811, 0.14401915270302976, 0.21121803112328053, 0.18558645221803868, 0.16397422977856227, 0.13696137070655823, 0.12493017129600048, 0.14478259959391185, 0.11424696312419005, 0.1710299625992775, 0.13647765666246414, 0.1512687022664717, 0.15656495307173046, 0.08802123860056911, 0.11847629903682641, 0.11821833359343664, 0.11189262981393508, 0.18621362213577541, 0.11141462224934782, 0.18040009694440023, 0.2227944220815386, 0.12171443099422113, 0.2757767162152699, 0.19455721442188534, 0.1296756552266223, 0.12815644246126923, 0.1135412392073444, 0.19382123462855816, 0.11472862799252782, 0.16750205547681876, 0.1914410830608436, 0.1719686479440757, 0.07480539847165346, 0.19812299736908504, 0.16200626109327587, 0.13517575152218342, 0.13839077257684299, 0.08390667688633714, 0.11624504519360405, 0.28357283930693356, 0.22900993855936186, 0.07633927437875952, 0.12313008574502808, 0.17649134168667452, 0.14569393997745855, 0.3617627093834536, 4.763199882847922, 35.51977831976754, 59.822996275765554, 52.85857016699654, 38.507972717285156, 36.64778362001692, 34.025026253291536, 31.515955311911448, 37.91618422099522, 38.290306500026155, 14.595184462411062, 4.148148383413043, 0.8037878062043871, 1.4882257538182395, 1.619180515408516, 5.039247904505048, 4.28196200302669, 6.626922573362078, 4.17670157126018, 3.992617734840938, 1.7497226191418511, 2.529535774673734, 3.5243808031082153, 5.854298957756587, 5.606292562825339, 3.7960818580218723, 8.005883778844561, 2.724174359015056, 3.1665863565036227, 1.3969877638987132, 0.2249216836478029, 0.3161091905619417, 0.14927783980965614, 0.4405752031930855, 1.8100300516401018, 2.6465985902718137, 0.16716765984892845, 0.23568012778248104, 2.336965147938047, 5.0794050182615, 2.6255631361688887, 0.2253142704388925, 0.6583380166973386, 2.162675231695175, 5.141794196196964, 11.489308425358363, 17.270272186824254, 17.118672915867396, 13.58393669128418, 8.837263533047267, 4.337400376796722, 1.922001140458243, 0.3057669869491032, 0.7933366298675537, 1.381699012858527, 10.1711665391922, 7.407622167042323, 5.6334148560251505, 16.181638853890554, 16.889424051557267, 13.440442493983678, 13.669664434024266, 15.273599624633789, 30.926279067993164, 20.698103427886963, 7.812035986355372, 10.433073673929487, 6.0547953077725, 3.2404847911426, 1.134633447442736, 0.27937851580125944, 1.3978338156427657, 10.591456992285591, 35.362231390816824, 45.21391541617257, 33.37806558609009, 23.50602333886283, 29.483996323176793, 41.96816866738455, 44.7507380758013, 39.14990288870675, 11.040252430098397, 0.3719604121787207, 0.13837471843830176, 0.2069630330162389, 0.06025399108018194, 0.1690424113933529, 0.14428684833858693, 0.17006617145878927, 0.1722795119775193, 0.12657844142190047, 0.1412417460232973, 0.14202248198645456, 0.13455821680171148, 0.24100266503436224, 0.08108479223613228, 0.16661808719592436, 0.18815462583942072, 0.11425073577889375, 0.15040408580430917, 0.12753160670399666, 0.1615696916622775, 0.13150402211717196, 0.15632380172610283, 0.14493813339088643, 0.1984945224331958, 0.0891468942697559, 0.1186065777604069, 0.0948997720011643, 0.1897881988968168, 0.1721427600298609, 0.12830179823296411, 0.16535925545862742, 0.13915381234671387, 0.19072446865694864, 0.1398261726966926, 0.2960944159754685, 0.153001178588186, 0.1665263899735042, 0.12212965371353285, 0.19478556859706128, 0.12427378366036074, 0.2718841779444899, 0.15931388842208044, 0.14848186394998006], [0.012977067896697139, 0.04243625860129084, 0.03651255289358752, 0.09972782685820546, 0.038407026058329005, 0.032189708070031235, 0.04096912679129413, 0.04438592041177409, 0.07255167833396367, 0.03284147488219397, 0.04451023820521576, 0.034488119916724305, 0.02350257520031716, 0.056434666737914085, 0.010700858563983014, 0.03095996512898377, 0.07115463579871825, 0.031003537255206277, 0.026175602838130932, 0.014418835219527994, 0.04377384450552719, 0.027813240320288708, 0.016799248023224727, 0.014785527417968427, 0.06171146394418819, 0.0198868028819561, 0.05806614990745272, 0.061653876677155495, 0.05509500790919576, 0.012147382417294596, 0.03567957991201963, 0.01796164297099624, 0.06381597423127719, 0.10529831437660114, 0.04808808211237192, 0.010743649526765304, 0.06937799363264016, 0.02620131422632507, 0.04406536350558911, 0.05170758806967309, 0.02135375657651041, 0.012964592182210513, 0.0036733752765160587, 0.038110994800393067, 0.06270829974008457, 0.02378381778752165, 0.12552467653793947, 0.026259685201304298, 0.031055038063121692, 0.02291049572106983, 0.03370608455900635, 0.1381618891443525, 1.190623334475926, 10.835539392062596, 35.28842415128435, 44.10361065183367, 43.556071758270264, 26.94584195954459, 17.792097534452164, 13.284292152949742, 19.62542142186846, 35.54502807344709, 24.043301480157034, 14.610637256077357, 5.367971956729889, 0.9606273216860635, 0.15317951116178716, 1.0176199206284113, 1.0414857885667255, 0.3838351549846785, 1.4536378383636475, 2.2069613124643053, 0.40293290306414875, 1.900525995663234, 3.03715227331434, 5.798647795404706, 1.2280957294361932, 1.1745805953230177, 4.252513800348554, 5.79580294234412, 0.6114375133599553, 1.302043235727719, 0.7382936520235879, 0.8096003543053354, 0.11863967669861657, 0.2386626691690513, 0.28901273597564014, 0.20586772821843624, 0.08083711338362523, 0.019434925700936998, 0.04553572174959949, 0.10839016096932547, 0.19958836159535817, 0.0200658530063395, 0.2640399602907044, 0.2212683425417968, 0.12701916348721298, 0.6780054356370653, 0.38835740089416504, 0.5849425122141838, 0.11704704644424574, 0.26241763734391754, 0.013929681020921894, 0.8432114507470811, 0.5444458052515984, 0.9683013898985726, 7.752153805324009, 5.459097581250327, 3.3518668029989516, 4.88362432377679, 4.5673562203134805, 5.60894547189985, 4.969553564276014, 1.4794633154358183, 11.83934998512268, 10.035199846540179, 1.3605582501207079, 0.2112946512975863, 0.10740120975034577, 0.1281773006277425, 1.717204941170556, 10.156099370547704, 24.998275790895732, 51.66374404089791, 27.518206766673497, 19.47789032118661, 25.72083980696542, 25.362870352608816, 38.77208416802542, 32.90064443860735, 14.589563369750977, 2.405406858239855, 0.00548570541598435, 0.025066031841561198, 0.0434126772784761, 0.05163215193897486, 0.06603279563465289, 0.04002604114689997, 0.03303836878123028, 0.04685468186757394, 0.02092119219845959, 0.012691048422961362, 0.024235197941639593, 0.05932056438177824, 0.011681956588290632, 0.019298916749124016, 0.04154239049447434, 0.004308516284384365, 0.012952473546777452, 0.026093115032251393, 0.021867836759026562, 0.05610244581475854, 0.020232735301500986, 0.0717797361846481, 0.024254108712609326, 0.03172371057527406, 0.016280697991273234, 0.008851053359519159, 0.05078411547999297, 0.020419956683846455, 0.04002499620297125, 0.03881863557866641, 0.042264436571193595, 0.004210967121512762, 0.04049430834129453, 0.03029809832306845, 0.03007088408672384, 0.1496356041835887, 0.08017241369400706, 0.0363519131205976, 0.08386735578200646, 0.055179553372519355, 0.03272931643628648, 0.026474239670538476, 0.02584762784785458, 0.01341555842996708, 0.02888074384203979, 0.0707331027037331, 0.02200735204054841, 0.07563215267977544, 0.042159148292349916, 0.09677284077874251, 0.01924611485031034, 0.009694931247005505, 0.03443617806104677, 0.07210177568984882, 0.020091910447393144, 0.03823748390589442, 0.0450162149832717, 0.02303225713382874, 0.035957806411066225, 0.044735803601465056, 0.022469709194930534, 0.03719007350238306, 0.010099176117884261, 0.05220034698556576, 0.01302393855127905, 0.037691534629889896, 0.03832656876849277, 0.04194215279338615, 0.040979596586631875, 0.052553005383483, 0.08713755530438252, 0.04920875054917165, 0.05005817800494177, 0.027368854165875485, 0.05133391883490341, 0.06916492006608418, 0.032429875539881844, 0.009833526265408312, 0.009673996745342655, 0.027023647778800557, 0.021243187598884106, 0.03091311567862119, 0.01990383241458663, 0.022673451208642552, 0.05047090371538486, 0.02753306642573859, 0.07195897120982409, 0.01667773936476026, 0.029379860631057193, 0.06378255638160876, 0.05259357499224799, 0.05067979411355086, 0.08456761070660182, 0.11427295101540429, 0.0375163233173745, 0.18042552843689919, 3.004927831036704, 21.269120284489222, 44.97289630344936, 46.179395403180806, 39.93301698139736, 25.169178894587926, 15.114254849297659, 20.565802778516495, 38.00762946265084, 43.49006387165615, 34.244575432368684, 17.85491098676409, 2.949390879699162, 0.4939834816115243, 0.06991374452731439, 0.31476571836641853, 0.560509226151875, 0.22093067637511662, 0.35430026267256054, 0.9276334749800819, 1.116390626345362, 1.2367687097617557, 2.928582544837679, 4.946042163031442, 7.582166995321002, 7.452961768422808, 4.505958029202052, 5.482863460268293, 1.8336261340550013, 3.6240016860621314, 2.7231584021023343, 1.3536134170634406, 0.6424839645624161, 1.2705721301691872, 1.1165009289979935, 0.40881851581590517, 0.3963623499231679, 0.10090227598058325, 0.09337323105760983, 0.06878471653908491, 0.6360361991184098, 0.3434599329318319, 1.0202487281390598, 1.068021501813616, 0.8428605124354362, 1.9015510720866067, 0.9785342408078057, 0.7091418334415981, 0.3532556715820517, 0.5658120587468147, 0.5261610235486711, 2.1932642417294637, 1.9615617947919028, 3.364312980856214, 10.139786737305776, 6.079424500465393, 4.7339679428509305, 4.500122845172882, 3.2536459820611134, 2.3970744482108524, 2.5471707369600023, 1.8794067289148058, 2.102203105177198, 3.1715048125811984, 0.3911423257419041, 0.4132773865546499, 0.02665044503685619, 0.20600898563861847, 0.18887829700750963, 7.202123548303332, 20.828411681311472, 47.647601876940044, 50.16278723308018, 24.824841805866786, 18.196176971708024, 18.253600358963013, 34.52499777930123, 40.9647341455732, 25.33329360825675, 5.6526492067745755, 0.007071886195002922, 0.06072610217545714, 0.031071638422352926, 0.029996618428932767, 0.029446319743458713, 0.011685456980818083, 0.0325088671940778, 0.059826765076390336, 0.04975685078118529, 0.0639046316168138, 0.04823997217629637, 0.04386276312704597, 0.024143175022410493, 0.05206731340980955, 0.06439036769526345, 0.009734457608179321, 0.03884939696373684, 0.10764521094305174, 0.05221224509711776, 0.04792293008150799, 0.05448616861498781, 0.04177443929282682, 0.06291606716279473, 0.04732743417844176, 0.03930143020781023, 0.018017211596348455, 0.04220873223883765, 0.00909615377895534, 0.011672502050974538, 0.014877782735441412, 0.009184530420627977, 0.04036517634189554, 0.027952920146552578, 0.030302763251321654, 0.028958100226840804, 0.10782203038356133, 0.06975188678396599, 0.04347594727628997, 0.032864416151174476, 0.04171485034748912, 0.03767755002315555, 0.041181715205311775, 0.01592568338050374, 0.018495432899466584, 0.14615056690360817, 0.1254170880253826, 0.1510999370366335, 0.3551260397902557, 0.09464245795139245, 0.22405841068497725, 0.05920272320508957, 0.18029302411845752, 0.15380228417260305, 0.2229575826121228, 0.12499726483864443, 0.1401345668626683, 0.10094351733901671, 0.10199164359697274, 0.11241045381341662, 0.11586665335510458, 0.19511205250663416, 0.0920627424493432, 0.11996071652642318, 0.0963138389800276, 0.15067830894674572, 0.09231070628655808, 0.24688626932246344, 0.21717350584055695, 0.13105773606470653, 0.20239383248346193, 0.20366337150335312, 0.15279962654624665, 0.2202392763325146, 0.0753106763586402, 0.13868950440415315, 0.1369104262973581, 0.1764461241130318, 0.18605249721024716, 0.09680810424366168, 0.07351840074573245, 0.13300241742815289, 0.09825178249073879, 0.21012128783123835, 0.1325792015663215, 0.14337972844285624, 0.10384968282388789, 0.10787401973669018, 0.16436569020152092, 0.17119876854121685, 0.16717212460935116, 0.1566299024437155, 0.10595620835998229, 0.1334425559533494, 0.24211687381778443, 0.1411513380174126, 0.26177359904561726, 2.3155544911112105, 20.701296125139507, 53.34111908503941, 59.31452710287911, 54.38139295578003, 37.22002683367048, 26.895978212356567, 19.0650109904153, 29.09899663925171, 45.35317816053118, 32.60887220927647, 21.073825529643468, 7.194531772817884, 1.3507807233503886, 0.19847788475453854, 2.0720014572143555, 2.8193310243742804, 4.063637009688786, 4.556254301752363, 5.685327887535095, 5.88241788319179, 4.816562916551318, 8.05668032169342, 13.975158487047468, 12.714981947626386, 10.081593837056841, 8.252527458327156, 12.614699465887886, 1.4188832747084754, 3.751635100160326, 2.5966597156865254, 1.9869661458900996, 1.2930241482598441, 1.529796825987952, 1.3365046722548348, 0.33997470566204613, 0.27396947890520096, 0.09736069637749876, 0.17595023715070315, 0.14859549142420292, 0.3868815058044025, 0.25908860883542467, 0.9472800493240356, 0.7219729306442397, 0.40333755420786993, 1.4216870899711336, 0.7208076417446136, 1.0169966455016817, 0.3520202493028981, 0.5981418096593448, 0.42003459110856056, 2.2202271606240953, 1.835458287170955, 5.974664338997432, 22.17420652934483, 12.887635128838674, 12.856190187590462, 10.782054764883858, 12.559018339429583, 13.334712624549866, 12.30794084072113, 9.02996747834342, 20.562891483306885, 18.548775468553814, 3.5180201615606035, 1.4657990315130778, 0.9081037172249385, 0.23642412785972866, 2.1491733619144986, 12.208314963749476, 29.83172239576067, 58.17362247194563, 37.81458418709891, 25.40096037728446, 34.71615661893572, 34.66351359231131, 48.48374114717756, 47.87923397336687, 28.123096091406687, 4.590120255947113, 0.07038054947874375, 0.12865124376756804, 0.14256814627775125, 0.13106351718306541, 0.13841676046805723, 0.09183442898626838, 0.16419061459600925, 0.1549275123647281, 0.13933982593672617, 0.1407509752150093, 0.11801070187773023, 0.1388584596237966, 0.11973002819078309, 0.17105301921921118, 0.22397970062281403, 0.06918514719499008, 0.1303966122546366, 0.2055091496024813, 0.17412218238626206, 0.22021817389343465, 0.18286737240850925, 0.20832093086625847, 0.22623216547071934, 0.22716502898505755, 0.14374847151339054, 0.08473201295627014, 0.2506089567073754, 0.12496168246226651, 0.168991765539561, 0.09335951786488295, 0.0868822361475655, 0.1097944299025195, 0.11685761303773948, 0.18265807149665697, 0.15336813032627106, 0.21790271385439805, 0.12461044559521334, 0.18993229259337696, 0.15116994827985764, 0.159241719437497, 0.15438644854085787, 0.09406372186328683, 0.10197649869535651, 0.09774400759488344], [0.0371604350927685, 0.1336083627705063, 0.04262297447504742, 0.078650581783482, 0.05502536307488169, 0.09280350591455187, 0.04873674462682434, 0.03191703198743718, 0.012599959337551678, 0.028697817586362362, 0.02020113422934498, 0.02444937582393842, 0.05553233390673995, 0.05455426638945937, 0.05800901725888252, 0.019017231417819858, 0.02534234317551766, 0.01663261678602014, 0.04694770223328045, 0.06859526277652808, 0.07009278277733497, 0.10792450952742781, 0.05129960531901036, 0.022097883879074028, 0.0744951722611274, 0.0688094694965652, 0.018374076911381314, 0.06434558438403265, 0.027373130632830516, 0.027236139501578042, 0.059402680689735074, 0.0636797176141824, 0.0181352410665048, 0.07309929002076387, 0.10246194978909832, 0.016152332736445323, 0.023369740096053908, 0.06661314663610288, 0.04086271892966969, 0.03909242785136614, 0.035896728081362586, 0.02347204282081553, 0.030450246230299984, 0.04934587569109031, 0.07353894678609711, 0.05411094553502543, 0.022918295481109192, 0.11414272657462529, 0.1051082160057766, 0.0672375074188624, 0.12932360411754676, 0.02596919927080827, 0.04052616556042007, 0.301149094743388, 6.24292299577168, 28.98552908216204, 41.883713313511436, 42.2665799004691, 32.238574913569856, 23.997377361570084, 24.387251206806727, 20.631067207881383, 16.31302755219596, 28.662071330206736, 33.11295706885201, 21.120628595352173, 12.269263693264552, 3.3695738528456007, 0.7266526509608541, 0.0615700368902513, 0.07880519277283124, 0.48335469194820946, 1.1360852952514375, 1.4355299643107822, 3.2021259580339705, 2.7141161901610236, 6.833239342485156, 5.8468122737748285, 3.5581460084233965, 3.57658457330295, 1.8172933076109206, 5.795500695705414, 3.9732014281409125, 1.2933361658028193, 0.9752190815550941, 1.1271612026861735, 0.32036534217851503, 0.33135291401829037, 0.6822286918759346, 0.0977795221177595, 0.327290552003043, 0.07006910869053432, 0.6657810573066983, 0.6086120392595018, 1.1604007333517075, 1.6932816420282637, 0.6961305173380035, 0.450959394552878, 0.10346356247152601, 0.07069763567830835, 0.310467823275498, 0.2663774591471468, 0.22195485713226454, 0.7347920856305531, 1.3306369185447693, 1.6634966688496726, 5.569681635924748, 4.166162022522517, 3.1706035009452274, 3.7245857630457198, 1.8401253053120203, 1.7024763886417662, 0.5710993121777261, 1.3536734538418906, 1.7219652171645845, 0.744445304785456, 0.2871196504150118, 1.2980113263641084, 4.817358485289982, 13.943066494805471, 33.11617408479963, 31.858070714133127, 47.177278314317974, 38.481910024370464, 17.290376799447195, 30.027626855032786, 31.48069667816162, 39.63688128335135, 32.75017424992153, 9.515386870929174, 0.6277567691036633, 0.08091617628399815, 0.029724298577223505, 0.0685727625553097, 0.09648755751550198, 0.024481976038909385, 0.004889427925393517, 0.01974945721615638, 0.058463615365326405, 0.042383617854544094, 0.028682136642081395, 0.09283143441591944, 0.08632781196917806, 0.018677455007231662, 0.027394136380670325, 0.015975606594500796, 0.037550219534231086, 0.054331333709082434, 0.07961801665702037, 0.07434685807675123, 0.03126651707238384, 0.0250299592236323, 0.038425427928034744, 0.05037433461153081, 0.021332942514813373, 0.04032506474426814, 0.0259514114752944, 0.05594594171270728, 0.1138154962765319, 0.03747986563082252, 0.06889053407524313, 0.03857702961457627, 0.051463851505624394, 0.06250703268285308, 0.09520418995193072, 0.010609232587739825, 0.03566426198397364, 0.015507610814113702, 0.0008321828593450066, 0.04703796774681125, 0.06925353673951966, 0.03025437013379165, 0.04274334998003074, 0.03605395143053361, 0.042987724366996966, 0.046838084901017804, 0.08014572691172361, 0.029690354862915616, 0.04569979151710868, 0.060406267909067016, 0.015927065895604234, 0.0911901124886104, 0.038705859665891955, 0.05359459395653435, 0.03714945639616676, 0.058777831361762116, 0.013081002498178609, 0.016852509629513537, 0.05624860225777541, 0.09111683070659637, 0.06533323960112673, 0.07938131650111505, 0.050671977390136035, 0.012748084380291402, 0.07292374622608934, 0.07526345710669245, 0.025108579379905547, 0.10890710965863296, 0.05347464932128787, 0.06895939180893557, 0.046451584569045475, 0.0212014712659376, 0.019821828064907874, 0.057052391448191235, 0.044421177091343064, 0.05328492075204849, 0.01892078614660672, 0.08284712409866707, 0.038079900933163505, 0.039796882907726934, 0.026752284661467587, 0.04461997767378177, 0.019757331615047793, 0.02545509873224156, 0.0936250150469797, 0.029787327695105757, 0.024724255449005535, 0.010805341930660819, 0.036420071963220835, 0.03091835736164025, 0.03508727312354105, 0.0285176190414599, 0.10908920810158763, 0.10707330091723374, 0.03337598066510899, 0.02891046367585659, 0.14619499737662928, 0.026885267347097397, 0.06371814983763865, 0.6701257984553064, 14.029000077928815, 41.335743631635395, 47.92808675765991, 38.22807148524693, 28.121572698865617, 13.40265645299639, 17.065062352589198, 31.889052731650217, 29.094101633344376, 40.56113413402012, 41.229213850838796, 24.475826842444285, 6.705527109759195, 1.7724822035857608, 0.4606665979538645, 0.13658896354692324, 0.09269111337406294, 0.34422806171434267, 1.1093075892754962, 0.9260510227509907, 1.658857877765383, 0.6266032052891595, 0.4433838767664773, 1.3727754631212779, 1.628351269023759, 2.249686654124941, 2.458084191594805, 2.649281463452748, 2.3935934007167816, 1.5958566069602966, 1.9038559198379517, 0.9885469206741878, 1.1573202929326465, 1.6383728512695857, 2.337039406810488, 1.9177510142326355, 1.406147118125643, 0.5518109500408173, 2.370738821370261, 2.0877636628491536, 2.4427108679498946, 3.7257426381111145, 2.055536832128252, 1.2703529362167632, 0.4629963072282927, 0.7257780464632171, 0.9448906289679664, 1.0269556939601898, 0.4360350439591067, 2.054946235248021, 2.5757167594773427, 4.1813008444649835, 2.998139875275748, 3.434999176434108, 1.8674525703702654, 1.6033796604190553, 2.073826879262924, 1.3968415260314941, 0.4559604419129235, 0.603821147765432, 0.26573342084884644, 0.16039469971188478, 0.1251468410981553, 0.5646723370466913, 2.431885791676385, 11.331804922648839, 33.84396662030901, 45.95461770466396, 56.883765833718435, 55.87638473510742, 17.26593824795314, 20.15235022136143, 30.889575208936417, 38.55586665017264, 42.2302998815264, 18.619072130748204, 1.3576448921646391, 0.10907466031078782, 0.11962823436728545, 0.02507727686315775, 0.07581490251634802, 0.015042067937819021, 0.057587742007204464, 0.08992672099598817, 0.042947127616831234, 0.06086124599512134, 0.06240935078156846, 0.07049641611852817, 0.005734129384758749, 0.06580308438943964, 0.01665440115279385, 0.05736539965229375, 0.018131995972778116, 0.07653386465140752, 0.01680399098300508, 0.04057796492374369, 0.06851469352841377, 0.04227953397535852, 0.057299500331282616, 0.0526908599505467, 0.03397574116076742, 0.006828317992455725, 0.014475740558866943, 0.04254988268283861, 0.03887226698654039, 0.030578462207423787, 0.01882590489861156, 0.033632511006934304, 0.0231224666682205, 0.06848871920789991, 0.018532701435365846, 0.06255242667560067, 0.04337824841162988, 0.022016474943874136, 0.04997277419481959, 0.0409271729710911, 0.014403708977624774, 0.03706800165985312, 0.03518528411430972, 0.028018889017403126, 0.08346844504454307, 0.002851524332072586, 0.2094568663409778, 0.2943446641521794, 0.12671170569956303, 0.11933141600872789, 0.17332582654697554, 0.2956596107355186, 0.21044482689883026, 0.17150174799774373, 0.15083870105445385, 0.09883695787617139, 0.12694388681224414, 0.0858052314392158, 0.14533842833978788, 0.17948932653026922, 0.1707875763199159, 0.2079521335129227, 0.16533528960176877, 0.09378788380750588, 0.12389873021415301, 0.1425004827656916, 0.11403866644416537, 0.2500456640762942, 0.08535634659762893, 0.22115285588162287, 0.20055462260331425, 0.17918512571070874, 0.11603187663214547, 0.22083965768771513, 0.09109845597829137, 0.13871165178716183, 0.12842663510569505, 0.2757684923708439, 0.11687293435846056, 0.1675504350236484, 0.22603631312293665, 0.1227596327662468, 0.165118185537202, 0.16392133118850843, 0.20084050297737122, 0.09104000697178499, 0.12867560317473753, 0.13649417220481805, 0.22023204314921582, 0.08859392215630837, 0.13048279977270535, 0.08144874484943491, 0.188811542732375, 0.22893749816077097, 0.15910924226045609, 0.14454581801380428, 0.2520967125892639, 0.09481415445251123, 0.22156889284295694, 0.5273268009935106, 11.57115386213575, 44.26397507531302, 57.24857752663748, 53.098265647888184, 45.288115228925435, 35.089163712092805, 32.78966433661324, 30.396152360098704, 21.61732404572623, 37.09653997421265, 42.5739369392395, 27.896237407411846, 15.796361242021833, 4.81949679340635, 1.3768000985894884, 0.215540882732187, 0.5796223634055683, 2.3709018869059424, 3.3877027886254445, 3.715544853891645, 10.01983564240592, 7.636623501777649, 14.929271221160889, 15.445902790342059, 11.682084458214895, 9.659066932541982, 7.712430953979492, 13.327333637646266, 12.853592429842267, 3.9549589327403476, 3.3380437961646487, 2.7321710841996327, 1.6878882114376341, 3.747615567275456, 2.5733673998287747, 1.631998313324792, 1.1273299136332102, 0.36851141867893084, 3.173671130623136, 2.7874077430793216, 4.760435368333544, 4.987350506441934, 3.1995909512043, 1.2619413818631853, 0.4080177630696978, 0.652233427124364, 0.9983498517956052, 1.3794962167739868, 1.469818564397948, 3.119299956730434, 4.231009994234357, 8.155523657798767, 12.82510655266898, 15.8656747341156, 11.667507137571063, 13.24441123008728, 10.114753246307373, 7.208327855382647, 5.059947890894754, 4.047376922198704, 3.4197963007858823, 1.6651613052402223, 0.7515945125903402, 1.9556675510747092, 6.744586842400687, 18.650059359414236, 41.706294536590576, 41.51487513950893, 52.48846742085048, 48.702970709119526, 25.38501947266715, 43.255058424813406, 41.99080242429461, 51.12963948931013, 46.41407775878906, 19.99632842200143, 1.1074164850371224, 0.19542546783174786, 0.15425524700965199, 0.1922604955200638, 0.1685414489890848, 0.08870389911213092, 0.15438798203, 0.13556736122284616, 0.1746717957513673, 0.16529931367508002, 0.1927865772907223, 0.16903726809791156, 0.18252533647630895, 0.14813620464078017, 0.0883523365482688, 0.1614877110613244, 0.12853847124746867, 0.1250199279082673, 0.20615818191851887, 0.18228094173329218, 0.2021044644394091, 0.12862502517444746, 0.12551297859421798, 0.1759735651846443, 0.1332082985235112, 0.1815512858863388, 0.0774997321090528, 0.19310262533170836, 0.19022480903991631, 0.1386752687394619, 0.2563354122851576, 0.11254763323813677, 0.16747826603906496, 0.185550150594541, 0.14510892065508024, 0.26703039982489174, 0.11349696479737759, 0.08819467215133564, 0.1176090362880911, 0.10935696480529648, 0.17895339243113995, 0.22567636386624404, 0.14881912299564906, 0.11191516396190439, 0.3127806234572615, 0.2013708052358457], [0.06006942955510957, 0.03654520399868488, 0.036880671711904664, 0.05106655228883028, 0.032597249772931845, 0.023410409788734148, 0.014575018713782941, 0.030887304206511805, 0.07591847410159451, 0.003415427856712735, 0.0336830652584987, 0.03372843550252063, 0.012295289480659579, 0.06543007333363805, 0.03884465739663158, 0.0645130875387362, 0.09645293187350035, 0.01006093218789569, 0.016315145517832468, 0.032657714028443606, 0.03205229115805455, 0.018591289541551044, 0.06111638194748333, 0.035559726879000664, 0.01777330200587, 0.0369232769257256, 0.016859167754384022, 0.027257314883172512, 0.04945184250495263, 0.03730956351916705, 0.034446627500333955, 0.013662853062019815, 0.014011364762804337, 0.01172859060378479, 0.02898335869290999, 0.056018589064478874, 0.004443010406768215, 0.04224218062258192, 0.0673521730516638, 0.06395062272037778, 0.07090739120862313, 0.027713582185762267, 0.015305161409612213, 0.034081962425261736, 0.030230295711330006, 0.07625992649367877, 0.039327285784695826, 0.05626274971291423, 0.03836620878428221, 0.03811598203278013, 0.04541999420949391, 0.00880482985771128, 0.06034695037773677, 0.024983007993016924, 0.1367436559604747, 2.4602400873388564, 17.55631388936724, 40.31101288114275, 44.627421447208945, 41.95303896495274, 38.912865093776155, 21.46743403162275, 29.704410552978516, 21.644244841166906, 16.822559799466813, 26.75073654311044, 33.608572074345176, 31.13339444569179, 24.9001133782523, 14.732635463987078, 6.760624587535858, 2.863708734512329, 1.46003235237939, 0.4464382071580206, 0.14674444789333002, 0.8945515815700803, 1.250006547995976, 2.740519344806671, 1.3229268065520694, 1.7634870005505425, 3.266279544149126, 0.8842255813734872, 1.2311066878693444, 1.3257773050240107, 2.0669036507606506, 0.6704462841153145, 1.4001271554401942, 0.8569749636309487, 2.2498112874371663, 3.501993707248143, 1.6239701041153498, 0.8562297150492668, 2.9918511041573117, 2.364686071872711, 3.1951035005705695, 4.182945830481393, 1.5230263492890765, 2.498243476663317, 1.2125915842396873, 1.365045809320041, 0.8784529311316354, 1.568873603429113, 0.8001150861382484, 2.222334853240422, 2.895256378820964, 3.3646217414311, 1.589281222649983, 1.9522518600736345, 1.1037229746580124, 0.6617122899208749, 1.1759362540074756, 0.2649503914373261, 0.27122388194714275, 0.5639781685812133, 3.1260846555233, 6.284953951835632, 14.747772114617483, 27.69402919496809, 43.57245908464704, 36.3251440184457, 20.664955309459142, 27.844145025525773, 31.763220855167933, 21.453779084341868, 26.707230397633143, 30.86182062966483, 38.325499125889365, 22.798790522984095, 4.467271327972412, 0.0692700387111732, 0.05803296275969062, 0.10864450982106583, 0.06342979959611382, 0.03788716984646661, 0.06411680273179497, 0.07200291313763175, 0.05759928388787167, 0.09983941194202219, 0.026244148445714797, 0.00786090622256909, 0.05544245855084487, 0.05125391955620476, 0.031205655873886178, 0.0425385884674532, 0.025246534030884504, 0.017679776131574596, 0.025042737734370997, 0.04445530061743089, 0.04897958552464843, 0.02968698932922312, 0.11200486629136971, 0.024711819598451257, 0.026739845418238213, 0.03230766120499798, 0.10371052886226348, 0.05703718547842332, 0.00849074702377298, 0.05467164616233536, 0.06154113808380706, 0.03148009614752872, 0.005839996962874595, 0.02225368739371853, 0.04387318542493241, 0.02586121890427811, 0.08076933452061244, 0.03841913112306169, 0.04575939064047166, 0.059059674452458105, 0.04153279600931065, 0.08004911709576845, 0.026234404682847004, 0.05000998166256717, 0.01923194364644587, 0.007797830455404307, 0.028831472021660635, 0.012288532968211387, 0.012157586735806294, 0.029161440208554268, 0.03046367104564394, 0.025636554263266068, 0.020713584231478826, 0.032427334426237006, 0.027469311275386384, 0.043539037462323904, 0.002703883805744616, 0.032158044233386, 0.03839092102966138, 0.028235105897432992, 0.03160759287753275, 0.0466300460643002, 0.0475580512679049, 0.03588845334681017, 0.03318229962938598, 0.03359171748161316, 0.040819350363952775, 0.04485421474756939, 0.019700058170461228, 0.012404434382915497, 0.0844188215477126, 0.034188197260456424, 0.02180974737608007, 0.030612612874912362, 0.028416558035782406, 0.0201092538024698, 0.0104071529848235, 0.010717028053477407, 0.016775087087548206, 0.026403380258541023, 0.0404127416467028, 0.04553397112925138, 0.051980593241751194, 0.08631861781967537, 0.021980997740424106, 0.05886989499309233, 0.06449694519064256, 0.01882167762544538, 0.03796818353501814, 0.1005826113479478, 0.009828503409932767, 0.03082919107483966, 0.013804613446284617, 0.03254053442339812, 0.017472049420965568, 0.08631664328277111, 0.05486757654164519, 0.011871261921312128, 0.04924985959327646, 0.015372472083462136, 0.018655429760526334, 0.0748811908332365, 0.33458754473498886, 6.160384910447257, 29.00674888065883, 50.60643318721226, 45.40100955963135, 39.65657595225743, 32.74741928918021, 17.802111625671387, 14.832380328859601, 22.38187255178179, 30.91101734978812, 40.229069301060264, 47.58000980104719, 37.18271500723702, 21.956486463546753, 10.09665926865169, 5.0809231996536255, 1.0778953262737818, 0.5482035321848733, 0.16144199137176785, 0.12885785768074648, 0.3100835010409355, 0.18240311874875, 0.553469289626394, 0.9538795351982117, 0.3517142300094877, 0.46798739369426456, 0.7812034466436931, 0.45417266498718945, 0.9553142296416419, 0.4980274960398674, 0.53485897396292, 0.8605944322688239, 1.3554088750055857, 1.7863095530441828, 1.693011422242437, 1.9250385888985224, 1.507433180298124, 1.414196823324476, 1.219767444900104, 1.705837254013334, 3.9232378005981445, 1.5551524311304092, 3.2724491102354865, 1.7145241307360786, 0.9031956834452493, 1.6867240624768394, 1.568078143256051, 0.5313031790511948, 1.1603520959615707, 1.5373135826417377, 0.9675338310854775, 0.9457526398556573, 1.2766767740249634, 0.5888542937380927, 0.5859882703849247, 0.5152483891163553, 0.02325755450874567, 0.08767120274049894, 0.19994635667119706, 1.2485479691198893, 3.962271477494921, 13.237345780645098, 21.855817488261632, 37.2784993989127, 49.421449184417725, 42.38094030107771, 32.01673977715628, 35.6077425139291, 24.71592010770525, 20.374195780072892, 35.35555417197091, 41.81368241991316, 36.004547187260215, 10.231251086507525, 0.16040844683136257, 0.029853854661009142, 0.07902802367295537, 0.06240105229829039, 0.009572070607516383, 0.027317982699189867, 0.05784439109265804, 0.05479457974433899, 0.012328361277468503, 0.04016175154330475, 0.08706068407211985, 0.02930599530892713, 0.03186191458787237, 0.049052388939474306, 0.09255826978811196, 0.03483173005016787, 0.10323677571224314, 0.022614204923489263, 0.05552043918786304, 0.03819447496373739, 0.005174189564838473, 0.06271530222147703, 0.12429527964975152, 0.06695345230400562, 0.02092335163615644, 0.027191676798143556, 0.04052624698462231, 0.05698978302202054, 0.028349462796800902, 0.038223261811903546, 0.07283870543220214, 0.08175678617720093, 0.03055228093372924, 0.014153779085193361, 0.03707732812368444, 0.10509448924234935, 0.0649394178763032, 0.044929294647382836, 0.04127606210697975, 0.0715013604078974, 0.0937808948968138, 0.020404884724744728, 0.032350965309888124, 0.03394856922594564, 0.025759779615327716, 0.01590681671431022, 0.043345132510044744, 0.07671027018555573, 0.1890556796320847, 0.19485640765300818, 0.1728831095887082, 0.1869932317308017, 0.09435443340667657, 0.09212967992893287, 0.14872083041284764, 0.11872477856065546, 0.07805028185248375, 0.21697290374764375, 0.14876294029610498, 0.19674977819834435, 0.13975400371210916, 0.16117190729294503, 0.14083672847066606, 0.2156193485217435, 0.10426365703876529, 0.12775070566151822, 0.1342513696955783, 0.08290292003325053, 0.09170320709901196, 0.13967404514551163, 0.1783163837556328, 0.12753466011158057, 0.14776706801993506, 0.10177534698907818, 0.08224569779953786, 0.12995926929371698, 0.1379499826580286, 0.1064269488145198, 0.1614830427403961, 0.12661330455115863, 0.10390568910432713, 0.12687767536512443, 0.21658854080098017, 0.1321146222097533, 0.10577319389475243, 0.10127500205167703, 0.13529666646250657, 0.08888118674180337, 0.14755597577563354, 0.10306631414485828, 0.11779806257358619, 0.1187759129596608, 0.12399354869765894, 0.12132121995091438, 0.14080818928778172, 0.16320692880877427, 0.11046427967292921, 0.1526846827140876, 0.09179430042526551, 0.1755126906292779, 0.1949814073741436, 0.2952048294246197, 4.0347989456994195, 27.56279683113098, 58.586779730660574, 60.36924975258963, 54.57353843961443, 52.221031257084434, 32.447878973824636, 40.08664512634277, 32.72533096585955, 27.44717880657741, 35.82422406332833, 44.49050371987479, 40.40651587077549, 33.08308328901018, 19.769521849496023, 9.308079549244471, 4.069341480731964, 2.280828697340829, 0.8529166728258133, 0.6435437819787434, 2.077367637838636, 2.5446591803005765, 6.187134172235217, 4.599295352186475, 5.953756775174822, 9.53075020653861, 6.520538704735892, 5.192490858691079, 8.27611311844417, 5.50478024993624, 3.5228035620280673, 4.7550700562340875, 6.30277521269662, 5.469882053988321, 5.829410510403769, 4.967786984784262, 2.8877069439206804, 6.697966166904994, 8.20238925729479, 9.045275228364126, 9.229032499449593, 5.09665652683803, 7.625200663294111, 4.181533174855368, 2.9576653156961714, 4.9697776436805725, 6.110077347074236, 5.845922470092773, 9.952442458697728, 8.07550733430045, 10.847188915525164, 8.931982244764056, 7.558470164026533, 3.975884735584259, 3.0941982865333557, 2.209909954241344, 0.7191678125943456, 0.35469782991068705, 0.7538485516394887, 4.519500936780657, 8.477977395057678, 19.722876855305262, 35.71175357273647, 54.05205529076712, 46.06752593176705, 29.63507447923933, 34.824336596897666, 39.34108257293701, 31.371300765446254, 38.06440666743687, 43.238396644592285, 54.096853801182334, 38.083079951150076, 8.789955854415894, 0.2442871273628303, 0.10852514872593538, 0.17709004027502878, 0.19100729562342167, 0.0731304008513689, 0.1893548457218068, 0.18532296349959715, 0.2229680727635111, 0.19617321342229843, 0.13264234603515693, 0.19181446731090546, 0.12661585584282875, 0.14656652244074003, 0.18301297245281084, 0.11852381005883217, 0.1000921798071691, 0.20712204091250896, 0.1836416215768882, 0.12323422729969025, 0.13097153497593744, 0.11316792959613459, 0.1947190043117319, 0.15434258803725243, 0.15280609977032455, 0.09721753905926432, 0.15927920171192714, 0.18447917806250708, 0.14967362928603375, 0.14336398643042358, 0.11216886142002684, 0.15088121805872234, 0.1106113317821707, 0.2284940348139831, 0.1729729204837765, 0.0837545357644558, 0.13339238507407053, 0.12506946096462862, 0.2324789081301008, 0.15563537366688251, 0.16701958993715899, 0.1944781650922128, 0.09600798253502164, 0.13253677955695561, 0.07538730331829616, 0.08662693734679904, 0.07304352801293135, 0.11464733949729375], [0.03420205633821232, 0.11187585642827408, 0.02768111428511994, 0.05468467403469341, 0.0529362046425896, 0.04575471553419318, 0.04507374457482781, 0.027999048653457845, 0.04063424940354057, 0.024915069674274752, 0.006192298705822655, 0.02534513025810676, 0.023555913141795566, 0.017980794621897594, 0.07775427773594856, 0.016287985457373515, 0.05404161621949502, 0.005616071925032884, 0.021824313826592903, 0.01561753687980984, 0.02600873581000737, 0.04797485836648515, 0.0682436798566154, 0.04258726656969104, 0.044065451715141535, 0.040005586708762815, 0.03604388875620706, 0.09756032137998513, 0.03306365099602512, 0.02464264634597514, 0.031664542321647914, 0.050687488700662336, 0.042113520205020905, 0.023672979092225432, 0.01718808421199875, 0.04395233992753284, 0.030876088022653545, 0.03571059235504695, 0.024688254077253596, 0.021170689524816613, 0.010298109014651604, 0.02246213165510978, 0.059503178511347087, 0.043033671365784745, 0.045058528427034616, 0.0420159299059638, 0.04423100408166647, 0.05941675350602184, 0.0500813058710524, 0.03822685804750238, 0.05031476941491876, 0.026453590153583458, 0.040542063635907004, 0.10511621593364648, 0.004290542739909142, 0.11696228384971619, 0.23679441799010548, 6.6448050652231485, 29.540808268955775, 46.37123169217791, 40.67530345916748, 37.90029716491699, 35.47555998393467, 25.497967651912145, 24.575229508536204, 27.131708008902415, 17.693344524928502, 21.27770130974906, 30.06705788203648, 31.25271933419364, 32.180487973349436, 32.818290914808, 26.393291677747452, 20.634047985076904, 14.799068927764893, 9.659527250698634, 4.277716219425201, 1.4815107541424888, 0.3294260916965348, 0.06950335297733545, 0.1542894316038915, 0.5290861065898622, 0.13230191144560063, 0.35139520998511997, 0.3817998213427407, 0.38020822246159824, 0.6981634082538741, 0.7776730560830661, 2.0990892265524184, 0.532624856701919, 2.182108474629266, 2.2347074236188615, 1.005144972886358, 0.6856857463717461, 1.4615186154842377, 2.662158646753856, 1.7439245645489012, 1.764718460185187, 1.4451056676251548, 1.3210365708385194, 1.8775066137313843, 0.5050108156033924, 0.2069683934428862, 0.6821809230106217, 0.6711188480257988, 0.3756111477102552, 0.17780962666230543, 0.16431095956691674, 0.3526482198919569, 1.6972245275974274, 4.912843670163836, 9.95518786566598, 21.611458029065812, 23.21552436692374, 29.925151348114014, 45.64383520398821, 44.07074567249843, 64.68648515428815, 58.868647302900044, 15.339739527021136, 19.801533937454224, 28.73270845413208, 29.236939225878032, 34.10825177601406, 34.706953729902, 35.761315073285786, 13.489422082901001, 0.3062068133481911, 0.15992765048784868, 0.031060649547725916, 0.006771924098887081, 0.01664142756323729, 0.034521737934223244, 0.030974777548440864, 0.038365380971559455, 0.053458364480840306, 0.011203055901985084, 0.013528816950773554, 0.06604155552174364, 0.08463593918297972, 0.01919665643280106, 0.02756399235555104, 0.07853987200983933, 0.03745251049154571, 0.009570911160803266, 0.04930993029847741, 0.04695439598123942, 0.07119878128703151, 0.020316257873283963, 0.050505220623953004, 0.05819874922079699, 0.09177215982760702, 0.035130051363791735, 0.021059574326500297, 0.025226814106905034, 0.0224977903666773, 0.04314621318397777, 0.007819125428795815, 0.056311041050191434, 0.07914589877639498, 0.03626125066408089, 0.0011993852843131337, 0.03413828083180955, 0.03755999383117471, 0.026811980476070727, 0.008934060244687965, 0.09037853710885559, 0.010550265350112957, 0.03995309863239527, 0.01629058933550758, 0.021581857997391905, 0.04096525235633765, 0.0243763417072062, 0.016427398958642567, 0.041110268860523186, 0.030390518185283457, 0.0498312928580812, 0.01170801742201937, 0.02357998926059476, 0.09472333932561533, 0.029203790971743207, 0.014250215874718768, 0.025424111734277437, 0.06881116583411183, 0.01714879533808146, 0.04418114532849618, 0.0683702469936439, 0.06061301752924919, 0.06252687304679837, 0.037900102723922045, 0.05852220007883651, 0.029371721603508507, 0.07510246110281774, 0.02540061915559428, 0.02403625995585961, 0.036628494172223976, 0.05240191938355565, 0.0518546808910157, 0.055988285690546036, 0.031326872762292624, 0.05827739142945834, 0.03653860863830362, 0.018682803559516157, 0.011049362631248576, 0.049657482720379315, 0.019885242251413207, 0.026604462414979935, 0.008369548795079547, 0.015507381808544909, 0.011874690219493849, 0.02026719639876059, 0.003877191080911351, 0.07600742325718914, 0.056617660847093375, 0.02971471766276019, 0.01699548543963049, 0.023679369195763553, 0.044877264582152875, 0.10190909302660398, 0.10455245511340243, 0.019466789705412726, 0.011621099630636829, 0.029449902408357178, 0.050036034014608176, 0.03210019912304623, 0.05636375304311514, 0.08380745471056018, 0.015499563388792532, 0.04889572877436876, 0.07501883166176931, 0.03211812601823892, 0.12598937803081103, 0.9370719513722828, 14.86809059551784, 42.37915808813912, 52.879459926060264, 47.0939485686166, 38.73208686283657, 31.26420818056379, 23.064614704677037, 20.281392165592738, 23.281716380800518, 26.149585349219187, 34.908937862941194, 45.11961446489607, 49.73326696668352, 42.27576194490705, 36.082290581294465, 24.454966613224574, 18.070541381835938, 12.036108204296657, 5.591547182628086, 1.3969735418047224, 0.39817843532988, 0.2607742798115526, 0.06328524449574095, 0.04374213317143066, 0.21008039931101458, 0.11558492561536175, 0.09748900734952518, 0.061020945997110436, 0.44045455966676983, 0.6108990822519574, 0.21393082769853727, 0.6762427645070213, 0.3019188791513443, 0.5922389892595155, 0.6724743438618523, 0.6620973721146584, 0.7808746014322553, 0.7788803598710469, 0.5251593430127416, 0.7769304673586572, 0.7064348044139999, 0.642932340502739, 0.24120587270174706, 0.6735497947250093, 0.8944479557020324, 0.36616927864296095, 0.5416295592273984, 0.31923520139285494, 0.07190338562109641, 0.09560946534786906, 0.06769700454814093, 0.1956449467688799, 0.7170557230710983, 1.6471273643629891, 6.98837958914893, 13.607859339032855, 26.541243144444056, 34.68163102013724, 45.572484152657644, 47.38051659720284, 63.05268573760986, 63.35761438097273, 22.95400980540684, 13.925287791660853, 21.60895320347377, 26.215216296059744, 29.182663372584752, 36.27586391993931, 42.966555322919575, 23.995952980858938, 1.3072021646159036, 0.08507926003741366, 0.08123852112995726, 0.018474547591592585, 0.03133517124557069, 0.022129585035145283, 0.041531710353280814, 0.009343174452494298, 0.05780017775084291, 0.01597798485974116, 0.02249690657481551, 0.02030656160786748, 0.038058052105563026, 0.03129130056393998, 0.023774416684838276, 0.02637511588233922, 0.013656077889858611, 0.044854608297880204, 0.03283559198358229, 0.07928318676671811, 0.07570524447198425, 0.014111233243186559, 0.05153370668579425, 0.056835528263556104, 0.025855244403438907, 0.04551460573981915, 0.04528134236378329, 0.06547691260597535, 0.016673861537128687, 0.05895545147359371, 0.04607424785249999, 0.06340413740170853, 0.060603748740894456, 0.05351799753095422, 0.013249156198331287, 0.009204267307982912, 0.04182137356006673, 0.08962713421455451, 0.023908057549436177, 0.04001594454582248, 0.009196278406307101, 0.030262007045426538, 0.0358207118032234, 0.02008588844910264, 0.05223884027717369, 0.027043976687959263, 0.04705565715474742, 0.03781345719471574, 0.0749852577490466, 0.13869569264352322, 0.14696251547762326, 0.11413028224238328, 0.11639866552182607, 0.1016979736409017, 0.09655582492372819, 0.11494157942278044, 0.18536869675985404, 0.09929868738566126, 0.17030289875609533, 0.19112468218164785, 0.14243759614016327, 0.18993063696793147, 0.09716519686792578, 0.14253850786813668, 0.14201780009482587, 0.15386935057384626, 0.11341285359646593, 0.1448212353778737, 0.09808837768754788, 0.1378798492785011, 0.1526907216757536, 0.19050967161144527, 0.1367218071328742, 0.1250991943691458, 0.10827932905937944, 0.15637690387666225, 0.237136643912111, 0.1680020543613604, 0.12897077947854996, 0.11313146512423243, 0.12881810909935407, 0.09868848762874093, 0.09371837468019553, 0.0707158339875085, 0.18198510046516145, 0.12674366469894136, 0.14932247384318284, 0.08772672726107494, 0.09729768761566707, 0.09040366326059614, 0.13886390147464617, 0.15181238523551396, 0.23619432161961282, 0.08484804244445902, 0.0896049529047949, 0.11945096030831337, 0.11895683753703322, 0.1740944031625986, 0.15861868858337402, 0.12376272465501513, 0.11625336403293268, 0.11487340022410665, 0.14544388625238622, 0.09302882025284426, 0.22156543231436185, 0.38120013209325926, 10.97441737992423, 42.07193653924124, 61.90708759852818, 56.30900042397635, 52.821185384477886, 48.95426968165806, 37.130005972726, 36.76132065909249, 36.69684485026768, 27.46108910015651, 32.48929371152605, 39.25967400414603, 40.6972701890128, 41.892110211508616, 43.98327480043684, 35.75629499980381, 27.848081180027553, 18.967770951134817, 13.083909579685756, 6.109038157122476, 2.3646556735038757, 0.5148295973028455, 0.4797518881303923, 0.23848117462226323, 1.6283728735787528, 0.6551204579217094, 2.0016025262219563, 2.863775610923767, 3.198408671787807, 3.5751597583293915, 7.265190609863826, 9.039048773901802, 6.861898924623217, 9.051241993904114, 9.120459948267255, 4.970472029277256, 6.432354339531489, 8.15765414919172, 10.684244104794093, 9.55391550064087, 7.134185365268162, 4.082838790757315, 5.026669928005763, 5.091636453356061, 3.885225943156651, 1.2009016743728091, 2.6189927458763123, 2.7293616235256195, 0.9553663411310741, 0.33081480860710144, 0.35185360110231806, 0.6704117059707642, 2.194705124412264, 6.357373288699558, 14.505317330360413, 27.478692361286708, 30.698114122663224, 40.174275806971956, 56.727045740400044, 53.80457435335432, 73.05113656180245, 65.6993796484811, 20.428134645734513, 25.143100568226405, 39.19881820678711, 40.41849456514631, 46.28653315135411, 50.323481695992605, 52.30540670667376, 24.687746899468557, 1.2506829117025648, 0.4158102763550622, 0.23282623663544655, 0.11610275640019349, 0.0978187821539385, 0.1382566262036562, 0.09368627318846327, 0.08082053677311965, 0.10249392914452723, 0.07959046134991304, 0.06944611176316227, 0.1084072600517954, 0.14104349166154861, 0.13845017153237546, 0.12236263549753598, 0.16188397551221506, 0.09317856614610978, 0.13430961514157908, 0.1219068770962102, 0.19963513979954378, 0.16439684852957726, 0.12713937275111675, 0.287086727895907, 0.12782051334423677, 0.17970056805227483, 0.09965243483228342, 0.08702413139066525, 0.1154530184077365, 0.08638942973422152, 0.1549718478428466, 0.21427845475929125, 0.15476973940219196, 0.2190053875425032, 0.14292943903378078, 0.12325192349297659, 0.12451192231050559, 0.14463623959038938, 0.13321345538965293, 0.08049389680049249, 0.24156313495976584, 0.05723287497780152, 0.1258782475654568, 0.16187675589961664, 0.11187098454684019, 0.13782483365918907, 0.16169972611325129, 0.102949287210192, 0.10008067185325281, 0.19481294069971355], [0.008910827205649443, 0.0551532771039222, 0.04730502895212599, 0.027417547535151243, 0.028609126274074827, 0.043393437418022325, 0.025528570504060814, 0.03429168402882559, 0.06944055456135954, 0.012877721040110503, 0.08098469475018126, 0.07820034665720803, 0.031732100660779645, 0.07009116107864038, 0.028924855403602123, 0.052787357808223793, 0.06247633575860943, 0.038796606939285994, 0.029756077764821903, 0.021510440490341613, 0.03584103731970702, 0.03735730863575425, 0.023737958998286297, 0.04931269872135349, 0.02659758037355329, 0.021277567271941474, 0.01563598115795425, 0.06623079893844468, 0.013981554174928792, 0.03488652175292373, 0.09105494152754545, 0.02315849518137319, 0.08390684652009181, 0.013339395418630114, 0.032911577727645636, 0.06292648946068116, 0.034781121515801976, 0.06344685796648264, 0.02039281019408788, 0.048991395426648, 0.05543624656274915, 0.0584239074960351, 0.041305914255125184, 0.08913727942854166, 0.04108434543013573, 0.008248115623635905, 0.04748990599598203, 0.08534329158387013, 0.05192118750086852, 0.002011117575291012, 0.05539529697437372, 0.041008223979068656, 0.08748162005628858, 0.006328336071289543, 0.04368376898180161, 0.056856206618249416, 0.09708732818918568, 0.09008123699043478, 0.7759106563670295, 9.005150250026158, 17.372794594083512, 40.08665207454136, 36.61892775126866, 34.05896820340838, 30.624998228890554, 29.3530992099217, 22.558035441807338, 22.441257068089076, 22.075271129608154, 21.46864649227687, 26.118667602539062, 22.86908197402954, 34.64879035949707, 33.39699942725045, 29.71141086305891, 31.78768198830741, 37.15366111482893, 31.454408168792725, 26.547729287828716, 19.55915297780718, 12.006862367902484, 6.471137012754168, 2.449292983327593, 1.021716209394591, 0.13720731250941753, 0.016648078902757595, 0.032163296094430346, 0.3530245896961008, 0.4873282473002161, 0.39364606567791527, 0.4106145165860653, 0.35745949457798687, 0.5991773626634053, 0.23868530509727343, 0.5063444897532463, 0.7554902264050075, 0.14209022692271642, 0.3092793827610356, 0.1279782455946718, 0.15680199249514512, 0.16447384868349346, 0.7311146429606846, 1.1451622481857027, 3.7954078827585493, 7.612449850354876, 11.744485361235482, 17.111064638410294, 23.60099826540266, 30.0035582951137, 31.597363880702428, 31.945253235953196, 32.70126240594046, 23.00100220952715, 35.600641454969136, 46.91514710017613, 31.450951439993723, 42.26984207970755, 65.96990081242153, 43.76958295277187, 33.54407542092459, 34.39693553107125, 33.365207944597515, 37.818791321345735, 35.11281885419573, 23.415540422712052, 4.805680734770639, 0.05149956280365586, 0.08256515208631754, 0.020051907415368726, 0.08233251635517393, 0.06008656256433044, 0.04452686231317265, 0.08545231859066657, 0.024112730852461288, 0.11205571570566722, 0.053418290202638934, 0.052821559365838766, 0.03559264939810548, 0.019653793956552233, 0.024633820301720073, 0.015555501815729907, 0.04120791683505688, 0.06568390649876424, 0.09205186553299427, 0.022778449413765754, 0.0738642704007881, 0.011879051503326212, 0.03516882964010749, 0.08472909525568996, 0.052407836208918264, 0.04827061142506344, 0.07135126167642218, 0.058680156245827675, 0.02508086122439376, 0.009918690043767648, 0.03710946014949253, 0.05615881171875766, 0.022223609632679393, 0.05180109358791794, 0.04822505458391138, 0.05182309169322252, 0.03056958018402968, 0.05116180842742324, 0.043824700705174885, 0.041858947436724386, 0.02391379965203149, 0.047016851737030914, 0.05955885909497738, 0.024771942890116146, 0.06385786698332854, 0.019991858762555888, 0.017915007259164537, 0.015244792149003063, 0.09105606789567641, 0.0891341445967555, 0.0831559118149536, 0.03668584055932505, 0.02692088025755116, 0.026630738683577095, 0.03376707128648247, 0.005689128094153213, 0.04802456444927624, 0.040610514248588254, 0.04548810894734093, 0.0520822004681187, 0.03805795371798532, 0.049870379867830446, 0.01916524365411273, 0.0107688155424382, 0.04790135266791497, 0.01734443225099572, 0.021708776276292543, 0.041382256230073314, 0.005046061373182705, 0.03201231187475579, 0.03844123100861907, 0.04107641335576773, 0.04787741395245705, 0.057029640169015954, 0.004647214248377297, 0.041807103968624554, 0.0079130999843723, 0.048301488161087036, 0.06465484028948204, 0.03606553741597703, 0.054211568885615895, 0.09545534968908344, 0.04526489467493125, 0.07112912966736726, 0.015391832383881723, 0.014674206962808967, 0.03486163987378989, 0.03422619861417583, 0.023985234122457247, 0.04820047465286084, 0.07044881010161978, 0.058146936286773, 0.054164179999913485, 0.05674249093447413, 0.034750003899846754, 0.012751225997427744, 0.022269229238320674, 0.019100311245503168, 0.05751275031694344, 0.05253607593476772, 0.05319466880921807, 0.020922249016751136, 0.040601272601634264, 0.04630032893536346, 0.030442012207848684, 0.1213173930134092, 0.04923636692443064, 0.0907330648707492, 0.28320032358169556, 3.654507100582123, 21.980720043182373, 32.4997854913984, 48.92061260768345, 44.93046712875366, 37.69172266551426, 31.795314584459575, 26.98534767968314, 20.284690822873795, 19.132820197514125, 21.566117559160503, 24.286099331719534, 32.334143911089214, 39.30022369112287, 48.67688717160906, 51.08260713304792, 46.95740951810564, 47.61848545074463, 43.514834199632915, 32.74787787028721, 26.255244868142263, 12.764828324317932, 5.690694502421787, 3.41536117877279, 1.1264518350362778, 0.733490492616381, 0.230991396520819, 0.2252909152635506, 0.27344027587345665, 0.1329822785087994, 0.13140684233180114, 0.025566196967182413, 0.24850614954318317, 0.13738998770713806, 0.22285832650959492, 0.2701153999992779, 0.22993942296930722, 0.1829387950045722, 0.16417480473007473, 0.1634211287434612, 0.3056384452751705, 0.0708453052544168, 0.07380192660327468, 0.5773322262934276, 0.505194400038038, 1.5418382712772913, 3.2676066500799994, 7.701147079467773, 11.660413895334516, 19.972817455019268, 25.9805999483381, 36.99898379189627, 44.439344133649556, 48.73737818854195, 51.33489622388567, 46.87970781326294, 49.19148465565273, 45.385897227696006, 46.342452253614155, 71.18455164773124, 53.84931032998221, 18.3450334412711, 23.61706076349531, 32.77536146981375, 40.410580566951204, 45.05105658939907, 33.98988921301705, 10.61630027634757, 0.1273897114608969, 0.1276282300906522, 0.04609821031668356, 0.11075832960861069, 0.043380792917949815, 0.02648583922668227, 0.060728164921913824, 0.06465947468365942, 0.11005677868212972, 0.07605298688369137, 0.03724605942677174, 0.04654190775805286, 0.0122577766721536, 0.009435377183503338, 0.02613016643694469, 0.07099368050694466, 0.05177337882508125, 0.04589293651016695, 0.024916343623772264, 0.030585420584040027, 0.036755685561469624, 0.035806445604456325, 0.08427802553134305, 0.02809472887643746, 0.036570445501378605, 0.07322610821574926, 0.041471944988838265, 0.05862799047359398, 0.05594594510538237, 0.041010184945272546, 0.011916462531579393, 0.04374574976308005, 0.0028478965021869434, 0.048197136260569096, 0.0006987878576702704, 0.03449164829882128, 0.029736166154699664, 0.0038240130192467143, 0.06954663672617503, 0.032712583762726614, 0.02241862059703895, 0.0726427309481161, 0.05592471035197377, 0.004763450689746865, 0.02967883673097406, 0.01803737596076514, 0.08257155745689358, 0.018511843268892596, 0.054984393130455694, 0.09508118512375013, 0.11056994114603315, 0.1628488523087331, 0.10786314960569143, 0.11252829499010529, 0.11479976560388293, 0.08447001701486961, 0.15540137408035143, 0.25044084287115503, 0.17352575010487012, 0.13345462030598096, 0.15733631168092999, 0.0990945433399507, 0.08274809191269533, 0.15011038870683738, 0.21782234816678933, 0.12717965058982372, 0.1741063046668257, 0.14635798148810863, 0.125905144693596, 0.15013168113572256, 0.14891702202813967, 0.17423642054200172, 0.110508262312838, 0.21745439219687665, 0.13473388951803955, 0.1705385675387723, 0.15451843717268535, 0.160131021003638, 0.13413734867104463, 0.1520053877362183, 0.13264056827340806, 0.15576060408992426, 0.1658390068582126, 0.15446194234703267, 0.07289117654519421, 0.23026794248393603, 0.12226606639368193, 0.128072819805571, 0.18276019101696356, 0.14383748173713684, 0.1896750871092081, 0.13989436546606676, 0.16568264524851525, 0.15778980377529347, 0.15184609485524042, 0.11509367983256068, 0.20424655878118106, 0.15697643027773925, 0.20776458643376827, 0.13231112595115388, 0.09084449389151164, 0.08499155260090317, 0.23338141398770468, 0.12457510749144213, 0.178770228688206, 0.09437269278402839, 0.1918053070881537, 0.22080117118145737, 1.813121348619461, 17.09362813404628, 33.36203261784145, 59.95213549477713, 55.377114977155415, 47.89624663761684, 47.23251301901681, 41.079087597983225, 32.28872353690011, 33.68898357663836, 31.342479637690953, 28.240511962345668, 38.079237597329275, 33.79726430347988, 45.81460108075823, 44.86650548662458, 39.121661935533794, 43.07969978877476, 48.356043679373606, 41.70219509942191, 35.24717269624983, 25.802283116749354, 16.111112901142665, 9.433110645839147, 4.6816354138510565, 2.3183517924376895, 0.6430809668132237, 0.23375382114733967, 0.26308857277035713, 0.495304779282638, 1.3579009984220778, 1.4911122960703713, 1.1704750784805842, 1.1153740180390221, 1.5588709115982056, 0.7372057703988892, 0.9738146769148963, 1.5852223890168327, 1.0659119635820389, 0.6096191480755806, 0.47155654217515675, 0.27403008565306664, 0.337868261550154, 1.2058746303830827, 1.8227921554020472, 5.553060242107936, 10.558505160467965, 15.406961611339025, 22.53151764188494, 30.97980104173933, 38.62189885548183, 39.64556653159005, 40.62991435187203, 40.67085313796997, 31.260046209607804, 45.07623338699341, 58.65017509460449, 42.284235273088726, 50.39148371560233, 69.85918971470424, 53.565844672066824, 43.14133031027657, 43.16311986105782, 46.23941741670881, 53.02327026639666, 53.008338587624685, 35.493166719164165, 8.039912581443787, 0.24003947100469045, 0.18356273509562016, 0.11232396773993969, 0.1887411650802408, 0.1656985908214535, 0.10831704203571592, 0.1297713965177536, 0.19876972266605922, 0.2628399575395243, 0.21867488670561994, 0.18891955193664345, 0.09290673823228904, 0.1467557522867407, 0.09634536371699401, 0.09837058718715395, 0.15208478990410054, 0.12126351733292852, 0.14451858161815576, 0.16108843391495092, 0.14091207299913677, 0.15507358738354274, 0.16774951719811984, 0.21690753368394716, 0.06276425173772232, 0.1484676282852888, 0.1315763403794595, 0.12048715113529138, 0.2275077841643776, 0.0891478985015835, 0.11830353045037814, 0.13482159695455007, 0.09327854149575744, 0.15738292703671114, 0.14894843819950307, 0.18849837167986802, 0.13918107588376316, 0.1989378636436803, 0.10091188403644732, 0.1338524046753134, 0.12444780075124331, 0.11445264065904276, 0.19270823363746914, 0.1522255316376686, 0.13877206854522228, 0.08854633649545056, 0.09980986852731023, 0.23297174168484552, 0.21235419729990618, 0.17745604206408772, 0.17255514647279466], [0.033396960967885594, 0.08304720371961594, 0.04674357854362045, 0.04273918716769133, 0.0385675776217665, 0.1252402617995228, 0.024359812594151924, 0.03182556885959847, 0.04956330205979092, 0.06572828947433404, 0.04115244998995747, 0.05403136694803834, 0.08854550189737763, 0.02254085868064846, 0.053136647279773436, 0.07365213321255785, 0.060647744951503615, 0.02282390108198992, 0.03547647402488759, 0.04011640504800847, 0.06305057994489159, 0.04114683172000306, 0.05369186534413269, 0.09247906439538513, 0.02661779223542128, 0.030302637722343206, 0.015601430154804672, 0.06632920008684907, 0.03424944522391472, 0.06905714156372206, 0.04625746587823544, 0.08653729608548538, 0.06419342290610075, 0.05926128077719893, 0.018942494178190827, 0.05015857743897608, 0.05607757411364998, 0.04104627961558955, 0.03330580996615546, 0.08393685812396662, 0.05087315284514001, 0.08058563473501376, 0.0021424433632221606, 0.012952554122810917, 0.05669204524851271, 0.0636727422741907, 0.029470126144587994, 0.024862925954429165, 0.04424421176580446, 0.0432025281978505, 0.06681331446660416, 0.02111369597592524, 0.03312149949903999, 0.022723622087921416, 0.02116751398092934, 0.058827819036585946, 0.0404008435351508, 0.07023665255733899, 0.06907066476664372, 0.039762016385793686, 1.3806973866053989, 6.409605937344687, 13.000327093260628, 27.155239820480347, 39.496381759643555, 39.660366194588796, 40.93015990938459, 35.336300713675364, 35.848462854112896, 39.03877340044294, 25.589803729738506, 22.39542501313346, 17.87206608908517, 23.075860364096506, 31.80794988359724, 24.31188235964094, 23.221075977597916, 29.574110984802246, 29.625399112701416, 32.04375089917864, 43.64716958999634, 34.88680437632969, 32.258005550929475, 30.54378420966012, 24.32725351197379, 18.892023427145823, 13.808820349829537, 12.714196801185608, 8.208939671516418, 7.118552352700915, 6.44740674325398, 5.211402118206024, 6.158395554338183, 6.868398530142648, 8.803586483001709, 7.782148310116359, 10.518840500286647, 12.978148443358284, 12.878959434373037, 14.50977633680616, 23.0029650756291, 30.09887715748378, 38.89594970430647, 36.870410851069856, 37.51057618004935, 32.93564598900931, 33.987019606998985, 28.566660404205322, 32.888961042676655, 29.73482629231044, 20.23213812283107, 24.21517559460231, 25.869435719081334, 50.73331424168178, 30.953856468200684, 23.74637542452131, 25.88849983896528, 32.18387522016253, 36.08531652178083, 42.64638580594744, 39.70375074659075, 31.496621949332102, 23.081179210117885, 6.202109711510794, 0.11006080239479031, 0.13255793627883705, 0.033968986344656775, 0.12025547213852406, 0.0538013571474169, 0.03643783261733396, 0.042628239906792126, 0.04448634698720915, 0.06296877576304333, 0.032639980515731234, 0.041073115675577095, 0.09503465119217124, 0.029193999711424112, 0.029453196695872715, 0.0472952342991318, 0.059566974373800416, 0.08950638890798603, 0.10393194840954882, 0.04091914590182049, 0.014373648179961103, 0.03523638458656413, 0.021087898074516227, 0.0035130088259133375, 0.042901614880455394, 0.019474983015762906, 0.025516923450465714, 0.05119982674451811, 0.04411134443112782, 0.08024796856833355, 0.0310299322674317, 0.015624809078872204, 0.01751920421208654, 0.05478390299582055, 0.08792524625148092, 0.0716172813304833, 0.012972659963582243, 0.05678394263876336, 0.1005078571449433, 0.02442032434711499, 0.028392721100577285, 0.06021855119615793, 0.08170044741460256, 0.08380682367299284, 0.1044116048142314, 0.0690750956003155, 0.04368208621495536, 0.008542961989795523, 0.02105132842968617, 0.0991481543917741, 0.04403165727853775, 0.05107413831033877, 0.017933361631418978, 0.03858256985300353, 0.04061562700995377, 0.12681161319570883, 0.06726312890116658, 0.09069252918873515, 0.019308797915333083, 0.03991109052939074, 0.0609809531431113, 0.002916149915628401, 0.08802789502910205, 0.040195115110171695, 0.03271191879840834, 0.09666119462677411, 0.0147642044550074, 0.019054885022342205, 0.06887867328311716, 0.03292541305667587, 0.060099271525229724, 0.08319006926779236, 0.05323722991826279, 0.05208125391176768, 0.09540906003011124, 0.037012351610298665, 0.14218146274132387, 0.1676204191254718, 0.10792158504149743, 0.0423256302518504, 0.05380953349439161, 0.052735351491719484, 0.07418514282575675, 0.055548693386039565, 0.05926778792802777, 0.04155256851975407, 0.04000419231929949, 0.05053370213136077, 0.03905370046517678, 0.004476512225145208, 0.07645464568798031, 0.08616224942462784, 0.06705360407275812, 0.061859527070607455, 0.04261102208069392, 0.054210483229586055, 0.026983607427350113, 0.037522732080625634, 0.025407348526641726, 0.11398204948220934, 0.03708183698888336, 0.05715721153787204, 0.042759546610925875, 0.07613057736307383, 0.03789157014606254, 0.023870090122467706, 0.009746594903325396, 0.05238093229542885, 0.033442891003297906, 0.047299526033124754, 0.0278658573183098, 0.0675037849162306, 0.22652350126632623, 3.9227844306400845, 18.71800753048488, 28.524736710957118, 41.178009101322715, 46.56563534055437, 42.68216902869088, 42.331465653010774, 36.48092263085501, 31.065454959869385, 23.734568698065623, 22.94530371257237, 18.44075182506016, 20.991091591971262, 23.34766694477626, 28.00914910861424, 29.63095419747489, 35.96514047895159, 44.75137383597237, 47.035788672310964, 54.15376649584089, 45.134257793426514, 40.0250597681318, 40.16330112729754, 31.130292075020925, 21.859072719301494, 15.837383406502859, 12.652635761669703, 6.299057057925633, 3.8775056259972707, 2.4979375387941087, 3.0163404643535614, 3.308825969696045, 3.08082560982023, 2.6929654393877303, 3.333191130842481, 5.330120776380811, 7.494556290762765, 10.4816780601229, 16.017713478633336, 12.402626548494611, 20.14579807009016, 32.503985677446636, 44.74047906058175, 48.04628951208932, 53.08486257280622, 52.28407226290022, 55.689697061266216, 48.713326999119346, 54.025054591042654, 41.451618739536826, 28.97252552849906, 25.602409499032156, 17.132609265191213, 37.619051456451416, 38.289722851344514, 26.757969617843628, 31.68577970777239, 42.10913372039795, 38.72125114713396, 39.39279106685093, 41.40662220546177, 40.97888762610299, 34.49882738930838, 13.622751934187752, 1.5070428869553973, 0.1834077848387616, 0.03262114438361355, 0.07928049976804427, 0.10527774798018591, 0.07138138184589998, 0.0542585540429822, 0.02035023381800524, 0.03143733826332858, 0.013291434867174497, 0.03323984957699265, 0.1033562792997275, 0.05663129261561802, 0.03969582190204944, 0.07236588866050754, 0.007906487660615571, 0.06092339301747935, 0.040674472959446054, 0.007239709109334009, 0.03595027467235923, 0.0400094102535929, 0.053504569322935173, 0.030244382098317146, 0.06372359847383839, 0.05223247901137386, 0.031089894407029663, 0.09175440935151917, 0.07075179634349686, 0.044708485781614266, 0.03179223582680736, 0.04019530849265201, 0.034378285453255684, 0.024982358295736567, 0.09284524938889913, 0.05041996609153492, 0.043688003040317974, 0.029848484056336538, 0.029094445053488016, 0.043856978616011996, 0.04753633136195796, 0.04549292315329824, 0.08744062975581203, 0.12516277310039314, 0.14593950180070742, 0.06820484051214797, 0.05346251372247934, 0.005202099830577416, 0.027989761205390096, 0.05435344037999, 0.018223102869732038, 0.020230567382116402, 0.06673108280769416, 0.11281294721577849, 0.19631539365010603, 0.21438915096223354, 0.14095762984028884, 0.14567802154592105, 0.2543399493609156, 0.11716281808912754, 0.18856823364538805, 0.09933223415698324, 0.12738118906106266, 0.11019397846290044, 0.1552566018487726, 0.12833229159670217, 0.08365551036383424, 0.1306051124951669, 0.16025725565850735, 0.1131144135392138, 0.15016278518097742, 0.23208647061671528, 0.14968459441193513, 0.14224831201136112, 0.19524656528873102, 0.11857989776347365, 0.18096659226076944, 0.19995558474745068, 0.1430736141545432, 0.09404397649424416, 0.10432797537318297, 0.10757478579346623, 0.15196489276630537, 0.13257958154593194, 0.23279187562210218, 0.1852035549070154, 0.19698596266763552, 0.1520993241242, 0.21226938042257512, 0.18090157503528254, 0.11626814252563886, 0.09995024385196821, 0.23101601377129555, 0.14914040932697908, 0.13930534278707846, 0.15420632463480743, 0.10525372784052577, 0.09115176168935639, 0.154845531763775, 0.14599292964807578, 0.1226778014429978, 0.3441934292869908, 0.15294978634587356, 0.11325711623898574, 0.0923956927976438, 0.11393220429973942, 0.15147207278226102, 0.142347676679492, 0.08233399556151458, 0.17526279975261005, 0.166882742994598, 0.15804425440728664, 0.18484994316739695, 2.8132287689617703, 15.023704188210623, 29.790085315704346, 50.00299951008388, 61.12736770084926, 56.95718050003052, 57.451030663081575, 49.66782883235386, 48.619762556893484, 49.099931716918945, 37.80071210861206, 31.704915046691895, 28.123202051435197, 33.01276751926967, 39.75649104799543, 32.82267870221819, 32.85790606907436, 38.79006610597883, 38.273189612797324, 43.749110085623606, 56.073744841984336, 47.436654567718506, 45.325253350394114, 43.87430272783552, 33.54357515062605, 28.232342617852346, 21.43004056385585, 18.940827574048722, 12.625722782952444, 10.176157082830157, 8.766017573220388, 7.976836834635053, 9.217517597334725, 10.217283470290047, 11.3349472454616, 12.220408303397042, 14.973658050809588, 18.26388716697693, 19.213059731892177, 21.96666557448251, 29.72074576786586, 39.21310370309012, 48.920494488307405, 46.20722988673619, 49.34206601551601, 42.004049164908274, 42.91321747643607, 36.33023009981428, 43.07885210854666, 36.95964656557356, 28.110332250595093, 30.96185037067958, 32.72589724404471, 59.66206210000174, 40.390559332711355, 33.50055537905012, 37.34224912098476, 44.362868785858154, 46.64917353221348, 55.51819467544556, 55.885090827941895, 49.22736167907715, 35.257563727242605, 11.088055167879377, 1.0175525013889586, 0.2939539908298424, 0.12783540040254593, 0.28157384800059454, 0.1719028436179672, 0.20157372791852268, 0.1450009657336133, 0.1380072645843029, 0.12031510179596287, 0.16583128512970038, 0.12737463441278252, 0.2726672887802124, 0.09757453668862581, 0.1732077207416296, 0.13528213224240712, 0.1392291025923831, 0.2033403752637761, 0.2046541819082839, 0.07660676645381109, 0.08312160508441073, 0.12104319701237337, 0.14164343875433716, 0.1327005507690566, 0.13490222048546585, 0.2108047761555229, 0.1468695154679673, 0.14894758324537957, 0.189999752544931, 0.17951774357685021, 0.0913520652268614, 0.13956686375396593, 0.13818234018981457, 0.11290643577064786, 0.20834151761872427, 0.20562790680144513, 0.13001740617411478, 0.1599249770598752, 0.24348805738346918, 0.16825358729277337, 0.1452314369380474, 0.1368403472006321, 0.2805462474269526, 0.2968482683811869, 0.28498001237000736, 0.12635111861995288, 0.1391648996089186, 0.11916537848966462, 0.08472876277353082, 0.17588648200035095, 0.07788017990865878, 0.15632524022034236, 0.10084363698427166], [0.04544873016753367, 0.005824602275554622, 0.04512737598270178, 0.03695173468440771, 0.0073197100843702045, 0.03315659333020449, 0.03178089750664575, 0.01455931062810123, 0.016689018313107745, 0.04339854000136256, 0.05271141956161175, 0.08508263914180653, 0.01171932096726128, 0.09124419851494686, 0.04225801084456699, 0.04517208804775562, 0.033921597458954365, 0.009675997575478894, 0.07248681038618088, 0.012639867374673486, 0.08088003750890493, 0.06720486309911523, 0.07756824378988572, 0.10057528995509658, 0.023397848409201418, 0.020260372032810534, 0.02037824035089995, 0.04135135235264897, 0.036534242265458615, 0.033105984795838594, 0.060792137203472, 0.04147272191143461, 0.04667082941159606, 0.0681321829823511, 0.021983703398810964, 0.03992006754768746, 0.01927341061777302, 0.01551188897740628, 0.05359609691160066, 0.02270745938377721, 0.03955822517829282, 0.027228999616844312, 0.04271634089361344, 0.011612971629282194, 0.027497285577867712, 0.008147254785788911, 0.033892939532441754, 0.04934799950569868, 0.1173263993114233, 0.016256231714838316, 0.007627106803868498, 0.03577627454485212, 0.07679073086806706, 0.018607945879921317, 0.10957045227821384, 0.020688632802505578, 0.01500203097904367, 0.05900021442877395, 0.01240540892883603, 0.04322623960407717, 0.0712601887062192, 0.04919464380613395, 1.4164480396679469, 8.150116222245352, 16.46162346431187, 28.600115980420792, 36.411475385938374, 44.95492826189314, 49.26496185575213, 50.65657833644322, 47.11835759026663, 48.01892403193882, 40.67110674721854, 39.19820329121181, 37.79525082451956, 35.44756916591099, 25.808734519141062, 37.48568773269653, 47.96396030698504, 14.524983337947301, 50.513678210122244, 64.0259199142456, 21.388412169047765, 24.04812352997916, 19.188756670270646, 22.325048446655273, 23.40737281526838, 17.74274969100952, 29.328085694994243, 36.175167151859824, 31.037359918866837, 33.05543293271746, 28.488156182425364, 37.35172993796212, 34.83218806130545, 36.59578677586147, 32.906668526785715, 31.052249908447266, 27.30745574406215, 46.12196159362793, 57.60781676428658, 28.62798867906843, 23.470330442701066, 25.18164917400905, 19.71722796985081, 26.699061053139822, 23.126830611910137, 24.859989268439158, 25.936199222292217, 35.77927269254412, 45.47680050986153, 60.079120772225515, 73.24630451202393, 44.192446844918386, 41.541691711970735, 46.66672815595354, 44.65468965257917, 42.563545908246724, 45.117033209119526, 34.07165213993618, 18.579740115574428, 4.024086994784219, 0.3087310179003647, 0.05267955216446093, 0.05811211386961596, 0.02237526560202241, 0.054767166929585595, 0.06840929668396711, 0.008556365600920149, 0.04238593844430787, 0.025023292617074082, 0.06510167595531259, 0.0171106972931219, 0.014802575610311968, 0.019243405799248388, 0.017482649834294404, 0.03046613752043673, 0.06303166917392186, 0.015617117884435823, 0.06664568917559725, 0.06874006893485785, 0.02385968478795673, 0.03441077370994857, 0.038482265413871834, 0.03303682850673795, 0.04427289683371782, 0.045960471100573025, 0.025569618480013948, 0.017889631745804633, 0.026016365936292068, 0.05861437227576971, 0.09835965598800353, 0.04072242842188903, 0.0965811274945736, 0.05762335152498313, 0.06891492740916354, 0.012692926268625473, 0.03855265324403133, 0.0028294346245404866, 0.05577141232788563, 0.05852281754570348, 0.026519718480163386, 0.04590718574555857, 0.029614138416945934, 0.062121115890996795, 0.025865586973460655, 0.06024837281022753, 0.022480070424665297, 0.029498159818883454, 0.06020706359829221, 0.06211315667522805, 0.055514423974922726, 0.050052702227341275, 0.03228658590731876, 0.03759239387831517, 0.11005679903818028, 0.006415734774366553, 0.012327854920710837, 0.04091498308948108, 0.04265943894694958, 0.005487746958221708, 0.07423439089741025, 0.01619033239382718, 0.030234000512531826, 0.017923780716955662, 0.016979298986760632, 0.0334398850931653, 0.05254001483055098, 0.057453032449952195, 0.03998091517548476, 0.019299961693052734, 0.05108991085684725, 0.023447379769225205, 0.03155960348833885, 0.10415657742747239, 0.02794927471716489, 0.011244533899506288, 0.11426579925630774, 0.1093571072976504, 0.04156150821862476, 0.029971332821462835, 0.0036270203085483183, 0.0539329386582332, 0.017031659837812185, 0.028093841691900576, 0.038063941789524894, 0.056168976173337014, 0.028361535631120205, 0.026047145981075506, 0.09293452424130269, 0.027164878057582036, 0.007450017645688993, 0.031251131290835996, 0.014735351449676921, 0.07244516190673624, 0.045354118637208424, 0.0274525344970503, 0.02619165019132197, 0.05286446992041809, 0.010392048795308386, 0.05243042463968907, 0.02127625261034284, 0.02003297968102353, 0.05613491032272577, 0.044846676223512204, 0.052909650174634795, 0.014275903514187251, 0.019121498501460468, 0.05154099075921944, 0.04498146381229162, 0.12886279741568224, 0.024399537426818694, 0.037848208365695815, 0.05550983029284647, 0.05151363561994263, 0.08835279795208148, 0.062497329632086415, 0.1409683506935835, 2.3242707891123633, 13.305458971432277, 28.308658157076152, 43.008043016706196, 48.07503420966012, 52.45565455300467, 52.18067959376744, 52.097627776009695, 45.96743713106428, 41.28289910725185, 34.15461015701294, 30.59146622249058, 30.02679307120187, 24.8293650831495, 18.94959967476981, 28.436141967773438, 30.222301483154297, 17.948614392961773, 52.94531147820609, 57.33551686150687, 35.18523645401001, 49.260174546922954, 46.37952784129551, 41.983503341674805, 42.823363372257774, 44.61876746586391, 46.37565769468035, 48.09771660396031, 44.17782436098371, 46.980189187186106, 46.97845213753836, 52.44709437234061, 49.98638636725289, 50.61310345785958, 46.73312861578805, 48.164481844220845, 36.75878456660679, 44.188861574445454, 56.48846197128296, 39.42658363069807, 37.1532199042184, 34.25292369297573, 27.649737903050013, 24.873701538358414, 22.36689223561968, 19.154981476919993, 21.80167712484087, 23.132675783974783, 25.545583656855992, 38.45118509020124, 45.31568915503365, 51.012833322797505, 39.48448296955654, 41.21296201433454, 43.505488872528076, 42.89108746392386, 49.23138468606131, 45.216510568346294, 29.8592164175851, 10.95468623297555, 1.7327412217855453, 0.1311568021774292, 0.1566034938607897, 0.02785286846171532, 0.09368393224264894, 0.11534271575510502, 0.023373439808243086, 0.05641449049913457, 0.015277702793745058, 0.041654562511082203, 0.04790251635547195, 0.031860547339809794, 0.07670393266848155, 0.025057763892358968, 0.029046224962387766, 0.007355769131598728, 0.021968075040993944, 0.0362994012955044, 0.054866762299622805, 0.09170593480978693, 0.03446637286937662, 0.02746865140008075, 0.07640032217438732, 0.015474084398842283, 0.08518716746142932, 0.05903533540133919, 0.016847666585817933, 0.09422284511051007, 0.03804632362776569, 0.07577256193118435, 0.0029941008667395052, 0.06021095160394907, 0.033221301822257895, 0.031708192479397566, 0.015110035094299486, 0.09769434561686856, 0.022414042182000618, 0.06592627242207527, 0.02135177355791841, 0.009487625228108039, 0.09353964855628354, 0.05620725233373897, 0.07157259301415511, 0.0390858223129596, 0.0550496580212244, 0.02780520137665527, 0.04702185932546854, 0.0251730639554028, 0.08429074127759252, 0.025781998244513358, 0.059540240094065666, 0.027160301338881254, 0.057609936887664456, 0.03294903964602521, 0.15949125747595513, 0.07602480053901672, 0.09404133699302163, 0.15675142806555542, 0.17750043182500772, 0.1351624522358179, 0.09497825136142117, 0.10929305359189, 0.11492225474544934, 0.09893833100795746, 0.14816287106701306, 0.16717331883098396, 0.13033384776541165, 0.2148583714983293, 0.08626217049147401, 0.11400685672249113, 0.20818214331354412, 0.09665589526827846, 0.15245600284210273, 0.1660319957882166, 0.1555514388850757, 0.19230679874973639, 0.17537652222173555, 0.24756602570414543, 0.10616396221199206, 0.11866605814014163, 0.16656723778162683, 0.16662350190537317, 0.12409047063972269, 0.2390738342489515, 0.11381016299128532, 0.08275075855531863, 0.12200559037072317, 0.18934407058571065, 0.09023945100073304, 0.15690339276833193, 0.11393645192895617, 0.0999704845515745, 0.16394080514354364, 0.11661454822335925, 0.07319696513669831, 0.10894857493362256, 0.20787146926990577, 0.1090292323912893, 0.1494258011558226, 0.13341290397303446, 0.10716536454856396, 0.1805118109498705, 0.14827282088143484, 0.0842332218640617, 0.05263814117227282, 0.10218882587339197, 0.1851281968078443, 0.09678752427654606, 0.20305156361843857, 0.16836121651743138, 0.14626570072557243, 0.17769384144672326, 0.08924681533660207, 0.1413406899997166, 0.1841503464217697, 0.2298181823321751, 2.0365250408649445, 11.967788304601397, 25.176219156810216, 43.20542049407959, 52.236213071005686, 61.44796453203474, 65.97224930354527, 66.70502717154366, 63.979665756225586, 61.745194571358816, 53.73780563899449, 52.12315893173218, 49.509284836905344, 46.23795829500471, 37.177222456250874, 46.91981976372855, 57.766590050288606, 20.599129813058035, 57.97639785494123, 74.48707212720598, 29.594569955553325, 37.58265331813267, 31.57010609763009, 34.742417335510254, 36.43320935113089, 31.084715366363525, 43.36578491755894, 50.894376959119526, 45.627538204193115, 45.5290196963719, 41.54230662754604, 50.020932810647146, 46.08176973887852, 50.16498981203352, 43.10027340480259, 43.83798449380057, 39.27517196110317, 61.223231996808735, 72.97258022853306, 37.85761438097273, 30.504200322287424, 34.02603721618652, 27.517800297055924, 33.56699057987758, 31.274189267839702, 34.56856645856585, 37.73039633887154, 46.28121083123343, 56.15364217758179, 71.23034027644566, 80.95922878810337, 55.79204750061035, 54.60235261917114, 61.52837603432791, 61.10493891579764, 59.38532229832241, 61.17242676871163, 49.257652350834434, 29.373332364218577, 8.25111871106284, 0.8048647227031844, 0.24795251925076756, 0.29471473715135027, 0.14820134400257043, 0.2328348947422845, 0.25147639587521553, 0.14747912489942142, 0.175228886572378, 0.09441748288060937, 0.1302255807178361, 0.12642605602741241, 0.15296939600791248, 0.12385462543794087, 0.11208270782870905, 0.11527342375900064, 0.08310876041650772, 0.13549482582935266, 0.11828759844814028, 0.16278486645647458, 0.15726776607334614, 0.14094161641384872, 0.09346502327493258, 0.18660057708621025, 0.1131683299317956, 0.16305600904992648, 0.14884538230087074, 0.10602510002042566, 0.18369013683072158, 0.20469192202602113, 0.18179770266371115, 0.09363346959331206, 0.1320921898420368, 0.17302512696811131, 0.15274231747857162, 0.17432154954544135, 0.295671742941652, 0.11900083374764238, 0.1469138373753854, 0.09846315293439797, 0.12428674367921692, 0.14407705888152122, 0.12529225115265163, 0.11997084026890141, 0.09322625358722039, 0.12230204232037067, 0.12138829992285796, 0.13186660408973694, 0.16281086791838917, 0.19580974935420922, 0.21497697941958904, 0.1726166353161846, 0.19125657581857272, 0.12263278742986065, 0.14566914630787714], [0.027856578351929784, 0.06096314159887178, 0.05280586485085743, 0.07138119864144496, 0.04974296795470374, 0.03918310048590813, 0.036121849037174664, 0.06345000636896916, 0.07766783915992294, 0.02533531355272446, 0.033529505998428376, 0.026542191559981023, 0.10783049171524388, 0.07293473849339144, 0.058969334300075255, 0.012827468736629401, 0.05014265900743859, 0.027501908097682253, 0.04525131040385791, 0.005297747399059257, 0.06383432860353164, 0.056362901481666734, 0.05418177102027195, 0.022087924681337814, 0.08525186577545744, 0.04740042419039777, 0.08519037693206753, 0.017608828510024717, 0.005925269306836916, 0.02298919390887022, 0.013030119157130165, 0.04657832133982863, 0.038210349290498664, 0.05942087899893522, 0.016740586974525025, 0.04317470486941082, 0.038494760636240244, 0.02189882884600333, 0.011999714537523687, 0.056944674013980796, 0.03713761596009135, 0.06338379492184945, 0.03982875369755285, 0.08259230027241365, 0.06013199726917914, 0.040036751822169335, 0.1025534298803125, 0.08869388393525567, 0.0625324302486011, 0.0654261853279812, 0.06307801311569554, 0.023160096524017196, 0.054009918456098864, 0.05692266233797584, 0.061453953119260926, 0.062072383505957465, 0.07037281417953116, 0.03305335422711713, 0.06842319986649922, 0.0406427209132484, 0.0638175280764699, 0.030214051582983563, 0.19710082507559232, 0.07852970076990978, 0.06305119062640838, 0.7299539680991853, 3.3672685708318437, 8.528219819068909, 13.19679261956896, 25.835035187857493, 33.36700752803257, 41.10632453645979, 44.13737889698574, 48.97196674346924, 50.51494625636509, 50.89061450958252, 49.0527742930821, 52.318775040762766, 41.53707810810634, 42.22226081575666, 41.20579842158726, 73.02348273141044, 37.01703521183559, 21.277798584529332, 28.25788766997201, 33.13547270638602, 31.98866558074951, 21.650093487330846, 15.17099905014038, 19.763817378452845, 22.07411425454276, 26.12718435696193, 24.480734007699148, 21.078647579465592, 26.634989976882935, 26.867549657821655, 27.48406331879752, 30.3429673739842, 37.17506851468767, 54.38497475215367, 84.70701067788261, 40.37871265411377, 45.26221234457833, 47.445228644779746, 48.09671606336321, 47.66518429347447, 50.35982772282192, 49.30957623890468, 51.03390720912388, 42.519014903477256, 51.742845807756694, 46.982416084834504, 45.749166420527864, 41.93579701014927, 37.739498479025706, 31.658362116132462, 23.11776147569929, 18.86044212750026, 9.17641466004508, 2.180245271750859, 0.11884888261556625, 0.12918310665658542, 0.026189473790249655, 0.02819425130396017, 0.02776604820974171, 0.08170208946934768, 0.03128206230966108, 0.02137736450614674, 0.0542589577713183, 0.008822158793918788, 0.008419608564249106, 0.047771820332854986, 0.11350132099219731, 0.02972952668954219, 0.021393761304872375, 0.038345791665571075, 0.10591109935194254, 0.012598405492358973, 0.038835839834064245, 0.009931404941848345, 0.03899915303502764, 0.05471490616244929, 0.035104555410466025, 0.03336839803627559, 0.04745089701775994, 0.05997230405254023, 0.03478850397680487, 0.035607695912144015, 0.027922810155100057, 0.01974038520295705, 0.00958019182352083, 0.02109777245537511, 0.025257115784500326, 0.04399285525349634, 0.012707593651222331, 0.05025081070406096, 0.02828679669515363, 0.061632380687764714, 0.042118137635822804, 0.05272741602467639, 0.0743986845814756, 0.06436138746461698, 0.030931799140359675, 0.03741320974326559, 0.038676991393523555, 0.032808118100677214, 0.043002709812883816, 0.017855682942484106, 0.033971571563077826, 0.0064489774771833, 0.041394042383347235, 0.05314468113439424, 0.03560355345585516, 0.08445007487067155, 0.046352359000593424, 0.1266509632446936, 0.014651632102738534, 0.01818882497692747, 0.03191332718623536, 0.02985594454886658, 0.031253244927419085, 0.057346997782588005, 0.023945500808102742, 0.055338853038847446, 0.06295273519520249, 0.04153918780918632, 0.05608430178835988, 0.08815020096621343, 0.009276566910557449, 0.029987091797270944, 0.04943256193239774, 0.07065535616129637, 0.07740508325930152, 0.02126957243308425, 0.03753663865583284, 0.05440166047109025, 0.021173054219356606, 0.045468129483716826, 0.09253685522292342, 0.03638323429705841, 0.024956122739240527, 0.07616399521274225, 0.08038451695548636, 0.09770185021417481, 0.061523930435734134, 0.0562077917690788, 0.026232106145471334, 0.05977274690355573, 0.018753388164831058, 0.021575618867895434, 0.0016038960561023227, 0.04216632040749703, 0.03562807910410421, 0.043690866458096674, 0.027954911646832312, 0.01021537184715271, 0.006336698591309998, 0.035538536230368276, 0.03486910375899502, 0.15413723619920866, 0.05308921428929482, 0.012064658820496073, 0.07707150187343359, 0.07949711528739759, 0.027864920939984064, 0.027826777093910744, 0.05772010383329221, 0.02855820900627545, 0.01779747142323426, 0.030811467740152563, 0.028053750450323735, 0.08920074959418603, 0.05820841155946255, 0.013353625994308718, 0.09551312016057116, 0.05418634095362254, 0.062200416278626235, 0.03176694343398724, 0.04263124242424965, 0.23060604291302816, 0.4338076849068914, 2.64704783473696, 9.472494772502355, 18.707482746669225, 27.67551224572318, 39.16860396521432, 47.02949013028826, 51.924666268484934, 52.6003542627607, 54.70298685346331, 56.005888734545024, 51.870043005262104, 45.68962035860334, 44.92589521408081, 42.49926117488316, 21.704032352992467, 47.99349362509591, 77.37215178353446, 21.43482092448643, 15.646552869251796, 17.64413043430873, 27.27532206262861, 23.00609871319362, 15.188303538731166, 22.880807059151785, 31.213232721601212, 30.287889003753662, 30.655886445726665, 24.75680157116481, 28.94842917578561, 31.138188702719553, 30.4976863861084, 27.28697419166565, 26.351703235081263, 26.550390447889054, 59.37715121677944, 82.74392223358154, 26.662173066820415, 21.886542422430857, 25.145706142698014, 24.278081110545568, 28.155943700245448, 30.87676967893328, 38.73844793864659, 43.71166276931763, 42.84350619997297, 57.387454645974294, 58.93201487404959, 58.73441505432129, 50.72379868371146, 51.23505755833217, 43.86296674183437, 36.926243100847515, 33.18091739927019, 18.802977051053727, 7.587477156094142, 0.915354813848223, 0.07257633629654135, 0.04723226285672613, 0.011783826746977866, 0.05009722430258989, 0.01504067694103079, 0.049694096469985585, 0.04421253775113395, 0.053717761633119414, 0.023778922157362103, 0.048355085642210076, 0.03220402176624962, 0.07050803263804742, 0.011327178616608893, 0.027591590071097016, 0.03722885177869882, 0.03505925641262105, 0.040278622414916754, 0.09961892877306257, 0.06231321594012635, 0.029837681778839657, 0.03178596955591014, 0.020509891411555663, 0.075522725337318, 0.03716325440577098, 0.0642835120005267, 0.016136468587709323, 0.02981508317004357, 0.020417025412565896, 0.03219325341550367, 0.048289535766733546, 0.04948342491739562, 0.03590125051726188, 0.1319972085101264, 0.030237800308636258, 0.023705604752259593, 0.03239837455164109, 0.042314553167670965, 0.1314740851521492, 0.02614324859210423, 0.03816211223602295, 0.09482051911098616, 0.04483968731282013, 0.10619575157761574, 0.03126184196610536, 0.03183043056300708, 0.0159675218497536, 0.043225951226694245, 0.01655022906405585, 0.0892702926482473, 0.03627071962026613, 0.014838488772511482, 0.11262890816267047, 0.04869281626971705, 0.03847529685923031, 0.05856831331870385, 0.12801541574299335, 0.11146558022924832, 0.11795906536281109, 0.18785892027829373, 0.22593973044838223, 0.1650463558201279, 0.15260967745312623, 0.16632641213280813, 0.11247874157769339, 0.14535887938524994, 0.16076072864234447, 0.16523266796554836, 0.1473678451563631, 0.10346701621477093, 0.16475188519273484, 0.19444723746606282, 0.21110394224524498, 0.172979705833963, 0.19437652054641927, 0.09478632773139647, 0.34200756943651606, 0.15744041252349103, 0.19576569886079856, 0.07690698427281209, 0.10657073038497142, 0.11861121893993445, 0.14693426127944673, 0.11690516477184636, 0.16333325845854624, 0.28046430753810064, 0.10780283462788377, 0.15333288721740246, 0.11200680690152304, 0.10899880009570292, 0.09422344900667667, 0.1074862369735326, 0.10193786969674484, 0.09240645436303956, 0.12066111394337245, 0.14619867503643036, 0.1563480118555682, 0.11390351583915097, 0.08553592089031424, 0.31823664211801117, 0.17208660447171756, 0.1090354545574103, 0.1994466292006629, 0.10480148425059659, 0.150523860805801, 0.08974770310201816, 0.1301309522241354, 0.0926663875579834, 0.10340938823563711, 0.147905950567552, 0.08879539955939565, 0.16467530573053019, 0.13571883738040924, 0.10084901776696954, 0.1711029051137822, 0.1647518037685326, 0.12569000838058336, 0.17777833262724535, 0.27179667406848496, 0.33192247631294386, 0.17305955583495752, 1.1771327555179596, 5.410807166780744, 13.266695840018135, 21.715604577745708, 35.804532868521555, 46.42643860408238, 57.397883892059326, 61.66542230333601, 66.66816002982003, 69.24805395943778, 66.08401107788086, 60.52577877044678, 67.36647483280727, 53.85740845543997, 52.48834235327584, 50.30752168382917, 80.59362152644566, 50.58737775257656, 32.17810821533203, 38.50630862372262, 43.43260226930891, 41.89872489656721, 29.75093569074358, 24.843228476388113, 30.897124426705496, 31.97979620524815, 34.97100959505354, 31.343045915876115, 29.142999580928258, 35.91521419797625, 35.546237060001914, 38.90240110669817, 39.92156982421875, 49.411742550986155, 68.44485609872001, 95.74011775425502, 55.48586818150112, 56.469420433044434, 60.20459829057966, 56.65804665429251, 58.268117972782676, 60.90758228302002, 63.128407205854145, 64.26101221357072, 61.62512275150844, 70.01965836116246, 64.8665268761771, 64.81640951974052, 60.40377535138811, 57.412273611341206, 46.60892609187535, 37.521335465567454, 30.262576716286794, 15.463702338082449, 4.662762369428362, 0.4445520969373839, 0.2686642307255949, 0.14083222299814224, 0.10142031032592058, 0.1336880906351975, 0.1622727217950991, 0.12554453047258513, 0.1534339210816792, 0.12494638828294617, 0.11782018281519413, 0.14569453708827496, 0.1385807352406638, 0.21715513111225196, 0.12227661082787172, 0.14851574998881134, 0.10513890614467007, 0.16931396110781602, 0.1814351071204458, 0.19537533766457013, 0.11962984928062984, 0.13895535442445958, 0.1497230673474925, 0.07983017420130116, 0.21011390537023544, 0.17387728552733148, 0.09363841611359801, 0.11611194376434598, 0.12899188191762992, 0.07304907842938389, 0.09237418323755264, 0.19035274003233227, 0.1243478525429964, 0.11203286943158933, 0.22937537037900516, 0.09986433453325715, 0.08972519609544959, 0.10312685982457229, 0.10310766406889472, 0.21661133957760675, 0.1435185702783721, 0.2142823495502983, 0.22190882531659945, 0.10800558767680611, 0.28555684856006075, 0.13165977304535254, 0.08801962368722473, 0.13799210611198628, 0.12766127474606037, 0.09182471236480133, 0.16643841112298624, 0.14437637424894742, 0.09657443035393953, 0.19088129167045864, 0.22576796609376157, 0.1633780553404774, 0.1334999735866274], [0.0903960500976869, 0.09051676826285464, 0.028078355826437473, 0.019651637911530476, 0.03609610202589205, 0.05366531426885298, 0.016845327336341143, 0.03286724564220224, 0.012083374512647944, 0.04958745112110462, 0.05269706515329225, 0.026454696165663854, 0.09325685551656143, 0.004860511307405042, 0.019615382089146545, 0.04351087147369981, 0.032502383791974614, 0.04507688279928906, 0.051760517193802764, 0.019769686041399837, 0.04908709600567818, 0.04697966801800898, 0.061624041492385526, 0.00912655723680343, 0.08025420430515494, 0.132209359269057, 0.06611226565603699, 0.06233626577470984, 0.0208500257493662, 0.012170095528875078, 0.07597107413624014, 0.037241038267633746, 0.03134741201730711, 0.044377231770860295, 0.02195107264976416, 0.026413337759939686, 0.028601737027721744, 0.04187275223167879, 0.06920888234994241, 0.07457593828439713, 0.01839149829798511, 0.055083286216748614, 0.050471602606454065, 0.029672363506896154, 0.03622156993619033, 0.012791854978006865, 0.05596640972154481, 0.018201795173808932, 0.00323501684553256, 0.08913647197186947, 0.04879453545436263, 0.025157567911914418, 0.08467568776437215, 0.03843949395897133, 0.02922217587807349, 0.040233241992869546, 0.024349006923979948, 0.05868781012083803, 0.02011636654580278, 0.04479488025286368, 0.06155337207019329, 0.06176510892276253, 0.023019839942987477, 0.03382215815197144, 0.04276075779593416, 0.022747160467718328, 0.009394762621793364, 0.03546298135604177, 0.06457686304513897, 0.3577940123421805, 1.1506328689200538, 3.363010193620409, 7.471113068716867, 11.820575084005084, 12.936004144804818, 29.466261046273367, 43.41298403058733, 53.35908017839704, 54.78534732546125, 58.94373648507254, 50.25465631484985, 44.165442671094624, 44.21173504420689, 46.13557311466762, 53.10789237703596, 49.49667733056204, 47.01296383993966, 52.07171099526541, 46.509118693215505, 45.3809813771929, 40.59651436124529, 42.436254910060335, 51.35690116882324, 51.054088251931326, 47.91432932444981, 48.75583260399954, 50.26957062312535, 49.86081504821777, 44.94453028270176, 39.1736170904977, 50.21183109283447, 50.35729510443551, 54.470416750226704, 53.03425536836897, 46.911714690072195, 47.12020928519112, 48.24353149959019, 38.1434702192034, 31.316885948181152, 23.739015545163834, 17.824684585843766, 10.323111483028956, 13.508478386061531, 7.713626044137137, 2.460927741868155, 1.8362566786152976, 0.35776955794010845, 0.09021141393376247, 0.0234727841203234, 0.034831007410373004, 0.08892196669642415, 0.10004268746290888, 0.02978012165320771, 0.010808936469922108, 0.012571805223290409, 0.028469945171049664, 0.02943255566060543, 0.013991772064140864, 0.025893730909696648, 0.03771404502913356, 0.01047810654355479, 0.02832760718385024, 0.018944477196782827, 0.033997742658747096, 0.05738019850105047, 0.06900265520172459, 0.1021874552326543, 0.06029354288641896, 0.04839565525097506, 0.04750946816056967, 0.013690581395556884, 0.029609327603663717, 0.02122124208004347, 0.08168625246201243, 0.10017202980816364, 0.07066980895719358, 0.024757720796125274, 0.029912554725472416, 0.04755996473665748, 0.03121632244437933, 0.05887210701725312, 0.032861702011099884, 0.03709692082234791, 0.05694593608911548, 0.0254338690678456, 0.0337311089304941, 0.14107800195259707, 0.021230887455333556, 0.058906216972640583, 0.027859675864289914, 0.07177589567644255, 0.09016291903597967, 0.012895556333075677, 0.05348533624783158, 0.016688375401177576, 0.03946572049920048, 0.03388853584017072, 0.029141029875193323, 0.02002095604049308, 0.03121741149308426, 0.05297465043674622, 0.013608613517135382, 0.058730856382421086, 0.016556553010429655, 0.033183602416621785, 0.0708992759298001, 0.060602357744106224, 0.0172180313550468, 0.01896861268739615, 0.10575781150587968, 0.03961475732337151, 0.0700832222189222, 0.04511634300329855, 0.028809046439294304, 0.04616563294881156, 0.04269074994538512, 0.04128064561103072, 0.042792886429067166, 0.06163184464509998, 0.01860913840521659, 0.03271263126017792, 0.044325727570269785, 0.04863431976575937, 0.04488079296424985, 0.028730533152286495, 0.010394006368837186, 0.05541402114821332, 0.010133172418656093, 0.04687672747032983, 0.09017176713262286, 0.07881123851984739, 0.013026330387219787, 0.03248166133250509, 0.039358562856380425, 0.058346059173345566, 0.04025433425392423, 0.0105506453297234, 0.07525633927434683, 0.03716450969555548, 0.025335495060841953, 0.02969271277210542, 0.03508592623152903, 0.0037338229927367395, 0.010146613349206746, 0.019777704628982713, 0.025035640258075934, 0.048565523100218604, 0.02395071365338351, 0.04196987773424812, 0.04360953385808638, 0.05925731134733983, 0.04591040200154696, 0.06712156614022595, 0.023052769247442484, 0.05726949551275798, 0.11816276157540934, 0.03917748221595373, 0.016229985980316997, 0.05243274862212794, 0.03068074457613485, 0.03361990043361272, 0.01414091490940856, 0.051519471021103005, 0.034830881881394556, 0.012039263799254383, 0.07182965600597006, 0.03473432634824088, 0.01823149974058781, 0.03530994117526071, 0.019228557756702815, 0.01773785024748317, 0.024380429880693555, 0.07521226163953543, 0.136508652142116, 0.4438883268407413, 2.2637776008674075, 4.895021106515612, 10.395540373665945, 15.8520701612745, 23.300441776003154, 28.276124954223633, 43.65812689917428, 56.34855304445539, 60.013460295540945, 57.43025207519531, 58.91895226069859, 48.18323155811855, 53.242458139147075, 40.09710911342076, 31.92700379235404, 36.08144290106637, 39.48972191129412, 36.767619201115195, 33.34834814071655, 27.286618096487864, 32.27190889630999, 27.478251150676183, 26.843302181788854, 31.658514976501465, 28.430593831198557, 33.19031136376517, 33.178516796657014, 37.69143778937203, 38.48963642120361, 42.21780354636056, 48.20319720676967, 62.67161178588867, 52.76922675541469, 56.489917618887766, 61.87414618900844, 59.26600088391985, 56.18396411623274, 57.983936650412424, 52.572634424482075, 48.571347509111675, 38.26823207310268, 34.338330950055806, 24.57778991971697, 24.989957060132706, 19.35867312976292, 9.941627587590899, 6.062649377754756, 2.0996765664645602, 0.4498025194874832, 0.03634652215987444, 0.08155554626137018, 0.045501014683395624, 0.05546313690553818, 0.04897732600303633, 0.025772203591519167, 0.015394485455804637, 0.04228124388360551, 0.037381661257573535, 0.024636064556294253, 0.02847576021615948, 0.04595854066844497, 0.01807382346929184, 0.040173038973339965, 0.06052365446729319, 0.017163714626803994, 0.033376930614135096, 0.04754919299323644, 0.04054469635177936, 0.04065927716770342, 0.048902147715645175, 0.054231548349239996, 0.01616854633071593, 0.05836041697434016, 0.03612643593390073, 0.01763042967234339, 0.01510787396026509, 0.043957713924880536, 0.01782596141232976, 0.06572100879358393, 0.03729546695415463, 0.06566719418125493, 0.025425982794591358, 0.015541255973013384, 0.00942477337749941, 0.09177963728351252, 0.03161278027775032, 0.05340431916660496, 0.051773161693875275, 0.04530745917665107, 0.029209958855062723, 0.025036425662360022, 0.12817253731191158, 0.044488223136535714, 0.0348072654700705, 0.09215203765779734, 0.023343302675389817, 0.05291380620162402, 0.05811001041105815, 0.0064171092318637026, 0.03097670798056892, 0.028187347210145423, 0.043232421058097055, 0.0364042247778603, 0.010319302207790315, 0.02435295090877584, 0.06449887901544571, 0.03327028187257903, 0.1988275609910488, 0.18044048334871018, 0.23391216407929147, 0.25309755174177034, 0.10697373947394745, 0.20965955832174846, 0.14151162654161453, 0.08973627657230411, 0.1552637264664684, 0.17899429452206406, 0.16974324307271413, 0.2138189101325614, 0.23300097297344888, 0.08070245810917445, 0.1645691150001117, 0.24585025491459028, 0.1717691043657916, 0.1926051913095372, 0.12518042858157838, 0.08697271200695209, 0.2943727826433522, 0.16826907146189893, 0.15538690771375382, 0.16309258208743163, 0.18752356113067695, 0.23130105276192936, 0.15905805357864924, 0.15503387951425143, 0.13213759740548475, 0.07169992011040449, 0.2058115726602929, 0.16937141945319517, 0.10615347206060376, 0.17125254922679492, 0.11692393305046217, 0.12154293805360794, 0.07660956201808793, 0.13080270189259732, 0.2189351591680731, 0.15353391000202724, 0.11585661103682858, 0.10448750574141741, 0.1469971343342747, 0.14143715053796768, 0.20068304214094365, 0.1059059424858008, 0.18626316876283713, 0.11247057201606886, 0.13065862176673754, 0.2333055537726198, 0.11484695092907973, 0.14328815335673944, 0.14690751342901162, 0.2499355785548687, 0.13983868488243648, 0.1464040404451745, 0.12545284682086535, 0.1273533148424966, 0.08577079578701939, 0.17764801319156373, 0.20077809132635593, 0.09120904361563069, 0.12703029146151884, 0.12598408545766557, 0.05929659852491958, 0.10154436009802989, 0.2185127032654626, 0.12628306155758245, 0.2718992142805031, 0.9636051676103047, 2.330992736986705, 6.391319147178105, 10.886703320911952, 18.57967758178711, 25.34099394934518, 43.52241121019636, 59.829722132001606, 69.16828863961356, 73.59955092838833, 75.6932099206107, 65.80949469975063, 59.36467225211007, 57.543163776397705, 58.50475624629429, 65.47057546888078, 61.79023279462542, 62.9930910382952, 67.10618141719273, 58.96115561894008, 59.07971967969622, 51.506864139011924, 54.325762203761506, 64.29557950156075, 64.92216805049351, 60.94050979614258, 61.43048981257847, 61.449632099696565, 62.6572915485927, 60.913932936532156, 53.42302097593035, 63.923941203526084, 67.83257389068604, 71.88743836539132, 74.3385682787214, 68.68443693433488, 65.76271942683628, 64.29227910723004, 55.110158239092144, 49.1576121875218, 37.81567505427769, 30.97830023084368, 20.91682403428214, 21.492117507117136, 13.863924775804792, 6.661367833614349, 3.6177159547805786, 1.0500039543424333, 0.2503097227641514, 0.1299603142376457, 0.1715988056468112, 0.18187193439475127, 0.17354902385600976, 0.21262873256845133, 0.10443168945078339, 0.1313063512955393, 0.12217255069741181, 0.11382392368146352, 0.13528393714555673, 0.10538423726601259, 0.1994390838912555, 0.08827337542814867, 0.19956455858690397, 0.10883321040975195, 0.08320280537009239, 0.13703928009739944, 0.1704778250839029, 0.12606496683188848, 0.09313320608011313, 0.12575673551431724, 0.1541611206318651, 0.11664059039737497, 0.12227156252733298, 0.11525177849190575, 0.19188515708914824, 0.1303612741508654, 0.15171433692531927, 0.1452951920883996, 0.08086420050156967, 0.17953497836632387, 0.20888262215469564, 0.13995456509292126, 0.1885072197765112, 0.11025475484452077, 0.21872364623206003, 0.09914281432117734, 0.16621404673371995, 0.18245244824460574, 0.10436487410749708, 0.16044827683695725, 0.04718434132103409, 0.22341939354581491, 0.21847807083811077, 0.16166810638138226, 0.13808057350771769, 0.10136968482817922, 0.13085262849926949, 0.11647466144391469, 0.10137746762484312, 0.07572254711495978, 0.09196938281612736, 0.10619771932916981, 0.13289022844816956, 0.1100184889510274, 0.21205165210579122, 0.15158411248454026, 0.1940916444041899], [0.009858155390247703, 0.06571682223251887, 0.03729195553543312, 0.0162768473050424, 0.03798394590350134, 0.04766604011612279, 0.03384864815909948, 0.0616200856332268, 0.03420814958267978, 0.0270722461531737, 0.03834624967670866, 0.013252479323585118, 0.023101730638050606, 0.0085065882719521, 0.03345667204952665, 0.02720285057356315, 0.09799513340528522, 0.028385706744822006, 0.05428736124719892, 0.03351546710889254, 0.08654377609491348, 0.025769131524222236, 0.05422983504831791, 0.020775826248739446, 0.10070277311440025, 0.08488557221634047, 0.013193110053959702, 0.017381219027031745, 0.05723089365554707, 0.06207370664924383, 0.037005393233682425, 0.07497974804469518, 0.04099422919430903, 0.0700733359637005, 0.06321241733218942, 0.02999587882576244, 0.1315571242677314, 0.026171275481049503, 0.03133895747097475, 0.01899124352660562, 0.050065122810857635, 0.03608780354261398, 0.05542146807004299, 0.06596156302839518, 0.0564889291833554, 0.05370788894859808, 0.04419648361259273, 0.06077606270888022, 0.06265325019402163, 0.04901673870959452, 0.039540576482457776, 0.05080158097137298, 0.021958307529400502, 0.038557989921952994, 0.049708874962691746, 0.08334347246480839, 0.03300032332273466, 0.027141383782561337, 0.014046745275014212, 0.01443729137203523, 0.044867049237447124, 0.05532484129071236, 0.09108111262321472, 0.03849344088562897, 0.05370258619742734, 0.015414017086316432, 0.039617797160255055, 0.07774675956794194, 0.006257164109099124, 0.03998697449320129, 0.0339053160111819, 0.027110746230131814, 0.09469705966434308, 0.043387001513370445, 0.18550995418003627, 0.5750989775572504, 2.6484129386288777, 7.9797020980290005, 14.180033070700508, 28.63310429028102, 40.81992326463972, 54.36491877692086, 51.48340702056885, 52.62510027204241, 54.11051743371146, 56.21252816064017, 55.308324337005615, 54.94119889395577, 57.542941434042795, 55.47912495476859, 57.322009563446045, 59.02614906855992, 55.53064584732056, 53.73490824018206, 57.044832025255474, 54.554889474596294, 46.6244900567191, 47.143819264003206, 49.11188609259469, 46.97459588732038, 43.88506201335362, 35.653093406132285, 31.6162143434797, 13.879096167428152, 10.679916245596749, 8.545301096779959, 5.1236437644277295, 1.6480380126408167, 1.0617140574114663, 0.3012235164642334, 0.14129445462354592, 0.050083979299025874, 0.05496964517182537, 0.07005372630166155, 0.04820867135588612, 0.021957562837217535, 0.011814035126008093, 0.07556219571935278, 0.056731535986598046, 0.03386622900143266, 0.04437462280371359, 0.06098127205457006, 0.031298119840877395, 0.14955059731645243, 0.046710890119097064, 0.03679286928049155, 0.08561775899891343, 0.055990830196865966, 0.029973018980984176, 0.11542176508477756, 0.05829405624951635, 0.04429280165848987, 0.049657916982791254, 0.0638750067778996, 0.018748524765084897, 0.025599480806184665, 0.02776903715649886, 0.02884423526536141, 0.023022204637527466, 0.056688415086162944, 0.0733320207468101, 0.060264745860227516, 0.0506302271304386, 0.055867842332060845, 0.01857831934466958, 0.08139994461089373, 0.01717391300813428, 0.04466193488665989, 0.06709831274513688, 0.02196269086562097, 0.0527163151917713, 0.04813904348494751, 0.023480638163164258, 0.051599012288664065, 0.051186741196683476, 0.0408678825811616, 0.15640110043542726, 0.011278123927435704, 0.03255605251927461, 0.04229614111993994, 0.007628921885043383, 0.07295377818601471, 0.06417139087404523, 0.01465518762623625, 0.032301649384732754, 0.05839697644114494, 0.04034540043877704, 0.020210263918020895, 0.01645700174516865, 0.014055392355658114, 0.07285199114786726, 0.028051038006586686, 0.04338663510446038, 0.05487892503983208, 0.058631193158882, 0.0965020510235003, 0.036698101687112024, 0.04774769841294203, 0.03406914150608437, 0.008324172613876206, 0.06979166250675917, 0.026604285995875086, 0.036953352990427187, 0.03877299392063703, 0.05452103174424597, 0.05060058193547385, 0.018188609542059045, 0.027447815285995603, 0.019117522286251187, 0.03018028089510543, 0.05810420893664871, 0.004580853523553482, 0.029312631381409507, 0.0277253395012979, 0.02525557720634554, 0.04070335480251482, 0.016225994498069798, 0.06593325454741716, 0.02158947624931378, 0.09759987997157232, 0.04401220028687801, 0.025407010955469947, 0.04601666737081749, 0.03675035906157323, 0.062354735497917445, 0.10729126672127418, 0.031112638900854757, 0.061252041453761716, 0.05234107854110854, 0.040861721483192275, 0.0505745024420321, 0.04179290223068424, 0.06239204813859292, 0.03228884542893086, 0.03245014338088887, 0.039832577242382934, 0.1188423822500876, 0.04642186473522868, 0.06507720119718995, 0.013855134619266858, 0.08723926091832773, 0.03714689153379627, 0.03803078856851373, 0.055547387206128666, 0.10667273455432483, 0.03778844978660345, 0.034943145500229936, 0.09067732321896724, 0.036485978069582155, 0.002969927420573575, 0.08121583770428385, 0.10440185426601342, 0.06249969771930149, 0.024174201036138192, 0.047062798735818694, 0.04228597666536059, 0.023968991690448353, 0.05915801453271082, 0.036966764235070775, 0.058575220805193694, 0.06867821368255786, 0.021556148305535316, 0.017393894061180096, 0.038116904840405495, 0.009053970953183514, 0.0395768102524536, 0.055189093574881554, 0.15019464918545314, 0.2843638211488724, 0.5004117052469934, 0.866415231355599, 2.9554783701896667, 8.273604818752833, 18.861760548182897, 29.58383846282959, 43.469987051827566, 56.911721910749165, 59.761768749782014, 59.01867280687605, 60.89611775534493, 61.00010449545724, 60.414795194353374, 62.08989470345633, 61.138491766793386, 65.2711135319301, 62.68446595328194, 63.51018292563302, 62.72607871464321, 64.9550747190203, 65.2917149407523, 65.35291467394147, 66.37283379690987, 59.83396053314209, 60.787003244672505, 60.41320405687605, 58.421905926295686, 54.917526381356375, 48.39898354666573, 46.088144711085725, 27.643587010247366, 21.027029412133352, 18.284285340990337, 12.728521381105695, 7.601707935333252, 4.5063141243798395, 2.1024000431810106, 0.5023057407566479, 0.4298401549458504, 0.45302564225026537, 0.1814771627209016, 0.15794031641313008, 0.04632955004594155, 0.019481171255132983, 0.07053510618529149, 0.05791825641478811, 0.07654829709125416, 0.030103738752326796, 0.031994062675429244, 0.013384820793622305, 0.05989879835397005, 0.10972230841538735, 0.017611138921763216, 0.02685786810304437, 0.03243622662765639, 0.015850401616522243, 0.06223073322325945, 0.0863597709685564, 0.018018205650150776, 0.06216617740158524, 0.09488752444407769, 0.046511858834752014, 0.0332421837374568, 0.0328132953228695, 0.009076266765727528, 0.00465553775263418, 0.03427093442795532, 0.08466359627033983, 0.008525285304390957, 0.02593215465146516, 0.030125492585024664, 0.04368419645886336, 0.03849228398342218, 0.012928874946997633, 0.02225299019898687, 0.03904072687562023, 0.04771284546170916, 0.07652254668729645, 0.054524095329855166, 0.05237872366394315, 0.050991781122450314, 0.10240082056926829, 0.045814572500863245, 0.028695340933544294, 0.01316996946531747, 0.03018465744597571, 0.08279451049332108, 0.043715697447104115, 0.07039818460387842, 0.044872250208365064, 0.07509162489856992, 0.009404110289844019, 0.06387366327856268, 0.061909311184925694, 0.021980926494247148, 0.019859154276283722, 0.07479713391512632, 0.058513698035052845, 0.020060175364570956, 0.07286607753485441, 0.09297691910926785, 0.04213317736451115, 0.06150755060038396, 0.12957178508596762, 0.1566934540335621, 0.16103234621030943, 0.11066606920212507, 0.1913213487714529, 0.08946457758013691, 0.08041136658617429, 0.1534465282623257, 0.19089731866759913, 0.12723310557859285, 0.10401230052645717, 0.09280771961701767, 0.13131625790681156, 0.13939817994832993, 0.13906297007841723, 0.08550518325396947, 0.1864845883101225, 0.0934060246550611, 0.08938200665371758, 0.17463147720055922, 0.16084241068788938, 0.11406181805900165, 0.14544738749308245, 0.1168935482523271, 0.11919664538332395, 0.15730632043310575, 0.08135866254035916, 0.12755806956972393, 0.25216909870505333, 0.20543466002813407, 0.19293505432350294, 0.12371657070304666, 0.15887104932750973, 0.09916796082896845, 0.217795301760946, 0.09741489096943821, 0.25630251690745354, 0.1545079741626978, 0.14903638990862028, 0.10096685215830803, 0.18994541546063765, 0.13083957348551067, 0.16196994589907782, 0.1339595860668591, 0.14970215489821775, 0.1060354680355106, 0.10734073192413364, 0.1395200855497803, 0.22955727204680443, 0.12891204548733576, 0.16077428577201708, 0.21223875135183334, 0.19197234883904457, 0.17227402941456862, 0.22164202534726687, 0.14565622700112207, 0.14918196281152113, 0.08046876386340175, 0.21057722265166895, 0.1040228313899466, 0.09807565515594822, 0.17867634658302578, 0.1174253975706441, 0.2087157161108085, 0.13020648674241134, 0.08072742141251053, 0.08659950417599507, 0.14708501818989003, 0.13259336937751087, 0.19480939874691622, 0.08524570467748813, 0.22547646744975022, 0.20147325045296124, 0.21969821250864438, 0.3801929961357798, 1.467080105628286, 4.527097923415048, 12.740196960312979, 22.740019185202463, 39.85793127332415, 57.241007464272634, 70.33333478655133, 73.18403475625175, 72.09406389508928, 74.9658933367048, 75.136214528765, 75.11505726405552, 73.48445401872907, 77.99899741581508, 75.94048241206578, 76.46518952505929, 79.19125965663365, 76.43379756382534, 72.55058138711112, 75.86200250898088, 75.73239081246513, 68.911240032741, 69.34286212921143, 67.58277920314244, 68.38394124167306, 62.67154925210135, 54.041872705732075, 48.23206697191511, 28.259921755109513, 18.892349992479595, 13.116018073899404, 8.043249453817095, 4.071702131203242, 2.391453789813178, 0.7889494938509805, 0.15130057984164783, 0.2186109008533614, 0.2854992002248764, 0.20799933240881988, 0.19940145233912127, 0.14946880670530455, 0.13648197214518273, 0.20040960609912872, 0.18449144597564424, 0.233686591897692, 0.09738044174654142, 0.16181800833770207, 0.1328372484339135, 0.25960361691457884, 0.19830492617828505, 0.09997895945395742, 0.15032005602759974, 0.19772110107753957, 0.12048503410603319, 0.25732802759323803, 0.2773454620369843, 0.11387789435684681, 0.12965745691742214, 0.19040015605943544, 0.1802308295986482, 0.09459797998092004, 0.08159574267587491, 0.18934130216283457, 0.19336375274828502, 0.13987909842814716, 0.12162084744444915, 0.24874540099075862, 0.1467218662479094, 0.1500120825533356, 0.09246182282056127, 0.20725392097873346, 0.08833715093455144, 0.10678497781710965, 0.153032798320055, 0.16985742694565228, 0.23603877425193787, 0.11337641626596451, 0.12254711559840611, 0.11705476817275796, 0.19710648405764783, 0.1258127282240561, 0.189876951277256, 0.1899476003433977, 0.1356941115643297, 0.11015304244522538, 0.11405987744884831, 0.22650746069848537, 0.2356750794819423, 0.12092617686305727, 0.1856941357254982, 0.15857979495610508, 0.19334962564919675, 0.10248673667332955, 0.11800129738237176, 0.177753905366574, 0.20720981620252132, 0.19794598115342005, 0.1998369361140898, 0.26048636383243967, 0.10417703525828463, 0.16917617778692925], [0.03541676972859672, 0.06068267593426364, 0.04637674554916365, 0.016654324817604253, 0.0510299962147006, 0.041050856334290335, 0.09635351292256798, 0.03461410351363676, 0.06484021605657679, 0.03682526593495693, 0.0435172497028751, 0.040996057846184285, 0.051128071666296036, 0.013893579565254706, 0.06058009501014437, 0.04126763130937304, 0.04304853128269315, 0.027915943380711333, 0.02304207723188613, 0.03320487788213151, 0.004756914277095348, 0.02668773732148111, 0.16186243881072315, 0.12093229724892549, 0.055789400291229994, 0.064070194161364, 0.07896510990602629, 0.009000141073816588, 0.019191316362204294, 0.025080742480765496, 0.06550976048622813, 0.049066458363085985, 0.04259337677753397, 0.08962233697197267, 0.07237247045018844, 0.039953203805323155, 0.04141566390171647, 0.030094395325120007, 0.009678724438085087, 0.055418825176145346, 0.03838639859376209, 0.05364995902138097, 0.06828452087938786, 0.04785613848694733, 0.13322127211306775, 0.0806295427360705, 0.05250039856348719, 0.03235843937311854, 0.03968777108405318, 0.08969502164317028, 0.03182057144918612, 0.010947014105373194, 0.08505004231951066, 0.019612637414996113, 0.09223574852304799, 0.1009348863735795, 0.06653254346123763, 0.07508820508207593, 0.023387302278674076, 0.013597682317984956, 0.023444343325016753, 0.02741686051844486, 0.09290222597441503, 0.09156762901693583, 0.08434363308229617, 0.024551471595519354, 0.04339730506762862, 0.03509677600647722, 0.02438811768245484, 0.042733022677046914, 0.04148734434108649, 0.037932750436344316, 0.09606371061610323, 0.015450537537357636, 0.05635056232235261, 0.04047891916707158, 0.01260970818943211, 0.06895313571606364, 0.08108450725142445, 0.12956833812807286, 0.6752206193549293, 2.8709776358945027, 5.983005217143467, 7.328288504055568, 12.61804849760873, 13.78268643787929, 12.609189544405256, 15.176222358431135, 11.012067931038992, 12.4376254933221, 11.452713131904602, 12.654444030353002, 11.609185695648193, 9.74774158000946, 7.559432489531381, 5.9383556587355475, 5.623845015253339, 5.063740738800593, 5.039902772222247, 2.9354289088930403, 2.476647172655378, 1.1662982340369905, 0.47926969400474, 0.04549923013629658, 0.03184392323185291, 0.019654380889343362, 0.06519626373691217, 0.06583214604428836, 0.03274184897808092, 0.009421215309495372, 0.0013669067806664056, 0.08330409029232604, 0.03590974238302026, 0.008503409335389733, 0.09426253940910101, 0.07039873421724353, 0.03501110756769776, 0.034968509139227014, 0.06448878241436821, 0.027499870796288763, 0.042819393399570665, 0.11489864172680037, 0.018254310391577225, 0.024999126592384915, 0.02796914052617337, 0.043418845161795616, 0.09991357581956045, 0.0532019834167191, 0.048669518769851754, 0.043967026818011484, 0.08273840243262903, 0.039269142118947845, 0.060021789611450264, 0.05319061456248164, 0.024977935943752527, 0.022402283170127442, 0.027765423957524554, 0.048750708877508125, 0.03544819947066052, 0.07791878855121986, 0.04344279405527881, 0.049746309739670584, 0.016344288596883416, 0.017996908132252947, 0.019327452539333274, 0.038060837491814575, 0.08541063618447099, 0.00693387768530686, 0.06515544307019029, 0.03193016842539821, 0.023047568276524544, 0.012931467798937644, 0.01752171988066818, 0.028681631133492504, 0.03837558274556484, 0.05040182885048645, 0.05952825038028615, 0.07964775684688773, 0.0386085916709687, 0.10648298902170998, 0.015796381747350097, 0.07603712952030556, 0.08221943849431616, 0.08321753636534725, 0.031662886696202416, 0.03786808265639203, 0.030851501306252818, 0.04993125463702849, 0.026492171654743806, 0.037708464078605175, 0.015511578547635248, 0.0018445705188371772, 0.06324346030929259, 0.036461900254445415, 0.027861044808690037, 0.08356444417898144, 0.04259149045018213, 0.08014156070670911, 0.04899452347308397, 0.052940235140600374, 0.05565269244834781, 0.026087515422009995, 0.043249920476228, 0.029826984674270664, 0.016876670565190058, 0.005978441855404526, 0.03607432783714362, 0.07299417816102505, 0.06860054177897316, 0.02187868144496211, 0.004252972255926579, 0.034559661256415505, 0.06601453625730105, 0.039090188685804605, 0.019296842128304497, 0.0451798742370946, 0.03263966838962265, 0.0950897414503353, 0.06053031089582613, 0.060885591831590445, 0.053289748528706174, 0.13425241463950702, 0.05891807097941637, 0.018155766750818918, 0.06590752449951001, 0.05579926958307624, 0.05926546733826399, 0.0674784891307354, 0.016780729106228267, 0.018997382572186843, 0.07538588518010718, 0.0705689922241228, 0.03801286167332104, 0.04089682549238205, 0.02767670720017382, 0.04467883040862424, 0.039545339798288684, 0.01883295487745532, 0.048172105103731155, 0.033250780776143074, 0.05529607140592166, 0.03927827859297395, 0.009868095928270901, 0.0347601751397763, 0.08307414834520646, 0.04296761258904423, 0.030268032436392138, 0.014137942077858108, 0.013923132309823163, 0.022821823068495308, 0.08636441893343415, 0.015881235944107175, 0.07991547962384564, 0.019679576590923325, 0.03323984279164246, 0.052777593689305444, 0.041578223928809166, 0.09289155261857168, 0.03666406297790153, 0.02988722501322627, 0.0398880203387567, 0.02338634554429778, 0.06586041381316525, 0.022971611370199492, 0.03455161043841924, 0.09599931764283351, 0.06376684829592705, 0.06130990692015205, 0.03753170909892235, 0.007989545435910779, 0.004048724733625672, 0.01995088712179235, 0.07574789718325649, 0.04654452011787465, 0.1821744931595666, 0.842377775481769, 3.3030374688761572, 9.063748751367841, 14.173106585230146, 18.44184442928859, 24.387124402182444, 26.667229618344987, 24.990412167140416, 28.72908844266619, 23.507744755063737, 24.341389622007096, 23.627038376671926, 24.79025888442993, 23.778675862721034, 19.79912986074175, 17.772076300212316, 14.800833770206996, 13.615197505269732, 12.720342482839312, 12.600614598819188, 9.56944819859096, 8.481121454920087, 4.845839151314326, 2.421689961637769, 0.2574858548385756, 0.12769471295177937, 0.14359067140945367, 0.056087711426828585, 0.056725870219192336, 0.04538756023560252, 0.055522820845778496, 0.008561622550977128, 0.05428939006690468, 0.18986910741244042, 0.020977814249428253, 0.14414789793746813, 0.032267363010240455, 0.007743764785118401, 0.010314651698406254, 0.1191188038459846, 0.021047055355406234, 0.027857480803504586, 0.00859537797181734, 0.03448122939360993, 0.04492980354864683, 0.04564430092328361, 0.032276397704013755, 0.06312459454472576, 0.08358391813401665, 0.060814087811325274, 0.04011369090793388, 0.03876056994444557, 0.12109141371079854, 0.037687249681247134, 0.07452497351914644, 0.02154454535671643, 0.02047140320896038, 0.06497353461704083, 0.06123539698975427, 0.006487168820707926, 0.06513738725334406, 0.029934600328228304, 0.02170898831848587, 0.021422252990305424, 0.03510225178407771, 0.03276217449456453, 0.05146588032533016, 0.03449566861880677, 0.02340351078393204, 0.006501147066176469, 0.046200624999723265, 0.0821711742984397, 0.055084422762904844, 0.015321665077603288, 0.04166867943214519, 0.022165092772671154, 0.01985825691372156, 0.1006120258410062, 0.12487139659268515, 0.039598998347563405, 0.025021983044488088, 0.04409077464203749, 0.09091305306979588, 0.09450516996106931, 0.09352925339979784, 0.011615347350016236, 0.036144437467945476, 0.060617238017065186, 0.03538753504731825, 0.006433584486200873, 0.030337344788547074, 0.012397077366975802, 0.03330368615154709, 0.04378088430634566, 0.02253887226938137, 0.04096426169521042, 0.07710698246955872, 0.1603874529578856, 0.21959245604063782, 0.20877474865743093, 0.09161691780069045, 0.2120263156081949, 0.13609295444829123, 0.1746797346110855, 0.07432751304336957, 0.15682221283870085, 0.16350547064627918, 0.15573220061404364, 0.13242957102400915, 0.15821749796824797, 0.09851451124995947, 0.18487556464970112, 0.16470982959227903, 0.1971056019621236, 0.13194160935069832, 0.0766560145254646, 0.11929754354059696, 0.09781057188021285, 0.1919248920998403, 0.1829540484717914, 0.13364910201302596, 0.21060984661536558, 0.2035492147718157, 0.1630279448415552, 0.10846117644437722, 0.1205407554017646, 0.1384516643094165, 0.09748609643429518, 0.13719729733254227, 0.147108739774142, 0.15260670546974453, 0.14139438926109246, 0.14325455230261597, 0.14895020239055157, 0.1927408847425665, 0.12993841112724372, 0.15013328247836658, 0.10845020453312568, 0.15507468661027296, 0.15829542092978954, 0.1565714670079095, 0.16632747064743722, 0.14194753100829466, 0.15733578242361546, 0.1883509803031172, 0.2171326580324343, 0.22673619485327176, 0.16149957185345037, 0.10728069514568363, 0.1371915162141834, 0.1317296621522733, 0.2138545060796397, 0.16102721648556845, 0.28484026129756657, 0.22892183757254056, 0.09558362673435893, 0.05770832446536847, 0.08031638525426388, 0.13823902500527246, 0.1393550115504435, 0.32636986140693935, 0.15097599583012716, 0.18644885665604047, 0.1547503061592579, 0.06727660460663692, 0.21802373736032418, 0.17612031873847755, 0.11629893444478512, 0.12782432671104157, 0.20075804740190506, 0.13442202125276836, 0.07295056193002633, 0.1088526707940868, 0.13643577748111316, 0.19029110191123827, 0.17495359134461197, 0.34042802133730476, 1.5789997343506132, 4.871904015541077, 8.966218624796186, 14.04376413140978, 18.454491887773784, 20.63717120034354, 19.980446577072144, 22.090451206479752, 18.80185317993164, 18.561610528400966, 19.103538751602173, 19.79702455656869, 17.700766938073293, 15.190172604152135, 12.686611584254674, 10.039046542985098, 10.297716685703822, 9.014257601329259, 9.200810653822762, 6.240824639797211, 5.494918150561197, 2.9150161870888303, 1.1025545916387012, 0.14233102543013437, 0.12634911015629768, 0.13419315139097826, 0.18442722942147935, 0.15133689503584588, 0.19055126580808843, 0.14709520978587015, 0.10539406245308262, 0.21224567240902356, 0.21351565926202706, 0.0967475992760488, 0.2253611029258796, 0.20098127185234002, 0.1263207338218178, 0.07721533772668668, 0.14736855083278247, 0.12365265270428998, 0.11137282449219908, 0.13722561938422068, 0.10233721469662019, 0.18901146629026958, 0.10939739870705775, 0.09269817013825689, 0.19840514580053942, 0.24156036653688975, 0.16350537565137657, 0.10999689118138381, 0.17759610526263714, 0.20346510357090405, 0.2396650282399995, 0.17035748011299542, 0.11001357635749237, 0.16973630844482354, 0.18564270277108463, 0.14914646185934544, 0.1045034241729549, 0.165267693943211, 0.22100565449467727, 0.12073343220566, 0.09198775754443236, 0.12501544957714422, 0.21509575018925325, 0.1373969494764294, 0.145260858216456, 0.11638725256281239, 0.11918789228158337, 0.14314142694430693, 0.2447787124131407, 0.12949918183897222, 0.08709679570581232, 0.10969921108335257, 0.12540948843317373, 0.14222563537103788, 0.2188593532357897, 0.158965406407203, 0.09380764953259911, 0.22996102752430098, 0.13220835503722939, 0.14340513279395445, 0.2244352011808327, 0.1962880486888545, 0.09953683960650649, 0.18293553803648266, 0.08071610344839947, 0.09865819104015827, 0.11287009343504906, 0.11189579178712197, 0.09425457340798207, 0.08067637522305761, 0.13896842300891876, 0.1294788122177124, 0.22542162824954304, 0.3562285506299564], [0.02218941316407706, 0.022657922934740782, 0.015045043313875794, 0.0326521466486156, 0.01833622483536601, 0.005468236531929246, 0.07628343094672475, 0.06558174626635653, 0.019119344152776257, 0.0051079967774317735, 0.02539759119307356, 0.04248911987191864, 0.05222369198288236, 0.04744390132171767, 0.024718143544825058, 0.04233980145571487, 0.011733790726533957, 0.025590067829138467, 0.036056791099586656, 0.026297240418248942, 0.05751861285950456, 0.020589358040264676, 0.035773465409874916, 0.012509513164072164, 0.05851789816681828, 0.025535749404558113, 0.052621591703167984, 0.04654850311843412, 0.032460202662540336, 0.03487829451582261, 0.03350603207945824, 0.07420497640435185, 0.02548238432167896, 0.0549780149012804, 0.027440424343304973, 0.043325438031128476, 0.014065317626643394, 0.030130065911050354, 0.022109632712921927, 0.05205285722123725, 0.007935816488627876, 0.059259435161948204, 0.017924510142100707, 0.023200174194893668, 0.05690917306180511, 0.05037242792812841, 0.028717444211776768, 0.027020205909918462, 0.055243875099612136, 0.06090997838016067, 0.10338406530874115, 0.027464324042999318, 0.04972992651164532, 0.09484858331935746, 0.06257340019302708, 0.03171512032193797, 0.04812742357275315, 0.010528819402679801, 0.06196039808647973, 0.02862886485776731, 0.04112336119370801, 0.03042806831321546, 0.11425300208585602, 0.032166644664747376, 0.025976771721616387, 0.023732349210019623, 0.03134940012491175, 0.035549101020608626, 0.023357921712366597, 0.03277664425383721, 0.03985054824235184, 0.015538781016532863, 0.07018642060990844, 0.035671885324908156, 0.09468184690922499, 0.09853154926427773, 0.03533526070948158, 0.07436859833874873, 0.057579497806727886, 0.09882815727697951, 0.055550786666572094, 0.19050211273133755, 0.018637009231107574, 0.026497718678521257, 0.09701579702751977, 0.1328714873109545, 0.1381805217159646, 0.14630988692598684, 0.010935020998918583, 0.11954465242368834, 0.07045431980597121, 0.15879670903086662, 0.2500147228794438, 0.05806488783231803, 0.09724125385816608, 0.05022205778264573, 0.11512699590197631, 0.17429237253963947, 0.09816215480012552, 0.06248479709029198, 0.02273215296944337, 0.030199768420841013, 0.04283317105312433, 0.03446850686201027, 0.041441183603767834, 0.01878591543728752, 0.056153339333832264, 0.024569352689598287, 0.027944650501012802, 0.01852615866144853, 0.043978704405682426, 0.025090733908915093, 0.015165003216160195, 0.03498698564778481, 0.020054630037131052, 0.043731446244886944, 0.06562732346355915, 0.026894826209172606, 0.041497970199478526, 0.03702928784436413, 0.03639941057190299, 0.03246393121246781, 0.011819302254090351, 0.03780051753191011, 0.04297782793374998, 0.03274662247193711, 0.027992767115522708, 0.06506384762802295, 0.06526243447193078, 0.009396631137600966, 0.04793955418946488, 0.05005116195284894, 0.09480424784123898, 0.09116402960249356, 0.03535090772701161, 0.03660979035443493, 0.013171585226830627, 0.04681633785367012, 0.02876812399231962, 0.030851257033646107, 0.03386036306619644, 0.022637873921277266, 0.06087079976818391, 0.06890757887491158, 0.014816193808136242, 0.06841985468885728, 0.051643575076013803, 0.05913152452558279, 0.03765519229429109, 0.04778106876515916, 0.04022845492831298, 0.03213519456663302, 0.05719281427030053, 0.01912967993744782, 0.01261602874313082, 0.04158727219328284, 0.029300220975918428, 0.023600243530901413, 0.05269611520426614, 0.038569555551345856, 0.016853746259585023, 0.025325230522347347, 0.01972962703023638, 0.045676419378391335, 0.05250493796276195, 0.059399857984057496, 0.0054385985463990694, 0.008353483630344272, 0.030279665919286863, 0.023462838493287563, 0.02930395631119609, 0.04227935416357858, 0.014773552971226829, 0.023702447868085334, 0.04446767709617104, 0.017746028290795426, 0.03182883261303816, 0.0439393086624997, 0.031340585955019505, 0.03106700742085065, 0.007270727489542748, 0.018062966908993464, 0.01939852229718651, 0.03239191150558846, 0.03663829221789326, 0.0682355985045433, 0.05859512223729065, 0.05388468803305711, 0.0791957371735147, 0.020939929942999567, 0.03157837515962975, 0.022175292850338986, 0.041816070808895996, 0.031707446090877056, 0.053599791534777196, 0.04077990033796855, 0.045269976902220926, 0.04899610445967742, 0.026080507851604904, 0.03301071508654526, 0.04443027963861823, 0.039115783026708026, 0.05105760919728449, 0.06201800570956298, 0.0696884776864733, 0.03871726244688034, 0.07734066314463105, 0.02733699355407485, 0.035878485667386224, 0.09464908723852464, 0.03684368816071323, 0.014104207861237228, 0.03248194292453783, 0.08959610480815172, 0.010767181969380804, 0.037772612779268196, 0.028917700251830474, 0.05895734458629574, 0.02203653922437557, 0.04479643070538129, 0.01500303521087127, 0.01745019550435245, 0.007639780989848077, 0.017224275573555912, 0.08979447452085358, 0.015009091135912707, 0.037284590037805695, 0.023566796843494688, 0.039148030403469286, 0.0426676661840507, 0.052793681754597595, 0.025286699911313396, 0.010058245189221842, 0.029240822020385946, 0.020576516765036752, 0.012335901497863233, 0.03350794894088592, 0.02930297582809414, 0.02644781073156212, 0.011736348803554262, 0.07776336331984826, 0.03615231865218707, 0.03800036984362772, 0.023993617422612648, 0.03521837287449411, 0.011323232935475451, 0.013166630224856948, 0.03780334023758769, 0.020771101948672106, 0.031400992535054684, 0.04618091695010662, 0.029104575581316437, 0.03612678198676024, 0.03347786948350923, 0.06659061248813357, 0.11332990947578635, 0.137323436992509, 0.0784391841984221, 0.0655984314424651, 0.07171595389289515, 0.20957493143422262, 0.23185973135488375, 0.28163347765803337, 0.26358360477856224, 0.07518020085990429, 0.12995716583515915, 0.10600687456982476, 0.08984801093382494, 0.2730063662997314, 0.19142331901405538, 0.022896287197779332, 0.09889954594629151, 0.1476068387606314, 0.13333213116441453, 0.1648806304271732, 0.11545077924217496, 0.1802344936877489, 0.1463076477604253, 0.1242655733866351, 0.08341351763478347, 0.09673384537122079, 0.09476401071463313, 0.025958919465275745, 0.01066943645543818, 0.02680618069799883, 0.014256378669025642, 0.07488382354910884, 0.060679866799286435, 0.06913357174822263, 0.07627344291125025, 0.024211505195125937, 0.029863788413682153, 0.056953841022082737, 0.04984666846160378, 0.027630794128136973, 0.014401834524635757, 0.014793228790430086, 0.040659321272479634, 0.013266558077053299, 0.0315339718280094, 0.0370761915775282, 0.018264352709853222, 0.09671471746904509, 0.06574876766119685, 0.0066774491237343424, 0.03251874327127423, 0.010571178647556474, 0.01036147485553686, 0.08270958505038704, 0.05878046407763447, 0.03522236266040376, 0.026889927186337963, 0.00728071213234216, 0.039768825484705825, 0.01324003329500556, 0.02136541380813079, 0.029362693695085387, 0.06552365688341004, 0.008788712954680835, 0.01152733966175999, 0.041607367007860115, 0.05354938316824181, 0.04355714077662144, 0.07950455881655216, 0.03568119482536401, 0.03312792522566659, 0.024016567173280885, 0.06345538036631686, 0.036005534564277956, 0.018606444621192555, 0.03125320082264287, 0.04274236271157861, 0.04146453199375953, 0.016671719062807303, 0.10174252625022616, 0.01721509838742869, 0.06486161026571478, 0.020713250052982142, 0.02943792287260294, 0.04706666638542499, 0.016721474339387248, 0.05040935380384326, 0.02525860347252871, 0.026400462557960833, 0.029770092905632088, 0.062372791314763684, 0.029173847221370255, 0.002072461593862889, 0.030284052648182427, 0.0382597805666072, 0.04460004570760897, 0.047055433238191266, 0.11118074479912009, 0.12446015008858272, 0.13091466017067432, 0.0882341561040708, 0.09003504911171538, 0.061146977091474194, 0.10441618492560727, 0.11197020672261715, 0.08122561539390258, 0.1332700994930097, 0.10386553340192352, 0.10371993335762195, 0.11893597937055997, 0.12015578177358423, 0.12959557452372142, 0.09749679014618907, 0.1423042504382985, 0.10650304651686124, 0.16907641956848757, 0.09741047370646681, 0.15320035575756005, 0.19279590036187852, 0.12075676023960114, 0.14616092134799274, 0.16929140660379613, 0.0774922953652484, 0.1156813454415117, 0.15252970531582832, 0.24415899280990871, 0.08055332289742571, 0.14398985356092453, 0.11353700514882803, 0.09397343599370547, 0.1779050286859274, 0.07139265231255974, 0.11740430870226451, 0.13343011162110738, 0.1057414316705295, 0.0823736966454557, 0.08965593802609614, 0.08115690015256405, 0.10703350483839001, 0.10979225859045982, 0.18546522515160696, 0.094650919283075, 0.12106447587055819, 0.06766191750232663, 0.06247872420187507, 0.17126497998833656, 0.1831063660127776, 0.22358066774904728, 0.06893990428319999, 0.1714627593755722, 0.11883149854838848, 0.1269433032721281, 0.11713415676993982, 0.07961999119392463, 0.06661442906728812, 0.1484423189290932, 0.18017358838447503, 0.09979278301554066, 0.1415983840290989, 0.1452015813972269, 0.12252876801150185, 0.14565899542399816, 0.09266806353947946, 0.1076289668147053, 0.16506276279687881, 0.06574770914656775, 0.0848544342443347, 0.07558469594057117, 0.09402532356658153, 0.22864173831684248, 0.13050333224236965, 0.22809980596814836, 0.13631816022098064, 0.1326627835099186, 0.1920080262103251, 0.17584416855658802, 0.2213256787508726, 0.22062448066260132, 0.23046056500502995, 0.18742659847651208, 0.17628022230097226, 0.31584116922957556, 0.26836540390338215, 0.2544110598308699, 0.23327830380627088, 0.10356335461671863, 0.22483303983296665, 0.10936897487512656, 0.22242490548108304, 0.35123103165200775, 0.17121624760329723, 0.16814149330769265, 0.2692378642303603, 0.3631069143967969, 0.3694775439798832, 0.29861438646912575, 0.18896236749632017, 0.3220564414347921, 0.24370508002383368, 0.1718346101364919, 0.17267627854432377, 0.19497872037546976, 0.15402960697455065, 0.12074399021055017, 0.10031788769577231, 0.09014790984136717, 0.10561906466526644, 0.13452378793486527, 0.1685832603169339, 0.23200325508202824, 0.18484649620950222, 0.23170163269553865, 0.13395936893565313, 0.22174318134784698, 0.20077818632125854, 0.09821265816156353, 0.09930755583835499, 0.10514478225793157, 0.08759451471269131, 0.09793838752167565, 0.09851059610290186, 0.18781733965235098, 0.13656639547220298, 0.15498969331383705, 0.16492168179580144, 0.2109977515148265, 0.104104859488351, 0.12396001549703733, 0.08392729756555387, 0.17154948972165585, 0.19999010860919952, 0.11693949864378997, 0.19802156995449746, 0.066243691103799, 0.051965275313705206, 0.059700951113232543, 0.15976586059800216, 0.0820850342778223, 0.12431168662650244, 0.09720896916197878, 0.14677080219345434, 0.08906731568276882, 0.18451485543378762, 0.10306910970913512, 0.10846717469394207, 0.2141792665102652, 0.09822871908545494, 0.08882559436772551, 0.18693314066955022, 0.12747390408601078, 0.13943214741136345, 0.12007894446807248, 0.1411195554371391, 0.11678362557930605, 0.13573509507945605, 0.1640088079231126, 0.07735780972455229, 0.1420212063406195, 0.119962711419378, 0.13693669917328016, 0.21851252684635775, 0.12604836986533233, 0.16471960049654755, 0.09396656921931676, 0.08458205671714884, 0.10766947535531861, 0.09880814049392939, 0.13068944082728454, 0.15502262940364225, 0.08307758173240082, 0.16353808103927545, 0.1241416728922299, 0.1733976969761508], [0.007687979028560221, 0.027346891683659384, 0.040416965527193885, 0.020081723940425684, 0.028985390905290842, 0.06224629881658724, 0.008489343304453152, 0.031186385479356562, 0.033238037888492854, 0.014224287355318666, 0.04289525022198047, 0.0479027436647032, 0.03092911553436092, 0.06627740750887565, 0.07509747387043067, 0.06775030347385577, 0.08317030354269914, 0.03458107921427914, 0.051435923004256826, 0.028207723616755435, 0.037490722191120894, 0.011549981527163513, 0.05900869611650705, 0.01335346738674811, 0.050376889295876026, 0.03525545481326325, 0.0560254049487412, 0.05026406927832535, 0.039121391118637154, 0.009823502606845327, 0.04623166797682643, 0.07991036346980504, 0.03838070568495563, 0.04784441000914999, 0.04500789275126798, 0.038259030785411596, 0.03005745927137988, 0.045780696640057225, 0.01732167418647025, 0.07244102284312248, 0.039725999747003825, 0.007821165274695625, 0.037935929372906685, 0.07894275896251202, 0.03587646363303065, 0.06276097441358225, 0.008153822156600654, 0.0370710720308125, 0.02958252207775201, 0.01348003197927028, 0.030046656993882995, 0.025570178271404335, 0.008827524309578751, 0.03037698141166142, 0.04570220710177507, 0.059930628431694846, 0.026711153564974666, 0.0326589218207768, 0.02039086110224681, 0.042455495069069524, 0.007335147604213229, 0.040775659494102, 0.021406266705266068, 0.03372988078211035, 0.08028545762811388, 0.11342812741973571, 0.05315230447532875, 0.05498147203720041, 0.06667914773736681, 0.006617783419122654, 0.06195367380444493, 0.03644653482894812, 0.1018934188676732, 0.02555000372896237, 0.06966715811618737, 0.02290907588654331, 0.04420752677002123, 0.07159616532070295, 0.03853172043870602, 0.04628734177510653, 0.03655491044212665, 0.045405212324112654, 0.011055998703730958, 0.09771786364061491, 0.07581433933228254, 0.10533091119889702, 0.10771080492330448, 0.1265478123511587, 0.07613633812538215, 0.07828023058495351, 0.07795208426458494, 0.1071913999372295, 0.07309205005211489, 0.06528695672750473, 0.08664713054895401, 0.047889563121965954, 0.060837083363107274, 0.03565376165456005, 0.024350297836852924, 0.007939813059887715, 0.06018205279750483, 0.05616697110235691, 0.05433499101283295, 0.06583356418247734, 0.03902341405461941, 0.02791787720551448, 0.01893565115252776, 0.05228375929540821, 0.031702896513577015, 0.02175215502003474, 0.06149431238217013, 0.01884673422734652, 0.028759951038019996, 0.023923796169193726, 0.01335690331844879, 0.03737738648695605, 0.07374259550124407, 0.07472212865416493, 0.042725555399166684, 0.09335876469101224, 0.037829090641545396, 0.02233519810917122, 0.03379646881616541, 0.033055997121014764, 0.020178966490285735, 0.015602319035679102, 0.020171955527205552, 0.02339716817784522, 0.016879779951913015, 0.015938487336305634, 0.06423037592321634, 0.008255611739254423, 0.03780183388984629, 0.0485994634218514, 0.04123802682650941, 0.023871128281046237, 0.031046566553413868, 0.06507132508392845, 0.011977928474412432, 0.052094841575516124, 0.042289220062749724, 0.050649680729423247, 0.007921245797271175, 0.050488175824284554, 0.021970862123583044, 0.015253691135772636, 0.004448113838277225, 0.020632767318082706, 0.04048436441059623, 0.03900436079129577, 0.032054716920746226, 0.06901452956455094, 0.03883587036814008, 0.037103366905025074, 0.014191677810491195, 0.016538336041516492, 0.02096813664372478, 0.04837486154532858, 0.07754603533872537, 0.017459328585703458, 0.003966493498800057, 0.03095815683315907, 0.044324007483997514, 0.09201870552663292, 0.05993689130991697, 0.012258982768149247, 0.06226120623094695, 0.04626418676759515, 0.03827708999493292, 0.04605454998090863, 0.051110579033515284, 0.04594806408775704, 0.017206570898581828, 0.04516037314065865, 0.05307705154908555, 0.07574884034693241, 0.01734915146205042, 0.03483145185081022, 0.03475231770426035, 0.013742142423455204, 0.015472153966714228, 0.044149596842804124, 0.025459629649828588, 0.05591805392344083, 0.0029372718625901534, 0.009574589668773115, 0.015562100568786263, 0.02826221676410309, 0.01129943925687777, 0.01944576360152236, 0.06701949411737067, 0.022290301143324802, 0.01852590251447899, 0.03989117552659341, 0.02392358243066285, 0.017534813910190548, 0.014362311556137033, 0.0251463059269424, 0.045544247542108805, 0.04059742870075362, 0.029957748550389494, 0.08765567107392208, 0.026422733773610423, 0.048961268471820016, 0.011852938083133526, 0.03511348832398653, 0.026651415341932858, 0.02498554571398667, 0.03811631451493927, 0.030390056781470776, 0.04470882844179869, 0.015245039814284869, 0.013399386395966368, 0.04984472785145044, 0.04850540150489126, 0.036840468512049744, 0.038732685547854216, 0.03293041725243841, 0.04108799934121115, 0.04531021402882678, 0.07539543895316975, 0.05290344497188926, 0.009317994866121029, 0.041344434688133855, 0.009719803796282836, 0.013920942338050475, 0.07464379857161216, 0.009400920327087598, 0.01409171857605023, 0.05214087678385632, 0.022015357057430913, 0.04526488110423088, 0.01946314936503768, 0.05608347397563713, 0.01668383600190282, 0.04186159033062203, 0.046416151470371654, 0.021895239395754676, 0.079329428928239, 0.013004741947432714, 0.013626569250066365, 0.06511120258697442, 0.052600804782871685, 0.03480592197073357, 0.08772315138152667, 0.05218254901202662, 0.0357899911302541, 0.06401264760643244, 0.057214045631034036, 0.012469883326308003, 0.03427267147760306, 0.04897867628772344, 0.006880962131877563, 0.05381576923121299, 0.03542006401611226, 0.03690999460273555, 0.02811956325811999, 0.02264003505531166, 0.05215088178270629, 0.028009979852608273, 0.04434924220134105, 0.0875438620735492, 0.06167489090668304, 0.0644674017759306, 0.026979147755940045, 0.08187730078186307, 0.09421174427760498, 0.04893006603898747, 0.05726457613387278, 0.06058719927178962, 0.025442942777382474, 0.002647741394217259, 0.04694221627765468, 0.025786910838048373, 0.044650603351848464, 0.0478533429226705, 0.03761706201891814, 0.02137748833878764, 0.03780670916395528, 0.03674652873139296, 0.04840595541255815, 0.0225600680070264, 0.029032545696411814, 0.06629176530987024, 0.030357554954077517, 0.04742889891245535, 0.024175190000927875, 0.049677479147378883, 0.04209938632058246, 0.02259592349374933, 0.03254579985514283, 0.057261203814830096, 0.05661396622391684, 0.02945313902039613, 0.04843790423391121, 0.04285173577123454, 0.022097147668578794, 0.07267019804567099, 0.03199615256328668, 0.017114566639065742, 0.03662674015920077, 0.024570730115686144, 0.017031610644023334, 0.018769566136013185, 0.028663473536393473, 0.006385723170491734, 0.024315628090075085, 0.041387029723929505, 0.04304369332801018, 0.06591896459992443, 0.019700477165835242, 0.022019387555441687, 0.032088290833468945, 0.044782045762985945, 0.02392421686090529, 0.03495408009205546, 0.06286104475813252, 0.01357726180659873, 0.001847406371130741, 0.08934553539646523, 0.053246946539729834, 0.03004877402314118, 0.016646781204534427, 0.03301931891058173, 0.03293558768928051, 0.048165984717862945, 0.07089262628661734, 0.04291416438562529, 0.060053687542676926, 0.02065334389252322, 0.03659028247264879, 0.0033325920895939426, 0.02586638934112021, 0.0033640538500289297, 0.027354989999106953, 0.03691141274092453, 0.024941273000357405, 0.037243803297834735, 0.04959455877542496, 0.04297146327527506, 0.0324276906571218, 0.02681424169402037, 0.027846605583493198, 0.0667387977508562, 0.028800133881824355, 0.0658226397686771, 0.03795636684766837, 0.04734994118501033, 0.06252272719783442, 0.051905689761042595, 0.1157212568713086, 0.040330462490341494, 0.16454124078154564, 0.1370108766215188, 0.1289450087185417, 0.10276195726224355, 0.16802721443985189, 0.17300315600420746, 0.125828443095088, 0.06729483684258801, 0.12753566434340818, 0.06921012406902653, 0.15279107700501168, 0.14854552410542965, 0.1506884191185236, 0.12825143736388, 0.12209272783781801, 0.16027035138436727, 0.09630828856357507, 0.10333202845816102, 0.13498375325330667, 0.10163229823644672, 0.13262767610805376, 0.10905893186905555, 0.08663984986820392, 0.1950310625668083, 0.14548930738653454, 0.1816053922687258, 0.11318735605371849, 0.15886938013136387, 0.11159011176122086, 0.15882752809141362, 0.11230186106903212, 0.15570172082100595, 0.11375094045485769, 0.15518401217247757, 0.11539043033761637, 0.09583066097859826, 0.12091815657913685, 0.22452083230018616, 0.1106701675536377, 0.13637692135359558, 0.1242881143199546, 0.110546721677695, 0.10867145444665637, 0.10816593228706292, 0.15331308756555828, 0.16214118099638394, 0.058555136168641705, 0.17942850265119756, 0.10489896259137563, 0.13608340067522867, 0.12769731852625096, 0.10545725441936936, 0.10105616093746253, 0.13796761099781307, 0.21549531232033456, 0.11223946298871722, 0.09291410712259156, 0.13269213693482534, 0.07110786437988281, 0.13925829316888536, 0.09257196262478828, 0.15322455231632504, 0.1269041518015521, 0.11454067379236221, 0.11274253563689333, 0.16846584661730699, 0.1639124152383634, 0.12580671640379087, 0.22356504787291798, 0.09737529166574989, 0.11848127948386328, 0.13228573517075606, 0.17342901815261158, 0.08133151435426303, 0.16676788058664116, 0.10777599178254604, 0.10832188677574907, 0.18718775414994784, 0.16921239798622473, 0.11701704162572112, 0.16497965582779475, 0.09685986289488417, 0.11205921016101326, 0.1781302208879164, 0.17353214190474578, 0.19777474605611392, 0.17231740137296064, 0.25125166507703917, 0.15033226965793542, 0.13042690205786908, 0.18779137890253747, 0.16783029000673974, 0.20782264188996383, 0.15720486587711743, 0.15330603080136435, 0.16901919192501477, 0.11119329769696508, 0.10838769110185759, 0.1475015708378383, 0.044474248707826645, 0.12562462474618638, 0.2673731142921107, 0.17482635245791503, 0.159208281231778, 0.12114682288042136, 0.11251441894897393, 0.0836174241932375, 0.15378044891570294, 0.1569868932877268, 0.15269043669104576, 0.1409999704254525, 0.15134986862540245, 0.0960913405620626, 0.12441816234162875, 0.088365588337183, 0.10369423045111553, 0.18700680243117468, 0.1373238034014191, 0.12935339180486544, 0.19993016682565212, 0.08319601323455572, 0.10315645073673554, 0.20130502805113792, 0.1935578001929181, 0.1052607846047197, 0.1287747099995613, 0.14878705543066773, 0.1285832952708006, 0.10204714097614799, 0.07941474113613367, 0.10734807367303542, 0.2081986859972988, 0.06415376253426075, 0.25960125561271397, 0.0887328250599759, 0.1399359189506088, 0.08285416050681046, 0.18350556173494884, 0.07439812139741012, 0.15059140218155725, 0.22358152270317078, 0.12251424736210278, 0.08736700192093849, 0.13464207015931606, 0.1376218566937106, 0.13106254009263857, 0.12191681084888321, 0.15128847477691515, 0.18340573566300528, 0.16697958351245948, 0.08247648791543075, 0.09961223163242851, 0.15947072500629084, 0.09570589874471937, 0.11212483128266675, 0.1187555297677006, 0.12238080666533538, 0.1336777497615133, 0.15979191634271825, 0.08308368854756866, 0.05482606037652918, 0.15166960789688996, 0.18744782305189542, 0.13019203394651413, 0.09493945272905485, 0.1634439682321889, 0.15872660279273987, 0.19703934980290277, 0.10328558273613453, 0.21974229014345578, 0.14233608730137348, 0.2128492971616132, 0.17182880187673227, 0.1303136409925563, 0.1520845592021942, 0.18198074427034172], [0.048385670608175654, 0.0699050999911768, 0.005564129645270961, 0.03974376718646713, 0.024042578813220774, 0.047766056177871566, 0.1103248203705464, 0.011200743793909038, 0.045972898469439576, 0.04609506530687213, 0.025299922862489308, 0.03851925235773836, 0.04582968347572854, 0.12108010931738786, 0.00725105675935213, 0.053920216126633544, 0.03177714181531753, 0.03371253064168351, 0.05194174711193357, 0.02838158973359636, 0.035029665500457795, 0.06781300689492907, 0.015983587862657647, 0.013875869801267982, 0.031154748784112077, 0.04929233927811895, 0.030783003196120262, 0.00942542901196118, 0.03323301672935486, 0.011537426084812199, 0.03531415487772652, 0.015787419996091297, 0.0579967764871461, 0.047643014030264955, 0.028641092058803354, 0.013956915720232894, 0.016862803005746434, 0.0407766637259296, 0.030237620496856313, 0.07183258727725063, 0.054094684443303516, 0.09631432073989085, 0.04380832426249981, 0.04472146276384592, 0.012201592276271964, 0.020560291296403323, 0.01049378324699189, 0.01908945638154234, 0.042634116020053625, 0.027276033967999474, 0.004779596006431217, 0.03679889467145715, 0.02291799183668835, 0.14050805967833313, 0.035458967821406465, 0.014725616168496864, 0.03376896779185959, 0.08258025627583265, 0.020769139286130667, 0.0195401495189539, 0.02080884206640933, 0.024318727298772762, 0.06505902324404035, 0.04610283114016056, 0.05229219009301492, 0.04252790154090949, 0.010208986832627227, 0.029308638202824762, 0.019368595510189022, 0.014353809512353368, 0.053777045237698724, 0.028289688950670615, 0.01625826901623181, 0.02735135135506945, 0.02012649198461856, 0.033794684269066365, 0.05096981015854648, 0.030802154847021614, 0.039781544623630385, 0.010659067592184459, 0.011758551317533212, 0.03204046429267951, 0.05031021644494363, 0.03993461873116238, 0.04621387678863747, 0.02602700366904693, 0.09996422845870256, 0.08937933322574411, 0.0281255089212209, 0.01718412496016494, 0.060100248615656576, 0.048910754932356734, 0.04673608751701457, 0.04563783448455589, 0.05629766373229878, 0.07931671318198953, 0.03147744646828089, 0.03882062368627105, 0.03359351220673748, 0.05972450306372983, 0.05799934134951659, 0.019116173697901622, 0.05137722293979355, 0.03764560798715268, 0.045103986880608966, 0.014780501169817788, 0.03727357402177794, 0.025339701977957572, 0.004036179469299636, 0.033320245798677206, 0.003049184975679964, 0.014153313440536814, 0.0505308760330081, 0.014072598307393491, 0.03993695289162653, 0.027453545514228087, 0.02016266299012516, 0.006896709657407233, 0.01885904454892235, 0.03309287549927831, 0.029346961860678027, 0.044855378435126374, 0.03387687521587525, 0.022479846508109143, 0.021290876736332263, 0.026150032245953168, 0.042002223498587093, 0.01607741229236126, 0.05588328239641019, 0.01836241459074829, 0.10000208392739296, 0.01824999151618353, 0.05303704173171094, 0.06116189807653427, 0.045715628524443934, 0.09172423489923988, 0.03897479023518307, 0.021347751541595374, 0.04895508362512503, 0.04254506169153111, 0.03333550265857151, 0.049278826253222566, 0.026688056232939874, 0.018474135381568755, 0.053222013770469596, 0.02925488126597234, 0.03324716418449368, 0.02300720731727779, 0.01678515993990004, 0.03233600700540202, 0.03981485051502075, 0.026194605211328183, 0.015942180263144628, 0.032836392654904296, 0.06902251592172043, 0.02859619339661939, 0.022013121284544468, 0.09980886429548264, 0.004897452026073421, 0.018390751909464598, 0.02966864513499396, 0.030629410009299005, 0.004974023854759122, 0.028056934475898743, 0.02225851347403867, 0.05243411247751542, 0.011622926586174538, 0.01734666632754462, 0.02092512770156775, 0.03363708433295999, 0.0603635541296431, 0.08180785272270441, 0.038277174811810255, 0.04801697503509266, 0.05747127825660365, 0.02644447233927037, 0.07069002251539912, 0.0294883956999651, 0.02287071490926402, 0.051266804936208894, 0.025543354085779617, 0.020247710569362556, 0.07511652034840413, 0.033390379178204706, 0.042836404272488186, 0.06799393825765167, 0.06395164052290575, 0.05188662971236876, 0.01674858690239489, 0.11792230233550072, 0.01813290690604065, 0.01691715366074017, 0.05686609287347112, 0.01599898891124342, 0.025377900106832385, 0.07460694733474936, 0.028522382357290814, 0.045920043984161954, 0.06326984175081764, 0.002835610565463347, 0.013990380219183862, 0.05535807254325066, 0.05438419837238533, 0.03291468881070614, 0.08190924621054105, 0.07959945193891015, 0.004950564354658127, 0.03577314649841615, 0.0138731997659696, 0.03793080643351589, 0.03870025835931301, 0.036808682539101155, 0.012788603098929992, 0.026087886919932704, 0.05723932784582887, 0.03820594220555254, 0.041141868236341646, 0.01192462191517864, 0.02360497461631894, 0.013475956528314521, 0.013464286574162543, 0.03278607249792133, 0.04608028342149087, 0.024584290638033832, 0.038086448796093464, 0.079030520681824, 0.005855367477384529, 0.09627078593309436, 0.0036935943478186217, 0.10387805915836777, 0.024211491624425565, 0.060706316094313345, 0.018327578602890884, 0.05931655423981803, 0.04240639288244503, 0.040880503332508464, 0.033695068542978594, 0.02297140272068126, 0.025360197128195847, 0.04080644462789808, 0.011381871931787049, 0.019358576940638677, 0.010734936288957084, 0.018606451406542743, 0.016830097617847577, 0.03474580716075642, 0.028261068343584026, 0.020594950865155885, 0.02378895429761282, 0.020033609022253325, 0.023735509486868978, 0.0315312610806099, 0.034222059550562074, 0.026741026069170663, 0.0562376608805997, 0.03522171465946095, 0.028882277331181934, 0.01441204986934151, 0.016692940245515535, 0.07960158932421889, 0.10285006503441504, 0.02638682909309864, 0.08144501969218254, 0.030797900432454686, 0.03447426423164351, 0.016323696755404984, 0.06279207167348691, 0.042694034054875374, 0.02864236431196332, 0.024790125932278376, 0.028382697442014302, 0.02505633218346962, 0.05400615258674536, 0.0691226948318737, 0.06298704192574535, 0.04745333295847688, 0.042204325153891525, 0.09091793852193014, 0.00773128482978791, 0.08672905008175544, 0.05176103288041694, 0.010455538468834544, 0.050806859973818064, 0.08590188875262227, 0.014422485737928321, 0.08871045376041106, 0.018469500987391387, 0.052705139720014164, 0.04512524199006813, 0.06374848713832242, 0.01956130115182272, 0.027833099343947003, 0.023080616324607815, 0.030087745681937252, 0.025279582078967775, 0.05225356448707836, 0.0280897382513753, 0.047332136426120996, 0.07539376297167369, 0.013085043174214661, 0.027332903684249947, 0.06804037040897778, 0.04540145324010934, 0.029752067622861693, 0.0585541319368141, 0.00846634860083993, 0.08691011715148177, 0.03899458649435213, 0.04039465529578073, 0.02978870172851852, 0.048272670778845034, 0.032966013199516704, 0.038043945362525325, 0.06626434570976666, 0.018988200297046984, 0.06577878605042185, 0.03127231854679329, 0.0007827192468019867, 0.026292012305930257, 0.02582659326227648, 0.020534958191482083, 0.06255113067371504, 0.061498302168079784, 0.009877228161453136, 0.009733907994814217, 0.021863994554483464, 0.010362693674064108, 0.025755131650449972, 0.029991773688899617, 0.059895602454032214, 0.04595032360936914, 0.01693218321140323, 0.017474782220753174, 0.03184791641043765, 0.08039073233625718, 0.03521337207140667, 0.031707703934184144, 0.033939110447785685, 0.11397956604404108, 0.028697895617889504, 0.043971522112510035, 0.056337049297456226, 0.01752250189227717, 0.030309127909796577, 0.030230567125337462, 0.009391847465719496, 0.08025927974709443, 0.053194285436932526, 0.04617848440206476, 0.01853153944414641, 0.007903244263226432, 0.012998291623911687, 0.12338381712990147, 0.14382948859461717, 0.09652193209954671, 0.12239846214652061, 0.06621158961206675, 0.15608483526323522, 0.20535514929464885, 0.10031640848943166, 0.1509381742881877, 0.1964317216937031, 0.16070210321673326, 0.10239679685660771, 0.15133872708039625, 0.19761976865785463, 0.08309805313391344, 0.1829721246446882, 0.09428139589726925, 0.07688895559736661, 0.0798243795122419, 0.1642414504396064, 0.10804508520024163, 0.2004206119371312, 0.12943933505032743, 0.09069868350135428, 0.048615900932678154, 0.17414544256670134, 0.13904462249151298, 0.15082876730178083, 0.13835757864373072, 0.09985568321176938, 0.09577643924525805, 0.17819970287382603, 0.15533448409821304, 0.1576143889022725, 0.12842116611344473, 0.13141586684754916, 0.13445174108658517, 0.16179582024259226, 0.07614319132907049, 0.10131698301328079, 0.09753410957221474, 0.17754862138203212, 0.10018647581871067, 0.08971271105110645, 0.08543366566300392, 0.08298386926097528, 0.05837308522313833, 0.14821904019585677, 0.1933916133961507, 0.18355966811733587, 0.05810711306652852, 0.23147880179541452, 0.14215380565396377, 0.2583918890782765, 0.12051509320735931, 0.18737516552209854, 0.18762958901269094, 0.15556798156883034, 0.07262503475482975, 0.13370001928082534, 0.1101678887914334, 0.16082624798374517, 0.13842305727303028, 0.1450530636523451, 0.12123714946210384, 0.118681935859578, 0.2237476823585374, 0.14452289710087435, 0.09970008156129292, 0.2105395503874336, 0.19318892141538008, 0.10431597887405328, 0.13479437412960188, 0.10030417450304542, 0.12957772905273096, 0.2113978157618216, 0.1102583578654698, 0.16804018802940845, 0.18054678264473165, 0.13977634108492307, 0.09948808686541659, 0.11429455557039805, 0.1906834172883204, 0.1753186703260456, 0.15435767865606717, 0.2211607133171388, 0.24269826976316317, 0.23752623157841818, 0.14816017049763883, 0.17466890519218786, 0.12862199890826428, 0.18844949001712458, 0.17621706426143646, 0.2008623925170728, 0.1348181499966553, 0.13176824365343365, 0.19981548083680017, 0.15988464493836674, 0.16542359414909566, 0.15668651940567152, 0.20337784396750586, 0.18243809044361115, 0.11728564649820328, 0.19429781048425607, 0.27943689695426394, 0.14937416464090347, 0.17850125740681375, 0.175946301647595, 0.11780715494283608, 0.1729535415236439, 0.07724046387842723, 0.09268569866461412, 0.14570107816585473, 0.13667189409690245, 0.09148646944335528, 0.19913923926651478, 0.1264570922191654, 0.0803806357351797, 0.11614482557134968, 0.14112475301538194, 0.07597469751323972, 0.12891180121472903, 0.1772944014519453, 0.14519839228263923, 0.15021564305893012, 0.13174857970859322, 0.2562013880482742, 0.11136417317071132, 0.1493127979338169, 0.1548995974340609, 0.2149473274392741, 0.11821637941258294, 0.15718387200364045, 0.1599757857620716, 0.1117093710760985, 0.17847873004419462, 0.10081438533961773, 0.1654509933931487, 0.10336310536201511, 0.19589448480733804, 0.14186103136411735, 0.09905687786106553, 0.09598679188638926, 0.11889252598796572, 0.16690459182219847, 0.1646670683154038, 0.1107194224106414, 0.09512220256562744, 0.11867740324565343, 0.129072369741542, 0.14598524863166468, 0.1185518064137016, 0.14783045676137718, 0.13391759831990513, 0.13388801419309207, 0.10202600461031709, 0.12175428814121655, 0.18027095815965108, 0.13842474003987654, 0.0710988873615861, 0.10474487407399075, 0.10845436395278998, 0.22507458472890512, 0.07114112616649695, 0.0971055943518877, 0.13053275352077826, 0.12224535750491278, 0.1085245448297688, 0.116026692624603, 0.12527246507150785, 0.15471789932676724, 0.10060403948383671, 0.14630676566490106, 0.12748632127685205, 0.1306554190814495, 0.1172332228826625], [0.05623096373996564, 0.06676804261015994, 0.07729153720928089, 0.05276691015543682, 0.031550711286919456, 0.043459007649549415, 0.01918893470428884, 0.037993923760950565, 0.0012406438181642443, 0.03361339667545898, 0.029643926104264598, 0.024529963731765747, 0.0037669893603638877, 0.03645885702488678, 0.02324563604114311, 0.0319407705350646, 0.04062081780284643, 0.027848724309088926, 0.017854205432481, 0.04880084583003606, 0.036186713592282364, 0.036890941339411905, 0.10247693862766027, 0.022347113184098686, 0.07854570062564951, 0.04437797476670571, 0.05385166373369949, 0.035222471226006746, 0.04363236316878881, 0.06215156175728355, 0.06588682918144123, 0.04570979990863374, 0.04466939198651484, 0.03616585542580911, 0.061431500395493846, 0.05291491560637951, 0.01483199858505811, 0.03991558921656438, 0.013717091758735478, 0.04365660722500511, 0.02772999255518828, 0.011497406937581087, 0.01313783913584692, 0.035177233296313455, 0.13418718028281415, 0.05604133355830397, 0.045208169147372246, 0.017817352499280657, 0.015578225953504443, 0.07752519752830267, 0.05312258464151195, 0.04642422942976866, 0.026414174054350172, 0.032029248108821254, 0.053255947306752205, 0.026302319252863526, 0.04175674309954047, 0.053560640064201186, 0.08255435659417085, 0.05474692622997931, 0.006742432422470301, 0.036626580703471384, 0.044868888067347665, 0.04445532097348145, 0.028572515917143652, 0.022076667785378437, 0.009529716451652348, 0.046931841477219544, 0.05225356448707836, 0.025533215076263462, 0.02136718817720456, 0.0341234480563019, 0.03968873121110456, 0.034840347444904704, 0.00563603951429416, 0.008666083017098052, 0.03154923886592899, 0.04523578891530633, 0.07844283471682242, 0.03026926058477589, 0.08420302027038165, 0.015467758756130934, 0.009330086360153343, 0.014232370403728314, 0.010502478673255869, 0.03805788586448346, 0.06847474138651576, 0.032416369300335646, 0.0411903359927237, 0.028555528792951788, 0.023941349870126163, 0.010180518895919834, 0.053992839729679484, 0.04979175462254456, 0.03997822478413582, 0.07176536481295313, 0.05218971773449864, 0.04341490626601236, 0.04710705278973494, 0.028875003435782025, 0.054092326534113715, 0.04059105386425342, 0.04859415049265538, 0.005064984018515263, 0.04685210682717817, 0.06146709634257214, 0.02839329106999295, 0.06975796645773308, 0.036998621454196315, 0.08977278854165759, 0.03672907341803823, 0.042683218206678114, 0.05592573493985193, 0.07753116863646678, 0.041348193772137165, 0.04011631005310586, 0.020319075489948903, 0.03069695477773036, 0.01906043034978211, 0.013396820685427104, 0.00386757157476885, 0.07630104571580887, 0.04778530282367553, 0.027585763151624372, 0.04820008110255003, 0.0204548265984548, 0.007106635245561067, 0.031787214667669365, 0.03495336084493569, 0.04486732404412968, 0.037092683371156454, 0.03573688219434448, 0.006797542612600539, 0.019261341176128814, 0.009373954497277737, 0.027863019345594302, 0.016879323637112975, 0.025386252872911946, 0.028625065061662878, 0.023498663445934653, 0.04293947034914579, 0.028759730514138937, 0.011117045651189983, 0.011555331775785556, 0.040119607733296495, 0.047564833225416284, 0.04661522685949292, 0.014454359920429332, 0.030940830441457883, 0.014183008677459188, 0.02609898944917534, 0.018816128905330385, 0.01675873778627387, 0.03798515708850963, 0.050112772932542224, 0.023080706230497787, 0.06279357802122831, 0.02012323840920414, 0.035084294354809184, 0.021968105575069785, 0.05039299093186855, 0.08153792470693588, 0.031919454357453754, 0.040107173579079766, 0.02152423171459564, 0.04720520627285753, 0.0750050845422915, 0.03440487724063652, 0.056980982422828674, 0.028290426857503395, 0.06598583422601223, 0.03567642133150782, 0.01675331120246223, 0.023485425227720822, 0.029816854146442244, 0.028719442497406687, 0.003697517976563956, 0.04391358879261783, 0.018136643937655857, 0.028662713577172587, 0.016506877461714402, 0.07940847147256136, 0.06019708913351808, 0.026051315578765104, 0.03960278457296746, 0.03450000785025103, 0.0176010813364493, 0.016954647809533135, 0.035459215486688275, 0.011712293040805628, 0.035703230250094614, 0.04280831292271614, 0.043484150764665434, 0.006430765597282776, 0.013758694437066359, 0.027406953907172595, 0.019125220266037753, 0.04984214263302939, 0.036177173389920166, 0.023809787019022872, 0.08317807276866265, 0.021452554667900716, 0.03811785139675651, 0.043712644039520195, 0.046605137043765614, 0.028347834312756146, 0.06785743058259998, 0.0399387238680252, 0.049878250874046764, 0.04505748687578099, 0.03469913412949868, 0.025509885345984782, 0.020162014989182353, 0.05643725195633514, 0.021892579538481574, 0.022098109491967728, 0.022892862292272703, 0.02749745690795992, 0.07342307336096253, 0.025457512620570402, 0.03712990440960441, 0.016560600471815894, 0.03183019646842565, 0.023203904441158687, 0.012283257358441395, 0.07754486825849329, 0.034743496749017916, 0.05751817859709263, 0.03534785771210279, 0.023191862140915225, 0.04682535558406796, 0.09490163797246558, 0.029624547144132, 0.017710537516645024, 0.03501137898170522, 0.054165754201156754, 0.10996419936418533, 0.01133681635838002, 0.02602926827967167, 0.005034983440834496, 0.042643557834838114, 0.03839013732171484, 0.04052328517926591, 0.04887572556201901, 0.012997581706648427, 0.04958493036351033, 0.04226454852947167, 0.09828277797039066, 0.042626801412552595, 0.023204774662320102, 0.045228728758437295, 0.008743977140901344, 0.042018711899540255, 0.056232229207775423, 0.05580227549320885, 0.05396331327834299, 0.024998068077755824, 0.01799682840438826, 0.05925636139831372, 0.02588898964625384, 0.04118144039862922, 0.010213789164221712, 0.02368099259079567, 0.07732303480484656, 0.019240449082904627, 0.04510551358440092, 0.04231095014672194, 0.03204916311161859, 0.042920641002378294, 0.11372500684644495, 0.022294509756777967, 0.04739419184625149, 0.02407361500497375, 0.06816005720091717, 0.033132736038948805, 0.033750833943486214, 0.06635778676718473, 0.01918365909451885, 0.04503246589696833, 0.02603000618650445, 0.03876690406884466, 0.03240913611703685, 0.020396550618378178, 0.04388998934466924, 0.054103159345686436, 0.060591718315013816, 0.009038171265274286, 0.05717823255274977, 0.04139807288135801, 0.028273327775033455, 0.07067833135702781, 0.04360462465722646, 0.03820118906774691, 0.02268912367123578, 0.017100096879793063, 0.08138524075703961, 0.02270651961277638, 0.08037857977407319, 0.028735120049012557, 0.0647930239460298, 0.02498818521520921, 0.016691769772608365, 0.055768189286547046, 0.052262368478945324, 0.03369919403589197, 0.05722608284226485, 0.027785771526396275, 0.02365767303854227, 0.04497096009020295, 0.08885452031557049, 0.00828661909326911, 0.01812787726521492, 0.030177108743893247, 0.021199822425842285, 0.029574070924094746, 0.01576358645356127, 0.07618667863841568, 0.0891434337411608, 0.034240787117076774, 0.026190170984981314, 0.03444678017071315, 0.043781993711101155, 0.039363299030810595, 0.06034847708152873, 0.05833957916391747, 0.04886898770928383, 0.005734865171169596, 0.05585342346291457, 0.03830283361354044, 0.00845455566221582, 0.027351975607286607, 0.025272353984681622, 0.04596469498106411, 0.05430242811728801, 0.05847062463206904, 0.014960950772677149, 0.05193398467132023, 0.09533448224621159, 0.03394736482628754, 0.05664495152554341, 0.011275587054634733, 0.05355714221618005, 0.025977957461561476, 0.06955695045845849, 0.015960307326167822, 0.028210454720205495, 0.021115114114114215, 0.06097063941082784, 0.06536881519215447, 0.023252697894349694, 0.06841890473983117, 0.012834556034899183, 0.08887842510427747, 0.11844797698514802, 0.15071325350020612, 0.14183230219142778, 0.09768267481454782, 0.18636614323726722, 0.11677985292460237, 0.1450548278433936, 0.09861752643649067, 0.14928645720439299, 0.12465159195874419, 0.15186098191354955, 0.06375588317002569, 0.12436966065849576, 0.10903974968407835, 0.14292067236133985, 0.13467981027705328, 0.11007577087730169, 0.08189933281391859, 0.08377068489789963, 0.09964273178151675, 0.19076310444091046, 0.16566729678639344, 0.19807663985661098, 0.12762839293905667, 0.13641285656818322, 0.1873821137206895, 0.13136131263204984, 0.1397510181580271, 0.19011788549167769, 0.2475625244634492, 0.14868143466966494, 0.1879605512533869, 0.08197818536843572, 0.14719392306038312, 0.11986781151166984, 0.11467081680893898, 0.1849976195288556, 0.27017839519040926, 0.07814688488308873, 0.18398259899445943, 0.0900812302050846, 0.14266657456755638, 0.17318721541336604, 0.2306395625429494, 0.11578714262161936, 0.14492558049304144, 0.07055324342633996, 0.15721013130886213, 0.16079347474234446, 0.1283962774489607, 0.18439535184630326, 0.128396833847676, 0.13228258676826954, 0.14789319410920143, 0.19739323295652866, 0.14368160867265292, 0.08605122073952641, 0.10637442341872624, 0.12022070400416851, 0.25977924891880577, 0.11922727445406572, 0.12223090470901557, 0.09711833045418773, 0.09888578525611333, 0.09503569613609995, 0.12020961674196379, 0.09322487616113254, 0.148010485672525, 0.10172943730971643, 0.14039933122694492, 0.10995820111462049, 0.12160448117979936, 0.18359159997531346, 0.06621053788278784, 0.21460873846496853, 0.16626184274043354, 0.1351088886814458, 0.18886487558484077, 0.19064494435276302, 0.1779335814395121, 0.15993164027375834, 0.206291649756687, 0.13894970901310444, 0.11281132551708392, 0.2196198824260916, 0.14550736998873098, 0.1936393329607589, 0.09492181760392018, 0.1061805591785482, 0.16710796233798775, 0.11202826896416289, 0.13500497782868998, 0.16833920484142645, 0.10014190963868584, 0.15082153411848204, 0.15196857042610645, 0.18383748749537127, 0.1569286614124264, 0.17395788191684655, 0.16325696398104939, 0.09669466675924403, 0.14191017087016786, 0.07255523385746138, 0.10631822036313159, 0.13577301161629812, 0.12013929337263107, 0.17225984803267888, 0.12868317562554563, 0.21101922036281653, 0.13396326372666018, 0.12407175664390836, 0.24429556833846228, 0.2546339178723948, 0.1414974858718259, 0.1172913597630603, 0.1065571325431977, 0.10742687194475106, 0.07252298987337522, 0.15630355424114636, 0.08982502895274333, 0.20428993073957308, 0.20462298286812647, 0.17104301761303628, 0.08305963448115758, 0.0766184169000813, 0.13292553941054003, 0.16625896575195448, 0.21015900080757483, 0.14533693556274685, 0.10834364739379712, 0.10405361652374268, 0.13288733788899013, 0.1452869139611721, 0.15244224215192453, 0.18605385428028448, 0.09809593656765563, 0.1787751955645425, 0.11632994349513735, 0.0836365045979619, 0.08458169030823878, 0.16814515739679337, 0.09150054904499225, 0.11197161129010574, 0.1367356085351535, 0.12873863907796995, 0.16064020725233213, 0.19304569624364376, 0.1486935397343976, 0.11135947092303208, 0.09817934887749807, 0.10203175858727523, 0.10182050349456923, 0.14943530064608368, 0.12744484921651228, 0.09194056543388537, 0.17842340229877404, 0.1054410645738244, 0.14237551018595695, 0.054786735879523416, 0.09733348033790078, 0.13823024476213114, 0.10323700641414948, 0.10929564559566123, 0.059992232626037936, 0.17430411119546207, 0.1637570442897933, 0.14894885889121465, 0.10914368767823492, 0.059938614788864336, 0.07955004101885216, 0.2103254318769489, 0.136209852461304, 0.09135437224592481, 0.1442309506237507, 0.11746653036347457], [0.02165710413828492, 0.04250227666593023, 0.03486774668895772, 0.05084211326071194, 0.03692520396517856, 0.014027597016787954, 0.04061606127236571, 0.0246134998742491, 0.04506724081667406, 0.038722958748361895, 0.011065869691914745, 0.025463475247046778, 0.02455394315932478, 0.03123344188289983, 0.01875345771467047, 0.009360697619350893, 0.03946949315390416, 0.04169332721669759, 0.05110319996518748, 0.05092485721356102, 0.022043132888419286, 0.009466404893568583, 0.04381226994363325, 0.008115386540469314, 0.03252905361088259, 0.03132147162354418, 0.06607730074652604, 0.03573816801820483, 0.009578570972995033, 0.0677586223131844, 0.02412002340757421, 0.05470606145848121, 0.05377045326999255, 0.04346155554854444, 0.014435084436887076, 0.027783844486943314, 0.06413692808044807, 0.02927954262122512, 0.018464971766141907, 0.04817351306389485, 0.03812812102426376, 0.0343549336705889, 0.041209491036300144, 0.009287328475953212, 0.022077617734404545, 0.029442312994173596, 0.03003387339413166, 0.03495093508224402, 0.025071385482858335, 0.0407662210719926, 0.013372036345702196, 0.05315331209983144, 0.04119019350036979, 0.05964898890150445, 0.02973247492419822, 0.026092059910297394, 0.07101028425885098, 0.041840762698224614, 0.03066177273701344, 0.058652092037456374, 0.03863014194316097, 0.015291907924360462, 0.07563534857971327, 0.06180776163403477, 0.05497194540553859, 0.04290410510397383, 0.0232308304070362, 0.04682120294975383, 0.025037443464887992, 0.003965252627884703, 0.01607914425299636, 0.011852516543253191, 0.027597729116678238, 0.0049305187338697055, 0.04570803911026035, 0.025877094927376935, 0.011717472807504237, 0.010352032192583595, 0.017780267167836428, 0.01418989580789847, 0.011337212453197156, 0.04202244723481791, 0.0809680095740727, 0.13761766334729536, 0.02032513650400298, 0.007536198378407529, 0.042076370412749906, 0.06599515729716846, 0.026371816505811045, 0.03816835136551942, 0.06335315228040729, 0.0167990105359682, 0.0018405113951303065, 0.061095211654901505, 0.057833582029810975, 0.02322097129321524, 0.026674916402303746, 0.053258023623909266, 0.04422819494668927, 0.02097152592614293, 0.07114101081554379, 0.05838653378720794, 0.06550830842128821, 0.031180916487106254, 0.04992845907275166, 0.013691701826506426, 0.029576662927865982, 0.016115773269640546, 0.025257322737681012, 0.032649201806634665, 0.020415971986949444, 0.04901595160897289, 0.0050830724898592704, 0.021969617011823823, 0.06323246804199048, 0.02763773554137775, 0.017785172976021255, 0.02815471476476107, 0.03778305882588029, 0.02040504926948675, 0.03843755674149309, 0.044749628752470016, 0.049030777599130354, 0.03599915633510266, 0.06558692348854882, 0.04758224104131971, 0.0407900647925479, 0.021701946821329848, 0.06741195198680673, 0.021208142961508462, 0.03180267508806927, 0.038103656444166384, 0.054058644055788, 0.02296783701915826, 0.05248486689691033, 0.024953391635790467, 0.04641042124213917, 0.037827180565467904, 0.04677461812804852, 0.06426413982574429, 0.03461107385477849, 0.03168433518814189, 0.056352889697466574, 0.03953869354778102, 0.009200706695472556, 0.014345824851521423, 0.029149508170251335, 0.05831212563706296, 0.02714571283598031, 0.0071769149342019644, 0.07456829798008714, 0.027900359127670527, 0.01878868046748851, 0.06042144673743418, 0.02683353583727564, 0.04173505372766938, 0.030983025141592537, 0.03915579623675772, 0.02970399341679045, 0.004644026830127197, 0.03412551758810878, 0.050587435319487534, 0.06274281681648322, 0.011754067049228718, 0.06551963317074946, 0.020447919111964957, 0.039313796508525095, 0.04307913999738438, 0.04053198739088007, 0.05301645837192025, 0.053755813876965215, 0.02818669581652752, 0.03987676005012222, 0.037005471265209575, 0.04655733425170183, 0.04033344804442354, 0.015269165126872914, 0.03897084116137453, 0.04757681615384562, 0.02355104126036167, 0.06086859452937331, 0.04659961037603872, 0.0640356567289148, 0.024030041182413697, 0.03455057227984071, 0.06768350848662001, 0.03713524108752608, 0.056023101322352886, 0.029463015097592558, 0.0994345708084958, 0.043322852812707424, 0.045371835186545334, 0.06050640610711915, 0.014223326380098504, 0.08077507492687021, 0.09254249384892838, 0.019914822985551188, 0.011603771542598094, 0.06725326978734561, 0.03502853234697666, 0.05879769886710814, 0.05594340059906244, 0.051302238034882715, 0.018904901641820158, 0.03867255377450159, 0.030813964749021188, 0.03904112381860614, 0.06760589086583682, 0.04849066033161112, 0.03326005974252309, 0.05222163941445095, 0.025312343446005667, 0.04031902238992708, 0.008858813255626177, 0.05699805436389787, 0.09159308086548533, 0.030457998492888043, 0.03561576708619084, 0.014143052294717302, 0.04707036779395171, 0.05378203586276088, 0.01324258289033813, 0.05960366954760892, 0.01709390864042299, 0.03227193972894123, 0.022792919173038433, 0.0057331289696906295, 0.045509157103619406, 0.016227380405845385, 0.023024986631103923, 0.03535956583384957, 0.029927197511174848, 0.004664312058594078, 0.04951790128169315, 0.06274906612400498, 0.019316348313753093, 0.038286362175962756, 0.01769711439763861, 0.04326857679656573, 0.05837225741041558, 0.035177460605544705, 0.006831891327497682, 0.0307925230424319, 0.01634955911764077, 0.0648975929777537, 0.006428995469052876, 0.019497966693182076, 0.03596568080995764, 0.05491291285891618, 0.046293170390916724, 0.01465412402259452, 0.02497205643781594, 0.04207251972651907, 0.05647976217525346, 0.023008559298302447, 0.03256222040259412, 0.031452812254428864, 0.05476492437134896, 0.07170253925557647, 0.014297282456287315, 0.019823135941156318, 0.03229783262525286, 0.04423024072977049, 0.03450556165937867, 0.053736116005373855, 0.06671044177242688, 0.031505453001175604, 0.07772416435182095, 0.014753559936902352, 0.04913196074111121, 0.04756589852539556, 0.01796089149346309, 0.012686715976867293, 0.03163318043308599, 0.020242786101464714, 0.026265451052625264, 0.04018031626141497, 0.03501792345196009, 0.016404432244598866, 0.06405861156859569, 0.03635520062276295, 0.011197767569683492, 0.031904102502656836, 0.06545025975044284, 0.053770202212035656, 0.04067006926717503, 0.007469400846665459, 0.060812622175685, 0.051171487729464255, 0.025807037883039032, 0.016258581142340387, 0.041670131497085094, 0.024113037889557223, 0.03246517293155193, 0.04621688609144517, 0.07743212966514484, 0.015470683242061307, 0.040167776934270344, 0.028839967280094112, 0.015441691137052007, 0.05143303244507738, 0.03263839952913778, 0.04766846248613937, 0.0573233033397368, 0.023733899662537233, 0.016909453984616057, 0.036260008944996765, 0.02640063049537795, 0.035607434676161835, 0.04449222310047064, 0.03981461302776422, 0.019037870756749595, 0.020617476531437466, 0.0380326138277139, 0.020636232935690453, 0.05601900297084025, 0.013635776122100651, 0.0035829274066989975, 0.031239989745829786, 0.039841337129473686, 0.02514911675825715, 0.012341515526973774, 0.0802890674344131, 0.036903494237256904, 0.030438046170664684, 0.050952931599957604, 0.03667882450723222, 0.05311288159074528, 0.030081499767090594, 0.013030893535220196, 0.0027071416220029016, 0.01342672117919262, 0.025910450012556145, 0.009864438624520386, 0.017165119194292595, 0.045718213742864985, 0.006923966409106339, 0.03261913252728326, 0.03868960875219532, 0.027731327572837472, 0.009538973365644259, 0.04065692265118871, 0.05928536877036095, 0.04487123919118728, 0.024629040022513697, 0.02658723101818136, 0.029082662292889187, 0.07485647858785731, 0.05743657797574997, 0.01644946831012411, 0.015573035160611783, 0.019989108999392817, 0.06491452242646899, 0.11121676822326013, 0.1225730220654181, 0.12237297637122017, 0.1930143886378833, 0.10385642067662307, 0.11136656161397696, 0.09717598557472229, 0.16791037070964063, 0.148640831134149, 0.18546743717576775, 0.08776701188513211, 0.14753928381417478, 0.11134558131120034, 0.18607051910034247, 0.22240001681659902, 0.17732151571129048, 0.16307332526360238, 0.12101169941680771, 0.23279798243727, 0.08384121861308813, 0.04044812724792531, 0.14219519629010133, 0.19571860853050435, 0.18505306941057953, 0.12820077793938772, 0.17012703604996204, 0.09872066375932523, 0.07667638414672442, 0.166712349280715, 0.10104535187461547, 0.17592046303408487, 0.13800636891807827, 0.12833434077245848, 0.10485705626862389, 0.13574895076453686, 0.18178985879889556, 0.10854313668927976, 0.19910099703286374, 0.18233712443283626, 0.1048365237989596, 0.15441862467144216, 0.12757067675037043, 0.1295992521835225, 0.08258388643818242, 0.07923353835940361, 0.12698267187391007, 0.07445338807467904, 0.10493020234363419, 0.14671251603535243, 0.0786276405145015, 0.12766020266073091, 0.08210207229214055, 0.10849660275770084, 0.0842230234827314, 0.08901827117162091, 0.10141098725476436, 0.08155755472502538, 0.17223536648920604, 0.12650240478771074, 0.15059867607695715, 0.07393918066684689, 0.20788383217794554, 0.1622662485710212, 0.11024963869048016, 0.10004484520426818, 0.11446353793144226, 0.055649092820073874, 0.15924139374068805, 0.06490644785974707, 0.11968600483877317, 0.08188289869576693, 0.15915532835892268, 0.11795997459973608, 0.09860021700816494, 0.08873621773506914, 0.11004818842879363, 0.1333250201174191, 0.15108678702797207, 0.11897252526666437, 0.14319889886038645, 0.14643832003431662, 0.18826372069971903, 0.1563628717724766, 0.15377580773617539, 0.17623979518456118, 0.12390999389546258, 0.10121014088924442, 0.13959266165537493, 0.1714271227163928, 0.2108227437628167, 0.12899819229330334, 0.11540307823036398, 0.14706067235342093, 0.18496826610394887, 0.09954337389873606, 0.12015883518116814, 0.10064141319266387, 0.13165680106197084, 0.09624662330108029, 0.2922910643475396, 0.08631296562297003, 0.0970337035666619, 0.19914280836071285, 0.10390372813812324, 0.1427957404937063, 0.08773790951818228, 0.16586111352912017, 0.11405550768332821, 0.1224663427897862, 0.10491476567195994, 0.18239089154771396, 0.1533943217779909, 0.07474786548742227, 0.14795989410153457, 0.18614979913192137, 0.11612457808639322, 0.1037230139066066, 0.09681390571807112, 0.2516842175807272, 0.17458469899637358, 0.1590233261563948, 0.10483092588505574, 0.10194017671580825, 0.16084634619099752, 0.1097052161182676, 0.12360488383897714, 0.19083766186875956, 0.28913384090576855, 0.10819017634327922, 0.10181327031127044, 0.15004404155271395, 0.17112465894648007, 0.14739277453294822, 0.20769483303385122, 0.07930617553314992, 0.08443567635757582, 0.1165746096521616, 0.15161352019224847, 0.147489370778203, 0.1216806128088917, 0.08928900664406163, 0.1511118249701602, 0.15245358725743635, 0.057669403696698804, 0.0650037294253707, 0.12996720815343515, 0.14153123620365346, 0.12862825500113623, 0.08748305176517793, 0.1872844046780041, 0.14647668440427097, 0.1126232220392142, 0.09754293052745716, 0.17053357352103504, 0.1683881679283721, 0.08545198610850743, 0.13986977535699094, 0.15400185489228793, 0.09164004905947618, 0.07989947976810591, 0.1778365916439465, 0.20715644263795444, 0.11798157915472984, 0.1316342736993517, 0.2094086225011519, 0.10753340872802905, 0.11037651795361723, 0.1427874487957784, 0.10891290434769221, 0.2131490603621517, 0.11747043872518198, 0.12390314069177423, 0.12061527211751256, 0.15863780970019953, 0.12305874457316739], [0.021927793809611882, 0.04654430977201887, 0.025955791418839778, 0.04357688953833921, 0.020169076842388937, 0.03055859130940267, 0.08039208940629448, 0.014582226452018534, 0.03657462527709348, 0.029338039125182798, 0.046098651364445686, 0.0042612860062425685, 0.011404768247822565, 0.03308555071375199, 0.02614966922971819, 0.0825402702071837, 0.05711160719926868, 0.033220752208892784, 0.07440145978970186, 0.05051370231168611, 0.023479886685631106, 0.04313326334314687, 0.05275949716035809, 0.09098159189202956, 0.03990853923772063, 0.04486999407942806, 0.017490727793691412, 0.022475307108834386, 0.0401085611831929, 0.0819449642939227, 0.017322525747918656, 0.023886760031538348, 0.01946379566964294, 0.0047775934799574316, 0.030190947465598583, 0.026366374654961482, 0.022639441337170343, 0.00396399140091879, 0.02065046351136906, 0.07572100684046745, 0.019261151186323593, 0.031143675092607737, 0.027695672253945043, 0.019444942574149797, 0.015310632098200066, 0.06607660864080701, 0.016446160451908196, 0.006776661545570407, 0.014563456477065171, 0.07896890970213072, 0.043996756829853566, 0.003969967598095536, 0.03352599797238197, 0.010293621353672018, 0.01395404466893524, 0.025816997080775242, 0.0038634800086063997, 0.01093873767448323, 0.03313482253413115, 0.03254296697143998, 0.018826507098440613, 0.056386059881853204, 0.03650104154699615, 0.019310302566736937, 0.048156128996717076, 0.023950315014060055, 0.01971205127691584, 0.04918213501306517, 0.05554859160578676, 0.038367158733308315, 0.031078807144824947, 0.049957235742892535, 0.044935968039291244, 0.03349719076816525, 0.020951402273827364, 0.024092990572431257, 0.03535911460806217, 0.02551927966331797, 0.03801782176430736, 0.048725514872265716, 0.06551169431103127, 0.015914484160020947, 0.05916476595614638, 0.02692469532069351, 0.041548700870147774, 0.060753386068556986, 0.021868762959327017, 0.08932232271347727, 0.058794855805380006, 0.0640663332971079, 0.001895366286459778, 0.04041937093383499, 0.01429765734688512, 0.06893037765153817, 0.04817579294155751, 0.036177733181310553, 0.01362325799917536, 0.019985919884805168, 0.03491893197808947, 0.05044751461329205, 0.030623489791261296, 0.02553204629969384, 0.044419623246150355, 0.004534544780783887, 0.048724480106362274, 0.01823244120792619, 0.015444629193682755, 0.03892421562756811, 0.028254668062020625, 0.06005620490759611, 0.08429725521377154, 0.041069726393158944, 0.04578363469668797, 0.018308862910739014, 0.02724930308093982, 0.03259974338912538, 0.011452157133524972, 0.0306774570739695, 0.0571563769397991, 0.010165832005441189, 0.06637983236994062, 0.06754843252045767, 0.053627238276281526, 0.04140164876090629, 0.03234721640391009, 0.018605158797332218, 0.03873004265395658, 0.04695062332653573, 0.018507466718022312, 0.04723527215953384, 0.05669433191152556, 0.026967605875272836, 0.03825432853773236, 0.033955195120402744, 0.02402867393435112, 0.05165041131632669, 0.050424848150994094, 0.0346567053347826, 0.029957212507724762, 0.028826342296919653, 0.01928995669420276, 0.01963149899217699, 0.05777841713279486, 0.03009721463812249, 0.03184166031756571, 0.013886552486967827, 0.07707839578922306, 0.02650693996942469, 0.03354752449584859, 0.0046168510785459405, 0.020818282184856277, 0.0866970367995756, 0.00521261669928208, 0.04559805536908763, 0.013914468265803797, 0.02251868924525167, 0.05712280302707638, 0.035958929386522086, 0.08270786835678987, 0.023819474802751626, 0.05200949544087052, 0.030596738548151085, 0.026869683094056587, 0.006759840238373727, 0.0695365129836968, 0.056083060069275756, 0.01724595476740173, 0.05557871516793966, 0.052230694464274814, 0.004993287888022938, 0.02458881137759558, 0.045393161542181454, 0.028223533482689942, 0.05094794436757054, 0.025182093560163463, 0.025768654853371636, 0.01438957848586142, 0.04099940980917641, 0.018285536573135426, 0.06660421032990728, 0.03094709331968001, 0.02428758593409189, 0.05103257804044655, 0.016869121863107597, 0.027794036082923412, 0.07774556534630911, 0.07684255737279143, 0.038231092106018744, 0.06167085362332208, 0.02395550750329026, 0.017170467746577094, 0.05056758817019207, 0.08329253484095846, 0.02119340857357851, 0.05953811627945729, 0.019886322818430405, 0.010454432456754148, 0.029948951343872716, 0.03263644195560898, 0.030680099967867136, 0.022961638601762906, 0.049634046120835204, 0.0780916724886213, 0.021188516336094056, 0.018480060688619102, 0.007972412426689906, 0.015026822952287537, 0.07615229048367057, 0.039302291947283914, 0.013175441002074097, 0.04300922035638775, 0.03275334336129682, 0.048273162716733556, 0.012584076529102666, 0.017253528914547393, 0.052565955224313905, 0.03271882289222308, 0.025188402239499346, 0.05862565631312983, 0.012864878068545034, 0.0010666894917708955, 0.01854469284548291, 0.011806898633949459, 0.019160020630806684, 0.030427589946027313, 0.012251910736917384, 0.02974151640332171, 0.0248785729719592, 0.018984425946005752, 0.021215591579675674, 0.02667509451774614, 0.020743617887741754, 0.004938930447679013, 0.04808098802875195, 0.0215023625309446, 0.07706584289137806, 0.018784264900854657, 0.02372596928450678, 0.020554237067699432, 0.026229922959048833, 0.017702719096892645, 0.04733584461999791, 0.04338870802894235, 0.032733065342264514, 0.022875099941822033, 0.014869049989751406, 0.0359881403190749, 0.0055404589511454105, 0.1483458855322429, 0.03441084156345044, 0.030506920867732594, 0.06242269078003509, 0.08728091618312256, 0.03145499035183873, 0.016117836016097238, 0.017385833065158555, 0.03944366471841931, 0.04728254908695817, 0.013450944879358369, 0.012464037747122347, 0.03343022953984993, 0.05487145436927676, 0.01145980422318514, 0.030670505482703447, 0.03928744560107589, 0.05439200831044998, 0.05401317203151328, 0.03227442655978458, 0.022912083493013467, 0.027526292949914932, 0.04665084994797196, 0.03021574792053018, 0.04681126580440572, 0.025520565487178307, 0.024687088693359067, 0.043533839884081056, 0.027174457275707806, 0.012550777423062494, 0.09704302663781814, 0.05922666870589767, 0.09325473170195307, 0.045094765589705536, 0.053766215818801096, 0.03168345309261765, 0.03802479710429907, 0.030320561224860803, 0.03354207585964884, 0.01614191722390907, 0.03888441615604928, 0.02173997531645, 0.037915349405791075, 0.027375342656991312, 0.008631760171348495, 0.04719564910711987, 0.045326380125646076, 0.013721039984375238, 0.08195135609379836, 0.037124767899513245, 0.05625097034499049, 0.02075231501034328, 0.021487277001142502, 0.05148580211347767, 0.03652679195095386, 0.050259679156754694, 0.047542984397815805, 0.01903479529677757, 0.05017899116501212, 0.038335430435836315, 0.06823918116944176, 0.041123398513134034, 0.07952258070664746, 0.03730718186125159, 0.053111446489180834, 0.04244446548234139, 0.012070994641232704, 0.06369780735777957, 0.014786307733239872, 0.0236051951402, 0.04576700719605599, 0.007106069092904883, 0.02591312683320471, 0.028998296641345536, 0.04881225539637463, 0.017320086414526616, 0.04596657452306577, 0.028601421508938074, 0.056595628815037866, 0.06687811456088509, 0.016932926207248653, 0.055264838439013274, 0.03078878770715424, 0.05698275339922734, 0.03788058466411062, 0.033211866792823584, 0.0226599212203707, 0.04163605207577348, 0.053769449038164954, 0.005017573080424751, 0.01780476906735982, 0.048401273520929475, 0.0439867009408772, 0.03571311650531633, 0.03843140582154904, 0.0005347558866820431, 0.03286770026066473, 0.05666367909205811, 0.09046673309057951, 0.06024941096880606, 0.028644342241542678, 0.04232311288693121, 0.03640662679182632, 0.06872852705419064, 0.0849802414221423, 0.17156627667801722, 0.07149501610547304, 0.1390356251171657, 0.12468298098870687, 0.16465904803148337, 0.221266239083239, 0.08680646414203302, 0.17184391963694776, 0.09471227241946117, 0.148707707545587, 0.13549322448670864, 0.10066130783941064, 0.15699219943157264, 0.09626174106129579, 0.17817877685385092, 0.14096098180328095, 0.08337079028465919, 0.18101042562297412, 0.12176825239190034, 0.08552190235682897, 0.15981860991035188, 0.17844288982450962, 0.1008241358878357, 0.07082847080060414, 0.10185260498630148, 0.14290304402155535, 0.1299531760492495, 0.15660327672958374, 0.13125784961240633, 0.08569696439164025, 0.2150819759283747, 0.1025237168318459, 0.11338847383324589, 0.1322279239871672, 0.13372501651091234, 0.1482328280274357, 0.07440247080687966, 0.0844481410458684, 0.177594571773495, 0.2054233963468245, 0.11574476132435457, 0.1584529903318201, 0.09208643010684422, 0.1902989593467542, 0.1589130370744637, 0.0750398323205965, 0.09561674602861915, 0.06912812311202288, 0.1453010139188596, 0.1376682413475854, 0.0801268025700535, 0.16501344687172345, 0.05187535585303392, 0.13520863332918712, 0.1016427001782826, 0.12385653890669346, 0.12080454267561436, 0.12043801162924085, 0.14396956536386693, 0.09250981560243027, 0.12318484352103301, 0.1696678035493408, 0.14624993157173904, 0.1291538482265813, 0.17923601583710738, 0.22295599484017917, 0.09513485724372522, 0.144321562190141, 0.1222727567489658, 0.2359697808112417, 0.12455891764589719, 0.27068327952708515, 0.10192462469318084, 0.0953849313248481, 0.1514308178531272, 0.12505981219666346, 0.11140026444835321, 0.1175842426185097, 0.14470952137240342, 0.11532833081270967, 0.17473582231572696, 0.17396792423512253, 0.0776852300124509, 0.1827241200953722, 0.24473384767770767, 0.1876023526170424, 0.18915374151297978, 0.15148614559854778, 0.12940049570585999, 0.18679298247609818, 0.20065784135035106, 0.13473063254995005, 0.17656216717192105, 0.13035362027585506, 0.07909325802964823, 0.19644227969859326, 0.10478353699935333, 0.08347011424068894, 0.1620578704667943, 0.09276504654969488, 0.20625875437898294, 0.10340379710708346, 0.11492833441921643, 0.16406957751938275, 0.1371397032801594, 0.16795465190495762, 0.12273439126355307, 0.06399041201387133, 0.09238714325640883, 0.16678917301552637, 0.09664420410990715, 0.12402477487921715, 0.11175111455044576, 0.13760801457933017, 0.10696656057345015, 0.06313348335347005, 0.0985443600054298, 0.14369576291314193, 0.07163680956832, 0.2903856023081711, 0.11394193449190684, 0.10585065545248133, 0.0832894000091723, 0.15020659140178136, 0.05974803465817656, 0.11273333470204047, 0.09313159795211894, 0.10332693944552115, 0.1827294398099184, 0.1948397292622498, 0.1599638435457434, 0.18182605185679027, 0.1443917362817696, 0.14477635707174027, 0.12821277443851742, 0.15732263241495403, 0.13772164205355303, 0.08074474441153662, 0.09176068580044167, 0.10514565078275544, 0.062325456711862764, 0.11220160752002682, 0.14607519523373672, 0.12616216018795967, 0.13873598405293056, 0.21597325881677015, 0.1432785453008754, 0.1710159440657922, 0.0975792592923556, 0.1525786141199725, 0.11280402448028326, 0.07135424723050424, 0.16791871669037, 0.07091150313083615, 0.12200046064598219, 0.1175847447344235, 0.12393983586558274, 0.10462271741458348, 0.08084724391145365, 0.09648240743471043, 0.14316114517194883, 0.10298630129545927, 0.0974128892911332, 0.1572496627590486, 0.08967893357787814, 0.08327158846493278, 0.14839205305491174, 0.12473122482853276, 0.09579925159258501, 0.24806966153638704, 0.10690448818994419, 0.14000816935939447, 0.13629760060991558, 0.07969614996441773, 0.08566407579928637], [0.006193381817346173, 0.030599096457340887, 0.013170827812116061, 0.01512937673500606, 0.060903186244624, 0.04018827208450862, 0.059185183074857504, 0.020568152124594365, 0.037960173429122994, 0.006376916210034064, 0.022909505059942603, 0.0325637878184872, 0.09391375205346517, 0.07358946371823549, 0.007827572341609215, 0.025177209804366742, 0.04265558826071875, 0.02125656322043921, 0.029189219432217733, 0.04705657656969769, 0.08176811092666217, 0.044291139247694185, 0.0204340430708336, 0.08824618652995143, 0.02381398036543812, 0.02981740715248244, 0.04152095218056014, 0.05011468640129481, 0.04441666144079395, 0.037404443070824654, 0.03436229916821633, 0.0053811864262180665, 0.04089035226830414, 0.024209864836718355, 0.06129987138722624, 0.04255100226561938, 0.038857166189700365, 0.03561842694346394, 0.029340597202203104, 0.09102935397199222, 0.027358838989000236, 0.02293232419261975, 0.07766245837722506, 0.01850518344768456, 0.10415518643068415, 0.025808747791286026, 0.009155540011956223, 0.03265487775206566, 0.021544533482353603, 0.04376542049327067, 0.013897612607771797, 0.05846899614802428, 0.048795868775674274, 0.0465214058224644, 0.05920554591076715, 0.055566650815308094, 0.03601442337302225, 0.07618965740714755, 0.058284509261803966, 0.005827154415393514, 0.009553880780003965, 0.05290083261206746, 0.03320142753156168, 0.046123451819377284, 0.029826733616313765, 0.005206968743420605, 0.04288405778684786, 0.08125296714050428, 0.011485579224037272, 0.12202811773334231, 0.11319336108863354, 0.03906848913590823, 0.05549277192247765, 0.06072356445448739, 0.05414392233693174, 0.007937143024589335, 0.017767225724778006, 0.0417233456059226, 0.016196249219189798, 0.051348395379526277, 0.0377171357561435, 0.046790421208632846, 0.021687176810311418, 0.008029087912291288, 0.034166389144957066, 0.022671805761222328, 0.06102648962821279, 0.03162008470722607, 0.052295704904411516, 0.06478139385581017, 0.020189811176221286, 0.042765477006988864, 0.042246292544794936, 0.030299635204885687, 0.03916391490825585, 0.00911917392763176, 0.07323912930275712, 0.008329181050482606, 0.0519619640628142, 0.05559951565893633, 0.04685572681150266, 0.03644211756597672, 0.011808140353033585, 0.016360800746562223, 0.03134173607187612, 0.03318591961371047, 0.056497149635106325, 0.0026898640000061797, 0.08387639386845486, 0.045750834313886504, 0.012311683734878898, 0.02290705724486283, 0.022685593592801263, 0.10082505869546107, 0.030719047877937555, 0.03405503476304667, 0.05799941598836865, 0.009544001310132444, 0.03547380738226431, 0.057487474887498786, 0.02844863068977637, 0.0265134606909539, 0.026654204120859504, 0.0306024043155568, 0.05246108763718179, 0.05355498447482075, 0.03215360661436405, 0.02606960549019277, 0.018151057717789496, 0.04570708576855915, 0.028503420696194683, 0.02471826228845332, 0.0241903382952192, 0.016017687640019825, 0.05352985153773001, 0.021267329874847616, 0.026954308285244873, 0.05627874956865396, 0.05659802743632879, 0.02185897169900792, 0.0416576769868178, 0.07739462024931397, 0.032528181693383625, 0.024664557938064848, 0.07089919450559787, 0.018727644546223537, 0.0758160153137786, 0.027921495493501425, 0.050660194629537206, 0.026011804484629204, 0.02804451049970729, 0.05393457392762814, 0.03580347362107464, 0.04088523950693863, 0.026968645730188916, 0.05581829231232405, 0.022732702582808476, 0.027077586223770465, 0.038429882510432174, 0.03805996557431562, 0.027466514014772007, 0.06926121775593076, 0.026162854861468077, 0.08854208208088364, 0.0719526879755514, 0.04592598455825022, 0.03277082920872739, 0.03212485708562391, 0.037147631136966605, 0.07244961309645857, 0.023811432466443096, 0.029494665363537412, 0.01906953120071973, 0.005192160988891763, 0.07172235926347119, 0.012173885146954229, 0.046815632177250724, 0.013204620552382298, 0.031060625799000263, 0.04938444022887519, 0.04524196358397603, 0.035678802989423275, 0.009130284090393355, 0.0682023163618786, 0.049240628124347756, 0.017983210206563984, 0.027975678211078048, 0.02140092833100685, 0.06973414987857852, 0.034283684100955725, 0.021734684439642087, 0.04835449531674385, 0.05348776201052325, 0.04944474842133267, 0.015866445577038184, 0.03866754618606397, 0.10198886160339628, 0.029402540664055517, 0.03738857552941356, 0.08797828054853848, 0.03844504437542387, 0.032062533644161055, 0.03147080361044832, 0.06163894212139504, 0.030060444825461934, 0.024016677435221415, 0.01365282601078174, 0.05434235651046038, 0.015901771806446568, 0.03661480133554765, 0.01616623082996479, 0.036777537781745195, 0.047386402264237404, 0.014053243944155318, 0.05452735908329487, 0.0704447321061577, 0.03277620320607509, 0.04352448967152408, 0.040284478172127686, 0.0506736533716321, 0.04997880637113537, 0.023035408928990364, 0.02568859450652131, 0.0651840026091252, 0.04168961223747049, 0.04954721738717385, 0.013420270855671592, 0.02815110665479941, 0.03512443309383733, 0.0665973706969193, 0.03591087553650141, 0.04452684534979718, 0.016764873439179998, 0.024452235849042023, 0.020502446186063544, 0.05074487240718944, 0.00028838851514072824, 0.02529208069401128, 0.03486699690776212, 0.025107400425310646, 0.026480745125029768, 0.04062643607280084, 0.04398047198940601, 0.08027420751750469, 0.019768868406702365, 0.06411343719810247, 0.023975220641919544, 0.03270338282787374, 0.07360781130513974, 0.0486541838784303, 0.023815776786899993, 0.031406685443861146, 0.025695576631863202, 0.03499368618109396, 0.040282703803053925, 0.031869602389633656, 0.019016544401113476, 0.0755097313917109, 0.02867568377405405, 0.04627364215308002, 0.03757112180548055, 0.017447608589593853, 0.03789820961122002, 0.05679564397515995, 0.02749935510967459, 0.06505609197275979, 0.03088714475078242, 0.06377081094043595, 0.049080938300383944, 0.0162449951749295, 0.047483626154384444, 0.04368328722193837, 0.03295635086085115, 0.01728770841977426, 0.039423254385058365, 0.07537519146821328, 0.018068529199808836, 0.008345611775959176, 0.08904343803546258, 0.05310548555904201, 0.0462810788968844, 0.018165030450161015, 0.030615886806377342, 0.02439896236839039, 0.02032592360462461, 0.07227006594517402, 0.03163911761449916, 0.08839968472187008, 0.004922271564802421, 0.07086963073483535, 0.01930750021710992, 0.021955615441714014, 0.02939280029386282, 0.005062330946592348, 0.018807530170306563, 0.03910914695422564, 0.04252349106328828, 0.03467694942706397, 0.021859887721283094, 0.04214449193594711, 0.0024785997894858675, 0.040139699155198674, 0.019557272350149493, 0.04680644481309822, 0.036711818272514005, 0.048571752051689794, 0.028578537915434157, 0.032388902202780755, 0.02989796961524657, 0.04632107853623373, 0.0525957802310586, 0.01413865793230278, 0.0408858060836792, 0.10704115871340036, 0.04129860982564943, 0.011121602013840206, 0.04362125555053353, 0.06514889520726033, 0.07475264915930373, 0.04108684922435454, 0.04030963146526899, 0.023369012367246405, 0.0858525185446654, 0.04716828378981777, 0.029292221048048565, 0.016117145606715764, 0.09379014332911798, 0.06565062435609953, 0.025822715434644903, 0.03882876949916993, 0.025897286433194364, 0.03558815071093185, 0.025838567709018077, 0.0020397188865380095, 0.05692973267287016, 0.031473880766757896, 0.02376041341839092, 0.03682769848299878, 0.056125108884381394, 0.05052848419706736, 0.046620906197599, 0.03171902529097029, 0.04422931792214513, 0.010888219894176083, 0.04254349766831313, 0.0375948942798589, 0.014835784810462167, 0.029205354994961193, 0.03130140055769256, 0.05730999048267092, 0.036518887017986605, 0.03918068829391684, 0.06403366183595997, 0.08574159842516695, 0.11599994477416788, 0.11497193707951478, 0.1752396481377738, 0.1384795792400837, 0.19801004842988082, 0.175543767533132, 0.13183326087892056, 0.20532422166849884, 0.18722390649574144, 0.17516400505389484, 0.14732798800936767, 0.15894021918731077, 0.1305121939097132, 0.1705646232834884, 0.17996913221265587, 0.08058762962796859, 0.10331129242799111, 0.08821479071463857, 0.20387606509029865, 0.14223243429192475, 0.13453809145305837, 0.22657348215579987, 0.15219889235283646, 0.18785731893564972, 0.10746693943760224, 0.14657777255134924, 0.10370883252471685, 0.32549547404050827, 0.1269359208111252, 0.2117831150868109, 0.0740907382486122, 0.09181876161268779, 0.1766605954617262, 0.18034297786653042, 0.10851408181978123, 0.12456072254904679, 0.10177738259413413, 0.17096681813044207, 0.14731715859047004, 0.09512792940118484, 0.20677051906074795, 0.1627129688858986, 0.19536106128777775, 0.12005747562008244, 0.12212058848568372, 0.13110059233648436, 0.18511326903743403, 0.10637023007231099, 0.14776340393083437, 0.16485832019576005, 0.10077789372631482, 0.1787904083196606, 0.1453606164348977, 0.12883595457034452, 0.07024721056222916, 0.14675508732242243, 0.2125811536929437, 0.14392803902072565, 0.10297194349446467, 0.17214755048709257, 0.09141619357147387, 0.09005805144884757, 0.12653125609670365, 0.08143216145357915, 0.14084155963999884, 0.09465951632176127, 0.07022312935441732, 0.20082656586808817, 0.2559466117194721, 0.16925860622099467, 0.1238529019589935, 0.12198260160429136, 0.10564095420496804, 0.12090478943926947, 0.06265969627669879, 0.13730450586548873, 0.09321454207279853, 0.09638439983661685, 0.1433214151433536, 0.16623736119696073, 0.12129365785845689, 0.10273738750921828, 0.1286412693027939, 0.1538223009556532, 0.14977258683315345, 0.20603390144450323, 0.12194571644067764, 0.17850101313420705, 0.17714350883449825, 0.09953776919948203, 0.1670434879405158, 0.10041365612830434, 0.2397497636931283, 0.1232340508805854, 0.1339094830410821, 0.10255008470267057, 0.13852077988641603, 0.13583108064319405, 0.15119444339403085, 0.09670681253607784, 0.21463929968220846, 0.11868802910404545, 0.13077155713524136, 0.09816311831985201, 0.20729593586708817, 0.12963889219931193, 0.18754900619387627, 0.17867158326719487, 0.15676703437098435, 0.18279247571315083, 0.11197110238884177, 0.10513920470007829, 0.07948163790362221, 0.14457879481571062, 0.17824835383466311, 0.09426247834094933, 0.14201932001326764, 0.1246109748525279, 0.0674536886758038, 0.1146376228758267, 0.09332035960895674, 0.10528768851820912, 0.15710149785237654, 0.08729236306888716, 0.16191816010645457, 0.08915964394275631, 0.12260024489036628, 0.14541114015238626, 0.1689730379730463, 0.13613171236855642, 0.12647413701883384, 0.13910077804965632, 0.20738136342593602, 0.08180806306856019, 0.059673063323966095, 0.21257470761026653, 0.19051737976925714, 0.06986024204109396, 0.1822455764881202, 0.12465438752302102, 0.16002621448465756, 0.10442758431392056, 0.15414822846651077, 0.2053809743374586, 0.13937163565840038, 0.11780464436326708, 0.12673457232969149, 0.12883406824299268, 0.19788612079407486, 0.21386639401316643, 0.10002794289695364, 0.11524989216455392, 0.14069737094853604, 0.13565538078546524, 0.10372041511748518, 0.0766777005046606, 0.22066553203122957, 0.20408369680600508, 0.09385315209094967, 0.14400826900133065, 0.1588645896741322, 0.32083939388394356, 0.12607993531439984, 0.1367013832288129, 0.11736597147371088, 0.18814893971596444, 0.13716273275869234, 0.1375399710876601, 0.10738268574433667, 0.15926986507007054, 0.1484934804694993, 0.08931124902197293, 0.14693238852279528, 0.07281754871032067], [0.013258034829050303, 0.033079121594450304, 0.02103915381511407, 0.026090784264462333, 0.04252144867288215, 0.046540913704250536, 0.034100839269480536, 0.05290385548557554, 0.025504567327776125, 0.026433088217994997, 0.03500975049766047, 0.032210691765482934, 0.008761274694864239, 0.024773583248523728, 0.020649194650884186, 0.014816631463223269, 0.0340127518533596, 0.02683492174505123, 0.0652176375899996, 0.010932104146507169, 0.03771391271480492, 0.02487819129601121, 0.0069765736531865385, 0.010700711830785232, 0.011065625419308032, 0.04335477449265974, 0.05767101861004319, 0.05157889711803623, 0.043615661029304774, 0.06378248852810689, 0.10799989476799965, 0.047682789753058126, 0.04356496089271136, 0.004263431449154658, 0.027659494463088255, 0.029671651045126573, 0.00426732242340222, 0.029558529079492604, 0.027517488958047967, 0.027509331270786266, 0.08746113508407559, 0.020672166453940526, 0.018313119021643485, 0.020573688970346535, 0.03299806719379766, 0.032473668189985413, 0.05239430622064641, 0.006563494680449367, 0.03231976626973067, 0.02477948650318597, 0.01825366069429687, 0.030001259608460323, 0.029629836324602365, 0.03280880342104605, 0.044732170046440194, 0.02847301893468414, 0.0339762534547065, 0.0074435300027419415, 0.01838356622361711, 0.11990419455936976, 0.016400432280663933, 0.016143408304612552, 0.03814221419660108, 0.0429995580177222, 0.040824100109083314, 0.03214280094419207, 0.00714682020978736, 0.008162903499656489, 0.02915944531559944, 0.029241972137242556, 0.02350677702842014, 0.019202522368037274, 0.04743061221337744, 0.06139753971781049, 0.026449021916570406, 0.027635754219123294, 0.027498646040580103, 0.03451203827613166, 0.05163541229973946, 0.11034384649246931, 0.01847818453929254, 0.025546975766441653, 0.0020730211732110804, 0.010177401027509143, 0.050938879139721394, 0.0656402020582131, 0.03760966598721487, 0.13653758487531117, 0.05182647079761539, 0.08004225710672991, 0.04696745438767331, 0.10763781491134848, 0.046046193822153976, 0.03326908765094621, 0.035345937458000014, 0.034566748554685285, 0.013126098783686757, 0.011087732090215598, 0.05926567089876958, 0.045879230102790255, 0.04315524448507598, 0.019474569109401534, 0.045878836552479436, 0.02848555486915367, 0.037079197487660816, 0.030708109893436943, 0.026615717614601766, 0.03342929994687438, 0.055362384633294175, 0.08776602122400488, 0.04845628574756639, 0.02168472560255655, 0.0071724018281591785, 0.007699727862408119, 0.015267643512093594, 0.06277361552097968, 0.03573910100385547, 0.046835672709026506, 0.030020706422094787, 0.00857504312547722, 0.06310218931840998, 0.06607188603707723, 0.0394427656595196, 0.006985794520005584, 0.024698276039479033, 0.019167155426527773, 0.03570890619552561, 0.045614754115896564, 0.0873985198725547, 0.02634765557013452, 0.04722131808687534, 0.008346056216396391, 0.031877575176102776, 0.012745049632420498, 0.017991174511345367, 0.08392096683382988, 0.04327727561550481, 0.019085805863142014, 0.018314526981807182, 0.09648439554231507, 0.03646623609321458, 0.03325720650276967, 0.08010398343737636, 0.014734888349526694, 0.050238003355583975, 0.05680507221924407, 0.01391706959943154, 0.05451341179598655, 0.031147155977253402, 0.013835772622509726, 0.01991089935680585, 0.025703032035380602, 0.022443704340340834, 0.05909153845693384, 0.046652169698583226, 0.05078300268256238, 0.02215300127863884, 0.13209486327001027, 0.01698479681674923, 0.0707072980169739, 0.009198088398469346, 0.0640674325238381, 0.03946754575840064, 0.03797634970396757, 0.0205980551628662, 0.05001490443412747, 0.08284425389553819, 0.0655528949573636, 0.017351823193686347, 0.016806182651115314, 0.015649582392403057, 0.05876369747732367, 0.022860294307715127, 0.033410993072071245, 0.027538866203810488, 0.06124324085456984, 0.019558122215260352, 0.049671667494944165, 0.038681520614773035, 0.060481938134346686, 0.024296900523560386, 0.02559064967291696, 0.015721222119671956, 0.036996246581631045, 0.0238356544702713, 0.03967348452923553, 0.04167535960940378, 0.012925167601289493, 0.016729723628876463, 0.053695536218583584, 0.03238872578367591, 0.04555913120774286, 0.03308780345001391, 0.0362131018191576, 0.008610929994444762, 0.038697235485804934, 0.019721270871481726, 0.03195974915953619, 0.043904286077512164, 0.013033410900139382, 0.05043572506734303, 0.03388164531705635, 0.009630552692604917, 0.04376305240605559, 0.07121196522244386, 0.04803800283532057, 0.02868491524298276, 0.07040969255779471, 0.0573002602905035, 0.011438024097255297, 0.021342192643455098, 0.05940869929535048, 0.03020552239779915, 0.06808221566357783, 0.013007037940302064, 0.03138202748128346, 0.04685388458892703, 0.01950250948513193, 0.03492206341720053, 0.017155193923307315, 0.02228315277690334, 0.040119516131068976, 0.049355541422430954, 0.03950196783989668, 0.015619611500629356, 0.032539313060364554, 0.030658142574663674, 0.06045763979532889, 0.008475129692150014, 0.03784810319276793, 0.04344375757500529, 0.03339271673134395, 0.018077837003927146, 0.023814239905082753, 0.013910562448602701, 0.026330417387985756, 0.03250767297244497, 0.04351055256224104, 0.03608003770932555, 0.025577874554853355, 0.0323781881348363, 0.03719708616180079, 0.028598086509321417, 0.023384253960102797, 0.01652889931574464, 0.03074667782389692, 0.07707925752869674, 0.019672791240736842, 0.08172830127711807, 0.027156545647553036, 0.008864787756465375, 0.02947496749194605, 0.03203154494985938, 0.045116271757121594, 0.058365567055131705, 0.03290475505803313, 0.028752948556627547, 0.028630347456783056, 0.016791041142174175, 0.021597089412223016, 0.026710257898750048, 0.08577899249004466, 0.03492048582328217, 0.022607746966449276, 0.03171595152733581, 0.03656195363562022, 0.03903609248144286, 0.04754759165059243, 0.04997517281611051, 0.0547484868605222, 0.020542189678443328, 0.01665122221623148, 0.05333071508045707, 0.009006252129828292, 0.023056029608207088, 0.04351443378254771, 0.07498047407716513, 0.011383800667577555, 0.009394973815817918, 0.04053962430251496, 0.03274477346401129, 0.05733955425343343, 0.012685225744332587, 0.020384248778490082, 0.09681136799710137, 0.0585324459576181, 0.09076709340193442, 0.017790017716054405, 0.046831727027893066, 0.031765209777014594, 0.018956315936520696, 0.01900140967752252, 0.057517608627676964, 0.0303349224185305, 0.022635370127058456, 0.02589278944235827, 0.014700428948604634, 0.04221050660791142, 0.01937025792098471, 0.037189869941877465, 0.024540190950834324, 0.04911033243739179, 0.02657949402263122, 0.048800360677497726, 0.030940321540193896, 0.0579326684985842, 0.0214621016556131, 0.04371867282316089, 0.022553925568770086, 0.012086967355571687, 0.010705920435222132, 0.06480791100433894, 0.021729410526209643, 0.034328525087663105, 0.027922706678509712, 0.05194636793541057, 0.023475771370743, 0.08184745881174292, 0.04052610449226839, 0.04939270817807742, 0.008012028693753694, 0.07358521608901875, 0.05749013474477189, 0.03213272469916514, 0.014249484753236175, 0.03209881151893309, 0.011823795004082578, 0.042742915717618804, 0.007112506693894309, 0.09998980244355542, 0.06339282622294766, 0.0767254965113742, 0.04059067727731807, 0.05353995831683278, 0.01287990846737687, 0.06271110208971159, 0.030075715256056616, 0.04665269556322268, 0.02602703420312277, 0.0698736770344632, 0.07556809218866484, 0.021736284085948552, 0.05287995408954365, 0.01630869773881776, 0.00615729605280129, 0.02926444521706019, 0.028777949179389646, 0.05276156669216497, 0.04863819080804076, 0.03910214786550828, 0.02310411399230361, 0.0270242533713047, 0.1284729383353676, 0.19878049780215534, 0.13919068393962725, 0.10108808601008994, 0.10610028848584209, 0.12133932326521192, 0.08577859215438366, 0.1274233396564211, 0.08189859321074826, 0.08198463823646307, 0.07748769489782197, 0.08082055034382002, 0.1648664626159838, 0.14615516737103462, 0.11711021805448191, 0.10062622757894651, 0.11475769643272672, 0.09213725237974099, 0.1588815666202988, 0.10981260785566908, 0.09425076004117727, 0.07221374075327601, 0.1396371599818979, 0.11926900435771261, 0.07231720377291952, 0.13174525488700184, 0.06911022335823093, 0.19655646357153142, 0.14775566863162176, 0.13304380806429045, 0.2226664096649204, 0.14584221344973358, 0.15986396319099835, 0.10326350320662771, 0.11579607214246478, 0.15196850257260458, 0.19133426807820797, 0.08616682275065354, 0.1635992577565568, 0.10392737508352314, 0.1438308728060552, 0.10400297745530095, 0.11163535647626434, 0.061484310775995255, 0.13702181460601942, 0.11657945439219475, 0.12017019385738031, 0.16280767880380154, 0.10603183787316084, 0.11142444743641786, 0.07089703676423856, 0.10234661919197865, 0.09969640390149184, 0.23789730880941662, 0.1299228048218148, 0.09377790934273175, 0.05597446732489126, 0.08898557256907225, 0.06812919742826905, 0.1380695676697152, 0.05614285257511905, 0.12192009495837347, 0.12673094895269188, 0.09617026775543179, 0.18787601936076367, 0.16070441023579665, 0.15497994955096925, 0.12168817168899945, 0.07414909226021596, 0.09487403516790696, 0.1497799964355571, 0.08728981856256723, 0.18411361053586006, 0.12424886785447598, 0.09685566276311874, 0.0939716175198555, 0.10845788554953677, 0.13200119829603604, 0.15334112463252886, 0.1658493070197957, 0.10153574270329305, 0.08496456726321153, 0.08522920949118477, 0.07517943411533322, 0.20622173350836548, 0.22485434583255223, 0.09681333574865546, 0.18393849421824726, 0.1611331765140806, 0.14781415835022926, 0.1905655421848808, 0.2539920780275549, 0.13591411975877626, 0.1185539641550609, 0.18169898938919815, 0.10736312357974903, 0.1218783650547266, 0.07237618882209063, 0.08761364261486701, 0.09001900175852434, 0.09226048112447773, 0.09121087566018105, 0.11934091549898897, 0.16135997005871364, 0.10204712062009744, 0.11082869369004454, 0.1426894547683852, 0.21438442835850374, 0.2157340616519962, 0.20396981148847512, 0.21156040632299014, 0.13170146223689827, 0.18581032806209155, 0.07058636272060019, 0.09527487294482333, 0.1066280190965959, 0.13606604374945164, 0.1240960346268756, 0.16455323728067534, 0.11775435134768486, 0.11863603975091662, 0.18356292508542538, 0.0971224627324513, 0.14354335037725313, 0.07306224200874567, 0.16518690756389073, 0.11460092770201818, 0.21282149079654897, 0.2521487697958946, 0.13342230846839293, 0.09505403015230383, 0.11727016232907772, 0.10604677921427147, 0.1371578880186592, 0.06263136065432004, 0.18760859513921396, 0.16252103847052368, 0.17736909458679812, 0.15500231406518392, 0.12091842799314431, 0.0799522494365062, 0.15430510576282228, 0.11516742301838738, 0.12070821784436703, 0.21132054419389792, 0.11670564833496298, 0.12081370289836611, 0.19387188048235007, 0.18528366275131702, 0.10408189786331994, 0.2697830806885447, 0.07488256147397415, 0.09582144647304501, 0.21279866487852164, 0.22189646240855965, 0.11160921252199582, 0.10309189491506134, 0.23769909515976906, 0.10422082112303802, 0.13651902015720094, 0.08694390141006027, 0.14899555567119802, 0.12635890820196696, 0.106042395878051, 0.11083531619182654, 0.07945959230086633, 0.14122436195611954, 0.17242668622306415, 0.08510416905794825, 0.08418685078088727, 0.1604580341705254, 0.15572073337222847, 0.1243832449295691, 0.10285537117826087, 0.13698499729590757, 0.17005701123603753], [0.009139799695861126, 0.05277094743879778, 0.024740204414618865, 0.03025389855195369, 0.014017316363086658, 0.0661269152270896, 0.028001942605312382, 0.05119351636884468, 0.0374014609094177, 0.024342175772679702, 0.020709060099241988, 0.012670357345736452, 0.05790953045444829, 0.010694687287988407, 0.03994561778381467, 0.0270720714304064, 0.028069529782182405, 0.06611114607325622, 0.09361230608608041, 0.034021253897143264, 0.015160306057493602, 0.0067917097559464824, 0.031228787132671902, 0.038143187894352844, 0.10064967096384082, 0.015416956839284726, 0.0394832300953567, 0.026349631803376333, 0.047147154209337065, 0.04199243902361818, 0.045510107052645514, 0.046701404199536355, 0.04564724576526454, 0.011860297643579543, 0.02107785575624023, 0.022471651501421417, 0.014827633908550655, 0.05924832754369293, 0.05694404976176364, 0.026134590485266278, 0.01727304867069636, 0.02492723919983421, 0.04741280066913792, 0.06080279698861497, 0.04783562637333359, 0.015858907052981, 0.047359593345650604, 0.04195276168840272, 0.03516961334805403, 0.03922847751528025, 0.022245273559487293, 0.032376464655888934, 0.020311664191207716, 0.016299025222126926, 0.05723432704274144, 0.03400465693058712, 0.02230638581594186, 0.049951678541089804, 0.03887938142621091, 0.07270172956798758, 0.03096067759075335, 0.050710202660411596, 0.043410417756864, 0.06938634639871971, 0.0742660988388317, 0.052875024532633166, 0.06024061715496438, 0.014122641113187586, 0.06214871869555541, 0.01211475590909166, 0.044735199705298455, 0.07506115867623261, 0.04768834695486086, 0.02472457944947694, 0.06611230636813811, 0.01648713887802192, 0.034820686892739365, 0.0973940599443657, 0.019883707065933516, 0.06615765964878456, 0.05297311016225389, 0.033875507967812676, 0.03619409944596035, 0.01692800173935081, 0.05884158651211432, 0.03819597791880369, 0.039061808958649635, 0.02641392808540591, 0.015734171960502863, 0.04174470588830965, 0.00585136200035257, 0.03435595486579197, 0.0283835269510746, 0.05707247608474322, 0.029450411309621165, 0.026236569209556495, 0.04486252001619764, 0.017470631282776594, 0.017977866743292128, 0.004345568537246436, 0.05390821284215365, 0.036632103978523185, 0.002235543032708977, 0.011446666088886559, 0.04505428758316806, 0.0241268817002752, 0.01968585982519601, 0.00600196496816352, 0.01983687118627131, 0.05802185514143535, 0.0422547945885786, 0.032908188445227485, 0.04492699441366962, 0.050734782591462135, 0.025818727345072796, 0.013497772277332842, 0.041217915048556666, 0.02683890304927315, 0.030649918730237653, 0.03302505931683949, 0.029877633920737674, 0.027253621956333518, 0.03655155169378434, 0.07676650716790132, 0.035793085249939134, 0.04349295814920749, 0.035600757891578336, 0.03855751834011503, 0.053075962500380616, 0.07012690630342279, 0.0299460981041193, 0.007010715414902994, 0.020703550394890562, 0.09255670237221889, 0.012321708241610654, 0.05227777800921883, 0.04227235846753631, 0.015418368192123515, 0.061545351786272864, 0.02390802531902279, 0.02840977268559592, 0.013176590270761932, 0.050663502487753115, 0.0629359618095415, 0.023892978804984262, 0.039396788126655986, 0.027742511526282345, 0.06957523019186088, 0.026736987089472156, 0.008981125129918967, 0.0854249397026641, 0.029698476927088838, 0.014929526119625993, 0.036403519101440907, 0.025559618570176617, 0.02541658508458308, 0.02453718673703926, 0.04755163232662848, 0.011848123029007443, 0.0490710181184113, 0.0634770934869136, 0.012401546368242373, 0.022712495809953128, 0.026081033716244355, 0.024764426418447068, 0.014556857724008816, 0.023258017608895898, 0.02460201227638338, 0.04184739198535681, 0.08406220389796154, 0.01871216546611062, 0.03693013691476413, 0.008383514742100877, 0.04071161935904196, 0.032881566123770814, 0.03671650694949286, 0.04314828271578465, 0.015410083279545819, 0.11486866404967648, 0.07781203463673592, 0.052411300130188465, 0.017055040458217263, 0.033527243084141185, 0.08395664420511041, 0.03582104767805763, 0.046085464036358256, 0.10121559631079435, 0.05675579700618982, 0.06840135103889874, 0.0056047463274028686, 0.06667370588651725, 0.026173328049480915, 0.06638752017170191, 0.06340596944625888, 0.07058163333152022, 0.019640053622424603, 0.0351784648373723, 0.011706253230970885, 0.0597951046324202, 0.02385596980872963, 0.05232250025229795, 0.009063192244086946, 0.031576285271772316, 0.04644326912239194, 0.02134205524011382, 0.024487982770161967, 0.02418761736979442, 0.025868789658748677, 0.05304263286026461, 0.06023580634168216, 0.033894211785601716, 0.029886987525969744, 0.00947558632053967, 0.11294920383287327, 0.033223337427313836, 0.04182209959253669, 0.02693624229037336, 0.04521414704088654, 0.03814621416053601, 0.03679223824292421, 0.02398915944754013, 0.012397344540139394, 0.0054836914392321235, 0.03206159048048513, 0.07436135837009974, 0.023981542891955802, 0.035224228631705046, 0.022986917423882654, 0.011860831141737955, 0.022576495339827876, 0.0669827310900603, 0.014379359748480576, 0.09011396951973438, 0.008573621594613152, 0.04741017134594066, 0.06144039598958833, 0.027117438281753233, 0.0504420659770923, 0.028628199893449034, 0.0354363590345851, 0.07553600426763296, 0.10751588895384755, 0.06067346142871039, 0.02151655069818454, 0.02412584693437176, 0.019238428744886602, 0.0842608314539705, 0.03013786906376481, 0.03778068056063993, 0.01850588064241622, 0.016147920562486564, 0.045649817412985225, 0.025699474815545336, 0.03385679397199835, 0.005619184704430933, 0.06140992298190083, 0.03028794743918947, 0.022831483710823313, 0.04005640558898449, 0.012534786897179271, 0.029515666022364582, 0.06767572568995611, 0.03126460360363126, 0.06450160672622067, 0.02312952003973935, 0.012964123144878872, 0.09444036986678839, 0.039297844150236676, 0.003383261268027127, 0.035028189686792235, 0.050414025517446656, 0.034850437260632, 0.06848510261625051, 0.0324915441950517, 0.03441727746810232, 0.024761707189359834, 0.051021456851490905, 0.01537545254853155, 0.024120262591168284, 0.021891071494402628, 0.05838799263749804, 0.032226053798305135, 0.04992807909314122, 0.009005872998386621, 0.04768499838454383, 0.012813541805371642, 0.019976162551237003, 0.008521079235444111, 0.03583313917208995, 0.01527069352700242, 0.016790057266397134, 0.01797776496303933, 0.012592430991519774, 0.02474847575649619, 0.004333302744531206, 0.09708162170967885, 0.03040825848334602, 0.013606144497836275, 0.060052432252892425, 0.01758888636582664, 0.022248781585533704, 0.052329434880188534, 0.0384975935199431, 0.047378324304840395, 0.041555065528622696, 0.021126259051795517, 0.07879362375076328, 0.08715100386845213, 0.034724789538553784, 0.05970648117363453, 0.04997913546061941, 0.03220460530636566, 0.024809755950367877, 0.05345167751823153, 0.01467397965357772, 0.06501067083861146, 0.03319190429257495, 0.04732093381296311, 0.027655682792620997, 0.07825823926499911, 0.019979721467409815, 0.1413502980555807, 0.04728839127346873, 0.04743662742631776, 0.02400687599687704, 0.04788317471476538, 0.025399246818519065, 0.06781242335481302, 0.02350668203351753, 0.026431712488244687, 0.03005733374240143, 0.032373401070279736, 0.04589607812730329, 0.008620942626813692, 0.04609400339956794, 0.019112187304667065, 0.061329971200653484, 0.05039894846933229, 0.06733246160937206, 0.03310871929196375, 0.022407999827659557, 0.018972090179366723, 0.024027159104921987, 0.06876294235033648, 0.0384228393169386, 0.06187316562448229, 0.023081866525379673, 0.060994693477238925, 0.049591200027082644, 0.010005916568583675, 0.08362429096762623, 0.010376441641710699, 0.12734897221837724, 0.13414444614733967, 0.22239002878112452, 0.21573251459215367, 0.12063617099608694, 0.11138809831546885, 0.12346464422132288, 0.11350219630237136, 0.12589199468493462, 0.1590198656277997, 0.19186580527041638, 0.12879271831895622, 0.19532828804637703, 0.06398228316434793, 0.15826139918395452, 0.12255683221987315, 0.1145058920873063, 0.16723638187561715, 0.1576456015131303, 0.08323675247707538, 0.1300856260848897, 0.10800904820540122, 0.12060243423495974, 0.06735111453703471, 0.20109160164637224, 0.10618916300258466, 0.12879186336483273, 0.1299362126737833, 0.15810263556029114, 0.0598422424601657, 0.13493584868099007, 0.16773851136011736, 0.2254945979054485, 0.12233613191970757, 0.0735528092565281, 0.1539218963256904, 0.10092506797185966, 0.2578140486563955, 0.12443223515791552, 0.13171598288629735, 0.13285179622471333, 0.1908117961138487, 0.1443724523165396, 0.16495897408042634, 0.10865047414387975, 0.09904069480087076, 0.14631815148251398, 0.11841486447623797, 0.180767510086298, 0.1001061304871525, 0.12041091094059603, 0.09246163283075605, 0.07483106745140893, 0.1007768419970359, 0.1481715834566525, 0.13037941817726406, 0.1460194332259042, 0.11039065183805567, 0.11517609469592571, 0.15763237008026668, 0.15024735778570175, 0.14272320510021277, 0.16185093085680688, 0.145822033818279, 0.17461097187229566, 0.2389301476734025, 0.13560378498264722, 0.059803789880658896, 0.1730812011020524, 0.16460992209613323, 0.12665609296943459, 0.10477185262633221, 0.1093988779133984, 0.09804123985980238, 0.1306353480155979, 0.05995496069746358, 0.11097301808851105, 0.18876479166959012, 0.07282170134463481, 0.14145412748413427, 0.17798071248190744, 0.05967760950859104, 0.11560175328382424, 0.14784834294446877, 0.1366053840943745, 0.086582472947027, 0.08425426323498998, 0.20126589015126228, 0.10864717646368913, 0.18225515740258352, 0.15602863899299077, 0.14401369728147984, 0.18741339418504918, 0.12194179450826985, 0.1396013061915125, 0.13417715153523854, 0.18442105475280965, 0.10291269381663629, 0.07686234345393521, 0.12816892750561237, 0.1283365935087204, 0.11940000232841287, 0.0869270194587963, 0.1011553763278893, 0.14777150563895702, 0.10255843746875014, 0.10734679802720036, 0.08513034015361752, 0.10359052315886531, 0.1463299444211381, 0.11711616202124528, 0.10094024001487664, 0.14182657535587037, 0.20312772238893168, 0.12823364617569105, 0.11642248210098062, 0.0641928936487862, 0.09845851175487041, 0.08221125536199127, 0.2370845324226788, 0.0896320128813386, 0.07959884804274354, 0.1078959974859442, 0.1497791821935347, 0.12113456853798457, 0.16249722189136914, 0.09089532973510878, 0.3143917370055403, 0.11340557291571583, 0.12133655484233584, 0.2083889472165278, 0.08403230085968971, 0.08195644510643822, 0.19799638273460524, 0.14286778734198638, 0.14555819226162775, 0.11413166645382132, 0.09947685032550778, 0.09947813954204321, 0.12731883169284888, 0.12001368296997887, 0.12905210868588515, 0.13548741622694901, 0.16533705379281724, 0.13185911306313106, 0.1788708825728723, 0.11119274808359997, 0.21765903835850103, 0.06421525137765066, 0.1217731921268361, 0.07008297794631549, 0.19210611523262092, 0.09830550210816519, 0.1850752303642886, 0.06831855619592325, 0.10624788342309849, 0.08252389715718371, 0.11338191239961556, 0.15214497596025467, 0.101358651848776, 0.13017963032637322, 0.12008623193417277, 0.10778299426393849, 0.16162959273372376, 0.1442143672278949, 0.11359037871339492, 0.0773011249090944, 0.18598810423697743, 0.15831604839435645, 0.17584135942161083, 0.08122479436653, 0.18896174324410303, 0.15940093089427265, 0.10107819296951805, 0.12307969773454325, 0.1308398584702185], [0.02868553270984973, 0.07033706216939858, 0.0219100382445114, 0.07953890625919614, 0.04116037867165037, 0.011523614504507609, 0.044001150344099314, 0.060350648393588405, 0.03306371545685189, 0.021716905125815953, 0.03032590468813266, 0.024149339513054917, 0.05306158773601055, 0.016040157327162366, 0.025312670839152167, 0.003526246195958395, 0.07137105454291616, 0.011730974806206567, 0.031747754463659864, 0.05048530562115567, 0.060379425063729286, 0.049534650918628485, 0.005175089471906955, 0.01920269539446703, 0.027111687697470188, 0.008815710166735309, 0.016746220511517355, 0.025350107312468544, 0.029792884896908487, 0.006524603173602372, 0.022486010998753563, 0.04638939004923616, 0.03162961473156299, 0.03773608723921435, 0.019805400732106397, 0.045744551079613824, 0.023814884513350468, 0.07655139799628939, 0.03136461966538003, 0.023642901331186295, 0.030751926292266165, 0.04647081425147397, 0.04538677313498088, 0.013826881269259112, 0.04425749069611941, 0.07241926222507443, 0.046678937905068905, 0.007219414975095008, 0.012824339842024659, 0.014367415835814816, 0.02966398699209094, 0.03205162619373628, 0.024092069461143444, 0.01698835742925959, 0.04443848991234388, 0.01733090735173651, 0.01573173432344837, 0.04154655669948884, 0.06153898712779794, 0.039399349596351385, 0.05583389522507787, 0.07364817735339914, 0.018334214675373266, 0.038624089410794635, 0.05348903087100812, 0.01876381385539259, 0.03767914118777428, 0.03155794786289334, 0.020013156280453717, 0.028596074652991126, 0.01833740378996091, 0.03998692360307489, 0.012413048384977239, 0.041334813061569414, 0.05803397377686841, 0.02211293378578765, 0.08088905523930277, 0.045735387464186976, 0.03594231545659048, 0.07238690289003508, 0.03485424044941153, 0.05953064560890198, 0.07355897713984762, 0.033258994442543814, 0.05225417856127024, 0.017705728399700353, 0.025343461061960885, 0.0312378252191203, 0.029593690764158964, 0.014107870254000383, 0.049033566378057, 0.042268962399767976, 0.06644191153879676, 0.01564725671362664, 0.014321065108690943, 0.036432702892592976, 0.044218549571399174, 0.022629797658217803, 0.029771086959434406, 0.017155159996556382, 0.03098296746611595, 0.026166179683059454, 0.03328292297997645, 0.033277772899184904, 0.019248152151703835, 0.05043468012341431, 0.028102990040289502, 0.04640429067824568, 0.06964095987911735, 0.057283615826496055, 0.035665334069303105, 0.08975359278598002, 0.025813356740400195, 0.06206056342593261, 0.05162169232166239, 0.038021570670285394, 0.021883980803457753, 0.010729422343761792, 0.023879318198721324, 0.04947150644979306, 0.014174844204847301, 0.07427532012973513, 0.02551018729406808, 0.024563008387173926, 0.006558780982491693, 0.022816332023856894, 0.03362385629277144, 0.00835728766729257, 0.0597941478980439, 0.034392093640885184, 0.028030656510964036, 0.03278163827157446, 0.07585937370147024, 0.01957218994253448, 0.02712490895230855, 0.04455247701012662, 0.08256823942065239, 0.010977781427625035, 0.02754204853304795, 0.018027874774166515, 0.029727043251373937, 0.02254049396807594, 0.009215184936432965, 0.019532380292990377, 0.012612106810723032, 0.05762263906321355, 0.03931276174262166, 0.024830603938815848, 0.04649469868413039, 0.06881937610783748, 0.006276754687340664, 0.027844200176852088, 0.016938883744712387, 0.007334080607896405, 0.030800353336547102, 0.010939192292945725, 0.027710469406364218, 0.08168277157736675, 0.062077805000756464, 0.04720051081052848, 0.060329342394002845, 0.01743078261746892, 0.00895658675913832, 0.026819814162861024, 0.05483002980638828, 0.013403633177014334, 0.027948835365740315, 0.07624127356601612, 0.04261165311826127, 0.007313305561962936, 0.04193584241771272, 0.03791482014847653, 0.02238639527266579, 0.05499961606359907, 0.03624997341207095, 0.007246657307924969, 0.02152720369797732, 0.039082894434354136, 0.029109104802565913, 0.026109082657577734, 0.025125030461432676, 0.03119887730904988, 0.015750631523717726, 0.047733727376908064, 0.01661982640091862, 0.006945459429906415, 0.06957209536007472, 0.019765435019508004, 0.018948404218203256, 0.01818629234497036, 0.046748511493206024, 0.026190327048035603, 0.014263757737353444, 0.013053246175072022, 0.00024653862211770114, 0.07169344688632659, 0.03510825003364256, 0.04208795979086842, 0.04113797005265951, 0.02145177435262927, 0.05000070948153734, 0.054268494581005404, 0.04939489645351257, 0.023991853231564164, 0.04121311102062464, 0.004266988244905535, 0.06670763942279986, 0.06429856869259051, 0.020297063813943948, 0.00892894493881613, 0.04147264387990747, 0.0175894342828542, 0.03423390677198768, 0.03731295619426029, 0.016915184212848544, 0.013996711799076625, 0.022949238374297107, 0.03815638879314065, 0.038985165035618205, 0.07217123053435769, 0.028298581152090004, 0.04692141578665801, 0.02948973580662693, 0.018095612925078188, 0.03171499140028443, 0.02679312738057758, 0.015037840664652842, 0.015086835982011897, 0.04160088699843202, 0.043058251296835284, 0.040679623040237596, 0.008222150632978549, 0.04661337106621691, 0.027757585181721618, 0.050437048210629394, 0.01547606402475919, 0.0387049334655915, 0.006134914999295558, 0.04371519533119031, 0.07247518029596124, 0.045973420941403935, 0.01837699970097414, 0.009846735645883849, 0.03907701153574245, 0.05296915091042008, 0.04462270199188164, 0.03506153629028371, 0.08888791780918837, 0.03356173301913908, 0.04034804333267467, 0.055329645318644385, 0.03220863241170134, 0.022683374783290283, 0.016400717265371765, 0.020811980290870582, 0.039308917841741016, 0.050360723199056726, 0.004291521950757929, 0.1495880660201822, 0.022111330746806095, 0.038260035017239194, 0.035088243428617716, 0.013149040900836033, 0.05246633271287594, 0.03284921696675675, 0.010824362115402306, 0.03153553245855229, 0.013743334948750479, 0.06644601667565958, 0.02860332140699029, 0.02555467713890331, 0.02360792793998761, 0.03317493073908346, 0.03642610753221171, 0.04413805156946182, 0.016019365317853432, 0.011041080263177199, 0.027932932201240743, 0.08840382378548384, 0.06371909300131456, 0.05886372032442263, 0.02413985359349421, 0.016145627114123533, 0.007717462223289269, 0.027443426860762492, 0.0007254896949494391, 0.047399911896458695, 0.1307265566928046, 0.041291023804140944, 0.0263885305196579, 0.06892366015485354, 0.020108275015705397, 0.026495912079034106, 0.04557652206027082, 0.011808861296490898, 0.10216051060706377, 0.04931225428091628, 0.07596252459500517, 0.06392168998718262, 0.02527256093786231, 0.005963289320269334, 0.010883301363459654, 0.026143830435882722, 0.031633848790079355, 0.024844978703185916, 0.023829830943473747, 0.02472628596504884, 0.0187169203002538, 0.06774598799113717, 0.02645137982576021, 0.003316829297026353, 0.026368761401889578, 0.05984871568424361, 0.006871702673379332, 0.048125316721520255, 0.027330956288746426, 0.026673423625262718, 0.04975582619330712, 0.04747658296089087, 0.09518732835671731, 0.03827901364171079, 0.04657472510422979, 0.061271698613251956, 0.022956301923841238, 0.021368433288963776, 0.05604529620281287, 0.027299599489197135, 0.036832200562847514, 0.02520731301046908, 0.02286879126248615, 0.05283690782796059, 0.05281499453953334, 0.038400529085525444, 0.03564741735213569, 0.026123523579112122, 0.07625542780650513, 0.07036216796508857, 0.0713338843945946, 0.03609797138986843, 0.014755359751039317, 0.06255649788571255, 0.013626557375703539, 0.040439940722925324, 0.03906317620671221, 0.09747407957911491, 0.015199995267071893, 0.015246875251510313, 0.06013520673981734, 0.024340401403605938, 0.008771825914404221, 0.03725203053493585, 0.036887463847441335, 0.15324921027890273, 0.20291960212801183, 0.10003884695470333, 0.13172844078923973, 0.16100022436252662, 0.08692868186959199, 0.07167003742818322, 0.16141562350094318, 0.10576486148472343, 0.07342561786728245, 0.18249651230871677, 0.17939524086458342, 0.14480352561388696, 0.10495320468076638, 0.2660216082419668, 0.10654456607465233, 0.17624111154249736, 0.07324404189629213, 0.05143703580168741, 0.21828586900872843, 0.2513124889561108, 0.09166509378701448, 0.11543984125767436, 0.09203159769198724, 0.13853566694472516, 0.06310450312282358, 0.09572157968900033, 0.08004107645579747, 0.12082139748547759, 0.08602801484188863, 0.11129086424729653, 0.12119558240686144, 0.15288201426821096, 0.05367006062130843, 0.10195785933839423, 0.1276150257991893, 0.2145441012190921, 0.13173684105277061, 0.18211943682815346, 0.1426823301506894, 0.09386000529463802, 0.1196126009204558, 0.10371458650167499, 0.08927445206791162, 0.10832495375403337, 0.14773532615176269, 0.11969460866280965, 0.08646421107862677, 0.08182705526373216, 0.04622402088716626, 0.09189544285514525, 0.09897852742246219, 0.08558599677469049, 0.1412674082177026, 0.08582919051072427, 0.07329283534948315, 0.08732464097972427, 0.18836866292570317, 0.16147050341325148, 0.07971892838499375, 0.10212798842361995, 0.15110651882631437, 0.13120621309748717, 0.3147652026798044, 0.11322399015937533, 0.09811983457101242, 0.06389690310295139, 0.09285041982574121, 0.11968596412667207, 0.11912679698850427, 0.14743248240223952, 0.1561989105705704, 0.10999053330825907, 0.19560882156448706, 0.09263897474323, 0.07065417551036392, 0.19841792940029077, 0.14645924605429173, 0.08396590620811496, 0.1730549010847296, 0.1022916714261685, 0.08224898190902812, 0.25585951496447834, 0.10605029402566807, 0.12088694396827902, 0.08049003593623638, 0.08091654947825841, 0.18556528192545685, 0.07270786352455616, 0.1284126572843109, 0.14566544150667532, 0.1942260486206838, 0.18731938994356565, 0.09701207187026739, 0.15433403849601746, 0.12576354800590447, 0.22175751200744084, 0.07548831004117217, 0.12991952071232454, 0.10087010663534914, 0.0733204177979912, 0.10096261131444148, 0.2114912907459906, 0.22399777679571084, 0.14060267460133347, 0.1634868923574686, 0.07425493015242474, 0.08288124083940472, 0.18103103951684066, 0.1078456434022103, 0.1021316796541214, 0.22912181541323662, 0.09334455616772175, 0.0879212903923222, 0.13858260799731525, 0.10562487971037626, 0.11574256287089416, 0.11204897106758185, 0.06630740554205009, 0.15980175510048866, 0.1193206680140325, 0.17300132395965712, 0.10759087385875837, 0.09112375176378659, 0.25252266973257065, 0.09643856728715555, 0.10600086953490973, 0.06632762588560581, 0.15754935810608522, 0.14528002004538262, 0.11568920287702765, 0.05097581519346152, 0.16866577017520154, 0.08353034779429436, 0.15064362223659242, 0.08995856464441333, 0.16340434178709984, 0.06290726656360285, 0.13084948009678296, 0.07895976305007935, 0.1294966848301036, 0.11939621610300881, 0.11239759557481323, 0.19432075853858674, 0.1238483829157693, 0.20622066142303602, 0.13610915786453656, 0.06593502552381583, 0.11812403079654489, 0.16487258300185204, 0.08241761143186263, 0.11875083430537156, 0.19809870581541741, 0.07543651746319872, 0.07941040529736451, 0.1667850746640137, 0.11515634932688304, 0.17077380205903733, 0.07896733550088746, 0.11682792034532342, 0.16933412716857024, 0.13667273548032555, 0.09650319774768182, 0.08855006843805313, 0.10081342181989125, 0.0942375964618155, 0.1270385288766452, 0.24332797740186962, 0.16041352227330208, 0.05993653168635709, 0.12666272904191697, 0.1236912477761507, 0.21143453807703086, 0.12431043812206813, 0.12826715223491192, 0.08686122870338814], [0.032806699962488244, 0.05940844823739358, 0.01675319585150906, 0.06512468507779495, 0.05182927314724241, 0.046548038321946344, 0.07780641636678151, 0.061756620449679236, 0.031930232886224985, 0.04490389708163483, 0.07461394303079162, 0.023694436065852642, 0.0365060389574085, 0.0429847455982651, 0.009436272849727954, 0.021101073528240834, 0.04031041178054043, 0.03300399419718555, 0.1656665639685733, 0.048026803614837785, 0.09103514187570129, 0.012180520371267838, 0.024547110311686993, 0.03646888916513749, 0.04028488190046378, 0.07033127426568951, 0.046328019949474504, 0.05137760970475418, 0.03912889232326831, 0.095627365101661, 0.03625274522762213, 0.02644544094800949, 0.03736975975334644, 0.02269145443902484, 0.04094734242452042, 0.027916513350126997, 0.0440548733542008, 0.008605686615088155, 0.04594239492767623, 0.04064174382282155, 0.027411893642108356, 0.014648156307105507, 0.03087769615064774, 0.03215897721903665, 0.018069813327331628, 0.023074100692091242, 0.04417364073118993, 0.060372612572142055, 0.049111709863479645, 0.03461715692122068, 0.03205294255167246, 0.008783383062109351, 0.05469600896217993, 0.0155012105325503, 0.032226369317088804, 0.05231773693646703, 0.03347640724054404, 0.03557955367224557, 0.026849396593336548, 0.02786044430519853, 0.05092502345464059, 0.026461259295631732, 0.026076470568243946, 0.08689558293138232, 0.04773229227534362, 0.03945754075955067, 0.03167016398427742, 0.022134896268003752, 0.04239439977599042, 0.009600671706721187, 0.0488505790542279, 0.07132150113050427, 0.02323882354955588, 0.03167844211150493, 0.010534468206710048, 0.03780182371182101, 0.04419417998620442, 0.03614550955327494, 0.024632585367986133, 0.055029614096773524, 0.05553516000509262, 0.05885420047811099, 0.030548247043043375, 0.02813763603834169, 0.028266043701608266, 0.046180676070175, 0.05876084763024535, 0.02387149299361876, 0.024761495147166506, 0.02819644466840795, 0.022077268288869942, 0.0170283129638327, 0.03633327376363533, 0.03918635066864746, 0.03824339733858194, 0.030958862509578466, 0.07490745692380837, 0.020868261377992373, 0.058864297079188485, 0.07727339318288223, 0.0700441182457975, 0.04975168373701828, 0.035024827545774836, 0.03433129351053919, 0.033524118430380306, 0.021958270209974477, 0.04969456126647336, 0.03624829064522471, 0.020476334462208406, 0.16519412717648915, 0.01585348046916936, 0.025749482846419727, 0.046672858231301816, 0.04803990273337279, 0.02261007434156324, 0.015400979035933102, 0.021095132954152565, 0.029649089755756513, 0.08896324876695871, 0.06071244326553174, 0.029199655300804546, 0.011624505876430442, 0.05049761424639395, 0.0028084577144389705, 0.04326820360230548, 0.05797250528952905, 0.04326101791645799, 0.08170947871570076, 0.0541838032326528, 0.020520127112311975, 0.06796651865754809, 0.01652068056033126, 0.036413971933403184, 0.029622670994805436, 0.08050833602568933, 0.02203954174183309, 0.029764678196183274, 0.030948630201497247, 0.060062121732958725, 0.04040758138788598, 0.010534951662910836, 0.02089111952643309, 0.03357511372970683, 0.02472765151677387, 0.03529889462515712, 0.030632483772933483, 0.03105663601309061, 0.03145512266616736, 0.004744256630406848, 0.037517229161624394, 0.009070399134153766, 0.04787608741649559, 0.07458889830325331, 0.01604730060457119, 0.04588932331119265, 0.03216464977179255, 0.03488836736817445, 0.0220363984283592, 0.010943394121048706, 0.01176359283272177, 0.03577439161017537, 0.017751626204699278, 0.06252829797033753, 0.07909858452954463, 0.02447881067304739, 0.027004541929012964, 0.02214551703738315, 0.031376599201134274, 0.0467305472785873, 0.05648479011974164, 0.09032084127621991, 0.02921010474009173, 0.058996930319283686, 0.030985457689634392, 0.03938502911478281, 0.008311601904486971, 0.028795957498784577, 0.014407803936462318, 0.03146021846415741, 0.060123074533683915, 0.032061186752149036, 0.026850502605416944, 0.06403929367661476, 0.027993683137797883, 0.10543921895857368, 0.022814208209248524, 0.027265591314062476, 0.016590520473463193, 0.057372605694191794, 0.01790183350177748, 0.0449304685129651, 0.015925223673028604, 0.03872406476044229, 0.016366206974323307, 0.05416396286870752, 0.05370323080569506, 0.04798279044085315, 0.04255663410627416, 0.03972464267696653, 0.023212348809465766, 0.04933149414137006, 0.04830244489546333, 0.06585095503500529, 0.014792528203023332, 0.0345907381602696, 0.047250847930886915, 0.020749948619465743, 0.05503009585663676, 0.031025915340121304, 0.03204218437895179, 0.067952506909413, 0.016369180654042532, 0.06680133832352501, 0.05374742379145963, 0.041100484385554276, 0.07037546046610389, 0.026169112650677562, 0.05579023149662784, 0.029028047009238174, 0.023783882248348424, 0.03430485100086246, 0.04696992764781628, 0.0465970624770437, 0.01690633950888046, 0.06611356844327279, 0.014450653422889965, 0.07246186743889536, 0.02627578005194664, 0.007468920783139765, 0.03926318118880902, 0.05472885344975761, 0.01648172247223556, 0.025250645953097513, 0.020247388265228698, 0.00875357332240258, 0.017472476898027316, 0.03072344817753349, 0.01875089624497507, 0.06490940627242837, 0.034028907772153616, 0.04188477247953415, 0.037400629704019854, 0.021773011490170444, 0.04038047052121588, 0.02535751521853464, 0.05619068929393377, 0.03626499957005892, 0.005842801432923547, 0.010567354254557617, 0.011603910642276918, 0.02611745577970786, 0.04115566285327077, 0.031831326229231696, 0.06782250638519015, 0.016292942155684744, 0.03524674581629889, 0.025089275058625, 0.007721163631815995, 0.024233369289764335, 0.05047592826719795, 0.014343329538990344, 0.023938065760635903, 0.042606296084289036, 0.006032891322060355, 0.030683713166841438, 0.04302265874243208, 0.024851860744612556, 0.030295865942857096, 0.01904777736802186, 0.03172863334683435, 0.03686483470456941, 0.034339619135218005, 0.017390445406947817, 0.02564230145487402, 0.05404753643753273, 0.03533537606043475, 0.02615125530532428, 0.03161549781050001, 0.045294594152697494, 0.04509037886080997, 0.019090835503967743, 0.02226460162949349, 0.01207519053215427, 0.05689296964555979, 0.03828770906797477, 0.03367531978126083, 0.04976273707247206, 0.026924055801438432, 0.056367186430309496, 0.03505552447001849, 0.0019453651995198534, 0.02719886418032859, 0.018654981927414025, 0.019482691173574755, 0.028412656459425176, 0.05430674020733152, 0.04915349065725293, 0.04736086559881057, 0.04868572897144726, 0.007625780267907041, 0.014187447992818696, 0.0036243040480517913, 0.0067395605230038715, 0.04171915904485753, 0.03506855234237654, 0.06569468842021056, 0.018710124772042036, 0.014025339191513402, 0.04708864074200392, 0.041682681002254994, 0.05656437888475401, 0.050037455545472245, 0.03688924500186529, 0.008251974791554468, 0.07672848885080644, 0.03386978791760547, 0.02460380021615752, 0.007718704790542168, 0.043486508673855236, 0.07306160418582813, 0.0469096737381603, 0.035416505099939447, 0.04375018398942692, 0.02440844150260091, 0.022346410900354385, 0.01925150241835841, 0.008925293572247028, 0.06272135475384337, 0.03169048610808594, 0.09564428776502609, 0.06902162025549582, 0.020646268468616263, 0.019532363329614912, 0.04285358477916036, 0.06471782190991299, 0.03613215259143284, 0.00518148296812017, 0.02183216786943376, 0.06409181907240834, 0.044888718253267665, 0.022140017511057, 0.02082977317539709, 0.020730030223993317, 0.03731585693146501, 0.01951704709790647, 0.0281754338315555, 0.03317497484385967, 0.03358211281842419, 0.08053822549326078, 0.022380948332803588, 0.025947392851646458, 0.01002849142865411, 0.09360441472381353, 0.07178988706852708, 0.13504571707120963, 0.15394985196845873, 0.1766812772090946, 0.14238970513854707, 0.14199848898819514, 0.1687818539461919, 0.14362296967634133, 0.06293689140251704, 0.11846617529434816, 0.09672550617584161, 0.09159788489341736, 0.12693510656910284, 0.06662288361362048, 0.07900031230279378, 0.24554887680070742, 0.13195129883076462, 0.22161330974527768, 0.10867156979760953, 0.19603684145425046, 0.08171910712761538, 0.14395803026854992, 0.1390318117503609, 0.09749693263854299, 0.17587966950876371, 0.1267860188548054, 0.10284249258360692, 0.08608592102038008, 0.20074478882764066, 0.1016630290874413, 0.09514447887028966, 0.11927515188498156, 0.13599215128592082, 0.1287974544933864, 0.10325557113225971, 0.13916009558098658, 0.0992120656051806, 0.1436200655464615, 0.19728527803506168, 0.08034833068294184, 0.1224228215536901, 0.12004902107375008, 0.07985327153333596, 0.13879436520593508, 0.13837427060518945, 0.11756419869405882, 0.09243468820516552, 0.19643298376883778, 0.09476926936102764, 0.1740413417241403, 0.044170003783489974, 0.20902583375573158, 0.1778045240789652, 0.103221087982612, 0.15481739970190184, 0.1312234750283616, 0.1281953225178378, 0.0663193409730281, 0.11337792261370591, 0.07965526822954416, 0.09366090276411601, 0.10710872044520718, 0.17131771572998591, 0.33754438321505276, 0.08257131318428687, 0.21434539902423108, 0.12739489546843938, 0.1323652866163424, 0.09319831830050264, 0.09777828039867537, 0.14973228185304574, 0.1792653149792126, 0.09092779085040092, 0.07529854415250675, 0.1536068118044308, 0.18972934276929923, 0.231729262641498, 0.09005725077752556, 0.20204049215785094, 0.12883923867983477, 0.12263706220047814, 0.08160292157637221, 0.17821274431688444, 0.18942876532673836, 0.14900919422507286, 0.1437238406922136, 0.07934431598654815, 0.09661090839654207, 0.1262716893106699, 0.11493486192609582, 0.12188251768904072, 0.1280184012970754, 0.12671490838485105, 0.12373738815741879, 0.11971429974905082, 0.23217587439077242, 0.0661787756585649, 0.1948856118002108, 0.16228907448904856, 0.16999544096844538, 0.12624350296599524, 0.10300424854670252, 0.08997569765363421, 0.1792432354497058, 0.08878628004874502, 0.17565881993089402, 0.1608282428767, 0.1330297895308052, 0.20074159971305303, 0.12056934886745044, 0.1646034081599542, 0.18091880982475622, 0.19176204369536468, 0.11627560641084399, 0.08801694347390107, 0.12920316415173666, 0.0839565492102078, 0.15255383402109146, 0.1444398851266929, 0.14516409912279674, 0.08023331899728094, 0.08813508999134813, 0.05812279401080949, 0.10860028969390051, 0.1348300107887813, 0.046545924685363255, 0.1578346277986254, 0.19466431438922882, 0.12858204676636628, 0.15962866081723145, 0.09516751513417278, 0.10603669618389436, 0.11319754086434841, 0.19649285769888333, 0.12545656519276754, 0.10044139463986669, 0.08392376239810671, 0.121458161888378, 0.1697115283459425, 0.07237181905657053, 0.11197940765747003, 0.19743619779390947, 0.1688806622156075, 0.12552540935575962, 0.09254484836544309, 0.10037680489144155, 0.09364020066069705, 0.1051776504942349, 0.103261949361435, 0.06406717468053102, 0.13350783102214336, 0.20715509913861752, 0.11039736254939012, 0.13355247862637043, 0.09995029813476972, 0.15307699809116976, 0.12960986447121414, 0.19750691471355303, 0.15610293857753277, 0.1245565020612308, 0.15560258685478143, 0.10376711189746857, 0.12412054331174918, 0.10763611857380186, 0.08403783092009169, 0.10687999986112118, 0.0711391923416938, 0.1673213616013527, 0.1117442138493061, 0.22123174236289092, 0.07906433208180325, 0.10068694289241518, 0.1859825538205249, 0.09574846324643918, 0.17025515703218325], [0.025966802345854894, 0.01811657626447933, 0.010399231088480778, 0.022787492589226792, 0.034722248424908946, 0.0374727986886033, 0.03202199117679681, 0.020361080200278332, 0.030116152550492967, 0.041173783130943775, 0.04788511193224362, 0.02749560620369656, 0.04843351411234055, 0.016618206398561597, 0.00527793841735859, 0.035408905507730584, 0.07515025032418114, 0.029185192326882055, 0.026469296542927623, 0.03580155675964696, 0.04235209311757769, 0.061212225018867424, 0.0269464644204293, 0.07394975902778761, 0.07663709696914468, 0.020854868793061802, 0.04602157996435251, 0.03255709407052823, 0.07413275992231709, 0.02643287617580167, 0.00821433899857636, 0.06455300575388329, 0.018812917738354633, 0.0478176451953394, 0.055912164239478965, 0.08774903070713792, 0.007016011380723545, 0.04010075803047844, 0.050184273560132296, 0.041229212656617165, 0.07419668470642396, 0.06342563339109931, 0.03695425544200199, 0.024614738200658133, 0.04381264992324369, 0.041048220225742886, 0.04260081012866326, 0.03296407937471356, 0.05278017890772649, 0.04963381202625377, 0.05634381429159215, 0.02506151788734964, 0.03237365891358682, 0.0423547461895006, 0.019125620601698756, 0.01930054523316877, 0.015112365862088544, 0.009862821166669684, 0.007472547552814441, 0.051619802601635456, 0.02522413050090628, 0.08013748271124703, 0.0450115975524698, 0.003512005230212318, 0.022441731499774114, 0.008261247820753072, 0.14227785542607307, 0.015633387457845465, 0.07162363920360804, 0.031801396049559116, 0.06700869862522398, 0.08759990906608955, 0.04230511474556156, 0.003922724173337753, 0.04078359156847, 0.0694897212088108, 0.10185520377542291, 0.06923528414751802, 0.050320821947285106, 0.04937852679618767, 0.01727817839543734, 0.04070372799677508, 0.04460749262943864, 0.03101050920252289, 0.055899180471897125, 0.023132442829332182, 0.002586318920033851, 0.040309587360492775, 0.03605202439108065, 0.082364611061556, 0.031653434703392644, 0.04086342460608908, 0.027030329652396694, 0.04689739564699786, 0.12156779957669121, 0.004620963848927724, 0.03726905158587864, 0.0186519573575684, 0.013385959884284862, 0.02255631740471082, 0.07795656938105822, 0.06572753630046334, 0.049655464078698835, 0.10685931811375277, 0.024342967962313975, 0.03350671739982707, 0.03818514171455588, 0.03205512743443251, 0.018835959091250385, 0.06406048432524715, 0.03428956360689231, 0.056356842163950205, 0.035194352734833956, 0.05632277631333896, 0.026967982462208186, 0.031318889797798226, 0.025396620887996893, 0.0927336575197322, 0.007286258307950837, 0.01604814707700695, 0.03628011054492422, 0.016367273970640132, 0.05071032479671495, 0.009513030427375009, 0.09111799778682844, 0.018084870019395436, 0.024098970162283097, 0.018106416898912618, 0.01742232128578637, 0.039148746257913966, 0.06128887911992414, 0.07376483787915536, 0.02651217656343111, 0.011634448110791189, 0.046474949922412634, 0.05620763570602451, 0.03259552290130939, 0.024498345696234276, 0.058945280233664174, 0.04745194535436375, 0.0399153313732573, 0.02552114563461925, 0.05650312752862062, 0.08052544867885963, 0.050742578958826404, 0.035558271421385665, 0.05742127701107945, 0.03702948122684445, 0.05327162146568298, 0.055954796594700644, 0.09649168979376554, 0.03107645602098533, 0.012861557487797524, 0.027925800798194747, 0.02715051347123725, 0.030571497045457363, 0.04360880782561643, 0.0154208855570427, 0.019333601762939776, 0.02701197867281735, 0.055766933996762545, 0.027580563877043978, 0.03162961133888789, 0.04396785802340933, 0.059839032989527495, 0.04509003620062556, 0.02815731694655759, 0.031625560484826565, 0.03881500541631665, 0.06297166632222277, 0.009315090736241212, 0.018882778007537127, 0.006037575334110963, 0.0458027965256146, 0.008093947378386344, 0.05202543083578348, 0.026911658966647725, 0.059875606027032645, 0.031085711238639693, 0.0292700125968882, 0.04193169656874878, 0.014445004618859716, 0.08765603748283216, 0.010707012028433383, 0.04841965164190956, 0.04672435564654214, 0.011013456254399248, 0.02366349656533982, 0.022388510605586425, 0.02231074370709913, 0.05996502337179013, 0.042733002320996354, 0.039657939291958294, 0.07657665306968348, 0.03384608668940408, 0.07577715561326061, 0.043408127701176066, 0.032328309025615454, 0.021134172466450503, 0.015125860227271914, 0.03850218720201935, 0.021778448252007365, 0.05891967232206038, 0.0354052855234061, 0.027575505398479954, 0.014071963028982282, 0.05322096204119069, 0.05135826127869742, 0.04325346242902534, 0.023783822876534293, 0.02864596394023725, 0.01784891794834818, 0.024505059800243804, 0.05812827657376017, 0.01571791086878095, 0.05725153469081436, 0.02026805983457182, 0.008551168022677302, 0.031476964708417654, 0.0035017915818441126, 0.01478861814497837, 0.013330209750815161, 0.008494964967082654, 0.03694696119055152, 0.01997536527259009, 0.0464153236576489, 0.013500393967011144, 0.02316103968769312, 0.040411818839077435, 0.05286897200026682, 0.02059783972799778, 0.04426639307556408, 0.09704688071672406, 0.041297527562294684, 0.04948615262817059, 0.011825865384058228, 0.005922203176721398, 0.029799497220665216, 0.04676285572350025, 0.06110508433942284, 0.014794036247102278, 0.056023657721068175, 0.08781243301928043, 0.02588294559557523, 0.04688515826793654, 0.038001156944249354, 0.025707035391990627, 0.03460394923708268, 0.03393268132848399, 0.02859705513609307, 0.02130914120269673, 0.02677568224524813, 0.027676715681861554, 0.058573375189942975, 0.02022613654844463, 0.034653760492801666, 0.018280637550300786, 0.047423538485808034, 0.0495530188615833, 0.02159958642109164, 0.0478002272014107, 0.0354660279782755, 0.03157435483964426, 0.040976570320448706, 0.05710856057703495, 0.06372503018272774, 0.05091359692492655, 0.05938069615513086, 0.047664940889392576, 0.04707677655720285, 0.03754690828334008, 0.03183615739856448, 0.022528567018785646, 0.012545624797764634, 0.057883142227573056, 0.033455108026308675, 0.014937860225992543, 0.050509095058909485, 0.06444482013050999, 0.016672987923292176, 0.040107353390859704, 0.006858387695891517, 0.02194684537659798, 0.03636713605374098, 0.03857585235631891, 0.06022344343364239, 0.0201402034810079, 0.054187938903591464, 0.03360129161072629, 0.06960184912064246, 0.037503688995327265, 0.03906337637454271, 0.001386483046059896, 0.03168517657156501, 0.015955342146168863, 0.023140347762299434, 0.011687453570110458, 0.025791397650859187, 0.04328013564060841, 0.059473791159689426, 0.019448136777750084, 0.055970609853310246, 0.023207756823727062, 0.04511243464159114, 0.009855261438393166, 0.06780143108751092, 0.03159294330648013, 0.0644423570483923, 0.016724863621805395, 0.08848283240305525, 0.03486676959853087, 0.04772302348698888, 0.07813754824123212, 0.03943018562027386, 0.07507144526711532, 0.057570276515824456, 0.037863851990550756, 0.030639225018343756, 0.05777137393930128, 0.08350358637315886, 0.05826331182782139, 0.027116951432877352, 0.03470205861542906, 0.027752321446314454, 0.04585834140224116, 0.05358785271112408, 0.04112288621919496, 0.019911581284499595, 0.026889280881732702, 0.018035591413666095, 0.04419015966621893, 0.018477675638028553, 0.03403464139306119, 0.015114484587684274, 0.023430324791531478, 0.035688366940511126, 0.06199170569224017, 0.017310527552451407, 0.09066756588539907, 0.05836726339267833, 0.04949504482958998, 0.009686244302429259, 0.041685004984693866, 0.018903240927362015, 0.0379731707674052, 0.03600724107984986, 0.06018037681600877, 0.043418302333780696, 0.032020216807723045, 0.04775371362588235, 0.06525458382176501, 0.07355640549212694, 0.146145138623459, 0.166749790843044, 0.05828096730900662, 0.07119110705597059, 0.09363579018307583, 0.11731442995369434, 0.1406827960163355, 0.17867466381617955, 0.13449803074555738, 0.10698978682713849, 0.08727833096470151, 0.06862840921218906, 0.14990547113120556, 0.12359296876404967, 0.1376867653535945, 0.09822835946189505, 0.12500795855053834, 0.1072395419968026, 0.1649659222790173, 0.13227310084870883, 0.0885136853903532, 0.23174630744116648, 0.11011102755687066, 0.17095816002360412, 0.13454085987593445, 0.11096243972757033, 0.18498774005898408, 0.09113560577056237, 0.10155344568192959, 0.08515079798442976, 0.11332558042236737, 0.24507170383419308, 0.11223675563399281, 0.16642953588494233, 0.16862937355680124, 0.1689520576702697, 0.10810839251748153, 0.14067286226366246, 0.0875035503080913, 0.11460204049944878, 0.11230654974601098, 0.1042449769697019, 0.11847230925091676, 0.12780627767954553, 0.12651991099119186, 0.11965769635779516, 0.16595012375286647, 0.11871850889708314, 0.10929520454789911, 0.10772629587778024, 0.1798986867070198, 0.09151678638798849, 0.14866489198591026, 0.09915680571326188, 0.056109153133417876, 0.16160691609340055, 0.10752712549375636, 0.09811145466353212, 0.0973819073821817, 0.09312775744391338, 0.09723856007414204, 0.11185322728540216, 0.0739089519317661, 0.1070016815460154, 0.0828981160053185, 0.15597814241690294, 0.31161411319460186, 0.07995624600776605, 0.11990293248423509, 0.15134388394653797, 0.13453805074095726, 0.1150045067604099, 0.11705917865037918, 0.0873926030471921, 0.1100791839084455, 0.20700816916567938, 0.10304201580584049, 0.23357520358903067, 0.18984698717083248, 0.13256332384688513, 0.15862711598830564, 0.31090906102742466, 0.17554610169359616, 0.2216806204191276, 0.14070278565798486, 0.1266740741474288, 0.14188598788210324, 0.20708470791578293, 0.12448791574154582, 0.18620945593076094, 0.1196444784956319, 0.15941767713853291, 0.17887551018169948, 0.13180177685405525, 0.2576665080019406, 0.179314413773162, 0.07843540475836822, 0.0632352703916175, 0.09426787947969777, 0.09505927522799798, 0.11496616953185626, 0.14250012992748193, 0.13873929530382156, 0.19772943348756858, 0.07708974768008504, 0.15655955193298204, 0.10045322829059192, 0.17294879177851336, 0.18783457444182464, 0.20976749967251504, 0.07738982300673213, 0.1207521597721747, 0.1330560352653265, 0.18841427404965672, 0.0974633451551199, 0.12774888718766825, 0.09432578565818922, 0.11557314624743802, 0.0652590621528881, 0.08207333633410079, 0.08271454514137336, 0.10123342142573424, 0.1192020872341735, 0.09724489759121623, 0.15388387122324534, 0.09212828214679446, 0.17275051027536392, 0.19811456996415341, 0.11053769716194697, 0.13441755649234566, 0.20808276507471288, 0.1600242331624031, 0.12389118490474564, 0.17832164918737753, 0.059417907015553544, 0.14081846230796405, 0.18466414670859063, 0.1338830201753548, 0.13983484437423094, 0.12159324463989053, 0.16618843882211617, 0.16418043657072953, 0.1825814920344523, 0.1602033664073263, 0.1311924388366086, 0.12324177260909762, 0.20923440184976372, 0.06648645057742085, 0.11910144692020756, 0.10201867643211569, 0.13301555386611394, 0.08696061372756958, 0.10461840193186488, 0.1321177299001387, 0.14628115775329725, 0.15495307956423077, 0.14530811139515468, 0.06336475522922617, 0.07809163177652018, 0.08284341929746525, 0.15674624405801296, 0.09854419037167515, 0.09166155183421713, 0.12393942874457155, 0.11877983489206859, 0.09334961125361067, 0.10489970897989613, 0.08306895076696362, 0.15961612149008683, 0.1307981014251709, 0.10688582169158117, 0.1207332286451544, 0.08265261525022131, 0.09045042789408139, 0.16494681473289216, 0.16964281988995417], [0.04512032600385802, 0.03854550148493477, 0.014575076389259525, 0.022439287077369433, 0.09030841730002846, 0.02461271107728992, 0.009243679166372334, 0.029146892417754446, 0.02506420827869858, 0.010508610933486904, 0.025310482563717023, 0.07443333736487798, 0.0752632331901363, 0.06646832012172256, 0.026597590551578572, 0.03931683973808374, 0.06342109399182455, 0.027126718944470798, 0.06165735756180116, 0.010805082391016185, 0.043086617453289885, 0.016448063742635504, 0.04313427096764956, 0.07027215350951467, 0.012843899462105972, 0.036105316531445296, 0.03427570452913642, 0.0410072977787682, 0.005663244527698095, 0.03224800101348332, 0.01949923894634204, 0.025193048508039544, 0.04245116601565054, 0.025761784686307822, 0.014247761274288808, 0.016961752071178386, 0.012833700232606913, 0.07678866133626018, 0.05345433398282953, 0.052962073790175576, 0.027495517994144132, 0.03571012755855918, 0.03873263465772782, 0.07063352090439626, 0.008258520109978105, 0.04499867485303964, 0.02196885535626539, 0.01571220947828676, 0.00711993919685483, 0.05075836507603526, 0.041699087979005914, 0.05168118287942239, 0.00979473187388586, 0.03142708220652171, 0.021013362699055245, 0.010223820456303656, 0.041855391913226674, 0.024107920039179068, 0.019138848641887307, 0.06034100641097341, 0.044598542752542665, 0.015747981844469905, 0.04642407336671438, 0.03536229354462453, 0.052697149970169575, 0.001623419629010771, 0.02287808888857918, 0.03301545465365052, 0.03636498170505677, 0.03367462767554181, 0.05207004112058452, 0.02428146724456123, 0.034988380037248135, 0.047097668650427034, 0.08739223663828202, 0.02161193745476859, 0.0047152518028659475, 0.03682684352887528, 0.07068185295377459, 0.022888317803985307, 0.061857321831796847, 0.008575441764800676, 0.009941898485911744, 0.01801520143635571, 0.04417368144329105, 0.008019166033981102, 0.05328691903767841, 0.036451114940324, 0.004490578680166176, 0.029465725844992057, 0.011953682721858578, 0.022945219750649164, 0.024195681758491055, 0.06279646179505757, 0.011050349051531936, 0.031138073786028793, 0.013123385491780937, 0.0356192988609629, 0.021901938232726285, 0.024358750686847737, 0.04670937020065529, 0.05576352775096893, 0.05979735736868211, 0.022835280114252652, 0.04136432254953044, 0.011485102553186672, 0.016735173961413757, 0.040573808896754465, 0.043232125895363946, 0.033254265053463836, 0.03190504566633275, 0.02307979529723525, 0.04702789828713451, 0.0399820008315146, 0.01110346392462296, 0.052131316225443564, 0.04819920579237597, 0.007385948672890663, 0.029491347327296222, 0.030086972152015994, 0.05403814212019954, 0.04114709974133542, 0.05806439928710461, 0.024193408666178584, 0.02679011638143233, 0.03915092435532382, 0.030131175315805843, 0.0313558021028127, 0.029119252293769802, 0.022119978675618768, 0.05671407049521804, 0.01586735311762563, 0.03646617163238781, 0.07127863807337624, 0.08710611877696854, 0.03455329659794058, 0.017684592033869455, 0.03905839592750583, 0.0341081844110574, 0.058883961024028916, 0.04134565605116742, 0.07179803627410106, 0.0538399623973029, 0.030198628482009684, 0.055568102880248, 0.05197979935577937, 0.06394231066639934, 0.05986280207123075, 0.014910762930022818, 0.02194394463939326, 0.01719265753802444, 0.08123343890266758, 0.010402189501162087, 0.03580443374812603, 0.027579520629452806, 0.033782284041600566, 0.025520082030977522, 0.02296597613686962, 0.05493189487606287, 0.03978677273594907, 0.052492262928613594, 0.027540554059669375, 0.031263460272124836, 0.038934444542974234, 0.025231872585469058, 0.00766696988804532, 0.021565111753131663, 0.020734874964026467, 0.015842111614931906, 0.0792500606871077, 0.04899958873699818, 0.05196371129048722, 0.023116164774234806, 0.04404574366552489, 0.02074086303556604, 0.009999701187812855, 0.06351712026766368, 0.06268073764762708, 0.01066509128681251, 0.053479388888393126, 0.015016989283529776, 0.010595327708870173, 0.041523462760129144, 0.011088392813690007, 0.04758507053234747, 0.04200060858524271, 0.04966131644323468, 0.043244353096399984, 0.04079703673986452, 0.02187905294288482, 0.0041141367816765395, 0.0548080283084086, 0.03189838584512472, 0.06747441113527332, 0.012308308023161121, 0.027213997207581997, 0.029977538024208376, 0.05144530375088964, 0.014792027783447077, 0.014164975761169834, 0.048072129754083495, 0.00519659394298547, 0.02425097388082317, 0.02271306069035615, 0.027592480648308992, 0.07054360144372497, 0.029283308490578617, 0.051655025354453495, 0.02383189708260553, 0.05500266947118299, 0.025851977257324115, 0.03415290326146143, 0.027134053908022385, 0.0702950337103435, 0.025388950049611073, 0.006229227550128209, 0.01582053759401398, 0.039781507304204364, 0.06926067492791585, 0.054337471058326106, 0.017419685177238922, 0.055443649379802604, 0.011381732832108225, 0.05269150795148952, 0.043568709798689396, 0.03088390135339328, 0.001366614586524, 0.025924817991576025, 0.017100163036957383, 0.009168815549596079, 0.03952139429748058, 0.03174747287162712, 0.08204681240022182, 0.07792641528482948, 0.04656088638252445, 0.0335211125202477, 0.0360925125756434, 0.008394766549047614, 0.0073322553486962405, 0.040725678604628356, 0.04433407694367426, 0.0324052990015064, 0.029248428397944996, 0.02493977513430374, 0.03891837004838245, 0.041683936292039495, 0.0251818730362824, 0.012576305606801595, 0.08987587836704083, 0.04999207851610013, 0.05883602931031159, 0.018086639299456562, 0.04748145823499986, 0.01147154118267021, 0.02316254942810961, 0.022954154360507215, 0.0641463597172073, 0.05752775951155594, 0.04873258520716003, 0.021272093190678527, 0.012083495800782527, 0.018476303300953338, 0.04678049763398511, 0.04290501094822373, 0.026712293503805995, 0.026099118370828883, 0.025120301072352698, 0.030895036113049303, 0.01709021910625909, 0.05843044857361487, 0.03503888679136123, 0.037117300621633015, 0.014059953807320977, 0.019414366089871953, 0.03137849909918649, 0.03786709878061499, 0.031545551028102636, 0.010641150026848274, 0.005981951577788485, 0.035891211591660976, 0.023315850844872848, 0.015148268846262778, 0.028821728258792843, 0.05632263382098504, 0.028959755852286304, 0.029460942173110585, 0.07556569017469883, 0.037284067565841336, 0.01095341777961169, 0.014249047098149146, 0.010595437970810702, 0.05156956726152982, 0.05453381534399731, 0.028345591754519513, 0.01347145190395947, 0.009274302299932709, 0.04583747984309282, 0.03020413140101092, 0.01369577897379973, 0.014165780673335706, 0.014948316450629915, 0.04354872015704002, 0.06305237806269101, 0.007431535199949784, 0.023533034637304287, 0.058985876983829906, 0.03436991572380066, 0.012668000284715422, 0.07308970232095037, 0.07722622821373598, 0.05771403094487531, 0.02884365851059556, 0.020632923381136994, 0.03552218014374375, 0.055157830073897324, 0.08728800008871726, 0.035057207236864736, 0.06671244345073189, 0.026877803461892263, 0.015095417753660252, 0.06646686805678265, 0.03292265820450016, 0.03238753495471818, 0.047522669059357474, 0.02041669123406921, 0.017184331913345625, 0.04807008057832718, 0.044118486012199094, 0.027187208645045757, 0.07784803091947522, 0.009152247420778232, 0.04237311752513051, 0.03288259071164897, 0.025310136510857513, 0.09109539578535727, 0.008220594243279524, 0.01433986222504505, 0.040060398767569234, 0.04429134280819978, 0.04482478329113551, 0.029308471961745193, 0.0744481294282845, 0.009233523193480713, 0.023202359077653716, 0.0064464032849563015, 0.016013326356187463, 0.014856961888394185, 0.04888037691957184, 0.05055813957005739, 0.05230175743677786, 0.018968777232138172, 0.0197860438243619, 0.10412787539618355, 0.2052842288144997, 0.07302389120949165, 0.13259977474808693, 0.13677359292549746, 0.08603374167744603, 0.08066972557987485, 0.12218343439911093, 0.15804559790662356, 0.1268860213458538, 0.1289555531527315, 0.23225252170647892, 0.2517244411366326, 0.13207624426909856, 0.16247310675680637, 0.0942457728087902, 0.13433347243283475, 0.2141534686088562, 0.07969140700463738, 0.09078883366393191, 0.11089293738561017, 0.19685005210340023, 0.10303831100463867, 0.12489266188016959, 0.14956530795565673, 0.10434694721230439, 0.06143173788275037, 0.11573607607611588, 0.09165517360504184, 0.2083302675081151, 0.12365931591817311, 0.09080545098653861, 0.11353894575898137, 0.13151778280735016, 0.1333210031901087, 0.06828844281179564, 0.07088219720338072, 0.2239554633519479, 0.09914432745426893, 0.11228933531258788, 0.07157318333962134, 0.12136968092194625, 0.12977192577506813, 0.1710378878882953, 0.10914965200104884, 0.17636315285095147, 0.04518319905868598, 0.0844252472743392, 0.16342692343252047, 0.1143966479493039, 0.1530594647462879, 0.10530736603374992, 0.1267266741820744, 0.08971959139619555, 0.11898931222302572, 0.08989998671625342, 0.11099249204354626, 0.14281110252652848, 0.2020356474178178, 0.12806996995849268, 0.18742927190448555, 0.06990491678672177, 0.1797551629798753, 0.10013348223375422, 0.19179394841194153, 0.07855351056371417, 0.08373077346810273, 0.09486025412167821, 0.08392733827765499, 0.16198560648730823, 0.20551161946994917, 0.07059886812099389, 0.10528344767434256, 0.15172906113522394, 0.16146865779800074, 0.09400152734347753, 0.0915605586820415, 0.1489733811467886, 0.15581594540604524, 0.09908623128597226, 0.1865813745451825, 0.14367334411612578, 0.11851482625518527, 0.14258083488259995, 0.11017706937023572, 0.12888285491083348, 0.20212583829249653, 0.1362701877951622, 0.09356111061892339, 0.14248313941061497, 0.15742657040911062, 0.102686219183462, 0.06826022932572023, 0.17260390599923475, 0.07387783431581088, 0.1682396773248911, 0.09465309738048486, 0.10831772735608475, 0.12406142934092454, 0.07572371419519186, 0.08078429621777364, 0.07672650752855198, 0.13329221973461763, 0.1379516382834741, 0.12899332041186945, 0.1582555773534945, 0.1718208087342126, 0.1347915649946247, 0.07585029490292072, 0.09511680142687899, 0.16889223802302564, 0.07411827319966895, 0.09730021176593644, 0.11652423521237713, 0.058758262411824295, 0.11175559288156883, 0.1466681534158332, 0.16845161095261574, 0.15111068503132888, 0.14639823218541487, 0.13223424793354102, 0.1798658049000161, 0.1480984916644437, 0.06562104022928647, 0.11201380259756531, 0.0941329188644886, 0.25022783715810093, 0.1225346169833626, 0.09823811001011304, 0.16064437345734664, 0.1030248420845185, 0.12790488238845552, 0.17839186399110726, 0.22304516791232995, 0.13486373397920812, 0.08170254408781018, 0.08857472640063081, 0.09473655040242843, 0.1089738639337676, 0.1960146805005414, 0.13597054673092707, 0.16856663620897702, 0.1107757001050881, 0.1126519376412034, 0.17442199986960205, 0.11691329362136976, 0.12246661420379366, 0.09435370058885642, 0.14882316706436022, 0.1106303579040936, 0.09616083611867257, 0.1263872031122446, 0.16323660793048994, 0.16383951343595982, 0.08638966043612786, 0.11678026004561357, 0.11481136855270181, 0.09403147787920066, 0.14418046761836323, 0.09730365872383118, 0.10076498120490994, 0.09606366990400211, 0.1468746859048094, 0.162835458027465, 0.0806175869490419, 0.12579073011875153, 0.07980950602463313, 0.11423526518046856, 0.12216410972177982, 0.16059523395129613, 0.13016979156860284, 0.10949339105614594, 0.11829825144793306, 0.13564574558820042, 0.07058606416519199, 0.10003476217389107], [0.0484469966031611, 0.03715991262080414, 0.07850261365196534, 0.023844826567385877, 0.0833420136145183, 0.040775272729141374, 0.042985871966396055, 0.03931034955063036, 0.0540141185878643, 0.04215838833312903, 0.07067006001515047, 0.03412692554827247, 0.038787236370678456, 0.014775332429313233, 0.020725355117714832, 0.04061851417645812, 0.0322539348022214, 0.016252805112994144, 0.04093598374830825, 0.044673578547579904, 0.034451753832399845, 0.037438437675258944, 0.02848168382687228, 0.06876763102731534, 0.0432638236587601, 0.035781411054943285, 0.03024174938244479, 0.010181471389452261, 0.027518018215362514, 0.040202243120542595, 0.041915781529886384, 0.022403418019946133, 0.055481158795633485, 0.052116748078593185, 0.007168836974804955, 0.006636295974853316, 0.025898551901004145, 0.01864028994792274, 0.046515356682773144, 0.05070118832268885, 0.05219929864896195, 0.04094084545171686, 0.035773726645857096, 0.01789369956324143, 0.007268830135996852, 0.012374052977455514, 0.07517414154218775, 0.06461095942982606, 0.025029509694182446, 0.024078378320804665, 0.02070969283314688, 0.03976280687909041, 0.01661986032766955, 0.01641737699641713, 0.08614134376070329, 0.05008720573303955, 0.01614460931159556, 0.07002365362963506, 0.05059891952467816, 0.04060773904036198, 0.03152467929092901, 0.052589792159519026, 0.022234822423862557, 0.022355691563071947, 0.03373023022764495, 0.05495219664382083, 0.053255238237657716, 0.052027571613767316, 0.060744741532419405, 0.006090443390088954, 0.0438094302745802, 0.03489498647728136, 0.041784342511423996, 0.017943945081372346, 0.0373008002394012, 0.014594170364684292, 0.046477738701339276, 0.049279335154486556, 0.03322536963969469, 0.03444514490131821, 0.017418233112299016, 0.04205299488135746, 0.05429884545238955, 0.0037476417824759013, 0.021797778018351113, 0.05293541754196797, 0.01535945778180446, 0.0351250505607043, 0.03609856850068484, 0.007445117774685579, 0.015151217080918806, 0.02484758597399507, 0.03359441805098738, 0.008584395882540514, 0.06004298026008265, 0.07023351094020264, 0.011147530533240309, 0.05724671709218195, 0.019421024214742438, 0.016061543054612618, 0.013819675227361066, 0.0421373673182513, 0.0625939258773412, 0.029301798569836786, 0.019520594139716456, 0.04352414361866457, 0.018671785847150853, 0.026382769757349576, 0.015737076090382676, 0.04590311114277158, 0.024209703684651425, 0.015359708839761359, 0.02931575264249529, 0.014409237341689212, 0.04206308130440967, 0.046344986717615805, 0.06226597633212805, 0.00918623015084969, 0.03644460439682007, 0.04690579251785364, 0.01541229191103152, 0.03381383931264281, 0.04425758229834693, 0.05523192270525864, 0.021241106192714403, 0.016442677870924984, 0.051460302767476866, 0.04946614263047065, 0.05330467290644135, 0.02316928728084479, 0.04913438989647797, 0.04218226258776017, 0.02341926975974015, 0.052771944885275195, 0.043555668355630975, 0.037446746336562295, 0.026301437157339284, 0.01584870188630053, 0.05317373261121767, 0.021654049034363458, 0.07503888915692057, 0.0646000960841775, 0.037129989226481745, 0.06311171595007181, 0.02527714444191328, 0.042985519128186364, 0.022141311816605072, 0.009242709709464439, 0.016577964182943106, 0.02577393894482936, 0.013826964389798897, 0.058040976258260865, 0.020934493181162646, 0.052173829837036986, 0.04244863508003099, 0.014566788084006735, 0.030633335334381888, 0.02516281129127102, 0.06600240405116763, 0.02844542800448835, 0.054948780220001936, 0.02882337031353797, 0.015112199621008975, 0.008712059701792896, 0.021763939476971115, 0.018548487552574704, 0.027126318608809794, 0.058404514965202124, 0.07213641490255084, 0.016734641311424117, 0.006431616310562406, 0.019855474920145104, 0.0509070456693215, 0.05585140482123409, 0.026561407671709145, 0.03845339374882834, 0.0494096919095942, 0.001837987032818741, 0.06182470465345042, 0.0015674807779890085, 0.03242106815533979, 0.028123122174292803, 0.02701485396495887, 0.041929589717515876, 0.03641885399286236, 0.06877594308129378, 0.038894638286105225, 0.030955137352326086, 0.020743680652230978, 0.058474824763834476, 0.019329927495813796, 0.03535657688709242, 0.07125632105661289, 0.02485360627594803, 0.04067497507535985, 0.012210137576663067, 0.03739530320412346, 0.03316930568377886, 0.007095920329447836, 0.07913856381284338, 0.011327893622884793, 0.007471418640177164, 0.028778827882238796, 0.023501499722312604, 0.030302844675523893, 0.027799783274531364, 0.03034101566299796, 0.009136468088919563, 0.01979630666651896, 0.02158427527839584, 0.018013058962034326, 0.06878872668104512, 0.03010349108704499, 0.02521472261287272, 0.018184704573026726, 0.015370073462171214, 0.04995171586051583, 0.025414542694176947, 0.001285986602722135, 0.041330365264522176, 0.030125292417194163, 0.06676577630319766, 0.06397559959441423, 0.024117244806672846, 0.013822620069342, 0.01418617065064609, 0.021166145036529218, 0.029916178102471998, 0.011992532244351293, 0.03750729540895138, 0.04170937117721353, 0.0015191450178722984, 0.01332914360266711, 0.024640310489173447, 0.09474144263991288, 0.07932578519518886, 0.011090944953528898, 0.04246040087725435, 0.03760062111541629, 0.010666344880259462, 0.00522884344016867, 0.06899703014642, 0.05158160786543574, 0.004515275658507432, 0.017587737945307578, 0.05576834874227643, 0.032564452782805474, 0.00552583991416863, 0.0652371726131865, 0.027287896456462995, 0.00838920341006347, 0.03913418150373867, 0.04992022844297545, 0.01641152972089393, 0.036361857051295896, 0.07445103355816432, 0.03076306783727237, 0.04869625983493669, 0.043425521946379116, 0.034673346406114955, 0.044824009761214256, 0.05296270143506782, 0.02043326954091234, 0.02660439456147807, 0.043296756355890205, 0.01867144488330398, 0.04622503529701914, 0.01681434203471456, 0.03692890876638038, 0.036972959259791036, 0.012891731091908045, 0.024762504468006746, 0.019377754036603228, 0.06638950827930655, 0.04298623498263104, 0.050561756161706786, 0.03235811706898468, 0.06292680158678975, 0.014313458731131894, 0.03503145004755684, 0.013036222579622907, 0.012563631420822015, 0.025737538933753967, 0.05657366124380912, 0.06202584278902837, 0.016148103766941597, 0.014045652833634188, 0.09417670472924199, 0.04063695675826498, 0.05349228444642254, 0.01699803164228797, 0.041447629686445, 0.04693679478285568, 0.04649484456915941, 0.03791460980262075, 0.022450279344671538, 0.035874689263956885, 0.022787701238745024, 0.012835061543488076, 0.06979301957679646, 0.012824110836455864, 0.04539484091635261, 0.027892316791361997, 0.033670729491859674, 0.04048138224918928, 0.039170924174998484, 0.011652414021747453, 0.06012642649667604, 0.040819740521588495, 0.021913783757814338, 0.05102774008576359, 0.026091596810147166, 0.02462082974878805, 0.03355034041617598, 0.03655009623616934, 0.07318328587072236, 0.012894321399341737, 0.03532037025849734, 0.05020076535376055, 0.04092428241191166, 0.011523092880712023, 0.045984253752976656, 0.07629521031464849, 0.021441530170185224, 0.02205958396994642, 0.03197054125900779, 0.01706977654248476, 0.07225387609962906, 0.019881966623610685, 0.10573794400053364, 0.04071373978097524, 0.030488671668406044, 0.0332214985974133, 0.05423438462561794, 0.043426695811961374, 0.03022465369264994, 0.043890175941799364, 0.06651465049279587, 0.0818710175475904, 0.0169884524241622, 0.054135783309383054, 0.008276557267111326, 0.10673171960349594, 0.042272436499063454, 0.041940887325576375, 0.009774155299445348, 0.0434564529652042, 0.03641215006687811, 0.05421314308685916, 0.03065659890749625, 0.019186949989359294, 0.02303986860040043, 0.22730148237730774, 0.07697604556701013, 0.18649400637618133, 0.14266172982752323, 0.10802202858030796, 0.09585312048771552, 0.06561980529555253, 0.09239210334739514, 0.12571120581456594, 0.09762202735458102, 0.10201250854879618, 0.12074495373027665, 0.12786567663507803, 0.11954443529248238, 0.2149665164096015, 0.14003509362893446, 0.1397647245654038, 0.13148981359388145, 0.11229456681758165, 0.10737653143171753, 0.22530633157917432, 0.11867724039724895, 0.08661857779536929, 0.24365207286817686, 0.09320682712963649, 0.16052413705204213, 0.09497408515640668, 0.08563221858016082, 0.11356002105666058, 0.11806858091482095, 0.14144804781036718, 0.10490378697535821, 0.1247332604335887, 0.09150354138442449, 0.08669022430798837, 0.11058825480618648, 0.13425496593117714, 0.1023697911628655, 0.12412567303649016, 0.11571292446127959, 0.2639874145388603, 0.0999518655506628, 0.1457347742148808, 0.14495181265686238, 0.059181050796593936, 0.13867663938019956, 0.18714957976979868, 0.17566711162882193, 0.09623262512364558, 0.06583364560667958, 0.1256431351814951, 0.07733206610594477, 0.06814400306237595, 0.08571336458304099, 0.14794055585350308, 0.09639846586755343, 0.10725737389709268, 0.1698652436690671, 0.12176074779459409, 0.16072072221764497, 0.0941822212189436, 0.15830338693090848, 0.1303032458360706, 0.1087931836290019, 0.08266423176974058, 0.17629528577838624, 0.15758427551814488, 0.09690961308245148, 0.1151218797479357, 0.12076159140893392, 0.10713926809174673, 0.19491712296647684, 0.1474605601813112, 0.12519843690097332, 0.07548731938004494, 0.1380283941647836, 0.1638678897704397, 0.13270851677017553, 0.11366461722978524, 0.1235702106995242, 0.15125574224761554, 0.16223027264433248, 0.12716612060155186, 0.08196337973432881, 0.129937366183315, 0.1633366918457406, 0.18155452928372792, 0.08943398922149624, 0.21591886744967528, 0.1254041822893279, 0.1620343660137483, 0.11902353752936636, 0.164648300036788, 0.19869515166750976, 0.1407620081944125, 0.15865838288196496, 0.14164620717721327, 0.15432449829365524, 0.14259492126958712, 0.11882369539567403, 0.16584096103906631, 0.11892966899488654, 0.1261627844401768, 0.1586532260158232, 0.12218684064490454, 0.12815879019243376, 0.11747740049447332, 0.11882115767470428, 0.0897000835144094, 0.14468270566846642, 0.10879320398505245, 0.18308169447949954, 0.13508036306926183, 0.11720101961067744, 0.06837841655526843, 0.15314147248864174, 0.06920620892196894, 0.13945095640208038, 0.09349960141948291, 0.17177715179111275, 0.10344402744833912, 0.11462865264288016, 0.1458538028278521, 0.23386903639350617, 0.10174036850886685, 0.22201521960752352, 0.14284725487232208, 0.18834499562425272, 0.1417092430804457, 0.2716835487101759, 0.13377446814307145, 0.12351556148912225, 0.24756941837923868, 0.12200565822422504, 0.2093653862497636, 0.0941136891820601, 0.05922806648803609, 0.10971996068422284, 0.10681155603379011, 0.15118516103497573, 0.17913122288882732, 0.14206687174737453, 0.15962134620973042, 0.12058931136769907, 0.09488713089376688, 0.10689405232135739, 0.20677313820591994, 0.08094063068607024, 0.09429742289440972, 0.13030648923345975, 0.03885663014703563, 0.1848615596869162, 0.15790115137185368, 0.14805881093655313, 0.1323239231216056, 0.09788594355008431, 0.08325091350291457, 0.1566489285656384, 0.15692642224686487, 0.10359648748167924, 0.13341882079839706, 0.13786009033875807, 0.12792750474597725, 0.07022334648562328, 0.09638530228819166, 0.11005173038159098, 0.2726251653262547, 0.12459393005285944, 0.18676128132002695, 0.13354690106851713, 0.15204867827040808, 0.09592592729521648, 0.13014212091054234, 0.10068350271987063, 0.13826394081115723, 0.1252400582390172], [0.010123346383417291, 0.02694668833698545, 0.008294521481730044, 0.03935244586318731, 0.007169789468337382, 0.01718707149848342, 0.039371427880334, 0.0292187560615795, 0.06639166602066585, 0.07489868346601725, 0.02297127040635262, 0.016401158313133886, 0.05504240448187504, 0.029416342066334825, 0.042018840821193795, 0.022271800886041353, 0.07797111717185803, 0.03731550070058022, 0.05089771920549018, 0.04258539042036448, 0.0334932009822556, 0.053437862545251846, 0.007231058636015015, 0.04492231930739113, 0.019655091654775397, 0.03635281217949731, 0.01051494081704212, 0.022834562563470433, 0.018298997011567866, 0.01838717602991632, 0.008172821985291583, 0.02771056440126683, 0.003663363916400288, 0.0643263818430049, 0.05779063754848071, 0.07278443620141063, 0.03555187962150999, 0.07999197766184807, 0.049191614147275686, 0.029701238564614738, 0.004333082644734532, 0.022860747229840075, 0.016790684911289384, 0.08152208091425044, 0.06668092549911567, 0.03621740373117583, 0.039687197721962414, 0.04365423574511494, 0.02914051418857915, 0.018484496611303518, 0.09824646956154279, 0.025392878767369047, 0.03135643992573023, 0.03518844608749662, 0.025434096377076845, 0.06376191534634147, 0.09120259753295354, 0.03114469289513571, 0.026141408065866147, 0.03171798034704157, 0.05410217546990939, 0.02767905662767589, 0.010817080586483436, 0.03426811172227774, 0.07114330426390682, 0.03280580090358853, 0.029694653382258754, 0.02676465774753264, 0.005919367748512221, 0.11302340842251267, 0.05720009495105062, 0.004867593940746571, 0.037829650432935784, 0.05487667569624526, 0.03907476897750582, 0.0358370780678732, 0.026666577206924558, 0.08013957938445465, 0.023020990059844086, 0.037038166475083144, 0.00991826765571854, 0.027861767448484898, 0.08891478101057665, 0.02516897238924035, 0.03347380505874753, 0.03596880885639361, 0.03528483198689563, 0.018246807490608523, 0.012412815986733352, 0.06694514703537736, 0.022968554569940482, 0.018544675882107446, 0.11477182353181498, 0.054132790969950814, 0.02905453023101602, 0.053691912841584, 0.008734742279297538, 0.022786461215998446, 0.05281405816120761, 0.07017856995974268, 0.045271754663969786, 0.03477588322545801, 0.028855230925338607, 0.02086539287120104, 0.04203129872413618, 0.012476369272917509, 0.014215543583434607, 0.05459425924345851, 0.0473928822736655, 0.015513142570853233, 0.08535320498049259, 0.034225000999867916, 0.09557053779384919, 0.04227423122418778, 0.08642797052328076, 0.031162874240960394, 0.06037686698670898, 0.047311441108052216, 0.016555859208373085, 0.027125429727935364, 0.06715157774410077, 0.03865544790668147, 0.01711138939884092, 0.010008414425621075, 0.012428138155623205, 0.03246616359267916, 0.04407200636342168, 0.039756740776023695, 0.0189693421125412, 0.09060467247452055, 0.07835768535733223, 0.03382178156503609, 0.05566553372357573, 0.05928671226969787, 0.02646312696327056, 0.03299379242318017, 0.051525180893284936, 0.010231118948597993, 0.05220169387757778, 0.04706690048000642, 0.033216711532856734, 0.011795386439189315, 0.007616785438066083, 0.030728194529988935, 0.018853182006361227, 0.04281363602993744, 0.03886514576151967, 0.06520509826285498, 0.004532811547895628, 0.048319537192583084, 0.07938377958323274, 0.05421943989183221, 0.029441916051187685, 0.044094954417752366, 0.030202452026839768, 0.021408015629276633, 0.05857085782502379, 0.004467531814173396, 0.019044952966006737, 0.06163366311894996, 0.051431560024086914, 0.0009792186943481543, 0.007429396118303495, 0.020344401809519956, 0.08514709996857814, 0.07034149300307035, 0.028769576057259525, 0.013258875364304652, 0.018737954885831902, 0.015402578682239567, 0.021830971951463392, 0.05286367603444627, 0.021422174958778278, 0.03854816812755806, 0.0069805927009188706, 0.020726837716730576, 0.035166044253855944, 0.031543247401714325, 0.005616239438365612, 0.026422757522336075, 0.05214858154899307, 0.06546667351254395, 0.052296210413000414, 0.05218981612207634, 0.04277160078553217, 0.031035411437707286, 0.03200518386438489, 0.007141972077079117, 0.04091682191938162, 0.09688501618802547, 0.04722831717559269, 0.037203942758164237, 0.017543339702699865, 0.03812735427969268, 0.045336558150925806, 0.017004153724493723, 0.04944145413381713, 0.025867062787126218, 0.03460359300619789, 0.0882076525262424, 0.020241976948454976, 0.059280910795288425, 0.04021562722378543, 0.05970561943416085, 0.025841675399403487, 0.03529127806957279, 0.02068325032347015, 0.02063046538803194, 0.023613827801974754, 0.045960230220641406, 0.055351680743374994, 0.10418363740401608, 0.012756018150996948, 0.04065642053527491, 0.020340415416285396, 0.01445561521021383, 0.039677884828831465, 0.07588918174483947, 0.06349077275288956, 0.0252437757860337, 0.022654967914734567, 0.06324848146843058, 0.03858957911974617, 0.04114580373944981, 0.027584950605939542, 0.06659375410526991, 0.06258362571575812, 0.047944507495101006, 0.024441747393991266, 0.025868754035660198, 0.007628522397551153, 0.03274514326559646, 0.025851605759401406, 0.030976548524839536, 0.009834313366029943, 0.045453853106924465, 0.07598097396216222, 0.013807956927589007, 0.03625419729256204, 0.04802870351289, 0.01854839764668473, 0.01571132568642497, 0.03281382118750896, 0.012418530947927917, 0.01825004070997238, 0.03733911711190428, 0.009381370885031564, 0.03213944558852485, 0.01857943892745035, 0.04188738823203104, 0.02147052906054471, 0.029265744611620903, 0.03551593762157219, 0.032005699550999064, 0.0410338047492717, 0.015562431354607855, 0.01012196556465434, 0.026858248082654815, 0.013103629096544214, 0.03969078377953597, 0.029583614519132034, 0.02419258763880602, 0.024667762319690416, 0.031230340977864604, 0.1060644889782582, 0.039754698385617564, 0.009680099319666624, 0.030014005888785635, 0.05026682413050106, 0.005854034156072885, 0.11257529711084706, 0.031872126539903026, 0.04006901276963098, 0.026410046865099242, 0.061240682777549536, 0.035002653021365404, 0.025164909660816193, 0.029492239600845745, 0.030491205996700695, 0.029080677577959638, 0.04056452993037445, 0.027078274936814393, 0.0365650240065796, 0.02897100935557059, 0.05456361320934125, 0.01626914253990565, 0.05800788410540138, 0.02196846350229212, 0.031563793442079, 0.045958136940108876, 0.016808460832440426, 0.01388498507107475, 0.08918447832443885, 0.009379107122575598, 0.019124696097735847, 0.019532828126102686, 0.036289657532636604, 0.030721005451466357, 0.04293989782620754, 0.048712191837174554, 0.034574249759316444, 0.08081098978540727, 0.023439714019852023, 0.07336898054927588, 0.041160534734704664, 0.03641734764512096, 0.0501178551598319, 0.02724573907575437, 0.03151911869645119, 0.013874636563871588, 0.047821017514382086, 0.009561840843941485, 0.12510281774614537, 0.027122208382934332, 0.01889281184412539, 0.12293797891054835, 0.020848390479971255, 0.026170652925169895, 0.018599779710971882, 0.036827915614204745, 0.041588005011102984, 0.025846625312364528, 0.07118124794214964, 0.032850173701133044, 0.01713785226456821, 0.006896798291044044, 0.03760204264628036, 0.02780446346982249, 0.019258240271093588, 0.02255087046484862, 0.010260496970399149, 0.030623099633625576, 0.02563924465461501, 0.017338315257802606, 0.04654827241652778, 0.018687463398756723, 0.030871202570519278, 0.012589906841250402, 0.050421486009976695, 0.037238432693162134, 0.06217911706439086, 0.05609700057123389, 0.05151910800486803, 0.032074618352843184, 0.021841356929923807, 0.022139388169827204, 0.03872751171833702, 0.07632178174597876, 0.0168345555929201, 0.03250180703720876, 0.04622508279447045, 0.0029227160141869846, 0.10845783805208546, 0.05337964763332691, 0.17391341073172434, 0.0687389357813767, 0.09968729117619139, 0.13128664663859776, 0.12633026045347961, 0.11157069887433733, 0.10892072785645723, 0.139469426125288, 0.12114838351096426, 0.13084417395293713, 0.12608889197664602, 0.12198421651763575, 0.10763941625399248, 0.10592650888221604, 0.09325517953506537, 0.11940680124929973, 0.0787970774940082, 0.13044292905500957, 0.07226792855986527, 0.15732795212950024, 0.12472610867449216, 0.18828224470572813, 0.09144784044474363, 0.1517191952360528, 0.1214009342449052, 0.10396083364529268, 0.11450153589248657, 0.1913376743240016, 0.10956339551401989, 0.13379766047000885, 0.19388156996241637, 0.17717934905418328, 0.11345285323581525, 0.25143970070140703, 0.16898029829774583, 0.21372468875987188, 0.16275548589016708, 0.05944557088826384, 0.11075230421764509, 0.06433725197400365, 0.1748734020761081, 0.12612778560391494, 0.17638759368232318, 0.10721942343349967, 0.17618001624941826, 0.1275841524558408, 0.10419887051518474, 0.12123622665447847, 0.17761255295148917, 0.10313213204166718, 0.10829380221132721, 0.13146925398281642, 0.12827312334307603, 0.14938544189291342, 0.22980982278074535, 0.12354405995990549, 0.11430588710520949, 0.15642147005668708, 0.17959378021103994, 0.14993038693709032, 0.10684713841016803, 0.1841804055230958, 0.13324994700295584, 0.11143614538013935, 0.18570324166544847, 0.11494532493608338, 0.08505738406841244, 0.15771198937935488, 0.1862453640039478, 0.1262579693325928, 0.119369916085686, 0.16585461316364153, 0.22287386496152195, 0.22693846614233085, 0.22122559483562196, 0.18005305342376232, 0.1889590426747288, 0.13372863988791192, 0.12601295033735888, 0.1335754266807011, 0.16796468065253325, 0.16159384750894137, 0.079517288133502, 0.09377486272049801, 0.14547641522118024, 0.0859912314585277, 0.17011346534958907, 0.16398030945232936, 0.11605909945709364, 0.11521378053086144, 0.21442387838448795, 0.1298520743314709, 0.1519024268324886, 0.1493151592356818, 0.10567298784319844, 0.10677978702421699, 0.11518366714673382, 0.10766507844839777, 0.13500547994460377, 0.07860376286719527, 0.07374882445271526, 0.19605396767812117, 0.1423808163298028, 0.09060051305485622, 0.12175032549670764, 0.18883294372686318, 0.15313730628362723, 0.1396901264254536, 0.1457959780735629, 0.08223038326416697, 0.18501150235533714, 0.12645901925861835, 0.14314940651612623, 0.08914513007870742, 0.3205437697470188, 0.21608425357512065, 0.14293000900319644, 0.1252758577466011, 0.18356543566499436, 0.10549725405871868, 0.1085113405383059, 0.14047711848148278, 0.1256978658160993, 0.20403295595731052, 0.10510126102183547, 0.1106543576877032, 0.12641815787979535, 0.21704102866351604, 0.09504577238112688, 0.1508625312043088, 0.1321515209440674, 0.13292693719267845, 0.11554942466318607, 0.07195633849395172, 0.11158980642046247, 0.10312698874622583, 0.1510867734572717, 0.17575373340930256, 0.19149338454008102, 0.12722450175455638, 0.07478616200387478, 0.11317554954439402, 0.08670426319752421, 0.11456240048365933, 0.1581216345408133, 0.233895227845226, 0.06885777440454278, 0.11633761094084807, 0.20646577541317257, 0.10046059718089444, 0.10517587273248605, 0.12194400653243065, 0.1373159731073039, 0.10894928061004196, 0.11600119327860219, 0.11702939096306052, 0.1434838699975184, 0.10107838295932327, 0.15051904320716858, 0.07595985795238189, 0.11141642036714725, 0.1235983699027981, 0.18997498601675034, 0.22975893265434674, 0.13560842616217478, 0.1008131436205336, 0.1157832071185112, 0.08653586437659604, 0.1670292115637234, 0.18558652007154056, 0.09998077114245721, 0.12440464592405728, 0.138775515503117, 0.07098405209503003], [0.10062245492424284, 0.008453825388901999, 0.0518725026132805, 0.060211446934512684, 0.09035178925842047, 0.07156187894621066, 0.019396040555355803, 0.036080583930015564, 0.013413762008505208, 0.04640550186325397, 0.016295557908181633, 0.04916458470480783, 0.0295615417749754, 0.029596170809652125, 0.024471297594053403, 0.021751759773386375, 0.03524308851254838, 0.015885824537170783, 0.022776876908860037, 0.04993030468800238, 0.039079596754163504, 0.037278659641742706, 0.058142329033996375, 0.026891594686146294, 0.08323020461414542, 0.008460095900643085, 0.04644252273387142, 0.03870222611086709, 0.014363841652604086, 0.024596232854362046, 0.023713874397799373, 0.056722949125937054, 0.034876398010445495, 0.0504188193673534, 0.020363860497517244, 0.013887032550493521, 0.047778235881456306, 0.06294003301965338, 0.027024947173361267, 0.03440993232652545, 0.08446306203092847, 0.049876608819301636, 0.05970375346285956, 0.05520156504852431, 0.020105314906686544, 0.05848019876118217, 0.03958059987053275, 0.007379641689892326, 0.030485994847757474, 0.028660277636455636, 0.013135217446168619, 0.021382460304136788, 0.04847973591781088, 0.006702656275592744, 0.056294118386826346, 0.026737063424661756, 0.056006616314074824, 0.02237726728032742, 0.013776882568241229, 0.024899736479190842, 0.018831755566809858, 0.0468587666483862, 0.04125466111249157, 0.0737570347264409, 0.06446063678179469, 0.03583861155701535, 0.0070453160359258095, 0.04646816796490124, 0.08989872464111873, 0.030159941807921444, 0.04713977514100926, 0.014600558771884866, 0.07825088394539696, 0.06399151124060154, 0.04832366607817156, 0.03728155359359724, 0.010508649101081704, 0.03585707449487277, 0.017232623250622834, 0.0786779403154339, 0.06695970839687757, 0.048149482746209414, 0.03435821099472897, 0.03480772687388318, 0.05447637056931853, 0.04186332059491958, 0.030118859905217375, 0.032066123094409704, 0.02563709539494344, 0.03337820625997015, 0.02611316234937736, 0.06462315270411116, 0.014906308347625392, 0.026001758773678114, 0.04188097268342972, 0.051066023031515737, 0.03916938390050616, 0.010412152091573392, 0.03338464216462203, 0.03074666764587164, 0.022727616962843707, 0.01636606448196939, 0.025846901815384626, 0.053018120782715936, 0.010943182078855378, 0.049032562146229405, 0.06064100031341825, 0.05937769024499825, 0.11435877212456294, 0.04813412071338721, 0.026645206746512225, 0.04783030665878739, 0.03043284180707165, 0.05242210580036044, 0.022860165386061584, 0.005567199592145958, 0.03817863456372704, 0.059623842393713336, 0.032741730234452655, 0.08197440592838184, 0.02418528320933027, 0.030991272734744207, 0.014132923463226428, 0.0232763160020113, 0.05715035833418369, 0.03395900170185736, 0.010303767148538359, 0.023857384554243515, 0.032186040588255437, 0.06003693451306649, 0.013089319641169692, 0.04854653090504663, 0.01688771541895611, 0.03469211807740586, 0.006396369809018714, 0.05131386133975216, 0.034056686995817084, 0.07086351034896714, 0.007036183802743575, 0.013144030767892088, 0.026579704368487, 0.0179416075282331, 0.02827880864164659, 0.004743267665617168, 0.03654583164357713, 0.04564375809526869, 0.029492785821535757, 0.03358745288902095, 0.036008842422493866, 0.030017137327896695, 0.04644982037799699, 0.06287670534636293, 0.03462452920419829, 0.05860663019120693, 0.08141855682645525, 0.027521919791719744, 0.01686135263714407, 0.058521182276308537, 0.03322630262534533, 0.04344173554064972, 0.02394034563829856, 0.04616518172302416, 0.022916672086077075, 0.03442188132820385, 0.052564418342496665, 0.07041105641318218, 0.022124377278877155, 0.05184085913268583, 0.0173873665543007, 0.04064519417339137, 0.03785485461620348, 0.03438714712059923, 0.01355042150576732, 0.04776314186996647, 0.02604630629398993, 0.08811731915920973, 0.023843486460724046, 0.00831698692802872, 0.04846795994256224, 0.04213609845776643, 0.026119501562789083, 0.10897224223507301, 0.03778824283342276, 0.02184804728520768, 0.009809971770404704, 0.07381228783300944, 0.03594654951510685, 0.03592606793556895, 0.027584877663425038, 0.014123009218435203, 0.02831913228146732, 0.02687861940025219, 0.049535044468939304, 0.008619255619123578, 0.026349852327257395, 0.05040430211062942, 0.02006156636135919, 0.025047668987619023, 0.008291009214839764, 0.06329744455537625, 0.0626534198277763, 0.07296791885580335, 0.004194270919210145, 0.06023981648364237, 0.03218654948951943, 0.06175569085670369, 0.0335261302867106, 0.042074009110885005, 0.07986646903944866, 0.020227598791409816, 0.08010000043681689, 0.037203114945441484, 0.08784044294485024, 0.025302859222782508, 0.006881113530003599, 0.03220432032165783, 0.04376336792483926, 0.01662033360584506, 0.05035620076315744, 0.010230118109445487, 0.013065561585660492, 0.012254501044351076, 0.05305916875866907, 0.0023099832012251553, 0.022647710982710123, 0.020124105237690464, 0.04141210498554366, 0.026635632617399096, 0.10599725972861052, 0.010951119242236018, 0.08407342686717, 0.02397250141283231, 0.025030183140188456, 0.034069908250655444, 0.03837513830512762, 0.05605352683258908, 0.014871085594807352, 0.03024403943813273, 0.017300617548504045, 0.03904883536909308, 0.01642034897979881, 0.01867353986017406, 0.0547400051727891, 0.0054640559080455986, 0.05642644289348807, 0.017834458367100785, 0.04685479382585202, 0.003444727846986747, 0.03826035392869796, 0.03539852731462036, 0.01447866843747241, 0.009888303549295025, 0.023259654574628388, 0.024422259868255684, 0.008157176664099097, 0.027087119640782475, 0.07188003044575453, 0.05010686967787998, 0.034555227030068636, 0.03769673899348293, 0.01786322146654129, 0.04358628724834748, 0.01597893480876727, 0.05615206029532211, 0.04100206966644951, 0.0607163312711886, 0.04838638985529542, 0.013101104098106069, 0.0252159626356193, 0.007361540071932333, 0.0843131940013596, 0.022897696854280572, 0.059172487684658596, 0.03040542559964316, 0.07924292249871151, 0.0477207062899002, 0.05331752775236964, 0.011750702363704997, 0.04334287638110774, 0.018527400380532657, 0.028031893141035522, 0.006083473563194275, 0.07259676020060267, 0.029418781399726868, 0.06157196392970426, 0.04240510705858469, 0.0152612652829183, 0.05208579670371754, 0.028314986432503377, 0.037710391118058136, 0.032065488664167266, 0.03786422857748611, 0.012597788873660778, 0.05132263819021838, 0.024068922935319797, 0.03505312924140266, 0.022735225036740303, 0.010785309032403996, 0.0460641546440976, 0.02377769909799099, 0.04654883220791817, 0.04382778464683464, 0.0547887986259801, 0.025616417040250132, 0.011568134035249906, 0.04465850828481572, 0.014368552381971052, 0.006976830224240465, 0.017907562033672417, 0.031586035819990296, 0.05506097598533545, 0.036329317904476605, 0.036351604387164116, 0.008399579058667379, 0.03745475644245744, 0.048510785680264235, 0.010664211735794587, 0.018482856252895932, 0.038013753946870565, 0.03232124886874642, 0.006724683218635619, 0.04132991743140987, 0.028819014118718247, 0.05826381394373519, 0.013449748113219227, 0.013256538659334183, 0.023979281674006155, 0.043655362113245895, 0.03381775106702532, 0.03826698660850525, 0.06204404788357871, 0.03417432800467525, 0.03998490156871932, 0.09523048996925354, 0.03198737571282046, 0.030689724987106662, 0.02275573375767895, 0.08671054643179689, 0.026756150614736334, 0.013035057195728379, 0.03538263602448361, 0.057885361037084034, 0.020068989534463202, 0.06605268349604947, 0.03162630008799689, 0.032873172645590136, 0.10339083030287709, 0.045335323217191865, 0.05623539796631251, 0.07048116943665914, 0.07591927477291652, 0.04791423126256891, 0.13969324768653937, 0.13031692510204657, 0.14954747605536664, 0.1899399600390877, 0.2063353338411876, 0.2360829333109515, 0.10288410713630063, 0.10373962444386312, 0.103600117644029, 0.10254175907799176, 0.1381268495959895, 0.19082235411873885, 0.08936494149799858, 0.15197053817766054, 0.12060160642223698, 0.09356075099536351, 0.09876573884061404, 0.11751242647213594, 0.12367040318037782, 0.12332717302654471, 0.14826904822673115, 0.12265583047909395, 0.15149194028760704, 0.22450822511953966, 0.21691658534109592, 0.1170943131936448, 0.1243133151105472, 0.17230070941150188, 0.10944281984120607, 0.1261944313134466, 0.13012453328285897, 0.146963451855949, 0.14416445419192314, 0.15966338823948587, 0.1466095144195216, 0.11786298480417047, 0.16876091435551643, 0.11000428721308708, 0.09275256150535174, 0.1263763601226466, 0.125715684145689, 0.14776928004409584, 0.15647428722253867, 0.13281539960631303, 0.09430078842810222, 0.1921112992401634, 0.12943869722740992, 0.1212651322462729, 0.1420239611927952, 0.10481659522546188, 0.09169279158647571, 0.12331394159368106, 0.17455374422882283, 0.1043276632470744, 0.18965739091592176, 0.04918905607025538, 0.10331408799226795, 0.1272234432399273, 0.1251012571156025, 0.09810791271073477, 0.06272047265831913, 0.15086762021694863, 0.10351067994322095, 0.3013969771564007, 0.12037671277565615, 0.19977521656879357, 0.12891355183507713, 0.10954394191503525, 0.14957178117973463, 0.1373965423554182, 0.1350205705634185, 0.09738428904009716, 0.13440713419445924, 0.08000865605260644, 0.10386869537511043, 0.17878656781145505, 0.11431369025792394, 0.2360301704279014, 0.11403167753347329, 0.15330337094409124, 0.1615288302834545, 0.15668356099299022, 0.08770736865699291, 0.07911062174077545, 0.11420649529567786, 0.09880768587546689, 0.09109602003757443, 0.14725872315466404, 0.11827271138983113, 0.15297186587538036, 0.1158340158207076, 0.13766254165342875, 0.21906205878726073, 0.13215179235807487, 0.1499076560139656, 0.12386770759310041, 0.15101726432996138, 0.1167230595435415, 0.18524498625525407, 0.14904324311230863, 0.15695604708577904, 0.14121839084795543, 0.06496277983699526, 0.12496070537183966, 0.1313800130571638, 0.10079825656222445, 0.16365937595920904, 0.15305742914123194, 0.285461636526244, 0.12086144462227821, 0.12965592342828, 0.17162115659032548, 0.1322112591671092, 0.1383517568132707, 0.12106877778257642, 0.12971209255712374, 0.09871049251939569, 0.2332312949001789, 0.07903516864670174, 0.19184806836502893, 0.10361279946352754, 0.09692403873694794, 0.2058759249214615, 0.12990335800818034, 0.14852758363953658, 0.14850089007190295, 0.13343317859939166, 0.15488430325474056, 0.11505447407918316, 0.16470133433384554, 0.08843196941805737, 0.09794129165155546, 0.12794798293284007, 0.11424157555614199, 0.11441362489547048, 0.12994728636528763, 0.11276849638670683, 0.20293210074305534, 0.08087827331785645, 0.1221565915537732, 0.09306963413421597, 0.08285502224628415, 0.0971654411405325, 0.08006737647312027, 0.12617683011506284, 0.2950588901128088, 0.12042305671742984, 0.16785971128514834, 0.13366834526615484, 0.060138674053762636, 0.12674907940839017, 0.1375475978212697, 0.1068348501409803, 0.09749854755188737, 0.11151509971490928, 0.12334788191531386, 0.10716684375490461, 0.20974274671503476, 0.11072434857487679, 0.06786188177232232, 0.1826973586742367, 0.1590221726468631, 0.09871423124734845, 0.1295028187866722, 0.090687175547438, 0.11043778966580119, 0.1031382524275354, 0.2453959621489048, 0.12499708841953959, 0.08166672422417573, 0.147972134873271, 0.13065034363951, 0.14945328182407788, 0.21486651391855308, 0.12750069264854702, 0.14731688717646257], [0.009441562878367091, 0.042748608626425266, 0.049565632827579975, 0.05598552405302014, 0.027896262472495437, 0.007822235663687544, 0.013739032188563474, 0.02072780123645706, 0.045952617057732174, 0.029575017480445758, 0.04792731681040355, 0.037714784632303884, 0.013062011999344187, 0.04653122422418424, 0.028485663434756652, 0.032797943468072584, 0.025204442807340195, 0.035580646113625596, 0.09445645793208055, 0.04143380792811513, 0.027874413644894958, 0.049615189632666964, 0.028647846874914, 0.0717773816681334, 0.019646833883598447, 0.05815173352935484, 0.043094824334340434, 0.058983759954571724, 0.052331826716129265, 0.03414816030168107, 0.050090622156858444, 0.02716928344619061, 0.03519350456606064, 0.02398683037608862, 0.0072815933796976295, 0.04771697095462254, 0.017184730552669083, 0.0478603182626622, 0.025270084285044243, 0.005118847400548735, 0.027994514343195727, 0.052187217332954915, 0.051671995515269895, 0.022597015935129354, 0.015826388262212276, 0.003068510501179844, 0.026581931659685712, 0.0181308238035334, 0.03503786898883326, 0.038708852005324194, 0.029170403656150614, 0.006173314568254032, 0.09591300798846142, 0.010883922223001719, 0.057429331221750805, 0.061081403467272005, 0.05626339092850685, 0.01727451091366155, 0.08841184406940426, 0.028838559319930415, 0.027620692438046848, 0.027245884960783378, 0.02563826077883797, 0.04921376831563456, 0.11122056123401437, 0.01803229034080037, 0.04002240759187511, 0.10098701821906225, 0.010331688864555742, 0.04354371256860239, 0.03658738173544407, 0.04166783465604697, 0.012681031549748565, 0.019170717735375677, 0.006790018083328115, 0.02974442731855171, 0.016369526706902043, 0.03493700475831117, 0.010275127033569982, 0.030545068106481006, 0.05242668930441141, 0.06855272541620902, 0.024397439057273523, 0.01441460964269936, 0.04121792522658195, 0.01964957177239869, 0.025507203436323574, 0.02746735030918249, 0.009709124503258084, 0.025841108822662915, 0.05258643341117671, 0.025673961898844157, 0.06075230041252715, 0.0413715693035296, 0.029817821058843817, 0.024712335285065428, 0.07900384747024093, 0.04918851324224046, 0.045778576218123944, 0.03396607882210186, 0.02677644050813147, 0.019709030099745308, 0.042573427847985706, 0.0181206830976797, 0.09088349608438355, 0.07253984468323843, 0.022786215247054185, 0.014895227870770862, 0.026246825266363363, 0.024849633453413844, 0.007270612138589578, 0.008831424189598432, 0.018904085703460232, 0.028972868541521684, 0.022979562104280506, 0.0200625892528998, 0.021478937805763314, 0.04823571776172944, 0.012439700392340975, 0.029691796749830246, 0.07515685925526278, 0.02397819601797632, 0.052015799031193764, 0.021777206532923237, 0.02585923588568611, 0.002855157887097448, 0.026259837871683494, 0.025939280965498517, 0.038884796135659726, 0.010944132876050259, 0.0812835826405457, 0.05232680894966636, 0.017243842827156186, 0.08666404642696891, 0.024653324790831124, 0.04272025943334613, 0.02823247487789818, 0.0483555741874235, 0.019541935762390494, 0.006525781704112887, 0.005268193806322026, 0.034472873234855275, 0.058492290255214484, 0.05592567387170025, 0.003675052954349667, 0.03031864097075803, 0.03480724172134485, 0.028821314352431467, 0.027091653951044594, 0.06675622931548528, 0.010576556037579263, 0.05026416766590305, 0.03401617845520377, 0.025205231604299376, 0.051141075789928436, 0.025334675729806935, 0.037885385299367566, 0.005041684822312423, 0.04267322338585343, 0.03895234090409108, 0.02181297041741865, 0.05422900045024497, 0.02452909859961697, 0.008668699617763715, 0.009120212086210293, 0.01735801312939397, 0.060421311030430455, 0.030487012650285448, 0.006249714218678751, 0.026853296473356228, 0.026476819799946885, 0.05475050210952759, 0.06254108157008886, 0.012332292539732797, 0.03503099882176944, 0.034675829844283204, 0.03449931574453201, 0.028127468191087246, 0.039915507792362144, 0.018250625946425965, 0.038448386160390716, 0.018050486953662973, 0.044214905838349035, 0.014604205897610103, 0.09522246289998293, 0.051020052284002304, 0.015276216802054217, 0.0030135597667789882, 0.06764223320143563, 0.03436418888824327, 0.03193365948806916, 0.010481645103677042, 0.012664806929283907, 0.03506750061309763, 0.04943944227748683, 0.03494455346039363, 0.041901053927306614, 0.04818541456812194, 0.012608835423764373, 0.02536791207135788, 0.06955600729478256, 0.05406249813469393, 0.06454519581581865, 0.028271826516304697, 0.05033392106582012, 0.0448004408473415, 0.00576359688836549, 0.07403705255793673, 0.023070114298856685, 0.014538778158436929, 0.04892799311450549, 0.06085047764437539, 0.11997979693114758, 0.057902650109359195, 0.01307629600965551, 0.015441506236259426, 0.014544021537793534, 0.029134753426270824, 0.09076733088919095, 0.014256429559152042, 0.04633364161210401, 0.021542453772521446, 0.03107142468382205, 0.022393947367423346, 0.025911218453464762, 0.04469369032553264, 0.024894644073875885, 0.034480248910507987, 0.031945683128599606, 0.019149276028786386, 0.026051917778594152, 0.04739653618474092, 0.021990353041993718, 0.013858479796908796, 0.049868975300341845, 0.0256438943158303, 0.03890208860060998, 0.020730808842927217, 0.03567882673814893, 0.023683284342821156, 0.07327220788491623, 0.03858457153130855, 0.04041832938258137, 0.09089624575738396, 0.01957510594677712, 0.02362336291532431, 0.025504482510898794, 0.059498740892325125, 0.06448348305587258, 0.032839140721729825, 0.018228487045105015, 0.01680509529874793, 0.04447573809219258, 0.02810060159702386, 0.013013378001882561, 0.012105941739199417, 0.031019543896296194, 0.04098884162626096, 0.03900447614224894, 0.05544258747249842, 0.03966436841125999, 0.015387303162632244, 0.022874014285792197, 0.026133230022553886, 0.00919643701386771, 0.04514245642349124, 0.02292069579873766, 0.07894910326493637, 0.042574157273130755, 0.060670170533869944, 0.02428695489652455, 0.056038941722363234, 0.04540449307699289, 0.01526121948180454, 0.040275664002235444, 0.06380135180162531, 0.060273817873426845, 0.03161780482956341, 0.008180352027661033, 0.01089091198186257, 0.04025728588125535, 0.06372969171830586, 0.03311398811638355, 0.08115207576858145, 0.02222845098003745, 0.005193237739149481, 0.023443254276311824, 0.05519168557865279, 0.030728035074259554, 0.021053287699552517, 0.025440396574724997, 0.03527433165748205, 0.045798840666455884, 0.020574835694528053, 0.012819896285821284, 0.04174547263288072, 0.011594607927171248, 0.05496494970949633, 0.1046155249433858, 0.029025315905788114, 0.015290374435218317, 0.014933071465098431, 0.023854477031688606, 0.03484760098425405, 0.06901926573898111, 0.06690410245209932, 0.07436998933553696, 0.03652005409821868, 0.03316956352708595, 0.07652291988155671, 0.033461896769170246, 0.012694346103151994, 0.02162965739678059, 0.0753975695531283, 0.033681989780494144, 0.013892703406911875, 0.025477269863975898, 0.03588339486824615, 0.009421434137038887, 0.07940556055733136, 0.034809983002820184, 0.05199403502047062, 0.00867047907585012, 0.025103614199906588, 0.006512039249563324, 0.028711391679410423, 0.02542185560534043, 0.018054023817447678, 0.1193996359195028, 0.0462793757739876, 0.057188390221978934, 0.11222934603158917, 0.016996357357129455, 0.018026604217344096, 0.02280663575844041, 0.0430114052391478, 0.026353982909183418, 0.04385510246668543, 0.025996966620108912, 0.005497436438288007, 0.021595644132633294, 0.0422592627416764, 0.045741165189870765, 0.03464669355058244, 0.022792043862864375, 0.05991119518876076, 0.03756628045812249, 0.05518648121505976, 0.07416779268532991, 0.023230136604979634, 0.008794994492615973, 0.02329411736822554, 0.17950422715927872, 0.09845043040279831, 0.1028990824041622, 0.1565414486186845, 0.11373055047754731, 0.10716455709189177, 0.11462726843144212, 0.14269119181803294, 0.1539198878620352, 0.1087153149502618, 0.10559725654976708, 0.08425719450627055, 0.13348334947867052, 0.17010832205414772, 0.12290739055190768, 0.1063676652099405, 0.15847517842692987, 0.1793989592364856, 0.21966352579849108, 0.13011351387415612, 0.11127568541892938, 0.13232374670250074, 0.056652571473802836, 0.24451812782457896, 0.1449097841978073, 0.15697518177330494, 0.23965012761098997, 0.10635593333946806, 0.09758314051266227, 0.16783087354685577, 0.17533551156520844, 0.13615371047386102, 0.1057058832209025, 0.11959764600864478, 0.15321361433182443, 0.10311180991785866, 0.19363809802702495, 0.14311167996908936, 0.11175244447908231, 0.07764421935592379, 0.0752766817542059, 0.14216797346515314, 0.13031643655683312, 0.08072494475969247, 0.18892251034932478, 0.08247496799698897, 0.08314874648515667, 0.0809494855680636, 0.13522949149566038, 0.09996111398296696, 0.10464569261031491, 0.10384451238704578, 0.16536893136799335, 0.09284193813800812, 0.09496867044695786, 0.07903301769069263, 0.07781981743339982, 0.06544838020844118, 0.17415007017552853, 0.15032986764396938, 0.13795360603502818, 0.1275693332510335, 0.1628860631691558, 0.17858565359243325, 0.20235012125756058, 0.04860872542485595, 0.12479556351900101, 0.1833932370479618, 0.09935387942407813, 0.21140171055282864, 0.15766648682100431, 0.14801200559096678, 0.12415764560656888, 0.1609808046902929, 0.1478373371064663, 0.12537930719554424, 0.1481410629515137, 0.12807847878762654, 0.1319133551525218, 0.03657542255574039, 0.12984408118895122, 0.1528018114290067, 0.14107254653104714, 0.1060715660985027, 0.08119348676076957, 0.06575534266552754, 0.13135208455579622, 0.15307705237397126, 0.10790613479912281, 0.10431288475436823, 0.14313074680311338, 0.1199927840914045, 0.253595732152462, 0.1297228541225195, 0.13338374053793295, 0.12939179688692093, 0.1930884982326201, 0.16443549788423947, 0.1199023218027183, 0.09844352970165865, 0.09557773026504687, 0.12232724311096327, 0.10430974313723189, 0.1822893148554223, 0.25520464724728037, 0.21196530173931802, 0.09495615826121398, 0.12992429759885582, 0.07280379480549268, 0.09348520969173738, 0.09096118155866861, 0.1312810962221452, 0.1654453751231943, 0.1240134569151061, 0.17820732960743563, 0.09674308701817479, 0.1268096590148551, 0.1901294341576951, 0.05633543099143675, 0.13799969213349478, 0.10902351912643228, 0.1486542389861175, 0.23735361226967402, 0.11455410878573145, 0.07889424370867865, 0.12988464401236602, 0.12226871268025466, 0.10253025112407547, 0.14161126262375287, 0.1587721732045923, 0.26236826713596073, 0.10115594629730497, 0.12640548284564698, 0.23161554017237254, 0.2070644875722272, 0.1438830250075885, 0.08027432286845786, 0.13640379134033406, 0.11510246007570199, 0.0875125341117382, 0.08926641142794065, 0.15319150766091688, 0.09638581118945565, 0.18472845825765813, 0.10535360140992062, 0.18748151910092148, 0.13464599209172384, 0.12902420732591832, 0.07484608343137161, 0.14907254225441388, 0.10956739208527974, 0.10446527693420649, 0.1336315143853426, 0.09548094402998686, 0.12866887210735253, 0.17569072464747088, 0.12170167453587055, 0.12140657965626035, 0.06432762356208903, 0.08440740180334874, 0.0817590117720621, 0.12664265797606536, 0.11930856294929981, 0.11069954811994519, 0.09870567492076329, 0.11557314624743802, 0.13847504662615912, 0.14792155687298092, 0.08688853295253855, 0.11238211819103786, 0.1537202221474477, 0.14927336147853307, 0.22836359324199812, 0.09975457470864058, 0.13748418193842682, 0.05491556593083909], [0.020417461371315376, 0.029093725806368247, 0.021396561958161846, 0.03106607443520001, 0.0132383064233831, 0.052143838589212725, 0.025974408723413944, 0.009622790251991578, 0.04213456836129938, 0.011015635199977883, 0.027618785754644444, 0.02929689615432705, 0.019308652030304074, 0.02807948728358107, 0.06027813335614545, 0.02432804019190371, 0.021971751004457474, 0.02292199349696083, 0.035396600275167396, 0.029739616505269493, 0.05359760665201715, 0.024730491185826913, 0.07598725041108471, 0.09557846986821719, 0.0693254071686949, 0.050917912407645156, 0.016599449994308606, 0.035259471740573645, 0.026809934692989503, 0.05981424610529627, 0.04140280227043799, 0.07120833506009408, 0.02122905371444566, 0.05789133893059833, 0.012866648196774935, 0.022111843040745174, 0.03143810500789966, 0.03714486271409052, 0.05857822671532631, 0.030253684813422815, 0.03418610737259899, 0.0549272604818855, 0.008400808903388679, 0.031313461517649036, 0.04553799484191196, 0.014756730391776987, 0.038385411325309954, 0.08165617300463573, 0.06805623455771379, 0.05541680992713996, 0.04961214979578342, 0.07062461173960141, 0.010227331026856388, 0.023219502264899865, 0.03020536633474486, 0.019056274322792888, 0.07127476363841977, 0.029209351566221033, 0.02499910623633436, 0.03437837366280811, 0.013163744754690145, 0.037989750770585876, 0.023595936529870545, 0.018437789653294852, 0.027509122621268034, 0.05877195524850062, 0.04863921200324382, 0.014084984115990145, 0.08768353850713798, 0.01980481549565281, 0.0475777287834457, 0.02529649286797004, 0.056822982151061296, 0.017186019769204513, 0.06724982961480107, 0.09513674357107707, 0.022784106699483733, 0.0053328365652955, 0.06264094156878335, 0.02982844691723585, 0.005262276980959411, 0.08135299677295343, 0.004095671299312795, 0.04999073162408812, 0.05505767830514482, 0.04269835293026907, 0.0265533466756876, 0.021475389067615782, 0.01257600705139339, 0.011905840914031225, 0.044152107422373126, 0.055591159500181675, 0.04744220498417105, 0.02893990870299084, 0.0017999793178335363, 0.058572214895061085, 0.05682314499946577, 0.035152422663356574, 0.05547327421871679, 0.01979572991175311, 0.03992210315274341, 0.07896131689527205, 0.013694802731541651, 0.03126676134499056, 0.049600818260971985, 0.026421135823641504, 0.022853422444313765, 0.023063474833699207, 0.028567091029669558, 0.011197684449143708, 0.06039680913090706, 0.03990583188299622, 0.0707346158368247, 0.02595428337476083, 0.04037839759673391, 0.04069426582594003, 0.024791767987023507, 0.013422753445671072, 0.05942246677087886, 0.03050924145749637, 0.01822655152396432, 0.037629801513893266, 0.012735009010482048, 0.029716291864003454, 0.11397557625813143, 0.04930727044120431, 0.06667976520423378, 0.022946261301902787, 0.016527917136305144, 0.06763149199209043, 0.06533030832984618, 0.03813207349074738, 0.02323911023060126, 0.03188513744888561, 0.02085592900402844, 0.04388459159859589, 0.017367694127772535, 0.028300058662093112, 0.05359525552817753, 0.05976651795208454, 0.08474306629172393, 0.08381129521876574, 0.052319894677826335, 0.05420793533059103, 0.027664610617128865, 0.03819378625069346, 0.033152026789528985, 0.019210062588432004, 0.06790774395423275, 0.03322596335783601, 0.013604970632254012, 0.05322220376027482, 0.024434242796685015, 0.041765611552234204, 0.04011255096910255, 0.04157235799357295, 0.04707587749830314, 0.06483863506998334, 0.011975075234659016, 0.029177114367485046, 0.015173568024433084, 0.011153410887345672, 0.06195866782218218, 0.01910963262032185, 0.022566631136994277, 0.11608094828469412, 0.02918712275901011, 0.04391954293740647, 0.0613115896869983, 0.04239605879411101, 0.04909249375175152, 0.11188726260193757, 0.06437734660825559, 0.033358145372143815, 0.02830442164226302, 0.0794748729094863, 0.05668624716677836, 0.0322458534501493, 0.07922361139208078, 0.04140376579016447, 0.01889854546503297, 0.0578777953716261, 0.05301136596660529, 0.023014274259497012, 0.03591512316571815, 0.03994980773755482, 0.012632613835324134, 0.02906241820060781, 0.00859117868822068, 0.013438810128718615, 0.08006833999284677, 0.05760677491447755, 0.013212031002954712, 0.011806778193983649, 0.058544903860560486, 0.020504799006240707, 0.030865075399300883, 0.10651997596557651, 0.03472485399938055, 0.027617764559441378, 0.015429860879001873, 0.020902188128924797, 0.033981705483581336, 0.02169699521203126, 0.006679481336115194, 0.059585131970899444, 0.05497626767360738, 0.02544565182844443, 0.015261338225432804, 0.01960748733420457, 0.03002819066335048, 0.02433059996526156, 0.023258972646934644, 0.029229897606585706, 0.025464557510401522, 0.009156964087326611, 0.021108995424583554, 0.03234235130782638, 0.04668957394148622, 0.020877433475106955, 0.06913446741444723, 0.04075503881488528, 0.029014055617153645, 0.013561916737151998, 0.05259125100980912, 0.04039025838885989, 0.025498674251139164, 0.013980899388635797, 0.0061483415109770635, 0.029501342148120915, 0.07622735002743346, 0.019797684092606817, 0.04810650433812823, 0.09673666129154818, 0.043043530479605706, 0.009234392566473355, 0.02421914380309837, 0.04913039332521813, 0.05779952635722501, 0.04146909514175994, 0.017895881053326384, 0.09915994733039822, 0.08783871268055268, 0.03449940395408443, 0.03731478484613555, 0.09630814607122115, 0.03792655880429915, 0.05665723640205605, 0.07177638422165598, 0.04198259687317269, 0.02071049520080643, 0.03175026165055377, 0.0392381907440722, 0.006661823310423642, 0.02299918364068227, 0.03548314402412091, 0.04555810322718961, 0.05500528183100479, 0.031984332483261824, 0.05119751972545471, 0.03205435051183615, 0.02344863166633461, 0.06397462250398737, 0.014727755250143153, 0.015385506741170372, 0.03139225300401449, 0.020706688619351814, 0.01425136938425047, 0.07326789240219764, 0.03521098702081612, 0.032104528176465204, 0.01173297648451158, 0.04506698975871716, 0.03963389540357249, 0.02099024840364499, 0.021380702898438488, 0.019974666381520883, 0.014655063793595349, 0.02762588153460196, 0.040951664692589214, 0.03530259942635894, 0.05410122212820819, 0.03133726452610322, 0.05616094231871622, 0.029198243947965757, 0.01795048446261457, 0.050451572252703566, 0.08210275761250939, 0.09763014941875424, 0.04687428813693779, 0.012175428814121654, 0.034823326393961906, 0.02821030544250139, 0.022946514056197236, 0.01401574894719358, 0.01761627882452948, 0.042491392964231114, 0.050089254908795865, 0.04882519505918026, 0.02893107078437294, 0.05247033606948597, 0.03377759536462171, 0.038282280787825584, 0.01801694866402873, 0.056560002333883724, 0.041232184639998844, 0.04923142379681979, 0.04505009762942791, 0.05580568852435265, 0.010036350560507603, 0.02296024590863713, 0.022659381785030876, 0.016183835421023623, 0.034467146399297884, 0.01814825876083757, 0.046365346160850356, 0.03353146357195718, 0.0343646231506552, 0.01385011091562254, 0.03700695386422532, 0.03357750895832266, 0.015371422050520778, 0.038072888273745775, 0.0578479262601052, 0.07459819423300879, 0.01792450505308807, 0.04161790465669973, 0.04530792058046375, 0.013322398116412972, 0.033167979147817404, 0.03065721976703831, 0.030015882038112198, 0.02270612775880311, 0.02775337147925581, 0.05618709645101002, 0.09601162626807179, 0.023216484480404427, 0.018957347309749042, 0.05533854091273887, 0.04432868937562619, 0.029847707133740187, 0.07575819055948939, 0.03266216182549085, 0.024568937086899365, 0.0410345545304673, 0.09192565801952567, 0.08819967295442309, 0.05940396312092032, 0.06560930157346384, 0.022117615677416325, 0.04049124814836042, 0.04775014113900917, 0.13095419162086078, 0.12885249725409917, 0.12878084395612988, 0.10514746247125523, 0.11297767516225576, 0.15157161386949675, 0.07183809698160205, 0.1621085163205862, 0.1058117618252124, 0.0692754059231707, 0.09343229753098317, 0.12478488337780748, 0.13708315417170525, 0.11064171658030578, 0.20265824400952884, 0.11086510387914521, 0.11110506100314003, 0.10428306992564883, 0.12769110314548016, 0.19996977970004082, 0.13775254253830227, 0.21262234076857567, 0.16578781817640575, 0.1608998826039689, 0.14093135696436676, 0.14567576880965913, 0.09524057978498084, 0.10311451048723289, 0.11478505496467863, 0.13669974117406777, 0.17217912950686046, 0.16850330175033637, 0.08487916006041424, 0.16483643065605844, 0.08938319409000021, 0.1142423219446625, 0.09173986156071935, 0.15386916058404104, 0.10807680671236344, 0.09529930699084486, 0.13929734964455875, 0.16196200703935965, 0.14077202337128775, 0.10319906952125685, 0.1080386255468641, 0.0964100348896214, 0.125948625217591, 0.12998669567917073, 0.1519657748618296, 0.1718066952058247, 0.07724756814007248, 0.12462415200259004, 0.07016436822180237, 0.11940045016152517, 0.22488068656197616, 0.10436690971255302, 0.14300092948334558, 0.17677437221365316, 0.15821449884346553, 0.08570999904934849, 0.08434289347912584, 0.16624508292547294, 0.11071412305214576, 0.17288040901933396, 0.09426052416009562, 0.2684812976845673, 0.13169118921671594, 0.11957897272493158, 0.19543560514492647, 0.16335474087723664, 0.1436264437756368, 0.100620968932552, 0.20661706158093043, 0.13692927600017615, 0.16675447273467267, 0.20050261967948504, 0.11918530027781214, 0.1178809931235654, 0.1365806447075946, 0.10578555001744203, 0.1327304198805775, 0.15503968777401106, 0.09081132709980011, 0.20378603706402437, 0.10104396087782723, 0.16594236131225312, 0.11129603468413864, 0.1231226490012237, 0.092405633335667, 0.09394277978156294, 0.0667564600173916, 0.12176534826202051, 0.24665958434343338, 0.11255150088774306, 0.0753668047753828, 0.1293603400034564, 0.1097670170877661, 0.12099298542099339, 0.14086654329938547, 0.09983340690710715, 0.13145598183785165, 0.1880529270108257, 0.11478683272642748, 0.12900352557854994, 0.08624702558985778, 0.15450789273849555, 0.06324392171310526, 0.16668104167495454, 0.09376612997480802, 0.10686508566141129, 0.13496596206511768, 0.11960756619061742, 0.1782396821571248, 0.1414003332278558, 0.13908142623092445, 0.09437166141080004, 0.16889314725995064, 0.08066106068768672, 0.1650333008063691, 0.17164437605866364, 0.10437311152262346, 0.14101700165442058, 0.08963232500744717, 0.14423532038927078, 0.14533712555255207, 0.14616142346390656, 0.15724973061255046, 0.09325811759169612, 0.1447979480560337, 0.14749850385955401, 0.17360368663711206, 0.16840772330760956, 0.13667083558227333, 0.11552370818597929, 0.131789359663214, 0.18162163639707224, 0.11533223917441708, 0.16754720519695962, 0.1293616292199918, 0.12817024386354856, 0.20375787786075047, 0.22750243730843067, 0.09226390094097171, 0.17400969485087053, 0.14080524444580078, 0.16782008484005928, 0.1388356201350689, 0.08451758910502706, 0.16510226710566453, 0.1483582891523838, 0.12607214573238576, 0.15981128173215048, 0.1025381696277431, 0.10875435785523482, 0.21153042864586624, 0.16767912597528525, 0.10140830704144069, 0.13033995458057948, 0.1586909525628601, 0.126700062038643, 0.13112867011555604, 0.10522216917680842, 0.14374630020133086, 0.11215432719992739, 0.0700384931904929, 0.29131269827485085, 0.09132896789482661, 0.1705395853413003, 0.19201220598603996, 0.17909349634179048, 0.17436763564390795, 0.173758541899068, 0.18431392764406546, 0.08356217787201915, 0.10816399846225977, 0.13874238942350658], [0.02857538951294763, 0.041724892665765116, 0.022711396583222916, 0.03093351244128176, 0.04723677850727524, 0.01975150978458779, 0.020790849014052322, 0.06200372254742043, 0.06110623784895454, 0.04683729101504598, 0.042717602968748124, 0.05537650155435715, 0.014958996591823441, 0.016341101178633313, 0.03512594283425382, 0.05221246222832373, 0.030076997687241862, 0.04235734158594694, 0.02981159550004772, 0.04258346677358661, 0.04971158231741615, 0.03686177111896021, 0.030896803696772883, 0.07520615482436759, 0.050275119221104045, 0.04272610840520688, 0.013661129583072449, 0.0533271900910352, 0.039018291115228615, 0.015923671524173448, 0.056519337730216127, 0.010873901108945054, 0.06454955879598856, 0.026422380935400724, 0.02095629451131182, 0.02691645112021693, 0.05233092765722956, 0.03800847494442548, 0.01127728763302522, 0.07243535707571677, 0.03108527697622776, 0.02490642004912453, 0.01828742290048727, 0.042866110535604615, 0.04480553664533155, 0.05434980003961495, 0.05651650145383818, 0.03287347798634853, 0.010084160986090345, 0.05373420932197145, 0.04900529521650501, 0.0266634932652648, 0.052692122025681395, 0.07135390117764473, 0.028791689513517276, 0.02804039348848164, 0.0654262328254325, 0.056948412741933546, 0.036187514263604365, 0.05142826234389629, 0.027878045503582274, 0.03649132153285401, 0.020917930141357437, 0.027277279079758694, 0.038687990446175845, 0.0648328335955739, 0.020360179445041076, 0.0553225614130497, 0.045375787653028965, 0.012842041972492422, 0.017550935902233635, 0.01831074584541576, 0.008832811793711568, 0.04564191248001797, 0.008501517070856477, 0.043818342832050154, 0.0145333702343383, 0.017827801938567842, 0.02073555689172021, 0.05423228116706014, 0.02226341249687331, 0.02027849909583373, 0.06477407924830914, 0.04529651779947536, 0.0328000944240817, 0.06190419503088508, 0.03388127212279609, 0.08087323858801808, 0.009512568175393556, 0.046274408897651095, 0.026277578169746057, 0.028483163033212935, 0.035949572388614924, 0.009124206112963813, 0.024947719083034565, 0.0550724466198257, 0.04868965429653015, 0.01667055537525032, 0.03181192012769835, 0.018050741404294968, 0.015696984848805835, 0.0220028143376112, 0.019748797340850745, 0.017444227788863436, 0.05379297723993659, 0.030944898258894682, 0.022072467653613006, 0.013848259363190403, 0.020107470951708298, 0.0815610084682703, 0.020005151263571212, 0.01871296444109508, 0.007692704176796334, 0.03841322786839945, 0.03920940728858113, 0.023645600204222968, 0.04334508840526853, 0.0196727861517242, 0.0691516547064696, 0.05514020512678793, 0.03477654818977628, 0.021509436258514012, 0.0462986563465425, 0.06246639522058623, 0.03944662313110062, 0.08427243440278939, 0.06392838034246649, 0.023102958786434362, 0.057316056585737636, 0.07189083950860159, 0.019471495345767056, 0.10254589814160552, 0.042223710899374316, 0.04758873462144818, 0.03227756139157074, 0.032121145499071906, 0.0168034532440028, 0.02967725574438061, 0.031413905056459565, 0.01604805208210434, 0.026589948550931046, 0.03416859099109258, 0.015561825762103711, 0.05594161944463849, 0.07451723821993385, 0.00890193839690515, 0.03728425416297146, 0.022005038236134818, 0.0411643820282604, 0.06409828551113605, 0.03380266723356076, 0.04633665430758681, 0.09806882230831043, 0.09780304014150586, 0.02603153289029641, 0.021606989238145094, 0.03507319352190409, 0.013993412422548448, 0.04825429265786495, 0.08339457972241299, 0.05382824409753084, 0.060348721354135444, 0.04127359563218696, 0.012455435619423432, 0.021816020432327474, 0.0278521763559963, 0.009783680234769625, 0.008862931963189371, 0.03228858758562377, 0.04631127031253917, 0.0774264774684395, 0.038617969024926424, 0.025601977815053294, 0.019006576721689532, 0.034994307040636025, 0.07373240390526396, 0.13463930173643998, 0.052960367274603674, 0.007204600859300366, 0.024621730504025306, 0.0608671899618847, 0.05671155991564904, 0.05150747112929821, 0.023337019441117133, 0.02582393340500338, 0.029296519567391703, 0.00896863330022565, 0.04192778142169118, 0.034069799685052464, 0.011667150954183723, 0.03693531074428132, 0.08157089472349201, 0.01872931543870696, 0.062092434215758524, 0.02500310620026929, 0.004349344160540828, 0.0536481371548559, 0.015293801037062491, 0.04070243538756456, 0.016647139131756764, 0.04545268602669239, 0.01644737333325403, 0.10251607652753592, 0.06333240267953702, 0.036800227992768796, 0.07278786958860499, 0.09612006973475218, 0.019235641662297503, 0.04235313806150641, 0.08532203986708607, 0.028584919537284544, 0.05749233319823231, 0.02182259882933327, 0.016128828283399343, 0.048985940005098066, 0.04196991166099906, 0.014367022285504, 0.013431757605368537, 0.04707472738144653, 0.022303751403731958, 0.009051072760485113, 0.026695459049993327, 0.04290614749437996, 0.020759958707328354, 0.05104591464623809, 0.06493863756103174, 0.03416661306151322, 0.04281988533745919, 0.04009398285831724, 0.0413170490147812, 0.06396641901561193, 0.03071811149961182, 0.03637554988797222, 0.02874178665557078, 0.031218137525554215, 0.10675551582659994, 0.05045726516151002, 0.03460209683648177, 0.01224637558750276, 0.033740116482866664, 0.013317579669611794, 0.028492672701499293, 0.05696434474417141, 0.023366583211879646, 0.05916983461273568, 0.055445410178175995, 0.011626704329890864, 0.0015803959499213047, 0.041713907183813195, 0.026834652027381316, 0.007147045822681061, 0.006448730235985879, 0.018979399697855115, 0.058174864788140566, 0.030847738829574416, 0.02619532954746059, 0.02976137033796736, 0.013554837920569947, 0.03839120601436921, 0.032490936906210015, 0.03002715589744704, 0.02119028052714254, 0.01786995423026383, 0.02616659358942083, 0.03384030557104519, 0.06797468821917262, 0.043016331403383186, 0.03973307008189814, 0.01998260184856398, 0.024347487005538175, 0.016953670719106282, 0.05620582401752472, 0.046160873025655746, 0.06610784839306559, 0.01232211196994675, 0.030725890903600624, 0.03062362889094012, 0.02506106666156224, 0.012851736541571361, 0.035227689160300155, 0.029605402278580835, 0.05299159684883697, 0.056892610021999905, 0.013815091723310096, 0.05957605317234993, 0.024114571378699372, 0.046634880626308065, 0.07270905774618898, 0.036919714616877694, 0.038145196358008046, 0.03345621403838907, 0.03836402390152216, 0.012984486828957285, 0.012415620032697916, 0.04964870247723801, 0.06458017429602997, 0.01639227968241487, 0.06158334296196699, 0.03929744042190058, 0.021080574985327463, 0.019508699420839548, 0.07258159494293587, 0.08225559762545995, 0.031244831093187844, 0.03123233587081943, 0.003134061860951728, 0.03811410927612867, 0.04447076782318098, 0.051722186750599315, 0.03023741693635072, 0.022847637933279787, 0.10170798881777696, 0.03359040790902717, 0.05570367078429886, 0.02076878644792097, 0.025510977787364806, 0.013072757449533259, 0.033979683449225764, 0.021476004838145206, 0.05187471803011639, 0.02256355058800961, 0.02665203620147492, 0.03390577741499458, 0.05226763730336513, 0.06920810203467097, 0.048274153377860785, 0.08043142408132553, 0.030954550419534956, 0.044730134441384246, 0.05263342535389321, 0.0608460535960538, 0.018247745565271804, 0.006736099994408765, 0.03415146476722189, 0.051312249819082875, 0.03168195353022643, 0.03849758334191782, 0.02044495052125837, 0.06619500621621098, 0.024644687040043727, 0.006480629863550088, 0.0219365706600781, 0.002920113196263888, 0.01276738106805299, 0.05467569023104651, 0.010527799055645508, 0.01917215622961521, 0.04595288507906454, 0.04922164610720106, 0.028715557884424925, 0.013641696340138358, 0.03567209906343903, 0.24907671606966428, 0.1855088278119053, 0.07411425627235856, 0.08197219390422106, 0.22266666750822747, 0.17934064593698296, 0.11237825054143157, 0.12037018526877676, 0.13247415077473434, 0.09420255691345249, 0.06392709112593106, 0.0851023370133979, 0.07794154661574534, 0.06812428483473403, 0.07386059274098702, 0.18539821303316525, 0.06583635974675417, 0.22848727660519735, 0.0848144753170865, 0.06089336105755397, 0.09179104345717601, 0.14230794166879995, 0.14078518695064954, 0.08523488882929087, 0.14145756087132863, 0.13306493764477118, 0.24738727243883268, 0.15478507429361343, 0.09841134678572416, 0.08689299771296126, 0.25926266663840836, 0.09668112998562199, 0.1419530814247472, 0.09603530714022261, 0.11420292620147977, 0.11961087744150843, 0.1016647864931396, 0.09861097857356071, 0.11591850700122969, 0.1645580141672066, 0.062229247231568606, 0.17995178885757923, 0.16452321889145033, 0.11950183686401163, 0.13233753453407968, 0.11959847382136754, 0.22080961215708936, 0.10296757372894458, 0.08320334141275712, 0.1202623253422124, 0.10562604000525815, 0.12561916932463646, 0.12756942824593612, 0.1670059242418834, 0.12154723996562616, 0.06356991707746472, 0.12897784981344426, 0.0663787399285606, 0.14883022382855415, 0.11725052552563803, 0.1414487399160862, 0.09989080418433462, 0.12482270491974694, 0.11245960689016751, 0.09114158366407667, 0.11638943744557244, 0.19406054035893508, 0.2537007965147495, 0.21443723195365497, 0.15007461634065422, 0.0972678524308971, 0.09629953546183449, 0.12752030231058598, 0.1214411442301103, 0.1024915339159114, 0.11058629383998257, 0.1280880868434906, 0.09679469639169318, 0.17331461714846746, 0.1786545113261257, 0.12179110545132842, 0.14330784444298061, 0.14002982819718973, 0.1187276691198349, 0.11549979661192213, 0.1404852337603058, 0.11315111549837248, 0.13485226673739298, 0.14272870123386383, 0.18501636066607066, 0.2647225936608655, 0.14085989365620272, 0.10442957920687539, 0.0798807114894901, 0.12041956904743399, 0.1376656764852149, 0.20238749496638775, 0.1449607964605093, 0.11481280704694134, 0.0705892261383789, 0.12328466959297657, 0.13111275168401854, 0.07898527596678052, 0.07199317616011415, 0.14626092383904116, 0.10955036764166184, 0.10881353967956134, 0.13043233033801827, 0.15779413282871246, 0.19769938795694283, 0.08724360354244709, 0.17337854871792452, 0.09737875897969518, 0.0865311146314655, 0.08828258993370192, 0.10818327564213957, 0.09801038687250443, 0.08480993591781173, 0.11567141168883868, 0.14886486982660635, 0.1293688216911895, 0.16129069163330964, 0.19085713582379477, 0.11969957553914615, 0.08598358436886754, 0.1358589277203594, 0.14412148935454233, 0.05947811342775822, 0.1618971662329776, 0.14166574898575032, 0.14393531291612557, 0.20731360491897377, 0.16594522473003182, 0.1556892086352621, 0.11159343658281223, 0.17146148372973713, 0.09175827021577529, 0.10674191798482623, 0.11607492289372853, 0.1164147603724684, 0.1153351975870984, 0.1783810888550111, 0.0678410507472498, 0.202874343842268, 0.20792364861283982, 0.10916631003575665, 0.1022973982617259, 0.12682992007051194, 0.09415254209722791, 0.19304545197103704, 0.08711590325193745, 0.10963620910687105, 0.2881728453295571, 0.17878362296947412, 0.1717076019517013, 0.09023049433848687, 0.06221289453761918, 0.12619665690830775, 0.14647314245147364, 0.09542058155472789, 0.13627210126391479, 0.1956473487828459, 0.12022089399397373, 0.1448449298207249, 0.041745520130332024, 0.1446916080479111, 0.08024193639201777, 0.10443033238074609, 0.08775443184588637, 0.12714755588344165, 0.1250777526625565, 0.1144629136792251, 0.1529868207871914, 0.12809559144079685, 0.11398922838270664, 0.14390429029507296], [0.047934974078089, 0.031822440813162496, 0.0030044360152844873, 0.11137805599719286, 0.06436526189957346, 0.022961151752887026, 0.005581255020972873, 0.029947224472250258, 0.04098665335082582, 0.04335449968597718, 0.008753720903769135, 0.03282818577385374, 0.025458842549206953, 0.030293104305331196, 0.04456237005069852, 0.010450063539402825, 0.02568290668672749, 0.0782186331759606, 0.039805306919983456, 0.0402454658012305, 0.0695175343592252, 0.04882904574541109, 0.04956967689629112, 0.025039268724088157, 0.01570208234313343, 0.042716839616852145, 0.03008498065173626, 0.022729883269805993, 0.012118029840556639, 0.010476828353213412, 0.03685348281370742, 0.06017604776258979, 0.029987020551093986, 0.0457644423336855, 0.05140254586668951, 0.007489588111639023, 0.05472990857171161, 0.07397168249424015, 0.04122419149747916, 0.03248278430796095, 0.032272753970963616, 0.024599396523886492, 0.06489705693508897, 0.061757909666214666, 0.032024406761463196, 0.06072030070104769, 0.06963870035750525, 0.04669352640796985, 0.043103153351694345, 0.050494391205055375, 0.037043984912868054, 0.045206618694854636, 0.05122414883226156, 0.05734681457813297, 0.042228776163288524, 0.0255665565907423, 0.029662694382880415, 0.022953928747613515, 0.016656894768987383, 0.017730084414194738, 0.00897131351354931, 0.016102706381518925, 0.05697530308472259, 0.044536436442285776, 0.031132842281035016, 0.0760974580688136, 0.03907629228862269, 0.013650725944899023, 0.03340643670942102, 0.07027091179043055, 0.03401609363832644, 0.04465141420119575, 0.02542516346355634, 0.02524783512178276, 0.03792112713147487, 0.02219297208024987, 0.027634719453219856, 0.025536543290529932, 0.023127893252032142, 0.026672507602987543, 0.011981239725303437, 0.010445202684162982, 0.05150247711156096, 0.05978873318859509, 0.05010885439280953, 0.06702701907072749, 0.023556094649913054, 0.028906640131026506, 0.04193001040922744, 0.12737975056682313, 0.05157650188942041, 0.03174806998244353, 0.02276093981760953, 0.03363197496426957, 0.06384612832750593, 0.04978467071694987, 0.020848655108628527, 0.0032852095651573366, 0.010129414182821555, 0.004749666250843022, 0.03874493310494082, 0.04522082721814513, 0.0917358242773584, 0.030380866024643183, 0.05204585134716971, 0.05881761386990547, 0.042569444847426245, 0.04105603355648262, 0.05354105754356299, 0.057666560634970665, 0.0467093125251787, 0.017566051966111575, 0.028332236489014964, 0.019990410090291073, 0.05340419024495142, 0.055586501357278655, 0.026407213981396387, 0.05838301897581134, 0.06023607775568962, 0.008415504275555057, 0.01849538540201528, 0.01930380898660847, 0.03189379894839866, 0.018850573039214526, 0.060663032345473766, 0.03784279704892209, 0.030242373634661947, 0.04293051029422453, 0.03429697999464614, 0.055397983973047564, 0.02367017504626087, 0.025065539903672676, 0.017430914931797555, 0.027750279055908322, 0.008491375516834003, 0.02313164385434772, 0.035472195861595016, 0.021986924743812, 0.012675304714191173, 0.07180208712816238, 0.033825869738523445, 0.037587142017270835, 0.019080106168985367, 0.06252717838755675, 0.022964948156316365, 0.04817421195496406, 0.04889256001583167, 0.01042709088817771, 0.015461538286347474, 0.04935267800465226, 0.07914997677185706, 0.046360481064766645, 0.033356276008167436, 0.039808971009084156, 0.04586210387891956, 0.0384219402580389, 0.01762598696430879, 0.033662159594574144, 0.13580032943614892, 0.022536086883129816, 0.01462136095921908, 0.06438709715647356, 0.021300556038373282, 0.050559337184365304, 0.04604219725089414, 0.03349393380007573, 0.04362973723826664, 0.040886661037802696, 0.043994198752833266, 0.038226610382220576, 0.03167271188327244, 0.01965858950279653, 0.032852643568600924, 0.016247787346531237, 0.007954678065808756, 0.013266401165830237, 0.008671421391357268, 0.026443797196926813, 0.019242761190980673, 0.05554969761786716, 0.03186683735943266, 0.02079776328589235, 0.022029801371640394, 0.07108870255095617, 0.046701282063233, 0.013685821472401065, 0.0730468121224216, 0.016972008127985255, 0.06416402198374271, 0.04895171130608235, 0.07227299043110438, 0.0743144376735602, 0.015506313115890537, 0.06689651643059083, 0.06937319639005832, 0.051109758006142716, 0.05736985084201608, 0.042073147371411324, 0.06729805309857641, 0.014168418478220701, 0.043303117621690035, 0.007728608857308115, 0.04975628759711981, 0.039840940186487775, 0.007719383325560817, 0.04776687041989394, 0.02536025989268507, 0.026503811922988722, 0.02124747254752687, 0.0031750926614872044, 0.040198551890041144, 0.04115919802071793, 0.01789447818217533, 0.0935354009270668, 0.06317826666470085, 0.019054282822513154, 0.04281820596328803, 0.04125528197203364, 0.011790831772876638, 0.05501351924613118, 0.03562129714659282, 0.04650547042755144, 0.05068197899631091, 0.05098565395123192, 0.042510592112583775, 0.07151137558477265, 0.042131742262946706, 0.05870259539889438, 0.025485826190561056, 0.0061617765043463025, 0.028057870854224478, 0.03641440958849021, 0.022015933812196766, 0.05992614331522158, 0.019448253825040798, 0.03361048576022897, 0.018829843794394816, 0.03445279199097838, 0.02580993013855602, 0.0788100850103157, 0.04533903141106878, 0.004388144065160304, 0.1315099253718342, 0.02435002981552056, 0.03427372999223215, 0.10000404489359685, 0.03637406050360628, 0.060918853618204594, 0.012546816474891134, 0.015110284455918839, 0.044766368211380074, 0.029355311234082495, 0.02890302353937711, 0.03253566254196422, 0.020250658804018582, 0.0631469115614891, 0.04090002817767007, 0.0657972829150302, 0.06492146383970976, 0.055194759342287264, 0.07156730722635984, 0.08818994954760585, 0.014192088324177479, 0.02483071420075638, 0.027376796418268765, 0.02273346423836691, 0.05536675100613918, 0.032755853940865824, 0.04704833236922111, 0.03789522744981306, 0.04218216080750738, 0.024554265463458638, 0.041026778519153595, 0.06255444192460605, 0.017408448637330105, 0.048012154043785164, 0.03672701745693173, 0.0923998047198568, 0.03208218401830111, 0.038393624991710694, 0.0152771039865911, 0.02408934853571866, 0.02551206513973219, 0.07069514545478991, 0.023385931637936404, 0.01308293208213789, 0.03912830199780209, 0.07558865179972989, 0.060298251919448376, 0.009865682888110834, 0.048966615327766964, 0.013218377001716622, 0.032888002028422694, 0.054824652416365485, 0.0667793537889208, 0.02427946726259376, 0.03319392293425543, 0.017334674917427555, 0.008970689261332154, 0.0373626046015748, 0.023516656498291662, 0.03203148727438279, 0.02563374682462641, 0.022165289547826563, 0.042100594112915654, 0.047152222865926366, 0.02585382796158748, 0.038781153304236274, 0.022640353966770426, 0.016356692217024307, 0.009796769175279354, 0.008182905015668698, 0.04171225155836769, 0.02763122839054891, 0.05237478816083499, 0.04648687856804047, 0.05265640394229974, 0.021472881880721877, 0.06613315096391098, 0.06709932376231466, 0.023097774778891886, 0.03324444665174399, 0.07104273180344275, 0.0982766847259232, 0.02232450100460223, 0.030577234059040035, 0.053917783578591685, 0.06812250028763499, 0.051628297860068936, 0.05133682296478322, 0.01874666897180889, 0.013750892132520676, 0.031397311482578516, 0.0563791863221143, 0.033954994952572246, 0.011508387330520366, 0.05594752609197583, 0.038183170570326705, 0.03116317618904369, 0.049446597429258485, 0.042495433640267165, 0.053485098760575056, 0.029185233038983176, 0.03761881263926625, 0.02212502358348242, 0.02890085901266762, 0.03675414528697729, 0.0676825110401426, 0.026398533822170327, 0.008132027611801667, 0.05774622743151017, 0.01895333716778883, 0.11475566082767077, 0.1259938563619341, 0.17288650226380142, 0.16826843363898142, 0.16719155785228523, 0.07060344144701958, 0.12881905904838017, 0.21014619006642274, 0.17993861170751707, 0.1311629225632974, 0.09905979556164571, 0.15971018001437187, 0.14320818121944154, 0.20366229941802366, 0.12408460809716157, 0.17154285364917346, 0.11239942083401339, 0.1417351902595588, 0.1955748541014535, 0.08539256001157419, 0.19957382737525872, 0.14003307159457887, 0.15958975361926214, 0.1458870374730655, 0.10781188628503255, 0.1142510071929012, 0.13533508511526243, 0.15868570070181573, 0.08087686196501766, 0.07984360240932022, 0.11040262798113482, 0.18143137517784322, 0.13968420960009098, 0.1466463181589331, 0.14708165265619755, 0.1117703170914735, 0.13846093309777124, 0.1640447974205017, 0.14335493477327482, 0.13053470770163195, 0.10734392782407147, 0.21135912569505827, 0.11079180174108062, 0.15381726622581482, 0.12239578871854714, 0.09782433257039104, 0.096574192866683, 0.09853535584573235, 0.2251569724508694, 0.18164872351501668, 0.15441652121288435, 0.10489092195140463, 0.1805979713265385, 0.17053548698978765, 0.15096500356282505, 0.1290237187807049, 0.11945805778460843, 0.0859060346015862, 0.10897207938666854, 0.0963053097948432, 0.10902454371431045, 0.1333532471741949, 0.17569343878754548, 0.1556916106492281, 0.19522512358214172, 0.12888993881642818, 0.24483820636357578, 0.21424641433571065, 0.12659571692347527, 0.22106829684759888, 0.19882593250700406, 0.18158165711377347, 0.1329044234007597, 0.08165091435824122, 0.13494875441704476, 0.08828286134770938, 0.07540067045816354, 0.12300695878054414, 0.1806676025901522, 0.13061419129371643, 0.156090575669493, 0.1660707944205829, 0.139815926817911, 0.2018749431840011, 0.17292485306305544, 0.12452083826065063, 0.04892374548528876, 0.16767201492828981, 0.17553259884672506, 0.22320967194225105, 0.17801979609898158, 0.11864868764366422, 0.16989874972828797, 0.11627732988979135, 0.20545972511172295, 0.10776923357376031, 0.11417431916509356, 0.17634156186665806, 0.08153048796313149, 0.12618257052132062, 0.16881974334163324, 0.2084568685718945, 0.14811788419527666, 0.09954190826309578, 0.06593170748757464, 0.10020721863423075, 0.21795025201780455, 0.08038626079048429, 0.0989640067730631, 0.16252672459397996, 0.19976209370153292, 0.12693573082131998, 0.11873744002410344, 0.11523634860558168, 0.13225247338414192, 0.12863383255898952, 0.1956582867673465, 0.16207659803330898, 0.16108889531876358, 0.0707500728645495, 0.13911858280854567, 0.20863320625254086, 0.07677970467401402, 0.12382626267416136, 0.07394277011709553, 0.09888034340526376, 0.057678909972310066, 0.09729698872459785, 0.11110662163368293, 0.17687091417610645, 0.09605320689401456, 0.12839021134589398, 0.06319955230823585, 0.08861796943736927, 0.07491956877389125, 0.11618741042912006, 0.1309306328850133, 0.195013040676713, 0.22123836486467294, 0.15838505540575298, 0.07961292085903031, 0.0883359634982688, 0.144764849117824, 0.1294640065836055, 0.08375403364854199, 0.14559481958193438, 0.13748446692313465, 0.11520719874118056, 0.07427364414823906, 0.1411803386041096, 0.12147748656570911, 0.14549909186150345, 0.10924852812396628, 0.10517760978213378, 0.14095062735889638, 0.11051255065415587, 0.06617137962686163, 0.108783690924091, 0.2916203189109053, 0.10240951260285718, 0.12942030892840453, 0.11848715559712478, 0.1343287226877042, 0.0957745122058051, 0.0966315765732101, 0.13223306728260859, 0.10517359285482339, 0.10250982722001416, 0.10218575210975749, 0.10385840878422771, 0.1245708598622254, 0.13862036168575287, 0.1087546224838921, 0.07911854024444308, 0.11306909418531827, 0.08040405197867326], [0.014389429208157318, 0.00502431093315993, 0.021766344883612225, 0.014461934067574995, 0.057955311212156496, 0.033608979412487576, 0.05906707726951156, 0.04272415083167808, 0.010670709556766918, 0.07287937003586974, 0.08493551917906318, 0.06092365086078644, 0.05642362358048558, 0.0517466445453465, 0.03621633503852146, 0.03890440579769867, 0.05639198349256601, 0.03263766331864255, 0.04751938494986721, 0.04248217845867787, 0.0334541411139071, 0.046803944411554506, 0.08371165235127721, 0.013921823585405946, 0.08587844536772796, 0.029519570991396904, 0.034293736597257, 0.024496936039733033, 0.03088355530053377, 0.0782545819612486, 0.029891476035118103, 0.032377265327210934, 0.022998091199302247, 0.04061238021988954, 0.006750473910610059, 0.039059172850102186, 0.017456629712666785, 0.10478971166802303, 0.06755224588726248, 0.059887127551649294, 0.03862932091578841, 0.027367118812565292, 0.03871987480670214, 0.05337751703336835, 0.08861045126936265, 0.010913406265899539, 0.04407767891617758, 0.08157173610691514, 0.02148675961819078, 0.032221677247434855, 0.02334434083396835, 0.012818777551209288, 0.02350597466076059, 0.004555302863341889, 0.0499685503143285, 0.02333395415917039, 0.03031491581350565, 0.08620642205434186, 0.06176585531128304, 0.042560949588992765, 0.007107473236309099, 0.04026656824031046, 0.04885518969967961, 0.06592805018382412, 0.051318794289337735, 0.05490942518892033, 0.039505218022636006, 0.025194675295746753, 0.010878365869367761, 0.06386127322912216, 0.037872788296746354, 0.02203118388674089, 0.03807351591863802, 0.046757098353867016, 0.01917690088573311, 0.008060863707214594, 0.039181573782116175, 0.008973780836510872, 0.007777951075695455, 0.010898923784095262, 0.08221441733517817, 0.02119252478171672, 0.013454330769101424, 0.02894133362653, 0.0408225496565657, 0.06333156129611389, 0.028029933871169175, 0.020092799328267574, 0.016663449417267526, 0.019082542109702314, 0.030659265550119535, 0.016920756681689193, 0.030652378419680253, 0.0876193151676229, 0.043632763504449806, 0.02768707351892122, 0.061681228423757214, 0.03681127454287239, 0.027457840640896132, 0.022318090545013547, 0.0637184212516461, 0.008721494731227202, 0.05907196950699602, 0.028833514412066767, 0.017419870078031505, 0.0708880326045411, 0.029423917909818034, 0.06744333423141922, 0.039665406569838524, 0.02562903779159699, 0.04364318580233625, 0.05890861220125641, 0.004224137062140341, 0.016982632290039743, 0.04249542685491698, 0.05023473960214427, 0.023047551313149076, 0.048618784706507406, 0.05267873452976346, 0.028349133707316856, 0.06733061599412135, 0.015916260225432258, 0.06451426818966866, 0.016051726349230324, 0.04486716798107539, 0.029599420992391448, 0.0759597493867789, 0.050074605337743244, 0.026520235863115107, 0.030560114620519534, 0.04751691847507443, 0.04345254799617188, 0.029186552789594446, 0.016095266245039444, 0.012741886811064822, 0.052429070962326865, 0.057620332044150145, 0.02456980730806078, 0.030864457932433913, 0.01025398981957031, 0.02936628314533404, 0.03333619476429053, 0.022378403826483657, 0.020784447036151375, 0.04089107151542391, 0.09025790036789008, 0.0564797927093293, 0.04191902153460043, 0.03228417371532746, 0.050401523509728055, 0.08719617394464356, 0.014218217011408081, 0.030222078652254174, 0.019330507643254738, 0.030063138609485965, 0.061939539920006476, 0.01836343069693872, 0.030975781780268465, 0.03651621698268822, 0.05540210268061076, 0.04544972422133599, 0.012474147918900209, 0.013560021079943647, 0.054680209274270704, 0.027062585510845696, 0.04357266226517303, 0.04013007752863424, 0.0367069022863039, 0.03924521358151521, 0.008404025159377073, 0.0195275491236576, 0.04369854747450777, 0.038907113152423074, 0.04487899823912552, 0.024134718779740588, 0.01617313831645463, 0.02279844244809023, 0.044207516591995955, 0.027956652089155147, 0.05367257120087743, 0.02528839455252247, 0.022744938265532255, 0.020768252101593783, 0.04518827450062547, 0.055708905681967735, 0.04008985397272876, 0.10625331170324769, 0.021741775130586963, 0.029483751127762452, 0.03877518219607217, 0.005385940836276859, 0.17729889335376875, 0.05279916092487318, 0.025589803200481192, 0.08716538881084748, 0.05174417467787862, 0.02703433300900672, 0.02382200234569609, 0.02517453468005572, 0.04001511334042464, 0.013657005786496614, 0.01606078479172928, 0.032346269847559075, 0.03229410407532539, 0.025689612309049283, 0.04012057803837316, 0.06511226788695369, 0.02235974072079573, 0.05260211096278258, 0.08046243991702795, 0.010030727201540555, 0.03092840646526643, 0.039827247349811454, 0.014643511734902859, 0.058174226965223036, 0.02485153335146606, 0.027601618818672638, 0.05740058169301067, 0.041239387289221795, 0.06200560887477227, 0.09578175217445407, 0.027290605507524948, 0.004865158848198397, 0.016353372484445572, 0.05816026949988944, 0.03278513951227069, 0.04702455989484276, 0.04473343212157488, 0.1046078439269747, 0.03457115563963141, 0.020723280496895313, 0.03148167034877198, 0.01717735148434128, 0.07696864274995667, 0.11129523401281663, 0.01709100111786808, 0.02715744640279029, 0.10622523392417602, 0.008593543382760669, 0.040359459684363434, 0.0326348236495895, 0.05621071964768427, 0.025242854674745883, 0.016483473092583672, 0.049910247192851136, 0.0342097441399736, 0.037936621478625705, 0.034626089834741185, 0.05616146818335567, 0.005897540973299848, 0.05366608440609915, 0.028804527396070104, 0.022771867624084865, 0.03101672458329371, 0.05184891673603228, 0.021111304139984504, 0.0287627601729972, 0.055879007625792704, 0.022829325969464014, 0.021321214037016034, 0.047116830479353666, 0.012697106044340347, 0.024544187522094165, 0.02005419577471912, 0.01702522223682276, 0.03529277423928891, 0.029572985268064907, 0.006076016039254942, 0.032749082161379714, 0.05165645367066775, 0.02117882007067757, 0.008270662494136818, 0.05223696073517203, 0.05177314133782472, 0.0456504823773035, 0.08429129089095763, 0.1316934283822775, 0.10580347012728453, 0.02112180446939809, 0.063005694853408, 0.08807225764862128, 0.08021378397409405, 0.06291756672518593, 0.027727726248225996, 0.02064866878624473, 0.06580288761428424, 0.0768626012972423, 0.04184108839503356, 0.0293978316310261, 0.054602595046162605, 0.024788373615592718, 0.042768208110438924, 0.03879293267216001, 0.04991285276732274, 0.034643076958933046, 0.0415329724284155, 0.03454513042899115, 0.03654261538758874, 0.051158354684178314, 0.005060470488388091, 0.04821412338476096, 0.02621797056469534, 0.023892966930621436, 0.029004983603954315, 0.014426351691197072, 0.012445287280050772, 0.02480195110131587, 0.02343764788072024, 0.035204191492604356, 0.022474513222862567, 0.00947115887954299, 0.06774020687277828, 0.026931224523910453, 0.032659712314073525, 0.04485484917781182, 0.11591850700122969, 0.032424766171191416, 0.023678990912490656, 0.02287635183893144, 0.02170757357297199, 0.05615992112351315, 0.06803409396005528, 0.1322448059384312, 0.02893974246191127, 0.04658839079950537, 0.05821997379618032, 0.0804916304935302, 0.02694535331933626, 0.03170836550582733, 0.0484783720624234, 0.008779637548806412, 0.009463653434067965, 0.025733740833987082, 0.012637961539439857, 0.024472542705812624, 0.046068900996553044, 0.0824435246842248, 0.027293258579447865, 0.04513650906405278, 0.03086349441270743, 0.05533450362937791, 0.032021997962147, 0.009451282044340457, 0.025510367105848024, 0.020285752635183077, 0.021270178025588393, 0.04063119599595666, 0.06230406928807497, 0.059112484832959514, 0.06649106461554766, 0.026739339909649322, 0.06017654309315341, 0.14565667483423436, 0.10475028199808938, 0.12899895225252422, 0.13629289157688618, 0.0820507343326296, 0.1412875742784568, 0.12504601079438413, 0.1365066979612623, 0.1278795458908592, 0.13648147002926894, 0.17140764876135758, 0.11473564404462065, 0.2503418581826346, 0.16167956005249703, 0.10694502387195826, 0.2401067002543381, 0.15647398866713047, 0.11112543740975005, 0.23764326529843466, 0.273438104561397, 0.07960054438029017, 0.08963322067367178, 0.19738967743303093, 0.12835431684340748, 0.22040276255990776, 0.13607757884476865, 0.07512124295213393, 0.2087748572230339, 0.1367462072521448, 0.16310269225920948, 0.13803437884364808, 0.07268121066902365, 0.09873294524316277, 0.2432401478290558, 0.12921859403806074, 0.1451602993266923, 0.1867845957832677, 0.20712821558117867, 0.18561908975243568, 0.09959942089127642, 0.1369547074926751, 0.09503733140549489, 0.10526292877537863, 0.15792499509240898, 0.1920199277145522, 0.10887549671211413, 0.08801448717713356, 0.13318452265645775, 0.10456519800105266, 0.17096755094826221, 0.1689093235347952, 0.12047835732144968, 0.128639817237854, 0.10573064974908318, 0.12700654273586615, 0.09462674986571074, 0.10797234624624252, 0.14331901312938758, 0.14089179837277957, 0.13328741570668562, 0.1317096453692232, 0.15655006601342134, 0.13894022309354373, 0.17099125896181377, 0.14143906400672027, 0.10363538789429835, 0.15014333836734295, 0.10224685418818678, 0.10806858965328761, 0.1847109113420759, 0.14506025612354279, 0.10113604486520801, 0.12040864463363375, 0.18265432598335402, 0.14745316414960793, 0.1291054551090513, 0.18928301600473268, 0.08428255814526762, 0.13238843823117868, 0.11198728544903652, 0.20051384264869349, 0.09923127493155853, 0.07766554571155991, 0.12862392594771727, 0.12581268751195498, 0.1487330033310822, 0.13634868072611944, 0.13279767627162592, 0.0711016964965633, 0.07109900271253926, 0.16596188955008984, 0.03948399344725268, 0.135949987119862, 0.14260375579552992, 0.1258748820317643, 0.07267242364053215, 0.12505268757896765, 0.15315390325018338, 0.21170493428196224, 0.13803732368562902, 0.20368177337305887, 0.17075788362749986, 0.12342710766409125, 0.10259600116738252, 0.1849999808307205, 0.22141992726496287, 0.22878884470888547, 0.15450919552573136, 0.16508945636451244, 0.09602990600147418, 0.10598438791930676, 0.15767540277114936, 0.09751986033682312, 0.08631518443248101, 0.17241262697747775, 0.13742631647203649, 0.17227431439927646, 0.13065209425985813, 0.08107715871717248, 0.1371488906443119, 0.19475979783705302, 0.15420555110488618, 0.19152400004012243, 0.11858813517860003, 0.16333846960748943, 0.08771572820842266, 0.23810800750340733, 0.23754976317286491, 0.05244563739480717, 0.08204303296016795, 0.13314637541770935, 0.100261915342084, 0.1435631364583969, 0.14329392090439796, 0.10424231032707862, 0.10404322136725698, 0.19094164057501725, 0.09118414816579648, 0.11534629842000348, 0.19936886908752577, 0.13707803801766463, 0.09746340622327157, 0.10052730395857777, 0.2248554586299828, 0.17634970428688185, 0.10451537995998349, 0.2989409789443016, 0.11057159677147865, 0.15027436347944395, 0.1363443923848016, 0.20205788979572908, 0.06974749666239534, 0.09357418598873274, 0.12917843833565712, 0.12142646073230676, 0.17451840612505162, 0.07578728614108902, 0.10406266818089144, 0.12443804341767516, 0.10897276470703737, 0.15399759369237082, 0.08273384946265391, 0.16205420637769358, 0.17644374924046652, 0.08187890890985727, 0.16001762423132146, 0.08167920248316866, 0.09112994000315666, 0.09197135056768145, 0.09974728724254028, 0.10976648783045155, 0.18500521912106446, 0.11265659239143133, 0.1472193816942828, 0.11379297569926296, 0.16842360102704593], [0.06327053385653666, 0.05761787574738264, 0.02916369294481618, 0.061103795122887404, 0.020940934174827168, 0.03921049972996116, 0.03146457126630204, 0.07236626864011798, 0.029119096230715513, 0.02038325642102531, 0.037971213193876405, 0.03420540490852935, 0.02534251450560987, 0.028840086023722376, 0.09563452364610774, 0.04014575168756502, 0.043964261787810495, 0.00019726350183191244, 0.03889642622587936, 0.011549118091352284, 0.05788007524928876, 0.08237348629959992, 0.07025054216917072, 0.05899283875312124, 0.04037819064355322, 0.050677459953086715, 0.06177158893219062, 0.024578127843726958, 0.040985567694795985, 0.015610142544444119, 0.024440517549269965, 0.028675415752721683, 0.03196142174835716, 0.0366048879389252, 0.08616311794945172, 0.023578711918422153, 0.05103979426036988, 0.09584314602294139, 0.022619400805394565, 0.0123314375856093, 0.015172300860285759, 0.07717486989817449, 0.05382762323798878, 0.022237321129068732, 0.055923689156770706, 0.037517174878822904, 0.021385182925899113, 0.03627167635464242, 0.04100977782426136, 0.07000825088471174, 0.01126824615390173, 0.03470324944438679, 0.026793704135343432, 0.08028848389429705, 0.03711464415703501, 0.049096015348498306, 0.01946737663820386, 0.016171540366485715, 0.02305176671195243, 0.003512556751957163, 0.055660281862531386, 0.030868698776300465, 0.026172802184841464, 0.03197282113667045, 0.03166751430502959, 0.008695757049801094, 0.04407835405852113, 0.030496963366333927, 0.02515615995175072, 0.01056579192767718, 0.0474393687077931, 0.029183350104306425, 0.04191784427634307, 0.013661246630363166, 0.05276504418413554, 0.039777578586446385, 0.08832646400800773, 0.061386432099555216, 0.040251311380416155, 0.07741050475410052, 0.02107791682439191, 0.02617469529754349, 0.028219847341201136, 0.025029625045135617, 0.005108273704536259, 0.038530041064534865, 0.042665301489510706, 0.03758849908730813, 0.05614876600780657, 0.044953572630350075, 0.03667879058048129, 0.02643798554449209, 0.06899679944451366, 0.033343180282307525, 0.04576654579224331, 0.0731885377317667, 0.07599102306578841, 0.06954521180263587, 0.025022924511826465, 0.028601465613714287, 0.04420116211154631, 0.04846179884459291, 0.00945779767685703, 0.04579628937478576, 0.07931560716990914, 0.06370985135436058, 0.0213654104154557, 0.0174562700891069, 0.058721255111907206, 0.04400088232276695, 0.01906546168694539, 0.04015931899526289, 0.02731341276583927, 0.021406863816082478, 0.01409894582216761, 0.06675353553146124, 0.03196133353880473, 0.03946249406518681, 0.01566947195013719, 0.0021684944430100067, 0.07960481915090765, 0.011146497463674417, 0.01584116505858089, 0.05447559364672218, 0.03523995028808713, 0.08331282303801604, 0.03343337454966136, 0.04137093148061207, 0.008167622710711189, 0.04981430234121425, 0.016339847585186362, 0.05332801790375795, 0.036591564903834035, 0.029319304773317914, 0.09158894180187158, 0.045548831046159775, 0.03441898737634931, 0.049850695566939454, 0.05501045226784689, 0.018632647947275212, 0.027751259539010267, 0.032693296404821534, 0.03952686328973089, 0.03680559181209121, 0.030670641189707176, 0.02817610727756151, 0.08327003461974007, 0.0402563562882798, 0.003389851751437943, 0.002359970664006791, 0.0255394966141986, 0.039213933117155514, 0.060971704710807116, 0.024695935093664696, 0.06131185431565557, 0.016974939399265816, 0.05480562968711768, 0.03442499580393944, 0.04694514076358505, 0.04142929567024112, 0.014881921799055167, 0.01129677685509835, 0.04084456133257065, 0.05995689452226673, 0.04031425228874598, 0.06662341287093503, 0.015733276294278245, 0.05747139360755682, 0.0506752072168248, 0.04614123961489115, 0.01920934673398733, 0.00992964075079986, 0.05506456204290901, 0.046480395165937285, 0.059293952238346846, 0.04848290467634797, 0.1022274616573538, 0.02629380363837949, 0.045836611318268945, 0.018285538269472972, 0.04522657101707799, 0.027414087006556134, 0.024984821377854263, 0.06933752580412797, 0.029992961125182252, 0.015243280712249023, 0.02838754896739764, 0.01741905413967158, 0.01684454532473215, 0.02998529707214662, 0.02103551008206393, 0.05635402624362281, 0.02975332291264619, 0.01875569179121937, 0.012573585529545588, 0.036654234398156404, 0.021552428237295577, 0.028758556648556675, 0.02661810436152986, 0.05350879659610135, 0.05063136028391974, 0.061273442448249886, 0.04873349105140992, 0.03707326030624764, 0.03599158727696963, 0.024576202500611544, 0.06370629583086286, 0.006837366681013788, 0.06152260729244777, 0.011942395291823362, 0.048035013888563426, 0.026578572911343405, 0.0530610109812447, 0.022253195455830013, 0.053970166482031345, 0.036204806728554625, 0.035010982038719315, 0.021825794729271104, 0.050601823654557974, 0.010128175008243747, 0.0049824983330576545, 0.051543097610452344, 0.01157824251069022, 0.01171360261339162, 0.01589223330042192, 0.06672952896250145, 0.02015180982250188, 0.0638634106144309, 0.017501202678041797, 0.0057174327583717445, 0.07999887157763753, 0.0573266688734293, 0.048483233765832016, 0.06481399746345622, 0.03218668858919825, 0.057488540187478065, 0.034237723531467576, 0.030590441743178026, 0.012457126867957413, 0.04368898691609502, 0.02896756918302604, 0.0048320310722504345, 0.09929361872907196, 0.041957033066345115, 0.013763901345165712, 0.07158045723502125, 0.007647678289296371, 0.03122328082099557, 0.036557607618825774, 0.019757360452786088, 0.039122120543782196, 0.032142505781458955, 0.03290209859343512, 0.02966810230697904, 0.03303647566852825, 0.04301021441019007, 0.016079011938667724, 0.032593249808996916, 0.024333119026518295, 0.04203096963465214, 0.028230295084150772, 0.03131722738700254, 0.028839146252721548, 0.005333039277632321, 0.05224341021052428, 0.05034575132387025, 0.03674515809065529, 0.1268983164003917, 0.04541637422516942, 0.01715180803356426, 0.04949606941746814, 0.026898376643657684, 0.053454167741749964, 0.06953182430671793, 0.02979485604113766, 0.022274800010823777, 0.04976968527106302, 0.044307956738131385, 0.032182875222393444, 0.03312104827325259, 0.03798784747985857, 0.05309017102367111, 0.07002546531813485, 0.030312778428196907, 0.01056244844637279, 0.011074152059986122, 0.019814301415213516, 0.014285901727687036, 0.03493001924029418, 0.0405795662663877, 0.05170416146782892, 0.0645216777920723, 0.025004005259168998, 0.02557383048614221, 0.04340465020920549, 0.017208555613511374, 0.032474716526589224, 0.012848467699119022, 0.035038869827985764, 0.05470562719606927, 0.031895417254418135, 0.01806300592475704, 0.08091505670121737, 0.0478464150801301, 0.010854393227158912, 0.039449975094092746, 0.048050969639526944, 0.07246532796749047, 0.0061877584583791235, 0.06917760188558272, 0.01347218217727329, 0.028987026174685786, 0.0179703231302223, 0.025029185693711042, 0.04871609002085669, 0.00906416424550116, 0.019472418153392415, 0.012052955787761934, 0.022892595967277884, 0.041667098445551734, 0.04123859001057489, 0.08650494353579623, 0.03634077836094158, 0.05362592531102044, 0.04271675479997482, 0.06486603431403637, 0.017432967500228966, 0.036519351814474375, 0.00578901226565774, 0.02244511230050453, 0.0052080361638218164, 0.04307457684938397, 0.02734910710049527, 0.01715765191641237, 0.009747312454107617, 0.022366103682933108, 0.019813909561240246, 0.04363243780764086, 0.08970557286271028, 0.006652260631588953, 0.003013886947883293, 0.009106623574293085, 0.020056105850796615, 0.04658097101907645, 0.01880128255912236, 0.08803119949464287, 0.06559774612209626, 0.07202732004225254, 0.041287074730332406, 0.06669920523251806, 0.06523916750614132, 0.037653665590499125, 0.15276142502469675, 0.10375573286520583, 0.11800843557076794, 0.09078461996146611, 0.20115986226924829, 0.13882333865123136, 0.17881552768605097, 0.14003209450415202, 0.09210715256631374, 0.10203523947192089, 0.09057812818459102, 0.10878322273492813, 0.11590967247528688, 0.10010997778070824, 0.19713054490940912, 0.12761258307312215, 0.10333812848797866, 0.11093226527529103, 0.1101350069844297, 0.14884878854666436, 0.14820275535540922, 0.1815281342715025, 0.20490822541926587, 0.24599263870290347, 0.12194659853620188, 0.14643724794898713, 0.14983243362179824, 0.06636059590216194, 0.1441494042852095, 0.10996315442025661, 0.1001104459698711, 0.0953786548759256, 0.11574286142630236, 0.08410201354750566, 0.25513383533273426, 0.10567584447562695, 0.18041209344352993, 0.16081381722220353, 0.21249332412012986, 0.09437782250876937, 0.0693553848458188, 0.10018149537167378, 0.0908612876332232, 0.058442438287394385, 0.08549380422170673, 0.11404589962746416, 0.09692363840128694, 0.08494821456926209, 0.13369997856872423, 0.17908676527440548, 0.07810060200946671, 0.0963163020621453, 0.10095342395028897, 0.10945976964597191, 0.18894334137439728, 0.11730650466467653, 0.1054036705089467, 0.17501615227333137, 0.13452521285840444, 0.2550038551645619, 0.1275596030588661, 0.11191105882504157, 0.09374749061784574, 0.11650404201022216, 0.10611305851489305, 0.15457151218184403, 0.1422425987465041, 0.1846557328743594, 0.10630096521760736, 0.17450011282094888, 0.2208225993173463, 0.08778405668480055, 0.19740065612963267, 0.13739956862160138, 0.16040896251797676, 0.09281935649258749, 0.207654582336545, 0.10442970134317875, 0.1379018880959068, 0.2085068223199674, 0.11701022913413388, 0.06986448288496051, 0.0918909984507731, 0.12002171682459967, 0.14280540283237184, 0.19851923467857496, 0.13595865879740032, 0.10821893944271974, 0.15762615469949587, 0.13486697737659725, 0.13498420108641895, 0.11663878549422536, 0.1671128206487213, 0.2275169850992305, 0.1080515787803701, 0.21173986526472227, 0.18868526736540453, 0.19717907373394283, 0.19533843893025601, 0.10800307031188693, 0.09379544268761363, 0.1479346254574401, 0.09009628689714841, 0.12163456742252622, 0.2004354718540396, 0.15639146523816244, 0.18109057417937688, 0.16192618039037499, 0.14802491132702145, 0.08990044812006609, 0.09167817594217402, 0.09832243834223066, 0.08349726242678505, 0.10771183629653283, 0.13458324117319925, 0.14847513288259506, 0.09905291521655661, 0.1830342241695949, 0.11911740606384617, 0.07615260260977916, 0.1396496178848403, 0.07651177833655051, 0.12196983157524041, 0.1353018640407494, 0.12976402762745107, 0.1626462960349662, 0.1468766943684646, 0.11707292576985699, 0.07652838887380702, 0.1574391775897571, 0.1687687717910324, 0.13836192126785005, 0.10272955042975289, 0.11421268353504793, 0.1223023273050785, 0.10353021496640784, 0.21298961820346968, 0.09530396174107279, 0.15028831415942737, 0.13516946828791074, 0.13124054696943077, 0.14634844128574642, 0.10830459091812372, 0.13883788644203118, 0.08443686379385845, 0.18103988761348383, 0.1741606281804187, 0.14703229601894105, 0.14447706884571485, 0.12613119184970856, 0.1171462754053729, 0.13522913865745068, 0.15463813074997493, 0.12112352198788098, 0.19416873955300876, 0.058177572142864974, 0.07560619871531214, 0.10949503311089107, 0.09941336658916303, 0.12333915595497404, 0.08181226998567581, 0.12459649491522994, 0.17465054403458322, 0.11224077934665339, 0.16694321403545992, 0.1801387116845165, 0.08729383548987762, 0.10848971562726156, 0.08483674483639853, 0.20076262072793075, 0.11347950609134776, 0.12510011717677116, 0.12150579504668713, 0.20928552267806871, 0.19959904173655169, 0.12330957182816096], [0.003692694864834526, 0.0153391305689833, 0.030596497668219463, 0.021756453539377878, 0.04884657909029296, 0.03728124825283885, 0.005799726757686585, 0.028539359303457395, 0.020739816395299773, 0.01442852639593184, 0.04491954409916486, 0.05086468472810728, 0.0299681878116514, 0.032710188534110785, 0.02803621710544186, 0.03064807311498693, 0.026597191912255118, 0.01575278247972684, 0.012556054729170032, 0.08297948592475482, 0.04762142983132175, 0.05507040762209466, 0.020243926040296043, 0.026618168822356632, 0.04014931060373783, 0.08373810164630413, 0.025662547243492942, 0.019306351796590855, 0.0650316918534892, 0.028647432968552624, 0.014003066279526268, 0.034264637622982264, 0.05705976712384394, 0.046015659746314795, 0.02972511960459607, 0.050559995363333395, 0.03614811173507145, 0.008442853477650454, 0.057360412419906685, 0.03874637159918036, 0.08432322274893522, 0.019972566315638166, 0.04285418188997677, 0.028875665007425205, 0.038128019244010956, 0.06928657460957766, 0.09214658902159759, 0.03976532763668469, 0.025519931056935872, 0.03712125648079174, 0.019791341486520002, 0.0490146895338382, 0.01358053319355739, 0.043203980262790403, 0.020350230425330143, 0.011654466590178865, 0.013910620124079287, 0.043874464463442564, 0.04063800848754389, 0.020130670063995888, 0.02806621344227876, 0.019751457198123847, 0.048633861754621775, 0.05977226514369249, 0.04502340745446937, 0.01766181700596852, 0.06672168509768588, 0.07164919961776052, 0.026009701026071395, 0.018332034881625856, 0.02779257214362068, 0.03774336791996445, 0.03703089936503342, 0.031386156366871934, 0.027987518647153462, 0.049488276442778964, 0.03968601707102997, 0.07373217320335762, 0.0670297739229032, 0.012195187753864696, 0.03766916333032506, 0.03410350251942873, 0.024431952740997076, 0.06185018364340067, 0.01641955679016454, 0.023585726274177432, 0.04321389705208795, 0.04341502161696553, 0.022054837617490972, 0.05305898216153894, 0.0299334468186966, 0.02990386269188353, 0.014762117959825056, 0.029946593434682915, 0.05099636123382619, 0.01887594855257443, 0.10693969737206187, 0.011188871127420237, 0.007306075771339238, 0.0265988322706627, 0.02405387981395636, 0.016617760261786834, 0.05085532433752503, 0.02457593278294163, 0.02211884891481272, 0.0356128731343363, 0.031214860201414143, 0.021331936586648226, 0.09166476130485535, 0.02361187701379614, 0.08780817181936332, 0.021193752930100476, 0.040783723882798634, 0.0227257136721164, 0.04096064171088593, 0.018684929070462073, 0.024493170170379535, 0.05489095885838781, 0.01779487093777529, 0.02446601859160832, 0.02941182641578572, 0.012516971112095883, 0.021923044064481343, 0.0581066720187664, 0.05688711728102394, 0.07956057866769177, 0.042684660093592744, 0.018046091743079678, 0.07567866625530378, 0.0285074783356062, 0.054602428805083036, 0.04189627704077533, 0.006788454908278904, 0.013443251988584442, 0.020510620836700712, 0.03624194634280034, 0.04440380998754075, 0.07535106276295014, 0.04779723146930337, 0.022968237354819263, 0.02174480478944523, 0.008016325516759284, 0.05718307050743273, 0.01009397769147264, 0.046209995568330796, 0.040691911309425316, 0.02553912341993834, 0.010314677143469453, 0.03192659254584994, 0.05996611581317016, 0.045396947767585516, 0.026857540709897876, 0.018977990041353872, 0.02516416666497077, 0.02982372770618115, 0.034588264900126627, 0.03312349099931972, 0.025904746925724403, 0.027990005477996807, 0.039295818723206005, 0.010477457694443209, 0.07276535579668623, 0.004670705978891679, 0.08447934687137604, 0.03821287004809294, 0.00742522143160126, 0.018760648489530598, 0.0398023722560278, 0.03363889262878469, 0.045127498119005134, 0.05622544725026403, 0.040202955582312176, 0.12133648698883397, 0.01235310490509229, 0.010814467378492867, 0.01642662542872131, 0.026614231622910926, 0.03503472397902182, 0.028092272579669952, 0.02617845098887171, 0.0703113456921918, 0.01965898644578244, 0.013473029497877827, 0.02020314269300018, 0.05688562789665801, 0.010642445180565119, 0.023904098297602365, 0.009315021186401802, 0.027722917131281326, 0.03954309384737696, 0.029883099520312886, 0.02389611702944551, 0.06385441324008362, 0.021178083860182335, 0.02037159918940493, 0.036836200526782444, 0.02295478879074965, 0.012538147341859127, 0.03439292484628303, 0.05507727100380829, 0.040802078255053074, 0.03072858808029975, 0.016133145462455492, 0.029857888551695005, 0.07516884218369212, 0.011118602040889007, 0.06343551964632102, 0.04177832729848368, 0.15612386459750788, 0.07413189139749322, 0.03226499153035028, 0.010523693918782686, 0.05091583948316319, 0.024843367182516625, 0.013661078692946051, 0.022745699921090688, 0.03007114532270602, 0.024177486841966, 0.02798870099442346, 0.022595243262393132, 0.03909147111698985, 0.07895168848335743, 0.033530927529292445, 0.04802101571112871, 0.026862616151837364, 0.03105246980807611, 0.021567890354033028, 0.018649891218436614, 0.021480691818786517, 0.03263439277985266, 0.028156775814880217, 0.05590029326932771, 0.0426974844054452, 0.014687738647418363, 0.05627480728019561, 0.03334893425926566, 0.026099489868751595, 0.020222075516358018, 0.03512261122731226, 0.0360056634859315, 0.0117880523238065, 0.041107408835419586, 0.027809050366548554, 0.031023163880620683, 0.03065234449292932, 0.0667602326720953, 0.05318397170464907, 0.024914458992757967, 0.06843219045549631, 0.003958344293226088, 0.021873789207477654, 0.042782301282776256, 0.0723847383633256, 0.04880528684173312, 0.03674828952976635, 0.01813097477757505, 0.027926097657265406, 0.014873143252251404, 0.020028092532551715, 0.010449474062105375, 0.03998688628364887, 0.006365047360304743, 0.04866198363846966, 0.08211323419319731, 0.011644277538705086, 0.061946013144084384, 0.021849163475313356, 0.03213000716641545, 0.028066812249432718, 0.008090664117064859, 0.034185394910829406, 0.032233690709940026, 0.03798128265355315, 0.01455211137155337, 0.07188570299851042, 0.031046902428248098, 0.07313471633408751, 0.023090884255777513, 0.055989164393395185, 0.012701166228258183, 0.08909506097968135, 0.022319096473178694, 0.021441570882286345, 0.01894204634507852, 0.03611512814781495, 0.04254966555163264, 0.06093721477580922, 0.03622071837474193, 0.016954793694562147, 0.057914076639073234, 0.051970065770936866, 0.024699075014463494, 0.005583689265352274, 0.03615074445094381, 0.021373288207022206, 0.03962921351194382, 0.02038687131633716, 0.014826644943760974, 0.01655288552865386, 0.01794070846933339, 0.015581910398655703, 0.017756345415753976, 0.03456222951146109, 0.03051552129909396, 0.010687058009872479, 0.05789648222603968, 0.049796032785837135, 0.013163531864328044, 0.0125215817575476, 0.01765182218514383, 0.01743727789393493, 0.04128047258460096, 0.019459361443296075, 0.05028098176366516, 0.052950511553457806, 0.026021063094958663, 0.011994544100681586, 0.031114196138722554, 0.07577829555209194, 0.04371890013239213, 0.028943766174571853, 0.014182346257647234, 0.05380400004131453, 0.024511030908407908, 0.01654045985612486, 0.03673703602648207, 0.05002584581130317, 0.056146811826952865, 0.0262290595232376, 0.045046399613576274, 0.04370781287018742, 0.0389405886775681, 0.04645565917183246, 0.0375742091398154, 0.04633222686659012, 0.009153009076336665, 0.008034106526922966, 0.051159386057406664, 0.08289196169269936, 0.0642634816467762, 0.04732521876160588, 0.018475278713075177, 0.04898718511685729, 0.018907926211665784, 0.02897292621699827, 0.06280456350318023, 0.026370557823351452, 0.06305543147027493, 0.055347025993147066, 0.015382872328960469, 0.06661784209843193, 0.033210092423749824, 0.08622504784060375, 0.05517093258510743, 0.07585934656006948, 0.11456800518291337, 0.1275057273783854, 0.23514185952288763, 0.09039270492004496, 0.08503748263631548, 0.19350716790982656, 0.08419303223490715, 0.1174013502895832, 0.09527119528502226, 0.12010987209422247, 0.09387977101973125, 0.10274025771234717, 0.091017119985606, 0.19547107895570143, 0.14778260647186212, 0.12802563448037418, 0.17819822366748536, 0.1181549041398934, 0.09536657016724348, 0.06986227086079971, 0.18276876769959927, 0.16341526620090008, 0.20376585743256978, 0.11805524091635432, 0.09894398999001298, 0.19833453744649887, 0.0857656185648271, 0.292650823614427, 0.18222348338791303, 0.16883477967764648, 0.15032271588487284, 0.0913245574172054, 0.10549175113971744, 0.11474694843803133, 0.17370069000337804, 0.09449552797845431, 0.09465495656643595, 0.23979647404381207, 0.0773224580500807, 0.14842482629631246, 0.11360263305583171, 0.11407918855547905, 0.14393334516457149, 0.16465234410549912, 0.1533256404634033, 0.12996753385024412, 0.07916208862193994, 0.08001195373279707, 0.15401448921433517, 0.11890566242592675, 0.12707917312426226, 0.15450127023671353, 0.1678890918514558, 0.12472336739301682, 0.1791577400373561, 0.13295394288642065, 0.1546493944312845, 0.08239308917628867, 0.09042435857866492, 0.12141149224979536, 0.11199974335197892, 0.09158195967652968, 0.09611469573740448, 0.15602443207587513, 0.12565099261701107, 0.08194685062127453, 0.1305016494755234, 0.21997901744076184, 0.11418285513562815, 0.24087119208914892, 0.08067513350397348, 0.10879330576530524, 0.12600818702152797, 0.1294120443718774, 0.143181053389396, 0.15591768494674138, 0.12140497831361634, 0.12110741356653826, 0.08495603807802711, 0.13196047262421676, 0.08173763791897468, 0.09978449810296297, 0.1354073490947485, 0.11786245554685593, 0.19555278814264707, 0.15992052587015287, 0.1154064301933561, 0.08546070528349706, 0.1203468165227345, 0.1101704468684537, 0.12174404226243496, 0.14861848019063473, 0.09602987886007343, 0.1513718803014074, 0.04740245979545372, 0.11274035075413329, 0.07547445435609136, 0.11731791762369019, 0.07950411098343985, 0.2132412325590849, 0.18388018091874464, 0.18729091861418315, 0.1996444221585989, 0.057438851068062444, 0.08413934654423169, 0.13280013256839343, 0.09410353829818112, 0.19764381593891553, 0.11714901668684823, 0.16382116584905557, 0.15332574902900628, 0.13141562257494244, 0.11304959308888231, 0.09205246942916087, 0.15229191950389318, 0.07802066379891974, 0.0778837286468063, 0.1024779292887875, 0.09388570141579423, 0.1087580355150359, 0.19432185776531696, 0.1130632045013564, 0.11427149895046439, 0.09359643515199423, 0.12282843621713774, 0.1482092421501875, 0.09293483636741127, 0.17968023914311612, 0.1603779670383249, 0.11187160201370716, 0.18147313222289085, 0.10365236484046493, 0.1384111421981028, 0.10498779639601707, 0.1919332652219704, 0.1404407625751836, 0.10475596812154565, 0.0852954141529543, 0.09510285074689559, 0.2168166914156505, 0.11519905632095677, 0.12000255499567304, 0.08803387292261634, 0.11493991022663456, 0.14514526299067906, 0.10934786565069642, 0.19415640378636972, 0.13818045386246272, 0.1881317456385919, 0.07467347769332783, 0.10999337636998721, 0.1892814960862909, 0.20246092602610588, 0.12063847801515035, 0.2078333491725581, 0.09854158479720354, 0.09328231415046112, 0.1632852860327278, 0.1537795261080776, 0.16565519172166074, 0.16528856568038464, 0.09916019838835512, 0.04419857689312526, 0.16311189319406236, 0.1680918788271291, 0.15418177523783275, 0.1277988680771419, 0.23749678315860884, 0.1445398876177413, 0.2420484232051032, 0.1063456738899861, 0.17770407375480446, 0.10864520871213504], [0.03147594351321459, 0.03760433948731848, 0.011335744273050554, 0.04388910724914499, 0.03972438483365944, 0.050300951049263985, 0.048211785831621716, 0.011698459408112934, 0.05886771011033228, 0.09876577955271516, 0.019630326822932278, 0.026731316233053803, 0.0461388070668493, 0.03314609978614109, 0.06674827009971653, 0.10197641048580408, 0.06257967664194958, 0.018609989966664995, 0.028516170369195085, 0.04036602111799376, 0.03486490023455449, 0.035322497465780804, 0.055895977786609104, 0.020277045334556272, 0.024855926865711808, 0.02637242209831519, 0.04322683671489358, 0.0207547645217606, 0.024508106422477534, 0.04230666859075427, 0.017193880597395555, 0.0034208769169968684, 0.048128868852342875, 0.03466651355847716, 0.027781579876318574, 0.05276001623964735, 0.013473170293894197, 0.027851382470024482, 0.04114398865827492, 0.045470446680805514, 0.048558513833475966, 0.054164576942899396, 0.05430462657074843, 0.01353852339421532, 0.015008521166497042, 0.02268683531188539, 0.08495844009199313, 0.07902655803731509, 0.01881195421862815, 0.007888745666215462, 0.020790776071537818, 0.022454800084233284, 0.02201360134807016, 0.0031613699268616203, 0.029579577235771076, 0.003851287582490061, 0.05193837479289089, 0.08929737976619176, 0.03401908597775868, 0.032427514238016944, 0.058919950521418026, 0.01728707059685673, 0.01347440098678427, 0.02819584755759154, 0.011078330987532223, 0.006887644005473703, 0.039892200114471574, 0.10076059786868946, 0.019026064247425114, 0.041386710812470744, 0.02102773915976286, 0.06572856767369167, 0.012735754550833787, 0.04373815695622137, 0.02579699386842549, 0.049326544228409014, 0.03913580320243325, 0.05320021244032042, 0.019954137304531674, 0.014239413597221886, 0.013251671866912926, 0.02186706492544285, 0.0016308215978954519, 0.020201804282675897, 0.013177411298134496, 0.025443092055086578, 0.08565314460013594, 0.010142089216969907, 0.038804223494870324, 0.052778906654566526, 0.03682379351396646, 0.04033297985526068, 0.03368243422093136, 0.049311392541442595, 0.00882783389118101, 0.002827945240174553, 0.06676294681216989, 0.018911147556666816, 0.043653207764561684, 0.008700338009345745, 0.026723796368709633, 0.05651350911440594, 0.02465357245611293, 0.03145450859197548, 0.03796928615442344, 0.03252429708040186, 0.038388766680977175, 0.021841784406985556, 0.028501798997500112, 0.022398008399509957, 0.0872176902900849, 0.07044782622584275, 0.02167640676322792, 0.042113557524446926, 0.029189426385398422, 0.02923096969191517, 0.034722095754529746, 0.028038088165755783, 0.0017122967962807576, 0.03000994146402393, 0.051638733728655746, 0.04786871174084289, 0.020020089212006757, 0.06826254313013383, 0.022925542235108357, 0.02868713405249374, 0.05106125293033464, 0.04646704159677029, 0.0472992512264422, 0.007956763712822326, 0.019063303945586085, 0.02734570424737675, 0.024578881017597656, 0.019651249450232302, 0.009801574051380157, 0.021684313392532722, 0.040381030312606266, 0.042636188944535594, 0.03734253014304808, 0.05854151118546724, 0.04189189031187977, 0.0390091614265527, 0.12302956756736551, 0.028894470605467047, 0.1256161973412548, 0.017228726763278246, 0.04321697081572243, 0.012840948682943625, 0.013670001428441277, 0.06841269614441053, 0.02401947639217334, 0.025218973634764552, 0.009188956165287112, 0.0054845116184359145, 0.015327171389279621, 0.0507855573669076, 0.02153340890072286, 0.03539841535634228, 0.030258376883076768, 0.0423720691885267, 0.019408149012763585, 0.014755558222532272, 0.03583108660365854, 0.02776899983707283, 0.04878325820235269, 0.026747889450884292, 0.030856257836733545, 0.020754754343735318, 0.07432329255555357, 0.06404439625995499, 0.056785978243819306, 0.016531399717288356, 0.027268112071656754, 0.08643229279134955, 0.014414068511021989, 0.03604124925498452, 0.004408774498317922, 0.032284200856728215, 0.014645503235182591, 0.07650447729974985, 0.006384454310006861, 0.04222128174400755, 0.05590745520644954, 0.04387543476851923, 0.03148419789171644, 0.021253730336736356, 0.08739492363695588, 0.046386859113616605, 0.04337069631687232, 0.02260177585828517, 0.05530222571854081, 0.036849072336086204, 0.016377708142889396, 0.024325032585433552, 0.033380163833498955, 0.0443272780227874, 0.06357817484864167, 0.0025446456316525912, 0.06934487433837992, 0.03740116235400949, 0.05867985769041947, 0.04548181892771806, 0.027644086629152298, 0.05820470675826073, 0.024230784071343284, 0.024272614058905413, 0.0851402874769909, 0.03616955004898565, 0.04051653375583036, 0.07208213210105896, 0.09391779612217631, 0.03053664748689958, 0.09842062914477927, 0.030081469233014753, 0.061068497731217315, 0.061399697459169796, 0.05204413465357252, 0.05975332044597183, 0.024482437442722063, 0.0066535702041749445, 0.011385290900112262, 0.0300757729315332, 0.014590779385928596, 0.014958367250593645, 0.05912708690656083, 0.09318930735545498, 0.03284721189577665, 0.013687715433271868, 0.017872485165883387, 0.06867195758968592, 0.03894773365131446, 0.022445105515154343, 0.06351582426577806, 0.03756631438487342, 0.02793290845251509, 0.0776022451796702, 0.045051057756479294, 0.026533165347895453, 0.07569824877594199, 0.051635307126811573, 0.04622871295682021, 0.014286224031820893, 0.011099564044603279, 0.04349065452281918, 0.039715377281286886, 0.021274980357182876, 0.05826629059655326, 0.02121624127695603, 0.013554622485701526, 0.007100483477448246, 0.03825319877692631, 0.020363672204049568, 0.01602340769022703, 0.02113678821894739, 0.012167322865155126, 0.020592250295781662, 0.03499026297192488, 0.012791242600152535, 0.04772474018058606, 0.01930790564178356, 0.030592938752046654, 0.034456747850137096, 0.04627884651667305, 0.0034943455081832197, 0.050761625436799865, 0.04250679570915444, 0.0522172967903316, 0.012558941047505608, 0.060160821436771324, 0.008624716977854925, 0.012373753573878534, 0.01895007680702422, 0.014995187953380602, 0.018139140946524482, 0.0131148062646389, 0.07809235102363996, 0.07118651337389435, 0.022166305654016987, 0.06811840193612234, 0.03179497032293251, 0.03738438557567341, 0.06374204784099545, 0.021939430685181702, 0.060481843139444075, 0.03758840409240552, 0.031882396167410273, 0.10567523379411016, 0.05609982666958656, 0.006627841852605343, 0.05329498342637505, 0.08429840872330324, 0.0625727962968605, 0.022691646125167608, 0.03445812527622495, 0.03875055816024542, 0.05524089293820517, 0.03543129716334598, 0.024357215501368046, 0.009258632381845797, 0.048984969700021405, 0.056628123857080936, 0.07612233994794743, 0.013263793046852308, 0.08625000435858965, 0.02251103876291641, 0.021558769147044847, 0.040585075970739126, 0.010120275164289134, 0.008400758861431053, 0.038277900844280205, 0.036529825002487214, 0.02521546391238059, 0.03906062491504209, 0.08230810266520296, 0.08590987510979176, 0.06502248413328614, 0.023242526654420153, 0.06452784567539181, 0.0415824240605746, 0.057525581414146085, 0.10622349687452827, 0.006587567406573466, 0.03504976031503507, 0.08158936444669962, 0.028560085155602013, 0.03775707772001624, 0.03659331213150706, 0.01609462672578437, 0.03498572017997503, 0.0452374581114522, 0.019669688639364073, 0.01074789630781327, 0.11485385841556958, 0.05593327346390911, 0.036286726261356046, 0.06344085293156759, 0.009609522347870682, 0.04232480922447784, 0.01208379096351564, 0.03913397455055799, 0.0339805723301002, 0.05391472338565758, 0.021189722432089702, 0.023587699114744152, 0.04113121862922396, 0.04492226502458964, 0.0334202041849494, 0.035111601996634684, 0.026123971412224428, 0.07253250293433666, 0.04745897836983204, 0.06071566630687032, 0.2109988643122571, 0.12662530105028832, 0.07497569040528365, 0.13130468209939344, 0.08047450426965952, 0.0952706728130579, 0.1188084962112563, 0.09510257933288813, 0.15111561119556427, 0.07825097215494939, 0.18084208108484745, 0.0987187706466232, 0.14618327229150704, 0.13731186118509087, 0.1494697973664318, 0.14801588681127342, 0.20001081749796867, 0.06609426412199225, 0.12804901679711683, 0.10589837682034288, 0.1779494998710496, 0.13080137196396077, 0.07780348509550095, 0.13333473673888616, 0.13018393223839148, 0.13528656986142906, 0.15635688709361212, 0.12121536848800522, 0.16754453176898615, 0.16566873528063297, 0.09518491277205092, 0.13394790169383797, 0.11826200410723686, 0.09254945561821971, 0.1644958332180977, 0.1259258942944663, 0.13187653784240994, 0.22153491180922302, 0.14449445291289262, 0.14678891907845223, 0.1310345573084695, 0.12675646186939307, 0.11189146951905318, 0.10215817644659962, 0.10205483556325946, 0.13265876658260822, 0.12763748530830654, 0.18432109297386237, 0.1279880843524422, 0.15213779705975736, 0.10700865688600711, 0.10356380923518113, 0.12948128208518028, 0.12864551693201065, 0.11174104509076901, 0.08062467763998679, 0.14534119676266397, 0.17762962489255837, 0.0670633614063263, 0.16195938789418765, 0.16094026900827885, 0.11032471180494342, 0.09189126986478056, 0.10028558942888464, 0.0935451921873859, 0.08729201023067747, 0.12458044077668871, 0.15343632309564523, 0.08963134791702032, 0.09065592222447906, 0.10021821768688303, 0.07285361963191203, 0.0821639953979424, 0.12289536691137723, 0.09247761911579541, 0.13571798242628574, 0.11390412652066775, 0.1072791005883898, 0.12900357986135141, 0.20502880109207972, 0.14850064579929623, 0.08649961703589984, 0.09879972665969815, 0.10970322801066296, 0.05492458366123693, 0.08925801116440978, 0.22916999139956065, 0.0823948330112866, 0.18090678618422576, 0.12059060058423451, 0.2168249288307769, 0.10179472594921078, 0.12000974746687071, 0.12854700721800327, 0.10908498082842145, 0.22761244140565395, 0.11942490456359726, 0.19020139958177293, 0.17878044742558682, 0.14048680796154908, 0.1561545343803508, 0.12828978816313402, 0.20373676185097012, 0.14237316245479242, 0.12814759436462606, 0.10989283783627407, 0.0881670354200261, 0.15353210509887763, 0.12398525699973106, 0.06865358286138092, 0.17522383827183927, 0.20096960105001926, 0.08679543794797999, 0.17129972098129137, 0.15242637800318853, 0.13886291081351892, 0.10683704859444074, 0.1648107548909528, 0.16418897254126413, 0.14562430871384485, 0.10076563938387803, 0.10327117065233843, 0.08646252831178051, 0.21133138718349592, 0.1374171698199851, 0.1410306537789958, 0.10176805952297789, 0.1298887695052794, 0.12001736062977995, 0.08263484441808291, 0.18030156008899212, 0.08354993710028273, 0.17043673300317355, 0.14314290615064756, 0.1385064763682229, 0.15818099278424466, 0.14225692940609796, 0.14924906992486545, 0.19228177437824862, 0.14664086273738317, 0.13254184142819472, 0.16447957551905087, 0.27287500192012104, 0.16157909615763597, 0.18279356136918068, 0.07915849917169128, 0.13668302207120828, 0.15458205661603383, 0.17532104519861086, 0.10953843221068382, 0.1177356509225709, 0.08820350667727844, 0.14966001787355968, 0.1712298183036702, 0.08228278652365718, 0.1793432379407542, 0.17426274770072528, 0.15417790758822644, 0.10444129072129726, 0.16618947019534452, 0.0853724278775709, 0.09623946475663356, 0.11858505462961537, 0.14049595461360045, 0.12798435240983963, 0.09555166773498058, 0.1465515268168279, 0.05897504077958209, 0.13698704647166388, 0.11757680587470531, 0.10741214773484639, 0.1760539444429534, 0.10971061047166586, 0.1865878477692604, 0.11802195198833942, 0.14637309924832412], [0.09782604247863803, 0.06393713344420705, 0.08721308303730828, 0.027029305064518536, 0.04261098136859281, 0.046774200829012055, 0.02238801697136036, 0.033592457084783485, 0.02669046842493117, 0.014421249107856835, 0.06077564201716866, 0.06544321655694928, 0.03229920326599053, 0.07522747439465352, 0.030994020801569735, 0.04911165897335325, 0.019967964151874185, 0.02892359672114253, 0.03155547460275037, 0.05349056775282536, 0.01710591701391552, 0.00425169533783836, 0.04413522547110915, 0.04606939971979175, 0.04782280206148114, 0.05820832334991012, 0.02436003990338317, 0.0035520267099075553, 0.13196480167763575, 0.021033018162207942, 0.028441523035456027, 0.04212561509172831, 0.007866813718075199, 0.004462226094411952, 0.015020951928038682, 0.025970878644979427, 0.031207813615245477, 0.03209849260747433, 0.06818337844950811, 0.029823212019566978, 0.06974757808659758, 0.0500325090251863, 0.06594069129122154, 0.021061784654323543, 0.04530783915626151, 0.0026927579518607153, 0.023252038019044057, 0.07682180098657097, 0.0391624323092401, 0.02662270822163139, 0.04386648489162326, 0.03949519606041057, 0.013381905637548437, 0.041843622723328214, 0.029094336487885033, 0.037530518269964626, 0.03840613717745457, 0.03028044623455831, 0.02659900190441736, 0.025817634903692772, 0.018821484242965068, 0.01737267796748451, 0.021358794699023877, 0.06553992136780705, 0.09566130542329379, 0.013500588197660233, 0.02157087930079017, 0.03491341209571276, 0.04559296974912286, 0.05828091302620513, 0.036329511286956925, 0.032752617328826866, 0.05458928897444691, 0.03206061339005828, 0.043431001116654704, 0.04965438860069428, 0.02738432815697576, 0.04535621531041605, 0.04693006371547069, 0.05216978576832584, 0.032357028020279746, 0.06298255002392189, 0.011101730267650314, 0.03567740520728486, 0.04017370054498315, 0.019568312114902904, 0.07342985192579882, 0.010370176218982254, 0.014939900920061129, 0.08930869094495263, 0.00983431251786117, 0.044223960888172896, 0.12988916305559023, 0.06723541074565478, 0.033281236820455105, 0.014077441351089095, 0.05598850960710219, 0.04041680267878941, 0.03272712476817625, 0.034408168135476966, 0.03071642534009048, 0.037522304603563886, 0.0366157275358481, 0.03039072174578905, 0.028387823774080192, 0.03478988818824291, 0.08432882066283907, 0.005558853611416582, 0.06234938185662031, 0.03538358597350972, 0.03971621187935982, 0.017243771580979228, 0.03810604488743203, 0.09976260177791119, 0.053184127767703364, 0.06201194639184645, 0.03274785401299596, 0.07549206912517548, 0.04902998371315854, 0.05153588139052902, 0.02867708834154265, 0.06185329133378608, 0.035977931759719334, 0.01616137082289372, 0.06979954708367586, 0.07238475871937615, 0.02727626806258091, 0.02800684841349721, 0.011330818956983941, 0.02986772052411522, 0.03582394162991217, 0.08340494095214776, 0.0176833129953593, 0.024584073506827866, 0.037388507675911696, 0.05481123099369662, 0.0494575829112104, 0.045796051887529235, 0.05601506746773209, 0.04382009684507336, 0.04413534760741251, 0.04735609210495438, 0.03186773641833237, 0.06507388994629894, 0.03390439320355654, 0.013664145671230341, 0.025061288881780844, 0.029535560669111352, 0.06992880800472838, 0.03669991337561181, 0.03171356308407017, 0.01015115190031273, 0.03314556374347635, 0.06252618094107934, 0.014044267774027373, 0.07714947911777667, 0.042621563122208626, 0.06357079917298895, 0.02500276523642242, 0.03418753908148833, 0.02832961225483034, 0.04310441203415394, 0.06178845052740403, 0.01812181285848575, 0.04346385917493275, 0.039133231554712565, 0.05461337696760893, 0.05849022750875779, 0.05319208359079702, 0.022731087669464092, 0.02534474179680858, 0.012446410255506635, 0.10724440030753613, 0.039709236539368115, 0.016883555999291793, 0.07774033384131533, 0.07123713208628552, 0.04383075663021632, 0.03141802376402276, 0.023616899869271686, 0.038841807549553256, 0.020259427172797065, 0.03552735397326095, 0.05167678597250155, 0.04879019283024328, 0.009104953529978437, 0.02452372799494437, 0.02694759757391044, 0.05584736753787313, 0.041591465539698086, 0.0811501962265798, 0.07444726768881083, 0.0028243653318246026, 0.014874839589798024, 0.06506591715982982, 0.057594778415347846, 0.02559355041012168, 0.09091147886855261, 0.05122072562309248, 0.021697782312652895, 0.014961346019325512, 0.027382484238062586, 0.032398557756096125, 0.018942511141566292, 0.09228889817105872, 0.023032545511211668, 0.0669774588729654, 0.04526512537683759, 0.056285490814064226, 0.005948378937318921, 0.02025431950044419, 0.019289400295487473, 0.022349231909694414, 0.021794381950582777, 0.020507562340104153, 0.042940318517919095, 0.07310009747743607, 0.004422345622775278, 0.003639386185178799, 0.034311127449784956, 0.018087763971249973, 0.006104702379421464, 0.029876731469162872, 0.0446523912916226, 0.04224809744794454, 0.047690209533487044, 0.038831761838602166, 0.044293422518031936, 0.02894657870222415, 0.08907131225402866, 0.04834700429013797, 0.03590256687519806, 0.05606853602720158, 0.015955499905560697, 0.014394867666331785, 0.07675821546997343, 0.035935153519468646, 0.01328640353001122, 0.005610865865102304, 0.05432384268247655, 0.0327528514234083, 0.04685217468068004, 0.012369202300240951, 0.01440883191701557, 0.010705468361265957, 0.025880638576511825, 0.012179162453061767, 0.047418337514890094, 0.05942930640386684, 0.028224072918029766, 0.028739503385233026, 0.046394472276525836, 0.0037885154597461224, 0.025161574661199535, 0.0345084047211068, 0.02190038438753358, 0.013595756126700767, 0.065441242020045, 0.026830859016627073, 0.05509421741589904, 0.03674645409254091, 0.0391538997313806, 0.06726729510618107, 0.01814171259424516, 0.04340504375951631, 0.02786216269513326, 0.027304839475878646, 0.038815928223942, 0.10133125260472298, 0.07949979550072125, 0.03003334074414202, 0.031092021614313126, 0.050466873217374086, 0.07875789888203144, 0.04566471804199474, 0.011519083586920584, 0.05515871895477176, 0.10086567580167737, 0.07113102278006928, 0.034339283260383775, 0.04359604458191565, 0.041957799810916185, 0.010190975120557206, 0.01404053667959358, 0.04113394633999892, 0.02261307685902076, 0.06370811430471283, 0.03339269637529339, 0.008189957539018775, 0.08695800815309797, 0.02791519699219082, 0.057761128060519695, 0.02874532521569303, 0.0648642090548362, 0.07082509848156146, 0.004506778703736407, 0.028003085936818804, 0.07989082844661814, 0.016963389036910873, 0.04571731807664037, 0.0524839271259095, 0.06454306521586009, 0.009558359959295817, 0.029672119234289442, 0.06814845425209828, 0.03587828889223082, 0.05782149053577866, 0.03911055830706443, 0.0175427951783474, 0.023440753874768103, 0.08295749460480042, 0.05319411919585296, 0.022957818449607918, 0.03352598440168159, 0.02779812764908586, 0.019109982065856457, 0.010259337523686034, 0.0322177383516516, 0.03342447895556688, 0.035543655777083974, 0.08304942252912692, 0.005650828609109989, 0.026698325860447118, 0.027156625375417725, 0.014092517551034689, 0.015656391491315196, 0.09045983917479004, 0.014100917814565557, 0.014397271376635348, 0.027914409891569188, 0.021462751352893453, 0.03125558587323342, 0.06075401710612433, 0.033555134266082726, 0.06923286856285163, 0.05655866561989699, 0.042473099660128355, 0.027559505542740226, 0.05309787578880787, 0.02186576383454459, 0.025585292638944726, 0.04240205704367586, 0.0181895357423595, 0.06475527704294239, 0.02722567818792803, 0.022672821867412755, 0.03638226738465684, 0.04314087311338101, 0.020971106930768917, 0.01823668205179274, 0.018716557284018824, 0.07299744191446475, 0.2270508451121194, 0.14282357400017126, 0.14697806750025066, 0.09193508965628487, 0.10797382545258317, 0.10309894489390509, 0.1666304636746645, 0.11536844580301217, 0.14727629721164703, 0.12960216988410267, 0.17035304249397346, 0.14934057715748036, 0.1453731693327427, 0.16032277499990805, 0.1686740754438298, 0.1597864202090672, 0.1195469865841525, 0.07795783824154309, 0.1364863147693021, 0.15846164843865804, 0.19716946567807878, 0.22947943050946507, 0.1423206709857498, 0.0983327588598643, 0.08789150270500354, 0.1572098463241543, 0.06059823903654303, 0.12343995911734444, 0.17969148925372533, 0.15060752417360032, 0.12082287669181824, 0.18161012844315597, 0.15159723535180092, 0.10309319770229713, 0.15764072963169642, 0.1551532745361328, 0.1831618430359023, 0.07995197802249875, 0.14916524370866163, 0.12731609041137354, 0.22427726536989212, 0.10161983354815415, 0.13817802470709595, 0.1280741904463087, 0.14953526242503098, 0.0999183187793408, 0.0930523993447423, 0.1647215411067009, 0.12576954625546932, 0.09046629204281739, 0.13144030767892087, 0.11731759192688124, 0.08197942030216966, 0.21829223366720335, 0.10382619872689247, 0.1024195956332343, 0.2047534380108118, 0.09883482049086265, 0.08722405494855982, 0.13629806201372827, 0.1523875929415226, 0.06522344584975924, 0.11170695549143211, 0.15120235511234828, 0.2525707371532917, 0.2163684240409306, 0.071326949766704, 0.11266598331608943, 0.07845156746251242, 0.1495883102927889, 0.12268426109637533, 0.1761027853935957, 0.11105354662452425, 0.12448251460279737, 0.10442594904452562, 0.09478393928813082, 0.07013103179633617, 0.08459049090743065, 0.11753781725253377, 0.1644488921655076, 0.10361794954431908, 0.1196284107863903, 0.09389311101819788, 0.10972538896437202, 0.1470738902155842, 0.09375532769731112, 0.14414096330957754, 0.08028116250144583, 0.14119085589689867, 0.14064276245023521, 0.1447868879352297, 0.16956891385572298, 0.2412297571344035, 0.252627001277038, 0.10473710484802723, 0.07126825648759093, 0.14761457405984402, 0.18238121563834803, 0.1007622399234346, 0.07556381741804735, 0.12093875690230302, 0.20202567295304366, 0.16929128446749278, 0.21948459611407348, 0.14534965130899632, 0.09328879415988922, 0.19407606524016174, 0.1252442922975336, 0.17754543226744446, 0.17922309653035232, 0.11090207725231137, 0.08476097283086606, 0.08729930448212794, 0.21758176679057734, 0.21744411917669432, 0.1889606033052717, 0.08986131700554065, 0.2052248027175665, 0.14921886154583522, 0.13035378312425955, 0.1516438235661813, 0.1531211028673819, 0.10312840009906463, 0.2565587860132967, 0.12874600796827249, 0.11357111510421548, 0.06873738872153418, 0.10582896268793515, 0.12631989243839467, 0.12377355407391276, 0.11218929889478854, 0.1744799196187939, 0.09047121142170259, 0.10379991906562022, 0.1611208136060408, 0.10300177189388446, 0.09722619038075209, 0.20296758812453064, 0.08336927036621741, 0.1268773903804166, 0.0825405212651406, 0.1551881648067917, 0.05388146159904344, 0.14616297052374908, 0.1339854925338711, 0.08784431059445653, 0.10975062368171555, 0.07012301829776593, 0.15758363769522735, 0.10693091712892056, 0.2124404391007764, 0.09025670614625726, 0.07639811015022652, 0.1737467082483428, 0.09685357966061149, 0.15660303245697701, 0.11654270493558475, 0.11900590918958187, 0.17951607438070433, 0.16288523535643304, 0.07608789072505065, 0.11357580378119435, 0.1406136125858341, 0.0812133474807654, 0.1050417535007, 0.16534833104482718, 0.11224396167589085, 0.11099464978490557, 0.09303202972348247, 0.1648712937853166, 0.08358896643455539, 0.13111896706478937, 0.18278693886739866, 0.11546729478452887, 0.09231944581759827, 0.16633344175560133], [0.07150667333709342, 0.07590674223112208, 0.026289542438462377, 0.028055533301085234, 0.007650607864239386, 0.04032317163156612, 0.07709623447486333, 0.014456480342362608, 0.0706451984920672, 0.02856657195038029, 0.039026243545647175, 0.04225759693820562, 0.006553054995103074, 0.02835523204079696, 0.03414285076516015, 0.022815183603337834, 0.02301018947868475, 0.024779092952875153, 0.05410707449274404, 0.06792759788887841, 0.05421489370720727, 0.058988699689507484, 0.038972384828541956, 0.0057749169728984785, 0.020750761165150573, 0.030328371162925447, 0.021436347858980298, 0.02778176816978625, 0.030183225737086365, 0.026190084471766437, 0.032521973097962995, 0.08841244796557085, 0.05836791478629623, 0.02222792341906045, 0.036192796658724546, 0.05898394315902676, 0.07403574977070093, 0.029956167563796043, 0.020480653337602104, 0.010041101153806915, 0.03863235396732177, 0.015426412224769592, 0.02914135217932718, 0.03642382086919887, 0.021894974767097404, 0.03860778421429651, 0.026725024517093385, 0.018226900969498923, 0.016625139330114638, 0.03009115532040596, 0.036922052170016935, 0.054077079852244685, 0.02245386370590755, 0.01274712594957756, 0.016177684501079575, 0.04782766376488975, 0.07799667758601052, 0.01310209306289575, 0.02068455989605614, 0.07292489973562104, 0.05353623655225549, 0.055865189260137935, 0.03350360631676657, 0.08770244249275752, 0.028015988280198405, 0.008220345729828944, 0.02453877790165799, 0.03944063845223614, 0.04806540547204869, 0.017074589052104523, 0.06841554599148886, 0.05598353933809059, 0.045006423722952604, 0.0355415353551507, 0.03268520148204906, 0.07976941817573138, 0.015844296497691954, 0.026788696546905806, 0.03150945635778563, 0.02116481341155512, 0.018456359460417713, 0.021770948743713752, 0.05813839353088822, 0.027184905018657446, 0.01351024883998824, 0.04240413336083293, 0.035629677054073126, 0.04074913216754794, 0.03773378361282604, 0.03845449976090874, 0.009014157910964318, 0.011015779388669347, 0.04043879060606871, 0.060539593254881244, 0.055108520934092145, 0.060234042150633674, 0.018295919855258296, 0.06672946789434978, 0.03392792819067836, 0.057154985943010876, 0.007244750624522567, 0.0539967446987118, 0.020944007938461642, 0.025151347442130958, 0.02433692560797291, 0.0817566029727459, 0.00728625915611961, 0.1022263624306236, 0.030795949644276073, 0.03579806230430092, 0.033595262827085595, 0.03749367042577692, 0.014234163432515093, 0.004566369769496045, 0.020567073253914714, 0.06281569826283626, 0.012137374025769532, 0.010799503984994121, 0.030203642855797495, 0.035771311061190705, 0.04752941709011793, 0.033865984728825946, 0.023356125290904726, 0.04621823976880737, 0.039150537590363195, 0.06369714239346129, 0.0037278654552730067, 0.046868652903607914, 0.04490013121228133, 0.001096678407131029, 0.03715504413204534, 0.060971311160496304, 0.030700327096773044, 0.021210746839642525, 0.052472232574863095, 0.027515953772568276, 0.008689680768709098, 0.04451130689787013, 0.03901636746845075, 0.011210406980743366, 0.10133839757846934, 0.0667955232784152, 0.011389819273192967, 0.007989765959791839, 0.042669488050575764, 0.04803599776434047, 0.06789134376283203, 0.08548635390720197, 0.05732429400086403, 0.05709965819759028, 0.017913361811744313, 0.00987431894256068, 0.028822369474385465, 0.041328119313610454, 0.035953036309885125, 0.010657213495246001, 0.049167702573218515, 0.03732921050063201, 0.004419554299342313, 0.02963309668536697, 0.014923158068475979, 0.023180790145748427, 0.01931056210638157, 0.01685484209364014, 0.02128345356322825, 0.020502871966787746, 0.024836931277864745, 0.0476130193897656, 0.01822039551500763, 0.04049169937414782, 0.047212235895650725, 0.02864149578713945, 0.05040620879403182, 0.032358469907194376, 0.03514364581289036, 0.0497833984637899, 0.04221877455711365, 0.076776902324387, 0.0150653976680977, 0.011934623521353518, 0.020352310135162303, 0.04206834673615439, 0.05500570252271635, 0.022676165348717144, 0.0718716098261731, 0.01806662930175662, 0.03651206434837409, 0.04221818423164742, 0.06057578631277595, 0.033715760468372276, 0.02803396776185504, 0.038833403893347294, 0.012741751952229865, 0.042460658720561435, 0.02912371026884232, 0.02871949678020818, 0.047481794109834094, 0.033432638339166126, 0.03489844022052629, 0.029441715883357183, 0.025413675865690624, 0.07351553732795374, 0.014335034448387367, 0.053705846558191946, 0.013359058515301772, 0.03155737789347768, 0.023183729898716723, 0.01997855947619038, 0.08560511110616581, 0.02349528094886669, 0.06622749447290387, 0.017268648371100426, 0.07826923153230123, 0.017447922412039976, 0.03177933348342776, 0.0256592054585261, 0.028208566696516106, 0.039101353979536464, 0.008266344466911895, 0.02841830187078033, 0.05281077065904226, 0.04242497456393071, 0.012939622941693025, 0.072481829939144, 0.05034768854134849, 0.08358532948685543, 0.0944789174411978, 0.0446541486973209, 0.04904649247016225, 0.03166189942775028, 0.04698880449203508, 0.044122377410531044, 0.0810674149543047, 0.03719953567321811, 0.028828103095293045, 0.045462290689881356, 0.017704808984750083, 0.02788948390765914, 0.03845106976638947, 0.023686276682253395, 0.008403037042756165, 0.030744927203548805, 0.03751290350088051, 0.06677619181573391, 0.02636207783195589, 0.008964473032392561, 0.07793138216116599, 0.025768612444932972, 0.02849966161219137, 0.02350181693743382, 0.02570847388623016, 0.051940705560679944, 0.023295647464692593, 0.030275024739759307, 0.050547069271228144, 0.04572188122464078, 0.04212927578815392, 0.04842051338138325, 0.03572976775467396, 0.06111974748117583, 0.04030117352626153, 0.02025184963297631, 0.054951911659113, 0.04349228979221412, 0.06151528589959655, 0.04216760962403246, 0.04665439868611949, 0.03147707666669573, 0.0437933184605624, 0.044168924912810326, 0.0669874536937901, 0.07547250017523766, 0.02110301244205662, 0.02731718372420541, 0.0230868741138173, 0.025345437295202698, 0.012239135618853782, 0.02297219999932817, 0.0203421185391822, 0.0638162660013352, 0.03468992980197072, 0.07809149606951646, 0.03635800297238997, 0.030492797161319425, 0.07020263759685413, 0.017610017642644898, 0.017064361833035946, 0.034967616865677495, 0.042450558726808856, 0.04329260032890098, 0.045164542738348246, 0.06597981562039681, 0.010407394712923892, 0.01765866860348199, 0.024932669176320945, 0.07162065364952598, 0.05532195073153291, 0.02597370813600719, 0.04771953920966812, 0.008884996225658272, 0.009123550478502043, 0.0427703794224986, 0.040054319093802145, 0.08179696902100529, 0.028403189199577485, 0.06542870947825057, 0.029891319972063814, 0.036836519438241205, 0.07870411141110317, 0.052450007160327265, 0.008367247713197554, 0.014723582259778465, 0.012382946027043675, 0.01218002419253545, 0.03566279634833336, 0.06035817334694522, 0.020441756317658082, 0.07423640614641563, 0.07294301662061896, 0.054886670517069955, 0.03411044053999441, 0.06855522242507764, 0.045991761742958, 0.08877316396683455, 0.022515023459813426, 0.03915798790486796, 0.053619733678975275, 0.05394696058439357, 0.08279360804174628, 0.027473587742341415, 0.017375856904046874, 0.03047576253967626, 0.05377890781632491, 0.026858870638534427, 0.03900511396516647, 0.02479407500608691, 0.015067015974117177, 0.03928711651159184, 0.011950793010847909, 0.04556813197476523, 0.0454312952102295, 0.04702559805342129, 0.025736460063074316, 0.07521481293120555, 0.07081418763846159, 0.06412921992263623, 0.038717360834458044, 0.032951594330370426, 0.0797738761508039, 0.053378110751509666, 0.024724411512059823, 0.06691073173923151, 0.16311008829091275, 0.17425740084477834, 0.13804778669561657, 0.08366359171590634, 0.15096870836402687, 0.10633908531495503, 0.23047134014112608, 0.11517414051507201, 0.13247580640017986, 0.11130013982100145, 0.08773638281439032, 0.15061284388814652, 0.14893640098827227, 0.10858967062085867, 0.17266284355095454, 0.1179014713104282, 0.08398862356053931, 0.09514240933848278, 0.2440018712409905, 0.19714559481612273, 0.10683001218629734, 0.1893022321164608, 0.1315143901322569, 0.22499672962086542, 0.09346272982656956, 0.12530009501746722, 0.132654356104987, 0.12439506500959396, 0.07260263631386416, 0.17463508700685842, 0.10860318025307995, 0.2198858002998999, 0.20547690561839513, 0.12085696629115514, 0.18561565636524133, 0.1015545924061111, 0.18344775055135998, 0.1305727870868785, 0.10623450271253075, 0.09286153422934668, 0.12110358662903309, 0.07366658600845508, 0.10906544580523457, 0.12935508814241203, 0.07405951885240418, 0.1180145830980369, 0.08302594521748168, 0.12924562687320368, 0.08509045586522136, 0.09461625971432243, 0.1329288235200303, 0.12567715692733014, 0.1116072651264923, 0.0949176921110068, 0.13406519325716154, 0.1397710485117776, 0.24206003972462245, 0.14677515838827404, 0.08727290946990252, 0.16577249685568468, 0.08730960464371101, 0.21948125772178173, 0.1255683470517397, 0.18370389752089977, 0.09270323200949601, 0.10243739360677344, 0.0928333071725709, 0.20373536406883172, 0.19727457075246743, 0.1627496640597071, 0.19642276503145695, 0.12854942280266965, 0.1637367560927357, 0.15382759352879866, 0.18153866513499192, 0.1392185174460922, 0.12253412843814918, 0.12156484116400991, 0.12178360085402216, 0.08982276264578104, 0.13870635921401636, 0.18963556922972202, 0.12919563241302967, 0.1464590967765876, 0.06507524023098604, 0.11316053356443133, 0.16739119642547198, 0.13100875940706047, 0.10299593649272408, 0.13892720879188605, 0.16294466145336628, 0.08178770023265056, 0.15354988271636621, 0.13648900176797593, 0.17359341361692973, 0.15885879498507294, 0.0729723564748253, 0.14159368856676988, 0.20158725790679455, 0.1360114352511508, 0.09123739959406, 0.13623983013842786, 0.11108045732336384, 0.1700066775083542, 0.08505734335631132, 0.15370267523186548, 0.07755271212330886, 0.12039136913205896, 0.13761469136391366, 0.14505022737596715, 0.10906342377087899, 0.20745357312262058, 0.1616804285773209, 0.10473447213215487, 0.09911175098802362, 0.2246610312057393, 0.06528704493705716, 0.08093021517353398, 0.07461913382368428, 0.15994351463658468, 0.1342250561075551, 0.1260669074420418, 0.09207803662866354, 0.10312338572527681, 0.10030652901956014, 0.1295342892408371, 0.1595842032028096, 0.18200275594634668, 0.13650018402508327, 0.12510849029890128, 0.07411109429917165, 0.10332901576267821, 0.2100442876773221, 0.1484783762799842, 0.1297038144298962, 0.11200955496834857, 0.07459911025528397, 0.07906664588621684, 0.12034526946289198, 0.09738726780882903, 0.16099387327475206, 0.11092993111482688, 0.15469054079481534, 0.12099244259297848, 0.09064317933682885, 0.18113420398107596, 0.14555260113307408, 0.16307044827512332, 0.1363415289670229, 0.1630364672413894, 0.09775670298508235, 0.11138237147991147, 0.16001440797533306, 0.08615829356546913, 0.14719215886933462, 0.0956916291532772, 0.1951839772186109, 0.050786958541721106, 0.16299206390976906, 0.09710613717990262, 0.1063036590016314, 0.13078063593379088, 0.10150772599237305, 0.11975824167685849, 0.18084829646561826, 0.11566639052970068, 0.12491090090147086, 0.20490100580666745, 0.13739396392234735, 0.11279790409441505, 0.1702279206365347, 0.10260122588702611, 0.14001732958214624, 0.11783192147101675, 0.07087822098817144, 0.11293576883950404], [0.030330274453652755, 0.01980021333188883, 0.02673921098799578, 0.014052282968935157, 0.008040009781585207, 0.016865568035947423, 0.12428700152252402, 0.043683948793581555, 0.05959667385156665, 0.007561198153000857, 0.04019652985568557, 0.03308710116626961, 0.0442128634479429, 0.03687911447403686, 0.02612015974175717, 0.12066453375986644, 0.05484501185960003, 0.04378943045490554, 0.05408504246068852, 0.05780671204307249, 0.008241030021703668, 0.02390012377873063, 0.01893017876760236, 0.04180336184799671, 0.028180650069511363, 0.05451855169875281, 0.07164908426680736, 0.03624805994331837, 0.012203955274474407, 0.03825893239783389, 0.031507305401776514, 0.0434778912791184, 0.020606524976236478, 0.034141527621873786, 0.03927046186955912, 0.01414876725591187, 0.04535082774236798, 0.06261282986296074, 0.033468234286244423, 0.014770090746294175, 0.03185935311817697, 0.03743101450215493, 0.024515083458806788, 0.012863923030506288, 0.05256507991413985, 0.03849129671497004, 0.08099342749587127, 0.016567470638879707, 0.010049881396948226, 0.019965272064187696, 0.006763528500284467, 0.026885073964617083, 0.007821393432095647, 0.03925691831058689, 0.00415686413180083, 0.03792534422661577, 0.05439215758815408, 0.06362657475152186, 0.008573861626375998, 0.04626885508852346, 0.08513337999050107, 0.023361261800995896, 0.02164914831519127, 0.006557590577618352, 0.025756366584183912, 0.02621839634541954, 0.04343389506850924, 0.046572828598852666, 0.05522420097674642, 0.006125557153219623, 0.0587887829169631, 0.026716084818222692, 0.02947536443493196, 0.02683369698934257, 0.07532229287815945, 0.045742569757359366, 0.01790267149252551, 0.012378467695920594, 0.024699231077517782, 0.07291916611471347, 0.032849396778536696, 0.05604437678786261, 0.05617344432643481, 0.06458106996225459, 0.00339663985817294, 0.031188845168799162, 0.07265554168926817, 0.05609784195465701, 0.020824673984731947, 0.023068175385040895, 0.04345083808792489, 0.05228227669639247, 0.05337040598637291, 0.062323665379413536, 0.003728531691844442, 0.0627353461459279, 0.0834823346563748, 0.04792445678529995, 0.06402499015842165, 0.0433081557442035, 0.035216537437268665, 0.017839710228145123, 0.03973951277190021, 0.047774079854467084, 0.060331622271665504, 0.013650362080495273, 0.02434520373520042, 0.039544406812638044, 0.05037534223603351, 0.10875287186354399, 0.00788819944552545, 0.04666206952450531, 0.0654931567343218, 0.04927005958078163, 0.004904146622201162, 0.014664839786876525, 0.04546574104045119, 0.030482310402606214, 0.039607374862368615, 0.020852044391046678, 0.007626502059533128, 0.04631374357268214, 0.03899603516661695, 0.04603999540475862, 0.03338346490636468, 0.0929085092086877, 0.04707240339900766, 0.07791187427937984, 0.08029392574514661, 0.046920642256736755, 0.06079677159764937, 0.08739915091012206, 0.03862630482763052, 0.03650761655132685, 0.019603555223771503, 0.03219314145722559, 0.02191570570825466, 0.0411333051244063, 0.0184020715699132, 0.08280531955616814, 0.016842625070629374, 0.06232407928577491, 0.021440200241548673, 0.034500615139092715, 0.013124587346932717, 0.05279832971947534, 0.007389707756893975, 0.10317960235157184, 0.03692226251587272, 0.029870777324374233, 0.03556153517482536, 0.048570517117955854, 0.047936110624245236, 0.0051972347344937065, 0.03175573742815426, 0.04677504899778536, 0.08066475191818816, 0.042103118263185024, 0.03385276347398758, 0.04261212809277432, 0.07968839430915457, 0.009906084559458708, 0.04230326573763575, 0.02688958791882864, 0.012715239044544953, 0.04711101882691894, 0.019126219408852712, 0.015969213098287582, 0.01453400805725583, 0.04915140076939549, 0.03028714337519237, 0.01221774480239089, 0.013377876835875213, 0.04401551153776901, 0.034293207339942455, 0.065240029245615, 0.03110745150063719, 0.08193028758146934, 0.042245444376021624, 0.021790315829483525, 0.02504045785670834, 0.05532643584800618, 0.0019460793576269808, 0.06686892719673258, 0.10755640427981104, 0.021566406058679734, 0.03952233406848141, 0.03822244756988116, 0.0342552806250751, 0.04852009857339518, 0.026294941880873272, 0.03362428716250828, 0.029721665861351148, 0.05180380094264235, 0.05390524085877197, 0.07353605622691767, 0.008756209430950028, 0.07386283869189875, 0.007222470927185246, 0.016976640825825076, 0.04259535809978843, 0.04388491051005466, 0.037620200243379386, 0.02484776748211256, 0.02834912352929158, 0.0405183183029294, 0.04354799073189497, 0.055223943133439334, 0.03261263894715479, 0.01964371940786285, 0.02928588692364948, 0.06944049349320786, 0.036024638717728, 0.10512216668576002, 0.051057191898248026, 0.051542968688798804, 0.023622833658009768, 0.04321907766695533, 0.037038336108837805, 0.05893041353140559, 0.04335392293121133, 0.024927949965266243, 0.05435360662106957, 0.008621361622187709, 0.026947936841419766, 0.04628705000504851, 0.02572390716522932, 0.02863663069105574, 0.030547714393053736, 0.04192665844623532, 0.04252545542216726, 0.015664031795625175, 0.06232127693614789, 0.04887667551104512, 0.034810827778918405, 0.03825241506897977, 0.04929615943027394, 0.02810483904821532, 0.035211730016661544, 0.03783986917031663, 0.011715514385806662, 0.024849764071404934, 0.024037688272073865, 0.011562607367523015, 0.04527666047215462, 0.02661465061828494, 0.01844245458154806, 0.015157447728727545, 0.02129082754254341, 0.06738367743257966, 0.006278393773495087, 0.024174044973083904, 0.014690999008182968, 0.015209364139341881, 0.08170678493167673, 0.01340187237864094, 0.030758141673036983, 0.04147872355367456, 0.04975308491183179, 0.04107637942901679, 0.008760293363593519, 0.035222396587154696, 0.02900020671742303, 0.059420580443527014, 0.02806158922612667, 0.03493116935715079, 0.05400811694562435, 0.019414274487644434, 0.009925952912973506, 0.02935459537963782, 0.03677011800131627, 0.01531603154061096, 0.05790668739272015, 0.032340149461690865, 0.0681805218170796, 0.06575972600174801, 0.037137846661997695, 0.004646074309545968, 0.027047818892502358, 0.021934479075883116, 0.022902645070904067, 0.047175252344459295, 0.04500605392136744, 0.01850668979542596, 0.036041259433009794, 0.06542288086244039, 0.07933096241738115, 0.06198242333318506, 0.03802139764385564, 0.01032072289048561, 0.07657029519655875, 0.013020946211846811, 0.015185099727075015, 0.030256120754139762, 0.02791287809876459, 0.045031624513545206, 0.03577764518558979, 0.03146128715681178, 0.04730426220755492, 0.02510381436773709, 0.033094839858157296, 0.04754163411312869, 0.025870533493746604, 0.04070720888142075, 0.058482397214642594, 0.01940224745443889, 0.027706231955172758, 0.04107845574617386, 0.04807822639122605, 0.01197252988017031, 0.02887986513919064, 0.02722371043637395, 0.029599166541759456, 0.05526187324098178, 0.05475525524733322, 0.026939875845398222, 0.03319139539131096, 0.043738201060997586, 0.015683575300499797, 0.012561209898974215, 0.017195570149591992, 0.041271322539874485, 0.05605584402967777, 0.0686952584822263, 0.01765598839015833, 0.03137649402820638, 0.06183948993150677, 0.011971897146265422, 0.020579266528199826, 0.012915692707922841, 0.04080127079838088, 0.04447779744597418, 0.028660019793148552, 0.04131854857717242, 0.019424179402579154, 0.051614245399832726, 0.05179337525208082, 0.0791245995621596, 0.07129007138844047, 0.03165315989671009, 0.05148822787616934, 0.07973288585032735, 0.06314765795000962, 0.018333797376336794, 0.0337674580514431, 0.022156712865190845, 0.050915663064058335, 0.04611007450148463, 0.03322276067254799, 0.015368460245164377, 0.02752210129983723, 0.02857337087126715, 0.09975097847304173, 0.14349038393369742, 0.13287407931472572, 0.05393083519967539, 0.0815033737037863, 0.14161048909383162, 0.19728206177907331, 0.14997419315789426, 0.14946761248367174, 0.044307586936546225, 0.11148666231227772, 0.10458705361400332, 0.16945319649364265, 0.11340974590608052, 0.12419934836881501, 0.18011522080217088, 0.09266975987702608, 0.08446544368884393, 0.17528194801083632, 0.18139892763325147, 0.11894026771187782, 0.14451988440539154, 0.11786692030727863, 0.14031174592673779, 0.18728695596967423, 0.15605242843074457, 0.205482795302357, 0.14074975385197572, 0.16762755731386797, 0.1459114375923361, 0.16953202869210923, 0.16328601885054791, 0.14150986235056603, 0.14364808904273169, 0.18404193009649003, 0.1932260644223009, 0.1655075696430036, 0.1623709193829979, 0.08103761369628565, 0.11950366890856198, 0.1180527846195868, 0.1421858189361436, 0.10239591476108346, 0.21794400949563297, 0.09742202915783439, 0.08429665131760494, 0.1802033217889922, 0.08123727941087314, 0.12395796632128102, 0.11978416171457086, 0.1436803601682186, 0.19800812139042787, 0.07386747308607612, 0.15835834826741899, 0.17426300554403237, 0.10906435336385455, 0.15408953518739768, 0.18037143562521252, 0.0976664646129523, 0.10003969512347664, 0.22718999907374382, 0.08661308844706841, 0.10757969160165105, 0.16310100949236325, 0.13328077963420323, 0.06508379655757121, 0.06978753701384578, 0.1614316776394844, 0.2160398366727999, 0.11767185506011758, 0.1552754244101899, 0.0505338378383645, 0.1330813310508217, 0.16427522791283472, 0.10166535646255527, 0.10940400763813939, 0.09824186230876616, 0.10778749295111213, 0.1242373599005597, 0.1304978903915201, 0.10799767595848866, 0.1113926445000938, 0.08300604378538472, 0.12700652916516575, 0.10095406177320651, 0.10317403836441891, 0.16252724028059415, 0.23510991409420967, 0.154615209837045, 0.09635666132505451, 0.11394897768540041, 0.19103122076817922, 0.12896647756653173, 0.1718126256018877, 0.15662812468196663, 0.12216177556131567, 0.23062167635985784, 0.0992698021499174, 0.1173515458192144, 0.1790521735591548, 0.1337429162647043, 0.14596417333398545, 0.12098102963396482, 0.17937086788671358, 0.17567988165787288, 0.2000503625188555, 0.18121869516159805, 0.16224156346704277, 0.14443570535097802, 0.18776146907891544, 0.20674781527902397, 0.20221837689833982, 0.29775405834828106, 0.13847458522234643, 0.21896850237888948, 0.09275298219706331, 0.12392626516520977, 0.11941043819699969, 0.09373645763844252, 0.07612252315240246, 0.14004312748355524, 0.08348987996578217, 0.10497736731278044, 0.1381082713071789, 0.14583225255565985, 0.223727909848094, 0.12397556751966476, 0.18857497828347342, 0.2587474414280483, 0.1598853234733854, 0.12628623710146972, 0.17439526558986732, 0.16838713655514376, 0.18715145252645016, 0.16669492450143608, 0.13665278655077728, 0.08706316072493792, 0.09436947652804, 0.25490003930670874, 0.10167873038777284, 0.13841187501592295, 0.15969903846936567, 0.08907680838767972, 0.17063417312289986, 0.0612509422270315, 0.13779694586992264, 0.10317658965608903, 0.24484928005508014, 0.06413434964737721, 0.14381726139358111, 0.1457243790583951, 0.19465771902884754, 0.17090553284755775, 0.10760998140488352, 0.1757673176803759, 0.15002264055822576, 0.10735273520861353, 0.10186606712107148, 0.13382200630647795, 0.1280804058270795, 0.1717743697975363, 0.17991712928882667, 0.0782089979786958, 0.12266140803694725, 0.14082285921488488, 0.14863191518400395, 0.1436062641441822, 0.11845374453280653, 0.18975702699806007, 0.17429271180714878, 0.10127733621214118, 0.09930871613323689, 0.12386263215116092, 0.14484792894550733, 0.17151153247271264, 0.17314427771738597], [0.06455930255885635, 0.016545862691210847, 0.05639930488541722, 0.01573830932777907, 0.03754352917894721, 0.029038808574633937, 0.030349195402647768, 0.023053290023069297, 0.031872092613152096, 0.0638653172978333, 0.031579236899103434, 0.012388197888088013, 0.07981911408049719, 0.040647216207746945, 0.032467395133738, 0.036039803975394795, 0.05271482580740537, 0.07391282636672258, 0.025857349558334266, 0.038385282403656414, 0.02797305567323097, 0.025689390088830675, 0.07473678501056773, 0.008928580226243606, 0.03476462293682354, 0.06833543814718723, 0.05314076938001173, 0.013681563665159047, 0.05412609722199185, 0.02563246269710362, 0.029374347534030676, 0.02383565786294639, 0.07969894552869455, 0.050504419952631, 0.035732325831694264, 0.011493644460902681, 0.024556450346218686, 0.025098079050491964, 0.026111372713265673, 0.034991246847701926, 0.11480053913380418, 0.040277316235005856, 0.025150679085137587, 0.0330671250953206, 0.08544186915137938, 0.023554337244214754, 0.04554725345224142, 0.046636322513222694, 0.09866017914776291, 0.1339963898062706, 0.036891467204051356, 0.02892771882138082, 0.05924469738134316, 0.017219895630010536, 0.02023754102577056, 0.014295540317626936, 0.03747571638918348, 0.010655724959048842, 0.03112824520628367, 0.024015172783817564, 0.01440002622881106, 0.010332692248214568, 0.039660955380116186, 0.055384291136371236, 0.074178893518235, 0.01955286187252828, 0.05994527121739728, 0.05218955149341907, 0.035849359551710744, 0.03138295368158391, 0.014039515484390514, 0.038566278227205784, 0.055100029068333764, 0.02217067881221218, 0.04795340308919549, 0.04434443138805883, 0.12279140177581992, 0.019169587974569628, 0.04557134144540344, 0.017711307653891187, 0.026043714290218692, 0.03433865561549153, 0.058679667700614245, 0.02018096816859075, 0.06250846439174243, 0.015859136058549796, 0.06303261233759777, 0.03780749287190182, 0.0718332047441176, 0.04139951816094773, 0.02155976150450962, 0.05162749379607184, 0.05406821818490114, 0.044627506019813676, 0.023313523469758884, 0.06314678263983556, 0.013919114534343992, 0.027172606571444442, 0.02802384571571435, 0.03379576313974602, 0.05162524784516011, 0.054539043456315994, 0.03291979817939656, 0.02081595141706722, 0.06781696953943797, 0.006777881212266428, 0.022693790295826535, 0.021065804974309037, 0.051931653903531175, 0.03209662324349795, 0.01764370690632079, 0.03547516105962651, 0.04119011886151774, 0.00802763584735138, 0.05401044771341341, 0.04573411521102701, 0.01340707334955888, 0.04603806497263057, 0.01423314562998712, 0.015579983359202743, 0.050524301028677394, 0.03157883995611753, 0.012151127082428761, 0.029839418828487396, 0.02782056510581502, 0.010691024047056479, 0.03838250719543014, 0.027436237782239914, 0.017690666618623903, 0.08037745340594224, 0.056199489893125634, 0.023298190274674977, 0.053893597197851965, 0.029952489903994968, 0.04720927748296942, 0.01765059742943517, 0.0721955220880253, 0.04595129391444581, 0.025452196298699294, 0.04830233293718525, 0.02355457133879619, 0.037398814622844966, 0.08260825941605227, 0.020367039434079613, 0.016776467906311154, 0.041837451447333605, 0.014540343877992459, 0.16230758492435726, 0.05154148269710796, 0.01504904158147318, 0.023920964981828417, 0.0353404209682984, 0.12176054423408848, 0.07224542833864689, 0.00031338765360747596, 0.015490063898531454, 0.05873977911791631, 0.04905707422377808, 0.038733581214078834, 0.015916377272722975, 0.03130423683407051, 0.06719189629490886, 0.08294168473886591, 0.03383177638586078, 0.008825705835728772, 0.024910623573565056, 0.06009605526924133, 0.026328595521460687, 0.026523112851594175, 0.03348445127319012, 0.03294004566435303, 0.013291672354431024, 0.030768943950533867, 0.020596628542989492, 0.03761950135231018, 0.027115482404561977, 0.006381696913324828, 0.00988993966685874, 0.010026256503936435, 0.06207262777856418, 0.051314662011074166, 0.006839031636315797, 0.03256257663347891, 0.012139463913626969, 0.03278052547414388, 0.0669281090210591, 0.006290161267055997, 0.04010299380336489, 0.05035412783867546, 0.05468007017459188, 0.04701117918427501, 0.010653914966886597, 0.0702706335910729, 0.06272699337984834, 0.05154402720342789, 0.047763922185237916, 0.03796092660299369, 0.041054147229130776, 0.0805992190060871, 0.024475779317851578, 0.025585531822538803, 0.041964666585304906, 0.027232790931261013, 0.059291665575334, 0.0672237602993846, 0.06150375080427953, 0.034245889700417004, 0.010277501906135252, 0.06074662785977125, 0.05260217542360936, 0.05328057812792914, 0.041172266605177095, 0.028179594947557365, 0.038995373594973765, 0.03370993185256209, 0.02690720947326294, 0.01870096454929028, 0.06588996401322739, 0.05096184076475246, 0.03222243381398065, 0.04992852353357843, 0.04889561342341559, 0.06109021085181406, 0.014866922782467944, 0.02282201305830053, 0.05153736059686967, 0.05447194652099695, 0.028942456601985862, 0.07701690694583313, 0.03519365045108965, 0.016737681148307662, 0.044440444093197584, 0.020759366685524583, 0.048815827883247814, 0.0727512219122478, 0.03179627650284341, 0.016784152315397347, 0.017576055268623998, 0.008202401871260787, 0.01970317943154701, 0.07141300836311919, 0.017256745170535784, 0.019732030740539943, 0.021906696459544555, 0.07126890788120882, 0.022678468975105455, 0.0400799439687814, 0.019715294674304978, 0.03759232602481331, 0.03913157932194216, 0.01751286330233727, 0.057127369567751884, 0.019978601884629046, 0.050843097136488984, 0.02820367954804429, 0.005015984884396727, 0.06137074436992407, 0.013025279506109655, 0.032234589768839736, 0.01076933546989624, 0.056118001230061054, 0.04410331057650702, 0.01094495814426669, 0.031031706636505466, 0.08806454949080944, 0.0190557908665921, 0.04267753886857203, 0.053117923105933836, 0.04650627788422363, 0.00856535873442356, 0.045485957991331816, 0.06541376813713994, 0.021748964209109545, 0.033296313868569474, 0.01360730648905571, 0.08924710710666009, 0.06629988737404346, 0.013757638466943587, 0.023575784039816687, 0.02509169403596648, 0.05804569886199065, 0.033342857978173664, 0.029072701398815428, 0.021773562799873095, 0.04852473636024764, 0.04742272085111056, 0.029605819577617303, 0.04575692755835397, 0.08470217098614999, 0.032281859910913875, 0.040230470177318366, 0.03964365612981575, 0.02299735668514456, 0.03443026802103434, 0.020976711630022953, 0.0258969420766724, 0.09474314576280968, 0.014769422389300806, 0.020621705500941192, 0.05290717352181673, 0.0157533303967544, 0.00758860503057284, 0.012250579111943287, 0.011909164887453829, 0.01323666182413165, 0.065753103499966, 0.05307693619813238, 0.04216751462912985, 0.05665616770940168, 0.03687001531943679, 0.04029252899012395, 0.018608936541048542, 0.07617383397051267, 0.018413576131154383, 0.0588586652385337, 0.07714943162032536, 0.054252498117940764, 0.024762567232495973, 0.02267862164548465, 0.025955696423937167, 0.02702857394303594, 0.01206977412636791, 0.008357868662902286, 0.03849251807800361, 0.058746062352188995, 0.05432558651747448, 0.03537754361916866, 0.03017846920660564, 0.06520730350166559, 0.005478322106812681, 0.031833660389695845, 0.004954692816162216, 0.054240657681865354, 0.04344968797106828, 0.05922558304986783, 0.035456331712859016, 0.00675588522738378, 0.03929609692256365, 0.05343002546578646, 0.017307843946452652, 0.05766758522284882, 0.05099000336070146, 0.010964289606947984, 0.0363630071681525, 0.022813936795241067, 0.1077870111912489, 0.007606104448703783, 0.026986387724589025, 0.0334504227420049, 0.08707277556615216, 0.011130733398853667, 0.03294600320181676, 0.09305683017841407, 0.18794641058359826, 0.11805473880044051, 0.21824778962348187, 0.09605997188815049, 0.08652758624936853, 0.13515475764870644, 0.1170645390770265, 0.08765557607901947, 0.15463737079075404, 0.07606051183704819, 0.0641573994819607, 0.14385795992399963, 0.07656894491187163, 0.15669219195842743, 0.13313534243830613, 0.16936922099973473, 0.11562714406422206, 0.11717742016272885, 0.10187351065022604, 0.09672107534216982, 0.0741911410753216, 0.2075564390314477, 0.12797204378460134, 0.13173777743109635, 0.16125287009137018, 0.09666948632470199, 0.13890720557953629, 0.09173796166266714, 0.1526384066258158, 0.13273295760154724, 0.10418144573590585, 0.1307322292455605, 0.10199275639440332, 0.13956438031579765, 0.07008143088647298, 0.2124548511845725, 0.12413291979048933, 0.10276723626468863, 0.15258788290832723, 0.1383069735020399, 0.11034249620778219, 0.11902766302227974, 0.11265442786472184, 0.2716755691383566, 0.17360740500901425, 0.1705546352480139, 0.09991995404873576, 0.22640364484063216, 0.18395085712628706, 0.1587889330195529, 0.10643005650490522, 0.19090627532984528, 0.10090291380350079, 0.10970690567046404, 0.08648936437176806, 0.10350415243634156, 0.109647886694542, 0.10420136752405337, 0.1228360358093466, 0.059671638400426934, 0.13987242164356367, 0.12992444687655993, 0.0927285345803414, 0.18771142033593996, 0.11505683538104806, 0.07358004565217666, 0.12663484125265054, 0.16011063781167778, 0.11588523164391518, 0.07683421817741223, 0.15555742356394017, 0.15902156196534634, 0.1301233662026269, 0.16675186716020107, 0.1324932447501591, 0.18226970519338334, 0.15055037795432977, 0.09059534940336432, 0.04828800567026649, 0.1441698553306716, 0.1039549575320312, 0.09873859065451793, 0.10069296828338078, 0.21236637021814073, 0.14763403444417886, 0.13450994582048484, 0.122185402150665, 0.2486466062920434, 0.1942320740116494, 0.19782289490103722, 0.1710112350327628, 0.1131589390071375, 0.06636380537280015, 0.15792148028101238, 0.1095103747876627, 0.1206679128642593, 0.12482982953744275, 0.15236182218151434, 0.1532792422388281, 0.13342370625053132, 0.10944756280098643, 0.13133303129247256, 0.16187679661171778, 0.2674879767000675, 0.16145162656903267, 0.09065983737153666, 0.09087029179292065, 0.16784394213131495, 0.11926816297428948, 0.09315047479633774, 0.09824468501444374, 0.17007596950445855, 0.10772387350776366, 0.14635225465255125, 0.19785682165196963, 0.10925205650606326, 0.1771435902587005, 0.09840727557561227, 0.18709668117974484, 0.14014026655682496, 0.17244333747242177, 0.09857331988002573, 0.1516228568341051, 0.13691361541194574, 0.08245624043047428, 0.05307875467198236, 0.0834367438884718, 0.1045496595491256, 0.1679292204124587, 0.10396977673683848, 0.10019111021288804, 0.21148755880338804, 0.15465645119547844, 0.11003587980355535, 0.07545755204877683, 0.18802927328007563, 0.08285771603030817, 0.12561621091195516, 0.12683583689587458, 0.0804114547957267, 0.14485223085752555, 0.13745102871741566, 0.12774466669985227, 0.0916261730183448, 0.14234118988471373, 0.07059304629053388, 0.21429514672074998, 0.12131505885294505, 0.11247669240193707, 0.11597140559128352, 0.12818133112575325, 0.20614467907164777, 0.1670913246593305, 0.09463453944772482, 0.07702230808458158, 0.14245112612843513, 0.15282408094831876, 0.1463115561221327, 0.11395322531461716, 0.12140005214938096, 0.13702444732189178, 0.1869558444512742, 0.07453233562409878, 0.08669897740972893, 0.1314153918730361, 0.1394829832549606, 0.11472085198121411, 0.07820529996284417, 0.1643278415181807, 0.06944781488605908, 0.0718112677069647, 0.09348950481840543, 0.15856812415378435, 0.11697844655386039, 0.1138334163863744], [0.03816555919391768, 0.00894055382481643, 0.03416750533506274, 0.03740868052201612, 0.0355642255661743, 0.03192757981430207, 0.057611823215016296, 0.0295921165629157, 0.04789383449990835, 0.08054724322365862, 0.01671515717836363, 0.08253722358494997, 0.036112536144043715, 0.016217224432953765, 0.02642085592794631, 0.037469046389950175, 0.04177960633699383, 0.06011376503322806, 0.02204824056077216, 0.0792344950937799, 0.04193646327725478, 0.025593019456469586, 0.00991761456576309, 0.010596292924934199, 0.04785842514996018, 0.04320790898054838, 0.024918189239022986, 0.07383009259189878, 0.04460708550842745, 0.06907528559012072, 0.031984033927853615, 0.019732392060437372, 0.024510856185640608, 0.06463244184851646, 0.02212675554411752, 0.023915353497224193, 0.03034078496109162, 0.07768417149782181, 0.011419784227785255, 0.022245907989729728, 0.04030043053041611, 0.01553221619022744, 0.06639978808483907, 0.021601698361337185, 0.0431600552983582, 0.0502465766455446, 0.026292119175195694, 0.05397451249882579, 0.04009166566122856, 0.016696393988760452, 0.018570003898016045, 0.02386604096474392, 0.023785922942417007, 0.027957763190248182, 0.0325157916439431, 0.025021302813131894, 0.03489977354183793, 0.034333709095205577, 0.037882895075849125, 0.06489145902118512, 0.031272864767483304, 0.03325204285127776, 0.014429069223946758, 0.0024234450704950306, 0.061003148023571284, 0.013893230967888874, 0.014120312889904847, 0.010347223923807698, 0.03953727540959205, 0.023243135639599392, 0.08884069177189044, 0.06417852227709123, 0.01036029335643564, 0.034745854658207724, 0.030865316279232502, 0.014177540533377655, 0.07439320880387511, 0.03016411479828613, 0.03520649851166776, 0.011896184512547084, 0.05207904188760689, 0.048190174491277764, 0.02405985601113311, 0.06934159701423985, 0.03639768709295562, 0.06560598353722266, 0.039317820221185684, 0.029610416652368646, 0.06675615467663322, 0.036622204152601104, 0.07762414150472198, 0.10345020211700882, 0.06019062269479036, 0.06371268084538834, 0.018849271948316267, 0.015176884364336729, 0.019350073200517466, 0.03443855632628713, 0.047399932252509255, 0.04810944239475897, 0.027944112762010524, 0.02446959277481905, 0.034459363602633984, 0.020171662060809985, 0.05362252924325211, 0.04278947339792337, 0.02665266045369208, 0.028801104186901023, 0.026261295025636042, 0.07192684936204127, 0.011184881341510584, 0.04108324959608061, 0.020905643568507264, 0.035248845882181606, 0.03486400117565479, 0.022429663754467453, 0.038425468640135865, 0.017047719065366045, 0.026412818680650423, 0.02806443059151726, 0.0351575795294983, 0.045131090961928876, 0.05743560088532312, 0.021929552911647728, 0.05272763315588236, 0.052085209770926406, 0.06000040897301265, 0.028383594804576466, 0.04086891734706504, 0.036336954816111496, 0.029211709475410835, 0.02705133709657405, 0.05821101713393416, 0.013092720797950668, 0.04632841349978532, 0.03931051579170993, 0.014411880235586847, 0.015852605158995305, 0.010614397087400513, 0.037063910093690665, 0.021771310063611184, 0.07368081488779613, 0.05587958438055856, 0.03984959150797554, 0.058293750908757956, 0.05839792639017105, 0.04445816403520959, 0.045070124590503316, 0.03219488529222352, 0.03255894647112914, 0.011445439636840351, 0.05926795756178243, 0.03878929911713515, 0.031554300737168105, 0.04872434439935854, 0.04178367754710572, 0.023491365801809088, 0.03129522588902286, 0.03069086492593799, 0.056520528559173853, 0.06433178976710353, 0.0410420896618494, 0.03264485239716513, 0.05118930945172906, 0.01963841326401702, 0.10070910384612423, 0.07286951092204877, 0.02774395002052188, 0.03395688467259918, 0.06527916714549065, 0.021494384655462842, 0.016476479092878953, 0.07677421532571316, 0.034120286083115, 0.020225994056090713, 0.018619940682713474, 0.058735009016735215, 0.0856122967920133, 0.03548563424763935, 0.01815134609517242, 0.08107743691653013, 0.024816612546731318, 0.04204769213018673, 0.03510523733815976, 0.06312152078109128, 0.06737137559269156, 0.020868380121620636, 0.03138930137668337, 0.033197447923677306, 0.019682032887690833, 0.015737971756607294, 0.009329901459360761, 0.03545932744496635, 0.08778380562684365, 0.00592612595729796, 0.06725313408034188, 0.025808864838576744, 0.0167382392433605, 0.03757061629689165, 0.07434363503541265, 0.052800867440445085, 0.04717872644375477, 0.02436559201617326, 0.02854611411956804, 0.021662508669708456, 0.06710791401565075, 0.045853225248200555, 0.027124946271734576, 0.028879576761807715, 0.04121081078691142, 0.040945924286331446, 0.07217229583433696, 0.04738083827708449, 0.031414933037012815, 0.01834357506595552, 0.027429294672661593, 0.07837128319910594, 0.03676529022465859, 0.034346825177116055, 0.007093272770621947, 0.04214636129992349, 0.018105460164536322, 0.021560024436829344, 0.03925803789336767, 0.044957911861794334, 0.008081294396626098, 0.06132311799696513, 0.010624420745963497, 0.046659986421998055, 0.067333805108709, 0.019662180649382726, 0.07399458305111953, 0.07498869792159114, 0.04869485187477299, 0.03006937095363225, 0.056503809456314356, 0.044327074462281804, 0.0337905011006764, 0.02227277628013066, 0.011212100773783666, 0.060811020833040984, 0.029520022217184305, 0.015171683393418789, 0.02873046529878463, 0.045538574989352903, 0.045150846508996825, 0.05109160380171878, 0.07026311542306628, 0.07703844364732504, 0.03164794874776687, 0.04228075533839209, 0.0022092245677153444, 0.03235445297988398, 0.04797605937346816, 0.011901111524951245, 0.037402203905263116, 0.021910918643698096, 0.06407343077340297, 0.029723033109413724, 0.0032672362327243066, 0.017379517600472485, 0.06130903160997799, 0.047183014785072634, 0.03240965858900121, 0.03351099217044456, 0.05025048500725201, 0.07345723759915147, 0.07008444358195577, 0.0524354288354516, 0.014886666455173066, 0.030700893673513616, 0.024020906404725144, 0.03423703142574855, 0.006037009605539164, 0.06818958704492875, 0.016840562324172685, 0.02728158947346466, 0.03740817840610232, 0.01213630533311516, 0.049517887710992775, 0.01045736372803471, 0.0035415986868818955, 0.027198088954069784, 0.03496467541637165, 0.00554381897174088, 0.044294280864830525, 0.02349596966191062, 0.03126489876636437, 0.01946464892742889, 0.01198881641695542, 0.04170411931616919, 0.019543270780039684, 0.03670978606013315, 0.05463048283542905, 0.027566569092284356, 0.01042807221944843, 0.024020869085299115, 0.036950954369136264, 0.04108191627476897, 0.07270807387041194, 0.03944448235311678, 0.051053588877299, 0.06341198126652411, 0.026392479593466436, 0.03140996616067631, 0.026130488741078546, 0.01715641698267843, 0.008275575935840607, 0.09143616285707269, 0.01856363075785339, 0.03317597568301218, 0.009037220468079405, 0.027377520754401172, 0.014840315728049194, 0.05340936068179352, 0.0051495646808429486, 0.013716586250146585, 0.01685216018397893, 0.037999589528356276, 0.012619234821093934, 0.056837441732308695, 0.05113326585186379, 0.02586836218168693, 0.08881228829600982, 0.015300416753494313, 0.04769312723406723, 0.02451902235459004, 0.04104323638603091, 0.01555320667102933, 0.03764245279931596, 0.11536274610885552, 0.07736559252121619, 0.025078150476994257, 0.07566905141408954, 0.04539654743192451, 0.018191683305693523, 0.05294772955988135, 0.09038931903030191, 0.02736366506932037, 0.04809236706101468, 0.060246282922370095, 0.0178406991929348, 0.15064421934740885, 0.03443775226229003, 0.04353909853047558, 0.007986134101104523, 0.054367720149457455, 0.00929879317326205, 0.04011376554678593, 0.03520230855792761, 0.016967383911833167, 0.025357718779040233, 0.1369244855429445, 0.10176307229059083, 0.14680421325777257, 0.1567198219043868, 0.1900640640939985, 0.14567890364144528, 0.1353165746799537, 0.10285552045596497, 0.21497472668332712, 0.18411301342504366, 0.09458232617803983, 0.16359771069671425, 0.1660963480493852, 0.08488799458635704, 0.09443355058985096, 0.1749750737633024, 0.10511779692023993, 0.11988719047180244, 0.07820955437741109, 0.12171981856226921, 0.11812432935195309, 0.09037475766880171, 0.08047794444220406, 0.13154835759529046, 0.2596392264323575, 0.14796266252441065, 0.08089589487229075, 0.14845992012747697, 0.08611520659178495, 0.21650248898991517, 0.11444966867566109, 0.13887046969362668, 0.11240927994783435, 0.20829007109361036, 0.16564923418419703, 0.19895713403820992, 0.15285848267376423, 0.11975282696740967, 0.10934878845832177, 0.11235979438892432, 0.16995388748390333, 0.12658704524593695, 0.12165648410362856, 0.09991732811821358, 0.13706710003316402, 0.10067802694227014, 0.15682468270616873, 0.12123162618705205, 0.19123878463038377, 0.14842443274600164, 0.17920450467084134, 0.12956117279827595, 0.1304594717387642, 0.1435463630727359, 0.07139451828386102, 0.12809905196939195, 0.1307337898761034, 0.14536402268069132, 0.15106234619660036, 0.16388431031789097, 0.09061751035707337, 0.10054429447544472, 0.0641577523201704, 0.08753416580813271, 0.1220483516475984, 0.057059909616197856, 0.12229301780462265, 0.11266155926776783, 0.12397843093744346, 0.1165059826203755, 0.13714780498828205, 0.15891071648469993, 0.22181183552103384, 0.11540043194379125, 0.17944793589413166, 0.11620795646948473, 0.18445754636611256, 0.10069499710308653, 0.12874821999243327, 0.061386656016111374, 0.09806574854467597, 0.15174154617956706, 0.13230583337800844, 0.20560751003878458, 0.16972139424511365, 0.18601254506834916, 0.16746751804436955, 0.1074701760496412, 0.12171532666044575, 0.14969053837869847, 0.12315481156110764, 0.17200201829629286, 0.11418099594967705, 0.17433127973760876, 0.1605070379695722, 0.12582287910793508, 0.11976048084242003, 0.11506036376314503, 0.1475407765912158, 0.251790639013052, 0.08166071918926068, 0.1708393892539399, 0.1429892722517252, 0.10251644293644599, 0.06898806669882365, 0.06967082220528807, 0.21646210258560522, 0.09740558825433254, 0.10267335415950843, 0.1782205067574978, 0.11269657846008029, 0.1512739269861153, 0.10890875849872828, 0.10845796697373901, 0.06278689445129462, 0.09822355543396302, 0.07530582483325686, 0.10049277331147875, 0.09651307721755334, 0.08449854941240378, 0.08596837161374943, 0.11171586465622697, 0.1301330149705921, 0.17482301406562328, 0.13513567724398204, 0.12460119037755898, 0.1890458408743143, 0.10757009711648736, 0.08014805428683758, 0.10860360094479152, 0.09981822807873998, 0.1721256880887917, 0.18850533344915935, 0.1785620270030839, 0.10091685769813401, 0.060857554764619896, 0.10449309008462088, 0.10377511861068861, 0.13100087483014378, 0.07792264941547598, 0.1043760563646044, 0.14322669165475027, 0.09027010721287557, 0.13351802261812346, 0.1994255810443844, 0.14905192836054734, 0.13860102343772138, 0.2691042199730873, 0.13549287164849894, 0.11680702146674905, 0.11279828407402549, 0.15427982354802744, 0.16593120619654655, 0.0888937735663993, 0.13514624881957257, 0.1828413438051939, 0.09263277293315955, 0.17274493271751062, 0.15196429565548897, 0.13759096977966173, 0.2530941590666771, 0.12445670313068799, 0.14367247559130192, 0.1356211147670235, 0.11076305899769068, 0.13738552294671535, 0.1841471301657813, 0.15803862256663187, 0.08618216442742518, 0.12476215245468275, 0.1194595777030502, 0.10472979702587638, 0.2541942543217114, 0.23141482951385633, 0.11177972837218217, 0.19306107184716634], [0.011553624412044883, 0.017263632300975065, 0.018564887743975435, 0.05683908039437873, 0.02733629127033055, 0.02972929598763585, 0.030132362752088478, 0.043038858766002316, 0.015683541373748864, 0.031348171976528, 0.035548164642282894, 0.06694218183734588, 0.01834637571924499, 0.06515287142246962, 0.05699223931878805, 0.06861719981368099, 0.07994117574500186, 0.08161264498318944, 0.04544681669878108, 0.035479697066226175, 0.03495744901842304, 0.03502998101924147, 0.020941858678790073, 0.012880425002159817, 0.07118752439107214, 0.010287874162064066, 0.02171832835301757, 0.007136620132119528, 0.0315038007684052, 0.08153639800314393, 0.014743436194424118, 0.049768664075859954, 0.016924415681777254, 0.0377315953373909, 0.07720684925360338, 0.024985647494239465, 0.024979026688795005, 0.07262265988226448, 0.029576669713216167, 0.07165597139724664, 0.044519106657909494, 0.03463077511904495, 0.03513039402397616, 0.03821054267297898, 0.007430078045997236, 0.039634465372988155, 0.013655604611683105, 0.02564802659409387, 0.059387264374111376, 0.06918306409248284, 0.006533024641352573, 0.04278896110398429, 0.06860596327377216, 0.03383949472169791, 0.027370645498324717, 0.08638932116861854, 0.02301921908344541, 0.05598435018743787, 0.024429180925445895, 0.03188461158424616, 0.09138567306633506, 0.00789156073837408, 0.030337181940142597, 0.016972118389925787, 0.0016163772836859736, 0.011949462234042585, 0.014220218689713095, 0.03434866400701659, 0.034583772998303175, 0.020642612861203294, 0.016999595665505955, 0.022416413661890795, 0.02648201398551464, 0.02130292751826346, 0.03517584229952522, 0.005726867363721664, 0.080078463735325, 0.01746780688076147, 0.06209582010550158, 0.008563569098311876, 0.013484939483792653, 0.045239558177334924, 0.03354575351944991, 0.03534929281366723, 0.013755905658139713, 0.022465315680684786, 0.06469059908496481, 0.015690862766600082, 0.03876820007073028, 0.023269910631435256, 0.04680423278893743, 0.03961067254255925, 0.03861709371475237, 0.005785833753179759, 0.020649328661550368, 0.042522463082735024, 0.010261728511457997, 0.050900589408619065, 0.02884796042261379, 0.034250439277717044, 0.0861709075314658, 0.07761948675449405, 0.030960779371006147, 0.03668595591027822, 0.00869641946961305, 0.02725407657479601, 0.022318497666024735, 0.005777694301546684, 0.0431404761703951, 0.020400764320843985, 0.01249401203157114, 0.0019110334479981767, 0.055370089398430924, 0.06465505063533783, 0.03741900443232485, 0.02807556026216064, 0.02949299616739154, 0.04516239856768932, 0.009197613423956292, 0.009396809253043361, 0.008625397209211119, 0.04813830727445228, 0.012372182765310364, 0.06492892772491489, 0.03802914312109351, 0.01643529032090945, 0.035611641593277454, 0.050995251829070706, 0.014471867820248008, 0.038267329268689664, 0.036919694260827134, 0.03332886319341404, 0.026641652919352055, 0.06647400624517884, 0.0330778188072145, 0.01774938534280019, 0.022247215865978172, 0.06223620221550975, 0.03352624224498868, 0.03103178127535752, 0.07777618763170072, 0.05461996554264, 0.026743709675169418, 0.02694283765075462, 0.05114560161850282, 0.037567783413188796, 0.05974889639765024, 0.026611183304339647, 0.03187238099053502, 0.052477145168398104, 0.08533626874642712, 0.029551791226757423, 0.04421518403770668, 0.04548923870814698, 0.06485183257609606, 0.03114106273278594, 0.04452339160655226, 0.014383371586778333, 0.012189262446814349, 0.04004125390201807, 0.039546184574386904, 0.045163226380412064, 0.012782590430495995, 0.03030672250315547, 0.01393491676675954, 0.019785154943487475, 0.015620664926245809, 0.04484790776457105, 0.05454758960487587, 0.007237058581917414, 0.02696430140973202, 0.03449194346155439, 0.03275524665202413, 0.051071875396051576, 0.070782255780484, 0.08013665489852428, 0.023162383187030042, 0.0341574867655124, 0.01096099107858858, 0.04475926734240992, 0.033608436584472656, 0.028362334606104662, 0.038327216769435575, 0.05821374484470912, 0.027806672101308192, 0.03366893815941044, 0.045262438378163745, 0.05614856244730098, 0.040128961338528564, 0.0403663027100265, 0.03334482912240284, 0.05090889467724732, 0.05057572380506566, 0.11973221307354313, 0.03967426145183189, 0.0358145880246801, 0.04140372507806335, 0.015463424613699317, 0.02608031446912459, 0.026735004070880156, 0.035843826098633666, 0.04350569425150752, 0.011172176621455168, 0.04993532245446529, 0.07453555866543736, 0.05531981334622417, 0.017371052876114845, 0.08484619004385811, 0.03918072561334286, 0.06145114398428372, 0.024500279521037425, 0.012691758340224624, 0.03920652351475187, 0.020856152920584594, 0.03829159368095653, 0.02920567729909505, 0.04267786795805607, 0.053748645154493194, 0.04482786723279527, 0.03126286994665861, 0.032828063637550385, 0.031246846342193227, 0.02336180123633572, 0.02532901844408895, 0.05343486342046942, 0.038188459750797064, 0.06967815716883966, 0.07567518537065812, 0.02273221403759505, 0.026903691269191246, 0.02309119638188609, 0.06033715233206749, 0.022772269656083415, 0.010847009917987245, 0.011812509270384908, 0.06215982631381069, 0.05180814695943679, 0.037329295317509344, 0.043166307998555045, 0.06196179586861815, 0.05314043689785259, 0.0077816609659099156, 0.029630820200379406, 0.032861810576702864, 0.07888979930430651, 0.03221109888649412, 0.042871586313205104, 0.025121642875352075, 0.040667199064046144, 0.011848184945327895, 0.029720335932714597, 0.012996607160727893, 0.06432724358247859, 0.054295917573784075, 0.08704897255769797, 0.02273227001673409, 0.01600835608717586, 0.05386371112295559, 0.024169066222384572, 0.047617833595722914, 0.008481015135268015, 0.0713083307657923, 0.06164651457220316, 0.05120141790913684, 0.05692782598946776, 0.046474145858415535, 0.074123368997659, 0.02529283726055707, 0.026069926097989082, 0.019339196284168532, 0.048942310203398974, 0.03314681224791067, 0.05495127383619547, 0.03626167135579245, 0.02510161930695176, 0.056692605039903095, 0.012485306427281882, 0.050278986870710335, 0.03270972373762301, 0.029363833633916717, 0.045781348033675125, 0.05328122612887195, 0.0066073352520886275, 0.02151793660596013, 0.029540127209786857, 0.011550024783770953, 0.03717110166326165, 0.02701866054641349, 0.03108055776517306, 0.017542286277083412, 0.023988894818882858, 0.04577364666121347, 0.054693383031657765, 0.016011558772463883, 0.025869719251724224, 0.021482562879100442, 0.027351975607286607, 0.012120587917576944, 0.03383708592238171, 0.019564797303506305, 0.04576662043109536, 0.024328688192846518, 0.04832699089976294, 0.015236278230856572, 0.024909790671829666, 0.026080021002729024, 0.013207374556389238, 0.06366604513355664, 0.03249728460130947, 0.08323523934398379, 0.060011706581073146, 0.005871643836144358, 0.028363893540310006, 0.06286099726068121, 0.010261223002869104, 0.02894298585930041, 0.043347045978797336, 0.025407105950372558, 0.014371602396879877, 0.032091188177998574, 0.006144612536965204, 0.020747222605028322, 0.04218954326851027, 0.034952292152281315, 0.035178841424307654, 0.027923066302069595, 0.027870152444977845, 0.06254624522158078, 0.04127182126311319, 0.06727300158568791, 0.015016929911715644, 0.0076528835010581785, 0.030715682344245057, 0.07631701164479766, 0.007769403230798031, 0.01863891421817243, 0.020612496084400585, 0.04115508270582982, 0.008902209810912609, 0.01917133180956755, 0.0005440361253152202, 0.02504023054747709, 0.019910119041534405, 0.038840589579194784, 0.06323771311768464, 0.05923178485993828, 0.015560087016118425, 0.03716883535629936, 0.03500827468399491, 0.036741935049316714, 0.05722290729837758, 0.0605355491861701, 0.1344495697745255, 0.13148049052272523, 0.12904461765927927, 0.22191744271133626, 0.08562520931341819, 0.1862902965928827, 0.21942552285534994, 0.17908414612923348, 0.1689780048493828, 0.12424365670553275, 0.15892381221055984, 0.17107093254370348, 0.0921029592198985, 0.14780370891094208, 0.08227886459124939, 0.17979343235492706, 0.23814779679690087, 0.3086296176271779, 0.169500327536038, 0.15380577184259892, 0.10403058025985956, 0.15285058452614717, 0.1848084439656564, 0.10930918236928326, 0.16854108258017472, 0.06435589133096592, 0.07523383905312844, 0.129050575196743, 0.1849955567823989, 0.14945021484579357, 0.1273480358400515, 0.20984171783285482, 0.0853870842339737, 0.19149666864957127, 0.19431357963808946, 0.08222386932798795, 0.11887899599969387, 0.26533373658146175, 0.1454477674726929, 0.2580801972321102, 0.10272570313619715, 0.12890049682131835, 0.1721398423292807, 0.18222261486308916, 0.11334468118314232, 0.19212970110986913, 0.12977599698518003, 0.16656206734478474, 0.10227396844753198, 0.12555791118315288, 0.13997983373701572, 0.19848388300410338, 0.12582621750022682, 0.10468865066234555, 0.08952373226306268, 0.22803681077701704, 0.11656614153512887, 0.1067109021491238, 0.11462378076144628, 0.10218731952565056, 0.1357616257986852, 0.14758603487695965, 0.12990692710237844, 0.13724704752010958, 0.1071616258206112, 0.10517326715801444, 0.07669669269983258, 0.21754811145365238, 0.14172748210174696, 0.11282526941171714, 0.10730302573314734, 0.14931697770953178, 0.10765118883656603, 0.15261252730020455, 0.12346022017300129, 0.0783932405923094, 0.14208627784890787, 0.14391159133187362, 0.24152315567646707, 0.08204530605248042, 0.07110660230474812, 0.15321399431143487, 0.11693297113691058, 0.09695301896759442, 0.12276413823877062, 0.28503318237406866, 0.15081445021288736, 0.10242007739309754, 0.10932894809437649, 0.13888846444232122, 0.14100381093365805, 0.1744794175028801, 0.11195411865732499, 0.12574427761137486, 0.12478523621601717, 0.12302712484129838, 0.11770513041743211, 0.14431506182466233, 0.11095444658505065, 0.13736463763884135, 0.0862579092915569, 0.13145062141120434, 0.13423482701182365, 0.13311841977494104, 0.08779500824000154, 0.12027158055986677, 0.12239707793508257, 0.10489071839089904, 0.08526518541787352, 0.12305528404457228, 0.11943832598626614, 0.09341172434921775, 0.10755651963076421, 0.15670835466257163, 0.11445406558258192, 0.1288887853068965, 0.13147693499922752, 0.09269621595740318, 0.09672886492418391, 0.07269217579492501, 0.08585078149501767, 0.07432168442755938, 0.10425007955304214, 0.22383234995816434, 0.1240839838449444, 0.12843662314116955, 0.1572332557822977, 0.11823772612426962, 0.0631209033142243, 0.08140922018459865, 0.17349888011813164, 0.17952659167349339, 0.07070243292089019, 0.15569212633584226, 0.14889680168458394, 0.11579542074884687, 0.0888491938156741, 0.13796492399913923, 0.07958569124873195, 0.128044511324593, 0.1109516035233225, 0.09484470888440098, 0.10428104789129325, 0.07220555083560092, 0.09102045159254755, 0.11004400865307876, 0.1424627969307559, 0.14095881049122128, 0.1382673063448497, 0.0788740369358233, 0.15172796190849372, 0.09761492987828595, 0.21193590760231018, 0.1808157539261239, 0.11520273398075785, 0.12403507504080023, 0.1680118388363293, 0.16793511009642056, 0.1904368105211428, 0.12460180105907576, 0.22660265916160174, 0.17097555766148226, 0.09340679139963218, 0.13934066732014927, 0.08577377455575125, 0.08827725664845534, 0.1221217012831143, 0.15652865144823278, 0.17803578238402093, 0.10254928403134857, 0.0803611007119928, 0.16355569580835955, 0.17611210846475192, 0.1534299991492714, 0.19113742506929807, 0.08966863341629505], [0.01801793762881841, 0.05176686488890222, 0.036378331881548674, 0.060441042828772745, 0.028633906372955868, 0.06520369369536638, 0.027844047506472895, 0.008541880574609553, 0.029879767913371325, 0.041034951473453214, 0.03163164694394384, 0.01734488008410803, 0.025426752931837524, 0.001954552139587966, 0.0154233452464853, 0.04523627406784466, 0.005911026008626712, 0.03560506998162184, 0.016873284675447003, 0.03270658212048667, 0.03684673478294696, 0.010009673108080668, 0.024201730898182307, 0.09921625216624566, 0.032469013439757485, 0.04593725502490997, 0.04999280794124518, 0.041971360333263874, 0.032109172748667855, 0.06851940934679338, 0.08162125559257609, 0.06222620739468506, 0.08347066385405404, 0.0237781689834914, 0.06695798491793019, 0.033168437158955, 0.003444104654980557, 0.014292364773739661, 0.027142513543367386, 0.0245907333280359, 0.018964156408661177, 0.014436153129541447, 0.05564044828393629, 0.010762037825770676, 0.06370438236211028, 0.05892077154879059, 0.035329197999089956, 0.06010873708873987, 0.0302880322560668, 0.02169049993556525, 0.023499760976327316, 0.03415289308343615, 0.028720182100577012, 0.050655329533453496, 0.022228588383378725, 0.02621946164539882, 0.02343001096908535, 0.07010547816753387, 0.040213001293263266, 0.0040451458854866874, 0.04834742498184953, 0.03166238118761352, 0.017526466233123626, 0.04655878631664174, 0.03816473138119493, 0.03250144402097378, 0.04004104694883738, 0.04924852966463991, 0.05500339550365295, 0.028906538350773708, 0.025375041778066328, 0.05593411145465715, 0.020146429039803997, 0.032440467471522946, 0.0058802578382061, 0.03579397413081356, 0.006019351579847613, 0.030118239045675312, 0.05479152972943016, 0.07205981508429561, 0.009691792174375482, 0.028068598492869308, 0.008030499265130078, 0.07225590491933481, 0.059143731370568275, 0.04017102372433458, 0.05653294235734003, 0.04299238929525018, 0.03929869571168508, 0.022731759419132556, 0.04926228696214301, 0.034462583251297474, 0.03257393870236618, 0.012253401817620864, 0.03253649714003716, 0.02639006570513759, 0.013261333357409706, 0.03835371695458889, 0.02563215226733259, 0.039566893463156054, 0.01919365391534354, 0.01306867182055222, 0.014055865633833622, 0.011571969454442816, 0.016619186881663542, 0.01299756219876664, 0.032655600391860516, 0.02463957936769085, 0.048820323177746365, 0.05512302462011576, 0.0524191134609282, 0.036250977643898556, 0.07153924301798854, 0.050053821810122044, 0.0415661086860512, 0.006176714452781847, 0.04873640875199011, 0.02956262743100524, 0.02926966654402869, 0.07318197629813637, 0.06566382186221224, 0.02088680743638958, 0.022170010455218808, 0.006278395893917019, 0.019201567329998528, 0.05706655925938061, 0.06337426150483744, 0.026518003482903754, 0.03649888041296175, 0.06777569425425359, 0.0550752082573516, 0.03444616609652128, 0.019999707716384103, 0.03685452775763614, 0.02478097249487681, 0.03851650429091283, 0.05917071670825992, 0.08487001340836287, 0.04390580260327884, 0.04248262629179018, 0.05171725719368883, 0.011936635377683809, 0.022389416449836323, 0.043535278378320594, 0.0435327644060765, 0.004374230704602918, 0.06641419338328497, 0.03428722605375307, 0.011016514750995805, 0.03187557349779776, 0.038737079062099965, 0.020786986453458667, 0.012856517668946512, 0.007475119200535119, 0.02589008548030896, 0.019718093631256903, 0.06759273407182523, 0.03424189312915717, 0.02868939357410584, 0.014415009978360363, 0.02658651177106159, 0.027197318816823617, 0.06265314162841865, 0.02449003533859338, 0.026863482980323688, 0.03966685863477843, 0.007546625765306609, 0.008560307889378496, 0.032653544430754015, 0.01241352251132152, 0.04573911940678954, 0.04687655105122498, 0.009466636443643697, 0.017623927610527192, 0.07083030284515449, 0.06315957302493708, 0.05349715293518134, 0.047425950677799325, 0.010435556460704123, 0.10245372594467231, 0.04483379762885826, 0.0073919774565313545, 0.024454585276544094, 0.01585003690394972, 0.02144382701122335, 0.03243488652099456, 0.045111667897020064, 0.026089590042829514, 0.05418211707313146, 0.01100202463567257, 0.0441968500215028, 0.012336915907716113, 0.06504113706094877, 0.02626474537620587, 0.03239071389128055, 0.0565561991451042, 0.024286792048120072, 0.04046860882746322, 0.004763457899181438, 0.03275037816326533, 0.04431356483006051, 0.03487808077729174, 0.0332418817893735, 0.020101594838446805, 0.02038249815814197, 0.04002690627904875, 0.0029910514879572603, 0.008901047819693173, 0.060075556726327965, 0.0335083594545722, 0.10798825789242983, 0.03448625055274793, 0.013932689475560827, 0.027930555632337928, 0.07928442848580224, 0.04971263065401997, 0.02501894660027964, 0.024808536283671856, 0.0638216467840331, 0.01131574614971344, 0.04704608641830938, 0.076001669280231, 0.041284923774323294, 0.027612745096640925, 0.0530543850867876, 0.06010398055825915, 0.017484643030911684, 0.04079049905495984, 0.0624539101762431, 0.024461502941059213, 0.033082880678453615, 0.0091487114051623, 0.027466242600764548, 0.026125879791964377, 0.036803033735070906, 0.0526737439047013, 0.059350019586937766, 0.016700892675934092, 0.06539531876998288, 0.03723369991140706, 0.040424412449023554, 0.03954901406541467, 0.027795130220640982, 0.1071926009442125, 0.02076003164984286, 0.060631955441619666, 0.026038849194134985, 0.057927287715886316, 0.028515522368252277, 0.030571982197995697, 0.02336991990783385, 0.015202585574505585, 0.03748726166252579, 0.043388613034039736, 0.03621556829395039, 0.043886365967669656, 0.011913368411894356, 0.031466060650667975, 0.002373860063796331, 0.05396353719489915, 0.011438804412526744, 0.07547065455998693, 0.042806467307465415, 0.0442848051232951, 0.018936982777501856, 0.020547258335032632, 0.036310257855802774, 0.02594041751165475, 0.044687101750501564, 0.05909941624850035, 0.028498348646930287, 0.07366104237735271, 0.022396803999851857, 0.012300952703558972, 0.035004057588854005, 0.06424076429435185, 0.061950464333806715, 0.017909115878865123, 0.016693243889936378, 0.05152054649910756, 0.03193847030135138, 0.04519462898107512, 0.011607171851210296, 0.044798378100884814, 0.04345743344830615, 0.01903860696724483, 0.04707716332216348, 0.010597672895528376, 0.0580098315009049, 0.03908671797918422, 0.047704523229705434, 0.03725864964404276, 0.010929225461690553, 0.01814075925254396, 0.04070284590125084, 0.08427907047527176, 0.045378125206168206, 0.040856819067682536, 0.021403471140989234, 0.04680700460448861, 0.052621143870055676, 0.06367782450148038, 0.02465509746356734, 0.054756856589977226, 0.03579609455274684, 0.003243104770912656, 0.02758350532634982, 0.02367963212808328, 0.12470759823918343, 0.02160739466281874, 0.03963924565219453, 0.07335403242281505, 0.028088404930063655, 0.04250427834423525, 0.033418626591031036, 0.023950019851326942, 0.12281292490661144, 0.03331140109470912, 0.04033564989055906, 0.04121043759265116, 0.028146536721448814, 0.05636102193966508, 0.040799479465931654, 0.05600024487024971, 0.041530366853943894, 0.016706409165635705, 0.054623677129192014, 0.017618012481502125, 0.018735710631257722, 0.027549305465072393, 0.027133558577458774, 0.044788427384836335, 0.06169899247054543, 0.051245444653821845, 0.03642052658168333, 0.054740266408771276, 0.017283454005207335, 0.02607436032433595, 0.03177096714664783, 0.0360259923950902, 0.03577618633529969, 0.059828821037496836, 0.04607183226783361, 0.0582246014050075, 0.036427685126130066, 0.03884668282366224, 0.09469827424202647, 0.04580035719222256, 0.03036847258252757, 0.03228594808440123, 0.008775403490290046, 0.05060691266719784, 0.09947892664266483, 0.1101239604343261, 0.10458770500762121, 0.23341254517436028, 0.12083701736160687, 0.144207093332495, 0.10755402262189559, 0.06629654898175172, 0.12736883972372326, 0.1010560727279101, 0.12051316616790635, 0.1344420380358185, 0.11206115755651679, 0.06727422973407166, 0.16739240421780519, 0.09937374692942415, 0.15173598219241413, 0.10913699053760086, 0.1568007439907108, 0.27595918785248486, 0.17168693377503327, 0.14182083494961262, 0.09547125454992056, 0.20902347245386668, 0.19158368398036274, 0.0897755908912846, 0.10243420449218579, 0.14579292466597898, 0.10857897690896477, 0.1579791693282979, 0.1367502241794552, 0.12194224234138216, 0.1501880402543715, 0.07857280809964452, 0.1559656709432602, 0.07413023577204772, 0.08831539710185357, 0.1366951542773417, 0.138281324878335, 0.0942741423579199, 0.13991876558533736, 0.0955549722005214, 0.1362885625234672, 0.05988078324922493, 0.12890635936387948, 0.17842938697763852, 0.13129010716719286, 0.12085315292435032, 0.1414948667266539, 0.0980323985485094, 0.1184743991387742, 0.07599273975938559, 0.11907986950661455, 0.1997017990797758, 0.15084787484790596, 0.13253854374800408, 0.11531923844345979, 0.08173365491841521, 0.10205106290855578, 0.13459042007369654, 0.10338061835084643, 0.09367092472634145, 0.16771416552364826, 0.1433050895908049, 0.09960292891732284, 0.12862791573362692, 0.13387859612703323, 0.23691582147564205, 0.15190885934446538, 0.11644880925970418, 0.16926336953682558, 0.13141084568841116, 0.09048746233539921, 0.10598878482622759, 0.10198588283466441, 0.10178897197225265, 0.09317833544420344, 0.09711250183837754, 0.08621921243944339, 0.19209034607878753, 0.14881587959825993, 0.13937200206731046, 0.07268845063767262, 0.11502927328859057, 0.12069198728672095, 0.14802265859075955, 0.16951104838933262, 0.11192569482539381, 0.12496405733483178, 0.06256980395742825, 0.10477567956383739, 0.16660383796053274, 0.13415952319545404, 0.14456021652690001, 0.08826772323144333, 0.11253434752247163, 0.0782765189984015, 0.10951633911047663, 0.06841046376419918, 0.15618945179241045, 0.15730313131851809, 0.08749007460262094, 0.054332100453653505, 0.09930759655045611, 0.12537727159048828, 0.1562260112592152, 0.08249161924634661, 0.1372583383428199, 0.09329415458653655, 0.18122823536396027, 0.14400609768927097, 0.059917715910289965, 0.18689693404095514, 0.1134968087343233, 0.09157100812132869, 0.07218820748052426, 0.08747034958962883, 0.07505064138344356, 0.05794749448874167, 0.1951823215931654, 0.1554645321198872, 0.17307029025895254, 0.07336544538182871, 0.1485262672816004, 0.1938739296581064, 0.14266836590000562, 0.12056210211345128, 0.10241498159510748, 0.1506375561335257, 0.13046857767871448, 0.14395759600613797, 0.07371782218771321, 0.263643777264016, 0.07030108624270984, 0.08555967640131712, 0.25271635076829363, 0.20596538297832012, 0.1759101900139025, 0.09960206717784915, 0.13590286964816706, 0.22770441004208156, 0.1346726720886571, 0.17686665297618934, 0.10938207060098648, 0.09809692722878285, 0.0881933354373489, 0.14450946210750512, 0.14942741606916699, 0.07896995464605944, 0.1315654566777604, 0.18283021583088807, 0.10795490789626326, 0.10894095498536314, 0.08974255980657679, 0.07984966172703675, 0.11982969141432218, 0.16301115788519382, 0.08527236431837082, 0.08361111381756407, 0.10894516190247876, 0.14020366886896746, 0.07825314346700907, 0.11856473929115705, 0.10832477733492851, 0.09011952672153711, 0.3498142233916691, 0.12892841175198555, 0.12412347458302975, 0.08518645499965974, 0.11135083317224469, 0.14721517477716717, 0.09988401883414813, 0.06970592282180275, 0.1303147537899869, 0.14999492918806417, 0.13150358785476002]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.034410203740532906, 0.02285394152360303, 0.017613761459610293, 0.05552389632378306, 0.01921507526588227, 0.04135965422860213, 0.004449121462779918, 0.05156369793361851, 0.006462288637911635, 0.05741955353213208, 0.03077619748988322, 0.02468387413370822, 0.03672987748203533, 0.03255297536296504, 0.03953929405127253, 0.045195056458136866, 0.040498905416045866, 0.02461492649412581, 0.07829194209937539, 0.07116692406790597, 0.04789724074570196, 0.005117866069278014, 0.048869615354176076, 0.0370894976492439, 0.021499756956472993, 0.02381726786760347, 0.01448170148900577, 0.06165805645287037, 0.03468009104420032, 0.07494024373590946, 0.02940286636086447, 0.044246484858116934, 0.029081125411071947, 0.055581486983490844, 0.014012270607054234, 0.0313856237168823, 0.03408229151474578, 0.01749252082247819, 0.035882044583559036, 0.03312761649223311, 0.02333459198208792, 0.05280340855408992, 0.0530192912556231, 0.06524710636585951, 0.009252621409749346, 0.020988172086487924, 0.022533915571070144, 0.0212668599893472, 0.05809142533689737, 0.07942710404417344, 0.03287356619590095, 0.012363213380532605, 0.01673238687882466, 0.058080595917999744, 0.06730079438005175, 0.052139384006815295, 0.03298282729727881, 0.023408823713128055, 0.03584588545241526, 0.036718590052000115, 0.03691255607243095, 0.05516915482335857, 0.05596168033246483, 0.04539049829223326, 0.05987184015767915, 0.016742257867008448, 0.0305001389102212, 0.041465790676219125, 0.051025005589638434, 0.0837683439520853, 0.046243165752717426, 0.06067562595541988, 0.022500674140506556, 0.0073594323725306564, 0.027490354342652217, 0.02007187670096755, 0.03598325825961573, 0.043743921111204793, 0.006293408481204616, 0.05151433111833675, 0.022874200882922326, 0.017336795339360833, 0.016694173482911925, 0.05048461012276156, 0.0815922821472798, 0.013776254075180207, 0.04002725911725845, 0.03829044017142483, 0.015009223450241345, 0.0365164782186704, 0.05038558132946491, 0.014019706502689846, 0.0161152949024524, 0.01591936791581767, 0.02541779287691627, 0.04091710351141436, 0.055214385967701674, 0.052964872747127495, 0.012679186782666614, 0.012399568438663014, 0.022783216122271757, 0.014902661221900156, 0.053980734664946795, 0.06535507485802684, 0.04717015654646924, 0.021494192969320074, 0.019835468315120255, 0.03563438608710255, 0.025087280165670172, 0.020211839815601707, 0.0699405941580023, 0.0924147189195667, 0.017382754212511436, 0.04620776318811944, 0.04593744840739029, 0.025992466236597726, 0.04604988844533052, 0.042452258457030566, 0.0315517460528229, 0.07380378578922578, 0.025179803504475524, 0.03214859224057623, 0.042074813174882104, 0.024002294189163616, 0.047709337435662746, 0.06458246774439301, 0.03564052004367113, 0.038313632498362234, 0.04013163137382694, 0.023090266788910543, 0.03896617962579642, 0.015845541609451175, 0.04538262728601694, 0.07731273464326348, 0.05903601393635784, 0.046430760329323154, 0.011646581165093397, 0.031987192508365424, 0.03504526162786143, 0.03191778516130788, 0.015863437970568026, 0.053874659285481484, 0.05350988903748138, 0.03157620384757008, 0.01915216149895319, 0.0358256345747837, 0.07963187912745134, 0.044303149317524264, 0.06587235602949347, 0.04034566506743431, 0.01985116452643914, 0.026011714578739235, 0.07696366230291979, 0.027836173107581477, 0.037427964487246106, 0.03065833934981908, 0.03166435233184269, 0.06792270565139395, 0.07195774984679051, 0.048035013888563426, 0.036812573937433105, 0.046041630674153566, 0.05259240451934082, 0.007929998050842966, 0.02884692226403526, 0.009814342384093573, 0.02520841732621193, 0.01200910291767546, 0.027358316517035876, 0.017951464945716516, 0.021195942901873162, 0.04233839349555118, 0.034744117608559985, 0.03901096632970231, 0.022896887701270834, 0.035496901321624, 0.06546207304511752, 0.060962686980409284, 0.04796121981261032, 0.02876760152035526, 0.053765282833150456, 0.03583073715812393, 0.015980671858415008, 0.08473295611994607, 0.04917356511577964, 0.04726310905867389, 0.0339494954262461, 0.0029346132775702116, 0.052722388080188205, 0.03270895699305194, 0.01534953759983182, 0.011795821549770023, 0.0325005313913737, 0.038256686446922164, 0.02543578762561083, 0.07300816955310957, 0.0371922617778182, 0.03127341438084841, 0.07187464287770645, 0.041271376822675974, 0.02459086224968944, 0.030848787166178226, 0.016353567563263432, 0.08490011322179011, 0.04670013873172658, 0.021438064552577477, 0.012399553171625095, 0.027368041620190655, 0.026597102006365145, 0.04255214898980089, 0.015090189641341567, 0.02133197899508689, 0.03033371123352221, 0.04124003529016461, 0.022857563204265068, 0.08517080798212971, 0.011745862712684487, 0.018158743823213235, 0.012165014997922947, 0.05742344153778894, 0.07143483004931893, 0.03634497170735683, 0.03607856189565999, 0.021975881586383497, 0.020482566806354692, 0.027283497853204608, 0.04718578660062381, 0.057525337141539366, 0.0245576734055898, 0.02256146409282727, 0.04687853915882962, 0.034571111534855196, 0.08052751142531633, 0.04631338734179735, 0.04371738699930055, 0.033701202499547174, 0.0027737379257035044, 0.0267888746623482, 0.006119442280448441, 0.015224498862932836, 0.05016084374593837, 0.001469737702531607, 0.03367969633213111, 0.02587148344277271, 0.027864814070718627, 0.014625450829043984, 0.029067015275359154, 0.03675173309498599, 0.03630494831928185, 0.026356062619015574, 0.021694228485492722, 0.03931996099916952, 0.07250241669160978, 0.021837343395288502, 0.05380053272736924, 0.01602642038570983, 0.03352970616625888, 0.03088722617498466, 0.06674671625452382, 0.11500480531581811, 0.09280568401196174, 0.017212457189868604, 0.03576104482635856, 0.04351275101570146, 0.03527482020269547, 0.009145182174896556, 0.020048036373087337, 0.029336006912801946, 0.012840746818775577, 0.030773066050772156, 0.007459750382362732, 0.06190647490854774, 0.037669214220451455, 0.018537602154538035, 0.022585657258917178, 0.041475799067744186, 0.04174656507426074, 0.03953460876696876, 0.049472320691815445, 0.041442890119339736, 0.05730889125594071, 0.06907405744173697, 0.05180759734607168, 0.023517562342541556, 0.06682026945054531, 0.013286769090752517, 0.07221701807741608, 0.007024966770716543, 0.06456116174480744, 0.0818327549578888, 0.013611815354254628, 0.04296173308310764, 0.029403405796204294, 0.018267243269032667, 0.031173113334391798, 0.06737864948809147, 0.044007565892700634, 0.08185708043830735, 0.06140376866928168, 0.04476990337882723, 0.040588797735316415, 0.0606955477435674, 0.0817320535757712, 0.03066618999998484, 0.06646532099694014, 0.025686005895425166, 0.017579207063785622, 0.02343240280502609, 0.044630566212747774, 0.07907608430832624, 0.06725364298160587, 0.06167739470090185, 0.018456449366307685, 0.04748483394671764, 0.0566574603186122, 0.05003827318016972, 0.06217590080840247, 0.014044982780303274, 0.026970820434923683, 0.009707892114030463, 0.012290738207021994, 0.012983697183829333, 0.06940381189009973, 0.0845438755516495, 0.08004389237612486, 0.02542861381412617, 0.05569910763629845, 0.05180205371496933, 0.021503566930602704, 0.06223333879773106, 0.022189701541459987, 0.03317678653235946, 0.06254195688026291, 0.015932612919381688, 0.0416979412548244, 0.03489486434097801, 0.01736862032807299, 0.014008819408315634, 0.02438291162252426, 0.0164204287076635, 0.03232752192499382, 0.008109993035239833, 0.014288325794041157, 0.016319091198965907, 0.05266845133155584, 0.08746500951903206, 0.02447988954372704, 0.022879337393013493, 0.02781888742798141, 0.030485207747135843, 0.05483109510636755, 0.021435983146407774, 0.14236078597605228, 0.1633003902222429, 0.09820805090878691, 0.09116504061967134, 0.1100588482139366, 0.08935143186577729, 0.09375345494065966, 0.16908765610839638, 0.18575833870896272, 0.20296472470675195, 0.08547893751944814, 0.06360178786729064, 0.15194100833364896, 0.09338906806494508, 0.14572440619979585, 0.14296975758458885, 0.13983302590038094, 0.08216447037245546, 0.13483429913009914, 0.14250441826879978, 0.07917462116373436, 0.08487669697829656, 0.12244046346417495, 0.1373637012605156, 0.17910002384866985, 0.06479582629565682, 0.1418044822556632, 0.16233229716973646, 0.15584319537239416, 0.10480783533837114, 0.12750506241406712, 0.10284826013126544, 0.07848936186305114, 0.13429798505135945, 0.09103897559855666, 0.10083339110549007, 0.07578530481883458, 0.11287837156227656, 0.18826229577617987, 0.1792553269437381, 0.09935011355472462, 0.11702139782054083, 0.15610559843480587, 0.19361158087849617, 0.17027738583939417, 0.2337863908282348, 0.10047193550105606, 0.18022466850067886, 0.20028561060982092, 0.17059488594532013, 0.11607931980064937, 0.1310733152287347, 0.14090812392532825, 0.18098777612405165, 0.11280619579234294, 0.11137530793036733, 0.16021097957023553, 0.1752487812191248, 0.07833408590938364, 0.12336735587034907, 0.1233157329261303, 0.18413811922073364, 0.1621537474649293, 0.0787127355911902, 0.14583484455943108, 0.05440463584714702, 0.08523112974528756, 0.16152129854474748, 0.14571084907012327, 0.18284940480121545, 0.10043453465082816, 0.1353421825915575, 0.14825098562453473, 0.10200790129601955, 0.09551815489040953, 0.11670479338083949, 0.11903077071266514, 0.16799361338572844, 0.31092132894056185, 0.07355352850364787, 0.10859563494367258, 0.08105480098830802, 0.14841952015246662, 0.27374282106757164, 0.1858406314360244, 0.10708977574748652, 0.14151401498488017, 0.12581857719591685, 0.055685129814914296, 0.10397022456995078, 0.1523859237453767, 0.13887656293809414, 0.13385989570191928, 0.10295005395476307, 0.1372911115842206, 0.14119309506246022, 0.1618418927703585, 0.19007323788745062, 0.11696916419480528, 0.10513060087604181, 0.13217628747224808, 0.10930946056864091, 0.06764065221484218, 0.09196067042648792, 0.1219688273434128, 0.11333849972912244, 0.20133637636899948, 0.13179415012044565, 0.19581729466361658, 0.1557483904595886, 0.143275220479284, 0.19956598351044313, 0.1490726779614176, 0.1931223435593503, 0.13310778034584864, 0.09071086999028921, 0.10216127056628466, 0.06644155191523687, 0.12693159175770624, 0.14353428514940397, 0.1709756797977856, 0.09770273909504924, 0.14781486402664865, 0.15946962577956064, 0.11992197217685835, 0.14441406008388313, 0.15470890195241996, 0.12522920167871884, 0.1601353907691581, 0.15017113116170677, 0.08249273882912737, 0.05849819350987673, 0.09734959554459367, 0.1510691044053861, 0.11659427359700203, 0.1252568859074797, 0.18512123503855296, 0.0928598650332008, 0.1247555028115, 0.1780383065342903, 0.15372465976646968, 0.19464809740228312, 0.164815966039896, 0.09142819007060357, 0.1301146945250886, 0.07675735373049974, 0.1766905595681497, 0.16742403752037457, 0.12815060706010886, 0.10238678167973246, 0.14476144287203038, 0.1876036554042782, 0.14788022051964486, 0.12923103837030275, 0.1752799938299826, 0.1594888690326895, 0.12165803116347108, 0.1476954147219658, 0.20220024644264153, 0.16156620399228164, 0.15237832415316785, 0.0865407498287303, 0.12100694967167717, 0.11866030416318349, 0.10592772345989943, 0.11204760721219437, 0.16418724906231674, 0.07939167094549962, 0.09267210082284041, 0.13062111235090665, 0.08121098617890052, 0.12318253650196961, 0.10473715234547853, 0.16342461641345704, 0.14601066655346326, 0.2326562771839755], [0.018403806923223392, 0.050458639194922786, 0.08925851328032357, 0.014904759591445327, 0.00722715281881392, 0.046841491146811416, 0.03711256444720285, 0.057786308495061736, 0.0376244614432965, 0.05144465235727174, 0.020269759564793537, 0.02739789546467364, 0.050238227272140126, 0.027561162864523273, 0.030789422137396674, 0.03372511746627944, 0.038567143359354565, 0.006069016526453197, 0.023593951814941, 0.048327937456113954, 0.12395483148949486, 0.04388537869921752, 0.029104467015713453, 0.054070436994412115, 0.029937060017670904, 0.01893174448715789, 0.02924021812421935, 0.07009884209505149, 0.018471063314271823, 0.028001783149582998, 0.04409327504358121, 0.01873074714759631, 0.08020084431128842, 0.06476808099874429, 0.018762835068628192, 0.03541011330006378, 0.026801751560664604, 0.020746803609654307, 0.035216778317200284, 0.03277690888249448, 0.03296551786895309, 0.04696277928139482, 0.013428019725584557, 0.018071200931444764, 0.013958158287485796, 0.05934826218123947, 0.03796320648065635, 0.012384925652960581, 0.035576490086636374, 0.030458361509123018, 0.0604478960324611, 0.01089783982440297, 0.05897425367896046, 0.07055993378162384, 0.0676909452304244, 0.027186491094263535, 0.021918971158031906, 0.015259594390434878, 0.04451305751821824, 0.014249067454199706, 0.03001667253140892, 0.03202784014865756, 0.017763169781704034, 0.026688271667808294, 0.06104864379657166, 0.015028519289834159, 0.02579280561102288, 0.04434647038578987, 0.029932652932724783, 0.0254206902214459, 0.025129310321062803, 0.03071329729365451, 0.04932970280892082, 0.03847663357321705, 0.025762602321005294, 0.04527459094034774, 0.06517625373921224, 0.013917642961522298, 0.016921141750312278, 0.08757421973028354, 0.06919328961521387, 0.051316660296704085, 0.029954691750130484, 0.015058111898334963, 0.036532542535236905, 0.01793595533152776, 0.02051373361609876, 0.031254116844918044, 0.03870669426396489, 0.06899916074637856, 0.07554108649492264, 0.005965212118878428, 0.014819443990875567, 0.025111950002610683, 0.047255136272204776, 0.0566128296777606, 0.027050225995481014, 0.0444611190552158, 0.04314790273617421, 0.053086625678198676, 0.05826504887746913, 0.009933836641721427, 0.06715063458042485, 0.0040562263623412165, 0.03758627349244697, 0.042915551989738426, 0.024861348360510807, 0.052351697614150386, 0.04097569501027465, 0.048384591737496, 0.04492850076141102, 0.049763985576906374, 0.04692141239398292, 0.03743498732468911, 0.03653622358771307, 0.029997622660760368, 0.04893940268084407, 0.028863783859248673, 0.031058705544897487, 0.07012311329266854, 0.04927778470196894, 0.023687394568696618, 0.029566413656409298, 0.024407666276342103, 0.0120056568079495, 0.175080287403294, 0.036943337813551934, 0.025040744537753717, 0.027127034463254467, 0.0074767892448497665, 0.017227145776684796, 0.034288993637476645, 0.013492344845352429, 0.04098288069612213, 0.05600601241790822, 0.02154770732990333, 0.015689366596883962, 0.029398856218904257, 0.009294822047065412, 0.039646699359374385, 0.04694032655762775, 0.06677868203925234, 0.04690229806250759, 0.013470371336942273, 0.01190849398595414, 0.03571149819929685, 0.01169873506296426, 0.03599952274401273, 0.023063401891184703, 0.07650548153157745, 0.051795217474656444, 0.01616767610955451, 0.015372738408456956, 0.04834002895014627, 0.051679961516388824, 0.04572785233280488, 0.018292325315997005, 0.017340618884190917, 0.014051331323571503, 0.02598453755490482, 0.06245584400104625, 0.018173946400306056, 0.0871199473206486, 0.03682489274069667, 0.03203855760927711, 0.05342805432155728, 0.07222153712064028, 0.07416596064077956, 0.034030322517667494, 0.02568985997433109, 0.12289485122476305, 0.06422105285206012, 0.019464145115177547, 0.04250371516016977, 0.023434843834755675, 0.03924180055037141, 0.02200163877569139, 0.034689895875219784, 0.01747666685176747, 0.03761322829606278, 0.02740100654773414, 0.05154582532122731, 0.02583885269372591, 0.029265669972768853, 0.05431417016578572, 0.040600509249738286, 0.09035643722329821, 0.033329877603266916, 0.031011611821928194, 0.010934140599731888, 0.024147838254326155, 0.041856419893779924, 0.015802305358062898, 0.02231191926901894, 0.03223631664046219, 0.04719631407143814, 0.005342836899217218, 0.04556462734139391, 0.03152879121314202, 0.010160815087147057, 0.05081092439857977, 0.0349280005986137, 0.012093621239598309, 0.0621565557750208, 0.06246910257531064, 0.07130717047091041, 0.07630000077188015, 0.05705792150859322, 0.05980668043983834, 0.032796837455992184, 0.028930507600307465, 0.01968096419503646, 0.027890969899349978, 0.006597816253945763, 0.00947448200479682, 0.007565712107212416, 0.020158751235742654, 0.06407773947077137, 0.07855733750121933, 0.0747622029323663, 0.045998597983270884, 0.017799125352342213, 0.09071800817868539, 0.030242882535925934, 0.02517658724848713, 0.07626667791711432, 0.014137422150400068, 0.013246180822274514, 0.04182728020740407, 0.02175353923147278, 0.08950151024120194, 0.011746592137829533, 0.046547838154115846, 0.07620174211582967, 0.05021276185289025, 0.018522214676652635, 0.003978527741440172, 0.06555339028792721, 0.028021489502862096, 0.009527103243661779, 0.018563703700367893, 0.011663253618670362, 0.06183128644313131, 0.02997399607141103, 0.018561152408697774, 0.016043651782508408, 0.007486929102534694, 0.023204337007233074, 0.03145703274224486, 0.013659071077459624, 0.022003313060849905, 0.021863763852577125, 0.040368138147251945, 0.02374806917006416, 0.056898146867752075, 0.08532621285745076, 0.015375891899956124, 0.032691291333841424, 0.034051394422671626, 0.025531764707661102, 0.009009120636619627, 0.03917395383385675, 0.029514970523970466, 0.041450954508036375, 0.042524169598306925, 0.0763884817383119, 0.008080054373879517, 0.016996903577819467, 0.010705157083326151, 0.07330976479819842, 0.03474218378375683, 0.041706667215164216, 0.014970826849873577, 0.05283292822007622, 0.04789946973323822, 0.042175032797136476, 0.09156129149986164, 0.02878249536401459, 0.026452652078920176, 0.03222559917984264, 0.08613031756665025, 0.022732950248090283, 0.0013106126529497228, 0.03442654964913215, 0.051679065850164206, 0.021847592666745186, 0.018175859869058644, 0.03918491556708302, 0.04960799716146929, 0.04426538545106139, 0.015034621015989354, 0.07590099503951413, 0.04366646294615098, 0.03428013875548329, 0.02586174137624247, 0.01213867511666779, 0.0028454030980356038, 0.04712533591581242, 0.0633978813088366, 0.004544285999145359, 0.04645344036232148, 0.06577915924468211, 0.039716554539544244, 0.04406299202569893, 0.04684645463047283, 0.03484006246019687, 0.047125525905617645, 0.07348477933555841, 0.037067238307957134, 0.04896233377179929, 0.02204395391579185, 0.037153072987816164, 0.029436372420085326, 0.06344328887228455, 0.05749506090900727, 0.024357117113790343, 0.05109662835353187, 0.05262612092441746, 0.053131819503115754, 0.020287876449791447, 0.03711584855669311, 0.03107469861528703, 0.03685780508177621, 0.04792344916079726, 0.043646066183490415, 0.06723157702279942, 0.03642111351447446, 0.035011877704943926, 0.0456997779464083, 0.07402731558041913, 0.004638891168204802, 0.018133571870358925, 0.008697193847703082, 0.06628618096666676, 0.010321506598432149, 0.00686210479554055, 0.04840503599760788, 0.032228672943477116, 0.02412728712494884, 0.02806870705847229, 0.02459872986323067, 0.07370866875031165, 0.023211890798328177, 0.12707147853715078, 0.05813417982842241, 0.01753025415486523, 0.030976399247135435, 0.048288300832999606, 0.027352889933224236, 0.04917210965816464, 0.03356590261682868, 0.026152955035545995, 0.10823390792523112, 0.09635009989142418, 0.1605429867548602, 0.08797551212566239, 0.1321346661342042, 0.2084563257438796, 0.25578115774052484, 0.15764242596924305, 0.15851624336625847, 0.12040981171386582, 0.17638606019318104, 0.11383404742394175, 0.16570795460471086, 0.07267996894993953, 0.08898630538689238, 0.08880550294582333, 0.1476282804672207, 0.10889875010720321, 0.13274580905480043, 0.1835589895823172, 0.3546781523951462, 0.1665500301335539, 0.07050967469279255, 0.14594539148466928, 0.09651915689132043, 0.10601495592189686, 0.11137946056468145, 0.15806037639932974, 0.13182524059500011, 0.14770963681595667, 0.1635491954428809, 0.12534962807382855, 0.14656740453626427, 0.12295931205153465, 0.13645082738782677, 0.18953976008508885, 0.08149377243327242, 0.07204728932785136, 0.15114041843584605, 0.07236019575170108, 0.13342594541609287, 0.10511227364518813, 0.1596195548772812, 0.17963439731725625, 0.09612386274550642, 0.08188683419887509, 0.19053791223892144, 0.08573557303420135, 0.13187224950109208, 0.13414477184414864, 0.1573292820581368, 0.08030875173530408, 0.1157214604318142, 0.22502567592476094, 0.18533601851335593, 0.07550525306058781, 0.07256698608398438, 0.13906172157398292, 0.17193027000342095, 0.1236608222659145, 0.09876506709094558, 0.1350663173943758, 0.055468307342380285, 0.10174101311713457, 0.08705429905759436, 0.0865427107949342, 0.14077479179416383, 0.0746171660721302, 0.1624621009188039, 0.10071894938924483, 0.11218762969864265, 0.1027501303968685, 0.12355322018265724, 0.14613762045545237, 0.11614068650773593, 0.13260037185890333, 0.23099345926727566, 0.06509039191795246, 0.1449296245617526, 0.19073831077132905, 0.13309084411178315, 0.18153322328414234, 0.10045837837138347, 0.06879630591720343, 0.07264724320599011, 0.1338493376970291, 0.1028706653575812, 0.14256722347012588, 0.1546649057418108, 0.10974980265434299, 0.13815437097634586, 0.10433489643037319, 0.14963396212884358, 0.22483842740101473, 0.12154520436057023, 0.0717552410704749, 0.07419884244778327, 0.11407457451735224, 0.10272062090890748, 0.15394515650612967, 0.14115336005176815, 0.09663540351071528, 0.13955599362296717, 0.1316050695521491, 0.27284818621618406, 0.14443615318409034, 0.12969261860208853, 0.11194724509758608, 0.11244661294456039, 0.12774530452276978, 0.0748953925711768, 0.10717934236994811, 0.1393929145165852, 0.10238416253456048, 0.14413709565997124, 0.15060892195573874, 0.11292133639965739, 0.08329516755683081, 0.1338405574538878, 0.13312139175832272, 0.07000297866761684, 0.11204466237021343, 0.15133384162826197, 0.11888454641614642, 0.07247490888195378, 0.19748635510248796, 0.09394602996430226, 0.185100933270795, 0.12739717534610204, 0.11793215466397149, 0.09612319778118815, 0.14093920082918235, 0.07097246271691152, 0.14234387688338757, 0.12126110174826213, 0.12181931893740382, 0.10235572513192892, 0.21513255392866476, 0.10046340631587164, 0.11801204537706715, 0.1815701084477561, 0.20023710892668792, 0.16294129591967377, 0.14501102162258966, 0.12873266796980584, 0.16289824965809072, 0.11773015478891985, 0.12269340774842671, 0.12514294630714826, 0.19491572518433842, 0.13935372233390808, 0.1565229788954769, 0.10634158910917384, 0.25820863034043995, 0.08686487922178847, 0.14322821157319204, 0.13522833798612865, 0.1324226635375193, 0.06936742205704961, 0.2195485412542309, 0.1514319306505578, 0.13388546290142195, 0.16353411839476653, 0.08531978713082415, 0.11712558008730412, 0.20001601507621153, 0.2000416772706168, 0.21528339226331028, 0.12191780151001044, 0.13181377335318498, 0.20264627465179988, 0.17135173747582094, 0.19108455362064497, 0.1674585613821234, 0.06183836356337581, 0.09294532651879958], [0.007266430666537157, 0.023301733923809867, 0.01659668157143252, 0.05003869387188128, 0.017634519542168294, 0.03996666933276823, 0.030345083480434756, 0.045634272175707986, 0.010251783732590931, 0.06308637266712529, 0.01807540445588529, 0.03547031631959336, 0.06167070434561797, 0.023506349551358392, 0.037010980969561, 0.026985241000407507, 0.010525213837224458, 0.030380207845675092, 0.0759417274966836, 0.08392729078020368, 0.001105878599836225, 0.006536504253745079, 0.04738646672506418, 0.03455046371423772, 0.021224753498764973, 0.05113475523622973, 0.08627391593264681, 0.02678642006191824, 0.03843811992555857, 0.05986135679164103, 0.042556739279202054, 0.05213449516200593, 0.026897160369636755, 0.024678126942100267, 0.0013480996983292113, 0.015104639044563686, 0.0521691038406321, 0.01798392097199602, 0.039189112306173356, 0.05140196911192366, 0.022561406417350684, 0.026544885344005058, 0.04702818327184234, 0.023285730675395046, 0.030226658763630048, 0.029249235854617188, 0.011389399429650178, 0.0464776776331876, 0.05799989774823189, 0.03609664485390697, 0.014418026066518255, 0.031479136020477326, 0.037416683842561076, 0.02762311650440097, 0.03372622008568474, 0.04726731597578951, 0.024535673603947674, 0.06049908471426793, 0.04838831689474838, 0.04122907694961343, 0.05608456302434206, 0.030110083054751158, 0.09385554053421531, 0.026681216599951898, 0.04934205553893532, 0.02232834660182042, 0.05903856522802796, 0.03479326389996069, 0.00832091479761792, 0.05380359631297844, 0.08962901375655617, 0.05108472006395459, 0.03956293760399733, 0.01327731624977397, 0.022382366470992565, 0.020084105598341142, 0.03315815056807228, 0.00571302355300369, 0.032458872733903785, 0.06262558632131134, 0.014438563625195196, 0.03608221919941051, 0.03720719972625375, 0.05794133339077234, 0.04142015580353992, 0.022659868633906757, 0.03990346040310604, 0.03172017201515181, 0.032435636302190166, 0.026987471684281315, 0.03283924589465771, 0.06104338515017714, 0.07835075751479183, 0.007561643441606845, 0.013487226994974273, 0.06633185315877199, 0.046798346497650654, 0.06613377521612815, 0.0996613372117281, 0.014867328207141586, 0.03404122657541718, 0.041329242289066315, 0.037394831622285504, 0.03733060149742024, 0.01722012972459197, 0.07786358972745282, 0.022506141436419318, 0.04856939414249999, 0.056176070256956985, 0.025165264195363437, 0.062003892181175094, 0.015884969583047286, 0.04486979730427265, 0.027917093497567942, 0.02762231244040387, 0.032856093919170756, 0.028032324010772363, 0.054889998731336424, 0.03225450137896197, 0.012743734970821865, 0.019934697276247398, 0.038601897923009734, 0.0351395067492766, 0.02267800417861768, 0.04501384350338152, 0.026099081051402857, 0.02076040654044066, 0.04805735465405243, 0.003962066481887762, 0.0128461072454229, 0.0233868120371231, 0.04921820932733161, 0.022352288709953427, 0.04980212263762951, 0.023765453237241933, 0.03396028074036751, 0.03752658276685646, 0.03170588206765907, 0.024867653647171598, 0.06518953945487738, 0.018496143664898615, 0.01344472186506859, 0.03725011706618326, 0.0481061141804925, 0.05036104550319059, 0.08476205170154572, 0.01267770248731332, 0.012594047601201704, 0.07240428695721285, 0.05168730665796569, 0.07313077404562916, 0.03776255349761673, 0.036821106515292606, 0.00893568279155131, 0.07640219493103878, 0.049142128588365655, 0.07270017572279487, 0.019086559037012712, 0.05935379224164145, 0.03379291668534279, 0.03802434927118676, 0.017390908507098044, 0.025755757599004676, 0.03388372163421341, 0.018613871186971664, 0.05010305291840008, 0.0569180652632245, 0.012836936844645866, 0.04299808220405664, 0.03189826710149646, 0.019299535912328532, 0.014258592389523983, 0.01869004183182759, 0.05571511767006346, 0.06396980490535498, 0.05100594214828951, 0.03170035539993218, 0.012666001999085503, 0.03616574686020613, 0.014300853246822953, 0.05926143005490303, 0.03329606959596276, 0.01573602945011641, 0.01380147522182337, 0.021751654600458484, 0.057608566246926785, 0.009955999291768032, 0.07523358799517155, 0.05068762780034116, 0.07439410447009973, 0.04574573851589646, 0.04185842496476003, 0.011709204858302005, 0.021193510353831307, 0.027302702090569904, 0.05053285396258746, 0.04466765832954219, 0.016602360909538608, 0.012492745715592588, 0.003628753117352192, 0.021281256806105375, 0.07286029641649552, 0.015767160636772002, 0.05982889567634889, 0.053540735239429135, 0.03783316524433238, 0.03837362177936094, 0.05627491584579859, 0.02572246527831469, 0.03121194928618414, 0.009129055942009603, 0.04093015513249806, 0.07791559265128203, 0.008764566437873458, 0.11791823112538882, 0.06928289694977657, 0.031797199310468774, 0.0374168738323663, 0.027543790671708326, 0.02868007050294961, 0.04793730145320296, 0.05046240506427629, 0.037941893695720603, 0.06334581053150551, 0.04664532667292016, 0.015094713773578405, 0.08179942531777279, 0.034388673824391196, 0.040389111664678366, 0.02169360762595066, 0.05508120311424136, 0.030585753066199164, 0.06325231519128595, 0.04036878954086985, 0.03480024941797767, 0.033761425875127316, 0.042906608898192644, 0.11345495669437305, 0.08170223874705178, 0.010061701476973082, 0.037595525317426236, 0.03579715306737593, 0.05740017457199948, 0.022101464847634946, 0.01942838971236987, 0.05247580845441137, 0.02066632087475487, 0.05195301757859332, 0.025632413503314768, 0.021290162578225136, 0.030089404700057845, 0.026088022626936436, 0.01759466409151043, 0.0838872165020023, 0.02733504955124642, 0.0623021965314235, 0.03981982756938253, 0.06597887245672089, 0.07195437752774783, 0.07875072676688433, 0.04838880543996181, 0.05117400170170835, 0.042943874041416814, 0.030763196758925915, 0.009005655867180653, 0.02886128006502986, 0.035028766441558085, 0.03591863797711475, 0.02657839309956346, 0.05049751585881625, 0.018564356790323342, 0.06233005039393902, 0.01925989080752645, 0.03178430714511445, 0.09026664668428046, 0.027330640769962753, 0.011421119245434446, 0.004456792301165738, 0.013199060806073248, 0.036076580573405535, 0.11215710919350386, 0.09837418342275278, 0.029904330881046395, 0.05361887193950159, 0.024996000242286494, 0.10243144964001008, 0.02664594634968255, 0.028925649289573942, 0.05069000267290643, 0.0698420980146953, 0.04546585978407945, 0.0115606438568128, 0.03142345204417195, 0.035699718831373115, 0.01473356011722769, 0.0382290090035115, 0.027275782910042574, 0.03041424655488559, 0.03954619814508727, 0.014460319154230612, 0.05037519974367959, 0.05452173063531518, 0.038904348122222085, 0.06938040243195635, 0.01673337584361434, 0.05748210767550128, 0.012018736418602722, 0.061175991248871596, 0.04081721976399422, 0.07621998792248112, 0.07792153661804539, 0.03450730549437659, 0.012635991243379456, 0.05346145520785025, 0.05852003555212702, 0.05524466220023377, 0.027405442470418553, 0.011174515022763183, 0.029542468155601194, 0.02601284264320774, 0.014972389176754015, 0.04562263869281326, 0.03968054468610457, 0.030321565456688404, 0.05061861061091934, 0.07215463356780154, 0.011747735469335956, 0.07376619494919266, 0.09809432165431124, 0.028574843292257616, 0.009184253917607878, 0.03431540900575263, 0.028680036576198678, 0.029856348277202675, 0.04924832949680941, 0.0132263446991731, 0.04107210126572421, 0.03742936226938452, 0.058284373554800234, 0.034006231131830385, 0.015955927382622446, 0.04692823506359543, 0.06800073039318834, 0.07645228438611541, 0.023701976286247373, 0.026902544545009732, 0.0033817538600747605, 0.04427786710272942, 0.008614410030921655, 0.012057445145079067, 0.011321372901355582, 0.04533239194591131, 0.12016933890325682, 0.07419779071850435, 0.08495450458888497, 0.0965879535568612, 0.17110122234693595, 0.08900174205856663, 0.10835978974189077, 0.07580694330057927, 0.12229121290147305, 0.14330390893987247, 0.11125661179955516, 0.13734259882143565, 0.1422788460872003, 0.22477364087743418, 0.13743956147560052, 0.0871570428301181, 0.13005034226391995, 0.06317253982914345, 0.16210831276008061, 0.17453668585845403, 0.12308314469243799, 0.11420623745237078, 0.11529441763247762, 0.13167016820183822, 0.10647926386445761, 0.1279581202460187, 0.16788008090640816, 0.15588645876518317, 0.15955856814980507, 0.08886053213583571, 0.14042758542512143, 0.11711350216397218, 0.10306251434875385, 0.10259041682417903, 0.08942094099308763, 0.14595031764890465, 0.19825759157538414, 0.08798617191080536, 0.19495778078479425, 0.13873753111277307, 0.11168616517846074, 0.134623220456498, 0.15094350757343428, 0.11941277235746384, 0.09571744741073676, 0.12709381590996469, 0.11382511790309634, 0.18213197615529808, 0.17358029074966908, 0.13014202591563973, 0.2050482343350138, 0.16076336135821684, 0.1267494186758995, 0.14686552568205766, 0.09778872983796255, 0.1390425054622548, 0.0968594489885228, 0.15725389681756496, 0.10886455194226333, 0.12736231221684388, 0.19126561390502111, 0.15385925397276878, 0.21783228191946233, 0.09915601182729006, 0.17423898540437222, 0.1371351299541337, 0.15009468740650586, 0.07118005372051682, 0.10175081794815403, 0.16062354243227414, 0.12196007424167224, 0.11121426442904131, 0.1386724460337843, 0.06841695734432765, 0.05912972640778337, 0.16175501314657076, 0.0714335883302348, 0.23676838938679012, 0.13788664819938795, 0.1351996630962406, 0.1399959692997592, 0.18637039086648396, 0.15878118414963993, 0.12741126173308917, 0.09016385541430541, 0.18097782880067825, 0.07958539947867393, 0.10044793571744647, 0.1264004074037075, 0.10815770844263689, 0.16914359453533376, 0.13168557094676153, 0.12762478313275746, 0.07480898113655192, 0.11677359683173043, 0.10414207713412386, 0.14539351181260177, 0.1588957751435893, 0.18148473517170974, 0.08930285554379225, 0.10575309568750006, 0.10263497621885367, 0.16281054222158023, 0.17362629542393343, 0.23830152569072588, 0.19522095737712725, 0.08582247979938984, 0.1192199055637632, 0.09380881661283118, 0.1815109537648303, 0.08732761974845614, 0.13449926567929132, 0.15649091133049556, 0.08922871202230453, 0.13643921086830751, 0.0680716848000884, 0.07944728367562805, 0.26638950992907795, 0.19050542398222856, 0.14538493512996606, 0.09121956769376993, 0.10795470433575766, 0.1525120905467442, 0.10011639672198466, 0.11782174344573702, 0.14690408004181726, 0.09767531949494566, 0.15413800972912992, 0.10803916837487902, 0.1484652669834239, 0.07055339270404407, 0.10480014753660985, 0.1873807566506522, 0.1998500996934516, 0.11758792027831078, 0.13899926921086653, 0.08227442697222744, 0.1346766890159675, 0.15215512684413365, 0.09021184819617442, 0.09662769535290343, 0.12257376845393862, 0.11520688661507197, 0.07624579260924033, 0.09360943588295154, 0.15320548548230103, 0.10970441544694559, 0.1281139390277011, 0.10241036077163049, 0.1973845748496907, 0.23752699153763907, 0.2312238354768072, 0.14587960072926112, 0.09706982877105474, 0.15380172777388776, 0.170295027749879, 0.11150072834321431, 0.10118969662913255, 0.19792118748383863, 0.14927994326821395, 0.09686881955713034, 0.09150421991944313, 0.15821316891482898, 0.16566095926931926, 0.12312191618340355, 0.09007120824285916, 0.1597896907478571, 0.13219106596495422, 0.14266253049884522, 0.1407414214419467, 0.05430336110293865, 0.07291931539241757, 0.08538007496723107, 0.1489594711789063, 0.2668274635715144, 0.1452753245830536], [0.02123456511513463, 0.038278348677392514, 0.020650360034778714, 0.045660127752593586, 0.018128803465515375, 0.05049340732927833, 0.02411800985490637, 0.06373186303036553, 0.06425776838191918, 0.03996204172394105, 0.02813761228961604, 0.03501205073137369, 0.04875552986881562, 0.03325634815597108, 0.05051944271794387, 0.059691241277115684, 0.02812954450824431, 0.08705584611743689, 0.052215301897376776, 0.04556737540821944, 0.0495189292622464, 0.031082803716084788, 0.014889068469139082, 0.06497455241956882, 0.03440336410754493, 0.07487377444548265, 0.06009739876857825, 0.011555401325624968, 0.0231349432308759, 0.01101872423065028, 0.05670954466664365, 0.015397202988554324, 0.0216779487340578, 0.025685042375698686, 0.08295486867427826, 0.05827235669961997, 0.0122183419132073, 0.011981942857216512, 0.005675941190150167, 0.04472687408061964, 0.05156864445390446, 0.03034856097240533, 0.06647515296936035, 0.060030339152685235, 0.024994436219068508, 0.021242425943325673, 0.01573348494379648, 0.012472856157858456, 0.005400530187346573, 0.019215580774471164, 0.04562260137338724, 0.002320304779069764, 0.006249144249263087, 0.011711956317802625, 0.020438582470108355, 0.051292246606733115, 0.03114845197913902, 0.009064729974072958, 0.0271769203578255, 0.019677332336349145, 0.028591385976012264, 0.04659538310287254, 0.04877485454614673, 0.022056323609181812, 0.0070858652886402395, 0.035697075937475474, 0.04629918221118195, 0.07727098438356604, 0.014592957483338458, 0.038189379165747335, 0.06584866158664227, 0.04254829830357006, 0.03089460524331246, 0.012800888823611396, 0.020286605892969028, 0.016505591637854065, 0.08255647362342902, 0.05218089338658111, 0.04008813727913158, 0.015470688331073948, 0.015785789815708995, 0.03893392885636006, 0.033328995507742674, 0.04756767628714442, 0.05310435240556087, 0.05212560635326164, 0.03289586964196392, 0.01819597164701138, 0.0256132431927004, 0.05147743916937283, 0.05809843460364001, 0.020700617427272455, 0.0304243838680642, 0.062300859817436764, 0.003734576590691826, 0.019036354230982915, 0.046448476878660064, 0.008680015037368451, 0.0703491468780807, 0.01683262176811695, 0.05244013786848102, 0.06189388129860163, 0.012810572366496282, 0.010298399088372077, 0.09350984051291432, 0.04088871021355901, 0.03174621758184262, 0.042214615137449334, 0.039605675132146904, 0.06965292245149612, 0.1528155314070838, 0.04916610123057451, 0.06051902685846601, 0.0024138361664621955, 0.012307599802235407, 0.035262090885745626, 0.020285547378339937, 0.05080595752224326, 0.01688226847909391, 0.05105444722409759, 0.037978636366980414, 0.0774559530296496, 0.03507880500650831, 0.016726875478135686, 0.0756337268810187, 0.04579974990338087, 0.019623337912240198, 0.021363705596221343, 0.03959372273779341, 0.038157817109354904, 0.046696878370961974, 0.0643769394872444, 0.06059728230216673, 0.0016675141211765418, 0.04590498050674796, 0.04264660445707185, 0.04476800348077502, 0.03325445504326906, 0.05803406198642083, 0.06157161109149456, 0.017994344966220002, 0.07298260913895709, 0.0032785709481686354, 0.07360876125416585, 0.04492179683542677, 0.04248914362064429, 0.024342045154688612, 0.07704402799052851, 0.03703292818473918, 0.0549768613917487, 0.05868607985654047, 0.03278138042826738, 0.01789488360684897, 0.027776624874344895, 0.029539479208844047, 0.05710734599935157, 0.033620816455887895, 0.016099756450525353, 0.019543185963162353, 0.019803076749667525, 0.017740221727373343, 0.07116984176848616, 0.030233515359993492, 0.014821588161534496, 0.05055864168597119, 0.018129359864230667, 0.03718005832550781, 0.020494522593383278, 0.048029178487403054, 0.06315777490713767, 0.02051756564261658, 0.11086988755102668, 0.015305521033172096, 0.01898115879989096, 0.011879796195509178, 0.032750768320901055, 0.01584594533778727, 0.033490259532949755, 0.07961491575198514, 0.03171082180259483, 0.041100128154669485, 0.08884320235145943, 0.03389844584411808, 0.03822732962934034, 0.022424311809507862, 0.050053485935287814, 0.042439556281481466, 0.06402454232530934, 0.025445046235940287, 0.055219179817608426, 0.019046873220109513, 0.007097980531398207, 0.02722649073361286, 0.03132793127692171, 0.05387296634060996, 0.02156942045050008, 0.06401281045483691, 0.061568489830408774, 0.02689406116093908, 0.024208811411101903, 0.052309431667838774, 0.04189936437511018, 0.038169433628874164, 0.03374077466183475, 0.025739393030692424, 0.06643382340137448, 0.03400453479428377, 0.028150439994143586, 0.03169286098065121, 0.014082063022734863, 0.06062575363154922, 0.03060864344505327, 0.04023970164624708, 0.03706887697002717, 0.02384668236066188, 0.0193433794525585, 0.04807011450507811, 0.010543056763708591, 0.040541524200567176, 0.027479234850034118, 0.03086706350690552, 0.0350542148974325, 0.04129396864612188, 0.04962266369589737, 0.008501440735666879, 0.046239427024764676, 0.020208669360727072, 0.02221608467932258, 0.001465319061285949, 0.07827454446149723, 0.035606108140200377, 0.03203879509653364, 0.052814953827432225, 0.0416253956833056, 0.06090160525803055, 0.05151058221235871, 0.06587669865361281, 0.0349086216384811, 0.033233556164694686, 0.015721415502152274, 0.01684259114387844, 0.02193621442919331, 0.054400120196597915, 0.043008436648441215, 0.028335544347230877, 0.0474797822535038, 0.06290709014449801, 0.03364439894046102, 0.029755304234900644, 0.0022150084426227424, 0.0323343072751803, 0.0032009883143473417, 0.047744634827332835, 0.03217478029962097, 0.033315231424889395, 0.013351942379293697, 0.014742733910679817, 0.0041114162803361455, 0.016778303343536596, 0.021382811446008936, 0.015211672854742833, 0.012422134817045714, 0.07354683814836399, 0.04870350319626076, 0.02659400619034256, 0.033455087670258114, 0.015168982824044568, 0.020443394979728118, 0.02130955341272056, 0.028493442838745456, 0.029555971002472297, 0.06292131902383906, 0.011195925347107862, 0.06708175649068185, 0.10716236542378153, 0.0318827320422445, 0.049727436288126876, 0.05331725633836218, 0.039742298158151765, 0.04451348499527999, 0.0024338429835292375, 0.05948764005942004, 0.05433796299621463, 0.042044730324830325, 0.010878348057823522, 0.044960235844233205, 0.08000624725329024, 0.01310036110226065, 0.07088880613446236, 0.033110402058809996, 0.06142136308231524, 0.0214023091497698, 0.02187021163159183, 0.03683885359870536, 0.019446306429537277, 0.015261596068739891, 0.05566674830125911, 0.02598535010058965, 0.03908112006528037, 0.02894413597615702, 0.06297370192727872, 0.048523973008351665, 0.010300089488737285, 0.049587274701999765, 0.07637670237038817, 0.04228686893891011, 0.04762242727779916, 0.07176132074424199, 0.023462126031517982, 0.04461710747065289, 0.0689486845263413, 0.06885900255292654, 0.0763266332713621, 0.04056337642084275, 0.048883606746260605, 0.0188287479603397, 0.04083205253950187, 0.05593492569667952, 0.0378208057289677, 0.06279870096061911, 0.01907799931775246, 0.01436215210040765, 0.08808293100446463, 0.03393247098262821, 0.007255249257598604, 0.028428944692547833, 0.06658361000674111, 0.039650007217590294, 0.04032407747581601, 0.03105815253885729, 0.03994973649137786, 0.03352318883740476, 0.040501578844019344, 0.05229846314926233, 0.05003018843542252, 0.05211934008236442, 0.032716570155961175, 0.07772190483020884, 0.042855725557144196, 0.03800690074318221, 0.030809391422995498, 0.02990811032110027, 0.053411348789398155, 0.008197002428849893, 0.03039745959852423, 0.043594602695001025, 0.0788149976038507, 0.054489225415246825, 0.024844904064333866, 0.040094637644610236, 0.006988442078831473, 0.06001019344798156, 0.12431967976902213, 0.10525815188884735, 0.21264013195676462, 0.14330838727099554, 0.09799171358879123, 0.20175246761313506, 0.153793585353664, 0.09175938301320587, 0.14397635071405343, 0.15775438424732002, 0.10404189822397061, 0.14175342928086007, 0.15972544705229147, 0.13018957764974662, 0.19711284871612275, 0.15556457532303675, 0.09175297764262982, 0.2065086859677519, 0.15688037686049938, 0.14947192796639033, 0.10940315268401589, 0.19577427554343427, 0.07230369414069823, 0.0984025394011821, 0.10708863580865519, 0.13034363224038056, 0.18603527599147388, 0.1719045535262142, 0.0917910977399775, 0.1094215749097722, 0.19943179642515524, 0.1754112767853907, 0.12829248873250826, 0.0975319246894547, 0.21934840056513036, 0.10324291645416192, 0.07133748741554362, 0.1316444788660322, 0.14876912853547505, 0.10408025580857481, 0.16449936160019465, 0.08263090891497475, 0.10198165556149823, 0.10879637952893972, 0.16881161449210985, 0.1619951602603708, 0.1890851551932948, 0.10223279494260039, 0.0833525105512568, 0.11921601077275616, 0.09886918828955718, 0.06608508354318993, 0.06815824551241738, 0.12216896803251334, 0.13609033530311926, 0.137589015598808, 0.1258394489330905, 0.13322163852197783, 0.11782063064830643, 0.11139123993260519, 0.10861949902027845, 0.1065855020923274, 0.119319012388587, 0.07666469298835311, 0.08263171637164694, 0.16118973919323512, 0.164526408006038, 0.1389553408537592, 0.06941610694463764, 0.101577438680189, 0.12751633966607706, 0.12958922343594687, 0.15937943490488188, 0.08685620754425015, 0.09462149800466639, 0.09517820884606668, 0.1371688260031598, 0.12679079574133667, 0.14930815675428935, 0.10812971208776746, 0.0777433126100472, 0.09843330417892762, 0.06477335321583919, 0.21249643181051525, 0.15689363543476376, 0.08177564266536917, 0.19599011753286633, 0.107918585916715, 0.1463548330856221, 0.18143954473946775, 0.1172219727720533, 0.20376391682241643, 0.10796140147639172, 0.13904027986739362, 0.1310330509607281, 0.13536465567137512, 0.1116037503150957, 0.11469696754855768, 0.16408217112932885, 0.09694478833781821, 0.1311864677284445, 0.14241015618400915, 0.1394763064703771, 0.07319184898265771, 0.16361299130533422, 0.14340161798255785, 0.0912566292764885, 0.09688353019633464, 0.15181887203029223, 0.16820835614843027, 0.15390771494380065, 0.1135954541553344, 0.1225093211978674, 0.09470211475023202, 0.17061334209782736, 0.10725713640983615, 0.09798168484121561, 0.10567999032459088, 0.08127830363810062, 0.10037358185010296, 0.21122538644288266, 0.12973212291087421, 0.12862107610063894, 0.0835928272988115, 0.12239744434399263, 0.16020644695631095, 0.08753144488270793, 0.09468675271740981, 0.15220251572983606, 0.1653214203459876, 0.13671431610626833, 0.14900383379842552, 0.2590440426553999, 0.11442262226981775, 0.18545088092131273, 0.19854750244745187, 0.13112400179462774, 0.15598149437989506, 0.20058807437973364, 0.11859806893127305, 0.12203712867838995, 0.2457172620509352, 0.1223686473178012, 0.14340787407542976, 0.09909444834504809, 0.15976371642734322, 0.10307518938290221, 0.15478928121072905, 0.18058826827577182, 0.1481329341019903, 0.15229656068342073, 0.09358432330191135, 0.095421131168093, 0.09722996303545577, 0.15584658804748738, 0.07433547904448849, 0.17054276088518755, 0.11723960111183779, 0.11682014433400971, 0.1771496156496661, 0.13527880742081574, 0.14585577057940619, 0.10100227847163167, 0.09555443615785666, 0.1313371296439852, 0.16556166245469026, 0.16670008136757783, 0.09777099293257509, 0.13955254666507244, 0.20560871783111775, 0.1433350129851273, 0.16535134374031, 0.11831589335841791, 0.10277651183839355, 0.11215353331395558, 0.10617206392011472], [0.06095087368573461, 0.011218958218315882, 0.047609830275177956, 0.01168128483862217, 0.04274179274216294, 0.029692689023379768, 0.014946078981405922, 0.05355258585352983, 0.034320762647049766, 0.01896562204430146, 0.06037947256118059, 0.0768669235653111, 0.015915449376084974, 0.04858727693291647, 0.04093767669317978, 0.02300653896028442, 0.016154556634968946, 0.04342163394072226, 0.017812346607180576, 0.05769847892224789, 0.04136384757501738, 0.09894217151616301, 0.03976048289665154, 0.04813503673566239, 0.03423619343500052, 0.05304091616666742, 0.019958464661613107, 0.02955598457317267, 0.06318904858614717, 0.06155545517270054, 0.060248393166278086, 0.007768534705974162, 0.017897512930046235, 0.06674206150429589, 0.036220311253730736, 0.023848578866039003, 0.028499281632580926, 0.054130151468728266, 0.03836768459794777, 0.0046374467367838535, 0.055906400084495544, 0.025760717689990997, 0.09713672553854329, 0.029818333352782896, 0.0522059007946934, 0.06642052411500897, 0.028746438013123612, 0.046583980321884155, 0.03194979165813752, 0.050365459373486896, 0.018562346630330597, 0.032558993968580446, 0.03961296599092228, 0.02072286998320903, 0.03644643983404551, 0.07971675707293407, 0.030206740368157625, 0.04445285789136376, 0.03604123229160905, 0.03976263724533575, 0.035636150278151035, 0.04603919812611171, 0.01829353141199265, 0.055053339073700566, 0.019118289030822258, 0.0557836259582213, 0.008682864884446775, 0.08463260757603816, 0.013023409293964505, 0.04403997951054147, 0.0616332899246897, 0.026026308170652816, 0.05797673934804542, 0.007431474131798106, 0.012000052108695465, 0.03609488405553358, 0.03869112867063709, 0.055451150584433756, 0.03590714359389884, 0.04200691896091614, 0.056085248344710896, 0.09918332964714084, 0.036784255278429816, 0.03809560901884522, 0.03531721507066062, 0.029398696763174872, 0.02309339483534651, 0.028332636824675968, 0.05666000821760722, 0.03359730861016682, 0.08650570349501711, 0.045317701662757566, 0.04700954391488007, 0.024541334282340746, 0.017877913446032574, 0.045812906697392464, 0.04255807938586388, 0.05551113647275737, 0.011230941994913986, 0.02426401532388159, 0.030853044973420243, 0.050316313082086186, 0.007909977875117744, 0.02362191254672195, 0.035357557370194366, 0.016090733631114875, 0.04422073784683432, 0.004360587061715445, 0.06865861759121929, 0.024591503465282064, 0.04970144161156245, 0.05778643063136509, 0.02089842565224639, 0.019289249321445823, 0.019814180975247706, 0.07168308565659182, 0.022371387774390832, 0.08184431040925638, 0.050487354796911986, 0.022521030191066008, 0.020581851746620874, 0.03562548370765788, 0.058519234880805016, 0.07172660689268794, 0.017605289949902465, 0.03388439677655697, 0.09240350273570844, 0.019633536293570484, 0.03825015554736767, 0.04257685784250498, 0.015880893283922757, 0.015881922960813557, 0.06965533125081233, 0.029892924707382917, 0.07614837533661298, 0.016923757502809167, 0.01796240801922977, 0.024104927699746828, 0.02092543473866369, 0.05659319626699601, 0.018708889838308096, 0.03387523316113012, 0.05894549736487014, 0.025651595688291957, 0.08139022120407649, 0.010072562278115323, 0.03938687812270863, 0.05813721287995577, 0.06821726448833942, 0.010844176186115613, 0.016783962325592126, 0.03763669203700764, 0.02615070908463427, 0.012408085749484599, 0.035332169982471635, 0.0763344635654773, 0.006089660954395575, 0.04621129496289151, 0.0091794481933383, 0.0764129293550338, 0.03446863578366382, 0.04421411195237722, 0.020999498532286713, 0.02182131809448557, 0.04100400349125266, 0.03288530145904847, 0.02688152013745691, 0.011641901817971041, 0.05182131393147366, 0.008328931688863252, 0.03335468145087361, 0.044004726223647594, 0.01105559412722609, 0.02049316043433334, 0.04321595301319446, 0.04130264710901039, 0.050134716755045314, 0.053127517591097524, 0.040501914718853574, 0.010806024706523334, 0.02631027507595718, 0.010813357973737376, 0.02777200235453035, 0.02637729567608663, 0.01054459364552583, 0.02100837546666818, 0.02323144448122808, 0.03596969095191785, 0.013835882884450257, 0.02703486056998372, 0.039443125283079486, 0.0184922353031912, 0.01570619935435908, 0.05035409051924944, 0.04379339309941445, 0.02559830354792731, 0.02831735451971846, 0.04112442310101219, 0.03297074937394687, 0.04501037618943623, 0.05576063719178949, 0.03592875832691789, 0.04357855534180999, 0.01177794554470373, 0.022928841611636535, 0.05366804537230304, 0.03537209498296891, 0.012121007761119731, 0.059878808712320666, 0.032767901330121925, 0.05081995230700288, 0.04332420988274472, 0.018048695621213744, 0.051515654261623106, 0.022357825555705597, 0.019395818335137198, 0.05411192262545228, 0.020227761639814292, 0.026267093107370392, 0.09287038911134005, 0.03355686113770519, 0.07414963508823089, 0.014116327344839062, 0.04924654834238546, 0.00857840441832585, 0.05073955947799342, 0.007173768228052982, 0.049242531415075064, 0.015547902223521044, 0.07011079788208008, 0.011280986497045627, 0.06064782637570586, 0.06018719609294619, 0.07119597215205431, 0.0558802663082523, 0.09905107638665608, 0.07643500209919044, 0.03681805989305888, 0.05568809840562088, 0.03605835512280464, 0.03851321339607239, 0.006548118652842406, 0.045701989970569096, 0.025820550907935415, 0.027258933189191988, 0.01020051701925695, 0.023317153632108654, 0.02636551800450044, 0.04047167580574751, 0.0311530320905149, 0.020775259671998874, 0.026974699958892803, 0.07207888191831963, 0.012973013649960714, 0.05769808537193707, 0.02644496427715889, 0.020505558965461593, 0.049684016832283566, 0.07954329638076679, 0.03793989880276578, 0.046740358894956965, 0.05126695760658809, 0.01107005710114858, 0.06519547663629055, 0.08764464487986905, 0.045004177772040875, 0.07735126186162233, 0.007315224967896938, 0.016029767259689312, 0.029176612251571248, 0.06352544589234249, 0.06974659421082054, 0.08634142338165215, 0.04949477341558252, 0.03576473266418491, 0.042905804834195545, 0.008589199062303772, 0.030991282912769487, 0.01740219084812062, 0.044637399060385566, 0.030223574821970293, 0.016799319269401685, 0.04807276418432593, 0.05126531894451805, 0.06657206134072371, 0.028414714116869227, 0.022000615884150778, 0.00585595822693514, 0.010725286672823131, 0.018983745714649558, 0.0537524076311716, 0.05123568732025368, 0.05892847292125225, 0.0538392058307571, 0.09667652273284537, 0.007958577097659665, 0.0468446599053485, 0.0444769865966269, 0.035201270399349074, 0.014600397619817938, 0.04859866614320448, 0.056874706875532866, 0.04174120804028852, 0.07006828766316175, 0.009560119061331664, 0.011782166880688496, 0.049058224340634685, 0.015813562254022275, 0.022371109575033188, 0.023844987719452808, 0.012002860395503896, 0.053667570397789986, 0.04322569338338716, 0.04442705659727965, 0.03648801028196301, 0.08246547529207808, 0.03715389062251363, 0.04982013774237462, 0.014976275486073323, 0.03486671531572938, 0.12241782753595284, 0.028057952278426716, 0.002178200674409579, 0.05461467636216964, 0.06475798439766679, 0.02004030446654984, 0.03642283020807164, 0.024279540205108266, 0.012455265137499996, 0.02625468439821686, 0.009182007966696151, 0.0422757273939039, 0.03730934299528599, 0.033556725430701456, 0.041907476261258125, 0.012622176270399774, 0.0024498532293364406, 0.031017118133604527, 0.017725863926378743, 0.021769742647718106, 0.0585688425760184, 0.03874608322179743, 0.0381656507961452, 0.008381721713314099, 0.06084580932344709, 0.029510648255901675, 0.07554321030953101, 0.04501994014052408, 0.04546561211879764, 0.0908884493900197, 0.014295813427971942, 0.04215917543375066, 0.14250517822802067, 0.14795270163033689, 0.093410496200834, 0.07032269758305379, 0.11541242844292096, 0.10503642700080361, 0.09921237773128919, 0.11694324415709291, 0.12391211092472076, 0.0658242953941226, 0.18806097443614686, 0.10696581418492965, 0.08584130236080714, 0.17175626648323877, 0.12334201937275273, 0.09115862846374512, 0.10129113082907029, 0.1321882161178759, 0.1046155724408371, 0.15732166889522756, 0.1344393374664443, 0.21997957383947714, 0.14283425414136477, 0.13090334220656327, 0.15134686950062, 0.09691858331539802, 0.1712344866245985, 0.08484891775463309, 0.07671358143644673, 0.12258841123964105, 0.12045132448630673, 0.11253311258873769, 0.08614624956888811, 0.17876807094684669, 0.17308721292231763, 0.13900731663618768, 0.11458389647305012, 0.13934016520423548, 0.05406599937539015, 0.1164024653179305, 0.13835299174700463, 0.11511171529335634, 0.20963620314640657, 0.20050701658640588, 0.1839950568974018, 0.17632815401468957, 0.07426396145352296, 0.13156294609819139, 0.09450505461011614, 0.12254678990159716, 0.1043045184175883, 0.05673144438437053, 0.10557056298213345, 0.11952528703425612, 0.2156568579375744, 0.17132270974772318, 0.2114981710910797, 0.1353699482445206, 0.2229140070932252, 0.1250582787075213, 0.1535996057625328, 0.13488181015210493, 0.11772341015083448, 0.10955126330788646, 0.1449654104986361, 0.11321700124868325, 0.1341443375817367, 0.15268565980451448, 0.09342488114322935, 0.14231014012226037, 0.12901917259607995, 0.13000211199479444, 0.12242639064788818, 0.09021041648728506, 0.10507431639624493, 0.10339948840971504, 0.19797025913638727, 0.10639704577624798, 0.18030123439218315, 0.14291789036776337, 0.07169894980532782, 0.18515634244041784, 0.18708157699022973, 0.09223389612244708, 0.1315061120050294, 0.13074001882757458, 0.09463293131973062, 0.23282373962657793, 0.20478982105851173, 0.11569638177752495, 0.15532455034554005, 0.10934228130749293, 0.10416182928851672, 0.10273431374558381, 0.11937394658369677, 0.25251914135047365, 0.19173334166407585, 0.1662862157183034, 0.1805515866726637, 0.17165278989289487, 0.08438971918076277, 0.14034149290195533, 0.13756804886673177, 0.16404912647392067, 0.1794311489377703, 0.13807146756776742, 0.18598154958869728, 0.12490060073988778, 0.14660441183618136, 0.16389594040811062, 0.17049553484788962, 0.12150603931929384, 0.10916336519377572, 0.08463105373084545, 0.19627023035926477, 0.1980875235583101, 0.1104755840663399, 0.12942995769636972, 0.26124037908656256, 0.07531987729349307, 0.11943149992397853, 0.20447147956916265, 0.09817896211253745, 0.10964363906532526, 0.10451417895300047, 0.08861943507300955, 0.28235478752425736, 0.11745560594967433, 0.14071247513805116, 0.06722178576248032, 0.1319834478199482, 0.10810088113482509, 0.10361370191510234, 0.08423834480345249, 0.16561766873512948, 0.09484471566975117, 0.15527729716684135, 0.09555245483560221, 0.17879785863416536, 0.12175559092845235, 0.10782426276377269, 0.12415719777345657, 0.11120603379926511, 0.11061207817069121, 0.2620960660278797, 0.11608005261846951, 0.1335588704262461, 0.2775560793067728, 0.15268199571541377, 0.09128240682184696, 0.08662927829261337, 0.15740864351391792, 0.09850312543234654, 0.18132384094808782, 0.11537315483604159, 0.15793294752282755, 0.16061564428465708, 0.1347185546266181, 0.21607030289513723, 0.11211269907653332, 0.10315645073673554, 0.12760053229119095, 0.1347937091652836, 0.09123362693935633, 0.08642972792897906, 0.2552373526351792, 0.07755698689392634, 0.09775894893599407, 0.2688604901943888, 0.11139195239437477, 0.13933977165392467, 0.17227231950632163, 0.07118560413696937, 0.1030464805662632, 0.1333899830601045, 0.12784217218203203], [0.02968419376494629, 0.030760716713432754, 0.0601437155689512, 0.027273866048614894, 0.018586824781128337, 0.07211636419274978, 0.005963003063308341, 0.037419805103646855, 0.04523325797968677, 0.03364991203748754, 0.028078138695231507, 0.03749376542067953, 0.021725390206224153, 0.03201053411300693, 0.041718321054109504, 0.025940480276143978, 0.023882943272058452, 0.0156100509422166, 0.0740151833742857, 0.06323596928268671, 0.039539056564016004, 0.053344285780830045, 0.030765727694545473, 0.009323177177325954, 0.01623491384088993, 0.02885319192760757, 0.03981358504721096, 0.01002028794027865, 0.06770395953208208, 0.03563922064911042, 0.04530527090121593, 0.01280680819348033, 0.031025647318788936, 0.014239321994994367, 0.03046262949439032, 0.01958537727062191, 0.11981698923877307, 0.01110094231885991, 0.015409482776054313, 0.0635103824149285, 0.026711094193160534, 0.037330326690737686, 0.039575459967766485, 0.029364627519888536, 0.04597587384549635, 0.024762445096192614, 0.034474952944687436, 0.026252971097294773, 0.10468990595213004, 0.034177459443786314, 0.06983640510588884, 0.013369770886908685, 0.009634494981063264, 0.05895469829972301, 0.010836807295813091, 0.07996299064585141, 0.05741882071431194, 0.01566646943267967, 0.009025709121488035, 0.03501512449500816, 0.08697906309472662, 0.049610433102186234, 0.01089027670345136, 0.043714716964002164, 0.04896112937214119, 0.060039689365242205, 0.0182491280803723, 0.03418349501277719, 0.049796667216079574, 0.012341902291934406, 0.03200356216569032, 0.03163035433473332, 0.0623394481039473, 0.056861855422279665, 0.11923172564378806, 0.03186211475570287, 0.04827498458325863, 0.015577723837590643, 0.03966575940804822, 0.0371115364666496, 0.025959726921947937, 0.048217940144240856, 0.0339694748898702, 0.03300809933404837, 0.018975364110831703, 0.014338620505960924, 0.07116970606148243, 0.04262307964797531, 0.02198002064999725, 0.00664194901972743, 0.039241681806743145, 0.04336609924212098, 0.041010571710233173, 0.06728213466703892, 0.02321156340518168, 0.02914609174643244, 0.007663538197188505, 0.03297216072678566, 0.04137068720800536, 0.03346917744992035, 0.008434606732667556, 0.046295789536088705, 0.012276360049976833, 0.035008396820298264, 0.02001041839165347, 0.03638272539579442, 0.033718976724360666, 0.02738213648886553, 0.04444873918380056, 0.024079162028751204, 0.06128391224358763, 0.06725530539240156, 0.02156063511834613, 0.026696268203003064, 0.06565616798720189, 0.0037869052113299923, 0.0504677213861474, 0.028980393494878496, 0.018232739763334394, 0.01087127941926675, 0.016217080244262303, 0.03640090334894402, 0.022584401969132677, 0.012555800278538039, 0.004255775029637984, 0.02111142118727522, 0.032044630497694016, 0.04533805771331702, 0.07341906321900231, 0.023384371007393514, 0.06899708442922149, 0.011011466450457062, 0.05329765346167343, 0.02858446491882205, 0.024217377915712338, 0.04121270389961345, 0.03650046818490539, 0.04369079181924462, 0.051990584669900794, 0.024933778581076434, 0.028854650777897665, 0.02759501667294119, 0.011504616372154226, 0.04863963948030557, 0.03307633960087385, 0.03456215826528413, 0.016441651586709276, 0.043018892873078585, 0.009332748761932765, 0.012216182475510453, 0.02474293721440647, 0.025116526721311466, 0.045747675733374696, 0.014445425310571278, 0.04286340996623039, 0.05119532127199428, 0.01403239680387612, 0.026054983060540896, 0.04142841696739197, 0.042394640655922036, 0.032089956636939726, 0.07877957807587725, 0.03701280962143626, 0.012597861816175282, 0.04461030176441584, 0.0570037608434047, 0.026703538705727885, 0.027591847914404104, 0.050931639171072414, 0.036218496172555854, 0.056174774255071364, 0.029983824651156153, 0.01643545486565147, 0.04222252346309168, 0.03138460930702942, 0.02125695168173739, 0.019665843042145883, 0.00925272743084601, 0.047656594908663204, 0.01742102189122566, 0.01635320793970355, 0.05022934864142111, 0.03941352419289095, 0.02639340579376689, 0.006585905419862164, 0.02435607386619917, 0.008662127157939332, 0.06077169294336012, 0.06048047249870641, 0.047488599816071134, 0.036082287052912373, 0.04224530188366771, 0.018161725984620194, 0.052363293777619085, 0.020377278527511016, 0.08253905562950031, 0.024003378148855906, 0.05934713581310851, 0.03436508794714298, 0.057577102578112056, 0.005297423822672239, 0.012754136912657746, 0.0071692576665165165, 0.06433229866836752, 0.04298342924032893, 0.04554117038579924, 0.05036174439425979, 0.01992761337065271, 0.041157898626157215, 0.04619692698387163, 0.022157394792884588, 0.030935514119586775, 0.02843987419536071, 0.01201123182129647, 0.017326949796240245, 0.05626133157472525, 0.013316404955860759, 0.06456040857093674, 0.01241347671020776, 0.02626311858849866, 0.04318898803155337, 0.027804066526836584, 0.03117474860378674, 0.015646832629239986, 0.03827921720221639, 0.021432017109223774, 0.12176412689898695, 0.02201883794207658, 0.0405313699240131, 0.085918288944023, 0.03051752637007407, 0.01706917943166835, 0.01946558360941708, 0.02866266607972128, 0.04001356967325721, 0.027071891618626456, 0.013424358180990177, 0.01087955160931285, 0.04301678602184568, 0.018352121214515398, 0.08750207788710083, 0.021757954798106636, 0.039055613933929374, 0.024919595502849137, 0.05400757411760943, 0.042360103223472834, 0.05295019264199904, 0.051160715986043215, 0.01074816772182073, 0.0570638044072049, 0.02424444637394377, 0.05285255145281553, 0.010406986743743931, 0.012059261074422725, 0.006709149007552436, 0.11695005664868013, 0.05322433775290847, 0.06291001463042838, 0.03437846187236054, 0.02878221377198185, 0.019893617069880878, 0.022535466023587754, 0.07372574069138084, 0.033471060384597094, 0.047691827839506526, 0.005772135827490794, 0.03837628842198423, 0.04999829050419586, 0.027772112616470883, 0.012962030712515116, 0.01064694217140121, 0.09132579913628952, 0.031077541677015166, 0.02497710134567959, 0.029866434700254883, 0.03757841944960611, 0.042809235730341504, 0.04904433133612786, 0.012124067105885063, 0.05523088454668011, 0.05773897389216082, 0.024936309516695992, 0.027945407067558596, 0.031051180591540675, 0.0358953676186502, 0.014537063161177295, 0.030206214503518174, 0.021970997830586772, 0.01825554362897362, 0.024407679847042476, 0.03555816285578268, 0.06332349351474217, 0.032632760903132815, 0.013258851615579, 0.08707643965525286, 0.06025452712284667, 0.048665942890303474, 0.07069403265735932, 0.04739743524364062, 0.016212269430980086, 0.036602021128471406, 0.04614806228450366, 0.04638350036527429, 0.05399941812668528, 0.012355526426940091, 0.06928056957466261, 0.034534182266465256, 0.017881396027015786, 0.05338088935241103, 0.03892863967588969, 0.012453819009741502, 0.03431831992098263, 0.018145956830786805, 0.029507231832082783, 0.0036860757557276103, 0.05056399193459323, 0.03393161263582962, 0.04338741541973182, 0.00931491601347391, 0.038950980441378694, 0.053133369955633364, 0.014221245822097574, 0.029967899434268475, 0.09230332382555519, 0.005541618821942913, 0.0125185817845964, 0.049292447843721936, 0.04600686253979802, 0.09091177063861064, 0.04238097835332155, 0.013603238671618913, 0.030350932452295507, 0.02479534556290933, 0.02236108422013266, 0.014663224873532141, 0.04056368515427623, 0.016704259905964136, 0.06119224216256823, 0.02782196967330362, 0.0220864505640098, 0.017711311046566282, 0.05057725050885763, 0.03996062019307699, 0.03147622510524733, 0.03443069889077118, 0.06589216246668782, 0.050079093846891604, 0.02317233899209116, 0.03514594604660358, 0.10993982638631548, 0.028179871450577463, 0.024013941242758716, 0.10888458229601383, 0.08694497349538974, 0.1090946499524372, 0.10474622435867786, 0.10315172813300576, 0.19236680838678563, 0.2278598759855543, 0.10359873343259096, 0.1113907853141427, 0.1281397912119116, 0.11700644290872983, 0.19289488505039895, 0.18330649313117775, 0.09616743147905384, 0.15176659769245557, 0.123938098815935, 0.11340044319097485, 0.12266808482153074, 0.23650981326188358, 0.16069235945386545, 0.07741093223116227, 0.1512931023857423, 0.12088782606380326, 0.20896365280662263, 0.08505046301122222, 0.0855865938855069, 0.09440269081720284, 0.11423712436641965, 0.19880943053535052, 0.15626852826348372, 0.1384237086666482, 0.10538819991052151, 0.11128281682197537, 0.10839615921889033, 0.10743793206555502, 0.13734958773212774, 0.2523105868271419, 0.05985144339501858, 0.11735850758850574, 0.10451139695942402, 0.12999483809939452, 0.11972307999219213, 0.07220062467136554, 0.11792222091129848, 0.1398321438048567, 0.06943622550794057, 0.16798731658075536, 0.0925650279968977, 0.17285461111792497, 0.17121551478547709, 0.12116404409919466, 0.15837559662759304, 0.19291429115193232, 0.16055883733289583, 0.151804527799998, 0.0900657663920096, 0.13315511494874954, 0.13300034111099585, 0.10750178221080985, 0.1095520979059594, 0.19009135477244854, 0.06983162143400737, 0.1881549515362297, 0.1387063999261175, 0.1339920200407505, 0.1105990842250841, 0.13494887655334814, 0.09551789704710245, 0.1084677582340581, 0.21244882579360688, 0.13441024188484463, 0.10740781189607722, 0.12491057520466191, 0.1476433982274362, 0.13831241535288946, 0.13789523845272406, 0.09456826693245343, 0.11884297936090402, 0.10747706318008048, 0.25747725101453917, 0.1089785797521472, 0.13287002167531423, 0.08950777311942407, 0.18709332921675273, 0.12645336027656282, 0.12401144845145089, 0.16623911181730883, 0.13123043679765292, 0.08419364970177412, 0.10444686149380036, 0.0999342914936798, 0.135957627424172, 0.10601009761116334, 0.13954842117215904, 0.11430363436894757, 0.14224278873630933, 0.09097475904439177, 0.21665225523923123, 0.12496662219720227, 0.11637201266629355, 0.05116955390466111, 0.1351028632904802, 0.10355628428182431, 0.16500321456364223, 0.18239406709160122, 0.10798819682427815, 0.10616837268961327, 0.13602159970573016, 0.12172136562211172, 0.1258454607533557, 0.07782779021986894, 0.1550026669033936, 0.08170477646802153, 0.11936254719538347, 0.17173266703529017, 0.1098462360511933, 0.21840062285108225, 0.09938864077308349, 0.22239510422306402, 0.11434611066111497, 0.139395927212068, 0.14887880693588937, 0.12770474169935497, 0.10484502584274326, 0.10569666192999908, 0.16294255799480847, 0.21554565961871827, 0.17858087670590195, 0.21978562138974667, 0.13761783976640019, 0.11590356566011906, 0.11020331510475703, 0.12749976984092168, 0.10558351621563945, 0.08032861245529992, 0.10644817338990313, 0.0774701072701386, 0.14474798073726042, 0.11650041863322258, 0.13143966985600336, 0.1658884992024728, 0.16054230821984156, 0.05774014775774308, 0.12995682656764984, 0.09423961849617106, 0.06194449322564261, 0.1760680986834424, 0.19391783087381295, 0.09494326609585967, 0.0849945517256856, 0.10856966740850892, 0.127112747036985, 0.2034210937895945, 0.12904340986694607, 0.07653841762138264, 0.11446832838867392, 0.15131163996245178, 0.1445670018770865, 0.11589329263993672, 0.18505362580929482, 0.07785213605633803, 0.1554284340568951, 0.14221582375466824, 0.09765830862202815, 0.13380295304315432, 0.10137944216174738, 0.09976940069879804, 0.09006949154926197, 0.10241168391491685, 0.1636966818145343, 0.1689319594630173, 0.10569359495171479, 0.08585602657071181, 0.21805617133421556, 0.14800649588661535, 0.13046825198190554], [0.06324060367686407, 0.061267824178295474, 0.026500159708250846, 0.04987092608852046, 0.02630826152328934, 0.06027805193194321, 0.03443359623530081, 0.01872088124842516, 0.011759328240129565, 0.0473743039848549, 0.02039843694573002, 0.01465620203608913, 0.015396349730768373, 0.09188519019101347, 0.052313781077308316, 0.03579231511269297, 0.022635241205404912, 0.0220666967132794, 0.020605318880240833, 0.06635207350232772, 0.01176093636812376, 0.04998267402074166, 0.05306583536522729, 0.03428389444681151, 0.00551542906656063, 0.01783827512658068, 0.037351313778864484, 0.029592805275959626, 0.02471221484509962, 0.06295321695506573, 0.009494885552807577, 0.013608337014115282, 0.021852639270946383, 0.02800164065722908, 0.006752186787447759, 0.03848003303366048, 0.054915440401860645, 0.022305149185870374, 0.0493643555923232, 0.03719384954976184, 0.008734498854859598, 0.09019337168761662, 0.01400966163990753, 0.07223240725163903, 0.0601946192660502, 0.013167882121966352, 0.026120156349082078, 0.10798573374216046, 0.02512533071317843, 0.05802180085863386, 0.03216349286958575, 0.04980745253020099, 0.012889443580726427, 0.009721942029760351, 0.00924093958123454, 0.0649330939299294, 0.037434902507811785, 0.021770550104390298, 0.029388674800949435, 0.03424736890675766, 0.040506820527038405, 0.016103049041703343, 0.05748106273157256, 0.024563310335257223, 0.015750526350789835, 0.01586655923165381, 0.01335532233185534, 0.049780582543462515, 0.08001675097537891, 0.01859066528933389, 0.029819293479834284, 0.03862693925787296, 0.01033425033425114, 0.01687473843672446, 0.05915937838809831, 0.021064683695190718, 0.05485112206744296, 0.0282887169492564, 0.025134801365701214, 0.022049516206607223, 0.023794996651953886, 0.022154590746920024, 0.07083355302789382, 0.03400958309482251, 0.031986303627491, 0.05147585139742919, 0.01008561983638044, 0.057969078687684875, 0.006348769305207367, 0.03816146084240504, 0.03601132586066212, 0.02171819773502648, 0.03311207125495587, 0.020453303287337934, 0.04829429229721427, 0.03941911532144461, 0.020098115650138686, 0.056204599261816056, 0.03876910252230508, 0.025257212475740483, 0.01084443657392902, 0.04063120956665703, 0.03373715128483517, 0.022152982618925825, 0.05656831778053727, 0.032923065325511355, 0.05272534988554461, 0.00822651106864214, 0.06009657095585551, 0.02382832968474499, 0.015286506785612022, 0.0324581127746829, 0.038684360283826075, 0.07050001913947718, 0.030822365012552057, 0.017198520080585564, 0.0916501253045031, 0.036468919699213335, 0.06337223268513169, 0.0452126610491957, 0.03384575081456985, 0.04423075641638466, 0.029661618904875856, 0.020564481250143478, 0.006587706506252289, 0.06429934222251177, 0.05322544715766396, 0.029491768019007783, 0.07822773911591087, 0.05095136757673962, 0.016038869806964482, 0.04206399393400975, 0.03233576951814549, 0.026357283982049142, 0.054847549580569775, 0.04503256089187094, 0.04987583868205547, 0.03442342499537127, 0.03218402873192515, 0.047654688225260804, 0.0073697885132527775, 0.08435368897127253, 0.054861958271690776, 0.04583344255973186, 0.0011704052657088532, 0.019884933517979722, 0.014799055709902729, 0.04389486801145332, 0.024436061270534992, 0.07822221584085907, 0.017869525056864535, 0.043170233323637924, 0.023056974468220557, 0.03760090270744903, 0.0386044763560806, 0.04558444395661354, 0.021874150527375083, 0.02921998081728816, 0.03854810705940638, 0.07673925720155239, 0.040836256063942394, 0.03781065484508872, 0.015145871921309402, 0.04292096330651215, 0.023119377637548105, 0.07639481247003589, 0.013359369793241578, 0.04964570335245558, 0.06297593430749007, 0.06631222992603268, 0.04336598049849272, 0.043115407694131136, 0.012387224190336252, 0.03563228602121983, 0.014703872513824275, 0.035203852225095034, 0.0376603050556566, 0.02161833773633199, 0.014036951470188797, 0.04871900772143688, 0.018175754696130753, 0.044706188940576146, 0.0354580959039075, 0.06476224559758391, 0.02437756985558995, 0.01650609714644296, 0.027432136038052182, 0.01571701350621879, 0.02041421627758869, 0.10758607661617653, 0.025645622883790305, 0.018560886083702956, 0.04683689746473517, 0.03361947634922607, 0.01605148716563625, 0.04941306422863688, 0.022134699492848346, 0.019213652038680654, 0.08081256398665053, 0.03690918375338827, 0.012511486004638885, 0.00730845149207328, 0.012866903495575701, 0.014803657873666711, 0.03327147609421185, 0.01585729044329907, 0.011943301136073257, 0.014629920678479331, 0.012153541818926377, 0.04430041482139911, 0.04602902349350708, 0.016846029620085443, 0.01694786754835929, 0.00952578943023192, 0.027645330044573972, 0.06261116066681487, 0.05032552758763943, 0.044325374732060094, 0.007096886393680636, 0.024528698263955966, 0.04599898474823151, 0.031918114250791926, 0.023835025129041502, 0.014638421025925448, 0.039499922056815455, 0.08160231089485542, 0.029021980906171457, 0.07840191905519792, 0.04137119610926934, 0.029594498220831156, 0.0897595299673932, 0.03810243168845773, 0.02514543061676834, 0.05034967325627804, 0.08351554894553763, 0.03862077137455344, 0.05780646777046578, 0.015334940615243145, 0.02936164875115667, 0.03714842163026333, 0.03853356944663184, 0.05228033269356404, 0.04186992274065103, 0.016783226115096892, 0.03330560301297477, 0.07836544779794556, 0.01102628480709557, 0.016464460541361144, 0.011552039184607565, 0.027205831038632562, 0.008394367061555386, 0.026812080559985976, 0.02719831626330103, 0.02338321240884917, 0.02546878987258034, 0.026412769486861568, 0.051308561981256516, 0.01466325540760798, 0.03589937776061041, 0.04879104099901659, 0.02646233307729874, 0.03446631180122495, 0.014278376774330224, 0.03172856888600758, 0.03419896561120238, 0.046344447282275984, 0.007958510940495347, 0.03327186285917248, 0.021604892564937472, 0.011796353351590889, 0.06529927892344338, 0.008327061476718103, 0.025678260418187295, 0.07652755427573409, 0.00868981986838792, 0.008438887440466454, 0.051984674629888365, 0.055142532501901896, 0.03445975376026971, 0.016616379443023886, 0.03180714663384216, 0.04779455804132989, 0.050231475848704576, 0.012091764598153532, 0.020530664761151587, 0.06600088413272585, 0.02158356281662626, 0.0496552333767925, 0.033594143244304826, 0.04105406580492854, 0.007513272376464946, 0.06306403529431139, 0.050933830839182646, 0.016614884969645312, 0.007736455266630011, 0.0836520159084882, 0.018238446242841225, 0.036876936376627, 0.03606202260458043, 0.04627018501716001, 0.013194232181246792, 0.028530572274965898, 0.04967884639544146, 0.05246739801285522, 0.045519148531769, 0.020073761331981847, 0.018378650237407004, 0.09270363913050719, 0.012555878310065185, 0.11622852965125016, 0.046106790391994376, 0.09907452655690056, 0.05485873862302729, 0.02867883217654058, 0.05801899850900684, 0.0062060666054354185, 0.040322191148464165, 0.04816855636558362, 0.03394428427730288, 0.0443385213480464, 0.026454083787809526, 0.01598648351084973, 0.02991665307698505, 0.013825392733061952, 0.018263743724673986, 0.05693322034286601, 0.008684340698112334, 0.004788004327565432, 0.017104117199778557, 0.009728455965939378, 0.021451429996107305, 0.004878073914109596, 0.07407386986804859, 0.027547381818294525, 0.04583106429449149, 0.06054901810629027, 0.05750410578080586, 0.030731478639479195, 0.005687718013567584, 0.020264348248019814, 0.06790204426007611, 0.05553383007645607, 0.03983549155028803, 0.009805948905912893, 0.017836113992546285, 0.009662951043407832, 0.03563288313203624, 0.02776524584208216, 0.025674721858065044, 0.0933143070765904, 0.0077000552555546165, 0.04187674541026354, 0.17414371908775397, 0.08026278777314083, 0.08014569977032286, 0.13092755233602865, 0.13662233389914036, 0.13170276502413408, 0.10928675000156675, 0.14303286134132318, 0.05513241554477385, 0.1882028425378459, 0.1502323214496885, 0.19930864231927053, 0.10116990376263857, 0.1766544615051576, 0.12482612473624093, 0.13857016366507324, 0.17204876935907773, 0.14177419245243073, 0.118798006059868, 0.12437466824693338, 0.07703171936529023, 0.12974966982645647, 0.12522964951183113, 0.17699366116097995, 0.06476558398987566, 0.07642070536634751, 0.1415379944124392, 0.17843965999782085, 0.07832535316369363, 0.14835936123771326, 0.10394182109407016, 0.10058101000530378, 0.09813338491533484, 0.13554054551890918, 0.16526857603873524, 0.10112974806023495, 0.13136676805359976, 0.11961163740072932, 0.16235957427748612, 0.07511345337011985, 0.1614679249801806, 0.11383071581700019, 0.0902927770678486, 0.14200942697269575, 0.21633368304797582, 0.1303999506469284, 0.061210169057760916, 0.2433093584009579, 0.1755954311894519, 0.14362861508769648, 0.10502170957624912, 0.10836899067674365, 0.10607630227293287, 0.16010301107806818, 0.13915164103465422, 0.17044635462973798, 0.10467149729707412, 0.06408485051776681, 0.18065487327320234, 0.13456676634294645, 0.1190976199827024, 0.1526052262634039, 0.15313026309013367, 0.09511417549635683, 0.07921237485217196, 0.15163139280463966, 0.14993177114852838, 0.22343989887407847, 0.0928154888429812, 0.15867430131350244, 0.13392442438219274, 0.11089676432311535, 0.14420912893755095, 0.07898465849991355, 0.13863714864211424, 0.05588020184742553, 0.1115514352651579, 0.11293777730315924, 0.07365450129977294, 0.08177312530044999, 0.14475605530398233, 0.08952985264893089, 0.12947327537196024, 0.14925223189805234, 0.12032057078821318, 0.22238633755062306, 0.06525231072945253, 0.11753621590988976, 0.13758046605757304, 0.14089091627725533, 0.09679289827389376, 0.09581172306622777, 0.19722309708595276, 0.09414945476289306, 0.10562987372811351, 0.31957300326653887, 0.0995887950328844, 0.15865059329995088, 0.09037919528782368, 0.1514763475528785, 0.13983206238065446, 0.15280128217169217, 0.15062600746750832, 0.07923754171601363, 0.07604793858315263, 0.08106816134282521, 0.10727834062916891, 0.11964314856699534, 0.15755984825747354, 0.19364875102681772, 0.09874754731676408, 0.13015281462243625, 0.11801231679107461, 0.20485258554773672, 0.1328360949243818, 0.09509573291454997, 0.17836283626300947, 0.058287386250283034, 0.11286260240844317, 0.18753471624638351, 0.15309233298259123, 0.0871734158801181, 0.14225824576403412, 0.09354272231991802, 0.14552495761641435, 0.14534011110663414, 0.13011914571481092, 0.1091023241834981, 0.2279863277716296, 0.05856333287166698, 0.10900486619876963, 0.13663940584020956, 0.0801081767837916, 0.16987823082932405, 0.14156130887567997, 0.1673581517700638, 0.17336983632828507, 0.13647609603192123, 0.12185438562716756, 0.16805511579981872, 0.08836630079895258, 0.1339905679758106, 0.13954323716461658, 0.18872900573270662, 0.08607122395187616, 0.0978868527870093, 0.10310492957276957, 0.12572618786777767, 0.06336788327566215, 0.14831163308450154, 0.11980647194598402, 0.08238886868847267, 0.09402484180671827, 0.1366383744669812, 0.11722569114395551, 0.05714193092925208, 0.12320977289761816, 0.13736089212553843, 0.14833481184073857, 0.1661242629800524, 0.05871279378022466, 0.14641674262072357, 0.125300705698984, 0.13089373415069921, 0.19108121522835322, 0.20804140157997608, 0.10091923257069928, 0.17107701221747057, 0.11752928128199917, 0.12326320074498653, 0.10405787772365979, 0.10255815926939249, 0.17059863145862306, 0.1766161514180047, 0.0910145551232355, 0.11977884200002466], [0.018346745520830154, 0.02616854946661208, 0.018089814843343835, 0.02548672864213586, 0.019131254138691083, 0.04672841328595366, 0.07722341907875878, 0.05540669636268701, 0.04028404051704066, 0.022639616059937646, 0.02224645421041974, 0.025561050279065967, 0.0127831273213295, 0.02680371591954359, 0.02370746902722333, 0.052165816338466744, 0.027350650767662694, 0.04333169073132532, 0.025184426024290066, 0.024122637463733554, 0.05379887031657355, 0.01871249794826976, 0.08013457858136722, 0.1331380158662796, 0.03892530806894813, 0.04847564774432352, 0.017838137723239403, 0.04841063391151173, 0.028024044187207307, 0.019264046834515672, 0.018176080392939702, 0.004312146446734134, 0.026918749657592604, 0.059762107474463325, 0.02904318173282913, 0.07087016677750008, 0.052451652607747486, 0.018554063414090445, 0.04375884888161506, 0.04098130310220378, 0.05576913245022297, 0.05017145603363003, 0.06432619863854987, 0.059127962216734886, 0.022237470406772833, 0.041403402773929496, 0.020161210925185254, 0.039029069643999846, 0.04227544580187116, 0.054240735713392496, 0.0028452114118928356, 0.05148384453994887, 0.04928437666967511, 0.09474974112319094, 0.055916822382381985, 0.023722406975658875, 0.02399113228810685, 0.02330952350582395, 0.01592757479686822, 0.038472423263426335, 0.010485768900252879, 0.07185743522963353, 0.04962440413822021, 0.08699874061026744, 0.05902505559580667, 0.03441915361742888, 0.07465027858104024, 0.020360917351873856, 0.04121966227622969, 0.05026191492964115, 0.01841582717107875, 0.03520816770781364, 0.08405663991080863, 0.02559031549442027, 0.02447034085967711, 0.0396004063077271, 0.019873050673465644, 0.022140584087797573, 0.08164709420608622, 0.039807077896382125, 0.06360079042081322, 0.006186314026958176, 0.021961554319464734, 0.039638390698071034, 0.06364835572562047, 0.052455991839191744, 0.023651137049975138, 0.04888015978836587, 0.0672490560848798, 0.063511637704713, 0.07116292749664613, 0.016221056459471583, 0.011334809591062367, 0.030667197624487535, 0.06723668639148984, 0.013195983649763678, 0.04936074578602399, 0.05160512588918209, 0.03290313335933855, 0.08660324290394783, 0.060807397456041405, 0.03379704217825617, 0.03508314423795257, 0.05326886661350727, 0.02087678208148905, 0.03673453562493835, 0.020969736290031245, 0.04166415699624589, 0.014962294272014072, 0.02115128851229591, 0.019843890631039227, 0.035981636560921154, 0.040736063583088775, 0.011722038500010967, 0.051576026914907355, 0.039551650173962116, 0.0465847131397043, 0.05894819114889417, 0.019188245991244912, 0.05838576025728669, 0.020822787657380104, 0.054804425287459574, 0.03499870055488177, 0.04263789885278259, 0.02746525702864996, 0.031310465785541704, 0.02606635700379099, 0.028830247265951972, 0.02344851801171899, 0.02280033386445471, 0.02626734416532729, 0.019364849996886084, 0.026244380843958685, 0.03207992110401392, 0.03208686590992978, 0.04149260298748102, 0.03324622102081776, 0.02408048008302493, 0.0825977489086134, 0.07697793867971216, 0.0928730693246637, 0.03629646663154874, 0.075907285059137, 0.014851501377831613, 0.040947752938206704, 0.0874623835885099, 0.04808491335383483, 0.047602641196655374, 0.03254962679264801, 0.03873853791239006, 0.018067725135811737, 0.08110008641545262, 0.03851639233263476, 0.022671961824276617, 0.017796954040282538, 0.05338223285174795, 0.03100038206736956, 0.005334007886371442, 0.005523072339461318, 0.022427241384450878, 0.03712058473112328, 0.0055560979110720965, 0.049200143332460096, 0.03375739198444145, 0.021847233043185303, 0.051905184252453704, 0.017382954380341938, 0.07642977737954684, 0.034424985625914166, 0.04648461904642837, 0.024414075039593235, 0.01579805263983352, 0.05087984659309898, 0.0008306388211037431, 0.032751891296356916, 0.07840530494494097, 0.03958845391337361, 0.07098992820829153, 0.06317467721445219, 0.06247575900384358, 0.026442592797268714, 0.026304622879251838, 0.05050528847745486, 0.0444751240180007, 0.03128106486318367, 0.013219345610455742, 0.011943570005574396, 0.012257409415074756, 0.01254846022597381, 0.03368328917505486, 0.01573803791377161, 0.02490567705327911, 0.01791504118591547, 0.017149295757657716, 0.012212881402644728, 0.010653510390381728, 0.03078632801771164, 0.0345783888229302, 0.01380467027359243, 0.060376785562506745, 0.04514037332098399, 0.016728702433673397, 0.02572850593631821, 0.06501599055315767, 0.01221132162027061, 0.035749404558113644, 0.0114431690890342, 0.024047628810097064, 0.09117401085261788, 0.04134045168757439, 0.09803316529308047, 0.05310848807649953, 0.03176565082477672, 0.047080237085797956, 0.029462733505559818, 0.06452023929783277, 0.0361441219491618, 0.12570579110511712, 0.07902596771184887, 0.06551577909184353, 0.013690568673025285, 0.046842855002198897, 0.040595118289015124, 0.053018287023795505, 0.015821765742397735, 0.048412045264350514, 0.030928857691053833, 0.041119174632642946, 0.027352216487218226, 0.050962906064731736, 0.031395761030060906, 0.014834000263363123, 0.04607942507469228, 0.037345664974834235, 0.017750465909817388, 0.02708633423649839, 0.02287523395248822, 0.03184075786599091, 0.05485231628907578, 0.05053621271092977, 0.008787777424523873, 0.015717990596645644, 0.049672132291431935, 0.014563907702852572, 0.05565427004226616, 0.034773932437279394, 0.029421895875462463, 0.04793209708960993, 0.0901622608570116, 0.002623020455108157, 0.05457419157028198, 0.02053681398475809, 0.030061832429575067, 0.023149053366588693, 0.023474363410579305, 0.05110508629253932, 0.02240167248861066, 0.06792420521378517, 0.018434115386168872, 0.02007656028893377, 0.0732967776379415, 0.028115078141646724, 0.040907200292817185, 0.08059551420488528, 0.04831477726942726, 0.03460607983704124, 0.0728059932589531, 0.026031403968642865, 0.0423644865596933, 0.022742658387869596, 0.026586925677422966, 0.02633135885532413, 0.03361866549987878, 0.028500021235751252, 0.009282304772308894, 0.07923170631485325, 0.04235673429710524, 0.02009690785780549, 0.04592555029583829, 0.042573163219328435, 0.006839963349713278, 0.018571662916136638, 0.04800416090126548, 0.05346849500866873, 0.025834136875346303, 0.0656749905486192, 0.0250651005522481, 0.0515980419835874, 0.07580420880445413, 0.011686677495682878, 0.01484438863449863, 0.029429529394422258, 0.08217819035053253, 0.02764640891525362, 0.011700404259110135, 0.05332517484202981, 0.04651705302031977, 0.042474965631429634, 0.05670355998777917, 0.08219104180378572, 0.09003947994538716, 0.031242049099611383, 0.026242050076169626, 0.04130392275484545, 0.06951123755425215, 0.026941568790269748, 0.06785992080611841, 0.022484234933342253, 0.027767551164808016, 0.031574989269886694, 0.04027359447042857, 0.021356735345242277, 0.0840502277548824, 0.025862002612224648, 0.07762210589966603, 0.025391414828066314, 0.020464178507349322, 0.039548864787710566, 0.029114421124437025, 0.02435808232985437, 0.024109288983579193, 0.026882882296506847, 0.03705543179863265, 0.0440747069327959, 0.03322363259004695, 0.050846710335463285, 0.039920148971889696, 0.057885381393134594, 0.03949315367000444, 0.021370782716465846, 0.06539694046867744, 0.031161812333656207, 0.014408004104292818, 0.03735449950077704, 0.02959488837846688, 0.03425415086426905, 0.018456488382071257, 0.05364381488678711, 0.011566885530815592, 0.06370928138494492, 0.032215278662208996, 0.04859432012641004, 0.03553654473008854, 0.0461774123167353, 0.04087622177654079, 0.019519974976511936, 0.05766831125531878, 0.014955566597304173, 0.014154838447991227, 0.03090819629973599, 0.02882918875132288, 0.008370709938130208, 0.09424504677632026, 0.12614162771829537, 0.103294478330229, 0.21834743927632058, 0.089600481359022, 0.11473610544843332, 0.1922673758651529, 0.11255116162023374, 0.1274835392832756, 0.08636329256530319, 0.06383654741304261, 0.06670246220060758, 0.07206007971295289, 0.12343318733785834, 0.13469688221812248, 0.11197937373071909, 0.1391693236572402, 0.10557277500629425, 0.10176153880144868, 0.23958938515612058, 0.12388076260685921, 0.13517955131828785, 0.08209523944450275, 0.18173871082918985, 0.10148634535393544, 0.1230291740170547, 0.07342486469341175, 0.2340261579624244, 0.06058659537562302, 0.0935114554262587, 0.12376990355551243, 0.09884227759071759, 0.13371743048940385, 0.16916362488908426, 0.2365303321608475, 0.15428754527653965, 0.13849783183208533, 0.14206532468753202, 0.11783918179571629, 0.11373986676335335, 0.1373952395681824, 0.20408775444541657, 0.20729252962129457, 0.1133117586640375, 0.15356288344732352, 0.15822144704205648, 0.05667096995083349, 0.09658366521554333, 0.10952558075743062, 0.16744663273649557, 0.08928999730518886, 0.20261823758482933, 0.1765900549611875, 0.18617187866142818, 0.16320645383426122, 0.0867357472223895, 0.1474414254937853, 0.08361238267804895, 0.06039196439087391, 0.0884905473462173, 0.08655349950173072, 0.20796676272792475, 0.12275021470018796, 0.12790837005845138, 0.17932003204311642, 0.10308424782540117, 0.1334189429347004, 0.10170604820762362, 0.17043521308473178, 0.12114268381680761, 0.15586986179862702, 0.10403085845921721, 0.17037941036479815, 0.08605153286563498, 0.11785116472414561, 0.162624094369156, 0.12981987105948584, 0.11997113882430963, 0.2031278716666358, 0.11915182135999203, 0.10954639821180276, 0.1467933566974742, 0.10546152918998684, 0.11792344227433205, 0.1600436121225357, 0.10050832533410617, 0.13056965225509234, 0.13909503764339856, 0.20999627453940256, 0.11599744776529924, 0.24851752179009573, 0.08433316328695842, 0.11498862904097353, 0.0661554340539234, 0.09584923248205866, 0.07979858839618308, 0.10402580337332827, 0.12721177243760654, 0.043315612844058445, 0.20029702356883458, 0.1546219816165311, 0.14669505054397242, 0.11606147432965891, 0.11438953690230846, 0.14027179378483975, 0.10820714650409562, 0.20518685903932365, 0.1138531006872654, 0.12054346954183918, 0.18367956525513104, 0.1518777281578098, 0.18191929613905294, 0.20346850981669767, 0.09957936339612518, 0.14880507732076304, 0.0781708914520485, 0.2292902006634644, 0.09933373371937446, 0.13417074616466249, 0.08614526569311108, 0.12555108512086527, 0.1622939192290817, 0.13331490994564124, 0.2692409854914461, 0.10218853410333395, 0.1275255541716303, 0.09447336023939507, 0.0885391915217042, 0.17557206244340964, 0.12563858899687017, 0.1206445712596178, 0.11288685325000967, 0.09039044539843287, 0.09850699308195285, 0.10167602303304843, 0.1014766219471182, 0.12445326974349362, 0.09312340803444386, 0.20384117481963976, 0.14060397738856928, 0.1769507098942995, 0.1260031522916896, 0.13753743336669036, 0.10965984248157058, 0.08427063628498997, 0.13007007406226226, 0.12264969652252537, 0.13847564373697552, 0.11252370809337922, 0.11365329248032399, 0.08062187529035977, 0.18011041677423886, 0.0931756484455296, 0.14158577684845242, 0.16111003846994468, 0.08052114676684141, 0.0877424692735076, 0.13293377682566643, 0.07018686165767056, 0.12091749161481857, 0.125370092689991, 0.07778033348066465, 0.12314054875501565, 0.13597779348492622, 0.10327775922736951, 0.14166720105069025, 0.09831057755010468, 0.12479776197246142, 0.1626511136335986, 0.12337851098605565, 0.11817203036376409, 0.1118188187746065, 0.07956133184156247, 0.09138307427721364, 0.10404621370668922, 0.12101308362824575], [0.04934941764388766, 0.06040960630135877, 0.042882042537842474, 0.03192624310031533, 0.02082782408355602, 0.025774317228102257, 0.01751815926815782, 0.07142277926738773, 0.013168766761996915, 0.04721643263474107, 0.014751593881685818, 0.057778322137892246, 0.05962340134595122, 0.03267326605107103, 0.04749181607205953, 0.016424143686890602, 0.045817734474050145, 0.02297658672822373, 0.08116825204342604, 0.0271816395688802, 0.08953327246542488, 0.02111489019755806, 0.07341463917068072, 0.05261643144435116, 0.06753277193222727, 0.020474889182618687, 0.011597751240645136, 0.01378854997788689, 0.021300501755571792, 0.04457389157531517, 0.028833409239138876, 0.041834174123193534, 0.034800761711916754, 0.03893436651144709, 0.02433770931591945, 0.03760699934459158, 0.023725645284035375, 0.03346544550731778, 0.010855640883424451, 0.02934176767511027, 0.08690094335802964, 0.05705376887427909, 0.02094602827647967, 0.044855978938617876, 0.03881934804043599, 0.02137564102719937, 0.019604983539985757, 0.021631810049127256, 0.05572382327435272, 0.038781475608370135, 0.04588069573843053, 0.0446182541948344, 0.01102706597053579, 0.06632493210158177, 0.013896038406528533, 0.04479176238445299, 0.06291950054998909, 0.055901273752429655, 0.04026480404926198, 0.02962748859343784, 0.004678285215049982, 0.04974743950047663, 0.05418079732252019, 0.028848560926105295, 0.07356699742376804, 0.03791472176089883, 0.025294769389022673, 0.03393341075362904, 0.06497388745525054, 0.024444631167820523, 0.03543013686846409, 0.02557568627941821, 0.05717616980629308, 0.06079258503658431, 0.05466362927109003, 0.049568438569882085, 0.035371151819292984, 0.04170891655875104, 0.035226226917334964, 0.05843096426022904, 0.01826458001908447, 0.022398798892806684, 0.03572452946432999, 0.037635860831609795, 0.01318447315134108, 0.06470093317329884, 0.050886743901563544, 0.03339230961033276, 0.012575174149658, 0.04523758703310575, 0.029733977879264524, 0.03353440162858792, 0.05103090205895049, 0.06128332870347159, 0.018566166782485585, 0.06986499857157469, 0.03600961255974003, 0.03866650463481035, 0.023433354450389743, 0.04220357198002083, 0.05021352181211114, 0.0296307727029281, 0.02601061704834657, 0.03270756260358861, 0.01584874768741429, 0.05477538059598633, 0.009839206451683171, 0.031039102668208734, 0.059478126998458586, 0.04601155460945197, 0.013179870139408325, 0.032542997505515814, 0.016567757319925085, 0.018205483011635284, 0.030596412851342132, 0.04111171414011291, 0.07247283935014691, 0.03383977631373065, 0.02315120432259781, 0.026304078354899372, 0.07591101021638938, 0.01523856319753187, 0.023205069825053215, 0.009477290291605251, 0.03616223204880953, 0.0379148880019784, 0.06717971659132413, 0.02625838411040604, 0.032734843104013374, 0.012065827597065695, 0.042737585825047324, 0.059232008776494434, 0.058155241555401256, 0.04776002400155578, 0.03686081438458391, 0.01606276272130864, 0.0695853064368878, 0.04303788167557546, 0.01754458311812154, 0.030043661261775663, 0.02165059359478099, 0.020333808181541305, 0.028584878825183426, 0.029695297990526472, 0.021153449646330306, 0.08959411670054708, 0.006929254317323544, 0.08544190986348049, 0.008943499514966138, 0.05439842725172639, 0.05347096148346152, 0.038365099379526715, 0.011855412191445274, 0.041697934469474215, 0.021367747968594943, 0.014585288341290184, 0.0654353659067835, 0.009839715352947158, 0.011164402306479002, 0.06943184895707027, 0.006810046316656683, 0.012221080650176321, 0.0915174377816064, 0.022333042064149464, 0.08664387358086449, 0.046173816081136465, 0.01955244966250445, 0.01971018360927701, 0.029980727138796022, 0.06410490801291806, 0.01703726962607886, 0.017339709647265927, 0.06440241169184446, 0.017155887725363885, 0.013922276507530893, 0.029457654670945237, 0.04141106343429003, 0.0479304075374135, 0.013235038429099535, 0.0030162249251069234, 0.008647499639274818, 0.006238663851815675, 0.012451201560907066, 0.014339477156421967, 0.0415307637969298, 0.040226677166564126, 0.04350328205951622, 0.02698801620863378, 0.0495644657473479, 0.054053548257797956, 0.03530045186302491, 0.039145075383463075, 0.019669210272175924, 0.018503839948347638, 0.08487419318407774, 0.05750024491654975, 0.018411993448223387, 0.022974033740216067, 0.030508942902088165, 0.0634660062247089, 0.05404373324875321, 0.055430702931646786, 0.011915233535026866, 0.04638090496882796, 0.03919284424877592, 0.04500869681526508, 0.043781491595187357, 0.03981814819521137, 0.047983696285103045, 0.04453549327860985, 0.003844053975106882, 0.08928477937089545, 0.06626694449888808, 0.045305382859494, 0.038130265194922686, 0.06612685415893793, 0.030350033393395797, 0.010727128895398761, 0.05116196109780243, 0.025275449800704206, 0.030483385880610774, 0.04009791496875031, 0.048060940711625984, 0.02173920687554138, 0.050089516144778044, 0.029844589265329496, 0.04237567220947572, 0.024738162024212734, 0.03701298264786601, 0.0294477819864239, 0.041588154288807085, 0.02861916519967573, 0.06660539776618991, 0.06899561879358121, 0.0565785908007196, 0.03439924879265683, 0.02180517913906702, 0.020952886569180658, 0.04559052363038063, 0.03279072046279907, 0.03434851812198758, 0.0745725320386035, 0.037247653984065564, 0.03378485568932124, 0.07778988046837704, 0.028108080749266913, 0.0058815602013575176, 0.07387361382799489, 0.04667562326150281, 0.041666633649063964, 0.03775992417441947, 0.011292666629222887, 0.011024898899319981, 0.07675365571464811, 0.049046387297234366, 0.028558382032705203, 0.07119419439030544, 0.01578121479334576, 0.023738707083144357, 0.04431810083666018, 0.0487230110780469, 0.07830762982900653, 0.014738538867927023, 0.02236877880724413, 0.023598716827109456, 0.014022199270714606, 0.030503680863018547, 0.07367657404392958, 0.009055264410562813, 0.08411878014781646, 0.13013199716806412, 0.053476508507238965, 0.03156681292291198, 0.06715908234140702, 0.026745641803635017, 0.028984549521867718, 0.07499729496027742, 0.06719053243952137, 0.03068972159443157, 0.025782256087820445, 0.019474587769114544, 0.01771569947179939, 0.042849079306636534, 0.014703382272273302, 0.020752342151744024, 0.014874468091875315, 0.05131526590724077, 0.013494500890374184, 0.06212589956287827, 0.05155249532046063, 0.006024262901129467, 0.0049041470462855485, 0.08435982971319131, 0.008170743971796972, 0.022646370876048292, 0.09934058013771262, 0.05761751612382276, 0.03749715470309768, 0.011481560600389327, 0.028836734060730253, 0.0645865932373064, 0.02504458504595927, 0.027157344622537494, 0.02430326009302267, 0.032217395691467185, 0.015823134686797857, 0.014011324050703218, 0.09921885095536709, 0.05992488802543708, 0.05076253128104976, 0.05896369567407029, 0.023623237386345863, 0.08412942636225905, 0.012327479181944259, 0.018382455122524073, 0.03381084018786039, 0.012155438324303498, 0.008357313960524542, 0.028870966152421067, 0.02783911455688732, 0.010231945064983197, 0.03517846144469721, 0.03326822591147252, 0.05142734292894602, 0.06984780449420214, 0.030431108150099005, 0.04412918650944318, 0.04309932980686426, 0.005317801501535411, 0.026915536794279302, 0.032956530672631094, 0.022412685111963322, 0.035847133956849575, 0.032395840223346434, 0.03525177036811199, 0.011786037922969885, 0.05176269529121263, 0.058358985265450816, 0.029332312289625406, 0.02645920163818768, 0.04625209527356284, 0.009884956675315542, 0.03167817409017256, 0.012472561843294119, 0.009083706054038234, 0.06630572956055403, 0.016202339070982168, 0.0072674026679513705, 0.03725351991930178, 0.07031860601689134, 0.01043021384560104, 0.016792332055047154, 0.16486900033695356, 0.13903441732483252, 0.08818031435034104, 0.05191922992733972, 0.09217607136815786, 0.12723206063466413, 0.11798152487192835, 0.09657147872660841, 0.09637296652155262, 0.11048944653677088, 0.1254281752875873, 0.11189451614128691, 0.12364210827010018, 0.08981281532240765, 0.15517890958913735, 0.1534472203680447, 0.17699129985911505, 0.11297657593552556, 0.21881903468498162, 0.0909616429624813, 0.133156879139798, 0.13638397811778954, 0.21572940690176828, 0.20844567274408682, 0.10420463127749306, 0.15486098879149982, 0.10606677564127104, 0.11220103076526097, 0.09513739496469498, 0.13919419875102385, 0.07349756293530975, 0.1030051645689777, 0.16565880152795995, 0.12776173864092144, 0.07074834938560214, 0.17092587532741682, 0.13320079392620496, 0.16673913784325123, 0.061122882312961986, 0.2633087438132082, 0.22062281146645546, 0.14523720448570593, 0.12176534826202051, 0.08283972128161363, 0.08110605073826653, 0.10853958795113222, 0.15282739219920977, 0.07829583689038243, 0.146808230185083, 0.11945836991071701, 0.0829955129218953, 0.09071646790419306, 0.11032476608774491, 0.16526136999683722, 0.16656126667346272, 0.16108098360044615, 0.1749819948204926, 0.1952464295817273, 0.10627269744873047, 0.10749972624970333, 0.06602801196277142, 0.18643449885504587, 0.16582923595394405, 0.1145772739712681, 0.15622042013066156, 0.15714448983115809, 0.09080408713115112, 0.13068281832550252, 0.12498912241842065, 0.1428364525948252, 0.14588802813419274, 0.16947585956326552, 0.08324253359543425, 0.14942377912146704, 0.11661800875195436, 0.13311835192143917, 0.07246872064258371, 0.2091936083244426, 0.1534937135875225, 0.1623031065932342, 0.10695982272071497, 0.07523873807596308, 0.11466129017727715, 0.11101146388266768, 0.1638619593743767, 0.2168423400393554, 0.16805339232087135, 0.09290922845580749, 0.12054534229849066, 0.09629728951092277, 0.14901443251541682, 0.29925940185785294, 0.1331126115151814, 0.2776767228330885, 0.14791265449353627, 0.15205420154545987, 0.0718919930181333, 0.11682969810707228, 0.09957676460700375, 0.14973218685814313, 0.1334855207907302, 0.1149348754967962, 0.08728413243911096, 0.1099230530006545, 0.07265609808798347, 0.08477414319557802, 0.12449297761278492, 0.14587939716875553, 0.08534445866410222, 0.08509437101227896, 0.13476734129445894, 0.16866110185427324, 0.15885355669472898, 0.08647559689623968, 0.1684162321367434, 0.15398976339825562, 0.16796291646148476, 0.10544082708656788, 0.12975087761878967, 0.1907627516027008, 0.23383415969354765, 0.1199920784149851, 0.14065348330352986, 0.09593961334654263, 0.14337580651044846, 0.10645689256489277, 0.14298456321869576, 0.13283450715243816, 0.07408175444496529, 0.1164158188870975, 0.13895376665251596, 0.15594977965312345, 0.18650578574410506, 0.09134717977472714, 0.1338471799556698, 0.08991623084459986, 0.22567896944071564, 0.09625684203846113, 0.1601288089794772, 0.18548195782516683, 0.08681896275707654, 0.0733157494770629, 0.20407194457948208, 0.10812138646308865, 0.09314782172441483, 0.1376344503036567, 0.1016690544784069, 0.19860911342714513, 0.15263148556862557, 0.1079762681786503, 0.09540302785379545, 0.07878387998789549, 0.13998127223125525, 0.13666396880788462, 0.10122477010424648, 0.09816292833004679, 0.13050154090992042, 0.09464836799140487, 0.11522280504660946, 0.17978058090167387, 0.14976544864475727, 0.08313010034284421, 0.1491957777845008, 0.14422976997281822, 0.10034474411181041, 0.15254229892577442, 0.12339957271303449, 0.0698405441695026, 0.14357119745441846, 0.14188514649868011, 0.10765164345502853, 0.09028461429157428, 0.1870938449033669, 0.21868005714246205, 0.12729892347540173, 0.09115569040711437], [0.04672250324594123, 0.03913097542577556, 0.05804811444665704, 0.04747348544853074, 0.05774850730917283, 0.01480796657103513, 0.03576843407271164, 0.039718858165932555, 0.041096609950597794, 0.05342585586809686, 0.04449408228642174, 0.026764890145776526, 0.036292972176202705, 0.050229769333132675, 0.039585315688912354, 0.03193378162437251, 0.06829749446894441, 0.07587087487003633, 0.014105197674195682, 0.031646981835365295, 0.059017469574298174, 0.009224144991354218, 0.0327388430679483, 0.03506065419475947, 0.019693266034924557, 0.08057133121682064, 0.02472456927145166, 0.11322388837912253, 0.004659874439572117, 0.04547988171023982, 0.020647757852982198, 0.022557233426985995, 0.04158624082005449, 0.01531469652296177, 0.07667659449258021, 0.050506740542394776, 0.01234605407807976, 0.014685362078515547, 0.021631336770951748, 0.004730111719774348, 0.024609024935801114, 0.041695532455508194, 0.010239874594844878, 0.014742443836959345, 0.019104862519140755, 0.04616293916478753, 0.024453056876414588, 0.022586603815268193, 0.02203302102030388, 0.03400959666552288, 0.04318816700418081, 0.02766361995600164, 0.033566224920962534, 0.02588345280050167, 0.005217768052326781, 0.061126173207802434, 0.012649533106014132, 0.057406186392264705, 0.07271120870219809, 0.017767093410449367, 0.04141436450715576, 0.04478599822946957, 0.10762478025364024, 0.06725637747773103, 0.043630029008324654, 0.034461087081581354, 0.0631547486409545, 0.04065856131325875, 0.012248242406972816, 0.04659567826560565, 0.03732710364939911, 0.06682537203388554, 0.0589666540867516, 0.03787147193881018, 0.03769397057060685, 0.027481314559866275, 0.035826197758849175, 0.10079067054071597, 0.026572868128174117, 0.08259133675268718, 0.007762350707447955, 0.029943339859268496, 0.06688413316650049, 0.06049414497933217, 0.058020769485405514, 0.01906795021412628, 0.015803399495780468, 0.05314225197902747, 0.052209914329328706, 0.017941722879186273, 0.04137173554460917, 0.0400060447199004, 0.011371229110019547, 0.027333938450153385, 0.013912135801677192, 0.045825646192367585, 0.06185555764074836, 0.05135427488546286, 0.06108056886919907, 0.05624312308749982, 0.025699600344523787, 0.07434210154627051, 0.039303401352039406, 0.04139961315585034, 0.008271092515704888, 0.032808606645890644, 0.01815453520976007, 0.014228026083271419, 0.08162089596901621, 0.01797718820827348, 0.01861573037292276, 0.04757829536018627, 0.0166024660824665, 0.037794139302734814, 0.022499966767749617, 0.017269160665039505, 0.018126774645809616, 0.029491734092256854, 0.035649524203368595, 0.020318909248869334, 0.043656281528196166, 0.01010675196136747, 0.04868514543133123, 0.12855424040130206, 0.056165427435189486, 0.0051444001811822605, 0.03969744360074401, 0.02244231503989015, 0.03318611638886588, 0.016589073497535925, 0.054201692808419466, 0.037232678716204, 0.007761053857393563, 0.018871198807443892, 0.04007789818570018, 0.05732072490666594, 0.07498326285609178, 0.0644404978624412, 0.015598295323018516, 0.031028860182102238, 0.0628233046403953, 0.07646470836230687, 0.026486829887809496, 0.008828866960746902, 0.042268311006150076, 0.019103123773155466, 0.04039058069299374, 0.029398259108087847, 0.045072129661483426, 0.028732734998422008, 0.04587539977260998, 0.04257231844323022, 0.003994787136824536, 0.04300707279305373, 0.02943509677425027, 0.036563633009791374, 0.018689344637095928, 0.06408154605222599, 0.02563222690618464, 0.04056526614086969, 0.03806305630132556, 0.013745759863273373, 0.05361954368917005, 0.019515052204951644, 0.041499724212501726, 0.02784753856914384, 0.048562642719064436, 0.0506598485766777, 0.0071067340572231585, 0.03159831391115274, 0.015422977141237684, 0.03131311546478953, 0.009649627160147896, 0.013400601821818521, 0.05185108804809196, 0.09579136023031813, 0.02170625382236072, 0.016408941109797785, 0.09036191978624888, 0.047697771806269884, 0.008159923034587076, 0.03520358759643776, 0.015185703623241611, 0.03339134269793119, 0.059820061150406084, 0.03362536264051284, 0.03779674826988152, 0.08401519499186959, 0.03836889239028096, 0.04263289804969515, 0.03253918413871101, 0.032250749080308845, 0.03390104463323951, 0.07810480214123215, 0.012847454137434917, 0.02930762040029679, 0.04229138458945921, 0.0025758404309661792, 0.019038400014064143, 0.02807843725063971, 0.04239121066140277, 0.036157268565148115, 0.036906713885920386, 0.05035961040162614, 0.050344916725797315, 0.07325218431651592, 0.025542645016685128, 0.04404058679938316, 0.04477903985285333, 0.008792030142753251, 0.07103101350367069, 0.026600087560447197, 0.06161695080144065, 0.010112784137683255, 0.05924953533602612, 0.004671381121235234, 0.015381567845387118, 0.03538818983361125, 0.033887741954198906, 0.006468757621145674, 0.03661717620811292, 0.07124868075230292, 0.04901728832295962, 0.007456712241816733, 0.0725382094138435, 0.04498944677678602, 0.021902370798800672, 0.01677702769770154, 0.08181240569267954, 0.024059386125632694, 0.034997675967003615, 0.04083387101335185, 0.04814979487231799, 0.009505132279757942, 0.04069594180743609, 0.0394688214042357, 0.053481767153633494, 0.034592135942408016, 0.09886601953102009, 0.02477700645769281, 0.07789837821785893, 0.07570720543818814, 0.01088703585056854, 0.04758087040058204, 0.025930217433986918, 0.031287307385355234, 0.07356258694614683, 0.02941410968612347, 0.04060878737696579, 0.04250803403556347, 0.021122203108721545, 0.03318052526031222, 0.046844968638781986, 0.044922482155795605, 0.05839994842452662, 0.03918536340019532, 0.008726909440676016, 0.019622886686452796, 0.016761443444660733, 0.03680352567295943, 0.024569218678932105, 0.036027122155896256, 0.0749205458643181, 0.029411398938723972, 0.048934249207377434, 0.054580220353922675, 0.024124510220385025, 0.03532582228737218, 0.03938634886539408, 0.01155265495513699, 0.06195701898208686, 0.03742376774815576, 0.008687423791603317, 0.04913248321307557, 0.08932822596813951, 0.03710799112117716, 0.02430605056828686, 0.028134784494925822, 0.04309897018330438, 0.032967828280691586, 0.07812092413327523, 0.04405991147671427, 0.05980302992143801, 0.08969589016799416, 0.042189607729337046, 0.03380786141912852, 0.00811247477707054, 0.039371736613767486, 0.01849307838295187, 0.0018884621926450304, 0.01264610480783241, 0.018700650726844157, 0.041178797504731586, 0.01469484799807625, 0.04012274595775774, 0.0410822521496032, 0.017385548080450723, 0.0942064652751599, 0.08704034159226076, 0.05484318999307496, 0.03371026094204613, 0.031063757238111327, 0.03988668362476996, 0.03139614100967135, 0.02662623151471572, 0.07805520801671914, 0.02654388450485255, 0.10739656178546803, 0.07891215024782078, 0.0631732183641621, 0.005235529978693063, 0.01220042519603989, 0.04060545237734914, 0.06326211323695523, 0.020715842056753378, 0.03437075371454869, 0.015332945722288318, 0.004585264001174697, 0.035503679886460304, 0.03285437383289848, 0.07215094912265028, 0.05773454984383924, 0.02287970040924847, 0.030274675294224705, 0.041303535989884815, 0.011487680986257536, 0.027560565753706863, 0.026278236348714148, 0.02213430424619998, 0.029004705404596667, 0.01983857770184321, 0.026669401608939682, 0.0909595327185733, 0.00899369499113943, 0.011913482914678752, 0.04852108923452241, 0.045598292856344154, 0.04674058620418821, 0.022744792380503247, 0.0053847427978845576, 0.05603308935782739, 0.03217570649992142, 0.02409539258639727, 0.03966973901593259, 0.036710678333682675, 0.013885086851327546, 0.03739662974008492, 0.029131893401167223, 0.0301947031569268, 0.021700669479157244, 0.011479194209511791, 0.1027481219332133, 0.19300357278968605, 0.11000461290989604, 0.18151144231004374, 0.18311325992856706, 0.11379176112157957, 0.16560194029339723, 0.10652277831520353, 0.08189256103443247, 0.16563544635261807, 0.2105868849903345, 0.14708343041794641, 0.1561426328761237, 0.14083258940705232, 0.13880235834845475, 0.2185840851494244, 0.09551263161535774, 0.15622994676232338, 0.14514401448624475, 0.06855279326971088, 0.10574136381702763, 0.09483157244643994, 0.07398154160806111, 0.09623079307909523, 0.13413443097046443, 0.1948024369776249, 0.15382086246141366, 0.10612258514655487, 0.2841150430696351, 0.07880316395312548, 0.14533076089407715, 0.09765437990427017, 0.11039024471704449, 0.10730401639427457, 0.0850969155185989, 0.16259419811623438, 0.18023671928261006, 0.09673757052847318, 0.12907811014779977, 0.11764190452439444, 0.08996098022907972, 0.09724476866956268, 0.0785980224609375, 0.06667686107435397, 0.11863950027951173, 0.07172197928386075, 0.17638322391680308, 0.14079160589192594, 0.11880612133869103, 0.09707812046898262, 0.11974448098668031, 0.1388614180364779, 0.142796894003238, 0.11960695550910064, 0.08344866574874946, 0.0469143963418901, 0.11990484595298767, 0.08208431503070251, 0.15006545611790248, 0.20998848495738848, 0.14075241370924882, 0.11450703202613763, 0.1343417912721634, 0.19501513056457043, 0.16473427042365074, 0.14429520789001668, 0.16162207456571714, 0.1889697363866227, 0.12235952780715056, 0.0975164540910295, 0.11897086964121886, 0.2907507084310055, 0.1979388158236231, 0.14126626827887126, 0.1135732660602246, 0.10344186292162963, 0.09793090328041996, 0.1274494496839387, 0.1636330352297851, 0.16474224999547005, 0.22078567344163144, 0.08248999076230185, 0.09338378227714982, 0.1591363022369998, 0.13320034609309264, 0.13151509580867632, 0.17741963187498705, 0.15840917054031575, 0.18601048232189246, 0.10632680383111749, 0.11844534426927567, 0.2605938437793936, 0.16378985824329512, 0.11875652042882782, 0.05795090751988547, 0.1257309511836086, 0.11399134541196482, 0.10723914844649178, 0.09199884480663709, 0.2454975795532976, 0.11629403542195048, 0.08491208257951907, 0.1531620185290064, 0.15380917808839253, 0.17563326630209172, 0.15715248297367776, 0.1864957841379302, 0.11261999899787561, 0.20834679662116937, 0.10252533853054047, 0.1196875518986157, 0.06731952873191663, 0.12794548592397145, 0.08943191290433918, 0.21354448342961924, 0.07776031669761453, 0.07695721622024264, 0.13849150788571152, 0.13475843891501427, 0.10478196279811007, 0.1008226295400943, 0.14613532700708934, 0.12981696692960604, 0.15519291455192225, 0.21554518464420522, 0.12462020292878151, 0.12585833934800966, 0.10731647429721695, 0.11587449721992016, 0.07563690242490598, 0.1560510035072054, 0.13631213483001503, 0.17297495608883245, 0.18418436816760472, 0.11573667318693229, 0.1227677616157702, 0.0956564878246614, 0.21632925899965422, 0.16117752556289944, 0.15925771929323673, 0.142796676872032, 0.12975334748625755, 0.14891460644347326, 0.1344584178711687, 0.1111954961504255, 0.11982557949210916, 0.14486041398985045, 0.14290655883295195, 0.08798889283623014, 0.2145301912512098, 0.0660942844780428, 0.09019035899213382, 0.12029348367026874, 0.07656065321394376, 0.088179439040167, 0.12185378851635115, 0.2000256231320756, 0.1530635223856994, 0.18181972791041645, 0.12434091791510582, 0.1992743627301284, 0.13274320348032884, 0.13711300971252577, 0.13046884909272194, 0.11612558231822082, 0.17128100698547705, 0.10330673945801598, 0.11260071503264563, 0.15016898699104786, 0.08702986501157284, 0.1019847361104829, 0.22945541036980494, 0.076589043119124, 0.0942312657300915, 0.09764746563243014, 0.20183140837720462, 0.1762091118310179], [0.028930205652224164, 0.013873860489444008, 0.00571956463058346, 0.07298137420522315, 0.02225476796073573, 0.03893974390146988, 0.0456380787571626, 0.02334953162686101, 0.018744438287935088, 0.03356633348656552, 0.02017251362225839, 0.06881244826529707, 0.02994459854172809, 0.053591374307870865, 0.05303785936640842, 0.013995224959217012, 0.05426972612206425, 0.046628539716558795, 0.03270011907443404, 0.026936774940363, 0.06907799294484512, 0.05458388105034828, 0.03342245352853622, 0.028524139762989113, 0.033683414704033306, 0.012065875094517, 0.008792002153183733, 0.0664545933582953, 0.01842469223109739, 0.07844322826713324, 0.035059039281415086, 0.02620878828955548, 0.03120212409911411, 0.0454927433415183, 0.037643524884645424, 0.005642750225628593, 0.02681682012709124, 0.028357060692672218, 0.04551507053630693, 0.05343536553638322, 0.04630655449415956, 0.03994808425860746, 0.021022897812404802, 0.06924208306840487, 0.028064191407923187, 0.03842541775000947, 0.06268767227551766, 0.052153826624687226, 0.046159953610705476, 0.01817845187282988, 0.04572363863033908, 0.08120939162160669, 0.03683284177844014, 0.0070889076700301045, 0.027876761376059482, 0.03082248375618032, 0.08537613267877273, 0.029098119320613996, 0.08964152594230004, 0.06032957988125937, 0.050190353233899386, 0.021509499023003236, 0.05429140192323497, 0.015375042034845268, 0.035754198408020396, 0.10080488584935665, 0.04684759456930416, 0.009853073162958026, 0.023217186764148728, 0.07582917889314038, 0.05084993676947696, 0.034441165293433836, 0.06438827780740601, 0.021110822380121266, 0.07151369617453643, 0.02857037853183491, 0.010595797594370586, 0.011531097049425756, 0.01307019597983786, 0.022068170830607414, 0.031223406349974017, 0.010842943796887994, 0.036374111393732686, 0.1232954990118742, 0.04058764083310962, 0.027079740572454672, 0.058783890679478645, 0.02532329160853156, 0.05885055674506085, 0.0182499066993062, 0.05814675986766815, 0.017052299176741923, 0.040857005664812665, 0.036143799645027945, 0.011306965058403355, 0.048328222440821786, 0.04488017889005797, 0.01795448612288705, 0.10745047139269964, 0.05025359269763742, 0.007236158674848931, 0.035976011505616565, 0.055686361355973144, 0.04021319467574358, 0.04040403604241354, 0.021384640097884194, 0.07999562139489821, 0.07172048650681973, 0.023902286609102572, 0.01907700187127505, 0.026527621716793095, 0.04194611543789506, 0.048128231029425345, 0.03142521284254534, 0.044794781865285974, 0.024835860888872827, 0.05345506001529949, 0.014548740748848234, 0.05402521602809429, 0.07613929653806345, 0.05816164014062711, 0.057418535729604106, 0.05453189169721944, 0.023456948809325695, 0.04331796396789806, 0.08501310287309544, 0.03644579861845289, 0.04885836185089179, 0.07501360694212572, 0.04121465129511697, 0.027814426060233797, 0.03758197836577892, 0.01892463174382491, 0.11029914460544075, 0.03214164404198527, 0.012517604694169546, 0.050886740508888445, 0.009943069806987686, 0.010811902516122376, 0.08038838460509266, 0.025330568896606565, 0.09000625208552394, 0.08229848782398871, 0.02905973798728415, 0.027977376244962215, 0.034244936358715804, 0.035724844983113666, 0.10798936390451022, 0.04045767762831279, 0.05510336746062551, 0.11243382255945887, 0.015745703663144792, 0.003891669321871762, 0.009984518118601824, 0.013186014274002185, 0.03152415681896465, 0.09601375686803035, 0.02100496243552438, 0.05341738775106413, 0.012656017356286091, 0.04038747300260833, 0.039831325345273526, 0.018807881312178712, 0.022544777220381156, 0.07471343662057604, 0.01991658378392458, 0.037760473787784576, 0.02879912286464657, 0.041136406029441526, 0.08582245944333927, 0.009941629616410604, 0.09617902085717235, 0.09594255818852357, 0.014573425852826663, 0.060821463486977985, 0.04102330102718302, 0.03302094400195139, 0.021720779560772435, 0.02269170549698174, 0.055119245180061886, 0.014680742951376098, 0.029052983171173503, 0.04042052783604179, 0.06485143902578525, 0.01812029124370643, 0.031410519166716507, 0.025481888991115347, 0.037292817274906805, 0.049548513389059474, 0.07991528284869023, 0.015079704578965902, 0.0105962547573394, 0.009000718676751214, 0.058269242223884375, 0.02722626003170652, 0.007972189358302524, 0.044829658565244505, 0.057317135456417284, 0.0342473994408335, 0.04739081613453371, 0.06202232797763177, 0.01803162368014455, 0.05538851501686232, 0.08381168876907655, 0.04897522593715361, 0.01877115560429437, 0.09125881415924855, 0.011667464776629848, 0.04299540877608316, 0.020037103477599363, 0.037029175886086056, 0.05836454246725355, 0.010256951624926711, 0.052075479578758986, 0.030841784684785774, 0.021879290430141345, 0.01166972769091704, 0.023551188841728226, 0.07561548107436725, 0.05107837915420532, 0.043031649331429174, 0.023392854391464164, 0.004211302572262606, 0.024265860939132314, 0.07306686961757285, 0.0041196562399688575, 0.04750144448397415, 0.028340643537896018, 0.027935778655643975, 0.012040335884583848, 0.0856215859364186, 0.022846058643023883, 0.012399095160487508, 0.06918124561863286, 0.06192142982035875, 0.04354251156161938, 0.04548846857090082, 0.019679756402703266, 0.010449849800871951, 0.032252153647797446, 0.011599643505178392, 0.047876151877322366, 0.04527432631169047, 0.02197617674911661, 0.04706004049096789, 0.04084256983229092, 0.034150952473282814, 0.06558197018291269, 0.03301090168367539, 0.10756093689373561, 0.039308090029018264, 0.03664671962282487, 0.02918049007920282, 0.07613553745406014, 0.05474814759301288, 0.04867816669866443, 0.020228999966223325, 0.02920718364683645, 0.018501012153657417, 0.024174257015277232, 0.01286997047385999, 0.02895039546170405, 0.04925449738012893, 0.04065212540860687, 0.02786519574666662, 0.006126490138870264, 0.04865264021126287, 0.03422135387414268, 0.014546326860519392, 0.013265918557798224, 0.02827241175275828, 0.04394123570195266, 0.051507572909551005, 0.04852025802912457, 0.0887750910062875, 0.08301468153617211, 0.05455270915159157, 0.041693910756813626, 0.06920449222837176, 0.08312528274421181, 0.023658066588853086, 0.01701928335907204, 0.08438149533633675, 0.05506832112691232, 0.04737758470167007, 0.012464567004436893, 0.019143908816788877, 0.0633561581905399, 0.060362061352602074, 0.06888250022062234, 0.03130694758147001, 0.044343800350491486, 0.029986599859382426, 0.06866181349115712, 0.03807082213461399, 0.025957063671999743, 0.06990859444652285, 0.0647333332204393, 0.019871727530179278, 0.042993016940142424, 0.04953477984028203, 0.04902482006166663, 0.017421666499493376, 0.047558197152933905, 0.08062651646988732, 0.056036607561899085, 0.010804396222478576, 0.004103252231808645, 0.02174667245708406, 0.039990248424666267, 0.03503577570830073, 0.018941763056708232, 0.025183693206469928, 0.015710107716066495, 0.076142736710608, 0.05508525396830269, 0.014907848622117723, 0.03927356616726943, 0.022109658157985126, 0.03667216468602419, 0.009780456345262272, 0.03057523238073502, 0.0575491672913943, 0.07613774947822094, 0.012806244161246079, 0.038021479068057876, 0.056049024752740345, 0.0430285212849932, 0.050959289473082335, 0.05179902066343597, 0.0642341553632702, 0.032277578354946206, 0.01218276547401079, 0.022289190042231764, 0.027970226182203208, 0.0031710424435524537, 0.025352818059868047, 0.01250456494744867, 0.04968189301767519, 0.0388659837522677, 0.06950827235622065, 0.10680757981858083, 0.02430130760850651, 0.026817744631054144, 0.010089736847606088, 0.06298789687986885, 0.027945722586342266, 0.0464972567611507, 0.006732708167484296, 0.017923373595944474, 0.03564302044521485, 0.01900801182325397, 0.11664008828146116, 0.05787766644997256, 0.1334616770701749, 0.19952387362718582, 0.1756226947265012, 0.11964238860777446, 0.10617245747042553, 0.1306548626827342, 0.08960703600730215, 0.11211259729628052, 0.10699848564607756, 0.12688342934208258, 0.11226839572191238, 0.11914057124938283, 0.11948821188083716, 0.09505086139376674, 0.1383544709533453, 0.1271353286824056, 0.0876187112714563, 0.06507595947810582, 0.23566959691899164, 0.25459882404123035, 0.09780975763819047, 0.10729512758553028, 0.13398788097713674, 0.08911595985825572, 0.20237684196659497, 0.2754168483827795, 0.11588762008718081, 0.16885368366326603, 0.17941585475844996, 0.07726586822952543, 0.15882418969912188, 0.13219489290245942, 0.13822483005268232, 0.17523887460785254, 0.10707305664462702, 0.08129021871302809, 0.13288402663809912, 0.12066351595733847, 0.09687512993280377, 0.1372017078101635, 0.15915458197040216, 0.12902358307370118, 0.0838239159701126, 0.12298782409301826, 0.14861867018043995, 0.12300345753984791, 0.16086301101105555, 0.20242302305996418, 0.1322531790605613, 0.09113041497766972, 0.1370077689311334, 0.16520442733807222, 0.14784196471529348, 0.10874224600515195, 0.17929097717361792, 0.10833011062017509, 0.13574965644095624, 0.19434761495462485, 0.11198668833822012, 0.08327201594199453, 0.0778435186616012, 0.13555004500917026, 0.07718424725213222, 0.17533579654991627, 0.09905730533812727, 0.12378840042012078, 0.11442467144557408, 0.16433003997164114, 0.15472301548080786, 0.14614049744393143, 0.16865499503910542, 0.2927204141659396, 0.15756714929427418, 0.0895453639594572, 0.15299522105072225, 0.12065086806459085, 0.11274523620626756, 0.08709516722176756, 0.1343201052929674, 0.09298907845680203, 0.055931957105972936, 0.19067045726946422, 0.08861155728144304, 0.11292124819010496, 0.17096052132546902, 0.1080248241445848, 0.11829751863011292, 0.15089017472096852, 0.10026499589106866, 0.07217414823493787, 0.1747734538678612, 0.11564199041043009, 0.08830072717475039, 0.10412611799048525, 0.11707806906529836, 0.1476532776973077, 0.22414792302463735, 0.23370838644249098, 0.1706607174128294, 0.13798750564455986, 0.19711742204214844, 0.15979866098080361, 0.16291863285005093, 0.08737089671194553, 0.15144841905151094, 0.22620995023420878, 0.10820186750165053, 0.10601134611559765, 0.11372420617512294, 0.14543388464621135, 0.1886868415666478, 0.16783683108431952, 0.12667422342513288, 0.13288121750312193, 0.09904741908290557, 0.16814997499542578, 0.14182696890618118, 0.1037879293518407, 0.1492781112236636, 0.13020488539976732, 0.0615295215642878, 0.12140353981937681, 0.19162150552230223, 0.13948541241032736, 0.11650614546877996, 0.16782731802335807, 0.12244864659649984, 0.12584122669483933, 0.09915620860244546, 0.11241300510508673, 0.12192799310599055, 0.1121011096984148, 0.1324363835155964, 0.07533081527799368, 0.15235494183642523, 0.10734415174062763, 0.20448442601731845, 0.15516206834997448, 0.08709823420005185, 0.13708358843411717, 0.15402763922299656, 0.13451028508799417, 0.10600071347185544, 0.09582591123346772, 0.1347781028598547, 0.1668046707553523, 0.13032086060515471, 0.12461313259388719, 0.25859452677624567, 0.18035876059106418, 0.13823415312383855, 0.07856763087745224, 0.254110224545002, 0.11500985361635685, 0.15540285328669207, 0.09586464201233216, 0.1422924574996744, 0.07893359873976026, 0.09648128106657948, 0.07625978400132485, 0.10979521700314113, 0.05937720848513501, 0.1693521219172648, 0.2355563087122781, 0.15043159361396516, 0.10832329812858786, 0.12993575126997062, 0.2035854078297104, 0.13531014216797693, 0.17096908443740436, 0.20840379356273583, 0.10741614430610623, 0.0926557413435408, 0.12474288206015315], [0.03203708179561155, 0.014157693384082189, 0.04835819333259549, 0.020608977880328894, 0.08967910321163279, 0.07318139275802032, 0.1256702630115407, 0.04206827548997743, 0.03150576512728419, 0.03695309175444501, 0.035768111768577776, 0.008150233554520776, 0.01806894819518285, 0.009171635710767337, 0.03750281368515321, 0.033610550221055746, 0.039097428654453585, 0.0474441863064255, 0.01343612906722618, 0.02066712493875197, 0.010333590458945503, 0.012291094437906784, 0.034141452983021736, 0.05395426840654441, 0.026210523642865673, 0.05729866573320968, 0.029159896541386843, 0.030271696525492837, 0.022824187763035297, 0.017820210828046714, 0.07354666172925915, 0.026933168526738882, 0.007722169559981141, 0.029094428090112548, 0.043242856926683865, 0.03330356401524373, 0.07541401045663015, 0.019255527827356542, 0.013295740171867822, 0.02514323894865811, 0.025932181792865907, 0.022501686854021888, 0.0037664465323489693, 0.05841356662235089, 0.046227993709700446, 0.01876010905419077, 0.027101245043533187, 0.010253383378897394, 0.020901516379256333, 0.01796554454735347, 0.015139654844201036, 0.030961624147104364, 0.03780973882281354, 0.06234932078846863, 0.020649610253583108, 0.05412508620481406, 0.033074181859514544, 0.06152642744460276, 0.027418862196749876, 0.036319553785558255, 0.03560528372015272, 0.011991101383630718, 0.04265242628753185, 0.04148275405168533, 0.02970681612246803, 0.015011744207835622, 0.037322303014142175, 0.01063931713412915, 0.044798279713307104, 0.032411704372082434, 0.047051613086036274, 0.01884096159067537, 0.013749647020761455, 0.04747398077909436, 0.03537948422932199, 0.001395367507939227, 0.02040965821860092, 0.03425695999924626, 0.05541948674778853, 0.049375558205481083, 0.038662813404308896, 0.06648846582642623, 0.025259019075227634, 0.0121569192269817, 0.05286452081054449, 0.009473453176074793, 0.05041193902226431, 0.03588911831112845, 0.06676938610949687, 0.03233604432482805, 0.018017693356211697, 0.012365086137184074, 0.00915999204984733, 0.007024164827141378, 0.029715301202876226, 0.03712458469505821, 0.0474224019396518, 0.014138467094328786, 0.036058080316122086, 0.013206819854011493, 0.057724405745310445, 0.03914042741858533, 0.03342030596520219, 0.02339559736927705, 0.018643239878916314, 0.04695729671844414, 0.04593401841287102, 0.0582519124395081, 0.010887749160506895, 0.04700699262320995, 0.03418574096368892, 0.011541772949775415, 0.023970526875928044, 0.031414817686059644, 0.027860213603292192, 0.0396697356232575, 0.019899080973118544, 0.006348217147335942, 0.08439827550734792, 0.03167043879095997, 0.004554076411295682, 0.007413006104928042, 0.06133709581834929, 0.053930529858917, 0.060249797733766694, 0.013145224989524909, 0.008730464964173734, 0.0618828483191984, 0.028968726085232835, 0.05457305163145065, 0.05058204775143947, 0.04378256707319191, 0.02027476206421852, 0.03599545831925102, 0.018406682215364914, 0.0439514578320086, 0.0642503791355661, 0.04030533294592585, 0.04746386042929121, 0.016333009648535932, 0.05166738486981817, 0.06720641015895776, 0.049227939519499025, 0.007123844165887151, 0.040718269002224715, 0.028625292370894125, 0.02041334266375218, 0.07517741208097764, 0.013899416662752628, 0.024595559408356036, 0.013775763833629233, 0.015621133115408676, 0.014830895965652806, 0.06854546509150948, 0.044671912744109116, 0.04799407108553818, 0.042320877114044766, 0.023189997865951488, 0.11116656341723033, 0.08272912685892411, 0.015748412714206746, 0.04145203337871602, 0.023487080853166323, 0.08856540332947459, 0.05249303985120995, 0.031235209466623406, 0.033765425839062245, 0.02585430463243808, 0.015596358105540276, 0.030618434705372368, 0.07633238046297006, 0.03312658511900476, 0.03799486692462649, 0.06472819671034813, 0.04171243815549782, 0.035785550118557045, 0.05795954527067287, 0.10951971142951931, 0.032760193172310076, 0.01826811009751899, 0.08534046887819256, 0.07627246582082339, 0.006162726877456797, 0.0380623845516571, 0.05172317062637635, 0.031826070975512266, 0.010129788225250584, 0.013625721081293054, 0.05366487322109086, 0.022662670983533775, 0.04115950336147632, 0.030987523828766177, 0.07626594509929419, 0.03461015443982823, 0.057602506929210255, 0.03191921008484704, 0.011557148553297987, 0.030116315398897444, 0.08281571471265384, 0.0892774240512933, 0.04384225779878242, 0.015875558302338635, 0.03287115739658475, 0.03444577254621046, 0.030147168386195387, 0.03660640446469188, 0.06350369884499482, 0.04315376867141042, 0.023616959241085818, 0.028145216970837543, 0.032029757010085244, 0.08555327103074108, 0.053905413885201724, 0.019709776488265822, 0.020703993138990233, 0.00617201644594648, 0.022833751714123145, 0.04186327988281846, 0.06833558742489133, 0.010005649395420082, 0.024936830292322805, 0.030799623911402056, 0.034822763209896426, 0.023905267074171985, 0.040554392617195845, 0.016272823592381816, 0.024636130713458573, 0.016199579129793813, 0.07264250703155994, 0.07463279951895986, 0.032948785195393224, 0.05143656421984945, 0.015158051624894142, 0.02880566394222634, 0.0382532055622765, 0.029815802417163337, 0.056897040855671675, 0.035119466217500825, 0.012918586659777378, 0.04396148657958422, 0.03354928868689707, 0.06161080327417169, 0.0664100136075701, 0.018187966630128876, 0.019963360291772654, 0.021524886500888636, 0.007707461465283164, 0.02643677605582135, 0.031796863435634544, 0.07708593431328024, 0.0334242177195847, 0.04172814284850444, 0.01948624330439738, 0.053596426001084704, 0.1121751582249999, 0.014404285732390625, 0.025451519460018193, 0.06231352128088474, 0.03126960440671869, 0.047874068774815114, 0.00958280757601772, 0.04484436581177371, 0.054427417660398145, 0.01906926148304982, 0.01721097798352795, 0.0005771832501133238, 0.024649413036448613, 0.023253054125234485, 0.03506981781018632, 0.04232501278498343, 0.02126302626649184, 0.02618618119907166, 0.03869429403649909, 0.05019092659599014, 0.0698213144870741, 0.01772163834955011, 0.04825633504827108, 0.017476504003362994, 0.03530681312882474, 0.0363392109450485, 0.02787756035104394, 0.027983153970646005, 0.0029982295402857873, 0.030713127659899846, 0.024520184345809475, 0.005155319081885474, 0.03541256620415619, 0.03899156701351915, 0.06445497779973916, 0.07919355907610484, 0.03565948509744235, 0.008688025991432369, 0.025717462778889706, 0.02376241170402084, 0.01896500288109694, 0.0370502885031913, 0.013603058011670197, 0.017434051459921256, 0.03674016407291804, 0.04042110798348274, 0.04892695156325187, 0.02646944921330682, 0.07794386720550911, 0.08280719231281962, 0.018147215513246398, 0.0382197164664311, 0.04594447463750839, 0.01008372163466577, 0.01387059419149799, 0.0125104113748031, 0.04280619589345796, 0.09723153723669903, 0.01719814688632531, 0.017810736782848835, 0.011619467753916979, 0.05823658433343683, 0.008425001221309816, 0.03900038796876158, 0.030507528156574284, 0.044386344496160746, 0.02584348199889064, 0.045715194262031994, 0.018153166265359948, 0.0343022691751165, 0.0533879325459046, 0.005497000479538525, 0.03292671584391168, 0.030125808103808334, 0.032337811908551624, 0.07107149490288325, 0.02679132078109043, 0.008727549808099866, 0.012218671850860119, 0.016359952577788914, 0.0988803773320147, 0.0400256272405386, 0.057361552358738015, 0.025731299804257493, 0.06491279216217143, 0.027017043936731558, 0.023388201337573782, 0.023768957870613252, 0.009907891158945858, 0.03570663310321314, 0.04637111710118396, 0.03170146480468767, 0.05214751964168889, 0.021035834082535336, 0.07662883241261755, 0.08389500608401639, 0.07412155052380902, 0.024884798530755297, 0.10922557328428541, 0.15619147382676601, 0.11363491775201899, 0.0730362676882318, 0.1845186823712928, 0.20635784763310636, 0.2563023269176483, 0.06511561984994582, 0.199289738333651, 0.10528720675834588, 0.06322494308863368, 0.06618245331836597, 0.1022140605907355, 0.10584454185196332, 0.1346872334501573, 0.0874268419242331, 0.1846188884228468, 0.12595885752567224, 0.13747462816536427, 0.15514000239116804, 0.1027978246233293, 0.09148127865046263, 0.11383523486022439, 0.12031321546861104, 0.18127506785094738, 0.12268321615244661, 0.08982072025537491, 0.10361510648259095, 0.13543922666992458, 0.104389613494277, 0.1658075906868492, 0.11242223318134036, 0.06575770396739244, 0.09492633664714438, 0.10134322874780212, 0.24184171429702214, 0.1536930807467018, 0.07221493497490883, 0.06021085660904646, 0.06316042797906057, 0.19033030766461576, 0.13842870268438542, 0.10264894725488764, 0.1613534561225346, 0.13400356870676788, 0.10982674852545772, 0.0839260219197188, 0.09628840748752866, 0.1507246528885194, 0.09442511639956917, 0.08821987294192825, 0.1210892695401396, 0.16535521138991627, 0.10536899736949376, 0.09124419851494686, 0.14746114372142724, 0.054291412101260254, 0.21639000145452364, 0.13148202401186737, 0.15411913288491114, 0.17294663403715405, 0.1379535381815263, 0.1289076485804149, 0.10193330315606934, 0.1215804610401392, 0.16842996568552085, 0.1977535079100302, 0.09878832727138485, 0.06389365970556225, 0.16024420064474854, 0.1165131615208728, 0.07096265110054187, 0.13033737614750862, 0.14935861261827604, 0.14402800079967293, 0.1409538843269859, 0.07362733954297644, 0.1576659439929894, 0.216589517891407, 0.07140672512884651, 0.08850187888102871, 0.2103586122393608, 0.11111088961895023, 0.05989348542477403, 0.10740367961781365, 0.24552662085209573, 0.11835433915257454, 0.06174857980970826, 0.10484408946441752, 0.1206896531262568, 0.18314801449222223, 0.17559042360101426, 0.05711261821644647, 0.10585727116891316, 0.19834880025259086, 0.19441344642213412, 0.22846111229487828, 0.10003170876630715, 0.1326254912252937, 0.09778361368392195, 0.19852068674351486, 0.10689947381615639, 0.1409648358821869, 0.08918424083718232, 0.13459246924945287, 0.15864847627069267, 0.09949866522635732, 0.10970974873219218, 0.08857037020581109, 0.14861425970281872, 0.07942286998565708, 0.07409778822745595, 0.1340936781572444, 0.17103619155074867, 0.11563616857997008, 0.10627172035830361, 0.11423280888370105, 0.16181272933525698, 0.19647195882030896, 0.11820177733898163, 0.1429156104901007, 0.1092215088595237, 0.19196617417037487, 0.1560984059636082, 0.15475439094007015, 0.10264303721487522, 0.1492907591164112, 0.16798817153487886, 0.09935688533421073, 0.14055695491177694, 0.09317696480346577, 0.06556900337870632, 0.11252133322081395, 0.06879577665988888, 0.19602222580994877, 0.1805633253284863, 0.1316953689924308, 0.14757696964911052, 0.1140458724860634, 0.13208478023963316, 0.1306291733469282, 0.1104486733675003, 0.1385622519467558, 0.13421033189765044, 0.083613257988223, 0.15246158039995603, 0.07649560206170593, 0.1175915707967111, 0.14188346373183386, 0.08439585313733135, 0.13584709406963416, 0.11427467449435166, 0.17296532089156763, 0.17881071008741856, 0.2194373972181763, 0.14706463499792985, 0.13728305058819906, 0.08300745513822351, 0.1867422280567033, 0.15743735911590712, 0.13044526321547373, 0.18865199200809002, 0.14412547914045198, 0.1228529584727117, 0.14910657757094928, 0.14797628750758512, 0.06570208445191383, 0.09121477723653827, 0.11697394108133656, 0.08090407800461565, 0.20405724751097815, 0.10844010793204818, 0.17181970950748238, 0.2551235487418515, 0.2227672128272908, 0.14595582735325607], [0.02955352488373007, 0.06476151277976376, 0.016494044668174217, 0.009705514696958874, 0.04914155861894999, 0.04838261041524155, 0.04226876223193748, 0.010590546581495022, 0.034912071989050934, 0.010948712987426137, 0.021512177539989352, 0.06171854106443269, 0.02540911441402776, 0.047586105298250914, 0.027030645171180367, 0.028465039362864833, 0.029779799349073852, 0.019497244053387215, 0.007536388368212751, 0.023534130471359407, 0.023236350289412906, 0.018704972994912947, 0.05732359510979482, 0.025921742531604, 0.008845054261785532, 0.017219761619344354, 0.06383943118687187, 0.011933982305760895, 0.03021075390279293, 0.0300051374360919, 0.038757024598973136, 0.0417282107020063, 0.027869319543242455, 0.041456376002835374, 0.04325764220474022, 0.047650722188076804, 0.035264109527426105, 0.03261884754257543, 0.011742557398974895, 0.028884611491646086, 0.028291685539962988, 0.04206797354189413, 0.019315345778263042, 0.044917864724993706, 0.020996224600821733, 0.028152154991403222, 0.024633703254429356, 0.02129054595051067, 0.026921558792569807, 0.05390667596033641, 0.0441920324228704, 0.004097299783357552, 0.014336647665394204, 0.0655688608863524, 0.03339483715327723, 0.0743916074612311, 0.07042664236256055, 0.019995840066777806, 0.015078467948894416, 0.0317302177261029, 0.04702807470623936, 0.03429483921666231, 0.03496424454663481, 0.02494641629579876, 0.051627693963902335, 0.0206724056375346, 0.04438187634306295, 0.049342937634459565, 0.03829023661091924, 0.05553579104265996, 0.003065414261072874, 0.052319348457136323, 0.046644946693309715, 0.03170032486585634, 0.03582848781453712, 0.06502516434660979, 0.03643074192638908, 0.008652476693636604, 0.050972931419632266, 0.017360087750213485, 0.022501062601804733, 0.024634793999471834, 0.0217419328899788, 0.011270487015800816, 0.012544726587033697, 0.033285504805722406, 0.014639669530359762, 0.08308237218963248, 0.026069719144808393, 0.06675401050597429, 0.01977291756442615, 0.0947467487837587, 0.014412277178572757, 0.0438007484190166, 0.0352729983361704, 0.02790282729880086, 0.07829224065478359, 0.04352357364924891, 0.020612509655100957, 0.05444437764318926, 0.03848919325641223, 0.018539147518043007, 0.03292793720694525, 0.030617155666862215, 0.0136592975385221, 0.008733015407675078, 0.018458179630605236, 0.029421658388205936, 0.11404056634221758, 0.02388974728195795, 0.003509384176660595, 0.06703421154192515, 0.07801281993410417, 0.02516983073603894, 0.016945494372131567, 0.041165606783969064, 0.02871603285893798, 0.031549795264644284, 0.06389186837311302, 0.040094013392393074, 0.028192627908928052, 0.053594308971826515, 0.03723515197634697, 0.0385858505698187, 0.03810160048305988, 0.01969219564593264, 0.062863317850445, 0.042180545894162993, 0.025548114008935432, 0.03610517064641629, 0.07123456722391502, 0.038599618045347076, 0.08420950706515994, 0.053288761260254044, 0.015279811341315508, 0.009368139452167919, 0.01423922021474157, 0.05746325118733304, 0.042952331980424266, 0.03215827154261725, 0.012033733738852399, 0.01806681589888675, 0.028403165450851833, 0.09599803521164826, 0.01718566523465727, 0.020987106786508645, 0.03313772327133587, 0.017958363950518624, 0.06193200818129948, 0.11658788179712636, 0.008190200115287942, 0.01113312693113195, 0.0106441364290991, 0.016648633605135337, 0.021010366966947913, 0.04400148282625845, 0.034163115213492086, 0.041525895308170996, 0.01224385482990848, 0.04650285806772964, 0.05085534130090049, 0.0876677150705031, 0.030091674399695227, 0.027764811579670225, 0.014794506132602692, 0.03914991673082113, 0.0036157434806227684, 0.0035094897736728725, 0.02352761653518038, 0.027436839982068965, 0.020348642653386508, 0.016801746728430902, 0.07037662076098578, 0.043452605671648464, 0.04424215241202286, 0.025286830529304485, 0.0428031119517982, 0.022433578901525055, 0.02699424516010497, 0.056085859026227675, 0.020673386120636548, 0.09819032757409982, 0.018101682420819998, 0.033805459405162504, 0.01657244938957904, 0.026081591811297194, 0.017510870105719993, 0.04847297092367496, 0.027968760546562926, 0.033074015618434975, 0.036661138491971154, 0.007608737164576138, 0.039927355013787746, 0.048117343935051134, 0.05826306076986449, 0.011653957688914878, 0.025399262085556984, 0.0458195156284741, 0.02793922391720116, 0.016117159177416136, 0.012413450416975787, 0.018460501916706562, 0.07467174742903028, 0.031941734054791074, 0.027852834534964392, 0.030253264121711254, 0.05203425179102591, 0.03638504259288311, 0.027860775091020123, 0.004761387095121401, 0.08921861542122704, 0.017060249910822937, 0.0835542729390519, 0.04752930513183985, 0.029213215823152235, 0.010946143036043006, 0.05743921747697251, 0.07408199193222181, 0.02113384168062891, 0.04999004630371928, 0.039714698746268234, 0.03225571595664535, 0.025856492907873223, 0.05003033771312662, 0.02517442781079028, 0.00939041914950524, 0.03141675151086279, 0.021616734697350433, 0.0314062579667994, 0.02866404689848423, 0.0212245906503605, 0.10757751350424119, 0.032915950885840824, 0.02258766402623483, 0.03673000301101378, 0.06580710131675005, 0.08087463637015649, 0.0775777907775981, 0.06484323553740978, 0.0357585104980639, 0.036824794353118966, 0.025531661231070757, 0.052915991084384065, 0.05783023006681885, 0.03516832073884351, 0.013725603132375648, 0.036740157287567854, 0.04882094742996352, 0.025740919734484384, 0.038261707606060166, 0.030705463606864214, 0.044061238012675724, 0.02840886853768357, 0.023723443437899863, 0.06142207554408482, 0.029006259249789373, 0.043978385494223664, 0.021730580999116813, 0.02038953795896045, 0.04135914532733815, 0.014750265649386814, 0.021356623386964202, 0.009336327185987361, 0.033235310177717886, 0.04808330861851573, 0.03223522419908217, 0.02255591028369963, 0.02394412168567734, 0.0331415230674403, 0.07692603753613574, 0.024352442007511854, 0.028125731141439507, 0.021153375007478253, 0.01945535130133586, 0.04516233749953764, 0.048169726838490794, 0.029849888623825142, 0.01722729335805135, 0.07669445353427104, 0.01689368313444512, 0.024838278169876764, 0.016194427352664725, 0.03421635307105524, 0.039197624527982304, 0.1376297412706273, 0.05628820156146373, 0.02367428187946124, 0.00942605156784079, 0.05782096127846411, 0.0361359897069633, 0.020850197079458406, 0.04401724858741675, 0.048248409759253263, 0.02780491978462253, 0.0349808686545917, 0.021905714280105064, 0.025213969439002018, 0.03937174000644258, 0.023730634212759987, 0.04847482671695096, 0.05890513810196093, 0.009955770286199237, 0.04040719123025026, 0.021733008458146026, 0.060156648446406634, 0.017460478702560067, 0.032830852416477034, 0.03869412440274443, 0.04801250688199486, 0.02523802520175065, 0.015360456924619419, 0.0587441013859851, 0.037832099944353104, 0.0673564885343824, 0.055222711592380486, 0.05996566119470766, 0.03443220863118768, 0.04497984550627215, 0.013537955121137202, 0.060167125027094565, 0.05385767894663981, 0.03961939850289907, 0.01566632354765066, 0.013817815193241196, 0.04342684169699039, 0.07299165401075568, 0.031916706290628226, 0.0192470885480621, 0.09903769567608833, 0.026455554512462447, 0.012738511099347045, 0.011369357201536852, 0.014694836123713424, 0.048963321040251424, 0.02612320806032845, 0.016086655635652796, 0.029973751798804318, 0.014103527629881032, 0.010622888953158898, 0.03643012106684702, 0.041191330046526024, 0.0445353202521801, 0.010658387360828263, 0.0728386240079999, 0.021083587680810263, 0.03609444640044655, 0.03724806449775185, 0.05105063046461769, 0.11045513980622802, 0.020062153294150318, 0.03841350606775709, 0.031692586173968654, 0.205604687333107, 0.12723073070602758, 0.12837126664817333, 0.15925458446145058, 0.12036263995936938, 0.2192636379706008, 0.10784010655645813, 0.1109700800318803, 0.2229625087763582, 0.08507826937628643, 0.11753297251250062, 0.1454789936542511, 0.1225132295595748, 0.08970186806150846, 0.15908108305718216, 0.09533836346651826, 0.17722578799085958, 0.1567569649113076, 0.12649989420814173, 0.05931463398571525, 0.1665947184498821, 0.1903714540281466, 0.1230181274669511, 0.09387149289250374, 0.07176747505686112, 0.11046114484114306, 0.1033899685634034, 0.11494328933102743, 0.07877542544156313, 0.1389031479401248, 0.12743099353143147, 0.13552630985421793, 0.10714658269924776, 0.1644845695367881, 0.144161210794534, 0.1406876000442675, 0.17626646161079407, 0.1006859250898872, 0.09427482767828874, 0.09423359989055566, 0.12846270602728638, 0.15035193360277585, 0.07977927050420217, 0.12425384830151286, 0.15249529001968248, 0.1934874089700835, 0.08980893410210099, 0.1755716824637992, 0.1610015407204628, 0.1270588713565043, 0.17598106978195055, 0.11608487021710191, 0.09327782903398786, 0.10997037403285503, 0.13372952198343618, 0.2146070964102234, 0.17499247140118054, 0.13795420314584458, 0.17546570886458668, 0.14131011521177633, 0.1339673213660717, 0.2547048654939447, 0.22549854697925703, 0.07654919954282896, 0.11500985361635685, 0.070916992479137, 0.2704866943614823, 0.13315166799085482, 0.1581492509160723, 0.12935324252716132, 0.13019112470958913, 0.21049548632332257, 0.1320069929850953, 0.1289151803191219, 0.08555789185421807, 0.15196310143385613, 0.17702913497175488, 0.06526120632354702, 0.1325016857257911, 0.11276956847203629, 0.17800043070954935, 0.13784961375807012, 0.07354092132300138, 0.1314602701791695, 0.08740707619913987, 0.08516131527721882, 0.07680652716330119, 0.19290777721575328, 0.14778365141579083, 0.09912589165781226, 0.05150721328599112, 0.16224119705813272, 0.08015949438725199, 0.19805903865822724, 0.10573126043059997, 0.061278131125228744, 0.13286045433155128, 0.11091914919338056, 0.1141833301101412, 0.11871219852140971, 0.07441476586141757, 0.1517950418804373, 0.1839097107627562, 0.18874355352350644, 0.08816422628504889, 0.05360228515097073, 0.13461606869740145, 0.09974409134260245, 0.293844963823046, 0.10888981380100761, 0.08598755379872662, 0.13697593206805841, 0.15878023420061382, 0.08762033975550107, 0.0840081110862749, 0.16782617808452674, 0.1303908582776785, 0.07250598578580789, 0.16750285614814076, 0.0872451573876398, 0.10327245308352367, 0.13235998047249659, 0.06706284571971212, 0.10253789821373564, 0.16176406480371952, 0.15004879129784449, 0.13142434853528226, 0.0862303471990994, 0.11335857079497405, 0.11220053543469735, 0.15157168172299862, 0.16331402877611773, 0.16389758246285574, 0.12898506942604268, 0.0965146989162479, 0.10964382905513048, 0.09182644941444908, 0.3022582823676722, 0.17699410899409226, 0.13799321890941688, 0.09057683896805559, 0.0797680611056941, 0.10681637363242251, 0.17165711894631386, 0.11672984489372798, 0.12874257458107813, 0.12789755421025412, 0.10168199414121253, 0.1961123895432268, 0.16196457190173014, 0.061204598285257816, 0.10361498434628759, 0.24476690590381622, 0.09889155958912202, 0.09714676785681929, 0.12085996541593756, 0.1314848874296461, 0.17518129412617, 0.1328292688620942, 0.07097343980733838, 0.1402445166770901, 0.17786975843565805, 0.05893801312361445, 0.16934483445116452, 0.10018496268561908, 0.13116719733391488, 0.11110793120626893, 0.1311593127569982, 0.08694270718842745, 0.11864828052265303, 0.09195940156600305, 0.1027296454246555, 0.19156103448144027, 0.16150684574885027, 0.11773537950856344, 0.21646184474229813], [0.044724034411566596, 0.039905221201479435, 0.027431805252230594, 0.02480050073271351, 0.03383794766185539, 0.016849335781963806, 0.028455911370526468, 0.06080770958214998, 0.03210564436657088, 0.034175423838730366, 0.014139379723928869, 0.041913311662418504, 0.04948353348299861, 0.021404455016766275, 0.008634324185550213, 0.024573471397161484, 0.01924822848689343, 0.006517495943366417, 0.043958402637924464, 0.027273413126489947, 0.030182889862252132, 0.08489657805434295, 0.031242269623492445, 0.006063758728227445, 0.029479544210646833, 0.037047092603253465, 0.0253416205357228, 0.021444483493853892, 0.01153752107971481, 0.048041636390345435, 0.021030348126909564, 0.009853369173859912, 0.0242572842564966, 0.05095252787162151, 0.02758930340808417, 0.0393652023215379, 0.02252890119728233, 0.03797260079798954, 0.009461788310935455, 0.03533659742346831, 0.044835867160665135, 0.052849094316895516, 0.04701608499245984, 0.056486934290400574, 0.03566870638834579, 0.09243335827652897, 0.06101578913096871, 0.04770616528445056, 0.04975691184933696, 0.029571360176695243, 0.03357453018959079, 0.06989780573972634, 0.00933640352117696, 0.023109516827389598, 0.00502259423956275, 0.03157178658459868, 0.015359372964927127, 0.03205103586827006, 0.011858404530877513, 0.11045974705900465, 0.03263957339472004, 0.03702249910150256, 0.0268513015804014, 0.04450866400397249, 0.07924949071769204, 0.050910964209054194, 0.07502137616808925, 0.023103046995986785, 0.04980208871087857, 0.024199408612080982, 0.0329305190326912, 0.01716753138628389, 0.05342793218525393, 0.03410899865307978, 0.0163206009393824, 0.051468906591513326, 0.041630230245313475, 0.03021662662337933, 0.03946859748767955, 0.055294795760086606, 0.027201919284250056, 0.02694543813621359, 0.03113821627838271, 0.07966030974473272, 0.04763431181865079, 0.0858248071745038, 0.04598641488701105, 0.02454068628139794, 0.05642244971490332, 0.0725767637736031, 0.08866003860852548, 0.05331612657755613, 0.03431076782622507, 0.061198308265634944, 0.028027408024562255, 0.008959220323179449, 0.053772370131420236, 0.02345009899831244, 0.04022565936403615, 0.03471671836450696, 0.02238506873670433, 0.011827140181724514, 0.061708729448063035, 0.030268897568540912, 0.009160557778419127, 0.036592012736946344, 0.006135667324997485, 0.04298885752047811, 0.044081821372466426, 0.03961548674851656, 0.010496954550035298, 0.036726973352155516, 0.019255095261282155, 0.03257376906861152, 0.015751428802364638, 0.034351310293589316, 0.02003929853838469, 0.019078625266307166, 0.02844256967572229, 0.02365920822402196, 0.01044690071804715, 0.05013165656211121, 0.028560943502400602, 0.038224133729402504, 0.04765498338799391, 0.05858843188200678, 0.013337974735934819, 0.052076080082250495, 0.027160915413073132, 0.027307723249707903, 0.052229876829577346, 0.04220343966569219, 0.04047468510855522, 0.13221812594149793, 0.03002352573509727, 0.010202885106472033, 0.02501793558310185, 0.03554534532928041, 0.058777749937559874, 0.020850599111456956, 0.05556271870487502, 0.028114425051691275, 0.03469133436945932, 0.00621891169742282, 0.023607064504176378, 0.0884312501709376, 0.07879870597805295, 0.0398101550526917, 0.02758662319476051, 0.021123297246439115, 0.03927702330318945, 0.03097868591014828, 0.025561065546103885, 0.005418938418318118, 0.035005048249981234, 0.029856925031968524, 0.020600151836073825, 0.0104958358154233, 0.012002108917970742, 0.02585003155815814, 0.0231689819400864, 0.01811592995987407, 0.01772848137521318, 0.030799233753766333, 0.01578407651478691, 0.03945511160418391, 0.019842436869761775, 0.03488770579653127, 0.05122792827231543, 0.030915246278579746, 0.023613284973959838, 0.013875443172375006, 0.03087330942175218, 0.04620661985661302, 0.03508866072765418, 0.07305338034140212, 0.061920439159231525, 0.014982153295672365, 0.005368456261099449, 0.016917533640350615, 0.057972803844937255, 0.04952139573703919, 0.0629094989438142, 0.03797264490276575, 0.02560479543171823, 0.01944105965750558, 0.01992203920547451, 0.04556560103914567, 0.017948335202943002, 0.026404233516326973, 0.00925369858409145, 0.05270015927297728, 0.01578421052545309, 0.018820266272606592, 0.01917171009284045, 0.02438970884707357, 0.09218146572155611, 0.08301687998963253, 0.03133146983704396, 0.0017777412867872044, 0.04474910628050566, 0.03768537353192057, 0.04040463315322995, 0.008890818056118275, 0.01161323965061456, 0.02941965331722583, 0.0992230578724827, 0.006565776678533959, 0.022204863406451683, 0.03306676886443581, 0.016020303392516713, 0.053469777439853976, 0.07535177522471972, 0.014464887391243662, 0.007150106863783938, 0.03874158453462379, 0.014804836828261614, 0.01183341832698456, 0.017529490802969252, 0.02635257494901972, 0.05367874926222222, 0.05906301284474986, 0.016362381733155677, 0.04099051421508193, 0.014985649447355951, 0.03306675190106034, 0.04621700144239834, 0.11026964868818011, 0.024900694909904684, 0.03267564431631139, 0.01619369792751968, 0.04101683119578021, 0.003740186378958502, 0.043784870699580224, 0.028449290565082004, 0.03855298233351537, 0.028794210271111557, 0.02399993288729872, 0.048048913678420443, 0.04007054965144821, 0.01710993903023856, 0.057738512488348145, 0.08187947209392275, 0.057499539240130355, 0.023198247155440704, 0.0659657156627093, 0.05275199256305184, 0.044859588744917085, 0.0644077585477914, 0.009584861840786678, 0.030408648640981743, 0.10084616113454103, 0.04565529319058571, 0.055674646448876174, 0.0285922714642116, 0.06907831864165408, 0.03278000978752971, 0.028073475463315845, 0.0103974253371624, 0.10290581347154719, 0.06811348255723715, 0.030221725814044476, 0.044223306101879904, 0.08637007113013949, 0.05692366656980344, 0.06291984660284859, 0.04801395555425968, 0.062453591264784336, 0.01795827234829111, 0.050902625013675006, 0.014828936695786459, 0.015942348200561743, 0.015171188062855175, 0.022139506913455467, 0.016619487133409296, 0.008932581886516085, 0.0337102745127465, 0.04733794468588062, 0.04428401802267347, 0.03887923214850681, 0.058497209634099684, 0.02294079739866512, 0.00803186312051756, 0.05669914951015796, 0.042205919711185355, 0.011114340840971895, 0.07781352062842675, 0.017471937462687492, 0.015896821893485527, 0.031435360333749225, 0.016621816204860806, 0.04100628676159041, 0.042698542920074294, 0.04053945127608521, 0.030943391911153282, 0.004668280216200011, 0.04513808326529605, 0.04834169475361705, 0.05778551460908992, 0.029490468624447073, 0.03283417045271822, 0.04227199884397643, 0.012158730067312717, 0.036158333865127394, 0.026217717810400894, 0.021839519796360816, 0.020638814761436412, 0.005770756280981004, 0.045542917613472254, 0.06335499111030783, 0.007434013549105397, 0.024422186925741177, 0.017472480290702412, 0.027534710176821266, 0.011480388431144612, 0.028793467275266136, 0.08286723587661982, 0.06635911669582129, 0.019181211279439073, 0.04300197699506368, 0.015810447778286676, 0.027707276899101477, 0.030697555281221867, 0.01802598505413958, 0.034501157967107635, 0.00477664904402835, 0.06876524936939989, 0.023915126187992946, 0.08059006556868553, 0.04989153319703681, 0.02737383800558746, 0.02631329116411507, 0.016883511894515583, 0.008300899710905339, 0.04476954036259225, 0.05513629676508052, 0.03979025701326983, 0.03922476253605314, 0.014165611887749816, 0.05129299299525363, 0.10895301933799471, 0.01811026079979326, 0.02366795454041234, 0.03321847911658032, 0.05082906503230333, 0.04957006026857665, 0.030337972433439324, 0.014809048834389873, 0.02326990384608507, 0.023419215476938655, 0.006739366292354784, 0.09160538949072361, 0.24212344203676495, 0.08076687822384493, 0.123102320092065, 0.12912127854568617, 0.10964917591107742, 0.12895320542156696, 0.18255777045020036, 0.17233310267329216, 0.09155471649553094, 0.12116313486226968, 0.111412627356393, 0.12445822304912976, 0.1631153401519571, 0.19865429028868675, 0.07162116933614016, 0.0920690188982657, 0.07029599044471979, 0.11381175754857914, 0.1228660134864705, 0.1186419158641781, 0.1924239546060562, 0.1874860924269472, 0.1454871225037745, 0.1156814404364143, 0.09065058893923249, 0.14755309878715447, 0.08998314118278877, 0.08635014934199196, 0.11280652148915188, 0.13623335691434996, 0.21179792072091783, 0.05590252225686397, 0.07911400084516831, 0.1957490611821413, 0.05667669339371579, 0.11506336288792746, 0.19761507319552557, 0.081129209138453, 0.11088967363217048, 0.13404802632118973, 0.1383298129907676, 0.13750778138637543, 0.10123055122260537, 0.1553585042378732, 0.14994078209357603, 0.15967971379203455, 0.09054574170815093, 0.066288772970438, 0.11025485662477356, 0.12638774594025953, 0.14526464444186005, 0.26450065842696596, 0.12449267905737672, 0.14344740552561625, 0.08902808957334075, 0.1535212213971785, 0.1294802642826523, 0.12438217284423964, 0.11966840364038944, 0.17247810560677732, 0.15640800792191709, 0.0578904975471752, 0.12108795318220343, 0.1424185971596411, 0.2055703941732645, 0.11280083536569561, 0.2657300281737532, 0.13666411808558873, 0.10225724255932228, 0.09956007943089519, 0.11028741273496832, 0.06737347226589918, 0.13554087121571812, 0.12491001880594663, 0.07122416528207914, 0.17858413367399148, 0.1097950270133359, 0.20956392559622014, 0.15470590282763752, 0.1336438094398805, 0.07369648226137672, 0.1576826088130474, 0.14959140441247396, 0.16958177887967654, 0.14227651192673615, 0.21141568837421282, 0.12539179223988736, 0.15479230747691222, 0.15690784395805427, 0.11281092518142291, 0.21918912125485285, 0.15354212027575287, 0.15138474532536098, 0.12719023573611463, 0.1607594529965094, 0.07905865952904735, 0.14490719219403608, 0.21196128481200763, 0.08833062342767205, 0.11319916934839316, 0.10440703148820571, 0.07179842303906168, 0.14548208777393612, 0.11027554515749216, 0.1610441120075328, 0.08356578089296818, 0.06970924764339413, 0.1593967375478574, 0.15619375370442867, 0.17894193876002515, 0.17588688912136213, 0.06146335761461939, 0.06711976802242653, 0.11836693276252065, 0.07874018911804471, 0.10364904680422374, 0.12356979000781264, 0.17374290845223836, 0.09286084212362766, 0.06095614590282951, 0.13121238776615687, 0.14053038348044666, 0.14711880923381873, 0.11862094913210187, 0.09815241782260792, 0.12627151289156505, 0.08580652065575123, 0.10844995347516877, 0.1029732869938016, 0.14805057352142675, 0.2154472041875124, 0.14514675576772007, 0.14782981893845967, 0.15186277324599878, 0.07718455937824079, 0.05648228632552283, 0.10637864390654223, 0.1108995463166918, 0.13567044426287922, 0.1287443387721266, 0.19070975801774434, 0.19074334550116742, 0.14104760358376162, 0.1205569723887103, 0.07570269318031413, 0.12238618066268307, 0.11587976265166487, 0.05823410768061876, 0.222311562991568, 0.06283766922674008, 0.16651565554950917, 0.1426488376621689, 0.16230451794607298, 0.09002564461635691, 0.17200841009616852, 0.08386882141764675, 0.10041191229330641, 0.1424867356462138, 0.14219392064426625, 0.16989343001374177, 0.1158314509583371, 0.1138324596519981, 0.16293969457702978, 0.1412370234195675, 0.18748457250850542, 0.15409990320248262, 0.11945843776421887, 0.0643424970496978, 0.14089984579810075, 0.09201529249548912, 0.13664978742599487, 0.09456416858094079, 0.12186311158750739, 0.11555884272924491, 0.1353516685111182, 0.3294903353921005], [0.03865247931597488, 0.02477571045580719, 0.08647822282676186, 0.030664788825171332, 0.0100231242166566, 0.054316721457455835, 0.0333425390667149, 0.06692794617265463, 0.07063848099538259, 0.023283245540889244, 0.03269033120679004, 0.04258345998823643, 0.012268756216924106, 0.031065226266426698, 0.11643317581287452, 0.020804392573024546, 0.010430318170360156, 0.0412177963049284, 0.055626161729118655, 0.031112971383013895, 0.054328544930155785, 0.00410470344857978, 0.034321081558508534, 0.060112767586750646, 0.01695183358554329, 0.02354057316136147, 0.030829007870384624, 0.06655687572700636, 0.041553138489169736, 0.03230887917535646, 0.018060191700767194, 0.020389785624242256, 0.032910624385944436, 0.025194632887308086, 0.013416102954319544, 0.0448596328496933, 0.012506853306799062, 0.008687318618675428, 0.012768119823054543, 0.027005725972620503, 0.04710806041423764, 0.05354535945558122, 0.011382406278114234, 0.0018762886382838978, 0.05916236394218036, 0.04123432881065777, 0.01946105608450515, 0.06572664063423872, 0.00956055841275624, 0.013634697251421, 0.06840188708156347, 0.019297225500590036, 0.05399235457714115, 0.03406332306829946, 0.00495442861158933, 0.033717032721532245, 0.03544133948162198, 0.03425408301076718, 0.04027410337169256, 0.026769122507955347, 0.035533033311367035, 0.01334907641700868, 0.07491092423775367, 0.00899268058128655, 0.008855032967403531, 0.017473491307880198, 0.028770105314574072, 0.020246294127511125, 0.007213180086442402, 0.017796996448721205, 0.0417615980175989, 0.013098087161779404, 0.03392058304910149, 0.01685478102548846, 0.009777149335215134, 0.07144789184842791, 0.02268534423118191, 0.02303440639350031, 0.023213958633797507, 0.025488343555480242, 0.023903611448726485, 0.033435009819056304, 0.024395400059542487, 0.02503031545451709, 0.027036565389218073, 0.034809070373220105, 0.07822341684784208, 0.027262549780841385, 0.0665334594835128, 0.08216612599790096, 0.06007101732705321, 0.029994229985667125, 0.018347468160625015, 0.045788180881312916, 0.031346947220819335, 0.025263862118923237, 0.029976018105766604, 0.005328360354594354, 0.014810349925288131, 0.030158856151891605, 0.006008958967868239, 0.015190144634938665, 0.01191282897655453, 0.026823568157851696, 0.008650977131245392, 0.023074363624410968, 0.05260202953858035, 0.03949241406683411, 0.0429789746579315, 0.0072876747498022655, 0.05815465122993503, 0.035445685498416424, 0.018125378560008745, 0.03512172234643783, 0.04824696108698845, 0.04865484884274857, 0.012950543114649398, 0.013883024953039629, 0.053814215386020284, 0.024868333878527795, 0.027865409485197494, 0.06081732442336423, 0.0315073155798018, 0.013912404671178331, 0.06480749709797756, 0.044550499080547264, 0.008501022588461637, 0.11782432187880788, 0.06373276548194033, 0.03275965034429516, 0.04218564847750323, 0.024640142551756332, 0.027683406037145426, 0.03670555878696697, 0.03097738990826266, 0.030632137720073973, 0.06465997001422302, 0.030898208264261484, 0.0483853958014931, 0.02712334832176566, 0.051042990160307715, 0.032115550977843146, 0.024374745453574827, 0.027981844398060014, 0.107921496831945, 0.04995633329131773, 0.03748543640332563, 0.007403826374294502, 0.031589645626289506, 0.013911428428920252, 0.04699272981711796, 0.027142454171553254, 0.09227800768400941, 0.01880103150116546, 0.03786765857200537, 0.04670010141230055, 0.09432456429515566, 0.02507692063227296, 0.05184099144701447, 0.008672531644281532, 0.045671401611928425, 0.022034858153866868, 0.03617331591833915, 0.07058720410402332, 0.016038540717480437, 0.04163060343957373, 0.03013193527502673, 0.049967186458941014, 0.015113624544548137, 0.028201989995847856, 0.07668888954711811, 0.003644608784400459, 0.06996267368750912, 0.026736108386623006, 0.08366234999682222, 0.06328700190143925, 0.024045013057600175, 0.0164178926830313, 0.02049555057393653, 0.032911055255681276, 0.007443518976547888, 0.04419965576380491, 0.020696610677987337, 0.01731279555575124, 0.04734055365302733, 0.044974213665617366, 0.03054272037531648, 0.021346944084923183, 0.0877378484500306, 0.049431052191981247, 0.040259297737585645, 0.019714183573211943, 0.021606712735124996, 0.07722914591431618, 0.023212240243862783, 0.01430542826918619, 0.06500900842781578, 0.041744828024613004, 0.07366803807339498, 0.014292112019445215, 0.07135380618274212, 0.027804007155022452, 0.008990827332516866, 0.04048016767150589, 0.03372457463826452, 0.011304429033771157, 0.043713431140141826, 0.031215450526880364, 0.022817103857440606, 0.04260771422247801, 0.029722700627254586, 0.06555499841592141, 0.011975149873511066, 0.04868334052818162, 0.01869639800861478, 0.0314771920176489, 0.04049244236999324, 0.0581246464114104, 0.01764767463984234, 0.041048216833067794, 0.04865788867963212, 0.028581852559000254, 0.029460640225027288, 0.013966580603404768, 0.01634294679388404, 0.00508988879820598, 0.03470167863581862, 0.034823075336005004, 0.018967586403180445, 0.035179723519831896, 0.02033647312782705, 0.04917903071535485, 0.016639953445909277, 0.021679572129089917, 0.033058131113648415, 0.020913814826469337, 0.08089869722191777, 0.04694273874961904, 0.00720211911746966, 0.0530504156569285, 0.030693219442452704, 0.04188713378139904, 0.023098248057067394, 0.030873248353600502, 0.009946911163362009, 0.04078343211274062, 0.016100010901157345, 0.010334309706065272, 0.0454904329297798, 0.04788053860621793, 0.010176724188828042, 0.04450898630810635, 0.01009907603396901, 0.03053443207006369, 0.052793379806514294, 0.0475528774383877, 0.04904267910335745, 0.01567508852375405, 0.06568983689482723, 0.04134129307099751, 0.016191716605265225, 0.04284275536026273, 0.09388776416225092, 0.0012802056964054437, 0.0030058689964269952, 0.05889799312821456, 0.03906391580988254, 0.002758787678820746, 0.0034134075186947094, 0.05013577187699931, 0.04684552164482219, 0.024863942060619593, 0.02873161880831633, 0.01861007308720478, 0.036094670317002704, 0.04058648053822773, 0.057730675408882756, 0.03218289218576891, 0.05238299164921045, 0.036874493650559864, 0.040625367380146465, 0.0276137374541057, 0.024131743403683816, 0.03466245252639055, 0.016789153118484786, 0.02175826013886503, 0.02433242352812418, 0.050582234348569594, 0.02559501095674932, 0.024936358710484843, 0.06480280842099871, 0.07330990050520216, 0.01737700871724103, 0.03708324834172215, 0.028223526697339754, 0.045748985305960686, 0.03275848665673818, 0.010983541341764587, 0.023576879873871803, 0.00787120299147708, 0.048529866084988625, 0.041527896986476014, 0.027042354989264692, 0.09782450220414571, 0.03714053026799645, 0.03872193076780864, 0.05978622260902609, 0.033903792700065036, 0.014134877644080137, 0.007738042190404875, 0.018837740245674337, 0.07966486950005804, 0.043743008481604714, 0.012841288798621722, 0.04841997394604342, 0.037372847087681293, 0.0709871326440147, 0.022315761473562037, 0.03470801954556789, 0.0371851337674473, 0.02215741854161024, 0.05009573831089905, 0.04124676975022469, 0.01319157995749265, 0.03099377652896302, 0.06678919254669122, 0.028502538600670438, 0.02859635285234877, 0.07437969917165381, 0.0628411772527865, 0.0005567869645476874, 0.00980643490662, 0.046427099632897546, 0.052212289201893976, 0.004753912607806602, 0.01658059859515301, 0.015564064927665251, 0.032248499736722024, 0.05666150438732334, 0.033742640633136034, 0.03134756129501121, 0.05793717397110803, 0.030738219884889464, 0.03534688062167593, 0.013331176663216735, 0.012286357415307845, 0.05139660868527634, 0.019989404162125926, 0.043697997861142666, 0.05494680229042258, 0.046468290101204596, 0.024930530094674656, 0.10384996102324554, 0.07400786876678467, 0.18830315715500287, 0.1289314923009702, 0.12988851166197232, 0.08981491878096547, 0.09202184714376926, 0.10157032763319356, 0.15014981159142085, 0.1741547520671572, 0.13870580281530107, 0.10885461818959032, 0.17196482100657054, 0.12633256747254304, 0.24254348235470907, 0.06628426071256399, 0.047685028918619664, 0.18559094411986216, 0.14484259566026075, 0.10557679871895484, 0.10818999992417437, 0.13375085512442247, 0.09859301775161709, 0.10631893961025135, 0.18044743154730114, 0.13782571575471333, 0.13882468215056828, 0.17670399456151895, 0.19990217047078268, 0.07064644021115132, 0.09915028499173266, 0.08237027004361153, 0.17931938064949854, 0.13221212769193308, 0.19519088470510074, 0.17088069846587522, 0.06538685065295015, 0.17478448684726441, 0.13325932435691357, 0.07577125914394855, 0.08436211637620415, 0.14398560593170778, 0.10918957021619592, 0.13421630300581455, 0.10949903646750109, 0.14976535364985466, 0.08284533276621785, 0.09023258422634431, 0.0546119350806943, 0.12391151381390435, 0.2132163303239005, 0.19894922231989248, 0.06242201903036662, 0.08648476390434162, 0.1518320898924555, 0.11834665813616344, 0.11022791199918304, 0.14960341448230402, 0.09939045924693346, 0.0717824435393725, 0.13331922542835983, 0.08030976953783206, 0.1599428496722664, 0.09277476995651211, 0.1256526346717562, 0.09662390912749938, 0.12487340505634036, 0.08982952085456677, 0.06482285913079977, 0.10661411591406379, 0.07119521219283342, 0.04508160201034375, 0.1609031938548599, 0.09281331753092152, 0.13063997562442506, 0.16138251099203313, 0.08061847582991634, 0.09464488032140903, 0.16951068198042257, 0.12707427410142763, 0.10872699253793273, 0.10540003356124673, 0.1823960891259568, 0.0857954333935465, 0.07292413299104997, 0.08258472782160554, 0.29265014507940834, 0.1654894527580057, 0.1024426386824676, 0.2296055294573307, 0.1532537971756288, 0.10011370972331081, 0.06424111713256155, 0.09212837714169707, 0.09802209838692631, 0.2857912688383034, 0.13430657530469553, 0.21728672619376863, 0.08343829094831433, 0.1968195451689618, 0.17540662203516277, 0.09800800521458898, 0.08765841235539742, 0.09325083012559585, 0.06934353762439319, 0.11591942980885506, 0.1307641611035381, 0.09342753421515226, 0.11788495576807431, 0.0732098233753017, 0.12960911808269365, 0.13602064975670405, 0.11774246341415814, 0.14347456049706253, 0.13878238227750572, 0.1448865375880684, 0.18058585269110544, 0.0808683056384325, 0.16335957204656942, 0.12891291401215962, 0.1250901969947985, 0.10616660849856478, 0.16848869967673505, 0.10961854005498545, 0.09935512114316225, 0.14055539428123406, 0.1105375343135425, 0.2488598291363035, 0.1203786940979106, 0.06990246048995427, 0.15782311984470912, 0.07872308325022459, 0.11964666337839194, 0.15104910119303636, 0.21279350801237992, 0.1688769438437053, 0.17390521402869905, 0.14856957138649055, 0.07274340518883296, 0.07881358625101191, 0.20095508040062018, 0.09671705162950925, 0.11889681432928358, 0.13948461173900537, 0.16299267459128583, 0.10285628041518585, 0.13564631555761608, 0.10127352963068656, 0.08513279645038502, 0.18923612923494407, 0.20389118285051414, 0.07263317717505352, 0.16204081209642546, 0.10471911688468286, 0.10939080334667649, 0.10601422988942691, 0.19352299134646142, 0.16514980526907103, 0.09004521356629473, 0.165770542674831, 0.17758043110370636, 0.11443604369248662, 0.0973528932247843, 0.12404162968908038, 0.10801706170397145, 0.09982588195375033, 0.16700481144445284, 0.1125558502972126, 0.10012670366891793, 0.08177649761949267, 0.1036249655964119, 0.12522793960358414, 0.12087634525128774, 0.0937122135822262, 0.14335644112101623, 0.14450973352151258], [0.026400394704458967, 0.037366451895130534, 0.030470782092639377, 0.032741669166300974, 0.01323335396591574, 0.04174753537933741, 0.008408210024104586, 0.034467841897691996, 0.027796197216957808, 0.04665872434686337, 0.07000082092625753, 0.051254794866378815, 0.06381241870777947, 0.05391713557764888, 0.05777150286095483, 0.025743562628382018, 0.0331437825890524, 0.009734123429682637, 0.06477576201515538, 0.007367965798558933, 0.048213336284139326, 0.01969311336454536, 0.033515830125127516, 0.05218842173261302, 0.026613415684551, 0.01060247522712286, 0.04246750853157469, 0.012472135214401143, 0.07410810195973941, 0.0461854970614825, 0.03020443334909422, 0.04679213450955493, 0.02052767920706953, 0.0634287071547338, 0.04327478199931128, 0.0071210214602095735, 0.09105937236121722, 0.021017691752474223, 0.02724448887498251, 0.010695376849201108, 0.060232366169137616, 0.048317121607916694, 0.013741656422748097, 0.05605539619656546, 0.04104271391406655, 0.026119689856256758, 0.08333313837647438, 0.014234180395890559, 0.022591268743521402, 0.018628941449735845, 0.05721060545848949, 0.054065551542277844, 0.006820233247708529, 0.08318636446659054, 0.0160701367006238, 0.021141454843538146, 0.06520877592265606, 0.01511430986491697, 0.04188466052125607, 0.025733810383826494, 0.029777010570147207, 0.017543259974835173, 0.0549196778530521, 0.017258682388014028, 0.039379892604691644, 0.05143962102010846, 0.025575262195031558, 0.037347147573849986, 0.043945853132754564, 0.018790487066975663, 0.025164188717358878, 0.038959889606173546, 0.06830351985991001, 0.05379847676626273, 0.02809377044572362, 0.048126307382647476, 0.027359771974650875, 0.06010037075195994, 0.07767039045159306, 0.03663032282409923, 0.036416686073477776, 0.05604369825284396, 0.026263517227822115, 0.03603467425065381, 0.042107851044940095, 0.02149431001661079, 0.06939613765903882, 0.010979941713490655, 0.01343114607568298, 0.028954551488693272, 0.008120288107810276, 0.01060410710384271, 0.007359595220935131, 0.03890958641256605, 0.011548018864622074, 0.02600959754948105, 0.04872588806652597, 0.059904905169137886, 0.027817910337554555, 0.009890928631648421, 0.035482655478907485, 0.04416343895718455, 0.03677713744608419, 0.054108228002275736, 0.03900826236765299, 0.011373318149708211, 0.01559814774165196, 0.0270953146474702, 0.031415604786681275, 0.03101927587496383, 0.03850738817293729, 0.055527685941862207, 0.060230045579373837, 0.03207600934963141, 0.023008177622354457, 0.06504391905452524, 0.08127393387258053, 0.02833678776265255, 0.03620219097605773, 0.018967599973880818, 0.027190211162503277, 0.05176862568727561, 0.036766274100435634, 0.04078506398946047, 0.029690192014511143, 0.05132817503597055, 0.049436544932957203, 0.042392672904367955, 0.028102447212274586, 0.06024918705224991, 0.017797956575772593, 0.022463746568454162, 0.053609816889677725, 0.02425511633711202, 0.006394634031624134, 0.03250555933586188, 0.060311062660600455, 0.01808939245529473, 0.02295344020240009, 0.0443189931102097, 0.04034611629322171, 0.050623937110815725, 0.010089920052061123, 0.019914024010566727, 0.04595541940735919, 0.030929207136588435, 0.039237529172429016, 0.048787919737930806, 0.11889882279293877, 0.04264186828264168, 0.06458356018577303, 0.07957849877753428, 0.04897773312404752, 0.04464136849024466, 0.033654342871159315, 0.052973066057477675, 0.03119321832699435, 0.058075601900262494, 0.026235844873424088, 0.02963181764685682, 0.06502708460071258, 0.04275075958243438, 0.052182257241968594, 0.024341512504698973, 0.06331497111490794, 0.08606158875461135, 0.025772366439923644, 0.021607440463932495, 0.0690172640606761, 0.041925715282559395, 0.026398664440161417, 0.0030184649388372365, 0.03508943086490035, 0.024546855861054998, 0.043976105616561005, 0.021216075035876462, 0.012802384145158743, 0.015283125984881605, 0.05491438188723155, 0.039893078817320723, 0.009813623136973806, 0.0804177380299994, 0.06537526127483163, 0.012117444604103054, 0.04246493349117892, 0.027609659458643625, 0.10523013517792736, 0.031228427509112016, 0.017880005030227557, 0.06479792975421463, 0.08746652265212365, 0.08504381336803947, 0.014389795617067387, 0.054166972171515226, 0.049837973035339794, 0.019308555339063917, 0.07129834273031779, 0.025730327802843282, 0.033402049980525456, 0.024996342902470912, 0.01628346980682441, 0.011654319856981081, 0.017768285935744643, 0.03723996618230428, 0.04032422336084502, 0.04812659236735531, 0.07391102146357298, 0.024433428554662635, 0.010057514915908021, 0.03418286736788494, 0.04632047464006713, 0.009594460566794234, 0.03342687418418271, 0.025202137484614338, 0.016883491538465023, 0.03181904474539416, 0.033264158094035726, 0.037670581468514035, 0.014691506213109409, 0.06047534277396543, 0.029366632590868642, 0.10764283607048647, 0.012948532106487878, 0.009887353600268918, 0.04848325412188258, 0.041702497617474625, 0.04060990017439638, 0.09930777975491115, 0.03001719161069819, 0.03337014187127352, 0.027217488270252943, 0.028539535722562244, 0.03141840035095811, 0.031488360704055855, 0.04507719153272254, 0.07058691911931549, 0.0038004708226903206, 0.05751062650233507, 0.011943798162974417, 0.025705378070207577, 0.03233224792139871, 0.011624268389173915, 0.05138305834095393, 0.09921680177961077, 0.024311611162764684, 0.036818412731268575, 0.014461621941466416, 0.03378744090774229, 0.049519366917333434, 0.012311118854475873, 0.014947257936000824, 0.05846068409404584, 0.03918203179325376, 0.013471523150136428, 0.07370298941220556, 0.011536011339298316, 0.07102295250764915, 0.056330443759049685, 0.049035554485661645, 0.024272678519732187, 0.08103523882372038, 0.08367793594620057, 0.020931967334555726, 0.0223562428727746, 0.039653247222304344, 0.036551212426275015, 0.026453807284789424, 0.018515933138717498, 0.025163695083132813, 0.015156879455649426, 0.0503128932655922, 0.026816083916596005, 0.03993529726618102, 0.0010049332631751895, 0.02423163902546678, 0.034338798107845445, 0.01773606570038412, 0.015058692045775908, 0.04199346361149635, 0.006269080880364137, 0.02050810686445662, 0.007708203612959811, 0.021314216644636223, 0.03148578905633517, 0.01621119225663798, 0.0679585797978299, 0.012070715593706285, 0.05113290283562882, 0.030966669054968015, 0.026866171675335084, 0.05174625778038587, 0.055792301028434715, 0.03575660042198641, 0.029928815817194324, 0.025749504898807833, 0.08698532597294875, 0.02207672885353012, 0.03831083354141031, 0.06205172211463962, 0.039783865213394165, 0.04252068192831107, 0.03441395264651094, 0.03303200751543045, 0.021826278185471892, 0.032214657802666934, 0.031564889276134114, 0.010288830896440362, 0.09050875476428441, 0.048817028890230825, 0.0435622840720628, 0.024312574682491164, 0.02600178761141641, 0.03004557473052825, 0.019986703592751707, 0.016868107453254715, 0.008777944603934884, 0.03949564050084778, 0.029099340683647563, 0.044335342411484034, 0.036890771705657244, 0.03083486362759556, 0.03529166144185832, 0.05739901427711759, 0.02549910342453846, 0.029808620123990943, 0.06210259867033788, 0.042060051645551405, 0.05194691076342549, 0.030725721269845963, 0.04047853240211095, 0.004683500180752682, 0.05341908748128584, 0.008439510844514837, 0.03656074584328702, 0.01533306616225413, 0.07232189923524857, 0.013263625109435191, 0.004844806614398424, 0.08218179337148156, 0.007431525870093277, 0.0271493328203048, 0.0350824758809592, 0.029404844290443828, 0.0368002754902201, 0.049674432525145154, 0.058473868029458184, 0.030133129496659552, 0.012781213852576911, 0.022597792857725705, 0.02069324684063239, 0.10955301392823458, 0.03789939365482756, 0.1270513396177973, 0.08559770150376217, 0.12952199418629917, 0.1486609022000006, 0.19151661757911953, 0.1774576705481325, 0.1496989115008286, 0.06718844933701412, 0.19311578891107015, 0.1601642013660499, 0.23469826046909603, 0.11841523088514805, 0.23189851641654968, 0.10646833945065737, 0.27056426448481424, 0.1933274239833866, 0.0629323452178921, 0.09611392220748322, 0.12886313668319158, 0.09920819117022411, 0.26665826407926424, 0.054204362843717845, 0.09757263000522341, 0.16041973765407289, 0.15831072867981025, 0.07334313515041556, 0.11302761533962828, 0.08370952853666884, 0.207368118422372, 0.1303232897605215, 0.15960035233625344, 0.11982724868825503, 0.12474494480660983, 0.16738579528672354, 0.08593983243086509, 0.06459938362240791, 0.11384330264159612, 0.083329012883561, 0.10361765098891088, 0.10083793729011502, 0.16119786804275854, 0.19908593355544976, 0.11042353364505939, 0.12527513849948133, 0.11146089155226946, 0.19199962594679423, 0.11651423360620226, 0.055387863623244424, 0.11233567925436155, 0.0709923505783081, 0.11952463564063821, 0.17552565064813408, 0.06128393938498838, 0.2330676865364824, 0.07909083565963165, 0.14893725594239576, 0.10150218914662089, 0.09577029850333929, 0.11276114106710468, 0.11850452609360218, 0.22245488315820694, 0.13712767963962896, 0.09728698711842299, 0.13205455828990253, 0.0875085646818791, 0.12555515633097716, 0.1962393977280174, 0.19426411443522998, 0.07813788750874144, 0.18417672786329473, 0.0615966422483325, 0.08350332174450159, 0.1490928711635726, 0.18727593656097138, 0.07806613243051938, 0.14334342681935855, 0.15785635448992252, 0.12183516951543943, 0.20205852761864662, 0.13794000819325447, 0.13464896407510552, 0.09177488753838198, 0.11552469884710652, 0.10197862250996487, 0.2465518872652735, 0.11907343699463777, 0.1161743418446609, 0.16011869880769933, 0.1400698481925896, 0.11458384219024863, 0.13618774579039641, 0.16086210177413054, 0.08820326240467173, 0.12533985716956003, 0.13520657058273042, 0.17532746413988726, 0.16170223669282027, 0.1343088551823582, 0.19064031674393586, 0.0708061537838408, 0.10741579146789652, 0.11988647122468267, 0.2004942194159542, 0.08923768904060125, 0.13435701759798185, 0.06325268160019602, 0.04757698918027537, 0.09574720795665469, 0.15226319033120359, 0.2436997874506882, 0.07544847325022731, 0.13955801565732273, 0.19029677446399415, 0.10248510140393462, 0.15664858929812908, 0.15395281038114003, 0.14238278408135685, 0.10859114982719932, 0.12321472620325429, 0.14576226845383644, 0.11469387342887265, 0.16063334047794342, 0.16559424570628575, 0.1363889585648264, 0.12353016356272356, 0.1447503420391253, 0.08711998803274972, 0.12146226023989064, 0.11618812967623983, 0.14387466545615876, 0.08903962466865778, 0.16712403004722937, 0.11704640862132822, 0.1843513963477952, 0.10146952447082315, 0.09704711820398058, 0.07791742469583239, 0.13161929164613995, 0.11296908490891967, 0.181725872946637, 0.1037416464782187, 0.13417702939893517, 0.12845807841845922, 0.08476072177290916, 0.17360416161162512, 0.1418880641992603, 0.12423045241406985, 0.17220598592289857, 0.13437081900026115, 0.13097008291099752, 0.11795959462012563, 0.12036844821912901, 0.14056246461612837, 0.11849524373454706, 0.12043126699115549, 0.09725719943110432, 0.10876643577856676, 0.12905582705778734, 0.09103063640317746, 0.20550966528909548, 0.10078873671591282, 0.11906606810433523, 0.14949862153402396, 0.08037890547088214, 0.13862880266138486, 0.19025444744953088, 0.09241731770868812, 0.10052890530122177, 0.153383519500494, 0.17625285019832, 0.07738126668014697, 0.0794640299198883, 0.1231355004544769, 0.1132917758077383, 0.14501786125557764, 0.08152740062879664], [0.05119842217702951, 0.06568571140191384, 0.01800470789229231, 0.04908219698284354, 0.04868262128106185, 0.06435331968324524, 0.030594224575906992, 0.05037850420922041, 0.04868035836677466, 0.04853257004703794, 0.06521248750920806, 0.11667317364897047, 0.02339699345507792, 0.009037438447454145, 0.045701389467077594, 0.057931684622807164, 0.05796974365200315, 0.012609698859575604, 0.026346703924770867, 0.028461521158793142, 0.044121498707681894, 0.011349250512596751, 0.017246229574084282, 0.10081709269434214, 0.04939313904781427, 0.04280129008527313, 0.018644559629527584, 0.014371980680152774, 0.04239902399214251, 0.038670782798102925, 0.025523925931858163, 0.04181612848437258, 0.04797442749674831, 0.012951890854830188, 0.05049792976517763, 0.06333447899669409, 0.027006027920703803, 0.03191864690078156, 0.013925139925309589, 0.046532462550593276, 0.041275553205715756, 0.03982701325523002, 0.07201151017631803, 0.040835550387523005, 0.033862636158508916, 0.025309362980936254, 0.09591436505849872, 0.049422801206154485, 0.03545300689126764, 0.044671671864177497, 0.0402793518400618, 0.04226296754287822, 0.017109094254140342, 0.061210487969219685, 0.040141256393066475, 0.07515191273497683, 0.01984025877235191, 0.044986427295953035, 0.026135499722191265, 0.011782309373042412, 0.02593222420130457, 0.02835106074676982, 0.031245061795094183, 0.04331837448158434, 0.00808631131492023, 0.09123221558651753, 0.01104893091334296, 0.033897109130131345, 0.02985954417714051, 0.04144346687410559, 0.08272599881248814, 0.010595653405679124, 0.03262434706890157, 0.039283622056245804, 0.042238224763423204, 0.043603040277957916, 0.04369321758193629, 0.029462994741541997, 0.024505775654688478, 0.05483326641842723, 0.04229135744805847, 0.03957666776009968, 0.030080244477306093, 0.018641933699005415, 0.06458056106099061, 0.03810720857498901, 0.07054889401687042, 0.05692425010991948, 0.06528060563973018, 0.024400585763422505, 0.02879384725487658, 0.031062542660427944, 0.0594847969976919, 0.04952787574646728, 0.04101028333285025, 0.06354969673390899, 0.03785497675250683, 0.03386142158082553, 0.014652424292372805, 0.026644896316741194, 0.01557608347918306, 0.04108951247430273, 0.01961745840630361, 0.03939136663185699, 0.04849982733971306, 0.08884347376546689, 0.06778138037770987, 0.04488521022722125, 0.07752926873841456, 0.021117634871708493, 0.04683538433164358, 0.037889870415840826, 0.020890027085053067, 0.008637233404442668, 0.017485253712428466, 0.027045194658317735, 0.08927463527236666, 0.07979501930198499, 0.007277634976032589, 0.02176548314413854, 0.04275002676461424, 0.015597387782431074, 0.024349620998171822, 0.02407133682364864, 0.07660033394183431, 0.06960249372891017, 0.037746384008122344, 0.013794759421476295, 0.0403618854470551, 0.04946476859705789, 0.016343345433207493, 0.008638190986987735, 0.026089975111452595, 0.04200459158580218, 0.03352273082626717, 0.016162107033388953, 0.023313969606533647, 0.0875166053218501, 0.004580563873917396, 0.03567350023825254, 0.02000386543971087, 0.05524716938712767, 0.017337334774700657, 0.029138668573328426, 0.0038244222606798367, 0.036652103798197846, 0.05253448477014899, 0.016017694425370013, 0.025358497397974133, 0.030923225850399052, 0.04363382541175399, 0.03377574635669589, 0.012388047762215137, 0.01728578477299639, 0.050767107999750545, 0.0333028753021998, 0.07324002496898174, 0.09315749763378076, 0.0641126704535314, 0.015439789542662246, 0.07658750962998186, 0.013818245214809264, 0.05443417926185897, 0.06896156990634543, 0.030970614736101458, 0.04843558364414743, 0.049589018536997695, 0.04956813322912369, 0.08201962350202457, 0.03869423296834741, 0.054607344791293144, 0.02178543377002435, 0.0350913612970284, 0.013489884307741054, 0.016068587944443737, 0.058464619597154, 0.10634876122432095, 0.04706311425460236, 0.03922368705804859, 0.017684505520654575, 0.01664326130412519, 0.05547819359760199, 0.06969488984239952, 0.026439283242715255, 0.040978683957031796, 0.026303891757769243, 0.03728964851636972, 0.023486173312578882, 0.022197633615827987, 0.025830399843731096, 0.041333544201084545, 0.027557395298832228, 0.05299364263191819, 0.06483638911907162, 0.01828238308163626, 0.06047308325235333, 0.027857967652380466, 0.02408722641744784, 0.06204107590019703, 0.02909603961078184, 0.016794245523799742, 0.023232209529461603, 0.027935110298650603, 0.041527846096349616, 0.026267585045258914, 0.05062578611874154, 0.06440868135541677, 0.04468026551018868, 0.06010275240987539, 0.04943621584347316, 0.029062876211745397, 0.04311647638678551, 0.033431590002562316, 0.048189370427280664, 0.03709053580782243, 0.049352219993514676, 0.017670795720602785, 0.05301027352522526, 0.03263162774965167, 0.01690711303880172, 0.058607159448521476, 0.029496202245354652, 0.04032636753150395, 0.02397304932985987, 0.040743391761290174, 0.02978270687162876, 0.034667823131063154, 0.02556042093783617, 0.024341987479212027, 0.025169885018840432, 0.021685897771801268, 0.03667181524048958, 0.04785988400025027, 0.04211586115083524, 0.026562430563249757, 0.015277543338015676, 0.03674774670175143, 0.03031527204439044, 0.049028630035796335, 0.04510057384946516, 0.017426691051306467, 0.05089104242090668, 0.08410993883652346, 0.011410856403277388, 0.020415284970243062, 0.034764002077281475, 0.013901967106253972, 0.021693806097443615, 0.02137171570211649, 0.034041630303753276, 0.04182004023875509, 0.002904086835249992, 0.027483251777344515, 0.024618256404729824, 0.008831853362997728, 0.02921977047143238, 0.04806121551830854, 0.030084641384226934, 0.04401962345998202, 0.02117121878213116, 0.06845071446150541, 0.07337416455681835, 0.012080679880455136, 0.06783935440970318, 0.06392148642667703, 0.020702917660985674, 0.026759950410840765, 0.03819344359050904, 0.01112061135271298, 0.02833557148863162, 0.04036571916991046, 0.030985495009060417, 0.06125705582754953, 0.010941083709310209, 0.010623501331013228, 0.04219717000211988, 0.04500357726854937, 0.03618960075878671, 0.02698561080199267, 0.05399916706872838, 0.02093801986692207, 0.05136737061132278, 0.021002477301018577, 0.04523124612335648, 0.07733648336891617, 0.02814412283311997, 0.021501482131757906, 0.006036387473743941, 0.036247418727725744, 0.02514605826166059, 0.027171480203313485, 0.017564912027280246, 0.02242547719340239, 0.027230731577479413, 0.05410432642591851, 0.031257224535303454, 0.03387692610600165, 0.024451455533770577, 0.0413739814955209, 0.04060092315609966, 0.0601655033284, 0.0670076333252447, 0.045608582839901955, 0.026635211925687532, 0.02832365471736661, 0.04782291401975921, 0.042868821283004115, 0.004547023887945605, 0.0532949562849743, 0.02938248316890427, 0.009080348153864699, 0.028122843974935155, 0.047996741120836565, 0.031744748553527255, 0.05872259182589395, 0.08742068082626377, 0.031035950873047113, 0.07856223652405397, 0.025210491947031448, 0.008190649644737797, 0.06945459345089537, 0.07073042249040944, 0.058297584631613324, 0.0330920748279563, 0.07043417410126754, 0.05472474492021969, 0.03186042859618153, 0.04760095503713403, 0.02389220188238791, 0.05053204311324017, 0.04519173842189567, 0.032661082954811196, 0.1180804552776473, 0.09775388027940478, 0.053441954111414294, 0.07881957771522657, 0.09255955221929721, 0.02386563384373273, 0.03964743896254471, 0.06061864936990397, 0.05398487372856055, 0.04303230411772217, 0.013880451608981405, 0.09056746839944806, 0.03756802090044532, 0.03395620613758053, 0.04410587543887751, 0.04671573146645512, 0.03085089401741113, 0.017768106123964702, 0.05367963135774646, 0.015630279767460058, 0.20882272108324937, 0.14589680837733404, 0.12253852534507002, 0.08650995112423386, 0.13552879329238618, 0.1976126576108592, 0.09103966091892549, 0.15451866787459168, 0.1550759215440069, 0.12375718780926295, 0.12394094866301332, 0.1355548897492034, 0.11583211592265538, 0.12198395867432867, 0.15876983904412814, 0.1453323486660208, 0.09072347038558551, 0.12534635753503867, 0.19844308947878225, 0.11073129677346774, 0.17149690325771058, 0.08347573251064334, 0.13472740272326128, 0.16436948999762535, 0.12458178427602563, 0.17979785640324863, 0.07649289470698152, 0.13091905707759516, 0.10930270914520536, 0.13811885645346983, 0.20133755701993192, 0.12158735495592866, 0.137445546154465, 0.11997027029948575, 0.11239436574812446, 0.17228103189596108, 0.09219264797866344, 0.10586556286684104, 0.09966525235878569, 0.2464309451835496, 0.18308554855840548, 0.13262108074767248, 0.17287621567291872, 0.11453816321279321, 0.17796307057142258, 0.10306792905820267, 0.1975804679095745, 0.10940158526812281, 0.10740982714508261, 0.1496655682900122, 0.1224651892802545, 0.15403127617069653, 0.09973701422235795, 0.11630645261279174, 0.16723378987184592, 0.1742446715278285, 0.12235998921096325, 0.15433204360306263, 0.10925375962896006, 0.076648387791855, 0.14531930722296238, 0.16986508082066262, 0.09579528216272593, 0.07274782245180436, 0.11451441448714052, 0.2320673902119909, 0.1067524217069149, 0.09604207891970873, 0.12987297321004526, 0.11955367693943636, 0.18053266911634377, 0.1825925385845559, 0.08317536541393825, 0.07111903985163995, 0.15204597770103387, 0.13069097431642668, 0.09807676116802863, 0.0899431686848402, 0.13841628549354418, 0.14081064558454923, 0.18453712495309965, 0.11046836445374147, 0.12705446087888309, 0.09664088607366596, 0.17346341987805708, 0.13996861076780728, 0.1697501234178032, 0.19486315229109355, 0.1627868070666279, 0.09916469029017858, 0.12344514312488691, 0.09628515730478934, 0.15331999505204813, 0.23040937632322311, 0.21291126097951615, 0.1279723151986088, 0.1651653437209981, 0.16507052523749216, 0.1350246417735304, 0.13142185152641364, 0.12442759397838797, 0.11375345103442669, 0.10980067242469106, 0.15038063563406467, 0.1231744076524462, 0.14806456491351128, 0.1426547544875315, 0.14304358219461782, 0.1756977814116648, 0.09332177774714571, 0.13604564698679106, 0.1877122481486627, 0.2134401790265526, 0.19609510047095163, 0.08436895600919213, 0.10900499512042318, 0.24094721515263828, 0.17796157779438154, 0.12752479421240942, 0.0942882491009576, 0.1515263013009514, 0.10949328927589314, 0.1890917776950768, 0.15115903743675776, 0.15141797997057438, 0.1943656639861209, 0.14659567230514117, 0.09342389048210212, 0.10564144953553166, 0.16739340844963277, 0.18159798266632216, 0.0774764312165124, 0.06842676217534713, 0.1171364773597036, 0.11613677814602852, 0.1498675953064646, 0.11807139004979815, 0.17046019674411841, 0.13029072007962636, 0.11861469303922993, 0.12315794639289379, 0.20130762005490915, 0.0967957413356219, 0.12268761305936746, 0.14759191099022115, 0.10891740303486586, 0.14032079758388655, 0.11516468173691205, 0.14717845246195793, 0.13176588235156877, 0.12008650334818022, 0.11738190347594873, 0.1026692558079958, 0.11795598481382642, 0.09758430759289435, 0.13278064504265785, 0.1223885283938476, 0.23179128074220248, 0.18539843016437121, 0.17547585974846566, 0.1593445853463241, 0.11260568190898214, 0.171195172305618, 0.23695645215255873, 0.12361816955464226, 0.07963859662413597, 0.10606916408453669, 0.22034875117242336, 0.16537923152957643, 0.11206014653933899, 0.1370005357478346, 0.14903676988823072, 0.11019349670303719, 0.12283180175083024, 0.1710690733577524, 0.11449380059327398], [0.07445743214339018, 0.022061254862429838, 0.03577173175290227, 0.032613972268466435, 0.0974212217011622, 0.04234689553933484, 0.006428162991401872, 0.03489367011934519, 0.011917760229802557, 0.057060133532754014, 0.04066981481654303, 0.01527057817604925, 0.034285366867801974, 0.023470502546323196, 0.06055220722087792, 0.04036723230300205, 0.025258094571264725, 0.028873127286455462, 0.002819606892964137, 0.021904447115957737, 0.03274804400280118, 0.007585106334382934, 0.007293985973644469, 0.03132976332147207, 0.019435398979112506, 0.01623609958083502, 0.02201868866437248, 0.031114932349217788, 0.031633136328309774, 0.017592502957476035, 0.03376616204955748, 0.04498724153797541, 0.004755256531227912, 0.006279589267381067, 0.031107071521026746, 0.03269414457359484, 0.022963821788185408, 0.02310523696775947, 0.025296179045523916, 0.022736388724297285, 0.019540480304775492, 0.020841360857178057, 0.03972399467602372, 0.02321715623007289, 0.02013748594825821, 0.033157655237508674, 0.05750912015459367, 0.025122903254149214, 0.009836789170679237, 0.05011759053117462, 0.032324963847973516, 0.04407857458240219, 0.006824360436959458, 0.008323188738099166, 0.019067527826077173, 0.03197047679818102, 0.1328787747770548, 0.010539476643316448, 0.05561246210709214, 0.057235548405775, 0.048182656323271136, 0.040869789264564, 0.02854552718677691, 0.03509014332666993, 0.03271661086806229, 0.01830616912671498, 0.02666199200653604, 0.11167205165007285, 0.05777226282017572, 0.015227898323376263, 0.03631009840007339, 0.04522858965875847, 0.009863676968961954, 0.057274876295455864, 0.039516122080385685, 0.016546537833554403, 0.05322734366304108, 0.02383711332056139, 0.030614112437303578, 0.008272446193067091, 0.054900753511382, 0.02297657315752336, 0.04369296991665449, 0.0025599438397746, 0.008785800343113286, 0.06342533483569111, 0.03526038097749863, 0.012136826108741974, 0.056542869324662855, 0.025450425322300622, 0.023587419219048958, 0.04035733247707997, 0.08752478166882481, 0.025788135593757033, 0.03732743273888316, 0.028195043493594443, 0.0555841671968145, 0.04721436310293419, 0.019666955839576464, 0.031675453164747784, 0.0818060478195548, 0.03706596266212208, 0.017234316195494363, 0.016702466877177358, 0.022276308054902723, 0.029554461262055805, 0.0551884693226644, 0.0284345833185528, 0.0380428020310189, 0.011253630509600043, 0.04750962083094886, 0.042081530671566725, 0.04727298852854541, 0.016015484097546766, 0.02892465523577162, 0.023793179874441454, 0.03402448711650712, 0.02963011452396001, 0.040522121491708925, 0.0307766588936959, 0.026671659434214234, 0.020940041901277642, 0.0065106741219226804, 0.00899704356145646, 0.08241280740393059, 0.05155478198347347, 0.031617641981158934, 0.059323773852416446, 0.031680185946502855, 0.07498268610132591, 0.0231712160166353, 0.038027670700103045, 0.025518704604889666, 0.02328952877516193, 0.05458204561312284, 0.035207672377250025, 0.009344511166481035, 0.030915046110749245, 0.04288881431732859, 0.02905277282531772, 0.0060058924136683345, 0.018248402047902346, 0.02365454668844385, 0.03810552580814276, 0.026234967866912484, 0.02935061916442854, 0.0698017862492374, 0.05734416150621005, 0.016475875196712356, 0.06771517571594034, 0.02684588517461504, 0.029405977443924973, 0.057148811274341176, 0.032027548378599544, 0.01961135328747332, 0.06117532628455332, 0.033617970001484664, 0.06975331849285535, 0.01240143271362675, 0.040037783195397685, 0.05232325342616864, 0.01858525736523526, 0.036082209021385224, 0.017842811133180345, 0.07055994056697402, 0.055621279669659476, 0.031651714617120366, 0.03594505673806582, 0.08162922159369503, 0.020869258824469786, 0.023121708405337164, 0.033046497630753686, 0.005135103827342391, 0.04284697924075382, 0.023080351695950543, 0.01298286852293781, 0.02481784069511507, 0.04776043790791716, 0.03720584944156664, 0.015986471636486903, 0.03056950554517763, 0.01586412498727441, 0.021173751414088265, 0.038193100930324624, 0.004819948059905852, 0.023380169179290533, 0.04946958619569029, 0.038227655326149294, 0.0523888406210712, 0.00965834379063121, 0.044946583719658, 0.008295577451852816, 0.039774552320263216, 0.023069225417982255, 0.0322651815201555, 0.026079345860385468, 0.04632782656699419, 0.07490882077919585, 0.03635135332920721, 0.03664727262886507, 0.010823308689785855, 0.037739761506340334, 0.0253847957189594, 0.023085500080404536, 0.04571211032037224, 0.058817953137414794, 0.04339870963511722, 0.04815151156591518, 0.03327668045780488, 0.017729205711345588, 0.05768453502761466, 0.02661779393175883, 0.07843332844121115, 0.014044229606432574, 0.05876890862626689, 0.06696835971836533, 0.03641537310821669, 0.061819948122969696, 0.01546876468429608, 0.037941242302102704, 0.029257025436631272, 0.019945986402620162, 0.01619319581160588, 0.04741301780034389, 0.0423576096072793, 0.01569986522996, 0.030930364038795233, 0.06807376111724547, 0.020046421459742954, 0.011565702335376824, 0.03858697015259947, 0.08995004224457911, 0.021892905235290527, 0.02354259858839214, 0.0382424100701298, 0.023937689173700552, 0.02508218097500503, 0.02641660320971693, 0.013822784614084023, 0.017923879104533365, 0.05740348582289048, 0.057729399763047695, 0.043428290369255204, 0.05175478018022009, 0.05327119738129633, 0.06750949139573745, 0.041280228311994245, 0.02281689181524728, 0.043932964360075336, 0.061105559313935895, 0.06769791378506593, 0.041678419802337885, 0.013553733604827096, 0.035810279327311685, 0.011192663290005709, 0.01914065015236182, 0.009503818466328084, 0.0828196977132133, 0.07071639038622379, 0.017852695692064505, 0.04252354534608977, 0.018159534316509962, 0.037862053872751336, 0.032732939813286066, 0.04029435085664902, 0.01792978405553315, 0.04891025281644293, 0.031129503888743262, 0.050305680438343964, 0.020763994294351766, 0.0789162078872323, 0.02542133822238871, 0.008955523155496588, 0.06968799592661006, 0.02719049614721111, 0.014089734709289457, 0.06753314512648753, 0.043913565043892176, 0.07884368606443916, 0.013889940921217203, 0.009188510876681124, 0.06479235219636134, 0.01594627182930708, 0.02757335953148348, 0.010926028713583946, 0.07725807864751134, 0.07399742611284767, 0.027345951912658553, 0.05393752894763436, 0.03527028080342071, 0.0521976667722421, 0.041148300748318434, 0.07297695694225174, 0.02593655664739864, 0.032252306318176646, 0.03399006164233599, 0.027633289440668056, 0.08091146725096873, 0.015886652349893535, 0.03772123750033123, 0.010561621481818812, 0.018966200495404855, 0.009285125781648924, 0.032849040547651906, 0.1139235869050026, 0.06483157152043921, 0.03680324408092669, 0.042433829445924075, 0.03185468479724867, 0.060639195410268645, 0.05024034430139831, 0.00806680173679654, 0.03207114764622279, 0.057752707440938265, 0.03481861736093249, 0.02694455604068935, 0.027290793800992624, 0.030840237624943256, 0.05182698987690466, 0.029491099662014415, 0.02479346432457013, 0.04063031729310751, 0.024657485906832984, 0.04316014690058572, 0.004580935795924493, 0.042673532119286914, 0.0712637035176158, 0.007539256875004087, 0.03205416391470602, 0.034217530329312594, 0.00587255519349128, 0.025615149876102805, 0.06363661706979785, 0.010584175137669911, 0.04748288315853902, 0.05597291347969856, 0.06204326078295708, 0.011603579856455326, 0.035636808457119126, 0.05586276010477117, 0.015844267659953663, 0.04430174475003566, 0.04871867184660264, 0.03489193306969745, 0.01646419252002878, 0.06368329349373068, 0.04256522096693516, 0.02805137218508337, 0.044677975454500744, 0.07416286652109452, 0.01213878792311464, 0.012942840894018965, 0.15581196919083595, 0.13500478783888475, 0.14025146487568105, 0.10002794968230383, 0.13490941295666353, 0.13765587843954563, 0.06539654013301645, 0.1783783340028354, 0.11976934250976358, 0.14644965156912804, 0.09988866001367569, 0.1324048452079296, 0.14924233885748045, 0.07432296685874462, 0.14314290615064756, 0.10776254321847643, 0.14844967424869537, 0.14332449569233827, 0.18203105085662433, 0.18291875108012132, 0.18352040808115685, 0.17291276156902313, 0.13352265022695065, 0.11629094130226544, 0.08349707922233002, 0.14006699834551128, 0.05935569892504385, 0.10063220547246081, 0.16107825588967117, 0.10130329696195466, 0.0624947240576148, 0.08715089530284915, 0.11919005002294268, 0.10563796865088598, 0.10746440850198269, 0.09006095557872738, 0.17318831464009626, 0.12546487046139582, 0.18496213214738028, 0.11175030709377357, 0.1924899760633707, 0.14505299579884323, 0.10847611100013767, 0.09403573907911777, 0.16325762894536766, 0.19070305409176008, 0.10196285335613148, 0.19270758224385126, 0.09702505903052432, 0.12499658630362578, 0.16491188375013216, 0.158621416294149, 0.12408511021307536, 0.06521972747785704, 0.2463334532720702, 0.1397522259503603, 0.2897025075341974, 0.0953901017616902, 0.1265306318444865, 0.1646417046764067, 0.10935666624988828, 0.07628125284931489, 0.07485700784517185, 0.07297322499964919, 0.11737841580595289, 0.1520494653710297, 0.1247956178018025, 0.1940334125288895, 0.14461517786341055, 0.15206154329436167, 0.1712170618453196, 0.11842136484171663, 0.21626961577151502, 0.26537917128631044, 0.1262532060167619, 0.22163271584681102, 0.10389558571789946, 0.15407523166920456, 0.10547784795718533, 0.0935176300949284, 0.23051818619881356, 0.23849083696092876, 0.13907179103365966, 0.15602155508739607, 0.14368595129677228, 0.1407784287418638, 0.22939119381564005, 0.12129882829529898, 0.1649193883474384, 0.16856770829430648, 0.1082746810945017, 0.12253710042153086, 0.1780418756284884, 0.10091296969247715, 0.10255756215857607, 0.09117808206272976, 0.19541081147534506, 0.12373563753707068, 0.1571064375873123, 0.11418413078146321, 0.17997563257813454, 0.16155720661793435, 0.1550156269222498, 0.18277821290705884, 0.16638879664242268, 0.19957226674471581, 0.1369496863335371, 0.1524543607873576, 0.15647043314363274, 0.12038433950926576, 0.16012761475784437, 0.11752139670508248, 0.19489961676299572, 0.07917306731854167, 0.12009539215692452, 0.14413660711475781, 0.21669260093144008, 0.06956702670348541, 0.17638122902384826, 0.09743053798696824, 0.15013419171529158, 0.15296988455312593, 0.14634014958781855, 0.10116966627538204, 0.13645393507821219, 0.14207650694463933, 0.07798724594925131, 0.09976371457534176, 0.16399848062012876, 0.1315545186932598, 0.09979469648429326, 0.12350688981158392, 0.1323979648628405, 0.1411491667053529, 0.16998474725655147, 0.09637829980679921, 0.1292899894927229, 0.10509519491876874, 0.11950180972261087, 0.11600617372563907, 0.07456970933292593, 0.07731147935347897, 0.20342422862138065, 0.0938643818455083, 0.07252667431852647, 0.06183007186544793, 0.1694430320390633, 0.11207867054534809, 0.10035694417144571, 0.1805730690913541, 0.09228054540497915, 0.11353857935007129, 0.1713239582521575, 0.08121722870107208, 0.08820681792816945, 0.13291754626802035, 0.16446559769766672, 0.15505282421197208, 0.17169114069214889, 0.11488835513591766, 0.1931951910789524, 0.09857203744884048, 0.12103501388004848, 0.12556148027735098, 0.1064296154571431, 0.08778139004217726, 0.14431385403232916, 0.10596726848078625, 0.18099144021315233, 0.17831225826271943, 0.07846836120422397, 0.09044797838266407, 0.163731490660991, 0.19472971159432614, 0.11044648848474026, 0.1391482347888606], [0.047885016937341006, 0.0004786427899879137, 0.016074769398463622, 0.02875913679599762, 0.06379981152713299, 0.04836011019402316, 0.021516075723671486, 0.03273021549518619, 0.012584709263007556, 0.02191193474988852, 0.03442604074786816, 0.01529274761144604, 0.0634269972464868, 0.03494463149192078, 0.06176985188254288, 0.09025139321706124, 0.029922471514769962, 0.04609596775844693, 0.028128348590273942, 0.04079168649124248, 0.025168205644669275, 0.04826306950833116, 0.008456708314562482, 0.0421981131657958, 0.04225163600806679, 0.005312198498618922, 0.021840032090299895, 0.01601929746435157, 0.02572337960425232, 0.020342939566554766, 0.040145558305084705, 0.04127787718815463, 0.02559289732016623, 0.01665366324596107, 0.028773888147303035, 0.019420917345477, 0.056043715216219425, 0.02901262730093939, 0.07948765650923763, 0.04037936111646039, 0.04529342707246542, 0.07326401118189096, 0.020474945161757723, 0.02021778717504016, 0.026658511121890376, 0.060102494566568306, 0.06977985599743468, 0.004811134314097996, 0.02278980639364038, 0.03557179801698242, 0.023448007414117455, 0.030807410100741044, 0.06285396763788802, 0.014061149725291346, 0.02178582901667271, 0.02582424383477441, 0.02067068385492478, 0.053627889669899426, 0.0860302404367498, 0.011295110203458794, 0.010841836936638823, 0.03845114101256643, 0.03340034685762865, 0.061063557996281555, 0.030409825899239098, 0.015816578342180167, 0.015073004045656748, 0.021685894379126172, 0.04695298462840063, 0.02408125191660864, 0.033763122212673934, 0.01878664655877011, 0.07104087940284184, 0.026148919448522583, 0.019598836012716805, 0.018673365137406757, 0.010124664437691016, 0.05530155057619725, 0.11463826069874422, 0.06828558617936713, 0.056100379675626755, 0.01328698537378971, 0.03980119499777045, 0.07750551322741167, 0.010481793533212371, 0.04507036207775984, 0.06134648674300738, 0.057199301065078804, 0.03697453685370939, 0.039421951597822566, 0.0032386395864055623, 0.029350768442132642, 0.06395639026803629, 0.01631033979356289, 0.028940743301063776, 0.0014957527351465874, 0.05428683538255947, 0.024015364469960332, 0.01882309915630945, 0.037920977853770764, 0.02219518749708576, 0.025917065728987967, 0.0522172967903316, 0.04217481227325542, 0.018777455801942518, 0.03124815591477922, 0.009403487733964409, 0.04622410570404359, 0.02998883223959378, 0.02389497878695173, 0.026768766277070557, 0.0832720295126949, 0.03445578772308571, 0.016257256302716475, 0.020056345034390688, 0.03779981864084091, 0.020542472966813614, 0.05149677741740431, 0.09371299389749765, 0.043755968500460894, 0.03784375039062329, 0.0541301378980279, 0.030874897193695818, 0.08617254958621093, 0.03367675827550037, 0.040595196320542266, 0.03587435678179775, 0.021701597375795245, 0.07972502841481141, 0.02181046492686229, 0.051529967957841497, 0.019516653547595655, 0.01674331977431263, 0.026807949978059957, 0.08261081749307257, 0.026118921415348138, 0.010599086792873484, 0.03437071300244757, 0.022790674918464253, 0.04576135499935065, 0.0135182012704068, 0.011622854491828807, 0.034038485293941836, 0.040566816593387296, 0.03303688278953944, 0.06241145424012627, 0.015499266529721873, 0.03711962799674698, 0.01666047064853566, 0.055523380637168884, 0.016425631374918988, 0.007503825472667813, 0.02017303100521011, 0.015270367830193468, 0.07032797658549887, 0.01699095282570592, 0.037249754049948285, 0.01778182270936668, 0.01653907903736191, 0.04898770419614656, 0.032615003641694784, 0.03485005049567137, 0.01095452718436718, 0.02236319785671575, 0.04247033802260246, 0.030373273217784505, 0.02565349728268172, 0.05426745981510196, 0.05185554941583957, 0.06150048705083983, 0.011213380660462593, 0.06062715141368764, 0.07951884197869472, 0.023148271354979703, 0.052429834314222844, 0.053497573626892905, 0.061019222518163066, 0.01968857566160815, 0.014260293816083243, 0.04173593921586871, 0.005711255969280111, 0.027561483472319584, 0.013781938502298934, 0.03137520481167095, 0.01821841249641563, 0.010467923429262425, 0.01813298663390534, 0.0237700876314193, 0.04599237920982497, 0.0152642270882747, 0.03333124824400459, 0.02846601984596678, 0.022842594721753682, 0.041168073258761845, 0.05217239812814763, 0.0541869652058397, 0.028018176555633545, 0.02132489000047956, 0.03617483922945602, 0.03209505243492978, 0.05693822793130364, 0.032414381192731004, 0.052464724584881745, 0.017914690044043318, 0.01241136052911835, 0.03141150643516864, 0.012155623225096081, 0.0656238290082131, 0.0503968823302005, 0.03379108124811735, 0.03949592209288052, 0.04788656738985862, 0.07370970012353999, 0.03243724103750927, 0.06786111502775125, 0.07171252729105097, 0.027732932308156575, 0.035689595088894875, 0.022752005207751478, 0.007220412421572421, 0.040699063068521876, 0.028420973602416258, 0.01891486592856901, 0.043276234064251184, 0.03905181074514985, 0.053996432572603226, 0.08696633377777678, 0.022575050060238157, 0.0339370443086539, 0.025631434716550366, 0.03768355845074568, 0.011638407362625003, 0.031248895517949547, 0.003318548111045467, 0.006606213972970311, 0.060109714179166725, 0.012142052524723113, 0.014256041097853864, 0.024110919163961495, 0.03480340460581439, 0.02675718198796468, 0.03926505733813558, 0.11727016232907772, 0.022294536898178712, 0.07597876193800143, 0.0026058486421659055, 0.03702481629859124, 0.023555421203907047, 0.06694092654756137, 0.026538932895553962, 0.039611588564834425, 0.014633125060104897, 0.03201916168576904, 0.02527832509284573, 0.08072382517691169, 0.024076715910008976, 0.05835319736174174, 0.056694549042731524, 0.051192498566316705, 0.042137503025255034, 0.0037797513318115045, 0.012510139112626868, 0.05707892216742039, 0.05200813837083323, 0.023928386458594884, 0.021687746779727082, 0.07149686172072377, 0.0018254712423575775, 0.022589063504710793, 0.060896930151752064, 0.06958403757640294, 0.036223625897296836, 0.0672216432701264, 0.021928736973287802, 0.023951056313567927, 0.02583927847445011, 0.035075799096375704, 0.022669005107932856, 0.059584595928234715, 0.05231272256267922, 0.017186284397861788, 0.04156986437737942, 0.047456949550126276, 0.009016100217455199, 0.06952360046229192, 0.009551405823523445, 0.031470532196440866, 0.01908097808648433, 0.03294597945309111, 0.05728970907096352, 0.024572931961821656, 0.0508419843390584, 0.06425005343875714, 0.05040143530017563, 0.029013102275452445, 0.0263220357841679, 0.04522772791928478, 0.013073914351740053, 0.05969666277191468, 0.04178897690560136, 0.04092085241739239, 0.012507027181397592, 0.01594752542275403, 0.016065062955021858, 0.03674507327377796, 0.05261092173999973, 0.0790858416418944, 0.04208741357017841, 0.05863040605826037, 0.03408473084813782, 0.015317524317651987, 0.07301220683647053, 0.01495547329873911, 0.014614762206162726, 0.03848821955866047, 0.02851517292271767, 0.007804160338959524, 0.08944397047162056, 0.03629947932703154, 0.0961328601198537, 0.03346373559907079, 0.014249976691124695, 0.013688924073773836, 0.03323158502046551, 0.037582728146974526, 0.02544219808519951, 0.03315566712990403, 0.016295025258191993, 0.08047485710786921, 0.008479978673027029, 0.041578329101737053, 0.07261252256908587, 0.05540063025962029, 0.052676963553364785, 0.044866326597652266, 0.03276703619797315, 0.04239994340709277, 0.00953629145598305, 0.021706129989719818, 0.0198202097588884, 0.10124944842287473, 0.018941215139680674, 0.049836836489183564, 0.03536078041153295, 0.026233203675863997, 0.049010577611625195, 0.04352479161960738, 0.0033886954853577273, 0.0810453218540975, 0.01945692889525422, 0.02263311399812145, 0.05693410922374044, 0.2134895763759102, 0.10229214640068156, 0.1182404945471457, 0.1348168607801199, 0.1756017008530242, 0.12128840599741254, 0.09509312055472817, 0.14570988555039677, 0.14218060778720037, 0.1375322357884475, 0.09265523244227682, 0.08073470887861081, 0.17665352512683186, 0.11021027008869819, 0.13753796262400492, 0.11658184283546039, 0.08538462793720619, 0.08585939210440431, 0.10024024971893855, 0.12697629364473478, 0.10425569782299654, 0.16591796119298252, 0.08326394137527261, 0.12332781084946223, 0.1649353610617774, 0.11212614764060293, 0.09088055124240262, 0.11240620618419987, 0.0964067711361817, 0.18182630970009736, 0.11566744904432978, 0.15978108692382062, 0.08494311877127204, 0.14063958690634795, 0.09673984362078564, 0.12190397296633039, 0.19810018502175808, 0.07924695978207247, 0.16281314779605183, 0.17236065119504929, 0.15295585244894028, 0.05077100279075759, 0.09881896991282701, 0.05542445701680013, 0.1372506573264088, 0.1353709524763482, 0.08892890132431473, 0.132630159546222, 0.10679918634040014, 0.1454153334988015, 0.10637867104794298, 0.1207128454531942, 0.10493610559829644, 0.13717463426291943, 0.1754069070198706, 0.1077382652355092, 0.09923448440219675, 0.13200240608836922, 0.23308649552719934, 0.12410704046487808, 0.12477193692965166, 0.1670747005513736, 0.11491488585514681, 0.11017073863851172, 0.11998071973877293, 0.09715689838464771, 0.17642682657710143, 0.1679448267178876, 0.1659313283328499, 0.09870925758566175, 0.14482112681227072, 0.1466723196208477, 0.15117110178938933, 0.16689680224018438, 0.14703156320112093, 0.09899576899728604, 0.10681228885161025, 0.10938509008181946, 0.16943604312837124, 0.22267727979591914, 0.1285591937069382, 0.10092936988387789, 0.12089675558464867, 0.15470002671437605, 0.1315950815166746, 0.15165026964885847, 0.17648329426135334, 0.12503264365451677, 0.12970762779670103, 0.07470652234873601, 0.13955439228032315, 0.1021759065666369, 0.10409272049686738, 0.09911362374467508, 0.16875279907669338, 0.13865328420485767, 0.3517301348703248, 0.07988770040018217, 0.16348736733198166, 0.1307761576026678, 0.23906965447323664, 0.12279235172484602, 0.07983674242028169, 0.13477939207639011, 0.12442810966500215, 0.08241731287645442, 0.15226110044334615, 0.07801102181630475, 0.1564632813845362, 0.09663362574896642, 0.07602643580841166, 0.10132187525076525, 0.1378013834889446, 0.1323825078351157, 0.08176568177129541, 0.0977035601224218, 0.1566605179437569, 0.20032972895673343, 0.20912852324545383, 0.1017235815525055, 0.12265117572886602, 0.09238040540367365, 0.20570635902030127, 0.14032381027936935, 0.2112252100237778, 0.11882418394088745, 0.08394482412508555, 0.1247693584965808, 0.12324333323964051, 0.2315138413437775, 0.19800966845027038, 0.12447689633284297, 0.158010938337871, 0.11383655121816055, 0.1712010484188795, 0.14662490359374455, 0.09510608735893454, 0.12317235847668988, 0.16585928148456983, 0.0681381065930639, 0.062020020958568366, 0.13307350075670651, 0.10896111426076718, 0.13209688530436584, 0.05976849927433899, 0.13777475777481282, 0.10759214950459343, 0.13931474728243692, 0.12894222672496522, 0.06132822058030537, 0.10124296162809644, 0.09908084371792418, 0.13881807321948664, 0.10465658309736423, 0.13738647289574146, 0.16298819626016275, 0.18790355431182043, 0.1425749994814396, 0.12053592423243181, 0.16422349640301295, 0.1442508181290967, 0.09231164266488381, 0.17542163122977528, 0.12571690550872258, 0.19983392341860703, 0.10369242554796593, 0.07099278484072004, 0.08526182666953121, 0.15059469986174787, 0.19545193069747516, 0.06593391951173544, 0.11738183562244688, 0.24980706402233668, 0.10287402410592351, 0.14535265043377876, 0.24058523029088974], [0.06782414165458509, 0.0549715891746538, 0.04222123085388115, 0.05902773580913033, 0.023498663445934653, 0.01172688663271921, 0.1190845649689436, 0.02646588351178382, 0.017327557085081935, 0.053988873692495484, 0.04452945092426879, 0.04088159577388849, 0.013002269535458513, 0.03313176573387214, 0.039448417856224945, 0.023657690001917735, 0.010704883124812372, 0.01105603517498821, 0.023140834611175314, 0.011855058505066803, 0.027937956753053834, 0.011674361236925637, 0.0625196737902505, 0.03457394102588296, 0.028747191186994314, 0.040595226854618104, 0.04996821783216936, 0.036581203674099276, 0.012563399022578128, 0.030943239240774086, 0.04165298491716385, 0.05146307797570314, 0.06600665168038436, 0.005003469730062144, 0.015369525545143654, 0.034145961848220656, 0.020294539663674574, 0.07214226387441158, 0.08086526580154896, 0.024198743647762706, 0.019506687564509254, 0.048941451856600385, 0.018416517580460225, 0.015684786485508084, 0.03365574065329773, 0.030066521106553928, 0.004835844439055238, 0.01901834930426308, 0.015971177457166568, 0.04790764268753784, 0.05804350719388042, 0.06153816610042538, 0.06613345630466938, 0.07550895107643944, 0.02254557280269052, 0.03591542511380144, 0.0317060177746628, 0.034702323244086335, 0.020048609735178094, 0.07243786086993557, 0.03629965913881149, 0.05166818554114018, 0.04380857192778161, 0.020963846606069376, 0.04063130116888455, 0.024596453378243104, 0.024752077081107667, 0.02822500590368041, 0.07112275143819195, 0.040751734349344454, 0.015035036618688276, 0.019505647709593177, 0.07637124016348805, 0.011889631560604488, 0.05797040183097124, 0.03657276609114238, 0.012089192102264081, 0.019536273387659873, 0.06503148150763341, 0.02098669796915991, 0.00694255657227976, 0.05984532979450055, 0.04375761394788112, 0.0638303252469216, 0.027461820248780505, 0.055510172953030894, 0.023327039887330363, 0.06940841914287635, 0.02477050439587661, 0.08217379344361168, 0.06868558257286038, 0.050536775894995244, 0.031724898011556694, 0.030783288180828094, 0.03158243619171636, 0.020854344624759893, 0.06181430271161454, 0.0129118360845106, 0.05096282803320459, 0.02563952624664775, 0.017941420931102972, 0.048602978233247995, 0.008689275344035454, 0.015987452119588852, 0.03351198961692197, 0.011385173852821546, 0.04850286378392151, 0.07988696758236204, 0.053050049248018434, 0.019749716755801013, 0.05026442211653505, 0.07098921574652195, 0.06187317240983248, 0.041722100494163375, 0.10141714156738349, 0.05446995162804212, 0.010088534144285535, 0.028092762821220925, 0.014077208952845206, 0.021929712367377112, 0.0328437174404306, 0.06951006368866988, 0.04077277572027274, 0.024260183297363774, 0.03854567451136453, 0.011626095344711627, 0.06324633051242147, 0.0586709553109748, 0.016248335263558795, 0.017152186316837157, 0.06398002364273582, 0.06396647329841341, 0.05752761023385184, 0.022510360227897763, 0.03376088983246258, 0.009528538345226219, 0.027723237739077637, 0.04737090791708656, 0.06637469585984945, 0.08945428420390401, 0.0830648931275521, 0.009140803079519953, 0.04998216851215277, 0.009363715403846331, 0.06157503769333873, 0.037639935434396775, 0.04124166716688445, 0.059292432319905074, 0.026784642300169383, 0.01739119179546833, 0.05250346893444657, 0.029645646190536872, 0.005635071753723813, 0.021987113037279675, 0.03212818190721529, 0.05484257931155818, 0.021285161775137697, 0.02008138636925391, 0.06634039591465678, 0.07732132489659957, 0.042778891644307544, 0.04811109123485429, 0.006971896850570504, 0.022726339620671103, 0.05273598592196192, 0.006106506858486682, 0.01651105554109173, 0.04616515797429851, 0.01656690236580159, 0.009286148673189538, 0.05550155895096915, 0.014308418912280883, 0.06038489405597959, 0.06292309000023774, 0.060632199714226384, 0.028631463646888733, 0.03239006589033774, 0.07004616742155381, 0.03911301799650703, 0.019637548131868243, 0.012618476558210594, 0.05732422614736216, 0.09252349486840622, 0.01774668986243861, 0.050349147391638586, 0.03161063610709139, 0.020395035788949047, 0.013727985638459879, 0.01678088347294501, 0.017346182871343832, 0.029389573859849145, 0.03758849569463304, 0.005501221391438905, 0.04098253125058753, 0.037739032081195285, 0.07803095717515264, 0.02814233658968338, 0.08448651220117297, 0.06092849560081959, 0.05794195085763931, 0.040025623847863505, 0.029150953449841057, 0.04088740064097302, 0.03309565070750458, 0.05120311085400837, 0.09758290981075593, 0.060670082324317524, 0.04605316576947059, 0.0702374464433108, 0.03872448545215385, 0.02085845824331045, 0.02332113154365548, 0.03440480260178447, 0.05760205231074776, 0.02971444624875273, 0.034316420022930415, 0.01372789149172604, 0.013808287713410599, 0.059315712856394906, 0.05979700453047242, 0.02602769577476595, 0.08225470874458551, 0.06898305232503585, 0.00807562523654529, 0.011493902304209769, 0.015783245309389064, 0.024186852321560894, 0.03359016363642045, 0.03149653705103057, 0.027016920104090656, 0.03442856150546244, 0.03779164568654128, 0.010904274880886078, 0.038377916906028986, 0.04921220089974148, 0.026920054141165953, 0.021798242814838886, 0.040218456714813194, 0.0465748200991324, 0.016359207885605947, 0.04461768761809383, 0.03828629771513598, 0.03402859903872013, 0.03450475759538157, 0.06792237316923481, 0.04634769746501531, 0.024882688286847303, 0.059706040125872405, 0.007958773872815073, 0.056912172186587534, 0.018519375007599592, 0.05685508703546865, 0.039363896141627004, 0.02758885218229677, 0.01691014609033508, 0.05460452887096575, 0.05859880668244191, 0.01252657238260976, 0.03286156291142106, 0.032723304616021257, 0.046883037846003256, 0.06181017043335097, 0.03805441176518798, 0.016900934977456927, 0.05256016732060483, 0.022407835282917534, 0.012313091695042593, 0.02100155788606831, 0.0246340577889766, 0.01730299072473177, 0.006208742153830826, 0.021900287696293423, 0.02459109464793333, 0.062264497125787396, 0.016006256021293144, 0.06596844337348427, 0.04187640275007912, 0.020771729593564357, 0.03143846123878445, 0.017083147075027227, 0.014892415343118566, 0.04503587553543704, 0.0056072929541447335, 0.01606623173159148, 0.042139243467577865, 0.05487176310271025, 0.0036299935641831583, 0.08765991191778864, 0.030711736663111618, 0.036404397804290056, 0.030432658602616618, 0.06585772681449141, 0.02681871154345572, 0.005949634651187807, 0.05073783599904605, 0.038126146487359486, 0.041764305372323306, 0.030199520755559206, 0.02001637084010456, 0.02883933624252677, 0.07047909311950207, 0.024534301266872456, 0.028826461040547917, 0.009849785660792674, 0.016854063474706242, 0.03838422728170242, 0.03612305682950786, 0.028741030089024986, 0.07635134551674128, 0.03336956172383257, 0.03632630181631871, 0.04265303357637354, 0.030755003448575735, 0.0549401628252651, 0.052504235679017644, 0.03325726417824626, 0.04818176404972162, 0.06954290478357247, 0.059690101338284354, 0.015450722438150218, 0.014792241521977952, 0.010936350079386361, 0.01068400714679488, 0.05108479470280664, 0.017373688984662294, 0.0907128309564931, 0.04893916519358754, 0.055826892743685415, 0.020995215279981494, 0.034306506626307964, 0.044906940311193466, 0.01647819409013859, 0.023979587014764547, 0.020915628211306672, 0.03900668816640973, 0.04108940390869975, 0.04496372012155397, 0.02087902294338814, 0.014678144162254674, 0.020265929234613265, 0.040608047773795466, 0.020264141294839125, 0.026626777735405734, 0.028948519312377487, 0.02994124318606087, 0.03772547495152269, 0.02120319304854742, 0.01930438065236168, 0.022329596802592278, 0.02208819779168282, 0.028409077187201807, 0.006277305148874542, 0.22233342538986886, 0.23905730513589724, 0.0923507602087089, 0.11663973544325147, 0.13038013742438384, 0.12357555755547114, 0.1931044573762587, 0.11175241733768157, 0.24966221036655561, 0.24502795189619064, 0.1295904583696808, 0.12232975369053227, 0.059998101953949244, 0.08418725111654826, 0.14881906871284756, 0.118132512484278, 0.09876048019421951, 0.0815228069467204, 0.2411622293293476, 0.1383872984775475, 0.14686764271131583, 0.11523315949099404, 0.1781777319099222, 0.15894262120127678, 0.12051309831440449, 0.11958760369036879, 0.20781829926584447, 0.17535183711775712, 0.10383290265287672, 0.24530381709337234, 0.1892958538872855, 0.09517936235559837, 0.1787622898284878, 0.1365749721548387, 0.1607214550354651, 0.1311557979456016, 0.12698991862790926, 0.13111239884580883, 0.12583022085683687, 0.0992890250469957, 0.11646892103765692, 0.08859939793390886, 0.11895381127085004, 0.11626742327851908, 0.15111194710646356, 0.17210525061403, 0.17474441256906303, 0.07398165017366409, 0.09072133978562695, 0.16496390024466173, 0.12293206208518573, 0.12273728182273251, 0.1235539937125785, 0.16104956742908272, 0.11592956712203366, 0.1500630269625357, 0.05089328497914331, 0.09545594679989985, 0.15020713422979626, 0.11734499117093426, 0.13430459398244107, 0.2910777080271925, 0.1280645009662424, 0.15767665127558367, 0.11975480828966413, 0.121902358052986, 0.13181309481816633, 0.18044942644025597, 0.2804197684994766, 0.1352242532053164, 0.09840748592146806, 0.12964233915720666, 0.23112514934369496, 0.15357215223567827, 0.1035370138872947, 0.143236761114427, 0.14378338892545017, 0.14363470833216394, 0.1161257858787264, 0.1322347093373537, 0.11025551480374166, 0.16628720637943062, 0.13079052897436277, 0.10467440821230412, 0.22585336651120866, 0.1671370036367859, 0.15015336711491856, 0.13357082621327468, 0.2364650299506528, 0.22461761853524617, 0.10552222414740495, 0.0782376660832337, 0.0650266164115497, 0.1315701249986887, 0.10176562358226095, 0.0661984531741057, 0.11903093356106963, 0.15845707511263235, 0.1360465833651168, 0.11426639636712414, 0.04224283201619983, 0.16444418313247816, 0.10939073549317462, 0.10813187661447696, 0.11589918232389859, 0.0994772370904684, 0.08393663420741047, 0.17846496935401643, 0.10167155148727552, 0.07220095715352468, 0.16727809820856365, 0.16399511508643627, 0.1090585451040949, 0.13716182352176734, 0.15903049148619175, 0.16598628966936044, 0.08984623317207609, 0.08923338034323283, 0.0948905846370118, 0.13484377147895948, 0.08383129843111549, 0.15145303308963776, 0.11393730688307967, 0.11473773393247809, 0.1643059519784791, 0.1394254977681807, 0.15715241512017591, 0.13533703929611615, 0.14801773242652416, 0.08483506885490247, 0.16875910945236683, 0.20608008253787244, 0.1513130377445902, 0.1777043587395123, 0.1445400504661458, 0.053827609667288404, 0.07710295197154794, 0.24806572603327887, 0.14309010255549634, 0.20378197942461285, 0.26498217401759966, 0.13336609862744808, 0.23179920603122028, 0.12389794311353139, 0.15199694676058634, 0.11684643078063216, 0.09671668522059917, 0.17957109000001634, 0.1458479809973921, 0.2952016538807324, 0.17360204458236694, 0.17150617204606533, 0.05910318890320403, 0.11082031378256423, 0.15583661358271325, 0.23841902081455502, 0.08071279898285866, 0.09768362476357392, 0.12287228315004281, 0.14909164980053902, 0.13134000663246426, 0.11993236733334404, 0.14988865703344345, 0.1237482311470168, 0.13480478285678796, 0.15965698286890984, 0.10142047995967524, 0.08109981500144516, 0.10922795494220086, 0.14012003264256886, 0.0888200303805726, 0.06542746097381626, 0.23003971044506344, 0.151993988347905, 0.1487339532801083, 0.12395514361560345], [0.02224925147103412, 0.028762492151664834, 0.03908464166202715, 0.03736928477883339, 0.03954555692949465, 0.022310938785916994, 0.03255606948265007, 0.022534120827913284, 0.04070672372888241, 0.03760544549939888, 0.0017964454226395382, 0.0706103014360581, 0.029483133660895482, 0.063811054852392, 0.029435856733471155, 0.01690942345054022, 0.12142977198319775, 0.05477462402944054, 0.05035155279827969, 0.009546796026240503, 0.038767121200050624, 0.06507533522588865, 0.03770482713090522, 0.020750566086332713, 0.0192897870604481, 0.08490153135997908, 0.07124746617461954, 0.019265030710292712, 0.029308926580207686, 0.07106567307242326, 0.030427406741572276, 0.042504607433719296, 0.04063920270917671, 0.02251951875431197, 0.024100245808118155, 0.022521730778472762, 0.025416440895891616, 0.02246904423061226, 0.02432240665491138, 0.029756508634558747, 0.037037884883050404, 0.026531647125791227, 0.0547091284367655, 0.054765463806688786, 0.023494834812091928, 0.03820903293256249, 0.05419866654223629, 0.023333299372877394, 0.03468915627204946, 0.0531465572837208, 0.03919224035260933, 0.026832965867859975, 0.04890945893047111, 0.03986024111509323, 0.049396643681185584, 0.047848240339330265, 0.029593683978808776, 0.04125316494277545, 0.06237238419375249, 0.02150528532053743, 0.012558264208824506, 0.0054409780838925925, 0.0194079420595829, 0.039455620505447896, 0.013033306575380266, 0.016994901899514452, 0.03817750480292099, 0.016407957234020745, 0.0012457938989557857, 0.010169755634186524, 0.023808565655989305, 0.005821657009489302, 0.034586799264486344, 0.006986908589689327, 0.02243374174992953, 0.05928750615566969, 0.0333680926955172, 0.05220866921756949, 0.027191164504204477, 0.05341948103159666, 0.03674150417957987, 0.031191691623202393, 0.06389836195324149, 0.07510054084871497, 0.014813045405649712, 0.02973829336198313, 0.06854422337242536, 0.023537560465878675, 0.035928809217044284, 0.012750283681920596, 0.030669647135904858, 0.056418520997145345, 0.028525534152452434, 0.042991473272975, 0.022034469692568694, 0.053311305586248636, 0.008469735338751758, 0.03340807876416615, 0.0358796527476183, 0.005677534475190831, 0.027119448441745977, 0.05091745100383248, 0.07489402871578932, 0.05369482036413891, 0.026297581382095814, 0.030994631483086517, 0.007286831670041595, 0.024744195896866064, 0.03781662256057773, 0.014510369593543666, 0.08853721698479992, 0.03567188871758325, 0.025029270510588373, 0.03140347936589803, 0.04591360468683498, 0.0289970583149365, 0.023982082327295626, 0.029433607389884334, 0.012297848405848657, 0.008976159949920006, 0.013817144291741508, 0.04075091332197189, 0.023195304009797316, 0.016162980647225465, 0.017499737042401518, 0.0626222954264709, 0.014019647130875714, 0.031408330891281366, 0.01679844395922763, 0.019305383187851737, 0.06344117184302636, 0.011372233341847147, 0.029268977830984762, 0.010200152306684425, 0.05276725281562124, 0.0581391059926578, 0.03138306563986199, 0.007924612179132444, 0.0324483690118151, 0.018697794094415646, 0.04720755061134696, 0.03676371602341533, 0.03559152302997453, 0.03206762604947601, 0.056090523954480886, 0.02045696398376354, 0.051681064135794125, 0.014213295936185335, 0.018588110604988675, 0.049312573192375045, 0.042819902300834656, 0.03703460077356015, 0.031441701243498495, 0.035964469624949355, 0.035814730517034016, 0.03897882751854403, 0.006513884016645274, 0.052560547300215275, 0.035556045826524496, 0.03025227685325912, 0.047325154300779104, 0.04376941706453051, 0.01803460414521396, 0.0689040504928146, 0.05983382862593446, 0.048952993737267594, 0.025476589632619704, 0.025755492970347404, 0.023433999058657458, 0.07056298718920775, 0.023024640578244413, 0.015245626747076, 0.03373180782156331, 0.05761691222765616, 0.007178332224222166, 0.005562095312468175, 0.01929626876621374, 0.014125369672131325, 0.0348845268599689, 0.05199162282847932, 0.021169203533125774, 0.026483321861763085, 0.0827477051477347, 0.046102091536990235, 0.059893750053431304, 0.09546664729714394, 0.022784987098670433, 0.019299724205796207, 0.008330221753567457, 0.03673605215070503, 0.020587529388389418, 0.017467257267396365, 0.07608554299388613, 0.021095709708918418, 0.0715438841975161, 0.0198855221471084, 0.030009734510843242, 0.02402482324812029, 0.022914051244567548, 0.023288594093173742, 0.030751800763287714, 0.09242503943720035, 0.07482324394264392, 0.012836578917423529, 0.04164656936856253, 0.04030821332708001, 0.031069470502968346, 0.011592511253963624, 0.06306798436811992, 0.013341249515568572, 0.0344953531000231, 0.041174515948763916, 0.011576759911674474, 0.04751093379620995, 0.011713962236951505, 0.025961414777806828, 0.026862621240850006, 0.002458727831253782, 0.04039872989856771, 0.015230880484783223, 0.040470094819154055, 0.017630239682538167, 0.037130806861179214, 0.01959540941087263, 0.0582109967778836, 0.058634884389383454, 0.06645607256463595, 0.01909059123136103, 0.043846010097435544, 0.03565744949238641, 0.01445425474750144, 0.028255516230793934, 0.03640577183770282, 0.1181711618389402, 0.09170431989644255, 0.0077560496616310304, 0.033323424735239575, 0.017672395366909247, 0.05151976279116102, 0.050451026032013555, 0.02353276831230947, 0.05870187615177461, 0.037181133803512366, 0.02136958679849548, 0.024315378728455732, 0.005302408934637372, 0.02184928730795426, 0.012783802463673055, 0.033975591883063316, 0.05093795293942094, 0.024775783398321698, 0.014477978028090937, 0.033822935074567795, 0.005994486664089241, 0.00710234690424321, 0.013013716421223112, 0.019554783822968602, 0.009353406760575516, 0.021383099823391864, 0.04593752643891743, 0.0654556066063898, 0.05284195612849934, 0.08305669642452683, 0.05348774504714778, 0.0313946075205292, 0.06559172073113066, 0.03670630856816258, 0.08234390895813704, 0.012599323210971696, 0.046550922095775604, 0.02976350433060101, 0.010342503864584225, 0.040621828820024214, 0.020965162964005555, 0.029599224217236042, 0.027584548573940992, 0.025771060260012746, 0.0516253021279616, 0.08354672084429435, 0.02707609175039189, 0.06388164285038199, 0.015054417275158423, 0.02919874945655465, 0.0334004723866071, 0.033237274536596875, 0.021492381280820285, 0.01440234512223729, 0.019813790817611983, 0.07880876186702933, 0.051239337838654, 0.06634693020688635, 0.030487640295177698, 0.014151277835480869, 0.05359166268525379, 0.02142994079206671, 0.003245781167476837, 0.045640874321439436, 0.02924032329714724, 0.008244090214637774, 0.03293905161055071, 0.03896393706755979, 0.036138598674110005, 0.053802826175732274, 0.02434877452573606, 0.04586462124383875, 0.0979207931086421, 0.009401630244350858, 0.04691208932282669, 0.05220533421795283, 0.05672174811895404, 0.008549569224539613, 0.01597651413508824, 0.00534808833617717, 0.04593636614403554, 0.0224043628799596, 0.060570575163832734, 0.03182607436818736, 0.0398782765758889, 0.06169828000877585, 0.02800043286489589, 0.03363170355026211, 0.035720261479062695, 0.05238752765581012, 0.048008914039071114, 0.035521806949483495, 0.07750847842544317, 0.030358158850244114, 0.016154999379068613, 0.020292766990938356, 0.059418694116175175, 0.04626052946384464, 0.020138130556525927, 0.013410249741614928, 0.12097949614482266, 0.03148618260664599, 0.02315917032371674, 0.03520718722471169, 0.014046740186001574, 0.029639692045748234, 0.0713679739939315, 0.053843022590237, 0.06148435827344656, 0.05968795716762543, 0.03469434706494212, 0.011339345597662032, 0.019051522881324803, 0.030058487251933132, 0.015594520971977284, 0.038278952573559115, 0.03782996255904436, 0.02503988449461758, 0.0014159522460041834, 0.22411094286612102, 0.1401514895260334, 0.13292802284870828, 0.10562660997467381, 0.08809525998575346, 0.08897567274315016, 0.12991629088563578, 0.12254236585327558, 0.15748795068689755, 0.20925749918179853, 0.12792534700461797, 0.11935124280197279, 0.0890406696125865, 0.08239639364182949, 0.1329790215407099, 0.10507015697658062, 0.17776723179434026, 0.14806451063070977, 0.11304199349667345, 0.1326570702450616, 0.10355349550289766, 0.10245857068470546, 0.1789052164448159, 0.06803515926003456, 0.10329168955130236, 0.189902057072946, 0.17364073464913027, 0.1674113624862262, 0.14000120759010315, 0.16797548293003015, 0.08113974678729262, 0.17213374908481324, 0.1309742626867124, 0.07942020334303379, 0.07479969877749681, 0.09822651384664433, 0.06811663774507386, 0.10002931353769132, 0.12179794508431639, 0.1741980290306466, 0.12026821502617427, 0.15946237902556146, 0.12640559141124996, 0.14891162088939122, 0.10778955569756882, 0.0979261128231883, 0.2029275002756289, 0.08840630722365209, 0.10244521711553846, 0.17626462956624372, 0.12155059192861829, 0.09390719061983482, 0.16900889176343167, 0.12636995475207055, 0.15283653885126114, 0.14704278617032937, 0.11107914096542768, 0.17723413397158894, 0.2378925047814846, 0.1921386034893138, 0.12797148738588604, 0.11241443002862589, 0.180766600849373, 0.16048794399414743, 0.14932122533874853, 0.14074603548007353, 0.1269086165619748, 0.08439024843807731, 0.09826751771782126, 0.08211751574916498, 0.10665668720113379, 0.10032218282244035, 0.12408965639770031, 0.12834415238882813, 0.15852602784122738, 0.09481359805379595, 0.12143844366073608, 0.1081799983179995, 0.13774298876523972, 0.1079658798075148, 0.11132217185305697, 0.07042442355304956, 0.1682753139840705, 0.14806185077343667, 0.12237243354320526, 0.10868936777114868, 0.13672791394804204, 0.14281138751123632, 0.11110742909035512, 0.14114687325698988, 0.1887649138058935, 0.1836579471294369, 0.1519041367407356, 0.08116859131093536, 0.08549347173954759, 0.1726588537650449, 0.12429046205111913, 0.10872858709522656, 0.16332846800131456, 0.07562932997409787, 0.11892141800905977, 0.14577407496316092, 0.14340161798255785, 0.13736884455595696, 0.18233401674245084, 0.1206433634672846, 0.12020376777010304, 0.14427293837070465, 0.08087792047964674, 0.08768139433647905, 0.21565744147769042, 0.09571199198918683, 0.1238795141024249, 0.17929051576980523, 0.13645407078521593, 0.09359885073666062, 0.10822995206607239, 0.09246052681867566, 0.0928091173991561, 0.10738294358764376, 0.14803742351276533, 0.11858419967549187, 0.139181360868471, 0.09740718959697656, 0.08385924728853361, 0.20307767364595616, 0.1950249828930412, 0.18836902933461325, 0.19577618901218685, 0.22736932230847223, 0.10603061651012727, 0.12274737842381, 0.11450477928987571, 0.11166802793741226, 0.18534051041517938, 0.12637015831257614, 0.10616673063486814, 0.09075021823602063, 0.10568356620413916, 0.15160400713128702, 0.21609132391001495, 0.23957293746726854, 0.2019486999405282, 0.167366891301104, 0.21220576097922667, 0.11900814835514341, 0.14181068406573363, 0.12213447131216526, 0.09238892780350787, 0.15815021443579877, 0.0859314389526844, 0.08419549531702485, 0.09634357916989497, 0.2271375483168023, 0.1542897437300001, 0.18300476217908518, 0.10238687667463507, 0.2116137391754559, 0.11950980286513056, 0.06407261653138058, 0.14790920753564152, 0.10962263162114791, 0.17886603783283914, 0.1500779411622456, 0.10561288321124655, 0.20406206510961056, 0.07418759912252426, 0.14127485853220734, 0.21070994410131658, 0.09262207243591547, 0.09371028654277325, 0.07130575911807162, 0.10894580651074648, 0.19122833519109658, 0.08018266635813884, 0.06384300706642014], [0.009815686731599271, 0.055001739878207445, 0.014391826133110693, 0.04243288967492325, 0.06189998132841928, 0.030576219649187157, 0.01159834411061768, 0.0657181114490543, 0.03262696960674865, 0.004918248700310609, 0.06839105087731566, 0.015263065097055264, 0.04443490385477032, 0.044000946783593724, 0.036601644541536055, 0.0170799986725407, 0.028874881299478666, 0.040118617072169266, 0.039267405069300106, 0.024967379635199904, 0.010429524284388338, 0.013643657306342252, 0.02236254307042275, 0.011106428274485682, 0.023698444511475306, 0.011676354433542915, 0.02896035635577781, 0.021124779845454862, 0.01613798680981355, 0.06022201172475304, 0.0342485054529139, 0.07347241642751864, 0.012688974650310618, 0.022367596459974135, 0.03641168527039034, 0.03153508123276489, 0.0033673657370465143, 0.05920593946107796, 0.01427525551324444, 0.02209235551500959, 0.017198599808450257, 0.06339798987443958, 0.007215861147934837, 0.04682487043152962, 0.03810458603714194, 0.017542160748104964, 0.12077360147876398, 0.05382049522761788, 0.031863878946751356, 0.03678676246532372, 0.029168211988040378, 0.029640760738402605, 0.05001651595479675, 0.06852402338492018, 0.01921855954320303, 0.05208308256364294, 0.013647524107779776, 0.06261523187692676, 0.05969848803111485, 0.06223859744412558, 0.01996057660185865, 0.013171489383759243, 0.020637588309390203, 0.04638703892539654, 0.023243871850094626, 0.0145251871020134, 0.03839695320597716, 0.03367266670933791, 0.038832209671714475, 0.015190926646547658, 0.030703896190971136, 0.010302513555091406, 0.04793094697275332, 0.011043665481598249, 0.0441563380882144, 0.01094881137500384, 0.08745805453509092, 0.02393903097669993, 0.0351733927881079, 0.0018173489661421627, 0.028683673523898636, 0.013072435993568172, 0.026890030662928308, 0.058616116110767634, 0.0023742423758709003, 0.054896899432476075, 0.01607008750683495, 0.01147614504277174, 0.08809949404426984, 0.018832866667902896, 0.00442053732695058, 0.03626132191025785, 0.0480928115014519, 0.0508571937015014, 0.009603640297427773, 0.027468522478427206, 0.021735122094729116, 0.0436111284153802, 0.01959643230241324, 0.055422842103455744, 0.014504881941580346, 0.05983148768012013, 0.03407366054930857, 0.030032923445105553, 0.03397406178659626, 0.01856888092256018, 0.033101699847195826, 0.03261945822409221, 0.01693504154016929, 0.03778936920155372, 0.0435900972224772, 0.07483104031000819, 0.021982839962999736, 0.04173658721681152, 0.0017846978610448006, 0.02840306027792394, 0.045746668108872006, 0.01274207086368863, 0.033327088824340274, 0.012555599262538766, 0.011161024050254906, 0.009300173992025, 0.03894229519313999, 0.023356215196794698, 0.061457149019198756, 0.03239186400813716, 0.02439668418706528, 0.04756041256976979, 0.04646475493375744, 0.03673109205971871, 0.04520744990025248, 0.04805186530575156, 0.025846842443570495, 0.09020409254091126, 0.011428547507551099, 0.041830927333129306, 0.017559047788381577, 0.05493590501802308, 0.01857422268949449, 0.04031714963327561, 0.012505368163276995, 0.03718692170722144, 0.015640802149261748, 0.10091358715934412, 0.040427764412015676, 0.05549648350902966, 0.0311503213431154, 0.04152753736291613, 0.0641856197533863, 0.06015037878283432, 0.035414744301566055, 0.04702969979760902, 0.054679052372063906, 0.049398384123508415, 0.05126672690468175, 0.020088258232655268, 0.059524857705192905, 0.08377998082765512, 0.012701379966789057, 0.03808271006814071, 0.035671803900705915, 0.020961241031597768, 0.01717592486446457, 0.041675987254296026, 0.03913990155394588, 0.03985805623233318, 0.006157338461239955, 0.0295946271424847, 0.020934301495019878, 0.03754210764808314, 0.008879690929981214, 0.10199218642498765, 0.0034502615121060182, 0.06504125241190195, 0.01872088124842516, 0.023635936169219867, 0.05320596641727856, 0.016762344199897986, 0.01627123073142554, 0.0224130481281983, 0.054921163844742944, 0.01004879828542471, 0.052269907003002505, 0.023688347910397818, 0.04262731031381658, 0.03528644011488982, 0.025362968943747025, 0.04369172480489526, 0.03242202149704099, 0.04348032382716026, 0.04650124654706035, 0.04973937850445509, 0.024783667975238392, 0.07017780321517161, 0.028652759468449012, 0.020628877616088306, 0.05103439312162144, 0.008265301219320722, 0.043348087530050955, 0.006086519337259233, 0.027104985467823486, 0.03692004031368664, 0.032543899957090616, 0.02518311475536653, 0.04361015132495335, 0.05568752843620522, 0.016175267220075642, 0.01232915770794664, 0.07603091413953475, 0.048338241010372124, 0.030799403387520994, 0.002187613015329199, 0.02925083041191101, 0.01703125610947609, 0.048298736701586416, 0.03750923941177981, 0.04151681650962148, 0.0317335289769939, 0.025962895680485026, 0.06527796613850764, 0.03341618386496391, 0.028863173177731887, 0.05893970946116107, 0.06273174991032907, 0.04822251347026654, 0.06451622237052236, 0.04619539010205439, 0.027126062461840253, 0.030782650357910564, 0.01761285731169794, 0.04872816115883844, 0.02750105144722121, 0.04498377761670521, 0.023575817966567617, 0.05634533760270902, 0.011701177789031394, 0.013823597159768854, 0.04426883240895612, 0.04233946218820555, 0.025502457083868127, 0.0443642785373543, 0.013664263566689832, 0.11526008376053401, 0.014079038452889239, 0.037752982761178694, 0.018469431437551975, 0.05681070066722376, 0.030274037471307174, 0.022687971858041625, 0.05013218242675066, 0.019402298344565288, 0.06871265612010445, 0.07009671149509293, 0.027626261514212404, 0.004020992583329124, 0.002414103551667982, 0.06364754826894828, 0.03373399270432336, 0.027315729962927953, 0.03541703435725399, 0.05274922753285084, 0.07592050970665046, 0.04616853368601628, 0.05510129453614354, 0.033460122400096486, 0.05186790893120425, 0.07328010603253331, 0.03810080998976316, 0.02403463825716504, 0.01643015381081828, 0.02142891281151346, 0.030198357068002224, 0.030799318570643663, 0.018477796077994362, 0.002127903842067878, 0.04219036429588284, 0.014498405324827348, 0.04858807760423847, 0.03258624054225428, 0.08335458008306366, 0.033596087247133255, 0.04022642610860722, 0.03916033902870757, 0.04014546670285719, 0.048287493376327414, 0.05144066935671227, 0.02402531518600881, 0.04403833406312125, 0.024359907589054534, 0.021203878368916254, 0.03637740907392331, 0.01953588831903679, 0.03101069579965302, 0.028881167926426445, 0.06840557831206492, 0.013656035481419946, 0.03610729446102466, 0.06433283471103225, 0.05817864422819444, 0.03460751833128078, 0.05650176028055804, 0.04724356385746172, 0.07172073077942644, 0.06360437987106186, 0.02441922342404723, 0.04137983046738165, 0.04333620638187442, 0.020095287855448465, 0.01313606052592929, 0.06023921258747578, 0.03283303729923708, 0.1107534102297255, 0.027645479322278073, 0.027263270724298697, 0.015461036170433675, 0.00792711427701371, 0.035397604506994994, 0.006391121340649468, 0.02032464456611446, 0.05189948116562196, 0.05044718213113291, 0.09128387245748724, 0.03144754343000906, 0.08053590490349702, 0.058811405274484835, 0.06593778037599154, 0.031159800477325916, 0.029755178705922196, 0.029270935404513563, 0.03142556907343013, 0.028430157573893666, 0.04400846155892525, 0.03625855688005686, 0.07970797682979278, 0.029461376435522522, 0.05460909880431635, 0.023729402671701143, 0.022687932842278054, 0.03935575372140322, 0.06611827747630221, 0.03241034730204514, 0.042431003347571404, 0.02220523320803685, 0.025846716914592043, 0.08505549095571041, 0.11130987679851906, 0.02327304715955896, 0.057956077956727574, 0.05356667224051697, 0.027482027021635855, 0.06925565376877785, 0.0367750238095011, 0.1977154692368848, 0.12645998277834483, 0.08184675313532352, 0.14794017587389263, 0.1980096005967685, 0.06831006093748979, 0.10847726450966937, 0.12377074493893556, 0.10251077038369008, 0.09732272555785519, 0.08729195594787598, 0.17301159697983945, 0.09402383078954049, 0.10961934751165764, 0.14082207211426326, 0.19588668165462358, 0.20143302689705575, 0.12791506041373524, 0.10392431489058904, 0.1289510748216084, 0.13157635395015987, 0.06590033881366253, 0.12320107407867908, 0.05776144697197846, 0.11761887504586152, 0.10465496818401984, 0.05884810723364353, 0.09772511717996427, 0.15399075405938284, 0.15882033562021597, 0.10643690970859357, 0.159614927268454, 0.2120821861816304, 0.14244740775653295, 0.10845719344381775, 0.09913097388510193, 0.11230814430330481, 0.08941246609070472, 0.10106843563594989, 0.093084880816085, 0.1102159833535552, 0.15019786544144154, 0.13751027839524405, 0.14889382970120224, 0.13948256256324904, 0.10800425096281938, 0.1817011878426586, 0.18296118666018757, 0.12995199539831706, 0.09909773923988853, 0.12520318664610386, 0.09629944725228207, 0.16507394505398615, 0.12953082871224197, 0.12886198317365988, 0.08964866413069622, 0.1361656662608896, 0.16775061642485006, 0.11786700173148087, 0.08946835702019078, 0.09883244561829738, 0.12354068085551262, 0.09860902439270701, 0.11833041400781699, 0.09342667247567858, 0.1992881234203066, 0.1855088820947068, 0.11105873063206673, 0.1092441040756447, 0.08438956990305867, 0.12032785825431347, 0.06119568233511277, 0.17915700721953595, 0.1079395255073905, 0.14864478020795754, 0.13910662702151708, 0.16694600959973677, 0.09679301362484694, 0.14551460317202977, 0.09362337977758475, 0.10670531780592032, 0.11028803698718548, 0.1930986355457987, 0.1292885917105845, 0.10533960323248591, 0.1472017533544983, 0.16090915139232362, 0.07794152625969478, 0.19121073399271282, 0.11713184975087643, 0.21569366167698587, 0.12453481608203479, 0.08856432445879493, 0.1763660434101309, 0.08499274682253599, 0.10951513810349361, 0.07311165292880364, 0.15314935706555843, 0.14168941628720078, 0.20085084385105542, 0.07910373461033617, 0.1821632973317589, 0.23879427782126836, 0.0969986572329487, 0.29624825343489647, 0.11332708677010876, 0.2135680421654667, 0.16472022474876472, 0.1389998798923833, 0.20826962004814828, 0.11076316077794347, 0.1437646477882351, 0.15150138549506664, 0.07154133969119617, 0.08955691262547459, 0.07450233759092433, 0.09623166838926928, 0.10211959494543926, 0.14187863256250108, 0.09793110005557537, 0.14750910257654531, 0.14186131634882518, 0.1789621455328805, 0.10492394625076226, 0.15151685609349183, 0.17385330609977245, 0.18585384929818766, 0.12407544787440981, 0.08194977510720491, 0.1593681847942727, 0.13565105173204625, 0.22354580461978912, 0.11203947836267096, 0.153027085055198, 0.1696848212076085, 0.10991605051926204, 0.07920656659241233, 0.19503469951450825, 0.11659468071801321, 0.12451477215758391, 0.10050071895654712, 0.09371405241212674, 0.06558885731335197, 0.1312963632600648, 0.15530758697007382, 0.11194672262562172, 0.14523814086403164, 0.1625143074031387, 0.16486180786575588, 0.1292679099632161, 0.1727101510124547, 0.10884218064269849, 0.24739777616092137, 0.07833293918520212, 0.15350477370832646, 0.1603621028895889, 0.25466648755328997, 0.2457574856068407, 0.14145196974277496, 0.14332300291529723, 0.0954250938126019, 0.11686743822480951, 0.12085375003516674, 0.13336497225931712, 0.1675526334771088, 0.10912469548306294, 0.0876753485894629, 0.14386061978127274, 0.1459820188049759, 0.1911222937383822, 0.09168839467955486, 0.24538600125483104, 0.13984884933701583, 0.1810032467224768, 0.09625305581305708, 0.13905748751546654], [0.042838080253984244, 0.049282788897731473, 0.022199214602421437, 0.00931979383208922, 0.04293247465310352, 0.061648360187453885, 0.00824296215016927, 0.04801286311287965, 0.02170665585435927, 0.01341842778492719, 0.061697357201150486, 0.005175610671618155, 0.05560848589188286, 0.02041569209125425, 0.05803474730678967, 0.04358230085511293, 0.040336185933223793, 0.048915151839277575, 0.05995035344468696, 0.024716267395498495, 0.03885747153045876, 0.0415277002113206, 0.035504412704280446, 0.0656424140823739, 0.04278370924293995, 0.04459421369912369, 0.023619412145178233, 0.010916307851273035, 0.01142866285850427, 0.02508322931160884, 0.049986232936914475, 0.018023308233491013, 0.02314566578050809, 0.040113975892641714, 0.016111812321469188, 0.030584986321628094, 0.03352291063804712, 0.03777596813493541, 0.08586298834000315, 0.04442071908020547, 0.010507722900781249, 0.0472739995457232, 0.0404575724553849, 0.048498494018401415, 0.018830802225108658, 0.0474789781895067, 0.031029949230807166, 0.018973274222974266, 0.039073350839316845, 0.03347432753071189, 0.021530092560819218, 0.06894071173987218, 0.024540458972166692, 0.026382072562617914, 0.08681495261511632, 0.045976321678608656, 0.039663140262876234, 0.06706697799797569, 0.013223548286727496, 0.049462142666535716, 0.02779164763965777, 0.038891310071838756, 0.0425351788289845, 0.007063687795640102, 0.007381570425682834, 0.021746122843718955, 0.0312481152026781, 0.025818779931536744, 0.02758486578906221, 0.08150905304189239, 0.045144149368362765, 0.015011041924091322, 0.02315657662360796, 0.01251537146578942, 0.10292337395782981, 0.0878974466717669, 0.0808396850313459, 0.018369274579786828, 0.007155214536136815, 0.05834686663001776, 0.028090764535591006, 0.025851805927231908, 0.031410946643778255, 0.029102003933595758, 0.024166986512552415, 0.04218624219564455, 0.10954966875059263, 0.013779667954492782, 0.009946289455651172, 0.012233341777963298, 0.041245918188776286, 0.03550474179376449, 0.09219742486519472, 0.03812571901029774, 0.0038465153608870295, 0.016071926336735487, 0.005830501289372998, 0.03005043982661196, 0.06385016561086689, 0.011641522686529373, 0.03802970630515899, 0.047109546405928474, 0.018916491019938673, 0.08382982601012502, 0.039168888569942543, 0.044864117966166565, 0.04306428347315107, 0.01895074007500495, 0.027155556682763354, 0.08380043865846735, 0.0339020522577422, 0.05654383284438934, 0.02768428304365703, 0.04919727312933121, 0.018651573985282863, 0.038586800518844805, 0.03315493770475898, 0.05215676807399307, 0.016814141866884062, 0.017576864421633736, 0.023021305578627756, 0.033614461975438256, 0.045191385583685975, 0.014896488249568003, 0.03132478626711028, 0.0034521393577701277, 0.03682932018169335, 0.042375909696732245, 0.03281082206272653, 0.060902073447193415, 0.03442048693874052, 0.014647806861570902, 0.03648563540939774, 0.029741563900773014, 0.0219231153106583, 0.0035032387698135737, 0.04104310407170227, 0.06273997375475508, 0.025904780852475336, 0.04378531853269253, 0.004191150082208748, 0.031146280667079345, 0.0641609142933573, 0.005764264821274472, 0.03250035836494394, 0.07560703331338507, 0.06008857102798564, 0.06633267418614455, 0.017600662341075282, 0.059235306456685066, 0.015699195176629082, 0.03973388093124543, 0.018580782426787273, 0.03573207138106227, 0.04979965955551181, 0.07758450827428273, 0.055582348722964525, 0.03887924911188228, 0.06686887969928128, 0.07114741618611983, 0.02564774839473622, 0.05324469380346792, 0.03644759673625231, 0.054894938466272185, 0.09429435591612544, 0.03457009373232722, 0.0153889825368034, 0.09395134967884847, 0.019640433602035046, 0.06539900321513414, 0.033967283221759965, 0.029358150903135538, 0.010975236921305103, 0.0223842561910195, 0.012351704578447555, 0.008629487079036022, 0.026088166815627898, 0.052988936991563866, 0.032924992364964316, 0.02155072002538613, 0.04891296695651753, 0.027377016942149827, 0.019489613927102516, 0.033411800528743436, 0.023716091510972807, 0.0067941779270768166, 0.06348039795245443, 0.025857661684442843, 0.06637750499482666, 0.02343541380417134, 0.005584462371189147, 0.01763735751488379, 0.006746955282453979, 0.048888529517820904, 0.08482727927288838, 0.022598154177623134, 0.07651370537600347, 0.022910965606570244, 0.021994702451463257, 0.03385416804147618, 0.05906110616134746, 0.03258278340633426, 0.020551516142274653, 0.013420186038794262, 0.09457697253674269, 0.026294909650459886, 0.03648920450359583, 0.05217327683099678, 0.04072307642283184, 0.03177094679059727, 0.029253347776830196, 0.054713949428073, 0.056742982872362645, 0.01191579841542989, 0.07866636450801577, 0.052404382465673346, 0.03152932047045656, 0.036286946785237105, 0.08973022403993777, 0.029383806312190633, 0.03717090149543115, 0.020956113003194332, 0.06057223078927823, 0.02709795754136784, 0.041914621235004494, 0.013992234316122319, 0.075529856740364, 0.06113675156874316, 0.007079868735412934, 0.03670239342110498, 0.020354450913146138, 0.011398361180908978, 0.07492671374763761, 0.018581922365618602, 0.025921369337343743, 0.044848664331116846, 0.012323206955833095, 0.026622004241549542, 0.015761866367288997, 0.05476313303889973, 0.028178544914616004, 0.020921921623604636, 0.04034519687827144, 0.01550993649289012, 0.010582551742637796, 0.04741067346185446, 0.028368007158860564, 0.048628195987216065, 0.024518208112567663, 0.03194793925753661, 0.04670716156916959, 0.028437584139672772, 0.05752209374415023, 0.038923238537141254, 0.043205276264676025, 0.03210768336430192, 0.020212643879598806, 0.03230896059955869, 0.021347839751147797, 0.02583295961708895, 0.003337172413012013, 0.02729998286148267, 0.05091280643162983, 0.061494095250964165, 0.02186765525090907, 0.052397848173443756, 0.025106764298730662, 0.02665439580700227, 0.041105240916035006, 0.09168863895216159, 0.044823215875242434, 0.018053053512371013, 0.03705743347693767, 0.018678537270586406, 0.05832790836159672, 0.02097506618260273, 0.010256478346751204, 0.008697384685677077, 0.08304348534771375, 0.033615259254085164, 0.03758782733763967, 0.0560564784599202, 0.03662749672574656, 0.06187879067978688, 0.08492881525307894, 0.01336437398900411, 0.02023190918511578, 0.03957853712407606, 0.011110424845745521, 0.01799325252483998, 0.022069923147293072, 0.04018305415021522, 0.06652250114296164, 0.022767368936911225, 0.024300120172223875, 0.04393362593171852, 0.03184927687315004, 0.05814740447593587, 0.019643495491306697, 0.03433825867250562, 0.016389199133430208, 0.04577417591852801, 0.002143050652063851, 0.031988206918218305, 0.058258148176329475, 0.07747144398412534, 0.024798219158713306, 0.025297787173518112, 0.03667849202507308, 0.045587914663233926, 0.029171306107725416, 0.02587271837650665, 0.014070194597089929, 0.022087804241372005, 0.020612211099692752, 0.007500012954031783, 0.010256273938076836, 0.03872249395187412, 0.030431087794048444, 0.01079012154202376, 0.06232544992651258, 0.014845586248806544, 0.033917726416672976, 0.03123351652175188, 0.02218049212491938, 0.04177403895716582, 0.046392616483249834, 0.06961873107190643, 0.04710960068872996, 0.024980724722679173, 0.03262363799980708, 0.02261900046973356, 0.03089037797014628, 0.012981981338400925, 0.02408556400665215, 0.04016760730051568, 0.039402603171765804, 0.0479355745815805, 0.0494760560270931, 0.03946196480787226, 0.060750129100467475, 0.10259212673242603, 0.023501730424218943, 0.07479277093495641, 0.03913090757227369, 0.02058621303045324, 0.0255812892823347, 0.0157444704257484, 0.013953584113291331, 0.01818784449382552, 0.03556534514895507, 0.02416732408372419, 0.12584764563611575, 0.12544622431908334, 0.2212260290980339, 0.09526750405452081, 0.10059826515082802, 0.2818066397947924, 0.131204788173948, 0.157196737027594, 0.1847911684640816, 0.08154261338391475, 0.22477256879210472, 0.1638219529496772, 0.14328282007149287, 0.1281499963785921, 0.23025358468294144, 0.13883103323834284, 0.16736301008079732, 0.18299485556781292, 0.17992038625691617, 0.08948869271469967, 0.09972468524106912, 0.13080726164792264, 0.07545483790870224, 0.11979675532451697, 0.16864951247615473, 0.08743576465972833, 0.10757981373795442, 0.10464918028031077, 0.1876643571470465, 0.09084628522396088, 0.13811789293374332, 0.10211957458938871, 0.12290160943354879, 0.18484029439943178, 0.11882972078663961, 0.09563493076711893, 0.25590660529477255, 0.13605691066810063, 0.09093273058533669, 0.1292142921260425, 0.150915226233857, 0.10674833692610264, 0.15268061150397572, 0.15430156381002494, 0.06563912997288363, 0.1664879441793476, 0.1711551658809185, 0.14801094707633766, 0.16640368370073183, 0.09542527701705694, 0.1063297622437988, 0.20028320859585488, 0.12281026504933834, 0.08256722161812441, 0.15827354496078833, 0.1618341031883444, 0.1449090920920883, 0.0940646989537137, 0.16597066979323113, 0.10609614263687815, 0.1421158891171217, 0.1121396708435246, 0.12635436201734201, 0.1643136872776917, 0.13067125608878477, 0.10619605691837412, 0.12744125298091344, 0.11324074997433595, 0.08961001477603402, 0.13396919412272318, 0.12419279372053486, 0.08107137081346341, 0.0807145292471562, 0.11767750047147274, 0.1334419995546341, 0.16195945574768952, 0.2268800035651241, 0.08524609822779894, 0.08474947844765016, 0.09596499734159027, 0.075373325496912, 0.2182687699262585, 0.15046919802469866, 0.08052331129355089, 0.09428501248891864, 0.11930928219641958, 0.23174557462334633, 0.1040237813389727, 0.06242037019027131, 0.18385734143001692, 0.08187267995838608, 0.10817264299839735, 0.22832676236118588, 0.14806391351989337, 0.214839440371309, 0.0630795398194875, 0.07799903888787542, 0.16567773265498026, 0.11724914131419999, 0.10970149774636541, 0.12918393446930818, 0.18361202387937478, 0.37583378862057415, 0.12264231406152248, 0.15493285922067507, 0.13263083808124065, 0.1893401350826025, 0.0992617140124951, 0.13810437651617186, 0.2122268227062055, 0.09107510080294949, 0.10108886632536139, 0.14929002629859106, 0.1100846529006958, 0.06698642910591193, 0.06539153254457883, 0.14956097890223774, 0.2641657878245626, 0.06353336439601012, 0.12728911185903208, 0.10388620157859155, 0.11789075045713357, 0.13320160816822732, 0.2263862607734544, 0.08087686196501766, 0.13939855992794037, 0.06788250923688922, 0.17155514870371136, 0.16568637719111784, 0.1589746344834566, 0.07665298825928143, 0.08439862156020743, 0.09950957606945719, 0.09016028632010732, 0.08628424323563065, 0.07473977734999997, 0.2703945221645491, 0.13005826755293778, 0.0938650875219277, 0.10446704112525497, 0.11031663723822151, 0.2032963383410658, 0.1416681781411171, 0.15470591639833792, 0.16698176839521953, 0.14504707897348063, 0.1611287931778601, 0.17237119562923908, 0.25467769695179804, 0.18536843891654695, 0.08168790130210773, 0.15265372794653687, 0.13102969899773598, 0.1543868285204683, 0.09290156101009675, 0.16799221560359, 0.11700640219662871, 0.3263884261250496, 0.07174473734838621, 0.13111710787883826, 0.060461493874234815, 0.14861379829900606, 0.1606436406395265, 0.1276407694177968, 0.1594401773597513, 0.21016635612717696, 0.11359320820442267, 0.1973148893032755, 0.2114222158810922, 0.13508169299789838, 0.09869565295853786, 0.10602612460830382, 0.16023746957736357, 0.10010779289794819, 0.17569086035447462, 0.16145518209253037], [0.010508440451563468, 0.02622506464831531, 0.026981368261788572, 0.00882272282615304, 0.049625164097441096, 0.056244894063898494, 0.02911421756393143, 0.029409017280808518, 0.0512668524336602, 0.010564473873403455, 0.037851672286966016, 0.027622672063963752, 0.04310166396732841, 0.040456049144268036, 0.04696884199178644, 0.015619492757001092, 0.022406590171158314, 0.11291001843554632, 0.03468543790014727, 0.03460744029975363, 0.034303344653121064, 0.034889208751597574, 0.01556938124953636, 0.027088208689487407, 0.03311963013506361, 0.08848961096789155, 0.06391953224582331, 0.0070653018608157125, 0.037631182332656214, 0.00906006250131343, 0.023628190691981996, 0.08042453016553607, 0.049832772064421854, 0.012999608830016638, 0.0612294055255396, 0.016123606956430843, 0.07431605937225477, 0.017698859928974083, 0.027571693728012697, 0.056729252716260295, 0.02896402044487851, 0.01924821830886815, 0.03374743787571788, 0.016543199441262653, 0.028738974127918482, 0.013624511592622315, 0.07272841635027102, 0.03303228910746319, 0.03421047356511865, 0.053727118631026576, 0.06204712164721318, 0.031400921288877726, 0.014043427238773023, 0.004018183872436306, 0.016227499149473648, 0.0405083777649062, 0.02455951732450298, 0.025306472421756813, 0.04720746918714472, 0.01927258280505027, 0.03132922049345715, 0.027737816063953296, 0.06566680063094411, 0.01915083496299173, 0.06418640006865774, 0.004567467299888709, 0.04483995872682758, 0.056092837758894475, 0.0249000587833247, 0.0053727602935396135, 0.027896440587937832, 0.07241045484053237, 0.022852441961211816, 0.02347873996144959, 0.010540021167668914, 0.006530775297765753, 0.02355894958600402, 0.10587074008903333, 0.026780067277806144, 0.023033393679984977, 0.05477691408512848, 0.08453290364039795, 0.008901950271267976, 0.07942525842892272, 0.04512106899970344, 0.045455498554344685, 0.048313718754798174, 0.009438971722764629, 0.052116785398019214, 0.04901207717401641, 0.037431462335267236, 0.028477222459124665, 0.03192255526248898, 0.0229325481091759, 0.025771455506661108, 0.04294529217960579, 0.02374669852932649, 0.015672420184793215, 0.05619527279798474, 0.040815268975815604, 0.015592868739206876, 0.03910775935011251, 0.018490309960075786, 0.046653367312891145, 0.026240158659805144, 0.025506957467379313, 0.041208463055746894, 0.01486680912785232, 0.04350644742537822, 0.01936776769746627, 0.018515286834112236, 0.055695270520767996, 0.07383235211351089, 0.02626637216391308, 0.02678231831773051, 0.015870762756094337, 0.055315779455538304, 0.016468986369935528, 0.04084334675488727, 0.08166491932102612, 0.05364731273480824, 0.04536175894151841, 0.05095744725050671, 0.02290560687626047, 0.006035950242741299, 0.052804137979234965, 0.018594458300088133, 0.022285132402820245, 0.02435918664559722, 0.03337752093960132, 0.012277490658951657, 0.09331643767654896, 0.023368386418691704, 0.04364257172814437, 0.06531214394739696, 0.003235061374393159, 0.0719649830300893, 0.055743480433842967, 0.031628311944327185, 0.031554246454366615, 0.023077527293935418, 0.006010538682208529, 0.06230306505624737, 0.01736438966223172, 0.03430049819871783, 0.0027741681593137658, 0.033753096857773404, 0.06782755468572889, 0.049695612995752265, 0.02005064194755895, 0.02282774667920811, 0.04040238720231822, 0.04137578300599541, 0.03253352176398039, 0.0528529178617256, 0.04686008979167257, 0.04182477980586035, 0.03763564370040383, 0.05417038520265903, 0.061091045449887, 0.03225128173029848, 0.06538239267787763, 0.03556701773777604, 0.034544991329312325, 0.03045635304546782, 0.0030135063321462697, 0.02032883621619216, 0.0053146950834031615, 0.028118206188082695, 0.043915468334619484, 0.040400354989937375, 0.006613744863508535, 0.040341142631535015, 0.025706322930221046, 0.013002710583220636, 0.02772152952716819, 0.00894272089603224, 0.017780855796965103, 0.01753043057397008, 0.04859992821833917, 0.031132509798875878, 0.0627427761043821, 0.06576303046728883, 0.07950915249862842, 0.027716767907674824, 0.02166514308191836, 0.035432593165231605, 0.030342084355652332, 0.014660856786317058, 0.029806319890277724, 0.022820678040651337, 0.0358913506913398, 0.0136770810931921, 0.0657701754410352, 0.010149229949872409, 0.04008491084511791, 0.03072704780580742, 0.05145045383168118, 0.04196067340672016, 0.11261249440056936, 0.03315906659034746, 0.003285431785375944, 0.01366194721776992, 0.03663687747237938, 0.03993755678779312, 0.04160452733880707, 0.03382670433659639, 0.016438660943614583, 0.0452312359453312, 0.020235086425340602, 0.041999777379844866, 0.021285575681499073, 0.036570370862526555, 0.04102164879441261, 0.005600436357781291, 0.027801462648702518, 0.026785977317818573, 0.046303887851536274, 0.03441683981301529, 0.02045749154474054, 0.06974197338734354, 0.027625182643532753, 0.04103584035432764, 0.034355537566755495, 0.03676008925374065, 0.025776030529024344, 0.04585999363501157, 0.03598748553278191, 0.020952175803748623, 0.056642447731324604, 0.036367112305015326, 0.050204103746052296, 0.052724070847034454, 0.040329638070293834, 0.05639350001833268, 0.007064172524094049, 0.059727088282150884, 0.05633874563500285, 0.039621854799666574, 0.01716926334691899, 0.03718104559395995, 0.006276088450769228, 0.014681014365383556, 0.007532454561442137, 0.04501496987151248, 0.041709791868925095, 0.020044100869979178, 0.04348347222964678, 0.035224245595080514, 0.04620651129101004, 0.04644707909652165, 0.005023140884337148, 0.044094316594834836, 0.04428269148671201, 0.005767622721448008, 0.04802177906302469, 0.041717503419412036, 0.06098332801567657, 0.04714822968734162, 0.046745142566838434, 0.06716745546353714, 0.08522946054914168, 0.0366037310367184, 0.011826487091769065, 0.02729652402922511, 0.04817437141069344, 0.013353391899727285, 0.07095416941280876, 0.030042731668800116, 0.04664643947035074, 0.03478671942970582, 0.04937823163345456, 0.015009445670459951, 0.062025218536811214, 0.017282541375607252, 0.019267288535567265, 0.02578018994868866, 0.021793779750753726, 0.012863231772956039, 0.052493742134954245, 0.020827561151236296, 0.049706035293638706, 0.012479711057884353, 0.032971122568207126, 0.013889264930704874, 0.06174998437719686, 0.016317817249468396, 0.015278922460441078, 0.029869114913578545, 0.02582457970960864, 0.004696895310189575, 0.04347718221002391, 0.05171622582046049, 0.011938523401373198, 0.05265172205067106, 0.04874568771837013, 0.03357084574443953, 0.008098799751938453, 0.021146106201090982, 0.04429515278232949, 0.02912144735455513, 0.02033435949124396, 0.04703672942040222, 0.038339806986706595, 0.025432235494788204, 0.022823936705078398, 0.023716162757149765, 0.09699852831129517, 0.038575580942311456, 0.027795204859493033, 0.05381452072677868, 0.034997173851089816, 0.04494580001171146, 0.04270373710564204, 0.06550207268446684, 0.06513047298150403, 0.04517590141456042, 0.05278950537155781, 0.08937224932014942, 0.05285398655437997, 0.03559430502355099, 0.0215017111373267, 0.023577409131186347, 0.04276896806965981, 0.04200966702774167, 0.03493451792746782, 0.05259958341983812, 0.044036590228123326, 0.03352906495066626, 0.02343375817872584, 0.024266624291028296, 0.054622533797685585, 0.08024410770407744, 0.032106048094906976, 0.02896967264158385, 0.03431880507352097, 0.05559527820774487, 0.07409135571547917, 0.016180206955011402, 0.03651777422055602, 0.04314577552889075, 0.014897365256079605, 0.03082860753472362, 0.009893607148634536, 0.017243305088153908, 0.005968229903373867, 0.016706412558310797, 0.03153053844081504, 0.004355151148047298, 0.04180417609001909, 0.04252033926812666, 0.01902562489600054, 0.086010454355606, 0.13166890612670354, 0.08493032838617053, 0.12122874919857297, 0.15504773519933224, 0.15521845461002418, 0.18531217479280063, 0.11680647863873414, 0.08766428846865892, 0.11433234997093678, 0.11777001193591527, 0.10357721708714962, 0.13843916569437298, 0.1828919489468847, 0.10796113684773445, 0.06241533546043294, 0.07481959342424359, 0.17911841214767524, 0.10279291881514446, 0.09720023641628878, 0.12124363625688211, 0.17519858319844517, 0.12654777163905756, 0.20319305174052715, 0.0821395952786718, 0.13906416430005006, 0.20950101182929107, 0.1074703253273453, 0.1761254756046193, 0.09100236863430057, 0.0983392388692924, 0.09512989715273891, 0.1469628954572337, 0.1388697504465069, 0.14649187001798833, 0.13420168736151286, 0.14725338986941747, 0.09952197968959808, 0.05702558931495462, 0.15127854102424212, 0.12838542088866234, 0.09589044669909136, 0.18416756764054298, 0.1229063727493797, 0.10240088842277016, 0.1140250957437924, 0.15070023919854844, 0.14549548205520424, 0.1329602939741952, 0.13653895551604883, 0.204172802024654, 0.10966025638793196, 0.16179561668208667, 0.09261609454240118, 0.10512756782450847, 0.09920536846454654, 0.15903696471026965, 0.18143911047705583, 0.12154391514403479, 0.06927647800850016, 0.08405710131462131, 0.16039323407624448, 0.17215272092393466, 0.09240790642797947, 0.17725234585148947, 0.07730892806180886, 0.11136640555092267, 0.0792542743895735, 0.08139657229185104, 0.14980466796883515, 0.12100739750478949, 0.11651644563036305, 0.08564499539456197, 0.12089093375418868, 0.18731386666851385, 0.09649769482868058, 0.12868512980639935, 0.14867751273725713, 0.11800135166517325, 0.19344882746892317, 0.1336635005261217, 0.21158912192497933, 0.2024013235100678, 0.18356911332479545, 0.09630203925605331, 0.15453731401690415, 0.10571828005569321, 0.09874773052121912, 0.13387487775513104, 0.06880753567176205, 0.1789108889975718, 0.13029774970241956, 0.12866177463105746, 0.14740217902830668, 0.17722312813358648, 0.09941200951912574, 0.1606803493840354, 0.13257736952177115, 0.10722390854997293, 0.12384930572339467, 0.06846627326948301, 0.09222595047737871, 0.09086884651333094, 0.11745213185037885, 0.1185236879225288, 0.16254991692091736, 0.11012288834899664, 0.07847568938242537, 0.06193337882203715, 0.16721697577408381, 0.06791341650698866, 0.13427955604025296, 0.08798226354909794, 0.08296376426837274, 0.08005608565040997, 0.0919190626591444, 0.1435334166245801, 0.1303040872194937, 0.10689244419336319, 0.20369136785822256, 0.13157511901642593, 0.09590350171285016, 0.18915911551032746, 0.1184442179011447, 0.08099063871694462, 0.2027601192572287, 0.13332107104361057, 0.13314884528517723, 0.0958679396925228, 0.1314229236117431, 0.0924881092671837, 0.14967605844140053, 0.1310402298612254, 0.1486285767917122, 0.16691448486277036, 0.10828614155096666, 0.19055028871766158, 0.13500239939561912, 0.29263293743133545, 0.09692490726177182, 0.12161577200250966, 0.11892027807022844, 0.21920030351196015, 0.12856574835521833, 0.18979786123548234, 0.116409942773836, 0.11053833498486451, 0.16812778690031596, 0.09157327442829098, 0.11697335754122053, 0.1000343414821795, 0.15917948420558656, 0.10945343891424791, 0.08018969598093204, 0.19189614935645036, 0.16817784921399184, 0.18631860507386072, 0.10664610884019307, 0.08714457814182554, 0.2629312883530344, 0.11405976888324533, 0.1796190081430333, 0.13143337305103028, 0.08831372112035751, 0.07648583115743739, 0.1703104983483042, 0.07643606739916972, 0.16288292833736964, 0.18039086886814662, 0.20074294321238995, 0.07363877964339086, 0.10006959816174847, 0.11817914141075951, 0.15054740597094807, 0.15323310185756, 0.10382129970405783], [0.016827809258497188, 0.04165448787223015, 0.025432868228693093, 0.016134924920541898, 0.06254278469298567, 0.045972783118486404, 0.043833080612655194, 0.008954697887280157, 0.04092743420707328, 0.015330677718988486, 0.022143951317827617, 0.025621729969446148, 0.034574907938284535, 0.023145282408222556, 0.06148625138614859, 0.046469508071563075, 0.03272469900548458, 0.06197919350649629, 0.048529004345514944, 0.03297532609264765, 0.06383389434111969, 0.09316656964698009, 0.06601342345987048, 0.033573074731975794, 0.04062184239072459, 0.02172431642455714, 0.006417384886715029, 0.01671613087611539, 0.0510427933851523, 0.0045308399795820666, 0.056961237053786, 0.005141385365277529, 0.024293350089075308, 0.05307469363989575, 0.04779442572700126, 0.04707883591098445, 0.031196845096669028, 0.01627792278304696, 0.008395073586143553, 0.0035529565149252968, 0.016210542559357624, 0.06054748461714812, 0.016021765635481904, 0.05385282742125647, 0.07596077397465706, 0.051937075398330174, 0.05136291942160044, 0.08492931736899273, 0.06664512599153177, 0.03509691510615604, 0.0931718757908259, 0.06342974531331233, 0.02007669090692486, 0.07866350787558726, 0.0037873831544337527, 0.03425507367189441, 0.045766267592885664, 0.021273499454504678, 0.040585255782519064, 0.016058689814859202, 0.06759495288133621, 0.01920221872361643, 0.03377123409882188, 0.0026483474108057892, 0.05547149645696793, 0.015740361896210482, 0.02548342417659504, 0.020414211188576052, 0.01345258523776595, 0.014816709494750415, 0.08016403378652674, 0.03036577540582844, 0.08513123581984214, 0.006037527836659657, 0.04525885910594037, 0.029253870248794556, 0.038911625410297086, 0.017601167849664177, 0.01716292243716972, 0.11987607606819697, 0.04150186159781047, 0.019309106648766568, 0.01835801768382745, 0.07244484978062765, 0.026207397292767252, 0.017737521157999123, 0.048963511030056646, 0.034221031570008824, 0.027402650298816816, 0.06317048386803695, 0.05306461739486881, 0.00992297668874796, 0.012515709885129971, 0.030484709023897136, 0.0830060030732836, 0.010684469398776335, 0.06509468704462051, 0.059787233626203876, 0.04575554673959102, 0.025398990671549524, 0.02456737815269402, 0.043196950639997206, 0.06060748068349702, 0.023707089047612886, 0.042107348929026296, 0.04874719406611153, 0.01433295473855521, 0.037085372156330516, 0.08445280258144651, 0.028010495539222444, 0.050312679527061324, 0.015360078641346522, 0.047680129895785024, 0.03748147375881672, 0.0274106654937246, 0.005355730760909084, 0.06262669233339173, 0.031971952611846585, 0.009704149993402618, 0.03484867646225861, 0.05034419069332736, 0.07561763203037636, 0.0161190098816795, 0.034660844398396354, 0.04807399572538478, 0.08352790506822722, 0.024519217433407903, 0.028792564823691334, 0.01602074783295393, 0.09075392303722245, 0.010660187174965228, 0.08043651309396539, 0.015244739562539118, 0.04656069639271923, 0.01694674796557852, 0.024732282518276145, 0.05975169874727726, 0.027460246047537242, 0.022242980111124258, 0.021035235275381377, 0.01941082583341215, 0.10856190496789557, 0.03177526566599097, 0.013913435196237904, 0.021190117678738067, 0.04869551005374108, 0.01177265721240214, 0.010990591320608343, 0.01998404543181615, 0.060358485473053794, 0.019645663410691277, 0.07060359751007386, 0.03688047832942434, 0.0241380266379565, 0.05062052407967193, 0.028057109198666046, 0.06987661509109394, 0.03509297960304788, 0.022483315518391982, 0.05223226188016789, 0.07273523562720843, 0.024223489819892814, 0.022364319135834063, 0.03389077500573226, 0.006832282333302179, 0.05555828787120325, 0.09474127300615821, 0.036163592511521916, 0.06499030800270182, 0.033316561353525946, 0.02480666183068284, 0.04576918190079076, 0.07082746656877653, 0.02306376490741968, 0.02044371049851179, 0.055782217998057604, 0.02076228947511741, 0.010903996681528432, 0.027769664801391106, 0.006889645683778716, 0.04190177995977657, 0.0350425678438374, 0.06519046904785292, 0.019117086327501705, 0.022594144035662924, 0.054343435381140025, 0.019138387238074626, 0.03518107380451901, 0.03587706752919725, 0.035667071118950844, 0.0636167156377009, 0.01844004917490695, 0.023181348240801265, 0.02359116812502699, 0.03269954910501838, 0.05312158040968435, 0.10968948767653533, 0.037292593358350654, 0.022009177299748574, 0.07675736051584993, 0.02735751075670123, 0.038644727053386826, 0.022351633923660432, 0.0830854798800179, 0.026666568725236824, 0.015920409467071295, 0.004206441292938377, 0.0232719971266176, 0.02138121858505266, 0.055386537087282965, 0.03558672918006778, 0.010578895287056054, 0.05908572341182402, 0.026885072268279533, 0.036214998324534724, 0.009442689246498048, 0.037359849749399085, 0.07718476972409657, 0.0789214801043272, 0.02238025113807193, 0.021593723878530518, 0.032590722266052446, 0.043893785748098574, 0.03900473737823112, 0.0794934444129467, 0.03168264563594546, 0.028916098909186463, 0.06426502870661871, 0.03541849999289427, 0.05643044964277318, 0.008834837220742233, 0.11803975674722876, 0.02212208552685167, 0.042422178999653885, 0.020307533609281694, 0.03444938235250967, 0.03592855815908738, 0.03961172087916306, 0.018867782383624996, 0.03362200389217053, 0.01946174819022417, 0.016578797084678496, 0.04067587074158447, 0.026582910446450114, 0.05018406660695161, 0.033468180003442934, 0.05379737075418234, 0.009293889061414769, 0.04247932521892445, 0.052726130200816054, 0.05298147310635873, 0.03383110463619232, 0.008661733607628515, 0.0571160651743412, 0.03662839239197118, 0.07614655686276299, 0.07962938211858273, 0.01742486239943121, 0.02065348468853959, 0.03699433650555355, 0.04283287589039121, 0.031995894719979594, 0.019910911231168678, 0.008517042800251926, 0.02377022842743567, 0.03877609143299716, 0.07582760469189712, 0.01429463956238968, 0.05754388828894921, 0.02593784416759653, 0.01721525445048298, 0.03646281627672059, 0.03554305188091738, 0.05689035050038781, 0.08048065179692847, 0.034816252666392496, 0.04733433827225651, 0.07080557702907495, 0.03377830782639129, 0.05426256757761751, 0.05253837616848094, 0.046363843205784044, 0.0016863854522983144, 0.031160825065204074, 0.06808231065848044, 0.03161090752109885, 0.06507906038314104, 0.02087369983616684, 0.032569935345756154, 0.01998811833826559, 0.004082148096391133, 0.06876894059990134, 0.011718921479769051, 0.07123671139457396, 0.023220983167578067, 0.05784118162201984, 0.006726613226679287, 0.04304935570274081, 0.013756235595792532, 0.05774274654686451, 0.024921178185780133, 0.09834016846226794, 0.04250522829326136, 0.026019845124600188, 0.07130208824362073, 0.07171613709735018, 0.013562887890397437, 0.03920881017776472, 0.02271349325643054, 0.030617749385003532, 0.028796279802918434, 0.044580887271357436, 0.03975356523213642, 0.020595863494755964, 0.033421676605939865, 0.033968799747526646, 0.012145449440660221, 0.03528533071013434, 0.018312240318794335, 0.025572266462924223, 0.02668926232893552, 0.0424699648283422, 0.012155641884809094, 0.032248917035758495, 0.03841739746608904, 0.01990846511242645, 0.03598822174327714, 0.04687567574105092, 0.009392729561243738, 0.017868902500984923, 0.03422368124925664, 0.06865285682891097, 0.14669844321906567, 0.008866233884223869, 0.06535945819424731, 0.0688160987836974, 0.043873904672052176, 0.028122584435290525, 0.05698690603354147, 0.04306199002478804, 0.027302776729421954, 0.05935169556843383, 0.018740777591509477, 0.09588041795151574, 0.05713204467403037, 0.04271807794326118, 0.009124960983172059, 0.023663167475855777, 0.04329859179311565, 0.04717061795028193, 0.024515100422182252, 0.05967538391372987, 0.10144767564322267, 0.11799924820661545, 0.1366579027048179, 0.12217223857130323, 0.1332853665309293, 0.06805704879973616, 0.17914600138153347, 0.08746888395398855, 0.17020514900130884, 0.16357245562332018, 0.12270540424755641, 0.09812129342130252, 0.12458255780594689, 0.10668652238590376, 0.16651163862219878, 0.11445692900036063, 0.12148496402161461, 0.16837533004581928, 0.1882753779313394, 0.14224422723054886, 0.18228084673838957, 0.1807420921644994, 0.12622858876628534, 0.09332716531519379, 0.13883157606635774, 0.101367784930127, 0.13494092412292957, 0.19062043566788944, 0.0830132362565824, 0.08418024863515582, 0.10113310680857726, 0.05786030273884535, 0.06572343116360051, 0.14930523905370915, 0.13122783122318132, 0.11167703888245992, 0.15615906699427537, 0.11357505739267383, 0.08141007513872214, 0.09866180084645748, 0.09408080058970622, 0.16018254895295414, 0.1180436515382358, 0.07376153341361455, 0.15123636328748294, 0.07268435228615999, 0.16005585289427213, 0.15384161206228392, 0.15308870960559162, 0.12457423896661826, 0.15474685920136316, 0.09833051290895257, 0.15929480801735604, 0.17373748017208918, 0.11877636079277311, 0.23119419706719263, 0.09244341416550533, 0.13957865669259004, 0.13745515421032906, 0.08350950998387166, 0.1106386970994728, 0.13295269438198634, 0.13529928560767854, 0.08330783580562898, 0.10040475374885968, 0.08708793403846876, 0.1921155604400805, 0.10979928142790284, 0.07630081501390253, 0.14322681379105362, 0.16850708797574043, 0.08293775602110795, 0.16043105561818394, 0.12687550405306475, 0.15790634895009653, 0.11179985372083527, 0.0836136651092342, 0.13202137792749064, 0.1139370354690722, 0.2509199157357216, 0.21469914647085325, 0.11952880184565272, 0.07366592782948699, 0.15362457585121903, 0.11523797708962645, 0.08604073737348829, 0.13261607315923485, 0.2067619152367115, 0.12082370450454098, 0.1060006320476532, 0.09340541397354432, 0.08254958649298974, 0.12602517753839493, 0.11810632103255816, 0.11737255326339177, 0.10177677191261734, 0.14641629478761128, 0.11261435358652047, 0.10949905003820147, 0.10931695159524679, 0.14078738540410995, 0.16497810876795224, 0.1946755237877369, 0.09985313192009926, 0.07955068562711988, 0.17864422473524297, 0.05479746351816824, 0.13973176133419785, 0.15141975773232325, 0.11332074246768441, 0.1447486457015787, 0.05616308988205024, 0.17220708514962876, 0.07896627020090818, 0.10581891358430896, 0.10883631810013737, 0.16983109978692873, 0.16290040739945003, 0.06713279589478459, 0.1451900191605091, 0.1279277354478836, 0.18546293170324393, 0.07569843876574721, 0.15932683487023624, 0.08072811351822955, 0.28345124583159176, 0.15058724954724312, 0.1176926860851901, 0.12496799283793994, 0.20503660424479417, 0.11304199349667345, 0.2126860823482275, 0.12082943134009838, 0.10992683244070836, 0.07433440017380885, 0.21594355255365372, 0.09276931453496218, 0.1730675082653761, 0.11257030987845999, 0.10249848211450235, 0.09622683721993651, 0.1978847501533372, 0.11391114257276058, 0.10237000829407147, 0.09716888131307704, 0.1492827795445919, 0.05032380410869207, 0.07542391706790243, 0.12715457193553448, 0.2226931575153555, 0.10546400584280491, 0.20327708151723656, 0.0855680698794978, 0.09159805452717201, 0.11597281694412231, 0.1228448296231883, 0.2650914452970028, 0.15162411890923977, 0.13796294267688478, 0.12188220556293215, 0.18337936779218061, 0.10280065411435706, 0.10452686077249901, 0.13895251814808163, 0.14279279565172537, 0.10578091562326465, 0.2362241500190326, 0.20169587779257978, 0.16935707522290094, 0.15509144642523356, 0.07636596116104297, 0.1119826849816101, 0.12799492398543016, 0.09226317490850176, 0.07133710065058299, 0.12749599718621799], [0.0033708512866204338, 0.07170547731220722, 0.0031609144602303524, 0.06595314919416394, 0.03382910295788731, 0.03162250029189246, 0.017060969157942703, 0.01022638107783028, 0.045400221699050496, 0.02557056164368987, 0.019690862324620997, 0.019780064234510064, 0.05725326495511191, 0.022025465532871227, 0.009876112819516232, 0.016757565617029156, 0.01454243206951235, 0.016113203318257417, 0.03626299449907882, 0.012522995654892708, 0.015409825436238731, 0.014596611394413879, 0.07037041895091534, 0.04428755319012063, 0.031391567683645656, 0.05871710247759308, 0.02110730417604957, 0.023175862285175493, 0.0009190395295653226, 0.11903371555464608, 0.03174282151407429, 0.033303275637860806, 0.07520025156970535, 0.04085667657532862, 0.01495950888576252, 0.010979559189373893, 0.04558362292924097, 0.043374933768063784, 0.04862605520923223, 0.026725219595911245, 0.02400706598668226, 0.028725970004286085, 0.11372392797576529, 0.038779155018606355, 0.0559362420546157, 0.05040849545704467, 0.014352243792797838, 0.03082291462591716, 0.06656662627522435, 0.02941593833799873, 0.03717160377917545, 0.05751666546400104, 0.028575945911662917, 0.061455011633890014, 0.04617801960557699, 0.006860882160253823, 0.06111943535506725, 0.029722727768655335, 0.060712768962340694, 0.04021075873502663, 0.025565374243472303, 0.046612224342035394, 0.07183783235294477, 0.020809819156836187, 0.07259549812546798, 0.04890209682551878, 0.058714890453432284, 0.08380129361259085, 0.03915774702493634, 0.02474966997812901, 0.028381642320060303, 0.030579727675233568, 0.028911389876157045, 0.05908099402274404, 0.0244379391161991, 0.023531175451353192, 0.02719846384466759, 0.03616135334596038, 0.023015046093080724, 0.029426448845437596, 0.006719046288968197, 0.011736544730540897, 0.017939015524461865, 0.05079245128269706, 0.02289825494933341, 0.03914304656375732, 0.04715459095314145, 0.03249322696189795, 0.06179932065840278, 0.041031663971287866, 0.030144980110760247, 0.07831140248371021, 0.03437553060107997, 0.022924685584647313, 0.03623760711135609, 0.07605897834790604, 0.059182306086378436, 0.10051449321742568, 0.03241209113704307, 0.015798393603680388, 0.02913560498771923, 0.029560181312263012, 0.04434276897726314, 0.020068531523325613, 0.024480939576668397, 0.063112923742405, 0.023910703836008906, 0.04452916593956096, 0.02661536816906716, 0.027683562100199715, 0.03518103987776807, 0.009728760458528996, 0.03988466498308948, 0.030790602788329124, 0.03786851352612887, 0.07065558007785253, 0.02660299338666456, 0.003558883094228804, 0.040268295111932924, 0.06551064936710255, 0.003037497209983745, 0.08534356978322778, 0.034807889722287655, 0.02759524228583489, 0.06741772631981544, 0.033711943708892377, 0.008756262865582747, 0.011768074556519943, 0.031224285052823167, 0.023589895871867026, 0.03761941992810794, 0.04715954765145268, 0.026458858978003263, 0.00640247026292075, 0.0829733723242368, 0.011681511299684644, 0.025344846969736472, 0.04800799801679594, 0.03664616322410958, 0.033883674136762104, 0.005272452885817204, 0.08057449997535773, 0.03360879281535745, 0.0440352467287864, 0.034208685625344515, 0.020135516500366584, 0.04440900417310851, 0.0033154626850903568, 0.043610331136733294, 0.03919721401429602, 0.03322261478751898, 0.05180403842989888, 0.06729670959923949, 0.013054520972738308, 0.001684501881494985, 0.043236556729035716, 0.01037573257261621, 0.026673427017937814, 0.05241492689986314, 0.004777350479603878, 0.03945209551602602, 0.038352281853024445, 0.04342085362545081, 0.03709176056353109, 0.015472031830410873, 0.055348016654274294, 0.05681622733495065, 0.04839040678260582, 0.08185821359178849, 0.022066735729042972, 0.07100839793149914, 0.06821440785591092, 0.02751427948740976, 0.061720902366297584, 0.039667744122977765, 0.01494818922531392, 0.017426475616438047, 0.0811537110379764, 0.03584399912506342, 0.04474702996334859, 0.09178726401712213, 0.011130680812389722, 0.017626221058890224, 0.00576038148054587, 0.027144696729789888, 0.013272111886180937, 0.030492732700492655, 0.018271093955263495, 0.0605718440243176, 0.03671998444146343, 0.018050648105729903, 0.04876958911440202, 0.05182669471417155, 0.050062378136707206, 0.03874195772888405, 0.0391950155608356, 0.007908705621957779, 0.035542651545256376, 0.03932183714849608, 0.05508445329698069, 0.020689258751060282, 0.08602669848395245, 0.017225503721939664, 0.026469500103433217, 0.04228887740256531, 0.10741041068519865, 0.03212977646450911, 0.042771817916738133, 0.00907965944082077, 0.033485614960747104, 0.03550050773524812, 0.03273072778912527, 0.028546494099178484, 0.0429078370465764, 0.00854847508682204, 0.09274106712213584, 0.027416480538834418, 0.039679475993450196, 0.03078201932034322, 0.0646457207788314, 0.0458178566103535, 0.03649663446205003, 0.048881961298840385, 0.014244967406349522, 0.01180632781636502, 0.004395952730971787, 0.019962727557867765, 0.04951582835721118, 0.020633746104847108, 0.0527199283907456, 0.028313671770904745, 0.031039136594959667, 0.03869203790756209, 0.10929981858602592, 0.046205730975738595, 0.021058978912021433, 0.020199775462970138, 0.03674297999324543, 0.02526178749810372, 0.03696401956092034, 0.028200719439025437, 0.07460400927811861, 0.014525095499785883, 0.01755911733822099, 0.02513382427527436, 0.06564393400081567, 0.012664208970298725, 0.012368367702168013, 0.03594434088362115, 0.05042922470186438, 0.011494862431261157, 0.04885256376915744, 0.0072084710534129825, 0.01182966009115002, 0.041973063456160684, 0.0009681471232657454, 0.029247223998286893, 0.05178315990737506, 0.010081300112817968, 0.011858427431434393, 0.06919145078531333, 0.00921277274444167, 0.010515493823082318, 0.005481840310884374, 0.020592898296724473, 0.042325833812355995, 0.016749618275623237, 0.03272286017558404, 0.01637283286878041, 0.01903339581830161, 0.00971445778850466, 0.010071167888652002, 0.02773120882920921, 0.05451042963457959, 0.05481632000633648, 0.02333705167153052, 0.021632939809933305, 0.09287275719855513, 0.057909869721957614, 0.04533242926533733, 0.007831951436985816, 0.04384708218276501, 0.021885795884632638, 0.034134976366268735, 0.008096935476974716, 0.037662554399243424, 0.022629775605829697, 0.06731593249631779, 0.022462586273572276, 0.055104347943727455, 0.08494531722473246, 0.03803364180826715, 0.024177378276363015, 0.013487392387885069, 0.09247649274766445, 0.061276936903595924, 0.02163736555459244, 0.007484807832432645, 0.03593600508091705, 0.006241062897190983, 0.03106913123545902, 0.0537766584727381, 0.021058605717761174, 0.06282038015446492, 0.020591349540544406, 0.022020371431218724, 0.050924029400838275, 0.0613835279696754, 0.008858188155240245, 0.04260610270180872, 0.04911183878513319, 0.012146213640724974, 0.03143632385347571, 0.021001208440533707, 0.04762057148452316, 0.01442168337026877, 0.007694922138138541, 0.033625718871397633, 0.024240332755393217, 0.029001278802752495, 0.03667078386726124, 0.042387383723897595, 0.03938326831640942, 0.009113959386013448, 0.039236932061612606, 0.0535472288195576, 0.03020231971251113, 0.03914163860359362, 0.03804766373442752, 0.08460258240146296, 0.01114193516384278, 0.029306548314967325, 0.05925311800092459, 0.06092636500086103, 0.07729875682187931, 0.0030147143365216573, 0.05093193094113043, 0.0681665236396449, 0.0496741068283362, 0.04261707800573536, 0.01987998530135623, 0.040635192567216497, 0.04614974505134991, 0.03613475477322936, 0.05020308594352432, 0.06795229656355721, 0.081321689167193, 0.005564239059042717, 0.05230426462367177, 0.03224095103463956, 0.08590991582189288, 0.04700466864077108, 0.11172882467508316, 0.1611875407397747, 0.0887724311490144, 0.15963556830372128, 0.2041470312646457, 0.1842805165797472, 0.11971086636185646, 0.07273592773292746, 0.08576082810759544, 0.0665502260838236, 0.1022999088412949, 0.13443669117987156, 0.20453796243028982, 0.07528296498847858, 0.13488149802599633, 0.1467068570532969, 0.18143275938928127, 0.10776884002344948, 0.08853875725929226, 0.07741331388907773, 0.08463080945823874, 0.13783425172524794, 0.19637047712291988, 0.13470418325492314, 0.06024004040019853, 0.16258627282721655, 0.04939240622999413, 0.106621437306915, 0.15778263844549656, 0.27244565210172106, 0.09792238766593592, 0.1754421094166381, 0.1717670959021364, 0.15905821642705373, 0.08732772152870893, 0.16809425369969436, 0.13066132233611175, 0.15662019939294883, 0.08893608022481203, 0.14255144074559212, 0.12534105139119284, 0.10688609989093882, 0.18047309374170645, 0.11946538596280984, 0.16616007605833666, 0.1078023664387209, 0.11747185007802077, 0.0711099271263395, 0.2265687052692686, 0.059654837873365195, 0.18801534974149295, 0.15315299401325838, 0.08312909611101661, 0.1341514621994325, 0.12750711158982345, 0.11410673707723618, 0.15183553685035023, 0.13077440698231968, 0.08962596713432244, 0.15466954692133836, 0.12049091021929469, 0.11855342132704598, 0.11232606441314731, 0.1553949958511761, 0.17810018892799104, 0.14355799316295556, 0.11112992252622332, 0.22419053502380848, 0.0847854543743389, 0.14276028025363172, 0.09542400137122188, 0.12157037800976209, 0.0745700825271862, 0.17540202156773635, 0.17476520288203443, 0.0769578879699111, 0.11751699979816164, 0.1470959833157914, 0.0936929431876966, 0.0797410486266017, 0.1305714842996427, 0.1645117923617363, 0.09154006692447833, 0.1038057001839791, 0.10649729932525329, 0.13313688949814864, 0.1327883532004697, 0.11024471931159496, 0.1755657656384366, 0.11792173236608505, 0.13140559382736683, 0.21430550116513455, 0.11286621900009257, 0.09898516349494457, 0.10110595862248115, 0.20880019372063024, 0.13928299184356416, 0.10669811176402227, 0.13222544054899896, 0.07519424653479032, 0.18495565892330237, 0.1785167008638382, 0.14075241370924882, 0.18186231276818685, 0.08897282968142203, 0.1512096697198493, 0.16773749355758938, 0.13028419257274695, 0.11055398878774472, 0.18542874710900442, 0.13046481859471115, 0.22273638019604342, 0.10539237968623638, 0.08674763515591621, 0.14472481555172376, 0.13842928622450146, 0.14844210179788725, 0.1541997699865273, 0.160079316635217, 0.149084226627435, 0.10889051269207682, 0.20746183767914772, 0.1146842110902071, 0.11353885754942894, 0.20875782599406584, 0.12096095856811319, 0.09531774278730154, 0.10331636108458042, 0.09945205665592637, 0.10600214518074479, 0.10351067994322095, 0.12143501027354173, 0.11452999365116869, 0.07978280567164932, 0.1405551635793277, 0.09319598414003849, 0.21103527450135776, 0.09481429694486515, 0.11790404974349908, 0.1150384470820427, 0.05009940239999976, 0.1295945295797927, 0.22088858006255968, 0.10595185895051275, 0.10036507302096911, 0.1602441327912467, 0.21176830945270403, 0.049560995040727515, 0.12029361937727247, 0.09663671308330127, 0.1517448845718588, 0.13327601631837233, 0.12137918041220733, 0.14155487636370317, 0.15165915845760278, 0.11097571865788528, 0.1035972610116005, 0.15232942891972406, 0.1873600206204823, 0.094163242594472, 0.21138915765498364, 0.2003805919417313, 0.20192879172308104, 0.1222095579973289, 0.08302122261375189, 0.1470161061733961, 0.10638641991785594, 0.1388043396707092, 0.17459124007395335, 0.18456072440104826, 0.1917741894721985, 0.1813650280237198, 0.11172941500054938, 0.11877551940934998, 0.22860949433275632, 0.135209393288408], [0.008628601590836686, 0.0658048689365387, 0.019844282485012497, 0.09197851589747838, 0.04466105618381074, 0.00712985937882747, 0.05334688796262656, 0.009428254262145077, 0.023807422324482883, 0.10335933270731143, 0.05170760842572365, 0.023535226305414523, 0.03590413089841604, 0.012373930841152157, 0.02583660843915173, 0.04125284603131669, 0.019719070721683756, 0.03379104392869132, 0.01671363725992186, 0.05748147663793393, 0.09973589463957719, 0.021123592409172227, 0.03953655955514737, 0.02404268059347357, 0.028112632022904496, 0.020978674292564392, 0.012749822278107916, 0.046962450191910775, 0.012684407261466342, 0.0590852823640619, 0.03091252196047987, 0.030751549705330814, 0.021919191681912968, 0.03664852113329938, 0.029497233618583, 0.01123547800151365, 0.0021568143108327475, 0.07868427783250809, 0.022057017411238382, 0.028008366635601436, 0.02511281004574682, 0.012728219419451696, 0.03493008030844586, 0.08269488798188311, 0.03174686897546053, 0.044422951460416825, 0.0600510887535555, 0.009884703921021094, 0.0593147086245673, 0.02569186843798629, 0.03605002949812582, 0.06541048402764968, 0.031317464874259064, 0.011726564328585352, 0.05175624581586037, 0.027828956887658154, 0.03063876022185598, 0.051040723853345425, 0.0072856493227716, 0.0850075049591916, 0.05507517433060067, 0.011518022527785172, 0.024534034941877638, 0.03962831445304411, 0.08493712730705738, 0.04253406942422901, 0.06318625302187034, 0.0638097927772573, 0.05588808981701732, 0.023402024792241197, 0.022602624027058482, 0.02810124450895403, 0.010861134472569185, 0.011157226798656796, 0.02356873406097293, 0.013245207124522753, 0.029196656176022122, 0.01245315743809832, 0.029695043539894477, 0.042019851838371584, 0.06858858599194459, 0.04232143012008496, 0.05800557030098779, 0.047721703736377616, 0.024804711042504226, 0.006536310447180378, 0.02152975838232253, 0.015167098193030273, 0.043847166999642334, 0.0010931114333548716, 0.010355834533194346, 0.08493067443903003, 0.025173618657780544, 0.03118702330227409, 0.010289134540861207, 0.04202732590160199, 0.012479473570627826, 0.03971120768359729, 0.03603968183909144, 0.016798983394567455, 0.01638480901185955, 0.0155827907978424, 0.055109192683760605, 0.009313896514608391, 0.008128379637907659, 0.032940235654158254, 0.043653214549911876, 0.06334015833480017, 0.0761594083160162, 0.027798629764999663, 0.016890507590557848, 0.06310220967446055, 0.061449047311076095, 0.04960385470518044, 0.0284551412332803, 0.006465001505733068, 0.032235743278371434, 0.027769676675753932, 0.03409215062856674, 0.012132897390983999, 0.04294251697137952, 0.02334215764754585, 0.03783716520826731, 0.052928750935409746, 0.025836627098864744, 0.07087145599403552, 0.07287552952766418, 0.03101513341867498, 0.018504011278439845, 0.02158411073365382, 0.050479572000248094, 0.03160837997815438, 0.06945655441709928, 0.04705949427027788, 0.018385778247777904, 0.04848597504730735, 0.03681147810337799, 0.05230299915586199, 0.05303996282496622, 0.059307773996676715, 0.061185307534677644, 0.01617769298276731, 0.019680982854749476, 0.04350902585844908, 0.06182023310767753, 0.07179365972323076, 0.040861385608358045, 0.040572390758565495, 0.033324418789041896, 0.03831660108906882, 0.061972299590706825, 0.046085291009928496, 0.0006606224363037784, 0.01765722841290491, 0.09238085323678595, 0.009252260938020689, 0.021649937112150446, 0.06564765237271786, 0.011404785211198032, 0.048321633865790706, 0.03153031452425888, 0.018929184713800038, 0.03322512875976307, 0.055408816784620285, 0.010489309156712676, 0.03858550451695919, 0.029523326682725122, 0.031338285721306286, 0.031055845519793884, 0.01716664420174701, 0.009407435111435396, 0.03258751279541424, 0.03813945595175028, 0.00975165338188942, 0.03061580198950001, 0.013382660507756685, 0.04146038953747068, 0.10075189904975039, 0.05805539512740714, 0.07879987305828504, 0.025257673879553164, 0.020809035448889648, 0.08423168158956937, 0.041323087976447175, 0.010681000388493496, 0.015305039273308856, 0.031572695821523666, 0.02634201355145446, 0.0804271696667586, 0.03851954752047147, 0.022326399206316898, 0.03698759186746819, 0.009740186988243034, 0.018202507635578513, 0.14094120929283754, 0.06320975068956614, 0.01639996069882597, 0.07419579582554953, 0.02864915644749999, 0.03849521525470274, 0.01542906360035496, 0.00810402786425714, 0.0070264998357743025, 0.04153817000665835, 0.07365432488066809, 0.046872880176774094, 0.03413867098944528, 0.006888857310903924, 0.00949721462425909, 0.022818099607580473, 0.09361474202679736, 0.04465855238959193, 0.06941299246890204, 0.018748370398368155, 0.030123317880289893, 0.04590727734778609, 0.02206009965656059, 0.03208480316347309, 0.037908207824719806, 0.051223965627806525, 0.031935946151082, 0.02939331598047699, 0.03157255672184484, 0.066776741429099, 0.01630908789645348, 0.016291323849665265, 0.027792117525158182, 0.05462691713390606, 0.03757041612906115, 0.029253880426819836, 0.02877091955659645, 0.03193836512842348, 0.02526142108919365, 0.030521770606615713, 0.030614794364997318, 0.047577403086636744, 0.00607434514677152, 0.016516400700701133, 0.061004986853471825, 0.033284436113068035, 0.026841510320082307, 0.0681174248456955, 0.015938919902380024, 0.01849340577609837, 0.04943720650460039, 0.04318931033568723, 0.05899484043142625, 0.021990398843107477, 0.009723070942397629, 0.013927770096675625, 0.018497342975544076, 0.010795637183556599, 0.08858462622655289, 0.006094698652824653, 0.01860011219313102, 0.04095747295234885, 0.030010277338858162, 0.04527522197791508, 0.054140631442091296, 0.07162277746413435, 0.01702796182196055, 0.022029735214476074, 0.012274667953274079, 0.009208592968726797, 0.04173466696270874, 0.05329484432669623, 0.011431551721346165, 0.07007343774395329, 0.025220088128532683, 0.04494358120220048, 0.0521936023474804, 0.00993287651467004, 0.047072450896458964, 0.030516763018178086, 0.011067734815047255, 0.03491734420614583, 0.04616510708417211, 0.009769529386955713, 0.06226455819393907, 0.027097326503800492, 0.03572290437296033, 0.09323936288378068, 0.033003878846232376, 0.03807748195582202, 0.06617185460137469, 0.10060092500810112, 0.10717862312282835, 0.035342381934502294, 0.03104954192947064, 0.023741297390578047, 0.03661456724096622, 0.02483129095552223, 0.050070381457252164, 0.030662536088909422, 0.038504585823310275, 0.02917642904711621, 0.044081974042845626, 0.014210794686472841, 0.05870450208229678, 0.08579946389155728, 0.010589762025379708, 0.01786958782135376, 0.05842271327440228, 0.013200993782707622, 0.019802995325465287, 0.028957370801695755, 0.04653582129893558, 0.08208791126630136, 0.08792194857129029, 0.022205730234938006, 0.03905867751953857, 0.04982858889603189, 0.014759777014010718, 0.034476018244666715, 0.05346370794411216, 0.05842261827949967, 0.025295196866084422, 0.04388056110058512, 0.04012133460491896, 0.01602185723770942, 0.06550907516585928, 0.006733291707600334, 0.03941168536299041, 0.039322797275547466, 0.02411668501528246, 0.02580667147412896, 0.025618859766317264, 0.05747552588582039, 0.013370591066112476, 0.03019099496304989, 0.02454572610024895, 0.027701807906851172, 0.020273233664089015, 0.03204151941463351, 0.05759970457958324, 0.03801465639844537, 0.03847376676276326, 0.029931998146431785, 0.03646177472546697, 0.09286197527710881, 0.021644993984539593, 0.0686000735898103, 0.025322100779573833, 0.046554606540926864, 0.019024825921016078, 0.0363381049329681, 0.04079340997018984, 0.02943105609821422, 0.009331899744990681, 0.013654416327231696, 0.03187082714534231, 0.0522452592184501, 0.12613301032355853, 0.1653887310198375, 0.09125481758798872, 0.17941706255078316, 0.09181716705539397, 0.05834451211350305, 0.20712938266141073, 0.13699301757982799, 0.06250679519559656, 0.17115078254469804, 0.07776893409235136, 0.12488390877842903, 0.15608247396137032, 0.07910233004284756, 0.08503479563764163, 0.12296635524502822, 0.11863788536616734, 0.2155616730451584, 0.25894247953380856, 0.11504661664366722, 0.22075991625232355, 0.20033734211964266, 0.11157208987112556, 0.07804591208696365, 0.06105541557605777, 0.1043822310332741, 0.10645733361265489, 0.17786880848663195, 0.09785851037928037, 0.12303317737366472, 0.07511647963630301, 0.14618548431566783, 0.08780393097549677, 0.056856220188949785, 0.08769092775349106, 0.08554681137736354, 0.14958471405719007, 0.12274432501622609, 0.1377389311258282, 0.09967790703688349, 0.1571120965693678, 0.1132286177682025, 0.16242837772837707, 0.148532292672566, 0.12426646905285971, 0.11703199653753213, 0.09736279305070639, 0.17856497184506484, 0.14817937303866657, 0.0892713511628764, 0.1287904248705932, 0.1494895155940737, 0.137379470414349, 0.07525256661964314, 0.14993481098541192, 0.09175615997186728, 0.0684876199811697, 0.09276616613247565, 0.07943681388029031, 0.18559283044721397, 0.1291953202869211, 0.07165678563926901, 0.12033965119293757, 0.15112359076738358, 0.12014048759426389, 0.11131227881248508, 0.19949358382395335, 0.16466529055365495, 0.12609531091792242, 0.09690436122140714, 0.1394752072436469, 0.11235356543745313, 0.08265320557568755, 0.10325958805957011, 0.05441515653261116, 0.06146078596689871, 0.13484671632094042, 0.08391963690519333, 0.13433648512831756, 0.1187680826655456, 0.18308967405131885, 0.13909521406250341, 0.17480705492198467, 0.12147619734917368, 0.09733655410153524, 0.1056506640410849, 0.09834708273410797, 0.12609700725546905, 0.11081291775086097, 0.09373000477041517, 0.12091555100466524, 0.22735499164887837, 0.06098186916538647, 0.17114017025700637, 0.11056346113660506, 0.09064205975404807, 0.10428344990525927, 0.14504878888172762, 0.13542106907282556, 0.15806805741574081, 0.14166733675769397, 0.10161878181887524, 0.13043633369462831, 0.11373167684567825, 0.08459527457931212, 0.1274141522922686, 0.09992922283709049, 0.17848067065434797, 0.21463929968220846, 0.1326971309525626, 0.24401259209428514, 0.1492652054876089, 0.12702582670109613, 0.1582280695438385, 0.09975889019135918, 0.16196185776165553, 0.14061594674629824, 0.13228540947394712, 0.10673596723271267, 0.07725108295146908, 0.12084431839840752, 0.06127498272274222, 0.13428160521600926, 0.12326067659471716, 0.07479150885982172, 0.078841752239636, 0.15549483549382004, 0.10770573626671519, 0.09226303241614785, 0.08895847866577761, 0.06537672691047192, 0.14464096219411918, 0.20660293448184217, 0.10261143105370657, 0.09337385530982699, 0.20214527153543063, 0.11420371330210141, 0.13653177661555155, 0.18507117272487708, 0.21262858329074724, 0.22713792829641274, 0.06491007802209683, 0.10738171543926, 0.15070888373468602, 0.17248031763093813, 0.1598040485488517, 0.09956502595118114, 0.17844989230590208, 0.1219882063035454, 0.1368336568453482, 0.20696527218180044, 0.1425018534064293, 0.12977301143109798, 0.13511438481509686, 0.18214052569653305, 0.11650666115539414, 0.08101947645523719, 0.10981034154870681, 0.12123953790536948, 0.13147210382989474, 0.12427861482969352, 0.10836043435015849, 0.11123255094779388, 0.14344367358301366, 0.08784730293388877, 0.1978314444422722, 0.14210758384849342, 0.1219441829515355, 0.09203321260533162, 0.08991483984781162, 0.08841994577752692, 0.13560074514576367, 0.06339535037321703, 0.15578295503343853, 0.14447831735014915, 0.17680687404104642], [0.0383335305377841, 0.02627768843168659, 0.05594607741971101, 0.04505510861054063, 0.016561100891392146, 0.03281300016013639, 0.016877746043194617, 0.05370724434033036, 0.019199536813955222, 0.06937145934041057, 0.050157240724989345, 0.07621335184999875, 0.013828314674486007, 0.005285364134968924, 0.05796605920685189, 0.055820908064820936, 0.01721794653816947, 0.0883969637964453, 0.06540422793477774, 0.025262214975165467, 0.010382355922566993, 0.030444733133273463, 0.012718714840177978, 0.02974336880392262, 0.01196745443823082, 0.030147249810397625, 0.02478526083619467, 0.011676998193641859, 0.02688937248396022, 0.0890591936185956, 0.04368308026875768, 0.015522021201572247, 0.037982025649398565, 0.004210392487168844, 0.07894481492361852, 0.044958254521978755, 0.0018500301812309772, 0.0328620955614107, 0.024686888525528566, 0.008858838700689375, 0.014875078773392099, 0.04675591431025948, 0.026936774940363, 0.01139145199808159, 0.05880251646574054, 0.043359520845115185, 0.057402020187250206, 0.02023661652180765, 0.02334755708995674, 0.11317832475262028, 0.024781929229253104, 0.0435608761118991, 0.026149564056790302, 0.0318523099246834, 0.016560178083766783, 0.04735941014119557, 0.05341151842315282, 0.019141976688323275, 0.024455167120322585, 0.04329726864982929, 0.028638208284974098, 0.020436334822859083, 0.004719925636891276, 0.048690264978046925, 0.04109214858285018, 0.026606184197589755, 0.014229585865645536, 0.04516589302303536, 0.04133575961792043, 0.027585902251303196, 0.03529500322682517, 0.003331910161900201, 0.027202054991253784, 0.1351490579545498, 0.01913622610404023, 0.04702735545911959, 0.016587723212848817, 0.0724507055378386, 0.07070506563676254, 0.011301200903419937, 0.00868572575771915, 0.053210675450307984, 0.029510057930435454, 0.07715773010360343, 0.0075726119601832965, 0.023013224226555655, 0.031045056812997376, 0.027123904720480953, 0.03244292037561536, 0.029570355944867645, 0.031234534324279854, 0.016209602788356797, 0.037255572487733195, 0.025936108814286332, 0.01287864554407341, 0.03693794346015368, 0.012161380594729312, 0.042049670059766085, 0.0174768788939608, 0.049073175859770606, 0.0437375937721559, 0.01750725521040814, 0.007010148838162422, 0.016642189218795726, 0.0748554811413799, 0.025707992126366923, 0.028547457618904964, 0.006322587183344045, 0.041217243298888206, 0.05721405241638422, 0.029043656707342182, 0.04648403889898743, 0.01777175664236503, 0.06369449610688857, 0.08077675769371645, 0.023383841750078967, 0.022892263485118747, 0.054891047067940235, 0.06602001203490154, 0.05222251133194991, 0.02737637742289475, 0.01926313590125314, 0.10162564180791378, 0.03891214109691126, 0.03450620626764638, 0.039536830969154835, 0.05030060499640448, 0.037335398740002086, 0.03201851707750133, 0.03290167111637337, 0.055278253076331954, 0.009623726630317313, 0.02190915445264961, 0.06420694610902242, 0.02346036523314459, 0.04266508096562965, 0.027018353509317552, 0.057369687993611605, 0.0681805218170796, 0.03358751056449754, 0.05626384215429425, 0.08394951280206442, 0.03171186335384846, 0.05777710756020887, 0.013933502021245658, 0.07227155193686485, 0.033408954074340205, 0.06166116414325578, 0.008167791496297079, 0.03226838081276842, 0.057024998989488394, 0.026505635485851338, 0.02063873503357172, 0.03505468987194555, 0.01946355139703623, 0.06572583996291671, 0.04585271973961166, 0.06482270306774549, 0.02720131878075855, 0.05761590799582856, 0.10070947025503431, 0.02730944163964263, 0.02060052503033408, 0.022842543831627284, 0.027446504017072063, 0.010077013467837657, 0.022130853895630156, 0.03292134523923908, 0.045552834402769804, 0.042189943604171276, 0.034699161270899434, 0.021298043762466738, 0.1147491740328925, 0.0680078346548336, 0.023718671640381217, 0.0417205805757216, 0.0291567549242505, 0.03302307799458504, 0.011441390479116567, 0.010297427086957862, 0.020032116245212298, 0.045867386274039745, 0.008117167694893266, 0.0451525665952691, 0.027079284257654632, 0.05226819370208042, 0.05674085905775428, 0.014778876078448125, 0.03889366119567837, 0.027399998923231448, 0.060541635645287376, 0.0062213624810933, 0.003936937361556504, 0.017519979438345348, 0.07705233325915677, 0.047418320551514626, 0.01937619679873543, 0.0356395293825439, 0.01967235019297472, 0.025138004050989236, 0.0208844647942377, 0.013727380894124508, 0.04621277416923216, 0.032436742314270565, 0.04167452161865575, 0.0710756950346487, 0.024611074111557434, 0.03772757162473031, 0.03726630691172821, 0.019299837860411832, 0.01966688289706196, 0.059980819667024274, 0.029036250497613634, 0.03642377337174756, 0.029880344668137174, 0.06389081664383411, 0.023417799035087228, 0.013656278905857886, 0.007912971062718757, 0.03419142708714519, 0.020422993128054907, 0.03207683716235416, 0.023785242711060813, 0.08599689722593341, 0.038674131368419955, 0.056733276428920884, 0.02366794096971197, 0.007811883763809289, 0.01880821379433785, 0.01804356080746012, 0.027378994871729186, 0.05793037505022117, 0.019679110098098005, 0.024598521213712435, 0.023665391374379396, 0.05697744047003133, 0.02309167305273669, 0.055299915306802304, 0.04454323197049754, 0.008993833242649478, 0.015912652115470598, 0.05703842041215726, 0.048295483126172, 0.02005950191856495, 0.057269644790462086, 0.026178082883624092, 0.03187323933733361, 0.05886339462761368, 0.031033945802067007, 0.038478167062359195, 0.0456591642328671, 0.10323155099259955, 0.01666041466939662, 0.052076415957084725, 0.02651295518236501, 0.0694666306621262, 0.033044621481427124, 0.03220853741679873, 0.056412064736442905, 0.05913128703832626, 0.021099872521257827, 0.04968109913170338, 0.028876913511859517, 0.03474898948999388, 0.03781951990510736, 0.07648182101547718, 0.034730818322194476, 0.021776331222749183, 0.0398434371953564, 0.05453504349238106, 0.03498763364872762, 0.035066991711833646, 0.029861569604171172, 0.025597669117684876, 0.04459521793095129, 0.013046467610235726, 0.049943766822772365, 0.023417698951171975, 0.025367425222482, 0.04730922908389142, 0.04772532032802701, 0.0571179718577436, 0.020862999338922755, 0.042648911476135254, 0.049476992405418835, 0.06480706962091581, 0.017560484586283565, 0.012796310408573066, 0.012217313932654048, 0.009664002772686737, 0.06633981237454073, 0.04605163228032844, 0.019720492252547826, 0.04673625375809414, 0.01718370257211583, 0.031999165258769474, 0.03762344364076853, 0.05047426585640226, 0.045073133893311024, 0.04387282919404762, 0.05758274798946721, 0.028700647077390125, 0.061724573240748475, 0.016292965904410397, 0.03011117549613118, 0.004402785578609577, 0.015452520555949636, 0.009323840445306684, 0.009411373159049876, 0.021898006122293215, 0.030382847346897637, 0.037695890824709616, 0.04165883728169969, 0.037166898138821125, 0.028644810430705547, 0.04817859868385962, 0.0474001595617405, 0.042105360821421654, 0.01430156231591744, 0.05370541229578001, 0.03198115693937455, 0.037860167545399497, 0.040574372080819945, 0.05616739518674357, 0.008480842957007033, 0.024600529677367637, 0.06684627091245991, 0.06214660166629723, 0.03552176284470728, 0.10444673257214682, 0.012114349636249244, 0.021642612326624136, 0.054632243633802445, 0.06648405534880501, 0.027028587513736317, 0.02410308038815856, 0.036791101696767976, 0.060302234920007844, 0.028633336403540204, 0.005976779020524451, 0.016568303540615097, 0.04493756938193526, 0.03334756361852799, 0.03128469841820853, 0.030668483448347876, 0.02450998766081674, 0.0322822466758745, 0.054864407783108096, 0.01790076480912311, 0.048607426030295234, 0.03133067595107215, 0.03323182590039713, 0.09116609913430043, 0.09730998945555516, 0.11547895201614924, 0.11724777067346231, 0.19969467446208, 0.14231372278715881, 0.09956058833215918, 0.1444051984165396, 0.15798626680459293, 0.18395681466375077, 0.15536697235490593, 0.15443098757948193, 0.10485034555728946, 0.1245038884558848, 0.08254741518093006, 0.09604137324328933, 0.10204682206468922, 0.17013988750321524, 0.2191454235996519, 0.1052794578884329, 0.07481774102364268, 0.08313048710780484, 0.07484286717538323, 0.13297101482748985, 0.08361266766275678, 0.14109012058803014, 0.11085405732904162, 0.139907691893833, 0.13348889989512308, 0.14102648757398129, 0.14601454777376993, 0.1303693080054862, 0.09042378860924925, 0.06643352484596626, 0.15124776267579623, 0.1891555871282305, 0.1468049053634916, 0.11199886125645467, 0.06073582558227437, 0.1837477037417037, 0.1365201058132308, 0.10085171155099358, 0.09079391589122159, 0.172190610319376, 0.18475084991327353, 0.12191488380943026, 0.12187945071075644, 0.23846961238554545, 0.13845566766602652, 0.1677467759166445, 0.09031356738082, 0.07556949675615345, 0.12955951717283043, 0.07162228213357073, 0.10544330373938594, 0.15557475334831647, 0.1744762555296932, 0.1123337997123599, 0.12317199206777982, 0.24771158503634588, 0.11067326167332274, 0.1526751017996243, 0.05281248735263944, 0.21054041891225747, 0.14367856883576938, 0.130518517856087, 0.2127280972365822, 0.08514362586928265, 0.1305031965353659, 0.09323867077806167, 0.08175879464085613, 0.1044005582641278, 0.16433787026575633, 0.1508900254432644, 0.1170314537095172, 0.22220914491585322, 0.09244985346283231, 0.15878373544131005, 0.1423135327973536, 0.16014208112444195, 0.07943404545741421, 0.10351898521184921, 0.23609354559864315, 0.13296618365815707, 0.184363650690232, 0.09361455882234232, 0.08136669639497995, 0.08188574854284525, 0.1342921903623002, 0.14302342970456394, 0.15464760309883527, 0.0803127618772643, 0.12828495699380124, 0.13453319243022374, 0.18077018351427146, 0.10238454251417092, 0.1643488761037588, 0.10922255380345242, 0.15647872484156064, 0.19067883039159433, 0.21946848769273075, 0.09980585159999983, 0.12051360043031828, 0.1405168670628752, 0.2728395281093461, 0.2398219598191125, 0.09267691163612263, 0.13496651846383298, 0.11559137169803892, 0.13978913825537476, 0.0681636059390647, 0.09764855807381016, 0.11307498386928014, 0.15339210975383008, 0.21651525901896612, 0.09136520166482244, 0.1309888104775122, 0.11421792182539191, 0.1344883276947907, 0.11947279556521348, 0.13791525523577416, 0.18257086617606028, 0.12263415807059833, 0.16595551132091454, 0.12795156559773854, 0.07750836307449, 0.15920729057065078, 0.16192489117383957, 0.09886890330484935, 0.14327230277870381, 0.12787436188331672, 0.08219837676733732, 0.15823945536145143, 0.1476484193865742, 0.10897568240761757, 0.13572821473436697, 0.11412375473550387, 0.11665585743529455, 0.11837726006550447, 0.11887253634631634, 0.09474818727799825, 0.14661821323846067, 0.0917368217238358, 0.18052272179297038, 0.11041378988219158, 0.16168388910591602, 0.08499595629317419, 0.16616048317934784, 0.07605240334357534, 0.1996320728212595, 0.15125670576734201, 0.22039592292691979, 0.09106332822037594, 0.0861592095877443, 0.1003977580528174, 0.11474626990301268, 0.1166977094752448, 0.14930093714169093, 0.17183378232376917, 0.13696271420589515, 0.18423113280108996, 0.12439657135733537, 0.11297426213111196, 0.10527015517332725, 0.11873320596558706, 0.17706349598509924, 0.06872603683067219, 0.05481007069881473, 0.13999617286026478, 0.1526123915932008, 0.08851186013115303, 0.09275079052895308, 0.2386593036353588, 0.17464223876595497, 0.1421822091298444, 0.15899968599634512], [0.02701348502055875, 0.024481945504833545, 0.05489471794239112, 0.02214916585944593, 0.016051855270883868, 0.03610552687730108, 0.05018318111875227, 0.06295677247856345, 0.018616298646000878, 0.02762326578210507, 0.014749400517238038, 0.008211059129929968, 0.0208968141315771, 0.041678531760615964, 0.06535576017839567, 0.027910927310585976, 0.04747657956821578, 0.05406076447772128, 0.05439098711524691, 0.03440326571996723, 0.07390496214585644, 0.05209735894043531, 0.01701875919077013, 0.03353109037769692, 0.01653785937066589, 0.05458110244944692, 0.029740464674042802, 0.0392518462613225, 0.07460385321506433, 0.04746058649782624, 0.01992842591633754, 0.021364918477567177, 0.045010576357266734, 0.03426565881818533, 0.03105820682165878, 0.05164721880906394, 0.007421361415513924, 0.031592410656490495, 0.04170029237866402, 0.07415415413145508, 0.053300415099199326, 0.023357858947877373, 0.037077735244695625, 0.004482264081681413, 0.010814906729917442, 0.06567919746573482, 0.0184687410281705, 0.03500114328094891, 0.03959856747782656, 0.06307121419480868, 0.025898249952920845, 0.04351650670702968, 0.04451056390202471, 0.028272510140335987, 0.018450101671208228, 0.09079543580966336, 0.02346607849800161, 0.028551318483161073, 0.04450895916670561, 0.013699040182733109, 0.0215946110630674, 0.007558054839526969, 0.01918929093517363, 0.05615304756377425, 0.062523439659604, 0.029155808367899487, 0.027264889030318176, 0.07050749659538269, 0.00862622756644019, 0.01378791469947568, 0.08629345095583371, 0.04579012827681644, 0.02299603184552065, 0.053607126498328786, 0.050632710568606853, 0.04519081561427031, 0.029831412115267346, 0.0436447667889297, 0.05869512472833906, 0.04495485845421042, 0.0285008015510227, 0.040796521053250344, 0.04059602752594011, 0.04451012285426259, 0.036510412115603685, 0.03155121001015816, 0.023513100974793946, 0.04060666016968233, 0.023264787692044462, 0.041528799438050816, 0.06971406524202653, 0.06357190518506936, 0.0869276708524142, 0.009294958602237915, 0.00857402871562434, 0.012046940574821616, 0.026737604556339126, 0.06726992782205343, 0.05976135430059262, 0.06584818661212921, 0.02349110965483955, 0.061482085181134086, 0.04997267580724188, 0.01773226760061724, 0.04259522578545979, 0.026786526931183677, 0.04119252087548375, 0.007023538454502288, 0.03488575161567756, 0.010305251443891652, 0.017085423560014794, 0.021236193599179387, 0.05427734946299877, 0.06717351478125368, 0.04099377118317144, 0.04582382432584252, 0.03267100992213402, 0.04868564076189484, 0.042561170112873824, 0.03605923382565379, 0.03033816920859473, 0.036691835416214805, 0.010401461772354586, 0.024230332845555883, 0.023827783464054977, 0.02166603196279279, 0.02610276040754148, 0.029833580034651926, 0.05453804600983858, 0.04616783818762217, 0.038718127579029114, 0.023335589428565333, 0.04195860048223819, 0.043348857667297125, 0.017458924857367362, 0.021131119058866586, 0.0556597254638161, 0.04243300163320132, 0.016752208583056927, 0.031793704855122736, 0.06823493354022503, 0.006668962346988597, 0.020706328995791928, 0.11264684184321336, 0.025993163431329385, 0.04091474220954946, 0.06566202374441282, 0.04592546887163605, 0.014456064739663686, 0.032132351504904885, 0.0485266667923757, 0.037337899141545804, 0.048352011878575595, 0.06847723161003419, 0.045134103657411676, 0.010359531700877207, 0.01378674931558115, 0.0794508731258767, 0.020484587144372717, 0.06618476033742939, 0.05620676718120064, 0.03761353702949626, 0.032836141596947394, 0.02987329468929342, 0.03044964911948357, 0.03312039687963469, 0.025812817305060368, 0.07481669607971396, 0.05533644763220634, 0.012751459243840404, 0.08651838531451565, 0.008904032525606453, 0.007884444602366005, 0.08067731160138335, 0.02858646320445197, 0.03346183230834348, 0.03138653634648238, 0.019771378986271362, 0.03745569621345826, 0.01875637541525066, 0.01986430605341281, 0.07056564026113067, 0.012691308810774769, 0.0066543382209991765, 0.016887269282181348, 0.0486549879424274, 0.03862888326070138, 0.013912035717761942, 0.024330085974984934, 0.05029907150726233, 0.04401158960536122, 0.05897231985415731, 0.06453726374145065, 0.08165827646319355, 0.05879301019012928, 0.021029533884887184, 0.013049101174276854, 0.05875072388776711, 0.03393842512741685, 0.010326695694987263, 0.014918376092932053, 0.024016782608149306, 0.04010901580165539, 0.017259343959657208, 0.03392673057637044, 0.018630077995892082, 0.010951029336346048, 0.013772575567210359, 0.01081506788198437, 0.038295824346797805, 0.040540957623826604, 0.009652107205641056, 0.06797396218670265, 0.018686582999570028, 0.025079317557226335, 0.04930790487144675, 0.03075821291921394, 0.03587331523054412, 0.01911810413002968, 0.02312981859514756, 0.03827018250844308, 0.02429528221754091, 0.024341923018385257, 0.02586724259890616, 0.017297806717189293, 0.04641571381528463, 0.0374141596922917, 0.011077654997019895, 0.05111953230308635, 0.026364235573315194, 0.07095160455043827, 0.06416400841304234, 0.044120884633490016, 0.05401995738169976, 0.0244563138445041, 0.0326585689825671, 0.03440125047096184, 0.023287396478865827, 0.05975038238934108, 0.01712901095327522, 0.028763394603239636, 0.11170961534870522, 0.0693514154159597, 0.05445373124842133, 0.05504409742674657, 0.030589386621224027, 0.05039425979235342, 0.05014107123549495, 0.04138108914984124, 0.05052607200507607, 0.01014957600273192, 0.03128984510632498, 0.06129827004458223, 0.058305048516818454, 0.04286358638533524, 0.048170493583061864, 0.042285159030663114, 0.05224667057128889, 0.039801595333431444, 0.044621721508779695, 0.03788294257330043, 0.03248533899230616, 0.04620792264384883, 0.024002073665282557, 0.07209479356450693, 0.05705698513026748, 0.024707809456491044, 0.061192846058734825, 0.018996240937017968, 0.08683677430131606, 0.016323637383590852, 0.05151425987215979, 0.013163124743316854, 0.047779134940356016, 0.04518363332109792, 0.06166945584118366, 0.023500987428373525, 0.03821295825764537, 0.03177388823990311, 0.039982852392963, 0.033583812548645904, 0.0617538791682039, 0.04311559768393636, 0.034929225354322364, 0.00815457193779626, 0.03217702964320779, 0.02760080118397517, 0.055422767464603694, 0.05924348958900996, 0.013263618324085005, 0.03839975894827928, 0.035817560008061786, 0.02999617059582046, 0.06281896201627594, 0.03572356255192842, 0.026998285836141025, 0.03196314522730453, 0.009539353345254702, 0.04416722518258861, 0.026649703737348318, 0.04187934080670987, 0.015327649756467767, 0.05796995399785893, 0.021341651511777724, 0.033842619375458786, 0.03617859152810914, 0.0553433449406709, 0.006837733514008245, 0.03317238962543862, 0.057329824061266015, 0.05628540938986199, 0.06452775746583939, 0.01247497064261032, 0.014810126008731979, 0.014868298512218254, 0.06299014961613075, 0.09864905795880727, 0.05295760902975287, 0.034654096367635896, 0.01828368247619697, 0.01486159288989646, 0.017804194008931518, 0.01655871923347669, 0.04539822680609567, 0.023086271913988248, 0.031866403097020726, 0.039611174658473046, 0.027308488297941427, 0.054984338847654204, 0.026435332472569177, 0.028495983952390294, 0.012449612940794655, 0.01753685969327177, 0.06053459923714399, 0.01946806874392288, 0.025421613029071262, 0.04398066537188632, 0.02528081870903926, 0.06585919923548188, 0.022471335982637744, 0.021485215951023356, 0.03523087488221271, 0.026543053299454705, 0.03008941827075822, 0.05289900056751711, 0.05107979050704411, 0.040106104886425395, 0.013861998000980487, 0.05255064068894301, 0.03187558028314795, 0.014908238779753447, 0.03538417290630085, 0.0921544125303626, 0.09760382904538087, 0.17567692324519157, 0.11604543376181807, 0.10461340112877743, 0.22210778535476752, 0.14087012596428394, 0.14012717083096504, 0.09523118207497255, 0.08690866508654185, 0.11605392902025155, 0.11613124130027634, 0.09604929853230715, 0.10390422346868686, 0.13910955829279764, 0.15706609189510345, 0.1589720831917865, 0.1575761738100222, 0.09474291506090335, 0.14647006190248898, 0.19716719937111649, 0.13872507320983068, 0.09283585167889084, 0.20828157583517687, 0.15284218426261628, 0.12538636395973818, 0.12515556705849512, 0.09211107449872152, 0.13104667594390257, 0.1374930436057704, 0.13247465289064816, 0.09212142215775591, 0.1185728409992797, 0.12693524227610656, 0.1234462559223175, 0.125794095652444, 0.12990361585148744, 0.11455459733094488, 0.2284738958946296, 0.1919420997479132, 0.1363678832671472, 0.07575067917683295, 0.09144269714930228, 0.0832210783181446, 0.11422390650425639, 0.16049491933413915, 0.05296336979206119, 0.19254999927112035, 0.13255486930055277, 0.11770502185182911, 0.08881314325013331, 0.11193106882274151, 0.1357040453170027, 0.14114314131438732, 0.14756107835897378, 0.1916791945695877, 0.1420229026781661, 0.11121860026781048, 0.13810392868305954, 0.07937077206692525, 0.10480595579636948, 0.08093097513275486, 0.158300604937332, 0.09005412273108959, 0.1530201911394085, 0.1594691915171487, 0.1280354189553431, 0.2613272587103503, 0.08984493038484029, 0.09505958735410656, 0.16378612630069256, 0.16741889422493322, 0.12293056930814471, 0.15102742878454073, 0.1541831458785704, 0.15904681703874043, 0.17551129284713948, 0.2091810554265976, 0.16664739990872995, 0.13673563567655428, 0.15567816208515847, 0.07921621536037751, 0.13410500969205583, 0.09927291662565299, 0.1399641188659838, 0.16466477486704076, 0.08000118538205113, 0.12209848181477614, 0.16075501537748746, 0.13600578983979567, 0.1713211898292814, 0.14059740916958877, 0.14891046737985952, 0.14732314326933452, 0.09523764851370028, 0.139395126540746, 0.17222350569708006, 0.20527691420699867, 0.1617773776607854, 0.2310516775718757, 0.0629689928942493, 0.1618948049311127, 0.16316519890512737, 0.09876243437507323, 0.1606020193014826, 0.117507079616189, 0.15257144879017556, 0.07144947962037154, 0.11647095664271287, 0.09540863933839969, 0.10367657496993031, 0.09411959922207253, 0.20779849961400032, 0.13015596302492277, 0.09603183982627732, 0.12244582389082227, 0.1735826249101332, 0.17153161710926465, 0.16801306019936288, 0.21251346303948335, 0.10797029028513602, 0.12667870175625595, 0.12643604406288692, 0.0942803170265896, 0.1464552834097828, 0.07608765323779412, 0.17769787194473402, 0.07003308526639428, 0.17781607274498257, 0.1352658202605588, 0.14112355879374913, 0.12376299606902258, 0.11331910041293927, 0.12293335130172116, 0.10674235224723816, 0.1549173750515495, 0.1172792546983276, 0.15111505479684897, 0.06275710676397596, 0.15996927182589257, 0.14862633762615068, 0.0994595680385828, 0.10006984243435518, 0.17888471111655235, 0.10373159058924232, 0.08786125361387219, 0.10197345885847296, 0.15895005794508116, 0.08616250726793494, 0.11894580455762999, 0.2071604731359652, 0.118869795064841, 0.0809299573302269, 0.14163643627294473, 0.19540102700037615, 0.10432775824197701, 0.0850953073906047, 0.2839374840259552, 0.06517102901956864, 0.1939755334917988, 0.15298865283174173, 0.11387892573007516, 0.11856952974838869, 0.11105273916785206, 0.060781036370566914, 0.10817061417869159, 0.08502732496708632, 0.17621274877871784, 0.16958122248096125, 0.13287247797208174, 0.17782211170664855, 0.05691079476049968, 0.12672602278845652, 0.09863905635263238, 0.18992272524961404, 0.11150904718254294], [0.037059367301740816, 0.03014674430180873, 0.03733620619667428, 0.0730093094919409, 0.04401103659932103, 0.028462966438382864, 0.04598510192174997, 0.043750675927315436, 0.040491964002805095, 0.05158099379124386, 0.04812552367470094, 0.052806723197656016, 0.019272363977506757, 0.02321971600343074, 0.03885962587914296, 0.01908341233086373, 0.04409501887857914, 0.03714486610676561, 0.033671550519232235, 0.019626162314255322, 0.011867426502119218, 0.00643967730658395, 0.07631304900028876, 0.022649717750027776, 0.07423154783568212, 0.049088945013603995, 0.05696473150913205, 0.06449416998241629, 0.05847509617784193, 0.0474884641090674, 0.013070867729506322, 0.030591008319918598, 0.011346037649283451, 0.04594389788274254, 0.048349508084356785, 0.028690998309424946, 0.04854494991845318, 0.0454117669723928, 0.020934594961415445, 0.06790650902049881, 0.06856345305485384, 0.03420929969953639, 0.062109200816069327, 0.06683712426040854, 0.05083669515858803, 0.10619658617568867, 0.03340570728427597, 0.070320885894554, 0.058639430574008396, 0.03565750716786299, 0.0682899220181363, 0.0048397396541466665, 0.010219812858849764, 0.028875101823359728, 0.015856574588854398, 0.034796554794801135, 0.08710974893931832, 0.05614504763590438, 0.023949295515194535, 0.009681241803004273, 0.02988543368077704, 0.06582251763237373, 0.01504705347386854, 0.03333548230252095, 0.05143340903201273, 0.04525127308443189, 0.015165971824899316, 0.04902100330218673, 0.013268348561333758, 0.010224199587745326, 0.01583783684431442, 0.02231740522464471, 0.04863239951165659, 0.012825126094477517, 0.049190749015126906, 0.05868179151522262, 0.015609229914844036, 0.027486354378717284, 0.02553513363402869, 0.0189184859128935, 0.12825446363006318, 0.019513476307370832, 0.03415971914572375, 0.03536762682987111, 0.006048876758930939, 0.07365817895957402, 0.03787715806226645, 0.02378870323965592, 0.056699899291353564, 0.04050198257235544, 0.04905905893870762, 0.020248780958354473, 0.022313283124406422, 0.031938351557723114, 0.05475681587787611, 0.03503350600866335, 0.003689712279343179, 0.04847207525745034, 0.00286982484560992, 0.029064555585916554, 0.0672297856903502, 0.054363170572157414, 0.02357685103613351, 0.026245239190757275, 0.020890588572781, 0.047279153019189835, 0.05026070035195776, 0.07403215353510209, 0.018487936783848063, 0.05013479817924755, 0.06708080654165574, 0.02662040968425572, 0.06892382300325803, 0.011729358196524637, 0.016955585884196416, 0.019116942138810242, 0.040881996109549484, 0.07547722277896744, 0.02736695426782327, 0.020755862052153264, 0.03620114942480411, 0.07162161716925246, 0.026873652523915683, 0.04957859284643616, 0.030344869741903882, 0.018182762266535844, 0.04190260777249932, 0.05834029162568705, 0.03465659337650452, 0.005702074966393411, 0.051772435661405325, 0.012341390846164098, 0.027316528937912414, 0.07915160525590181, 0.08641179424843617, 0.026237839766378914, 0.007907718353505646, 0.04221802816859313, 0.02605263363303883, 0.024225447393421615, 0.025994006511090056, 0.0043430579576774365, 0.02789905294775963, 0.0867569310856717, 0.019498358547155346, 0.02457555110699364, 0.04903780043657337, 0.0697317478646125, 0.011062229351539696, 0.02422464672209961, 0.06154843233525753, 0.006278327616330768, 0.02216109280873622, 0.042761443116303, 0.03610253453786884, 0.02626479626633227, 0.029698303900659084, 0.04035191437495606, 0.03684468560719064, 0.02563277991222484, 0.07719006229724203, 0.009702653823686498, 0.05972153108034815, 0.027842279922749315, 0.03308442095294595, 0.030401266179978848, 0.038072752566742044, 0.034605343626546006, 0.10156174416520766, 0.024136406635599475, 0.04208098105820162, 0.01641085627488792, 0.01229496972103204, 0.04503070170591984, 0.018807603112821068, 0.030556884793830768, 0.090679752374334, 0.0023309734699848506, 0.013759220301705812, 0.04675254877656698, 0.044761706675801954, 0.01285858720075339, 0.028612013440579176, 0.06456538901797362, 0.010390014038421214, 0.027249169070273638, 0.04225836368277669, 0.04125056954632912, 0.04031126334198883, 0.02461967963193144, 0.02922773307987622, 0.010916357045061886, 0.039074921647885015, 0.10263149533420801, 0.086717718546944, 0.00901486273921494, 0.01767404759967966, 0.019314599389742528, 0.03678590751120022, 0.010761476338042744, 0.03237763173612101, 0.01860593063091593, 0.05344907533643501, 0.022771521571225355, 0.00971775546869529, 0.07389204283910138, 0.022941348708367774, 0.019181372431506003, 0.03773835693885173, 0.0522175987384149, 0.028064389879416143, 0.020988989721185396, 0.014142357644491961, 0.013045724614390304, 0.02911068239648427, 0.03888873163876789, 0.06210393538432462, 0.029927007521369627, 0.04671218951365777, 0.03227729337023837, 0.07911254199487822, 0.031719754716115336, 0.07108366103576762, 0.03278109883623464, 0.01508039329200983, 0.04078740154259971, 0.11332512580390487, 0.0452076907801841, 0.017329234762915542, 0.03869280804480825, 0.06689137313514948, 0.03271451758752976, 0.019828491278791, 0.03607799531891942, 0.06519291855927024, 0.02875498416168349, 0.013015959827628518, 0.042220206266002994, 0.08866092748939991, 0.03210074534373624, 0.013512805220670998, 0.005449780379422009, 0.030496410360293727, 0.06004181317985058, 0.04019183778603162, 0.03693854057097009, 0.08743201914642539, 0.025223860783236365, 0.030933692253061702, 0.024870391535971845, 0.0362841376502599, 0.012555017418760275, 0.02710269032312291, 0.04191621579229832, 0.06822085393858807, 0.009023067923927946, 0.0582532152267439, 0.03719972227034824, 0.04592879030055233, 0.03519612031855753, 0.023997805680015256, 0.02333511445405228, 0.014563775388523936, 0.04843433513971312, 0.04746734131393688, 0.024526225003812994, 0.010971826434667622, 0.04928309763116496, 0.02680555305310658, 0.04280523576640657, 0.09899143994386707, 0.03819212723257286, 0.036775159516504834, 0.029004661299820458, 0.015214317444978016, 0.041105329125587425, 0.019582108428169574, 0.04833630718556898, 0.00794872731369521, 0.005037236601180796, 0.01712796261667141, 0.035233731514641216, 0.11970444742058005, 0.05254214543050953, 0.0420188883186451, 0.00970711519143411, 0.04149236550022449, 0.04745106325883951, 0.09486656449735165, 0.03912190001990114, 0.02879193378612399, 0.03058521363085934, 0.019164721182148372, 0.03813081820096288, 0.04325024617303695, 0.06158438790589571, 0.02225190115028194, 0.03219615415270839, 0.02170337174486901, 0.021419379394501448, 0.03839453422863569, 0.02427083290448146, 0.02742712844961456, 0.0222667559781777, 0.027358452224039605, 0.03809378036696996, 0.05246613593772054, 0.009438041281620306, 0.11740444440926824, 0.05994478267218385, 0.005570657576234745, 0.016580539223338877, 0.02922145663095372, 0.019564858371657983, 0.01789018984085747, 0.021084279786529284, 0.02872082670884473, 0.03483557055837341, 0.01806311449036002, 0.039610557191606076, 0.05500588233449629, 0.03567288277138557, 0.036262254895908494, 0.06003409145133836, 0.04935010974960668, 0.021414651701759015, 0.05020546081608959, 0.027677572332322598, 0.014051487386625792, 0.04876880201378039, 0.032553012682391066, 0.048872980887868574, 0.04680137276383383, 0.018903396990416304, 0.03770800267479249, 0.05011732590251735, 0.017097620226975, 0.05742896481284073, 0.049986219366214106, 0.018937717291659543, 0.01702964967781944, 0.013492692594549485, 0.04400265669184072, 0.012161703747031944, 0.034396188599722724, 0.03728376901043313, 0.036360320169478655, 0.0038188955929529455, 0.020287084260157177, 0.032900578674993346, 0.05499336675607732, 0.021990963723510504, 0.26129892308797154, 0.08287016036255018, 0.07723278964736632, 0.13776616752147675, 0.1070137255425964, 0.06308226074491229, 0.09656368235924415, 0.15294557942875794, 0.12473233762596335, 0.10509841796010733, 0.12024168430694512, 0.12830262604568685, 0.1146847674889224, 0.15475745791835444, 0.11546688766351768, 0.16634587251714297, 0.1932214775255748, 0.21215740857379778, 0.1484223021460431, 0.09276575222611427, 0.14084576655711445, 0.04359529819339514, 0.17672661691904068, 0.10588773060590029, 0.12322835118642875, 0.09297565703413316, 0.17380130317594322, 0.24075095568384441, 0.11463545156376702, 0.16409682748573168, 0.1430104018322059, 0.14415129061256135, 0.13430695528430597, 0.09982249606400728, 0.14551404677331448, 0.171011533588171, 0.1665910543607814, 0.08037916331418923, 0.12265436484345368, 0.14581743335085257, 0.18837023712694645, 0.11543918986405645, 0.14667962065764836, 0.0987526566854545, 0.2074631540370839, 0.19457432707505568, 0.2223874774894544, 0.23682883328625134, 0.10721495867307697, 0.07782767486891576, 0.20956503839365073, 0.09253895868148122, 0.1066316831856966, 0.10388044081628323, 0.09101942700466939, 0.19718931961272443, 0.18240671498434885, 0.1597515299384083, 0.16887390400682176, 0.11207115237734147, 0.1443459487387112, 0.11422539928129741, 0.12142150742667061, 0.14584084280899592, 0.15236655835594448, 0.15359454389129365, 0.07812979258596897, 0.07659658842853137, 0.14848247463149683, 0.10162810489003148, 0.14399050495454244, 0.1625667717307806, 0.10103824082762003, 0.18670561430709703, 0.12043775378593377, 0.1095856378919312, 0.11480972649795668, 0.12224541178771428, 0.10406775719353131, 0.11322833956884486, 0.21860049212617533, 0.2004511867250715, 0.15720604652804987, 0.08751392510852643, 0.08243690896779299, 0.14365085746560777, 0.05753988493233919, 0.14467273120369228, 0.07125777990690299, 0.1320737472602299, 0.10508489475718566, 0.165195904938238, 0.12232273763843945, 0.11461391486227512, 0.16770576526011738, 0.17727952796433652, 0.10697278952492134, 0.19117037472980364, 0.062369758263230324, 0.11172125222427504, 0.10599242855927773, 0.1292689684778452, 0.09077375661581755, 0.11179207770952157, 0.07183970510959625, 0.15856607497802802, 0.16126744502357074, 0.12782618589699268, 0.0768976476309555, 0.1809426671160119, 0.13003685298774922, 0.11766302053417478, 0.24614921744380677, 0.08072834422013589, 0.16084475841905388, 0.11821426238332476, 0.08733886985906533, 0.15779855687703404, 0.13410350334431442, 0.09483799817306654, 0.16466795041092805, 0.11115881454731737, 0.1174439215766532, 0.12090424661125455, 0.23850410910589354, 0.08168273765061583, 0.17215854275439466, 0.15997224380927427, 0.16760333361370222, 0.11782144489032881, 0.13849401846528053, 0.13404224520283087, 0.23164089024066925, 0.1946852539799043, 0.21813827407147202, 0.12209305353462696, 0.05967899372002908, 0.10511666376675878, 0.14142858742603234, 0.07051864492573909, 0.08104169169174773, 0.15721186835850987, 0.0877948250355465, 0.14886898174881935, 0.12332139190818582, 0.16553313684250626, 0.17964525387755462, 0.22910295213971818, 0.1364428342453071, 0.08076797745057515, 0.24434762554509298, 0.1264311314693519, 0.0925240105550204, 0.22713924465434893, 0.1588805081056697, 0.1350189692207745, 0.10887207011026995, 0.1421130664114441, 0.17603790387511253, 0.0854138456551092, 0.11873378950570311, 0.11894197762012482, 0.1205693217260497, 0.05505293534536447, 0.15619470365345478, 0.1798214151390961, 0.13304451374070986, 0.10188139522714273, 0.2650850670678275, 0.14657353849283286, 0.11663858193371977, 0.08046596151377473, 0.1255023663065263, 0.12093322005655084, 0.16962378019733088, 0.08411022382123129], [0.032285093130277734, 0.013050283521546848, 0.054898884147405624, 0.032590369427842755, 0.021198319470775977, 0.05114614783919283, 0.03173221940440791, 0.0350545168455158, 0.0247580855086978, 0.03152365131037576, 0.04362224281898566, 0.013091630901076963, 0.009702124566371952, 0.04337948334536382, 0.020631844510457346, 0.04632476298138499, 0.037881527827786546, 0.005333588890997427, 0.06482519329126392, 0.09906372427940369, 0.027880247349717786, 0.020022786388705884, 0.04901266749948263, 0.009550069109536707, 0.016405582361455475, 0.025521644357857958, 0.04262410084317837, 0.024736192576321106, 0.029800291106637036, 0.06842940167656966, 0.04361136929531183, 0.05586608831903764, 0.0814294201721038, 0.020588399609550834, 0.011954385005602879, 0.04334221141678946, 0.04627556919253298, 0.05171675507777503, 0.03064437849181039, 0.047708981204777956, 0.02549643847825272, 0.10386165896696703, 0.021426624452163066, 0.04869570343622139, 0.019358137589214102, 0.018945131983075823, 0.05126118327357939, 0.06891688837536744, 0.039486280110265524, 0.04195077697347317, 0.08261630005602326, 0.04948982350262148, 0.031210887378879955, 0.03988513995760253, 0.007164495198854378, 0.02251731012282627, 0.050630281413240094, 0.05985740093248231, 0.041241948758917193, 0.030612653587013483, 0.012339021910780242, 0.10097922863704817, 0.020610012646232332, 0.058381356565015655, 0.060414349261139116, 0.01254909041537238, 0.02871197521952646, 0.08548099348055464, 0.03929506215666022, 0.06590659490653447, 0.042981682012655904, 0.10597927176526614, 0.029467971795903783, 0.02458156123092132, 0.03489563447822418, 0.02653021372056433, 0.007926929376221128, 0.06685496973139898, 0.04767350400132792, 0.032639210378485065, 0.040792090219578574, 0.08170514287693159, 0.04246561202619757, 0.005205367824860981, 0.06698780653199979, 0.005907140971560563, 0.03451708657667041, 0.012884377468643444, 0.15884584853691713, 0.03467371281502502, 0.06398141463952405, 0.010931710596196353, 0.039269651020211835, 0.04705309907772711, 0.04890145221725106, 0.02309264335781336, 0.033573298648531945, 0.05071792099624872, 0.041494675911962986, 0.013954182072276515, 0.06323193199932575, 0.048407614430678744, 0.04171870103371995, 0.022175328473427465, 0.023289912147447467, 0.05217830477548497, 0.06481505597808532, 0.043476744554936886, 0.013637019537522324, 0.06322600160326276, 0.03121083988142865, 0.06500344444066286, 0.03406221705621906, 0.008159101159045739, 0.05512998638940709, 0.018191165922741805, 0.039316005140010796, 0.04431965807452798, 0.04021227526079331, 0.031633943784981966, 0.048767974201057634, 0.056817011042897186, 0.009410409639323396, 0.03912787452074034, 0.04082437152309077, 0.026460645221439854, 0.005268397790912006, 0.0451778182759881, 0.029377153276332786, 0.009650177621681775, 0.02682756812178663, 0.012809537600592842, 0.023445361127544726, 0.041623716309134445, 0.021041465923190117, 0.026572247268632054, 0.0059685123435753796, 0.03369430179840752, 0.02699569213603224, 0.04248160509658711, 0.028465592368905033, 0.046434804398034296, 0.04601855369816933, 0.03157409021098699, 0.07117769241865192, 0.041002364829182625, 0.023234072108087794, 0.02753438108733722, 0.02798897071209337, 0.0121873795121376, 0.034792581972266944, 0.07802827696182899, 0.01612936602240162, 0.027312316931784153, 0.02741357810529215, 0.038838774498019896, 0.07374333510441439, 0.07344672709171261, 0.04140789806842804, 0.05043979627745492, 0.015179724033389772, 0.0362231916348849, 0.015279572157721435, 0.071918143757752, 0.015009231931929077, 0.014750589649858219, 0.01391300602283861, 0.0243157960274922, 0.006631413067225367, 0.031536431517452, 0.04425640504008957, 0.018028273413489972, 0.005995424738752523, 0.0208739966952375, 0.09451448624687535, 0.07373809681407043, 0.018557585010837232, 0.03566091341365661, 0.03163035433473332, 0.017630989463733773, 0.05238771425294025, 0.012540365303201335, 0.022521710422422205, 0.03321433326761637, 0.009166850342548319, 0.011811561865865119, 0.02609110826493374, 0.014237646013498306, 0.026220116431691816, 0.05482520202973059, 0.06399633562458412, 0.04217951791360974, 0.0395918194470661, 0.01892432470672897, 0.05277251485469086, 0.04566529479676059, 0.01938877853431872, 0.04145381792581507, 0.012031947495415807, 0.06484752387872764, 0.029485902083771567, 0.030038239766976664, 0.03438760852441192, 0.052967437609497986, 0.029219974031937972, 0.04766556514160974, 0.005879550041364772, 0.09789509698748589, 0.05668081549395408, 0.01954125383469675, 0.034188407606312206, 0.015919691916289072, 0.07110962178558111, 0.028727510278778415, 0.01765242268863533, 0.04422221366049988, 0.012697605615747827, 0.06825405465705053, 0.01450203887985221, 0.05536844055833561, 0.014551234365041767, 0.029775965626218488, 0.07418675773910113, 0.056904654018580914, 0.02601731418898063, 0.040009942903582535, 0.0027567452884146144, 0.012405537002320801, 0.036241301734532626, 0.049603946307407956, 0.030513957275875976, 0.03515918426481741, 0.0486550863300051, 0.030205390083470514, 0.023400857712009122, 0.009889550357391792, 0.058136290072330406, 0.027417583158239722, 0.04831257203061666, 0.03779473641355123, 0.015868474396743944, 0.043055615188287835, 0.08042735287121364, 0.0261607344395348, 0.048641457954155545, 0.07859063321458441, 0.034035489561834505, 0.0727770740964583, 0.07708769850432873, 0.053213141925100765, 0.035400603631777425, 0.020930703563083495, 0.01721836722988103, 0.02816590211088104, 0.03642642305099538, 0.059224863802748065, 0.0708992759298001, 0.017621958162635565, 0.014363476940031563, 0.021562684294102446, 0.056034823014800034, 0.02565720717289618, 0.01832802643600319, 0.01593342037605388, 0.007363564650794225, 0.06243614612945488, 0.04950400149183614, 0.03483355530936803, 0.04996959525825722, 0.009410611503491444, 0.040225662756711245, 0.03045051425163235, 0.03211775960932885, 0.0672468983435205, 0.0497605080849358, 0.021695622874956046, 0.025117176418591822, 0.028496696414159875, 0.01376557138948036, 0.028735632342951636, 0.051973597545708926, 0.04834192884819848, 0.013204714699116136, 0.030873054971120188, 0.03740840232265847, 0.060730675501482825, 0.02632107226444142, 0.06693598002727542, 0.011272961972281337, 0.033318895513990095, 0.02176220073098583, 0.03301545465365052, 0.034046529326587915, 0.025898200759131993, 0.028124185777934532, 0.04790869102414165, 0.04408393840172461, 0.010332499713903027, 0.013277026176053499, 0.024360207840800285, 0.024927405440913777, 0.017553763696923852, 0.00649940619976925, 0.020544520446232388, 0.046081416574972014, 0.08803619351238012, 0.011211446835659444, 0.04235545186592, 0.021212638256007006, 0.03369639507894005, 0.05017984611913562, 0.0476567950764937, 0.013819686253555119, 0.049188937326627116, 0.052297950855323246, 0.0235309464457844, 0.014095655775495937, 0.03769357702029603, 0.06370802609516041, 0.006458212338787104, 0.0346979738346168, 0.018898034867431437, 0.026221950172579715, 0.014137535805015691, 0.0366415831127337, 0.07761643334691014, 0.053831931935357194, 0.1104967679296221, 0.021643241667853932, 0.03656191970886929, 0.030051701901746646, 0.048911280796996186, 0.10736073513648339, 0.02026323545058923, 0.03886464025293078, 0.029297835925327878, 0.025547181023284793, 0.03648884827271104, 0.045459651188658814, 0.005912759241514972, 0.03638190436842186, 0.0160191057782088, 0.022362068095909696, 0.018475075152569582, 0.022205194192273275, 0.015542504477447696, 0.02405925211496651, 0.03397066232615283, 0.058245934545993805, 0.09289623451020036, 0.06885181686707906, 0.018412263165893297, 0.1204384866037539, 0.062171870310391696, 0.23439758803163255, 0.12846528446035727, 0.09068126550742558, 0.11903869600168296, 0.11685736876513277, 0.06616109303597893, 0.10018802966390337, 0.11012499859290463, 0.10081085695752076, 0.10336051335824387, 0.08482387302709476, 0.09880577919206449, 0.12366181292704173, 0.33098015402044567, 0.16364085195319994, 0.047072210016527345, 0.12172131133931023, 0.1486293367509331, 0.1295866992856775, 0.16241157720131533, 0.12015119487685816, 0.14707380879138196, 0.13429311316992554, 0.07119294588587113, 0.06837206546749387, 0.10436593262212616, 0.14565424567886762, 0.13348957843014173, 0.1481322284255709, 0.22490942930536612, 0.1549234954374177, 0.1305763561810766, 0.10032918530383281, 0.1086953320939626, 0.12396621730710779, 0.1829928606748581, 0.09187073060976607, 0.16552810211266789, 0.11899864886488233, 0.12967824723039353, 0.1538864496563162, 0.14178788528910705, 0.19251481044505322, 0.0750907835151468, 0.18340551853179932, 0.11378612249557461, 0.07410335221460887, 0.13583311624825, 0.168135101507817, 0.14292618206569127, 0.14416691048869065, 0.08244512602686882, 0.13314461122666085, 0.10361860772328717, 0.14931886403688363, 0.13248538731464318, 0.14271355633224758, 0.12165936109210763, 0.13407875038683414, 0.1596463570105178, 0.10699908954224416, 0.16514230067176477, 0.16532070109886782, 0.1328723965478795, 0.1662341992237738, 0.15657984013003962, 0.16696483216115407, 0.1466565504670143, 0.12788036013288157, 0.23588048560278757, 0.1371506955474615, 0.1410229049090828, 0.11713585310748645, 0.11692017396645886, 0.09240883602095501, 0.10513022768178157, 0.19988470497940267, 0.11816844769886561, 0.1899041198194027, 0.24633187907082693, 0.11795721974756036, 0.14024356672806398, 0.16142246313393116, 0.0783994152609791, 0.10425940262419836, 0.11801436596683093, 0.26516068301030565, 0.11180942106459822, 0.18243130509342464, 0.1365165910018342, 0.12274036237171718, 0.12666099199226924, 0.10125947038510016, 0.1372610931949956, 0.13604118222636835, 0.20910340387906345, 0.19916696420737676, 0.14930631113903864, 0.13811583018728665, 0.13771647161671094, 0.10992941087377922, 0.11036514570670468, 0.1248238312878779, 0.16868676404867852, 0.10554821882396936, 0.11948574201336928, 0.1046149278325694, 0.22268208382385118, 0.0681462354425873, 0.1856644158916814, 0.13827949283378466, 0.0916507224153195, 0.15432406403124332, 0.12470921315252781, 0.1963071290935789, 0.1612526122480631, 0.10520454762237412, 0.09287645521440677, 0.1422806102782488, 0.13804891306374753, 0.12674468250146934, 0.15028351013149532, 0.11394053670976843, 0.13332929488803658, 0.09727009838180882, 0.07596138465617384, 0.1354105110679354, 0.16566914240164415, 0.2556260717766625, 0.22663890650229795, 0.1621128318033048, 0.14845320263079234, 0.11233679205179214, 0.08512494580021926, 0.16452190253351415, 0.11246879425432, 0.14187730263386453, 0.15255278907716274, 0.07849246276808636, 0.13624901750258037, 0.15741378680935927, 0.09957309373255287, 0.15449272069547856, 0.09789133790348258, 0.13542395963200501, 0.04364704327391727, 0.10042223959629025, 0.10630298046661274, 0.1804799876574959, 0.18341748788952827, 0.11901031966720309, 0.14356609487107821, 0.14208772991384777, 0.17518615243690355, 0.21221618327711309, 0.11393977675054755, 0.11976082010992936, 0.10539370961487293, 0.09638982811676604, 0.0623887979558536, 0.09075935810272183, 0.15575278736650944, 0.11080057519887175, 0.10214501286723784, 0.12979275680014066, 0.06041316861020667, 0.14234876233552182, 0.1043799240142107, 0.13458309189549514, 0.14719419447439058, 0.14127697556146554, 0.11539389086621148, 0.11793994424598557, 0.1043507062963077], [0.10524658286677939, 0.023776822091479386, 0.015543218635554825, 0.005868379658620272, 0.00809723318421415, 0.024009961634874344, 0.0393846321717969, 0.03743090932922704, 0.039180993634675226, 0.10465687486742224, 0.07517567503132991, 0.008829969580152204, 0.05291504452803305, 0.013314851958836828, 0.02237724183526422, 0.04498581322176116, 0.038857257791927884, 0.05782964652670281, 0.04344619351572224, 0.07787747933928456, 0.03795603775818433, 0.032999237666704824, 0.03646668731900198, 0.04817869707143732, 0.021689181881291524, 0.043322069104760885, 0.08894762889082942, 0.02997375519147941, 0.004783017943347139, 0.06296527452234711, 0.03394688645909939, 0.02538357605226338, 0.028592905894454037, 0.026680890903142945, 0.07223181014082261, 0.002648851435099329, 0.04488917626440525, 0.03749406736876283, 0.06421311399234192, 0.021590940188616514, 0.12165484204888344, 0.00839703794502254, 0.047296401379363875, 0.04316644370555878, 0.0736203845590353, 0.047810018461729796, 0.03397718304768205, 0.08109621198049613, 0.030961322199021066, 0.03478771009083305, 0.016312626456575732, 0.011253838310949504, 0.03644828884197133, 0.01996526527883751, 0.05358309278796826, 0.03540581138804555, 0.05348217088196959, 0.05931295800421919, 0.009285604148837072, 0.07098403173897948, 0.05908368102141789, 0.00565822676123519, 0.02376140747219324, 0.021703086760161177, 0.0818409923730152, 0.03188135800883174, 0.04805021985833134, 0.01696640342873122, 0.013221896053957087, 0.058271542457597594, 0.017272368439340165, 0.043878359254449606, 0.014690425646092211, 0.042045683666531525, 0.033928186033985445, 0.06627885278846536, 0.04583576314949563, 0.02202333662925022, 0.05641793067167912, 0.031534060037561824, 0.05474558612331748, 0.02912461611309222, 0.053050178169671974, 0.04229251095759017, 0.02941958885639906, 0.02392833387213094, 0.024996275048969046, 0.008789730757208807, 0.04733515251427889, 0.012306213894459819, 0.04127760238147207, 0.016774802102840373, 0.04246818367391825, 0.022886249968515973, 0.03410761444164174, 0.0030452829752383487, 0.043244353096399984, 0.012160199943796864, 0.026513530240793313, 0.05281096404152257, 0.04182620472939951, 0.030955866777471135, 0.015350204260487641, 0.058994385812963755, 0.03346804090376411, 0.05658420228532382, 0.018405096139758825, 0.056661629916301796, 0.020313041617295573, 0.042669661077005525, 0.030689942118312632, 0.046335375269076655, 0.010934334830380976, 0.07982615048864058, 0.02672556564877076, 0.053179618902504444, 0.017644022425104464, 0.015814261145091484, 0.0534070604480803, 0.043965103171233616, 0.02546330900596721, 0.05970992134617908, 0.047481380203472714, 0.006979451489834381, 0.03386245634672897, 0.027320462744683027, 0.051732941530644894, 0.049633411690592766, 0.17355704413993017, 0.0307971404732338, 0.01153677299485675, 0.04387276812589594, 0.04038889792614749, 0.016117154088403498, 0.011642448886829828, 0.023263759711491208, 0.058853481230991225, 0.02272454828822187, 0.01338296924119017, 0.028267975830073868, 0.01189275027718395, 0.022842321611408676, 0.05783516980175461, 0.06078286162976708, 0.062133539867188246, 0.018344655632972717, 0.0038138871563465466, 0.022886841990319744, 0.05478404888084956, 0.020600311291803206, 0.05983699059912136, 0.0328536613711289, 0.017454153059848716, 0.04074948839843273, 0.018884913696508323, 0.041080786513962915, 0.005208282556850463, 0.036571789000715525, 0.019509053955386792, 0.11334368373666491, 0.0732697176613978, 0.013887970625156803, 0.029233632941863368, 0.06850261560508183, 0.007175869990273246, 0.04821694948311363, 0.018931851356423328, 0.03487552609294653, 0.013943451889125364, 0.009550361727763499, 0.04285272643236177, 0.02017972305683153, 0.0341429254040122, 0.01753823203034699, 0.058241632633975575, 0.0845203846693039, 0.048942574832056246, 0.06179326812603644, 0.020786355415891324, 0.027195900678634644, 0.04125775183950152, 0.009724991196500403, 0.06967670510389976, 0.04087678496060627, 0.07484378998300859, 0.006445478780993393, 0.054407662113330195, 0.009498035651631653, 0.024515970643343668, 0.044268075842410326, 0.005966021271888167, 0.05046674429572054, 0.03419165100370135, 0.024327614411179508, 0.02833214488678745, 0.0360239330413086, 0.010919810788306807, 0.027022972636457, 0.021414936686466848, 0.024560557179419056, 0.05962023937276431, 0.053807389323732684, 0.06763056239911489, 0.03395518154970237, 0.06787840410002641, 0.05454890935548714, 0.034810003358870745, 0.011318857232773942, 0.07442068268678018, 0.013972101333950247, 0.037236468334283145, 0.028396146006083915, 0.007795595530686634, 0.05559267263327326, 0.07274251630795853, 0.028242970118299127, 0.015835874181772982, 0.07355756578700882, 0.008804659375787845, 0.07707668588097606, 0.02692279881531639, 0.011604174422765417, 0.021396930063409463, 0.042125883113060675, 0.03658432832786015, 0.04408104105719498, 0.08785630030823605, 0.016515432091962014, 0.024434117267706564, 0.03769274581489818, 0.04454689945227333, 0.07962262390979699, 0.030080617671566348, 0.04061627501089658, 0.022429729911631772, 0.0769926764603172, 0.010744564700871706, 0.08652437677873032, 0.04144179428528462, 0.02800116059370339, 0.05029731749423912, 0.003009062775942896, 0.06560734060725995, 0.05994549513395343, 0.022548325958528688, 0.02437958849727043, 0.05147287941404751, 0.0259552027897111, 0.07394470394189868, 0.013834815888133432, 0.03460923841755305, 0.07673808333597013, 0.044360712835831304, 0.01431894299042012, 0.03528340706335647, 0.013377324678003788, 0.032968652700739245, 0.0064426615884128425, 0.030454561713018587, 0.0453390212330435, 0.0479669025433915, 0.01965744617129011, 0.029120806138962507, 0.02553525916300714, 0.04531675171373146, 0.07016065663525037, 0.029607984104326794, 0.046391812419252734, 0.015745198154555898, 0.015073757219527448, 0.0354293294117919, 0.025184668600559235, 0.1787105311772653, 0.002800091165616842, 0.010449560575320252, 0.0477358681548919, 0.020390889939985106, 0.02540102458026792, 0.022592222085222602, 0.02804068356220211, 0.033472987424050055, 0.012488031593550528, 0.02404659574053117, 0.026808772701770067, 0.023937999603471587, 0.017300305422395468, 0.0411958626604506, 0.016458309621417096, 0.053678739084196944, 0.05260320340416261, 0.05281788170603769, 0.014887124466310655, 0.03959712219823684, 0.056355088150927, 0.03550636688513415, 0.0455729156466467, 0.03143976402602025, 0.03290614605482135, 0.012124067105885063, 0.06999480232064213, 0.02785467166852738, 0.05402929063088127, 0.03549447216625724, 0.02080375644644456, 0.034219179169407914, 0.01798603460857911, 0.03329879730673773, 0.05791248208177941, 0.024744830327108502, 0.06204703343766076, 0.017338615509548357, 0.03397735268143671, 0.03952908209924187, 0.04225648074809994, 0.024248658380072032, 0.038928405581308265, 0.037509001924523284, 0.01741016872360238, 0.04110200430399605, 0.025556071528366635, 0.0145904011026557, 0.03675952267700008, 0.029032830681119646, 0.053117041010409594, 0.02881270374304482, 0.035294212733528445, 0.03873067708419902, 0.025138931947627237, 0.023483219988910214, 0.017897402668105702, 0.043361542879470756, 0.05979158303567341, 0.058004498215658326, 0.033477292728743384, 0.053078486650649986, 0.045409202110022306, 0.05066043890214392, 0.044341367802449634, 0.032933127999837906, 0.015777399730203406, 0.017955846585599438, 0.04676728316449693, 0.02424927754327655, 0.06340808647551707, 0.027333280271185294, 0.05834867153316736, 0.04805464390665293, 0.04445843205654195, 0.07158569552536521, 0.04101135541817971, 0.028525201670293297, 0.05361150983454926, 0.29297798605901854, 0.20043900023613656, 0.11596593659903322, 0.09913436656019517, 0.12643820180424623, 0.10231681793395962, 0.135586020935859, 0.09336685961378471, 0.23371080202715738, 0.17598136833735875, 0.14917116053402424, 0.10245137821350779, 0.09326266377632107, 0.08421997007514749, 0.1340543231261628, 0.17904070631733962, 0.0791739019166146, 0.09760946088603564, 0.18397160672715732, 0.14238961014364446, 0.10780012048780918, 0.10027507892144577, 0.07389945244150502, 0.1447558110313756, 0.20591595848756178, 0.18554533299590859, 0.2309067967746939, 0.11678201066596167, 0.16706670740885393, 0.13400495291820594, 0.08851697628519364, 0.08050064822392804, 0.22169629457805837, 0.12782781438103744, 0.11378985443817717, 0.06874359053160463, 0.14119557850062847, 0.10293366054871253, 0.14222092633800848, 0.07232096285692283, 0.16131031486604894, 0.2139527036675385, 0.1167433884527002, 0.1421946534620864, 0.10337921378335782, 0.08073935684348856, 0.12577373960188457, 0.132195096462965, 0.17482496824647697, 0.08538743707218341, 0.18478797934949398, 0.1013915336557797, 0.11699099945170538, 0.154995040169784, 0.14822925893323763, 0.12757828991327966, 0.12667473911174706, 0.1140521557203361, 0.08201939958546843, 0.12767430261841842, 0.1294678199504103, 0.21552101522684097, 0.17962655345244066, 0.07282263093761035, 0.14400349211479935, 0.10974177558507238, 0.1606187926871436, 0.13256502018443175, 0.15187041355030878, 0.16695815537657055, 0.11187813630593674, 0.11371318676642009, 0.13426051634762967, 0.1332727186381817, 0.1735745096313102, 0.18345927207597665, 0.18257911716188702, 0.07230043717260871, 0.12516213527747563, 0.12789113526897772, 0.0868890622098531, 0.09476762052093234, 0.10711412836930581, 0.1346311050334147, 0.08182702812233142, 0.10891530636165823, 0.06319278052874974, 0.08295578469655343, 0.18525072666151182, 0.15574503849659646, 0.13977969304791518, 0.09172692189791373, 0.1929792676653181, 0.23875904828310013, 0.23426041539226258, 0.1285576873591968, 0.2155573439917394, 0.133492753974029, 0.056099555255579095, 0.1603776549122163, 0.12961977108248643, 0.05982555728405714, 0.11039572049464498, 0.10554386941449982, 0.1431964018515178, 0.1594333512974637, 0.11089164816907474, 0.11063199995883874, 0.0978627580084971, 0.0710109288671187, 0.14313472301832267, 0.10376268784914698, 0.12095747089811734, 0.1765019539743662, 0.14906327346605913, 0.12446331206176962, 0.09644263849726745, 0.18667448312044144, 0.1148552019149065, 0.17182498850992747, 0.11740523150988988, 0.1648100492145334, 0.16242331585713796, 0.1362440777676446, 0.0904185910310064, 0.11726757032530648, 0.14358418461467537, 0.126056363007852, 0.30363052444798605, 0.11376400903931685, 0.17530523533267633, 0.15774960736078875, 0.15840466506779194, 0.1333606703472989, 0.06370970886200666, 0.21251852491072246, 0.12356605806521007, 0.17690192322645867, 0.12019277550280094, 0.10482922954750912, 0.1214279942214489, 0.08861018664070539, 0.10978474720780339, 0.13644959245409283, 0.19016315734812192, 0.1413967777043581, 0.09743803579892431, 0.1373858079314232, 0.24649266472884587, 0.05561209909085717, 0.1111811383494309, 0.10216031383190836, 0.12573563307523727, 0.1242575938148158, 0.11959570539849144, 0.16172177850135735, 0.11293331254273653, 0.18027082245264733, 0.11453551692622048, 0.17845196862305912, 0.2013189380190202, 0.15568335966340133, 0.11672179746840682, 0.16035618606422627, 0.1358470804989338, 0.09055794176778623, 0.08207334990480117, 0.1599696110934019, 0.12599099294415542, 0.09509272021906716, 0.16356866939791612, 0.12488428875803947, 0.22869186848402023, 0.14104054681956768, 0.25391765630670954, 0.12322346573429448], [0.019141539033236246, 0.016710717863004123, 0.0951122823836548, 0.0466917961436723, 0.025348105634163533, 0.03432810778862663, 0.03190798033028841, 0.051138510927557945, 0.005448913126851299, 0.03193550510331988, 0.027158347158027545, 0.0012019280942955188, 0.018098420363717845, 0.057318730013711114, 0.037347066149647744, 0.03699313549857054, 0.028194814488025646, 0.0173853072005191, 0.022047219365569096, 0.023446821674172367, 0.045556037088057826, 0.046468181535601616, 0.032834462222776244, 0.06211011005299432, 0.02632399505403425, 0.018425014535231248, 0.08165484986134938, 0.09573842092816319, 0.023547511181927154, 0.021002097321408134, 0.04542953101918101, 0.03465638642332383, 0.04569522158375808, 0.006461504081796322, 0.0029262024119296776, 0.04329528732757483, 0.0683019660147173, 0.07061073569847004, 0.04663196631840297, 0.06399733307106154, 0.05628589793507542, 0.004558929208932179, 0.015044254516916615, 0.014371663465031555, 0.01701514938447092, 0.03558327882949795, 0.052911597570138316, 0.02608257399073669, 0.020771213906950185, 0.009478938283531793, 0.06301730458757707, 0.039967456433389864, 0.06063946682427611, 0.023973985708185604, 0.049950243439525366, 0.004678008287945496, 0.08535328640469483, 0.06588871550879308, 0.04129565819831831, 0.053771097878260274, 0.014212788731258894, 0.10522623360157013, 0.03325442111651812, 0.021632486887808357, 0.02041088297430958, 0.026901759140725647, 0.009583428435559784, 0.05320967461115547, 0.010136114716130708, 0.03968578976179872, 0.034602894115128686, 0.05349103594198823, 0.07104446885309049, 0.02146435948088765, 0.05114833950730307, 0.0202701548114419, 0.030687054951808283, 0.04979602939316204, 0.042728008303259096, 0.037978979027164836, 0.03948941154937659, 0.02635048166848719, 0.05026423891208001, 0.009508614860741156, 0.06879288610070944, 0.03535196284896561, 0.030411885253020694, 0.04910881591162511, 0.048150201993329186, 0.04223412980458566, 0.024446469997721057, 0.026912368035742214, 0.02609123888292483, 0.01239151762066675, 0.06966293762837138, 0.05885263306221791, 0.06306951785726206, 0.04782378932993327, 0.008998002840339072, 0.012970775332567947, 0.06954603283000843, 0.006165258661245129, 0.017444314302078316, 0.0398373134168131, 0.027899183565750718, 0.040985567694795985, 0.04704390832089952, 0.046899370183902125, 0.005188093171454966, 0.06421379931271076, 0.06629812318299498, 0.04948221712506243, 0.0008035098778366644, 0.01653798489964434, 0.03232582898012229, 0.06180625528629337, 0.03870523541367479, 0.0029356688236085965, 0.032257184984960725, 0.0391963217407465, 0.003315485585647236, 0.020553431307364787, 0.07181470787950925, 0.010395947827159293, 0.0055352630692401105, 0.03700312014136996, 0.03295073598357184, 0.03193474853677409, 0.028551498294941018, 0.03879309891323958, 0.024668147388313497, 0.054599019166614325, 0.008053493120574524, 0.042479647523058314, 0.015836459418226565, 0.01967694896406361, 0.07172502590609448, 0.055853810227875195, 0.012854462556008781, 0.05424166191369295, 0.04010102265913572, 0.057559406384825706, 0.017234940447711518, 0.023379719649840678, 0.0609127264469862, 0.01727319455572537, 0.07247245937053647, 0.015538764053157397, 0.05828846512096269, 0.014847554000360625, 0.120347671476858, 0.1006659490189382, 0.01789269533141383, 0.018795850886298076, 0.02620444736177368, 0.012749667063222399, 0.024693020785759603, 0.034898022921489816, 0.03837506027360048, 0.03584904403292707, 0.043640899139323404, 0.037155712489038706, 0.0599903937961374, 0.01301383092400751, 0.03445824741252831, 0.05516514807407345, 0.05147474877802389, 0.017063790167282735, 0.03654593003115483, 0.003595593959159617, 0.03482473774680069, 0.020358749432489276, 0.03881564323923417, 0.06666865758597851, 0.06051610915788582, 0.0075654339078547695, 0.0498084024792271, 0.037038074872855625, 0.01586956514178642, 0.09499914345464536, 0.015110175890315856, 0.05090211271973593, 0.030827209752585207, 0.01185437064019165, 0.032306897853102, 0.03637761263442891, 0.008687874169221945, 0.02496183939677264, 0.039439515476780276, 0.054554069614303966, 0.021653694499816214, 0.00579879419612033, 0.021933335744376694, 0.03794940847105213, 0.034225615074059794, 0.020724369545600245, 0.05946921104831355, 0.0731649382838181, 0.020654068228655627, 0.003985838108097336, 0.0175440504681319, 0.06346728865589414, 0.013435515841203076, 0.048098636724586995, 0.050440607126802206, 0.062344333556081565, 0.026547818311623166, 0.04251939271177564, 0.03102964049737368, 0.04802639988650169, 0.05213981826922723, 0.05026762480182307, 0.03321614834879126, 0.06003835265125547, 0.03746132466143795, 0.013259718444065323, 0.011795348271594515, 0.06701975874602795, 0.0174399292695203, 0.05242245185321995, 0.029109827442360774, 0.04155832249671221, 0.04998947972697871, 0.04946005617135337, 0.025938834828723754, 0.045962696695434194, 0.0377779833839408, 0.04652912415830152, 0.022302781098655293, 0.04942926085953202, 0.022343055544687167, 0.029083089769950936, 0.010570523013094706, 0.04817864618131092, 0.0062211724912880784, 0.09400204981544188, 0.01255210311085518, 0.07742706779390574, 0.028116394499582902, 0.029402801900037696, 0.040561802219599485, 0.014383161240922553, 0.02627332036250404, 0.04137726899768625, 0.028736331234020845, 0.022128843735637407, 0.023251384929088608, 0.051819373321320326, 0.04166304419881531, 0.0402999351998525, 0.06188975580568824, 0.04069455420332296, 0.0512580654051687, 0.024304330482014587, 0.04102729759844286, 0.06374755075999669, 0.031765698322228024, 0.07805247352059398, 0.03559381987101265, 0.008717409950414938, 0.014726165781861969, 0.0342335437557527, 0.0525973849663777, 0.03541237621435097, 0.027753252735627548, 0.06787792234016315, 0.029214454149561267, 0.07368301334125654, 0.028428213571065238, 0.060080340398209434, 0.09290145922984396, 0.05607310935322728, 0.009695736159171377, 0.03301846734913332, 0.012257160901624178, 0.057216508713151724, 0.023814524889790585, 0.04667860881558486, 0.021265679338414754, 0.0271863587799349, 0.05491958625082459, 0.08746718761644193, 0.004873871237837842, 0.051160810980945826, 0.006036754306738398, 0.04391319863498211, 0.05276897629456861, 0.005890097868229661, 0.037761593370565345, 0.021814278293667094, 0.009799777629918285, 0.17501406238547393, 0.02859335033489125, 0.026911981270781586, 0.060338957235217094, 0.012958687231210726, 0.04133803949558309, 0.06665210811687367, 0.025647811159225445, 0.005361943173089198, 0.08501339464315347, 0.04035491689241358, 0.05359386113871421, 0.04119269050923841, 0.034891383456332345, 0.053817041484372954, 0.0003237014919120286, 0.08050712144800595, 0.011014168716168829, 0.0507666296325624, 0.010541123787074216, 0.029531981396887983, 0.022062712016382387, 0.031317108643374274, 0.019129115057044795, 0.006374478148895183, 0.04230898239516786, 0.02915051579475403, 0.03345655669857349, 0.022480146759854894, 0.05340619870860662, 0.03901384671085647, 0.013917989862550582, 0.038962020206132104, 0.0385790245075311, 0.02297258167527616, 0.07763057401669876, 0.0377036804067237, 0.049680139004651985, 0.03276104812643357, 0.04822967201471329, 0.05192887530262981, 0.02147892253872539, 0.04147220961749554, 0.02826712596496301, 0.051656467241368124, 0.10857744341982262, 0.047766826315117736, 0.04088967712596059, 0.006554946835551943, 0.030156963039189577, 0.027925634557115178, 0.083933160108115, 0.039536308497190475, 0.06345006065177065, 0.018400743337614194, 0.04558694435815726, 0.028819950497043983, 0.09088202366339308, 0.04425107854019318, 0.031214839845363582, 0.047421499488076994, 0.1754759004605668, 0.09010717738419771, 0.18604077212512493, 0.16119319972183022, 0.06343131272920541, 0.09667120980364935, 0.09939874415951115, 0.10746928716876678, 0.09643549352352108, 0.10581001799021449, 0.08910981233098678, 0.05956963423107352, 0.0938805920471038, 0.10549641267529555, 0.09693901400480952, 0.11817424238792487, 0.1515253513519253, 0.11428644029157502, 0.19701394545180456, 0.13703009273324693, 0.2118384564029319, 0.09992287853466612, 0.09492283540644816, 0.1069019233275737, 0.09453040467841284, 0.09156306247626032, 0.16345470265618392, 0.22519030209098542, 0.12341321126690932, 0.10315961270992245, 0.11542051658034325, 0.16051207269941056, 0.09839279563831431, 0.12572400298501762, 0.13600874825247697, 0.12944772174315794, 0.16133033164909907, 0.2375448505793299, 0.21620720412049974, 0.1851294453122786, 0.082263204003019, 0.1349293618862118, 0.09692072070070676, 0.11665155552327633, 0.14977329250957283, 0.11573922447860241, 0.1583153155765363, 0.12378251073615891, 0.05914261178778751, 0.09863486979156733, 0.10787015208708388, 0.10545506953660931, 0.21807689379368508, 0.16670983870114597, 0.1297374019133193, 0.11545926092990808, 0.14062433343912872, 0.12597135614071572, 0.11830720811017922, 0.2026635772947754, 0.09469827424202647, 0.20408467389643192, 0.06716439527060304, 0.10091635558222022, 0.11000223803733077, 0.07476500528199331, 0.16556219171200479, 0.1953159115676369, 0.12842588871717453, 0.09007281637085335, 0.11294522083231381, 0.1329644058964082, 0.19461328855582646, 0.12617209394063267, 0.10926269593515567, 0.1187024140464408, 0.13478464393743447, 0.16177979324545178, 0.1350371539592743, 0.16889561712741852, 0.09605130021061216, 0.16096983956439154, 0.12829354724713735, 0.1050545031737004, 0.2087327880518777, 0.2009957789310387, 0.13097528048924037, 0.17724581834461006, 0.09419648402503558, 0.144133594419275, 0.08640794695488044, 0.11203090168003525, 0.14218599535524845, 0.0816695944273046, 0.1931571659765073, 0.16753811282770975, 0.09959584501172815, 0.11343603235270296, 0.08432412520051003, 0.11815019510686398, 0.15139979523207459, 0.1861896834203175, 0.14785492473414966, 0.1809709213141884, 0.21115184681756155, 0.20087433473340102, 0.10175228358379432, 0.15051263783659252, 0.04737332010907786, 0.12860232139272348, 0.14419182629457541, 0.13641801343432494, 0.12402500558112349, 0.08083739836833306, 0.10909747265811477, 0.1475821943687541, 0.10256828301187072, 0.1334353227700506, 0.1291508355310985, 0.12797957552330835, 0.08843876833894423, 0.1112440928284611, 0.0923436830884644, 0.08176150878093072, 0.19989310524293355, 0.13432699920875685, 0.09763945213385991, 0.18829007499984332, 0.11024357258741345, 0.08839197656405823, 0.08223926528756108, 0.1540498544595071, 0.11232387953038726, 0.15392348409763404, 0.08572331190641437, 0.09200503983135734, 0.12261838891676494, 0.12005462577300412, 0.11786142417362758, 0.10204953620476381, 0.07264542473214013, 0.1555684701140438, 0.10412733935351882, 0.17368759427751812, 0.1950003927839654, 0.09886703054819788, 0.1680013079728399, 0.16402722336351871, 0.10088853564645563, 0.07556885893323592, 0.19276922036494526, 0.17801952468497412, 0.10198577426906143, 0.0901279201997178, 0.1957442978663104, 0.1252082349466426, 0.08704589200871331, 0.09023734075682503, 0.1524411022130932, 0.13471502624452114, 0.22658258809575013, 0.11529748461076192, 0.12285101786255836, 0.15216115223509924, 0.09500459209084511, 0.19412561186722346, 0.17590249542679104, 0.08686565953705992, 0.2501961631434304, 0.10724148939230613, 0.07971493181373392, 0.1285128090530634, 0.1641313920595816, 0.1462866538869483, 0.14103868763361657, 0.09627782234123775], [0.01772857128110315, 0.04897425563207694, 0.02969746251723596, 0.04625104693695903, 0.03498696529173425, 0.026300505868026187, 0.03218968432130558, 0.041726236165102036, 0.06188464643699782, 0.036117387669427056, 0.02188753802329302, 0.011595905625394412, 0.08044387519891773, 0.03330012384269919, 0.028711164370179176, 0.045373874184276373, 0.034805979646210156, 0.05345534500000732, 0.03825194009446672, 0.024224292187552367, 0.030717371896441494, 0.06015557636107717, 0.03124555034030761, 0.03847814331363354, 0.03516822235126581, 0.047278403237994225, 0.04745046614802309, 0.037740507894860845, 0.03351415753630655, 0.030668452914272035, 0.04590279223131282, 0.027303674091984118, 0.046154884954116175, 0.012335056721765016, 0.03489863021033151, 0.046285594547433515, 0.014428014101992761, 0.03995392983779311, 0.029506529548338482, 0.0679464340209961, 0.05312515968190772, 0.019993421089436327, 0.02420904380934579, 0.009854259751071888, 0.014365780566419874, 0.02320282387414149, 0.01886619291534381, 0.0723491966990488, 0.04752659438444035, 0.023083718925980583, 0.014961318877924765, 0.0057946933001013735, 0.009654113972958709, 0.01761401760657983, 0.035012230543153625, 0.061483075842261314, 0.024815844105822698, 0.03361935421292271, 0.08211792287017618, 0.04731032831062164, 0.020740947852443372, 0.018662187969312072, 0.009217190007413072, 0.03480734010892255, 0.007904626778326929, 0.059579656193298955, 0.005923715037559825, 0.08056327022079911, 0.055240370466240814, 0.01455472203503762, 0.08324621125523533, 0.01909455726854503, 0.053028387017548084, 0.19920066025640282, 0.13090986971344265, 0.04692393993692739, 0.391422126442194, 2.139221804482596, 2.7066883487360816, 7.380478160721915, 13.089427317891802, 8.22585940361023, 9.526359813553945, 8.731378197669983, 8.261093718664986, 4.583570275987897, 1.8566346594265528, 1.4641968203442437, 0.47806689568928307, 0.4039647105549063, 0.5991573323096547, 1.3982485362461634, 0.479583774294172, 0.609215392598084, 0.5842709253941263, 0.1427872045231717, 0.043358788027295043, 0.0165058002873723, 0.001344964442458669, 0.009668219019658864, 0.03749731755150216, 0.04746428451367787, 0.09327411066208567, 0.043608573731034994, 0.03690476309774177, 0.03239826259336301, 0.07631650274353367, 0.03677509505567806, 0.03465166721226914, 0.0372157560528389, 0.020365366845258644, 0.01583831351516502, 0.044805224519222975, 0.09595290584755795, 0.016508086950385144, 0.04577207924532039, 0.07730010032121624, 0.023161487520805428, 0.018669336335733533, 0.022725477881197418, 0.02587227732874453, 0.06932888805334057, 0.04587289937106626, 0.005062411522625813, 0.09080359180058752, 0.022687043961403624, 0.06110521326107638, 0.022954039009554044, 0.03694682887622288, 0.014074454948838269, 0.028084886725991964, 0.012505247723311186, 0.03773961222863623, 0.02863073082906859, 0.039398878014513423, 0.01159447306833629, 0.045199015709970675, 0.025824450787955096, 0.011436852776179356, 0.035013655466692786, 0.014870571604530727, 0.039906208469931564, 0.028489425911435058, 0.020478668622672558, 0.02879262589184301, 0.04236695981983628, 0.044362378639302084, 0.08248544457767691, 0.013373877720109053, 0.04327169805765152, 0.03727023223681109, 0.02945846552029252, 0.096251488397164, 0.04263266395511372, 0.048669291460620503, 0.038468643823372464, 0.021801682987383435, 0.03146276297047734, 0.06598563745085682, 0.042666329470063956, 0.02841934172569641, 0.04076157310711486, 0.06907467490860394, 0.029348206972437244, 0.009967183245212903, 0.004063253440628094, 0.038839127336229594, 0.04607344718117799, 0.02779911831021309, 0.03578221851161548, 0.018712496251932213, 0.06785886229148932, 0.024333300534635782, 0.05819657790873732, 0.05502114597974079, 0.02947804464825562, 0.029936968415443386, 0.04694693209603429, 0.009185855260251887, 0.065429598359125, 0.05272129563880818, 0.008496608718165329, 0.054508397422198734, 0.012013946809539837, 0.09496388677507639, 0.027400923427194357, 0.038189623438354046, 0.02601889008656144, 0.09166584696088519, 0.020852907826857905, 0.0250619894691876, 0.04943693848326802, 0.014051194768399, 0.008333778973402721, 0.030683580852512802, 0.03175062805946384, 0.03268367817093219, 0.03934987082279154, 0.06310972105711699, 0.02989901795185038, 0.03571754055363791, 0.05226404106776629, 0.020179202281204716, 0.0393660572756614, 0.0444642335309514, 0.051159464088933806, 0.07362854733530964, 0.013579858051213835, 0.011875024397990533, 0.018795043429625884, 0.042782596445509365, 0.06963974530143396, 0.025940848381391594, 0.0329420676987086, 0.07725657229976994, 0.0457865320412176, 0.047895137287144146, 0.02017177571542561, 0.08701496438256331, 0.022611528102840697, 0.030263238586485386, 0.04004720804680671, 0.05057025820549045, 0.09028738271445036, 0.03278211324608751, 0.04285711655393243, 0.08574815307344709, 0.05430549170289721, 0.1369026502860444, 0.02759533897707505, 0.022061568684875965, 0.08342382458171674, 0.029690015595406294, 0.004685096858468438, 0.11100490923438754, 0.03124444093555212, 0.02678510540031961, 0.003947434722379382, 0.060448601708880494, 0.033268249660198174, 0.013300863959427391, 0.003536882232375709, 0.05688392138108611, 0.03260253556072712, 0.10589558125606605, 0.12251303956976958, 0.0620662427640387, 0.06633098463394813, 0.027473033039963672, 0.07530623195426804, 0.1104517878432359, 0.08774801290460996, 0.49194174259901047, 2.118689226252692, 2.745874886001859, 6.977536490985325, 12.621640716280256, 8.683935029166085, 9.74376460484096, 9.697927338736397, 8.053714309419904, 4.294358892100198, 1.824657095330102, 1.4299467610461372, 0.501857364816325, 0.6040560837302889, 0.6686741677778107, 1.327531399471419, 0.4466880980346884, 0.6092202780502183, 0.6513144735779081, 0.08037580456584692, 0.1291670932301453, 0.008981596711756927, 0.007150867671173598, 0.022850255382114222, 0.05091629410162568, 0.05247248363281999, 0.14116361950125011, 0.05472145063270416, 0.059717656645391665, 0.03492633818781801, 0.02020539712559964, 0.03444825937705381, 0.012258046389823514, 0.07241274150354521, 0.023481403211397783, 0.016616153830130185, 0.03716266408030476, 0.11558709692742143, 0.029781960483108248, 0.029557107548628534, 0.038069593986230235, 0.027627304761803577, 0.047576605807989836, 0.003240109674931903, 0.027810987584026794, 0.026496409105935266, 0.02532235353386828, 0.01923578924366406, 0.04947958101651498, 0.017660132542784725, 0.015808305303965296, 0.05850010019327913, 0.04322987994445222, 0.045944121799298694, 0.09807748720049858, 0.03400036180391908, 0.014479267244626368, 0.0015909615883304337, 0.0613297608547977, 0.04956270494897451, 0.064661496718015, 0.04221599256353719, 0.0037355549533718397, 0.06278502847999334, 0.03380045520939997, 0.029745278880000114, 0.022984070969479423, 0.06121859646269253, 0.02923838947234409, 0.026320481938975196, 0.017093012974198376, 0.020328266246776496, 0.02640200622512826, 0.037914358744663854, 0.0347856744857771, 0.017719151518706764, 0.04823969058426363, 0.059548613216195784, 0.021497948660648296, 0.0294738886212664, 0.0368981745227107, 0.04342143716556685, 0.06663729569741658, 0.02249862326841269, 0.03878417278506926, 0.05584861943498254, 0.01592054178139993, 0.06698239182255097, 0.03810140710057957, 0.011267527754950737, 0.022961077114034976, 0.07202665507793427, 0.009763654970031763, 0.015500347096739071, 0.06460600612418992, 0.060846976403679164, 0.0032056061692336307, 0.023951029172167182, 0.035960143964205465, 0.040870922418045144, 0.10718299967369863, 0.12103787729782717, 0.1805774795689753, 0.11017875892243215, 0.16402092655854567, 0.18039788492023945, 0.1297962580408369, 0.12705508513110025, 0.12168579681643418, 0.08948570037526743, 0.08529534629945244, 0.08509450671928269, 0.4099212166454111, 0.09750717851732459, 0.1098702358348029, 0.19439705301608357, 0.1246418481958764, 0.1078810832862343, 0.07814299687743187, 0.1807928601545947, 0.08999110718390771, 0.10152731529836144, 0.14455609103398664, 0.08929731869804007, 0.17894682421215943, 0.1931426181857075, 0.1038449127227068, 0.08709531649947166, 0.10410070006868669, 0.15146604739129543, 0.09876512815909726, 0.15487868498478616, 0.16207811795175076, 0.07674849884850637, 0.11642845320914473, 0.11990485952368804, 0.10055106625493083, 0.09719967323222331, 0.11651075950690679, 0.16501473608825887, 0.19150648026594094, 0.10955338712249484, 0.19184007522250923, 0.11939523901258196, 0.16756802265133175, 0.13290782964655332, 0.11204890999943018, 0.2061011985476528, 0.09591528786612408, 0.108261775358447, 0.14561893471649714, 0.08892018893467528, 0.20023904953684124, 0.1034483565017581, 0.053081329712378125, 0.19027531918670448, 0.0658626461933766, 0.1349210837589843, 0.18069850307490143, 0.1372462875608887, 0.08772186895034143, 0.16107217621590408, 0.12713313022894518, 0.08276705018111638, 0.06595916779977934, 0.1418925425303834, 0.1829512800489153, 0.2104395478963852, 0.1942984890192747, 0.2376008704304695, 0.2068814052534955, 0.15987325912075384, 0.1941797182496105, 0.33445577323436737, 0.23072842348899159, 0.1739518700965813, 1.2912575687680925, 3.8347559656415666, 5.093529837472098, 12.148442336491176, 20.546181065695627, 14.919785193034581, 15.748955420085363, 15.827339785439626, 13.370763352939061, 7.9281030382428845, 3.553600366626467, 2.935543337038585, 1.237923196383885, 1.064721433179719, 1.567498185804912, 2.448224046400615, 1.4789065910237176, 1.1807221514838082, 1.3471197826521737, 0.2703296813581671, 0.17778125032782555, 0.07119506291512932, 0.09855615294405393, 0.06414321810007095, 0.09571343048342637, 0.11888708413711616, 0.23899905968989643, 0.1723486954080207, 0.07787693651126963, 0.13041878677904606, 0.23982206838471548, 0.14392316713929176, 0.09802826627024583, 0.14983830973505974, 0.0846022634900042, 0.06063085621488946, 0.0764900923573545, 0.19868981838226318, 0.17076286407453672, 0.10904751212469169, 0.13918229724679673, 0.13004944659769535, 0.12124060999069895, 0.16595709909285816, 0.11710656753608159, 0.08486537901418549, 0.12078244957540717, 0.14234655031136104, 0.19703184520559652, 0.09227956831455231, 0.13817421134029115, 0.16407244093716145, 0.0954610900953412, 0.11347765369074685, 0.1399759796581098, 0.13915453159383365, 0.1150069630571774, 0.114002704088177, 0.13852603174746037, 0.12774919931377682, 0.1820210356797491, 0.16547964114163602, 0.05458544507356627, 0.19291836236204418, 0.13124376322541917, 0.07985672527658087, 0.10965996461787395, 0.1684805436858109, 0.16310791697885307, 0.10449621813105685, 0.0893714079367263, 0.16254741991204874, 0.14798284215586527, 0.11460129411092826, 0.12417834092463766, 0.11503147174205099, 0.24020782911351748, 0.11309170297213963, 0.11060622919883047, 0.09528700515095677, 0.10904278273561172, 0.14942855600799831, 0.20222090104860918, 0.1204529936824526, 0.12850233247237547, 0.18939911334642343, 0.09284974807607276, 0.13446358830801078, 0.1079118073518787, 0.1486517284065485, 0.1444841663220099, 0.16709045613450663, 0.0821440125416432, 0.11533708391445023, 0.11077102499880961, 0.18033893379781926, 0.07233619596809149, 0.17304688080080918, 0.10814456521932568, 0.21286866255104542], [0.011936219774984887, 0.027837691329685704, 0.03881160595587321, 0.05196391485099282, 0.019737016276589463, 0.05517377903951066, 0.046393383227820904, 0.013961392355018427, 0.06426184637738125, 0.07468615951282637, 0.06121317496789353, 0.031468564444886785, 0.06860417194132294, 0.04159522123102631, 0.03994815211210932, 0.05806320506547179, 0.06782954279333353, 0.056056994146534374, 0.02733337696242545, 0.045328493762229166, 0.04773587494024208, 0.04005557099091155, 0.05431482495207872, 0.01741345283309264, 0.02102860768458673, 0.02356122267831649, 0.02781263303144702, 0.05738918909004756, 0.05602374932329569, 0.046295901494366784, 0.05710812631462302, 0.09973854771150009, 0.030182404709713798, 0.011672330720882331, 0.022276542149484158, 0.06606408966971294, 0.023703396120773892, 0.057313437440565655, 0.0424284961606775, 0.013022245606407523, 0.006091338632229183, 0.031481738202273846, 0.03862436421747718, 0.027956339963046566, 0.015488172482166971, 0.02327710310263293, 0.04213614595521774, 0.0651151720168335, 0.029181246645748615, 0.03200485138222575, 0.020061612162472944, 0.13027230463922024, 0.03303361225074955, 0.05612768053210207, 0.028790882056845084, 0.05870465814535107, 0.03217921791864293, 0.07176880498549768, 0.08602326509675809, 0.03725559623645885, 0.014116402831859887, 0.04720413758020316, 0.05635657414261784, 0.016175168832497935, 0.053361269512346814, 0.027954574075660536, 0.07264470548502036, 0.03960045041250331, 0.18247508417282784, 0.2647307903638908, 0.6824206901448113, 0.5707367573465619, 1.0853128539664405, 4.962632724217006, 12.268123320170812, 26.19791875566755, 36.005433082580566, 46.207184723445344, 54.995714460100444, 60.73177201407296, 66.78458404541016, 77.37402779715401, 66.59975501469204, 67.17017432621547, 62.2949777330671, 52.1065353666033, 43.99801540374756, 42.770275660923545, 39.063033035823274, 37.04517889022827, 43.20809555053711, 45.795337200164795, 35.83712339401245, 33.31484392711094, 24.341516426631383, 21.96584916114807, 15.532385281154088, 10.26808522428785, 10.199495213372366, 5.000811772687094, 1.7679900846311023, 0.7437360999839646, 0.7570986258132117, 0.13711648381182126, 0.04573208299864616, 0.04450361231075866, 0.015469524643516966, 0.0655699126156313, 0.046028925105929375, 0.04676275733592255, 0.01911353928569172, 0.02914458539869104, 0.060941720248333046, 0.05529276015503066, 0.03528957833935108, 0.009607529151253402, 0.07539152380611215, 0.03637852865670409, 0.02318953476580126, 0.04327244783884712, 0.02245583654647427, 0.009708496858365834, 0.008647141712052482, 0.03194922847407205, 0.021019693430779234, 0.026330101869202087, 0.0517575384250709, 0.07674093318304845, 0.031986649680350504, 0.036036994840417585, 0.05499545664393476, 0.01946687282595251, 0.07568268318261419, 0.019372173086074845, 0.03900822504822697, 0.03558006596618465, 0.0344337048009038, 0.07400312580700431, 0.0448851355883692, 0.07722271340233938, 0.02025226523567523, 0.059460654721728394, 0.05738778452255896, 0.008777024340815842, 0.015373579791880079, 0.06511053083730595, 0.022038576525769064, 0.040882074141076634, 0.05131207000730293, 0.01942750083149544, 0.021754514625562087, 0.007433338406761842, 0.0166229731070676, 0.07608086110225745, 0.03172677755355835, 0.024990222516602704, 0.09593930800578424, 0.027531005375619446, 0.0066443395834150055, 0.02014294815515833, 0.01747445822028177, 0.04170082163597856, 0.0628927798409547, 0.01885197082135294, 0.03596157567309482, 0.01815344955373023, 0.02776087946923716, 0.019544193587665046, 0.027475480855043446, 0.025878575830055133, 0.06759671028703451, 0.01866389618122152, 0.02011230381737862, 0.04246090977851834, 0.02743000034908099, 0.06457940076610871, 0.05103969248011708, 0.09539259198520865, 0.053937464486807585, 0.030113920170281614, 0.026715959289244244, 0.0590746361496193, 0.04168527639870133, 0.019474888020860295, 0.021477378871557967, 0.05134888053206461, 0.03558211514194097, 0.050046327390841076, 0.04419613755973322, 0.04308284140591111, 0.05248830367677978, 0.05609477497637272, 0.020483869593590498, 0.03873041245554175, 0.04472434314500008, 0.06369911014501538, 0.06667109352669545, 0.06692874005862645, 0.06371909300131456, 0.05566753200920565, 0.027825362348396863, 0.013586480552995843, 0.04785396717488766, 0.08981333100902182, 0.0228533037006855, 0.030710725645933832, 0.10980797346149172, 0.026750055673931326, 0.03865622482927782, 0.05851138423063925, 0.027382170415616462, 0.05228536742340241, 0.04621741874143481, 0.05314771757860269, 0.024982058043990816, 0.04763673758134246, 0.024411985151735798, 0.021069826990632073, 0.07315548629100833, 0.02711024072154292, 0.022239190493045107, 0.04445806225495679, 0.03007974914674248, 0.08721087101314749, 0.03645203774794936, 0.03416806851912822, 0.025070104748010635, 0.03378374967724085, 0.045088305936328, 0.04686389298045209, 0.086003831853824, 0.05375673668459058, 0.0831000819536192, 0.0549908663545336, 0.007719578404378678, 0.028693441035492078, 0.07587835232594184, 0.028098406536238532, 0.02257324006807591, 0.05346548570586102, 0.07502630911767483, 0.06937674512820584, 0.03761171855564628, 0.045255347687218866, 0.1988835944128888, 0.13910255581140518, 0.6384926587343216, 0.7726171016693115, 1.4747517853975296, 5.423334334577833, 14.0275513785226, 29.292900017329625, 41.38319635391235, 52.866994857788086, 62.402250971112935, 70.15020111628941, 76.34865433829171, 84.73622785295758, 76.02056734902519, 75.81966713496617, 69.48413290296281, 58.874254499162944, 49.465149879455566, 46.940108503614155, 42.15617649895804, 41.62868663242885, 49.32251031058175, 54.063582352229524, 44.07987560544695, 40.18204389299665, 29.529486179351807, 26.470559120178223, 19.128590481621877, 13.247114079339163, 12.63507158415658, 6.720127880573273, 2.4531924426555634, 1.3949768032346452, 0.9529870173760823, 0.08098185168845312, 0.003138501812437815, 0.014158827385732105, 0.014673199338306273, 0.0675506784713694, 0.06213753643844809, 0.06370459949331624, 0.02495506252827389, 0.0749650238347905, 0.040710934038673124, 0.01997345350017505, 0.017178817119981562, 0.02336014900356531, 0.10667441053582088, 0.07634923527283327, 0.030357802619359324, 0.06187977455556393, 0.006421767374766725, 0.029142383552555527, 0.03828379052824207, 0.09569188699658428, 0.06332644514207329, 0.02158790035173297, 0.029633778613060713, 0.028751408282135214, 0.029638725133346658, 0.0648272560377206, 0.04894543485715985, 0.062081699791763506, 0.02589231277150767, 0.011591771650793297, 0.04593197602246489, 0.060071885851877074, 0.023356581605704765, 0.024861485763852085, 0.014648634674293655, 0.08162156093333449, 0.04697297087737492, 0.01208417009495731, 0.04946995260460036, 0.039846514351665974, 0.029681048755134855, 0.04169716772490314, 0.04943544909890209, 0.09493289808077471, 0.009835365095308848, 0.05055910987513406, 0.019235590772171105, 0.026195295620709658, 0.037954544981143305, 0.026605690563363687, 0.028576478561652557, 0.03107107863096254, 0.09361469452934605, 0.05693734583577939, 0.05568407469296029, 0.036143423058092594, 0.05743074257458959, 0.05352377525663801, 0.01690460754824536, 0.056383444129356315, 0.056107860524207354, 0.023630389145442417, 0.016026835988408754, 0.009138764081788915, 0.03614782335768853, 0.04686370299064687, 0.044060009864291975, 0.044711535796523094, 0.028570320856358324, 0.05668716997440372, 0.05494646641558834, 0.021278049031804715, 0.14498943063829625, 0.17692909176860536, 0.10720117084149804, 0.15921489016285964, 0.17250355066997664, 0.1941761084433113, 0.14570487796195916, 0.14319332130253315, 0.12555054229285034, 0.14654562356216566, 0.18105725810996123, 0.15620853219713482, 0.13015543376760824, 0.15580264611967973, 0.11717710803662028, 0.19233628788164683, 0.12928860528128489, 0.1246215599988188, 0.11167522040860993, 0.19933431808437618, 0.10681579009230648, 0.19749893514173372, 0.10841452716184513, 0.11847156286239624, 0.1106025990364807, 0.10280980755175863, 0.1032031068046178, 0.17163915133902005, 0.11539257450827531, 0.10884924419224262, 0.16928201567913803, 0.1655602375311511, 0.19075080938637257, 0.1262345870158502, 0.1560802347958088, 0.206362054550222, 0.11184704583138227, 0.11040821910968848, 0.10631284636578389, 0.12630415042596205, 0.09396956834409918, 0.11457206282232489, 0.1480225228837558, 0.1070303971480046, 0.16315507516264915, 0.20658240201217787, 0.10846558692199842, 0.19180243009967463, 0.12323091604879924, 0.1416528161082949, 0.15097710862755775, 0.20306349226406642, 0.07164409024907009, 0.20492331603808062, 0.15675349081201212, 0.20412837155163288, 0.1366785844521863, 0.16294320938842638, 0.15084094022001537, 0.1460588425397873, 0.14489968759672983, 0.17298380418547563, 0.09527151419648103, 0.1113554472103715, 0.21779889799654484, 0.17771621953163827, 0.14099766340638908, 0.08872567330087934, 0.3881019188889435, 0.3718209596616881, 0.9960171026842934, 1.401564672589302, 2.895062480654035, 8.16403693812234, 20.57765119416373, 41.801349367414204, 55.95958941323416, 69.78998565673828, 80.94440133231026, 85.9651209967477, 92.9998732975551, 106.41305106026786, 94.44749573298863, 96.01958124978202, 85.00339303697858, 76.28372342245919, 66.94098799569267, 63.1637179510934, 56.37491798400879, 56.85275949750628, 66.3286988394601, 69.71668910980225, 57.84413194656372, 53.581238406045095, 42.02392448697771, 37.860525676182334, 26.773682968957083, 19.453015770230973, 16.57299961362566, 9.929999777248927, 4.6391384942190985, 2.3000498030866896, 1.2657483432974135, 0.2681842621948038, 0.13286056289715426, 0.13714192887502058, 0.10595752471791846, 0.1655233252261366, 0.13990390566842897, 0.1286802307835647, 0.08932477901024477, 0.1449329358126436, 0.13511842888380798, 0.18214197776147298, 0.13998303642230375, 0.19055397994816303, 0.26961542825613705, 0.24721367603966168, 0.19343813375702926, 0.13519251133714402, 0.11931868669177804, 0.12314296433968203, 0.11795644621763911, 0.2323463223874569, 0.10800179466605186, 0.07415887673518487, 0.1803272765661989, 0.17670396742011818, 0.12421917516205992, 0.11406062383736883, 0.18424834044916288, 0.12542748318186828, 0.15862098203173705, 0.09398112379546676, 0.16982305236160755, 0.1349696668663195, 0.11135326232761145, 0.16871752882642405, 0.10329032569591488, 0.21375759770827635, 0.10997264712516751, 0.07043870671519212, 0.17280838931245462, 0.0892185882798263, 0.10126559755631856, 0.13510548243565218, 0.09126296000821249, 0.1895783958690507, 0.11855031363666058, 0.1324423546237605, 0.14405078600559915, 0.10578356190983738, 0.14259650904153073, 0.1320095578474658, 0.17650818292583736, 0.07183776449944292, 0.2775791494974068, 0.1699457722050803, 0.12507122515567712, 0.1580977365374565, 0.17354982452733175, 0.19174950436822005, 0.14360937183456762, 0.13508450213287557, 0.11478912617479052, 0.173076600634626, 0.13451971672475338, 0.09614609155271735, 0.1247941114540611, 0.11828518286347389, 0.20861177811665194, 0.20861082816762583, 0.09748105491910662, 0.12591073582214968, 0.14945024198719434, 0.1289158452834402], [0.01652966606031571, 0.03476624124284301, 0.11792173236608505, 0.0498457524393286, 0.018109972422410334, 0.045502772089093924, 0.05486670123147113, 0.0652871670733605, 0.03256682765537074, 0.03266163596085139, 0.06015211583248206, 0.04057028390733259, 0.03605148834841592, 0.049639545647161346, 0.06233895955873387, 0.029876314170126404, 0.0070932617444278935, 0.008807562657498887, 0.023537755544696535, 0.00790677943067359, 0.03430762620908873, 0.14076248316892556, 0.03258609126455017, 0.0416035604264055, 0.023867387856755937, 0.027188338405851806, 0.013565799653796213, 0.054387811571359634, 0.04302961372637323, 0.01050068055545645, 0.020757594012788365, 0.05055733550606029, 0.03977228601330093, 0.05027849832549691, 0.07571986011628594, 0.018287928409076164, 0.06633195493902479, 0.025733142026833127, 0.038498645249222, 0.04522690010656204, 0.00976741235769753, 0.028681464892412935, 0.052706296622220955, 0.017590614933786646, 0.04025584738701582, 0.0632080068545682, 0.052906454274696965, 0.0078043944335409576, 0.06618375610560179, 0.021299595911321894, 0.030150594988039563, 0.036043763227228603, 0.04030140083549278, 0.10017423504697424, 0.09086367607648883, 0.033956097571977546, 0.06421666951583964, 0.08683794138154813, 0.06649572615112577, 0.030215822559382235, 0.03675324962075267, 0.02971443607072745, 0.09483664788837944, 0.26616220069783075, 0.2821762242487499, 1.4941359566790717, 4.233586473124368, 6.009864781584058, 16.100727081298828, 18.491376399993896, 27.608686208724976, 37.09608834130423, 51.70196260724749, 62.012311117989675, 72.60671588352749, 80.51515551975795, 79.24481637137276, 79.52974115099225, 86.23261969430106, 79.4703757422311, 81.22118282318115, 78.40912178584507, 83.52319049835205, 78.9161457334246, 79.13208184923444, 86.02398613521031, 89.31343705313546, 87.2325210571289, 93.89748328072685, 84.66929585593087, 88.11599145616803, 91.29971163613456, 92.00505106789726, 86.11279106140137, 81.51754433768136, 77.50206920078823, 74.37268393380302, 66.21612412588937, 69.94597271510533, 63.35427229745047, 42.88315609523228, 35.57447453907558, 17.831280163356237, 5.943673636232104, 2.5495276962007796, 0.484783903828689, 0.057961071974464824, 0.0656413012849433, 0.04717864501955254, 0.027815258961969187, 0.04015416891447135, 0.008777478959278336, 0.05432210224015372, 0.0361226361377963, 0.01710426138847002, 0.06114891091627734, 0.00611055559212608, 0.032556320540606976, 0.04809666897303291, 0.03354818267481668, 0.055496235843747854, 0.00802776392083615, 0.039869472584021945, 0.10933532632355179, 0.02356358737285648, 0.001131862568269883, 0.071672758353608, 0.04372465071667518, 0.07284943985619716, 0.04678102010594947, 0.05619428213685751, 0.044121552990483384, 0.005816244844546807, 0.05148822787616934, 0.018056987319141626, 0.014354949451184698, 0.039286146206515174, 0.0904620715550014, 0.006084582119780991, 0.009317009294006442, 0.018095919962174127, 0.052872439314212115, 0.035105301798986535, 0.05345864946554814, 0.040612590565745316, 0.10980700315641505, 0.014902459357732108, 0.03756367827632597, 0.020759831482012357, 0.00883529523187982, 0.04876025586522051, 0.025626374541648796, 0.011224291503562458, 0.006784291671855109, 0.020348255888425877, 0.03294134505891374, 0.08181174751371145, 0.06713709780680281, 0.06721597071737051, 0.014244085310825279, 0.06029535457491875, 0.04333884249042187, 0.018566468730568886, 0.05782716987388475, 0.07106485204505068, 0.13559655179934843, 0.04466664731236441, 0.05613750911184719, 0.10952414226319108, 0.010058814310468733, 0.029230766131409576, 0.03761227834703667, 0.038024752999522855, 0.05495056815977607, 0.02541015257260629, 0.046748565776007514, 0.04912565375811287, 0.06151016974555595, 0.04147166000413043, 0.032256452167140584, 0.04968119751928108, 0.03827947165284838, 0.06836245741162982, 0.0417660661706967, 0.056596765361194096, 0.0201575739774853, 0.037748294084199836, 0.012750078425077456, 0.029607977318976606, 0.045740473084151745, 0.022670472439910685, 0.07339636622262852, 0.015200758618967873, 0.01474719527842743, 0.02649874665907451, 0.033053978479334285, 0.01061689664077546, 0.07457000788833414, 0.014521075179800391, 0.07847277846719537, 0.06976937941674675, 0.014517560368403792, 0.01772925490513444, 0.04853156242253525, 0.041305636055767536, 0.047843225965542455, 0.040256044162171226, 0.0237929814029485, 0.055533429740795066, 0.03349056487370815, 0.01939662579180939, 0.05519487130056534, 0.04545420255245907, 0.05345386918634176, 0.05285229021683335, 0.02225805207022599, 0.015740526440952505, 0.05174399147342358, 0.02290628201860402, 0.0395635041807379, 0.052210884634405375, 0.01905125655632998, 0.05475166918975966, 0.04400736911754523, 0.04371790947126491, 0.036940162269664664, 0.0267271754731025, 0.04881919341694031, 0.05121577910280653, 0.07280994233276163, 0.05486833989354117, 0.028683588707021306, 0.03979123749637178, 0.03992797587332981, 0.05403613365654435, 0.019151075842923353, 0.0635826735358153, 0.037857636609779935, 0.04661675017060978, 0.12469793590051786, 0.28190768722976955, 1.3165067796196257, 3.1462444194725583, 6.085308756147112, 16.71282168797084, 21.15160366467067, 32.41660165786743, 43.293464592524934, 61.421943528311594, 73.73068428039551, 85.68123149871826, 94.92605985913957, 93.7700046811785, 96.34500013078961, 98.86098452976772, 90.95890944344657, 92.04763657706124, 92.16668006352016, 95.34172889164516, 96.39401272365025, 92.30104432787213, 98.08305031912667, 102.46106856209892, 97.84716592516217, 105.58866119384766, 99.39741325378418, 102.50830241612026, 105.08664689745221, 103.32065105438232, 100.54996653965541, 95.21552181243896, 91.20907238551548, 88.66216850280762, 78.38119002750942, 82.84368446895054, 73.12898417881557, 54.918332372392925, 42.84659120014736, 22.506040334701538, 7.787565299442836, 2.471998176404408, 0.49027265501873835, 0.17509385810366698, 0.0556954197984721, 0.07275285039629255, 0.03832195812304105, 0.04369046612243567, 0.053045129869133234, 0.0652572979618396, 0.027794402491833483, 0.028631473824914013, 0.06947848466890198, 0.0019009120379840688, 0.0038758289218614145, 0.021454939718491266, 0.010438741334447903, 0.01508175375472222, 0.025580001762136817, 0.04667995570759688, 0.009346474677191248, 0.01693473450307335, 0.034852947840201, 0.039001605939120054, 0.05409553939742701, 0.06376683472522668, 0.030230811397944177, 0.026105267594435384, 0.021461122868848697, 0.035535408183932304, 0.051056177488395145, 0.06791180837899446, 0.00990246542330299, 0.032518376862364154, 0.05274628947622009, 0.037154341848301034, 0.04835978449721422, 0.029355691213692938, 0.05018254668850984, 0.016128704450758438, 0.08240430536014692, 0.04928686010784336, 0.06313165809426989, 0.02308586479297706, 0.02051517041400075, 0.019915542232670953, 0.027521056355908513, 0.045682047826371024, 0.00937914104932653, 0.0455535400791892, 0.025720580647300397, 0.08596589496093136, 0.032672940354262076, 0.011780000657641461, 0.0855567722714373, 0.01165859802027366, 0.04457566933706403, 0.06548973013247762, 0.08348761365881988, 0.030769463029823134, 0.0044716284693484855, 0.048420184291899204, 0.03234250737088067, 0.02099600068426558, 0.06890175704445158, 0.01659854923907135, 0.028621618103768145, 0.03258539915883115, 0.05320129809635026, 0.04735395811232073, 0.024013208424938575, 0.02001824359675603, 0.006530729496651995, 0.1504253510917936, 0.10585023476076977, 0.1444923494543348, 0.11558797902294568, 0.09473837566162858, 0.1732552589050361, 0.15836003103426524, 0.1763754886175905, 0.13163671642541885, 0.11830498251531806, 0.14042245570038045, 0.1357875322656972, 0.07748634461313486, 0.1389480805290597, 0.10715472511947155, 0.09628892317414284, 0.08376224392226764, 0.11308550116206918, 0.07099722924509219, 0.07543560822627374, 0.09118205827793904, 0.21443295718303748, 0.09904896614274808, 0.1331223552780492, 0.11096420391861882, 0.11812499431627137, 0.10320527811667748, 0.1723588870040008, 0.1273076222943408, 0.13669953761356218, 0.13575534256441252, 0.07786916049995593, 0.0884117219331009, 0.12148318625986576, 0.1582225869808878, 0.1059909425675869, 0.12585757938878878, 0.11925873133753027, 0.10139397638184683, 0.11090067268482276, 0.07761874036597353, 0.14203080082578318, 0.106752170648958, 0.09138505559946809, 0.159012781722205, 0.14479737808661802, 0.21905546342687948, 0.11977426867399897, 0.21525676654917852, 0.09973185735621623, 0.10902782103845052, 0.14222425115959986, 0.13350255201969827, 0.31103784697396414, 0.14901912797774586, 0.08988896730755057, 0.10301233668412481, 0.10741094672786337, 0.16895680741540023, 0.1174663675150701, 0.23740575090050697, 0.10424652402954442, 0.3094048574566841, 0.4354737869330815, 0.5529308042355946, 2.955452097313745, 5.305951467582157, 9.323278733662196, 22.87240321295602, 30.936739580971853, 45.419932978493826, 56.5611366544451, 76.31521265847343, 87.44998577662876, 99.91613796779087, 110.78077207292829, 107.45070893423897, 107.79216425759452, 111.28031281062535, 104.58624458312988, 106.49249676295689, 103.67277881077358, 110.40859876360211, 105.29561397007534, 106.65084620884487, 112.42578588213239, 117.25652095249721, 111.73236261095319, 120.12408420017788, 112.50987992967877, 115.86843068259103, 121.72047451564244, 119.28340775626046, 113.9704260144915, 110.1365350995745, 106.11016518729073, 103.57437842232841, 95.41440010070801, 96.62826429094586, 87.82937131609235, 72.96649360656738, 55.38608510153634, 32.246085916246685, 11.956747617040362, 4.533814660140446, 0.9163054142679486, 0.44722984039357727, 0.16162824923438684, 0.13244448522371904, 0.10456146605845008, 0.08780108112841845, 0.11016811949333974, 0.1579306676451649, 0.13185087564800466, 0.09450388074453388, 0.14050216999437126, 0.08447132658745561, 0.14704936796001025, 0.16501689382961818, 0.1032101432127612, 0.1760671894465174, 0.14178027212619781, 0.09128618626190083, 0.19468351693025657, 0.06462035035448414, 0.08336764188217265, 0.1417146577898945, 0.14107557279723032, 0.08693271915295295, 0.11298878956586123, 0.09802874124475888, 0.11113129995231118, 0.10888743892844234, 0.2502104395202228, 0.16167707661432879, 0.1452295370399952, 0.07319041048841816, 0.21056553827864782, 0.14882536551782063, 0.1286394236875432, 0.16429447116596357, 0.13987623501036847, 0.14126109784202917, 0.1715989142124142, 0.1104359236944999, 0.1857471971639565, 0.07836161407509021, 0.12202363940221922, 0.20031733890729292, 0.08625064896685736, 0.16679135789828642, 0.08945456918861185, 0.09853920313928809, 0.12066123607967581, 0.1936004664748907, 0.0866270526977522, 0.13355817832052708, 0.1774122222725834, 0.1974893949393715, 0.13118368573486805, 0.18544248065778188, 0.1628173275717667, 0.15205406583845615, 0.0985786531652723, 0.17709025740623474, 0.24403921780841692, 0.1028267437858241, 0.1625316236168146, 0.16075159556099347, 0.10853223263153008, 0.14078240495707306, 0.10113535954483918, 0.1851379405707121, 0.1188686415553093, 0.07777881356222288, 0.17579625041357108], [0.052596146639968665, 0.058290588935571055, 0.017976928668628846, 0.04250959466610636, 0.04859249825988497, 0.05363375899781074, 0.07662461192480155, 0.11071170746747937, 0.021284435742667744, 0.004937458026688546, 0.12652113235422544, 0.03250972893355148, 0.005763116824839796, 0.04946396792573588, 0.07504858542233706, 0.036280585519437275, 0.011490731849335134, 0.04007995075413159, 0.05013404500537685, 0.013072728611794966, 0.06764714579497065, 0.1055059325216072, 0.019236247254801647, 0.03876948928726571, 0.03937390114047697, 0.05700781848281622, 0.052672458080840964, 0.014420831808820367, 0.0715644641646317, 0.0802354970946908, 0.05747847751315151, 0.07326485256531409, 0.05739545875361987, 0.04173528103690062, 0.025099166402859346, 0.09417293885988848, 0.02132710880999054, 0.09438895726842539, 0.048447312121944766, 0.014639352315238543, 0.07377172500959464, 0.04645394926358547, 0.024122774867074828, 0.04651272735957589, 0.01718606726665582, 0.047832630641226254, 0.017527750360646417, 0.018516516678833535, 0.01975568786396512, 0.05479107850364276, 0.024160364010770406, 0.020507618319243193, 0.05205357646835702, 0.022582454573629156, 0.03483724653986948, 0.09610697400889226, 0.07702825883669512, 0.0921550707093307, 0.04020436693515096, 0.048697725470576964, 0.0051367942277075985, 1.7164224003042494, 4.464347439152854, 9.24351601941245, 14.555535435676575, 19.785223041261943, 22.96241191455296, 49.51808820452009, 76.53154482160295, 76.50954682486397, 79.89248575483049, 78.61902686527797, 72.12227358136857, 76.10305636269706, 71.62372643607003, 70.64814376831055, 68.57063933781215, 48.94379527228219, 59.65050029754639, 61.76874896458217, 55.364875725337434, 45.234586306980674, 51.51805073874337, 47.07751955304827, 54.22709430967058, 53.2466652733939, 63.723694120134624, 73.30908148629325, 69.10273933410645, 78.7564344406128, 67.77877398899624, 73.21437059129987, 74.76732771737235, 75.28417641775948, 74.51567786080497, 75.62206731523786, 90.41900662013462, 84.54719516209194, 74.61878217969621, 84.22599383762905, 75.84952354431152, 89.69989585876465, 74.63204629080636, 59.07378591809954, 34.06026751654488, 21.01874715941293, 8.578196474484034, 4.405222611767905, 1.001089179090091, 0.19300727759088787, 0.06347787380218506, 0.004968125265025134, 0.01913803270352738, 0.06726678620491709, 0.04858120743717466, 0.008166008645535579, 0.08401888622237103, 0.036151880997100046, 0.029919262044131756, 0.028323909167998602, 0.0449283616617322, 0.031131000058459382, 0.05114225983353598, 0.05160900710948876, 0.020983023702033927, 0.039623578278613944, 0.036940420112971745, 0.02456616357501064, 0.03761588815333588, 0.049039819078253846, 0.030859962637935365, 0.03478630552334445, 0.11688641006393091, 0.033020492776163986, 0.03966324882847922, 0.03276461722063167, 0.016108200818832432, 0.019220269451450025, 0.02205419131288571, 0.0900245996724282, 0.03232930647209287, 0.06069987001163619, 0.0742126302793622, 0.08721657070730414, 0.008066705045556384, 0.021698750921392014, 0.038279790564307144, 0.0263398829514959, 0.06243370340338775, 0.03820692268865449, 0.04338817198627761, 0.06710798186915261, 0.05571783520281315, 0.011099489405751228, 0.02396150236018002, 0.047818907270474095, 0.005907410265146089, 0.028228116986740912, 0.054371726898742576, 0.040015184586601596, 0.012032240961811371, 0.031374600915504355, 0.03571323864161968, 0.06941117399505206, 0.053295831595148356, 0.08823351149580308, 0.027762472330193435, 0.03806818602606654, 0.06213493764932666, 0.03045940984572683, 0.05410919152200222, 0.040395825768687894, 0.01744927608940218, 0.05516485969669052, 0.011647188453935087, 0.037506647408008575, 0.019088404652263437, 0.031251555375222645, 0.04895593857924853, 0.06715097384793417, 0.05207219886194382, 0.08327530683683497, 0.06894348016274826, 0.05384368755455528, 0.028015140111425092, 0.008532988373190165, 0.104062688536942, 0.04577958384262664, 0.033060916499899964, 0.06883380176233393, 0.03091411991044879, 0.03229074871965817, 0.027374160309721316, 0.015053212875500321, 0.07122577341007334, 0.02376890698048685, 0.030652239320001433, 0.09711379784026317, 0.012786736279459936, 0.02931482983486993, 0.027380592821698104, 0.04845734765487058, 0.06493569271905081, 0.006221214899726744, 0.028458157321438193, 0.009816775780304201, 0.03546850802376866, 0.034605662538004775, 0.12062300741672516, 0.012886745555858527, 0.03574820015845554, 0.042063271294214895, 0.027474133963031427, 0.07973698420183999, 0.0022540110595790403, 0.029305890135999237, 0.01585129219373422, 0.0391872327641717, 0.027323697660384432, 0.022269419228125895, 0.02476936106437019, 0.02191541563453419, 0.02286617211731417, 0.031017895056200877, 0.004425511412721659, 0.056602861998336654, 0.06039119086095265, 0.09024781055216279, 0.01344744787950601, 0.026925952306815555, 0.0227784511101033, 0.07110969642443316, 0.022037557026903545, 0.0720807071775198, 0.05164414843810456, 0.013330046902410686, 0.12840341563735688, 1.481842964887619, 4.445136972836085, 9.154490487916128, 15.989324876240321, 22.129715476717266, 31.188038553510392, 58.04228067398071, 85.80090032305036, 89.49923188345772, 94.48433508191789, 90.35395063672746, 85.30361774989537, 85.61329201289585, 83.24070453643799, 82.17764404841832, 84.3641448702131, 62.218123708452495, 78.96262918199811, 81.29871082305908, 78.51089899880546, 65.73766422271729, 75.05328777858189, 63.05837631225586, 72.750974382673, 70.51657267979213, 81.81448255266461, 93.59238093239921, 83.31245858328683, 93.0372268131801, 79.83246026720319, 88.78237233843122, 89.30801745823452, 85.94957092830113, 85.96441922869, 90.89114366258893, 102.50130558013916, 95.59649848937988, 87.17050838470459, 94.89604364122663, 86.4937607901437, 102.38441603524345, 86.99806104387555, 67.72347327641079, 41.403624057769775, 25.141526801245554, 10.795218995639257, 4.895261253629412, 1.388739492212023, 0.15322531227554592, 0.0811859414513622, 0.07106004123176847, 0.019511159110282148, 0.013966602655792875, 0.026211588942844952, 0.07185548783413001, 0.052855231666139195, 0.059724340215325356, 0.08429621026984283, 0.025189313172761883, 0.05934936819331987, 0.10916149243712425, 0.015615457169977682, 0.0378746712314231, 0.08275104354002646, 0.03486131078430584, 0.0024301996745634824, 0.04449609414275203, 0.03870100474783352, 0.014346895240513342, 0.08585317672363349, 0.024565534233780842, 0.02303984315533723, 0.034503872107182226, 0.022629010557596172, 0.08464321986372982, 0.01740870139162455, 0.014755312253588011, 0.03778523013793996, 0.02727022740457739, 0.00893241649360529, 0.04752656724303961, 0.01954846496560744, 0.020930342243186066, 0.01942668658947306, 0.009940169069782963, 0.026051434322393367, 0.048366620737527094, 0.007929036227454032, 0.03515117755159736, 0.033535375326339684, 0.0507026166389031, 0.024699163224015917, 0.04871448189286249, 0.028624966674085175, 0.045531446978982, 0.045692582082535536, 0.04229104532194989, 0.11459326025630746, 0.03339416540360876, 0.05222604310672198, 0.03212557972541877, 0.03409374179318547, 0.026643895477588688, 0.03799387287082417, 0.09712905809283257, 0.06860826350748539, 0.03269957624641912, 0.051803957005696635, 0.014017064456960984, 0.07961961799966437, 0.00847688624967954, 0.022910276893526316, 0.06969976172383342, 0.049666822754911015, 0.03997775998764804, 0.1545681602188519, 0.12538408408207552, 0.1788891080234732, 0.17451076582074165, 0.09770236590078898, 0.1997200245303767, 0.12335578006293092, 0.17891819003437245, 0.12274049807872091, 0.07589030132762023, 0.2274212980909007, 0.20554769039154053, 0.09417726112795727, 0.12249037650014673, 0.13177049638969557, 0.12696213940424578, 0.10471742733248643, 0.09152526129037142, 0.17075716438038008, 0.11965912128133432, 0.2883443518408707, 0.17406200990080833, 0.15013048691408976, 0.12862095396433557, 0.21300081403127738, 0.18142784679574625, 0.11714318128568785, 0.22913381191236631, 0.15951986451234135, 0.15277437147285255, 0.10937251004257373, 0.12223640084266663, 0.3163316957652569, 0.1598931944796017, 0.1555712656783206, 0.16645491309463978, 0.149319678278906, 0.23636485104049954, 0.16560728714934417, 0.1455922004367624, 0.17145621829799243, 0.08345016531114068, 0.19273627070443972, 0.13290478980966977, 0.09475979701216732, 0.22211169371647493, 0.09651333506086043, 0.09074183832854033, 0.10276182834059, 0.1283778077257531, 0.22767174536628382, 0.14980956699166978, 0.178957979327866, 0.13174415566027164, 0.195257625409535, 0.1607089564204216, 0.1813685428351164, 0.14076967564012322, 0.2380445237670626, 0.11723799976919379, 0.5978674100978034, 3.60844532081059, 6.173013261386326, 13.534055573599678, 23.030030046190532, 31.313946860177175, 42.15880986622402, 70.32455226353237, 97.74487454550606, 103.2735492161342, 106.5347626549857, 101.23815781729562, 94.77383177621024, 97.60172080993652, 94.97685813903809, 92.30371938432965, 91.35623523167202, 69.04991218021938, 83.13599518367222, 86.21034376961845, 81.29588290623256, 67.33691024780273, 72.85489164079938, 68.67645345415387, 75.50871440342495, 76.50305025918144, 87.47338730948312, 96.09450367518834, 91.11717551095145, 102.54141753060478, 90.34000560215541, 97.48457418169293, 100.98440960475376, 98.4714685167585, 98.84175886426652, 100.16559219360352, 114.35461275918144, 110.6908415385655, 98.0504424231393, 110.15009798322404, 101.03909192766461, 115.4550337110247, 101.50268268585205, 80.36019679478237, 52.90297610419137, 36.324428353990825, 18.760678155081614, 9.110850589615957, 3.1067476017134528, 0.7629568257502147, 0.15359885937401227, 0.10274871225867953, 0.08868648111820221, 0.10487270328615393, 0.15977985199008668, 0.11988875110234533, 0.1311958586531026, 0.18179502923573765, 0.09761769830116204, 0.15725967793592385, 0.11983889234917504, 0.1997417512216738, 0.1439210908221347, 0.0623306135780045, 0.21927506450031484, 0.18905179841177805, 0.15974724159709044, 0.12798515308116162, 0.1290293370506593, 0.10154151025095157, 0.1611343707357134, 0.15595640215490544, 0.18464446919304983, 0.16784595059497015, 0.2144216527896268, 0.15321988399539674, 0.1333823020436934, 0.09065394768757479, 0.09263708841587816, 0.128764219848173, 0.1667137470628534, 0.140463154230799, 0.13399499202413218, 0.13446722525571073, 0.11275641167802469, 0.11892890903566565, 0.11560544451432568, 0.0941411494942648, 0.1318524227078472, 0.1562425810843706, 0.09699097621653761, 0.16280276621026651, 0.10974664068115608, 0.1571479367890528, 0.12516525653856142, 0.1151498896735055, 0.1526153635765825, 0.17483532269086155, 0.20800933401499475, 0.09251936259014265, 0.11450461644147124, 0.19122419612748282, 0.1631809137761593, 0.17134173586964607, 0.16687483127628053, 0.23539422026702336, 0.15193743923945086, 0.08310579521847622, 0.1364462404911007, 0.13109407840030535, 0.168448055429118, 0.15798857382365636, 0.08799596317112446, 0.18693366992686475, 0.12490688397416047, 0.09063523369176046], [0.043114352572177134, 0.03230493688689811, 0.04209005646407604, 0.07388206158897706, 0.0437037077333246, 0.004156179235516382, 0.026720663233261024, 0.07166646833398513, 0.04748467788366335, 0.03838950967682259, 0.041397709865123034, 0.06601644972605364, 0.03688615427485534, 0.08905045408755541, 0.03379196673631668, 0.09797371205474649, 0.03564521889867527, 0.04289225788254823, 0.040532710030674934, 0.07264808458941323, 0.013233194510186357, 0.05638800388468163, 0.05800321578447308, 0.04516313138550945, 0.05458092263766697, 0.027272951722677265, 0.025780030492959276, 0.07183809019625187, 0.008296973537653685, 0.05615473711597068, 0.021618561652888144, 0.05183062343192952, 0.04191203601658344, 0.06111148292464869, 0.01414171897340566, 0.05831130460969039, 0.06500905592526708, 0.032522940010364564, 0.018120957904362252, 0.038829010379101546, 0.05070139527586954, 0.057469195154096396, 0.036297945837889395, 0.02205812681599387, 0.036464034247079065, 0.10898835065641574, 0.05529748275876045, 0.019659726048952768, 0.06572030311716454, 0.0784355133239712, 0.03910854984340923, 0.0384603453400944, 0.05774198658764362, 0.06609351773347173, 0.11741520597466401, 0.008685114228033593, 0.09883637433605534, 0.06438264596675124, 1.13443346960204, 4.148279964923859, 12.741037692342486, 17.703193596431188, 31.333224637167795, 46.8624450138637, 61.75832666669573, 65.58765261513847, 61.74326992034912, 66.52826499938965, 73.5088699885777, 67.15356118338448, 55.47336837223598, 48.23544727052961, 49.353540965488975, 54.0367762020656, 42.9827480997358, 44.71628195898873, 30.835344518933976, 41.04527766363961, 28.17106819152832, 25.939077513558523, 25.5147579738072, 18.234437227249146, 12.720963478088379, 16.393908057894024, 20.800382648195537, 20.93155595234462, 18.743396248136246, 26.514298030308314, 33.965292590005056, 29.49487372807094, 28.923792600631714, 29.019080196108135, 40.21396739142281, 39.67405761991228, 46.01847512381417, 38.013122013636995, 49.51827927998134, 55.93262345450265, 59.49324171883719, 56.62387541362217, 68.4712939943586, 81.56684875488281, 64.62997545514787, 72.02230984824044, 70.34399332318986, 75.19391931806291, 50.375429902757915, 43.979540143694194, 35.49730437142508, 20.762740782329015, 7.8365283863885065, 2.3773611060210635, 0.11065421519534928, 0.029440240069691623, 0.03413081355392933, 0.027034075165699636, 0.03158645651170185, 0.03222742443904281, 0.07237129658460617, 0.013478206720070114, 0.07063238096556493, 0.04805441659742168, 0.026320719426231723, 0.05944035973932062, 0.011581794641512846, 0.01787046143519027, 0.06996170338243246, 0.038367660849222114, 0.06086393299379519, 0.041795287281274796, 0.046952516439237764, 0.015994103459109153, 0.02300216580208923, 0.033107589531157694, 0.023749371957299963, 0.02675445766986481, 0.07298477366566658, 0.048222798454974375, 0.038752929640135596, 0.03404902294278145, 0.0333620673045516, 0.0314022376468139, 0.01990538795611688, 0.024960090472762073, 0.07504628518862383, 0.031376280289675505, 0.06276632805487939, 0.0192574803118727, 0.034313332688595564, 0.035956890388791046, 0.02819811556089137, 0.004961540506753538, 0.03193843637460044, 0.03132999063070331, 0.05335422971152833, 0.009104601539937513, 0.03310755899708186, 0.04368102770032627, 0.048525448822017224, 0.013248999287108225, 0.02744260922606502, 0.05531918570133192, 0.06794335347201143, 0.016572982039568678, 0.04925079257892711, 0.033205271432442326, 0.043185130559972355, 0.01341456183165844, 0.04673521559951561, 0.030925291989530836, 0.01762140685293291, 0.021719532752675668, 0.03894320782274008, 0.010217883274890482, 0.028906063376260654, 0.04051707658384528, 0.030839023047259877, 0.03765655614967857, 0.07675704838974134, 0.013247489546691733, 0.08225587582481758, 0.01603919720011098, 0.07180191749440772, 0.03623441799676844, 0.06957478235874857, 0.035127245621489625, 0.029902101893510138, 0.05763216569487538, 0.05062243754842451, 0.12108898455543177, 0.037890094332396984, 0.05126266926527023, 0.02171005022579006, 0.05615313916600176, 0.006892857698923243, 0.09493481833487749, 0.03993243724107742, 0.01541020711218672, 0.027120272861793637, 0.10769297980836459, 0.0159736710733601, 0.012811328933042074, 0.061705058573612144, 0.027406616336000816, 0.03459545397864921, 0.050042059405573776, 0.09189593140035868, 0.04325204089816127, 0.047261551820806096, 0.05735585266458137, 0.03459087386727333, 0.02138696577666061, 0.06777666455933026, 0.009237113491898137, 0.01750476159421461, 0.03890014799045665, 0.04192696039431861, 0.02937411004677415, 0.11057064003710236, 0.029556832741945982, 0.046809963017169914, 0.051559263707271645, 0.03619808583919491, 0.1251294706016779, 0.011139965715951152, 0.03879708191379905, 0.04575984865160925, 0.03722595443416919, 0.054363211284258535, 0.0259592451620847, 0.054828710055777004, 0.02284122577735356, 0.09831982598240886, 0.050271427990602593, 0.5860123176659856, 3.4455971334661757, 12.351756181035723, 20.423984834126063, 39.26396451677595, 55.87815305164882, 72.56785460880825, 76.10846206120083, 75.4588680267334, 79.41383825029645, 89.29690034048897, 79.98145743778774, 72.00455025264195, 67.66930512019566, 70.85574204581124, 75.95553221021379, 65.98939745766776, 64.9942764554705, 54.004116194588796, 52.18041556222098, 42.68717520577567, 44.26289463043213, 46.360611370631624, 35.227662154606406, 33.07835156576974, 34.52008192879813, 35.9299304825919, 39.63552638462612, 35.12560701370239, 45.32332175118582, 62.38106591360909, 60.656821795872276, 51.873513630458284, 45.425342151096885, 49.673724378858296, 61.28855895996094, 66.87933662959507, 60.52251311710903, 68.26337609972272, 71.74336051940918, 74.81458241598946, 70.07682813916887, 78.38253102983747, 94.07264736720494, 76.82605811527797, 85.49302564348493, 81.93188626425606, 86.91876125335693, 58.39498860495431, 51.12341390337263, 38.99513871329171, 24.577586684908184, 9.460417934826442, 2.5843629240989685, 0.04172592403899346, 0.01905447111598083, 0.03672771295532584, 0.0677355724786009, 0.009461203922650643, 0.0384182218861367, 0.033191164689404626, 0.013483087083191743, 0.06254866759159736, 0.0692387582468135, 0.01655988292103367, 0.053973403094070296, 0.05536108184605837, 0.02413368401383715, 0.013766869935872299, 0.09117979875632695, 0.06817955151200294, 0.08144284159477268, 0.08267356162624699, 0.031160512939095497, 0.12841507286897727, 0.06333794631063938, 0.015649578999727964, 0.018123270012438297, 0.027306357697982873, 0.016946802248380015, 0.09620584334645953, 0.050424949931246896, 0.01259853526218129, 0.017182694947613136, 0.02015345696625965, 0.04167635027053101, 0.049172493030450175, 0.00443121195504708, 0.05236316824864064, 0.023995724273845553, 0.03250538970210722, 0.025680346913369637, 0.02077676262706518, 0.055906549362199645, 0.039217807552112, 0.025448786660230586, 0.04075573431327939, 0.05978448555937835, 0.03408653575128742, 0.03898610819929412, 0.02326303198268371, 0.03686442079820803, 0.03552256690870438, 0.015772692393511534, 0.06032996664622, 0.05900717619806528, 0.003468604222039825, 0.059525461601359506, 0.044425458647310734, 0.020537869106712084, 0.012522467245746936, 0.022109463079167262, 0.037464965001813004, 0.04468636214733124, 0.038297768349626234, 0.008104444315124835, 0.03802660879279886, 0.027321446620460068, 0.13727740517684392, 0.10806707652019602, 0.19157008613858903, 0.30141195920961245, 0.20663140581122466, 0.1116899446185146, 0.21471532274569782, 0.2548074871301651, 0.1418308365557875, 0.15474329010716506, 0.11249425967356988, 0.12666439823806286, 0.07536737474479846, 0.20829800995332853, 0.21944665243583067, 0.12659820036164351, 0.08745458722114563, 0.16799032927623817, 0.10483065447104828, 0.20425904382552418, 0.1402891507106168, 0.12244697740035397, 0.14222237840294838, 0.17751613312533923, 0.09268603793212346, 0.1711186742676156, 0.1749107622142349, 0.22143108238066944, 0.15147131282304013, 0.16084032080003194, 0.13843736079122337, 0.09955716173031501, 0.17131459446890013, 0.2150203242365803, 0.12821493217987673, 0.14634833272014344, 0.224834071206195, 0.10534154384263925, 0.13769779833299772, 0.1358993412660701, 0.15718828248126165, 0.1383704300969839, 0.12932910025119781, 0.11803704260715417, 0.17418726746525082, 0.19505858394716466, 0.1641394259142024, 0.22583922584142002, 0.07576931174844503, 0.20183971364583286, 0.07544490415602922, 0.11823315279824392, 0.22866689839533397, 0.15669977797993592, 0.1827274313462632, 0.1354509653257472, 0.2757414866771017, 0.35524003367338863, 1.718916695032801, 6.573856575148446, 18.03051802090236, 29.768156800951274, 52.6046586717878, 69.44754368918282, 86.2619549887521, 93.2497444152832, 91.66673633030483, 95.8996970312936, 96.27763039725167, 89.61248057229179, 75.5959142957415, 68.58926745823452, 69.14371980939592, 76.90268284933907, 61.03568622044155, 63.66415500640869, 47.78018740245274, 61.53888865879604, 41.581987789699006, 41.30676964351109, 42.188999789101736, 27.861036096300396, 25.04878224645342, 30.28357069832938, 35.76287146977016, 36.99197653361729, 32.743319852011545, 37.92853116989136, 50.344458307538716, 43.22381584984915, 46.22850527082171, 48.621589933122905, 57.65644373212542, 60.71062169756208, 66.22451754978725, 56.02533674240112, 71.34523568834577, 79.14661748068673, 82.98794296809605, 80.6262572152274, 90.35509014129639, 104.78050926753453, 86.91890021732875, 96.10043743678501, 94.72386033194405, 100.91555295671735, 74.75135380881173, 66.42229802267892, 55.10558979851859, 37.26445014136178, 16.601782526288712, 5.2262009126799445, 0.5427653725658144, 0.1167944957103048, 0.14150032214820385, 0.1788950384195362, 0.15630595625511237, 0.1358842642179557, 0.16591178652431282, 0.18029153134141648, 0.12219760221030031, 0.19119185714849404, 0.12461805875812258, 0.17768956667610578, 0.2952360420354775, 0.11416074846472059, 0.13814017602375575, 0.13585682426180157, 0.17582037911883422, 0.2078929381178958, 0.2210023296730859, 0.13677028167460645, 0.15525794534810952, 0.1162208757762398, 0.11095574937228646, 0.11237127520143986, 0.24084470208202088, 0.1611622313835791, 0.1729277300515345, 0.1123837059629815, 0.11065542977303267, 0.12480077466794423, 0.16929135232099465, 0.12915616881634506, 0.16593572523977074, 0.16073332939829144, 0.1571673157491854, 0.12575923252318585, 0.09044907760939427, 0.17910139448940754, 0.09994271211326122, 0.10530051961541176, 0.10487021984798567, 0.16928836676691258, 0.10369431187531777, 0.2207689679094723, 0.1771408218358244, 0.1427851010646139, 0.12859662169856684, 0.10219090219054904, 0.12771752529910632, 0.08510808420500585, 0.1677207608840295, 0.1310480194432395, 0.08328769688627549, 0.07570130896887609, 0.13139643360461506, 0.14747969486883708, 0.13155858990337166, 0.09213649920587029, 0.2139671700341361, 0.13695311972073146, 0.1655813263995307, 0.09223401825875044, 0.12346722265439374, 0.10687145031988621], [0.06651001609861851, 0.030726589794669832, 0.024632668488525918, 0.037900089153221676, 0.05067588235916836, 0.07548214894320283, 0.03618139387773616, 0.02408580488658377, 0.0208439749133374, 0.07368477753230504, 0.04680621750386698, 0.030582611449062824, 0.05516219983941742, 0.0202970875626696, 0.022575162018516233, 0.06368576336119856, 0.010310152163063841, 0.05223077588847705, 0.025263171709541763, 0.04868629215551274, 0.030105153497840677, 0.054073222380663664, 0.04399288918024727, 0.005554768830604319, 0.0659471916567002, 0.07660399124558483, 0.04038778852139201, 0.07527222377913338, 0.03932422219908663, 0.07261074480733701, 0.030343343038111925, 0.06360611013535943, 0.0285102399731321, 0.011708375349241709, 0.0388657326943108, 0.04861033694552524, 0.03985007666051388, 0.01123644067307136, 0.020371977472677827, 0.058401020509856086, 0.010722158626387162, 0.0714398647791573, 0.0603456815172519, 0.053480345622769425, 0.037616797390260866, 0.03139168303459883, 0.039541845342942646, 0.022161045311284915, 0.05323850217142275, 0.0324563519763095, 0.013515385350079408, 0.030964117763297896, 0.05504165130800434, 0.039451203242476494, 0.03237129082637174, 0.9400256957326616, 2.753445816891534, 8.12300261429378, 19.403193712234497, 37.75543417249407, 45.537996768951416, 52.802216802324565, 70.81945855276925, 70.73132065364292, 65.02379935128349, 61.19925376347133, 52.89997795649937, 32.501015322549, 41.39367423738752, 42.93547603062221, 30.14408908571516, 19.172296387808665, 14.333972147532872, 19.37002648626055, 20.2428366116115, 21.58604325566973, 30.582058361598424, 39.63098226274763, 56.40044566563198, 33.352388518197195, 42.20075961521694, 43.716866970062256, 43.73057576588222, 39.820397104535786, 41.865363121032715, 23.9830310685294, 27.888947010040283, 39.67612818309239, 26.80834753172738, 20.48400684765407, 22.611845765795024, 23.299060821533203, 23.969099930354528, 15.634952851704188, 15.507727861404419, 15.608633075441633, 25.712295259748185, 25.97010816846575, 26.617096628461564, 25.255367824009486, 49.713297843933105, 71.37753786359514, 76.39472089494977, 79.96192605154855, 71.81087616511753, 70.83990710122245, 79.29390539441789, 86.05041708265031, 76.46085384913853, 74.10877050672258, 49.83949450084141, 34.08583688735962, 19.02008741242545, 4.94962352514267, 1.5294921909059798, 0.13482528818505152, 0.046833633711295466, 0.0324096653743514, 0.019919908605515957, 0.05747103398399694, 0.03731837768905929, 0.00872271100524813, 0.0736857478373817, 0.0386933847995741, 0.003136910223734698, 0.022067980840802193, 0.023850790890199796, 0.05102346531514611, 0.007691276708750853, 0.034058105134006054, 0.042909529991447926, 0.08218641419495855, 0.03199712626103844, 0.04069452706192221, 0.04063583717548421, 0.046690741021718295, 0.013483167659225208, 0.02692667833928551, 0.012539232149720192, 0.061295888386666775, 0.03043391728507621, 0.02473547332920134, 0.008676037125821625, 0.018607118067198565, 0.016950722484450256, 0.025672548849667822, 0.10187093221715518, 0.033505767450800965, 0.02689643094449171, 0.04936196714905756, 0.03746688186324068, 0.022213448570775132, 0.02822595415636897, 0.037383625616452525, 0.046355293664549074, 0.017141261903036917, 0.026820245032597865, 0.021526674440662776, 0.022834333557901636, 0.058026231692305634, 0.042565665407372374, 0.022413090536636964, 0.016264128166117837, 0.03118545588638101, 0.03757798518719418, 0.10785796559814896, 0.12333109495895249, 0.03435119154996105, 0.07567329225795609, 0.07030872654701982, 0.04460468688713653, 0.06044991806681667, 0.030708079359361103, 0.013581233780964144, 0.04780469874718359, 0.07587567889796835, 0.09563962622944798, 0.03189681164388146, 0.03387195583699005, 0.019257766992918084, 0.09116390068084002, 0.05353552409048591, 0.03911862608843616, 0.05024256989625948, 0.013522175789278532, 0.10024997312575579, 0.021173944796568582, 0.04426748212426901, 0.016045809523867707, 0.040016287206006904, 0.0982593617268971, 0.03321796342996614, 0.06576969368117196, 0.024831362201699188, 0.054076852543013434, 0.058774330121065886, 0.017260219269831265, 0.05367049149104527, 0.007212992641143501, 0.014986090495118072, 0.04415084195456334, 0.008760876055540783, 0.026482719661934034, 0.052727999564792426, 0.08310808188148908, 0.03141879050859383, 0.013780451662439321, 0.007746571375589285, 0.021063932217657566, 0.014392574217968752, 0.057266645665679655, 0.030392462188111882, 0.09452208583908421, 0.02332749280945531, 0.06025763481323208, 0.021121967317802564, 0.04923861287534237, 0.04700884163113577, 0.01677336191226329, 0.039984962636871, 0.05258549703285098, 0.09249773089374815, 0.010991544662309545, 0.07352358475327492, 0.10994275087224585, 0.03212402927290116, 0.04148515945832644, 0.044465868800346336, 0.1477703114173242, 0.037009491585195065, 0.14657108219606535, 0.7280935336436544, 2.4025168418884277, 7.233214999948229, 20.584026166370936, 42.659038475581575, 56.06850937434605, 65.28396769932338, 81.01741300310407, 84.18366541181291, 78.09493119376046, 73.80491188594273, 65.9484030859811, 44.58406468800136, 52.62609386444092, 63.09643159593855, 41.502333641052246, 32.13056864057268, 29.466222831181117, 32.87876456124442, 32.38152367728097, 33.46505355834961, 36.41199997493199, 46.81498186928885, 42.57887710843767, 31.501801831381663, 43.324860027858186, 31.810246263231548, 34.338997977120535, 30.48734746660505, 38.681069714682444, 30.087430000305176, 29.059878281184606, 31.23434829711914, 30.134319918496267, 19.163541657584055, 26.864765167236328, 32.58680820465088, 36.16423416137695, 22.98507867540632, 25.1354957648686, 29.480046272277832, 45.18245397295271, 45.62764242717198, 47.404303755079, 42.279871804373606, 65.0881952558245, 82.37567465645927, 77.86394527980259, 87.23839228493827, 81.40818664005825, 80.33478723253522, 87.94206414903913, 93.32963480268205, 84.79274450029645, 82.33087962014335, 56.47694533211844, 38.29005983897618, 21.202935218811035, 5.621306751455579, 1.994425688471113, 0.12938430586031505, 0.020725528144144585, 0.03360226870115314, 0.04371376022962587, 0.08506615752620356, 0.04693350728069033, 0.026482697609545927, 0.10280411464295217, 0.022308579180389643, 0.012464761235085981, 0.0900667706238372, 0.07329909144235508, 0.04694940535617726, 0.02618291405295687, 0.02416080336219498, 0.07092745548912457, 0.03984686718987567, 0.015857683993609886, 0.06763486431113311, 0.02629834643032934, 0.0491511429260884, 0.04331029652218733, 0.030372557363339832, 0.039970289317092726, 0.03215226650770221, 0.03929325046816042, 0.00963240085236196, 0.016839882092816488, 0.009527059138885565, 0.023066441728068248, 0.04980275367519685, 0.027678844585482563, 0.047445726580917835, 0.016497523856482336, 0.06599014970873084, 0.04652525990137032, 0.019773602884794985, 0.06820916278021676, 0.022226439123707156, 0.04488440616322415, 0.017415038908698728, 0.0454846585967711, 0.03447970608249307, 0.06521443490471159, 0.08325830274926764, 0.014512532423915607, 0.04406491906515189, 0.03623008215799928, 0.03915724830169763, 0.017409836241443242, 0.07346255052834749, 0.024974602640473416, 0.0582102436040129, 0.024353415705263615, 0.07618711968617779, 0.061949100478419235, 0.04128863875355039, 0.04012330235647304, 0.05437767765085612, 0.014064099656284919, 0.0029699723735185607, 0.24014773805226597, 0.14039615568305763, 0.09747309570333787, 0.10881288150059325, 0.15017041191458702, 0.2107552159577608, 0.11935102567076683, 0.16769748713288987, 0.14379900880157948, 0.2002737091055938, 0.17009419495505945, 0.15687773057392665, 0.11035844856607062, 0.10311022214591503, 0.16520894638129643, 0.15903103431420668, 0.2629592439958027, 0.15211294910737447, 0.1361859408872468, 0.11320742033421993, 0.10986992370869432, 0.12260845516409193, 0.11226892497922693, 0.11152032443455287, 0.12671619760138647, 0.1669868981199605, 0.10383455827832222, 0.12618711670594557, 0.16651416277246817, 0.1404304759843009, 0.1079708466838513, 0.20881073815482004, 0.08746357102479253, 0.13692937099507876, 0.11162351604018893, 0.19221514223941735, 0.19194769087646688, 0.10725531793598618, 0.19955135429544107, 0.1151192741734641, 0.07001823213483606, 0.11612867643790585, 0.15010947946991238, 0.11537775530346803, 0.13674005972487585, 0.10404387954622507, 0.10724349785596132, 0.15786058854843887, 0.21911364101937839, 0.09411975528512682, 0.16337135141449316, 0.09356936160475016, 0.19128257728048734, 0.12585092974560602, 0.403747877904347, 1.8639070349080222, 5.2370118754250665, 13.044011286326818, 30.349727971213206, 55.87283420562744, 72.82003252846854, 83.89013181413922, 97.10554300035749, 97.4042877469744, 88.10970333644322, 88.01483263288225, 76.42124216897147, 54.23428569521223, 62.00743348257882, 63.765654291425435, 44.92816727502005, 30.359629154205322, 20.149888822010585, 29.205179010118755, 31.057110173361643, 36.1025584765843, 43.22281878335135, 55.18314559119088, 74.08899593353271, 48.91333784375872, 58.12790332521711, 61.83116463252476, 61.32637800489153, 54.92417580740792, 58.09669549124581, 35.31262125287737, 44.56317492893764, 58.247572149549214, 40.37790666307722, 31.627293246132986, 36.51584080287388, 39.070658683776855, 41.08660207475935, 28.050358874457224, 24.64052173069545, 24.937548535210745, 40.52013976233346, 40.45734541756766, 42.73535054070609, 41.59702716554914, 68.67634228297642, 89.82956314086914, 93.60076740809849, 100.09335177285331, 93.10483278547014, 92.04359967367989, 99.09087262834821, 106.44936234610421, 97.3677749633789, 96.63737337929862, 72.8236733845302, 55.16732454299927, 33.32035732269287, 14.416479400226049, 5.230590437139783, 0.4996947380048888, 0.2576219418219158, 0.12960705533623695, 0.12998528432633194, 0.1736381562160594, 0.11067321417587143, 0.09718568184013877, 0.2263123004564217, 0.15978165689323628, 0.12635322207851069, 0.08626098984054156, 0.21281095993305954, 0.1265328981514488, 0.15350243954786233, 0.12884778822106974, 0.24803036078810692, 0.19236298144928046, 0.11704441372837339, 0.10865698808005878, 0.07574299816042185, 0.12765273877552577, 0.08475928327866963, 0.1528417771416051, 0.09532471134194306, 0.2229257593197482, 0.1094740799495152, 0.06520110169159514, 0.16615451207118376, 0.11300964094698429, 0.10088531939046723, 0.1659431755542755, 0.15292994598192827, 0.1521949568497283, 0.11586898751556873, 0.12318455853632518, 0.16431576359484876, 0.0737011098702039, 0.07514091368232455, 0.10849447894309248, 0.12386663550777094, 0.13624812183635576, 0.15806056638913496, 0.06650340716753687, 0.12236050489757742, 0.13953244845782006, 0.2140252526317324, 0.09899912096027817, 0.08319512435368129, 0.1132616556382605, 0.09587465718920742, 0.1759133112749883, 0.24361361350331986, 0.13434887517775806, 0.14533177869660513, 0.2503729893692902, 0.14088959991931915, 0.2062945674572672, 0.05929330763007913, 0.08971383741923741, 0.10083440212266785, 0.1261107272335461], [0.09126626447375331, 0.04422858849700008, 0.031051815021783113, 0.05219128854306681, 0.05750519822218588, 0.021793528692796826, 0.046843709956322394, 0.017640483864982213, 0.05007782159373164, 0.008046574607890631, 0.05191368629623737, 0.04574692595217909, 0.0323736690916121, 0.030574852401124578, 0.02922281709366611, 0.04240669483052833, 0.02825406246951648, 0.026404744113928506, 0.009063215144643826, 0.07632650434970856, 0.0780766090112073, 0.013849325511338455, 0.07050664842660938, 0.041116443529192886, 0.0575258731842041, 0.019047059817239642, 0.012323888035358062, 0.03205729874649218, 0.03058343247643539, 0.05970086968903031, 0.04707201324137194, 0.01603809118803058, 0.017623213452420065, 0.02248958857463939, 0.08795268620763506, 0.06682382497404303, 0.06644858832338027, 0.00572702893987298, 0.026193780791280524, 0.02862454598237361, 0.04406176387731518, 0.01075220330884414, 0.019197611470839808, 0.03441709765632238, 0.01433033898605832, 0.049551655006195815, 0.008490490028634667, 0.057425124304635186, 0.02989142175231661, 0.06141478129263435, 0.060278289419199736, 0.03140226139553955, 0.2652500325015613, 2.1866806064333235, 12.69851471696581, 18.885189873831614, 32.40481751305716, 51.89714445386614, 60.12784154074532, 67.14413247789655, 70.24737167358398, 57.443922655923025, 69.46050902775356, 39.92805596760341, 47.78674302782331, 55.92273269380842, 44.75702272142683, 34.96513836724417, 34.842155252184185, 28.864974362509592, 32.17361273084368, 44.545932974134175, 50.03639950071062, 54.19681406021118, 57.35289083208357, 67.64416653769356, 83.70759568895612, 56.15530974524361, 64.8507753099714, 74.82860388074602, 85.94399847303117, 96.83078343527657, 95.61698177882603, 94.64344188145229, 76.63601098741803, 95.63504014696393, 86.79856436593192, 76.98335143498012, 91.01707281385148, 105.4158525466919, 79.85085909707206, 61.40913105010986, 44.307713985443115, 67.62896387917655, 64.34268133980888, 56.78830453327724, 33.25341837746756, 27.418682507106237, 33.86723613739014, 28.13228508404323, 24.6651166166578, 29.455918652670725, 50.076438495091026, 46.85032735552107, 51.01388250078474, 54.052823066711426, 65.18893718719482, 60.21829319000244, 67.90794794900077, 74.55817304338727, 66.38614654541016, 74.85849503108433, 60.78010368347168, 47.83682911736624, 29.89494058064052, 14.019336002213613, 3.040576215301241, 0.19391320326498576, 0.08503175580075809, 0.06105484560664211, 0.010923494385289294, 0.028785073797085454, 0.04500139917113951, 0.05020478567374604, 0.0825968464570386, 0.06019921973347664, 0.02219596102700702, 0.06604726200125047, 0.059368278964289596, 0.03498873287545783, 0.022363038400986364, 0.02219796779432467, 0.024616941743131195, 0.03070311926837478, 0.010230552371857422, 0.04704645961256964, 0.04069797741249204, 0.024069426747571145, 0.015600634572495307, 0.050506231641130786, 0.03317700705624052, 0.06428775284439325, 0.021667701158938662, 0.053624371465827735, 0.0401700093144817, 0.031100622045674493, 0.012804010084697177, 0.08188538891928536, 0.030524315112935643, 0.03593316201918891, 0.034154531745506186, 0.060476231654839854, 0.05427299326817904, 0.05144113076052495, 0.05569514838446464, 0.021151095129815594, 0.03300509342391576, 0.03983989863523415, 0.03844173312453287, 0.04415803103308592, 0.04280737315171531, 0.02116514928638935, 0.02349007997794875, 0.029211492344204868, 0.013921151835737484, 0.07549066455768687, 0.06624266651592084, 0.0465582027765257, 0.05317476059177092, 0.0471721887588501, 0.034795394499919245, 0.04722367260339005, 0.06619733359132494, 0.039398565888404846, 0.028723415319940875, 0.02233107770527048, 0.06087144437645163, 0.02977191816483225, 0.013790322650623108, 0.04278228431940079, 0.03173570707440376, 0.07823393414063112, 0.049663884698280265, 0.012632558704353869, 0.024510038550943136, 0.01809074273998184, 0.057381005957722664, 0.008952373904841287, 0.03999340361250298, 0.05287118063175252, 0.0506508104902293, 0.03177343701411571, 0.008056383679753967, 0.04358304724363344, 0.05089274893647858, 0.06009188906422683, 0.0424033462602113, 0.006340894482231566, 0.03847996178748352, 0.011551700765267015, 0.040117012336850166, 0.02003807039000094, 0.038117749616503716, 0.01930959858665509, 0.05307483613224966, 0.07066583952733449, 0.056149865234536786, 0.01806325019736375, 0.04178188621465649, 0.038295749707945755, 0.05668455422190683, 0.07541237518723522, 0.03244714764878154, 0.01444843630971653, 0.05757541981126581, 0.06153910247875111, 0.0538065750817103, 0.022651142673566937, 0.04482803347387484, 0.028518083837947676, 0.02821675152517855, 0.03442962680544172, 0.008949335764295288, 0.030814643284039836, 0.09362509647118193, 0.09466942971838371, 0.03563737842653479, 0.05718438686536891, 0.08394146537674324, 2.064174745764051, 12.890998925481524, 19.767188991819108, 34.3312611579895, 54.44541365759713, 70.77990245819092, 81.23619093213762, 80.7019578388759, 71.96621009281704, 82.98098087310791, 51.66022825241089, 63.00044918060303, 69.55837440490723, 57.14984709875924, 48.46056890487671, 38.53536946432931, 33.01536961964199, 38.42998266220093, 38.12973015648978, 28.112229108810425, 41.10732160295759, 42.834702832358225, 53.62064511435372, 55.01077815464565, 52.62051446097237, 63.53449467250279, 53.57495723451887, 57.617106505802695, 69.52990068708147, 60.218605858939036, 66.49162714821952, 61.27200140271868, 61.76331547328404, 71.7614744731358, 67.4164810180664, 58.96131542750767, 59.89049802507673, 58.020209721156526, 56.21543945584978, 41.29338393892561, 54.977621350969585, 47.33594390324184, 39.54304238728115, 37.803751945495605, 28.864755494253977, 35.40131500789097, 33.46038784299578, 39.96346746172224, 42.13620042800903, 66.7156787599836, 65.80907780783517, 66.3775794165475, 69.34706578935895, 74.94953032902309, 70.22024590628487, 78.83285072871617, 84.46417113712856, 76.23387704576764, 86.40328829629081, 68.56808934892926, 55.71042353766305, 34.715989862169536, 14.983519281659808, 3.4326734840869904, 0.26766789704561234, 0.0647581811728222, 0.06471501956028597, 0.05520819094298141, 0.017307752344225134, 0.05967409469719444, 0.07907767886562006, 0.04221739034567561, 0.017720437342567102, 0.027394200841497098, 0.046729000218744786, 0.06620607312236514, 0.06420161282377583, 0.02080164959521166, 0.041498675875897915, 0.03331294136920145, 0.04934873910886901, 0.05212133497531925, 0.03985229207734976, 0.03152642312592693, 0.01415773494435208, 0.06028536653944424, 0.06054005465869393, 0.04812056358371462, 0.06276254182947533, 0.039030470818813355, 0.056872963040534935, 0.02711247479809182, 0.04209239401721528, 0.05671166508857693, 0.03021153082538928, 0.03337132591488106, 0.040564828485782654, 0.021549385007736937, 0.04473071798150029, 0.04111983959696122, 0.03348721291071602, 0.03392129551087107, 0.015886564140341113, 0.014673536909478051, 0.04489287767293198, 0.0036115522546294543, 0.0250542321175869, 0.03041864006913134, 0.05479168579248445, 0.02609905051732702, 0.05287442742181676, 0.0649026141368917, 0.032889745863420625, 0.051320738292166164, 0.0655453157212053, 0.07669222115405969, 0.030028282265577997, 0.03510628906743867, 0.010463270375372043, 0.06416224422199385, 0.02028783573769033, 0.034102576319128275, 0.051862718138311587, 0.16680055883313927, 0.12484665720590524, 0.09123111635978733, 0.1196716877498797, 0.14572949521243572, 0.13565614074468613, 0.13225631389234746, 0.12775191345385142, 0.17101036650793894, 0.10141436635915722, 0.152539299800992, 0.1164497049259288, 0.15694620832800865, 0.14367406336324556, 0.09405944030731916, 0.15701316616364888, 0.14450085828346865, 0.12930118532053061, 0.1283654583884137, 0.2195764968969992, 0.22625575134796755, 0.08761968157653298, 0.19490602213357175, 0.14675130109701837, 0.12290190798895699, 0.16024208361549036, 0.1254284874136959, 0.10871279758534261, 0.11814875661262444, 0.07990814466029406, 0.10736156973455634, 0.06502040781612907, 0.08893903185214315, 0.17829874184514793, 0.1989493580268962, 0.23611976419176373, 0.1158002247767789, 0.0816725596253361, 0.14428535556154592, 0.15771644056907722, 0.1807619868112462, 0.09308553899505309, 0.16784775549811976, 0.08363661316356488, 0.10966598322348935, 0.23614326864480972, 0.0983707636062588, 0.10577479523739644, 0.14954276702233724, 0.30336239455001696, 0.15976691911263124, 0.17901302208857878, 0.43519507188882145, 4.5902739848409375, 21.770460605621338, 31.502614770616802, 48.16050747462681, 67.67840031215123, 84.02615669795445, 95.22980036054338, 95.1724499293736, 80.3836886542184, 91.76933343069894, 59.05850682939802, 71.18267563411167, 76.50762912205288, 65.30142852238247, 54.93947226660592, 51.560914175851, 42.388305391584126, 47.16921840395246, 61.13833195822579, 66.98358740125383, 73.8644996370588, 78.62053462437221, 85.80902276720319, 106.21249825613839, 75.86478178841728, 88.15203176225934, 96.00738716125488, 111.35683332170758, 123.69381850106376, 124.45029667445591, 124.27442387172154, 102.03860419137138, 127.9867491040911, 115.06007031032017, 103.61786719730922, 118.37707083565849, 138.89576830182756, 105.4482033593314, 86.75229631151471, 63.29168292454311, 93.15418584006173, 84.14422743661063, 75.63931969233921, 47.149110317230225, 40.75811903817313, 45.66921697344099, 42.944908210209434, 38.27195978164673, 44.82558407102312, 69.43885149274553, 65.11973312922886, 69.84551565987724, 73.98245920453752, 85.33197334834507, 80.7004987171718, 89.57197952270508, 94.27792494637626, 87.53218296595982, 99.37440082005092, 82.77137456621442, 72.06042766571045, 51.61303608758109, 28.282519033976964, 8.065061586243765, 0.7395920966352735, 0.150142103433609, 0.12722337538642542, 0.1467716164354767, 0.1263875559504543, 0.1772143750318459, 0.13609009103051253, 0.1593588888645172, 0.14097532603357518, 0.08828903601637908, 0.24733950357351983, 0.22682747138398035, 0.22447589971125126, 0.12852095147328718, 0.10473042806344372, 0.06821202619799546, 0.11705308540591172, 0.08289947986070599, 0.13170785403677396, 0.12419841199048928, 0.1762122195214033, 0.13786279090813228, 0.19951716970120156, 0.12367064745298453, 0.1662438887038401, 0.18733828035848482, 0.1897344724940402, 0.11966653088373796, 0.10454678934599672, 0.10847687095935855, 0.09887712036392518, 0.1287308766373566, 0.0818032386845776, 0.09014089378927435, 0.1494003425219229, 0.19177652363266262, 0.12114478727536541, 0.10358268607939992, 0.11399096543235437, 0.15067210713667528, 0.14976407800401959, 0.12903855155621255, 0.10001661814749241, 0.09222289028444461, 0.20753359954271997, 0.1425707654229232, 0.1377782997276102, 0.15137776998536928, 0.16545849799045495, 0.15155706607869693, 0.14114026432590826, 0.1036619186135275, 0.12855555675923824, 0.10357224342546292, 0.1572307723441294, 0.12928671895393304, 0.08526502256946904, 0.119819934080754, 0.17092063703707286], [0.05209397644336734, 0.07544936213110175, 0.03290061938709446, 0.0608883263277156, 0.039522049083773575, 0.031388758548668454, 0.0046411570510827005, 0.09380330012312957, 0.033653070617999346, 0.03797065340248602, 0.11772297588842255, 0.048291266031031094, 0.066368093714118, 0.02615155725340758, 0.0293654994373875, 0.0479697659611702, 0.04679444492129343, 0.028135013500494615, 0.053456739389470646, 0.07779794146439858, 0.06565223926944391, 0.047194465063512325, 0.023626197495364716, 0.09223407254155193, 0.026037051076335565, 0.02478923705140395, 0.024457080589075173, 0.04926102488700833, 0.08723893522151879, 0.015093338043828095, 0.013054650742560625, 0.05659406479181988, 0.025052964953439574, 0.009891892151374902, 0.021227574508105005, 0.11980830399053437, 0.04327104327135852, 0.11734138136463505, 0.010527504741081169, 0.026785393777702535, 0.06156875445906605, 0.11344251914748124, 0.041640069003083875, 0.035210145637393, 0.03820359447438802, 0.013702041852021856, 0.03893673120598708, 0.06037954720003264, 0.05461404871727739, 0.04711396027622478, 0.3974927621228354, 2.837464302778244, 13.701028602463857, 37.383472783224924, 54.84888512747628, 61.31212030138288, 63.104310853140696, 62.04965073721749, 63.46322005135672, 53.30129895891462, 46.146721499306814, 32.20226015363421, 25.81267762184143, 30.56643533706665, 20.650633335113525, 20.467171362468175, 20.336248193468364, 19.45368106024606, 32.21022973741804, 57.758623940604075, 65.83851037706647, 71.83625098637172, 90.12664726802281, 67.60647256033761, 66.87799562726701, 58.76624475206648, 54.872019154684885, 48.73290702274868, 34.49196604319981, 39.705460003444124, 39.65501608167376, 28.222576924732753, 31.70450857707432, 25.77151128223964, 28.47066409247262, 40.932560511997764, 30.445109367370605, 25.496211494718278, 34.1310453414917, 32.06489426749093, 41.44129024233137, 51.67512171609061, 54.77814204352242, 47.98451655251639, 68.8363037109375, 101.79557704925537, 98.56663799285889, 95.90424810137067, 84.3184813090733, 82.73974636622837, 39.65915025983538, 29.376577172960552, 23.375562225069316, 15.39563431058611, 22.784864595958165, 16.730998175484793, 30.125829219818115, 40.89562736238752, 38.683932372501914, 45.00665760040283, 52.7812853540693, 57.44342933382307, 65.87172276633126, 64.80091503688267, 62.19992637634277, 54.905453886304585, 41.12774930681501, 19.13284625325884, 4.937878029687064, 1.1099547488348824, 0.10360194290322916, 0.06385431145983082, 0.06449907579060112, 0.05705265607684851, 0.04275032871269754, 0.05932870001665183, 0.03144228817628963, 0.02975634578615427, 0.015621842184503163, 0.04333711561879941, 0.0073473307004730615, 0.0374892633408308, 0.09995998082948582, 0.015595754209373678, 0.020142064363296543, 0.045306285311068804, 0.01698831671715847, 0.020054116046854427, 0.02274126060573118, 0.0116129809591387, 0.01649085894626166, 0.08381432148494891, 0.05186170372845871, 0.00817159129240151, 0.05213164531492761, 0.06882559827395848, 0.06060152993138347, 0.04049287323973008, 0.05887865488018308, 0.06311843344675643, 0.038234260864555836, 0.08386025152036122, 0.05479761618854744, 0.03221947540129934, 0.07349816683147635, 0.07068618879254375, 0.0481993923895061, 0.00774926007060068, 0.04591638668041144, 0.0410848102266235, 0.02170781445290361, 0.0441223502691303, 0.035645429244531054, 0.07408098770039422, 0.02127846293816609, 0.06433555563645703, 0.04842193151957222, 0.015493526123464108, 0.07875272844518934, 0.027518371053572212, 0.031279337991561205, 0.04081209343192833, 0.09139424296362059, 0.004963934463116207, 0.03608262971309679, 0.034305607567408254, 0.060832598246634007, 0.022132032850225056, 0.03226851312709706, 0.05508128793111869, 0.03220715320536068, 0.07842399858470474, 0.05399430536531976, 0.030594852220799242, 0.023921331390738487, 0.02998563294698085, 0.021597220030214106, 0.03148944975276079, 0.039493340267134566, 0.06153163180819579, 0.020171580636607747, 0.02401410918017583, 0.01611792083297457, 0.027277543708415966, 0.0133441723051614, 0.06304469026092972, 0.03334756701120308, 0.03433433674009783, 0.02358805704196649, 0.044102153674300225, 0.07784928620925971, 0.011872857326774724, 0.024957803809749227, 0.01535297607603882, 0.044160450010427406, 0.014996533149055071, 0.030600904753165584, 0.06677313840815, 0.022054423711129596, 0.03382867548082556, 0.02936164875115667, 0.0539068829135171, 0.08158882161868469, 0.046099435072392225, 0.026063003344461322, 0.03325224301910826, 0.037007547582366636, 0.03460591020328658, 0.047330300988895554, 0.04675845203122922, 0.01888662021208022, 0.06784789716558796, 0.07205231048698936, 0.07622534156377826, 0.10193808682795082, 0.05058582719149334, 0.37131102702447344, 2.998787577663149, 15.442798682621547, 41.78065068381173, 61.29064341953823, 68.51620715005058, 74.48079095567975, 73.05222048078264, 75.0007871900286, 67.53767844608852, 62.62002141135079, 41.61951848438808, 42.7467942237854, 38.31414576939174, 34.86887454986572, 32.94560275759016, 36.059771469661165, 35.387185846056255, 35.29382637568882, 40.901724406651084, 49.45703090940203, 58.043055398123606, 65.03329059055874, 59.510299546378, 51.1976032938276, 51.77053090504238, 46.60786649159023, 44.2386280468532, 36.28675174713135, 39.81976134436471, 36.876740659986226, 32.181446824754985, 33.030058111463276, 30.706507546561106, 29.519178526742117, 38.85492753982544, 29.193290642329625, 25.897588082722255, 33.51208938871111, 33.748098850250244, 35.77316870008196, 37.918907914842876, 41.205579553331646, 46.192864486149375, 59.308544703892295, 69.0382878439767, 57.70528956821987, 69.25847625732422, 65.18652616228376, 69.98214503696987, 31.747788906097412, 32.55275855745588, 32.92250347137451, 19.787924153464182, 33.51146752493722, 30.652155263083323, 46.72232416697911, 54.772409779684885, 54.228699343545095, 58.9010398047311, 66.04318346296037, 66.9383407320295, 75.42307785579136, 76.27522577558244, 73.91563143048967, 62.85418265206473, 47.860473837171284, 23.38463830947876, 7.29801607131958, 1.4721519649028778, 0.22728802024253777, 0.13754149100610188, 0.08867886116994278, 0.06334589874105793, 0.051771312685949464, 0.06520783275898014, 0.002647538257796051, 0.0352148614557726, 0.06493056299430983, 0.04443348910925644, 0.03717613639310002, 0.023479627145986472, 0.060243378792490275, 0.018145159552139894, 0.0147959073074162, 0.05305802881983774, 0.08349125060651984, 0.006145470883763794, 0.06421896974955286, 0.04129228587927563, 0.07368466896670205, 0.04035978538117238, 0.061456490840230665, 0.04445055426497545, 0.024808677079688226, 0.014354245471102851, 0.07665720196174723, 0.030533339628683667, 0.0555177996866405, 0.08305940377925124, 0.010073502897284925, 0.08385337796062231, 0.05201291525736451, 0.05061438673042825, 0.008915044300790344, 0.02397985164342182, 0.043243922226663144, 0.011289843923545309, 0.06289958554719176, 0.02025857730768621, 0.002124452219244891, 0.06122625033770289, 0.06753768452576228, 0.034654072618910244, 0.055479099441851885, 0.029623587017080615, 0.0740066474037511, 0.02263621999216931, 0.006761386450047472, 0.038920046029878516, 0.040478233846702745, 0.06820430446948324, 0.02227504937244313, 0.005914882207954568, 0.009454554279467888, 0.014777525793761015, 0.16748423714722904, 0.12201378707374845, 0.18809490118707928, 0.13641901766615255, 0.14751496511910642, 0.12569352319197996, 0.18584380697991165, 0.22858338430523872, 0.1015458596604211, 0.10535613913089037, 0.1930422085736479, 0.1115869769294347, 0.12884792392807348, 0.14041296978081974, 0.08880911275212254, 0.1572357935032674, 0.13047384311045918, 0.18296803986387594, 0.20582818319754942, 0.22708892449736595, 0.1919776956949915, 0.1398354007729462, 0.16286405149315084, 0.29671576406274525, 0.24520692229270935, 0.13732744034911903, 0.07761527305202824, 0.17553976417652198, 0.157466536121709, 0.09795642976782151, 0.08228398753064019, 0.13470022061041423, 0.13994359996701988, 0.14456312065677984, 0.15564209116356714, 0.14685508981347084, 0.1946862039289304, 0.2079013248107263, 0.10778545734605618, 0.10568927946899619, 0.2349788211286068, 0.2879652407552515, 0.16732802481523582, 0.06870555864380938, 0.21091756224632263, 0.12558851311249392, 0.15198789510343755, 0.13642684796026774, 0.27791209306035725, 0.11206672832901989, 0.8211663365364075, 6.293486773967743, 24.745012215205602, 55.33157300949097, 73.74679715292794, 80.12295750209263, 82.62455912998745, 82.00714915139335, 85.80208846500942, 76.49981239863804, 68.3115896497454, 48.26226036889212, 41.09269911902291, 48.70113638469151, 34.20725318363735, 32.288327489580425, 35.30243171964373, 36.190981251852854, 51.147531100681846, 78.19110815865653, 88.68253367287772, 93.00333350045341, 117.52797317504883, 89.74532318115234, 88.02057184491838, 77.44387803758893, 71.60072095053536, 63.97402381896973, 49.09402922221592, 52.926943915230886, 52.8172527040754, 39.47834423610142, 44.74741683687483, 37.25949607576643, 40.036513873508994, 54.77238546098982, 41.61186851773943, 36.48219067709786, 46.786654063633506, 45.94279187066214, 54.25881283623831, 69.04793889181954, 72.39207213265556, 64.71185997554234, 88.46192836761475, 127.13452475411552, 119.7333869934082, 118.250460760934, 104.33284378051758, 104.87953499385289, 51.56492328643799, 44.40973091125488, 39.04347038269043, 26.065048354012625, 36.500554765973774, 27.555685349873134, 46.04826899937221, 59.1343047278268, 59.27282401493618, 64.84630067007882, 71.14466898781913, 76.9088111604963, 86.16188703264508, 84.94367327008928, 85.33212620871407, 76.1428347996303, 63.315612520490376, 36.09966107777187, 13.536027993474688, 2.9064788052013943, 0.4018848107329437, 0.2313790571476732, 0.2338684664240905, 0.10269035824707576, 0.15958953648805618, 0.1575260300721441, 0.14282493107020855, 0.10306304360606841, 0.1670829379665, 0.16413042853985513, 0.12968206059719833, 0.12835572819624627, 0.16870581731200218, 0.11341389175504446, 0.13219397009483405, 0.12820071008588585, 0.2053996069090707, 0.14693203568458557, 0.13480529854340212, 0.18501653708517551, 0.15705851944429533, 0.1945568480129753, 0.12910230670656475, 0.21876848382609232, 0.16541591313268456, 0.14740611453141483, 0.1631992749337639, 0.10244085413536855, 0.16131381610674517, 0.16389201847570284, 0.09558423063052551, 0.21477063692041806, 0.12606538752360003, 0.1365773334567036, 0.18851126384522232, 0.12497719377279282, 0.11211771345032112, 0.07703365319009338, 0.22601328364440373, 0.0750183906140072, 0.0976442765178425, 0.1532964227455003, 0.1270022001117468, 0.1621134831969227, 0.09544063226452895, 0.15825932286679745, 0.1193770949861833, 0.11018042811857802, 0.2505987786820957, 0.14093313472611563, 0.10929933682616268, 0.18728326473917278, 0.15424958802759647, 0.0636563760095409, 0.10450856746839625, 0.14298757591417857], [0.045515328379614015, 0.05967449503285544, 0.06429208189781223, 0.07156312745064497, 0.033014972893787284, 0.031688179089022536, 0.00735419662669301, 0.008270804986490734, 0.07749948105109589, 0.03561355506203004, 0.04396151711366006, 0.057133584948522706, 0.019017172046005726, 0.06915122722940785, 0.016024147293397357, 0.05853703285434416, 0.02473705940480743, 0.030407844576984644, 0.05398946062528661, 0.01283002766181848, 0.03525930889216917, 0.03173495390053306, 0.07094513811171055, 0.03671060708750572, 0.02020138019828924, 0.03938575853992786, 0.021613801729732325, 0.019411192242322222, 0.017269552519012774, 0.06953151218060936, 0.04042270254077656, 0.03526383132806846, 0.009667318264421607, 0.03362641776246684, 0.053768963885626624, 0.020522166110043014, 0.05998971526111875, 0.012688844880488302, 0.030692866604243006, 0.02401888945938221, 0.041263129229524305, 0.032505586477262635, 0.05980437342077494, 0.09904275754732744, 0.025773129791819623, 0.07945909018495254, 0.06371582246252469, 0.10267657720084701, 0.6602277638656753, 4.335119196346827, 18.122407947267803, 44.70514399664742, 61.04130036490304, 61.58038330078125, 65.47197205679757, 69.69937419891357, 52.752207142966135, 46.97364745821272, 36.00548519407, 31.229449817112513, 24.008214814322336, 24.300334453582764, 24.705949442727224, 25.694262947354996, 34.61474766050066, 37.89169529506138, 20.483213015965053, 40.801757199423655, 37.9188106400626, 30.158346789223806, 46.0605013029916, 44.17248119626726, 33.15080043247768, 30.785341807774135, 25.30779024532863, 15.448603902544294, 10.784694211823599, 7.991798911775861, 5.608976304531097, 2.3301342001983096, 0.6599759459495544, 1.2932206520012446, 0.7919450902513095, 0.8965390920639038, 0.7698186604040009, 0.30863116468702045, 0.502441936305591, 0.701730982533523, 0.8357740012662751, 1.0708828568458557, 2.287148952484131, 3.670968685831342, 6.158535386834826, 12.903684599058968, 18.227925028119767, 28.480184861591884, 43.67337472098214, 44.35521534511021, 57.213919912065776, 58.48496082850865, 74.2849976675851, 60.91092436654227, 39.33748688016619, 59.1223121370588, 50.71478687013899, 35.31740508760725, 24.197817257472447, 15.641119377953665, 12.494243758065359, 20.09076312610081, 27.20730093547276, 52.01739692687988, 65.29853807176862, 65.40745803288051, 59.912169456481934, 70.02933025360107, 69.58826555524553, 67.23380592891148, 49.14392076219831, 35.92240905761719, 13.369509203093392, 4.02732789516449, 0.13260577299765178, 0.20118190108665399, 0.033126025327614377, 0.05222012967403446, 0.046381210309586356, 0.05926346565995898, 0.02370253947031285, 0.03340835017817361, 0.023408855943541442, 0.04183642685945545, 0.0231805781035551, 0.05708636569657496, 0.04516935355163046, 0.04306406294927001, 0.05258527650896992, 0.01627027060437415, 0.05128588194825819, 0.015402651624754071, 0.03718405489676765, 0.07608864389892135, 0.03241295287651675, 0.04885210915069495, 0.031143152620643377, 0.009439252466628594, 0.005372102962740297, 0.04962350847199559, 0.04963231246386256, 0.017381300451233983, 0.04485322408644216, 0.024863880992467915, 0.03244660482076662, 0.06775752987180438, 0.03990964864247611, 0.06267206597008876, 0.08177758327552251, 0.03555686006854687, 0.07221249224884169, 0.02674853236281446, 0.039035390197698555, 0.028891912528446743, 0.026448414627728716, 0.03872599858524544, 0.03987046663782426, 0.04478980481092419, 0.03922718829874482, 0.05732012101049934, 0.03277180290647915, 0.12575357354113034, 0.016487744470526065, 0.042501289397478104, 0.03235442583848323, 0.015474025027028151, 0.03602715268997209, 0.028386113865833198, 0.02568127311367009, 0.011413917444380266, 0.038946719241461585, 0.019837812653609684, 0.021686667909047434, 0.06187164570604052, 0.014725726430437394, 0.055584706632154326, 0.0071431086232353535, 0.07688029070517846, 0.039853160602173636, 0.03586726948352797, 0.03477791543783886, 0.04576493766424911, 0.028551956306078603, 0.017324403593582765, 0.08126578466700655, 0.05018071125128439, 0.03473312194858279, 0.03796503173985651, 0.01602635931755815, 0.03060875540333135, 0.021251206186466982, 0.06437440176627465, 0.004992854897864163, 0.06929701726351466, 0.008363714242087943, 0.05601740502087133, 0.05636704733063068, 0.02308411756530404, 0.028635901265910695, 0.0100471587751859, 0.01884535001590848, 0.00984370004984417, 0.05095572377155934, 0.010041838212470924, 0.011242676409892738, 0.018501946835645607, 0.026392907070528184, 0.04547541355714202, 0.024307277020333067, 0.02230393630452454, 0.02756390075332352, 0.04323610211057322, 0.004890697634047163, 0.049694839465831, 0.07114202861807176, 0.111152069909232, 0.5986553249614579, 5.099251244749341, 19.644664457866124, 49.07915660313198, 69.34222289494106, 69.46009908403668, 75.07133225032261, 77.93242672511509, 60.85258729117257, 56.52121925354004, 47.78665964944022, 43.75205612182617, 36.05388287135533, 36.69469090870449, 35.00959989002773, 34.07072802952358, 29.897834505353654, 32.80297013691494, 23.373788697378977, 35.23104592732021, 39.600142683301655, 37.29326432091849, 47.22481441497803, 44.65272331237793, 35.723093032836914, 30.541446140834264, 23.15520010675703, 16.657864911215647, 12.951397010258265, 9.79795013155256, 7.138466324125018, 3.744715128626142, 1.4858718344143458, 1.6345054187944956, 1.1406146522079195, 1.0122480945927756, 0.997562968305179, 0.5464395039847919, 0.7964328122990472, 1.205987538610186, 1.228483525770051, 1.3697191242660796, 2.416376978158951, 3.863262687410627, 5.367014842373984, 9.53777049268995, 14.272913983889989, 27.013065780912125, 39.8029328073774, 40.73622179031372, 48.95686483383179, 51.93638440540859, 58.185625485011506, 53.052296366010395, 39.04744822638375, 51.08743265696934, 47.561551911490305, 33.94114065170288, 34.13739946910313, 28.76603548867362, 20.440670933042252, 31.06801537105015, 38.99511439459664, 61.76564311981201, 75.67497784750802, 73.44120148250035, 69.64563683101109, 78.7748054776873, 79.61266790117536, 77.61409500667027, 56.82020371300833, 41.06461797441755, 18.237444060189382, 4.342803035463605, 0.11196849002901997, 0.18696809879371099, 0.04592918724353824, 0.0651832969327058, 0.06466493689055954, 0.03889175790495106, 0.1242029717458146, 0.04051031498238444, 0.05111481309203165, 0.03027943182470543, 0.05837800460202353, 0.04936431148754699, 0.07534068796251502, 0.009597396078918661, 0.02013230194071574, 0.02918279031291604, 0.04114457219839096, 0.03727153841672199, 0.02884717332199216, 0.034836310161543746, 0.08149415241288287, 0.04160277332578387, 0.027635601548744098, 0.010173237367000963, 0.01992704000856195, 0.02998202314068164, 0.02478774427436292, 0.05189455500138657, 0.04298926803416439, 0.029047052775110518, 0.011920730516846691, 0.03433021803253463, 0.0438678182129349, 0.04595791980890291, 0.02381214323187513, 0.05343711954940643, 0.06473990143941981, 0.0024707306916492856, 0.02674061046647174, 0.04048224398866296, 0.045962309930473566, 0.002915917305342321, 0.01799112871023161, 0.04240252523283873, 0.022735391277819872, 0.06491602877421038, 0.02688724866935185, 0.05678833615300911, 0.042741385621151755, 0.06453535027269806, 0.03506253034408603, 0.032933104251112254, 0.029611135899488415, 0.05334785148235304, 0.11002498931650605, 0.1005556056542056, 0.1159603726118803, 0.15770433550434454, 0.10369501076638699, 0.17780867671327932, 0.11300405660378081, 0.13535195349582604, 0.1225093211978674, 0.252097988235099, 0.1447389019387109, 0.16822816937097482, 0.06163839250802994, 0.1595124141978366, 0.10432106788669314, 0.12770324892231397, 0.1246161860014711, 0.10396154610706226, 0.1480727344751358, 0.16623537987470627, 0.13556919326739653, 0.13846773201865809, 0.11962290108203888, 0.10286667557167155, 0.13293912368161337, 0.10255499729620558, 0.10013272227453333, 0.10784650514168398, 0.19957472304148333, 0.18194847314485482, 0.11755817330309323, 0.1520964607064213, 0.09089158422180585, 0.16026459740740912, 0.14656257336693151, 0.1653368230909109, 0.14069434468235287, 0.16418081655033998, 0.11772206665149756, 0.09853819212211029, 0.14121156478566782, 0.11080104338803462, 0.17948353184120996, 0.1753380899982793, 0.11416367973600115, 0.23387907871178218, 0.159032174253038, 0.1622930099921567, 1.518033742904663, 8.470483762877327, 29.1778621673584, 62.611468178885325, 84.20913750784737, 82.59732913970947, 84.97232764107841, 87.92226873125348, 71.75429698399135, 65.41233566829136, 52.968181473868235, 43.77392905099051, 38.78936433792114, 38.64107240949358, 39.571516105106895, 42.60488074166434, 47.9247898374285, 54.77938229697091, 31.883202348436626, 56.549074581691194, 56.500068937029155, 46.26962123598371, 65.18500450679234, 61.11540290287563, 45.48047958101545, 39.06144189834595, 34.80458981650216, 21.316508735929215, 15.062423024858747, 12.007814271109444, 8.88975283077785, 4.207277987684522, 1.5515122264623642, 2.184824134622301, 1.1915228004966463, 1.4905669710465839, 1.1292582558734077, 0.5559600559728486, 0.9469642319849559, 1.4496212367500578, 1.360489853790828, 1.773049241730145, 3.6655052304267883, 5.466420114040375, 7.838848216193063, 17.30562114715576, 23.9408346584865, 38.398747035435264, 58.6420179094587, 57.31422063282558, 74.68554047175816, 79.01392773219517, 98.07414967673165, 81.79688971383231, 63.848198890686035, 85.24960245404924, 67.13705226353237, 49.51159858703613, 38.51689420427595, 27.40111572401864, 24.730622495923722, 34.013999462127686, 43.276403290884836, 72.35066086905343, 81.23519733973912, 84.09945324489048, 78.37649999346051, 89.3658264705113, 87.20892497471401, 89.25441210610526, 74.51920754568917, 56.43077107838222, 28.9452086857387, 7.787111060959952, 0.2669037309076105, 0.4009262578827994, 0.16270234302750655, 0.13706210601542676, 0.1761551411556346, 0.10593025439551898, 0.27280752839786665, 0.14818853326141834, 0.18048308177718095, 0.11152947108660426, 0.1550039289785283, 0.18290328048169613, 0.12635003296392305, 0.10890110462371792, 0.1082941550495369, 0.11281163085784231, 0.16132935455867223, 0.13533083748604569, 0.12675452125923975, 0.11371512059122324, 0.13747785799205303, 0.07220217173120805, 0.08081697446427175, 0.11387585875179086, 0.09036674417023148, 0.18125553961311067, 0.1346972350563322, 0.14340429141053132, 0.13830663423453057, 0.1434055127735649, 0.13970722550792353, 0.1290968648557152, 0.1448966884719474, 0.1911988460591861, 0.1775763463228941, 0.1476433982274362, 0.15763479923563345, 0.10601927818996565, 0.15723928117326327, 0.11533917380230767, 0.1763650934611048, 0.20190763500119957, 0.1331417749502829, 0.15102128125727177, 0.16432557521121843, 0.2055156228265592, 0.16186675429344177, 0.24936911037990026, 0.08560350297817163, 0.1528283150068351, 0.13254881676818642, 0.12261841605816569, 0.12558790243097714, 0.1310852031622614], [0.016056811969195093, 0.06555462522166115, 0.05844553240707942, 0.0197926476664309, 0.03580632007547787, 0.04281639088211315, 0.04284544575161167, 0.009764526887530727, 0.022826320059331398, 0.0535963751109583, 0.044369411654770374, 0.06634921008454901, 0.11325252934225968, 0.005097416720153498, 0.011561713397635945, 0.01640683425856488, 0.03518092791949, 0.021283316159886972, 0.08053250544305358, 0.03651458849864347, 0.04144452878140977, 0.052266724673765044, 0.0263661168116544, 0.014511657113741552, 0.04102073616481253, 0.03730105808270829, 0.03382190030866435, 0.058467170888824124, 0.02271588678870882, 0.03651270895664181, 0.017371354824198142, 0.06536194163241557, 0.01431333998750363, 0.023804982991090844, 0.02259391333375658, 0.017603554596592273, 0.024815102806314826, 0.042826392488288026, 0.04321270961580532, 0.053535100006099255, 0.007829854763778192, 0.015040624354566847, 0.06368663867137261, 0.027861109269516807, 0.05716608677591596, 0.019379808301372186, 0.8963600131017821, 4.107162262712206, 18.24760753767831, 47.86127635410854, 61.89708914075579, 68.32868916647774, 69.24732439858573, 78.13252094813755, 57.38837875638689, 36.35505253928048, 30.09184558050973, 24.486824103764125, 21.338975736073085, 31.09337977000645, 28.58675112043108, 24.021736008780344, 52.00231238773891, 44.42651775905064, 58.922843251909526, 52.89551373890468, 63.57568359375, 54.47180986404419, 32.69252504621233, 26.453548192977905, 15.569507769175939, 11.764128787176949, 8.562450119427272, 4.810282179287501, 1.1367546021938324, 1.1494178026914597, 0.4220144748687744, 0.23630872262375696, 0.07101004677159445, 0.03648443100973964, 0.10526947663830859, 0.04130439094400831, 0.03597385376425726, 0.045353267075760026, 0.020717948907986283, 0.03919970763048955, 0.03927090970267143, 0.08376550767570734, 0.150510398671031, 0.10910952344004597, 0.030059026687272956, 0.025356288766488433, 0.010143044255008655, 0.20549602673522063, 0.8818127108471734, 2.0757780202797482, 2.2681221791676114, 6.361293375492096, 12.511682868003845, 20.382464136396134, 31.893457889556885, 46.911655630384175, 47.52676575524466, 42.94195869990757, 58.638919012887136, 75.21880776541573, 58.81638295309884, 32.91229656764439, 30.96020712171282, 21.504891770226614, 19.808303219931467, 21.21736662728446, 27.979924985340663, 38.069239139556885, 47.480112075805664, 55.826024191720144, 64.51617785862514, 64.91299642835344, 66.17395550864083, 72.566652570452, 66.49667154039655, 49.109655720846995, 28.885968344552175, 2.562421815735953, 0.21319247303264482, 0.03942855713622911, 0.06953698117285967, 0.0475687924772501, 0.044454530480184724, 0.028435243193858435, 0.08257702644914389, 0.018607450549357703, 0.03818933506097112, 0.10049149766564369, 0.029075975330280404, 0.026776840843792473, 0.01546459847928158, 0.05909234591360603, 0.09678962094975369, 0.05888987106404134, 0.014535901169957859, 0.015441005816683173, 0.06203866710088082, 0.06039207295647689, 0.06015217011528356, 0.03379852816994701, 0.053530167056513686, 0.041341798579586406, 0.03727314654471619, 0.03761474821450455, 0.03419421586607184, 0.05811575081731592, 0.024017759698576162, 0.030631106346845627, 0.028856041774685894, 0.032182488457432816, 0.03617600630968809, 0.03811741713434458, 0.017292671903435673, 0.14234165128852638, 0.0347847720342023, 0.056572429702750275, 0.051892858663839955, 0.007040184614847281, 0.02762768983042666, 0.06258213293871709, 0.052980937063694, 0.0447814147254186, 0.08886754818792854, 0.03790817729064396, 0.07254908633019243, 0.020617766605157937, 0.031632037101579566, 0.06353777487363134, 0.011419388132968118, 0.012495971301437488, 0.019711376134572283, 0.07696313304560524, 0.024171332529346858, 0.04039547971582838, 0.022668218007311225, 0.029150838098887886, 0.024934720048414807, 0.03322119325665491, 0.02418918308934995, 0.06519310176372528, 0.016683662975473062, 0.06890755851886102, 0.02223372658980744, 0.009886725107207894, 0.029706310613879135, 0.023529526611257876, 0.04285734047048858, 0.01911027044323938, 0.07070748122142893, 0.0022999385504850318, 0.028006926445024352, 0.03898082919684904, 0.005418154286287192, 0.015781333536974022, 0.06254139369619743, 0.03255053942224809, 0.021586154820397496, 0.013956480609652187, 0.023254599488739456, 0.03278078671012606, 0.01256632011583341, 0.019527362526527474, 0.029751914952482496, 0.05875833026532616, 0.03083992549883468, 0.032938776803868156, 0.04294245590322784, 0.09727169293910265, 0.046516500014279566, 0.022804031880306344, 0.060542049551648755, 0.03978263367233532, 0.09866391109036547, 0.042079325432756116, 0.04429101711139083, 0.0813040676127587, 0.6879180723002979, 4.2513013396944315, 21.131556374686106, 52.97795064108712, 69.89654323032924, 76.10698904309953, 77.25668661934989, 84.28829833439418, 63.541686058044434, 50.733692918504985, 44.15126139777047, 38.09982510975429, 34.67345993859427, 36.77398027692522, 28.792989288057598, 25.691334281648906, 42.732279436928884, 39.770383971078054, 50.487876074654714, 50.511510372161865, 44.67674323490688, 48.84415463038853, 37.786232062748496, 30.335383415222168, 19.617675917489187, 15.149452686309814, 10.904018231800624, 6.030221700668335, 2.088155367544719, 1.3460645249911716, 0.5976245488439287, 0.3108113519847393, 0.0748509146007044, 0.053338877856731415, 0.04119464469009212, 0.046936017860259326, 0.036877116188406944, 0.022519245643966963, 0.04039362731522747, 0.13450658028679235, 0.07305848971009254, 0.1530309934169054, 0.05752409542245524, 0.07971048062401158, 0.029514488764107227, 0.10157542343118361, 0.08418227066951138, 0.3057513806436743, 1.0668027443545205, 1.5867999557937895, 1.831732098545347, 5.691174362386976, 11.76859734739576, 20.42468660218375, 31.571693761008127, 44.034361430576865, 46.639734404427664, 47.63140215192522, 58.16032361984253, 58.77938379560198, 51.817921093532014, 28.440957069396973, 37.823241642543245, 31.294418948037283, 27.854437044688634, 33.483073711395264, 37.76316751752581, 50.12610421861921, 58.19014876229422, 63.39607266017369, 71.48312963758195, 75.44208117893764, 75.57157475607735, 84.44728006635393, 78.24611704690116, 59.82034206390381, 35.79474980490548, 4.2972849522318155, 0.1395833792963198, 0.05061366409063339, 0.06524506397545338, 0.036657471010195355, 0.05973276083490678, 0.02096385169508202, 0.03541185374238661, 0.006486338887563241, 0.075904374143907, 0.05734733705009733, 0.0415318698090102, 0.055650032591074705, 0.045058582709836106, 0.04066026443615556, 0.072564061598054, 0.033369595650583506, 0.011098005110397935, 0.030756251953010048, 0.015746902973790253, 0.022859035625255535, 0.039114246144890785, 0.02684503361316664, 0.02366967123400952, 0.024614456608625393, 0.08244578420583691, 0.09410378257078783, 0.0126829721599019, 0.05052928826106446, 0.024052017235330174, 0.02902152289503387, 0.02662707629081394, 0.03635337197088769, 0.023272010697317973, 0.04960933048278093, 0.0484917731290417, 0.03699763757841928, 0.06618142873048782, 0.013071329133319003, 0.022153961405690228, 0.046182138313140185, 0.022256739104964902, 0.03941047417798212, 0.032614050299993584, 0.011684043083472975, 0.02819334715604782, 0.013025453380708183, 0.022181387791143994, 0.04290737225008862, 0.09454837228570666, 0.046127363573759794, 0.0717463590470808, 0.018315753433853388, 0.07278469404471771, 0.1595476030239037, 0.08764083829841443, 0.08135068975389004, 0.09126924324248518, 0.18738048523664474, 0.1188005573515381, 0.09641289830740009, 0.09140633445765291, 0.15989916558776582, 0.16157081803040846, 0.16828587198896067, 0.23743870056101254, 0.16242684423923492, 0.1720992387937648, 0.12385543967996325, 0.1268446035683155, 0.1344238125852176, 0.12463576852210931, 0.0951576085229005, 0.1252016667276621, 0.13723083053316387, 0.08266894758812018, 0.06921497559440987, 0.2055967077612877, 0.11788232305220195, 0.10116267736468997, 0.08827245262052331, 0.06448249239474535, 0.1246182487479278, 0.13272106966802052, 0.14583274110087327, 0.08378951424466712, 0.11545977661652224, 0.1062216241178768, 0.20342027954757214, 0.07657039019146136, 0.24274457299283572, 0.14562616789979593, 0.10967306034373385, 0.16728834408734525, 0.07482126940573965, 0.1277816875704697, 0.1289546032037054, 0.1126013324995126, 0.20160598547330924, 1.5924250653811862, 8.627424461500985, 34.19940519332886, 68.59687573569161, 82.40601049150739, 86.80394227164132, 86.18732438768659, 91.98178849901471, 74.8795828138079, 52.093597820826936, 45.277293409620015, 39.162291526794434, 34.08295338494437, 43.15174218586513, 41.146085602896555, 37.139080320085796, 66.75266402108329, 64.35409723009381, 81.32351589202881, 70.56393854958671, 86.30597182682583, 74.01658875601632, 45.08670779636928, 38.376530170440674, 23.02329203060695, 18.195214646203176, 13.735601101602827, 7.739562800952366, 2.5671357342175076, 2.6699380236012593, 0.9901435949972698, 0.6804514729550907, 0.2498713620007038, 0.20992593759936945, 0.32344950096947805, 0.10917409961777073, 0.1290177476725408, 0.06843667557196957, 0.17851736582815647, 0.24030694950904163, 0.14433955693883554, 0.10079003950314862, 0.2998844954584326, 0.3295751251280308, 0.15854136273264885, 0.23173284530639648, 0.16085125878453255, 0.5338447540998459, 1.743851934160505, 2.8589843937328885, 3.3526966784681593, 9.788376382419042, 17.256942067827495, 28.376717499324254, 40.61012935638428, 62.66923550197056, 65.92929553985596, 61.93815994262695, 82.70030839102608, 95.66704354967389, 77.99780232565743, 49.25110019956316, 49.16236128125872, 35.018632548195974, 32.876138142177034, 34.75434391839163, 43.49695648465838, 54.74373109000069, 66.15557752336774, 73.97672694069999, 81.61331830705915, 82.95832974570138, 84.12835080283028, 92.50768375396729, 91.74525792258126, 76.88754272460938, 50.23403753553118, 7.749461378370013, 0.22068499241556438, 0.13470258191227913, 0.15942714948739323, 0.07341250857072217, 0.1413262914866209, 0.1013062350185854, 0.0962372866592237, 0.10018263531050511, 0.1563883846891778, 0.16351920419505664, 0.11775878896670681, 0.16655704618564673, 0.09226165499005999, 0.15868498145469598, 0.2068480077598776, 0.14460482341902597, 0.06328193324484996, 0.06085011123546532, 0.07049361376890115, 0.13404107812259877, 0.17086758916931494, 0.08877150155603886, 0.1506240125745535, 0.17018772422202996, 0.09632767430905785, 0.17813091299363545, 0.11449010936277253, 0.23206486606172153, 0.08127040549048356, 0.10225557336317641, 0.12779622179056915, 0.10866607366395847, 0.09536054477627788, 0.09571665352476494, 0.1416341835366828, 0.2504065361406122, 0.13863052614033222, 0.1559148215289627, 0.15962505101093225, 0.1622347781168563, 0.13790656998753548, 0.22116645372339658, 0.09235019702464342, 0.1297633626631328, 0.16171685233712196, 0.09563704101102692, 0.10241827248994793, 0.1345218744661127, 0.15257052598255022, 0.13487741324518407, 0.15951911812382086, 0.078568350124572], [0.04562656401789614, 0.11414941692990915, 0.030456234301839556, 0.013248092594689556, 0.02518310797001634, 0.052792412894112725, 0.03867394137861473, 0.019466901663690805, 0.031025559109236513, 0.05247405444138816, 0.048849751241505146, 0.06456532116447176, 0.09972026797809772, 0.016174015322966234, 0.05021565919741988, 0.020884371495672634, 0.029686877370945046, 0.03187216046665396, 0.009187838278843887, 0.004473003775014409, 0.02686168146984918, 0.05070128671026655, 0.050434914217995744, 0.04115309799090028, 0.026395305691819106, 0.04533663957512804, 0.046234354975500276, 0.005046069854870439, 0.03293849860451051, 0.06465020589530468, 0.012621115211264362, 0.038428874885929484, 0.08208059665880033, 0.009199917050344604, 0.01630525417359812, 0.04164447948070509, 0.021727039046319466, 0.023477676357807856, 0.07061247274811779, 0.07751572517944233, 0.03485749402482595, 0.03624575970960515, 0.04852873971685767, 0.20528185394193443, 1.7874927009854997, 4.9316198740686685, 17.80834242275783, 37.37642730985369, 64.39801679338727, 67.91808537074498, 69.66518211364746, 63.86000388009207, 59.31763294764927, 50.64207744598389, 34.69210542951311, 24.18840765953064, 18.62386291367667, 21.38190518106733, 27.992598499570573, 49.1342453956604, 57.50999655042376, 71.62086377825055, 60.974000113351, 35.215169293539866, 22.582109212875366, 20.978188787187847, 15.945591177259173, 7.090206742286682, 6.099691527230399, 3.2539154418877194, 1.873025459902627, 0.6295350736805371, 0.16246313229203224, 0.03579541601772819, 0.13473445948745522, 0.08060462014483553, 0.008885712928271719, 0.0447971295964505, 0.050729897139327865, 0.1085977858996817, 0.006211335005770836, 0.06607595046183892, 0.0367508272507361, 0.01816167000548116, 0.07588302064687014, 0.07223779481968709, 0.07724608214838163, 0.14536749677998678, 0.038131554411458116, 0.04521465254947543, 0.07504812401852437, 0.13196184326495441, 0.055715246591717005, 0.06487650410937411, 0.05306319247132965, 0.06841304219727005, 0.18326369114220142, 0.15124320292047091, 0.32495780289173126, 0.8382109190736498, 3.037891387939453, 8.233439019748143, 19.241206884384155, 32.18654332842146, 46.77602679388863, 59.765979358128135, 71.18276596069336, 72.31831700461251, 51.296955585479736, 43.37128094264439, 37.43960380554199, 27.674932071140834, 28.53199757848467, 21.84116894858224, 27.67913399423872, 43.851693289620535, 51.67732082094465, 50.13221515927996, 61.17836053030831, 65.35447801862443, 67.63469614301408, 66.626220703125, 74.76191507066999, 54.212131364004954, 23.452998161315918, 2.3926673361233304, 0.35731162822672297, 0.010166145827887314, 0.05030056767697845, 0.06616564600595407, 0.045574761261897426, 0.06800017399447304, 0.012079475480797035, 0.025104949217555777, 0.021071156919268624, 0.016819800848939588, 0.040599756075867584, 0.026595750025340488, 0.053401625382580926, 0.04495277535170317, 0.003762659034691751, 0.018468819059697644, 0.011350607582634049, 0.04129815859986203, 0.03796240920200944, 0.01806643252660121, 0.02964522549882531, 0.07482359678085361, 0.019112862447010617, 0.02126195587749992, 0.02198688403171088, 0.014785072799505932, 0.028764314018189907, 0.016030059029747332, 0.04039584951741355, 0.030299882870167494, 0.06145244677151952, 0.07916925395173685, 0.05216520226427487, 0.04484143114781805, 0.06501823650406939, 0.08771040849387646, 0.06973907604281392, 0.032327840836452584, 0.01282241619524679, 0.09460891796542065, 0.0339424658034529, 0.007242432579265109, 0.017469469291557158, 0.022394897316449454, 0.02769369602070323, 0.04950471056093063, 0.02917729757194008, 0.010181368761030691, 0.02092365867325238, 0.019684862378718596, 0.053586322614657025, 0.04288841737434268, 0.014461090987814324, 0.04278552771678992, 0.011929560801945627, 0.014493837087814296, 0.10438337775745563, 0.04499115329235792, 0.06271739889468465, 0.04751783110467451, 0.020195122409079756, 0.023096137813159397, 0.03322132217830845, 0.0164787403108286, 0.06540633139333554, 0.008053862073990916, 0.027192033029028347, 0.05492736565481339, 0.01262110164056399, 0.016820655803063085, 0.01234270296325641, 0.06965571801577296, 0.03773648078952517, 0.06118285123791013, 0.0024224860036546098, 0.060910432998623164, 0.01974325710242348, 0.011472482650008584, 0.07820958151881184, 0.0209772883847888, 0.01922036105367754, 0.12005822200860296, 0.049191101853336604, 0.02583457961944597, 0.05853462405502796, 0.04051424709281751, 0.0316970814684672, 0.034705108630337884, 0.06306504631148917, 0.0445289420230048, 0.0430775216913649, 0.08546706994197198, 0.05018632612856371, 0.2246669480311019, 1.4144121089151926, 5.827215313911438, 20.328292506081716, 43.849980558667866, 73.19330365317208, 77.13253620692662, 76.7611619404384, 72.46384702410016, 68.99056066785539, 63.24837480272566, 45.425727776118684, 29.402282033647808, 23.588250058037893, 25.089302403586252, 34.05851657049996, 43.76255832399641, 48.61574649810791, 49.876782008579795, 48.58116183962141, 41.7773711340768, 29.2640198298863, 23.949479954583303, 19.95566930089678, 10.519353798457555, 8.797062993049622, 5.054852255753108, 2.486948311328888, 1.013822730098452, 0.24016025023800985, 0.05068197560363582, 0.05339657368936709, 0.04754080630040594, 0.051850633429629464, 0.038475290073880127, 0.03005500975996256, 0.04388364843491997, 0.03845163295045495, 0.07606062040265117, 0.027549319035772766, 0.259341973811388, 0.20392744376191071, 0.1895915594484125, 0.1854716848049845, 0.23436100142342703, 0.03495486719267709, 0.046553992466734986, 0.07878566453499453, 0.023246375644313436, 0.021288878450702344, 0.036334878498954434, 0.0211343251368297, 0.1396861094981432, 0.20051392407289573, 0.07163738632308585, 0.27536362409591675, 0.9509122201374599, 3.3796064002173285, 8.419088806424822, 18.618740354265483, 26.612311056682042, 40.32681655883789, 50.530784675053184, 55.311805384499685, 57.61960785729544, 44.90390069144112, 37.76037086759295, 34.9502831186567, 30.559007712772914, 37.67296947751726, 30.579980850219727, 40.96623495646885, 56.20536456789289, 62.91787678854806, 59.184317861284526, 69.95255960736955, 72.31935228620256, 75.50907570975167, 76.11721679142543, 87.29104573386056, 64.23633221217564, 25.954250642231532, 3.4632251475538527, 0.2736151750598635, 0.025398627655314546, 0.03598937186013375, 0.09038624526666743, 0.020026196027174592, 0.08090536043580089, 0.048566143959760666, 0.07282202704144375, 0.060126942183290205, 0.047889973635652235, 0.04987057664298585, 0.05223830762718405, 0.03322411774258528, 0.019188948274989213, 0.03219029161014727, 0.02546643026705299, 0.015834182933239, 0.05357100807928613, 0.0662602541436042, 0.048025324408497126, 0.019617080123030713, 0.04609856315489326, 0.01402158519652273, 0.021343196875282695, 0.018659438206148998, 0.01761989711251642, 0.02891855520595397, 0.029553148296794722, 0.015196036015238081, 0.061064697935112884, 0.0818833058167781, 0.05076184935335602, 0.014150524661610169, 0.011268548950153803, 0.03854879237977522, 0.07370710133441857, 0.027045269297169786, 0.0311522280265178, 0.049902220123580525, 0.04929298049371157, 0.04559256602078676, 0.04844374302774668, 0.028522070231182233, 0.020234813314995596, 0.0060446265852078795, 0.11791878752410412, 0.04427169582673481, 0.05804565814988954, 0.034328134930027385, 0.04511495200651033, 0.13233123772910663, 0.15356322271483286, 0.11042118591389485, 0.1564665926354272, 0.12791582037295612, 0.11533663608133793, 0.1174541674554348, 0.10825408755668572, 0.19405593989150866, 0.13150202722421714, 0.10424154358250753, 0.1287300216832331, 0.252087945916823, 0.08386475699288504, 0.23609590690050805, 0.08876024466007948, 0.07380763308278152, 0.11570916537727628, 0.11250864461596523, 0.10037227906286716, 0.09932977786021573, 0.17204228256429943, 0.15350976772606373, 0.1143049778682845, 0.11541559041610785, 0.1743563719625984, 0.25240604313356535, 0.07764035170631749, 0.19464342908135482, 0.1346985785556691, 0.05060924682766199, 0.15853311174682208, 0.12733796638037476, 0.09235566601689373, 0.10624985796000276, 0.17083303816616535, 0.12314231294606413, 0.1037634274523173, 0.18728987367025443, 0.12246171518095902, 0.23853325897029468, 0.09666297917387315, 0.16924386844038963, 0.4876284311924662, 3.6318264433315823, 10.236954689025879, 31.892863818577357, 57.83666958127703, 85.10864434923444, 86.5005908693586, 85.92862210954938, 80.95581722259521, 76.42108930860246, 65.92411913190568, 51.64362553187779, 35.706038679395405, 30.002137388501847, 32.301661082676475, 39.17050082342965, 63.48138959067208, 75.06095164162772, 93.10720212118966, 81.63154343196324, 51.76965543201992, 34.40351547513689, 30.64601305552891, 24.109813111168997, 12.042617797851562, 10.281126993043081, 5.500133642128535, 3.5475795354161943, 1.4289669564792087, 0.5060862664665494, 0.14535502530634403, 0.3811095069561686, 0.2007581288261073, 0.12617210751133306, 0.24018782590116772, 0.17843936144241265, 0.20256029069423676, 0.1197960903601987, 0.2747296281158924, 0.18570482943739208, 0.3405225548361029, 0.3609476802604539, 0.2619342489966324, 0.34976270901305334, 0.6921670043042728, 0.14772877150348254, 0.1416648668902261, 0.2752301426870482, 0.2957388093428952, 0.2631547977881772, 0.1972618821476187, 0.18278684387249605, 0.24793666867273195, 0.4766528829932213, 0.3892615352358137, 0.6449893872652734, 1.6772930771112442, 5.253550325121198, 11.718407903398786, 24.897042274475098, 40.90476424353463, 60.186345372881206, 77.6099955695016, 95.64132131849016, 98.31509235927037, 69.52798993246896, 59.57680770329067, 53.022874219076975, 43.262937682015554, 45.69675963265555, 34.76891776493618, 40.061169556209016, 62.478868756975444, 68.97904055459159, 68.69223976135254, 78.53141702924455, 80.36752714429582, 84.85260323115757, 87.8083530153547, 98.526123046875, 80.9315402167184, 37.577640192849294, 6.0057045476777215, 0.46261220212493626, 0.13155392158244336, 0.11479812354913779, 0.15724450589290687, 0.11498423213405268, 0.12735263630747795, 0.11383602196084601, 0.2276938520371914, 0.154891414301736, 0.1374030155794961, 0.13644109719565936, 0.14083265726055416, 0.16333688183554582, 0.11709428605224405, 0.13672198355197906, 0.1319367510399648, 0.09833762395594801, 0.1466507422072547, 0.1269226758075612, 0.1315088125744036, 0.09292596791471754, 0.12417064633752618, 0.12413381545671395, 0.06453393891985927, 0.13633520502064908, 0.07714700925030879, 0.05402103625237942, 0.16054578231913702, 0.10065043092306171, 0.16013742637421402, 0.1930160985461303, 0.19053945929876395, 0.1796421054750681, 0.10197457844125372, 0.09964343067258596, 0.15995528043380805, 0.11233330438179628, 0.1216143470789705, 0.19327471538313798, 0.1373614485242537, 0.08798997849225998, 0.13188788294792175, 0.16398489634905541, 0.11584802078349249, 0.1529640220105648, 0.1589304618537426, 0.17297752095120295, 0.17311511428228446, 0.17259621141212328, 0.18780765017228468], [0.012992921867407858, 0.011397706394615983, 0.04728835056136761, 0.07078105477350098, 0.029141481100980724, 0.06309028102883271, 0.03833811064915998, 0.028043056738429835, 0.047764108782368045, 0.03204521064513496, 0.022582298510574868, 0.03972370969131589, 0.06877162759857518, 0.0809136385630284, 0.009911039561432387, 0.049158684842820675, 0.06593988383454935, 0.0506555805914104, 0.027718013019434044, 0.055472890846431255, 0.038683145706142695, 0.05497136525809765, 0.015550322897200073, 0.03862484597734042, 0.028265843533777764, 0.008421268430538476, 0.029653306850897412, 0.04285833113161581, 0.08287468619112458, 0.03241792653820344, 0.03524315297337515, 0.01226583936451269, 0.09565173807953085, 0.038746341065104516, 0.048620613358382664, 0.010294609470292926, 0.08586842340550252, 0.02213481145112642, 0.025470168995005742, 0.03254967429009931, 0.08275240061006375, 0.05431270792282053, 0.31124317167060717, 4.399984972817557, 30.974975517817906, 47.04922996248518, 64.90609686715263, 65.32796369280133, 62.11665221623012, 60.66250542231968, 60.59217575618199, 43.3432171685355, 23.8281991481781, 18.56694327081953, 14.48652332169669, 17.053879226957047, 29.264516626085552, 51.31341239384243, 69.06624044690813, 60.198428290230886, 41.377846240997314, 36.802092688424246, 16.764366899217876, 6.408036947250366, 4.987191132136753, 2.738688711609159, 0.4784669599362782, 0.5992302883948598, 0.3078710697591305, 0.053358762325452905, 0.05517618783882686, 0.014522216814969267, 0.07870677126837627, 0.15445905178785324, 0.033249600125210624, 0.09858517388680152, 0.045587147918662856, 0.036426355197493515, 0.0593191801703402, 0.1166074371763638, 0.047861987458808083, 0.02294977780963693, 0.04260312732575195, 0.1289782840758562, 0.13490234262176923, 0.2740612711225237, 0.41206875283803257, 0.3169654474726745, 0.0445311031570392, 0.06516070171658482, 0.06486995624644415, 0.04009073267557791, 0.14954245489622864, 0.057666709912674766, 0.045448618209255595, 0.07147260409380708, 0.03333312778600624, 0.052269869683576484, 0.025522373783003007, 0.06639892634536539, 0.04685506863253457, 0.011918377696669527, 0.665028697678021, 2.4529559867722646, 5.123821377754211, 10.84310337475368, 20.422221728733607, 35.229625020708355, 70.85774312700543, 77.67839363643101, 59.22935608455113, 36.482117721012656, 18.74865777151925, 23.073253052575247, 24.554016658238, 22.464997325624736, 27.979838132858276, 34.23686988013131, 37.504555565970286, 49.489715235573904, 61.322042328970774, 64.02450942993164, 62.890202113560264, 65.0858050755092, 68.92034217289516, 50.83501502445766, 19.463552713394165, 2.6550426057406833, 0.18660605964916094, 0.04252627644953983, 0.03377963436235275, 0.11230255317475114, 0.05158691740195666, 0.09937170453901802, 0.0831648006236979, 0.003473585729287671, 0.03983200388029218, 0.043277994862624576, 0.02077776176988014, 0.05592782482770937, 0.02821402551074113, 0.07067052141896316, 0.020065227057784796, 0.038942471612244844, 0.04602324916049838, 0.048183796262102466, 0.0679288599640131, 0.026150050905666182, 0.0364614592066833, 0.009908040436649961, 0.04055432815636907, 0.04662130653326001, 0.016429202165454626, 0.0138278032287157, 0.03925895730831793, 0.01824423245021275, 0.023086731621463383, 0.06042494119278022, 0.03912233088963798, 0.034099190429385216, 0.035775110857295137, 0.017466373475534574, 0.02197393079820488, 0.023239839655746306, 0.05592658310862524, 0.03099949997184532, 0.04403736375804458, 0.03467855416238308, 0.08399291190185718, 0.02756100849780653, 0.01225076146822955, 0.06367091701499053, 0.03575112803706101, 0.061436345135526996, 0.03153660793655685, 0.0051433904362576345, 0.028295821210901653, 0.015786541293242147, 0.02503140619955957, 0.0396627568905907, 0.02170695101709238, 0.09567715600132942, 0.0561023643905563, 0.05057243969557541, 0.034471190468009026, 0.04864676749067647, 0.01525253932257848, 0.08434665256312915, 0.022979126145531024, 0.06283197631793362, 0.06017099946205105, 0.04988597260255899, 0.017213792207517793, 0.03728758916258812, 0.03580467123538256, 0.019283076349113668, 0.040076022036373615, 0.04361086039404784, 0.0375454935378262, 0.02482100436463952, 0.024177052579554062, 0.07345287461898156, 0.017803030321374536, 0.017937259815101112, 0.016187355321432863, 0.01925716140041394, 0.028085599187761545, 0.03578673416216459, 0.025780965174947466, 0.011493183057090002, 0.0075166548735329086, 0.012292505790745574, 0.015833992943433777, 0.04704198128144656, 0.06497274751641921, 0.01711028508309807, 0.07613043487071991, 0.044051324616053274, 0.31322454820786205, 6.6955225723130365, 34.447723388671875, 52.93080016544887, 73.7476726259504, 73.03579493931362, 70.39274188450405, 66.9507919039045, 69.7631447655814, 53.80301448277065, 35.945713315691265, 33.46247577667236, 22.55808581624712, 26.534920283726283, 32.70133536202567, 39.100963251931326, 44.71899175643921, 50.74353504180908, 43.8428829738072, 40.248492990221294, 21.13037518092564, 8.008507592337471, 5.589941280228751, 3.868405657155173, 0.663438537291118, 0.6923232302069664, 0.4468657113611698, 0.05169872300965445, 0.04031425228874598, 0.030951547902077436, 0.027086619221206223, 0.13855505947555813, 0.22201165051332541, 0.2967068888247013, 0.04990574850567749, 0.12567839186106408, 0.1561145686677524, 0.20486375423414366, 0.20354462787508965, 0.23607587654675755, 0.13249312261385576, 0.030935470014810562, 0.3837741139744009, 1.787631664957319, 0.9628964513540268, 0.9040486291050911, 0.33915907942823, 0.2372960996414934, 0.23791812626378878, 0.37033236239637646, 0.44331387909395353, 0.3779912314244679, 0.2312912004334586, 0.21358026936650276, 0.08473356001611267, 0.19185558653303555, 0.0012839720958644258, 0.22893540827291353, 0.06499509845993348, 0.04767916976873364, 0.6765867546200752, 2.111389057976859, 5.816188088485172, 11.546124713761465, 21.030126571655273, 29.62066044126238, 51.64221157346453, 51.69899920054844, 51.70616626739502, 42.23694583347866, 26.16977334022522, 29.299837793622697, 25.539201736450195, 33.519784518650596, 39.33189010620117, 47.9095732825143, 49.731133869716096, 59.28494167327881, 68.6166364124843, 74.43358489445278, 72.20208059038434, 75.49932738712856, 82.3087774004255, 58.75737885066441, 22.904701914106095, 2.7713348226887837, 0.09195724382464375, 0.03769771269123469, 0.014116927848330565, 0.03231334054310407, 0.027698547546086565, 0.05611174174451402, 0.10733913058148963, 0.003953571223454284, 0.08122406154870987, 0.02067233439135764, 0.030208575805383067, 0.028706370520272424, 0.04861097137576767, 0.03635052212380937, 0.024529753385909965, 0.03037986179281558, 0.02599948737770319, 0.04398055002093315, 0.03211318628330316, 0.029933460389396975, 0.051218896971217225, 0.04405002861416765, 0.04246551024594477, 0.06644679020558085, 0.029379769028829675, 0.0504245462029108, 0.01974980496535344, 0.05377132518749152, 0.04279762599617243, 0.06948210126055138, 0.016345830567713295, 0.011817548241067146, 0.07099249307066202, 0.024191038882625953, 0.00462913468280541, 0.0433878293260932, 0.044720723160675595, 0.032424579574061294, 0.008771490887738764, 0.017141528228031735, 0.04516614408099225, 0.03769541924287166, 0.018774592384163822, 0.017151012451254895, 0.03498449203159128, 0.009112442012077995, 0.02347146436971213, 0.07162502341504608, 0.1279403426285301, 0.07197337650826999, 0.15752760427338736, 0.10189438917274986, 0.15894921656165803, 0.20116292924753257, 0.1613805160990783, 0.11529379338026047, 0.14228332441832336, 0.09305909648537636, 0.10722052266022988, 0.15826795383223466, 0.18998430908790656, 0.17782188100474222, 0.15670895177338803, 0.19515789433249406, 0.17104897515050002, 0.17558769589023931, 0.08730433921196631, 0.12707236063267502, 0.11517135852149554, 0.2024488616734743, 0.1297782225800412, 0.1289372734193291, 0.12407993977623326, 0.35569999899183, 0.10848073860896484, 0.136772520840168, 0.13616725403283322, 0.1275313760020903, 0.12586645462683269, 0.09251827693411283, 0.23739768990448543, 0.13762549364141055, 0.09562380957816329, 0.05495855790962066, 0.18746043023254189, 0.11251261404582433, 0.15847759401159628, 0.12792660907975265, 0.18507105058857373, 0.14470268173941545, 0.4486456715634891, 12.263007708958217, 44.64845364434378, 69.62246458871024, 85.51298086983817, 82.76289081573486, 76.95475264957973, 77.0181063243321, 76.96653679439, 60.39497198377337, 38.34113604681832, 32.189593587602886, 27.663472754614695, 29.168770449502126, 45.24952145985195, 69.90236582074846, 89.63661166599819, 79.38118171691895, 56.168372358594624, 50.97388172149658, 24.3745116846902, 10.507621765136719, 7.8226215669087, 5.1402082698685785, 1.0504132466656821, 1.240360819867679, 0.7148206830024719, 0.3342443145811558, 0.19512335690004484, 0.15777463173227652, 0.33839209058455055, 0.48200831562280655, 0.28310367305363926, 0.38120990299752777, 0.15649568821702683, 0.14330559170671872, 0.1940211717571531, 0.270515681377479, 0.29530118139726774, 0.31510609867317335, 0.1987758566226278, 0.2526251013789858, 0.17997593113354274, 2.104823878833226, 1.0584799966641834, 0.578331029840878, 0.4272282293864659, 0.35512726115328924, 0.23686210864356586, 0.18315329349466733, 0.20666780242962496, 0.18297500163316727, 0.39842922187277247, 0.23754593623535974, 0.1425397970846721, 0.2637231115783964, 0.10443616778190647, 0.3214911403400557, 0.2240103839763573, 0.2312342577746936, 1.6643468460866382, 4.280827275344303, 8.38883374418531, 15.870944942746844, 30.749002729143413, 45.8214624268668, 92.74406841823033, 96.76824964795793, 81.3468826838902, 56.361699036189485, 31.36093405314854, 36.38396051951817, 35.95594801221575, 37.53322730745588, 42.21235268456595, 50.60321964536394, 52.941118240356445, 67.6634338923863, 80.55120972224644, 82.4581080845424, 81.49172483171735, 82.7194437299456, 92.99592672075543, 75.46557998657227, 34.4633012499128, 5.226934816156115, 0.45590339068855557, 0.15915224780993803, 0.18790002592972346, 0.18561383789139135, 0.11121051213038818, 0.13177538184182985, 0.2294959324811186, 0.1317875547600644, 0.25576039456895416, 0.1701828794819968, 0.14917315542697906, 0.0922335364988872, 0.12041897193661757, 0.11079442767160279, 0.15018022353095667, 0.14281027471380575, 0.1006563613191247, 0.1197834424674511, 0.19006709036018166, 0.2017698652510132, 0.05446438424821411, 0.15587412299854414, 0.11805095257503645, 0.08751657139509916, 0.13606677656727179, 0.10868959168770484, 0.16482974030077457, 0.1368483674845525, 0.1612805271787303, 0.12883412252579415, 0.10127155509378229, 0.13240134396723338, 0.11654917815966265, 0.11408168556434767, 0.13206299926553453, 0.12553664589566843, 0.10140989481338433, 0.07856435355331216, 0.1043995540323002, 0.08646422464932714, 0.19578777839030537, 0.15756849279361113, 0.14299015434724943, 0.1626357923128775, 0.15209226736000606, 0.06625112784760338, 0.06650211116565125, 0.12354638054966927], [0.01659318881242403, 0.05479972643245544, 0.01775638952053019, 0.02992336718099458, 0.015892090808068002, 0.03340567335752504, 0.01743989873544446, 0.0165892363459404, 0.02383175289391407, 0.030182085798255036, 0.042450331417577605, 0.04661112172263009, 0.053050259593874216, 0.03945740165987185, 0.03421210204916341, 0.0280778401398233, 0.033079365867057016, 0.10747374514383928, 0.07398266797619206, 0.05700093135237694, 0.023552440738837634, 0.06481243683291332, 0.04287167452275753, 0.010667176085657306, 0.02496096069392349, 0.024723643071151206, 0.05430442979559302, 0.07561930122652225, 0.01748609509585159, 0.05114044475236109, 0.0600935107629214, 0.018666573001870086, 0.020301584553505694, 0.04668727031509791, 0.015757554277245487, 0.001071682449297181, 0.03206839279404708, 0.04533300602010318, 0.11309164190398795, 0.0667919609695673, 0.16175464673766068, 0.6203889644571713, 10.215842587607247, 39.28273160117013, 45.619384493146626, 65.44745881216866, 66.62750611986432, 60.76165621621268, 47.18442106246948, 92.40391935620988, 52.662227971213206, 21.370428494044713, 21.73242095538548, 20.34541460445949, 22.254081283296856, 37.43888119288853, 43.6689487184797, 48.4578834261213, 59.63561725616455, 39.76193148749215, 19.16683336666652, 4.445935581411634, 0.7503884030239922, 0.22883218952587672, 0.07333219716591494, 0.022379789734259248, 0.06595935778958456, 0.023911808151751757, 0.07641119230538607, 0.1291054008262498, 0.17136796803346702, 0.5696716202156884, 0.4895081903253283, 0.20697121614856379, 0.12981094153864042, 0.18767244528446878, 0.034691042599401305, 0.18874743474381311, 0.17603182420134544, 0.06251940237624304, 0.12563884684017726, 0.17253428830632142, 0.1589806598744222, 0.4041307345032692, 0.33889895624348093, 0.8530641049146652, 0.38634027913212776, 0.3885935310806547, 0.17918859981000423, 0.1006748853251338, 0.16697366668709687, 0.5374452237571988, 0.6071234962769917, 0.06334659763212715, 0.016712578745292764, 0.14206776741359914, 0.21127440381262982, 0.031384887506387064, 0.08961399099124329, 0.07694089745304414, 0.033138048968144825, 0.11144922753529889, 0.06486477902425186, 0.030310461231108223, 0.14064440450498036, 0.1289089513676507, 0.3592031124447073, 2.259653627872467, 6.813399629933493, 23.788474559783936, 45.2996700831822, 64.9838124683925, 61.56603527069092, 57.129092829568044, 36.78115776606968, 24.036143098558696, 16.209261417388916, 18.584999901907786, 23.973836864743912, 30.56978436878749, 39.44368314743042, 44.16009603227888, 65.2249983378819, 63.308045932224815, 65.151597567967, 69.04695919581822, 74.96858228955949, 44.868180002485005, 10.359561732837133, 0.8335287017481667, 0.055572021419980695, 0.007095396161145929, 0.04282883182168007, 0.043916031518684964, 0.04124665439927152, 0.09778389866862978, 0.047090954546417506, 0.04815287881397775, 0.035392498530979664, 0.012960169830226471, 0.02197566954419017, 0.02507589434805725, 0.01851422492680805, 0.03543495785977159, 0.051944956582571776, 0.008413097172576402, 0.03800014592707157, 0.028210112060021077, 0.005837688671558031, 0.07128976604768208, 0.0380141373191561, 0.021031131834856102, 0.048471851340894184, 0.02124169821451817, 0.007849187922797032, 0.061274521318929534, 0.02230591932311654, 0.03944320670728173, 0.014966903221128243, 0.014291523390316536, 0.04192436160519719, 0.036633467833910666, 0.007692068898385125, 0.04377531014116747, 0.06104622142655509, 0.03017488314903208, 0.05414321326783725, 0.07008352077433042, 0.04479980980977416, 0.03292052760454161, 0.013111217662559023, 0.10065579813505922, 0.04677018050902656, 0.09540718048810959, 0.006579008535481989, 0.018292720562645366, 0.03187887457066348, 0.03078206003244434, 0.040587807074189186, 0.018217236934495822, 0.02782731652925057, 0.03654165865321245, 0.05077723174222878, 0.002576475073250809, 0.01689921998019729, 0.019636910308950713, 0.08726090618542262, 0.018188614631071687, 0.009705997304990888, 0.04283544753811189, 0.025495826100398387, 0.059594360047153065, 0.032778954665575705, 0.029262138197996786, 0.02921105808179293, 0.06068131207887616, 0.09847471517111574, 0.035471110205565176, 0.02316685134012784, 0.019918251283732907, 0.028813718152897697, 0.10761628499520676, 0.01385378179007343, 0.028037033043801785, 0.13008126989006996, 0.04085084456684334, 0.03325535070949367, 0.06333425508013793, 0.053792407270520926, 0.038584442609655004, 0.024948835273140242, 0.017321682668157985, 0.024843546994296566, 0.07547129238290445, 0.08495457244238683, 0.0478303473708885, 0.08785893302410841, 0.4848106652498245, 12.154305747577123, 45.23719188145229, 54.841464451381135, 75.95897851671491, 71.83675125667027, 69.55470575605119, 57.86686992645264, 89.66033281598772, 63.847900118146626, 34.40350505283901, 26.73796054295131, 19.554376091275895, 23.27607444354466, 25.378443002700806, 37.847209453582764, 48.35594293049404, 53.485332420894075, 42.232012612479075, 21.692795378821238, 6.46532484463283, 0.8973846552627427, 0.3390970341861248, 0.07086933896477733, 0.07417875102588109, 0.10548891486333949, 0.08438531548849174, 0.06185622939041682, 0.17797807976603508, 0.2129954264632293, 0.37202983988182886, 0.3456019051373005, 0.40139463703547207, 0.7585587246077401, 0.8953543699213437, 0.4289450044078486, 0.3651916453880923, 0.25309008785656517, 0.8369162742580686, 0.6336788056152207, 0.5175627906407628, 0.6612090340682438, 1.45108220406941, 1.2702047441686903, 1.7259279702390944, 1.4993060678243637, 1.9040027005331857, 0.6417742169329098, 0.6232344146285738, 0.5097318994147437, 2.6764890892165045, 3.4669374397822788, 1.1633210395063673, 0.22149954656405108, 0.35659995355776375, 0.48862414062023163, 0.09225437430930988, 0.4223139802260058, 0.05929952301084995, 0.08488812350801059, 0.1499199103564024, 0.081767595240048, 0.11074437214327709, 0.2574545608035156, 0.04869902486513768, 0.5761760026216507, 2.5051686593464444, 8.611580831663948, 23.21281804357256, 41.75222560337612, 49.43257325036185, 40.2698517526899, 51.99562127249581, 41.72778531483242, 34.159425258636475, 26.965974364961895, 28.785966396331787, 34.22663170950753, 39.06086867196219, 51.793970652988975, 50.9014641216823, 73.53448799678257, 70.84605625697544, 73.85418851034981, 78.8843160356794, 86.77876199994768, 51.294440337589805, 12.729772056852068, 0.7725477282490049, 0.03384340986875551, 0.04989000988591995, 0.02601971281027155, 0.050643713013934236, 0.08312984249953713, 0.05816157907247543, 0.009816851267325026, 0.024229286205289618, 0.03159478892173086, 0.031632912411753616, 0.042178174414272816, 0.049920754307614904, 0.04703115525522402, 0.02470981452747115, 0.03379092857773815, 0.03655165008136204, 0.04782001667522958, 0.026296487244378244, 0.05066327178584678, 0.026102066605484912, 0.0160613785098706, 0.025783072026180368, 0.04995447410536664, 0.059992551537496705, 0.032318527943321636, 0.04647927897583161, 0.02379751232053552, 0.02858533344364592, 0.05498797918802925, 0.020294965444398776, 0.05718660567487989, 0.00846510857809335, 0.036149428093007634, 0.01835860970563122, 0.06176077986934355, 0.04822889509211693, 0.021720291015559008, 0.013846793727550124, 0.07122026370572192, 0.023514420725405216, 0.040466091462544033, 0.04376107108380113, 0.08031450571226222, 0.033566903455981185, 0.03196337592921086, 0.07091934021030154, 0.1324809089835201, 0.14534730357783182, 0.12922791710921697, 0.09076656414461987, 0.12780380781207765, 0.1406105998903513, 0.1185784592692341, 0.10677542404404708, 0.10210945763226066, 0.1219982486218214, 0.2074058178280081, 0.0869258591639144, 0.12604885841054575, 0.11553387264055864, 0.17111445377979959, 0.12171491953943457, 0.09119102172553539, 0.21189652542982781, 0.10407300226922546, 0.19644348749092647, 0.28968728120837894, 0.15215053994740757, 0.08149175718426704, 0.1129564166601215, 0.10501759086868592, 0.22002290508576802, 0.10703222919255495, 0.10041175623025213, 0.20423395160053456, 0.1621488213006939, 0.14999467134475708, 0.14819379869316304, 0.12602962872811727, 0.11044308902429682, 0.10095623987061636, 0.0912690803940807, 0.07732218663607325, 0.2537479954106467, 0.32515691220760345, 0.1862432062625885, 0.28386189522487776, 1.4436149533305849, 21.595569235937937, 59.742098399571006, 67.26135553632463, 83.72730078016008, 81.14325182778495, 77.2019487108503, 61.354115213666645, 101.22936834607805, 67.1702993937901, 34.72045407976423, 34.7198600087847, 33.52351917539324, 36.86862516403198, 54.0423139163426, 62.17087595803397, 68.22149235861642, 78.76990699768066, 52.34398657935006, 27.278353214263916, 7.763615727424622, 1.5640099729810442, 0.7029345950910023, 0.252483423267092, 0.18674779204385622, 0.26825491126094547, 0.24955155487571443, 0.219638962830816, 0.3349667915276119, 0.4349767736026219, 1.2190024916614806, 1.12455986227308, 0.3229127254869257, 0.45260286065084593, 0.32173918560147285, 0.36884650641254013, 0.5650959600295339, 0.4096581350479807, 0.6171270566327232, 0.3669002779892513, 0.6096299503530774, 0.7984975672193936, 1.5367166889565331, 2.202273449727467, 3.069759952170508, 1.7651179816041673, 1.2977111424718584, 0.4146604309124606, 0.2714400903454849, 0.5871306519423212, 1.4981997843299593, 1.2240275591611862, 0.3964152756546225, 0.28239452253494945, 0.37274843560797827, 0.9107361074004854, 0.22983248585036822, 0.6590410332594598, 0.28941356018185616, 0.26650228244917734, 0.39235712055649075, 0.22346828877925873, 0.1524813664810998, 0.4513295761176518, 0.3791864572891167, 1.001357118998255, 4.120688668319157, 10.430314370564052, 31.989214488438197, 58.42211437225342, 84.27316515786308, 80.70636299678257, 75.41615744999477, 55.75215441840035, 39.68533802032471, 29.541881765638077, 31.32016897201538, 35.97341578347342, 45.00518110820225, 57.75800902502877, 60.496679714747835, 84.86643709455217, 84.28661687033517, 82.50880908966064, 84.82024547031948, 96.58995887211391, 66.04570565904889, 20.204312324523926, 1.5679355966193336, 0.09229622634926013, 0.1793225969054869, 0.13519029931298324, 0.10602443505610738, 0.13361704801874502, 0.15083407344562666, 0.2185026609471866, 0.09265054376529795, 0.1189624150948865, 0.08171684760600328, 0.11460095484341894, 0.11317757157874958, 0.1762822171939271, 0.1184373918388571, 0.13275076236043656, 0.09011071255164486, 0.1790984496474266, 0.10053099518907921, 0.0751735647874219, 0.2066613156348467, 0.10808321208293949, 0.08445391537887709, 0.18371902885181562, 0.17683447684560502, 0.12510931811162404, 0.12053189373442105, 0.07331979354577405, 0.13187733851373196, 0.15197121671267919, 0.11689658808921065, 0.1704660728573799, 0.05581288438822542, 0.12002550305000373, 0.1427066759871585, 0.11850410540189062, 0.09308610896446876, 0.13617193592446192, 0.15053793362208776, 0.13566165044903755, 0.13868455109851702, 0.13852638458567007, 0.25385425399456707, 0.11663497212742056, 0.12146737639393125, 0.17176052768315586, 0.10385402544800725], [0.019645237629967074, 0.041116311214864254, 0.09936576057225466, 0.034113816251712184, 0.0575566990301013, 0.026764761224122982, 0.024118193059361408, 0.0913331408851913, 0.012898456222111625, 0.0356705587889467, 0.0482617938624961, 0.05312388403607266, 0.024456529279372523, 0.02499733865261078, 0.05017124229509916, 0.029547133083854402, 0.04640349679227386, 0.03057704067655972, 0.04486000265127846, 0.014432173521657075, 0.05142957191648228, 0.01670568822217839, 0.03431933093816042, 0.028378638106265237, 0.008899934174093817, 0.0014957584602858073, 0.04074219414698226, 0.0303028412828488, 0.035724112165293524, 0.03993658987539155, 0.047198631268526824, 0.014017338415474763, 0.030525695931698595, 0.0216168025508523, 0.05698997979717595, 0.013295621428239559, 0.04122953835342612, 0.0973483741815601, 0.0572048243401306, 0.13382652534970216, 8.17391380241939, 28.714603185653687, 59.192481994628906, 67.72364003317696, 68.58149937220982, 64.71295084272111, 56.65407575879778, 46.62789814812796, 40.14913375037057, 74.66857297079903, 33.3314779145377, 27.515595981052943, 47.15158040182931, 58.252314295087544, 58.16509355817522, 69.37011991228376, 60.866365568978445, 37.13905252729143, 15.058424336569649, 5.521532791001456, 0.6796306627137321, 0.0785642789144601, 0.045280226173677614, 0.03549708452607904, 0.01640757216539766, 0.08993530446397406, 0.054214038753083775, 0.11970608947532517, 0.14482833285416874, 0.19141806715301105, 0.2530440831823008, 0.9671010885919843, 0.7542685376746314, 0.4578402010457856, 0.1830698743994747, 0.7315610647201538, 0.28809041689549175, 0.2108330846365009, 0.983035262141909, 1.104173196213586, 1.002880511539323, 0.6682203635573387, 0.96390372301851, 0.2551808985216277, 1.0299300657851356, 1.3525229841470718, 1.56976894395692, 2.437120173658643, 1.529677620955876, 0.43481267669371193, 0.9364742977278573, 6.356216413634164, 8.99023333617619, 1.4159448380981172, 0.13663357043904917, 0.4017802620572703, 0.7086926975420543, 0.1743577290326357, 0.08544102098260607, 0.21942275443247386, 0.13327947684696742, 0.16612213238009385, 0.028762210559632097, 0.13040491752326488, 0.035214556115014214, 0.08556082991084882, 0.10479809157550335, 0.055568357330879996, 0.21912315408033983, 0.30364759638905525, 6.655930868216923, 31.776947021484375, 66.3788092476981, 80.64395427703857, 49.42249141420637, 35.90550409044538, 33.83035857336861, 37.21812997545515, 22.504798344203405, 22.67748887198312, 23.28860204560416, 40.58486223220825, 51.69579608099801, 49.5967035974775, 62.636954171316965, 66.5604282106672, 69.70145171029228, 72.58212620871407, 59.12679372514997, 30.589645794459752, 1.8334296303136008, 0.27574762063367025, 0.015484079219666975, 0.040585242211818695, 0.04597769910469651, 0.040746292498494895, 0.026869947722713863, 0.05606194405949541, 0.03204743963267122, 0.021427509940362403, 0.0722411535680294, 0.007653109962120652, 0.0881534782903535, 0.038010480015405586, 0.07840127444693021, 0.030920135123389106, 0.005315526712885392, 0.03291518414126975, 0.005897020621757422, 0.008011718263982661, 0.06459593666451317, 0.043888591562530825, 0.01756238448433578, 0.04991577386057802, 0.04393541726416775, 0.01154717493669263, 0.03639409425003188, 0.07696476152965001, 0.07343459488557917, 0.042650543352855105, 0.016875342332891057, 0.08389638351010424, 0.027845798126821007, 0.04048519900866917, 0.0829049963504076, 0.02383428722220872, 0.030735247901507785, 0.04336927817868335, 0.0635744904034904, 0.010687879037245043, 0.04572509069527898, 0.07525364549032279, 0.03906420079459037, 0.03258655945371304, 0.0499141793032842, 0.008972111640364995, 0.034128163874681504, 0.03495864324005587, 0.05573744486485209, 0.029855764737086635, 0.10317127672689301, 0.06120953123484339, 0.0384128512814641, 0.05365976385240044, 0.018327442895887152, 0.08272005484572478, 0.03610057696434004, 0.03272989658372743, 0.03367112304217049, 0.006526554385865373, 0.03865519006337438, 0.04273014908124294, 0.05799449660948344, 0.025847015470000248, 0.054400869977793524, 0.05510800524747797, 0.05305254964956215, 0.02733684766904584, 0.04788802284747362, 0.02340389245988003, 0.047083551729364057, 0.07055343341614519, 0.02510725793295673, 0.0492865411963846, 0.04361391380163176, 0.041688017680176666, 0.05743538375411715, 0.06391758485031979, 0.11911646968552045, 0.009070957229206604, 0.029116460122168064, 0.027922272416097776, 0.02929145430347749, 0.09653675808970417, 0.061162257700094154, 0.1688669558082308, 8.696916001183645, 34.516024180821006, 67.06388078417096, 77.52112116132463, 76.81506606510708, 72.04791396004813, 68.03541960035051, 57.62162283488682, 39.73082092830113, 80.4328749520438, 41.503216062273296, 31.910644258771622, 51.409255845206125, 50.3480817931039, 43.23977238791329, 58.074621064322336, 49.43766975402832, 39.00949369158064, 17.73569553239005, 7.2451120529856, 1.1325581073760986, 0.06866059891347374, 0.10261875923190798, 0.03554792036967618, 0.05578593976263489, 0.10099701982523714, 0.08991445986820118, 0.04056492008801017, 0.1585711504199675, 0.18051680496760777, 0.19370890994157108, 0.7660825380257198, 1.3018673594508852, 2.3593932815960477, 3.2685930771487097, 4.369831093720027, 3.679229659693582, 2.420951932668686, 2.666427880525589, 2.064115468944822, 2.4397978356906345, 2.502039364406041, 3.0412567045007433, 1.7612071228878838, 3.110347637108394, 4.644664917673383, 4.257659809929984, 5.132219578538622, 2.536343272243227, 3.406912169286183, 2.5291056377547125, 4.9500773293631415, 10.693551216806684, 3.700208442551749, 1.0209103269236428, 0.29659294922436985, 0.9043441989592144, 0.5944072614823068, 0.2877741924354008, 0.23099250931824955, 0.11821728864950792, 0.09630125894078187, 0.10884688289037772, 0.11447721719741821, 0.08717228951198713, 0.04405700734683445, 0.049129687648798735, 0.1255531750087227, 0.0807382304753576, 0.2983449809253216, 5.906059563159943, 29.432812418256486, 60.53138596670968, 66.16285228729248, 44.115895066942485, 33.32069083622524, 30.460419722965785, 32.207617214747835, 22.421965394701274, 30.367529256003245, 37.159532342638286, 53.168581417628694, 64.3544932774135, 59.809627941676546, 73.74886076790946, 72.99281338282994, 77.86534186771938, 82.81391838618687, 71.52811227525983, 35.6356395312718, 2.9990255534648895, 0.23732283392122813, 0.021490337194076607, 0.012002047849819064, 0.0789799155401332, 0.08883088015552078, 0.03826953111482518, 0.04096709118623819, 0.0184136168432555, 0.03344111663422414, 0.007995022909848817, 0.053484050423971245, 0.023184501732300435, 0.028318536866988455, 0.1161495888871806, 0.028108258864709308, 0.018807197688147426, 0.04038723212267671, 0.10394950889583145, 0.05903793419046061, 0.04791239582534347, 0.031130833817379813, 0.05998807999172381, 0.03979339523773108, 0.015021632159394878, 0.013705340380381261, 0.019523030080433403, 0.037183922582439015, 0.038161392988903184, 0.007956148790461677, 0.011033532409263509, 0.023672286986506412, 0.028581099385129552, 0.02820676009702895, 0.05507467221468687, 0.013162115422476615, 0.06072232952075345, 0.047000278519200425, 0.04313812165388039, 0.014868880355996745, 0.02931867034307548, 0.010470376333354839, 0.008528922252090914, 0.012075893664067345, 0.04828890812184129, 0.04761253762990236, 0.08862044609018735, 0.09018174159739699, 0.15238297890339578, 0.10743614751845598, 0.20713500093136514, 0.13403497130743094, 0.19931928174836294, 0.21816344772066387, 0.2226483877748251, 0.18834960966237954, 0.1512815130076238, 0.1395634575081723, 0.10659168354634728, 0.11037361382373742, 0.1285537247146879, 0.27012356956090244, 0.1689785069652966, 0.15158096408205374, 0.09779632264482123, 0.21095592661627702, 0.1753607259265014, 0.08981710366372551, 0.13694777286478452, 0.19455967071865285, 0.0930314597540668, 0.13955284522048064, 0.08732315498803343, 0.14133569598197937, 0.08317907021514007, 0.18065528039421352, 0.22290742530354432, 0.11211409007332154, 0.16884137503802776, 0.10620454539145742, 0.18019440583884716, 0.1617255782974618, 0.14086294706378663, 0.24141070885317667, 0.1670959386974573, 0.6592296659946442, 14.624158450535365, 48.263986996241975, 81.62900733947754, 86.03986971718925, 85.24366174425397, 81.8420877456665, 73.58655084882463, 62.14145033700125, 51.08186020169939, 85.04123987470354, 44.40618732997349, 39.995321478162495, 60.97057465144566, 76.95055593763078, 74.07643359048026, 92.4289676121303, 79.61787905011857, 51.606775760650635, 22.315016984939575, 8.664753658430916, 1.5836517704384667, 0.21954258371676716, 0.29674380112971577, 0.2585785947740078, 0.1576599593141249, 0.2810502903802054, 0.21449498885444232, 0.27581615267055376, 0.4297364747950009, 0.5255833459751946, 0.6808308554547173, 2.42638629249164, 1.4826488473585673, 2.2442440433161597, 3.758222426686968, 7.531921097210475, 2.4959410173552374, 2.4090509712696075, 2.761074504681996, 3.9165766494614735, 2.8480961322784424, 1.5582970338208335, 1.9514126479625702, 1.0390026760952813, 2.9789845602852956, 4.432861677237919, 4.195745715073176, 4.997867473534175, 2.9747756889888217, 2.959177417414529, 1.21133710869721, 14.329256926264081, 20.05643207686288, 2.2691029608249664, 1.6610429776566369, 1.285476233278002, 2.269216303314481, 2.3467955461570194, 0.7738251111337117, 0.9356490905795778, 0.18041864809181007, 0.3078975597662585, 0.27076551797134535, 0.49104955047369003, 0.3745783088462693, 0.21257279414151395, 0.4168127439916134, 0.28002773810710224, 0.5162979470832008, 0.6617315603154046, 9.705682396888733, 41.922970635550364, 85.0404269354684, 100.20077092306954, 63.81090096064976, 51.26209994724819, 50.352921213422505, 51.00831004551479, 36.98178700038365, 37.34987129483904, 38.194035734449116, 57.22317838668823, 69.18897342681885, 65.41228703090123, 82.31220286233085, 84.89338220868791, 86.31244059971401, 91.47377790723527, 84.26876694815499, 47.08143138885498, 5.70742359331676, 0.4935429223946163, 0.12371783277818135, 0.0713556721540434, 0.15375254755573614, 0.13489052254174436, 0.1507963468985898, 0.18808271469814436, 0.13134333145405563, 0.18497629995856965, 0.10784372314810753, 0.16202706497694763, 0.14074972671057495, 0.12337442620524339, 0.19519283888595446, 0.07444728804486138, 0.13015113185559, 0.12815885804593563, 0.1706674891923155, 0.11620854000960078, 0.1881332112742322, 0.17584971897304058, 0.14261553516345365, 0.12180091706769806, 0.2602164154606206, 0.07008679809847049, 0.14115010308367865, 0.12424308673611709, 0.14026104579014437, 0.14082728326320648, 0.06895337320332016, 0.18041213415563107, 0.19571514800190926, 0.13181333909077303, 0.24154956425939286, 0.10700538634721722, 0.0772949502404247, 0.15650403419775621, 0.1528339468474899, 0.09753334282764367, 0.13434987940958568, 0.15517764751400265, 0.1721240731754473, 0.09567294229886361, 0.15170429460704327, 0.07357577088155917], [0.04777253957997475, 0.008550449623726308, 0.03299625211262277, 0.03988500085792371, 0.07192938029766083, 0.037927864984210045, 0.02010320975179119, 0.018970599098663245, 0.08191950566002301, 0.04365799143644316, 0.027021500215466534, 0.020894688620631183, 0.0640978580340743, 0.04272242396005562, 0.027960482419335415, 0.051125673045005114, 0.060883705504238605, 0.037173144053667784, 0.025791499431111982, 0.01352523174136877, 0.005035441027887697, 0.038578312045761516, 0.03765115161825504, 0.029403002067868198, 0.057846019576702795, 0.020552919013425708, 0.030093849104429995, 0.022671710766319717, 0.029005692673048804, 0.05690376513770648, 0.09937008284032345, 0.039370501680033546, 0.05172207818499633, 0.10416716935911349, 0.09300389766160931, 0.01876020065641829, 0.07538145434643541, 0.2795396271560873, 5.867813638278416, 28.66795298031398, 65.27567155020577, 76.94477503640312, 65.37200832366943, 68.82650675092424, 76.11503505706787, 58.469369070870535, 24.49191539628165, 25.655002151216777, 65.04492882319859, 64.30356298174176, 42.3332965033395, 36.52960518428257, 42.1269280569894, 66.16936274937221, 58.54309640611921, 37.618919440678184, 16.86048480442592, 5.9897341132164, 1.3349562010594775, 0.09798138628580741, 0.021200429714683975, 0.03296868323481508, 0.06873880007437297, 0.10870204959064722, 0.10756107260073934, 0.08651484336171832, 0.06934079634291784, 0.03378959186375141, 0.0727017702800887, 0.3951825946569443, 1.0938484988042285, 0.30913691754852024, 0.7258676130856786, 1.2001164193664278, 4.53342512675694, 4.715497025421687, 4.881574605192457, 0.9084755544151578, 0.7343939212816102, 1.0226639871086394, 2.617933362722397, 2.1625334450176785, 1.6724621249096734, 3.0369611978530884, 1.3953307271003723, 2.2107050887175967, 2.907552953277315, 2.950419864484242, 2.1432061621121, 3.5090691447257996, 1.7500813198941094, 5.8665065084184915, 13.06285045828138, 8.160777364458356, 0.5874142795801163, 0.4896717444062233, 0.8391988117780004, 0.9740662234170097, 0.6737339762704713, 0.42070712787764414, 0.2463763638266495, 0.056791793288929124, 0.22530896429504665, 0.0199153183161148, 0.11510136084897177, 0.08554730670792715, 0.046128076035529375, 0.0480267934368125, 0.05728010780044964, 0.023928964909698282, 0.03795185119711927, 0.15480334045631544, 3.6494996207101003, 22.55555146081107, 60.371070180620464, 75.25969791412354, 63.744490078517366, 62.32224246433803, 51.82265976497105, 35.08307709012713, 31.30927072252546, 23.74934925351824, 25.143428870609828, 36.847308090754915, 46.1492714881897, 49.96656315667288, 63.24565805707659, 62.67776788984026, 63.62254919324602, 62.75120340074812, 49.23918056488037, 6.746835018907275, 0.7395560528550829, 0.015851509324940186, 0.028927545794951062, 0.03683961695060134, 0.011188798184905733, 0.017717404291033745, 0.0901737484548773, 0.030566845687904527, 0.02287189386385892, 0.07762555964291096, 0.03241080870585782, 0.031053328154874698, 0.047983791280005655, 0.05091345782524773, 0.0507729026888098, 0.05610566546342202, 0.04690410975100739, 0.011161736512024487, 0.029356003339801515, 0.0563968553739999, 0.046252051168786626, 0.05417937918433121, 0.06863196473568678, 0.008786582354722279, 0.07011853318129267, 0.052689720011715374, 0.03240386389994195, 0.00963239067433668, 0.06052704035703625, 0.019929733792585985, 0.02948155945965222, 0.012384011327022952, 0.034583552474422116, 0.00819276412948966, 0.04810042466436114, 0.05774538604808705, 0.024600500839629343, 0.04275220146934901, 0.06572848624948945, 0.011821206392986434, 0.04232816458014505, 0.07578778147165265, 0.03204777550750545, 0.045851783361285925, 0.05435746069997549, 0.0180903593676963, 0.024754641943478158, 0.010601278460983719, 0.049538077520472665, 0.03223649984491723, 0.012880644677872104, 0.041749862754451375, 0.03607602756736534, 0.02336274609634919, 0.02320087647863797, 0.06662096335951771, 0.06522842629679612, 0.0524638424893575, 0.01495343939002071, 0.06631590758583375, 0.06323203377957855, 0.036870887236935754, 0.030190404637583663, 0.015666291317237274, 0.016955185548535416, 0.03061951357605202, 0.017748145320053612, 0.03681049083492585, 0.07021856281374182, 0.018272671549181854, 0.035871378013065884, 0.0040696240362844294, 0.04246382408642343, 0.06634457569037165, 0.07321586233696767, 0.02024439592579646, 0.028495447909725562, 0.08499155938625336, 0.051556807410504134, 0.05086385352270944, 0.03253629357953157, 0.2405034261090415, 6.639543107577732, 33.15271118709019, 75.08097634996686, 87.13865784236363, 74.95253195081438, 77.57091890062604, 84.3555360521589, 65.7809237071446, 34.52950368608747, 39.59742246355329, 64.08890533447266, 69.38036850520542, 34.23630012784685, 32.802907603127615, 43.76990951810564, 61.42427117483956, 61.45737934112549, 39.733176367623464, 22.120208603995188, 6.907374015876225, 1.7595649595771516, 0.0500662932837648, 0.024793620387624418, 0.12632104594792637, 0.05586123000830412, 0.030809014836060147, 0.11272659684930529, 0.12361385407192366, 0.05739551303642137, 0.1608373216752495, 0.3031487103019442, 0.2221668857548918, 1.9952551296779086, 0.6203457010643822, 0.6890518771750587, 0.962567606142589, 0.820290917796748, 5.018150568008423, 4.098622926643916, 2.401512392929622, 3.633626243897847, 3.2110706780638014, 5.737377711704799, 6.581621187073844, 5.00194867168154, 4.898876053946359, 5.502556826387133, 6.009712355477469, 4.761434171880994, 11.06016857283456, 7.026343243462699, 3.1107992700168063, 4.41216299363545, 3.0780686948980605, 3.291543194225856, 0.989614446248327, 0.50545099484069, 0.36794003791042734, 2.9937166954789842, 1.8827900673661913, 0.8055793015020234, 0.5568048049296651, 0.4350566236036164, 0.20861192739435605, 0.14309447232101644, 0.10212103343967881, 0.06493844757122652, 0.08523986927632775, 0.03875567092161093, 0.03664246860093304, 0.06665413693657943, 0.07864649700266974, 0.02834239924725677, 0.31231512129306793, 4.040096512862614, 20.085517236164637, 45.25425318309239, 53.47789784840175, 48.21014887945992, 50.37745530264718, 43.84222984313965, 34.67607593536377, 29.39152274812971, 33.0347273009164, 36.519287109375, 47.15552350452968, 55.926595892224995, 59.26797417231968, 73.05620874677385, 70.10054928915841, 72.07786069597516, 74.36386666979108, 60.14036219460623, 11.337706548827034, 0.814946884555476, 0.06703096135918583, 0.031016402279159853, 0.007391337937276278, 0.04670980107039213, 0.056267329824290106, 0.022963129682466388, 0.056821051718933244, 0.03441548952832818, 0.08695374016783067, 0.07409458554216794, 0.08574675529130868, 0.07599145732820034, 0.03005799531404461, 0.02768130597126271, 0.014247505127319267, 0.006811497957512204, 0.04585472820326686, 0.017340274527668953, 0.02632039881843541, 0.028725603595376015, 0.0694035744028432, 0.03667304678154843, 0.058001444808074405, 0.01899305691144296, 0.03584414501009243, 0.017616029462910125, 0.0022288836355853292, 0.007515705772675574, 0.021769299903618436, 0.016050798452592323, 0.05177551960306508, 0.012297669442237487, 0.013379438314586878, 0.016101668222940395, 0.01825720095075667, 0.009082488931848534, 0.03064943357769932, 0.004839054333777832, 0.022024066054395268, 0.0479841203694897, 0.06395348613815648, 0.03581829961123211, 0.0516151614221079, 0.15629527611391886, 0.10377996335072176, 0.12784574127623013, 0.0946431364864111, 0.2116278527038438, 0.08614805447203772, 0.08355099561491183, 0.09944077940391642, 0.1645169085157769, 0.1041258465764778, 0.10834222925560814, 0.13990780045943602, 0.17609457511987003, 0.11661841587296554, 0.09260718537760632, 0.13170690408774785, 0.20298371011657373, 0.11157166239406381, 0.161184785887599, 0.10181286319025926, 0.14621554341699394, 0.1755925134888717, 0.07911022819046463, 0.19681149774364062, 0.16472382098436356, 0.20835193991661072, 0.1839394848793745, 0.1285007582711322, 0.16203311750931398, 0.14749340127621377, 0.16201637126505375, 0.09581953300429241, 0.11350246093102864, 0.23535269392388208, 0.1772710598473038, 0.14260701276361942, 0.2626355013677052, 0.5650307121021407, 11.90484196799142, 44.15640653882708, 85.74480056762695, 96.4115013395037, 80.75546591622489, 86.85904148646763, 93.64520113808769, 74.44879450116838, 38.79548222678048, 40.2558719771249, 74.63615962437221, 72.99244512830461, 55.03223071779524, 50.437334878104075, 53.84718418121338, 78.0418678011213, 74.49297114780971, 50.77934953144619, 26.35726179395403, 9.523432884897504, 2.235457177673067, 0.3901043028703758, 0.08778375812939235, 0.36578587921602385, 0.15460397329713615, 0.2635432726570538, 0.22399555120084966, 0.28632098755666185, 0.1836734041571617, 0.4089495273573058, 0.1955421758549554, 1.038925594517163, 2.464170379298074, 2.2991089735712325, 1.0247052375759398, 3.181773381573813, 16.350681577410015, 25.47796552521842, 14.420234901564461, 3.2922827431133816, 4.394939712115696, 6.1571222969463895, 8.616705996649605, 7.300057973180499, 6.712480953761509, 9.83168797833579, 7.726020761898585, 8.542778032166616, 11.552438020706177, 13.744017107146126, 7.45067754813603, 11.636901191302709, 7.831588217190333, 13.105438573019844, 27.44871609551566, 12.622722029685974, 2.1190064549446106, 1.617048938359533, 4.148905737059457, 2.8773526081017087, 0.9975846814257758, 0.7920815029314586, 1.2268578644309724, 0.36903587196554455, 0.6688156287584985, 0.26072824799588745, 0.22658051177859306, 0.25308976215975626, 0.31963029876351357, 0.25690261327794617, 0.26725621627909796, 0.26859469445688383, 0.11330222524702549, 0.4205000932727541, 5.777102300098964, 32.39606278283255, 79.61620453425816, 95.22341496603829, 82.79625606536865, 78.73914732251848, 71.23819868905204, 52.23922164099557, 43.14762190410069, 35.40998635973249, 39.08393669128418, 51.89547688620431, 63.976559911455425, 66.80450453077043, 82.11629145486015, 80.59110627855573, 80.56873307909284, 84.17104748317173, 73.5656715120588, 16.90140274592808, 1.6514486010585512, 0.12145086085157734, 0.11098967612321887, 0.21734786219894886, 0.10829118306615523, 0.12366886969123568, 0.15018486471048423, 0.16762918579791272, 0.09381456380443913, 0.24204853177070618, 0.14038304638649735, 0.12092396483889647, 0.15853543233658585, 0.13773283788136073, 0.09135110849248511, 0.13036101630755834, 0.13622304318206652, 0.21985384130052157, 0.1057403731559004, 0.11267087555357388, 0.1433015883501087, 0.21888147347739764, 0.16097526784454072, 0.12667259494108812, 0.1926211097410747, 0.11069942598364182, 0.16626311838626862, 0.06865487886326653, 0.20019977592996188, 0.10702300111630134, 0.09336313445653234, 0.07632726430892944, 0.0593321809012975, 0.10785355512052774, 0.12990685924887657, 0.1312776356935501, 0.05685507007209318, 0.09026643633842468, 0.18642897557999405, 0.11010412685573101, 0.11863389558025769, 0.19832644930907659, 0.07347335959119455, 0.16901583996202263], [0.02410678518936038, 0.034516967833042145, 0.030585155955382755, 0.02208029625139066, 0.03342139840658222, 0.04164105627153601, 0.029864901211112738, 0.058727504419428964, 0.018406682215364914, 0.03450085941169943, 0.016311886853405407, 0.03651836793869734, 0.022939258820510337, 0.02892333209248526, 0.013896029076672025, 0.03664954911385264, 0.05438703804143837, 0.05317781399935484, 0.01888737508228847, 0.030936341932309524, 0.09591748631958451, 0.04461170633190444, 0.03640172437631658, 0.02350083475799433, 0.032404094601848295, 0.03571821230330637, 0.0185771556571126, 0.023118756778006042, 0.05603390020717468, 0.061676546532128534, 0.08561649013842855, 0.05069723246353013, 0.04335182625800371, 0.050516630190291574, 0.01628523230153535, 0.06844947274242129, 2.509466988699777, 24.263370037078857, 55.524229185921804, 70.00913184029716, 71.45985317230225, 59.32986177716936, 67.02731241498674, 45.05047641481672, 49.28613996505737, 42.8238080569676, 35.29317324502127, 21.310531548091344, 28.486610208238872, 38.83221387863159, 32.09929827281407, 41.838376317705425, 57.78136192049299, 46.80873196465628, 17.90346152441842, 7.804860234260559, 1.15970841050148, 0.17831970857722418, 0.03390462051278778, 0.006735760302815054, 0.021509270017434443, 0.016590890275048356, 0.06389342221830573, 0.05270751119990434, 0.07897272985428572, 0.0527980481274426, 0.1876553597726992, 0.23460315700088227, 0.39195982473237173, 0.258685613317149, 0.4601396747997829, 0.1083837691694498, 2.3691086002758572, 3.1655599772930145, 2.732505900519235, 4.5979912621634345, 5.979277508599417, 5.303519598075321, 5.579357002462659, 2.5661380163260867, 4.851724709783282, 7.44247259412493, 6.591915377548762, 3.6539673124040877, 5.000581179346357, 7.542934860501971, 5.411341309547424, 11.055258802005223, 5.266626400606973, 4.566080357347216, 9.16093407358442, 2.915338844060898, 5.494918150561197, 6.962009438446589, 1.2188959888049533, 0.5745126690183366, 0.4625847893101828, 0.7818565773112434, 0.8622129282781056, 1.2015399315527506, 0.34076300050531116, 0.04648723140625017, 0.0636444745053138, 0.11073993452425514, 0.09438465535640717, 0.09736995838050332, 0.05226394607286368, 0.015245684422552586, 0.07474244399262325, 0.038607231208256314, 0.06675593754542725, 0.06135058509452002, 0.10436550514506442, 0.7687041259237698, 5.226813656943185, 23.224107129233225, 45.728769983564106, 63.3743109021868, 74.86465113503593, 71.90272440229143, 55.82203939982823, 41.46436173575265, 22.4248297895704, 22.3397855758667, 16.941551174436295, 27.91513650757926, 40.63779708317348, 51.60990939821516, 55.16627883911133, 68.6036432811192, 77.08715057373047, 70.47247246333531, 41.59253168106079, 3.718491324356624, 0.4699741985116686, 0.05186899458723409, 0.043991688173264265, 0.07200938636170966, 0.03310135718701141, 0.06433818835232939, 0.06147122862083571, 0.01806959619612566, 0.02175469613367958, 0.042237532657704184, 0.037991827087742944, 0.010108601817462062, 0.030320961560521806, 0.03868611429684928, 0.04150510160252452, 0.004738353375744606, 0.02158152042622013, 0.03970289223694375, 0.05093387494395886, 0.08463858546955244, 0.04668108207572784, 0.057379282478775294, 0.058003392203577926, 0.06362021687839713, 0.08288012125662395, 0.05635065392458013, 0.038640041769083054, 0.02664558502978512, 0.05480939894914627, 0.044710640130298476, 0.028093936686803187, 0.008830362282294248, 0.00959544613890882, 0.09417990741453, 0.013521838218106754, 0.0179910846054554, 0.016391171973996928, 0.034086915730897865, 0.040089429888342104, 0.05760301583047424, 0.00955082822058882, 0.12256265405033316, 0.020115850859188607, 0.014832463381545884, 0.036740157287567854, 0.007763070802736495, 0.019147408361147557, 0.04288359638303518, 0.06832406590027468, 0.03401441426415529, 0.03406564365806324, 0.02739368854755802, 0.028682038254503692, 0.024797415094716207, 0.014830156362482479, 0.014419807220942207, 0.040697821349437745, 0.03957104609747018, 0.04401045645188008, 0.03011635611099856, 0.03421986788245184, 0.044546851954822025, 0.01847552298568189, 0.06743274229977812, 0.033049167666052065, 0.01972305032956813, 0.01840180524491838, 0.016189373963113343, 0.028546863900763646, 0.01355302962474525, 0.030719685700855086, 0.07636315881141595, 0.05779741611331701, 0.07125148988728013, 0.015041959372216036, 0.018266927750248994, 0.005128724325913936, 0.026280928436400633, 2.4896813418184007, 27.824439934321813, 64.78110572269985, 82.46493816375732, 81.138749395098, 68.34622641972133, 75.21941225869315, 55.444401332310264, 62.354711396353586, 55.515543937683105, 34.740635122571675, 19.645173413412913, 43.19828816822597, 50.36372913633074, 35.70086227144514, 37.41362796510969, 40.42950398581368, 45.11322212219238, 21.586524418422155, 9.440473130771093, 1.0326406231948306, 0.21961909532546997, 0.029868575478238717, 0.06225286703556776, 0.08464613077895981, 0.07052239043904202, 0.10479381001953568, 0.21975138251270565, 0.07606177391218287, 0.10255628651274101, 0.3975082327212606, 1.1254675792796272, 2.5813641250133514, 0.22878238505550794, 1.2027697627033507, 0.44400422062192646, 3.171093131814684, 1.3139065248625619, 0.434349671538387, 0.6605624716196741, 0.8616279225264276, 1.0072260669299533, 1.5630379851375307, 0.23464354340519222, 3.9946713617869785, 10.2109979561397, 10.819857307842799, 7.811514002936227, 7.698025601250785, 7.1679883514131815, 6.755389988422394, 8.201307075364248, 5.8764402610915045, 0.5829928911158017, 1.7803377934864588, 0.562373623251915, 0.7275825696332114, 0.7604091167449951, 0.9690763311726707, 0.8318482147795814, 0.4955491061721529, 0.4803799401436533, 1.2359870374202728, 2.5325625836849213, 1.183890421475683, 0.14330567313092096, 0.047358433050768714, 0.23012013041547366, 0.7581911757588387, 0.23105311606611523, 0.23317158381853784, 0.5875722425324577, 0.09260205565286533, 0.0589470240686621, 0.017839328552197133, 0.033067708635436635, 0.15412673247712, 0.8815290289265769, 6.086331444127219, 24.487346955708094, 41.2326705796378, 62.20165647779192, 80.27451855795724, 71.22505964551652, 45.39452689034598, 39.52638060706002, 33.133530684879844, 37.76020758492606, 34.70639092581612, 38.3609835760934, 50.66776493617466, 58.70413480486189, 63.189162254333496, 76.09731020246232, 86.53201062338692, 83.80493995121547, 53.261291231427876, 5.945402000631605, 0.3683501716170992, 0.04096486898405211, 0.02187025234369295, 0.04292267321475914, 0.029527978040277958, 0.06597820749240262, 0.06453628665102379, 0.03071282571181655, 0.058694955094584396, 0.01661897823214531, 0.06521139506782804, 0.025200117146596313, 0.015363103211192148, 0.017234124509351592, 0.029894040897488594, 0.03425079890127693, 0.05231973182942186, 0.011618248935389732, 0.020402552260618125, 0.029712159585739886, 0.03134993277490139, 0.04041107923590711, 0.0347085657662579, 0.0700826251081058, 0.043230850249528885, 0.009812010768135744, 0.037394661988530836, 0.040989252139947245, 0.026532731085483516, 0.02528347517363727, 0.02901702420786023, 0.05134374062929835, 0.08029868227562734, 0.01932223460503987, 0.06697830025638853, 0.024577483235459243, 0.03595304648791041, 0.0369721721591694, 0.02228526641348643, 0.010932774199838085, 0.07078238470213753, 0.027770955714264085, 0.09261597240609781, 0.09509804671896355, 0.13789994748575346, 0.04932926854650889, 0.2189339513757399, 0.12968888665948594, 0.10733241308480501, 0.11623025313019753, 0.13796071708202362, 0.12564130313694477, 0.10004069935530424, 0.09677778051367827, 0.07803546943302665, 0.19499155825802258, 0.18710510858467647, 0.16900073577250752, 0.13414862592305454, 0.17521956350122178, 0.0958924823041473, 0.11624980850943498, 0.1654579687331404, 0.17557639149682863, 0.10102431728903737, 0.13502899796835013, 0.12210806272923946, 0.08116859131093536, 0.10767283410366092, 0.06452355733407394, 0.1319543793797493, 0.22806335506694658, 0.1833610473466771, 0.14143153226801328, 0.1949205156415701, 0.23807741914476666, 0.10897442033248288, 0.21539184930069105, 4.996289798191615, 37.70033148356846, 80.28817871638707, 92.98541409628731, 87.40808119092668, 78.26370293753487, 85.48323563167027, 62.00019345964704, 66.403628213065, 60.532643590654644, 50.920571667807444, 31.492188998631068, 38.43347413199288, 49.83077451160976, 44.2002774647304, 56.13897453035627, 76.12475558689663, 64.09172630310059, 27.064659629549297, 13.192894680159432, 2.1613092592784335, 0.3830160546515669, 0.15355047982718262, 0.28361431136727333, 0.19010364982698644, 0.14557776121156557, 0.21422497262912138, 0.43261566172753063, 0.21689217165112495, 0.16268717098448957, 0.20256870452846798, 0.6590885849935668, 2.360623981271471, 0.921166113444737, 0.9056194648146629, 0.7560233377984592, 4.642160526343754, 8.650411708014351, 11.213138375963483, 11.194852454321724, 16.31735975401742, 11.130316717284066, 14.332769240651812, 9.129102638789586, 15.202997241701398, 19.34195055280413, 17.617603949138097, 15.497177021844045, 18.747935158865793, 18.76043496813093, 18.886285952159337, 21.809882947376796, 16.165459973471506, 14.766042402812413, 17.63636061123439, 8.518734659467425, 14.23776478426797, 17.11106984955924, 2.4362466548170363, 1.2624010486262185, 0.9608747426952634, 1.5272941717079707, 2.999229439667293, 2.6509874633380344, 1.2104605500187193, 0.17228640589330876, 0.3642817570694855, 0.3012820061828409, 0.5347499740975243, 0.2867458590439388, 0.3277968748339585, 0.6546500431639808, 0.2523515432008675, 0.2219863004450287, 0.4393739790788719, 0.3584318624011108, 0.36732615370835575, 1.407149287206786, 8.667111703327723, 33.604962485177175, 61.47028909410749, 79.42065443311418, 85.07803753444126, 85.7963423047747, 74.95379652295793, 58.55060740879604, 37.349343231746126, 34.63542202540806, 29.913520063672745, 44.07220826830183, 55.64982829775129, 69.23162146977016, 76.34356130872453, 85.18631131308419, 94.08501516069684, 94.94990607670375, 66.99886648995536, 9.678926621164594, 0.4833171825323786, 0.17251218163541385, 0.1849635706416198, 0.10856446983026606, 0.15097030970667089, 0.16401042283645698, 0.15672420524060726, 0.09336785027491194, 0.0989087400957942, 0.12691726109811238, 0.1334550002855914, 0.07456408427762133, 0.0916412907785603, 0.07768034456031662, 0.09342782598521028, 0.18221633162881645, 0.12804323567875794, 0.11613805379186358, 0.12427587354821817, 0.1879072998251234, 0.12502531547631535, 0.12392440597925868, 0.1535753413502659, 0.19659771850066526, 0.12847159483603068, 0.15044107953352587, 0.17945842604551995, 0.12856630475393363, 0.10574451900486435, 0.1297451914953334, 0.0704282708466053, 0.13525315879711083, 0.1574025231280497, 0.21416746000094072, 0.13975963555276394, 0.13581702139760765, 0.0776217734175069, 0.12006348744034767, 0.10460064467042685, 0.14278447681239673, 0.16900419630110264, 0.115873872967703], [0.06807941331395082, 0.05925248696335724, 0.04166554460035903, 0.026564871592979346, 0.029518536225493466, 0.01134482816061271, 0.016197529954037497, 0.04367500909471086, 0.04082278035847204, 0.049619284591504505, 0.044462367559650114, 0.05206712681267943, 0.01862756741632308, 0.01424776975597654, 0.024998524392555867, 0.040772619657218456, 0.02632287547125348, 0.06236806871103389, 0.06566876838249819, 0.04467677105484264, 0.032431073154189756, 0.0323238680139184, 0.040284315323723216, 0.03463834756985307, 0.01912929317248719, 0.05365951279444354, 0.0997565696015954, 0.09607696919036762, 0.04944037865581257, 0.021666618895583918, 0.04296503076329827, 0.02513480475837631, 0.03018982449014272, 0.05539936479181051, 0.040741037244775465, 7.513319901057652, 51.71835688182286, 69.98585537501744, 70.93788364955357, 64.06152943202427, 63.689300537109375, 62.05598749433245, 43.51071739196777, 36.70100334712437, 18.156754629952566, 18.657255956104823, 39.10711588178362, 44.387316022600444, 16.593086855752126, 25.953759057181223, 37.5387407030378, 52.1687947000776, 45.207908698490684, 10.759903907775879, 1.9512241780757904, 0.051744018614824326, 0.04389142783890877, 0.04442817618006042, 0.09029279742389917, 0.14679573157003947, 0.12005288872335639, 0.117628971646939, 0.12258252155567918, 0.07746975443192891, 0.21881404066724436, 0.11753894362066473, 0.5451954507402011, 0.723413704761437, 1.3530382364988327, 0.5593300951378686, 0.7802897042461804, 0.1606930379888841, 0.7136833497456142, 0.15712618295635494, 0.028614897214408432, 0.5697288342884609, 1.6113858308110918, 0.9551785226379121, 1.7898295755897249, 1.8943670690059662, 4.23696460042681, 6.498932412692478, 7.039115335260119, 5.059403760092599, 5.12850706917899, 4.3301069395882745, 1.1699931557689394, 7.670391746929713, 6.641346165112086, 0.7393428300108228, 1.3473846827234541, 0.07732781847672802, 0.4051666132041386, 0.6164158976503781, 0.2275964958327157, 0.30589987124715534, 0.40785285191876547, 0.7900106683373451, 0.5477560247693742, 0.47291089807237896, 0.3082104186926569, 0.11237781627901963, 0.07819608545729093, 0.14732363181454794, 0.08930119991834674, 0.1667584896619831, 0.1133164269849658, 0.1188308335840702, 0.09039797713713986, 0.12712137800242218, 0.039214967883058956, 0.04374269296282104, 0.028524706339729682, 0.0500515860372356, 0.13836764810340746, 0.8943018264004162, 8.46329845700945, 24.068756205695017, 42.17754568372454, 35.061732224055696, 28.269275767462595, 29.070246730531963, 26.089250666754587, 37.60975824083601, 19.3754825592041, 16.273744174412318, 18.815634931836808, 27.210757664271764, 45.069438048771445, 56.48373719624111, 62.581653458731516, 64.29051426478794, 74.06193964821952, 53.88920341219221, 22.715201956885203, 0.5852383534823145, 0.05799067645732846, 0.07404778698193175, 0.10565328997160707, 0.05664322465392096, 0.022304239948945384, 0.03632076497056654, 0.056731834542006254, 0.05944907891431025, 0.02254079421982169, 0.007484776450188032, 0.03362779858122979, 0.021535454683804085, 0.027814819610544612, 0.051450328302702734, 0.014284118876925536, 0.03316475271380373, 0.06759780272841454, 0.08597916032054595, 0.027361834721107568, 0.09888568347586052, 0.017431081172877123, 0.0503253952733108, 0.02734510544022279, 0.04053761923153486, 0.05746907301779304, 0.04216727035652314, 0.036440499259957244, 0.025306404568254948, 0.017518854766551937, 0.01014745473262987, 0.036345653635050566, 0.017156266008636782, 0.0647649597376585, 0.05699462776205369, 0.03513870268527951, 0.026866010523268154, 0.030320951382496526, 0.04132904212123581, 0.02436450805648097, 0.030778860739831413, 0.027159668604976366, 0.03686617820390633, 0.030307390860148838, 0.046388670802116394, 0.00572306290268898, 0.02948410057329706, 0.02942284582448857, 0.049193520830678086, 0.052261954572583945, 0.020338240711550628, 0.035938108539474864, 0.054726454828466685, 0.017828270127730708, 0.008549231653367835, 0.02639733620786241, 0.03481397618140493, 0.0051831657349664184, 0.0008050033970253675, 0.03301139362156391, 0.01227792916220746, 0.011243056389503181, 0.05880343248801572, 0.010171075384797794, 0.046660359616258314, 0.032856182128723176, 0.03359611099585891, 0.04861815706161516, 0.012275628080325467, 0.031403520077999146, 0.016027592554954544, 0.03714909677260688, 0.03959409932472876, 0.003113564378249326, 0.07488482099558626, 0.03296836093068123, 9.40631057534899, 60.17039230891636, 81.10884434836251, 80.55230753762382, 72.29359531402588, 73.3067329951695, 68.11399677821568, 57.087810107639854, 47.83226762499128, 30.529807908194407, 32.72496618543352, 44.19815479006086, 37.58643661226545, 21.461741719927105, 34.71053900037493, 37.237015179225374, 51.219399792807444, 42.04116644178118, 13.277039970670428, 1.959844938346318, 0.05888374389282294, 0.054269651483212195, 0.08506150277597563, 0.030519260027046715, 0.11036975974483149, 0.11671628776405539, 0.05062163009175232, 0.2573147283068725, 0.2520761122660977, 0.5957100487181118, 0.6940983863813537, 1.1904344303267342, 1.799235156604222, 2.307220561163766, 2.4707731221403395, 2.4862951806613376, 0.1146006698587111, 1.0553987962859017, 0.15398004677678856, 0.0324094143163945, 0.4107022647346769, 0.4329798179013388, 0.6063577830791473, 0.45543460441487177, 0.6207957597715514, 2.3514045902660916, 7.064428491251809, 4.202151085649218, 6.783022539956229, 4.609916976519993, 4.415315304483686, 2.511935770511627, 3.6921976038387845, 3.742090880870819, 0.6271024442144802, 0.48379981092044283, 0.3137079636965479, 0.41715844401291435, 0.14754027447530202, 0.2798033872885363, 0.33026378388915745, 0.5315697618893215, 1.897621865783419, 0.7669968775340489, 0.8706058636307716, 1.2633870414325168, 1.4058790696518761, 0.45752204954624176, 1.7851469240018298, 0.9434600600174495, 0.7951070091554097, 0.518326821071761, 0.7498973065188953, 0.17975140389587196, 0.09446476320070879, 0.049294503804828436, 0.021529210465294973, 0.1292816570826939, 0.07886413032455103, 0.03843372980398791, 1.0871642231941223, 10.518738882882253, 29.637520245143346, 45.46528387069702, 38.63504137311663, 32.75202941894531, 31.89477457318987, 21.122134617396764, 25.6795814037323, 16.777566739491053, 25.520003863743373, 32.29507071631295, 37.84628881726946, 52.981129441942485, 64.06898484911237, 70.94137859344482, 70.73291873931885, 84.41968876974923, 69.602203641619, 31.194837365831646, 0.6599782801100186, 0.07278349303773471, 0.02292994423104184, 0.12205559840159756, 0.011123413702339997, 0.02422378328628838, 0.054219741839915514, 0.02696158048430724, 0.07012818873460804, 0.02523219319326537, 0.026313491331945573, 0.018549147427880337, 0.009670769463160207, 0.05691407208463975, 0.09954710584133863, 0.017705241550824473, 0.05612770088815263, 0.08185429165938071, 0.0412653887511364, 0.025935783117477382, 0.0441985090396234, 0.04844668786972761, 0.05734291300177574, 0.03497434454038739, 0.03889874681564314, 0.05777174034821136, 0.05617048591375351, 0.02337257467609431, 0.02561393190574433, 0.050622512187276564, 0.038353710169238706, 0.08679860670651708, 0.017141682594748478, 0.023438675861273493, 0.04434537794440985, 0.0810625430728708, 0.0740585078352264, 0.018940477232847894, 0.03525250997128231, 0.01585025742783078, 0.041693554525928836, 0.09661176335066557, 0.18365507014095783, 0.0763412421303136, 0.07900043443909713, 0.2356708725648267, 0.12827111487942083, 0.07681896471019302, 0.18267784400710038, 0.12293430125074727, 0.11130993786667075, 0.15269851125776768, 0.17081315709011896, 0.08529264573007822, 0.08313479580517326, 0.10741284662591559, 0.16324202263993876, 0.06947517341801099, 0.1459455814744745, 0.12236781950507845, 0.16564057607735905, 0.09110166544892959, 0.22825106499450548, 0.1354416829666921, 0.12935644521244935, 0.10718754585832357, 0.15040464220302446, 0.19298746436834335, 0.2313049611236368, 0.11155271091099296, 0.0928217652919037, 0.11258433519729547, 0.11418631566422326, 0.10176502647144453, 0.19278922357729503, 0.10565429420343467, 15.536693164280482, 74.2800019127982, 92.556321144104, 87.71982601710728, 80.30545193808419, 82.71041107177734, 77.99498830522809, 61.52099009922573, 52.75594874790737, 30.23194558279855, 31.644517830439977, 54.80675472532, 66.79252583639962, 29.629713944026403, 41.445657185145784, 52.32869012015206, 70.911105292184, 60.13054438999721, 17.390807798930577, 3.22832435795239, 0.14179897255131177, 0.1854845362582377, 0.152797346668584, 0.24392668956092425, 0.3751722712601934, 0.36863865756562775, 0.6247041214789663, 0.341054661997727, 0.22004837729036808, 0.7632675405059541, 0.6592647326844079, 1.0121094563177653, 2.171258862529482, 5.055731202874865, 3.428021013736725, 3.7988924043519154, 0.2833519625876631, 1.5793912219149726, 1.5045864816222871, 0.30722491443157196, 0.6995662929756301, 4.107319031442914, 4.0355888690267285, 6.605066580431802, 7.080182663031986, 14.135464719363622, 16.61065537588937, 19.754946265901836, 17.21573403903416, 17.936170169285365, 14.291338000978742, 9.902363317353384, 17.223792212350027, 24.206434760774883, 7.512315017836435, 6.176872551441193, 2.386812610285623, 1.5125480315514972, 1.643808513879776, 0.6495873034000397, 0.9138101424489702, 1.7860925304038184, 3.6365416646003723, 2.5273477435112, 1.1747719964810779, 0.5910989418625832, 0.7496185643332345, 0.49180212723357336, 0.8210040309599468, 0.41484488387192997, 0.3804731768156801, 0.42379383796027725, 0.731712839433125, 0.3779632214988981, 0.3390931529658181, 0.30233378974454744, 0.15269210588719162, 0.2505976658846651, 0.24929181167057582, 0.25832172855734825, 1.4991728578295027, 13.400121229035513, 37.01478746959141, 57.794751099177766, 49.05790206364223, 42.807399885995046, 42.4578777040754, 41.57555375780378, 50.194776739392964, 29.3210506439209, 27.15950080326625, 31.98110941478184, 42.79862431117466, 63.1618766784668, 73.69090584346226, 81.77926908220563, 79.23657580784389, 92.21748529161725, 82.07719394138881, 40.05066040584019, 1.7771053612232208, 0.10115632627691541, 0.16549454177064554, 0.21588537496115479, 0.21194193299327577, 0.10191323887556791, 0.19008361947323593, 0.15428344692502702, 0.1718917427850621, 0.16824814544192382, 0.09378527144768409, 0.07131158094853163, 0.1860229537955352, 0.21087903502796376, 0.17508153590772832, 0.15177966627691472, 0.2559188189251082, 0.17385285826666014, 0.18665362495396817, 0.14426441597087042, 0.14310424322528498, 0.08138925089899983, 0.11643203587404319, 0.1558740415743419, 0.13004894448178156, 0.18957460964364664, 0.13999762492520468, 0.09152354459677424, 0.08568624353834561, 0.11618130361395222, 0.1387008223682642, 0.22861253416963986, 0.12725278309413365, 0.2172972841986588, 0.11467279813119344, 0.11376145096229655, 0.16313816606998444, 0.0938840661463993, 0.14573419067476476, 0.1269471166389329, 0.1302204645637955], [0.019333581406889216, 0.051177794712462595, 0.04928629692377789, 0.04222504761336105, 0.01868008602676647, 0.025295566667669585, 0.0927270825154015, 0.053194210798080475, 0.0527684775713299, 0.02865609446806567, 0.01785846154338547, 0.04771420592442155, 0.05046349072030612, 0.030542082552398955, 0.0618862138528909, 0.029240706669432775, 0.049088290227310996, 0.038789424646113596, 0.05150608013250998, 0.023197585583797524, 0.025418827642819712, 0.025234454411215017, 0.007826765733105796, 0.01818433646777911, 0.06461237078266484, 0.022894921646054302, 0.05764336830803326, 0.01613408692979387, 0.047115687147847245, 0.014942521761570658, 0.07493648465190615, 0.03307713009417057, 0.06334520663533892, 0.07625882726694856, 12.316585268293109, 62.10973181043352, 73.96338639940534, 66.95315429142543, 64.38745553152901, 69.60933944157192, 61.567473547799246, 45.038174629211426, 27.974050283432007, 18.279713426317485, 20.602550063814434, 24.45010461126055, 36.10669265474592, 37.70675161906651, 58.38765825544085, 52.38803815841675, 44.73778315952846, 24.509541239057267, 3.5965345885072435, 0.07002756877669267, 0.015996117011776993, 0.12558624680553163, 0.00971658414761935, 0.007058726008316236, 0.05599388699712498, 0.020602918562612364, 0.06218003987201622, 0.13220783935061522, 0.2225066010973283, 0.45635904052427834, 0.353116761893034, 0.44073430608425823, 1.279384183032172, 3.7269633497510637, 3.5640230987753188, 1.508875148636954, 1.8636579854147775, 0.31044323316642214, 0.3450450993009976, 0.488250729228769, 0.2622338629194668, 0.250283911292042, 0.3144885232406003, 0.11951417263065066, 0.2418556378356048, 0.07105503364333085, 0.47105822605746134, 8.026711872645787, 6.228888503142765, 4.310927305902753, 4.570814686162131, 3.7423627291406905, 3.7168658801487515, 5.781148322990962, 5.007268386227744, 1.6004012716667992, 0.9931768093790326, 0.07155471361641373, 0.18919191589312895, 0.3277727189872946, 1.1072621047496796, 2.9488643365246907, 1.5713964509112495, 1.2138140329292841, 0.2596544256167752, 1.4145424962043762, 2.48791041970253, 0.6955317237547466, 0.13980884291231632, 0.4338477998971939, 1.3591890207358768, 1.4344975054264069, 0.5152084369744573, 1.6110750074897493, 0.2965826897748879, 0.0430745089958821, 0.0497385201576565, 0.07801751539643322, 0.08481700625270605, 0.008011373907460697, 0.053816630970686674, 0.04210073999794466, 0.035498553554394414, 1.0991683219160353, 14.370041114943367, 47.05645956311907, 45.973336151668, 47.211355754307334, 64.98452813284737, 158.48076684134347, 100.83925478799003, 20.127715383257183, 16.113294635500225, 19.42381249155317, 28.671861342021398, 55.089845180511475, 58.286596706935335, 62.45204176221575, 67.89151545933315, 69.08711283547538, 76.61634758540562, 33.482250349862234, 2.300782403775624, 0.3338124948952879, 0.047638223573033295, 0.0596062886927809, 0.06779454395707164, 0.017382425123027394, 0.04045485831531031, 0.05392266224537577, 0.03237884970647948, 0.06146411757384028, 0.012457042051080083, 0.06201356130519083, 0.035674328050975285, 0.008522441394494047, 0.030718864673482518, 0.08902724140456744, 0.037107879162899086, 0.022105631052649448, 0.04821900205154504, 0.012545692651266498, 0.04929735704458185, 0.02258766402623483, 0.01811951432111008, 0.05525053492082017, 0.0342330891372902, 0.026605449683432068, 0.033897451790315766, 0.025751053654987897, 0.03305970531489168, 0.005977460100049419, 0.05491868040657469, 0.04612458836553352, 0.017578168905207088, 0.05866714872952018, 0.057395838733230314, 0.10248759162745305, 0.04894778598099947, 0.02319163822435907, 0.041059029288589954, 0.030975310198430504, 0.04913254767390234, 0.011492777632416358, 0.0429481997021607, 0.0061878271600497615, 0.0627006051529731, 0.02520776932526912, 0.08612451609224081, 0.03888062314529504, 0.02339902057844613, 0.09153839094298226, 0.024701711123010943, 0.03211735248831766, 0.091810327422406, 0.05189588153734803, 0.01393392780196986, 0.015555232098059995, 0.030722016468644142, 0.030147823172488382, 0.015894148465512053, 0.06491005766604628, 0.035347094360206804, 0.006702751270495355, 0.04724468344024249, 0.01716410308810217, 0.06512526183256082, 0.02781949980583574, 0.05181356845423579, 0.02054608446945037, 0.024369354492851665, 0.028974754868873527, 0.024284807333190526, 0.030219065956771374, 0.053347427397966385, 0.12475960116301264, 14.828647409166608, 73.92036315373012, 84.79991504124233, 76.04247501918248, 74.30145795004708, 76.20575073787144, 68.21668420519147, 58.295413970947266, 35.32512106214251, 31.430819034576416, 32.426749501909526, 27.112089770180837, 42.78980357306344, 41.10690818514143, 44.11878204345703, 48.458397592817036, 46.450354303632466, 24.851958887917654, 4.813784505639758, 0.03219467494636774, 0.06337441756789174, 0.10825534284647022, 0.05180842176611934, 0.18416919612458774, 0.03292133845388889, 0.016170412302017212, 0.07424376825136797, 0.4997696482709476, 1.1932561589138848, 1.2625025574650084, 2.855426481791905, 2.744633764028549, 6.147549416337695, 7.851684144565037, 4.730611962931497, 2.501321528639112, 1.9408101311751773, 0.2325902964387621, 0.4456311304654394, 0.5039136516196387, 0.40591381596667425, 1.02479730120727, 0.13406443329794065, 0.21373042916612967, 0.047409058548510075, 0.07962727866002492, 0.6324860496180398, 3.893748777253287, 4.428054826600211, 4.620225063392094, 1.758167177438736, 0.3095960414835385, 1.5248790213039942, 2.6975327943052565, 4.680885876928057, 1.397576515163694, 0.7866945862770081, 0.11586497058825833, 0.3659616469272545, 0.41203830018639565, 1.497200763651303, 3.967232491288866, 2.039217684950147, 1.8389669103281838, 1.6279624955994743, 2.419849991798401, 4.001399389335087, 2.4573398658207486, 1.8270948273794991, 2.212588267666953, 4.223640995366233, 2.7199118563107083, 2.150618370090212, 1.9381240010261536, 0.7302551290818623, 0.2434877316866602, 0.15049822575279645, 0.09916745871305466, 0.07302523470882859, 0.018912879517301917, 0.032381211008344374, 0.08001808090401547, 0.06145770541791405, 1.175173472080912, 14.586266449519567, 37.10609722137451, 39.61382368632725, 32.86083126068115, 43.09233161381313, 122.731354032244, 78.67405659811837, 23.305354152406963, 21.585315431867325, 29.856093202318462, 43.96088770457676, 66.08096081869942, 66.016266141619, 70.90536608014787, 74.7257774897984, 76.86044475010463, 89.19820812770298, 44.95033202852522, 2.505069864647729, 0.22170533266450676, 0.0314666509761342, 0.07845252419688872, 0.04114497931940215, 0.02693074446038476, 0.05970158215079989, 0.038543180895170996, 0.032691742559628825, 0.05758848161037479, 0.01593851956671902, 0.04877349408343434, 0.05752110986837319, 0.02678836745742176, 0.00947806382152651, 0.08094869168209178, 0.02670076349750161, 0.01157068702325757, 0.01863466658895569, 0.009257734171114862, 0.03507633174636534, 0.0033534718843709144, 0.03374654220949326, 0.026959716209343502, 0.012440581639696444, 0.014548589774806584, 0.052319579159042666, 0.023766991815396717, 0.045491491444408894, 0.012442692731773215, 0.08242823729025466, 0.06464871311826365, 0.03963589029652732, 0.07369986815111977, 0.04324783058837056, 0.08541736725185599, 0.06924282267157521, 0.05906639873449292, 0.06203788000025919, 0.16324302687176637, 0.11459388450852462, 0.12985028299902165, 0.20450300430612905, 0.17420139456433908, 0.13293894726250852, 0.09512972073363406, 0.2190179947231497, 0.18079746062202112, 0.27197531876819475, 0.17920958011278085, 0.13624078008745397, 0.19447376818529197, 0.12760909540312632, 0.11431199392037732, 0.10917042195796967, 0.1337264007223504, 0.11078484675713948, 0.15073873927550657, 0.12697687718485082, 0.13573590932147844, 0.15307465036000523, 0.19296322709747724, 0.12932033357875689, 0.088791409773486, 0.1983137878456286, 0.10313811672053166, 0.11934276111423969, 0.13086139517171042, 0.14435175699847086, 0.10488855386418955, 0.20465186131852015, 0.13556185151849473, 0.16782628665012972, 0.2989918147878987, 22.056575264249528, 88.75155012948173, 92.83026082175118, 84.55200331551688, 81.99183532169887, 87.719117300851, 77.37973921639579, 61.37714154379708, 40.949163232530864, 30.262062549591064, 32.09782525471279, 37.0286352293832, 50.89648226329258, 52.5125081879752, 79.89744676862443, 71.7115169252668, 61.03281661442348, 35.28916413443429, 5.939402665410723, 0.37062616805945126, 0.1463315457637821, 0.35645444850836483, 0.12521865724452905, 0.5414434235010828, 0.15371503813990525, 0.22431315987237863, 0.11466523925108568, 0.42629898924912724, 0.7696862646511623, 1.20631334398474, 2.427858224936894, 1.9913732579776218, 4.411161150251116, 8.485217417989459, 9.824923038482666, 3.8558376686913625, 8.390126977648054, 1.2473165094852448, 0.9068621067064149, 1.5295541818652834, 0.6191023534962109, 1.3480044837508882, 1.043767294713429, 0.5055189026253564, 0.7304418619189943, 0.12693517442260469, 4.373921845640455, 17.100642340523855, 17.244278975895472, 20.35023318018232, 11.65787867137364, 11.172236936432974, 9.360166719981603, 14.91276924950736, 9.676678878920418, 2.032052138022014, 1.2510757020541599, 0.2886376961001328, 0.5121758739863123, 0.5926702118345669, 1.7616054500852312, 5.821866938046046, 2.844379497425897, 2.866307143654142, 1.7035276293754578, 4.16255156482969, 6.655984716756003, 1.1724785481180464, 0.721426574247224, 1.5455467637096132, 4.361151925155094, 3.5431989133358, 2.8877180176121846, 3.78952362707683, 1.0542309560946055, 0.204044871032238, 0.2510092652269772, 0.3279070960623877, 0.2450381570628711, 0.18127506785094738, 0.21529579588345119, 0.27973621232169016, 0.20066617376038007, 1.7182645414556776, 22.348344019481114, 65.44736153738839, 61.22926998138428, 64.95541518075126, 79.35277053288051, 160.8237966809954, 114.5188820702689, 33.6730409349714, 26.861211163657053, 31.03259345463344, 45.535054206848145, 70.57598672594342, 75.4797612598964, 79.60972881317139, 85.13800048828125, 83.7083738871983, 100.23014790671212, 56.46779108047485, 3.697322334562029, 0.43796976442847935, 0.09394292905926704, 0.22970180000577653, 0.11396925231175763, 0.14442042474235806, 0.18323507053511484, 0.1496655818607126, 0.15190191114587442, 0.1641166949910777, 0.042537546916199584, 0.20645656090761932, 0.08770142469022955, 0.15377607915018285, 0.09777851788593189, 0.2277652339211532, 0.13285543317241327, 0.11406289014433112, 0.15160906900252613, 0.08370309602469206, 0.12485283187457494, 0.05894241003053529, 0.12559835187026433, 0.08645163103938103, 0.14798240789345332, 0.08733488685850586, 0.14554724070642674, 0.12222686064030443, 0.1471199763140508, 0.08848482729601008, 0.17369201832583972, 0.11236968064414603, 0.1131137078627944, 0.15161921988640512, 0.08239304846418755, 0.2234780461128269, 0.14408632766987595, 0.08227606902697257, 0.10908436336155448, 0.3309550482247557], [0.10737543220498733, 0.025315452832728624, 0.05863778173391308, 0.06948899517634086, 0.01842650561593473, 0.08012599511338131, 0.03731117503983634, 0.03802164870181254, 0.045841568016580174, 0.04391497300405588, 0.07520194790725197, 0.024475243275186846, 0.06235248276165553, 0.057095003447362354, 0.04714695404150656, 0.07545931623982531, 0.0643346735409328, 0.08270470638360296, 0.03522696991318038, 0.014699770769636546, 0.01764956266353173, 0.1157103595989091, 0.049223620644105334, 0.057386054258261404, 0.05909697352243321, 0.10172232626272099, 0.0510643809767706, 0.007186578969205064, 0.04113848234659859, 0.0609412927712713, 0.0423032894863614, 0.06614767161331006, 0.16040358852062905, 15.038967643465314, 68.78686727796281, 68.47497653961182, 63.722047397068565, 63.94470936911446, 53.78410496030535, 48.65649768284389, 46.19241632734026, 18.012589931488037, 21.236599240984233, 21.658915962491715, 35.78623826163155, 36.35213776997158, 33.80368791307722, 39.15913009643555, 48.112516266959055, 37.43128333772932, 13.339522515024457, 2.135556629725865, 0.08972938944186483, 0.1294173098036221, 0.18183097802102566, 0.02564200459580336, 0.0866860920297248, 0.03715517305369888, 0.06807965758655753, 0.027219871624505947, 0.19437628984451294, 0.15989964056227887, 1.1040804811886378, 1.7353368082216807, 0.6698009158883775, 1.3259861852441515, 8.187580909047808, 4.453858699117388, 2.266174077987671, 3.814373425074986, 1.829667832170214, 0.7162808903626033, 0.07365507805453879, 0.05199927331081458, 0.283656543386834, 0.7459442700658525, 0.3313509598374367, 0.20422050303646497, 0.11444516320313726, 0.12111608524407659, 1.4394466855696268, 3.3669700154236386, 2.8363169814859117, 2.9953319345201765, 3.9198505537850514, 10.733266251427786, 26.757709060396465, 34.63138164792742, 46.85253340857369, 46.38616337094988, 33.21453973225185, 12.613476582935878, 3.5069779540811266, 0.9987952964646476, 0.9314772401537214, 0.8283692300319672, 1.2458082075629915, 0.7517690317971366, 1.4919076476778304, 1.9906280636787415, 2.7950855025223325, 1.813609459570476, 2.3039175612585883, 4.8808081320353915, 5.0342417274202615, 2.9214476134095873, 1.8451212772301264, 0.912048014146941, 0.9898142069578171, 0.11629645100661687, 0.2777536687042032, 0.032756559617285214, 0.2551002342786108, 0.11603643638747078, 0.1329546757042408, 0.19119569765669958, 0.1419005628143038, 0.07676753854112965, 0.018946919922849963, 3.1018334882599965, 17.855138540267944, 48.96249982288906, 52.69390480858939, 41.595151151929585, 40.54453836168562, 29.605079105922155, 25.17910439627511, 19.553354706083024, 16.079352685383387, 19.8657283442361, 27.762451580592565, 52.09354223523821, 52.09676619938442, 57.05360412597656, 66.03189958844865, 69.57814897809709, 34.210497992379324, 1.1605462112597056, 0.1338291580655745, 0.05663065818537559, 0.04235158760898879, 0.04218621166156871, 0.08932052459567785, 0.03868210415488907, 0.047894557139703205, 0.047902377255793126, 0.03702576285494225, 0.032097888711307726, 0.0203187005993511, 0.11400794237852097, 0.028077921564025537, 0.05370558871488486, 0.048138015504394255, 0.0949040874838829, 0.052286799132291756, 0.03864399084289159, 0.012636858920034553, 0.06835470175636665, 0.06329925624387604, 0.013474580798564213, 0.06202558494572129, 0.044445231157754145, 0.05681015783920884, 0.0421468091330358, 0.03299245231651834, 0.021095952285187583, 0.02012907381036452, 0.03526876088497894, 0.06977445485868625, 0.020483136775770357, 0.031031896626310687, 0.060757654053824287, 0.15955797103898867, 0.11937239952385426, 0.07859104033559561, 0.2352882602385112, 0.09087175742856093, 0.01293128204997629, 0.021231720357068946, 0.06710443313100509, 0.06920263304242066, 0.019381991487794688, 0.030428634889956032, 0.0495444320009223, 0.06277793778904847, 0.04445480528686728, 0.044362697550760846, 0.06702934644584145, 0.060779034692261896, 0.026004513625853827, 0.03838167938270739, 0.12896943597921304, 0.10112222310687814, 0.06913967177804027, 0.05435394588857889, 0.046158250487808666, 0.001856934911172305, 0.046649136647049866, 0.014535453336845552, 0.08526884272162404, 0.028445333009585738, 0.073428257368505, 0.04595960257574916, 0.045208186110747714, 0.04486827399315579, 0.0360203707324607, 0.02721050614491105, 0.026083288148843815, 0.11563516434814249, 18.336297818592616, 80.85679844447544, 79.12653718675885, 72.54664870670864, 73.81174196515764, 62.094932147434776, 62.48298209054129, 57.665281840733115, 30.258539812905447, 29.145365442548478, 24.058252266475133, 33.43557235172817, 44.73615033285958, 41.141385146549766, 45.715165410723, 50.73422792979649, 38.31408323560442, 16.749567236219132, 2.1523918977805545, 0.05692688961114202, 0.021655582523505603, 0.09428957224424396, 0.13315520994365215, 0.29440505376883913, 0.15234861789005144, 0.4563607775739261, 0.46892540050404413, 0.4939750134944916, 1.423509037920407, 3.617941988365991, 3.0262681373528073, 3.3077542100633894, 4.193229598658426, 7.863542113985334, 8.223481382642474, 4.6070451991898675, 4.039078601769038, 1.3652071378060748, 1.4495572916099002, 1.6902286687067576, 0.6213188831295285, 0.6821171950016702, 2.110352256468364, 0.8772690775138992, 0.3581550201135022, 0.20180176996759006, 0.036180257331579924, 0.2919066335473742, 0.7962101442473275, 0.3453636850629534, 0.6687467981662069, 3.4523965971810475, 12.234821472849164, 25.749421221869333, 35.53144781930106, 46.900583675929475, 45.05578831263951, 30.128410475594656, 11.687266945838928, 3.835741307054247, 1.2261306920221873, 1.7338179754359382, 1.6818667288337434, 2.149170322077615, 3.1524146369525363, 1.783223684344973, 2.446373002869742, 2.655377204929079, 3.5278457828930447, 3.7547526700156073, 7.317736795970371, 6.0242123774119785, 3.599616765975952, 2.8465062975883484, 1.9602550991943903, 1.01875801384449, 0.7051792432154927, 0.7808214042867933, 0.10370306497705833, 0.2693745754659176, 0.1642424953835351, 0.1526687778532505, 0.11406488503728594, 0.36527393811515396, 0.11709092051855155, 0.01242364540563098, 3.5050943408693587, 20.706609760011943, 48.745896680014475, 57.468234402792795, 56.24427795410156, 47.398005213056294, 32.176798479897634, 25.728866713387625, 28.545652525765554, 25.8645806653159, 40.09881142207554, 43.36823763166155, 60.13205909729004, 59.8216552734375, 64.53791182381767, 73.75472504752022, 80.44899477277482, 47.643811634608674, 1.8936633467674255, 0.13004504969077452, 0.030450456576155763, 0.03687536217538374, 0.027267930563539267, 0.057610364364726205, 0.03625966967748744, 0.012268411012233367, 0.015298518551779645, 0.044307787104376724, 0.01988289112757359, 0.03093683047752295, 0.13495188924883092, 0.00718762052045869, 0.021612733037077954, 0.04428257952843394, 0.07411592546850443, 0.035971241404435465, 0.02083688252605498, 0.05754597817680665, 0.019058046995529106, 0.04095085723591702, 0.028161081119573543, 0.07411021220364741, 0.10660650275115456, 0.03605257739712085, 0.05416381359100342, 0.031494158785790205, 0.10524658286677939, 0.08305381943604775, 0.04603076393582991, 0.0576619737382446, 0.04805661165820701, 0.05398486694321036, 0.12172566753412996, 0.13551963306963444, 0.03916397936908262, 0.1154191866517067, 0.07426453820828881, 0.1671621230031763, 0.12735758961311408, 0.08759688279990639, 0.18746667275471346, 0.16373462549277715, 0.1368837191590241, 0.10723605432680675, 0.12719554187996046, 0.15643647925129958, 0.11162394351725068, 0.13075953349471092, 0.1121993072863136, 0.2839389496615955, 0.16294392863554613, 0.18691392455782208, 0.21338563838175365, 0.21391676845295088, 0.25210368792925564, 0.1988855078816414, 0.09612359133149896, 0.14625765330025128, 0.1420315065022026, 0.12476523300366742, 0.13399339068148816, 0.10426542801516396, 0.1555563107665096, 0.16589384605841978, 0.10980895055191857, 0.18606551151190484, 0.16165323289377348, 0.08163703831710986, 0.24070058124405996, 0.27391527752791134, 28.345702477863856, 94.48851789746965, 88.08472456250871, 80.22668715885708, 83.77938447679792, 70.67329624720982, 64.9848963873727, 61.796215193612234, 33.37692608152117, 33.94041109085083, 33.46684966768537, 47.80058036531721, 49.922059944697786, 46.857605593545095, 54.229522705078125, 62.61175305502755, 51.25261913027082, 20.90188888141087, 3.4166537608419145, 0.18710829769926413, 0.23178324688758167, 0.24034513745989117, 0.37434546276926994, 0.38312166184186935, 0.15408159632767948, 0.45488216834408896, 0.3108919619449547, 0.8144147502524512, 1.3485913894006183, 3.499859307493482, 4.482541731425694, 5.271439330918448, 6.362573146820068, 18.98590748650687, 13.810907414981298, 7.363329138074603, 9.317183426448278, 5.535892111914499, 4.754214125020163, 2.086846500635147, 1.0295232704707553, 0.6540587406073297, 3.093436590262822, 1.6856925806828906, 1.3680403743471419, 0.2166232139404331, 0.807191500706332, 2.71795984676906, 11.349211028644017, 5.760830921786172, 7.809576324054173, 5.99409019947052, 10.737149425915309, 23.893864836011613, 31.451340539114817, 43.96914216450283, 44.21596997124808, 33.51197474343436, 13.229099137442452, 4.570327877998352, 1.9792899063655307, 2.5036519978727614, 2.581307019506182, 3.8677677256720404, 4.617704604353223, 4.9460473741803845, 7.370647328240531, 8.277145794459752, 8.312410507883344, 6.835451909473964, 17.247572422027588, 11.634782859257289, 8.18303678716932, 4.218246587685176, 1.6383997755391257, 1.235278646860804, 0.5802745169826916, 0.5658706298896244, 0.14648969870592865, 0.3411775582603046, 0.215167566335627, 0.3224844884659563, 0.572827296597617, 0.6336581238678524, 0.22628484692956718, 0.16169610273625168, 4.301313604627337, 27.80215358734131, 65.57600048610142, 69.25767721448625, 54.65453706468855, 53.232629912240164, 45.34806776046753, 40.752595220293315, 30.871968473706925, 27.350194113595144, 33.89950009754726, 43.528949465070454, 67.41753019605363, 70.3597240447998, 76.31829765864781, 82.58442633492606, 89.12099279676164, 58.40078340257917, 3.0562381063188826, 0.3414986681725298, 0.17788593471050262, 0.16942965132849558, 0.11409418417939118, 0.1548491008579731, 0.14486854283937387, 0.19217145815491676, 0.16527640633285046, 0.15091951457517488, 0.16769322593297276, 0.151246880580272, 0.18022895684199675, 0.08617881924978324, 0.1555500275322369, 0.11532223756824221, 0.1598080111933606, 0.09552541521510907, 0.05637044679107411, 0.17269662102418287, 0.18988404875355108, 0.13946603345019476, 0.07950641800250326, 0.1462684284363474, 0.21509355173579284, 0.16242586714880808, 0.1562935390642711, 0.13640309923461505, 0.18126037078244345, 0.09843126857387167, 0.2003639271216733, 0.142532224633864, 0.10363344728414502, 0.17859294105853352, 0.25692934755768093, 0.2069969190550702, 0.13038817127900465, 0.20971223978059633, 0.26514301395842005], [0.3612416216305324, 0.05954103398003748, 0.08200466859021358, 0.15629581894193376, 0.2484085490661008, 0.07288088316896132, 0.1570861493902547, 0.05291824721332107, 0.05187178336616073, 0.03735583282208868, 0.04405232545520578, 0.09576947069061653, 0.11446868122688361, 0.14005606036101068, 0.1105990842250841, 0.21004229278436728, 0.09071439837238618, 0.040112856309860945, 0.14574307948350906, 0.1134025805762836, 0.027233712042548826, 0.11945203239364283, 0.17347747912364347, 0.3006240443459579, 0.2907579823264054, 0.14333970844745636, 0.06954207697084971, 0.15262978923107895, 0.04974336489768965, 0.1258692094790084, 0.03962180730221527, 0.11393741544868265, 19.541117191314697, 70.66959980555943, 64.82919420514787, 74.03510570526123, 67.89797728402274, 54.19927372251238, 47.623738288879395, 21.319281067167008, 22.483460426330566, 28.86334674698966, 22.022344963891165, 33.70966836384365, 51.254067829677034, 48.419129848480225, 43.877641337258474, 41.78489603315081, 31.73331928253174, 10.988346781049456, 0.6052882490413529, 0.022248069123764123, 0.05788573423134429, 0.10987945712570633, 0.10782720760575362, 0.06479957859430995, 0.10614028133984123, 0.12697580509952136, 0.1572722444044692, 0.1914688894259078, 0.2793188861438206, 2.057877289397376, 3.2691165804862976, 2.0033169942242757, 4.773932244096484, 5.692803280694144, 6.640330859592982, 10.129305379731314, 2.751415422984532, 1.5384559099163329, 0.26512800476380755, 2.337081096002034, 0.8127050591366631, 2.3624589570931027, 5.025864805494036, 6.77166006394795, 5.367915936878749, 6.849205868584769, 9.27214867728097, 11.978359120232717, 10.377949271883283, 8.003338132585798, 10.92613869053977, 17.375226463590348, 46.082297801971436, 73.15479673658098, 83.43232195717948, 78.92288548605782, 79.57339668273926, 83.06071840013776, 81.87372984204973, 77.58844920567104, 36.773209026881624, 14.963456358228411, 6.310576302664621, 2.9037909380027225, 7.023703362260546, 9.643974576677595, 3.2563759727137427, 4.077843904495239, 1.6450002385037286, 6.069820352963038, 6.318961475576673, 7.77074544770377, 5.4848319717815945, 3.461665059838976, 2.964053750038147, 3.543053218296596, 1.9585084957735879, 2.3046714408057074, 0.3502231628767082, 0.31624744885734146, 0.16390447637864522, 0.11105216241308621, 0.14746160512523993, 0.20414533492709908, 0.23379806163055555, 0.10621965636632272, 0.18979163228401116, 0.016999127476343086, 0.09463458015982594, 2.6270930426461354, 17.698969091687882, 29.530424186161586, 36.76084123338972, 42.382448060171946, 33.58150884083339, 29.10282509667533, 23.41664171218872, 13.55712011882237, 15.736096041543142, 20.65988138743809, 29.723177637372697, 42.935861655644004, 59.51157801491873, 61.358339718409944, 77.75782544272286, 48.217878750392366, 3.4171151646545956, 0.07410814945719071, 0.14973977287965162, 0.09650480587567602, 0.05524096757705722, 0.01523571674312864, 0.055479506562863073, 0.06887186079152993, 0.025723788421601057, 0.010081607149913907, 0.07661448139697313, 0.11107655574700662, 0.06610356683709792, 0.10512135922908783, 0.16935384539621218, 0.20424491672643594, 0.12924223419811043, 0.10063382717115538, 0.07111340122563498, 0.05131575784512928, 0.13528893116329396, 0.018860147168327655, 0.02545301054072167, 0.11249147767999343, 0.07313318963029555, 0.07876914899264063, 0.09084036161324807, 0.2086286057851144, 0.04755637528640883, 0.09604323921459061, 0.02705523867293128, 0.03810187868241753, 0.05343977262132934, 0.024811387827087725, 0.08019932439284665, 0.056277144833334854, 0.06300497560628823, 0.24482884258031845, 0.25208534034235136, 0.08810850498931748, 0.09719217542026724, 0.0879970488271543, 0.09985634139073746, 0.026576851128733585, 0.04077479096927813, 0.009570855181664228, 0.09087534687880959, 0.056473132888121266, 0.022166073255773102, 0.045725507994315455, 0.06428501156291791, 0.05866983572819403, 0.09625597351363727, 0.12695258563118322, 0.10921350893165384, 0.051612952790622196, 0.007589286110097808, 0.09160515200346708, 0.06598307258848633, 0.15014761313796043, 0.10673739894160203, 0.17843641660043172, 0.11409087292850018, 0.08731653248625142, 0.04114728294579046, 0.06211489372487579, 0.036393096803554466, 0.07144457381218672, 0.0540534261214946, 0.16419202594884805, 22.457489797047206, 82.03207233973912, 76.67209298270089, 82.06025423322404, 74.40155369894845, 66.24325684138707, 56.681013924734934, 35.00865493501936, 38.25355747767857, 32.247183731624055, 21.719030039651052, 30.956899779183523, 36.2120794568743, 32.990112917763845, 46.16690949031285, 44.39197826385498, 35.48594406672886, 12.342977132116046, 0.7657650922025953, 0.06488930806517601, 0.05956349348915475, 0.11705597596509115, 0.020573498980541314, 0.08411420003644057, 0.7806209921836853, 0.9751501423971993, 1.2000563825879778, 1.5647875198296137, 2.1297255711896077, 5.23321772473199, 4.379460428442274, 3.8651521631649564, 3.828246372086661, 7.356027449880328, 6.252346055848258, 7.78346586227417, 4.78373441525868, 2.6013944787638525, 1.3289873727730341, 1.7603277415037155, 2.2546871857983724, 2.876053729227611, 6.559231919901712, 7.758114491190229, 6.783823319843837, 9.012985212462288, 11.400460941450936, 13.896228688103811, 12.49345166342599, 9.470904503549848, 13.169027617999486, 20.091061898640223, 49.765451022556846, 78.43512889317104, 93.44955376216343, 90.78006975991386, 92.38149751935686, 94.64718001229423, 89.92050116402763, 76.07572214944022, 37.31347663061959, 17.071419954299927, 8.217911532946996, 4.0999756540570935, 9.02057351384844, 9.928596241133553, 5.0372667993818006, 3.5191863732678548, 2.279053432600839, 3.5377997287682126, 1.8852356161390031, 5.1144243734223505, 2.868786999157497, 3.215318415846143, 2.611740346465792, 2.385823577642441, 2.353863384042467, 3.47987368277141, 1.8546453033174788, 1.9304143232958657, 0.780869715980121, 0.7254065892526081, 0.352525242205177, 0.6345771316971097, 0.5025538674422673, 0.04792185799617853, 0.06370096933096647, 0.0938547941456948, 0.11555622358407293, 3.7820777637617926, 19.27642556599208, 32.63470213753836, 34.08144562585013, 34.86087369918823, 29.000731740679058, 19.381836686815532, 24.385786873953684, 16.8374046257564, 23.063994577952794, 37.66222756249564, 38.79204634257725, 48.86821971620832, 63.95857102530343, 67.87593759809221, 86.44504002162388, 61.80592877524239, 4.776987280164446, 0.050832939467259815, 0.035178206994065216, 0.05222090659663081, 0.047554658592811654, 0.027088405464642813, 0.08443445499454226, 0.008289973600767553, 0.022932717742930566, 0.014970268754820739, 0.021214046216170703, 0.09304076925452266, 0.05552206088655761, 0.10477757267653942, 0.10658204156373229, 0.07882274647376367, 0.08406543372465031, 0.05852956896913903, 0.05424807406961918, 0.029038723757756606, 0.027745790546759963, 0.07987391256860324, 0.035123730810093026, 0.035187146692935906, 0.05260117119178176, 0.09195193768079792, 0.05141791807753699, 0.058114291967025826, 0.0120755518520517, 0.031297074896948676, 0.05704027959810836, 0.00927697233523109, 0.03091138880699873, 0.03560440501730357, 0.021083435010431067, 0.05843422122831855, 0.026311394658737948, 0.17374886598970207, 0.47266923104013714, 0.2431912390249116, 0.17811940503971918, 0.2617791358913694, 0.36305417865514755, 0.18227887898683548, 0.2720302258219038, 0.23692917504480906, 0.14567773656121322, 0.1426358912140131, 0.10424397273787431, 0.14148715856884206, 0.23359333404472896, 0.2426031120121479, 0.29721652290650774, 0.44072651650224415, 0.2405202809189047, 0.21326869965663978, 0.2494265144424779, 0.1663472702992814, 0.11917200099144663, 0.28290266383971485, 0.26227153518370216, 0.35488011155809673, 0.36765679025224274, 0.1964647527784109, 0.22645902686885425, 0.201322751385825, 0.16841278517884867, 0.31560183635779787, 0.11615090524511677, 0.4305180385708809, 35.92187057222639, 95.22037860325405, 84.668274470738, 93.08687169211251, 85.74792725699288, 71.11915520259312, 65.7058275767735, 36.77892739432198, 37.18585559300014, 44.62181077684675, 35.11175230571202, 49.52657890319824, 71.979001726423, 63.467493193490164, 60.14237717219761, 57.855273383004324, 47.371421405247276, 17.30146438734872, 1.1841992906161716, 0.14743453157799585, 0.16675388919455664, 0.39297618876610485, 0.21602530245270046, 0.24273803191525595, 0.6630745168243135, 0.7402697631290981, 1.0266714692115784, 1.3326115097318376, 3.425038282360349, 5.36836713552475, 11.6570257799966, 9.64242252281734, 11.874342850276403, 16.322228704180034, 20.945570468902588, 24.30633248601641, 11.549016901424952, 5.039866728442056, 1.6101586052349635, 3.913114709513528, 2.6327364998204366, 4.460130751132965, 11.68599455697196, 13.784738762038094, 9.2554669209889, 13.739542467253548, 15.947908401489258, 17.087511982236588, 15.117360694067818, 12.074911287852697, 17.092189856937953, 23.15883227757045, 51.65347807747977, 73.74171107155937, 88.43833923339844, 86.80162852151054, 88.47184344700405, 90.7984060559954, 83.25888102395194, 80.76870918273926, 45.13260064806257, 21.17485407420567, 10.061242563383919, 5.863910921982356, 11.885475601468768, 17.8492933682033, 7.8059241771698, 12.723353658403669, 13.709665213312421, 20.08166446004595, 17.472914661679948, 15.749811785561697, 15.384974036897932, 10.835261464118958, 11.481953757149832, 11.162790860448565, 7.645028216498239, 6.078169482094901, 1.7336706519126892, 1.4424434219087874, 0.42068004075969967, 0.6386860683560371, 0.28244405559131075, 0.7249498537608555, 1.3449089527130127, 0.4262557258563382, 0.5824581512383052, 0.13899309454219683, 0.17389814369380474, 5.086682387760707, 28.40687789235796, 45.614392212459016, 55.04208326339722, 61.38415922437395, 50.59826905386788, 42.63474757330758, 34.17297077178955, 21.6009749344417, 25.02119963509696, 35.19517237799508, 44.71056359154837, 57.85883780888149, 76.19545350755963, 78.38517134530204, 95.9686301095145, 69.89064420972551, 5.951730506760733, 0.1712787678199155, 0.17862879484891891, 0.13593820775193827, 0.11802972799965314, 0.1293467828737838, 0.2575070522725582, 0.11446526141038962, 0.10871565421777112, 0.13034764916769095, 0.29847314261964386, 0.24086535668798856, 0.14684428753597395, 0.27960216094340595, 0.3787574331675257, 0.26293473531092915, 0.2545921743980476, 0.13277843301849707, 0.22549579212708132, 0.10945562379700796, 0.2890984485191958, 0.17669802345335484, 0.22710845273520264, 0.21087036335042544, 0.14657993029270852, 0.15772436585809502, 0.1610236202499696, 0.26487678395850317, 0.14311486908367702, 0.16672843056065695, 0.12187467382422515, 0.08931835328361817, 0.1757403662694352, 0.15618638481412614, 0.28141634645206587, 0.12094580009579659, 0.11363571163799081, 0.29458326420613695], [0.23875161153929575, 0.021630980540066957, 0.016060947640133754, 0.061742941183703284, 0.13374264485069684, 0.024285078747197986, 0.05392516943226967, 0.07913295232823916, 0.03587772910084043, 0.10834705363959074, 0.04560584495110171, 0.20206934346684388, 0.03409605559759906, 0.038845824476863654, 0.04791039414703846, 0.04144601138042552, 0.026657924189099243, 0.06272335643214838, 0.1054673238790461, 0.05784375326974051, 0.07892540882208518, 0.1837359515151807, 0.1430620654885258, 0.31609380138771875, 0.10903345287910529, 0.10322193615138531, 0.08666703876640115, 0.09706889917807919, 0.12203498450773102, 0.2232773761664118, 0.08904866275510617, 14.67002350943429, 68.91805621555874, 63.893723487854004, 73.3144177028111, 61.09798376900809, 49.105719566345215, 37.56785018103463, 30.749648911612375, 25.291590520313807, 16.17783124106271, 40.40787076950073, 51.301412854875835, 33.632668427058626, 45.38626895632063, 72.31545434679303, 45.68267216001238, 22.493431091308594, 6.72121353660311, 0.2376143325652395, 0.03890387314770903, 0.058883804960974624, 0.04682322159143431, 0.08089130797556468, 0.14248274586030416, 0.32885701794709477, 0.636633364217622, 1.1278849009956633, 1.0571414913449968, 3.3758880283151353, 1.0271781448807036, 3.421380272933415, 3.0490163224084035, 2.1983770302363803, 0.5241363836186272, 3.5714750417641232, 3.495538613625935, 3.9114805800574164, 3.7467618073735918, 3.3300566247531345, 3.736907958984375, 8.280654634748187, 15.739316531590053, 16.728413445608957, 21.704011508396693, 26.622104542596, 30.535863263266428, 32.1161858694894, 41.7320237159729, 51.27790709904262, 50.09657784870693, 48.90941558565412, 49.43028729302542, 55.80590220860073, 69.19808946337018, 59.707781246730256, 47.99315663746425, 52.337236404418945, 48.09909929547991, 54.10458367211478, 55.54130090985979, 70.2687999180385, 52.180481570107595, 38.71716560636248, 28.002105372292654, 30.07932492664882, 23.10101284299578, 24.51661797932216, 21.33214565685817, 17.030262299946376, 12.505542397499084, 12.559680155345372, 6.527311895574842, 8.87596413067409, 4.605580432074411, 2.856213365282331, 3.154014676809311, 4.539896505219596, 1.8309669281755174, 0.9920443615743092, 2.444710646356855, 2.0171395667961667, 0.7394819568310464, 0.4072329151843275, 0.30887820571660995, 0.18598661145993642, 0.016658901536305035, 0.13299063806022915, 0.08548004353152854, 0.037600186853004355, 0.14672330474214895, 0.11683185584843159, 1.549168512225151, 11.472723943846566, 35.07954740524292, 55.34890876497541, 50.21300881249564, 54.32096447263445, 35.741151400974815, 43.543835980551584, 21.913190501076834, 10.791886465890066, 27.67687061854771, 56.26869739804949, 61.51341656276158, 69.81032998221261, 59.43229906899588, 68.73768098013741, 53.86058030809675, 9.245128870010376, 0.19341187445180757, 0.0532335590438119, 0.022313211878229464, 0.028210575160171305, 0.06501345961753811, 0.05251676482813699, 0.051604742516896555, 0.04475899253572736, 0.08067571025873933, 0.08933058727000441, 0.006634793443871396, 0.09582183323800564, 0.027806052938103676, 0.23138383403420448, 0.008405088763018804, 0.045213577071470876, 0.08613002579659224, 0.03272852594298976, 0.1538167233977999, 0.03872258894677673, 0.042196057204689295, 0.08305906451174191, 0.048741056716867855, 0.13753024089549268, 0.2002440435545785, 0.2640652832176004, 0.13258275708981923, 0.0766085713569607, 0.03913437488621899, 0.03817018341006977, 0.08540278553430523, 0.06805945081370217, 0.049804399122617075, 0.07416921082351889, 0.0388700006795781, 0.09759297248508249, 0.2354764315698828, 0.04013931239023805, 0.011307343341676252, 0.11592283605464868, 0.09167316156838622, 0.08102922700345516, 0.054479593610657115, 0.03672757724832211, 0.020771232566663196, 0.11189669423869678, 0.10436497588774987, 0.0951636339138661, 0.13918600204799855, 0.07424970543278114, 0.06551116505371672, 0.05486791241647942, 0.07727822435221501, 0.05041213919009481, 0.07899732674871172, 0.024497221024440866, 0.016258811844246726, 0.10788767186126538, 0.07777571944253785, 0.026417695651096956, 0.040470057499728034, 0.2352212481200695, 0.016904095254306282, 0.09759006156985249, 0.022193749002846222, 0.19529399488653454, 0.015331480086648037, 18.24191870008196, 82.49638571058, 74.28678335462297, 80.52208287375313, 66.42440332685197, 58.07653876713344, 46.67174822943551, 42.382670402526855, 27.34102075440543, 23.614781754357473, 45.6593679019383, 49.50361510685512, 29.30905110495431, 45.41397837230137, 57.71108089174543, 41.00271299907139, 23.91213686125619, 8.465580071721758, 0.40686335787177086, 0.09075863207025187, 0.09969970836703267, 0.05864647376750197, 0.2792518740253789, 0.7654701194592884, 1.0394423667873656, 1.4616461800677436, 2.1234294176101685, 2.3374691094670976, 3.0683822546686446, 3.73766314131873, 2.245884903839656, 2.171226075717381, 5.283885291644505, 5.488692130361285, 3.427363540445055, 2.35278901883534, 4.140186616352626, 3.546384010996137, 4.254626052720206, 4.6008239558764865, 8.409799933433533, 14.950603927884783, 17.53052043914795, 22.535761254174368, 30.496644156319753, 33.10408769335066, 37.12002141135079, 49.087178298405235, 54.958277566092356, 53.98805890764509, 54.72387661252703, 58.05277245385306, 63.593867029462544, 77.52365030561174, 72.5195368358067, 60.78658635275704, 60.52632767813546, 56.82498754773821, 62.21806812286377, 68.7376184463501, 81.3830133165632, 62.57669939313616, 42.220794745853965, 30.89679786137172, 31.201702186039515, 25.21351534979684, 24.84405878611973, 20.872855833598546, 19.97958152634757, 14.278786948748998, 11.796204277447291, 7.98171968119485, 2.368980492864336, 2.136843349252428, 1.640342122742108, 1.9556123997483934, 2.934668732540948, 3.041553957121713, 3.5480696005480628, 3.618681537253516, 5.039900600910187, 2.969583213329315, 2.703087879078729, 1.1439944079944064, 1.2762392546449388, 0.7889022135308811, 0.45256985670753885, 0.2520436511508056, 0.185484183420028, 0.12119102265153613, 0.09488674412880625, 1.7106241285800934, 12.581503578594752, 35.33745411464146, 45.97497592653547, 42.04803821018764, 42.43309000560215, 27.359372683933803, 32.100069522857666, 28.491962058203562, 17.754660640444072, 36.43086086000715, 61.84101022992815, 71.94798496791294, 81.04442759922573, 67.90541185651506, 77.33098370688302, 68.92766557421002, 12.450317246573311, 0.23136279944862637, 0.054018671557839425, 0.040690767977918894, 0.029139401391148567, 0.058679016306996346, 0.016307656187564135, 0.06635009218007326, 0.022784888711092726, 0.0942983389166849, 0.0609900862244623, 0.037221001128533056, 0.05040598148480058, 0.054835746463920386, 0.20741959208888666, 0.04181112428861005, 0.07548329566738435, 0.0358199111319014, 0.04797880404761859, 0.08122619214866843, 0.07763512020132371, 0.041609446717692275, 0.10464085465563194, 0.12928203706230434, 0.19957968991781982, 0.15853814647666045, 0.292011019374643, 0.08070106711238623, 0.06940976942756347, 0.04028834242905889, 0.03488142934760877, 0.045135935701962025, 0.06528006959706545, 0.05124114613447871, 0.06160787200289113, 0.029218060563185384, 0.13387250288256577, 0.5110713275415557, 0.09682454514716353, 0.10529089120349713, 0.2516370458262307, 0.32904711631791933, 0.20240217846419128, 0.15683457574674062, 0.1763419011341674, 0.06969152430870704, 0.37225720339587753, 0.26511380981121746, 0.27087964756148203, 0.45182881504297256, 0.25474278203078676, 0.18303047865629196, 0.15081339169825825, 0.11550103154565607, 0.16510335276169436, 0.19133205605404718, 0.16862807076956543, 0.12371578360242502, 0.30232724866696764, 0.269413523375988, 0.4280030349535601, 0.23941928999764578, 0.3492485966001238, 0.1637260080980403, 0.21218357288411685, 0.21138809914035456, 0.3254315017589501, 0.16471348011067935, 26.756286416734966, 92.59967790331159, 80.65327181134904, 92.3539548601423, 79.5747376850673, 67.25344153812954, 53.42860732759748, 45.1206636428833, 35.779991831098286, 23.95945061956133, 55.729364327022004, 66.64090919494629, 47.09980590002877, 59.809440340314595, 92.83720902034214, 63.60334437234061, 34.89505883625576, 11.583434803145272, 0.5601231668676648, 0.1252450793981552, 0.5071464095796857, 0.2886695872460093, 0.3173697186367852, 0.9667601925986153, 1.140098205634526, 2.1259353288582394, 3.919808864593506, 4.541454638753619, 9.60578727722168, 4.1203130313328336, 12.321785994938441, 9.519624403544835, 13.267382843153817, 12.852079459599086, 12.615024294172015, 11.05098044872284, 12.411488975797381, 13.165075830050878, 11.325856396130153, 8.066343528883797, 11.35666731425694, 20.966111080987112, 24.436772755214147, 31.191064493996755, 39.476291043417795, 37.2035630771092, 41.353798525674, 53.94192634310041, 61.71649156297956, 58.32836927686419, 58.844300815037315, 61.22246074676514, 66.97093473161969, 79.08581379481724, 74.01150962284633, 63.760088784354075, 66.74314498901367, 63.07717118944441, 69.12094361441476, 74.86706215994698, 85.26922416687012, 69.02390507289341, 50.077518939971924, 36.46290247780936, 36.75079066412789, 32.33266741888863, 33.01012372970581, 27.843851464135305, 25.14698461123875, 16.99888597215925, 17.936192750930786, 12.11493638583592, 17.7854220526559, 11.62809521811349, 7.86401459148952, 8.307163749422346, 11.472199354852949, 12.01358996118818, 7.816996131624494, 8.492003202438354, 6.7215739744050165, 3.9761331336838857, 2.795735159090587, 1.0277907805783408, 1.3040108787161964, 0.9180230306727546, 0.7746323506746973, 0.8555432004587991, 0.4786754601768085, 0.37203787373644964, 0.40976157092622345, 2.473614283970424, 16.73880100250244, 49.895486559186665, 76.02222796848842, 73.13250691550118, 77.99048587254116, 51.69416325432913, 65.18336473192487, 32.03603492464338, 16.80748220852443, 40.288636207580566, 72.0147293635777, 77.45934472765241, 88.68006011417934, 77.31300176892961, 86.05593395233154, 78.86543083190918, 14.504706757409231, 0.4062958854649748, 0.12466335775596754, 0.21796003649277346, 0.1397405687187399, 0.22738552572471754, 0.1519602108746767, 0.15442918267633232, 0.11916516135845866, 0.21262064443102904, 0.25986987405589645, 0.19366420805454254, 0.16373416408896446, 0.18131355435720511, 0.5215552364076886, 0.1962689140013286, 0.10605245176702738, 0.1094440615602902, 0.08596586103418044, 0.27823141164013315, 0.16053854913583823, 0.1964999958872795, 0.17387938898588928, 0.3520688595516341, 0.2529569592859064, 0.2989052065781185, 0.47538407679115025, 0.35424633270927836, 0.17281430613781723, 0.1644293503569705, 0.15811450992311749, 0.18183578204895767, 0.22075455582567624, 0.15155364626220294, 0.16137024307889597, 0.16817364229687623, 0.41854566814643995], [0.06839463354221412, 0.10460536727415663, 0.09937880201531307, 0.033909119199961424, 0.05135804754016655, 0.01059740996320865, 0.027455609957022325, 0.020457844382950237, 0.028725868224033287, 0.0358271409225251, 0.0848809921049646, 0.08625999917941433, 0.07980964173163686, 0.034413477671997886, 0.04655225880976234, 0.10030427628329822, 0.01557167639423694, 0.0640797818611775, 0.051128685740487914, 0.0412011823749968, 0.07022256617035184, 0.04189864173531532, 0.041442048735916615, 0.08537590197686638, 0.03445179115182587, 0.1067294804379344, 0.09497111995837518, 0.04086032370105386, 0.033330623991787434, 0.13940086694700377, 11.104987927845546, 64.47325883592877, 63.34453092302595, 74.41169112069267, 58.240422453199116, 58.73161493028913, 40.45978076117379, 29.331191539764404, 26.08524329321725, 32.5894068309239, 35.45685543332781, 32.74790913718087, 33.5990252494812, 53.92106785093035, 49.22490896497454, 28.65626958438328, 18.855965750558035, 4.540137520858219, 0.370343626077686, 0.10142147740615265, 0.08684064873627254, 0.08427630205239568, 0.06945585552603006, 0.44570107385516167, 0.8687091139810426, 0.6133042446204594, 1.1644883368696486, 1.748995121036257, 2.295710001673017, 1.5309071264096668, 2.9517660779612402, 4.917465959276472, 3.3040525572640553, 4.1615336537361145, 2.153483416352953, 8.023217797279358, 6.18963726077761, 9.497680255344935, 11.22065806388855, 18.06551957130432, 28.301869767052786, 34.84635196413313, 47.60119138445173, 45.13294805799212, 49.869743483407156, 53.915266105106895, 51.26055744716099, 57.65659659249442, 58.28095824377877, 54.49580546787807, 59.05704770769392, 57.51890066691807, 53.117380142211914, 38.11916889463152, 47.18129437310355, 43.30373750414167, 46.292129925319124, 48.85622017724173, 53.149845600128174, 56.41524880273001, 52.91794599805559, 42.48790781838553, 30.675209386008127, 44.273000785282676, 46.191415786743164, 54.61389010293143, 50.38234683445522, 48.169488021305625, 42.881196703229634, 37.74968801225935, 38.22919361931937, 35.689675671713694, 28.718205826623098, 15.176222358431135, 6.860135384968348, 3.323867951120649, 1.7341499690498625, 1.4937409950154168, 0.34295716562441414, 3.0045146303517476, 3.1375298585210527, 3.5888752852167403, 1.8103464118071964, 1.5735322620187486, 0.4519422932394913, 0.4876292997172901, 0.40486702642270495, 0.19681524325694355, 0.19398980986859116, 0.10470051145447151, 0.10069655773362943, 0.061575288751295636, 0.025497965182044675, 0.06325415402118649, 2.6676852873393466, 23.54462058203561, 44.550313813345774, 35.46917806352888, 45.62268141337803, 32.340935775211875, 16.67195585795811, 31.14579698017665, 18.41521372113909, 32.11306265422276, 31.68290662765503, 34.768101351601736, 55.42035709108625, 63.38222490038191, 66.20566013881138, 54.362427847726, 10.06494334765843, 0.300994198769331, 0.09312576255095856, 0.0636984451806971, 0.04497837308528168, 0.06504032960427658, 0.022756057758150355, 0.0347583634512765, 0.07551699171641044, 0.09957054922623293, 0.023550081133310283, 0.027447180855753164, 0.017983245829652463, 0.14352755408201898, 0.04144925817048975, 0.005434708420320281, 0.0407567826498832, 0.04790658078023365, 0.031482091040483544, 0.07217746627117906, 0.050363243956651, 0.055655433729823144, 0.04837720249114292, 0.16332864442041942, 0.24948988961321966, 0.15356719893004211, 0.05894268822989293, 0.053035945897655826, 0.052465063852391074, 0.05419780480276261, 0.08678021162216153, 0.12253976027880396, 0.04992288490757346, 0.02513181072260652, 0.0341366014576384, 0.047358097175934484, 0.07397022364395005, 0.03685340478218027, 0.03957592137157917, 0.040066481834011416, 0.0453742134517857, 0.027800524574039236, 0.052775032219610045, 0.07427662291697093, 0.033385042500283034, 0.07282934843429498, 0.06828410018767629, 0.04393281847504633, 0.08368966103132282, 0.10208024669970785, 0.025627841873626624, 0.02784473113050418, 0.051625339447387626, 0.012486750010534056, 0.029989286858056272, 0.07791933816458498, 0.025840739021077752, 0.019335839232163768, 0.13534121907183103, 0.10005625137793166, 0.05632799085495727, 0.028360938520303795, 0.14065736452383654, 0.040307975839823484, 0.059912966165159426, 0.03485341263668878, 15.636498825890676, 75.59585176195417, 73.44024957929338, 81.5904517854963, 68.93464851379395, 67.67941474914551, 51.751541478293284, 39.39898191179548, 36.881712096078054, 36.093254838671, 24.862118891307286, 32.72187771115984, 38.93974767412458, 48.936666420527864, 44.65227862766811, 33.67923525401524, 19.316111939293997, 6.100670788969312, 0.3417344998036112, 0.07627216726541519, 0.14179982750543527, 0.06458742105002914, 0.16718925083322184, 1.064688320670809, 2.281418425696237, 1.877066271645682, 2.453928517443793, 1.5604858249425888, 2.1727946315492903, 2.5629722433430806, 4.082125297614506, 3.9117876035826544, 3.826706043311528, 3.2228126994201114, 4.881146422454289, 5.346233214650836, 5.817011884280613, 8.562272071838379, 11.886307648250035, 18.19617870875767, 28.124202592032297, 36.15023701531546, 48.090580804007395, 49.647421973092214, 53.05417932782854, 56.07105588912964, 55.30882808140346, 59.718481472560335, 61.72167491912842, 62.921830313546316, 62.99076339176723, 59.61247975485665, 55.5847202028547, 44.77792985098702, 54.59668288912092, 50.200797353472026, 50.468598297664094, 56.20668819972447, 58.599293436322895, 63.002700396946494, 59.61043698447091, 48.57710409164429, 35.885618346078054, 49.73973573957171, 51.787324701036724, 56.65603167670113, 52.98770243780953, 51.11477729252407, 45.513546058109824, 42.266621589660645, 41.24167891911098, 35.86261633464268, 31.98720645904541, 16.246818167822703, 7.566064545086451, 3.856488193784441, 2.515295658792768, 1.9837341478892734, 1.696753352880478, 3.8458461591175626, 5.499526109014239, 4.888252692563193, 3.4114829983030046, 3.452895781823567, 1.1913703743900572, 2.5031567215919495, 1.0545644696269716, 1.112215084689004, 0.9463646241596767, 0.24456130979316576, 0.17753654345870018, 0.03694198074351464, 0.06953546803976808, 0.0817901361733675, 2.7926990134375433, 25.4048079422542, 43.99288068498884, 38.99230037416731, 44.12429543903896, 33.84318494796753, 12.147307174546377, 24.84899721826826, 26.489194188799175, 45.01983485903059, 45.80206305640084, 47.04089559827532, 61.10574490683419, 72.13177871704102, 75.40669400351388, 71.99222414834159, 15.328026601246425, 0.38730016191090855, 0.08570845877485615, 0.021263631858995984, 0.026856008917093277, 0.08964620104857854, 0.0612966279898371, 0.09092274933521237, 0.04799931276855724, 0.007386550872719714, 0.03348458358751876, 0.1153493518275874, 0.10483334146972213, 0.13180154615214892, 0.03314182162284851, 0.025419012543612292, 0.09804501929985625, 0.05014441980581198, 0.10396179037966899, 0.07144254499248096, 0.07086095227194683, 0.02474154282494315, 0.026746802098516907, 0.13472094306988375, 0.19755062593945436, 0.12119622022977897, 0.0942484869488648, 0.04655998053827456, 0.02086745052864509, 0.018304572873083607, 0.09034392503755433, 0.12101902759500913, 0.025739672926387618, 0.08359983656555414, 0.049624092012111626, 0.02894957782700658, 0.21386467053421906, 0.22788883586015019, 0.207461593406541, 0.18582889278020176, 0.14895421931786196, 0.14388924038835935, 0.18513943334775312, 0.19901296389954432, 0.15952445140906743, 0.22028677378382, 0.17250576269413742, 0.212252674890416, 0.1890062958534275, 0.2815850302577019, 0.20731729614947522, 0.15492489321955613, 0.14636665316564695, 0.09083052964082786, 0.20318119094840117, 0.2058261340217931, 0.2704515191061156, 0.12471793911286763, 0.19985688504363808, 0.26250117857541355, 0.18081620175923618, 0.22865275772554533, 0.3534473441541195, 0.22305164113640785, 0.20502339995333127, 0.22701106938932622, 25.25261286326817, 88.82105990818569, 79.95352567945207, 93.54919787815639, 75.3923807144165, 76.91225746699742, 55.82918562207903, 43.29055677141462, 41.27378307070051, 45.768503257206504, 48.1763458933149, 43.590739795139854, 47.49250418799264, 72.19023391178676, 65.7116710117885, 40.00772053854806, 29.675572054726736, 8.03311550617218, 0.903721303812095, 0.2931110332054751, 0.6362040415406227, 0.25774483808449333, 0.35460921323725153, 1.1882835286004203, 3.4693347854273657, 2.078712982790811, 5.61009018761771, 5.6999868495123724, 8.26891825880323, 6.185761034488678, 9.781291825430733, 12.742914574486868, 9.721470441137042, 10.306697232382637, 10.083762543542043, 18.187069620404923, 14.870670114244733, 18.074055433273315, 17.899025099618093, 24.854104144232615, 38.27480159487043, 42.047850608825684, 55.80455078397478, 52.656815324510845, 58.754752431597026, 57.71754619053432, 60.45442771911621, 64.1587277821132, 61.76889487675258, 65.6045367377145, 70.92726680210659, 63.70254380362374, 59.97420992170061, 50.78001308441162, 59.20319611685616, 57.10321773801531, 57.33199412482125, 62.427709170750205, 63.91387326376778, 70.285642351423, 67.37650803157261, 57.71343633106777, 42.16886043548584, 56.931128229413716, 55.19978305271694, 59.39571680341448, 57.11293131964547, 55.99182905469622, 49.444197586604524, 43.47098759242466, 44.306831564222065, 43.09457240785871, 34.38972677503313, 19.295844044004166, 10.697502136230469, 7.048065917832511, 4.6455060839653015, 5.589686368192945, 3.8361542906079973, 11.31581016949245, 10.576027648789541, 12.147428768021719, 10.678966079439435, 6.470615463597434, 3.630004061119897, 3.7340461696897234, 1.8048166228192193, 0.9783292689493724, 1.0410505490643638, 0.3295102300388472, 0.24569044634699821, 0.15696869497852667, 0.23047945541994913, 0.25446254706808497, 4.928922235965729, 34.663037640707834, 61.6117057800293, 51.29931102480207, 63.505722182137625, 47.11727714538574, 25.89933729171753, 43.71125282560076, 28.48031861441476, 44.54590170724051, 48.212698868342805, 49.13635764803205, 73.79824161529541, 80.66746003287179, 84.08397265842983, 82.17080007280622, 18.35437876837594, 0.5575343114989144, 0.16059899303529943, 0.1288138750408377, 0.1487526944173234, 0.14078680186399392, 0.1834480491067682, 0.12070644008261816, 0.17544547495033058, 0.2159714132015194, 0.17626686873180525, 0.20620398303227766, 0.26369792435850414, 0.29084320632474764, 0.09081994449453694, 0.0861435422141637, 0.2318589985370636, 0.15450753990028585, 0.13242018009935105, 0.1446411521839244, 0.16572197313819612, 0.13076216621058329, 0.15163882954844407, 0.295728359903608, 0.3661812480006899, 0.20540876713182243, 0.21828424052468368, 0.2602999024093151, 0.20749832929245063, 0.10434573941997119, 0.16953669701303753, 0.22187557710068567, 0.15101807857198374, 0.13397338746913842, 0.1949666967349393, 0.17422284984162875], [0.009351546726455646, 0.10204754809715919, 0.05804326970662389, 0.07107596644865614, 0.08188804877655846, 0.03682263661175966, 0.09249807016125747, 0.04853022910122361, 0.059577484881239276, 0.022400415502488613, 0.05592158569821289, 0.08771675279630081, 0.030447108005838733, 0.022015623382425735, 0.056736869271844625, 0.023591353025819575, 0.011615880000005876, 0.04429678465904934, 0.028550806189221994, 0.02187927346676588, 0.015875263139605522, 0.02487400982395879, 0.03410754319546478, 0.07116431170808417, 0.05185017202581678, 0.07230417590056147, 0.02989220546026315, 0.0363829391343253, 0.1381559180361884, 19.439409460340226, 67.42658369881767, 64.40413120814732, 73.0180561883109, 60.34588990892683, 58.735964502607075, 36.75590106419155, 18.686766692570277, 22.22098353930882, 24.634047746658325, 16.550353697368077, 47.548061983925955, 57.06945991516113, 47.969515391758506, 36.49863011496407, 20.291564328329905, 4.997174824987139, 1.091555267572403, 0.04392537155321666, 0.06520735778446708, 0.043063248707247634, 0.1134368194533246, 0.19504679100854055, 0.20165714701371534, 0.4025854659932, 0.3621366636029312, 0.7315140015312603, 1.3927861664976393, 1.077920513493674, 1.3428547829389572, 4.974932772772653, 14.417366164071218, 7.117906170231955, 13.27499372618539, 14.240865417889186, 21.14226528576442, 17.876526832580566, 23.264797517231532, 32.567064898354666, 47.15252535683768, 53.883992263248985, 57.66186332702637, 60.617043358939036, 59.57029724121094, 63.46435955592564, 66.22882543291364, 64.13850852421352, 67.02800028664726, 67.95789160047258, 75.7284094946725, 76.85651206970215, 73.12444700513566, 71.12553364889962, 69.61899743761334, 50.18862063544137, 30.72135237285069, 45.26032938276018, 43.316748006003245, 43.557676792144775, 45.276365825108115, 50.458214214869905, 42.424474239349365, 25.39525590624128, 29.02574872970581, 46.00630187988281, 57.610828808375764, 68.92523370470319, 67.1483222416469, 67.10318674360002, 63.24233681815011, 64.39659936087472, 52.78221641268049, 51.827773639133994, 52.1538074357169, 35.33982345036098, 26.32675572804042, 14.477296113967896, 10.021315608705793, 4.247232735157013, 2.7262340656348636, 1.625832547034536, 2.678730751786913, 4.788168234484536, 2.5711706834180013, 4.3362491471426825, 1.2728425626243864, 1.417843650494303, 2.07958476458277, 0.3971930124929973, 0.2885145827063492, 0.05658629556585636, 0.0650887702192579, 0.046453267335891724, 0.09803718900574104, 0.01067886215501598, 0.060509588436356614, 1.1944203078746796, 12.163773536682129, 37.34446212223598, 37.84332888466971, 38.97257096426827, 56.56126519611904, 29.427632536206925, 20.20627519062587, 39.329902921404155, 48.203926767621724, 35.75358172825405, 46.08730745315552, 53.169828619275776, 67.0493243081229, 66.29842553819928, 63.80988652365548, 8.208509751728602, 0.18892074615827628, 0.045264311134815216, 0.0514966315323753, 0.02933042256959847, 0.06856043357402086, 0.01521847686464233, 0.014101929679912115, 0.044150102351393015, 0.06732713510947567, 0.03715723580015557, 0.06616754590400628, 0.05424314790538379, 0.10311342483120305, 0.07486625627747603, 0.008035268518142402, 0.033153054770082235, 0.027533465065062046, 0.06313276410635028, 0.02523219828227801, 0.04919689654239586, 0.12590491399168968, 0.10259823354759387, 0.1499906544174467, 0.1328848408801215, 0.10692468817744936, 0.07728913519531488, 0.016389477332787852, 0.012539226212538779, 0.019643785565027168, 0.013357826126074153, 0.046238426185612164, 0.04351973992639354, 0.08162406472755329, 0.014625138702935405, 0.04271439349810992, 0.027616310798163925, 0.040594911335834434, 0.05155278030516846, 0.05259664536320737, 0.08637924492359161, 0.05811936062361513, 0.040600393898785114, 0.035459887236356735, 0.013229940086603165, 0.036940460825072866, 0.047341917508414814, 0.035063415832285366, 0.06315749670778002, 0.04539964833695974, 0.00908546261156776, 0.032593714605484686, 0.09486534991966826, 0.013110971693614764, 0.061459225336355824, 0.031704430002719164, 0.03666195273399353, 0.012420705652662685, 0.045602672799889526, 0.011864277251463915, 0.09162766579538584, 0.030204891360231807, 0.06125527128045048, 0.19164118303784303, 24.14235326222011, 79.52469675881522, 76.16699368613106, 80.58854239327567, 67.78759820120675, 65.96939359392438, 51.83627823420933, 33.472206728799, 32.22114883150373, 22.290260553359985, 18.86547957147871, 38.46165949957711, 48.237093993595664, 44.30121047156197, 41.03693287713187, 23.51111463138035, 6.36438923222678, 1.5623592329876763, 0.10199965709554297, 0.11095433801944767, 0.084095913517688, 0.2769825815090111, 0.9425959863833019, 0.9857578703335353, 1.243086793592998, 0.9814219772815704, 1.3709630689450671, 1.8412087900297982, 1.1597918974501746, 1.4250836734260832, 4.698758815016065, 9.277388487543378, 8.908249803951808, 13.968010527747017, 15.609755209514073, 17.332286596298218, 19.138154676982335, 25.37306683404105, 33.84690918241228, 49.27491167613438, 58.48940767560686, 62.46696649278913, 65.44924449920654, 63.10440117972237, 66.56108828953334, 67.99245194026402, 65.89176831926618, 69.58024733407157, 70.97222164699009, 78.18602902548653, 79.87459414345878, 78.2849713734218, 74.58163711002895, 72.99721159253801, 55.62087515422276, 39.616939953395296, 51.886635303497314, 48.76926694597517, 49.50342403139387, 51.491449560437886, 58.10380002430507, 50.25102240698678, 33.065024920872276, 34.7712037222726, 50.2328702381679, 59.594296319144114, 70.51007611410958, 69.98946843828473, 71.65561171940395, 65.96855981009347, 64.00465842655727, 56.244451659066335, 56.632821219308035, 54.28340251105172, 37.46677473613194, 28.48852096285139, 16.720806905201503, 10.502077102661133, 4.98225964818682, 3.1215353224958693, 0.41745260251419886, 2.1272209627287726, 6.421313217708042, 3.6373962930270602, 3.653042333466666, 3.8461792383875166, 2.930115274020604, 3.7819331543786183, 2.158254874604089, 1.1891992794615882, 0.43724394908973147, 0.3460274823009968, 0.12290848977863789, 0.043577201664447784, 0.06740049831569195, 0.06631558867437498, 1.1048406575407301, 13.159861207008362, 34.49483912331717, 37.4955472264971, 32.012053217206685, 32.86954777581351, 21.9722831930433, 11.66123378276825, 36.50130517142159, 46.91479621614729, 38.93192400251116, 54.29320294516427, 60.87566920689174, 75.62907109941754, 74.84370926448277, 80.63757583073208, 14.361874376024518, 0.26682865779314724, 0.04629149780209575, 0.04685943839805467, 0.10395708134663956, 0.024051705109221593, 0.05186234833672643, 0.028920974183295454, 0.04535300244710275, 0.031594636251351664, 0.025538317659603696, 0.009279481218462544, 0.07658971486879246, 0.06595520515527044, 0.018461757206491063, 0.058441128714808395, 0.0199857027535992, 0.0182228721678257, 0.010621294395865073, 0.031502928850906234, 0.024216439841049056, 0.21895038549389156, 0.16581785013633116, 0.1869544738105365, 0.11101918561117989, 0.07829272919999701, 0.08197952886777264, 0.013382894602338118, 0.029770666267722845, 0.025366246267887096, 0.037349932960101535, 0.026603261407996927, 0.09342753421515226, 0.09369613908763443, 0.002819109654020784, 0.2545930700642722, 0.17097994099770272, 0.24177429505756923, 0.1467352605291775, 0.23942843664969715, 0.15985371731221676, 0.26011797360011507, 0.18306272264037812, 0.12559613984610352, 0.11478633061051369, 0.1138799571033035, 0.146080881357193, 0.2027928517865283, 0.14791287162474223, 0.18133275689823286, 0.08033523495708193, 0.10438940993377141, 0.12120525831622736, 0.10670190477477652, 0.18138170641447815, 0.09902763978711196, 0.1648173231099333, 0.1164799811584609, 0.1891853476741484, 0.13891184675906385, 0.23968514001795224, 0.07957920445395367, 0.2161640492933137, 0.4705180578998157, 32.81354876926967, 92.70569351741246, 83.86427061898368, 94.45832102639335, 77.33259568895612, 77.17826925005231, 51.9814886365618, 30.52050427028111, 33.46089506149292, 38.22070639474051, 26.34432077407837, 65.51396696908134, 73.76632159096854, 64.66640486036027, 51.72687884739467, 30.169363158089773, 9.490589618682861, 2.2233243201460158, 0.41784582712820595, 0.29251560515591074, 0.19447452814451285, 0.4641419457537787, 1.3708070601735796, 1.7028485515287943, 2.141211811985288, 2.1791307372706274, 2.387257946389062, 4.0983211142676215, 5.18102719954082, 4.4501731140272955, 10.241296444620405, 22.01614543369838, 10.87441803727831, 21.64230455671038, 21.192085606711252, 31.0984172139849, 21.700542620250157, 30.07086549486433, 39.03877340044294, 54.544943128313335, 62.39674799782889, 66.17206559862409, 66.81184877668107, 61.72398172106062, 65.29581437792096, 69.90108040400914, 67.6489816393171, 73.35033988952637, 73.94923291887555, 81.00034127916608, 81.15467466626848, 79.29075091225761, 77.40387725830078, 75.18038422720772, 58.55522796085903, 44.05717931474958, 58.21436323438372, 54.83814321245466, 55.62972368512835, 58.06117977414812, 65.01021562303815, 56.915991578783306, 37.32974583762032, 41.48074211393084, 55.52006026676723, 62.27178464617048, 76.10159029279436, 73.40709277561733, 73.99359716687883, 68.95151179177421, 67.57507365090507, 56.72964089257376, 57.278996740068706, 56.09825808661324, 37.83797877175467, 31.065944807870046, 19.355669770921978, 13.230947358267647, 7.71275578226362, 6.283613818032401, 5.639144080025809, 9.120993222509112, 14.525338564600263, 10.159325071743556, 10.943982533046178, 7.370460595403399, 5.977456212043762, 6.418846607208252, 2.87735629933221, 1.0138171932526996, 0.30144805727260454, 0.26034064165183474, 0.15886643528938293, 0.17636080511978694, 0.1436505860516003, 0.18339542193072184, 1.8520924917289188, 19.846808399472916, 51.41661398751395, 53.12383154460362, 55.79870734895979, 80.66619546072823, 44.02153505597796, 32.178737027304514, 50.836543628147666, 57.56324407032558, 46.2727826663426, 60.16759218488421, 72.02053805759975, 85.58513791220528, 84.24387850080217, 90.19354452405656, 17.506510938916886, 0.4321233710008008, 0.14970360696315765, 0.1364273229347808, 0.2611702728484358, 0.1684074518936021, 0.11197380974356617, 0.06762219606233494, 0.1318351472062724, 0.30160216614603996, 0.16520074967827114, 0.12180243698613984, 0.16401308269373008, 0.244081938373191, 0.1777952824320112, 0.12999643944203854, 0.1535142867692879, 0.08158485897417579, 0.10694275077964578, 0.13669111020863056, 0.14299945027700492, 0.314637583813497, 0.22994729397552355, 0.43420807485069546, 0.38742346529449734, 0.2511952109634876, 0.23134328478149005, 0.19496854235019, 0.11275232689721243, 0.10765304123716694, 0.16689255461096764, 0.1853518555206912, 0.16634135347391876, 0.13549528723316534, 0.11730645038187504], [0.061980062031320164, 0.12322954540806157, 0.056377048936805556, 0.09070683949227844, 0.03470925787197692, 0.05404066287779382, 0.01611968332768551, 0.02245612831653229, 0.06503688264638186, 0.08470969593950681, 0.06956400722265244, 0.01320717269222119, 0.00899931919827525, 0.06110823952725955, 0.03869224486074277, 0.02724727086855897, 0.05532902445910232, 0.024589303315484097, 0.045794090921325345, 0.0186068754909294, 0.043074040806719234, 0.0657650050041931, 0.04249520293836083, 0.03515684331900307, 0.04810282667832715, 0.026065098321331397, 0.12910443730652332, 0.09329726227692195, 12.238930463790894, 66.13421181270054, 60.379088401794434, 74.28287151881626, 62.074573925563264, 53.20469120570591, 30.816844940185547, 20.178725583212717, 23.870166267667496, 26.36829900741577, 30.17010314123971, 27.670995916639054, 45.01654141289847, 49.52474110467093, 31.722976888929093, 15.659787450517927, 2.151459753513336, 0.05979036167263985, 0.035010527420256815, 0.0318671698415918, 0.027042991115844676, 0.02925049453707678, 0.30828576322112766, 1.1770083393369402, 0.5156050814049584, 0.7362425220864159, 0.6038814016750881, 1.4056499962295805, 1.0162236584084374, 4.165709955351693, 12.77546341078622, 34.65284810747419, 38.152607100350515, 44.01417691367013, 39.325984137398855, 46.42405537196568, 45.49710314614432, 52.38611003330776, 61.86043044498989, 65.59059170314244, 66.39201777321952, 70.14189801897321, 70.50907557351249, 68.99222823551723, 66.25341510772705, 64.82373986925397, 63.09645938873291, 67.67566272190639, 65.09600503104073, 61.16367898668562, 64.82698467799595, 67.58277225494385, 69.01872866494315, 69.55789497920445, 69.29516274588448, 73.79903370993478, 37.938279492514475, 33.89924648829869, 53.8011280468532, 46.47791085924421, 49.98857504980904, 43.46959447860718, 30.29106433050973, 35.72808183942522, 55.71892465863909, 59.757766587393625, 68.92586599077497, 62.28194291251046, 61.335146631513325, 62.602650914873394, 65.73883846827916, 60.4388290132795, 61.40790121895926, 56.90757383619036, 62.05934347425188, 57.29850033351353, 53.94688040869576, 42.78269209180559, 31.956651755741664, 12.944363696234566, 6.933647760323115, 2.640563211270741, 4.422037252358027, 3.008441013949258, 3.6533315522330145, 2.774841925927571, 0.4713146580117089, 3.1403695004326955, 1.3875415793487003, 1.2815924073968614, 0.8668270206877163, 0.2998429691152913, 0.28073930421045845, 0.039217997541917224, 0.18248801705028328, 0.012750582237328802, 0.031120628650699343, 0.04123489199472325, 0.17817157081195287, 6.622785789625985, 32.06216709954398, 49.46493101119995, 52.41367701121739, 49.25847918646676, 53.03008644921439, 106.22922951834542, 128.46655000959123, 80.3830702645438, 37.98079899379185, 46.89008147375924, 46.25324780600411, 61.8232158933367, 68.79727567945207, 61.34004511151995, 8.434241090502058, 0.2272042211677347, 0.0313138313192342, 0.01614136591420642, 0.03740194945463112, 0.08487046124147517, 0.030601919163018465, 0.04023523688582437, 0.04015264899602958, 0.037422424248818836, 0.03539580638919558, 0.08539473810898406, 0.0416404082705932, 0.05079330962949565, 0.023769061347203593, 0.026697131638814296, 0.05979940654443843, 0.05191272956186107, 0.0706142708659172, 0.03396609578547733, 0.06242781371942588, 0.08180953548955065, 0.16230945768100874, 0.04626482119783759, 0.07232331058808736, 0.0448448713203626, 0.04900303230221782, 0.10111931219164814, 0.017201205382921865, 0.011852807465142437, 0.02069982184496309, 0.06546950300357171, 0.040385841125888486, 0.0680576323398522, 0.04316761417846594, 0.011580778535322418, 0.09093043035162346, 0.03906138487426298, 0.023499840704192008, 0.04284475703856774, 0.03536254120990634, 0.03410553812448468, 0.02984833138595734, 0.029123900258647542, 0.047402999230793545, 0.02454335631669632, 0.04060906896899853, 0.08203190498586212, 0.034506172340895445, 0.024807839088940194, 0.024867684181247438, 0.04053140724343913, 0.021495650123272623, 0.06167177643094744, 0.01826009150993611, 0.0072317159668143305, 0.060165910449411185, 0.0641487210190722, 0.06429233295576912, 0.020696223913026706, 0.15418432652950287, 0.06384703077908073, 15.315042155129568, 78.8936127253941, 71.18601771763393, 81.98408808026994, 72.89440604618618, 70.06706592014858, 48.06334039143154, 30.760099002293178, 23.590584652764456, 30.973023074013845, 38.1922014100211, 24.707094158445084, 41.07657929829189, 50.249295779636924, 35.65515007291521, 17.173984050750732, 2.1914153695106506, 0.07083731889724731, 0.04465167882985302, 0.027434609298195158, 0.1064665616889085, 0.19978170336357184, 1.2287324666976929, 2.641562883343015, 1.3712029989276613, 0.930571260196822, 1.4113820429359163, 0.8362384991986411, 0.9847492958818163, 5.3943542667797635, 14.908152171543666, 33.43882063456944, 39.050331728799, 45.11161708831787, 44.914767674037385, 46.38087926592146, 47.86666120801653, 55.405755451747346, 63.85653672899519, 70.31995950426374, 70.20642593928746, 73.38672760554722, 72.5569737298148, 73.24751349857875, 68.85883671896798, 67.5509842463902, 62.99605097089495, 68.7481449672154, 67.53821345738002, 64.12290981837681, 64.89460454668317, 70.11254187992641, 70.43176296779087, 73.80528708866665, 71.53593594687325, 75.78368241446358, 40.998738629477366, 40.0016165460859, 58.25645194734846, 51.69170706612723, 56.61204610552107, 49.976262841905864, 36.62448978424072, 38.51071378162929, 57.055886609213694, 64.28715133666992, 68.77057375226701, 63.338221958705354, 65.95098781585693, 65.2300774710519, 68.81092888968331, 64.14001628330776, 61.82284763881138, 59.82584503718785, 61.0115134375436, 59.97971289498465, 54.61843075071062, 45.289890493665425, 33.857706683022634, 14.28326506274087, 7.345810992377145, 2.009921691247395, 1.8640049610819136, 1.2919190589870726, 2.5522663721016476, 2.158870441573007, 0.1751625665596553, 2.8037245018141608, 2.1035306453704834, 1.4698318094015121, 2.2054841688701083, 2.148379747356687, 0.8551149634378297, 0.24578924104571342, 0.5299528943640845, 0.0962595222517848, 0.042234374077192376, 0.022223780962771604, 0.11859378058995519, 7.294556736946106, 30.54860625948225, 46.176289558410645, 50.55841418675014, 33.04168244770595, 41.399635791778564, 95.90624223436627, 112.87145028795514, 80.65844127110073, 46.389623573848176, 55.338139057159424, 52.43000527790615, 71.20382595062256, 76.1625815800258, 77.81662109919957, 12.659234813281468, 0.26933980733156204, 0.007315671104671699, 0.012624869206255036, 0.03212058910035661, 0.03074911715728896, 0.07008034523044314, 0.04935639637655445, 0.04906201735138893, 0.03700632621933307, 0.07122726618711438, 0.00861534895375371, 0.03941827393802149, 0.03154947296051042, 0.07213702558406762, 0.012891647971368261, 0.012005096168390341, 0.04845835527937327, 0.07931933232716151, 0.036090931589049954, 0.04661486045058284, 0.17448004175509724, 0.15096973973725522, 0.03055596198620541, 0.0793548875621387, 0.04442825760426266, 0.016992409979658465, 0.057346882431634834, 0.09118437208235264, 0.01992238186565893, 0.05697195790708065, 0.05244062302101936, 0.03075132578877466, 0.06202800053038767, 0.1299264281988144, 0.14659844072801725, 0.20172732110534394, 0.13482078271252768, 0.12330992466637067, 0.15139253490737506, 0.11783331925315516, 0.17592336716396467, 0.18476971318679197, 0.1640389213072402, 0.21167977420347078, 0.16855491112385476, 0.2019878514111042, 0.18749690827514442, 0.17648716191095964, 0.11926278897694179, 0.1526965435062136, 0.12989605697137968, 0.1675970639501299, 0.2544638498553208, 0.16594978448535713, 0.10802101756313018, 0.16741151176393032, 0.10178143344819546, 0.16101427003741264, 0.13569012177842005, 0.3385030174893992, 0.21345176840467112, 19.004460913794382, 93.33927195412772, 79.37685993739537, 94.37015533447266, 78.94423035212925, 72.49446078709194, 44.74933801378523, 33.87692192622593, 36.07702037266323, 41.987713950020925, 45.934214319501606, 41.7775239944458, 59.312678882053916, 68.89116668701172, 45.955298628125874, 23.389712231499807, 3.240624406508037, 0.18429084388273104, 0.12683380129081862, 0.13892083056271076, 0.18650269162442001, 0.47601310589483803, 1.826468403850283, 4.147253802844456, 2.2862098600183214, 3.5122016966342926, 2.5928125849791934, 5.070935598441532, 4.20497726542609, 7.2192282761846265, 16.417943613869802, 37.27118294579642, 41.57440383093697, 51.8705085345677, 48.24782548631941, 49.531727518354145, 50.148196016039165, 59.62687642233712, 69.05883366721017, 73.39780303410122, 72.11412334442139, 75.34432697296143, 77.15146309988839, 77.82562596457345, 69.62977409362793, 66.13692161015102, 63.480521065848215, 68.4185015814645, 69.03187465667725, 67.4253955568586, 70.49172592163086, 75.91058431352887, 73.31520284925188, 72.81234087262834, 73.89419623783657, 76.26893765585763, 46.44241598674229, 44.01001841681344, 65.30452047075543, 58.3538761138916, 61.89742265428816, 55.143394947052, 42.36216974258423, 44.37416655676705, 64.30848925454276, 68.87589454650879, 71.92489610399518, 66.23182010650635, 67.31680910927909, 65.49924373626709, 70.87443964821952, 65.91152204786027, 64.54514489855084, 59.128801754542756, 61.631306648254395, 61.62652628762381, 56.952761445726665, 48.91389717374529, 39.167155265808105, 18.149023021970475, 10.83458227770669, 5.8570408906255444, 9.645619562694005, 8.52565506526402, 9.400923984391348, 9.0698127916881, 4.225645550659724, 9.513886060033526, 4.3601987191608975, 5.797056223664965, 4.232552060059138, 2.0225224665233066, 0.5774135962128639, 0.14840371028653213, 0.41363540877188953, 0.24816267511674336, 0.1633099711367062, 0.14178264699876308, 0.21974064808871063, 10.519689917564392, 46.52000304630825, 69.10848549434117, 71.67441354479108, 66.96602930341447, 65.76253182547433, 108.81960133143834, 126.7421738760812, 84.74386392320905, 50.38646016802107, 62.85264015197754, 61.94682434626988, 82.87090056283134, 85.9107027053833, 88.58325781141008, 15.613660097122192, 0.3344206522618021, 0.19475762652499334, 0.13727295398712158, 0.09943419761423554, 0.16587260791233607, 0.11493469907769135, 0.12021241230624062, 0.11446011811494827, 0.18346516175993852, 0.1789866949298552, 0.13774199810411247, 0.16502002866140433, 0.1872704132859196, 0.1254267775054489, 0.1341424783957856, 0.1386955976486206, 0.1501511008079563, 0.1569994054734707, 0.1163510052221162, 0.19070295909685747, 0.2619063476366656, 0.349526008857148, 0.13599057708467754, 0.16139019200844423, 0.1877964407737766, 0.14949531028313295, 0.2123421872300761, 0.17994735123855726, 0.07412897369691304, 0.18942112502242836, 0.15347688591906003, 0.1812675768243415, 0.13413517735898495], [0.014715660363435745, 0.023117394618956105, 0.04223903561277049, 0.04268489758084927, 0.002865907154045999, 0.03850126778706908, 0.03887015674263239, 0.051208349144352336, 0.0378447037323245, 0.02979970078117081, 0.0053363865756961915, 0.04757663294939058, 0.04078160006819027, 0.018243728637961403, 0.05539979226887226, 0.09104196115263871, 0.11230395774223975, 0.02205975869271372, 0.059732828688408644, 0.044913637451827526, 0.05363635778693216, 0.035694514467780075, 0.07487745889063392, 0.04412262507581285, 0.05373560031875968, 0.052056602734540186, 0.031438674977315326, 1.8001395080770766, 48.30541215624128, 68.3168841770717, 74.06130736214774, 61.85459395817348, 38.30674941199166, 17.85803246498108, 15.134791987282888, 24.948425940104894, 29.309683391026088, 20.469672713960918, 21.116369349615915, 44.65580483845302, 49.45391811643328, 35.95724037715367, 13.590053711618696, 0.9481143759829658, 0.0665817576061402, 0.08257087892187492, 0.03929242604811277, 0.11811146432799952, 0.23186955654195376, 0.08432515657373837, 0.9535874937261853, 0.7743922035608972, 0.6482599260551589, 0.3726847618818283, 0.9423048134360994, 2.420296196426664, 15.673621313912527, 35.68442283357893, 54.62881830760411, 59.104080063956125, 62.412798336574006, 61.80175290788923, 64.25295925140381, 64.06307193211147, 65.2586623600551, 68.16292599269322, 66.00148732321603, 61.68571104322161, 63.72777271270752, 60.784328188214985, 62.06866100856236, 62.74723597935268, 65.63258661542619, 68.17805222102574, 62.771686690194265, 61.381664821079795, 62.969182286943706, 61.216610363551546, 61.09587846483503, 61.15095683506557, 61.8412812096732, 62.7896477835519, 63.612515994480674, 68.28724316188267, 62.01910645621163, 26.197870118277415, 38.04675129481724, 47.581118038722444, 48.87720373698643, 37.14194645200457, 27.771489449909755, 46.11760854721069, 60.26506151471819, 67.19117178235734, 68.74489321027482, 62.943112645830425, 58.904500007629395, 58.51859705788748, 62.64505577087402, 52.26311649594988, 56.72132737295968, 57.656270027160645, 54.532269614083425, 57.10186978748867, 57.61767973218645, 52.43658522197178, 53.47689730780465, 44.33977992194039, 33.285331453595845, 14.69793963432312, 6.0579515269824435, 3.219368781362261, 1.9420393109321594, 2.2626000983374457, 2.5683827187333788, 2.0026100150176456, 1.7829783260822296, 2.1857399940490723, 2.3703627501215254, 2.0126592814922333, 1.1363601833581924, 0.6805236147982734, 0.11312885276441063, 0.049941110358174355, 0.07359013546790395, 0.026999252748542597, 0.008731722798464554, 0.13694201888782637, 1.5946622767618723, 15.440814971923828, 34.54825687408447, 50.49811771937779, 54.00741311482021, 73.63794667380196, 92.84358051845005, 58.573995045253206, 35.96355281557356, 24.523816313062394, 47.019196374075754, 59.872133936200825, 63.028512954711914, 68.86932849884033, 50.81203038351876, 2.868785262107849, 0.09331738762557507, 0.058150145757411204, 0.06476837955415249, 0.04609369466613446, 0.030911161497767483, 0.04227595470313515, 0.11153878058706011, 0.034917028687362156, 0.0706142708659172, 0.07640615079019751, 0.030177044283066477, 0.09346754063985177, 0.04300621444625514, 0.03343717434576579, 0.03172460284882358, 0.006224677124659398, 0.008724667730608156, 0.04993740216429744, 0.06074694677123001, 0.14996377086000784, 0.09145093456442867, 0.121743716565626, 0.07303582664046969, 0.04465915967843362, 0.0762070007622242, 0.04582486926977124, 0.09188645226614815, 0.06088150705077818, 0.024743900734132955, 0.02914118593824761, 0.048417921377612014, 0.024789218391690935, 0.015629696227344017, 0.08596587460488081, 0.0768684706251536, 0.03704802219622901, 0.039221831264772584, 0.02393184189817735, 0.04784571958173599, 0.016868463684139506, 0.055144361153777154, 0.05886163043656519, 0.09293959968324218, 0.06430850244526352, 0.037217201332428625, 0.031767102889716625, 0.09018245405916657, 0.06081386389476912, 0.043870386467980485, 0.07055154708879334, 0.04763622868007847, 0.016756990558600852, 0.0411408877532397, 0.020301521789016466, 0.09013056648629052, 0.050913586746901274, 0.056003376309360774, 0.032681286334991455, 0.05936559196561575, 2.5242772911276137, 57.0525723184858, 79.05426202501569, 82.33992617470878, 66.88536766597203, 46.63189683641706, 31.05116946356637, 21.657064267567225, 19.865103006362915, 28.573890004839214, 23.021949291229248, 23.94833697591509, 44.83602026530674, 50.387582302093506, 38.17031111036028, 14.869747740881783, 0.9418248449053083, 0.094401605161173, 0.12036901818854467, 0.05777960456907749, 0.1311819622559207, 0.5873214559895652, 0.763111911714077, 1.8779578123773848, 1.4890135058334895, 1.1250439562967844, 0.5774898092661584, 0.8408621453813144, 3.787207705633981, 17.902535676956177, 38.93493257250105, 58.67394488198416, 63.51087774549212, 66.43295655931745, 64.51627513340541, 65.24793434143066, 65.33035387311662, 65.30230399540493, 71.41971342904228, 68.44242422921317, 65.73830345698765, 67.71042455945695, 63.61651120867048, 65.4501964024135, 66.76688003540039, 67.73451396397182, 67.35911669049943, 64.54973765781948, 62.71596908569336, 65.5234443119594, 64.46048109872001, 64.6019811630249, 65.257050377982, 65.04754829406738, 66.52251883915493, 66.34851510184151, 70.69535677773612, 65.1595879963466, 29.241278375898087, 44.60343279157366, 52.58564840044294, 54.189799853733604, 42.23305136816842, 32.711504050663535, 49.365186146327424, 66.36746978759766, 70.80807045527867, 68.12001391819545, 64.41251073564801, 61.033025060381206, 64.11637851170131, 65.0246331351144, 57.323493003845215, 58.972502027239116, 58.65371172768729, 56.48827089582171, 56.94646290370396, 59.91563660757882, 56.20129292351859, 57.84616082055228, 49.25309433255877, 36.39010967527117, 19.316700799124582, 7.133097972188677, 3.054291090794972, 1.8820259826523917, 1.7570948749780655, 0.9371607580355236, 1.7138046664851052, 1.4904252929346902, 1.5886432911668504, 3.1286541862147192, 3.5163686616080145, 2.953613647392818, 2.325776159763336, 0.859267380620752, 0.46352268755435944, 0.022836927258010422, 0.01794988565546061, 0.04884952732494899, 0.035475242483828745, 2.2646723985671997, 18.492123331342423, 36.63731615883963, 49.981581687927246, 56.0372667993818, 79.55717263902936, 105.16429996490479, 69.34666974203927, 49.17887020111084, 38.107801641736714, 56.40730701174055, 66.85101577213833, 71.18466281890869, 75.8919631413051, 66.89073167528424, 5.278715397630419, 0.2048665497984205, 0.06140669994056225, 0.09045952704868146, 0.02155826024578086, 0.013540526768857879, 0.01348818203301302, 0.13303483783134393, 0.012331222998909652, 0.0685381233426077, 0.05753511483115809, 0.03087712957390717, 0.059305718035570214, 0.056754344941249917, 0.02586913062259555, 0.03929589336205806, 0.02077568884539817, 0.019865535898134112, 0.028531040464128767, 0.027534889988601208, 0.10778283141553402, 0.06436924490013293, 0.10016358883253165, 0.03295741955350552, 0.04760557246793594, 0.1090548810149942, 0.012553537364250847, 0.0542647796017783, 0.056908755762768645, 0.037369539229465384, 0.017678861805636967, 0.021351700615403906, 0.04257642697276814, 0.1912392188927957, 0.2128690696720566, 0.18214488189135278, 0.13720974166478428, 0.09842088020273618, 0.076960249271776, 0.13969279985342706, 0.07434343826025724, 0.1479416550802333, 0.2105596893067871, 0.12499338361833777, 0.1340557209083012, 0.15226978569158486, 0.15950432606041431, 0.15954731803919586, 0.2505689231412751, 0.15410359443298408, 0.1000558849690216, 0.11975864879786968, 0.1583763701575143, 0.14638989977538586, 0.18839273734816483, 0.2671010488910334, 0.10319047248257057, 0.14130719751119614, 0.1680557264813355, 0.2793664378779275, 3.5751536786556244, 70.71898065294538, 88.85393878391811, 94.61021559579032, 79.3417090007237, 55.19135141372681, 29.631312029702322, 25.81319178853716, 36.59343828473772, 45.407884802137104, 28.8713093825749, 30.37986578260149, 61.2277900150844, 66.08248247419084, 51.0543383870806, 21.303965500422887, 2.1300028477396284, 0.17702629869537695, 0.1871564465441874, 0.18970735823469503, 0.23391308688691684, 0.7014192906873566, 1.178319160427366, 2.7190958772386824, 2.18832038130079, 3.818607917853764, 4.242721617221832, 3.6647556935037886, 5.3730723687580655, 20.255376373018535, 40.82252883911133, 61.65933568137032, 65.10992922101701, 68.56954847063336, 66.10425118037632, 63.93720531463623, 67.18430696214948, 67.73002542768205, 74.26211030142647, 71.20611190795898, 68.4284027644566, 71.01853833879743, 66.35360813140869, 67.8934679031372, 68.63673060280937, 72.76414816720145, 71.54449612753731, 64.80305508204869, 64.81560352870396, 68.10643018995012, 67.89959621429443, 67.49701063973563, 68.12475953783307, 68.34936005728585, 68.51189926692417, 68.89179202488491, 72.5073983328683, 68.90579959324428, 37.39086219242641, 48.65796375274658, 57.88584198270525, 60.07597323826381, 49.084461552756174, 38.42590059552874, 52.63511610031128, 67.38465826851981, 73.0477875300816, 72.91177654266357, 67.45746844155448, 64.335357938494, 64.4668664932251, 65.03313773018974, 58.537843567984446, 58.97168213980538, 58.77547195979527, 55.49651282174246, 57.65712465558733, 59.06217547825405, 56.21376493998936, 59.142322949000764, 52.36496319089617, 42.01434292112078, 21.474078246525355, 10.144251823425293, 7.526254841259547, 5.2056229540279935, 5.593129200594766, 6.792626687458583, 6.282425676073347, 8.414088709013802, 7.4103684425354, 5.960476985999516, 6.7195998174803595, 4.987249323299952, 2.0377746309552873, 0.47603259342057364, 0.3464661144784519, 0.21138051311884606, 0.22404546423682145, 0.19793456819440636, 0.2762734852731228, 3.047870955296925, 25.219506434031896, 50.20571320397513, 65.68464946746826, 63.67423684256417, 80.17041369846889, 92.15320750645229, 63.40970502580915, 47.15440831865583, 38.21877479553223, 63.17318139757429, 75.92921243395124, 80.97735663822719, 83.51956353868756, 75.19646235874721, 7.331323998314994, 0.35253818865333286, 0.1614068296871015, 0.26111001893877983, 0.10345947090536356, 0.1641907367323126, 0.0956644198990294, 0.27317445299455095, 0.1470833218523434, 0.2026992275246552, 0.13486087056142942, 0.11620503876890455, 0.187529057264328, 0.1114439485328538, 0.14370009196656092, 0.15778328983911447, 0.1009274564151253, 0.13135524652898312, 0.13752710606370652, 0.12874809785612992, 0.19940959475934505, 0.19761484249361924, 0.238759916807924, 0.18686021172574588, 0.09180371849132435, 0.16725759288030012, 0.0941724299586245, 0.15945258097989218, 0.14543901437095233, 0.14413948410323688, 0.18684687172727926, 0.08829639812133142, 0.1449989436992577], [0.04032815886395318, 0.015151417248749306, 0.09638276456722192, 0.049968241580895016, 0.02500670073953058, 0.05725950747728348, 0.058581456542015076, 0.04247717087024024, 0.07130655300404344, 0.026368408563679883, 0.0029832152566606446, 0.014966024518279093, 0.059216986011181555, 0.022702095564454794, 0.057614238799682686, 0.010439832079490381, 0.01633206818119756, 0.03275040191199098, 0.04286898073873349, 0.037533324012266736, 0.03445252396964601, 0.015174014161207845, 0.033171666985643763, 0.07260997127741575, 0.01929085236042738, 0.041321272895272286, 0.47898150661161965, 38.87400381905692, 76.70456191471645, 73.38720008305141, 63.95131710597447, 57.361885275159565, 33.70571831294468, 39.633928298950195, 88.73659760611397, 63.401061466761995, 18.57075435774667, 42.06453323364258, 48.754258837018696, 43.70708390644619, 32.19374861036028, 11.494688068117414, 0.6621988266706467, 0.018948872407366122, 0.05168546782806516, 0.020316549643341984, 0.010914704812291478, 0.03747722612959998, 0.22509225378079073, 0.8316876462527684, 1.2592105226857322, 1.77692340527262, 0.88743635479893, 0.3623397084219115, 6.073441667216165, 30.99907534463065, 50.22242709568569, 60.60894175938198, 64.3065437589373, 69.14443547385079, 69.6044340133667, 73.12362711770194, 67.11023916516984, 67.0908397947039, 67.89140428815568, 64.23107937404087, 60.70546613420759, 56.65217890058245, 52.322700772966655, 53.13266965321132, 55.78660706111363, 57.08977992194039, 56.850546496255056, 61.05150726863316, 63.70156410762242, 59.44113022940499, 63.004993302481516, 64.0912538255964, 57.36725623267037, 56.80198206220354, 56.898009640829905, 57.792701380593435, 63.10456098828997, 68.28720147269112, 59.104121753147666, 40.50040340423584, 25.425072363444738, 37.007537024361746, 37.4784060205732, 32.23298508780343, 42.695339339120046, 52.6767566544669, 62.54929569789341, 63.99558407919747, 62.447261401585166, 58.95909200395857, 55.42288623537336, 62.52795083182198, 67.30237075260708, 62.70497703552246, 53.19000966208321, 58.099693638937815, 59.83574622017996, 64.19331591469901, 65.74116611480713, 64.50000245230538, 61.231514249529155, 60.85195500510079, 57.84513248716082, 57.21326330729893, 48.27859558377947, 34.04347024645124, 24.163249969482422, 15.18186776978629, 7.121606520244053, 4.815302687031882, 2.460474371910095, 1.2724619316203254, 1.7906200417450495, 3.0400711681161607, 2.4209462872573306, 2.060281366109848, 1.9869995840958186, 0.06297221593558788, 0.16282331225063118, 0.08438100679112331, 0.09886201617441007, 0.10593910249216215, 0.17222020801688942, 1.1158664716141564, 8.328010950769697, 24.489480052675518, 36.02229983466012, 37.46715688705444, 33.44171803338187, 29.06710614476885, 20.69042914254325, 14.531479035105024, 26.038386378969463, 48.42454596928188, 57.54501894542149, 65.67853505270821, 73.97974940708706, 37.381096499306814, 0.5404647588729858, 0.04784444732857602, 0.01893543402132179, 0.04697746617187347, 0.021777618742947067, 0.06335608355168786, 0.03741514356806874, 0.018483393991898214, 0.03749189944937825, 0.04199546528980136, 0.0367401335388422, 0.032791663626474996, 0.05175310080604894, 0.06679718568921089, 0.03494377653779728, 0.03576374200305768, 0.08162779667015586, 0.03477228698985917, 0.028144465493304387, 0.09296962485781737, 0.015301448126722659, 0.06701589788177184, 0.036842524473156245, 0.018051263876259327, 0.06662691411163126, 0.10663149319589138, 0.05917861485587699, 0.09228041648332562, 0.10242845051522766, 0.05214485978441579, 0.011682410358584352, 0.0576537906059197, 0.013882174239759999, 0.01420167093497834, 0.017116395290941, 0.030965746247342656, 0.02977778749274356, 0.036023285040365796, 0.03653984357203756, 0.022123247518071106, 0.05473095351564033, 0.025952965320487107, 0.024545704047860842, 0.04575471553419318, 0.06587130430021457, 0.02827025910041162, 0.0643943574811731, 0.0500994295414005, 0.027049662811415534, 0.04475804597937635, 0.04251584397362811, 0.033982675788658004, 0.016234835809362785, 0.008059680511775826, 0.022438669610502462, 0.019043434743902514, 0.016270029724442532, 0.13002159952053002, 0.9089735448360443, 44.8547317641122, 86.5433987208775, 81.19345256260463, 72.41108240400041, 67.85739980425153, 41.69418382644653, 36.53875248772757, 64.32672132764543, 59.412253516060964, 21.076907055718557, 29.518181460244314, 38.6943234034947, 41.61463737487793, 36.972928047180176, 14.998407534190587, 0.5377831341964858, 0.05423359413232122, 0.03962047737357872, 0.039610930385866334, 0.1780307340834822, 0.13198684049504145, 0.9370021436895642, 2.5388446237359727, 2.2285971343517303, 1.2149133682250977, 0.8980986369507653, 0.6717318637030465, 6.767968833446503, 31.62769624165126, 51.89505304609026, 63.736506598336355, 67.44928346361432, 71.74889823368618, 71.04775551387242, 75.16406290871757, 65.20482771737235, 66.99189744676862, 71.6774707521711, 66.0689126423427, 65.61771747044155, 60.12813336508614, 55.76500858579363, 56.9364401272365, 56.3944285256522, 61.51866940089634, 60.247357504708425, 65.11576570783342, 65.05345426286969, 61.322292464120046, 64.63522829328264, 67.30549049377441, 60.373731340680806, 59.09176090785435, 58.014147417885916, 59.50704084123884, 65.31324740818569, 69.6291070665632, 63.14971038273403, 44.75830813816616, 29.787246976579937, 43.627196993146626, 43.160886015210835, 37.73802546092442, 46.43419974190848, 57.348687171936035, 64.98250620705741, 66.58350317818778, 65.65190955570766, 60.49871553693499, 57.96937322616577, 64.73795046125139, 67.78112942831856, 61.00154277256557, 55.62377602713448, 60.59626824515206, 60.42858042035784, 66.87634195600236, 67.63001305716378, 67.87836251940045, 63.566880226135254, 64.97812884194511, 63.81131090436663, 61.59261907849993, 51.10897207260132, 37.94356707164219, 27.383587156023296, 17.966653653553553, 9.088256784847804, 5.535277196339198, 1.8981955264295851, 0.9405472448893956, 1.113731203334672, 1.9797869196959903, 3.0934893531458716, 3.6868870088032315, 3.8518980400902882, 1.0871749711888177, 0.8849665416138512, 0.12195455096662045, 0.06812246636088405, 0.10130062353398119, 0.18063223734498024, 1.2534413465431757, 9.4343569789614, 25.83323734147208, 42.337767669132774, 42.78401919773647, 37.45616831098284, 25.491233110427856, 25.154120411191666, 22.387719460896083, 36.90301179885864, 57.32603257043021, 63.75890064239502, 74.32705511365617, 82.37976019723075, 53.40228407723563, 1.119088155882699, 0.10308314181332077, 0.014942835584016783, 0.05871404228465898, 0.06545180681028537, 0.018713598871337514, 0.04021065016942365, 0.045020174235105515, 0.06183239924056189, 0.026147516577371528, 0.08178696741483041, 0.06798957527748176, 0.013735712455984737, 0.08044652827084064, 0.06509043941540377, 0.030027556233108044, 0.019490161844130074, 0.06152264800454889, 0.05298042816243001, 0.06775508714573723, 0.016557506352130855, 0.07294720318168402, 0.04464386889178838, 0.022450572811067104, 0.024066229151295762, 0.055882583505340984, 0.009968948284430163, 0.05979477893561125, 0.026783894215311323, 0.03265037227954183, 0.034928309332047186, 0.04807784301894052, 0.0982695058254259, 0.14868123110915932, 0.15311676024326257, 0.1849664340593985, 0.09225961259965386, 0.10694326646625996, 0.158369991928339, 0.10002193107668843, 0.13171286162521156, 0.1721789530877556, 0.12919233473283903, 0.15682546980679035, 0.10057866227413927, 0.08459500995065485, 0.14883813554687159, 0.22882627270051412, 0.08085902327937738, 0.13389530165919236, 0.09236354380846024, 0.15983382266546997, 0.08816597012004682, 0.09552506237689938, 0.11993341227727276, 0.11106077980782304, 0.18908035116536276, 0.23042378840701921, 1.996843010187149, 58.4285831451416, 97.04908193860734, 92.14186109815324, 81.83306203569684, 78.57743494851249, 46.77899367468697, 49.18999079295567, 97.61516557421002, 70.25539684295654, 28.46106341906956, 56.719850880759104, 67.57808916909354, 60.70943355560303, 48.08523416519165, 19.524806295122417, 1.3753386970077242, 0.13912977863635334, 0.19429966967020715, 0.17601019250495092, 0.2652940015707697, 0.14224211020129068, 0.7782523621405874, 3.3797955214977264, 4.38396155834198, 4.859063310282571, 4.003516418593271, 2.113160414355142, 9.123576215335301, 39.48657437733242, 54.22726454053606, 64.54600647517613, 70.29291711534772, 75.02667617797852, 74.41447040012905, 78.31138842446464, 67.73558398655483, 67.40627411433628, 72.84172480446952, 71.39729159218925, 68.83476815904889, 63.69193390437535, 58.51859705788748, 59.409321376255576, 61.76044586726597, 63.64291436331612, 63.556513513837544, 66.40500395638603, 67.87373501913888, 61.19643974304199, 67.03097411564418, 69.60915878840855, 63.62803132193429, 62.954459054129465, 59.685887472970144, 61.83384663718087, 68.15619318825858, 71.62722832815987, 66.50481482914516, 49.929487568991526, 36.43853514535086, 48.25773361751011, 47.13616929735456, 40.87064858845302, 46.6892785344805, 57.143020493643625, 65.82349531991142, 68.0592588697161, 67.58309882027763, 62.63395254952567, 61.397444180079866, 67.93830462864467, 70.12888404301235, 62.88747841971261, 54.610784258161274, 60.37416212899344, 62.47418567112514, 69.51363495418003, 71.94253758021763, 70.7497055871146, 65.70848873683384, 67.24392250605992, 67.76821272713798, 66.96598761422294, 56.16870239802769, 42.113837650844026, 28.494583266122, 19.297937188829692, 9.085917847497122, 7.203902721405029, 5.371905939919608, 4.275603532791138, 7.867929032870701, 8.52214969907488, 7.039320307118552, 6.2147780145917615, 4.284648784569331, 0.9129452002899987, 0.5613427928515843, 0.2450779734977654, 0.39858064374753405, 0.3017532080411911, 0.35231657911624226, 2.064148255756923, 13.986979109900338, 36.19589710235596, 52.59108883993966, 51.90356458936419, 43.674410002572195, 37.381159033094136, 29.808484145573207, 24.78181161199297, 37.29966708592006, 65.90425423213414, 72.77753734588623, 83.81261771065849, 88.53033338274274, 62.7179354258946, 2.5184609975133623, 0.2357566665325846, 0.05457370302506855, 0.17780947738460132, 0.12047166696616582, 0.16273400347147668, 0.1041797629690596, 0.08679252703274999, 0.13261829875409603, 0.1731315619711365, 0.10502614040992089, 0.1366074468408312, 0.10178680066019297, 0.2000754547438451, 0.2361517639032432, 0.11157030532402651, 0.19341112806328706, 0.14449998975864478, 0.11495225956397397, 0.2155743616500071, 0.13734539438571247, 0.12375205808452197, 0.16053400295121328, 0.16451557858714036, 0.1288965477475098, 0.2530800998210907, 0.11198456452361175, 0.1833763008138963, 0.22688715532422066, 0.12296018057635852, 0.09076294755297047, 0.14162885025143623], [0.010392313423965658, 0.02102386811748147, 0.05189533531665802, 0.0457570123752313, 0.02373381145298481, 0.0714061823008316, 0.04062854292403374, 0.02277427981607616, 0.03777469927445054, 0.02018715301528573, 0.0567060569966478, 0.036812689288386276, 0.04151597851887345, 0.04401088392894183, 0.032959485692637305, 0.024163171449410062, 0.07769179144608122, 0.02346780536962407, 0.0805312976507204, 0.07682632681514535, 0.007341750598113451, 0.044731138673211844, 0.06265975734485046, 0.005814771999471954, 0.04396419732698372, 0.08224008631493364, 17.77198944772993, 71.89963940211705, 70.17725045340401, 66.79946708679199, 67.87684086390904, 43.982996872493196, 26.273360558918544, 46.42956529344831, 81.68425246647426, 55.898493903023855, 30.874619211469376, 45.70047344480242, 48.41968223026821, 39.599816117967876, 14.872705936431885, 0.8405267319508961, 0.0387333471194974, 0.0375405198761395, 0.04084668514717903, 0.06314588018826076, 0.0199175778377269, 0.33681436095918926, 0.5054281417812619, 1.115280868751662, 2.1960784792900085, 0.8604780499424253, 1.1181587257555552, 9.253066318375723, 33.2952812739781, 54.615707056862966, 63.91604804992676, 65.31225381578717, 67.6626626423427, 65.31927149636405, 65.51487023489815, 66.91484192439488, 61.61788272857666, 65.05114051273891, 62.440486907958984, 59.30719675336565, 52.85465833118984, 46.01149913242885, 46.450507164001465, 48.26856585911342, 46.769408634730745, 48.15734951836722, 51.01048830577305, 56.657716614859446, 60.80108029501778, 65.39745957510812, 62.297875131879536, 61.70822320665632, 58.27305119378226, 54.47504425048828, 52.01129640851702, 54.56165354592459, 58.296074049813406, 63.02443436213902, 62.370428221566335, 62.367753165108816, 36.79345955167498, 21.74007092203413, 33.04961034229824, 43.14304651532854, 68.16183512551444, 61.989715576171875, 61.14408506665911, 59.28985404968262, 53.69096783229283, 52.70983355385916, 54.06774779728481, 58.94188131604876, 63.70231451307024, 62.29342828478132, 58.888533047267366, 61.79171970912388, 62.22070149012974, 56.70942858287266, 57.091044494083945, 59.41450473240444, 60.2676670891898, 58.83842958722796, 58.11771379198347, 58.741571698869976, 62.28966930934361, 59.46721376691546, 56.98041180201939, 54.510487011500764, 49.484236580984934, 40.132489340645925, 26.55575966835022, 6.638304591178894, 1.7633491222347533, 2.2239865703242163, 2.5387297613280158, 2.956505400793893, 3.187615079539163, 0.8676673727376121, 0.362573504447937, 0.06551677653832094, 0.020167925029194782, 0.06627211493573018, 0.031020863646907464, 0.08793441325958286, 0.21746249390499933, 2.9715082986014227, 11.363251600946699, 27.428990159715923, 47.66910307747977, 53.41405779974801, 35.55431086676461, 26.849826540265763, 12.41113635471889, 31.540836811065674, 52.89645869391305, 60.04413659232003, 65.43494510650635, 73.80861527579171, 21.426436185836792, 0.26410081131117685, 0.016507954636056508, 0.07087788172066212, 0.030457041758511747, 0.07878270612231322, 0.03844405710697174, 0.024817396254677857, 0.040205476339906454, 0.028707272971847227, 0.06922969980431454, 0.12059350471411433, 0.024092274717986584, 0.024749457935935686, 0.013638828681515796, 0.05242002948320337, 0.028922324467982565, 0.018484766328973428, 0.05383491748943925, 0.0246521814593247, 0.033573003485798836, 0.09100694874567644, 0.0123690640487309, 0.05019234134150403, 0.04519923962652683, 0.05243419390171766, 0.07732369298381464, 0.09338668640702963, 0.05074463491993291, 0.03967679238745144, 0.04882678961647408, 0.012962132492767913, 0.04374269635549613, 0.08547968390796866, 0.03473875378923757, 0.024882863009614602, 0.0976574740239552, 0.03889432276732155, 0.02527847606688738, 0.028292163907151138, 0.01210495362257851, 0.04926231749621885, 0.026193360099568963, 0.034001705303256, 0.02601969245422099, 0.04944847357858505, 0.10437246691435575, 0.0081746709932174, 0.05005839513614774, 0.034114080880369456, 0.0751699006983212, 0.043004728454564295, 0.006982216095950986, 0.03482260714684214, 0.019608540759821023, 0.016059135951633965, 0.03969783375837973, 0.0963711751891034, 22.905132702418737, 86.25643117087228, 75.90760353633335, 74.57076317923409, 74.91166959490094, 56.70361294065203, 35.754881041390554, 53.83422579084124, 94.37416444505963, 69.57864230019706, 38.31046322413853, 45.290703432900564, 46.98844017301287, 42.33668027605329, 16.457734210150583, 0.8178681135177612, 0.08107415959239006, 0.05428021288077746, 0.40552819094487597, 0.5580204139862741, 0.6649682809199605, 0.8856453480465072, 2.939519443682262, 2.8352843054703305, 1.1109489926270075, 0.551061575966222, 1.0586192863328117, 11.005464536803109, 36.43157305036272, 57.07787765775408, 67.28373568398612, 67.97960472106934, 71.10551588875907, 67.9229907989502, 68.2206585747855, 68.28118433271135, 63.51525511060442, 65.60183388846261, 64.48624501909528, 63.05345698765346, 57.5995831489563, 48.63830382483346, 49.918415614536826, 50.931077344076975, 50.0758444241115, 50.85406698499407, 53.98891701017107, 58.637452942984446, 63.41971737997872, 67.71081365857805, 64.67244979313442, 64.45170552389962, 61.510713713509695, 56.75953551701137, 55.494338035583496, 56.75318833759853, 60.59868621826172, 66.78304849352155, 65.1418422971453, 66.48336574009487, 41.62060240336827, 26.147624220166886, 37.34933628354754, 44.953820024217876, 67.08671256474086, 65.62979343959263, 63.96094036102295, 60.12690353393555, 56.87959344046456, 55.17280319758824, 57.3697714805603, 62.064276695251465, 65.55093833378383, 63.163613728114534, 59.63360922677176, 63.71912915366036, 65.0705120904105, 60.3462929044451, 61.10135364532471, 62.28673022133963, 62.98295361655099, 62.684736933027, 62.89073712485177, 63.4512483051845, 67.14387539454869, 63.512385504586355, 59.751916204180034, 57.18029063088553, 51.12631477628435, 42.726877212524414, 28.39098562513079, 8.859945927347455, 2.0251623477254594, 0.6216169499925205, 0.2894652916916779, 1.968987899167197, 3.3808440480913435, 3.1317400549139296, 1.5126319527626038, 0.7506887497646468, 0.18030215719980852, 0.08957380814743893, 0.02296796763714935, 0.032341516709753444, 0.16342952900699206, 3.157910010644368, 11.97175225189754, 31.56721912111555, 39.47609649385725, 36.991611753191265, 21.613504273550852, 23.101139647620066, 19.687197855540685, 40.265380586896626, 57.071339402879985, 65.29853112357003, 69.51111275809151, 86.0382160459246, 34.47832325526646, 0.20020772836038045, 0.05140112094315035, 0.08140588857765708, 0.05258264040042247, 0.046496035398117135, 0.04847092853326883, 0.04183658631518483, 0.050303044329796515, 0.054462396140609465, 0.12303756070988518, 0.045979273305939775, 0.07267645413854293, 0.06034787318536213, 0.04095091151871851, 0.007089934378330196, 0.028007080811741095, 0.006505897235391396, 0.06432881099837166, 0.0330871045589447, 0.05475772172212601, 0.0037310456640885343, 0.04529987654781767, 0.06667188741266727, 0.03060001926496625, 0.044593267142772675, 0.012419385053882641, 0.09489412658980914, 0.04365301777475646, 0.05022181011736393, 0.016250060438843708, 0.027443335258534977, 0.22827275097370148, 0.15096049809030124, 0.08895068229841334, 0.13918847191546643, 0.20359030685254506, 0.17947211888219627, 0.08583940246275493, 0.17292573515857967, 0.11807931533881597, 0.11024779307522944, 0.1651366145483085, 0.11714490476463522, 0.1406564281455108, 0.19614284219486372, 0.16044065010334763, 0.1278506810111659, 0.18983656487294606, 0.11648018471896648, 0.21782846855265753, 0.16407972840326174, 0.12148819384830338, 0.14197228396577494, 0.14718738198280334, 0.09040793803121362, 0.14118138354803833, 0.15899036292518887, 32.59506961277553, 95.69552421569824, 86.10925442831856, 85.01238400595528, 86.42368820735386, 62.443009104047505, 36.2585802759443, 56.09508623395647, 86.51108959742955, 64.67723710196358, 46.39969498770577, 64.57495267050606, 65.7896853855678, 57.769598620278494, 23.59799143246242, 1.4026984231812614, 0.24833529442548752, 0.16420647874474525, 0.5856216986264501, 0.7173801713756153, 0.39905537398798124, 1.405812301806041, 1.3415701261588504, 4.394198860440936, 5.406065021242414, 5.0315636311258585, 3.3334301923002516, 11.832360965864998, 40.55779552459717, 58.41595132010323, 70.4222161429269, 71.85697746276855, 72.57496956416539, 70.4176025390625, 70.6474836894444, 70.91664995465959, 62.2533232825143, 66.49708843231201, 67.40245260511125, 64.84321566990444, 58.31466048104422, 50.011215754917686, 50.95674746377127, 52.960024288722444, 51.47035135541643, 53.688932010105674, 55.80856336866106, 60.69152109963553, 66.44226714542934, 72.72081225258964, 65.95787348066057, 68.56355217524937, 65.24902520860944, 59.178564752851216, 58.770246914454866, 58.32474231719971, 62.650871413094656, 68.79097366333008, 67.44388471330915, 68.14106001172746, 46.77901104518345, 31.3307615007673, 43.09872743061611, 47.208392347608296, 70.29852431161063, 67.8541966847011, 68.54701546260289, 62.821352413722444, 59.30318069458008, 58.05547530310494, 59.501607349940706, 63.48963015420096, 67.69622244153703, 64.32479667663574, 59.44274915967669, 65.2295355115618, 68.46213626861572, 63.27390248434884, 64.39175646645683, 66.25720882415771, 65.49999414171491, 66.71919454847063, 65.37368283952985, 65.80163628714425, 70.95846421377999, 66.33525099073137, 62.36671788351876, 58.24344491958618, 53.74344410215105, 45.4738301549639, 28.918555395943777, 10.214452947889056, 5.927427010876792, 6.828609670911517, 9.172495876039777, 8.793565443583898, 8.31823570387704, 4.109371355601719, 1.577563954251153, 0.6057998101626123, 0.21075334320110933, 0.31236109882593155, 0.14426065688686712, 0.25536350586584633, 0.3990642492260252, 5.127470484801701, 17.95072317123413, 43.65143925803048, 69.6314069202968, 76.81968661717006, 50.845607553209575, 38.75776045663016, 21.07937366621835, 46.121218136378694, 65.59991618565151, 76.34137262616838, 79.04062965938023, 94.3027161189488, 42.09504624775478, 0.4981625516499792, 0.13288998417556286, 0.11331337357738189, 0.13931496441364288, 0.23120407653706415, 0.22668725890772684, 0.09723136081759419, 0.09653580135532788, 0.12126577006919043, 0.18032800938401902, 0.22205656953155994, 0.10783677494951657, 0.10173952034009354, 0.08619567405964647, 0.12461945654026099, 0.07934200896748475, 0.09116508811712265, 0.118993288438235, 0.11473066359758377, 0.16284335617508205, 0.11737878221486296, 0.07416958401777915, 0.14070488911654266, 0.20401497477931635, 0.0890685302604522, 0.13201859593391418, 0.116423296343003, 0.17070778060172284, 0.129536433411496, 0.09705028696251766, 0.15734897314437798], [0.038447113907230754, 0.06610952437456165, 0.039826477212565284, 0.03396992950833269, 0.015164702964414443, 0.038762880356184075, 0.03813515743240714, 0.05044654430821538, 0.002329584805660748, 0.0826593531029565, 0.03796163906476327, 0.012240357830056121, 0.06423705949315003, 0.0044771322365184975, 0.06625002862087317, 0.029176456188516955, 0.024876683251932263, 0.026357428170740604, 0.00804341009019741, 0.037688654248735735, 0.029657422165785517, 0.06051980038838727, 0.06114374726478543, 0.019223977645326937, 0.05404937866010836, 7.05120997769492, 59.27919551304409, 70.27700574057442, 71.56113011496407, 52.49830954415457, 40.931688513074604, 29.98128237043108, 21.345168318067277, 22.756774766104563, 20.537688629967825, 32.345240184238975, 34.20614842006138, 44.1148875781468, 35.59852225439889, 10.536724294934954, 0.4394616186618805, 0.07140905250396047, 0.02543564004424427, 0.08931664337537118, 0.09698648431471416, 0.019306948907407265, 0.7468818426132202, 0.5379648730158806, 1.6597319394350052, 1.9492013837609972, 1.0585929048912865, 2.778373564992632, 21.210736308779033, 45.372650487082346, 63.85273606436593, 67.67919935498918, 60.91589232853481, 65.8985983984811, 62.21169662475586, 60.69074984959194, 61.25917502811977, 64.90392208099365, 62.906488691057476, 62.40432848249163, 64.066664150783, 60.17006574358259, 50.58959075382778, 46.79147611345564, 50.44114596503121, 54.088793890816824, 54.44687972749983, 49.12484795706612, 46.03127023151943, 50.10500601359776, 55.770039081573486, 58.4138251713344, 62.4912782396589, 59.91899258749825, 56.867826666150776, 50.151069096156526, 52.39252322060721, 49.8872320992606, 55.59303372246878, 59.272622517177034, 63.24850681849888, 62.381628717694966, 64.77574171338762, 26.12540909222194, 16.553770474025182, 59.69212000710623, 62.37019893101284, 58.817043031964985, 55.699438435690745, 52.94484942299979, 48.306298051561626, 49.971583230154856, 54.30411856515067, 58.647305488586426, 63.843877111162456, 59.88974067143032, 57.17683737618582, 62.496406010219026, 58.86308874402727, 55.57374552318028, 53.02933256966727, 52.0241436277117, 52.86100203650338, 53.72912386485508, 53.42095736094883, 57.59967000143868, 59.0382319859096, 60.31882667541504, 57.34759630475725, 54.1016445841108, 56.42577184949602, 65.94453293936593, 58.088621684483115, 45.61720970698765, 29.180415630340576, 6.102495125361851, 1.2851837575435638, 1.6328212405954088, 4.3582393271582465, 2.2992008200713565, 1.4119159685713905, 0.6999601147004536, 0.08052016289106437, 0.12455893121659756, 0.09962425527295896, 0.07088312001100608, 0.059085160227758546, 0.129241745652897, 0.48749152996710365, 6.599340830530439, 31.26632390703474, 52.02956322261265, 57.59975337982178, 38.83353751046317, 29.402514798300608, 28.800274474280222, 37.929976395198274, 51.28166260038103, 58.420078550066265, 70.06279972621373, 57.65272297177996, 2.0045952456338063, 0.17072150057979993, 0.035815873848540444, 0.030545332735138278, 0.07083885917173964, 0.03768025737787996, 0.03041731014049479, 0.024714319999994974, 0.038092416511582475, 0.046746794799608846, 0.02260003541596234, 0.10404330279145922, 0.028928960540464947, 0.08292194615517344, 0.03778944384040577, 0.03415637396808181, 0.03737049596384168, 0.0053231029804529885, 0.055009841586330106, 0.07103525434753724, 0.07842962364000933, 0.06292940037591116, 0.027183776954188943, 0.07403222817395415, 0.06721058993467263, 0.06830635613628797, 0.06765283191842691, 0.04482003354600497, 0.0064385424567652595, 0.047935472801327705, 0.05785158356385572, 0.028225053401131715, 0.033992127781467776, 0.004941074618337942, 0.03116838394531182, 0.040357681922614574, 0.010457423099848841, 0.03184444570381727, 0.025130407851455466, 0.006163665376204465, 0.058110152903412066, 0.04759325705734747, 0.08635109250566789, 0.002619363151357642, 0.03485731082037091, 0.03430872543581894, 0.04875815919201289, 0.03199350627671395, 0.04514718920524631, 0.05368871015629598, 0.03456973750144243, 0.04064956733158656, 0.018369751250637428, 0.06473778441016163, 0.037912095830376656, 0.05785690327840192, 9.05544478552682, 70.43318734850202, 80.12877314431327, 79.66108294895717, 60.39110878535679, 51.99508278710501, 45.215902600969585, 28.381435326167516, 24.042931488582067, 33.06088032041277, 35.74223531995501, 31.250791209084646, 38.059018339429585, 35.83132859638759, 12.039623124258858, 0.5963639936276844, 0.05913178236888988, 0.08342724439821073, 0.17385908721813134, 0.8223360223429543, 1.0467487233025687, 2.146244913339615, 1.4173912576266696, 2.664083297763552, 0.8051030242017337, 0.3141478443784373, 3.115049396242414, 23.39701305116926, 49.75405945096697, 65.89194202423096, 69.35955170222691, 64.18089253561837, 68.17778124128068, 66.4279955455235, 62.453195163181846, 64.72371360233852, 67.16443511417934, 62.62997817993164, 62.25610951014927, 66.40308625357491, 62.19342981066023, 51.819303785051616, 50.712073598589214, 52.6947455406189, 56.766296114240376, 55.542530741010395, 51.06582375935146, 50.47722796031407, 52.542458398001536, 58.19442537852696, 60.63721397944859, 63.90069947923933, 61.14684350149972, 59.90704863412039, 53.455781732286724, 53.88408953802926, 52.339216641017366, 57.14795371464321, 60.98551327841622, 65.44176823752267, 65.28445407322475, 66.25120558057512, 29.31363344192505, 20.10328377996172, 62.29841014317104, 64.56122997828892, 62.72366768973214, 59.88853863307408, 56.16052436828613, 51.29369340624128, 52.11888231549944, 55.64017724990845, 59.94315842219761, 66.26424040113176, 59.73216247558594, 58.78281620570591, 65.26948765345982, 60.912981033325195, 59.682218824114116, 55.803181988852366, 54.345863342285156, 56.0000661441258, 56.27734790529524, 56.532687255314414, 59.84076281956264, 62.73582703726632, 63.457195963178364, 60.20742620740618, 56.340604305267334, 59.79470321110317, 67.88913917541504, 63.70924881526402, 50.8910869870867, 34.465500354766846, 8.505458389009748, 0.8021828808954784, 1.724465700132506, 1.2604866027832031, 1.8943850908960616, 2.962576823575156, 2.479937796081815, 0.9685523935726711, 0.2575382377420153, 0.07888174509363514, 0.05057051604879754, 0.04603598526279841, 0.00667481089476496, 0.428204207015889, 6.318213675703321, 34.61783613477434, 51.095829554966514, 51.27367912020002, 34.821251596723286, 25.755073581423076, 41.838504859379356, 48.658703735896516, 57.31092023849487, 66.44189889090401, 75.40861170632499, 71.3691166469029, 5.075378102915628, 0.27031635493040085, 0.04727970263255494, 0.04871092636936477, 0.04422709232728396, 0.03228108298831752, 0.008166255462648613, 0.022936217287289243, 0.01061808577339564, 0.026417661724346023, 0.06700842042586633, 0.06977022758552007, 0.051602628880313466, 0.05687058138261948, 0.13327715625720365, 0.037080503667571714, 0.030012234912386963, 0.08045735090438809, 0.018914260336064866, 0.04551584406622818, 0.030512596813163588, 0.0843453701319439, 0.07582447664546114, 0.014370216489104288, 0.004688748649121928, 0.02686834129105721, 0.04231459048709699, 0.049606568845255036, 0.059202451791082106, 0.0193166214240981, 0.01603361964225769, 0.09435920350785766, 0.20354025810956955, 0.15275952512664454, 0.1272475312330893, 0.11871730110474996, 0.12155895148004804, 0.1410983172910554, 0.07466534884380442, 0.15597257842975004, 0.13390447545264447, 0.12347609789243766, 0.12278918975165912, 0.1120232410196747, 0.09437157320124762, 0.09647087233939342, 0.17477529948311193, 0.08376305816429001, 0.1183335759810039, 0.08252883689211947, 0.10290652593331677, 0.0921916641028864, 0.10847562245492424, 0.1542767837111439, 0.10179865466696875, 0.16985833618257726, 13.66047283581325, 84.43217468261719, 89.8207528250558, 91.7941871370588, 70.0223056248256, 56.301305294036865, 43.89525154658726, 31.645396777561732, 31.202900750296457, 28.612643582480295, 48.59875120435442, 51.14185789653233, 59.281946999686106, 50.91536399296352, 17.794996670314244, 0.9066988783223289, 0.16627354068415506, 0.16208802456302301, 0.27922039000051363, 0.9209448567458561, 0.9426429952893938, 2.6931560805865695, 1.8891698164599282, 2.3857981732913425, 6.86180990082877, 3.9582740919930592, 4.512783331530435, 27.415154559271677, 51.12000928606306, 68.34575394221714, 71.93300465175084, 68.32404776981899, 70.6576350075858, 69.52666977473667, 64.19052273886544, 66.64434855324882, 69.0502734865461, 64.23702008383614, 61.759070123944966, 68.48362009865897, 65.8453265598842, 56.34684031350272, 52.21551786150251, 55.49889257975987, 60.342061451503206, 59.99945967538016, 55.41787658418928, 51.9135422025408, 56.13494804927281, 61.65175519670759, 62.86397961207798, 66.80669321332658, 64.56611456189836, 62.80906799861363, 56.25253241402762, 57.61466768809727, 55.816147327423096, 60.969018254961284, 63.979589326041086, 68.26721150534493, 68.0383517401559, 66.36955424717495, 35.28403288977486, 23.95611548423767, 64.66788482666016, 69.28828402927944, 64.99201134272984, 62.20030852726528, 58.417806489127024, 53.19306339536394, 53.81743894304548, 57.66972868783133, 62.083912304469514, 68.92393439156669, 61.97522858210972, 58.667378834315706, 67.81154169355119, 64.1323663166591, 62.6051800591605, 57.28064693723406, 55.92565093721662, 58.23906408037458, 58.30213287898472, 60.81720011574881, 64.12048489706856, 66.52301910945347, 66.21369920458112, 60.74805164337158, 56.2662273134504, 63.05354731423514, 67.51389476231166, 68.89619718279157, 56.54155315671648, 34.765818868364605, 8.59581971168518, 5.999581013407026, 8.881289056369237, 10.204252992357526, 8.106882793562752, 4.921280086040497, 2.2837239248411993, 0.6082028555018562, 0.3403371790690081, 0.2816527751939637, 0.2410082018801144, 0.1563422850200108, 0.3510923119527953, 0.9046425372362137, 9.80595098223005, 45.83123159408569, 69.90269238608224, 77.52595015934536, 55.46206712722778, 38.34059061322893, 40.29249593189785, 52.24310915810721, 65.84155368804932, 77.72608607155937, 80.9792673928397, 83.37175451006208, 6.850495627948216, 0.41414213872381617, 0.14131386072507926, 0.1718018233243908, 0.17856684460171632, 0.15649433114698955, 0.15224364852266653, 0.11330150599990572, 0.07369430416396686, 0.12437287691448416, 0.09832361220781292, 0.1590709186026028, 0.14605813686336788, 0.19778268491583212, 0.22752986369388445, 0.09610338455864362, 0.12960406978215488, 0.1526275229241167, 0.09423319276954446, 0.2947207082595144, 0.14061011134513787, 0.1474305282213858, 0.15239266838346208, 0.19382982488189424, 0.08373107202351093, 0.15416983302150453, 0.2164089868643454, 0.13813324139586516, 0.15330061609191553, 0.1063193670873131, 0.15024484720613274], [0.020420570758038332, 0.03381957293355039, 0.01586760756825762, 0.010827192454598844, 0.025428383112219826, 0.08198735916188785, 0.05145163108993854, 0.004831743967120669, 0.0504383001077388, 0.07153426935630185, 0.02413234899618796, 0.02731314135183181, 0.026152821024879813, 0.032528314007712264, 0.003088393061521596, 0.021328677922221165, 0.054311686727617464, 0.04178292776591011, 0.036272002051451376, 0.01893126272729465, 0.05489695032260247, 0.020737533124962022, 0.020556610243927156, 0.04227699625438877, 0.3362914004496166, 35.89031532832554, 73.5946524483817, 69.50580433436802, 58.935301371983115, 57.13670458112444, 27.874843903950282, 16.774577277047293, 33.39361565453665, 36.773031847817556, 47.21259948185512, 45.16995416368757, 57.412707873753135, 33.68860837391445, 8.87020754814148, 0.7729563148958343, 0.06033526600471564, 0.027466296883566037, 0.08254928793758154, 0.15092920405524118, 0.2927104804132666, 0.8320424386433193, 1.9018118466649736, 1.552054185952459, 7.828918371881757, 1.4934135611568178, 6.254290682928903, 28.778158358165197, 52.73530912399292, 62.52349703652518, 65.31611006600517, 59.862253597804475, 63.46644401550293, 65.2743444442749, 61.09350218091692, 56.67390939167568, 60.218751771109446, 62.53884560721261, 61.30522768838065, 59.94635459354946, 61.87650162833077, 57.90158660071236, 49.30155801773071, 43.45538888658796, 53.82926825114659, 56.76020949227469, 57.193269865853445, 53.377562386649, 48.59482199805123, 43.69808598927089, 47.21154335566929, 48.6230525289263, 53.31325680868966, 48.62683234895979, 50.541599546160015, 48.98482091086251, 52.11011021477835, 51.566830566951204, 55.96054131644112, 52.0913222857884, 62.77136012486049, 54.875225748334614, 70.68518461499895, 32.77328743253435, 20.76001708848136, 67.68682847704206, 51.907490321568076, 59.741764886038645, 49.397335461207796, 47.92599882398333, 45.25429834638323, 52.32062326158796, 53.81054980414254, 59.373579842703684, 57.80550691059658, 58.22405597141811, 59.69177259717669, 60.8689364024571, 54.747823578970774, 48.38130732945034, 45.036322934286936, 44.54931674684797, 43.807016372680664, 45.36014025551932, 48.12032604217529, 54.410349573407856, 56.12960141045706, 60.122845785958425, 59.97081225258963, 56.75869131088257, 55.83225672585623, 62.86252049037388, 59.989808627537315, 64.05258015223912, 69.12780843462262, 60.30121994018555, 26.598979200635636, 1.1819232127496173, 2.3790386617183685, 3.134842642715999, 1.8404318945748466, 1.693814373442105, 0.6519914886781147, 0.043657757341861725, 0.032178651341902356, 0.06936565786600113, 0.09799788825746093, 0.1005767420200365, 0.0927390790145312, 0.12498716823756695, 3.0442995812211717, 25.208854845591954, 38.203766686575754, 48.67559828077044, 39.09035335268293, 15.94611576625279, 18.125574588775635, 48.32524231501988, 52.61588001251221, 58.52241856711251, 60.18838119506836, 29.82262372970581, 0.016041602606752088, 0.009755836550279387, 0.028844618637646948, 0.017419883648731878, 0.09688443943325963, 0.018502996868586967, 0.034017942646252256, 0.04070031496563128, 0.029458828536527495, 0.02659575341801558, 0.0302381293981203, 0.009168297318475587, 0.03036647429689765, 0.03241029641191874, 0.025264201386432563, 0.07245294470340014, 0.03700020583346486, 0.024455060251057148, 0.0682456883202706, 0.06391383255166666, 0.04165851158489074, 0.039804387505033186, 0.021779172588139772, 0.04737547106508698, 0.03924482681655458, 0.04021914542785712, 0.036216158619416614, 0.031041155236640146, 0.05133638870237129, 0.03302694225151624, 0.05114931659772992, 0.03118184268740671, 0.007260927747535918, 0.03647719782644084, 0.06204091305179255, 0.11212072614580393, 0.04817777765648706, 0.0525841297847884, 0.08478036536169903, 0.03647512150928378, 0.04555220336520246, 0.027458441144387637, 0.05247521812894514, 0.011959401075728238, 0.05640039054144706, 0.026695143531209657, 0.024596105629046048, 0.03404017484613827, 0.03601976344361901, 0.03379484372479575, 0.06649208920342581, 0.09860842728189059, 0.061104358306952884, 0.02086008163834257, 0.5066348484584263, 44.11207355771746, 87.92395714351109, 77.96846008300781, 67.98489230019706, 67.12231513432094, 38.85629633494786, 23.96254083088466, 33.23016970498221, 28.676907471248082, 32.0422431400844, 44.12282936913626, 47.23558759689331, 39.21037653514317, 11.557524102074758, 0.7290513536759785, 0.0774132324648755, 0.05514429669295039, 0.4645727883492197, 0.8268948548606464, 1.2932937166520526, 2.175261893442699, 2.9073071607521603, 2.211163018430982, 2.843142283814294, 0.05515183521700757, 7.265505884374891, 32.820889541081016, 57.38124295643398, 66.15666839054653, 66.90198080880302, 63.29092557089669, 64.659546988351, 68.72786317552838, 64.2182946886335, 59.150591305324006, 63.4077456338065, 65.21924522944859, 63.27602168491909, 58.88999911717006, 63.97466305324009, 61.3734381539481, 51.83625044141497, 46.18528400148664, 56.5892699105399, 59.34514781406948, 61.70980044773647, 55.62147617340088, 50.59169258390154, 46.974373544965474, 49.09826414925711, 51.32185445513044, 56.97160496030535, 53.69292722429548, 54.85498217173985, 50.85039138793945, 52.671274525778635, 52.93038327353341, 56.31668165751866, 55.111926555633545, 64.69007737295968, 57.22664206368582, 72.28201961517334, 34.80385330745152, 21.752584627696447, 69.64587306976318, 55.02115876334054, 64.17228371756417, 51.212187562670024, 49.83073629651751, 47.50946126665388, 55.76914276395525, 55.89913313729422, 63.77767467498779, 60.161776542663574, 59.64808232443673, 60.09813104357038, 63.73481123788016, 57.35144560677664, 49.36180237361363, 46.29016011101859, 47.07729026249477, 45.35911192212786, 47.82737609318325, 50.88999611990792, 58.47004999433245, 58.67820412772042, 64.07348728179932, 60.5711852482387, 59.72586740766253, 60.16096360342843, 64.98651531764439, 62.78974505833217, 67.91208907536098, 71.15674495697021, 65.9247236251831, 30.48339741570609, 2.4722506999969482, 1.3111253998109271, 0.027511409284280877, 3.0332810410431454, 2.5455858962876454, 2.0518996672970906, 0.6929624101945332, 0.08877591203366007, 0.2701609161283289, 0.07067166135779449, 0.08096340232129608, 0.03362172230013779, 0.03842551613758717, 2.813432438032968, 27.01464649609157, 39.445923941476, 42.79395859582083, 28.785294158118113, 21.259116615567887, 26.145987919398717, 56.240230628422324, 58.40855148860386, 64.51377378191266, 69.49461773463658, 43.757322856358115, 0.29596782848238945, 0.030193251091986895, 0.05127236892336181, 0.039272846920149665, 0.06214907153376511, 0.008567161093066846, 0.022686149991516556, 0.009940729709342122, 0.019778663059696555, 0.03082071617245674, 0.034489507520837445, 0.03388572670519352, 0.051152783911675215, 0.05599828051137073, 0.0326924075239471, 0.0955791687592864, 0.05576420628598758, 0.05216634898845639, 0.04554717542071428, 0.036146713952933035, 0.025578972085246017, 0.040732362174562046, 0.041818072487201007, 0.05003333005255886, 0.027785489934363534, 0.015634301783783094, 0.04015648950423513, 0.031317783785717826, 0.08013700773673398, 0.023388467662568604, 0.06689097279948847, 0.1697095605943884, 0.1289897241762706, 0.09476091659494809, 0.13018364725368364, 0.21432319735842092, 0.21693695496235574, 0.11033669473337275, 0.24095758316772325, 0.11710544116795063, 0.08782407668020044, 0.09657835907169751, 0.2005418932863644, 0.1875906139612198, 0.10084428837788956, 0.10190717955785138, 0.11993809416890144, 0.11313787049480847, 0.09035471374435083, 0.12799653889877455, 0.17340312525629997, 0.11832563712128571, 0.13780202131186212, 0.19951056077011994, 1.024830088019371, 52.97917004993984, 97.50014509473527, 87.50788511548723, 77.06556946890694, 74.94918291909354, 41.07779523304531, 25.525183745792933, 45.111929757254465, 50.88287421635219, 61.18330764770508, 58.9386226109096, 74.79241071428571, 49.922094685690745, 15.447068350655691, 1.2327301778963633, 0.33792029161538395, 0.10111895935343844, 0.6392630945358957, 1.0594934565680367, 1.519490367599896, 2.438176516975675, 4.77298902613776, 6.2615367855344495, 16.983087505613053, 5.224989320550646, 8.576911057744708, 36.54230301720755, 57.89274154390608, 68.58063084738595, 70.55583000183105, 63.71972669873919, 66.70053168705532, 71.12597833360944, 66.88934203556606, 62.52931962694441, 66.68268871307373, 66.90744209289551, 63.915770121983115, 60.94127409798758, 66.57533209664481, 64.61987972259521, 54.75088773454939, 47.43640095846993, 60.169975417000906, 63.10704844338553, 62.41058880942208, 58.13738414219448, 52.614712715148926, 49.37525061198643, 51.75647817339216, 53.404504026685444, 59.52037443433489, 54.539130960192, 57.06920630591256, 52.781945432935444, 56.455624784742085, 56.956176485334126, 59.397787366594585, 57.91791486740112, 66.10497379302979, 59.96708106994629, 72.13871996743339, 39.05038036618914, 26.33458287375314, 69.6932875769479, 57.485657010759624, 65.60416848318917, 54.36821917125157, 52.035010610307964, 49.66136005946568, 58.18807125091553, 59.12149224962507, 65.58591556549072, 61.15529251098633, 59.88008962358747, 62.9445926121303, 65.22118377685547, 59.90019771030971, 52.5925166947501, 48.71769741603306, 48.974415983472554, 47.66602849960327, 49.751884664808, 52.93687983921596, 60.82942199707031, 60.72887461526053, 67.41107531956264, 63.09386771065848, 61.544078963143484, 61.14081941332136, 66.30136462620327, 65.83924688611711, 67.72578007834298, 73.44582203456334, 68.65506689889091, 30.405556746891566, 2.239694710288729, 6.065693557262421, 11.322219014167786, 6.256386867591313, 4.088577134268625, 1.7789336059774672, 0.43527695749487194, 0.07735419991825308, 0.21158243156969547, 0.21478332552526677, 0.1775179108870881, 0.1795201591615166, 0.20667806187910692, 5.304138422012329, 38.52553081512451, 52.26444707598005, 60.61425713130406, 54.2165504183088, 23.89566615649632, 27.821492161069596, 61.41062491280692, 69.00260189601353, 73.84742791312081, 78.12815747942243, 48.24136018753052, 0.5618385576776096, 0.12545184258903774, 0.13290181782628807, 0.0982689019292593, 0.15809164329298905, 0.1658122590077775, 0.09373539912381343, 0.10588720813393593, 0.15723127446004323, 0.16908385631229195, 0.1923720059650285, 0.10161165720117943, 0.18354186335844652, 0.20646740389721735, 0.14359057641455106, 0.1875162058110748, 0.16172608041337558, 0.13860185125044414, 0.1473403237760067, 0.1617756270404373, 0.0789261484252555, 0.13557363088641847, 0.11135422584733792, 0.09046454142246928, 0.1476416883191892, 0.11251665811453547, 0.08405294189495699, 0.15641053207218647, 0.15409196434276445, 0.10237044934183359], [0.04196554868082915, 0.04860890184396079, 0.03809537153158869, 0.08360088829483305, 0.035877379655305824, 0.05012682539277843, 0.02615198303413178, 0.02836547452690346, 0.037316165664898496, 0.0221254340971687, 0.06160204338708094, 0.026086392446554134, 0.05945813057145902, 0.026920305199122856, 0.022891315232430185, 0.05203753590051617, 0.028482708414750438, 0.03671131276392511, 0.029005594285471097, 0.02697665583608406, 0.01588786014222673, 0.04224241132448826, 0.03322194303785052, 0.031609455456158946, 8.821003879819598, 71.98701299939836, 72.81723240443638, 65.95157146453857, 46.04567732129778, 32.49130174091884, 19.747124331338064, 26.94467987333025, 26.591806922640117, 34.749956130981445, 54.05596712657383, 45.040259088788716, 24.46181579998561, 3.484412810632161, 0.3290065942066056, 0.07251728339386837, 0.06599732182387795, 0.17905818537942, 0.19816380446510656, 0.022510322908471738, 0.42445440537163187, 1.6834073833056857, 1.9235468975135257, 1.403856492468289, 2.5308092491967336, 10.897922924586705, 36.05060332162039, 54.792069707598, 63.70621245247977, 59.12445913042341, 63.711673736572266, 64.60653223310197, 65.2294590813773, 64.47204290117536, 58.127538544791086, 54.97882686342512, 60.4368348802839, 63.435406412397114, 61.15828023638044, 59.66331972394671, 63.65453175136021, 57.12686940601894, 47.2636513710022, 44.040006841932026, 56.756294182368684, 59.84415354047503, 63.4597806930542, 59.15281472887312, 52.87121588843209, 42.417741434914724, 43.41679859161377, 41.61860132217407, 44.35690375736782, 45.152027811322895, 47.994605336870464, 48.96475451333182, 54.92667715890067, 54.73086997440883, 55.85548455374581, 54.237221309116904, 60.3080986567906, 54.77576575960432, 68.69478280203683, 38.29783139910017, 33.86711801801409, 68.53556483132499, 51.051788398197715, 55.055885859898154, 44.12340954371861, 47.96676737921578, 43.07254661832537, 47.18984065737043, 52.254973207201274, 58.72771004268101, 60.13670744214739, 62.3955112184797, 61.10528632572719, 58.01253890991211, 49.108797618321006, 44.72182314736502, 43.480662958962576, 43.97244603293282, 42.2256897517613, 45.63201284408569, 42.14142199925014, 48.81632014683315, 54.16184377670288, 59.35308265686035, 60.68432971409389, 57.586965220315115, 58.82150377546038, 63.29155785696847, 62.75196770259312, 62.333734784807476, 61.08703340802874, 62.082918712071006, 72.2227097920009, 53.56211348942348, 7.81894770690373, 0.38745633353080067, 2.1632630058697293, 3.4206941383225575, 2.167337472949709, 0.6351621917315892, 0.15098066415105546, 0.11651259155145713, 0.06257440442485468, 0.03605000914207526, 0.09798533535961594, 0.15141605293112143, 0.13872713595628738, 4.358991469655718, 38.1482366834368, 46.464372294289724, 51.84146506445748, 37.6995393889291, 28.42016111101423, 37.710531439099995, 39.893429619925364, 55.822456291743684, 63.88631670815604, 58.72358281271798, 7.643312879971095, 0.10460115357169084, 0.05060352338477969, 0.05818729554968221, 0.02550350542047194, 0.03365293151832052, 0.021971683150955608, 0.021446727748428072, 0.041808379614459615, 0.05466507115800466, 0.03654684266075492, 0.01666623310718153, 0.059758741940770826, 0.032066615032298226, 0.033679635263979435, 0.030480559782258103, 0.07216684041278702, 0.0510115197061428, 0.05129471986687609, 0.05257603146934083, 0.01917413585553212, 0.03523602496300425, 0.04772762395441532, 0.02473547332920134, 0.060417151610766134, 0.05844527456377234, 0.03261636410440717, 0.020975987293890545, 0.14450039687965596, 0.0240944256739957, 0.08091751299798489, 0.05771145929715463, 0.04082773027143308, 0.03884117311931082, 0.02542261217188622, 0.0162182880365955, 0.057215877675584385, 0.03593269722270114, 0.03996291703411511, 0.0028832462682787862, 0.024419995257630944, 0.02384852458323751, 0.022698484061818038, 0.004973164235707372, 0.04107920552736946, 0.020360939404261962, 0.019453242753765414, 0.029248028062283993, 0.09029321133026055, 0.029793132562190294, 0.010772013138713581, 0.035498407669365406, 0.042823379792805226, 0.05051110012988959, 12.326857311385018, 83.65859699249268, 79.57601615360805, 72.95584201812744, 52.59835318156651, 43.275037969861714, 24.792200905936106, 31.23983042580741, 30.469435010637554, 31.61684662955148, 44.767344270433696, 41.7332570212228, 28.530333484922135, 4.430504935128348, 0.24918387031980924, 0.020058504472087537, 0.06423072876142603, 0.3526795410684177, 0.8347714522055217, 1.2904768735170364, 2.8453001337391988, 2.4298393300601413, 2.4883679151535034, 0.5354886544602258, 2.6217038461140225, 12.77260683264051, 39.80288764408657, 56.89598076684134, 67.17701830182756, 61.44678333827427, 65.01469026293073, 66.69789137159074, 67.24429076058524, 65.25420161655971, 58.7682249886649, 56.12341056551252, 62.89141804831368, 65.14262744358608, 62.0356570652553, 60.24334144592285, 65.35068430219377, 59.85112953186035, 50.21499252319336, 46.183543477739605, 60.23151561192104, 62.18312563214983, 66.7385105405535, 62.01074777330671, 56.09026418413435, 46.1306676864624, 44.814213344029014, 44.125240394047324, 47.5464882169451, 46.699530601501465, 51.016390800476074, 50.79297147478376, 58.25502756663731, 57.35306453704834, 58.95941162109375, 55.94074937275478, 62.0948348726545, 57.676207883017405, 70.9633071081979, 39.503934451511924, 37.29355614525931, 69.64150960104806, 54.7986044883728, 57.505442006247385, 45.86447525024414, 50.70923178536551, 44.552200249263215, 49.48122453689575, 54.035251072474885, 60.89827864510672, 60.95376001085554, 63.23968955448696, 62.55360358101981, 59.83192471095494, 51.77184411457607, 47.360248701913015, 44.88850000926426, 46.155976499829976, 45.67467130933489, 48.107815810612266, 44.86791249683925, 50.68511111395699, 57.397362777165, 62.648752212524414, 63.21753174918038, 58.34512138366699, 58.23172330856323, 66.0701424734933, 63.878743171691895, 64.89584132603237, 63.197708538600374, 65.73825481959751, 75.91812310900006, 58.675480433872764, 10.14928753035409, 0.37403159961104393, 0.639949229146753, 1.7415846501077925, 2.9641564530985693, 1.0929452329874039, 1.4109815444265092, 0.39297814294695854, 0.16399202096675122, 0.12613632157444954, 0.03282816541780319, 0.05911903948123966, 0.1292633502078908, 4.745883234909602, 37.40120458602905, 42.06348752975464, 51.437045165470664, 28.36100935935974, 29.41157524926322, 49.47561386653355, 45.32247059685843, 63.142553738185335, 69.16529396602085, 71.47444438934326, 12.43684903212956, 0.17167629434594087, 0.019955808197015097, 0.05063087513138141, 0.04615221491881779, 0.02258037995280964, 0.05083318713254162, 0.05442153815446155, 0.06119202503136226, 0.05197091054703508, 0.048828794687454186, 0.027556248574650714, 0.08097362105867692, 0.021546670867662345, 0.06066356160278831, 0.03477076367874231, 0.04559720041496413, 0.020187709414001023, 0.01255962043069303, 0.18364417286855833, 0.022867322234170775, 0.04051917664972799, 0.13065415700631483, 0.06857834689851318, 0.04168037398319159, 0.036093917143132, 0.06071556452661753, 0.03628025982262833, 0.013196438268226172, 0.04450247237192733, 0.14445105381309986, 0.14888594512428555, 0.11372120026499033, 0.15184309573045798, 0.0939475634534444, 0.13715628667601518, 0.10730173651661191, 0.12504622792559011, 0.21799247046666487, 0.20922387098627432, 0.13932708304907593, 0.09273649379611015, 0.22660617397299834, 0.10333877309624638, 0.11718202063015529, 0.15178442959274563, 0.11581401260835783, 0.1468773457620825, 0.17363955399819783, 0.09762396117938416, 0.13211162308497088, 0.18937556818127632, 0.20132854607488426, 0.0843813664146832, 17.327652147838048, 94.63292230878557, 89.23665251050676, 84.47983237675258, 62.912929671151296, 46.3354936327253, 32.37525987625122, 37.63188477924892, 38.88435663495745, 50.63121393748692, 74.83117471422467, 60.74033219473702, 37.071147782461985, 5.580897765500205, 0.5791074367506164, 0.12840783968567848, 0.19076975408409322, 0.5446304210594722, 1.4373537578753062, 1.3574861692530769, 3.82224486555372, 6.9723900471414835, 6.415303025926862, 7.604530641010829, 5.878790055002485, 14.408895441464015, 43.21856301171439, 59.93825994219099, 69.51205076490129, 65.0332419531686, 65.86271790095738, 69.71754373822893, 69.371169090271, 67.47269194466728, 62.178532872881206, 61.09662192208426, 66.22075162615094, 68.64841052464077, 62.72442504337856, 59.66938550131661, 69.05898652757917, 63.457751819065635, 52.69329684121268, 50.076876231602256, 63.322359221322195, 65.26445715767997, 69.28367737361363, 64.14030810764858, 59.350734165736604, 48.15685619626726, 46.746052265167236, 45.94245488303048, 49.549657344818115, 49.57617514474051, 52.18630763462612, 54.07827431815011, 60.558497837611604, 60.22884750366211, 60.86357239314488, 58.65007781982422, 64.41079453059605, 61.01848248073033, 70.25502164023263, 43.60212789263044, 40.69386557170323, 70.69458552769252, 57.58035748345511, 60.18716526031494, 48.634933948516846, 52.39703260149275, 46.989405972617014, 53.006504263196675, 57.11570712498256, 63.35935837881905, 63.484439849853516, 65.15404333387102, 65.7236636025565, 63.19210829053606, 54.865064007895334, 50.5011818749564, 47.4357339314052, 48.69980233056204, 47.41691126142229, 50.96380683353969, 46.40325246538435, 54.387024470738, 60.839594159807476, 65.70539678846086, 66.83201244899205, 60.26433195386614, 59.51825523376465, 66.49833215985979, 67.17201559884208, 69.24148096357072, 66.60326385498047, 68.05176176343645, 80.36804131099156, 60.192897524152485, 9.203475287982396, 1.6633927715676171, 10.757546731403895, 10.876076919691902, 10.142258558954511, 2.364618326936449, 1.1605139672756195, 0.4744831994175911, 0.20391102321445942, 0.23842955167804444, 0.2956463657319546, 0.2520891401384558, 0.25276045554450577, 7.021416102136884, 54.00299406051636, 62.1973694392613, 68.02310044424874, 52.91219636372158, 39.223717076437815, 50.5338488306318, 53.89448404312134, 71.35209356035504, 77.49642726353237, 78.9327449798584, 14.623046738760811, 0.25519417066659245, 0.1267600581049919, 0.1115006333483117, 0.11367189791053534, 0.11257590779236384, 0.08993644440280539, 0.10101645985352141, 0.15656666297997746, 0.2075798213481903, 0.2119445792798485, 0.15157602434711798, 0.26874649631125586, 0.12260814303798334, 0.1491463804351432, 0.10059688093938998, 0.13784292340278625, 0.1998506560921669, 0.15106356755963393, 0.3153073793011052, 0.11234084969120366, 0.10355158203414508, 0.1700217274150678, 0.18675550020166806, 0.09260556367891175, 0.11531619860657624, 0.19673338479229383, 0.07187216622488839, 0.23981691151857376, 0.17943607510200568], [0.07912293036601373, 0.0935130567689027, 0.043697248079947064, 0.021678081048386436, 0.06270756692226444, 0.012077946232498755, 0.08787692777280297, 0.06681927878941808, 0.009291798325388559, 0.020134493608825972, 0.04693582108510392, 0.008892158162780106, 0.050125397076564174, 0.0358954151161015, 0.022840901776882153, 0.062210933571415286, 0.04784971954567092, 0.01485750132373401, 0.0686487720480987, 0.027225047150360684, 0.03147622510524733, 0.06448737784687962, 0.02746692283212074, 0.7493545870695795, 47.481303691864014, 74.06226621355329, 67.73745305197579, 71.24759265354702, 55.799252782549175, 49.49291140692574, 67.60360295431954, 24.35466241836548, 31.608487946646555, 42.519424847194124, 41.33880431311471, 20.22303077152797, 2.8739938054765974, 0.28755719693643705, 0.03353761449190123, 0.06750983066324677, 0.04777650222448366, 0.038355742381619554, 0.43840777235371725, 0.7848143385989326, 1.917119813816888, 1.993729782955987, 2.254315674304962, 2.925705122096198, 20.30653248514448, 42.53621169498989, 59.80577169145857, 61.9149112701416, 56.8649640083313, 61.46694006238665, 62.01841858455113, 60.05602496010916, 62.17083426884243, 59.61134719848633, 54.37152998788016, 52.659038748059956, 61.61850111825125, 58.83842263902937, 60.22972992488316, 55.90454925809588, 61.14557892935616, 56.01050581250872, 47.56080845424107, 40.39206709180559, 54.938937255314414, 54.236776624407085, 58.185281549181255, 57.313192299434114, 56.88158062526158, 49.21165527616228, 45.38337503160749, 46.876942430223735, 48.86213309424264, 47.898977279663086, 53.795531272888184, 54.1308582850865, 57.44731337683541, 54.39381286076137, 57.964575495038716, 53.70982871736799, 60.193272726876394, 54.03979172025408, 68.56480285099575, 36.01769665309361, 36.21552228927612, 64.87013299124581, 52.067802633558, 52.07270458766392, 41.76946408408028, 44.242439133780344, 41.794522762298584, 44.49289737428938, 45.711111136845176, 52.036622592381065, 54.23454277856009, 60.01660088130406, 58.096424511500764, 54.92852537972586, 46.55837447302682, 43.5677273614066, 42.706915037972585, 44.55425691604614, 44.49143130438668, 43.24372591291155, 43.886465549468994, 44.51708057948521, 51.449541500636506, 56.75860445840018, 59.08916922977993, 55.86883899143764, 56.67254754475185, 63.76788466317313, 61.20149108341762, 58.94971888405936, 58.78150994437081, 58.92155088697161, 58.778779302324565, 70.17329692840576, 69.76483317783901, 28.2013658114842, 0.7469729834369251, 1.8904923626354762, 2.6455945755754198, 1.948514597756522, 0.8278381271021706, 1.4386856406927109, 0.17598900864166872, 0.11133885024381535, 0.1742519997060299, 0.19748573085027082, 0.03000746141853077, 0.07415198960474559, 7.352776561464582, 45.25712973730904, 38.1825156211853, 42.34745693206787, 20.21945592335292, 17.14828440121242, 45.05632332393101, 53.18991238730294, 56.54370362418038, 60.83402170453753, 33.21483850479126, 1.2543977009398597, 0.037373600261551995, 0.05532316530921629, 0.025872029663462724, 0.014776786190590687, 0.029576059031699384, 0.007563975905733449, 0.026165540163804377, 0.05344001350126096, 0.05066404870844313, 0.03636786547888603, 0.018006869026326706, 0.01917975751816162, 0.02964185657245772, 0.03561401307316763, 0.07939945374216352, 0.04360568317185555, 0.04192787641659379, 0.04112333744498236, 0.05887245985546282, 0.049627050424792936, 0.022920795882652913, 0.006027585178214524, 0.06448935238378388, 0.032366347698760886, 0.07434486996914659, 0.017733585654890964, 0.020312946622392962, 0.017384759283491542, 0.05357119467641626, 0.027635492983141115, 0.023341178860781447, 0.019101804022544196, 0.06071524561515876, 0.09796661457845143, 0.11915066785046033, 0.029119214974343777, 0.02502256997727922, 0.018914346849279742, 0.059953617198126655, 0.09860348754695483, 0.08640106660979134, 0.032342395412602594, 0.086706475221685, 0.008768510422669351, 0.0424962716310152, 0.06312252501291887, 0.01742777501099876, 0.07391773217490741, 0.06166989688894578, 0.044483944973243136, 0.02094685100018978, 1.3504119259970528, 59.486627033778596, 83.21558679853166, 77.0835930960519, 78.21082019805908, 65.71868174416679, 52.29868432453701, 63.52291897365025, 29.133150509425572, 27.390943561281475, 41.36543328421456, 45.24105160576956, 24.82361544881548, 3.3777314722537994, 0.2702508898718016, 0.00830845519833799, 0.05295895252908979, 0.14054969458707742, 0.4959850513509342, 1.2833514958620071, 1.7649941082511629, 2.9166698583534787, 1.8212351075240543, 1.0170851264681136, 2.511393811021532, 21.739242349352153, 46.22373880658831, 61.57775688171387, 63.82006563459124, 61.602158955165315, 65.4252940586635, 62.87258843013218, 63.86282484872, 65.21464552198137, 62.73534066336495, 55.97019236428397, 54.801213536943706, 63.72220720563616, 60.979016712733674, 61.20540986742292, 58.02136312212263, 62.526582036699565, 59.142718996320454, 49.355542046683176, 43.56822068350655, 57.534124170030864, 56.99433946609497, 60.23620564596993, 61.25880677359444, 59.224839755467, 50.390563079289024, 47.6705448286874, 49.29349115916661, 51.260293415614534, 49.9084484236581, 57.48302016939436, 56.959740911211284, 59.48410483769008, 57.85484606879098, 61.3314710344587, 58.950281688145225, 62.482412338256836, 57.748298917497905, 70.35817459651402, 38.51248557226998, 38.464101791381836, 67.19006701878139, 55.62104885918753, 53.462601389203755, 44.69584035873413, 46.616444042750764, 43.66052055358887, 46.081328528267996, 47.83718000139509, 54.98801238196236, 56.90138993944441, 61.6575847353254, 61.929988861083984, 58.01367494038173, 48.6446544783456, 44.54010343551636, 44.638604572841096, 46.28539712088448, 47.40712472370693, 45.5107216153826, 47.335867473057334, 47.60353292737688, 54.30598415647234, 59.52341774531773, 62.03998579297747, 58.662647111075266, 56.84340027400425, 65.2227749143328, 63.24521337236677, 61.57514435904366, 63.34309264591762, 62.306379726954866, 62.683104106358115, 71.15177699497768, 75.98016357421875, 31.438903263637, 2.350376691137041, 1.1310475255761827, 0.7330943367310933, 2.747277553592409, 1.9557053319045474, 1.625272457088743, 0.6608557073133332, 0.14551441318222455, 0.6478664843099458, 0.08812126144766808, 0.03790748518492494, 0.0283465518815709, 7.141686814171927, 46.273720673152376, 39.432051862989155, 40.25536128452846, 24.83983428137643, 23.55576549257551, 52.140616280691965, 59.13005937848772, 63.50107383728027, 68.09059524536133, 49.23355599812099, 2.1207306938511983, 0.06991515588015318, 0.026668465230613947, 0.034725691990128586, 0.009542170113750865, 0.05013671164800014, 0.013508487193446075, 0.02107200169536684, 0.04032356518187693, 0.021695046120190194, 0.03322203803275313, 0.008708569487290723, 0.002455968950276396, 0.013444322377576359, 0.02462105536168175, 0.037187030272824426, 0.057627517729997635, 0.010082799675209182, 0.0416077741288713, 0.047178393961595635, 0.06207241064735821, 0.02018565684556961, 0.031676610066954575, 0.033391688750790696, 0.0241364185099623, 0.010022653482987412, 0.05246456512915237, 0.0119102335801082, 0.017631447474871362, 0.17919668794742652, 0.25907416961022783, 0.22305355460516044, 0.08357346190937928, 0.1256135781960828, 0.19144729844161443, 0.21778805500694684, 0.11025904318583862, 0.11485407554677554, 0.1545830201357603, 0.19175723966743263, 0.15397780761122704, 0.14571192115545273, 0.12489088411842074, 0.11189069598913193, 0.21829162298568658, 0.1407148228692157, 0.12197768901075635, 0.1155776245785611, 0.1989704876073769, 0.1373186736766781, 0.19907678690339836, 0.22309852790619644, 2.4340935817786624, 74.9283035823277, 92.62684535980225, 88.06025995526994, 87.4607207434518, 72.69191469464982, 60.94467871529715, 78.06886155264718, 35.645599773951936, 44.50764145169939, 58.68142114366804, 57.08212300709316, 31.996124471936906, 4.805504424231393, 0.5699772323880876, 0.13338418837104524, 0.14933470104421886, 0.3055559354169028, 0.48625133080141886, 1.3870941804988044, 3.9341438668114797, 8.344254970550537, 9.003517423357282, 8.585303613117762, 4.9207376922879895, 27.678291525159562, 49.897994858878, 64.27796581813267, 66.68177155085972, 64.35743931361607, 65.80776459830147, 64.98497976575578, 64.58042785099575, 67.19766139984131, 65.82848412649972, 58.799109731401714, 58.29503182002476, 66.89841638292584, 64.11602415357316, 60.826566287449424, 59.45312976837158, 64.97845540727887, 60.94934095655169, 51.391110624585835, 45.581892013549805, 60.36591461726597, 60.706181798662456, 63.38674817766462, 62.89920003073556, 61.549644470214844, 53.52016026633126, 50.21709087916783, 52.81042262486049, 53.84561736243111, 53.876498631068635, 59.601842062813894, 60.05493409293038, 61.59601674761091, 59.03837789808001, 62.46616744995117, 62.06554126739502, 63.23668793269566, 59.71984331948416, 71.09209891727993, 40.693382671901155, 42.5098363331386, 67.99382073538644, 59.39056124005999, 57.20686401639666, 46.56199448449271, 47.68830442428589, 46.58325597218105, 49.043679101126536, 51.027563503810335, 57.62783799852644, 59.62988499232701, 65.46185547964913, 65.3369060243879, 61.406886781964985, 51.834454332079204, 47.6159667287554, 46.86431407928467, 48.573928764888215, 49.886891637529644, 47.723312922886436, 49.19125883919852, 48.772598607199534, 56.13139057159424, 62.68443816048758, 63.8845796585083, 60.51457827431815, 58.20068917955671, 68.24521350860596, 66.94054331098283, 63.70485060555594, 65.3527409689767, 63.49523040226528, 64.68622807094029, 75.77604634421212, 79.46013409750802, 33.171339307512554, 3.067932141678674, 7.3109761987413675, 8.930735911641802, 6.503650673798152, 2.542571029492787, 2.5645373250756944, 0.6527161097952298, 0.2001140226743051, 0.932074785232544, 0.3908421689910548, 0.1546914093196392, 0.13572122582367488, 10.745308348110743, 62.41707842690604, 49.029511724199565, 59.89545209067208, 31.261046750204905, 25.70059970446995, 58.18645926884243, 69.32333769117082, 71.1604413986206, 78.47350379398891, 54.56481497628348, 2.062899968453816, 0.1427682733961514, 0.2038044932165316, 0.10822891390749387, 0.06628402322530746, 0.11883308632033211, 0.08570669458380767, 0.08755879662930965, 0.2664684099810464, 0.10663859745753662, 0.1775510369666985, 0.11333249469420739, 0.2548493934529168, 0.09361445025673934, 0.10210221087826149, 0.13846934693200247, 0.11078025986041341, 0.10958417225629091, 0.17286550839032444, 0.10860199281679732, 0.20720102238867963, 0.07548538555524179, 0.12004101436053004, 0.1264474434512002, 0.09604456914322716, 0.1207614964140313, 0.07249794514583689, 0.11191428186638014, 0.10773080813565425], [0.06220016522066934, 0.023102655142013515, 0.021502111472987702, 0.04391602134065969, 0.01083797522421394, 0.038595200782375674, 0.018328503106853793, 0.023486719533268894, 0.07706761386777673, 0.04973350578386869, 0.014521314363394464, 0.05024495494685002, 0.06054927594959736, 0.05031521724803107, 0.029038543945976665, 0.0774356173351407, 0.02548857425738658, 0.024820997579289333, 0.006214052114436137, 0.03850848400699241, 0.06013047056538718, 0.02926294904734407, 0.20901180165154593, 11.072552868298121, 64.11203588758195, 67.05674498421806, 64.5444917678833, 52.11662415095738, 39.77350718634469, 24.651479039873394, 31.14672109058925, 37.71534306662423, 56.098674978528706, 40.78465073449271, 27.03335973194667, 2.5559604253087724, 0.04242822474667004, 0.04128770237522466, 0.052247399996433935, 0.012021129102712231, 0.07061926488365446, 0.363665728696755, 1.0294179618358612, 0.9564713218382427, 1.5501755667584283, 0.7536836947713579, 7.706506746155875, 21.80415936878749, 51.152898584093364, 55.69271257945469, 60.345799582345144, 55.02893727166312, 61.900695255824495, 62.049087933131624, 60.33830942426409, 61.6372195652553, 62.502305030822754, 54.12983342579433, 48.613425799778526, 55.19891800199236, 61.041522707257954, 59.62016446249825, 59.2830239704677, 58.314674377441406, 61.393893650599885, 54.751742362976074, 44.44220331736973, 41.03373670578003, 54.41874647140503, 58.27004957199097, 56.59777103151594, 60.298266955784385, 57.82875905718122, 51.2253543989999, 49.39917325973511, 49.9074444089617, 55.079092843191965, 53.415138244628906, 59.33617074148995, 57.39660889761788, 60.67911856515067, 56.55215263366699, 62.12380191258022, 56.072904109954834, 62.89321763174874, 51.130629607609336, 65.06855964660645, 33.68850415093558, 38.613001687186106, 61.66488034384591, 49.35479164123535, 46.76677526746477, 42.12349912098476, 46.49960313524519, 42.373425824301584, 43.01077018465315, 39.82093211582729, 42.89145571844918, 44.57343741825649, 48.82576969691685, 44.95853090286255, 46.00825432368687, 40.52101523535592, 43.39682599476406, 43.61362716129848, 48.54565307072231, 49.93453890936715, 45.22784308024815, 41.49834190096174, 43.60388231277466, 49.0436304637364, 53.02781438827515, 57.66862392425537, 61.28206239427839, 55.65526178904942, 58.772373063223704, 62.35562855856759, 58.95335974012102, 57.20792361668178, 54.12133230481829, 61.05589158194405, 59.84844057900565, 61.59573187146868, 70.80048997061593, 49.94827202388218, 8.93022174494607, 1.0345166368143899, 0.4285171745078904, 2.457328574998038, 0.523804172873497, 0.761254788509437, 0.21834980057818548, 0.10464495300714459, 0.13393081618206842, 0.03830317288104977, 0.09720175633473055, 0.2904428978051458, 13.584260651043483, 45.39216797692435, 28.80676061766488, 26.697230202811106, 26.28569882256644, 29.329885278429302, 40.57132714135306, 56.209130491529194, 59.0801226752145, 63.06514385768345, 16.612135342189244, 0.4206713012286595, 0.06978379828589303, 0.07483536936342716, 0.013263940628218864, 0.06156149413436651, 0.033070605979966264, 0.049215800528015406, 0.057568865162985663, 0.033600443441952975, 0.03813512011298111, 0.03337259138269084, 0.01642137356767697, 0.022134448434891443, 0.03623931701960308, 0.040133578769330464, 0.025024183194286058, 0.03830140869000128, 0.028991117740848234, 0.07503293161945683, 0.04997705914346235, 0.010674023352164243, 0.029723043287439004, 0.014326973452365823, 0.026644529907831123, 0.047972944897732565, 0.09011881425976753, 0.01839784768942211, 0.030940803300057138, 0.03989268187433481, 0.022784949779244404, 0.045345589452024014, 0.03237526025623083, 0.022521277856347815, 0.05722590642316001, 0.034310903533228805, 0.03597826424187847, 0.010298234543630054, 0.021423170708918145, 0.008828609965608587, 0.06089988177908318, 0.05023097373279078, 0.13684055076113769, 0.026578757812135985, 0.01157778110687754, 0.042622384149581194, 0.02580104472248682, 0.11372291017323732, 0.05727428596998964, 0.07673461602202483, 0.03796018021447318, 0.17276262891079697, 14.80798694065639, 75.57227652413505, 76.69136728559221, 71.41694109780448, 60.46409961155483, 49.02476263046265, 39.897306714739116, 37.272878306252615, 29.008548464093888, 44.55763374056135, 42.93317270278931, 30.16550690787179, 2.5117525117737904, 0.005104431499993163, 0.06896112207323313, 0.05201966668080006, 0.06824511156550475, 0.4281923190823623, 1.5836943281548364, 1.7474287365164076, 2.235125618321555, 1.951467365026474, 0.30287542353783337, 7.464375921658107, 25.466478415897914, 55.78803144182478, 59.78389876229422, 65.89033004215786, 58.05750070299421, 63.841382707868306, 62.29137856619698, 60.720467294965474, 64.23243427276611, 66.03019033159528, 56.02192865099226, 50.68550716127668, 57.7489138330732, 63.13455636160714, 62.353627477373394, 59.72570065089634, 59.83200808933803, 62.56256675720215, 58.83692182813372, 46.63538483210972, 43.21672868728638, 57.98644495010376, 59.624910082135884, 58.90905107770647, 61.07028824942452, 61.69676562717983, 54.09491177967617, 53.03046860013689, 51.46643951960972, 57.12253025599888, 56.02357884815761, 61.57132979801723, 58.62033952985491, 63.21085453033447, 59.09674971444266, 63.224070004054475, 58.85427148001534, 63.282733644757954, 54.17975623267037, 65.92312553950718, 35.634666783469065, 40.88553510393415, 65.69677407400948, 52.54844774518694, 49.056814670562744, 44.58236585344587, 48.66310541970389, 45.56066526685442, 44.00892407553536, 40.80062811715262, 45.091707025255474, 46.9546719278608, 49.93072782244001, 46.70460626057216, 48.98347643443516, 43.32219191959926, 44.901236057281494, 46.49583721160889, 52.15384565080915, 52.40286214011056, 49.132824489048545, 44.94009733200073, 45.237032072884695, 49.76297746385847, 57.598224776131765, 60.54927062988281, 62.23000512804304, 57.1641013281686, 61.46696090698242, 63.36135251181466, 62.30631719316755, 61.48791667393276, 56.643993922642295, 62.556396756853374, 64.21283340454102, 63.651953969682964, 74.64410836356026, 55.11807223728725, 10.432054025786263, 0.15557817316481046, 1.2323336963142668, 1.6601186501128333, 3.5944460034370422, 2.124353745153972, 1.8831646186964852, 0.6866187591637883, 0.2439019094620432, 0.17899609942521366, 0.07887597754597664, 0.228045468883855, 15.538030692509242, 46.14010681424822, 31.169181142534526, 26.731180838176183, 28.404336588723318, 38.03167370387486, 47.12370075498308, 62.283645221165244, 63.541505404881065, 72.2036439350673, 28.362412895475114, 0.40502808349473135, 0.13392633785094532, 0.11815645119973592, 0.02542889370982136, 0.03153069789654442, 0.0760196368875248, 0.08471984682338578, 0.10321362409740686, 0.0737027654956494, 0.061898027147565565, 0.005337482833835695, 0.03983762215024658, 0.033988294058612416, 0.03811228062425341, 0.07164136932364532, 0.027556392763342177, 0.0516832863379802, 0.017455033459035412, 0.002924934187571385, 0.018974463355594447, 0.03852253646722861, 0.03424788120069674, 0.007934655345577215, 0.03356434537896088, 0.05458400318665164, 0.03660221111827663, 0.027680400127012814, 0.018362609669566154, 0.18321217676358564, 0.1260187585971185, 0.12763322410838945, 0.07988446378814322, 0.0907188563474587, 0.11734431263591562, 0.09792113237615142, 0.12690170907548495, 0.13925903955740587, 0.1639804315886327, 0.09988251927175693, 0.18208700285426208, 0.1714671291410923, 0.20497907804591314, 0.13550959075135843, 0.1746180829192911, 0.10851965259228434, 0.10113786333905798, 0.1959844042680093, 0.16676344296761922, 0.11689502745866776, 0.1943233369716576, 0.2682341480893748, 21.733622993741715, 85.10227979932512, 84.49197087969098, 83.0384772164481, 69.56929002489362, 55.308709962027415, 36.41309431621006, 39.28162683759417, 51.96480253764561, 75.73145975385393, 58.00093541826521, 39.58001722608294, 3.9654806767191206, 0.16695265924291952, 0.09586566660021033, 0.21885743976703712, 0.13312859780022077, 0.26569672567503794, 2.177069293601172, 3.035621715443475, 6.948347108704703, 5.672263537134443, 5.351163395813533, 11.171746219907488, 28.272362504686626, 59.417263167245046, 61.456260681152344, 69.22593089512416, 61.584392411368235, 65.64960970197404, 63.719983782087056, 62.90145124707903, 68.13256931304932, 68.88537188938686, 58.70353725978306, 53.2523558480399, 60.88045651572091, 65.7195155279977, 64.13564586639404, 59.595178740365164, 60.43019240243094, 65.23983969007219, 61.41958114079067, 48.478057520730154, 46.43047898156302, 60.70038005283901, 63.50483281271798, 59.572861126491, 62.92152459280831, 64.80477823529924, 57.51132018225533, 55.78484569277082, 54.67191798346383, 60.81847858428955, 58.173570360456196, 64.60249532972063, 60.66346427372524, 65.19411359514508, 60.30718844277518, 64.81673608507428, 61.092939376831055, 65.27729048047746, 55.727074895586284, 65.60766342708042, 37.63450077601841, 45.0036073412214, 64.91046728406633, 55.51182317733765, 50.52187361036028, 48.14904294695173, 52.39811304637364, 48.52433599744524, 46.08614362989153, 43.862362248556956, 47.589118889399934, 49.60845300129482, 51.850601945604595, 50.49970885685512, 51.24665757587978, 44.84887095860073, 47.75206109455654, 48.62016902651106, 54.28350673403059, 56.03623846599034, 51.21534204483032, 45.8519789150783, 47.53764316013881, 54.25991759981428, 60.2090242930821, 65.11638409750802, 65.58284446171352, 58.39800412314278, 61.838981355939595, 65.92013781411308, 65.65074225834438, 63.96957002367292, 60.28963034493582, 65.81005750383649, 66.11051150730678, 64.31680624825614, 79.03494603293282, 58.85885034288679, 11.54185244015285, 3.9608332003865923, 4.475881014551435, 8.633102876799446, 4.147747124944415, 2.426067761012486, 1.5473804367440087, 0.49419350177049637, 0.7319733968802861, 0.4979705533811024, 0.24045158603361674, 0.560249102967126, 21.14029199736459, 64.43599564688546, 39.24162605830601, 40.18818262645176, 36.693787642887656, 41.910786969321116, 54.843917165483745, 71.91120120457241, 73.06897258758545, 82.51099082401821, 31.451357909611293, 0.8311142570206097, 0.2653319723904133, 0.1557653131229537, 0.08796866570732423, 0.10757578323994364, 0.15190868292536053, 0.09208251495978662, 0.239538169332913, 0.188131894916296, 0.11940528133085795, 0.18913194696818078, 0.2012538800814322, 0.13493621508990014, 0.11953883059322834, 0.17599202133715153, 0.16412614019853727, 0.1450717505067587, 0.08407087557549987, 0.16282199589269503, 0.1968007090368441, 0.2356153412589005, 0.07753503628607307, 0.15980902899588856, 0.15900645777583122, 0.10901982789593083, 0.19794405411396707, 0.11160757725260087, 0.14968828564243658], [0.02863520916019167, 0.030743553170136044, 0.027653925386922698, 0.05182813999376126, 0.05354564444028905, 0.03637316144470658, 0.007651806326716074, 0.07307795687977757, 0.04912897179435406, 0.03601543778287513, 0.015295297206778611, 0.03937607923788684, 0.04694607035656061, 0.020539721507312994, 0.05712782418621438, 0.028187667817941735, 0.07155948371759482, 0.05164258102221148, 0.05506308622924345, 0.022052807101447667, 0.08587896783969232, 0.06375145233635392, 0.51518379258258, 45.04028688158308, 72.608473777771, 63.96152400970459, 59.971757207598, 48.921977928706575, 31.19921820504325, 12.897468566894531, 17.57822503362383, 44.30101244790213, 44.75377096448626, 37.46881750651768, 6.10275741985866, 0.028184147917532494, 0.021113823201241236, 0.05957577497299228, 0.034572566992470195, 0.05762144484158073, 0.11444980438266482, 1.4067102479083198, 1.7929932858262743, 1.1049817928246088, 1.89748073049954, 6.803560980728694, 30.42853443963187, 49.29969242640904, 56.08893360410418, 61.257257325308665, 59.861371176583425, 60.37374523707798, 57.84927013942173, 61.58969388689314, 63.765181813921245, 59.30694661821638, 57.91525370734078, 47.075775555201936, 49.912499223436626, 53.00044543402535, 59.217648369925364, 59.24715736934117, 55.03016710281372, 57.22444295883179, 57.89921031679426, 53.09747007914952, 44.88441794259207, 41.01150941848755, 50.16098764964512, 55.66566324234009, 56.23390776770455, 54.19055025918143, 59.563126700265066, 55.696395124707905, 54.88211836133684, 56.381355490003315, 57.53339113507952, 57.912967750004356, 60.855922426496235, 57.55711923326765, 59.72197641645159, 57.88963917323521, 60.77161298479353, 54.95384461539132, 59.156191553388325, 51.92578840255737, 61.67951325007847, 32.01655217579433, 40.30815369742257, 62.793038504464285, 52.385126863207134, 47.875641754695344, 46.02273089545113, 52.42895262581961, 50.3991128376552, 50.27541753223964, 43.61524609157017, 41.01270450864519, 39.08096981048584, 40.6768980707441, 41.10824223927089, 40.421680314200266, 40.51483481270926, 45.07435737337385, 47.15736130305699, 52.068327222551616, 49.12522315979004, 47.192842279161724, 41.41647822516305, 43.45024027143206, 42.859612124306814, 51.05895546504429, 56.11460024969918, 60.141307149614605, 59.17397199358259, 57.97714826038906, 59.96303721836635, 61.004064968654085, 63.15927805219378, 57.02580438341413, 48.057889529636924, 57.74214628764561, 65.98595809936523, 61.474027224949424, 65.09194033486503, 56.43605865750994, 12.276739086423602, 1.9176185641969954, 1.8095165363379886, 1.6008730977773666, 0.9417614425931657, 0.14063277441476071, 0.275747647775071, 0.027542628680488894, 0.15225724636444024, 0.04257115814834833, 0.10363200878990547, 1.8598143288067408, 26.54843626703535, 43.619168349674766, 43.07807738440377, 21.784695727484568, 24.854217052459717, 49.181361130305696, 44.11816365378243, 54.166460854666575, 57.63466460364205, 52.732036522456575, 5.443783751555851, 0.2876879099224295, 0.02583711564407817, 0.022675858311621205, 0.03558506676927209, 0.03390456622998629, 0.05686510221234389, 0.009976627604503716, 0.048039166522877555, 0.017929154714303355, 0.03588475193828344, 0.030532457533159425, 0.09264190601451056, 0.01079797643303339, 0.06874910023595605, 0.03503498860767909, 0.022563206231487647, 0.050333893924419365, 0.02326946788733559, 0.03354280867746898, 0.030935965345374176, 0.03137896389567426, 0.010974650836682745, 0.025882060107375895, 0.047746633112962754, 0.024344738938712647, 0.06560181733220816, 0.013238030768531774, 0.062133336306682656, 0.04106129559555224, 0.03866478794121316, 0.026867922295683196, 0.03981061984917947, 0.012229620013386011, 0.01819484188620533, 0.018502645726714815, 0.03431146332461919, 0.02925431468923177, 0.03202168244336333, 0.025532952143943737, 0.010024063987657428, 0.02898994048259088, 0.10469202298138823, 0.014890612136306507, 0.024756662281496183, 0.023415220602016364, 0.07721157185733318, 0.017794971021690538, 0.02790346342538084, 0.062021031975746155, 0.8508315618549074, 53.544159344264436, 83.1276365007673, 72.3853462764195, 69.16714913504464, 56.39114202771868, 40.227999278477256, 19.64451333454677, 22.011226109095983, 37.35408190318516, 43.18061542510986, 38.54640320369175, 6.835981275354113, 0.04560476608042206, 0.028546840152037994, 0.07827222387173347, 0.24256117854799542, 0.3039461246558598, 1.061775722673961, 2.902693339756557, 2.5731624279703413, 0.6142692299825805, 0.630778584097113, 7.388465983527047, 32.1944260597229, 52.329200812748496, 59.74596854618618, 64.02547522953579, 62.18571036202567, 62.16820090157645, 58.90055343082973, 62.11693014417376, 66.6883931841169, 61.69065121241978, 61.3002736227853, 49.899721486227854, 49.98490292685372, 56.45544760567801, 61.85640048980713, 60.61769648960659, 55.54346179962158, 59.39311122894287, 61.08222525460379, 55.652145521981375, 47.694304193769185, 43.52465547834124, 52.35854652949742, 58.98840645381382, 58.717440605163574, 56.88628455570766, 61.93839618137905, 57.606962135859895, 57.48430906023298, 58.11725868497576, 59.70147228240967, 60.1798210144043, 62.398554529462544, 58.449080330984934, 59.68406704493931, 58.0589667728969, 60.63892323630196, 55.792676312582834, 58.44459874289376, 53.04354510988508, 62.50793307168143, 33.609996455056326, 41.7212609563555, 64.80746023995536, 53.66125038691929, 51.57949365888323, 50.102911131722585, 54.99577351978847, 51.95338664736067, 52.60434947695051, 46.984622137887136, 42.96623917988369, 40.65540729250227, 42.362496307918, 41.538672719682964, 42.1920222554888, 42.37441594260079, 47.38537686211722, 49.38644068581717, 54.247959750039236, 51.21241685322353, 49.891025815691265, 44.15699713570731, 46.062127181461875, 44.093358584812705, 53.81958246231079, 58.30849742889404, 63.3997482572283, 60.14553165435791, 56.63172687802996, 63.074878283909385, 63.79974215371268, 65.64546162741524, 60.09136349814278, 50.72939198357718, 61.35215582166399, 67.53976290566581, 63.35199328831264, 69.783586365836, 61.49082102094378, 14.978172642844063, 0.18825139850378036, 0.7975369244813919, 1.8346557702336992, 3.5732900415148054, 2.1102649697235654, 1.233433683003698, 0.6216877890484673, 0.717148383813245, 0.07531399439488139, 0.0738851557086621, 1.9378224057810647, 28.251382419041224, 45.20948593957083, 35.94078009469168, 22.704392296927317, 32.963376249585835, 54.65447800500052, 49.98979098456246, 60.86884607587542, 65.07875960213798, 64.74336310795375, 17.356858900615148, 0.25691393124205725, 0.037429630290716887, 0.03345582388075335, 0.024173412239179015, 0.030973294949425117, 0.0742720699469958, 0.02181694663262793, 0.067349669257445, 0.0452810845204762, 0.07319536379405431, 0.0030971429826292607, 0.030248890963516066, 0.020844463458550826, 0.03175168318141784, 0.050736746950341124, 0.019016505385349904, 0.08031880762428045, 0.01967225010905947, 0.015054057651598538, 0.038632601632603576, 0.02675897840942655, 0.004217767314652779, 0.005252442464032876, 0.04199518369776862, 0.0148663680800902, 0.04990591135408197, 0.0484042217555855, 0.21863843580441816, 0.09969883984220879, 0.09796493181160518, 0.1413258979363101, 0.21640810476882116, 0.10342162222202335, 0.09762867021241359, 0.10061966614531619, 0.1105386878230742, 0.13515202993793146, 0.12266348435410432, 0.11860399932733603, 0.19970316972051347, 0.07989402434655599, 0.2471124114734786, 0.0987446296161839, 0.11326030535357338, 0.11317464030746903, 0.24001927780253546, 0.09082964075995342, 0.15713899369750703, 0.2717708083135741, 1.275663422686713, 64.89249229431152, 93.14679295676095, 82.60321426391602, 78.37583991459438, 64.81467941829136, 43.501636096409385, 21.945702859333583, 27.532172645841325, 62.83761814662388, 58.82573522840227, 53.646589687892366, 10.064972008977618, 0.07647579562451158, 0.10453300151441779, 0.23943030940634863, 0.30547081998416353, 0.2758026091115815, 1.5799342670610972, 5.746849843433925, 7.116684590067182, 4.60013347864151, 5.580067890030997, 10.652789609772817, 36.456082820892334, 55.07175554547991, 61.95639896392822, 66.41449519566127, 62.596717153276714, 62.99084677015032, 58.87781892504011, 64.235748563494, 69.02546841757638, 65.17800072261265, 64.00435965401786, 52.457023348127095, 52.4310370853969, 58.74954128265381, 64.73544216156006, 61.856928552900044, 55.60079138619559, 60.96502998897007, 63.80148615155901, 59.36255999973842, 50.28934172221592, 46.820269448416575, 54.56396729605538, 61.63850498199463, 59.15622629438128, 56.47350597381592, 63.67551531110491, 61.495663915361675, 58.74129377092634, 61.250962257385254, 63.55859797341483, 62.48625469207764, 63.106256348746165, 60.63348279680525, 61.6549722126552, 61.36330073220389, 62.369983536856516, 58.25469752720424, 60.76613780430385, 56.330237592969624, 63.458516120910645, 36.7889849117824, 46.1987669808524, 67.29653426579067, 57.293077264513286, 53.892740045275005, 51.56189039775303, 57.22163936070034, 55.74978160858154, 56.1493273462568, 51.118136746542795, 45.21636813027518, 43.185486112322124, 45.13248947688511, 44.27684661320278, 43.352308886391775, 44.37873152324131, 49.82794312068394, 51.8973251070295, 57.18304559162685, 53.97132069723946, 52.50522300175258, 45.90283972876412, 48.198851108551025, 46.43715967450823, 56.50382096426827, 60.84924520765032, 65.22322654724121, 60.93946756635393, 59.13952282496861, 66.42986461094448, 65.73685823168073, 68.44628742762974, 62.44241155896868, 52.97248240879604, 64.4547974722726, 71.58307947431291, 66.06062344142369, 69.96617112840924, 64.74918569837297, 15.309005907603673, 5.103699828897204, 8.291983672550746, 10.103534511157445, 4.595875535692487, 1.919624422277723, 1.5997851618698664, 0.7277661540678569, 0.886591008731297, 0.15310468231993063, 0.17970400143946919, 3.223382885966982, 38.7010040964399, 63.027964047023225, 61.95332786015102, 30.413543701171875, 35.3521078654698, 61.56301975250244, 59.52311202457973, 70.54123878479004, 73.85935797010148, 75.05924933297294, 18.685390949249268, 0.6574089665498052, 0.16124579975647585, 0.1617144231817552, 0.0847506116011313, 0.08389526392732348, 0.207865728863648, 0.06512721601341452, 0.1843130998313427, 0.1139126353498016, 0.17654392815061978, 0.16671723473284925, 0.13825151004961558, 0.09663239760058266, 0.13555798386888845, 0.12397374904581479, 0.08314929609852177, 0.17304108611174993, 0.04258495955062764, 0.08276453960154738, 0.11846280976065568, 0.09763969640646662, 0.16542450338602066, 0.14656239694782666, 0.10882147853927952, 0.09175874519028834, 0.1371466921908515, 0.11704372162265436], [0.04650021517383201, 0.045255439289446385, 0.03942324759970818, 0.014962769246527126, 0.060314149994935305, 0.060168197112424035, 0.023590686365163753, 0.03838027481521879, 0.05014467425644398, 0.057460435267005644, 0.02258631374154772, 0.08321421154375587, 0.04125843715987035, 0.03360610242400851, 0.042884573473462036, 0.02884107329217451, 0.028991965909621546, 0.02920198267591851, 0.05691315606236458, 0.03148930047505668, 0.04845590576795595, 0.28532145119139124, 7.626735346657889, 67.5240113394601, 67.22225107465471, 61.2409360068185, 55.4504462650844, 40.37705203465053, 21.92863460949489, 27.650521312441143, 27.715658937181743, 38.29987416948591, 44.08182804925101, 14.0190007516316, 0.0774699579924345, 0.11571968267006533, 0.09633145374911171, 0.07488863436239106, 0.09351947571017913, 0.09215397148260049, 1.4499006846121378, 1.7512165904045105, 1.566549105303628, 1.3300324252673557, 5.181490123271942, 29.89577783857073, 57.27991737638201, 62.500720841544016, 65.7711545399257, 62.19638974325997, 63.66981084006173, 52.89014972959246, 54.19843646458217, 63.30568354470389, 59.23262868608747, 58.98375810895647, 47.60169512884957, 45.167588302067344, 51.80977780478341, 56.66314663205828, 57.34182235172817, 60.008297783987864, 55.8513434273856, 56.112675598689485, 58.05232082094465, 49.955425194331575, 42.26984207970755, 41.53706073760986, 49.10361426217215, 54.37858588354928, 58.822101320539204, 55.419561522347585, 56.52133389881679, 56.51777989523751, 57.176667145320344, 57.502704416002544, 56.109965801239014, 55.48976264681135, 57.10409321103777, 52.77776261738369, 56.83169950757708, 54.70088849748884, 56.43368237359183, 52.51806674684797, 57.21861342021397, 48.50366858073643, 55.14945030212402, 32.568180084228516, 37.71176821844918, 63.088760784694124, 48.735064438411165, 51.018906048366, 51.16933454786028, 57.00409821101597, 54.820362772260395, 58.28121532712664, 52.735184056418284, 51.65067795344761, 44.69841814041138, 41.98910011563982, 39.38939339773995, 41.32664843967983, 42.11386544363839, 48.253054005759104, 52.26349169867379, 56.84392833709717, 54.9899821962629, 48.152656010219026, 41.059149742126465, 42.6957597051348, 42.14688328334263, 49.860867159707205, 53.56867606299264, 59.7771520614624, 56.91110699517386, 56.767657961164204, 58.028766427721294, 59.89906515393938, 60.52093587602888, 59.96865136282784, 54.75162076950073, 47.57521554401943, 54.66362530844552, 63.32572214944022, 64.5116754259382, 62.1926029750279, 60.24803147997175, 11.078649044036865, 0.4505712996636118, 3.4658315905502866, 3.0280221232346127, 2.7590410709381104, 0.9124834707805088, 0.19170602384422505, 0.07520972391856567, 0.5414524887289319, 0.22401883852268967, 0.065532715325909, 5.534050405025482, 36.394282068525044, 36.557665484292166, 34.37490626743862, 18.968827077320643, 41.905589716775076, 44.22645132882254, 47.26624652317592, 56.59552328927176, 59.37477493286133, 61.48360184260777, 7.512779678617205, 0.25801076952900204, 0.013620202047085124, 0.09394780772605113, 0.004455453042672681, 0.03428107513380902, 0.028886379075369666, 0.05798509889947517, 0.032649669995797534, 0.05925497718687568, 0.05393578511263643, 0.0721046526783279, 0.08303038283650364, 0.03622576667528067, 0.060967172096882544, 0.04475947090291551, 0.0417595420564924, 0.049749973828771284, 0.03726835608748453, 0.031650384688483815, 0.03950770824615445, 0.03780371003917285, 0.0369722230492958, 0.03737522874559675, 0.04527926604662623, 0.041165871412626336, 0.03543818090111017, 0.0946205887677414, 0.025102245255506465, 0.03273786597752145, 0.02480809693224728, 0.08788781825985227, 0.021127516037917564, 0.056871392231966765, 0.04115747793444565, 0.010619593817474586, 0.02978799944477422, 0.02158643301975514, 0.048021585680544376, 0.01867818273603916, 0.05303235984008227, 0.028151863221345202, 0.0692831412223833, 0.01853212807327509, 0.020434601165886437, 0.11516688019037247, 0.07577824126929045, 0.03397810246263232, 0.2679885998368263, 10.762297562190465, 80.56335517338344, 72.39284338269914, 69.51470497676304, 60.94313621520996, 50.46601356778826, 31.456197329929896, 28.498100791658672, 27.572934252875193, 42.23672349112374, 43.81357547215053, 17.052803993225098, 0.06551385883774076, 0.04618903562160475, 0.14965032839349338, 0.10820101933287722, 0.2525594191891806, 1.1360146190438951, 2.293827908379691, 1.934514194726944, 1.4062443929059165, 0.32228377780744005, 7.379312600408282, 34.02668687275478, 60.71417222704206, 64.59895174843925, 68.66631603240967, 65.4245297568185, 66.31612954820905, 55.7457412311009, 55.36409752709525, 65.4278232029506, 62.01975958687918, 61.37763486589704, 49.839154039110454, 47.031466892787385, 53.72598327909197, 57.05166557856968, 61.80410139901297, 60.62730584825788, 57.28026131221226, 57.03542763846261, 59.614869935171946, 52.18659945896694, 45.372872829437256, 43.68081276757376, 49.86551897866385, 58.13889537538801, 61.376787185668945, 56.26696382250105, 57.38303906576974, 58.08788864953177, 58.58850983210972, 61.36495440346854, 57.29387283325195, 55.951797008514404, 56.93199675423758, 53.74313143321446, 56.878193378448486, 55.41626460211617, 56.11975233895438, 54.98133863721575, 56.075520106724326, 50.75369330814907, 57.43372964859009, 34.13912609645298, 40.86000394821167, 65.09460844312395, 51.93409149987357, 53.00598662240164, 52.997725214277, 59.33233533586775, 57.382455417088096, 60.557247161865234, 55.598335197993684, 53.930916922433035, 46.729449544634136, 43.398410184042795, 40.77723005839756, 43.204232352120535, 43.07860197339739, 51.52318198340279, 55.693716594151084, 59.09970269884382, 57.13603407996041, 49.74127129146031, 43.27344683238438, 43.82077380589077, 42.96367529460362, 51.28609207698277, 56.03453268323626, 62.39285700661795, 58.602086612156455, 57.82870694569179, 59.967609133039204, 61.69702965872628, 63.01564489092146, 61.40311391013009, 57.25615106310163, 50.46625675473894, 57.4448641368321, 65.6046062197004, 67.33691024780273, 63.45863424028669, 64.62398610796247, 14.60115817614964, 0.49649856665304726, 1.4990101179906299, 2.616749563387462, 2.175367202077593, 2.267408903156008, 0.758162297308445, 0.5795897394418716, 0.708294153213501, 0.14593129152698175, 0.04649207614628332, 5.685872886862073, 37.75639649799892, 36.61492211478097, 29.200259685516357, 28.828670024871826, 54.44638640539986, 52.22838939939226, 53.66307428904942, 63.49939932141985, 66.12351158687046, 75.48502104622978, 17.33189923422677, 0.2700706438294479, 0.04965743183025292, 0.09690299058066947, 0.04122043241347585, 0.03411968557962349, 0.028094011325655237, 0.013683171793153244, 0.02078849958655025, 0.027096188261306713, 0.021038705982001762, 0.029612923839262555, 0.04876065280820642, 0.032390479796699116, 0.07411003578454256, 0.023412197728508284, 0.03604392946830817, 0.09243070520460606, 0.03886427045134561, 0.07568567552204643, 0.008322414360009134, 0.0763804003862398, 0.0340551229725991, 0.042847155659858666, 0.04278743440019233, 0.010549675024646734, 0.07864963183445589, 0.1815553978085518, 0.16910550157938684, 0.26544322499207085, 0.10759856844586985, 0.15171011643750326, 0.16590027857039655, 0.06938990192221743, 0.11000912516777005, 0.09272884670644999, 0.17936386540532112, 0.12597111186810903, 0.1605264169297048, 0.1746085291462285, 0.19117417452590807, 0.11338687927595206, 0.15975819315229142, 0.12967074263308728, 0.12346290717167513, 0.23850535761032784, 0.14458168537489005, 0.16883385687002114, 0.6066078096628189, 15.626802614756993, 94.93348748343331, 81.3207574571882, 80.07582787105015, 69.54884842463902, 56.36949144090925, 33.52689252580915, 37.48362411771502, 39.66736650466919, 52.357327120644705, 61.43682656969343, 21.59146806171962, 0.23876140958496503, 0.2331918313034943, 0.212613438389131, 0.3336084187030792, 0.3222928430352892, 1.009420286331858, 4.386550196579524, 7.3905947378703525, 6.166201421192714, 5.528145739010402, 9.041121074131556, 36.585475649152485, 63.502908161708284, 67.64784213474819, 70.33248015812465, 67.59261090414864, 68.97506618499756, 59.51619856698172, 58.03134420939854, 67.86893381391252, 65.03451347351074, 63.9477596282959, 51.747650487082346, 50.20214530399868, 56.83916187286377, 62.688662665230886, 62.65336581638881, 61.75357409885952, 56.31866536821638, 59.09820188794817, 63.71360533578055, 55.56537641797747, 47.81079421724592, 46.125362736838206, 52.30219316482544, 60.81193338121687, 63.80954606192452, 56.35437216077532, 57.45403228487287, 60.98811885288784, 60.099597113473074, 62.944578715733115, 59.07682228088379, 58.307205063956125, 59.107852935791016, 54.487144538334434, 57.59779746191842, 57.583619662693565, 58.32084437779018, 56.698988914489746, 57.50029339109148, 54.298518317086355, 55.84502056666783, 37.08802148274013, 44.39507021222796, 66.69140175410679, 54.89341960634504, 55.632072176252095, 56.06039387839181, 61.55666215079171, 60.2659786769322, 62.72893442426409, 57.21265533992222, 57.1764691216605, 48.78019993645804, 45.75704567773001, 43.52002797807966, 46.36830302647182, 46.43260165623256, 52.78611782618931, 58.21900463104248, 61.99997806549072, 60.92524460383824, 52.40392868859427, 45.32333564758301, 45.58434820175171, 46.97022894450596, 55.304989201681956, 59.08297143663679, 65.29866313934326, 58.60323306492397, 57.15754222869873, 60.348287037440706, 62.79017584664481, 65.79966994694301, 63.70193236214774, 60.299100739615305, 53.37946619306292, 58.67665467943464, 69.16128485543388, 70.15653092520577, 66.43294961111886, 68.7072617667062, 13.894200682640076, 2.228816871132169, 12.638602137565613, 8.384690880775452, 6.307543848242078, 2.7532280342919484, 0.9025387529815946, 1.0163919350930621, 1.59254090487957, 0.5783174591405051, 0.17073000940893376, 9.490911841392517, 52.10580233165196, 49.358439445495605, 48.537766865321565, 28.545975617000035, 54.51143544060843, 58.2822436605181, 61.911124501909526, 72.9418066569737, 72.88060692378453, 86.28402941567558, 18.657740592956543, 0.416683415217059, 0.14198157989553042, 0.2446929727281843, 0.07076953324888434, 0.10197658690490893, 0.08012014614152056, 0.09665952543062822, 0.12078942491539887, 0.13368036890668528, 0.16337580260421547, 0.10723887024713413, 0.17027260895286286, 0.1477656023842948, 0.0995381356083921, 0.19331282190978527, 0.1412290981305497, 0.15758689466331685, 0.16688180661627225, 0.22592003936214106, 0.16763443765895708, 0.15173059462436608, 0.08687695035977022, 0.10133164615503379, 0.13624783685164793, 0.147532851302198, 0.1503722489412342], [0.014531278650143316, 0.06872466618993453, 0.01275686631977026, 0.07774351617055279, 0.08174812807036297, 0.007517899137123355, 0.03136170196479984, 0.03849244683182665, 0.06105869968554803, 0.016241225912900906, 0.007683255576661655, 0.10966979659029416, 0.01678477826395205, 0.07283489885074751, 0.10024324205837079, 0.04380355416131871, 0.018295044545084238, 0.04977739003619977, 0.06358380668929645, 0.03742963368339198, 0.06835206225514412, 0.09398480824061803, 34.58894899913243, 73.47080080849784, 64.0873350415911, 57.305389472416465, 41.38574981689453, 23.307249273572648, 19.05967477389744, 32.05076857975551, 34.40823677607945, 36.54139627729143, 33.91896547589983, 0.7051450450505529, 0.029607023977275406, 0.05576950903715832, 0.05379954206624201, 0.12177639481212411, 0.2749196993453162, 1.1412910159145082, 0.7061008566192218, 2.163158348628453, 0.7122876846364566, 4.402078117643084, 40.330294132232666, 62.62088993617466, 66.17743655613491, 60.55309213910784, 61.0845251083374, 60.38675226484026, 60.227110454014365, 58.1751059123448, 56.13996812275478, 60.966892106192454, 59.84095736912319, 48.313638823372976, 42.39378752027239, 49.01032427379063, 55.35999461582729, 56.026111466544016, 61.30498450142996, 54.40756334577288, 56.93860101699829, 56.62898233958653, 54.13213675362723, 46.091941901615684, 41.64357662200928, 39.745106424604145, 46.812782764434814, 53.08020380565098, 59.0332362311227, 55.9610207421439, 53.52640322276524, 55.26530109133039, 56.77856315885271, 56.20507274355207, 53.8165738923209, 53.318443638937815, 53.86564901896885, 53.640183448791504, 54.53135592596871, 54.99901832853045, 54.34465782982962, 52.82905421938215, 57.84209959847586, 44.474613189697266, 58.08186456135341, 28.23886350222996, 38.046240602220806, 61.87962136949812, 50.61133166721889, 52.305104460035054, 48.02860287257603, 56.506739207676475, 53.67157193592617, 57.12708132607596, 53.993266582489014, 57.282641070229666, 50.96985871451241, 48.268944535936626, 42.22685010092599, 43.300781045641216, 47.24468278884888, 53.248016698019846, 58.032848494393484, 58.57749693734305, 54.87230403082711, 50.44105911254883, 41.11802877698626, 42.61320468357631, 41.774286133902415, 47.91896724700928, 54.33553484507969, 58.1577319417681, 54.22444704600743, 53.21772950036185, 54.67227234159197, 55.41472210202898, 59.486314364842, 59.14764526912144, 54.76260239737374, 48.71758624485561, 50.633715288979666, 54.88526242119925, 59.22588198525565, 66.46932343074253, 64.23448399135044, 64.84803077152797, 14.69504918370928, 0.9759593904018402, 1.8357164561748505, 3.451905880655561, 1.0361690052918024, 0.3801644705235958, 0.8700217806867191, 0.31360672627176556, 0.2996870960508074, 0.14467761665582657, 0.05535984691232443, 16.393124648502894, 40.150950704302105, 36.459622928074424, 21.971244437353953, 13.834976843425206, 28.854204654693604, 37.425422532217844, 46.61436653137207, 56.16402626037598, 52.960222312382285, 53.582027026585166, 3.3018061178071156, 0.21536426006683282, 0.006949956844826894, 0.011725293771762933, 0.028327252649302994, 0.043199437470840554, 0.0329398115697716, 0.06692981214395591, 0.06706618411200387, 0.025798496823491793, 0.03789731055232031, 0.030753812619618008, 0.03324847375707967, 0.05552308547443577, 0.007793286815285683, 0.047152670699038675, 0.06480850132980517, 0.04844575149140187, 0.06007202834423099, 0.0026097472499324276, 0.01655302123565759, 0.033895504394812245, 0.035346215657357655, 0.019640072282137613, 0.018534499553165266, 0.10054622830024787, 0.01956855638750962, 0.03950178124276655, 0.08340661693364382, 0.02114627922752074, 0.033280378473656516, 0.024964239714401107, 0.021522112988999913, 0.0645342781873686, 0.07296241593680211, 0.0661721531567829, 0.03677812471453633, 0.04087353138519185, 0.06462204669203077, 0.05215080714385424, 0.02364251626256321, 0.0716235034966043, 0.02806313967864428, 0.03556995579440679, 0.10854582368795361, 0.02558389655314386, 0.0395316774956882, 0.160755544634802, 42.67906665802002, 82.7888492856707, 71.98879868643624, 65.37179987771171, 54.200298581804546, 35.37791347503662, 25.40036630630493, 28.290142944880895, 26.44211666924613, 35.94885390145438, 35.54851259504046, 1.1757523438760211, 0.08062559366226196, 0.03610539795564754, 0.22609181728746208, 0.5725347122975758, 1.2845516886029924, 2.7794060238770077, 3.4023270096097673, 1.665812915989331, 0.16333324488784584, 5.623895823955536, 42.32248510633196, 66.52543013436454, 66.8312759399414, 62.16591494424002, 62.504424231392996, 63.55030182429722, 62.97094018118722, 60.710072789873394, 57.44260597229004, 63.96972288404192, 62.346734864371165, 50.88154363632202, 44.740159443446565, 51.74400615692139, 59.187284742082866, 59.57014438084194, 62.98939459664481, 55.817714146205354, 58.82546424865723, 58.66117409297398, 55.66094194139753, 47.91834190913609, 43.3495226587568, 42.43267658778599, 48.758827277592246, 56.401446206229075, 61.09589236123221, 56.23349782398769, 53.40737363270351, 56.63045188358852, 58.088503565107075, 58.05385289873396, 55.212366240365164, 54.57116215569632, 54.02554096494402, 55.051042965480256, 56.154472487313406, 55.918595041547505, 55.979204177856445, 53.05549948556082, 57.90500511441912, 48.35111393247332, 57.45697137287685, 32.23003905160086, 40.81631367547171, 63.60669340406145, 52.867859908512656, 54.32057189941406, 50.00589690889631, 59.04742445264544, 54.864591530391145, 58.92172459193638, 57.89512825012207, 62.321763038635254, 54.06620877129691, 50.771571023123606, 43.933998176029746, 45.31831904820034, 48.59155634471348, 55.742416518075125, 58.12605857849121, 61.179076194763184, 57.92849349975586, 51.87006732395717, 43.352916853768484, 45.46459947313581, 43.93360560280936, 50.54269388743809, 55.33540146691458, 61.28646755218506, 56.63724374771118, 53.86611802237374, 54.81286219188145, 57.393742765699116, 62.806184496198384, 60.72795050484793, 58.28241041728428, 51.343046460832866, 54.13680941717965, 58.04953806740897, 61.294096674237935, 68.84391893659318, 66.43518693106515, 68.99876649039132, 19.010000365121023, 0.20079113276941435, 0.4120823506798063, 3.3698539521012987, 2.778944185801915, 2.1654123876776015, 1.829787688595908, 1.1795087137392588, 0.5113452928406852, 0.13890491213117326, 0.06858204491436481, 16.85291474206107, 41.20601034164429, 30.945205960954937, 15.431853532791138, 21.065313986369542, 43.443900040217805, 47.49576984133039, 53.51673480442592, 62.48938832964216, 57.37784876142229, 67.54584952763149, 9.297914334705897, 0.3163686894944736, 0.1038104702851602, 0.04225935773657901, 0.009534621411668403, 0.06801276081906897, 0.06870270201138087, 0.05815431196242571, 0.02618268844006317, 0.03368203388527036, 0.05345879874325224, 0.07714044103132826, 0.013260878738947213, 0.03187210279117737, 0.03936303100947823, 0.03481003050027149, 0.06221607008150645, 0.007957578803013479, 0.06882819027772971, 0.09700205669339214, 0.022853965272328684, 0.024271638664816107, 0.047612690300281556, 0.016898510911102806, 0.04424784192815423, 0.07916148472577333, 0.08984155128044741, 0.15167423550571713, 0.16146903777761118, 0.16566451479281696, 0.137780294620565, 0.08293458726257086, 0.08026649935969285, 0.14189516167555535, 0.17164462033127034, 0.14405082671770028, 0.0957983084289091, 0.16024749832493917, 0.10970826274050133, 0.194010980161173, 0.15253687064562524, 0.13897268420883588, 0.12933024019002914, 0.10951002194945302, 0.21081966321383203, 0.1143519189208746, 0.11873157748154231, 0.4310893107737814, 53.045014653887065, 91.7656717300415, 81.86309909820557, 75.05003602164132, 58.62721129826137, 37.447872161865234, 30.080183029174805, 46.422339166913716, 47.84497935431344, 50.87815291540963, 50.912056650434224, 1.3590304063899177, 0.21820603257843427, 0.16618311910756997, 0.4450117365590164, 0.9030966716153281, 1.4184496636901582, 3.5742929705551694, 6.6821690031460355, 8.10634343964713, 4.3604753443173, 6.572573329721179, 45.39864717211042, 69.07921968187604, 70.44583306993756, 64.36697919028146, 67.38800730024064, 66.79561083657401, 64.52530084337506, 62.73280457087925, 58.440471512930735, 66.31997190202985, 66.16606930324009, 52.563004221235005, 46.50028058460781, 55.810401167188374, 62.36536298479353, 62.05495221274239, 66.16704205104283, 55.77899183545794, 60.786391803196494, 61.289990288870676, 59.84480667114258, 50.31399393081665, 45.29704713821411, 44.657993521009175, 51.67114387239729, 59.11566965920584, 64.23162133353097, 56.898985862731934, 53.67748485292707, 58.09824841363089, 61.083274432591026, 61.26833275386265, 57.71841124125889, 55.60571071079799, 55.12488147190639, 56.23019395555769, 58.68684768676758, 57.78323098591396, 57.60051073346819, 56.125745160239084, 61.87907246180943, 50.62656211853027, 61.24981580461775, 37.89888668060303, 44.30292667661394, 65.20521681649345, 56.97146947043282, 57.008697918483186, 53.03967496326992, 61.7279908316476, 56.72857434409005, 62.408219473702566, 59.38714272635323, 64.173951285226, 55.52350309916905, 53.15588011060442, 45.17436279569353, 47.16289554323469, 51.505210467747276, 57.84084892272949, 60.00339930398123, 62.80001449584961, 59.14599854605538, 53.79577445983887, 45.452339376722065, 47.061267716544016, 45.95787293570382, 52.14207887649536, 59.31639616830008, 63.412553787231445, 56.53353146144322, 52.85926498685564, 55.95999240875244, 60.36098139626639, 65.04796518598283, 61.9043083190918, 60.19532939365932, 54.08362095696585, 56.43421391078404, 58.751083782741, 62.491827147347585, 72.96221351623535, 69.92453752245221, 71.67937455858502, 19.366505486624582, 2.7896663418837955, 8.628494484083992, 11.074870092528206, 6.055236952645438, 2.6499037614890506, 2.0399650505610873, 1.780436696750777, 0.84854663589171, 0.390588641166687, 0.16012633911200932, 24.51127655165536, 56.73001609529768, 49.736046246119905, 30.213310514177593, 23.644087518964493, 39.465844426836284, 51.752392632620676, 60.267062595912385, 71.73712798527309, 65.84674399239677, 77.41494573865617, 9.149774398122515, 0.5112209852252687, 0.16738099125879152, 0.09908748657575675, 0.13343560775475843, 0.14563699731869356, 0.07396717702171632, 0.14856615156999656, 0.30706676148942535, 0.14272009740982736, 0.14495815017393657, 0.18836189114621707, 0.17221543113035814, 0.1606958471238613, 0.12914718501269817, 0.1276722534426621, 0.22800502819674356, 0.09687479745064463, 0.16224635392427444, 0.10399663315287658, 0.06957157288811036, 0.09028221906295844, 0.1700376458466053, 0.08317327552608081, 0.08263658146773066, 0.16447344156248228], [0.02626960877595203, 0.043724864455206056, 0.01860469569718199, 0.07388085379664387, 0.06967121575559888, 0.027548386050122123, 0.055263664573431015, 0.093685608224145, 0.04720513163400548, 0.020727161717201983, 0.004796406287433845, 0.038045126013457775, 0.041150132792868784, 0.05157758415277515, 0.028481582046619484, 0.05254231845693929, 0.04184917313978076, 0.02223311590829066, 0.010511324225392724, 0.10465059163314955, 0.08736919358904872, 0.7336444929242134, 56.6124074118478, 73.44006197793144, 56.01977470942906, 49.24019500187465, 33.28014809744698, 20.383499417986187, 19.013375452586583, 36.298188482012065, 44.050536836896626, 57.77041155951363, 10.921175071171351, 0.07348711349602256, 0.018035060460014, 0.14751279380704674, 0.04222735123974936, 0.12265884317457676, 0.4732672646641731, 1.5519865495818002, 1.5723024308681488, 0.46019629176173893, 5.665609334196363, 40.170468194144114, 67.21861716679165, 59.08513232639858, 61.174170766557964, 60.560068130493164, 60.13702705928257, 56.54737227303641, 60.09225981576102, 58.32169900621687, 62.702475684029714, 59.61469623020717, 54.121398312704905, 44.048535755702424, 48.18474626541138, 51.956735679081504, 57.53079598290579, 57.631968702588765, 57.31287268229893, 55.743729727608816, 57.59978812081473, 52.4640132359096, 51.4564653805324, 41.763301031930105, 40.98470674242292, 39.97691222599575, 47.18435852868216, 55.05423566273281, 59.95503289358956, 56.469892910548616, 54.48645666667393, 52.4443359375, 55.277331897190635, 53.866972650800435, 58.13656772886004, 54.983332770211355, 54.18240697043282, 50.044393403189524, 53.21226126807076, 55.266468388693674, 57.43047094345093, 54.22224794115339, 53.84328276770455, 50.970873151506694, 56.07082312447684, 26.545938389641897, 30.587276458740234, 59.71285343170166, 46.500311851501465, 50.75510726656233, 46.00956058502197, 54.15750462668282, 50.7623472894941, 57.9509083884103, 52.609247956957134, 56.48479332242693, 55.56100600106375, 55.82895285742623, 50.28372062955584, 47.33522476468767, 49.57741887228829, 56.19603313718523, 56.242787565503804, 51.8294620513916, 58.08031511306763, 48.342637130192344, 40.60215629850115, 40.883367265973774, 43.48072896684919, 50.773335865565706, 53.051094327654155, 57.57145684106009, 57.21230445589338, 52.17499596732003, 52.92380680356707, 53.896314893450054, 57.573030608040945, 59.13677133832659, 57.70302445547921, 47.740002495901926, 45.44940723691668, 51.69146040507725, 56.502743993486675, 57.824034282139365, 61.44605377742222, 62.10506956917899, 63.400109563555034, 17.165258850370133, 1.1176715918949671, 0.6357334096516881, 1.357844978570938, 0.8925112539104053, 0.1984490877283471, 0.14281543157994747, 0.05325259195108499, 0.024726738887173787, 0.036955500553761206, 1.2824642977544238, 31.32027666909354, 43.480680329459055, 42.90405280249459, 29.298878942217144, 15.900129113878522, 27.171773059027537, 35.353393282209126, 50.18943704877581, 60.715999603271484, 55.993500096457346, 47.248994146074565, 0.1867712964969022, 0.09398699990872826, 0.09508809939559017, 0.023081172723323107, 0.01999633200466633, 0.05857824028602668, 0.08580965548753738, 0.04367235941546304, 0.05213515334097402, 0.02378781944779413, 0.020483479435954775, 0.06600866692938975, 0.004189254425000399, 0.02258480909014387, 0.03186605704416122, 0.08643609258745398, 0.025226839551968232, 0.02636299385423107, 0.056175337439136844, 0.006517557859686869, 0.007202707746598337, 0.01319886148641152, 0.045494300579386096, 0.0309351002132254, 0.04297895430188094, 0.029027337940143685, 0.05576067451121552, 0.027185240893491676, 0.09395499341189861, 0.017609668197110295, 0.021217728964984417, 0.01572271150403789, 0.04490206503708448, 0.08855162906859602, 0.02866871521941253, 0.05487329998452749, 0.026768710297931517, 0.016534146087776338, 0.03660799562931061, 0.028123030572065284, 0.027397145683478032, 0.0500613230147532, 0.05471907236746379, 0.03437840419688395, 0.04993614687451294, 0.17406762817076274, 1.8937350000653947, 70.83996268681118, 79.760984148298, 63.748228209359304, 57.181204319000244, 39.30813421521868, 26.79789570399693, 24.448534318378993, 31.545884677342006, 40.35872616086687, 46.49377359662737, 13.166991795812335, 0.13607809453138284, 0.040719225736601014, 0.30840830664549557, 0.2500186040997505, 0.6733265295624733, 1.934480756521225, 2.7578581401279996, 1.8352487555571964, 0.5234515517950058, 6.488585242203303, 42.49309812273298, 70.61337498256138, 62.048851694379536, 62.3922038759504, 63.59358215332031, 63.32493700299944, 59.32847908564976, 62.487255232674734, 60.32310676574707, 64.76266520363944, 62.68351405007498, 56.99681649889265, 45.98734024592808, 49.338560649326865, 55.40753766468593, 60.219126973833355, 60.34236022404262, 58.33578300476074, 56.32468598229544, 59.81582573481968, 54.43466132027762, 54.82855817249843, 42.645843846457346, 44.26366588047573, 41.874374934605186, 50.732734067099436, 57.28685515267508, 61.557030405317036, 55.66041735240391, 54.42652497972761, 55.0361772945949, 56.5632141658238, 55.31866673060826, 60.533963748386924, 56.44496624810355, 55.000373227255686, 51.89935050691877, 55.94146156311035, 56.400716645377024, 59.015935216631206, 54.98618153163365, 57.44469738006592, 53.11074113845825, 59.77382387433733, 32.33902154650007, 32.76376840046474, 62.65356731414795, 47.994726930345806, 52.98927273069109, 47.993715967450825, 55.3778897012983, 52.40827478681292, 58.60199628557478, 53.394008772713796, 58.33107212611607, 58.05145577022007, 58.512649399893625, 51.4663005556379, 49.860266140529085, 52.13285861696516, 58.731934547424316, 57.13854585375105, 55.41731030600411, 60.49021789005825, 50.125607422419954, 43.3636657169887, 42.71517992019653, 46.330702849796836, 52.862120696476524, 55.65234007154192, 58.98116643088204, 58.28782653808594, 51.776343073163716, 52.294258322034565, 57.17703192574637, 59.78006335667202, 62.9764848436628, 60.326532227652415, 49.514318806784495, 47.257432733263286, 53.61192512512207, 58.906035559517996, 60.720495087759836, 63.54689025878906, 63.552344594682964, 67.7336732319423, 21.126982722963604, 0.17250625123935087, 0.6103280271802629, 1.665023752621242, 2.8256506281239644, 2.221631348133087, 1.8280799516609736, 0.33615903183817863, 0.14834455560360635, 0.0853903004899621, 1.379294936146055, 34.07533121109009, 38.302604811532156, 31.476659774780273, 24.45204142161778, 22.8263418674469, 36.211620875767295, 42.0715856552124, 55.746404784066335, 67.94422449384416, 61.078327315194265, 63.6953524180821, 1.9286466581480843, 0.27333035320043564, 0.04500449329082455, 0.025865451266456927, 0.01783380188447024, 0.012575845051157688, 0.025277909490146806, 0.08913265181971447, 0.054361036579523764, 0.04019991235275354, 0.051192067696579864, 0.03005316753738693, 0.02539777270119105, 0.05989759734698704, 0.016363409713708928, 0.05209007486701012, 0.03849736960338695, 0.0652409859799913, 0.0837300813623837, 0.034653458544718366, 0.070362256174641, 0.03794934740290046, 0.024849762375067388, 0.0579919113910624, 0.022865038963833025, 0.07989232800900936, 0.20582700254661696, 0.07578809359776122, 0.26231827267578667, 0.282310601323843, 0.05586051754653454, 0.13000365905463696, 0.1486344121928726, 0.18453071958252362, 0.06975420058837958, 0.09265324433467217, 0.09462863619306258, 0.10246728307434491, 0.14186512971562998, 0.1742391482527767, 0.1581702312188489, 0.1394041646271944, 0.1749010591634682, 0.13818590928401264, 0.18089510181120463, 0.28711025949035374, 4.32000686441149, 84.01264939989362, 87.75797857557023, 75.1280712400164, 65.78873348236084, 46.13910974775042, 29.649509361812047, 28.153900929859706, 52.43061671938215, 58.682581492832725, 78.2281003679548, 17.492260183606827, 0.2186867067856448, 0.1507005648953574, 0.4040055583630289, 0.48356959755931583, 0.5775311184780938, 2.2393099537917545, 7.898528030940464, 10.062232681683131, 4.230009019374847, 7.336163418633597, 44.15516628537859, 74.81902231488908, 63.580797467912944, 67.33541638510567, 66.44561617715019, 66.4620556150164, 61.62027290889195, 66.01941367558071, 62.59932272774832, 67.29954283578056, 64.74797671181815, 60.326421056474956, 48.941092423030305, 52.01370048522949, 57.68032816478184, 63.78780514853341, 62.31978975023542, 59.29031957898821, 58.17643649237496, 62.31667695726667, 56.174924509865896, 57.03592096056257, 44.71526404789516, 45.588093280792236, 44.577119963509695, 52.078283991132466, 59.003671646118164, 65.41362108503068, 56.83125482286726, 55.44426931653704, 55.91975539071219, 60.58328901018415, 57.16042225701468, 63.32464517865862, 59.08202648162842, 55.44575275693621, 52.19391243798392, 56.80529982703072, 57.73555244718279, 61.34816060747419, 57.64223466600691, 59.45008645738874, 57.4105087688991, 62.09458473750523, 35.56757150377546, 36.18763222013201, 65.19650377546037, 50.87234074728829, 55.34327030181885, 50.88158185141427, 59.07956681932722, 54.64545576913016, 62.291649545942036, 54.15094552721296, 59.389803886413574, 61.78677259172712, 60.69355692182268, 54.947024958474294, 51.16931022916521, 54.5306784766061, 60.59195341382708, 59.15115410940987, 57.78509657723563, 63.02569893428257, 53.08422681263515, 44.69800819669451, 44.59258665357317, 49.13979353223528, 56.240737846919465, 57.3192789213998, 61.67674091884068, 58.65437180655343, 52.82703924179077, 52.08718810762678, 58.67344461168562, 62.90015888214111, 65.02320180620465, 62.44377340589251, 52.559015955243794, 49.48376062938145, 56.36217846189226, 61.97572190420968, 63.70035512106759, 66.5450518471854, 65.92305605752128, 70.10350922175816, 21.89852111680167, 3.8590512105396817, 6.239885764462607, 8.587258662496295, 5.5936837536948065, 2.486780903169087, 2.1092946103640964, 0.7440729247672218, 0.23273140458124025, 0.16704983902829035, 2.235640002148492, 46.47472858428955, 58.171072483062744, 58.297644342694966, 41.07851089750017, 25.477432250976562, 39.378001826150076, 47.70859316417149, 62.626045499529155, 76.06084605625698, 69.18974467686245, 70.28660815102714, 1.8738496899604797, 0.4033952568258558, 0.15470423363149166, 0.1561466905155352, 0.1477789423827614, 0.10749146847852639, 0.20550704614392348, 0.136674933933786, 0.16886722722223826, 0.08637030861739602, 0.09409078183983054, 0.1677731844995703, 0.10404309923095362, 0.15284770753766808, 0.1035474022584302, 0.1296603474766016, 0.12278106090213571, 0.11128089656787259, 0.1371437202074698, 0.06639758963137865, 0.19300943533224718, 0.14422373101115227, 0.1466338602559907, 0.13085990239466938, 0.06242739302771432], [0.05051188723051122, 0.07629522388534886, 0.10207378026098013, 0.009599725998538946, 0.010325005294622054, 0.064032644033432, 0.022984154090019207, 0.022272135064538037, 0.02983088625062789, 0.017513674151684557, 0.08088072282927376, 0.07135165522673301, 0.04122790986938136, 0.005844132209728871, 0.03477343710671578, 0.022869081336206624, 0.004935827422221857, 0.011993519512803426, 0.00979034005597766, 0.07953083169247423, 0.16315032541751862, 19.889677047729492, 77.42708424159459, 63.738118580409456, 63.69463675362723, 42.320775849478586, 36.05625915527344, 21.214149611336843, 41.78422205788748, 50.98111827032906, 45.99131114142281, 31.240000656672887, 0.6495892032980919, 0.026597217357318317, 0.07150107542318956, 0.20312914731247084, 0.145366085427148, 0.394713536969253, 1.4139053246804645, 1.989628608737673, 1.8232930770942142, 3.326893674475806, 46.18008327484131, 61.90289783477783, 62.27782263074602, 59.48635605403355, 60.03565979003906, 55.03993974413191, 55.934732232775005, 53.121573380061555, 54.2266982623509, 59.445097650800435, 60.91571862357003, 56.571378299168174, 47.07315608433315, 44.60843202045986, 54.52104479925973, 55.33082955224173, 60.555371148245676, 55.262789317539756, 55.588176931653706, 57.77905511856079, 52.96473169326782, 49.088668687003, 43.59358160836356, 39.774809973580496, 40.487372057778494, 40.70982905796596, 48.131776673453196, 53.845843178885325, 56.95774677821568, 51.54380771092006, 55.8239814213344, 55.03428391047886, 56.39966746738979, 50.8083165713719, 54.951888697487966, 54.109023571014404, 55.6138505254473, 50.87823976789202, 55.55302252088274, 52.34888505935669, 57.76702431270054, 51.28135340554373, 55.34204394476754, 49.176566873277935, 59.316493443080354, 36.54740299497332, 29.258165972573416, 63.128712926592144, 48.87285416466849, 51.912274156297954, 43.51065485818045, 48.56831462042672, 47.75758491243635, 54.91770356042044, 53.8344099181039, 56.638087953839985, 54.001524516514365, 56.72733409064156, 52.00821835654122, 53.35449436732701, 52.71585764203753, 57.89569105420794, 48.75612790243966, 49.59112419400896, 56.38126516342163, 47.74821874073574, 41.67484698976789, 40.81526449748448, 44.51580558504377, 53.059532914842876, 53.43172359466553, 56.05926479612078, 53.728217124938965, 51.16100365774972, 52.896055698394775, 54.900617940085276, 56.53387539727347, 57.38193777629307, 56.76465286527361, 47.933422974177766, 46.4439445904323, 47.062091078077046, 49.49552740369524, 55.49068328312465, 58.08519969667707, 61.083600997924805, 61.86293179648263, 64.36332443782261, 20.06942868232727, 1.8429124014718192, 2.2452296018600464, 2.703058349234717, 1.7554933152028491, 1.0895056575536728, 0.4155278429389, 0.009396571765786834, 0.2079430411436728, 0.039228752321962795, 9.31844105039324, 30.853145803724015, 35.40414639881679, 35.044403416769846, 17.968795435769216, 18.691119738987513, 33.46493196487427, 43.46752391542707, 47.3380457333156, 54.37012645176479, 53.895543643406455, 29.29091283253261, 0.7120402636272567, 0.1037477668640869, 0.09863142283367259, 0.0625680194103292, 0.06439749231295926, 0.022510324604809284, 0.0076489810765321764, 0.036337331403046846, 0.05504547146015933, 0.006023798952810466, 0.01904666457059128, 0.002608085687305512, 0.01578242937102914, 0.05109313389818583, 0.015900592851851667, 0.01982132255631898, 0.04981513354661209, 0.039014230083142004, 0.00658689480873623, 0.07328445544200284, 0.009009811046001102, 0.023650522975783263, 0.015302854390548808, 0.0477166384724634, 0.025364933302626014, 0.041934505703725984, 0.10606502502092294, 0.043708979950419495, 0.01864513468795589, 0.04936919015433107, 0.004850073742480683, 0.03605934239125677, 0.059459630133850236, 0.09413619618862867, 0.06092439724930695, 0.03237890738195606, 0.010976264053689582, 0.0394380973385913, 0.08928978695933308, 0.03974982650418367, 0.04765888835702624, 0.024465085605957677, 0.016907377667458992, 0.18421362659760884, 0.16222426082406724, 25.60166777883257, 86.36840139116559, 72.07992431095668, 73.21621881212506, 50.51977525438581, 44.21219709941319, 24.70103532927377, 25.195324965885707, 41.48028700692313, 47.8506942476545, 35.86204310825893, 1.0455616669995444, 0.09601074417254754, 0.04102568947044866, 0.452029607125691, 0.7034887682114328, 2.2962024552481513, 2.555961945227214, 1.3330133110284805, 0.13866977260581084, 4.900077658040183, 48.61276919501168, 67.09709317343575, 65.47104794638497, 61.92080334254673, 61.68159076145717, 57.56024592263358, 59.878804206848145, 54.44369397844587, 57.23264878136771, 60.59253011431013, 63.25249508449009, 60.01519039699009, 48.35946566717965, 46.05968141555786, 57.10734844207764, 57.2619423866272, 62.544445855276926, 56.21354259763445, 57.522909777505056, 57.65547098432268, 53.85327080317906, 51.57166303907122, 45.27503177097866, 43.192878995622905, 42.440639223371235, 42.33653783798218, 51.084212166922434, 56.17200626645769, 58.868501390729634, 53.506163120269775, 55.961496693747385, 56.67383990968977, 57.467119216918945, 53.822903701237266, 56.7829578944615, 55.4522910118103, 55.98710427965437, 51.624399866376606, 56.713163239615305, 53.26444918768746, 59.209838594709126, 53.41000699996948, 57.59614726475307, 51.580765179225374, 63.77296379634312, 37.96536009652274, 30.8547716821943, 63.16849831172398, 51.971649987357004, 54.211926392146516, 46.23793050221035, 50.18589694159371, 50.741617338997976, 56.57222597939627, 55.35601329803467, 56.985237325940815, 56.141496726444785, 58.526858466012136, 56.98945140838623, 56.02753932135445, 56.60872139249529, 58.207953521183555, 50.4062625340053, 53.270191873822895, 58.31855147225516, 51.00456844057356, 42.945332050323486, 43.11147390093122, 47.74383095332554, 55.734537260872976, 56.305960587092805, 57.500262124197825, 53.31128352028983, 51.42422226497105, 55.35121209280831, 57.68505988802229, 60.20076288495745, 60.1532233101981, 58.25696611404419, 49.99608605248587, 49.41474764687674, 48.294145652226035, 52.85133361816406, 57.817165987832205, 60.23148087092808, 63.096514974321636, 64.08834947858537, 67.69317218235561, 23.057437215532573, 0.49865967354604174, 0.5358729224119867, 1.2537049438272203, 1.9568761033671243, 2.389669405562537, 1.4644176427807127, 0.5568290150591305, 0.18715171036975725, 0.055108371656388044, 8.977261917931692, 34.26765734808785, 34.568246841430664, 31.482346875326975, 19.695599964686803, 29.875152111053467, 44.08574683325631, 49.90802805764334, 51.800043378557476, 60.58766637529646, 59.031971658979145, 43.99104288646153, 0.5716544623885835, 0.08547696976789407, 0.03876469883003405, 0.052136388274707963, 0.005458828643895686, 0.055753502396068404, 0.011317205000003534, 0.02260014058889023, 0.09144098045570509, 0.04392598223473344, 0.0353454421274364, 0.04888435992013131, 0.064908592030406, 0.07160592265427113, 0.010886150362369205, 0.06637827852474791, 0.008025635865383914, 0.03386535029858351, 0.04104370118251868, 0.05888213576482875, 0.019146047898435166, 0.04869584592857531, 0.01785088230722717, 0.011495625783157135, 0.18624754888670786, 0.22901884093880653, 0.18573833549661295, 0.0763478714174458, 0.15138520672917366, 0.12711783604962484, 0.15221938411039965, 0.09949904520596776, 0.12562744745186397, 0.153024465910026, 0.17517081754548208, 0.10835589495088373, 0.1381184086203575, 0.12275613152555057, 0.1430847964116505, 0.14828723296523094, 0.08954287373593875, 0.14197292178869247, 0.14921804730381283, 0.23242815371070588, 0.24846535601786204, 32.88369083404541, 97.4786821092878, 80.94207368578229, 83.27857221875871, 57.525918347494944, 49.790061541966026, 30.10775348118373, 58.68588883536202, 63.016499519348145, 61.479328700474326, 47.25779056549072, 1.3912271644387926, 0.15257275157741138, 0.28383092688662664, 0.6791994944214821, 1.0169714582817895, 2.792557009628841, 5.63110761983054, 9.707359518323626, 5.3984949588775635, 5.916208275726863, 51.272352014269146, 67.80451706477574, 67.91987800598145, 64.33553859165737, 65.66661889212472, 60.59729657854353, 62.15928636278425, 57.53299856185913, 58.676494870867046, 64.4192921774728, 65.99797848292759, 62.70289257594517, 50.35175044195992, 48.87688411985125, 57.973622049604145, 61.18809495653425, 64.08815492902482, 57.921593938555034, 58.02033478873116, 60.501911708286826, 56.375591959272114, 54.73682805470058, 47.83181251798357, 44.80494792120797, 43.52219581604004, 45.76675925936018, 53.496060439518516, 59.494645254952566, 60.52311066218785, 54.14448717662266, 56.41260501316616, 58.86823041098458, 60.17270605904715, 56.47314814158848, 59.491018295288086, 58.13396215438843, 58.01913969857352, 51.15560143334525, 58.2713280405317, 55.2555319241115, 62.04276507241385, 55.452548095158164, 61.87759944370815, 56.74373531341553, 65.41162000383649, 40.60859727859497, 35.102198532649446, 65.66389519827706, 53.944045543670654, 57.33460317339216, 49.77205875941685, 53.793867179325645, 54.15789025170462, 58.75891440255301, 56.828110763004844, 58.30260535648891, 57.45238903590611, 61.03831958770752, 58.19882011413574, 58.42909036363874, 59.59432411193848, 60.71212945665632, 51.649368218013215, 55.43946463721139, 61.49399634769985, 53.14258820669991, 45.28133378710066, 44.30967337744576, 50.59075805119106, 59.58581256866455, 59.96762302943638, 58.22419840948922, 54.96328026907784, 52.33221633093697, 55.80624614443098, 60.491690908159526, 64.11148003169468, 61.75777775900704, 63.06529671805245, 50.66363770621163, 51.50812176295689, 50.6854897907802, 53.8551607131958, 60.51607213701521, 64.34580108097622, 65.47511959075928, 67.47384534563336, 68.75938020433698, 24.83563756942749, 3.825355052947998, 8.018311500549316, 9.012460623468671, 5.481159848826272, 2.968650200537273, 1.842633170740945, 0.5554606541991234, 0.4148895857589585, 0.12524878419935703, 13.520218236105782, 46.404475348336355, 49.452775137765066, 49.264232294900076, 28.195049898965017, 28.860364232744487, 46.28214536394392, 56.57152073723929, 60.98489488874163, 68.92203753335136, 69.96731063297817, 48.11969723020281, 1.0590798216206687, 0.16911464823143824, 0.13726753927767277, 0.17055295248116764, 0.11491040752402373, 0.09830962081572839, 0.1339112336614302, 0.139749267537679, 0.21898367442190647, 0.09853329988462584, 0.10013485965984208, 0.12726647593080997, 0.21923454238900117, 0.2129897674811738, 0.0710925091324108, 0.13068361899682454, 0.07520161542509284, 0.13231348725301878, 0.13485557798828396, 0.20457583825503076, 0.06490353694451706, 0.09844382825706686, 0.07104534416326455, 0.09110256111515419], [0.11140381318650075, 0.028227126325613687, 0.03154749842360616, 0.013093558788698698, 0.0935531242617539, 0.03489792114123702, 0.024080983895276274, 0.05056185794195958, 0.035205087158828974, 0.11285182727234704, 0.0562872617904629, 0.01845672756566533, 0.025366034225693772, 0.028565296304545233, 0.03190462836729629, 0.13688815677804606, 0.04627870063164404, 0.04648367588275245, 0.010203690866806676, 0.01621933637319931, 0.20161034166812897, 38.67854404449463, 69.08689049312046, 60.70444474901472, 50.836630480630056, 44.160888126918245, 26.648592812674387, 23.79804744039263, 56.69147443771362, 47.81755134037563, 43.62503957748413, 10.883830240794591, 0.017998813119317805, 0.08136813488921948, 0.19347207407866204, 0.13198047583656652, 0.4758205105151449, 1.3030150064400263, 2.313597704683031, 0.7855087241956166, 1.5775164025170463, 40.00330148424421, 64.49477740696499, 59.570311137608115, 60.43278408050537, 56.309254033224924, 53.396916593824116, 52.05199200766427, 51.459411416734966, 50.7307642527989, 52.98033387320382, 55.84835570199149, 57.81865290233067, 50.91004514694214, 43.58219003677368, 52.77784946986607, 56.47402708871024, 57.39652551923479, 55.344930921282085, 54.312213216509136, 57.197240761348176, 54.35809564590454, 55.53643022264753, 47.67727763312203, 43.49014377593994, 39.185668740953716, 38.3089485168457, 39.58200788497925, 49.44571229389736, 55.67246552876064, 57.361197403499055, 54.764304706028526, 55.015249320438926, 53.4719362940107, 50.032869815826416, 48.13873529434204, 52.39543104171753, 52.6352515901838, 55.252915927342, 52.17323807307652, 53.1628873688834, 54.29593358721052, 54.86252096721104, 49.194618293217246, 50.80898707253592, 50.42320224217006, 60.504552023751394, 39.21480253764561, 27.295676810400828, 60.23524679456438, 50.780162470681326, 54.344539710453574, 49.13482557024275, 46.62973594665527, 44.67276886531285, 48.46842731748308, 52.871288844517295, 56.204732281821116, 51.86421694074358, 54.31033720288958, 54.262933118002756, 55.01751790727888, 53.780217443193706, 52.86445876530239, 53.25606618608747, 57.606458391462056, 54.65147985730852, 45.120813029153005, 39.402035645076204, 42.37189027241298, 49.02499539511544, 55.00450393131801, 55.40678031103951, 52.9522179876055, 49.29221616472517, 51.108513491494314, 53.16207790374756, 55.97059188570295, 54.18289681843349, 54.510987281799316, 54.50251047951834, 46.03259038925171, 43.496105330330984, 48.02092858723232, 49.07723542622158, 48.225320271083284, 51.60197108132498, 55.61349269321987, 59.848850522722515, 59.698665210178916, 68.84489863259452, 30.172771249498638, 0.25934441653745516, 2.0630877869469777, 2.841450180326189, 1.9981848810400282, 0.29904045217803543, 0.46566023571150644, 0.09893487726471253, 0.06307545503867523, 0.07035674647028957, 17.30448685373579, 35.26370593479702, 31.254605770111084, 20.757725919995988, 11.308557118688311, 12.607827697481428, 32.57129635129656, 43.898524148123606, 56.03578335898263, 54.46636595044817, 64.52275085449219, 11.048106500080653, 1.0242333028997694, 0.05995186657777854, 0.012896379056785787, 0.0606169258909566, 0.00442597917780014, 0.13144945433097227, 0.03666431064318333, 0.0639274236080902, 0.05587939439075334, 0.05515982157417706, 0.01391196362341621, 0.04769941046833992, 0.012859419254320008, 0.020931661993797337, 0.05108477095408099, 0.04271736887416669, 0.026199483878112266, 0.04208556456225259, 0.011702687529447888, 0.04279294071186866, 0.010496455826796591, 0.07445108784096581, 0.040345838093864064, 0.038285999159727774, 0.030087416592453207, 0.014620039512270262, 0.008587171090766788, 0.02552371388966484, 0.04900218752611961, 0.018267891269975474, 0.08876318271671023, 0.017425851364220892, 0.04724880214780569, 0.041518563737294505, 0.07090445993734257, 0.035016349250716824, 0.05801150069705077, 0.05578604493556278, 0.06379951297172479, 0.030505248278911625, 0.007952052135286587, 0.013385088814954673, 0.015673492270122682, 0.3256673333900315, 48.78846481868199, 77.5673405783517, 67.71005630493164, 57.91545173100063, 49.81427948815482, 34.08188336236136, 24.033165795462473, 59.289200919015066, 60.300796100071494, 49.13087204524449, 11.950148565428597, 0.07029670290648937, 0.057621906245393414, 0.5101332664489746, 0.5534502363630703, 1.3210708775690623, 2.58846800667899, 2.4369275782789503, 0.43896370966519627, 2.8500718091215407, 42.71362352371216, 68.36582728794643, 63.220623697553364, 62.10304069519043, 60.21930067879813, 56.26502874919346, 56.41000986099243, 54.97533539363316, 52.725168228149414, 55.14131048747471, 58.13684218270438, 59.37933989933559, 51.816805907658164, 46.08265216009957, 53.825665610177175, 59.41586657932827, 60.24894864218575, 57.34750597817557, 57.20862538473946, 58.329585211617605, 55.23308229446411, 57.45269823074341, 51.28438976832798, 45.789035184042795, 42.83524131774902, 41.05437632969448, 43.17286818368094, 50.984244959695, 57.312910897391184, 59.3229969569615, 54.11215720857893, 55.956754548209055, 56.49275943211147, 52.58695118767874, 50.334835052490234, 55.87760066986084, 54.90518985475813, 56.23745829718453, 52.00665848595755, 56.065340995788574, 56.61952236720494, 58.33757563999721, 51.77040236336844, 54.893277168273926, 52.764144148145405, 61.97707680293492, 41.876716477530344, 30.531961849757604, 63.2010714667184, 51.693058490753174, 56.19592891420637, 50.3758294241769, 49.41552584511893, 46.75663437162127, 51.23181274959019, 54.63703107833862, 57.483617714473176, 52.65706198556082, 55.310381003788535, 56.15269027437483, 57.21217591421944, 54.25848279680525, 53.57856682368687, 55.11612674168178, 58.02497965948922, 56.31167548043387, 46.78249209267752, 41.14871202196394, 44.8953092438834, 51.47648661477225, 57.97790561403547, 55.98393242699759, 53.24673475537981, 49.4289984021868, 51.63849081311907, 54.59472349711827, 56.99058396475655, 58.33022444588797, 57.65566553388323, 56.307298115321565, 47.63679395403181, 45.85895490646362, 50.67976100104195, 51.66616201400757, 50.44001340866089, 51.71243701662336, 58.43063981192452, 62.760736329214915, 61.574366160801475, 71.8461799621582, 34.796217237200054, 0.536526270210743, 0.767888255417347, 1.0193581644977843, 3.281660033123834, 1.7279795344386781, 1.5328590273857117, 0.7068530533994947, 0.09863891386027847, 0.06527886859008245, 18.91816602434431, 38.78214863368443, 33.38310650416783, 23.272067070007324, 16.458277906690324, 22.50210418019976, 47.41545213971819, 47.43714788981846, 63.17055497850691, 58.75645474025181, 73.14272771562848, 19.70805982181004, 0.9431053761925016, 0.06128873662757022, 0.06331039778888226, 0.05561564104365451, 0.07412670738995075, 0.04773491820586579, 0.04316385170178754, 0.023254931970898594, 0.028771784688745226, 0.015213374281302094, 0.018333933083340526, 0.026433948261131133, 0.01314496120903641, 0.01799155109828072, 0.03151959367096424, 0.019981980989021913, 0.009406561497598886, 0.06454123317130975, 0.0893163380346128, 0.04322408864806805, 0.023003751877695322, 0.03293291426130703, 0.054857636003621986, 0.1341614638056074, 0.10874626293246235, 0.10689056465136153, 0.07375744184745209, 0.15490882551031454, 0.15078699668603285, 0.10258863227707998, 0.15561807102390698, 0.10676701699516603, 0.2291995755263737, 0.10112541222146579, 0.1715529638209513, 0.14141602095748695, 0.15210391102092607, 0.17503262710358414, 0.23560141772031784, 0.10416658581899745, 0.1469929138464587, 0.08628480641969613, 0.14588839454310282, 0.6661334069711822, 56.93407426561628, 85.60522515433175, 77.25661713736397, 67.72408471788678, 58.88785907200405, 39.60136556625366, 35.612147671835764, 73.1527053288051, 56.42552866254534, 62.233173506600515, 15.778002364294869, 0.19562940831695283, 0.28256079075591906, 0.6702522773827825, 0.8418070461068834, 1.869720071554184, 5.0457592351096014, 8.388677409717015, 4.676122886793954, 2.8727170739855086, 44.4850354875837, 68.79173101697648, 65.36788804190499, 64.67935630253383, 61.27145249502999, 58.181192534310476, 59.37448310852051, 56.92419740131923, 55.36716168267386, 58.2536552974156, 60.610275813511436, 61.44096769605364, 53.83190161841256, 49.856948375701904, 58.64475549970354, 62.685737473624094, 61.37653010232108, 59.86417130061558, 58.196464674813406, 57.60309198924473, 59.299393926348, 60.8280462537493, 53.72215829576765, 48.19920546667916, 45.069601331438335, 43.32105936322893, 44.878932339804514, 52.74179179327828, 61.32407120295933, 60.84140069144112, 54.726805278233115, 57.97092267445156, 57.47457810810634, 54.27074636731829, 52.915409905569895, 57.45112793786185, 57.78872006280081, 57.22452286311558, 52.911473751068115, 57.25633519036429, 60.6845520564488, 59.8593145098005, 53.649521827697754, 55.93276936667306, 56.06075171061924, 63.438491412571494, 45.7641258920942, 34.06613874435425, 63.31495244162423, 56.35734946387154, 57.89732388087681, 54.15148401260376, 51.07207366398403, 50.385428360530305, 52.73920358930315, 59.150987352643696, 59.95722852434431, 53.07518720626831, 56.13818938391549, 58.278950214385986, 59.10636602129255, 56.09255708966936, 54.824820041656494, 57.20914997373308, 61.48601981571743, 59.825296129499165, 49.359683173043386, 42.956855637686594, 48.75574575151716, 55.21528795787266, 60.97701563153948, 58.50399194444929, 55.365511485508506, 49.82986429759434, 51.8517483983721, 57.120355469839915, 60.19730268205915, 59.27120508466448, 59.30507060459682, 60.12193557194301, 50.14724063873291, 49.5226149559021, 53.47913810185024, 54.54515504837036, 53.56390959875924, 55.21708754130772, 61.845575196402415, 66.33040114811489, 63.32423523494175, 75.04229572841099, 34.75145346777779, 0.727344702397074, 7.22860096182142, 8.800192287990026, 6.737361150128501, 1.9319531321525574, 2.2284028019223894, 0.6748249520148549, 0.3572024926543236, 0.42345847881266047, 26.738540717533656, 49.51340511866978, 44.8196815763201, 27.698788711002894, 17.217059407915386, 20.17713097163609, 48.42618574414934, 55.005421093532014, 72.62079988207135, 66.1509222303118, 81.76524066925049, 22.72222137451172, 1.1545149577515466, 0.1483491967831339, 0.26278263490114895, 0.23949420026370458, 0.16522973669426783, 0.28988297070775715, 0.14570261165499687, 0.1703008631510394, 0.14334696877215589, 0.1460295162562813, 0.16144070215523243, 0.2481823797736849, 0.11370144811059747, 0.15534212440252304, 0.09054330576743398, 0.2673636148018496, 0.08081554954073258, 0.1148214108709778, 0.15633954373853548, 0.11395911499857903, 0.12210518574076039, 0.1955365982971021, 0.18840025551617146], [0.04035076086542436, 0.01255839313047805, 0.09254803748003074, 0.06352217535355262, 0.024737620892535363, 0.054805158105279715, 0.08646653166839055, 0.025202313903719187, 0.04376192603792463, 0.033659448847174644, 0.035808203010154624, 0.018381025109972273, 0.009972668352669902, 0.030717602598347833, 0.013617191047939872, 0.013645278156868048, 0.02751932948428605, 0.03881927679425903, 0.05679387299876128, 0.04830424301326275, 4.814845408712115, 59.59237861633301, 62.83909811292376, 65.07264518737793, 60.26260880061558, 43.20500707626343, 22.42256988797869, 36.552030495234895, 27.803968804223196, 29.776456424168178, 34.19104651042393, 0.9915867575577327, 0.020255506936726824, 0.08345209913594381, 0.18817086996776716, 0.2197641118296555, 0.40591734434877125, 1.9760644223008836, 0.4437210001051426, 0.9395438815866197, 29.593433925083705, 66.41827501569475, 61.57558209555489, 58.93802506583077, 56.89871835708618, 55.59658077784947, 53.63814762660435, 49.801665033612935, 50.17795515060425, 46.96931178229195, 47.70506347928728, 50.86873810631888, 48.81112289428711, 42.2804901940482, 44.91471208844866, 55.69842747279576, 57.545838832855225, 58.666829926627024, 50.91849068232945, 59.36260863712856, 54.216230801173616, 53.288549014500205, 52.73988103866577, 48.79930053438459, 47.48842559541975, 40.99529232297625, 39.8622704233442, 40.292416027614046, 46.59432445253645, 51.54506880896432, 57.6011187008449, 51.82789870670864, 55.19711494445801, 54.22184147153582, 50.1324896131243, 43.84401553017752, 48.870391028267996, 51.19256932394845, 54.58726460593087, 50.74699871880667, 52.778231620788574, 53.07323823656355, 53.43846682139805, 48.8721558707101, 48.07068116324288, 49.07314988545009, 57.8492180279323, 42.03777224676949, 27.75381670679365, 50.964810848236084, 50.582083225250244, 58.022749287741526, 48.9376391683306, 49.74332101004464, 43.28162138802664, 45.44066987718855, 47.90338243756975, 52.73561484473092, 49.82978091921125, 48.64986562728882, 45.745000975472585, 45.22755125590733, 44.59605380467006, 54.911335536411826, 54.46566418239048, 55.37571838923863, 46.95226437704903, 41.78055688313076, 39.914798804691856, 41.78615713119507, 49.497031688690186, 56.4260949407305, 54.820282867976594, 52.13141686575753, 48.54441976547241, 54.08749457768032, 54.613577433994834, 55.23157453536987, 54.38428340639387, 54.374041761670796, 48.87948622022356, 44.71612562452044, 43.864874022347585, 46.09737886701311, 47.53713246754238, 48.27808836528233, 47.07678304399763, 52.60923753465925, 54.78867898668562, 59.03924642290388, 56.47193220683506, 66.66627706800188, 36.087717124394004, 1.0348067241055625, 1.2579505102975028, 1.853808913912092, 1.9417490065097809, 0.6271563470363617, 0.18804566668612616, 0.14098002149590425, 0.004429898565701608, 1.6900476898465837, 23.164495059422084, 32.09703663417271, 35.232018675122944, 28.962992600032262, 18.074699878692627, 22.99522999354771, 36.062071323394775, 39.29010016577584, 55.68533706665039, 53.32899100439889, 54.51214068276541, 2.9587001630238126, 0.25579752400517464, 0.052882186469755, 0.12202600070408412, 0.023179061577788422, 0.0381267435981759, 0.029420409883771623, 0.050118177463965755, 0.050025703318949254, 0.06175067648291588, 0.03298491718513625, 0.037651629985443184, 0.02967251617727535, 0.05678860417434147, 0.0552310881071857, 0.06383407754557473, 0.026563019192378436, 0.0222906030914081, 0.02325906085648707, 0.08258873796356575, 0.035542851713086875, 0.04737840572904263, 0.042027671954461505, 0.027998069866693447, 0.013214779917949011, 0.05369551586253302, 0.049761966935225894, 0.03515856001260025, 0.06038869385208402, 0.04854673785822732, 0.036445740942976305, 0.018886949301564267, 0.03733777021989226, 0.031710808231894455, 0.04361552532230105, 0.030821537199829305, 0.038271746531661065, 0.11373290499406201, 0.041195275727659464, 0.08963695261627436, 0.06548384723386594, 0.03921647762347545, 0.09683804120868444, 7.079088756016322, 70.65230573926652, 70.6327257156372, 72.98099449702671, 64.15756743294853, 50.468865803309846, 29.951908860887798, 32.79870394298008, 30.288837432861328, 31.299529348100933, 34.91918298176357, 1.3531175979546137, 0.03706573196021574, 0.0806727654167584, 0.6957676910928318, 0.9798944592475891, 2.7252862879208157, 3.3099124942507063, 0.7763204372354916, 1.555335364171437, 33.151547363826204, 70.10454450334821, 64.05565820421491, 64.3478924887521, 60.14183521270752, 57.08643089021955, 55.90253775460379, 53.211785316467285, 51.47861623764038, 49.499098777770996, 49.727138655526296, 53.29537909371512, 50.78531455993652, 44.82087319237845, 47.350531646183555, 57.979305676051546, 60.82586451939174, 59.92101451328823, 54.9931366784232, 57.804843357631135, 55.23461089815412, 56.77802814756121, 54.71426725387573, 51.029484680720735, 49.01126228060041, 43.90276254926409, 40.24653359821865, 41.53623390197754, 47.64224828992571, 54.34698895045689, 59.70868451254708, 53.16779974528721, 56.354608399527415, 56.52649988446917, 51.972977093287874, 46.919336863926475, 50.576448236192974, 54.64163425990513, 55.95044558388846, 51.89843681880406, 53.686913558415, 53.609458514622276, 55.864468574523926, 51.04091099330357, 49.10847452708653, 52.588403361184255, 59.97290366036551, 44.01218278067452, 30.039629868098668, 53.87352132797241, 54.24896723883492, 60.09370504106794, 53.81201239994594, 52.33756644385201, 45.67104434967041, 49.60281106403896, 49.33493716376168, 56.335844789232524, 53.481354577200754, 49.759242807115825, 45.52601112638201, 46.12038435254778, 44.6264591217041, 56.160784925733296, 57.189503942217144, 57.631506647382466, 49.45586708613804, 43.86357123511178, 42.78613492420742, 43.756621088300435, 51.91888189315796, 59.20213304247175, 54.7959884916033, 52.367256096431184, 48.40393761226109, 55.36586236953735, 57.52167994635445, 56.743947233472554, 57.65942103522164, 56.7762633051191, 52.25652265548706, 46.269357204437256, 47.39559071404593, 49.58383205958775, 49.325536251068115, 49.621817861284526, 49.80218267440796, 55.365681716373985, 57.09117303575788, 62.3194979258946, 58.65524727957589, 69.23615864345005, 42.572849546160015, 1.690580855522837, 0.39847742500049727, 2.3032162274633134, 4.3900064911161145, 3.2207547298499515, 0.6169062341962541, 0.13681651705077716, 0.009506487653457692, 1.6609120475394386, 28.36490903581892, 39.49694456372942, 32.23847416469029, 18.745020389556885, 20.02445994104658, 32.775604656764436, 46.31654242106846, 45.39986310686384, 61.156800270080566, 58.33579690115792, 66.71986852373395, 5.715485674994333, 0.4714273491076061, 0.0676359703232135, 0.0281833913509867, 0.035362079806093655, 0.037950161644922834, 0.032077268032091, 0.0293755892531148, 0.06844027180756841, 0.10941565129905939, 0.00372005975805223, 0.015411528559135539, 0.02175192940714104, 0.04321184787633164, 0.016125690058938096, 0.0363464882331235, 0.01780865028766649, 0.06815098518771784, 0.005423875608747559, 0.005590950438220586, 0.030960144940763712, 0.011088302059631263, 0.019660811704982604, 0.10070411661373717, 0.06903206290943281, 0.17490029920424732, 0.22933815951858247, 0.14048972566212925, 0.12908325344324112, 0.12408695582832609, 0.07295977643557958, 0.09355755509542567, 0.11396987656397478, 0.17387090729815619, 0.19224731837000164, 0.12597098973180565, 0.12232494966260024, 0.1938547542584794, 0.07599537926060812, 0.1788541091872113, 0.14796407387724944, 0.17141418983893736, 0.213555244995015, 9.050619261605398, 81.80763162885393, 80.00863879067558, 83.61164106641496, 73.10980715070451, 58.66055570329939, 32.40228489467076, 49.575820786612375, 37.27962153298514, 38.84103809084211, 49.992608479091096, 1.98395670737539, 0.11198254248925618, 0.32348972452538355, 0.9718568048306874, 1.473373219370842, 3.9449934789112637, 6.859307246548789, 5.161299092429025, 3.1389095102037703, 34.74353946958269, 71.2359961100987, 66.0813638142177, 64.43983800070626, 61.54715701511928, 59.99868147713797, 58.94074875967843, 56.528341157095774, 55.691326413835796, 51.95915365219116, 51.664108821323936, 55.064616271427695, 53.51018960135323, 47.695468017033164, 50.98638847896031, 59.59670039585659, 62.754656655447825, 63.33507442474365, 57.01239088603428, 57.11232335226876, 54.70106220245361, 59.36356748853411, 57.05312122617449, 53.52592727116176, 51.196314402988975, 45.23723357064383, 43.4382198878697, 44.30584144592285, 51.464622565678184, 56.24922507149832, 61.43565927233015, 53.88227605819702, 59.39674513680594, 60.16475731985909, 53.65851627077375, 49.66162061691284, 53.92224209649222, 56.79590933663504, 58.965699740818565, 53.206383092062815, 54.992295946393696, 58.38230119432722, 58.03907060623169, 53.0206230027335, 51.752090385981965, 55.905601910182405, 61.755373682294575, 47.771658488682334, 33.53667906352452, 51.87211356844221, 56.61973081316267, 60.723753792899, 56.25848702022007, 54.93115874699184, 48.57152468817574, 51.490066868918284, 50.27838093893868, 58.882564544677734, 54.3611215863909, 51.240032468523296, 46.21449770246233, 45.62652029309954, 45.673406737191335, 56.60989563805716, 59.23136411394392, 60.022131647382466, 51.94146006447928, 45.13041543960571, 44.8076160294669, 45.05905744007656, 55.074256896972656, 61.51721722739083, 57.84456273487636, 54.278427600860596, 48.398531913757324, 57.186735085078645, 59.341472217014854, 58.5568607875279, 59.36481121608189, 59.18583951677595, 55.10615955080305, 48.37343502044678, 50.167334829057964, 51.059747559683665, 52.15771927152361, 52.56564106260027, 51.696678502219065, 57.58010734830584, 58.82629803248814, 64.63016305650983, 61.46553652627127, 72.48463603428432, 44.33634751183646, 1.6725838269506181, 4.263513667242868, 8.981669681412832, 5.9239594255174906, 3.6385214669363837, 0.8671536945870945, 0.4126784572643893, 0.12960119279367582, 2.879787734576634, 36.571513244083945, 46.31525353022984, 48.370721748897004, 41.21357692990984, 27.18359194483076, 32.313007490975515, 49.491612093789236, 52.622960226876394, 70.88666152954102, 65.19155665806362, 73.92541449410575, 5.789722400052207, 0.5739864515406745, 0.15174348678972038, 0.2154299693980387, 0.11327051730560404, 0.08732319570013455, 0.11542407210384097, 0.1208546185599906, 0.20549586388681615, 0.20744410077376024, 0.09935725852847099, 0.1600429200168167, 0.09294540794300181, 0.11653336829372815, 0.08307615002351147, 0.1781468992786748, 0.22392277153474943, 0.12138046962874276, 0.09569462149270944, 0.20264351979962417, 0.14353210026664392, 0.1529292403055089, 0.15689941655312264], [0.019926732971466014, 0.07569001136081559, 0.07526252072836671, 0.030146601809454814, 0.07855679467320442, 0.02082771891062813, 0.009782120452395507, 0.0029578972067351317, 0.02856725387807403, 0.018733096575098376, 0.026007297315767834, 0.03359734592959285, 0.07513055923793997, 0.019482245036799992, 0.08359413008604731, 0.051316531375050545, 0.0700201184621879, 0.018591966380232146, 0.13243414435003484, 0.14185710943170957, 19.167908600398473, 71.57252516065324, 60.591265542166575, 60.94819450378418, 36.99933467592512, 27.520690747669764, 14.254290206091744, 50.140521730695454, 51.06059523991176, 62.25145421709333, 14.705824102674212, 0.11396210055266108, 0.09826830481844288, 0.06611375164772783, 0.25544045173696106, 0.3445051211331572, 1.517954164317676, 1.3794021989618028, 0.9909047484397888, 13.64169098649706, 60.79346506936209, 62.6407687323434, 63.495800154549734, 60.02985804421561, 59.548299244471956, 49.10432297842843, 49.984058720724924, 47.137190682547434, 47.04592956815447, 43.8293583052499, 44.65324442727225, 43.681347778865266, 44.93002591814314, 42.332153524671284, 44.82979815346854, 54.37599767957415, 56.10107210704258, 55.03882455825806, 57.571856362479075, 54.030356066567556, 52.18918766294207, 54.23098182678223, 54.522767952510286, 52.53444365092686, 51.240400723048616, 48.068020003182546, 40.85610948290144, 37.93415226255144, 44.68750946862357, 51.310546261923655, 57.12370102746146, 51.12973328999111, 53.85866955348423, 53.28257008961269, 48.222346442086355, 41.72028126035418, 46.526020186288015, 50.542422907693044, 52.7018917628697, 51.10344478062221, 51.81189700535366, 52.43461888177054, 53.604716369083945, 45.32925203868321, 46.27585029602051, 47.172932216099326, 57.204109055655344, 40.15854855946132, 28.996932813099452, 50.54963861192976, 44.44165093558175, 54.342406613486155, 52.61894416809082, 51.52874401637486, 47.37010472161429, 47.04530423028128, 48.50712183543614, 53.18468386786324, 54.727861404418945, 52.76331731251308, 49.383254936763215, 47.73155001231602, 48.56345435551235, 54.165894576481406, 52.04546070098877, 52.21213756288801, 43.364690576280864, 40.50376285825457, 39.70797872543335, 41.93058238710676, 50.423230034964426, 54.43447024481637, 53.76348270688738, 53.4747051511492, 49.55686957495553, 55.669905117579866, 55.37780284881592, 54.96399940763201, 52.693133558545796, 47.18492480686733, 48.7716258593968, 44.50024162020002, 46.29755299431937, 49.263561793736045, 50.27042177745274, 50.25274903433663, 51.07304293768746, 47.41388532093593, 50.48423521859305, 53.8917464528765, 60.78872639792306, 58.08572775976998, 63.064372607639854, 34.41345139912197, 1.5067762498344694, 3.155283591576985, 3.457001950059618, 5.4895345994404385, 0.8799365886620113, 0.028069402556866407, 0.12719931453466415, 0.08634884655475616, 11.182813831738063, 32.122751917157856, 41.764100074768066, 43.93505082811628, 29.20521722521101, 15.856994697025844, 22.143511125019618, 46.57885428837368, 48.09372138977051, 50.6476012638637, 58.36450685773577, 33.66878168923514, 0.10220031347125769, 0.038243295558329136, 0.05066834044243608, 0.0278057628643832, 0.023619603831321, 0.07712525541761092, 0.030167822992163043, 0.11473222422812666, 0.05025798960455826, 0.056895510759204626, 0.050036017051232715, 0.05973457930875676, 0.05142419791913458, 0.023956426918240528, 0.01295342095129724, 0.03608519796814237, 0.04996606348348515, 0.020834767193134342, 0.023544035386294127, 0.020832156529650092, 0.02761217173455017, 0.024792008866955127, 0.07689838723412581, 0.032890902765627415, 0.049807988572865725, 0.051552115340850184, 0.04469249949657491, 0.06299903842487506, 0.005292845407633909, 0.04195365735462733, 0.009420565612215017, 0.01188024742129658, 0.028978249324219565, 0.03154818374397499, 0.008964579053489225, 0.03544664562546781, 0.05464962770098022, 0.04350559586392982, 0.03184394358790346, 0.024406178588313714, 0.09813390060194901, 0.14806285500526428, 26.994609628404888, 83.07965224129813, 66.34864016941616, 68.30358532496861, 49.528527872903005, 41.173180103302, 16.464633771351405, 41.60786982945034, 43.424941880362375, 51.32518611635481, 17.468130826950073, 0.050554421198155196, 0.05259134600471173, 0.46396389816488537, 0.7678074283259255, 1.4880315299545015, 3.1522474459239413, 1.5802060067653656, 0.3546921844993319, 15.617825542177473, 63.82828535352434, 65.05036926269531, 67.23792621067592, 60.33801759992327, 60.293979917253765, 53.71831594194685, 53.670248304094585, 50.99076584407261, 50.49185391834804, 47.392005443573, 47.1241489137922, 46.06760583605085, 45.787447520664756, 44.16617570604597, 47.386009148189, 56.189046723502024, 57.04855625970023, 55.83816269465855, 58.936586788722444, 53.83699812207903, 51.941765785217285, 56.852999210357666, 57.44019147327968, 53.70957510811942, 54.80345433098929, 49.50432729721069, 43.09454114096505, 39.8358325277056, 45.79875571387154, 52.859299727848594, 58.94962855747768, 53.88685144696917, 54.88583564758301, 56.335056168692454, 50.59484011786324, 43.26593582970755, 47.49889653069632, 53.37512009484427, 55.34405197416033, 53.44092648369925, 53.85535178865705, 54.44224527903965, 55.50589983803885, 49.09943144662039, 48.30134746006557, 48.63635832922799, 59.22978687286377, 43.07753542491368, 31.467696598597936, 51.201289313180105, 44.189820425851, 55.35598203114101, 53.52473218100411, 55.33565160206386, 49.646890435900005, 50.27280500956944, 50.99493128912789, 55.47490392412458, 56.1470170702253, 54.324073791503906, 49.85223749705723, 48.21255990437099, 48.38954094478062, 56.35169015611921, 54.24170637130737, 54.22338744572231, 44.857253960200715, 42.77120671953474, 41.27610029493059, 43.778990813664024, 52.289953913007466, 57.92414740153721, 56.21239267076765, 53.64252846581595, 49.44363130841936, 56.63030597141811, 57.60486377988543, 57.276217460632324, 53.80214943204607, 51.23379993438721, 50.383868489946636, 46.57928507668631, 47.603140354156494, 51.55327810559954, 53.766369683401926, 52.681700297764365, 53.62293454578945, 49.52421651567732, 52.69573565891811, 54.93926382064819, 62.912054198128835, 60.30883516584124, 65.2046401160104, 39.93048088891165, 2.0004460854189734, 0.7411562012774604, 4.819814673491886, 9.138969949313573, 2.622613842998232, 0.12970590431775364, 0.22259035946003028, 0.09609700632946831, 11.826232654707772, 37.3718067577907, 37.10443312781197, 39.18046801430838, 20.04913125719343, 17.779165199824742, 31.736557143075125, 51.855653285980225, 55.87665571485247, 54.94105992998396, 65.29780851091657, 40.965157985687256, 0.2643320289041315, 0.03374809266201087, 0.03701416329879846, 0.12141018946255956, 0.04150472840826426, 0.047349211759865284, 0.033901563712528775, 0.03632607789976256, 0.032562790372009785, 0.054325101364936144, 0.011680339130439928, 0.04763391487566488, 0.04315110881413732, 0.06817742091204439, 0.0057625952010442105, 0.08477108978799411, 0.09505337875868593, 0.04086743474804929, 0.057428265921771526, 0.032065936497279575, 0.035359952598810196, 0.04283689281770161, 0.1851297031555857, 0.14819712351475442, 0.14326961578002997, 0.1179414913058281, 0.13392930983432702, 0.13830729919884885, 0.08526236949754612, 0.12095962863947664, 0.06721668996449028, 0.10525751406592981, 0.08429829337235008, 0.1264916296516146, 0.12252553818481308, 0.14653037009494646, 0.13382074423134327, 0.14053126557597093, 0.2608158332960946, 0.12080823390611581, 0.23012295312115125, 0.20206118747591972, 33.67904417855399, 93.4103867667062, 76.59488459995815, 78.20490728105817, 52.07655736378261, 40.509498596191406, 21.550781147820608, 64.9078825541905, 63.70692811693464, 82.72431441715786, 23.20630931854248, 0.3436150460370949, 0.20088240930012294, 0.5207804579819951, 1.3663905028785979, 2.305176270859582, 4.692486763000488, 5.261736605848585, 4.643579695905958, 16.206662791115896, 65.02095753805978, 66.15095002310616, 70.10143865857805, 63.968569483075825, 65.90166255405971, 56.2981264931815, 56.1287294115339, 52.113191740853445, 52.99740212304251, 48.847965717315674, 49.60394014630999, 48.54857478822981, 47.20595005580357, 46.59896584919521, 48.414224420275005, 58.697269984654014, 61.26383032117571, 59.40388788495745, 61.66617270878383, 53.93006924220494, 53.629180976322715, 57.74375132152012, 58.837324823652, 56.29058074951172, 57.45843396868025, 52.38102395193917, 47.5610169001988, 41.07931341443743, 47.50079338891165, 55.11326060976301, 61.15550095694405, 55.248451709747314, 56.47118180138724, 59.32592909676688, 53.91529737200056, 46.217329093388145, 51.21377175194876, 55.97768947056362, 56.28968790599278, 55.33036749703543, 55.96687112535749, 58.18433659417288, 57.5417845589774, 50.693115438733784, 50.66196666445051, 52.60739278793335, 61.419414384024485, 46.635534218379426, 34.59139476503645, 52.124142101832796, 44.5357642854963, 57.249171597617014, 55.705493790762766, 56.685002190726145, 54.1136337007795, 51.772104672023225, 53.19887556348528, 57.635286467415945, 58.92234992980957, 56.445445673806326, 50.58091940198626, 48.66454369681222, 48.358194146837505, 57.828974451337544, 55.78950445992606, 56.458563872746055, 48.59999145780291, 45.01406438010079, 44.752749579293386, 46.35413217544556, 55.17222302300589, 61.09362030029297, 58.297206606183735, 54.62561518805367, 49.255508831569124, 59.66352122170584, 59.43226432800293, 61.50510651724679, 57.45807613645281, 53.30388368879046, 53.6196654183524, 50.37689249856131, 50.33427224840437, 54.57745374952044, 56.27353681836809, 53.778039182935444, 55.773989132472444, 51.59306001663208, 55.177277837480815, 58.218691962105886, 65.88003976004464, 62.51216452462332, 66.94678279331752, 41.16648203986031, 1.8744565716811588, 6.163914161069052, 9.305436628205435, 9.837012904030935, 2.7852789887360165, 0.22297823721809046, 0.2777616482760225, 0.3758151153368609, 15.902149302618843, 49.14476844242641, 53.92638322285244, 58.81062289646694, 44.454974106379915, 25.930823053632462, 34.591332231249126, 58.693483216421946, 62.571189471653526, 63.84539181845528, 72.27047170911516, 49.43489394869123, 0.48625002801418304, 0.1526107902505568, 0.15109381665076527, 0.1784877274185419, 0.08456602293465819, 0.15003114938735962, 0.11554601841739245, 0.20688091670828207, 0.10336662695876189, 0.1774472075381449, 0.12530088211808885, 0.11105792317539454, 0.14211986533233098, 0.1002290810325316, 0.10353062208741903, 0.14775169241641248, 0.17044416974697793, 0.15801237683211053, 0.19748716934451035, 0.08848020647253309, 0.09060098802936928, 0.10819287012730326], [0.06942496861198119, 0.02788344324965562, 0.031361427158117294, 0.003080260395238708, 0.00929028688863452, 0.0714203297559704, 0.10563024692237377, 0.05874266289174557, 0.0046036378813109225, 0.05118345369451812, 0.016046308247106414, 0.009252070100046694, 0.020698719225557785, 0.03593437659687229, 0.02918885980865785, 0.01843731976779444, 0.03437181901452797, 0.07701673731207848, 0.061850828251668384, 0.6027794065220016, 47.47345570155552, 64.62802301134381, 63.29349640437535, 52.16179438999721, 29.549285071236746, 18.641896963119507, 31.142298562186106, 45.15213203430176, 54.79657561438424, 41.512495381491526, 2.0572174276624406, 0.11374496934669358, 0.08751133989010539, 0.3335107910845961, 0.6331469970090049, 0.6212533637881279, 2.4157635825020924, 1.3720454680068153, 4.2707133037703375, 52.61380597523281, 64.43672520773751, 62.7968739100865, 62.363174302237375, 60.58772196088518, 50.23306131362915, 45.46680552618844, 45.69784007753645, 43.79746259961809, 42.728565624782014, 44.8037736756461, 42.03948497772217, 43.664487974984304, 42.657238892146516, 43.29103619711739, 42.91815069743565, 47.67974771772112, 53.40956578935896, 54.28811338969639, 54.81449154445103, 52.18427528653826, 50.86638961519514, 52.200221402304514, 52.81006826673235, 53.812279905591694, 54.60213722501482, 53.57138238634382, 44.817781244005474, 38.320201124463765, 40.02622011729649, 45.267482553209575, 56.92262710843767, 53.546566895076204, 55.27993399756295, 51.38832787105015, 44.125466210501536, 38.98731504167829, 43.89599847793579, 50.27384723935808, 56.89123167310442, 50.15999753134591, 49.86405985695975, 50.322529792785645, 53.78790215083531, 45.71704837254116, 42.10875851767403, 45.9094683102199, 56.70221635273525, 43.43388073784964, 31.45152814047677, 50.50189059121268, 49.488937037331716, 49.09926816395351, 51.65427017211914, 52.88823202678135, 49.85412393297468, 51.753504344395225, 49.492768968854634, 54.11357464109148, 51.966616017477854, 52.011636870247976, 49.73654304231916, 49.14711345945086, 48.927407945905415, 53.35152401242937, 52.38846547263009, 48.35306290217808, 39.025439807346885, 39.93745340619768, 38.2891183580671, 39.98160226004464, 46.177300521305625, 54.257280758449006, 55.06812163761684, 51.7789625440325, 49.1489269392831, 54.589578356061665, 52.66857515062605, 51.97155271257673, 51.226209027426584, 47.849127428872244, 43.16518695013863, 43.767098971775596, 47.3121463230678, 50.55150072915213, 52.96262638909476, 54.79472391945975, 55.39320700509207, 51.90587486539568, 48.350933279309956, 49.322944572993684, 51.8612048966544, 59.258371761866975, 60.28626046861921, 59.8530124936785, 25.58910196168082, 0.169728939554521, 3.181793574775968, 3.3923326773302893, 2.034216501883098, 0.17290255640234264, 0.05972898139485291, 0.0327157525212637, 0.5593524596520832, 24.297873054231914, 39.94482544490269, 28.64152029582432, 52.05753319604056, 49.97645044326782, 21.17286515235901, 24.851430824824742, 28.921428476061138, 43.78790882655552, 50.84600012642996, 48.28358439036778, 6.9184529185295105, 0.22167635921921047, 0.010265463846735656, 0.08009771377380405, 0.02879394224977919, 0.035613171689744504, 0.03571209531011326, 0.06720770616084337, 0.014186933154373296, 0.03725389311356204, 0.06609304275895868, 0.03645107422822288, 0.042381205662552796, 0.023137821915692518, 0.024861309344747236, 0.11704579793981143, 0.03909341172714319, 0.07294730496193681, 0.07536290319902555, 0.014487251905458314, 0.01568955828302673, 0.11556712085647242, 0.047347752909575186, 0.022741540501426374, 0.0715561860374042, 0.0199180036184511, 0.01413262660415577, 0.015009574592113495, 0.0915640734934381, 0.03550095217568534, 0.02274807818633105, 0.023863810280870115, 0.04387290383289967, 0.048795159706579785, 0.05171008847121682, 0.010862980935988682, 0.04012829637421029, 0.035387022753379176, 0.05053843830579093, 0.010129889157334608, 0.04469564450638635, 1.0935353956052234, 61.34329686846052, 72.8787795475551, 71.23678125653947, 60.49189240591866, 34.38533203942435, 24.5012937273298, 28.499750988824026, 45.33039154325213, 47.973305634089876, 41.51555258887154, 2.973003681216921, 0.13183688425592013, 0.030353388749063015, 0.8243651134627206, 1.0582132509776523, 3.754226778234754, 2.56659768308912, 0.34620596415230204, 6.049294071538108, 54.89972857066563, 65.71527017865861, 65.24838597433907, 64.03202043260846, 62.83397034236363, 53.03575617926461, 48.753529276166645, 47.363910402570454, 45.864325863974436, 45.290456771850586, 45.979513100215364, 43.992060797555105, 46.13930777141026, 44.45157296316964, 43.93355696541922, 44.914142336164204, 49.874502999441965, 54.42819949558803, 56.824699197496685, 57.99449096407209, 52.74589817864554, 51.75659629276821, 53.19798966816494, 53.841312953404014, 55.78683982576643, 56.644869395664756, 56.295680727277485, 47.07551499775478, 40.31064115251814, 41.67587879725865, 48.14395686558315, 57.09952129636492, 53.897277218954905, 56.11580923625401, 54.58849791118077, 46.15597997392927, 40.21111863000052, 47.27100951331002, 52.91498259135655, 59.15510068620954, 51.7920321055821, 52.260059288569856, 52.91405848094395, 55.39658382960728, 48.14890398297991, 45.24942071097237, 47.938866887773784, 57.69587128502982, 45.29465348379952, 33.94875240325928, 52.007655552455354, 51.24984679903303, 50.49338947023664, 53.32470743996756, 55.27642168317522, 52.90386894771031, 55.020248549325125, 53.08301435198103, 54.28536190305437, 54.31572205679757, 52.51033340181623, 51.98362520762852, 51.95216029030936, 49.52226407187325, 56.402568340301514, 55.06878866468157, 50.19687162126814, 40.89429330825806, 42.375878538404194, 41.099914823259624, 40.96846532821655, 47.15195560455322, 56.6685905456543, 55.203687940325054, 52.258541107177734, 49.138622760772705, 55.42453990663801, 56.1527111189706, 54.13632999147688, 53.66214670453753, 49.974709919520784, 45.362565176827566, 45.53952537264143, 50.45140845435006, 51.655604226248606, 55.989261695316856, 57.767746925354004, 58.289473261152, 55.32949202401297, 51.527343954358784, 52.62533303669521, 54.11480794634138, 60.75061552865164, 60.76812498910086, 63.89454337528774, 29.82190111705235, 1.0195560795920235, 1.0682658829859324, 3.5274132575307573, 2.0708717235497067, 0.7126098530633109, 0.20181833979274544, 0.023713826900348067, 0.6049022440399442, 28.828438997268677, 37.49663461957659, 24.228309426988872, 43.243072782244, 44.48735271181379, 26.6154169014522, 36.759997027260916, 34.34155144010271, 49.1474608693804, 56.83543069022042, 59.24066080365862, 9.900234563010079, 0.27846021364842144, 0.053916212770023515, 0.04820410142253552, 0.00972162396647036, 0.03186123605285372, 0.09024932368525437, 0.036290336067655256, 0.07712273805269174, 0.05148190053712044, 0.020230541937053204, 0.021447955896811824, 0.054008459605808766, 0.04065676319545933, 0.07507332480911698, 0.020696795578779917, 0.028218240909544483, 0.04318473022431135, 0.05657168331422976, 0.023909986285226684, 0.011155971508872296, 0.023256177082657814, 0.16032638480620726, 0.08302110726279871, 0.137527268912111, 0.18476302283150808, 0.1596118060073682, 0.17857531271874905, 0.1688130936984505, 0.1808571717036622, 0.0507929330425603, 0.09157659924988236, 0.1638614029756614, 0.10315977555832692, 0.12274790768112455, 0.15378339375768388, 0.17906107593859943, 0.133541947762881, 0.1298638265579939, 0.180271392422063, 0.1308884687189545, 2.360511290175574, 74.66793373652867, 81.42479283469063, 81.76524066925049, 66.89374719347272, 43.32499899183001, 25.082043273108347, 45.22600180762154, 57.49004479816982, 66.49469130379813, 59.681273869105745, 3.9565765602248053, 0.20630830100604466, 0.22692241200378963, 1.0028653123549052, 2.5084749162197113, 5.17461314371654, 8.493787152426583, 6.2864808184759955, 6.201815281595502, 56.80406999588013, 67.56614521571568, 69.44024113246373, 67.1244968686785, 65.7173685346331, 53.92094625745501, 50.311638491494314, 50.06007548740932, 48.218187945229666, 48.51370872770037, 48.97805336543492, 46.44889865602766, 47.81051976340157, 46.108485562460764, 46.53645290647234, 47.10310282026018, 52.1923907824925, 57.62434305463518, 59.672741481236045, 59.114995683942524, 53.626318318503245, 51.20617389678955, 53.58382313592093, 54.36671836035592, 58.62978907993862, 58.808878898620605, 57.297621386391775, 49.34832981654576, 42.172699315207346, 43.4060184614999, 50.34418732779366, 60.743431091308594, 56.4645289012364, 57.826789242880686, 57.92583233969552, 47.59366301127842, 42.53465529850551, 48.42482737132481, 54.99099663325718, 62.63128444126674, 53.70079953329903, 54.97581481933594, 56.31860978262765, 58.10564477103097, 50.79262406485421, 46.2556414604187, 51.036071572984966, 59.682552337646484, 48.89104107448033, 37.63962507247925, 52.87871299471174, 53.20757818222046, 50.138034275599885, 53.690217426845, 55.90735633032662, 55.54235356194632, 56.66572093963623, 53.961367402757915, 58.417625835963655, 55.38476841790335, 54.79943479810442, 52.54059975487845, 52.93210990088326, 50.06110382080078, 58.67919077192034, 57.03148800986153, 53.61348499570574, 42.350965772356304, 43.54000057492937, 41.98465326854161, 42.90669311795916, 49.888823236737935, 60.66606984819685, 57.56387635639736, 52.7084195954459, 49.27533551624843, 58.81612586975098, 58.24093314579555, 56.78827326638358, 57.08003854751587, 52.34710284641811, 47.32766859872, 48.41957800728934, 52.62553106035505, 54.57614401408604, 58.261336530957905, 58.72632735116141, 59.977531160627095, 58.76548739842006, 52.90810734885079, 54.44130727222988, 57.76773302895682, 63.31017902919224, 65.28321729387555, 65.68571254185268, 31.94659423828125, 2.090261323111398, 8.931421177727835, 8.566763213702611, 4.5629879747118265, 0.9746746250561306, 0.20424854010343552, 0.18675081831003937, 1.1148804788078581, 37.845461981637136, 52.01174109322684, 34.52976771763393, 57.62910604476929, 60.28950527736119, 31.023675441741943, 38.20801551001412, 40.3257291657584, 60.062597955976216, 63.36183193751744, 69.64087731497628, 12.560255987303597, 0.4116616318268435, 0.13895592439387525, 0.17409740228738102, 0.09456573599683386, 0.1427165147449289, 0.18946973527116434, 0.1129071753738182, 0.21338584194225924, 0.13469921637858662, 0.1621204721076148, 0.1457816202725683, 0.1636195866657155, 0.09188082042549338, 0.2371557243168354, 0.22209071341369832, 0.10756088261093412, 0.2385442512375968, 0.17042123526334763, 0.1312478751476322, 0.09356659318187407, 0.15848178735801152], [0.05137131289978113, 0.021655582523505603, 0.04559011311669435, 0.04887344907703144, 0.0645822166864361, 0.03382558814649071, 0.02362828059787197, 0.0412037947348186, 0.01768821371453149, 0.08271063677966595, 0.026851240512249724, 0.015104472803484117, 0.024676868259640675, 0.04612658325848835, 0.04956066595124347, 0.05082203201683504, 0.018547147445912873, 0.08748901608799185, 0.06421907831515584, 7.3113479273659845, 62.92294202532087, 62.82412474496024, 57.123100008283345, 49.27936199733189, 37.22916371481759, 22.672388894217356, 38.795926911490305, 26.036496468952723, 59.5275171824864, 22.452843189239502, 0.16594519758863108, 0.00525029150802376, 0.09386310619967324, 0.24404312617012433, 0.7342652710420745, 1.934206736939294, 2.6698253325053622, 0.2602349530373301, 37.47935444968087, 65.70848178863525, 60.27337156023298, 61.3307067326137, 61.969100270952495, 56.69558082308088, 49.8949202810015, 43.02842208317348, 44.7883243560791, 44.481439794812886, 42.43987839562552, 42.954239640917095, 42.23883574349539, 42.3556592805045, 43.331318378448486, 40.64868491036551, 41.69147055489676, 42.923549447740825, 52.02325078419277, 53.81638976505825, 57.002430643354145, 52.63966369628906, 53.22717210224697, 51.61194174630301, 51.82681131362915, 49.86403553826468, 53.67519542149135, 53.857022830418174, 48.28972659792219, 38.689508301871165, 39.53019516808646, 40.01777458190918, 47.66725485665457, 56.46350751604353, 52.5945177759443, 49.14662708554949, 42.646827016557964, 39.16731507437569, 45.29296159744263, 51.99449913842337, 53.79666730335781, 49.29275812421526, 50.196611063820974, 53.49179424558367, 51.77507850102016, 44.438451290130615, 39.98348869596209, 46.70761830466134, 56.77347012928554, 41.74316167831421, 34.38428633553641, 54.414660930633545, 51.02114336831229, 55.05761596134731, 49.2185617855617, 52.439538206372944, 51.38621909277779, 52.28127908706665, 52.712751797267366, 52.52074180330549, 52.2126795223781, 53.23067399433681, 51.82052666800362, 53.17428241457258, 48.06479603903634, 54.02839320046561, 54.558064801352366, 48.09999908719744, 40.0503442628043, 38.19575888769967, 39.67509984970093, 39.474439348493306, 41.739374910082134, 52.70329877308437, 54.32432740075247, 55.12486410140991, 47.170958927699495, 53.224802766527446, 54.27459566933768, 53.43603147779192, 48.302448749542236, 45.95435019901821, 43.984292711530415, 42.28593758174351, 48.25120578493391, 53.24220452989851, 57.70473371233259, 60.444887842450825, 57.86470556259155, 54.52865307671683, 51.84194796425955, 50.94775996889387, 52.31371327808925, 55.20221839632307, 57.69990471431187, 64.52787167685372, 53.830279214041575, 8.592054656573705, 2.924594495977674, 5.609064025538308, 2.623476939541953, 0.4218723624944687, 0.0909632918025766, 0.06523657550237008, 0.025955350371077657, 6.36510055405753, 32.138347148895264, 71.43841797964913, 83.83032866886684, 95.72738865443638, 39.505591596875874, 14.940551621573311, 26.983869450432913, 41.45462383542742, 48.13105753489903, 54.50005776541573, 22.38337336267744, 0.17412017392260687, 0.018646802187764218, 0.04334153288177081, 0.029956978413143327, 0.0221177276356944, 0.08623439126781055, 0.02727481090862836, 0.08022943099162408, 0.03641304912577782, 0.026111459226480553, 0.01290779625664332, 0.020125525072216988, 0.0337397466812815, 0.02018851347799812, 0.005520813241933605, 0.02372648157844586, 0.05910394207707473, 0.058853521943092346, 0.09084559990359203, 0.04908674656014357, 0.036062120992158136, 0.024824064557573626, 0.027221014956012368, 0.06111396636281695, 0.06528627140713589, 0.04768036399036646, 0.047812023532709906, 0.0168875186438007, 0.030009117043976272, 0.0384766064318163, 0.01611153581844909, 0.04549569836152451, 0.03344806822549019, 0.04311925159501178, 0.037350943977279324, 0.09330826132957425, 0.04908257696245398, 0.02887994995606797, 0.03466575699193137, 0.09347670086260353, 11.542791315487452, 75.36886801038469, 69.24086952209473, 65.38627992357526, 56.71920122419085, 48.37504352842058, 23.671784775597708, 40.81137350627354, 34.65377221788679, 60.59018162318638, 24.205830267497472, 0.28029125396694454, 0.07934570698333637, 0.2630808103297438, 1.9246221312454768, 1.8493837799344743, 2.92809682232993, 0.8034223743847438, 1.1551290048020226, 40.62106582096645, 67.80918625422886, 64.25400148119245, 65.0669754573277, 64.76106711796352, 60.11869076320103, 52.127049922943115, 46.10055071966988, 47.516308716365266, 46.72595112664359, 44.55685206821987, 43.73376498903547, 43.13498313086373, 44.5366119657244, 44.6830278805324, 43.097358635493684, 42.88048103877476, 46.16284132003784, 53.43125459126064, 56.90835550853184, 58.94548743111746, 54.35921083177839, 54.474113191877095, 53.57963337217058, 51.76355491365705, 51.069950989314485, 55.35305683953421, 56.08362865447998, 51.0549567767552, 41.318018777029856, 41.098295892987935, 40.89671128136771, 50.09211710521153, 55.80549226488386, 55.98384557451521, 51.45656265531267, 44.24742794036865, 40.34791823795864, 47.50071348462786, 53.77777515138899, 55.99265936442784, 51.38839735303606, 51.658303601401194, 54.74752480643136, 53.61869267054966, 45.56888151168823, 42.49012776783535, 47.929580620356965, 57.56386593409947, 45.302247864859446, 36.98341982705252, 56.03587021146502, 53.55281332560948, 57.24609007154192, 50.16144970485142, 55.471019881112234, 52.88607808521816, 55.57285615376064, 52.63956989560808, 54.63911206381661, 55.30368294034685, 55.559911659785676, 54.14112424850464, 56.26467439106533, 49.17199148450579, 55.67306307383946, 56.834791455950054, 50.10865729195731, 43.94064065388271, 39.74016625540597, 40.56285728727068, 39.81171185629708, 44.024870191301616, 53.248992919921875, 56.15530627114432, 57.01010840279715, 48.81142514092581, 54.39101273672921, 57.22129889896938, 54.995843001774375, 49.602849279131206, 47.22620405469622, 45.19656923839024, 45.65090152195522, 49.29296657017299, 56.79276180267334, 58.92037664140974, 62.07695715767996, 60.873021943228586, 56.20571545192173, 54.837948662894114, 52.94715622493199, 54.604318959372385, 57.39042500087193, 60.56210395268032, 66.2890385219029, 56.348949091775076, 11.823233638490949, 1.0798965160335814, 2.1135812146323065, 4.7817776288305005, 2.23995309642383, 0.44664355899606434, 0.11838390970868723, 0.09424777448709522, 6.882297532899039, 37.2523706981114, 63.59490925925118, 84.47004931313651, 89.71486922672817, 48.19046115875244, 20.40193819999695, 33.97445726394653, 47.38137469972883, 52.872199058532715, 62.97498403276716, 29.57889481953212, 0.23446948560220854, 0.041397207749209235, 0.028411543661994592, 0.0648456850488271, 0.028053250030747483, 0.07518319998468671, 0.062837411383433, 0.03025613771751523, 0.0967840433919004, 0.01436420127616397, 0.024605415129501904, 0.013818652335820454, 0.06019832406725202, 0.012980136571318975, 0.009269468586093612, 0.04965749629107969, 0.04747319707114782, 0.03102649888023734, 0.08773020814572062, 0.03542391809501818, 0.056947537431759496, 0.11624136753380299, 0.16661568518195832, 0.12972987017461232, 0.17262931035033294, 0.14834465059850896, 0.10606836341321468, 0.10267133891050305, 0.12223740507449422, 0.19580449749316486, 0.13611229269632272, 0.24960779185806, 0.14557240078491823, 0.11348413370017495, 0.08842181174882821, 0.17420697212219238, 0.30003692156502176, 0.08731475472450256, 0.18349823355674744, 0.16455870627292565, 15.573275429861885, 88.41683455875942, 76.5432733808245, 77.5790274483817, 63.16949885232108, 53.13718250819615, 31.087435586111887, 51.167253562382285, 36.579250063214985, 77.1376987184797, 34.5394743510655, 0.30361774084823473, 0.21517447382211685, 0.5178678057023457, 1.8801171822207314, 2.280956370489938, 5.472534094538007, 8.352501613753182, 1.901033865553992, 43.95539515359061, 68.26220880235944, 68.38886056627545, 65.74568244389125, 68.62033285413469, 62.02392850603376, 54.42319679260254, 47.744160992758616, 50.340007986341206, 48.98863547188895, 46.71966300691877, 46.022296633039204, 45.31870814732143, 46.2956074987139, 47.379130431583945, 44.35429470879691, 46.334211690085276, 48.05618027278355, 57.57845715114048, 59.19619928087507, 61.10302816118513, 55.731073583875386, 56.38484695979527, 53.99444777624947, 52.72414684295654, 52.31155933652605, 58.29693562643868, 58.70723370143345, 53.98304230826241, 43.397301946367534, 42.81260756083897, 43.57229927607945, 52.30759538922991, 60.44809791019985, 58.215054580143516, 53.502605642591206, 46.89920793260847, 42.316134452819824, 50.00251661028181, 56.23619372504098, 58.2422011920384, 52.35119880948748, 54.505515575408936, 58.687931605747764, 55.78815998349871, 48.484797273363384, 43.362435885838096, 51.6619097164699, 59.393423897879465, 48.988840443747385, 40.35121168409075, 56.90282474245344, 55.80714593614851, 59.19251673562186, 52.279354436056956, 56.40521560396467, 54.993699482509065, 56.509400367736816, 55.806336471012656, 56.89379208428519, 57.82468046460833, 57.000919410160606, 56.632324423108784, 57.82455539703369, 49.7377416065761, 58.24986852918352, 59.98809937068394, 52.644312041146414, 44.839709758758545, 41.42516694750105, 43.68688896724156, 41.26329476492745, 47.29276084899902, 57.15726430075509, 59.965663637433735, 59.63005869729178, 49.03656414576939, 54.45784745897566, 61.3506897517613, 58.16792842320034, 52.537389687129426, 49.75558458055769, 48.30331727436611, 45.845089776175364, 52.20820835658482, 57.707961150578086, 61.42222840445382, 62.32262461526053, 62.10215827396938, 58.120229039873394, 59.02030563354492, 54.16305276325771, 57.38661043984549, 60.01862975529262, 62.574628829956055, 69.20198045458112, 60.09775584084647, 11.18281991141183, 6.747811675071716, 12.524073243141174, 7.608900189399719, 2.4940580555370877, 0.27666082020316807, 0.3380940780043602, 0.18169210904410907, 11.148093683379036, 47.22058643613543, 78.46743106842041, 84.08687005724225, 97.19243022373745, 48.00428070340838, 22.842463425227574, 40.92001206534249, 54.64178017207554, 61.660926818847656, 69.31346430097307, 37.414576394217356, 0.6364964629922594, 0.1832964779543025, 0.10100583399512938, 0.19587859351720127, 0.07363173644989729, 0.1540852061339787, 0.1266906846846853, 0.25742364674806595, 0.21257180348038673, 0.06401722771780831, 0.09801509590553385, 0.12806466381464685, 0.13388501506830963, 0.10973572305270604, 0.12902310809918813, 0.16886843501457147, 0.13959700427949429, 0.10354530558522258, 0.17539321418319428, 0.1830114253929683, 0.0896155923338873], [0.048444838861801794, 0.015489587227680852, 0.03014764336070844, 0.07441862672567368, 0.01961161113078041, 0.018518516660801003, 0.06217926634209497, 0.04017740195350988, 0.018044146043913703, 0.02196271122167153, 0.02143318927846849, 0.011866346783270794, 0.041447439696639776, 0.08935287036001682, 0.016911733862278715, 0.05175098716946585, 0.01854570216632315, 0.06265355553478003, 0.06569228640624455, 34.11142710277012, 72.9747758592878, 64.00606891087124, 56.17099182946341, 36.03496640069144, 21.384550707680837, 26.525663546153478, 39.999917711530415, 38.07917506354195, 34.59913158416748, 4.188453580651965, 0.14907735985304627, 0.09376955657665219, 0.20517380402556487, 0.9077850228973797, 0.39876479815159527, 2.1949433173452104, 1.5868939736059733, 16.36477599825178, 69.22679941994804, 60.797814641680034, 65.15558583395821, 59.25428622109549, 56.63396419797625, 48.920734201158794, 47.30046987533569, 48.289205483027864, 48.57969229561942, 45.20095355170113, 45.449362073625835, 43.43606942040579, 40.39257778440203, 41.93795095171247, 42.16985402788435, 39.865021909986226, 41.19087021691458, 40.89707258769444, 50.19575990949358, 54.180002893720356, 57.836718218667166, 55.38974680219378, 55.52090447289603, 54.757196698869976, 53.71177421297346, 48.438226972307476, 51.277247020176475, 51.54807390485491, 47.77853373118809, 37.427197796957834, 38.44730452128819, 39.19074787412371, 41.06217915671212, 44.56810120173863, 47.62497159412929, 42.39090401785714, 38.85185643604824, 37.407089710235596, 47.10510737555367, 52.25227035794939, 52.32340948922293, 48.43510375704084, 49.45041275024414, 51.055272919791086, 50.52734184265137, 41.261488233293804, 42.867168290274485, 47.39237717219761, 57.9821891784668, 41.6000565801348, 35.408169405800955, 56.84385190691267, 46.68518604551043, 53.39407825469971, 49.924161774771555, 53.78872551236834, 48.52700757980347, 49.69688272476196, 50.03522525514875, 52.50524384634835, 52.03763355527605, 52.39403097970145, 48.763913358960835, 53.81208535603115, 51.15745660236904, 50.12856388092041, 51.49068178449358, 49.89333956582205, 41.70234101159232, 41.73115866524832, 38.46408094678606, 39.445969104766846, 38.642858096531455, 47.93410389763968, 52.12711245673043, 56.16075365883963, 49.70067296709333, 50.5550651550293, 53.24565431049892, 52.348992756434846, 46.75342082977295, 41.65417957305908, 42.15503004619053, 42.13769776480538, 47.046686921800884, 53.53790596553257, 55.27143635068621, 64.49993991851807, 57.69276196616036, 58.03811175482613, 52.75816869735718, 53.770621980939595, 51.417392185756135, 54.87660843985421, 56.73692607879639, 61.054675647190635, 59.75123528071812, 39.00581462042672, 0.7996426086340631, 2.3515101160321916, 6.456490210124424, 1.9519910854952676, 0.48048058045761927, 0.018531432574880973, 0.026537843846849034, 1.18507139810494, 17.26844481059483, 28.289729527064733, 56.13784197398594, 58.95080280303955, 40.62765966142927, 31.280261993408203, 23.611455304282053, 35.60202762058803, 51.12913227081299, 50.872285161699565, 44.096033641270225, 3.253375219447272, 0.04719285015016794, 0.026348800597978488, 0.03283728492845382, 0.022862740426457355, 0.027698137032400285, 0.026607045937063437, 0.010815683652513793, 0.06417720591915504, 0.060737223364412785, 0.007912320517269629, 0.024717273323663642, 0.03853671106376818, 0.014305138195465718, 0.0412041916778045, 0.12294897117785045, 0.00753555037746472, 0.015194490651733108, 0.01761646711799715, 0.014651786469455277, 0.008867216063663363, 0.07338324335536786, 0.06141599587031773, 0.04998332541435957, 0.018881839932873845, 0.063313335845513, 0.046673496054219346, 0.03071300552359649, 0.02897725866309234, 0.05261492509660976, 0.005208573478739709, 0.025959121329443793, 0.055373346366520436, 0.04216038661875895, 0.0744881969211357, 0.04028956039941736, 0.05728574642645461, 0.05199018772691488, 0.09522447136363812, 0.031841331228081665, 43.05890383039202, 80.62429782322475, 69.65288380214146, 61.041349002293174, 44.14425413949149, 27.932001522609166, 33.837299823760986, 42.563511167253765, 34.58436666216169, 43.630222933632986, 5.688702540738242, 0.11718473477022988, 0.11971634892480713, 0.6659356004425457, 1.1193849742412567, 2.636783608368465, 1.8471188843250275, 0.2500789394336087, 18.89266266141619, 72.71539960588727, 63.83587278638567, 66.79448522840227, 59.95586667742048, 60.712588037763325, 51.44011279514858, 49.19954456601824, 49.81566217967442, 51.12178455080305, 47.94758687700544, 47.525869437626426, 45.155001640319824, 43.48012447357178, 42.699428353990825, 44.1713000025068, 40.60466807229178, 43.21191011156355, 42.53393268585205, 52.396080698285786, 56.422561781747, 59.32059982844761, 57.14335748127529, 56.654131344386506, 56.217020171029226, 53.94947903496878, 48.84555469240461, 53.63152599334717, 52.99705123901367, 49.29768787111555, 39.740371227264404, 41.32880238124302, 40.61207137789045, 43.74485778808594, 48.077271529606406, 49.58369656971523, 45.297575201307026, 41.20025723321097, 39.209087644304546, 48.576124395642964, 54.43624898365566, 54.02292149407523, 49.48554284232003, 52.207006318228586, 53.63355139323643, 53.41321359361921, 44.14540754045759, 45.18064396721976, 50.013678891318186, 59.4470431464059, 42.38121475492205, 37.56085334505354, 57.45246546609061, 50.49451855250767, 55.327866145542686, 52.59799534933907, 54.90973745073591, 49.653425216674805, 50.563611439296174, 49.77674879346575, 54.06085865838187, 54.283975737435476, 54.667981828962056, 50.53829567773001, 56.64284746987479, 52.160380431583945, 49.78004223959786, 54.45399815695626, 52.54518904004778, 43.89123201370239, 42.77852317265102, 39.741264070783345, 41.18848698479788, 39.990398679460796, 49.60366569246565, 54.422790322984966, 56.734883308410645, 50.988736970084055, 50.97032771791731, 56.82900708062308, 54.25046804973057, 49.781025409698486, 44.85005562646048, 45.69739191872733, 44.05710635866438, 49.51288052967617, 55.52749831335885, 57.61799240112305, 64.60842214311872, 60.02848924909319, 58.736777441842214, 54.347944327763145, 55.609407152448384, 52.83636719839913, 58.13062701906477, 59.333078793116975, 62.6278520311628, 60.55943584442139, 40.881831714085166, 1.69712638429233, 1.3560656969036375, 8.215416261128016, 4.253473086016519, 1.2796396378959929, 0.20711822754570416, 0.01591979878555451, 0.4830485369477953, 20.47239293370928, 35.76862457820347, 64.63194874354771, 72.8717062813895, 41.18863289696829, 39.98940508706229, 29.97824948174613, 42.35939393724714, 56.46055105754307, 56.179020472935264, 52.38018669400896, 4.444225456033434, 0.09779808005051953, 0.03923693884696279, 0.030152525420167615, 0.044287302132163725, 0.023879971288676773, 0.0046328500861168975, 0.06701582324291978, 0.026527540292590857, 0.05992146820894309, 0.020493671031934873, 0.03890628194702523, 0.02380314246485276, 0.027228187071159482, 0.037440218829682896, 0.09866278472223453, 0.02680425196220832, 0.03280038619413972, 0.02912408685577767, 0.03778495533125741, 0.019252460849072252, 0.14470060542225838, 0.1943330807345254, 0.11034096950399024, 0.15596439529742512, 0.09767242215041604, 0.08936288553689208, 0.13418111417974743, 0.12716335217867578, 0.12718882438327583, 0.16624387513313973, 0.12243741005659103, 0.0916311941774828, 0.08104956948331424, 0.20248934307268687, 0.13999993194426807, 0.19470765920622007, 0.12623024439173086, 0.1124658358416387, 0.1106010926887393, 51.498248372759136, 90.81933403015137, 78.59268624441964, 69.15938799721854, 49.12326724188668, 31.165272780827113, 37.01959562301636, 50.88515322549002, 49.88893093381609, 51.24788393293108, 7.182017632893153, 0.17290753684937954, 0.2486853099295071, 0.9939845374652317, 2.752911022731236, 5.150180237633841, 9.766220314162117, 4.328381615025656, 20.959284475871495, 73.55647904532296, 67.18196541922433, 70.60593346187046, 63.8449193409511, 61.99443340301514, 53.73360545294625, 52.06327588217599, 54.61193071092878, 53.78855528150286, 50.19106987544468, 50.0607008252825, 47.98990140642439, 45.849977833884104, 44.295485155923025, 46.35952745165144, 43.640384674072266, 45.08934811183384, 46.0575761113848, 55.32300935472761, 60.45842293330601, 61.483511516026084, 59.49524280003139, 57.60523203441075, 59.157991136823384, 56.64472000939505, 50.36022029604231, 53.856876918247764, 56.39319174630301, 51.13085889816284, 42.17406811032976, 43.87182222093855, 43.42516074861799, 44.533033643450054, 50.390410218920024, 52.47969879422869, 48.47717162540981, 42.01329026903425, 42.14961739948818, 51.2386463029044, 56.92584759848458, 55.84894282477242, 51.38054936272757, 56.23085403442383, 57.17949158804757, 55.86445467812674, 45.970383167266846, 46.771176951272146, 52.90173237664359, 62.87140028817313, 46.2931478364127, 41.59746142796108, 59.31870991843087, 52.08213676725115, 57.530514580862864, 53.94094317299979, 56.59460265295846, 51.59547798974173, 51.60970442635672, 50.861195836748394, 55.61507340839931, 55.252585887908936, 55.88579954419817, 53.681876114436555, 58.54229041508266, 53.68749720709664, 50.40734297888619, 57.21080017089844, 53.407008852277485, 46.283521107264924, 45.85994849886213, 42.31711414882115, 43.753935609545024, 42.583011286599294, 53.651898111615864, 57.942782470158164, 60.50148786817278, 52.10686888013567, 51.67765433447701, 59.59365708487374, 57.23214851106916, 53.44412612915039, 46.620286396571565, 47.01118162700108, 45.89951501573835, 51.804399899074006, 58.08633572714669, 59.65566975729806, 67.43451159340995, 59.89687647138323, 61.49963133675711, 55.095230034419465, 58.880917821611675, 54.39346892493111, 61.09660107748849, 59.66910062517439, 66.1109561920166, 62.84722750527518, 47.470474924360005, 1.10008504986763, 6.835340304034097, 14.375618781362261, 6.080957446779523, 2.1868999089513506, 0.1827594581991434, 0.16006875863032682, 1.4275311763797487, 27.62708330154419, 39.49243170874459, 60.678173610142295, 63.20127296447754, 48.46539095469883, 43.033303192683626, 33.38280078342983, 48.84401914051601, 64.97031906672886, 63.440499441964285, 61.55268778119768, 5.939885130950382, 0.32858671673706596, 0.13305816586528504, 0.14015930624944822, 0.06391644491148846, 0.13450358116200992, 0.08754239643790893, 0.1427384449967316, 0.2040429168513843, 0.1350578221359423, 0.11814467183181218, 0.14769115352204867, 0.14021847450307437, 0.10363211057015828, 0.10631269708807979, 0.22130347708506243, 0.1678034064493009, 0.09236242422567946, 0.0902299786518727, 0.25829968973994255, 0.11791464846049036], [0.05387588743386524, 0.049529080146125386, 0.014894980205489057, 0.06804609724453517, 0.037176757252642086, 0.05032024519251926, 0.021752468842480863, 0.0579721795927201, 0.06743729526975326, 0.049437352389629395, 0.026957634803173796, 0.08744595625570842, 0.004657127220915365, 0.05794141481497458, 0.033780034698013744, 0.00579704951295363, 0.0566717706221555, 0.08114144312483923, 2.206567870719092, 51.18303639548165, 61.65099089486258, 59.43043695177351, 52.525192124503, 36.432698658534456, 29.185776165553502, 27.165922675813945, 34.06330735342843, 44.97216326849801, 21.4541369165693, 0.5023572008524622, 0.052625540776976516, 0.06499209933515106, 0.18775116891733237, 1.724480356488909, 1.777464604803494, 1.0684800829206194, 1.112309753894806, 55.867768968854634, 63.218824114118306, 60.57502065386091, 56.68992498942784, 54.46640069144112, 50.531284945351736, 48.11720282690865, 49.75887107849121, 51.40207140786307, 50.1670742716108, 50.1794490133013, 49.41015836170742, 46.58096654074532, 42.763897214617046, 40.77316883632115, 40.66593381336757, 40.38321508680071, 41.368775367736816, 40.73781292779105, 49.496454988207134, 53.51850312096732, 57.12246077401297, 54.0383152280535, 50.292558738163535, 51.20029919488089, 53.613780294145855, 51.76947130475725, 51.919528075626914, 51.952646664210725, 44.57420172010149, 38.66485609327044, 37.82977989741734, 39.29830946241106, 38.721202509743826, 38.29288080760411, 40.30439124788557, 38.20980814525059, 37.822050026484895, 37.2180882862636, 46.495868478502544, 52.58614867074149, 52.521311555589946, 48.32709400994437, 50.216858114515034, 51.81314073290144, 48.16939074652535, 38.21148613521031, 41.85974202837263, 49.20187221254621, 56.27157047816685, 38.842848096575054, 37.05120645250593, 57.336743218558176, 46.99400915418352, 49.604958057403564, 48.344996043613975, 55.69079835074288, 51.2590913772583, 49.82612269265311, 43.0467722756522, 47.44536066055298, 53.29122059685843, 50.0829941204616, 46.83143172945295, 50.47992386136736, 52.52479607718331, 49.491302898951936, 50.17912244796753, 51.93073899405343, 44.014982904706685, 41.10387529645647, 38.91261495862688, 39.726599897657124, 37.972614015851704, 41.854308537074495, 48.547397068568635, 54.34764208112444, 52.259406157902305, 48.96787772859846, 52.90255226407732, 53.23998458044869, 48.45676129204886, 42.35215738841465, 41.904721191951204, 42.94479703903198, 45.71359164374215, 55.81439985547747, 53.38490663255964, 57.662280218941824, 57.2634779385158, 54.89264488220215, 58.22505303791591, 55.50303718021938, 56.280047280447825, 56.714636257716585, 59.09345626831055, 57.521228313446045, 51.065431186131065, 51.40115424564907, 19.877701827457972, 0.05530301281916244, 3.075814655848912, 4.140523603984287, 1.2072182382856096, 0.20866398460098676, 0.07919448188373021, 0.026679408304127197, 5.81936992917742, 24.32161852291652, 26.500457218715123, 26.04242328235081, 45.86408267702375, 17.44226094654628, 16.47812717301505, 31.142972537449428, 45.13528265271868, 46.359266894204275, 53.18796689169747, 17.67101648875645, 0.10859284616474595, 0.038891717192849944, 0.037977289474968395, 0.043183837950761826, 0.055471710195498805, 0.07715220004320145, 0.019250637286209633, 0.05843290487038238, 0.02666243475063571, 0.036125031366412125, 0.03945398523605295, 0.031039638710873466, 0.06027405536068337, 0.011057083511592021, 0.051926266335483105, 0.03555874639589872, 0.04871474991419485, 0.04541903408244252, 0.03151836212990539, 0.06800849283380167, 0.026885613399956907, 0.03496351512148976, 0.027344876434653997, 0.08798787503370217, 0.008650583580934575, 0.024174597979124104, 0.0063945314032025635, 0.05167722023491349, 0.061611949998353205, 0.05177120412034648, 0.02876398492870586, 0.04252560809254646, 0.04107244053323354, 0.007801275716961494, 0.052147221086280685, 0.049873633443244865, 0.02723469422198832, 0.07858935756874935, 3.0556045174598694, 63.1554148537772, 69.25858048030308, 67.4639094216483, 57.09452901567732, 41.49225180489676, 29.872869627816335, 25.185533217021398, 34.08844941002982, 44.09224339893886, 23.250268833977835, 0.5642881233777318, 0.0289472063471164, 0.5655660490904535, 1.201604636652129, 1.9150978880269187, 3.332964228732245, 1.6153707312686103, 1.8574061266013553, 58.26001289912632, 66.849118913923, 62.666914803641184, 59.26889133453369, 58.2540339742388, 54.08092853001186, 50.48388433456421, 51.96627902984619, 53.701237269810264, 51.8978670665196, 53.17310469491141, 50.205761841365266, 47.61647047315325, 44.51326949255807, 42.895464829036165, 42.26782362801688, 43.03706911631993, 42.73919289452689, 42.33963673455374, 50.75633709771292, 55.09117923464094, 57.827970436641145, 54.863733427865164, 53.070663928985596, 54.54460266658238, 56.17387185777937, 52.56607532501221, 55.4455304145813, 53.53686373574393, 46.51840148653303, 39.712227548871724, 40.16610125132969, 40.48784106118338, 41.15810946055821, 40.693914209093364, 42.11026280266898, 39.43053020749773, 39.9734867640904, 39.03591421672276, 47.492375646318706, 54.150500842503135, 53.235589844839915, 50.158948353358674, 51.81548227582659, 54.057770184108186, 49.997684138161794, 40.25000422341483, 44.15967914036342, 51.37387909208025, 58.48487745012556, 42.108966963631765, 40.1621025630406, 59.63454723358154, 49.773410184042795, 52.88739129475185, 49.73375334058489, 56.51331220354353, 52.260024547576904, 51.109072821480886, 44.85583652768816, 49.95315660749163, 53.36048024041312, 53.117665018354145, 48.509991441454204, 52.05593163626534, 53.12909133093697, 49.06916856765747, 51.2758469581604, 53.98458480834961, 46.42348909378052, 42.37923451832363, 40.3609356880188, 41.76504155567714, 40.46587780543736, 43.07666342599051, 51.65809515544346, 55.86497926712036, 54.13318593161446, 51.09451634543282, 54.56980378287179, 54.8168990952628, 51.298994881766184, 44.3744410106114, 42.21521534238543, 44.71559408732823, 48.61435685838972, 57.48943683079311, 57.33527020045689, 59.81752804347447, 58.052306924547466, 58.38344764709473, 60.22436591557094, 56.30045413970947, 58.57981068747384, 58.211146218436106, 61.02855042048863, 60.42208385467529, 56.06106090545654, 55.691190923963276, 22.88139418193272, 0.1848445013165474, 0.5020133735878127, 1.4684606258358275, 3.4617091374737874, 1.2376664387328284, 0.1178288816341332, 0.11245879943349532, 4.869058293955667, 33.80890948431832, 25.788407564163208, 28.385001489094325, 41.84263208934239, 19.914124284471782, 25.76804413114275, 35.37113898141043, 51.29224470683506, 50.98013162612915, 63.12176472800118, 22.809999704360962, 0.1710790613932269, 0.05962490090834243, 0.0557410546711513, 0.06245182707373585, 0.034040470008871386, 0.08399283726300512, 0.012875102743107294, 0.026820301011736904, 0.01578427159360477, 0.045628586052251716, 0.01463488076946565, 0.07803029899618455, 0.006166927433306617, 0.015973562507757118, 0.053529807432953797, 0.023642858922747628, 0.047098886620785506, 0.03820226454575147, 0.032381499385727305, 0.031632800453475544, 0.09313093977315084, 0.15632279749427522, 0.12412829218166214, 0.2023915797472, 0.11832596281809465, 0.12693776642637594, 0.1141984478703567, 0.18870693977390016, 0.1381917582558734, 0.14240588141339167, 0.10904917453548738, 0.14671904354223184, 0.08867016235100371, 0.12148139492741653, 0.12095339968800545, 0.12916427052446774, 0.19857152258711203, 0.2394622548350266, 3.823757835796901, 74.13521535055978, 78.2868265424456, 77.60176195417131, 67.41204806736538, 49.54355682645525, 39.749469893319265, 36.49133103234427, 47.45965657915388, 62.65155233655657, 33.59686088562012, 1.09609135559627, 0.2420556971005031, 0.6149746349879673, 2.2825885457651953, 5.254949952874865, 9.837626082556588, 7.276767177241189, 1.7164594211748667, 62.21544170379639, 68.05187293461391, 67.22363376617432, 60.49292073931013, 60.47864219120571, 55.900724274771555, 53.52776854378836, 54.38896649224417, 57.00506053652082, 55.524830205099924, 54.57485859734671, 53.21278585706438, 50.517975670950754, 47.53110490526472, 44.7753381729126, 44.40178564616612, 46.214209352220806, 46.01335777555193, 46.61847986493792, 54.509364877428325, 59.117635999407085, 61.109156472342356, 57.85868494851248, 53.89776359285627, 55.404734066554475, 57.46239096777779, 52.60521452767508, 57.063640798841206, 57.11669724328177, 48.373910972050254, 42.52734579358782, 41.37150600978306, 43.801805223737446, 44.20166015625, 43.463452271052766, 44.80376672744751, 42.102887289864675, 42.007505893707275, 41.724592617579866, 49.93900312696184, 57.00669683728899, 56.495695046016145, 51.606046199798584, 55.48881074360439, 56.669215883527485, 53.12713541303362, 42.26126800264631, 46.922091824667795, 54.70494624546596, 62.0355806350708, 45.11396557944161, 42.47240291322981, 62.05844020843506, 52.06365803309849, 55.32719217027937, 52.66757113592965, 59.84985106331961, 55.62821592603411, 52.107765197753906, 45.295490741729736, 50.30397115434919, 55.71993562153408, 53.72692128590175, 51.18324136734009, 56.3396315574646, 55.01254994528634, 50.274576800210134, 52.93337447302682, 56.87868670054844, 48.668368680136545, 44.42240789958409, 42.29385157993862, 44.28381218229021, 42.07015085220337, 46.236641611371724, 53.28512355259487, 59.2894788469587, 56.721532344818115, 51.869285651615684, 55.39593069893973, 57.34007140568325, 54.330375807625906, 46.623023986816406, 44.8859361239842, 47.28469399043492, 50.201492173331125, 59.67000389099121, 59.43503665924072, 60.68511486053467, 59.970311982291086, 58.85702991485596, 62.77547345842634, 57.58087165015084, 60.84078924996512, 60.04430334908621, 63.2746250970023, 62.382080350603374, 56.73437261581421, 56.65354074750628, 26.68136920247759, 0.37586052290030886, 7.237810799053737, 12.39888494355338, 4.8835261804716925, 0.9039180789675031, 0.3199601482067789, 0.13696618830519064, 8.501769764082772, 39.2874424798148, 36.317549637385774, 33.889796938214985, 58.10346303667341, 24.279151133128575, 26.726028748920985, 44.0862193107605, 59.689882687159944, 58.651265961783274, 68.43785926273891, 25.951306343078613, 0.19920680778367178, 0.1400083593491997, 0.2091980188020638, 0.13114975898393563, 0.13160701016230242, 0.2447625904210976, 0.08466299237417323, 0.12838730721601418, 0.15037367386477335, 0.09519822562911681, 0.2040343265980482, 0.1895201097109488, 0.1255544913666589, 0.11515573864536625, 0.184254311557327, 0.10720100799309355, 0.11623736417719296, 0.11219923264746155, 0.12201855038957936, 0.15578665983464035], [0.013088984614504235, 0.06589726505002805, 0.03927899784009371, 0.02305234346671828, 0.049117606332791705, 0.0830807572762881, 0.03660652320832014, 0.02839807983088706, 0.04622445854225329, 0.0386071362133537, 0.05803165318710463, 0.03976554816056575, 0.0795826039143971, 0.005056174089466887, 0.042658695951104164, 0.026880208868533373, 0.10096620755004031, 0.15340528690389224, 16.04996006829398, 68.54349967411586, 59.1633551461356, 61.54124409811837, 46.18552024023873, 31.670066356658936, 23.44771405628749, 45.50532981327602, 34.8997141293117, 36.73515026909964, 5.216067399297442, 0.1108451278081962, 0.05761828965374401, 0.3955216450350625, 0.53085436884846, 1.412720222558294, 1.2195587818111693, 1.3870573767593928, 25.76959010532924, 72.01285334995815, 58.228072030203684, 61.814113753182546, 55.14849492481777, 53.0718138558524, 49.22159467424665, 49.819594860076904, 48.29010527474539, 53.91376529421125, 50.742732524871826, 49.220437799181255, 48.53090899331229, 46.66222224916731, 43.086495126996724, 40.79007032939366, 41.16209772654942, 44.301863602229524, 42.46436384746006, 41.599712644304546, 44.9637177331107, 50.93299157278878, 48.64136798041207, 49.617614201136995, 49.53365911756243, 51.06871420996529, 52.54037046432495, 52.70670339039394, 51.55105120795113, 50.95507294791085, 46.50901794433594, 41.15768562044416, 41.75429269245693, 38.00777537482125, 38.92118556158883, 37.26478018079485, 39.121422222682405, 38.48226090839931, 38.307638781411306, 37.228837149483816, 46.07300806045532, 50.1232693535941, 53.77156693594796, 45.97258227212088, 50.47299998147147, 50.965318066733225, 46.33800540651594, 37.22190632138933, 43.82510600771223, 48.702849115644185, 58.10852827344622, 40.64906358718872, 39.18904556546892, 55.61133180345808, 44.3346243585859, 50.95460394450596, 44.62984636851719, 52.220270429338726, 50.43153313228062, 53.66525949750628, 49.53004605429513, 48.76682812826974, 50.613958086286274, 47.676527227674214, 44.35897084644863, 48.081773962293354, 51.918562276022776, 50.044105052948, 48.192754064287456, 52.92138188225882, 47.03233541761126, 39.822769914354595, 38.786039624895366, 38.48724971498762, 38.515303066798616, 40.67673478807722, 45.20801986966814, 50.349196978977744, 54.33924518312727, 51.18232420512608, 52.706911836351665, 52.74949039731707, 48.63316215787615, 42.51002393450056, 40.66304683685303, 40.2909951210022, 47.41809592928205, 56.77018015725272, 53.58936085019793, 53.974117347172324, 52.58845547267369, 52.1501214163644, 57.54334095546177, 56.07187230246407, 56.45519052233015, 56.91561985015869, 60.45241968972342, 52.70079047339303, 58.27019895826067, 48.297928946358816, 49.942296573093955, 13.39310267993382, 0.20926523448101111, 2.714022606611252, 1.4636914474623544, 0.9248380192688533, 0.11919029429554939, 0.10362759152693407, 0.6906560968075479, 15.44174429348537, 33.71043961388724, 36.47629165649414, 60.50233554840088, 35.289619241442, 12.608984572546822, 28.164868661335536, 39.75071014676775, 47.576007638658794, 49.00484561920166, 35.99882187162127, 0.5563401984316962, 0.061655932638261995, 0.035815836529114416, 0.010302237052071308, 0.01387481892015785, 0.01458230787622077, 0.03620404337665864, 0.045993617536234, 0.023022525245323777, 0.06629297988755362, 0.05412145943513938, 0.0824045224913529, 0.023048228151830177, 0.04590683290734887, 0.03735321028424161, 0.010954615393919604, 0.047291125769593885, 0.027133153152785132, 0.019977969150724154, 0.03870179184845515, 0.026937750334452306, 0.11724721427474703, 0.05304377958444612, 0.01967470979850207, 0.028470725486321107, 0.08453200118882315, 0.025241368683055043, 0.06764456736189978, 0.09677062196923153, 0.05494107206219009, 0.09030775912106037, 0.05918235358382974, 0.05450609040313533, 0.023195215800244893, 0.18225328464593205, 0.10480792354792356, 0.1046783301447119, 0.12585430884999887, 20.434698956353323, 79.195296560015, 65.3267686026437, 67.80778271811349, 56.154093810490195, 46.36905690601894, 33.84627342224121, 35.422180448259624, 33.71572719301496, 42.2558970451355, 6.500735470226832, 0.1843020532812391, 0.030307034629264047, 0.6351683256881577, 1.5565914681979587, 3.9402161581175665, 0.399442763200828, 0.6413524938481194, 27.998332500457764, 75.68817247663225, 62.35609408787319, 63.05577768598284, 57.27384465081351, 55.342839513506206, 50.06806591578892, 53.85112033571516, 52.205984933035715, 56.8680351121085, 53.17431368146624, 51.22101872307913, 51.62702281134469, 50.2386337688991, 44.97503982271467, 43.49043560028076, 43.86919927597046, 44.444082805088584, 45.92778723580496, 42.49710028512137, 47.18584891727993, 52.30440616607666, 51.41781949996948, 51.36540576389858, 51.16429015568325, 52.852261202675955, 55.146827357155935, 53.4767027582441, 53.06078706468855, 52.653101512363975, 47.75136974879673, 44.069675649915425, 43.2911890574864, 39.607712745666504, 41.01012672696795, 40.26382419041225, 42.06609310422625, 41.32887881142752, 39.17840092522757, 39.7624317577907, 48.21556847436087, 52.916285378592356, 53.77072272981916, 49.24562849317278, 52.66726541519165, 51.73821830749512, 48.69367749350411, 39.44833149228777, 45.21376950400216, 51.4902058328901, 57.4735324042184, 40.50041382653372, 40.91474185671125, 58.09196029390608, 46.196279525756836, 51.73598793574742, 45.53095129558018, 53.15541458129883, 52.800750732421875, 54.00075674057007, 50.52802971431187, 50.92730794634138, 51.96566758837019, 50.31369515827724, 47.200467927115305, 48.96848569597517, 53.306496211460654, 49.74605860028948, 50.17314352308001, 55.758067335401265, 48.57336596080235, 41.48104783466884, 40.260020051683696, 40.7058025768825, 40.64717715127127, 43.70379393441336, 46.73580019814627, 52.89629888534546, 56.60093593597412, 51.74442652293614, 54.71347515923636, 55.09494168417794, 50.46671880994524, 44.18172230039324, 41.73891632897513, 42.988720076424734, 48.82992124557495, 58.84582941872733, 56.85876274108887, 55.847876276288716, 52.738915239061626, 53.57645109721592, 57.67312635694231, 59.418986320495605, 57.618391922542024, 59.79602336883545, 61.48823629106794, 55.56073154721941, 58.23855686187744, 53.648774896349224, 56.1059775352478, 17.34649392536708, 0.32654533056276186, 0.8204818846923965, 0.9400734645979745, 3.656462584223066, 0.3639883313860212, 0.06825786802385535, 0.16817729281527655, 17.935477086475917, 37.89236927032471, 29.33597537449428, 55.19113254547119, 33.70373807634626, 17.721377032143728, 34.380013193402974, 47.028656346457346, 52.621511527470176, 55.9507235118321, 42.33991118839809, 0.8759729670626777, 0.02939178588400994, 0.038505271143679104, 0.031087156518229415, 0.02003825698713107, 0.038684607949107885, 0.008900596593905772, 0.007177137154420572, 0.04741381847166589, 0.03798931650817394, 0.07066938826548201, 0.035586311881031306, 0.03921442844771913, 0.020770805089601448, 0.01803938272808279, 0.01010223715898714, 0.029026771363403116, 0.014534773105489356, 0.027259036665782332, 0.034722957494003434, 0.08085737443928208, 0.16531075377549442, 0.0943006459357483, 0.08392857999673911, 0.1576646819178547, 0.22106164720441612, 0.1121376555945192, 0.0885349710338882, 0.14174709176378592, 0.15757054196936743, 0.1761519791824477, 0.13103016040154866, 0.1454681506646531, 0.11642572549836976, 0.24907766601869039, 0.2047135265810149, 0.218675361680133, 0.29953013733029366, 24.686558757509502, 90.68925680433, 73.4453912462507, 80.45139190128872, 60.745842116219656, 46.794165066310335, 32.91255712509155, 64.79967825753349, 49.023227078574045, 53.140413420540945, 9.062509366444178, 0.3401348942092487, 0.2270562055387667, 1.6261984131165912, 3.4358998366764615, 3.8766062685421536, 9.294776354517255, 3.76765547479902, 31.191026278904506, 78.76094382149833, 64.4728558404105, 65.8016779763358, 60.2938756942749, 58.644637380327495, 52.8290125301906, 55.19557591847011, 54.63628762108939, 59.99317850385393, 57.40154559271676, 54.65376581464495, 52.567402430943076, 52.32845040730068, 47.9779817717416, 45.11833599635533, 46.18010411943708, 48.31503193719046, 48.03287254061018, 43.38740076337542, 49.583905015672954, 55.099767208099365, 53.26846524647304, 52.987577370234895, 55.56054741995675, 54.49620846339634, 57.75831127166748, 54.764930043901714, 54.88144786017281, 55.60257707323347, 51.182980809892925, 46.8190187726702, 46.118560450417654, 41.22800139018467, 43.56942272186279, 41.129722595214844, 43.87668595995222, 42.869673115866526, 41.374184540339876, 41.98324278422764, 51.31238406045096, 56.129073347364155, 57.349131856645855, 51.23991782324654, 55.44113915307181, 54.43699938910348, 51.4782132421221, 42.81745045525687, 47.615077359335764, 53.75399841581072, 62.184063638959614, 44.14940275464739, 44.295613697596956, 61.05266761779785, 49.653272356305806, 54.44433668681553, 48.34826864515032, 56.051569666181294, 54.79271241596767, 56.83365542548043, 53.267874649592805, 51.1589469909668, 54.72031913484846, 52.88623441968645, 49.54934467588152, 50.968191146850586, 56.210005964551655, 51.40782799039568, 51.10297577721732, 58.46971648080008, 51.34522819519043, 43.94743251800537, 42.91055631637573, 42.10247734614781, 43.41246638979231, 46.02370016915457, 50.40132236480713, 55.51423420224871, 59.993282726832796, 52.47426530293056, 56.44505310058594, 57.489732129233225, 52.71277959006173, 46.83866480418614, 44.19573334285191, 44.60376283100673, 51.43561383656093, 60.18584510258266, 58.855932099478586, 59.78844288417271, 54.08665384565081, 54.98262752805437, 60.527592250279014, 61.04971463339669, 60.81078692844936, 60.910243443080354, 63.14714649745396, 56.008212906973704, 61.33469499860491, 53.353129046303884, 56.11372825077602, 17.90913299151829, 1.0762829099382674, 8.329686335154943, 6.212584555149078, 2.942357999937875, 0.3501904032060078, 0.23513637695993694, 0.8991476520895958, 23.395180463790894, 48.7883050101144, 49.471538748059956, 68.35587051936558, 44.98118550436837, 19.509535891669138, 40.52769592830113, 54.06810562951224, 60.751560483660015, 61.993412017822266, 50.558733803885325, 1.4010351981435503, 0.23529363423585892, 0.11941935414714472, 0.07261835118489605, 0.1597117813570159, 0.16555935543562683, 0.05246576274346028, 0.09771438275596925, 0.10349074458437306, 0.10674411643828664, 0.16793426871299744, 0.13841081650129386, 0.07805826142430305, 0.10398454165884427, 0.11168239930910723, 0.08897340643618788, 0.09221763842340026, 0.12256144625799996, 0.13438810807253632, 0.12248211194361959], [0.018529383399124657, 0.01014712733948337, 0.03395904241395848, 0.018127695757097433, 0.04858278503109302, 0.018969964668420807, 0.0689941735139915, 0.07471789459564857, 0.03976350237748452, 0.01724945940077305, 0.06265337233032499, 0.08527771117431776, 0.06189474303807531, 0.1036294371421848, 0.08832919850413289, 0.08168843055942229, 0.07429377628224236, 0.1578153031212943, 35.21461343765259, 65.89895275660923, 59.406986781529014, 53.458349091666086, 36.93845803397042, 18.38101121357509, 24.639620201928274, 37.07483727591378, 34.834738050188335, 24.738107442855835, 0.6435891081179891, 0.15228491702250072, 0.031126355486256734, 0.3839167148939201, 0.7747021583574158, 1.9973619537694114, 0.995866847889764, 2.168039241007396, 62.28193596431187, 59.87640707833426, 60.75083787100655, 54.61453628540039, 54.51835584640503, 51.4058130128043, 54.30098492758614, 51.92034101486206, 52.90506056376866, 49.61831596919468, 49.260167598724365, 49.77250691822597, 51.80300331115723, 47.72500480924334, 44.466758251190186, 40.490700244903564, 42.92823600769043, 46.504393918173655, 45.78498438426426, 42.43309695380074, 41.39349011012486, 44.055793149130686, 46.60410056795393, 44.25934757505144, 45.9424409866333, 49.256769929613384, 54.65660762786865, 53.84133727209908, 52.32090466363089, 51.58129324231829, 49.70585979734148, 44.62788002831595, 44.589723995753694, 41.43268142427717, 38.47216517584664, 37.550441469464985, 38.54704591206142, 37.62717737470354, 37.562197821480886, 38.37776000159127, 44.753486088344026, 49.11359534944807, 49.170640059879844, 47.89651761736189, 51.15925965990339, 47.765151500701904, 45.533390113285606, 35.88414880207607, 45.19895941870553, 46.055971077510286, 55.30409288406372, 38.795162609645296, 37.588993549346924, 57.23695319039481, 46.41903182438442, 49.00186136790684, 40.06255224772862, 44.762497901916504, 47.745943205697195, 49.82068225315639, 50.17505080359322, 50.72378478731428, 48.86778892789568, 50.36779383250645, 43.16841091428484, 46.49614640644619, 51.00767775944301, 49.64375332423619, 48.23474202837263, 51.80413934162685, 47.06011084147862, 38.56216866629464, 38.36364473615374, 38.73317078181675, 38.509299823216026, 40.620899064200266, 44.165268966129844, 48.34155321121216, 50.28515543256487, 51.51475381851196, 51.21742303030831, 53.80716255732945, 49.63635001863752, 42.08458226067679, 39.17536456244332, 40.27604954583304, 44.00765602929251, 56.502160344805034, 52.59112705503191, 48.3896347454616, 54.25595017841884, 52.04080540793282, 52.82316214697701, 57.48041806902204, 55.02301740646362, 55.930848189762656, 50.30249466214861, 56.83874150684902, 57.08507946559361, 61.460533823285786, 58.024746894836426, 62.26196684156145, 8.656023246901375, 0.3112721044038023, 3.3786590567656924, 2.185409737484796, 0.04875481740704604, 0.07643204368650913, 0.016664138130311455, 4.965761584894998, 27.16946452004569, 34.21899216515677, 30.60437944957188, 21.411838020597184, 20.531146900994436, 20.871394974844797, 34.06252915518624, 46.2257398877825, 49.48629672186715, 42.03659800120762, 4.0953941856111795, 0.20023121924272605, 0.030570116226694415, 0.026432479232815758, 0.029925511351653507, 0.041874513030052185, 0.006716895757043468, 0.017968014414821352, 0.028286335291340947, 0.02044547808223537, 0.02708569641358086, 0.011453710130548902, 0.02820931138869907, 0.0420580974646977, 0.05796235440565007, 0.017007615949426378, 0.024636620955009545, 0.014774373998599393, 0.02614209338623498, 0.042312225792557, 0.0042038378388887, 0.015403399709612131, 0.016777495886864405, 0.015198358301339405, 0.03793574616845165, 0.06914771241801125, 0.047839670442044735, 0.0154476690305663, 0.056007342346544774, 0.023455749498680234, 0.019822759354220967, 0.029582220129668713, 0.013744840448323106, 0.060787713155150414, 0.058511282450386455, 0.021634003413575034, 0.05369100021198392, 0.18474063117589268, 42.36181191035679, 74.96371160234723, 65.25119304656982, 60.80444322313581, 43.10205561774117, 26.066111428397043, 24.035347529820033, 35.96839918409075, 34.67632607051304, 30.91108683177403, 1.0277044709239687, 0.13321357752595628, 0.053322230000048876, 1.653995115842138, 2.6866490926061357, 4.362367859908512, 0.9208343369620187, 3.203205100127629, 65.89178916386196, 62.18360505785261, 62.86206190926688, 57.96553087234497, 55.992030552455354, 54.29204954419817, 56.93488025665283, 55.18043579374041, 55.49415043422154, 52.39780037743704, 51.05117000852312, 50.81180804116385, 55.262643405369346, 50.69491154806954, 46.69852311270577, 41.28783927645002, 45.12010778699602, 48.53283017022269, 48.3538167817252, 44.97195829663958, 43.21769448689052, 45.9551214490618, 47.497732707432334, 44.84376403263637, 47.02671085085188, 51.8555907521929, 56.18293925694057, 55.11865588596889, 54.5956198147365, 54.464774812970845, 51.786126136779785, 47.3659462247576, 46.48884384972708, 44.04958840778896, 40.208012785230366, 39.326258591243196, 40.69190617970058, 40.316213607788086, 39.589449405670166, 40.501789569854736, 47.24584313801357, 51.43064587456839, 50.891340596335276, 49.738148076193674, 53.36898136138916, 50.19213989802769, 45.76770074026925, 38.42464297158377, 46.563484873090474, 49.74994264330183, 57.93647697993687, 41.10606745311192, 40.79138353892735, 59.16933059692383, 48.09531600134713, 50.76003701346261, 42.98967892783028, 46.92047984259469, 48.521817275456016, 52.54189559391567, 52.42013188770839, 51.54757710865566, 51.974446637289866, 52.10997472490583, 43.703265871320454, 48.463584423065186, 52.31309488841465, 51.332547732761924, 48.69380603517805, 54.041278634752544, 49.53402737208775, 39.92862919398716, 40.49930558885847, 40.72721345084054, 39.87574645451137, 43.56354801995413, 46.61401217324393, 51.159415994371685, 52.90752717426845, 51.82180166244507, 51.17523009436471, 56.73767301014492, 51.56772688456944, 45.35519313812256, 41.49907841001238, 42.09960426603045, 46.152724742889404, 58.492180006844656, 54.98209946496146, 51.914935316358296, 54.761070319584434, 53.9134977885655, 55.75710848399571, 57.80175835745675, 56.15237065723964, 54.37167937414986, 53.757562841687886, 59.54079518999372, 58.59668786185128, 62.85471766335623, 60.47358390263149, 64.09235858917236, 12.054526141711644, 0.5140794089862278, 1.756009110382625, 2.715344718524388, 1.5953402689525058, 0.22278033569455147, 0.14015785418450832, 3.663792065211705, 34.458083152770996, 33.906628949301584, 32.26363706588745, 17.365167209080287, 24.85112336703709, 29.239628178732737, 38.47199147088187, 51.18055241448538, 52.9849613734654, 52.83534928730556, 5.408517735345023, 0.15750380126493319, 0.018097144717882787, 0.05167399040822472, 0.07562356242643935, 0.015895083147500242, 0.08469987075243678, 0.04377199210492628, 0.023228911849270974, 0.01801283165280308, 0.01636266502152596, 0.02661848603747785, 0.04396371556712048, 0.028068934367703538, 0.02574969149593796, 0.013557993956575436, 0.03979281848296523, 0.0499371205722647, 0.07115635249231543, 0.022710779116355946, 0.12424201465078763, 0.1394443339002984, 0.12466916601572718, 0.08466515011553254, 0.14889051845031126, 0.0986202270058649, 0.1949324578578983, 0.14595271966287068, 0.09770801809749433, 0.10247824141489607, 0.14253439594592365, 0.1459452286362648, 0.15235859235482557, 0.19085543948624814, 0.10468994666423116, 0.18938934244215488, 0.3314640851957457, 0.43565617714609417, 49.91990947723389, 83.42071151733398, 71.23485660552979, 68.90291609082902, 49.89286361421858, 25.560452801840647, 35.11531325748989, 51.562373297555105, 47.501825196402415, 39.41406645093645, 1.3429198137351444, 0.40325181452291353, 0.17586064338684082, 3.37489487017904, 3.2173614033630917, 8.819835713931493, 6.949036283152444, 2.857598228113992, 71.34650026048932, 62.604033606392996, 69.06784548078264, 60.10268211364746, 59.39729404449463, 56.38211979184832, 61.025416782924104, 58.62220859527588, 58.528519085475374, 53.92911386489868, 55.2689072063991, 54.43195847102574, 57.93586206436157, 51.704172134399414, 48.9708446093968, 44.65613835198538, 46.90898404802595, 51.2999050957816, 50.96310159138271, 47.825093609946116, 45.568478516169954, 47.38686030251639, 50.30372796739851, 47.742684500558035, 49.988568101610454, 53.09616034371512, 59.333370617457796, 56.792473452431814, 56.95324087142944, 58.047092301504954, 55.543711934770855, 49.145748138427734, 50.18284320831299, 46.4846818787711, 42.06878205708095, 41.15453461238316, 43.06036295209612, 42.22836480821882, 41.64914212908064, 43.38229383741106, 48.86936616897583, 53.02961049761091, 52.34166240692139, 52.76876470020839, 55.21451670782906, 51.739125047411235, 48.8666980607169, 41.20572893960135, 48.57136835370745, 51.56831748144967, 58.46242782047817, 43.315340995788574, 43.987165791647776, 62.30913816179548, 51.88607944761004, 53.89684295654297, 43.94453164509365, 49.11816726412092, 50.84411021641323, 55.887877055576865, 54.638875825064524, 54.57169369288853, 53.26943104607718, 55.67883702686855, 47.10191815240042, 51.146047660282676, 55.782445090157644, 52.46042101723807, 49.98516695840018, 57.91037607192993, 52.07151991980416, 42.53628812517439, 42.19244956970215, 44.351223605019705, 42.73116772515433, 44.99694749287197, 49.089735235486714, 51.83443348748343, 54.535861832754954, 53.2310665675572, 53.57726403645107, 59.23327486855643, 53.84794848305838, 47.135922636304585, 42.74714510781424, 43.65781423023769, 49.154631410326274, 61.00630923679897, 56.92797722135271, 54.926642417907715, 57.05114793777466, 55.124805041721885, 57.509444168635774, 60.95940889630999, 56.590305192129954, 57.049695764269146, 56.42233943939209, 62.19340896606445, 60.8525664465768, 68.31802368164062, 61.74745273590088, 66.7186039515904, 11.665816988263812, 0.9846544095448085, 10.91636518069676, 8.952478562082563, 0.8032616430095264, 0.16168794674532755, 0.19043172150850296, 7.319744825363159, 40.48454066685268, 48.275719029562815, 41.59036731719971, 28.224694388253347, 30.08858687537057, 30.58133922304426, 46.131828035627095, 59.288985524858745, 59.57362542833601, 60.93481227329799, 7.570066707474845, 0.390162711164781, 0.11321238721055643, 0.13094150301601204, 0.17470935944999966, 0.08352337245430265, 0.1559984441846609, 0.12426498984651906, 0.143014771597726, 0.11894409464938299, 0.11286906206182071, 0.09811629261821508, 0.06849678698927164, 0.12630417756736279, 0.14268048453543866, 0.09382702849273171, 0.12605750294668333, 0.1475145308566945, 0.09352100241397109, 0.1967048863215106], [0.020043566523651992, 0.037435594613530805, 0.04065553504707558, 0.03996873547190002, 0.051535688008048704, 0.058902661449142864, 0.017010945860030394, 0.07533087634614535, 0.047559038536357026, 0.028687975435916866, 0.05516443221962877, 0.06984650170696632, 0.030330796925617114, 0.0665642378319587, 0.026303749265415326, 0.06181252494986568, 0.14335759463054792, 3.9653595175061906, 54.2862616947719, 59.471208981105256, 57.72848960331508, 51.72654185976301, 44.08032029015677, 20.877285310200282, 36.618128708430696, 33.74311351776123, 42.41271788733346, 13.286633695874896, 0.1124448487535119, 0.02880591500018324, 0.09577281586825848, 0.39637703342097147, 2.102583084787641, 4.320519294057574, 0.6074898509042603, 26.9252735546657, 69.90881374904087, 56.987318311418804, 61.34150423322405, 54.94744185038975, 54.80897467476981, 52.08885220118931, 52.79138108662197, 51.24266583578927, 49.8073000226702, 45.662789889744346, 46.149750913892476, 48.05808755329677, 52.154088837759836, 48.082288128989084, 44.386732373918804, 41.67716073989868, 44.51345361982073, 47.27088444573538, 48.03510986055647, 45.06052350997925, 42.064675671713694, 39.363389764513286, 40.32395390101841, 40.34843587875366, 44.94980049133301, 49.911279814583914, 52.10322454997471, 51.6756706237793, 53.4598776953561, 52.125986848558696, 51.32359845297677, 50.044556685856406, 47.40347344534737, 41.795742171151296, 39.525341851370676, 38.820287295750205, 38.76462527683803, 37.728822571890696, 36.92161560058594, 39.09934432165963, 45.38833951950073, 47.779412678309846, 48.54894304275513, 48.314041818891255, 51.49391269683838, 44.584158488682334, 39.286903994424, 35.73379325866699, 45.4910477910723, 48.16227579116821, 57.04337985174996, 38.90866143362862, 36.33397170475551, 54.7311235836574, 48.49698093959263, 47.822501931871685, 41.11740691321236, 41.77430697849819, 41.10054016113281, 45.224872725350515, 48.21104867117745, 51.05763530731201, 50.45646674292428, 47.55692788532802, 38.78242308752877, 45.8715033531189, 52.216462816510884, 49.33600371224539, 45.913484369005474, 50.824957506997244, 49.463826247623985, 37.95330497196743, 36.97852482114519, 38.1613826751709, 38.25225816454206, 42.51895236968994, 44.764307907649446, 47.29216677801949, 52.82076154436384, 51.72796276637486, 49.774747712271555, 53.272686277117046, 49.23200307573591, 44.39717204230172, 40.12640271868025, 40.25851924078805, 42.32158184051514, 52.765231541224885, 52.73185586929321, 51.07511350086757, 53.65368032455444, 56.67207506724766, 52.160088607243125, 52.18274320874895, 50.25353070667812, 54.28646666663033, 58.683894702366416, 57.960945061274934, 55.64066014971052, 51.055220808301655, 55.372577803475515, 55.366584982190815, 57.68191235406058, 6.17213431426457, 0.48474031473909107, 5.650452707495008, 1.74327175957816, 0.10918195705328669, 0.1172317708177226, 0.25994277585830006, 16.680799177714757, 32.50673368998936, 27.217810085841588, 37.132125173296245, 17.71150537899562, 15.15466730935233, 29.350865364074707, 42.28930745806013, 46.68427930559431, 51.00474214553833, 17.93498202732631, 0.07440395001322031, 0.0648823327251843, 0.018458462918975523, 0.0481576726638845, 0.0549747002577143, 0.08417118340730667, 0.04020879098347255, 0.029459534212946892, 0.04156101628073624, 0.041462682985833714, 0.03234478724854333, 0.10953037800001246, 0.037423207956765375, 0.041755888145416975, 0.028608295068676983, 0.03799896188346403, 0.04783233208581805, 0.026606833894870112, 0.04183982971257397, 0.054622048645147254, 0.0378834616525897, 0.021222334521423494, 0.018719817644783428, 0.057383089060229917, 0.026558627374470234, 0.024172482646203468, 0.054690482294453044, 0.022336054759632264, 0.013644275621377995, 0.015913907405255095, 0.024957841129175255, 0.05066669160234077, 0.03242859989404678, 0.06449037018631186, 0.07379779432501112, 0.1704837554799659, 5.110358374459403, 65.06703799111503, 66.32253578730992, 64.91619954790387, 57.25320502689907, 51.781314509255544, 24.529619795935496, 34.53236286980765, 29.833956241607666, 45.23691047940935, 17.43977175440107, 0.10382986960134336, 0.03543993491413338, 0.2628175930253097, 0.8267545881015914, 3.1434156341212134, 1.6140187638146537, 0.21402496764702456, 29.204379967280797, 72.89110565185547, 59.21447999136788, 63.248715264456614, 57.31469658442906, 56.843813691820415, 54.47242477961949, 54.563936029161724, 53.194901193891255, 51.93044716971261, 47.63267019816807, 48.04201636995588, 50.4446895463126, 53.59137235369001, 50.176794801439556, 46.77180923734392, 43.71638059616089, 47.7391027041844, 49.854950768607004, 51.05445303235735, 46.926712376730784, 44.29194157464163, 41.48322262082781, 44.19357245309012, 41.5822240284511, 47.28733777999878, 52.684771401541575, 54.88644014086042, 53.47989198139736, 52.88623789378575, 53.56239141736712, 53.208877495356965, 51.859064851488384, 50.09607063020979, 44.3653701373509, 41.45167432512556, 40.08412987845284, 40.302664620535715, 39.6719696862357, 39.4278620992388, 40.46728481565203, 48.347886494227815, 48.31059551239014, 51.47661863054548, 50.0669298853193, 53.48826803479876, 46.078431129455566, 41.10481677736555, 38.98836074556623, 47.6184263910566, 50.11438955579485, 58.471460478646414, 40.98119790213448, 39.207319327763145, 55.917229720524375, 50.61235305241176, 50.36764097213745, 42.96647194453648, 43.29432269505092, 43.006959097726, 48.66403300421578, 50.81683158874512, 52.79736001150948, 52.40930659430367, 49.117406436375205, 40.961614404405864, 46.937871183667866, 53.97430494853428, 50.09954820360456, 46.91711344037737, 52.56012766701834, 51.39747517449515, 39.64000449861799, 40.204813139779226, 40.08979960850307, 40.361609663282124, 44.4230123928615, 46.84204510280064, 48.32090663909912, 54.28899581091744, 51.79247679029192, 50.93522194453648, 54.30477169581822, 52.10119915008545, 44.9671744619097, 41.340562207358225, 42.21850184031895, 43.67479910169329, 53.44177763802664, 54.12087024961199, 54.1755108833313, 56.93726001467024, 56.633488246372764, 55.10623945508684, 53.93939372471401, 51.65023674283709, 55.534519468035015, 61.3842009135655, 58.59488133021763, 57.53785882677351, 52.6105055809021, 58.09682750701904, 57.252412932259695, 65.00943742479596, 7.93987762928009, 0.13442951227937425, 1.319503407393183, 2.804198716367994, 0.9129252242190498, 0.045685528711016686, 0.03813625326646226, 17.746989829199656, 38.85658121109009, 28.115135192871094, 33.52275834764753, 17.48840045928955, 20.04356575012207, 33.82620702471052, 48.348873138427734, 51.57357726778303, 59.59140586853027, 23.25139444214957, 0.21801742698465074, 0.07514487632683345, 0.030299801445965256, 0.0625554190150329, 0.015037564161632742, 0.06630048448485987, 0.030354260666561977, 0.027951140688466172, 0.006653373004935149, 0.022389384219422936, 0.0352965435013175, 0.07499181918267693, 0.051138266654951234, 0.09954747225024871, 0.051269763348890204, 0.030417439062148333, 0.0259043211450002, 0.07107315052832876, 0.04299464203151209, 0.11250794572489602, 0.12642340974083968, 0.12409610248037747, 0.07093612038131271, 0.14073182695678302, 0.1450177255485739, 0.19663347729614802, 0.20881399512290955, 0.1429631622242076, 0.11263526603579521, 0.11108355144304888, 0.19243874666946276, 0.18543230263250216, 0.11285211225705487, 0.13313257401543005, 0.1820246861981494, 0.3336177282035351, 7.242863007954188, 77.20196260724748, 74.62101255144391, 73.24004418509347, 65.52623053959438, 57.44873080934797, 28.083383662360056, 52.77770355769566, 44.978149141584126, 59.8258033479963, 21.54646979059492, 0.21638308039733342, 0.10183431168219872, 0.34707131343228476, 2.4375453165599277, 5.850637257099152, 12.41696502481188, 1.5455362328461237, 32.306910446711946, 74.68947315216064, 62.04627391270229, 66.47866875784737, 60.85727037702288, 58.96344157627651, 56.93270894459316, 57.35530533109392, 55.23242221559797, 54.14143691744123, 50.65223571232387, 51.8398391859872, 52.706491470336914, 56.15055022920881, 51.81461375100272, 46.98473678316389, 45.727369921548025, 50.090588501521516, 51.551534107753206, 53.28403615951538, 49.92751775469099, 44.85045862197876, 42.54895469120571, 45.22454963411604, 44.82615729740688, 48.97604881014143, 53.230281421116416, 58.18648011343819, 55.27647032056536, 53.93726062774658, 57.92723934991019, 54.023991516658235, 54.354927267347065, 52.65014852796282, 46.48969152995518, 43.066744872501914, 43.62246526990618, 42.53337682996477, 42.81365326472691, 41.805764947618755, 43.205055713653564, 50.870002678462434, 51.1959878376552, 53.70404781614031, 52.14461496898106, 55.59659120014736, 48.57146562848772, 42.683419704437256, 40.08802434376308, 49.18851430075509, 52.72592558179583, 60.11531393868582, 44.25961855479649, 41.55119684764317, 57.00910438810076, 52.91575384140015, 52.48348208836147, 44.97023514338902, 45.469008105141775, 46.01997593470982, 49.93599108287266, 53.66476617540632, 54.13936635426113, 54.79189600263323, 52.768361704690115, 43.734685625348774, 50.142046860286165, 56.66226421083723, 52.54406690597534, 47.529162883758545, 55.75023324148995, 53.41127157211304, 42.56364665712629, 42.17963709150042, 41.91761704853603, 42.016722679138184, 47.33012478692191, 48.618838446480886, 51.341305937085835, 57.25507409232003, 53.30378293991089, 52.92157295772007, 57.48001159940447, 53.011399269104004, 48.01207658222744, 44.595480578286306, 44.09615176064627, 46.5929730279105, 55.73184135981968, 57.025755746024, 56.712569168635774, 59.26669570377895, 57.8069486618042, 56.70366505214146, 53.973537172589985, 52.964922768729075, 59.39368792942592, 62.6107177734375, 60.263519014631, 60.609942299979075, 55.700828075408936, 60.79879433768136, 57.95446239198957, 65.4707144328526, 7.567331722804478, 1.7745480984449387, 16.95384774889265, 5.32784480707986, 0.5862741236175809, 0.2888942909027849, 0.47626834362745285, 23.702904020036968, 47.60673952102661, 37.79180799211775, 50.98640584945679, 25.55189609527588, 23.108258077076503, 41.50240312303816, 55.20894077845982, 57.535975864955354, 66.34727832249233, 25.849299839564733, 0.4265209787658283, 0.13352653144725732, 0.10445724986493587, 0.1495818777808121, 0.112659564374813, 0.1387536802462169, 0.1439960010881935, 0.09627453823174749, 0.10667019683335509, 0.19747909477778844, 0.08833957330456801, 0.23714823329022952, 0.1253812885177987, 0.23527854361704417, 0.15409351140260696, 0.08487546204456262, 0.13519655540585518, 0.12772237003913947, 0.08226399110364062], [0.05093900127602475, 0.00982700299937278, 0.024012882728129625, 0.02500726392359606, 0.028889076252068793, 0.029355029642049755, 0.029362432459103208, 0.03076454365093793, 0.05284077887024198, 0.029193093867174218, 0.01945312401013715, 0.033820071656789095, 0.03471228413816009, 0.02950098252456103, 0.05252128387136119, 0.02802701956326408, 0.043375741224735975, 23.572533232825144, 64.2425786427089, 56.96013695853097, 57.21502467564174, 47.57068184443882, 26.327514818736486, 20.548894337245397, 35.75155285426548, 34.663381576538086, 37.47297600337437, 4.95635415826525, 0.021916636997567754, 0.12008328709219183, 0.09144013907228198, 0.9349465625626701, 2.135555326938629, 1.7524324165923255, 0.6160935663751194, 53.81154339654105, 61.28092983790806, 58.20696687698364, 54.191269397735596, 50.34141499655587, 49.805403164454866, 50.3826664515904, 49.93781498500279, 48.96842316218785, 45.93480839048113, 41.82591472353254, 43.34516266414097, 48.557190554482595, 52.125180857522146, 47.752735069819856, 46.567129203251426, 43.40064055579049, 48.30445677893502, 52.531428132738384, 50.86312396185738, 43.829688344682964, 42.76876095363072, 39.86408042907715, 39.930560793195454, 41.08271108354841, 49.321992669786724, 51.25351892198835, 56.477671418871196, 55.67040538787842, 50.379425116947715, 50.493587493896484, 51.482392583574565, 51.55578987939017, 50.170061997004915, 44.43434490476336, 38.964316504342214, 36.87364523751395, 38.33040802819388, 37.468487467084614, 37.16527850287301, 39.76797989436558, 44.553631578172954, 46.96425001961844, 49.22111872264317, 46.77006523949759, 47.551390171051025, 38.340875489371165, 39.33216803414481, 37.24951498849051, 44.87914425986153, 46.3848432132176, 56.103413649967735, 37.12854337692261, 33.55287184034075, 54.434126308986116, 45.04273612158639, 48.892600945064, 41.76485742841448, 43.167591026851106, 37.14669554574149, 43.47250229971749, 46.71365976333618, 49.335301944187705, 48.306450911930625, 44.45453289576939, 39.43045377731323, 43.208279677799766, 50.844440255846294, 50.878656659807476, 43.93360560280936, 51.530078070504324, 47.66728612354824, 41.05866684232439, 37.72056811196463, 39.07508816037859, 40.48515905652727, 45.02332285472325, 47.53967898232596, 49.17060879298619, 51.94867924281529, 51.02281093597412, 48.97976609638759, 53.11529220853533, 51.395842347826274, 45.47618906838553, 39.83466175624302, 40.749353885650635, 39.207253319876536, 50.06338977813721, 51.92059462411063, 52.49616602488926, 51.2517922946385, 53.223215103149414, 57.800410406930105, 52.54580395562308, 55.18741873332432, 57.95548030308315, 56.170258794512065, 55.941138471875874, 55.30496140888759, 53.33618933813912, 55.226137569972444, 57.304885728018625, 56.37133618763515, 52.11178820473807, 4.327236030782972, 2.6223296182496205, 5.294662381921496, 0.6730039268732071, 0.02685799023934773, 0.04163813517828073, 5.621449189526694, 38.52210882731846, 27.625625916889735, 30.851179463522776, 33.42171764373779, 18.386880704334803, 26.841568606240408, 43.982739789145334, 45.08501591001238, 50.40429271970476, 39.18536996841431, 1.6939347726958138, 0.11145101886774812, 0.036887894717178175, 0.07394076165344034, 0.027942406246438622, 0.008860659719045674, 0.01493069828887071, 0.061414285962070735, 0.05252876811261688, 0.02632420539989003, 0.027952190721407533, 0.038368427593793185, 0.027679713110306432, 0.049380257060485225, 0.061919801336313994, 0.032730785464601855, 0.02104862786031195, 0.04579012827681644, 0.013038633075276656, 0.04555945011920162, 0.01303490367718041, 0.06029178548072066, 0.06639247347733804, 0.01599651056208781, 0.014811349068103092, 0.010461949776591999, 0.07424648917679276, 0.012731437371777636, 0.027276403769584637, 0.06324710404234272, 0.017027904146483967, 0.017954318185469935, 0.040391150662409406, 0.051406104782862325, 0.02659064404932516, 0.05967817269265652, 30.138433252062114, 71.92281164441789, 64.42576789855957, 62.542694909232004, 54.42086567197527, 33.09146629061018, 19.483990839549474, 37.21116440636771, 38.25088242122105, 42.954917090279714, 6.075847480978284, 0.24580628584538186, 0.014828582161239215, 0.3595943828778607, 1.4818359081234251, 3.8540467705045427, 0.2595722143139158, 1.0013557076454163, 57.30639696121216, 63.85409096309117, 61.92506258828299, 57.05099507740566, 53.57081610815865, 52.71158797400338, 52.921927315848215, 52.959433691842214, 50.124426228659495, 48.03666625704084, 43.657129832676475, 44.86738095964704, 50.455487046922954, 54.84375040871756, 49.18402229036604, 48.245327608925955, 45.38827003751482, 52.98613561902727, 53.84436321258545, 53.8143504687718, 47.09345524651663, 44.74961941582816, 41.937051159994944, 41.41253512246268, 44.39400366374424, 51.57137816292899, 54.731839248112266, 57.753565652029856, 56.58706733158657, 52.2224452154977, 51.7373046193804, 53.76341322490147, 54.37391669409615, 51.35000160762242, 46.44489649363926, 41.2421236038208, 39.52189901896885, 39.80366931642805, 38.76042856488909, 38.09301240103585, 42.20187132699149, 45.79036576407296, 48.244796071733745, 51.40269674573626, 49.87033755438668, 49.83667005811419, 40.80443572998047, 40.66795573915754, 40.056889465876985, 48.092064244406565, 49.35166495186942, 58.52209200177874, 39.557616233825684, 36.24495833260672, 57.14869369779314, 47.41504567010062, 50.04605402265276, 43.951215812138145, 44.951040744781494, 39.40954317365374, 44.48516402925764, 49.018526622227256, 51.45797313962664, 50.9089230128697, 46.995152132851736, 41.65298100880214, 45.9910887990679, 53.49886751174927, 53.2118513243539, 45.22294807434082, 50.98422758919852, 49.51436397007534, 42.16480963570731, 39.67096567153931, 41.10050194604056, 41.678526060921804, 47.56403589248657, 50.34758847100394, 51.526812417166575, 53.64060034070696, 52.7897378376552, 50.02417761938912, 54.107161453792024, 52.323162828172954, 48.645165170942036, 42.46052496773856, 41.23170478003365, 41.29129253114973, 53.969274452754426, 53.83231503622872, 54.28277717317854, 54.90085417883736, 55.84212664195469, 58.80899006979806, 54.13514184951782, 56.903873920440674, 58.794232095990864, 55.850165707724436, 56.94251980100359, 57.49446732657296, 54.435112953186035, 57.202233042035786, 61.20282513754708, 58.8163343157087, 58.347157205854145, 6.225246778556278, 1.0719586334058215, 2.610552421637944, 1.9834877039705003, 0.5176571341497558, 0.09506604022213391, 4.0938608050346375, 43.292085375104634, 33.88821274893624, 27.80492765562875, 26.456323998314993, 21.2576870237078, 31.162107876368932, 48.216558592660085, 50.975333895002095, 56.087311199733186, 47.42705910546439, 2.637437390429633, 0.07852364145219326, 0.06414338773382561, 0.06726766830044133, 0.016163764355172004, 0.011210892981450473, 0.026888505655473897, 0.029416633836392845, 0.06258954932647091, 0.09650805605841534, 0.03477616481749075, 0.05091210754056062, 0.04220184510839837, 0.02948305562936834, 0.012319316405669918, 0.025403908354097178, 0.08822630545390503, 0.01661551939988775, 0.016442957766620175, 0.11894746018307549, 0.08819172052400452, 0.18151018023490906, 0.18211039874170507, 0.09114062692970037, 0.09539046817060028, 0.11222333421132394, 0.16899285119559082, 0.09673967398703098, 0.0912972938801561, 0.16752812479223522, 0.07318946053939206, 0.13759912577058586, 0.12210431721593652, 0.11412118987313338, 0.16963247901626996, 0.18693210929632187, 36.23458119801113, 80.86519186837333, 72.01046316964286, 72.96427018301827, 61.58110591343471, 36.582352433885845, 29.472521373203822, 49.79966047831944, 49.61239610399519, 52.8204801423209, 7.587610040392194, 0.35533866552369936, 0.1548023633658886, 1.1260211552892412, 3.828086563519069, 8.469966122082301, 6.7173499039241245, 1.5882636372532164, 63.74908283778599, 65.41429506029401, 63.652753012520925, 58.82651342664446, 56.678637640816824, 54.744300842285156, 55.235983167375835, 53.77839354106358, 53.391879149845664, 49.644250120435444, 46.25672190529959, 48.19140958786011, 52.96147993632725, 56.48521716254098, 51.709779330662315, 51.95832681655884, 48.14755603245327, 55.16700839996338, 56.68765640258789, 54.705481256757466, 48.374195848192485, 46.87638657433646, 43.81476361410958, 43.329240867069785, 46.176588330950054, 55.026387282780235, 56.8840263911656, 59.92625345502581, 56.17363909312657, 53.319402490343364, 53.829473223005024, 55.12189027241298, 56.37772158214024, 53.542731489454, 47.544424601963584, 42.933652128492085, 39.86589043481009, 42.11015510559082, 41.560514381953645, 40.82811519077846, 44.794741017477854, 48.16283859525408, 51.13477073396955, 53.82731580734253, 52.39386074883597, 52.16653306143624, 43.0795121874128, 44.359721251896445, 41.9369295665196, 49.932437079293386, 50.984825134277344, 61.320680482046946, 42.27415691103254, 39.629005500248496, 59.5840060370309, 50.63048437663487, 52.84643861225673, 45.839010102408274, 49.2668274470738, 41.14700276511056, 48.83451400484358, 51.01870455060686, 52.69629151480538, 54.89619541168213, 49.39734240940639, 43.72335311344692, 48.09750815800258, 55.79713358197893, 55.485013553074424, 47.11559220722744, 53.268413134983604, 52.29480722972325, 45.410070010593955, 41.77339676448277, 43.43755286080496, 44.58816759926932, 48.07916838782174, 53.09973866598946, 53.403131757463726, 56.82690177645002, 54.833369800022666, 51.48326458249773, 57.368718828473774, 55.1892078944615, 49.94976588657924, 44.88864244733538, 43.72041055134365, 43.643712861197336, 55.03376279558454, 56.59622853142874, 56.86399820872715, 56.87757498877389, 59.16960852486746, 60.82163306644985, 55.373185770852224, 60.1984977722168, 60.139472825186594, 58.71709319523403, 61.04713685171944, 60.076668058122905, 57.522197587149485, 59.381306239536826, 65.09567846570695, 59.971458435058594, 60.92179134913853, 6.065248438290187, 4.6744027733802795, 17.086683409554617, 3.0759440660476685, 0.30278569406696726, 0.1882302960647004, 6.8173436011586865, 50.58359445844378, 42.406395026615684, 43.910620961870464, 46.71430941990444, 25.80045747756958, 37.359883649008616, 56.188807010650635, 59.212048121861045, 64.29905360085624, 52.42220939908709, 3.2674429331507002, 0.22098675050905772, 0.13993268912392004, 0.21541420024420532, 0.08871539349534682, 0.16762024270636694, 0.10997343422578913, 0.09399719150470835, 0.1681397155459438, 0.11178405064025096, 0.11033488983022315, 0.14321340593908513, 0.127918398806027, 0.2638725521309035, 0.15187725318329676, 0.21586466607238564, 0.13148978645248072, 0.1549148644719805, 0.07255348323711328], [0.034172482389424524, 0.050853577109852006, 0.045563178669129095, 0.007072771683202258, 0.01689418694669647, 0.020412050054541657, 0.033875898125448396, 0.03932527732104063, 0.07255537634981529, 0.06264805261577878, 0.03162676488448467, 0.05404096821855221, 0.050223204506827254, 0.04250163205766252, 0.015098087788958634, 0.039023322452391894, 0.20793742287371839, 38.03357056209019, 64.14095429011753, 57.588740485055105, 51.91899306433541, 33.022929259708945, 34.29468584060669, 31.559409345899308, 42.15861531666347, 31.245809350694927, 38.79366527284895, 1.6760154770953315, 0.09285584810589041, 0.0875601808407477, 0.3401990836220128, 0.30407833041889326, 1.3497781200068337, 0.740454378936972, 3.784267314842769, 65.76482473100934, 63.68459660666329, 60.073562213352744, 54.84240940638951, 51.34788588115147, 46.62033155986241, 45.772852829524446, 44.70670734133039, 43.9743116242545, 44.64010885783604, 44.63112136295864, 41.202449389866416, 47.08786194665091, 48.59298767362322, 48.01162494931902, 45.38270453044346, 46.745451245989116, 50.43420818873814, 53.37115962164742, 53.73789249147688, 47.89549275806972, 43.60181522369385, 41.85465942110334, 41.10087020056588, 44.5785026550293, 51.100985118321006, 53.06301743643624, 58.78551210675921, 52.35839366912842, 53.089674200330464, 51.70843832833426, 50.47421939032418, 47.60237257821219, 50.953374113355366, 46.31753601346697, 40.57094499043056, 37.2798091343471, 37.50925949641636, 35.95194237572806, 37.19958870751517, 37.41333614076887, 43.39999784742083, 43.45457247325352, 47.69022907529558, 44.498056411743164, 42.67885821206229, 36.1389878817967, 39.623895100184846, 36.80279098238264, 46.90943220683506, 45.336471217019216, 56.26656777518136, 35.059922218322754, 33.91030107225691, 57.67454726355416, 47.00216981342861, 48.70937694822039, 40.62027720042637, 44.81533200400216, 39.49108375821795, 39.885334968566895, 41.818292549678254, 46.15946102142334, 41.85572944368635, 41.81840372085571, 36.24346099581037, 42.854998520442415, 49.45616238457816, 48.7988280568804, 47.15373086929321, 52.618690558842246, 46.93335485458374, 38.0872870853969, 37.42557886668614, 38.817931856427876, 40.70855406352452, 48.21831996100289, 49.27346645082746, 51.586726733616416, 49.71023716245379, 51.06036942345755, 47.82945360456194, 51.18278626033238, 51.222616808755056, 49.47359888894217, 38.284834793635774, 40.021853174482075, 40.88149125235421, 49.08193588256836, 51.93018661226545, 53.48383160999843, 52.40781967980521, 50.0803815977914, 51.563033376421245, 56.47058425630842, 56.963524205344065, 51.23224701200213, 52.43955557686942, 53.010739190237864, 50.290133816855295, 48.158006123134065, 50.03513145446777, 56.372982910701204, 58.76769692557198, 59.83323792048863, 41.11898068019322, 0.48636624749217716, 0.7523095799343926, 2.427531225340707, 0.1538760137877294, 0.04166449287108012, 0.05119610497994082, 23.725602047783987, 34.26448202133179, 27.886065244674683, 29.473480224609375, 12.455028993742806, 21.514101607458933, 26.65018047605242, 41.905964919498985, 46.94006334032331, 53.96464695249285, 9.926372817584447, 0.19828167956854614, 0.08314458706549235, 0.01476195002240794, 0.09548865897314888, 0.028482389503291676, 0.01729097217321396, 0.005950166877093059, 0.028201085847935507, 0.05545727775565215, 0.01723681659703808, 0.0432364651268082, 0.013152438664941915, 0.06450246168034417, 0.012704188253597488, 0.053149932995438576, 0.04741624423435756, 0.036050392514360804, 0.04684808650719268, 0.06420113784926278, 0.01008174624959273, 0.052482929679432085, 0.03228187348161425, 0.03780038521758147, 0.024702016463769332, 0.062421706904258044, 0.0572787235890116, 0.022225665593785898, 0.043755171221813986, 0.043709224223026207, 0.027417335492957915, 0.024267511475565176, 0.013622711778485348, 0.040959651049758704, 0.03273662765111242, 1.2285334659474236, 50.23167167391096, 72.67338384900773, 64.3080028806414, 58.49154077257429, 40.9587413242885, 39.82304089409964, 29.99968467439924, 36.125973905835835, 35.47082478659493, 41.69291925430298, 1.1949076588664735, 0.0525156045332551, 0.13594858933772358, 0.7500653117895126, 2.3023791866643086, 2.310366792338235, 0.3560386151075363, 4.363375348704202, 67.9193707874843, 65.68058477129254, 64.11692741939, 57.07277420588902, 55.30304370607649, 47.17471442903791, 49.59897565841675, 47.63753046308245, 46.723088468824116, 45.381318364824565, 46.74384273801531, 43.12689195360456, 49.13013901029314, 50.818130901881624, 50.117161887032644, 47.57010166985648, 48.89120088304792, 53.730145250047954, 56.827238764081685, 55.58594308580671, 49.88932350703648, 45.12272725786482, 43.23371008464268, 42.47052342551095, 47.44233124596732, 54.468933309827534, 55.040530341012136, 61.42548710959298, 54.006113801683696, 52.49097919464111, 52.694630895342144, 51.82583509172712, 50.438800948006765, 53.015387535095215, 48.13045651572091, 42.617682797568186, 39.8925576210022, 38.75987270900181, 37.85190296173096, 39.76300845827375, 38.89285428183419, 46.51412834439959, 45.548766476767405, 49.11033664430891, 47.389910561697825, 44.66133907863072, 39.70218392780849, 42.87223700114659, 38.915825026375906, 47.177330425807405, 48.28559936795916, 58.346865381513325, 37.46458952767508, 36.38850116729736, 58.44839940752302, 50.13176352637154, 50.233881201062886, 43.919677938733784, 47.430067675454275, 38.960974420819966, 41.797916957310264, 44.535684381212505, 47.80013220650809, 45.19578756604876, 43.55866343634469, 38.90785196849278, 46.23892409460885, 52.187881401606965, 51.54158776147025, 48.02888774871826, 53.90536492211478, 48.483383314950125, 40.84592342376709, 38.98140212467739, 40.40169382095337, 41.37743977137974, 50.32791812079293, 51.17372233527047, 52.8354708807809, 51.020823751177105, 51.72323104313442, 49.36173983982631, 52.28072323117937, 52.94336598260062, 50.528873920440674, 40.57784455163138, 41.757214409964426, 43.680850982666016, 51.56186260495867, 54.77256611415318, 55.67507457733154, 53.58186721801758, 53.322372845241, 54.850149699619834, 57.576237201690674, 57.49967152731759, 53.564500195639475, 55.609698976789204, 54.754469530923025, 51.59730536597115, 49.838101387023926, 53.00650773729597, 57.90076323917934, 60.300789151872905, 61.83040727887835, 47.09821823665074, 0.8606490950499261, 1.3408418680940355, 4.357035117489951, 0.8078933230468205, 0.05078176435615335, 0.1271832739668233, 25.855398620877946, 38.988173144204275, 32.28808430262974, 31.55728667122977, 14.681290013449532, 32.18195404325213, 31.528198037828716, 48.348616055079866, 50.30048663275582, 61.35430976322719, 12.954316990716116, 0.18869088563535893, 0.02213928638957441, 0.04986518907493778, 0.05054634323875819, 0.03545689828959959, 0.022256382874080112, 0.028731941112450192, 0.018532609833138328, 0.04172992739560349, 0.030531507584133318, 0.07374243943818978, 0.0307484454076205, 0.006019846486326839, 0.02361549699812063, 0.04200027949575867, 0.09112191293388605, 0.036920535644250255, 0.016299573139154484, 0.1583250593394041, 0.11146786010691098, 0.17087826931050845, 0.180632848026497, 0.11384560966065951, 0.07504276359187705, 0.0830717191898397, 0.1039826146193913, 0.12041471073670046, 0.16709501588983194, 0.11901327807988439, 0.16980068784739288, 0.13431656334017003, 0.10714931719537292, 0.12329704607171671, 0.08863972327006714, 2.9363960112844194, 63.784011432102744, 78.48175130571637, 71.79748003823417, 65.1345466886248, 46.36602054323469, 44.84605346407209, 43.22299943651472, 54.54618338176182, 44.41633169991629, 51.435332434517996, 2.3514521420001984, 0.09379466915769236, 0.28502278721758295, 2.1679543427058627, 2.750058570078441, 7.636405502046857, 2.7515787056514194, 5.020439565181732, 71.03987625667027, 68.9233090536935, 66.07702813829694, 58.87966019766671, 57.15230328696114, 50.85830538613455, 51.786546502794536, 50.6344552721296, 48.80657877240862, 46.08834273474557, 48.30155938012259, 46.30020720618111, 52.28903327669416, 54.1213253566197, 52.35664619718279, 50.43242597579956, 52.59119306291853, 55.185011182512554, 59.89177649361746, 59.171428952898296, 52.54051290239607, 47.53531551361084, 46.371262959071565, 44.86674519947597, 48.535460063389365, 55.94987235750471, 54.17930112566267, 61.61340808868408, 56.931270667484824, 54.38785825456892, 54.078058923993794, 53.1943279675075, 51.218652861458914, 53.930145672389436, 51.44863823481968, 45.42672136851719, 42.460497174944194, 39.97166633605957, 39.43890278679984, 41.60199860164097, 41.14080497196743, 49.54672867911202, 47.77511521748134, 52.39210285459246, 50.036736488342285, 46.981019496917725, 41.05963959012713, 46.23637063162667, 41.56083747318813, 50.44901827403477, 50.40775292260306, 60.65643269675118, 41.12417793273926, 40.223239762442454, 61.32701029096331, 53.19359145845686, 51.74605240140642, 45.70209584917341, 48.48972007206508, 42.63269785472325, 42.928593839917866, 46.5854411806379, 49.30260372161865, 46.53783212389265, 45.091074739183696, 40.96262536730085, 48.23613861628941, 55.43675831386021, 53.66058683395386, 49.35051849910191, 55.98302221298218, 50.5923352922712, 42.78692354474749, 41.507065364292686, 42.60581180027553, 44.084749766758506, 54.35594170434134, 53.709394454956055, 56.06956550053188, 53.446676118033274, 54.432205132075715, 50.01810836791992, 53.842719963618684, 55.578459875924246, 54.070162296295166, 42.53984560285296, 44.661252226148335, 47.063866342817036, 54.30987514768328, 58.901352473667686, 58.38917991093227, 56.65334619794573, 56.16652066367013, 56.04485770634243, 59.72290052686419, 59.8058967590332, 56.35883985246931, 57.687533446720664, 57.04626682826451, 55.45431988579886, 52.56435564586094, 55.760860511234824, 59.90307426452637, 64.24593462262834, 63.503818375723704, 49.54426554271153, 0.6465891557080405, 6.223833688667842, 11.332248738833837, 0.3953892764236246, 0.1797543080257518, 0.2615758739411831, 29.6143410546439, 49.20816033227103, 41.086136545453755, 42.03489221845354, 19.28670195170811, 33.59380367824009, 38.889644214085166, 54.73907232284546, 57.69805996758597, 68.69353212629045, 14.416332619530813, 0.4430529959499836, 0.19553900031106813, 0.07891844026744366, 0.2844940184482506, 0.10495200367378336, 0.1457851350839649, 0.11730898810284478, 0.06171206784035478, 0.17798348090478353, 0.10211517768246786, 0.15724584939224379, 0.1277196016162634, 0.12847567961684295, 0.16084222069808415, 0.12057959474623203, 0.10475740661578518, 0.11015365991209235, 0.1635257452726364], [0.020591134105675986, 0.0812300665836249, 0.012324611523321696, 0.018012321055201546, 0.021312929124438336, 0.058576530377779684, 0.016407275306327, 0.03231220060427274, 0.049742978132729015, 0.025006814394146204, 0.03085030029926981, 0.034192393999546766, 0.06919088081589767, 0.015106035130364555, 0.016130273562989066, 0.11828575283288956, 5.607165430273328, 50.85541146142142, 57.29676675796509, 62.51235907418387, 44.62696286610195, 20.863838808877126, 18.84025761059352, 39.09066949571882, 36.62339196886335, 47.24260180337088, 26.757894924708776, 0.05982630367257765, 0.09079121532184736, 0.11302606149443559, 0.4377885412956987, 1.9205001124313898, 2.1557196506432126, 0.6546407608049256, 21.84214343343462, 69.29309218270438, 52.03681019374302, 62.70312186649868, 55.376222133636475, 55.36950669969831, 54.46114785330636, 51.467721462249756, 47.0641234261649, 46.72596154894148, 42.91405126026699, 42.49618312290737, 42.34343045098441, 44.53032037190029, 46.810382161821636, 47.50404167175293, 46.22429813657488, 47.488012177603586, 52.575149672372, 52.749976771218435, 53.15146105630057, 47.623814719063894, 45.60786437988281, 41.92323119299752, 43.73096833910261, 48.56545543670654, 52.22930308750698, 55.18650157111031, 49.072653089250835, 51.00364433016096, 51.450913769858225, 51.03113835198538, 53.03980003084455, 47.67590536390032, 52.34547001974923, 46.812921728406636, 41.81962660380772, 37.37556225912911, 37.07123810904366, 34.99355302538191, 36.91733203615461, 37.96134751183646, 40.99659858431135, 40.765056814466206, 45.56985425949097, 42.07472276687622, 38.53433418273926, 36.41125304358346, 39.82135248184204, 38.14647878919329, 46.23288263593401, 46.50090592248099, 57.01544809341431, 33.93746158054897, 32.41279751913888, 57.24616650172642, 45.38507734026228, 50.49673155375889, 43.262732710157124, 45.70933239800589, 39.56891747883388, 39.95170416150774, 37.61866930552891, 42.289800780160085, 40.240759645189556, 39.64569507326399, 36.873231819697786, 44.497722898210796, 49.255269118717735, 49.72312607084002, 47.57847424915859, 52.448233876909526, 45.230361802237375, 38.92543091092791, 36.50776352201189, 36.81614542007446, 40.613033703395296, 46.45485673631941, 51.78775201525007, 51.38240105765206, 50.26258768354143, 51.06311396190098, 51.00019107546125, 50.45179407937186, 52.77931901386806, 47.17524596623012, 37.67919506345476, 39.833643845149446, 40.20493473325457, 48.11090428488595, 52.841362953186035, 48.642795835222515, 49.673071248190745, 48.940414973667686, 53.809587478637695, 54.11234480994088, 54.25348704201834, 51.4944338117327, 52.62543031147548, 49.65382126399449, 46.373708724975586, 44.37253025599888, 50.70313821520124, 52.58389745439802, 56.40954433168684, 54.9112799508231, 60.64417607443673, 19.411878960473196, 0.3200437437210764, 3.2178742672715868, 2.4712727410452704, 0.04477651230990887, 0.10677477943577937, 5.330551564693451, 41.748636858803884, 21.531970637185232, 36.3822477885655, 23.553729670388357, 14.243123582431249, 39.84080743789673, 46.86875745228359, 45.768204484667095, 50.30572557449341, 22.759668690817698, 0.08677728713623115, 0.015294041916994112, 0.04543431129838739, 0.04505164468927043, 0.029197171862636293, 0.03027404086398227, 0.027309709660974995, 0.021464939628328596, 0.08379682206681796, 0.025508870936131904, 0.015289738308638334, 0.012827015814504452, 0.027995830701131905, 0.055340104935956855, 0.06870397087186575, 0.00800260723501976, 0.05660120976556625, 0.047874224837869406, 0.017396414818774377, 0.0312570515088737, 0.015838971694133112, 0.029996706638485193, 0.030402738600969315, 0.046356606629810164, 0.011950235763963844, 0.03648022409262402, 0.018611813529527614, 0.09377137505050216, 0.051763770769217184, 0.043577853058065684, 0.0516232936643064, 0.07676404408578362, 0.11244252137839794, 0.12800868467560836, 9.811883875301906, 63.99074813297817, 61.74668148585728, 69.15874876294816, 53.06277424948556, 32.91612155096871, 25.74211171695164, 38.282666955675396, 35.357166154044016, 51.09273065839495, 29.958676406315394, 0.13286675113652432, 0.12823579034635, 0.30998573771544863, 1.0299952051469257, 3.1390098248209273, 0.6210706478783062, 0.5845713807003838, 22.72578058923994, 71.15559155600411, 57.166154520852224, 64.23131561279297, 58.49719660622733, 57.50479234967913, 57.472854954855784, 53.36805377687727, 50.275959491729736, 49.45591919762747, 45.47740500313895, 44.456527028764995, 43.02928365979876, 46.601328236716135, 49.66945818492344, 48.94139119556972, 48.98172548839024, 49.994692938668386, 55.489800861903596, 54.16478981290545, 54.40611464636666, 51.08116538184029, 46.953716550554546, 44.45918124062674, 45.94657169069563, 48.98139892305647, 54.462603500911165, 56.75700984682356, 51.6298576763698, 52.8033458845956, 53.01282712391445, 51.95084360667637, 54.34458834784371, 50.25288452420916, 53.47996841158186, 49.236602783203125, 42.659486634390696, 38.98561273302351, 38.804747649601524, 38.17480312074934, 39.08872400011335, 38.91003370285034, 44.509760652269634, 43.556474753788535, 47.37642758233206, 44.10259968893868, 40.640545095716206, 37.19523913519723, 42.54392072132656, 40.27178335189819, 48.485957622528076, 49.28495529719761, 59.1043301991054, 36.05823244367327, 33.3925838470459, 60.32648359026228, 48.1108660697937, 51.17032814025879, 46.00249426705496, 47.98768145697457, 41.73445905957903, 41.50896222250802, 38.94624423980713, 44.739721706935335, 41.39092969894409, 41.39252083642142, 39.690396308898926, 46.273967334202354, 52.175009863717214, 51.49584777014596, 49.812907218933105, 54.220500469207764, 48.23349830082485, 39.480807372501914, 38.340694836207796, 39.75677939823696, 43.1803548676627, 49.421518666403635, 53.44456039156233, 52.58695466177804, 51.360118184770855, 51.151700019836426, 52.43520253045218, 52.69820921761649, 54.393736430576865, 48.86717748641968, 40.852145535605295, 41.07404667990548, 42.99925354548863, 49.22033357620239, 52.62477718080793, 51.60436820983887, 50.37277569089617, 50.76907661982945, 55.05184895651681, 55.397195271083284, 56.19117634637015, 55.86823797225952, 53.72723395483834, 50.711920738220215, 49.88551936830793, 45.63132149832589, 52.82311003548758, 55.681164673396516, 57.689121110098704, 56.58617796216692, 63.50768852233887, 23.983206510543823, 0.16309251423392976, 0.8391836125935827, 2.682258699621473, 0.5034265720418521, 0.08356282926563706, 4.809225618839264, 48.49869367054531, 25.70086373601641, 31.274672167641775, 25.87285075868879, 19.912045036043438, 43.23141370500837, 52.31334849766323, 51.75225019454956, 57.89838695526123, 30.27553858075823, 0.37178524157830645, 0.02335978259465524, 0.03796977469963687, 0.01081096868230296, 0.034944736664848666, 0.008656557233605002, 0.09192552909787212, 0.037509507433112176, 0.051276195860866985, 0.024254792336640612, 0.010682477898496603, 0.008730217298891927, 0.037650507009987316, 0.02714157716504165, 0.04462191489126001, 0.04182461017210569, 0.029198858022157635, 0.012376713682897389, 0.11118323502263852, 0.17193776103002684, 0.09289778835539307, 0.09476700983941555, 0.07766082310783011, 0.18652265412466867, 0.11976444348692894, 0.09125959447452, 0.14835230447351933, 0.15625163274151938, 0.1006021870832358, 0.13415767758020333, 0.27322778584701674, 0.21412754857114383, 0.1880347015602248, 0.28563075459429194, 16.576835019247874, 77.1898032597133, 68.554776600429, 78.88442720685686, 59.06684466770717, 33.374306610652376, 27.090171677725657, 49.41073158809117, 50.93073688234602, 63.62992818014962, 32.32728603907994, 0.34936639027936117, 0.1984413524291345, 0.5692286725555147, 2.1332554732050215, 5.140601277351379, 8.315783858299255, 1.4450246776853288, 25.778372628348215, 74.45495755331856, 57.002705097198486, 66.41158390045166, 61.14329992021833, 60.666854994637625, 60.918588229588096, 56.37532097952706, 53.347848415374756, 52.42682300295149, 47.8125764301845, 46.40026126589094, 45.764570576804026, 50.147383076804026, 51.92724405016218, 52.7544618334089, 51.90882437569754, 52.80240440368652, 59.13958535875593, 56.73049552100045, 56.36094168254307, 53.75781297683716, 49.37486151286534, 47.190820353371755, 48.71451166697911, 51.65508311135428, 56.42486163548061, 57.74940020697457, 55.257206439971924, 55.260604109082905, 55.085693631853374, 54.80531644821167, 55.32214430400303, 51.920122146606445, 56.964382307870046, 51.93970217023577, 46.38056312288557, 41.48326431001936, 40.79037605013166, 41.37889541898455, 41.23245518548148, 41.784739698682515, 46.60414573124477, 46.70929282052176, 51.0677101952689, 46.28778730119978, 43.16849429266793, 40.23431519099644, 45.158569540296284, 43.11343329293387, 48.6652524130685, 51.3503212247576, 60.84243597303118, 41.26370470864432, 36.6293500491551, 62.43761035374233, 50.46807370867048, 54.27161489214216, 48.43939774377005, 51.247286387852256, 44.124128682272776, 44.67624296460833, 42.27123866762434, 47.278854029519216, 44.4270840372358, 43.591618742261616, 41.246438435145784, 49.61098909378052, 54.687419414520264, 53.70032705579485, 52.35626057216099, 56.627703871045796, 49.513717787606375, 42.019366468702046, 41.0085460117885, 40.97973530633109, 45.68802922112601, 50.349919591631206, 54.76051793779646, 54.249905245644705, 54.47890050070626, 54.03088412966047, 54.22142110552107, 54.568198748997276, 56.32799679892403, 51.936714444841655, 43.12098945890154, 44.96781022208077, 46.256305013384136, 50.93353353227888, 55.76078060695103, 53.87167658124651, 53.13787732805525, 54.96098388944353, 57.765870911734446, 58.31516769954136, 59.05171843937465, 56.90435334614345, 56.88821268081665, 52.62267882483346, 53.22886398860386, 47.68974617549351, 55.86882162094116, 57.33684744153704, 60.93821689060756, 58.926067216055735, 66.23921993800572, 25.125313179833547, 0.5209879811320985, 10.236571669578552, 6.110542007855006, 0.3379331837807383, 0.21280513810259954, 6.561105762209211, 55.4329263823373, 31.930800982883998, 49.08378757749285, 34.390192304338726, 23.445636544908794, 52.11551243918282, 60.44426250457764, 58.19679471424648, 64.98323576790946, 37.237616198403494, 0.8564393552286285, 0.12522367840366705, 0.11088180262595415, 0.16772084230823175, 0.05596001113631895, 0.08875535242259502, 0.1624648150588785, 0.07435551618358918, 0.1581354902258941, 0.08732670372618095, 0.13250061364046165, 0.08081362250127963, 0.12552779779902526, 0.10643511837614433, 0.1473987999239138, 0.07021044753491879, 0.17605416157415935, 0.2162760075713907], [0.016906902692945938, 0.005347879686658936, 0.04979330846773727, 0.05145870142483285, 0.0399203491397202, 0.023065052427617565, 0.02819006304655756, 0.03113753435068897, 0.04892354192478316, 0.025016844838059375, 0.02367726234453065, 0.06665688500340496, 0.0256285322830081, 0.04072376174320068, 0.05992140035544123, 0.012316814307788653, 26.45053093773978, 66.65639672960553, 58.756586756025044, 52.231220790318076, 38.310477120535715, 19.21356521333967, 24.0019006388528, 45.900581564222065, 32.20738445009504, 51.01323979241507, 9.636408856936864, 0.18979322005595478, 0.04714810076568808, 0.280517260410956, 0.4367558109973158, 1.863233928169523, 1.2657520345279147, 2.1768534651824405, 63.316800662449424, 59.109464917864116, 59.12656443459647, 49.82671676363264, 59.375928333827424, 59.33291898454939, 57.047930921827046, 54.53163037981306, 56.32372713088989, 51.77694756644112, 48.42155129568917, 41.16079146521432, 40.75459977558681, 40.15017598015921, 45.06647464207241, 44.93878412246704, 47.652628898620605, 49.057012694222585, 54.94296721049717, 50.34249544143677, 51.40962757383074, 50.790966919490266, 48.06171451296125, 45.05386366162981, 47.28138664790562, 48.26914255959647, 54.123764174325125, 49.36942107336861, 53.03566585268293, 52.715538024902344, 49.15410334723336, 48.94365283421108, 50.917656898498535, 51.31115770339966, 50.019164494105745, 47.257373673575266, 38.143723828451975, 37.89355741228376, 37.311114243098665, 36.8852904183524, 37.185077394757954, 36.07166678564889, 39.452955518450054, 40.86708068847656, 41.64459105900356, 37.00410461425781, 37.89997754778181, 35.60429620742798, 40.1207468850272, 40.657307624816895, 48.50203227996826, 46.10806867054531, 56.5107934815543, 33.229593004499165, 29.901656014578684, 55.88133185250418, 46.05522414616176, 50.15828480039324, 43.65738344192505, 46.427303654806956, 42.144965580531526, 41.87769269943237, 37.304204259599956, 39.32316664287022, 38.78214168548584, 39.080771786826, 36.265980107443674, 43.479221207754954, 48.44472006389073, 48.818956988198416, 50.027714252471924, 49.621088300432476, 41.60578189577375, 38.160076413835796, 36.40859535762242, 38.92785235813686, 39.92052412033081, 47.58083316258022, 51.275919914245605, 51.05242763246809, 50.84461743491036, 50.44831998007638, 49.99623196465628, 50.49468183517456, 49.154332637786865, 45.0716232572283, 38.55047484806606, 39.905880791800364, 39.128564970833914, 45.861289501190186, 50.145013741084504, 48.57221255983625, 47.59143958772932, 47.47235788617815, 47.14501782826015, 51.64014795848301, 51.297699042728965, 50.42490802492414, 47.122717584882466, 45.90335042136056, 41.37794351577759, 44.64222458430699, 43.77681950160435, 49.67018774577549, 53.67170395169939, 56.860808985573904, 57.39331545148577, 52.036907468523296, 2.0746550176824843, 1.633474154131753, 2.744733427252088, 0.230678917574031, 0.06005982828459569, 0.24797602370381355, 28.58862713405064, 40.050674302237375, 27.929248298917496, 24.566356658935547, 21.169495276042394, 32.71409920283726, 35.697120666503906, 43.137467111860005, 49.39806154796055, 48.22032451629639, 5.114532504762922, 0.16561447962054185, 0.02651673971143152, 0.00562466260245336, 0.022385942350540842, 0.06038755391325269, 0.09100997501185962, 0.024133840076891438, 0.12646800306226524, 0.06419660523533821, 0.008780882660565632, 0.02998097480407783, 0.038735358975827694, 0.04509085722799812, 0.022150673903524876, 0.06591216567903757, 0.03714676939749292, 0.03284324925126774, 0.03699563250743917, 0.007117129213708852, 0.0739833057991096, 0.02995526511222124, 0.020519535090508204, 0.07381097826042346, 0.01175773368283574, 0.026270404358261397, 0.06088406512779849, 0.046583549452147315, 0.03283903894147702, 0.034391143691859076, 0.039983530927981646, 0.033009619252490144, 0.04168043505134327, 0.09391126182994672, 35.20199203491211, 73.88773441314697, 63.875560896737234, 59.01741518293108, 45.11936432974679, 23.58442333766392, 24.132804700306483, 39.74816015788487, 30.321268149784633, 58.59991182599749, 10.717905521392822, 0.3009497954377106, 0.06759730061250073, 0.7362261829631669, 2.3344711789063046, 3.413083255290985, 0.8396949565836361, 2.575228431395122, 67.07820102146694, 59.43639155796596, 61.90623297010149, 54.669670241219656, 61.379754066467285, 62.447810309273855, 61.28675242832729, 57.42695862906319, 58.80088152204241, 54.9291924067906, 52.084096159253804, 43.179604462214876, 43.99373183931623, 41.993724141802105, 46.58832120895386, 47.09450789860317, 49.06139005933489, 51.734038966042654, 58.257938861846924, 52.81769391468593, 54.372874464307515, 52.96602405820574, 51.00979001181466, 48.10955286026001, 49.41962875638689, 51.15365593773978, 56.23581157411848, 51.08159964425223, 53.76327773502895, 54.713412625449045, 52.28599691390991, 52.32668209075928, 53.33786037990025, 52.987671170915874, 51.82019315447126, 49.124448435647146, 40.709641456604004, 38.447207246507915, 38.457952635628835, 37.84566347939627, 39.493484360831125, 37.38710669108799, 40.63820007869175, 44.64786304746355, 44.14816944939749, 38.80764157431466, 40.346163817814414, 37.44250120435442, 42.87882736751011, 43.104452746255056, 51.48547758374895, 47.93890510286604, 59.149090494428364, 34.56551619938442, 31.836736270359584, 57.87601375579834, 48.78081137793404, 51.684216908046174, 45.31297935758318, 47.806562764304026, 44.54609973090035, 43.48385565621512, 39.697118691035676, 41.160586493355886, 39.526891299656455, 40.52522931780134, 39.38455050332205, 45.48200123650687, 50.955892835344585, 50.19778183528355, 51.84157970973423, 50.76769740240914, 43.83836317062378, 39.884949343545095, 38.22253724506923, 39.93411827087402, 40.95238719667707, 48.41086844035557, 53.490890979766846, 53.782979352133616, 52.55380828039986, 51.975575719560894, 52.09774936948504, 52.76203536987305, 51.28533124923706, 45.69501216070992, 41.22554867608206, 41.916119711739675, 40.932991300310405, 47.70021711077009, 51.89827353613717, 52.86869716644287, 50.585480894361226, 48.85387168611799, 49.66147123064314, 53.550840037209646, 54.18093395233154, 53.49479934147426, 49.611843722207205, 47.6407961164202, 41.86860792977469, 46.08607414790562, 46.95397015980312, 52.00338588442121, 56.529696055821006, 60.01582963126046, 60.72477517809187, 55.77862705503191, 3.526954459292548, 1.417904447231974, 5.230367660522461, 0.7746053178395543, 0.05233453067817858, 0.05223327629002077, 31.437954834529332, 43.82505737032209, 30.102980068751744, 26.124669109072002, 23.159414189202444, 38.94343716757638, 41.74376617159162, 50.86813013894217, 53.202592849731445, 59.42958927154541, 8.295518568583898, 0.14694328579519475, 0.015680421809000627, 0.03979814837553671, 0.0884632363117167, 0.005942913337743708, 0.03744108056915658, 0.010332956028703068, 0.07842348289809056, 0.03251561861751335, 0.04067494114860892, 0.03530899801158479, 0.03641029427360211, 0.029081332364252636, 0.032959224456655126, 0.010600759381694453, 0.05403446446039847, 0.013819654023141732, 0.09074251007820879, 0.12591084438775266, 0.11565163917839527, 0.10111812475536551, 0.16875864804855414, 0.09916446637362242, 0.09262991630073104, 0.1316831417913948, 0.11477254277893476, 0.09030572351600442, 0.08911218041820185, 0.12046066112816334, 0.15205397084355354, 0.15007171221077442, 0.1923819397177015, 0.31055548999990734, 42.716416699545725, 82.54126412527901, 72.29846600123814, 67.83618000575474, 50.426606859479634, 28.049511194229126, 32.75897066933768, 61.42566776275635, 45.00285693577358, 67.88612365722656, 12.078459211758204, 0.45710922884089605, 0.16780386785311358, 0.9790416764361518, 2.9019607390676225, 6.978722895894732, 5.230366791997637, 2.692177253110068, 66.2516780580793, 58.980388232639854, 64.99820913587297, 57.548968996320454, 63.488136291503906, 66.27113996233258, 62.98406532832554, 58.08558879579817, 62.045815331595286, 57.218557834625244, 53.893031869615825, 45.81502839497158, 45.7242362839835, 44.05582789012364, 49.676517554691856, 49.50151675088065, 50.87628384998867, 54.098570006234304, 58.61330795288086, 57.186880997249055, 55.01739631380354, 53.40610211236136, 51.72134460721697, 49.81166001728603, 51.323348317827495, 54.99360915592739, 57.09950392586844, 52.33678477151053, 57.58256006240845, 56.970545360020225, 54.40875496183123, 54.123541831970215, 55.933978353227886, 53.69754082815987, 54.304736954825266, 51.0792407308306, 42.223695618765696, 40.965164933885845, 41.128892285483225, 40.46322359357561, 43.128642899649485, 39.746357100350515, 44.30151966639927, 45.99760620934622, 46.4966709954398, 42.828897612435476, 42.82733426775251, 39.84423289980207, 44.7761789049421, 44.905721119471956, 53.46534940174648, 50.61327716282436, 60.763268198285786, 36.92050041471209, 34.602094990866526, 59.379395484924316, 50.65132202420916, 53.76867995943342, 48.71597078868321, 50.647854873112266, 47.51250457763672, 45.78054101126534, 41.92451660973685, 43.59065294265747, 41.99613516671317, 43.57313305991036, 40.9838000025068, 48.724329471588135, 53.92404167992728, 52.04417181015015, 54.14946903501238, 53.21551302501133, 45.71195534297398, 42.98879998070853, 39.5217878477914, 43.206282070704866, 42.78189304896763, 50.57877935682024, 56.10947942733765, 55.37828574861799, 54.55852338245937, 54.856969356536865, 56.43016311100551, 54.86119386128017, 53.80406366075788, 49.74954659598214, 44.845171042851035, 43.376148155757356, 43.61157396861485, 50.68490961619786, 55.15844127110073, 55.27940246037075, 51.85449641091483, 52.35006972721645, 51.25452988488333, 58.06536953789847, 56.68707970210484, 54.83586072921753, 52.03825889314924, 51.56271375928606, 44.2191835130964, 48.88470779146467, 49.324000699179514, 55.001589162009104, 57.4556998525347, 63.21263326917376, 61.55014474051339, 58.54504884992327, 3.4993295073509216, 5.7171215415000916, 10.70934794630323, 0.41775965318083763, 0.28703613632491654, 0.4697732435805457, 35.46072905404227, 54.31597219194685, 40.402048179081504, 33.70727470942906, 30.813179765428814, 42.94601992198399, 48.70934220722744, 57.78451292855399, 62.932815415518625, 65.74229172297886, 9.485183051654271, 0.36070104635187555, 0.08734098010297332, 0.09364756955099957, 0.11923475190997124, 0.09243616741150618, 0.16243228609008448, 0.10209865535476378, 0.1881489125745637, 0.18486636371484824, 0.04376372415572405, 0.11536375034068312, 0.17457418170358452, 0.15375603522573197, 0.11197800308998142, 0.1111060855910182, 0.15918768090861185, 0.12095376609691552], [0.008811927334006344, 0.019507966603019407, 0.053969925602099726, 0.07957235125026532, 0.03966101644826787, 0.06221617864710944, 0.015977520063253384, 0.02712800646466868, 0.01977095490188471, 0.0384036639173116, 0.08394597763461725, 0.04139287530311516, 0.02741384443028697, 0.09229977508740765, 0.12188213770943028, 1.8298721526350294, 50.54092904499599, 59.02792085920061, 57.08703538349697, 42.070345401763916, 22.43440614427839, 19.032611540385656, 24.820869173322404, 32.588142258780344, 35.316053662981304, 42.82744543892996, 0.852724511708532, 0.055270921505455456, 0.08247394340911082, 0.5726529402392251, 1.336128709571702, 2.589701311928885, 0.26015388167330195, 34.06149387359619, 58.703780446733745, 61.715755053928916, 68.21655913761684, 61.530057498386924, 50.524406228746685, 54.49375574929373, 60.37994997841971, 54.750696659088135, 56.2022066116333, 51.74658393859863, 52.954194750104634, 44.79194784164429, 40.97446857179914, 39.64256838389805, 41.286769253867014, 43.17273964200701, 46.91554314749581, 49.007663113730295, 54.43605095999581, 55.64946699142456, 52.88931941986084, 49.52277129037039, 50.08455746514456, 48.55153819492885, 47.70717920575823, 50.7458279473441, 52.99961165019444, 49.77533483505249, 51.31315878459385, 47.037477084568565, 44.75136341367449, 45.72858933040074, 51.15759556634085, 49.78887340000698, 52.57650804519653, 46.99688918249947, 39.80131387710571, 35.08685343606131, 35.74851996558053, 35.87921210697719, 36.11580521719796, 35.22553947993687, 39.62541675567627, 37.96278926304409, 37.33302191325596, 36.393364906311035, 39.784242153167725, 37.26070853642055, 43.51383713313511, 45.148251465388704, 52.37919657570975, 46.33327715737479, 56.75031525748116, 30.87865264075143, 30.568842887878418, 57.082616329193115, 45.52402394158499, 50.298784324101035, 43.72537156513759, 48.251098087855745, 44.02975130081177, 45.41057028089251, 40.62837879998343, 40.60568250928606, 37.09259339741298, 40.374679224831716, 36.80134923117501, 38.29303019387381, 46.878578730991904, 51.99035801206316, 48.51248237064907, 45.7404568535941, 40.009520121983115, 37.30505888802664, 38.08891643796648, 37.431700229644775, 37.02262503760201, 48.727577754429404, 50.73619426999773, 51.448395047869, 49.638726302555625, 49.678199018750874, 45.55305004119873, 47.54865605490548, 43.83322497776577, 40.48836217607771, 39.78263711929321, 38.214949812207905, 38.01866667611258, 43.53861093521118, 46.87675482886178, 49.17305455889021, 45.806165967668804, 45.55871977124895, 47.75873136520386, 45.53641952787127, 45.8473653112139, 48.034616538456504, 43.89996937343052, 41.83416223526001, 40.296008246285574, 44.099372250693186, 45.48869235174996, 50.81531688145229, 50.38687705993652, 56.57566186359951, 53.47568137305123, 62.34578990936279, 21.082840817315237, 0.6674736493400165, 2.421618742602212, 2.6944790610245297, 0.16650057850139482, 0.06372695043683052, 9.37179800442287, 45.71379314150129, 29.709076268332346, 46.27163621357509, 16.334620816367014, 29.154686450958252, 33.77223341805594, 40.001081534794395, 46.20717082704817, 43.80540439060756, 21.898356097085134, 0.2304050608405045, 0.04177495837211609, 0.10579152112560612, 0.004464569584732609, 0.039717528237296004, 0.05577824517552342, 0.04398076715213912, 0.028688107750245502, 0.043284766642110686, 0.05167694542823093, 0.014991551005680646, 0.02028379506165428, 0.0153554459435067, 0.010680915571616163, 0.01575284863689116, 0.022718164970033934, 0.09263916473303523, 0.010165491889763092, 0.03042731513934476, 0.053763525427452157, 0.04207527118601969, 0.05019603596468057, 0.09268221777996846, 0.01288376933163298, 0.054144407489470074, 0.034437589413885555, 0.021451720069827776, 0.023532296730471507, 0.09168762114963361, 0.015874398007456745, 0.01346772929121341, 0.020548130252531598, 2.4562031839575087, 59.74155644008091, 67.47082982744489, 61.51168646131243, 49.2155636378697, 27.162450313568115, 21.496315956115723, 30.743183612823486, 36.86646774836949, 40.02734225136893, 47.40990400314331, 0.7156421989202499, 0.05307494130517755, 0.3490959805037294, 0.9993611403873989, 1.4921356354440962, 0.7591615351183074, 0.25036148141537395, 38.53574466705322, 63.80405003683907, 59.317771911621094, 66.28090912955147, 62.448581559317454, 54.71608073370797, 56.445230279650005, 61.14557198115757, 56.49670948301043, 57.966864926474436, 55.352778911590576, 54.34459529604231, 46.46742950166975, 43.70487437929426, 40.72803333827427, 44.89659466062273, 44.97760370799473, 50.58207975115095, 51.52429369517735, 57.01395075661795, 55.400071825299946, 55.19752836227417, 53.51591144289289, 52.44903639384678, 50.031667777470176, 51.11602102007185, 53.11185285023281, 54.57059587751116, 53.157985414777485, 54.14727340425764, 49.64890193939209, 46.402349199567524, 46.368038994925364, 51.93755170277187, 52.76058667046683, 53.23674324580601, 48.94399677004133, 40.75210884639195, 37.579422405787874, 38.45656994410923, 37.19934899466378, 38.14607579367501, 37.24591929571969, 40.77541657856533, 40.719306400844026, 39.608845302036826, 38.91712433951241, 41.946260997227256, 40.15223264694214, 45.30125774656023, 47.55925553185599, 54.44486127580915, 48.59258815220424, 59.00295598166329, 32.741732188633506, 33.38925565992083, 58.54237379346575, 47.63060310908726, 51.32698917388916, 46.125404426029746, 50.05206421443394, 46.12830877304077, 46.415595940181184, 41.49411392211914, 41.67655972072056, 38.917846952165874, 42.216664041791645, 37.797654901232036, 40.92626196997506, 48.66877167565482, 52.99134676797049, 51.728164264133994, 47.288887228284565, 40.65831511361258, 39.006217615945, 38.568821566445486, 38.83241190229143, 40.23705972943987, 49.514384814671104, 52.213968413216726, 51.22560453414917, 51.14777776173183, 51.161198207310264, 47.435848576681956, 49.053615025111604, 46.855118138449534, 41.643368176051546, 42.07785293034145, 39.90112474986485, 39.763025828770225, 44.53030300140381, 49.14045361110142, 49.148673330034526, 48.34195620673043, 48.18189402988979, 50.3990364074707, 47.100934982299805, 50.18634857450213, 50.87167024612427, 46.208438873291016, 42.679646832602366, 43.33498007910592, 45.98704147338867, 48.462260791233604, 52.34355231693813, 51.75464732306344, 58.478846413748606, 55.958022594451904, 64.04570838383266, 25.62828459058489, 0.1251463796943426, 2.3300838257585252, 2.5297880811350684, 0.28389875324709074, 0.15759704554719584, 8.676546488489423, 53.14497491291591, 27.64028661591666, 34.51846994672503, 20.18531768662589, 35.27663653237479, 38.28591523851667, 47.00670003890991, 50.28239352362496, 52.12529897689819, 27.535394872937882, 0.3144582605787686, 0.02289939658450229, 0.08401419076004199, 0.022012493639652218, 0.01091363187879324, 0.01623832347935864, 0.009860771990913366, 0.04832073819956609, 0.008783091292051333, 0.008410372854476529, 0.051284127935234985, 0.03983231939907585, 0.021486673104975904, 0.04704949266410299, 0.01422857484846775, 0.026328295269714933, 0.08833592957151787, 0.10319484903344087, 0.08709516722176756, 0.12655861462865556, 0.1148124270673309, 0.1278300942587001, 0.11895634899181978, 0.05892268501754318, 0.11475101964814322, 0.07443029074264423, 0.06099242038492646, 0.14970621253762925, 0.2693468912371567, 0.23520621178405626, 0.17548629561705248, 0.19976303007985863, 3.3122208161013464, 67.76595456259591, 75.5665442602975, 72.01207515171596, 56.4379346711295, 31.82466377530779, 28.496792793273926, 36.00866746902466, 45.79862369809832, 49.22122641972133, 53.27606310163225, 1.275116577744484, 0.10364089759864978, 0.6980282983609608, 2.258746236562729, 4.0625635130064826, 7.186942168644496, 1.391778134873935, 38.90862321853638, 66.44877065931047, 63.04641151428223, 65.27417073931012, 60.706334659031455, 57.81197568348476, 59.77576242174421, 62.49220929827009, 61.19234030587332, 60.26235866546631, 58.195384229932515, 55.914992400578086, 49.55799518312727, 45.951894010816304, 44.97847918101719, 47.65881626946585, 46.56668451854161, 52.35727153505598, 52.37880400248936, 58.88386385781424, 59.36205278124128, 57.61704397201538, 54.79564108167376, 54.5620322227478, 53.50050728661673, 54.547163077763145, 54.80697359357561, 56.09808438164847, 54.90624598094395, 56.24712324142456, 52.361228534153526, 48.836775643484934, 47.97151299885341, 54.441689423152376, 54.69047662190029, 54.848607199532644, 52.06447444643293, 42.115046637398855, 39.256835665021626, 39.65448801858084, 40.59018455232893, 40.05627455030169, 39.38643346514021, 43.79589925493513, 41.73075566973005, 40.45410408292498, 40.443640095846995, 44.799559593200684, 42.41334669930594, 49.15509693963187, 50.262511253356934, 56.31399965286255, 50.12578112738473, 60.160199301583425, 35.53643315179007, 34.68277399880545, 59.903845514569966, 49.025217737470356, 53.49757514681135, 48.90714005061558, 53.01164245605469, 49.46953419276646, 49.19873857498169, 42.55478770392281, 44.435140473502024, 40.07546200071062, 44.348263672419954, 40.86941875730242, 43.14585358755929, 51.72343601499285, 54.75044999803816, 54.75907966068813, 49.656058583940776, 43.305161884852815, 42.194725104740684, 41.58249153409685, 41.95586340767996, 41.95361566543579, 53.28682238715035, 54.4396709714617, 54.51304742268154, 52.691049098968506, 53.57275812966483, 49.18937587738037, 51.95103815623692, 47.8166480745588, 43.80614784785679, 44.55140815462385, 41.3870803969247, 42.43862077168056, 47.54498740604946, 51.46386521203177, 52.446663584027974, 51.2812283379691, 49.02747242791312, 52.782202516283306, 49.441393988473074, 52.65431744711739, 53.39704860959734, 49.052253178187776, 45.84774398803711, 45.1904513495309, 47.64474616731916, 50.43594871248518, 56.323824405670166, 55.56463990892683, 62.1647059576852, 58.614391871861045, 66.5745747429984, 27.26437517574855, 0.9219287868056978, 7.403461933135986, 4.541019507816859, 0.3890208452939987, 0.26174482916082653, 11.146479095731463, 58.26665537697928, 40.92982986995152, 60.72171797071184, 23.666575363704137, 40.593276500701904, 44.65763916288103, 53.3990010534014, 57.696333340236116, 58.66109766278948, 30.393039567129954, 0.5045990805540765, 0.11624572372862271, 0.19506091810762882, 0.07247634737619332, 0.15704853140882083, 0.1377207599580288, 0.0826482522700514, 0.1518870105168649, 0.2030288598367146, 0.19186457033668244, 0.0950954140030912, 0.09399669617414474, 0.18838901897626265, 0.16471410436289652, 0.06430571366633688, 0.17779475317469665, 0.18018767477146216], [0.005629786814097315, 0.01106110807242138, 0.03368162676425917, 0.025801017581086074, 0.023027127409087758, 0.047794924450239966, 0.05802798231265374, 0.02788670700309532, 0.013604784035123885, 0.04574019827746919, 0.06444570222603423, 0.08062813816858189, 0.02290761873259076, 0.033781629255307574, 0.028489042539149523, 7.503079993384225, 65.47261129106793, 51.745659828186035, 53.52094541277204, 31.546107019696915, 30.346059322357178, 17.328659636633738, 41.667937006269185, 32.439294474465505, 47.031414781297954, 24.53241297176906, 0.16569990717938968, 0.04014683055824467, 0.21252877078950405, 1.154725792152541, 1.0114333097423827, 2.2937812251704077, 10.497303690229144, 63.130908557346885, 57.05109582628523, 65.37309919084821, 57.73371812275478, 65.16708510262626, 63.13542488643101, 49.18838575908116, 53.90122379575457, 61.257034982953755, 53.23449550356184, 54.50045033863613, 50.36473315102713, 51.60163409369332, 42.1069450378418, 40.90026181084769, 39.20874718257359, 42.054840496608186, 47.20333405903408, 50.83487606048584, 51.03276423045567, 54.40632656642369, 56.65924869264875, 53.19214275905064, 53.50483948843819, 50.06893791471209, 50.025091307503835, 52.25023800986153, 51.249370847429546, 51.22742148808071, 50.460673877171104, 42.01829644611904, 39.06994301932198, 46.20732716151646, 49.70106554031372, 53.69410841805594, 50.66423872538975, 44.479226793561665, 38.83493062428066, 37.87377936499459, 36.912239006587434, 35.68604176385062, 36.373830045972554, 33.9681830406189, 38.726406710488455, 35.60379941122872, 36.730651310511995, 36.71381235122681, 39.59681102207729, 39.937713963644846, 46.61284487588065, 49.29459939684187, 50.10154233660017, 47.839111600603374, 53.57813950947353, 32.83708231789725, 30.43286316735404, 56.406532287597656, 44.488624232155935, 48.3462884085519, 45.28645460946219, 49.89571237564087, 47.2554281779698, 47.900554520743235, 44.08228663035801, 42.971297468457905, 37.61750200816563, 39.26688970838274, 38.695879799979075, 36.89530624662127, 40.65195403780256, 46.85892227717808, 45.514730725969585, 43.7128335407802, 38.92116124289376, 37.644544397081646, 37.45093979154314, 38.9059933253697, 36.42266198566982, 44.87123026166643, 50.33679444449288, 51.630847794669016, 50.32785906110491, 50.03751121248518, 44.139407770974294, 42.69871268953596, 40.42638424464634, 39.63754136221749, 38.32712500435965, 38.61156341007778, 38.813623973301475, 37.53060436248779, 42.5981444631304, 44.443346296037944, 43.485283511025564, 45.677273409707205, 45.2099723134722, 44.21102632795061, 44.91583769662039, 42.45047092437744, 39.60183456965855, 39.336736474718364, 41.75112083980015, 45.44233397075108, 48.71040528161185, 51.546861444200786, 52.27966363089425, 53.726500919886995, 55.57074390138899, 57.939610617501394, 45.874588353293284, 1.7690179837601525, 2.444570162466594, 2.6188018875462666, 0.12089238581912858, 0.09256615436502866, 0.4861004246132714, 36.12556743621826, 45.0659396307809, 42.65807267597744, 24.261295999799454, 29.18340335573469, 24.350113085338048, 34.11711767741612, 45.98389393942696, 49.95626940046038, 32.23855059487479, 1.2886848896741867, 0.0976850361164127, 0.03515837341547012, 0.06287558576358215, 0.035704566964081356, 0.11793006477611405, 0.04190757464883583, 0.029392050512667214, 0.03872546932793089, 0.03614077337884477, 0.008482088916935027, 0.02864071207919291, 0.04552194070337074, 0.052536225212471824, 0.04773604796667184, 0.07545203555907522, 0.004594224056095949, 0.03345541336706706, 0.029134526117039577, 0.041672228170292716, 0.03920642173449908, 0.050686352154506106, 0.037872584736240764, 0.013199948838778904, 0.0906249742422785, 0.03860218290771757, 0.02909211428569896, 0.06765096594712564, 0.06869092264345714, 0.03040040104783007, 0.06662943147655044, 0.10712415033153125, 10.346307175500051, 74.89977427891323, 58.33164187840053, 61.99632331303188, 37.63125249317714, 35.653635365622385, 21.972132069723948, 36.389703205653596, 29.328408786228724, 53.34145607267107, 26.82188262258257, 0.17576777908418859, 0.0409975574085755, 0.7454964912363461, 3.5876421970980505, 5.185114911624363, 2.368333876132965, 13.106051751545497, 66.73682907649449, 60.040377616882324, 67.66000843048096, 60.566182545253206, 64.84030437469482, 64.54775742122105, 52.36445597239903, 55.94756555557251, 63.37464441571917, 56.46556765692574, 56.05790294919695, 52.12403440475464, 54.08974231992449, 45.31770413262503, 41.65084791183472, 40.88579566138131, 44.66126959664481, 48.42585917881557, 53.715474128723145, 53.78779445375715, 55.47718293326241, 58.69996588570731, 55.89733007975987, 54.37185307911464, 53.28241375514439, 52.6800605228969, 55.554860319410054, 53.57261221749442, 54.21954161780221, 52.83556120736258, 44.002934728349956, 41.51452425548008, 47.587354046957834, 51.90655926295689, 53.82337965284075, 52.70964247839791, 46.354027952466694, 39.464652810777935, 40.2813058580671, 38.84612417221069, 36.65107706614903, 39.625583512442454, 36.674683570861816, 39.365696566445486, 37.45502185821533, 38.91338273457119, 37.89593022210257, 41.755282810756135, 42.36130121776036, 48.60245112010411, 51.26437200818743, 52.01430497850691, 50.37273052760533, 54.596248626708984, 33.95959159306118, 31.375844887324742, 56.106168610709055, 46.81704895836966, 50.832426820482524, 47.45735672542027, 50.224893706185476, 48.443045548030305, 50.011549268450054, 46.555365903036936, 45.309449672698975, 38.80238873617989, 40.93935237612043, 40.157006059374126, 39.07462610517229, 42.495630741119385, 49.27477618626186, 47.50220387322562, 45.24310827255249, 40.25864083426339, 40.27490309306553, 39.780973025730674, 40.770337445395334, 38.11339841570173, 46.07127101080758, 52.0763315473284, 53.333757468632285, 53.15148537499564, 52.03955473218645, 46.088975020817344, 44.81947660446167, 42.66566358293806, 41.114589418683735, 40.218626158578054, 40.11161000388009, 40.429851395743235, 40.06486252376011, 45.448993819100515, 47.20933730261666, 45.12240069253104, 47.5859192439488, 47.03494446618216, 46.53725889750889, 45.710048062460764, 44.354266916002544, 40.386192389896934, 42.54025207247053, 42.96277550288609, 48.043954917362754, 51.390207358769004, 53.9128793988909, 53.30203546796526, 55.767756598336355, 56.82970537458147, 60.100257192339214, 48.05794511522566, 3.221954162631716, 1.4832073088203157, 5.861114706311907, 0.4141376603926931, 0.09334271055247102, 0.5200233214667865, 37.775118419102256, 51.22756045205252, 36.045854227883474, 25.2545131955828, 36.390474455697195, 29.167509351457866, 37.77611895969936, 50.65443481717791, 58.08316387448992, 41.95715229851859, 2.0977262939725603, 0.0661359600988882, 0.032835137365119796, 0.06107491667249373, 0.04279644873791507, 0.09214221925607749, 0.011662188318691083, 0.01655212217675788, 0.03766494284250906, 0.04202928686780589, 0.030834636318364313, 0.038964099915964265, 0.045217013851340325, 0.023137928784957955, 0.06290331070444413, 0.04468307803784098, 0.04884617875463196, 0.12181915608899933, 0.11383824755570718, 0.14763992412814073, 0.14399737172893115, 0.15801076191876615, 0.0747789763180273, 0.1392836296664817, 0.18060069903731346, 0.11749599235398428, 0.09563044565064566, 0.11796243089650359, 0.16760634630918503, 0.1449319722929171, 0.20040746192846978, 0.14862601192934172, 13.214122295379639, 85.91799136570522, 64.26477813720703, 70.56758635384696, 43.36553130831037, 42.94768401554653, 26.420865603855678, 53.52294996806553, 44.62129661015102, 60.80610384259905, 30.872437477111816, 0.6811572036572865, 0.24801947708640779, 0.7699867742402213, 1.7578623252255576, 4.060892036982945, 5.83988448551723, 11.467355591910225, 70.77805423736572, 62.01759869711739, 71.74832848140171, 61.55447346823556, 66.21916048867362, 60.911917958940776, 54.36461305618286, 58.533202171325684, 64.46084240504673, 58.709269523620605, 59.087529454912456, 54.33226571764265, 56.53684227807181, 46.520454679216655, 42.52677951540266, 42.81275347300938, 45.6117901120867, 49.44223472050258, 56.473040444510325, 55.696231842041016, 58.257862431662424, 58.80992112840925, 58.19407102039882, 58.65906184060233, 57.37851578848702, 55.166327476501465, 57.37775148664202, 56.116174016680034, 56.830264704568044, 54.76734454291207, 45.7069456917899, 42.60927200317383, 50.968361377716064, 53.000344685145784, 55.2175669670105, 54.190737860543386, 48.19243444715227, 41.908994334084646, 42.259485789707725, 41.66441774368286, 40.21199410302298, 40.85002286093575, 37.914620876312256, 43.2092524256025, 39.969578402382986, 40.545531954084126, 40.52681350708008, 44.05126639774868, 42.84391266959054, 49.8687116759164, 54.58978680201939, 54.30150951657976, 50.727783475603374, 54.76445756639753, 36.41536637714931, 33.906628949301584, 58.96414334433419, 48.708859307425364, 53.315699100494385, 49.203466824122835, 53.49034554617745, 51.40317964553833, 52.699505056653706, 48.82868446622576, 47.38296583720616, 42.54048483712332, 42.227510179792134, 42.378793307713096, 40.147837911333355, 44.54576621736799, 52.67661074229649, 49.49350200380598, 48.533181054251536, 42.526296615600586, 42.81767974581037, 42.32667487008231, 42.325917516435894, 39.33739307948521, 49.46651520047869, 54.27655158724104, 56.89121430260794, 54.9277298109872, 53.86158432279314, 48.00638253348214, 47.25585201808384, 46.14585297448294, 43.936742714473176, 43.19579723903111, 41.375667980739046, 42.75865132468087, 42.2181579044887, 47.255348273685996, 48.70241832733154, 49.464479378291536, 50.25416646684919, 50.324152197156636, 47.44147661754063, 49.600104740687776, 46.53758546284267, 44.25050599234444, 45.12278284345354, 46.58489574704851, 49.460046427590505, 55.17335557937622, 56.12595360619681, 57.04402256011963, 57.62761565617153, 59.461655208042686, 59.50929205758231, 53.545823437826975, 3.323038944176265, 7.641515902110508, 11.271150623049055, 0.17427467634635313, 0.3319290445319244, 0.7074315452149936, 44.81320932933262, 60.399849619184224, 56.40963118416922, 32.56425782612392, 39.16176346370152, 33.61783054896763, 46.549008301326204, 58.85195772988455, 67.05853067125592, 48.89262178965977, 2.917074808052608, 0.18239876255393028, 0.12051281332969666, 0.11323884329093353, 0.17110582281436237, 0.17738806642591953, 0.08217084181628057, 0.1674723220723016, 0.13858336795653614, 0.13116389965372427, 0.1265384621386017, 0.09863220314894404, 0.15794037069593156, 0.13436454933668884, 0.15932277723082475, 0.15683290655059473, 0.17687446969960416], [0.04953239478969148, 0.045508929794388156, 0.02918830680261765, 0.020138695436928953, 0.04877627946968589, 0.017320262833631465, 0.019720071560836265, 0.012737651904379683, 0.09300940736596074, 0.0498799438189183, 0.03403658878856471, 0.022097573449302996, 0.04081423081723707, 0.13759912577058586, 0.04952437450577106, 25.45632188660758, 67.37668173653739, 53.4214437348502, 52.412825856889995, 36.469923632485525, 21.771629640034266, 35.32233483450753, 52.918651240212576, 38.67227329526629, 53.574026175907676, 11.56869854245867, 0.5861184405429023, 0.24293060015354837, 0.6707331144383976, 3.2573220133781433, 2.543733984231949, 0.18441283090838365, 45.441354274749756, 58.30463423047747, 59.81216403416225, 55.073381423950195, 60.885042326790945, 56.5994142804827, 57.77831513541085, 61.138602937970845, 47.97791576385498, 52.19305780955723, 54.91324281692505, 51.84695414134434, 53.310081481933594, 52.114418097904746, 48.79786573137556, 40.695967401777, 39.99972663606916, 39.699116298130576, 44.82846409933907, 48.74815484455654, 51.15190151759556, 48.08831916536604, 48.4754866872515, 53.31594923564366, 52.76533229010445, 49.98085560117449, 49.646008014678955, 50.36080741882324, 51.22907863344465, 50.87542574746268, 44.99217060634068, 37.1364677974156, 39.86594254629952, 46.10241283689226, 49.52525527136666, 54.061706338609966, 53.41604151044573, 41.68195499692644, 38.06216934749058, 35.39953974315098, 36.310795988355366, 36.33552115304129, 37.74914605276925, 33.49109540666853, 37.79254102706909, 36.06498956680298, 38.52382155827114, 39.06946011951992, 43.03183364868164, 44.33786916732788, 48.11168943132673, 49.13636459623064, 54.21006774902344, 45.65625858306885, 50.191413811274934, 32.922447885785786, 31.58102866581508, 55.230306489127024, 45.98128489085606, 49.58858462742397, 46.09264019557408, 51.31501395361764, 46.20773363113403, 49.00067670004708, 47.43247175216675, 47.455723898751394, 39.429606097085134, 37.184820311410085, 38.53138814653669, 36.57512978145054, 37.61273554393223, 40.98438017708914, 40.33659962245396, 40.11970465523856, 36.985695362091064, 36.64757864815848, 36.26364551271711, 38.37177760260445, 36.613994530269075, 41.751502990722656, 49.62721313749041, 50.8331424849374, 51.18673631123134, 48.26360484531948, 40.72415624346052, 39.23011984143938, 38.78248562131609, 37.56611660548619, 37.4980103628976, 37.80040986197335, 38.16567318780081, 37.862686565944124, 38.847875118255615, 42.93723045076643, 42.05772052492414, 42.63117272513253, 42.06148992265974, 42.79587977273123, 40.00356204169137, 38.793165002550396, 40.4026665687561, 41.938277517046245, 47.53154958997454, 50.11814158303397, 50.735106876918245, 51.439584732055664, 50.15595020566668, 53.574446541922434, 55.564316817692344, 56.45895644596645, 56.26912818636213, 9.646231872694832, 1.5676014316933495, 3.331877052783966, 0.8837003409862518, 0.1584220491349697, 0.0355651789078755, 14.540937270436968, 44.22216081619263, 27.290041821343557, 30.15921183994838, 25.599758761269705, 24.464317151478358, 27.577351570129395, 41.072636195591514, 45.86932509286063, 42.143259797777446, 8.697570868900844, 0.43599514610001017, 0.08318740941051926, 0.03025950664388282, 0.06263009857918535, 0.05865140671708754, 0.03766902083797114, 0.026578964765316675, 0.023882101888635328, 0.008718399763373392, 0.08153171611151525, 0.05797788607222693, 0.030026229697146585, 0.017073359207383225, 0.03597598097154072, 0.010323979858575123, 0.0506710919019367, 0.02767561306245625, 0.010199639164576573, 0.0814606056415609, 0.037057548827890835, 0.053881227504462004, 0.01811841848705496, 0.019763316293912273, 0.03373660845682025, 0.017254577251151204, 0.027278324023687413, 0.046150148779686005, 0.027726406497614722, 0.0640839005687407, 0.08309096244296857, 0.054726064670830965, 31.84504631587437, 76.1909510748727, 57.838569913591655, 58.94566113608224, 42.48161275046212, 27.180025781903947, 30.81244673047747, 47.22021470751081, 38.50156300408499, 60.98881367274693, 12.57237104007176, 0.5307415149041584, 0.05424260847004397, 1.9557274792875563, 5.517072916030884, 3.0030214190483093, 0.15907509837831768, 49.1738292830331, 61.53087738582066, 60.16889844621931, 59.487683159964426, 62.17126505715506, 59.236359868730815, 56.773195675441194, 61.83760561261858, 51.53842633111136, 54.33981840951102, 56.5335488319397, 54.39761005129133, 55.42571415219988, 53.33515405654907, 52.02049582345145, 41.84283011300223, 41.82684925624302, 40.10779544285366, 46.73461205618722, 50.18587957109724, 51.55076633180891, 51.433352197919575, 49.66747794832502, 54.02514491762434, 54.17192908695766, 52.57682418823242, 50.90281902040754, 52.140553746904644, 52.68741866520473, 53.076889514923096, 48.01601273672921, 39.2995879309518, 41.82078000477382, 48.4095378603254, 52.05780764988491, 55.205154010227744, 54.882642950330464, 44.09468569074358, 39.00504684448242, 37.51705884933472, 38.36058752877371, 38.22734192439488, 39.43621383394514, 36.552992820739746, 38.04634482519967, 37.405998843056814, 40.54245390210833, 41.30485194069998, 45.464710644313264, 47.571543421064106, 51.10147844042097, 51.77518967219761, 54.5661038671221, 47.62914398738316, 48.94672393798828, 33.43275138310024, 32.707679067339214, 55.947190352848594, 49.35035869053432, 50.83044310978481, 48.67650849478585, 53.353052616119385, 48.16584021704537, 51.295840399605886, 49.94817474910191, 49.980490820748464, 40.92582423346383, 40.057045800345286, 40.50674016135079, 37.72558123724801, 39.329395702907014, 42.31601285934448, 42.643988677433555, 41.70352567945208, 39.38886186054775, 37.89603444508144, 36.94333219528198, 41.03992060252598, 38.881678104400635, 43.525520529065815, 52.46142503193447, 51.46205868039812, 54.42781734466553, 51.4998117174421, 42.817182949611116, 40.83139821461269, 40.32990503311157, 38.60967002596174, 39.229932240077424, 40.12669106892177, 40.50680616923741, 39.24773699896676, 41.054372855595176, 44.23672424043928, 42.996370043073384, 43.761929512023926, 44.28928736277989, 45.49488319669451, 42.26574959073748, 40.91520043781826, 42.304927008492605, 44.55909286226545, 49.220052174159456, 52.932353087833945, 53.179542200905935, 52.5470198903765, 52.25298254830496, 55.39658382960728, 56.87002924510411, 58.27175882884434, 58.475511278424946, 12.536605187824794, 1.4816594890185764, 2.57803333231381, 2.635495586054666, 0.204864894172975, 0.07512901896344763, 14.648341655731201, 50.45794323512486, 28.321529694965907, 29.541659423283168, 29.900787489754812, 32.06218794413975, 33.94405542101179, 47.44971718106951, 50.651113578251426, 51.46089138303484, 13.351806930133275, 0.6372013794524329, 0.03926331689581275, 0.012511104328690894, 0.01598549115338496, 0.03246347998668041, 0.013429538795857556, 0.04033244041992085, 0.00659708640471633, 0.05663521794070091, 0.04686262411996722, 0.008677551955250757, 0.023729892913252115, 0.0381116326233106, 0.023170462842764597, 0.019791875832847187, 0.030833255499601364, 0.14559104692723068, 0.12197113436247621, 0.20259610377252102, 0.08926394834582295, 0.13739048982305185, 0.07441169209778309, 0.1100841982822333, 0.13232008261340006, 0.27953083334224565, 0.12155042908021382, 0.14527513459324837, 0.09530853506709848, 0.15100437216460705, 0.19146213121712208, 0.10209830251655408, 38.058615343911306, 82.78065735953194, 66.58827659061977, 67.36981691632951, 47.920551436288015, 30.74695995875767, 45.325649397713796, 68.25055667332241, 54.00134038925171, 66.0499301637922, 15.130958318710327, 0.8006142164979662, 0.37329294638974325, 1.867642125913075, 5.86287260055542, 6.923943298203604, 0.39232935490352766, 49.42008038929531, 63.938761711120605, 63.90230451311384, 60.92376463753836, 64.99078151157924, 61.696897642953054, 58.45086601802281, 58.783531870160786, 55.30114337376186, 55.74121447971889, 59.13106686728341, 55.140386377062114, 58.97969341278076, 56.574991362435476, 54.17847081593105, 43.303695814950125, 43.8325822693961, 42.67087125778198, 48.620860372270855, 53.00760555267334, 55.21404423032488, 52.19575718470982, 52.700773102896555, 57.454511710575645, 55.96032244818551, 54.31020518711635, 54.20872674669538, 55.27119663783482, 55.13350766045706, 55.73209496906826, 51.04041419710432, 40.88684136526925, 43.04330859865461, 49.34127392087664, 54.87199483598982, 57.34555353437151, 55.83331980024065, 46.95049606050764, 41.6744509424482, 38.735283034188406, 40.9628199168614, 40.711183956691194, 42.05654280526297, 37.669748987470356, 41.439191886356895, 39.68141228812081, 43.441381318228586, 43.60680750438145, 48.28800344467163, 49.58497156415667, 53.116324016026084, 53.48124688012259, 57.212745666503906, 49.48263502120972, 51.13645914622715, 35.32617718832833, 36.675006662096294, 56.9438191141401, 51.306523254939485, 51.823642935071675, 49.51384285518101, 54.695385524204795, 48.68052107947213, 53.448586872645784, 52.01616014753069, 51.28580720084054, 43.61853953770229, 41.162462506975444, 43.10126352310181, 39.87455136435372, 42.925338608878, 44.48105069569179, 45.682220527103965, 43.93363339560372, 41.79539476122175, 39.96302972521101, 38.84678425107683, 42.87569372994559, 39.6927934374128, 45.75997086933681, 55.971192904881065, 54.415741375514436, 57.03663315091814, 53.7567012650626, 44.78096273967198, 43.748679297310964, 42.50915193557739, 41.0895585332598, 41.51107447487967, 40.938574177878245, 42.225915568215505, 39.81378936767578, 43.76071357727051, 46.34724651064192, 45.829303468976704, 45.75967557089669, 47.433051926749094, 46.778361388615195, 45.163405486515586, 43.11699424471174, 45.660364968436106, 46.539138385227744, 53.17646414893014, 54.02961955751692, 55.324273926871165, 55.57125806808472, 55.45054701396397, 57.597092219761436, 59.88746861049107, 61.65725816999163, 60.44727802276611, 16.338923488344463, 4.463722969804492, 11.03845545223781, 3.1736628796373094, 0.47309269117457525, 0.13410923017987184, 16.687419073922293, 57.927948066166465, 37.507435594286235, 41.14875718525478, 32.193161487579346, 34.65889304024832, 40.58411182676043, 56.98199251719883, 56.409454005105154, 59.246580668858115, 17.07010153361729, 0.766204945743084, 0.2385915315576962, 0.09965712350926229, 0.09412687990282263, 0.29873351007699966, 0.10219886140631777, 0.10129156509148222, 0.14754273077206953, 0.13847702794841357, 0.13820570893585682, 0.17245042137801647, 0.1622873374394008, 0.09411162643560342, 0.15981299164039747, 0.08908716961741447, 0.13301545887121133], [0.025008931423404386, 0.08402025007775851, 0.06801814160176686, 0.03201781140108194, 0.06835522422833101, 0.06811066663690976, 0.04230975253241403, 0.049966870940157344, 0.04577403681884919, 0.05397806802232351, 0.04376385647005268, 0.1472493458007063, 0.049720097931900194, 0.01615124538407794, 0.43287909616317066, 47.17323098863874, 55.46997765132359, 53.52799436024257, 49.47577714920044, 34.50553934914725, 21.6759512083871, 40.02502850123814, 34.561788490840364, 37.19700397763933, 47.71247720718384, 2.447356390101569, 0.27599835289376123, 0.43928723516208784, 1.9606819791453225, 13.786631277629308, 6.453358309609549, 5.145686055932726, 66.51668930053711, 53.29362119947161, 62.834963934762136, 49.467814513615195, 57.484312534332275, 56.62425409044538, 61.80415003640311, 54.771054880959646, 64.82285744803292, 48.76977069037301, 60.479712213788716, 51.33852318355015, 54.21185343606131, 49.554691314697266, 53.03440475463867, 45.19145883832659, 39.8363675389971, 38.77189656666347, 41.56100075585501, 43.97321033477783, 44.32098504475185, 40.12692035947527, 42.823950495038716, 42.61468812397548, 46.32570709500994, 47.77896451950073, 49.90057264055525, 48.40979494367327, 49.051704270499094, 42.75482286725725, 39.15457902635847, 37.15517929622105, 40.419783455984934, 47.12728949955532, 49.64160285677229, 49.45354986190796, 50.160803522382466, 39.573892389025005, 38.09349530083792, 35.72591747556414, 36.79575593130929, 35.55069432939802, 36.945590359824045, 34.91464580808367, 36.03389637810843, 37.323103359767366, 41.28007466452462, 43.781867367880686, 44.19172770636422, 45.1569367136274, 52.237182344709126, 49.00807653154646, 54.685175146375386, 45.61093200956072, 49.621790068490164, 33.95646142959595, 34.053975922720774, 52.88947922842843, 45.89074986321585, 50.6662015914917, 47.97910737991333, 48.76094300406319, 45.10451602935791, 47.293858664376394, 49.12051575524466, 47.9500778062003, 46.717588969639365, 38.828322887420654, 37.63226693017142, 38.147006852286204, 36.17206130708967, 36.91890927723476, 37.608538831983296, 39.00983762741089, 37.29462616784232, 37.15146548407418, 36.67040695462908, 37.124131270817344, 37.31498438971383, 38.22088704790388, 44.927580152239116, 47.951953819819856, 48.91825369426182, 45.97297484534127, 37.44567653111049, 38.24877364294869, 39.13056605202811, 37.52918692997524, 37.77880096435547, 38.05223689760481, 38.573195457458496, 37.09027964728219, 40.29489653451102, 41.55129064832415, 37.35695498330252, 40.42353548322405, 39.53292581013271, 39.08218921933855, 38.24998957770211, 38.67557716369629, 39.60396766662598, 46.50979961667742, 46.006492955344065, 50.29916647502354, 51.38527761186872, 52.35067769459316, 53.68358537128994, 54.20869895390102, 51.462173325674875, 54.598923683166504, 57.461348737989155, 26.853451762880596, 1.4493401604039329, 2.6167877784797122, 3.287216420684542, 0.12100274275456156, 0.032701055452759774, 2.0428261884621213, 47.53894942147391, 43.48715952464512, 36.16062804630825, 26.048723561423166, 14.914063351494924, 23.257557494299753, 44.676222120012554, 45.537430490766255, 47.48514951978411, 24.164544071469987, 1.565367694411959, 0.12354031444660254, 0.04489064868539572, 0.048229682192738564, 0.06969703401305846, 0.04336772772616573, 0.03173906243007098, 0.00595461085738082, 0.03470386351857867, 0.023503289358424287, 0.016557229849110757, 0.036243825884802, 0.03748562978580594, 0.005343048093241772, 0.012599089964559036, 0.01891706438202943, 0.03357986347483737, 0.012716526564742838, 0.032776335520403724, 0.04345200177548187, 0.1080560978235943, 0.008784895347032164, 0.0596188415906259, 0.07820857050163404, 0.0779184764251113, 0.020609856583178043, 0.0673711041786841, 0.08085242113364594, 0.067904805897602, 0.007128427669938121, 1.6777878105640411, 57.05711644036429, 63.290460041591096, 60.16333293914795, 54.755584716796875, 39.350827421460835, 26.8207083770207, 33.66529369354248, 32.904490266527446, 41.4575629234314, 54.887548378535676, 2.0626014130456105, 0.11613012850284576, 0.266599638653653, 2.5043374810900008, 11.118343234062195, 4.807364370141711, 7.3803357226508, 68.71791335514614, 57.22257389341082, 63.98072188241141, 53.53768709727696, 58.553991181509836, 59.9180337360927, 63.256907190595356, 54.34882327488491, 65.46845626831055, 53.073964323316304, 60.137020111083984, 53.710346358163015, 55.553178855351035, 50.98660387311663, 54.978281429835725, 46.03378895350865, 40.42427199227469, 41.56880010877337, 42.82856062480381, 45.76165233339582, 46.0867793900626, 43.16314765385219, 43.66741664069039, 44.49681615829468, 48.71361187526158, 49.478080477033345, 51.10187448774065, 50.655814034598215, 52.458128111703054, 45.87960842677525, 41.075776781354634, 39.51666007723127, 42.30838026319231, 49.159571579524446, 52.66717161451067, 51.72555521556309, 52.192658288138254, 41.79469646726336, 39.909876005990164, 38.589419501168386, 39.024609497615266, 37.74597420011248, 39.46500716890608, 37.28438452311924, 37.82037203652518, 38.45422145298549, 42.44549254008702, 45.34385715212141, 46.7635235105242, 48.04687316077096, 53.40028994424002, 51.68411268506731, 56.03681516647339, 46.101068360464915, 50.25465978894915, 34.67785814830235, 36.099939005715505, 55.101935046059744, 48.25773361751011, 52.34978832517351, 49.2394689151219, 51.692089217049734, 46.248432704380576, 48.15159640993391, 49.86841985157558, 50.572188990456716, 47.765512807028635, 39.81001649584089, 38.58536522729056, 40.12431131090437, 37.82893221718924, 37.737723214285715, 40.36552149908883, 39.81840991973877, 38.00568049294608, 40.34545857565743, 37.47461230414254, 39.56710399900164, 39.37478828430176, 41.02704211643764, 47.527884415217805, 49.19246782575335, 52.53152193341936, 48.03857353755406, 40.47707830156599, 41.354350907461985, 40.0414331981114, 40.06271205629621, 39.491330419267925, 40.13674511228289, 40.23359605244228, 38.88172674179077, 42.05810962404524, 42.247128418513704, 39.78709438868931, 41.724457127707346, 39.75329835074288, 41.225062302180696, 40.38351385934012, 40.10196590423584, 42.30489226749965, 48.2135500226702, 48.96283333642142, 53.155960014888215, 52.41470187050955, 54.972365038735525, 55.06600591114589, 56.522080830165315, 55.169141496930806, 56.873836857931956, 59.53142901829311, 30.12351199558803, 1.0718258576733726, 3.435895928314754, 4.706984179360526, 0.4905570426157543, 0.08832621295005083, 1.934680300099509, 50.98085771288191, 44.79192352294922, 28.198143584387644, 28.51831831250872, 19.714334045137676, 27.837726627077373, 48.961474963596885, 50.22854845864432, 55.134014878954204, 34.59422615596226, 2.0516475779669623, 0.10090649646839925, 0.004453003955339747, 0.020617066017751182, 0.04911738920158573, 0.025411594459520917, 0.039709277251469235, 0.0511895367609603, 0.025922293841306652, 0.0007370622157135845, 0.05402012023010424, 0.02348967455327511, 0.02216153385649834, 0.03784849335040365, 0.06875862008226769, 0.06148043634103877, 0.1429781171360186, 0.1400959582201072, 0.12479681202343532, 0.07355614764881985, 0.16001702712050506, 0.13479212139333996, 0.1123061833371009, 0.11014612817338534, 0.13729412427970342, 0.2596442475914955, 0.12825341868613446, 0.22663913720420428, 0.17915134823748044, 0.09651868191680738, 2.8630102234227315, 66.3612928390503, 68.08263955797467, 68.60950061253139, 61.72669846670968, 45.33620718547276, 30.980370794023784, 53.399136543273926, 47.295633929116384, 50.91887978145054, 57.29494980403355, 3.6092582600457326, 0.41822531819343567, 1.0753739987100874, 2.6907989042145863, 28.754654339381627, 13.902925883020673, 5.783163734844752, 73.38868699754987, 58.80629416874477, 67.97130162375313, 53.862657819475444, 64.1087702342442, 61.64453601837158, 67.67805985042027, 54.71710211890084, 63.49072796957833, 53.23827879769461, 62.52704756600516, 54.10313149860927, 57.81112105505807, 52.76179218292236, 57.17327989850725, 49.3693585395813, 43.40579611914498, 43.937145709991455, 45.66788986751011, 49.21255506787981, 48.02345773151943, 45.20320476804461, 45.793304852076936, 46.41565152576992, 50.33151381356375, 51.97336619240897, 54.19563634055001, 52.23729004178728, 54.84557778494698, 45.86656665802002, 42.663419314793174, 42.40493243081229, 44.30694273539952, 51.6275508744376, 53.80938250677926, 54.82501459121704, 54.41529669080462, 44.28395462036133, 42.2169315474374, 41.41209738595145, 40.11102635519845, 39.65351179667881, 42.007068157196045, 39.52337898526873, 39.954306261880056, 41.47741740090506, 44.954813616616384, 46.853325503213064, 47.992315905434744, 50.680038928985596, 56.52117756434849, 54.39674847466605, 59.641203607831685, 47.27461910247803, 49.692397662571494, 36.14649541037423, 38.3853439603533, 57.110374382564, 50.332271167210166, 53.71530737195696, 51.62335416248867, 52.573954582214355, 47.2406702041626, 48.36373880931309, 51.20831741605486, 52.459423950740266, 50.03782388142177, 43.09195293698992, 41.50509554999215, 42.092339924403596, 40.868452957698274, 40.311659063611714, 41.118053095681326, 43.49694258826119, 39.59488637106759, 43.407894475119456, 39.752711227961946, 40.039216722760884, 41.413125719342915, 42.95635189328875, 49.7817063331604, 51.394119194575715, 54.58791773659842, 50.57608345576695, 42.20637375967843, 42.105614457811626, 42.189437525612966, 41.60018859590803, 41.862705435071675, 42.23216894694737, 43.245219775608604, 40.33935110909598, 44.06899472645351, 45.617025579724995, 42.02112783704485, 45.29331248147147, 42.40400832039969, 42.4056967326573, 42.54550838470459, 42.89693784713745, 43.39376531328474, 51.47741767338344, 49.81003066471645, 56.249200752803254, 55.20062378474644, 58.335956709725515, 55.09757505144392, 58.8621437890189, 57.83394588742937, 60.58103779384068, 60.659601075308665, 34.86440338407244, 2.1613969802856445, 10.45324603148869, 10.580350296837942, 0.36666154222829, 0.1772751717695168, 3.0207814489092146, 59.47696903773716, 55.291815417153494, 49.63419607707432, 30.116904258728027, 21.600233214242117, 31.694131442478724, 57.6344770022801, 57.6702880178179, 62.95618915557861, 41.48961843763079, 2.717288694211415, 0.24158908213887895, 0.09334965875106198, 0.1236855209405933, 0.11076225154101849, 0.10103093979081937, 0.0911854984504836, 0.09814135091645376, 0.1163999547383615, 0.08836600224354438, 0.18324729773615087, 0.08849951757916383, 0.14961332109357628, 0.23357919337494032, 0.1240459316010986, 0.1770366667104619], [0.06756867322006396, 0.01579040046116071, 0.014963561436161399, 0.021901166399142573, 0.03959172445216349, 0.032454865984618664, 0.027927252863134657, 0.04258647946906941, 0.04064409155398607, 0.005042082613467106, 0.05177850176447204, 0.018754358469907726, 0.03509685743067946, 0.03331400666918073, 7.128276790891375, 60.997464179992676, 57.44326605115618, 55.07379136766706, 41.05168737683977, 24.73764365059989, 11.373117174421038, 26.762159381593975, 37.05270378930228, 49.880179677690776, 34.051505838121685, 0.17784128710627556, 0.036468651677880964, 0.20327362098864146, 2.5312302666051045, 5.2175308636256625, 0.11620616513703551, 26.58757025854928, 62.91680676596505, 57.222740650177, 61.08059242793492, 47.30982562473842, 50.395881925310405, 52.72091245651245, 58.8584542955671, 54.29989753450666, 55.663755961826865, 58.759741238185335, 55.02136026109968, 53.62353556496756, 53.64538764953613, 52.779527459825786, 53.2066262790135, 49.46109560557774, 42.30465602874756, 38.48452254704067, 39.92398084912981, 38.876779624394004, 38.24863815307617, 38.00199099949428, 38.46607160568237, 39.57992689950125, 39.46667126246861, 39.244391441345215, 40.29261057717459, 42.52600826535906, 41.42671292168753, 38.562363215855186, 36.96602153778076, 37.85445989881243, 38.77343211855207, 43.40164804458618, 47.956060205187114, 46.70241410391671, 41.47620841435024, 35.63107109069824, 37.07338857650757, 36.003237451825825, 38.6392936706543, 36.10435111182076, 36.404134614127024, 35.73312275750296, 36.02185862404959, 38.66930641446795, 45.2886780330113, 45.70808867045811, 47.13891036169869, 45.92271157673427, 50.542113712855745, 49.26801906313215, 50.8479768889291, 45.929986340659006, 51.27158423832485, 33.696800300053184, 29.859080927712576, 50.543812547411235, 45.92987516948155, 49.27517570768084, 46.1336658341544, 48.04688705716814, 46.117139543805806, 47.46124424253191, 47.87373794828142, 48.718857765197754, 48.432463441576274, 44.58540916442871, 35.312180042266846, 37.24333109174456, 38.18791784558977, 36.911561557224815, 35.84251867021833, 37.765498638153076, 36.64522320883614, 36.568984099796836, 35.98192037854876, 37.75846358707973, 37.82909549985613, 36.79988316127232, 40.469296319144114, 45.36098098754883, 45.802462577819824, 40.70423575810024, 39.027506896427695, 38.69805111203875, 37.64261279787336, 36.78945391518729, 37.52936410903931, 39.3848249571664, 38.26895815985543, 38.73057562964303, 39.454355580466135, 37.282737800053184, 38.52470745359148, 39.33049004418509, 39.42457560130528, 39.2185823576791, 38.967488356998985, 40.13237816946847, 45.638429505484446, 46.79063885552542, 51.747442041124614, 52.866195814950125, 55.79305151530674, 53.105658531188965, 52.77797106334141, 50.14684459141323, 55.536155768803184, 56.58699090140206, 55.89498853683472, 41.877084732055664, 4.138542064598628, 2.3660440104348317, 2.1175768630845204, 0.47437810791390284, 0.06754273961165122, 0.09377692546695471, 19.919526508876256, 45.722627776009695, 37.62701409203665, 20.669987542288645, 14.312146987233843, 20.927857773644583, 26.86976613317217, 45.78607177734375, 43.343863351004465, 48.834260395595, 11.464752623013087, 0.16011397620396955, 0.07501461117395333, 0.07346694064991814, 0.008426132678453411, 0.028112246954281415, 0.047446849556373696, 0.011219889507628977, 0.02860764367505908, 0.08790975529700518, 0.01906354312918016, 0.05452979163133672, 0.035568615687744956, 0.08547515807939426, 0.04034425710727062, 0.06485236861876079, 0.04892496006297214, 0.01816600584425032, 0.032966162477220805, 0.06579393095203809, 0.060958011874130795, 0.07916595627154623, 0.03362616331183484, 0.013371781895070203, 0.014176567683794668, 0.05685535505680101, 0.03059204647849713, 0.02858653784330402, 0.009230772582148867, 0.11946586093732289, 10.202806898525782, 71.7265111378261, 61.75572109222412, 59.561188152858186, 47.517524651118684, 31.822645323617117, 16.022537265505107, 30.497297286987305, 32.65660980769566, 57.6108843939645, 37.67725304194859, 0.13366607895919255, 0.03772951562755874, 0.27124866204602377, 4.991786931242261, 1.1469618316207613, 0.1737489067018032, 29.421330520084926, 65.0775089263916, 59.36785452706473, 63.35200023651123, 49.02505792890276, 52.526216983795166, 56.065976755959646, 60.05767863137381, 55.99573046820504, 54.65489489691598, 59.378381047930034, 56.84058625357491, 55.11655752999442, 56.48648868288313, 55.860369137355256, 54.960702487400596, 52.1655672618321, 44.171418121882844, 41.06726871218, 41.42426020758492, 41.31585093906948, 40.54534782682146, 41.65357160568237, 39.7678131375994, 40.53310857500349, 41.6158116204398, 40.89674602236067, 43.28770106179373, 42.536500045231406, 43.45583357129778, 40.192403657095774, 39.71780347824097, 38.710474491119385, 39.823231969560894, 45.75746604374477, 49.129267011369976, 49.83108023234776, 43.74856465203421, 37.89162233897618, 39.396556990487234, 38.27226202828543, 40.8553694997515, 38.90162985665457, 39.69608340944563, 36.7074373790196, 37.93309266226632, 40.498777525765554, 46.705773557935444, 46.89352083206177, 48.38842575890677, 48.75718750272478, 50.84913723809378, 51.3797607421875, 52.68360410417829, 47.5623995917184, 52.212742056165425, 34.329034260341096, 33.186277934483115, 52.15694107328142, 48.35352495738438, 51.10379219055176, 47.060451303209575, 48.90238748277937, 47.25666495731899, 48.09469066347395, 48.1308525630406, 52.170114857809885, 48.29618494851248, 44.627018451690674, 37.40266023363386, 39.05020318712507, 39.778589793613975, 38.60742228371756, 36.60784190041678, 38.47222076143537, 38.625682149614605, 38.409930161067415, 38.34817804609026, 38.53278126035418, 39.33457905905587, 39.87263713564192, 42.37536784580776, 48.00161954334804, 47.583331039973665, 42.920297690800254, 40.76576900482178, 40.541078158787315, 39.11510631016323, 37.41482652936663, 40.61555242538452, 39.90965018953596, 40.43202270780291, 39.74445676803589, 40.418265274592805, 38.41804565702166, 38.73628010068621, 40.83883278710501, 41.67403752463204, 41.818438461848665, 40.663154533931184, 42.74970899309431, 47.09039109093802, 50.21977635792324, 55.18745347431728, 57.228987080710276, 56.41575602122715, 55.662154402051655, 53.553386551993235, 53.52307503564017, 55.52893311636788, 58.46959836142403, 55.00461857659476, 45.29778364726475, 6.641308384282248, 0.45087479480675285, 4.210996142455509, 1.1942823209932871, 0.06736908892967872, 0.09281350073537656, 19.255353416715348, 54.983384881700786, 34.15478733607701, 22.604465041841777, 18.182204144341604, 27.796907697405132, 33.246623039245605, 49.624374798366, 48.64699602127075, 58.15287862505232, 18.06114046914237, 0.3032441937497684, 0.01854111866227218, 0.05668393675503986, 0.03553878728832517, 0.01165204422016229, 0.030550954397767782, 0.028265982633456588, 0.04764076129400304, 0.03533661099416869, 0.08747681602835655, 0.07459274559680905, 0.03020217382748212, 0.03613798799259322, 0.048975107193525345, 0.015928066734756743, 0.1486142189907176, 0.24506622127124242, 0.09399938995816878, 0.1187604016491345, 0.14084792429847376, 0.14205547235906124, 0.16098613797553948, 0.10903456567653588, 0.13460636564663478, 0.15377791119473322, 0.17895929568580218, 0.12141559060130801, 0.21045358000057085, 0.1175627059170178, 13.233774406569344, 79.35451453072685, 69.83266844068254, 70.80533981323242, 56.640179361615864, 36.36959511893136, 18.20627096721104, 39.2873660496303, 50.899219853537424, 64.72793810708183, 43.429621492113384, 0.3035441333694117, 0.175884446395295, 0.7210277042218617, 7.3336012704031805, 16.50595644542149, 1.9108985705035073, 30.221179349081858, 67.16391399928501, 62.517646653311594, 66.20674405779157, 51.17805453709194, 53.15832240240914, 57.77427128383091, 61.52797998700823, 57.505296094076975, 55.337899344308035, 57.670625005449565, 60.004566601344514, 56.82734646115984, 58.168696199144634, 56.54185192925589, 57.9705023084368, 55.43288121904646, 47.36628321238926, 42.60905660901751, 43.45084476470947, 42.971373898642405, 42.56051996776036, 42.755826881953645, 41.74466596330915, 43.48558228356497, 43.194438866206575, 43.202012402670725, 45.08320243018014, 45.59200859069824, 44.96911995751517, 42.59068904604231, 41.540732860565186, 41.118369238717214, 41.27453000204903, 47.50842598506382, 52.955719879695344, 52.305722849709646, 45.32676805768694, 38.46377175194876, 41.40794931139265, 40.50598628180367, 42.578630447387695, 40.077195576259065, 41.503539153507774, 38.40477807181222, 39.52871172768729, 42.814139638628276, 48.555276325770784, 50.15056882585798, 50.178816727229524, 50.49574490955898, 53.22589710780552, 53.02672004699707, 54.59442472457886, 49.52961874008179, 52.43402133669172, 38.02412101200649, 35.53872953142439, 54.91806834084647, 49.5734167098999, 52.118138858250205, 48.67971856253487, 50.77802242551531, 49.76602077484131, 49.34639821733747, 51.105966976710725, 53.87948983056204, 50.56745726721627, 47.83722516468593, 37.469592230660574, 41.50609956468855, 41.92951583862305, 41.21428912026541, 38.390655858176096, 42.410709857940674, 40.15212147576468, 40.30946690695626, 40.47049140930176, 41.01107863017491, 40.96222584588187, 41.56123004640852, 45.178017548152376, 49.95930923734392, 50.254930768694194, 44.45026322773525, 42.077033042907715, 41.67862680980137, 41.39363949639456, 40.26924378531319, 42.477537631988525, 42.61440324783325, 42.576090880802695, 42.04957028797695, 42.58432797023228, 41.63872330529349, 40.75052465711321, 43.14320979799543, 44.72462327139718, 43.801047870091026, 41.34881666728428, 44.52945532117571, 49.7269788469587, 51.8580538885934, 57.88832596370152, 58.24728032520839, 59.60846369607108, 57.31273719242641, 56.41005849838257, 56.84577655792236, 58.64538083757673, 61.914786202566965, 58.22944777352469, 48.124494961329866, 7.871073961257935, 5.634844882147653, 11.063045127051216, 1.087252704160554, 0.23318648444754736, 0.13227111952645437, 23.27479076385498, 60.59942272731236, 52.41776602608817, 28.228446415492467, 19.416400500706263, 31.217696939195903, 37.115842069898335, 59.46093259538923, 56.45778567450387, 67.8618744441441, 21.49340292385646, 0.38622080268604414, 0.2056524154863187, 0.23444823388542446, 0.22155165805348329, 0.09690928060029234, 0.16528328667793954, 0.10033858301384108, 0.11028722953051329, 0.2163846953106778, 0.14531127336834157, 0.12583596126309463, 0.14299841890377657, 0.1600882461560624, 0.12033226873193469, 0.13763497956097126], [0.08843999648732798, 0.054466494492122104, 0.0110828983763765, 0.03034886292048863, 0.10427823197096586, 0.05157493108085223, 0.05268144527716296, 0.04855721443891525, 0.011954196712135204, 0.040192886122635434, 0.04258983821741172, 0.009873840575372534, 0.09742090278970343, 0.031511739628123384, 23.71742228099278, 62.652149881635395, 56.393195220402305, 58.86693804604666, 38.701566900525776, 24.22520010811942, 24.952190126691544, 30.752997943333217, 33.61066000802176, 56.181740692683626, 17.535886185509817, 0.4590507618018559, 0.5661752649715969, 0.6541885307856968, 3.1415461344378333, 1.8026966622897556, 0.7817196760858808, 52.29176044464111, 54.67083059038435, 62.3414820262364, 54.262127126966206, 50.77760553359985, 42.3268346786499, 55.99195064817156, 55.502276352473665, 58.02366992405483, 54.41928495679583, 52.03422198976789, 52.371984345572336, 54.56596837724958, 53.606373514447895, 55.51209415708269, 52.39885302952358, 52.22314698355538, 45.719376019069124, 41.30512292044503, 39.88355622972761, 39.25599145889282, 39.37735216958182, 39.742573806217735, 39.4505375453404, 38.87084238869803, 38.54346758978707, 38.640398434230256, 37.47399738856724, 37.86272825513567, 37.93786954879761, 38.80408409663609, 37.96538094111851, 37.9210444859096, 38.44180849620274, 35.54331186839512, 37.83121470042637, 36.98127283368792, 37.589028290339876, 36.92125429425921, 35.77447148731777, 38.47833865029471, 37.379064151218955, 36.470378739493235, 38.020101479121614, 37.171709060668945, 37.11570658002581, 40.28808382579258, 47.42372744424002, 45.942461831229075, 48.32458223615374, 47.56382049833025, 51.46864209856306, 47.95655352728707, 51.246000971112935, 45.15406363351004, 50.11831876209804, 31.562018394470215, 28.975587947028025, 51.04086583001273, 47.009607860020225, 47.76938990184239, 46.68279586519514, 48.7911433492388, 46.29447841644287, 48.00143541608538, 44.16923986162458, 48.10468564714704, 49.11402266366141, 48.226539679935996, 40.72643525259835, 35.430893489292686, 38.49503517150879, 37.187880992889404, 34.74485962731497, 35.899160385131836, 36.461571897779194, 36.39163133076259, 35.984234128679546, 36.929647718157085, 36.67087943213326, 37.46875844682966, 37.18666158403669, 40.08341073989868, 39.063112940107075, 38.16159112112862, 37.2363794190543, 39.97076654434204, 36.84580727985927, 37.69677747998919, 37.73392602375576, 38.536766052246094, 36.684185232434956, 38.0432459286281, 37.68701526096889, 38.107259682246614, 38.35758590698242, 39.77205501283918, 38.40293332508632, 37.15269531522478, 38.89102690560477, 44.532887731279644, 48.24252053669521, 51.19943414415632, 48.612842151096885, 50.90780087879726, 49.41634920665196, 51.16196598325457, 53.469271659851074, 54.96647991452898, 54.79278884615217, 54.28017854690552, 51.33569526672363, 55.839065960475374, 28.215279579162598, 2.777320695774896, 2.6103166171482632, 2.5886838350977217, 0.126163300126791, 0.07997011526354722, 3.682120978832245, 47.59632764543806, 35.66848366601126, 38.091612339019775, 18.2166394165584, 10.143042836870466, 27.00434752873012, 45.833521025521414, 46.594887256622314, 48.82476568222046, 33.49146713529314, 1.274347173316138, 0.0712244909788881, 0.028657560103705952, 0.09177916230899946, 0.022118619909243922, 0.028045647045863525, 0.039902283144848685, 0.1204388394419636, 0.08598140627145767, 0.06842058750667743, 0.05982699577829667, 0.01679831843024918, 0.029200439008751085, 0.029027840056057488, 0.029056375846266747, 0.03667887879003372, 0.024203009936692457, 0.008072244435814875, 0.03023127280175686, 0.03250066709837743, 0.0614769079589418, 0.05527118952678783, 0.03446574183180928, 0.007655984406093401, 0.03671831524531756, 0.06913308998835938, 0.011708667119299727, 0.09575929266533681, 0.04105704118098531, 29.4527085849217, 71.22219003949846, 62.74032252175467, 65.49269158499581, 44.26585456303188, 26.453068767275127, 18.293086971555436, 31.264194284166607, 37.29911470413208, 62.397852761404856, 19.268414293016704, 0.36714788898825645, 0.6221749229090554, 1.651001202208655, 6.307862596852439, 1.9307778009346552, 1.460247095142092, 57.21464252471924, 59.8972099849156, 64.11928980691093, 56.85658795492989, 53.52518033981323, 44.32556390762329, 56.726719175066265, 56.89676243918282, 60.32130718231201, 57.40396009172712, 52.569306237357004, 53.13684899466378, 55.30838687079293, 53.91984496797834, 57.002618244716096, 55.79232195445469, 53.50261606488909, 47.592645100184846, 41.84616872242519, 40.78761761529105, 41.94274173464094, 41.556098801749094, 40.170982360839844, 41.05102382387434, 39.43351098469326, 39.736212730407715, 40.63367680140904, 38.196022919246126, 39.06689623423985, 40.437612533569336, 39.69714995792934, 39.390248026166645, 39.50943047659737, 39.94736153738839, 38.583708081926616, 41.612309728349956, 38.594752243586946, 38.679853779929026, 38.12888595036098, 38.2946560723441, 40.287142344883506, 38.48521041870117, 39.43979563031878, 40.12184817450387, 37.82514544895717, 37.619478770664756, 41.85513537270682, 48.4402836390904, 48.28114209856306, 50.65005397796631, 49.89568110874721, 53.60027994428362, 49.07355982916695, 52.06720508847918, 47.128144127982004, 51.131109033312114, 33.9782509803772, 29.938325132642472, 52.6077367237636, 48.6441194670541, 49.91048424584525, 48.29708474023001, 51.35397597721645, 47.234177112579346, 49.5304525239127, 44.37087658473423, 49.8355062348502, 49.49860545567104, 50.42882680892944, 44.06606953484671, 37.05154691423689, 41.05464383534023, 38.41732651846749, 35.26588766915457, 37.86402409417288, 37.720606327056885, 38.19940321786063, 38.862546239580425, 38.58044242858887, 39.1995165007455, 39.69918578011649, 40.56648077283587, 42.102974142347065, 42.08047587530953, 39.48132153919765, 40.080051285879954, 40.89974764415196, 39.05298246656145, 40.53861154828753, 38.97496114458357, 39.6161652292524, 37.897906984601704, 39.36600228718349, 39.59951734542847, 38.984393324170796, 40.546789578029085, 40.28000654493059, 39.7108587537493, 38.35672433035714, 40.95077174050467, 46.12539747783116, 50.85968460355486, 52.457502773829866, 51.43344252450125, 50.989087854112896, 51.68927867071969, 51.85114043099539, 55.77301638466971, 55.80154568808419, 56.645942892347065, 54.32558502469744, 54.347190448216026, 55.67747170584542, 34.098805700029644, 2.2171523656163896, 2.9796798144068037, 5.606660383088248, 0.5272817462682724, 0.030056814663112164, 3.604161322116852, 53.93238994053432, 40.18098776681082, 33.369060720716206, 21.895793948854717, 17.05136397906712, 33.9261360168457, 51.79217454365322, 51.05992126464844, 57.28045238767351, 41.739152567727224, 2.0550291793687, 0.15041669298495564, 0.0494325313983219, 0.035238949448934624, 0.026873102910550575, 0.0395478401998324, 0.02187249150925449, 0.016599831670256596, 0.022977002330922654, 0.017987878527492285, 0.04249947092362812, 0.03667721298656293, 0.06505027692764997, 0.04874379121299301, 0.04682107063542519, 0.2437464435185705, 0.15848714778465883, 0.05985062236764601, 0.10139732155948877, 0.1627479541514601, 0.15230255893298558, 0.12753502652049065, 0.09398431291005441, 0.16580170100288733, 0.14787893130310945, 0.19398026966622897, 0.16596615075000695, 0.21401906439236232, 0.12630729882844857, 35.52562175478254, 79.33434391021729, 70.4469586781093, 73.79077925000871, 53.541824749537874, 35.55295944213867, 36.51413154602051, 44.40639925003052, 48.15607104982649, 66.59910188402448, 23.201878104891094, 0.5978555221642766, 1.0810082278081348, 1.270820528268814, 13.29611451285226, 11.946776952062335, 1.2892978510686328, 60.83722482408796, 60.45516422816685, 66.58209964207241, 58.35339668818882, 55.80439097540719, 46.43692690985543, 60.74930926731655, 58.7410158429827, 62.633778844560894, 58.30389077322823, 55.71850429262434, 54.8051357950483, 56.57862179619925, 55.707071031842915, 58.372142927987234, 56.05965736934117, 55.88623380661011, 49.43242038999285, 44.89818927219936, 42.723875590733115, 44.10409355163574, 43.68274089268276, 42.67460938862392, 43.52866458892822, 42.801987239292686, 42.392915521349224, 43.08937862941197, 40.91789633887154, 42.365605626787456, 41.60602160862514, 42.60380377088274, 40.91027763911656, 41.47651066098894, 42.95789091927664, 38.89973994663784, 42.56173242841448, 40.63034514018467, 41.23769065311977, 40.196836607796804, 38.45970358167376, 42.47540800912039, 40.17311198370797, 40.35136801855904, 43.97313737869263, 41.25738879612514, 40.638012477329795, 44.632455417088096, 51.024023396628245, 50.43610157285418, 52.551418100084575, 53.64422035217285, 55.582892826625276, 51.64807932717459, 53.764222690037315, 47.83004420144217, 51.03697483880179, 36.357769284929546, 33.81251907348633, 55.103779792785645, 51.14329269954136, 50.718747343335835, 50.85024200166975, 51.496876103537424, 50.53956719807216, 51.553292001996724, 45.33812141418457, 51.27447121483939, 52.70953130722046, 52.371414593287874, 46.73218366077968, 39.142336300441194, 43.81705304554531, 40.60635995864868, 38.02221373149327, 39.455804279872346, 40.3179680279323, 40.70108127593994, 39.180197034563335, 39.782612800598145, 40.21615954807827, 41.37595285688128, 42.01607302256993, 44.34801006317139, 43.795961788722444, 41.09105587005615, 42.43434068134853, 44.089165346963064, 41.74853958402361, 44.09681183951241, 41.60416643960135, 43.3002529825483, 39.97937536239624, 41.95647137505667, 42.48726511001587, 41.385537896837505, 42.76091991152082, 43.27444737298148, 42.11621740886143, 42.04206623349871, 42.99802371433803, 48.361435481480186, 52.60410628999983, 54.39875650405884, 52.84644208635603, 53.10339341844831, 52.85198327473232, 53.9371668270656, 57.944411822727744, 58.593804359436035, 58.87310109819685, 56.616656235286165, 57.37118891307286, 58.37341444832938, 35.32590968268258, 4.676250559943063, 8.926449741636004, 9.346065350941249, 0.6724839519177164, 0.15732153318822384, 5.104326903820038, 58.99487522670201, 49.980403968266074, 50.193439211164204, 26.30308495249067, 17.123519284384592, 38.32044778551374, 59.864421435764854, 58.47476782117571, 63.734206744602744, 50.683374064309255, 2.8740433113915578, 0.2547523358038494, 0.19392841602010386, 0.22224195886935505, 0.09230496588030032, 0.08584873910461154, 0.10048838318990809, 0.24007562335048402, 0.21453161617474897, 0.09126026622418847, 0.1552215080176081, 0.09196276031434536, 0.13814807417137281, 0.13527998807174818, 0.14088266529142857], [0.04283183094646249, 0.015310783072241714, 0.005288745783868113, 0.031071200767265897, 0.031199532095342875, 0.025268767927108065, 0.02629963225418968, 0.04430095086406384, 0.07243508566170931, 0.09336360264569521, 0.09137288268123354, 0.053178835194557905, 0.07850237616470881, 0.9418115999017442, 36.06879023143223, 60.88444478171212, 56.70433555330549, 50.03396415710449, 30.911416871207102, 22.78380673272269, 39.95458766392299, 40.82899413790022, 37.6742444719587, 58.925045830862864, 6.140913886683328, 0.20621440533016408, 0.18817534829889024, 0.4295096541089671, 3.882113150187901, 1.6902941337653568, 15.594382320131574, 57.70854479925973, 56.92227275030953, 60.03838348388672, 52.95985753195626, 48.0464632170541, 41.60250234603882, 44.029483795166016, 52.911331312997, 53.94228764942714, 56.86303240912301, 56.0175130707877, 53.54538222721645, 55.03160537992205, 50.40318100793021, 53.67619596208845, 53.93408530099051, 52.23966632570539, 48.099002020699636, 37.937695843832834, 38.35731145313808, 39.40022563934326, 39.18593624659947, 37.72410127094814, 37.770480496542795, 38.51653637204851, 39.68932281221662, 39.296923296792166, 39.52099922725132, 37.119375228881836, 38.301267283303396, 38.41541576385498, 38.841416767665315, 35.853583676474436, 36.541344165802, 36.19410794121878, 36.71899570737566, 36.793157305036274, 37.5937739099775, 37.54269422803606, 38.60874591554914, 36.381872585841585, 37.249956199101035, 36.44597666604178, 37.25753320966448, 36.56369999476841, 37.2422228540693, 41.916943073272705, 48.577444553375244, 47.68154730115618, 50.47996555055891, 48.6952234676906, 51.4224192074367, 47.05493790762765, 50.90691498347691, 44.477013792310444, 51.31884935923985, 29.3334219115121, 31.302767208644322, 48.77442250932966, 44.87512820107596, 50.92639078412737, 45.48931768962315, 48.52580901554653, 45.37918874195644, 47.62302957262312, 45.71697889055525, 46.77141319002424, 44.918207032339915, 48.958792958940776, 46.55846132550921, 38.081905705588206, 35.3836943762643, 39.8767226764134, 35.93203926086426, 36.681826319013325, 35.40159640993391, 36.219486236572266, 37.52651882171631, 36.99493299211775, 37.54101971217564, 38.37597778865269, 37.09616477148873, 37.79429544721331, 37.27055760792324, 38.83511127744402, 37.69654124123709, 38.475222383226665, 38.71711349487305, 37.11323649542672, 36.92253623689924, 38.30774300439017, 38.33108895165579, 39.516062532152446, 37.98519025530134, 36.024544102805, 38.674295221056255, 36.780970164707725, 38.61805302756173, 38.507698263440815, 40.9011754989624, 46.70146220070975, 49.58081306729998, 49.77626589366368, 50.01315082822527, 52.3985264641898, 52.6639198575701, 51.576248850141255, 54.69414527075631, 51.62435122898647, 55.64521816798619, 51.32785769871303, 58.59202562059675, 54.298827511923655, 57.017487389700754, 13.244524138314382, 2.295362808874675, 4.490667649677821, 0.1753089808459793, 0.19313146307000092, 0.06662049517035484, 24.062508038112096, 48.27612549918038, 44.01401015690395, 34.83336925506592, 17.81928062438965, 21.537902661732264, 31.60695239475795, 42.66507298605782, 47.68139444078718, 45.76279878616333, 11.67601694379534, 0.13525739285562718, 0.056266556294368844, 0.07154929890696492, 0.03787927509152463, 0.009752325131557882, 0.0446150413315211, 0.022130005726856843, 0.036292147756155045, 0.048470260176275454, 0.01460045190261943, 0.015223287677924548, 0.0824136080752526, 0.052463771243180544, 0.03308783737676484, 0.033814775690968545, 0.03465575538575649, 0.018517755005242567, 0.036086348084998984, 0.024305390692981224, 0.023888174777052233, 0.021104069260348166, 0.04849280110959496, 0.030767746336225952, 0.05470403603145054, 0.038136660387473445, 0.020130622566544583, 0.06460152779306684, 1.3052782735654285, 45.626944133213584, 68.48095893859863, 62.25122492653983, 55.623505047389436, 38.298522744859966, 29.406958171299525, 37.47665854862758, 43.69332994733538, 42.46558673041207, 66.95113236563546, 6.542926234858377, 0.3466008443917547, 0.5695113231028829, 2.7957388503210883, 3.5363935870783667, 0.24173857697418757, 16.686753783907207, 59.6274322782244, 57.622852666037424, 64.06325258527482, 55.0993572643825, 50.602834020342144, 43.42544215066092, 46.20248079299927, 55.40835060392107, 57.195215361458914, 57.26869603565761, 58.190624713897705, 55.322102614811485, 56.763190269470215, 52.30910662242344, 54.12276710782732, 55.136220932006836, 55.23148768288748, 49.6702607018607, 39.93248544420515, 40.02349989754813, 40.51199299948556, 39.48536539077759, 39.06732702255249, 39.37179708480835, 39.948164054325645, 39.71864421027047, 41.27324458530971, 40.74883277075631, 38.46272604806082, 40.42676639556885, 40.594975335257395, 40.37685053689139, 37.68788031169346, 39.12917641230992, 37.83663429532732, 37.55960961750576, 37.93232141222273, 40.410420758383616, 38.91871895108904, 41.361990451812744, 38.56597627912249, 39.57527508054461, 38.31043890544346, 38.31991624832153, 39.10886682782854, 38.01432752609253, 43.19700622558594, 50.04298291887556, 48.77704892839704, 51.771736417497905, 50.42467873437064, 51.88749688012259, 49.14639432089669, 52.51746225357056, 47.33503368922642, 51.54701083047049, 32.282984324863975, 32.83855881009783, 49.61794771466936, 46.51712301799229, 51.96337815693447, 48.30223682948521, 50.70934295654297, 47.115220478602815, 49.74363367898123, 46.89738750457764, 47.58036068507603, 46.49989495958601, 51.56700427191598, 50.05033411298479, 39.564286504473, 37.816991737910676, 40.51446655818394, 36.95404979160854, 39.19641760417393, 37.53610733577183, 38.82946239198957, 38.339013372148784, 38.925187723977224, 38.81370735168457, 39.25813150405884, 38.78231886454991, 38.9566387448992, 39.94351570946829, 39.53621578216553, 40.28826447895595, 39.935070174080984, 39.69613552093506, 38.146388462611604, 38.64802060808454, 39.14367035457066, 39.8614262172154, 41.22320365905762, 39.54477596282959, 38.0233428137643, 41.19475425992693, 39.37966591971261, 40.08496713638306, 39.18485232761928, 43.912312848227366, 48.414231368473594, 52.42697933741978, 52.156531129564556, 53.99541357585362, 52.52394839695522, 53.17706516810826, 52.939617429460796, 54.349299226488384, 52.70552914483206, 55.97865179606846, 53.17017255510603, 60.42948368617466, 55.52252687726702, 59.21755109514509, 16.404398100716726, 1.7169740221330096, 4.969487122126988, 0.8779118944491658, 0.11268356415842261, 0.09930309786328248, 25.89211811338152, 53.67628628867013, 34.34881230763027, 27.46612307003566, 22.538471051624843, 25.44959603037153, 35.54903718403408, 46.56016363416399, 54.60661881310599, 54.35394409724644, 16.713011026382446, 0.1975919622927904, 0.07666778710803815, 0.0875263355140175, 0.11793332174420357, 0.058996088935860565, 0.045794878021946976, 0.030186441993074756, 0.025744492221357565, 0.04887630231678486, 0.026515978055873086, 0.006266872248878437, 0.1162100327866418, 0.06171174892889602, 0.05125603319278785, 0.1308744637561696, 0.058219030632504394, 0.13769819188330853, 0.09729823722903218, 0.1433553961770875, 0.12813634425401688, 0.09310006642980234, 0.09501707034983806, 0.1782278892185007, 0.18157460034957953, 0.19428913880671772, 0.14520444481500558, 0.17754468587892397, 1.587056822010449, 55.612134320395334, 77.35430186135429, 70.3543391908918, 64.20947742462158, 42.361732006073, 33.36651768003191, 51.70968205588204, 54.981710365840364, 50.88269356318882, 71.80531065804618, 8.365374888692584, 0.4478594937494823, 0.3466907909938267, 2.654438546725682, 14.426794869559151, 3.88305332830974, 18.70261205945696, 65.76014859335763, 60.595920835222515, 66.70504801613944, 57.699703216552734, 53.92372553689139, 44.53561837332589, 48.99849843978882, 55.968236446380615, 57.9832626751491, 61.11613941192627, 59.285761560712544, 57.111677169799805, 57.53602450234549, 55.25331197466169, 58.51439339773995, 56.89842305864607, 57.63344866888863, 52.29935482570103, 41.216915539332796, 41.28110647201538, 42.546369961329866, 41.567264556884766, 41.93566846847534, 41.804187706538606, 41.21917717797415, 43.28459174292428, 43.6488163130624, 44.04675006866455, 40.155418395996094, 41.39133269446236, 42.33821930204119, 43.612505027226035, 39.45245177405221, 40.833037989480154, 39.72699594497681, 38.52549607413155, 39.92701373781477, 41.499602999006, 41.14803804670061, 42.4530348096575, 40.62098591668265, 42.36945840290615, 40.70750835963658, 40.23462438583374, 41.04569802965437, 39.55857855933053, 45.95439536230904, 51.79129907063076, 51.03648151670183, 54.02029854910714, 52.293518338884624, 55.46467270169939, 50.36244024549212, 54.72850063868931, 49.63271958487374, 54.685317584446494, 34.2018266405378, 37.08531863348824, 51.94062280654907, 48.29382950919015, 53.26951789855957, 48.173809800829204, 52.5595440183367, 48.36181763240269, 51.29715360913958, 47.52993413380214, 49.80577836717878, 48.82021461214338, 54.874155725751606, 51.35393081392561, 40.9814167703901, 39.543143136160715, 43.4292254447937, 39.073472704206196, 41.11817121505737, 39.802102497645784, 40.11418431145804, 40.401242188044954, 41.237968581063406, 40.93297740391323, 40.70619862420218, 40.53534589494978, 41.45576681409563, 41.45841407775879, 41.76454823357718, 41.31359624862671, 41.98680721010481, 43.53793348584856, 40.132044655936106, 42.3186114856175, 41.63442931856428, 42.81376443590437, 43.35090882437569, 41.50525883265904, 40.407957621983115, 43.867618560791016, 41.2497318812779, 42.92670740400042, 42.47526209694998, 46.04382562637329, 50.68076501573835, 54.59021411623274, 54.9058256149292, 55.10883808135986, 56.17121764591762, 55.192852224622456, 53.88144227436611, 55.747321946280344, 55.11927774974278, 58.84603786468506, 55.84817852292742, 63.38397584642683, 56.74805014474051, 62.570452962602886, 18.313518149512156, 5.040179397378649, 10.638274822916303, 0.49156512852225986, 0.302174334015165, 0.14941391322229589, 29.700908660888672, 61.00446796417236, 58.04027959278652, 45.8153897012983, 25.91972851753235, 30.67237799508231, 42.593892165592735, 56.53132193429129, 60.99678325653076, 62.54663453783308, 19.001059770584106, 0.31444854395730154, 0.10262643346296889, 0.181194132193923, 0.14366334250995091, 0.1419105508497783, 0.12307231527354036, 0.10533967108598777, 0.09910163403089557, 0.12576436224792684, 0.05771288422069379, 0.08794306458107062, 0.22022049448319844, 0.23670346715620585, 0.18166264705359936], [0.011868009194066482, 0.014756830475692238, 0.030762141636971916, 0.028994914144277573, 0.09119986303682838, 0.013492092091057981, 0.00551344604796863, 0.07717683764972857, 0.041386035670127184, 0.04508165629314525, 0.05230517725327185, 0.07035616293017354, 0.1002872179129294, 6.49361617224557, 50.796223231724326, 54.251010009220664, 52.99973324366978, 47.23750529970442, 24.349831683295115, 13.217190793582372, 34.714169434138704, 25.843086412974767, 49.969293798719136, 39.938526902879985, 1.364343824131148, 0.28741440602711266, 4.45859910760607, 10.738847391945974, 1.9829405333314623, 4.7774971042360574, 36.70718029567173, 56.79560361589704, 60.24057606288365, 57.07442440305437, 51.46072810036795, 46.68042305537632, 44.302954469408306, 41.741803305489675, 44.277649130140034, 50.92377478735787, 53.57638161523001, 52.40674270902361, 54.413399832589285, 51.65187651770455, 51.38382543836321, 47.0054806300572, 52.19627135140555, 51.273098945617676, 48.58141197477068, 38.46137114933559, 39.010931968688965, 38.159715107509065, 38.60076590946743, 38.854159763881135, 39.452208587101524, 37.209979738507954, 37.79034539631435, 37.05318668910435, 39.40336969920567, 35.96153783798218, 39.10260302679879, 37.72968067441668, 38.55642598015921, 36.69371816090175, 37.290738650730674, 37.868543897356304, 38.59530462537493, 36.772385665348594, 37.22115591594151, 38.10698870250157, 38.24740832192557, 37.09362867900303, 38.67789091382708, 36.36684710638863, 37.02508817400251, 35.82843814577375, 38.808968680245535, 39.50048467091152, 48.80241332735334, 46.04888391494751, 49.864931855882915, 47.82582664489746, 51.770697661808555, 46.64010265895298, 52.9283127103533, 45.282000814165386, 50.567248821258545, 24.794010911669048, 27.680242231913976, 44.7829464503697, 43.47667816707066, 51.53307621819632, 45.51615163258144, 46.96562576293945, 46.716362612588064, 48.650060176849365, 47.906377111162456, 47.9048867225647, 45.43622997828892, 47.81755134037563, 47.98342568533761, 41.13554171153477, 35.77105297361101, 36.9975767816816, 39.16034255708967, 36.143733501434326, 35.51632159096854, 36.86456046785627, 37.05196033205305, 36.838869503566194, 36.90233434949602, 37.855811323438374, 38.44701269694737, 37.82672963823591, 37.42794472830636, 36.85304730279105, 36.71839468819754, 39.09495306015015, 38.83991248267037, 37.173859528132844, 37.718702520642964, 37.38113818849836, 38.059907708849224, 38.493016719818115, 37.57300574438912, 37.93778269631522, 37.91081326348441, 36.38638891492571, 38.72834178379604, 37.820500578199116, 43.926143237522666, 48.03019748415266, 47.72983380726406, 50.47142274039132, 49.22065666743687, 49.60030623844692, 47.96910892214094, 51.5442350251334, 54.44335004261562, 53.39359882899693, 54.41067613874163, 52.8398551940918, 54.92658683231899, 52.33947719846453, 62.062484060014995, 31.792180946895055, 0.6236579290458134, 2.937713780573436, 0.8606624486190932, 0.17294201999902725, 0.014523809675925543, 7.457223619733538, 44.45195163999285, 44.806917735508506, 41.64484814235142, 20.949801921844482, 17.86420246532985, 23.902048076902116, 34.11078439440046, 41.95128454480852, 49.62356185913086, 27.82000524657113, 0.4541389282260622, 0.06587241709764514, 0.07349431275257043, 0.023960871322612678, 0.03298523609659501, 0.017207481831844364, 0.012674097770026751, 0.05583083163946867, 0.03985064662992954, 0.04928831895813346, 0.021960609459451268, 0.03544169571250677, 0.07234484728957925, 0.024442580295726657, 0.03794032967250262, 0.030350040178745985, 0.0184147483003991, 0.028197618533990214, 0.09267951042524405, 0.04335738006713135, 0.02332087709302349, 0.006513258068090571, 0.03730857625071492, 0.023915962482403432, 0.04656123582805906, 0.10996708313801459, 0.028883712432746376, 8.131458571978978, 64.64580345153809, 61.309222902570454, 59.760149819510325, 53.63066789082119, 32.913408279418945, 17.018215860639298, 30.706900119781494, 30.860531738826207, 55.018240519932334, 46.18204614094326, 0.958686494401523, 0.24414933047124318, 5.880144953727722, 12.493904164859227, 2.328856383051191, 4.465755317892347, 39.31665618079049, 60.85424791063581, 62.10409682137625, 59.87848458971296, 53.67002248764038, 47.91486086164202, 46.36098657335554, 43.54846000671387, 47.62166077750069, 53.81221737180437, 55.78138548987252, 53.21143443243844, 55.866698946271626, 54.103228773389546, 53.301087038857595, 51.31382928575788, 53.746240752083914, 53.10244151524135, 50.90905850274222, 40.4745317867824, 40.00944021769932, 40.12161888395037, 39.95285756247384, 40.140274797167095, 41.116510595594136, 38.91484185627529, 39.157285349709646, 39.80990879876273, 40.159938199179514, 37.65822540010725, 39.17988436562674, 40.01174007143293, 40.07174818856375, 39.54542561939785, 38.71643604551043, 38.94239493778774, 40.32261984688895, 39.10342986243111, 38.60915238516671, 40.0850887298584, 39.171553475516184, 38.79945659637451, 39.34204837254116, 37.253593581063406, 40.20729712077549, 38.87777321679251, 40.02155787604195, 40.40525129863194, 51.082558495657786, 49.097708293369834, 51.803944792066304, 49.66140522275652, 51.043523515973774, 49.00467191423689, 53.513941628592356, 46.70877865382603, 51.73148202896118, 27.443425042288645, 29.253041676112584, 45.61712980270386, 45.336325304848806, 52.833817209516255, 47.6865291595459, 49.82531670161656, 49.498358794621055, 50.42722872325352, 49.74090651103428, 48.666582993098665, 46.80176986966814, 51.19158615384783, 49.322388717106406, 42.76356370108468, 37.44153193065098, 38.141031401497976, 40.590017795562744, 38.4259283883231, 36.689677783421104, 37.5709490776062, 37.416598320007324, 39.06774738856724, 40.70289475577218, 39.338633332933696, 39.39238459723336, 39.60461037499564, 38.60706097739083, 39.18731198992048, 37.99855164119175, 40.33092641830444, 39.9129227910723, 39.870156628744944, 38.68466540745327, 39.49291460854666, 40.59811244692121, 40.170099939618794, 40.28098276683262, 40.887636934007915, 39.80369710922241, 39.75196082251412, 39.9667261668614, 39.93546622140067, 45.248816217694966, 50.997679301670615, 49.867846625191824, 53.09842545645577, 52.19771657671247, 51.90676770891462, 50.102310112544465, 54.84578275680542, 55.31042269298008, 55.46587126595633, 55.99252734865461, 56.11759144919259, 55.95466661453247, 55.319229534694124, 61.892155919756206, 35.58023806980678, 0.6909434156758445, 3.047746104853494, 1.8619057365826197, 0.37421502119728495, 0.04614876117557287, 6.538152388163975, 52.1271367754255, 46.42489957809448, 35.47796058654785, 22.036017281668528, 23.871114696775162, 30.24787085396903, 41.22169937406267, 46.64735310418265, 56.880489758082796, 35.3042973109654, 0.962881686432021, 0.14681677972631796, 0.08233264527682747, 0.04249398836067744, 0.07158365992030927, 0.019813010502340536, 0.07530594018421002, 0.024844100000336766, 0.07233074054654155, 0.021768789306016903, 0.08450740429439715, 0.01968793783869062, 0.10121120618922369, 0.06673444834138666, 0.08377685278121914, 0.10731010285339185, 0.15405265002378396, 0.13456274941563606, 0.18967306507485254, 0.10315010643431119, 0.14906920386212213, 0.18087566856827053, 0.23476291128567287, 0.1546836333083255, 0.15414548718503543, 0.21248530383620942, 0.23723372870257922, 10.452932494027273, 75.08148356846401, 70.9569217136928, 67.04223019736153, 62.98028550829206, 34.281227179935996, 21.619768074580602, 45.784800257001606, 37.7775468145098, 63.35026318686349, 49.179964542388916, 2.1236042082309723, 0.4740024709275791, 6.5462570275579175, 17.14830003465925, 8.782336286136083, 5.926452091761997, 46.45275490624564, 63.2131404876709, 64.64788791111538, 60.970630237034385, 56.44087723323277, 49.90966088431222, 48.44302817753383, 44.07239586966378, 51.10273606436593, 56.455916609082905, 58.81447914668492, 56.63070549283709, 58.62352875300816, 55.67771141869681, 55.61001859392439, 53.77871663229806, 56.61854614530291, 55.7728704724993, 53.72035871233259, 42.73655257906233, 41.8276344026838, 42.813632420131135, 42.42496061325073, 42.52456651415144, 43.93184076036726, 40.31399713243757, 41.56561088562012, 40.926251547677175, 41.88634320667812, 38.6037049974714, 41.94519444874355, 41.84860406603132, 42.00622047696795, 40.38732842036656, 40.10732296534947, 42.59113720485142, 42.91666725703648, 41.48840250287737, 41.12145076479231, 42.447729860033306, 41.810079778943745, 40.656175068446565, 42.722444261823384, 38.921261991773335, 42.332744121551514, 41.18553400039673, 41.941407680511475, 41.96610505240304, 53.086380754198345, 50.652666500636506, 53.94182906832014, 52.61111354827881, 55.15310852868216, 50.12115362712315, 56.91086728232247, 50.59614290509905, 52.23855461393084, 30.393543311527797, 31.24250200816563, 47.12610483169556, 46.897418771471294, 55.739175183432444, 49.401295934404644, 51.5706763948713, 51.68987621579851, 51.919555868421284, 52.01941885266985, 50.90696709496634, 49.25342089789254, 52.61329180853707, 52.61614751815796, 43.650716645377024, 39.830461570194785, 40.527737617492676, 43.483275481632774, 39.26821681431362, 39.67745181492397, 39.14614738736834, 39.65975475311279, 41.464240142277305, 41.10588332584926, 42.68955148969378, 42.10673311778477, 41.046834060123985, 41.08426400593349, 40.29423645564488, 39.30799525124686, 42.47544275011335, 41.694545132773264, 40.35308422361101, 41.79255294799805, 40.72100176130022, 41.5255058833531, 42.29213537488665, 42.43463945388794, 42.84306846346174, 43.21502637863159, 41.93090547834124, 42.970925739833284, 41.988321917397634, 49.189490522657124, 52.73700795854841, 53.26177760532924, 53.46248326982771, 52.201902866363525, 53.41379376820156, 51.248050689697266, 56.21507814952305, 57.441872937338694, 56.917499337877544, 58.53175694601876, 58.68218544551304, 59.21663393293108, 59.1418365750994, 66.68552357809884, 37.02975388935634, 3.2407794381890977, 12.791281853403364, 1.9679775876658303, 0.4064971389515059, 0.2349540681711265, 8.568786876542227, 56.08460487638201, 59.032708168029785, 55.54798855100359, 28.64148555483137, 26.219320944377355, 34.8642783164978, 48.58475753239223, 53.912069933755056, 65.20300728934151, 40.79777240753174, 1.1096620559692383, 0.2523836786193507, 0.20904282427259854, 0.11735507420131139, 0.14279054291546345, 0.07884078193455935, 0.1879827393484967, 0.13306503263967379, 0.10834178820784603, 0.1383749491402081, 0.147297399650727, 0.10039794804262263, 0.2501468743596758, 0.185844146247421], [0.09035364844437156, 0.0324367253508951, 0.037175203407449384, 0.0830367746363793, 0.014726601740611451, 0.02034399808118386, 0.03627267040844474, 0.06488383228757552, 0.04443253916023033, 0.057513720622020106, 0.04883167167593326, 0.05971631993140493, 0.04256191989406943, 13.287336332457405, 62.36905942644392, 50.06599882670811, 51.41671821049282, 30.543322154453822, 17.217408554894583, 36.216164997645784, 54.07560273579189, 30.752730437687465, 58.312916483197895, 25.150743586676462, 0.1486602100942816, 0.2744857354887894, 8.254645790372576, 14.295415725026812, 1.2651865163019724, 4.385423285620553, 39.86469881875174, 62.38290023803711, 56.11923122406006, 55.282470090048655, 50.27873877116612, 53.429739883967805, 49.82895755767822, 43.087509563991, 39.51212290355137, 43.82471343449184, 45.81984697069441, 49.788817814418245, 51.300589493342805, 52.01117828914097, 53.5770833832877, 51.10509497778756, 52.39656359808785, 52.64514929907662, 46.84123911176409, 40.753425530024934, 38.204777649470735, 38.71162441798619, 38.21526942934309, 38.15056432996477, 38.864081791469026, 37.441424233572825, 38.6779499735151, 38.53300012860979, 37.98438079016549, 36.785858222416465, 38.549592426845, 36.63869537625994, 38.296320165906636, 37.61511182785034, 36.35411800657, 37.44632271357945, 37.9246506009783, 37.41755369731358, 38.7325245993478, 36.954035895211355, 38.22804716655186, 35.9808850969587, 38.14203541619437, 37.778272901262554, 38.14710412706648, 36.250270230429514, 38.77801098142351, 37.216316495622905, 47.42400884628296, 46.88537754331316, 49.88118716648647, 46.921643665858674, 49.47912965502058, 47.37247405733381, 50.00260693686349, 45.9996246610369, 49.34128434317452, 24.721657582691737, 26.24759316444397, 49.10702930177961, 42.71594074794224, 51.269034249441965, 46.50148957116263, 48.03026001793997, 45.42521708352225, 48.49536895751953, 47.993792397635325, 49.76273775100708, 46.838234015873496, 49.69600377764021, 47.096536772591726, 45.73218502317156, 36.68644339697701, 35.75571829932076, 37.07568148204258, 38.170717579977854, 36.479571206229075, 36.88952534539359, 35.847142696380615, 38.0462440763201, 35.866934640066965, 39.62873452050345, 36.384387833731516, 37.50940888268607, 37.85055848530361, 38.24378483636038, 39.05287824358259, 39.532456806727815, 36.72762884412493, 38.68020118985857, 36.35232884543282, 37.69303934914725, 38.39998728888375, 39.23760305132185, 38.98312875202724, 40.37954643794468, 39.04605163846697, 38.63917555127825, 38.17266654968262, 38.421498911721365, 43.16357496806553, 49.121891498565674, 47.295376845768516, 44.9724828856332, 48.13726575034005, 50.20797831671578, 50.861036028180806, 52.83930281230381, 53.5936096736363, 53.64551271711077, 51.19010966164725, 52.955935273851665, 52.13696500233242, 53.80185760770525, 56.08513641357422, 53.962354046957834, 3.8160475066729953, 3.4784028359821866, 1.9885909387043543, 0.15769273255552563, 0.04905318282544613, 0.3552352567868573, 32.25137349537441, 42.7509457724435, 36.12847178322928, 31.31223065512521, 14.146424634116036, 18.833248615264893, 25.417787177222117, 42.52953447614397, 43.80840948649815, 41.384794439588276, 3.64771089383534, 0.1486026296125991, 0.007010820163746497, 0.03032080889014261, 0.06263896703187909, 0.03049637982621789, 0.045685267475034506, 0.024130087778238312, 0.05925868877342769, 0.11009078685726438, 0.035569796338677406, 0.020685075582670312, 0.0800836341721671, 0.038994966473962576, 0.05255533615127206, 0.025634854533044354, 0.021169982152059674, 0.004743606933126492, 0.01765620382502675, 0.022259638145832077, 0.022749470879456828, 0.023244555474125912, 0.0650194917938539, 0.05484692193567753, 0.044936738176537414, 0.07526305677103144, 0.054543515002088885, 17.506167003086635, 71.66998059409005, 56.96785293306623, 58.3695581981114, 37.8160537311009, 20.50217638696943, 35.00997856685093, 60.906748499189106, 30.995184353419713, 67.70826366969517, 26.397332055228098, 0.1544172947428056, 0.47376878346715656, 7.11999888079507, 13.730217984744481, 2.072391207729067, 6.083613395690918, 42.267222608838765, 63.82259477887835, 58.7035858971732, 58.29645620073591, 52.45721789768764, 54.291625704084126, 50.77850185121809, 45.05748019899641, 41.74729585647583, 46.04974896567208, 48.09623316356114, 51.12767662320818, 53.53241688864571, 52.429143701280864, 55.50188030515398, 52.51519019263131, 54.004807540348594, 54.3067102432251, 47.706581660679404, 41.77020059313093, 40.66959203992571, 38.91780873707363, 39.30789450236729, 40.07764026096889, 40.169165406908306, 38.23752450942993, 39.163288593292236, 39.86497674669538, 39.96725075585501, 38.550238609313965, 39.30092545918056, 38.726757594517295, 41.12140907560076, 39.67015620640346, 38.871387822287424, 38.86252192088536, 38.868643283843994, 38.52420023509434, 40.16128267560686, 39.577981403895784, 39.50740507670811, 37.973607608250205, 39.274782861982075, 38.926879610334126, 38.83165454864502, 39.389560154506135, 40.006115504673545, 38.497578212193076, 49.97814580372402, 48.79726818629673, 49.46752963747297, 47.69107328142439, 52.12847430365426, 48.88370377676827, 51.255311557224815, 46.62204776491438, 49.158800329480854, 26.01154896191188, 27.26653606551034, 49.73871782847813, 45.632127489362446, 52.6026680128915, 48.75523853302002, 50.10664231436593, 46.75449432645525, 50.20487594604492, 50.48498909814017, 49.692105838230674, 48.744420187813894, 48.54320730481829, 48.38178328105381, 47.38330977303641, 38.4183965410505, 37.94274718420846, 38.574119567871094, 39.90418890544346, 37.746022837502615, 40.403455189296174, 37.303106444222585, 40.878847462790354, 36.927907194410054, 41.56197350365775, 39.239520754132954, 39.32789836611067, 39.28502798080444, 39.46682759693691, 41.05998700005667, 40.71248326982771, 38.16489846365792, 40.118916034698486, 37.540939807891846, 38.73118707111904, 40.08281666891915, 40.23340845108032, 42.02679409299578, 41.47642033440726, 41.082995959690635, 41.24927677427019, 39.90737812859671, 40.15824978692191, 45.57584013257708, 52.09275014059884, 49.37878029687064, 44.913645539964946, 48.578167166028706, 51.3942859513419, 52.528822558266775, 55.10747276033674, 54.76664972305298, 55.54125574656895, 53.22878755841936, 54.31151492255074, 54.06940841674805, 55.95748063496181, 57.43508454731533, 55.61279787336077, 4.554624080657959, 2.308135986328125, 3.3056604138442447, 0.373109334813697, 0.06645899705056633, 0.11085769427674157, 35.029582909175325, 48.22459418433053, 33.28722831181118, 24.219014474323817, 21.483902999332972, 30.891284465789795, 30.797132900782994, 48.56982585362026, 51.1050637108939, 53.42263535090855, 5.591550656727382, 0.11829367812190737, 0.0385762085872037, 0.011776744537720723, 0.05122926837897726, 0.04635397391393781, 0.043234500767929215, 0.05624226813337632, 0.047968558168837, 0.034698075614869595, 0.00848569702689669, 0.06134094989725521, 0.006576531882663923, 0.07898875685142619, 0.24829884352428572, 0.09926816009517227, 0.1396630121661084, 0.17293190982724937, 0.19392901313092026, 0.06160602638764041, 0.10151521023362875, 0.22243249150259153, 0.20153072236904077, 0.12037559997822557, 0.2198708046759878, 0.13327475424323762, 0.20071322337857314, 23.027752774102346, 80.32685238974435, 63.62329959869385, 67.42644473484584, 43.64085367747715, 25.71718852860587, 43.40992682320731, 63.549447195870535, 43.364739213671, 71.85211372375488, 33.27253287179129, 0.3578115999698639, 0.4135750191552298, 14.74400792803083, 21.104562623160227, 4.973638670785086, 7.544489519936698, 47.773871489933555, 66.61429064614433, 61.218917165483745, 60.3118645804269, 54.501579420907156, 56.33639022282192, 53.20239135197231, 46.87233577455793, 44.03836011886597, 48.06962851115635, 49.4523651940482, 54.4367527280535, 56.43200090953282, 54.9404102734157, 57.28965527670724, 53.38644218444824, 58.25005613054548, 57.112173965999055, 50.8416679246085, 44.76610401698521, 42.55940130778721, 41.123969486781526, 41.347663266318186, 41.80581358500889, 42.633055686950684, 40.7802768434797, 41.86542912891933, 42.80081646783011, 41.33635854721069, 41.17109564372471, 41.75591509682791, 39.23858969552176, 41.6317959512983, 40.335943017687114, 40.43398209980556, 41.48793002537319, 41.09119830812727, 40.992672852107454, 42.44364084516253, 40.05254684175764, 40.600033623831614, 40.215857301439556, 42.13265684672764, 41.60206460952759, 40.8402293750218, 41.2097658429827, 42.533276081085205, 39.59767607280186, 52.58645439147949, 51.731193678719656, 52.895531109401155, 50.41525002888271, 54.15455164228167, 51.449513707842144, 52.53597225461687, 50.20893369402204, 50.304752826690674, 27.67523431777954, 30.1953980582101, 51.96230813435146, 45.42701666695731, 54.69988448279244, 52.45946216583252, 52.0044698034014, 49.35967969894409, 51.403912680489675, 51.46537297112601, 53.27601099014282, 52.32037660053798, 52.92991427012852, 50.53301157270159, 49.314002241407124, 40.46194165093558, 39.80710172653198, 40.6006624358041, 42.31733649117606, 40.15436921800886, 41.37926367350987, 38.50998074667794, 42.6291959626334, 38.54261296136038, 43.40599761690412, 41.26000131879534, 41.03648124422346, 41.014608315059114, 42.3960838999067, 43.368859495435444, 43.36161252430507, 40.16829340798514, 41.310299328395296, 39.97785023280552, 41.03074550628662, 42.69312286376953, 42.81288201468331, 43.606057098933626, 44.38794483457293, 42.27231911250523, 43.6404367855617, 42.8826071875436, 43.51378502164568, 48.631022112710134, 54.963902132851736, 51.806970732552664, 49.40599291665213, 51.35259675979614, 52.761323179517476, 54.28250619343349, 57.599579674857004, 56.86124324798584, 57.58254616601126, 55.57651785441807, 58.26780182974679, 57.76939017432076, 59.51842199053083, 60.638325691223145, 58.310901505606516, 6.382355536733355, 10.34443289893014, 5.200872991766248, 0.260611105710268, 0.12823123059102468, 0.67800087588174, 39.13600649152483, 55.441298961639404, 49.054500920431956, 38.99326964787075, 22.552059991019114, 28.957086631229945, 36.692853110177175, 56.15427098955427, 56.85748774664742, 61.37951782771519, 6.554335176944733, 0.2656263480229037, 0.08920256128268582, 0.16559534493301595, 0.1928395844463791, 0.148944869105305, 0.12188367119857244, 0.13621123667274201, 0.16123579815030098, 0.23424030361430986, 0.06818561082971947, 0.143635074741074, 0.20145712846091815, 0.1586619791175638], [0.03544797216142927, 0.06592959724366665, 0.049265221626098664, 0.07891255736883197, 0.01859873646338071, 0.07147027671869312, 0.020569697488099337, 0.03951974206471017, 0.016183881222137382, 0.0666705167719296, 0.04380156944638916, 0.043116191402077675, 0.4454108779983861, 25.13593350137983, 62.67342526572091, 52.55212334224156, 52.163382053375244, 27.32640869276864, 25.991779599870952, 43.08624151774815, 25.135796274457658, 38.81117473329817, 57.237929412296836, 12.030901397977557, 0.20519744418561459, 0.1426360404917172, 5.636557613100324, 3.122062299932752, 1.2150617774043764, 10.989818930625916, 58.10686765398298, 60.984505789620535, 54.73196431568691, 52.11251081739153, 52.1795539855957, 55.76350430079869, 54.3479061126709, 51.37740877696446, 41.7009722164699, 42.16629307610648, 40.00088003703526, 42.16328798021589, 43.02060883385794, 45.84448528289795, 47.876510279519216, 49.22045864377703, 49.72776746749878, 45.9267589024135, 42.300459316798616, 38.104834760938374, 37.98714617320469, 37.442393507276265, 38.823657172066824, 39.24798366001674, 36.85370390755789, 36.70727409635271, 37.90748855045864, 36.97251115526472, 37.72386155809675, 36.50755507605416, 37.88704695020403, 36.230624198913574, 38.15701920645577, 36.84638398034232, 38.75717680794852, 37.394885199410574, 37.6226749420166, 37.15616594042097, 38.403405802590505, 37.623355865478516, 38.87000860486712, 36.682125091552734, 37.4645756312779, 37.32895374298096, 36.86250032697405, 37.14409344536917, 38.51198182787214, 36.96371126174927, 44.348763942718506, 48.9940515926906, 48.05602741241455, 46.29599659783499, 49.08696290424892, 45.316918986184255, 48.96815913064139, 39.680182456970215, 47.45286124093192, 25.8087032522474, 26.997110979897634, 51.14223657335554, 44.825226238795686, 49.798628670828684, 45.6324644769941, 47.23769637516567, 45.69204527991158, 48.417722838265554, 46.55815213067191, 47.11220496041434, 46.97020809991019, 47.011049611227854, 45.6823490687779, 45.255493436540874, 37.43747418267386, 37.00530317851475, 35.47988176345825, 36.71678270612444, 35.5915184702192, 37.73396076474871, 37.1484569140843, 37.80173001970564, 35.575290952410015, 39.12141874858311, 37.178163937159944, 37.75444058009556, 37.47222907202584, 37.89924798692976, 37.77996131352016, 37.75054611478533, 37.23907879420689, 38.765552861349924, 37.936889852796284, 37.94641930716378, 39.092962401253835, 41.853578976222444, 40.57858453478132, 44.75636959075928, 40.53098937443325, 44.36330304827009, 38.02900559561593, 40.69398021697998, 41.77664852142334, 50.16922473907471, 45.386953353881836, 40.53253187452044, 42.450825282505576, 44.576675278799875, 50.61165475845337, 54.76435334341866, 50.69219132832119, 50.72280856541225, 49.838184765407014, 51.13927664075579, 46.808203901563374, 54.90697206769671, 52.77606725692749, 59.82484449659075, 13.252571020807538, 1.1760489451033729, 1.8627332236085619, 0.7033872050898415, 0.22195325578962052, 0.01824688721847321, 8.740738289696829, 51.73258679253714, 33.55932671683175, 54.56640263966152, 45.721599442618235, 12.56068764414106, 27.853898559297832, 46.70522117614746, 45.568961415972026, 51.74790409633091, 12.795474222728185, 0.2423628291913441, 0.04892556056646364, 0.03498592374048062, 0.023762820521369576, 0.020040884613990784, 0.11756806634366512, 0.0799362360100661, 0.05178305473444717, 0.03544042006667171, 0.07369324564933777, 0.04642710981092282, 0.05237701375569616, 0.049562114623508284, 0.02120668750389346, 0.052943020526851924, 0.06413353540535484, 0.03511286067909428, 0.028895155925835882, 0.023151699653161422, 0.04440232399584992, 0.02026233639168952, 0.044155004766902754, 0.0681067786312529, 0.14030937105417252, 0.061685659257428985, 0.6019318348595074, 35.09911353247506, 70.70940603528703, 59.83774035317557, 58.565386227199006, 34.87227916717529, 27.400855166571482, 42.21170997619629, 33.048439570835654, 40.40135335922241, 64.57076290675572, 12.499655536242894, 0.21653553364532335, 0.2674538056765284, 9.826350893293109, 4.39259078672954, 1.1198649427720477, 11.994205355644226, 63.11694962637765, 64.075411932809, 57.561976024082725, 54.219506876809255, 54.829329422542024, 57.295828751155305, 56.635478905269075, 54.829107080187114, 43.22702244349888, 41.69713681084769, 42.960559027535574, 43.97825820105416, 45.93395723615374, 48.469320161002024, 50.64754567827497, 51.669538838522776, 52.404369899204795, 48.64358792986189, 43.72644853591919, 39.9057730947222, 38.972824573516846, 38.69238485608782, 39.93199559620449, 41.40030281884329, 38.82364674976894, 37.705341134752544, 40.02886043276106, 38.39566898345947, 40.18228013174874, 38.990351404462544, 39.74794823782784, 39.183542592184885, 39.207096985408235, 39.50033181054251, 39.71283899034773, 39.70178093229021, 38.927744661058696, 38.63908869879586, 39.55946792875017, 38.390892096928184, 39.77572366169521, 38.81573969977242, 39.41759613582066, 38.54515600204468, 38.36080987112862, 38.8442759513855, 40.65095002310616, 40.039456435612266, 45.954808780125205, 49.689826829092844, 50.72769314902169, 48.784844807216096, 52.258148533957346, 48.4488959312439, 50.77951281411307, 42.84757784434727, 48.306304999760215, 26.106945991516113, 28.194290808268956, 54.232704980032786, 45.02359383446829, 52.751477582114084, 47.23535483224051, 49.99130916595459, 48.32379708971296, 51.702455929347444, 46.90633678436279, 49.88896220070975, 49.258024079459055, 49.151973724365234, 46.5975866317749, 47.10726826531546, 39.03319747107369, 39.06174067088536, 37.82209518977574, 38.3051825932094, 37.79022032873971, 39.67859131949288, 39.551887444087434, 39.69576726640974, 38.97883129119873, 41.04924161093575, 39.60870286396572, 39.45498091833932, 38.810941968645366, 39.83053452627999, 39.2970483643668, 40.40038061141968, 40.089775289808, 40.17027017048427, 37.47834696088518, 40.50171313967024, 41.20972762789045, 42.50967999867031, 44.72329616546631, 45.69752393450056, 42.609157357897075, 45.10166031973702, 38.87869732720511, 41.41637747628348, 43.98594290869576, 52.11900390897478, 49.48833949225289, 43.40126241956438, 45.52633421761649, 47.0575886453901, 51.749047074999126, 54.50613396508353, 51.59329278128487, 52.718025479997905, 52.03662954057966, 53.078887122017996, 48.59629501615252, 56.28980255126953, 55.190354347229004, 61.328455516270225, 15.66585670198713, 0.7278701599155153, 2.26568466424942, 2.1902317873069217, 0.15120278937476023, 0.13196960570556776, 8.26748171874455, 59.21476486751011, 37.29794045857021, 46.441467557634624, 37.61592129298619, 14.929161787033081, 31.975328513554164, 51.69800213405064, 50.49204151970999, 60.44217804500035, 17.27339366504124, 0.1865731778421572, 0.06862908096185752, 0.02878451400569507, 0.06344309888247933, 0.047164548454540114, 0.053392475337854454, 0.0481665580799537, 0.06063946682427611, 0.01334699585900775, 0.02948891817192946, 0.07489525686417307, 0.028820968299571956, 0.017338355969903723, 0.08760113042912313, 0.13477168391857827, 0.13902627490460873, 0.22127911767789296, 0.1238123391355787, 0.1700180633259671, 0.16638610964374884, 0.12071352398821286, 0.09925120350505624, 0.1830308993480035, 0.2267935989158494, 0.1381512904273612, 0.6807473142232213, 42.372293267931255, 80.28774792807442, 67.39100892203194, 66.12506103515625, 37.89646870749337, 34.691410609654014, 49.75470563343593, 35.13438606262207, 52.51114286695208, 67.95600169045585, 15.854455130440847, 0.35975970114980427, 0.2618230778191771, 12.850829652377538, 7.976859416280474, 5.039586629186358, 13.875559534345355, 65.70662661961147, 67.10623700278146, 58.92239856719971, 57.73709842136928, 57.48291942051479, 58.681261335100444, 59.16436958312988, 56.40214450018746, 45.79390934535435, 44.9828565461295, 45.26604775020054, 45.98882021222796, 47.51061119352068, 49.677882875714985, 52.793059076581685, 52.45607144492013, 56.41759034565517, 50.6741155896868, 46.8115633555821, 41.917627470833914, 40.51207985196795, 40.95795617784773, 42.05708129065377, 42.69604458127703, 40.76168693814959, 40.066262585776194, 42.57455880301339, 40.855619634900776, 42.265780857631135, 41.37617172513689, 42.77924231120518, 40.70519808360508, 42.353943075452534, 41.448241915021626, 42.68071685518537, 41.400021416800364, 40.19908087594168, 40.78783300944737, 40.65137733731951, 41.30257640566145, 42.18490382603237, 41.12694331577846, 40.98513753073556, 40.56532389777047, 38.654805524008616, 41.25937598092215, 42.77966267721993, 43.211868422372, 48.13706772668021, 52.352619716099326, 51.00798348018101, 50.66709096091134, 55.12284912381853, 49.39536564690726, 52.49774326596941, 43.68564523969378, 50.33491495677403, 30.12956735066005, 32.405112811497276, 55.67445618765694, 47.566943713596885, 54.398127692086355, 49.71007735388619, 50.365570408957346, 51.63653489521572, 53.64755201339722, 50.97595575877598, 51.16115304401943, 51.99872016906738, 52.03081042425973, 48.933477197374614, 47.402789047786165, 42.179369585854666, 40.7774315561567, 39.066653047289165, 39.90483161381313, 39.24982493264334, 41.72558968407767, 42.51672199794224, 42.82283878326416, 41.03136042186192, 43.410791873931885, 41.22180012294224, 42.030188288007466, 40.81543125425066, 42.046335901532856, 41.39043985094343, 42.269949776785715, 41.71406957081386, 41.994377272469656, 40.09922136579241, 42.07785293034145, 43.973616804395405, 45.21015644073486, 46.393646580832346, 49.0654547555106, 43.38148437227522, 48.56483704703194, 41.563877310071675, 44.61243765694754, 46.97820895058768, 55.450630392347065, 49.68251385007586, 44.46660886492048, 49.41938556943621, 53.02810968671526, 55.652016980307444, 57.8386116027832, 53.76409067426409, 55.140678201402935, 53.8928199495588, 55.627451624189106, 50.2640711239406, 60.34379850115095, 57.11185782296317, 65.49542222704206, 17.241793257849558, 3.411540972334998, 8.156682269913809, 1.8779397904872894, 0.4186844692698547, 0.30933979951909607, 11.105648006711688, 64.5935252053397, 44.633587973458425, 66.22152982439313, 55.03034428187779, 21.468703814915248, 42.58417163576399, 60.02470942905971, 57.006794112069265, 67.97906970977783, 20.434174367359706, 0.42737349016325815, 0.14809636106448515, 0.1592601348779031, 0.18557617919785635, 0.1640755214861461, 0.2091251848531621, 0.15959879170571054, 0.12119726517370769, 0.12793061243636267, 0.14826026798358985, 0.20643005732979092, 0.103254017287067, 0.19290247107190744], [0.045940813941082785, 0.048015801169510396, 0.020406362234747837, 0.031673580408096313, 0.024732886414442743, 0.05387897476820009, 0.026065123766394596, 0.038869098228003295, 0.04385259867246662, 0.030646763542400937, 0.05500888145927872, 0.056827545299061706, 2.664938577583858, 51.505846227918354, 60.22336537497384, 47.51185144696917, 46.56125102724348, 21.620195388793945, 23.580909286226543, 53.060140882219585, 38.78347226551601, 44.71629932948521, 54.34450496946062, 2.3932913712092807, 0.13584804401866027, 0.13727007699864252, 6.930907998766218, 7.396978395325797, 0.9262833531413759, 30.179639543805802, 62.858775411333355, 57.20873308181763, 53.82385213034493, 52.98614951542446, 55.2871219090053, 57.92702048165457, 54.70283399309431, 54.77250705446516, 45.654069900512695, 40.441614695957725, 38.19968114580427, 40.56588670185634, 40.59116424833025, 39.35666390827724, 40.84914738791329, 42.00547007152012, 41.46889196123396, 41.59113161904471, 37.82456180027553, 37.88885348183768, 37.42738887241909, 39.26157086236136, 37.72144358498709, 36.699585914611816, 36.475419657570974, 37.151712145124165, 37.070289679935996, 37.11518546513149, 36.68448747907366, 36.818042278289795, 39.05276707240513, 39.687196663447786, 37.57327325003487, 37.45847858701433, 36.86595358167376, 37.74079084396362, 39.42988749912807, 36.72492946897234, 38.595884799957275, 36.67410339627947, 36.5494179725647, 36.04536090578352, 37.41006006513323, 36.94959599631173, 36.00760439464024, 36.820852824619834, 39.25006117139544, 36.583234855106895, 39.75677939823696, 45.87414019448416, 49.78286320822579, 46.26834971564156, 48.68038558959961, 45.52341944830758, 50.86189413070679, 42.895791394369944, 49.01312092372349, 21.410754101616995, 25.200167860303605, 50.994799273354666, 42.00396926062447, 50.56616142817906, 43.83279071535383, 48.936430181775776, 43.5864006451198, 47.994813782828196, 46.70582914352417, 47.38260105678013, 47.044630255017964, 47.34285388674055, 46.665296827043804, 45.063959394182476, 37.77082095827375, 36.35106427328927, 35.28851100376674, 37.782021454402376, 36.59980283464704, 36.44026524680001, 37.13877807344709, 38.42501817430769, 37.01974153518677, 38.76023401532854, 36.29473870141165, 38.37248631886074, 36.42023011616298, 36.81560346058437, 37.308199473789756, 38.4023323059082, 38.129427909851074, 38.24770014626639, 37.2181647164481, 41.26634502410889, 42.34883267538888, 44.32607112612043, 44.08005625861031, 44.34640155519758, 43.13549729755947, 41.05026994432722, 38.45070219039917, 38.8906169618879, 40.93529462814331, 48.089851243155344, 49.902733530317036, 50.87888595036098, 48.43593406677246, 48.4274468421936, 48.08007165363857, 52.69626719611031, 52.279132093702046, 52.014336245400564, 49.44387102127075, 48.680809429713655, 42.83306653159005, 52.571425437927246, 53.33078016553606, 61.39581135341099, 30.09265504564558, 0.5851262594972337, 1.9290377114500319, 1.1643288539988654, 0.10724161152860948, 0.042344408708491495, 1.393695620553834, 38.37295184816633, 35.314393043518066, 51.66191666466849, 85.11370263780866, 27.40002485683986, 25.08945526395525, 41.5044458934239, 45.75034761428833, 52.91642434256417, 25.738533394677297, 0.27475161265049663, 0.025580113720414892, 0.04144667973741889, 0.0044763281725214, 0.05066884255834988, 0.022092316499246017, 0.08759286587259599, 0.08424518443644047, 0.03469173809779542, 0.02956359095073172, 0.005293114277135048, 0.07244483620992728, 0.024274208616199236, 0.08985126790191446, 0.055451805370726755, 0.05274328695876258, 0.024237864584262882, 0.03461968446416514, 0.037753702008298466, 0.06215382806424584, 0.02625503214741392, 0.16491101522530827, 0.081128408467131, 0.10283035359212331, 0.03392433534775462, 3.4606388977595737, 61.9999989100865, 68.1180475779942, 54.73275988442557, 52.01294313158308, 29.255206039973668, 25.34135525567191, 48.359080042157856, 36.29000697817121, 50.83841616766793, 58.768850326538086, 2.9879080014569417, 0.08584172983786889, 0.4279196022876671, 10.266360333987645, 10.595236812319074, 1.244148130927767, 34.086767945970806, 65.22595024108887, 59.88097204480852, 55.60327189309256, 56.26055758340018, 57.33188990184239, 59.28710951123919, 57.65203162602016, 56.01272576195853, 47.06257050377982, 41.67367621830532, 39.70735338756016, 43.82876076017107, 42.40917430605207, 42.02627297810146, 43.65293312072754, 44.83885513033186, 43.55841677529471, 43.22420494897025, 40.03940085002354, 39.582046100071494, 40.091800689697266, 40.249653339385986, 38.07273060934884, 38.51566784722464, 38.592848437173025, 39.00386217662266, 38.76016105924334, 38.67227676936558, 38.88588523864746, 39.54808677945818, 40.3269624710083, 40.308202334812705, 38.20599358422415, 39.250026430402485, 39.322409289223806, 39.40653460366385, 39.77160685403006, 38.09172003609793, 39.94700370516096, 39.45300415584019, 38.66852821622576, 38.73102378845215, 39.045179639543804, 39.12186343329293, 37.64162962777274, 37.955094133104595, 39.78726461955479, 38.63132756096976, 40.497929845537456, 47.049928256443565, 52.70783247266497, 49.692192690713064, 50.56507750919887, 47.01240798405239, 52.53915800367083, 43.77834810529436, 51.13567747388567, 23.264870473316737, 26.04565245764596, 54.01742199489048, 45.22870118277413, 52.554016726357595, 46.59373385565621, 48.42092595781599, 45.58287170955113, 50.4292437008449, 49.276520184108186, 50.01794855935233, 49.28787006650652, 49.95284741265433, 47.16016837528774, 46.72921677998134, 38.33356251035418, 38.09211955751692, 36.35808195386614, 39.74876465116228, 38.21483516693115, 38.6622713633946, 38.799724102020264, 39.684848172324045, 38.739670821598594, 40.67369147709438, 39.16533483777727, 39.80967256001064, 37.4370607648577, 38.56154680252075, 39.38647515433175, 40.512524536677766, 38.83492020198277, 39.66708857672555, 38.07200452259609, 44.71486452647618, 44.618006638118196, 46.85419055393764, 46.328576701028005, 46.44352075031826, 45.8565160887582, 42.91759484154837, 40.473354067121235, 40.66555513654436, 42.22442170551845, 48.84787539073399, 52.8667516708374, 53.5444963318961, 53.40116194316319, 52.57086958203997, 50.34263787950788, 52.52320146560669, 53.70732389177595, 54.5800176348005, 50.30721596309117, 49.3063314301627, 44.77541807719639, 54.45628758839199, 55.05741098948887, 63.01398427145821, 32.59569495064871, 0.7981632394450051, 2.333339491060802, 2.3662594045911516, 0.4342341034540108, 0.03160572690623147, 0.9883377147572381, 42.457547664642334, 37.442143372126985, 48.37005124773298, 72.45884432111467, 26.9111704485757, 33.5127911567688, 45.058348723820274, 50.61309650966099, 59.116454805646626, 34.76572159358433, 0.2789870553783008, 0.06758984351264578, 0.08174031134694815, 0.02372880047187209, 0.039246339949646165, 0.035951428181890926, 0.07043115462043456, 0.06754157931676932, 0.03743998473510146, 0.02601160601313625, 0.030407084617763758, 0.0840925479839955, 0.029334507350410734, 0.17561988559152397, 0.14155198580452374, 0.1076438267316137, 0.15356016930724892, 0.15414512077612536, 0.12527082301676273, 0.11827051293637071, 0.17727777734398842, 0.23560850162591251, 0.19881825149059296, 0.19005254256938184, 0.18877407402864524, 4.063874551228114, 70.69281373705182, 76.27089009966168, 61.96120016915457, 60.063487325395855, 31.449912684304373, 30.941047464098247, 60.29675224849156, 53.18490273611886, 57.3985161781311, 63.81331198556082, 3.956831906523023, 0.16580470012766974, 0.30461836286953514, 11.448803901672363, 13.550924062728882, 3.0508360990456174, 35.08629758017403, 68.07657378060478, 61.02231093815395, 57.51609706878662, 57.86137737546648, 59.27681228092739, 61.83604921613421, 58.59700747898647, 61.1702241897583, 49.00322321483067, 44.61788851874215, 41.061661515917095, 45.47324998038155, 44.65990774972098, 43.19563743046352, 46.5045120375497, 46.67192540849958, 45.13025910513741, 45.80219854627337, 41.83230011803763, 41.86408812659127, 42.713672161102295, 42.352056639535085, 39.52284049987793, 39.53452736990792, 41.46991682052612, 40.47165870666504, 41.25592620032174, 40.18772404534476, 40.0920855658395, 40.91940757206508, 41.857473441532676, 42.98209496906826, 40.95835222516741, 41.432375703539165, 40.7576048714774, 41.74799762453352, 43.73153461728777, 41.436551570892334, 41.506071771894185, 41.19452149527413, 39.49996703011649, 38.37054429735456, 41.965271268572124, 41.572743211473735, 39.731762409210205, 38.826377391815186, 42.83685677392142, 41.56417260851179, 43.55395950589861, 50.14734138761248, 54.53664697919573, 51.31879724775042, 53.63844987324306, 52.04161834716797, 55.09753336225237, 46.18126099450247, 51.792848518916536, 25.427641459873744, 29.55257156917027, 53.798251492636545, 46.70635025841849, 54.30592162268502, 50.25874880381993, 50.08589151927403, 47.18412576402937, 51.26824910300118, 51.8386093548366, 52.46492692402431, 52.33697237287249, 51.63829278945923, 49.637020519801546, 49.71036570412772, 40.59922068459647, 39.896285329546245, 37.438224588121685, 41.76302310398647, 40.05670881271362, 39.89618110656738, 41.59005812236241, 42.72813136237008, 40.828295843941824, 43.512252943856375, 41.72683341162545, 41.94654587336949, 39.436356272016255, 39.90213223866054, 40.98540503638131, 42.14530256816319, 41.317581040518625, 41.918801716395784, 39.38294199534825, 45.74204799107143, 47.93198469706944, 48.897746086120605, 49.578700814928325, 48.68634019579206, 47.775004046303884, 44.47347368512835, 43.30137859072004, 42.71783760615757, 44.77751990727016, 52.45339291436331, 55.270550455365864, 55.697875091007774, 52.19460378374372, 53.57490859712873, 55.36115149089268, 56.84334468841553, 57.376469544001985, 57.461331367492676, 53.556860651288716, 54.10863447189331, 47.48863751547677, 56.24314887183053, 58.34772000994001, 66.04011930738176, 34.549177510397776, 1.5364986892257417, 6.691372760704585, 4.1581533551216125, 0.2985422174845423, 0.13798143954149314, 1.9623302221298218, 46.72435998916626, 47.025842326028005, 60.25167233603341, 89.19171851021903, 40.214391231536865, 37.36830833980015, 53.49967002868652, 57.815897941589355, 67.36420972006661, 40.81559106281826, 0.5529794416257313, 0.2646018144275461, 0.16199315179671558, 0.10339954269251653, 0.09107706855450358, 0.107677312434784, 0.14346166833170823, 0.19738746540887014, 0.12168776456798826, 0.08399315617446389, 0.07165730811123337, 0.1363618985882827, 0.13243162019976548], [0.02797904544110809, 0.058471038538430414, 0.052180225029587746, 0.047146048197256665, 0.12305330272231783, 0.05383909047980394, 0.05742276978812047, 0.03936723114124366, 0.12425885588995048, 0.04524984476821763, 0.07952956961733954, 0.10967379994690418, 5.746229716709681, 61.421943528311594, 58.00946780613491, 49.78814383915493, 36.05270515169416, 19.71269600731986, 28.47685841151646, 42.43831157684326, 35.07875531060355, 55.213158335004536, 35.79272787911551, 0.27437035739421844, 0.0885078635598932, 0.9839891195297241, 2.5927459256989613, 2.4221911004611423, 2.3531583590166907, 45.450710024152485, 59.650180680411204, 58.9572993687221, 51.95291416985648, 55.99428524289812, 56.3712979725429, 56.33352061680385, 53.47735936301095, 53.89760725838797, 50.520136560712544, 45.19706950868879, 39.608682019369944, 38.8018467766898, 37.81190913064139, 39.37760925292969, 38.344175883701865, 39.70725263868059, 38.390972001211985, 37.8081362588065, 38.1058874130249, 37.35352604729788, 37.986197744097026, 38.49205786841256, 37.15565872192383, 36.518898010253906, 37.89459269387381, 37.91862998689924, 38.07957805906023, 37.12868234089443, 37.574065344674246, 37.383226122174946, 37.175329072134836, 37.27291304724557, 37.29813848223005, 37.46600696018764, 37.754906109401155, 36.7737648827689, 38.62201350075858, 36.53121369225638, 39.308884620666504, 37.28257104328701, 36.48127351488386, 38.05409206662859, 35.93684046609061, 35.948534284319194, 38.68738562720162, 35.136310713631765, 37.285749844142366, 36.655301570892334, 37.6839337348938, 37.45480646405901, 45.33198268072945, 45.5865021433149, 48.65117883682251, 44.3893518447876, 52.54472698484148, 44.9941543170384, 53.34046942847115, 22.730366400309972, 25.46428452219282, 53.51977811540876, 41.924936975751606, 47.942288875579834, 42.617550781794954, 48.670949935913086, 44.8000042779105, 50.62063530513218, 45.079763071877615, 48.30071169989449, 47.48361049379621, 47.33877876826695, 45.51248298372541, 45.01830972943987, 36.24302673339844, 37.45305551801409, 35.723436968667166, 37.25946133477347, 34.93388189588274, 36.721973010471885, 36.62752614702497, 37.36402130126953, 36.57215247835432, 38.61605542046683, 36.8495488848005, 37.591738087790354, 35.73798302241734, 37.76631852558681, 37.09897531781878, 37.883124692099436, 37.70817947387695, 35.96403571537563, 35.676769392830984, 42.361506189618794, 45.65024144308907, 47.947830063956125, 47.21928712299892, 45.711531502859934, 42.00667558397566, 39.477764061519075, 36.664382866450715, 36.35758168356759, 37.97164126804897, 44.84141901561192, 49.74139288493565, 51.87816892351423, 52.386433124542236, 53.30047559738159, 50.77659109660557, 52.19250890186855, 51.06949935640608, 51.298522404261995, 50.78685706002371, 45.923774651118684, 43.8054530279977, 50.56961815697806, 53.561884198869976, 53.56097745895386, 44.82124492100307, 5.226789338248117, 0.37477559968829155, 3.028985317264284, 0.28195157487477573, 0.10840468161872455, 0.1147179478513343, 28.13950773647853, 53.407144342150005, 48.279867104121614, 45.843210288456504, 16.96732551710946, 16.162329810006277, 34.40477309908186, 46.314725467136924, 49.156441416059224, 42.526251452309744, 1.2776068555457252, 0.08133652194270066, 0.04668960786823716, 0.029849111701228788, 0.042462863959372044, 0.026567838487348387, 0.11305516386138541, 0.03030540614521929, 0.0349176597249295, 0.06324573340160505, 0.02419741202278861, 0.0670849931027208, 0.05251438656289663, 0.015480089433757322, 0.047033991531601975, 0.077312171459198, 0.06915428742234196, 0.06920106562652759, 0.059591232000717094, 0.027987099651779448, 0.06649619434028864, 0.12511256150901318, 0.06890152634254523, 0.0986043560717787, 0.11965081601270608, 8.116885593959264, 70.51510660988944, 64.7644578388759, 55.93044866834368, 43.92954438073294, 23.847666263580322, 27.38996386528015, 41.4929118837629, 35.92999301637922, 62.525400842939106, 40.51539414269583, 0.18785721037004674, 0.04963188498680081, 2.9955182330948964, 10.139540076255798, 4.134065253393991, 2.7607160210609436, 48.54271050861904, 60.797189303806846, 62.39626857212612, 53.787499155317036, 58.32117789132254, 56.70473854882376, 58.55192061832973, 56.462434019361226, 54.367298534938264, 50.81376395906721, 46.77962596075875, 41.4966847555978, 41.15278019223894, 40.120038168770925, 41.90898738588606, 40.45241914476667, 40.87934078489031, 40.90590374810355, 42.08833428791591, 38.62328502110073, 39.464628492082866, 39.44948489325387, 40.4834497996739, 38.86069107055664, 38.32436656951904, 38.80163138253348, 39.01825884410313, 40.00416306086949, 39.27836813245501, 39.56461654390608, 39.8283771106175, 38.98005417415074, 39.189295700618196, 38.697894777570454, 38.29048367909023, 40.17796877452305, 40.27526092529297, 40.53056900841849, 39.32700204849243, 40.122876507895334, 40.75974491664341, 38.53219066347395, 39.12758527483259, 38.72473219462803, 38.780432428632466, 40.32740020751953, 37.4240711075919, 39.12069613592965, 37.75924873352051, 39.12087331499372, 38.37258359364101, 46.49726506641933, 48.80004399163382, 47.91053213391985, 47.25405590874808, 52.735837187085835, 47.86946133204869, 54.184307302747456, 22.943773371832712, 26.69301438331604, 56.14732279096331, 44.31074687412807, 48.93481125150408, 43.719542026519775, 49.52011013031006, 48.3820264680045, 51.33480242320469, 47.18264927182879, 49.97295202527727, 48.912278243473594, 47.23295422962734, 47.090457098824636, 46.0874012538365, 38.66677379608154, 37.87234456198556, 37.58886500767299, 38.03208017349243, 37.3123961857387, 38.35033893585205, 38.61511046545846, 39.662568773542134, 38.057722500392366, 39.990843364170615, 38.1947375025068, 39.59113434382847, 39.16741929735456, 39.0798476764134, 38.949944155556814, 40.03854622159685, 39.53556612559727, 40.59949861254011, 38.40427085331508, 46.16055883680071, 47.702159132276265, 49.725755964006694, 48.65722724369594, 46.90919596808297, 45.75025381360735, 40.64804220199585, 39.03404515130179, 38.16051067624773, 40.49191270555769, 46.23362956728254, 52.57021297727312, 52.775632994515554, 53.06285067967006, 54.22739308220999, 54.21450764792306, 54.3615072114127, 53.567672048296245, 52.463075229099815, 51.79038538251604, 47.535440581185476, 45.00640051705496, 51.99914400918143, 57.27698523657662, 54.2326910836356, 49.0496997152056, 6.074850414480482, 0.9557243904897145, 3.4687496168272833, 0.7945617384144238, 0.04935303084286196, 0.05220944953284093, 29.44648994718279, 57.84239142281668, 49.60882125582014, 47.953822885240825, 20.873375211443218, 23.683216299329484, 40.0820871080671, 53.672006198338096, 54.159342425210134, 52.19435017449515, 2.2813324417386736, 0.19684056618383952, 0.05738577605890376, 0.1042002954387239, 0.09185800807816641, 0.026901178993284702, 0.10498294487063374, 0.06007809444729771, 0.06358778290450573, 0.011669791303575039, 0.01253826608548739, 0.014425128631825958, 0.020068204130179117, 0.11638909817806312, 0.2006156907549926, 0.22629566277776444, 0.18158764179263795, 0.27063808909484316, 0.23815325221845082, 0.15852602784122738, 0.10670136194676161, 0.2900913080998829, 0.20652792922088078, 0.278109112488372, 0.4071390059377466, 10.759385398456029, 79.47985308510917, 71.99772017342704, 64.15047332218715, 49.8956116267613, 29.182993412017822, 37.81961120877947, 51.71887104851859, 47.07889182226998, 65.90380954742432, 44.28477450779506, 0.5403216694082532, 0.2254697499530656, 1.8423163763114383, 8.032576152256556, 4.974470283303942, 4.676861132894244, 52.332261494227815, 63.514254570007324, 64.23145457676479, 56.70151111057827, 60.160206249782014, 59.48461900438581, 60.87956714630127, 58.46547113146101, 56.399146352495464, 53.95701783043997, 50.83833278928484, 43.171819005693706, 43.784789085388184, 41.24259955542428, 44.12862416676113, 43.54947096960885, 42.934089865003315, 42.75696291242327, 43.27556603295462, 40.66339772088187, 41.4636356489999, 41.053222928728374, 41.08123459134783, 40.438581807272776, 39.69749736785889, 40.54949937547956, 39.757178919655935, 41.738235405513215, 41.647620473589214, 42.155957630702424, 41.296545369284495, 40.85510894230434, 41.05344874518258, 40.05004896436419, 40.981190953935894, 41.968668937683105, 41.13981832776751, 42.634368896484375, 41.48940999167306, 43.55117327826363, 43.091692379542756, 40.070716381073, 39.97852420806885, 39.26831408909389, 40.72381230763027, 42.92114189692906, 38.881070137023926, 40.77289438247681, 40.82943187441145, 40.24243416104998, 40.19883074079241, 48.34860910688128, 51.50045789991106, 52.35684074674334, 48.44425106048584, 54.97651311329433, 50.68309266226632, 55.63203396115984, 25.852548122406006, 30.424747671399796, 57.34062031337193, 47.3313615662711, 49.67721932274954, 45.535731656210764, 51.5575338772365, 48.819564955575125, 54.39174577168056, 50.817901611328125, 54.00599915640694, 51.41639164515904, 49.1925824710301, 50.566272599356516, 49.16364669799805, 40.2182057925633, 40.33990001678467, 40.16249861036028, 41.08818973813738, 39.14207574299404, 40.28947693961007, 41.38986315046038, 42.025324548993794, 41.02079916000366, 41.99477679388863, 40.04421942574637, 41.111077104296, 39.912304401397705, 41.06218263081142, 41.844431672777446, 40.567463942936485, 41.08972529002598, 41.61650991439819, 39.77585915156773, 47.66572625296456, 50.449921539851594, 52.19746644156319, 50.55465521131243, 49.19700847353254, 48.3162339755467, 42.82530886786324, 41.297274930136545, 39.77544920785086, 41.80805090495518, 48.87438971655709, 56.617104394095286, 54.51393331800188, 58.23611109597342, 56.73863533564976, 54.111441544124055, 56.241338866097585, 55.949198382241384, 54.100998401641846, 54.6193722316197, 50.44535657337734, 48.24843692779541, 54.390769549778526, 59.448509216308594, 56.134294918605256, 52.07446943010603, 7.1993646792003085, 4.121865953717913, 9.896497300692968, 1.145353649343763, 0.1442434356680938, 0.44647520088723724, 33.03656162534441, 68.21878950936454, 55.670523507254465, 52.20785052435738, 24.437578746250697, 25.091977460043772, 45.11395515714373, 59.11858095441546, 60.65508474622454, 59.52680846623012, 3.1034862909998213, 0.31782414710947443, 0.1344229576310941, 0.12975788010018213, 0.18670083742056573, 0.10503238293209247, 0.34387514208044323, 0.14450160467198916, 0.12764209934643336, 0.09764451400509902, 0.08536246698349714, 0.1877549144306353, 0.10624896229377814], [0.03809665057009884, 0.007071186031680554, 0.031179366034588644, 0.09456698450126819, 0.029628445327814137, 0.05498963142079966, 0.10584281158766576, 0.014584413031116128, 0.145911396880235, 0.09452011808753014, 0.11054520854460341, 0.07276511830942971, 13.348835706710815, 66.75054482051304, 52.28206423350743, 50.03632307052612, 35.14138637270246, 22.765348843165807, 30.201512472970144, 38.893076624189106, 32.75546530314854, 60.77420466286795, 22.229059083121165, 0.07908241504005023, 0.20515442506543227, 2.599253782204219, 6.832135447434016, 3.2192725922380174, 11.449696745191302, 56.983649662562776, 56.55848939078194, 58.1716422353472, 53.13123137610299, 57.83866024017334, 53.013296127319336, 53.76775237492153, 54.17262390681675, 55.671635219029014, 50.92161737169538, 51.99139676775251, 46.39168718882969, 43.667395796094624, 40.01622860772269, 38.127645696912495, 39.618517194475444, 38.252310276031494, 36.7430225781032, 38.74459709439959, 36.93837465558733, 38.62460170473371, 38.21622828074864, 38.521452222551616, 36.519512925829204, 37.257074628557476, 36.92750072479248, 36.248237882341655, 36.21746778488159, 36.193948132651194, 37.65570667811802, 36.71872820172991, 36.55793646403721, 38.1762935093471, 37.37239735467093, 38.21093027932303, 37.285259996141704, 37.368346554892405, 35.45111969539097, 37.18199239458357, 38.29176909582955, 35.816657475062776, 37.47359439304897, 36.96761614935738, 37.32717500414167, 36.1072485106332, 36.36867448261806, 36.62369768960135, 36.78496190479824, 35.24003689629691, 38.12003741945539, 36.90061467034476, 41.06750495093209, 42.78515870230538, 46.90895972933088, 44.11209440231323, 51.06795685631888, 45.73004845210484, 54.7145972933088, 26.652353525161743, 22.654558079583303, 55.95423582621983, 41.987363065992085, 49.19886016845703, 44.05681800842285, 49.50543206078665, 45.70608411516462, 48.41202531542097, 44.67727477209908, 47.917963232312886, 45.743774618421284, 48.97128929410662, 43.25064631870815, 44.91230801173619, 38.51244388307844, 36.5927643094744, 35.15191984176636, 36.29334211349487, 35.77448190961565, 37.77761629649571, 35.32412052154541, 36.48081145967756, 36.464573519570486, 38.63454457691738, 37.04711396353585, 38.18047979899815, 36.98490326745169, 36.42473602294922, 38.31675134386335, 37.49541868482317, 37.22081198011126, 37.580290930611746, 41.48693643297468, 46.46784291948591, 47.40430722917829, 48.45232139314924, 47.821800163814, 45.324277128492085, 40.14774758475167, 38.53750603539603, 38.45001431873867, 37.46778917312622, 37.62509638922555, 36.73588677815029, 41.16812181472778, 47.31978586741856, 50.04511601584298, 53.26041923250471, 52.39279767445156, 50.957067080906455, 52.2461142539978, 51.99423163277762, 46.45090668542044, 42.14331538336617, 43.15738064902169, 51.958882672446116, 54.53203337533133, 56.00951222011021, 52.93879059382847, 15.71854489190238, 1.4604641177824564, 1.6029250962393624, 1.3066775756222861, 0.11193772525127445, 0.09040310007653066, 15.17420390674046, 52.04068728855678, 30.962715421404155, 28.832521063940867, 15.915152856281825, 14.629300117492676, 31.118296010153635, 45.97995431082589, 50.50816134044102, 52.6409456389291, 3.4880554037434712, 0.12350564130714961, 0.030452278442680836, 0.02307212445884943, 0.010730373140956675, 0.062412580608257225, 0.0064162220473268205, 0.04716682154685259, 0.09172697618071522, 0.05749250283198697, 0.022524746866630654, 0.019315204982246672, 0.013062003517656453, 0.07338053600064345, 0.04923095900033202, 0.09560320246964693, 0.023963012100596513, 0.010048188452076699, 0.015364227882985557, 0.07659117371908256, 0.05383382844073432, 0.10797123344881193, 0.023441376430647712, 0.19377589491861208, 0.10292879545262881, 18.678420169012888, 75.58765983581543, 58.857655252729145, 56.448336124420166, 41.19866956983294, 29.453705651419504, 27.359607185636246, 38.78675528935024, 35.494865553719656, 67.27422360011509, 24.43930537360055, 0.11293937186045305, 0.051650105975568295, 1.7974985412188937, 7.929596900939941, 2.631232649087906, 13.034561736243111, 57.91974919182913, 59.807057108197895, 59.51485756465367, 55.66144221169608, 57.4253431728908, 55.84055287497384, 56.179399149758474, 56.2748361315046, 58.11124849319458, 55.07681383405413, 53.010714871542795, 48.65305485044207, 44.92761836733137, 42.536962100437705, 40.519142695835654, 39.98269312722342, 39.86344466890608, 39.6487592288426, 40.89368881498064, 39.77104752404349, 38.99185568945748, 40.072686195373535, 39.728055545261924, 39.04030895233154, 39.70967755998884, 37.40565838132586, 40.04677288872855, 38.01160383224487, 38.130980832236155, 38.509556906563894, 38.882800238473074, 39.49139642715454, 38.97699349267142, 39.09279217038836, 38.51670660291399, 39.343031542641775, 38.492363589150564, 37.8861471584865, 39.591610295431956, 39.58674308231899, 37.841953141348704, 38.77566943849836, 37.691177231924875, 39.2515480858939, 38.3423102923802, 39.29413359505789, 38.01338951928275, 38.18376282283238, 37.96812200546265, 39.88254526683262, 38.509883471897666, 41.8864300591605, 43.94532373973301, 49.29460634504046, 46.24337094170706, 51.36576359612601, 47.441104888916016, 56.43069117409842, 28.123235055378505, 24.70484467915126, 55.78776046207973, 43.91307715007237, 49.15734468187605, 45.319225788116455, 52.875277110508506, 47.841394083840505, 49.65817778451102, 47.47162137712751, 49.01502125603812, 48.40240553447178, 50.301171030317036, 46.03096451078142, 45.806965010506765, 40.98515837533133, 38.41093070166451, 35.880139691489084, 38.57197257450649, 37.65515429633004, 39.82406575339181, 37.29191289629255, 37.84622628348214, 39.71527780805315, 40.03553417750767, 36.71333639962332, 40.26399442127773, 39.11701706477574, 39.15569421223232, 39.62890475136893, 38.590232440403526, 37.83097498757498, 39.06799404961722, 42.78197990145002, 47.13512011936733, 49.634713717869346, 51.28468854086739, 49.349316460745676, 47.65659632001604, 41.770197119031636, 41.00084740774972, 38.47493403298514, 39.06385292325701, 39.52133274078369, 39.95179796218872, 43.010426248822895, 48.85321855545044, 53.044191292354036, 53.51756164005825, 53.43364824567522, 52.697625568934846, 53.292109966278076, 53.38348225184849, 48.13567461286272, 44.76934882572719, 45.26737485613142, 54.32501527241298, 56.210322107587544, 57.79483100346157, 54.4761038507734, 17.49736363547189, 0.6009252688714436, 1.6359313194240843, 1.9548895699637276, 0.06574586353131703, 0.08264347538352013, 14.508480497768947, 58.09357575007847, 35.79807104383196, 33.352464948381694, 19.412096091679164, 20.749434982027324, 34.88201011930193, 51.52287973676409, 55.207367011478965, 59.748733929225374, 6.812915427344186, 0.27837254692401203, 0.023021563421934843, 0.03905080651332225, 0.0244851057816829, 0.06085057942462819, 0.05305947070675237, 0.03320037580228277, 0.05045546704371061, 0.05462752781542284, 0.039997708917196305, 0.04295262035780719, 0.028355583182669113, 0.21053896684731754, 0.13295714557170868, 0.2103694552289588, 0.2342891309942518, 0.07585982153458254, 0.1556122899055481, 0.13938531492437634, 0.14391784742474556, 0.24557601820145333, 0.1766223260866744, 0.3189790951354163, 0.2054565359971353, 23.436324221747263, 84.75241020747593, 64.65350900377545, 64.84357697623116, 45.39769179480416, 32.70997197287423, 37.87189640317644, 51.48843404224941, 43.42052282605852, 72.0401667186192, 29.781233310699463, 0.3990067094564438, 0.27873702879462925, 4.360032396657126, 12.020048311778478, 5.792152966771807, 14.643740211214338, 61.79879992348807, 61.11202607836042, 63.240474700927734, 56.582613536289756, 61.343505314418245, 57.21427427019392, 59.33778967176165, 57.705251353127615, 60.66493034362793, 56.282388823372976, 56.03667272840227, 50.96074962615967, 48.96148885999407, 45.50021593911307, 42.16036973680769, 43.1522980417524, 42.581760610852925, 40.462608678000315, 43.66583592551095, 40.979544230869834, 42.032905033656526, 41.868347372327534, 42.04231289454869, 40.0232115473066, 41.59243788037981, 40.02562257221767, 42.04223993846348, 39.40040281840733, 40.192730222429546, 41.626800196511404, 41.338196345738, 41.08470869064331, 41.84044688088553, 41.07933078493391, 40.901210239955354, 40.87133993421282, 42.27507059914725, 37.936570235661094, 41.546357427324565, 42.316502707345144, 39.62883874348232, 41.30062048775809, 39.12724828720093, 41.93815244947161, 40.299621309552876, 40.504103319985525, 40.28259474890572, 39.110798427036826, 39.48083863939558, 43.96342727116176, 41.78122043609619, 43.24910729272025, 46.144769055502756, 50.45804745810372, 47.67139250891549, 52.48166513442993, 49.97914287022182, 56.13666772842407, 30.376812049320765, 27.42518080983843, 59.0651284626552, 45.594857352120535, 51.10532079424177, 47.587489536830354, 55.435295718056814, 49.23624495097569, 51.67186301095145, 49.41312871660505, 51.76202283586775, 48.84418937138149, 52.64030293055943, 47.023851667131694, 48.89587354660034, 42.82681662695748, 39.76825087411063, 38.16610745021275, 39.753850732530864, 39.84965944290161, 41.85166127341134, 38.76553896495274, 39.89653199059622, 39.77775253568377, 41.68119069508144, 40.10609660829817, 42.473980154309956, 41.41153458186558, 40.66144527707781, 42.47534547533308, 40.31194393975394, 39.40265056065151, 42.15125022615705, 44.85309198924473, 49.628085136413574, 51.901118823460166, 54.38767760140555, 52.009430817195344, 50.787888867514475, 44.118973118918284, 43.002595629010884, 42.420708315713064, 41.071448053632466, 41.457938126155305, 41.095989091055735, 45.61218615940639, 51.36786195210048, 54.80563259124756, 57.48279435294015, 56.12746831348964, 52.90923295702253, 56.17972918919155, 55.66954728535244, 52.15922008241926, 45.677874428885325, 47.57230772290911, 56.04514258248465, 60.56238882882254, 59.43665558951241, 59.14581094469343, 18.09729368346078, 3.3896482842309132, 6.243380274091448, 2.384932036910738, 0.2451044906462942, 0.2116396456424679, 18.63207915851048, 64.11216790335519, 41.46958678109305, 42.71644449234009, 21.588551555361065, 22.255568197795323, 41.533253124782014, 59.05132239205496, 61.87305532182966, 70.17632634299142, 10.322261197226387, 0.5100623731102262, 0.1514281037130526, 0.12516338378190994, 0.16823141276836395, 0.16389581827180727, 0.15030614605971745, 0.12447429075837135, 0.13523273489304952, 0.17965297560606683, 0.15041362600667135, 0.10462598116802317, 0.14572038927248546], [0.025564403938395635, 0.03340682347438165, 0.056281487457454205, 0.01978156210056373, 0.03256116867331522, 0.04719846163477216, 0.04747434379532933, 0.04560737165489367, 0.03893711118559752, 0.022247410944796035, 0.07578391382204634, 0.07714681926050357, 26.21577215194702, 64.30855873652867, 50.59743527003697, 49.31584003993443, 25.884707859584264, 14.10814266545432, 27.378678253718785, 36.90228223800659, 37.83859716142927, 56.447735105242046, 8.634899854660034, 0.01765917580840843, 0.02612651082953172, 6.163646221160889, 11.646230884960719, 3.746059605053493, 22.348719222205027, 55.4812649999346, 61.5841839654105, 56.05147933959961, 55.687414578029085, 56.60684885297503, 56.219952310834614, 53.23984909057617, 52.858917576926096, 54.062908376966206, 54.20300490515572, 52.55051483426775, 52.81439004625593, 48.91547441482544, 44.723490715026855, 40.28520379747663, 39.414181096213206, 37.35252203260149, 37.338372026171, 37.69224030630929, 37.68153313228062, 38.3197842325483, 38.4662765775408, 38.249624797276084, 36.730439390454976, 37.117231709616526, 38.6582726751055, 36.00824015481131, 36.29533624649048, 34.70523405075073, 36.3677955354963, 37.50468063354492, 38.1564598764692, 36.119824750082834, 37.08672911780221, 36.45321321487427, 37.358483586992534, 37.02951765060425, 38.226525511060444, 36.96087987082345, 37.16837739944458, 35.32484660829817, 38.30098588126046, 36.59735359464373, 36.14061376026699, 37.540415218898225, 39.29380355562483, 37.3212377684457, 38.64845139639718, 36.87448596954346, 38.657094955444336, 36.31381845474243, 40.563767501286094, 37.02541821343558, 42.0094826562064, 40.35452250071934, 47.43406636374337, 44.15391213553292, 54.899193559374126, 31.847505978175572, 21.489880187170847, 53.66657618113926, 42.64930752345494, 49.47733701978411, 44.45835093089512, 50.733039787837434, 45.059679303850444, 49.75269065584455, 45.81480605261666, 47.1764132635934, 46.13170296805245, 47.59003952571324, 44.39619582039969, 44.52756193705967, 38.579351561410085, 36.79427249091012, 35.42063447407314, 37.08992528915405, 35.3156749861581, 37.477697304316926, 35.1719514983041, 37.4567415373666, 36.875667163303916, 37.34424672807966, 37.88695314952305, 39.366947242191856, 38.1238728250776, 39.206739153180806, 37.51808370862688, 35.92263487407139, 37.116106101444785, 39.12230116980416, 42.75964491707938, 47.755948611668174, 47.713168552943635, 47.52923583984375, 48.72239439828055, 43.59673261642456, 37.01938370295933, 38.307895864759175, 36.75786740439278, 37.27537965774536, 38.72313410895211, 40.73469318662371, 40.37165675844465, 40.957671301705496, 43.20063318525042, 46.164387294224326, 49.173943928309846, 48.10277141843523, 47.463227953229634, 45.09504910877773, 42.254351070949006, 41.20526341029576, 45.237254415239605, 50.26394953046526, 54.42448568344116, 51.5430850982666, 54.953389508383616, 28.345773696899414, 2.5639439054897855, 1.6726955409560884, 1.044796279498509, 0.041117495258471796, 0.0843516465808664, 3.365328069244112, 50.62985903876168, 43.11001130512783, 33.97502701623099, 30.2299861907959, 17.84343429974147, 30.784303052084788, 40.912462847573416, 46.29231057848249, 49.809777055467876, 10.716866765703474, 0.31885500465120586, 0.0934278666973114, 0.08685033821633883, 0.03816819530246513, 0.0297095404405679, 0.04344730631315282, 0.03445183186392699, 0.015361108318237322, 0.01848659328451114, 0.032132446499807496, 0.05485231628907578, 0.011820566025562584, 0.002155859484836193, 0.04675317302878414, 0.05799782821642501, 0.01924741254853351, 0.015744629881477783, 0.09504617950213806, 0.10176955908536911, 0.07365294066923005, 0.09615200159272977, 0.07589143448110137, 0.056047325022518635, 0.05374044166611774, 34.10604224886213, 70.92144421168736, 57.48600442068917, 53.14018760408674, 33.61904648372105, 21.119949408939906, 27.676623957497732, 40.23537131718227, 42.81876366479056, 63.578039033072336, 9.465315546308245, 0.11870520961071764, 0.05475111279104437, 5.432027833802359, 9.464054448263985, 3.142778571162905, 24.271226712635585, 57.396681853703086, 62.469453947884695, 59.18425532749721, 57.614525250026155, 58.19109371730259, 55.86695255552019, 55.00601863861084, 54.667818546295166, 55.59461791174752, 57.393277236393516, 55.4389956338065, 54.66241979598999, 50.0403391293117, 47.91914095197405, 42.207589694431846, 39.81986904144287, 39.832160404750276, 39.536855016435894, 39.509562492370605, 38.934758867536274, 39.352078097207205, 38.4166316986084, 40.03986637932913, 38.97887645448957, 39.715899671827046, 39.822752543858115, 39.47880629130772, 37.90710292543684, 37.961097376687185, 38.99397489002773, 39.08027499062674, 39.24235214505877, 37.872952529362266, 38.88637508664812, 38.001779079437256, 39.50623083114624, 38.7215290750776, 40.18903725487845, 38.07616996765137, 38.46755852018084, 38.113342830113, 39.526411873953684, 38.87746054785592, 38.07002428599766, 38.662726470402305, 41.892547948019846, 38.476476533072336, 40.44216707774571, 39.59653309413365, 41.33190475191389, 38.67678267615182, 41.25553362710135, 38.4230101449149, 44.07175316129412, 43.41779913221087, 48.592775753566194, 46.84542192731585, 56.05595745359148, 33.875844955444336, 22.790329354149954, 56.755720955984934, 44.71158497674124, 49.23106854302542, 46.72769512448992, 52.68406615938459, 46.59435224533081, 50.470950262887136, 47.5930689402989, 49.901865005493164, 47.680112498147146, 49.18541193008423, 46.604663372039795, 45.52058458328247, 40.42039489746094, 37.54608494894845, 36.646237645830425, 37.96410594667707, 36.87011207853045, 39.56557192121233, 35.71408816746303, 38.27801513671875, 38.32496064049857, 39.79073177065168, 38.896102564675466, 40.14351960590908, 39.35591002873012, 39.176646505083355, 39.654977866581504, 37.67676666804722, 39.24709776469639, 40.51410525185721, 46.13370057514736, 50.254041399274556, 48.77826138905117, 48.72878326688494, 50.93554156167166, 46.24901635306222, 38.595745835985454, 38.1516239302499, 39.00486619131905, 38.99248102733067, 40.496901512145996, 42.49390063967024, 42.08299112319946, 42.111419677734375, 45.27911383765084, 48.62623132978167, 52.34992381504604, 51.12007529394967, 50.052738189697266, 46.994655336652485, 43.20714712142944, 43.220018659319194, 47.200544357299805, 50.99374662126814, 57.935236726488384, 53.750649384089876, 55.893897669655935, 30.28697531563895, 3.2890750638076236, 1.8991105173315321, 2.9344783084733144, 0.3582011604947703, 0.09319510204451424, 3.531027840716498, 55.794493266514365, 47.73937368392944, 38.51475068501064, 27.16459035873413, 19.3050434589386, 35.31895453589303, 45.28059032985142, 51.69527844020298, 59.3368238721575, 16.941712720053538, 0.39985509536096026, 0.16771827744586126, 0.08651121998471872, 0.08039538030113492, 0.07719762117734977, 0.02241134500530149, 0.019666820132572736, 0.06532672566494771, 0.026679104659706354, 0.008052106364630163, 0.05821229277976921, 0.029361692855932882, 0.15735722413020475, 0.13288703933358192, 0.15126355897103036, 0.11498292934681688, 0.1883151400834322, 0.3002251200377941, 0.23812958491700037, 0.15861089900135994, 0.14499671810439654, 0.1922635082155466, 0.17078096738883428, 0.22763061257345335, 41.387938499450684, 79.01956272125244, 62.77395180293492, 62.2607786996024, 35.89032922472273, 21.95406675338745, 38.034098625183105, 49.79571042742048, 48.24549783979143, 69.38644817897251, 12.204263295446124, 0.22053906667445386, 0.09669329611850636, 13.984494260379247, 23.757007905415126, 6.7541245477540155, 26.45525050163269, 58.48220239366804, 64.22303336007255, 59.43694741385323, 57.256185804094585, 60.43205451965332, 56.007493768419536, 55.685399600437705, 57.53355441774641, 58.7335604258946, 59.06959615434919, 57.154262678963796, 56.635273933410645, 52.32173844746181, 50.157218251909526, 45.61026498249599, 42.94558913367135, 41.98324278422764, 40.985849721091135, 41.557703835623606, 40.587488651275635, 40.883117130824495, 41.72919579914638, 41.225319385528564, 40.64226824896676, 41.54005888530186, 41.78476401737758, 41.07862206867763, 39.90818064553397, 38.894462789808, 40.66409254074097, 41.77584253038679, 42.01658371516636, 40.01126411982945, 40.92707143511091, 40.878513949257986, 41.29357501438686, 41.6035932132176, 42.01996053968157, 40.507198742457796, 39.88975749697004, 37.70023420878819, 41.53921815327236, 39.45118025371006, 39.75311769757952, 40.75469357626778, 42.90061691829136, 40.87864943913051, 42.2137770652771, 40.977609157562256, 44.77268396105085, 40.082340717315674, 44.30325671604702, 40.058220045907156, 45.837415490831646, 46.06638295309884, 50.482466902051655, 49.86591155188424, 58.17241695949009, 36.054584639413015, 25.892269236700876, 57.92530427660261, 47.44221312659127, 50.901210512433735, 48.877610206604004, 54.9333404813494, 47.695572240012034, 53.48486689158848, 49.12226670128958, 51.187208788735525, 49.05336141586304, 49.683642932346885, 48.89951440266201, 48.06358010428292, 42.22715582166399, 38.574609415871755, 38.74704286030361, 39.519644328526084, 38.537985461098806, 42.84368685313633, 37.61485127040318, 40.33128425053188, 40.44049951008388, 41.41970566340855, 41.93120077678135, 41.88736111777169, 41.93818024226597, 43.671717575618196, 41.27822296960013, 39.75133548464094, 40.707848821367534, 42.66538218089512, 47.83982031685965, 53.47265543256487, 50.86639656339373, 50.845847266060964, 53.073620387486045, 48.23737192153931, 39.95049170085362, 40.6516934803554, 40.93859849657331, 40.15881953920637, 44.16280582972935, 45.41593429020473, 44.675176416124614, 45.12307466779436, 47.96127135413033, 50.723034381866455, 55.259787695748464, 54.43085023335048, 53.74985728945051, 48.962385177612305, 45.97623355048043, 45.420839718409944, 49.640373025621685, 55.027710914611816, 61.658369881766184, 54.879693440028596, 59.22712571280343, 33.40339524405343, 4.639865015234266, 6.200606295040675, 4.861481283392225, 0.6154227395142827, 0.18688907660543919, 4.58523610660008, 60.542482239859446, 52.92944179262434, 48.218625681740896, 41.2028489112854, 25.082897901535034, 42.300323826926096, 54.630798544202534, 59.26176248277937, 66.73354952675956, 23.553625447409495, 0.605815660740648, 0.24071398909602845, 0.17896624388439314, 0.20682723101760658, 0.12211034260690212, 0.15184532132531914, 0.0928605232121689, 0.14726184441574983, 0.06944473433707442, 0.09354268839316708, 0.12543318287602492, 0.17077469772526196], [0.07954576624823467, 0.02545960420476539, 0.03866766832236733, 0.023963252980528132, 0.038551299566669125, 0.014747010377634848, 0.06562247193817582, 0.07803558478397982, 0.06900670605578593, 0.023396884889474938, 0.05100921607975449, 0.35878209503633635, 34.6624435697283, 57.53916161400931, 47.519671644483296, 36.90715639931815, 18.457592521395, 22.090242760522024, 39.36728770392281, 34.48844678061349, 46.489479609898154, 49.75621339253017, 2.6634177906172614, 0.08690569988851037, 0.05093714887542384, 1.2015868318932397, 3.224946230649948, 6.65677854844502, 37.313111850193565, 55.64462757110596, 57.311059202466694, 56.41016272136143, 58.190916538238525, 55.757028579711914, 56.749530111040386, 56.71628645488194, 59.10745688847133, 54.68408080509731, 54.34779494149344, 52.26373488562447, 52.348134653908865, 51.61361278806414, 49.96744210379464, 44.68688760484968, 41.71285016196114, 38.18187638691494, 37.92024196897234, 37.05863755089896, 38.148542404174805, 38.3668270111084, 37.27323266438076, 36.9104984828404, 35.886990615299766, 37.391859258924214, 36.03763450895037, 36.106661387852256, 37.485534872327534, 35.38075181416103, 37.79986442838396, 36.9932028906686, 39.89890827451433, 38.00644132069179, 36.90704870223999, 36.391888414110454, 36.90818125861031, 36.09842777252197, 36.16527986526489, 37.67953552518572, 37.59850563321795, 36.819081033979145, 39.16997970853533, 34.666845253535676, 38.42036982945034, 40.35345942633492, 42.051178795950754, 42.50078977857317, 43.503293241773335, 41.13640676225935, 41.48506736755371, 40.304954051971436, 40.890610763004844, 43.53552940913609, 45.238369601113455, 43.25911964688982, 48.36372838701521, 45.13629708971296, 53.60877064296177, 37.69398430415562, 26.22199773788452, 54.06057030814034, 44.32429238728115, 48.38678250994001, 46.248912130083355, 50.360123021262034, 44.23504277638027, 46.37145403453282, 44.043366295950754, 47.85858392715454, 45.342224325452534, 49.50581073760986, 43.087370600019185, 43.44762427466256, 38.24707480839321, 37.02086019515991, 34.56033631733486, 36.716879980904714, 37.358500957489014, 37.371525355747764, 36.23599863052368, 37.04700626645769, 37.77007055282593, 37.12871708188738, 36.46899952207293, 39.10612228938511, 37.99965293066842, 38.60058178220476, 37.52932589394705, 36.930992194584434, 37.73393644605364, 43.09789712088448, 46.07187897818429, 48.39757653645107, 47.16924967084612, 48.97417974472046, 46.90026405879429, 41.82840912682669, 38.88360970360892, 37.40876770019531, 37.93316214425223, 39.06069496699742, 39.51642383847918, 37.45417765208653, 39.14153725760323, 38.405514580862864, 39.41762392861502, 40.285255908966064, 40.39331776755196, 39.93349640710013, 38.483702659606934, 37.53421742575509, 38.25193854740688, 39.8301454271589, 42.31943484715053, 49.30147463934762, 52.96211569649832, 55.097793919699534, 52.504965918404714, 41.44831487110683, 7.796136770929609, 0.8198614322713443, 1.893407131944384, 0.3634127437004021, 0.10615921925221171, 0.3628309406340122, 30.013014793395996, 48.536936555589946, 32.17958470753261, 40.46865708487374, 20.453174216406687, 25.8615825176239, 41.34333801269531, 42.71111869812012, 51.95395987374442, 20.374018601008824, 0.18031257949769497, 0.03273233252444437, 0.005674090061802417, 0.006330495084902006, 0.008613565254823437, 0.019488092312323194, 0.027236127627215216, 0.03528390917927027, 0.04635073390922376, 0.053129858536911864, 0.03970906012026327, 0.015858801880053112, 0.03799097213361945, 0.044738097049828084, 0.02656610313403819, 0.013036924015198435, 0.08287573792040348, 0.016554374913019792, 0.04678499971383384, 0.05627301934042147, 0.03910982548924429, 0.03356524443786059, 0.05158080040876355, 0.7675991994994027, 43.34336655480521, 66.22042506081718, 51.62072079522269, 45.61991603033883, 24.704865523747035, 16.803283759525844, 40.64441524233137, 39.27816316059658, 51.17902033669608, 54.51820993423462, 2.5390595836298804, 0.1463063314024891, 0.03784066305628844, 3.293686713491167, 5.904998225825174, 5.376822658947535, 38.90052509307861, 56.684185777391704, 59.720086506434846, 56.33129024505615, 59.57867676871163, 55.50388486044747, 57.421601567949565, 57.12363154547555, 60.3160126549857, 54.67029210499355, 54.75547701971871, 55.11046395983015, 52.91025086811611, 53.66541930607387, 52.114623069763184, 45.5072648865836, 43.19513716016497, 39.98290157318115, 40.627416474478586, 38.48458855492728, 40.143464020320344, 40.31878444126674, 39.57897847039359, 39.5687472479684, 38.54841123308454, 38.68055902208601, 38.12738861356463, 37.460177421569824, 39.69103901726859, 38.79821286882673, 40.37381417410714, 39.10769953046526, 40.58933687210083, 38.82109328678676, 38.1574638911656, 37.4055506842477, 38.60229798725673, 37.70431974955967, 37.82549633298601, 39.27186461857387, 39.28249536241804, 37.14535454341343, 40.12444680077689, 36.68081535611834, 39.7610490662711, 43.728425298418315, 43.87895802089146, 43.606744970594136, 45.43766825539725, 43.66252163478306, 44.55753299168178, 42.82303333282471, 43.49968365260533, 45.38634538650513, 46.39807258333479, 44.809790815625874, 50.062135628291536, 48.80243764604841, 54.5119982446943, 39.05948250634329, 28.22333948952811, 54.1921900340489, 46.51341962814331, 49.644489833286826, 48.48459577560425, 51.029057366507395, 46.62049136843, 48.38434716633388, 45.53383132389614, 48.380181721278596, 47.18001937866211, 49.7246025630406, 45.40482759475708, 44.17205735615322, 40.19923026221139, 38.96354178019932, 37.22548811776297, 38.38544818333217, 39.317820004054475, 38.596749850681846, 38.4040276663644, 39.16261461802891, 39.54211827686855, 38.761693137032644, 37.87209095273699, 39.815960679735454, 40.151895659310476, 39.24718461717878, 39.0200514793396, 39.57939188820975, 40.773029872349326, 44.023987770080566, 47.699046339307515, 49.94382170268467, 47.67111110687256, 50.54226657322475, 48.97405467714582, 43.90020213808332, 40.32115030288696, 39.44688974108015, 39.37407956804548, 40.24438313075474, 40.328852381025044, 39.287199292864116, 41.70035382679531, 40.31722457068307, 41.70945596694946, 41.0057806287493, 42.4978472164699, 42.600267137799946, 40.921585832323345, 40.51182624271938, 40.83559145246233, 42.70458739144461, 44.84582417351859, 49.48022052219936, 54.81264679772513, 56.22171367917742, 57.88017225265503, 44.36146872384207, 8.480850475175039, 0.7862818198544639, 2.891081597123827, 0.8844405955501965, 0.018717288405501416, 0.42208645386355265, 32.532334327697754, 54.54654816218785, 37.509672914232524, 36.851320675441194, 23.818202427455358, 35.024507250104634, 47.124499797821045, 49.97173261642456, 58.18537187576294, 28.777769259044103, 0.11485533762191023, 0.02227244379797152, 0.024374032991805246, 0.02579368940288467, 0.029277435769992213, 0.03093070669897965, 0.0037617599757920417, 0.07790768771831479, 0.02569096429007394, 0.02873147970863751, 0.055914291446762424, 0.012782380932808986, 0.17832173061157974, 0.12492350808211736, 0.14973050409129687, 0.10427062559340682, 0.15373546204396657, 0.05784494749137333, 0.14637284140501702, 0.23490106101546968, 0.07281970645167998, 0.19159240994070256, 0.140761153240289, 1.3212119042873383, 52.5793012210301, 73.89293166569301, 60.591300283159526, 52.61510181427002, 25.853922128677368, 30.9197929246085, 48.39978953770229, 47.620298930576865, 57.44114685058594, 59.14545658656529, 3.9447450808116367, 0.29551369856510845, 0.0839109109448535, 4.562515497207642, 9.954147372926984, 10.377720849854605, 41.48022447313581, 56.501680919102256, 61.44476836068289, 58.19917447226388, 62.09755161830357, 58.36875915527344, 59.078670501708984, 58.948377881731304, 61.05566923958914, 57.58208758490426, 57.664837156023296, 56.06010552815029, 55.7604193006243, 54.440977232796804, 54.42979758126395, 47.70371205466134, 45.563892705099924, 43.08389302662441, 42.1030992099217, 43.010492256709504, 42.50148459843227, 42.73588555199759, 41.29716028485979, 41.5604761668614, 40.55572496141706, 41.42944008963448, 40.000508308410645, 40.200672013419016, 41.33525378363473, 40.697395256587434, 42.159087794167654, 40.67901727131435, 44.514957904815674, 42.00991344451904, 39.71260622569493, 39.48840870176043, 40.20058863503592, 40.43049757821219, 39.31953273500715, 41.02535023008074, 40.45586545126778, 40.44660350254604, 42.48292595999581, 38.96483414513724, 41.33657741546631, 45.0283568246024, 45.37217453547886, 46.83828960146223, 48.51242331096104, 44.93859652110508, 46.705704075949534, 45.286760330200195, 45.378754479544504, 48.35776335852486, 49.694843428475515, 46.7798934664045, 53.06575155258179, 49.97896916525704, 56.75409507751465, 42.568322794778005, 30.595409325190953, 56.42964547021048, 48.62575190407889, 51.41180583408901, 51.13040379115513, 54.120522839682444, 50.294969763074604, 51.0674010004316, 46.60810273034232, 49.39061655317034, 48.002734729221885, 52.92012773241316, 46.75602987834385, 47.27650901249477, 42.174474579947336, 41.82044996534075, 39.61188166482108, 40.173118931906565, 40.39023971557617, 40.793648651668, 41.290903432028635, 40.75375556945801, 41.27351903915405, 41.017696789332796, 40.426276547568186, 42.063987800053184, 42.204063483646934, 41.47562823976789, 41.07208033970424, 41.631028175354004, 42.00088426045009, 47.8859007699149, 50.470099108559744, 50.47583832059588, 49.431454590388704, 52.279576778411865, 51.70534985406058, 45.68531594957624, 42.253802163260325, 42.00206545421055, 42.41538252149309, 43.19316039766584, 42.4687168938773, 40.481507778167725, 43.36823068346296, 42.524312904902864, 43.280061517442974, 43.37022481645857, 45.05844252450125, 44.73246431350708, 42.400384834834504, 42.318260601588655, 44.06063951764788, 44.16357707977295, 45.4376335144043, 52.84024429321289, 57.14246463775635, 59.785142489842, 58.48125049046108, 48.2224680355617, 9.577802538871765, 3.3092241883277893, 6.100150108337402, 0.8475333931190627, 0.2443445585668087, 0.5583743378520012, 36.48805495670864, 59.36114256722586, 45.94658211299351, 54.65417923246111, 31.037922722952707, 37.92161076409476, 55.13723536900112, 55.96597828183855, 67.15993268149239, 34.786715575626914, 0.36001759873969214, 0.2055300756224564, 0.06452262095574822, 0.13287534138986043, 0.16795348482472555, 0.1382456882191556, 0.09913106209465436, 0.19785941365574086, 0.1335414456469672, 0.18749428912997246, 0.17762887850403786, 0.12452679579811436], [0.027135142956727316, 0.011924080783501267, 0.029452287458947728, 0.05819074250757694, 0.020432328073573962, 0.05165404147867646, 0.022052299896521226, 0.05258914415857621, 0.044436070935002396, 0.0494046673577811, 0.06518926804086991, 2.1657732597419193, 45.29931572505406, 56.40212712969099, 47.45962878635952, 25.836463042667933, 16.213626623153687, 36.39055783408028, 53.98303883416312, 34.350170680454795, 54.054692132132395, 33.503490992954795, 0.4496062328772885, 0.02891821933111974, 0.1792103943548032, 3.3792023190430234, 6.087806633540562, 11.083427667617798, 52.2444293158395, 54.54978254863194, 59.02774020603725, 57.297972270420615, 57.615588324410574, 56.48469257354736, 55.15176752635411, 52.225783824920654, 54.634390762874055, 55.022016865866526, 54.17995078223092, 50.58912175042288, 52.750939096723286, 51.473002093178884, 50.62311928612845, 47.90633889607021, 41.09228570120675, 37.45150259562901, 38.559354645865305, 38.06765842437744, 36.87333951677595, 35.94589744295393, 36.57712391444615, 37.081017698560444, 36.57584197180611, 36.95065559659685, 41.046295574733186, 38.45852238791329, 40.32169573647635, 40.296508516584126, 40.0834697995867, 40.15588045120239, 40.07776185444423, 40.03782360894339, 38.6207662991115, 36.18967499051775, 36.60707065037319, 35.73067699159895, 36.37398638044085, 38.6410550389971, 37.71833774021694, 36.114259243011475, 36.14256967817034, 35.77354390280587, 42.80278280803135, 47.28829663140433, 47.99892364229475, 47.37551736831665, 49.670771394457134, 46.109600748334614, 48.92527484893799, 46.7403929574149, 45.4843601499285, 44.49873733520508, 48.34388780593872, 46.287012577056885, 50.1025150844029, 45.18770681108747, 51.99833454404558, 36.959302629743306, 28.18302604130336, 52.2348963873727, 45.69220856257847, 48.57782670429775, 44.557338442121235, 48.83791862215315, 44.940948486328125, 46.6925858770098, 45.57145929336548, 47.0852563721793, 44.48354857308524, 46.17151962007795, 44.086775166647776, 43.469386032649446, 37.09049504143851, 34.94581890106201, 35.22306939533779, 36.44506297792707, 36.70484570094517, 37.968076842171804, 37.06295238222395, 36.98280838557652, 36.77247599193028, 35.89214270455496, 36.8553124155317, 35.95055273600987, 38.32349109649658, 36.91264200210571, 38.18631281171526, 38.809020791734966, 41.27065985543387, 45.17037452970232, 49.38369614737374, 47.69715295519148, 47.36500474384853, 49.65213632583618, 46.3802296093532, 41.487249101911274, 38.85631023134504, 37.232540539332796, 36.73780795506069, 36.16640199933733, 37.380179337092805, 38.27729947226388, 37.03583356312343, 40.30887631007603, 37.99107190540859, 37.90298611777169, 38.51445538657052, 38.08350726536342, 38.987943853650776, 40.67132561547415, 43.487058775765554, 44.75836719785418, 42.92947973523821, 44.140265873500276, 51.8159304346357, 52.82457610539028, 52.56103788103376, 51.042484760284424, 19.634877920150757, 0.442399051040411, 1.5467130839824677, 1.0039484713758742, 0.10439266690186091, 0.0814538202913744, 16.40773149899074, 59.75201347896031, 33.55304901940482, 39.579124382564, 17.498805386679514, 13.777014102254595, 31.451132093157085, 42.93428788866316, 46.490587847573416, 33.183707101004465, 0.3639275075069496, 0.061789807597441335, 0.07110466847994498, 0.056788841661598, 0.016609034301447015, 0.05097170327124851, 0.0070334047777578235, 0.058798010993216715, 0.014175611797587147, 0.04225854349455663, 0.09945954768253223, 0.009648040236373032, 0.014034440890619797, 0.024317940198151127, 0.051900095239813836, 0.03362041612022689, 0.03752903227827378, 0.03461669891008309, 0.012791818506749613, 0.013480176167961742, 0.04775435144879988, 0.051352561584540775, 0.035350449715874026, 3.2344817646912167, 56.45747995376587, 60.77838053022112, 56.437205110277446, 33.307068892887656, 19.099585226603917, 30.15386520113264, 56.95607921055385, 39.60323115757534, 60.404386792864116, 36.05106885092599, 0.28383152399744305, 0.05384913279807993, 0.2101006739373718, 3.357729128428868, 1.0268635217632567, 12.076630967003958, 53.88118519101824, 56.323240756988525, 60.08335222516741, 59.06594140189034, 59.14584568568638, 57.20916734422956, 56.68524537767683, 54.48803390775408, 57.740204266139436, 57.09442826679775, 54.9044429234096, 53.15508106776646, 55.13835055487496, 53.53775657926287, 52.767548765454976, 50.479618140629356, 43.07349852153233, 39.7124012538365, 40.28260517120361, 39.12485810688564, 38.90798051016671, 37.48611504690987, 38.26901721954346, 38.75440795081002, 38.52594075884138, 38.4442264693124, 42.282612868717735, 41.45284162248884, 42.207092898232595, 41.4054514339992, 42.106111254010884, 43.1961863381522, 42.5795441355024, 42.18829107284546, 40.00595222200666, 37.63557079860142, 38.79058722087315, 37.1234781401498, 39.22218499864851, 38.91419914790562, 37.53036117553711, 38.010294096810476, 38.07858099256243, 38.16232763017927, 45.2445569719587, 50.24851410729544, 49.93484810420445, 50.25926297051566, 50.76153782435826, 49.399642263139995, 51.52383858816964, 48.89999035426548, 48.60339954921177, 47.34437206813267, 50.43240165710449, 49.706335748944966, 53.59106315885271, 46.26062331880842, 53.978998456682476, 38.42918014526367, 28.655663354056223, 54.16856268474034, 46.39196859087263, 49.642766680036274, 46.97116347721645, 50.07767180034092, 46.49816138403756, 47.661460059029714, 46.28305557795933, 48.43389129638672, 46.35682807649885, 46.5760680607387, 47.11716250010899, 44.83564853668213, 39.858872754233225, 36.44332592827933, 37.17365108217512, 37.01238686697823, 38.03969887324742, 37.817839418138774, 37.79430934361049, 38.298095430646626, 38.256149155753, 37.14412818636213, 38.66871929168701, 37.70812736238752, 39.18719734464373, 39.08678545270647, 40.3984420640128, 41.219309193747385, 43.96507746832711, 48.43061522075108, 51.22453451156616, 49.28647347858974, 48.84661429268973, 50.68445450919015, 48.44667598179409, 43.13586207798549, 39.55205420085362, 39.360217911856516, 38.67368030548096, 38.76348229816982, 38.669254302978516, 39.73513575962612, 40.2527939251491, 41.25767714636666, 40.554800851004465, 39.4319372177124, 40.31380605697632, 40.3274245262146, 40.379358836582725, 42.260041645595, 46.738357135227744, 45.93951579502651, 44.61770786557879, 45.99883256639753, 54.144824164254324, 56.26332991463797, 55.51234081813267, 54.433921337127686, 22.394433157784597, 0.6202887584056173, 2.796839488404138, 1.6754271600927626, 0.05995620920189789, 0.027945471528385366, 17.491865873336792, 63.93892151968819, 37.55295671735491, 40.6339373588562, 20.826879603522165, 21.59255198069981, 35.55684348515102, 49.32623107092721, 53.72876255852835, 43.544409206935335, 0.9027605525084904, 0.05605888047388621, 0.060098939043070586, 0.036607205136013884, 0.03136036525081311, 0.09100491314062051, 0.023083131993189454, 0.052953334259135384, 0.04199707002512046, 0.035331739112734795, 0.05905503327293055, 0.05523247231862374, 0.11951280198991299, 0.155782425776124, 0.16352522958602222, 0.14449564713452542, 0.09953603893518448, 0.197806840762496, 0.12880470124738558, 0.11774608679115772, 0.14491416753402778, 0.12021104166550295, 0.18745272207473004, 4.311002433300018, 65.41611548832485, 68.26100676400321, 63.76656450544085, 37.99156175340925, 24.60309178488595, 46.62148148672921, 65.49797221592495, 46.818862438201904, 64.62732124328613, 41.00285543714251, 0.6826061201947076, 0.1271769500204495, 0.37599848264030045, 8.782199927738734, 13.393211245536804, 14.608111585889544, 53.94519199643816, 56.7126282283238, 63.25803279876709, 61.684008734566824, 62.321068218776155, 58.883113452366416, 59.8950560433524, 58.457202775137766, 62.309270177568706, 59.12960079738072, 58.784490721566335, 53.42487267085484, 57.77487230300903, 55.2652177129473, 54.339901787894114, 52.94404343196324, 45.40974691935948, 41.91273593902588, 42.4919308253697, 41.98979146139962, 40.52288082667759, 39.04384905951363, 41.17799867902483, 41.25444275992257, 40.840524673461914, 40.18913800375802, 44.9543376650129, 42.67705168042864, 44.932381357465474, 43.965827873774934, 43.607616969517295, 44.87044858932495, 44.150024618421284, 44.088335037231445, 43.130494594573975, 40.25386047363281, 39.44863026482718, 38.4844982283456, 41.131001063755576, 41.14796509061541, 40.205368995666504, 39.88910436630249, 39.99245882034302, 40.25239787782942, 46.309368406023296, 51.755442891802105, 51.11623641422817, 51.07414770126343, 52.55392639977591, 50.85072490147182, 53.594742230006624, 51.038916860307964, 50.870211124420166, 47.43936089106968, 52.24863297598702, 49.94968598229544, 55.8690995488848, 47.78916794913155, 55.51537370681763, 40.82595082691738, 31.373666627066477, 55.582180636269705, 47.51141718455723, 50.79657064165388, 48.64148609978812, 53.24619279588972, 48.43783439908709, 49.59722818647112, 48.82320581163679, 49.0277955191476, 46.63640621730259, 48.92690767560686, 49.268606185913086, 47.99466092245919, 41.31287711007254, 37.61796406337193, 38.993516308920725, 38.228995595659526, 39.336653096335276, 41.304897103990825, 40.34017447062901, 39.88364655630929, 40.77247749056135, 39.24191093444824, 39.957735197884695, 40.56339577266148, 42.601920809064595, 42.46048327854702, 43.62991026469639, 41.80879783630371, 45.281417165483745, 49.19657073702131, 53.43170622416905, 51.90654536655971, 50.4233273097447, 52.374245984213694, 51.45441913604736, 46.26971851076399, 41.14552974700928, 41.82290962764195, 40.08335862840925, 39.18741273880005, 41.37098489488874, 41.76966210774013, 43.355789933885845, 46.243485586983816, 43.60130453109741, 42.40040567943028, 41.593084062848774, 42.11171497617449, 41.40861286435808, 44.86263534000942, 48.56685549872262, 49.169347694941926, 47.56000593730381, 49.106834752219065, 55.381968293871196, 59.62955147879464, 58.25587524686541, 56.050325938633506, 22.756133794784546, 1.8743655937058585, 6.774306459086282, 2.6204622898783003, 0.46794863577399937, 0.21587154641747475, 19.246532678604126, 68.41277626582554, 46.39280932290213, 51.4241805757795, 24.08353328704834, 24.164497171129497, 42.972777434757774, 56.94709171567644, 61.09919275556292, 51.36712544304984, 1.6988741819347655, 0.19535256602934428, 0.20332620745258673, 0.11468655882137162, 0.1367822103202343, 0.20409706394587243, 0.08715941770268337, 0.15819125223372663, 0.1607842466660908, 0.11180043047560112, 0.1663030298160655, 0.11269834943647895], [0.03634926683402487, 0.031024819506066184, 0.04920647745685918, 0.01502908586657473, 0.06967648797269378, 0.032483266067824194, 0.042301701714417765, 0.0599695084882634, 0.0191667160751032, 0.17766044395310537, 0.14685302706701414, 10.389013409614563, 57.96653488704136, 48.88224465506417, 39.84775216238839, 31.936814648764475, 22.225122928619385, 25.002019132886613, 40.558504240853445, 35.27249888011387, 57.59997919627598, 22.984267473220825, 0.022401679273960844, 0.08474069820450884, 0.06363067988838468, 2.468164724963052, 4.5352255787168225, 26.41717263630458, 60.00300325666155, 56.44518511635916, 57.8532966205052, 53.67093617575509, 54.4776428767613, 51.431337220328196, 52.407020636967246, 51.22499309267317, 52.43986824580601, 48.88427005495344, 51.45079217638288, 50.43289497920445, 50.68413836615426, 48.98011350631714, 50.49110351290022, 44.519376959119526, 41.771680559430806, 36.768022196633474, 39.260014465876985, 39.00226409094674, 39.559846605573384, 36.389720576150076, 37.4510474886213, 37.697538307734895, 39.18639482770647, 39.02024602890015, 40.99534790856497, 42.00005047661917, 43.451101848057334, 43.53572048459734, 43.206000668661936, 45.3680750983102, 43.16933502469744, 41.89193650654384, 39.91736616407122, 38.45419366019112, 36.37868683678763, 35.902005672454834, 37.03940841129848, 37.34471573148455, 38.23755577632359, 37.657811982291086, 34.558866773332866, 40.68977655683245, 48.20238774163382, 51.58219303403582, 49.34129129137312, 48.906191621507915, 49.93662336894444, 47.34384053094046, 47.791092600141255, 47.322662421635215, 48.06370864595686, 48.35830184391567, 49.26621947969709, 45.87616906847273, 50.408812522888184, 46.9611302784511, 50.13756874629429, 38.11248472758702, 27.101952348436626, 49.8992212159293, 45.33549499511719, 48.442840576171875, 44.166926111493794, 46.251955441066194, 46.28344815117972, 46.78240524019514, 46.06822769982474, 47.89041709899902, 43.413671902247835, 44.31258814675467, 42.34119313103812, 41.72732325962612, 36.874270575387136, 35.24484504972185, 33.01088803155081, 35.209013189588276, 37.405613218035015, 36.388761724744526, 35.992703982761924, 36.90515184402466, 36.20008339200701, 37.22940690176827, 36.712078775678364, 35.808587142399375, 39.0358829498291, 42.09123863492693, 42.58597469329834, 45.76352834701538, 46.85900912966047, 48.600776604243684, 46.39538710457938, 45.329071385519846, 49.173085825783865, 48.75200414657593, 43.52363061904907, 37.60986941201346, 37.08221973691668, 37.683773926326204, 37.38898965290615, 38.08000884737287, 38.967182636260986, 39.53015347889492, 38.797625746045796, 38.62832593917847, 41.03253814152309, 43.40722049985613, 44.9371200289045, 46.7755890573774, 48.04382984978812, 48.307326384953086, 50.358597891671316, 50.732431820460725, 49.37028612409319, 44.068327699388774, 45.167206151144846, 53.81377029418945, 52.83242756979806, 56.159899030412944, 38.536502020699636, 1.8447740844317844, 0.9304452155317579, 1.399981568966593, 0.01964529530544366, 0.05583339310916407, 8.634590659822736, 54.70352533885411, 40.280944551740376, 39.68330567223685, 23.299713952200754, 16.89441806929452, 33.85804714475359, 43.73522411073957, 53.993926661355154, 41.725252696446006, 2.0573390211377824, 0.06377643599574055, 0.03354221495932766, 0.016922050987237265, 0.061272634991577694, 0.010087993860776936, 0.07979837126497712, 0.026259003273610557, 0.05467955109530261, 0.14228736848703452, 0.02138762904464134, 0.07364730882857527, 0.03676415367850235, 0.08043190584118877, 0.03291329102856772, 0.04278081529108541, 0.035206454406891546, 0.031387411656656435, 0.04665104333045227, 0.12954686928008283, 0.05121284104617579, 0.1763983281063182, 0.1555183535175664, 12.604158180100576, 67.45265333993095, 54.384179183415, 47.02204166139875, 32.82284198488508, 18.134259837014334, 21.001892566680908, 44.14304167883736, 39.41320834841047, 64.14799976348877, 25.569806814193726, 0.053386860460575135, 0.07791474448250872, 1.0534920586006982, 3.2995253716196333, 1.2508780040911265, 29.539369991847447, 62.848443440028596, 59.24399593898228, 58.7516187940325, 54.69892563138689, 56.4772093636649, 52.046398707798545, 53.80831248419625, 51.683393546513145, 53.00096307482038, 52.540245396750315, 53.13080753598894, 52.540314878736226, 53.08135373251778, 50.314219747270855, 53.00556625638689, 46.97363356181553, 42.82108783721924, 39.54060704367501, 40.08537360600063, 40.643946238926475, 40.870950835091726, 38.19487994057791, 39.28096328462873, 39.02461991991316, 40.88288089207241, 40.835449014391216, 43.78474044799805, 43.463983808244976, 46.3586311340332, 45.532542433057515, 46.497018405369346, 44.92110095705305, 45.514362471444265, 43.940532956804546, 41.12042590550014, 40.54974603652954, 36.30132906777518, 37.95446184703282, 39.244735377175466, 39.21625123705183, 39.57104015350342, 38.49342666353498, 35.76836402075631, 42.74501201084682, 49.94085134778704, 52.02031864438738, 49.831799370901926, 49.95449413572039, 49.7028477532523, 48.547181674412315, 50.45443092073713, 49.46705368586949, 49.96680981772286, 50.16320759909493, 52.05786670957293, 47.87750734601702, 52.37850175585066, 48.60924298422677, 52.45688785825457, 39.81703765051705, 28.57564789908273, 51.17326028006417, 46.4251184463501, 49.30491399765015, 47.018654414585654, 48.628117765699116, 47.847251415252686, 47.90566144670759, 47.657867840358186, 49.24506221498762, 44.71022660391671, 47.004747595105854, 43.962187017713276, 41.427258355276926, 38.413018635341096, 37.11323996952602, 35.77034078325544, 37.72869750431606, 38.637344700949534, 39.34085675648281, 37.7757784979684, 39.191380160195486, 38.602273668561665, 39.42111539840698, 38.68543665749686, 37.466420378003804, 40.39761175428118, 43.48206302097866, 44.30122436795916, 47.24138586861746, 47.34211390359061, 50.957247734069824, 48.070076669965474, 46.69639001573835, 49.96874836512974, 51.142240047454834, 44.64986760275704, 39.03421538216727, 38.79360621316092, 39.19454506465367, 39.68269770486014, 39.27465084620884, 41.37540742329189, 41.98231519971575, 40.83710963385445, 39.81384495326451, 42.629119532448904, 45.41093506131853, 46.80179418836321, 49.103541306086946, 49.92731973103115, 50.633576325007844, 52.857517514910015, 52.775101457323345, 52.140855993543354, 46.17842265537807, 46.74242877960205, 55.92137432098389, 55.620923791612896, 59.09759739467076, 41.80291618619646, 3.0635788781302313, 0.5964596942067146, 2.6229929540838515, 0.18958733896059649, 0.04561876425785678, 9.039655004228864, 58.64915370941162, 46.41700642449515, 42.0708178792681, 25.395342758723668, 20.974296058927262, 38.669775417872835, 49.41025216238839, 59.77488694872175, 51.89550815309797, 4.212904725755964, 0.10124776565602847, 0.03448391639228378, 0.03325301315635443, 0.034929113396044285, 0.03243263717740774, 0.04384798124166472, 0.04432901507243514, 0.07611801089452845, 0.030125234741717577, 0.004368806665297598, 0.03778673987835646, 0.15134028771093913, 0.1985727303794452, 0.11628091255468981, 0.08752586053950445, 0.15122932009398937, 0.21554907943521226, 0.09761562198400497, 0.19977227172681264, 0.1139114818402699, 0.3086779293205057, 0.33070591730730875, 17.015834365572246, 77.90807328905377, 61.37407738821847, 53.41956772123064, 42.30355473927089, 29.317093644823345, 31.816273825509207, 53.263639722551616, 47.559245109558105, 68.78482450757707, 29.04188244683402, 0.253868041826146, 0.20624146530670778, 1.4210067093372345, 10.041045887129647, 11.42179799079895, 30.14842128753662, 66.351989201137, 61.73660659790039, 59.969505991254536, 58.480757168361116, 59.12087385995047, 55.22239943913051, 55.31856598172869, 55.212136949811665, 55.04205894470215, 56.1013639313834, 55.528742040906636, 55.23423569543021, 56.780967235565186, 52.897382804325645, 54.60907500130789, 49.163952418736045, 44.83876827784947, 41.736546993255615, 42.28881066186087, 42.513553619384766, 42.99039806638445, 40.07721642085484, 42.30626801082066, 42.381047998155864, 42.23265879494803, 43.0019668170384, 46.5572384425572, 44.27271243504116, 48.540605204445974, 47.10917207172939, 48.43283517020089, 47.42170899254935, 46.69644907542637, 47.15486689976284, 44.42391913277762, 42.05461120605469, 39.31003107343401, 40.39689608982631, 40.95053897585188, 40.812248979296, 40.34946768624442, 41.065073081425254, 36.677289145333425, 45.9212246622358, 52.10315159388951, 55.135046686444966, 52.060969080243794, 52.335881505693706, 53.16564580372402, 49.3488370350429, 52.803314617701936, 50.47163813454764, 53.007813998631065, 52.899752140045166, 53.968100207192556, 49.00776386260986, 54.6633300100054, 49.60200159890311, 54.67581244877407, 40.78826379776001, 30.30293185370309, 51.26995141165597, 48.74915191105434, 50.691444396972656, 49.089693546295166, 50.10458217348371, 49.39212083816528, 50.23853996821812, 50.18446213858468, 51.59418215070452, 45.70788369859968, 48.4243722643171, 48.38274908065796, 45.62764937537057, 41.11634383882795, 38.92512171609061, 37.860233851841514, 39.056355816977366, 40.99567447389875, 41.5167407308306, 40.24415384020124, 40.85023825509207, 40.43489578792027, 40.40008531297956, 41.41379969460623, 37.440444537571494, 42.87859112875802, 45.8851774079459, 46.10806172234671, 49.99657590048653, 49.34561654499599, 54.137090819222585, 49.75392396109444, 48.25916494641985, 53.03732647214617, 53.03255653381348, 47.24604116167341, 41.02991172245571, 39.76426608221871, 42.63441058567592, 41.34327547890799, 41.63557924543108, 43.59195920399257, 44.096832684108186, 42.68085581915719, 42.27749899455479, 43.867319788251606, 48.46402563367571, 50.42579739434378, 51.71510859898159, 52.00112771987915, 52.03934628622872, 54.535920892442974, 55.291568756103516, 54.72309494018555, 48.062770639147075, 49.43112455095564, 58.67555686405727, 57.34942020688738, 60.83051981244768, 43.920080934252056, 3.063188693353108, 5.499010639531272, 5.072350859642029, 0.25830568798950737, 0.18037001070167336, 10.784413678305489, 65.26167093004499, 51.47803953715733, 53.64007922581264, 31.32262168611799, 26.379985877445765, 46.74049718039376, 58.79099423544747, 67.73709869384766, 61.419414384024485, 5.464425112519946, 0.45809701297964367, 0.17011417102600845, 0.13168562522956304, 0.11337829580796616, 0.11561555468610354, 0.2355270774236747, 0.13393899931439332, 0.2264187354594469, 0.21897052441324505, 0.14401756493108614, 0.19335787663502352], [0.019629829796031117, 0.062319438106247356, 0.02574993237586958, 0.0761920865625143, 0.010721089085564017, 0.07088689266570977, 0.10075179048414741, 0.07301551808736154, 0.02503139093252165, 0.0943697275859969, 0.03719438559242657, 12.479847959109716, 60.400481905256, 45.52544484819685, 49.790919644492014, 51.00550297328404, 38.07425226484026, 23.560196706226893, 36.81159782409668, 43.13763734272548, 58.11594547544207, 13.313456348010472, 0.015994783690465347, 0.03924418220828686, 0.4774389522416251, 1.64402260524886, 3.4699870475700925, 56.003359590257915, 55.349242278507774, 57.61262491771153, 53.40621675763811, 54.925603662218364, 48.270077092306956, 48.22140496117728, 44.347433362688335, 44.80882849012102, 41.8799022265843, 44.185286726270405, 43.17828777858189, 42.4641032900129, 43.43943234852382, 41.44148131779262, 41.47215414047241, 38.84487697056362, 36.619202205113, 38.882174900599885, 36.633043016706196, 37.16834960665022, 36.801714011601035, 36.99631915773664, 36.10686635971069, 38.59811864580427, 40.008731501443044, 41.64536925724575, 43.21214982441494, 43.44552591868809, 45.68493727275303, 45.336050851004465, 45.211167403629844, 46.01990645272391, 45.02660240445818, 42.94702741077968, 40.85935429164341, 37.5124591418675, 35.70134169714791, 36.50168037414551, 36.89546605518886, 36.512790543692454, 36.53233930042812, 37.90445566177368, 35.21850790296282, 42.987879344395225, 48.514570304325645, 47.9537672996521, 47.26690660204206, 46.352912766592844, 49.36435236249651, 48.51033885138375, 50.03266831806728, 49.19810281481062, 47.10020194734846, 47.72742278235299, 47.194026947021484, 46.52163239887783, 49.365950448172434, 46.7435439654759, 49.431155817849294, 43.53953504562378, 30.61177233287266, 49.368139130728586, 46.77807651247297, 48.02123083387102, 46.44545929772513, 46.55102327891758, 44.86878102166312, 45.93655586242676, 42.220280579158235, 45.700435229710166, 42.53583301816668, 44.339561053684776, 40.71280288696289, 38.01141970498221, 36.09097235543387, 34.899172169821604, 34.529614857264924, 35.940988540649414, 36.178571769169395, 38.57088170732771, 36.463982922690256, 37.32436793191092, 36.34353590011597, 38.454023429325645, 36.85923119953701, 39.074250902448384, 42.28732374736241, 43.53868041719709, 46.689865657261436, 50.04639448438372, 47.635512011391775, 48.881383078438894, 47.659889766148154, 49.50765895843506, 48.79457228524344, 46.18744836534773, 38.34551688602993, 36.88548149381365, 36.44139085497175, 37.48155702863421, 37.16311066491263, 37.62406805583409, 38.20564617429461, 39.254921436309814, 41.3204402242388, 46.16038165773664, 48.04521254130772, 49.29692356927054, 50.637641021183555, 50.39388084411621, 53.00407239368984, 54.03721393857683, 53.624209540230886, 52.21810259137835, 53.69758946555001, 52.2327424458095, 50.20802695410592, 46.38337366921561, 53.14443642752511, 51.69927365439278, 55.49709299632481, 10.34031435421535, 1.2000607252120972, 1.2720402628183365, 0.18217973144991056, 0.058285635629934926, 2.9471839581217085, 48.42005743299212, 47.349975790296284, 38.93854910986764, 31.905242034367152, 22.969302790505544, 27.229510852268763, 42.536225591387065, 42.73761912754604, 49.07039492470877, 10.362734454018728, 0.215987698041967, 0.10300665056066853, 0.022938324138522148, 0.009912534882979733, 0.0035613330297305113, 0.010627156090257424, 0.02246762439608574, 0.0137309118207278, 0.01104663492047361, 0.04133571551314422, 0.08984398722116436, 0.03595497352736337, 0.037898569234779904, 0.0745368953794241, 0.046715717895754745, 0.033727061469107866, 0.042900922774736366, 0.011320208365629827, 0.061212265730968544, 0.01920091763271817, 0.13631434685417584, 0.06503836863807269, 16.96291514805385, 69.10451112474713, 51.91756520952497, 55.143328939165386, 55.356120995112825, 43.04810285568237, 27.62827491760254, 41.63023608071463, 46.437489713941304, 65.17747265951974, 14.77455915723528, 0.06625861887420927, 0.04770038416609168, 1.0257240171943391, 0.6097018207822527, 4.629146550382886, 59.02671882084438, 58.314014298575266, 58.26477241516113, 54.94559015546526, 56.87177324295044, 52.13827473776681, 49.866946833474294, 45.624550478799, 46.514211722782676, 44.2377039364406, 45.92869397572109, 44.8789392880031, 45.15072502408709, 45.696832588740754, 44.197300161634175, 43.917155742645264, 41.1661867414202, 38.816451890128, 39.11153493608747, 37.17562089647566, 37.9650092124939, 38.26213155473982, 39.092086928231375, 38.35837800162179, 40.75307812009539, 42.55932140350342, 43.88632311139788, 44.17059128625052, 46.64983013698033, 46.08909314019339, 47.19259909221104, 46.621863637651714, 48.54652506964547, 47.767579896109446, 45.277557441166465, 41.73037004470825, 40.26030840192522, 38.61779594421387, 38.728835105895996, 38.039431367601665, 38.64394201551165, 39.08925553730556, 38.908432143075125, 37.47984777178083, 44.15498563221523, 50.52968338557652, 49.876945291246685, 49.512679031917024, 48.46304246357509, 49.88282346725464, 49.287230832236155, 50.11731127330235, 49.98933587755476, 50.91155290603638, 47.98507588250296, 47.6247353553772, 47.65788173675537, 50.547397817884175, 49.349778515951975, 50.842400959559846, 44.06834159578596, 31.56723996571132, 50.60491500582014, 48.76046705245972, 50.30578810828072, 48.15531022208077, 48.770559310913086, 46.1532632282802, 47.855627468654085, 44.80739368711199, 46.41703074319022, 44.22185162135533, 45.49921539851597, 43.29089028494698, 39.91657059533255, 38.7072296823774, 36.79739570617676, 35.60960463115147, 37.767367703574045, 37.96839298520769, 40.4586238861084, 38.5663514818464, 38.67293337413243, 39.1611659186227, 38.70704208101545, 38.77596821103777, 41.965931347438264, 43.73460572106497, 45.189815589359824, 48.1724305834089, 51.09417240960257, 50.38347939082554, 51.431139196668354, 48.898944650377544, 51.213365282331196, 50.53583254132952, 48.57460968835013, 41.16929258619036, 38.20540298734392, 38.6097742489406, 39.34610612051827, 38.810650144304546, 39.104409558432444, 39.840949875967844, 40.71714551108224, 43.711600235530305, 49.253188133239746, 50.50637912750244, 52.00390352521624, 53.834566252572195, 53.18574694224766, 55.86538921083723, 56.11034100396292, 55.810745103018625, 53.63582692827497, 55.503547872815815, 54.64577886036464, 50.98633289337158, 47.973621777125764, 54.38159097943987, 53.86811562946865, 57.11861147199358, 12.949789370809283, 1.8994676981653487, 1.9748291628701347, 0.24937969552619116, 0.09469371448670115, 2.4132255358355383, 50.12239040647234, 54.090760231018066, 36.19281210218157, 27.622990812574113, 27.8395904813494, 33.1720723424639, 50.253523758479524, 48.397409779684885, 57.93236017227173, 14.952488626752581, 0.285243066826037, 0.07280987447925977, 0.08453538707856621, 0.03186448623559304, 0.04051191971770354, 0.025266835798642466, 0.05421058161716376, 0.012214208786774958, 0.07891865739864962, 0.027555437725303427, 0.015843594213947654, 0.08670595274972064, 0.19526502144123825, 0.18590868849839481, 0.2119360433093139, 0.11504730874938623, 0.12165765118386064, 0.15157305236373628, 0.21140951370554312, 0.12700038163789681, 0.2264319804630109, 0.15993544006986277, 21.196456023624965, 77.30688040597099, 58.24460874285017, 65.3382956641061, 62.31521783556257, 49.40827539988926, 31.44622666495187, 51.29760524204799, 53.93723978315081, 69.21301419394356, 17.12006081853594, 0.1742109347667013, 0.18736429539109978, 2.7650955574853078, 9.093472276415143, 4.71496809380395, 62.036046164376394, 59.498598779950825, 61.74619511195591, 58.09980828421456, 59.165460450308665, 53.79502405439104, 52.42134782246181, 47.54870816639492, 49.146022592272075, 45.81697736467634, 49.430933475494385, 46.94918632507324, 47.11851045063564, 47.4991466658456, 47.76983806065151, 45.98880284173148, 42.943855558122905, 40.511728967939106, 42.805812222617014, 39.36241701671055, 41.722046102796284, 40.51217017854963, 41.11172328676496, 40.13306951522827, 43.135914189474924, 45.64097254616873, 46.62067896979195, 46.82016175133841, 48.92292635781424, 48.8615459714617, 48.41078158787319, 48.2658873285566, 50.49626949855259, 49.103103569575715, 47.10770947592599, 44.44762291227068, 42.017236845833914, 38.69734239578247, 39.58749696186611, 40.68619476045881, 39.1183545930045, 39.88988256454468, 41.32620028087071, 39.01469094412667, 46.49173430034092, 52.79684931891305, 50.95740059443882, 50.53725692204067, 48.66499185562134, 52.637461117335725, 51.494774273463655, 52.16739116396223, 51.62839160646711, 52.60023961748396, 50.01710087912423, 49.19752264022827, 50.20057848521641, 51.497022015707834, 51.919264044080464, 54.04947056089129, 46.692651884896414, 34.63687072481428, 52.55383607319423, 51.02552420752389, 52.16838475636074, 51.311136858803884, 51.27926894596645, 48.744274275643484, 49.604228496551514, 45.817991801670615, 49.700624329703196, 47.91752896990095, 47.647146769932334, 44.63001659938267, 42.58678763253348, 41.217311586652485, 39.33502721786499, 37.38006121771676, 39.3886638368879, 39.81465789249965, 42.14811658859253, 40.95279714039394, 39.927646023886545, 40.02549403054373, 42.02598115376064, 41.19974306651524, 45.22456005641392, 46.70519685745239, 46.26451431001936, 51.80792610985892, 54.52853148324149, 51.90385641370501, 52.98336328778948, 52.146602153778076, 54.905728340148926, 53.76691859109061, 51.37626232419695, 42.51035744803292, 39.95540755135672, 40.42145102364676, 41.1628863470895, 41.12295157568795, 41.76332882472447, 42.90683208193098, 43.89246531895229, 45.81461845125471, 52.011404105595176, 53.17421988078526, 54.39018242699759, 55.891024589538574, 55.06571061270577, 58.52621923174177, 58.20281185422625, 57.1494927406311, 56.355636732918875, 57.31530107770647, 57.330455098833355, 55.67792681285313, 51.64787088121687, 57.164629391261506, 55.58844443729946, 60.42571081433977, 13.015141521181379, 5.596668439252036, 5.5709874629974365, 0.3088989146053791, 0.17901197714465006, 3.7237762979098727, 58.58950342450823, 59.03811386653355, 50.12245988845825, 42.80701773507254, 32.73942191260201, 39.01875564030239, 58.13839857918875, 55.29975373404366, 66.94600459507534, 18.877432210104807, 0.30063023258532795, 0.2578149714640209, 0.164709028920957, 0.16410324642700808, 0.195675005870206, 0.10512680786528758, 0.08430087859077112, 0.09930520810719047, 0.14701130214546407, 0.12193088366516999, 0.14611127972602844], [0.04561102895864418, 0.06474781315773726, 0.10319586683596883, 0.039778718525277715, 0.06410923028098685, 0.0062010619855885, 0.0515733399162335, 0.03816632254581366, 0.04615864743079458, 0.0878136000995125, 0.02677553636021912, 20.19048193522862, 58.06553282056536, 46.289163044520784, 41.543981143406455, 16.834019115992955, 11.684487666402545, 15.470528943198067, 38.60526139395577, 45.55115665708269, 56.87158216748919, 7.635937367166791, 0.08958071563392878, 0.04623642450730715, 0.7244027916874204, 1.4589611355747496, 19.682249001094274, 61.62715857369559, 55.349068573543, 56.89744683674404, 51.86660712105887, 50.16656705311367, 44.63510615485055, 43.058215958731516, 39.48331914629255, 42.18253449031285, 37.194975103650776, 35.73384537015642, 38.77431453977312, 37.65651961735317, 36.29312324523926, 37.68527821132115, 36.505845819200786, 36.31354400089809, 37.70543493543352, 37.847400529044016, 38.056659426007954, 39.19824498040335, 36.297458921160015, 36.993755272456575, 36.2027028628758, 39.3170348576137, 41.77146169117519, 42.90454612459455, 44.581049169812886, 45.896273681095664, 43.01388645172119, 47.330604212624685, 46.4609294618879, 47.08442953654698, 46.31522921153477, 43.43402317592076, 40.73607587814331, 37.598443099430625, 36.982179573604036, 35.80698905672346, 36.87827273777553, 38.65610136304583, 35.888852732522146, 36.03487260001046, 35.76407698222569, 43.13175221851894, 46.12964630126953, 49.382525375911165, 47.46074397223336, 47.20774616513933, 49.0625330380031, 49.52443538393293, 49.00710030964443, 48.391260623931885, 47.641754967825754, 46.51968690327236, 48.1947968346732, 50.7523592540196, 48.342314038957866, 47.769514969417024, 47.66111264910017, 46.98164483479091, 33.047018664223806, 47.639729567936485, 46.6176495552063, 47.099298681531636, 46.24775178091866, 46.82249287196568, 45.04509503500802, 43.12198652539934, 42.58317804336548, 42.42251137324742, 42.05542067119053, 41.53533411026001, 42.302776541028706, 37.86441319329398, 35.99667140415737, 35.841584137507844, 34.24169192995344, 37.22568266732352, 37.20252084732056, 36.34055164882115, 37.444537026541575, 36.38749715260097, 37.458676610674175, 36.28336450031826, 38.55250719615391, 40.23113291604178, 42.59342663628714, 47.98759460449219, 49.01153673444475, 48.94657107761928, 48.16277606146676, 49.615401199885774, 50.25551094327654, 48.58206163133894, 46.175400188991, 41.99793127604893, 36.2661885534014, 37.13073205947876, 38.60307271139962, 37.32855422156197, 36.18234116690499, 37.80855662482125, 39.084575925554546, 45.1065970148359, 50.98014552252633, 50.317877973829, 51.93958405085972, 53.159097126552034, 51.94180747440883, 50.98965413229806, 49.56201819011143, 48.776774474552695, 49.479546546936035, 51.32254580089024, 53.541817801339285, 53.56923886707851, 52.38703761781965, 52.62743486676897, 52.259486062186106, 53.441291264125276, 55.45051922116961, 23.362371070044382, 0.3851664406912667, 0.8876361697912216, 0.4193961167974131, 0.028803594410419464, 0.44563579878636767, 33.58166517530169, 56.7535149029323, 41.1160763331822, 35.32060125895909, 14.585238116128103, 21.043812785829815, 44.27230943952288, 46.784757205418174, 49.228164196014404, 16.838062967572892, 0.16691585550350801, 0.05163404844435198, 0.05779022364211934, 0.04230291968477624, 0.02819094174940671, 0.051051461670015535, 0.007214900172714676, 0.02716267281877143, 0.051373511353241544, 0.02602538027401481, 0.05498687996129904, 0.027712498226069977, 0.05736794415861368, 0.10861871191965682, 0.0359358795519386, 0.04828769354415791, 0.02507926327442484, 0.059957206648375304, 0.05849991698882409, 0.0392260890720146, 0.06873585523239203, 0.046265425094004185, 25.963594232286724, 65.48296410696847, 51.2139767238072, 47.92033951623099, 27.497141565595353, 23.67173092705863, 20.72358594621931, 41.030370303562705, 51.776780809674946, 61.64849649156843, 8.68812392439161, 0.06962847483477422, 0.026746963250583837, 2.9865683019161224, 1.2674501091241837, 21.580583708626882, 66.18264075687954, 54.92482198987688, 60.15289674486433, 53.92081771578108, 52.58206312997, 45.710246086120605, 45.92380244391305, 41.50673532485962, 43.77992534637451, 40.19294561658587, 38.08545276096889, 37.75966215133667, 40.18275260925293, 37.346108845302034, 38.06152663912092, 39.488603251320974, 39.58152151107788, 37.62287643977574, 40.45151935304914, 40.49874973297119, 40.840781756809776, 39.56491879054478, 39.637124470302034, 38.94220386232649, 40.67527219227382, 41.947650636945454, 44.73338842391968, 44.95978505270821, 48.79511424473354, 46.57541840417044, 49.07158654076712, 48.48732989174979, 48.74815484455654, 47.54046760286604, 45.477147919791086, 41.919857842581614, 40.23474945340838, 39.02040236336844, 36.70065941129412, 38.745976311819895, 39.70104442323957, 37.92739861352103, 38.664974212646484, 38.39623178754534, 44.89682742527553, 49.76806354522705, 49.80700472423008, 48.55364349910191, 48.50591632298061, 50.55626024518694, 52.84969731739589, 48.16135515485491, 50.87483862468174, 48.73577662876674, 47.36382007598877, 48.764785357883994, 50.10391514641898, 50.76301084245954, 49.43003715787615, 49.443308217184885, 48.494187763759065, 34.96754591805594, 50.40792315346854, 48.47384691238403, 49.58324841090611, 48.95384236744472, 47.45111376898629, 45.16120638166155, 45.90031058447701, 44.826195512499126, 45.082455498831614, 44.30960042136056, 42.78439787455967, 43.42093276977539, 39.32684918812343, 38.3240122113909, 37.90610238483974, 35.93149382727486, 39.39038004193987, 39.14534139633179, 38.42227363586426, 38.714942182813374, 37.96367515836443, 37.77563953399658, 38.815701484680176, 38.937638895852224, 41.94558354786464, 44.32661655970982, 49.67275163105556, 49.408379622868125, 49.75155462537493, 50.705677781786235, 52.140435627528596, 51.71419491086687, 51.41480050768171, 49.394309520721436, 44.75455263682774, 38.93913970674787, 39.173089027404785, 40.45177296229771, 39.97372300284249, 37.815473556518555, 39.829964773995535, 41.46205145972115, 47.18050575256348, 53.07700068610055, 51.82609217507498, 54.066319942474365, 54.88755532673427, 52.40291077750069, 53.2774075780596, 51.580449036189485, 51.3143538747515, 49.96866498674665, 51.53956583568028, 55.38381651469639, 54.63546425955636, 54.33685152871268, 55.26018721716744, 53.82209076200213, 57.520766258239746, 58.4171325138637, 25.446359906877788, 0.5488410836883953, 1.8085348861558097, 1.305274473769324, 0.06409267402653183, 0.23297936841845512, 35.62281663077218, 61.77425193786621, 42.57407590321132, 29.08102512359619, 17.260575975690568, 26.89057946205139, 49.859178747449604, 53.41304683685303, 56.162250995635986, 24.81377158846174, 0.22840112979922975, 0.026854699344507287, 0.03601649629750422, 0.07348862662911415, 0.03851676552689501, 0.036124675135527334, 0.036582004345421276, 0.023856549956170574, 0.03933274120624576, 0.0060750660902288344, 0.023731244894276773, 0.12485876227063791, 0.13503566118223326, 0.3380880526133946, 0.1381975800863334, 0.13148887721555574, 0.1181947612868888, 0.19993472658097744, 0.11659097591681139, 0.14580994232424668, 0.1432195534663541, 0.14819936268031597, 31.8732316834586, 75.11332716260637, 58.59465203966413, 56.3590795653207, 27.90605868612017, 19.15553559575762, 21.836197512490408, 50.35211174828665, 55.704753807612825, 67.43670722416469, 10.565924099513463, 0.17412971412496908, 0.1514701321721077, 5.655811505658286, 6.062294151101794, 22.6045275756291, 68.48778901781354, 59.85213007245745, 61.460401807512554, 56.892023767743794, 54.700711318424766, 47.65251425334385, 48.109823840005056, 42.54938547951834, 45.88545880998884, 41.42309985842024, 39.07827738353184, 40.7194801058088, 42.774642603737966, 40.210660048893516, 41.315434047154014, 40.78147193363735, 40.666698115212576, 39.425378118242534, 42.26463440486363, 42.303752762930735, 41.803527627672466, 40.94643953868321, 40.8219312940325, 40.250570501599995, 43.62857968466622, 45.79438877105713, 46.72466918400356, 46.95647498539516, 49.9508741242545, 48.03285864421299, 52.54468182155064, 50.2084299496242, 50.55864347730364, 49.80586174556187, 47.390122481754844, 44.362114906311035, 41.79881674902779, 40.71623182296753, 38.42642865862165, 40.77177572250366, 42.91166455405099, 39.04640947069441, 39.75137717383248, 39.45513377870832, 46.8880421774728, 50.725170952933176, 51.78024101257324, 50.25530597141811, 50.42514426367623, 53.47743231909615, 54.445497035980225, 50.999850613730295, 53.66307428904942, 51.89080422265189, 50.09887770244053, 50.54706083025251, 53.45034129279, 52.8818153653826, 52.51952934265137, 51.22967617852347, 51.38682358605521, 37.74092285973685, 53.27897092274257, 51.115597179957796, 51.170950004032676, 50.83931595938546, 51.02086196626936, 48.60512965066092, 47.80072627748762, 47.689760071890696, 47.88279839924404, 46.616986002240864, 44.40546819141933, 47.80348818642752, 41.73793315887451, 39.2531670161656, 40.4025102342878, 37.62975863048008, 41.06955466951643, 39.869899545397075, 40.48023278372628, 41.09680550439017, 40.73997729165213, 40.19825751440865, 39.96348483221871, 41.0056277683803, 43.493183612823486, 46.58514935629708, 52.85630505425589, 50.78195858001709, 54.56679521288191, 52.535451139722554, 54.705780029296875, 55.01449196679251, 55.103540079934255, 51.43128858293806, 47.1823296546936, 40.72173479625157, 42.14188405445644, 42.23698057447161, 42.50580290385655, 39.6927239554269, 42.45084612710135, 43.025100844247, 50.054374490465435, 55.05661194665091, 55.5632016318185, 55.748325960976736, 58.6566994530814, 54.38052790505545, 54.45188243048531, 51.90806702205113, 51.57353557859148, 51.494843755449565, 54.63050324576241, 56.272449425288606, 57.54571376528059, 55.93400962012154, 58.2679442678179, 56.961592606135774, 59.79643331255232, 61.24659878867013, 28.02498231615339, 1.5616256552083152, 5.142398255211966, 2.134066892521722, 0.1434670423290559, 0.7581863988723073, 41.77326474870954, 66.4989436013358, 56.124595233372276, 45.5323166166033, 22.39960609163557, 32.462650844029014, 58.10896948405674, 60.026793888636995, 64.31458282470703, 30.527917998177664, 0.4569273271730968, 0.22944805505020277, 0.10414523232196059, 0.18771698432309286, 0.11666002364030906, 0.1402324658951589, 0.10387626104056835, 0.10032651866120951, 0.13370922021567822, 0.0955060226842761, 0.17946895690900938], [0.042482863779046705, 0.020128225641591207, 0.06482536971036877, 0.0356791897543839, 0.060129283129104545, 0.03389454087508576, 0.06999345203595501, 0.03582113588761006, 0.05787130179149764, 0.03169348184019327, 0.10730300537709679, 27.069391352789744, 55.09767232622419, 47.86804389953613, 35.439821924482075, 13.966719899858747, 22.59894643511091, 25.55160253388541, 39.748149735586985, 48.472783837999614, 53.68391193662371, 5.849437824317387, 0.1602544600942305, 0.11727206222712994, 0.7510579813803945, 0.7451274767518044, 35.933710302625386, 63.117213657924104, 51.5771347454616, 57.03092867987496, 47.98048659733364, 47.8930469921657, 42.42693737574986, 41.10605355671474, 39.954931599753245, 39.59369475500924, 37.47267028263637, 40.155633790152415, 36.94325229099819, 36.81900460379464, 36.21832588740757, 39.18135738372803, 36.37902382441929, 38.34267159870693, 36.12806878771101, 37.57644510269165, 37.85813896996634, 38.56947469711304, 36.24387093952724, 36.9882036617824, 37.220037255968364, 35.73280661446707, 38.404072829655235, 41.566243171691895, 42.6438809803554, 44.08778265544346, 44.73906857626778, 46.127857140132356, 45.92367042813982, 47.0164657320295, 45.44370971407209, 45.599728039332796, 39.18868773324149, 37.723865032196045, 34.80877958025251, 37.16020631790161, 35.85365663255964, 38.57774305343628, 36.46573386873518, 38.45822361537388, 35.961576053074424, 43.85092898777553, 45.962219033922466, 48.305697032383506, 47.91531596864973, 46.24050480978829, 48.610219206128804, 46.252799647195, 49.233180795397075, 49.5490528515407, 47.494501795087544, 47.8634546143668, 48.82378946031843, 47.22008269173758, 45.8337607383728, 42.880786759512766, 48.880253996167866, 47.89615283693586, 30.93888657433646, 46.50936188016619, 45.819638524736675, 46.77538755961827, 47.28943613597325, 46.40977682386126, 46.071990149361746, 43.772758279527935, 42.133706024714876, 42.72297232491629, 40.396632058279856, 39.82701178959438, 37.98653820582798, 36.353412764413015, 35.739094734191895, 34.82224518912179, 36.24309968948364, 36.13002470561436, 37.34569542748587, 37.87441512516567, 37.033186299460276, 37.64672613143921, 36.53272145135062, 36.87959636960711, 37.31595366341727, 40.045338085719514, 42.861019134521484, 47.7237298148019, 46.52759395326887, 48.46837520599365, 50.99225970676967, 48.30863959448678, 45.989737374441965, 45.12867838995797, 38.958983761923655, 37.230344908578054, 39.068000997815815, 39.31301532472883, 37.19906759262085, 38.48114572252546, 36.49825838633946, 38.15304136276245, 44.32331963947841, 47.6899858883449, 49.58139671598162, 50.48162269592285, 48.99658073697771, 48.13900974818638, 50.73147644315447, 47.05395821162632, 48.954349585941856, 51.505606515066965, 51.78104700360979, 51.84132610048567, 52.389031750815256, 56.05949408667428, 54.77881254468645, 51.83017424174717, 57.68548025403704, 54.15728228432791, 60.13655458177839, 30.080335889543804, 1.030019958104406, 1.2541469143969672, 0.3311431924147265, 0.03700413115854774, 0.05823829424168382, 24.380926609039307, 60.184448514665874, 35.003951004573274, 36.85719537734985, 24.88009909221104, 23.933139528547013, 36.77637045724051, 43.19369888305664, 48.657161235809326, 30.903110299791607, 0.40208139589854647, 0.03020308306440711, 0.1256505854959999, 0.044885067734867334, 0.035222803708165884, 0.034297600854188204, 0.0033415555371902883, 0.04614097498623388, 0.05822739018393414, 0.0863321070958461, 0.07383603655866214, 0.06020504156393664, 0.04329411346199257, 0.0786271926813892, 0.015799550505887185, 0.09544350925300803, 0.025619680793689828, 0.05767804144748619, 0.04561434360221028, 0.02342904744935887, 0.013947913256872977, 0.21404887922108173, 35.79909242902483, 63.50149072919573, 52.368124621255056, 42.048246656145366, 17.840939896447317, 22.16606671469552, 23.727742092950002, 44.6574376651219, 52.59301349094936, 58.403625215802876, 6.436485477856227, 0.2956507626388754, 0.28727438354066437, 2.017162799835205, 0.5728942815746579, 40.301643235342844, 63.97988115038191, 54.60396112714495, 57.73935311181204, 50.634486539023264, 49.62325266429356, 44.58496100561959, 43.021564211164204, 41.01007808957781, 41.41062784194946, 38.56056710651943, 41.89260005950928, 38.770802225385395, 38.429200989859446, 37.620910099574495, 39.22198002679007, 38.253915309906006, 39.82002190181187, 37.65871524810791, 40.452307973589214, 39.61210748127529, 39.93534810202462, 38.215231214250835, 38.71019308907645, 39.01565326963152, 38.69923577989851, 40.87495299748012, 41.72817093985421, 44.72804178510393, 46.13318988255092, 47.52272537776402, 48.91060372761318, 49.1172639983041, 50.620465074266704, 47.370101247514995, 47.089658055986675, 40.90634495871407, 38.37845482145037, 37.41913441249302, 38.50306034088135, 36.837062971932546, 38.29621246882847, 39.580420221601216, 39.641866615840364, 37.970366273607524, 45.693824018750874, 48.456938471112935, 49.50026260103498, 49.266931670052664, 48.165725571768625, 49.82065098626273, 48.21944556917463, 50.94332354409354, 49.94515575681414, 49.94512448992048, 50.99693584442139, 51.81084087916783, 49.02796575001308, 47.814417702811106, 44.725109645298545, 50.08034338269915, 48.52330418995449, 34.755160331726074, 47.1966290473938, 48.53064496176583, 48.75162199565342, 49.096912724631174, 47.989171845572336, 47.21392658778599, 45.06276430402483, 45.66228267124721, 43.4601206098284, 43.69900662558419, 41.11080265045166, 39.38578380857195, 38.3702073097229, 38.760682174137656, 36.385277203151155, 39.171768869672505, 38.16657297951834, 38.42048100062779, 38.06144673483712, 38.61082342692784, 39.32943739209856, 38.16697250093733, 39.96662194388253, 38.97530855451311, 40.590094225747244, 45.425331728799, 50.210913930620464, 48.147844382694785, 50.66959926060268, 52.22885145459856, 49.30516413279942, 47.85379661832537, 46.03301075526646, 41.94626447132656, 39.09241696766445, 39.32144348961966, 39.66768612180437, 38.43666682924543, 38.240949971335276, 39.29140642711094, 40.24569286618914, 45.53988667896816, 50.07865497044155, 51.06191887174334, 53.78487968444824, 48.33795404434204, 48.92775535583496, 50.841921533857075, 48.854663780757356, 50.734755992889404, 53.051257610321045, 52.980014256068635, 53.02468422480992, 53.82573161806379, 57.52356290817261, 56.77836513519287, 53.966470854622976, 57.589553424290244, 57.19813707896641, 61.34204619271414, 32.939637729099815, 1.882692358323506, 1.8501365738255637, 1.5105012442384447, 0.08205808965223176, 0.09745949786156416, 26.011000054223196, 64.60134192875454, 41.54720163345337, 35.993520396096365, 23.86403795651027, 28.403933593205043, 42.72772141865322, 48.31752634048462, 55.941249643053325, 40.881334917885916, 0.7554722045149121, 0.01923276637015598, 0.06258440603102956, 0.03870755261076348, 0.06509006622114352, 0.06080515829047986, 0.01226571383553424, 0.05515557394496032, 0.03929269067677004, 0.034791516672287665, 0.04251492116600275, 0.1423430490706648, 0.09087658181254353, 0.19233867632491247, 0.1704853025398084, 0.13800163274364813, 0.082443931805236, 0.16290887551648275, 0.14830175361463002, 0.1840482269014631, 0.12364845935787473, 0.5171628349593708, 42.32425342287336, 71.39164965493339, 59.33609431130545, 49.35409334727696, 21.269186292375835, 31.542049271719797, 34.93734557288033, 52.69163274765015, 56.91047818320138, 63.64939703260149, 7.534956591469901, 0.35555484678064075, 0.41577898232000216, 6.801624604633876, 3.4361938323293413, 39.22369623184204, 69.17040089198521, 54.85433598927089, 60.80028125217983, 51.80269411631993, 52.96014240809849, 46.89653982434954, 45.26348039082119, 42.831075872693745, 44.07174621309553, 40.328379903520855, 45.143262658800396, 41.41192715508597, 41.262426240103586, 39.39452811649868, 42.856791155678884, 40.357527596609934, 43.0991200038365, 39.20491525105068, 40.61965881075178, 41.358262743268696, 42.67507839202881, 40.414707796914236, 40.869053976876394, 41.85896383013044, 39.67309529440743, 43.21799325942993, 44.23449386869158, 46.45122977665493, 48.66014896120344, 49.16263573510306, 50.336662428719656, 49.34011009761265, 51.39318118776594, 50.125572681427, 49.55540350505284, 43.80034262793404, 40.509950229099815, 39.200951303754536, 40.70255776814052, 38.840148721422466, 41.608991963522776, 39.66449689865112, 42.26845938818795, 40.40547364098685, 46.093856130327495, 49.6953888620649, 52.025373458862305, 49.87958560671125, 50.396472522190635, 52.71762595857893, 51.10055085590908, 53.589315686907085, 53.49471596309117, 51.35329852785383, 51.03721802575247, 52.365619795663015, 50.82893535069057, 50.36085605621338, 46.768758978162495, 52.52041523797171, 51.19707523073469, 37.109460149492534, 49.42491633551461, 49.4794214793614, 51.6055702481951, 51.18741723469326, 49.40539884567261, 49.87169245311192, 46.681566034044536, 46.209595748356406, 47.04708644321987, 45.69927488054548, 44.049345220838276, 41.33023023605347, 41.280071190425325, 41.336532252175466, 38.302424158368794, 41.96852649961199, 39.10725137165615, 40.52496181215559, 40.266252585819785, 41.07298707962036, 40.568787574768066, 40.4034343447004, 41.27634000778198, 42.09628997530256, 44.37801238468715, 47.70315619877407, 53.04346520560128, 50.32626792362758, 51.679415702819824, 56.61715997968401, 51.9253819329398, 50.36081089292254, 48.01518242699759, 44.55270051956177, 41.04135887963431, 41.38911621911185, 43.0257157598223, 41.306759221213206, 42.266902991703574, 41.41546031406948, 42.58749982288906, 48.76660926001412, 51.68130908693586, 53.51483447211129, 54.043040003095356, 51.53346184321812, 49.79167004993984, 52.35762936728341, 49.510955878666465, 51.29784842899868, 55.976699352264404, 53.502397196633474, 54.327923093523296, 55.735815729413716, 60.814247131347656, 59.18690953935896, 57.32248204095023, 58.481959206717356, 60.20170783996582, 63.39147990090506, 34.59430258614676, 2.4900222378117696, 3.4864927104541232, 2.361518996102469, 0.1539670867579324, 0.3536173036055905, 28.664098467145646, 70.38904544285366, 47.37414509909493, 49.17954765047346, 34.30849885940552, 34.36541155406407, 49.77994149071829, 57.640098094940186, 62.77349322182791, 47.247587135859895, 1.3513106320585524, 0.14856955781579018, 0.2807390056550503, 0.08215642973248448, 0.15539187459009035, 0.17724516695099218, 0.08813839445688895, 0.13884594743805273, 0.25101841187902857, 0.1551738612885986, 0.12163650803267956], [0.02804145709212337, 0.02792961077232446, 0.08148668852767774, 0.05744887303028788, 0.01770649175159633, 0.0420868673494884, 0.05689526987927301, 0.04404060037008353, 0.059789364226162434, 0.08756792292531047, 0.6720470296485084, 36.7766101700919, 51.34137541907174, 48.69110318592617, 34.46439906529018, 18.53777473313468, 48.48113904680525, 41.72322382245745, 32.22752032961164, 56.16468633924212, 43.43471452168056, 4.958455988339015, 0.04080681782215834, 0.0663646331855229, 0.9665791051728385, 3.8167566571916853, 53.927435874938965, 58.41779259272984, 54.33057383128575, 54.15001794270107, 48.989319869450156, 47.42591960089547, 43.730224881853374, 40.86158118929182, 39.04508931296212, 38.11715391704014, 35.69951779501778, 36.999046325683594, 38.8265198298863, 38.81915821347918, 37.09891973223005, 39.88366045270647, 38.47952331815447, 36.649211474827354, 35.63233913694109, 36.23938587733677, 36.099098273685996, 37.22859396253313, 35.92182193483625, 36.80483375276838, 35.727373123168945, 36.030616828373496, 36.40578828539167, 37.55957835061209, 41.016460009983604, 45.03886597497122, 45.81404869897025, 47.98381131035941, 46.72482551847185, 46.523070675986155, 45.47595282963344, 42.170844146183555, 36.207608291081016, 36.79907717023577, 34.841863427843364, 38.35590444292341, 35.556391852242605, 37.02569266727993, 37.884965964726035, 36.93722472872053, 35.62467874799456, 40.85377141407558, 46.49745266778128, 43.4481314931597, 48.13689054761614, 45.677659034729004, 43.9682354245867, 45.07905782972063, 43.716797488076345, 45.94107566561018, 45.57588529586792, 47.297923360552105, 44.92846604755947, 43.52912664413452, 39.684014388493125, 45.206043107169016, 47.2770231791905, 49.50149590628487, 30.406616347176687, 42.934638772692, 47.80469022478376, 47.517816475459504, 47.939151763916016, 46.54423836299351, 44.99583578109741, 44.592958382197786, 42.77520540782383, 42.174988746643066, 42.102828230176655, 40.85424041748047, 39.15819556372506, 36.29507221494402, 34.88961839675903, 35.947144644601, 35.39981419699532, 37.438224588121685, 37.60196583611624, 36.995103222983225, 38.798591545649934, 36.4804744720459, 36.07283755711147, 36.60217564446585, 37.588402952466694, 37.28908150536673, 41.56886264256069, 47.98685114724295, 48.70361341748919, 47.70778022493635, 48.26710326331002, 45.37579454694475, 39.957512855529785, 37.083074365343364, 37.52996512821743, 37.11858313424246, 37.9529367174421, 36.716793128422324, 37.15275090081351, 39.14139134543282, 39.09388651166643, 42.98399182728359, 46.164550576891216, 48.24678325653076, 51.08874934060233, 47.88720703125, 44.27423409053257, 48.110157353537424, 50.760061332157676, 52.27528626578194, 53.23020499093192, 54.04956088747297, 51.94127593721662, 55.214426381247385, 53.53123916898455, 55.309953689575195, 52.998982838221956, 62.63425132206508, 58.860149656023296, 54.41670370101929, 55.48000737598964, 33.17908654894148, 1.854682432753699, 1.4842577895947864, 0.9572857809918267, 0.05000641256836908, 0.12124123424291611, 11.562604972294398, 61.030676569257466, 43.770993437085835, 41.20207418714251, 35.693962710244314, 25.334226403917583, 41.54315778187343, 51.13186986105782, 51.972858973911826, 39.64456251689366, 1.9282638558319636, 0.04131742220904146, 0.048988654145172665, 0.061439995653927326, 0.04673485936863082, 0.013262221390115363, 0.04417072981595993, 0.05893521077398743, 0.03830474029694285, 0.032168941505785496, 0.040249140068356476, 0.048377511224576404, 0.04878734298316496, 0.020432735194585154, 0.048173153440334966, 0.03187443355896643, 0.032521409913897514, 0.04590892279520631, 0.06028008075164897, 0.05645852402916976, 0.009171761239745786, 1.0971753831420625, 46.915206159864155, 57.45128427233015, 54.59825318200247, 37.53546462740217, 24.143883602959768, 40.5420891216823, 34.978972230638774, 40.98831980569022, 58.58220781598772, 47.45333024433681, 4.764030626841953, 0.31873615245733944, 0.42144792526960373, 1.9329009098666055, 4.212442670549665, 57.77472639083862, 59.78521197182791, 57.5550035067967, 55.4100216456822, 52.61391714641026, 49.26451022284371, 46.009157589503694, 43.29188387734549, 41.29059076309204, 40.0046911239624, 39.43586989811489, 38.780800683157786, 40.35950435910906, 39.77284363337925, 38.520792143685476, 41.31745249884469, 41.23148591177804, 38.16451283863613, 36.979778970990864, 38.43774380002703, 37.284221240452354, 38.23229251589094, 38.9449588230678, 37.77656364440918, 37.48850522722517, 37.42535999843052, 38.65544475827898, 39.783109596797395, 43.16943577357701, 46.616746289389475, 46.23702028819493, 49.832945823669434, 48.31627566473824, 48.16332149505615, 46.66478613444737, 44.260077135903494, 38.771239961896626, 39.64604595729283, 37.56811421258109, 37.64165047236851, 36.56123685836792, 39.26167508534023, 38.97761883054461, 38.84487002236502, 36.80533054896763, 42.39352001462664, 49.30443804604666, 46.79856327601841, 48.11780384608677, 47.6715418951852, 45.412456716809956, 46.04928343636649, 46.692182881491526, 47.639284883226665, 47.41865178516933, 49.583891119275776, 47.323579583849224, 44.59249980109078, 42.03780351366316, 48.03183031082153, 49.674707548958914, 50.642768791743684, 32.09837416240147, 45.54841559273856, 49.4604355267116, 49.97433124269758, 50.212390422821045, 48.27646943501064, 47.26076439448765, 46.59032923834664, 45.55615241186959, 43.86522143227713, 43.096090589250835, 42.50832857404436, 40.06977142606463, 37.476623807634624, 37.427197796957834, 38.6599645614624, 37.746828828539165, 38.7216089793614, 39.753190653664724, 38.279279708862305, 39.796891348702566, 39.297298499516074, 36.65404394694737, 37.709923471723286, 38.815256799970356, 39.178783076150076, 43.250917298453196, 50.431769371032715, 49.316882269723074, 49.75470215933663, 49.06492321831839, 47.58894171033587, 42.42715276990618, 38.42908981868199, 38.771761076790945, 39.37381901059832, 39.75315591267177, 38.84236172267369, 38.7611129624503, 41.38632999147688, 41.959202017102925, 44.494179316929404, 47.432805265699116, 51.32084001813616, 52.440187862941194, 48.92685209001814, 45.86882482256208, 50.253113814762656, 51.5596843447004, 54.43664155687605, 53.643278871263774, 54.87522227423531, 54.01820019313267, 55.148755482264924, 55.50987073353359, 55.29892689841134, 54.078677313668386, 61.14063876015799, 59.59244115012032, 56.809420108795166, 58.2665650503976, 35.286763531821116, 2.7294612867491583, 2.2848725489207675, 2.217992446252278, 0.1374940885496991, 0.015957910401214446, 13.197478754179818, 65.64075074877057, 49.0364043372018, 41.295343330928254, 35.36851256234305, 33.69897508621216, 48.508938789367676, 59.84682164873396, 58.02907909665789, 48.71153088978359, 3.574135116168431, 0.10104339769376175, 0.0710226743082915, 0.05899611607726131, 0.07725384458899498, 0.018093981048358337, 0.04871040050472532, 0.03435448583747659, 0.015802191703447273, 0.03258194541558623, 0.025796737721455947, 0.16624778349484715, 0.16545207904917852, 0.20124942889170988, 0.1531958502850362, 0.10815257871789591, 0.15347919293812343, 0.1217375961797578, 0.10415684205612966, 0.16266319155693054, 0.213148707523942, 2.0293075995785848, 55.436824321746826, 63.68153245108468, 60.57201208387102, 45.81879084450858, 26.371748788016184, 58.81594521658761, 50.47007826396397, 44.13179949351719, 64.98086643218994, 53.069642543792725, 6.8096619333539685, 0.39844029556427685, 1.0813998239380973, 5.497732170990535, 4.9496448040008545, 60.398425238473074, 63.96015521458217, 59.64974294389997, 57.96386330468314, 54.25762122017996, 52.590762274605886, 48.702821322849815, 44.936873367854524, 43.35453230994088, 41.826543535505024, 40.190517221178325, 41.00130251475743, 42.385362829480854, 42.42932755606515, 40.89054822921753, 43.51994807379586, 43.39104856763567, 40.09097385406494, 39.58897692816598, 41.432754380362375, 39.49068076269967, 41.37707846505301, 40.78013440540859, 39.95969111578805, 39.233253479003906, 40.40206554957798, 40.72876984732491, 41.001215662275044, 45.87007202420916, 48.703575202396934, 48.94564001900809, 51.25814642224993, 51.42832865033831, 51.148663657052175, 49.0192666053772, 45.41999551228115, 39.10284273965018, 40.147994245801655, 38.55332013538906, 39.98995399475098, 38.40922144481114, 40.14736543382917, 41.096614428928916, 40.32047980172293, 38.58842938286917, 45.03867489950997, 51.240220069885254, 48.576836585998535, 49.13177531106131, 48.601877893720356, 46.845703329358784, 49.6561940738133, 47.99651261738369, 49.40825455529349, 49.35207142148699, 52.01065717424665, 47.79394136156355, 46.35782514299665, 44.64340925216675, 49.30450405393328, 51.26405586515154, 53.51472330093384, 34.7401556968689, 45.90647711072649, 51.13031346457345, 51.93474810464041, 51.52413388660976, 49.97422354561942, 49.35656690597534, 48.94061647142683, 46.59544311250959, 45.721564701625276, 46.12978873934065, 44.61538369315011, 42.063022000449045, 40.2586338860648, 39.723598275865825, 41.234039374760215, 38.76999276024954, 40.47375011444092, 41.57901048660278, 39.22951534816197, 42.353265626089915, 40.42377519607544, 39.02564825330462, 39.251954555511475, 40.45699453353882, 40.51525865282331, 46.11794206074306, 53.012847968510215, 51.790576457977295, 52.180353028433665, 52.990408761160715, 49.78363445826939, 44.81778471810477, 40.604810510362896, 41.40054253169468, 41.94389166150774, 42.88956928253174, 41.34605475834438, 41.96017129080636, 43.10613073621477, 43.283594676426475, 47.432006222861155, 51.120613779340474, 52.84448964255196, 54.945180211748394, 50.293305669512065, 46.04992267063686, 50.40091936928885, 53.85535178865705, 56.110222884586875, 56.45611810684204, 57.29380335126604, 56.00776127406529, 60.094837597438264, 58.17076676232474, 57.43742609024048, 55.932133606501985, 60.35120528084891, 62.017550059727256, 59.076440129961284, 60.744744300842285, 36.79126739501953, 3.411601117679051, 4.7678577814783365, 3.377874778849738, 0.33992449407066616, 0.16876129433512688, 15.12572979927063, 70.38521698543003, 54.910116127559114, 54.33228656223842, 47.45716217585972, 37.736882482256206, 52.814247608184814, 66.81965160369873, 64.6668425968715, 57.99326113292149, 5.561332072530474, 0.22073931592915738, 0.21305126989526407, 0.14627403313560144, 0.13994849898985454, 0.08256239044879164, 0.18051966838538647, 0.08707575433488403, 0.10106899882001535, 0.06563639547675848, 0.1388909885925906], [0.06766136788896152, 0.05878545809537172, 0.031979080622217486, 0.08336970462862935, 0.02460030745714903, 0.012147412103201662, 0.024179457986195172, 0.016637303766661456, 0.05249720944889954, 0.06334115578127758, 1.1287255244595664, 40.67061342511858, 51.52965075629098, 45.331871509552, 30.815080097743444, 13.97761641229902, 46.88174710954939, 50.34483698436192, 35.17468908854893, 57.58846950531006, 38.46846178599766, 2.445339241198131, 0.47554285398551394, 0.8586229352014405, 1.378018096089363, 9.843683174678258, 60.568336486816406, 54.54793085370745, 56.0873806817191, 51.77978937966483, 49.134978430611746, 46.866197041102815, 43.782749789101736, 39.9651836667742, 37.417234080178396, 38.35958351407732, 39.451961926051546, 42.732845715114046, 45.8360710144043, 48.06309373038155, 49.45424815586635, 45.729805265154155, 44.91991628919329, 42.52973249980381, 40.46668379647391, 35.46286562510899, 35.214352880205425, 35.85889210019793, 34.93662643432617, 36.48567172459194, 37.605012621198384, 36.35063695907593, 37.833472864968435, 38.34119163240705, 39.86243718011038, 42.813427448272705, 45.348835536411826, 46.07828869138445, 47.42731966291155, 44.98996107918875, 43.16388068880354, 37.61836705889021, 36.84353174482073, 36.845473766326904, 36.38396051951817, 36.161628586905344, 36.73878417696272, 37.132135595594136, 36.58272416251046, 37.12935284205845, 35.61757074083601, 38.99495806012835, 46.12554686410086, 48.282038416181294, 44.919732161930625, 47.04062114443098, 46.88277544294085, 44.4178637777056, 43.38940879276821, 41.94242211750576, 40.96793379102434, 40.65274265834263, 40.32444722311837, 38.02881452015468, 41.867430210113525, 47.115599155426025, 46.953664439065115, 49.09224353517805, 30.62308052607945, 40.471947056906565, 44.41989959989275, 45.06453956876482, 47.8113431249346, 49.403717381613596, 49.493463788713726, 47.31319202695574, 46.02056653159005, 43.095774446214946, 42.86360386439732, 42.959589753832134, 39.12892975125994, 36.58893585205078, 35.3094459261213, 35.549950872148784, 35.87566157749721, 37.68775177001953, 39.41060624803816, 37.85965715135847, 37.96343197141375, 37.22379275730678, 36.40329735619681, 37.371379443577354, 37.8245062146868, 38.19072144372122, 37.995345047542024, 46.417527539389475, 48.10581125531878, 45.75365843091692, 47.62916483197893, 45.64557225363595, 40.918396609170095, 38.12252834865025, 37.94949041094099, 36.82984379359654, 37.34219700949532, 35.20525768824986, 37.38976437704903, 39.59487247467041, 41.59296594347273, 43.429993220738, 47.268143381391255, 49.74159785679409, 49.382810252053396, 46.74359607696533, 52.70746769223894, 50.303554262433735, 50.43593829018729, 50.426290716443745, 50.17154891150338, 50.06820140566145, 49.272479806627544, 50.524482658931184, 53.19881650379726, 54.27476937430245, 59.2256874356951, 44.567361218588694, 43.04363168988909, 52.013366971697124, 55.22959777287075, 36.38569409506661, 3.970168105193547, 1.37044358253479, 0.27301421016454697, 0.02728521285046424, 0.04168068610930017, 5.321462452411652, 55.9604857308524, 48.979130336216514, 41.51035533632551, 31.07425832748413, 12.062041487012591, 24.91032201903207, 40.828476497105186, 50.52012613841465, 48.329147202628, 6.611961364746094, 0.10923063515552453, 0.04819237294473818, 0.030866062667753016, 0.06816148212445633, 0.016763687699234912, 0.010156888913895403, 0.03682274178468755, 0.06392339989542961, 0.06758609799934284, 0.018873629659148197, 0.04575282920684133, 0.010770958016759582, 0.024388275441846678, 0.013465428209331418, 0.013393020889322673, 0.057419227835323126, 0.04771706255685006, 0.04349678847938776, 0.09638921743524925, 0.03753825356917722, 2.523880375283105, 51.27324833188738, 57.61020694460188, 49.259274755205425, 36.34368528638567, 14.059445347104754, 37.958352838243755, 50.69484554018293, 38.82834720611572, 63.20738737923758, 42.87336608341762, 2.9363289177417755, 0.4746155951704298, 0.7923428203378404, 1.8910271567957742, 12.149037275995527, 64.06702545710972, 56.431886264256065, 57.38756581715175, 54.51286676951817, 51.63710464750017, 48.26929889406477, 45.40790564673287, 43.81888042177473, 40.29908977236067, 41.17973572867257, 41.390144552503315, 44.805100781576975, 47.37593078613281, 49.324042388371055, 51.49659122739519, 48.60056815828596, 46.94325603757586, 45.100222042628694, 41.35599763052804, 37.41864456449236, 37.25417375564575, 37.639201232365195, 36.850646700177876, 37.615268162318635, 36.81896986280169, 38.794210706438335, 38.73992095674787, 39.6262331690107, 42.27738087517874, 44.82670273099627, 46.681274209703716, 47.47158316203526, 49.322809083121165, 47.81467478615897, 45.887004784175325, 39.76184810910906, 38.12442520686558, 38.73096820286342, 38.48432799748012, 38.57221576145717, 38.35242339542934, 39.89178984505789, 38.78645304271153, 37.82745572498867, 37.30953352791922, 39.99776029586792, 47.35215057645525, 48.70324168886457, 47.0336833681379, 49.70957360948835, 48.35926764351981, 46.66687406812395, 44.60154635565621, 44.005943298339844, 42.087924344199045, 43.03303916113717, 41.726187229156494, 38.425108500889365, 43.29698038101196, 48.11825547899519, 49.49260916028704, 53.700938497270855, 32.32163715362549, 40.60966035297939, 45.23103577750069, 46.58889790943691, 49.24305418559483, 49.200124740600586, 51.74940490722656, 50.58958380562918, 47.333915029253276, 46.428641183035715, 45.626054763793945, 44.86635610035488, 41.11074011666434, 37.81193344933646, 37.16864143099104, 37.25804042816162, 38.196297373090474, 37.98692035675049, 41.097378730773926, 39.944828919001985, 40.64747592381069, 37.32537194660732, 38.33325678961617, 38.72563893454415, 38.527618748801096, 38.655034814562114, 40.870016302381245, 49.49474573135376, 51.81883478164673, 49.03705399377005, 49.16720764977591, 46.844511713300435, 42.134769099099294, 40.484783853803364, 40.34146336146763, 38.71693631580898, 39.616116591862266, 37.06136471884591, 39.03069611958095, 41.66371944972447, 43.40407643999372, 46.695587498801096, 49.784197262355256, 51.581202915736604, 50.61148452758789, 49.427667822156636, 52.236536162240164, 51.818522112710134, 52.09164885112217, 52.295578479766846, 51.05054814474923, 51.73596361705235, 50.91752140862601, 52.25626557213919, 54.68571710586548, 57.17583336148943, 58.00389187676566, 44.72456768580845, 45.62656545639038, 51.98860011781965, 55.97526454925537, 40.284707001277376, 4.215928929192679, 2.379076659679413, 4.611328763621194, 0.5072456928236144, 0.034214317465999296, 5.0145183971949985, 59.547055516924175, 53.50381462914603, 43.06261764253889, 34.46379109791347, 20.592157295772008, 30.394460473741802, 44.98750489098685, 54.55759927204677, 57.93484762736729, 10.767225572041102, 0.1295318736561707, 0.047341842869562764, 0.05055048908772213, 0.13796486971633776, 0.015415883057617714, 0.008774624023187374, 0.035270888092262406, 0.06696757261774369, 0.07001768930682115, 0.01510330572325204, 0.22275267860719136, 0.18001931666263513, 0.13206502129989012, 0.22883115815264837, 0.16939420465912136, 0.13264066326831067, 0.1454193097140108, 0.18059829702334745, 0.17454489613217966, 0.1935041823557445, 3.965035557746887, 62.02335180555071, 64.83968598502022, 56.79092747824532, 42.792513370513916, 22.338121482304164, 53.441857542310444, 60.055100849696565, 47.0228476524353, 67.03945786612374, 48.099901812417166, 3.746680166040148, 0.7413882602538381, 2.360651122672217, 5.415280069623675, 12.917209267616272, 66.47789055960519, 58.543346541268484, 60.4366055897304, 57.75755391802107, 54.45977210998535, 50.415673868996755, 48.53925377982003, 45.61951303482056, 41.00106280190604, 43.60819019590105, 44.57632786887032, 47.22346299035208, 49.28645263399397, 51.68774311883109, 53.775732381003245, 50.72913490022932, 48.20949922289167, 47.72966705049787, 44.06681299209595, 39.5835816519601, 39.06805310930525, 38.87835686547415, 38.5289180619376, 40.31119353430611, 41.34610339573452, 40.42709296090262, 41.65050745010376, 40.884062085832866, 44.68764843259539, 46.64107193265642, 49.660182339804514, 49.1306323323931, 52.735184056418284, 49.04899099894932, 48.542147704533164, 39.756004674094065, 39.87317909513201, 41.0163106237139, 39.83363342285156, 39.95445564814976, 39.94027090072632, 41.44011599676949, 39.633191789899556, 39.19810601643154, 38.40323904582432, 41.00958824157715, 48.19243097305298, 52.04739577429635, 50.01593705586025, 51.43048259190151, 49.79300062997, 49.64644227709089, 47.14067867824009, 45.16803298677717, 44.21922172818865, 46.624684606279644, 45.06329236711775, 40.755690642765586, 44.588316985539024, 51.1303516796657, 50.49123205457415, 54.858727250780376, 35.17906297956194, 41.831344740731375, 46.48715196337019, 47.83203138623919, 50.822841780526296, 52.28680290494646, 54.10429184777396, 52.62113632474627, 49.58926207678658, 49.088661738804404, 47.70265245437622, 47.42779214041573, 42.577661173684255, 40.36544506890433, 38.880701882498606, 40.20318726130894, 40.983174664633616, 40.44145488739014, 43.46054792404175, 41.98783901759556, 42.77480936050415, 40.979443481990266, 39.811065673828125, 40.68654217038836, 40.78297969273159, 41.62928417750767, 44.320661953517366, 51.864237785339355, 53.88269989831107, 50.11010946546282, 51.22810588564192, 49.42428404944283, 45.11319432939802, 41.43954277038574, 42.504566124507356, 41.392270701272146, 41.268221037728445, 39.72550555637905, 41.63863297871181, 42.80869919913155, 47.03545863287789, 48.26730823516846, 51.8021035194397, 53.65382623672485, 53.090334279196604, 49.69162293842861, 55.34967654091971, 53.99913086209978, 54.81476252419608, 54.683313029153005, 53.98876067570278, 54.639063426426475, 53.077473163604736, 55.40866674695696, 57.33562455858503, 59.884112630571636, 58.979874065944124, 46.772531849997385, 48.46725307192121, 52.9578286579677, 57.786423683166504, 41.57287522724697, 6.335599371365138, 4.704589222158704, 6.265380007880075, 0.4121299295553139, 0.14595561022205011, 6.299674579075404, 65.96858760288784, 58.5930609021868, 52.969268866947715, 40.64554779870169, 23.150701148169382, 37.620472363063264, 53.99849162782942, 60.90757533482143, 67.33230359213692, 14.053831202643257, 0.42406194071684566, 0.17000340696956429, 0.1662163266113826, 0.20237946111176694, 0.10151269965405975, 0.12089284722294126, 0.17995869634406908, 0.1292082667350769, 0.2600295197750841, 0.11472343041428498], [0.015566066605970263, 0.06681699212640524, 0.04546793270856142, 0.07065684893833739, 0.056468637593622716, 0.02086217831155019, 0.046017888733851056, 0.0027941153925244828, 0.06601833605340549, 0.15254042616912297, 2.6047756459031786, 48.958653994968955, 52.90246541159493, 45.650408199855256, 27.68330291339329, 29.267313276018413, 46.65561103820801, 43.85567460741316, 42.42036785398211, 53.77182401929583, 36.51748405184065, 0.9624717427151543, 0.08618708380631038, 0.36222734302282333, 0.4923530976687159, 26.59388964516776, 64.65817124502999, 53.42278821127755, 54.61842727661133, 50.00764090674264, 51.78619909286499, 47.08619090488979, 44.66587972640991, 40.52166141782488, 40.236719267708914, 41.56064987182617, 45.71468251092093, 48.35992077418736, 46.809412888118196, 49.11885860988072, 46.58873462677002, 46.351241724831716, 46.71878405979702, 41.97158023289272, 40.189565317971365, 38.30065584182739, 35.855727195739746, 35.32852915355137, 36.3251405443464, 35.36875227519444, 36.25814253943307, 35.66871990476336, 37.23690748214722, 36.87646273204258, 39.009507587977815, 41.58445092609951, 44.50005054473877, 46.6948892048427, 46.745551994868684, 43.81159176145281, 40.17692654473441, 36.40763303211757, 35.90517405101231, 37.55108765193394, 35.890061719076975, 36.52947316850935, 37.82131699153355, 37.94037784848894, 37.09576525006975, 38.314041546412874, 37.36540746688843, 35.565268175942556, 39.40139988490513, 49.09115614209856, 46.818931920187815, 45.28700699125017, 47.080180713108604, 47.37658044270107, 44.5281594821385, 42.764213357652935, 41.153391633714946, 37.922868388039724, 39.615334919520784, 41.18982798712594, 46.81460666656494, 48.46465791974749, 47.958575453077046, 46.90802867071969, 30.540667942592076, 39.68362528937203, 43.24318395342146, 44.83092723573957, 46.19888162612915, 46.42156791687012, 47.17224434443882, 48.23658677509853, 45.31938559668404, 45.087489468710764, 45.47614390509469, 43.18886988503592, 40.939981188092915, 37.271770068577354, 34.320776326315745, 34.72630793707711, 34.63559225627354, 36.492974281311035, 36.87579917907715, 37.22961187362671, 37.97199215207781, 37.52902364730835, 35.63566384996687, 37.7890738759722, 36.26728636877877, 37.652090140751426, 38.76370811462402, 45.74339246749878, 49.49115003858294, 46.86862891060965, 47.2630329813276, 45.66050740650722, 43.08825649533953, 39.24652106421334, 37.607996872493196, 37.479865142277305, 37.456661633082796, 37.345962933131624, 37.516027041843955, 40.44464758464268, 41.52847276415144, 48.01089538846697, 49.69887685775757, 48.42362185886928, 50.42764561516898, 49.85619797025408, 47.842498847416465, 47.301918574741904, 46.95102412360055, 50.07252318518502, 45.324249335697715, 47.11522742680141, 46.947431904929026, 51.14051342010498, 51.571940967014854, 54.300825119018555, 44.002521310533794, 40.68836954661778, 54.555028438568115, 50.76526205880301, 50.46307100568499, 38.36460706165859, 4.129424290997641, 1.3294540963002612, 3.2179441835199083, 0.2585614142673356, 0.020988672506064177, 1.3970771133899689, 45.99328442982265, 57.60745198386056, 43.09908526284354, 35.362061159951345, 20.368367978504725, 23.25042516844613, 40.52951635633196, 46.59196901321411, 51.81610761369978, 12.096062472888402, 0.11968483775854111, 0.013814473408274353, 0.02996904615844999, 0.043723334358739, 0.05193156908665385, 0.03538579799767051, 0.05748252158186265, 0.0418523147569171, 0.0271391921144511, 0.03249856024714453, 0.04405449676726546, 0.019517761256013597, 0.02815471137208598, 0.09834398182907275, 0.1050730746771608, 0.006514175362618906, 0.03007689251431397, 0.02444830713128405, 0.0693362569436431, 0.10500258167407342, 4.384810975619724, 60.844061851501465, 56.49559429713658, 51.69387142998831, 34.23654678889683, 33.53328834261213, 52.41775212969099, 46.34469304765974, 45.03261259623936, 59.735539300101145, 39.834654808044434, 1.158225187233516, 0.013780624688869076, 0.7822780832648277, 0.4136617359306131, 28.756417444774083, 65.61166558946881, 55.040829113551546, 57.952020100184846, 51.700982911246165, 53.6989026750837, 49.20750372750418, 47.29890653065273, 41.51889814649309, 41.835975715092246, 42.269640581948416, 47.53648975917271, 49.746937547411235, 51.010988576071604, 50.53348752430507, 48.57688522338867, 48.23298413412911, 49.94808094842093, 45.74201325007847, 41.885540689740864, 40.31106151853289, 37.159094606127056, 36.273216656276155, 36.704953398023335, 37.04617943082537, 36.366815839494976, 37.71686472211565, 37.89142084121704, 40.2474125453404, 40.84950174604143, 42.706244536808555, 46.386003562382285, 48.08210400172642, 48.10916028703962, 47.339136600494385, 42.603088106427876, 37.53069816316877, 39.25327818734305, 38.13693196432931, 37.84569822038923, 36.70164258139474, 39.90088503701346, 38.175424984523225, 39.47315740585327, 39.82886348451887, 38.326770646231516, 37.91216468811035, 42.798738956451416, 50.556496483939036, 49.19055012294224, 46.940646989004954, 49.1911997795105, 47.9403190612793, 44.33234882354736, 44.88592570168631, 42.653980187007356, 39.099563189915244, 40.65961790084839, 43.392104693821494, 49.43962567193167, 51.15544509887695, 49.252166748046875, 48.3286087172372, 31.82984365735735, 40.866531780787874, 43.84666626793997, 46.1244455746242, 46.69820696966988, 48.39923020771572, 48.05893523352486, 48.207150731767925, 48.536609990256174, 48.84215702329363, 47.133615834372385, 44.593816484723774, 41.902150358472554, 39.62581975119454, 37.40968138831002, 36.98675496237618, 37.74323660986764, 37.69521066120693, 38.564694336482454, 39.22683334350586, 38.57571070534842, 38.23661082131522, 37.52643544333321, 40.08542224339077, 38.04690415518624, 38.59914003099714, 39.92559977940151, 47.23222466877529, 51.32366098676409, 48.383808680943076, 49.52654068810599, 47.336159297398154, 43.778229985918315, 41.87004620688302, 39.063547202519004, 40.276098183223176, 38.533833912440706, 39.323892729622976, 38.852752753666465, 41.962022985730854, 44.53416619982038, 48.61609738213675, 50.84276226588658, 50.6585898399353, 51.574977329799104, 50.8496653011867, 51.19836759567261, 49.89441653660366, 49.54057952335903, 51.327746527535574, 48.27759156908308, 50.162259169987266, 48.03929615020752, 53.3356682232448, 53.10572106497628, 56.166399070194785, 46.00629840578352, 42.05254759107317, 55.347390583583284, 50.99993051801409, 51.91005073274885, 39.84133550098964, 4.481582011495318, 2.183476835489273, 3.439626459564481, 0.6996642191495214, 0.04540337349421211, 1.378787717648915, 49.756286348615376, 61.340753827776226, 44.9596391405378, 34.32293374197823, 25.63391089439392, 27.455198764801025, 47.44254664012364, 52.179727690560476, 59.62640394483294, 16.93497817856925, 0.06476278842559882, 0.019474623392203023, 0.02970390859991312, 0.05265706551394292, 0.029883547353425195, 0.055108300410211086, 0.019777704628982713, 0.037309258178408654, 0.037146131574575386, 0.08961114114416496, 0.13674624796424592, 0.11428806877561978, 0.1121852955381785, 0.23823103947298868, 0.3538979728307043, 0.12375735065766744, 0.21360175178519317, 0.13915060966142587, 0.18639765440353326, 0.18152828354920658, 6.288404166698456, 72.89206450326103, 62.807865960257395, 60.676638058253694, 36.638990674700054, 39.6734288079398, 55.66260256086077, 51.59910842350551, 52.210855620247976, 64.62129020690918, 45.5759790965489, 1.6780534705945422, 0.15980697982013226, 2.1364611983299255, 3.1231701033455983, 30.573949813842773, 71.3407541002546, 58.557048388889854, 59.85867527553013, 54.554007053375244, 57.58084385735648, 50.87273679460798, 50.50589970179966, 44.44557319368635, 45.05176877975464, 45.656564303806846, 49.59291682924543, 53.408412388392854, 49.563644068581716, 52.95071717670986, 50.94097852706909, 52.70333003997803, 52.94821235111782, 45.75058037894112, 45.115709577287944, 42.265207631247385, 39.68612664086478, 40.109379632132395, 39.96439504623413, 38.913594654628206, 38.294836725507466, 39.14513989857265, 40.44175713402884, 43.19592578070504, 43.456747259412495, 44.61717980248587, 48.80929204395839, 50.3663763999939, 50.56764834267752, 49.48568875449044, 46.494676862444194, 40.13844742093767, 41.13255051204136, 41.109527656010215, 40.010395595005576, 38.78920800345284, 42.3433644430978, 41.120811530521934, 40.719872679029194, 42.06694425855364, 41.26736293520246, 37.88624095916748, 42.58956343787057, 52.577150753566194, 50.03365843636649, 48.564993381500244, 49.68346575328282, 49.94693449565342, 47.95655700138637, 45.189457757132395, 44.64423261369978, 40.52695941925049, 44.00461619240897, 45.002176012311665, 51.649257046835764, 51.69355181285313, 52.466882841927664, 48.94128697259085, 33.569109780447825, 42.536319392068044, 45.703454221997944, 46.11803586142403, 48.05594055993216, 50.501372950417654, 49.50202744347708, 51.45366178240095, 50.2666072164263, 50.028725215366904, 48.820826053619385, 46.45242486681257, 43.759400367736816, 41.273821285792756, 40.16344356536865, 39.8372152192252, 39.67462737219674, 39.56970262527466, 39.26624352591378, 41.009789739336284, 41.09759065083095, 41.30893400737217, 39.12117208753313, 42.36482742854527, 40.980600357055664, 40.73844173976353, 43.3971004486084, 49.40145921707153, 53.28581837245396, 50.6871782030378, 52.776894092559814, 50.81827333995274, 47.19931105204991, 42.92423037120274, 40.73767743791853, 41.06316580091204, 42.514512470790315, 41.147798333849224, 41.63367543901716, 45.03604500634329, 45.91145202091762, 51.58654955455235, 54.58374881744385, 52.371178354535786, 53.4868540763855, 53.37493944168091, 53.60632835115705, 51.29086201531546, 51.8582102230617, 54.28424324308123, 50.63510840279715, 53.60366719109671, 50.27326359067644, 56.1935248374939, 57.06638533728463, 57.810683318546836, 48.64008951187134, 45.91606215068272, 57.86472640718733, 53.94836732319423, 52.344000475747244, 42.812294891902376, 5.744323304721287, 5.368525207042694, 8.496067898614065, 1.5895670758826392, 0.1646979959415538, 2.051750715289797, 55.757980482918875, 66.95696190425328, 57.19462129047939, 46.49274526323591, 29.93841893332345, 33.887479713984895, 55.049660273960654, 60.06131253923689, 69.3829254422869, 24.573945828846522, 0.2832760752311775, 0.16836540986384663, 0.11583006674689905, 0.1934748153601374, 0.12164218058543545, 0.1298075895756483, 0.12916364627225058, 0.13522198689835413, 0.12322464638522693, 0.15363149690840924], [0.01729069397385631, 0.05794326721557549, 0.029612913661237274, 0.035337859498603005, 0.03191222795950515, 0.00647857941554061, 0.06224146764725447, 0.0406312740274838, 0.01295676697710795, 0.08548316479261432, 6.8576613920075555, 49.83911582401821, 50.95520148958479, 46.57552262714931, 22.990856102534703, 14.526570132800511, 17.94605224473136, 39.93145016261509, 42.99694674355643, 57.07849257332938, 32.19011122839791, 0.5817505206380571, 0.04797867851864014, 0.37828696412699564, 0.5393685176968575, 39.2899820463998, 60.02626582554409, 52.65713494164603, 53.25580562864031, 50.89135101863316, 50.177319390433176, 46.833912236349924, 41.23045063018799, 40.32715354646955, 43.601777008601594, 44.895722661699565, 48.48422752107893, 50.53127799715315, 48.88656643458775, 44.11568314688546, 47.52674491064889, 46.618802956172395, 49.503993783678325, 47.44693095343453, 41.6853700365339, 37.44455092293875, 36.45002746582031, 34.35723352432251, 35.13441732951573, 34.916553088596885, 35.08255597523281, 35.75567313602993, 36.78455196108137, 37.08079535620553, 36.02892146791731, 39.77037007468087, 43.280638217926025, 43.6674861226763, 43.31744629996163, 42.357535294124055, 38.90727874210903, 36.84525837217058, 37.648258209228516, 35.63798802239554, 38.332325731004985, 37.02427176066807, 36.82805463245937, 36.98549733843122, 38.55978890827724, 38.67100524902344, 37.23042828696114, 35.05549621582031, 36.14961862564087, 42.325670855385916, 48.84608622959682, 49.18186140060425, 46.92711884634835, 46.85889795848301, 44.77645683288574, 45.448351110730854, 42.99079758780343, 40.99368381500244, 39.267372608184814, 43.12526260103498, 45.41219615936279, 48.72491659436907, 48.28714186804635, 49.20553738730294, 29.43361840929304, 42.46691036224365, 50.28445019040789, 47.32303067616054, 50.425672326769146, 45.80900083269392, 46.20626756123134, 45.347470215388704, 45.51922968455723, 46.719673429216655, 48.000497409275596, 42.88846799305507, 41.36238649913243, 36.44854749952044, 34.688881465366904, 35.43139375959124, 36.777412687029155, 37.1474528993879, 38.439755303519114, 37.90062720435006, 38.16072607040405, 36.565221650259836, 36.70907020568848, 37.13699238640921, 37.276581696101594, 36.30056824002947, 37.33427258900234, 40.266554832458496, 47.89903286525181, 46.4600122996739, 46.96485103879656, 45.68064328602382, 42.874269349234446, 38.98471294130598, 37.565018790108816, 38.33781133379255, 36.48652287891933, 36.30462598800659, 36.20968232836042, 39.44241510118757, 46.264347553253174, 49.115711075919016, 49.57862785884312, 49.75951031276158, 49.34674562726702, 50.4492301940918, 48.3681891305106, 48.62031146458217, 44.71065739222935, 42.67202465874808, 41.304230076926096, 43.2694342476981, 44.22388744354248, 48.45583023343767, 51.85990905761719, 53.60688073294503, 49.31539535522461, 54.38930000577654, 53.43085159574236, 56.7202365057809, 53.933814321245464, 44.31385966709682, 6.231181842940194, 1.5137780798333031, 3.4947667121887207, 1.3608328125306537, 0.10768903073455606, 0.29706911795905655, 32.81063052586147, 61.0807591847011, 44.14844390324184, 47.216855253492085, 22.688345432281494, 23.4277640410832, 42.869457721710205, 42.72051266261509, 54.42619841439383, 19.936467954090663, 0.17377070124660218, 0.06768791896424123, 0.035509539036346335, 0.043683426321617196, 0.012419814227281936, 0.03623489297128149, 0.042432319705507586, 0.04651449155062437, 0.041123500293386836, 0.03686392207496932, 0.07201651776475565, 0.025773525038467984, 0.04189706414139696, 0.037796354719570706, 0.016406525525131395, 0.010368251724035611, 0.06806236172893218, 0.07058412355503865, 0.0726320915190237, 0.09868446391608034, 11.063217963491168, 61.48570714678083, 55.19831003461565, 53.2434378351484, 25.114967312131608, 17.92532924243382, 26.994166680744716, 43.24474729810442, 45.886115414755686, 61.51874583108084, 34.87318590709141, 0.5392463271106992, 0.0202676187868097, 0.3484090587922505, 1.05490862258843, 41.25663144247872, 62.85333497183663, 56.14695801053728, 54.439056055886404, 54.3303028515407, 53.033438955034526, 48.825998987470356, 44.19607033048357, 41.53055027553013, 45.23134844643729, 47.76590885434832, 49.821147782461985, 52.43989951269967, 50.468883173806326, 46.03727694920131, 48.041005407060894, 47.874519620622905, 49.50894090107509, 48.18326282501221, 43.189894744328086, 39.45006854193551, 38.27283525466919, 35.87079783848354, 37.099420002528596, 37.790856088910786, 37.15465818132673, 38.496403966631206, 37.35376923424857, 39.172359466552734, 38.59258787972586, 41.03535563605172, 46.35028287342617, 45.44397027151925, 46.74282830102103, 43.55752740587507, 40.46757663999285, 37.61635555539812, 37.256598676954, 37.036281721932546, 39.7014856338501, 38.48345252445766, 38.1006623676845, 38.81106703622, 40.30225120271955, 40.09372534070696, 39.73492383956909, 36.98217609950474, 38.416353770664756, 45.67876379830496, 49.28634146281651, 50.938564028058735, 47.958881173815044, 50.59737621034895, 45.49609913144793, 47.264318398066926, 43.77593013218471, 42.95318351473127, 40.859774657658164, 43.86974818365914, 46.46471970421927, 51.183453287397114, 48.95419325147356, 52.277870995657786, 31.138800144195557, 43.98103053229195, 50.94856595993042, 48.638713768550325, 51.40375634602138, 47.39266552243914, 48.21241399220058, 46.54603794642857, 48.64838913508824, 47.826782022203716, 48.99155371529715, 45.359365531376426, 42.09666517802647, 37.28696925299508, 37.18939222608294, 36.760090827941895, 38.332687037331716, 39.15646546227591, 40.4014367376055, 39.77090508597237, 39.81228160858154, 38.93139941351754, 39.085896083286826, 37.58631501879011, 37.390504360198975, 38.06900290080479, 38.813933168138774, 42.61603260040283, 47.914186886378694, 47.18041890008109, 47.66870355606079, 47.856905937194824, 45.919171469552175, 40.62981012889317, 38.30283062798636, 40.74491398675101, 38.8450402532305, 37.93302665437971, 38.297845295497346, 39.98840454646519, 48.2572055544172, 50.48661150251116, 49.931485176086426, 50.27474355697632, 50.475553444453645, 51.892860889434814, 48.56412833077567, 50.5198586327689, 47.90337201527187, 44.40624638966152, 44.28413527352469, 45.94113819939749, 47.37518385478428, 51.603002888815745, 54.11385256903512, 55.51804876327515, 51.609596729278564, 56.90302971431187, 56.518325328826904, 58.344600268772666, 53.69027648653303, 45.099193709237234, 7.090882020337241, 2.3401215842791965, 5.679182205881391, 3.0849141904285977, 0.2054088892681258, 0.2501079264496054, 34.89251579557146, 66.93935516902378, 46.08428151266915, 48.55305985042027, 27.35337117740086, 28.464652163641794, 49.24196679251534, 49.76205335344587, 62.631541524614605, 26.88436950956072, 0.046165897577468834, 0.08977360278367996, 0.08472743963024446, 0.015857960496629988, 0.04567850248089858, 0.031434145756065845, 0.04742793878540397, 0.010718274861574173, 0.017813227006367276, 0.030013327353766987, 0.09222527194236006, 0.13897212781012058, 0.17184599595410482, 0.20884332140641554, 0.10445072235805647, 0.08093835080840758, 0.22459082997270993, 0.12941884329276426, 0.1888482514768839, 0.17176987789571285, 15.335737364632742, 74.03033229282924, 61.130001068115234, 61.50097928728376, 31.876476492200577, 22.157739298684255, 23.20005246571132, 51.847961630140034, 52.87814324242728, 68.41873782021659, 38.77987309864589, 0.9168161068643842, 0.2219454797783068, 1.5450380252940314, 1.683706481541906, 44.713784081595286, 64.18279634203229, 58.05890423910958, 57.11459541320801, 56.16512754985264, 53.69731848580496, 51.395088468279155, 45.38061659676688, 44.882611410958425, 48.80431365966797, 49.167058263506206, 52.21341255732945, 54.234462874276296, 51.872829232897075, 48.09607335499355, 48.77533619744437, 48.67804752077375, 52.11696113858904, 52.380367347172324, 46.7172589302063, 42.01220982415335, 40.34326294490269, 38.16777154377529, 38.38309621810913, 40.168453216552734, 38.639592443193706, 40.575527327401296, 41.3429628099714, 41.404301507132395, 39.34516116550991, 43.18054246902466, 48.769607407706125, 48.156376770564485, 48.105828625815256, 47.171910830906455, 41.6045937538147, 39.196730273110525, 38.18788310459682, 38.292766162327354, 42.49463714872088, 40.88625424248831, 38.907841546194895, 41.692683015550884, 42.64789703914097, 42.25590746743338, 41.679022857121055, 38.03020068577358, 39.040447916303364, 46.33197089603969, 51.431635992867605, 53.3205246244158, 51.761522565569194, 51.79782690320696, 49.758523668561665, 49.830777985709055, 46.77181271144322, 44.69092798233032, 42.97773150035313, 48.29837015696934, 48.83676522118704, 53.710749353681294, 52.51528399331229, 54.10596636363438, 35.283428396497456, 45.47643920353481, 52.772006034851074, 51.661312171391074, 54.33677509852818, 48.7701667376927, 49.52118362699236, 49.49643414361136, 49.996509892599924, 48.964306354522705, 52.85594722202846, 45.77148403440203, 43.86626018796648, 39.27811104910714, 38.2412348474775, 39.40762199674334, 39.652955940791536, 42.03563220160348, 41.05388995579311, 41.07831634793963, 41.79206657409668, 41.15241888591221, 41.80906186785017, 40.336474554879324, 40.05748701095581, 40.19803864615304, 40.969247000558035, 44.407271248953684, 50.58010646275112, 51.57885789871216, 50.202451024736675, 49.774375983646934, 49.43931647709438, 42.4847811290196, 40.64903579439436, 43.52526691981724, 41.33319711685181, 38.945264543805806, 40.459117208208355, 43.346604415348594, 52.48389203207833, 53.69312177385603, 53.131290435791016, 53.19252838407244, 52.134029388427734, 55.74000201906477, 51.37283686229161, 53.32432181494576, 49.452448572431294, 46.905172961098806, 46.90068095070975, 49.04895625795637, 48.413487911224365, 54.92589201245989, 57.07833276476179, 59.141662870134624, 54.07607521329607, 58.986905642918174, 59.076725006103516, 62.22638511657715, 54.895128863198416, 47.84760924748012, 9.431950296674456, 5.675558286053794, 11.367021867207118, 3.5929671227931976, 0.3116325150643076, 0.5141746210200446, 40.80799668175833, 72.3735134942191, 55.38803059714181, 60.800343785967144, 30.457838467189244, 33.54527745928083, 56.83717121396746, 56.43386997495379, 69.33239119393485, 36.02972051075527, 0.5771262773445675, 0.20594428053924016, 0.1704216966671603, 0.12227468378841877, 0.12614078633487225, 0.08599637475396905, 0.15852168521710805, 0.12809663638472557, 0.16304006347698824, 0.13156822510063648], [0.041431891066687446, 0.06605119071900845, 0.048819050924586396, 0.05024386929082019, 0.06641614756413869, 0.06030171923339367, 0.05344227302287306, 0.0596862133326275, 0.09543797919260603, 0.16936049503939493, 14.496955173356191, 51.079522132873535, 45.880626337868826, 44.83066667829241, 31.593875885009766, 30.18651478631156, 26.703884840011597, 30.79361363819667, 47.62140716825213, 54.7571758542742, 30.76888152531215, 0.13580327427812985, 0.07024735305458307, 0.14274170196482114, 1.4912514771733965, 47.87945631572178, 58.81952353886196, 52.51194538388933, 54.6542660849435, 52.13201788493565, 50.71932404381888, 43.91644702638899, 41.860113756997244, 42.95896094185965, 46.02093826021467, 47.7490907396589, 51.0013062613351, 48.03473465783255, 44.34160382407052, 46.19105795451573, 46.851981026785715, 49.18377215521676, 51.14775344303676, 45.78448758806501, 40.78353207451956, 35.17803117207119, 35.00536496298653, 35.288597856249126, 35.77572216306414, 36.697532721928184, 37.027679852076936, 38.13454525811331, 35.6297196660723, 36.86720425742013, 36.41062423161098, 36.767671312604634, 39.75515004566738, 41.17989901133946, 40.81277356828962, 39.09427908488682, 36.41787467684065, 36.0658198765346, 36.2634231703622, 35.903669766017366, 36.151835100991384, 36.82836035319737, 38.04419783183506, 38.160152844020296, 38.16912644250052, 36.824705600738525, 38.753674915858674, 37.116304125104634, 36.043908732278005, 36.275078773498535, 44.23660264696394, 47.66530588694981, 46.56752872467041, 47.16693592071533, 45.00897135053362, 42.964314528873985, 40.768485750470845, 42.84316226414272, 42.33302204949515, 42.642797061375205, 42.742441177368164, 46.14954941613333, 46.659863335745676, 50.99787037713187, 34.955098220280235, 43.959835052490234, 49.336160046713694, 45.63173839024135, 48.435096808842246, 47.47629056658064, 48.14771931512015, 48.0265531539917, 46.68325444630214, 48.75380025591169, 48.395012651171, 44.56879254749843, 39.96639960152762, 34.77214867728097, 34.9095458303179, 34.63802065168108, 36.36301517486572, 37.85374423435756, 38.84620755059378, 37.53911937986101, 38.55403927394322, 38.34252568653652, 37.85720443725586, 36.65890073776245, 36.28398288999285, 37.80464826311384, 37.03641721180507, 38.96887452261788, 41.859658649989534, 44.90006528581892, 44.313706806727815, 42.4695645741054, 43.31127977371216, 38.893761021750315, 37.23079654148647, 36.09278583526611, 35.75928272519793, 36.853026458195274, 36.38269942147391, 37.79398625237601, 46.0575726372855, 50.190128394535606, 47.728680406297954, 50.21841103690011, 51.83359970365252, 48.93899754115513, 47.380700724465505, 42.47091252463204, 39.085201263427734, 40.40929167611258, 41.64022411618914, 46.81214700426374, 47.38379267283848, 49.15779284068516, 47.32686608178275, 49.88906294958932, 54.59265293393816, 51.995489256722585, 54.19309677396502, 56.50613471439907, 55.106232506888254, 50.65065499714443, 9.24801584652492, 1.2415122666529246, 2.7916185685566495, 0.5465714654752186, 0.10860203352889844, 0.04864765976422599, 24.908247981752666, 62.135836192539756, 48.310783113752095, 35.85903453826904, 21.432574919291906, 13.879804015159607, 33.29650068283081, 49.9403406551906, 47.71440880639212, 34.07123177392142, 1.131780126265117, 0.11228081291275364, 0.06386508659592696, 0.05704705137759447, 0.020186296364824687, 0.020736262568139603, 0.048843451043857, 0.020102588892249123, 0.06897085905075073, 0.0337873391274895, 0.03864590431164418, 0.013156447958733355, 0.03727873767326985, 0.022508994676172733, 0.06138631674860205, 0.06932344620249101, 0.049753115445907624, 0.07562522483723504, 0.1187192824270044, 0.09253318434847252, 21.881669998168945, 60.979308537074495, 51.68062121527535, 52.47398737498692, 33.083871909550254, 28.541879653930664, 25.384854452950613, 36.85652835028512, 51.11976262501308, 58.65184266226632, 35.016627992902485, 0.18785453694207327, 0.048387726569282155, 0.9879594721964428, 2.786524019071034, 51.180538518088206, 59.46665791102818, 55.8767842565264, 55.40893425260271, 54.17776557377407, 50.57344314030239, 47.131642545972554, 42.149071965898784, 45.60924012320382, 46.67235272271292, 50.68594142368862, 50.57960966655186, 49.933798926217214, 46.24130732672555, 47.243539810180664, 46.7486161504473, 49.94661487851824, 51.495201587677, 46.905617645808626, 43.01749951498849, 38.711332593645366, 37.36859321594238, 36.70553009850638, 37.06864643096924, 37.407252992902485, 38.75606162207467, 38.934519154684885, 37.88551834651402, 38.708000932421, 37.955094133104595, 37.661317348480225, 40.93500280380249, 44.54855939320156, 41.99685777936663, 41.67928341456822, 38.150668552943635, 36.53937782560076, 38.797042097364155, 36.8563164302281, 38.748317854745046, 37.505531787872314, 39.029240471976145, 40.586425576891216, 39.19154691696167, 39.99864966528756, 39.252607686179026, 39.162788322993684, 37.54511220114571, 39.13696186883109, 44.28478145599365, 50.5499894959586, 48.52395037242344, 49.371620178222656, 45.72935363224575, 44.64975643157959, 45.33993141991751, 44.94958162307739, 43.92975977488926, 46.46224267142159, 46.02444362640381, 47.80657318660191, 48.470873083387104, 53.63641405105591, 37.191268239702495, 46.05469260896955, 50.698114667619976, 46.94379799706595, 50.57747309548514, 48.51048476355416, 49.950905391148154, 49.14384433201381, 46.150265080588206, 48.925674370356965, 49.79495654787336, 46.033358165196006, 42.03883532115391, 37.81462587629046, 35.60459150586809, 36.96453809738159, 38.41304642813546, 39.54494966779436, 40.33399057388306, 39.13642338344029, 40.94608170645577, 39.86470576695034, 39.91833891187395, 37.70709555489676, 38.81215442929949, 37.59667130878994, 38.425716468266074, 40.95617743900844, 43.94416339056832, 46.54309885842459, 46.764746393476216, 45.321626390729634, 44.661773341042654, 41.44442735399519, 39.29969562802996, 38.490803718566895, 38.334007195064, 39.341026987348286, 38.89029387065342, 40.43534047263009, 47.28549303327288, 51.599417618342805, 50.46947724478585, 51.626387051173616, 52.629460266658235, 49.93910387584141, 48.68701764515468, 44.967327322278706, 42.18724536895752, 42.47199296951294, 43.65877308164324, 46.175990785871235, 49.45218106678554, 48.71480696541922, 49.41043628965105, 50.820569719587056, 56.408314500536235, 53.93612459727696, 56.85362107413155, 57.734812464032856, 58.1349071093968, 51.559757300785606, 11.504088112286158, 1.8455210157803126, 4.383981968675341, 3.076699899775641, 0.3259094889674868, 0.03714791612167444, 26.162067787987844, 67.16535227639335, 53.65143953050886, 38.852832657950266, 23.466734749930247, 18.98738397870745, 35.87928853716169, 55.86618825367519, 52.71955060958862, 44.7753381729126, 2.4244942111628394, 0.15433950748826775, 0.044585670943238905, 0.07816518497254167, 0.043526169045695236, 0.04361081289659653, 0.013258918620912092, 0.025636747645746385, 0.08484431728720665, 0.03609204438648053, 0.15837411742125238, 0.09297997930220195, 0.11685610668999807, 0.12248063273727894, 0.12088785320520401, 0.18614810279437474, 0.0967544796211379, 0.16891602746077947, 0.207632679226143, 0.20563644277197973, 26.07525178364345, 69.36406108311245, 58.74407999856131, 63.03165354047503, 41.00663873127529, 38.71506725038801, 34.56535986491612, 42.852111543927876, 56.396634578704834, 64.65492643628801, 37.766405378069194, 0.2703693078032562, 0.08846730073647839, 2.023588363613401, 4.832274530615125, 55.115466662815635, 61.636538641793386, 58.14516959871565, 57.815425464085166, 57.30158185958862, 52.6223383631025, 49.9004545211792, 44.2695266859872, 48.12281002317156, 49.46397910799299, 52.189469064985005, 54.18352563040597, 50.72469847542899, 47.82025766372681, 47.1004764011928, 49.195097718920024, 53.71630791255406, 55.6409068107605, 48.02796016420637, 44.989790848323274, 40.67137425286429, 39.19615009852818, 39.63902827671596, 40.767054421561106, 41.77433477129255, 42.1136292048863, 40.74739101954869, 39.053190912519185, 42.72661318097796, 39.88712065560477, 39.3240316935948, 44.37062644958496, 46.93406357084002, 43.024280956813264, 42.3348320552281, 40.8020281791687, 38.834683963230674, 40.36685902731759, 38.957489899226594, 40.082743712833945, 39.936897550310405, 40.36041109902518, 42.929253918784006, 42.447156633649556, 39.59817634310041, 41.63681255068098, 40.40544237409319, 39.36766290664673, 40.92565747669765, 47.787344047001426, 52.080733231135774, 50.9043094090053, 50.7969388961792, 49.395716530936106, 46.07503693444388, 46.05739893232073, 46.46506711414882, 46.88019071306501, 47.15111139842442, 47.66951649529593, 50.29187434060233, 50.48085144587925, 56.336727210453574, 39.88950736182076, 48.04660912922451, 53.42919792447771, 49.002226148332866, 51.93388652801514, 51.264007227761404, 51.92764357158116, 52.34223563330514, 49.558283533368794, 51.811747619083945, 52.885987758636475, 47.10086897441319, 43.45836271558489, 40.13576194218227, 38.39154870169503, 39.60408926010132, 41.467088903699604, 42.34285375050136, 41.71969066347395, 40.87687764848982, 43.13275623321533, 41.60253708703177, 41.77777412959507, 40.135386739458355, 38.734338079180034, 39.49018396650042, 40.393140588487896, 42.97112028939383, 46.776756354740684, 48.21678440911429, 48.473874705178396, 46.9497560773577, 47.49381044932774, 43.59463426045009, 41.890727519989014, 41.53670290538243, 39.09279217038836, 41.80777645111084, 39.67963702338082, 42.844649178641184, 49.894294943128315, 53.634062085832866, 52.394819600241526, 54.0053460257394, 54.9052871295384, 53.09501389094761, 51.42437512534005, 48.25849444525582, 44.25135367257254, 44.38298382077898, 46.02558313097273, 50.08433859688895, 52.11255945478167, 52.99847214562552, 50.951074259621755, 53.93759414127895, 59.67901570456368, 58.089000361306326, 58.562085832868306, 62.374353953770225, 59.96158504486084, 53.69955580575125, 12.405609062739781, 3.227058700152806, 8.20890840462276, 3.7929217304502214, 0.32859703046934946, 0.11047812178730965, 29.060020719255718, 72.45145838601249, 59.82346180507115, 49.65501288005284, 30.454847267695836, 24.364494119371685, 45.062191077641074, 64.40431880950928, 62.266747202192036, 53.630692209516255, 3.496000668832234, 0.30270929102386746, 0.11847054505986826, 0.18717752184186662, 0.13312909991613456, 0.11003265676221677, 0.17112471322928155, 0.05961778986134699, 0.25376400883708683, 0.19199445550995214], [0.03665753207834704, 0.011006440202306424, 0.10053143623684134, 0.011324813922068902, 0.013469184748828411, 0.008765675842628946, 0.03453132224136165, 0.021420826370428716, 0.08069860403026853, 0.11851583048701286, 18.418892792293004, 53.61258520398821, 44.705474036080496, 40.689258916037424, 24.63333034515381, 19.03818052155631, 40.36315563746861, 34.00577974319458, 46.94766814368111, 57.108418464660645, 27.337913172585623, 0.11809906070785862, 0.041434639133512974, 0.13081338203379086, 4.470467933586665, 43.43312685830252, 60.35380390712193, 52.88209329332624, 54.78155360903059, 50.05226918629238, 48.438233920506065, 41.01785659790039, 43.78124550410679, 46.54676750728062, 50.09988866533552, 48.68804945264544, 51.736828667776926, 46.48190607343401, 47.16573388235909, 47.576455797467915, 48.08438995906285, 49.735660621098106, 48.731531279427664, 45.54995114462716, 34.203296184539795, 34.64403084346226, 33.62771783556257, 33.576426233564106, 35.9537558555603, 34.72451530184065, 35.55769811357771, 36.56273419516427, 36.189831324986045, 35.99519143785749, 35.94373655319214, 35.65161343983242, 34.88753393718174, 37.729618140629356, 37.878587518419536, 35.573380197797505, 35.4328806740897, 35.935836451394216, 35.29386111668178, 35.548665455409456, 36.2662684576852, 36.574480124882285, 37.58292082377842, 37.563792433057515, 37.24811840057373, 37.984165396009175, 36.98700162342617, 39.168183599199565, 36.30994830812727, 37.34815508978707, 37.57901593617031, 46.715660844530376, 45.80821221215384, 46.50079127720424, 43.475430965423584, 42.546533243996755, 44.03397580555507, 46.77976145063128, 44.93002244404384, 43.58685922622681, 42.826743670872276, 46.005138056618826, 45.68323496409825, 50.741634709494456, 38.28690883091518, 43.51417759486607, 49.558033398219514, 46.13189056941441, 44.99379301071167, 46.18468645640782, 47.50630331039429, 48.85915926524571, 50.811752455575125, 48.82242413929531, 46.490233489445274, 41.34192058018276, 34.83329282488142, 34.543233326503206, 34.40591607775007, 35.45320415496826, 35.24917030334473, 37.09215218680245, 37.66946063722883, 38.16381107057844, 38.27746275493077, 38.53339965002877, 37.7512652533395, 36.94811255591256, 36.59129129137312, 36.07102060317993, 38.9309720993042, 36.67314454487392, 37.68079662322998, 41.69074099404471, 40.66181353160313, 42.240947995867046, 42.18683542524065, 40.85574470247541, 37.194707598005024, 35.77392257962908, 36.191630908421104, 37.8190484046936, 36.80755744661604, 39.29829209191458, 44.871883392333984, 48.93531152180263, 45.577261039188926, 51.71291644232613, 48.5052284513201, 46.66188873563494, 42.72699185780117, 40.57480124064854, 39.83123976843697, 38.72481557301113, 41.323264666966026, 43.054811341421946, 46.1893869127546, 48.73740250723702, 46.87023741858346, 48.22508750643049, 48.42738430840628, 52.537028380802695, 52.01847389766148, 54.134440081460134, 58.64766679491316, 57.73106391089303, 17.54074992452349, 1.6408946130956923, 3.1782539018562863, 3.0118174042020525, 0.3049114357147898, 0.037941296584904194, 13.419432009969439, 61.50277887071882, 46.20002807889666, 49.04534666878836, 33.68239321027483, 22.160261494772776, 30.241544519151958, 45.683189800807405, 48.15561941691807, 45.502804143088206, 7.079436165945871, 0.30833589338830536, 0.12335143743881158, 0.10405630352241652, 0.016859071063143865, 0.03817118764189737, 0.04654079496062227, 0.07218530335064445, 0.020170242226283466, 0.08733930412147727, 0.01287209174396204, 0.04428383821089353, 0.06010549369135073, 0.032155435266239304, 0.03816362536911454, 0.052132310279245885, 0.12354939324515206, 0.02583551430143416, 0.048924335810754976, 0.13867444092673914, 23.20176693371364, 59.02428000313895, 50.95498956952776, 46.12946564810616, 28.889096770967754, 21.64118242263794, 35.649716581617085, 35.75512075424194, 51.1239732333592, 61.45104258401053, 29.48123094013759, 0.05888069048523903, 0.1718402284064463, 2.056908232825143, 6.057159432343074, 48.091025488717214, 61.11091436658587, 56.213820525578086, 56.084472860608784, 51.41914313180106, 49.84449372972761, 43.34404400416783, 45.95724412373134, 49.06795610700335, 52.17012875420706, 50.68060868127005, 52.80996404375349, 48.73295913423811, 47.645295075007844, 48.523866994040354, 48.85106461388724, 51.694903237479075, 50.17684343882969, 48.01332378387451, 37.354481424604145, 37.63287489754813, 36.15178993770054, 35.73252868652344, 36.82598059517996, 36.14923300061907, 37.62172998700823, 38.74017456599644, 38.02584763935634, 38.772490637642996, 37.87796218054635, 37.35572167805263, 37.1326184953962, 39.56117371150425, 39.858365535736084, 38.089680739811485, 37.28490216391427, 36.857032094682964, 36.92163297108242, 37.256852286202566, 38.2367011478969, 37.658239296504426, 39.52585254396711, 39.857851369040354, 38.952587945120676, 39.81604405811855, 39.13236563546317, 41.01999316896711, 38.87095355987549, 40.66865055901663, 39.13488435745239, 46.9960241317749, 47.51260532651629, 48.724322523389546, 44.09823274612427, 44.734791960035054, 45.77599341528756, 48.143831798008506, 44.77739831379482, 46.427373136792866, 45.03070878982544, 47.93336044039045, 47.66534062794277, 51.257534980773926, 41.140794549669536, 45.724865095955984, 50.53847633089338, 47.488533292497905, 46.79788930075509, 47.91254016331264, 49.73659862790789, 50.09850249971662, 52.17960957118443, 50.89946304048811, 46.96806458064488, 44.98278359004429, 37.50798797607422, 36.068595681871685, 35.62253870282854, 37.775952202933176, 37.36777680260794, 39.188652992248535, 39.96775450025286, 39.90176051003592, 40.972453594207764, 41.1314492225647, 38.984528814043315, 38.218747002737864, 38.54949515206473, 38.553118637629915, 40.630973952157156, 39.617985657283235, 39.10204022271292, 42.87702430997576, 42.52788775307791, 44.31584685189383, 43.97167478288923, 42.83515446526663, 39.99297646113804, 36.22212307793753, 38.166962078639436, 39.49790688923427, 39.4685959134783, 40.44541883468628, 47.887846265520366, 52.13532175336565, 47.647664410727366, 54.14856229509626, 51.284931727818076, 49.742615767887656, 45.20764119284493, 42.39810235159737, 41.913382121494834, 40.66497496196202, 42.996345724378315, 45.339907101222444, 49.731005328042166, 48.44370910099575, 48.034095423562185, 51.80037341799055, 50.64765337535313, 56.21737800325666, 54.17383984157017, 56.703001499176025, 59.76847376142229, 61.261328969682964, 18.878726312092372, 1.1562640581812178, 5.632460347243717, 5.995227532727378, 0.3207036868802139, 0.10619324099804674, 13.842088324683052, 67.60692419324602, 50.97143595559256, 49.788140365055625, 30.148164204188756, 24.2016578742436, 36.20267507008144, 52.656676360539024, 55.969170979091096, 54.822436809539795, 8.653481074741908, 0.26280364234532627, 0.08205398451536894, 0.057934921234846115, 0.05198044396404709, 0.05148675884785397, 0.004885614558588713, 0.027447313170081804, 0.060944427603057454, 0.034288155646728616, 0.13781386853328773, 0.2623293735086918, 0.14137472531625203, 0.15250028403741972, 0.16449986371610845, 0.13231008100722516, 0.15467897855809756, 0.08627926957394395, 0.30370315483638216, 0.1868731038911002, 29.169830049787247, 71.03483881269182, 55.00501809801374, 55.906710147857666, 35.43406534194946, 26.907991647720337, 50.687987668173655, 46.66609934398106, 56.68931354795183, 68.5413179397583, 32.071477685655864, 0.23380633975778306, 0.12227081613881247, 1.069050812295505, 8.64513281413487, 49.679185662950786, 63.062899589538574, 58.436740330287385, 57.24789660317557, 53.75938674381801, 51.63161904471261, 46.4650045803615, 48.535015378679546, 52.83883033479963, 54.85066386631557, 53.05193853378296, 53.981246198926655, 49.06409290858677, 48.457202502659385, 50.1129651750837, 49.97417490822928, 53.427888189043315, 53.02126223700387, 48.313148975372314, 38.55547060285296, 38.333527769361226, 38.523706912994385, 37.53456483568464, 40.643974031720845, 37.89941474369594, 39.772246088300435, 41.7603098324367, 39.45378582818167, 41.42506619862148, 39.159324645996094, 40.02089432307652, 38.556908879961284, 42.51556164877755, 41.40918609074184, 39.24131686346871, 39.53508669989449, 40.25207478659493, 38.027744497571675, 39.99828488486153, 39.79080820083618, 40.30510343824114, 40.03417580468314, 41.634106227329795, 39.89755684988839, 41.43832336153303, 40.31723499298096, 42.40616226196289, 39.563508306230815, 41.66263900484358, 41.40010826928275, 49.34886482783726, 49.157292570386616, 51.89438601902553, 47.271245752062114, 46.770447390420095, 47.943480491638184, 50.94103063855852, 48.28205926077706, 46.79472439629691, 48.16168172018868, 49.96207462038313, 49.37460790361677, 52.43767261505127, 43.59144851139614, 48.59087194715227, 54.06042439596993, 50.81600475311279, 49.91623388017927, 51.08327068601336, 52.967497076307026, 54.0863481249128, 53.65434735161917, 53.958202498299734, 49.693523270743235, 46.70313324247088, 38.91624886648995, 38.55714511871338, 37.57913058144705, 40.61021620886666, 39.23219387871878, 41.54383175713675, 41.315976006644114, 41.978306089128765, 41.37497663497925, 43.116021496909006, 42.19818878173828, 41.40116092136928, 40.04267692565918, 40.525378704071045, 42.32874195916312, 39.82948882239205, 40.06582484926496, 46.84973675864083, 44.073222705296104, 46.548316955566406, 46.14356006894793, 45.87083980015346, 41.80773823601859, 39.12851285934448, 39.625479289463584, 41.373239585331504, 40.915808405194966, 41.771840367998394, 50.529388087136404, 53.31067555291312, 49.724442754473, 55.83025564466204, 52.84581674848284, 51.25518996374947, 48.16283164705549, 44.69395739691598, 45.05450289590018, 43.97921010426113, 44.08454826899937, 47.570296219417024, 51.67750494820731, 52.09791612625122, 51.1778495652335, 53.54338462012154, 53.44201735087803, 59.536431721278596, 57.0765575000218, 58.991873604910715, 62.801091466631206, 63.55784061976841, 22.034488677978516, 4.1636102965899875, 11.31812652519771, 12.088008642196655, 0.6437965227024895, 0.1401471197605133, 16.315026896340505, 72.51665333339146, 56.22744594301496, 61.71357331957136, 42.46101481573922, 32.006032603127615, 42.14073065349034, 62.24438789912632, 61.87422261919294, 61.969023840767996, 11.5715959412711, 0.4590352369206292, 0.1795378824962037, 0.22477459082646029, 0.15233892840998514, 0.11577023352895464, 0.09750792490584509, 0.1014196996444038, 0.2143290870423828, 0.20458157866128854], [0.0414536550774106, 0.024318801937624812, 0.04195710431252207, 0.008975668012031486, 0.012496057814652366, 0.04273440010313477, 0.06404398913894381, 0.04739969815792782, 0.02616980645273413, 0.059140141920319626, 16.31386481012617, 54.36954280308315, 47.17545788628714, 38.14916774204799, 22.09412854058402, 20.87855683054243, 32.836085251399446, 37.098707812173025, 51.73167657852173, 54.62671300343105, 22.337643793651036, 0.11709022841283254, 0.27528678679040497, 0.14190770100269998, 3.907197884150914, 50.201200348990305, 55.929493291037424, 56.051184041159495, 54.563765798296245, 52.26960958753313, 47.74003723689488, 45.0899977684021, 48.061648505074636, 48.00315856933594, 49.44681705747332, 50.19361639022827, 49.547041348048616, 46.800546986716135, 50.09826973506382, 48.375540324619834, 48.87483092716762, 48.09045573643276, 46.73832239423479, 40.92058181762695, 35.91825403485979, 34.52853441238403, 34.65189273016793, 33.70252561569214, 35.134382588522776, 35.1978509085519, 33.807224546160015, 34.400729247501914, 35.726275307791575, 35.90940202985491, 36.33539261136736, 35.595572744097026, 35.125857148851665, 34.514360087258474, 36.521072796412874, 34.33367565699986, 37.98486368996756, 35.23678513935634, 36.920566422598704, 36.92166076387678, 36.05931288855416, 35.13417066846575, 36.972198486328125, 38.49544164112636, 37.43361793245588, 37.86289848600115, 37.010357992989675, 38.329984188079834, 39.131559644426616, 37.714825425829204, 36.45422765186855, 40.290282930646626, 43.91177783693586, 40.539090973990305, 40.63990586144583, 46.18781661987305, 47.67038154602051, 45.39514875411987, 46.83792134693691, 47.73462111609322, 42.47408437728882, 43.044288294655935, 42.43037673405239, 50.25251974378313, 42.59336757659912, 46.930905614580425, 47.50151252746582, 43.45145968028477, 40.58601563317435, 40.15201377868652, 42.01049361910139, 42.815775939396445, 44.250867298671174, 42.46466261999947, 38.41703816822597, 35.83248199735369, 35.59881755283901, 35.33791616984776, 34.747444357190815, 34.274966853005544, 36.506523268563406, 37.025869846343994, 37.953954628535676, 37.932724407741, 39.40326200212751, 38.19634253638131, 38.56257166181292, 38.73223624910627, 36.3714850289481, 35.46761819294521, 35.878725733075825, 36.9916603905814, 36.642697538648335, 39.39454548699515, 39.52744368144444, 42.76394932610648, 39.84621313640049, 38.8833908353533, 36.20418282917568, 36.08762332371303, 35.511405740465435, 35.16954394749233, 37.478673526218955, 37.362009797777446, 43.064389433179585, 49.59817314147949, 49.76104933874947, 50.32653195517403, 45.18187379837036, 42.61664056777954, 37.708540780203684, 37.25274590083531, 36.619653838021414, 40.62894855226789, 45.374133927481516, 46.48650925500052, 45.02723816462925, 46.218770844595774, 46.83614608219692, 48.09859902518136, 48.90840114865984, 49.675496169498985, 50.75225155694144, 52.68516744886126, 54.35977363586426, 64.58452033996582, 28.57171869277954, 1.0071845948696136, 3.1870001639638628, 3.3924273465360915, 0.22477582576019423, 0.05180016738761749, 6.6668412770543775, 58.80395957401821, 53.3298282623291, 42.24041645867484, 35.47856855392456, 19.91799964223589, 29.967083726610454, 46.04411745071411, 53.473937375204905, 54.95245844977242, 9.912190675735474, 0.3922790618879454, 0.07496661839208432, 0.033282322476484945, 0.04243272343384368, 0.009619911567174962, 0.008599892774197673, 0.05404243724686759, 0.044343203239675076, 0.01814757683314383, 0.025500721730557934, 0.02335821687509971, 0.054727163897561174, 0.008530374317030822, 0.08578809164464474, 0.05073633982932993, 0.05494962499610015, 0.05007306506325092, 0.08580637816339731, 0.11674071502472673, 22.529909133911133, 63.70029258728027, 50.51325784410749, 44.67532927649361, 26.47728497641427, 21.53135745865958, 35.33036000388009, 41.59818751471383, 54.58714301245553, 59.6013001033238, 24.98229146003723, 0.11919636039861611, 0.8674453560795102, 1.5609547197818756, 7.1921029431479315, 52.80791779926845, 56.53755446842739, 57.24179955891201, 56.755446502140586, 54.10547651563372, 50.780325753348215, 47.16882930483137, 48.83865513120379, 49.2151780128479, 52.82951627458845, 52.14005695070539, 50.98217439651489, 47.40501594543457, 48.92086969103132, 49.94047614506313, 51.43520041874477, 49.476148877825054, 49.89333956582205, 42.85942104884556, 37.426134722573416, 37.15440457207816, 36.72877529689244, 36.12180151258196, 37.01969984599522, 37.56978872844151, 35.63418388366699, 36.874440806252615, 37.17773314884731, 38.6933263369969, 37.091745717184885, 36.57902772086007, 35.51159681592669, 36.06388827732631, 37.926623889378135, 36.08784219196865, 39.80650765555245, 37.20587682723999, 37.56287179674421, 38.87366335732596, 38.24362850189209, 37.643814836229595, 37.364281858716694, 38.28003011431013, 38.40927355630057, 39.16296202795846, 39.12855107443673, 39.45733635766165, 40.34975951058524, 38.33199221747262, 37.11192328589303, 44.07223606109619, 45.9223051071167, 43.17799595424107, 44.171032496861045, 45.4268707547869, 50.193414892469136, 47.165250982557026, 47.48397527422224, 48.84224387577602, 44.775789805821006, 44.18612745829991, 45.370281151362825, 51.07419981275286, 44.84403848648071, 47.9721348626273, 50.07234600612095, 45.36501094273159, 43.09169932774135, 42.61615766797747, 43.50141722815377, 46.565920216696604, 45.73611075537545, 44.09756571905953, 39.89187669754028, 38.64283030373709, 36.806035791124614, 37.438568523951936, 36.9719865662711, 36.95122882298061, 38.39973715373448, 38.944191047123496, 37.67958763667515, 39.78701795850481, 40.27224888120379, 38.91803455352783, 39.9455862726484, 40.20829766137259, 37.98057317733765, 37.23289837156023, 38.07349143709455, 39.47988326208932, 38.639540331704275, 40.42477921077183, 40.30073996952602, 42.56719718660627, 42.992795194898335, 42.06676707948957, 37.715485504695344, 38.420383725847515, 38.42888137272426, 37.197108200618196, 38.873138768332346, 39.75630692073277, 43.7855429649353, 50.821434770311626, 51.57325765064785, 50.68337059020996, 48.58757502692086, 44.547294821058, 40.0863949911935, 39.98326635360718, 38.41857024601528, 43.1134089742388, 47.10674715042114, 48.61865431921822, 47.30777243205479, 48.470417976379395, 50.47370522362845, 50.57187284742083, 49.734288351876394, 52.50810997826712, 53.19910485403878, 56.9599597794669, 57.17075770241873, 64.58825847080776, 29.77425037111555, 0.2582802836384092, 2.6249493062496185, 5.042664681162153, 0.7655454639877591, 0.08706104369567973, 7.139958884034838, 64.18359538487026, 57.4155809538705, 49.61768020902361, 37.56459494999477, 27.073690550667898, 34.05381958825247, 51.30876752308437, 59.378075327192036, 62.236286299569265, 13.292018549782888, 0.20032428710588387, 0.03537211533901947, 0.028791153470852544, 0.1059024887425559, 0.04406814889184066, 0.03976809945223587, 0.03528623655438423, 0.02514808368869126, 0.025142221146130135, 0.09810923585402113, 0.11660143892679896, 0.12909393358443463, 0.05016699805855751, 0.18950793679271424, 0.20075128919311933, 0.12037671277565615, 0.09761026834270783, 0.15718262349920614, 0.16515631920525006, 28.624795981815883, 73.3154182434082, 58.84591279711042, 53.08938237598964, 32.82545798165457, 30.103831223079137, 42.70455265045166, 50.05603163582938, 59.752353940691265, 64.4402687890189, 27.74315643310547, 0.21353454967694624, 0.7859956409249986, 0.8143206238746643, 7.2850919876779825, 59.045458112444194, 56.17302417755127, 60.82248074667794, 58.61086218697684, 57.77593190329415, 51.134430272238596, 48.94737359455654, 50.91656255722046, 53.13239867346627, 55.116383825029644, 53.11390604291643, 52.54253830228533, 49.7564947945731, 50.87619352340698, 51.88993917192732, 52.66257538114275, 51.33491359438215, 51.09852545601981, 45.84244251251221, 38.47559758595058, 39.52926410947527, 38.269357681274414, 37.62077113560268, 38.44263533183506, 40.025264739990234, 37.36013725825718, 39.15368618283953, 39.68961811065674, 39.65927185331072, 41.11793845040457, 39.56730897086007, 39.45654773712158, 38.69555670874459, 41.000357559749055, 37.466403007507324, 42.8409423146929, 38.89601223809378, 38.84539808545794, 41.353079387119834, 39.46909965787615, 38.00740017209734, 39.03840862001692, 41.33033445903233, 40.25896739959717, 41.478914737701416, 41.345981802259175, 40.886469636644634, 42.7441782270159, 41.17574051448277, 40.47070680345808, 46.2850010735648, 47.98647941861834, 43.586609091077534, 44.40440511703491, 50.1876722063337, 51.36933844430106, 49.65017345973423, 49.900339875902446, 51.1151351247515, 44.84392384120396, 45.771463189806255, 47.232401847839355, 54.115016392299104, 47.167985098702566, 50.50311000006539, 52.457457610539024, 47.44249452863421, 45.727300439562114, 44.19726889474051, 47.00082186290196, 47.45076288495745, 47.7080477305821, 45.76121807098389, 40.531989915030344, 40.69152750287737, 38.82943112509591, 39.47350828988211, 39.186679703848704, 38.83162328175136, 40.88571923119681, 41.09046527317592, 39.55751201084682, 42.24166713442121, 43.12369578225272, 42.04149995531355, 42.78190347126552, 41.139019284929546, 40.13126993179321, 40.5927414894104, 39.12485810688564, 40.47218329565865, 39.29614857264927, 43.36191824504307, 42.084585734776084, 45.728905473436626, 44.14312505722046, 43.118060793195454, 39.82999604088919, 40.06627648217337, 39.767715862819124, 39.355937821524485, 40.86109134129116, 41.16268832342965, 46.780702931540354, 54.52237885338919, 53.333552496773855, 54.58043105261666, 51.10202734810965, 47.55343294143677, 42.46185902186802, 41.96767881938389, 41.4607868875776, 45.71615552902222, 51.212309156145366, 51.21206944329398, 49.1174898147583, 50.940099579947336, 53.09591368266514, 52.168714795793804, 52.6337125641959, 55.150197233472554, 55.79773807525635, 60.39844608306885, 60.87038162776402, 65.53669452667236, 32.3009523664202, 2.8852405505520955, 9.617084179605756, 10.419249364307948, 0.982633460845266, 0.1352044671241726, 8.597565446581159, 70.43372235979352, 63.039908000401084, 56.381765433720176, 47.760829721178325, 29.441028663090297, 39.66152654375349, 61.83448587145124, 66.2967232295445, 72.3032672064645, 17.912957974842616, 0.388975519154753, 0.1520993241242, 0.17555058002471924, 0.15857451595366, 0.13314078428915568, 0.0986673105508089, 0.09191295584397656, 0.10564196522214583, 0.13748530830655778], [0.0573428315775735, 0.0091769503363009, 0.026087454353858317, 0.048015841881611517, 0.04238263058609196, 0.05418056322793875, 0.04563955796350326, 0.022976539230772426, 0.04928889571289931, 0.09986244142055511, 19.536503587450298, 56.22784546443394, 41.63101427895682, 43.925722871507915, 20.100615671702794, 23.531495434897288, 33.81898784637451, 34.96290799549648, 54.52382755279541, 52.99338606425694, 18.315036330904277, 0.8591823737536157, 6.488110159124647, 30.69388266972133, 1.3276909909078052, 39.59727307728359, 56.3939699445452, 52.199099268232075, 53.444181714739116, 53.54620211465018, 49.136076245989116, 50.372883387974326, 50.83507061004639, 51.18257086617606, 49.577509198869976, 49.495711530957905, 45.91580854143415, 49.25031157902309, 50.68721294403076, 48.77123328617641, 50.946623938424246, 47.75037963049752, 44.92737170628139, 37.659326689583914, 34.58293880735125, 34.515228612082346, 34.031380380902974, 34.225394930158345, 35.16651453290667, 33.4658282824925, 35.19033990587507, 36.980591910226, 38.134969098227366, 37.82609387806484, 36.80699464253017, 34.31475223813738, 34.75494493756975, 34.93515689032418, 33.98831197193691, 35.595207963671, 35.245411327907014, 34.86515031542097, 36.17544507980347, 35.433929852076936, 37.82314089366368, 35.497043813977925, 37.466764313834055, 37.2934901373727, 38.88023287909371, 37.382340226854595, 37.43202679497855, 37.75328370503017, 37.84626797267369, 36.4328202520098, 36.388528960091726, 37.98819187709263, 41.736383710588726, 41.085320132119314, 43.08265972137451, 46.2023800441197, 46.48926421574184, 46.49548632758004, 47.10398524148123, 46.780084541865754, 47.21678924560547, 44.449262687138145, 45.164784703935894, 48.612543378557476, 43.86343574523926, 46.623030935014995, 48.91699259621756, 43.54734829493931, 40.75223043986729, 37.01135505948748, 37.10999863488333, 36.35263456617083, 36.55320474079677, 35.014164856501985, 35.286409173692974, 35.71560287475586, 35.681365626198904, 34.46540307998657, 34.04413727351597, 35.366056374141145, 37.20598799841744, 36.208431652614046, 36.21765538624355, 35.46823310852051, 37.78943518229893, 36.431156158447266, 36.12445225034441, 36.39183630262102, 34.491233008248464, 36.711759158543174, 36.35919713973999, 36.24908556256975, 36.99982104982649, 36.593618937901084, 38.544457708086284, 39.20703445162092, 38.237097195216585, 38.5556686265128, 37.60912595476423, 35.89911869594029, 37.01178584780012, 36.62374980109078, 36.78761264256069, 36.90423468181065, 37.88441358293806, 43.98922593252999, 45.86539241245815, 45.466204507010325, 40.26466839654105, 36.18730912889753, 37.605384349823, 37.38040862764631, 39.50405951908657, 44.0938275882176, 45.09548684528896, 46.10817289352417, 44.54625953946795, 45.986853872026714, 47.69057648522513, 47.378692695072715, 46.78888096128191, 51.77602693012783, 49.8968379838126, 54.83028827394758, 53.682640416281565, 61.47114372253418, 41.61599922180176, 0.8597366011568478, 3.452996096440724, 5.061229399272373, 0.3545692610953535, 0.017195061248328005, 2.473300963640213, 50.20021023069109, 56.81452356066023, 48.11507320404053, 33.98829460144043, 14.881392921720233, 18.120762961251394, 42.094611985342844, 50.98048945835659, 54.522562980651855, 18.106527839388164, 0.24875300058296748, 0.033131874299475124, 0.053106737456151416, 0.017218547041660974, 0.04237223542960627, 0.03208966147420662, 0.01942897155614836, 0.036289046851119826, 0.037439713321094, 0.03992971631565264, 0.0045578274376956475, 0.12084980096135821, 0.06985774503222533, 0.054375390987843275, 0.07625090197793075, 0.016997872186558585, 0.0297929290016847, 0.04342316742986441, 0.09327974250274045, 26.325009993144445, 66.65594509669712, 48.18521179471697, 51.51784576688494, 26.202523674283707, 22.824802841459, 33.13238423211234, 44.04053143092564, 57.92752422605242, 60.329790932791575, 18.892296143940516, 0.7791041135787964, 3.6951141101973395, 21.796738692692347, 2.9646977611950467, 39.51354728426252, 58.04198884963989, 51.31249523162842, 56.90798030580793, 54.96151890073504, 51.97435631070818, 52.53296715872628, 52.970693247658865, 51.856751101357595, 51.070826462336946, 49.43028729302542, 47.49052742549351, 49.10756083897182, 51.647540841783794, 49.89817551204136, 52.751039845602854, 49.350146770477295, 48.50318220683506, 39.26511096954346, 36.23334789276123, 35.419592244284495, 36.99148668561663, 37.07116862705776, 37.454518113817485, 35.015648296901155, 36.883539472307476, 39.35826894215175, 40.23672274180821, 39.4297832761492, 38.619689328329905, 36.35945074898856, 38.14805603027344, 37.015701157706125, 36.703904220036094, 37.642185483660015, 37.35074329376221, 35.54695619855608, 37.92852074759347, 36.366781098502024, 37.50742517198835, 37.044393743787495, 37.673365524836946, 38.77997384752546, 39.82008443559919, 38.464727129255024, 38.81800481251308, 39.07901736668178, 38.55669348580496, 38.7375168800354, 37.80125059400286, 39.58275481632778, 45.533629826136995, 44.30578933443342, 45.02294070380074, 47.57678583690098, 49.02831663404192, 48.177367278507774, 48.38972854614258, 47.12820666176932, 48.47073064531599, 46.65753221511841, 45.89884451457432, 51.335969720567974, 45.320948941367014, 49.33686876296997, 51.11897053037371, 45.59522908074515, 42.13143048967634, 39.4728273664202, 38.60373279026577, 38.36524282182966, 39.40808057785034, 36.9967360496521, 38.831418309892925, 37.49760389328003, 37.31556803839547, 36.392548492976594, 36.094484669821604, 36.39977809361049, 36.96127244404384, 37.882256167275564, 38.432091440473286, 37.82548243658883, 39.944828919001985, 37.70189830235073, 37.11592197418213, 38.79901191166469, 36.069651808057515, 38.630792549678254, 38.429423332214355, 38.006604603358674, 39.52696772984096, 37.03468711035592, 40.49557440621512, 41.31617055620466, 41.153853688921245, 40.436830861227854, 39.64247805731637, 37.61424330302647, 38.60014057159424, 38.90611144474575, 37.95134905406407, 38.00486060551235, 39.8366003036499, 46.52489457811628, 48.92231144223894, 47.82662568773542, 42.771151133946006, 37.9131304877145, 39.972364630017964, 39.944349493299214, 40.895071506500244, 45.92425060272217, 47.10125459943499, 47.219797815595356, 47.38164567947388, 48.79137263979231, 48.6388110433306, 49.45379304885864, 48.322084358760286, 52.77411481312343, 52.644054957798545, 57.37741102491106, 56.94786991391863, 60.74952466147286, 43.35366725921631, 1.3290970240320479, 2.093989683049066, 7.605416536331177, 1.2662866115570068, 0.05897909163364342, 2.649786510637828, 53.726653780256, 62.03778321402413, 52.17867851257324, 37.09339244025094, 18.49510931968689, 24.057163136346, 47.64922775541033, 56.78072057451521, 62.418843269348145, 23.90070186342512, 0.19354538300207683, 0.03406346895332847, 0.007651862305855113, 0.03701786810000028, 0.02241009650086718, 0.10774381565196173, 0.01744681639995958, 0.02242212523041027, 0.029116181922810416, 0.1400115756051881, 0.07060405212853636, 0.20656068889158113, 0.23712904431990214, 0.09279074945620128, 0.1098613538114088, 0.19325636779623373, 0.13145367481878825, 0.1637819872370788, 0.16210401084806236, 32.578991481236045, 72.92221968514579, 55.03140040806362, 56.513437271118164, 31.54339722224644, 34.785534381866455, 43.53251041684832, 48.14847666876656, 62.779017039707725, 63.653996740068706, 22.184132031032018, 1.168819127338273, 8.916385275976998, 37.46704224177769, 2.2713331154414584, 44.662245818546836, 57.39224542890276, 52.84905113492693, 57.96003137316023, 57.838896478925435, 53.46929945264544, 55.79328427995954, 53.80649553026472, 54.96520839418684, 52.4680848802839, 52.43416377476284, 48.48665591648647, 50.63539327893938, 52.279420443943565, 51.483660629817415, 54.01067876815796, 52.58481461661202, 51.44537605558123, 41.381699017116, 38.41574232918875, 38.064496994018555, 39.11233745302473, 39.754813058035715, 40.10606186730521, 37.47524111611502, 39.347686835697715, 41.41760383333479, 43.0388582774571, 41.77832998548235, 41.36820214135306, 38.624688557216096, 39.168405941554475, 39.628623349326, 37.699622767312185, 40.27186673028128, 39.148975304194856, 39.08428062711443, 40.76465381894793, 38.25090673991612, 40.9774945122855, 38.71854829788208, 41.50289991923741, 41.40601076398577, 41.533211435590474, 40.384538718632285, 40.55510309764317, 42.085489000592915, 39.88991035733904, 40.31994826453072, 39.08328356061663, 41.194646562848774, 46.68315717152187, 45.12380075454712, 46.85887711388724, 50.436125891549246, 51.048230920519146, 50.24537352153233, 51.25452641078404, 48.03899390356881, 51.191120624542236, 47.300608839307515, 48.54202263695853, 53.476817403520855, 47.99207966668265, 50.583240100315635, 52.837006432669504, 47.21710886274065, 44.47386278424944, 40.61322130475725, 41.627592291150776, 39.6642050743103, 40.268500328063965, 39.57598032270159, 38.90800135476248, 40.0617983681815, 38.64001280920846, 38.600925718035015, 38.45348146983555, 39.20699971062796, 39.731831891196116, 39.618381704602925, 40.22621706553868, 38.12922988619123, 41.53120688029698, 39.51827900750296, 39.7500570161002, 39.868732248033794, 37.590615953717915, 40.734363147190635, 39.39264862877982, 39.833216530936106, 40.99939176014492, 38.61000006539481, 42.03103944233486, 43.29737990243094, 42.02202068056379, 42.015590122767854, 42.87958819525582, 39.40614897864205, 39.8132335117885, 42.47785724912371, 41.75328867776053, 39.93308646338326, 41.407480307987754, 47.4278164591108, 52.2549593108041, 50.36493812288557, 44.24519062042236, 39.361802101135254, 41.60824850627354, 41.916060652051655, 43.514174120766775, 48.74409709657942, 50.180310589926584, 49.88880239214216, 50.077956676483154, 49.89150176729475, 52.07691519601004, 52.59564338411604, 51.765517779758994, 55.983314037323, 56.81339447838919, 58.75616291591099, 60.14221041543143, 63.02420507158552, 44.70343821389334, 2.088369241782597, 12.291936533791677, 12.540909596851893, 1.4993325578314918, 0.12262978830507823, 3.2897127781595503, 59.154732431684224, 66.25509657178605, 61.80347606113979, 45.355165345328196, 24.61592858178275, 29.336677142551967, 55.93602112361363, 65.1486098425729, 69.7015837260655, 30.13789129257202, 0.40204486357314245, 0.14551321896059172, 0.0881611118093133, 0.10900681359427315, 0.13556098299367086, 0.2052223328500986, 0.1410711623196091, 0.10857488534280232, 0.12535200294639381], [0.07993893657944032, 0.07124993604208742, 0.036901156684117656, 0.06768480448850564, 0.03352875621723277, 0.04619230276771954, 0.02364152729777353, 0.019077551484640156, 0.044369652534701993, 0.14024055403258118, 24.27746966906956, 53.603764465876985, 49.35766472135271, 46.561796460832866, 23.412684713091167, 30.694289139338903, 30.126565728868755, 42.148043632507324, 52.51914024353027, 54.07823610305786, 11.07298105103629, 0.3582601116171905, 5.814621269702911, 20.27556436402457, 0.9409671766417367, 8.40324170248849, 57.57905469621931, 52.295894622802734, 53.7990540095738, 50.29969106401716, 53.39413036618914, 50.14285632542202, 53.878961767469136, 49.315767083849224, 50.96230602264404, 44.84308310917446, 46.26307603291103, 48.650890486580984, 47.96609340395246, 49.48832212175642, 48.34873764855521, 46.747921330588206, 43.00140053885323, 36.19306571143014, 35.32853957584926, 33.59309843608311, 34.58859116690499, 34.78699697766985, 36.677897112710134, 34.35661860874721, 36.08035203388759, 35.79055656705584, 38.581203256334575, 37.50256838117327, 37.15951497214181, 35.046442713056294, 35.73559979030064, 36.64865561894008, 35.53239277430943, 35.33955594471523, 34.4866680417742, 34.83679471697126, 36.65711505072457, 34.10171352113996, 35.19058656692505, 35.79094566617693, 35.84286955424717, 36.96174144744873, 37.864969049181255, 36.05444914954049, 38.99095242364066, 38.005267075129915, 38.32544354030064, 36.06276614325387, 36.82674142292568, 34.944012369428364, 38.598087378910606, 41.086796624319895, 40.920019013541086, 42.81407363074166, 45.4866669518607, 44.38735771179199, 47.09692587171282, 48.27061210359846, 44.964356967381065, 45.33860778808594, 45.06599521636963, 49.316652979169575, 46.61597503934588, 47.11675950459072, 47.27163485118321, 42.900429316929404, 45.16183519363403, 41.72924443653652, 37.3741135597229, 36.55858959470476, 38.48058639253889, 36.1881776537214, 35.72236694608416, 35.4267315183367, 35.706354822431294, 33.67658451625279, 35.99083144324166, 36.347180230276926, 36.91079725537981, 35.92360414777483, 35.04590422766549, 35.57865040642874, 37.30913748059954, 37.89112901687622, 37.66273478099278, 34.6428496497018, 37.210014479500906, 36.19743612834385, 36.6387231690543, 36.34699610301426, 36.70169121878487, 35.54138026918684, 36.62389918736049, 36.51503481183733, 37.36605364935738, 38.06083876746041, 36.24240834372384, 34.99822221483503, 35.803733825683594, 36.25909096854073, 36.77515452248709, 34.3021308353969, 36.75079066412789, 35.962486267089844, 37.989609309605186, 36.80001170294625, 36.734003816332134, 35.222207818712505, 38.85198845182146, 36.80810635430472, 42.51088203702654, 47.81145429611206, 47.71600341796875, 45.367262159075054, 46.187378883361816, 46.4042877469744, 47.26727138246809, 50.72678293500628, 48.39813239233834, 51.87023755482265, 54.90356050218855, 56.209971223558696, 45.34023366655622, 41.05407408305577, 50.321793283735005, 3.0694399007729123, 1.4708172593797957, 4.451514984880175, 0.786948738353593, 0.12677102323089326, 1.0000460807766234, 39.05676228659493, 61.29635483877999, 48.42431320462908, 35.661559786115376, 28.543778249195643, 25.178901161466325, 41.33616052355085, 44.99458857945034, 55.80420337404524, 26.830104078565324, 0.3421997848365988, 0.0061917592704828295, 0.09315462743065187, 0.061955933326057026, 0.021530453880716647, 0.03126870874049408, 0.03154468250327876, 0.016560191654467156, 0.02392605399446828, 0.02933901282293456, 0.04384213226980396, 0.05333527822845748, 0.02844372997060418, 0.045493961311876774, 0.030283876229077578, 0.05027396571157234, 0.04624946255769048, 0.04353932583970683, 0.1908414073820625, 29.70190225328718, 63.40672424861363, 53.7627010345459, 53.50814683096749, 27.781576497214182, 32.86710548400879, 32.543739795684814, 48.3361405645098, 56.64478949138096, 59.96389879499163, 12.45406927381243, 0.3655729820685727, 5.8847507408687045, 23.645164489746094, 1.3884639527116502, 9.041969622884478, 60.144482476370676, 51.46035984584263, 55.64238330296108, 53.108316217150005, 55.260312284742085, 52.02154152733939, 56.4649145262582, 52.300157342638286, 52.13698237282889, 45.7855715070452, 48.03414058685303, 48.61136218479702, 49.891883918217246, 49.93266289574759, 49.92980718612671, 48.44086033957345, 45.1182074546814, 38.23581525257656, 38.35577242715018, 34.73905440739223, 36.54241418838501, 36.03913879394531, 37.98126104899815, 36.95371627807617, 39.158879961286274, 37.73311308452061, 40.40180846623012, 39.8378301348005, 39.931186131068635, 37.23741470064436, 37.306167125701904, 36.429012639181956, 37.17084748404366, 36.09137535095215, 35.530204091753276, 36.75411190305437, 37.73920318058559, 36.96455546787807, 36.79986579077584, 37.01783078057425, 37.66000066484724, 38.284973757607595, 39.50187431062971, 37.970821380615234, 40.9030966758728, 38.711742537362234, 40.1366582598005, 38.69049494607108, 38.37547057015555, 37.41541017804827, 39.498542649405344, 43.545541763305664, 42.57383966445923, 44.89349576405117, 48.18092475618635, 46.1990727015904, 48.63409321648734, 50.52693884713309, 47.41492060252598, 46.6804438999721, 47.86666815621512, 51.62601184844971, 48.30384186335972, 48.20260313579014, 49.44862011500767, 45.071849073682515, 45.81633813040597, 43.948353154318674, 40.203260217394146, 37.56106179101126, 40.512343883514404, 38.10904884338379, 38.77310555321829, 36.96255438668387, 36.74057681219918, 36.329695088522776, 37.14848470687866, 37.371518407549175, 39.55942971365792, 38.65160240445818, 37.6770133290972, 36.98986080714634, 38.14065619877407, 38.98472683770316, 39.20401198523385, 37.03469753265381, 38.16923761367798, 38.802736146109446, 37.923392977033345, 37.473351206098286, 38.343456745147705, 36.78457627977644, 39.6622074672154, 38.68141712461199, 39.186283656529014, 40.35794448852539, 38.11044543130057, 37.52732481275286, 38.498488426208496, 37.418064389910015, 38.27281093597412, 37.24438026973179, 37.950223445892334, 38.5731919833592, 40.65166916166033, 39.15321717943464, 39.27533176967076, 37.54031794411795, 40.94757209505354, 39.32791921070644, 44.595230443137034, 49.59372976848057, 48.50386660439627, 48.636125564575195, 49.02194513593401, 47.28459324155535, 48.80637380055019, 52.552234513419016, 51.29887676239014, 54.06266866411482, 58.04833255495344, 59.82546288626534, 50.724903447287424, 40.954138142721995, 52.60382488795689, 3.4272193653242926, 0.6499034464359283, 5.313285725457328, 3.192247573818479, 0.12281814962625504, 1.1150862106255122, 43.438737528664724, 66.22782489231655, 53.36767162595476, 39.59852375302996, 29.347637925829204, 27.56205858503069, 47.85388694490705, 51.837046010153635, 62.08214051382882, 32.49550887516567, 0.42564034887722557, 0.01893929997459054, 0.023114090153415288, 0.052350181088383706, 0.05598411609285644, 0.0202787382794278, 0.058984580981944285, 0.07204151499484267, 0.017160474622089947, 0.1479010515447174, 0.17172269257051603, 0.211325022525021, 0.10820692258753947, 0.09269656879561287, 0.1272458213248423, 0.20957672276667186, 0.20794211833604745, 0.1292908444468464, 0.407112895910229, 39.103405543736045, 72.90680858067104, 60.684649331229075, 60.67968136923653, 30.54133496965681, 42.04827444893973, 41.58079617364066, 52.2312068939209, 61.417920521327424, 63.89937237330845, 13.724962541035243, 0.4647124579974583, 8.12032060963767, 23.9994409765516, 1.433073016149657, 11.656679238591876, 61.028307233537944, 50.99172122137887, 57.10974209649222, 54.02231700079781, 58.06314264025007, 54.90415457316807, 58.036819389888215, 53.99452420643398, 53.157804761614116, 47.15321322849819, 47.82668822152274, 49.57011978966849, 51.28991706030709, 51.63650710242135, 51.599271706172395, 51.40901265825544, 46.903404644557405, 40.9115561076573, 39.92728124346052, 37.219738483428955, 38.561567647116526, 38.44179112570626, 40.198337418692454, 39.510882650102886, 41.59430694580078, 39.8615790775844, 43.532249859401155, 41.84230899810791, 41.876914501190186, 38.86242812020438, 39.37562901633126, 40.35241372244698, 39.078951358795166, 39.64750855309622, 36.98401042393276, 38.927025522504536, 38.96329511914934, 37.93680647441319, 38.74342284883772, 38.568442889622276, 39.136909757341655, 40.81554242542812, 41.33463886805943, 39.05795390265328, 44.683118207114084, 40.8442245892116, 43.34858465194702, 40.651245321546284, 39.760378565107075, 38.488660199301584, 43.36385331835066, 44.10266917092459, 43.947821617126465, 46.41850028719221, 49.641179016658235, 46.84200688770839, 48.9062819480896, 50.93680960791451, 48.24914216995239, 48.17435870851789, 48.63630969183785, 53.347195284707205, 50.93909209115164, 50.78169802256993, 49.86583512169974, 48.30273362568447, 48.72735888617379, 45.905167375292095, 41.730373518807546, 40.327883107321604, 43.19523096084595, 40.808952059064595, 39.669781003679546, 41.16665921892439, 39.46088341304234, 37.29486240659441, 40.36553539548601, 39.35001795632498, 40.68493366241455, 42.24600975854056, 37.82342576980591, 38.99490942273821, 40.616910798209055, 41.200246810913086, 40.6419277872358, 38.739167077200754, 40.76337535040719, 39.86683191571917, 40.33664131164551, 39.72723913192749, 40.355769702366416, 37.31688124792916, 41.21349702562605, 40.78251763752529, 40.59848417554583, 43.00387062345232, 40.071991375514436, 38.68199035099575, 40.412665026528494, 39.52133274078369, 41.079223087855745, 38.54640667779105, 40.62020424434117, 40.8230881690979, 43.02136966160366, 40.65404544557844, 41.032624994005474, 39.030122893197195, 43.10751690183367, 40.1242869922093, 46.537140778132844, 51.91468865530831, 52.66635867527553, 50.22887849807739, 50.62206663404192, 50.05743864604405, 51.90275859832764, 55.90586246762957, 52.38637406485421, 57.6875855582101, 59.896786144801546, 63.294927733285085, 54.83152505329677, 44.48854432787214, 54.46990605763027, 3.979485205241612, 2.2613322692258016, 12.745769415582929, 3.099684540714536, 0.10318395854639155, 1.6369494476488657, 48.58496945244925, 69.45021179744175, 60.519455909729004, 47.221597399030415, 37.54141575949532, 36.120682852608816, 55.67325414930071, 61.3227927344186, 70.50252342224121, 41.62079347882952, 0.8672079231057848, 0.0838741207761424, 0.2105982843786478, 0.14875543569879873, 0.17837207790996346, 0.09750901734722511, 0.12925205938518047, 0.15841214252369745, 0.10418605977403265], [0.005026748146130038, 0.015243614890745707, 0.02998211813558425, 0.008704782413717891, 0.029377071852130548, 0.009754193647365485, 0.06382784859410354, 0.1593426718775715, 0.013661058336895491, 0.08716260681727103, 26.385264771325247, 52.36810030255999, 43.2810412134443, 36.62198495864868, 19.336702925818308, 27.291487046650477, 28.445614099502563, 43.432056835719514, 53.03380026136126, 53.25779628753662, 8.668889573642186, 0.4087748181607042, 6.088702516896384, 9.033506717000689, 0.750860826245376, 0.5681429079600743, 36.94530200958252, 49.230446679251536, 49.04549952915737, 50.98382111958095, 54.15654924937657, 50.790640354156494, 49.64582388741629, 49.42856066567557, 46.70052419389997, 44.96970360619681, 47.995918546404155, 49.90632574898856, 50.75485365731375, 49.82703985486712, 46.34778847013201, 44.86420215879168, 39.20884445735386, 35.96353197097778, 34.89318977083479, 34.754913670676096, 34.98390197753906, 36.22947774614607, 33.710436139787944, 35.36019556862967, 35.13682835442679, 37.34826626096453, 37.69431781768799, 39.148607049669536, 38.91246557235718, 37.09260034561157, 36.105365548815044, 34.11869144439697, 35.50757033484322, 34.69284888676235, 33.935064452035085, 33.71183272770473, 34.0187520299639, 34.77095706122262, 35.685628346034456, 35.16960300718035, 36.85498585019793, 36.85029929024832, 36.38792099271502, 34.08484329496111, 35.132520471300396, 36.880982535226, 35.72796719414847, 36.70904588699341, 36.54421724591936, 36.82635579790388, 36.158223969595774, 38.5293801171439, 39.17504147120884, 39.705154282706125, 37.67081206185477, 41.46237107685634, 43.53879853657314, 46.01317017418997, 45.05013247898647, 46.92929015840803, 46.44678292955671, 49.05714818409511, 41.226709025246755, 40.936336857931956, 51.245014326913015, 46.00542640686035, 49.644086837768555, 46.50954600742885, 43.765796184539795, 38.280530384608674, 37.70499719892229, 36.03388248171125, 35.47747073854719, 37.2298515864781, 36.35730375562395, 34.78693791798183, 36.39388254710606, 35.03371361323765, 36.97323029381888, 36.28568867274693, 37.540877274104524, 36.799966539655415, 38.75964341844831, 36.80270760399954, 38.13636916024344, 35.63829026903425, 37.03997816358294, 35.97009801864624, 36.48760679789952, 36.06827259063721, 37.95932558604649, 36.05281979697091, 36.232948371342246, 37.22817012241909, 37.664482252938406, 37.628775460379465, 36.51510776792254, 35.44943128313337, 36.21560219355992, 35.4013671193804, 35.113405976976665, 35.80644014903477, 35.05498552322388, 36.270037855420796, 37.637384278433665, 35.58597380774361, 35.91454022271292, 36.71007422038487, 37.30173070090157, 41.711488315037315, 46.703442437308176, 48.60111011777605, 47.24431453432356, 45.99608455385481, 47.62338045665196, 48.43246691567557, 51.42617123467581, 50.429368768419536, 51.470670972551616, 51.63434968675886, 58.76836395263672, 55.51256316048758, 56.82746458053589, 30.687431267329625, 39.07618250165667, 10.11586148398263, 1.1693419792822428, 6.88004457950592, 1.3214030883141925, 0.07617434287177664, 0.25291687143700464, 38.13833550044468, 56.696192264556885, 53.668466091156006, 36.65359231403896, 23.41380337306431, 23.425959246499197, 30.204642636435374, 48.403263636997764, 55.5138589995248, 32.69885832922799, 0.8754202595778874, 0.030696266064686433, 0.03801948756777814, 0.033634566968040805, 0.07314414118549653, 0.020325161949066178, 0.05675477581098676, 0.04242362427924361, 0.012268521274173898, 0.012214123969897628, 0.005619508280817951, 0.010027505856539522, 0.06094877701252699, 0.029651708900928497, 0.03530123896364655, 0.014793493419087358, 0.050725272923175774, 0.05491986105750714, 0.6462083075727735, 36.35544858660017, 59.617544991629465, 49.532592569078716, 42.6348865372794, 20.975004775183542, 30.794794831957134, 35.783608368464876, 45.61042479106358, 58.03655188424246, 57.85922690800258, 10.134447915213448, 0.5904470054166657, 9.355656470571246, 11.15788630076817, 2.353824083294187, 0.9528446878705705, 40.13185705457415, 49.16657188960484, 48.17802388327462, 52.14831141063145, 54.97534234183175, 51.880847454071045, 50.27116870880127, 48.15390321186611, 47.35498891557966, 45.25537531716483, 48.71126338413784, 52.07038736343384, 52.18669325964791, 50.85548789160592, 48.47800193514143, 46.03813852582659, 41.431913648332866, 37.19724716459002, 36.889987400599885, 36.63456119809832, 37.36042560849871, 36.59178113937378, 37.13550547191075, 37.830943720681326, 38.16626031058175, 37.24408149719238, 39.072889055524556, 41.084191049848286, 40.39307805470058, 39.39688702992031, 38.71585239682879, 37.953475202832905, 38.37130165100098, 35.68434640339443, 35.72805404663086, 35.61402021135603, 35.463539600372314, 36.37929480416434, 36.68452222006661, 37.32679285321917, 37.61673075812203, 37.60005855560303, 39.01571580341884, 36.83201510565621, 36.427741118839805, 37.99483782904488, 36.66333021436419, 38.42492437362671, 37.58788183757237, 37.98569399969918, 37.14573669433594, 40.39110476630074, 40.33331312452044, 41.22883169991629, 38.52260562351772, 44.53575038909912, 45.18267631530762, 47.157701764787944, 46.05424445016043, 48.12676007407052, 48.72545507975987, 49.35536139351981, 42.865462507520405, 43.72708082199097, 52.42852183750698, 48.28633935110909, 49.60883862631661, 48.108885833195274, 45.15818738937378, 40.39533969334194, 39.49804585320609, 38.25083725793021, 38.40197794778006, 37.52449689592634, 37.37382173538208, 36.14236470631191, 38.392292158944265, 36.86078759602138, 38.58445501327515, 38.76617472512381, 39.123659542628694, 38.77720846448626, 39.030637059892925, 38.21045432771955, 38.870203154427664, 38.01818725040981, 38.677262101854595, 38.875820772988455, 37.6604905128479, 37.2211593900408, 38.138151373182026, 36.77045406614031, 38.933258056640625, 39.19685534068516, 40.28587429864066, 38.52052116394043, 39.919926575251985, 37.92904881068638, 37.16301686423165, 36.878574984414236, 36.842524256025044, 38.21229212624686, 37.67891018731253, 38.18998493467058, 38.16684395926339, 37.32131767272949, 38.565382208142964, 38.24020651408604, 38.47551768166678, 43.3186240196228, 48.741411617824006, 50.00120687484741, 49.578648703438894, 49.104371615818565, 50.23522915158953, 50.51728432519095, 52.72299691608974, 52.461421557835166, 53.8082777432033, 52.22951848166329, 61.88066359928676, 55.73747287477766, 60.15293148585728, 33.28883681978498, 42.268636567252024, 10.262245263372149, 0.9933937234537942, 7.44678829397474, 6.3417298538344244, 0.13056567603988306, 0.3281247429549694, 40.48977266039167, 61.58562224251883, 59.20026397705078, 41.243516717638286, 29.9486015183585, 31.404516628810338, 39.02687808445522, 55.84340511049543, 62.852188519069124, 39.86283670152937, 1.5693476008517402, 0.022619020825784122, 0.046855557177747996, 0.044605728438390155, 0.027417228623692478, 0.03105916694871017, 0.017534800339490175, 0.024900012982210944, 0.009253694343247583, 0.09760148131421634, 0.16165891901722976, 0.09033783857843705, 0.14468294994107314, 0.09749550092965364, 0.11847496910818986, 0.09754400939813682, 0.21702102545116628, 0.09049752500972577, 1.2361090651580264, 44.41691187449864, 70.42656571524483, 56.58484043393816, 49.9769263948713, 28.31726176398141, 38.54916163853237, 38.307406016758506, 52.69532224110195, 61.39587388719831, 63.81925964355469, 10.386470368930272, 0.7109502649732998, 8.531470707484655, 12.69700174672263, 2.6358534182821, 1.405700153538159, 43.264268262045725, 48.814506667000906, 49.93212788445609, 53.700775214603965, 57.710337434496196, 52.7772901398795, 50.792304447719026, 49.81546763011387, 47.6706177847726, 44.6296830858503, 50.30855696541922, 53.022068228040425, 54.20304659434727, 53.51597397668021, 52.11479330062866, 48.79882458278111, 42.704469272068565, 38.568244865962434, 39.403651101248606, 38.366198199135916, 39.57091508592878, 39.537577629089355, 38.236669881003245, 40.65511894226074, 40.02663006101336, 40.1942275592259, 41.76980454581124, 44.0191969871521, 42.90427514484951, 40.85595662253243, 41.531787054879324, 40.4279545375279, 38.913740566798616, 37.71976212092808, 37.39296749659947, 38.22561877114432, 36.18673242841448, 38.19793367385864, 38.146655968257356, 38.22162355695452, 40.390920639038086, 39.440924712589805, 40.320219244275776, 36.59530735015869, 38.11455529076712, 40.23438119888306, 39.149763924734934, 39.32359395708357, 40.34829691478184, 41.208341462271555, 38.76479203360421, 42.34544890267508, 42.8019802910941, 42.579933234623496, 40.533977099827354, 44.21977063587734, 46.87894351141793, 51.17183937345232, 49.39834295000349, 50.487817014966694, 51.5932754107884, 50.61974246161324, 46.312342235020225, 45.74719660622733, 55.52148812157767, 49.124069758823936, 52.45872565678188, 49.83610030582973, 47.03281831741333, 42.65420600346157, 42.164844376700266, 41.09163951873779, 40.47946153368269, 40.679851055145264, 40.315775871276855, 38.760734285627095, 40.72195019040789, 38.86827155521938, 41.52538081577846, 39.848408767155235, 41.15702206747872, 41.056464263371055, 41.293029580797466, 39.201764242989675, 41.43005153111049, 40.06065191541399, 39.664093903132844, 40.12528058460781, 39.23396914345877, 40.137839453560964, 40.1201354435512, 38.67201968601772, 40.58014440536499, 41.12497697557722, 41.89364228929792, 41.45214680262974, 41.43213251658848, 40.32877247674124, 40.29693235669817, 39.54992805208479, 39.41760655811855, 39.93091515132359, 38.656896931784495, 40.43535089492798, 39.97744376318795, 38.48873315538679, 40.08250399998256, 40.106642041887554, 39.839817319597515, 44.8297495160784, 51.46888875961304, 53.51225669043404, 51.66245862415859, 51.356578077588765, 51.8539822442191, 54.12680401120867, 53.991484369550435, 55.85871199199131, 55.69291407721383, 53.60829816545759, 62.89254365648542, 58.76657826559884, 58.52438490731375, 36.88228184836251, 45.12993948800223, 12.237100481987, 2.723802847521646, 21.209313665117534, 5.162551070962634, 0.18647556379437447, 0.6178536862134933, 44.509607791900635, 65.73805332183838, 66.52807739802769, 49.30965614318848, 34.01580599376133, 34.47953919001988, 44.60568053381783, 64.04312365395683, 70.81227411542619, 48.82948350906372, 2.1459211707115173, 0.1432744740907635, 0.14581433923116752, 0.14612221771052905, 0.248188459447452, 0.1298052282737834, 0.14001903949039324, 0.09845213352569512, 0.06711758313966648], [0.02912436844781041, 0.09029978633459125, 0.012173812204439725, 0.026370576483064463, 0.03158809856644698, 0.04961041613881077, 0.06208362004586628, 0.10444176569581032, 0.04192142354856644, 1.250153654388019, 36.948164667402, 51.60760954448155, 46.372412885938374, 40.3411020551409, 24.321278061185563, 25.397988285337174, 30.688574245997838, 46.277253832135884, 53.59202548435756, 51.49253000531878, 7.837092058999198, 0.26565205092941013, 2.440220807279859, 6.629180303641728, 3.338983105761664, 0.14913268759846687, 35.299221651894705, 37.4243038722447, 31.03652960913522, 55.412057467869346, 51.68237910951887, 53.08168724605015, 49.5920934677124, 49.341923577444895, 46.65975216456822, 46.73029375076294, 48.258223465510774, 50.43537201200213, 48.3861745425633, 47.94337626865932, 45.450939314705984, 39.425972189222065, 34.71919298171997, 34.72971255438668, 34.70539385931832, 34.88583510262625, 33.43979685647147, 35.61299187796456, 35.266457421439036, 37.47828095299857, 36.201410497937886, 36.13134833744594, 36.55961445399693, 37.647546018872944, 37.516037464141846, 36.49981478282383, 34.45773574284145, 36.32091951370239, 34.79658201762608, 35.65466022491455, 33.75621782030378, 35.897093296051025, 34.936807087489534, 35.63945409229824, 34.370341300964355, 36.05754804611206, 34.71100800377982, 37.542944363185335, 35.743458202907014, 37.1095643724714, 35.07304736546108, 36.0199304989406, 36.22887672696795, 35.94220447540283, 36.94438484736851, 37.29497010367257, 35.81755379268101, 35.777751037052695, 35.07853296824864, 36.310201917375835, 35.86355434145246, 37.36747803006853, 39.219343185424805, 46.066337789808, 44.44702884129116, 49.319737979343955, 48.79833473478045, 51.48888914925711, 44.83360229219709, 37.33938646316528, 48.57036433901106, 46.56214039666312, 50.64292860031128, 47.30876949855259, 46.8976445879255, 39.273205620901926, 38.3267810685294, 36.88158702850342, 38.409356934683665, 37.21718502044678, 34.81195143290928, 36.643468788691926, 35.334139823913574, 36.92266130447388, 35.19660718100411, 35.78306293487549, 36.190484455653596, 36.906958375658306, 37.477874483381, 37.8525630405971, 38.038409982408794, 36.744269779750276, 37.71346010480608, 38.45706674030849, 38.71904509408133, 36.02344281332833, 36.298779078892295, 37.229156766619, 34.82183871950422, 34.64910650253296, 33.996052265167236, 36.209109101976665, 37.326455865587505, 37.12163686752319, 36.216217109135215, 35.53816325323922, 33.67569167273385, 34.57627895900181, 36.99677773884365, 36.60309280667986, 35.64373765672956, 37.98759085791451, 37.28004537309919, 37.30441270555769, 38.81006302152361, 47.452149050576345, 50.52853345870972, 51.389925956726074, 49.34993832451956, 48.73302166802542, 48.60614061355591, 50.757712841033936, 51.63445738383702, 53.330293791634695, 53.96688774653843, 54.208084038325715, 54.41862140383039, 53.61138316563198, 53.41598245075771, 33.126707553863525, 38.836167403629844, 14.333195686340332, 0.43015912068741663, 3.656149046761649, 6.321366855076381, 0.015828461186694245, 0.09616939244525773, 33.690428801945274, 58.10125003542219, 53.64805228369576, 46.57500498635428, 41.282687187194824, 14.653250558035714, 24.903580529349192, 53.099742140088765, 54.547746726444785, 35.88321426936558, 2.142494623150144, 0.029129837440060716, 0.0014031363098183647, 0.058402255443590026, 0.0068578279045011315, 0.03877843916416168, 0.07051627005317382, 0.04031545329572899, 0.01555636864421623, 0.011955368033211147, 0.03357453018959079, 0.04023531152467642, 0.07827911100217275, 0.08175656904599496, 0.07005344131695372, 0.02320801466703415, 0.05155537909428988, 0.09355705976486206, 1.900032239300864, 47.635091645377024, 60.34024797167097, 53.799672399248394, 46.17031063352312, 26.78894121306283, 31.64421558380127, 34.39787353788103, 47.480893748147146, 58.39924785069057, 52.99406698771885, 8.063468711716787, 0.7280788772872516, 4.156448440892356, 12.343198605946132, 2.6277012271540503, 0.06288680873279061, 35.80377551487514, 39.37681368419102, 31.93947580882481, 56.735192503247944, 51.8879519871303, 55.539723668779644, 50.436271803719656, 48.6338152885437, 48.12299067633492, 47.2361330304827, 49.30835683005196, 52.87665632792881, 49.79858350753784, 49.405944279261995, 47.432287624904085, 41.242933068956646, 36.16425848007202, 36.78419760295323, 36.682621887751985, 37.71654510498047, 34.685598441532676, 37.32658788136074, 36.089468070438926, 38.58992324556623, 37.776542799813406, 39.43648828778948, 38.7290609223502, 40.82517957687378, 39.34433780397688, 37.84768887928554, 37.20874643325806, 37.23020247050694, 35.95281090055193, 37.32516350064959, 37.325802734919954, 38.06034891945975, 36.24330813544137, 36.699096066611155, 37.64431858062744, 38.24451092311314, 37.566519601004465, 38.73192010607038, 37.28784472601754, 38.714302948543, 36.16731916155134, 37.2932573727199, 37.9478645324707, 38.41890375954764, 39.21277366365705, 39.04943193708147, 37.75468724114554, 36.93865258353097, 35.861292702811106, 37.546967370169504, 37.65920509610857, 39.25056838989258, 41.20157739094326, 46.73760672977993, 45.39747640064785, 51.118324347904746, 50.115806988307405, 53.49766547339303, 45.234294482639854, 39.177066871098106, 49.26393352236067, 49.54098946707589, 51.71932962962559, 49.13837262562343, 47.79285396848406, 40.767961161477224, 39.69767107282366, 37.91241134916033, 39.23495578765869, 38.421714305877686, 37.163930552346365, 38.48125689370291, 37.46044840131487, 38.553782190595356, 37.189381803785054, 37.49828829084124, 36.88822603225708, 38.500861236027305, 39.09528309958321, 38.93983105250767, 41.15077911104475, 37.54654353005545, 40.04269082205636, 40.913883754185264, 39.52781193596976, 37.66403409412929, 38.50918517793928, 37.33073943001883, 37.03122343335833, 37.418769632067, 37.307480335235596, 39.367760181427, 38.73179503849575, 39.50225298745291, 38.4782726424081, 36.65980747767857, 34.88577604293823, 37.28427335194179, 39.99617958068848, 38.94400691986084, 38.82472372055054, 38.92056022371565, 38.675639697483604, 39.65843112128121, 40.53220878328596, 47.588382380349294, 53.048214299338206, 52.67339025224958, 52.862096377781455, 51.517449719565256, 51.03515093667166, 53.031191212790354, 54.230988774980815, 53.39494677952358, 56.55134316853115, 56.006326471056255, 57.439746788569856, 53.99863406590053, 50.157551765441895, 37.258565017155235, 40.998325211661204, 16.365884235927037, 0.47041698332343784, 7.831041046551295, 13.946143678256444, 0.16756779194942542, 0.012553165866328138, 37.95809575489589, 64.0610430581229, 59.82619939531599, 43.98157249178205, 39.11280645642962, 21.100112301962717, 30.977959769112722, 57.050647667476106, 61.28024196624756, 45.65537963594709, 2.9515589347907474, 0.07040470532540764, 0.08218915547643389, 0.015014911270035165, 0.022756905926923667, 0.029050106182694435, 0.04626892294202532, 0.033654061279126575, 0.06792586083923068, 0.09724788314529828, 0.15227285266986915, 0.08710064978471824, 0.13184957286076887, 0.11809481307864189, 0.19176205726606504, 0.17941860961062567, 0.18389930203557014, 0.22131628782621451, 2.741286035094942, 57.21166174752371, 68.80530779702323, 61.98995876312256, 53.318509646824424, 32.94251080921718, 37.04630102430071, 41.260810783931184, 55.12185205732073, 62.43364988054548, 58.77993270329067, 9.968334725924901, 0.7975262850522995, 3.987963310309819, 14.635847057615008, 8.45561374936785, 0.2779881975480488, 40.800034046173096, 44.189417430332725, 35.477543694632395, 56.85567774091448, 54.99756962912423, 55.308108942849294, 52.35875497545515, 49.82855108806065, 49.46280138833182, 47.715468406677246, 49.86106170926775, 53.786707060677664, 53.639644963400706, 50.83245113917759, 49.79722513471331, 44.13847671236311, 39.04208074297224, 38.5467540877206, 38.04357944216047, 39.27534219196865, 37.174530029296875, 40.30393961497715, 40.9598981993539, 43.10119751521519, 40.54261718477522, 40.74209649222237, 40.83114113126482, 42.86080026626587, 43.45899847575596, 39.804617745535715, 38.12055853434971, 39.7442170551845, 37.05835267475673, 39.01666423252651, 37.65963241032192, 39.776387214660645, 39.54711055755615, 39.54851409367153, 37.87378978729248, 39.54385880061558, 38.935915742601665, 41.84282316480364, 39.61476516723633, 40.83395515169416, 38.35302788870675, 39.73243291037423, 40.39586428233555, 38.82412270137242, 40.52564968381609, 40.7189485686166, 39.60470764977591, 39.697368826184956, 38.190405300685335, 39.81635672705514, 39.47260502406529, 39.885619844709126, 43.25465890339443, 48.44956990650722, 49.05867678778512, 52.59188093457903, 53.22722768783569, 55.207950660160606, 48.23502343041556, 42.82279014587402, 50.13073866707938, 51.1736285345895, 54.19624778202602, 50.957504817417686, 50.04094014848982, 43.141677720206125, 41.93965326036726, 40.40119355065482, 41.456419944763184, 42.316787583487375, 38.17812088557652, 41.6568546295166, 37.79519871303013, 41.32161099570138, 39.473973819187705, 39.42015307290213, 40.549259662628174, 40.63974257877895, 41.21126665387835, 40.57720879146031, 41.489316190992085, 40.764497484479634, 43.01490436281477, 43.772605419158936, 42.84599018096924, 39.033440658024375, 41.09942497525896, 40.021999086652485, 39.719662121364046, 39.32478557314192, 37.93728937421526, 41.34570387431553, 42.05202647617885, 41.98279462541853, 41.24634116036551, 38.98982334136963, 36.08457653863089, 39.10387454714094, 42.899487836020334, 40.38831506456648, 40.20558786392212, 41.24180746078491, 41.09427636010306, 41.10064785821097, 42.01840761729649, 50.847966466631206, 56.529730796813965, 54.56647906984602, 56.8778008052281, 52.44386693409511, 53.26655101776123, 54.56480802808489, 55.87745475769043, 56.67743212836129, 59.640210015433176, 58.142029012952534, 59.240903990609304, 54.38947718484061, 53.81203671864101, 40.99668196269444, 43.37984459740775, 19.156692470823014, 1.6962755556617464, 8.182346309934344, 13.552344100815908, 0.12668056094220706, 0.26118653054748264, 40.98009661265782, 69.22224834987095, 66.04519149235317, 58.51859705788748, 50.305089814322336, 22.83432882172721, 36.39004366738455, 69.07245908464704, 67.27273668561662, 55.715509619031636, 3.650190097945077, 0.26632993455444065, 0.2259456201323441, 0.07300467509776354, 0.07467759640089103, 0.11258242851389305, 0.13857304065355233, 0.1179830583610705, 0.14119622989424638], [0.05894545665276902, 0.05244887400684612, 0.033025744637208324, 0.04269459045359066, 0.02795844681427947, 0.06939195109797375, 0.06329529359936714, 0.007284645939112774, 0.005583028541877866, 2.007448132549013, 41.58116442816598, 52.8431521143232, 44.90089559555054, 39.94493661608015, 14.305715560913086, 20.88912156649998, 39.005307401929585, 49.35334989002773, 54.22949143818447, 51.64235748563494, 5.00312682560512, 0.07188185570495469, 1.3626824447086878, 9.322267770767212, 2.476226589509419, 1.7968714662960596, 49.941052845546174, 47.51638167245047, 56.63300882066999, 50.44897658484322, 54.16913938522339, 50.08535303388323, 53.718072754996165, 47.11199998855591, 50.43136984961373, 47.899369852883474, 51.938284737723215, 47.22393546785627, 48.217844009399414, 44.80175174985613, 40.93785156522478, 33.119366782052175, 36.75561966214861, 33.897134235927034, 34.483669894082205, 33.32449150085449, 33.9719489642552, 34.95046724591936, 35.56499719619751, 35.17870167323521, 35.7562289919172, 35.27456944329398, 36.54215710503714, 37.447691508701865, 35.55820533207485, 34.28471864972796, 33.849104813167024, 32.932314327784944, 34.6250900541033, 35.768874713352744, 36.13658380508423, 35.26745448793684, 34.75925976889474, 35.94097464425223, 35.078487804957796, 35.71211487906319, 35.81890869140625, 36.439157009124756, 36.56639589582171, 35.45739391871861, 35.36387811388288, 34.2163587978908, 36.38860886437552, 34.741062436785015, 35.65113748822893, 34.52587672642299, 35.480663435799734, 37.13775321415493, 37.967194420950754, 37.02364642279488, 37.72471966062273, 37.57046965190342, 38.700389180864605, 46.38783441271101, 48.38756765638079, 48.61973476409912, 49.50968435832432, 43.32111842291695, 26.14637007032122, 37.42156628199986, 46.66102715900966, 49.18778126580374, 48.626092365809846, 47.45494222640991, 46.49026475633894, 36.5534861428397, 35.55398777553013, 35.85849257877895, 35.38218314307076, 36.67666380746024, 36.21527910232544, 35.15542868205479, 35.7301732472011, 35.67368786675589, 35.65335743767874, 36.05445957183838, 37.24439416612898, 36.38783414023263, 36.53030000414167, 36.67189734322684, 37.73466600690569, 37.46514885766165, 37.01219926561628, 37.295842102595735, 36.76352671214512, 37.862405163901194, 36.63461678368704, 35.54931511197771, 36.22300549915859, 35.663925647735596, 35.40233639308384, 34.67525952202933, 35.91413722719465, 34.632267543247764, 34.66749143600464, 35.38611929757254, 34.882982867104666, 35.653034346444265, 35.05123002188546, 35.84660768508911, 36.17216553006853, 34.99946594238281, 37.68213415145874, 37.67065920148577, 43.19194793701172, 47.669676303863525, 52.08506543295724, 49.00882693699428, 48.358538082667756, 53.821031161717, 50.76931633268084, 50.596730027879985, 50.634608132498606, 52.779482296534944, 56.65861293247768, 49.70708268029349, 54.41059970855713, 45.68767138889858, 34.75187383379255, 44.73972518103463, 48.32406806945801, 27.217718022210256, 0.4389216676354408, 5.284746434007372, 16.43175142151969, 0.4254585014922278, 0.09677482210099697, 27.973477057048253, 57.50305182593209, 51.041275773729595, 46.56499263218471, 52.49949768611363, 23.923318249838694, 22.52243287222726, 40.71381732395717, 50.81916618347168, 51.52505104882376, 4.552897887570517, 0.10590588141764913, 0.10407311762017862, 0.07435280882886477, 0.03571195960310953, 0.059313989377447536, 0.10371369083545037, 0.029922430802668844, 0.11287908402404614, 0.045921333200697384, 0.009676638791071517, 0.053062792135668654, 0.009715856418811848, 0.03030352321054254, 0.08067816655550684, 0.04029326859329428, 0.10797546750732831, 0.03843386551099164, 2.623269144977842, 51.460088866097585, 58.347490719386506, 50.9273670060294, 45.160911083221436, 18.71927383967808, 29.556750910622732, 38.727358613695415, 51.62731116158621, 57.387069020952495, 55.87881660461426, 5.056547616209302, 0.13778823348028318, 1.3084116939987456, 13.65712206704276, 1.058568911893027, 1.5745007757629668, 51.98211744853428, 48.3653473172869, 57.76845564161028, 50.615285192217144, 56.37008203778948, 51.90498202187674, 55.44130938393729, 48.61112247194563, 51.181386198316304, 49.33365522112165, 52.73369019372122, 49.21920796803066, 50.52481617246355, 46.06330142702375, 40.15942055838448, 35.3393474987575, 37.98373808179583, 36.35775538853237, 36.73408719471523, 35.32031290871756, 35.69372647149222, 36.506394726889475, 37.52500411442348, 37.767795017787385, 38.582978521074565, 37.511132035936626, 39.44880049569266, 39.77400745664324, 37.97260011945452, 35.40940965924944, 37.16979135785784, 34.26663943699428, 36.5348128591265, 37.14933933530535, 37.55252940314156, 36.134857177734375, 35.556252888270784, 37.32124124254499, 36.56572192055838, 35.996522017887656, 37.85356705529349, 37.52222483498709, 37.727498940059114, 36.15891184125628, 38.25980738231114, 34.77395520891462, 37.69655861173357, 35.5492456299918, 36.69635500226702, 36.35974604742867, 38.25662163325718, 37.766328947884695, 38.27837644304548, 38.32460975646973, 37.89725385393415, 38.49512897218977, 41.890932491847444, 47.60166386195591, 51.193218980516704, 50.10213640757969, 50.42814588546753, 43.99653196334839, 28.730514560426982, 38.26742608206612, 48.546094281332834, 48.91363661629813, 49.885376930236816, 47.99210398537772, 48.43770933151245, 38.43325178963797, 37.47353880746024, 37.04642609187535, 36.55875982557024, 38.056169578007285, 36.96782806941441, 35.52955443518502, 38.53211075919015, 37.45406648090908, 38.66509233202253, 36.93827043260847, 37.845566204616, 37.18623079572405, 38.578562940870015, 38.67723430906023, 38.72398178918021, 39.232384954180034, 37.764185428619385, 38.16073301860264, 38.99947786331177, 39.532918861934114, 38.344742161887034, 37.33364725112915, 38.214314052036826, 37.91755996431623, 37.525914328438894, 37.233002594539094, 37.93618113654, 35.07627132960728, 36.71155071258545, 37.425113337380544, 38.04389558519636, 36.93398339407784, 36.66676262446812, 39.924411637442454, 38.191068853650776, 37.980298723493306, 39.420799255371094, 39.64771352495466, 45.41864061355591, 50.17257029669625, 53.215933391026084, 52.13876805986677, 50.38118995938982, 54.94457571847098, 50.98091677256993, 52.42981767654419, 53.1012533732823, 55.15009995869228, 56.30241353171212, 51.41956697191511, 55.67507110323225, 45.70420462744576, 35.497102873665945, 46.76483672005789, 49.13200460161482, 29.842804772513254, 0.5607164236051696, 6.689225333077567, 15.400016886847359, 0.6787335308534759, 0.11748014177594866, 30.039160864693777, 64.23241342817033, 57.59034899302891, 49.6288285936628, 49.53913082395281, 26.030210086277553, 26.459252664021083, 48.74579593113491, 56.414564405168804, 62.62115396772112, 5.874014036996024, 0.1443209515086242, 0.04851685517600604, 0.059538421620215685, 0.04102523145931108, 0.03181862744635769, 0.08932027353772096, 0.040926633535751274, 0.04173509443977049, 0.3498433732560703, 0.0845412631918277, 0.20853948699576513, 0.17470455542206764, 0.11623926407524518, 0.15777351893484592, 0.10931949610156672, 0.20768101806087153, 0.13566948074315274, 4.229694613388606, 60.447201592581614, 66.4887922831944, 57.027940954480854, 51.46171474456787, 22.099056550434657, 27.381612130573817, 49.835881437574116, 59.35407624925886, 62.47034331730434, 60.10458592006138, 5.648354351520538, 0.2351742120725768, 3.4042015033108846, 17.89976681981768, 7.0058451890945435, 2.5125889011791775, 56.05038499832153, 47.65895870753697, 61.30797222682408, 51.981853416987825, 59.16964326586042, 52.226360525403706, 58.71345233917236, 49.982050691332134, 52.86207205908639, 49.61040197099958, 56.21458830152239, 51.87652220044817, 51.757972036089214, 47.96931389399937, 44.12944058009556, 36.20136533464704, 40.01749317986624, 38.66163560322353, 38.31768587657383, 38.12120819091797, 38.167194843292236, 40.31198910304478, 40.66374165671212, 40.37681579589844, 40.31470237459455, 40.56475414548601, 42.80110829217093, 42.932311126164024, 40.0920021874564, 37.994684968675884, 37.507032598767964, 36.726656096322195, 37.51756606783186, 39.44814389092581, 39.17198426382882, 37.574381487710134, 36.83783074787685, 38.50423806054251, 38.0622353553772, 37.55402673993792, 40.2919921875, 40.52207483564104, 39.52421276909964, 36.75337539400373, 39.39076566696167, 36.30885396684919, 38.96280179704939, 37.28920657294137, 39.53489562443325, 39.14552204949515, 39.68158599308559, 40.484318324497764, 41.992240701402935, 40.547904763902935, 41.86014154979161, 41.09472451891218, 42.869586263384136, 50.32693147659302, 54.09920229230608, 52.9684350831168, 54.212475299835205, 44.99124649592808, 32.43232890537807, 41.112598759787424, 49.200138636997764, 52.91152933665684, 51.067748410361155, 52.187127522059846, 50.85754108428955, 40.824404852730886, 38.39023896626064, 38.81004217692784, 38.046112060546875, 40.68949515478951, 39.71005276271275, 38.26927430289132, 39.93933636801583, 38.599873065948486, 41.34786128997803, 39.68092591421944, 40.999937193734304, 39.56214993340628, 40.785599163600374, 39.735295568193706, 38.676817417144775, 40.802778584616526, 40.71214280809675, 40.94392776489258, 41.20740345546177, 41.29983534131731, 39.241372449057444, 39.54523801803589, 40.32553114209856, 39.96447147641863, 39.55725492749895, 38.47072342463902, 40.78160742350987, 37.62975515638079, 40.58456345966884, 39.68984740121024, 40.95149087905884, 39.610603196280344, 39.80016047613961, 41.912843636104036, 41.063155378614155, 39.73025812421526, 42.131784847804475, 41.08601147787911, 47.183941636766704, 52.445746421813965, 56.10374368940081, 54.64533417565482, 54.319057192121235, 57.67664214542934, 53.21201808112008, 54.31740352085659, 53.84036105019705, 55.67547409875052, 59.535299164908274, 52.22284126281738, 57.264263084956575, 49.39734240940639, 41.785615171704976, 48.17858321326119, 51.05325099400112, 33.439313956669395, 0.9073192764605794, 11.352054578917366, 22.566844020571025, 1.147566324898175, 0.1778630545096738, 33.30337592533657, 70.26064273289272, 63.230406761169434, 59.68831934247698, 61.881205558776855, 33.088829449244905, 34.37464223589216, 59.20169530596052, 64.07114573887416, 70.12209565298897, 8.455881255013601, 0.3640176983816283, 0.3493051864206791, 0.2315646500459739, 0.10292007627763919, 0.1998004037886858, 0.24991693241255625, 0.11100449532802616, 0.18347215067063058], [0.026451734360307455, 0.06432820031685488, 0.010660484034035887, 0.037567725737712214, 0.014086044326956784, 0.021142850929339017, 0.032004556219492636, 0.06609632008309875, 0.15668810717761517, 3.4129996597766876, 49.81707613808768, 53.615058762686594, 47.976050172533306, 41.73029014042446, 21.74286409786769, 27.889737367630005, 39.802165031433105, 48.401644706726074, 50.662793500082834, 55.102442264556885, 5.483270798410688, 0.11584921500512532, 0.5980718934110233, 13.871499180793762, 0.5179182887077332, 10.258596590587072, 25.873992000307354, 19.475880554744176, 57.21667487280709, 46.07528359549386, 51.98077644620623, 46.56158801487514, 50.88152626582554, 46.84712423597063, 52.68369790485927, 49.256926264081685, 52.71215772628784, 45.36601843152727, 42.25226313727242, 35.009766646793906, 35.28887231009347, 35.418261664254324, 36.8691532271249, 34.60196644919259, 34.076852866581504, 33.49053260258266, 32.92678356170654, 32.8714793750218, 36.14549139567784, 35.17683955601284, 36.24026829855782, 35.50913715362549, 35.17332376752581, 35.79804672513689, 35.12943547112601, 35.04317358561924, 35.11878388268607, 33.13983270100185, 35.961603845868794, 35.03286940710885, 34.4029735156468, 36.19095345905849, 34.994980880192344, 34.17265115465437, 34.33567326409476, 35.89764220373971, 36.57673828942435, 34.6179473059518, 35.83509104592459, 34.85664224624634, 34.05585888453892, 36.21321201324463, 36.22908864702497, 36.650910309382844, 35.68007673536028, 35.30064950670515, 35.605682373046875, 36.51915856770107, 37.22744403566633, 36.63478006635393, 36.89625814982823, 37.60344580241612, 40.07189410073416, 48.4737948008946, 47.08705595561436, 48.01077726909092, 46.64260401044573, 48.03080892562866, 35.55365078789847, 38.590868200574604, 51.989110810416086, 47.350677558353965, 46.427053519657676, 44.62112637928554, 40.73321669442313, 35.17265326636178, 36.66649859292166, 35.86720561981201, 36.56356797899519, 35.18398577826363, 34.626952171325684, 34.275929178510395, 35.31830140522548, 35.26170137950352, 35.17634970801217, 34.65116664341518, 37.40578344890049, 36.72167076383318, 35.97957188742501, 36.68105854306902, 37.48980106626238, 36.76352323804583, 37.343701294490266, 36.263311999184744, 36.792403425489155, 37.02371937888009, 36.19607080732073, 36.389925548008506, 35.625182492392405, 35.28943164008004, 37.36845425197056, 36.3467390196664, 35.18288796288626, 34.493095125470845, 34.60507924216134, 36.11269589832851, 34.1660920551845, 35.37981033325195, 36.3037748336792, 36.307005746024, 38.354810101645334, 35.47079699380057, 37.797887665884836, 38.07655906677246, 46.76150853293282, 49.08256122044155, 51.60622337886265, 45.10131638390677, 48.62536627905709, 52.46002149581909, 50.836731229509624, 53.04262447357178, 52.115119865962434, 51.5380858693804, 51.14053773880005, 53.914359365190776, 55.051435538700645, 55.42336218697684, 56.8938615662711, 57.679612500326975, 59.08761283329555, 45.388131073543, 0.3612131231597492, 7.219950020313263, 21.771659169878276, 0.9591302020209176, 0.072574504251991, 20.513470683779033, 60.181773458208355, 47.42600992747715, 48.767693178994314, 59.2980876650129, 30.97124433517456, 23.97303261075701, 33.03686734608242, 48.828979764665874, 51.195425033569336, 5.555820848260607, 0.1570201822157417, 0.030859450343996286, 0.03933816609371986, 0.07259171868541411, 0.05580520676448941, 0.010577427106909454, 0.028249411111963645, 0.06109561199056251, 0.025837609278304235, 0.07058210830603327, 0.023438358646152273, 0.06990583959434714, 0.009487273238067116, 0.1231662245201213, 0.03910477040335536, 0.09676960416670356, 0.11760531791618892, 5.337290448801858, 58.960752623421804, 57.501745564596995, 54.474662099565776, 50.239120142800466, 23.68282720020839, 24.094254357474192, 38.17422989436558, 52.70829800197056, 53.27652168273926, 60.56469563075474, 6.017671951225825, 0.13485812927995408, 1.1938246084111077, 6.483590790203639, 0.9281085580587387, 13.087113567761012, 28.91367949758257, 22.129847492490494, 62.03748444148472, 48.87843009403774, 54.43034648895264, 47.16692897251674, 51.58338117599487, 47.07503209795271, 53.61225863865444, 50.912400586264475, 54.75491768973214, 47.62257446561541, 44.97803449630737, 37.186251640319824, 38.18181037902832, 36.31057712009975, 38.8211349759783, 36.74724013464791, 35.27564641407558, 34.34160702569144, 36.34894159861973, 35.44791310174124, 37.94030141830444, 37.80587114606585, 39.42237997055054, 37.958773204258506, 37.25372907093593, 37.25922162192208, 37.82486752101353, 36.72928598948887, 36.69528497968401, 35.32193878718785, 36.73936782564436, 36.122920172555105, 36.824260916028706, 37.43286752700806, 37.43480607441494, 36.681499753679546, 37.701415402548655, 36.777951172419954, 38.935540539877756, 37.4269928250994, 37.79482003620693, 37.25222826004028, 35.465443406786235, 36.76010472433907, 37.548450810568674, 36.6898375919887, 38.61453376497541, 36.58499622344971, 36.457121576581685, 36.46821437563215, 38.75878184182303, 38.20555932181222, 38.78083542415074, 38.64136075973511, 41.738759994506836, 50.721686431339805, 48.473273686000276, 49.731766155787874, 50.72993394306728, 48.7922237941197, 37.425474643707275, 41.86827094214303, 52.845160143715994, 49.30782181876046, 49.76504455293928, 46.709813935416086, 43.99328368050711, 36.3501158441816, 38.582849979400635, 36.972858565194265, 38.34813288279942, 35.88351651600429, 36.440074171338765, 36.27459934779576, 38.001202378954204, 36.23279551097325, 37.98421055930001, 36.441178934914724, 38.20224503108433, 37.441132409232004, 37.74636329923357, 36.94560773032052, 40.6515406199864, 38.53506374359131, 39.49373797007969, 37.68006706237793, 38.62564740862165, 37.727141107831685, 38.519367762974326, 37.49312577928816, 37.69164970942906, 36.77121489388602, 39.78493002482823, 39.35076488767351, 36.58068139212472, 36.54408523014614, 36.558763299669536, 38.119248798915315, 36.945409706660676, 37.64140381131853, 38.4565178326198, 37.76266029902867, 40.38209295272827, 38.46709993907383, 40.1747031211853, 39.696851185389924, 48.74222108295986, 51.89426442555019, 52.42175776617867, 48.589579582214355, 51.54069491795131, 52.648883955819265, 51.503605433872764, 53.80033942631313, 51.81921693256923, 51.42043202263968, 52.10208851950509, 56.16445357458932, 56.15525763375418, 56.643806321280344, 56.40352719170706, 59.54267815181187, 60.51980331965855, 49.371119907924104, 0.3990010369036879, 1.4185348876885004, 7.358249136379786, 1.543524186526026, 0.01587039465084672, 22.825306585856847, 65.03021253858293, 52.70469536100115, 48.69842311314174, 52.26281424931118, 30.029732159205846, 28.549771070480347, 41.99167442321777, 52.62743139266968, 61.54357174464634, 7.179652639797755, 0.18612044570701464, 0.0695390710607171, 0.027300563008923615, 0.09507874918303319, 0.030982811403061663, 0.0336870855784842, 0.043110949719058614, 0.1456293027315821, 0.08566838449665479, 0.17561037253056253, 0.11868550495377608, 0.15177083175097192, 0.14252154449267046, 0.18901480468256132, 0.10093979896711451, 0.2774920527424131, 0.28618036795939716, 7.041218902383532, 68.57850469861711, 65.78752449580601, 61.69636957986014, 53.096028327941895, 29.069640500204905, 36.69948863983154, 48.89499807357788, 59.2990117754255, 58.54714025769915, 65.14126559666225, 6.749482716832842, 0.15596887362854822, 2.0240128551210677, 26.737670455660137, 3.0416288673877716, 14.792219741003853, 31.376692567552837, 23.43419633592878, 65.17400550842285, 50.56979186194283, 57.36464718409947, 49.28176954814366, 54.743407998766216, 48.55478647777012, 55.31990350995745, 53.29409367697579, 57.949525696890696, 48.81469079426357, 46.269871371132986, 39.18902472087315, 39.659869398389546, 38.83135230200631, 40.72207873208182, 39.12620258331299, 37.290578842163086, 37.347970962524414, 38.95701742172241, 37.12382207598005, 41.51721668243408, 39.79956293106079, 42.45682157788958, 41.34245559147426, 38.664991583142964, 39.60298797062465, 39.3094995362418, 39.03121723447527, 37.81061676570347, 36.449214526585166, 39.27517890930176, 36.85829666682652, 39.161555017743794, 39.622119835444856, 39.64226613725935, 38.05526283809117, 38.72073350633894, 39.45094401495797, 41.12791953768049, 39.23101963315691, 40.12488106318882, 39.29448447908674, 36.17315217426845, 38.98722471509661, 38.886350767953054, 39.45962231499808, 41.832991463797434, 37.451988969530376, 38.20294679914202, 39.51376962661743, 40.408860887799946, 41.33390235900879, 41.07073238917759, 41.9512254851205, 44.8553466796875, 53.36416973386492, 50.579015595572336, 52.23245062146868, 52.80491965157645, 50.551240171704976, 40.310509136744905, 43.454148633139475, 55.90815189906529, 52.453153201511924, 50.99939898082188, 48.853051798684255, 45.803261620657786, 39.03727953774588, 40.26015901565552, 39.72273669924055, 41.26446901048933, 38.59172977719988, 38.00056661878313, 38.75655494417463, 39.848488671439036, 37.523128100803916, 39.750286306653706, 37.81460850579398, 40.143293789454866, 40.98862900052752, 38.20523623057774, 38.068929944719585, 41.101408685956685, 40.079863684517996, 42.461963244846885, 40.86570494515555, 39.617186614445274, 40.738525118146626, 40.43045588902065, 40.3471018246242, 39.443148136138916, 38.265112331935335, 41.67196001325335, 41.68479333605085, 38.35860729217529, 38.611962931496755, 38.55516488211495, 41.57796130861555, 39.47022179194859, 40.24520649228777, 41.59286172049386, 40.40586274010794, 43.0409323147365, 40.532427651541575, 41.29266480037144, 42.4257527078901, 51.75871549333845, 54.0775134904044, 55.29269436427525, 51.37378181729998, 52.86971855163574, 54.33891861779349, 53.15857253755842, 55.59548643657139, 53.84495380946568, 52.030466488429475, 52.25828054973057, 56.70200790677752, 57.70106158937727, 61.56951631818499, 57.72087090356009, 62.31668390546526, 60.78959492274693, 52.75395808901106, 0.688083960541657, 12.577722021511622, 35.73049981253487, 2.701030343770981, 0.14777160063385963, 25.534304993493215, 70.65236827305385, 57.190973486219136, 60.14074434552874, 65.26845932006836, 44.04015622820173, 36.25222267423357, 49.947726590292795, 61.722154344831196, 72.80833176204136, 11.068832107952662, 0.41489333127226147, 0.1823392143206937, 0.13997087707476957, 0.2605302786188466, 0.23786164500883647, 0.10457736413393702, 0.1710537520370313, 0.19074390189988272], [0.046326805371791124, 0.03992178763395973, 0.035679851326027086, 0.05922272641743932, 0.006012080653038408, 0.037375788536987135, 0.0548237431794405, 0.21471206577760832, 0.136147997209004, 7.206291598933084, 53.5328928402492, 51.19878796168736, 46.25516898291451, 25.475231409072876, 16.702321222850255, 40.610608782087056, 34.19623681477138, 48.18382215499878, 49.39389610290527, 53.28853511810303, 4.858298139912741, 0.14412967248686723, 1.5739557764359882, 8.617691772324697, 0.0636164170822927, 21.948991094316753, 28.756651946476527, 27.82750756399972, 60.12479822976248, 47.61339936937605, 52.656825746808735, 41.54721552985055, 44.98973526273455, 43.93696158272879, 48.444125992911204, 47.896840708596365, 45.75978674207415, 37.49057579040527, 36.01377786908831, 34.86582776478359, 35.40708548682076, 33.329191957201274, 37.001398290906636, 33.78351729256766, 34.2246584211077, 33.94221414838518, 35.330238410404746, 35.532219069344656, 34.5227187701634, 35.50691720417568, 35.42610618046352, 34.499664647238596, 35.16376652036394, 33.80009569440569, 34.19689341953823, 34.22400181634085, 33.50183384759085, 33.03745794296265, 35.037806102207725, 36.95411579949515, 35.063816683632986, 35.095114844185964, 36.19434070587158, 34.66816193716866, 35.0982380594526, 34.99507120677403, 37.73665319170271, 35.9739716393607, 35.98728438786098, 35.286530767168315, 37.11714833123343, 37.057727336883545, 36.524925572531565, 37.535666125161306, 35.37529053006853, 35.79589973177229, 34.57643181937081, 35.87722839627947, 34.674057483673096, 34.05866595676967, 36.633984497615266, 36.799973487854004, 36.75480672291347, 46.659491607121055, 48.746546336582725, 48.28471694673811, 46.259820801871165, 50.86509377615792, 45.373043060302734, 42.13117340632847, 49.562032086508616, 43.587491512298584, 46.92472171783447, 39.51560395104544, 36.95489052363804, 36.056874070848735, 35.83328104019165, 35.76375389099121, 35.430455752781455, 35.92783212661743, 36.57193013599941, 36.21050568989345, 37.69898353304182, 37.02915634427752, 35.265015670231406, 33.87921135766165, 37.001457350594656, 34.68237100328718, 36.02104221071516, 37.34762007849557, 36.75902427945818, 37.27457019260952, 38.434766496930806, 37.46318251746041, 35.26295552934919, 36.916116101401194, 35.54037625449044, 35.65105063574654, 35.24870129993984, 35.96484170641218, 35.70048359462193, 36.753941672188894, 35.61433288029262, 34.32178381511143, 33.72345011574881, 34.950529779706685, 34.60287666320801, 34.445486068725586, 35.55632584435599, 35.77138648714338, 36.066521644592285, 37.645718642643516, 36.3288300377982, 39.47024263654436, 45.66035107203892, 50.744153431483674, 48.22822461809431, 43.43540586744036, 47.546717507498606, 48.23392908913748, 47.949688707079204, 48.32109424046108, 48.19800690242222, 53.59042739868164, 49.56633302143642, 54.98626143591744, 51.44657809393746, 55.623546736580984, 50.841046060834614, 58.0964731488909, 55.00316292898995, 63.353049414498464, 2.3015058849539076, 2.483199323926653, 7.078420426164355, 1.1961378157138824, 0.014754547205354487, 14.622091361454554, 58.93545423235212, 48.23218856539045, 56.98977449962071, 61.37194429125105, 40.845985957554404, 25.09925048691886, 40.74558448791504, 49.894336632319856, 54.39043256214687, 7.11134272813797, 0.021800181728654673, 0.058493063785135746, 0.02930202927174313, 0.026943891076371074, 0.05280200059392622, 0.046488629188388586, 0.014954211223604423, 0.050160253420472145, 0.00785115228167602, 0.024882527134780372, 0.0553008720411786, 0.11483513084905488, 0.06677477367754493, 0.10108227775033031, 0.0716036767033594, 0.191290570423007, 0.1480844867016588, 10.37930417060852, 60.93966906411307, 56.36732707704817, 52.480852195194785, 32.35202857426235, 24.94417016846793, 35.64472082683018, 37.180627073560444, 52.15087529591152, 52.79515743255615, 55.4567482812064, 5.238485327788761, 0.12478845247200557, 1.2653845399618149, 4.338465622493199, 0.07719899181808744, 24.62317728996277, 32.437074525015696, 31.28455945423671, 63.52962398529053, 51.067724091666086, 54.51871715273176, 43.44016538347517, 47.16959360667637, 46.17354849406651, 49.96903324127197, 48.77379022325788, 47.7736109324864, 40.05810192653111, 38.23120164871216, 36.37245430265154, 36.93774931771414, 35.99977377482823, 38.21580791473389, 35.36160952704293, 37.00140176500593, 35.84176826477051, 38.09883846555437, 36.535215854644775, 36.45736476353237, 37.200623989105225, 38.39419943945748, 37.13558885029384, 38.097692012786865, 34.61985806056431, 35.667646408081055, 36.42269672666277, 36.24392305101667, 35.715665408543174, 37.30765751429966, 36.35099131720406, 36.05181925637381, 35.49855852127075, 37.02329553876604, 35.90942634854998, 36.643732820238384, 36.38613530567714, 39.110249519348145, 38.39001314980643, 37.22741971697126, 35.307462215423584, 38.14376204354422, 38.29881804330008, 37.923966203417095, 38.06455257960728, 37.49947990689959, 36.65723317010062, 35.783702169145855, 36.48961482729231, 36.34483868735177, 35.7775217464992, 37.75989491598946, 37.79212760925293, 38.53920834405081, 49.21884666170393, 51.15624066761562, 50.32822731563023, 46.96495873587472, 51.94007042476109, 47.76323727199009, 44.802304131644114, 51.23228175299508, 46.11670528139387, 49.68737758908953, 41.20621183940342, 38.412219592503135, 36.845612730298726, 37.219422340393066, 38.1975793157305, 39.548277854919434, 36.4712507384164, 38.400077615465435, 38.638039520808626, 39.80229704720633, 40.12284871510097, 38.92860623768398, 35.91253219332014, 38.76248523167202, 36.267293316977366, 38.86430760792324, 38.74108130591256, 37.80378321238926, 39.40038892201015, 39.668624128614155, 38.20215470450265, 37.16197116034371, 37.65421281542097, 37.58817713601248, 37.352532454899375, 37.404508454459055, 38.057687759399414, 37.36781849179949, 38.91264622552054, 37.9417952810015, 36.94965158190046, 35.49071747916085, 37.307633195604595, 36.777523858206614, 36.573990276881624, 37.13040896824428, 39.05995150974819, 37.82316173825945, 39.27298675264631, 37.76600933074951, 42.65559911727905, 48.59404032570975, 51.78409031459263, 49.97713484082903, 46.011141300201416, 47.26342902864729, 50.13618605477469, 48.41901520320347, 48.701442105429514, 48.54183503559658, 53.764368602207725, 52.040492738996235, 56.42035572869437, 52.821786403656006, 57.98855025427682, 53.22100905009678, 60.55005577632359, 57.51385627474104, 64.16098594665527, 2.5457843542099, 1.720466251884188, 4.482357169900622, 0.5719764136842319, 0.06332516271088805, 14.968118599482946, 64.52413354601178, 52.207374572753906, 61.19593947274344, 59.09520026615688, 39.77781854357038, 32.94843414851597, 48.872319153376985, 54.279619216918945, 64.05724239349365, 10.278894884245735, 0.045927151638482294, 0.035742354579269886, 0.06464183955852475, 0.05132309959403106, 0.024837050021493008, 0.03783000327114548, 0.03372201995391931, 0.06705416047147342, 0.09244436411453144, 0.13681085806872162, 0.12991637230983802, 0.20157374148922308, 0.15890327974089555, 0.2108743531363351, 0.21296342675174984, 0.3968980668910912, 0.29251736934695927, 12.632772598947797, 70.05439240591866, 61.80731841496059, 58.18864795139858, 36.877706459590364, 25.61937526294163, 48.57857710974557, 45.585168089185444, 57.26163666588919, 58.45207500457764, 59.83792795453753, 6.188662341662815, 0.42293999663421084, 2.724186952625002, 19.95813591139657, 1.0902910211256571, 26.60563383783613, 34.982661724090576, 34.62792491912842, 65.36869403294155, 52.812892709459575, 58.072783265795024, 45.811568192073274, 49.66191591535296, 47.954201562064036, 52.00092274802071, 51.7618282863072, 50.78398397990635, 40.70084503718785, 40.351816177368164, 38.44147845676967, 39.51629877090454, 37.019328117370605, 40.28959853308541, 36.642242431640625, 37.399012429373606, 36.547152859824045, 39.820025375911165, 38.57486302512032, 38.884756156376426, 39.326053619384766, 40.08036742891584, 40.4512483733041, 39.65937607628958, 36.6541724886213, 39.18468904495239, 38.314927441733225, 38.53754425048828, 35.984268869672505, 41.15546219689505, 39.445923941476, 38.41039221627371, 37.61421203613281, 39.642203603472026, 38.50649275098528, 37.99379212515694, 37.78141001292637, 43.47365917478289, 40.2232015473502, 40.139923913138254, 36.37803370612008, 39.78046580723354, 40.587488651275635, 40.33120782034737, 41.50762816837856, 39.4915041242327, 39.51234524590628, 38.349553789411274, 40.488365650177, 37.981181144714355, 38.56420448848179, 41.06746326174055, 40.06245149884905, 41.563766138894216, 51.837921483176096, 51.54212972096035, 52.36351796558925, 49.50781181880406, 54.28148480824062, 51.48362936292376, 47.25326381410871, 53.7530951499939, 47.09801326479231, 51.08642169407436, 42.96579449517386, 41.368775367736816, 40.283515385219026, 39.86320148195539, 39.69828598839896, 41.64527893066406, 39.398085594177246, 41.64610229219709, 40.45683472497122, 42.366953577314106, 41.917172363826204, 40.20894384384155, 38.01270512172154, 40.74306229182652, 37.83404261725289, 40.13915613719395, 40.712858472551616, 39.634588377816335, 41.656566279275076, 41.72182376044137, 39.04927212851388, 38.39224699565342, 39.777999196733745, 38.63267551149641, 39.65416145324707, 38.36437777110508, 39.41563326971871, 39.65595061438424, 41.03748525891985, 40.046060698372976, 39.523066316332134, 37.59635516575405, 39.38252510343279, 38.51730762209211, 38.45676449366978, 40.35889291763306, 40.118700640542166, 40.92057139532906, 41.603982312338694, 40.06552260262625, 44.69942215510777, 50.787649154663086, 53.22840888159615, 52.62211602074759, 48.92683471952166, 49.01505599703108, 50.85779121943882, 48.51815210069929, 49.709368637629915, 50.292114053453716, 56.43067380360195, 54.29692023141043, 59.9264896937779, 55.280514172145296, 61.32803167615618, 56.234897886003765, 64.13497189113072, 58.87434482574463, 68.91434587751115, 3.6988209741456166, 5.6491833584649225, 18.795851673398698, 1.4970941522291727, 0.11470502854457923, 17.413021189825876, 71.00300911494664, 57.76019423348563, 70.71451990944999, 65.62312316894531, 50.13309758050101, 34.51453379222325, 54.75175625937325, 64.08553545815604, 74.30311856951032, 14.73543211391994, 0.2759328064109598, 0.14099566851343426, 0.15007411422474043, 0.09957742278597184, 0.1648337436573846, 0.13658705007817062, 0.15749758588416235, 0.16414026729762554], [0.03228428567360554, 0.11013143789023161, 0.05304302980325051, 0.022266508312895894, 0.026439770091591135, 0.03079047047400049, 0.06187243280666215, 0.11064643918403558, 0.09018284760947738, 9.081278187888008, 54.7033759525844, 49.48442070824759, 44.84966305324009, 27.075630835124425, 13.696170943123953, 28.400716577257427, 33.6913355418614, 49.768160820007324, 48.69181537628174, 51.47843211037772, 3.3376114879335677, 0.03684801042878202, 0.7971670957548278, 1.8974974496023995, 0.07260526902973652, 29.41271127973284, 51.46173906326294, 50.54187052590506, 57.48078632354736, 50.262434823172434, 48.43197359357561, 36.863969870976035, 39.96889747892107, 37.04299715587071, 39.1512508392334, 37.119614941733225, 37.076543058667866, 33.31515659604754, 36.03157915387835, 36.08517755780901, 37.343909740448, 35.53731904711042, 37.76273325511387, 34.873265811375205, 35.51528630937849, 33.96442753928048, 34.527926445007324, 34.47734703336443, 35.46111467906407, 34.94524914877755, 35.00655310494559, 33.731273787362234, 33.19448375701904, 35.327733584812705, 33.384398869105745, 35.17457791737148, 34.38838924680437, 33.802704742976594, 34.556799684252056, 34.96433585030692, 34.8167074748448, 33.928856236594065, 35.937497070857454, 35.58994470323835, 35.19037117276873, 33.81510727746146, 36.67486422402518, 36.22014284133911, 36.576144218444824, 34.85687848499843, 37.55490568705967, 35.40948608943394, 37.12168550491333, 36.19375705718994, 35.24878120422363, 34.28963450023106, 35.358493259974885, 34.450672898973735, 34.15912996019636, 34.94410269601004, 36.1558198928833, 35.13626902444022, 35.189759731292725, 38.24608816419329, 40.295785903930664, 42.010406766619, 43.65901626859392, 47.53157043457031, 44.66536555971418, 43.88636132649013, 51.007747241428916, 46.43421016420637, 40.75092765263149, 37.338625635419575, 37.03076137815203, 36.40172358921596, 36.39939941678728, 35.104078020368306, 36.22654560634068, 36.53845371518816, 40.238768986293245, 37.96086113793509, 39.57183919634138, 38.710081917899, 37.40413325173514, 33.810938358306885, 35.79331152779715, 35.82213612965175, 35.48037508555821, 35.94945839473179, 37.381259781973704, 37.583341189793174, 35.76362187521798, 35.726341315678184, 36.765708446502686, 35.809257643563406, 34.84987817491804, 35.58650881903512, 37.43533761160714, 36.91680744716099, 36.25286538260323, 37.02558497020176, 36.912016664232524, 35.06720393044608, 35.433783939906526, 34.780201639447895, 34.75778327669416, 34.240469047001426, 35.09572628566197, 35.34482615334647, 36.40105308805193, 36.80361434391567, 36.78694908959525, 44.405256271362305, 47.75204719815935, 50.70810965129307, 40.1294390814645, 47.91540976933071, 48.86599629265921, 49.9429601260594, 47.190844672066824, 49.23197528294155, 50.26783357347761, 54.42826202937535, 52.95596654074532, 54.196362427302766, 49.85252584729876, 54.34147902897426, 52.13945940562657, 58.78264944893973, 52.823422704424175, 69.42656012943813, 10.402739575931005, 1.7661176536764418, 1.0919972381421497, 1.114439268197332, 0.0647304223052093, 12.018175772258214, 58.976386070251465, 52.70147487095424, 44.496281147003174, 48.87540415355137, 52.3114446912493, 18.024650267192296, 33.007400035858154, 48.31273903165545, 60.21996075766427, 15.529541730880737, 0.05972157179244927, 0.08060865742819649, 0.050250610536230464, 0.061367331338780265, 0.027956538434539522, 0.09821000508964062, 0.033384072195206366, 0.0459353822682585, 0.027425298101401756, 0.05559206195175648, 0.012627713116151946, 0.025258420268073678, 0.0313125760294497, 0.08256615631814514, 0.0310244598825063, 0.13669626707477228, 0.07962572481483221, 11.546809111322675, 63.327855246407644, 55.236737046922954, 51.349518707820344, 35.692531381334575, 20.01331329345703, 26.64497106415885, 38.56407594680786, 51.7851116997855, 54.197880608694895, 54.54283435004098, 4.137893710817609, 0.20265642553567886, 0.8362524498786245, 3.6841980559485297, 0.20640159957110882, 32.48654569898333, 54.111149719783235, 51.54988391058785, 58.07793535505022, 51.37144374847412, 52.35837629863194, 39.37266213553292, 41.82700211661202, 39.10677889415196, 41.63683339527675, 38.68361275536673, 39.4041166305542, 34.63787126541138, 37.19286979947771, 36.93991368157523, 39.6888816016061, 37.4395933832441, 40.30146953037807, 37.497273853846956, 37.2778879574367, 36.00290393829346, 36.28920098713466, 36.933431012289866, 37.35865729195731, 36.675968987601145, 35.98104837962559, 35.72833892277309, 35.68330069950649, 35.97036899839129, 36.45105927331107, 36.36254964556013, 35.41003499712263, 35.32162959235055, 36.41436236245291, 36.28321858814785, 36.5392701285226, 35.565361976623535, 36.81113576889038, 36.627105781010215, 37.06016615458897, 35.84102133342198, 37.29172529493059, 37.44235529218401, 37.90280546460833, 37.33253901345389, 38.595454011644634, 38.23067705971854, 37.943619183131624, 37.34542097364153, 36.67229339054653, 36.02445377622332, 36.035386766706196, 36.3122273172651, 36.12597043173653, 36.83293921606881, 38.063270636967246, 37.05631685256958, 36.328072684151785, 40.06943096433367, 42.926662240709575, 44.005849497658865, 45.2265750340053, 50.12911626270839, 46.682945251464844, 47.14038337979998, 51.42752960750035, 48.63019527707781, 42.64900875091553, 40.15214926855904, 38.520851203373496, 38.91804844992501, 37.51994582584926, 36.30527564457485, 38.471150738852366, 37.64314086096627, 41.713121141706196, 39.783787046160015, 41.382803780691965, 40.64050688062395, 39.18495307649885, 36.456795011247905, 36.99913317816598, 37.29268414633614, 37.51466866901943, 37.95969384057181, 39.10324573516846, 39.5911864553179, 36.913844040461946, 38.31237050465175, 38.10987567901611, 37.29274320602417, 35.467698097229004, 37.95727934156145, 38.67381579535348, 37.65325396401541, 37.12967593329293, 38.19798925944737, 38.82761417116438, 37.757230281829834, 36.855069228581016, 37.67749275479998, 38.13989537102835, 37.483947208949495, 37.35356426239014, 37.70306559971401, 37.776636600494385, 37.4458224432809, 37.021454266139436, 46.559764112745015, 48.770128522600444, 51.766334193093435, 45.54663685389927, 48.28673539842878, 50.74013042449951, 49.920371532440186, 49.699078355516704, 51.31851931980678, 51.41720805849348, 57.50416006360735, 54.27787869317191, 57.012856415339876, 51.23285845347813, 55.6397499356951, 53.79790408270699, 61.698836190359934, 53.81985691615513, 70.64944308144706, 10.990091647420611, 1.067646624786513, 2.1698822506836484, 1.0690940214054925, 0.06221715573753629, 12.304896661213466, 65.77956880841936, 57.184813908168245, 53.4556427683149, 53.576874937329976, 58.625001771109446, 26.20282939502171, 38.271021774836946, 54.306015423366, 67.33693804059709, 21.21086311340332, 0.05671117315068841, 0.027775618946179748, 0.06218720520181315, 0.07129801703350884, 0.039931955481214185, 0.08169612514653377, 0.020399473407971006, 0.04178606938304646, 0.08718762440340859, 0.14370682303394589, 0.11928911613566534, 0.09721190721860953, 0.14353685001177446, 0.30330002361110275, 0.11557358050984995, 0.28230359884245054, 0.28547325304576326, 15.313979080745153, 72.3100278036935, 61.63142476763044, 59.3075441632952, 38.43069832665579, 21.44519805908203, 36.57607126235962, 48.1985627583095, 59.09325477055141, 58.18534060886928, 59.96465614863804, 4.883043280669621, 0.258346970060042, 2.4817197918891907, 5.605922136987958, 0.31535476818680763, 34.50261068344116, 55.22388635362898, 54.05255208696638, 61.69838455745152, 54.93247890472412, 55.00959348678589, 40.614225319453645, 43.536488260541645, 40.379334517887656, 43.6461968421936, 40.595051765441895, 41.63348436355591, 35.66017014639718, 39.42593050003052, 38.893761021750315, 41.975537231990266, 39.9707213810512, 43.57767718178885, 39.19809212003435, 39.1516295160566, 37.98269585200718, 39.628369740077424, 39.56576647077288, 41.13585785457066, 38.28392457962036, 38.11904730115618, 36.94858850751604, 37.20546340942383, 39.811864716666086, 37.99310425349644, 39.166484764644075, 36.794098785945344, 35.72696665355137, 39.0119047164917, 38.046018259865896, 38.379781927381245, 37.976678712027415, 38.13920749936785, 38.77635383605957, 38.980748994009836, 37.202097007206504, 39.633334227970664, 39.81888934544155, 39.72022145135062, 39.65516199384417, 40.13283327647618, 38.907702582223074, 41.328986508505686, 39.74519675118582, 40.1498806817191, 38.53712388447353, 38.235544272831504, 39.78099387032645, 37.95072719029018, 37.7185183933803, 39.74754524230957, 39.29669748033796, 39.67482886995588, 41.74264751161848, 44.770054067884175, 46.25806638172695, 46.23348018101284, 52.829210553850444, 49.61060346875872, 49.69443001065935, 54.261765820639475, 51.21776001793997, 43.952546392168315, 41.55079732622419, 40.126871722085134, 41.74804973602295, 40.8015695980617, 38.22250597817557, 40.364944798605784, 38.85993371691023, 46.659946714128765, 42.168992451259065, 44.16471311024257, 43.08117628097534, 41.98006745747158, 37.92566851207188, 39.53711209978376, 39.036897386823384, 39.24012177331107, 39.34924670628139, 40.48636456898281, 40.605505330221995, 39.4182562146868, 40.99637276785714, 41.00445352281843, 38.83708456584385, 37.4860976764134, 39.15299483707973, 42.266072681971956, 39.59517124720982, 40.32221337727138, 41.35573707308088, 40.20493820735386, 40.238838468279155, 39.29419265474592, 38.72118861334664, 40.95294305256435, 39.54692643029349, 39.21106440680367, 40.05985982077462, 40.0686423437936, 41.86961889266968, 40.18702575138637, 49.15234892708914, 52.30224527631487, 54.510858740125386, 46.72008337293352, 49.32563699994768, 51.87988860266549, 52.25614397866385, 50.36141191210066, 52.50640766961234, 53.570416586739675, 58.65833922794887, 57.5175770350865, 57.90989664622715, 53.17779125486101, 58.68656281062535, 55.531337193080354, 64.51730346679688, 56.64465052740914, 73.08465467180524, 12.94345782484327, 2.3095690522875105, 5.195416918822697, 2.379061894757407, 0.2442814548100744, 14.97112716947283, 72.47459588732038, 62.688294410705566, 58.061079025268555, 60.20627975463867, 59.261269160679404, 28.77266580717904, 46.63034738813128, 61.60869721003941, 78.59388133457729, 28.405965941292898, 0.2447760525558676, 0.16839157417416573, 0.18712608888745308, 0.15822231556688035, 0.12011105274515492, 0.24036723056009837, 0.15945343593401567, 0.11776709423533507], [0.11333516133683068, 0.03317697652216468, 0.012044345178375286, 0.011147892701306512, 0.05825509476874556, 0.04664699247639094, 0.04670743637585214, 0.05341571176956807, 0.09418658419911351, 14.078376582690648, 58.704808780125205, 43.86666318348476, 34.15888329914638, 17.93115704400199, 34.48570224217006, 42.90465382167271, 39.80124092102051, 48.26939269474575, 49.96465240206037, 48.773474080221995, 3.3382804691791534, 0.3194521154676165, 0.4355008469096252, 1.7540523239544459, 0.1738118068980319, 40.46047905513218, 56.48998710087368, 51.24831124714443, 53.08815254483904, 48.375766141074045, 41.960435322352815, 38.83271067483084, 38.69906554903303, 37.729743208204, 38.01737083707537, 37.868408407483784, 38.471793447222026, 40.089424405779155, 36.43559953144619, 38.299432958875386, 40.08110393796648, 39.879390784672324, 40.84834139687674, 40.57254307610648, 37.788959230695454, 37.79290928159441, 37.151257038116455, 34.18078749520438, 34.257276739392964, 33.99441596439907, 34.59162752968924, 32.58245168413435, 33.57293823787144, 33.80539716993059, 35.29120690482003, 35.041530336652485, 35.00241197858538, 33.66030836105347, 35.89521380833217, 34.92620413643973, 32.88199199948992, 34.34134994234358, 34.982679094587056, 34.738498551504954, 33.752472741263254, 33.75713150841849, 36.60948862348284, 34.741097177777974, 35.80028404508318, 35.04530668258667, 35.943020888737266, 37.78368902206421, 36.28994444438389, 34.31330353873116, 33.37058585030692, 33.183113030024934, 34.39262069974627, 34.594410283224924, 33.731419699532644, 34.84478514535086, 34.79972607748849, 33.85801935195923, 35.99603911808559, 37.10861941746303, 37.40403250285557, 42.27394846507481, 44.87004559380667, 48.82361922945295, 45.15857648849487, 44.21084567478725, 47.87109068461827, 45.02701234817505, 41.110882554735454, 37.42247649601528, 36.208362170628135, 35.90701184953962, 37.00717224393572, 35.67511919566563, 36.38157033920288, 37.20723867416382, 39.093921252659385, 40.30108390535627, 41.382418155670166, 40.44934804098946, 36.7826828956604, 34.722861630576, 35.42200326919556, 37.12306819643293, 36.598878724234446, 37.52771043777466, 36.845449447631836, 37.800184045519146, 35.17341409410749, 36.008851596287315, 36.24555240358625, 36.0956380707877, 35.40167284011841, 33.772813592638286, 36.870667934417725, 35.22359051023211, 36.48789167404175, 35.62583909715925, 35.78108269827706, 35.16540282113211, 35.56602552958897, 34.652215821402415, 33.553229672568186, 34.85416521344866, 34.14601523535592, 34.981417996542795, 34.3397935458592, 36.52485956464495, 38.27889060974121, 43.39481449127197, 46.66985484531948, 46.66680806023734, 44.10506282533918, 51.37543896266392, 48.53072486604963, 51.2983660697937, 50.25462852205549, 52.31588806424822, 49.40449210575649, 53.614784308842246, 49.39289208820888, 52.01666389192854, 43.64895180293492, 48.055214473179404, 41.95375462940761, 57.16359063557216, 51.71374327795846, 71.21397032056535, 20.31770518847874, 0.30779165402054787, 1.0272056119782584, 0.4026650445801871, 0.10167619266680308, 9.893437487738472, 60.267458643232075, 54.53283589226859, 50.53058317729405, 45.97714376449585, 33.6168578011649, 13.399022545133318, 40.5889755657741, 46.846123695373535, 54.69656324386597, 19.225443158830913, 0.39131893483655794, 0.09651679558945553, 0.03943387685077531, 0.019478535146585534, 0.03771656917940293, 0.03356351756623813, 0.02802582534163126, 0.029641242498265843, 0.08877977289791618, 0.041680119532559595, 0.03498539787584117, 0.020113197787265693, 0.053034314020935974, 0.023124193539842963, 0.0737859538889357, 0.08414277314607586, 0.12799668817647866, 16.651437827519008, 65.70688370295933, 51.117705958230154, 42.13359137943813, 24.496977158955165, 27.989952972957067, 38.026191575186594, 42.79088054384504, 52.5169654573713, 54.678647313799175, 53.44651978356497, 3.972239536898477, 0.25620613779340473, 0.4686073032873017, 1.5496850673641478, 0.27118194848299026, 42.841751779828755, 58.700994219098774, 53.470095021384104, 55.13516827992031, 51.595182691301616, 44.056401116507395, 39.46941927501133, 40.38891608374459, 39.37281847000122, 39.77737733295986, 38.36656992776053, 40.007609367370605, 41.28088065556118, 39.496680532182964, 40.04175628934588, 43.56614664622715, 41.60146706444876, 42.052335671016145, 41.949099336351665, 39.10662950788225, 38.272675446101594, 37.43964549473354, 35.120607784816194, 36.20981087003435, 35.869213649204795, 36.57053354808262, 35.56274945395333, 35.435062408447266, 35.378587450299946, 36.487638064793174, 34.844111170087544, 36.416328702654155, 34.891970361982075, 36.92557954788208, 35.482876437050955, 34.68194716317313, 35.12441192354475, 36.820828505924766, 35.73722914287022, 33.9246768951416, 35.27896417890276, 37.58397694996425, 36.78928368432181, 37.58990028926304, 36.50106198447091, 38.737958090645925, 39.253601278577534, 37.89998797007969, 35.785487856183735, 36.486842496054514, 35.96612017495291, 36.332130432128906, 35.19386264256069, 36.142583574567524, 35.82061447416033, 36.801707063402446, 35.176572050367085, 38.65603535515921, 38.346430574144634, 39.9777946472168, 44.2556129183088, 45.778202942439485, 50.199928828648154, 47.674564361572266, 45.73208427429199, 47.94652727672032, 47.490332875932964, 43.27356147766113, 38.76806810923985, 39.3576158114842, 38.225250516619, 39.689718859536306, 38.45090021405901, 38.07282093593052, 38.833408968789236, 42.15066657747541, 42.132385866982595, 43.75579425266811, 41.65092086791992, 38.682803290230886, 35.92855473927089, 37.42181641714913, 38.0659179006304, 38.691231455121724, 38.50156995228359, 37.63363919939314, 38.16539525985718, 37.35349825450352, 38.79141058240618, 38.337158203125, 36.97911194392613, 37.94876779828753, 35.04022060121809, 38.301128319331575, 38.2785918372018, 37.15826777049473, 37.2306923185076, 37.88558782849993, 37.653882775987896, 36.5510299546378, 36.14822203772408, 36.207695143563406, 36.84758254459926, 36.09777464185442, 37.14518083844866, 36.725155285426546, 38.34667028699602, 39.42825814655849, 45.58889927182879, 49.93116903305054, 48.23216077259609, 46.55829456874302, 53.62853479385376, 51.78397566931588, 53.21279280526297, 52.20036036627633, 53.74020276750837, 52.13240698405674, 55.86375291006905, 51.979932240077424, 54.18702057429722, 45.591581276484895, 49.17092841012137, 45.04891307013375, 58.44330637795584, 53.534654208592, 72.46694592067173, 22.447374956948416, 0.7460969675864492, 2.165559385504041, 0.6650662070938519, 0.08084501831659249, 10.600341132708959, 64.89021328517369, 57.983328683035715, 56.19382013593401, 53.04356942858015, 40.56162745612008, 17.21698992592948, 45.99057810647147, 51.255019732883994, 63.59092099325997, 23.732482501438685, 0.3173784581678254, 0.028466067343418087, 0.11822012492588588, 0.060203603069697104, 0.03248207523886647, 0.03106518555432558, 0.03218040196225047, 0.06755880732089281, 0.18122605048120022, 0.12270226941577025, 0.1419364573167903, 0.15005538665822574, 0.16627625482422964, 0.12381012711141791, 0.19612268970480987, 0.1876621858349868, 0.20245460207973207, 20.10110204560416, 77.60534722464425, 56.29638596943447, 49.84214176450457, 25.92435428074428, 43.362032890319824, 51.15816879272461, 49.7403541292463, 58.75709397452218, 58.53305625915527, 59.141794885907856, 4.984506956168583, 0.45295730020318714, 1.9389879660946983, 7.0765118428639004, 0.26208862928407534, 44.96208143234253, 58.25383595057896, 56.92463861192976, 57.394795417785645, 53.950194699423655, 45.87821183885847, 42.277443408966064, 41.698748792920796, 42.34980889729091, 42.35301896503994, 40.47108200618199, 42.688154901777, 44.10699095044817, 39.35867541176932, 42.56621749060494, 45.61513566970825, 44.97551577431815, 44.39404535293579, 44.36049945013863, 42.65469585146223, 41.501364367348806, 41.29845264979771, 37.27557420730591, 38.21327877044678, 38.51345484597342, 38.475496837071006, 37.71330029623849, 37.78244529451643, 36.84856571469988, 39.06207071031843, 37.778154781886506, 38.67265544618879, 36.86785738808768, 39.17016383579799, 37.29992764336722, 35.846260275159565, 37.222552503858296, 38.53050919941494, 38.193768228803364, 36.654933316367014, 37.02400425502232, 39.69430119650704, 39.688690526144846, 40.496015616825645, 38.95875447137015, 39.708652700696675, 41.09550966535296, 38.53770405905587, 37.53800766808646, 37.947694301605225, 37.87637799126761, 37.80305017743792, 37.64243909290859, 37.89626373563494, 37.98313358851841, 38.066616194588796, 37.80391870226179, 40.50951944078718, 41.710084778921946, 40.6064989226205, 45.44635697773525, 48.77552727290562, 52.19246373857771, 49.280953134809224, 48.46850722176688, 50.589622020721436, 50.200050422123496, 44.93260369982038, 41.99924101148333, 40.85812793459211, 40.843630518232075, 42.971082074301584, 40.364618233272004, 40.034422465733115, 39.89685508183071, 43.529213496616904, 44.2865115574428, 46.591037954602925, 43.7689437185015, 40.45645604814802, 37.77720635277884, 38.44376788820539, 40.490759304591585, 40.06350415093558, 39.977534089769634, 40.170975412641255, 41.24955470221383, 39.26417991093227, 39.55109882354736, 39.86066191537039, 39.81864963259016, 40.20911060060774, 37.506844997406006, 40.59811592102051, 38.610736574445454, 39.16887494495937, 39.050331728799, 40.55934149878365, 38.20111247471401, 39.22886916569301, 39.3012033871242, 38.73002324785505, 38.30703428813389, 38.08485868998936, 39.9231470652989, 38.603955132620676, 40.121900285993306, 42.340411458696636, 48.06506354468209, 51.176248005458284, 52.072374548230854, 48.49199908120291, 55.520887102399556, 51.85587910243443, 56.226035458701, 54.379965100969585, 55.51208026068551, 54.44134201322283, 58.85364614214216, 55.162742206028526, 56.58916221346174, 47.16971867425101, 50.63126604897635, 49.02225433077131, 61.84879221235003, 56.18256752831595, 74.82981286730084, 25.9219172000885, 0.8485771428261484, 8.696558168956212, 0.703130556004388, 0.12873977901680128, 12.655739000865392, 71.28032561710903, 61.81292561122349, 63.812929834638325, 57.76396710532052, 39.41613354001726, 22.470378705433436, 56.50867428098406, 59.97077751159668, 74.55230181557792, 30.821187564304896, 0.6789968024407114, 0.13804965945226805, 0.22221609311444418, 0.1794735709471362, 0.13257304046835217, 0.12851027133209364, 0.10545467598629849, 0.10607115897749152], [0.04500561287360532, 0.008160947622465236, 0.008580980306890394, 0.0037314913767789093, 0.08226817766470568, 0.017255011513563137, 0.042049917725047896, 0.046511580635394366, 0.04480672408161419, 16.085857936314174, 58.70984622410366, 43.78878429957798, 42.421514306749614, 21.501777240208217, 51.93138517652239, 69.1242092677525, 39.343847955976216, 44.12442398071289, 50.54333312170846, 46.65850496292114, 3.2127063274383545, 0.27837203123739784, 0.2933882826140949, 2.5605475391660417, 0.834956013730594, 54.6244409424918, 56.47721978596279, 50.526112011500764, 50.88925961085728, 43.91159718377249, 40.604734080178396, 41.14890309742519, 41.65630224772862, 43.351958002362935, 45.270963600703645, 43.69377810614449, 43.08894436700003, 42.34885004588536, 41.42234945297241, 40.984494822365896, 42.01753561837332, 42.198595251355854, 39.57045997892107, 40.31122132710048, 39.55595908846174, 37.81281239645821, 35.92077275684902, 34.91804347719465, 33.64472007751465, 34.27099595751081, 34.35963412693569, 34.71346071788243, 33.22307212012154, 33.84132283074515, 34.55470827647618, 34.957484926496235, 35.76475443158831, 33.74675784792219, 34.00304215294974, 34.1242048399789, 32.85202441896711, 34.19717482158116, 34.4868278503418, 33.34517976215908, 33.80410827909197, 34.26902266911098, 35.61014659064156, 35.33897924423218, 35.59120232718331, 34.89981835229056, 34.785002844674246, 35.6275691986084, 36.24641745431082, 33.57115602493286, 34.411200182778494, 33.36867509569441, 34.431686946323936, 33.28981304168701, 33.01943778991699, 34.23605694089617, 32.64989784785679, 33.23283086504255, 34.69189350945609, 35.15140914916992, 41.113609722682405, 47.61629329408918, 46.69208213261196, 47.74115242276873, 43.52592352458409, 44.75630010877337, 49.77311488560268, 45.15928520475115, 42.10620158059256, 38.40546941757202, 36.89482682091849, 35.81234959193638, 36.19952753611973, 35.63336399623326, 35.699656758989605, 37.85365390777588, 39.87585415158953, 38.20097351074219, 37.726283005305696, 39.6076397895813, 37.88826635905674, 35.515195982796804, 35.18150874546596, 36.7642354284014, 36.769582067217144, 35.374519280024934, 37.89041682652065, 37.78442900521414, 35.462570326668875, 35.78504317147391, 36.50833674839565, 36.288773672921316, 36.74366876057216, 35.32067421504429, 34.70277091435024, 36.272549629211426, 36.67326266424996, 35.29935366766793, 35.79683773858206, 35.56025505065918, 35.40228080749512, 34.58903585161482, 35.1820889200483, 35.33775636128017, 34.96094512939453, 35.465537207467214, 36.22243227277483, 34.799166747501914, 35.90296104976109, 43.35967745099749, 46.009664808000835, 46.442488942827495, 48.082211698804585, 48.60993432998657, 49.22723661150251, 50.27074834278652, 47.532060282570974, 48.991977555411204, 46.997990471976145, 46.28619268962315, 41.763283661433626, 42.299524784088135, 39.457767145974294, 44.34673854282924, 46.004974773951936, 57.865084239414756, 53.33992746898106, 66.56030314309257, 34.544202600206646, 0.37339266389608383, 1.150750771164894, 0.4523767727826323, 0.1490628392036472, 9.642302666391645, 59.22005244663784, 52.008437224796836, 52.604241779872346, 36.04651778084891, 53.41348457336426, 33.27228273664202, 35.881967067718506, 46.50960854121617, 53.2702648299081, 20.627709490912302, 0.3133802312825407, 0.12382628981556211, 0.07096411673618214, 0.0011039539988684866, 0.024495750299787948, 0.008985621272586286, 0.05956360884010792, 0.06463454530707427, 0.020142559693860154, 0.10450210781501872, 0.06373541855386325, 0.04099234625963228, 0.036852838205439706, 0.03561545156740716, 0.019069275053750192, 0.05417153871219073, 0.0907924095434802, 19.64659432002476, 66.35065514700753, 48.50479071480887, 49.537953104291645, 24.98578987802778, 48.87356635502407, 69.21753747122628, 41.97803510938372, 49.61339317049299, 53.63147735595703, 52.4620885848999, 3.2920688688755035, 0.1625476370432547, 0.7262706628867558, 1.5593317725828715, 1.1150289965527398, 54.98788384028843, 58.769774436950684, 53.230882440294536, 53.06701612472534, 45.49322952542986, 42.13389362607683, 43.30067682266235, 44.08555575779506, 45.641601358141216, 47.12613957268851, 45.87292078563145, 45.44395637512207, 43.57919536318098, 43.7637951033456, 42.237182072230745, 43.57860129220145, 43.734393801007954, 42.51658303397042, 42.73671586172921, 41.175945486341206, 39.34074558530535, 37.507890701293945, 36.363720417022705, 36.62153679983956, 36.078086921146934, 35.90129695619856, 35.22763783591134, 35.53681182861328, 35.787992681775776, 35.85081481933594, 37.103227615356445, 36.43613106863839, 36.37774188177926, 36.39174945013863, 35.173810141427175, 34.93865530831473, 35.6581586429051, 35.60531064442226, 34.91364874158587, 36.67251573290144, 35.0947049004691, 37.039512634277344, 37.03149093900408, 37.301324231284006, 37.466378688812256, 36.763179302215576, 36.24718870435442, 37.65191643578665, 35.50555535725185, 36.22332164219448, 34.77645308630807, 37.29755483354841, 36.2066980770656, 35.48914023808071, 36.81556871959141, 35.240300927843364, 35.76566811970302, 36.49718836375645, 37.35571820395333, 43.93376888547625, 48.97672973360334, 49.2513746534075, 51.27817807878767, 45.98973390034267, 45.39514528002058, 49.73362479891096, 45.74832221439907, 42.978575706481934, 39.6539808000837, 38.52492979594639, 36.69217218671526, 38.03280973434448, 37.680723667144775, 38.225024700164795, 39.37649754115513, 41.9825827053615, 39.68550477709089, 40.22367055075509, 40.6785934312003, 39.88773557118007, 36.987505367824006, 36.94489901406424, 37.06192752293178, 39.387451376233784, 37.56283358165196, 38.412744181496755, 37.84905767440796, 37.36778027670724, 36.8438583101545, 38.08125952311924, 36.52407789230347, 38.00877244131905, 37.607628617967876, 37.362162658146445, 38.27285262516567, 38.0098876271929, 37.034968512398855, 39.10117517198835, 37.174272945949006, 36.97532170159476, 36.69948516573225, 36.633793422154014, 37.05969020298549, 36.66115195410592, 37.42163923808506, 38.70175102778843, 37.37304353713989, 37.23335000446865, 44.65476608276367, 47.28968627112252, 48.6115254674639, 49.457062176295686, 51.44619246891567, 51.2451810836792, 51.33921800340925, 49.660772936684744, 51.87209619794573, 49.25122874123709, 49.052364349365234, 44.462186336517334, 45.7162423815046, 41.09749337605068, 46.92150122778756, 48.82632555280413, 60.632246017456055, 55.174491609845845, 67.9187593460083, 35.73208400181362, 0.10459114518016577, 1.8458356388977595, 1.4097825459071567, 0.10810618049332074, 10.579478297914777, 64.22663947514125, 58.2528076171875, 57.05545929500035, 44.49244574138096, 53.39280673435756, 31.57814516339983, 44.171494552067344, 49.45959826878139, 64.7161192212786, 25.755989006587438, 0.47718501729624613, 0.06490772350558213, 0.07471463084220886, 0.022107770134295737, 0.07746367475816182, 0.014156175161977964, 0.057123929395207336, 0.03268453312505569, 0.09676770426865135, 0.09812463859894446, 0.10493314040026494, 0.11234424915164709, 0.16226362942584924, 0.18765979739172117, 0.07214525621384382, 0.14940923133066722, 0.20645128190517426, 23.654287474496023, 74.88988004411969, 55.6787223815918, 56.74300922666277, 31.053695133754186, 61.35420554024832, 73.85215963636125, 48.42383030482701, 54.727038042885916, 58.10241385868618, 56.6482948575701, 4.0698191693850925, 0.4612937271595001, 3.2250118042741502, 7.318898013659886, 1.4985666275024414, 57.88913542883736, 58.87397657121931, 56.4508444241115, 54.42601081303188, 47.98239040374756, 45.152840750558035, 46.21003695896694, 45.67068304334368, 48.50094836098807, 49.53359310967581, 49.228567191532676, 46.501340184892925, 46.76276963097708, 45.781103815351216, 44.34996945517403, 47.302040168217246, 46.505627223423545, 44.334905760628835, 44.176796027592246, 44.79326452527727, 42.123426164899556, 39.73666088921683, 40.49206904002598, 39.88615485600063, 40.01261554445539, 37.66114016941616, 38.48064545222691, 37.8982127053397, 38.06539331163679, 37.77707086290632, 39.739103181021555, 38.65941912787301, 37.444450174059185, 37.41578190667288, 36.8252614566258, 36.721406732286724, 38.200028555733816, 38.04922832761492, 37.75612551825387, 36.24077204295567, 37.15795162745884, 41.054536138262065, 38.255346638815745, 39.41468136651175, 39.763164792742046, 37.08324807030814, 37.87251826695034, 39.19135584150042, 36.571909291403635, 38.28692620141165, 37.4084654535566, 39.25287519182478, 38.45397479193551, 36.80626508167812, 36.388278824942454, 36.25670773642403, 37.657165799822124, 39.01321792602539, 39.21139792033604, 45.54109219142369, 53.39442219052996, 51.01724195480347, 53.25910949707031, 47.12147733143398, 48.8376441683088, 52.27098880495344, 47.172949586595806, 45.84342915671212, 41.625087465558735, 41.644139426095144, 39.083109855651855, 41.01345491409302, 39.32084594454084, 40.74242653165545, 41.208049637930735, 44.66188451222011, 42.07866586957659, 41.888788972582134, 43.73126016344343, 42.03932864325387, 39.473032338278635, 40.315028939928325, 41.64916297367641, 42.18356629780361, 37.86418390274048, 41.2705591065543, 40.89467198508126, 38.48860113961356, 38.71737057822091, 39.93834277561733, 39.66108880724226, 40.99559804371425, 39.119115420750205, 38.29179688862392, 40.84180314200265, 40.82005875451224, 39.95122820990426, 41.74992227554321, 38.57501935958862, 39.475022997174946, 39.24296358653477, 40.96639823913574, 39.39423976625715, 40.396871771131245, 39.03386797223772, 41.23085709980556, 37.728836468287874, 39.41758223942348, 47.443272726876394, 51.56938402993338, 49.32499429157802, 52.57559435708182, 51.958806242261616, 54.50970881325858, 53.68956429617745, 52.120893818991526, 53.02733496257237, 52.51754910605294, 51.26353475025722, 46.020281655447825, 47.95120688847133, 42.95980167388916, 49.506387438092915, 51.79849740437099, 63.22676590510777, 58.42932660239083, 68.59768172672817, 39.25277444294521, 0.4602207733052117, 6.452866290296827, 2.0228633625166754, 0.2946795347545828, 12.925818085670471, 70.40731920514787, 62.803071703229634, 64.26703630174909, 51.92430148805891, 62.96711867196219, 43.352583340236116, 50.612009116581504, 59.89629282270159, 73.9465022768293, 35.5773788860866, 0.802021606692246, 0.2908882610499859, 0.13834745490125247, 0.11462839479957308, 0.2032435890287161, 0.15542274793343885, 0.19074781026159013, 0.17866302015525953], [0.035190061000841, 0.010483819808411812, 0.0786700150264161, 0.05617640952446631, 0.027192343458799378, 0.09073566365987062, 0.08062057250312396, 0.24250876850315503, 0.051457625946828296, 20.97172348839896, 54.71650457382202, 47.56319863455636, 35.36311728613717, 22.069896697998047, 49.938165869031636, 66.08277429853166, 40.00546932220459, 40.60663093839373, 53.47994409288679, 45.68687234606062, 3.3641160428524017, 0.4506724828055927, 0.2855715863406658, 1.225090850676809, 7.001076119286673, 59.96363476344517, 51.92942925861904, 53.98602655955723, 46.728883266448975, 44.08671610695975, 45.17567253112793, 47.4713955606733, 49.951850346156526, 47.50292648587908, 48.780960764203755, 48.49164124897548, 47.51061119352068, 45.58582121985299, 44.23038400922503, 45.37713207517351, 43.525673389434814, 42.1649729183742, 42.36230870655605, 40.68439865112305, 39.81825705936977, 36.85824802943638, 36.95673527036394, 34.85217455455235, 33.88861921855381, 32.87630489894322, 32.832166467394146, 31.311761651720317, 33.41730901173183, 33.800047057015554, 33.402398177555625, 34.35417284284319, 34.716726371220176, 33.000882625579834, 34.346168518066406, 31.947963033403667, 34.028441292899, 33.22998210362026, 33.49213068825858, 33.97099706104824, 34.742379120418, 33.27385650362287, 35.54300267355782, 35.79979419708252, 35.43336704799107, 34.6654451915196, 35.09100151062012, 35.9366910798209, 35.37805243900844, 35.038382802690776, 33.08940267562866, 35.01609992980957, 34.91652529580252, 34.98749419621059, 34.86455971854073, 34.43506724493844, 34.224922452654155, 34.011102063315256, 35.271713733673096, 35.30093438284737, 36.99870238985334, 46.451896803719656, 49.37156459263393, 47.47292763846261, 44.174916539873394, 46.22485746656145, 48.51290273666382, 46.366625036512104, 42.16495207377842, 36.78435046332223, 35.625543798719136, 36.683900356292725, 34.601698943546836, 35.653617995125906, 34.98983921323504, 36.09035743985857, 38.28884390422276, 38.01962552751814, 39.179227760859895, 38.64379957744053, 37.05442346845354, 34.338327475956504, 36.790840080806184, 35.82295254298619, 37.87282746178763, 38.16033697128296, 37.57512147086007, 36.9474663734436, 36.810899530138286, 36.002487046378, 37.29232631410871, 35.74003621510097, 34.92066294806344, 32.706609044756206, 34.3371011189052, 34.61184331348964, 36.10482011522566, 35.29744986125401, 36.11058712005615, 35.1461250441415, 35.53959805624825, 35.19614165169852, 35.95307840619768, 35.46020793914795, 35.50230360031128, 33.94377749306815, 36.267876965659006, 36.875795704977854, 36.68922962461199, 37.09332990646362, 41.38840055465698, 44.34389672960554, 44.092090538569856, 45.646274021693635, 44.240629128047395, 42.789046219417024, 43.32358850751604, 41.43406064169747, 39.47319562094552, 38.65929406029837, 38.0942074911935, 40.58296537399292, 40.9326160975865, 47.04065588542393, 49.83487047467913, 53.3962356703622, 57.287261622292654, 63.8982606615339, 41.66737420218331, 0.09646831426237311, 0.6972766986915043, 0.4755616901176316, 0.06213372307164328, 6.8759811861174445, 60.182100023542134, 51.83389152799334, 60.204257828848704, 35.018983432224815, 42.196569851466585, 25.54329248837062, 25.45725815636771, 52.29227461133684, 55.51713507516043, 22.467444828578405, 0.37823292559811045, 0.011104163663860942, 0.10157545057258435, 0.027129265147128274, 0.025808805466762612, 0.03368340791868312, 0.011132184615624803, 0.021643100871837566, 0.06333598534443549, 0.02099748667595642, 0.03555273796830859, 0.01792872214822897, 0.0391792497996773, 0.1276736105126994, 0.025219012650528123, 0.07123579537229878, 0.058127611609441895, 23.529381445475988, 62.232506479535786, 51.68299749919346, 43.8202874319894, 22.394321986607142, 53.74803338732038, 77.88371985299247, 45.38989244188581, 45.57406139373779, 57.92181975500924, 51.48076670510428, 3.7307457753590176, 0.6412359486733163, 0.6086879266159875, 1.3055459963423865, 7.377037065369742, 62.6373849596296, 53.92538268225533, 54.985090664454866, 48.81640699931553, 45.01172283717564, 48.35187823431832, 49.50406673976353, 50.4126409803118, 48.981319018772666, 50.09376730237688, 49.87845652444022, 47.5962164742606, 48.67688022341047, 46.258174078805105, 47.15431451797485, 46.59063148498535, 44.14257614953177, 43.345475333077566, 43.55774974822998, 40.82065282549177, 40.12816061292376, 39.33030244282314, 36.777628081185476, 35.761697224208284, 34.46379109791347, 35.361477511269705, 33.71336827959333, 34.930515493665425, 36.525971276419504, 34.9943277495248, 34.126789569854736, 36.01120008741106, 35.32037544250488, 35.80061755861555, 33.360903535570415, 34.053830010550364, 34.77499049050467, 34.258642060416086, 35.33615827560425, 35.53083985192435, 34.91676500865391, 37.13358429500035, 37.99387550354004, 36.40754965373448, 36.95614814758301, 37.456123147692, 37.43296480178833, 37.03449950899397, 36.066598074776785, 35.26050628934588, 36.874270575387136, 36.543140275137766, 36.662333147866384, 36.75599833897182, 36.824115003858296, 37.205341815948486, 37.12067454201834, 36.71719264984131, 37.290217535836355, 40.944070202963694, 47.83684648786272, 49.33094889777047, 51.04778276171003, 45.21276201520647, 47.17952258246285, 49.09822940826416, 46.95292098181588, 43.604608399527415, 38.27679920196533, 36.55214514051165, 38.840318952287944, 36.67865794045584, 38.21830579212734, 35.89691959108625, 36.616516726357595, 39.62971074240548, 39.33360978535244, 42.198449339185444, 39.79928500311715, 38.18760865075247, 36.81024292537144, 38.57117700576782, 37.23422547749111, 38.81535060065133, 40.1003851890564, 38.81228297097342, 39.55382251739502, 38.64133991513933, 37.58611699513027, 38.910190037318635, 36.976374353681294, 37.15787867137364, 35.791737760816304, 36.87712281090872, 35.47634513037545, 37.55174078260149, 36.70207336970738, 37.94625949859619, 36.840783732278005, 37.02726990836007, 36.62821054458618, 37.329766682216096, 37.46651070458548, 37.342318602970664, 36.745093141283306, 38.562071391514365, 38.47260986055647, 38.72882815769741, 40.11992004939488, 45.26596784591675, 46.34506130218506, 46.085803168160574, 48.0526888029916, 46.55210024969918, 44.75294065475464, 45.366424901144846, 43.916513034275596, 41.590930121285574, 40.27594879695347, 40.42873273577009, 43.139225006103516, 43.34268910544259, 49.41917712347848, 52.583060196467805, 56.341281754629954, 58.441055161612375, 65.63226699829102, 42.881752559116904, 0.04268429368468268, 1.6508058926888873, 1.422533358846392, 0.09877443087420293, 7.220355187143598, 67.90149307250977, 56.04645579201834, 62.744838850838796, 43.861177580697195, 58.908265931265696, 32.667007786887034, 32.212790148598806, 58.272457122802734, 63.441604205540244, 28.053049564361572, 0.34269666246005465, 0.0643486717183675, 0.15495709649154119, 0.03110121576381581, 0.02072726858646742, 0.030387305321970155, 0.023194934208212153, 0.05353435022490365, 0.14152166885989054, 0.08702584129891225, 0.13323321432939597, 0.1937636812882764, 0.2314450650342873, 0.16306621421660694, 0.11689007415303163, 0.23347608319350652, 0.18951712415686675, 28.019607884543284, 69.7905832018171, 61.20311001368931, 49.94256407873971, 30.28275775909424, 57.30931520462036, 71.1300847189767, 48.741137163979666, 51.28471980776106, 62.7850341796875, 56.30340017591204, 4.263071588107517, 0.7103444146258491, 1.6744459441729953, 2.557707245860781, 8.262706569262914, 65.79712690625871, 55.128758566720144, 59.358050618852886, 51.803524426051546, 47.79844379425049, 51.71612303597586, 51.31472560337612, 54.22181020464216, 52.0631925037929, 53.773918901171, 52.596848896571565, 50.925501414707725, 51.10461902618408, 46.6530818939209, 49.426337242126465, 48.6773943901062, 46.0485052381243, 47.68876995359148, 45.392251355307444, 43.89259386062622, 41.219350882938926, 42.22231640134539, 39.148631368364605, 37.61123473303658, 35.37449148723057, 38.63568755558559, 35.364496503557476, 36.68186106000628, 38.744558879307334, 35.9582965033395, 37.045241424015586, 39.64604248319353, 37.685302530016216, 37.92507791519165, 34.74927173342024, 37.64223064695086, 37.070821217128206, 35.824898038591655, 36.53037643432617, 37.20953505379813, 36.25712810243879, 40.09368017741612, 40.0786303792681, 36.55542469024658, 38.349004881722585, 38.48851776123047, 38.610048702784944, 38.39531462533133, 38.4792697089059, 36.98536532265799, 38.83713320323399, 39.34746101924351, 38.539844104221885, 38.523765972682405, 38.65192549569266, 38.39039530072893, 38.44796807425362, 38.96222857066563, 40.05260590144566, 41.16705526624407, 51.06972517286028, 53.69547373907906, 52.36375420434134, 47.9750565801348, 49.32119710104806, 52.59610891342163, 50.40140226909092, 45.11232927867344, 42.518278394426616, 39.38555104391915, 41.403641428266255, 38.660412720271516, 41.174316133771626, 38.2560727255685, 39.581163678850444, 41.05132259641375, 40.95054244995117, 42.921423298971995, 41.55371904373169, 40.547529561179026, 39.50096409661429, 40.703766754695344, 39.79857628686087, 40.45847797393799, 42.661098616463796, 41.017061029161724, 41.073237214769634, 41.18492603302002, 39.30582046508789, 40.481198583330425, 40.092252322605674, 38.68402964728219, 36.72616277422224, 37.54090506689889, 37.77832848685128, 40.34803983143398, 39.01463188443865, 40.87743003027779, 40.402280943734304, 39.82473625455584, 38.783388887132915, 40.292579310280935, 39.640171255384175, 39.131952217647004, 37.81594255992344, 40.824505601610454, 40.670804500579834, 40.41083417619978, 41.1312928880964, 46.30979919433594, 47.75262042454311, 49.57048804419381, 50.34527472087315, 47.72382014138358, 47.068924631391255, 47.08023282459804, 46.72072260720389, 44.359457220349995, 40.76804453986031, 42.30950934546334, 45.147841521671836, 45.35838236127581, 50.736298492976594, 55.01959889275687, 57.881864139011924, 61.9160646711077, 67.14965629577637, 46.25862571171352, 0.2402888461947441, 5.917111107281276, 2.5868592815739766, 0.27615202750478474, 9.102987834385463, 73.11536570957729, 61.117334502083914, 70.65666225978306, 50.45856162479946, 58.85987172807966, 36.222623348236084, 41.26127283913748, 67.49306406293596, 73.37754208700997, 36.073132855551584, 0.611303163426263, 0.19501817040145397, 0.2615758739411831, 0.17554804230374949, 0.09729597092206989, 0.12615821111415113, 0.13390965946018696, 0.17834273805575712], [0.07984654046595097, 0.04779826284253171, 0.03495839557477406, 0.04252672428265214, 0.005750289120312248, 0.06026678146528346, 0.051626981502132754, 0.04766892728262714, 0.034531858284026384, 21.199035542351858, 58.913657733372276, 42.74823944909232, 32.54739802224295, 29.095727511814662, 43.606161321912495, 49.09213931219918, 30.80123233795166, 47.81448718479702, 50.77240480695452, 44.863555976322715, 2.827010520866939, 0.3025250823370048, 0.1353514242385115, 1.2168197802134921, 16.069854497909546, 64.22709110804966, 51.24789088112967, 52.41598033905029, 44.36954600470406, 48.45592056001936, 47.86569193431309, 49.27295923233032, 49.5166916166033, 49.24501010349819, 48.99677528653826, 48.342209815979004, 47.68798133305141, 46.785333905901226, 44.07114519391741, 44.56690263748169, 42.31721142360142, 42.17564535140991, 39.74522106988089, 40.05453750065395, 39.10078954696655, 38.12790625435965, 35.72536856787545, 34.74334839412144, 34.7899569102696, 32.469307218279155, 34.43656805583409, 33.83532306126186, 33.723609924316406, 34.47638470785958, 33.358561992645264, 33.42672382082258, 35.14123698643276, 32.469317640577046, 33.31120307104928, 32.417272159031455, 33.671425478799, 34.79581424168178, 33.4254800932748, 33.72986677714756, 34.57833909988403, 33.045121806008474, 35.59407193320138, 36.36713545663016, 35.638655049460276, 35.05998475211007, 35.55632931845528, 34.89170980453491, 34.7403050831386, 34.93470178331648, 32.95356886727469, 33.54035118647984, 34.21232884270804, 33.27173730305263, 34.439885820661274, 34.222257818494526, 33.23012106759207, 35.69039828436715, 34.068733896527974, 34.80565289088658, 36.93721430642264, 42.7268077305385, 46.40729979106358, 47.05544165202549, 48.380140032087056, 44.662555013384136, 49.00127077102661, 46.6161105292184, 41.30589764458792, 38.61611100605556, 36.74738604681832, 35.3996821812221, 35.76927770887102, 35.87845127923148, 35.623542717524934, 35.76691879544939, 37.16265555790493, 38.08600166865757, 37.22071123123169, 38.75454691478184, 36.5737818309239, 34.131503922598704, 34.07069328853062, 35.94695009504046, 37.12914787020002, 37.896183831351145, 37.993931089128765, 37.45100927352905, 36.87100839614868, 33.4595227922712, 37.217810358319966, 37.61458029065813, 37.02285432815552, 35.19820874077933, 35.07122346333095, 33.88556201117379, 34.40894201823643, 35.39410972595215, 34.841915539332796, 35.72717162540981, 34.524632998875205, 35.47290577207293, 35.89312934875488, 34.586221831185476, 35.10915715353829, 35.215398584093364, 36.45216751098633, 36.82224941253662, 36.081133706229075, 38.06971856525966, 37.586085728236604, 38.78187070574079, 39.9643429347447, 40.762680530548096, 39.623175961630686, 38.07889018739973, 37.61138759340559, 37.04703753335135, 36.72216756003243, 37.44334193638393, 39.68687357221331, 39.500078201293945, 42.2877962248666, 46.86760752541678, 51.85111263820103, 55.34035900660923, 57.380697522844585, 61.006225858415874, 50.748166016169954, 0.7514880097338131, 1.580350399017334, 0.966809372816767, 0.08464756927319936, 6.33601713180542, 57.45709296635219, 54.15066065107073, 56.356373241969514, 34.4055061340332, 12.927423119544983, 13.539458666528974, 33.86975833347866, 45.31799943106515, 57.91375984464373, 17.309843914849417, 0.3871250998760973, 0.021813986523609077, 0.03294002530830247, 0.03836228006652423, 0.053566417789884975, 0.029595054619546448, 0.06462398051683392, 0.0897257389234645, 0.057193947423781664, 0.014866284959550415, 0.04150850784831813, 0.02957246618877564, 0.06005840336105653, 0.041178325922893624, 0.013747731007502546, 0.045857259138886414, 0.037809837210391245, 23.58279572214399, 67.2121831348964, 49.22137928009033, 38.748046875, 27.973727192197526, 46.790520736149375, 54.1206305367606, 39.039145129067556, 51.382116181509836, 54.81969574519566, 50.124467917851035, 3.1002849084990363, 0.4682499053222792, 0.22455659109566892, 1.0520205604178565, 17.58598964554923, 68.27012974875313, 52.90717281614031, 53.89391081673758, 45.88765096664429, 49.300856249673025, 48.86028487341744, 52.221187591552734, 50.64844199589321, 51.15689032418387, 50.23103591373989, 51.02721609388079, 50.654611996241975, 48.856310503823416, 46.42832156590053, 45.81990950448172, 45.22198574883597, 44.465917519160676, 40.90663678305489, 42.49580097198486, 40.615778241838726, 39.38945940562657, 37.52751241411482, 36.746156215667725, 36.87914473669869, 34.82319361822945, 36.58891153335571, 35.76371567589896, 37.08390814917428, 35.819950921194895, 35.46283435821533, 36.027399812425884, 36.740462166922434, 34.08374547958374, 34.742597988673616, 33.025604316166465, 34.90551587513515, 35.710641860961914, 35.22748844964163, 34.33887985774449, 35.37344230924334, 34.36731536047799, 36.657566683632986, 37.61546966007778, 37.11415365764073, 36.09172970908028, 38.175021989004954, 37.887641021183555, 36.60788358960833, 36.24734156472342, 35.080940519060405, 36.086365699768066, 36.13854667118618, 36.67294304711478, 36.91450064522879, 36.831153529030935, 35.53137138911656, 36.44172089440482, 36.17624412264143, 37.18961109433855, 39.336145877838135, 45.101493562970845, 47.167846134730745, 48.53722837993077, 49.16020039149693, 46.106897899082725, 51.322097642081125, 47.940034185137065, 43.148632866995676, 39.11960179465157, 38.81995030811855, 36.98829746246338, 37.02395561763218, 38.80425780160086, 37.12030976159232, 37.986291544778005, 39.02578026907784, 39.83903217315674, 39.83791698728289, 40.32024703707014, 38.45584385735648, 35.46996668406895, 38.71556404658726, 37.62174040930611, 39.8143903868539, 39.32790878840855, 39.39288486753191, 40.48122290202549, 38.68906709126064, 36.68571383612496, 36.34984139033726, 38.60649469920567, 38.081561769757954, 36.18759747913906, 36.95921230316162, 35.45719936915806, 36.91222858428955, 36.025086062295095, 37.8096718106951, 37.082157203129356, 38.97983877999442, 36.30135686056954, 38.27737242834908, 36.365631171635215, 36.92059074129377, 36.308520453316824, 38.27597236633301, 38.7345222064427, 39.535183974674766, 39.18211126327515, 39.95402833393642, 40.416156496320454, 41.822503158024375, 42.00480304445539, 41.09459250313895, 40.77613571711949, 39.523264339991975, 38.11648688997541, 38.82353210449219, 38.80223934991019, 40.92360775811331, 41.288579259599956, 45.25102227074759, 49.58040312358311, 53.56565012250628, 57.08381836754935, 60.219057491847444, 62.95813465118408, 53.316651003701345, 0.9620610390390668, 1.1803047167403358, 0.8669971429875919, 0.22712779098323413, 6.753447098391397, 62.749528884887695, 58.750778062003, 62.57562242235456, 42.03401674543108, 16.442222356796265, 16.465450184685842, 37.226186411721365, 52.77533074787685, 65.72244071960449, 22.262273209435598, 0.2925985221351896, 0.016647812577762773, 0.026137521756546836, 0.02950148464047483, 0.007959354020256017, 0.010811134075213755, 0.06034665182232857, 0.016166849993169308, 0.1489884310535022, 0.13690986989864282, 0.1256947445550135, 0.1552031740014042, 0.07733218824224812, 0.16145052734230245, 0.16057213661926134, 0.10761834095631327, 0.09395539374755961, 27.81190538406372, 74.12687751225063, 54.96981504985264, 44.84686640330723, 39.788907868521555, 51.70785467965262, 53.159534863063264, 42.1698887688773, 58.61824117388044, 58.80758653368269, 54.1244728905814, 4.24254834651947, 0.632721582693713, 2.402890524693898, 1.9927531267915453, 18.749571459633962, 69.43291773114885, 55.9746287890843, 56.747779164995464, 47.87669440678188, 52.38114207131522, 51.58639669418335, 54.802054268973215, 52.349010126931326, 53.94715486254011, 52.90467841284615, 53.045831067221506, 52.95931904656546, 50.32881791251046, 48.79181037630354, 47.55695915222168, 47.43670320510864, 46.01923247746059, 43.20904745374407, 44.96471132550921, 43.2798878124782, 43.00623301097325, 39.52674886158535, 39.6205530166626, 38.33771753311157, 36.478077343532014, 38.59272684369768, 38.289622102464946, 39.21167237418038, 37.46331453323364, 37.75926610401699, 37.40619339261736, 39.709441321236746, 36.37038026537214, 37.46633005142212, 34.32523012161255, 36.58491284506661, 38.7694160597665, 37.67069394247872, 36.7296472958156, 38.24903767449515, 37.10950878688267, 39.22644077028547, 40.01401908057076, 38.465084961482454, 37.925425325121196, 39.065426690237864, 39.80967950820923, 37.617873736790244, 37.63775600705828, 37.35880667822701, 36.85373864855085, 38.02392298834664, 38.262162821633474, 37.59601470402309, 39.17447171892439, 37.04679087230137, 39.109419209616526, 38.10048866271973, 39.37424979891096, 42.18131160736084, 46.40281820297241, 49.79478284290859, 51.28916665485927, 52.26452350616455, 48.70730985913958, 52.898362500326975, 50.748131275177, 45.54620259148734, 41.32215295519148, 41.28107867922102, 39.901763984135215, 39.31486007145473, 41.797378471919465, 38.82354947498867, 39.64871059145246, 39.97169065475464, 42.05361761365618, 41.005579130990164, 41.91607802254813, 40.86153255190168, 37.27906220299857, 39.356177534375874, 38.72947434016636, 41.58073016575405, 42.04585647583008, 41.05936861038208, 43.03237213407244, 39.90937226159232, 37.5887051991054, 39.941382612500874, 40.58257280077253, 40.5485474722726, 38.36551380157471, 38.9878431047712, 37.56902095249721, 38.78743621281215, 38.73911843981062, 39.09539079666138, 39.888746534075054, 40.934276717049734, 38.851519448416575, 39.709302357264924, 38.6842485155378, 40.33559560775757, 38.852745805467876, 41.2336676461356, 40.66035788399832, 41.56051090785435, 41.874666758946006, 41.594550132751465, 41.97729860033308, 44.531122888837544, 44.727718693869456, 43.26071078436715, 41.80950307846069, 42.08681263242449, 40.847094195229666, 41.16370276042393, 40.515619959150044, 43.001480443137034, 43.611132758004324, 48.357610498155864, 52.32394102641514, 56.11846692221505, 58.830605915614534, 62.1212797164917, 64.48880195617676, 56.61922012056623, 1.524907031229564, 4.621672025748661, 1.9247039897101266, 0.28347274182098253, 7.6568158354078015, 69.04716069357735, 63.554317883082796, 68.55458205086845, 46.350991589682444, 20.398418937410625, 22.056792395455496, 47.587774412972585, 58.95257459368025, 76.87823213849748, 30.215707642691477, 0.7391880697437695, 0.07737813184836081, 0.18186371055032524, 0.10869802587798663, 0.18223294216607297, 0.1691154624734606, 0.1150158518659217, 0.1558546626142093], [0.0034116952779835886, 0.013077999132552316, 0.025196059507184794, 0.020079852880111763, 0.029798489596162523, 0.07753893107708011, 0.040820714219340255, 0.03650503811825599, 0.1299240668969495, 19.624320132391794, 60.84668132237026, 42.71976225716727, 39.643933704921174, 32.84551395688738, 54.215553351810996, 67.40008326939174, 34.00966031210763, 46.412972995213096, 50.70604951041085, 45.22074202128819, 2.7998721599578857, 0.27251486267362324, 0.14815798561487878, 1.139295145869255, 24.880533354622976, 58.70076492854527, 50.41474975858416, 52.576174531664165, 46.284629344940186, 49.25651979446411, 49.62151908874512, 48.50533962249756, 48.75659690584455, 47.36599833624703, 45.69023527417864, 44.074178082602366, 45.30940798350743, 45.321591649736675, 43.823619093213765, 44.46458346503121, 42.1485994883946, 39.161006110055105, 38.82241691861834, 37.05655656542097, 36.342069830213276, 34.89012908935547, 33.75011382784162, 34.323819637298584, 33.25993578774588, 33.13988133839199, 34.80291530064174, 35.38389587402344, 35.234384536743164, 34.76558610371181, 32.16538258961269, 34.29922996248518, 34.87231738226754, 32.94419922147478, 32.31371620723179, 32.181016036442344, 34.62125812258039, 33.90586812155587, 34.759370940072195, 32.08018030439104, 34.43443843296596, 32.9959146635873, 36.509507519858225, 37.14583049501692, 36.41392462594168, 35.115705830710276, 33.248182909829275, 35.018531799316406, 35.07676465170724, 33.591764381953645, 34.98562513078962, 33.55787454332624, 34.98517002378191, 35.652596609933035, 33.544728551592144, 35.52819606236049, 35.22470569610596, 34.50394126347133, 34.05304486410958, 35.640454632895334, 37.55210556302752, 38.195345469883506, 44.77482053211757, 46.489017554691856, 46.214219774518696, 47.69272347858974, 48.05575295857021, 45.36254780633109, 43.353559562138145, 37.48117140361241, 35.4064427784511, 34.473706177302766, 36.63769483566284, 35.75029523032052, 35.69936146054949, 34.85358503886631, 36.856604780469624, 37.91572216578892, 38.052414076668875, 36.29688916887556, 36.43883391789028, 36.53883586611067, 35.23805318559919, 36.999397209712434, 36.21730102811541, 36.558058057512554, 37.658093384334016, 35.64943170547485, 35.455146176474436, 37.38062054770333, 34.97894443784441, 35.108226094927105, 35.8051894732884, 34.088181904384065, 35.17040205001831, 33.2829030581883, 35.83553920473371, 33.91264261518206, 35.94959388460432, 35.191482884543284, 35.604789529527935, 34.44751146861485, 35.0202306338719, 34.12807846069336, 36.238847391945974, 36.10583455221993, 37.434076513562886, 36.3402042388916, 36.00422757012503, 35.44512340000698, 34.95432349613735, 35.50537470408848, 36.53702933447701, 36.911109924316406, 37.61974627631051, 36.923574992588584, 37.78449501310076, 36.97189276559012, 38.11482974461147, 40.971553802490234, 42.69421373094831, 43.12236867632185, 46.48194776262556, 47.0135509627206, 48.25181722640991, 50.98159769603184, 57.61515058789934, 57.48051186970302, 56.08002948760986, 4.1960397107260565, 1.1990911258118493, 0.799827115876334, 0.054410016629844904, 3.7493847523416792, 55.98474189213344, 55.821042333330425, 57.62791095461164, 41.41708966663906, 32.3099433353969, 27.69572629247393, 40.54207869938442, 46.485762323652, 53.60492828914097, 20.258068799972534, 0.1482324887599264, 0.02999773801171354, 0.03226654198286789, 0.04685011532689844, 0.005437760555651039, 0.05708021138395582, 0.06855811298425708, 0.0492043570349259, 0.047594709122287374, 0.022873228881508112, 0.028153810616848723, 0.028244853052975874, 0.01572507280590279, 0.06080402513699872, 0.043306842778942416, 0.11031958208020244, 0.034611287593309364, 22.97998217173985, 65.27783938816616, 49.35099792480469, 49.18920564651489, 44.054959365299766, 52.38456405912127, 56.079713344573975, 35.0593455178397, 52.23591777256557, 54.62686586380005, 48.25136906760079, 3.2081452693258012, 0.5380788668990135, 0.6119438633322716, 0.9048058741859027, 26.790105036326818, 62.435908045087544, 52.47713490894863, 54.84051602227347, 49.13992207390921, 51.78876297814505, 51.286519391196116, 51.673318658556255, 50.39360639027187, 50.326379094805034, 47.306372370038716, 46.52186516353062, 46.705148220062256, 46.664028780800955, 45.05805689947945, 44.95376443862915, 43.24074166161673, 42.29524121965681, 41.003411293029785, 39.51569427762713, 37.47631113869803, 36.02852194649832, 35.349241733551025, 36.00165326254708, 34.71505185535976, 34.84961761747088, 37.113309451511924, 36.96647317068917, 37.42702409199306, 35.58039787837437, 36.15794604165213, 35.151600224631174, 35.58961466380528, 35.2136823790414, 34.06072609765189, 33.66367128917149, 36.385662828172954, 35.3699369430542, 36.11066355024065, 33.19048159463065, 36.305623054504395, 34.840543270111084, 37.38488326753889, 38.070027760096956, 37.38981648853847, 36.50635303769793, 35.54230090550014, 37.643738406045095, 36.19617503029959, 35.845006125313894, 37.3269213948931, 36.431437560490195, 37.114108494349885, 37.15077066421509, 35.364093508039204, 35.76571328299386, 36.93133613041469, 37.00055408477783, 36.11937311717442, 37.178997720990864, 38.71281950814383, 40.133027826036724, 45.558566910879954, 48.491606507982524, 50.26301152365548, 48.406817640577046, 49.87690012795584, 48.41504430770874, 44.98443031311035, 39.38310527801514, 37.372772557394846, 37.634604998997276, 36.77302489961897, 38.341365337371826, 37.5676452091762, 36.39384433201381, 37.827539103371755, 37.72799226215908, 40.15793364388602, 39.45735025405884, 39.66506665093558, 37.86224882943289, 37.43500757217407, 38.07429395403181, 37.67018672398159, 38.642781666346956, 38.34527717317854, 36.96672330583845, 37.370128767830984, 38.42106464930943, 35.7591507094247, 36.685564449855256, 38.07889366149902, 34.53656652995518, 36.510629653930664, 35.4397211756025, 37.63085297175816, 36.91355916431972, 37.525973388126914, 37.16181829997471, 37.74450813020979, 36.18577357700893, 36.92924819673811, 36.4971536227635, 37.71464477266584, 36.32440403529576, 39.56991107123238, 37.984978335244314, 37.31515114648001, 37.0740556035723, 37.94129153660366, 37.463856492723735, 38.45216131210327, 39.02719075339181, 38.74620907647269, 40.394735200064524, 39.10140446254185, 39.10030664716448, 39.950856481279644, 43.6421981539045, 45.580106326511924, 44.712446553366526, 48.44752366202218, 48.266714164188926, 51.63468320029122, 53.82272999627249, 61.11639649527413, 59.93221500941685, 60.488286290849956, 5.424264524664197, 1.2245118703160967, 1.7193597512585777, 0.10382199859512703, 4.633102680955615, 59.27751404898507, 61.36582292829241, 61.96834986550467, 48.579862526484895, 28.50934645107814, 25.7393776008061, 45.73655891418457, 51.238625458308626, 62.64276286533901, 25.406953198569163, 0.17908673813300474, 0.11617693384843213, 0.06041802692094019, 0.03161187782617552, 0.005997795370473925, 0.02153388217889837, 0.04348262406087347, 0.05499214878571885, 0.14881168625184468, 0.10459055485469954, 0.36753978367362705, 0.08636058521057878, 0.08367896731942892, 0.2270692741232259, 0.18721728399395943, 0.19135868176817894, 0.14871887623199395, 25.54592411858695, 75.29871899741036, 54.997131892613, 53.72591379710606, 42.03057391302926, 59.51562186649868, 71.42454242706299, 44.493505341666086, 57.150858061654226, 59.725179536002024, 53.40857914515904, 3.5741950443812778, 0.5767976492643356, 2.215167352131435, 1.9409514835902621, 28.3737210886819, 63.95361001150948, 54.32828092575073, 57.24185514450073, 51.6177921295166, 52.50255489349365, 53.91153839656285, 52.442185470036094, 54.015115192958284, 52.176819869450156, 50.11330563681466, 48.842528751918245, 49.59261110850743, 49.94340828486851, 48.07664271763393, 47.54231582369123, 46.3647003855024, 43.336658069065635, 43.044649600982666, 41.6198867389134, 39.57059894289289, 38.484397479466026, 36.486884185246055, 39.72378240312849, 36.00252526147025, 37.43582051140921, 39.24330404826573, 38.98467820031302, 39.69283512660435, 37.95746694292341, 36.22410331453596, 37.65489026478359, 37.87524890899658, 37.195666449410574, 35.72231830869402, 36.29007298605782, 38.17651237760271, 36.9317877633231, 38.860541684286936, 33.949082442692344, 38.17993089130947, 36.32885088239397, 40.773484979357036, 40.64355366570609, 38.4289230619158, 38.2192576953343, 35.71504354476929, 38.59837572915213, 38.75255625588553, 37.7056815964835, 40.3403377532959, 38.189581939152305, 39.390074321201865, 40.67363589150565, 37.658645766122, 39.987900802067344, 40.09435067858015, 39.365533283778596, 38.693923882075715, 39.19086251940046, 42.396844727652415, 41.43175383976528, 48.70562144688198, 49.21336800711495, 52.47830220631191, 51.49415588378906, 51.51840162277222, 49.74538809912545, 47.477134772709434, 41.33936711720058, 38.714386326926096, 38.89573431015015, 40.64695480891636, 40.336679526737754, 40.931146553584504, 37.37183107648577, 40.57848726000105, 41.53463234220232, 42.98548221588135, 41.24211318152291, 42.3223808833531, 41.09142065048218, 38.737374441964285, 41.89283629826137, 39.720947538103374, 40.0918528011867, 40.48655564444405, 38.63201543263027, 38.52677454267229, 40.851311751774375, 37.13037770135062, 38.51604652404785, 41.140509673527305, 35.80783673695156, 39.244853496551514, 37.93830381120954, 39.80150842666626, 38.4592866897583, 40.15299000058855, 40.09267268862043, 40.71016604559762, 38.254342624119346, 39.79843037469046, 39.23628984178816, 39.30452810014997, 39.41386842727661, 41.44012989316668, 40.6089585849217, 39.78322424207415, 41.39803770610264, 40.06240633555821, 39.09447710854666, 40.73263304574149, 41.08522285733904, 42.01333195822579, 41.81411320822579, 41.11196299961635, 40.39772639955793, 42.20305599485125, 45.196711676461355, 48.3738762310573, 47.955990723201204, 51.18877560751778, 51.616329533713206, 54.780487060546875, 55.528012480054585, 63.78708948407854, 61.20739010402134, 63.74817262377058, 6.843966058322361, 2.110519881759371, 3.7583340321268355, 0.18776720948517323, 4.99110209941864, 66.73219462803432, 66.51734937940324, 70.3862383706229, 54.027910300663535, 43.26361165727888, 38.21215663637434, 55.76639822551182, 60.83238887786865, 70.62247017451695, 33.61198711395264, 0.49557641042130335, 0.21033749622958048, 0.11155190345432077, 0.12248340116015502, 0.08193832822144032, 0.11510263649480683, 0.11929193884134293, 0.17854935196893557], [0.07182204962841102, 0.025060786765867045, 0.02954408646162067, 0.053861438030643125, 0.06726838754756109, 0.13339425783072198, 0.09761633444577456, 0.10279644041189126, 0.016419868916273117, 17.167081015450613, 57.32339572906494, 45.68262004852295, 30.608458042144775, 27.982805013656616, 64.67731353214809, 75.4417198726109, 46.85926968710763, 44.51723343985421, 50.11720357622419, 47.18698147365025, 2.963890467371259, 0.3784004423235144, 0.13896987507385866, 0.42384953211460796, 30.165958540780203, 61.9584903717041, 49.730782985687256, 49.061678409576416, 46.55762754167829, 49.60833140781948, 48.55337251935686, 47.50619561331612, 44.09748234067644, 43.58030012675694, 41.262572152274, 40.00941242490496, 39.56035729816982, 38.667194162096294, 38.61551693507603, 38.511161940438406, 37.52466712679182, 36.86782264709473, 33.94851269040789, 33.85554926736014, 33.14908422742571, 32.67575556891305, 33.78272867202759, 33.298209939684185, 34.83010012762887, 34.97050585065569, 35.47202335085188, 34.471194403512136, 33.534285409109934, 33.98200300761631, 33.60441010338919, 31.824476173945836, 34.70655420848301, 33.49471194403512, 32.905605452401296, 32.75148398535592, 33.49725498471941, 35.14632306780134, 34.44683401925223, 32.42122915812901, 34.4653058052063, 34.020308426448274, 32.647584097726, 34.6306277683803, 34.924939564296174, 35.64796216147286, 34.03894349506923, 34.86562279292515, 35.75723648071289, 35.21372754233224, 35.50821999141148, 34.81334107262747, 35.42676625932966, 35.15390007836478, 33.35657480784825, 34.31606197357178, 33.97211572102138, 34.13339383261544, 33.291768959590364, 33.868521554129465, 35.61476019450596, 37.85567583356585, 44.13083369391305, 45.411219937460764, 48.84260170800345, 45.97796712602888, 46.30592557362148, 48.64769778932844, 42.749250411987305, 38.2136435508728, 36.81547491891043, 35.51876040867397, 36.11276190621512, 35.268093722207205, 35.264682156699045, 36.14799274717058, 35.913685594286235, 35.521584851401194, 35.054433141435894, 35.94165904181344, 36.36913653782436, 34.92148283549717, 36.58610098702567, 35.54860986982073, 35.76063067572457, 36.78027534484863, 36.61447743007115, 35.41123008728027, 35.74451780319214, 36.26989541734968, 34.38599211829049, 34.53571884972708, 35.66834122794015, 33.95014551707676, 35.246971198490684, 33.30601624080113, 35.84932095663888, 35.728915623256135, 34.89682715279715, 36.182799748011995, 34.57733161108834, 35.756072657448904, 34.855342933109824, 36.2771006992885, 34.157340799059185, 34.17554160526821, 36.50486959729876, 35.790254320417134, 35.11773470469883, 34.9083959034511, 37.75984975269863, 36.12542847224644, 37.25607408796038, 36.87254394803728, 37.910768100193565, 36.196056910923545, 39.488012654440745, 38.95549924033028, 45.04692588533674, 45.592998708997456, 51.232924461364746, 49.49537454332624, 50.07290881020682, 47.73409652709961, 50.42342111042568, 49.752878257206504, 57.29056201662336, 57.332470076424734, 61.353684425354004, 7.332251582826887, 0.45772240736654823, 0.7519349743212972, 0.18236799777618476, 3.282378737415586, 52.78472123827253, 56.44858973366873, 58.87756878989083, 45.42696802956717, 25.449215616498673, 18.73100413594927, 34.7770436831883, 48.32015970775059, 60.348099436078755, 23.527666977473668, 0.10570407153240272, 0.087316043941038, 0.031692104414105415, 0.07295089441218547, 0.03976392646187118, 0.03264887271715062, 0.021901585394516587, 0.04173847693683846, 0.0636184187605977, 0.05196354504940765, 0.03030001518449613, 0.034317224086927514, 0.06624935687120471, 0.02592828530552132, 0.04105445935523935, 0.023797464823084216, 0.017169999557414224, 20.74248504638672, 65.31130886077881, 52.02788870675223, 34.9729585647583, 28.095381464276993, 63.23008714403425, 71.45806053706578, 48.53610624585833, 50.17153154100691, 55.1508468900408, 51.09145566395351, 3.5211405541215623, 0.3863147390740258, 0.28849409094878603, 0.4273551697177546, 34.32643215996878, 63.08008943285261, 52.25734601702009, 51.84825692858015, 48.92300626209804, 52.33779920850481, 49.210901396615164, 48.65010186604091, 46.516938890729634, 45.983417987823486, 44.144820417676655, 41.99081632069179, 42.139598097120015, 41.59154503686087, 39.331702504839214, 39.40380048751831, 39.657843998500276, 38.76926319939749, 37.11950724465506, 35.557145731789724, 34.975088187626426, 34.65450177873884, 35.62088850566319, 34.74865334374564, 37.12643459865025, 37.04013797215053, 36.51508692332676, 35.90031378609793, 35.45370095116751, 35.1378219468253, 35.67411518096924, 35.259929588862825, 35.87714501789638, 34.599871567317415, 34.61395556586129, 35.47236033848354, 35.15083244868687, 36.69068874631609, 35.55392524174282, 33.51287106105259, 34.91325616836548, 36.06885623931885, 33.77421018055507, 36.207917485918315, 36.84515414919172, 37.47331993920462, 35.642341068812776, 36.22748361315046, 36.86272961752755, 35.99292285101754, 35.98682233265468, 36.67419024876186, 37.21568420955113, 37.41644893373762, 35.599911894117085, 37.42779534203665, 36.54533243179321, 35.22216612952096, 35.40957294191633, 35.44548123223441, 37.61965594972883, 38.86774001802717, 44.98305804388863, 46.70391838891165, 49.45111451830183, 48.13282585144043, 49.99030862535749, 49.58936629976545, 43.33295815331595, 41.19970485142299, 39.11861515045166, 37.36887114388602, 37.5392027582441, 37.752026081085205, 36.77194445473807, 36.96193947110857, 38.16651391983032, 37.46622582844326, 37.512195110321045, 38.27302633013044, 38.3279379435948, 35.527921608516145, 37.603341579437256, 36.45397056852068, 36.57398680278233, 38.666370800563264, 39.13495036533901, 37.46510369437081, 37.71366855076381, 37.347585337502615, 36.71277012143816, 35.87009607042585, 37.268726757594514, 36.25678069250924, 37.00566448484148, 36.545891761779785, 37.52151959283011, 37.61488948549543, 36.6241215297154, 37.28397110530308, 36.8114275932312, 37.27160331181118, 37.135915415627615, 36.73982988085066, 36.54052427836827, 36.81659357888358, 38.00100435529436, 37.82822697503226, 37.458513328007285, 37.44068425042288, 38.4067895753043, 36.982881341661724, 38.42233616965157, 38.228488377162385, 39.23745366505214, 37.9603157043457, 41.22996078218733, 39.96355084010533, 46.65609393801008, 48.320531436375205, 52.15456478936331, 52.66268655232021, 52.84669916970389, 50.770532267434255, 51.78969056265694, 52.31837204524449, 59.896598543439595, 58.82875769478934, 65.38996941702706, 10.104791266577584, 0.7514774245875222, 1.5652113599436623, 0.1303897047681468, 3.762423046997615, 57.280129296439036, 61.50808729444231, 63.2032254082816, 52.59134592328753, 31.853623867034912, 20.632434265954153, 43.494767802102224, 54.493269375392366, 68.15408788408551, 28.76924729347229, 0.15877053114984715, 0.049285950870918374, 0.03703138451757176, 0.03663049924320408, 0.03812045697122812, 0.010464874262522374, 0.05132776112960918, 0.047350219384367974, 0.17957811962280953, 0.17862099169620446, 0.10070543975702353, 0.11572413385978766, 0.10986313157315765, 0.2305013042475496, 0.16997180080839566, 0.23612516533051217, 0.08553248071776968, 25.032782282148087, 74.56335639953613, 57.95162057876587, 42.01408583777291, 35.92028638294765, 69.53891944885254, 74.10554654257638, 56.98321540015084, 54.59611661093575, 58.779772894723074, 56.15345457621983, 4.2139182942254205, 0.6109367002333913, 1.3672074590410506, 0.8378313737256187, 36.521965639931814, 65.4692553111485, 53.70622607639858, 53.78996229171753, 50.76398011616298, 53.37114225115095, 51.32110404968262, 51.614828722817556, 49.839199202401296, 47.478896141052246, 46.068217277526855, 43.50970990317208, 44.440560068402974, 42.99895824704851, 41.532148361206055, 42.31920208249773, 41.07700661250523, 40.34997837884085, 38.54164368765694, 37.66230051858084, 37.49970572335379, 36.35481630052839, 38.01613405772618, 36.198158740997314, 38.35648461750576, 39.279653549194336, 39.27215296881539, 37.869190079825266, 37.77148451123919, 37.290648324149, 37.91401638303484, 37.379091944013325, 38.04614332744053, 36.46011625017439, 36.45974104745047, 36.48320858819144, 37.143537589481895, 39.93611935206822, 36.30318076269967, 36.062154701777864, 36.64485148021153, 38.02185937336513, 34.801414489746094, 37.56228814806257, 37.879820823669434, 39.80127566201346, 37.17736142022269, 37.73228277478899, 38.11560794285366, 36.985935074942454, 39.22079883302961, 39.34482765197754, 39.51026426042829, 40.93150438581194, 37.05401005063738, 38.919698647090364, 40.19618000302996, 38.002762249537874, 37.389955452510286, 36.342754227774485, 40.04739475250244, 42.04863575526646, 45.956010818481445, 48.741960525512695, 52.217911515917095, 50.15843071256365, 53.220102310180664, 52.68480266843523, 45.961875098092214, 42.36187791824341, 41.88115637642996, 40.04340648651123, 41.40304388318743, 39.799952030181885, 37.339601857321604, 38.62503249304635, 39.92060055051531, 39.83711099624634, 39.96906076158796, 40.19167757034302, 41.330897263118196, 38.514858382088796, 39.46425676345825, 39.28804349899292, 39.12946823665074, 39.800525256565635, 40.693761348724365, 37.02149942943028, 39.636551243918284, 39.62189054489136, 38.956412928445, 37.16990600313459, 38.96293381282261, 37.433558872767854, 40.64207717350551, 38.13112327030727, 39.95062371662685, 40.399664946964805, 38.33949974605015, 40.46421023777553, 38.58152634756905, 38.91705485752651, 38.78285040174212, 40.24250711713518, 38.68532201222011, 39.187305041721885, 40.37897668566023, 39.066670417785645, 38.886548791612896, 39.441723755427766, 41.77741282326834, 39.9296783719744, 41.028740950993125, 39.87533303669521, 40.992151737213135, 38.67777279445103, 44.840960434504915, 43.537850107465474, 50.50552797317505, 50.134115491594585, 54.22369316646031, 54.30737727028983, 54.30949994495937, 51.61823681422642, 56.83737618582589, 52.56243446895054, 64.22135189601353, 60.58681869506836, 70.81950719015938, 11.634043744632176, 1.0964999965259006, 3.7044203536851064, 0.4049757277326924, 4.468812959534781, 63.72327722821917, 65.27431665148053, 70.43602916172573, 55.46207407542637, 35.583076408931184, 30.78842680794852, 49.92065640858242, 64.4573335647583, 76.32024315425328, 38.77191741125924, 0.3387779327375548, 0.16276900230773858, 0.149258732263531, 0.1818920597434044, 0.15727748269481318, 0.0973044933219041, 0.1696969534137419, 0.15070730953344277], [0.021662951413808123, 0.02272032949674342, 0.05472600021000419, 0.025099600665271282, 0.021070569986477494, 0.03540712435330663, 0.013094710601892854, 0.039701419815953286, 0.08632279081004006, 10.968998653548104, 54.948723793029785, 48.91017641339983, 38.59482172557286, 34.17911645344326, 31.49090358189174, 45.37478010995047, 38.88851860591343, 46.474200521196636, 49.81938294001988, 50.02728346415928, 4.331708933625903, 0.3504231950002057, 0.3724330796727112, 0.22744447684713773, 34.626104491097585, 59.41472012656075, 49.75698811667306, 52.05896799904959, 48.02137674604143, 48.29535116468157, 43.27164724894932, 40.286756719861714, 38.303657463618684, 38.826161997658865, 38.23565544400896, 36.24087279183524, 35.20262779508318, 36.06974213463919, 34.92894172668457, 36.05484519686018, 36.61037104470389, 35.12478712626866, 34.55719920567104, 35.366744245801655, 34.12480933325631, 35.13039084843227, 34.91258566720145, 34.10251603807722, 33.780154364449636, 34.078919955662315, 34.40456812722342, 35.22380243028913, 34.28566707883562, 33.446526186806814, 33.72011498042515, 32.356569222041536, 33.693715299878804, 34.29767009190151, 32.601889269692556, 33.981850147247314, 33.54595838274275, 33.57595723015921, 32.381541047777446, 33.665641103472026, 34.48593848092215, 32.374842984335764, 33.07775749479021, 35.07552787235805, 35.19097566604614, 37.53010409218924, 35.86247042247227, 35.42910085405622, 35.59291853223528, 34.41981247493199, 35.719973291669575, 34.68048109327044, 35.20921816144671, 35.05028854097639, 35.95185204914638, 34.300254821777344, 32.875436374119346, 34.92459215436663, 34.73544829232352, 35.04165193012783, 36.01292324066162, 37.67544651031494, 44.710806778499055, 48.66864660808018, 47.20171512876238, 41.222574847085134, 47.357684816632954, 45.213297026497976, 39.805996962956016, 36.18003783907209, 34.55812679018293, 34.57665763582502, 34.002173628125874, 35.097188881465364, 34.534350054604666, 34.94999129431588, 35.12978288105556, 34.64512518474034, 34.807990959712434, 33.984438351222444, 35.63045270102364, 35.371312686375205, 35.559709617069785, 36.20179959705898, 36.45485993794033, 36.63789633342198, 35.192650181906565, 35.61091784068516, 35.09525728225708, 33.77711452756609, 34.27782603672573, 36.75227757862636, 34.657249791281565, 34.168034076690674, 34.6699788911002, 33.758844239371165, 34.01820659637451, 34.94599608012608, 33.48179176875523, 34.18934072766985, 33.48635673522949, 35.38847473689488, 35.92289890561785, 35.35887541089739, 35.80437305995396, 35.545114925929475, 35.5697706086295, 35.877739088875906, 35.251543113163535, 36.604749952043804, 36.63771220615932, 36.386385440826416, 37.997637953077046, 36.41717638288225, 36.48959745679583, 38.22703620365688, 39.37738343647548, 42.78816727229527, 51.420647416796, 51.11972788402012, 52.15302228927612, 52.86234303883144, 50.21010446548462, 51.20879684175764, 52.53959574018206, 50.17584637233189, 56.67366967882429, 56.612643650599885, 55.44622523444039, 7.602378436497279, 0.389631771083389, 1.5596517154148646, 0.07931997693542923, 2.0701849375452315, 52.33246994018555, 55.33278547014509, 60.507699557713096, 46.122771058763774, 41.413125719342915, 31.57676247188023, 27.611936228615896, 44.552269731249126, 57.29643324443272, 24.71728195462908, 0.12567782189164842, 0.062200945535940785, 0.05665769102051854, 0.0256612902573709, 0.0065606020008479905, 0.08928367335881505, 0.030717826514903988, 0.012596296944788523, 0.044354636554739306, 0.028351159134347523, 0.0982359658394541, 0.025172655138054063, 0.04970676811145885, 0.027493945489238416, 0.04545466734894684, 0.04071982963276761, 0.015605250306959664, 13.622351544243948, 63.068652697971885, 51.93215990066528, 43.369272913251606, 36.62455926622663, 51.60398258481707, 60.72257259913853, 43.26148550851004, 51.95862906319754, 55.17001696995327, 54.63514116832188, 5.082548643861498, 0.35423373909933226, 0.3691918264542307, 0.38926476506250246, 36.126119818006245, 59.9845974785941, 51.68752077647618, 52.93665402276175, 48.57039908000401, 50.933144433157786, 46.59438003812517, 43.077448572431294, 40.976862226213726, 40.00749819619315, 40.01850414276123, 37.8255797113691, 37.6012328011649, 38.04583413260323, 37.303776945386616, 37.37345348085676, 37.46585757391793, 36.60410029547555, 36.42584078652518, 37.374169145311626, 36.137170927865164, 35.33000564575195, 37.752411706107004, 36.01965951919556, 35.02309329169137, 36.192138126918245, 35.11620610100882, 36.39221497944423, 36.20810161318098, 35.58399704524449, 35.33934055055891, 34.143190792628694, 36.26931871686663, 34.67295619419643, 33.67925957271031, 34.10876246861049, 35.4469507762364, 35.023871489933555, 34.2829190662929, 35.432696546827046, 34.736396721431184, 33.892315660204204, 35.833336625780376, 35.335376603262766, 36.18475219181606, 37.34337820325579, 37.0597596849714, 36.077069010053364, 36.246556418282644, 35.510471207754954, 36.29646185466221, 35.25604207175118, 36.174552236284526, 37.17854608808245, 36.925933906010215, 36.092091015407014, 34.57405553545271, 35.89159032276699, 37.073652608054026, 36.065493311200825, 37.97354507446289, 39.20647859573364, 46.160041196005686, 49.701875005449565, 49.30480282647269, 43.793887751443044, 48.92986413410732, 47.22489431926182, 43.05477660042899, 38.29532657350813, 36.843458788735525, 36.769557748522075, 36.074289730616975, 36.25661393574306, 37.75811617715018, 36.02375895636422, 36.63983140672956, 35.80416808809553, 37.183354241507395, 36.09392186573574, 36.36545746667044, 35.611136708940776, 37.550062792641775, 37.23600769042969, 38.305800982883994, 37.747273513248985, 36.77597788402012, 38.48500197274344, 36.26946810313633, 37.56611313138689, 35.96138497761318, 38.03799656459263, 35.47845043454851, 35.18176235471453, 36.09577703475952, 36.89420148304531, 35.97271054131644, 36.369629859924316, 35.800520283835276, 36.037262780325754, 35.44206271852766, 36.93970176151821, 38.22601134436471, 35.84764644077846, 38.70126117978777, 36.96850899287632, 36.62614345550537, 37.260948249271934, 37.64301579339163, 37.5390498978751, 39.089919090270996, 38.59301519393921, 39.042796407427105, 37.90865932192121, 38.229165826525005, 40.631342206682476, 41.66211788994925, 44.81951829365322, 53.02076196670532, 53.15937158039638, 54.535510948726106, 53.4450363431658, 53.39644064222063, 54.124003887176514, 55.172132696424214, 51.6335506439209, 59.71386786869594, 59.45296995980399, 59.497549601963584, 8.330906612532479, 0.7879987848656518, 1.5526245896305357, 0.027407389865922074, 2.363672286272049, 57.42322049822126, 59.54268510001046, 65.44423484802246, 49.332901341574534, 42.02763482502529, 37.92082561765398, 35.11788409096854, 52.14063712528774, 63.70982551574707, 29.609664916992188, 0.1361776627600193, 0.008380958361418119, 0.058731399210436006, 0.030390131420322826, 0.03165336006454059, 0.017876457988417575, 0.03829251988125699, 0.04137189839301365, 0.15513367844479425, 0.1173190711332219, 0.14797943591007165, 0.11825947995696749, 0.15080775985760347, 0.20358458001698765, 0.12390977676425662, 0.19650303572416306, 0.1654728286500488, 16.107977526528494, 71.81389168330601, 59.46268354143415, 49.712662083762034, 45.879014355795725, 41.6336476462228, 52.41352762494768, 49.90548849105835, 56.177255630493164, 58.59253978729248, 59.4305203301566, 5.704617823873248, 0.5356222987174988, 1.1655659590448653, 0.4053889012762478, 40.18182155064174, 63.36635521480015, 52.421855040958945, 56.51828363963536, 51.65756709235055, 52.02296590805054, 49.305973597935264, 44.291291918073384, 44.26893956320626, 41.842475754874094, 41.92234877177647, 40.059137208121165, 39.11917448043823, 39.177744320460725, 38.57692664010184, 40.017006805964876, 38.857811042240684, 39.43726648603167, 38.68692357199532, 39.388010706220356, 38.22557360785348, 37.8390348979405, 37.764254910605295, 37.38551207951137, 37.6318222454616, 37.4105429649353, 38.7465043749128, 39.05721044540405, 38.59873356137957, 37.511878967285156, 38.363342489515034, 35.20255831309727, 39.47960186004639, 37.8294220651899, 36.2256041254316, 37.170163086482454, 37.87055540084839, 36.37189497266497, 34.24710805075509, 38.04718903132847, 37.68029982703072, 36.17068903786795, 36.50706870215279, 36.943874154772075, 37.8145181792123, 40.357246194567, 38.27029916218349, 38.172697816576274, 38.910551343645366, 37.48007706233433, 38.430684430258616, 38.35651935849871, 38.907101563044954, 38.03785760062081, 40.34096656526838, 38.89210387638637, 36.96003566469465, 39.2367136819022, 41.02412039893014, 39.141196795872276, 40.91592999867031, 40.65265233176095, 49.41800287791661, 53.71232312066214, 49.663930892944336, 46.82300009046282, 51.96372209276472, 49.69034794398716, 44.9502660206386, 40.75817462376186, 38.542536531175884, 38.73834718976702, 37.58174657821655, 37.16615744999477, 39.408570425851, 38.081311634608674, 38.4761187008449, 38.07692732129778, 38.85870041166033, 37.70587962014334, 37.98082678658621, 39.23114817483084, 37.80643742425101, 38.19393498556954, 40.30545779636928, 40.652231965746196, 37.63534845624651, 39.817051546914236, 38.802322728293284, 39.0007563318525, 40.34752219063895, 40.523672921316965, 37.35878930773054, 37.416382925851, 37.57290846960885, 38.92771339416504, 36.969377517700195, 39.47668014253889, 37.52408695220947, 38.01605067934309, 37.53806325367519, 39.205707345690044, 40.9276898247855, 39.09461954661778, 41.04333216803414, 39.6006429536002, 38.23576661518642, 39.73950270244053, 39.11254242488316, 39.95480305807931, 40.63010195323399, 41.47985621861049, 40.43313441957746, 40.53268126079014, 40.84926898138863, 42.8341052872794, 42.6300436428615, 48.2382230758667, 54.78135905947004, 54.66536235809326, 56.186347348349436, 54.92370332990374, 55.82413080760411, 56.171870776585166, 58.399088042122976, 54.27801765714373, 62.57458714076451, 61.2089603969029, 63.525059018816265, 11.61693467412676, 0.9466501516955239, 4.9503739305904935, 0.19060830346175603, 3.024518494095121, 62.960608209882466, 65.42693383353097, 71.50081975119454, 58.760026114327566, 52.283950669424875, 43.97099733352661, 41.6192683492388, 59.47535705566406, 73.36457674843925, 38.95470019749233, 0.42720008375389235, 0.20488104330641882, 0.11521969735622406, 0.10963916751955237, 0.08581548410334758, 0.09808301047555038, 0.1330721572573696, 0.12558965305132525], [0.07845717894711665, 0.023650997950296317, 0.020079539057665637, 0.019476996568430747, 0.05773649723934276, 0.05505584965326956, 0.034117972278701406, 0.08063830262316124, 0.07888464922351496, 7.909095372472491, 54.63268150602068, 46.627488204411094, 42.155005727495464, 20.716219118663243, 14.101170148168292, 16.915458951677593, 31.2233110836574, 47.700272696358816, 48.54057046345302, 50.14089345932007, 6.063004170145307, 0.44611411169171333, 0.24524744440402302, 0.5066783832652229, 28.97025520460946, 60.45795045580183, 49.88986199242728, 48.690748827798025, 45.01352589470999, 41.43081930705479, 41.666898250579834, 38.04243993759155, 37.122425488063264, 39.01193945748465, 37.9593950680324, 37.091874258858816, 37.01060812813895, 36.203765937260215, 36.3405134337289, 36.171609674181255, 35.94742604664394, 36.16340037754604, 35.82431091581072, 36.235727650778635, 36.67124421255929, 35.24700941358294, 34.334016118730815, 34.27074234826224, 35.723384857177734, 34.802255221775596, 37.89707667487008, 34.0670975957598, 34.35496493748256, 33.16744484220232, 33.410965306418284, 32.820031438555034, 32.79587950025286, 32.600576060158865, 32.5869436945234, 31.989290918622697, 34.08266850880214, 32.71896989004952, 34.30593497412545, 32.625711168561665, 33.25335931777954, 32.95278024673462, 33.477782658168245, 34.346397808619905, 36.39547368458339, 35.28525924682617, 37.10799755368914, 35.551416942051475, 35.6033547265189, 34.55812679018293, 35.369471413748606, 36.00228207451956, 33.811984062194824, 34.01233884266445, 35.42861100605556, 34.58569376809256, 34.90041937146868, 33.57160765784127, 35.70290504183088, 34.05775574275425, 34.64873824800764, 37.852524825504844, 43.78458758762905, 47.07332978929792, 42.82552078792027, 44.95591490609305, 44.98223468235561, 44.652643408094136, 38.81048338753836, 34.20933764321463, 36.57750953946795, 35.50870289121355, 34.42285926001412, 34.5806702205113, 35.9943402835301, 34.863343783787315, 35.485860688345774, 34.01522581917899, 34.84148127692086, 34.10394041878836, 34.691275119781494, 36.898606640951975, 36.283208165849956, 35.95382186344692, 36.37129395348685, 35.03015266145979, 36.05988958903721, 36.30572380338396, 36.38605540139334, 34.67086131232125, 35.876658643995015, 34.24932452610561, 35.15297596795218, 34.89084822790963, 34.3597800391061, 34.10142169679914, 34.75437865938459, 34.509927136557444, 34.59065130778721, 32.364896638052805, 34.75599758965628, 33.85126917702811, 34.1988319669451, 36.04592023577009, 34.44669158118111, 35.25693838936942, 35.397260734013145, 38.162991183144705, 36.437242780412944, 35.780005727495464, 37.04589108058384, 40.75238330023629, 39.08690357208252, 37.88740130833217, 39.26578841890608, 39.412079266139436, 39.95910051890782, 46.16192763192313, 50.781156063079834, 52.67500570842198, 52.36566843305315, 53.81897102083479, 49.9516419001988, 49.857841219220845, 54.492783001491, 58.28417525972639, 54.968230860573904, 61.24942670549665, 53.542262486049104, 2.070975946528571, 1.6264634217534746, 1.1465399456875665, 0.09363592589007956, 2.1106996663979123, 51.07785109111241, 58.269455501011436, 57.27657529285976, 55.27508762904576, 37.061861515045166, 26.544493164334977, 24.351485354559763, 40.42617579868862, 54.9975175176348, 19.244927644729614, 0.26306637110454695, 0.0074051690254626525, 0.033267638978681395, 0.02010915880756719, 0.06897942216268607, 0.031126874565546, 0.05707412492483854, 0.04876985713573439, 0.047353252435901334, 0.04811053822881409, 0.04173179675957986, 0.052476476811404736, 0.01056119570109461, 0.07983445575726883, 0.0473758612227227, 0.07647470318313156, 0.18894213358206408, 9.092451759747096, 64.49664647238595, 52.93819652284895, 48.69717591149466, 27.714512484414236, 17.481219496045792, 30.354185240609304, 38.86981405530657, 53.05366168703352, 52.64133473805019, 54.1209397315979, 6.697710820606776, 0.6048362904361316, 0.4560028367808887, 0.45718940453869955, 30.812304292406353, 63.09691102164132, 51.60902350289481, 51.78260687419346, 46.462701252528596, 46.02710131236485, 44.47514125279018, 39.621998241969514, 38.34718445369175, 39.89848790849958, 38.60526486805507, 39.81460230691092, 37.79206160136631, 38.063902923039024, 37.578599044254844, 36.6800788470677, 38.110803263528005, 38.371583053043906, 38.26465722492763, 36.734441552843364, 37.359101976667134, 37.66336011886597, 36.165033204214915, 36.25763879503523, 36.242759227752686, 37.37802539552961, 37.765050479343955, 35.864037241254536, 35.558313029153005, 34.816043921879356, 35.16014650889805, 35.68642738887242, 35.94105454853603, 35.79333584649222, 34.94517271859305, 34.31234121322632, 35.71970231192452, 34.34677301134382, 35.7208696092878, 34.63306311198643, 33.93731219427926, 33.94557360240391, 34.62018115179879, 35.81357594898769, 36.00380720411028, 35.91854585920061, 39.266396386282786, 36.08686597006661, 37.93347481318882, 36.53963490894863, 37.17598567690168, 36.9875088419233, 36.139255387442454, 37.36916296822684, 37.037515027182444, 36.4704829624721, 35.19956016540527, 34.630318573543, 38.1765992300851, 35.96404613767351, 36.78435393742153, 39.447622776031494, 45.97965553828648, 47.85507508686611, 45.27880116871425, 46.83896705082485, 46.87503514971052, 46.21677671160017, 41.47932120731899, 36.625333990369526, 36.93704407555716, 36.99134772164481, 36.72578409739903, 35.88818917955671, 37.16796050752912, 36.93814189093453, 36.73260028021676, 35.83637646266392, 36.82972567422049, 37.13295200892857, 36.292108808244976, 37.40704802104405, 38.19933720997402, 36.601227215358186, 37.88412523269653, 37.38458102090018, 36.61357763835362, 37.81151308332171, 37.189486026763916, 35.947686604091096, 36.83589914866856, 36.34270906448364, 36.03024162564959, 36.36393233707973, 36.00024625233242, 33.77697556359427, 36.31379413604736, 36.13401297160557, 37.298597063337056, 35.74438926151821, 35.959185872759136, 35.462417466299875, 35.99082449504307, 37.19629178728376, 37.05581658227103, 37.86672346932547, 37.985836437770296, 40.17297649383545, 39.54362603596279, 37.75461081096104, 38.56352356501988, 40.089073521750315, 41.079584394182476, 39.11131954193115, 41.512297357831685, 40.49233654567173, 41.425114836011616, 48.05086142676217, 53.110313824244905, 55.27137381689889, 53.42735317775181, 56.052205426352366, 52.8211784362793, 51.098720005580354, 55.699480124882285, 60.3786506652832, 57.22621127537319, 63.37342848096575, 56.897339139665874, 2.7579102516174316, 1.8299214414187839, 1.4112937791006905, 0.11061507051012345, 2.0609859568732123, 56.473589352199006, 62.2112797328404, 61.74531963893345, 54.388514859335764, 42.56586313247681, 32.75854335512434, 28.82784492628915, 48.54321425301688, 61.52534661974226, 26.331847020557948, 0.2154176200606993, 0.018347052557926093, 0.03502796916291118, 0.03412466263398528, 0.03582642167540533, 0.053328832145780325, 0.02470603508741728, 0.054843132317598374, 0.15919806249439716, 0.10600412650299923, 0.13011820933648519, 0.18470048904418945, 0.15154576168528625, 0.16041448579302856, 0.19126747309097222, 0.23817550816706248, 0.26811594728912624, 10.847865496362958, 71.70005934579032, 58.70225879124233, 56.623646123068674, 31.024165289742605, 21.093224900109426, 24.471882002694265, 42.78298739024571, 57.82697684424264, 57.968640191214426, 59.686068126133506, 8.037208863667079, 0.8683322284902845, 1.2287814297846384, 0.6115120436464037, 34.16469546726772, 64.39031818934849, 54.227618898664204, 54.17902667181832, 48.02961383547102, 47.34205831800188, 47.04523822239467, 41.606431552342, 40.267273971012656, 42.41583068030221, 41.52891050066267, 41.513548033578054, 40.20616456440517, 41.0246901512146, 40.68102877480643, 40.31913185119629, 39.47832339150565, 39.93923214503697, 40.104620116097585, 38.25617694854736, 40.655059882572715, 39.10271419797625, 39.226941040584016, 37.78596108300345, 39.748208795275005, 38.232733726501465, 41.32723208836147, 37.749222482953755, 38.25663205555507, 36.94734130586897, 37.06013141359602, 37.73784133366176, 38.78173521586827, 36.65285580498831, 36.587403774261475, 36.746190956660676, 38.04470157623291, 36.85334954942976, 37.317847047533306, 36.394549574170796, 37.051810945783345, 35.930621828351704, 35.52499989100865, 38.00060830797468, 39.35634429114205, 37.92990343911307, 42.96199035644531, 37.99641159602574, 39.78289072854178, 37.67251437050955, 40.261760575430735, 39.84220402581351, 37.326619148254395, 38.77151094164167, 38.959129674094065, 38.812897886548726, 38.33737359728132, 36.540249824523926, 40.3461777142116, 38.519333021981375, 38.74421841757638, 42.162468092782156, 48.82016944885254, 49.68068994794573, 46.56783444540841, 48.834795406886506, 47.13342128481184, 48.92162357057844, 42.811283929007395, 37.40464047023228, 41.53367349079677, 40.64896283830915, 38.1387072290693, 38.71665491376604, 39.30717188971383, 38.76236711229597, 39.261390209198, 36.97746869495937, 41.1847870690482, 40.49946192332676, 38.752827235630576, 40.57134451184954, 41.03493527003697, 38.46380301884243, 39.872258458818706, 38.37045744487217, 38.93776396342686, 40.664578914642334, 40.32241834912981, 38.42124877657209, 38.89019659587315, 37.9952130317688, 38.69240917478289, 38.483216285705566, 38.17756502968924, 36.169997692108154, 39.12444468906948, 37.492403166634695, 39.601118905203684, 36.992650508880615, 38.24971859795706, 37.27163110460554, 38.92953382219587, 39.43505348478045, 38.82138163702828, 39.52345888955252, 39.67344617843628, 42.17212608882359, 40.98365756443569, 40.413780212402344, 40.07711219787598, 43.24214172363281, 42.73006990977696, 41.29058381489345, 43.472669056483674, 44.08274868556431, 44.46840844835554, 50.3017373085022, 55.757758140563965, 58.81673731122698, 55.85562004361834, 59.06373882293701, 54.89812353679112, 53.9522305216108, 57.65790285382952, 61.83051150185721, 60.082455907549175, 65.34664739881242, 61.05464785439627, 5.034845786435263, 2.614464908838272, 3.1767018479960303, 0.34748217995677677, 2.8009017961365834, 60.529009682791575, 67.29192066192627, 66.28278514317104, 68.961961882455, 47.34569222586495, 37.35067728587559, 36.8069737979344, 56.26972573144095, 71.69049167633057, 35.15176698139736, 0.5404413629855428, 0.09940851506377969, 0.1216285013194595, 0.1034715488286955, 0.08203118573874235, 0.18407968378492764, 0.10438323526510171, 0.1383865928011281], [0.024377904034086635, 0.036849130011562786, 0.018802833011639968, 0.07374304333435637, 0.057528763743383546, 0.016438973069723164, 0.05956655368208885, 0.02343494052599583, 0.041082784799592834, 2.596122533082962, 46.633175304957796, 49.40414816992623, 41.20236253738403, 34.07995523725237, 37.451954228537424, 29.67722225189209, 29.086515937532695, 42.942834172930034, 47.6420259475708, 52.497677258082796, 7.53863479409899, 0.2909374141267368, 0.41909302877528326, 0.5167793812496322, 21.464823246002197, 60.113576889038086, 49.6829376901899, 53.150026253291536, 42.84142174039568, 43.07017380850655, 41.05782263619559, 42.1560549054827, 41.15054982049124, 40.419759137289866, 37.60074642726353, 38.215762751443044, 36.702361719948904, 36.04195281437465, 34.145188399723594, 36.3390543120248, 35.260905810764854, 35.69510568891253, 34.51116739000593, 33.84385197503226, 34.4603830065046, 34.1458033152989, 33.04211671011788, 33.938802582877024, 34.19005986622402, 33.234161445072715, 32.00393424715315, 33.877130372183665, 31.914246899741038, 31.418430396488734, 33.40037277766636, 32.379508699689595, 32.326848302568706, 33.04046998705183, 33.318088735852925, 32.12954725537981, 33.81172003064837, 34.26171663829258, 33.537307875497, 33.54395382744925, 34.19785574504307, 32.384685107639854, 34.34264925548008, 33.70312663487026, 36.16443913323538, 36.31953682218279, 35.45828676223755, 34.319942542484824, 35.941186564309255, 34.726759569985525, 34.440094266619, 34.001986026763916, 34.84070307867867, 34.151122161320274, 33.58183888026646, 35.207373414720806, 33.141121591840474, 33.94818959917341, 33.25027779170445, 35.02232551574707, 34.049508231026785, 34.835106304713655, 41.80041830880301, 45.4549241065979, 46.942106110709055, 50.40568930762154, 47.2801741872515, 45.180015155247276, 37.27500792912075, 34.690795694078716, 33.53125946862357, 35.528675488063264, 33.945747307368684, 34.685039111546104, 34.647543157849995, 34.68839856556484, 33.217878341674805, 33.928178787231445, 36.27739947182791, 35.900949546269004, 35.88372496196202, 34.11325100490025, 35.18632732118879, 37.25593859808785, 36.68393857138497, 34.73994377681187, 35.62835781914847, 35.02548694610596, 35.88787998471941, 32.8175995690482, 33.78822469711304, 35.251431941986084, 35.16737263543265, 33.73536280223301, 34.17778239931379, 33.241168703351704, 32.9680940764291, 33.98497336251395, 34.05697407041277, 34.67395326069423, 33.68293864386422, 34.56174332754952, 33.53362185614449, 34.29558910642351, 35.314493792397634, 35.12099340983799, 35.699347564152305, 36.32546016148159, 37.06096172332764, 37.422653675079346, 38.05599934714181, 37.235729762486045, 38.6348364012582, 37.636029379708425, 37.1057949747358, 37.539616176060264, 39.0912253516061, 46.10776989800589, 51.60777282714844, 51.72479786191668, 52.404911858694895, 51.49096318653652, 55.004983357020784, 53.824147428785054, 53.07806723458426, 53.079366547720774, 57.191237517765586, 60.09335763113839, 48.603882449013845, 0.8256325625947544, 1.3267436474561691, 0.3447882059429373, 0.027035074308514595, 1.376382121018001, 47.10149431228638, 59.0489113671439, 56.68710054670061, 53.76775584902082, 28.71520073073251, 36.58222041811262, 39.19925594329834, 36.71397910799299, 56.30076680864607, 20.59464475086757, 0.24436708592942782, 0.03907332030524101, 0.009585414846826876, 0.03501915160034384, 0.028190459989543473, 0.038495137223175595, 0.06900480615773372, 0.023563841823488474, 0.020937957102432847, 0.030270739791116545, 0.010728902416303754, 0.02984730340540409, 0.05918003299406596, 0.04416779515200427, 0.02706808503717184, 0.01870430463791958, 0.04032721570027726, 3.3583579404013495, 53.34718486240932, 55.36174208777291, 47.56713826315743, 32.534126962934224, 26.10247482572283, 26.937884535108292, 35.03892823628017, 47.32694598606655, 53.602590220315115, 55.613180024283274, 8.92007303237915, 0.4791302957705089, 0.27761351051075117, 0.8128242641687393, 22.940479925700597, 61.70936271122524, 52.79122127805437, 54.25016580309187, 43.58871439525059, 45.20766551154, 41.48455320085798, 43.25856031690325, 43.09992946897234, 42.628966672079905, 39.589894090379985, 39.27525881358555, 39.11534602301461, 37.0225625038147, 35.36428805759975, 37.892709732055664, 36.78059843608311, 37.08764280591692, 36.03926386151995, 36.87501055853707, 35.107274191720144, 34.664812905447825, 35.12689243044172, 36.26617118290493, 36.64348268508911, 35.58525814328875, 34.43031120300293, 34.4613036428179, 33.81059789657593, 33.982270513262065, 35.28550590787615, 35.74719633374895, 34.644659655434744, 33.843549728393555, 35.6863683291844, 34.287650789533345, 35.39932434899466, 35.5283454486302, 33.362626688820974, 34.799983160836355, 33.86581523077828, 33.52523538044521, 35.61683423178536, 34.27160045078823, 36.42735896791731, 37.0047264780317, 36.53996842248099, 36.331536361149375, 37.53427995954241, 36.2043912751334, 37.2212358202253, 35.79359292984009, 35.08675268718174, 36.984854630061555, 35.6193390573774, 36.80111646652222, 36.2318331854684, 34.96442270278931, 36.23578323636736, 36.886746065957205, 36.60076516015189, 37.519028663635254, 43.6058486529759, 47.68375335420881, 48.283813680921284, 51.52230651038033, 47.85682603291103, 46.54448502404349, 40.10400172642299, 38.254412106105256, 35.45067153658186, 35.9605963570731, 36.01675169808524, 36.088679449898855, 38.05452285494123, 37.53268187386649, 35.27615015847342, 35.40584870747158, 38.26448699406215, 36.98833220345633, 37.437290055411204, 36.21540764399937, 37.76636021477835, 38.04890523638044, 37.81214884349278, 36.80466004780361, 36.64646346228463, 35.056715624673025, 35.79182113919939, 34.29483870097569, 35.935381344386506, 36.41876057216099, 36.349417550223215, 35.52863727297102, 34.869235856192454, 34.88071428026472, 34.572982038770405, 35.34667437417166, 38.184857164110454, 36.25103800637381, 36.1466760635376, 36.54535327638899, 36.30977807726179, 36.31251219340733, 37.6117593220302, 36.86047492708479, 39.118403230394634, 38.46077013015747, 38.952073778424946, 39.747333322252544, 38.63150126593453, 40.04146793910435, 40.69009269986834, 39.72308758326939, 38.66108669553484, 39.847835540771484, 41.245899949754985, 48.88339805603027, 53.63452066693987, 53.40570606504168, 54.11334187643868, 53.59657308033535, 55.964678968702046, 56.10961839130947, 55.129832063402446, 55.42981358936855, 59.432757650102886, 61.66344901493618, 49.77298286982945, 1.3749148568936755, 1.9225426656859261, 0.9756397732666561, 0.09402820734041077, 1.3793240317276545, 49.63940722601754, 63.27169295719692, 62.193950925554546, 58.479548181806294, 32.53885521207537, 39.439750467027935, 43.933484009334016, 42.11026627676827, 63.473274094717844, 26.15703555515834, 0.2775000051728317, 0.03782101946749857, 0.03704708242522819, 0.030714712039168392, 0.018590008806703345, 0.028999073563941886, 0.07377919568014996, 0.03285083866545132, 0.09819862605737788, 0.12904940811651094, 0.10703991699431624, 0.20731192215212754, 0.1524284543203456, 0.20163741521537304, 0.1411415942545448, 0.10581843182444572, 0.0985714267673237, 3.7662806000028337, 61.262343406677246, 62.20007923671177, 53.511957917894634, 43.09716408593314, 46.1319009917123, 40.44484908240182, 40.89501244681222, 53.66752461024693, 54.74235187258039, 60.33280645098005, 10.57601809501648, 0.7843925069485391, 1.7119333211864745, 0.9067940360733441, 26.888154540743145, 64.267564364842, 54.15344687870571, 57.31618697302682, 46.31981154850551, 46.79254266193935, 44.12417037146432, 46.353333132607595, 46.42964172363281, 44.141099657331196, 41.78231825147356, 42.31488030297415, 42.338577134268625, 40.22926732472011, 37.27286788395473, 40.73747941425869, 38.81832095554897, 40.0814721924918, 36.98591423034668, 38.44332667759487, 37.50511489595686, 37.07273891993931, 36.95824997765677, 38.27798734392439, 38.23669072559902, 36.36073963982718, 35.525416782924104, 38.4135536466326, 35.26389701025826, 36.519016129629954, 37.78910861696516, 37.75577463422503, 37.90493508747646, 35.12295627593994, 37.175540992191856, 35.93738242558071, 38.170220783778596, 38.39691618510655, 36.237200668879915, 36.74299825940813, 37.82740708759853, 35.40484469277518, 36.694576263427734, 35.84862266268049, 38.408978257860454, 40.343791007995605, 38.42256893430437, 37.447246823992046, 39.24874448776245, 37.04053749356951, 38.17786380222866, 38.40675483431135, 38.56259250640869, 39.78475284576416, 38.21824673243931, 39.93892295019967, 37.76058973584856, 36.63701738630022, 37.86876623971121, 38.67117895398821, 38.91093349456787, 38.30925076348441, 44.922038963862825, 50.9598776272365, 50.96992472239903, 53.43868916375296, 51.491567679813926, 50.434993335178916, 42.78602722712925, 39.60653502600533, 36.45106274741036, 39.55624049050467, 37.06326505116054, 38.83411768504551, 41.28567143848964, 39.79906613486153, 36.635707650865825, 37.98732682636806, 41.460835524967735, 38.825845854622976, 39.42341177804129, 38.14973749433245, 38.81417635508946, 40.106308528355186, 38.193278380802695, 38.90424932752337, 38.00854662486485, 37.230098247528076, 38.58399643216814, 35.36287062508719, 35.68596880776541, 38.3742789540972, 37.89440161841256, 36.54320280892508, 37.18254130227225, 36.83958864212036, 36.179370812007356, 37.85508176258632, 39.10187694004604, 38.59980010986328, 39.305917739868164, 39.092979771750315, 38.607658522469656, 39.342732770102366, 40.52822051729475, 37.72836399078369, 40.743916920253206, 41.532533986227854, 41.9151782308306, 40.22836058480399, 41.5410281590053, 40.66861581802368, 43.09614617483956, 41.39574480056763, 40.33453948157174, 41.593205656324116, 43.781777041299, 49.90692676816668, 55.272874627794536, 54.69869286673409, 57.480032444000244, 54.4399037361145, 58.14310598373413, 57.373151779174805, 57.79875673566546, 57.025995458875386, 61.54178605760847, 63.37140655517578, 55.117043903895784, 2.0163561574050357, 3.148752284901483, 2.264878021819251, 0.10304228721984796, 1.9488722128527505, 55.08699294498989, 69.90476989746094, 67.57342692783901, 67.013429914202, 39.59535884857178, 47.802265303475515, 54.42805010931832, 50.076233523232595, 72.06905732836042, 35.33941698074341, 0.4595327930791037, 0.10792710153119904, 0.16350635274180345, 0.12249714827963284, 0.11824802628585271, 0.1447742807545832, 0.1508818423109395, 0.13661742130560534], [0.031218300373958688, 0.04182990953060133, 0.03791170906541603, 0.01910112039851291, 0.018486566143110394, 0.011617492368843938, 0.017276220821908543, 0.03287714886079941, 0.03454303714845862, 0.3910024661038603, 38.17923954554966, 50.736215114593506, 38.9380418913705, 32.31303528376988, 18.311449323381694, 30.977942398616246, 32.20552233287266, 43.07591649464199, 45.76804467609951, 51.89226334435599, 11.585774609020778, 0.4801275251167161, 0.3648397299860205, 0.6826393412692207, 11.430093271391732, 62.92462348937988, 48.048012665339876, 53.756360803331646, 44.569188594818115, 44.36765956878662, 43.37457091467721, 44.76366867337908, 43.518898895808626, 43.64901433672224, 43.20592423847744, 42.667949540274485, 40.48687178747994, 39.90049941199166, 38.77989394324166, 34.37004600252424, 35.64064918245588, 34.93161678314209, 34.17010811397007, 34.04161160332816, 35.055676868983674, 35.11902706963675, 33.81544426509312, 32.5421382359096, 33.70605182647705, 32.83180168696812, 32.575982911246165, 32.63906908035278, 31.718200002397808, 31.929588522229874, 32.86436789376395, 33.71145057678223, 32.35003791536604, 33.84183004924229, 31.701322828020366, 31.022949354989187, 33.099651268550325, 33.444459097726, 32.58983414513724, 33.62833969933646, 33.23449495860508, 32.36373628888811, 34.5063488142831, 33.323876585279194, 34.0959916796003, 34.58492946624756, 34.831993511744905, 35.78873266492571, 34.37513555799212, 35.8004994392395, 34.59703670229231, 33.60343040738787, 33.946779114859446, 33.24177667072841, 35.26744753973824, 33.550467763628276, 32.44198342732021, 33.65657717841012, 33.822336878095356, 35.055360725947786, 36.815513134002686, 36.67962374005999, 41.65381479263306, 47.11534902027675, 46.80525091716221, 47.11917052950178, 45.94848939350673, 43.7893853187561, 39.915844508579795, 35.1523436818804, 36.05354935782296, 34.128220898764475, 34.57277011871338, 34.24162939616612, 34.99334110532488, 34.46142176219395, 35.034832273210796, 34.3457099369594, 34.36066940852574, 34.26256084442139, 35.039873191288535, 35.74526820863996, 35.725983483450754, 35.528025831495015, 37.08790683746338, 33.894313267299104, 33.986557551792686, 34.915215560368125, 34.37042120524815, 34.250022820064, 33.82357018334525, 34.572165625435964, 34.56592614310128, 33.9727132661002, 34.592266763959614, 34.276071616581504, 33.54964092799595, 31.326304231371196, 33.870734555380686, 33.980074882507324, 33.918472153799875, 33.835541929517476, 33.33945097242083, 35.028144632067, 35.04870435169765, 34.44940137863159, 35.24569967814854, 35.55695465632847, 35.886142935071675, 35.89797224317278, 37.01852560043335, 36.90183755329677, 36.285761628832134, 37.893432344709126, 37.32479177202497, 36.88234090805054, 40.55585697719029, 48.702067443302695, 50.73663548060826, 51.74907486779349, 52.77416345051357, 52.85233415876116, 50.58961507252285, 50.72103330067226, 53.3190655027117, 55.68777241025652, 53.74126584189278, 55.001255648476736, 44.97729451315743, 0.5692819782665798, 0.6487392974751336, 0.5648584184902055, 0.07047643326222897, 1.4033232182264328, 46.877988134111675, 60.405227524893625, 57.397744928087505, 53.001640524183, 29.6754469871521, 26.64132673399789, 43.56015035084316, 39.74870211737496, 64.3208292552403, 18.507591758455547, 0.17163556867412158, 0.08754707832953759, 0.017097903515345285, 0.07833359736417021, 0.03790251152323825, 0.04243473529017397, 0.01451887672633997, 0.01764382904262415, 0.05975250620394945, 0.05867134207593543, 0.08117224861468587, 0.026397198804521134, 0.04043504509276577, 0.006477561613012637, 0.03303502360358834, 0.04327830359605806, 0.05795344524085522, 0.631857020514352, 42.92537334987095, 57.02648183277675, 43.30159051077706, 38.66077750069754, 21.881044660295757, 37.605637959071565, 39.54882328850882, 47.70055757250105, 50.512632506234304, 55.072061266217915, 12.396650229181562, 0.46405916448150364, 0.4766760617494583, 0.7812853051083428, 12.39265501499176, 63.47403839656285, 50.62643357685634, 55.090658119746614, 47.212557792663574, 44.98979432242257, 45.80573170525687, 46.182668004717144, 44.71059833254133, 44.9377384185791, 44.572009563446045, 44.64126920700073, 42.307216439928325, 40.94482408251081, 39.80292933327811, 35.103320666721885, 38.271904196058, 38.112234592437744, 35.38329832894461, 35.69587346485683, 38.02912024089268, 36.413222857883994, 35.19180250167847, 34.19684130804879, 35.20689051491873, 35.090073926108225, 35.56792933600289, 34.147919041769846, 34.785207816532676, 33.95642668860299, 35.242197786058696, 35.65890557425362, 34.44975921085903, 35.6271071434021, 33.80323280606951, 33.30920893805367, 35.90009144374302, 35.38721711294991, 35.903624602726524, 34.708975655691965, 34.50049843106951, 34.612906387874055, 34.58141367776053, 35.15952117102486, 35.75673621041434, 35.78640501839774, 36.73968744277954, 37.28316511426653, 36.74237986973354, 36.20707675388881, 36.004359585898264, 35.25522565841675, 35.68680606569563, 34.53328003202166, 36.79051351547241, 36.46052271979195, 34.970585754939485, 36.62141520636422, 36.13474253245762, 37.374648571014404, 38.6702687399728, 38.197384766169954, 43.373414039611816, 47.88236066273281, 47.25965963091169, 48.3676506451198, 48.234943526131765, 44.477048533303396, 41.835624831063406, 37.88313511439732, 37.939874104091096, 36.44148465565273, 35.881529331207275, 36.361267702920095, 37.28519746235439, 36.43938282557896, 37.72758231844221, 36.05054078783308, 36.738266536167686, 35.546487195151194, 38.06694275992257, 36.85074050085885, 36.90731620788574, 37.67994894300188, 37.445085934230256, 35.929430212293354, 35.446259430476594, 36.44799859183175, 35.91453674861363, 35.42458799907139, 35.77141080583845, 36.186291217803955, 34.89413472584316, 35.334834643772666, 35.94858292170933, 34.59103693280901, 35.332416670663015, 34.78691707338606, 35.732337611062185, 35.08124623979841, 35.525930949619834, 37.05182484218052, 35.56099155970982, 37.25826277051653, 36.85735171181815, 35.717836720602854, 37.01536069597517, 36.502885886601035, 38.173059122903005, 36.454453468322754, 38.317814418247764, 39.251930236816406, 38.90088987350464, 39.566714899880544, 38.69389261518206, 38.53989621571132, 42.939849921635215, 50.698715686798096, 52.93107114519392, 53.83015414646694, 54.60932166235787, 53.29471901484898, 52.90214579445975, 54.80956874574934, 55.516641753060476, 56.54094866343907, 56.26597023010254, 56.04727220535278, 47.8962779045105, 0.8100323911224092, 1.6627870840685708, 1.2709955360208238, 0.03372364165261388, 1.352040084345, 51.649600982666016, 62.28086594172886, 62.989220891680034, 56.092154094151084, 35.17850712367466, 30.89559234891619, 49.059458460126606, 46.63320657185146, 69.01874256134033, 26.699950422559464, 0.21858206311506884, 0.04953030150915895, 0.03246299822681716, 0.05256863543763757, 0.0561214414026056, 0.04549928781177316, 0.06658596452325583, 0.05317667406052351, 0.13726934418082237, 0.1919824182987213, 0.12244363900806222, 0.05770119306232248, 0.10245739681912319, 0.12141249648162297, 0.154316885130746, 0.11275710378374372, 0.13039691081004484, 0.7962360914264406, 48.26393835885184, 64.68818746294293, 50.60285486493792, 45.83725915636335, 26.32722646849496, 39.921076502118794, 43.4146272795541, 54.568414143153596, 52.36545998709542, 60.55667740958077, 15.19123567853655, 0.6677424577730042, 0.9968766165631158, 1.0702038875647952, 14.259115730013166, 67.65646484919957, 52.45987210954939, 57.680512292044504, 48.37076691218785, 47.536649567740305, 46.67326988492693, 47.57958596093314, 47.03148773738316, 47.49270568575178, 47.08806691850935, 47.42357110977173, 45.40345879963466, 43.121371609824045, 42.88131134850638, 38.84054476874215, 40.28126416887556, 39.68792622429984, 37.1866581099374, 37.80711139951433, 38.866423334394185, 38.35923263004848, 37.92681149074009, 35.22542136056082, 38.351304735456196, 37.77192572184971, 36.80167927060808, 35.83384037017822, 37.01401621954781, 35.4497126851763, 37.46617719105312, 37.518344266074045, 36.11735119138445, 37.728812149592805, 34.570758615221294, 34.647018568856375, 36.91198887143816, 37.94614485331944, 36.42816843305315, 37.12751504353115, 36.59169428689139, 36.942835399082725, 35.53847939627511, 36.67922421864101, 38.07380758013044, 37.61681066240583, 38.32814291545323, 38.892138617379324, 39.016976901463096, 39.86080435344151, 38.731124537331716, 36.511213302612305, 36.357220377240864, 36.38963024956839, 41.22063977377755, 38.39935500281197, 36.13320698056902, 38.360639640263145, 37.640632561274934, 40.02660921641758, 41.61635357992989, 40.82428673335484, 44.12069974626814, 50.44284132548741, 50.87530415398734, 50.32448918478829, 50.757205622536794, 46.15989875793457, 44.447025367191856, 38.63086550576346, 40.57645838601248, 39.86475787843977, 38.35952098029, 39.1075154032026, 38.91338620867048, 38.49163402829851, 39.77060283933367, 37.66964823859078, 38.23717015130179, 36.760983671460835, 39.45889275414603, 38.99354757581438, 37.61523689542498, 38.81668812888009, 39.62368665422712, 37.289505345480784, 37.17660754067557, 39.927670342581614, 38.030395235334126, 38.15086310250418, 37.87524196079799, 37.919078145708355, 37.30366924830845, 38.1420910017831, 36.66622413907732, 38.178787912641255, 38.08631086349487, 36.7221918787275, 38.73863901410784, 37.68319722584316, 36.91076251438686, 38.989750385284424, 37.94942440305437, 40.670394556862966, 40.70364516122, 39.52283007758004, 39.135888372148784, 38.15975679670061, 39.49749347141811, 38.56092493874686, 40.08775336401803, 42.01613903045654, 40.83403853007725, 42.17064264842442, 39.72166667665754, 39.96274832316807, 46.1810108593532, 52.395048890795024, 54.80431938171387, 56.831765515463694, 56.261773518153596, 55.01635408401489, 55.968920843941824, 57.76583617074149, 57.536173888615195, 58.74652576446533, 58.394001960754395, 57.67941100256783, 50.30964435849871, 1.3483480938843317, 2.5035008745534078, 2.2280061032090868, 0.1214982768786805, 1.637168098773275, 56.703095299857004, 69.12305586678642, 66.58795697348458, 64.57727336883545, 40.65915584564209, 35.776816504342214, 58.378840991428916, 53.46057251521519, 80.78630896977016, 34.63052701950073, 0.30282255208918024, 0.18575576027589186, 0.11822815878050667, 0.14108322667224066, 0.12332759371825627, 0.15522213226982526, 0.07200095217142786, 0.14543055982461997], [0.044545881649745364, 0.02051246475561389, 0.031096065683024268, 0.02891157308061208, 0.04035482189751097, 0.052671372424811125, 0.026671905403158495, 0.027264144338135208, 0.019852828633572375, 0.055702357819037776, 20.600359644208634, 53.6538644518171, 43.936159065791536, 37.67367124557495, 18.401814120156423, 23.014021396636963, 27.936019318444387, 46.90472480228969, 47.914377961839946, 53.28937585013253, 15.329871347972325, 0.24714394978114537, 0.13708415840353283, 0.33096177929214066, 6.046093557562147, 59.60397515978132, 49.52012402670724, 52.7353230203901, 47.16985763822283, 47.73719194957188, 47.47649206433977, 47.771043573107036, 44.08834545952933, 46.399055753435405, 46.925597190856934, 46.81064966746739, 45.271717480250764, 43.80163846697126, 44.0809907913208, 39.94292858668736, 34.86564016342163, 35.389930384499685, 35.40337862287249, 35.73379673276629, 33.41052062170846, 33.281961577279226, 32.39916862760271, 33.649312836783274, 33.42550788606916, 32.679500647953574, 33.397760254996165, 32.39715017591204, 33.222905363355366, 32.40720074517386, 33.17919077192034, 32.39471483230591, 32.55608327048165, 33.52088580812727, 32.347849232809885, 31.96315179552351, 33.62235035215105, 33.45940119879586, 32.913929394313264, 32.990925856998985, 34.004150390625, 32.868189402988975, 33.41807331357683, 33.54340839385986, 33.40496901103428, 33.317126410348074, 35.3996057510376, 34.59361818858555, 34.68133919579642, 35.092363357543945, 33.907125745500835, 32.79718576158796, 34.4576940536499, 34.66741500582014, 34.69312334060669, 34.64158507755825, 31.523629597255162, 33.27651071548462, 34.04509265082223, 35.731771332877024, 35.66352265221732, 35.80454329081944, 39.47494656699044, 45.25982563836234, 46.77106230599539, 48.4727213042123, 45.117999008723665, 43.71446289334978, 37.55577073778425, 35.998495306287495, 34.03920405251639, 33.860562392643516, 33.664327893938335, 33.903814928872244, 35.66986983163016, 33.92363119125366, 33.80680070604597, 34.44156381062099, 33.44051946912493, 34.10313442775181, 35.46356739316668, 34.935177734919954, 36.939277921404155, 35.25093861988613, 36.07777425221035, 35.02559116908482, 35.27012954439436, 34.224321433476035, 33.67060211726597, 33.75119079862322, 33.60649108886719, 34.69590262004307, 34.605652468545095, 33.40190832955496, 34.53120599474226, 33.2612281526838, 33.39787837437221, 33.85717167173113, 33.10979911259243, 33.322323662894114, 34.84785277502877, 33.691769804273335, 34.11089209147862, 33.12863915307181, 33.37413985388619, 34.56499508449009, 35.63884265082223, 35.91399131502424, 36.98017501831055, 36.77733973094395, 35.177506583077566, 37.52180446897234, 38.16710104261126, 36.94696262904576, 38.268947737557546, 37.082990986960276, 41.751002720424104, 49.50880193710327, 52.34131152289254, 50.13631807054792, 52.01263393674578, 51.93558536257063, 48.437942096165244, 50.2597667149135, 55.23572260992867, 56.12234401702881, 57.39295761925833, 50.70188059125628, 36.62799515042986, 0.558796440916402, 0.9220123823199953, 0.3386308534869126, 0.03447432190712009, 0.9609076380729675, 45.90483038766043, 58.19584628513881, 54.71805402210781, 55.924886635371614, 26.25570171219962, 21.89391098703657, 42.864861488342285, 35.336411884852815, 59.45024626595633, 14.42505955696106, 0.10661080466317278, 0.06051203116242375, 0.01998145512438246, 0.03589637863582798, 0.011496468862917806, 0.02979199940870915, 0.05245878401079348, 0.03548518980720213, 0.046629252178328376, 0.06465721516204731, 0.0727541803249291, 0.01931056719539421, 0.004241121641825885, 0.03696797202740397, 0.04473830061033368, 0.023751254891976714, 0.01648425340785512, 0.022117239090480974, 24.98006108828953, 61.31348214830671, 49.0626129422869, 43.884339400700156, 19.77031741823469, 29.567934036254883, 34.97506386893136, 49.22853592463902, 52.21876267024449, 57.71752534593855, 16.19253362928118, 0.3785299339464733, 0.3182392476924828, 0.3470587469637394, 6.560560328619821, 62.08616352081299, 50.75115026746477, 53.48821939740862, 48.730683599199565, 48.362071241651265, 48.82046127319336, 49.45871237346104, 48.38928733553205, 48.449055739811485, 49.001420157296316, 47.62095900944301, 46.79019069671631, 46.55865587506975, 44.982846123831614, 40.52588939666748, 36.14001274108887, 36.24384662083217, 37.662286622183665, 37.89941821779524, 34.94750036512102, 34.95945474079677, 33.2443961415972, 36.06334284373692, 35.35901437486921, 34.803662231990266, 35.32050051007952, 34.71568414143154, 34.732634271894185, 35.055162702287944, 33.6818790435791, 35.07563556943621, 33.60197128568377, 35.04482725688389, 33.90512466430664, 33.305345739637104, 34.833115645817344, 35.43854693004063, 34.23499386651175, 33.67981890269688, 33.66204193660191, 34.331202098301475, 35.94957651410784, 35.361098834446494, 35.33400433404105, 36.09282405035836, 36.24183859143938, 37.28919962474278, 37.310985701424734, 36.04027829851423, 36.874791690281455, 35.05919613157, 34.088407720838276, 35.750138895852224, 35.82256344386509, 36.04824788229806, 34.28667804173061, 35.627892289842876, 37.04194450378418, 37.35955360957554, 37.10750075748989, 37.21138674872262, 39.08880043029785, 47.849172592163086, 49.56936591012137, 49.12753343582153, 48.94557401112148, 46.02541984830584, 39.68298952920096, 37.425130707877024, 37.01031630379813, 35.65535157067435, 36.849684374673025, 36.186058453151155, 38.02986717224121, 36.09027753557478, 35.72904416493007, 36.803517069135395, 35.134476389203755, 36.345276423863, 36.6637853213719, 37.09187078475952, 38.465574809483115, 36.94771998269217, 36.82921150752476, 35.704847063337056, 37.21923473903111, 36.74842480250767, 35.3008371080671, 35.745987347194124, 34.137986591884065, 35.19689553124564, 34.60939407348633, 36.35483019692557, 37.0487711088998, 34.97496312005179, 35.56042875562395, 37.36328131811959, 35.87803438731602, 34.781896999904085, 36.45100021362305, 36.52946622031075, 35.15025574820382, 36.14118003845215, 34.832601479121614, 36.22982515607561, 36.38794183731079, 38.1663749558585, 39.16948986053467, 37.529173033578054, 38.36645875658308, 39.84561211722237, 40.66519035611834, 40.09060559953962, 40.067290919167654, 39.555267742701936, 45.45767559323992, 51.545833110809326, 53.99724095208304, 51.36519036974226, 51.94043867928641, 53.3352061680385, 51.28979546683175, 53.291363034929546, 56.99938038417271, 56.932215622493196, 59.02755260467529, 52.115352630615234, 38.64557484218052, 0.8813629235540117, 1.1588620330606187, 0.9702183327504567, 0.00809926285208868, 1.1938221114022392, 49.24626077924456, 65.44765336172921, 59.14649881635393, 62.114074434552876, 29.56057241984776, 24.825510569981166, 48.0442328453064, 43.014122690473286, 67.66010570526123, 20.409206015723093, 0.2368454166821071, 0.024243896760578667, 0.05639403606099742, 0.008813642331265976, 0.03005413105711341, 0.06708352068173033, 0.046601113331105025, 0.09127645606973342, 0.22592439555696078, 0.17611699391688618, 0.14899603064571107, 0.11513321128274713, 0.13615869092089788, 0.19167189353278705, 0.14418445740427288, 0.0918705202639103, 0.09978681190737657, 0.11408830806612968, 28.82128930091858, 72.01805755070278, 54.525898115975515, 48.568457058497835, 26.370447737830027, 31.950756209237234, 38.99524988446917, 58.77997439248221, 57.42401259286063, 63.19537394387381, 18.239712647029332, 0.4267936684191227, 0.508137124989714, 0.7958954125642776, 8.651762264115469, 65.14961733136857, 52.91048015866961, 56.50454705102103, 51.342685154506135, 51.20286308016096, 51.08038023539952, 51.48086745398385, 49.757408482687815, 50.83470582962036, 51.33124147142683, 50.04617214202881, 48.91183008466448, 48.15551519393921, 47.113316672188894, 42.528954301561626, 37.710083280290874, 38.184301308223176, 40.03038556235177, 41.10263851710728, 37.146358558109824, 37.13187503814697, 34.9587390763419, 38.22307573046003, 37.68723412922451, 35.91461665289742, 36.8921274457659, 37.83049208777291, 35.89190993990217, 38.53062037059239, 36.75665841783796, 37.23967286518642, 35.846267223358154, 36.96364177976336, 36.14176716123308, 34.61397988455636, 36.055005005427766, 36.859821796417236, 35.44382061277117, 36.7563214302063, 36.29777159009661, 35.613811765398296, 36.852335112435476, 36.71187380381993, 37.01240076337542, 37.46538857051304, 38.44403886795044, 38.04028252192906, 38.48562036241804, 37.17768451145717, 36.61459902354649, 37.512493882860454, 36.181232929229736, 38.9883086340768, 39.343597820826936, 38.57858031136649, 35.86578123910086, 36.80010550362723, 39.55125863211495, 39.75462545667376, 40.08326482772827, 40.09830072947911, 42.27977800369263, 49.402602195739746, 51.093592235020225, 51.02465220860073, 50.50565651484898, 47.69876493726458, 42.503030572618755, 39.46484388623919, 39.23711667742048, 38.91778094427926, 39.66323927470616, 39.311302593776155, 40.30930015019008, 38.12034314019339, 38.12402221134731, 39.249477522713796, 36.290736539023264, 39.16505690983364, 38.74156073161534, 38.56243617194039, 41.06953729901995, 37.50790112359183, 39.899116720472065, 38.264288970402305, 38.99364137649536, 37.23773431777954, 37.31317090988159, 37.40252821786063, 35.63645594460623, 37.22364337103707, 36.33743190765381, 37.34992340632847, 38.4125565801348, 36.90248026166643, 37.8369573865618, 40.15246888569423, 38.491772992270334, 36.70155572891235, 38.94302722385952, 38.243548597608296, 36.85119560786656, 38.24202694211687, 36.651493958064485, 37.60625287464687, 39.49613162449428, 39.55677202769688, 41.08227334703718, 41.34059347425188, 39.67923402786255, 41.70578384399414, 42.91533667700631, 42.63080447060721, 42.80684750420706, 40.28365434919085, 47.25620985031128, 53.41417939322335, 56.92139032908848, 52.749059609004426, 54.89339181355068, 56.18735136304583, 55.41518415723528, 55.916500159672324, 60.001592772347585, 60.186164719717844, 60.86264133453369, 53.4266722542899, 42.60171236310686, 1.4344739466905594, 2.417090037039348, 3.3559258537633077, 0.13836311548948288, 1.4154217690229416, 53.46513748168945, 70.4738551548549, 63.8833498273577, 69.86468573978969, 37.914568764822825, 31.060365404401505, 56.0248191016061, 51.59997347423008, 77.87095601218087, 28.548840011869157, 0.5008733261908803, 0.16346173227897712, 0.16706335544586182, 0.11007568266774927, 0.14250813664070197, 0.1290657336690596, 0.2104588182909148, 0.16325134571109498], [0.05966605405722346, 0.04034279825698052, 0.06529418312545333, 0.02036711576926921, 0.012893730225706739, 0.016662148326369267, 0.0698145359222378, 0.04034085764682718, 0.045508532851402245, 0.08734952285885811, 9.705758827073232, 54.130656787327354, 39.99670416968209, 43.54460375649588, 32.420979022979736, 27.976039205278667, 31.23918424333845, 48.003106457846506, 47.347668988364084, 54.974001339503694, 20.41938512665885, 0.15457219071686268, 0.15161197313240596, 0.22594068039740833, 3.1375287728650227, 53.92440298625401, 53.68356452669416, 49.88561316898891, 50.419891425541465, 49.776196411677766, 50.64872687203543, 47.69837931224278, 47.43639053617205, 47.264568533216206, 48.154823848179404, 48.071070262363975, 47.87015267780849, 47.48004954201834, 46.77737474441528, 44.168597153254915, 35.19603048052107, 35.728571687425884, 34.2092091015407, 34.00543580736433, 33.24093246459961, 32.91783775602068, 32.27800941467285, 34.46992635726929, 33.933382987976074, 35.075621673039024, 33.69191919054304, 34.46136270250593, 31.55336093902588, 31.021684782845632, 33.176150935036794, 32.45794691358294, 31.719471522739955, 31.385495935167583, 32.48656306947981, 32.83557455880301, 33.44632468904768, 32.71865374701363, 31.75699179513114, 33.41746187210083, 33.34380054473877, 32.700623171670095, 33.150605882917134, 34.872032506125315, 34.95202016830444, 35.914637497493196, 36.75474418912615, 35.3467994417463, 33.80835362843105, 34.91537536893572, 34.93164457593645, 34.494199889046804, 33.69711296898978, 33.57699251174927, 34.631343432835166, 34.424071720668245, 32.28855678013393, 33.189349038260325, 35.09108141490391, 35.00865493501936, 35.58295828955514, 34.935865606580464, 39.14916637965611, 46.27056271689278, 47.672591073172434, 46.60724115371704, 46.845540046691895, 45.323168890816824, 38.20199837003435, 34.18375437600272, 34.79742274965559, 33.63627801622663, 33.446692943573, 33.405504022325786, 33.567959853581016, 36.215713364737375, 35.18241548538208, 33.62792975561959, 34.230494907924104, 34.88361515317644, 35.99948195048741, 35.88055658340454, 36.95543943132673, 36.547830309186665, 35.77174779347011, 35.19318519319807, 34.65218455450875, 35.56201294490269, 33.147166524614605, 32.541724818093435, 33.92201920918056, 33.41755567278181, 32.88095324380057, 33.92515632084438, 34.450964723314556, 34.524188314165386, 33.33082825796944, 32.828185149601524, 33.45817484174456, 32.83587333134243, 32.43050847734724, 34.408733572278706, 34.044543743133545, 33.752608231135774, 32.54804767881121, 35.17801380157471, 34.596407890319824, 36.254616328648154, 35.42738117490496, 36.96563243865967, 37.5976232119969, 36.56152868270874, 36.93024526323591, 37.163937500544954, 38.20727552686419, 36.81125388826643, 40.474090576171875, 46.52213961737496, 49.38226481846401, 49.2542998450143, 50.65694659096854, 48.65477452959333, 51.02400255203247, 53.41535711288452, 53.1010206086295, 55.25641434533255, 53.769697870527, 55.751661096300396, 40.105210712977815, 0.3836151739316327, 0.6208945001874651, 0.8429128953388759, 0.05927756561764649, 1.126943745783397, 46.967821393694194, 55.22551918029785, 56.25359896251133, 53.86262307848249, 32.277342387608115, 22.316714082445415, 37.62992191314697, 39.89852959769112, 57.97435508455549, 14.752642801829747, 0.0954739415485944, 0.13791863434016705, 0.07885423049862895, 0.00348391430452466, 0.04485572788066097, 0.033513326330908706, 0.028125242596226077, 0.048980026572410545, 0.02956305830074208, 0.07182609369712216, 0.0759081400132605, 0.019602099766156504, 0.027935709105804563, 0.020163299116705145, 0.07805397986833539, 0.017397444495665174, 0.011978123553230293, 0.13429400883615017, 11.513885072299413, 61.920205797467915, 44.18539789744786, 46.94317613329206, 30.820694242204937, 27.375447341373988, 37.04836463928223, 54.00683988843645, 51.03547402790615, 59.41128771645682, 20.60539013998849, 0.1936015792723213, 0.16540032039795602, 0.25214553996920586, 3.918310225009918, 55.94513716016497, 55.660069942474365, 52.248956067221506, 50.59035505567278, 52.34045689446585, 51.031517028808594, 48.84737164633614, 48.32125057492937, 48.538239342825754, 50.555172852107454, 49.329583576747346, 50.50658409936087, 49.10916934694563, 47.251599720546174, 47.01056323732649, 36.679724488939556, 38.166711943490164, 36.3857045173645, 36.33429479598999, 34.89131028311593, 35.47158908843994, 35.40753017153059, 36.11488458088466, 35.747317927224294, 36.99946321759905, 35.85243027550833, 35.42997980117798, 34.11878524507795, 32.766137736184255, 34.78706645965576, 34.444749559674946, 34.664673941476, 32.95826584952218, 33.38050092969622, 35.01000983374459, 34.87228611537388, 34.09681156703404, 34.61860738481794, 34.663395472935264, 34.07936116627285, 33.90271363939558, 35.26621423448835, 35.758525371551514, 37.22512681143624, 36.629756518772666, 37.62167092732021, 37.453840664454866, 36.401727063315256, 35.434075764247346, 35.73896966661726, 35.925038950783865, 36.18669421332223, 36.417530741010395, 37.18517814363752, 35.88546895980835, 34.06107003348214, 35.07003879547119, 37.65509523664202, 39.13305350712368, 37.394475255693706, 37.43919733592442, 40.68729952403477, 47.1790257862636, 48.81676830564226, 47.60072932924543, 47.232707568577354, 47.37392623083932, 38.840329374585835, 36.702834197453086, 37.08797631944929, 34.88355956758772, 34.94424860818045, 36.762894426073345, 35.53243098940168, 36.891272817339214, 36.053538935525076, 34.61761726651873, 34.63161093848092, 37.409240177699495, 36.98977048056466, 36.80470521109444, 36.73895788192749, 39.05060270854405, 37.21617405755179, 37.06919533865792, 36.65108054024832, 37.4688001360212, 35.72517054421561, 34.98959255218506, 34.35213007245745, 35.25232131140572, 35.537999970572336, 35.24401126589094, 36.06342969621931, 34.71505185535976, 35.49142966951643, 35.623768533979145, 35.0493540082659, 36.204874174935476, 35.02051898411342, 36.16966765267508, 36.23651279721941, 35.53996631077358, 36.00870221001761, 37.510558809552876, 37.1562180519104, 38.38962752478463, 38.26236431939261, 39.39314195087978, 39.176073278699604, 39.5308517728533, 38.31426041466849, 38.959136622292654, 39.26791109357561, 39.44927297319685, 42.12220328194754, 48.525541509900776, 50.86120973314558, 51.998688902173726, 53.395207336970735, 52.60326903206961, 52.305514403751914, 55.55610752105713, 54.953549316951204, 56.697821617126465, 55.62594733919416, 55.92624153409685, 40.89926127025059, 0.9488891001258577, 0.9116821480648858, 0.9172425525529044, 0.1194798116173063, 1.3371165479932512, 52.0783326285226, 61.619654519217356, 58.68787602015904, 60.96705886295864, 30.43245322363717, 23.647997617721558, 46.07382099969046, 43.173166956220356, 66.85756792340959, 18.480531999043055, 0.22419514906193527, 0.018222120690292547, 0.0179783569848431, 0.0811971847766212, 0.01593158154615334, 0.03968275331759027, 0.07231773303023406, 0.053106941016657014, 0.12629576373313153, 0.21615111641585827, 0.11458925689969744, 0.12115332324590002, 0.20341109218341963, 0.27232905264411655, 0.2375190391072205, 0.12105241151792662, 0.10416554087506873, 0.19598707769598278, 13.623175774301801, 73.15842369624546, 51.656253882816856, 56.054564339774, 42.99929176058088, 37.76956680842808, 42.07321153368269, 60.43264511653355, 54.92552375793457, 64.58240113939557, 24.24738918031965, 0.2793661393225193, 0.24671701554741177, 0.6254615294081824, 4.5543743797710965, 57.399596623011995, 59.15545504433768, 54.35401010513306, 53.992109707423616, 53.86981446402413, 54.240636348724365, 51.20810202189854, 51.33250604357038, 51.128812653677805, 52.65495320728847, 52.50255489349365, 51.676080567496165, 51.97109760556902, 48.68887281417847, 49.03565393175398, 39.80888046537127, 39.851670946393696, 37.721179553440635, 38.69192974908011, 37.361064842769075, 37.27647399902344, 36.54954651423863, 39.401531900678364, 38.06681074414934, 39.44728231430054, 37.769511222839355, 37.801504203251426, 37.36000176838466, 34.94944586072649, 38.03943484170096, 35.9970292363848, 36.80303416933332, 34.2701586995806, 35.93986988067627, 36.792615345546174, 37.13430690765381, 35.684669494628906, 34.209667682647705, 35.88340881892613, 36.348663670676096, 36.131417819431846, 36.22988074166434, 38.26764842442104, 39.110138348170686, 39.97111395427159, 40.523224762507844, 39.18799638748169, 37.70215538569859, 37.04680824279785, 38.28411912918091, 39.029038974217, 36.650253704616, 38.49766853877476, 37.889666421072825, 38.19064153943743, 36.1546630178179, 37.25418070384434, 40.88548299244472, 40.99221774509975, 38.74582345145089, 38.36455842426845, 42.041670186179026, 50.1811443737575, 51.46398333140782, 47.89537116459438, 49.05765192849295, 48.86440168108259, 41.268221037728445, 38.810247148786274, 38.88503408432007, 37.076251234327046, 36.85448210580008, 37.71001379830496, 37.660837922777446, 40.07651117869786, 38.427700178963796, 37.55498559134347, 37.55391556876046, 38.9511844090053, 39.345432145254954, 39.921590668814524, 39.32639060701643, 41.25585324423653, 38.264820507594514, 39.45770461218697, 38.53451483590262, 39.166665417807444, 36.62842246464321, 35.884642124176025, 37.3353009223938, 37.33526965550014, 37.018796580178396, 37.05431924547468, 38.46396630150931, 36.72177846091134, 37.086617946624756, 36.752142088753835, 37.41932896205357, 38.25089979171753, 37.44673613139561, 39.172213554382324, 39.2236510685512, 39.42299836022513, 37.755208356039866, 38.95854255131313, 38.738465309143066, 41.19140175410679, 39.2935916355678, 42.362569264003206, 41.398951394217356, 40.76659236635481, 40.20015089852469, 41.33574710573469, 41.34846230915615, 41.80454206466675, 44.69871343885149, 50.76262869153704, 54.4297593661717, 53.744302204677034, 55.7939304624285, 54.89758505140032, 56.0354185785566, 58.75739969526018, 57.90475150517055, 58.56376729692732, 57.341429778507774, 55.57921028137207, 45.24033941541399, 1.7344295254775455, 3.203014458928789, 2.661595408405576, 0.22697155150984014, 1.5254347686256682, 56.72693109512329, 64.81141376495361, 65.34645284925188, 65.2879420689174, 47.05941949571882, 32.51845530101231, 51.74495458602905, 52.84532342638288, 76.070816721235, 26.58346561023167, 0.6439231644783701, 0.16895458182053907, 0.22687434458306857, 0.13924941793084145, 0.1370389544005905, 0.12749804636197432, 0.11004557606897183, 0.15152376357998165], [0.051600569526531866, 0.0890818295468177, 0.008907912897744348, 0.030542201296027218, 0.02004867758867996, 0.009637539906959449, 0.038755915194217644, 0.03682066546753049, 0.0355272759417338, 0.05047857116109558, 3.50134339928627, 49.756352356501985, 48.6575607572283, 44.7723365511213, 25.911305563790457, 24.155450616564067, 27.833997181483678, 42.46589592524937, 50.80721180779593, 51.36644799368722, 28.52623404775347, 0.04232849706230419, 0.10626402577119214, 0.1809053612606866, 2.1568554639816284, 46.5587739944458, 51.20955766950335, 53.060818331582205, 52.50032452174595, 50.087183884211946, 49.79273312432425, 43.500385420663015, 46.19016858509609, 48.28051676068987, 47.87276520047869, 46.80730063574654, 46.411489554813926, 48.81913069316319, 46.24612242834908, 44.29666634968349, 35.391052518572124, 33.81381491252354, 33.739774908338276, 33.46239587238857, 33.16919231414795, 34.522447790418354, 35.35461963926043, 37.74844775881086, 37.187693391527446, 38.43919249943325, 37.48850522722517, 34.97922931398664, 32.8965345791408, 32.50442688805716, 32.647816862378804, 31.080793108258927, 32.673490456172395, 32.26354326520647, 33.46717970711844, 32.01028837476458, 33.43821266719273, 32.338868686131065, 32.42659316744123, 32.46465539932251, 34.453056131090435, 32.63307973316738, 34.61827734538487, 34.687693323407856, 34.43354211534773, 34.87183100836617, 35.87815250669207, 35.419831957135884, 35.15485545567104, 35.844450269426616, 32.938730989183696, 33.54221330370222, 33.619206292288645, 34.778561864580425, 33.28314971923828, 34.87391199384417, 32.44874055044991, 34.32685252598354, 34.86429916109358, 36.06430516924177, 37.28351599829537, 37.82239396231515, 38.20047671454293, 46.67533349990845, 48.25692067827497, 47.7489344051906, 47.204404081617085, 43.75714915139334, 37.363680839538574, 35.87830536706107, 34.561111041477744, 31.794772624969482, 32.273809228624614, 34.02858025687081, 34.486904280526296, 34.13023240225655, 34.248504638671875, 34.44850853511265, 35.1648712839399, 34.13428667613438, 35.47802659443447, 35.7775217464992, 35.101555824279785, 36.599469321114675, 35.34083093915667, 33.723331996372764, 35.27531290054321, 34.45618976865496, 34.582619190216064, 34.294157777513774, 34.0584123475211, 34.42027105603899, 34.08794566563198, 33.12025615147182, 34.08514206750052, 33.494180406842915, 34.57421881811959, 32.73695182800293, 34.92053093229021, 31.93000888824463, 32.86381203787667, 32.333237171173096, 33.564461435590474, 33.440714018685476, 34.04600286483765, 34.77824919564383, 33.244976316179546, 34.45659623827253, 34.43249641145979, 36.60712971006121, 37.133445331028526, 36.66173560278756, 37.968959263392854, 37.81583833694458, 36.018193449292866, 37.387811933244976, 38.45073345729283, 44.03077268600464, 47.98356812340872, 48.64840997968401, 47.35877915791103, 51.060022013528005, 54.35271774019514, 54.25904560089111, 53.44777045931135, 56.377356801714214, 55.01989419119698, 55.89677422387259, 37.55610077721732, 0.6983238682150841, 0.5793886216623443, 0.7078415432146618, 0.0426154020242393, 1.346531248518399, 49.46263810566494, 57.05637298311506, 58.58470916748047, 47.160230909075054, 35.6047374180385, 33.93154866354806, 49.27072886058262, 44.86259017671858, 54.21277754647391, 9.207148279462542, 0.1547569150903395, 0.04933772648551634, 0.04451574790956719, 0.09406299583081688, 0.02108494644718511, 0.05314333763505731, 0.020629837743139694, 0.021696867986715267, 0.03537766236279692, 0.06496575860572712, 0.021352404595485756, 0.031925143873585124, 0.025090029928833246, 0.015091494124914919, 0.027270559886736528, 0.028465751824634414, 0.027842834625127058, 0.06342901928084237, 4.698412707873753, 57.188374859946116, 53.63683441707066, 50.849682671683176, 28.270840849195206, 23.94003735269819, 30.535272666386195, 47.900339126586914, 55.49146842956543, 56.74859210423061, 30.17243078776768, 0.04379173068861876, 0.08173595515212842, 0.5275297643882888, 2.4170051387378146, 49.49857071467808, 51.76384673799787, 55.55296346119472, 53.90525375093733, 52.48200907026018, 51.04531267711094, 45.74632460730416, 48.045302867889404, 50.72127301352364, 49.354235785348074, 49.05357681001936, 47.509284087589805, 49.33863707951137, 48.75592640468052, 46.25343540736607, 37.454382623944966, 35.442264216286794, 35.214213916233604, 34.69801139831543, 36.144188608442036, 35.78572062083653, 37.445659160614014, 38.36831739970616, 39.48500061035156, 39.60189362934658, 39.94503041676113, 36.35272141865322, 34.58257750102452, 34.829645020621165, 35.13013029098511, 33.64035660879952, 33.95837913240705, 33.91067280088152, 35.353615624564036, 33.93243455886841, 35.34736919403076, 34.116745948791504, 33.5186311176845, 35.50427688871111, 34.84301682880947, 34.73189776284354, 35.96373346873692, 35.58318410600935, 35.226949964250835, 36.81281723294939, 36.92731312343052, 36.36346680777413, 35.33986513955252, 35.80906656810215, 36.14237860270909, 34.665532044001985, 35.51926415307181, 35.429479530879426, 35.83450392314366, 36.109423296792166, 35.22417763301304, 34.93949951444353, 36.8187301499503, 38.05947344643729, 39.13361631120954, 39.61514731815883, 39.25387920652117, 47.780982971191406, 49.686130387442454, 50.291186468941824, 49.02015250069754, 46.04147713524954, 40.11853040967669, 37.23736606325422, 36.7968989099775, 34.77494532721383, 35.20750543049404, 35.427085876464844, 36.21389988490513, 35.836491107940674, 36.76893935884748, 36.29476302010672, 35.09440265383039, 36.213715757642476, 36.936491693769185, 37.553304127284456, 36.52154874801636, 36.52952527999878, 37.67158678599766, 34.82369041442871, 36.5534097126552, 35.82110432216099, 37.347800731658936, 36.46297890799386, 35.65935025896345, 36.52084697995867, 33.90333897726876, 35.39285210200718, 35.26570701599121, 35.770153181893484, 35.07294314248221, 35.98975099836077, 36.80770335878645, 33.99811588014875, 36.14116266795567, 34.39155762536185, 35.119641985212056, 36.98742546354021, 37.15493263517107, 35.79823432649885, 35.53757265635899, 36.438246795109336, 36.57430641991751, 37.64082016263689, 40.18924570083618, 40.79491669791085, 39.04699659347534, 38.86567987714495, 38.572379044124055, 38.25055585588728, 41.125699588230674, 47.77134929384504, 51.1009156363351, 51.19182586669922, 50.263754980904714, 53.427502564021516, 56.84991421018328, 56.40407609939575, 55.886779240199495, 58.24421269553048, 57.19427388054984, 56.28049543925694, 41.877644062042236, 0.7344796338251659, 0.8072165793606213, 0.7213266938924789, 0.04154298421261566, 1.4169984672750746, 52.622043064662385, 60.77618489946638, 62.535885674612864, 51.561789648873464, 37.78325823375157, 35.36977366038731, 52.86401060649327, 50.51904916763306, 62.91789763314383, 15.090464217322213, 0.22260367231709616, 0.0978684780587043, 0.08483855652489833, 0.20629215187260083, 0.04321952210739255, 0.03467503935098648, 0.04950553498097828, 0.07617190014570951, 0.1357443095850093, 0.17532560495393618, 0.08298197614827327, 0.14122479621853146, 0.10634570781673704, 0.1838807916002614, 0.07667675734098468, 0.261686773704631, 0.1476402905370508, 0.2072230340646846, 5.428633638790675, 66.37432765960693, 61.37450817653111, 57.59063386917114, 34.979719161987305, 34.47370270320347, 38.381317479269846, 54.19769648143223, 59.06012575966971, 60.287302698407856, 35.853368282318115, 0.15432134989116872, 0.5888170014534677, 1.4557323945420129, 3.468058053936277, 53.59925855909075, 52.37836626597813, 58.90092168535505, 54.95550870895386, 52.95585189546858, 51.939254011426655, 47.85662106105259, 49.1244831766401, 50.59092133385794, 50.20225647517613, 50.04152727127075, 49.65176459721157, 51.440689495631624, 49.109363896506174, 48.942464692252024, 40.12442248208182, 36.36094461168562, 36.96678931372506, 36.87780026027134, 37.24056223460606, 37.91079241888863, 38.93062121527535, 43.19461257117135, 41.50023875917707, 43.12950447627476, 43.567383425576345, 39.07098872320992, 35.3652469090053, 38.42577205385481, 37.92103058951241, 35.12826469966343, 35.577246870313374, 37.09633847645351, 38.121486118861604, 34.84271805627005, 37.180317878723145, 35.727303641183035, 35.69751671382359, 37.26577377319336, 37.72382681710379, 36.142712116241455, 38.4097877229963, 39.29188585281372, 36.88953924179077, 37.168439933231895, 39.777040345328196, 39.10558727809361, 37.58288260868618, 39.02561698641096, 36.771711690085276, 35.254298073904856, 37.462647506168906, 37.30388464246477, 36.960494245801655, 37.78002732140677, 36.69070611681257, 37.354279926845, 38.32980006081717, 39.07837118421282, 42.007714339665, 41.47541631971087, 41.20240422657558, 51.84951107842581, 51.83904014314924, 52.10841485432216, 52.064846175057546, 47.77010209219796, 43.285310881478445, 38.94546604156494, 38.703495025634766, 36.490024771009175, 36.958930901118684, 39.431165967668804, 39.27736064365932, 37.5807078225272, 38.070552349090576, 37.33051708766392, 37.65344851357596, 38.29926272800991, 38.486773763384136, 39.09746830804007, 38.37885781696865, 38.99086904525757, 40.279964855739046, 36.91070345469883, 38.067661898476736, 38.42865555627005, 38.4934891973223, 38.84735400336129, 36.968776498522075, 39.458187511989046, 37.56719357626778, 37.27318402699062, 36.84923274176461, 37.199630396706716, 37.154877049582346, 37.869214398520334, 38.735453265053884, 36.829909801483154, 37.70869016647339, 35.911687987191335, 37.99822160175869, 38.05445684705462, 39.022320066179546, 39.22182716642107, 37.17848355429513, 37.40828480039324, 39.00838197980608, 40.568228244781494, 41.11588178362165, 41.464917591639924, 40.430476733616416, 42.255799770355225, 40.1715521131243, 39.558714049203054, 42.51939010620117, 49.65440838677542, 54.02936942236764, 54.163021496364046, 52.716799122946604, 56.421880858285085, 58.2446608543396, 58.1224489893232, 57.78292873927525, 60.03808471134731, 58.37535299573626, 57.59570952824184, 44.63267428534371, 1.381758832505771, 2.2464175266878943, 2.6080760402338843, 0.13017591195447104, 1.8252935068947929, 58.19442537852696, 65.65063108716691, 69.28713062831334, 59.246900285993306, 50.32139376231602, 42.32114062990461, 62.144549233572825, 58.568429538181846, 73.66194575173515, 20.654989855630056, 0.32580312181796345, 0.2877604860280241, 0.18670807060386452, 0.2948340507490294, 0.1290838641247579, 0.1191992238163948, 0.10074827567275081, 0.12090711002903325], [0.053477502561041286, 0.07276474511516945, 0.052088663514171324, 0.03431270843637841, 0.01858380190762026, 0.06790660401540143, 0.04341013616483126, 0.03614831190290196, 0.038481329035546095, 0.031622418867690225, 1.3756896896021706, 43.35956627982003, 44.52774259022304, 37.77805403300694, 28.38331307683672, 22.251456601279124, 28.698610169546946, 41.85733447756086, 51.019270828792024, 52.54682534081595, 36.83450950895037, 0.28635076167328016, 0.06057159975171089, 0.3885795532592705, 3.4396084376743863, 41.7773711340768, 47.35648625237601, 47.45014796938215, 51.328253746032715, 50.67417464937483, 45.9910123688834, 43.06930180958339, 41.789815357753206, 40.90802294867379, 48.987381322043284, 45.136762619018555, 48.95034047535488, 45.31032167162214, 46.33133513586861, 38.38093185424805, 32.86521904809134, 35.50104945046561, 35.03879969460623, 34.99570001874651, 36.70492907932827, 39.10636895043509, 38.42857217788696, 38.817577498299734, 41.35867616108486, 39.588521821158274, 38.8087671824864, 34.90365028381348, 31.89807149342128, 31.198589393070765, 31.921834332602366, 31.93316684450422, 32.094761099134175, 31.989040783473424, 31.887798581804546, 33.399577208927695, 32.40844447272164, 32.193880626133506, 32.730274609157014, 30.94080080304827, 33.44890941892351, 31.974307128361293, 33.17915950502668, 32.71830286298479, 35.14870629991804, 35.53116294315883, 34.59381968634469, 33.27992228099278, 34.67045136860439, 34.952294622148784, 35.270744459969656, 34.56352206638881, 33.88015978676932, 33.21397692816598, 35.14701441356114, 33.05136823654175, 33.77939353670393, 32.16561882836478, 35.45768921715872, 38.31169305528913, 37.063959871019634, 35.66212259020124, 40.699257373809814, 44.49498530796596, 48.1564427784511, 47.7047438621521, 46.674044609069824, 45.22351435252598, 36.739621434892925, 37.51271969931466, 34.828272751399446, 32.81430264881679, 33.66062102999006, 32.78463036673409, 34.04993554524013, 35.270230293273926, 34.088035992213655, 33.01794740131923, 34.43047448566982, 35.18841872896467, 35.84603793280465, 34.62712587629046, 34.98331832885742, 37.03091076442173, 36.26541730335781, 36.67948130198887, 34.406656060900005, 34.784915992191856, 33.75002697535923, 33.23913288116455, 33.7671160697937, 33.189046791621614, 34.94454738071987, 32.88021673474993, 33.2763682774135, 31.594466481889995, 35.131936822618755, 33.288496358054026, 33.40267957959856, 32.74840245928083, 33.13842569078718, 32.57231773648943, 32.80487741742815, 33.849090916769846, 33.65066426140921, 34.351098264966694, 33.98992395401001, 34.75525065830776, 35.92559133257185, 36.6944511958531, 34.42850467136928, 36.46454920087542, 35.80579744066511, 37.72115870884487, 41.086025374276296, 39.35951961789812, 38.93787513460432, 42.669714382716585, 43.9435658454895, 47.49280643463135, 51.74363790239607, 50.15889276776995, 52.17487437384469, 52.44242865698678, 53.94261768886021, 52.716284956250874, 53.557235854012625, 53.78901386260986, 36.102169377463206, 0.353343772568873, 0.31555621166314396, 0.36288465346608845, 0.10033247619867325, 1.475603265421731, 48.96051958629063, 56.009387152535574, 57.43032850537981, 51.18266119275774, 30.04177338736398, 22.881234373365128, 46.43744107655117, 45.288928168160574, 58.74817943572998, 9.869255151067462, 0.11555369943380356, 0.060503284846033366, 0.02588867921648281, 0.014554593113384076, 0.04976368023614798, 0.06456903953637395, 0.046423788382006545, 0.00727018466152783, 0.034837090476815186, 0.0059528369123914415, 0.03883744117670825, 0.030011726011122977, 0.01314419531263411, 0.07375898212194443, 0.07362466611500297, 0.02603589926314141, 0.015323011969615306, 0.025764486952019588, 1.797851379428591, 49.48234667096819, 50.63656405040196, 45.46175765991211, 32.08832706723894, 22.359257902417863, 31.775025844573975, 46.88808386666434, 55.18149886812483, 55.47639431272234, 40.8658960206168, 0.30127665932689396, 0.0627085847247924, 0.23262511885591916, 4.25890223469053, 45.893678528921946, 47.912481103624614, 49.2848128591265, 52.75494473321097, 52.20416450500488, 46.84598125730242, 45.80684689113072, 41.104733398982454, 41.63644429615566, 48.74300970349993, 45.7079427582877, 49.617631571633474, 47.71613890784127, 48.491675989968435, 41.15831790651594, 34.08668109348842, 36.68227447782244, 34.41860348837716, 36.225882053375244, 38.162675040108816, 40.08117341995239, 39.9233763558524, 41.10350009373256, 43.193042278289795, 40.77030965260097, 40.944320338112966, 36.35804373877389, 34.79170090811593, 33.5522916657584, 32.93990523474557, 34.562424251011436, 33.62875311715262, 33.5379227910723, 33.75171538761684, 34.101678780147004, 34.08770942687988, 33.81975909641811, 33.52050018310547, 33.78537940979004, 34.1936069216047, 33.64358057294573, 34.548291615077424, 34.64972489220755, 36.38941832951137, 37.219172205243794, 36.298035621643066, 35.648069858551025, 36.86916364942278, 37.74769040516445, 37.67304590770176, 36.777437005724224, 35.81254761559622, 35.91687134334019, 35.98250750132969, 35.81611551557268, 34.62510395050049, 35.387793813432964, 35.978557450430735, 39.907141889844624, 40.9418363571167, 38.391322885240825, 42.92657538822719, 46.80403845650809, 49.24124417986189, 48.33096415655953, 47.90145083836147, 47.237081459590364, 38.60691506522042, 38.27057709012713, 35.87676286697388, 35.349540506090435, 33.858366761888774, 34.03764418193272, 36.80132491247994, 37.62784787586757, 35.47294398716518, 35.08834382465908, 36.56122991016933, 35.825214181627544, 36.80890539714268, 36.47672244480678, 36.835020201546804, 39.68016161237444, 37.266875062670024, 35.38062674658639, 36.33344711576189, 37.151402950286865, 35.50134474890572, 34.69256748471941, 34.97341367176601, 34.84277711595808, 37.577546392168315, 34.68958323342459, 35.63950967788696, 35.16536113194057, 36.74772650854928, 35.029162543160574, 35.809299332754954, 34.95134619304112, 35.11293697357178, 34.65832328796387, 36.30098513194493, 36.39904853275844, 34.375621931893484, 35.704381534031455, 37.186018875667024, 38.16043772016253, 38.33541767937796, 38.632216930389404, 37.85316753387451, 39.753843784332275, 37.57306827817644, 39.373120716639924, 42.46206051962716, 40.93135847364153, 42.04044035502842, 44.29546431132725, 46.88617311205183, 49.47890731266567, 52.685671193259104, 52.778353214263916, 53.50330393654959, 54.65612472806658, 55.48604883466448, 55.270508766174316, 55.12295682089669, 55.4877233505249, 39.758464336395264, 0.5764550705041204, 0.5360032554183687, 1.5750066914728709, 0.0926622213529689, 1.4779888859816959, 55.57942567552839, 59.78155721936907, 62.08296734946114, 55.127987316676546, 39.78515236718314, 30.438237598964147, 52.77127647399902, 51.145106179373606, 68.2174346106393, 13.608971050807408, 0.23259770604116575, 0.06777514464088849, 0.08801368650581155, 0.1209017631730863, 0.014480532712436147, 0.02518564399464854, 0.02985009896968092, 0.010827008401975036, 0.12590378762355872, 0.17359148657747678, 0.12196597749633448, 0.11427812145224639, 0.20416446961462498, 0.15119527120675358, 0.17693272871630533, 0.07305236932422433, 0.12958090459661825, 0.12251176392393452, 1.8533961474895477, 56.020132541656494, 59.01041834694998, 50.626631600516184, 38.84042664936611, 31.131970064980642, 39.85046543393816, 51.67324570247105, 59.47693429674421, 59.11000687735421, 45.65581737245832, 0.4871915632060596, 0.1929025932082108, 0.6212672059025083, 5.943622393267495, 48.84659692219326, 48.25165741784232, 50.6585933140346, 54.72398778370449, 53.73991094316755, 48.7820759500776, 45.864471776144846, 41.662885665893555, 42.774291719709126, 48.585257802690776, 47.38283729553223, 52.5065153666905, 49.30962487629482, 49.64730385371617, 42.92486613137381, 35.184107371738975, 38.847430433545796, 39.007520403180806, 38.26573766980852, 41.05654069355556, 42.49298695155552, 41.06179353169033, 44.35018137523106, 44.99762494223458, 43.348845209394185, 41.96848133632115, 39.484024388449534, 37.56065879549299, 35.16376999446324, 35.58185700007847, 37.59542063304356, 35.481163706098286, 35.377916949135916, 35.97957536152431, 37.55749041693551, 36.18803868974958, 35.03371013913836, 36.34607546670096, 34.616703578404014, 36.61545712607247, 35.556339740753174, 35.12454046521868, 36.84600182941982, 37.99120739528111, 38.94704328264509, 38.05077430180141, 36.70570032937186, 39.381705215999055, 38.857745034354075, 38.7681097984314, 39.026426451546804, 36.60230418613979, 35.85311814716884, 37.91326250348772, 38.08580017089844, 36.646699701036724, 37.851069177900044, 39.10011904580252, 43.12510974066598, 42.77717522212437, 38.70863321849278, 44.382111821855815, 47.17246321269444, 52.44104249136788, 50.5201678276062, 49.608147280556814, 49.70256635120937, 40.23053537096296, 41.28091539655413, 38.996851444244385, 37.78229938234602, 36.62574740818569, 36.181778362819124, 38.14252873829433, 39.726033619471956, 37.20555721010481, 37.09267677579607, 38.30859068461827, 37.855863434927805, 38.809260504586355, 38.44749559674944, 38.28510577338082, 41.14479323795864, 39.175652912684846, 39.89013269969395, 37.81800964900425, 39.31751428331648, 37.096435751233784, 35.86601400375366, 36.601776123046875, 36.962036745888845, 39.48322881971087, 35.85428891863142, 37.54265948704311, 36.302621432713096, 38.84719072069441, 37.6109151159014, 38.63184520176479, 37.354915687016074, 37.86754335675921, 38.09539563315255, 38.243993282318115, 39.423001834324424, 36.46438244410923, 37.165792669568745, 38.811087880815776, 41.396873882838655, 39.29337624141148, 41.243457657950266, 39.32849938528878, 41.67498247964041, 40.39636107853481, 41.502847807747976, 44.937988553728374, 43.52985273088728, 44.02533572060721, 46.60626493181501, 49.52672134126936, 51.1508002281189, 55.45916625431606, 55.3611375944955, 56.02030624662127, 57.60744850976126, 57.25589745385306, 57.06731292179653, 56.78746032714844, 56.49290534428188, 41.18193483352661, 0.786457858979702, 1.1221790185996463, 3.26014906167984, 0.15003277787140437, 1.9469755717686243, 59.46376051221575, 66.03959819248745, 66.98857620784214, 63.09152616773333, 43.9038290977478, 33.23030172075544, 61.47792516435896, 58.26417139598301, 79.45900848933628, 18.314367566789898, 0.3822676848087992, 0.16569385464702333, 0.13511646113225392, 0.14012109115719795, 0.04799178442252534, 0.1735288577952555, 0.08141852289970432, 0.07952182753277676], [0.09372887161693402, 0.02556927751616708, 0.028828184519495283, 0.017229189863428473, 0.0702702264700617, 0.06439981968807322, 0.04644275004310267, 0.04254985214876277, 0.03542499018034764, 0.008373919408768415, 0.11171045673212834, 29.239388465881348, 52.52114132472447, 42.09393801007952, 36.64719649723598, 20.2668947492327, 22.020437683377946, 42.57520498548235, 51.90560735974993, 49.6608806337629, 42.52722420011248, 2.0943570690495625, 0.18144812142210348, 0.18478546876992497, 4.717436007090977, 27.494384867804392, 49.11427974700928, 47.19745588302612, 48.34597226551601, 46.16765989576067, 45.980527537209646, 46.36403335843767, 48.12635360445295, 47.17468316214425, 46.38370370864868, 49.44379806518555, 46.37136370795113, 45.81202677318028, 37.06983804702759, 32.20714473724365, 34.15433917726789, 33.52635751451765, 36.1866386277335, 37.2196238381522, 39.51446097237723, 40.82370655877249, 42.6542511667524, 42.70686640058245, 41.87027202333723, 41.65342569351196, 39.004407610212056, 34.51018074580601, 32.468862533569336, 32.34205443518502, 31.855944565364293, 32.58549152101789, 32.744424615587505, 32.98251853670393, 33.465178625924246, 32.67798941476004, 34.715517384665354, 32.72757870810372, 32.437981264931814, 33.526996748788015, 33.25889703205654, 33.076826436179026, 34.27081877844674, 32.96866035461426, 34.992305823734824, 34.47256319863455, 35.732191698891775, 34.141467639378135, 36.12143325805664, 35.942447662353516, 36.72593348366873, 33.935905184064595, 33.477928570338655, 34.77331597464425, 34.55716099057879, 33.719750199999126, 32.35042354038784, 32.301740986960276, 35.245953287397114, 38.34518337249756, 37.10223054885864, 38.01270512172154, 40.45041806357247, 46.618837697165354, 48.67729711532593, 48.39837210518973, 45.77137286322457, 43.636121954236714, 37.23646627153669, 36.487478256225586, 34.94334186826433, 34.779086453574045, 32.99273933683123, 33.00808443341936, 35.64625637871878, 33.95937272480556, 34.177869251796174, 33.762822083064485, 34.425992897578645, 35.737903118133545, 35.375575406210764, 34.938290527888704, 36.04840421676636, 35.662209442683626, 35.84094490323748, 36.14589786529541, 35.3656325340271, 33.4360865184239, 34.1565591267177, 34.93279797690255, 33.0567878314427, 33.186750411987305, 33.75895888464791, 32.45008850097656, 33.82028021131243, 34.59689426422119, 33.347997256687705, 33.2689128603254, 32.71903937203543, 33.49343000139509, 33.556769779750276, 33.90660810470581, 33.97206360953194, 33.56942939758301, 34.115821838378906, 35.07301262446812, 33.96986103057861, 35.11458717073713, 35.94063765662057, 34.53022977284023, 36.79095820018223, 36.760914189474924, 37.87828874588013, 45.489039761679514, 49.24349887030465, 47.65318128040859, 46.81241798400879, 45.2956713948931, 47.68605668204171, 48.90044546127319, 49.078725814819336, 50.710805552346365, 55.18272869927542, 55.08158377238682, 53.76648432867867, 55.253475257328574, 51.81581926345825, 52.98561797823225, 31.285195214407786, 0.13500549351530416, 0.3516301730913775, 0.729952828160354, 0.060269963794520924, 1.257429069706372, 51.92659091949463, 55.29183278764997, 57.19332545144217, 48.00009093965803, 29.342312131609233, 19.661757026399883, 49.40406131744385, 50.48804630552019, 54.05703020095825, 7.560790862355914, 0.17330741110656941, 0.04876847292429634, 0.044756492134183645, 0.03617855081600802, 0.020153655437752604, 0.00987186688663704, 0.022733547358906696, 0.03629765746050647, 0.03439712497804846, 0.022924590589744703, 0.013920232420787215, 0.058880419071231566, 0.037139230873435736, 0.032183438406458924, 0.050348092269684584, 0.016847003317837204, 0.03913017136177846, 0.016306682489812374, 0.3298666780548436, 33.76986060823713, 59.68732575007847, 46.972650391714915, 39.31222323008946, 22.02042899812971, 28.730314799717494, 45.236215659550254, 56.404618058885845, 54.12959371294294, 48.17885071890694, 1.6612678170204163, 0.14374193043581077, 0.1251462304166385, 5.733451110976083, 34.95152684620449, 48.827051639556885, 47.00452177865164, 48.44838523864746, 45.624776295253206, 45.86966208049229, 48.27110889979771, 48.9733807018825, 48.91474485397339, 48.69375392368862, 51.28879492623465, 48.66956377029419, 47.31252499989101, 39.415070465632844, 35.78427192143032, 35.73153509412493, 35.837658405303955, 37.55408579962594, 38.75261531557356, 40.69829852240426, 43.08475807734898, 43.59010403496878, 44.50021382740566, 43.28560617991856, 44.296291146959575, 41.08948557717459, 37.14538581030709, 34.042031969342915, 34.720971720559255, 33.51113053730556, 34.37888758523123, 35.183002608163015, 34.71264083044869, 34.61849273954119, 34.0899259022304, 35.75982468468802, 34.611037322453086, 34.60198381968907, 35.54202992575509, 35.40013728822981, 34.97644656045096, 35.225911208561485, 34.83878884996687, 36.7964368547712, 36.28468813214983, 37.21385335922241, 36.17781441552298, 36.8193485396249, 38.732993602752686, 37.81251014981951, 36.64122452054705, 34.757571356637136, 37.17129564285278, 35.60861798695156, 35.309056827000205, 33.82922601699829, 34.99000597000122, 38.24899598530361, 40.26558208465576, 39.3536171231951, 39.8324487549918, 41.08902352196829, 49.07524824142456, 49.383505071912495, 50.8767910684858, 47.28981133869716, 45.207627296447754, 39.59994118554251, 39.16202054704939, 37.288355418613975, 36.88072892597744, 33.798306533268516, 34.33684056145804, 35.82557201385498, 36.59738833563668, 36.30555704661778, 35.999471528189524, 36.34679460525513, 37.10950183868408, 36.310254028865266, 37.236844948359895, 36.814363207135884, 37.71686124801636, 38.14382457733154, 37.17088222503662, 36.58659430912563, 34.7292400768825, 34.548652921404155, 35.75177519662039, 33.715233870915, 35.70251941680908, 34.360436643872944, 33.57376159940447, 35.09202636991228, 36.50426857812064, 33.786105496542795, 36.07977533340454, 35.37799685341971, 34.482763154166086, 34.45896209989275, 35.70042453493391, 36.41164214270455, 36.10128695624215, 36.79465464183262, 37.24156624930245, 36.145738056727815, 36.78933926991054, 38.151578766959055, 36.216105937957764, 38.40883581978934, 37.27345153263637, 39.85500955581665, 46.54108040673392, 52.86570249285017, 49.362615312848774, 49.31476306915283, 47.819038254874094, 50.40543917247227, 51.48972640718733, 53.07125105176653, 53.65139784131731, 55.31269127982003, 57.90848963601248, 55.16843278067452, 57.144066197531565, 53.31816918509347, 54.803905963897705, 33.83087274006435, 0.13864557604704583, 0.753810065133231, 1.4316800108977725, 0.3215016983449459, 1.270806414740426, 56.08039774213518, 59.212513651166645, 62.133188928876606, 52.659156867435996, 30.460312025887625, 20.980690138680593, 55.57777200426374, 55.940426281520296, 63.48193849836077, 10.474765471049718, 0.25211560300418306, 0.04563907959631511, 0.04974622492279325, 0.026291442336514592, 0.05930266462798629, 0.0706535376874464, 0.023697718479005352, 0.07456306647509336, 0.13221400044858456, 0.06706429099930183, 0.07061162457934447, 0.15001767368188926, 0.15531776499535355, 0.0949877304956317, 0.21368719291474136, 0.11230924353003502, 0.08384296923343625, 0.062279716666255674, 0.36515980852501734, 37.5222178867885, 68.05240099770683, 52.75240516662598, 48.755526883261545, 28.288520540509904, 32.91022947856358, 51.26353475025722, 60.72017547062465, 56.40020942687988, 51.792282240731375, 2.3523128501006534, 0.40068923203008516, 0.17471269784229143, 7.3114148037774225, 37.15802805764334, 51.12441096987043, 48.35910088675362, 50.37191064017159, 47.57818242481777, 48.28004775728498, 46.73471280506679, 50.13359090260097, 51.56610795429775, 52.31564140319824, 53.562346254076274, 51.14835098811558, 50.635747637067524, 41.000520842415945, 38.68638856070382, 37.38434130804879, 37.77721677507673, 40.69371618543352, 41.41200705936977, 44.552648408072336, 44.65498842511858, 45.49828086580549, 47.118701526096885, 46.83137614386422, 45.75223057610648, 43.06840549196516, 40.01631546020508, 36.43193435668945, 37.98259857722691, 34.49852166857038, 36.58750452314104, 37.78629807063511, 37.23404482432774, 37.29831566129412, 35.8276286806379, 38.28026287896292, 36.239861828940256, 36.17593840190342, 36.37243345805577, 37.1821209362575, 36.92995343889509, 38.0530081476484, 36.79457821164812, 38.88448517663138, 38.96520239966256, 40.277418340955464, 37.918393748147146, 39.54403945377895, 39.885633741106304, 39.91893645695278, 37.85972315924508, 36.76374210630144, 38.08648804255894, 37.186473982674734, 38.032674244471956, 35.83467762810843, 36.44869341169085, 39.92026008878435, 43.87218005316598, 40.615479469299316, 43.62625898633684, 44.0221187046596, 50.71086808613369, 52.139723437173025, 52.056115763528005, 48.759223324911936, 47.38530043193272, 41.01350007738386, 40.58848224367414, 39.37739038467407, 39.256217275347026, 37.46330411093575, 35.987725598471506, 38.6435980796814, 38.10675246374947, 37.66376658848354, 37.969011374882285, 38.86791372299194, 39.42323807307652, 38.67196062632969, 39.13688891274588, 37.84592751094273, 39.12940222876412, 38.59243501935686, 39.96639960152762, 38.05872998918806, 35.773780141557964, 36.68535252979824, 38.44781868798392, 35.26984814235142, 37.12058768953596, 35.91191380364554, 34.93676539829799, 36.851407527923584, 39.640608991895405, 36.47932801927839, 37.9567860194615, 37.68442358289446, 37.52400704792568, 37.83122512272426, 38.13158532551357, 38.20969349997384, 37.15810101372855, 38.37149620056152, 40.68513863427298, 37.70596994672503, 40.415232385907856, 40.570166792188374, 38.07269239425659, 40.267395564488, 40.521091665540425, 41.316490173339844, 50.17343534742083, 55.43927008765084, 52.02051319394793, 51.11203622817993, 50.38008519581386, 51.4972756249564, 54.86501884460449, 54.954494271959575, 53.77405091694423, 57.745933055877686, 58.78540093558175, 58.08942072732108, 59.28995827266148, 54.18362290518624, 56.807498931884766, 35.92832197461809, 0.4339930335325854, 1.212572150996753, 1.6077939378363746, 0.4152718995298658, 1.4974702234779085, 63.022398539951865, 65.01137597220284, 68.82936246054513, 59.00599234444754, 40.21431132725307, 29.422306741986954, 65.94283757890973, 62.98324544089181, 75.65825353349958, 16.493849209376744, 0.4539481784616198, 0.1572733979140009, 0.09746465472770588, 0.17395235864179476, 0.13668786681124143, 0.15375242541943276, 0.10519966217023985, 0.15336582330720766], [0.038456243595906665, 0.04183299007958599, 0.025780027100284184, 0.014736082571159517, 0.005282797152176499, 0.06389754771121911, 0.05212458176538348, 0.038737153700952015, 0.034281027636357715, 0.09073944309992449, 0.04298505433169859, 21.292344638279506, 48.51508447102138, 44.427834442683626, 33.22084869657244, 21.10168433189392, 32.449035848890034, 37.46387038912092, 54.84609889984131, 45.07321092060634, 51.211649077279226, 3.717815612043653, 0.0475332474202982, 0.06245559294308935, 1.3642638112817491, 22.40809679031372, 44.15144899913243, 46.47892182213919, 48.71933371680123, 46.12369864327567, 47.03589289528983, 48.08466093880789, 49.29686450958252, 49.818771498543875, 48.447384698050364, 44.48215545926775, 41.444218908037456, 37.62089272907802, 31.759701592581614, 33.25505815233503, 34.32641478947231, 36.453980990818565, 38.15166561944144, 41.33066102436611, 44.215976919446675, 42.26143128531319, 44.119042600904194, 42.75284263065883, 42.53534664426531, 41.737644808632986, 38.99537147794451, 33.22373219898769, 33.07045146397182, 31.76482241494315, 31.526797975812638, 31.626935413905553, 33.10227073941912, 31.84245811189924, 32.79757138660976, 33.83912719999041, 33.206663949149, 31.933239800589426, 33.45950889587402, 33.27787603650774, 33.38822385243007, 32.5312955720084, 32.81887108939034, 33.23026350566319, 33.7779517854963, 34.378442900521414, 33.79569401059832, 35.600203718457905, 36.67717102595738, 35.71145480019705, 36.11702462605068, 35.12624972207205, 34.245923382895334, 34.59183597564697, 33.84965719495501, 35.210270813533235, 31.87721994944981, 32.37645149230957, 35.02056067330496, 38.81300558362688, 37.05745983123779, 39.034357820238384, 39.06261614390782, 46.123080253601074, 48.11404487064907, 46.388998235974995, 46.756460666656494, 44.21038709368025, 37.62894221714565, 37.03084128243582, 36.31905392238072, 33.25471074240548, 33.350210257938926, 34.530653612954275, 33.87016132899693, 34.39594888687134, 34.07035282679966, 33.253234250204905, 34.91397530691964, 35.419779845646445, 35.060874121529714, 34.73682403564453, 36.52109711510794, 35.252144132341655, 35.928676332746235, 33.44773864746094, 33.36839369365147, 33.47988101414272, 35.70611163548061, 32.434931005750386, 32.88041475840977, 34.68172829491751, 33.57909434182303, 33.12919500895909, 34.56102071489607, 33.77779197692871, 33.12888581412179, 33.01309061050415, 33.512315205165315, 33.14785092217581, 33.96557399204799, 33.60746036257063, 34.48356219700405, 34.589848790849956, 36.00588124138968, 34.48433344704764, 35.33299337114607, 33.86973054068429, 33.740803241729736, 35.68137952259609, 35.41949149540493, 36.74269253867013, 37.221875054495676, 48.560834884643555, 51.27880689076015, 50.56231212615967, 49.18295226778303, 49.97934089388166, 48.69555350712368, 51.52833407265799, 53.12543657847813, 54.22571856634957, 50.94560602733067, 50.58197552817208, 47.3262164252145, 48.43380444390433, 51.78092541013445, 54.583008834293906, 35.528574739183696, 0.10130077281168529, 0.2662162663681166, 0.6480524029050554, 0.13225640888725007, 1.644695820552962, 52.146848814828054, 53.00313091278076, 57.83494642802647, 47.02797889709473, 45.237799848829, 29.08024866240365, 49.00107274736677, 49.5051715033395, 52.95073454720633, 7.240550560610635, 0.09647016666297402, 0.08104002928095204, 0.02217307573716555, 0.04948968440294266, 0.038673418906650374, 0.08508893594677959, 0.04304592910089663, 0.09641768197928156, 0.021291433135047555, 0.05451216668422733, 0.03248696747635092, 0.03783349433381643, 0.11403303460351058, 0.07016187121293374, 0.045746722391673496, 0.04575155695368137, 0.005013363618802811, 0.05373079968350274, 0.055162589997053146, 24.90180352755955, 57.43312168121338, 50.10317863736834, 41.243311745779856, 21.571120262145996, 37.27195419584002, 43.80401127679007, 59.020986557006836, 50.031667777470176, 54.497730118887766, 4.0350560290472846, 0.1240070244031293, 0.0419475980369108, 1.9656768654073988, 24.41696344103132, 47.693369661058696, 48.8063633782523, 49.08855404172625, 47.85808365685599, 47.81179823194231, 49.39481673921858, 51.08608818054199, 51.55734974997384, 51.98605360303606, 46.605976581573486, 44.21279811859131, 39.68460151127407, 33.894622462136404, 35.77223069327218, 36.6132823399135, 38.01297262736729, 39.912759508405415, 42.354380811963765, 44.12642853600638, 43.6900816644941, 45.894689491816926, 44.02479723521641, 45.12212971278599, 43.407376834324424, 39.33744519097464, 35.777476583208355, 36.05677332196917, 34.317482880183626, 33.241477898189, 34.06339073181152, 34.21845367976597, 34.1494129044669, 33.20905760356358, 34.79548420224871, 34.44704941340855, 33.6395297731672, 35.13250657490322, 34.846230370657786, 34.851691654750276, 34.328742436000276, 35.35500179018293, 35.54434020178658, 34.83143070765904, 35.907348837171284, 35.840204920087544, 37.61705732345581, 36.99375179835728, 37.35760811397007, 35.66212953839983, 36.41749600001744, 35.34073713847569, 35.06155851909092, 34.48575782775879, 36.4188300541469, 34.12481280735561, 34.51440872464861, 37.57151535579136, 39.52213525772095, 40.10272325788225, 39.80359288624355, 42.400763511657715, 47.09665141786848, 49.71239110401699, 47.89402321406773, 48.23208086831229, 46.946778774261475, 39.17446477072579, 39.61085333142962, 39.888267108372276, 37.34956210000174, 34.53343289239066, 34.96114662715367, 36.03027636664254, 36.162656920296804, 34.70530005863735, 35.63945756639753, 36.08365590231759, 36.314026900700156, 36.620581422533306, 35.84717396327427, 38.038496834891184, 36.47499581745693, 37.27603278841291, 35.26409503391811, 35.029489108494346, 34.6253262928554, 37.21922084263393, 34.508273465292795, 34.725439412253245, 36.38609709058489, 36.012436866760254, 35.23041711534773, 36.00662817273821, 35.57459265845162, 36.18024281093052, 35.45342302322388, 35.48128877367292, 35.552174295697895, 36.140638078962056, 35.236295291355674, 37.329294204711914, 36.54483910969326, 37.231949942452566, 35.94057512283325, 38.41238982336861, 36.23976455415998, 35.56985398701259, 37.94212532043457, 36.97549888065883, 38.987898690359934, 39.49955013820103, 50.30036851337978, 53.40225975854056, 54.144636562892366, 51.38354056222098, 52.2196763583592, 50.45418425968715, 53.480694498334614, 55.87544672829764, 55.85752732413155, 51.95759725570679, 52.62967218671526, 49.69885948726109, 50.70818608147757, 52.750935622623985, 55.09142242159162, 35.89184045791626, 0.37647250720432823, 0.8991990036198071, 1.5311578043869563, 0.09802284477544682, 1.8986714780330658, 56.366375173841206, 57.381006717681885, 62.50363213675362, 49.78463152476719, 40.257258142743794, 28.279821395874023, 55.96190663746425, 55.22722496305193, 61.217520577566965, 9.140426465443202, 0.2310494248356138, 0.1475649867206812, 0.018622500456071327, 0.09192756470292807, 0.07136454060673714, 0.03224276950848954, 0.055730435598109446, 0.05449986484433923, 0.1025557911821774, 0.24754007852503232, 0.08888606540858746, 0.17099013259368284, 0.2059689113604171, 0.17995663359761238, 0.0919917066182409, 0.15757375822535583, 0.12579638910080704, 0.15985508795295442, 0.12410724402538367, 29.704313278198242, 64.76852253505162, 55.29063074929373, 46.28199945177351, 29.170354638780864, 44.25372995649065, 47.676638398851665, 64.82201671600342, 52.41863455091204, 60.43292999267578, 5.134485559804099, 0.19626951111214502, 0.10116603611303226, 2.0148731512682776, 26.446723324911936, 51.01537983758109, 50.8038523537772, 49.85821642194475, 49.62424625669207, 47.72097832815987, 50.381356716156006, 52.31465475899832, 53.6821540423802, 52.794163840157644, 49.29709727423531, 45.31383746010916, 40.98619018282209, 35.635146209171836, 38.31305490221296, 38.3327009337289, 40.35070446559361, 41.50139216014317, 45.52445820399693, 46.70237241472517, 46.95898675918579, 46.686033725738525, 46.10133934020996, 47.618266582489014, 45.623542990003315, 43.11137662615095, 37.202159540993826, 37.46990489959717, 37.30504846572876, 36.02696207591465, 36.15449626105172, 37.48559740611485, 35.487611634390696, 36.584718295506065, 36.32540110179356, 35.78555038997105, 35.51454980032784, 37.276116166796, 36.365117004939485, 36.84123189108712, 35.23178243637085, 36.55644260134016, 36.46483407701765, 36.44160624912807, 36.87512867791312, 36.9577670778547, 38.82556792667934, 39.66622700010027, 39.606083393096924, 37.64959226335798, 38.06665093558175, 38.38587202344622, 36.67993988309588, 36.00161852155413, 39.17685147694179, 35.825026580265586, 37.04264974594116, 40.209631715502056, 44.12993390219552, 42.05650806427002, 42.800573280879426, 44.29670109067644, 48.87014089311872, 50.74723148345947, 50.99543850762503, 50.89265727996826, 48.40716505050659, 42.01695891789028, 42.30916888373238, 40.80224357332502, 39.20380353927612, 37.07344763619559, 37.60463741847447, 38.007118770054404, 37.39445093699864, 36.52192047664097, 36.447025844029014, 37.12608371462141, 38.03461626597813, 38.212101050785606, 38.600119726998464, 39.909184660230366, 38.683498110089985, 39.509340150015696, 35.75774022511074, 37.134414604731965, 37.44308137893677, 39.804600375039236, 34.527405330113, 36.36142403738839, 37.93011883326939, 37.92758968898228, 36.56685100282942, 37.77420820508684, 37.40499482836042, 37.51258420944214, 36.498223645346506, 37.558226925986155, 38.05402258464268, 37.723048618861604, 37.68662963594709, 39.17859894888741, 37.96706935337612, 40.746689251491, 38.78865909576416, 41.610371180943076, 37.66667788369315, 37.51406070164272, 41.21267713819231, 37.975820609501426, 41.72983503341675, 40.70362431662423, 52.58583600180489, 56.20200858797346, 55.72679001944405, 53.11927005222866, 54.18551281520298, 53.328039101191926, 56.069610663822715, 56.35293735776629, 57.89817156110491, 55.24799312864031, 54.918460914066856, 53.517120429447715, 52.60183422906058, 53.79323836735317, 54.69024733134678, 37.06791687011719, 0.8415368263210569, 2.083313124520438, 4.863880583218165, 0.16467407079679625, 1.9074904790946414, 62.559363637651714, 62.637621198381694, 67.35643468584333, 58.512253352573936, 57.33660078048706, 38.311206681387766, 63.63058825901577, 62.205679484776084, 71.38163730076381, 12.536958677428109, 0.3110063900904996, 0.2592768615909985, 0.07801277922200305, 0.2700736293835299, 0.12767594467316354, 0.16568465371217045, 0.17737099448485033, 0.18376066376055988], [0.04713527984651072, 0.06637082142489296, 0.01750599652794855, 0.03213450924626418, 0.030990838472332274, 0.02553705558446901, 0.08683145458676986, 0.07168542660240616, 0.02490571776538023, 0.005401189214483435, 0.04331270192882844, 8.198539955275399, 50.759074687957764, 43.733028479984824, 32.65729073115757, 25.180388075964792, 22.353584698268346, 34.13224737984793, 55.841914721897666, 46.60974597930908, 53.07352658680507, 8.662208880696978, 0.16333876816289766, 0.15747550635465554, 0.4396910992051874, 14.473219258444649, 40.78708955219814, 46.48931632723127, 47.0201586995806, 48.23799378531319, 50.27546616962978, 49.11253922326224, 48.498585973467144, 45.451026167188374, 45.37111146109444, 40.75031621115548, 36.02155985151018, 33.61190373556954, 32.995806966509136, 34.710466044289724, 39.5732045173645, 42.0352326801845, 42.242080552237375, 45.588468483516145, 44.66223887034825, 42.48259939466204, 42.37150117329189, 46.77261175428118, 44.9850104876927, 42.85699265343802, 37.78620079585484, 33.87025165557861, 33.283340794699534, 32.15044048854283, 32.246686935424805, 32.33839273452759, 33.35373646872384, 32.10838304247175, 33.511338983263286, 32.37107706069946, 32.33301830291748, 32.81383711951119, 32.8650210244315, 32.96805933543614, 33.0650110244751, 32.37679542813982, 33.85002197538103, 34.424509457179475, 34.15692738124302, 33.512975284031455, 35.1322078023638, 34.55924892425537, 35.17836121150425, 34.17709800175258, 35.81622321265084, 33.7355295589992, 34.71789019448416, 35.380942889622276, 34.126657554081504, 34.36555051803589, 32.60818781171526, 32.64926208768572, 36.303298882075715, 36.9577670778547, 38.014605454036165, 37.49530403954642, 39.229744638715474, 44.33827216284615, 49.03375012534005, 46.265935216631206, 48.40937805175781, 43.224187578473774, 38.58937781197684, 38.423934255327495, 37.107948916299, 33.97444684164864, 31.230839456830704, 33.434436321258545, 34.55662597928728, 32.54830823625837, 34.900158814021516, 34.64808859143938, 35.568558147975374, 33.95651354108538, 36.32046440669468, 35.40648794174194, 35.56890555790493, 36.17721687044416, 33.83822740827288, 34.19325256347656, 34.0954601424081, 33.460874216897146, 33.697856426239014, 35.34150491441999, 31.60613250732422, 34.41817617416382, 33.934275831495015, 32.4456763948713, 32.669005393981934, 33.58290542875017, 33.17198201588222, 32.72418103899275, 34.3134320804051, 33.36328329358782, 34.89558342524937, 35.62915686198643, 35.93356786455427, 35.17516851425171, 35.79856784003121, 35.76505667822701, 33.85454872676304, 34.43566131591797, 33.23096874782017, 35.089097704206196, 35.55884804044451, 35.912271635872976, 38.26426117760794, 44.11025660378592, 50.48056309563773, 50.003833293914795, 51.357015814099995, 50.04200669697353, 52.6292587688991, 50.10637828281948, 46.624215602874756, 45.21815381731306, 48.910940715244834, 48.42348289489746, 51.56145960944039, 53.30644062587193, 49.885832037244526, 48.97430828639439, 29.95372928891863, 0.5604907699993679, 0.9020945025341851, 1.0036004100527083, 0.18190074499164308, 1.9494206862790244, 52.28229004996163, 54.004741532461985, 58.885378565107075, 46.69330848966326, 32.00050531114851, 16.136776072638376, 36.80711623600551, 51.44090836388724, 43.369787079947336, 3.3523140932832445, 0.06528344191610813, 0.06715009175240993, 0.017328627474073852, 0.05319335584395698, 0.019929262210748026, 0.029134220776281188, 0.058137280733457634, 0.02968842103811247, 0.049786234740167856, 0.017850225824596624, 0.05484806526718395, 0.03182791659076299, 0.014171354838513901, 0.04072077279644353, 0.020626076962798834, 0.03997427571032729, 0.04635757354221173, 0.014991588325106671, 0.06905836292675563, 11.885928971426827, 57.5739859853472, 48.862751483917236, 36.82117591585432, 24.091956240790232, 30.98798601967948, 39.03081423895699, 60.10044479370117, 50.521456718444824, 57.571168490818565, 9.175835353987557, 0.23014643043279648, 0.058643698559275696, 0.6061738186648914, 16.642729997634888, 43.469420773642405, 49.22771603720528, 48.23091009684971, 50.06365728378296, 50.808330467769075, 51.048533167157856, 50.82120895385742, 46.12218393598284, 46.939858368464876, 42.159449100494385, 37.96989379610334, 34.4499329158238, 35.50676781790597, 37.73932129996163, 39.87321036202567, 44.53370067051479, 43.43588529314314, 46.350168228149414, 45.90432664326259, 43.36575712476458, 44.486317430223735, 47.36019311632429, 46.435054370335166, 44.559547969273154, 39.45609610421317, 34.909865447453086, 33.76569168908255, 34.5217217036656, 34.12193625313895, 34.46792527607509, 35.11785282407488, 32.91173376355852, 36.154287815093994, 34.89286320550101, 34.30645956311907, 34.88037381853376, 33.778240135737825, 34.57173831122262, 34.37438515254429, 34.15504094532558, 35.71852806636265, 35.4199709211077, 34.99390390941075, 35.26515810830252, 35.06500135149275, 36.38391188212803, 36.420949254717144, 36.69714709690639, 36.89166191646031, 35.719424383980886, 35.611317362104145, 37.24505424499512, 35.674994128090994, 35.99420479365757, 34.52300712040493, 35.061773913247244, 37.47499792916434, 39.02631180627005, 41.30953502655029, 41.0957076890128, 41.67544453484671, 45.23474611554827, 50.636991364615305, 49.687923022678916, 49.434181758335654, 45.81299952098301, 38.93329974583217, 39.905939851488384, 39.252107415880474, 36.370758942195344, 34.7507586479187, 35.01449837003435, 36.06239441462925, 34.96368619373867, 36.34039878845215, 35.739445618220735, 37.65911824362618, 36.28239522661482, 37.42042677743094, 37.371407236371724, 37.54031794411795, 38.08164514814104, 36.14097854069301, 35.69144398825509, 36.43886865888323, 34.57297509057181, 34.37922804696219, 36.433761732918875, 33.388095310756135, 35.26246568134853, 35.27131073815482, 33.63014970506941, 34.554802077157156, 35.31635243552071, 36.221595014844624, 34.9659617287772, 36.160266739981516, 35.79826211929321, 35.29878738948277, 36.73014061791556, 37.13153805051531, 37.28624664034162, 36.85735171181815, 38.74047333853585, 36.702122007097515, 36.27675676345825, 35.943990162440706, 37.10194567271641, 35.63595567430769, 37.442365714481895, 40.80995259966169, 46.41468572616577, 53.06120048250471, 52.22179208483015, 52.79030064174107, 52.28079618726458, 54.778333118983674, 52.672455719539094, 49.73275974818638, 47.737421240125386, 50.43997866766793, 49.07181235722133, 51.57662752696446, 52.01095247268677, 52.47075298854283, 48.99744578770229, 33.14268493652344, 0.680171536547797, 1.0301195127623421, 2.4018845558166504, 0.23891386283295496, 2.0225817433425357, 56.38997820445469, 57.636752537318635, 64.30181203569684, 52.23570237840925, 37.72829450879778, 21.921106236321585, 43.09751149586269, 55.85122878210885, 50.77217204230172, 5.159760934965951, 0.15332159639469214, 0.039989854874355454, 0.07833816390484571, 0.03236634430608579, 0.024543765134045055, 0.04513906714107309, 0.05932633192943675, 0.01849664408447487, 0.1586750884141241, 0.13474094628223351, 0.1550697875874383, 0.11487375306231634, 0.18626159456159386, 0.1352821458131075, 0.12754648019160542, 0.2959014948989664, 0.11747702051486288, 0.19617971378777707, 0.12246573210826942, 13.776959385190692, 67.02466515132359, 56.59954629625593, 45.248520919254844, 34.45156226839338, 33.135806219918386, 44.032089369637625, 66.40829045431954, 54.14410155160086, 62.59622383117676, 10.617918338094439, 0.44969786224620684, 0.32857097472463337, 0.9701303946120399, 19.074137449264526, 44.8727171761649, 50.050215993608745, 49.21299280439104, 50.52425684247698, 53.34318617412022, 52.680758816855295, 52.84620237350464, 48.05156666891915, 49.95185729435512, 43.5776424407959, 39.143076283591135, 37.01281418119158, 36.85781724112374, 40.0596479007176, 42.251957416534424, 46.738853931427, 44.29590204783848, 48.82068361554827, 48.59542301722935, 44.86319466999599, 46.042550631931846, 50.05274166379656, 49.496979577200754, 48.0886526788984, 41.586987018585205, 37.90647063936506, 36.54988350187029, 37.56162806919643, 36.79600259235927, 35.76317719050816, 37.70790154593331, 34.7592111315046, 37.6466566494533, 35.66120195388794, 35.48454053061349, 37.08871977669852, 35.135376180921284, 36.95605434690203, 36.106515475681846, 36.05293096814837, 37.44842454365322, 38.4210854939052, 37.029771259852815, 37.53691332680838, 36.465396881103516, 38.362946442195344, 38.90767131532942, 38.35350384031023, 38.64733968462263, 35.860709054129465, 37.31313269478934, 38.982222012111116, 37.65116950443813, 38.39384855542864, 36.86527960641043, 37.63146788733346, 41.66202756336757, 41.67111233302525, 42.83000585011074, 44.342520986284526, 42.985892159598215, 47.07539340427944, 51.836222648620605, 50.39982850211007, 53.41528068270002, 47.83758299691336, 42.85454341343471, 41.666342394692556, 42.16198519298008, 39.3596898487636, 35.57203572137015, 36.63226134436471, 37.639371463230674, 35.634642464774, 38.38752222061157, 37.85284791673933, 38.8204471043178, 37.38065876279558, 39.44387422289167, 39.44547230856759, 39.14710276467459, 40.57335254124233, 37.38001605442592, 37.123394761766704, 39.03481987544468, 36.1090133530753, 37.76223645891462, 38.42665794917515, 33.736224378858296, 38.5036300931658, 37.36804778235299, 35.2282075881958, 36.97861862182617, 38.28518220356533, 36.95902122770037, 37.34307943071638, 38.75464766366141, 37.02958713259016, 39.56373759678432, 39.575264658246724, 39.68844386509487, 38.82417828696114, 40.04176671164376, 42.237835202898296, 38.5421404838562, 38.93224709374564, 37.65178094591413, 39.43460532597133, 38.50026716504778, 38.948453766959055, 42.1891040120806, 49.227538858141216, 55.282365867069785, 53.97117131096976, 54.53279767717634, 54.13676425388881, 55.83373669215611, 53.63670587539673, 51.958503995622905, 50.133660384586875, 53.44976806640625, 50.150409017290386, 53.47599751608712, 55.01317875725882, 53.86185530253819, 52.333995069776265, 34.787455558776855, 1.101106109363692, 2.423251135008676, 4.79283481836319, 0.2657953032425472, 2.7879622961793626, 62.43365682874407, 63.021530015128, 69.12269456045968, 57.97105469022478, 44.307859897613525, 24.793837206704275, 52.370723247528076, 62.16428211757115, 61.62186404636928, 7.5649710723332, 0.20148102646427496, 0.11330067140183278, 0.07312978338450193, 0.15598677338234015, 0.11483209101217133, 0.123435358649918, 0.12952468118497304, 0.13204884502504552], [0.010919975333048828, 0.028536821582487652, 0.017056684209299938, 0.0350953782243388, 0.016321842658466527, 0.038638084195554256, 0.01976930097277675, 0.021359636082447002, 0.013331358171334224, 0.0618824479835374, 0.07397130929997989, 6.04483072246824, 50.7179274559021, 43.11620215007237, 41.22142492021833, 29.783831936972483, 27.79117543356759, 34.2953702381679, 53.553205898829866, 47.212259020124165, 54.17236334936959, 16.514923095703125, 0.13285214906292303, 0.13412820201899323, 0.19267822881894453, 8.114179270608084, 34.94224405288696, 48.20790808541434, 48.77340807233538, 48.64626298631941, 48.34095219203404, 48.639547552381245, 45.70883560180664, 42.52394117627825, 37.05256829942976, 34.56389032091413, 34.64292260578701, 36.3045391355242, 39.840091773441856, 43.99902636664254, 46.035553795950754, 46.734851769038606, 45.93426990509033, 46.65900175912039, 45.27742542539324, 42.496811934879844, 41.054400648389546, 44.08287375313895, 45.435889516557964, 41.79507861818586, 34.62204326902117, 31.49379403250558, 32.49678386960711, 31.99187217439924, 32.44439445223127, 31.897456577845983, 32.767311981746126, 33.16325855255127, 33.773345129830496, 32.52378109523228, 33.99738284519741, 34.85327236992972, 33.3096466745649, 33.16727461133684, 33.048175539289204, 33.426161016736714, 33.03516503742763, 32.33170509338379, 33.37572404316494, 33.04042134966169, 35.82118075234549, 35.54631349018642, 35.40230165209089, 34.80614621298653, 35.01039545876639, 35.081815992082866, 34.94546454293387, 34.7886506489345, 33.87592485972813, 34.22189998626709, 33.471626554216655, 30.462128979819163, 34.60706990105765, 37.60197973251343, 37.40013108934675, 39.30684879847935, 41.92383916037423, 45.65423665727888, 45.901224272591726, 47.71099376678467, 44.68191269465855, 43.43985618863787, 38.28738478251866, 38.04568474633353, 36.79948711395264, 35.83309343882969, 33.26093632834298, 32.15829195295061, 34.429929052080425, 34.792437417166575, 33.36695541654314, 32.45163447516305, 34.45819779804775, 36.989999771118164, 35.49063410077776, 35.934530190059114, 34.653185095105854, 34.25709956032889, 33.87739092963082, 34.645330156598774, 33.79473515919277, 33.8063143321446, 33.76823820386614, 33.64571019581386, 33.46156208855765, 33.13850212097168, 32.89498165675572, 32.96605478014265, 32.75263391222273, 33.593873160226, 33.666565213884624, 33.920622621263774, 32.28439480917794, 33.69669607707432, 34.247167110443115, 35.18679632459368, 36.64052970068795, 36.72894900185721, 37.31189244134085, 36.56690311431885, 33.5292375428336, 33.70677791322981, 33.94133520126343, 34.570449420383994, 36.56992905480521, 35.57747963496617, 34.990815435137065, 41.43108333860125, 47.21303721836635, 48.289198534829275, 49.51589952196394, 48.623330456869944, 43.5947836467198, 43.35367768151419, 50.15633583068848, 53.53777394975935, 54.51735877990723, 54.433184828077046, 54.96406888961792, 53.275833811078755, 57.172887325286865, 51.57658931187221, 30.01230607713972, 1.0123889041798455, 0.3126040957868099, 0.930625108735902, 0.10855239869228431, 2.1664576573031287, 51.499603271484375, 53.85147816794259, 56.223391669137136, 48.6291287285941, 53.04518835885184, 26.498098305293492, 36.572850772312705, 49.16711037499564, 40.51679073061262, 2.8393728860786984, 0.12074133035327707, 0.02387454979387777, 0.041400142413164885, 0.0033951807958406527, 0.05257835205910461, 0.048350352860455, 0.02577279900599803, 0.034233886415937116, 0.004455278743989766, 0.04767754128468888, 0.030444899374353032, 0.01541532835523997, 0.010399827351128417, 0.015050190001992243, 0.03868804133630224, 0.08234059770724603, 0.03994350753990667, 0.0704078876546451, 0.08589422809226172, 7.109523602894374, 57.78216443743025, 48.27176203046526, 45.36277709688459, 30.76947907039097, 29.90872928074428, 41.081370081220356, 56.74419042042324, 50.57763637815203, 58.26862866537911, 17.35071495601109, 0.15576194758926118, 0.09264273382723331, 0.40018293634057045, 9.280877351760864, 38.202932902744834, 49.76199776785714, 50.439169202532085, 50.324767112731934, 50.63162735530308, 50.84901564461844, 47.93308251244681, 43.81383950369698, 39.00953538077218, 36.09372384207589, 36.81704868589129, 37.46625362123762, 38.99096632003784, 44.75871808188302, 46.69943332672119, 47.24437011991228, 46.7429255758013, 48.6290522984096, 45.2500182560512, 44.460772378104075, 41.45187929698399, 44.703681400844026, 46.758982862745015, 43.32334879466465, 37.23640373774937, 33.99506909506661, 34.65772574288504, 33.89443833487374, 35.40941660744803, 34.82068879263741, 34.790960924965994, 34.41508422579084, 35.69353539603097, 34.992760930742534, 36.01416002001081, 36.24670580455235, 34.82472569601876, 32.81318398884365, 33.297567231314524, 34.08316877910069, 35.44451890672956, 33.73794058391026, 35.52446140561785, 34.98832450594221, 36.63331747055054, 36.50989661897932, 38.21830231802804, 37.352480343409944, 37.397407395499094, 34.3844496182033, 36.539666175842285, 36.19754729952131, 34.09218406677246, 35.88499648230416, 34.639035088675364, 34.158532415117534, 37.15247992106846, 39.09226063319615, 40.23318958282471, 40.9984016418457, 42.48267929894583, 47.85069077355521, 46.41175706045968, 50.59882490975516, 47.366467339651926, 45.78461612973894, 41.20870624269758, 40.04592868259975, 38.84368882860456, 38.45718833378383, 34.690444810049875, 34.15708718981062, 35.14832067489624, 37.11647088187081, 35.21902206965855, 34.739269801548545, 36.79591226577759, 36.860429763793945, 37.09377459117344, 38.45761912209647, 36.588647501809255, 36.36205979755947, 35.82232025691441, 37.140073912484304, 35.0762539591108, 35.79991231645857, 35.36418383462088, 35.302695751190186, 34.311267716544016, 33.965257849012104, 34.51876524516514, 33.94808190209525, 35.19355692182268, 35.52345739092146, 35.85149226869856, 34.67701046807425, 34.343653270176475, 36.06262717928205, 36.04735503877912, 37.28831720352173, 38.95129558018276, 38.912222385406494, 38.969503334590364, 38.32856675556728, 36.2626553944179, 36.09775032315935, 36.58066749572754, 37.77898161751883, 38.987881319863455, 37.60681567873274, 36.979685170309885, 42.676044191632954, 50.069125516074045, 51.272060189928325, 52.625604016440256, 49.81577682495117, 45.35552665165493, 45.37035410744803, 51.33547987256731, 53.27256120954241, 55.587568964277, 55.15783330372402, 57.05832890101841, 55.9303548676627, 58.505478858947754, 52.9501439503261, 32.2474547113691, 1.3609397496495927, 1.1063353887626102, 2.42950125677245, 0.12024487342153277, 2.5336171899523054, 56.523202964237754, 57.7785131590707, 60.17308126177107, 51.66738837105887, 51.54042741230556, 25.810136318206787, 44.93164484841483, 55.20985099247524, 49.501419476100374, 4.223321378231049, 0.20629354965473923, 0.036289996800145934, 0.03880781294511897, 0.021551566497821893, 0.024672025215945075, 0.05495604733005166, 0.03322323903973613, 0.013021562830545008, 0.09865101892501116, 0.1526284185903413, 0.07065416872501373, 0.22445231383400305, 0.06725854200444051, 0.08930145097630364, 0.10723086353391409, 0.22783775574394635, 0.12720031876649174, 0.22174312706504548, 0.2274652807308095, 8.720579828534808, 66.41457162584577, 54.44847781317574, 52.5664644241333, 40.39814329147339, 39.00954580307007, 44.668850081307546, 63.30084065028599, 54.10866921288626, 65.40041950770787, 20.53222039767674, 0.2890222354659012, 0.3558101930788585, 0.4679928762572152, 9.853091035570417, 39.715781552451, 50.751049518585205, 51.008372579302105, 53.587679386138916, 51.10454607009888, 52.54733950751168, 51.467804840632844, 46.16136482783726, 40.53045088904244, 38.78502171380179, 38.612588269369944, 41.571867738451274, 42.86351701191494, 48.20435755593436, 49.87726838248116, 49.42851550238473, 47.96150064468384, 50.503870827811106, 47.65198966435024, 45.95420776094709, 43.10983760016305, 48.00088650839669, 49.28738716670445, 46.24661922454834, 38.94007076535906, 35.415399006434846, 36.172888142721995, 36.163601875305176, 37.27915252958025, 35.702317919049946, 35.83884654726301, 37.10166427067348, 37.374356746673584, 35.724885668073384, 36.918252672467915, 38.572403362819124, 36.999914850507466, 35.76878091267177, 35.90161657333374, 37.077467169080464, 35.8290947505406, 35.52881792613438, 36.51074429920742, 36.67159857068743, 38.991508279527935, 37.57287720271519, 38.345291069575715, 38.63765736988613, 37.69974436078753, 37.56651265280587, 38.41615922110421, 38.27258511951992, 35.442549092429026, 37.763490608760286, 36.46825606482369, 36.56551347460066, 38.728043011256624, 41.13140058517456, 42.58173976625715, 43.084101472582134, 44.206860882895334, 48.6146799496242, 47.48061582020351, 49.85208463668823, 49.37722390038626, 48.38482311793736, 43.24081114360264, 41.44976009641375, 41.77853148324149, 40.910121304648264, 38.69449710845947, 35.94958346230643, 37.886793340955464, 39.2243458884103, 36.23385511125837, 35.134014333997456, 37.82438809531075, 39.407139096941265, 39.28869662966047, 40.51288931710379, 39.28558036259243, 37.92720406396048, 37.82883146830967, 39.174134731292725, 37.09993069512503, 38.043864318302695, 37.98512077331543, 37.32725838252476, 36.25309467315674, 35.6307931627546, 35.37253556932722, 35.968027455466135, 36.79879576819283, 37.4722638130188, 38.15898902075631, 37.53194189071655, 35.5968998500279, 38.55573116030012, 39.16846152714321, 39.547874859401155, 41.578711714063374, 41.63031945909773, 40.81234277997698, 40.90872819083077, 37.50696311678205, 37.619728905814036, 38.22720643452236, 39.905470848083496, 40.46893848691668, 39.94049324308123, 38.640492234911235, 44.85914387021746, 51.7004895891462, 52.47871562412807, 53.76252385548183, 50.02214527130127, 47.46435356140137, 47.14987461907523, 51.037353515625, 54.30792270387922, 56.010554449898855, 56.70766374043056, 58.75624629429409, 58.14442614146641, 59.20404379708426, 54.08949218477522, 37.169631549290244, 2.2375451113496507, 2.6310389680521826, 4.923011924539294, 0.36607504369957106, 3.2056736648082733, 60.67977864401681, 62.23913506099156, 66.59377261570522, 58.85864189692906, 64.05125999450684, 37.381388323647634, 53.50175101416451, 62.78951576777867, 59.71934999738421, 6.054446595055716, 0.4305338077247143, 0.1129840330353805, 0.11037780717015266, 0.11752797849476337, 0.1295465435832739, 0.16741118606712135, 0.13819597874368938, 0.09054161621523754], [0.01619327045045793, 0.037837080391389985, 0.019819337841389433, 0.04202294935073171, 0.026425422468621815, 0.013349139181497906, 0.024634296972570673, 0.04849055176600814, 0.03387407286624823, 0.05402569778795753, 0.09276610506432396, 3.526044028145926, 44.014090061187744, 46.04703916822161, 38.40392344338553, 27.84613221032279, 25.649188246045792, 32.32842901774815, 52.946305070604595, 48.95512431008475, 55.823804242270334, 24.715800251279557, 0.059666902225996764, 0.10186202305236033, 0.1361844888223069, 4.542308398655482, 28.266086544309342, 45.78459528514317, 49.151202474321636, 49.36266395023891, 49.79943118776594, 47.90963929040091, 44.63131938661848, 34.98338781084333, 34.83197266714913, 37.69148990086147, 39.71394027982439, 43.199128900255474, 47.31246246610369, 47.015850816454204, 46.80987841742379, 45.4045079776219, 44.913148743765696, 45.9983183997018, 44.776022570473806, 43.76462541307722, 41.26509782246181, 41.29757717677525, 44.524195534842356, 36.63985572542463, 32.142766203199116, 33.53779424939837, 34.3363368170602, 33.235165459769114, 33.94798115321568, 34.300873211451936, 33.50252519335066, 34.10078246252877, 34.99628366742815, 31.89182506288801, 32.91000713620867, 34.41132525035313, 33.527201720646445, 34.32495566776821, 31.610801696777344, 33.51421553747994, 34.41983331952776, 33.95569712775094, 33.82021420342581, 34.23214510508946, 34.28740760258266, 34.74746172768729, 34.78969635282244, 36.061650957380024, 35.716394969395225, 34.63565479006086, 34.449206829071045, 34.37366601399013, 34.86739458356585, 34.886925969805034, 32.704232760838096, 32.04296922683716, 34.25917707170759, 37.8089839390346, 39.07197536740984, 40.25153977530343, 42.05635172980172, 45.53644732066563, 47.715690749032156, 46.75412259783064, 48.17382369722639, 46.18878936767578, 40.066307749067036, 38.51675871440342, 38.13766499928066, 35.09449645451137, 32.95131765093122, 35.74038709912981, 33.54144900185721, 33.83346789223807, 34.934896332877024, 33.3560745375497, 34.01099784033639, 35.86539561407906, 35.134698731558665, 34.08363083430699, 35.641868591308594, 35.68229668481009, 35.00553519385201, 33.486315046037944, 34.499748025621685, 33.976569516318186, 33.24665430613926, 33.133541107177734, 32.90674843106951, 32.60509933744158, 34.208972862788606, 35.0954726764134, 33.94072723388672, 32.79904440471104, 33.62664086478097, 31.928084237234934, 33.77297340120588, 32.544469356536865, 33.59405728748867, 36.923328331538606, 37.15441499437605, 37.29196153368269, 39.64258575439453, 37.113378933497835, 36.121151856013704, 34.050109250204905, 33.96698447636196, 33.446585246494834, 34.717105048043386, 35.32639953068325, 37.06085402624947, 37.51049974986485, 44.45959118434361, 47.393158844539094, 52.667783055986675, 41.87501416887556, 47.078092779432026, 50.718521526881624, 51.111952849796836, 51.27220957619803, 51.09431484767369, 51.38534361975533, 50.853591033390586, 50.66457918712071, 53.709522996629985, 55.98324455533709, 46.784597396850586, 2.2324835658073425, 0.26247913975800785, 1.8059096613100596, 0.3380799644759723, 1.9032373130321503, 50.39636482511248, 55.88030699321202, 55.56191274097988, 45.53399460656302, 35.22893020084926, 24.91327326638358, 38.16396740504673, 51.66270875930786, 41.52704838344029, 1.8800444432667323, 0.05299887752958706, 0.0261022735586656, 0.015033204574137926, 0.04619970897744809, 0.016240303105275546, 0.030926767803196396, 0.0519500150611358, 0.037016599239515405, 0.04855880560353398, 0.023836595937609673, 0.020340983689363514, 0.10453340863542897, 0.040479153261653016, 0.005410748924727419, 0.027751532649355273, 0.02230118145234883, 0.028664124930011373, 0.06669066926198346, 0.03232013267864074, 4.4936414786747525, 51.31779670715332, 52.46906457628523, 43.55866343634469, 32.88661255155291, 30.777163778032573, 37.6429671560015, 56.52895607267107, 53.9675304549081, 59.51176561628069, 26.235668318612234, 0.03367971668818167, 0.08858681110931294, 0.21298964534487042, 5.12636832680021, 30.55988665989467, 47.70946863719395, 48.310981137411936, 51.873857566288535, 50.939727851322715, 49.24487461362566, 46.16747229439871, 37.12462111881801, 35.666736194065635, 37.934197425842285, 41.74002456665039, 45.67629371370588, 48.75059018816267, 47.87787560054234, 46.3852253641401, 48.4771785736084, 47.50547647476196, 46.70015246527535, 45.520449093409944, 46.06043529510498, 43.406925201416016, 43.52650717326573, 45.55753510338919, 40.3240407535008, 33.92321082523891, 35.2189873286656, 35.45214455468314, 34.250262532915386, 35.674684933253694, 35.0339845929827, 36.19407320022583, 35.70625407355172, 36.364147731236045, 34.032512937273296, 32.69704137529646, 35.34121309007917, 35.18541363307408, 36.86751692635672, 33.9475017275129, 34.88231931413923, 34.73328740256173, 36.136701924460276, 36.097350801740376, 36.66872549057007, 35.79301970345633, 37.15804195404053, 36.760827336992534, 37.11206919806344, 36.57886791229248, 37.42563097817557, 36.36723273141043, 35.01159749712263, 35.5450176511492, 35.57934522628784, 33.70473861694336, 34.148568698338096, 36.92976236343384, 40.103428500039236, 41.50131572995867, 42.87029497964041, 44.57926000867571, 47.03826223100935, 48.25815050942557, 47.68289177758353, 49.420830794743125, 46.19519213267735, 39.679042952401296, 40.34350265775408, 41.459800243377686, 35.892007214682444, 34.82973187310355, 35.79782438278198, 35.613836084093364, 36.35290902001517, 35.78775296892439, 36.047167437417166, 35.66265065329415, 37.05531631197248, 35.515703201293945, 35.33177743639265, 35.48436682564871, 37.596608775002615, 37.028725555964876, 35.0713381086077, 34.77763775416783, 35.69287879126412, 35.95525319235665, 35.312624726976665, 33.79062877382551, 34.128742013658794, 35.4990587915693, 35.7864362852914, 33.85778658730643, 34.962310450417654, 35.449125562395366, 34.09842702320644, 36.016553674425396, 36.98316969190325, 35.98898669651577, 39.0385753767831, 39.4211779321943, 40.0986898286002, 40.019914627075195, 38.00186940601894, 38.454718249184744, 35.922304834638325, 36.372860772269114, 35.85083218983242, 36.79663487843105, 37.770188672201975, 38.35105460030692, 40.52383272988455, 46.73860379627773, 48.92275265284947, 54.36485971723284, 44.463225092206685, 49.38124343327114, 50.56957994188581, 51.12039491108486, 52.31100000653948, 54.693200315747944, 52.99852773121425, 53.00135564804077, 53.63838733945574, 54.7117520059858, 57.188211577279226, 47.78312301635742, 3.254243961402348, 0.5922436032976423, 0.9267475796597344, 0.2259456201323441, 2.5208566061088016, 55.04205894470215, 60.15889998844692, 58.913254737854004, 54.2917195047651, 46.79627384458269, 32.75691747665405, 44.502635274614605, 57.43981279645647, 49.957287311553955, 2.923552483320236, 0.05330148718452879, 0.04075431278241532, 0.027301141460027014, 0.023558147218344466, 0.03822766211149948, 0.06459280183272702, 0.04259708836408598, 0.022351952835119197, 0.12597067760569708, 0.258415339248521, 0.11855221353471279, 0.1460121457598039, 0.09945734922907182, 0.1156612608049597, 0.07187163696757384, 0.16136161211345876, 0.16735710682613508, 0.1718575581908226, 0.13400601143283503, 5.488124983651297, 57.17029912131173, 59.084305490766255, 51.19620323181152, 38.76945774895804, 34.679511819567, 42.381249495915, 62.141443388802664, 57.784391335078645, 63.67313207898821, 30.590118271963938, 0.13970480992325715, 0.21591646543570928, 0.46017441579273766, 5.984743569578443, 33.38852262496948, 50.07877308981759, 49.85430111203875, 54.322812693459646, 53.85183252607073, 52.89906426838466, 48.69564730780465, 38.8253664289202, 37.82586806161063, 41.76386036191668, 44.791336400168284, 46.49247080939156, 51.701514448438374, 49.71110916137695, 48.51406308582851, 50.38008519581386, 48.65632745197841, 49.561087131500244, 47.12105001722063, 46.89635222298758, 44.66898904527937, 47.349958419799805, 47.239148548671174, 41.9785145350865, 35.28383139201573, 36.74235555103847, 37.43919733592442, 36.672091892787385, 37.32194995880127, 37.51022529602051, 38.53973640714373, 38.36784839630127, 40.237466199057444, 35.39218854904175, 34.42330047062465, 38.26203427995954, 36.16935150963919, 39.279128960200715, 34.41653987339565, 37.22083977290562, 36.711074760981965, 37.51540865216936, 38.09684433255877, 38.45140395845686, 36.82592848369053, 39.126536096845356, 38.43531887871878, 39.63147211074829, 39.111107621874126, 39.84233604158674, 37.99860027858189, 37.11466782433646, 37.10030937194824, 37.40151725496565, 34.91110222680228, 37.20964275087629, 39.5486078943525, 41.00338697433472, 42.68208565030779, 44.36863579068865, 47.63866649355207, 50.081191062927246, 52.40151071548462, 47.11189923967634, 51.31548295702253, 48.805414949144634, 42.0213953426906, 42.66751875196184, 43.3333090373448, 38.9532584462847, 37.26216765812465, 40.31790896824428, 37.228632177625386, 38.2357805115836, 37.1675887789045, 37.18154770987374, 36.31237322943551, 39.92456797191075, 37.499750886644634, 36.63802834919521, 38.14880643572126, 39.64272124426705, 40.50785534722464, 36.21602603367397, 36.9274069241115, 38.01009259905134, 36.937057971954346, 37.40283741269793, 35.983890192849294, 36.77586671284267, 39.02703789302281, 38.41065624782017, 36.93961143493652, 37.12043482916695, 37.94153124945504, 36.18961593082973, 37.70418773378645, 39.24442618233817, 36.97018698283604, 40.83394472939627, 41.569133622305735, 42.63313559123448, 43.45699044636318, 41.31028195789882, 40.92943729673113, 36.94405828203474, 38.01545313426426, 37.6541884967259, 38.863300119127544, 39.563209533691406, 40.55483906609671, 42.275084495544434, 50.54072754723685, 49.90457132884434, 55.22175325666155, 48.666593415396555, 50.74498374121529, 49.169604778289795, 51.62685258047921, 53.782979352133616, 56.873989718300955, 55.36170039858137, 56.07278251647949, 55.568940843854634, 58.18188040597098, 60.55536420004708, 49.985309396471294, 3.9462285212108066, 1.5974085522549493, 6.437532050268991, 0.4918366510953222, 2.9363067703587666, 59.8534710747855, 65.46601050240653, 65.6187527520316, 57.85632950919015, 45.01976190294538, 36.78489589691162, 52.23931891577584, 64.91900662013462, 57.631478854588096, 4.598631364958627, 0.2326632525239672, 0.11917847421552454, 0.13402946160307952, 0.1353760686303888, 0.09858791516827685, 0.23337734277759278, 0.07841185959322111, 0.12294709842119898], [0.05181290348991752, 0.040309567004442215, 0.04047794207664473, 0.03375805016340954, 0.01657240528480283, 0.02451305803177612, 0.019524544909862534, 0.005549849027634731, 0.053917875180819204, 0.050721011723258665, 0.011560278296071504, 0.585993155837059, 35.2275127683367, 48.03036771501814, 43.36390542984009, 31.607216426304408, 22.158484492983135, 34.814133167266846, 47.42118092945644, 50.07119607925415, 50.78194120952061, 34.27478967394148, 0.1471459234931639, 0.02773193146900407, 0.3094963239771979, 0.8403079179780824, 17.64905670710972, 42.93403775351388, 47.299101080213276, 51.24068212509155, 49.70928178514753, 44.15641696112496, 39.814400809151785, 34.85915054593767, 38.77272687639509, 45.035909516470774, 44.97540807723999, 45.904712268284385, 45.9395956993103, 46.02111196517944, 44.85316494532994, 44.951297828129356, 45.23005608149937, 43.96866968699864, 41.67648676463536, 42.81101989746094, 42.477013042994905, 42.176180362701416, 40.08743027278355, 31.770943777901785, 33.12616906847273, 35.017381872449604, 32.921478612082346, 32.68517732620239, 32.853518281664165, 32.50725827898298, 32.37647928510393, 32.15035016196114, 32.24382080350603, 32.98019436427525, 33.81383923121861, 33.81176519393921, 33.19950383050101, 33.95139619282314, 32.88047729219709, 32.088792596544536, 34.08280399867466, 34.3095897265843, 34.05284684044974, 34.88514723096575, 34.92406061717442, 34.31409215927124, 36.70698227201189, 35.061527252197266, 37.16925287246704, 34.88115201677595, 34.5093434878758, 34.03691809517996, 34.29546403884888, 35.61205039705549, 32.542075702122276, 31.87117154257638, 32.62195914132254, 36.02829960414341, 38.44119358062744, 39.84042181287493, 41.926854678562705, 45.42850705555507, 44.502763816288535, 43.08015489578247, 45.89261892863682, 43.69086333683559, 39.433531829289024, 39.04418952124459, 36.90600299835205, 32.492211954934255, 32.07849884033203, 33.75478996549334, 34.363584177834646, 33.875542708805625, 34.57202666146414, 34.42753539766584, 33.68127107620239, 34.458604267665315, 34.88828086853027, 34.939020088740754, 34.0258218220302, 35.68100084577288, 35.784758295331685, 35.17862524305071, 33.29871368408203, 34.28907864434378, 33.81503779547555, 33.532329491206575, 32.08930328914097, 33.49444096429007, 33.973616531917024, 33.70531531742641, 32.478958266122, 32.46462413242885, 32.95690400259835, 34.2204269681658, 33.68442208426339, 33.46321923392159, 34.27612720217024, 36.25791672297886, 39.86026586805071, 39.62372834341866, 40.07562528337751, 39.06869234357561, 37.48615673610142, 36.079546042851035, 34.90864951269967, 36.17349263599941, 35.12241431644985, 36.09375858306885, 33.24638680049351, 37.19726800918579, 39.14139829363142, 46.06331532342093, 45.068486145564485, 48.57873691831316, 55.12620857783726, 48.74691459110805, 48.50574609211513, 51.34023591450283, 51.632185322897776, 49.80894674573626, 48.36472545351301, 50.597424847739084, 53.42754772731236, 53.569079058510916, 49.1792071887425, 3.6687839116368974, 1.2525828097547804, 0.5323629421847207, 0.1823081374168396, 1.9283843636512756, 49.508204392024446, 54.18676349094936, 54.08110918317522, 39.0272011756897, 26.974063805171422, 17.0510721547263, 31.857785837990896, 49.86552940096174, 31.493474415370397, 0.5312226233737809, 0.022954249355409826, 0.03164117357560566, 0.03595112623380763, 0.057769691172455034, 0.054319544163133414, 0.04534103308937379, 0.043189788702875376, 0.029875062273017, 0.024654323933646083, 0.07074708731046744, 0.014262198803148099, 0.05010566527822188, 0.12172036139028412, 0.01064865886499839, 0.05097033941586103, 0.020731724865202392, 0.0650888177167092, 0.050598064570554664, 0.02011239541960614, 0.7965686821511814, 42.32007755552019, 53.867830753326416, 45.89517933981759, 33.82610280173165, 27.049795695713588, 43.051979950496126, 50.76589087077549, 55.23519107273647, 54.28326007298061, 36.398913042885916, 0.07469593041709491, 0.08079883043787309, 0.8757871027503694, 0.8547678792050907, 19.752926077161515, 44.68023470469883, 50.43935680389404, 52.66578892299107, 51.84082235608782, 47.31264311926705, 41.12532785960606, 37.61007785797119, 40.22338914871216, 47.417324679238455, 47.52330902644566, 47.39316231863839, 46.832411425454275, 48.31041833332607, 47.19439172744751, 47.74145466940743, 46.42025123323713, 45.245394229888916, 43.41310562406267, 43.70002801077706, 42.68848494121006, 44.759086336408345, 42.14116144180298, 33.852724824632915, 34.317406449999126, 36.77858345849173, 35.03607947485787, 35.102962834494456, 35.48228931427002, 35.86107383455549, 33.07249423435756, 34.531185150146484, 33.81054925918579, 34.172981194087434, 34.74552665437971, 35.17295551300049, 33.40421860558646, 34.480848925454275, 34.50389610018049, 33.91761057717459, 35.24356310708182, 36.05888557434082, 36.515225887298584, 36.12194742475237, 36.86620371682303, 36.308228628976, 38.321305888039724, 37.18188122340611, 37.7659398487636, 37.11104781287057, 35.113544940948486, 37.006216866629465, 37.19199085235596, 36.51992286954607, 34.28412110464913, 34.78529814311436, 34.939534255436485, 38.93543979099819, 40.801746777125764, 41.23753431865147, 42.480247429439, 48.373973505837576, 46.98019960948399, 46.58387436185564, 48.98301437922886, 45.65906565529959, 40.656407833099365, 40.750020912715364, 39.058506284441265, 35.96242720740182, 34.39521932601929, 33.96105418886457, 36.82074165344238, 36.77819783346993, 35.87409823281424, 35.61055653435843, 34.66151598521641, 36.731912408556255, 36.662909848349436, 36.427821023123606, 35.931007453373496, 36.070318835122244, 35.23860556738717, 36.413076945713584, 35.297335215977256, 35.19535650525774, 34.51842130933489, 34.56388337271554, 33.68021147591727, 34.8475227355957, 33.743641580854145, 34.75957243783133, 34.20915004185268, 33.80747815540859, 36.006492682865684, 36.96861668995449, 35.417434828622, 35.536606856754844, 36.0389928817749, 38.2823542867388, 40.89804186139788, 42.09024156842913, 42.48350960867745, 42.250380175454275, 41.178405148642405, 37.08718422480992, 36.33678225108555, 36.95143379483904, 37.36762394223894, 37.195933955056326, 33.80333702904837, 38.94491713387625, 41.75831569944109, 46.48239939553397, 48.35370908464704, 50.6628178187779, 54.96052530833653, 49.759388719286235, 49.52351822171892, 52.314091954912456, 52.265048095158164, 52.279472555433, 52.73016050883702, 52.76312971115112, 55.88948208945138, 55.42432451248169, 52.257811546325684, 5.436170262949807, 1.000001677445003, 0.848135226539203, 0.2193856928497553, 2.426367836339133, 53.19024242673601, 58.510530199323384, 59.42172391074044, 44.48608813967024, 30.457824570792063, 20.07745906284877, 38.500572885785786, 56.67484392438616, 39.8858699798584, 1.0712543683392661, 0.07795440485434872, 0.01659961793172572, 0.016589623110901033, 0.018827811582013965, 0.012912356011968638, 0.04271978106615799, 0.07983379757830075, 0.008887304941059222, 0.14297253957816533, 0.09189271514437028, 0.08712358426834856, 0.11321244149335793, 0.2522109236036028, 0.24246990201728685, 0.11964731477200985, 0.09534966107457876, 0.10198764702571289, 0.14603551450584615, 0.1249713719423328, 1.0209425709077289, 48.32601009096418, 62.38260841369629, 55.106722354888916, 42.73659774235317, 31.462391648973735, 45.50206068583897, 56.88797296796526, 57.67462716783796, 61.39859063284737, 42.34284332820347, 0.3128444328904152, 0.3058976185108934, 1.4471176053796495, 1.3461603884186064, 20.86102478844779, 47.39673021861485, 52.627334117889404, 57.098274094717844, 54.85787957055228, 48.43507596424648, 42.68552500861031, 38.60142598833357, 44.503621918814524, 48.417774949754985, 49.31549610410418, 49.37050151824951, 48.167215960366384, 48.61464173453194, 49.29658310753958, 50.0438722882952, 49.3614375931876, 48.363613741738455, 46.30413293838501, 44.58647918701172, 45.555377687726704, 46.55129425866263, 44.59947231837681, 34.98953349249703, 36.871011870247976, 39.18617943355015, 37.46883487701416, 37.6846980367388, 37.72199944087437, 38.21607542037964, 35.08651992252895, 36.82800599506923, 35.291127000536235, 35.70058781760079, 36.303865160260884, 35.930065972464426, 34.732780184064595, 36.729622977120535, 35.67416729245867, 34.858886514391216, 37.246992792402, 37.671659742082866, 37.44281039919172, 38.92971794945853, 38.80371584211077, 38.249847139631, 39.671340874263215, 39.10188388824463, 40.89685024533953, 39.1789949962071, 36.75728375571114, 37.65676627840315, 37.50975629261562, 38.050551959446494, 35.187289646693635, 37.235208647591726, 36.997813020433696, 40.14136913844517, 41.78320762089321, 43.06549767085484, 45.92164502825056, 49.13943917410714, 48.6457279750279, 47.046996116638184, 52.23300995145525, 48.32731635229928, 42.66553156716483, 43.46134001868111, 41.26492759159633, 37.92626953125, 36.668701171875, 36.96802609307425, 39.604061467306956, 37.7589464868818, 38.86328969682966, 37.328832149505615, 36.84729766845703, 37.79978452410017, 38.4826534816197, 38.34383542197091, 38.787891319819856, 38.50787891660418, 38.51604652404785, 38.919709069388254, 35.99900252478463, 37.49421317236764, 37.303568499428884, 36.718293939317974, 36.44425698689052, 37.12572588239397, 35.29083865029471, 38.332780838012695, 35.919789586748394, 35.258394036974224, 37.606471742902485, 40.15474789483206, 38.035957268306184, 38.5186208316258, 38.21787847791399, 40.725643157958984, 43.509425027029856, 44.22660766329084, 44.29710061209542, 42.876583099365234, 42.50535821914673, 38.9750862121582, 38.3079514503479, 39.86188479832241, 40.25052186420986, 40.03456142970494, 36.38720185416085, 40.534279346466064, 43.625352246420725, 49.630127906799316, 51.110247067042756, 51.7795844078064, 54.114776679447715, 51.652276039123535, 51.2556346484593, 53.56039381027222, 55.577507972717285, 54.02625662939889, 54.89848484311785, 55.8041547366551, 58.96520641871861, 57.11277151107788, 54.27997357504708, 6.022513108594077, 2.139891219990594, 3.620578178337642, 0.3809615863221032, 2.637370514018195, 57.933676855904714, 62.608800070626394, 64.14507457188198, 50.14365884235927, 41.09711469922747, 27.244095121111187, 45.56009898866926, 64.95170484270368, 48.575704029628206, 2.0604826467377797, 0.20696958766451903, 0.11677905225328036, 0.16684490788195813, 0.13533467799425125, 0.0720143396673458, 0.10666986435119595, 0.1450638116470405, 0.1555602326989174], [0.01649571386432009, 0.06365277977394206, 0.07236810068466834, 0.047919700254819224, 0.052669126473899396, 0.04153599190924849, 0.009951659212155002, 0.027806153022018925, 0.021494238770433834, 0.05691572092473507, 0.07249791121908597, 0.091524263843894, 22.93922230175563, 51.865658691951204, 38.7659523827689, 34.90108639853341, 22.08432115827288, 31.020962170192174, 45.88672685623169, 51.18961981364659, 47.620093958718435, 43.21756247111729, 1.1693559842450278, 0.09496095550379582, 0.2534093250121389, 0.17984106551323617, 6.705022496836526, 35.36611543382917, 48.15582438877651, 50.51030485970633, 45.846187591552734, 41.67527777808053, 36.79810789653233, 38.62565435682024, 46.389665263039724, 48.11823810849871, 46.886579581669395, 48.309733935764854, 47.23163407189505, 45.86925908497402, 42.388260228293284, 44.01106064660208, 41.24123770850045, 41.55790533338274, 39.72252130508423, 41.047924927302766, 39.49796594892229, 39.415595054626465, 34.6616028376988, 31.64476101739066, 35.380755288260325, 32.62595435551235, 32.562708377838135, 32.941201073782786, 33.79131317138672, 32.946843011038645, 33.481840406145366, 32.92729425430298, 32.14851931163243, 33.019389152526855, 32.909555503300254, 33.16256373269217, 33.27505506787981, 33.00266136441912, 32.88998590196882, 32.8598689351763, 34.11885125296456, 32.69586018153599, 31.996430192674907, 34.03901992525373, 33.95448466709682, 33.85528176171439, 34.75047377177647, 34.98633732114519, 35.92818995884487, 35.18303387505667, 34.02948352268764, 33.26649488721575, 35.24078730174473, 35.44552986962454, 34.00663089752197, 30.29750531060355, 33.78058515276228, 37.27457019260952, 38.61445386069161, 39.65973738261631, 42.44863312585013, 47.557101590292795, 47.84149830681937, 40.45788390295846, 45.64972727639334, 44.73741143090384, 39.72660684585571, 39.772649083818706, 39.02408838272095, 33.83297109603882, 33.16712869916643, 33.57778113228934, 35.16844960621425, 34.26965495518276, 34.67449869428362, 35.67264911106655, 35.066106115068706, 35.807920115334646, 35.152475697653635, 34.93143960407802, 35.07624353681292, 34.07123177392142, 35.15898615973336, 34.73003217152187, 34.64649050576346, 33.46734993798392, 32.72793654033116, 33.89361497334072, 31.89045626776559, 33.879496233803884, 33.857724053519114, 32.482811042240684, 33.04378080368042, 33.934831687382285, 33.21846546445574, 34.47196217945644, 33.04862717219761, 33.62802703039986, 34.52892698560442, 37.63609538759504, 41.105025223323274, 41.38059772763933, 42.577831404549734, 43.16179622922625, 43.747932365962434, 44.15748003550938, 42.409361907414024, 42.17145906175886, 41.188924721309114, 39.59393446786063, 37.21665695735386, 34.01807458060128, 34.98434318814959, 39.60475281306675, 43.97157403400966, 48.40046003886631, 45.342714173453196, 49.766069412231445, 52.10497897011893, 50.52420820508684, 51.69044944218227, 48.49566078186035, 45.85186774390084, 48.07795592716762, 52.745543820517405, 53.20604957853045, 54.596616881234304, 7.5508471216474256, 0.627665573997157, 0.07469406444579363, 0.11324294164244618, 1.6411708039896828, 44.99267782483782, 56.77185467311314, 51.87497622626168, 44.23452166148594, 32.506216049194336, 26.92802504130772, 38.865308148520334, 58.47395488194057, 32.954663208552766, 0.06169175250189645, 0.06022108213177749, 0.01477959702190544, 0.038705483078956604, 0.05084985873794981, 0.015495766985363193, 0.018770784106371657, 0.04170427877189858, 0.028123079765854136, 0.051933994849345515, 0.06201760537390198, 0.015220327568905694, 0.02088861064320164, 0.06744629942945071, 0.0930094209366611, 0.07026409929884331, 0.019691997174439684, 0.052907105668314865, 0.04492835148370691, 0.06212485461894955, 0.12937211937138013, 28.096439327512467, 59.61812169211251, 45.186772278376985, 39.64900936399187, 24.30447905404227, 35.11783197947911, 50.238758836473735, 56.030575684138704, 51.909540040152415, 45.9150789805821, 1.343557745218277, 0.239359443209001, 0.7402390390634537, 0.6487698586923736, 6.882503807544708, 40.480041708265034, 50.29557773045131, 53.262402943202424, 48.14504425866263, 44.24683386938912, 38.96977778843471, 41.4085225377764, 47.66936016082764, 50.22935444968087, 47.95832184382847, 48.8554767199925, 47.94692332404, 47.98217500959124, 45.917309352329795, 45.105985573359895, 43.25717762538365, 42.886821269989014, 43.38658435004098, 42.56215279442923, 40.716012954711914, 41.26610878535679, 36.39525134222848, 33.92433295931135, 36.105219636644634, 33.835076400211875, 34.342162881578716, 35.14091736929757, 34.445965494428364, 35.4198180607387, 35.55197627203805, 35.76948962892805, 33.545322622571675, 34.53914431163243, 34.71292223249163, 34.143406186785015, 34.008579867226736, 36.65553433554513, 33.741640499659944, 35.08460916791643, 35.244897161211284, 35.109212739127024, 33.206969669886995, 36.76795271464756, 34.37340545654297, 36.015240464891704, 36.225882053375244, 36.166499274117605, 37.288237299237935, 37.77045270374843, 35.67731482642037, 35.95531225204468, 37.60526623044695, 36.95305619921003, 34.94036109106881, 33.22762319019863, 35.27569852556501, 38.9555652482169, 40.8198607308524, 41.24682058606829, 42.42457846232823, 48.25104250226702, 48.74481970923287, 44.89356524603707, 49.083773681095664, 45.317589487348286, 41.34487009048462, 41.326669284275596, 41.11823027474539, 34.99001291819981, 34.582758154187886, 35.477533272334504, 36.303590706416536, 35.27320759637015, 35.501091139657156, 37.53600658689226, 36.51640360695975, 37.26222324371338, 36.44284650257656, 36.36731263569423, 35.27729661124093, 35.692017214638845, 35.91184432165963, 35.61290502548218, 35.17735024860927, 34.93563979012625, 34.385140963963096, 36.53348227909633, 33.459543636866975, 35.426453590393066, 35.411195346287315, 34.65625619888306, 34.88329553604126, 36.220754282815115, 35.264605726514546, 35.611008167266846, 34.33827189036778, 35.46303238187517, 35.35893447058541, 39.968772411346436, 42.48343317849295, 43.04456622259957, 44.639608587537495, 46.03452546255929, 46.023140839168, 45.94600541251046, 44.36802434921265, 43.73467867715018, 42.77703625815255, 41.44063711166382, 38.50070142745972, 36.86625235421317, 38.239542961120605, 42.191004344395225, 46.08434752055577, 50.16847433362688, 47.24185139792306, 51.35667187826974, 53.598438671657014, 52.194923400878906, 52.87550292696272, 50.119381836482454, 47.81153767449515, 49.127054010118755, 54.91788073948452, 56.13459716524397, 55.636633668627056, 7.464251722608294, 0.7928597011736461, 0.7338010988065174, 0.15857131326837198, 1.5573014872414725, 51.397249358040945, 58.88897773197719, 56.838265555245535, 51.02273450578962, 38.70614923749651, 29.390556948525564, 44.852160930633545, 62.71517699105399, 39.87229667391096, 0.2501609878880637, 0.07361984851637057, 0.026963575377262065, 0.04612011342708554, 0.024917783814349344, 0.01956930447236768, 0.03443444440407412, 0.089787539892963, 0.05161954815100346, 0.13126633130013943, 0.12800810113549232, 0.13525542510407312, 0.08906698320060968, 0.22041819244623184, 0.14781912522656576, 0.1734160038509539, 0.09793869964778423, 0.12105105444788933, 0.10092496619160686, 0.18411503545939922, 0.3424327666206019, 34.87302609852382, 68.76775973183769, 50.16250583103725, 46.089037554604666, 29.969904695238384, 43.634756633213584, 54.799215929848806, 61.221376827784944, 55.439780780247276, 52.016233103615896, 1.5867279767990112, 0.29619103936212404, 0.9041308132665498, 1.3144320909466063, 8.35205258641924, 43.45267908913748, 52.32764441626412, 55.570073400224956, 51.146759850638254, 45.60724599020821, 40.942340101514546, 43.707073484148296, 49.6985433442252, 51.807366779872346, 50.369444029671804, 51.74913740158081, 50.66584723336356, 50.06351137161255, 47.40138898577009, 48.4298335484096, 45.877881799425396, 45.01814644677298, 43.79456172670637, 44.95535557610648, 42.52825600760323, 43.960863385881694, 38.85176263536726, 35.459610394069124, 38.48812518801008, 35.575565406254356, 37.226238523210796, 37.28394331250872, 37.181321893419536, 37.878698689596995, 38.30889293125698, 37.57370056424822, 35.37295593534197, 36.76145614896502, 35.896707671029226, 36.9873559815543, 35.039001192365376, 38.02118192400251, 35.94314248221261, 36.49790750231062, 37.0399295261928, 35.66536392484392, 35.47470882960728, 37.71354348318917, 37.94397006716047, 38.10685321262905, 38.71782568522862, 38.070208413260325, 39.18316044126238, 38.47336721420288, 36.91590070724487, 38.33771405901228, 39.413587025233674, 37.752901554107666, 37.52445520673479, 34.99666929244995, 37.92401136670794, 41.51395797729492, 43.25993953432356, 41.46256562641689, 45.53233746119908, 49.550838538578574, 50.67439004353115, 44.078121185302734, 50.87548133305141, 47.27959748676845, 43.52742086138044, 44.80532659803118, 44.4447637285505, 37.255615506853374, 37.20703370230538, 38.237218788691926, 38.8735591343471, 37.189621516636436, 38.52950518471854, 40.08687094279698, 38.66232000078474, 39.67697933741978, 39.14187771933419, 38.293190002441406, 36.54367528642927, 36.824559688568115, 38.826401710510254, 37.78006206239973, 37.24946982519967, 37.64771972383772, 36.70930297034127, 38.49292639323643, 34.75669240951538, 38.41004480634417, 37.06146894182478, 36.77418177468436, 36.55978121076311, 38.32720143454415, 37.40799992425101, 38.8272111756461, 36.95727028165545, 37.94603715624128, 36.92139325823103, 41.56372792380196, 45.09254080908639, 45.71351868765694, 46.887191023145405, 48.165819372449604, 47.99322264535086, 48.05027777808053, 47.60521786553519, 46.693655899592805, 44.78592375346592, 44.4405392238072, 40.67693975993565, 39.65442201069423, 38.57308081218174, 44.00415761130196, 47.437151363917756, 50.45161690030779, 50.27342687334333, 54.31991876874651, 55.53766005379813, 54.08488552910941, 55.65572384425572, 52.38066611971174, 49.65908105032784, 53.175828388759065, 57.758811541966026, 57.595042501177105, 56.856796400887625, 9.625436782836914, 1.215732712830816, 1.9253412697996413, 0.4554938812341009, 2.187791666814259, 55.28248398644583, 64.9709860937936, 62.240684509277344, 58.29610184260777, 45.81515346254621, 38.65995413916451, 52.525511741638184, 69.31461770193917, 48.71028021403721, 0.6081124746373722, 0.13420077812458786, 0.128914637491107, 0.14724019914865494, 0.12331885418721608, 0.10926949485604252, 0.1329037177243403, 0.18202878454966204, 0.0923294745651739], [0.060438505107803006, 0.0659925245812961, 0.009202321608816939, 0.03700641442888549, 0.03828449620466147, 0.03366515193400638, 0.034338458840336115, 0.04357181748907481, 0.0837087957188487, 0.050065088884106705, 0.07667621451296977, 0.013457634386473467, 16.178626809801372, 50.590299470084055, 42.91101489748274, 30.139986174447195, 27.255663871765137, 42.37078550883702, 38.98448712485177, 53.38761643001011, 45.28549575805664, 46.7400802884783, 2.9707231521606445, 0.18450193612703256, 1.1124389469623566, 0.4771284003342901, 0.7968288596187318, 25.236190795898438, 48.12958104269845, 47.38433115822928, 44.715625354221885, 39.06160518101284, 37.90747465406145, 43.98075260434832, 47.522106988089426, 46.2200527872358, 49.97977863039289, 45.65331949506487, 44.658573695591514, 42.392738342285156, 41.104872362954275, 40.52812671661377, 38.676122597285676, 37.98830999646868, 37.75447184698922, 36.315854276929585, 35.38572325025286, 33.39459882463728, 32.42173637662615, 31.986938953399658, 31.672157764434814, 33.16723639624459, 32.453614711761475, 33.43951198032924, 33.07563134602138, 32.819138595036094, 31.092830862317765, 33.098108768463135, 32.829800605773926, 34.104183605739046, 33.04670252118792, 35.06477206093924, 32.143540927342, 33.29669523239136, 33.649955545152935, 32.91890777860369, 32.446128027779714, 34.35718141283308, 34.920360701424734, 34.37519114358084, 34.96799407686506, 33.76154708862305, 36.69978741237095, 33.806109360286165, 34.84464965547834, 34.3639246395656, 34.266649859292166, 33.82400444575718, 34.575125558035715, 35.24689824240548, 34.49271992274693, 29.93391650063651, 33.29456908362252, 37.540123394557405, 40.45596620014736, 40.36214814867292, 43.588683128356934, 46.65932485035488, 46.02066033227103, 38.53361504418509, 45.85827398300171, 44.490948404584614, 41.2103078024728, 39.669360637664795, 37.82675743103027, 33.22562558310372, 32.36937475204468, 32.91138982772827, 34.50815882001604, 34.47719069889614, 34.10032735552107, 33.984962940216064, 33.89657143184117, 35.234797954559326, 33.902522563934326, 34.74989707129342, 34.770199707576204, 34.94533600125994, 34.12098434993199, 33.10908692223685, 34.74093042101179, 35.200102124895366, 34.46622296742031, 32.85886492047991, 33.33710248129708, 32.352212701525005, 32.939321586063926, 32.55709770747593, 32.74207959856306, 32.68032053538731, 34.09736047472273, 35.143231119428364, 34.31600291388375, 34.32560532433646, 34.680290017809185, 37.01998124803816, 41.08573007583618, 43.222464425223215, 43.53093664986746, 45.085363319941926, 47.77947173799787, 45.78100306647164, 45.476734501974924, 45.646308762686594, 46.363355909075054, 42.75536830084664, 42.61853395189558, 41.727132184164866, 37.03286668232509, 34.50463260923113, 37.61113051005772, 38.06462206159319, 42.75010504041399, 45.365240233285085, 48.105415207999094, 50.07478482382638, 49.287282943725586, 48.94854089191982, 46.42905112675258, 46.73960086277553, 51.516393593379426, 53.453923089163645, 54.284052167619976, 6.513194893087659, 0.8536093213728496, 0.4040919223002025, 0.1619840051446642, 2.0936959045273915, 49.36332402910505, 54.53630999156407, 52.97868367603847, 43.86476285117013, 27.099072320120676, 25.730457850864955, 41.734323569706504, 56.51124164036342, 23.800625222069876, 0.040210958902857134, 0.02533199212380818, 0.03007086712334837, 0.04874647142631667, 0.06721470864223582, 0.036974448644156964, 0.0020426936264682028, 0.028673848336828605, 0.05412224992843611, 0.03845561255833932, 0.04515949783048459, 0.045894510711410215, 0.05406027253983276, 0.08824761823884078, 0.006994456443603018, 0.025285899239991392, 0.015484689901183759, 0.0492879457638732, 0.014871346830789531, 0.07622447982430458, 0.010481517878361046, 19.383325338363647, 57.18745422363281, 48.744110992976594, 36.15062264033726, 25.608414479664393, 44.26151541301182, 45.55943543570382, 57.734055110386436, 50.96736431121826, 50.9525021144322, 3.1816852263041904, 0.3490555669580187, 1.5123717210122516, 0.5410341854606355, 0.970142662525177, 29.10233177457537, 50.79184239251273, 49.76327971049717, 46.84867368425642, 41.89259658540998, 39.1697712625776, 46.544405119759695, 47.94261196681431, 47.40841361454555, 49.62641062055315, 47.593357290540425, 46.06723410742623, 45.72236374446324, 43.986238207135884, 43.00354058401925, 41.08364561625889, 40.51574502672468, 38.2287871497018, 38.85387488773891, 36.85127898624965, 34.6504579271589, 34.123277255467, 34.734836850847515, 32.33467197418213, 34.93057107925415, 34.5724435533796, 35.390993458884104, 33.516088077000205, 35.33528627668108, 34.32903773444039, 34.91625779015677, 34.43968084880284, 36.28688376290457, 34.23351042611258, 34.955348355429514, 34.227837221963064, 34.19344711303711, 33.920167514256065, 34.97079072679792, 34.72523096629551, 35.3675537109375, 36.63708339418684, 35.07970373971121, 35.63727930613926, 36.15106037684849, 36.91898570741926, 36.397658893040244, 36.68365369524275, 35.91422755377633, 35.352361474718364, 35.34616368157523, 36.49315840857369, 37.781267574855256, 34.226784569876536, 31.96836989266532, 34.78586789539882, 41.4775424684797, 41.44598375047956, 42.9573107446943, 44.171873228890554, 48.64468921933855, 48.16483620234898, 43.34927947180611, 46.78851965495518, 46.62726933615548, 42.61958312988281, 42.47591870171683, 39.337869031088694, 36.54927553449358, 33.51814474378313, 34.99133307593209, 35.290466921670095, 36.096155711582725, 35.96075963973999, 34.57981211798531, 35.247325556618826, 35.878347056252615, 36.89639711380005, 36.131136417388916, 36.800230571201865, 35.45499331610543, 35.65014736992972, 35.21935558319092, 36.405663217817036, 36.90082311630249, 36.095856939043315, 34.48742886951992, 33.8036253792899, 34.38704824447632, 35.59712219238281, 35.17930269241333, 33.853676727839876, 35.356863907405305, 35.43076147351946, 35.54286370958601, 35.84906039919172, 36.09903226579939, 37.18547344207764, 40.06084646497454, 43.052143233163015, 45.2435599054609, 44.95637696129935, 47.041197844914024, 51.1527214050293, 48.48281356266567, 47.95773472104754, 47.895642144339426, 48.3787955556597, 44.01362453188215, 45.512938090733115, 42.53438779285976, 38.02383960996355, 37.88604293550764, 39.96973821095058, 40.514626366751536, 45.686003821236746, 48.02381903784615, 50.68816484723772, 51.77800369262695, 52.098426818847656, 52.30282197679792, 49.02629818235125, 48.10260466166905, 51.27816418239048, 54.59871871130807, 55.081826959337505, 8.19769401209695, 0.8053431170327323, 0.5189123153686523, 0.285221380846841, 1.940338739327022, 52.077696868351524, 60.53924437931606, 57.09415033885411, 49.88653727940151, 30.45642798287528, 27.8148409979684, 46.930391447884695, 62.046989577157156, 30.218782220567974, 0.04968703292044146, 0.039245461246797016, 0.024361926230735013, 0.049487004189618995, 0.022439819727359072, 0.02965046718184437, 0.037829613113509755, 0.025770744741229073, 0.026445637723164897, 0.21191732931349958, 0.13944547383912972, 0.10660230261938912, 0.11873870209923812, 0.1286947378622634, 0.14810036442109517, 0.07745528806533132, 0.09692680715982403, 0.16304306260177068, 0.12742541597357818, 0.17731983294444426, 0.07322841523481266, 22.228289570127213, 66.05252879006522, 53.666826316288535, 41.82172495978219, 37.55839715685163, 53.225007738385884, 47.879862785339355, 62.321651867457796, 54.842958314078196, 55.6056273324149, 3.972208704267229, 0.6176703731928552, 2.3201615810394287, 1.118360874908311, 1.50138900748321, 32.00544548034668, 52.518730299813406, 50.88695280892508, 50.011987004961284, 43.93772241047451, 42.0445293698992, 47.851048605782644, 50.10476630074637, 49.27198995862688, 52.49301849092756, 49.71131760733468, 49.157865796770366, 47.096314430236816, 46.77402918679373, 45.255066122327534, 43.17476504189627, 42.03137295586722, 41.410276957920615, 41.215543270111084, 38.759893553597585, 37.11887843268258, 37.46264403206961, 37.06457131249564, 33.640120370047434, 38.33393423897879, 38.04646641867501, 37.188085964747835, 36.05350072043282, 36.89949253627232, 34.4193434715271, 36.651587758745464, 37.13333068575178, 38.80921881539481, 36.831737177712576, 38.90993990216936, 35.15346929005214, 36.46057483128139, 35.90447228295462, 37.0785927772522, 35.07201555797032, 37.04846886226109, 39.11785432270595, 37.57708086286272, 37.6412023135594, 37.89300850459507, 39.24779258455549, 38.6038578578404, 37.8718512398856, 37.377427850450786, 38.193132468632285, 36.89648744038173, 38.61828926631382, 38.96483761923653, 36.295829568590435, 32.77604934147426, 36.89925282342093, 43.68576683316912, 45.19666651317051, 45.33155536651611, 47.68846423285348, 49.46883937290737, 48.03718042373657, 41.613681997571675, 48.3093135697501, 48.70222725187029, 44.43420246669224, 44.42230715070452, 41.648040839603965, 37.641011238098145, 36.48610946110317, 37.375378131866455, 37.209955419812886, 38.04368366513933, 37.40735374178205, 36.52639511653355, 36.71238797051566, 37.91730982916695, 37.86279773712158, 38.63580567496163, 38.54797349657331, 37.38868045806885, 37.39634779521397, 36.04747315815517, 38.168153694697786, 39.04566253934588, 37.96890367780413, 37.169923373631065, 36.538714272635325, 35.505687373025076, 37.37974854878017, 35.901081562042236, 35.32652807235718, 38.43977962221418, 38.16692386354719, 39.13068069730486, 38.53005409240723, 37.92355973379952, 39.041879245213096, 41.21456357410976, 44.81176062992641, 47.5258138520377, 46.06980841500418, 49.99618680136544, 53.24863856179373, 50.89303248269217, 50.638825689043315, 50.672107560294016, 50.45170375279018, 45.63258607046944, 47.01253652572632, 46.18674659729004, 40.313948495047434, 39.88583523886544, 41.210912295750205, 41.348646436418804, 47.03184904370989, 50.17649255480085, 53.10650273731777, 54.12955897194998, 53.87442806788853, 55.02079398291451, 50.98427275248936, 52.59844698224749, 53.216329438345774, 57.61385474886213, 55.757501057216096, 8.799830113138471, 1.9055688679218292, 1.2983909802777427, 0.3671570084989071, 2.3691405185631345, 57.152956417628694, 63.741412026541575, 62.87684767586844, 55.657238551548545, 38.398809569222585, 35.274354049137656, 56.02977316720145, 69.67452049255371, 38.544124194553916, 0.24124153650232724, 0.13826527073979378, 0.07213954973433699, 0.1359435681785856, 0.1394801198371819, 0.2100016621074506, 0.09751276286052805, 0.10136274341493845, 0.1169987754630191], [0.034770919741796594, 0.026864580510716354, 0.04690555163792201, 0.02105693143260266, 0.025199849125263945, 0.012491149461961218, 0.05843563936650753, 0.019980126892083457, 0.033890754649681706, 0.044180843380412886, 0.014877803091491972, 0.014327935275754758, 10.354239412716456, 50.37783745356968, 40.85961832318987, 28.012025662830897, 17.69878670147487, 25.419437374387467, 41.31034101758684, 52.72303165708269, 46.38135174342564, 51.00585733141218, 6.869031250476837, 0.5692585823791367, 1.0661414712667465, 0.7451646604708263, 0.07079969413046326, 14.19873675278255, 52.470416000911165, 47.30932535443987, 44.816384656088694, 39.6454518863133, 42.97050884791783, 46.15611546380179, 46.832685879298616, 47.56148590360369, 49.81524528775896, 45.831068311418804, 43.877109800066265, 40.82550266810826, 39.0299665587289, 36.34362275259835, 36.295478684561594, 35.20120688847133, 34.25014788763863, 33.38549321038382, 33.365506717136924, 32.54573392868042, 33.46284403119768, 29.993448666163854, 33.427078178950715, 31.39924989427839, 33.371287618364605, 33.764778000967844, 34.19103956222534, 33.77835130691528, 33.33976364135742, 32.220822266169954, 32.99394832338606, 34.06667028154646, 33.829750605991904, 32.35106972285679, 33.377506256103516, 32.55671903065273, 33.13160603387015, 31.540069035121373, 33.26964936937605, 34.49721540723528, 34.34206213269915, 33.00852216993059, 35.88902991158621, 34.75945084435599, 35.59061173030308, 35.828431197575156, 35.44568272999355, 34.53984955378941, 33.79895966393607, 34.05090134484427, 35.61356857844761, 35.78044693810599, 34.28269672393799, 32.5434444972447, 33.959768772125244, 36.65930025918143, 38.85867261886597, 40.13555697032383, 42.90301752090454, 47.207131249564036, 45.10293531417847, 39.01978049959455, 45.553397451128276, 44.29136487415859, 42.24915729250227, 39.263266222817556, 39.651250158037456, 34.309242316654746, 32.9130608694894, 31.183018480028423, 33.78081791741507, 34.006745542798726, 33.31482655661446, 34.637767042432515, 33.748244762420654, 34.59499045780727, 35.393463543483186, 35.683818340301514, 35.04126630510603, 34.88029391424996, 34.36942761284964, 34.567843845912385, 34.03098085948399, 33.9362074307033, 33.708414213997976, 32.073992933545796, 34.0729375566755, 34.11492204666138, 32.85793733596802, 33.36989450454712, 34.26438127245222, 33.97533621106829, 33.23431083134243, 33.2080466406686, 33.30076687676566, 34.06326913833618, 33.94561876569475, 36.13107735770089, 40.007908139910015, 44.27980307170323, 46.92555897576468, 42.835814544132774, 42.392067841121126, 42.590504918779644, 43.94867624555315, 43.40060928889683, 44.4021851675851, 46.91050917761666, 46.26577540806362, 42.646872179848806, 39.87066732134138, 38.60587283543178, 37.21008743558611, 36.038645471845356, 36.68685334069388, 36.90225444521223, 41.41804504394531, 45.1591705594744, 45.386831760406494, 44.95949322836739, 42.40947307859148, 44.32262134552002, 52.01280069351196, 52.79457030977522, 51.09956768580845, 4.051448566573007, 0.5023763626813889, 0.1419287355882781, 0.11319300146507365, 2.973233623164041, 53.12087161200387, 53.382464340754915, 53.860635893685476, 39.642088958195274, 34.91165113449097, 30.784143243517192, 39.710049288613455, 51.53805807658604, 16.69453055518014, 0.21273374264793737, 0.035296516359916756, 0.023041624309761182, 0.051835162831204276, 0.04302316764369607, 0.021956539945676923, 0.04702359637511628, 0.06942036814455475, 0.020353061612695456, 0.06092061102390289, 0.01135486623804484, 0.03126612691474812, 0.038894919878137965, 0.07200823285217796, 0.03353781465973173, 0.049399469779538255, 0.0038905522835973117, 0.037244179884770086, 0.09661295757229839, 0.07343660334923438, 0.03131707471662334, 13.336611219814845, 57.22618348257882, 47.728989601135254, 32.56709963934762, 25.023933751242502, 37.28299488340105, 44.366763251168386, 58.24439682279314, 50.343273639678955, 56.25894560132708, 6.283312439918518, 0.43095026537775993, 2.001734107732773, 1.0001602917909622, 0.10695220955780574, 15.585785661424909, 54.83396734510149, 48.73871571677071, 46.61919205529349, 40.58155141557966, 44.351866313389365, 48.68580518450056, 48.0675961630685, 48.55700642721993, 49.678105218069895, 46.57980966567993, 45.61345420564924, 43.785331044878276, 40.29556703567505, 38.78129053115845, 38.769582816532676, 36.608654839651926, 36.888212135859895, 34.52378879274641, 34.397936071668354, 34.1827712059021, 34.80282844815935, 33.50051368985857, 33.88536051341465, 33.67379134041922, 35.01079498018537, 34.82289831978934, 37.16292306355068, 35.03517273494175, 35.21707657405308, 34.248376096997944, 34.31337996891567, 35.23695189612252, 34.81913239615304, 34.451426778520855, 34.574969223567415, 34.77516072137015, 34.95653649738857, 33.379778317042756, 35.31178746904646, 35.94560214451381, 35.722794260297505, 35.64577695301601, 35.40630381447928, 37.08200434276036, 37.29316009793963, 37.18975700650896, 36.2190728187561, 35.458644594464985, 35.988694872174946, 36.109628268650596, 36.34559256689889, 36.93418836593628, 35.265925884246826, 33.48662771497454, 36.670684882572715, 40.1123708316258, 39.82707779748099, 41.09918178830828, 44.79598127092634, 48.47468417031424, 48.26494584764753, 41.9687488419669, 47.801236970084055, 46.401122842516216, 44.08749083110264, 40.30390139988491, 40.84824759619576, 35.90107808794294, 34.69821637017386, 34.35800477436611, 36.27442911693028, 34.662815298352925, 34.79968786239624, 37.202097007206504, 36.376411301749094, 35.71262904575893, 36.32113490785871, 36.6917587688991, 36.32124260493687, 36.71322175434658, 35.91219867978777, 35.168022292000906, 35.818519592285156, 34.12525054386684, 36.70120137078421, 33.723043646131245, 35.71727739061628, 35.19529397147042, 35.23245988573347, 36.132849148341585, 35.301983560834614, 35.19825042997088, 35.56282935823713, 36.43118742534092, 35.68206739425659, 35.190412861960276, 35.31457369668143, 39.3900500025068, 42.56797538484846, 44.431343282972065, 48.0531439099993, 45.645408970969065, 45.18592807224819, 44.61857986450195, 46.80992358071463, 45.538768018995015, 47.043059962136404, 49.483996868133545, 48.34704576219831, 44.62496178490775, 43.01962913785662, 40.42881958825247, 38.93286548342024, 37.76891367776053, 38.70451641082764, 40.462007658822195, 44.13931744439261, 47.098621232169016, 49.21180118833269, 48.05336625235421, 45.15572772707258, 47.42915746143886, 53.76904126576015, 57.11632898875645, 52.130513599940706, 4.3004099045481, 0.7523364499211311, 0.6224000879696437, 0.2746045876826559, 2.971333073718207, 57.75244351795742, 58.60688781738281, 57.97759641919817, 47.15492248535156, 39.32032135554722, 35.80640888214111, 46.64464330673218, 58.73590891701834, 23.09559498514448, 0.16160045644002302, 0.05762883408793381, 0.022676080531839813, 0.04903156469975199, 0.009575083302999181, 0.008505644260107406, 0.03273255304832544, 0.03534849214234522, 0.019884500951905335, 0.1978007068059274, 0.09876704841320004, 0.13445620584700788, 0.11082055126982075, 0.11591584714395659, 0.06671768852642604, 0.15142220045839036, 0.1422819130654846, 0.1527738015034369, 0.18293004190283163, 0.15188376711947577, 0.11469653328614575, 14.676858799798147, 65.97608470916748, 54.28422587258475, 40.297835622514995, 28.07129553386143, 33.70520414624895, 51.515681403023855, 61.49908937726702, 55.319743701389854, 60.258933203560964, 9.139955724988665, 0.8385197882141385, 4.900522777012416, 2.8164568586008887, 0.20708337798714638, 17.74567835671561, 57.42775419780186, 50.863262925829204, 48.615680490221294, 43.72256449290684, 47.571685859135215, 49.81280299595424, 48.877217633383616, 50.38610233579363, 52.79213844026838, 49.98870011738369, 47.942281927381245, 45.46226487840925, 42.35360608782087, 40.4177302633013, 39.99104486192976, 40.154365743909565, 38.013945375170024, 35.57972737721035, 36.868798868996755, 36.34035015106201, 37.79067890984671, 34.466014521462576, 35.87582833426339, 34.89684452329363, 37.64244604110718, 37.73626756668091, 40.89220537458147, 37.68722718102591, 37.72554997035435, 36.22121981212071, 36.34854555130005, 37.19775438308716, 38.04361418315342, 35.26653732572283, 36.500235148838584, 36.08936732155936, 37.665253502982004, 34.33411686761038, 36.097427231924875, 37.91067082541329, 37.03667082105364, 36.217307976314, 38.576829365321565, 38.46020385197231, 39.05605704443795, 39.460796560559956, 39.20770842688424, 36.47863667351859, 36.52896247591291, 38.44084964479719, 39.68709938866751, 39.35016734259469, 38.64789554050991, 35.75972393580845, 38.46294491631644, 41.20181710379464, 41.73072440283639, 44.43511268070766, 46.45984901700701, 50.386474064418245, 48.42263868876866, 43.158794607434956, 49.45971638815743, 46.936710834503174, 46.01910046168736, 43.87491416931152, 44.00260121481759, 38.80316693442208, 36.74093811852591, 36.03267349515642, 39.139525754111155, 35.408169405800955, 37.11690167018345, 38.340514183044434, 36.13633714403425, 37.30943277903965, 38.62378181729998, 39.137208529881065, 37.57679598672049, 39.22323765073504, 37.91310269492013, 38.05946997233799, 38.50058330808367, 36.915945870535715, 37.880585125514436, 35.66679872785296, 37.45833614894322, 36.95941380092076, 36.957447460719514, 38.08870104381016, 38.223961625780376, 37.4878694670541, 37.696742738996235, 38.374060085841585, 38.314034598214285, 37.359289578029085, 36.997090407780235, 40.79385014942714, 43.71173225130354, 48.29766491481236, 49.98148093904768, 46.44989224842617, 46.18423482349941, 46.21423019681658, 48.258233887808665, 47.07717214311872, 48.93232379640852, 50.61173813683646, 50.429521628788535, 48.02164772578648, 45.1005277633667, 43.457768644605366, 40.29525089263916, 40.225897448403494, 40.7411584854126, 42.14459037780762, 44.47210489000593, 48.19896575382778, 51.214925152914866, 49.57055057798113, 46.39584221158709, 50.38949653080532, 57.11719751358032, 57.903483458927695, 53.4005400793893, 5.4309578112193515, 0.8212138882705143, 2.370125642844609, 0.4455513076058456, 3.6972580637250627, 61.687260491507395, 63.059203147888184, 62.84519168308803, 52.339671748025076, 47.80162606920515, 43.06386137008667, 52.431193419865195, 64.85992608751569, 31.53486830847604, 0.2964378089777061, 0.18535226264170238, 0.06885307894221374, 0.22416834692869866, 0.10294777407710042, 0.07804574245320899, 0.1984925546816417, 0.15556613595357963, 0.18607828154095582], [0.021682381264067123, 0.05902905895241669, 0.0712999983557633, 0.016733864388827766, 0.023097023301358734, 0.07511808097894702, 0.011863024506185735, 0.02490170083806983, 0.08207527015890394, 0.05692404654941388, 0.06537370742963892, 0.06740393848823649, 5.196442646639688, 49.00383465630667, 46.61951862062727, 34.25633525848389, 20.647372892924718, 31.27029480252947, 35.454715388161794, 51.59318161010742, 46.87403808321272, 52.57267958777291, 14.731395210538592, 0.29533893508570536, 0.6802582261817796, 0.10757870094052382, 0.06674168152468545, 4.801365903445652, 47.774337019239155, 48.131047112601145, 44.42964792251587, 38.23186867577689, 44.98782798222133, 44.35892220905849, 49.4637393951416, 44.91712311335972, 46.518036706107004, 42.814903940473286, 41.294228145054404, 37.4854792867388, 36.105803285326274, 33.005214827401296, 33.52185855593, 32.950271947043284, 33.20082746233259, 31.308898993900844, 32.72519895008632, 30.475400039127894, 31.323792457580566, 31.609769889286586, 34.03316259384155, 32.65109641211373, 32.63637317929949, 32.856537273951936, 33.903481415339876, 34.26715012959072, 34.25055088315691, 33.32460962023054, 33.21359477724348, 34.0743202481951, 34.14340271268572, 32.09264884676252, 34.526717458452495, 32.80802147729056, 32.9552572795323, 33.01903826849801, 34.2221987588065, 33.19216653278896, 35.12266445159912, 33.87165171759469, 33.706354073115754, 33.311717237745015, 35.46778494971139, 34.91876956394741, 35.00065061024257, 35.400905064174104, 35.38327748434884, 33.259143693106516, 35.148546491350444, 36.591263498578755, 33.40785598754883, 31.665852274213517, 33.571493012564524, 36.57312522615705, 39.22914361953735, 39.65635360990252, 43.215415477752686, 48.36246728897095, 46.063183307647705, 38.05245923995972, 47.67578377042498, 43.00730650765555, 41.529344763074604, 39.26468365533011, 37.481084551130024, 35.58513307571411, 30.8307135445731, 33.73468535287039, 35.27865150996617, 33.534208978925435, 34.47587054116385, 37.15457827704293, 35.91385235105242, 34.22244194575718, 36.201031821114675, 35.394467558179585, 36.50681856700352, 35.970771993909565, 34.493147236960276, 35.83930165427071, 34.976846081869944, 33.78066158294678, 34.05591794422695, 33.265077454703196, 32.466347285679404, 33.52675008773804, 34.149701254708425, 32.58703402110508, 33.87183584485735, 33.05960880007063, 34.471090180533274, 34.17882462910244, 33.47376659938267, 33.63163314546858, 33.90313400541033, 33.46325397491455, 39.31993573052542, 42.52181850160871, 45.10530464989798, 45.08843789781843, 46.30562680108206, 43.708511761256624, 43.41261230196272, 45.84672955104283, 42.394590037209646, 41.61438029153006, 45.640281200408936, 47.48888765062605, 45.475893769945415, 41.97279964174543, 41.42448949813843, 39.99510955810547, 38.649017674582346, 36.93398686817714, 34.80083431516375, 38.37985488346645, 40.080301421029226, 43.34550312587193, 39.947813170296804, 46.135222230638774, 51.04562187194824, 59.4777889251709, 40.81595931734358, 0.8484657002346856, 0.36615321093371933, 0.07651684020778962, 0.1821887559656586, 5.408575057983398, 55.38434457778931, 53.009075096675325, 50.321689060756135, 38.823271547045024, 27.33124463898795, 11.586308751787458, 40.37542963027954, 46.08118609019688, 15.503103835242134, 0.2108810842037201, 0.06489079405686685, 0.092203911659973, 0.022678586022396172, 0.04637455048837832, 0.05131620567824159, 0.021239864473630275, 0.01316437918493258, 0.02207952781048204, 0.07428357790091208, 0.023917738547814742, 0.05654832813888788, 0.0759204418531486, 0.00739907578099519, 0.06079125510794776, 0.04954537855727332, 0.04033082211390138, 0.103001500479877, 0.006583888898603618, 0.048739072001938305, 0.02379376341455749, 6.430217334202357, 54.02557223183768, 49.56212936128889, 39.03382975714547, 23.316665819713048, 35.93825789860317, 42.02391753877912, 57.631197452545166, 49.55628592627389, 55.564542634146555, 14.850775684629168, 0.24779534339904785, 0.5963546569858278, 2.534909337759018, 0.3920513998184885, 5.797343705381666, 52.567590032305034, 48.066338539123535, 48.17608533586775, 40.10249744142805, 45.643400941576274, 47.7113550731114, 51.52722583498274, 46.44787379673549, 50.77705315181187, 45.06228487832205, 44.889239992414204, 40.33397667748587, 37.984224455697195, 34.699293340955464, 35.86376626150948, 33.94959313528878, 34.74887221200125, 34.33253615243094, 34.78969635282244, 32.302724157060894, 32.99704374585833, 33.644546372549875, 35.31303814479283, 34.89601421356201, 35.460975715092246, 34.45448398590088, 35.53409160886492, 35.33111735752651, 35.6596177646092, 34.87629175186157, 35.02719272886004, 35.578028542654856, 35.52553142820086, 34.96116747174944, 35.87986176354544, 34.04313325881958, 34.4138856615339, 34.07429592950003, 35.544670241219656, 34.398439816066194, 35.94878441946847, 34.633066586085725, 35.545948709760395, 35.00828320639474, 36.23640162604195, 35.66482196535383, 36.692613397325786, 36.24280091694423, 36.264618260519846, 35.866416999271934, 36.70986577442714, 38.505905628204346, 34.468748637608115, 33.47147716794695, 34.42240762710571, 38.7934707232884, 40.945133277348106, 41.98359366825649, 44.99317809513637, 48.589854036058696, 47.92835078920637, 41.56350210734776, 48.94825948987688, 46.134767123631065, 43.833506379808696, 40.21754918779646, 40.67882966995239, 37.59798451832363, 33.8291391645159, 35.601325852530344, 37.90033885410854, 37.291259765625, 35.79137992858887, 36.94354064123971, 35.99561527797154, 36.30363934380667, 36.99474539075579, 37.54234334400722, 38.27066741670881, 36.91976043156215, 36.23822552817208, 36.532273292541504, 36.386229106358115, 34.46060882295881, 35.74936069761004, 35.850846086229595, 34.46447549547468, 35.053106035505024, 35.886271476745605, 34.69148356573922, 34.207051685878206, 35.003061635153635, 35.62935488564627, 35.692659923008506, 35.77406849179949, 34.84819671085903, 36.062672342572895, 36.062526430402485, 40.781784602573936, 43.8074506350926, 46.64525127410889, 46.257187434605186, 46.051916803632466, 45.24026298522949, 44.321787561689106, 46.89702272415161, 43.861014298030305, 43.255134854997905, 47.02686718532017, 50.56264911379133, 46.132710456848145, 43.558559213365825, 42.683701106480186, 40.950639724731445, 40.288736956460134, 39.21801955359322, 37.46078191484724, 40.79344367980957, 41.148826667240684, 44.838278429848806, 42.96771567208426, 47.799958501543315, 52.7985828944615, 59.09706933157784, 42.81928130558559, 1.1434522313731057, 0.6228972641485078, 0.5762624751244272, 0.3467943082962717, 5.783086436135428, 60.946777071271626, 56.911506516592844, 56.22538580213274, 42.75644179752895, 28.144262041364396, 17.149239778518677, 45.891927582877024, 55.00461162839617, 19.208295004708425, 0.1679611929825374, 0.037632003360028775, 0.04610877171424883, 0.027881617990455458, 0.005927396090035992, 0.08283796387591533, 0.038179991633764336, 0.08818117608981473, 0.029104802890547683, 0.12361173704266548, 0.17024226486682892, 0.13166890612670354, 0.1812802247170891, 0.08244088518300227, 0.2060015488948141, 0.16476650083703653, 0.20372344899390424, 0.14303088001906872, 0.130304860749415, 0.18125392469976628, 0.17008742317557335, 7.171932756900787, 62.76357814243862, 56.67079312460763, 46.59124640056065, 29.044736419405254, 43.0320976802281, 46.123441559927805, 61.092793464660645, 55.3977233341762, 59.367465427943635, 19.006048577172415, 0.5284499121563775, 3.491684534720012, 2.7103114000388553, 0.3817559065563338, 7.234605942453657, 54.14032867976597, 51.64027650015694, 49.587695258004324, 41.90836899621146, 48.7680093220302, 48.991480759211946, 52.564470291137695, 48.656421252659385, 50.63020644869123, 46.9560580934797, 47.0599684034075, 42.087107930864605, 40.0189905166626, 37.10311644417899, 37.353279386247905, 37.111457756587434, 37.735440731048584, 35.67518172945295, 36.54421724591936, 34.12305838721139, 35.22660602842058, 36.36547483716692, 37.75035156522478, 37.5727938243321, 37.12837662015642, 35.9822677884783, 37.14342294420515, 38.25436346871512, 37.593332699366975, 37.04118367603847, 36.80346495764596, 37.26537772587368, 38.09936652864729, 36.668791498456685, 38.051170349121094, 35.224052565438406, 34.78623614992414, 36.61392157418387, 36.885057653699604, 37.19556222643171, 37.17310912268502, 35.76235382897513, 36.20828921454293, 34.69599642072405, 38.426737853458945, 36.32493209838867, 39.13536378315517, 38.53486224583217, 37.61851297106062, 37.70312813350132, 38.85286392484392, 39.80158485685076, 35.568492140088765, 35.99981198992048, 36.88932384763445, 40.17982046944754, 43.14512055260794, 42.98215055465698, 47.03443029948643, 51.326454162597656, 50.32117141996111, 41.243471554347444, 51.58208533695766, 45.59798404148647, 44.95713778904506, 42.46632671356201, 41.53707810810634, 41.36695841380528, 35.98498453412737, 37.2487576348441, 40.74849925722395, 37.33963312421526, 37.97273908342634, 41.569203104291645, 38.59770175388881, 37.22389350618635, 39.93239164352417, 38.4406099319458, 40.42494944163731, 38.97733742850167, 38.163050242832725, 38.83758136204311, 39.218898500714985, 36.19698796953474, 37.51961926051548, 36.24131052834647, 34.84899227959769, 37.18283660071236, 38.556703908102854, 36.533569131578716, 36.04062570844378, 36.75810711724417, 38.22001852308001, 37.48035846437727, 38.818616253989084, 36.52566902978079, 39.04509973526001, 37.43714761734009, 43.537791047777446, 46.0358247756958, 48.21557542255947, 47.86151259286063, 48.07662187303816, 45.041989190237864, 44.733874797821045, 49.116669927324565, 45.81213794435774, 45.25012942722866, 48.294173445020405, 50.008703981127056, 48.08447333744594, 46.81005212238857, 45.565803459712434, 44.19184929983956, 42.857614517211914, 41.461710997990195, 39.34148556845528, 43.30856997626168, 44.279921191079275, 47.97626904078892, 44.95952449526106, 49.518657956804546, 54.73013693945748, 63.5646151133946, 44.981543336595806, 1.6359562895127704, 1.1318898860897337, 2.3446982758385793, 0.6334848531654903, 7.2984746524265836, 66.41692011696952, 61.21432440621512, 59.51846367972237, 52.22135434831892, 38.58176258632115, 20.330406495503016, 53.46380342755999, 62.837048394339426, 25.72843939917428, 0.3609779972050871, 0.10324742871203593, 0.2750091574021748, 0.16081977475966724, 0.15313788982374327, 0.20728916408760206, 0.09591832091765744, 0.1810071143720831, 0.07971744239330292], [0.033474636264145374, 0.06744232321424143, 0.04488603125459381, 0.04042842937633395, 0.05272433886836682, 0.02615566408660795, 0.07391887889908892, 0.05898656230419874, 0.05600320667560611, 0.02683118132076093, 0.03539899889645832, 0.030843545483159165, 2.5258673429489136, 43.596968855176655, 46.71270438602993, 34.79435164587838, 29.52039793559483, 37.5478115762983, 35.46727078301566, 49.61646774836949, 46.80133213315691, 52.15601348876953, 25.96372103691101, 0.03606619559494512, 0.793224210185664, 1.4307726195880344, 0.23496962019375392, 1.3898710714919227, 40.0370523588998, 50.82002081189837, 46.87907552719116, 42.48964834213257, 45.32198074885777, 45.27382278442383, 48.89840269088745, 49.81379311425345, 42.78826107297625, 41.44342681339809, 38.77699307032994, 35.88478456224714, 32.72064788000924, 31.638674395424978, 33.18666008540562, 31.435714040483745, 31.480616773877824, 30.87464005606515, 31.599965981074742, 30.665381159101212, 31.910915238516672, 32.43483025687081, 33.45611122676304, 32.45019619805472, 33.035706996917725, 33.18669830049787, 32.53256709235055, 34.15383195877075, 33.86682619367327, 33.09885222571236, 32.173737798418315, 35.60753754207066, 33.200719765254426, 33.479874065944124, 33.267262663160054, 34.014023780822754, 32.61949600492205, 33.980856554848806, 32.860490798950195, 33.592518261500764, 35.25257839475359, 34.070800985608784, 34.085284505571636, 36.10193313871111, 36.975387709481375, 34.08866133008684, 35.74465676716396, 34.351011412484304, 34.39616775512695, 34.72876065117972, 34.51881388255528, 34.7657459122794, 34.20066281727382, 32.189155851091655, 32.92001601627895, 37.53373105185372, 38.8785514150347, 38.57136460712978, 42.62779937471662, 47.069077491760254, 44.54393884113857, 38.8733298437936, 46.156268324170796, 44.149691104888916, 42.70833247048514, 40.99241924285889, 40.384472710745676, 33.88459621156965, 32.1021921975272, 33.048234598977224, 34.37424618857247, 35.07184532710484, 35.59185198375157, 35.010694231305806, 35.21259846006121, 34.653296266283306, 35.905684743608745, 35.21388040270124, 35.51454285212925, 33.965292590005056, 35.32340833118984, 35.340365409851074, 34.77857576097761, 33.50322348730904, 33.267425945826936, 33.72514547620501, 34.08795608792986, 34.28444072178432, 33.55122511727469, 32.8422726222447, 34.92320251464844, 32.37725053514753, 32.904789039066856, 31.702229567936488, 32.54414973940168, 33.204749720437185, 33.07253244944981, 33.54739318575178, 34.57295077187674, 38.953237601688926, 42.68666451317923, 45.143992219652446, 45.233714308057515, 47.405835832868306, 45.33982719693865, 48.07595484597342, 47.77540009362357, 46.34450544629778, 41.15278019223894, 43.363113335200715, 49.11358840124947, 48.41916111537388, 46.282843657902305, 48.00404099055699, 42.274629388536724, 41.780855655670166, 40.678068842206685, 40.23182773590088, 35.73282051086426, 37.99312162399292, 38.37417125701904, 48.36252287455967, 48.554744788578574, 59.433056422642295, 28.83043486731393, 0.14001240341791085, 0.37115705385804176, 0.20789247671408312, 0.28161225308265003, 7.393600702285767, 59.23882647923061, 49.556636810302734, 49.686036586761475, 33.83349221093314, 32.080517292022705, 29.507828644343785, 42.95288126809256, 44.51844590050833, 10.984287296022687, 0.19911956175097398, 0.02135882353676217, 0.06655393767037562, 0.03681410742657525, 0.06583999669445412, 0.06404589582234621, 0.011782277142629027, 0.04311599801959736, 0.10057078448257276, 0.041722809563257864, 0.026263235635789375, 0.07777736149728298, 0.011379994934291711, 0.07108024121927363, 0.05904512666165829, 0.020372399860726934, 0.05881282341267381, 0.004752069537062198, 0.011991969908454587, 0.03328446664714387, 0.027590752080348984, 2.589014960186822, 50.89412334987095, 52.7690669468471, 39.99912214279175, 25.451258386884415, 34.19678224836077, 41.867506640298025, 54.20793465205601, 52.35621540887015, 56.05311911446707, 27.44510129519871, 0.039091196310307295, 0.3296735669885363, 3.3520659123148238, 0.8086742354290826, 2.0251949174063544, 43.33774893624442, 50.36206504276821, 49.174277441842214, 43.89947952542986, 47.73908880778721, 45.82167434692383, 50.25420468194144, 50.198087556021555, 44.55816527775356, 43.46773930958339, 40.913234097617014, 38.23980699266706, 34.437912532261436, 33.47169256210327, 35.06347969600132, 32.75826890127999, 34.50540733337402, 32.105711460113525, 34.04837914875576, 32.515571798597065, 33.42917653492519, 33.23979296003069, 34.73575053896223, 33.347139154161724, 35.131200313568115, 34.32976382119315, 35.802827085767476, 34.973038469042095, 35.88196359361921, 34.83731583186558, 35.095611640385215, 36.63798666000366, 34.977627754211426, 34.83895560673305, 35.55228894097464, 34.94553402491978, 32.294500964028494, 33.75218786512102, 34.84673758915493, 35.40557425362723, 36.332745347704204, 34.522583280290874, 34.75739417757307, 37.02593238013131, 38.75535985401699, 36.7783784866333, 36.13378715515137, 34.65648896353585, 37.0845821244376, 35.42094366891043, 35.8588365146092, 35.908050605228965, 36.2415954044887, 32.88574750082833, 34.28049067088536, 38.903689997536794, 40.96060691561018, 41.355678013392854, 43.52859510694231, 47.810617038181846, 46.10655048915318, 41.8118029321943, 48.27083444595337, 47.52851322719029, 44.287355763571604, 41.40392630440848, 41.11117090497698, 35.77703537259783, 33.099289962223594, 34.39836685998099, 36.342160156794954, 35.81035198484148, 36.754834515707834, 36.617993218558176, 37.25923204421997, 35.06906952176775, 37.820267813546316, 36.58148043496268, 39.04373788833618, 35.41363068989345, 36.10982281821114, 36.79866375241961, 35.94650541033064, 35.93531881059919, 35.52415221078055, 35.78007173538208, 36.27250446592058, 35.45993348530361, 34.77076598576137, 35.1980037689209, 36.32011699676514, 34.19634451184954, 34.4490122795105, 34.36544976915632, 35.71550907407488, 34.12631014415196, 34.90994187763759, 35.31473003114973, 36.67257826668875, 40.39543696812221, 44.38369948523385, 48.128267833164756, 47.200672898973735, 48.097431727818076, 48.083059379032676, 49.317156723567415, 49.352137429373606, 47.31899724687849, 43.861108098711284, 44.69843898500715, 50.41908196040562, 49.111128738948274, 48.46786103929792, 49.67547532490322, 44.48172467095511, 44.18998718261719, 41.218982628413606, 41.119915212903706, 37.96867091315133, 40.294587339673726, 40.35436616625105, 51.6090304510934, 52.123197146824424, 60.72715146200997, 30.808666910443986, 0.15059423845793518, 0.5130132947649274, 0.6527613273688725, 0.4339567454797881, 8.250423891203743, 63.9634347643171, 54.81084026609148, 53.41472830091204, 41.75606448309762, 34.776428767613, 26.84839173725673, 47.524094172886436, 51.60593155452183, 15.21573155266898, 0.18213843580867561, 0.16449605034930365, 0.051454928770129166, 0.11726857455713408, 0.059856525622308254, 0.05707181112042495, 0.08202030882239342, 0.012327824386634996, 0.023542829290298477, 0.1371170673519373, 0.1266729070671967, 0.16810967001531804, 0.11446446073906762, 0.30243632995656555, 0.11786272696086339, 0.15905985848179885, 0.19913804504488195, 0.0856208802599992, 0.09250594116747379, 0.19701528895114148, 0.12365177060876574, 3.231379176889147, 56.443927492414204, 59.285573959350586, 46.2674742426191, 35.52995048250471, 46.83059794562203, 47.099545342581614, 57.39655678612845, 55.84649705886841, 60.769208908081055, 31.001594066619873, 0.11364500078239612, 2.6185241767338345, 7.196536328111376, 1.5051265954971313, 2.5425892685140883, 46.21980612618582, 53.50719492776053, 51.4126569884164, 47.13425506864275, 50.64471081324986, 48.726705755506245, 52.76751402446202, 52.48786987577166, 46.30174970626831, 46.3729305267334, 43.42150947025844, 40.768391949789866, 36.803489276341026, 34.35779980250767, 37.6890024457659, 35.473263604300364, 37.68125867843628, 33.39814240591866, 37.08095863887242, 35.59636831283569, 36.00332430430821, 36.57164178575788, 36.13978345053536, 34.37470824377877, 37.92091247013637, 37.64342226300921, 36.31447853360857, 38.632724148886545, 39.143152713775635, 37.17685072762625, 37.71501650129046, 40.50545127051217, 37.32020596095494, 36.773869105747764, 36.629534176417756, 37.494564056396484, 35.51532799857003, 36.0962564604623, 37.71970306124006, 37.23000792094639, 39.00991753169468, 36.86308397565569, 37.97773831231253, 38.80853789193289, 40.137523310525076, 38.33545242037092, 38.92762654168265, 36.22142825807844, 38.18558325086321, 37.6929212297712, 37.334088461739675, 38.138801029750276, 36.93799597876412, 36.14184359141758, 36.34754501070295, 40.039129870278494, 44.056769371032715, 44.52189915520804, 45.798269339970176, 50.82628113882882, 46.23443555831909, 41.30655772345406, 49.848777294158936, 48.0225509916033, 46.225930963243755, 43.13142217908587, 43.60245098386492, 38.57061767578125, 36.93738453728812, 37.88316290719168, 39.07702323368618, 37.57291194370815, 38.161045687539236, 38.164714336395264, 39.13862943649292, 36.67975575583321, 40.44165291104998, 39.7323807988848, 41.40817165374756, 35.652075495038716, 39.513960702078684, 39.32305894579206, 38.375338554382324, 37.60088539123535, 37.17977244513375, 38.39543274470738, 38.228995595659526, 37.385522501809255, 36.21510192326137, 37.56548431941441, 38.35940286091396, 35.52942589351109, 37.33113200323922, 36.454856463841026, 37.04278523581368, 36.99024990626744, 37.052658626011436, 36.60805034637451, 39.62100117547171, 43.13404164995466, 47.338236808776855, 50.19173342841012, 48.55958768299648, 51.4138103893825, 49.22092417308262, 50.89302553449358, 51.3168934413365, 49.65275818961007, 46.35322543552944, 47.73487819944109, 50.42948688779558, 50.37916803359985, 49.86034951891218, 52.40434558050973, 47.90369858060564, 46.49680648531233, 44.01836667742048, 43.40351711000715, 39.740294797079905, 42.21598311832973, 42.39464214869908, 54.54996320179531, 53.96731506075178, 62.90922628130232, 32.42094080788748, 0.40678212365933825, 0.7514378524252346, 1.0825863374131066, 0.6950733597789491, 8.612356424331665, 70.81008543287004, 60.20628670283726, 60.06426552363804, 47.32263115474156, 44.33741058622088, 42.33972358703613, 55.44357797077724, 60.32253006526402, 20.6118780204228, 0.2904385280396257, 0.30590006123696056, 0.26985267124005724, 0.1840093739862953, 0.14010111508624895, 0.1349979889179979, 0.16769237097884926, 0.13061569764145783, 0.1495455897280148], [0.01982573981929038, 0.01749064976216427, 0.047962563311947246, 0.03633528222729053, 0.02753435224959893, 0.03847671499741929, 0.05761922603206975, 0.08199204783886671, 0.03507691189380629, 0.037871984232749255, 0.03972034415762339, 0.014178462492834245, 0.39687605521508623, 27.429024900708878, 50.53552334649222, 39.47262239456177, 30.98384141921997, 25.961563621248516, 33.24661609104702, 48.229746273585725, 48.18112277984619, 46.20305054528372, 37.52159949711391, 0.32961068036300795, 0.28015055294547764, 3.630440277712686, 0.3309835466955389, 0.26542978999870165, 30.878600529262, 54.489197731018066, 47.31771183013916, 45.12542315891811, 44.915170669555664, 47.98139681134905, 44.16648490088326, 48.074999468667166, 44.22634710584368, 41.247101988111226, 36.93842329297747, 34.9019410269601, 31.656715393066406, 31.424725464412145, 31.33511802128383, 32.56978164400373, 30.799981662205287, 30.65287787573678, 31.882007258278982, 30.059904711587087, 32.60804189954485, 31.457135336739675, 32.42409529004778, 32.09153018678938, 31.74141045979091, 32.40135383605957, 33.23128489085606, 32.97896453312465, 35.14732360839844, 32.90673106057303, 33.36403717313494, 33.83429820196969, 35.1482755116054, 32.85959448133196, 33.61663893290928, 33.942200251988, 33.48288263593401, 33.45215422766549, 34.43177727290562, 33.271806785038535, 35.95117112568447, 35.3557938848223, 33.98436539513724, 35.50498907906668, 35.24771465573992, 36.33856446402413, 36.44124494280134, 34.45732579912458, 34.49042354311262, 33.64962897981916, 34.418422835213796, 35.26580776487078, 33.55945873260498, 31.541719232286724, 31.50663082940238, 36.53854751586914, 39.60439498083932, 39.60038587025234, 42.1294606753758, 48.2987106187003, 44.568740436008994, 36.47216442653111, 46.920907156808035, 44.172088623046875, 42.02440391268049, 40.28901835850307, 39.05505650384085, 33.70990807669503, 31.747670786721365, 33.31579235621861, 34.97173220770699, 35.63545192990984, 34.80280065536499, 35.80316059929984, 34.66459403719221, 34.842096192496165, 36.228379930768696, 34.90151718684605, 33.29796327863421, 36.09604454040527, 35.20523336955479, 33.80655057089669, 33.50672885349819, 34.46713318143572, 33.567240715026855, 34.31464801515852, 34.840133326394216, 33.496376037597656, 33.57122203281948, 33.226622649601524, 33.606890610286165, 32.21192509787423, 33.72250516074044, 34.76104545593262, 34.147394452776226, 33.187848227364675, 34.08870996747698, 33.07894911084856, 31.35930470057896, 34.597926071711946, 37.47511952263968, 40.004725864955354, 41.657851696014404, 42.70383698599679, 44.4272403717041, 44.00063834871565, 46.68619353430611, 47.41026183537075, 48.6888484954834, 44.07202761513846, 41.197887897491455, 46.81023277555193, 43.19577292033604, 42.75771679197039, 42.37077856063843, 46.75083262579781, 45.45845031738281, 43.67689050946917, 39.21115125928606, 39.2383256639753, 36.80032784598214, 51.18155990328108, 49.53702204568045, 58.145555223737446, 17.241779361452373, 0.19821537312652382, 0.5713986275451524, 0.43034237942525316, 0.44287570832031115, 8.566896966525487, 57.930178437914165, 49.5235390663147, 49.12228059768677, 35.22239542007446, 20.80563201223101, 22.717498336519512, 42.04611355917794, 46.57033232280186, 7.099169049944196, 0.30984538953219143, 0.08435577207377978, 0.01484995601432664, 0.07146161182650498, 0.07340808452240058, 0.07220622258526938, 0.01871357172993677, 0.011399479915520974, 0.047058062561388524, 0.0074282468496156585, 0.03603392107678311, 0.056728787919772525, 0.02076465925867004, 0.050174224456506114, 0.02270173424455736, 0.015406500614647354, 0.03405840029673917, 0.03689838147589138, 0.07263774371572904, 0.01774015896288412, 0.06729653996548482, 0.9592313851628984, 33.68397739955357, 55.2849679674421, 45.82365805762154, 31.72998414720808, 35.45303392410278, 42.268226623535156, 51.65578835351126, 53.90294347490583, 50.06598493031093, 41.11728184563773, 0.3429802358150482, 0.31280906764524324, 2.700048042195184, 1.1230012944766452, 0.7148433732134956, 35.56866584505354, 54.956210477011545, 47.47030816759382, 47.68009165355137, 47.83101347514561, 50.03176505225045, 46.58722686767578, 49.134342670440674, 46.676024845668245, 43.08334411893572, 38.853798457554404, 34.76873016357422, 33.58930819375174, 33.78815868922642, 33.74843236378261, 34.1317366872515, 32.72003296443394, 33.98848220280239, 32.69222974777222, 31.75450086593628, 33.67907197134835, 33.82213538033621, 34.71552433286394, 34.474640710013254, 34.7008775302342, 34.936782768794465, 34.79734631947109, 34.478173868996755, 36.13474600655692, 34.69597210202898, 34.87244592394148, 34.378501960209434, 36.930238315037315, 34.859640393938335, 34.495530469076975, 34.560023648398264, 35.44828135626656, 35.2008455821446, 35.959432533809114, 33.842014176504954, 37.802911213466096, 37.09792961393084, 35.71575573512486, 36.76787281036377, 37.75104638508388, 36.280703340257915, 37.041135038648335, 36.526304789951865, 36.299654551914756, 36.00903572354998, 36.63243852342878, 35.89446687698364, 35.57355390276228, 32.212001528058735, 33.2686071395874, 38.65597629547119, 41.36966821125576, 40.88635151726859, 43.31189816338675, 48.09898117610386, 47.338921206338064, 39.581163678850444, 48.27436065673828, 45.19385249274117, 43.38969019481114, 41.343272004808696, 40.28165326799665, 35.66739279883248, 34.031911918095176, 35.43439538138253, 36.1383764403207, 37.731848512377056, 35.97869988850185, 36.928327560424805, 36.820922306605745, 36.154253074101035, 36.822937284197124, 35.66552720751081, 37.36624819891793, 37.11501523426601, 36.81812913077218, 35.805835655757356, 35.231580938611714, 36.20660080228533, 36.21267352785383, 36.05315678460257, 35.95158454350063, 35.38634163992745, 35.58725922448294, 34.3185772214617, 35.016103403908865, 33.789499691554475, 35.695077896118164, 36.79274736131941, 35.85912486485073, 34.13699647358486, 35.80414029530117, 35.03985582079206, 34.57600450515747, 35.901182310921804, 40.709606715611045, 41.805997712271555, 44.649006026131765, 44.42638921737671, 46.267137254987446, 45.96755872453962, 49.36452259336199, 50.32268612725394, 50.713035924094065, 45.26701007570539, 44.03574412209647, 48.44828796386719, 45.472979000636506, 45.1352652822222, 45.37947014399937, 49.29036794389997, 47.848290170942036, 46.98275307246617, 41.06085205078125, 40.85453571592058, 39.00386912482125, 53.62768711362566, 51.15444803237915, 58.3180581501552, 19.241038390568324, 0.13313376823706286, 2.449120146887643, 0.3734574504196644, 0.6811298994081361, 9.34599847452981, 60.947728974478586, 55.29002973011562, 55.7987733568464, 40.23121282032558, 27.551208972930908, 30.382738862718853, 47.44686841964722, 53.63331168038504, 8.478088566235133, 0.3815930852932589, 0.14093854943556444, 0.08379997046930449, 0.05228351841547659, 0.058892279863357544, 0.05543015331828168, 0.023589794091614227, 0.07302207273564168, 0.03688640194013715, 0.08409176766872406, 0.123549026836242, 0.09501120780727693, 0.09079718643001147, 0.18910445272922516, 0.07622467659945999, 0.1553168828998293, 0.16893662778394564, 0.1315099796546357, 0.1814649762319667, 0.10560833702662162, 0.1919129498835121, 1.2846838129418237, 37.86444098608834, 62.4451630456107, 53.261951310294016, 39.6373815536499, 36.36466189793178, 44.75555317742484, 59.10392720358712, 58.10237564359392, 55.05896738597325, 44.93394817624773, 0.6447698676160404, 1.5800204681498664, 10.099607041903905, 2.3780754676886966, 0.8518354137028966, 37.73553453172956, 57.54579019546509, 51.29363782065255, 50.05920001438686, 49.51293958936419, 51.41069064821516, 48.8707731791905, 50.92726278305054, 48.90042461667742, 44.861551421029226, 42.360595975603374, 38.217187132154194, 35.73914337158203, 35.589656352996826, 36.056762899671284, 37.464155265263145, 34.44539226804461, 35.97215815952846, 35.493750367845806, 33.788103103637695, 34.9110084261213, 34.85917139053345, 36.92953307288033, 34.64178657531738, 35.61883531297956, 36.68064512525286, 35.49215228216988, 37.42411627088274, 37.9548613684518, 36.87171711240496, 36.921139648982454, 37.159462860652376, 38.59532894407, 36.73071731839861, 35.955583231789724, 35.839065415518625, 36.853172370365684, 36.25955649784633, 38.49059527260916, 34.84571967806135, 39.84905842372349, 38.375553948538645, 38.06392724173409, 38.69110986164638, 39.79107918058123, 40.011621952056885, 39.39707810538155, 37.05936016355242, 38.692287581307546, 38.76630326679775, 37.60621465955462, 38.289799281529014, 36.80047723225185, 34.71167850494385, 35.2855441229684, 41.36600998469761, 43.449184145246235, 43.67942312785557, 44.04429735456194, 49.39899608067104, 47.1985502243042, 39.8900910105024, 51.17460823059082, 45.18644223894392, 45.75414480481829, 44.38268157414028, 42.784752232687815, 38.12658609662737, 35.160768372671946, 37.75300577708653, 38.29154675347464, 39.47883408410208, 38.35555355889456, 39.877035345349995, 38.978390080588206, 38.254961013793945, 40.9382232938494, 37.3853349004473, 37.234718799591064, 41.03361511230469, 38.82554708208357, 37.31427567345755, 37.43254096167428, 37.33427953720093, 37.292197772434776, 37.77617801938738, 38.655548981257844, 36.39789513179234, 37.08369970321655, 36.429252352033345, 36.60226944514683, 36.00954989024571, 37.60080548695156, 38.77194520405361, 39.21974270684378, 35.78612014225551, 39.22556529726301, 37.555079392024446, 33.56765413284302, 38.4460642678397, 42.54544932501656, 44.34536974770682, 46.97232035228184, 46.80205474581037, 49.527711459568565, 48.73280279976981, 50.986207825796946, 51.390561716897146, 50.80220563071114, 48.482038838522776, 46.60743222917829, 49.418336391448975, 45.307959284101216, 46.031669752938406, 47.35750763756888, 51.41506106512887, 49.75058535167149, 48.736884866442, 43.93720824377877, 43.858408723558696, 41.89076573508126, 55.9600236756461, 54.08629601342337, 59.29595456804548, 21.255989926201956, 0.22372866980731487, 2.5764226530279433, 1.9463884489876884, 0.9890573961394173, 11.197857550212316, 67.05346543448312, 58.93077114650181, 58.689752033778596, 47.45442458561489, 31.689219066074916, 33.58982236044747, 54.28263473510742, 62.52875682285854, 12.370238389287676, 0.4657888859510422, 0.294851936932121, 0.3356599286198616, 0.1688596683421305, 0.16167585525129521, 0.1590294601129634, 0.10442993204508509, 0.2083506914121764, 0.15960279506232056], [0.0182905204128474, 0.019896611105650663, 0.10893841726439339, 0.06074782208140407, 0.011404954844952693, 0.027414468682504127, 0.02981070661917329, 0.04317277104460767, 0.04564393790704863, 0.07295095548033714, 0.015307593957654067, 0.05707303248345852, 0.047842309943267276, 16.746951239449636, 49.23745741162981, 41.832202843257356, 26.835799864360265, 20.55275058746338, 34.3510913167681, 46.98110982349941, 51.85426017216274, 45.235677174159456, 49.7158374105181, 3.2764514897550856, 0.4272802865930966, 1.3086974386657988, 0.617297993174621, 0.31148133746215273, 18.814026423863, 53.421242237091064, 48.62949350902012, 49.88231972285679, 47.707894870213096, 48.49986444200788, 46.58372844968523, 46.57045044217791, 44.0607020514352, 38.688608510153635, 36.75344835008894, 31.817003386361257, 30.632123606545584, 33.16386999402727, 30.758104869297572, 31.775967325483048, 31.13393293108259, 31.752836772373744, 31.428154400416783, 32.921794755118235, 33.34166744777134, 33.065917764391216, 32.15118741989136, 32.86564288820539, 35.175609724862234, 36.05445957183838, 35.987218379974365, 36.79554748535156, 34.723559924534385, 34.753360748291016, 34.071530546460835, 33.91702345439366, 33.01646743501936, 33.081342765263145, 33.42932939529419, 32.760082381112234, 32.58392470223563, 33.720656939915244, 32.918595109667095, 33.90256772722517, 34.640879835401265, 34.83974075317383, 34.668491976601736, 34.817013195582796, 34.78816427503313, 35.58852727072579, 32.73883478982108, 34.231773376464844, 33.984132630484446, 35.69814205169678, 35.098203318459646, 35.8966520854405, 32.66871356964111, 30.711152417319163, 31.793393407549175, 35.70075804846627, 38.34757007871355, 42.06076383590698, 40.972523076193674, 48.83550064904349, 44.205891609191895, 40.16998529434204, 47.86417375292097, 45.12967545645577, 40.81638315745762, 39.803957666669575, 38.394341877528596, 35.10670443943569, 31.709379264286586, 33.2220333644322, 34.603884152003694, 34.62472527367728, 35.712552615574424, 33.577169690813335, 34.267421109335764, 36.06631319863455, 35.84347057342529, 35.18106058665684, 34.617683274405344, 35.78289270401001, 33.71706819534302, 35.34176547186715, 36.222890853881836, 34.640845094408306, 33.796764033181326, 33.050207887377056, 34.50412539073399, 34.273980208805625, 35.136036259787424, 35.42768342154366, 32.01462752478463, 33.44775949205671, 35.08644001824515, 34.74669395174299, 34.47933421816145, 33.79606921332223, 34.49718761444092, 32.212154388427734, 31.615265914372035, 30.781666210719518, 33.294881752559114, 34.66985729762486, 36.238882132938926, 39.25395563670567, 39.132852009364534, 41.9950338772365, 43.345527444567, 43.98923635482788, 44.47832005364554, 48.27188014984131, 47.36328159059797, 44.43053381783621, 44.318483693259104, 47.314835275922505, 46.351481437683105, 49.26341240746634, 49.301498958042686, 47.20709998267037, 43.28243432726179, 39.62145628247942, 38.264170851026265, 49.52255589621407, 51.49286004475185, 56.34494692938668, 9.923812406403677, 0.053524158628923554, 1.3373965386833464, 0.14004206896892615, 0.3095957429281303, 9.652692828859601, 58.310838971819194, 41.16680860519409, 49.68198578698294, 36.73276008878435, 28.553945200783865, 30.56538268498012, 40.52972132819039, 42.26920631953648, 3.9796002847807745, 0.20161000240061963, 0.05980392558766263, 0.0792231499882681, 0.035851133920784505, 0.035883333800094466, 0.06529919749924115, 0.08712696337274142, 0.04996615508571267, 0.025742349747036184, 0.054332008851425986, 0.026261688575946858, 0.12422429131610052, 0.030358481154377972, 0.03074903573308672, 0.02341319856766079, 0.022357481199183633, 0.08747908233531884, 0.05238964129239321, 0.0917158414210592, 0.007822010050793844, 0.05736803915351629, 0.04958695239786591, 22.347327845437185, 56.6515257699149, 47.73006657191685, 32.031911168779644, 24.67164271218436, 40.48276192801339, 50.944720132010325, 55.962608405521934, 49.98241547175816, 51.330122811453684, 3.2970796057156155, 0.19849977429424012, 1.1837933638266154, 1.9353468929018294, 0.5707302434103829, 21.00004608290536, 55.782917567661826, 50.49359791619437, 50.271755831582205, 48.707129205976216, 50.55189330237252, 48.329536301749094, 47.370417390550884, 46.16265719277518, 42.585147857666016, 38.465456690107075, 34.3350270816258, 33.350338799612864, 33.931204727717805, 32.53110449654715, 33.09385299682617, 33.237284660339355, 34.36576591219221, 32.4704258782523, 33.57343850816999, 35.335109097617014, 34.93656390053885, 33.61023269380842, 34.08873428617205, 35.80071135929653, 37.10790375300816, 36.56722967965262, 36.96101188659668, 35.52057041440691, 36.15823439189366, 35.81147064481463, 35.998175689152305, 34.84146043232509, 33.67858559744698, 34.954524993896484, 35.2435040473938, 34.35823059082031, 34.95171792166573, 34.49475921903338, 35.38147095271519, 36.881541865212576, 36.75757558005196, 35.3584098815918, 36.60024751935686, 37.38777024405343, 36.835596902029856, 35.04407685143607, 36.73415320260184, 35.71106570107596, 37.01535374777657, 37.20205531801496, 37.497051511492046, 34.20163556507656, 32.50964151109968, 34.87970331736973, 37.97537592479161, 40.74121059690203, 43.37837505340576, 43.81606987544468, 49.46157155718122, 46.70814984185355, 40.786846365247456, 49.80707768031529, 45.86833150046212, 44.407316412244526, 41.131772313799175, 40.52087279728481, 35.8587600844247, 34.498195103236604, 35.78491462979998, 36.18353278296334, 37.261688232421875, 37.649293490818565, 36.10143286841256, 35.10359512056623, 36.298480306352886, 37.18640102658953, 36.61158003125872, 36.41273648398263, 36.8420170375279, 35.659061908721924, 37.40758998053414, 36.6566356250218, 35.446276800973074, 35.26100655964443, 33.14657245363508, 35.267277308872764, 35.141567025865825, 35.23506546020508, 35.95450973510742, 34.701686995370046, 34.584978103637695, 36.80149514334542, 35.965797083718435, 36.12229483468192, 35.71132278442383, 36.10751254217965, 34.07614762442452, 34.41628279004778, 33.417670318058555, 35.28672184262957, 36.61801058905465, 38.70414815630232, 41.174990109034944, 42.17167445591518, 43.5699577331543, 46.33788728713989, 46.66474791935512, 46.97725009918213, 48.7083659853254, 48.21512726375035, 45.66462421417236, 45.69158322470528, 48.48399823052542, 47.24554783957345, 50.98920249938965, 50.331114292144775, 49.1199494770595, 45.09780754361834, 41.977423667907715, 39.10195337023054, 52.67912599018642, 53.13913842609951, 57.943831648145405, 11.459289601870946, 0.033656045994056125, 6.458118694169181, 1.7117650445018495, 0.4838610962033272, 10.829789757728577, 63.04996204376221, 47.69309868131365, 53.498144899095806, 44.69498225620815, 30.107750007084437, 31.793032101222447, 49.2300124168396, 50.63548013142177, 6.132049722330911, 0.3065654326762472, 0.06670718480433736, 0.0749053331092, 0.06065974145063332, 0.03599820299340146, 0.052666453045925925, 0.03336255245708993, 0.09153176165585007, 0.028338205900841525, 0.12844676045434816, 0.16554122497992857, 0.2441655338874885, 0.14158631967646734, 0.0985438171774149, 0.06491601520351001, 0.0647861436009407, 0.14028419740498066, 0.19772057182022504, 0.18793435980166706, 0.09812942905617611, 0.18765743608985627, 0.15722849246646675, 25.32963364464896, 65.55330766950334, 52.98405115944998, 38.24321508407593, 31.849479266575404, 45.3394832611084, 56.51459067208426, 61.318450110299246, 54.06585441316877, 57.190501008714946, 4.463114133902958, 0.9483693965843746, 4.865529477596283, 2.7172367998531888, 0.6464434063860348, 22.826423508780344, 57.00670378548758, 53.64976501464844, 53.555081912449424, 51.18260213306972, 51.13369723728725, 50.720289843423025, 51.03076662336077, 49.37955502101353, 44.229362624032156, 40.992752756391255, 36.59887177603585, 35.23582976205008, 38.109198229653494, 34.12345443453108, 35.41186237335205, 34.95982646942139, 35.68353346415928, 34.064856801714214, 34.80866493497576, 37.494102001190186, 36.42904043197632, 35.64283091681344, 36.111035278865266, 39.264242444719585, 40.85793685913086, 39.24602426801409, 40.95852940423148, 37.367471081869944, 38.76289864948818, 38.06556354250227, 36.889042445591514, 36.364800861903596, 37.004757744925364, 37.146316868918284, 36.19025863919939, 36.378700733184814, 36.43319545473371, 35.524183477674214, 37.88394110543387, 38.64599173409598, 39.03562934058053, 38.0553948538644, 38.059890338352744, 38.38451712472098, 38.23550258363996, 36.03846134458269, 38.07380410603115, 38.265782833099365, 39.79061017717634, 39.2938209261213, 39.419864722660606, 36.68885442188808, 34.60008348737444, 36.16066626140049, 39.58088575090681, 42.89169890539986, 47.24709728785923, 46.01879474094936, 52.087705748421804, 46.130924769810264, 41.476691314152305, 50.52476058687483, 48.07631615230015, 45.91357469558716, 43.488868781498496, 42.852358204977854, 39.043418271201, 35.518430369240896, 36.75385134560721, 37.30594825744629, 37.82995012828282, 39.70705461502075, 36.43851082665579, 36.681652614048545, 38.580227034432546, 39.82398237500872, 38.60422958646502, 38.28231259754726, 38.84062467302595, 37.71762554986136, 40.09320075171334, 39.56150375093733, 36.68817349842617, 36.86203132356916, 35.59878976004464, 38.34918900898525, 36.78895017078945, 37.92033576965332, 38.22213772365025, 35.5650041443961, 36.49283879143851, 38.64862510136196, 38.49290207454136, 38.69643912996565, 37.5728702545166, 37.564296177455354, 36.01523004259382, 35.95688601902553, 34.27506412778582, 37.49688128062657, 39.000349862234934, 40.50271715436663, 42.88159622464861, 43.64591544015067, 46.41362959997994, 48.4630355153765, 48.7269663129534, 48.55047164644514, 52.002889088221956, 50.78069053377424, 50.02948604311262, 48.092595781598774, 49.92785474232265, 48.91436617715018, 51.84884057726179, 53.260784012930735, 51.19650895254952, 47.185279164995464, 44.750039781842915, 40.98230266571045, 56.21618638719831, 54.21686656134469, 60.762219020298545, 13.059482319014412, 0.09029072789209229, 6.670269778796604, 2.826286171163831, 0.675268822482654, 11.926877311297826, 68.11301013401577, 51.97204950877598, 62.75917993273054, 48.628579820905415, 40.46373776027134, 42.02252789906093, 53.44176026753017, 59.230578967503135, 8.404595732688904, 0.5166179441979953, 0.15231166487293585, 0.1659557691642216, 0.2607052320880549, 0.1212862211146525, 0.16357096284627914, 0.12512857493545326, 0.17911518232098647, 0.05646885811750378], [0.03925232123583555, 0.04238671875957932, 0.03367363362173949, 0.020558672990383844, 0.03627896382074271, 0.02628358150832355, 0.01888123094769461, 0.034764785785228014, 0.0476054910437337, 0.04851096549204417, 0.05268704319106681, 0.026486281970781938, 0.06701834739318915, 11.200893912996564, 52.83295215879168, 44.148051330021445, 32.047211102076936, 26.60652494430542, 33.04907880510603, 38.82183674403599, 53.14577395575387, 41.69185617991856, 52.43962505885533, 9.484136479241506, 0.28495924919843674, 0.016422002908906767, 0.8008030120815549, 0.5005739022578511, 9.640829648290362, 46.24911362784249, 48.83948196683611, 49.859032835279194, 46.350949900490896, 47.55577448436192, 46.88596814019339, 46.40184892926897, 43.06607437133789, 39.65535306930542, 35.34361021859305, 32.490290778023855, 31.794810840061732, 33.044875144958496, 30.910982608795166, 30.063559464045934, 30.569888591766357, 32.48061541148594, 33.040869508470806, 32.434243134089876, 32.179414476667134, 35.076577050345286, 37.851559025900706, 40.655653953552246, 41.34686074938093, 44.074879850660054, 42.66503129686628, 44.11756263460432, 41.78571244648525, 39.61257301058088, 35.650084836142405, 34.59236751283918, 33.71398319516863, 32.9985271862575, 34.558154582977295, 34.131469181605745, 33.818939208984375, 32.92446633747646, 34.2371860231672, 34.40357106072562, 34.54711389541626, 34.993559973580496, 34.82378421510969, 35.29443781716483, 34.90252120154244, 35.98801742281233, 33.78918354851859, 34.22265386581421, 35.819864068712505, 34.79511594772339, 34.37451369421822, 36.9569993019104, 31.75515399660383, 31.56291123798915, 32.540171895708355, 36.1589743750436, 38.95429720197405, 39.17877265385219, 42.05651501246861, 48.49952050617763, 44.07621043069022, 41.055015563964844, 46.22255761282784, 43.69706807817732, 40.95919990539551, 39.78043801443917, 38.662726470402305, 33.91805526188442, 30.792303902762278, 31.381750856127056, 33.69965948377337, 35.106221539633616, 34.73798091070992, 35.15060315813337, 35.08461959021432, 36.30566821779524, 35.897246156420024, 35.28319215774536, 35.096435001918245, 35.90830768857683, 33.88475602013724, 34.57114424024309, 35.2813925743103, 34.766308716365266, 33.97361305781773, 32.754200731004985, 33.73435531343733, 33.85282904761178, 33.47227273668562, 33.8473608153207, 34.17964799063546, 34.68769679750715, 33.22082437787737, 33.36205346243722, 32.93777213777815, 32.50128977639334, 33.48251438140869, 34.61684601647513, 35.25861985342843, 32.50389187676566, 32.420701095036094, 33.049315043858115, 32.458270004817415, 34.41343750272478, 36.236241817474365, 36.29576703480312, 39.903059823172434, 40.65273571014404, 42.097999232155935, 42.77381924220494, 45.09012631007603, 48.971834727696006, 49.86922236851284, 48.29869672230312, 49.90405021395002, 49.011383874075754, 46.99578441892351, 49.78310292107718, 47.15676375797817, 42.614156586783274, 39.62592397417341, 49.359870774405344, 51.361799648829866, 47.60586404800415, 4.147449220929827, 0.2015386883701597, 6.093931904860905, 1.0784369600670678, 0.5935446534837995, 14.3101624080113, 54.91614716393607, 49.08574002129691, 45.70167548315865, 32.58301101412092, 18.53025851930891, 34.06596156529018, 42.43177332196917, 33.45544072559902, 1.206869091306414, 0.23341246375015803, 0.012705966863515121, 0.041673890581088405, 0.010721693829899388, 0.022460447191925983, 0.03288466024345585, 0.042425391862967184, 0.044814557768404484, 0.06329577535923038, 0.010820946539752185, 0.042880115498389514, 0.025290404712515216, 0.01993250730447471, 0.023700062817494785, 0.031031794846057892, 0.003880763991868922, 0.03610697554956589, 0.09952489739017827, 0.053622651379555464, 0.03265718477112906, 0.03311544018132346, 0.025885398499667645, 13.996125544820513, 59.33769934517996, 48.80110706601824, 35.405219895499094, 30.31625849860055, 38.49350309371948, 46.25278575079781, 56.75564799989973, 46.26380211966378, 56.864043372017996, 9.874536650521414, 0.4728199743798801, 0.11474337934383325, 3.3568345478602817, 1.2178520219666618, 11.78152186529977, 47.66474308286394, 49.07371963773455, 51.54108401707241, 49.93966667992728, 49.45644726072039, 48.56428813934326, 48.66330691746303, 45.48478399004255, 43.299912520817344, 37.29989290237427, 34.39530965260097, 32.852628912244526, 35.40487595966884, 32.93169246401106, 32.788295541490825, 33.16118104117257, 34.390998295375276, 34.904855796269004, 35.69894804273333, 34.27202081680298, 35.37458528791155, 37.88385772705078, 41.76920352663313, 44.691563742501394, 45.04606778281075, 43.22694948741368, 43.75759731020246, 42.69242456981114, 41.592990262167795, 36.97048575537545, 37.87578739438738, 36.72868149621146, 34.52586283002581, 35.71938616888863, 35.6792186328343, 35.45748424530029, 34.84739419392177, 35.88148069381714, 35.984380040849956, 36.98778329576765, 37.0133352960859, 36.69029269899641, 36.473620074135916, 36.91035257066999, 37.93603869846889, 36.366319043295725, 36.48356294631958, 36.633178506578716, 36.67916863305228, 36.09367520468575, 37.181836060115266, 33.821166106632774, 33.23956019537789, 33.7181521143232, 37.59808874130249, 39.7479829788208, 42.068740367889404, 43.219883169446675, 50.623268672398154, 45.42269836153303, 43.19204521179199, 48.3585832459586, 44.3985721043178, 43.35922234398978, 42.04740939821516, 41.254345485142295, 33.84201070240566, 32.78597136906215, 33.00804621832711, 35.0797905921936, 36.15740755626133, 36.30279861177717, 36.95983416693551, 35.1059262411935, 38.39181968144008, 37.12018469401768, 36.49698339189802, 35.1787120955331, 37.53512069157192, 34.49111836297171, 37.18271153313773, 36.328305448804585, 34.90178121839251, 37.2628242628915, 35.173938683101106, 33.93768392290388, 35.36796365465437, 35.010478837149485, 35.99530955723354, 36.40623297010149, 35.98971625736782, 34.669555050986155, 35.7575352532523, 35.54553529194423, 34.65951142992292, 35.119940757751465, 36.89287090301514, 35.43007012775966, 33.68193810326712, 33.47027860369001, 34.13078130994524, 34.559544222695486, 36.38208450589861, 37.736323152269634, 38.984084129333496, 41.462527411324636, 43.60788794926235, 44.367086342402864, 46.03004387446812, 47.39048031398228, 48.8079753603254, 50.690721784319194, 51.09695863723755, 51.380340916769846, 50.56704732349941, 49.905853271484375, 53.33181892122541, 47.64666039603097, 45.68287713187081, 41.3975374358041, 53.01549523217337, 52.295088631766184, 49.97947638375418, 4.343141760144915, 0.06205078573631389, 6.407596605164664, 0.32375101479036467, 0.5022459211094039, 14.703333173479352, 61.28920514242989, 52.23437179837908, 53.33781174251011, 38.2454628263201, 23.343529292515345, 38.125491755349294, 49.278382301330566, 42.42651006153652, 1.933484558548246, 0.27054711111954277, 0.07266569935849734, 0.11113845171140772, 0.044897376360105615, 0.039178656081535986, 0.029805101919919252, 0.05459873418190649, 0.06160850982580866, 0.029398866396929537, 0.12777821347117424, 0.08096742603395667, 0.17085663761411393, 0.0851582143721836, 0.12140645751995699, 0.10317088996193238, 0.20832677983811923, 0.06543357457433428, 0.2539697677961418, 0.2117284115936075, 0.2105155981012753, 0.1115277408223067, 0.14953868224152497, 16.119190182004655, 68.73537417820522, 55.50276967457363, 43.66652032307216, 35.42863532475063, 43.53387573787144, 49.1005848475865, 64.1611179624285, 51.199951784951345, 62.026520184108186, 11.898112637656075, 0.702014827302524, 2.727789810725621, 6.604423003537314, 1.5402665670428957, 11.926135591098241, 48.363356658390586, 49.52375793457031, 53.60307312011719, 50.63139111655099, 51.64973994663784, 50.638189928872244, 50.094542026519775, 47.33339391435896, 44.10863767351423, 39.45704800742013, 36.41502938951765, 35.40652615683419, 37.229789052690776, 35.24123198645455, 33.85689026968819, 34.43761723382132, 36.0151675088065, 36.94383941377912, 36.92243548801967, 35.7112706729344, 38.48573848179409, 40.36897822788784, 44.29805598940168, 47.06254618508475, 46.97648927143642, 45.43426711218697, 47.417991706303184, 45.110008580344065, 43.96622044699532, 39.75778341293335, 40.05166442053658, 37.55406495503017, 35.230295521872385, 37.08270263671875, 38.580449376787456, 37.95698751722063, 37.278888498033794, 39.04092386790684, 37.75820650373186, 39.502607345581055, 38.293721539633616, 38.95549576623099, 38.03267771857125, 38.89022091456822, 40.20971509388515, 36.72533246449062, 37.643908636910574, 38.72158466066633, 39.31356770651681, 36.520131315503804, 39.96237312044416, 35.450539520808626, 36.29930019378662, 36.10402454648699, 38.86466196605137, 42.72675909314837, 43.64413670131138, 47.392543928963796, 51.34345987864903, 46.58788694654192, 45.35083314350673, 50.54205117906843, 46.1152218409947, 45.38941649028233, 43.974593026297434, 43.61423512867519, 37.02073860168457, 34.918964113507954, 36.061727387564524, 36.244961806706016, 37.34465667179653, 37.76547431945801, 39.22609683445522, 35.89603022166661, 40.50156375340053, 39.18869468144008, 38.66248328345162, 37.11237839290074, 40.17167370659964, 36.51408290863037, 38.86105932508196, 39.53260966709682, 38.02497911453247, 38.66068022591727, 37.36822496141706, 35.9617532321385, 35.60725266592843, 36.890980992998394, 39.15516267504011, 39.785597051892964, 39.047983237675254, 37.015794958387104, 37.39146668570382, 37.45994813101632, 35.77239397593907, 36.79968861171177, 39.31008318492344, 37.75181763512747, 36.4534181867327, 35.55748271942139, 35.8659792627607, 35.939574582236155, 38.378444399152485, 39.8741066796439, 40.99445159094674, 43.85194342476981, 45.498652594430105, 45.14687919616699, 48.88425268445696, 50.213804381234304, 51.29350233078003, 51.66124268940517, 53.69415010724749, 53.61892543520246, 51.579333850315635, 50.78390407562256, 54.776345934186665, 51.536355767931255, 48.3282995223999, 44.83159078870501, 54.159026282174246, 54.61333424704415, 51.42562232698713, 5.838632072721209, 0.16396796011498996, 14.539919359343392, 2.1288331619330814, 0.859739152448518, 17.63457839829581, 66.61133766174316, 58.09112998417446, 56.683140073503765, 45.00966617039272, 27.02740512575422, 45.169012682778494, 55.22351809910366, 51.38165412630354, 3.494569339922496, 0.4356601669320038, 0.16290894336998463, 0.22613679058849812, 0.1623492469745023, 0.15474224516323634, 0.1438116431236267, 0.10315092067633357, 0.1539575872676713, 0.14827685137944563], [0.05194014576928956, 0.04375691505681191, 0.0335200065081673, 0.05116475326940417, 0.02416276093572378, 0.028397716814652085, 0.04019221437296697, 0.02312739792146853, 0.018602590542286634, 0.0527775122651032, 0.04684283464614834, 0.05338889606563108, 0.09329229540058545, 6.104845787797656, 40.42426156997681, 46.70717709405081, 29.794243812561035, 17.67523925645011, 34.99133307593209, 41.24746329443795, 52.6666122845241, 43.79742438452584, 51.20888716833932, 18.49026468821934, 0.14079434717340128, 0.44304498923676355, 2.0076554928507124, 0.34037297857659204, 3.6951423372541154, 35.660218783787315, 50.216976233891074, 48.6858468736921, 46.46065500804356, 44.74939012527466, 45.40145077024187, 46.005523681640625, 43.48087140492031, 40.79193939481463, 35.71051331928798, 34.00903844833374, 33.95389754431588, 31.289523942129954, 31.245295183999197, 31.55785642351423, 31.45676360811506, 33.01510558809553, 32.954885550907676, 34.991722175053184, 37.55194228036063, 42.2370604787554, 43.933063643319265, 44.306161063058035, 44.928789138793945, 46.13844272068569, 45.3671475137983, 45.068128313337056, 45.40799249921526, 43.72839403152466, 42.297725200653076, 37.380558013916016, 33.49539981569563, 33.86936576025826, 31.943960871015275, 33.22300958633423, 32.08058329990932, 34.49270602634975, 33.52412019457136, 34.60536411830357, 34.788431780678884, 35.10348742348807, 33.07864339011056, 35.87944834572928, 36.19484097617013, 35.39757340294974, 34.56269523075649, 35.20181485584804, 33.638612610953196, 33.74522229603359, 35.41409969329834, 35.03605168206351, 32.12803602218628, 32.06055511747088, 32.31416089194161, 35.127503871917725, 39.21116862978254, 37.17586408342634, 42.02088465009417, 47.56174993515015, 39.91826248168945, 41.643899713243755, 48.58065462112427, 45.21404048374721, 40.92059223992484, 39.57102973120553, 38.24076584407261, 34.754277910505024, 31.807397501809255, 31.463270596095494, 33.38451698848179, 35.488570485796245, 34.53302642277309, 33.92600400107247, 35.4467944417681, 35.905410289764404, 35.304571764809744, 35.021522998809814, 35.65882566996983, 35.26145819255284, 34.56233392442976, 34.34859343937465, 33.039917605263845, 34.62580919265747, 32.83688082013811, 34.20190307072231, 33.319700717926025, 32.53382819039481, 32.41320398875645, 34.21817922592163, 31.666891029902867, 32.72577217647007, 34.06232418332781, 32.78784390858242, 32.56154108047485, 35.284824984414236, 33.696150643484934, 33.75979961667742, 32.944407667432515, 33.64285101209368, 33.35489681788853, 32.922017097473145, 33.54940468924386, 32.860508169446675, 32.839899812425884, 35.245352268218994, 34.38107974188668, 36.875608103615896, 39.91998910903931, 41.452938897269114, 41.906909874507356, 44.59068979535784, 45.24286161150251, 47.03887367248535, 45.92672068732125, 48.91511310849871, 49.16642945153372, 50.252967902592246, 46.791250297001426, 45.29681437356131, 44.05974667412894, 48.94198179244995, 52.49350486482893, 37.10496813910348, 0.315253666469029, 0.1627933345735073, 3.930663687842233, 0.9541922041348049, 0.20501850093049662, 24.154637677328928, 54.56417226791382, 47.6732303074428, 40.01413719994681, 31.92469699042184, 26.064687047685894, 29.185904707227433, 46.13677862712315, 29.861398151942662, 0.5078403066311563, 0.09282108675688505, 0.044733947808189053, 0.04163566531081285, 0.026776401492367898, 0.02669087384960481, 0.04866329660373075, 0.027969540861834372, 0.008496352571195789, 0.019731206320492283, 0.006749649914646787, 0.07906788760530097, 0.03314011171460152, 0.025074561026745608, 0.024184591103611246, 0.031109632990722145, 0.03563595350299563, 0.04669965697186334, 0.04204192118985312, 0.05128059276778783, 0.08699512401861803, 0.05527182734970536, 0.0367160353676549, 8.055985501834325, 51.012659617832725, 52.142923082624165, 36.29442603247506, 20.294958523341588, 38.054112911224365, 43.590656416756765, 58.42617212023054, 47.463561466761995, 56.75724261147635, 18.56729589189802, 0.11892280222049781, 0.6442420216543334, 2.8214736751147678, 1.1076957157679965, 3.5326304861477444, 39.42276906967163, 50.70955835069929, 50.92095729282924, 49.032023497990195, 47.87761851719448, 45.06670045852661, 48.52692072732108, 44.69029917035784, 43.014112268175396, 37.185317107609336, 36.574188300541465, 34.84504222869873, 33.14243132727486, 32.88282230922154, 33.74570172173636, 33.742363112313406, 34.51442609514509, 33.86212921142578, 36.19958312170846, 37.541599886757986, 42.71979352406093, 44.39075190680367, 46.229783739362446, 47.857909951891216, 48.00129645211356, 46.84291362762451, 46.34962279456002, 47.38403238568987, 45.23895672389439, 42.446777956826345, 38.24614027568272, 35.96750634057181, 35.17695072719029, 34.15044123785836, 33.85011577606201, 33.73466450827462, 36.99875102724348, 37.126559666224885, 34.734235831669395, 36.68230921881539, 36.66466426849365, 34.18543931416103, 37.72833619798933, 36.167006492614746, 36.50605773925781, 35.78942401068551, 36.241730894361226, 35.31818675994873, 35.777862208230154, 36.17415271486555, 36.62134919847761, 35.081892422267366, 32.96252509525844, 34.22430058888027, 38.36825834001814, 40.14645869391305, 39.446716036115376, 44.26601784569876, 48.987954548427034, 42.375878538404194, 43.15490014212472, 49.78913743155343, 46.79722922188895, 43.26123884746006, 42.145222663879395, 40.15143013000488, 37.079516887664795, 33.36871331078665, 34.37140090124947, 34.52684252602713, 36.35240527561733, 36.27872657775879, 36.61008964266096, 37.8217443057469, 36.87192208426339, 35.6954357283456, 36.09093066624233, 36.98708847590855, 36.31789009911673, 34.842884813036235, 36.070843424115864, 35.66804245540074, 36.2087755884443, 34.3917487008231, 34.793844427381245, 34.75258255004883, 35.223048550742014, 34.807855469839915, 34.623144558497835, 34.06645488739014, 35.84353310721261, 35.115910802568706, 35.69415725980486, 34.92782654081072, 35.81082098824637, 34.30458354949951, 35.58831535066877, 34.94368927819388, 34.19932528904506, 34.47841705594744, 35.35097183500017, 33.38541678019932, 35.02986431121826, 34.31260871887207, 36.31273453576224, 37.608844552721294, 39.75108882359096, 42.338952336992534, 44.16232640402657, 44.245673520224436, 46.989610944475444, 48.108125005449565, 49.49505492619106, 49.311910833631245, 51.491671902792795, 49.81548500061035, 51.849941866738455, 49.619757720402305, 48.613957336970735, 47.55378382546561, 51.916460445949006, 55.42480741228376, 39.04940414428711, 0.7904714207564081, 0.22400792767958982, 5.939021383013044, 1.4617247815643037, 0.33035655319690704, 25.261565617152623, 59.55383695874895, 51.508993761880056, 46.98859303338187, 39.53776175635201, 25.582112073898315, 32.939783641270225, 51.03474794115339, 38.15722417831421, 0.8056533432432583, 0.11466443857976369, 0.04369377737332668, 0.048206092922815254, 0.0733503411923136, 0.027117548543693762, 0.07475116995296308, 0.0328965854964086, 0.050872654121901305, 0.021075523292113627, 0.10160046815872192, 0.20531507501644747, 0.1717477033713034, 0.1434011837201459, 0.1752180978655815, 0.1269243857158082, 0.11747608413653714, 0.1734310266162668, 0.17135549655982427, 0.12805335942123616, 0.14674680919519492, 0.1817959656140634, 0.3258100157337529, 9.08666217327118, 57.25374003819057, 59.31173392704555, 43.00550692422049, 26.28460274423872, 44.113827977861675, 50.45541409083775, 61.56909942626953, 51.86321987424578, 60.79197120666504, 22.894833735057286, 0.23521638980933599, 1.4826537328107017, 3.6628666520118713, 0.856839039496013, 4.85654502255576, 39.91539634977068, 51.35871812275478, 50.824564933776855, 49.14667224884033, 48.4312162399292, 49.12091180256435, 50.921652112688335, 47.44263349260603, 46.16837556021554, 39.70918076378958, 39.82504544939314, 38.03527634484427, 35.42318098885672, 34.37293645313808, 35.65836361476353, 34.96057687486921, 36.80797781263079, 36.160770484379356, 37.9521689414978, 40.88784885406494, 45.26476233346121, 46.95439052581787, 48.470160893031526, 49.83746910095215, 49.90384176799229, 50.10904291697911, 48.65321465900966, 49.92339399882725, 46.55972589765276, 45.55421733856201, 41.286810943058555, 37.122692993709016, 38.35553618839809, 35.10922316142491, 36.74155650820051, 34.26168189729963, 37.97129733221871, 39.17047997883388, 37.39616366795131, 37.985158988407676, 37.9055951663426, 34.87620489937918, 40.63607392992292, 38.53380959374564, 38.60732500893729, 37.69436992917742, 39.040114402770996, 36.652831486293245, 37.61310379845755, 39.894002846309114, 38.2172531400408, 36.28043930871146, 34.939690589904785, 36.359954493386404, 39.64431585584368, 42.89266470500401, 40.235673563820974, 45.63766867773873, 50.35811846596854, 43.51734944752285, 44.67140007019043, 50.51349755695888, 49.74480445044381, 43.46037769317627, 43.55638442720686, 42.05824858801705, 40.514042718069895, 36.393965925489155, 36.174284730638774, 37.118861062186106, 39.31161526271275, 38.15297188077654, 38.23584304537092, 38.80673483439854, 37.94998720714024, 38.050965377262656, 37.658350467681885, 38.46918439865112, 38.44785690307617, 36.77807623999459, 38.10577971594674, 36.56641674041748, 38.797698702131, 35.3433427129473, 37.007689884730745, 36.52063853400094, 35.77315132958548, 36.58506917953491, 36.70023557118007, 35.22083902359009, 38.874705587114605, 38.14714581625802, 37.4674209186009, 36.514419896262034, 39.091607502528596, 36.78877993992397, 37.189725739615305, 36.64153371538435, 37.35739619391305, 35.68603828975132, 37.08713558741978, 37.127039091927664, 35.976309708186555, 36.23533855165754, 39.42721244267055, 38.535539695194785, 41.360051904405864, 45.65496621813093, 46.618733474186485, 46.18328639439174, 48.77505132130214, 50.99702269690377, 51.58563586643764, 50.52983277184622, 53.521202496119905, 51.48561307362148, 53.58120019095284, 50.737319878169465, 50.40327828271048, 48.2722727230617, 54.92414454051426, 56.80757883616856, 41.85324546269008, 1.227088132074901, 0.5382852501102856, 14.372897693089076, 2.364473717553275, 0.5451417107667241, 29.56646796635219, 64.04532623291016, 55.00154399871826, 51.298164572034565, 42.896006788526265, 35.40458413532802, 40.981190953935894, 59.724783488682334, 45.76813152858189, 1.2066717190401894, 0.22329983567552908, 0.13770277878003462, 0.1482738929667643, 0.16491682348506792, 0.14134906312184675, 0.20125014813882963, 0.12441658814038549, 0.15758400410413742, 0.15362773782440595], [0.021903744832213436, 0.03246679123757141, 0.03752702381461859, 0.014349906239658594, 0.06515608089310782, 0.023053646253954087, 0.02793823664874903, 0.028691225618656193, 0.016824922091992836, 0.02371342826102461, 0.05014503048732877, 0.0550705399364233, 0.015130682914916958, 1.6666907774550574, 29.870114667075022, 46.80859300068447, 33.93813208171299, 29.096380642482213, 33.70406811577933, 40.413061073848176, 50.632634844098774, 45.53929608208792, 49.363396985190256, 27.563873801912578, 0.07779402631734099, 0.10352062048124415, 1.62586652806827, 1.6825396184410368, 0.20316509609775885, 16.95740348952157, 43.52257101876395, 45.38607440676008, 44.42566313062395, 45.03480475289481, 44.61393846784319, 45.290154525211875, 44.44316911697388, 41.09327234540667, 36.03302090508597, 32.553505488804404, 31.871824673243932, 31.245020730154856, 31.358794007982524, 32.100024359566824, 32.55990825380598, 35.097320897238596, 36.89433002471924, 40.17097193854195, 43.35192673546927, 44.244950907570974, 44.72842046192714, 47.55042437144688, 47.337205001286094, 47.47741617475237, 45.245581831250874, 48.041529996054514, 45.56218344824654, 45.34037263052804, 45.72686617715018, 42.724459239414756, 36.14140238080706, 34.73398222242083, 32.20213508605957, 33.34212255477905, 32.75142839976719, 34.78348813738142, 33.4853527205331, 33.928686005728586, 35.67441742760794, 34.83551277433123, 35.665263175964355, 35.66143471854073, 34.18835408346993, 35.42840256009783, 35.319228989737375, 35.36136981419155, 33.52590935570853, 34.34332323074341, 35.86123364312308, 35.13580002103533, 33.65429122107369, 31.11351912362235, 30.839843477521622, 34.369087151118684, 39.74525581087385, 38.58362817764282, 41.42250926154, 48.33220093590872, 40.56644255774361, 42.768792220524375, 48.12701368331909, 44.37315559387207, 42.65051998410906, 38.7649553162711, 39.16520629610334, 34.2230464390346, 31.447404384613037, 33.0610158102853, 34.01931135995047, 33.479446751730784, 34.766864572252544, 35.28617293494088, 34.56100681849888, 37.40772199630737, 35.51055111203875, 35.912271635872976, 34.54490784236363, 35.270761830466135, 34.82699428285871, 33.87612288338797, 35.35519633974348, 34.72636699676514, 35.44857318060738, 33.62910400118147, 33.799439089638845, 34.46396827697754, 34.25208296094622, 32.93141801016671, 33.4500732421875, 33.518773555755615, 31.913604191371373, 34.00917393820626, 33.7870226587568, 34.474494797842844, 32.05201578140259, 33.47125482559204, 33.930193764822825, 33.56384999411446, 32.15202120372227, 31.88653400966099, 32.60053089686802, 31.400045463017054, 33.59950467518398, 32.18261412211827, 33.194598402295796, 33.94798810141427, 35.491374083927695, 36.692123549325125, 39.91896424974714, 41.68390049253191, 44.875142097473145, 44.78411027363369, 47.385821546827046, 47.55787284033639, 49.95486239024571, 47.568298612322124, 50.013018812452046, 47.666657311575754, 48.07299491337368, 50.30382176807949, 55.561207498822895, 16.75309518405369, 0.0219720139367772, 0.10839575888322932, 1.9509147661072868, 0.5850354986531394, 0.1811261022729533, 27.715928179877146, 54.262787205832346, 47.872358730861116, 35.43899161475045, 21.783029896872385, 22.37003629548209, 35.9471481187003, 45.907835483551025, 16.494724682399205, 0.11256272385695151, 0.04206103212865336, 0.015808787063828537, 0.07085957484585897, 0.03792123230440276, 0.011793423776647874, 0.02529378720958318, 0.0845880481813635, 0.04297637926148517, 0.02461027683291052, 0.020723460308675255, 0.010895470040850341, 0.06160464896155255, 0.014134746177920272, 0.03950738933469568, 0.05239797030974712, 0.021049325055043613, 0.01934005123829203, 0.023341355279886296, 0.02085774069252823, 0.039812278867300065, 0.037306567787059715, 0.02820903149300388, 2.614912850516183, 38.37694011415754, 53.134048870631624, 38.94748101915632, 28.433060441698345, 40.212289401463096, 46.91979544503348, 54.448019232068745, 51.111907686506, 54.84812429973057, 29.912592479160853, 0.08152047278625624, 0.23542285444481031, 3.584847935608455, 2.8645724824496677, 0.7424826015319143, 20.31209451811654, 47.112340450286865, 47.78157009397234, 46.573295729500906, 47.711188316345215, 45.21298088346209, 48.23557233810425, 45.885246889931814, 43.41089957101004, 37.57023341315133, 34.14563308443342, 34.33955383300781, 33.42663696834019, 33.41523150035313, 34.12231492996216, 33.30266373498099, 37.05441999435425, 38.106745515550884, 41.084034715379985, 44.82113374982561, 46.730880873543875, 45.5782858984811, 48.17091587611607, 49.291260787418906, 49.98598337173462, 46.90774032047817, 50.034231662750244, 46.01394142423357, 47.12886674063546, 48.457810470036094, 44.623280320848735, 36.843879154750276, 36.9139586857387, 33.23680523463658, 34.81130872453962, 34.46557331085205, 35.476042883736746, 35.69829143796648, 35.4347254208156, 37.97181844711304, 35.639092785971506, 36.1136234828404, 37.645075934273855, 37.73802893502371, 36.07432099751064, 36.910404682159424, 36.538721220833914, 35.49604327338082, 36.5172095979963, 37.24411971228463, 36.28043236051287, 35.23245988573347, 32.61111647742135, 33.662569999694824, 38.14872305733817, 40.857711042676655, 40.63237748827253, 43.524936880384175, 48.59045158113752, 41.96048048564366, 43.30056912558419, 50.263171332223074, 46.291480268750874, 43.76333999633789, 41.51161643436977, 40.265258993421284, 36.14441442489624, 34.14927394049508, 32.70832872390747, 35.64203882217407, 36.14463676725115, 36.68771491731916, 34.59839160101754, 37.13668319157192, 39.18398380279541, 37.62933826446533, 36.71377413613455, 35.934967926570344, 37.393599782671245, 36.76989821025303, 34.673612798963276, 36.22870649610247, 35.49735995701381, 36.43319892883301, 34.903080531529014, 34.91237374714443, 36.64173868724278, 35.04708194732666, 34.770567962101524, 35.39081627982003, 34.952586446489605, 35.659774099077495, 34.74167387826102, 35.940304143088206, 37.13374410356794, 34.85949100766863, 34.997245992933, 36.87436090196882, 35.47419466291155, 34.18787465776716, 33.52527706963675, 32.85652337755476, 33.26409428460257, 35.245755263737266, 34.82195683888027, 35.73089933395386, 35.62451893942696, 37.92268426077706, 39.290412834712434, 43.41396720068795, 43.241123812539236, 45.81232207162039, 46.71958657673427, 48.18875537599836, 48.33888857705252, 51.33111987795149, 50.69742679595947, 51.795756340026855, 51.39142329352242, 50.33838905606951, 52.14392014912197, 56.51584482192993, 19.685365268162318, 0.02373390135887478, 1.1152390709945132, 3.4119517845766882, 0.43564534772719654, 0.14677973171429975, 29.58545391900199, 61.009845869881765, 51.815614291599815, 40.48539182118007, 28.274464334760392, 25.771445274353027, 40.02219363621303, 51.24855790819441, 23.724702256066458, 0.12922286880867823, 0.031789905059018304, 0.015977218115170087, 0.0617550326777356, 0.0058868909420977744, 0.036345935227083306, 0.0032903312322949724, 0.08653530797788075, 0.01859058895414429, 0.04428996198943683, 0.13335904186325415, 0.10062094179115125, 0.15282143466174603, 0.08300489027585302, 0.19050843667771133, 0.12733203598431178, 0.12814429668443544, 0.10113531204738788, 0.13072772377303668, 0.11234606762549706, 0.16850651800632477, 0.08109491597861052, 0.12233116504337106, 2.756009267909186, 46.28983701978411, 59.343111991882324, 47.343739782060894, 38.56842204502651, 43.02246747698103, 50.43061249596732, 58.566741125924246, 55.665333202907014, 58.27564982005528, 33.735546929495676, 0.2018370402178594, 0.9323786603552955, 8.788575768470764, 4.9004124743597846, 0.875045002571174, 19.216832603727067, 47.21748753956386, 47.487015111105784, 49.88856267929077, 50.428330012730186, 47.83606481552124, 50.45692532403128, 49.23373317718506, 44.784794671194895, 40.09037283488682, 35.63700137819563, 37.70727620806013, 35.3826938356672, 34.599743025643484, 35.43749080385481, 35.000737462724956, 40.23086888449532, 40.96488005774361, 42.54703351429531, 47.3851614679609, 47.730664116995676, 48.23444325583321, 51.62007113865444, 51.32794107709612, 52.062820775168284, 47.34085627964565, 52.682686941964285, 49.38197994232178, 48.82789584568569, 50.56312506539481, 46.63918202263968, 39.18679782322475, 39.1630071912493, 35.202596528189524, 36.19464642660958, 36.0636659349714, 37.41646977833339, 37.49163886478969, 38.16549253463745, 40.77147000176566, 37.55869245529175, 38.763117517743794, 39.64486823763166, 37.771439347948345, 37.51510293143136, 39.067014353615896, 38.21282713753836, 37.258266244615825, 37.9062066078186, 39.0184394972665, 37.90368093763079, 37.15708657673427, 35.61828293119158, 35.39479759761265, 39.67147636413574, 43.578111444200786, 42.788156849997385, 46.237927028111045, 50.87584611347744, 44.476558685302734, 44.909372397831504, 52.16429574148995, 47.810179301670615, 47.61455624444144, 42.46867520468575, 41.995697430201936, 38.071761335645405, 36.51826572418213, 36.76788323266165, 38.1924341746739, 36.9788270677839, 38.06438929694039, 37.85677017484392, 38.55917746680123, 40.49346910204206, 40.43396472930908, 38.06992353711809, 37.82284212112427, 39.44351291656494, 39.22461339405605, 36.73041507175991, 39.71198436192104, 37.44851834433419, 38.49958276748657, 37.223132678440635, 36.56177534375872, 37.559102399008616, 37.51974432809012, 36.90784774507795, 36.03763450895037, 38.15978806359427, 37.19426638739449, 37.12865802219936, 37.61991650717599, 38.75114924567086, 36.517404147556846, 36.672932624816895, 38.65246398108346, 38.26328842980521, 35.902700492313926, 34.65370968409947, 36.42678574153355, 34.55085897445679, 37.21661179406302, 35.391980103084016, 36.98904091971261, 37.820035048893516, 40.126718861716135, 41.085552896772114, 44.45351498467581, 44.64207172393799, 48.76858949661255, 50.33577305930001, 52.08670520782471, 50.89656911577497, 53.38698761803763, 51.479116507938926, 54.760104519980295, 52.80411713463919, 52.692317145211355, 55.99175262451172, 57.59963526044573, 20.2948351928166, 0.1460485423782042, 1.2927496944155012, 9.978866457939148, 2.2725961676665714, 0.28677699023059433, 34.521367345537456, 65.23994391305106, 57.08636835643223, 45.39337696347918, 32.693188599177766, 33.167757511138916, 46.02720900944301, 59.19767229897635, 32.66878652572632, 0.3174386035118784, 0.09763677192053624, 0.08719231308038745, 0.17758647006537231, 0.1332244612276554, 0.10902281345001288, 0.10355778384421553, 0.1686683486082724, 0.08928087100918804, 0.1324708123824426], [0.030169539685760225, 0.034727239049971104, 0.019809047857831632, 0.025497839653066227, 0.040001264440694025, 0.02661280330669667, 0.03196770837530494, 0.03084326389112643, 0.03288246178999543, 0.04697984104443874, 0.014592893022511686, 0.028310613274308186, 0.09354491398802825, 0.3447071617203099, 28.58971800122942, 44.94134453364781, 36.215404169900076, 18.24461112703596, 27.24154339517866, 40.632189886910574, 47.6743871825082, 48.49565730776106, 46.113755771092, 30.860861778259277, 0.18564756108181818, 0.25323268877608435, 2.5729198924132755, 1.7852902305977685, 0.06605182175657578, 3.3458403263773238, 29.878813811710902, 45.42281648090908, 41.00809437888009, 44.828585692814414, 45.4207980292184, 47.52715138026646, 42.00950002670288, 40.168727670397075, 33.48490456172398, 32.5681905065264, 32.047398703438894, 31.77429975782122, 32.987455231802805, 33.56101165499006, 37.574450969696045, 42.290245464869905, 42.82398523603167, 44.7120018686567, 44.26113673618862, 47.249216488429475, 44.935476779937744, 43.3747307232448, 42.25220060348511, 43.68722595487322, 44.61400447572981, 46.66735349382673, 45.72733518055507, 45.87695074081421, 44.908566406794954, 44.62277657645089, 39.41998979023525, 34.249397482190815, 33.50289692197527, 34.17113297326224, 34.3698445047651, 33.78891256877354, 32.943653787885395, 33.75616570881435, 34.42136539731707, 33.29826899937221, 33.640224593026296, 36.45936584472656, 35.48554801940918, 34.010678223201204, 35.13106482369559, 36.03591135569981, 34.56549882888794, 34.849548135484966, 34.86904130663191, 35.67872183663504, 32.79018892560686, 32.60434545789446, 32.79800912312099, 36.18461322784424, 38.57372352055141, 37.735697814396445, 41.61843803950718, 47.417779786246165, 43.76308291299002, 42.81502900804792, 47.80429070336478, 46.37103714261736, 41.06994376863752, 39.790835993630544, 38.312043939317974, 33.72694158554077, 32.101038796561106, 32.23607356207711, 34.16395548411778, 34.928437982286724, 34.707294191632954, 34.24926199231829, 35.88998876299177, 34.62500320162092, 35.7653762953622, 35.148230348314556, 36.14876052311489, 34.416800430842805, 33.9392854826791, 34.87427677427019, 35.350356919424875, 33.56691762379238, 33.869970253535676, 34.22718061719622, 33.32625634329659, 35.02551473890032, 32.3175550869533, 33.31638295309884, 32.94671794346401, 34.1643237386431, 33.243089880262104, 32.81397955758231, 33.99109125137329, 33.77686786651611, 32.46477351869856, 33.49287414550781, 34.54823950358799, 33.83720254898071, 34.06357485907418, 32.8192150252206, 33.072296210697715, 32.565313952309744, 32.76957362038748, 32.07118238721575, 32.5821008001055, 33.10021754673549, 32.288747855595176, 33.89222880772182, 35.42815242494856, 36.58799089704241, 38.70797313962664, 41.157119342258994, 44.45873655591692, 45.222413063049316, 47.22041620526995, 48.64667987823486, 51.11704240526472, 49.63991444451468, 50.760335786002024, 50.193334988185335, 45.61996119362967, 5.503637271268027, 0.08614462108484336, 0.7752532916409629, 1.8980448373726435, 1.3408505533422743, 0.12383521933640752, 29.811965193067277, 54.02558612823486, 48.97974872589111, 42.07041140965053, 23.319002151489258, 20.009060995919363, 34.47374439239502, 46.56973477772304, 11.5868524483272, 0.10080411910478558, 0.07910224861864533, 0.05442219294075455, 0.04444840330896633, 0.03037534953494157, 0.03998483371521745, 0.07651038733976227, 0.030830181735966886, 0.013162427548585194, 0.045838073561234136, 0.07803431592349495, 0.03705005440860987, 0.039783749862440994, 0.017415924396898066, 0.014840694011322089, 0.07697926182299852, 0.0553612684431885, 0.031612278161836524, 0.030050728203994886, 0.037511434472565136, 0.05261166473584516, 0.13255796342023782, 0.03898751615945782, 0.39152670225926806, 35.576861245291575, 51.447498730250764, 42.73025403703962, 23.512050901140483, 31.3243795803615, 46.9940299987793, 51.82580382483346, 52.736858572278706, 50.70897817611694, 33.95222650255476, 0.08155681512185506, 0.2904391251504421, 1.1693109295197894, 4.263395982129233, 0.19379884297294275, 4.9435781581061224, 32.80086830684117, 46.86956344332014, 43.87716885975429, 47.438693864004954, 47.32239144189017, 49.34921223776681, 44.12409741537911, 43.133298192705425, 36.362904003688264, 33.13081741333008, 34.02805914197649, 33.934609345027376, 34.50528226579939, 34.5013495853969, 39.263443401881624, 43.58573709215437, 44.538574831826345, 43.76212753568377, 45.93712561471121, 47.77897146769932, 47.44120911189488, 44.76890066691807, 45.30194214412144, 44.08424949645996, 45.868397508348735, 47.64311334065029, 47.12870345796858, 47.69420691898891, 45.644293785095215, 46.02674348013741, 41.34724290030343, 36.25648191996983, 34.106035300663535, 35.84396389552525, 34.86655732563564, 35.13022756576538, 34.83161136082241, 35.20961420876639, 36.99142415182931, 35.1398925100054, 34.99543251310076, 37.327623162950786, 35.55045461654663, 36.211141450064524, 36.39208991186959, 37.708540780203684, 37.6526529448373, 35.92788076400757, 35.79923139299665, 37.57242556980678, 35.15955591201782, 33.54669141769409, 34.3580082484654, 38.314239570072715, 41.67573288508824, 39.4682172366551, 42.5474990436009, 48.740279061453684, 45.7747357913426, 43.56041438238961, 49.331855637686594, 48.223694392613, 41.7272572517395, 42.59355865206037, 40.37746197836739, 35.19235488346645, 33.40023728779384, 33.9265251159668, 34.687047140938894, 37.01544754845755, 36.226166929517476, 35.70451354980469, 36.80032089778355, 35.47052601405552, 35.80427231107439, 37.07008123397827, 38.137866497039795, 35.602569580078125, 35.255187443324495, 35.42110000337873, 37.375225271497456, 34.19802597590855, 35.688956533159526, 34.63486269542149, 35.32424906321934, 35.96829843521118, 33.61244569505964, 34.37036909375872, 35.00583396639143, 35.37405375071934, 34.69408219201224, 35.217413561684744, 35.72877318518502, 35.886733531951904, 35.17850364957537, 35.26197930744716, 35.40731477737427, 35.54297488076346, 36.02565928867885, 34.67621489933559, 33.1398674419948, 33.8830189704895, 34.71434313910348, 33.47884225845337, 33.75740943636213, 34.8555201121739, 35.85467454365322, 35.5122013092041, 37.14163030896868, 38.72141095570156, 41.63597876685006, 42.647841453552246, 48.64017636435372, 46.368827615465435, 50.37692723955427, 50.804335253579275, 52.24944938932146, 50.75572565623692, 53.37405354636056, 51.81750767571585, 48.50866780962263, 6.344119599887303, 0.19137839999582085, 1.9492869334561485, 5.083677291870117, 0.9502136004822594, 0.313650586775371, 32.76801027570452, 60.54122461591448, 52.55725458690098, 48.241255964551655, 31.67721257890974, 20.283078840800695, 39.903539248875205, 53.35206944601876, 16.53447185243879, 0.10603548160621099, 0.01894536438131971, 0.014651655851464187, 0.06368834857961961, 0.019493281408878307, 0.0486868146274771, 0.06091643124818802, 0.03787007076399667, 0.037688949411468844, 0.027710296379934465, 0.19315137128744805, 0.1364510716604335, 0.13346276272620472, 0.1307595470654113, 0.13263892621866294, 0.11645881086587906, 0.12488654149430138, 0.13265517034700938, 0.12008412847561495, 0.13524760838065827, 0.07695615770561354, 0.1878913678228855, 0.17175214099032537, 0.5982896760106087, 40.99504566192627, 58.74528203691755, 49.66494185583932, 28.812348706381663, 37.3375278200422, 51.36359575816563, 55.37375552313668, 56.646276405879426, 54.1922664642334, 38.58126926422119, 0.2697196240936007, 0.7022669166326523, 9.300103885786873, 4.916592223303659, 0.4227977214115006, 5.233024912221091, 34.68277399880545, 48.0288599559239, 43.74685539518084, 46.92510386875698, 48.4466620853969, 52.02525881358555, 46.79571451459612, 45.57422815050398, 38.63551732472011, 35.42806557246617, 36.29084076200213, 35.208787373134065, 36.893496240888325, 36.267043181828086, 41.71979488645281, 47.36086361748831, 46.21231596810477, 48.338190283094136, 46.8483019556318, 52.22407109396798, 48.15131500789097, 45.24553666796003, 46.26052604402815, 44.96515948431832, 48.15058544703892, 49.02547829491751, 49.0307172366551, 47.91666391917637, 48.15064103262765, 48.12907035010201, 43.79642384392874, 38.426748275756836, 35.789646353040425, 37.9216559273856, 38.80404588154384, 37.03025415965489, 37.05953734261649, 36.742529256003245, 39.289092676980154, 36.33149119785854, 37.72007826396397, 38.808951309749055, 38.39783334732056, 37.23281499317714, 39.3550831930978, 40.161320890699116, 38.514788900102886, 37.844072341918945, 38.96410458428519, 38.888925075531006, 36.24235275813511, 36.394410610198975, 36.30095386505127, 41.425927775246755, 44.57075193950108, 40.85870810917446, 45.36411809921265, 50.03328323364258, 47.71958868844168, 45.69589458193098, 49.9741644859314, 50.66724034718105, 44.809825556618826, 45.18227331978934, 42.14827639716012, 37.56438650403704, 34.584668908800396, 37.242195061274934, 35.56292315891811, 38.71255547659737, 38.62393120356968, 38.6550487109593, 39.30705724443708, 38.001779079437256, 38.39101716450283, 39.17816816057478, 40.437122685568674, 37.19191442217146, 36.71173831394741, 37.75441973549979, 39.10949216570173, 36.02892146791731, 37.18986817768642, 36.39503942217146, 36.13971744264875, 37.69467217581612, 34.91837699072701, 36.518005166734966, 36.26163748332432, 38.22230448041643, 36.23508494240897, 36.19036981037685, 38.398628916059224, 36.792188031332834, 36.04912682941982, 38.23749671663557, 38.952535833631245, 36.80072736740112, 38.54883854729788, 37.295456477573936, 35.85139846801758, 36.11144869668143, 36.94617053440639, 36.415394169943674, 35.6454747063773, 37.19688933236258, 37.044973918369834, 36.81431804384504, 38.38471862248012, 41.84231942040579, 44.020906244005474, 44.47402606691633, 49.39435468401228, 48.4545830317906, 51.67610141209194, 53.66571807861328, 53.418129444122314, 52.967160088675364, 53.22063732147217, 52.48512881142752, 49.112160546439036, 8.41033320767539, 0.3708958721586636, 2.657236716576985, 10.007849999836512, 3.499288252421788, 0.31553683270301136, 36.42704977308001, 65.2700365611485, 57.46778971808297, 54.50787101473127, 35.36799839564732, 28.1267352104187, 48.22372218540737, 61.94458702632359, 22.749223811285837, 0.22019180602261, 0.17219550934221062, 0.10601800932948079, 0.1654464743499245, 0.11055508122912475, 0.12913258293909685, 0.11606763542762824, 0.12967471884829657, 0.14321306667157582, 0.10472209565341473], [0.018894609961924807, 0.009823971644176968, 0.08299613038876227, 0.029051507357507944, 0.03693326156852501, 0.07447613935385432, 0.01830591637242053, 0.06981646296169076, 0.03647737763822079, 0.01041211816482246, 0.04486543771677783, 0.017739845140437995, 0.01823041578089552, 0.0851130239399416, 22.36839825766427, 49.389883518218994, 36.09804562159947, 23.72108919279916, 26.861801760537283, 34.92851788657052, 46.81013550077166, 48.544687271118164, 45.84634045192173, 40.917024339948384, 0.9074304476380348, 0.254121976771525, 0.7822422566158431, 2.8002534423555647, 1.3813486716576984, 0.2683066970535687, 14.897123643330165, 43.507528168814524, 46.73877402714321, 48.03386960710798, 49.69761575971331, 46.14908388682774, 44.292132650102886, 37.78765296936035, 30.482556683676584, 33.65887008394514, 31.671289239610942, 32.45106472287859, 35.88538210732596, 41.031127657209126, 43.124713693346294, 45.346942152295796, 44.202691963740754, 47.65066950661795, 43.473905835832866, 45.65020670209612, 40.62109361376081, 40.04938193729946, 45.30671208245413, 47.20825685773577, 46.4429475239345, 44.885203089032856, 46.26603249141148, 44.89867564610073, 45.63272156034197, 46.10331610270909, 41.05148240498134, 34.40960209710257, 32.488717011043, 34.033711501530235, 33.767730985369, 34.184216431209016, 33.16153539930071, 33.88683353151594, 35.49181529453823, 34.93028967721121, 34.57618515832083, 35.96702344076974, 34.81140947341919, 34.55710193089077, 36.28773839133126, 34.40700347082955, 34.34800979069301, 36.03854124886649, 34.84960719517299, 35.65201990944998, 33.05931697572981, 32.119482789720806, 30.42375407900129, 34.02490813391549, 36.942415033067974, 36.634172098977224, 39.1793806212289, 48.5432767868042, 47.530927726200645, 43.077267919267925, 48.04546267645699, 45.84519052505493, 40.461733204977854, 38.53009230749947, 37.904132570539204, 35.406533105032786, 31.784843649183, 30.719295706067765, 34.52234009334019, 35.34251240321568, 36.05616882869175, 35.62515469959804, 35.107336725507466, 34.76380041667393, 34.77148859841483, 34.939603737422395, 35.440085956028526, 34.694679737091064, 35.20979486192976, 34.430359840393066, 35.377993379320415, 34.98243938173567, 33.906698431287495, 33.60521609442574, 32.526803561619346, 32.19875478744507, 35.24446637289864, 33.41065263748169, 34.435553618839805, 33.46692957196917, 35.7361730166844, 38.167048931121826, 39.06451995032174, 40.35995946611677, 40.883565289633616, 42.97920104435512, 40.12347752707345, 37.56223256247384, 33.65891524723598, 33.49898508616856, 32.14264808382307, 32.57543052945818, 33.20763669695173, 32.20029728753226, 32.55806698117937, 33.63057354518345, 33.294711521693635, 32.341845989227295, 33.34910202026367, 33.35466405323574, 35.636389936719624, 37.39474623543875, 39.616700240543906, 42.15936919621059, 44.048844950539724, 46.985539300101145, 48.293443884168354, 50.34873144967215, 51.17966651916504, 50.51986905506679, 32.923285143715994, 0.8280605780226844, 0.03092983817415578, 0.7821169719099998, 1.9378230571746826, 0.22068370319902897, 0.1644804576145751, 27.706021785736084, 56.101478576660156, 45.9345999445234, 40.341689177921836, 19.599424736840383, 23.6475442477635, 33.52260201317923, 40.42254536492484, 7.209214619227818, 0.14419813667024883, 0.019101050848673497, 0.03618408766176019, 0.030621572929833616, 0.034117595691766055, 0.055941324281905375, 0.10179490915366582, 0.034351235654737265, 0.050624462975455184, 0.05937904052968536, 0.06484330339091164, 0.059837764129042625, 0.05109528824687004, 0.029217066509383063, 0.018912638637370298, 0.047310765965708663, 0.026874699164181948, 0.024156206287443638, 0.019988467783800194, 0.01784988825342485, 0.027434860356152058, 0.022708460222929716, 0.018592936685308814, 0.1712738959384816, 25.99718008722578, 55.552015032087056, 43.19715213775635, 24.719534908022197, 32.980489662715364, 42.48763336454119, 50.52102245603289, 53.983466148376465, 50.97560487474714, 43.170276505606516, 0.8014162991728101, 0.4218692955161844, 0.727397790976933, 3.6097867574010576, 2.1277865895203183, 0.9025412499904633, 17.410723073141916, 46.46282632010323, 48.56453480039324, 49.84854105540684, 50.498253209250315, 48.08897924423218, 46.36672231129238, 39.79915646144322, 33.59707975387573, 34.278732776641846, 33.597090176173616, 34.701686995370046, 37.09115512030465, 41.617830072130474, 45.428249972207205, 46.975050994328086, 46.656326702662874, 48.79166099003383, 45.176277024405344, 45.95781735011509, 41.94014310836792, 42.445965017591206, 47.283825465611045, 47.34244046892439, 48.01324387959072, 46.61390100206648, 47.70038039343697, 46.6091171673366, 47.42372397014073, 47.469067914145334, 44.39178024019514, 34.57709189823696, 33.89503935405186, 35.43791811806815, 34.59382316044399, 35.66003465652466, 36.13467999867031, 35.35284437452044, 37.82025044304984, 36.378040654318674, 36.01748473303658, 36.23893771852766, 35.57154239927019, 36.67511435917446, 36.58222736631121, 37.17159788949149, 36.9008161681039, 37.40744406836373, 36.24715396336147, 36.74828931263515, 35.162970951625276, 33.82469926561628, 32.21929018838065, 36.38000699451992, 39.17988436562674, 39.85133048466274, 41.12981292179653, 50.61715425763811, 47.52131141935076, 43.848563126155305, 50.073190212249756, 48.149199281420024, 42.417057037353516, 38.97408219746181, 38.651991503579275, 35.464765957423616, 34.629370144435335, 33.80492469242641, 35.140708923339844, 37.07786321640015, 36.9690648487636, 36.67987387520926, 35.76913527079991, 35.88147374561855, 36.24564273016793, 36.8973559652056, 37.40522064481463, 34.28512511934553, 37.15301840645926, 35.70339488983154, 36.865745135716026, 35.607954433986116, 34.69382163456508, 34.32051576886858, 33.67572641372681, 35.26544993264334, 36.866217613220215, 35.153014183044434, 35.962031160082134, 35.087322439466206, 37.17529085704258, 38.715953145708355, 40.007668427058626, 40.55422067642212, 44.18132277897426, 41.93489374433245, 42.44101790019444, 39.04317855834961, 35.03817088263375, 34.93615048272269, 34.398717744009836, 34.21941947937012, 34.08791787283761, 33.85774837221418, 34.09065546308245, 34.95307976858956, 34.889232771737234, 33.768019335610525, 36.21647071838379, 35.83133554458618, 37.31814929417202, 39.42613199778965, 42.01070901325771, 44.8933151108878, 47.11594309125628, 49.079778466905864, 50.256980487278526, 53.24880184446062, 52.90326792853219, 50.40584216799055, 36.44083499908447, 1.1856808854000909, 0.4419759708855833, 5.250156564371927, 2.987846987588065, 0.41892486065626144, 0.1870802334908928, 31.749939373561315, 60.91882446834019, 49.488422870635986, 44.89741107395717, 21.944301060267858, 25.219598497663224, 38.60044281823294, 49.49431494304112, 10.063645771571569, 0.1074739351336445, 0.06292197720280715, 0.007382080175115594, 0.03160037326493433, 0.010081476531922817, 0.0661523195781878, 0.03798538439774087, 0.08101091334330184, 0.07693361677229404, 0.0374538200641317, 0.13567102780299528, 0.11337350535073451, 0.15071087862764085, 0.09066325718803064, 0.1599490243409361, 0.16731203853019647, 0.12693140176790102, 0.19378284311720304, 0.1245955585369042, 0.10040840426726, 0.18797040358185768, 0.1155277251132897, 0.09716685249337129, 0.2701598033308983, 31.89762680871146, 64.2375898361206, 49.9020665032523, 32.28348459516253, 37.94147218976702, 46.539756774902344, 55.109129905700684, 57.85871621540615, 55.73947048187256, 49.455835819244385, 1.213093483022281, 0.8933580656136785, 3.6244952252932956, 8.203723311424255, 2.3222466920103346, 0.7055465749331883, 19.79682305880955, 46.593327386038645, 48.177342959812705, 51.62687689917428, 53.64429330825806, 48.892121519361226, 48.36272437231881, 42.4817795072283, 33.50328254699707, 37.07988166809082, 35.50775793620518, 36.668371132441926, 40.12189333779471, 43.68484967095511, 47.63178082874843, 48.43189716339111, 48.613596030644004, 50.87859412602016, 47.1165441104344, 47.13432802472796, 43.61866113117763, 41.90310573577881, 50.07456595557076, 50.82971354893276, 49.22864014761788, 48.84015941619873, 49.71676499502999, 48.08687741415841, 50.443748065403526, 49.81357772009713, 45.20385095051357, 37.677482332502095, 35.39542988368443, 38.38610131399972, 37.619881766183035, 36.86201395307268, 36.306557587214876, 36.80875948497227, 38.65714706693377, 37.752564566476, 39.21951341629028, 38.16010768072945, 38.2919671194894, 38.351766790662495, 39.31594051633562, 37.10981103352138, 36.61368186133248, 39.971107006073, 38.23405041013445, 39.93637990951538, 37.558956486838206, 36.488075801304404, 33.39700290134975, 37.19986316135952, 41.4481064251491, 40.735780579703196, 43.21885483605521, 53.557948044368196, 51.238111291612896, 45.89875766209194, 51.352058274405344, 49.47626004900251, 44.35820654460362, 40.637147426605225, 40.72511509486607, 38.413018635341096, 36.54828541619437, 35.447794982365195, 38.002164704459055, 38.920059953417095, 38.4793461390904, 38.45614610399519, 38.49823134286063, 38.09692423684256, 38.250535011291504, 38.32131978443691, 39.45808328901018, 37.990502153124126, 39.22598218917847, 38.10896546500069, 38.739021165030344, 37.70508405140468, 37.065571853092735, 36.51568446840559, 35.04577221189226, 34.82579224450247, 39.08671249662127, 37.58025271551949, 38.73904895782471, 37.79578236171177, 38.87894051415579, 41.08718919754028, 42.88173866271973, 43.962860992976594, 46.64940282276699, 46.303966181618826, 44.60513162612915, 40.820117814200266, 36.30105113983154, 38.29477766581944, 35.12255675452096, 35.854695388248985, 36.311230250767295, 35.82694428307669, 34.7947998046875, 36.8515499659947, 37.083230699811665, 36.003758566720144, 37.4865597316197, 37.36447293417794, 40.289636748177664, 41.3204402242388, 45.08662441798619, 45.58327470506941, 50.523308413369314, 50.936906882694785, 52.562385831560405, 53.03580134255545, 54.89922482626778, 50.83094685418265, 38.491807733263286, 1.9181902706623077, 0.24401530623435974, 6.8763424924441745, 6.987783781119755, 0.5167960460696901, 0.27677030861377716, 35.4142039162772, 65.65097154889787, 53.90213400976998, 50.59249857493809, 28.911591563905986, 33.12575217655727, 44.89901958193098, 57.13299771717617, 12.856188450540815, 0.3021898588963917, 0.11425795539149217, 0.09944166149944067, 0.11020698597920792, 0.18741522622959955, 0.1465826987155846, 0.10453959687479905, 0.11379473310496126, 0.12565519953412668, 0.13831417954393796], [0.039449893669890504, 0.04021333038274731, 0.012625004065089991, 0.14536836530481065, 0.011837116342836192, 0.04347596423966544, 0.03203320396797998, 0.030381320643105676, 0.02764647507241794, 0.01793606559346829, 0.0673579473846725, 0.025395842269062996, 0.02949685024629746, 0.01472362466821713, 12.126086507524763, 48.090528692517964, 42.69141360691616, 25.370212861469813, 18.024354968752178, 32.519514901297434, 42.616866384233745, 49.97113159724644, 44.111514227730886, 45.24895518166678, 3.0975575234208788, 0.7976286624159131, 0.7718281554324287, 2.7624993196555545, 0.47355165226118906, 0.2912717419011252, 10.369952763829913, 47.58551624843052, 47.748079776763916, 49.6423602104187, 46.455693994249614, 47.06088209152222, 39.256995473589214, 34.57477814810616, 32.82263701302664, 33.37354230880737, 34.234003748212544, 37.56262860979353, 42.388406140463694, 46.63085113252912, 44.60235582079206, 45.76231588636126, 44.20901482445853, 43.71647092274257, 40.30202538626534, 44.02973740441458, 46.16080549785069, 48.08668981279646, 45.962371894291465, 43.585236821855815, 41.09967163630894, 42.66513204574585, 44.770172187260215, 45.93991879054478, 44.99445308957781, 45.85698856626238, 39.9664169720241, 33.914605481284006, 33.82958384922573, 32.082292556762695, 33.26037005015782, 33.469569887433735, 33.58585841315133, 33.729467255728586, 34.57330165590559, 35.426828793116975, 33.246692521231516, 35.402464934757774, 34.656801632472444, 34.184713227408274, 36.94252620424543, 36.629506383623394, 36.17269011906215, 35.80761439459664, 35.77032341275896, 34.24018069675991, 31.524310520717076, 32.08291094643729, 31.49921362740653, 33.77962282725743, 35.78016553606306, 37.387263025556294, 38.62201002665928, 45.965502057756694, 48.52316870008196, 45.215079239436555, 48.64379290172032, 45.69047498703003, 40.53475529806954, 38.053529262542725, 36.02340807233538, 33.47252287183489, 33.19816977637154, 32.27852358136858, 33.675681250435964, 36.08759205681937, 34.48896442140852, 35.43973159790039, 34.58654144832066, 33.01657165799822, 35.67691877910069, 35.80314670290266, 36.193416595458984, 34.30397210802351, 34.442029339926584, 34.996165548052105, 34.651065894535606, 35.943861620766775, 33.18100425175258, 33.50092363357544, 33.50460965292794, 33.81754609516689, 33.853840010506765, 35.515908173152376, 35.14964778082711, 37.5166836466108, 39.39469139916556, 41.80063022886004, 45.67874295370919, 47.32176957811628, 45.694022042410715, 45.326410225459504, 44.98242228371756, 44.326151030404226, 42.02372646331787, 38.91349043164934, 35.81821387154715, 34.13359880447388, 32.68125854219709, 32.280653204236714, 33.733681338174, 33.57171882901873, 33.10109996795654, 34.02264302117484, 34.45440060751778, 31.988002027784074, 34.31538799830845, 33.596412726810996, 35.56705733707973, 38.94719614301409, 42.36789158412388, 45.60566527502877, 47.06436661311558, 47.105548586164204, 52.628629956926616, 48.087151868002756, 27.24939485958644, 0.2909981294402054, 0.9160571247339249, 2.6982868909835815, 2.2231110973017554, 0.45853067828076227, 0.6753644144960812, 32.94285821914673, 54.01773466382708, 44.09537703650338, 38.52934537615095, 31.344376495906285, 23.809251410620554, 39.4403966494969, 33.19368471418108, 3.188521602324077, 0.10231219032513243, 0.026515755835654478, 0.09793272853962012, 0.05471428869558232, 0.011127083728622113, 0.07984852178820542, 0.030709534816976105, 0.013080270528527243, 0.03631414586145963, 0.04439700088862862, 0.03679106777001705, 0.019894933427817056, 0.01621503785385617, 0.03497021904747401, 0.00745732631600861, 0.02227720202478979, 0.031152445157723765, 0.013080457973826145, 0.03248889112312879, 0.019502655370160937, 0.03303211608103343, 0.002242464938067964, 0.035423049570194313, 0.0388231105171144, 17.792457103729248, 55.96871934618269, 46.005155427115305, 29.01959088870457, 21.6922082560403, 41.0964025088719, 49.29216752733503, 55.02960777282715, 47.74079459054129, 48.766063826424734, 2.768068952219827, 0.1766682764781373, 0.8135687527912003, 4.073632861886706, 2.613669774362019, 0.5402254260012082, 11.724293027605329, 46.867020402635845, 50.333264759608674, 50.134372574942454, 47.3167599269322, 47.59566756657192, 42.18467106137957, 36.3280622618539, 34.126872948237825, 36.5195163999285, 35.61382566179548, 37.93288769040789, 42.87285886492048, 48.27477407455444, 46.64678682599749, 47.66357231140137, 46.54250826154436, 45.25853674752371, 42.331114768981934, 45.08788899012974, 46.5763703073774, 48.38689715521676, 48.4622677394322, 45.172469411577495, 44.350862298692974, 44.528114318847656, 45.72417375019619, 47.79378502709525, 46.29790735244751, 47.081726687295095, 42.36893033981323, 35.2266720363072, 35.270546436309814, 33.666610377175466, 33.33253404072353, 34.22201810564314, 34.3464047568185, 34.5580746786935, 36.40206405094692, 37.01774392809187, 35.22848899023873, 36.585850851876394, 36.1398320879255, 36.27959510258266, 36.49705287388393, 39.50805473327637, 37.711243629455566, 36.28118624005999, 35.68830687659127, 36.63610369818551, 33.59928928102766, 33.86801086153303, 33.3011976650783, 35.013949462345664, 37.59743561063494, 38.74971791676113, 39.77183614458357, 48.48449502672468, 50.8274519102914, 46.31115409306118, 49.752263341631206, 47.48834221703665, 41.57938568932669, 40.01465484074184, 38.02440936224801, 35.277647495269775, 34.66124153137207, 33.56020218985421, 35.42162111827305, 37.69768074580601, 36.14267042704991, 36.6112117767334, 35.73112167630877, 35.52931472233364, 36.309302125658306, 36.92377996444702, 37.607593876974924, 36.27818809236799, 36.509104524339946, 36.69596937724522, 36.38975184304373, 37.465555327279226, 35.63750164849417, 34.460706097739084, 36.0004095349993, 35.02004650660923, 34.34369495936802, 36.34498807362148, 37.18998282296317, 38.99636159624372, 40.22733572551182, 44.217390877859934, 47.79092584337507, 49.58078874860491, 48.01760734830584, 47.49911887305123, 45.85715184892927, 46.03015851974487, 45.1115927696228, 39.44970028741019, 37.01308863503592, 35.58387197766985, 34.78044830049787, 35.11420849391392, 35.27212020329067, 36.15395082746233, 36.1014016015189, 36.13980776923043, 35.856481075286865, 33.9692565373012, 35.38738734381539, 34.744209970746724, 37.811057976314, 40.19870914731707, 44.44293287822178, 46.50590515136719, 49.09532158715384, 48.25625365121024, 54.920847620282856, 48.60257966177804, 31.129576410566056, 0.497362314590386, 1.9624038296086448, 5.465588501521519, 5.447763332298823, 0.9786930722849709, 0.5774425832288606, 34.97960451671055, 60.387836183820454, 48.55432442256382, 44.10771356310163, 28.76478828702654, 26.507158756256104, 44.29241057804653, 40.78571728297642, 4.08521203483854, 0.07230208601270403, 0.012919644326237696, 0.05710890662989446, 0.023126008621017848, 0.03791932901367545, 0.08122947625815868, 0.017304373239832263, 0.022944274890635694, 0.022728076670318842, 0.031814803901527605, 0.11866422609559127, 0.1182028901364122, 0.17605626503271715, 0.2375713134450572, 0.07996370989297118, 0.16146735501076492, 0.12769608359251702, 0.1420538438750165, 0.11755760333367757, 0.09907204311873231, 0.12615994816379889, 0.17367414571344852, 0.2729619358267103, 0.11626901105046272, 20.06441729409354, 62.883455412728445, 54.778687477111816, 35.83448655264718, 26.45372884614127, 43.16048649379185, 53.41159813744681, 59.48272909436907, 52.8350887298584, 53.75525256565639, 4.103185287543705, 1.3753313145467212, 2.6300903218133107, 10.873236843517848, 2.4697971173695157, 1.2513203003576823, 14.280392851148333, 51.33630323410034, 51.06180075236729, 52.908343587602886, 49.664368629455566, 50.95691074643816, 43.8454920223781, 38.76221425192696, 35.461243220738, 37.21346773420061, 37.82579857962472, 41.5236611366272, 46.38442284720284, 50.28342880521502, 47.61192635127476, 49.58684062957764, 47.48010860170637, 46.2783968108041, 42.46084805897304, 46.98520231246948, 49.80402742113386, 50.72327062061855, 50.53353268759591, 46.78479889460972, 44.34942749568394, 45.40996926171439, 48.45517710277012, 49.34261839730399, 48.67668914794922, 49.524702889578684, 44.02731248310634, 37.29522023882185, 37.50850909096854, 35.055225236075266, 35.1721008845738, 36.074453013283865, 37.51126405170986, 36.634234632764546, 38.42918709346226, 38.575279917035786, 35.91603061131069, 38.174473081316265, 36.56445734841483, 36.57351779937744, 40.06499801363264, 40.559636797223774, 39.78984587533133, 38.60943726130894, 37.12749072483608, 38.57390417371477, 34.43553624834333, 37.24102776391165, 35.59370020457676, 37.68613631384713, 40.992255960192, 42.01626409803118, 41.51862716674805, 48.49949966158186, 53.43588556562151, 47.46090725490025, 51.628308228084016, 50.24342802592686, 43.7963022504534, 42.389726298195974, 41.473818234034944, 37.60940735680716, 36.899027006966726, 35.443952628544395, 36.87966932569231, 40.62359149115426, 37.34702948161534, 39.2385619027274, 37.15813228062221, 35.91828530175345, 38.55908019202096, 40.032501288822715, 39.373343058994834, 38.2005739893232, 37.56130150386265, 38.74034479686192, 38.204048088618684, 38.733671052115305, 38.15054695946829, 35.74236386162894, 37.844423225947786, 36.70130559376308, 36.515517711639404, 38.930881772722515, 38.22342661448887, 41.014583996364046, 43.61334923335484, 46.591079643794465, 50.041718346732004, 51.324341910226, 49.309895856039866, 49.723897320883616, 47.297992842538015, 48.79533658708845, 45.9502785546439, 43.65597643171038, 39.83354309626988, 37.94473089490618, 36.83722278050014, 35.856182302747456, 37.76480729239327, 37.422712734767366, 37.98745884214129, 37.188231876918245, 38.856560366494314, 35.624522413526265, 38.35626227515084, 36.685494967869346, 39.46609108788626, 42.60722575868879, 46.63980736051287, 48.59754569189889, 51.86141334261213, 50.36150918688093, 59.521777970450266, 49.87089688437325, 34.25048834936959, 0.8675749291266713, 3.762492528983525, 10.391915151051112, 8.300958139555794, 2.397840052843094, 0.885222430740084, 40.27519144330706, 64.88450881413051, 52.49270234789167, 50.88996485301426, 44.251846994672505, 34.70583854402815, 52.4214312008449, 49.602564402988975, 6.472566604614258, 0.27421858268124716, 0.1234295911022595, 0.13415283284017018, 0.1502259567912136, 0.1322524869548423, 0.23743107382740292, 0.10980656210865293, 0.14365020607198986, 0.08034020861876862, 0.15622933608080658], [0.02391240865524326, 0.02143070414396269, 0.01683238597719797, 0.04427122085222176, 0.04987968258293612, 0.04565131697537644, 0.022400841283212816, 0.07540076545306615, 0.022414878476411104, 0.01643354139689888, 0.03617901900517089, 0.008468182341727828, 0.07105208201599972, 0.09247130874012198, 7.6120772532054355, 42.870204653058735, 43.232761655535015, 26.671547923769268, 20.708148785999843, 29.75727939605713, 32.74069343294416, 47.23732464654105, 44.1816736630031, 49.21468816484724, 9.078445928437368, 0.3465425175215517, 0.17837298714688846, 1.809032985142299, 2.7425458303519656, 1.009279259613582, 17.75728358541216, 50.91231025968279, 47.384192194257466, 46.910470962524414, 43.631963457380024, 42.612947600228445, 35.557934352329795, 34.39254774366106, 32.69942460741316, 33.74697324207851, 36.60369382585798, 42.33764607565743, 45.75556918552944, 45.31993103027344, 44.68474061148507, 43.13528537750244, 44.17004237856184, 40.54023742675781, 45.05756705147879, 46.57473400660923, 45.29848541532244, 44.34838873999459, 42.95151942116873, 43.71916682379586, 41.78111621311733, 42.67025286810738, 43.502907616751536, 44.69066047668457, 43.63649715696062, 43.00925547736031, 35.923034395490376, 32.99571663992745, 34.296089376722065, 32.7952333177839, 33.048724446977886, 33.60032456261771, 33.44965635027204, 33.931771005902974, 35.0638062613351, 34.57440294538225, 35.12796245302473, 36.59046445574079, 36.4580317905971, 33.961526666368755, 35.39598573957171, 35.41662188938686, 35.332211698804585, 35.40094675336565, 33.54096262795584, 35.452752522059846, 35.19096176964896, 31.946326732635498, 32.53515182222639, 33.992970739092144, 35.837769576481406, 35.66116721289498, 37.99737739562988, 45.882342542920796, 48.35982697350638, 49.277798652648926, 46.22752904891968, 46.03583867209298, 39.81347669873919, 38.54488502229963, 36.35210302897862, 33.69118268149239, 33.366931097848074, 32.46314069202968, 33.063260078430176, 34.728406293051584, 35.998116629464285, 36.31298119681222, 33.97266462871006, 35.51956639971052, 35.08290685926165, 35.44746841703142, 34.07450090135847, 33.23392868041992, 34.710921151297434, 34.411578859601704, 35.35234063012259, 33.47695582253592, 33.183568137032644, 33.83646603993007, 33.38246379579817, 33.661267212459016, 34.50643914086478, 32.98137903213501, 37.78754179818289, 41.05008929116385, 42.885483741760254, 44.54885121754238, 46.09524924414498, 43.673972266060964, 43.137724195207866, 44.82403462273734, 45.874348640441895, 45.81630686351231, 46.028358936309814, 43.17226021630423, 41.17955507550921, 37.79659182684762, 37.92452900750296, 34.26126153128487, 32.607805660792756, 32.76708616529192, 33.222071579524446, 31.05838516780308, 32.91880008152553, 34.79286820547921, 33.43982812336513, 33.57826403209141, 34.31795883178711, 35.20915215356009, 36.34523820877075, 38.69085277829851, 44.930283001491, 47.02745083400181, 49.15610442842756, 49.37647349493844, 22.45411992073059, 0.5089930562036378, 1.3793509559971946, 4.69813608271735, 3.3285998914922987, 0.30730454730136053, 0.9998099505901337, 40.39311974389212, 50.956698826381135, 45.17633955819266, 29.667949880872452, 16.676281111580984, 24.480930294309342, 39.48791537966047, 29.76417200905936, 0.5173597729631833, 0.020101238607562015, 0.06201953241335494, 0.05249951986063804, 0.054243412534041066, 0.05383802178714957, 0.08498760352709464, 0.009627251619739192, 0.03199571151552456, 0.030387922788837125, 0.033245206610964875, 0.023170915764889548, 0.03579087322577834, 0.05452430567571095, 0.00586983045130702, 0.021516258928126523, 0.018751350863437568, 0.039887518222842894, 0.03754963260143995, 0.054049765425068994, 0.014328337307753307, 0.038688855578324625, 0.01686188019812107, 0.05436377107564892, 0.06760177894362382, 10.544624396732875, 50.656689507620676, 47.75780725479126, 30.90479176385062, 20.75018538747515, 34.28402730396816, 38.51589018957955, 53.03316102709089, 49.38339042663574, 53.994072573525564, 8.777631487165179, 0.27276836335659027, 0.4090257946934019, 3.3404170402458737, 3.6992343919617787, 1.1234320827892847, 20.059187037604197, 52.75150190080915, 50.80258778163365, 48.28782973970686, 44.95847879137312, 44.438083035605295, 38.462924071720664, 35.58169371741158, 35.0819410596575, 36.314530645098, 38.102211815970286, 43.413897718702046, 46.4766115461077, 46.62847832271031, 46.48708248138428, 44.53585113797869, 45.526469707489014, 42.21556970051357, 45.831318446568076, 48.872791630881174, 46.82444878986904, 45.17382778440203, 44.553315435137065, 46.141364438193186, 43.17642566135952, 45.678062030247276, 45.18655341012137, 45.67125626972744, 46.813435895102366, 44.62727900913784, 37.81333351135254, 34.059746401650564, 36.52369226728167, 34.16172511237008, 36.40111562183925, 35.42536619731358, 34.460313524518696, 35.98620394298008, 35.65861027581351, 36.715167249952046, 37.508825234004426, 37.3860297203064, 37.214575971875874, 34.29586703436715, 37.05490984235491, 37.120730127607075, 36.11837257657732, 36.132029260907856, 35.52941199711391, 36.452275208064485, 36.494996207101, 33.28538703918457, 34.295564787728445, 35.99569518225533, 38.04023388453892, 37.68314511435372, 41.08504567827497, 46.64183970860073, 49.896445410592214, 50.99134601865496, 49.615984848567415, 46.855246680123464, 41.54500600269863, 40.36257893698556, 38.53116580418178, 35.497995717184885, 34.74058648518154, 34.63086748123169, 35.182627405439106, 35.7546899659293, 37.512716225215364, 37.61282239641462, 35.20290572302682, 36.74641677311489, 36.539718287331716, 37.22738150187901, 36.790086201259065, 35.832443782261436, 36.473849364689414, 35.737156186785015, 35.9946460042681, 35.729078905923025, 35.060498918805806, 36.301172733306885, 34.31865017754691, 34.995352608816965, 35.28492225919451, 35.34424597876412, 39.65555109296526, 43.25100762503487, 44.5284617287772, 45.77149098260062, 46.917391368321006, 46.43852499553135, 45.6693628856114, 46.087345668247764, 47.29613419941494, 47.86896800994873, 47.77140487943377, 44.15714999607631, 43.330501965114046, 38.715501512799946, 37.82269273485456, 35.32785170418875, 34.12303406851632, 34.082248142787385, 35.71829530170986, 32.54324647358486, 35.52772011075701, 36.074084758758545, 35.65494510105678, 34.559644971575054, 37.06124312537057, 35.90404496874128, 38.57209416798183, 40.77669504710606, 46.52955681937081, 48.81762988226754, 51.847628116607666, 51.13762991768973, 25.408747570855276, 0.5667081049510411, 2.8475194317953925, 7.470174193382263, 5.584119992596762, 0.3026329151221684, 0.9653383088963372, 43.491130420139854, 55.71258442742484, 48.95288004193987, 35.59646211351667, 24.02867204802377, 26.845680202756608, 46.47248779024397, 37.332518168858115, 0.942688375711441, 0.06115813899253096, 0.03996903741998332, 0.07988998706319503, 0.06651650967874698, 0.09490618415709053, 0.05776505677827767, 0.036070775706321, 0.061100321023591926, 0.0184054337109306, 0.01706840081273445, 0.1358972785196134, 0.10132729674556426, 0.14866656118205615, 0.1302716668163027, 0.09399295744619199, 0.08982069989932434, 0.10642207014773573, 0.16425842738577298, 0.1324350671576602, 0.18771645506577833, 0.1151345819234848, 0.12052252995116369, 0.2261325701006821, 0.22084014623292855, 13.856402482305255, 57.27832971300398, 55.582840715135845, 37.483717918395996, 30.060589109148296, 40.66170930862427, 41.47003493990217, 58.05006265640259, 52.61838483810425, 59.414337975638254, 11.111994317599706, 0.8469508843762534, 1.035999208688736, 6.610661617347172, 7.102035181862967, 3.411722494023187, 23.327880212238856, 55.511322907039094, 51.94016769954136, 51.259695870535715, 48.29835973467146, 46.54922022138323, 39.74662460599627, 37.36136014120919, 37.06280647005354, 37.83602285385132, 39.87858131953648, 47.440837383270264, 49.040649686540874, 48.93431098120553, 48.76644945144653, 47.05078288487026, 46.805872780936106, 43.831310749053955, 46.92628506251744, 50.051192215510774, 49.13095194952828, 48.06116560527256, 46.144105502537315, 47.79694645745413, 46.62263836179461, 47.45403896059309, 47.83027001789638, 48.02760580607823, 47.84541014262608, 45.803852217538015, 39.4688286781311, 35.66088581085205, 39.33383560180664, 36.28089094161987, 36.94914436340332, 38.029894965035574, 36.815068449292866, 38.10410172598702, 36.93743664877755, 37.579012462071006, 39.42080620356968, 39.71972118105207, 39.127606119428364, 37.17269223076956, 38.57074621745518, 38.93921266283308, 37.50598342078072, 37.92097500392369, 36.487777028764995, 39.29217767715454, 39.05907951082502, 36.14370918273926, 37.26126091820853, 38.794116905757356, 40.943427494594026, 40.06692961284092, 42.993788787296836, 49.08210263933454, 51.63221311569214, 53.941592829568044, 50.875321524483816, 48.285040037972585, 42.463217394692556, 42.196948528289795, 40.58303485597883, 38.08692230497088, 38.656726700919016, 36.69274541309902, 36.84671401977539, 37.44854613712856, 40.35333783285958, 40.52191502707345, 36.98860665730068, 38.35837800162179, 37.42740624291556, 39.36798252378191, 38.77355023792812, 36.44993366513933, 37.92729091644287, 37.600603989192415, 37.95400674002511, 37.09934704644339, 36.64416708265032, 36.73239878245762, 35.94730792726789, 37.7365003313337, 37.07767908913748, 37.119159834725515, 43.124706745147705, 45.20001207079206, 45.857335976191926, 47.56266014916556, 50.6418342590332, 49.01889487675258, 47.9898875100272, 48.195394379752024, 49.15500661305019, 50.198525292532786, 49.81878539494106, 46.270701680864605, 46.02315126146589, 42.25468805858067, 40.940123626164024, 37.377281938280376, 36.10992704119001, 36.67363091877529, 36.98180784497942, 34.53814377103533, 36.21840231759207, 37.86014699935913, 37.04686382838658, 37.09185688836234, 39.3583835874285, 38.89559187207903, 39.490354197365896, 42.574770723070415, 50.247666427067344, 50.81208596910749, 53.5012993812561, 52.478743416922434, 29.78187949316842, 0.8878373961363519, 3.7313641650336127, 14.445363061768667, 11.568685514586312, 1.269063828246934, 1.1585051779236113, 49.16554355621338, 59.84576552254813, 54.47132001604353, 40.938497747693745, 26.896480219704763, 34.95651912689209, 52.426100390298025, 46.54431479317801, 2.0930442937782834, 0.23432134783693723, 0.14689319634011813, 0.10592078883200884, 0.14951212438089506, 0.11857294956488268, 0.2188986675547702, 0.11569810525647231, 0.1470015583825963, 0.12003988799239908, 0.17529458233288356], [0.0051311373660740045, 0.06076418834605387, 0.010863871513200658, 0.010089064249768853, 0.05930483594004597, 0.012533115156527077, 0.04882818400593741, 0.0480325168796948, 0.040207328740507364, 0.03674922590809209, 0.10374893394431897, 0.07671069766261748, 0.1008946221055729, 0.007079099022251154, 9.156578421592712, 42.113726479666575, 46.46405962535313, 28.739727871758596, 46.37140539714268, 47.60389423370361, 26.485985858099802, 54.45620421000889, 43.109271321977886, 50.71891062600272, 19.559747048786708, 0.0718551417812705, 0.2418282250208514, 3.233140979494367, 2.376262422118868, 0.7979520793472017, 27.828912837164744, 51.011322089603965, 48.46865313393729, 47.28180701392037, 43.88159486225673, 39.05299636295864, 35.34968989236014, 33.45507247107369, 34.802296910967144, 35.18720626831055, 39.054795946393696, 43.94852338518415, 45.44531127384731, 45.014224188668386, 45.227554730006624, 44.41199949809483, 42.37051452909197, 45.63662297385079, 46.9889543397086, 44.37679992403303, 44.107463427952354, 43.880875723702566, 41.089916365487234, 41.09635387148176, 39.33072975703648, 39.35253667831421, 40.03047588893345, 40.554182461329866, 39.21019240788051, 35.42302118028913, 32.96933780397688, 34.24397441319057, 33.53849254335676, 32.60164260864258, 32.749621868133545, 32.98356424059187, 33.81016363416399, 33.409363746643066, 34.40171589170183, 34.4467054775783, 33.62478916985648, 35.31815896715437, 34.63438326971871, 34.873849460056846, 35.85779428482056, 36.08133520398821, 34.135113511766704, 35.51451505933489, 34.18731532778059, 37.239700657980784, 34.27105849129813, 32.50217914581299, 31.37739086151123, 33.723523071834016, 34.61427170889718, 35.100499698093955, 38.11204351697649, 46.872037002018516, 48.79590286527361, 47.18497691835676, 47.35492638179234, 47.588813168661936, 39.103294372558594, 36.540162972041536, 35.888147490365164, 33.722904682159424, 33.11726842607771, 32.17586742128645, 32.77698734828404, 34.953256947653635, 35.03795548847744, 34.26981476375035, 34.69669818878174, 35.92925303322928, 32.264849526541575, 34.426739828927175, 35.05316856929234, 34.08458273751395, 33.83223806108747, 34.666681970868794, 33.98059947150094, 35.77465214048113, 34.13941444669451, 33.04973540987287, 34.922274930136545, 33.85205084936959, 35.40345157895769, 33.40764059339251, 38.67873511995588, 42.751161166599815, 43.75459221431187, 43.90915489196777, 45.97316939490182, 44.37304442269461, 46.17992694037301, 44.33331114905221, 42.286465644836426, 45.00299937384469, 46.519332545144216, 44.61553307941982, 45.02667883464268, 43.47578879765102, 39.979302406311035, 38.49908249718802, 35.8665976524353, 35.317683015550884, 35.62666940689087, 33.425441878182546, 32.217181410108296, 31.87360688618251, 34.65928561346871, 34.475206988198416, 34.75331558500017, 34.566294397626606, 35.68222025462559, 36.99149363381522, 42.79242999213082, 47.58353253773281, 49.68804461615426, 47.903194836207796, 12.437433549336024, 0.04005543189123273, 2.9264907027993883, 3.362943534340177, 4.748418893132891, 0.16782460388328346, 3.0086051651409695, 49.85366882596697, 46.90542309624808, 41.7193397794451, 29.39392682484218, 23.834456001009258, 30.67179434640067, 38.66894858224051, 18.802596637180873, 0.051114056525485854, 0.02635264958787177, 0.042308191901871135, 0.08165045295442853, 0.05098483631653445, 0.03313220678163426, 0.02479878912812897, 0.023382667884496704, 0.02605178376792797, 0.046272705774754286, 0.014131188958085008, 0.034744541692946634, 0.05322977281840784, 0.021341220642040883, 0.07191734308643, 0.02475548841591392, 0.02349858371806996, 0.040244627810482464, 0.04203808746699776, 0.0009798522764218173, 0.03260663391223975, 0.035597779122846465, 0.04375826873417411, 0.03824552793854049, 0.08229635043867997, 11.387050918170385, 51.12528991699219, 51.289785044533865, 34.15599979673113, 41.223432949611116, 43.347129004342214, 31.823152542114258, 55.99911076681954, 47.11607163293021, 54.48023802893502, 20.59657982417515, 0.045472543354013135, 0.10016314099941935, 4.825031902108874, 2.4577263593673706, 1.0887335389852524, 30.18548992701939, 52.721944264003206, 51.543481145586284, 49.09060723440987, 46.26346860613142, 40.94490051269531, 36.13427700315203, 34.51342902864729, 37.39942584718977, 36.99553401129586, 41.10659899030413, 45.348922388894216, 46.30989646911621, 46.72422797339303, 46.912065574101035, 44.085521016802105, 43.848597867148264, 47.00774574279785, 47.79565756661551, 45.21326575960432, 46.65050411224365, 44.848575660160606, 42.67025286810738, 43.38748066765921, 42.27759974343436, 41.13590996606009, 42.07321153368269, 43.60557419913155, 41.93791273662022, 37.99114138739449, 33.93135411398751, 34.154450348445344, 34.41601528440203, 35.46289341790335, 34.84221431187221, 35.05798714501517, 34.02841697420393, 34.311531748090474, 35.04115513392857, 36.215626512254985, 36.34477267946516, 36.52071149008614, 37.78952203478132, 36.34060376031058, 36.51799821853638, 36.893350328717915, 35.95412411008562, 37.271849972861155, 35.02296127591814, 37.79163081305367, 36.26670272009713, 34.387148993355886, 33.03067997523716, 36.53028958184378, 37.33629451479231, 36.031825814928325, 40.27876281738281, 48.200789655957905, 49.40864365441458, 49.52035331726074, 49.0418586730957, 48.263920988355366, 41.177811077662874, 38.39773607254028, 36.718999181474956, 36.04524973460606, 35.00582701819283, 34.07629006249564, 35.690026555742534, 37.237970556531636, 35.84272364207676, 37.6754013470241, 36.78077908924648, 37.749260698046, 33.92782095500401, 35.87461239950997, 35.63472931725638, 35.96099240439278, 35.96703038896833, 36.02536746433803, 37.1019560950143, 36.169389724731445, 35.14908845084054, 34.32495566776821, 35.58966677529471, 34.55411073139736, 36.22360304423741, 35.4740800176348, 39.87216118403843, 42.278541224343435, 45.294907093048096, 47.30847767421177, 46.44818993977138, 46.22887005124773, 47.21683440889631, 44.97256278991699, 44.06545114517212, 46.8694418498448, 48.62967416218349, 45.20111336026873, 46.352388177599224, 44.98335681642805, 42.55877249581473, 39.43472344534737, 38.81880732945034, 36.47097975867135, 35.60448728288923, 35.135504722595215, 33.824866022382466, 34.211613178253174, 37.08560698372977, 36.176935468401226, 36.587316921779085, 37.08110802514212, 38.1488550731114, 39.72270195824759, 44.565492153167725, 50.728822231292725, 49.49208804539272, 50.110637528555735, 14.434870413371495, 0.014778855722397566, 4.1829744918005805, 4.247224484171186, 5.58530205488205, 0.406281229108572, 3.3112191898482184, 51.18216092245919, 52.20318480900356, 47.133931977408274, 37.274490288325715, 22.859818288258143, 35.034550871167866, 45.60823263440813, 25.730541229248047, 0.22882654411452158, 0.03390694110255156, 0.033443226878132136, 0.06292771760906492, 0.02778984952185835, 0.026931935289342488, 0.01656290579454175, 0.045312029110001664, 0.049706913996487856, 0.049576465639152696, 0.058756593215678415, 0.1042374452309949, 0.1471470362905945, 0.08306992107204028, 0.17119350310947212, 0.20372646168938705, 0.12272558387901102, 0.14106931670435838, 0.10799346904137305, 0.17354515620640346, 0.13579870095210417, 0.24006335543734686, 0.21191286455307687, 0.1927000640758446, 0.1398318452494485, 13.535201157842364, 59.01711641039167, 58.279617241450715, 40.70701503753662, 51.746097564697266, 56.64302117483956, 34.90442500795637, 62.01190117427281, 50.594815799168174, 60.309912136622835, 25.89384126663208, 0.1123633702684726, 1.2685421705245972, 10.544442006519862, 6.8686816692352295, 2.3774813967091695, 33.37552254540579, 54.94687557220459, 53.95535373687744, 52.371192250932964, 47.665747097560335, 42.672306060791016, 38.204770701272146, 36.61368186133248, 40.06596381323678, 38.871603216443745, 44.178915228162495, 48.77630199704851, 48.791146823338096, 48.83532346997942, 48.76875972747803, 45.513549532209126, 43.88826860700335, 48.43228278841291, 51.20863355909075, 47.2139231136867, 48.352183955056326, 47.672848156520296, 43.470793042864116, 47.29459169932774, 44.04334545135498, 42.84057406016758, 42.93180043356759, 46.375397137233186, 43.22051545551845, 40.32092448643276, 35.209610734667095, 36.65273073741368, 37.275424821036204, 37.92156907490322, 36.88802800859724, 36.905106680733816, 35.17110729217529, 36.4118366922651, 37.0189459664481, 37.57112625667027, 36.750314712524414, 38.644376277923584, 37.571181842258994, 38.90140404020037, 38.381324427468435, 38.90511090414864, 37.071960721697124, 39.7664339201791, 36.500235148838584, 40.09605993543352, 37.69197627476284, 36.087949889046804, 34.73539618083409, 39.05417060852051, 40.09369059971401, 37.86757114955357, 42.72215938568115, 50.35340758732387, 51.567407267434255, 50.76391758237566, 51.75349044799805, 50.74878093174526, 43.385854789188926, 40.76149238858904, 39.70837129865374, 38.13911369868687, 37.47444207327706, 36.374226093292236, 38.126891817365376, 39.701523848942344, 38.73668657030378, 38.04199872698103, 38.001879828316824, 39.81711408070156, 34.85410267966134, 37.049570151737754, 38.20036554336548, 37.77697011402675, 37.96486677442278, 37.995424951825825, 38.184113706861226, 38.61706985746111, 37.79582405090332, 35.346872397831504, 38.09957844870431, 35.96926423481533, 39.32522678375244, 36.14102370398385, 41.65333536693028, 45.62703445979527, 48.25645167487008, 49.474967684064595, 48.009689876011436, 46.43443945475987, 47.72583164487566, 46.30196510042463, 45.313316345214844, 49.1948892729623, 49.89925595692226, 48.71446302958897, 50.57441936220442, 47.5149746622358, 44.872011934007915, 41.97117376327515, 41.62932586669922, 38.70033706937517, 39.347766739981516, 37.68349947248186, 34.889559337071006, 35.716207368033274, 39.0205135345459, 38.05714579990932, 38.28033583504813, 37.2811153956822, 40.659072467258994, 41.340020247868125, 47.24415125165667, 52.885772364480154, 52.6955897467477, 50.79327719552176, 17.345102548599243, 0.1478708160242864, 7.170673830168588, 8.417029534067426, 13.265033483505249, 1.266653454729489, 3.7047543014798845, 59.52575234004429, 54.45237922668457, 52.158768449510845, 42.18972934995379, 35.88327332905361, 43.10893780844552, 53.04963173185076, 31.81433527810233, 0.5153071231075695, 0.20398366717355593, 0.115078955622656, 0.11943432262965611, 0.16613801009953022, 0.1850749318088804, 0.21666007196264608, 0.09230575976627213, 0.10457673309636967, 0.11029953815575157, 0.23174812591501645], [0.05659148296607392, 0.05317141541412898, 0.021999004363481487, 0.07052984753889696, 0.016494390721033727, 0.023437881975301673, 0.010462030352625464, 0.08712059192891632, 0.039751875679939985, 0.02312885846809617, 0.0326963735611311, 0.042176810558885336, 0.02749794545317335, 0.03666225128940173, 3.567629648106439, 38.89010279519217, 43.47340556553432, 48.164033685411724, 61.28582831791469, 66.88406835283551, 43.91340718950544, 39.3105799811227, 49.88371283667428, 45.22078718457903, 35.05476318086897, 0.6707895142691476, 0.12936438407216752, 3.0020981771605353, 1.9488346491541182, 0.03163480891713074, 23.291713101523264, 51.12460551943098, 47.47617244720459, 47.34829780033657, 41.80834967749459, 37.48422861099243, 36.455995968409944, 36.24371460505894, 34.66583776473999, 35.78773212432861, 41.49334267207554, 43.88483967099871, 45.068315914699006, 45.15258019311087, 47.37238373075213, 45.28149012156895, 45.39469712121146, 44.027347224099294, 45.462115492139546, 43.75633273805891, 41.745322568076, 39.55985355377197, 39.8708792413984, 38.42165524618966, 38.70698996952602, 38.10090208053589, 38.30047171456473, 37.443036215645925, 36.71534790311541, 33.82623481750488, 33.77408858707973, 32.69150366101946, 33.573681695120676, 32.2873477935791, 35.111870425088064, 33.463059425354004, 34.96990483147757, 34.40447780064174, 34.53892544337681, 34.746096406664165, 35.2820074898856, 34.58854947771345, 35.86569786071777, 34.283808435712544, 35.662133012499126, 35.38493462971279, 35.16726841245379, 35.31891284670149, 36.47243193217686, 36.57512630735125, 34.49874748502459, 30.767172268458776, 31.17369052342006, 34.21779360089983, 32.957501547677175, 32.459624903542654, 36.161086627415244, 45.62385218484061, 47.19287007195609, 45.9126158441816, 45.193435600825715, 46.25067349842617, 40.58999695096697, 38.09357173102242, 35.503321511404856, 34.119011061532156, 33.62243720463344, 33.04082781927926, 33.141885893685476, 35.42349018369402, 35.01961919239589, 35.23915447507586, 35.30761160169329, 33.915665081569124, 34.35200500488281, 34.76163257871355, 34.482273306165425, 34.13195555550711, 34.36820125579834, 34.66727256774902, 33.23847280229841, 33.4197130884443, 34.524935245513916, 34.588973317827495, 33.57797915594918, 34.338313579559326, 33.410795075552805, 34.20389372961861, 38.19949007034302, 41.08859968185425, 43.517484937395366, 43.421443462371826, 45.02624109813145, 45.38258293696812, 45.15375443867275, 47.570084299360005, 45.463220255715505, 43.83898156029837, 46.22910976409912, 48.283323832920615, 46.840721470969065, 44.45649923597063, 43.475844383239746, 43.133006368364605, 40.46403653281075, 38.84832327706473, 35.13548387799944, 34.86039774758475, 32.34128318514143, 34.43084274019514, 33.468805585588726, 34.8439096723284, 36.79646464756557, 35.43377699170794, 34.880908829825266, 40.37634331839425, 45.09298896789551, 47.42096553530012, 48.53139189311436, 47.248334067208425, 10.094955222947256, 0.21941619978419372, 4.080488996846335, 3.3397765031882694, 2.9940717050007413, 0.36165862211159294, 5.132694227354867, 51.43270601545061, 45.42287901469639, 43.16927943910871, 23.200210537229264, 18.96041280882699, 28.579992260251725, 37.97122785023281, 11.603547232491628, 0.024541013674544435, 0.07839438731649093, 0.059163205325603485, 0.0337117299703615, 0.06134889554232359, 0.031848968139716556, 0.024702979983495812, 0.07192444056272507, 0.0537870468438736, 0.0893302344317947, 0.03644445851179106, 0.02103123870412154, 0.04084687513698425, 0.035767121107450554, 0.03861256788617798, 0.028722054857228483, 0.03451160740639482, 0.05788029238049473, 0.02561888860405556, 0.04617191618308425, 0.01596215463775609, 0.005655468092299998, 0.027654761681333184, 0.028044722541900616, 0.06608914118260145, 5.56836017540523, 46.02795941489083, 49.59167310169765, 44.56853893824986, 58.42085674830845, 63.4435635975429, 41.56788642065865, 47.06538452420916, 52.30502108165196, 49.970176219940186, 36.51554897853306, 0.8330888482076781, 0.3141900221151965, 6.744041408811297, 4.7050065483365735, 0.07823491801640817, 26.2220515864236, 53.05117770603725, 50.72447265897478, 48.095621722085134, 43.53949335643223, 38.025357791355674, 38.41913652420044, 35.980252810886924, 37.0933507510594, 37.95989881243025, 44.95955923625401, 45.345979826790945, 46.26281547546387, 46.861413206372944, 49.42375251225063, 45.16720267704555, 47.0968668120248, 45.63467747824532, 45.48260572978428, 46.5487060546875, 43.67593165806362, 41.122426986694336, 41.94237000601632, 40.759772709437776, 41.42269686290196, 40.01509952545166, 38.78469862256731, 39.93143974031721, 39.37436097008841, 35.0604224886213, 35.54484394618443, 35.871162618909565, 34.17998497826712, 34.768949031829834, 36.261453356061665, 35.118516377040315, 36.503434794289724, 34.77380582264492, 35.315084389277864, 36.023404598236084, 35.59829643794468, 36.15030302320208, 36.42575740814209, 36.288335936410085, 36.21247203009469, 37.39743866239275, 36.66642911093575, 36.67897408349173, 37.05509744371687, 37.21135548182896, 34.41262803758894, 32.8762388910566, 32.72416019439697, 35.68179294041225, 34.80266863959176, 35.788017000470845, 38.979185649326865, 47.00433765138899, 48.11699438095093, 47.20373010635376, 48.178201062338694, 46.813713823046, 41.697039536067415, 37.24319560187203, 37.54786368778774, 35.46151420048305, 34.87539196014404, 33.98150621141706, 34.88819749014718, 35.62006861822945, 35.97019181932722, 38.71673134395054, 36.29989773886544, 37.08261578423636, 36.47539186477661, 36.22314098903111, 35.90580286298479, 36.38748673030308, 35.52216155188424, 36.38089983803885, 35.18656355994088, 36.393663678850444, 35.77797685350691, 36.15642786026001, 35.35322652544294, 36.711991923195974, 35.894425187792095, 35.884256499154226, 40.84635421207973, 43.814930370875764, 45.23214748927525, 45.73152494430542, 48.74960701806204, 47.49008968898228, 47.38541855130877, 48.170537199292866, 45.42581115450178, 43.147302286965505, 47.620246819087434, 48.93801784515381, 48.63745961870466, 46.3751574243818, 44.20637798309326, 45.09486845561436, 43.01558528627668, 41.43015227999006, 38.05864313670567, 35.72641774586269, 34.09589440482003, 36.628967898232595, 36.193392276763916, 35.49090160642351, 40.168897901262554, 38.169928959437776, 36.63353286470686, 41.91368784223284, 46.075804710388184, 48.45202956880842, 51.609443868909565, 48.91532850265503, 11.437928233827863, 0.0729041365640504, 6.273495503834315, 7.227184397833688, 5.3007238166672845, 0.36181685647794176, 5.23591753414699, 56.346298354012625, 51.67690045492989, 48.45866162436349, 30.20972524370466, 24.012104068483623, 32.81523718152727, 46.61854934692383, 16.56141870362418, 0.032120782482836924, 0.07015770500791924, 0.015670284495822022, 0.029722273150192838, 0.04749000099088464, 0.03680789204580443, 0.034454488328525, 0.03282411456374185, 0.010930762343507792, 0.05425386197332825, 0.07803400379738637, 0.15056119380252703, 0.11025909068328993, 0.18841037925864967, 0.17914767057767936, 0.17808101352836403, 0.13660917031977857, 0.15744707573737415, 0.12760530917772225, 0.1620857718267611, 0.10243898816406727, 0.12266854622534343, 0.12445930870515959, 0.11311302254242556, 0.15756195171603135, 6.151469937392643, 53.141622407095774, 56.21687773295811, 55.94823258263724, 64.62963499341691, 68.85850320543561, 53.906973430088584, 48.65292283466884, 57.429602418627056, 53.562648500714985, 40.27675826208932, 1.4382984957524707, 0.7894537267940385, 8.982835241726466, 5.792498639651707, 0.23957801290920802, 28.928850889205933, 53.65540000370571, 52.429942744118826, 50.813305377960205, 45.146253858293804, 40.38294063295637, 41.098792689187185, 39.331542696271626, 38.16852542332241, 39.61432048252651, 46.70338685171944, 48.22406612123762, 48.867594378335134, 48.112978322165354, 51.04712268284389, 47.97268724441528, 48.79901565824236, 47.76341445105416, 47.505236761910574, 47.98594093322754, 44.88665526253836, 42.05251285008022, 44.69387401853289, 42.84881114959717, 43.912250314440044, 41.06310674122402, 41.14003372192383, 41.012242453438894, 41.39103739602225, 37.80973087038313, 37.261886256081716, 36.071854387010845, 36.30757202420916, 35.38611929757254, 37.75549670628139, 36.82577214922224, 38.83962413242885, 36.64267321995327, 37.8374194417681, 36.39413268225533, 37.47989640917097, 37.27689436503819, 38.33419132232666, 36.47750759124756, 38.26220103672573, 38.66326148169381, 38.471664905548096, 37.1343138558524, 39.46303040640694, 40.30307803835188, 38.025281361171174, 34.2874492917742, 35.327990668160574, 39.35973848615374, 36.140172549656455, 35.8756685256958, 40.14727163314819, 47.37263734000069, 49.006471497671946, 49.28578213282994, 48.236513819013325, 47.73750809260777, 44.03390632356916, 40.94651596886771, 38.812672070094514, 36.585027490343364, 37.43216575895037, 36.472866194588796, 37.07368387494768, 37.88997561591012, 37.50092165810721, 39.86760663986206, 38.04592445918492, 39.46523298536028, 37.86648028237479, 38.29184900011335, 38.277494021824424, 36.79200390407017, 36.34477615356445, 37.587649072919575, 36.6989084652492, 37.35476630074637, 39.2190374646868, 38.29893268857683, 38.277136189596995, 37.125607763017925, 37.96379327774048, 37.88360759190151, 43.23329666682652, 46.55896506990705, 48.09714337757656, 47.34859657287598, 48.851147992270334, 47.562142508370535, 49.663260391780305, 49.79620374952044, 47.80478055136544, 45.53517927442278, 48.27806404658726, 50.878948484148296, 50.82870258603777, 49.70964656557356, 45.51801722390311, 46.411739689963206, 43.84800727026803, 43.68226841517857, 39.896302700042725, 38.76970093590872, 36.04104954855782, 39.25971221923828, 38.15375702721732, 38.639995438711985, 42.047378131321494, 39.30847120285034, 38.609895842415945, 44.22383533205305, 49.30822828837803, 50.90524741581508, 54.06611149651663, 49.51086555208479, 14.359483327184405, 0.3208025358617306, 7.572547214371817, 13.788008757999965, 9.849117534501211, 0.5324029486094202, 6.233899891376495, 61.99995027269636, 54.93783596583775, 53.97070925576346, 33.558499881199424, 30.000257900782994, 39.585735593523296, 53.25169229507446, 22.34532502719334, 0.09823967742600612, 0.18477069027721882, 0.17001647555402347, 0.11142071549381528, 0.11267546245029994, 0.15918992007417337, 0.2062633005636079, 0.13180875219404697, 0.08926525791840893, 0.2234962172806263, 0.1490841316325324], [0.007879079086706042, 0.04282673854114754, 0.06059165046151195, 0.04308593552559614, 0.04805865404861314, 0.03569996649665492, 0.028877347774271454, 0.032715372541653256, 0.008210462019113558, 0.02871868932353599, 0.045731601238782914, 0.08639654756656714, 0.01921833901932197, 0.02590005994508309, 2.828199314219611, 33.91480350494385, 44.72723579406738, 35.29689400536673, 63.74904114859444, 68.20810317993164, 49.20442567552839, 38.85207877840315, 49.42977312632969, 44.72189610345023, 43.91724259512765, 5.618848826204028, 0.25232863585863796, 4.917218429701669, 4.3894892845835, 0.04873334516638091, 28.425665821347916, 52.35727153505598, 48.08100618634905, 46.65465218680245, 41.97170877456665, 37.68567425864083, 36.21789509909493, 35.82753835405622, 34.42851856776646, 39.08358580725533, 42.11930935723441, 43.78236068998064, 45.43249879564558, 46.193458557128906, 45.49036686761038, 46.03714493342808, 46.627060890197754, 45.63428143092564, 43.893368584769114, 40.552500997270855, 40.205917903355186, 40.80589485168457, 39.39143616812569, 37.7295868737357, 36.14708253315517, 37.34643888473511, 34.94035414287022, 37.2180882862636, 36.180381774902344, 33.688149792807444, 34.21903732844761, 33.04412473951067, 34.08224466868809, 32.912206241062705, 33.40605640411377, 33.562345709119526, 33.1945914540972, 34.61751651763916, 34.56472063064575, 34.66924933024815, 34.60994298117501, 37.19199085235596, 35.208255835941856, 35.62297296524048, 34.626952171325684, 34.63464035306658, 35.036239283425466, 34.120143617902485, 36.40866831370762, 37.27807903289795, 33.689084325517925, 32.87858043398176, 32.55966854095459, 33.61168834141323, 34.81851748057774, 35.87539059775216, 38.62781524658203, 44.6796475819179, 48.6767065184457, 47.76586716515677, 48.11780037198748, 46.544644832611084, 40.705663612910676, 38.38003553662981, 36.46842976978847, 35.16119221278599, 35.06218385696411, 33.633999007088796, 32.21424579620361, 35.09973192214966, 34.74755205426897, 34.793173926217214, 33.09848397118704, 34.484236172267366, 34.765947410038535, 35.04207924434117, 33.484539781297954, 33.47537858145577, 33.00489173616682, 34.74088525772095, 35.663248198372976, 33.924371174403596, 33.678776672908235, 32.611918994358604, 33.657966818128315, 33.904561860220774, 34.149930545261924, 32.850120612553184, 37.91985981804984, 40.1071457862854, 41.80639723369053, 42.48965181623186, 42.258964674813406, 44.23287146432059, 45.44795853751046, 44.07668290819441, 44.75852353232247, 48.02291577202933, 44.717855725969585, 43.145843165261404, 45.08172246388027, 46.11453744343349, 43.52644116537911, 44.99979625429426, 44.278590611049104, 42.49611364092146, 39.99405690601894, 38.71474763325283, 36.778451442718506, 36.53087670462472, 36.39152710778372, 35.38996512549264, 33.23961578096662, 37.67209053039551, 36.554267815181184, 39.840487820761545, 46.08702605111258, 48.48401212692261, 50.072307791028706, 41.94997828347342, 6.508521361010415, 0.12057783055518355, 4.110665457589286, 4.07627317735127, 3.1375797986984253, 0.2953719933118139, 10.024048856326512, 53.96800293241228, 44.35597964695522, 41.334173338753835, 27.158085107803345, 24.73419213294983, 31.66753373827253, 36.227768489292686, 5.966988316604069, 0.1013345027874623, 0.04701280766831977, 0.023156951514205763, 0.00814999352275793, 0.03079730671431337, 0.07187310938856431, 0.01113774096925876, 0.012143363793646651, 0.02868666247065578, 0.037622330843337944, 0.06723089848778077, 0.04321170199130263, 0.028063548495993018, 0.036905611266515086, 0.04877633714516248, 0.03692398938749518, 0.02835771208629012, 0.08364168182015419, 0.0437439177185297, 0.0168543348887137, 0.03794285382277199, 0.04701336745971015, 0.039689687945480855, 0.046950100854571374, 0.044622043812913556, 3.475938613925661, 42.12777573721749, 50.391817229134695, 42.36945145470755, 65.64336327144078, 68.54611914498466, 51.427192619868684, 39.77538667406355, 52.79797145298549, 48.02402400970459, 47.400551727839876, 5.275983452796936, 0.2595676545585905, 5.334399998188019, 5.840094668524606, 0.22237611881324224, 29.863486085619243, 54.014225823538645, 50.00425713402884, 49.21531697681972, 43.34574283872332, 39.0640092577253, 38.58322170802525, 37.60080896105085, 37.62540905816214, 40.927658557891846, 44.70671428952898, 45.11578253337315, 48.29341261727469, 46.49877977371216, 45.1563252721514, 47.58606168201992, 48.467134952545166, 47.599496023995535, 45.538021087646484, 43.41605860846383, 41.69087300981794, 40.79479857853481, 42.036636216299875, 39.001465048108784, 37.76664509092058, 38.7391288621085, 37.73562833241054, 38.63217524119786, 37.01749379294259, 34.948789255959646, 35.469911098480225, 35.493614877973286, 35.02890893391201, 34.1213630267552, 34.64209229605538, 35.84283481325422, 34.582754680088584, 35.3740884917123, 36.395584855760845, 35.93978302819388, 36.98874562127249, 38.62746088845389, 36.57632834570748, 37.4160007749285, 36.30650894982474, 35.90883575166975, 35.608201095036094, 36.881173610687256, 37.957314082554404, 37.17603778839111, 34.7562963621957, 35.55561712809971, 34.418732030051096, 35.12225798198155, 36.55572346278599, 36.289781161717, 39.580712045942036, 46.71788426807949, 50.25099114009312, 48.373528821127756, 48.35777725492205, 47.90917723519461, 41.95474822180611, 41.20373828070504, 39.030525888715474, 36.8005884034293, 36.30880880355835, 35.42194768360683, 33.65109504972185, 36.00686093739101, 36.070534229278564, 37.00055408477783, 36.74699694769723, 35.776729651859824, 36.2536609513419, 37.54373298372541, 35.13509825297764, 35.80871220997402, 34.884285654340474, 35.41856738499233, 37.47904525484358, 34.7721278326852, 35.5470187323434, 34.96675729751587, 34.202566623687744, 35.199261392865864, 34.66675840105329, 35.07542017527989, 39.912217548915315, 42.68765115737915, 42.71845946993147, 44.97779825755528, 44.76384585244315, 45.765838623046875, 46.40475675037929, 46.24898508616856, 45.39372089930943, 47.49431071962629, 46.90759093420846, 44.73228018624442, 47.16240916933332, 48.67663703645979, 45.050264494759695, 47.08507571901594, 46.22892216273716, 43.91249697549002, 41.93450117111206, 41.091709000723704, 38.37477227619716, 38.00464173725673, 37.294952733176096, 37.62671184539795, 35.68523924691336, 38.39837530681065, 39.0817688533238, 42.547776971544536, 47.789001192365376, 50.75763988494873, 52.16332994188581, 43.60506350653512, 7.665188414709909, 0.2561350001820496, 8.182797074317932, 6.409933371203286, 4.082970806530543, 0.12877276938940796, 10.342741881098066, 59.65455804552351, 48.16458606719971, 48.35811424255371, 30.349630696432932, 24.65196541377476, 35.87657526561192, 42.580919878823416, 8.41152048110962, 0.0890950406236308, 0.05505640944465995, 0.08687563400183405, 0.04262891165646059, 0.12368466598646981, 0.03577810658940247, 0.03456611751711794, 0.05255371445257749, 0.04435116245544382, 0.020597987309364334, 0.017285779683983753, 0.09306573934320893, 0.1427221465855837, 0.11165517648415905, 0.14861881945814404, 0.09592726400920323, 0.14407195629818098, 0.1676443578409297, 0.0916570463616933, 0.13027945639831678, 0.1872608188007559, 0.12551778262215002, 0.16705771003450665, 0.14114563832325594, 0.12368052692285605, 4.3079456601824075, 49.150163718632285, 55.64437396185738, 46.32148606436593, 70.47727366856166, 68.25895009722028, 55.196263790130615, 46.214098181043354, 57.6308639390128, 51.94778639929635, 51.75612728936331, 7.206045372145517, 0.5553979575634003, 8.420794589178902, 7.1315454840660095, 0.5490882875663894, 32.722360610961914, 55.843210560934885, 54.02394635336739, 51.415137495313374, 46.520093372889924, 38.87536219188145, 41.04649359839303, 40.27558749062674, 38.38655989510672, 43.06239530018398, 45.956309591020855, 47.65146507535662, 50.2228022984096, 50.78151389530727, 46.8173268863133, 48.84567975997925, 50.85224655696324, 49.41590452194214, 47.782921518598286, 44.748743942805696, 43.43066719600132, 44.83452640260969, 44.38415111814226, 40.6352470942906, 39.34542867115566, 40.76712390354702, 38.88975191116333, 42.37926231111799, 38.907643522535054, 37.28233480453491, 36.814689772469656, 36.65306772504534, 37.533845697130474, 35.499986376081196, 35.78491462979998, 36.96875217982701, 36.53438207081386, 36.48250682013375, 38.25487068721226, 38.30198294775826, 38.50183745792934, 40.59321049281529, 39.11664186205183, 39.323659964970176, 37.77168600899832, 37.75830030441284, 38.397934096200125, 38.963065828595845, 40.40513317925589, 41.37897879736764, 37.92578663144793, 37.17593356541225, 35.90797764914376, 36.71038341522217, 38.753900732312886, 39.25583165032523, 41.86786099842617, 47.51141371045794, 52.9805770601545, 50.44150032315935, 50.34644896643502, 50.28786870411464, 44.55925267083304, 43.71950381142752, 40.98447397777012, 39.512991428375244, 37.87748622894287, 37.9538573537554, 36.068144048963276, 39.54505041667393, 37.946339402879985, 38.86188268661499, 36.35834945951189, 37.68067850385393, 37.06670093536377, 39.7562061718532, 35.68219593593052, 37.241819858551025, 36.430537768772666, 38.400369439806255, 39.71458993639265, 36.89917639323643, 36.793869495391846, 35.96779121671404, 35.92229788643973, 37.37813656670706, 36.94938407625471, 36.46426085063389, 41.53254788262503, 43.69207232339041, 45.177510329655235, 47.29557834352766, 46.42253371647426, 49.448349135262625, 49.44852631432669, 48.64072527204241, 47.29305614743914, 51.214786188943044, 47.47345570155552, 46.479345662253245, 48.18471499851772, 51.122243131910054, 47.700185843876426, 49.6464388029916, 48.461096967969624, 46.33206122262137, 44.25029059818813, 43.882960183279856, 40.42328534807478, 40.75153909410749, 40.13390677315848, 39.83381060191563, 37.15745483125959, 41.13486426217215, 40.62345947538103, 43.72041402544294, 49.70248992102486, 53.871329171316965, 53.51034593582153, 45.08721154076712, 9.352539334978376, 0.4562285989522934, 12.786617006574359, 11.882362808500018, 11.556609545435224, 0.40793484609041897, 12.844711763518196, 64.67190783364433, 52.21536152703421, 52.97410133906773, 37.55194575445992, 35.64071519034249, 42.77309315545218, 52.223855699811665, 12.578012977327619, 0.2701252523277487, 0.0907807048144085, 0.18193737231194973, 0.1206409071705171, 0.2517729699611664, 0.12940263987651893, 0.1669237943632262, 0.140785458364657, 0.13768538114215645, 0.08228113089821168, 0.10598866947527442], [0.0491237843941365, 0.05146817716636828, 0.0425181577780417, 0.06449011234300477, 0.09058346825518779, 0.06589515480612006, 0.1247359745736633, 0.06489256503326551, 0.02118393961739327, 0.01265096481490348, 0.058423391809420924, 0.039360903802194765, 0.011288805764966776, 0.034949116608394046, 0.6071988950882639, 24.14619561604091, 45.07448591504778, 32.678559167044504, 34.218825408390586, 51.86813225064959, 53.371781485421316, 43.097445487976074, 48.02224179676601, 44.20595761707851, 45.858989647456575, 12.4393938098635, 0.2307734510728291, 4.851443307740348, 2.8450022297246114, 0.14293443305151804, 24.411785296031407, 51.26379878180367, 45.467875548771445, 46.93273993900844, 39.2676157951355, 37.22644696916853, 36.69061231613159, 35.06923280443464, 37.34697389602661, 41.342698778424946, 43.266641071864534, 46.19319452558245, 45.04832942145211, 46.31779657091413, 46.507805483681814, 44.91016101837158, 45.48693445750645, 44.826605456215994, 43.33223206656319, 41.470177377973286, 40.26830577850342, 38.64824295043945, 37.6574923651559, 38.26447657176426, 37.4410594531468, 37.28061512538365, 34.32778011049543, 35.56924254553658, 33.69552183151245, 33.486221245356965, 32.904882839747835, 35.06545645850045, 33.98967729296003, 34.07438278198242, 33.667895793914795, 34.318813460213796, 34.011366094861714, 34.82444429397583, 34.97493185315813, 34.94203560692923, 34.39711618423462, 35.0027038029262, 33.97084072657994, 34.84489631652832, 36.14533853530884, 34.239826338631765, 33.7249960899353, 36.05330269677298, 35.569864409310476, 37.2441405568804, 33.79295294625418, 32.35575975690569, 32.66552087238857, 33.52130617414202, 33.55353886740548, 36.349949087415425, 37.48147712435041, 46.72045857565743, 47.783605916159495, 48.46893801007952, 46.890533106667654, 46.504605838230674, 41.366253171648296, 39.29550239018032, 39.31068767820086, 37.64997441428048, 36.415984766823904, 34.622811044965474, 32.833205223083496, 32.7772479057312, 34.20102412360055, 33.91995212009975, 34.90829515457153, 35.82144825799124, 34.12591757093157, 34.91552822930472, 34.28011546816145, 34.21733501979283, 34.01494789123535, 34.23937470572335, 35.35152074268886, 34.20319890975952, 35.01572125298636, 33.22843265533447, 31.87434686933245, 34.7502236366272, 33.8561190196446, 33.249221665518625, 32.53081962040493, 40.41813325881958, 39.84140845707485, 40.47064079557146, 39.783255508967805, 39.56725685937064, 39.99509913580758, 41.92415182931082, 43.62662724086216, 44.872338499341694, 46.814155033656526, 44.64537559236799, 44.46243299756731, 46.25212914603097, 46.22314126150948, 45.93397113255092, 44.35943637575422, 43.67160293034145, 43.538725580487935, 43.94728313173567, 41.737936632973806, 42.2698073387146, 39.89091784613473, 39.16252776554653, 35.790803228105815, 33.969829763684956, 36.07420287813459, 41.029136998312815, 45.97548314503261, 50.43376350402832, 48.93838609967913, 38.311797278267996, 3.9235991069248746, 0.13100419965173515, 6.8163491402353555, 5.580095248562949, 3.2036682409899573, 0.2955241751457964, 14.14179539680481, 54.276589802333284, 42.58828844342913, 37.70314202989851, 20.412153788975306, 20.991105488368444, 33.92219986234392, 35.38627910614014, 2.059284733874457, 0.037051442012723, 0.1005344217909234, 0.023341153415718248, 0.024356136630688394, 0.09264421981892415, 0.018561349183853184, 0.01805081095413438, 0.069646659573274, 0.03924598032608628, 0.00971066817042551, 0.02441832436514752, 0.0025096226225806667, 0.03424794566152351, 0.017223023676446507, 0.06106008389698608, 0.033978859029178105, 0.034598252935601134, 0.07990193606487342, 0.025693320502926196, 0.026838755467906594, 0.05054702855912702, 0.019862674176692963, 0.034936841909906695, 0.03462817972259862, 0.08652223260807139, 0.8391649935926709, 30.644196101597377, 52.07139137813023, 34.79163837432861, 47.655654839106965, 60.18324647630964, 55.79676532745361, 48.45700100490025, 52.08358546665737, 49.77338586534773, 48.92993014199393, 12.57266546998705, 0.3538634218275547, 2.5388239962714056, 4.201928309031895, 0.1975624053073781, 28.29532630102975, 53.16440902437483, 47.920627866472515, 49.5195438521249, 41.75655780519758, 39.00526918683733, 37.5022418158395, 37.220613956451416, 37.99328490665981, 43.54713984898159, 44.44851228169033, 48.05211557660784, 46.410930224827354, 47.707509245191304, 47.65778793607439, 46.038280963897705, 47.7610763822283, 46.521715777260916, 43.27669858932495, 43.844797202519004, 41.61205611910139, 40.34528487069266, 40.32047632762364, 38.88071230479649, 40.233137471335276, 37.61448648997715, 36.559207984379356, 38.140670095171245, 37.39797714778355, 34.21925272260393, 35.12864685058594, 36.41484873635428, 35.535564626966206, 35.07463155473982, 35.45615019117083, 35.92683506011963, 34.9778778893607, 36.45223004477364, 35.56103672300066, 37.119684423719136, 35.95135872704642, 36.248908383505686, 35.127048764910015, 37.03212322507586, 35.75944948196411, 36.401845182691304, 34.96868542262486, 36.06370415006365, 37.605835982731406, 37.81569937297276, 35.73999800000872, 34.771360056740896, 33.40490995134626, 37.00524064472744, 35.57375887462071, 37.94968148640224, 39.74669408798218, 48.65160615103585, 50.512246881212505, 50.787082876477925, 48.9816768510001, 46.939712456294465, 43.47417334147862, 41.484254428318565, 39.77223219190325, 38.79218183244978, 37.36203064237322, 37.6853164264134, 35.32208469935826, 35.726428168160574, 36.821721349443706, 35.43842881066458, 35.65951006753104, 36.534684317452566, 34.71164723805019, 37.121688979012625, 36.04363775253296, 36.436085905347554, 36.26920059749058, 36.06109510149275, 37.69475555419922, 36.700433594839915, 35.90270396641323, 35.477543694632395, 33.340725966862266, 35.31675543103899, 34.54506765093122, 34.469436509268625, 36.18507528305054, 41.34707266943795, 42.52065815244402, 43.627151829855784, 42.40504012789045, 42.78620788029262, 43.14667347499302, 43.63518394742693, 44.63986567088536, 45.56070000784737, 47.44159126281738, 46.282339913504465, 46.07731941768101, 46.5476290839059, 47.69671174458095, 48.015863350459504, 45.51633923394339, 45.25379807608468, 44.42116069793701, 45.575451033455984, 43.81725801740374, 43.33048459461757, 41.79176432745797, 39.809425898960654, 37.69053452355521, 36.0369223185948, 37.14942271368844, 42.95984336308071, 48.14036117281233, 51.673610482897075, 51.12625224249703, 39.89099080221993, 5.745742474283491, 0.3130023958427565, 11.38520096029554, 6.96278807095119, 4.861834338733128, 0.15842715171830996, 15.162711586271014, 60.7751704624721, 46.559823172433035, 44.38637454169137, 27.659729412623815, 26.775711842945643, 39.07396255220686, 42.365459714617046, 3.3207540724958693, 0.06656360000904117, 0.03462091600522399, 0.03023022785782814, 0.01678886134842677, 0.0526736455171236, 0.07267319717045341, 0.044269846818808994, 0.02584078991120415, 0.022883057461253235, 0.05864725408277341, 0.03211777996537941, 0.10246426359351192, 0.16321349702775478, 0.16840118223002978, 0.15919359773397446, 0.17764848816607678, 0.15096068808010646, 0.16508674222443784, 0.10838606261781283, 0.11724629146712166, 0.1336837208696774, 0.10466765000351838, 0.0901032147396888, 0.08743521504636322, 0.16079004135515007, 0.9085282630154065, 34.825031416756765, 58.53967094421387, 44.167843273707796, 44.6760379927499, 59.465532302856445, 61.2526923588344, 51.802211216517854, 58.92543492998396, 53.37422725132534, 53.54934964861189, 15.380895444325038, 0.38762629298227175, 11.237453596932546, 8.057626145226614, 0.5702773077147347, 29.96648965563093, 53.5242805480957, 49.87878656387329, 51.625667912619456, 42.88759252003261, 40.45122405460903, 39.77416379111153, 38.77949442182268, 41.44662298474993, 46.82198217936924, 46.57697827475411, 50.088854925973074, 48.496855872017996, 50.22475821631295, 49.317698683057515, 48.06930194582258, 49.773316383361816, 48.428965023585725, 46.32602323804583, 45.96651996885027, 44.50401101793562, 42.3628055027553, 42.13157640184675, 41.1767167363848, 42.250140462602886, 41.44928067071097, 38.48796190534319, 39.96955408368792, 38.643466063908164, 36.85586132322039, 37.00907605034964, 39.200742857796804, 38.596159253801616, 37.5139217376709, 36.87010860443115, 38.0365617615836, 37.385237625667024, 38.67449671881539, 37.50974587031773, 37.74077694756644, 36.64393779209682, 38.010704040527344, 36.8620000566755, 38.29961013793945, 38.56362778799874, 37.9945946420942, 37.401489462171284, 38.293214321136475, 40.1314297403608, 40.67407362801688, 38.04872110911778, 37.6100743838719, 36.523261478969026, 38.74947820390974, 39.41566801071167, 38.99237680435181, 41.754115513392854, 50.094917229243684, 51.029116426195415, 52.57725150244576, 50.17366116387503, 48.82564115524292, 46.59537363052368, 42.5416590826852, 41.67513534000942, 40.87626620701381, 39.83215345655169, 39.74494661603655, 37.8312737601144, 37.24282039914812, 37.90622050421578, 38.30121864591326, 36.964583260672434, 38.7716394833156, 37.48784862245832, 39.811176845005576, 37.94317102432251, 37.77002886363438, 38.32260867527553, 38.374001026153564, 40.00529214314052, 37.4613481930324, 38.80874286379133, 36.64184985842024, 34.846668107169016, 37.23983267375401, 37.4897836957659, 35.929506642477854, 36.91669627598354, 43.73202446528843, 44.48547322409493, 45.67223596572876, 44.36935840334211, 43.65113353729248, 44.679713589804514, 45.922131402151926, 47.81258337838309, 48.48799344471523, 50.308466638837544, 47.34569917406355, 46.259358746664866, 49.08027526310512, 49.306411334446494, 49.257499490465435, 46.78389910289219, 47.492194993155344, 47.72218036651611, 48.00693144117083, 46.37068278448922, 45.7708864893232, 44.05727311543056, 43.375359535217285, 40.255885873522075, 37.76666593551636, 38.99942922592163, 46.070016860961914, 49.63301140921456, 54.13783427647182, 51.37573078700474, 42.64389140265328, 7.338128021785191, 0.7326305444751466, 17.772229160581315, 13.060415983200073, 9.943308183125087, 0.4296785279044083, 18.18292154584612, 66.49344757625035, 50.56063066210066, 49.86506734575544, 29.17320340020316, 30.05471440723964, 43.419914858681814, 48.943545137132915, 4.3694997514997205, 0.2518288269639015, 0.1821335774979421, 0.046549972146749496, 0.16663724902485097, 0.12301207493458476, 0.19948287654135907, 0.09804913800741945, 0.17575579615575926, 0.08543031370001179, 0.12817953979330404, 0.10095142905733415], [0.026856300687151294, 0.033049188022102625, 0.05227635308567967, 0.04226512528423752, 0.03503719723916479, 0.021267039801127145, 0.03982121178082057, 0.02538870068799172, 0.0463182829719569, 0.026460034539923072, 0.07016749626823834, 0.03849462153656142, 0.07447896205953189, 0.07560583909175225, 0.03126585210806557, 9.405443787574768, 47.94786133084978, 37.85565846306937, 24.238736936024257, 33.085897309439524, 47.67172949654715, 40.5877492087228, 49.9662435395377, 41.05515105383736, 49.376626355307444, 17.52441818373544, 0.031340026163629124, 0.5983741943325315, 2.2769654989242554, 0.06457859330943652, 17.18293333053589, 54.16310487474714, 46.53651544025966, 48.998658248356406, 42.430706773485454, 36.83446087156023, 35.15996585573469, 35.82859795434134, 38.83962760652815, 43.82534919466291, 45.089685099465505, 45.342283385140554, 46.43090976987566, 45.40633882795061, 43.86072594778878, 45.50532981327602, 44.198088782174246, 42.87750026157924, 41.799855504717144, 39.85758038929531, 38.46141978672573, 39.40474544252668, 38.17062030519758, 36.19457694462368, 34.30950287410191, 34.45217718396868, 35.389054911477224, 35.22544567925589, 34.19179344177246, 34.46248483657837, 34.024880341121126, 34.464239256722585, 33.68260860443115, 35.36910663332258, 32.74853100095476, 34.73250225612095, 33.488392557416645, 35.488372462136404, 36.80508736201695, 36.474373953683035, 37.03982530321394, 35.94643592834473, 36.04268932342529, 35.157860551561626, 35.78753410066877, 35.24320527485439, 35.15508474622454, 35.31101621900286, 35.48513460159302, 34.584488255637034, 34.5496187210083, 33.63789347239903, 31.819233758108957, 33.10510213034493, 35.37588807514736, 37.05813380650112, 41.149927956717356, 44.790044035230366, 46.42525046212332, 47.87324115208217, 47.75973885399954, 48.04332957948957, 42.25257928030831, 42.92514058521816, 42.70732150759016, 41.50305625370571, 40.60134335926601, 36.25584963389805, 34.616748741694856, 33.525169372558594, 33.94500732421875, 34.14182547160557, 35.1100743157523, 33.80519914627075, 34.99143729891096, 34.511956010546, 33.904759883880615, 34.38639858790806, 34.56833716801235, 34.237484795706614, 34.345053332192556, 35.44919504438128, 32.99693604878017, 32.59891891479492, 32.93227958679199, 35.31734602791922, 32.34948900767735, 34.26743153163365, 32.98192793982369, 35.47152655465262, 38.43125070844378, 36.52370963777815, 37.87976523808071, 36.568424769810264, 36.84822525296892, 37.02611998149327, 38.969444274902344, 42.506605420793804, 43.305530139378135, 45.2490177154541, 45.06211117335728, 45.64892475945609, 43.651790142059326, 45.01033319745745, 46.024398463112966, 46.27035774503435, 46.27713223866054, 45.809125900268555, 45.87066956928798, 42.63509150913784, 44.444221769060405, 42.848199708121165, 40.53917782647269, 38.66878877367292, 35.53552293777466, 39.08367265973772, 45.047975063323975, 49.09785073144095, 51.392121587480815, 36.6614750453404, 2.6985064106328145, 0.04820121764870627, 7.8640102488654, 4.336567895753043, 1.6459273887532098, 0.021257942342864614, 20.57542255946568, 52.54087768282209, 38.48076357160296, 34.72834723336356, 26.909369128090994, 21.844401597976685, 37.086395604269846, 24.21263255391802, 0.17617054390055792, 0.02701046214705067, 0.09464863940541234, 0.10681714037699358, 0.16855516896716186, 0.018443311232009103, 0.0737775671961052, 0.013865155733323522, 0.03272102813103369, 0.014062054721372468, 0.06903131652091231, 0.04327073793060013, 0.06965647118964366, 0.004045482184405306, 0.04201026074588299, 0.013856166840663977, 0.06793340614863805, 0.044697880279272795, 0.024978287085624676, 0.009969105195653225, 0.024448454712650607, 0.017739638187257305, 0.04570272278838924, 0.011108215366091048, 0.007137011986092797, 0.018161795534459606, 0.057857303614062924, 14.077876312392098, 55.240204198019846, 43.00889069693429, 28.699178184781754, 45.84472499574934, 52.87245266778128, 45.83957290649414, 53.15503937857491, 46.384898798806326, 52.60639224733625, 18.75822717802865, 0.09835059076015439, 0.8737174080950874, 5.254708502973829, 0.0370397474616766, 19.59915896824428, 54.10206842422485, 48.38068893977574, 51.0468829699925, 44.36740943363735, 39.05236407688686, 37.58992460795811, 38.342188698904856, 40.08033268792288, 45.716343130384175, 46.27819878714425, 47.432013171059744, 48.54026821681431, 46.49385697501046, 45.151451110839844, 46.868510791233604, 47.651916708265034, 44.44516672406878, 43.71526888438633, 42.36820077896118, 40.344475405556814, 40.39506523949759, 40.71953569139753, 37.45361137390137, 37.142731598445344, 37.03015341077532, 36.33881459917341, 36.64620985303606, 35.29565027781895, 36.70156267711094, 35.07803617204939, 36.20917510986328, 33.75673198699951, 36.05018990380423, 35.11715453011649, 35.8433906691415, 34.69403008052281, 35.263848372868125, 37.31472035816738, 36.413886410849436, 37.82997097287859, 37.07814114434378, 37.69271625791277, 36.07882343019758, 36.97238261359078, 36.5159797668457, 37.09155116762434, 36.49318620136806, 36.78640365600586, 37.07510825565883, 36.63821595055716, 34.405325480869834, 34.05340269633702, 35.2499589238848, 37.0284024647304, 37.618672779628206, 42.820733479091096, 47.020790985652376, 49.663190909794395, 48.51978145326887, 48.66377592086792, 48.358503341674805, 43.57309831891741, 43.547188486371724, 43.40910346167428, 44.51503780909947, 41.39464351109096, 37.92786761692592, 37.169770513262065, 35.332503523145405, 35.623250893184114, 35.56626871653965, 36.11183432170323, 36.5991427557809, 35.605922085898264, 36.145130089351106, 36.38727133614676, 35.7354017666408, 35.92901679447719, 36.404117243630544, 34.91575057165963, 37.24492917742048, 34.752888270786826, 33.39271238871983, 34.06040300641741, 36.90841402326311, 34.3185841696603, 35.362412043980186, 35.41664273398263, 38.290615694863455, 40.5426276070731, 39.286417620522634, 39.30155774525234, 38.27055277143206, 36.77590145383562, 39.29756253106253, 41.64515733718872, 44.62185246603829, 44.8784042767116, 48.601943901606965, 46.187847886766704, 46.17005007607596, 45.09529576982771, 45.63326351983206, 47.14840507507324, 47.63976778302874, 47.952725069863455, 48.1806572505406, 46.769940171922954, 44.33457572119576, 45.35338660648891, 45.78822571890694, 41.83790384020124, 39.2345666885376, 36.23843050003052, 41.50271579197475, 47.28737252099173, 52.45838172095162, 50.68221024104527, 40.01328604561942, 3.528990932873317, 0.5146392275180135, 9.225859778267996, 7.45867839881352, 3.5416409969329834, 0.0322031803828265, 21.861990962709697, 57.85372740881783, 43.67122425351824, 40.910079615456716, 23.06710910797119, 21.490625381469727, 42.81272915431431, 29.583449363708496, 0.36719758489302223, 0.05089336640334555, 0.033814399104033194, 0.013725888965252255, 0.03916201161752854, 0.03449729371017643, 0.06365685098405395, 0.0178641459705042, 0.01173223094415984, 0.04154611565172672, 0.020074198987068873, 0.057877374679914544, 0.09883275095905576, 0.10004451272210904, 0.14446933354650224, 0.06730629729905299, 0.16678462683090142, 0.11608560303492205, 0.04974794500906553, 0.07440912045006241, 0.15993571148387023, 0.08335675139512334, 0.12108295916446618, 0.13207411366914, 0.24135846165674074, 0.15128263937575476, 0.2791606517774718, 15.300155639648438, 62.89915139334542, 48.98816646848406, 34.43567521231515, 43.01862859725952, 55.37859146935599, 49.38494682312012, 58.818578583853586, 50.3671407018389, 58.65646321432931, 22.29050200326102, 0.09607364436877625, 2.376101527895246, 5.116134064538138, 0.28021981780018124, 21.131163801465714, 57.478892939431326, 50.36546966007778, 53.64289672034127, 46.58072335379464, 40.79546907969883, 40.01587077549526, 40.05735499518258, 41.99107687813895, 46.60599742616926, 48.8703875541687, 48.469671045030864, 50.13206924710955, 47.431568486349924, 46.91637693132673, 48.822514465876985, 48.80689491544451, 46.81012855257307, 47.08911957059588, 43.5100052016122, 42.75079638617379, 43.878318786621094, 42.77851969855172, 40.751625946589876, 38.553959369659424, 38.75086784362793, 38.942724977220806, 38.43324831553868, 36.73359039851597, 40.267617906842915, 37.77979803085327, 38.411886078970774, 35.76640115465437, 38.41819504329136, 36.23783642905099, 37.643661975860596, 36.59543241773333, 36.964909826006206, 40.85410840170724, 38.280162130083355, 40.1429637500218, 38.30817379270281, 40.26786456789289, 37.44634355817522, 38.744895866939, 39.166554246629985, 39.06511402130127, 38.07840033939907, 38.22485794339861, 38.184096336364746, 39.45027003969465, 36.45573888506208, 36.04805333273751, 36.89930840900966, 40.59377677100045, 39.57717193875994, 46.08946834291731, 47.94995968682425, 51.48469591140747, 49.556612491607666, 51.37886789866856, 50.247676849365234, 46.63948426927839, 46.739910057612825, 45.88895027978079, 45.734186104365754, 43.07099717003958, 40.46813596997942, 38.695518493652344, 37.37262317112514, 37.80848714283535, 36.738745961870464, 38.808617796216694, 38.2059588432312, 38.00000034059797, 36.6234301839556, 37.04250383377075, 37.916566371917725, 37.61517783573696, 37.702144963400706, 36.72468628202166, 38.94672366550991, 36.70119442258562, 35.422840527125764, 36.075661999838694, 39.88696084703718, 34.80420766557966, 37.9345691544669, 36.86260454995291, 39.34202057974679, 42.418703760419575, 39.933802127838135, 42.224001339503694, 40.97363131386893, 39.41968059539795, 40.63060917173113, 42.13726002829415, 46.80173512867519, 47.96127135413033, 49.45195525033133, 47.87397418703352, 47.625933919634136, 46.86001314435686, 46.81865051814488, 48.96075235094343, 48.48139613015311, 50.785220759255544, 50.28468990325928, 49.041834354400635, 46.69906507219587, 47.799847330365864, 47.23238100324358, 44.88056516647339, 41.524720736912315, 39.312247548784526, 43.83903019768851, 49.53196028300694, 54.86787802832467, 52.7563065801348, 40.2036006791251, 4.742749163082667, 0.5202363271798406, 18.64193344116211, 15.64422001157488, 6.44230763401304, 0.10410833358764648, 25.778693982533046, 62.47368540082659, 47.34203747340611, 45.02192626680647, 38.12193080357143, 30.261336462838308, 49.14239910670689, 36.863198620932444, 0.8514162961925779, 0.14693975741309778, 0.16732159230325902, 0.33014137617179323, 0.21774756003703388, 0.15089762503547327, 0.15224351281566278, 0.07592871319502592, 0.07572908819253955, 0.11667408288589545, 0.15548464389783995, 0.09983482504529612], [0.04511440917849541, 0.016767828459186212, 0.029592058887439113, 0.04180417609001909, 0.02322803993177201, 0.045608097687363625, 0.04950428647654397, 0.03604406178263681, 0.011979911493004432, 0.017448200611397624, 0.04138675491724696, 0.04028699892972197, 0.03558403539604374, 0.023441172870142118, 0.05073372746950813, 1.4105867998940604, 33.06514304024832, 46.11604520252773, 32.457832268306184, 27.22016031401498, 41.226486682891846, 34.935678005218506, 48.33419506890433, 45.14752885273525, 47.17523206983294, 29.83907358986991, 0.2601756219352995, 0.9145492570740836, 6.746740783963885, 0.07841339308236327, 7.4351683003561835, 47.9828211920602, 50.27155780792236, 46.79759400231497, 42.1459070614406, 38.833666052137104, 35.62124981198992, 37.90886776787894, 43.09591688428606, 43.99193920407976, 46.63915422984532, 46.86681890487671, 44.60946730204991, 41.51382943562099, 44.38230984551566, 46.59230252674648, 44.431127888815745, 42.3202269417899, 41.37129061562674, 37.158681188310894, 36.940417425973074, 34.9704259463719, 32.8757038797651, 36.09403998511178, 35.135789598737446, 33.75710718972342, 33.77392530441284, 33.25976208278111, 33.50705541883196, 33.050593512398855, 33.98536940983364, 32.82954004832676, 34.29672513689314, 35.34785556793213, 35.87853813171387, 35.18008436475481, 35.07898112705776, 35.55058315822056, 35.07934243338448, 36.56320667266846, 38.47223465783255, 38.399358476911274, 35.766939640045166, 36.00665943963187, 35.63030331475394, 34.75096361977713, 33.42690099988665, 34.25976766858782, 34.09294836861746, 34.5015788759504, 33.044889041355674, 33.36396074295044, 33.93564462661743, 34.13728482382638, 38.28356327329363, 40.49568557739258, 43.78511912482125, 46.97261912482125, 49.860651765550884, 47.435914584568565, 48.59379366465977, 47.751724106924875, 43.74736956187657, 45.174150875636506, 42.856534072331016, 46.996135302952354, 45.6228585924421, 41.23739535467965, 34.92932735170637, 34.45387601852417, 34.73043516704014, 34.56750685828072, 33.761356013161794, 35.213831765311106, 36.02363736288888, 35.083452292851035, 33.91909401757376, 33.88537440981184, 34.52874285834176, 33.84772212164742, 34.60362706865583, 34.14601870945522, 34.385766301836284, 34.35412073135376, 33.953209672655376, 32.38402155467442, 32.657488754817415, 33.57282011849539, 32.70524719783238, 33.04477787017822, 37.28876536233084, 36.827721118927, 37.978933402470176, 36.87957205091204, 35.47281544549124, 34.114414828164236, 35.304609979902, 37.47629724230085, 39.95537281036377, 42.533943108149934, 41.95850024904524, 46.11261626652309, 43.862035683223176, 43.503300189971924, 44.49301896776472, 45.03151478086199, 45.71068729673113, 46.85694898877825, 48.160973003932405, 48.66938311713082, 44.631659848349436, 46.42178331102644, 47.13126386914934, 42.81252070835659, 38.996611731392996, 37.54180833271572, 46.261748926980154, 47.80900158200945, 51.20902960641043, 31.0404622895377, 0.9643547045333045, 7.372100370270865, 10.675131542342049, 5.3330906970160346, 4.2056616629873, 0.30010656639933586, 24.193146330969675, 52.44614941733224, 34.420145988464355, 32.5087764603751, 33.21945905685425, 33.92073726654053, 36.503837789808, 14.07020115852356, 0.20011741534939834, 0.02767981489055923, 0.10179445453520332, 0.041084813619298596, 0.06313713387187038, 0.059046789072453976, 0.06466315912881068, 0.053533159395945926, 0.019348122412338853, 0.056543958373367786, 0.015122155426070094, 0.021804178299914514, 0.05441290718902435, 0.013487258377218885, 0.08436506800353527, 0.05442515474611095, 0.044013706634619405, 0.06006138891513858, 0.013811827969870396, 0.02725304350523012, 0.006282575669631894, 0.05652049123974783, 0.04240320037518229, 0.01352714266561504, 0.05586641740852168, 0.03708089721788253, 0.08723095564969949, 2.6033527851104736, 42.563295773097444, 49.360437052590505, 32.31703049795968, 29.346901416778564, 50.55371720450265, 43.1217885017395, 55.011872495923726, 50.33438341958182, 51.138140610286165, 30.400752067565918, 0.29615985389266697, 1.051910149199622, 5.466965113367353, 0.0424464671606464, 9.442970139639717, 50.092422825949534, 51.47831746510097, 49.08737632206508, 45.3397090775626, 38.83445119857788, 38.1380158833095, 40.02020297731672, 44.069727761404856, 46.964847564697266, 49.25039495740618, 47.56934084211077, 46.809145382472444, 42.95859963553292, 45.92112391335623, 47.10822016852242, 46.49868597303118, 44.34060328347342, 44.22310924530029, 39.47978598730904, 40.30976915359497, 36.76720230919974, 36.51223121370588, 36.738686902182444, 36.9855112348284, 34.97029740469796, 35.240738664354595, 35.35135746002197, 33.988899094717844, 34.45074585505894, 35.656963552747456, 34.6001877103533, 34.494099140167236, 36.04794910975865, 37.679987158094136, 37.18470914023263, 35.00610842023577, 37.26260192053658, 36.12411526271275, 37.301279067993164, 38.37230913979666, 40.756006785801475, 37.70502151761736, 37.6112243107387, 37.661609172821045, 36.73345838274275, 34.72344527925764, 37.149540833064485, 34.76215021950858, 36.5028407233102, 36.018860476357595, 35.237764835357666, 35.03963347843715, 35.05553443091256, 38.999217305864605, 42.112663405282156, 44.74958120073591, 49.64602191107613, 50.199682167598176, 50.61582020350865, 50.079363686697825, 47.79172836031233, 45.53538077218192, 46.023324966430664, 44.87826183864048, 48.07562828063965, 45.23143182482038, 41.56451654434204, 36.5214375768389, 35.04123156411307, 35.27730008534023, 36.50208684376308, 36.842138631003245, 36.55045672825405, 36.40517336981637, 36.546253068106516, 36.62817580359322, 36.07774298531668, 36.54570416041783, 35.809129101889475, 36.13523585455758, 36.08550412314278, 35.05635779244559, 36.052903175354004, 35.57924795150757, 34.155405725751606, 33.22884954724993, 35.28895568847656, 33.801443644932334, 34.65031201498849, 40.564858368464876, 40.57053852081299, 39.678810187748496, 39.50069311686924, 36.39673825672695, 35.47518825531006, 37.13283388955252, 39.66330180849348, 42.71387365886143, 45.16768905094692, 45.82281037739345, 46.13170644215175, 44.71785920006888, 45.42821870531355, 47.215079988752095, 46.33482313156128, 46.891929694584434, 47.61428526469639, 50.06749963760376, 48.70472860336304, 46.173451219286235, 48.43431166240147, 47.47245168685913, 42.98079913003104, 40.786346094948904, 40.59553813934326, 48.980391434260774, 48.62875352587019, 53.31806148801531, 33.00784124646868, 1.9890384461198534, 10.095830695969717, 10.712918451854161, 5.8556095617158075, 1.63928556229387, 0.20117276800530298, 26.63616074834551, 58.93404374803816, 38.96183599744524, 38.97579492841448, 36.370897906167166, 34.55214091709682, 42.62464836665562, 18.947836569377355, 0.16304458252021245, 0.012592548038810492, 0.12890703789889812, 0.05291986891201564, 0.05174506695142814, 0.02327546613690044, 0.06691092851438693, 0.08525491239769117, 0.029075982115630592, 0.07114557735621929, 0.035119686741381884, 0.0494353439259742, 0.10957533773034811, 0.12351881845721177, 0.19958942010998726, 0.14710907904165132, 0.09059703217021056, 0.18065122275480203, 0.1369853229927165, 0.11639964261225291, 0.10788343101739883, 0.11712868777768952, 0.1296581897352423, 0.1103056517562696, 0.11525154778999941, 0.19859770046813147, 0.16542093429182256, 2.6466706778321947, 49.05519226619175, 57.25593566894531, 41.812608923230854, 36.23279551097325, 52.853539671216694, 43.59234830311367, 56.39021791730608, 53.80245515278408, 55.622792857033865, 38.1398606300354, 0.43038686418107575, 3.3868954948016574, 15.058704001562935, 0.17285123201353209, 11.564299464225769, 52.081643445151194, 54.82960387638637, 51.92213017599923, 47.99540785380772, 41.90412712097168, 37.60065262658255, 43.362991741725374, 47.88703332628523, 47.04842397144863, 51.3633143561227, 50.05877270017351, 46.869525228227886, 43.559313092912944, 47.26307814461844, 49.05868026188442, 48.5963089125497, 46.54191071646554, 45.23572928564889, 40.818325178963796, 41.82754407610212, 38.76466696602957, 38.14273371015276, 39.70361178261893, 38.8522698538644, 38.23096193586077, 37.81926727294922, 37.115685735430034, 36.41438320704869, 35.33458798272269, 37.249949250902446, 36.82775933401925, 36.888305936540874, 38.760126318250386, 40.21533966064453, 38.38882500784737, 36.514319147382466, 38.776888847351074, 39.569383008139475, 39.22824730191912, 41.29768139975411, 42.947475569588796, 38.928283146449495, 39.22174378803798, 39.12762348992484, 38.64698185239519, 36.52909101758684, 38.617966175079346, 36.91525452477591, 39.42227227347237, 37.7296598298209, 37.035791873931885, 37.628740719386506, 37.16406604221889, 42.11581093924386, 44.614303248269216, 46.076860836574006, 51.04337412970406, 52.9928753716605, 53.04661621366228, 50.94674900599888, 49.19168962751116, 47.52299288340977, 49.28717177254813, 47.02352857589722, 52.019286836896626, 48.40418774741036, 43.74985006877354, 38.87882934297834, 36.81641639981951, 37.246707916259766, 39.50032833644322, 37.43946136747088, 37.656464031764436, 39.58893871307373, 38.40867601122175, 37.51630844388689, 36.986039297921316, 37.77419778278896, 37.906748567308696, 38.44267702102661, 37.86266919544765, 37.19407531193325, 38.05152470724923, 36.861294814518516, 35.87379251207624, 36.25253881726946, 35.248423371996196, 36.449464661734446, 35.758740765707834, 42.21019179480416, 41.931461334228516, 41.59033605030605, 41.33447905949184, 37.595399788447786, 37.63810689108712, 38.90587520599365, 41.344428879874094, 43.21324763979231, 46.69213424410139, 46.54460661751883, 48.31213453837803, 45.74030746732439, 45.89622851780483, 46.9393754686628, 46.539166178022114, 46.59794098990304, 49.752190385546, 49.960896900721956, 49.45335183824812, 48.027175017765586, 50.79397896357945, 50.50161961146763, 46.35998255865914, 42.57518761498587, 42.11364310128348, 50.98012467793056, 51.929811409541536, 55.35508223942348, 34.91906138828823, 3.8299803818975175, 14.91678878239223, 19.55847031729562, 14.360462154660906, 8.473369870867048, 0.48740087768861223, 28.82173572267805, 62.14834295000349, 44.443554741995676, 43.441388266427175, 45.176176275525776, 42.680296489170615, 50.127907276153564, 22.790980747767858, 0.316703125834465, 0.1382520528776305, 0.29139216829623493, 0.16872677047337803, 0.2110864089003631, 0.16694273906094687, 0.20233504420944623, 0.10717185134334223, 0.10694874902921063, 0.23057483030217035, 0.11810189698423658, 0.16331402877611773], [0.09663636703044176, 0.022076426905446818, 0.06188791697578771, 0.0356219078281096, 0.04957776503371341, 0.044520436586546044, 0.05073161044024995, 0.021599550798003162, 0.014285372470372489, 0.06247078534215689, 0.04522531572729349, 0.049163390483175, 0.02416063712111541, 0.028529469655560594, 0.05656433817265289, 0.03458067209326795, 12.47028636932373, 51.4637679372515, 37.650426047188894, 33.357801164899556, 29.64511115210397, 28.288298198154994, 36.45079524176461, 42.55029916763306, 44.2648401260376, 38.263587202344624, 1.4815398497240884, 0.3761962620275361, 5.974880167416163, 0.39986581621425493, 3.195762493780681, 45.834389550345286, 47.84529202325003, 48.828149454934255, 44.561771392822266, 42.983918871198384, 36.96527113233294, 42.324854442051475, 43.95224414552961, 46.91259363719395, 45.11726597377232, 43.37597792489188, 44.26128612245832, 43.606581687927246, 45.70797402518136, 46.26749856131417, 41.90594754900251, 38.74333252225603, 38.02436419895717, 34.98946748461042, 33.36722639628819, 33.23661763327462, 33.90647956303188, 33.54259198052542, 33.243586676461355, 34.097384793417795, 32.35702085494995, 33.73900713239397, 34.77240228652954, 33.00094863346645, 33.12052713121687, 33.28422321592058, 32.94752393450056, 35.51580742427281, 35.418880053928916, 35.06015498297555, 34.147710595812114, 35.176228114536826, 35.50037547520229, 36.36865016392299, 35.92612981796265, 35.176863874707905, 35.215631348746165, 35.2211343220302, 34.90991061074393, 34.776769229343955, 33.865030084337505, 35.58689096995762, 33.85194315229143, 33.938993658338276, 33.20152228219168, 33.983906814030235, 32.98312650408064, 35.661490304129465, 41.59688472747803, 42.24335902077811, 46.61787189756121, 48.532819747924805, 48.207425185612266, 46.589238371167866, 48.10528319222586, 51.617889404296875, 43.96956253051758, 47.00691543306623, 45.60129138401577, 48.272237982068745, 46.92027139663696, 44.39554268973214, 38.363332067217144, 32.99021019254412, 32.946763106754844, 35.06384795052664, 34.690434387751985, 34.954309599740164, 34.35976961680821, 33.61134787968227, 34.44997460501534, 34.270353249141145, 32.933387824467246, 35.021043573107036, 33.163331508636475, 35.292089326041086, 34.01190110615322, 34.108248301914756, 33.01295164653233, 33.20041751861572, 32.28069836752755, 32.454875809805735, 33.980477878025596, 32.316120283944265, 34.08670541218349, 36.48196138654436, 36.67743158340454, 34.963401317596436, 36.04882458278111, 34.395413875579834, 32.27819701603481, 35.53509562356131, 37.116040093558176, 42.105510234832764, 42.56430673599243, 44.68105459213257, 43.449180671146934, 43.60992724554879, 43.5080840247018, 46.21915299551827, 43.7614118712289, 44.26778963633946, 40.538430895124165, 44.77621364593506, 49.62397527694702, 44.961494309561594, 45.55741350991385, 47.092822960444856, 41.96757459640503, 42.72272566386631, 42.452308722904746, 49.51744897024972, 45.76717962537493, 25.568940026419504, 6.425084352493286, 5.043196218354361, 8.5094918182918, 2.9092761065278734, 1.6646811195782252, 0.16535462784980023, 20.46210959979466, 56.02676459721157, 35.973061425345286, 28.9403657913208, 21.548760959080287, 26.024406603404454, 40.37407125745501, 5.349346876144409, 0.1233328455793006, 0.02221777762419411, 0.061602036601730754, 0.10667740966060332, 0.04424451032121267, 0.037511716064597876, 0.03818769979157618, 0.02801771684815841, 0.06836170423775911, 0.03460985588442002, 0.04598710360005498, 0.06616595134671245, 0.12121684769434588, 0.03149910869875124, 0.020320921105199626, 0.0039561801906009865, 0.04523827235347458, 0.048503806947597435, 0.06678493813212429, 0.023530464685921158, 0.011903607685651098, 0.037840296647378376, 0.0826897786131927, 0.045531175564974546, 0.037344301119446754, 0.034284973317491155, 0.04929907373817904, 0.043684790177004676, 18.52409199305943, 60.2372270311628, 38.34356096812657, 33.62072794778006, 41.70085409709385, 32.21553816114153, 42.599509784153526, 47.94812536239624, 48.63924183164324, 39.451482500348774, 1.4945434033870697, 0.7844337075948715, 7.498515026909964, 0.8045004851051739, 3.4803728674139296, 50.55726773398263, 49.08798428944179, 51.754946095602854, 45.89237921578543, 44.22221292768206, 39.06527730396816, 42.857725688389365, 45.78156239645821, 48.93580136980329, 46.49933215550014, 46.318665095738, 44.88011353356497, 44.855343205588206, 46.06332574571882, 47.549604484013145, 43.7141432762146, 40.94785697119576, 40.24983746664864, 37.162954330444336, 35.5685407774789, 35.2694798878261, 35.62991074153355, 35.604337896619526, 35.147271496909006, 35.915787424360005, 34.35691043308803, 36.288627760750906, 35.906886781964985, 36.157167843409944, 34.87608330590384, 34.97228806359427, 35.05042403084891, 36.37619243349348, 37.294581004551475, 36.589925970349995, 36.50859383174351, 37.95475367137364, 36.85399573189871, 38.302834102085654, 37.302307401384624, 37.679677963256836, 35.61704267774309, 37.220766816820415, 36.43860462733677, 35.639037200382774, 35.77524273736136, 35.31302077429635, 36.05592564174107, 36.812323910849436, 34.7936429296221, 35.54200560706002, 34.58541931424822, 38.5389130456107, 43.27208151136126, 45.443223340170725, 47.38872936793736, 48.68424531391689, 48.82366091864449, 48.186389514378135, 49.21431643622262, 50.707609380994526, 44.58026054927281, 48.13788761411394, 48.089045252118794, 47.535739353724885, 47.50326347351074, 45.559921809605186, 40.186282294137136, 35.225605487823486, 35.670175552368164, 37.03258875438145, 36.16749286651611, 36.850799560546875, 36.21168340955462, 34.91426018306187, 36.0269273349217, 35.64861529214041, 35.26792001724243, 36.977618081229075, 35.36150530406407, 36.25469275883266, 35.62899010522025, 36.03057166508266, 35.480423722948345, 35.058549949101035, 33.39316749572754, 35.171076025281636, 35.462400095803396, 33.89814172472273, 36.761101790836875, 38.95270259039742, 38.739896638052805, 37.63510874339512, 38.195251669202534, 37.81996209280831, 34.498111724853516, 37.291023526872905, 39.449328558785574, 43.8422645841326, 44.550067152295796, 46.30926070894514, 46.430482455662315, 47.684621879032676, 45.19190352303641, 47.445270333971294, 44.972451618739534, 45.20148856299264, 43.066539900643484, 47.848366601126536, 50.63081441606794, 47.49659320286342, 46.324581486838206, 47.59999976839338, 43.511867318834575, 43.7543420791626, 45.23546525410244, 50.90864855902535, 47.60122265134539, 28.06236709867205, 9.752194506781441, 9.157383544104439, 13.904198271887642, 6.4473099027361185, 1.3282828905752726, 0.14883390148835524, 23.296792234693253, 58.7570036479405, 40.774461201259065, 38.21467188426426, 23.608015945979528, 30.20052582877023, 46.48464713777815, 6.9799066952296664, 0.22519490255841187, 0.12599458917975426, 0.023826446750068238, 0.08298651554754802, 0.07133029494434595, 0.03245115439806666, 0.016405587450468113, 0.03349800840286272, 0.04654038444693599, 0.031038695547197546, 0.01349536856702928, 0.02539657847955823, 0.23281022320900643, 0.21118426722075256, 0.13803078260804924, 0.07741414848715067, 0.13691115911517823, 0.274446570447513, 0.169622219566788, 0.10709705642823662, 0.10516631217407328, 0.15457118648503507, 0.15133861851479324, 0.17433593448783669, 0.21567519195377827, 0.14049771880464895, 0.27504701965621536, 0.168672772656594, 21.55918673106602, 68.0826951435634, 48.03275442123413, 45.10277203151158, 38.263166836329866, 39.804822717394146, 46.491272245134624, 51.45864016669137, 53.2147730418614, 45.21640634536743, 2.539050898381642, 1.6229971391814095, 18.94754821913583, 1.3753100356885364, 4.6413445472717285, 53.61189733232771, 50.20540400913784, 54.40313734327044, 47.172348567417686, 47.283544063568115, 41.84261471884591, 46.36135482788086, 48.58368056161063, 50.435035024370464, 48.2837233543396, 45.78459875924246, 45.02571650913784, 46.38712569645473, 48.40237079347883, 48.93604803085327, 45.902235235486714, 42.41033465521676, 42.3287593296596, 38.135782037462505, 37.356503350394114, 37.16763046809605, 39.022723061697825, 37.65527588980538, 37.30961690630232, 38.80040502548218, 35.77989455631801, 38.35603993279593, 38.45081683567592, 38.372576645442415, 37.7464918409075, 37.10927949632917, 36.29175097601754, 38.35755811418806, 39.05424356460571, 37.495310987745015, 37.54467446463448, 39.40956054415022, 38.375911780766074, 41.21117285319737, 38.56710883549282, 39.13925477436611, 37.179400716509136, 39.247247150966096, 39.036692414964946, 37.67889976501465, 36.40035479409354, 38.572313036237446, 38.2196398462568, 37.04063476834978, 36.93223244803292, 37.898018155779155, 35.05818516867501, 39.86807564326695, 45.757073470524375, 46.0084627696446, 49.16497032982962, 51.60523673466274, 48.99333940233503, 49.16646071842739, 50.95028911318098, 53.565389565059114, 46.17800576346261, 50.438450063977925, 50.567033427102224, 50.415732928684776, 49.78888382230486, 47.39390230178833, 42.408608027866904, 37.070762157440186, 38.8334367615836, 38.464991160801475, 36.776992321014404, 37.97379868371146, 37.467271532331196, 36.92392240251814, 37.64527743203299, 37.933460916791645, 35.653145517621724, 38.931913580213276, 36.62362820761544, 37.0067275592259, 36.81613499777657, 37.24682603563581, 36.7897492136274, 37.030080454690115, 33.35298258917672, 35.050642899104524, 37.19972767148699, 34.85198695319039, 39.23996891294207, 40.53512702669416, 39.49183068956648, 38.979133537837434, 40.07062258039202, 38.650952747889924, 35.93276882171631, 39.87876544679914, 40.282212597983225, 45.80358471189226, 46.058114596775596, 48.51717240469796, 47.7806008202689, 48.73833009174892, 46.55782209123884, 51.78105395180838, 45.73867116655622, 45.76788486753191, 43.56712634222848, 47.41092191423689, 49.250520024980815, 49.005502223968506, 48.86421407972063, 50.37306751523699, 46.57240983418056, 47.04048218045916, 46.18186548777989, 53.775336333683555, 48.312318665640696, 32.792891774858745, 12.270763635635376, 13.110089523451668, 20.808079515184673, 12.462094443184988, 5.82626210791724, 0.3010356165468693, 28.188763516289846, 65.2932435444423, 47.0452104296003, 38.46110711778913, 30.35577985218593, 35.601829596928184, 54.21581390925816, 8.970618571553912, 0.30709900547351154, 0.19091060438326427, 0.15211627392896584, 0.17359787837735244, 0.08652504852839879, 0.15934212904955658, 0.10120397979127509, 0.09431331418454647, 0.15043299139610358, 0.13907465445143835, 0.10942148670021977, 0.1699860229023865], [0.07176807216767754, 0.050908877713871856, 0.026590535483722175, 0.021828493602307777, 0.027727571881509254, 0.03683337103575468, 0.04311898357367941, 0.026709660787933638, 0.01272501758233245, 0.11504026555589267, 0.0299605067952403, 0.02333864792516189, 0.05579480482265353, 0.01948358683979937, 0.07053160494459526, 0.03382663309041943, 1.0481314148221696, 31.56899438585554, 45.628969533102854, 23.25360918045044, 24.335304737091064, 37.130770274571006, 37.32447910308838, 46.44173158918108, 41.312032903943745, 44.669107164655415, 2.6935171697820937, 0.34917333349585533, 2.56929640684809, 5.274212964943477, 1.402873648064477, 33.989840575626914, 52.73938076836722, 46.55674164635794, 46.41881990432739, 44.34642934799194, 45.81718233653477, 43.778768471309114, 46.34111819948469, 45.97482654026577, 44.88033587591988, 42.803418568202424, 39.8813328061785, 42.44341850280762, 44.54100322723389, 41.21230888366699, 39.75918000085013, 38.01059634344918, 35.04785667146955, 33.77707283837454, 33.22085911887032, 32.467292240687776, 32.156527110508506, 33.49724803652082, 32.00378138678414, 32.811578954969136, 33.28258344105312, 31.73375701904297, 33.29002148764474, 34.248733929225374, 32.56844064167568, 34.29685715266636, 34.20961209705898, 34.04782329286848, 34.79719693320138, 36.5183664730617, 34.376566886901855, 34.91291223253523, 34.83026688439505, 35.56589003971645, 35.61464902332851, 35.32292195728847, 34.68223551341465, 35.33349364144461, 33.67689023699079, 35.288316454206196, 34.63038110733032, 35.8936574118478, 32.80232742854527, 34.68773848669869, 34.80293614523751, 36.043394565582275, 35.246356282915386, 41.03194407054356, 42.778304304395405, 48.88980082103184, 45.6599828175136, 56.732670307159424, 61.39497756958008, 39.825069768088206, 48.34410320009504, 49.950005599430625, 50.03016001837594, 46.96926314490182, 48.78517484664917, 46.26777996335711, 47.61222859791347, 46.20515584945679, 43.630445275987896, 35.7583829334804, 33.70705931527274, 32.17233773640224, 32.782525062561035, 34.65611376081194, 35.980923312050955, 34.67936243329729, 35.59062910079956, 34.044818196977886, 34.15683010646275, 34.22686447416033, 34.32070337023054, 34.146150725228445, 32.7577234676906, 33.58798108782087, 34.87678854806082, 34.06467614855085, 36.40504482814244, 33.904912744249614, 32.66997814178467, 31.398179871695383, 32.63821792602539, 35.168029240199495, 35.73117726189749, 37.55636828286307, 35.29124164581299, 34.6521498135158, 33.683022022247314, 32.89656237193516, 32.539546557835166, 34.38346297400338, 38.699850695473806, 41.83264752796718, 42.04786797932216, 41.9991089957101, 44.46814094270979, 43.12007924488613, 43.65400661740984, 44.49867827551705, 45.03710808072771, 40.334400517599924, 42.734124183654785, 51.10860729217529, 48.070882661002024, 45.79151569093977, 43.93955326080322, 44.823183468409944, 45.71777098519461, 48.592966829027446, 42.3678047316415, 23.853104966027395, 7.902465053967067, 0.5878686266286033, 9.904709202902657, 3.555584511586598, 0.5867371559143066, 0.2494537372674261, 26.013006346566335, 54.30204105377197, 32.57508659362793, 28.899162973676408, 22.701187440327235, 35.785692828042166, 25.07749046598162, 0.9555945460285459, 0.048099237228078504, 0.07763712187962872, 0.021614174923992584, 0.02508177894300648, 0.03485061367973685, 0.06963836787534611, 0.018666293106174896, 0.014348214991124613, 0.04560461001736777, 0.015354309397350465, 0.012150856516590076, 0.03830816689878702, 0.03728680206196649, 0.06702266287590776, 0.013678294822706707, 0.0612844279302018, 0.057086324984473844, 0.03764269707192268, 0.01429539782527302, 0.045455294993839095, 0.05004255812881248, 0.04404175387961524, 0.0748381106449025, 0.06512769777327776, 0.04491537789415036, 0.044649972314281125, 0.04215334003259029, 0.04205561741920454, 2.8531865562711443, 39.888069084712434, 49.94724716459002, 27.570379052843364, 27.239042043685913, 43.596444266183035, 39.326814447130474, 50.89989382880074, 47.34808240618025, 45.88089036941528, 3.1085400198187148, 0.5819517469831875, 4.142219398702894, 5.160908256258283, 1.6693859185491289, 38.284845215933665, 53.04021692276001, 49.468293939317974, 47.95267990657261, 47.29452569144112, 45.49517502103533, 45.66671909604754, 46.4894448689052, 49.10191542761666, 47.20934077671596, 44.09781585420881, 41.09964036941528, 44.74473135811942, 46.55524778366089, 44.20105913707188, 42.431728158678325, 39.92286566325596, 36.37230839048113, 35.17703757967268, 33.61812932150704, 33.7626553262983, 34.85272346224104, 35.18242590767996, 33.94377749306815, 35.58863844190325, 35.951991013118196, 34.23343052182879, 34.94443620954241, 35.71138531821114, 34.2869941847665, 34.544675077710835, 35.85793324879238, 35.35139914921352, 36.0297726222447, 36.99230309895107, 35.104675565447124, 35.57644435337612, 36.358453682490754, 36.242759227752686, 37.84921053477696, 36.22687564577375, 35.613467829568044, 37.01707690102713, 36.02128192356655, 36.035477093287874, 35.64074298313686, 37.08170557022095, 33.88656949996948, 35.44533879416329, 36.90288325718471, 37.01464850561959, 36.459668091365266, 41.746844223567415, 45.23731347492763, 48.81145640781948, 48.706243310655864, 53.328209332057405, 55.10746233803885, 43.655055795397075, 48.99051495960781, 50.479190826416016, 47.5021448135376, 48.1831169128418, 49.7319780758449, 48.76003973824637, 48.607071672167095, 47.82081699371338, 44.60357175554548, 36.85218225206648, 34.8092485836574, 36.01173162460327, 35.27160951069423, 36.57902077266148, 36.81895249230521, 35.75543689727783, 37.06011404309954, 35.87681497846331, 34.52624150684902, 35.309254850660054, 35.82607923235212, 36.34366791588919, 34.15757008961269, 35.5852928842817, 36.48626926967076, 35.78778076171875, 37.50003923688616, 35.35793045588902, 34.9421398299081, 33.670546531677246, 34.490916865212576, 38.0994360106332, 37.1387676511492, 38.0835211617606, 37.20313923699515, 35.15178435189383, 34.37280791146414, 33.97359916142055, 34.394197940826416, 36.59603691101074, 41.312453269958496, 43.435103620801655, 42.89484296526228, 44.74375166211809, 45.371559619903564, 45.5861234664917, 46.2537202835083, 45.69442156382969, 46.27059050968715, 41.75618955067226, 44.38993549346924, 50.793600286756245, 47.362461703164236, 48.57227509362357, 46.56147684369768, 48.1685083253043, 45.838554995400564, 50.91532230377197, 44.00441469464983, 27.553256954465592, 8.448965191841125, 1.86652563725199, 11.156091928482056, 7.5417406388691495, 0.3577680108802659, 0.1336124746927193, 30.44071810586112, 57.91314492906843, 41.57670715876988, 32.461195196424214, 25.735172203608922, 39.65550592967442, 34.33757012231009, 1.5870008021593094, 0.11104633379727602, 0.05883603609566178, 0.059650983794459274, 0.01702594318028007, 0.05204037217689412, 0.018100131968302385, 0.04875665623694658, 0.027153310731851628, 0.11671136159982, 0.005624041318826909, 0.031085134483873844, 0.047926940223468203, 0.19341490071799072, 0.13122646058244364, 0.11383004406733171, 0.21803548958684715, 0.1366718126727002, 0.12562699961875165, 0.13217609748244286, 0.1858679899679763, 0.1309617097888674, 0.191257240782891, 0.15457516270024435, 0.1823621623750244, 0.14881695168358938, 0.15182218328118324, 0.19459555165043899, 0.08885252542261567, 3.2913755689348494, 48.29419081551688, 57.24622903551374, 32.794958863939556, 33.384999888283865, 48.84389407294137, 47.56843410219465, 57.506744793483186, 49.97643654687064, 52.12457289014544, 4.008685444082532, 1.0729762188025882, 9.063199843679156, 7.806709323610578, 2.4609359928539822, 41.536591734204976, 56.01885754721505, 51.97205993107387, 51.122569697243826, 49.753454957689556, 48.20780038833618, 47.68868657520839, 50.72195393698556, 50.19788605826241, 47.447681358882356, 42.408086912972585, 42.20419897351946, 46.490792819431846, 49.243068081992014, 45.08973721095494, 44.308502605983186, 41.3831581388201, 37.766850062779014, 37.4424421446664, 36.32744039808001, 36.30548061643328, 35.943535055433, 37.675533362797324, 35.75029523032052, 38.27273103169033, 37.57017435346331, 37.101289067949565, 36.52132640566145, 36.137987341199604, 36.61883395058768, 37.46308871677944, 36.74607631138393, 35.66029173987252, 37.509655543736045, 39.31163610730852, 37.40072168622698, 37.662502016339985, 39.123565741947715, 38.603611196790425, 39.9802508354187, 38.80594621385847, 38.42465339388166, 38.61971017292568, 37.897615160260884, 40.22084958212716, 37.29839556557791, 40.5815236227853, 35.600801263536724, 38.611757959638325, 38.45143175125122, 38.1287157194955, 39.38135085787092, 44.74801785605294, 46.38329029083252, 50.667587757110596, 51.570457526615684, 55.59280790601458, 55.511840547834126, 43.22082117625645, 50.365302903311594, 52.25536230632237, 49.932582991463796, 50.79479537691389, 52.431811809539795, 49.83508586883545, 49.132935660226, 51.42978082384382, 47.127018519810264, 39.7775753566197, 37.617953641074045, 36.277451583317344, 36.62799515042986, 38.72608709335327, 37.9877541405814, 38.52727133887154, 38.062037331717356, 37.21687929970877, 37.89146253040859, 36.19390296936035, 36.538912296295166, 38.11811971664429, 35.403871944972444, 36.53465305055891, 38.33299970626831, 37.510239192417686, 38.84808356421334, 36.84812102999006, 36.52761452538626, 33.79450934273856, 35.56882217952183, 39.89519793646676, 39.20663145610264, 40.29230833053589, 39.245728969573975, 37.94720445360456, 36.91947555541992, 36.42833171572004, 36.18248013087681, 37.22717653002058, 42.287535667419434, 46.08202682222639, 44.51775802884783, 45.94471304757254, 48.01135744367327, 47.41126585006714, 47.174380915505544, 48.46860102244786, 46.88976533072335, 44.42264413833618, 44.34214230946132, 48.98834017344883, 49.27880614144461, 51.911982331957134, 48.49504239218575, 48.817129611968994, 50.05754634312221, 52.34433051518032, 46.95790631430489, 29.015150989804948, 9.890592200415474, 2.128354604755129, 20.219530616487774, 15.537813561303274, 1.8390778643744332, 0.37420826298849924, 32.760804993765696, 64.02582263946533, 43.35900347573416, 39.585513251168386, 34.37266894749233, 44.43585613795689, 41.83498559679304, 2.793729518141065, 0.27288718840905596, 0.1915533806064299, 0.14912943063037737, 0.14285543800464698, 0.2374270297586918, 0.12860867248049804, 0.1370744417820658, 0.11153533362916537, 0.1858745581869568, 0.0883215107023716, 0.07440441820238318, 0.09016945332820926], [0.056397082683231146, 0.08002491375165326, 0.013000820863193699, 0.06394892638283116, 0.017122707362951975, 0.07839033646242959, 0.034781979862600565, 0.06534771275307451, 0.021901264786720276, 0.006761529790570161, 0.015157793781587055, 0.058078797800200324, 0.01247966949761446, 0.00995331653393805, 0.012427120353095233, 0.05403297168335744, 0.0783919853025249, 17.165118149348668, 46.190067836216514, 35.68388087408883, 24.049247401101248, 20.340569972991943, 42.06847981044224, 46.34706585747855, 45.651968070438926, 44.79178803307669, 8.63467230115618, 0.5798069792134422, 2.1103972026279996, 10.160581827163696, 14.18896758556366, 32.365400382450645, 47.84938798631941, 50.61133861541748, 46.98048448562622, 47.21488891329084, 45.87757955278669, 46.63500268118722, 46.459390435900005, 46.67473248073033, 44.42883498328072, 42.02087770189558, 42.85419600350516, 44.679901191166465, 42.32359334400722, 40.71507494790213, 38.27212306431362, 37.58810417992728, 33.04183530807495, 32.52485111781529, 31.63480772290911, 32.33217062268938, 32.70664725984846, 32.83619294847761, 32.315081528254915, 33.31311729976109, 33.5879602432251, 33.275117601667134, 34.03129700251988, 33.89291320528303, 33.474440574645996, 33.95973055703299, 34.21101910727364, 35.920091833387104, 33.90025397709438, 34.35243926729475, 34.97470951080322, 34.66384015764509, 34.32904815673828, 34.55297122682844, 36.37977075576782, 34.64850895745413, 34.800882952553884, 37.52298566273281, 34.633608545575825, 35.17756216866629, 34.68997928074428, 33.60797452926636, 34.25877060209002, 36.3162260055542, 35.45669909885952, 36.56235204424177, 35.990692479269846, 37.9455577305385, 47.514644622802734, 46.300415652138845, 46.62995828901018, 47.92223637444632, 61.938555989946636, 41.60852643421718, 43.856015069144114, 47.88731472832816, 54.94750785827637, 46.737613677978516, 46.76624373027256, 44.59060641697475, 45.417153699057444, 46.62346519742693, 44.11390093394688, 37.99208981650216, 33.728365966251914, 32.64469017301287, 34.85739265169416, 35.527629784175325, 33.33915219988142, 34.15445382254464, 34.083953925541465, 34.91722011566162, 33.50866392680577, 34.17635801860264, 35.3406537600926, 33.48075648716518, 32.92668628692627, 33.54689986365182, 34.506136894226074, 33.7020149230957, 35.11678280149187, 35.85079744883946, 34.702715328761506, 33.16324118205479, 32.68037264687674, 33.82022115162441, 35.19059351512364, 35.8978054864066, 33.43523188999721, 32.89861903871809, 32.33116660799299, 33.50007247924805, 32.509568555014475, 32.84220661435808, 33.370919363839285, 34.94193485804966, 36.15194974626814, 36.21381650652204, 38.74372509547642, 40.07442324502127, 41.938576289585654, 44.14943054744175, 43.47690050942557, 46.39130156380789, 41.68725994655064, 42.85622487749372, 45.151187079293386, 49.08349922725132, 45.401857239859446, 45.603733675820486, 47.33870581218174, 47.81139523642403, 35.530666146959575, 6.10398942232132, 1.5734817790133613, 4.824032230036599, 4.5320815188544135, 5.504766353539058, 0.29452282030667576, 0.3104849766407694, 30.904274123055593, 48.20591047831944, 28.284801517214092, 31.57247543334961, 23.56441252572196, 38.62531042098999, 15.494164977754865, 0.08166525180318526, 0.044073363433458974, 0.0344793362809079, 0.016901437093370726, 0.021105344906183224, 0.0881836459572826, 0.039498083226914914, 0.07986062006758791, 0.032028786705008576, 0.0705734094870942, 0.0868442856839725, 0.017884440952911973, 0.03659385156684688, 0.061730741124067984, 0.02967245171644858, 0.046943312111709795, 0.04767676775476762, 0.05007860869435327, 0.01896098256111145, 0.04774122518886413, 0.024267659056931734, 0.029577568772115877, 0.0840304484590888, 0.04185724092115249, 0.04837330091478569, 0.030912471070353473, 0.0823328352666327, 0.028889100000794445, 0.07291299144604377, 0.13551786887858594, 22.55590408188956, 53.42986147744315, 33.42178017752511, 25.56133348601205, 30.478582314082555, 45.930017607552664, 49.32113804136004, 49.39836032049996, 48.884572301592144, 7.7748700720923285, 0.5675603449344635, 2.590927017586572, 11.739232523100716, 11.611713102885656, 35.91687134334019, 50.05192872456142, 51.887750489371165, 49.61461952754429, 49.00286190850394, 47.02264615467617, 48.95855324608939, 47.886001518794465, 48.561717305864605, 43.80540439060756, 41.65796634129116, 43.60268374851772, 48.900706018720356, 45.39752156393868, 43.77988018308367, 41.547847815922324, 38.534229959760395, 36.04860918862479, 33.971525124141145, 32.783879961286274, 35.15523413249424, 34.571026120867046, 35.26431737627302, 33.61198711395264, 34.39701543535505, 35.67172152655465, 35.424608843667166, 34.37740067073277, 35.2015369279044, 35.496144022260395, 35.49156863348824, 35.099832671029226, 37.56255912780762, 35.986033712114605, 36.87069920131138, 35.98436614445278, 37.335109846932546, 35.56016819817679, 36.601268904549734, 37.54446601867676, 36.87046296255929, 36.261932781764436, 38.21322318485805, 36.32016910825457, 35.98671463557652, 36.35069254466465, 35.50327982221331, 34.642252104622976, 36.71288129261562, 37.762153080531526, 39.48720318930489, 38.47704628535679, 39.52619300569807, 49.255116258348735, 48.46976831981114, 48.963559423174175, 50.02315623419625, 58.497377259390696, 41.38017736162458, 45.70579923902239, 51.30100638525826, 51.357529980795725, 47.063925402505056, 47.91667086737496, 46.66818380355835, 47.146383149283274, 47.70440687452044, 44.95484140941075, 39.69114671434675, 34.76776436397007, 34.92595400129046, 34.82266902923584, 37.47822536740984, 36.360145568847656, 35.50047622408186, 36.404992716653005, 36.49128934315273, 35.30926527295794, 35.43090738568987, 37.33857004983084, 36.52040924344744, 33.517529828207834, 33.88531535012381, 36.94265127182007, 35.675431864602224, 37.052846227373394, 37.474070344652446, 35.08973693847656, 35.71089547021048, 34.21937779017857, 36.165116582598, 36.375587940216064, 36.58765043531145, 35.2858498437064, 34.35233851841518, 34.723014490945, 34.79977124077933, 34.78605897086007, 35.23579849515642, 34.978954860142295, 37.287104742867605, 38.59834793635777, 37.87640230996268, 40.464220660073416, 42.57252992902483, 43.04195022583008, 46.102114064352854, 46.462555340358186, 48.22706079483032, 43.62778411592756, 44.26119926997593, 46.16819143295288, 48.86687176568167, 47.24414430345808, 46.85292945589338, 49.65203905105591, 49.82213790076119, 39.72625248772757, 7.791166203362601, 4.318019245352064, 14.22967881815774, 7.988190191132682, 5.422638646193913, 0.5247732837285314, 0.14105054842574255, 34.04960897990635, 53.34620516640799, 34.16379220145089, 33.23282044274466, 24.735757214682444, 43.9189692224775, 19.906912054334367, 0.05184521872018065, 0.04211186118690031, 0.04494584072381258, 0.01448760474366801, 0.03202525153756142, 0.013485173578374088, 0.0437137432662504, 0.08252251973109585, 0.06367788556963205, 0.02263745153322816, 0.016708512624193515, 0.07788532998945032, 0.02316634583153895, 0.09710895310023002, 0.18782963470688888, 0.14101761233593735, 0.13453644939831325, 0.09813679794647864, 0.10704812048269169, 0.10323185633335795, 0.15166609308549336, 0.21839268399136408, 0.14595961357866014, 0.18794939613768033, 0.15361943255577767, 0.08461391393627439, 0.11506172083318233, 0.1683361650045429, 0.1992165922586407, 0.20004219295723097, 26.088720866612025, 61.72025053841727, 44.45886162349156, 35.300243037087576, 29.59181499481201, 49.45416477748326, 53.72494452340262, 54.8008313860212, 55.10461357661656, 10.40217764036996, 0.7833797527211053, 7.628763352121625, 13.553647756576538, 17.876622370311193, 39.753541537693565, 49.23466076169695, 54.88741288866316, 50.67369869777134, 51.42596278871809, 49.00213582175118, 51.65988431658064, 49.74272346496582, 50.87704815183367, 42.50871419906616, 42.58148615700858, 45.21239376068115, 49.162785121372764, 46.70692695890154, 46.6748297555106, 43.45449256896973, 42.11991385051182, 37.56749929700579, 36.57255547387259, 35.57272011893136, 37.46206733158657, 37.345552989414756, 37.350670337677, 35.729454108646934, 37.19958870751517, 38.743617398398264, 36.73210000991821, 37.1955691746303, 35.87621743338448, 36.153457505362375, 36.72921303340367, 38.272057056427, 37.780788149152485, 36.749619892665315, 38.64823252814156, 37.62118107931954, 40.121024812970845, 37.71946334838867, 38.3944982119969, 39.840102195739746, 38.51970475060599, 40.455010822841096, 40.43407590048653, 38.39330659593855, 38.86083003452846, 37.16098799024309, 37.547196660723, 37.52733176095145, 39.25702326638358, 39.240309374673025, 41.23023176193237, 40.11722762244088, 41.17706414631435, 50.40156555175781, 48.09357895169939, 49.43013095855713, 54.05627979551043, 60.996074540274485, 39.87000724247524, 47.78384910311018, 50.77347830363682, 52.40748964037214, 49.64421885354178, 48.55144786834717, 48.94945110593523, 47.00053351266043, 49.16455691201346, 46.69394077573504, 42.21457610811506, 38.81088638305664, 36.280609539576936, 37.38459839139666, 40.24589783804757, 37.471676690237864, 37.47117294584002, 38.336571080344065, 38.02027518408639, 36.9578469821385, 39.02236522947039, 38.60025521687099, 39.427893366132466, 34.22621481759207, 35.62288958685738, 39.005599226270405, 37.15266057423183, 39.1894450868879, 39.58821957451956, 38.33413921083723, 36.611885751996724, 38.1730625970023, 37.573196819850374, 38.803403173174175, 40.791234152657644, 36.8975887298584, 36.35685559681484, 36.4581047466823, 37.197768279484336, 37.21341562271118, 37.16973229816982, 36.42938436780657, 37.710889271327424, 39.91794286455427, 40.17313977650234, 43.49043212618147, 44.246486459459575, 45.47183602196829, 49.18755892344883, 48.196176052093506, 50.542200565338135, 47.063042981284006, 46.41139228003365, 44.71348878315517, 48.53002309799194, 50.154129777635845, 49.20136499404907, 51.56359270640782, 50.99620975766863, 40.78705481120518, 9.601679154804774, 3.6011779393468584, 15.239263364246913, 16.7743045602526, 14.571020364761353, 2.1817821264266968, 0.5350821848426546, 38.91527264458792, 58.51031480516706, 39.07084281103951, 42.853508131844656, 32.441594328199116, 49.06573963165283, 26.58430460521153, 0.14712544530630112, 0.1815954585160528, 0.13971736282110214, 0.09851999381291014, 0.10413365651454244, 0.16946724216852868, 0.11644954207752432, 0.1509036368557385, 0.21524536716086523, 0.15523031540215015, 0.1225143423570054, 0.18724528034882887, 0.1012073385396174], [0.014347042821879898, 0.0604861993342638, 0.09255295685891594, 0.0380652954668871, 0.05331106809899211, 0.055868385160075765, 0.0412009788144912, 0.08964840628738914, 0.045623568285788806, 0.06687603145837784, 0.08253433981112071, 0.03424531973100134, 0.027916345412709882, 0.05887532327324152, 0.059315034321376255, 0.03213995448978884, 0.11180393850164753, 4.729421215397971, 41.82501145771572, 38.35427509035383, 18.21707715306963, 28.07095854622977, 38.99274853297642, 45.705375398908345, 45.635768345424104, 47.002277510506765, 15.373860393251691, 0.4318692460656166, 1.7187500468322208, 1.9803058632782526, 14.576127290725708, 18.410714762551443, 30.905118329184397, 54.75161382130214, 47.19413464409964, 48.87805836541312, 46.73053346361433, 46.23700639179775, 45.533178193228586, 45.50882823126656, 46.57566506522042, 44.28373575210571, 41.88334158488682, 45.69204180581229, 43.29445818492344, 41.970503262111116, 39.28224870136806, 36.183015142168315, 35.32991879326956, 33.52035427093506, 33.12246915272304, 32.304999692099436, 31.88269165584019, 32.83831214904785, 32.69865335736956, 32.62981407982962, 33.820738792419434, 34.84862402507237, 33.82961859021868, 35.02129370825631, 34.962234020233154, 36.06408977508545, 33.59512036187308, 34.74636391230992, 36.88701009750366, 35.32602085386004, 35.52539941242763, 34.203289236341206, 35.511270250592915, 35.300559180123464, 37.40683262688773, 34.828814710889546, 35.40187086377825, 33.514392716544016, 36.14961167744228, 32.774979318891255, 34.96643073218209, 34.720551354544504, 35.42130150113787, 34.78987005778721, 36.148861271994456, 34.55678926195417, 34.87821987697056, 36.67160551888602, 47.30012246540615, 46.40474285398211, 50.15681178229195, 37.79821423121861, 28.897828919546946, 46.36153200694493, 41.960796628679546, 38.26453215735299, 51.79849393027169, 52.68048783711025, 46.09493657520839, 48.048262800489155, 45.12928635733468, 47.61875295639038, 41.73966326032366, 39.574045249394004, 33.891064984457834, 32.378605433872764, 32.25511857441494, 36.217700549534385, 33.123799732753206, 36.672776290348594, 33.731471811022075, 35.13598067419869, 32.38145072119576, 34.326675346919465, 33.36911630630493, 33.66453981399536, 30.93329327447074, 33.32565532411848, 33.948648180280415, 34.35308197566441, 33.25729547228132, 34.61972257069179, 33.73590128762381, 33.52934871401106, 34.620712688991, 34.82410383224487, 33.19232634135655, 33.10703372955322, 34.277555056980674, 32.73089647293091, 32.1998074395316, 33.12101003101894, 31.692703587668284, 31.26245376041957, 30.752664429800852, 31.314579146248953, 30.800474984305247, 33.80131162915911, 31.476972443716868, 33.61644090924944, 34.72094392776489, 36.856493609292166, 39.70014115742275, 42.95365946633475, 46.72098663875035, 44.554513999394004, 41.211273602076936, 42.230313777923584, 46.32908044542585, 49.35658080237252, 46.35007790156773, 44.91571262904576, 17.52423231942313, 2.556388173784528, 3.887323864868709, 5.242923923901149, 6.3692916205951144, 4.078109673091343, 0.23391295117991312, 0.6468921623059681, 41.386882373264854, 43.005836963653564, 27.353108882904053, 29.62222031184605, 31.473769324166433, 44.44190801892962, 7.926856705120631, 0.1124739171937108, 0.03499945712142757, 0.07124374780271735, 0.04447916469403675, 0.012576692371762224, 0.038141114969870875, 0.0346604203140097, 0.04675673533763204, 0.07265932112932205, 0.032636988176298995, 0.044951723622424264, 0.06768551016492502, 0.009076588221692612, 0.05594788232286062, 0.10006697901657649, 0.047763643985880275, 0.03331130609980651, 0.04359643813222647, 0.027156805187197666, 0.04565470286511949, 0.02453834703192115, 0.06895743762808186, 0.05204993952065706, 0.02541804563121072, 0.027976382191159894, 0.03071538039616176, 0.0311515257427735, 0.04542934102937579, 0.03894057510686772, 0.10939985500382525, 7.763281345367432, 49.793775354112896, 45.43005302974156, 20.346950156348093, 27.92992922237941, 48.074339389801025, 49.963829040527344, 50.42310496738979, 50.25850561686924, 16.653032439095632, 0.29180509756718365, 3.6186040214129855, 4.515191750867026, 20.402961322239467, 22.75792121887207, 34.110409191676546, 54.43943125861031, 49.495711530957905, 51.261658736637656, 49.091604300907676, 49.30308314732143, 47.747263363429475, 45.872795718056814, 43.86468294688633, 44.81386593409947, 43.95984894888741, 46.82565082822527, 45.504645415714805, 43.47646277291434, 41.884984833853586, 37.28744867869786, 36.05686017445156, 35.03956399645124, 34.92772926603045, 34.2152818271092, 33.62917348316738, 33.898499556950156, 34.71058068956648, 34.8381461415972, 36.23248284203665, 37.470742157527376, 36.38532584054129, 36.28279822213309, 37.531316552843364, 37.36977093560355, 34.977103165217805, 35.772734437670024, 39.57541404451643, 35.99600437709263, 38.18738283429827, 35.692086696624756, 36.742657797677175, 35.6938967023577, 36.94834879466465, 37.01883479527065, 36.38095889772688, 35.3275077683585, 36.03800623757498, 34.50263500213623, 35.994583470480784, 35.39483233860561, 36.52852126530239, 36.12191963195801, 37.6743243762425, 36.58913040161133, 36.97043711798531, 38.731458050864084, 49.501172815050396, 48.01875032697405, 51.48355293273926, 40.11991310119629, 34.50775235039847, 45.23884207861764, 42.03758117130825, 40.46357100350516, 52.22595752988543, 51.15552152906145, 48.47364888872419, 48.11513573782784, 47.25372239521572, 48.1898775100708, 43.959227085113525, 40.878350666591096, 34.52484144483294, 34.178119386945454, 36.017901624952046, 36.74982139042446, 34.83941766193935, 37.81365660258702, 35.38443783351353, 35.27212020329067, 34.65863595690046, 37.218922070094514, 34.75615392412458, 34.035486766270225, 32.44734048843384, 35.06239925112043, 36.215883595602854, 35.12373794828142, 33.96426773071289, 35.44821187428066, 36.18529067720686, 35.432446411677766, 35.17838205610003, 36.10075889314924, 34.98204333441598, 34.18263919012887, 35.658453941345215, 34.12213427679879, 34.703761032649446, 35.17081894193377, 33.898826122283936, 33.39644704546247, 33.19988598142351, 32.346716676439556, 32.23580605643136, 35.66582250595093, 34.15531539916992, 36.30211421421596, 37.538633005959646, 39.64754676818848, 41.42975623267037, 45.61347157614571, 49.28631019592285, 45.64886917386736, 44.125070163181846, 43.538569246019634, 47.83726337977818, 49.97617598942348, 48.32694114957537, 46.26004661832537, 21.083942106791906, 3.4723283733640398, 7.412169763020106, 4.882749285016741, 5.414935265268598, 2.5990583641188483, 0.2246713720794235, 0.5939270758203098, 43.583315644945415, 48.19576958247593, 33.46821846280779, 31.121721472058976, 32.61928408486502, 50.066655431474956, 9.907755119459969, 0.16057780917201722, 0.06250794870512826, 0.050346470570990016, 0.028018770273774862, 0.05770534569663661, 0.03934866303045835, 0.033061588249568424, 0.02288706929955099, 0.03451921378395387, 0.060456235227840285, 0.058457461052707264, 0.051319187839648554, 0.0188054284080863, 0.21018493441598757, 0.19894068634935788, 0.20731230213173799, 0.13507950811513833, 0.05925994406321219, 0.11817610157387597, 0.16363371376480373, 0.15759138656514032, 0.2249952368438244, 0.14129289399300302, 0.15688416308590344, 0.11411102541855403, 0.16623695407594952, 0.15228256929133618, 0.15450228803924151, 0.11099326557346753, 0.28496516602379934, 8.105038915361677, 57.755563259124756, 50.677541051592144, 27.873056479862758, 37.83880908148629, 49.11934150968279, 53.11523314884731, 53.30682972499302, 54.73183229991368, 20.393464871815272, 0.5044721130813871, 7.28287638085229, 4.711597783224923, 17.172229630606516, 24.17464327812195, 34.74273695264544, 57.08020183018276, 50.19558620452881, 53.12147610528128, 50.423838002341135, 51.01256929125105, 48.1120959009443, 46.58957535879952, 44.03864846910749, 43.93779536655971, 45.10071536472866, 48.163863454546245, 47.5547913142613, 45.57873405729021, 44.49019799913679, 40.09818261010306, 39.54592588969639, 38.26169034412929, 37.57716424124581, 36.51740067345755, 35.391643115452354, 36.58506917953491, 36.975054195949006, 38.03049945831299, 37.39652497427804, 39.53132772445679, 37.85324396405901, 39.219694069453645, 39.55241550718035, 38.74864789417812, 36.698408194950645, 37.40698201315743, 40.32735504422869, 38.424629075186594, 39.4989595413208, 37.673612185886924, 39.19123772212437, 38.273106234414236, 38.64017261777605, 38.579153537750244, 37.646833828517366, 36.55037682397025, 37.690155846732004, 36.36061109815325, 37.93407235826765, 37.587621280125205, 40.6798996925354, 37.8067535672869, 39.090370723179404, 39.07578298023769, 38.634447302137104, 41.42892939703805, 50.19146939686367, 48.86446074077061, 50.85674204145159, 42.78172281810215, 39.361458165305, 43.86509983880179, 42.790376799447195, 43.32767404828753, 52.96906736918858, 49.84190899985177, 52.334860120500835, 48.83714042391096, 49.66619947978428, 50.93809502465384, 46.651414326259065, 42.48835597719465, 36.834506034851074, 36.76386717387608, 35.9553678376334, 39.279153278895784, 36.31372812816075, 39.42132731846401, 36.96945742198399, 37.63065842219761, 34.920833178928916, 38.03534582683018, 35.519854749952046, 34.545831952776226, 33.61849062783377, 36.97518621172224, 37.984655244009836, 36.22256428854806, 34.71543400628226, 37.89524929864066, 38.27879680906023, 38.06772790636335, 37.36682142530169, 38.136681829180034, 36.823743275233674, 36.22036518369402, 39.773052079336985, 35.45175198146275, 36.840620449611116, 37.0930415562221, 35.18612929752895, 34.278114386967246, 34.644996643066406, 33.623646191188264, 34.03794642857143, 37.672483103615896, 35.28556844166347, 38.02197401864188, 36.93936129978725, 39.88880559376308, 42.666243757520405, 47.372203077588765, 50.64266456876482, 48.50228936331612, 47.214600563049316, 43.773967266082764, 46.054161071777344, 53.161681856427876, 50.559119428907124, 48.130043097904746, 22.88074278831482, 5.644376942089625, 10.082699469157628, 17.181361300604685, 15.468176977975027, 13.776727489062718, 0.6338296575205666, 1.251603982278279, 50.43804012026106, 51.994391441345215, 37.07866225923811, 42.051505361284526, 40.911312920706614, 56.272619656154085, 13.330924987792969, 0.22081518971494266, 0.25061248508947237, 0.16418252645858697, 0.23671386231269154, 0.11081626971385308, 0.097858388242977, 0.2205185613461903, 0.10489065732274737, 0.07812043558806181, 0.18947524497551577, 0.185904183025871, 0.1319851577281952, 0.07134070367153202], [0.05482998230893697, 0.047306016220578125, 0.016605278610118797, 0.04779063271624701, 0.016225366853177547, 0.11072147158639771, 0.04406524815463594, 0.02415478984559221, 0.03651966394058295, 0.018458768259733915, 0.027392887876236012, 0.011109100854290383, 0.03226148350430386, 0.03999629417168243, 0.042379265052399466, 0.07455582650644438, 0.028442927602944628, 0.3449404149183205, 21.29541400500706, 44.11494663783482, 28.156721898487636, 28.02780328478132, 34.00443179266793, 44.173572063446045, 47.07635920388358, 48.3797995703561, 20.44366213253566, 0.054121605320168395, 2.785042098590306, 3.7100201674870084, 0.6163829479898725, 2.3397956703390395, 25.53675423349653, 50.239665576389854, 46.557231494358604, 50.97668531962803, 45.37160130909511, 44.05879477092198, 42.3558156149728, 45.63960027694702, 44.83649621691023, 39.554048333849224, 45.51755516869681, 46.4943641935076, 43.148056166512625, 41.11556911468506, 39.16267020361764, 37.108741010938374, 35.02678278514317, 32.802831172943115, 32.507491043635774, 32.38506725856236, 33.285664967128206, 33.45809146336147, 34.823085921151296, 35.44408117021833, 35.468854972294395, 35.364951610565186, 35.012629304613384, 34.32287120819092, 33.7831004006522, 33.22620575768607, 33.75132976259504, 35.773481369018555, 36.61573157991682, 35.39535345349993, 34.69047955104283, 35.42466442925589, 35.04587296077183, 34.39808893203735, 35.19897651672363, 33.38315166745867, 33.51642853873116, 34.71907138824463, 34.975723947797505, 33.73409823008946, 33.85323551722935, 34.072756903512136, 34.041413579668315, 36.459761892046245, 35.67492812020438, 36.29145220347813, 32.57963766370501, 35.92433718272618, 43.10021434511457, 50.3574583871024, 47.02990354810442, 51.19661317552839, 34.05887787682669, 40.13699524743216, 42.83669696535383, 57.36391414914812, 41.53499017442976, 50.14608723776681, 48.25330761500767, 44.36082948957171, 47.21365213394165, 43.04121371677944, 42.50583764484951, 39.2593126978193, 33.81043461390904, 32.65705796650478, 32.59925242832729, 32.20616504124233, 34.645955494471956, 34.40604114532471, 34.262550422123496, 34.6569128036499, 34.47757979801723, 32.98296669551304, 34.230640820094514, 34.4699159349714, 32.96626670019967, 32.47832945414952, 33.257007122039795, 34.50778014319283, 32.893303666796, 33.571819577898296, 34.81577294213431, 34.40306384222848, 33.542783055986675, 32.47973646436419, 34.43120057242257, 33.219945430755615, 33.22530596596854, 32.97380896977016, 33.032833916800364, 32.73474924904959, 31.659220218658447, 30.130269118717738, 30.794301509857178, 30.481677736554825, 31.686967849731445, 31.535917486463273, 32.196958678109304, 32.466434138161794, 31.23197201320103, 31.288912500653947, 33.85905115944998, 35.904645987919395, 40.314952509743826, 43.55456747327532, 44.40717397417341, 42.3184551511492, 39.61542872020176, 41.40962035315377, 41.88723952429635, 32.2632931300572, 4.174819477966853, 0.4247178669486727, 12.031322632517133, 10.528500233377729, 3.0997976660728455, 1.6169182253735406, 0.3014476772929941, 3.724554930414472, 47.828790051596506, 32.11644295283726, 23.285649061203003, 23.19064634186881, 35.671863964625764, 30.67636626107352, 1.4027512946299143, 0.03867956643391933, 0.09650963025965861, 0.05594075091981462, 0.036716774970825226, 0.04479520255699754, 0.06061292253434658, 0.06089429065052952, 0.06848236133477517, 0.03293644942875419, 0.03747732451717768, 0.0407510592070009, 0.007014561860289956, 0.04076003961797271, 0.019020098228273646, 0.03176831407472491, 0.02113809439885829, 0.038669992304806194, 0.0507937879966838, 0.07562149967998266, 0.009503899890530323, 0.006091823784767517, 0.017804160082180585, 0.05423700037811484, 0.058210094326308796, 0.0629929383950574, 0.042017792484589984, 0.04861117493627327, 0.006498268381359854, 0.01782482486617352, 0.03443033587453621, 0.8839116639324597, 28.57716086932591, 48.84997027260916, 27.51030319077628, 30.0866413797651, 39.259072984967915, 50.215055056980674, 49.43858344214303, 52.73552451814924, 20.78213667869568, 0.10761840202446495, 0.6901576178414481, 5.897104203701019, 2.4880330988339017, 3.0878272226878574, 30.76518508366176, 49.472730364118306, 48.60716894694737, 51.524790491376606, 47.54924317768642, 45.027206897735596, 43.738201413835796, 44.31867824281965, 45.51728766305106, 42.118253231048584, 45.43743201664516, 47.57603195735386, 45.01952913829258, 42.053537709372385, 41.81417921611241, 38.13615724018642, 37.46028164454869, 34.184900828770225, 36.094957147325786, 35.661952359335764, 35.13813461576189, 34.440323557172505, 36.69780370167324, 35.15671757289341, 36.14554698126656, 37.075347968510215, 36.84443153653826, 36.67468704496111, 35.8429286139352, 35.45712641307286, 35.32392597198486, 37.07917295183454, 36.61846569606236, 35.613596371241975, 36.56395707811628, 37.136224610464915, 36.303555965423584, 34.80066755839756, 35.78508833476475, 34.34652287619454, 34.634105341775076, 36.56824064254761, 36.138612679072786, 34.979642731802805, 34.62815073558262, 36.48645339693342, 35.354713439941406, 36.604590143476216, 38.40665408543178, 36.826182092939106, 34.89307859965733, 37.339191913604736, 46.02311304637364, 51.48340007237026, 49.3007937158857, 51.74170977728707, 34.76147624424526, 41.12372282573155, 44.74910872323172, 49.68482065200806, 43.67886727196829, 52.75246770041329, 48.82892765317644, 47.08960247039795, 47.14470863342285, 45.6075656073434, 43.58976704733712, 39.55866541181292, 35.68442978177752, 33.670880045209614, 35.60861103875296, 34.883281639644075, 36.72121565682547, 36.06163706098284, 35.36842918395996, 35.45898158209664, 35.82148994718279, 35.62512343270438, 36.603106703077046, 36.85401657649449, 34.65286200387137, 33.933084215436665, 35.185910429273335, 35.17177084514073, 35.339892932346885, 35.519476073128835, 36.66909721919468, 35.97968653270176, 35.75804941994803, 34.124343803950715, 36.18463059834072, 35.32033722741263, 34.19647305352347, 35.368783542088096, 33.67700835636684, 35.150922775268555, 33.96408012935093, 32.46625695909773, 32.30082035064697, 32.96153845105852, 32.45546988078526, 33.703526156289236, 33.25778532028198, 34.29530075618199, 32.412710666656494, 32.42666612352644, 36.40588903427124, 39.94094835008894, 42.90906940187727, 46.170063972473145, 45.43485770906721, 45.05669157845633, 40.057619026729036, 43.18721621377127, 43.043027196611675, 36.73930181775774, 6.230427963393075, 1.3491597303322382, 14.184393065316335, 2.1387247911521365, 0.40229233886514393, 0.5566496104001999, 0.27359001498137203, 3.1384932696819305, 52.685782364436555, 35.991300446646555, 31.54149341583252, 27.615120240620204, 37.69228546960013, 38.141048771994456, 1.8955984200750078, 0.1749780728880848, 0.02030566763798041, 0.04420776425727776, 0.04707483933972461, 0.09404839375721556, 0.040784236176737716, 0.07443912526858704, 0.016045918089470694, 0.0436314098270876, 0.020444570541647927, 0.0599361245653459, 0.05033412462632571, 0.019489145737939646, 0.14662631494658335, 0.19703754489975317, 0.08171621656843595, 0.1811380580599819, 0.08357569428959064, 0.18213074122156414, 0.13721421999590738, 0.12527410712625298, 0.14307845889457635, 0.1494452343987567, 0.08288694053356137, 0.15425612910517625, 0.07541457364069563, 0.17396360875240394, 0.10577947712902512, 0.1868964590664421, 0.08573772399021046, 1.085337064095906, 33.87460470199585, 59.191530091421946, 36.231652532305034, 38.34601020812988, 44.14514350891113, 53.439019203186035, 55.02850300925118, 56.57986204964774, 26.998104572296143, 0.2325834296643734, 6.067786702087947, 5.999363882201059, 1.1637325031416756, 3.8723487598555426, 33.81770590373448, 49.30253423963274, 50.32441970280239, 51.63943576812744, 47.007172516414094, 45.06045402799334, 43.84420313153948, 44.79296922683716, 45.348192828042166, 43.411312988826204, 46.073404107775005, 49.23831551415579, 46.94517721448626, 44.27008949007307, 44.245756898607524, 41.54193489892142, 40.25351306370327, 36.42440250941685, 38.146030630384175, 37.6386627469744, 38.31697368621826, 37.169864313943044, 39.574990204402376, 38.42842626571655, 39.35745600291661, 38.78721734455654, 38.83965539932251, 38.677168301173616, 37.66319683619908, 36.02591984612601, 36.60937745230538, 38.96802684238979, 38.66174677440098, 36.514909744262695, 38.02184895106724, 38.9170618057251, 39.377821172986714, 36.55697066443307, 38.03022847856794, 35.03090654100691, 37.09559849330357, 38.321556023189, 38.068801403045654, 37.3295373916626, 37.38489716393607, 37.192616190229145, 36.621634074619834, 38.80411188943045, 41.41540820258004, 39.10570192337036, 37.21800490788051, 38.58346489497593, 46.97510657991682, 52.18569619315011, 51.089023794446675, 53.621009894779746, 39.07137434823172, 42.288564000810894, 43.82861137390137, 51.542265210832866, 47.83025959559849, 51.63613189969744, 48.87872191837856, 48.59718785967146, 49.38166727338518, 48.04464626312256, 45.73317861557007, 42.91550343377249, 37.60567617416382, 36.148638929639546, 36.12199606214251, 36.27915389197213, 37.669978278023855, 38.24526827675955, 36.32637732369559, 37.955024651118684, 37.36006082807268, 36.80962453569685, 38.20620550428118, 38.24284335545131, 35.42385149002075, 35.3977575302124, 36.472897461482454, 37.77879401615688, 36.562390259334016, 37.10872711454119, 38.19214582443237, 37.62830993107387, 36.81137548174177, 36.571395124707905, 38.57087475912911, 37.32419075284685, 35.65240206037249, 37.776688711983816, 34.81440414701189, 37.40996626445225, 34.86592156546456, 34.143628529139924, 34.32873548780169, 34.354836395808626, 34.77349315370832, 35.80100318363735, 34.43258326394217, 37.185212884630474, 34.291044984545024, 34.92065599986485, 38.6013217653547, 39.91502114704677, 44.22986636843, 46.884505544389995, 46.59196901321411, 47.75307553155081, 41.07350124631609, 42.503332819257466, 43.890085560934885, 37.63737733023507, 9.136003937040057, 1.877674239022391, 26.483567884990148, 26.216425282614573, 8.048642992973328, 7.6465959038053235, 0.7761466237051147, 4.197643007550921, 59.37768622807094, 40.11052261080061, 35.215888432094026, 34.09594999040876, 44.06870985031128, 45.30777168273926, 3.4844158504690443, 0.25493554025888443, 0.11812346082712923, 0.12819403330130236, 0.19097862073353358, 0.18472377636602946, 0.13912364467978477, 0.17566014985953057, 0.1632940662758691, 0.13290097644286497, 0.13808421045541763, 0.199474286288023, 0.10619649796613626, 0.09559235269469873], [0.05709870146321399, 0.03883507987484336, 0.031471841769026856, 0.06157415559781449, 0.02086586275670145, 0.031432985461183956, 0.023752610265676464, 0.020728825824335217, 0.027303521421604922, 0.03742489411628672, 0.0349123400103833, 0.034053372352250984, 0.06318142185253756, 0.02978451856012855, 0.028689342683979442, 0.0481929157727531, 0.07377158930259091, 0.04586613776960543, 9.690810646329608, 39.95859677450997, 27.98569025312151, 23.146130970546178, 28.31709153311593, 36.885238306862966, 44.296600341796875, 46.13584756851196, 37.49974741254534, 2.6762899799006323, 3.037028725658144, 8.19056602886745, 1.2725956844432014, 0.9838407103504453, 13.390884467533656, 44.79275035858154, 44.115672724587576, 45.99119649614607, 40.953186239515034, 43.51310757228306, 43.017534255981445, 41.96650109972273, 36.22931446347918, 39.11745827538626, 39.87061520985195, 42.1020187650408, 43.613258906773154, 44.521388462611604, 40.373504979269846, 38.579066685267854, 33.69457687650408, 35.559737409864155, 33.23250777380807, 33.18717425210135, 34.2880676814488, 36.13202231270926, 37.2499075617109, 36.98570231028965, 37.49314314978463, 38.751461914607454, 38.05793442044939, 38.30188914707729, 35.48538473674229, 35.58349677494594, 35.96598468508039, 35.17396994999477, 37.34669944218227, 35.97441979816982, 36.3921663420541, 34.56464420046125, 36.558968271527974, 36.658595017024446, 35.79207474844796, 34.3290307862418, 33.735637256077354, 35.486145564488, 33.16801806858608, 35.013633319309776, 34.41336802073887, 37.29389313289097, 40.00780739103045, 40.876429489680696, 41.54081971304757, 38.018312317984446, 37.73613902500698, 35.62946605682373, 36.79734359468733, 44.73323903764997, 45.72499016353062, 47.30418021338326, 44.02364036015102, 42.29097849982125, 41.48139871869768, 50.0122823034014, 34.86936092376709, 35.39841413497925, 53.67403507232666, 44.410727977752686, 46.40664318629673, 44.295287132263184, 43.59937293188912, 37.95507328850882, 34.46683440889631, 31.910956927708217, 32.396007197243826, 33.36731324877058, 34.53410339355469, 32.64654881613595, 34.58632952826363, 33.78239515849522, 35.57918889181954, 33.73781899043492, 32.4708115032741, 32.765922342027935, 32.55753544398716, 33.839210578373496, 34.062414509909495, 33.70587117331368, 34.55374595097133, 32.51428638185774, 33.90439510345459, 34.36626965659005, 33.39170837402344, 33.28193378448486, 35.16677509035383, 34.779617990766255, 34.48083502905709, 31.318150520324707, 33.17128719602312, 32.49876410620553, 31.569373062678746, 31.927854946681432, 31.239080020359584, 31.650653089795792, 32.725105149405344, 38.31601136071341, 39.19528504780361, 40.367123058864046, 42.09944445746285, 41.11828933443342, 39.81920548847744, 36.45703819819859, 35.85707514626639, 39.73839446476528, 43.544339724949424, 46.422335692814414, 44.34404264177595, 40.785446303231375, 41.58994000298636, 14.451985563550677, 0.3398132143276078, 8.088543023381915, 1.659820094704628, 1.0129238069057465, 1.0037096270493098, 0.6337601212518555, 0.19883948963667664, 3.573485676731382, 49.78243241991316, 26.313257115227835, 23.971050637108938, 18.773919684546335, 40.70834214346749, 20.677189350128174, 0.10496626647987536, 0.05511232412287167, 0.06531204895249434, 0.05686668319893735, 0.013405360896805567, 0.07302399298974446, 0.02844427788763174, 0.02471545654615121, 0.08341092563101224, 0.057101422388638766, 0.022560612531378865, 0.060574564949742386, 0.022316736867651343, 0.03873276697205646, 0.01579802549843277, 0.05063761976946678, 0.02675060528729643, 0.029012600159538642, 0.04764777056074568, 0.06418629828840494, 0.05827536939510277, 0.028520105872303247, 0.033251622159566195, 0.026225091789716055, 0.04655639108802591, 0.025782517323802625, 0.05749849429620164, 0.03665490275514977, 0.10331469188843455, 0.038719589821994305, 0.06633007539702312, 0.02236628349471305, 14.45724708693368, 48.418459347316194, 34.18096120016915, 28.67917605808803, 36.65780987058367, 44.14783246176583, 49.38326188496181, 49.277968883514404, 39.10390928813389, 1.4879400091511863, 1.3015578389167786, 5.946761676243373, 3.775424429348537, 1.5367064837898528, 16.421382972172328, 48.841267653873985, 44.87169231687273, 46.73468153817313, 40.86633723122733, 44.71105343954903, 42.753408908843994, 43.08530003683907, 37.56878123964582, 39.34689474105835, 41.6308023588998, 44.82701192583357, 47.426513671875, 46.63411331176758, 41.70868819100516, 40.722829137529644, 36.853217533656526, 36.53041812351772, 35.253043924059185, 34.643245697021484, 35.05393981933594, 37.30238730566842, 38.874097619737896, 39.29735408510481, 39.69638565608433, 41.728528772081646, 39.898592131478445, 41.14306313650948, 36.930154936654226, 35.832402093069895, 37.14909267425537, 37.76302855355399, 37.786273751940044, 38.04813051223755, 37.45188822065081, 35.49862800325666, 37.93842887878418, 37.2426883833749, 36.96218613215855, 35.057170731680735, 35.890061719076975, 36.460731165749685, 34.540276868002756, 37.9487122126988, 35.466721875326975, 37.9924441746303, 41.59378930500576, 41.79082979474749, 43.072213104793, 38.47957195554461, 36.838716643197195, 37.66586147035871, 39.56514113289969, 46.51544850213187, 47.00524091720581, 49.260619231632774, 45.26440102713448, 44.09458146776472, 42.101334367479595, 51.470987115587505, 36.74499586650303, 39.31696884972708, 53.4004601751055, 46.19534846714565, 49.25133296421596, 45.27828005381993, 43.827537877219065, 39.883389472961426, 35.99199179240635, 34.409160886492046, 35.527914660317556, 34.65132992608206, 35.83628266198294, 34.394065925053184, 35.22877386638096, 35.61304746355329, 36.21224273954119, 34.9360671043396, 34.56430721282959, 34.721934046064106, 33.59836169651577, 34.69716371808733, 35.69890635354178, 34.73859582628523, 35.785949911390034, 33.9169157573155, 35.75804941994803, 35.5714624949864, 36.48771449497768, 34.7494523865836, 35.77387741633824, 36.18675674710955, 35.74867977414812, 33.583763531276155, 34.8886456489563, 33.45565264565604, 34.023052964891704, 33.55655091149466, 33.58406230381557, 33.18896688733782, 33.68101051875523, 39.79547739028931, 39.090377671378, 40.503700324467246, 41.003411293029785, 41.736084938049316, 39.730886936187744, 38.39028065545218, 37.17232745034354, 41.962005615234375, 45.398108686719624, 47.44393975394112, 44.762765407562256, 43.04663678577968, 43.76874222074236, 16.73076888493129, 1.1866943453039442, 7.570035440581186, 3.7268786685807362, 0.7484870936189378, 0.547777303627559, 0.05140312262145536, 0.17252392029123648, 4.164629076208387, 54.631382192884175, 31.740038190569194, 27.213069677352905, 21.243186133248464, 47.04115962982178, 26.261315856661113, 0.11526089800255639, 0.0752826121502689, 0.051083865109831095, 0.05379882621179734, 0.011369839809568865, 0.040457392643604956, 0.04135667545987027, 0.045326607434877327, 0.08937728404998779, 0.03067138757822769, 0.03607604453074081, 0.0341994541564158, 0.009274800175002642, 0.025195431862292544, 0.1306100386594023, 0.1531018324728523, 0.11396185628005437, 0.18088223678725107, 0.11962302321834223, 0.09946385637990066, 0.18283668905496597, 0.0996011918676751, 0.12042400666645595, 0.06482769030013255, 0.19192490567054066, 0.09645246368433748, 0.15772364661097527, 0.08636374039841549, 0.20395839852946146, 0.11879350058734417, 0.17696850108248846, 0.09401956958962338, 16.671153341020855, 54.584596497671946, 38.69522666931152, 34.51030581338065, 39.95325360979353, 46.90389101845877, 51.89197152001517, 54.701242855616975, 44.30443096160889, 3.253535028014864, 5.315419256687164, 18.535731962748937, 4.195887718881879, 1.7472551401172365, 20.332035848072596, 47.89463465554373, 45.44764586857387, 45.94552251270839, 41.57738808223179, 43.849980558667866, 44.16211795806885, 42.00842653002058, 40.5181873185294, 41.203658376421245, 42.69161857877459, 45.18344061715262, 48.45215811048235, 49.048726967402864, 43.10001284735543, 42.627698625837056, 37.91316522870745, 38.15483399799892, 37.58173268181937, 37.08292497907366, 37.76864964621407, 40.05539212908064, 42.061142512730186, 41.99396732875279, 40.67481708526611, 42.80703163146973, 42.648619651794434, 43.969816139766145, 38.55187838418143, 37.35685076032366, 37.81668949127197, 39.30714062282017, 40.11310386657715, 39.98233182089669, 39.793556213378906, 36.61195175988333, 40.93142100742885, 38.715473720005576, 39.772072383335654, 38.202324935368125, 37.403264726911274, 38.80098172596523, 36.12901026862008, 39.78730978284563, 37.92253140040806, 42.15022884096418, 43.70823730741228, 44.712752274104524, 47.52245787211827, 41.05413661684309, 41.149934904915945, 39.1599360874721, 41.615113326481406, 47.56060348238264, 49.24314103807722, 50.508234296526226, 47.74852793557303, 45.65379892076765, 41.07856995718819, 53.137095655713765, 39.28933933803013, 41.3259779385158, 54.43261160169329, 48.83375665119716, 50.5961081641061, 47.53690665108817, 46.30053377151489, 42.105941023145405, 37.37645162854876, 36.76900884083339, 36.167753423963276, 36.587994371141704, 37.75139726911272, 36.23081180027553, 37.17083706174578, 37.622101715632844, 38.90058415276663, 36.55151980263846, 35.2750106539045, 36.70844486781529, 35.655685084206716, 36.53507341657366, 37.97180802481515, 36.7816093989781, 38.856681959969656, 35.631098883492605, 37.98287650517055, 36.81983838762556, 38.67561190468924, 37.87950120653425, 38.67799513680594, 38.83464574813843, 37.60591241291591, 35.67762054715838, 38.0085848399571, 35.90254068374634, 36.531946727207725, 35.20920079095023, 35.464543615068706, 35.08706883021763, 34.28120286124093, 41.92359944752285, 42.39418356759207, 43.35816274370466, 46.44780431474958, 45.38322564533779, 43.25512095860073, 40.83105427878243, 39.58155972617013, 44.74345636367798, 48.4169203213283, 49.7910064969744, 46.12637717383248, 43.6732496534075, 42.502585887908936, 21.09778986658369, 1.8065705001354218, 12.734948464802333, 5.813197323254176, 3.4825307173388342, 4.364687689713069, 1.5437518485954829, 0.3592284896544048, 5.093356132507324, 59.991962569100515, 34.36354596274239, 33.98130471365792, 29.03769268308367, 53.070379052843364, 35.00388847078596, 0.3128305364932333, 0.2714333321366991, 0.19509479057575974, 0.1412613692560366, 0.10222687133188758, 0.16732609777578286, 0.11303457710891962, 0.158572914611016, 0.13454674955989632, 0.11051578726619482, 0.06912291196307965, 0.1690875475427934, 0.0995517877329673, 0.17007818152861937], [0.047620157578161786, 0.02449657302349806, 0.032794126708592684, 0.037979440430977514, 0.022772975332502807, 0.10711852527622666, 0.0735155576840043, 0.0012180864515747608, 0.04226933220135314, 0.043213941156864166, 0.03954815911129117, 0.04215165726574404, 0.002188956514666123, 0.02467426098883152, 0.048245156183838844, 0.08506072924605437, 0.09829561585294348, 0.027116769924759865, 1.6720157031502043, 25.207107373646327, 42.66695942197527, 16.552320037569316, 17.485344988959177, 28.469884157180786, 42.86156456811087, 45.68329054968697, 42.58945574079241, 3.3275626557213918, 0.3990945933120591, 3.6810618128095354, 4.211928938116346, 0.17238714120217732, 7.1367475134985785, 38.124814305986675, 49.083363737378804, 45.24824299131121, 44.60274144581386, 43.28779486247471, 43.728717122759136, 41.86871910095215, 42.92210422243391, 49.422237804957796, 46.57208326884678, 42.731080872671946, 41.42486817496163, 45.1397260257176, 41.37974309921265, 36.87405170713152, 35.960172516959055, 33.6532107761928, 33.978900636945454, 33.82311160223824, 34.34424039295742, 36.20773335865566, 37.912491253444124, 38.507180622645784, 41.35422236578805, 39.9025421823774, 42.287372384752544, 40.52245698656355, 39.26948833465576, 37.32456595557076, 36.011005537850515, 36.282624517168315, 38.159107140132356, 37.1739706993103, 34.59569569996425, 34.508169242313926, 35.409395762852256, 35.79586846487862, 36.41525520597185, 33.65756034851074, 35.06605747767857, 35.69954906191145, 33.26521641867501, 33.80050563812256, 37.07862057004656, 42.90662711007254, 46.36358519962856, 44.11560671670096, 45.54364218030657, 42.77261025565011, 44.045819010053364, 39.43359783717564, 36.269589696611675, 37.98218168531145, 44.792931011744905, 46.143667766026084, 48.223454679761616, 42.27569593702044, 42.85646459034511, 40.21849414280483, 41.407858984810964, 36.08406932013375, 43.74307557514736, 50.095073563711985, 43.114468574523926, 46.510233879089355, 40.69729798180716, 38.34402649743216, 33.71307298115322, 32.609685148511616, 32.67055484226772, 33.46515083312988, 33.21712793622698, 34.46114036015102, 34.37790094103132, 31.886217866625103, 33.595846448625835, 34.868311745779856, 34.49931376320975, 34.52510895047869, 33.31752940586635, 32.48599679129464, 32.80128867285592, 33.41043029512678, 34.62288400105068, 31.337935515812465, 33.26922900336129, 32.98882402692522, 36.05456379481724, 38.36823402132307, 39.66168635232108, 39.346359729766846, 38.26514707292829, 36.84858308519636, 34.12164095469883, 32.53508928843907, 32.21218565532139, 31.83675364085606, 32.826541900634766, 33.389648233141216, 37.23049776894705, 40.01191030229841, 43.60124894550869, 43.75924055916922, 43.465390818459646, 42.077092102595735, 44.40851845060076, 43.575693471091135, 41.49016734531948, 43.369304180145264, 43.54410696029663, 45.91979333332607, 43.169262068612234, 44.08169255937849, 26.59720914704459, 1.5693221965006419, 1.49611782176154, 6.631642137254987, 2.8092396344457353, 0.6650284805468151, 0.2670135721564293, 0.26389526948332787, 0.09640806713806731, 5.619470689977918, 45.15272610528128, 23.2350401197161, 28.347418682915823, 24.744569267545426, 39.98889786856515, 12.033138717923846, 0.08236133373741593, 0.0619858160082783, 0.03539763843374593, 0.02447924663179687, 0.04740763362497091, 0.07165515715522425, 0.040735184880239625, 0.07441703895373003, 0.03922728329364743, 0.04720850734572325, 0.027320438995957375, 0.06745199233825717, 0.02833741031853216, 0.060253590744520934, 0.031169791905475513, 0.046588207595050335, 0.04749803484550544, 0.05882505061370986, 0.04356800412227001, 0.03578384021031005, 0.015714857461197034, 0.01797360384703747, 0.03754753932090742, 0.027044329526168958, 0.15129083607878002, 0.0431294296202915, 0.02049998310394585, 0.05747973280293601, 0.06239203456789255, 0.02397829101287893, 0.04843892542911427, 0.017199514134387885, 3.40727738397462, 31.778169904436382, 45.35496384756905, 19.465541635240825, 26.811712196895055, 35.053658417293, 45.83789839063372, 48.61868211201259, 48.04755755833217, 3.2045738952500478, 0.20459829776414803, 1.7665861142533166, 5.092563603605543, 1.9224447395120348, 8.162118366786412, 41.62393059049334, 47.84489597593035, 45.789101191929404, 43.870891162327354, 45.274152823856895, 44.20925801140921, 41.61918149675642, 43.57174342019217, 48.80283716746739, 44.91526794433594, 43.82731900896345, 42.15038864953177, 46.26623746326992, 44.372936725616455, 39.14749881199428, 38.11336020060948, 35.75958149773734, 35.57100738797869, 37.71669449125017, 36.1256890296936, 37.62731981277466, 40.08784369059971, 41.46399348122733, 40.57313714708601, 42.45985794067383, 43.672266483306885, 42.17925841467721, 39.4974239894322, 39.306021962847026, 36.93604700905936, 38.52599287033081, 38.68882737840925, 38.4043299130031, 36.456864493233816, 35.02020978927612, 37.41721323558262, 36.79306697845459, 36.575956617082866, 35.76232951028006, 36.68186453410557, 37.47802734375, 34.286938599177766, 35.9225514956883, 38.02826908656529, 43.429538113730295, 46.36561407361712, 45.786915983472554, 46.758510385240825, 45.33193404333932, 46.05730513163975, 41.38026074000767, 37.92585263933454, 39.59700557163784, 45.79306861332485, 48.37524502617972, 49.59162099020821, 45.14973837988717, 42.48030301502773, 42.33074998855591, 43.0997314453125, 37.80760472161429, 47.387072222573416, 50.67404958180019, 45.088604654584614, 47.4620988709586, 42.717674323490684, 40.02449696404593, 35.862491267068044, 33.82720061710903, 34.42130981172834, 34.94861555099487, 34.78483608790806, 36.575518880571636, 35.32623624801636, 35.039966991969514, 34.68987505776541, 36.607633454459055, 36.617715290614534, 34.67476619992937, 35.15428917748587, 34.15576008387974, 34.469443457467214, 34.406371184757774, 35.84326212746756, 33.14395298276629, 34.42380768912179, 33.77651350838797, 37.75628185272217, 40.19477299281529, 41.528358118874685, 41.51380164282662, 39.26278679711478, 38.05830267497471, 35.875835282461985, 35.02513953617641, 33.700559275490896, 34.03752258845738, 33.4530679157802, 34.096808092934744, 39.01016419274466, 41.46914904458182, 44.578106607709614, 46.151988233838765, 45.022197246551514, 45.34526416233608, 47.04793412344796, 46.05979953493391, 44.316975934164866, 44.215650354112896, 45.29778364726475, 46.65232801437378, 45.12302255630493, 45.17034673690796, 31.194246768951416, 3.411848647253854, 2.5655005191053664, 9.439996310642787, 1.0550522548811776, 0.3556803757590907, 0.2259601814938443, 0.17760086857846805, 0.12238981761038303, 6.035071977547236, 50.24805900028774, 30.363224846976145, 33.3368627684457, 26.11880135536194, 47.7611597606114, 15.861571822847639, 0.03338687793750848, 0.08237195959580795, 0.024617608403787017, 0.05843734248940434, 0.010894157075589257, 0.018878823844715953, 0.0495760110206902, 0.05651517491787672, 0.016580410301685333, 0.03006397999290909, 0.009455785820526736, 0.03203946006085191, 0.053437560597168546, 0.029150583648255894, 0.10794306067483765, 0.14025898304368767, 0.12795882592243807, 0.13778294090713772, 0.13388724066317081, 0.2476637890296323, 0.12419219660971846, 0.292290060115712, 0.10827323581491198, 0.16793425514229707, 0.22185459679790906, 0.11938997358083725, 0.0959334522485733, 0.14810520916112832, 0.14573169366589614, 0.20438743622175284, 0.16200597610856804, 0.03331997099199465, 3.4260566277163367, 39.30014031273978, 52.08474928992135, 25.920108931405203, 27.090784856251307, 36.79183367320469, 50.891948563711985, 52.68186010633196, 51.580115522657124, 4.589770240443094, 0.8719300382903644, 12.425044911248342, 10.552102395466395, 1.2971138145242418, 12.384971175874982, 41.75947952270508, 48.597305979047505, 46.60592794418335, 44.84414618355887, 44.8480475970677, 44.38976526260376, 43.88725764410836, 44.54905618940081, 47.994230134146555, 47.316541058676584, 46.16349445070539, 43.62112079347883, 48.36870329720633, 46.71362502234322, 40.21273408617292, 40.16961356571743, 38.90310287475586, 37.46066379547119, 39.820105280194966, 37.60033300944737, 40.93894938060215, 41.81873723438808, 43.615103653499055, 44.14710637501308, 43.67485816138131, 46.171179158346995, 45.537114347730366, 41.496629170009065, 41.17719963618687, 38.536147662571494, 40.3245028087071, 42.16914531162807, 40.1477302142552, 37.83896541595459, 35.45772048405239, 39.684889861515586, 40.30426618031093, 38.83946779796055, 36.573458739689414, 38.87304496765137, 38.3319331577846, 35.89022152764456, 38.05629117148263, 40.687431539808, 46.15775523866926, 48.628809111458914, 47.45699889319283, 49.28902694157192, 45.80688510622297, 46.95752763748169, 44.3599852834429, 39.045190061841694, 40.975840841020855, 48.018111092703684, 48.19675622667585, 51.97648940767561, 47.90074907030378, 43.045076915196006, 42.70849575315203, 43.662955897195, 41.64049857003348, 48.63401331220354, 52.38145126615252, 46.179951259068076, 50.27631732395717, 44.46688331876482, 41.280303955078125, 38.0822878565107, 35.87106187002999, 37.192004748753135, 36.64954498835972, 36.069710867745535, 37.5395883832659, 38.08824593680245, 35.6925869669233, 37.032592228480745, 38.46709646497454, 39.00655460357666, 37.32048736299787, 35.831012453351704, 35.61921746390206, 37.52884299414498, 35.51308025632586, 37.85257346289498, 35.17457444327218, 36.698564529418945, 36.00793095997402, 39.819813455854145, 42.64717790058681, 44.16218744005476, 43.242106982639854, 41.928640365600586, 39.88286140986851, 37.39096641540527, 37.46001761300223, 35.85166597366333, 35.165892669132774, 35.31564024516514, 35.40451465334211, 41.42792190824236, 43.55911159515381, 47.25726250239781, 48.225598199026926, 47.15456812722342, 45.673559597560335, 49.597068377903526, 47.012269020080566, 45.76231241226196, 45.60820484161377, 47.2967004776001, 49.408671447208945, 45.750205176217214, 45.15070070539202, 33.27051789419991, 4.495428468499865, 3.3942625394889285, 14.978883096149989, 10.690063221114022, 1.8552743324211665, 0.8774957082101277, 0.7512391230889729, 0.3094244806894234, 6.900943458080292, 55.30537830080305, 33.67197438648769, 40.23941169466291, 33.42813777923584, 53.585087708064485, 21.336682830538066, 0.21551695758742945, 0.20663521917802946, 0.1210483538785151, 0.16037503576704434, 0.10107609629631042, 0.11359031085989305, 0.1468850267784936, 0.1275756164853062, 0.12523153583918298, 0.08510764315724373, 0.11015487448977572, 0.09423224960586854, 0.13177960232964583, 0.12744060158729553], [0.029896880566541637, 0.028177886735647917, 0.03887610410207084, 0.07014749305588858, 0.1041665111801454, 0.011095068750104733, 0.050899106809603314, 0.03846498651962195, 0.04102142148518136, 0.05594781107668366, 0.02555399012219693, 0.039813574869185686, 0.03483383011605058, 0.04842496796378067, 0.004699656523631087, 0.060074959615511556, 0.06957763899117708, 0.03339759539812803, 0.0728193468281201, 11.579994576317922, 43.00516298839024, 26.45316083090646, 27.080103737967356, 28.164083514894756, 41.60947486332485, 39.27211822782244, 47.164973054613384, 4.6380793281963895, 0.4698821891631399, 1.652445450425148, 4.357667403561728, 2.6517276636191776, 1.9000040122440882, 26.900400740759714, 42.81687375477382, 50.79913452693394, 46.334885665348594, 46.024328981127056, 44.91092184611729, 45.85257298605782, 44.942414556230815, 43.90537854603359, 46.417312145233154, 47.27831207002912, 46.188448905944824, 43.32582235336304, 44.86100598743984, 39.697813510894775, 36.25968851361956, 33.56204693658011, 35.08250386374337, 35.883005823407856, 37.05528851917812, 38.77901152202061, 39.90116991315569, 42.013078348977224, 42.11031838825771, 42.81748519624983, 41.83380787713187, 40.23335633959089, 39.76956408364432, 37.938699858529226, 34.315057958875386, 35.48734065464565, 34.46190813609532, 34.81148937770298, 35.21749694006783, 35.01697192873274, 35.95315831048148, 35.285954066685264, 34.9495188168117, 33.393216133117676, 36.13364124298096, 33.662132263183594, 33.415030002593994, 33.0830728667123, 38.56126887457711, 45.11930179595947, 46.98260368619646, 47.09606776918684, 48.09767491476876, 46.7367069380624, 46.72307109832764, 45.312673636845176, 39.662106718335835, 37.36393444878714, 40.444317545209614, 43.22150904791695, 46.517512117113384, 45.08559955869402, 42.48054272787911, 38.838383878980366, 41.922706604003906, 46.20834507261004, 43.17296893256051, 45.237633092062815, 45.04577248437064, 43.88406842095511, 40.06086383547102, 37.87642662865775, 34.203004360198975, 32.690339837755474, 32.08706249509539, 33.68669414520264, 33.05656896318708, 33.83607694080898, 33.17847858156477, 32.70030355453491, 33.163161277770996, 33.37112780979702, 34.96653495516096, 35.20848165239607, 31.832383223942347, 32.62828895023891, 33.052743979862754, 33.99579865591866, 33.49446528298514, 33.23830951963152, 33.428554671151296, 32.835098607199534, 35.42676625932966, 40.07684121813093, 42.795521940503804, 41.35884986604963, 41.71421895708357, 40.462539196014404, 38.60196099962507, 35.980555057525635, 32.2659056527274, 32.889690603528706, 33.16258805138724, 32.23068870816912, 32.453520911080496, 37.99871839795794, 42.032477719443186, 45.314448901585166, 44.01324585505894, 43.02734163829258, 43.3263886315482, 45.27554593767439, 43.391666957310264, 43.6646408353533, 44.17440932137625, 43.505950927734375, 43.91642270769392, 40.48235893249512, 12.085580246789114, 0.18152779500399316, 0.3972814120352268, 1.1419036516121455, 2.8976802144731795, 0.25182063026087625, 0.09058331897748367, 0.26769042440823143, 0.307416776993445, 11.323494877134051, 39.009809834616526, 19.00490733555385, 19.283304282597133, 20.806113174983434, 41.82489333833967, 2.5496143315519606, 0.04696253161611302, 0.0074021656598363605, 0.035166770286325894, 0.02338746512707855, 0.03475318283640912, 0.006515170264589999, 0.05865901987999678, 0.02054877655713686, 0.04452197686103838, 0.049671891411500316, 0.04403065983206034, 0.09916476492903062, 0.06223801390400954, 0.021866177740905966, 0.039626367057540586, 0.02694222696923784, 0.005692451219407043, 0.01893000743751015, 0.08941330747412783, 0.03689432722915496, 0.025197029812261462, 0.0382839771253722, 0.037939057419342656, 0.039636429731867144, 0.048288650278534205, 0.015544216082032238, 0.023231067894292728, 0.045354834491653104, 0.03562963294929691, 0.02077172280821417, 0.02288699466069894, 0.025651259813457727, 0.18023658357560635, 18.2975355557033, 49.025294167654856, 26.95668462344578, 24.402872494288854, 33.64686359677996, 47.05564662388393, 45.15197917393276, 50.89144481931414, 4.388182588985988, 0.32663733991129057, 0.30542318682585445, 1.5644616058894565, 2.627504289150238, 3.5206930467060635, 30.120965480804443, 45.09289864131382, 50.8356751033238, 46.590280600956504, 46.624976430620464, 44.2632211957659, 47.28094891139439, 45.50047302246094, 44.891425200871055, 46.4519419670105, 47.327105794634136, 47.27896172659737, 45.449216161455425, 46.014406953539165, 42.52856172834124, 38.224784987313406, 36.05662740979876, 36.47069488252912, 37.198230334690635, 39.571019308907644, 39.5322379384722, 42.42840344565255, 43.520861761910574, 43.96219049181257, 44.367062023707796, 44.396286146981375, 42.86831821714129, 41.895674637385774, 39.66685233797346, 35.998794078826904, 35.25494425637381, 36.31143174852644, 36.37833595275879, 35.903034005846294, 36.39353861127581, 36.50836106709072, 35.82148994718279, 35.82443598338536, 35.932164328438894, 36.684577805655344, 35.06860399246216, 35.0332168170384, 34.90905250821795, 39.16714831760952, 47.48782457624163, 47.089574677603586, 47.5393454687936, 49.83213983263288, 48.67404188428606, 46.83837645394461, 45.87342800412859, 41.173874923161094, 39.578933307102744, 42.56391416277204, 45.03436354228428, 48.47324241910662, 47.608987263270784, 41.65497166769845, 42.48915849413191, 44.18915687288557, 44.952214990343364, 43.577260289873394, 47.56617593765259, 46.11008712223598, 46.075558049338206, 40.75149393081665, 38.567817551749094, 35.497154985155376, 34.15531192507063, 33.89224965231759, 34.54543243135725, 34.54624884469168, 34.082727568490164, 35.63169642857143, 33.681135586329866, 35.09025805337088, 35.41204302651541, 35.7796756880624, 36.19361114501953, 32.865712370191304, 34.92481449672154, 35.15422316959926, 35.027713843754356, 35.45738002232143, 35.688904421670095, 34.62080301557268, 35.30171952928816, 38.56601449421474, 41.89718934467861, 44.329072747911724, 43.49569886071341, 42.89403002602713, 42.52623060771397, 39.86818334034511, 36.53182165963309, 34.067809786115376, 33.926771777016775, 34.744081429072786, 34.34145763942173, 34.68684911727905, 38.91401154654366, 43.757169995989116, 46.495587076459614, 45.0238995552063, 45.40487970624651, 43.99512842723301, 46.06041445050921, 45.28034366880144, 44.71470124380929, 45.745883396693635, 44.849940981183735, 42.93260989870344, 42.26267153876168, 14.04450672013419, 0.8173876021589551, 1.719063150031226, 2.680061331817082, 1.4954706622021539, 0.3016169582094465, 0.14851504431239196, 0.20170011185109615, 0.46333465192999157, 12.390761630875723, 42.359560694013325, 27.250167846679688, 27.06402908052717, 23.160221917288645, 49.02872657775879, 4.606924039976938, 0.07440709841570683, 0.022396293402250324, 0.02787589794024825, 0.018453377299010754, 0.05414121498220733, 0.013397268518539411, 0.020800321362912655, 0.1293295616550105, 0.047201362371976884, 0.014686892174982598, 0.013863679919657963, 0.06889904290437698, 0.046077325008809566, 0.058242379022496085, 0.1665101729865585, 0.05070513739649739, 0.1609967231218304, 0.15615836131785596, 0.2329491600394249, 0.07113921269774437, 0.12056685185858182, 0.11490231938660145, 0.12224674171635083, 0.17907694008733543, 0.11289917544594832, 0.1412734743207693, 0.09427528229675122, 0.15997280020798954, 0.08470729392554079, 0.11098793907357113, 0.11924263648688793, 0.07009611438427653, 0.2976720913180283, 20.59722079549517, 57.246694564819336, 35.04715142931257, 36.410318510872976, 37.73553105763027, 51.488729340689524, 47.32147427967617, 57.96515219552176, 6.123402689184461, 0.8942141596760068, 4.863225281238556, 11.899927854537964, 4.713674426078796, 3.6085934042930603, 34.12296806062971, 43.485860211508616, 51.12864242281233, 46.91173553466797, 46.34550251279558, 43.843675068446565, 47.74417836325509, 47.53677116121565, 46.25328949519566, 47.10563543864659, 47.39519466672625, 48.408506052834646, 48.140281268528526, 47.402910641261506, 45.074360847473145, 40.44273683003017, 38.05289697647095, 39.75959341866629, 40.213335105351035, 41.708841051374165, 43.23673602512905, 45.16135229383196, 46.155976499829976, 45.5174092565264, 47.23056752341134, 45.89019053322928, 44.714753355298726, 43.91335160391671, 41.77799647194998, 37.77743216923305, 37.8384929384504, 37.87580476488386, 37.784269196646555, 37.94672850200108, 39.38547113963536, 37.604241371154785, 37.99293402263096, 37.78303241729736, 37.43779379980904, 39.433396339416504, 37.44756644112723, 37.117804936000276, 36.783707754952566, 40.515310764312744, 48.60893726348877, 48.44643974304199, 49.832845074789866, 52.16926717758179, 49.96876573562622, 49.13989775521414, 48.78750596727644, 42.04526587894985, 41.86911514827183, 44.1596930367606, 46.119814600263325, 49.50353520257132, 49.631256989070344, 42.53582606996809, 41.89031062807356, 44.51302630560738, 48.95204278400966, 46.9452988079616, 48.115764549800325, 48.42572716304234, 47.37030274527413, 43.10881968906948, 41.023307459695, 37.591929163251606, 35.65054341724941, 35.50388431549072, 37.54243714468819, 36.19818305969238, 36.263371058872764, 38.67000470842634, 35.63022688456944, 36.60625076293945, 38.22100516727993, 38.26144715717861, 39.01430531910488, 35.14230700901577, 36.48983369554792, 36.67109135219029, 37.95836673464094, 36.813289710453574, 37.02827739715576, 36.36682973589216, 36.55363552910941, 39.537157263074604, 43.85126944950649, 46.39192342758179, 45.42672136851719, 45.21467276981899, 45.08439404623849, 42.44234848022461, 39.10100146702358, 35.20870399475098, 36.885828903743196, 36.56790712901524, 36.062550749097554, 36.65354367664882, 40.44606154305594, 46.46693270547049, 48.55012771061489, 47.442894050053184, 46.7531533241272, 45.2998993737357, 46.822256633213584, 46.62343740463257, 46.4651574407305, 48.808194228581016, 44.89367641721453, 42.19238703591483, 45.62218114307949, 16.892500366483414, 0.9810728303023747, 0.9568493472678321, 6.735678817544665, 7.769615496907916, 1.0838641545602252, 0.2073246514690774, 0.5818126744457653, 0.4153582363256386, 14.52380301271166, 48.390298298427034, 28.388689245496476, 29.701982157570974, 27.996199403490337, 57.38156257356916, 7.501358577183314, 0.12282836836363588, 0.09811479305582387, 0.1850408829216446, 0.09587887089167323, 0.23697216702359064, 0.19079905322619847, 0.18871338585657732, 0.27333602575319155, 0.10733693891337939, 0.06854096640433584, 0.1397457527262824, 0.24138291605881282, 0.12697500442819937, 0.13726078106888703], [0.03173845174855419, 0.05311993496226413, 0.023304217361978123, 0.047863147753689966, 0.026678407464974692, 0.07825465660010066, 0.027240543193849068, 0.026555970909872224, 0.042587415847395144, 0.04393559707594769, 0.07453161637697901, 0.028291397162580063, 0.07390987473939147, 0.09409811680338212, 0.029550240774239813, 0.014256351527624896, 0.06072701819773231, 0.048427441223923645, 0.07168643083423376, 3.057504198380879, 39.92631891795567, 34.38372700554984, 26.23920147759574, 28.771359545843943, 34.21154369626726, 34.07876014709473, 53.73459209714617, 8.826248901230947, 0.11716615648141929, 0.2905364270721163, 2.0926397783415656, 2.6025431028434207, 0.47312748645033154, 14.551246660096304, 43.375376905713765, 48.213977336883545, 47.18584891727993, 47.54845108304705, 47.120820726667134, 42.761253425053184, 43.3167792728969, 45.56369468144008, 42.68094614573887, 44.03158562523978, 43.94531331743513, 42.88072075162615, 41.941696030753, 39.657645974840435, 35.613853454589844, 32.349416051592144, 35.396826471601216, 36.36085775920323, 37.54583828789847, 38.36720221383231, 40.31951052801949, 39.60669136047363, 43.00313758850098, 43.02218607493809, 41.33806780406407, 40.0978456224714, 39.259215423039024, 38.548515456063406, 35.44379281997681, 35.298992361341206, 34.28306497846331, 35.55079855237688, 33.93806954792568, 36.60492713110787, 35.201755796160015, 33.886298520224436, 34.35413462775094, 34.53498928887503, 35.29535845347813, 33.66269506726946, 32.493935108184814, 33.420776162828716, 38.82853133337838, 46.87232187816075, 45.80708312988281, 45.1216641834804, 43.46278871808733, 51.23084347588675, 65.16624437059674, 45.606759616306846, 43.50000326974051, 40.23738282067435, 39.99071134839739, 45.31987544468471, 46.31000764029366, 46.2734740121024, 45.081159659794395, 39.944623947143555, 44.02620424543108, 44.71888753346035, 44.18611356190273, 44.77321202414376, 42.528294222695486, 41.73862450463431, 39.724105494362966, 37.19947058813912, 33.74425997052874, 32.18370846339634, 33.74010842187064, 33.37457064219883, 32.583691937582834, 33.16762202126639, 33.04938799994332, 32.39747674124581, 33.301246302468435, 34.275720732552664, 33.81818880353655, 34.02331352233887, 33.10501527786255, 33.678853103092735, 32.661647251674104, 33.9216023172651, 32.829369817461284, 35.25216497693743, 34.60493332999093, 33.53410128184727, 34.69935934884207, 41.65587840761457, 44.151334353855674, 45.23316887446812, 42.013516085488455, 43.705537932259695, 41.07596090861729, 39.74808372770037, 37.56797872270857, 35.751820359911235, 32.16933611461094, 31.3336797441755, 30.785807337079728, 35.30743442262922, 37.431092262268066, 42.16948924745832, 42.95355871745518, 43.15842635290963, 43.94497285570417, 45.65259688241141, 43.50218847819737, 45.57523563929966, 43.051208700452534, 44.351216656821116, 42.94432456152779, 27.79375147819519, 2.008151637656348, 0.11603986977466516, 2.525328206164496, 0.8265011417014259, 0.22793334775737353, 0.07765559160283633, 0.04754999027188335, 0.15072463931781904, 0.4987795299717358, 19.9771340233939, 40.140712533678325, 18.800301994596207, 19.383241959980555, 33.70955719266619, 29.477628299168178, 0.2726077676883766, 0.06211755358214889, 0.02039049130066165, 0.027907741588673422, 0.08473281362759215, 0.013519839084308063, 0.06752042259488787, 0.05554537534979837, 0.06454218312033586, 0.030204470668520247, 0.021063776154603277, 0.022226876778794185, 0.01674610685690173, 0.06964100059121847, 0.027293606328644922, 0.02371716020362718, 0.013574062513985803, 0.03236197454056569, 0.018827870953828096, 0.04702024780479925, 0.06893664731511048, 0.018844437386308397, 0.051495729080800495, 0.013406689129104572, 0.010641182257261659, 0.02288290479087404, 0.033276524394750595, 0.03406156226992607, 0.07009432983717748, 0.033484268068735085, 0.046547777085964165, 0.02942239459870117, 0.04855686499338065, 0.010322360704386873, 5.067981745515551, 46.18988718305315, 37.93916538783482, 25.88849810191563, 35.727098669324604, 41.1935487474714, 39.129586356026785, 56.77962275913784, 9.282186218670436, 0.23635529726743698, 0.47694937565496986, 0.41949987837246483, 0.5315853410533496, 0.7204464982662881, 17.174390520368302, 44.683469091142925, 49.69942576544625, 46.95993866239275, 47.38159009388515, 47.019554206303184, 44.750751972198486, 44.79513359069824, 45.487591062273296, 43.59588146209717, 45.72615051269531, 44.80409329278128, 45.035885197775706, 43.49473653520857, 40.528748580387656, 37.67006860460554, 36.669125011989046, 37.07332604272025, 38.60008151190621, 39.95239898136684, 40.91936935697283, 41.1676458631243, 42.958408560071675, 45.32430492128645, 45.02873550142561, 42.477999687194824, 42.68904079709734, 40.534109115600586, 40.16567741121565, 36.17794990539551, 36.39201348168509, 36.997555937085835, 35.89897973196847, 35.55724995476859, 38.65136269160679, 37.338486671447754, 36.261898040771484, 35.40199940545218, 35.919800009046284, 36.004773003714426, 34.71386023930141, 34.202917507716585, 35.023211411067415, 41.38642726625715, 48.11637599127633, 47.16034555435181, 47.480848584856304, 44.72432797295706, 51.0257500239781, 62.446858406066895, 47.431568486349924, 45.91641303471157, 41.06736946105957, 40.9420621735709, 46.371210847582134, 47.995352268218994, 47.57566717692784, 44.94176837376186, 42.17240054266793, 46.11073330470494, 47.039759567805696, 44.890549727848594, 45.28104543685913, 44.179936613355366, 43.47146006992885, 40.534724031175884, 38.62005410875593, 35.89498104367937, 33.967005320957725, 34.650930404663086, 34.55367646898542, 34.11758320672171, 34.735747064862935, 34.13832010541643, 32.97353451592581, 35.162925788334434, 35.756597246442524, 35.59971387045724, 36.845070770808626, 34.599805559430806, 35.00619527271816, 34.91587911333357, 34.97759648731777, 34.13690267290388, 35.52632004874093, 35.0611173084804, 35.549085821424214, 38.14792054040091, 44.064530508858816, 45.21553782054356, 45.75649677004133, 43.349890913282124, 45.37224401746477, 43.09029579162598, 41.26723786762783, 39.084867749895366, 36.48597744532994, 33.97083725248064, 33.35466752733503, 33.80810349328177, 36.236686502184185, 39.87885924748012, 44.89624377659389, 44.302964891706196, 45.10735436848232, 44.67252915246146, 45.70042828151158, 44.30646678379604, 46.93717983790806, 41.65180328914097, 45.405286175864084, 41.6963655608041, 31.309267248426163, 3.0546930006572177, 1.5650384149381091, 6.194368549755641, 1.8257516537393843, 0.13710634649864265, 0.0687405914068222, 0.12385809953723635, 0.07439774820314986, 0.644501656293869, 20.814075810568674, 45.24357727595738, 24.21669203894479, 19.218500171388897, 33.642298630305696, 37.859497342790874, 0.6542732119560242, 0.04060829883175237, 0.03317904944664665, 0.03202022359307323, 0.021626508994294063, 0.05806165800562926, 0.07371077899421964, 0.07575274192328964, 0.016173262149095535, 0.0515650108988796, 0.007919537585361727, 0.02311592050162809, 0.01495511706785432, 0.039544596802443266, 0.026934386497097354, 0.10736805652933461, 0.11822114272841386, 0.0942313607249941, 0.10962328980011599, 0.13749335573187896, 0.15314090251922607, 0.0691025084150689, 0.0879374055990151, 0.10006067542625324, 0.12882524728775024, 0.18271050868289812, 0.08208652026951313, 0.17831001909715788, 0.18708891873913153, 0.10640297617231097, 0.17063973711005279, 0.1765242913471801, 0.1793822401336261, 0.11372414510697126, 5.785061895847321, 54.79107958929879, 43.406306811741416, 36.504070554460796, 38.44219759532383, 44.961921623774934, 41.95379284449986, 61.760286058698384, 11.361296551568167, 0.3108957345996584, 1.2722412177494593, 7.659689784049988, 7.1786260434559415, 1.4674867923770631, 21.75909682682582, 45.29362515040806, 49.73711626870291, 46.99544048309326, 48.15081821169172, 47.569834164210725, 45.35950102124895, 45.37774699074881, 48.2282315662929, 45.50770957129342, 48.32846280506679, 46.954925537109375, 45.18472950799124, 45.576257024492534, 43.15655728748867, 41.246483598436626, 37.63617876597813, 39.242025579724995, 40.06154475893293, 42.03430509567261, 41.05301448277065, 43.80248614719936, 45.14086553028652, 47.99226726804461, 46.180569648742676, 44.498692171914236, 44.289634772709434, 42.61895431791033, 42.125552313668386, 38.74903351919991, 38.78628976004464, 39.5169484274728, 37.85319880076817, 37.639458315713064, 42.32475021907261, 38.51356601715088, 37.527561051504954, 37.49703761509487, 38.1268744468689, 38.99749762671334, 36.265149797712056, 35.91323743547712, 36.739930629730225, 43.27109139306204, 49.87016037532261, 47.972961698259624, 49.78468016215733, 45.39145926066807, 52.353721005576, 60.83994156973702, 49.5887131690979, 47.74641220910208, 43.632599217551096, 42.45322935921805, 47.65208346503121, 50.967263562338694, 49.02605152130127, 45.38445895058768, 42.52063383374895, 47.600982938494, 48.30533920015608, 47.63148900440761, 47.544306482587544, 45.55973073414394, 44.45366089684622, 43.15267671857561, 39.98718861171177, 38.724666186741416, 35.038751057216096, 36.78881468091692, 35.80731214795794, 34.654908248356406, 36.3150760786874, 34.792882101876394, 35.17028393064226, 36.90398107256208, 37.372779505593435, 38.63373858588082, 38.99296392713274, 35.828618798937114, 35.9855751310076, 36.766806261880056, 35.63917963845389, 35.192400046757285, 37.76384844098772, 37.72969109671456, 37.64865773064749, 38.29762642724173, 45.1027511869158, 47.426346915108816, 49.31429059164864, 46.12921551295689, 47.30126196997506, 45.55123656136649, 43.52614934103829, 41.47524608884539, 39.29304620197841, 36.430100032261436, 34.31793103899275, 34.66520200456892, 38.029373850141255, 41.07799325670515, 46.701382296425955, 47.503350325993125, 46.209116322653635, 47.269668510981965, 46.93026638031006, 45.88474314553397, 47.20255586079189, 42.29185049874442, 45.04199613843645, 42.38660308292934, 33.08319446018764, 4.41762558051518, 1.1511368304491043, 7.349078382764544, 3.179939925670624, 0.6831070961696761, 0.24898017410721096, 0.42393850162625313, 0.6479919861469949, 2.5054007726056233, 23.89363728250776, 50.9880108833313, 28.409823928560527, 26.510441780090332, 41.618775027138845, 44.06996052605765, 1.3608569140945161, 0.18912191822060517, 0.12253784681005137, 0.10178882947989873, 0.23625319131783076, 0.16734406538307667, 0.20409800032419817, 0.16109854408672877, 0.1278249645339591, 0.2851218261889049, 0.061777641464556964, 0.10028320098561899, 0.09058378038129636, 0.21740739686148508, 0.12542491831949779], [0.03911486700443285, 0.09676661861262151, 0.01756430134576346, 0.027244826446154287, 0.05107972604621734, 0.06390809893075909, 0.04291927714699081, 0.06515542949948992, 0.02616113138252071, 0.024088408764717833, 0.035925331725073714, 0.05405009790722813, 0.06558816520763294, 0.011352955313798572, 0.05133122165820428, 0.1138154419937304, 0.03105467165421162, 0.02239272091537714, 0.051399146406246085, 0.16137265866356237, 22.917029755456106, 42.10008021763393, 29.027433667864116, 27.04900186402457, 28.80091370855059, 31.84564733505249, 51.51854753494263, 16.65904610497611, 0.22709385066160134, 0.083392069142844, 0.1633125495697771, 0.582266315817833, 0.5459712605391229, 4.877906390598842, 26.6573805468423, 44.3185601234436, 47.833848340170725, 48.38303048270089, 47.40203169413975, 47.92168746675764, 43.08264929907662, 44.24603482655117, 48.159805706569124, 45.966728414808, 44.310500213078086, 43.461899348667686, 42.053589820861816, 36.673095907483784, 34.97026266370501, 33.19523763656616, 33.101461274283274, 34.71228994641985, 36.235203061785015, 37.45018591199602, 36.63540540422712, 37.54865230832781, 38.95381082807268, 39.925644942692344, 40.378907203674316, 39.5776617867606, 39.65600272587368, 35.761123997824534, 36.64622722353254, 35.51756879261562, 35.13608142307827, 35.330634457724436, 36.70872279575893, 36.013920307159424, 36.33239098957607, 35.37428304127285, 34.679355485098704, 34.25766931261335, 35.20593861171177, 33.53676244190761, 32.63127320153372, 32.060666288648335, 37.93613249914986, 46.060456139700754, 45.625009059906006, 46.81127153124128, 42.60653093882969, 46.74244267599923, 45.228200912475586, 44.66064773287092, 45.90692179543631, 43.10700273513794, 41.92867163249424, 41.8174136025565, 44.8603389603751, 46.55481352124895, 44.384939738682334, 39.45808328901018, 46.65231759207589, 47.025970867701936, 45.141598565237864, 42.34600823266165, 41.96056038992745, 39.812497002737864, 37.57974549702236, 35.07226569311959, 34.191866397857666, 32.69693715231759, 32.41007382529122, 32.00256197793143, 32.36306231362479, 32.72320829119001, 33.036137785230366, 33.1802955354963, 32.289244651794434, 33.64816638401577, 33.3765161378043, 33.40993002482823, 34.2535525049482, 34.01819269997733, 33.41148294721331, 34.63821867534092, 33.73688098362514, 34.90305273873465, 32.791793959481375, 34.67473840713501, 32.33024249758039, 39.9084655216762, 43.399403776441304, 45.59160559517996, 44.03606373923165, 42.802741118839805, 44.938659054892405, 42.08639226640974, 40.12484632219587, 37.0851970400129, 35.172267641339985, 31.61885813304356, 30.103594984327042, 30.790466104234966, 31.63914339882987, 34.345654351370676, 39.3510046005249, 40.525764329092844, 42.13204887935093, 42.274090903145925, 43.58405910219465, 46.03776332310268, 44.31427308491298, 42.85335527147566, 41.56640298025948, 12.318506445203509, 0.07924792330179896, 1.5573170121226991, 3.641046919992992, 0.2608113278235708, 0.2684950583747455, 0.017445766367018223, 0.07797137501516513, 0.39396302295582636, 0.4156009890139103, 24.05493450164795, 31.532089029039653, 20.220155954360962, 23.931965282985143, 39.891404220036094, 20.18215799331665, 0.1309663781097957, 0.04236055784193533, 0.028034598799422383, 0.007176378891537232, 0.009392071382275649, 0.05411811086482235, 0.024764446774497628, 0.024988392168389897, 0.021613723698205183, 0.0465434446398701, 0.03928085024069462, 0.0106580175592431, 0.018448184809780548, 0.05121252213471702, 0.010395303218891578, 0.0956139097522412, 0.02942467786903892, 0.014644013850816658, 0.03528552748528974, 0.01620816090144217, 0.02032873104326427, 0.03840223220842225, 0.03696558697681342, 0.027420253193538104, 0.026457978578816568, 0.04548791217218552, 0.026894956827163696, 0.0586448995662587, 0.014552350555147444, 0.005758889975758004, 0.04572886674265776, 0.01073056906794331, 0.0692817298695445, 0.017454687406175902, 0.5589554895247731, 30.80228499003819, 44.60765034811837, 29.94081606183733, 32.65016882760184, 38.637104988098145, 34.8193929536002, 56.555859497615266, 15.16612662587847, 0.3403912175978933, 0.13739567383059434, 0.15282169250505312, 0.2022033269916262, 0.3503089025616646, 7.528214233262198, 30.50682326725551, 47.310298102242605, 48.50990111487252, 47.934194224221365, 48.05518668038504, 48.47147410256522, 45.9772549356733, 46.92880378450666, 50.77555234091622, 47.25299630846296, 45.56816584723336, 46.10949305125645, 43.50556877681187, 38.974332332611084, 36.9790563583374, 33.57513039452689, 35.84514856338501, 37.39373527254377, 38.602496010916575, 39.85575301306588, 38.86214671816145, 40.07497910090855, 40.751188210078645, 42.442053181784495, 42.50757122039795, 41.04968976974487, 41.625969886779785, 37.84506940841675, 38.16248049054827, 35.413349287850515, 36.701437609536306, 37.54611621584211, 38.37467500141689, 37.18176310403006, 37.583344663892476, 36.55079024178641, 35.23033026286534, 36.467463970184326, 36.58488505227225, 34.68630368368966, 34.842919554029194, 33.80010264260428, 39.9743344443185, 47.81208310808454, 47.34300674710955, 47.645305497305735, 45.555850165230886, 47.44433927536011, 51.23386246817452, 46.7209484236581, 48.372163500104634, 43.43298789433071, 42.9573107446943, 43.64084325517927, 47.56491136550903, 47.293389660971506, 45.5590671811785, 43.25447130203247, 48.30637100764683, 48.34478759765625, 46.41962936946324, 44.74730913979666, 42.7705466406686, 41.72635746002197, 39.87028169631958, 35.4471036366054, 35.70730325153896, 33.32633972167969, 34.19011892591204, 34.69598599842617, 34.28608397075108, 35.29581356048584, 34.64003562927246, 33.8177614893232, 34.065072195870535, 34.265277590070454, 34.24845600128174, 35.88433640343802, 35.57573216302054, 35.9144846371242, 33.417149203164236, 34.92073243004935, 35.710857255118235, 35.92612981796265, 33.808701038360596, 36.497921398707796, 33.9111522265843, 42.351566791534424, 43.54348162242344, 46.36150074005127, 45.78189243589129, 44.66517448425293, 45.56205143247332, 44.80602489198957, 40.394926275525776, 38.74885981423514, 36.825160707746235, 33.7332957131522, 32.18065125601632, 33.07337318147932, 33.70399863379342, 37.3564373425075, 41.78064373561314, 43.02201236997332, 43.84259114946638, 44.328475202832905, 45.017938000815256, 47.00216633932931, 43.38832834788731, 43.908369745527, 42.72470242636544, 15.012465476989746, 0.5210778191685677, 3.801921818937574, 8.215266874858312, 1.5304544078452247, 0.36187629614557537, 0.12846512161195278, 0.024118274483563643, 0.18445443867572717, 1.4477503257138389, 28.270305837903702, 38.6560492515564, 24.281233855656215, 23.354653358459473, 44.963988712855745, 25.735606466020855, 0.029112568723836114, 0.046661916854126115, 0.06215092393436602, 0.10089648807687418, 0.05119694975603904, 0.032231034245342016, 0.024559537680553536, 0.06727609570537295, 0.023103935876861215, 0.03102906034993274, 0.022432377894542048, 0.055646290470446856, 0.012189416813531091, 0.02053304302639195, 0.05320716403158648, 0.13842368152524742, 0.13144402605082306, 0.08595189678349666, 0.10417206159659795, 0.10659460124692746, 0.12060593547565596, 0.1276833949876683, 0.1863561009189912, 0.12639545409807137, 0.07030333219362156, 0.1418631619640759, 0.2679796703159809, 0.09852180550140993, 0.10886660111801964, 0.13045844036553586, 0.218620237495218, 0.2088647631130048, 0.12015523894556931, 0.12105382287076541, 0.7364948828305516, 34.519154344286235, 54.161548478262766, 39.19949565614973, 36.38052463531494, 39.08061892645699, 38.25424187523978, 60.99360792977469, 20.2860335622515, 0.4140568604426724, 0.40181136610252516, 1.0014428858246123, 4.013288625649043, 1.2143143032278334, 8.588749919618879, 29.78327260698591, 46.16170876366751, 48.11431237629482, 47.91289799554007, 47.213801520211355, 49.4862619808742, 47.52439989362444, 47.95333998543875, 52.65889630998884, 49.408396993364605, 48.11741474696568, 48.91543967383248, 45.89728464399065, 40.90646307809012, 38.14384542192732, 36.288318565913606, 36.83003486905779, 38.922651631491526, 40.19499880926949, 41.913847650800435, 39.752075467790874, 41.36816392626081, 42.67607545852661, 43.930680411202566, 44.720155579703196, 43.683456557137625, 43.27676459721157, 39.65078115463257, 41.523522172655376, 38.012514046260286, 37.85804864338466, 39.13058342252459, 41.437579904283794, 39.21254089900425, 39.13350861413138, 38.73823949268886, 36.22774417059762, 37.52761663709368, 39.74559627260481, 36.397221156529014, 35.16009439740862, 35.25663266863142, 41.21149247033255, 49.62563937050955, 50.028297901153564, 49.4315310205732, 47.93126555851528, 46.375688961574006, 49.82154730388096, 47.9357784135001, 49.671775409153526, 47.08114651271275, 45.14101839065552, 46.42609466825213, 49.978920527866904, 49.5694214957101, 43.726358209337505, 41.20858812332153, 50.33276448931013, 50.69385542188372, 49.14167301995413, 44.81904581614903, 45.176989214760916, 42.58419942855835, 40.82376561846052, 37.94811814171927, 37.84933907645089, 35.70286682673863, 36.01545238494873, 35.855167865753174, 35.678030490875244, 36.82726601191929, 37.076935631888254, 35.460993085588726, 34.977697236197336, 35.94203424453735, 35.929232188633506, 37.02342408043997, 37.88325670787266, 37.76628378459385, 36.061393874032156, 36.870007855551584, 38.0945132119315, 37.94896929604666, 35.77781009674072, 38.41688878195626, 35.82991116387503, 43.56994036265782, 45.28808396203177, 49.27544321332659, 47.528742517743794, 45.562228611537385, 48.63177599225725, 46.52365779876709, 42.744584696633474, 40.65982634680611, 37.83201026916504, 35.047231333596365, 33.33889511653355, 34.05869027546474, 34.196667603084016, 38.3733617918832, 42.87162208557129, 44.92325837271554, 45.24260105405535, 45.57735136577061, 47.267003876822336, 49.18997342245919, 44.53759513582502, 44.08759157998221, 42.76250410079956, 17.79052029337202, 0.5123822029147829, 2.6126418752329688, 7.524489998817444, 2.544722148350307, 0.8379857540130615, 0.21466626466384955, 0.2946114369801113, 1.3131099790334702, 2.8939184163297926, 29.70769010271345, 42.307886941092356, 29.66608428955078, 33.683331217084614, 51.05643326895577, 32.2269401550293, 0.18967431357928685, 0.14186640536146505, 0.13517001111592564, 0.23793546961886541, 0.08009124054972615, 0.14986224845051765, 0.0888875988977296, 0.16593952503587517, 0.12794206610747746, 0.11521802816007819, 0.12289177067577839, 0.19611716642975807, 0.15220502630940505, 0.19519403310758726, 0.22420204297772475], [0.049993829136448245, 0.023406442055212598, 0.017517616440142905, 0.008944456249342432, 0.013294821605086327, 0.04516123488013234, 0.05867090781352349, 0.026080187243808593, 0.0310163785304342, 0.017390506475099494, 0.011260364969660128, 0.04203211296615856, 0.006629282043182424, 0.03567404306626745, 0.025114665839022825, 0.09143381512590817, 0.05631069839000702, 0.020686164631375244, 0.07156063722712652, 0.05854531776692186, 5.637347536427634, 45.40220464978899, 34.90676307678223, 22.920288460595266, 31.691716943468364, 28.19676784106663, 50.11889198848179, 16.736332654953003, 0.3067844094974654, 0.08107941145343439, 0.1510769889823028, 0.1156021196927343, 0.28660713934472626, 0.7463663731302533, 10.843461206981114, 33.072827747889924, 45.23188345772879, 46.398242814200266, 46.10086686270577, 47.88030399594988, 48.2887920652117, 46.13354076657976, 42.080274377550396, 41.15100145339966, 41.18880660193307, 39.26628868920462, 37.18429919651577, 35.12508589880807, 31.555292538234166, 32.721151624407085, 32.485489572797505, 33.016995498112266, 33.70141042981829, 33.89478921890259, 33.68788923536028, 34.4940505027771, 34.92940378189087, 35.290168149130686, 37.15805932453701, 36.58846337454659, 36.481860637664795, 35.355314459119526, 35.630602087293354, 36.00485290799822, 35.14109454836164, 36.88996308190482, 37.181030069078716, 35.37493617194039, 34.6116418157305, 33.644904204777305, 34.2113595690046, 33.900153228214805, 34.020395278930664, 33.27741398130144, 32.828942503247944, 32.992496149880544, 34.637680189950125, 43.17962530681065, 45.19120175497872, 47.464020047869, 44.80303716659546, 44.5090970993042, 33.535306794302805, 45.110515798841206, 46.15923867906843, 44.26034116744995, 43.904103551592144, 43.75907032830374, 46.72030571528843, 47.52022750037057, 45.300361428942, 41.49897766113281, 46.61266769681658, 45.43228340148926, 44.39383690697806, 41.72458219528198, 40.639565399714876, 38.6821015221732, 36.73563664300101, 33.191919871738975, 33.22947835922241, 32.65146466663906, 33.52275834764753, 32.13496685028076, 32.54494183404105, 31.680151666913712, 33.425243854522705, 33.88239015851702, 33.26778030395508, 33.38852262496948, 33.61380059378487, 32.40808664049421, 34.23199571881975, 33.502764906202046, 34.13518646785191, 34.25922570909773, 33.580143519810264, 33.353760787418906, 33.634228297642295, 32.467309611184255, 33.09103202819824, 37.16196073804583, 42.85372352600098, 44.93729025976998, 42.323475224631174, 42.426162651606965, 43.253074714115684, 43.02462836674282, 42.67847258704049, 40.849769251687185, 38.68352937698364, 36.737776688167024, 33.19254173551287, 33.21357045854841, 31.286230495997838, 30.643320628574916, 30.729433127811976, 35.28166355405535, 37.60303585869925, 39.80300923756191, 40.789896624428884, 45.99996164866856, 44.715496812547954, 45.73663534436907, 27.540887423924037, 1.950725644826889, 0.4552253170737198, 7.050942472049168, 9.84882744721004, 0.5478240411196436, 0.04517863251801048, 0.026828745380043983, 0.08606734951691968, 0.5793248936533928, 2.099364983183997, 28.263387169156754, 26.096231869288854, 13.7708032812391, 17.105577298573085, 35.480284758976524, 6.525639116764069, 0.2978741590465818, 0.02702956460416317, 0.08724136437688555, 0.11334918665566615, 0.04471828382728355, 0.07553314763520445, 0.03351961635053158, 0.06382700721068041, 0.01890315780682223, 0.007636135560460389, 0.011592273766707097, 0.08216656704566308, 0.02929673669859767, 0.03052641517881836, 0.007661501743963787, 0.017860168058957373, 0.014007363950700631, 0.020927461862031902, 0.012837257452442177, 0.025495481743876423, 0.061802564055791924, 0.026080290720398937, 0.07652446694139924, 0.025922453297036033, 0.09855808676885706, 0.026680829834991267, 0.032339087554386685, 0.011987275294294315, 0.04031640663743019, 0.04732462165078946, 0.032891055436006615, 0.04373388218560389, 0.030381714193416492, 0.023463389802990214, 0.08791450504213572, 10.430925812040057, 51.146082401275635, 37.80545425415039, 23.968648297446116, 34.24826145172119, 34.3765356200082, 52.48131077630179, 19.973288195473806, 0.3612234097506319, 0.06637491977640561, 0.27279018504279, 0.03685677031587277, 0.3644031605550221, 1.0049119911023547, 12.384987677846636, 36.62552159173148, 45.00404160363333, 47.44959906169346, 46.47142818995884, 48.787596293858115, 48.28762476784842, 47.05329813276018, 45.45445510319301, 42.96858767100743, 43.40824883324759, 41.27543674196516, 40.034293924059185, 37.16271461759295, 34.17507607596261, 35.45673731395176, 34.98596559252058, 35.73559979030064, 36.17310701097761, 35.339517729622976, 35.550517150333945, 38.38690383093697, 35.94390678405762, 37.541016238076345, 38.13945416041783, 37.918101923806326, 38.84528691428048, 38.18319654464722, 38.81483990805489, 37.9165038381304, 35.02518817356655, 37.74890981401716, 37.749934673309326, 37.28508281707764, 36.2096962247576, 36.6115140233721, 36.32564428874424, 35.62704113551548, 35.32843535287039, 35.42568234034947, 34.389994280678884, 34.37615694318499, 35.191885880061555, 44.939600535801475, 47.58415787560599, 49.32342747279576, 45.21408217293875, 44.82321126120431, 37.47144392558506, 44.72850036621094, 46.815277167728965, 45.36603580202375, 45.10211542674473, 44.04901170730591, 49.12272528239659, 49.07047135489327, 46.70970971243722, 44.395240443093435, 46.669378893715994, 46.54226507459368, 46.074776376996724, 42.616942814418245, 43.64155197143555, 41.01536566870553, 38.1202597618103, 36.308426652635845, 35.346445083618164, 33.6086311340332, 34.48362820489066, 33.68411636352539, 34.801695891789024, 35.01962266649519, 34.61232621329171, 35.47823851449149, 34.94001368113926, 34.328853607177734, 35.636587960379465, 34.78408915655953, 35.62728432246617, 35.50186933789934, 35.83034890038626, 34.82936709267752, 35.10503339767456, 33.72773020608084, 35.06070041656494, 34.69248063223702, 35.076215744018555, 38.42128004346575, 45.540390423366, 45.164503301892964, 44.77060644967215, 43.7774726322719, 44.72862195968628, 45.76139177594866, 43.34244244439261, 40.94094351359776, 39.594573702131, 37.6392047064645, 34.53317928314209, 33.43587459836687, 33.02314117976597, 32.70405558177403, 33.90222726549421, 39.67427996226719, 40.56372233799526, 42.15776068823678, 42.97105080740792, 46.344766003744944, 46.34093754632132, 45.30410303388323, 31.1484511920384, 2.8706171980925967, 0.8859384208917618, 11.337724787848336, 9.701618569237844, 3.3916165786130086, 0.13360745353358133, 0.01818395988084376, 0.0894083066710404, 0.7250053307839802, 2.63558634689876, 31.95640856879098, 33.993408475603374, 17.24909928866795, 19.086328063692363, 42.76887559890747, 10.531120572771345, 0.317065599241427, 0.0512160471241389, 0.11316475405224732, 0.03526575158217123, 0.019262786455718533, 0.016678797879389355, 0.04954551426427705, 0.055794977849083285, 0.02714650332927704, 0.021759362758270333, 0.03513258908476148, 0.046279884675251584, 0.01598106710506337, 0.009417342570876437, 0.03919881535694003, 0.1265968975744077, 0.1508120617696217, 0.09740948304533958, 0.07918967107044798, 0.0961376302210348, 0.1370286135269063, 0.16629982713077748, 0.16582998234246457, 0.15899243924234593, 0.15569034857409342, 0.12628033384680748, 0.12728182439293179, 0.1172036523265498, 0.10917844902724028, 0.15513920171984605, 0.12245434629065649, 0.2092407936496394, 0.07904180471918412, 0.16383792566401617, 0.19276130864662783, 13.037701453481402, 59.326596123831614, 44.594108309064595, 31.77729443141392, 39.073625564575195, 37.5925475529262, 57.417484760284424, 21.390177011489868, 0.3827385881117412, 0.4174667160425867, 0.45094986792121616, 0.2516905143857002, 1.4479980724198478, 2.4348548437867845, 14.053096430642263, 38.6219231741769, 45.606047425951274, 48.6850825718471, 45.92646707807268, 50.919887270246235, 50.41251938683646, 49.713023390088765, 46.19782549994332, 45.330322061266216, 45.473889214651926, 43.88460690634591, 40.941290923527305, 39.906943866184776, 35.77105297361101, 38.07809461866106, 35.16614975248064, 36.054386615753174, 37.72817986352103, 37.52157170431954, 36.60492713110787, 39.40636437279837, 37.02521324157715, 38.545677116939, 39.945277077811106, 40.214012554713655, 39.8804851259504, 38.78511551448277, 40.410316535404746, 39.79384108952114, 36.99997043609619, 40.49500812802996, 41.14989668982369, 39.277808802468435, 38.52889026914324, 37.20069694519043, 37.29378890991211, 37.8399590083531, 36.41600908551897, 37.265040738242014, 36.132644176483154, 36.25176409312657, 36.871303694588796, 47.27739838191441, 48.468514169965474, 51.745461804526194, 46.58563225609915, 45.5514623778207, 38.21168763296944, 47.23948553630284, 49.30855137961251, 47.9522317477635, 47.23535483224051, 46.714107922145296, 52.198050090244834, 51.340618065425325, 46.06161648886544, 44.95352125167847, 48.941776820591514, 49.178866727011545, 48.08951078142439, 44.63586350849697, 44.373965059007915, 43.10777398518154, 39.06471797398159, 37.39428765433175, 36.20537791933332, 35.57763596943447, 36.47557599203927, 34.434403691973, 36.90075363431658, 36.67771645954677, 37.11868735722133, 37.79025159563337, 36.790558678763254, 35.112075396946494, 36.65936974116734, 36.57474068232945, 36.7656945501055, 37.38644313812256, 38.30834749766758, 35.90737315586635, 35.9510669027056, 36.21311126436506, 36.950322083064485, 36.75469902583531, 37.632402420043945, 39.30026190621512, 44.904512132917134, 48.13911049706595, 45.442983627319336, 45.2347982270377, 46.67681694030762, 46.943610395704, 45.03157731464931, 43.901866231645855, 41.593820571899414, 40.14238010134016, 37.36112042835781, 36.05641548974173, 34.346998827798025, 35.14430114201137, 34.885359151022776, 39.832090922764365, 40.98749297005789, 43.347483362470356, 45.00921106338501, 49.20325837816511, 47.27058219909668, 47.71601036616734, 32.87260498319353, 3.621331189359937, 0.6699395541633878, 13.719064388956342, 21.706742150442942, 5.181944361754826, 0.20474969249750885, 0.21409539958196028, 0.35348667204380035, 1.7961529791355133, 6.250791396413531, 35.043965680258616, 37.26176118850708, 22.85413292476109, 25.983262845448085, 50.60093021392822, 13.684242623192922, 0.5272355516042028, 0.11005167609878949, 0.18277477951986448, 0.2518273613282612, 0.12784491346350738, 0.10987064295581409, 0.15787386069340364, 0.16181665126766476, 0.10727691570562975, 0.109245352580079, 0.11794332335037844, 0.2244588549115828, 0.08293407157595668, 0.12758526525327138, 0.15488076130194323], [0.07389899782304253, 0.02858154721824186, 0.015613899932109883, 0.06282287716333355, 0.006346096725402666, 0.015001771439399039, 0.08094960770436696, 0.12791381190930093, 0.060495990594582896, 0.05166641117206641, 0.016422002908906767, 0.03459464652197702, 0.03846714086830616, 0.024809757646705424, 0.10923569024141346, 0.07606690363692385, 0.03983468748629093, 0.025550594054428593, 0.06581547443888017, 0.021391980150448422, 1.2517675906419754, 30.030868189675466, 41.91224609102522, 29.549893038613455, 31.619813510349818, 28.445614099502563, 40.8976423399789, 17.476400920322963, 0.4089267557220799, 0.2669345092560564, 0.3848143624407904, 0.11089652005050864, 0.16448224894702435, 0.1530832134719406, 1.1487084350415637, 14.280480572155543, 35.88624020985195, 47.20705829347883, 49.09736088344029, 49.84639058794294, 44.135110310145784, 44.49899441855294, 42.209493500845774, 39.77835008076259, 36.20348106111799, 35.84500959941319, 34.065888609204976, 32.681713649204795, 33.86179917199271, 32.34085587092808, 33.33332960946219, 34.85270609174456, 34.91397878101894, 34.785259928022114, 34.03979812349592, 33.43367896761213, 35.39573213032314, 35.68523577281407, 35.07136590140206, 37.01308863503592, 38.11002853938511, 37.424950054713655, 36.24258899688721, 34.45245163781302, 35.20118604387556, 35.88581984383719, 36.67878300803048, 35.55006551742554, 34.94479056767055, 34.31501279558454, 34.687047140938894, 35.309220109667095, 35.71681533540998, 34.58656924111502, 33.66332040514265, 32.79562241690499, 35.643188749040874, 41.855802399771555, 44.47763218198504, 46.68146875926426, 47.71326582772391, 45.88186659131731, 36.67230381284441, 46.87116847719465, 44.82389913286482, 47.04891381944929, 44.23410824366978, 44.18537705285208, 45.07767513820103, 47.14227328981672, 42.911973748888286, 43.63446133477347, 46.416797978537424, 46.35195044108799, 43.39566911969866, 41.74392250605992, 39.3204151562282, 35.808083398001536, 36.01732839856829, 33.732156208583284, 33.79706627982003, 32.52915205274309, 33.83271401269095, 32.45119326455252, 32.61683137076241, 33.48022147587368, 33.70045852661133, 32.55034753254482, 34.223303522382466, 33.87754378999983, 32.52352748598371, 33.347646372658865, 33.71050214767456, 34.935393129076274, 32.966634954724995, 33.6893379347665, 32.44165686198643, 35.388026578085764, 33.85297148568289, 33.500312192099436, 32.737024784088135, 32.364378997257774, 38.21870183944702, 41.878568172454834, 43.102614947727744, 42.28422485079084, 41.47384950092861, 42.12922443662371, 41.77817365101406, 42.24922330038888, 40.57795572280884, 38.93463379996163, 37.01031977789742, 35.42698165348598, 33.315729822431294, 32.63261767796108, 31.395393644060405, 32.98844882420131, 34.89645542417254, 38.03726352964129, 42.823717730385916, 43.13320091792515, 46.07409197943551, 41.72758034297398, 12.106366651398794, 0.06433311969574008, 1.5233340242079325, 6.718921065330505, 6.615617419992175, 1.9673225028174264, 0.06701557897031307, 0.03370313971702542, 0.05599876905658415, 0.171255317649671, 8.176901527813502, 32.88860321044922, 24.296759605407715, 22.985172476087296, 27.173155750547135, 28.88952234813145, 0.8615446527089391, 0.0682606500174318, 0.05461189436859318, 0.0666792020201683, 0.0245523028009172, 0.041815399059227536, 0.026581046171486378, 0.09093580434897117, 0.04447034373879433, 0.03267321176826954, 0.06887585736278977, 0.05098283803090453, 0.019391221260385852, 0.03283831969435726, 0.05677439904372607, 0.029712590455476726, 0.03497972193041018, 0.03648854971730283, 0.030148206544773917, 0.014087686381701912, 0.06702171292688165, 0.037470596842467785, 0.06759754488510744, 0.04923753739733781, 0.1336701094572033, 0.05620881974963205, 0.011632521071338227, 0.03179072608639087, 0.034774940061782084, 0.019732631244031445, 0.01634238530615611, 0.013883059727959335, 0.039121821988373995, 0.009095064730250409, 0.04983549638252173, 0.024076408872913038, 2.054068373782294, 37.86798109327044, 43.79992226191929, 29.86765500477382, 38.58045285088675, 34.37194286073957, 46.79153517314366, 18.924216168267385, 0.36696555305804524, 0.34923065613423077, 0.5663616721119199, 0.2538651648376669, 0.20043442691011087, 0.22406206120337757, 2.0213347588266646, 17.217561415263585, 38.49175214767456, 48.27854347229004, 49.839386803763254, 51.117226532527376, 46.66258702959333, 45.65476819447109, 43.72553832190377, 42.331073079790386, 37.576441628592356, 37.431536946977886, 35.95453405380249, 34.182972703661235, 34.882399218423025, 35.29458372933524, 33.877943311418804, 36.10099860600063, 35.545201778411865, 35.8037234033857, 34.35161590576172, 34.893443380083355, 35.88370064326695, 37.76344197137015, 37.18733555930001, 37.27285051345825, 40.22694662639073, 38.180716037750244, 37.64031989233834, 36.28169345855713, 35.58820070539202, 37.78171920776367, 36.80638320105416, 38.053650856018066, 36.2887875693185, 35.16943277631487, 35.93156678336007, 37.74492154802595, 35.07862676892962, 34.86064440863473, 35.718778201511924, 34.086785316467285, 36.50762455804007, 42.88134608949934, 46.57151699066162, 47.756681646619526, 48.89933027539934, 47.16444846561977, 38.834232330322266, 46.74133791242327, 46.589811597551616, 48.029044083186555, 45.464866978781565, 46.46521302631923, 45.770587716783794, 48.17391402380807, 46.05716616766793, 47.05291945593697, 47.97657823562622, 47.50866222381592, 43.07258483341762, 44.10594524656023, 40.95220306941441, 36.861906255994526, 37.44254289354597, 36.26281520298549, 34.64299208777291, 33.51578235626221, 34.68039771488735, 34.254952566964285, 35.12234830856323, 35.236434255327495, 35.804206303187776, 34.41066517148699, 35.14316511154175, 35.35746145248413, 34.74303225108555, 34.53211620875767, 34.535326276506694, 35.62067658560616, 35.2114520072937, 34.984298024858745, 33.930037430354524, 35.94593913214547, 35.593342372349326, 34.436995370047434, 33.2666130065918, 33.98738438742501, 41.14986194883074, 43.62847546168736, 45.64501987184797, 44.63579750061035, 42.763407366616384, 44.68305219922747, 42.82585430145264, 42.66934960229056, 42.18684932163784, 40.40052652359009, 37.32175193514143, 37.38354573931013, 34.2251170022147, 33.94908939089094, 32.819124698638916, 34.92267445155552, 36.95875719615391, 40.448896408081055, 43.45877613340105, 45.719223158700125, 45.990268911634175, 43.257955823625835, 14.4566182749612, 0.37065767922571724, 3.579310004200254, 9.995935576302664, 10.904270103999547, 3.9432121344975064, 0.26485900634101456, 0.042448967562190125, 0.11740806778626782, 0.6981586313673428, 9.814759560993739, 35.31684228352138, 29.371703011648997, 21.49670852933611, 30.885357652391704, 38.06321505137852, 1.99616773213659, 0.11810822093061038, 0.011091556483214455, 0.08428002720964806, 0.041613355079399686, 0.003610517064641629, 0.07941420509346894, 0.006278546443874282, 0.025787982923377837, 0.03431106638163328, 0.02748508212555732, 0.041298396087118557, 0.08040606044232845, 0.016998740711382458, 0.025475539599678347, 0.04258005713511791, 0.11048511069800172, 0.12478351273706981, 0.16537378967872687, 0.10535503990416016, 0.13903044110962323, 0.15642604338271276, 0.1749368586710521, 0.20243443601897784, 0.14650040598852293, 0.11274163997066872, 0.09586584301931517, 0.09661863691040448, 0.12012199072965554, 0.08739106277269976, 0.2900547486330782, 0.16254881769418716, 0.19878919662109443, 0.08807968760707549, 0.21045329501586302, 0.11664368451706, 2.332824455840247, 42.7275824546814, 53.48432840619768, 37.90375736781529, 40.77475649969918, 39.22135468891689, 48.894334520612446, 22.502706936427526, 0.5250311813184193, 1.2589674443006516, 1.3977253586053848, 0.31180103602153914, 0.4924218196954046, 0.8248920366168022, 1.9398714729717799, 17.81631374359131, 40.017753737313406, 47.37726831436157, 49.5206173488072, 51.544280188424246, 48.04020289012364, 47.61456666673933, 45.53312955583845, 43.76643194471087, 39.01756402424404, 40.57612139838082, 38.20145641054426, 36.500672885349815, 35.92520570755005, 36.26560837881905, 35.59111894880022, 37.83166980743408, 37.88035236086164, 38.19626610619681, 37.30967596599034, 36.734125409807476, 38.190843037196565, 39.96074376787458, 38.158249037606375, 41.436516829899375, 41.72570432935442, 40.325430393218994, 40.29395505360195, 37.7151380947658, 36.96806083406721, 38.99707726069859, 40.2034478187561, 39.013419423784526, 38.0747629574367, 37.343339988163535, 38.14814288275582, 39.70685659136091, 37.79379865101406, 36.730901445661274, 37.73057351793562, 35.32038933890206, 39.60362720489502, 44.5920273235866, 47.541169370923726, 50.82434606552124, 49.01264149802071, 47.4588679586138, 39.94354002816336, 49.0052034514291, 47.51623228618077, 51.660054547446116, 47.29631832667759, 48.794283935001914, 48.60228088923863, 50.07136978421892, 44.004640511104036, 46.80720336096627, 50.92709950038365, 49.3042573928833, 44.39618539810181, 45.029829842703684, 42.61845404761178, 38.635201181684224, 40.43290512902396, 37.87041296277727, 36.315089975084575, 34.81091962541853, 37.148290157318115, 34.36481400898525, 36.49837303161621, 37.563552720206125, 37.21267563956124, 35.164437021527974, 37.06994921820504, 37.288567338671, 34.5722906930106, 36.85857459477016, 35.34819255556379, 38.04423952102661, 36.426132610866, 36.70273344857352, 35.66136871065412, 38.92112650190081, 37.5677980695452, 36.425392627716064, 35.508817536490305, 34.31475223813738, 43.53270844050816, 44.75378833498274, 47.657701083592, 46.53285721370152, 44.62081718444824, 46.34493623461042, 44.02925450461251, 45.419880867004395, 44.366523538317, 42.91927283150809, 39.45585291726248, 39.544025557381765, 36.37318386350359, 35.273145062582834, 34.590981347220286, 36.64822483062744, 38.172614438193186, 41.82293047223772, 46.64838491167341, 47.5529465675354, 49.05825989586966, 43.397757053375244, 16.09500697680882, 0.42394941246935297, 4.578388222626277, 15.031018904277257, 15.466134207589285, 7.144496491977146, 0.5775438749364444, 0.26497479155659676, 0.48380686768463677, 1.8383187736783708, 13.883077485220772, 41.285105160304475, 34.95800951548985, 31.708277974809917, 39.75076573235648, 45.45170014245169, 2.714195443051202, 0.17825201792376383, 0.14827884627240046, 0.1998509546475751, 0.09279286648545947, 0.11444692739418574, 0.1500471763845001, 0.1399000651602234, 0.12570693104394845, 0.1372654222484146, 0.08398731398795332, 0.13076299402330602, 0.28964540202702793, 0.08817880800259964, 0.2156441014792238, 0.11002489432160344], [0.023225556493603756, 0.01985509324419711, 0.019291781953402927, 0.029598803525524478, 0.03467037442273327, 0.01297602295276842, 0.0751143761777452, 0.013662921763690454, 0.021024833333545496, 0.050689680368772576, 0.056025286205112934, 0.059347441153866906, 0.03551159839012793, 0.015057896463466542, 0.01987911168751972, 0.055383710988930294, 0.0046612569546726134, 0.027668150873588662, 0.012572350595811648, 0.041567747348121235, 0.11308662753020014, 10.377267479896545, 42.661098616463796, 26.56821084022522, 24.370113474982126, 30.733991146087646, 34.92651680537632, 28.296675988606044, 0.09939231843288455, 0.3954890753541674, 0.30179052746721674, 0.010168786177278628, 0.023313671051125442, 0.22782600351742335, 0.02845548728613981, 2.6102071830204556, 17.40540943826948, 41.405020645686555, 51.41535288946969, 49.15646226065499, 48.81626108714512, 45.1915283203125, 39.41684225627354, 37.503516810280935, 35.677808148520334, 35.7105758530753, 34.81775317873274, 35.691082681928364, 36.231635161808555, 39.09390735626221, 39.96963051387242, 42.74636690957205, 44.21619578770229, 45.38033866882324, 42.62956769125802, 36.98485115596226, 34.31157691138131, 35.78416769845145, 34.90638092585972, 36.346516677311485, 37.89768116814749, 37.45188127245222, 37.62655551092965, 36.714941433497835, 34.16720724105835, 35.056072916303364, 35.13643230710711, 34.697354793548584, 34.46282182421003, 36.855086599077495, 35.37824698856899, 33.725006512233186, 35.06423357554844, 33.034796782902305, 33.57930973597935, 33.365183625902446, 34.6981885773795, 39.75306558609009, 45.09033128193447, 44.68741914204189, 48.84020457948957, 43.00660473959786, 39.37072706222534, 46.17753676005772, 47.71934897559029, 47.44097287314278, 43.688712869371685, 48.31433711733137, 46.8669821875436, 48.52616684777396, 41.16116319383894, 42.41119623184204, 46.84080484935215, 45.21583659308297, 41.24046298435756, 38.91864252090454, 37.15065949303763, 35.77212994439261, 33.507944788251606, 33.978223187582834, 32.208662918635774, 33.519749777657644, 33.58294711794172, 32.09197834559849, 32.69037457874843, 34.08544084003994, 32.401082856314524, 32.426461151668, 34.2146703856332, 33.70481852122715, 32.29511587960379, 34.02478654044015, 33.43045500346592, 31.678630011422293, 33.003773076193674, 32.64001750946045, 32.95021636145455, 32.78676346370152, 33.929498944963726, 34.32318387712751, 32.77989169529506, 31.57805483681815, 33.54386002676827, 39.687898431505474, 40.83090489251273, 43.36311680930001, 41.14212512969971, 42.583087716783794, 41.61104168210711, 42.63071761812483, 40.06967762538365, 41.78445134844099, 40.13356978552682, 38.972668239048545, 35.45506974628994, 33.89750943865095, 30.375842775617325, 33.86886896405901, 34.01622288567679, 37.19108758653913, 40.04483781542097, 43.58410773958479, 46.12946564810616, 35.51953165871756, 2.23646662064961, 0.05122326673673732, 1.6094121081488473, 12.163437417575292, 5.528271675109863, 3.271712818316051, 0.08148706850728818, 0.0869660284370184, 0.17416711497519696, 0.10640949010848999, 15.197537694658552, 32.54364946910313, 28.918963602610997, 31.899815491267614, 27.924969945635112, 11.961055500166756, 0.09985131344624928, 0.023186561086082032, 0.06955600050943238, 0.03697851306891867, 0.02005609736910888, 0.020306040832240666, 0.031789006000118594, 0.046292851479457955, 0.038793689238705804, 0.01630247218002166, 0.029308763731803213, 0.02834720497152635, 0.019101408775895834, 0.024687195562624505, 0.03239120922184416, 0.02340731058003647, 0.0008400179244095593, 0.019107914230387126, 0.01801476887028132, 0.029011046314345937, 0.011684470560534723, 0.023709195898845792, 0.022839395429140756, 0.04714919999241829, 0.025947996747813055, 0.01476059464870819, 0.06332871823438577, 0.014725241277899061, 0.04012771283409425, 0.009958973819656032, 0.012320342689885624, 0.02294991521297821, 0.0670658719858953, 0.05146191428814616, 0.017927281957651888, 0.054731828825814385, 0.20223933005971567, 16.091122933796473, 49.04548563276018, 29.827216488974436, 27.84722134045192, 40.60099942343575, 39.6253924369812, 29.795060225895472, 0.13870184017079218, 0.43448752271277563, 0.5763491647584098, 0.055933242929833274, 0.048544271383434534, 0.08592794449733836, 0.0802892642095685, 3.3122190790516988, 20.37166837283543, 44.90685020174299, 51.067526068006245, 52.22016620635986, 48.94380569458008, 46.548563616616384, 42.34239516939436, 38.89171477726528, 37.40144082478115, 37.68097380229405, 36.92672947474888, 36.78718185424805, 37.61139454160418, 38.756481988089426, 40.62716981342861, 43.20699078696114, 44.117958681924, 46.41022498267037, 43.659308092934744, 37.293243476322715, 37.12959255490984, 36.787119320460725, 36.03310080936977, 37.71545423780169, 38.97470753533499, 39.54416104725429, 38.8869309425354, 38.67485455104283, 36.70200736182076, 36.289294787815635, 36.42707061767578, 37.44002069745745, 36.50261838095528, 37.0867395401001, 37.90012345995222, 36.01016827992031, 35.471300738198416, 34.767757415771484, 35.1123046875, 34.805541719709126, 36.808651787894114, 41.47702135358538, 46.18771587099348, 46.26691838673183, 50.278109959193635, 44.96593073436192, 40.15916347503662, 46.342827456338064, 47.90791961124965, 48.238973481314524, 44.63922643661499, 48.9675372668675, 47.296679633004324, 48.12717349188668, 42.50471551077706, 45.52521208354405, 47.53318241664341, 47.88249962670462, 44.51896006720406, 41.254929133823936, 40.025018078940256, 36.5722462790353, 34.47681549617222, 35.53685004370553, 34.76027767998831, 35.10919189453125, 35.37415449959891, 33.373073305402485, 35.12799024581909, 33.9158353124346, 33.838943072727744, 34.82496888296944, 35.94091558456421, 35.08997665132795, 34.1919185093471, 34.376420974731445, 33.64732912608555, 33.28378895350865, 34.10932527269636, 34.73169279098511, 34.9641934122358, 34.06919942583357, 35.32096256528582, 35.95695897511074, 34.27957698277065, 32.92185034070696, 35.17853144236973, 41.416380950382774, 43.217763968876426, 45.398518630436485, 42.96413040161133, 43.183318274361746, 44.223289898463655, 44.504549503326416, 41.63376923969814, 44.55971820013863, 40.66943570545742, 40.38956921441214, 37.64991882869175, 35.509279591696604, 32.39855023792812, 34.8309964452471, 35.777452264513286, 39.8929397719247, 41.90407848358154, 45.66468674795968, 46.31146328789847, 37.03145967211042, 2.96821311541966, 0.4377664753368923, 5.810827987534659, 9.585154601505824, 8.669610449245997, 5.165799788066319, 0.14447801879474095, 0.05084587573739035, 0.2862885535827705, 0.7993520327976772, 17.964852333068848, 37.435994216373985, 31.086865833827428, 34.75874212809971, 33.72104603903634, 18.20243729863848, 0.11185764454837356, 0.011684535021361495, 0.1448332725891045, 0.07306145490812403, 0.017761461569794586, 0.02044994623533317, 0.04304522342447724, 0.020157275422077094, 0.004674072784837335, 0.05196114303544164, 0.025722790975123644, 0.02618945513053664, 0.06956298942012445, 0.06971451986048903, 0.0318860466858106, 0.025292513260085667, 0.11773713012891156, 0.16735884387578281, 0.20418080873787403, 0.1349929677588599, 0.0780450842742409, 0.10048598117594208, 0.10392255748489074, 0.18689284926014288, 0.19323580818516867, 0.09098898792373282, 0.12291076965630054, 0.17658610588737897, 0.13162778690457344, 0.07412392539637429, 0.12620880268514156, 0.09345310820000512, 0.15672902283923967, 0.1009910080049719, 0.07511907842542444, 0.14536263846925326, 0.23647645648036683, 17.57927073751177, 56.0519448689052, 35.10488748550415, 32.23613262176514, 41.567142963409424, 43.48131956372942, 34.74177810123989, 0.2449333369731903, 0.7816658818296024, 1.5931814419371741, 0.08590606174298696, 0.2327193266579083, 0.7192948343498367, 0.9622371324471065, 4.167529949120112, 21.463662896837505, 45.57986313956124, 52.134689467293875, 54.04052822930472, 50.898677894047324, 49.4901008605957, 43.54683412824358, 41.464969703129356, 38.15217978613717, 39.153290135519846, 39.622137205941335, 39.34076295580183, 40.804998534066335, 43.27430146081107, 42.578116280691965, 45.74167626244681, 48.1206248147147, 49.4990953036717, 45.71319907052176, 40.07876239504133, 37.36643232618059, 38.64543240410941, 38.244893074035645, 39.40420000893729, 41.22202941349575, 40.74044976915632, 41.49928685597011, 40.634927477155415, 38.1231814793178, 37.811537402016775, 38.49059179850987, 39.28439916883196, 37.385751792362754, 40.727925641196116, 39.334797927311485, 37.63864190237862, 37.96927193232945, 37.25803695406233, 36.40767819540841, 37.65611662183489, 38.19888210296631, 43.717818873269216, 47.859796387808665, 48.465015751974924, 51.60763733727591, 45.90429885046822, 42.85758325031826, 46.13683768681118, 50.25387464250837, 49.36388683319092, 45.837450231824604, 51.34208066122872, 49.66223553248814, 49.69361012322562, 41.807710443224224, 45.31580032621111, 50.50641734259469, 49.270662852696006, 45.55290412902832, 42.471996443612234, 40.91282067980085, 37.63901015690395, 35.59586456843785, 37.690996578761506, 35.91606535230364, 37.045147623334614, 37.198515210832866, 34.85184451511928, 36.30771098818098, 38.03823280334473, 35.58102321624756, 35.57132353101458, 38.05854933602469, 35.779251847948345, 35.14933858598982, 35.88421828406197, 36.552544661930625, 34.65075669969831, 35.45290538242885, 37.13081891196114, 34.682350158691406, 35.57888664518084, 37.655390535082134, 38.24678993225098, 35.96846171787807, 35.27958951677595, 36.917352880750386, 42.86658116749355, 44.56862926483154, 46.92955418995449, 44.721493107931956, 44.916285855429514, 44.10223143441336, 46.81653479167393, 43.183464186532156, 46.15175199508667, 43.03755896432059, 43.36256790161133, 40.086054529462544, 36.78627511433193, 33.538624559129985, 38.72998850686209, 37.75153275898525, 40.849699769701274, 43.8088368007115, 46.55722107206072, 47.10761220114571, 38.12594338825771, 4.018845013209751, 0.2909683824649879, 5.3592298201152255, 20.55293297767639, 14.46557537146977, 10.239442144121442, 1.4116606222731727, 0.21500452794134617, 0.8202925462807927, 2.21022783432688, 23.14629077911377, 42.17263330732073, 39.424179553985596, 39.74647174562727, 41.19954851695469, 21.90462163516453, 0.1629136795444148, 0.0853143452799746, 0.21004078643662588, 0.13153501759682382, 0.14503382039921625, 0.20558965099709375, 0.1067507660814694, 0.12424928854618754, 0.10429850659732308, 0.14250346831977367, 0.10877604383443083, 0.16066308745316096, 0.22181851230561733, 0.14349008537828922, 0.0908018411802394, 0.07899661428694214], [0.07514135473008667, 0.03519293459664498, 0.013325927346678717, 0.03319334278681448, 0.0933381032996944, 0.07675050731216158, 0.004547404715724821, 0.0463358027461384, 0.020742762933618257, 0.030142194724508693, 0.03463595912658742, 0.037622727786323855, 0.05500264232978225, 0.07118667622229882, 0.06338958961090871, 0.05956491841269391, 0.023734459453927617, 0.05527966782184584, 0.025175364189116017, 0.0842478782204645, 0.03129749898133533, 2.1925798441682542, 29.97981630052839, 38.180563177381245, 27.06175528253828, 29.889878817967006, 32.115793296269004, 29.88664095742362, 1.623794662100928, 0.1409425392214741, 0.635861299932003, 0.14641940247799667, 0.01024013667899583, 0.21311493005071366, 0.16366123514516012, 0.012483956990763545, 4.381374222891671, 29.35162271772112, 50.76679413659232, 49.81331021445138, 47.35829973220825, 44.42064305714199, 40.40089130401611, 36.46587978090559, 37.303919383457725, 36.32814564023699, 40.67312519890921, 42.07609503609793, 42.285875047956196, 44.788942745753694, 46.149747439793174, 48.11975628989083, 47.26694481713431, 47.11317423411778, 48.80781207765852, 40.87307003566197, 35.164992877415244, 36.272462776729036, 34.58644069944109, 35.90754338673183, 37.756785597120015, 37.66659450531006, 38.7077751159668, 37.188242299216135, 34.515596866607666, 35.08700977052961, 35.439064570835654, 35.80605452401297, 33.835840702056885, 33.986953599112375, 34.17931795120239, 36.00549214226859, 35.32332147870745, 33.01824964795794, 32.59972837993077, 32.719171387808665, 34.29286193847656, 39.36366074425833, 43.74784203938076, 46.41787494931902, 46.17636251449585, 41.935713631766184, 43.14751420702253, 45.77396106719971, 45.29942342213222, 47.46835224969046, 45.32467317581177, 46.78908593314034, 45.43934277125767, 45.65527193886893, 41.980675424848286, 43.137373311179026, 46.6481625693185, 42.67021812711443, 41.57182257516043, 37.299264090401785, 36.79631526129586, 33.19388968603951, 34.78208460126604, 33.60858597074236, 33.85758856364659, 33.15296132223946, 32.44771916525704, 33.54009410313198, 32.20654719216483, 32.973590101514546, 32.81818321772984, 33.80590786252703, 32.917104721069336, 34.4310233933585, 33.588686329977854, 33.71048477717808, 34.08284221376692, 32.75232819148472, 34.89346422467913, 32.67563744953701, 34.435880184173584, 37.399172237941194, 34.951704025268555, 32.767037527901785, 34.877726554870605, 33.11647285733904, 34.45244468961443, 39.21899577549526, 43.01452568599156, 43.36654574530465, 41.624847752707346, 42.2783397265843, 43.1409273147583, 41.26123462404524, 40.289407457624165, 39.32131494794573, 38.28508145468575, 37.36707156045096, 36.405763966696604, 35.55777106966291, 36.21802364076887, 34.93418761662075, 35.8965721811567, 38.34956421170916, 42.47186095373971, 43.308945178985596, 44.96811941691807, 21.681127616337367, 0.017639228575197712, 0.34681876269834383, 5.9173807842390875, 5.6876494543893, 8.930463194847107, 3.096908735377448, 0.21975667508585112, 0.14243043081036635, 0.2383228045489107, 1.375907797898565, 20.206626074654714, 24.739966085978917, 29.820556640625, 31.37616797855922, 31.20239700589861, 5.41520711353847, 0.19991394983870642, 0.056031891743519475, 0.056069665788007636, 0.05198509532159992, 0.025790944728734236, 0.023316375013174753, 0.03017529027004327, 0.029226447256015878, 0.031218300373958688, 0.10298818762281112, 0.008727307231830699, 0.020862369997692958, 0.036790389234998395, 0.05482812312298587, 0.013661142305604048, 0.030808675568550825, 0.05304616124236158, 0.08204021025449038, 0.07062242685684136, 0.02609921675840659, 0.031419306195208004, 0.039013765286654234, 0.07157761417329311, 0.01742179542114692, 0.015755874903074334, 0.04779050040191837, 0.029991644767246077, 0.044950526008116345, 0.020473242038860917, 0.021825988111751418, 0.03871338801192386, 0.018046398780175617, 0.05554503608228905, 0.034373783373406956, 0.03144844248890877, 0.06039185582527092, 0.051254330069891045, 4.088800345148359, 39.47658634185791, 39.523007256644114, 27.252156768526348, 35.25753593444824, 37.03305775778634, 34.875732421875, 1.576656997203827, 0.11254071218094655, 0.589656647826944, 0.24558372635926518, 0.08377956013594355, 0.15230137828205312, 0.3714516737631389, 0.1608543393335172, 6.094316227095468, 32.25738716125488, 51.717078413282124, 50.02077995027815, 50.20348283222744, 47.28729261670794, 41.85057735443115, 38.21608931677682, 38.2018837247576, 37.13624545506069, 42.10245302745274, 42.60411991391863, 44.5532112121582, 46.5084342956543, 48.84396702902657, 48.93974447250366, 48.48935529163906, 49.99078457696097, 50.887609413691926, 42.0805001940046, 36.18514129093715, 36.971889291490825, 36.764464718954905, 35.55665240968977, 39.97096456800188, 39.532199723379954, 39.494967801230295, 39.19518082482474, 36.92344645091465, 37.338024616241455, 37.62691681725638, 38.631556851523264, 35.79694890975952, 35.2684063911438, 36.320818764822825, 37.325170448848176, 37.378935609545024, 33.55482428414481, 34.77086673464094, 33.9067713873727, 36.28319079535348, 40.9181673186166, 45.18766859599522, 47.01895318712507, 47.31904935836792, 43.174622603825156, 46.051499911717, 46.34832000732422, 47.544494083949495, 47.76187889916556, 45.59446130480085, 47.29067986352103, 46.37970502035958, 45.989924975803916, 42.87665605545044, 45.23676456723894, 47.29445273535592, 44.614105224609375, 42.71454416002546, 40.49895123073033, 37.93898126057216, 34.574840681893484, 35.64807333265032, 34.94677427836827, 33.297327518463135, 33.64785718917847, 33.47361373901367, 34.08035475867135, 33.97583300726754, 33.58487524305071, 34.42284188951765, 36.44829389027187, 35.712743691035676, 37.217810358319966, 34.90168046951294, 35.25579193660191, 35.099162169865195, 34.63859735216413, 35.53872953142439, 33.85884966169085, 35.163964544023784, 38.37862157821655, 36.43986572538103, 34.39683825629098, 35.164027077811106, 34.13964721134731, 35.83981582096645, 40.7038813999721, 44.900697571890696, 44.61476877757481, 43.39339358466012, 43.98818717684065, 44.54787152154105, 43.22879076004028, 41.8792074067252, 41.08837039130074, 40.07413836887905, 40.08768040793282, 38.88550656182425, 37.170757157461985, 37.86457300186157, 36.50868763242449, 36.411235673086985, 40.19304983956473, 44.09710366385323, 44.31086499350411, 45.63945089067732, 24.127468483788626, 0.22960498662931578, 3.264303433043616, 9.657404576029096, 8.433708684785024, 7.960048249789646, 4.410127605710711, 0.25003434611218317, 0.12981797116143362, 0.20607797907931463, 2.771715236561639, 24.75530423436846, 32.004309449877056, 33.88036128452846, 34.83932038715908, 35.988177231379915, 8.522148830550057, 0.23445235937833786, 0.057711622145559104, 0.10821961797773838, 0.07184064827327218, 0.01395141619390675, 0.03294946373041187, 0.05724342619734151, 0.04503389421318259, 0.07412034273147583, 0.030526133586785624, 0.05301539307194097, 0.035314830020070076, 0.0802969384406294, 0.003641504910774529, 0.05075522006622382, 0.018026787421799133, 0.12551308715982096, 0.11405770613678864, 0.16082786289708956, 0.11165630285229002, 0.12012082364942346, 0.21731788452182496, 0.14012043976358005, 0.2373707927763462, 0.15812614001333714, 0.17556723127407686, 0.18213846295007638, 0.13334889097937516, 0.16043036351246492, 0.31522204673716, 0.12422920390963554, 0.1419802771082946, 0.12505066554461206, 0.17546965793839522, 0.13342248488749775, 0.1825839483312198, 0.17239255591162614, 4.597776302269526, 44.375594411577495, 47.84461457388741, 35.72075148991176, 38.51973949159895, 42.00107533591134, 38.48623875209263, 2.695419890539987, 0.5576822321329797, 1.9665677547454834, 0.4829597845673561, 0.1912722906896046, 0.5665803775191307, 0.8921765461564064, 0.4066296432699476, 6.863100094454629, 33.56490612030029, 51.70716680799212, 53.68615967886788, 52.13985892704555, 48.72331503459385, 44.67824751990182, 40.476817744118826, 41.60983269555228, 39.13668046678816, 45.93439497266497, 45.572612694331575, 47.406082493918284, 48.206876277923584, 50.62808377402169, 51.39452913829258, 51.78556333269392, 51.9709586415972, 53.352743421282085, 44.682868071964805, 38.30719409670149, 39.981293065207346, 37.86621625082833, 38.49320432118007, 40.96614810398647, 41.285869462149485, 42.91891152518136, 42.49520342690604, 38.13835634504046, 38.859954561506, 38.88918910707746, 40.36105033329555, 36.897619996752056, 38.17904152188982, 37.91121278490339, 39.15860898154122, 38.2706743649074, 36.6816908291408, 35.957580838884624, 35.984748295375276, 37.5923182623727, 42.36384425844465, 46.90146262305123, 47.67954274586269, 49.449891635349815, 44.42477376120431, 46.61681924547468, 47.42756632396153, 48.70166097368513, 50.82295642580305, 47.2544276373727, 49.69853639602661, 49.84751967021397, 45.4872019631522, 44.351515429360525, 46.3384188243321, 49.576609407152446, 45.04064471381051, 45.051824365343364, 40.78971597126552, 41.44562591825213, 36.391513211386545, 38.86052778788975, 36.94433968407767, 35.14491605758667, 36.07722881862095, 34.57051542827061, 36.16060372761318, 35.22452156884329, 35.528814452035085, 36.47653136934553, 39.08812298093523, 37.35075371606009, 39.48906530652727, 35.68548590796334, 36.500221252441406, 35.9061085837228, 35.693729945591514, 38.98091227667672, 35.34720591136387, 37.778978143419536, 41.23386219569615, 37.692288943699424, 36.077941008976524, 37.81308337620327, 36.57898950576782, 37.41193607875279, 42.94596781049456, 46.57203810555594, 46.929036549159456, 45.44478668485369, 46.172412463596885, 45.57761192321777, 43.67160293034145, 43.2509103502546, 42.68471901757376, 42.05024773733956, 40.35496023723057, 40.14381490434919, 39.17897762571062, 40.639207567487446, 39.05618906021118, 39.07014104298183, 42.19628150122506, 45.99551132747105, 46.90339074816023, 45.81026887893677, 25.255274023328507, 0.4534846304782799, 3.5094717059816634, 14.163369553429739, 12.7467326096126, 17.186014856610978, 8.150864890643529, 0.27521733194589615, 0.6082979589700699, 0.7437473365238735, 4.219538952623095, 30.147299153464182, 33.942651884896414, 38.50756972176688, 38.38024050848824, 47.237890924726216, 10.95862238747733, 0.3335216205034937, 0.1346179550247533, 0.19328568050903933, 0.19487491808831692, 0.12438012366848332, 0.22359419773731912, 0.22221875297171728, 0.12349702391241278, 0.23387145197817258, 0.15517680613057955, 0.10925776977092028, 0.09274301451763936, 0.11473648542804377, 0.08045009736503873, 0.13049238068716867, 0.12130842278046267], [0.06388224674654858, 0.04651112262425678, 0.02434126314307962, 0.06314314569213561, 0.02990336057596973, 0.043788857092814784, 0.001020480620874358, 0.017636161596913422, 0.05076234807659473, 0.04797039360606244, 0.04429723588483674, 0.02822680232514228, 0.025049587545384253, 0.046722299685435634, 0.06067998893558979, 0.012745787539253277, 0.03353450680151582, 0.028363087779975364, 0.03656080351876361, 0.019981711271352003, 0.044432813966912885, 0.0962767909680094, 11.83712829862322, 42.6880715233939, 27.34218978881836, 31.317101342337473, 29.824909687042236, 33.89727667399815, 4.736569608960833, 0.38398068717547823, 0.8630951323679515, 0.19157208103154386, 0.04176715521940163, 0.14962941594421864, 0.015376027606959854, 0.17143246957233974, 0.22178294349993977, 8.950935193470546, 45.36493451254708, 51.71553243909563, 48.632189410073416, 46.23870175225394, 42.638047967638286, 40.828716209956575, 41.29999514988491, 43.84263631275722, 45.2237332207816, 45.4262558392116, 46.57110704694475, 46.38685471670968, 47.843770367758616, 45.9340614591326, 48.005712032318115, 45.81454202107021, 45.301810128348215, 40.159972940172466, 36.44522973469326, 35.19845192773001, 36.93029390062605, 37.825687408447266, 39.49738924843924, 39.02540854045323, 39.93186010633196, 36.852411542619976, 34.30045631953648, 34.383476870400564, 35.29954126902989, 35.84599624361311, 34.61038071768624, 33.757944447653635, 35.89451551437378, 34.17338418960571, 33.921626635960166, 33.3534620148795, 33.57170145852225, 33.61969266619001, 34.93320792061942, 37.736093861716135, 40.15777383531843, 44.70865978513445, 45.475654057094026, 39.76359558105469, 43.063461848667686, 42.195774282727925, 45.822761740003315, 45.30459983008248, 44.99127776282174, 47.5292705808367, 46.18321343830654, 45.183127948216026, 40.86171667916434, 43.25154263632638, 47.333578041621614, 43.17429951259068, 41.38289063317435, 36.07880258560181, 36.029397419520784, 35.845214571271626, 36.70878185544695, 36.24321780885969, 36.71154029028756, 34.772020135607036, 34.83932038715908, 32.69960873467581, 32.85783658708845, 32.69284813744681, 34.80884906223842, 33.898371015276226, 33.31380864552089, 34.136141845158164, 33.42635556629726, 32.92513683864048, 34.63020045416695, 33.70840726579939, 32.15888602393014, 33.8287604876927, 41.21060657501221, 41.4775424684797, 41.459584849221365, 36.52875402995518, 32.986763886043, 32.88850246156965, 34.43143333707537, 39.95220790590559, 43.822684560503276, 43.794127464294434, 41.76033762523106, 41.7044289452689, 41.492540155138286, 39.40335580280849, 38.72665337153843, 38.11502429417202, 36.40487807137625, 36.77892739432198, 37.852441447121755, 36.323201996939524, 35.901491505759104, 36.368375710078645, 38.1623033114842, 39.84926339558193, 44.22653123310634, 43.60052980695452, 45.412317752838135, 9.976283465112958, 0.15722539834678173, 2.029231820787702, 8.402262006487165, 5.625661534922464, 7.066219389438629, 3.521391340664455, 0.3597494959831238, 0.11128578202000686, 0.08325499828372683, 4.415613642760685, 30.671551159449987, 24.594818217413767, 36.338251795087544, 33.14908422742571, 21.267697640827723, 0.7225969657301903, 0.020884839684835503, 0.030713137837925127, 0.060983063387019296, 0.025234707165509462, 0.011429800252829279, 0.02249625009218497, 0.03476176630439503, 0.030333263400409902, 0.02376855244593961, 0.03577079537457653, 0.027193198412922875, 0.01609643841428416, 0.015184483956545591, 0.02695113613403269, 0.03439388158065932, 0.04250213417357632, 0.018227667714069997, 0.04419527582025953, 0.05380420020914503, 0.015467470378748007, 0.02739222630459283, 0.04232653948877539, 0.05568547247509871, 0.048230730529342375, 0.022998734111232415, 0.06257263344845601, 0.046200116098459275, 0.012787504720368555, 0.010528628564705806, 0.017853111294763427, 0.03920595693801131, 0.03766914975962468, 0.055230585991271904, 0.020472923127402152, 0.024603759504056404, 0.06555108326886382, 0.0475067404497947, 0.3043883666396141, 17.87397336959839, 50.717031138283865, 28.338563203811646, 35.92905848366873, 36.287290232522146, 36.70480053765433, 6.43890996490206, 0.604048592703683, 2.490508177450725, 0.3369972940002169, 0.06049395498952695, 0.19678139793021338, 0.450994325535638, 0.49653748742171694, 0.08162290443267141, 11.799436058316912, 45.52020590645926, 51.37133605139596, 49.92559657778059, 46.91507066999163, 43.75501605442592, 41.445504324776785, 41.79316438947405, 44.909813608442036, 46.70723615373884, 47.90639100755964, 48.07916838782174, 46.944874967847554, 49.14095388139997, 47.06278242383684, 49.27537720543997, 47.165549755096436, 48.560688972473145, 41.99452665873936, 38.390516894204275, 36.5863094329834, 38.62254156385149, 38.40666798182896, 42.022503580365864, 41.68624550955636, 40.82441874912807, 37.91168178830828, 37.935166699545725, 35.91662468229021, 37.52252360752651, 36.69733469826834, 36.657146317618235, 34.94588490894863, 36.73095008305141, 36.09355708530971, 36.716212953839985, 34.645451750074116, 35.44439731325422, 34.98240116664341, 36.83284888948713, 39.99882684435163, 41.662611212049214, 47.34799902779715, 48.346250193459646, 43.693833691733225, 45.194095679691856, 44.610443523951936, 48.04168633052281, 47.22327538899013, 46.603548186165945, 49.255425453186035, 47.95714412416731, 46.67839070728847, 41.33793578829084, 45.143245288303916, 48.20675468444824, 44.35393687656948, 41.29433931623186, 38.17948620659964, 38.35074887956892, 38.4761187008449, 37.357344082423616, 37.13848277500698, 38.38988808223179, 36.7663893699646, 35.82178177152361, 33.36557272502354, 34.50188112258911, 34.189636026109966, 36.07686056409563, 34.343507358006065, 35.41954013279506, 36.66866643088204, 34.71276937212263, 35.80375467027937, 36.04511077063424, 33.25449882234846, 34.342635359082905, 34.562302657536094, 41.86280270985195, 44.348934173583984, 42.557292529514854, 37.71774019513811, 34.89849124635969, 34.37383624485561, 34.6528446333749, 41.22356496538435, 46.14503656114851, 44.813709599631174, 43.601040499550955, 44.47967495237078, 42.508940015520366, 40.43996449879238, 40.06510918481009, 39.7771897315979, 37.950800146375386, 38.86272341864449, 40.20747777393886, 38.27116421290806, 38.38706363950457, 37.965314933231895, 40.35682235445295, 41.061748368399485, 45.10833753858294, 43.31864139011928, 45.976521900721956, 11.04858158315931, 0.203715944396598, 4.670560419559479, 12.526766538619995, 9.630610585212708, 6.888784110546112, 3.5761748467172896, 0.48545923616204945, 0.09266213314341647, 0.046889548389507194, 4.383188571248736, 33.48053067071097, 29.223741122654506, 35.82388012749808, 36.235442774636404, 29.618398802621023, 1.6362609245947428, 0.07965577713080815, 0.0260305829412703, 0.019288238304268037, 0.05992294062993356, 0.029231661797634194, 0.020965822839311192, 0.03185882725353752, 0.015188243040548903, 0.01787343681124704, 0.025701213561530625, 0.07372544213597264, 0.06070548149624041, 0.029114244705332176, 0.04282873682677746, 0.046997136902064085, 0.02479901134834758, 0.2228748013398477, 0.11433077576969351, 0.11881951561995915, 0.1495591468576874, 0.12436178965227944, 0.13159434869885445, 0.19902491968657288, 0.1563185905771596, 0.07496046407946519, 0.16623227218432085, 0.19133569300174713, 0.08802996456090893, 0.08796924246209008, 0.12456809143934931, 0.14192735137684004, 0.08780654333531857, 0.1407181748322078, 0.1280867297734533, 0.09870278436158385, 0.09027455161724772, 0.1590335720351764, 0.3993213597152914, 21.03001366342817, 57.96168851852417, 35.929284300122944, 40.75985261372158, 39.23799909864153, 42.5504207611084, 8.104912110737391, 2.555008739233017, 4.496122854096549, 0.557520252253328, 0.14182434976100922, 0.6637410553438323, 0.46433535537549425, 0.5792460750256265, 0.43430521392396515, 12.411943214280264, 48.84360224860055, 54.588025433676584, 53.057285172598704, 49.098354475838796, 48.13706772668021, 44.15074723107474, 45.72217961720058, 48.92102255140032, 49.06958198547363, 50.41790771484375, 50.32516663415091, 49.96489906311035, 50.12540939876011, 49.181437560490195, 50.83526168550764, 48.97567360741751, 49.6739501953125, 44.65850421360561, 39.447699206215994, 38.015876974378315, 40.77663598741804, 41.443892342703684, 43.590517452784944, 43.27600029536656, 44.55118233816964, 40.27238784517561, 38.378732749394004, 37.72422981262207, 39.1372641154698, 38.22968694141933, 37.9213536807469, 36.63450908660889, 39.65292467389788, 37.48470803669521, 38.61711502075195, 36.411287784576416, 36.2361410685948, 37.5477420943124, 39.370758329119, 41.28671714237758, 44.45856979915074, 48.40181146349226, 50.57717432294573, 45.535363401685444, 44.69500657490322, 44.886033398764475, 49.35509041377476, 47.93311030524117, 47.56698540278843, 50.745775835854666, 48.83585500717163, 47.116026469639365, 43.648298672267366, 46.35599776676723, 50.82803208487374, 46.08204766682216, 45.19504063470023, 40.27564655031477, 40.00106416429792, 40.28720835277012, 39.903094564165386, 38.360417297908235, 41.188104833875386, 37.590897355760845, 38.16433218547276, 36.214417525700156, 35.95987374441964, 36.613410881587434, 37.88109234401158, 37.66698360443115, 37.12134504318237, 37.049132415226524, 35.592407839638845, 37.52605676651001, 37.72513655253819, 36.4219081061227, 34.82002176557268, 37.002777508326936, 44.33649342400687, 45.574645042419434, 45.19837229592459, 39.523274762289866, 36.071760586329866, 36.1890982900347, 36.01782866886684, 43.70051091057913, 47.39679275240217, 46.420108795166016, 45.55557223728725, 44.953323228018625, 45.969952378954204, 42.32666097368513, 41.496910572052, 42.64227247238159, 39.50258650098528, 41.581876618521555, 42.09845086506435, 40.23017406463623, 40.18265186037336, 40.52171352931431, 41.619296142033164, 42.70318385532924, 47.96189669200352, 44.70663438524519, 46.53785644258772, 12.842612539018903, 0.2138006846819605, 6.965723250593458, 16.154678106307983, 13.579363039561681, 11.942030463899885, 9.670318671635219, 1.1044496042387826, 0.3018283082970551, 0.12972346480403626, 7.920438306672232, 41.02079916000366, 33.81568397794451, 43.39965043749128, 41.85227271488735, 35.88649034500122, 2.178413335766111, 0.22470083406993321, 0.08417846408805676, 0.10795514538351979, 0.12596325443259307, 0.07778748523976121, 0.11997204806123461, 0.1369961252702134, 0.19271953803087982, 0.1434444064008338, 0.14101173622267588, 0.11473503336310387, 0.11962724370615822, 0.13421269319951534, 0.15803265145846776, 0.254690941955362, 0.08651236670890025], [0.08418400771915913, 0.06478539042707, 0.027938764209726026, 0.009686064490649317, 0.06123282534203359, 0.049568492852683575, 0.03994159746382918, 0.01847099376443241, 0.021960434736683965, 0.07343361100980214, 0.005813213065266609, 0.07198127465588705, 0.048664056562951634, 0.020552783306421976, 0.017751029093882868, 0.049620092048176696, 0.05243148315431816, 0.054214113391935825, 0.027084756642580032, 0.03736862999254039, 0.06174351115311895, 0.012205479433760047, 3.9894063643046787, 27.758543218885148, 31.490514482770646, 23.985645328249248, 34.70413623537336, 30.08483832223075, 7.866944994245257, 0.2439397717160838, 1.152688232915742, 0.45398598643285887, 0.05178227781185082, 0.08241875815604414, 0.41271273685353144, 0.1709042436310223, 0.08907410781830549, 0.6793186451707567, 23.381596735545568, 52.38685001645769, 46.72874430247715, 48.673169885362896, 45.05852937698364, 44.61603682381766, 45.259551184517996, 46.11794900894165, 47.018494606018066, 47.65047148295811, 47.576462745666504, 47.159699371882844, 47.37128938947405, 48.16859517778669, 47.294966902051655, 46.56478418622698, 43.129466261182515, 38.61798701967512, 35.0552009173802, 34.66883243833269, 36.79000282287598, 38.0351755959647, 39.99844816752842, 39.791881697518484, 36.95971952165876, 35.767683097294395, 35.272724696568076, 36.29632289069039, 36.820244857243125, 33.87684897014073, 36.073886735098704, 35.59146983282906, 35.705444608415874, 34.33713238579886, 33.69967338017055, 33.860878535679404, 32.35424157551357, 34.80326965876988, 33.25038201468331, 36.19047055925642, 39.21994073050362, 43.6958451952253, 45.26163911819458, 41.26483726501465, 44.964607102530344, 43.13529927389962, 45.53926828929356, 44.72213929040091, 46.54033694948469, 46.70275109154837, 43.4244589805603, 44.07931627546038, 40.984939507075715, 45.54179743358067, 45.09457663127354, 41.04068143027169, 38.86516571044922, 36.59675257546561, 37.2925660269601, 37.14377382823399, 39.0816194670541, 40.27582025527954, 39.48736299787249, 38.59905317851475, 33.85163743155343, 33.553441592625205, 33.07854264123099, 33.58112668991089, 32.65897914341518, 33.40609809330532, 33.64750977924892, 33.606352124895366, 32.97943006243025, 32.23622294834682, 33.69255495071411, 32.321546827043804, 33.44380596705845, 36.54776777539934, 43.92885650907244, 45.439749240875244, 45.78774976730347, 43.82394218444824, 36.19291285106114, 32.43549380983625, 32.98543678011213, 37.937678473336355, 43.64732245036534, 43.42168664932251, 42.1108638218471, 43.0847407068525, 39.204508781433105, 38.47719914572579, 36.92627436774117, 35.57813276563372, 35.95041377203805, 34.511094433920725, 36.12680074146816, 35.798296860286165, 36.0595942905971, 36.287245069231304, 40.323801040649414, 41.49754980632237, 44.92109053475516, 45.371114935193745, 37.02323647907802, 1.3449181807892663, 0.1079720544761845, 3.587721449988229, 10.301839573042733, 7.399920957429068, 6.040945376668658, 1.7070357097046716, 0.6970100072877747, 0.10145502417747464, 0.06310277285852603, 18.47673828261239, 27.145748581205094, 23.23439567429679, 38.70898757662092, 36.151602336338584, 9.604877931731087, 0.05177537711071117, 0.04339026187413505, 0.023632528227088705, 0.024174594586449008, 0.02454265233661447, 0.0665013308503798, 0.10976219270378351, 0.054278279055974314, 0.030361436174384186, 0.043686323666146824, 0.01685265721088009, 0.046433023243610344, 0.08799988510353224, 0.020693065332514898, 0.04197210332910929, 0.01880413749521332, 0.028656874783337116, 0.0881627674347588, 0.053700235073587725, 0.019541940851403133, 0.028478684702089856, 0.02659589421403195, 0.010795185109600425, 0.054043614505124946, 0.05481515292610441, 0.039185390541596074, 0.02248011961845415, 0.04751441128818052, 0.0648427741335971, 0.051534212194383144, 0.006751202487586332, 0.08232571743428707, 0.04985824766169701, 0.026825060934892724, 0.03671296499669552, 0.06295612787029572, 0.050992741249501705, 0.030627784917929342, 0.06988969724625349, 6.4211143255233765, 36.7956725529262, 34.03309658595494, 26.275088923318044, 41.39697115761893, 35.427078928266255, 8.860440117972237, 0.3992769292422703, 2.5309988047395433, 0.6737147058759416, 0.06851070374250412, 0.13730302665914806, 0.5263925939798355, 1.3923723144190652, 0.5506335560764585, 1.2018098256417682, 27.831110204969132, 54.2262396812439, 48.8073604447501, 50.36633471080235, 46.94842202322823, 45.89166702542986, 46.74581255231585, 48.46285833631243, 46.37104409081595, 49.2707462310791, 49.08175870350429, 47.53839703968593, 47.82062591825213, 48.8809175491333, 49.50196490968977, 47.73602812630789, 44.46655675343105, 39.62232480730329, 37.12948138373238, 37.004775115421836, 39.04729536601475, 40.96063123430525, 42.73388794490269, 42.40852812358311, 38.104893820626394, 37.381287574768066, 36.335482937949045, 36.84953498840332, 37.64899819237845, 36.684098379952566, 36.81528731754848, 37.28901897157942, 37.9252724647522, 35.44503654752459, 35.36065067563738, 34.75527845110212, 34.71378033501761, 35.29888813836234, 35.48010410581316, 38.12009995324271, 41.89718587057931, 47.32182516370501, 46.298202650887625, 43.17542512076241, 46.156765120370046, 44.84900992257254, 46.20220981325422, 46.08219705309187, 48.2098605292184, 47.289262431008474, 45.39703171593802, 45.39001056126186, 42.69962637765067, 46.688580240522114, 46.609867572784424, 44.64838416235787, 41.247272218976704, 37.51993192945208, 38.26140546798706, 38.746104853493826, 41.42053597314017, 40.859055519104004, 41.585031100681846, 40.03825787135533, 34.728010245731895, 35.29313850402832, 34.639729908534456, 35.228381293160574, 34.05270440237862, 34.66558068139212, 35.52894994190761, 35.208530289786204, 34.289561544145855, 34.26869262967791, 36.185460908072336, 33.992070947374614, 33.37125635147095, 37.93246732439314, 44.749060085841585, 46.48402874810355, 46.24473278863089, 43.37555061067854, 36.305237429482595, 33.536050251552034, 35.12461689540318, 39.96006979261126, 45.016683850969585, 44.11589854104178, 44.11303588322231, 44.678719997406006, 41.76415566035679, 41.290243353162495, 38.30132981709072, 37.91419356209891, 37.359616143362864, 36.58497885295323, 36.8610794203622, 37.137089661189485, 38.35592181341988, 37.31677007675171, 41.762074674878804, 42.89180312837873, 46.14755180903843, 46.00867468970162, 38.19160039084298, 1.8880005649157932, 1.5675422634397234, 6.886673595224108, 11.746436936514717, 9.515113285609655, 7.7186495917184015, 4.147645507540021, 1.1899167895317078, 0.046638344547578266, 0.0286686304025352, 19.214367730276926, 36.33368335451399, 25.66855808666774, 41.00597170421055, 39.994960171835764, 14.89683529308864, 0.04645713498549802, 0.034196580560611825, 0.015238907554053834, 0.01897833270153829, 0.022164970636367798, 0.013476290706811207, 0.028123215472857867, 0.035857983731797764, 0.02976088857810412, 0.06335000387792077, 0.042989464809319804, 0.08228190442813293, 0.08921372996909277, 0.054816177513982565, 0.027424875713352646, 0.010976349718735685, 0.038347810307251554, 0.23866291344165802, 0.14859171876949923, 0.19779933616518974, 0.07559460933719363, 0.16799426477934631, 0.1546928613845791, 0.12771278912467615, 0.15776905417442322, 0.14413352656577313, 0.1615403246666704, 0.11586327425071172, 0.1495698405695813, 0.1564106677791902, 0.07885478689734425, 0.1457179058343172, 0.12039058203143732, 0.1264550701848098, 0.243095049900668, 0.1269477680325508, 0.13844539464584418, 0.11422757059335709, 0.11666907529745783, 7.285157561302185, 42.58479697363717, 41.35555641991751, 32.74480676651001, 44.02405030386788, 39.960754190172466, 13.65081136567252, 0.9604104076113019, 4.335378451006753, 1.1668965390750339, 0.2423181544457163, 0.31035578357321875, 1.0225672551563807, 1.4865704540695464, 0.41071423409240587, 1.4472432157823016, 28.30385000365121, 54.463187149592805, 50.75653164727347, 52.50077615465437, 48.07079928261893, 48.78143324170794, 48.43249818256923, 50.61453826086861, 50.27515697479248, 52.48727233069283, 50.078651496342246, 47.507508822849815, 49.877838134765625, 51.457927976335796, 50.728214263916016, 50.869721276419504, 46.71281208310808, 41.72373798915318, 38.70168501990182, 39.26761926923479, 42.39430168696812, 41.674239022391184, 44.36415767669678, 44.070026533944265, 39.40339054380144, 39.454567500523154, 37.57950578417097, 39.99986560004098, 40.78586319514683, 38.62289244788033, 40.35308769771031, 38.29165097645351, 38.82435199192592, 36.849093777792795, 37.30626787458147, 36.176146847861155, 36.03559173856463, 36.911888122558594, 37.49769769396101, 39.733176367623464, 42.85659313201904, 47.98631266185215, 48.47873844419207, 45.64199045726231, 47.92561319896153, 45.572133268628804, 47.10874475751604, 47.85045453480312, 49.707527365003315, 50.13805512019566, 45.26173291887556, 47.082497937338694, 45.25271763120379, 46.958792209625244, 47.62752158301217, 44.69631283623831, 43.08980941772461, 40.46759748458862, 41.9464624949864, 40.91268866402762, 42.42430053438459, 42.3537346294948, 42.08028827394758, 42.73002822058541, 36.56212970188686, 37.029496806008474, 36.09390796933855, 37.50710902895246, 35.30126789637974, 36.025461265019004, 37.94291046687535, 35.98705162320818, 35.928005831582205, 36.425118173871724, 37.57439538410732, 35.02997548239571, 35.72062989643642, 40.54596274239676, 46.481256416865754, 50.10502338409424, 48.70490230832781, 46.29147332055228, 39.840564250946045, 35.20760270527431, 36.71913814544678, 41.41288253239223, 45.81035573141915, 45.64782346997942, 45.38222163064139, 46.31975596291678, 41.11079222815377, 43.07693787983486, 40.49506718771798, 39.64542409351894, 38.87553242274693, 38.281569140298025, 37.91915110179356, 39.41317708151681, 39.57771389825003, 39.03606360299246, 44.3072623525347, 44.20570053373064, 47.224039690835134, 46.24646636417934, 39.00038807732718, 2.0970623067447116, 1.1526327558926173, 10.00585847241538, 20.125493696757726, 19.815484183175222, 12.477964128766741, 6.839662952082498, 1.2375150982822691, 0.1217819723699774, 0.22271888756326266, 25.894989456449235, 37.352904183524, 32.55520779745919, 43.26242004122053, 47.279402937207905, 17.24507975578308, 0.17411237076989242, 0.1999222551073347, 0.17205612467867987, 0.1076074301132134, 0.15711296509419168, 0.07098587056888, 0.1402995322964021, 0.14272054524293967, 0.16694599602903637, 0.11920372928891863, 0.15826935161437305, 0.18772617168724537, 0.22205519889082226, 0.1274994034320116, 0.10719085710921458, 0.05732462648302317, 0.12131481458033834], [0.044793496041425636, 0.06699586752802134, 0.05721437811319317, 0.04666149955508964, 0.02208893060950296, 0.06196892727166414, 0.03281168040952512, 0.005619632961627628, 0.056653843726962805, 0.0378367682652814, 0.08077049481549434, 0.01741930689396603, 0.08082219239856515, 0.02402720829871084, 0.05340782719265137, 0.03958325294245567, 0.024205586673425775, 0.058420365543237755, 0.047392203738646846, 0.04286131668569786, 0.06076813741986241, 0.09986118613077061, 0.31901440609778675, 11.80222749710083, 36.049644470214844, 27.203232765197754, 23.34578398295811, 31.83833088193621, 22.89031219482422, 1.060954532452992, 0.5790839322975704, 0.8088901181306157, 0.13188557592885836, 0.3713919626814978, 0.5564491440142904, 1.0346466984067644, 1.036133070077215, 0.0694785253810031, 4.833926899092538, 41.274523053850444, 52.244314670562744, 48.672534125191824, 45.74817630222866, 47.23977736064366, 45.390364919389995, 46.246417726789204, 47.04562732151577, 47.10482249941145, 45.89688164847237, 46.12293781552996, 46.30164200919015, 48.619984899248394, 45.86180019378662, 45.19010393960135, 38.80489008767264, 34.93825578689575, 35.29529939379011, 36.15044546127319, 37.47775983810425, 38.27978345326015, 38.032184396471294, 39.12138400759016, 36.532891682216096, 37.53074680055891, 35.14844921657017, 34.82535103389195, 34.05324288776943, 35.47693920135498, 35.24852759497506, 35.76067583901541, 34.60386678150722, 34.87283502306257, 33.48193768092564, 35.24301419939314, 33.986581870487754, 34.55564628328596, 33.68402256284441, 36.2361341203962, 38.63503442491804, 43.11347845622471, 43.751569747924805, 43.44101306370327, 45.19881698063442, 43.93071167809622, 44.688812255859375, 46.03499099186489, 46.89447620936802, 47.00351081575666, 44.15652813230242, 41.70206308364868, 42.54117965698242, 43.78675889968872, 43.65960686547415, 40.53258398600987, 38.8089964730399, 38.63748713902065, 37.67214264188494, 41.1223783493042, 41.83675043923514, 41.35762350899832, 42.13328218460083, 41.14598485401699, 36.286946296691895, 33.64094720567976, 32.422848088400706, 31.90488072804042, 32.76202440261841, 33.47936337334769, 32.46240765707833, 34.02799660818917, 33.25623934609549, 33.23500912530081, 33.25563137871878, 33.29187318256923, 32.195089612688335, 37.103088651384624, 45.676088741847444, 44.21576499938965, 46.14005470275879, 44.1780675479344, 41.1674930027553, 33.56599351337978, 31.589293548039027, 36.496396269117085, 41.586584023066926, 41.36316122327532, 42.11789539882115, 41.6827575138637, 39.74785096304757, 37.28140722002302, 35.221273286002024, 34.235007762908936, 32.09829773221697, 33.5494498525347, 33.427738257816856, 35.41801847730364, 36.15611866542271, 40.31806182861328, 40.43471166065761, 41.73896149226597, 43.80804818017142, 47.03917244502476, 18.19953989982605, 0.06147006154060364, 1.483632994549615, 4.331842252186366, 11.328827619552612, 8.099687933921814, 4.9431226168360025, 2.566610276699066, 1.4049551763704844, 0.05283828864672354, 1.1060946988207954, 27.734690053122385, 35.72918312890189, 26.373228754316056, 38.805626596723286, 27.43627187183925, 1.091728321143559, 0.0038763959226863725, 0.05597298133320042, 0.0599480735670243, 0.030157224275171757, 0.11795717903545924, 0.026105513563379645, 0.045767526275345256, 0.09040991935346808, 0.008945855727818395, 0.02267422982757645, 0.016081817680969834, 0.042388686511133394, 0.04097293337274875, 0.03282207217333572, 0.043709946862821064, 0.038853312110794444, 0.07869641003864151, 0.04506829933130315, 0.026178322067218165, 0.03887043494199004, 0.08130482757197958, 0.09332799991326672, 0.033876773435622454, 0.03637074925271528, 0.0407208372572703, 0.033003559934773614, 0.04313000976773245, 0.03317388579515474, 0.009014721095029796, 0.07306710031947919, 0.009220145027419286, 0.11243517284414598, 0.02349180684957121, 0.05238915613985487, 0.040851075268749676, 0.015655974192278724, 0.013899297919124365, 0.048483566247991154, 0.08621400129050016, 0.5678326274667467, 20.263726370675222, 41.13741077695574, 27.91773165975298, 31.379513536180767, 39.05715833391462, 22.007482767105103, 1.553148852927344, 1.3724700680800845, 1.1175036409071513, 0.08875996646072183, 0.48307898959943224, 1.2544251680374146, 2.928523050887244, 1.8404162611280168, 0.24391683723245347, 5.943030493600028, 44.71155718394688, 52.610578536987305, 50.31788492202759, 47.57212706974575, 47.78807013375418, 47.03336375100272, 48.700969627925325, 48.43222025462559, 48.35113477706909, 46.50528328759329, 46.68531111308506, 47.4312801361084, 50.42944172450474, 46.81259168897356, 46.50530413218907, 41.27375527790615, 37.55115365982056, 36.65322058541434, 37.855776582445415, 38.85138743264334, 41.31676115308489, 39.79338945661272, 42.5442681312561, 39.43774243763515, 38.58358996255057, 36.28874588012695, 38.069454533713206, 34.80996077401297, 36.28226668494088, 36.549570832933696, 37.81599814551217, 35.5219600541251, 36.26886360985892, 36.23961864198957, 36.77981676374163, 35.80236503056118, 34.95602927889143, 34.75118248803275, 37.17536381312779, 40.034526688711985, 45.24669006892613, 45.92484814780099, 45.3894408089774, 46.85490274429321, 45.26156268801008, 45.62622152056013, 47.545894145965576, 48.84267118998936, 47.84843955721174, 45.9811806678772, 42.63548755645752, 43.38036571230207, 45.33599526541573, 44.3661379132952, 42.27258661815098, 41.51929071971348, 40.32075078146798, 40.80923693520682, 41.92445755004883, 42.51423454284668, 44.21177673339844, 44.12637989861624, 42.46445417404175, 37.14543444769723, 34.77852712358747, 33.672380856105256, 34.07873930249895, 33.82642241886684, 34.18831239427839, 33.958062989371165, 34.628487723214285, 33.71906580243792, 34.66840165002005, 34.15619434629168, 35.42452546528408, 33.222234862191335, 38.5042519569397, 45.62109375, 46.147141865321565, 46.065542221069336, 45.95794241768973, 41.886322362082346, 34.846021924700054, 33.116921016148154, 37.58566536222185, 43.183026450020925, 43.86137907845633, 43.28214945111956, 43.021178586142405, 41.53594555173601, 38.608832768031526, 36.927299227033345, 35.06550162179129, 34.87259531021118, 33.63235575812203, 35.36339521408081, 35.96145445959908, 38.97736174719674, 41.16878536769322, 42.718191964285715, 43.27473224912371, 45.256514821733745, 45.943403312138145, 20.998399359839304, 0.2653852238186768, 4.855349498135703, 7.214298095021929, 11.363186461584908, 9.065088016646248, 6.600832087653024, 7.499485169138227, 1.15519294994218, 0.07308790420315095, 1.3009850467954363, 33.99862657274519, 37.676144804273335, 27.5285804271698, 41.94298492159162, 33.26808255059378, 3.3318399233477454, 0.02542683605237731, 0.1053704833611846, 0.04804434035239475, 0.0128718864871189, 0.08319306839257479, 0.030660958494991064, 0.07440331897565297, 0.012497125659137964, 0.01085372911100941, 0.00535725661653227, 0.006069002531668437, 0.045495070716632266, 0.04572440876758524, 0.04768743771793587, 0.02892613783478737, 0.02573006826319865, 0.028837626334279776, 0.0930631405540875, 0.1309270773615156, 0.18133137268679483, 0.15396179418478692, 0.1339756537761007, 0.0988747522767101, 0.10496240561561924, 0.1157973613590002, 0.13171463938696043, 0.15675574354827404, 0.09324960197721209, 0.09246683040899889, 0.24349299711840494, 0.09592921819005694, 0.21825830691627093, 0.16040069796144962, 0.12998238019645214, 0.12132869740681988, 0.13669873694224016, 0.1455150374344417, 0.1023527260071465, 0.21452289021440915, 0.5836668663791248, 24.408964327403478, 48.16663925988333, 36.85019506726946, 32.76700278690883, 42.14840146473476, 32.525716168539866, 2.3734609952994754, 3.415582001209259, 1.791071348956653, 0.3247504968728338, 1.0264246995959962, 1.9386251398495264, 3.2364635212080817, 2.948333667857306, 0.1465329620987177, 6.525582662650517, 44.335812500544954, 54.45465823582241, 52.18481029782976, 48.13359362738473, 51.06652552740914, 48.998015539986746, 50.049562862941194, 49.579541546957834, 50.37846973964146, 48.1208575793675, 47.92634970801217, 48.94470201219831, 52.68938500540597, 50.67509528568813, 50.089730398995535, 42.773836612701416, 38.948839391980854, 39.25481721333095, 40.17426885877337, 40.15350416728428, 41.97794130870274, 42.227802004132954, 44.83142750603812, 40.67511585780552, 41.26128326143537, 38.75138201032366, 38.746917792728965, 36.33018146242414, 39.49928610665457, 38.390878200531006, 39.52368123190743, 37.73961312430245, 37.91886969975063, 37.40371635981968, 38.568255288260325, 38.037364278520855, 38.03793403080532, 36.94972801208496, 39.7027884210859, 42.54634911673409, 46.44245420183454, 48.53971930912563, 48.456062998090474, 49.357557024274556, 47.233909606933594, 48.09950229099819, 48.423715659550254, 52.395847933632986, 50.387915815625874, 47.50339548928397, 42.100959164755686, 46.33444792883736, 46.741678374154226, 46.59729828153338, 42.457974978855674, 42.71139662606375, 43.1500746182033, 42.81397983006069, 44.98035519463675, 43.95772280011858, 45.22898953301566, 46.61090980257307, 43.91280617032732, 39.33928298950195, 37.2444497517177, 35.204997130802695, 35.90059518814087, 35.6131134714399, 37.18696730477469, 36.31248787471226, 37.15063170024327, 35.458043575286865, 36.35145684650966, 36.89481292452131, 36.68129825592041, 34.15242494855608, 40.590386050088064, 48.88474600655692, 47.51131990977696, 48.17808294296265, 48.74212033408028, 43.5773332459586, 38.142591272081646, 33.802062034606934, 40.357287883758545, 45.36063010351998, 45.51329244886126, 44.75140162876674, 45.049903188432964, 43.6774046761649, 41.096433775765554, 38.6411384173802, 37.0262450490679, 36.50538028989519, 34.93477473940168, 37.54892328807286, 36.78163024357387, 40.09844316755022, 45.035513469151084, 43.50066334860665, 44.12838445390974, 47.46507269995553, 47.062664304460796, 21.29582221167428, 0.3643992521933147, 4.322261989116669, 13.247084549495153, 20.07861246381487, 17.527989557811193, 11.286602548190526, 10.011468274252755, 4.977806721414838, 0.16923920011946134, 2.697854148490088, 39.366905553000315, 43.74053600856236, 34.82509395054409, 45.89435945238386, 39.17256791251046, 3.9034184983798434, 0.1394499521702528, 0.1962496300360986, 0.12053411932928221, 0.11687533637242657, 0.20671592413314752, 0.15121014469436236, 0.09972051903605461, 0.20897879770823888, 0.1165386608668736, 0.07712098743234362, 0.07979199982115201, 0.13570426244820866, 0.11832129449716636, 0.18769263848662376, 0.09303025196173362, 0.14797195845416614, 0.18169934222740786], [0.05558856071106025, 0.03554727576140847, 0.014618312640647804, 0.0656795638746449, 0.02068525878712535, 0.050886465702205896, 0.04508861806243658, 0.06835726661873714, 0.06946355689849172, 0.043791309996907196, 0.02050979302397796, 0.03446369604872806, 0.041331878397613764, 0.014722162425251943, 0.016953007451125553, 0.03634764174265521, 0.048484726542873044, 0.05678953715999212, 0.04257583664730191, 0.04689859326130577, 0.06426906598997967, 0.05581644669707332, 0.06279072817414999, 1.7358452209404536, 23.25968885421753, 33.91870491845267, 28.70561569077628, 34.263665607997346, 28.67617964744568, 6.597890394074576, 0.9248117463929313, 0.34467024941529545, 0.1329964327492884, 0.08715986553579569, 1.0703575078930174, 2.6044336642537798, 0.7300861467208181, 0.34079386027795927, 0.18897991441190243, 17.061739376613072, 47.46116433824812, 49.190004689352854, 50.26267453602382, 49.26634454727173, 46.45667021615164, 47.18590797696795, 45.22610255650112, 47.09664099557059, 47.28273112433297, 46.87470163617815, 47.04068715231759, 44.80731725692749, 44.00556114741734, 41.87754331316267, 39.33866112572806, 36.18025323322841, 35.87668643678938, 35.83944409234183, 36.32764189583914, 38.44219759532383, 37.572599274771555, 38.817494119916645, 36.911717891693115, 35.66345664433071, 35.53420625414167, 35.947950635637554, 35.36374262401036, 36.371359961373464, 35.69285447256905, 36.38172319957188, 34.20027371815273, 34.98707035609654, 34.90758296421596, 35.59719862256731, 33.886854376111714, 33.424507345472065, 32.75371435710362, 34.54347651345389, 35.53633935110909, 40.41833823067801, 43.48082276753017, 45.70339863640921, 45.79082434517996, 45.6594443321228, 44.39684547696795, 47.021082809993196, 45.0059106690543, 46.457094056265696, 44.81432104110718, 42.01287685121809, 45.196927070617676, 44.49355745315552, 42.90134995324271, 41.43612773077828, 39.24806009020124, 41.13686881746565, 40.33634601320539, 41.640651430402485, 42.37685476030622, 43.90632350104195, 44.64284644808088, 43.20126894542149, 37.09844030652727, 31.325737953186035, 33.40051521573748, 32.529857294900076, 32.77983610970633, 32.85762119293213, 33.2224155153547, 33.20959261485508, 32.34180082593645, 32.6980870791844, 33.04765095029558, 32.59233202253069, 33.34774364743914, 33.09989445550101, 44.014124802180696, 42.965148312704905, 44.348395688193186, 44.171025548662456, 42.32645947592599, 38.28082915714809, 33.60574415751866, 31.91475064413888, 36.14578669411795, 37.927072048187256, 39.04945625577654, 39.040128299168174, 37.313250814165386, 36.82807895115444, 33.780609471457346, 32.382305349622456, 32.49839237758091, 30.619769709450857, 33.91019684927804, 35.85138804571969, 38.15604645865304, 39.653101852961946, 41.56767450060163, 41.70601313454764, 46.30719361986433, 34.02668687275478, 4.71074880020959, 0.21912936946111067, 6.8339584810393195, 5.7842975940023145, 8.750777568135943, 5.67217972448894, 5.583759120532444, 5.500113231795175, 0.4597187659570149, 0.03797962363543255, 6.532599908964975, 31.489006723676408, 25.312933649335587, 26.752768891198293, 35.764545985630576, 13.87313721861158, 0.3195223845541477, 0.05220222992024251, 0.05444639967754483, 0.02631020043710513, 0.06539262498595885, 0.007567975869668382, 0.052210698037275245, 0.041175615175494125, 0.042760618696255345, 0.013368009240366518, 0.03832292164276753, 0.03725152502634695, 0.04620826869670834, 0.018155641221840466, 0.0680443737655878, 0.051470630070460696, 0.02565586197722171, 0.026004679866933396, 0.02907170055966292, 0.034858101313667636, 0.024884528813085387, 0.040624454750546386, 0.007691224122286907, 0.01465970666946045, 0.0479507873366986, 0.006915263773407787, 0.026865851067538773, 0.011521727328986993, 0.0449841881303915, 0.019670114420088272, 0.024472325574606657, 0.041743708441832235, 0.040287769066968133, 0.008221260055766573, 0.07456869831574814, 0.05157169107613819, 0.05147036544180342, 0.023288100458947674, 0.04829972057736345, 0.060828350617417266, 0.05863658751228026, 4.543137405599866, 35.22835002626692, 35.46570743833269, 26.720980882644653, 39.678664275578086, 32.21159158434187, 7.488876138414655, 2.294795662164688, 0.6659751183220318, 0.22266437405986444, 0.9885971865483693, 2.362281995160239, 5.494258940219879, 4.335205614566803, 1.9699022386755263, 0.25701590148465975, 19.436550276620046, 49.88910116468157, 51.57517882755825, 51.60323912756783, 50.53125367845808, 48.42347594669887, 47.66525377546038, 48.05324118477957, 47.98426294326782, 48.71688447679792, 48.344912665230886, 47.61951725823538, 46.97705554962158, 46.07742364065987, 43.77139295850481, 39.875336510794504, 37.69698592594692, 37.22599533626011, 36.79700313295637, 38.33995485305786, 40.34799466814314, 40.921662262507844, 39.871931893484934, 38.88889728273664, 37.240728991372244, 37.31003727231707, 37.34102971213204, 37.33895567485264, 38.176703453063965, 37.13502952030727, 37.82439851760864, 35.986943926130024, 36.051464898245676, 35.76440354755947, 37.131840297154014, 34.943737915584016, 35.26822573798043, 34.847929205213276, 35.48976557595389, 37.809307030269075, 41.79640225001744, 44.17040368488857, 45.93042060307094, 47.543097496032715, 46.02409621647426, 44.80877637863159, 48.115021092551096, 45.973801680973594, 46.96769632611956, 46.37901367459978, 42.101824215480256, 46.0096926007952, 46.07672187260219, 44.59569597244263, 43.35950027193342, 41.452629702431814, 42.402229581560405, 42.5043055670602, 43.400647503989084, 45.20126622063773, 45.76453583581107, 46.72143479755947, 45.34689351490566, 38.584100655147004, 33.23245913641793, 34.964731897626606, 34.67698267527989, 35.02376726695469, 34.72301796504429, 33.77392530441284, 34.46249178477696, 33.455993107386995, 33.54436377116612, 33.81575345993042, 33.388310704912456, 34.21203007016863, 35.818123544965474, 45.403778416769846, 43.685610498700825, 46.30691916601998, 44.350702490125386, 44.175510610852925, 39.04338353020804, 33.95740985870361, 34.210866246904644, 38.97884518759591, 39.129089559827534, 40.298728466033936, 40.8672821862357, 39.458788531167166, 36.42511122567313, 35.85284716742379, 33.46463666643415, 35.350440297807964, 33.9136848449707, 35.26113510131836, 36.708073139190674, 40.04331963402884, 41.368250778743196, 42.86575780596052, 41.84027317592076, 46.93374742780413, 37.3732693535941, 6.099046213286264, 0.4655541128345898, 8.507259709494454, 7.471162574631827, 9.079477735928126, 7.5200388090951105, 7.953529970986502, 5.018011604036603, 0.3577628811555249, 0.15238696868930543, 7.402630754879542, 39.29221241814749, 35.77233144215175, 29.42039598737444, 39.52690519605364, 20.656252690723964, 0.4493949370724814, 0.06520956980862788, 0.029192045530570403, 0.03708992851898074, 0.048102226174835644, 0.023408632026985288, 0.04063349962234497, 0.023871165600472262, 0.04488619749567338, 0.05808937616114106, 0.008597411880535739, 0.028791251858430247, 0.041970515557165654, 0.039470120798796415, 0.05333763274497219, 0.04970321258796113, 0.00888020746476416, 0.06439452711492777, 0.08386836679918425, 0.06901799687849623, 0.11297749874315091, 0.1744696737400123, 0.12296342397374765, 0.09670141818267958, 0.13530098194522516, 0.09952294320932456, 0.21704858754362377, 0.16894985921680927, 0.17080854305199214, 0.14885741951210157, 0.14488710755748407, 0.11159184202551842, 0.1533838180559022, 0.13416056813938276, 0.19882906733879022, 0.16681307101888315, 0.18699076186333383, 0.11789505236915179, 0.13710638721074375, 0.12145459279417992, 0.1172768526843616, 5.373619973659515, 41.11911269596645, 42.02138492039272, 37.74140575953892, 43.35204485484532, 39.3728323663984, 12.301379135676793, 4.379004887172154, 1.0041251076119286, 0.33097570283072336, 1.5598717778921127, 1.8904298288481576, 5.212328399930682, 4.547755786350795, 1.3760894281523568, 0.3650831069265093, 20.14930169922965, 49.49781683513096, 52.52018594741821, 52.69360603604998, 52.69996016366141, 50.25704649516514, 49.761688573019846, 48.23561750139509, 48.76023428780692, 50.9285238810948, 49.59359080450875, 48.35653352737427, 47.06821591513497, 47.31656537737165, 45.62821217945644, 41.47222362245832, 40.28199372972761, 39.466806752341135, 39.48376383100237, 40.80003752027239, 42.94062464577811, 42.17363732201712, 42.53805296761649, 40.12971006120954, 40.273190362112864, 39.25692251750401, 40.040126936776296, 38.98175995690482, 40.610546248299734, 38.53766236986433, 39.32235370363508, 37.156204155513215, 38.24548714501517, 38.6806389263698, 40.41618776321411, 36.93129791532244, 37.10547883169991, 36.39227403913225, 38.30681889397757, 40.44927855900356, 43.156355789729524, 45.34846033368792, 49.359450408390586, 49.427237033843994, 47.52392046792166, 46.13875191552298, 50.21089308602469, 48.5031544140407, 49.48688384464809, 47.221142292022705, 43.3265380178179, 47.66866881506783, 48.313638823372976, 45.83811378479004, 46.67665365764073, 43.059199128832134, 44.53748396464756, 44.00661379950387, 45.36497620173863, 47.46457590375628, 47.99234022412981, 47.72160366603306, 46.9690512248448, 39.938405309404644, 33.536196163722444, 37.23225566319057, 36.958614758082796, 36.014111382620676, 36.10657453536987, 35.6598470551627, 35.028641428266255, 35.840830257960725, 35.34229006086077, 36.4832398550851, 36.12831892286028, 36.45918519156319, 37.23310334341866, 47.868738719395225, 45.72740466254098, 47.76049620764596, 46.91379567555019, 45.86106021063668, 41.29145233971732, 37.27942698342459, 36.14273643493652, 40.92632450376238, 41.691859654017854, 41.92389474596296, 42.115717138562886, 41.3573351587568, 38.38529532296317, 37.760711329323904, 35.73190334865025, 36.815450600215364, 34.156889166150776, 37.428365094321116, 38.729793957301546, 42.11605065209525, 42.43056780951363, 45.28032282420567, 43.35270493371146, 47.70959717886788, 36.21178763253348, 6.781165633882795, 0.5095526576042175, 13.105604461261205, 13.88967740535736, 18.329229763575963, 11.860777361052376, 15.10963429723467, 11.280392595699855, 3.324201464653015, 0.16111307830682822, 10.392730695860726, 41.881604535239084, 33.08420194898333, 37.081240040915354, 44.37155403409685, 23.44676215308053, 0.4615761605756623, 0.16940176353922912, 0.1532410950000797, 0.12998502648302487, 0.1830579186124461, 0.17083875143102237, 0.12240032133247171, 0.2256495210209063, 0.10888123711837189, 0.09490834868380002, 0.13657909764775208, 0.14408225645976408, 0.05406472372955509, 0.09821585406150136, 0.1395122959677662, 0.09291501635951654, 0.12211149611643382, 0.07189761807343789], [0.038498312767062864, 0.03305836860090494, 0.03336294261472566, 0.050209121512515206, 0.020795535994693637, 0.015954590668635707, 0.027017803895952444, 0.008991216641983815, 0.04002314719504543, 0.006735848088283092, 0.016164641361683607, 0.017112763432253684, 0.05849176099789994, 0.03294520592316985, 0.015469672224883522, 0.048497801912682395, 0.03408834065443703, 0.059280334040522575, 0.06524362548121385, 0.035397143103182316, 0.058520300180784295, 0.018069533431636434, 0.028976953322333947, 0.1724267676472664, 8.452262980597359, 32.6592674936567, 32.137669699532644, 30.83911391666957, 38.245838029044016, 14.405558569090706, 1.056952804327011, 0.030429598409682512, 0.08200686704367399, 0.32454864627548624, 1.3612634922776903, 5.057933781828199, 2.833770683833531, 2.6805029766900197, 0.07679985716406788, 1.6598388765539442, 29.052542720522197, 51.12009266444615, 50.14158133098057, 48.87083223887852, 47.31327887943813, 47.8841289792742, 48.153118065425325, 47.98559352329799, 47.11357375553676, 48.66192422594343, 47.972061906542095, 45.20557062966483, 42.05690063749041, 40.85204826082502, 38.34585387366158, 34.94862249919346, 35.220571517944336, 34.560450962611604, 36.14081873212542, 36.38997071129935, 37.12443004335676, 36.08204392024449, 36.73068257740566, 34.1567189352853, 34.78764663423811, 34.82527807780674, 36.5218961579459, 36.27827841894967, 34.64191859109061, 36.41430330276489, 36.16790281023298, 35.239686012268066, 35.49452856608799, 32.94827781404768, 34.88379233224051, 34.35561806815011, 34.95573398045131, 33.834788049970356, 36.12184320177351, 36.22157417024885, 41.99470383780343, 42.584703172956196, 43.16078874043056, 46.31984281539917, 45.15006494522095, 43.703085218157085, 44.90381383895874, 46.1142213003976, 46.4173538344247, 46.132349150521414, 45.676227705819265, 47.18792642865862, 44.549035344805034, 42.985506534576416, 41.00331054415022, 40.70505217143467, 42.04060711179461, 43.79657323019845, 43.93609305790493, 44.24394341877529, 44.530049392155235, 45.208631311144146, 38.110417638506206, 31.925721849714005, 33.40475014277867, 33.21368857792446, 31.947327273232595, 33.17780113220215, 33.463257449013845, 32.905706201280864, 33.23137869153704, 32.820048809051514, 33.78580672400338, 31.5338226045881, 32.09493827819824, 31.971329825265066, 39.03627552304949, 44.8141508102417, 43.64521714619228, 43.685884952545166, 44.00418540409633, 41.92975902557373, 40.60317420959473, 35.04222168241228, 30.46558918271746, 32.2556813785008, 34.10874857221331, 35.26988288334438, 34.68814148221697, 32.90070002419608, 32.54470559528896, 32.92178780691964, 33.18489524296352, 33.85851614815848, 35.40848207473755, 36.457705225263325, 36.180812563214985, 41.457080023629324, 45.02800246647426, 44.10867241450718, 42.10107381003243, 19.216002293995448, 0.37466429280383245, 0.6953662154929978, 6.889217070170811, 5.02756233726229, 7.067122220993042, 7.245704821177891, 3.5018137054783955, 7.786947778293064, 0.19746272851313862, 0.006778264160467578, 16.59775083405631, 35.25544800077166, 25.92417883872986, 29.41307953425816, 31.387503964560374, 4.769661273275103, 0.1493145078420639, 0.02050014425601278, 0.029348122155559913, 0.052204730321786234, 0.07347295247018337, 0.04533259889909199, 0.06755599818591561, 0.015819948964885304, 0.007813775180173772, 0.03231555935261505, 0.021705044333689978, 0.025355925750253454, 0.02502778621523508, 0.022708841898877705, 0.03995276954291122, 0.05673676749159183, 0.030240405883107866, 0.06736659870616027, 0.013125744249139513, 0.010317312403848129, 0.0373394597720887, 0.07476687803864479, 0.04732999225546207, 0.09668698574283294, 0.037023764569312334, 0.025317756459116936, 0.06404106465301343, 0.017580942417095815, 0.03332719738994326, 0.06290640482412917, 0.008494780066290071, 0.019548029006857957, 0.03682128293439746, 0.020450249879754016, 0.024616761931351254, 0.01856875030456909, 0.04678078940404313, 0.011052368541381188, 0.04391374146299703, 0.034185883456042836, 0.02809930220246315, 0.2660449227052075, 15.729375396456037, 39.508207593645366, 33.68527671269008, 34.60643066678728, 41.84390013558524, 16.929202488490514, 1.9970594899994987, 0.02342154794106526, 0.21066005820674555, 1.2258170459951674, 3.7490725176674977, 8.195114493370056, 6.375680489199502, 5.070399718625205, 0.3211721474570887, 2.4601519320692335, 33.81482240131923, 51.93646430969238, 51.85582004274641, 49.84133577346802, 48.11281851359776, 47.84278719765799, 48.824814319610596, 48.56294018881661, 47.24511705126081, 48.88584382193429, 49.824535029275076, 45.45642491749355, 43.67653962544033, 42.57277659007481, 39.878490992954795, 37.183274337223594, 37.79790503638131, 36.95073202678135, 38.345839977264404, 38.375553948538645, 37.82008021218436, 38.71846144539969, 38.6990099634443, 35.89490113939558, 36.51718875340053, 37.520425251552034, 37.7897686958313, 37.52993386132376, 35.80932365145002, 36.727076462336946, 37.046665804726736, 35.179358278002056, 36.4063024520874, 36.429252352033345, 35.17338630131313, 36.8560836655753, 35.11945785794939, 35.36349943705967, 38.53287158693586, 40.2881498336792, 43.3602055140904, 44.53059829984392, 44.87345368521554, 46.84641899381365, 48.09778956004551, 45.50128248759678, 46.96307577405657, 48.12761122839791, 49.00764226913452, 45.46200432096209, 46.25801427023751, 48.96766928264073, 45.285850116184776, 44.69036865234375, 42.90975727353777, 41.478244236537385, 43.90139028004238, 43.68079539707729, 45.23163332257952, 46.67671619142805, 44.83589519773211, 46.36709751401629, 40.13702998842512, 34.084339550563264, 34.2196626663208, 33.39210442134312, 34.00859028952462, 34.88162449428013, 34.79021399361746, 34.40892464773995, 34.09717634746006, 35.23580544335501, 36.006701128823416, 33.01787097113473, 33.71737044198172, 34.057946818215505, 41.5733129637582, 44.71095963886806, 45.09928750991821, 44.90129164287022, 46.11515235900879, 43.15478549684797, 41.84645012446812, 35.26829521996634, 31.982189859662736, 34.44193206514631, 35.822695459638325, 36.00085769380842, 36.34678765705654, 34.28991937637329, 33.81266845975603, 34.78263350895473, 33.88370336805071, 35.31265599387032, 36.12531035287039, 38.38388136454991, 37.79200948987688, 41.60342993055071, 45.20203399658203, 45.56605706896101, 44.026377950395855, 22.18884638377598, 1.2408323202814375, 2.4474252206938605, 6.736144781112671, 6.685431616646903, 8.884377530642919, 8.22423439366477, 6.193295053073338, 2.7236473815781728, 0.12484858424535819, 0.017183212330564857, 19.26952600479126, 38.909401416778564, 23.40329248564584, 32.40671437127249, 36.39931256430489, 7.0041528684752326, 0.0899494451337627, 0.01261065389761435, 0.05102736010615315, 0.008470720910866345, 0.04062108921685389, 0.02082549501210451, 0.052973944760326824, 0.05229216295161417, 0.03155004971527627, 0.011184374984752918, 0.029318646594349827, 0.01768852923331516, 0.06263321305492095, 0.010025188659450837, 0.055771011992224624, 0.05647165368178061, 0.029824786220810244, 0.048647035512008836, 0.07203291117080621, 0.13059048328016484, 0.10976671174700771, 0.1731660994035857, 0.10908152029982635, 0.10554254627121346, 0.18909688027841703, 0.09594783719096865, 0.15590758834566387, 0.11918258613773755, 0.1545972286590508, 0.13637153378554753, 0.14583371819130012, 0.09260698860245091, 0.16087905157889637, 0.08255884849599429, 0.1693271111164774, 0.20526277353721006, 0.12598610749202116, 0.08926312731845037, 0.10713221811290298, 0.07375746898885284, 0.15969940487827572, 0.4271321216864245, 19.23903557232448, 46.00943204334804, 41.041862624032156, 39.59205845424107, 48.0386951310294, 23.099030869347708, 2.992602595261165, 0.0795502717207585, 0.3156040890940598, 2.038797753197806, 4.469801775046757, 11.737964476857867, 9.506612164633614, 6.719885562147413, 0.20135625744504587, 2.9898656564099446, 32.138124806540354, 52.79315982546125, 51.98559154782976, 50.80650309153965, 50.0108961377825, 49.95521674837385, 50.73919241768973, 50.65244763238089, 49.91231509617397, 51.96578918184553, 51.937940801892964, 48.42368786675589, 46.224371092660085, 44.86885397774832, 42.88113764354161, 39.76171261923653, 40.508605752672466, 38.52627774647304, 40.254704679761616, 40.404709339141846, 40.33219793864659, 40.2928398677281, 40.01615217753819, 36.29744502476284, 38.123570578438894, 38.575724601745605, 40.29180806023734, 38.92993334361485, 37.961903367723735, 38.413491112845286, 39.246972697121755, 37.32644544328962, 39.052110467638286, 38.34060103552682, 37.90616144452776, 38.39328922544207, 37.91265453611101, 36.373503480638774, 42.08158411298479, 41.52630145209176, 46.64117268153599, 45.44537728173392, 45.97042833055769, 47.88244751521519, 49.875805786677766, 47.550935064043315, 48.579862526484895, 51.007250445229666, 50.20701946531023, 46.89857564653669, 46.43678099768502, 50.14089693341936, 47.71891818727766, 46.97500583103725, 46.07850408554077, 44.38608271735055, 45.26551968710763, 46.514520917619976, 48.37017284120832, 47.389507566179546, 46.56510727746146, 48.35408428737095, 41.358439922332764, 35.4016763142177, 36.74297046661377, 35.27308252879551, 34.20328228814261, 36.089349951062886, 36.115065234048025, 36.3784818649292, 36.728278500693186, 37.00506346566336, 37.49827439444405, 35.589670249394004, 35.52164738518851, 35.32749734606062, 41.0253814969744, 47.49211508887154, 46.14733294078282, 45.1543276650565, 48.59464481898716, 45.3796785899571, 44.363914489746094, 38.87726599829537, 33.64630079269409, 35.93937308447701, 37.067048345293315, 39.32286787033081, 37.204490661621094, 35.508362429482595, 35.757806232997346, 37.13751350130354, 35.13891976220267, 36.95100648062569, 39.05698462894985, 40.57946000780378, 39.04792070388794, 44.24498217446463, 47.05311400549752, 47.98876885005406, 45.410208974565776, 22.426530361175537, 0.9340495935508183, 2.9826343187264035, 13.441590683800833, 12.029177376202174, 17.524911505835398, 15.47035002708435, 10.81177828993116, 17.256615502493723, 0.7884050916348184, 0.19902956086610044, 23.608048949922832, 46.69747740881783, 33.782461166381836, 39.34113815852574, 43.27317585263933, 8.065726007734026, 0.374735810394798, 0.14245750435761043, 0.18947745699967655, 0.13021969103387424, 0.19347554817795753, 0.08834268778030362, 0.1239094374967473, 0.09541346372238227, 0.0921908634315644, 0.06477625056036881, 0.1593362393655947, 0.1188395731151104, 0.2360613558973585, 0.0975714289982404, 0.0701318188969578, 0.11560229611183916, 0.13131441229156085, 0.08952709779675518], [0.037708070528294356, 0.05574730058599796, 0.05411988862657121, 0.005986917181871831, 0.041884613023804765, 0.02546451340562531, 0.07007005863956042, 0.002862797131196463, 0.05011279668126788, 0.03734640457800456, 0.00895969444952373, 0.03486983657681516, 0.014536138657214386, 0.015339688664036137, 0.09409333313150064, 0.04702449543401599, 0.007168654618518693, 0.039464522884892564, 0.008500726577559752, 0.041823402379772494, 0.03846258111298084, 0.023248194118163416, 0.03297996727217521, 0.03043228540835636, 2.790910069431577, 21.10474501337324, 29.70000192097255, 25.302421024867467, 35.25131729670933, 23.88429021835327, 3.3645579048565457, 0.04383021040952631, 0.40629148855805397, 1.0577698690550668, 5.310988911560603, 6.827157931668418, 6.837207632405417, 5.501295728342874, 1.0134379736014774, 0.06864774746022054, 9.026079961231776, 42.04116644178118, 50.0269638470241, 50.64203575679234, 48.785171372549875, 49.14486224310738, 48.766022137233186, 46.871307441166465, 45.838145051683696, 46.61263642992292, 46.927733761923655, 46.231506892613, 44.34297956739153, 42.643140997205464, 41.160517011369976, 38.19229173660278, 34.58951875141689, 35.57665279933384, 35.59617028917585, 34.535625049046104, 35.348359312329976, 35.8931119782584, 35.71043341500418, 34.1294333594186, 36.19507721492222, 34.94477319717407, 35.23793854032244, 35.04052284785679, 35.48192800794329, 37.01729576928275, 36.027194840567454, 35.04038388388497, 33.79613869530814, 33.282441002982004, 35.209551674979075, 33.859276975904194, 34.02030495234898, 33.800314562661306, 35.38604981558663, 36.591621330806184, 37.192598819732666, 39.98856088093349, 40.92636966705322, 43.86158405031477, 41.461523396628245, 44.038443497249055, 44.67807381493704, 45.97443396704537, 46.777093342372346, 44.88692971638271, 48.18342958177839, 48.10033260072981, 44.95802021026611, 44.886599676949636, 40.08645405088152, 44.07930237906319, 43.89500835963658, 43.83610848018101, 44.27016939435686, 45.3012056350708, 47.55370044708252, 45.54965237208775, 41.43663147517613, 33.31758499145508, 34.36489391326904, 33.12703759329659, 31.645983900342667, 32.82110493523734, 33.59536007472447, 32.85935476848057, 33.11322110039847, 34.04959160940987, 34.63294151851109, 32.58772536686489, 34.091492721012656, 32.467247077396934, 35.61674043110439, 42.64759826660156, 42.68894004821777, 45.22118670599801, 44.43388979775565, 42.61554970060076, 41.89581707545689, 41.854506560734336, 37.16250964573452, 31.866280010768346, 29.550087588174, 32.314112254551475, 32.17631210599627, 32.20980589730399, 32.991895130702424, 33.3980381829398, 38.86055905478341, 37.9453319140843, 34.92618676594326, 34.98826892035348, 38.1118072782244, 37.3236210005624, 43.34449911117554, 40.70264114652361, 37.04952846254621, 6.063867483820234, 0.10229030078543083, 1.614296908889498, 4.830453668321882, 5.40363358599799, 6.805440468447549, 5.644485507692609, 5.91723313501903, 0.8506932492767061, 0.19123068292226109, 1.650727508323533, 27.77776541028704, 44.76324830736433, 43.20618479592459, 32.01060799189976, 14.728313684463501, 1.719870878117425, 0.09053479015294995, 0.04162202336426292, 0.025436233762385588, 0.05218153799484883, 0.028764124028384686, 0.07211405717368637, 0.04824301201317992, 0.03731654564450894, 0.05273676962990846, 0.0287585939679827, 0.04038204811513424, 0.03191918633612139, 0.04989167908206582, 0.0072493570291304165, 0.008290360365728182, 0.029293432233056853, 0.03679486417344638, 0.06046068641756262, 0.030186903396887437, 0.02144488213317735, 0.025932739887918745, 0.04098376618432147, 0.009392498011168624, 0.032743694593331645, 0.060673169658652375, 0.006121852776102189, 0.043578511237033775, 0.01582316352453615, 0.03565445376027908, 0.040906671035502634, 0.0018441254422733827, 0.02712267487575965, 0.04984709933134062, 0.021484503489253775, 0.052267810329794884, 0.03762752842158079, 0.029001465399882624, 0.017014535310279046, 0.05794952330844743, 0.04001947292791946, 0.03183300221072776, 0.048188698677612204, 4.596212523324149, 30.392570563725062, 33.1520163672311, 28.532258135931833, 44.906398568834575, 27.226594345910208, 4.311584344932011, 0.03075387029509459, 0.38135540804692675, 1.1827692644936698, 4.10297076191221, 7.313718131610325, 8.979572193963186, 4.8707345468657355, 3.0461970908301215, 0.33254024173532215, 11.946305343082972, 44.53818573270525, 51.38626078196934, 51.338481494358604, 50.250188623155864, 48.30644048963274, 48.50094836098807, 49.431586606161936, 48.057583808898926, 47.89252587727138, 47.79623774119786, 47.50711972372872, 45.60693679537092, 43.894449029650005, 41.85066768101284, 39.05505650384085, 36.070819105420796, 36.69004256384713, 36.31773376464844, 36.76619829450335, 36.342042037418906, 37.17368234906878, 36.30313559940883, 36.93035296031407, 38.08134637560163, 35.43307522365025, 37.28637170791626, 36.50864246913365, 36.25326142992292, 37.185053076062886, 36.769564696720664, 35.73943519592285, 36.53174522944859, 34.66697726930891, 35.87238202776228, 35.33617912020002, 35.73554767881121, 36.71795347758702, 37.11714833123343, 37.80125059400286, 39.15020860944475, 41.26123462404524, 42.92568254470825, 43.40732472283499, 43.52605554035732, 44.70620012283325, 47.02748557499477, 46.759316376277376, 48.243819849831716, 45.24115235464913, 48.62579706736973, 49.20792061941964, 47.24789980479649, 44.92249059677124, 42.85253538404192, 44.92200074877058, 45.50855377742222, 45.058171544756206, 46.064777919224326, 48.14951195035662, 48.11564295632498, 47.17677804401943, 42.421882561274934, 34.7001097542899, 35.44190290996006, 34.797478335244314, 33.386080333164756, 34.19207484381539, 35.45058468409947, 33.94572646277291, 35.715401376996724, 35.056166716984336, 35.81773444584438, 33.656625815800254, 35.498819078717915, 34.335509981427876, 36.200962339128765, 42.92895514624459, 47.114345005580354, 45.034005710056846, 44.32594953264509, 44.746360710689, 43.82249695914132, 42.901315212249756, 37.89285911832537, 33.38570860454014, 32.20039456231253, 33.799088205610005, 33.47211292811802, 34.14550454275948, 35.087027141026084, 34.93229423250471, 40.08999068396432, 40.00744261060442, 37.69532183238438, 38.74332904815674, 37.376500265938894, 38.891975334712434, 43.622315883636475, 41.5272707257952, 38.456236430576865, 9.03584999697549, 0.6582201144524983, 3.9519699045589993, 6.476417209420886, 8.946879182543073, 8.702209659985133, 6.900279905114855, 6.052542354379382, 1.0539681187697818, 0.28405592909881044, 1.6977730010237013, 30.23694133758545, 44.123972347804475, 39.49153539112636, 36.29311977113996, 24.3284364427839, 2.4649264301572527, 0.13022866126682076, 0.08126494328358344, 0.034416263058249436, 0.06241275702736207, 0.048445066171033044, 0.10388508199581079, 0.05945428327790328, 0.008296997286379337, 0.0383229861035943, 0.13104544101016863, 0.038975899639938555, 0.007951993611641228, 0.035230454190501144, 0.030858683599425212, 0.05536379259345787, 0.008082346974073775, 0.04053571933348264, 0.012535613861733248, 0.14589950894670828, 0.15236406134707586, 0.18424941253449234, 0.07881268379943711, 0.06513164684708629, 0.071094517596066, 0.2786225735076836, 0.0736192242641534, 0.15547627077570983, 0.1465322428515979, 0.17727590458733694, 0.22108566734407628, 0.11113210062363318, 0.0840182483994535, 0.20503270945378713, 0.11690192137445722, 0.161394113940852, 0.16718652312244686, 0.18275364993938378, 0.10930129100701638, 0.17730664222368173, 0.12017915051962648, 0.11884435000164167, 0.1625649125448295, 4.937065958976746, 36.46324641363961, 42.03030988148281, 34.009608200618196, 44.46248858315604, 34.598311696733745, 7.678163307053702, 0.15647725920592034, 0.9323580328907285, 3.9578854271343777, 12.596695814813886, 16.469012873513357, 12.660036461693899, 10.900045599256243, 3.431895068713597, 0.20668458938598633, 12.69811953817095, 44.1012031010219, 50.9634177344186, 53.33499772208077, 51.7426894732884, 50.35606179918562, 50.62983472006661, 49.86350400107247, 48.57587773459298, 49.50174604143415, 50.081232752118794, 49.0588504927499, 46.664723600660054, 46.25071518761771, 45.18393046515328, 41.35792922973633, 38.28492512021746, 39.63182299477713, 39.253104482378276, 37.85254914419991, 38.58357606615339, 39.47657591956002, 38.754637241363525, 38.13471548897879, 39.02596092224121, 37.10407529558454, 39.37656702314104, 37.661616121019634, 38.11452054977417, 40.429309436253135, 40.720223563058035, 37.68712643214634, 38.00859873635428, 36.05922603607178, 38.246807302747456, 38.159485816955566, 37.82521840504238, 39.2322564125061, 40.045734133039204, 41.39560236249651, 40.70938784735543, 43.417840821402415, 44.0363312448774, 45.62740618841988, 43.998064041137695, 46.38975558962141, 48.694719723292756, 49.33744893755232, 50.3800539289202, 47.67303923198155, 51.34874050957816, 51.61117397035871, 48.78180497033255, 47.72773197719029, 44.44543770381382, 47.558960233415874, 47.10694169998169, 47.667994839804514, 48.81400292260306, 48.65475368499756, 50.00073439734322, 48.24569238935198, 44.31796257836478, 37.211626461574006, 37.350190911974224, 35.67307989937918, 33.5039495740618, 35.76146445955549, 37.898379462105886, 35.72019910812378, 38.12805216653006, 37.022885595049175, 37.536058698381694, 35.44806943620954, 37.088907378060476, 36.68102380207607, 39.97569976534162, 45.77414519446236, 48.5173009463719, 46.37856204169137, 46.650830677577424, 45.182947295052664, 46.08292661394392, 45.51677002225603, 40.87709999084473, 35.311374051230295, 33.1680006980896, 35.82600975036621, 35.898354394095286, 34.80765049798148, 37.178678103855674, 36.49059452329363, 42.09591129847935, 42.31294175556728, 38.39467191696167, 39.79993118558611, 41.76653889247349, 39.766301904405864, 45.78811454772949, 41.9719033241272, 39.51092086519514, 8.18304547241756, 0.5470075192196029, 4.515778873647962, 12.506246771131243, 14.891228096825735, 12.721791182245527, 12.611056872776576, 11.042001639093671, 4.887319028377533, 0.5098829684512955, 2.2682313961642127, 39.45039510726929, 54.10861015319824, 49.04928282329014, 44.39563301631382, 28.205593790326798, 2.3016930520534515, 0.29261928530676024, 0.1187189838715962, 0.057950106848563464, 0.15323148694421562, 0.15192153437861375, 0.1863583265138524, 0.10831451788544655, 0.08582843055150338, 0.09819950136755194, 0.2509515354675906, 0.13092126910175594, 0.1115151879244617, 0.09314012713730335, 0.16713272886616842, 0.17177612041788443, 0.10107012518814631, 0.09491659966962677, 0.09678481013647147], [0.027009590229551707, 0.03199388625632439, 0.04501390117885811, 0.02415358035692147, 0.03477981872856617, 0.009671653255021997, 0.014542406624449151, 0.04044345553432192, 0.011425272727917348, 0.017265296408108304, 0.10764759938631739, 0.012741777397293066, 0.04284105563004102, 0.03732554641153131, 0.020466577128640244, 0.02623779226892761, 0.035231913040791235, 0.04752699811277645, 0.0455389278275626, 0.0654044450659837, 0.048434888145753315, 0.06366690687303032, 0.04329559945368341, 0.02274090946385903, 0.06079852221799748, 9.0535192659923, 32.01931755883353, 25.32773678643363, 30.470974036625453, 34.91605281829834, 10.12039257798876, 0.43530396318861414, 0.4507529299174036, 0.4041684881917068, 3.5624154593263353, 5.969562189919608, 7.1854157362665445, 2.5315327303750172, 2.516153109925134, 0.09116711693682841, 0.6864482568843024, 21.43096467426845, 49.03109243937901, 48.67775222233364, 49.90379313060215, 47.67511326926095, 50.963970116206575, 48.58946146283831, 48.22227348600115, 48.04613665172032, 47.348346437726704, 46.850351674216135, 45.56308323996407, 43.2668981552124, 42.242824009486604, 38.25509302956717, 38.08959041322981, 36.44682087217058, 34.26257126671927, 35.02636241912842, 34.12530265535627, 35.625672340393066, 35.08159017562866, 36.79558917454311, 35.21926178250994, 35.3642463684082, 35.2785507610866, 34.980240276881624, 35.75928272519793, 35.933647768838064, 33.40068544660296, 33.308295249938965, 34.57186337879726, 34.39432648250035, 33.927004541669575, 33.71617187772478, 34.52731500353132, 34.66553551810128, 34.70010280609131, 35.982441493443076, 38.3189435005188, 38.627610274723594, 40.194762570517405, 39.926520415714805, 43.80361870356968, 42.00943749291556, 44.58485678264073, 45.40961837768555, 46.10521296092442, 44.7880985396249, 44.86017220360892, 47.026818547930034, 48.255781173706055, 47.2026218686785, 43.497255257197786, 43.63233518600464, 44.66850961957659, 43.978727204459055, 45.6914199420384, 45.51840284892491, 46.82998997824532, 45.824474470955984, 43.60548039845058, 36.482145513807026, 31.89016444342477, 32.79925285066877, 32.21224124091012, 34.28516680853707, 32.30145263671875, 33.571096965244834, 36.567115034375874, 38.42898906980242, 38.321760995047434, 33.46640150887625, 34.224175521305625, 32.344041619982036, 33.765719481876914, 37.36974661690848, 43.25116048540388, 43.61217846189226, 44.41893032618931, 43.449413435799734, 44.51483283724104, 42.617929458618164, 41.769894872392925, 39.322200843266074, 35.66093097414289, 31.747184412819998, 30.749464784349712, 30.070816857474192, 32.98134776524135, 38.20883887154715, 41.42052207674299, 38.39344208581107, 36.71928058351789, 38.84953573771885, 39.66122777121407, 39.86951044627598, 40.44335521970476, 43.03800712312971, 22.713190453393118, 1.5302497616836002, 1.368406891822815, 2.6055440732410977, 4.296977494444166, 5.655560501984187, 8.478337832859584, 5.341758574758257, 4.687795860426767, 0.2644579921449934, 0.1692868061363697, 4.547487846442631, 34.29801402773176, 32.56748526436942, 25.231224570955547, 27.10428520611354, 4.787798677171979, 0.22753839966441902, 0.03156011578227792, 0.03949650902567165, 0.004511285024429006, 0.030537563509174755, 0.07836009415664844, 0.045161563969616375, 0.013856194830233497, 0.09217126734022583, 0.020001806085929275, 0.05208180691780789, 0.037934524805418084, 0.02881279195259724, 0.026945014051826935, 0.05255780941141503, 0.022115702208663737, 0.09814020419227225, 0.027674697040181075, 0.07142484201384441, 0.04867186310834118, 0.014224384046558822, 0.040226599135036976, 0.054651273148400445, 0.03745182177850178, 0.03644592075475624, 0.05143422666671021, 0.014100190085758055, 0.0423740267620555, 0.06512314480330263, 0.0414466254546174, 0.009084309950204832, 0.028974992356130054, 0.028480757626571825, 0.056530146793063195, 0.03925792593508959, 0.05302153042118464, 0.014420609588601759, 0.05885937770030328, 0.03084615445030587, 0.015222770294972827, 0.08700625199292387, 0.05138844930167709, 0.0600834209471941, 0.2642195549394403, 14.088940450123378, 37.21697310038975, 26.572480508259364, 35.130383900233674, 39.36136089052473, 11.949136734008789, 0.4717134194714682, 0.34508171305060387, 0.2629448047706059, 2.9247955594744, 6.559557182448251, 8.720020498548235, 9.49560969216483, 4.80883434840611, 0.6449171911392892, 1.9197494898523604, 23.862254006522043, 49.412315777369905, 50.1768399647304, 51.04493052618844, 49.08278703689575, 51.30385167258126, 50.861831596919465, 47.604245117732454, 49.59841285433088, 48.465950284685405, 49.71327699933733, 45.61222784859793, 44.627285957336426, 43.04463223048619, 38.9333553314209, 39.01409339904785, 37.26046187537057, 36.30651937212263, 37.83491114207676, 35.86230713980538, 38.38943297522408, 37.85874693734305, 38.41643020084926, 37.19386339187622, 37.5255252293178, 37.707793848855154, 37.904938561575754, 37.71878937312535, 37.04517889022827, 36.21574810573033, 35.38974278313773, 35.328650747026714, 35.57435989379883, 35.41129609516689, 34.27326454435076, 35.9891117640904, 35.69899320602417, 36.27230644226074, 36.84460176740374, 39.47712482724871, 39.76952586855207, 42.51177488054548, 42.85289321626936, 44.69883503232683, 44.48023080825806, 45.166045801980154, 46.65348488943917, 48.94989231654576, 45.70947136197771, 46.0003160067967, 48.11643852506365, 47.92712095805577, 48.502146925245015, 45.50002833775112, 45.0949136189052, 46.74034432002476, 46.500259740012034, 47.201075894492014, 46.114318575177876, 47.04758671351841, 48.82252836227417, 43.994291169302805, 37.47269112723214, 32.42443227767944, 34.23753343309675, 33.806943144117085, 35.97141122817993, 32.66478436333792, 34.5250220979963, 37.29535225459507, 39.75858245577131, 38.80150978905814, 35.38638680321829, 34.91512523378645, 34.22952216012137, 35.014480999537874, 39.85871989386422, 45.46435628618513, 43.82816668919155, 44.84217289515904, 45.63084554672241, 45.047304562159944, 44.38970620291573, 43.819158349718364, 41.28211048671177, 35.682129928043906, 32.2072628566197, 32.672385692596436, 30.670581885746547, 34.83231312888009, 39.78144550323486, 43.69305549349104, 38.71065167018345, 37.64290114811489, 39.94246653148106, 41.43368543897356, 41.703959941864014, 43.42105783735003, 43.07781335285732, 25.137830359595164, 2.5000278609139577, 1.8778707427637917, 2.8923869899341037, 5.512379842145102, 6.863886543682643, 9.364034261022296, 7.7449893440519055, 3.9027041367122104, 0.19145777502230235, 0.17637120027627262, 5.536850963320051, 38.419810499463765, 40.86404779979161, 30.791251250675746, 36.03683546611241, 8.742019363812037, 0.39681680553725784, 0.052443140385938544, 0.06821605669600622, 0.08169452380388975, 0.07184792895402227, 0.04447713926700609, 0.008077039982059171, 0.029236469218241315, 0.05914846754499844, 0.01326935873034277, 0.031731160889778814, 0.025671817728185227, 0.034266775008291006, 0.02260839836006718, 0.019857817562296987, 0.02464859540175114, 0.10681300131337983, 0.04921415847327028, 0.04085813542561872, 0.11464740735079561, 0.10209381740008082, 0.14494737503784044, 0.09958036762795278, 0.17422206274100713, 0.15320448125047342, 0.16431060672870704, 0.1033443845808506, 0.12481925796185221, 0.14776888649378503, 0.37779421199645313, 0.10945482991103615, 0.0957998622741018, 0.1838450056633779, 0.17674807219633035, 0.08951163398368017, 0.10167176183313131, 0.09580335672944784, 0.16545011129762444, 0.12675491480955056, 0.1695805982287441, 0.16830848077578203, 0.11373373959213495, 0.17777230723627976, 0.24770162414227212, 15.709390640258789, 44.45894847597395, 33.95505789348057, 39.642467635018484, 44.47267116819109, 18.823370013918193, 0.9687266413654599, 1.4099642847265517, 3.4051911873476843, 8.35402066367013, 15.399652106421334, 13.354493277413503, 10.968864032200404, 6.901230071272169, 0.34608860473547665, 1.687981903553009, 24.9900404385158, 51.863876479012625, 52.037060328892295, 52.95601865223476, 49.06615999766758, 54.49449920654297, 52.418912478855674, 51.31708799089704, 52.213822501046316, 50.6167026247297, 51.3551641191755, 48.75066314424787, 45.94204493931362, 45.8747273172651, 40.64693743841988, 43.1818904195513, 38.367191791534424, 36.59300054822649, 39.780813217163086, 36.49153253010341, 40.47797809328352, 39.39910697937012, 40.66531194959368, 39.41614396231515, 38.851262365068706, 39.510761056627544, 38.559250422886436, 40.21599626541138, 38.86908796855381, 37.77342653274536, 36.899277142116, 39.723598275865825, 37.37865768160139, 37.2951021194458, 36.37865209579468, 38.66692665645054, 37.83539751597813, 38.436392375401084, 39.12406601224627, 43.29616396767752, 42.03688982554844, 44.83507531029837, 43.867319788251606, 47.8836738722665, 45.648143087114605, 48.10390050070626, 48.29640729086739, 49.42611837387085, 46.89855132784162, 47.011091300419395, 50.07018859045846, 52.771759373801096, 51.271476541246685, 48.17967408043997, 46.624163491385325, 48.27663966587612, 47.66973883765084, 50.38099888392857, 47.75428799220494, 49.098027910505024, 50.39992230279105, 45.638144629342214, 39.99626643317086, 34.833546434129985, 35.76282630647932, 36.47542313167027, 38.649573530469624, 34.75035565240042, 35.90207862854004, 39.69553450175694, 41.49181406838553, 42.38664477212088, 36.892071860177175, 38.146166120256694, 35.13985429491316, 34.93911736352103, 40.310734953199116, 46.235040051596506, 45.35625621250698, 45.83205148151943, 45.93485355377197, 47.66287749154227, 47.00477538790022, 44.457357338496614, 44.34943791798183, 39.1345716885158, 34.116009439740864, 35.322647503444124, 32.9185916355678, 36.61373049872262, 41.78009482792446, 44.589418275015696, 40.943573406764436, 40.78667960848127, 41.90079893384661, 44.33490228652954, 42.93165799549648, 43.88889047077724, 44.64924226488386, 25.813942193984985, 2.677935400179454, 3.688953229359218, 8.00707539490291, 12.133825932230268, 12.176452262060982, 17.21609708241054, 15.01380821636745, 13.083503978593008, 1.2170800119638443, 0.36030782173786846, 8.187141435486929, 43.141351154872346, 40.56208256312779, 35.51782587596348, 43.920706272125244, 11.387869937079293, 0.5261439787490028, 0.14747860921280725, 0.12083559243806771, 0.2827569959419114, 0.16693284602037498, 0.18130049934344633, 0.10198472253978252, 0.1614336861031396, 0.14870537338512285, 0.08130815239357096, 0.14791728210236343, 0.10647733003965446, 0.10588259409580912, 0.12429574105356421, 0.17946994757013662, 0.11977413296699524, 0.31419591179915835, 0.12990090171141283, 0.2688668684235641], [0.018154231565339223, 0.06727899983525276, 0.0637999065220356, 0.02945782769737499, 0.03870717941650322, 0.04426374339631625, 0.037132866214960814, 0.035449237629239044, 0.01804850054239588, 0.021937240713409016, 0.03844098334333726, 0.03009834439892854, 0.01769103472387152, 0.006110083162119346, 0.03190101856099708, 0.028483166425888027, 0.07457918846713645, 0.02329663303680718, 0.023809639437656318, 0.01833932743673878, 0.029072399450732127, 0.04078517594773855, 0.043031052220612764, 0.048451349405305724, 0.05283087565164481, 0.5943947221551622, 20.48595060620989, 35.600426060812815, 25.674248661313737, 36.08083840778896, 22.011392865862163, 0.6532464527658054, 0.020434195741212795, 0.5935331455298832, 0.8745097198656627, 2.691751024552754, 8.41075096811567, 6.166837615626199, 14.797085217067174, 2.6095117117677415, 0.24843612472925866, 6.802408014025007, 34.59240920203072, 48.72745616095406, 50.09450033732823, 49.3927982875279, 50.00443083899361, 48.22844696044922, 45.81658131735665, 46.80509458269392, 47.436713627406526, 47.32747752325875, 46.76101868493216, 46.731940473829, 47.02866676875523, 40.4911345073155, 37.79741171428135, 34.616679259708945, 34.26619822638375, 34.510879039764404, 34.2484073638916, 36.81052432741438, 36.48198223114014, 35.36314160483224, 35.37740625653948, 35.963882855006624, 36.85843563079834, 35.964973722185405, 35.8783609526498, 35.15902784892491, 35.79500341415405, 35.07298830577305, 34.4524690083095, 35.573216915130615, 35.07085868290493, 34.06420019694737, 34.585561752319336, 34.256640979221885, 36.6103640965053, 37.740002223423545, 39.89969342095511, 39.67098651613508, 41.73715148653303, 43.06922885349819, 42.435646942683626, 42.05516358784267, 45.01503017970494, 46.181243624006, 48.11065067563738, 42.819732938494, 43.79060125350952, 46.6997320992606, 47.784109660557334, 46.29054921013968, 45.120983260018484, 44.622766154153005, 45.617230551583425, 44.807046277182444, 44.942286014556885, 46.43609312602452, 46.32151733125959, 45.81206151417324, 45.311131136757986, 40.897447790418354, 33.314520835876465, 33.23502649579729, 33.12901782989502, 33.742828641619, 32.80510670798165, 33.90605572291783, 39.360207489558626, 41.42338820866176, 39.34419536590576, 36.92842483520508, 33.185326031276155, 32.211907727377756, 33.06189475740705, 33.55371952056885, 37.678965772901265, 42.3043919972011, 42.506324018750874, 44.7621921811785, 42.51249054500035, 42.29518910816738, 44.59006445748465, 42.430915219443186, 42.54519918986729, 37.63109615870884, 30.87561627796718, 30.12126772744315, 35.12092740195138, 39.01434700829642, 41.14195489883423, 36.9513122013637, 38.695921489170615, 42.50306183951241, 38.4960287639073, 42.42778853007725, 41.2067676952907, 39.31737879344395, 10.739790609904698, 0.5952874028256961, 1.832933485507965, 2.1553001531532834, 4.130923799106053, 8.068326371056692, 6.528785347938538, 4.783158149038043, 3.1478257860456194, 0.11179900555206196, 0.08415718522987195, 19.427781649998256, 36.333843163081575, 24.15361281803676, 29.985399178096227, 15.472592558179583, 1.3712627100093024, 0.06681132635899953, 0.06124581250229052, 0.019785229582339525, 0.03294257999264768, 0.0539791740344039, 0.016394435727436627, 0.07441653005246605, 0.02581604034639895, 0.05368940904736519, 0.04944580015061157, 0.05588427305753742, 0.027467513157586967, 0.07032341683017355, 0.03595284292740481, 0.03303666226565838, 0.020957259727375846, 0.016144582170194814, 0.08821677882224321, 0.019792379645098532, 0.06821934080549649, 0.05777132644184998, 0.016617831507963792, 0.03103396276544247, 0.03053737012669444, 0.03739003777237875, 0.032074971191052876, 0.03213951004935162, 0.07689183258584567, 0.05251499045906322, 0.03388716519943305, 0.057439115696719716, 0.026547797955572605, 0.05753719114831515, 0.022926320854042257, 0.02247004846243986, 0.015731018469003693, 0.023582632154492394, 0.07383030972310475, 0.05351800431630441, 0.0036378984971504125, 0.024578175341178263, 0.02216063649393618, 0.035069593893630166, 0.036353280368660174, 1.916812138898032, 28.06434212412153, 37.047419684273855, 28.850421360560826, 44.795401096343994, 23.510277373450144, 0.9929379650524685, 0.16274065311465943, 0.7863980393324579, 1.4752370736428668, 7.794149586132594, 7.514954464776175, 10.060761400631495, 17.202518565314158, 1.416466930082866, 0.6922864264675549, 7.90426116330283, 37.84569822038923, 49.579079491751536, 52.040534428187776, 49.59131179537092, 51.53850276129586, 47.68195377077375, 47.885188579559326, 47.07723815100533, 49.5648877961295, 48.39737156459263, 48.485165527888704, 47.84510094778878, 47.953694343566895, 41.09101070676531, 40.86296388081142, 36.92450605119978, 36.8736070224217, 36.02489846093314, 35.93328646251133, 38.01398011616298, 37.01850822993687, 36.64691856929234, 38.117431844983784, 37.79928077970232, 37.81934370313372, 37.0624486378261, 37.84301968983242, 36.3105354309082, 37.47821841921125, 36.28150585719517, 36.088988644736155, 36.65545095716204, 35.81849179949079, 35.21164655685425, 35.748860427311485, 35.16465936388288, 38.68591260910034, 38.45623990467617, 41.4058335849217, 41.37321179253714, 43.506517205919536, 42.65828807013375, 43.428884983062744, 43.631584780556814, 46.129573345184326, 47.02161087308611, 48.0077235358102, 44.399888787950786, 44.52803441456386, 49.147488662174766, 49.795328276497976, 47.479948793138774, 46.17717545373099, 45.526883125305176, 46.72365127290998, 46.26815169198172, 46.309375354221885, 49.58398839405605, 46.49833856310163, 46.29697629383632, 47.032985074179514, 40.17042997905186, 34.60732351030622, 34.756556919642854, 35.23096602303641, 34.57900265284947, 35.13857930047171, 36.129652976989746, 41.31817511149815, 42.16844701766968, 41.500582695007324, 39.48954125813076, 35.78877782821655, 34.543987206050325, 33.87827335085188, 34.483291217258994, 40.36501775469099, 45.34453807558332, 44.92054510116577, 45.66270303726196, 43.714198861803325, 44.2425468308585, 44.53912026541573, 43.39429685047695, 44.35173429761614, 38.63186604636056, 32.44512401308332, 31.107578413827078, 35.901508876255576, 40.89517225537981, 42.154088565281455, 38.52586432865688, 40.80029807771955, 43.00633723395211, 40.94599832807268, 44.000290938786094, 42.30622284752982, 40.76927784511021, 13.073932835033961, 1.3147970885038376, 4.081537740571158, 3.6368421741894315, 4.598639615944453, 5.542870708874293, 7.880414077213832, 5.637861268860953, 1.8927097065108163, 0.1453354020736047, 0.039737748580851724, 18.506889990397863, 41.241098744528635, 25.688092947006226, 34.21481282370431, 24.078433309282573, 3.67698278597423, 0.027324384677090814, 0.055693862560604296, 0.05986201497060912, 0.024727800794477974, 0.05950268318078347, 0.03376717306673527, 0.08895606986646142, 0.026686962095222304, 0.06874303413288933, 0.053265670713569434, 0.061507394537329674, 0.03774763251255665, 0.0387666835449636, 0.028764456510543823, 0.029255949958626713, 0.014238808004717742, 0.01877692315195288, 0.035781991202384233, 0.016305947975654687, 0.10501421176429306, 0.17041117937437125, 0.1485768181404897, 0.12946638145617076, 0.17282643834395067, 0.13760158206735337, 0.12538464048079082, 0.1274162693215268, 0.15484291261860303, 0.10804189608565398, 0.12600540502795152, 0.19947645760008267, 0.0632405426087124, 0.1696016870971237, 0.11204184644988605, 0.08506186239953552, 0.11496751303119318, 0.1137034430035523, 0.13017545055065835, 0.12207470594772271, 0.12821261159011296, 0.10228255191551787, 0.09504789619573525, 0.10302114406866686, 0.12285146569567067, 1.615980109998158, 31.45922327041626, 46.47507946831839, 35.50101123537336, 45.587422779628206, 32.508891105651855, 1.952301800251007, 0.4000384083815983, 2.703488051891327, 5.03570910011019, 13.898842079298836, 15.335056441170828, 15.242508172988892, 29.093964406422206, 4.573480623109, 0.4189218208193779, 9.088899493217468, 38.45252261843, 49.80525030408587, 52.443609850747244, 51.04831429890224, 52.39321804046631, 48.75652394975935, 48.38866547175816, 47.91459335599627, 51.88353293282645, 49.93451459067208, 50.20641149793352, 50.267743246895925, 50.90897512435913, 44.62955454417637, 42.5895425932748, 38.585132462637766, 38.443222454616, 37.51207004274641, 38.28229175295149, 40.50548601150513, 38.836024965558735, 38.92208535330636, 39.04303959437779, 40.67600522722517, 39.73513228552682, 38.92752579280308, 39.65363686425345, 39.00461605616978, 39.498903955732075, 39.839157240731375, 37.91832079206194, 38.05064576012747, 38.57892424719674, 37.35269226346697, 37.55874456678118, 37.00678314481463, 40.82991130011422, 41.59338630948748, 43.317474092756, 43.993707520621165, 44.999421051570344, 44.82247822625296, 45.723152365003315, 45.6072564125061, 48.68048981257847, 49.666314125061035, 49.4771911076137, 45.47243356704712, 45.70575754983084, 50.57636138371059, 50.428854601723806, 48.08321571350098, 48.90695939745222, 47.40478318078177, 48.987638405391145, 49.825664111546104, 49.761104924338206, 49.434782777513774, 48.49211720057896, 48.74801935468401, 48.362019130161826, 42.41491004398891, 37.733186040605815, 37.420364243643625, 36.8076616695949, 36.60262380327497, 37.11253472736904, 36.96786628450666, 43.62342412131173, 44.29190335954939, 43.543766498565674, 41.58461420876639, 38.06990269252232, 36.88971989495413, 36.29422800881522, 35.58062022072928, 41.31406872613089, 47.69084399087088, 46.637986932482036, 48.27420432226998, 44.82775885718209, 44.00646441323416, 46.45533963612148, 44.69587857382638, 46.87573691776821, 41.04820285524641, 34.63988971710205, 33.08167627879551, 38.69753694534302, 43.06395864486694, 44.04051406042916, 40.166059562138145, 41.15108483178275, 45.57272733960833, 42.620090348379954, 46.728567123413086, 45.16745628629412, 42.16160651615688, 12.931132589067731, 1.7692203500441142, 6.292335978576115, 7.142362526484898, 11.533958418028694, 15.546795845031738, 14.877310855048043, 12.25502336025238, 8.05964025429317, 0.3345852105745247, 0.2765862356339182, 27.532085793358938, 45.30317197527204, 32.059971468789236, 43.21026686259678, 30.43317583629063, 4.49097033057894, 0.15105606296232768, 0.17905567479985102, 0.14512606044965132, 0.12850563015256608, 0.1150640957057476, 0.14623538378093923, 0.17238401994109154, 0.15116367861628532, 0.17818789636450155, 0.14570091531745025, 0.15391405246087483, 0.13859186321496964, 0.11232833750545979, 0.10528481831508023, 0.09311954038483755, 0.1848529830042805, 0.119764009224517, 0.15483688722763742, 0.08198838374976601], [0.01233387946350766, 0.06528860556760005, 0.03552348632365465, 0.04556507517450622, 0.0029798787727486342, 0.027113652056349174, 0.04332129557483962, 0.03628748622057693, 0.039755953675402064, 0.026143131544813514, 0.008576547776881074, 0.052060344855168035, 0.057449083376143656, 0.06568019491221223, 0.043438855159495554, 0.05436705179246409, 0.029687328596732447, 0.04254903790674039, 0.024140679709879414, 0.02555436670913228, 0.009515192409578179, 0.028804646139698367, 0.03655701390068446, 0.04007641558668443, 0.027172706655359695, 0.019175323291814754, 4.473064822810037, 32.46759101322719, 24.658587047031947, 25.493055275508336, 37.67342111042568, 4.370227575302124, 0.1907338731523071, 0.08810933280204024, 0.7493630009038108, 4.808754009859903, 6.2857569030353, 11.251332623617989, 12.987604073115758, 1.909103546823774, 0.7104875583733831, 0.4974435759442193, 16.071007898875646, 44.481412002018516, 49.465049130576, 49.88240310123989, 48.54355818884713, 48.79970700400216, 47.17539535249983, 46.70683315822056, 45.90188782555716, 46.59479693004063, 47.20042276382446, 47.28795616967337, 44.845264843532014, 43.44556065968105, 36.220806394304546, 35.74399321419852, 35.14893906457083, 38.67781448364258, 41.47517313276018, 43.83144276482718, 41.481742654527935, 38.944138935634065, 35.71817718233381, 35.04762738091605, 36.18208408355713, 36.54293530327933, 34.10231106621878, 35.32187277930123, 36.672630378178184, 35.56969765254429, 34.778450693402974, 36.1483644757952, 36.30927433286394, 34.19024051938738, 35.091685908181326, 36.07002701078142, 38.07696206229073, 37.664183480399, 41.393170492989675, 41.94581283841814, 42.8793762751988, 43.73217037745884, 44.47540875843593, 44.83923033305577, 45.92772470201765, 46.80360071999686, 46.40464905330113, 43.03850391932896, 46.201980522700715, 49.318862506321494, 46.68831968307495, 45.540095124925884, 46.07061093194144, 44.83315413338797, 43.72501720700945, 47.205432415008545, 45.30990825380598, 46.200302532741, 45.22131177357265, 47.16131830215454, 44.24630928039551, 40.77463838032314, 36.04257467814854, 31.703935350690568, 33.25302233014788, 34.82455199105399, 31.95540107999529, 35.126159395490376, 40.36287770952497, 41.58423900604248, 42.504652976989746, 40.46816028867449, 36.75188500540597, 35.60334777832031, 31.92355748585292, 33.66990382330758, 33.916471072605674, 39.87447146006993, 41.19873905181885, 43.000639711107524, 44.58478382655552, 41.574518476213726, 43.200511591775076, 44.329142229897634, 43.96921859468733, 41.85328367778233, 37.684315885816304, 30.798932484218053, 34.49815688814436, 40.99157851082938, 42.18463979448591, 41.281172479902, 36.91039078576224, 43.44899654388428, 42.04506785529, 41.93666900907244, 42.94527646473476, 30.866517611912318, 3.8555645176342557, 0.6203116114650453, 3.6011516664709364, 1.3151231110095978, 1.900499505656106, 3.382676418338503, 5.696398104940142, 5.1314339978354315, 0.6715690152985709, 0.030613084456750324, 2.02089506813458, 31.40503774370466, 32.94302150181362, 26.355972903115408, 24.79893892151969, 4.633292019367218, 0.8279700343097959, 0.053869916325701137, 0.07907186382051025, 0.026289930899760554, 0.0569494916126132, 0.010399672136242901, 0.03935090898137007, 0.023225797373535376, 0.02606940532236227, 0.06839397536324603, 0.06555754292224135, 0.01292343479248562, 0.042930890273834975, 0.060283995898706574, 0.10092997378004448, 0.036677810097379346, 0.03479378976460014, 0.07332394618008818, 0.043628278387976546, 0.05533760792708822, 0.0775130856782198, 0.031216285124953305, 0.04800035431981087, 0.07726396833147321, 0.04574141624782767, 0.02713075453149421, 0.014789432387000747, 0.08170702920428344, 0.07546437132571425, 0.07003012685371296, 0.027971812257809297, 0.02599542634561658, 0.04635842849633523, 0.10078269096889667, 0.014602207611980183, 0.03147792822814413, 0.04472414297716958, 0.039042185725910325, 0.01805712641882045, 0.0428346909715661, 0.02445131304141666, 0.029331012895064693, 0.047229711565056016, 0.024819436948746443, 0.021093250019475818, 0.03353669846962605, 8.02967267377036, 39.036143507276265, 24.361238888331822, 33.75218439102173, 44.14846127373831, 4.465113478047507, 0.19091926249010222, 0.03435938825298633, 0.8209418228694371, 4.1006839360509595, 6.5309666480336865, 8.866775138037545, 14.177081823348999, 9.19638899394444, 2.3808071953909735, 1.0314277282782962, 19.7977089541299, 44.200319153921946, 51.05424806049892, 49.5271486554827, 50.27822807856968, 48.613127027239116, 48.33832924706595, 46.520155906677246, 48.236513819013325, 49.84592505863735, 48.97630589348929, 49.26293298176357, 47.373950549534385, 45.52742855889456, 38.99181400026594, 38.331280027117046, 36.894385610307964, 39.05690472466605, 43.95183072771345, 45.0592485155378, 41.936133997780935, 40.19995982306344, 36.74375213895525, 37.33311223983765, 37.80432864597866, 36.85987738200596, 36.98615394319807, 37.02650908061436, 38.119790758405415, 36.65306077684675, 36.674405642918174, 38.67187377384731, 36.821610178266255, 35.690481662750244, 34.884105001177105, 36.345061029706685, 40.525010449545725, 39.829047611781526, 42.65078054155622, 42.82588904244559, 44.73942640849522, 45.153594630105154, 44.99109363555908, 47.0070926121303, 48.61727510179792, 48.998675618852886, 49.09362275259835, 45.26186840874808, 47.03140435900007, 49.96515614645821, 47.18724203109741, 48.487156186785015, 46.45521109444754, 46.63558285576956, 45.45999281747, 47.37856067929949, 46.020632539476665, 47.19075434548514, 45.84315817696707, 47.48153645651681, 47.01497881753104, 42.063699449811665, 36.97969559260777, 33.215991905757356, 34.67873362132481, 35.83019951411656, 33.710231167929514, 36.99033328465053, 42.28509684971401, 42.82016372680664, 43.389054434640066, 41.28265939440046, 38.3825021471296, 36.605781759534565, 32.994142872946604, 35.42806557246617, 36.20383194514683, 42.55066742215838, 43.65954433168684, 44.86319466999599, 45.40182249886649, 42.210521834237234, 44.02576303482056, 45.25092499596732, 45.5244790485927, 43.42911079951695, 38.0828298160008, 32.21682357788086, 36.83788285936628, 42.630602972848074, 44.43007871082851, 42.61754730769566, 38.14551646368844, 43.176449980054585, 43.07911614009312, 42.782598291124614, 44.4064895766122, 31.944982256208146, 5.985549560614994, 0.6437226980924606, 5.1463296328272135, 4.629232968602862, 5.337830236979893, 6.6840198295457025, 7.694837246622358, 2.2944065630435944, 0.7006731192980493, 0.10580033529549837, 1.6144859216042926, 35.49099540710449, 38.07053845269339, 29.261202335357666, 33.11291190556118, 9.364639622824532, 1.2089484483003616, 0.10506929523710694, 0.04252375569194555, 0.025248851227973188, 0.0195425617109452, 0.03264649445191026, 0.027860963384487798, 0.08177400061062404, 0.05602477051849876, 0.06855084587420736, 0.032889538910239935, 0.02645963420426207, 0.033902218498821766, 0.0423209619309221, 0.005591605224513582, 0.040234999398567846, 0.011341063987596758, 0.048396014874534946, 0.007061835395039192, 0.047336865815200975, 0.17449815864009516, 0.263159520391907, 0.07800677418708801, 0.1273924256009715, 0.2035330927797726, 0.13239708276731627, 0.1764925630497081, 0.17857726689960274, 0.14178443833121232, 0.0797955214178988, 0.10087499887283359, 0.13628275426370756, 0.17057815327176026, 0.1648250448384455, 0.13105015004319803, 0.12592236591236933, 0.1270484762000186, 0.1973447719854968, 0.14402874718819345, 0.09553756777729307, 0.1094507315595235, 0.09816092665174178, 0.14960363161350998, 0.19590561278164387, 0.1493561834629093, 0.08099103226725544, 9.11486143725259, 44.830868176051546, 33.773473671504426, 34.02404308319092, 50.95727552686419, 8.515042560441152, 0.3191557042300701, 0.31332657273326603, 2.7736222999436513, 10.12364433492933, 14.765043599264962, 20.919351441519602, 20.59747440474374, 7.865644812583923, 1.5281835411276137, 1.1665066799947192, 18.342502559934342, 46.602356570107595, 50.73969963618687, 52.213864190237864, 50.94445262636457, 49.03186021532331, 50.053422587258474, 48.938820362091064, 48.764941692352295, 52.60207394191197, 50.95368678229195, 51.497821058545796, 48.06684923171997, 47.38944503239223, 40.77521160670689, 40.07077891486031, 38.66014868872506, 42.67232690538679, 46.30263212748936, 48.696307386670796, 44.51945686340332, 42.61601870400565, 38.769617557525635, 39.20775359017508, 40.43305104119437, 38.65452412196568, 37.98571137019566, 39.464051791599815, 40.09129694529942, 38.841507094247, 37.65681144169399, 40.88053934914725, 39.82967642375401, 38.15217978613717, 36.87761960710798, 40.047551086970735, 43.49912084851946, 42.13073219571795, 46.251031330653596, 44.72567592348371, 47.544323853084016, 47.992771012442454, 47.96196617398943, 49.77981642314366, 49.80316237040928, 50.66940123694283, 51.10676949364798, 47.17870269502912, 48.77831697463989, 51.8184700012207, 49.00096157618931, 50.11479255131313, 49.04430791309902, 48.0896566935948, 47.185324328286306, 49.5445955821446, 49.19072730200631, 49.16303178242275, 47.53648281097412, 50.20815202168056, 48.17378895623343, 42.55085154942104, 39.27556800842285, 34.950237955365864, 36.2877105985369, 38.99438830784389, 34.68503563744681, 38.899830273219514, 45.47288867405483, 44.254813875470845, 45.594541209084646, 43.294357436043875, 40.54952369417463, 39.608595166887554, 34.65855952671596, 36.911040442330496, 37.9560877255031, 44.05628647123064, 44.46872459139143, 45.99313851765224, 46.4282659803118, 43.55721126283918, 44.66165174756731, 46.27636098861694, 48.31768962315151, 45.391393252781455, 41.22843565259661, 33.72904688971383, 38.5063989503043, 45.12274462836129, 45.484047480991904, 44.14591128485543, 40.73053816386631, 45.199883529118125, 45.2675416128976, 44.188423837934224, 45.8976320539202, 31.564630917140416, 6.185299847807203, 1.1641965125288283, 9.81353407246726, 8.408038565090724, 6.554214017731803, 11.039391721997942, 14.956911155155726, 10.554548161370413, 3.0516892075538635, 0.5484517674360956, 3.57914867571422, 41.90372065135411, 42.54752336229597, 36.45807695388794, 40.66792447226388, 12.407763004302979, 1.3355181366205215, 0.19823625843439782, 0.24216580976332935, 0.1122196361954723, 0.10652260189609868, 0.11240617904279913, 0.17531678399869374, 0.26455116857375416, 0.12928650182272705, 0.20313134576593125, 0.09864776874227182, 0.15565957022564753, 0.10911199330751385, 0.24544416527662957, 0.18792215974203177, 0.08433159587106534, 0.10598472718681608, 0.12574684247374535, 0.10986419687313692, 0.1181855739227363], [0.011590742822071272, 0.03284026708986078, 0.048571344930678606, 0.043389169432755025, 0.047331719127084525, 0.03080669424629637, 0.07649864868393966, 0.022267168188201528, 0.032911126501858234, 0.10337431476052318, 0.03506991280508893, 0.04128096791516457, 0.06292933930775949, 0.033998601005545685, 0.023367767255487185, 0.03785916331357189, 0.01630888942496053, 0.02603872027248144, 0.006580378752135272, 0.03530324064195156, 0.06534263731113502, 0.012432122852520218, 0.048058905106570037, 0.06943551304617099, 0.025998874999848858, 0.037682951161903996, 0.036056400941950936, 17.423113448279246, 37.252401965005056, 20.24866615022932, 33.98222882407052, 23.33990059580122, 0.1181986289364951, 0.17742744859840187, 0.15485983528196812, 5.54455521277019, 5.490941175392695, 5.314119943550654, 3.3717397366251265, 2.8809113885675157, 3.8286133238247464, 0.25682425605399267, 5.0178713372775485, 27.55045509338379, 46.53019952774048, 50.0209675516401, 49.58998816353934, 47.380554812295095, 47.29150322505406, 45.79907533100673, 45.27836690630232, 44.40088585444859, 47.43784270967756, 47.56704446247646, 44.16533497401646, 38.8452730178833, 36.41176373617989, 35.42870480673653, 39.39071702957153, 45.60030473981585, 46.6905118397304, 47.037119252341135, 46.16009678159441, 40.54592800140381, 38.582179478236604, 35.91244534083775, 36.38805995668684, 36.750238282339915, 35.07875878470284, 36.345696789877756, 36.257378237588064, 35.95441940852574, 34.64090762819563, 34.70431341443743, 33.792004517146516, 35.729815414973665, 34.864521503448486, 35.61709826333182, 38.28053385870797, 39.45500871113369, 42.19003159659249, 42.73536443710327, 41.56190054757254, 44.33933523723057, 44.92208760125296, 44.88789899008614, 45.032431943076, 44.860908712659565, 45.63819326673235, 43.82333769117083, 43.73847934177944, 48.4265262058803, 46.54677445547921, 43.460426330566406, 46.497327600206646, 47.69519356318882, 46.42674779891968, 42.79454224450247, 43.07788283484322, 48.51333352497646, 46.3263498033796, 45.21496112006051, 45.51949719020298, 43.919427803584504, 36.152623721531455, 33.185395513262065, 34.08452367782593, 34.650721958705354, 33.99415193285261, 34.40068408421108, 41.39152029582432, 43.32787902014596, 43.493214879717144, 44.229532854897634, 40.79973527363369, 36.98870740618025, 34.715138707842144, 32.21721615110125, 32.43526104518345, 33.90791784014021, 37.34923553466797, 41.979945863996235, 42.49688836506435, 45.0821602003915, 42.35147646495274, 41.90259851728167, 44.83886555262974, 43.514775139944895, 38.79924815041678, 35.443431513650076, 32.350437436785015, 40.4156562260219, 41.158682686941965, 41.516431535993306, 38.679482051304404, 40.049274240221294, 42.5844669342041, 44.65032270976475, 38.94980519158499, 18.011217662266322, 1.2160184574978692, 0.9385361756597246, 3.6717803222792487, 2.4463489013058797, 4.934590228966304, 3.9763828345707486, 5.532337239810398, 1.8634523621627261, 0.43957322410174776, 0.0315581683867744, 7.666489464896066, 37.80910553250994, 18.391532523291453, 25.44562860897609, 21.21074673107692, 0.23491664017949784, 0.06325538216957025, 0.08254083339124918, 0.020671633803950887, 0.0527485456051571, 0.022618985202695643, 0.004202702140901238, 0.02503958254653428, 0.04158577263089163, 0.0414239827410451, 0.023401195283180902, 0.039681328394051106, 0.05609666469639965, 0.015298510070091911, 0.022303995676338673, 0.04311222197221858, 0.08408876854394164, 0.07690427691808768, 0.04277691710740328, 0.049541965526129515, 0.054806484641241174, 0.04116898928103702, 0.04568338114768267, 0.0414478773517268, 0.03275575216061302, 0.033649084224764786, 0.006856028514448553, 0.02609027536319835, 0.018986361467146447, 0.043673998077533076, 0.07573391257652215, 0.03149580084053533, 0.005449822363776288, 0.05573690203683717, 0.027940930432773063, 0.035503774881362915, 0.0037781105493195355, 0.02529256584654961, 0.02741388344605054, 0.010779655987529882, 0.019941957600946938, 0.07220544905534812, 0.03079354763031006, 0.04421317896672657, 0.02116737318491297, 0.0657767504453659, 0.02161194254378123, 0.28858878729598864, 24.41838608469282, 38.36208486557007, 20.329777683530533, 45.23263733727591, 21.54878875187465, 0.07510543308619942, 0.19413414783775806, 0.34038611501455307, 2.596168999161039, 5.4146751420838495, 8.115344830921718, 7.6092632327760965, 10.997171861784798, 7.82278311252594, 0.3866442356790815, 5.9843414425849915, 31.326585633414133, 47.06888294219971, 53.04715122495379, 49.306644099099294, 48.47032764979771, 46.825619561331614, 47.3181426184518, 46.92504480906895, 47.13386596952166, 48.07354729516165, 48.65455913543701, 45.2423300743103, 41.72322382245745, 37.49386576243809, 37.43003266198294, 40.772779737200054, 45.93445750645229, 48.182908466884065, 48.57658297674996, 47.52164493288313, 42.57083109446934, 39.18290335791451, 37.77856819970267, 39.02108676092965, 38.23921292168753, 36.57534517560686, 37.96921634674072, 38.00233146122524, 38.70228603907994, 35.38689054761614, 37.13834033693586, 35.4799234526498, 37.53446408680507, 35.05943931852068, 37.490131105695454, 39.68592166900635, 40.1055338042123, 42.019578388759065, 43.48309135437012, 43.93679482596261, 45.74984039579119, 46.1009259223938, 47.22971984318325, 45.72940921783447, 46.47447497504098, 47.743205615452354, 44.5697409766061, 44.72980315344674, 48.71312550136021, 49.43277474812099, 45.8017886025565, 47.1288354737418, 49.24510390417916, 48.22386809757778, 46.514083181108745, 46.7566864831107, 49.01701538903372, 48.69736351285662, 46.723008564540315, 46.906072752816335, 46.01304163251604, 36.49080644335066, 34.853869915008545, 35.35089193071638, 36.318213190351216, 36.06041417803083, 35.36520869391305, 42.37206050327846, 45.289890493665425, 45.130005495888845, 44.75890220914568, 42.05905457905361, 38.57681546892439, 35.95842504501343, 34.495092732565745, 34.50468472072056, 36.161586897713796, 39.439674036843435, 43.84601313727242, 43.57097217014858, 45.10884823117937, 43.603486265454976, 42.194488865988596, 44.96257128034319, 44.43939624513899, 41.5257351739066, 35.69270508629935, 34.555701868874685, 42.62025710514614, 41.1584221294948, 43.38674415860857, 41.440651008060996, 42.27475445611136, 43.92337090628487, 45.36702939442226, 40.961023807525635, 19.963597195489065, 1.615318511213575, 1.6018484511545725, 4.141244479588099, 5.154137236731393, 6.089142424719674, 5.3588433265686035, 4.688026888029916, 1.337605744600296, 0.26580056867429186, 0.0549279118755034, 7.492558683667864, 44.43823937007359, 25.189769881112234, 28.968193326677593, 29.444044181278773, 1.4304850293057305, 0.12666249834001064, 0.046611291356384754, 0.01829143473878503, 0.0340739455340164, 0.0143778907201652, 0.018749094734500562, 0.05540934943460992, 0.07956941997898476, 0.04027812708435314, 0.05578649616135018, 0.04969908370237265, 0.07581124521259751, 0.03404123675344246, 0.04352237942761608, 0.04004097570266042, 0.09421061112412385, 0.0470014455994325, 0.021894357300230434, 0.04139828322721379, 0.03869969517524753, 0.11713661306670733, 0.14127061090299062, 0.10123803546386105, 0.08096326661429235, 0.10403851233422756, 0.13375856328223432, 0.14275569335690566, 0.0899710293327059, 0.12593918001013144, 0.17215459368058614, 0.10642276903880493, 0.22190361416765622, 0.11102211688246046, 0.11549223773181438, 0.19079270213842392, 0.1048734225332737, 0.0973895409011415, 0.10928832420281001, 0.10597239142017705, 0.14287157356739044, 0.2219721462045397, 0.08749627641269139, 0.15606715264064924, 0.17646995426288672, 0.150206577831081, 0.06598402932286263, 0.3170400049005236, 27.57469388416835, 45.44576985495431, 28.937958240509033, 42.79491049902779, 32.02511235645839, 0.2898524094905172, 0.8590118714741298, 1.2195812548909868, 13.168526479176112, 11.010661789349147, 12.233580350875854, 11.463300449507576, 10.21775073664529, 8.734305994851248, 0.57322073834283, 6.479169130325317, 29.313098430633545, 49.669496400015696, 52.23636940547398, 51.57018654687064, 48.949103696005686, 49.07204164777483, 48.57891409737723, 51.02192851475307, 48.30805941990444, 50.805502550942556, 50.359522002083914, 47.48687614713396, 43.07787241254534, 41.212927273341585, 39.89492695672171, 42.30369022914341, 48.43737929207938, 49.67539542061942, 50.238192558288574, 48.03812190464565, 43.535046509334016, 40.74720689228603, 40.39779588154384, 39.56415796279907, 40.62603030885969, 39.694613865443635, 39.79842342649187, 40.1053010395595, 39.9943904195513, 37.39387771061489, 38.0159638268607, 37.38791615622384, 41.02127511160714, 38.231250286102295, 38.739511013031006, 41.65225492204939, 43.00318969999041, 43.9974421773638, 46.3816922051566, 44.86947236742292, 48.929481983184814, 49.60964461735317, 49.11043739318848, 47.30191510064261, 49.160266399383545, 48.32035078321184, 45.88163730076381, 47.0853397505624, 51.13383967535836, 50.33101354326521, 47.017782415662495, 48.60290275301252, 52.59403487614223, 49.51462800162179, 47.15631212506975, 49.18660702024187, 50.104120118277415, 49.73828704016549, 47.946044376918245, 49.793320247105186, 47.81991720199585, 38.4848803792681, 35.982639517102925, 37.56616524287632, 37.19284200668335, 38.201157638004844, 36.95518929617745, 45.296553816114155, 47.006821632385254, 46.28429583140782, 47.325563294546946, 44.15217508588518, 39.7395270211356, 38.9970703125, 35.991394247327534, 35.93366861343384, 37.225724356515066, 41.08492061070034, 46.010112966809956, 46.320051261356895, 47.849850041525706, 44.944300992148264, 41.66712406703404, 46.347322940826416, 45.90956905909947, 42.63241645268032, 38.56628199986049, 35.96321930204119, 44.13933481488909, 43.00503444671631, 45.559654303959434, 41.67501374653408, 44.18481077466692, 45.60720082691738, 48.97108779634748, 42.10679912567139, 21.154096330915177, 1.9868378213473727, 3.9182880776269093, 7.829727837017604, 6.300979971885681, 12.378080299922399, 9.064404487609863, 13.129275236810956, 8.028475846563067, 1.2494239849703652, 0.12955615163913795, 12.193563069616046, 48.1919515473502, 27.174642665045603, 36.89846420288086, 35.31688744681222, 2.224457745041166, 0.24331087831939968, 0.1676399880754096, 0.0989031150404896, 0.183361807305898, 0.09733628947287798, 0.11694305416728769, 0.15385868400335312, 0.11340792064688035, 0.16101205801325186, 0.1344688944518566, 0.11338417870657784, 0.18654611786561354, 0.12287646292575768, 0.08618848837379899, 0.14416726332690033, 0.18275116650121553, 0.08769539929926395, 0.19814030001206057, 0.10617006902715989, 0.10376426205039024], [0.03818903311288782, 0.01875527109950781, 0.026299700107691542, 0.055637350771576166, 0.0213028817171497, 0.0807751292096717, 0.019476068671792746, 0.029305459266262393, 0.038361638850931606, 0.01612007518165878, 0.012538723248456205, 0.020258579004023756, 0.08151094615459442, 0.03407308718721781, 0.035912965424358845, 0.05439971307558673, 0.017794163565018346, 0.03624274701412235, 0.06266692945999758, 0.026538832811638713, 0.049743707557874065, 0.030742552330983535, 0.012111523537896574, 0.08342018763401679, 0.026986869484452263, 0.05021908240658896, 0.043975145489509614, 2.389805329697473, 30.79716764177595, 25.357961450304302, 27.320599998746598, 36.862298829214915, 3.345322685582297, 0.384137428764786, 0.15700901352933475, 1.4990386707442147, 2.4476673219885146, 8.639881713049752, 3.7053891931261336, 18.491405929837907, 7.680338093212672, 0.282843468444688, 0.6155903105224881, 11.934979779379708, 33.78922871180943, 49.20175061907087, 48.420588970184326, 47.516204493386404, 43.9462547983442, 44.37008101599557, 46.10239199229649, 49.60170630046299, 46.83720915658133, 47.31249025889805, 40.943889549800325, 38.2967266355242, 36.18047904968262, 40.83257246017456, 44.86157921382359, 48.60380949292864, 48.006611824035645, 48.159670216696604, 44.13883454459054, 38.06862769808088, 37.338521412440706, 35.4378799029759, 37.30261312212263, 38.07633672441755, 35.035596575055806, 37.24793774741036, 36.78138358252389, 39.19979442868914, 37.26547500065395, 35.53928886141096, 34.22726399557931, 34.95562628337315, 33.80043268203735, 34.95113774708339, 35.54763017381941, 38.472238131931846, 40.20152316774641, 42.59690073558262, 42.701957498277935, 44.43956300190517, 45.394968100956504, 45.44058302470616, 45.20071036475045, 46.66750635419573, 47.17855330875942, 45.03686836787632, 42.15241057532174, 48.43317910603115, 41.939170360565186, 44.34111050197056, 44.1839040347508, 44.90672166006905, 46.78377056121826, 54.640564237322124, 46.69676521846226, 45.96740933826992, 45.52251965659005, 44.818236351013184, 45.900588512420654, 42.43104376111712, 36.41212851660592, 32.601826735905235, 33.100714342934744, 33.47638259615217, 34.17545475278582, 35.82750013896397, 41.13264431272234, 43.079404490334646, 45.2660824911935, 43.81275905881609, 43.060915333884104, 40.83543859209333, 38.27507952281407, 35.5724595614842, 32.62940066201346, 31.65798691340855, 34.95509474618094, 35.53214611325945, 39.11362286976406, 41.70455053874424, 44.23651579448155, 43.318307876586914, 41.275700773511616, 44.41822508403233, 40.50552422659737, 37.05296087265015, 32.43524020058768, 38.846169335501536, 42.73135185241699, 42.05380174091884, 39.77236073357718, 39.66091857637678, 42.36182928085327, 42.104137965611045, 31.634804248809814, 8.245456797736031, 0.6313411167689732, 0.12093265008713518, 2.3801484193120683, 3.5160559926714217, 3.9903830204691206, 3.7763815437044417, 4.136405059269496, 0.46008381779704777, 0.11292538046836853, 0.08490064247910466, 19.700599193572998, 35.59421437127249, 17.821453673498972, 27.91484294618879, 8.037805540221077, 0.23295013712985174, 0.028130250184663703, 0.023513743886724114, 0.026973649925951446, 0.03639025713450142, 0.04908328263887337, 0.02554870263806411, 0.02128761976824275, 0.03890257714582341, 0.03433813314352717, 0.042453998899353404, 0.009615212712170822, 0.09630327418978725, 0.04674814847697105, 0.017379320825317075, 0.06440950916813952, 0.02346481642286692, 0.008318251547669726, 0.027627535463709916, 0.025827477054138268, 0.053060325660875866, 0.009947417520119675, 0.0992007679971201, 0.04814751838733043, 0.04955714774717178, 0.05790499784052372, 0.008418029273993202, 0.017835750976311307, 0.016255539609119296, 0.07624203352523701, 0.014334584918937512, 0.05158389113577349, 0.013109450927004218, 0.012323462254633861, 0.014740421802603772, 0.03791323916188308, 0.025346719726387943, 0.022678899844842296, 0.0502115337045065, 0.05513064796105027, 0.05156372507501926, 0.03408729571050831, 0.01799375464075378, 0.02703404632796134, 0.015275667188689113, 0.03979792106630547, 0.026463720681411878, 0.027911086766315357, 4.059224903583527, 40.28917121887207, 24.549715723310197, 32.66931458881923, 44.53369719641549, 3.1668527764933447, 0.3479677667575223, 0.06212209976677384, 1.488869222147124, 3.232828310557774, 8.159274816513062, 6.6013262782778055, 10.916958383151464, 7.596686993326459, 1.633155188390187, 0.984671128647668, 14.875408785683767, 36.32287195750645, 50.96719755445208, 48.22772782189505, 48.574599266052246, 45.64717728751046, 46.28017554964338, 49.1432328905378, 50.23889780044556, 48.89714159284319, 49.869100775037495, 43.83260311399187, 40.52246046066284, 36.26475722449166, 41.7802928515843, 45.96762473242623, 50.004406520298545, 49.38468279157366, 48.94434417997088, 46.38370370864868, 40.37357793535505, 39.44897420065743, 37.720623697553364, 38.76984684807913, 37.887891156332834, 36.14576237542288, 39.65008633477347, 38.17873232705252, 41.242401531764436, 38.73373358590262, 37.32860285895211, 35.652513231549946, 37.18508434295654, 34.60355411257063, 36.04964794431414, 37.68380519321987, 41.80082130432129, 42.566985266549246, 44.33837638582502, 45.16798782348633, 46.233709471566335, 45.40931960514614, 46.702198709760395, 48.421290738242014, 48.813356740134104, 47.78226491383144, 44.58844552721296, 44.01391288212368, 49.031894956316265, 45.41135890143258, 46.83358219691685, 46.29770932878767, 48.16788993562971, 48.18608379364014, 53.422871589660645, 45.31483800070626, 46.791569914136616, 45.81040784290859, 45.49122149603707, 46.90243189675467, 44.35157796314785, 37.19685459136963, 34.458107471466064, 35.57201140267508, 34.47594002314976, 34.120407649448936, 37.40108299255371, 43.163696561540874, 44.765301500047954, 46.898818833487375, 46.39653008324759, 44.13166747774397, 42.663874421800884, 40.575370992933, 36.95723206656319, 33.856497696467805, 32.63263157435826, 35.962545326777864, 38.06192963463919, 41.52514805112566, 42.19806024006435, 45.62051010131836, 43.09001438958304, 43.009901659829275, 45.6535244669233, 42.33330692563738, 37.74797180720738, 33.82730484008789, 40.302602086748394, 44.56085423060826, 43.275757108415874, 40.5594596181597, 41.04557296207973, 43.922498907361714, 42.18428891045706, 34.41904469898769, 9.861075384276253, 1.768874134336199, 1.759649640747479, 4.5434422578130444, 6.446521282196045, 7.151370431695666, 6.9959830897195, 3.057518311909267, 0.5936450766665595, 0.05667568916188819, 0.037100374565592835, 22.67145609855652, 44.14329181398664, 18.81345840862819, 34.3122752053397, 12.77853798866272, 0.22256270237267017, 0.04677770546238337, 0.053021374358130355, 0.07102941216102668, 0.06541451452566044, 0.026665639132261276, 0.047404400405607054, 0.05518581285806639, 0.052380470891616175, 0.017023939805637513, 0.03725289905975972, 0.028108872938901186, 0.05992728325405291, 0.04636546829715371, 0.031610368085759025, 0.04280595162085124, 0.03401986290035503, 0.019336117431521416, 0.005449348237432007, 0.0424594712842788, 0.018221457422311817, 0.09329722156482083, 0.15776175313762256, 0.13668443342404707, 0.1196298221392291, 0.08307256057326283, 0.12899968507034437, 0.11062451571758304, 0.10851963902158396, 0.15211398048060282, 0.1146989217294114, 0.11554000659712724, 0.12326907685824803, 0.1965709842209305, 0.16092375346592494, 0.10199737043253013, 0.11338611253138099, 0.1035994119676096, 0.12084682897797652, 0.20573869799929007, 0.12210762846682753, 0.1660139196153198, 0.07175527499722582, 0.08503003232181072, 0.11074258759617805, 0.10631807787077767, 0.21697609286223138, 0.1271677083734955, 4.837507392678942, 44.6416791507176, 35.88262367248535, 36.535233225141255, 49.12368760790144, 6.479945591517857, 0.9104155674576759, 0.32421087154320305, 3.3442029399531226, 9.75141978263855, 17.8929853779929, 8.421324389321462, 25.762989316667827, 15.082708290645055, 1.5834553752626692, 1.366102695465088, 13.616316165242877, 37.931435516902376, 52.86016477857317, 50.13543912342617, 49.60015337807791, 45.756267479487825, 49.352453572409495, 51.387243952069966, 53.491551058632986, 51.413244111197336, 51.31150163922991, 43.8892239843096, 42.39106035232544, 39.06713247299194, 45.397566727229524, 48.43315826143537, 52.957043511526926, 51.57642950330462, 51.28402846200125, 48.60646717888968, 41.22108098438808, 41.337011677878245, 39.01050465447562, 42.1974835395813, 41.05295542308262, 37.48193917955671, 41.231388636997764, 40.09534774507795, 42.52970470700945, 42.01531914302281, 39.693936416081016, 38.54595504488264, 39.053413254874094, 36.90966469900948, 39.19069228853498, 39.174683638981406, 44.20131622041975, 44.62300934110369, 47.25490011487688, 46.86156954084124, 50.03958872386387, 48.31998600278582, 48.22384377888271, 49.18461288724627, 50.99650853020804, 51.43893160138811, 45.65989249093192, 45.78171525682722, 50.76194429397583, 46.01673807416643, 46.634967940194265, 48.72991234915597, 47.993271282741, 49.2815819467817, 54.023692744118826, 48.428899015699116, 48.791320528302876, 47.30257517950875, 47.16709572928292, 48.18532296589443, 45.37884828022548, 38.09076118469238, 36.55459090641567, 36.864939144679475, 36.04093142918178, 36.55337497166225, 39.171598638807026, 44.231693744659424, 45.919480664389475, 48.91656180790493, 48.67476797103882, 46.01253093991961, 44.14856549671718, 41.872241837637766, 38.98240613937378, 35.83186708177839, 35.01021480560303, 36.76734127317156, 38.310928753444124, 42.19738279070173, 44.54425845827375, 46.504223687308176, 45.12551348549979, 42.00326749256679, 47.40575245448521, 43.815823214394705, 40.57362004688808, 36.37610558101109, 42.02846513475691, 46.31396116529192, 46.04352337973458, 42.13952514103481, 42.95166185923985, 45.46044097627912, 43.02340200969151, 35.9837303842817, 11.148142320769173, 1.6716173759528568, 2.974179229566029, 7.171950561659677, 9.703764694077627, 9.643410904066902, 10.082792401313782, 11.455422929355077, 2.6302208176680972, 0.16247199395937578, 0.3257529916507857, 28.208496400288173, 46.00506510053362, 26.54454527582441, 41.88539825166975, 15.279251984187535, 0.3730950041541031, 0.1840139880244221, 0.18480070866644382, 0.20095153844782285, 0.11213720097605671, 0.14544024930468627, 0.21287642499165876, 0.23097641446760722, 0.13701443214501652, 0.10153690299817494, 0.12443446075277668, 0.10380863824060985, 0.14470644082341874, 0.12104471693081514, 0.13760637252458505, 0.22101672818618162, 0.17002883846206324, 0.13751087550606045, 0.14668731524475984, 0.16347622578697546, 0.17136328614183835], [0.031416670086660554, 0.015224585376147712, 0.042041517461517026, 0.0320422793738544, 0.025917515258437822, 0.02705582560572241, 0.012023375053623957, 0.025845507425921302, 0.030680442628051554, 0.06717830523848534, 0.025067748535158377, 0.0628283190141831, 0.065188725212855, 0.03400585115221994, 0.0506366019669388, 0.004874272421667618, 0.03243402817419597, 0.03713364653023226, 0.07663183153739997, 0.03260116831266454, 0.07951393617050988, 0.07152796576597861, 0.015570097103981035, 0.0722237355741007, 0.04235719230824283, 0.004658879113516637, 0.08355410330529724, 0.1247079646480935, 12.67606942994254, 37.24778836114066, 25.565300907407487, 38.37861810411726, 17.902130944388254, 0.007658256650237101, 0.197259819401162, 0.595522555921759, 3.3174721343176703, 3.724200572286333, 9.34126501423972, 18.279609203338623, 5.755436079842704, 1.530397193772452, 0.12793403225285666, 2.0422896572521756, 17.672843864985875, 40.80614151273455, 45.28732660838536, 46.70182350703648, 43.062527315957205, 45.948465074811665, 48.3352164540972, 50.46840027400425, 47.75005306516375, 43.708334582192556, 39.40755251475743, 36.36745854786464, 37.663891656058176, 44.19608770098005, 46.335618700299946, 48.93359531675066, 47.874081884111675, 49.27925430025373, 42.5901575088501, 40.71144451413836, 38.50957775115967, 35.59116063799177, 36.059677668980186, 36.44615731920515, 35.48498521532331, 39.04744822638375, 40.04210369927542, 39.90910823004586, 39.24469716208321, 36.82852363586426, 33.51860679898943, 35.50791079657418, 34.368368012564524, 35.07324538912092, 34.99342448370797, 37.35586411612374, 39.30549389975411, 41.730689661843435, 41.83041020802089, 42.9870559828622, 43.50272348948887, 44.63190303530012, 44.42461395263672, 45.400526659829275, 46.39682190758841, 45.85749231066023, 41.16013833454677, 47.902750151497976, 41.620901175907676, 42.9403258732387, 47.08141054425921, 47.84250232151577, 45.60554715565273, 47.47509200232369, 54.51326976503645, 43.321410247257774, 46.76226588657924, 46.97984872545515, 45.44294888632638, 41.56107718603951, 33.9737902368818, 33.06443779809134, 33.10385145459856, 34.50998967034476, 33.416471753801616, 37.28604514258248, 40.967464787619456, 41.05606821605137, 41.940070152282715, 41.408536434173584, 41.043860231127056, 41.51391976220267, 40.216767515454976, 38.860777923039024, 34.93288482938494, 31.85784489767892, 32.89333493368966, 32.82465546471732, 38.07782711301531, 41.55722440992083, 45.00871426718575, 44.10311385563442, 42.59219333103725, 43.09795618057251, 43.43804618290493, 39.83848326546805, 36.64495917728969, 37.24519320896694, 42.66898829596383, 40.18195356641497, 42.271130970546174, 39.147123609270366, 42.84634106499808, 37.07217958995274, 22.92765007700239, 2.5582585419927324, 0.347794523196561, 1.9197028066430772, 2.228078842163086, 6.870122986180442, 6.079118345464979, 5.816441697733743, 1.3728311572756087, 0.04140090915773596, 0.04170969348134739, 1.4347931295633316, 33.22168595450265, 23.703878504889353, 23.645355565207346, 26.177819354193552, 2.0415904947689603, 0.013322929070065064, 0.04671181631939752, 0.035953185587589226, 0.05605378806857126, 0.018230773708117858, 0.01803990520004715, 0.03939711382346494, 0.05213822031925831, 0.0362718900931733, 0.053208524494298866, 0.07252979557961226, 0.07131156059248106, 0.0722890445696456, 0.03109125147706696, 0.015333047502541115, 0.021081774295972924, 0.021174000775707618, 0.0412028380004423, 0.02112400292285851, 0.040686038588838916, 0.04449852669079389, 0.024211929279512594, 0.028533191420137882, 0.01932868068771703, 0.11432407184370927, 0.030773323894079243, 0.033745802606322935, 0.02096819262286382, 0.011923881463839539, 0.03038587361308081, 0.044500250169741254, 0.033370956113295894, 0.051519864571413825, 0.07287926825561694, 0.03587327112576791, 0.0497624147683382, 0.07965410114931208, 0.027356520095574002, 0.02051013568416238, 0.026914586845253195, 0.03851836347686393, 0.04135261442778366, 0.01540866683769439, 0.02986555260473064, 0.047854184306093624, 0.0445058005861938, 0.0266144453614418, 0.0785248763859272, 0.16451798060110637, 18.774604082107544, 39.559092726026265, 25.96236613818577, 47.525963238307405, 17.532561472484044, 0.057646001023905616, 0.10638631813760314, 0.45722827102456776, 1.1021873142038072, 6.253763922623225, 10.800764526639666, 16.805519342422485, 4.719643362930842, 1.3679897827761514, 0.324879309960774, 2.326235826526369, 21.494125536509923, 41.863639967782156, 46.89271136692592, 47.49641949789864, 46.09560707637242, 47.95136669703892, 49.38710423878261, 50.96357406888689, 48.58948925563267, 45.06910106113979, 41.71996511731829, 38.382668903895784, 39.64043876102993, 45.0543326650347, 48.06310067858015, 49.991607938494, 51.21474797385079, 49.881086417606895, 44.06599310466221, 40.73658309664045, 40.39229985645839, 37.73193883895874, 38.07611090796334, 37.734360286167686, 37.65973663330078, 39.9092298235212, 41.91249622617449, 42.29008913040161, 40.57209491729736, 37.655519076756065, 35.432137216840474, 36.90410961423601, 36.14837837219238, 37.4239946774074, 36.364140783037456, 39.61556421007429, 42.42776421138218, 42.832465512411936, 43.996160234723774, 45.43809904370989, 45.48983185631888, 46.914879594530376, 46.21441779817854, 46.045253481183735, 46.65371070589338, 45.887004784175325, 43.059619494846885, 47.99340329851423, 44.303100381578716, 45.97908926010132, 47.603345326014924, 48.94104378564017, 47.53696918487549, 51.269763810294016, 55.4693557875497, 45.36200932094029, 47.21673366001674, 47.90199974605015, 46.46003314426967, 42.609577723911826, 35.9023391859872, 34.05859994888306, 33.821544783455984, 34.288095474243164, 36.053188051496235, 37.55452701023647, 42.28008719852993, 43.153757163456504, 43.17619637080601, 43.745344161987305, 42.86341626303536, 43.061318329402376, 41.80507360185896, 40.023465156555176, 36.05773564747402, 33.526138646262034, 34.97641181945801, 35.20003611700875, 39.797850200108115, 41.99820572989327, 46.20225497654506, 45.035523891448975, 41.295395442417686, 44.51468345097133, 44.70373351233346, 41.05407060895647, 38.17048134122576, 39.64326320375715, 43.65691096442086, 40.852187224796836, 43.71951075962612, 40.69778435570853, 43.49184261049543, 38.79053858348301, 25.285583802631923, 3.330412719930921, 0.8674908993499619, 3.1751200471605574, 3.6662773489952087, 6.357795826026371, 9.393312232834951, 7.479250277791705, 0.9802168990884508, 0.11796177950288568, 0.05455607468528407, 1.2688205327306474, 37.23065757751465, 29.725769315447124, 24.958188159125193, 32.56156539916992, 3.3849122183663503, 0.04817094820152436, 0.026720537704282572, 0.034645899664610624, 0.025039689415799718, 0.0439678749867848, 0.009386986610479653, 0.07685282360762358, 0.02318790288908141, 0.012641619691359145, 0.07398299367300101, 0.03846216381394437, 0.054619711092008014, 0.03969993382426245, 0.028292218189952627, 0.0365386154236538, 0.026526625966653228, 0.03195777801530702, 0.0719527422583529, 0.014817192950951201, 0.04727263908301081, 0.005560645367950201, 0.1287217978388071, 0.09588351885655097, 0.09689895329730851, 0.19666781116809162, 0.18297777005604335, 0.11621770023235253, 0.13452764201377118, 0.10223657438265425, 0.07309207040816545, 0.15819429207061017, 0.1660906212138278, 0.2577388398349285, 0.15022812810327324, 0.13722171102251324, 0.15690580835299833, 0.11890460391129766, 0.09633460893694844, 0.10900092391031128, 0.12366861184792859, 0.0822947762374367, 0.229311289531844, 0.11634044721722603, 0.06930855914418187, 0.13491561476673397, 0.14969827367791108, 0.11007051223090716, 0.16356416392539228, 0.21695652391229356, 22.56484467642648, 49.72551277705601, 33.8809414591108, 50.579991817474365, 25.53214931488037, 0.081504927548979, 0.30066307368023054, 1.1949893001999174, 8.294497183391027, 11.304563641548157, 19.539444412503922, 27.717116321836198, 11.683150138173785, 5.038349849837167, 0.37165919691324234, 2.974245671715055, 20.838118314743042, 42.41715778623308, 47.63462611607143, 49.22112567084176, 47.07958664212908, 49.33582305908203, 50.29082863671439, 54.691834994724815, 51.5769019808088, 46.51828684125628, 44.441102027893066, 40.94105815887451, 41.033569949013845, 48.41591630663191, 51.19188492638724, 52.071182932172505, 52.90558862686157, 52.82015357698713, 45.78012064525059, 43.27682365689959, 41.78527470997402, 39.083033425467356, 39.03322526386806, 39.57320104326521, 39.5456132207598, 43.04460791179112, 43.97151844842093, 44.65134409495762, 42.89630903516497, 40.619568484170095, 36.83721235820225, 39.92801080431257, 36.98507349831717, 39.597304344177246, 38.97297395978655, 41.57852063860212, 42.606037616729736, 44.567979608263286, 44.03943361554827, 47.3011542728969, 46.675211906433105, 48.818512303488596, 48.01324387959072, 47.46077176502773, 49.23480667386736, 47.80492646353585, 45.285815375191824, 48.708251340048655, 45.74378504071917, 47.875488894326345, 49.24409294128418, 48.7152099609375, 47.535353728703086, 52.24846969332014, 56.43972035816738, 45.72238111495972, 49.10415622166225, 49.70581463405064, 48.76584495816912, 44.319512026650564, 36.76775469098772, 35.89883381979806, 36.55327074868338, 38.159381593976704, 36.90908799852644, 39.304288387298584, 44.824444566454204, 43.40436131613595, 44.80401686259678, 44.823381492069785, 44.22194194793701, 45.48637860161917, 43.881799834115164, 43.504776682172505, 38.8890049798148, 35.44126714978899, 37.43464626584734, 37.445402077266145, 41.01840203148978, 45.396625246320454, 49.403356075286865, 46.53910364423479, 42.579551083701, 45.202346665518625, 47.73654924120222, 43.21170513970511, 40.494070121220176, 42.6338859966823, 46.29047972815377, 43.47353063310896, 44.97469588688442, 40.86995376859392, 42.867821420942036, 42.99156536374773, 25.31049656867981, 3.6672327263014655, 0.808621418263231, 4.323381083352225, 8.15857912812914, 12.165931820869446, 10.077818359647479, 12.785211733409337, 4.698169520923069, 0.43454568673457417, 0.13667952083051205, 2.8435111897332326, 43.461041246141704, 31.382991109575542, 32.37898758479527, 38.770072664533345, 4.126011856964656, 0.20583693629928998, 0.12478581975613322, 0.13313910152230943, 0.10830182249524764, 0.07763600908219814, 0.1224469638296536, 0.181999091857246, 0.17059432954660483, 0.07239115051925182, 0.15680983635996068, 0.2218567273978676, 0.13531985878944397, 0.15583033034844057, 0.09227830623941762, 0.11422714990164552, 0.087158203125, 0.1308116992669446, 0.14445573570472853, 0.10424344348055975, 0.09686947095074824, 0.12251831857221467], [0.031202012140836035, 0.012785565806552768, 0.046175892398293526, 0.019022439174087982, 0.024823628598824143, 0.01570332406221756, 0.0554536883054035, 0.013052486215851136, 0.03658564807847142, 0.06270273575293166, 0.03949483982952578, 0.008823280921205878, 0.058048100875956674, 0.05105818595205035, 0.012237532579872226, 0.03750495107046195, 0.06815992149391345, 0.03736185482037919, 0.0400100616472108, 0.03653949751917805, 0.0402295032649168, 0.034107078398977, 0.09032467499907527, 0.029437393615288392, 0.08613919959004436, 0.020976051754717315, 0.052793607115745544, 0.031123892404139042, 1.512249584708895, 32.04549489702497, 26.019589764731272, 25.0457250390734, 35.27379124505179, 2.285070138318198, 0.050810439246041436, 0.3284790468003069, 0.8649446559803826, 4.086636849812098, 8.528443898473467, 22.361623764038086, 5.65915402344295, 1.4681267866066523, 0.5660481889333043, 0.06993233638682536, 5.836328744888306, 26.01078118596758, 39.74403640202114, 47.36843020575387, 45.589069502694265, 46.67643478938511, 49.64285005841936, 47.19183826446533, 46.94949204581124, 42.946839809417725, 35.98229905537197, 38.46030807495117, 40.20131819588797, 44.29714230128697, 48.09255409240723, 47.46916518892561, 48.03225415093558, 47.353672231946675, 43.06735978807722, 43.93392174584525, 44.855874742780415, 39.6517539024353, 35.3770067351205, 36.862743513924734, 36.808926241738455, 41.30961145673479, 43.46567916870117, 41.8660648890904, 39.523274762289866, 37.221221923828125, 36.705088887895855, 34.44079950877598, 34.844875471932546, 34.699807507651194, 33.20646939958845, 35.50021914073399, 36.899489062173025, 38.508434772491455, 39.28924553734915, 40.65251336778913, 43.03646462304251, 43.00881426674979, 44.32683195386614, 46.51603215081351, 48.142681871141704, 46.18613168171474, 42.27990654536656, 44.8475785936628, 42.8272647857666, 49.97718347821917, 46.6602281161717, 45.32163333892822, 41.58516311645508, 33.581904888153076, 34.77854796818325, 43.59299101148333, 45.697357177734375, 46.482972621917725, 43.532472201756065, 38.50209106717791, 32.14547252655029, 32.54704366411482, 33.28017241614205, 34.278937748500276, 33.13842569078718, 36.759816374097554, 38.64384126663208, 39.59530326298305, 38.47072689873831, 37.785530294690815, 37.99186747414725, 40.22125605174473, 38.54371772493635, 37.65224300112043, 35.45888430731637, 36.34470667157854, 33.66941050120762, 32.60581152779715, 34.11534936087472, 38.800436292375835, 40.08311544145857, 43.60511909212385, 43.92339175088065, 43.377124377659385, 41.60851253782, 42.135582038334434, 38.33880492619106, 37.4114670753479, 41.14448056902204, 43.00833484104702, 40.73403658185686, 42.821042673928396, 37.47511257444109, 30.398337568555558, 9.716938478606087, 0.36770716469202724, 1.4073244035243988, 1.7433452584913798, 3.63921411548342, 6.234818356377738, 12.917396868978228, 7.8029268980026245, 1.0333709440061023, 0.0875486321747303, 0.018731602101719806, 7.277521925313132, 41.69011218207223, 20.744253362928117, 31.642353466578893, 14.997424364089966, 0.07295366283506155, 0.02901760096262608, 0.08090360981545278, 0.02025453663165016, 0.028737552597054412, 0.023167275424514498, 0.022770532606435672, 0.017170679788770418, 0.05350308672391942, 0.02449558236237083, 0.07639989469732557, 0.02735107994106199, 0.01347474449513746, 0.02955599475119795, 0.023697957662599425, 0.05744232516735792, 0.02484854101203382, 0.015126783034897276, 0.02211776325878288, 0.06248984539083072, 0.06829550636133977, 0.05237641664487975, 0.06354569337729897, 0.02223659509659878, 0.019416808815939084, 0.04584449250251055, 0.019585557082401853, 0.02503015599878771, 0.06435205760811057, 0.026921859044315558, 0.048083390042717965, 0.05690066423267126, 0.019736563354464512, 0.019591831834986806, 0.049158348967986445, 0.02207974494168801, 0.004974761761591903, 0.04589163372293115, 0.037935532429920774, 0.005627322883810848, 0.05922932856317077, 0.04526322887146047, 0.037696806846984794, 0.016431331069075635, 0.07420563458331994, 0.012634633325173386, 0.04915809112467936, 0.05287690068195973, 0.012621834458384131, 0.05124191627172487, 2.941406313862119, 39.08151524407523, 25.867134128298076, 34.33037873676845, 41.98902368545532, 1.7843208483287265, 0.05795845282929284, 0.06326263570891959, 0.767343201807567, 1.6757553539105823, 10.089077915464129, 19.761218752179825, 5.694740091051374, 2.0763364817414964, 1.0369098569665636, 0.4567680614335196, 7.693997383117676, 28.67054292133876, 42.55723346982683, 47.09024517876761, 47.174895082201274, 47.796852656773154, 49.88834033693586, 47.89196654728481, 49.2555262020656, 44.96116427012852, 38.09027828489031, 40.39653478349958, 41.67279379708426, 45.79543447494507, 49.608001368386404, 48.09465592248099, 49.80414554050991, 49.04022584642683, 42.84611177444458, 45.24073198863438, 45.08509234019688, 40.0245977129255, 37.431974683489116, 38.18522194453648, 38.10217012677874, 42.29573106765747, 45.163131032671245, 43.64768723079136, 41.256523745400564, 39.6553704398019, 36.811514445713584, 35.33324350629534, 36.88916751316616, 35.96176365443638, 35.071602140154155, 37.311878544943674, 39.14289215632847, 41.76725803102766, 41.209922177451, 42.9066618510655, 46.195035798209055, 45.027060985565186, 45.97701174872262, 49.362948826381135, 47.746690137045725, 46.970395701272146, 42.89385632106236, 45.5533800806318, 43.68388039725167, 48.9249587059021, 48.54297454016549, 46.14105871745518, 43.945625986371724, 34.86324650900704, 39.147370270320344, 45.04998309271676, 46.05638449532645, 48.833885192871094, 45.10487386158535, 40.275170598711284, 32.215096950531006, 33.739104407174246, 33.679815428597585, 34.95131492614746, 35.46822616032192, 38.78115504128592, 40.32811934607369, 41.379767417907715, 40.731886114392964, 40.08709675925118, 39.681485244206016, 42.086892536708284, 38.675059522901265, 39.90897968837193, 37.70567464828491, 36.9085043498448, 35.14053521837507, 33.20864418574742, 35.31733213152204, 40.674320289066856, 41.65592704500471, 44.76524938855852, 43.79146630423409, 43.64932005746024, 43.530339104788645, 43.5182283946446, 40.463928835732595, 37.65294476917812, 42.83665527616228, 43.06432342529297, 41.45350170135498, 42.66255078996931, 41.0580484526498, 33.67424297332764, 13.49550609929221, 1.4584442547389438, 3.1330884397029877, 3.3244882949760983, 3.3894139996596744, 6.052172797066825, 9.724670086588178, 4.026309984070914, 0.790682635137013, 0.051850389157022746, 0.02393561116020594, 7.614691512925284, 49.338588442121235, 22.369280678885325, 32.035472120557515, 22.21036842891148, 0.15311437179999693, 0.051637800743005106, 0.054402199906430075, 0.04194561671465635, 0.012950006223815893, 0.06979759290282216, 0.05572233049731169, 0.04633345162229879, 0.037346340117177794, 0.018947866479200975, 0.09138475025870971, 0.05113221751525998, 0.05136396775820425, 0.02414988912642002, 0.021144247015139887, 0.03553046505632145, 0.02381224840480302, 0.041873936275286336, 0.08371156414172479, 0.07477203490478651, 0.03475271803992135, 0.02127552148886025, 0.1328191858317171, 0.13826801202126912, 0.09863303774701697, 0.0804499141605837, 0.05475624930113554, 0.14779198382581982, 0.17797489065144742, 0.0745172585759844, 0.16081210731395654, 0.18018274860722677, 0.11987309051411492, 0.12754557095468044, 0.13437734650714056, 0.13678352667817048, 0.19914496610207216, 0.17443657480180264, 0.11415162895406995, 0.10746481562299387, 0.12907969791974339, 0.10705317556858063, 0.15951359484876904, 0.16080310993960925, 0.13879194962126867, 0.18024756227220806, 0.33423845203859465, 0.1136409906404359, 0.17439099081924983, 0.08866643040840115, 3.419024182217462, 44.804732527051655, 35.40917689459664, 32.25323561259678, 46.28993082046509, 3.704823349203382, 0.3655521646142006, 2.046247524874551, 3.0393099061080386, 9.32305291720799, 19.028750079018728, 33.444650173187256, 13.241288883345467, 4.9520410639899115, 1.8763154319354465, 0.39012137481144493, 7.398425357682364, 28.35101090158735, 42.546894550323486, 48.75561720984322, 48.938785621098106, 50.469935825892854, 52.076661586761475, 49.765520504542756, 51.14788545880999, 47.55157429831368, 39.00725637163435, 43.066720553806846, 43.41288675580706, 48.80688796724592, 52.38610308510916, 49.52478974206107, 50.67240285873413, 50.19806671142578, 45.36352055413382, 48.911201272692, 48.804678440093994, 43.19671787534441, 39.317608083997456, 39.47188935961042, 40.09532342638288, 45.00888449805123, 46.71949277605329, 45.824578693934846, 43.86285557065691, 41.54995312009539, 39.49970299857003, 37.19862985610962, 38.90836613518851, 38.44623449870518, 37.36439650399344, 40.24959775379726, 41.53521251678467, 43.26580728803362, 43.082746573856895, 45.145715372903005, 46.73213849748884, 46.8563688141959, 47.76203523363386, 51.21719721385411, 48.770764282771516, 48.72163009643555, 46.35706084115164, 45.10571806771414, 45.54383672986712, 51.576592785971506, 46.027115208762034, 47.47429643358503, 45.362127440316335, 39.39652572359358, 41.93019676208496, 46.70681231362479, 49.60456201008388, 49.244996207101, 47.14215169634138, 42.33122941425869, 34.30744273321969, 35.10037810461861, 35.42826359612601, 37.50382947921753, 37.09027964728219, 40.79201235089983, 41.70164966583252, 43.4781094959804, 41.439021655491416, 42.468515396118164, 41.387469496045796, 44.16235767092024, 40.41114337103707, 41.904311248234336, 39.530177797589985, 38.530026299612864, 37.744522026606965, 35.809625898088726, 38.48777082988194, 41.98698786326817, 43.385736669812886, 46.21988255637032, 46.0161509513855, 45.03739990506853, 44.08682380403791, 44.5985621043614, 41.489528111049104, 40.29510498046875, 45.72983653204781, 45.357906409672324, 43.27301951817104, 42.50166177749634, 43.72833844593593, 35.04451806204659, 11.615286214011055, 1.1615208046776908, 5.740652484553201, 4.879246958664485, 7.711972372872489, 14.134874122483389, 23.720356157847814, 14.66402200290135, 3.473897146327155, 0.269669059664011, 0.1253748152937208, 11.249454004423958, 52.14290223802839, 27.89200595446995, 41.90162924357823, 25.33159477370126, 0.24854097196034022, 0.1358996941042798, 0.14240712991782598, 0.1787937195705516, 0.20915194627429756, 0.10859441358063902, 0.12216596890773092, 0.23106196416275843, 0.13996524523411477, 0.14208344157252992, 0.20348453681383813, 0.1508549858949014, 0.1224027369171381, 0.12013675565166132, 0.1066583428265793, 0.18498558231762477, 0.16988103996430123, 0.10128342945660863, 0.1202186005456107, 0.2122196438057082, 0.13103473372757435, 0.15646970032581262], [0.014717694272154143, 0.026813486823812127, 0.03963083860331348, 0.050754103876118145, 0.04755090629415853, 0.05209348450547882, 0.0592430213998471, 0.037241374142467976, 0.04585663488666926, 0.06993220067982163, 0.03981449089146086, 0.030471762575741326, 0.07168904997940574, 0.06189393558140312, 0.007187363525320376, 0.025467853494254605, 0.021376155017475997, 0.04728733275883964, 0.02071504308176892, 0.020250572290803705, 0.06779210123100451, 0.09283544455787965, 0.023848494049161673, 0.032210715514208586, 0.02000376196312053, 0.13469696364232472, 0.06494108707244907, 0.001412875937863386, 0.22164927210126603, 13.05892038345337, 36.20888328552246, 20.720829248428345, 41.56812265941075, 16.232586520058767, 0.1274018979498318, 0.14898446840899332, 0.4929461915578161, 2.388331877333777, 4.115950431142535, 17.924823760986328, 11.800330638885498, 1.0205046172652925, 0.65430762725217, 0.13364653715065547, 0.7274794323103768, 11.072859457560948, 27.104222672326223, 43.47508355549404, 44.233597551073345, 44.30878053392683, 49.43640170778547, 48.07755640574864, 47.51473147528512, 41.21201705932617, 38.61371735164097, 37.380839415958945, 40.438057218279155, 46.328687872205464, 49.195483343941824, 48.286026682172505, 47.65653726032802, 46.09975862503052, 45.3953606741769, 48.25910588673183, 48.738399573734824, 42.25260707310268, 37.21756369726998, 35.19363682610648, 36.303246770586284, 41.73214183534895, 43.30849354607718, 44.94815724236624, 39.81539787564959, 38.179705074855256, 35.652099813733784, 36.0798795563834, 33.918291500636506, 35.11716147831508, 33.13275943483625, 34.75321136202131, 35.89631857190813, 36.454008783612935, 39.86218009676252, 39.77204459054129, 39.41222170421055, 40.133423873356406, 43.78041866847447, 47.41648742130825, 47.01369687489101, 48.76976374217442, 41.3080689566476, 44.46158184323992, 46.53853736604963, 46.32164587293352, 41.52846929005214, 44.08102205821446, 42.24864312580654, 43.841170242854524, 41.035706520080566, 46.640060969761436, 45.47689083644322, 44.60018450873238, 39.10522597176688, 34.22999463762556, 32.74631452560425, 33.01307324000767, 33.03968136651175, 34.09809698377337, 34.086399691445486, 34.85614892414638, 36.95996618270874, 37.68745647157942, 36.907705307006836, 34.67429372242519, 35.08805547441755, 33.94237743105207, 35.33964627129691, 36.692047119140625, 34.959534645080566, 34.93697731835501, 33.77083683013916, 33.75694738115583, 36.33898483003889, 36.851098333086284, 39.824760573250906, 41.6399427141462, 42.063758509499685, 41.91970150811331, 42.112131868089946, 43.2894172668457, 41.44816895893642, 40.08803129196167, 41.00903238568987, 43.69436175482613, 42.18243374143328, 36.42964839935303, 36.27877174104963, 18.320825917380198, 2.0897684352738515, 1.111634150147438, 2.3061889708042145, 3.0982202078614915, 1.89913809299469, 3.4872533210686276, 6.20645580972944, 4.687152717794691, 0.27462323382496834, 0.03715496949319329, 0.08474869134702853, 19.40390416554042, 31.99200071607317, 16.915625708443777, 33.68485287257603, 4.241317646844046, 0.12772262788244657, 0.04403638666761773, 0.0470893023136471, 0.01302322354500315, 0.024424950259604623, 0.06762149038591556, 0.04047798618142094, 0.10600114773426737, 0.010528508124739995, 0.06406734431428568, 0.027544448850676417, 0.05444279665659581, 0.020887204379375492, 0.006413967614727361, 0.016332129249349236, 0.05305043262030397, 0.028751689874167954, 0.05055178848228284, 0.01792369081106569, 0.00696869967837951, 0.0337675089415695, 0.057958228912736685, 0.0415314660806741, 0.02353241208142468, 0.027507891080209186, 0.03689753669979317, 0.08642066270112991, 0.04679379352767553, 0.06550226945962224, 0.06667756675077335, 0.009077203992222036, 0.025378989155537317, 0.018128106270783713, 0.037448049123798094, 0.050368875797305784, 0.032682215927967, 0.036799105017312934, 0.04591904314500945, 0.02944088467795934, 0.02545064584618168, 0.017637900342898707, 0.003125508502957278, 0.01748524692707828, 0.06317868735641241, 0.020032077229448726, 0.0674111648861851, 0.09318168062184538, 0.11490488424897194, 0.03134347651419895, 0.04787159551467214, 0.17208606164370263, 17.41048162324088, 39.10667814527239, 21.456784180232457, 47.92740930829729, 15.311840772628784, 0.14467636815139226, 0.12718486173876695, 0.2686472673501287, 0.5729779856545585, 5.595507221562522, 21.886427777154104, 11.450517501149859, 2.6034580937453677, 2.6909391709736417, 0.5673286659376962, 1.9979974968092782, 12.817017980984279, 29.866668360573904, 44.885216985430034, 48.27020215988159, 46.285588196345735, 50.49078042166573, 48.98707560130528, 48.892239638737266, 43.611271721976145, 39.43063790457589, 40.72884627750942, 43.35507774353027, 47.43810326712472, 49.16474103927612, 49.47543668746948, 49.709215777260916, 47.819451672690256, 47.386582374572754, 50.07255792617798, 49.20414079938616, 44.804551873888286, 37.85543959481375, 37.37855345862252, 38.73255239214216, 45.00428131648472, 44.79567902428763, 46.54838296345302, 41.71667514528547, 38.40227672031948, 37.30779300417219, 38.198843887874055, 35.66120195388794, 35.78464017595564, 35.19920580727713, 36.05754109791347, 39.22989402498518, 39.288227626255576, 41.854902608054026, 42.42132323128836, 41.092282227107454, 43.54527078356062, 45.87447370801653, 48.549429416656494, 48.06184652873448, 49.46281181062971, 42.70887442997524, 43.33141565322876, 46.38426998683384, 45.54796395983015, 42.79996878760201, 44.46636915206909, 42.542235783168245, 44.48170730045864, 40.21873385565621, 48.07453046526228, 47.0844121660505, 44.9404308455331, 40.89068371909005, 35.49625866753714, 34.437794412885395, 33.07828208378383, 34.222626073019846, 34.527756214141846, 35.377170017787385, 36.899864264896934, 39.21988861901419, 39.317194666181294, 39.29452616827828, 36.127217633383616, 37.497881821223665, 36.483601161411826, 36.90100724356515, 38.51872158050537, 37.93231098992484, 36.50766624723162, 36.46476806913103, 35.83020298821585, 37.86869328362601, 38.585670948028564, 41.02587134497506, 43.622159549168174, 43.59451961517334, 42.59980508259365, 43.951525006975444, 44.36081559317452, 42.509051186697825, 40.18255805969238, 41.624614988054546, 44.97076668058123, 43.10873631068638, 40.30620125361851, 38.26818690981184, 20.762058121817454, 2.648680010012218, 2.0635300832135335, 3.0005817328180586, 2.3117394958223616, 3.6582886576652527, 6.384337076119014, 5.552136131695338, 1.0360232016869952, 0.5760258021099227, 0.08826312954936709, 0.04145589085029704, 20.250364984784806, 39.9882447378976, 17.692158120019094, 38.720274925231934, 6.683767088821956, 0.08163992887628929, 0.014549073231007372, 0.0632158439340336, 0.06347687635570765, 0.01557229895011655, 0.044005513324269226, 0.06273139028676919, 0.08830013006393399, 0.06369444860943727, 0.06567164537097726, 0.03417451460180538, 0.06800628080964088, 0.023408928886055946, 0.06715968623757362, 0.01898582372814417, 0.05169704702815839, 0.058372040279209614, 0.0442805405307029, 0.0749238571152091, 0.02966202263321195, 0.05336145610947694, 0.02640445573654558, 0.10266964935830661, 0.1576689566884722, 0.08085484350366251, 0.1160780441548143, 0.24786924943327904, 0.23337745134319576, 0.13796663390738623, 0.20119472539850644, 0.10427053738385439, 0.1782994068094662, 0.15556034126452037, 0.08039746340364218, 0.15322699504239218, 0.14591253681906632, 0.11446864051478249, 0.05581393951017942, 0.10501517528401953, 0.1769458922956671, 0.11885934562555381, 0.16371247810976847, 0.11374135954039437, 0.2631302076791014, 0.09347894681351525, 0.11275719199329615, 0.14657786754625185, 0.1993400449199336, 0.1011415206428085, 0.15905006043612957, 0.309098268193858, 21.657427310943604, 50.77408627101353, 26.747979845319474, 51.171259198869976, 22.224752937044414, 0.13259817340544292, 0.29721242455499514, 1.1340012699365616, 7.301462377820696, 12.393643396241323, 26.31945664542062, 19.489360060010636, 4.03323038986751, 2.6443532364709035, 0.4873678737453052, 1.4269581671272005, 11.881760920797076, 29.512563841683523, 45.01059375490461, 48.117258412497385, 46.598601068769185, 52.95999302182879, 52.29623508453369, 51.70685066495623, 46.05436256953648, 43.407672132764546, 42.56337915148054, 46.54720524379185, 50.50635133470808, 51.80638360977173, 50.06383793694632, 51.25989389419556, 49.969422340393066, 50.17006547110421, 52.19276251111712, 50.76189913068499, 46.627265862056184, 40.83090141841343, 39.067167213984895, 41.28970834187099, 46.669267722538535, 47.38871547154018, 49.210421970912385, 43.18284927095686, 40.78892387662615, 39.19807822363717, 40.37296996797834, 37.05265515191214, 38.46254539489746, 37.85264989307949, 38.34268549510411, 40.59964452471052, 41.86376850945609, 43.14668389729091, 45.051181656973704, 43.25204290662493, 44.405676637377056, 47.70199932370867, 52.18118681226458, 48.52870294025966, 50.95828996385847, 43.7025363104684, 44.521072319575715, 47.403313636779785, 45.58621031897408, 45.19324452536446, 47.103464126586914, 43.942606994083945, 44.81752416065761, 41.75090544564383, 49.57287127631051, 48.05515193939209, 48.28878164291382, 42.93605620520455, 36.808095932006836, 36.792076860155376, 35.44758653640747, 35.7174927847726, 36.63098982402256, 36.89173139844622, 38.54987382888794, 41.588161264147075, 40.52816145760672, 40.728352955409456, 37.478409494672505, 39.029462814331055, 37.64131695883614, 39.65834774289812, 40.53800010681152, 39.71844271251133, 38.18703889846802, 38.359705107552664, 38.006597655160085, 40.56065123421805, 40.46014206750052, 43.85770695550101, 44.13900130135672, 43.42886413846697, 44.263697147369385, 44.56265033994402, 46.21991729736328, 45.30987351281302, 42.53664595740182, 43.403381620134624, 45.898625646318706, 43.0463866506304, 43.432588372911724, 40.64110442570278, 19.84829878807068, 3.6329943920884813, 2.667427118335451, 4.243554966790335, 6.551145953791482, 7.4756137643541605, 10.406303133283343, 15.883399588721138, 10.012439285005842, 0.8932229014379638, 0.23658825191003935, 0.22386097056525095, 26.42559732709612, 40.616910798209055, 23.598566395895823, 47.316600118364605, 8.34685012272426, 0.3250337445310184, 0.1499877774289676, 0.20127586461603642, 0.08366425668022462, 0.09595276335520403, 0.1280718698565449, 0.1512798573821783, 0.17050200807196753, 0.1451646283801113, 0.15857884500707897, 0.14808927715889045, 0.13171368943793432, 0.09637196228972503, 0.10874795927000896, 0.16528849782688276, 0.1113584056230528, 0.1262204870581627, 0.11939297270561967, 0.12032933746065412, 0.11828892837677683, 0.08718887290784291, 0.16658745812518255], [0.03223125816189817, 0.01932784608964409, 0.023606772734118358, 0.02068135721076812, 0.04161482071503997, 0.028716881027711288, 0.04489289463630744, 0.04122913462509002, 0.018850547594151328, 0.04470241289319737, 0.016625833132171204, 0.026962676318362355, 0.016492109147033522, 0.06712719119553055, 0.03987266509128468, 0.023762817128694484, 0.03579849995938795, 0.0405315225943923, 0.013553111897116261, 0.006581884251707899, 0.02547697809391788, 0.06434931632663522, 0.05619380037699427, 0.021675204059907367, 0.023460458531709652, 0.026042693095015626, 0.03222056445000427, 0.062211754598787854, 0.16154002611126217, 2.6728619124208177, 32.69327197756086, 30.00238404955183, 39.04846613747733, 33.296128954206196, 1.137064774121557, 0.04809137300721236, 0.14786823759121553, 0.13311987183988094, 1.9614810219832828, 5.699396686894553, 14.751067297799246, 3.6401375745024, 1.5429395607539584, 0.7583318767803056, 0.5379060304590634, 3.4878493462290083, 16.147311278751918, 32.392585209437776, 47.31123958315168, 49.171953269413535, 49.69496154785156, 47.8388614654541, 47.543705463409424, 42.731000968388145, 41.02043437957764, 40.96157618931362, 45.92761353084019, 47.70129755565098, 48.528223514556885, 47.41135965074812, 47.92138522011893, 47.0423720904759, 49.70024217878069, 49.1872010912214, 46.328729561397004, 42.82140745435442, 34.45229877744402, 34.9052448953901, 35.63852303368704, 42.29022809437343, 43.15396213531494, 44.94959551947457, 43.29975618634905, 41.2903163092477, 37.18417065484183, 35.754349504198345, 34.976158210209434, 34.75563975742885, 33.07400894165039, 36.0715069770813, 33.60582753590175, 36.79023558752877, 32.951182161058696, 35.21787214279175, 42.038161345890586, 36.792177609034944, 42.53021192550659, 47.47153452464512, 46.98857913698469, 46.24794980457851, 41.427411215645925, 48.09171336037772, 45.72083861487252, 45.18136657987322, 46.8922632081168, 49.24039997373308, 49.86661679404122, 48.22979491097586, 47.0068633215768, 46.4515563419887, 46.65618773869106, 43.78412205832345, 34.865292753492085, 31.85584729058402, 32.58327504566738, 34.05104725701468, 32.96318517412458, 33.986953599112375, 33.57899011884417, 33.97096579415457, 38.32507528577532, 36.12096772875105, 34.28679616110665, 34.05973597935268, 32.46015991483416, 33.70837599890572, 32.90202365602766, 33.33368049349104, 34.078044482639854, 34.80389847074236, 34.35213354655674, 37.3273035458156, 36.11736856188093, 37.340459959847585, 39.392398493630544, 41.21533829825265, 42.623838901519775, 42.05646290097918, 42.86344058173043, 42.322540691920686, 42.10568741389683, 44.11223684038435, 43.517801080431255, 43.191319125039236, 38.795926911490305, 39.419572898319785, 24.590762206486293, 4.358112522533961, 0.23392996883818082, 1.569295055099896, 2.070398811783109, 1.9242388946669442, 2.3509416665349687, 4.843606608254569, 2.9925140057291304, 0.18761532620659896, 0.29345119638102396, 0.040106009891522784, 1.3892091470105308, 30.182714121682302, 28.639121430260793, 27.43755555152893, 22.969935076577322, 0.3587501767490591, 0.09322486259043217, 0.06312388886830636, 0.029451123771390746, 0.0716556321297373, 0.047350952202188115, 0.015315637990300144, 0.024804344633594155, 0.016224069154954383, 0.10718043481132813, 0.021515144434358393, 0.012464505936285215, 0.061106366770608087, 0.03972765197977424, 0.029229792433657815, 0.028355886827089956, 0.02507093595340848, 0.00788612652104348, 0.022914919769391418, 0.005021524274655218, 0.07123577501624823, 0.036169071681797504, 0.0674136754657541, 0.026802192608426725, 0.03996829103146281, 0.016103722487709353, 0.014523865655064583, 0.02948029738451753, 0.013030149691206003, 0.03842679178342223, 0.07975241408816405, 0.026060309560437287, 0.02837259914459927, 0.022520260053819845, 0.023792957654222846, 0.03736871820209282, 0.039879816850381236, 0.06176308010305677, 0.01345796262778874, 0.046097131446003914, 0.10910265666565724, 0.05340505537710019, 0.04973214871383139, 0.018404549919068813, 0.04261260645996247, 0.01678242883644998, 0.03963913030124136, 0.021627633666087474, 0.038872633395450454, 0.048113883406456025, 0.0648825837831412, 0.1724804261965411, 3.94122234412602, 42.08352266039167, 25.220812695366995, 42.67198991775513, 37.555902753557476, 0.8793266671044486, 0.0360692693585796, 0.08431536531341927, 0.31349843208278927, 1.3801524958440234, 8.31909728050232, 17.76996578489031, 4.022933159555707, 4.375547289848328, 1.0932943799665995, 1.2799792311021259, 5.281814294201987, 17.517798287527903, 34.31547137669155, 48.53517518724714, 48.45132780075073, 52.7392452784947, 50.157534394945415, 49.20524903706142, 43.044837202344624, 41.846547399248394, 43.088030678885325, 46.69898516791207, 49.64296122959682, 49.9163624218532, 48.14881713049752, 49.319894313812256, 48.48917463847569, 50.00181484222412, 52.085544858660015, 49.80071660450527, 43.90602820260184, 37.07634156090872, 36.59251764842442, 37.9085134097508, 44.17918620790754, 45.111439909253804, 46.4880621773856, 45.261267389569966, 42.71992553983416, 38.97295658929007, 37.26625319889614, 36.57317386354719, 35.9410788672311, 35.818064485277446, 36.99397414071219, 36.00583607809884, 38.938729763031006, 35.70930085863386, 37.118482385362896, 42.28774411337716, 38.01514393942696, 45.55743782860892, 49.509611402239116, 47.75797748565674, 49.32979202270508, 42.14051873343331, 45.44142375673567, 46.10866274152483, 44.745648520333425, 48.41234145845686, 50.04440035138811, 50.54622704642159, 49.16581106185913, 47.54764856610979, 47.24202857698713, 47.332070282527376, 45.29977430616106, 36.90581539699009, 33.65761593409947, 34.25794376645769, 34.77184643064226, 34.3477075440543, 35.44985164914812, 35.836852414267405, 35.352278096335276, 38.16266809191023, 37.75773402622768, 36.081039905548096, 35.388516426086426, 34.41353130340576, 35.593658515385215, 34.411200182778494, 35.53220864704677, 37.477363790784565, 36.398100103650776, 35.176332337515696, 38.41795533043997, 37.302984850747244, 39.16157933643886, 41.330417837415425, 43.46347311564854, 44.09985862459455, 44.36485597065517, 43.41321332114083, 42.156551701681956, 44.034062658037456, 43.551270553043906, 44.595352036612375, 43.18715020588466, 39.6456811768668, 41.447571413857595, 29.118658304214478, 5.5962784716061185, 1.0445485327925002, 4.173021631581443, 3.322424679994583, 2.946760335138866, 3.555797300168446, 6.453854671546391, 2.1671007999352048, 0.5676950205649648, 0.25555127007620676, 0.021954014099070003, 0.9723103919199535, 35.518267086574006, 30.16871002742222, 23.700249808175222, 31.490267821720668, 0.9289276855332511, 0.05557921728385346, 0.022441556777006814, 0.023879248648881912, 0.07450236473232508, 0.053313076562647305, 0.01720750388423247, 0.0384658652224711, 0.0488622736052743, 0.052504612265952995, 0.047257416149867434, 0.06317733707172529, 0.014679496143279331, 0.031371737497725656, 0.04754836857318878, 0.02672287865009691, 0.019278835505247116, 0.015411655784451535, 0.012814115167462399, 0.05019319968830262, 0.04006381179871304, 0.03533314707289849, 0.04415350181183644, 0.0837490057040538, 0.13994689764721052, 0.15590357141835348, 0.09436037058808974, 0.17121391344283307, 0.12671025363462313, 0.14609788544476032, 0.1788034090506179, 0.09163589642516204, 0.11620915069111756, 0.10399091988801956, 0.11594425061983721, 0.10360203789813177, 0.12220354617706367, 0.17135130321340902, 0.11790198699704238, 0.1396948897412845, 0.19342691078782082, 0.20753611012228898, 0.13282928243279457, 0.0363766626854028, 0.15343405678868294, 0.08859072625637054, 0.20445526258221694, 0.14139981754124165, 0.17182007591639245, 0.2022528736186879, 0.12973912539226667, 0.22596255636640958, 5.317988353116172, 47.59404863630022, 36.57507072176252, 46.91858993257795, 44.74706595284598, 1.9247452446392603, 0.19619717927915709, 0.5365029286061014, 0.855684335742678, 7.24502910886492, 14.23092862537929, 24.4259318283626, 9.763943910598755, 5.493231909615653, 1.9159509965351649, 1.766069450548717, 4.474610796996525, 17.944806780133927, 34.056077752794536, 51.178787572043284, 51.10015828268868, 54.712606634412495, 52.74551255362374, 53.273054531642366, 45.973958015441895, 45.6189398084368, 45.84008012499128, 50.93534006391253, 52.31419617789132, 52.020263058798655, 49.8773204939706, 50.806916509355815, 49.775355679648264, 52.5500145639692, 53.77427673339844, 52.63050249644688, 46.99146611349923, 38.13577856336321, 37.97908626283918, 38.7644932610648, 46.30703033719744, 46.99467270714896, 49.28429521833147, 47.829894815172466, 46.47849798202515, 40.34367983681815, 40.186084270477295, 39.84406961713518, 37.18898923056466, 37.18357310976301, 39.3986553464617, 37.271085671016145, 40.62427936281477, 36.207608291081016, 38.897679805755615, 45.48613888876778, 38.84908757890974, 47.141922405787874, 51.904565129961284, 49.82229423522949, 50.09213100160871, 45.17096512658255, 46.72520766939436, 45.842987946101594, 47.816585540771484, 49.97733286448887, 51.871578557150706, 51.85155732291085, 50.98629467827933, 51.66095781326294, 50.327838216509136, 48.35027320044381, 47.64992952346802, 38.50476959773472, 35.24294124330793, 35.52682031903948, 36.73482370376587, 36.534263951437815, 37.124596800122944, 36.957523890904014, 37.16411815370832, 40.07907158987862, 38.278216634477886, 37.653007302965435, 37.53564180646624, 35.87074225289481, 37.58288260868618, 36.43627003261021, 36.84833295004708, 37.970057078770225, 38.033007758004324, 37.2774259022304, 40.4604686328343, 38.751104082380024, 40.74408367701939, 42.70439631598336, 45.78963620322091, 45.54886375154768, 45.15067638669695, 43.842646735055105, 44.601473399571006, 45.12211234228951, 45.21246324266706, 45.14336688177926, 44.97191660744803, 43.825651441301616, 42.5980715070452, 26.91975842203413, 6.084204426833561, 1.0236970973866326, 4.5133878248078485, 7.842106921332223, 4.83797596182142, 7.189529938357217, 12.16415742465428, 8.091220685413905, 2.60337666954313, 1.171652906707355, 0.12778396744813236, 2.4660609407084326, 40.36903728757586, 37.23993689673287, 35.26954936981201, 36.21574115753174, 1.1913940416915076, 0.2582585705178124, 0.12085944972932339, 0.11818816592650754, 0.1910903618804046, 0.12486796320549079, 0.25481131406767027, 0.11750935949385166, 0.12536283236529144, 0.190854598102825, 0.22304953767785005, 0.14527357396270546, 0.12551829830876418, 0.09041669791830437, 0.08655243420175143, 0.1608688464122159, 0.12232960441282817, 0.10709714463778905, 0.14132585722420896, 0.18623184758637631, 0.18302666528948716, 0.1664757848318134, 0.135630994236895], [0.01959004728788776, 0.014640702599925655, 0.017039137293717692, 0.011672468124223607, 0.009103738952295055, 0.042735923414251635, 0.04726454755291343, 0.009739783259906938, 0.021277417994237373, 0.029611861931958368, 0.027480442642367313, 0.02574300792600427, 0.03415282183725919, 0.040937971855912886, 0.015809647106964673, 0.05391766483496342, 0.04502416741369026, 0.024577048973047307, 0.03455184792567577, 0.05592289187812379, 0.03416600237999644, 0.09242518192955426, 0.1340183336287737, 0.04445287485473922, 0.02497427355098937, 0.029388057334082465, 0.06957513519695827, 0.013085777688372349, 0.04052034712263516, 0.11631847625332219, 15.603553942271642, 34.578450271061485, 19.84807644571577, 38.212434564317974, 11.329579762050084, 0.04589874137725149, 0.12912912241050176, 0.06478126493415662, 1.4082124701568057, 3.182282554251807, 6.31270158290863, 4.930986719472068, 3.3807548071656908, 1.0752870376620973, 0.9844721278973988, 1.5542046534163612, 4.960772778306689, 19.48462312562125, 41.79869515555245, 47.85840327399117, 50.624984877450125, 47.47403587613787, 47.436498233250205, 42.71629163197109, 41.438438006809776, 42.89112915311541, 47.36478240149361, 48.47660534722464, 49.543782642909456, 47.386214120047434, 48.23555844170706, 48.245445728302, 48.42194734300886, 46.74725430352347, 48.68506520135062, 45.478645256587434, 35.171218463352744, 35.27074098587036, 36.873850209372385, 43.008102076394216, 43.431337697165354, 45.74308327266148, 44.8010048185076, 44.05638722011021, 38.99259219850813, 35.10352911267962, 36.883112158094136, 35.9770496913365, 35.58326053619385, 33.71774217060634, 35.34797021320888, 34.68622030530657, 35.427290848323274, 34.92158358437674, 37.31937912532261, 38.525325843266074, 41.372513498578755, 45.45913471494402, 47.95921121324812, 47.643161978040425, 41.95810767582485, 49.470343657902305, 47.763720171792166, 50.54349293027605, 47.295772893088206, 47.48102576392037, 46.564197063446045, 46.700902870723176, 46.12546348571777, 45.54301684243338, 45.94664464678083, 37.66096646445138, 33.424427441188264, 33.8423615864345, 32.750274998801096, 31.950961181095668, 33.2995057787214, 35.115174293518066, 33.57111086164202, 33.98575850895473, 34.25705787113735, 33.55934061322893, 33.43096569606236, 32.88565370014736, 33.68314708982195, 31.429891450064524, 32.09584501811436, 31.48735305241176, 32.017059394291465, 33.486297675541465, 34.59055403300694, 36.36176102502005, 39.26881435939244, 41.339731897626606, 42.52807535443987, 42.217984199523926, 44.52219097954886, 42.34853042875017, 41.237916469573975, 40.145472049713135, 41.13356842313494, 39.33335617610386, 40.633631638118196, 38.65517030443464, 41.010356017521445, 25.114260332924978, 4.550449516092028, 0.2540248105568545, 0.9408467773880277, 2.454798562186105, 1.9040860789162772, 1.7935355710131782, 1.6201041915587016, 4.937257034437997, 0.8024009349090713, 0.13344939558633737, 0.039343523127692084, 0.05751842286969934, 6.494786075183323, 39.5268600327628, 19.854857887540543, 33.719996861049104, 10.119175774710518, 0.09319458635790007, 0.015377857955172658, 0.039631286436425786, 0.018150094198063016, 0.10368276320930038, 0.07177736131208283, 0.09049853602690355, 0.031803485937416553, 0.054147681420935054, 0.018610578595793674, 0.0407297260660146, 0.007263140619865486, 0.02475539511734886, 0.04627600684762001, 0.006154835939274302, 0.012501663362075175, 0.07613938474761588, 0.02344998873637191, 0.012111473495938947, 0.06285409655954156, 0.11291965363281113, 0.06367220623152596, 0.0910596844873258, 0.027996102115139365, 0.009284585498140326, 0.0657528049445578, 0.023068882757797837, 0.07005322418574776, 0.04925299442506262, 0.02649923350795039, 0.029077451143945967, 0.032100952296916924, 0.04334953620231577, 0.00169857194123324, 0.013208868181599038, 0.051182096624480825, 0.06041550277067082, 0.03858475134308849, 0.05259978019499353, 0.0574569475970098, 0.024130864700834666, 0.01584111586479204, 0.030447932425886393, 0.013475015060976148, 0.11229578818061522, 0.03644144242363317, 0.047217307944915125, 0.027930078961487328, 0.047954122336315255, 0.022750449666221226, 0.04448072532457965, 0.036776879602777104, 0.32312475410955294, 24.251716170992168, 37.565223761967246, 28.644855431147985, 51.433762141636436, 10.092594572475978, 0.03510864697662847, 0.21336651726492814, 0.03390178423640983, 0.4166594222187996, 1.8002587131091525, 15.701214347566877, 8.192868488175527, 3.2366059592791965, 2.895589675222124, 2.2184375652245114, 2.385959718908582, 6.909364674772535, 22.342910528182983, 44.144448689052034, 50.22243056978498, 52.39034148624965, 50.70197091783796, 48.468264034816194, 44.40630544934954, 41.89698089872088, 45.51935127803257, 48.401206970214844, 50.984783445085796, 51.27627774647304, 49.016115597316194, 49.48492097854614, 49.81630836214338, 48.74844666889736, 49.019068581717356, 49.90459564753941, 46.581379958561485, 36.23109320231846, 36.12322241919381, 38.94093929018293, 43.50671175548008, 45.427343232291086, 46.90107699802944, 45.78097527367728, 45.815462657383506, 41.12657853535244, 36.41726323536464, 37.32394061769758, 37.69589505876814, 37.17323071616036, 35.713754653930664, 37.428208759852815, 36.398054940359934, 35.91485289164952, 37.44303274154663, 40.58449745178223, 39.090756348201204, 43.57778835296631, 46.75735003607613, 49.77631453105381, 50.639812333243235, 42.440913677215576, 47.983887740543906, 49.90322685241699, 52.51328986031668, 49.369139671325684, 49.65435627528599, 48.57560675484793, 48.51273945399693, 48.44664124080113, 47.4109844480242, 47.031862940107075, 39.54837165560041, 35.94685629435948, 35.129775932856965, 33.043106828417095, 33.228185994284495, 34.52603653499058, 36.17537907191685, 35.459217820848735, 36.45755583899361, 36.24564273016793, 35.0546624319894, 34.60298088618687, 33.14751393454415, 34.33174058369228, 33.162883349827354, 32.88668203353882, 33.89661659513201, 34.23345136642456, 34.17648656027657, 36.81710079738072, 38.35930906023298, 39.99119424819946, 41.54869202205113, 43.32296664374215, 43.452870164598735, 44.63902841295515, 42.87009348188128, 41.737266131809776, 40.81730726787022, 41.25462341308594, 40.5626106262207, 41.75330604825701, 39.868381364004954, 41.79058313369751, 28.41506460734776, 7.17230578831264, 0.6143339893647602, 1.9347621585641588, 4.336260003702981, 4.690990728991372, 3.9998955386025563, 4.574839864458356, 5.860105046204158, 0.9461135119199753, 0.1794529434825693, 0.07693324357803379, 0.03804329736158252, 6.533104087625231, 44.76999500819615, 22.55553582736424, 36.28896822248186, 15.82941382271903, 0.06290690015469279, 0.0457215182084058, 0.024337941714163338, 0.046073297903473885, 0.06396451911755971, 0.04243935950632606, 0.046348749194294214, 0.017094599049804465, 0.03921230124043567, 0.016707313313548054, 0.006998550554271787, 0.0024388488756293164, 0.03686537413990923, 0.008626388718507119, 0.02959864746247019, 0.044223394311432324, 0.0385914722324482, 0.015188029302018029, 0.015273964065792305, 0.029689713647322993, 0.06365195196121931, 0.02081853324281318, 0.027672909100406935, 0.10822337706174169, 0.1242161760372775, 0.12460413521953992, 0.15025457739830017, 0.1543009259871074, 0.08959453739225864, 0.12832326708095415, 0.13719963149300643, 0.0765449112015111, 0.10225062684289046, 0.12359196453222207, 0.11678237707487174, 0.11912154512745993, 0.17494487895497254, 0.10310973360070161, 0.22882176722799027, 0.13240730150469712, 0.10131899826228619, 0.08546925482473203, 0.14911473356187344, 0.11341880434857947, 0.25237816891499926, 0.19792643934488297, 0.10207717972142355, 0.18496956889118465, 0.13886205585939543, 0.19073128114853585, 0.10686636130724635, 0.16634978087885038, 0.5463664393339838, 29.67820542199271, 47.39142179489136, 29.827886990138463, 50.60335166113717, 16.75533424104963, 0.14982564827161177, 0.4878354657973562, 0.3772119203848498, 3.5317391625472476, 10.6252486876079, 18.731662477765763, 12.760976416724068, 9.718775408608572, 4.412833494799478, 4.053681543895176, 2.767577584300722, 6.9878241675240655, 22.15214252471924, 44.78267894472395, 51.18067053386143, 54.686578682490754, 51.196845940181184, 50.63251672472273, 47.06174366814749, 44.95601565497262, 47.97679015568325, 51.683720111846924, 53.5945268358503, 53.9940447807312, 48.571253708430696, 52.5012138911656, 51.112876960209434, 50.942920548575266, 49.377783230372835, 53.15294449669974, 48.64834744589669, 38.53982325962612, 39.31578070776803, 40.66776466369629, 46.89568519592285, 46.46988568987165, 48.84861189978463, 47.330208165305, 47.684493337358745, 43.51532752173287, 39.22099685668945, 39.99100317273821, 38.81884554454258, 39.08143186569214, 35.99137340273176, 38.8900819505964, 38.09332159587315, 38.50927203042166, 39.39086294174194, 42.1539808682033, 41.47712557656424, 45.42763505663191, 49.07899679456438, 50.37852879932949, 53.0140951701573, 45.80597489220755, 50.47664431163243, 50.28764288766043, 53.534247738974436, 51.50823988233294, 51.52973760877337, 50.67350762231009, 49.66642877033779, 49.999004295894075, 48.51259354182652, 49.31573234285627, 40.28750712530953, 36.91958325249808, 37.51429346629551, 35.35083981922695, 34.29487691606794, 36.901316438402446, 38.18178606033325, 36.54063197544643, 37.44954667772566, 38.6698761667524, 36.45662478038243, 37.07882901600429, 34.588879517146516, 35.34528473445347, 33.143668106624055, 34.77295119421822, 34.96968943732125, 36.422589029584614, 35.95374195916312, 38.511238370622905, 39.914249897003174, 42.565595626831055, 43.53725951058524, 45.996838433401926, 44.8016232081822, 45.72458369391305, 44.4601400920323, 41.666658537728445, 42.127490861075266, 42.59348569597517, 41.582776410239084, 43.94804743358067, 40.95302643094744, 42.19031299863543, 26.000510011400493, 6.258102204118456, 0.5156275002019746, 1.538274062531335, 5.176744503634317, 4.7417625188827515, 5.756852209568024, 6.804406489644732, 13.855764985084534, 4.166363086019244, 1.060673890369279, 0.5534478479198047, 0.14602803704994066, 9.998445613043648, 50.97503512246268, 27.00690793991089, 43.798424925122944, 17.116829906191143, 0.12934127316943236, 0.15475531374769552, 0.0877483453867691, 0.12862554086106165, 0.2943119044814791, 0.14326003486556665, 0.2195776096944298, 0.1383474820426532, 0.1215316065187965, 0.15852574285651955, 0.07242159638553858, 0.10673838281737906, 0.25179872715047424, 0.1539602471249444, 0.09454822979335274, 0.14164719783834048, 0.18159718199500016, 0.1633038914629391, 0.09001416380384139, 0.12288402180586543, 0.24109470152429172, 0.23131155648401805, 0.2006083218646901], [0.01596459057847304, 0.008927067093152021, 0.03275532807622637, 0.00855088812698211, 0.04005688056349754, 0.02446171159057745, 0.014920150462005819, 0.05061395586069141, 0.02934967600075262, 0.04356793626876814, 0.07250910026154347, 0.055159970851881165, 0.06774296851030417, 0.045006634068808386, 0.06462824171675102, 0.021522587963512967, 0.035731691401451826, 0.01720672526529857, 0.020506458024361303, 0.04041768816698875, 0.059591720545930524, 0.011488042306154966, 0.022778878587165048, 0.018321356436769878, 0.049627800205988545, 0.04010423891512411, 0.023515396119494523, 0.010644379005368267, 0.03457359836569854, 0.040284610486456325, 5.165449338299887, 36.8208771433149, 22.33037771497454, 31.040351118360245, 31.2964061328343, 1.2705832038606917, 0.029684190372271196, 0.18313304600971086, 0.1281016846852643, 0.8692800604871341, 5.233353214604514, 5.628583252429962, 2.4740715622901917, 0.8788519640054021, 1.0501611573355538, 0.9781239713941301, 1.0832622668572833, 10.632737108639308, 30.53216334751674, 50.61362109865461, 50.758671692439485, 51.152592863355366, 47.985079356602256, 45.473903111049104, 44.19537551062447, 46.21226733071463, 49.39212431226458, 49.192363602774485, 49.04228598730904, 47.190622329711914, 46.62265920639038, 49.5113137108939, 47.860286235809326, 49.66654688971383, 48.36343308857509, 44.50687020165579, 39.71266181128365, 37.06934472492763, 36.8829071862357, 39.95417077200753, 44.127453395298545, 43.99466289792742, 46.44053302492414, 46.76996796471732, 44.36265686580113, 38.7096129144941, 34.74401542118618, 35.90015050343105, 35.73172616958618, 35.365114893232075, 36.41834715434483, 35.161814076559885, 37.37868547439575, 40.31360803331648, 40.4803717476981, 41.499741962977815, 46.48217705317906, 48.10656860896519, 48.74993358339582, 46.709324087415425, 43.57337277276175, 48.98547056743077, 47.62920304707119, 45.816431931086946, 46.54042727606637, 46.70682621002197, 45.7387649672372, 44.86019652230399, 46.16006898880005, 42.74757589612688, 36.70711428778512, 33.52333852222988, 34.45407404218401, 34.186120237622944, 33.27320684705462, 34.26087243216378, 34.3663078716823, 33.32628413609096, 31.977979251316615, 33.66406386239188, 35.54243639537266, 38.25282096862793, 40.95544787815639, 40.022144998822895, 40.33323322023664, 37.57365540095738, 34.22363703591483, 32.941148962293354, 31.77443872179304, 31.350942543574742, 35.61939811706543, 37.02865259987967, 40.06965330668858, 42.66195671898978, 42.18555695669991, 44.683621951511924, 42.46378019877842, 41.026468890053884, 43.07801832471575, 42.58919865744454, 41.2146052633013, 40.86418676376343, 40.365861960819785, 39.169385637555806, 26.795986686434063, 4.798339094434466, 1.2841882109642029, 0.39314527969275204, 2.851657518318721, 6.2246448908533365, 1.8204944729804993, 2.349826914923532, 3.3201834516865865, 3.499099782535008, 0.5981021832142557, 0.16819652249770506, 0.04646834438400609, 0.1028717238722103, 19.76912406512669, 34.25423690250942, 17.89200915609087, 29.17111199242728, 2.657638192176819, 0.077958381069558, 0.01237185113132, 0.005544464852261756, 0.07721590091075216, 0.042066331487149, 0.021079994837886522, 0.03379697432475431, 0.03935674098985536, 0.09011331812611648, 0.02167672397834914, 0.07645527672554765, 0.013174174686095544, 0.038341676350682974, 0.03091154487005302, 0.04408386376287256, 0.014674030543704118, 0.01981204528627651, 0.07211295794695616, 0.04717538805146303, 0.04347768771861281, 0.0702575310798628, 0.026031811089654053, 0.004539486636141581, 0.07701500704778091, 0.013510795060678251, 0.02782120292873255, 0.021304326996739422, 0.0226284694259188, 0.02772023861429521, 0.00398072661898498, 0.013906479364127984, 0.04446452869368451, 0.009871547975178276, 0.055625076073088815, 0.029573426315827028, 0.0193493030632713, 0.05049632163718343, 0.016244440472551754, 0.02225444226392678, 0.035611360001244714, 0.05091786830286894, 0.03534946584009698, 0.016285931192604557, 0.010202799441425927, 0.05660643448520984, 0.012596503049800438, 0.00835310704340892, 0.020299374225682447, 0.026419729559815357, 0.019917940853961875, 0.03193558992019721, 0.02321802475489676, 0.05537611139672143, 9.121550815446035, 45.06224666322981, 21.094633647373744, 39.90409163066319, 34.18888562066214, 0.5435458506856645, 0.047152806406042407, 0.03028961324266025, 0.06204497069120407, 0.5538346128804343, 3.6509695989745, 3.9967944707189287, 5.178956636360713, 5.622579140322549, 2.3389647092138017, 1.8145140281745364, 1.6418659495455878, 11.288325701441083, 32.93350941794259, 52.41509444372994, 51.32670777184622, 53.46135418755667, 48.51297221864973, 47.13417516435896, 45.476699760981965, 49.35506956917899, 51.048831939697266, 50.49474784306118, 49.39269406454903, 47.903441497257774, 47.00462252753121, 49.70959792818342, 47.91678898675101, 50.87582874298096, 51.29050765718733, 46.683521951947895, 40.87854521615164, 38.97811910084316, 37.73216118131365, 42.94235822132656, 44.5718879699707, 48.28861141204834, 49.1226419040135, 48.61738279887608, 45.75755289622715, 40.504481996808735, 35.946091992514475, 37.7657869883946, 37.002589906964985, 36.87143571036202, 37.777525969914024, 36.175476346697124, 37.81220095498221, 39.774671009608674, 40.64050688062395, 43.11497926712036, 46.28518867492676, 49.31638894762312, 50.48996748243059, 48.24353149959019, 45.44103813171387, 49.56607941218785, 50.61006014687674, 47.99217346736363, 46.849375452314106, 48.12428651537214, 47.90029048919678, 46.35043225969587, 47.3885452406747, 44.160922867911204, 40.352545738220215, 35.33095407485962, 34.669530732291086, 34.4577704838344, 34.78563513074602, 35.99755729947771, 34.232117312295095, 34.645979813167024, 33.36477715628487, 36.05079787118094, 36.264976092747276, 38.40857873644148, 41.556029319763184, 41.128385066986084, 39.643892015729634, 38.70588868004935, 35.02466011047363, 33.16690288271223, 33.47237695966448, 33.16993229729788, 35.78699214117867, 39.46710899897984, 41.23725986480713, 43.07285928726196, 43.73469257354736, 43.9659355708531, 43.72091082164219, 43.5276779447283, 42.306153365543906, 42.92539766856602, 42.428691795894075, 41.44805431365967, 41.04711546216692, 39.74261202130999, 31.16526930672782, 6.943407373768943, 2.2736572878701344, 1.5966273141758782, 2.1418078371456692, 5.406359885420118, 7.12482179914202, 6.667287264551435, 5.159040927886963, 2.495658095393862, 0.1423232222774199, 0.21399564136351856, 0.0835224903587784, 0.1753348330301898, 19.986050299235753, 41.31504842213222, 17.713562045778545, 34.91668510437012, 4.38928040436336, 0.1277887171932629, 0.03359539853408933, 0.02215006322200809, 0.04394877761868494, 0.05259731032752565, 0.07167396614594118, 0.03376824515206473, 0.0438799164923174, 0.06404808070510626, 0.02522276494918125, 0.06846484834594385, 0.04243230613480721, 0.07128136578415122, 0.031312396217669757, 0.05636571400931903, 0.01873578696644732, 0.05411068429904325, 0.09659501710640532, 0.036890062636562755, 0.019582362878801565, 0.056885929844741306, 0.0225561019698424, 0.031945421892617426, 0.14047065882810525, 0.07457112068576471, 0.08767748597477164, 0.1253005564212799, 0.1393386452857937, 0.056219140267265696, 0.15159766961421284, 0.0775612752352442, 0.1145324499479362, 0.18039644642599992, 0.10736144081290279, 0.13198081510407583, 0.2911325879395008, 0.15662508484508308, 0.1528306763087, 0.1807246402438198, 0.14899533853999206, 0.126519042466368, 0.1400915884545871, 0.12634665385953017, 0.1291035959231002, 0.12089770553367478, 0.0883976151900632, 0.06414976596300091, 0.1472470387816429, 0.1094219209626317, 0.22213222618613923, 0.09987648031009094, 0.10287425480782986, 0.15139353913920267, 11.646084104265485, 53.05249091557094, 29.4700026512146, 40.458252157483784, 40.9320706639971, 2.325574662004198, 0.10783936016793762, 0.3935224637389183, 0.17883618229201861, 1.926464055265699, 12.125252723693848, 13.22571883882795, 6.760792647089277, 5.459113214697156, 5.289991455418723, 3.25873401761055, 1.8801443236214774, 11.975558996200562, 34.52453919819423, 54.44141149520874, 54.00291763033186, 56.64475475038801, 52.41959340231759, 50.10601002829415, 47.87623235157558, 51.05081565039498, 53.60486575535366, 53.39970282145909, 50.481643540518625, 48.82998725346157, 48.57056931086949, 51.68916055134365, 49.36573157991682, 52.93813746316092, 53.645936557224815, 48.12533221926008, 44.06718472072056, 40.35693005153111, 39.74431085586548, 44.2860495022365, 47.010716097695486, 49.31364093508039, 52.424616949898855, 50.49020024708339, 49.10975994382586, 42.25204426901681, 37.45963198798043, 39.4990359715053, 39.566044398716514, 39.47486318860735, 40.17566544669015, 38.291129861559185, 40.47190189361572, 44.131837708609446, 43.68335580825806, 45.55888305391584, 50.80759743281773, 52.04793773378645, 53.61058759689331, 48.37367820739746, 47.311583518981934, 50.715839522225515, 51.933024951389854, 48.467503207070486, 50.02238845825195, 50.924688475472585, 49.61594663347517, 48.658953871045796, 49.79687425068447, 46.07336589268276, 40.51232303891863, 36.54725360870361, 36.900312423706055, 37.291992800576345, 36.14941017968314, 38.523328236171174, 38.14697905949184, 36.35446889059884, 33.5539105960301, 35.78108269827706, 38.68925469262259, 41.69463198525565, 44.871445655822754, 43.33047069822039, 43.45930072239467, 41.98121043613979, 38.04019914354597, 35.745243889944895, 35.113604000636506, 34.88531051363264, 38.299801213400706, 41.9801230430603, 42.48023700714111, 46.0572703906468, 44.5622056552342, 46.47573954718453, 46.124699183872764, 43.87663384846279, 43.98373338154384, 45.07803644452776, 43.99717467171805, 42.02544961656843, 41.00575283595494, 39.6231620652335, 29.16998291015625, 6.5597986323492865, 2.3381170289857045, 1.5600514539650507, 6.270254169191633, 12.153677804129464, 7.5135960919516425, 7.170787172658103, 9.187617761748177, 10.274480172566005, 2.2875449998038153, 0.6423670394080025, 0.1840181542294366, 0.6013588256069592, 26.12391175542559, 45.374293736049104, 24.88135497910636, 42.31409863063267, 5.391524612903595, 0.23383681955082075, 0.1718812526336738, 0.12527716053383692, 0.15732343308627605, 0.10400683831955705, 0.19510818485702786, 0.2019397568489824, 0.13194828613528184, 0.1318242092217718, 0.12605808648679936, 0.1373135575226375, 0.1370838327067239, 0.1293051615357399, 0.08752075117081404, 0.17909760826400348, 0.14036914998931543, 0.1535533025328602, 0.2501775984253202, 0.11235226265021733, 0.09116841972406421, 0.269141322267907, 0.07619401360196726, 0.08192331902682781], [0.040284121941242895, 0.018261826863246303, 0.02127374372711139, 0.01693602032693369, 0.03386894653418234, 0.008973499244478132, 0.03887428223554577, 0.03652108547144702, 0.027174487809783647, 0.04927230213901826, 0.02509881865366229, 0.09714956342109612, 0.018342638687629784, 0.023075776673587303, 0.07036517387522118, 0.042099192938102145, 0.014502588493217314, 0.023285986822364584, 0.055055520563785515, 0.036960721880729706, 0.02856165257149509, 0.05048197401421411, 0.059979510094438276, 0.007475880007924778, 0.04580129696322339, 0.023448253383061717, 0.06898649928293057, 0.04303769847112043, 0.016135447392506257, 0.08336921608341591, 0.5193981464420045, 24.886970860617502, 36.179172788347515, 29.574489661625453, 44.52732917240688, 12.846341116087777, 0.17576597418103898, 0.09872018199946199, 0.05993689130991697, 0.2436630922768797, 2.0463843175343106, 0.9635381826332637, 4.232660625662122, 4.722988486289978, 1.5443637243338992, 0.9571226068905422, 0.3545515649020672, 3.072310809578214, 19.83007366316659, 43.04681396484375, 53.408037185668945, 51.3123527935573, 50.6307692527771, 47.119372027260916, 48.46705157416207, 49.524324212755474, 51.333002839769634, 49.57783923830305, 49.926294871738975, 49.990395477839876, 48.93610709054129, 47.997426305498394, 47.77677583694458, 49.36055517196655, 48.49730403082711, 47.052825655256, 41.59754828044346, 38.017572334834504, 36.43518263953072, 38.00307491847447, 42.085256235940115, 44.7209928376334, 44.40676055635725, 47.38587018421718, 45.96038123539516, 43.3582878112793, 37.466316155024934, 34.56496729169573, 36.64277049473354, 37.25293697629656, 37.42648213250296, 35.05165386199951, 40.53560297829764, 43.50715296609061, 45.464126995631624, 46.471549783434185, 47.22672516959054, 46.20349175589425, 48.62730482646397, 46.51084532056536, 39.06326232637678, 49.70297976902553, 50.16134895597185, 44.418565545763286, 41.39566142218453, 41.46956246239798, 39.3835951260158, 40.72057097298758, 37.299469062260215, 36.38708373478481, 33.9901636668614, 32.29476152147566, 33.451181479862754, 35.48826476505825, 33.20994002478463, 33.13480567932129, 33.07709394182478, 34.28371116093227, 34.18832976477486, 36.571624415261404, 41.65922049113682, 45.26612070628575, 45.82590927396502, 46.21272243772234, 45.76487977164132, 44.81066281454903, 41.31014994212559, 37.50562558855329, 33.268284048352925, 31.555424554007395, 34.01389871324812, 38.101558685302734, 39.62567731312343, 42.05110583986555, 43.24801989964077, 42.99621023450579, 42.96240724836077, 40.66415854862758, 41.94126871653965, 43.15255165100098, 41.42610148021153, 40.742982387542725, 40.53104148592268, 24.23953250476292, 6.978052828993116, 0.4644685653703553, 0.9555659932749612, 1.4277161721672331, 1.582768480692591, 3.6302806862762997, 11.614600947925023, 9.131490213530403, 2.621019014290401, 1.3517658476318632, 0.16652283445000648, 0.03487873217090964, 0.0691284623795322, 3.427166602441243, 33.028255053928916, 23.878721237182617, 25.894555194037302, 16.91344918523516, 0.08641452195921115, 0.09178806468844414, 0.0623369375243783, 0.04880382799144302, 0.06590122090918676, 0.015680352259161215, 0.05634972093892949, 0.06398564191269022, 0.06253957522234746, 0.01248378396433379, 0.06430162888552461, 0.012733020054708635, 0.02354616259357759, 0.0624798641407064, 0.035098234856767316, 0.07130042583282505, 0.01945673212009881, 0.04934659833088517, 0.0738106050661632, 0.04042450405125107, 0.022056367713958025, 0.019898492343989865, 0.0816967561841011, 0.051675327122211456, 0.041729812044650316, 0.04810261633247137, 0.022280706658161113, 0.02221613048043634, 0.00798226475516068, 0.054813765321991274, 0.026387007208541036, 0.027362236753106117, 0.06931071010019098, 0.020643601825992976, 0.05416647684095161, 0.0453482594873224, 0.024057106247970035, 0.017121852408828478, 0.02543399968583669, 0.05604173389396497, 0.01942350765291069, 0.036685324872710874, 0.07310007033603531, 0.0346752802309181, 0.016937925313998545, 0.0415512962665941, 0.06888634751417808, 0.00994018094414579, 0.04472200219918575, 0.04306940980521696, 0.03478750992300255, 0.0396619019364672, 0.06152057168739183, 0.0508171329940004, 0.9005746926580156, 32.82103197915213, 35.96273987633841, 28.751088176454815, 49.039579663957866, 11.341320480619158, 0.11124596558511257, 0.07688081317714282, 0.12271445590470519, 0.1197645113404308, 0.9254224279097149, 2.89394816330501, 3.8256481800760542, 7.5831866434642246, 3.4974658702101027, 1.7579357155731745, 0.7440802529454231, 4.740906153406415, 21.283504792622157, 45.099152020045686, 53.61100448880877, 51.72274119513375, 52.0316789490836, 47.92312226976667, 51.35899952479771, 51.007799352918354, 52.555138860430034, 51.141767569950645, 49.37655687332153, 51.479390961783274, 50.84033734457833, 49.26753616333008, 49.25380999701363, 52.1013137953622, 49.78145967211042, 48.7362699508667, 44.06478064400809, 39.78693805422102, 37.899348735809326, 40.734390939985005, 44.62773411614554, 44.937672410692485, 48.52117804118565, 48.12323733738491, 47.73370047977993, 44.295339243752615, 39.24636820384434, 37.285628250667024, 38.64053392410278, 38.50295959200178, 38.798671449933735, 36.69868959699358, 41.5480180467878, 45.19818469456264, 47.594729559762136, 48.17210749217442, 49.36646808896746, 48.678537368774414, 50.46406807218279, 46.47927965436663, 40.671534061431885, 50.159455571855815, 52.833191871643066, 45.9877085004534, 44.99132292611258, 43.994374547685894, 42.920068400246755, 43.53850323813302, 40.58557442256382, 38.59591259275164, 36.04639271327427, 34.7682785306658, 34.00127731050764, 34.64711236953735, 35.14937332698277, 35.281566279275076, 35.339045252118794, 35.422166551862446, 34.83578722817557, 37.512118680136545, 42.712616034916465, 46.48903145108904, 46.833818435668945, 46.62701572690691, 47.449036257607595, 45.93745912824358, 42.9096565246582, 37.70108536311558, 34.89384984970093, 32.25551462173462, 36.19093608856201, 39.29990059988839, 42.61653634480068, 44.13127143042428, 44.948056493486675, 44.152845587049214, 43.944330147334504, 42.01481887272426, 42.61016832079206, 43.67288834708077, 41.76371792384556, 39.51343611308506, 41.41447366986956, 27.99467079980033, 9.988723346165248, 1.107619502714702, 2.838519560439246, 3.6451344149453297, 3.4356570839881897, 5.041212507656642, 12.099652085985456, 8.973365715571813, 2.07469779253006, 0.8103630276662963, 0.1668039650789329, 0.054753172144825966, 0.023612894816324115, 3.143417154039655, 39.16793693814959, 28.194191796439036, 26.041843107768468, 24.491550615855626, 0.40645474408354076, 0.14527304470539093, 0.04188610580084579, 0.021883831525753652, 0.027821945924577967, 0.016781838510983756, 0.020200645684131553, 0.04680157971701451, 0.017563756821410995, 0.0701389503000038, 0.03987654631159135, 0.02885229965405805, 0.0235706068176244, 0.01797105764437999, 0.049362113034086566, 0.015471755327390773, 0.03860155865550041, 0.03579191816970706, 0.03725300084001251, 0.04231659895075219, 0.0025882334489974058, 0.009331617304789168, 0.03696097293868661, 0.03157879585134132, 0.11979159845837525, 0.10419899943683829, 0.05368264405322926, 0.134840405945267, 0.1134975076253925, 0.1744330735611064, 0.10995097471667187, 0.13482186836855753, 0.1514708785606282, 0.15294401879821504, 0.15254453809133597, 0.3116263539663383, 0.13423496271882737, 0.09620277636817523, 0.13605510576495103, 0.1596338448247739, 0.10175026154943875, 0.13351662483598503, 0.15254043973982334, 0.16005072316953114, 0.14272800912814482, 0.09244756679981947, 0.18092866215322698, 0.15005371746207985, 0.09523314982652664, 0.10314678161271981, 0.16903607387627873, 0.08367593426789556, 0.24647336719291552, 0.21651570685207844, 1.244476324745587, 38.023662430899485, 46.68356711523873, 38.902223927634104, 54.22770575114659, 18.437046698161534, 0.37612336022513254, 0.12855178410453455, 0.5728410301463944, 0.8542869335838726, 7.335498128618513, 9.04026210308075, 13.442818777901785, 12.26560720375606, 3.9991399220057895, 3.356932908296585, 0.6874444005744798, 4.177964406354087, 20.588146448135376, 46.05460923058646, 55.14589977264404, 55.52701541355678, 55.05626106262207, 49.46548686708723, 53.197402545383994, 54.345363071986604, 55.20570291791643, 51.85185956954956, 50.367078168051584, 53.87686341149466, 53.39063542229788, 50.40503965105329, 49.94900853293282, 53.81881468636649, 51.723130294254844, 51.06230797086443, 45.73808751787458, 41.35100882393973, 39.52892017364502, 42.99013403483799, 47.29276084899902, 49.12901340212141, 49.31061152049473, 49.82657779966082, 49.48667887278965, 48.56129346575056, 41.07845183781215, 39.4131110736302, 40.487340790884836, 40.66917167391096, 40.99589681625366, 37.89449889319283, 44.6799567767552, 46.879746028355186, 49.15917553220476, 50.122772557394846, 51.547778606414795, 50.771192346300396, 50.96800354548863, 49.57036297661917, 42.288866247449604, 51.821256228855674, 55.09039061410086, 47.30871391296387, 44.99468585423061, 46.44888823372977, 44.25327137538365, 45.3481685093471, 40.80875056130545, 39.917432171957834, 38.582797867911204, 35.55268151419503, 36.136632442474365, 36.494843346732004, 36.379336493355886, 36.263054915836875, 35.50773361751011, 37.398119585854666, 37.67074605396816, 40.4348714692252, 44.36956337520054, 49.69753238133022, 49.612521171569824, 48.85225970404488, 49.23050921303885, 48.73329264777047, 45.151124545506065, 41.03028345108032, 37.21177237374442, 34.62193904604231, 38.20798076902117, 41.731127398354666, 43.77212251935686, 46.10232251031058, 46.86131245749337, 44.5479097366333, 45.766703673771445, 43.290292739868164, 43.945139612470356, 44.66184977122715, 43.17196144376482, 41.30725949151175, 41.77825008119856, 26.779759168624878, 8.982071808406285, 1.0116354588951384, 2.807585311787469, 4.17408036334174, 4.488395154476166, 10.909529890332903, 19.97151987893241, 18.661155632564, 7.5667871577399115, 4.566125520638057, 0.7172789882336343, 0.2543852212173598, 0.14038611336478166, 5.786281738962446, 42.949257782527376, 32.53893511635916, 35.709561416081016, 27.789139611380442, 0.6194650168929781, 0.19857370746987207, 0.16116111858614854, 0.10971785044031483, 0.1156065980238574, 0.09448732449007885, 0.19137031185839856, 0.1000662733401571, 0.14144821065877164, 0.19612890508558067, 0.14356624414878233, 0.1598190170313631, 0.13445864857307502, 0.12488215815808092, 0.11519982985087804, 0.12831778451800346, 0.0990814883261919, 0.13233192983482564, 0.19464261483933243, 0.1523201058485678, 0.09441980347037315, 0.14858106576970645, 0.09672973344900779, 0.11029605048575572], [0.02228526641348643, 0.022257366749857153, 0.04932688349591834, 0.04444920737296343, 0.03458333534321614, 0.011923062980973294, 0.013704371771642139, 0.04317713063210249, 0.0467087629118136, 0.012600709118747284, 0.026934842811897397, 0.02698690171486565, 0.03263273036905697, 0.03526041151157447, 0.0025255713761518045, 0.027354002730654817, 0.016137973239113177, 0.05523838235863617, 0.029084114357829094, 0.042654845264873335, 0.07158948853611946, 0.03309029367353235, 0.0571155155609761, 0.06676709266113383, 0.03694609605840274, 0.04318221964474235, 0.03778416483796068, 0.032305802019046884, 0.030240141254450594, 0.058042916868414195, 0.08987471128680877, 5.851628678185599, 36.47312675203596, 28.402184384209768, 33.13919346673148, 34.822088854653494, 5.586109348705836, 0.3312087117561272, 0.0176858744650547, 0.07009233494422265, 0.2314812173800809, 0.699903660586902, 2.5697945058345795, 7.870515499796186, 1.9180467469351632, 1.0544185574565614, 0.3489936574229172, 0.4662551209330559, 10.581621817180089, 30.66112538746425, 50.90675170081002, 53.11023391996111, 50.94622094290597, 50.03242860521589, 50.86566005434309, 50.77303014482771, 51.595696857997346, 49.23366022109985, 51.05128117970058, 49.681954520089285, 48.93158381325858, 48.86566277912685, 47.63864912305559, 48.22820724759783, 49.70155538831438, 46.50811815261841, 44.103589807237896, 40.85870810917446, 36.58744893755232, 35.832916259765625, 41.12048496518816, 43.314576693943565, 46.12258693150112, 50.00119297845023, 47.72674880708967, 46.211166041237966, 41.98757151194981, 35.11901317323957, 36.438555989946636, 35.213623319353374, 38.7781777381897, 37.721471377781455, 43.869195801871165, 48.02281502314976, 49.957012857709614, 48.098348890032085, 49.10217598506382, 48.94565738950457, 48.10950769696917, 43.42083549499512, 44.4191700390407, 47.696430342538015, 48.103775433131624, 47.94970260347639, 43.44050931930542, 39.46133852005005, 35.03964390073504, 35.98128114427839, 34.99234403882708, 36.42677879333496, 33.23216731207711, 34.32695327486311, 35.54911708831787, 34.078784465789795, 33.99894271578108, 33.84002004350935, 34.63321944645473, 34.811166286468506, 34.63910804476057, 39.875687394823345, 45.99057810647147, 46.27100740160261, 46.255575452532085, 44.23710291726248, 46.12109306880406, 45.041089398520334, 43.66454356057303, 39.109863894326345, 35.457518986293245, 33.647228377205984, 34.156447955540244, 38.054130281720845, 39.24870974676949, 41.37558112825666, 41.15431227002825, 43.88731670379639, 40.53976147515433, 43.01565129416329, 42.36547013691494, 42.64624336787632, 41.636406081063406, 40.785755498068674, 25.53356327329363, 8.779721157891409, 0.8925570143120629, 0.39761981101972715, 2.2234871685504913, 3.6631667273385182, 2.09144794515201, 1.8213690774781364, 8.542288184165955, 13.80945611000061, 8.932553734098162, 0.358569225030286, 0.060006149379270415, 0.05800844728946686, 0.4322717530386788, 14.54047347818102, 36.26250948224749, 18.969117164611816, 28.466003588267736, 7.328382304736546, 0.015171992126852274, 0.03815509957660522, 0.09715883899480104, 0.05135179144729461, 0.04417338628055794, 0.013529611684914147, 0.004624619032256305, 0.09393916318991355, 0.013020028493234088, 0.024041735733460103, 0.06824686897120305, 0.044889501961214204, 0.02608014313903238, 0.030910849371658902, 0.023837291436003785, 0.03380859762962375, 0.07383215533835547, 0.03919303423858114, 0.051893907000443766, 0.010583960550970264, 0.016687081095629504, 0.020260509436151812, 0.04361495874556048, 0.029517867868500094, 0.028296090928571563, 0.03179966578526156, 0.05173395933317287, 0.04159138750817094, 0.0505047219007143, 0.028778251127472947, 0.025941107921036224, 0.04493800703702228, 0.02175842468360705, 0.03398563080866422, 0.03260758046859077, 0.04409258293786219, 0.03320857250530805, 0.017234730101855736, 0.014425266035167235, 0.02478519976804299, 0.01924580442053931, 0.05299384958509888, 0.02347005980222353, 0.02645995990107102, 0.004514713322610727, 0.042784353851207664, 0.042449506997529945, 0.03133863516684089, 0.02072511423778321, 0.027263933992279426, 0.05210241741899933, 0.0552581514764045, 0.011560703228626932, 0.025735416815483143, 0.11471253314188548, 9.553966743605477, 43.75368547439575, 28.5318603515625, 43.41918877192906, 37.58066265923636, 4.441602945327759, 0.28284794677581104, 0.04573524497183306, 0.017325962527788112, 0.06630351753639323, 0.8455937057733536, 2.85819816163608, 8.668057526860919, 5.404555090836116, 2.490368562085288, 1.346035320843969, 0.9453480158533368, 11.360127517155238, 34.29978929247175, 53.89946590151106, 54.59397656576974, 50.93585770470755, 52.20939302444458, 50.938838481903076, 53.47299936839512, 53.97664301736014, 49.50187110900879, 51.40905087334769, 49.50914587293352, 50.59313086100987, 50.66211952481951, 48.811334814344136, 49.537411144801546, 52.76236193520682, 47.77409383228847, 45.25867223739624, 41.41438681738717, 37.75404800687517, 38.60556364059448, 43.20612226213728, 45.6970340864999, 46.47750786372593, 51.58198806217739, 50.67279890605381, 47.22127430779593, 42.27347598757063, 36.33906126022339, 38.20078590938023, 38.3174809047154, 40.35138538905552, 38.67332247325352, 44.33297068732125, 48.63390908922468, 50.46182380403791, 51.09809119360787, 50.294351373400005, 50.69261516843523, 48.65753296443394, 44.75429902757917, 44.424224853515625, 49.42314454487392, 49.359030042375835, 49.07810395104544, 44.40298768452236, 41.58723367963518, 36.56383548464094, 39.11000633239746, 36.6702367237636, 37.4864833014352, 33.809454917907715, 35.50016702924456, 36.4401228087289, 35.18955475943429, 35.5401018006461, 33.97349146434239, 35.03272696903774, 35.84121240888323, 36.15511465072632, 41.03411538260323, 48.69121435710362, 46.764350346156526, 46.8493789264134, 46.60802630015782, 48.25446796417236, 47.53066716875349, 44.804854120527, 41.82940966742379, 36.350737707955496, 34.870239870888845, 35.32683726719448, 40.358969347817556, 41.894646303994314, 44.208618777138845, 44.257009506225586, 45.22119018009731, 42.69669076374599, 44.04555497850691, 42.25696011951992, 43.21243470055716, 43.477567536490305, 41.70353957584926, 29.586353710719518, 11.159119606018066, 2.002796313592366, 1.6192481517791748, 2.5156606563499997, 2.760473051241466, 3.148362751517977, 5.772904719625201, 10.762912477765765, 16.13811707496643, 6.608300532613482, 0.16077834341142858, 0.1485188983912979, 0.06912956839161259, 0.22908064190830502, 14.61780605997358, 41.077972412109375, 22.230247225080216, 32.99017892565046, 10.850252202578954, 0.04162476464573826, 0.011653246923482843, 0.04648394729675991, 0.029256143341107026, 0.024749254375430088, 0.0560332352428564, 0.04036764281668833, 0.06937051617673465, 0.04867268413571375, 0.04004246508702636, 0.03193734732589551, 0.008840080600098839, 0.030632918035345416, 0.0447504396018173, 0.07471720927527972, 0.02143415788720761, 0.043530623628092666, 0.030290047505072186, 0.03740695025771856, 0.02777360030449927, 0.02906228249360408, 0.016112926815237318, 0.08672335717294898, 0.042327988161040206, 0.14340567562196935, 0.11826505751482078, 0.1263303283069815, 0.11960249074867793, 0.1598200619752918, 0.109328493475914, 0.12271387236458914, 0.14076495303639344, 0.15157721856875078, 0.13003793864377908, 0.1687842152480568, 0.11358910985291004, 0.06301124526986054, 0.1758083961904049, 0.08210258797875472, 0.15416977873870305, 0.1446284500083753, 0.16522611331726822, 0.1777641512453556, 0.14610273018479347, 0.13631395330386503, 0.20582837318735464, 0.18019958984638962, 0.1303234797503267, 0.11712716785924775, 0.19013811940593378, 0.11656159535050392, 0.12049198230462414, 0.09043398699057953, 0.11821568730686392, 0.17659956802214893, 10.629789335387093, 51.98241969517299, 36.75691550118582, 42.93865483147757, 43.2738949911935, 8.791011112076895, 0.654618613421917, 0.23821795731782913, 0.21437026054731437, 1.6496895125934055, 5.233539513179234, 9.402727041925703, 14.053795593125479, 5.392587253025599, 4.065965524741581, 1.611679500767163, 1.093752526811191, 12.88787657873971, 33.24857895714896, 54.489357539585654, 56.230815819331575, 55.08225774765015, 54.42203991753714, 54.01980175290789, 54.018453802381245, 55.623609270368306, 51.25822285243443, 52.14898885999407, 51.38840430123465, 51.08849573135376, 53.3644928250994, 50.1440236227853, 49.734041690826416, 54.73699481146676, 48.98674208777291, 48.11692837306431, 43.626012325286865, 39.60166433879307, 38.822003500802175, 45.380897998809814, 47.91547925131661, 49.62788711275373, 54.95486947468349, 52.054562841142925, 49.25747864586966, 45.00398254394531, 39.44763667242867, 40.34177255630493, 38.9566387448992, 42.705310004098074, 40.4922844341823, 47.710014070783345, 50.77753952571324, 53.123195784432546, 53.1774195262364, 53.304731369018555, 51.36636808940342, 49.86229848861694, 46.50779158728463, 48.071688652038574, 49.25332014901297, 49.95680093765259, 52.13116673060826, 48.52562141418457, 42.941350732530864, 37.89036818913051, 40.428729261670796, 38.51645646776472, 39.932617459978374, 35.66936261313302, 38.190613746643066, 38.05545391355242, 35.73649958201817, 38.28285108293806, 35.88121318817139, 38.36651086807251, 37.938345500401084, 39.33884177889143, 42.93500702721732, 50.58369173322405, 47.81402512959072, 47.790852887289866, 48.15841606685093, 50.807079792022705, 50.04331990650722, 45.57849087033953, 42.790300369262695, 38.46380649294172, 36.69701508113316, 36.44613300051008, 42.65863200596401, 42.73136922291347, 44.767292158944265, 44.98323522295271, 47.73820986066546, 42.83529690333775, 45.01425892966134, 43.93773978097098, 44.3281694820949, 44.277253082820344, 42.23487179619925, 27.989061866487774, 10.684337036950247, 1.5491990191595895, 1.561659419110843, 5.156057545116969, 7.8619509765080045, 6.657979718276432, 10.270240902900696, 15.998692784990583, 22.412359510149273, 16.921601159232004, 0.4511751415474074, 0.4720709260020937, 0.11086160263844899, 0.8592424105320657, 20.341422864368983, 46.48983744212559, 26.89815126146589, 40.412262031010215, 12.124231338500977, 0.17711935298783438, 0.08826479874551296, 0.16499551997653075, 0.1272105375038726, 0.13321177262280667, 0.1574079514081989, 0.12204859592020512, 0.27694273793271607, 0.15370315020637854, 0.09305168009762253, 0.12927341966756753, 0.16434473704014504, 0.10092408409608261, 0.12618185127420084, 0.12662935868969985, 0.16133786338780606, 0.1492506034140076, 0.13690950348973274, 0.12514988093503884, 0.08037454249071223, 0.08398624868797404, 0.12035054846533708, 0.19566851907542773, 0.12595298141241074], [0.010473413625732064, 0.05484562593379191, 0.03839054783540113, 0.08839758804866246, 0.03749101056850382, 0.04427824029698968, 0.07962625407214675, 0.02423238880666239, 0.006692200475039759, 0.0751640856532114, 0.020593960204028657, 0.024447201119203652, 0.08386506233364344, 0.009483942479294325, 0.05275884237406509, 0.025701734337157438, 0.020397515834442208, 0.025989132933318615, 0.018624714176569666, 0.017163422856745974, 0.04984501622883337, 0.08017527711178575, 0.004594063328113407, 0.060361009623323164, 0.04227258238409247, 0.06659676001540252, 0.022369625279679894, 0.024191240746794, 0.04561942582949996, 0.044431989546865225, 0.02496598015672394, 0.5436113700270653, 22.854388271059307, 34.0321238381522, 22.341725860323223, 38.74635846274239, 22.720126492636545, 4.6147563968385965, 0.28332080425960676, 0.029563940396266322, 0.031524536798575094, 0.7023171282240322, 0.9104473228965486, 7.701499700546265, 6.8122318983078, 1.8539127026285445, 0.8574704027601651, 0.8525300707135881, 1.199460900255612, 13.001873067447118, 32.49202782767159, 48.87048830304827, 53.71698188781738, 51.59360892432076, 50.989918163844514, 53.24792637143816, 48.64243800299508, 51.30442489896502, 51.886756896972656, 50.54696702957153, 50.33628027779715, 48.93146916798183, 47.98062556130545, 49.8842339515686, 49.57116549355643, 47.62072624479021, 47.43421227591378, 42.43296146392822, 37.63740164893014, 36.59772879736764, 39.21025494166783, 42.62878254481724, 49.51963070460728, 51.134951387132915, 50.99403497150966, 46.889504773276194, 45.49701976776123, 37.692427907671245, 35.45184578214373, 37.38983038493565, 36.37561920710972, 38.13249206542969, 41.88471385410854, 48.71991736548287, 50.041176387241904, 50.98517949240548, 48.19308410372053, 49.23910066059658, 43.96292005266462, 47.719387190682546, 39.01127243041992, 42.09108577455793, 51.169775758470806, 46.34224380765642, 47.204112257276265, 43.91375459943499, 38.43272372654506, 36.399392468588694, 34.466615540640696, 33.43978990827288, 36.899436950683594, 35.553004605429514, 34.66011592320034, 33.6299204145159, 33.64245843887329, 34.78471449443272, 35.12238652365548, 34.09210763658796, 35.00946092605591, 43.874059540884836, 46.043169021606445, 46.19210018430437, 44.704539503370015, 47.94580813816616, 46.00920622689383, 44.43856940950666, 43.49353449685233, 40.06842000143868, 37.40759692873274, 34.45186104093279, 33.9369752066476, 36.11187253679548, 39.87119538443429, 40.202874592372346, 43.54364490509033, 43.32283462796892, 43.7931547164917, 41.748414516448975, 43.61994307381766, 40.11553921018328, 39.53191484723772, 27.939149481909617, 9.913502148219518, 1.5554482723985399, 0.707606281552996, 1.3548434653452464, 1.7661937581641334, 1.6380755986486162, 2.6717343500682285, 3.130915173462459, 9.188084159578596, 5.4784352864537915, 0.8051518244402749, 0.060500109302146096, 0.05735293496400118, 0.2882792939032827, 6.106065630912781, 33.05950110299246, 28.863199097769602, 22.39924304825919, 21.962387221200125, 0.8714299851230213, 0.02338960251238729, 0.08745352192116634, 0.02713649154507688, 0.04858864757365414, 0.0343215972451227, 0.04064141134066241, 0.04956035043245979, 0.027278047520667315, 0.047116118017584085, 0.02116036900718297, 0.024473993074414984, 0.09655193013272115, 0.01368255602262382, 0.04481447295152715, 0.023242918508393422, 0.01948680479212531, 0.04919011119220938, 0.04271194737936769, 0.05309346531118665, 0.05701976069914443, 0.007479766317244087, 0.020211763480412107, 0.09202913460986954, 0.03442608824531947, 0.02301566525628524, 0.04542832661952291, 0.06585814072085278, 0.043619386186557155, 0.01992817146570555, 0.03907541358577354, 0.005623984915603484, 0.05059550988620945, 0.0384613461792469, 0.03281280677765608, 0.04130155127495527, 0.028176680639652268, 0.021329943390030946, 0.0686214135161468, 0.03758119126515729, 0.040487085336021016, 0.025239441643602083, 0.05555505804451449, 0.06258697089340005, 0.026640417985618114, 0.023267176135310104, 0.044099704162882905, 0.041662314773670266, 0.008481344224752059, 0.05164755129122308, 0.04328060722244637, 0.034925690186875205, 0.0442108583769628, 0.022357783147266934, 0.037277604519788704, 0.04888079082593322, 0.8707071010555539, 30.91363682065691, 35.53841686248779, 25.16356996127537, 46.95526252474104, 25.181202752249582, 4.5704377463885715, 0.5094050626669611, 0.09203511928873402, 0.015042648085259964, 0.20113330440861837, 0.4801277422479221, 4.736006370612553, 7.00099013532911, 2.0389093586376736, 2.2585212886333466, 1.8987783065864017, 2.804525281701769, 16.997673511505127, 36.3840925352914, 51.96460451398577, 54.2852646282741, 52.3619441986084, 54.737859862191335, 53.14423492976597, 50.838662828717915, 51.96306201389858, 52.92696475982666, 51.03649193899972, 51.300589493342805, 51.25061457497733, 49.19868646349226, 51.327051707676475, 48.79275533131191, 49.86646045957293, 46.881392751421245, 44.06612859453474, 39.49810143879482, 37.37177201679775, 40.71129165376936, 43.9990611076355, 50.215426785605295, 51.26716865812029, 52.83261864525931, 49.48648084912981, 46.59346982410976, 38.52543701444353, 36.92739650181362, 39.03010899680001, 39.53118528638567, 38.661861419677734, 44.80981166022164, 50.263876574380056, 51.27290787015642, 52.52441740036011, 50.49258000510079, 50.16125862939017, 45.452777113233296, 46.674989564078196, 40.192421027592246, 45.3580071585519, 53.82009315490723, 47.87437718255179, 49.17957891736712, 44.90049607413155, 39.494144439697266, 37.658635343824116, 36.37649815423148, 34.378126757485525, 37.604376861027305, 36.97270917892456, 36.469100270952495, 34.330448218754356, 34.94357115881783, 36.00808382034302, 36.032941000802175, 35.67344120570591, 36.31484678813389, 45.33209385190691, 47.84908921377999, 47.727791036878315, 44.73851619447981, 47.418696948460166, 47.82308210645403, 44.7562757900783, 44.482270104544504, 41.30039119720459, 38.75137506212507, 36.62626852308001, 35.07637555258614, 37.80724688938686, 41.838376317705425, 42.17116028921944, 45.10288667678833, 46.028907843998496, 43.99209553854806, 42.41233573641096, 44.55032423564366, 42.48704971585955, 40.05447496686663, 32.73119524547032, 11.427331362451826, 3.4176914308752333, 2.0355025700160434, 3.003559253045491, 3.327506418739046, 2.7266900411673953, 5.526843386037009, 6.049289294651576, 6.420789062976837, 3.5704608219010487, 1.8355496994086673, 0.16819479901875767, 0.046446383598127534, 0.32278396668178694, 5.426082781382969, 36.44713701520647, 32.91095209121704, 23.058899811335973, 28.604903289249965, 1.9911952103887285, 0.09791331565273659, 0.04207060965044158, 0.0689742856525949, 0.05843926274350711, 0.03845286788418889, 0.03951090753876737, 0.06205394770950079, 0.045924535885985406, 0.0498756249435246, 0.010448811642293419, 0.006385159986426255, 0.05043245792122824, 0.06161471842122929, 0.03925026866740414, 0.07089097066117184, 0.018198390624352863, 0.028089249706161872, 0.03861628286540508, 0.03121119611231344, 0.021057377569377422, 0.041497125423380306, 0.06282260574932609, 0.0584845006732004, 0.030644741508045366, 0.12118634075990745, 0.1150971267904554, 0.1296573347811188, 0.18419864454439708, 0.14455406899963105, 0.15065715222486428, 0.11386467649468354, 0.10826014008905206, 0.14211838612599031, 0.1596088068825858, 0.1282290049961635, 0.09635562316647597, 0.27804647013545036, 0.0773444561553853, 0.10428796894848347, 0.11365065976445164, 0.0717096570879221, 0.09478350502571889, 0.11590212716587953, 0.11775785258838109, 0.12807781382330827, 0.1484530262116875, 0.062523039323943, 0.1096784614824823, 0.15458474361470767, 0.08492620967860733, 0.08560367261192628, 0.09605822126780238, 0.11895700038543769, 0.08197190891951323, 0.17419234290719032, 0.9912883107151303, 33.72882802145821, 43.895939418247764, 30.134076731545584, 46.903717313494, 29.251676355089458, 6.6143810749053955, 0.8884613769395011, 0.22861234417983464, 0.17697876053197042, 1.882063980613436, 4.7575080054146905, 15.196667432785034, 14.898042542593819, 5.092035974775042, 3.6017001398972104, 2.8516809684889655, 2.1152364058153967, 15.120007957730975, 35.98659304210118, 53.03980003084455, 55.96972336087908, 54.37444475718907, 55.842762402125764, 55.518142563956125, 52.2467291695731, 53.132037367139546, 54.49369321550642, 53.75534289223807, 54.398728711264475, 51.34983137675694, 51.27470050539289, 53.802625383649556, 51.20543738773891, 50.504256452832905, 51.240779399871826, 44.4918794631958, 41.259250913347515, 39.24026073728289, 42.20365353993007, 46.573834214891704, 52.32606370108468, 54.13069152832031, 53.07405464989798, 50.95955106190273, 49.555521624428884, 41.31630604607718, 38.38743189402989, 40.72379841123308, 40.726449148995535, 41.26986428669521, 45.564115047454834, 52.364223207746235, 52.21280458995274, 54.37538971219744, 52.94057975496565, 50.533661229269846, 45.47069999149868, 45.94400085721697, 41.20585400717599, 44.281265667506624, 54.47822652544294, 50.823741572243826, 51.13812323978969, 48.53871182032994, 42.133740765707834, 40.41490582057408, 37.968566690172466, 36.014573437826975, 40.577993937901084, 39.228553022657124, 38.14431095123291, 36.3879348891122, 37.33267102922712, 38.176324776240754, 38.26851347514561, 36.455158710479736, 37.14684840611049, 47.88325350625174, 49.74149363381522, 47.26275852748326, 45.04969126837594, 50.27148485183716, 47.92600577218192, 44.98503828048706, 46.2675576210022, 43.0967298235212, 40.58523743493216, 38.35846832820347, 37.65542875017439, 39.455109460013254, 43.946991307394846, 43.83198125021798, 47.76896258762905, 46.530710220336914, 46.11340141296387, 42.087316376822336, 46.500843388693674, 42.378991331372944, 41.99577733448574, 30.969236305781774, 11.18291197504316, 2.505740148680551, 1.81877273108278, 3.1328569778374264, 5.32864819254194, 4.963207253387996, 7.66364244052342, 9.877110958099365, 18.94717649051121, 12.40220878805433, 1.9142172038555145, 0.5079832332474845, 0.2002527830856187, 0.6935606609497751, 9.168102877480642, 41.15407950537545, 37.488765784672324, 30.906448909214564, 33.85502120426723, 2.158105705465589, 0.2987154339041029, 0.21398253206695828, 0.22042208723723888, 0.10260695950793368, 0.08717743959277868, 0.24828627705574036, 0.13788400191281522, 0.1232978603137391, 0.26968795007893015, 0.2112358630235706, 0.10053753626665898, 0.215378020757011, 0.09128831686185938, 0.16040772758424282, 0.0718808446877769, 0.10157194254653794, 0.12467787840536662, 0.13053360847490175, 0.13265332473175867, 0.20585114482258046, 0.08368653977023703, 0.1542585175484419, 0.25208544890795437, 0.10958242842129298], [0.03316749060260398, 0.04664780332573822, 0.03279007585453136, 0.0895062532009823, 0.015068798824878675, 0.0676817646516221, 0.02146975213794836, 0.020345020972724472, 0.017641706924353327, 0.030193583574146032, 0.05267506704798766, 0.0508569460362196, 0.049200160295835564, 0.014971194955121194, 0.05961122164236648, 0.06319356084402118, 0.06501482347292559, 0.03859650696228657, 0.017932830677766885, 0.0846423241975052, 0.014554386160203388, 0.026816962619445155, 0.028368331159331968, 0.025207535230687687, 0.10972954159868614, 0.007031169004871377, 0.006974324733684105, 0.019067816203460097, 0.012416823584187244, 0.07916834471481186, 0.04682795776586447, 0.04625220723184092, 4.535515231745584, 34.136169637952534, 31.849281242915563, 26.122162546430314, 38.60533782414028, 23.094623974391393, 6.011397293635777, 0.22413313096123083, 0.04659452136339886, 0.03356528514996171, 0.07153100560286216, 4.572279019015176, 4.955365777015686, 1.1409351378679276, 1.2258248627185822, 0.4487053012209279, 0.38989667115466936, 2.084556200674602, 10.458123666899544, 30.590896470206125, 44.30402796609061, 52.61907270976475, 51.89781148093087, 52.450318336486816, 50.37111854553223, 52.33433205740792, 50.62113210133144, 51.76664686203003, 49.569515296391074, 49.199704374585835, 49.38701738630022, 51.11068132945469, 48.50780275889805, 46.909564222608296, 45.924135957445415, 41.398075921194895, 37.091606753213064, 37.614257199423655, 37.67888239451817, 42.887978145054404, 49.45158004760742, 51.358238697052, 51.239004135131836, 51.408964020865305, 46.80971166065761, 39.18262195587158, 35.35470996584211, 37.22591543197632, 36.03626223972866, 36.55779750006539, 39.89092132023403, 47.35514177594866, 48.84856326239449, 50.24698550360543, 48.39930663790022, 50.18988173348563, 49.457840374537874, 47.76978942326137, 37.92022112437657, 39.744866711752756, 52.159199237823486, 46.56056315558297, 48.18909931182861, 46.66362231118338, 42.13936880656651, 37.486872400556294, 36.31579174314226, 37.64977291652134, 36.52342128753662, 34.54534905297415, 34.788553374154226, 33.306193419865195, 34.362264020102366, 35.225390093667166, 34.94004842213222, 34.82855415344238, 38.16658687591553, 46.018805163247244, 46.261665548597065, 46.59823281424386, 45.86917223249163, 46.541858604976106, 46.09489141191755, 42.91255044937134, 40.769823278699604, 38.76052236557007, 37.339647020612446, 33.17668942042759, 34.62676109586443, 36.830621991838726, 39.841311182294575, 41.91438961029053, 43.430927753448486, 44.88789899008614, 44.05522687094552, 44.09514774594988, 44.60413803373064, 44.086910656520296, 31.914729799543107, 13.441744412694659, 2.263246715068817, 1.2188219470637185, 1.6936027790818895, 2.5071015613419667, 2.222378279481615, 2.304449098450797, 3.6324975958892276, 4.509392176355634, 5.050638607570103, 3.2562849947384427, 0.293951575245176, 0.01750445455711867, 0.12803529681903975, 4.0562145965439935, 24.53006969179426, 35.18784202848162, 17.90545392036438, 29.25782551084246, 8.204894082886831, 0.17130593636206218, 0.014699538371392658, 0.022896506025322845, 0.08042009933186428, 0.020697921946910874, 0.04611813210483108, 0.035426496528089046, 0.05273843543337924, 0.021640093265367404, 0.005914382212462702, 0.05681120278313756, 0.011489600392191537, 0.013408056377167148, 0.03214517242408224, 0.055190498142370155, 0.07143128809652158, 0.05013714251773698, 0.043685499246099165, 0.015569333752085055, 0.06929838111890213, 0.06752292638910667, 0.059006321243941784, 0.05442697321996093, 0.011330444066386138, 0.05739061401358672, 0.03362295384119664, 0.02535200212150812, 0.01624160589251135, 0.0697596627952797, 0.01936124188692442, 0.02591372394402112, 0.013721112926889743, 0.019350941725341336, 0.02664222288876772, 0.02950063647170152, 0.02534563067768301, 0.0389384241508586, 0.053452803886362484, 0.003684453632948654, 0.03452425869181752, 0.022995792661926577, 0.03842442708888224, 0.055879275647125075, 0.03109451523050666, 0.10854997632226773, 0.06394921136753899, 0.07369341528309242, 0.020991379860788584, 0.018615896614002328, 0.04348787931459291, 0.027478301864383475, 0.00716642478281366, 0.05823587187166725, 0.03578409126826695, 0.029052474269909517, 0.051372452838612456, 0.015176124405115843, 8.152757406234741, 41.92393296105521, 29.44130311693464, 29.39701877321516, 42.402695110866, 25.443271432604107, 5.108270440782819, 0.27331919808472904, 0.054653576774788756, 0.07157314262752022, 0.20737930067947932, 1.5013033492224557, 6.259174398013523, 5.616446486541203, 3.7898150171552385, 2.7512788474559784, 0.7802735822541373, 1.9030223531382424, 13.913404635020665, 34.52931955882481, 46.99238674981253, 54.67598615373884, 51.54949481146676, 51.97811181204659, 51.56138317925589, 54.81237234388079, 52.05224214281355, 53.22569213594709, 50.712348052433555, 51.9598172051566, 51.29596199308123, 53.47298199789864, 50.77825171606881, 49.606226103646414, 47.827396937779014, 44.4749710219247, 39.64329447065081, 38.686892305101665, 41.207997526441304, 45.17316770553589, 52.86008834838867, 52.14070313317435, 52.164427757263184, 51.51927362169538, 48.79927274159023, 40.34684821537563, 36.862298829214915, 38.53315993717739, 38.59908444540841, 38.43191426140921, 42.119111333574565, 49.83333144869123, 51.10141243253435, 51.45549610682896, 49.171327931540354, 50.775729519980295, 48.90964835030692, 47.784867014203755, 39.193850244794575, 40.780026708330425, 53.22329500743321, 48.00588573728289, 48.94639042445591, 48.48013850620815, 43.20649399076189, 38.50128160204206, 36.4621798651559, 39.09407411302839, 38.855813435145784, 34.855815410614014, 37.222097396850586, 34.842909131731304, 36.52960171018328, 37.170204775674, 35.99876628603254, 36.46646690368652, 38.93447051729475, 45.856314590999055, 48.37121507099697, 46.61395311355591, 47.00689806256975, 47.304715224674766, 48.10300765718733, 44.39030374799456, 43.018948214394705, 41.43859781537737, 39.25310795647757, 34.55358614240374, 35.59206737790789, 38.7611893926348, 41.43485621043614, 43.62190593991961, 45.139111110142295, 45.8909444127764, 43.74338129588536, 44.22858789988926, 44.21829414367676, 44.08792161941528, 33.94237743105207, 15.118465457643781, 3.39983651467732, 1.7924592516251971, 2.640903890132904, 3.657133085387094, 3.3966694389070784, 2.9998610743454526, 6.297566669327872, 5.937595699514661, 3.7125870926039557, 0.4130303183836596, 0.2011549361050129, 0.04708849146429982, 0.08638966722147805, 3.483749909060342, 24.763725451060704, 41.093525954655235, 21.138464621135167, 32.2277044568743, 14.185972911970955, 0.15099597190107616, 0.04436872972707663, 0.015252654673531651, 0.02187990111165813, 0.034087292317833216, 0.06473481242677995, 0.03723872446322015, 0.020562474482825825, 0.037198344844260385, 0.023491708461993506, 0.018793554045259953, 0.024485088818307434, 0.021027957987306372, 0.01910424674861133, 0.04564047398577843, 0.02123782886857433, 0.01853179219844086, 0.037782583851367235, 0.044966858346015215, 0.04217695983658944, 0.011246377818419464, 0.04675123920398099, 0.028116487798147967, 0.041979557036289146, 0.022422396644417728, 0.14897230906145914, 0.10031313116529159, 0.12110630076910768, 0.22665126941033772, 0.12231838144361973, 0.13082588064883435, 0.10100108424999885, 0.13251650493059838, 0.06668175331183843, 0.0887265418257032, 0.15503866997148308, 0.11744187240089689, 0.15745797300977366, 0.11770905234983989, 0.1662872742329325, 0.17459128078605446, 0.14453695634646074, 0.14259235640721662, 0.09676729036228997, 0.2597891826714788, 0.15819750832659857, 0.19622419854359968, 0.11036781234932797, 0.0627975474510874, 0.21312110471938336, 0.09616322456193821, 0.0822373925309096, 0.18670688995293208, 0.13851756363042764, 0.16070489878101007, 0.1089275199919939, 0.16862245249961103, 8.508819580078125, 49.73400000163487, 40.563152585710796, 33.247376918792725, 47.328151498522075, 30.434433460235596, 8.508122154644557, 0.6857378578611782, 0.17112512035029276, 0.28019104791539057, 2.4587696748120442, 10.456835644585745, 8.659223760877337, 4.15449686561312, 2.3060536980628967, 2.1158196202346256, 0.9472114358629499, 2.9267977263246263, 13.409749695232936, 34.12076548167637, 47.08747284752982, 54.892617089407786, 52.45910433360508, 53.947905267987935, 53.750135217394146, 56.967290128980366, 53.35033934456961, 54.811976296561106, 53.43319661276681, 52.75955833707537, 52.90967416763306, 55.57335989815848, 53.51368801934378, 52.024035930633545, 49.63869850976126, 45.31930569240025, 40.75328656605312, 42.21121665409633, 41.93952471869332, 46.85559409005301, 56.129802908216206, 54.11073282786778, 52.546477930886404, 52.42633662905012, 49.9434187071664, 43.25211933680943, 38.86495379039219, 41.819477217538015, 39.36600228718349, 40.71261875970023, 43.63437795639038, 52.25382328033447, 52.90648147038051, 54.36018705368042, 51.191290855407715, 52.036254337855745, 49.809082235608784, 47.42761843545096, 39.59739119665963, 41.3142910684858, 54.2841077532087, 49.5362924848284, 50.828139781951904, 50.05654580252511, 44.69921718324934, 40.30819886071341, 39.572683402470176, 39.95886080605643, 41.35474695478167, 36.33677182878767, 38.75780214582171, 35.799352986471995, 39.124767780303955, 40.84197684696743, 39.233062403542654, 38.18366207395281, 41.2399696622576, 48.526979787009104, 50.50939464569092, 47.99420581545149, 46.01170410428728, 47.87572513307844, 49.93709584644863, 46.45322043555123, 43.82195847375052, 42.948899950299946, 41.08697380338396, 35.580495153154644, 37.69413716452462, 39.49413054330008, 42.7042121887207, 45.83079733167376, 47.14936392647879, 48.053904737745015, 45.37348427091326, 45.085971287318635, 46.04611158370972, 45.15096821103777, 33.707299028124126, 15.37059473991394, 3.4835779411452155, 2.274587477956499, 4.0720148001398355, 5.55793570620673, 4.929251406873975, 5.1573433961187085, 9.83441514628274, 11.343143514224462, 12.730503354753766, 7.268969561372485, 0.5736812193478856, 0.17691163984792574, 0.33723206711666925, 6.6144227640969415, 32.487393379211426, 44.640028953552246, 26.53074094227382, 40.309532914842876, 14.66700278009687, 0.237024794199637, 0.07463657217366354, 0.08742264179246766, 0.15077227247612818, 0.09764882270246744, 0.15758819745055266, 0.17959148676267692, 0.14407849737576076, 0.0940494794132454, 0.0813396160623857, 0.15148309219096387, 0.0813763112361942, 0.09314281413597719, 0.1108725881204009, 0.13456535499010766, 0.18189162548099244, 0.14366965288562433, 0.16045344727379934, 0.13898720485823496, 0.09900595380791596, 0.1400142761745623, 0.18346765876880713, 0.12998593571994985, 0.07806796447506972, 0.1393397987953254], [0.013621514164177435, 0.006349690840579569, 0.03018095943012408, 0.031858786541436396, 0.03370680380612612, 0.03771971079653927, 0.04208823120487588, 0.03995580259444458, 0.0022021673794370145, 0.1024689386997904, 0.03849857739572014, 0.07049595471471548, 0.05378184926563075, 0.052914515270718505, 0.03853685694879719, 0.06658656841942243, 0.058466329505400996, 0.030206482524850538, 0.02509101719728538, 0.020081237091549804, 0.004216806763517005, 0.023005692487848655, 0.02413362803469811, 0.043050298866416724, 0.0018566340232999729, 0.007499450618135077, 0.01674646817679916, 0.045063593690948825, 0.07448555741991315, 0.04298251661072884, 0.05474597967362829, 0.05852184045527663, 0.023520274786278605, 11.205740281513759, 36.34160082680838, 27.215360845838273, 30.77235562460763, 38.240220410483225, 27.408100400652202, 8.231909547533308, 0.26693054661154747, 0.020193220814689994, 0.06229220171059881, 0.16938260171030248, 2.3174081402165547, 6.159323138850076, 10.61620647566659, 5.522628000804356, 0.6683157384395599, 0.14451357402971812, 0.6341794558933803, 4.645861744880676, 19.024610689708165, 36.1335300718035, 49.229845660073416, 51.07541574750628, 54.06013604572841, 51.9539008140564, 51.87469482421875, 53.67955194200788, 51.67193944113595, 51.6045731816973, 50.45855120250157, 48.768516540527344, 48.4860896383013, 47.01635456085205, 47.18989276885986, 41.817194734300884, 38.32903575897217, 37.66178287778582, 40.796181270054404, 46.67801203046526, 50.59242909295218, 49.59564399719238, 50.4287816456386, 49.70488357543945, 47.876673562186106, 41.6537036214556, 38.501316343035015, 36.2462020601545, 36.275575569697786, 35.75734765189034, 37.50895030157906, 40.71324062347412, 47.29171861921038, 50.45465326309204, 49.926621437072754, 48.90038292748587, 49.49447127750942, 50.27654314041138, 47.84160252979824, 47.07502862385341, 50.44667673110962, 49.776582036699565, 46.97317845480782, 47.411529881613596, 43.03923348018101, 41.234324250902446, 36.75380965641567, 36.777558599199565, 36.22781712668282, 35.450935568128315, 34.30561188289097, 34.10519456863403, 34.36674908229283, 34.94588838304792, 35.187974044254844, 36.0851080758231, 40.1395834514073, 46.652394022260395, 46.01760312489101, 48.57866743632725, 47.34501130240304, 48.028582027980256, 45.69073554447719, 45.138537883758545, 40.13378517968314, 37.36406299046108, 34.73440258843558, 32.765005179813926, 35.99056393759591, 38.1076592036656, 40.97089719772339, 43.208804266793386, 44.04684386934553, 43.66407455716814, 43.87856197357178, 43.60374334880284, 45.39629520688738, 37.66031680788313, 17.386790003095353, 3.4466352377619063, 0.21156241478664534, 1.5945805268628257, 3.2872859026704515, 3.3178442972046986, 2.3231881729194095, 2.5164896632943834, 5.318323169435773, 3.790555000305176, 1.9978557101317813, 0.18358049914240837, 0.022297798955280865, 0.09978852181562356, 4.372295532907758, 20.53025926862444, 35.859500067574636, 24.596956525530132, 24.293233394622803, 16.442845957619802, 0.6678055886711393, 0.062262414023280144, 0.051767624848123105, 0.03954114645187344, 0.039406423323920796, 0.004491221168011959, 0.02893416490405798, 0.05632474406489304, 0.04360944564853396, 0.04152364257190909, 0.008799003786407411, 0.10122037998267583, 0.07059455263827528, 0.03047289912189756, 0.04503005709765213, 0.03371080716273614, 0.048235500630523474, 0.0170180484253381, 0.0392037516992007, 0.03776465356349945, 0.0399981669283339, 0.0385770669340023, 0.027840943208762577, 0.04362108591677887, 0.031003584752657583, 0.010920476600793856, 0.04723775899037719, 0.040476771603737555, 0.027641560782545378, 0.015786392015538046, 0.045770484688026566, 0.020977149285109978, 0.020333129646522657, 0.010953299884152199, 0.050210356446249146, 0.04651807760819793, 0.023190530515941124, 0.02185107864040349, 0.06097426278782742, 0.03858670891661729, 0.0201158542518637, 0.01704799217571105, 0.06619257706084422, 0.05489405637074794, 0.03911313674013529, 0.014202484328831946, 0.052869097529245276, 0.04864934253107224, 0.005678165512758174, 0.022546855233875767, 0.005933404517626124, 0.019142751914582083, 0.04533335207296269, 0.0347986786094095, 0.01346044521778822, 0.026753071762089218, 0.047376000322401524, 0.0682565855926701, 0.15915209853223392, 18.39844945498875, 41.63654851913452, 25.984784500939504, 36.498897620609824, 44.65771211896624, 31.537838663373673, 6.2636633685656955, 0.3235662632754871, 0.08776344279093401, 0.07450402714312077, 0.21400744787284307, 7.023185287203107, 8.659445234707423, 7.649812051228114, 5.119506980691638, 2.169134885072708, 0.3599381830011095, 1.0645996225731713, 8.428458452224731, 23.85380325998579, 41.02909183502197, 50.2749137878418, 52.086097240448, 55.1307110105242, 54.18802111489432, 53.88588564736502, 55.5541342326573, 53.07412413188389, 51.878446851457866, 50.743107727595735, 48.71036359242031, 49.92293541772025, 49.361131872449604, 48.20495162691389, 44.195378984723774, 39.20685379845755, 38.8747889654977, 42.01825475692749, 48.047508920942036, 51.07700341088431, 50.9184524672372, 52.20946945462908, 52.35354035241263, 50.22826705660139, 43.84714221954346, 39.01857498713902, 37.09531361716134, 37.737858704158235, 37.13912895747593, 38.096430914742605, 43.74885300227574, 51.54642718178885, 52.23870400020054, 54.10544524874006, 50.37419312340872, 51.97060775756836, 49.38531160354614, 49.78767483575003, 48.39238623210362, 51.06134564535958, 51.829267501831055, 49.752364090510774, 49.28608785356794, 46.20304012298584, 42.02980266298567, 37.15284122739519, 39.04966817583357, 36.16163553510393, 36.724050521850586, 35.53746495928083, 35.53103787558419, 36.72383165359497, 36.43625266211373, 36.34797927311489, 36.81344257082258, 41.43187195914132, 48.81626803534371, 48.10144083840506, 47.78394290379116, 47.721099921635215, 47.62859855379377, 46.64573417391096, 45.40155151912144, 42.687011923108784, 39.23099531446184, 36.519797801971436, 35.19004808153425, 37.49094404493059, 40.04772131783621, 42.492243494306294, 44.239249910627095, 45.53524875640869, 45.67075252532959, 43.826481751033235, 45.062663555145264, 45.37069456917899, 39.35818556376866, 20.094148635864258, 4.886872172355652, 0.7526048240917069, 3.2569941452571323, 3.437483157430376, 3.8339634367397855, 3.004902643816812, 4.315131834575108, 7.002711985792432, 4.662349820137024, 0.48631142186267035, 0.12304137407669, 0.08006634509989194, 0.12566419690847397, 3.5562285227434973, 20.904176575796946, 44.40245962142944, 29.74819462639945, 23.842915432793752, 24.334000212805613, 1.4479941640581404, 0.03593616792932153, 0.04808388198060649, 0.032648357030536444, 0.0016018170884178418, 0.00698741664278454, 0.04978235012718609, 0.04819824227264949, 0.03964365612981575, 0.03398306933896882, 0.038748760042446, 0.06858315771179539, 0.0600101255944797, 0.009837494847098631, 0.023468578899545327, 0.049243613678429804, 0.06055063980498484, 0.031394912861287594, 0.04946349973657301, 0.012347573996521533, 0.029760223613785844, 0.010626848204992712, 0.07301795402807848, 0.044382582019482336, 0.04584030594144549, 0.00812652045195656, 0.13536715268024377, 0.08215635509363242, 0.09099563756691557, 0.1001614039497716, 0.1115189537938152, 0.12342556060424872, 0.10180722456425428, 0.0907281997746655, 0.12286373360880784, 0.12118407445294516, 0.17455337781991276, 0.16733296455017158, 0.10234030881630522, 0.08894348982721567, 0.07026888975607497, 0.11468351898448807, 0.1673289883349623, 0.11573101420487676, 0.11625894159078598, 0.10701562544064862, 0.13249443897179194, 0.12903226832193987, 0.1383394617587328, 0.11045374202408961, 0.14275474340787955, 0.1331927329301834, 0.13290445054216043, 0.13662048828388962, 0.1282688078603574, 0.09504569774227482, 0.13456882908940315, 0.09868120694799082, 0.16280869660632952, 19.43265754835946, 48.922492095402305, 36.55443457194737, 40.720129762377056, 46.781422070094514, 35.66583292824881, 11.281220299857003, 0.5455683735864503, 0.19969500015888894, 0.19907808969063417, 2.423496276140213, 8.71218032496316, 16.05375725882394, 19.14135605948312, 14.340137805257525, 2.956985043627875, 0.33895617031625336, 1.1302150445325034, 6.062615071024213, 21.992908920560563, 37.54928112030029, 49.94842488425118, 53.12912607192993, 56.432872908455984, 56.63211597715105, 56.10907643181937, 56.316712924412315, 55.72428519385201, 52.974414008004324, 51.70388725825718, 51.55033554349627, 52.915100710732595, 50.31725263595581, 51.14003052030291, 46.301023619515554, 41.28699507032122, 41.077027457101, 44.370185238974436, 51.74354410171509, 53.75828545434134, 52.35181719916207, 53.63647658484322, 53.94291646139962, 52.0515125819615, 45.83542135783604, 41.28498704092843, 39.52411896841866, 38.965216296059744, 39.24814346858433, 39.86223220825195, 43.877203600747244, 52.81709636960711, 53.6154339654105, 55.957789829799104, 53.59003829956055, 54.0101889201573, 49.55925280707223, 49.50166613715035, 48.22092553547451, 53.68663215637207, 54.09530087879726, 50.781301975250244, 50.7186153275626, 46.494138377053396, 45.03176839011056, 39.12861360822405, 39.46225915636335, 39.23577914919172, 38.95700005122593, 38.059386593954905, 36.9620714868818, 38.40242610658918, 39.378908566066194, 37.805586269923616, 39.11847966057913, 43.91792351858956, 52.15648249217442, 49.2430750301906, 49.89466667175293, 48.27912712097168, 49.24885245731899, 49.27770137786865, 48.338558537619456, 45.224587849208284, 41.33516345705305, 37.7761606488909, 36.96204021998814, 38.566299370356965, 41.379510334559846, 44.370636871882844, 47.040443965366904, 48.98171854019165, 47.53017732075283, 44.05776991162981, 45.72552170072283, 45.65003994532994, 40.236017499651226, 20.105595793042863, 4.607919803687504, 0.6226294328059468, 3.739404533590589, 7.927848560469491, 6.721537062100001, 6.881700422082629, 7.202422320842743, 10.976595640182495, 10.193484153066363, 5.251370762075696, 0.7287830880710057, 0.21080940376435006, 0.32515373666371616, 6.0611186027526855, 27.021643332072667, 43.89169406890869, 33.374101638793945, 32.741766929626465, 29.2813138961792, 1.5553754248789378, 0.20945770772440092, 0.11512558454913752, 0.1531533468514681, 0.09434289152600936, 0.034157839603722095, 0.12711350699620588, 0.20741211463298115, 0.1081983255488532, 0.08268930363867964, 0.11839463056198188, 0.2118899164987462, 0.11645435967615672, 0.08265335485339165, 0.09905706106552056, 0.10884043680770056, 0.18011769066963876, 0.1508512268108981, 0.13973476045898028, 0.10227232639278684, 0.13368825348360197, 0.10337835882923432, 0.15697075772498334, 0.11625541320868901, 0.13236352242529392, 0.09885837244135992], [0.01904032366084201, 0.04256937699392438, 0.07761875393667392, 0.06128711492887565, 0.0632546968492014, 0.040706974786839316, 0.011127610441430338, 0.11521702392825059, 0.012434010876209607, 0.053390120821339745, 0.042580966372042894, 0.021340572641098073, 0.04912850360519119, 0.052246073460472484, 0.019328718007143055, 0.014690120305333818, 0.06253588399184601, 0.0979288744607142, 0.011212318753158408, 0.03924023652715342, 0.036888247555387874, 0.058336084708571434, 0.05543484878061073, 0.09655911581856863, 0.03389221689264689, 0.0531888300153826, 0.015950314201680676, 0.013965941932318466, 0.031223674371306385, 0.042817503679543734, 0.011484240813712989, 0.03327929281762668, 0.07750986263688121, 0.7270990184375218, 19.00388421331133, 36.58513866152082, 22.995589562824794, 26.817717177527292, 42.00995513371059, 28.92930599621364, 9.41139144556863, 0.36553897389343804, 0.15738040288644178, 0.10163818792040859, 9.026205897331238, 8.771559630121503, 4.923262928213392, 3.382911571434566, 2.385893928153174, 0.4708567282983235, 0.06345828449619667, 0.26831299385854174, 1.6887982083218438, 13.005704130445208, 30.180129391806467, 46.55594260351998, 56.223714760371614, 51.41335528237479, 52.420673847198486, 52.27937180655343, 47.19020196369716, 51.24581336975098, 49.009205613817485, 51.02114336831229, 50.80071176801409, 47.681245054517476, 45.06051656178066, 40.140420709337505, 37.27373988287789, 40.68606621878487, 43.69750581468855, 47.20454651968819, 51.37335797718593, 49.311876092638286, 51.23679460797991, 51.611295563834055, 48.64581135341099, 40.60592917033604, 36.47987345286778, 36.98646661213466, 35.13676234654018, 36.489441122327534, 35.40974317278181, 37.94089548928397, 38.972591808864046, 43.325228282383506, 45.79843609673636, 48.61259549004691, 50.94286148888724, 48.38657406398228, 44.00433131626674, 52.24785130364554, 49.037099157060894, 49.071093218667166, 47.43554980414254, 48.09098727362496, 42.7873751776559, 40.62974064690726, 37.600451128823416, 35.64112860815865, 36.08776576178414, 37.804950509752544, 35.369985580444336, 35.22598763874599, 34.589504855019705, 35.12205301012312, 37.406471320560996, 39.47963660103934, 41.75624166216169, 45.009867668151855, 47.688516344342915, 46.86922298158918, 47.633521352495464, 48.024757044655935, 47.485139097486226, 45.363027232033865, 40.903791495731895, 35.121045521327424, 34.17881073270525, 35.82261208125523, 37.265923159463064, 38.30113526753017, 41.787157671792166, 43.85872139249529, 42.89376252038138, 44.39066505432129, 43.560702732631135, 43.78309719903128, 40.21097271783011, 24.273655108043126, 6.973162165709904, 0.8897404968738556, 1.2180870664971215, 2.4056563419955115, 0.9242224522999355, 2.1841953226498196, 2.2680253386497498, 3.40108089361872, 5.687436665807452, 4.092512854507991, 0.6275394207664898, 0.03231001911418779, 0.07182832607733351, 3.2612957315785542, 21.66586068698338, 33.77844163349697, 22.56382850238255, 20.701391662870133, 28.288458006722585, 4.748024582862854, 0.13367502205073833, 0.0234594305511564, 0.035528636404446194, 0.09628667043788092, 0.02433413852538381, 0.015958071553281376, 0.05269616609439254, 0.046732009521552494, 0.03804210992529988, 0.049161677182252915, 0.046930070500820875, 0.07864040375820228, 0.03205742427547063, 0.0447666056986366, 0.010135362390428782, 0.04496482613363436, 0.059916487761906216, 0.03677732404321432, 0.008066613443328865, 0.040365708991885185, 0.015551065893045493, 0.05848932505718299, 0.011026513812664365, 0.03981558333284088, 0.023231410554477146, 0.016027205789993917, 0.02542230174211519, 0.038235193850206475, 0.07011459089283432, 0.01634767109395138, 0.01567844387942127, 0.0453705968601363, 0.07113223057240248, 0.07986936638397829, 0.03840294127751674, 0.008734167220869234, 0.030980304216167757, 0.0664110721221992, 0.02837886880817158, 0.05281896396939244, 0.013640821878133076, 0.04287634284368583, 0.051532756736768146, 0.11985922125833375, 0.07432034771357264, 0.034998106836740456, 0.014553704232509648, 0.05972402130386659, 0.04335713579452463, 0.0320784249342978, 0.04625088069587946, 0.047016088385134935, 0.07118245573448283, 0.013273915092992996, 0.034477477094956806, 0.005748002033215016, 0.02226206730119884, 0.036679916948612244, 0.024749028762536388, 1.5379288239138467, 28.87612795829773, 39.60123355048043, 25.76947546005249, 31.178189482007706, 47.39270373753139, 31.90986258643014, 7.300550426755633, 0.23646389001182147, 0.04966439359954425, 0.06521243322640657, 0.535984202155045, 1.4871158876589365, 4.3014838354928155, 4.852968003068652, 4.725716957024165, 1.6613581436020988, 0.21839826154921735, 0.2744694777897426, 3.51495600598199, 16.972064188548497, 34.41138431004116, 49.360298088618684, 57.001089641026084, 52.923626150403706, 54.7176718711853, 53.56698070253645, 48.80316373280117, 51.7833433832441, 50.647205216544016, 52.17245987483433, 52.05736296517508, 48.62847212382725, 47.54691900525774, 42.16754722595215, 39.199387959071565, 41.0897912979126, 43.74778992789132, 50.23049395424979, 52.55154316765921, 50.752849102020264, 50.61343002319336, 53.59009388514927, 49.84831523895264, 42.64038256236485, 37.56254870550973, 38.59342861175537, 36.743119852883474, 37.6997652053833, 37.67478295734951, 39.45700979232788, 41.20116049902779, 44.793233258383616, 49.7702557018825, 50.25720282963344, 51.79589877809797, 49.91965239388602, 46.514083181108745, 55.52439941678728, 51.70723281587873, 51.0752455166408, 48.83954450062343, 49.53908566066197, 45.67193371909005, 41.92245299475533, 38.96574783325195, 36.05788155964443, 38.08733919688633, 39.087362153189524, 36.89537225450788, 35.53583908081055, 37.63040828704834, 36.69238063267299, 38.747605664389475, 39.79997982297625, 43.04248523712158, 46.835600648607524, 49.06480162484305, 47.2512766293117, 47.413423265729634, 49.7748658316476, 48.811762128557476, 46.2929185458592, 40.9484406198774, 37.02073860168457, 35.54842921665737, 36.768845558166504, 38.74824142456055, 40.373348644801546, 42.73670891353062, 45.35160786764962, 44.92098978587559, 45.27760260445731, 44.339012145996094, 43.599042892456055, 41.85739353724888, 27.899549961090088, 8.445519753864833, 1.4988116600683756, 1.9389593047755105, 3.3533678310258046, 3.137747641120638, 4.546863377094269, 3.222564084189279, 4.890668060098376, 6.570520571299961, 0.43865180068782395, 0.13721071875521115, 0.07361490199608461, 0.02392947381096227, 2.6060882040432523, 22.10236736706325, 36.66310787200928, 30.275055680956157, 22.402468749455043, 33.00841447285244, 7.689313428742545, 0.23919656766312464, 0.0324940547746207, 0.026252182300335596, 0.056749140577656884, 0.041538858719702275, 0.055109270715287755, 0.01667922705278865, 0.035313384740480354, 0.038965429844600816, 0.006057602295186371, 0.022761899944660918, 0.03611463960260153, 0.015933481444205557, 0.049263538859252415, 0.016584193134414296, 0.02988155585314546, 0.04914303443261555, 0.05123033028628145, 0.01676608292785074, 0.02772651506321771, 0.007936447526195219, 0.03393004861261163, 0.0033299390176710275, 0.03148290528250592, 0.020535763951816728, 0.014398584341896432, 0.1403257373188223, 0.12667233709778103, 0.1629028365548168, 0.12443891194249902, 0.16531990042754582, 0.10420006473681756, 0.1619826073625258, 0.20810643237616333, 0.10433791591120617, 0.07612337810652596, 0.16161362001938478, 0.11258471517690591, 0.14280342151011738, 0.10641101002693176, 0.13063751932765755, 0.15609532541462354, 0.27745478759918896, 0.27261751145124435, 0.11245146446994372, 0.17171000396566732, 0.09979982620903424, 0.17161579616367817, 0.16142111963459424, 0.16286691491092953, 0.08879405606005873, 0.09125959447452, 0.149338053007211, 0.19210664448993547, 0.17197050713002682, 0.1499948613345623, 0.12076159140893392, 0.14194772099809988, 0.20313495557223046, 1.7002642559153693, 31.620331151144846, 49.17419753755842, 33.103073256356375, 35.002186162131174, 49.538929326193674, 37.96721526554653, 12.766088553837367, 0.8131127229758671, 0.2681947387754917, 0.3187096081674099, 16.287479025977, 16.959844044276647, 12.427054677690778, 10.492281011172704, 6.109490658555712, 1.445216947368213, 0.16618672891386918, 0.5004359696592603, 2.7929118020193915, 15.452870096479144, 32.902364117758616, 49.399694374629426, 58.92692879268101, 55.447809423719136, 54.96560444150652, 54.74223027910505, 47.470593043736045, 54.26492725099836, 53.35707214900425, 55.05953713825771, 54.09291764668056, 51.58816153662545, 50.58368131092617, 43.990594727652415, 41.41213212694441, 45.11004332133702, 45.8795736857823, 51.257413387298584, 55.41268627984183, 52.158400194985525, 52.58918503352574, 55.03145946775164, 51.270979745047434, 44.44899518149239, 39.684271471840994, 38.72554513386318, 37.56543220792498, 39.925030027117046, 38.14917469024658, 42.18106494631086, 41.86584602083479, 46.23983083452497, 49.68746096747262, 52.20164925711495, 54.49007320404053, 50.72571638652256, 48.20914486476353, 55.882922989981516, 52.760524136679514, 53.08887168339321, 50.31281968525478, 52.24732324055263, 46.713232449122835, 43.367431640625, 40.99253041403634, 38.63902269090925, 39.500943252018516, 41.54278257914952, 38.0942074911935, 38.556078570229666, 39.48063366753714, 39.172522749219624, 41.50855227879116, 42.04774638584682, 45.90430927276611, 49.175674029758994, 51.37287507738386, 48.04521254130772, 49.20986611502511, 50.91763605390276, 50.73065308162144, 48.23166397639683, 42.912137031555176, 38.1277151788984, 36.88115276609148, 40.51499114717756, 40.318398816244944, 42.210264750889365, 45.205956254686626, 48.98248284203665, 45.30656617028372, 46.12395225252424, 44.68023470469883, 44.62409326008388, 43.57874025617327, 27.070282459259033, 8.466950603893824, 1.6405777101005827, 2.8161850103310178, 5.137203173977988, 4.050184862954276, 6.9258818456104825, 7.152150801249912, 9.745547686304365, 13.773118768419538, 9.641649535724095, 1.3326311601059777, 0.22148916497826576, 0.1528977562806436, 4.700588362557547, 28.667444024767192, 42.667793205806184, 30.891308784484863, 28.769643340791973, 39.34131186349051, 8.764892833573477, 0.2932404705456325, 0.16100988670119218, 0.10099499779088156, 0.186193157519613, 0.1209027674049139, 0.08270254864224366, 0.14080935636801378, 0.15927979882274354, 0.1398216536534684, 0.09567945623504263, 0.10830467234232596, 0.16201160794922284, 0.17134867049753666, 0.153912166133523, 0.10383565071970224, 0.11975560896098614, 0.1022509593250496, 0.10693120889897857, 0.09343631445829358, 0.1012445901121412, 0.061642429791390896, 0.18474250393254416, 0.10470588545181922, 0.10900038108229637, 0.14040482736059598, 0.2539538900767054], [0.08564626425504684, 0.022688188989247595, 0.03759954563741173, 0.009564651675256235, 0.010983218189461954, 0.016256011190957258, 0.0190942213937108, 0.017542690005419508, 0.033220684355390925, 0.024750808220622793, 0.01868030146163489, 0.018233942466654947, 0.007722819257261497, 0.06073392568422215, 0.08226926332073552, 0.031179345678538084, 0.033847311445112736, 0.021457742068118284, 0.03609985771722027, 0.042237366416624615, 0.025644905333008085, 0.06595783787114279, 0.040998100236590417, 0.02413215222103255, 0.0094923266276185, 0.03435532043554953, 0.03678644694654005, 0.03323534410446882, 0.005179322682254548, 0.04724678350612521, 0.01073896000161767, 0.03117528125377638, 0.05510198324918747, 0.05469711158158524, 2.618968210050038, 26.544357674462454, 36.59227098737444, 24.200912679944718, 29.56795140675136, 37.56147868292672, 33.38638257980347, 10.717851672853742, 0.852741502225399, 0.07715572842529841, 0.7236416382449014, 0.6918655719075884, 2.2838780879974365, 3.4160405823162625, 4.160929594721113, 2.3266286168779646, 0.791334083037717, 0.090059741001044, 0.01649587501638702, 2.632014972823007, 15.051823547908239, 33.37735339573452, 51.03947966439383, 57.35775804519653, 54.232343673706055, 52.07205145699637, 51.15816184452602, 48.05540207454136, 48.516731194087434, 50.11146783828735, 49.467324665614534, 48.44379595347813, 42.57498264312744, 39.10027190617153, 40.63004289354597, 47.57486118589129, 49.72312259674072, 50.41487830025809, 52.26246336528233, 51.19851698194231, 49.11698259626116, 51.60544865471976, 46.35922867911202, 43.97746958051409, 38.7464314188276, 37.45949649810791, 37.928864683423726, 38.347632612500874, 37.04711396353585, 38.1118871825082, 41.176765373774934, 43.13394784927368, 44.91405895778111, 49.685366085597444, 47.10142830439976, 52.51336281640189, 41.11882781982422, 50.018480096544536, 50.39685467311314, 48.6388909476144, 49.16807964869908, 46.506235190800254, 44.98784187861851, 40.06962203979492, 35.46020793914795, 36.85760532106672, 38.54509694235665, 36.28745004108974, 34.56396675109863, 37.03443002700806, 36.500485283987864, 37.32657398496355, 39.504219327654155, 42.60792057854788, 44.265847614833284, 45.56138787950788, 48.3156920160566, 49.01755734852382, 48.06738076891218, 47.84071316037859, 47.818204471043174, 46.84136765343802, 42.51301513399397, 36.59933730534145, 36.02984210423061, 38.01448038646153, 39.14409072058541, 41.56550318854195, 43.97233138765608, 43.05552700587681, 44.87361696788243, 46.789912768772666, 45.28912966591971, 42.87786504200527, 30.587300777435303, 11.414529306547982, 1.9744600398199899, 0.38874278164335657, 2.048792085477284, 4.2556131311825345, 2.382586802755083, 2.709156479154314, 1.7893458072628294, 3.0129777533667426, 4.79228504214968, 0.41992594408137457, 0.0357576080464891, 0.09076024019824606, 2.708788658891405, 19.512857130595616, 29.656679902757915, 41.26882553100586, 25.39299600464957, 23.713814428874425, 17.524367809295654, 0.1810385983969484, 0.029865661170333624, 0.026975076545828154, 0.008360402143028165, 0.03153476571398122, 0.033948392806840796, 0.06553036759474448, 0.0635841798835567, 0.07281352499766008, 0.020708590213741575, 0.03968450054526329, 0.05900543236306735, 0.050988096677299054, 0.03417836528803621, 0.03401424802307572, 0.04794051770919135, 0.05254256612222109, 0.026055539459256188, 0.04230314360133239, 0.1263724381902388, 0.07176453021488019, 0.05572887496756656, 0.04252772172912955, 0.01789373518632991, 0.03719799879140087, 0.053699899198753495, 0.07013633115483181, 0.045178588413234265, 0.02240019497860755, 0.036553346418908665, 0.036566499820245166, 0.055537355065877946, 0.036895280570856163, 0.01639950099135084, 0.01190750247665814, 0.019173993363178203, 0.016575799656233618, 0.050966661756059954, 0.06956771880920444, 0.06906406940626246, 0.02412424559172775, 0.02262394529368196, 0.0348286495011832, 0.04302357815738235, 0.04859732264386756, 0.09729031872536455, 0.009490685421042144, 0.010084292452250208, 0.020008347163509046, 0.03494770525555525, 0.04181729217192956, 0.012107448086940815, 0.039077537400381904, 0.045561383944004774, 0.03392641845026186, 0.022612025129741857, 0.03092910535633564, 0.033455739063876014, 0.022610388164009367, 0.055658595703010044, 0.026698846636073928, 4.984513904367175, 34.0532672064645, 36.153738907405305, 24.50131630897522, 34.16720724105835, 45.416107995169504, 36.7998241015843, 9.126986043793814, 0.6299478943858827, 0.07631441285567624, 0.13752228846507414, 0.3297887279519013, 1.5153796396085193, 3.007665421281542, 5.318357041903904, 5.548705892903464, 2.0771733054092953, 0.40733111277222633, 0.26692042286906925, 3.7518144505364552, 18.58588058607919, 36.048195770808626, 52.72773906162807, 56.37670367104666, 56.88430084500994, 52.53429079055786, 52.07947908129011, 50.78596074240548, 50.62441165106637, 52.5231945174081, 50.54817601612636, 49.76758411952427, 44.72070448739188, 40.78969860076904, 42.16382646560669, 49.046576499938965, 51.20226900918143, 51.52389417375837, 53.68865755626133, 51.6127164704459, 49.24224819455828, 54.053229536329, 49.569372858319966, 44.636693818228586, 41.00737871442522, 38.662743840898784, 39.61997284208025, 39.022559779030935, 38.09730986186436, 38.507997035980225, 40.64042002814156, 45.05738639831543, 47.02381345203945, 50.08530787059239, 49.835596561431885, 53.26282678331648, 44.61936501094273, 52.17258841650826, 51.499363558632986, 50.012039116450715, 50.77599007742745, 47.382201535361155, 45.96065221514021, 40.75380768094744, 37.047360624585835, 39.412996428353445, 39.536247049059185, 38.69037682669503, 35.83036279678345, 37.96786144801548, 36.82277052743094, 38.93961565835135, 41.42629255567278, 43.65843261991228, 44.78765385491507, 47.89686502729143, 50.29408734185355, 48.35909046445574, 46.968252182006836, 49.22686835697719, 48.12110424041748, 48.49776608603341, 44.317566531045095, 36.754817145211355, 37.46678168433053, 39.51908152444022, 40.5145012991769, 43.521007674080984, 44.27277149472918, 46.446185384477886, 45.28780950818743, 48.30036081586565, 45.158097062792095, 43.69765520095825, 32.58353907721383, 13.825602855001177, 3.0364987083843777, 1.13600897363254, 3.0581358330590382, 3.9946435689926147, 3.127822139433452, 2.76268909232957, 3.7367572699274336, 3.8529806562832425, 2.6511976463454108, 0.2872254747365202, 0.011044242236364101, 0.11954766511917114, 2.403695430074419, 19.533991813659668, 39.22761501584734, 39.79478257043021, 21.718491554260254, 25.276565040860856, 23.3131674017225, 0.4552955590188503, 0.012061042228846677, 0.028679961937346628, 0.010681310818264527, 0.004458900424651802, 0.10177468881011009, 0.03400042965742094, 0.02624658608276929, 0.016729196067899466, 0.01564113123874579, 0.03440055497256773, 0.05461869328948004, 0.021424354752525687, 0.06724529700087649, 0.03203826583921909, 0.051173435124967775, 0.005870469122393323, 0.022449020662211945, 0.032553063572517464, 0.04695522718663726, 0.023350160968090807, 0.01748711459471711, 0.039750321834747276, 0.0291515844874084, 0.010118204784313483, 0.06999887353075401, 0.03481601857181106, 0.16713122251842702, 0.10369169273014579, 0.19590771624020167, 0.1093908508441278, 0.0873118709506733, 0.1323310884514025, 0.10882402983094965, 0.09933266841939517, 0.09346839559397527, 0.09327196649142674, 0.12618239410221577, 0.14919921117169516, 0.1271719288613115, 0.11761369103831903, 0.1873073120202337, 0.09422129126531736, 0.19636090977915696, 0.10518964699336461, 0.21422618042145455, 0.1290193083030837, 0.1541840144033943, 0.13569297162549837, 0.12683309561439923, 0.13669945618935994, 0.14532575330563954, 0.12965962822948182, 0.12752031588128634, 0.20258925056883267, 0.09101718783910785, 0.13964030838438443, 0.15405866184404918, 0.15886969225747244, 0.15347495887960705, 0.16081180875854834, 4.588853078229087, 37.67464746747698, 47.77338511603219, 32.402163301195415, 38.30067668642317, 46.11765718460083, 44.096919536590576, 12.595349601336888, 1.5402460481439317, 0.15493938672755445, 1.752428291099412, 4.011020473071507, 6.57884190763746, 8.484678932598658, 6.520299426146916, 5.891946469034467, 2.284795250211443, 0.4133075677922794, 0.2391817213169166, 3.5463499213968004, 17.847752605165752, 36.512078353336875, 53.54507998057774, 59.344876834324424, 58.123935903821675, 53.084021840776714, 53.269966057368684, 52.569667543683735, 52.703969274248394, 54.10263817650931, 52.36377852303641, 52.896208558763774, 47.85565178734915, 43.06147813796997, 44.532939842769075, 52.479292324611116, 53.29303755078997, 54.507273469652446, 57.42655563354492, 52.890267848968506, 49.446942125047954, 56.30492183140346, 50.65295832497733, 47.34894745690482, 41.96750858851841, 40.78917401177542, 41.13499627794538, 42.45531381879534, 40.70075123650687, 41.26792573928833, 45.004816327776226, 46.751854010990684, 49.345644337790354, 53.206303187779014, 50.80808728081839, 54.32838862282889, 45.19368226187569, 52.56408814021519, 54.00161484309605, 51.72640636989048, 53.78588022504534, 50.30627448218209, 48.77094841003418, 43.79188667024885, 37.9016763823373, 40.8453745160784, 41.57688086373465, 39.29124314444405, 38.130730697086875, 40.81847109113421, 39.968473638807026, 42.049393108912874, 43.010613850184846, 46.271799496241975, 47.00047445297241, 48.76050179345267, 53.15351077488491, 50.49909046718052, 47.531959533691406, 48.14696543557303, 49.30132177897862, 50.24030828475952, 46.1435809135437, 39.55488906587873, 38.592188358306885, 42.25929124014718, 42.40977185113089, 44.734382016318186, 47.143461431775776, 47.4908435685294, 47.633257320949006, 49.10101910999843, 46.32496016366141, 43.542626993996755, 33.453790528433665, 12.966339979852949, 3.0860786650862013, 1.0774655150515693, 3.6464380707059587, 8.445616160120283, 6.987431160041264, 7.318353448595319, 6.112058886459895, 9.003444467272077, 11.706332802772522, 2.395824206726892, 0.34538252119507107, 0.2821231356688908, 3.8200739877564565, 25.698461396353586, 38.6936285836356, 48.240251949855256, 33.073873451777864, 32.24308776855469, 25.333312715802872, 0.5520524542246545, 0.12256220621722085, 0.14128621720841952, 0.1590037029236555, 0.11993749705808503, 0.2874876335263252, 0.23273620860917227, 0.13607322264994892, 0.20947074916745934, 0.09114720193403107, 0.08173001118536506, 0.18818617771778787, 0.09741852791713816, 0.12287289383155958, 0.0925660322287253, 0.09837138107312576, 0.0950692564781223, 0.12418661905186516, 0.16875744025622094, 0.21365393112812722, 0.12756424423839363, 0.15221521790538514, 0.17849272143627914, 0.12083069341523306, 0.18027772993913718, 0.17976346824850353, 0.17549385449716023], [0.03999874368309975, 0.04929505681086864, 0.026675935901169266, 0.03577078180387616, 0.05967157054692507, 0.02499877884318786, 0.13025758042931557, 0.033562526905110905, 0.07698667142540216, 0.07853023681257452, 0.029650623244898658, 0.04017585489366736, 0.029343708285263607, 0.046230629818247895, 0.01711374561169318, 0.022370190160082917, 0.03901128863383617, 0.03619674573253308, 0.019840316447828497, 0.033956826997122595, 0.022269965448815907, 0.04215583364878382, 0.026251756519611393, 0.04508828218760235, 0.09497896382319075, 0.01710554551599281, 0.043016256764531136, 0.06283398478158883, 0.043621971404978206, 0.006027678900863975, 0.01947461491051529, 0.0009071086574944534, 0.0675768292109881, 0.03638447940881763, 0.11218986207885401, 4.7301928997039795, 28.374155351093837, 31.22196660723005, 25.483833278928483, 20.860759019851685, 36.38934537342617, 34.55755703789847, 12.983480317252022, 1.088374838232994, 0.1320256662688085, 0.021280936198309064, 1.1225454275097166, 1.3229340804474694, 3.7893690296581815, 3.4606960032667433, 2.543760257107871, 0.6932781732508114, 0.2626625070614474, 0.374029238309179, 6.889110241617475, 22.336109978812082, 40.977042879377095, 51.55721426010132, 54.17954431261335, 52.71264410018921, 50.90157181876046, 50.10655198778425, 52.21225568226406, 51.802829606192454, 50.96638461521694, 46.529716627938406, 40.823494638715474, 41.34216724123274, 48.65766845430647, 50.65710639953613, 52.45591163635254, 51.59178849628994, 51.786588191986084, 48.70445762361799, 50.50990186418806, 52.289359842027935, 52.72644669669015, 49.35749101638794, 46.33297143663679, 41.839276109422954, 37.666778632572715, 39.18780878611973, 39.038439886910574, 39.887711252485005, 48.449562958308626, 50.88408667700631, 49.93835694449288, 49.83994613374983, 51.40564625603812, 48.55448770523071, 35.70933212552752, 50.97014706475394, 50.227429798671174, 49.00309467315674, 49.16609593800136, 47.93861675262451, 47.35256052017212, 44.01272126606533, 40.46679149355207, 38.12666947501046, 38.35981280463082, 36.64316654205322, 36.48174251828875, 37.05901622772217, 38.9460323197501, 40.023110798427034, 42.43165520259312, 44.69069521767752, 45.59047998700823, 47.6610119002206, 47.94628061567034, 48.09877273014614, 46.85984638759068, 49.21434422901699, 47.53944969177246, 46.53769663402012, 43.47814771107265, 37.964571475982666, 37.04552630015782, 40.895783696855815, 43.93744100843157, 45.147549697331016, 42.94634996141706, 45.369989327022004, 44.90489428383963, 46.73446614401681, 41.8027320589338, 32.006032603127615, 13.717191849436078, 3.0960085093975067, 0.10462489551199333, 1.2273314275911875, 2.56283284510885, 1.9580282015459878, 2.148560617651258, 2.4837727674416135, 1.232711830309459, 2.695537575653621, 2.4897223796163286, 0.01849783830610769, 0.054272535257041454, 4.037378030163901, 18.997467551912578, 35.03491565159389, 25.89989835875375, 46.0867793900626, 35.102455615997314, 20.82644534111023, 3.861387542315892, 0.08158410580030509, 0.0181521603371948, 0.04036015518275755, 0.07804409361311368, 0.027210986208436743, 0.03576427126037223, 0.023137587821111083, 0.06200987007468939, 0.03460284322500229, 0.027651007686342512, 0.02486200993215399, 0.03255271751965795, 0.044143422174134424, 0.04258659142734749, 0.009143334863308285, 0.04279206200901951, 0.033739220816642046, 0.057624525390565395, 0.07225816444094692, 0.013567571478363658, 0.026404854375869036, 0.02399992270927344, 0.013667966671554106, 0.023756033474845544, 0.014064068274040307, 0.013031905400566757, 0.02543795045598277, 0.054103179701736996, 0.011553263092147452, 0.02143307732019041, 0.01633300625586084, 0.020487046833815317, 0.03895699565431901, 0.04387165193579026, 0.03340778699410813, 0.05787305241184575, 0.022546490521303246, 0.022993680721681033, 0.06970174983143806, 0.04031522259382265, 0.01802638708613813, 0.03944140858948231, 0.05191008327528834, 0.05548759809296046, 0.04488644855363028, 0.03476343210786581, 0.033940996775137525, 0.02412452209474785, 0.012404502236417361, 0.016971068356984427, 0.04714969193030681, 0.02939145000917571, 0.04561838088557124, 0.024295119369136434, 0.06928521075419017, 0.022247090336999724, 0.011292101748819863, 0.041996432202202935, 0.046797281197671375, 0.04056192774857793, 0.03788615882928882, 0.02823583871525313, 8.692898205348424, 36.37381962367466, 33.82448387145996, 24.91709998675755, 27.097293581281388, 45.034992354256765, 39.421230043683735, 10.250159740447998, 0.8538412717836243, 0.07723468954541854, 0.20316527251686367, 0.17320793787283556, 1.7050131325210844, 5.24162243945258, 6.397742322513035, 4.017039350100926, 1.8527907856873103, 0.6105528665440423, 0.9498568539108548, 9.225138902664185, 25.383914709091187, 43.082395689828054, 51.98377806799752, 55.65585238592965, 52.770136969430105, 50.87458154133388, 51.549904755183626, 53.75025681086949, 54.472372668130056, 53.68534673963274, 47.89062554495675, 44.079441343035015, 43.340587275368826, 49.48503909792219, 53.056892599378315, 54.714791842869346, 54.29860169546944, 53.140875475747244, 48.90248128346035, 49.88909421648298, 54.466591766902376, 53.47580991472517, 48.91025284358433, 47.79767949240548, 42.68651165281023, 39.63009984152657, 41.1786344391959, 41.088999203273225, 41.80252708707537, 48.21230629512242, 51.75283036913191, 51.17822476795742, 50.75924491882324, 52.85703114100865, 50.40938227517264, 39.043532916477744, 52.25381980623518, 51.247390610831125, 50.48995706013271, 51.252261298043386, 50.315025738307405, 48.847597462790354, 44.57061644962856, 42.25767925807408, 39.3680693762643, 41.23764548982893, 37.70736653464181, 37.0702862058367, 39.33846310206822, 40.63236706597464, 41.50513029098511, 45.272909096309114, 46.55944102151053, 47.162530762808665, 49.16505023411342, 49.44454847063337, 48.61331115450178, 46.88466535295759, 48.36381523949759, 48.53653008597237, 48.14988367898123, 44.14469535010201, 38.986234596797395, 39.38132653917585, 42.71421759469168, 45.01339735303606, 45.92570972442627, 44.38620778492519, 46.469784940992085, 45.90659870420183, 45.81295435769217, 44.37951666968209, 33.94233226776123, 16.73834068434579, 3.815342264516013, 0.7261142741356577, 2.2926417206014906, 3.1127169728279114, 3.251858340842383, 4.205790204661233, 3.769785097667149, 4.199710530894143, 1.8890336751937866, 0.5382564259426934, 0.04371305116053138, 0.05834095659000533, 3.538376429251262, 17.29711307798113, 39.42128215517317, 30.361512116023473, 49.54173987252371, 35.88846710750035, 26.340365512030466, 6.602143560137067, 0.07137714778738362, 0.013611219939775765, 0.059528189312134466, 0.05151336759861026, 0.06187876353838614, 0.03828849277592131, 0.05035287594156606, 0.042471081018447876, 0.018934407737106085, 0.032304176927677224, 0.008952719957700797, 0.06005944151963506, 0.039671133405395916, 0.07742746134421655, 0.016953368771022985, 0.04953091558335083, 0.04254042390467865, 0.06624897010624409, 0.04446662536689213, 0.023237072929207767, 0.023197027488744686, 0.04111980567021029, 0.04326235463044473, 0.014791001499231373, 0.04071663373282977, 0.012079856308576251, 0.008298792011503662, 0.24200475269130298, 0.18077976442873478, 0.09984478593936988, 0.08687383588403463, 0.15061369884227002, 0.07439649291336536, 0.2541892331625734, 0.1749846682484661, 0.1161474311458213, 0.17689790629914828, 0.09872109802173716, 0.12274697130279881, 0.1326596758195332, 0.11300681145595652, 0.10316177723663193, 0.07937629534197704, 0.13974294359130518, 0.15165727213025093, 0.09518304001539946, 0.11607614425676209, 0.16569304040500096, 0.14037269194211277, 0.07139378546604089, 0.09039592117603336, 0.14615626659776482, 0.12807410902210645, 0.17628600341933115, 0.16783919238618442, 0.1024202945243035, 0.06796608439513616, 0.1562197551663433, 0.15266450308263302, 0.1338682281119483, 0.11571145882563931, 0.20362576709261962, 7.484481402805873, 40.74747439793178, 41.44273199353899, 34.041576862335205, 29.11393005507333, 45.43006345203945, 43.295927728925435, 15.640721593584333, 2.048805330480848, 0.19628635235130787, 0.5133188526545251, 2.8904727612222945, 6.648306957312992, 11.739593829427447, 8.492093529020037, 7.039882676942008, 2.2528991103172302, 0.9198204427957535, 0.7008761912584305, 8.431874360357012, 25.37957034792219, 43.84999792916434, 54.141534192221506, 56.37835039411272, 54.60800150462559, 50.396628856658936, 54.258343832833425, 57.026200430733816, 56.822194371904644, 57.87344987051827, 50.029242856161936, 45.09144646780831, 46.84029415675572, 52.257606574467246, 55.54895087650844, 57.29226432527815, 57.32106460843767, 53.98148591177804, 50.172292368752615, 51.013569831848145, 55.588322843824116, 57.788713114602224, 52.55539246967861, 50.793641975947786, 46.4693089893886, 42.49186829158238, 43.22818626676287, 43.74738693237305, 44.69650043760027, 52.24852875300816, 57.034225600106375, 55.089167731148855, 52.401326588221956, 55.312541893550325, 51.99123001098633, 39.79775987352644, 52.6347200529916, 53.08237164361136, 51.89993415560041, 52.50275639125279, 51.73664801461356, 51.731794697897776, 48.151540824345176, 44.34422329493931, 41.870935576302664, 42.52419131142752, 39.723313399723594, 40.14854662758963, 40.946995394570486, 42.5857766696385, 43.78457369123186, 47.34334373474121, 49.38143450873238, 49.43039151600429, 51.61813259124756, 50.6944842338562, 50.273437295641216, 47.02345561981201, 49.70448752811977, 50.913995197841096, 50.90605340685163, 46.70296995980399, 40.389214856284006, 40.34910985401699, 44.35796683175223, 47.06082650593349, 48.86212614604405, 44.61178800037929, 48.27811615807669, 47.14212390354702, 48.14081627982003, 42.357973030635286, 34.09204510280064, 15.783871855054583, 4.102085300854274, 0.533166381929602, 3.5427140593528748, 6.162786381585257, 5.204015748841422, 5.548969490187509, 9.735446742602758, 9.25170533997672, 10.489684990474156, 4.920762445245471, 0.1275189452405487, 0.2593771762081555, 5.600770481995173, 24.897612026759557, 44.34514045715332, 31.514742851257324, 51.95964697429112, 43.21469633919852, 31.249623911721365, 6.4736765793391635, 0.22944941212024006, 0.11214758256184203, 0.1552837568202189, 0.1436531509139708, 0.22663493028708867, 0.15785484814218112, 0.1256330114390169, 0.2290038860269955, 0.1090089984770332, 0.08828714290367705, 0.09365492487060172, 0.19979767607791082, 0.10811988011534725, 0.09443599331591811, 0.18041923163192614, 0.13462104914443834, 0.09208496447120394, 0.14568129208471092, 0.1575796479093177, 0.14810545343373502, 0.13765091156320913, 0.09406910264598471, 0.16339138176824364, 0.11306433086948735, 0.14203921466001443, 0.07838312363518135, 0.10654661525040865], [0.013430096042741622, 0.02271050600601094, 0.046758950754467926, 0.027092271417911564, 0.031924434804490635, 0.005818767298478633, 0.011440633912570775, 0.04007986593725426, 0.024659955774300864, 0.04825581596898181, 0.02393829306986715, 0.007057975803036243, 0.07460810762963124, 0.052442278646464856, 0.09118899969117981, 0.05865345589284386, 0.05795930099806615, 0.02181448015783514, 0.06409635847168309, 0.04303869591759784, 0.033042250001536946, 0.0769186754311834, 0.01038666207542909, 0.018804129013525586, 0.08014806785753795, 0.023884291860408018, 0.07006410788744688, 0.04563626706866281, 0.05854180295552526, 0.0409304367245308, 0.040994582032518725, 0.03413513582199812, 0.05124118684657982, 0.10187735115843159, 0.028556753548660448, 0.07949471327343158, 5.455080653939929, 27.104959181376866, 35.414137908390586, 24.294053282056534, 20.12314346858433, 29.57116494859968, 37.11666195733206, 16.293492691857473, 1.9813921707017081, 0.11457914672791958, 0.11424781807831355, 0.9578679097550256, 4.996813084397997, 6.139236765248435, 2.068904514823641, 1.7056653946638107, 0.6933850018041474, 0.22171012312173843, 2.2518555777413503, 10.564256531851631, 23.507928882326397, 40.634197916303364, 50.10890047890799, 53.45643138885498, 51.80014760153634, 49.789477893284385, 50.07074097224644, 53.91394942147391, 50.83918741771153, 46.68078783580235, 45.90834617614746, 48.968294620513916, 51.203047207423616, 53.31264884131295, 52.530083656311035, 53.99618482589722, 50.907432624271934, 51.94741467067173, 51.63745205742972, 52.023118768419536, 50.38311461039952, 51.06098781313215, 49.66719307218279, 50.1924421446664, 42.84247439248221, 38.18703195026943, 40.016141755240305, 44.43300042833601, 51.75593968800136, 54.384835788181846, 51.01618235451834, 52.975657735552105, 47.786315713609966, 55.05480888911656, 41.274370193481445, 48.90086235318865, 51.87969057900565, 49.89024414334978, 51.25342512130737, 50.004722663334434, 51.94283580780029, 50.28016315187727, 49.74064595358712, 45.23655612128121, 40.07263060978481, 37.32214103426252, 36.00594030107771, 37.75834894180298, 39.757317883627756, 44.053955350603374, 44.67213657924107, 46.79940400804792, 47.63294465201241, 47.640417439596995, 49.79118367603847, 51.16350153514317, 49.406399386269705, 50.591199261801584, 49.96098027910505, 47.617589133126394, 44.89972482408796, 38.370554719652446, 39.60515580858503, 44.50791937964303, 45.1527886390686, 45.35979631968907, 46.144859382084434, 47.16069991247994, 47.03290516989571, 43.086161613464355, 31.70906659534999, 14.654346636363439, 2.8497167995997836, 0.2326702821467604, 0.6780514674527305, 0.7681965274470193, 2.907784415142877, 3.0216586589813232, 2.9478036505835394, 1.5472169369459152, 1.7822384514978953, 0.5126727787511689, 0.1156859187675374, 0.11265836336783, 4.207879441125052, 20.039395093917847, 34.637767042432515, 25.65980509349278, 21.434272016797745, 34.022163595472065, 27.81049142565046, 9.532745208059039, 0.11127920701567616, 0.044187951034733226, 0.03315671546650784, 0.02977231510781816, 0.01451293784858925, 0.04496874806604215, 0.018760322792721645, 0.03207200260034629, 0.03723587461614183, 0.033437991980463266, 0.030561732926539013, 0.05936004833451339, 0.00820493365504912, 0.019202588525201594, 0.019543194444850087, 0.061033098559294424, 0.060507926025560925, 0.022733471023717096, 0.03060691657343081, 0.008137156488373876, 0.01025007721701903, 0.024993579568607465, 0.025539403315633535, 0.0751306474474924, 0.009464672932933484, 0.0315486281844122, 0.022080199560150504, 0.044180748385510275, 0.009073768060521355, 0.02716655912809074, 0.043690269347280264, 0.050956616045108864, 0.02371607454759734, 0.011990175183330263, 0.027056753502360413, 0.04250966591228332, 0.04362241245274033, 0.02217532168807728, 0.027707936774407114, 0.021688901985596334, 0.07612455875745841, 0.021199189691937396, 0.036412180600953956, 0.087663345304983, 0.011528359160625508, 0.08242185906107936, 0.04299224341022117, 0.0333518282111202, 0.04529326083138585, 0.03965719968878797, 0.061923099016504626, 0.023774895052026426, 0.08423628205699579, 0.05281588342040777, 0.04803602829841631, 0.059140135134969435, 0.05512898215757949, 0.08516869095287152, 0.027321276986705403, 0.029661859784807478, 0.05685941608888762, 0.05616402965305107, 0.03513938122029815, 0.18317489804966108, 10.097612040383474, 34.82932540348598, 35.86946725845337, 23.575866631099156, 24.686411108289445, 44.06955058234078, 44.27716275623867, 15.988746438707624, 1.2473289945295878, 0.20131521964711802, 0.03763285152880209, 0.3788630132164274, 2.3501350241047994, 7.3844464506421765, 7.829284889357431, 5.277306650366102, 2.9769163855484555, 0.2703405107770647, 2.7446107481207167, 13.583082931382314, 28.142248800822667, 43.368609360286165, 51.44718606131417, 52.67367860249111, 50.98264339991978, 51.655447891780305, 52.54757227216448, 54.8781544140407, 53.04173163005284, 48.3649616922651, 46.82674864360264, 50.971397740500315, 53.763573033469065, 54.74934523446219, 54.327356815338135, 54.35968678338187, 53.46573502676827, 51.513701166425435, 52.00064829417637, 51.72427674702236, 54.25349746431623, 53.64028072357178, 51.91044330596924, 50.947822502681184, 43.34679896490914, 39.19489247458321, 40.635809898376465, 43.45454468045916, 54.38949455533709, 55.2010372025626, 53.9493921824864, 54.04233823503767, 49.975224086216514, 53.390044825417654, 42.28170265470232, 49.2513016973223, 53.70352670124599, 52.73925570079258, 52.779166153499055, 52.3835391998291, 53.554432255881174, 52.34430967058454, 51.756179400852744, 46.17989567347935, 40.459561892918174, 38.52904660361153, 37.341634205409456, 40.43177604675293, 41.41780185699463, 45.89206307274954, 45.72286401476179, 48.236496448516846, 48.211163316454204, 48.725847652980256, 51.071153027670725, 50.60935490471976, 49.300932679857524, 50.88135603496006, 50.17547116960798, 48.78362192426409, 46.75075966971261, 39.43949338368007, 42.55736548560006, 45.750264235905235, 47.57671635491507, 46.3236608505249, 47.71000712258475, 48.18330104010445, 47.04493250165667, 44.980316979544504, 34.324702058519634, 17.24635648727417, 5.0497157999447415, 0.7163120486906597, 1.5097654951470239, 2.4867053415094102, 3.138983117682593, 3.759691536426544, 4.309209363801139, 3.9960809775761197, 0.8660228209836143, 0.045974225005401034, 0.09211622457951307, 0.08168036956340075, 3.309855171612331, 19.35558465548924, 39.969661780766074, 34.14774186270577, 21.00803824833461, 38.052483558654785, 33.8666490146092, 13.423821534429278, 0.2156952087368284, 0.034986642987600396, 0.024538465775549412, 0.05410894724939551, 0.03653506329283118, 0.046041291406644244, 0.03356442001781293, 0.03519009153491684, 0.05488612429637994, 0.007759070838801563, 0.029832803112055575, 0.016805500723421574, 0.11164850648492575, 0.01665695244446397, 0.04492806649899908, 0.03514025653047221, 0.02227357355877757, 0.07483819885445492, 0.044416366278060844, 0.017175590685967888, 0.023212162212335637, 0.01446704682894051, 0.02422700632762696, 0.0405663144774735, 0.03117355777482901, 0.03405705001205206, 0.014311976132116147, 0.014684644527733326, 0.06688061156975371, 0.17064416115837439, 0.10350932287318365, 0.08066809031047992, 0.1330800418342863, 0.05607305846310087, 0.08110191846000296, 0.13616004799093517, 0.14144054321306093, 0.1273753129478012, 0.13738776211227688, 0.08239539619535208, 0.13269083414758953, 0.1514381460313286, 0.16484469521258557, 0.16383403087300913, 0.12353032641112804, 0.10682860761880875, 0.15275265835225582, 0.08859134372323751, 0.1148381842566388, 0.0908294982675995, 0.1367198665227209, 0.09817915888769285, 0.2008923159113952, 0.12374192077134337, 0.15737721377185412, 0.19871638981359346, 0.10429201301719461, 0.15532123909464904, 0.111350371768432, 0.1679348386824131, 0.09068671414362532, 0.14111723484737532, 0.10900460157011237, 0.27587399099554333, 8.589897240911212, 39.67568349838257, 45.65026576178414, 33.46311501094273, 28.72705783162798, 37.84005628313337, 46.24882527760097, 21.877857174192155, 2.9744026575769698, 0.3088933506182262, 0.3527685920042651, 3.2228595997606004, 10.515821507998876, 13.03981717995235, 5.904671226228986, 2.7683123563017165, 1.6081492730549403, 0.9580749443599156, 3.3737742560250417, 13.107952083860125, 26.514772244862147, 43.36259569440569, 52.29746144158499, 53.317637647901265, 52.4121310370309, 52.590195996420725, 55.417126178741455, 56.98562642506191, 54.42124087469918, 50.0852175440107, 49.237794399261475, 53.78800637381417, 56.0293528011867, 57.811517102377756, 55.68595545632498, 55.99129751750401, 52.86957263946533, 52.63135365077427, 53.09050451006208, 53.09391260147095, 55.20529644829886, 55.03303670883179, 53.33440712520054, 54.46449341092791, 45.852920395987375, 41.251312596457346, 42.487852232796804, 47.535902636391775, 56.19026960645403, 57.18845476422991, 55.942733083452495, 57.09617921284267, 51.79671171733311, 54.22647244589669, 45.596556186676025, 49.998775005340576, 55.14365203039986, 54.474842752729145, 54.55289534160069, 55.281226362500874, 55.57820626667568, 54.47957100187029, 53.20043543406895, 48.653096539633616, 43.15282957894461, 40.69455344336373, 38.42665100097656, 41.465442180633545, 42.406697273254395, 48.44276067188808, 48.45820304325649, 49.910560676029746, 50.58115216663906, 50.8124611718314, 52.36518553325108, 53.70310286113194, 49.485178061894004, 51.52615928649902, 51.60292993273054, 51.75207648958479, 49.10299587249756, 41.5703877721514, 44.06940814426967, 48.38562216077532, 49.33834178107125, 48.10967097963606, 49.78139019012451, 50.23583017076765, 47.49872629983084, 44.45793056488037, 33.12490797042847, 16.70276764460972, 4.053024504865919, 0.9846207542078835, 1.8937960139342715, 2.3760079443454742, 7.485477600778852, 7.7589248248509, 7.777436562946864, 4.893302730151585, 9.230677485466003, 2.7533227034977505, 0.36902227412377087, 0.21226425069783414, 6.183487670762198, 26.590443338666642, 43.33093275342669, 35.95521150316511, 29.07637677873884, 41.1086209160941, 38.64048528671265, 14.462771773338318, 0.2612529455551079, 0.0667879440422569, 0.07724061315613133, 0.14823186450770923, 0.11329567738409553, 0.10226768521325928, 0.07871170421796185, 0.11071935455713953, 0.09518694159175668, 0.12020009011030197, 0.08417501713016204, 0.0950213111937046, 0.15827452205121517, 0.1022946909070015, 0.14734458497592381, 0.10549933716122593, 0.16436860790210112, 0.13622946212334291, 0.16881808771618775, 0.10094477262880121, 0.10989905321704489, 0.08409844445330755, 0.09064691806478159, 0.13951165814484867, 0.13329653521733625, 0.11649481393396854, 0.09735608912472214, 0.19164115589644226], [0.026946394870589887, 0.018281475541048815, 0.031842121721378396, 0.03180867333763412, 0.053084206700857194, 0.061252373935920854, 0.060455970599183013, 0.02950530479262982, 0.015103902834068452, 0.020372528782380477, 0.041006144269236496, 0.034834040461906364, 0.044296112909380875, 0.04023815458640456, 0.023348892107605934, 0.06673855347824947, 0.022168164839968085, 0.06545235642365047, 0.060274191067687104, 0.029959390605134622, 0.04193126909168703, 0.012602051769915436, 0.05500245912532721, 0.024561422311567833, 0.030814412582133497, 0.04644186455490334, 0.07114113973719732, 0.028624695260077715, 0.0578494326078466, 0.03814690626625504, 0.037176085502973626, 0.04220265595774565, 0.01926587548639093, 0.026988268962928226, 0.055806054933262725, 0.03632406604343227, 0.04943270103207656, 5.282598572117942, 26.871093239103043, 34.61841630935669, 22.846668822424753, 19.592268092291697, 29.777126925332205, 42.26340457371303, 20.559115137372697, 2.4496173773493086, 0.05715048725583723, 0.2093353678605386, 0.8836905700819833, 5.686060053961618, 11.384354148592267, 10.32369773728507, 4.355816142899649, 0.13960871579391615, 0.18223386497369834, 2.850904941558838, 10.7204007932118, 18.941716943468364, 36.36412341254098, 47.839181082589285, 49.161166191101074, 53.32102836881365, 56.36736876623971, 52.141575132097515, 52.260754108428955, 47.50097056797573, 47.994796412331716, 50.5884929384504, 53.67985418864659, 52.43528938293457, 51.66997310093471, 53.26867369243077, 55.503169195992605, 54.4831736428397, 53.86276204245431, 53.3020841053554, 50.99885702133179, 49.951079096112935, 50.14289801461356, 49.8459597996303, 48.85603952407837, 41.56065682002476, 40.13290623256138, 42.20556082044329, 50.23107065473284, 50.859097480773926, 51.603405884334016, 54.0636761529105, 48.62965679168701, 48.196999413626536, 36.142111097063335, 48.06015116827828, 50.59373882838658, 48.74680341993059, 51.30256278174264, 50.09555993761335, 49.56397410801479, 50.09661258969988, 52.34393099376133, 49.67531899043492, 43.697015966687886, 38.33245079857962, 38.36412763595581, 38.5829507282802, 45.42495652607509, 45.41082041604178, 48.08790227345058, 47.998131547655376, 48.43770585741316, 48.95469004767281, 49.99896955490112, 50.00511523655483, 50.69194119317191, 48.01401512963431, 48.639519759586875, 45.77394369670323, 44.22903953279768, 39.901645864759175, 41.79453665869576, 43.9536337852478, 46.98906898498535, 46.729373114449636, 46.720649651118684, 46.5706137248448, 43.31923198699951, 29.803314685821533, 13.561647738729205, 2.5740947893687656, 0.3170731174094336, 0.32931003506694523, 1.2754912376403809, 2.9473633084978377, 1.0470255655901772, 1.7827342706067222, 3.61141220160893, 3.4346233223165785, 1.0562348599944795, 0.21422556973993778, 0.17556416429579258, 4.3357080561774115, 21.591419424329484, 36.50078405652727, 23.31106730869838, 19.2308349609375, 25.834583554949077, 22.420565332685197, 10.466302565165929, 0.6033923679164478, 0.007633387493634862, 0.06269025749393872, 0.01464220555499196, 0.03280164487659931, 0.040854071000857015, 0.0323162344949586, 0.03498775239235588, 0.019780851335131695, 0.05987412003534181, 0.019083963640566384, 0.02291576624182718, 0.03092617747773017, 0.018081867501937916, 0.027345322571428757, 0.007832925134737576, 0.026674426160752773, 0.011607967433519661, 0.03272245305457285, 0.0650168794340321, 0.023903704747291546, 0.06754420524729149, 0.033926873068724356, 0.08139714904661689, 0.05816764517554215, 0.07507833918290478, 0.04692346156973924, 0.04992728859984449, 0.06786382238247565, 0.027427622083840624, 0.027825696526893547, 0.032157043394233496, 0.020313701492601206, 0.07087235166026012, 0.023082724872178266, 0.009596601344778069, 0.02879906858184508, 0.04582836033244218, 0.036510968514318974, 0.023868473512785773, 0.0493134485025491, 0.018719892283635478, 0.06378938922924654, 0.023343416330005442, 0.00950112977131669, 0.03500027475612504, 0.01989685877093247, 0.07487525365182332, 0.028865982312709093, 0.0579651024724756, 0.01518452466864671, 0.037799567582884004, 0.03247294894286564, 0.06547426631940262, 0.025661249545269778, 0.02986082321565066, 0.0495452360649194, 0.0807541421215449, 0.07639598633561816, 0.12793632570121968, 0.016629515880984918, 0.032761238116238794, 0.02040752931497991, 0.04146835214591452, 0.05892009301377194, 0.2239306696823665, 10.215430906840734, 35.57283476420811, 35.82821927751814, 20.676181861332484, 18.042929240635463, 39.19994034085955, 47.66605976649693, 20.440384319850377, 1.642177967088563, 0.008345115597226789, 0.1641536480081933, 0.007086644331658525, 2.670232887778963, 10.927807126726423, 7.7772098779678345, 4.925138941832951, 0.9282049643141883, 0.4752644917794636, 3.7968774267605374, 13.645368320601326, 24.535369430269512, 39.402167660849436, 50.61174161093575, 49.5042473929269, 53.889422280447825, 58.258651052202495, 56.55874300003052, 53.35105848312378, 49.32920837402344, 48.35826015472412, 53.01765264783587, 53.54350968769619, 54.62653929846627, 52.380634852818076, 55.77048029218401, 56.91036353792463, 54.442220960344585, 53.91198655537197, 55.00233609335763, 50.59735189165388, 52.74615526199341, 52.23430231639317, 52.66003581455776, 49.61159011295864, 41.825188636779785, 42.18735654013497, 44.89376674379621, 53.181838580540244, 53.34219952992031, 51.85707766669137, 55.68740068163191, 48.00055646896362, 49.19709185191563, 40.497568539210725, 48.78518526894705, 51.5305609703064, 50.84301587513515, 52.277561800820486, 50.66524968828474, 50.334244455610005, 50.39705964497158, 53.35346603393555, 51.420282636369976, 44.59924650192261, 39.537963254111155, 39.573472023010254, 39.35217884608677, 44.99324410302298, 48.31459072657994, 49.894816058022634, 48.51602247783116, 49.453879901341026, 50.025553362710134, 51.40941565377371, 50.327306679316926, 50.4659023966108, 49.656451157161165, 49.05317381450108, 46.99176141193935, 45.186404023851665, 42.24020453861782, 42.56598472595215, 45.732369150434224, 48.93172972542899, 48.584639413016184, 48.06967714854649, 48.183638027736116, 44.747868469783235, 34.61912155151367, 16.785848992211477, 4.93997551713671, 1.0781837850809097, 1.1588779922042574, 4.152368545532227, 3.6654083899089267, 3.942258059978485, 3.7012471982410977, 5.247467611517225, 1.5538660373006548, 0.46415633069617407, 0.13725835191352026, 0.12931470173810208, 3.7338524886540005, 23.221857649939402, 40.470960412706646, 29.48881142480033, 20.424036945615494, 26.435439450400217, 29.626844338008336, 16.69426131248474, 1.1597600877285004, 0.014410404421921288, 0.01742770546115935, 0.003927171970384994, 0.0046699099724979275, 0.05783555656671524, 0.01883479710003095, 0.09145326193954263, 0.06334116935197796, 0.045209159808499474, 0.07335687548454319, 0.011443437958535339, 0.026440675935841033, 0.02837815465006445, 0.030439616979232857, 0.025474496352087175, 0.08752949748720441, 0.03490990406966635, 0.04718016154531922, 0.007849496656230517, 0.01700724445150367, 0.06215722752468927, 0.015983006018879156, 0.09525446261146239, 0.03167531067239387, 0.05385180622605341, 0.09048398823610374, 0.027315738444615687, 0.062142706875290186, 0.133583718378629, 0.14421618570174488, 0.11860699845211846, 0.1121231485158205, 0.20289163291454315, 0.11826872160392148, 0.1624176161629813, 0.11262557655572891, 0.12265158284987722, 0.08386461450053112, 0.13279952188687666, 0.14260812556105001, 0.24067783675023488, 0.14406439741807325, 0.09237000346183777, 0.1630010205720152, 0.12799339049628802, 0.1373735535889864, 0.22087707210864338, 0.1317100796316351, 0.16996918166322367, 0.10923844509358917, 0.26765839755535126, 0.1533537996666772, 0.1800390077488763, 0.18765814176627568, 0.156232443771192, 0.169728939554521, 0.115197536402515, 0.14075320080987044, 0.33103554961936815, 0.12981585413217545, 0.08653159639132874, 0.14502346595483168, 0.1524895496134247, 0.11401627478854996, 0.3197086831288678, 9.266187991414752, 38.641530990600586, 46.08872141156878, 33.33768960407802, 26.399843829018728, 36.20718445096697, 51.26782873698643, 29.076381989887782, 3.5720860489777158, 0.11672263885182993, 0.7642281289611543, 3.232928625174931, 13.769015857151576, 19.388383626937866, 19.50608089991978, 8.34870616027287, 1.0786509428705489, 0.6430800440055984, 3.78482186794281, 12.919212085860115, 22.152236325400217, 38.570853914533345, 49.86428567341396, 48.916586126599995, 55.59441293988909, 60.55095904214041, 57.8025678225926, 56.88951894215175, 51.909984724862234, 52.08818517412458, 55.27322898592268, 57.027332987104145, 55.50600406101772, 53.83926323481968, 57.18632514136178, 60.324510301862446, 58.02584818431309, 56.54950189590454, 55.86968667166573, 52.563348157065256, 52.45388971056257, 52.0199990272522, 55.15862887246268, 52.05979830878121, 44.58719832556588, 44.787313393184114, 46.397572313036235, 54.46586568014962, 54.73242637089321, 54.393625259399414, 56.43535688945225, 50.225998469761436, 47.356003352573936, 42.58071838106428, 48.560810565948486, 51.18970666612898, 52.20744405473982, 53.62865291322981, 51.765020983559744, 50.975445066179546, 52.403556959969656, 56.4924259185791, 53.74768597739083, 47.66794967651367, 42.813486507960725, 41.285393510546, 41.57908691678728, 50.01601696014404, 49.72222975322178, 52.328540733882356, 50.294865540095735, 51.67780024664742, 52.10343994413103, 52.1414326940264, 51.97602735246931, 51.987026350838796, 50.6435991014753, 52.36615480695452, 48.358201095036094, 47.315123626164024, 43.80213873726981, 44.893520082746235, 47.11167689732143, 50.27673421587263, 49.95404945101057, 47.86496237346104, 47.524410315922324, 45.292103494916645, 33.401317732674734, 15.974709340504237, 3.613538133246558, 0.8228098569171769, 1.1084784737655093, 4.431531097207751, 9.340126378195626, 4.250051532472883, 6.685376465320587, 10.60418609210423, 9.804013303347997, 3.571220563990729, 0.7131333564008985, 0.27989724225231577, 7.218798790659223, 30.62940686089652, 45.48536763872419, 32.53316463742937, 27.134501184735978, 34.6722092628479, 33.99189724240984, 17.108660561697825, 1.1405079322201865, 0.09644492516028029, 0.1735388051186289, 0.07688753067382745, 0.10547243324773652, 0.11822509180222239, 0.09657990613154002, 0.182327909927283, 0.11201900696115834, 0.16727333489273274, 0.16283070828233445, 0.11910768944237914, 0.1715560850820371, 0.12429028563201427, 0.12538689321705274, 0.06924647997532572, 0.13164439744182996, 0.10783851878451449, 0.1294967255422047, 0.11059864317732197, 0.13950701696532114, 0.12611272212650093, 0.09660293561007295, 0.3052770575242383, 0.09326005141649928, 0.3079665260655539, 0.17894484288990498, 0.12093347789985792, 0.21033567775573048], [0.05530947586521506, 0.019904689065047672, 0.06031642308724778, 0.05494546218376074, 0.015008572056623442, 0.03695494754772101, 0.08275504689663649, 0.07285906148276158, 0.03487105793984873, 0.009283342082718653, 0.028485934848764112, 0.023681711837915436, 0.026464334755603756, 0.04952446271532348, 0.05784177194748606, 0.03450541916702475, 0.017106736344950538, 0.11341541845883642, 0.045925455300935676, 0.0351324296290321, 0.013792786580909575, 0.08077208937278815, 0.03439983233277287, 0.011308658003274883, 0.041572324066822014, 0.024098736067701663, 0.020103859449071542, 0.0813894137474043, 0.018331237602978945, 0.055147601158491204, 0.014460215677640267, 0.04947438004559704, 0.013787895191593893, 0.07676270058644669, 0.04548366793564387, 0.020994450231747966, 0.010904299477780504, 0.10461690236947366, 4.783633232116699, 30.59585748400007, 38.02496174403599, 28.653728280748638, 19.917912789753505, 27.446228640420095, 42.64961324419294, 24.28669513974871, 4.203245861189706, 0.09006221765386206, 0.013077961813126291, 2.0966699506555284, 9.264815722193037, 9.056417533329554, 5.547661057540348, 0.4443099685013294, 0.32214733798589024, 0.2957562884049756, 2.3466007794652666, 7.526504107883998, 19.486485242843628, 36.93848582676479, 51.17145722252982, 52.86150925500052, 54.61759001868111, 53.43414504187447, 53.18718869345528, 52.04990407398769, 48.91546746662685, 50.22319139753069, 50.14787639890398, 50.87592601776123, 50.65872532980782, 52.358004570007324, 49.48973955426897, 50.28262281417847, 51.284202166966026, 52.04326854433332, 53.48565551212856, 53.530575616019114, 52.13979639325823, 52.04672179903303, 50.02867657797677, 44.674200194222585, 39.389303071158274, 39.874290806906565, 45.40196146283831, 51.68900769097464, 51.72463457924979, 52.809925828661235, 54.06377690179007, 44.90776736395699, 33.58694233213152, 46.75057206835066, 53.45127929959978, 50.656345571790425, 51.719322681427, 51.75066947937012, 52.66855778012957, 53.59223393031529, 49.59436552865164, 48.475761141095845, 44.30618190765381, 39.87484666279384, 36.650062629154746, 40.11313165937151, 45.58294813973563, 46.89016137804304, 50.607843671526226, 48.601874419621055, 49.37967661448887, 50.18798834936959, 48.419696126665386, 49.60774775913784, 49.26325607299805, 50.10072939736502, 49.92404018129621, 48.37860100609915, 44.91446542739868, 43.043617793491904, 43.92065763473511, 46.530237742832725, 47.14949941635132, 48.07526697431292, 48.14509637015206, 43.790646416800364, 27.24874520301819, 9.887694801603045, 1.7459607124328613, 0.4163952006825379, 1.2283804970128196, 1.3098771125078201, 3.3773493213312964, 1.9508806765079498, 4.411882894379752, 2.3368300923279355, 3.0101061931678226, 1.496298040662493, 0.03577185049653053, 0.1021660678088665, 4.009744610105242, 23.799979039600917, 34.12922143936157, 24.56521020616804, 20.03920749255589, 29.255001068115234, 19.58518440382821, 6.915696220738547, 0.7076643098677907, 0.05020183404641492, 0.05156564532912203, 0.02899144683033228, 0.059530299556042464, 0.07782904550965343, 0.009905613825789519, 0.046972536614962986, 0.03194062804271068, 0.06749431935272046, 0.02029608502717955, 0.021152039989829063, 0.04163891888622727, 0.025107805849984288, 0.031344965898564885, 0.026154427456536462, 0.025671748178345815, 0.03457165775554521, 0.04697024995195014, 0.07077660358377866, 0.045881211425044706, 0.031247219536453485, 0.048231911180274825, 0.028720202456627573, 0.019699030189907978, 0.03629111299025161, 0.01788637477771512, 0.018989861011505127, 0.03700554251138653, 0.04352355668587344, 0.019191336718254855, 0.04043108584093196, 0.053184236333306344, 0.04577676792229925, 0.03614373518420117, 0.039452665485441685, 0.06669502545680318, 0.040831228119454215, 0.02907716276656304, 0.02098321878085179, 0.08250400251043694, 0.018776366753237586, 0.040919247682073286, 0.023369185393676162, 0.04987555369734764, 0.05269991160769548, 0.04995972257373588, 0.03460808490802135, 0.03650871577805706, 0.028803054975079637, 0.0270254577709628, 0.040670415320034535, 0.07654350663402251, 0.039418090733566453, 0.009560599973026131, 0.025052372931635807, 0.01036710075901023, 0.02067535726486572, 0.0436615842793669, 0.07939134524869067, 0.01281608291901648, 0.006769559404347092, 0.04086154506408742, 0.08428148605993815, 0.010464620660059154, 0.03009738427187715, 0.04442529579890626, 0.31635767008577076, 9.62035070146833, 37.700428758348735, 40.646468435014995, 22.93700408935547, 20.54665354319981, 40.809910910470144, 50.47710984093802, 22.27137361254011, 3.147286866392408, 0.0759049237572721, 0.19722606906933443, 0.43024214623229845, 2.7770293056964874, 3.681610720498221, 5.2750988602638245, 1.2261585933821542, 0.9694106046642575, 0.5003953661237444, 4.22193260703768, 10.491976158959524, 21.59289939062936, 39.329173360552105, 49.73562240600586, 52.706998688834055, 58.02815498624529, 55.69894858769008, 54.92712879180908, 53.57023245947701, 50.17528356824602, 52.964606625693186, 52.27310105732509, 53.22563655035836, 53.31825603757586, 53.49729027066912, 52.26629529680525, 53.7936691556658, 54.65621158054897, 54.06879002707345, 53.91933080128261, 55.398320879255024, 52.38411937441145, 54.12091193880354, 51.66834027426583, 46.06537546430315, 40.3178915977478, 41.83864729745047, 49.02185133525303, 54.64476442337036, 52.97516441345215, 57.220461641039165, 55.583261081150596, 43.882049969264436, 36.36944920676095, 48.36840105056763, 53.972025939396445, 51.32151051930019, 53.00937039511544, 52.72912870134626, 53.763639041355674, 54.74102476664952, 53.082917077200754, 50.2915095601763, 46.64448002406529, 41.0269900049482, 38.62257630484444, 40.93872356414795, 46.524991852896555, 48.608530793871196, 50.45490339824131, 51.217051301683696, 49.591454233442036, 51.561661107199534, 49.84157548631941, 49.763623646327424, 49.945357254573274, 49.09267084939139, 49.67408568518502, 49.448647907802034, 47.10985994338989, 44.404808112553184, 46.03608880724226, 48.032962867191856, 49.05040495736258, 50.10663536616734, 47.41654300689697, 45.03374515260969, 29.76047556740897, 14.338824595723834, 3.3181521892547607, 1.4498113351208823, 2.3819640704563687, 2.182207486459187, 3.8730444482394626, 4.706191650458744, 3.7980095488684515, 2.7628384785992757, 1.5491608040673392, 0.17944868228265218, 0.10542897986514227, 0.1646969781390258, 3.575770331280572, 23.006189039775304, 41.91180140631539, 31.963120528629847, 20.483732393809728, 28.868703808103287, 26.646108831678117, 12.12687165396554, 1.602881018604551, 0.033865964372775385, 0.04372742931757655, 0.04567326419055462, 0.042077137157320976, 0.01588247257417866, 0.030494232262883867, 0.06537591266844954, 0.01388765256186681, 0.052853603182094436, 0.04551519267261028, 0.01268187293317169, 0.07923636106508118, 0.014062286271447582, 0.004727476459395672, 0.04290319925972393, 0.03811451978981495, 0.026056504675320218, 0.04255787921803338, 0.04763580120301672, 0.03627340661893998, 0.020768403075635433, 0.03536082790898425, 0.05053869614909802, 0.06768545588212353, 0.02496334913718913, 0.024553549609013965, 0.0077859264066708934, 0.011915752614316131, 0.06244842082794223, 0.10622089130005666, 0.14191980606743268, 0.1357866230287722, 0.16011622894023145, 0.16807468474975654, 0.15892244156982216, 0.13108843298895018, 0.15838082134723663, 0.17435353568622045, 0.07685792619096381, 0.12064382487109729, 0.18375934740262373, 0.17009781833205903, 0.2140208828662123, 0.17159626792584146, 0.16836439206131867, 0.12188713172716753, 0.17257865092584065, 0.12781009104635033, 0.0943129952730877, 0.12095584241407258, 0.12966293948037283, 0.12190524861216545, 0.0904557476086276, 0.09872035841856684, 0.09237695166042872, 0.1305296051182917, 0.2085256584520851, 0.10747934984309332, 0.21092362834938935, 0.14394931787891047, 0.14542875492147037, 0.15457266569137573, 0.19992401929838316, 0.0755942700696843, 0.21890915770615849, 0.14901849015482835, 0.3115207196346351, 8.160546336855207, 42.17575652258736, 50.41989489964077, 36.561403615134104, 28.152994189943584, 36.03662354605538, 51.551544530051096, 31.36128146307809, 5.5713822075298856, 0.32734640900577816, 0.3194716029933521, 4.314394022737231, 15.571955272129603, 17.186211143221172, 14.921893971306936, 2.2787296899727414, 1.1308607927390506, 0.5821699095623833, 3.1673702001571655, 8.983691607202802, 21.05364101273673, 38.857435839516775, 53.036774090358186, 52.13732978275844, 58.21212591443743, 57.96593386786324, 57.3175835609436, 57.15707669939314, 53.694542680467876, 55.49924693788801, 53.999766622270855, 56.06568145751953, 55.524590492248535, 57.23479577473232, 53.41562461853027, 56.111477034432546, 55.54912805557251, 55.29529993874686, 57.51422452926636, 57.00365700040545, 52.31588806424822, 55.378271852220806, 54.32441772733416, 48.1634396144322, 42.5720157623291, 44.724157742091585, 50.68186977931431, 56.78742558615548, 55.29012353079659, 58.57742050715855, 57.872880118233816, 50.00032445362636, 39.58454745156424, 48.77953290939331, 54.6269805090768, 53.50264733178275, 54.692300524030415, 55.82652793611799, 56.78929117747715, 56.257159914289204, 52.504281520843506, 52.11050626209804, 48.77348102842058, 43.44116244997297, 38.895234039851594, 43.306843348911826, 48.539302417210166, 50.995646953582764, 52.17689282553536, 53.010266712733674, 52.2483446257455, 52.22037117821829, 50.85280588694981, 50.57388782501221, 50.473958832877024, 51.227682045527864, 51.443857874189106, 52.09486239297049, 49.80747372763497, 46.68788194656372, 48.92371497835432, 49.145859309605186, 50.14635474341256, 51.17990623201643, 48.48152814592634, 45.30557952608381, 28.929587398256572, 11.491394621985298, 2.71541029214859, 1.3103885650634766, 4.276346121515546, 4.16899037361145, 8.253664357321602, 5.525118495736804, 11.133749995912824, 8.150316851479666, 7.457461595535278, 3.7730286036218916, 0.37701210539255825, 0.4817808706845556, 6.607611792428153, 30.648417132241384, 42.505973134722026, 34.12642131532942, 28.113660437720164, 38.74990899222237, 29.914927073887416, 11.17531064578465, 1.2722748730863844, 0.1012948899130736, 0.08973046831254448, 0.16239207610487938, 0.1704342495650053, 0.10676314934555974, 0.17491883678095682, 0.12440731935203075, 0.05762550926634243, 0.14433794202549116, 0.10964220057108573, 0.07133422366210393, 0.11396644317678042, 0.16614119921411785, 0.12237128003367356, 0.1327243944896119, 0.11033543265823807, 0.11467722217951502, 0.14312834478914738, 0.19750931672751904, 0.176225233823061, 0.09036213691745486, 0.13246942817100457, 0.11975290839161191, 0.20692313515714236, 0.07899782886462552, 0.21278541987495764, 0.07680545507797173, 0.15067467199904577, 0.1444371845573187], [0.03459350658314569, 0.040200933547956605, 0.04944838536903262, 0.034283572142677646, 0.08043243509850331, 0.034257658890315464, 0.060767845649804385, 0.015110277670568653, 0.025879844690540006, 0.014247807075402566, 0.02377554983831942, 0.03439014624538166, 0.012740028473282499, 0.05861684214323759, 0.02435856239338006, 0.029052477662584612, 0.057812011401568136, 0.04956907978547471, 0.08156334941408463, 0.029159750656357834, 0.03006681626928704, 0.044265751859971454, 0.06799746663974864, 0.03154339328674333, 0.05402356718799897, 0.016713024882067527, 0.02428509571057345, 0.07185249549469777, 0.01816599566622504, 0.019186022092721293, 0.03476179683847087, 0.05889935019825186, 0.016475047383989607, 0.08965317638857023, 0.04331272907022919, 0.02624264040163585, 0.02389169467746147, 0.048481917407895835, 0.04300945784364428, 5.838066228798457, 22.369086129324778, 31.763856615339005, 25.30833567891802, 18.914952482495988, 31.220205238887242, 37.4419766153608, 27.647007261003765, 4.994169729096549, 0.4582992706980024, 0.0654817573460085, 1.7825336413724082, 1.320558447922979, 1.9329004756041934, 1.28366742176669, 0.8841476855533463, 0.06658062445265905, 0.7841358578630856, 1.917032744203295, 7.40013461453574, 20.106825624193462, 32.35423810141427, 49.3333078111921, 57.21875933238438, 55.483599594661165, 55.68723392486572, 53.72653913497925, 51.0304331098284, 52.40362991605486, 50.43000105449131, 47.22888605935233, 47.18282992499215, 47.18976770128523, 47.75313459123884, 49.10236011232649, 50.358743803841726, 51.65951606205532, 52.36119726725987, 52.33393601008824, 52.05353798185076, 53.04416697365897, 50.54869713102068, 47.38637740271432, 40.12579475130354, 39.47039202281407, 39.185411657605854, 44.49814326422555, 50.70995092391968, 55.11813129697527, 54.785083293914795, 56.42277022770473, 36.80995110103062, 45.89599575315203, 55.911511353084016, 52.51042720249721, 55.493608474731445, 52.9407673563276, 52.525042738233296, 50.51095451627459, 50.73392915725708, 45.37209463119507, 44.51787614822388, 39.16240617207119, 39.04615933554513, 41.94777570452009, 45.84717423575265, 49.76424551010132, 49.6521189553397, 49.343980244227815, 50.78222261156355, 50.873125893729075, 49.227983542851035, 49.859032835279194, 49.81878192084176, 51.18442256110055, 48.6288160596575, 46.92092105320522, 44.714579650333945, 47.25828388759068, 44.834641047886436, 46.53721373421805, 47.30671283176967, 51.02996063232422, 40.13041182926723, 20.083913939339773, 6.037324930940356, 0.965934659753527, 0.11651910548763615, 0.7315928744418281, 1.7379767979894365, 1.7590967161314828, 4.3744759644780835, 4.139482242720468, 3.154502136366708, 2.3044708115713934, 1.7873934720243727, 0.0509795403507139, 0.2192617923553501, 7.126885414123535, 29.16669293812343, 33.36395379475185, 21.83292143685477, 21.637034348079137, 28.5901974269322, 19.208366223743983, 5.152578234672546, 0.13869569264352322, 0.04484795526202236, 0.014078107163576143, 0.03388119748394404, 0.035930793931973834, 0.026998720098552958, 0.05667256111545222, 0.07247638130294425, 0.04751852660306862, 0.07490374533725636, 0.013609941749434386, 0.05540480324998498, 0.01721533587468522, 0.008190799770610673, 0.03962554603016802, 0.029723077214189937, 0.009704649564810097, 0.009272489763264145, 0.036289138453347344, 0.01623327687515744, 0.03686086866738541, 0.0781033704323428, 0.016166208777576685, 0.007353947265073657, 0.05412495728316052, 0.049204295966774225, 0.053698416599737744, 0.023772270817841803, 0.07805011221872908, 0.029321455729327033, 0.04004070768132806, 0.03210093533354146, 0.07467572364423956, 0.020022633718326688, 0.00815994932781905, 0.05819570938391345, 0.00794745675687279, 0.007906919378521187, 0.058431534229644706, 0.0901937313111765, 0.008579663948954215, 0.026493812013151388, 0.07735721261373588, 0.010764645096579832, 0.035906926462692876, 0.016986148797773888, 0.02914831055594342, 0.030139657003538947, 0.015642318675028424, 0.05569871747866273, 0.02882057474926114, 0.027802678922723447, 0.045761517847755125, 0.08741643319704703, 0.05579201604372688, 0.01504247505883021, 0.022571859249312962, 0.04215109408167856, 0.004459046309680811, 0.014539254829287529, 0.024247832263686826, 0.015575384588113852, 0.0705710481852293, 0.007556314397204135, 0.05787740860666547, 0.013788518595642276, 0.031204346301300184, 0.04554986581206322, 0.10540499365223305, 0.3309293996010508, 10.36195625577654, 32.50892237254551, 35.31009210859026, 21.917291675295147, 17.306041513170513, 42.16347905567714, 48.297637122017996, 26.134782212121145, 4.4088000655174255, 0.22166843393019267, 0.058434560495827875, 0.7806275604026658, 1.622480041214398, 3.2516088570867265, 3.2780550037111555, 2.1718685669558386, 0.5601598620414734, 0.4871133416891098, 3.641753247806004, 9.332977550370352, 22.694499799183436, 36.44920063018799, 49.13660083498274, 58.405320576259065, 56.38040706089565, 56.88532223020281, 54.066980021340505, 53.7899101802281, 54.41654736655099, 51.639258589063374, 49.87443699155535, 50.46287645612444, 50.362009457179475, 49.737623487200054, 50.36511877604893, 51.81744514192854, 54.70951468603951, 53.82859774998256, 53.11138732092721, 52.515495913369314, 53.77041006088257, 52.862912791115896, 48.8235045841762, 41.91739123208182, 40.996216433388845, 40.02565731321062, 47.28688267299107, 53.592841897692, 56.74412441253662, 55.56948280334473, 57.29690572193691, 38.051830427987234, 45.74978133610317, 55.114490440913606, 52.46061904089791, 55.14591366904122, 54.329861640930176, 53.72927325112479, 52.503353936331614, 52.96085459845406, 47.59924936294556, 46.79730217797415, 39.96668447766985, 40.03925493785313, 42.02421631131853, 46.963242530822754, 50.13647787911551, 51.49000433513096, 50.690732206617085, 51.96942656380789, 50.84917197908674, 49.31958859307425, 50.29979181289673, 49.16275038037981, 51.19681467328753, 50.56066540309361, 49.49530506134033, 45.5928840637207, 47.904327392578125, 46.833679471697124, 47.88760655266898, 48.185663427625386, 51.88875102996826, 43.941672461373464, 25.47051010813032, 9.62307526384081, 2.101597091981343, 1.0449001767805643, 1.8145682024104255, 3.0695310958794186, 2.9959863679749623, 3.7594340188162665, 4.62872314453125, 4.41567747933524, 1.2903419264725275, 0.017967378288241367, 0.04330557731113263, 0.2881512407745634, 5.029522163527353, 28.554389885493688, 41.72963006155831, 27.194716010774883, 21.789920772824967, 29.7409302847726, 26.093992812292917, 8.724848628044128, 0.6316810356719154, 0.013677008150677596, 0.03225577023944684, 0.010810182429850101, 0.05393509300691741, 0.03329736899052348, 0.031829209199973514, 0.06259380374103785, 0.028849700864936625, 0.03664059584428157, 0.01738431484305433, 0.048280026098447185, 0.06637927597122532, 0.023804942278989723, 0.00849518209828862, 0.02194654512485223, 0.05456795244078551, 0.022370042578716363, 0.021365137305110693, 0.010878672058294927, 0.07365091863487448, 0.016391076979094317, 0.05504786329610007, 0.012931446594718312, 0.016683305048250725, 0.14029064348765782, 0.040205425449780056, 0.010547400235996714, 0.04416182404384017, 0.011932462387319123, 0.015516899958519, 0.08118349872529507, 0.1295134582157646, 0.1519527877015727, 0.09700234846345016, 0.09468967041799001, 0.08828332953687225, 0.18475530110299587, 0.13942226794149193, 0.234952412545681, 0.10034976527094841, 0.05417876850281443, 0.18330352114779608, 0.08018433555428471, 0.13717578777245112, 0.16881236088063034, 0.17212954216769763, 0.22802978115422384, 0.17147603152053698, 0.12243941852024623, 0.08913170865603856, 0.13647597389561789, 0.15671507215925626, 0.17313082915331635, 0.19117547731314385, 0.09128577235553946, 0.16156925739986555, 0.22108922286757401, 0.14718959400696413, 0.14093488534646376, 0.1476846124444689, 0.07597891800105572, 0.19489800184965134, 0.07161072668220315, 0.13752629182168416, 0.11588409170508385, 0.09860946544046913, 0.11950275967163698, 0.21211479657462665, 0.3486416334552424, 8.979910050119672, 36.471184730529785, 45.9557398387364, 34.27406358718872, 26.208950757980347, 38.05237238747733, 45.34211662837437, 34.461126463753835, 6.4828060780252725, 0.8826443233660289, 0.2065118479409388, 3.910523899963924, 4.431039946419852, 3.7671304515429904, 4.058770665100642, 1.783663700733866, 0.600364473249231, 1.6595275104045868, 2.8123252860137393, 8.271528175898961, 22.061428580965313, 33.70714269365583, 50.33367470332554, 60.00929832458496, 56.9356723512922, 60.54207924434117, 55.91551698957171, 55.88281181880406, 56.67326668330601, 54.86277110236031, 51.28030770165579, 51.47769907542637, 51.898402077811106, 51.81291491644723, 54.19503879547119, 55.16478150231497, 56.348271642412456, 56.08490712302071, 55.185139724186485, 56.05883748190743, 57.11399439402989, 54.893944195338655, 50.888182640075684, 43.793443066733225, 42.20631122589111, 41.00435972213745, 47.506661142621724, 55.931834833962576, 58.30964388166155, 58.788520676749094, 56.80427149363926, 42.2173102242606, 46.057600430079866, 55.07766151428223, 53.71917404447283, 55.760690280369346, 55.52557366234915, 55.60689537865775, 55.305065631866455, 54.194451672690256, 48.63399246760777, 49.035521915980745, 41.329285281045095, 42.254830496651785, 45.27494839259556, 49.95665502548218, 52.86574765614101, 52.69095529828753, 53.21025323867798, 53.65000472749983, 52.09144387926374, 49.62645925794329, 51.172777380262104, 48.74846403939383, 53.95685454777309, 51.27403000422886, 51.20428398677281, 46.63397434779576, 50.881442887442454, 49.54628052030291, 49.7526524407523, 50.663137435913086, 53.77198730196272, 42.62803908756801, 22.78830395426069, 7.289337771279471, 1.7954524052994592, 0.5938825096402849, 2.028792347226824, 3.598321578332356, 4.745730374540601, 7.327310545103891, 10.891210964747838, 9.29795776094709, 6.207717776298523, 3.89767233814512, 0.1824408317250865, 0.6024648376873561, 9.65375850881849, 35.8577560697283, 42.664965288979666, 30.559883185795375, 28.85571415083749, 38.67763730457851, 27.897328274590627, 7.940722703933716, 0.5667137503623962, 0.09385535054441009, 0.12139869507934366, 0.12889247653739794, 0.14771205240062305, 0.09342341550758906, 0.11298040965838091, 0.20032902328031404, 0.08432831854692527, 0.13349046052566596, 0.10148235556802579, 0.13191186237548078, 0.16301946315382207, 0.0677088653402669, 0.1494513683553253, 0.13947410801691668, 0.14394581663821424, 0.13561454654804297, 0.10923349857330322, 0.06307945160993508, 0.1278381145426205, 0.1925597701753889, 0.13472893621240342, 0.11245763235326324, 0.13131751998194627, 0.2470440694264003, 0.1080173399033291, 0.20384576171636581, 0.16568613291851111, 0.12251358239778451, 0.09231821766921453], [0.03747429146564432, 0.014384406352681773, 0.06157543124364955, 0.024049069000674144, 0.016637524290542518, 0.10499801513339792, 0.04785911386300411, 0.08528476793851171, 0.049313431539173634, 0.03561986204502838, 0.015474886766501834, 0.03799640041376863, 0.04609394233141627, 0.03253332159614988, 0.018464752938598394, 0.06945036617772919, 0.04021839903933661, 0.028050054130809646, 0.04381120125097888, 0.009842544843974923, 0.04437686536195023, 0.037759269388126473, 0.07580462271081549, 0.06944638317716972, 0.07366271157349859, 0.023481642394991856, 0.05935991262750966, 0.06422443874180317, 0.030918849299528768, 0.06724828934030873, 0.011134551006502338, 0.029015012351529937, 0.00829530434150781, 0.044425777558769496, 0.047278294672391245, 0.08231486765933888, 0.01638437814212271, 0.06738506842936788, 0.026223062970010296, 0.07590493054262229, 2.6384811401367188, 24.280339275087627, 37.62831340517317, 31.688107354300364, 21.364459991455078, 24.118008511407034, 33.85935688018799, 27.156603404453822, 6.453836432525089, 0.5111835843750409, 0.05542766648743834, 0.9128459713288716, 3.5639974772930145, 1.387710833123752, 1.8114473755870546, 0.36384250063981327, 0.17785795192633355, 0.681965637419905, 1.0901765929801124, 5.706066523279462, 18.291398559297832, 27.743081739970616, 41.43239654813494, 56.26940958840506, 57.19967610495431, 56.45035457611084, 55.32630974905831, 53.89254549571446, 50.57068470546177, 50.33022492272513, 48.10821533203125, 46.909852572849815, 46.17594909667969, 47.244199889046804, 49.20023938587734, 49.69825151988438, 51.37336492538452, 54.25400120871407, 55.20776653289795, 53.04819345474243, 50.66118499210903, 46.63582256862095, 41.589960847582134, 42.26924106052944, 40.209819316864014, 44.08708436148507, 48.11430542809622, 56.26768296105521, 53.660096985953196, 55.40151705060686, 36.3362090247018, 46.63106305258614, 58.52883175441197, 52.50715112686157, 55.529614039829795, 52.36667939594814, 53.16176176071167, 49.378384249550955, 47.81825310843331, 44.446090834481375, 42.07609156199864, 39.56135783876692, 39.7680424281529, 42.71254307883126, 47.175332818712505, 48.82783678599766, 49.73401389803205, 51.99258490971157, 52.66239472797939, 50.377361501966206, 50.03876188823155, 49.38100719451904, 49.70897953850882, 50.50296756199428, 49.00346640178135, 51.02263028281075, 49.47009699685233, 45.96116290773664, 47.706599031175884, 49.284607887268066, 48.333576679229736, 40.25493744441441, 20.104343380246842, 4.166779977934701, 0.6320324082459722, 0.4821842461824417, 0.8828885959727424, 1.5805934774024146, 3.5714242330619266, 2.5421877929142545, 2.0045822177614485, 4.6195758410862515, 2.5273160423551286, 0.7826605598841394, 0.062365530990064144, 0.31773808172770907, 6.836034255368369, 24.88687011173793, 26.3033698286329, 20.485432965414866, 17.408153976712907, 28.285378217697144, 17.18641264098031, 2.920219302177429, 0.05980174070490258, 0.04540569408397589, 0.04945737595802971, 0.008112186399687613, 0.049757349504423995, 0.03800508566200733, 0.0788486325847251, 0.09396409935184888, 0.03200526868126222, 0.00587998387969232, 0.02490850824064442, 0.07051870599389076, 0.041595994760947566, 0.014482322348547834, 0.03886130525331412, 0.020230745497558798, 0.012825256712468607, 0.029397431295365095, 0.006616507349203208, 0.012163189738722784, 0.028903155853705745, 0.09105002893401043, 0.05198507835822446, 0.03127164001177464, 0.0111121797069375, 0.09538883968655552, 0.03538056988535183, 0.05346208963809269, 0.019806722179055214, 0.04807280828910215, 0.030574411353362457, 0.008376780282040792, 0.06830897528145995, 0.02927373436146549, 0.0037669613707943684, 0.057816387952438424, 0.032201714747186215, 0.031989591129656346, 0.019963229673781564, 0.03853499776284609, 0.06660571667764868, 0.03435564273968339, 0.02982601776186909, 0.0076775626678551945, 0.0766748438722321, 0.03346825124961989, 0.030449021474591324, 0.045320727928940735, 0.022176297082166587, 0.013401556011688496, 0.03371468159769263, 0.007316978132751371, 0.020127046686996306, 0.022165299725851843, 0.024245610061500753, 0.030268086719193628, 0.032218271001641235, 0.04413842815639717, 0.016881723954741443, 0.007293164946271905, 0.006011115861058767, 0.055731351620384624, 0.03458772885746189, 0.014824692459244813, 0.016869106596069675, 0.016166359751618335, 0.0471539124181228, 0.07225005594747407, 0.038678636840943775, 0.04038426692464522, 0.08772813861391374, 0.18804231472313404, 5.791182390281132, 33.22673382077898, 40.78018651689802, 26.20832542010716, 20.454942532948085, 32.58480364935738, 43.6995381627764, 33.232268060956685, 7.45604590007237, 0.2680055632122925, 0.043225964797394614, 0.6320497244596481, 0.2844836504331657, 3.349861813443048, 2.8397046625614166, 0.896654985845089, 0.5863693356513977, 1.7868149259260722, 2.4229124103273665, 8.819947753633771, 20.483838353838237, 32.95968328203474, 45.93448877334595, 55.48759133475167, 57.927649293627056, 56.19914593015398, 56.414685998644146, 53.9866623197283, 52.2021530015128, 51.95176771708897, 49.57536915370396, 48.09730666024344, 49.09976496015276, 49.54357419695173, 48.99830041612898, 52.329680238451274, 55.08387320382254, 55.393391132354736, 56.667190483638215, 54.66077307292393, 53.049249580928254, 49.395723479134695, 43.03818777629307, 42.53777156557356, 42.14334317616054, 46.035828249795095, 50.52111625671387, 57.90096473693848, 57.571832043784006, 57.46266194752285, 37.881040232522146, 47.02912882396153, 57.24456146785191, 54.07570001057216, 57.79452180862427, 54.52542216437203, 54.80254759107317, 51.375657830919536, 50.33162151064192, 47.63567181995937, 45.76126670837402, 42.27567856652396, 41.537567956107004, 43.18954733439854, 48.446964332035606, 51.8024821962629, 51.47954729625157, 52.40573174612862, 53.587231227329795, 50.52852651051113, 50.55446066175188, 49.89386068071638, 50.59223801749093, 49.827811104910715, 49.80380507877895, 51.57901423318045, 50.56173195157732, 47.571755341121126, 49.31516259057181, 49.979531969342915, 49.14082881382534, 42.4760159764971, 24.114619527544292, 6.767000862530299, 1.4703641065529414, 1.168479751263346, 2.589589489357812, 3.6726770741598944, 5.212198555469513, 4.435052531106131, 6.444672627108438, 3.691256122929709, 1.301961594394275, 0.49123438341276987, 0.062244324279682975, 0.24863262847065926, 5.355712294578552, 30.50149052483695, 38.95438058035714, 25.626288720539637, 18.176668167114258, 29.383567060743058, 23.942276409694127, 5.65832154239927, 0.2215917594730854, 0.030936209617980888, 0.02491460827046207, 0.05963207980883973, 0.06039735195892198, 0.0297014590884958, 0.00873955902976117, 0.06626797587211643, 0.02351238681668682, 0.029740600381046534, 0.01843462259109531, 0.023856594060946788, 0.03349788287388427, 0.025338852112846713, 0.052201286756566594, 0.027866875120837773, 0.01157588544966919, 0.014130800496786833, 0.040107601056141515, 0.047524691093713045, 0.021010253312332288, 0.07828145194798708, 0.012387342085795743, 0.03445655446765678, 0.03238855614992125, 0.05912800292883601, 0.03296437453744667, 0.08999152787561927, 0.045489771358136616, 0.07187017811728375, 0.023759249730833938, 0.05233089033780353, 0.20248323625751904, 0.0571790196533714, 0.11145608073898725, 0.2508156384740557, 0.25007152983120506, 0.2014256715774536, 0.10488605685532093, 0.2089393205408539, 0.14408703334629536, 0.06672420924795525, 0.11542905255087785, 0.12705817925078527, 0.183117114007473, 0.07511318874146257, 0.05963396613619157, 0.15179220560405934, 0.16755010932683945, 0.11897844209202699, 0.1611631406205041, 0.1319468340703419, 0.11530412068324429, 0.08917674302522625, 0.165859797171184, 0.1388805527240038, 0.13131636647241457, 0.13400920054742269, 0.150339204285826, 0.15989419871142932, 0.06084322410502604, 0.11453980526753835, 0.13834797058786663, 0.11923893168568611, 0.10151454526931047, 0.1809938693685191, 0.1740199135882514, 0.12025042383798532, 0.10712737337286983, 0.1736963473792587, 0.1075302738962429, 0.22974017794643128, 5.7234057528632025, 35.890780857631135, 52.99886819294521, 39.856635434286936, 29.572151592799596, 31.688975879124232, 42.46707017081124, 35.02792228971209, 8.663588966642108, 0.6734979003667831, 0.22712719387241773, 3.627947828599385, 11.05720864023481, 4.268235402447837, 5.586498882089343, 0.8531951435974666, 0.8482551372476986, 2.2568287508828297, 1.6708074765545982, 7.239894390106201, 21.128697190965923, 30.749096529824392, 43.311894689287456, 57.624388217926025, 60.32058456965855, 60.07345104217529, 60.377872467041016, 56.64707544871739, 55.53589521135603, 56.70398814337594, 52.532081263405935, 51.32313987186977, 49.78497198649815, 51.31323868887765, 52.46680988584246, 55.05943986347744, 55.43577514375959, 57.457214559827534, 59.20645482199532, 57.43190227236067, 54.61589813232422, 51.08904116494315, 45.87763513837542, 46.36423485619681, 44.69403730119978, 48.891735894339426, 53.4464989389692, 60.192869731358115, 57.24512774603707, 59.88769095284598, 41.61318867547171, 48.40099852425711, 58.638411794389995, 54.3523599079677, 58.66312653677804, 56.611090728214805, 58.141539164951865, 54.37731088910784, 52.25323963165283, 47.877743584769114, 46.019451345716206, 43.427547454833984, 42.77610172544207, 45.99215882165091, 50.334150654929026, 53.536328724452424, 52.50650494439261, 54.80875928061349, 55.88859619413103, 51.46923269544329, 51.911075592041016, 51.35497304371425, 51.143688746861045, 51.19644641876221, 50.16014691761562, 54.651448590414866, 53.00063303538731, 48.947241578783306, 50.13575874056135, 51.86971296582903, 49.49287666593279, 42.05684157780239, 22.696452242987498, 5.429024040699005, 1.4060227019446236, 1.2083831472056252, 2.533867759363992, 4.190114200115204, 9.924560206277029, 7.249146350792476, 7.799491013799395, 12.459588749068123, 8.916478208133153, 3.747535228729248, 0.2497940090085779, 0.6348675989678928, 9.383973853928701, 32.64736870356968, 34.37825182506016, 28.27220790726798, 26.736051525388444, 39.02649940763201, 25.537761722292217, 4.684335223266056, 0.24336882520999226, 0.14670227015657084, 0.09888208045491151, 0.1497831041259425, 0.21807088197341987, 0.10774969176522323, 0.1736113947949239, 0.14378743299416133, 0.13063960921551498, 0.12192457328949656, 0.1022919767669269, 0.13115089892276696, 0.15710449697715895, 0.11985293802406106, 0.14885055273771286, 0.12542755103537015, 0.08885495457798243, 0.12416197465998785, 0.07696967412318502, 0.11785408242472581, 0.12030671510313239, 0.29947856866887634, 0.17185571257557186, 0.09297255612909794, 0.10830092682902302, 0.18201798227216515, 0.16388220685933316, 0.2624857894011906, 0.14593386996005261, 0.18389346663440975, 0.12146008892783097, 0.1110492040004049], [0.016891718775566136, 0.03901685940633927, 0.03223223185964993, 0.023412889834227305, 0.02487388938399298, 0.02048270420969597, 0.04480303963646293, 0.06719390475856406, 0.008979425399697252, 0.033920399844646454, 0.03673990622961095, 0.02842493455058762, 0.09297496492841414, 0.025350002139540653, 0.03279533789360097, 0.03837066336667963, 0.024112856381439736, 0.013287334819324315, 0.021553150877090435, 0.02003716115307595, 0.022364314046821425, 0.008473574150619763, 0.012338820046612194, 0.03713526822892683, 0.046737420838326216, 0.04421464120969176, 0.037824934614556174, 0.039368964798216305, 0.019929703258510147, 0.01790319226815232, 0.05407285936442869, 0.016423624607601335, 0.039000764555696926, 0.039146194966243844, 0.1459153459540435, 0.0894407881423831, 0.030088264761226516, 0.01065109480571534, 0.025548175077087114, 0.019975558655070405, 0.04346139948549015, 2.007161953619548, 19.327826602118357, 37.50977366311209, 28.075950826917374, 21.794907842363628, 24.181716544287546, 31.15810571398054, 30.040720735277446, 12.367400050163269, 0.8172133543661663, 0.09750260519129889, 0.18052771581070765, 4.164669028350285, 1.8668220213481357, 1.1863394443477904, 0.36049235612154007, 1.4834086980138506, 0.5903192779847554, 0.1659203496362482, 0.947604334780148, 7.083077456269946, 17.90750363894871, 36.068689482552664, 54.579635483878, 59.998118673052105, 57.489138058253694, 57.94740997041975, 55.26897668838501, 53.17862851279122, 52.38946601322719, 52.148255825042725, 50.89108003888811, 50.4207877431597, 49.39346531459263, 50.10763243266514, 52.17916488647461, 53.23437738418579, 55.431738240378245, 54.5337495803833, 51.170668601989746, 48.48379325866699, 44.34500844138009, 45.00768593379429, 42.92320203781128, 45.01383856364659, 50.23651456832886, 56.46951423372541, 52.15260192326137, 59.91106469290597, 38.00334937231881, 47.24156999588013, 57.653122493198936, 54.90441165651594, 55.17606537682669, 49.98637247085571, 48.52257810320173, 45.31109292166573, 46.14568274361746, 45.596042019980295, 45.851384844098774, 43.22035564695086, 44.89042813437325, 48.881872926439556, 50.46642698560442, 51.243086201804026, 51.14486994062151, 51.76727914810181, 52.30620922361101, 52.38077729088919, 51.296378884996685, 50.10644081660679, 50.38163117000035, 50.551813398088726, 50.048878465379985, 50.208110332489014, 49.59330940246582, 50.819829736437114, 49.299313749585835, 45.479392187935964, 35.24203102929251, 17.169391291482107, 3.212381933416639, 0.6634495024170194, 0.2022743560373783, 1.0652526446751185, 3.3482598194054196, 3.2141139890466417, 3.6007493223462785, 3.782191106251308, 4.312116316386631, 1.3221101760864258, 1.0020474876676286, 0.16980832815170288, 0.5654129715902465, 8.805291397230965, 32.3885726247515, 41.58877617972237, 35.25907843453543, 16.479138135910034, 24.193512848445348, 20.589409283229283, 2.0318732219082967, 0.06677863454180104, 0.08231297454663686, 0.02871260286441871, 0.0704025679400989, 0.0983701122126409, 0.04391215369105339, 0.011848405469208956, 0.11220310708241803, 0.028804049028881958, 0.05984672757663897, 0.027247147035918066, 0.055662320860262425, 0.06417542815740619, 0.020062831829168966, 0.03605483691873295, 0.05578897620684334, 0.026106146297284534, 0.03207033679687551, 0.045891552298728905, 0.033203225649361096, 0.00743527223156499, 0.027488106695402945, 0.02599102774235819, 0.06025328540376254, 0.02240514489156859, 0.034290153932358534, 0.048552749678492546, 0.03639932914770075, 0.037327693974865336, 0.01644730208707707, 0.03659923913489495, 0.038562559855303595, 0.11270163354596921, 0.020941802699651037, 0.028197280962818434, 0.018476975050621798, 0.020112224089513932, 0.02208585854220603, 0.01903223043440708, 0.028977726852255206, 0.013357865141837724, 0.04194114177620836, 0.04384641721844673, 0.03065239538305572, 0.028891539334186485, 0.05272450510944639, 0.013662117699693357, 0.02695510895656688, 0.03081319461177502, 0.048536549654922316, 0.06640119265232768, 0.043817477699901373, 0.03836838688169207, 0.030542608417038406, 0.012114369992299803, 0.03921317994328482, 0.047649246374411244, 0.06045620808643954, 0.037519030672098906, 0.02004827555668141, 0.020790550458644117, 0.017782462228621756, 0.026365363637783697, 0.09713281717683588, 0.033383977200303755, 0.057811210730246136, 0.04128012653174145, 0.09223078164671149, 0.0516066254515733, 0.05713830076690231, 0.03695771936327219, 0.032482126128992865, 0.04993969561266048, 0.12303853780031204, 5.906016571181161, 29.000198466437205, 41.79462003707886, 25.193417685372488, 17.099761656352452, 27.0162741116115, 39.833953039986746, 30.958414486476354, 8.594013180051531, 0.5778180030839783, 0.07626283740890877, 0.2514871438699109, 1.3665813612086433, 1.7786532895905631, 1.3033121504953928, 0.8775596533502851, 2.0871695918696265, 0.7054044082760811, 1.0451845100947788, 3.9251520293099538, 8.093541383743286, 22.314989192145212, 40.803831236703054, 57.45210415976388, 59.79574544089181, 57.91991942269461, 59.44178336007254, 57.61374705178397, 54.223595891680034, 55.53640242985317, 52.21174498966762, 51.90895291737148, 51.18621867043631, 50.51198284966605, 50.38403524671282, 54.70011029924665, 55.14415577479771, 56.90982157843453, 54.623961516789024, 53.471390860421316, 50.38784980773926, 46.03841297967093, 45.894644328526084, 45.27250610079084, 46.25808375222342, 52.300337995801655, 59.256530489240376, 55.85744741984776, 60.65647438594273, 39.72264984675816, 47.992308957236155, 56.36216803959438, 54.17364876610892, 54.29114975248064, 53.233658245631624, 50.567464215414866, 48.7912267276219, 47.22661052431379, 46.769940171922954, 47.74731894901821, 45.30255705969674, 46.27866084235055, 50.225414821079795, 53.15129082543509, 53.147083691188264, 52.49788917813982, 53.14441210883004, 52.77690798895699, 52.634348324366975, 51.921768869672505, 50.92565427507673, 50.69966064180647, 52.78669105257307, 52.13893134253365, 52.497239521571565, 51.11228288922991, 52.41241938727242, 50.4107997076852, 47.754173346928184, 37.54344463348389, 21.024997064045497, 5.3207146525383, 1.0394180480922972, 1.06095409819058, 2.821972208363669, 5.272483732019152, 8.871086495263235, 6.480227427823203, 5.7372461301939826, 5.374567099979945, 0.8094955884984562, 0.5649542276348386, 0.09489446585731846, 0.15357672556170396, 6.144373221056802, 31.660776615142822, 42.10775450297764, 25.94436682973589, 18.49425642830985, 25.40267137118748, 26.441948175430298, 4.120138457843235, 0.14202206129474299, 0.128383480278509, 0.0108627833126645, 0.09218214425657477, 0.024815392880035297, 0.02986234313409243, 0.022490764136559198, 0.11338498616325003, 0.041942288500389883, 0.03365899422871215, 0.03193316415750554, 0.041778876911848783, 0.0457726763561368, 0.05738583034170525, 0.02562473079056612, 0.028683205334735767, 0.02570208378269204, 0.03652695479935833, 0.053830154173608334, 0.01806808475937162, 0.028365064013217176, 0.06160502215581281, 0.02102092157916299, 0.013626886465187584, 0.03498963193435754, 0.03486971104783671, 0.03678819417421307, 0.01626534783281386, 0.020539597674672092, 0.05012073893366115, 0.061645272853119035, 0.01336919582848038, 0.05897322230573211, 0.08687543044132845, 0.191250509715506, 0.0627069358846971, 0.11250753181853465, 0.04322695545852184, 0.11229761343981538, 0.10425518213638238, 0.1995810605585575, 0.1868172740297658, 0.11177096169974123, 0.13392888914261544, 0.0849889809531825, 0.16642424331179687, 0.12137850187718868, 0.040173710723008425, 0.11660298598664147, 0.21711253268378122, 0.1476782342152936, 0.22655923292040825, 0.14178821098591599, 0.1440448827509369, 0.1111355000840766, 0.11900334432721138, 0.09032228655580964, 0.18154963026089327, 0.10538203202720199, 0.18055256376309053, 0.18274317335869583, 0.10661591403186321, 0.08692682946899108, 0.13720784176673206, 0.2059086710214615, 0.19193671217986516, 0.08091758763683693, 0.3052311885569777, 0.21515540698809282, 0.1589898472385747, 0.09090294289801802, 0.0978658724842327, 0.14453744489167417, 0.19673046709171363, 5.570726037025452, 32.10898058755057, 50.46706621987479, 38.79322058813912, 29.842766557421, 31.183487483433314, 38.13747392381941, 37.201773915972026, 16.335225309644425, 1.2183618460382735, 0.33969362931592123, 1.2872560577733176, 9.513111335890633, 5.9950920428548535, 2.6342816054821014, 1.8994618356227875, 3.5612603213105882, 1.669305037174906, 0.5056474985820907, 1.551198037607329, 8.247713225228445, 20.93831307547433, 38.940459864480154, 58.00343329565865, 62.65431077139718, 59.68865980420794, 61.64798927307129, 59.93696757725307, 56.83400630950928, 57.85423810141427, 55.277040072849815, 54.92164666312081, 55.04138496943882, 52.87247698647635, 52.44931779588972, 56.187598024095806, 56.15812723977225, 59.983867917742046, 56.90133087975638, 55.510826110839844, 53.4903108051845, 49.686189447130474, 48.78750944137573, 49.01637962886265, 48.17701292037964, 56.02200160707746, 60.96017319815499, 57.78087554659162, 61.57738862718855, 43.33949293409075, 48.32309184755598, 55.60959127971104, 57.05024119785854, 57.64761257171631, 53.78020007269723, 51.31738328933716, 49.76340477807181, 48.574255330221995, 49.42043474742344, 49.397703715733115, 48.11281156539917, 49.43870503561837, 53.71062428610665, 56.118234157562256, 55.35300472804478, 53.88699388504028, 54.81551987784249, 54.53187704086304, 54.243714400700156, 52.62523576191494, 51.265886715480256, 51.25320625305176, 53.041095869881765, 53.295222759246826, 51.78973920004708, 52.30813387462071, 54.45329291479928, 52.547061579568044, 47.26627779006958, 37.77741827283587, 19.22508011545454, 4.305480352469853, 1.2109183711665017, 0.8960583092910903, 2.519579006092889, 7.06987110206059, 6.974670359066554, 6.043834090232849, 8.876137835638863, 10.23209181853703, 5.107793186392103, 2.7258093569959914, 0.6096916698983738, 0.9795330443552562, 11.214526278632027, 41.05314302444458, 50.76464714322771, 41.83292545591082, 26.43822741508484, 34.86215911592756, 29.332212924957275, 3.516285934618541, 0.2172630860337189, 0.26259918617350714, 0.15623509005776473, 0.18190002574452332, 0.22923863200204714, 0.16576071748776094, 0.20673599519899913, 0.32243514539940016, 0.09092156868427992, 0.15835891823683465, 0.10502846099968467, 0.0670679754444531, 0.1492224849228348, 0.12339828349649906, 0.08254024985113315, 0.10919799762112753, 0.10742410352187497, 0.1203850180442844, 0.11696767141776425, 0.13021424918302468, 0.08335840023521866, 0.12839314261717455, 0.0983207148632833, 0.059682881725685935, 0.09712223881589514, 0.0990255091871534, 0.09601037097828728, 0.07352169164057289, 0.15697241335042886, 0.086113170986729, 0.12818659655749798, 0.08810857284281935, 0.2915549081351076], [0.021517688940678324, 0.03000582954181092, 0.015111722950158375, 0.024244814479191388, 0.051223473689918, 0.028954490420541594, 0.050540843712432046, 0.015814284893817136, 0.02740257735630231, 0.01951536433106022, 0.04943675867148808, 0.010224422656132706, 0.018050797383434007, 0.04960782074236444, 0.04967244441754051, 0.05221669967951519, 0.04042604093306831, 0.036933166573622396, 0.0664077065885067, 0.014089266520126589, 0.07683419782136168, 0.017498858339552368, 0.044107446247445684, 0.06886626287762608, 0.06848000681826047, 0.04201033538473504, 0.024506840954667757, 0.00764601248582559, 0.049260733116950305, 0.04471628554165363, 0.027296345913782716, 0.05981772020459175, 0.025424871693498323, 0.03512227874515312, 0.00787036500072905, 0.016441546413781385, 0.047195774636098316, 0.020141375650252615, 0.04267093672284058, 0.07825591867523533, 0.03834892310468214, 0.08827636776758091, 2.205958817686353, 21.173705884388514, 33.805501392909456, 33.973960467747276, 19.478863068989344, 28.02626425879342, 42.93620211737496, 32.92576912471226, 16.689100537981304, 2.876833881650652, 0.18494086685989583, 0.48384014304195133, 0.9921147120850426, 0.8241232292992728, 0.7533743913684572, 1.1805129455668586, 0.8096716819064957, 1.8355811834335327, 1.4964525295155389, 0.05882889112191541, 1.3653816027300698, 9.060355424880981, 25.009762900216238, 45.36126586369106, 58.78099577767508, 60.331368173871724, 57.65492902483259, 56.577999932425364, 55.79863091877529, 54.83110816138131, 53.69657155445644, 53.607099601200645, 51.996399470738, 53.66335916519165, 52.941024439675466, 56.37841640199934, 55.29682854243687, 55.62788936070034, 53.69955233165196, 51.844358989170615, 47.410866328648154, 48.330932889665874, 47.01063619341169, 48.62984091894967, 49.47470017841884, 59.13604177747454, 55.92810712541853, 61.33821078709194, 28.048406430653163, 44.68374701908657, 61.98326069968087, 52.26560395104544, 55.65859692437308, 51.01050567626953, 49.737908363342285, 48.83012621743338, 51.7091783114842, 49.57977083751133, 48.69133595057896, 49.78248453140259, 50.37162576402937, 48.80666562489101, 50.31408773149763, 51.3512418610709, 54.381542342049734, 53.1139303616115, 51.72899109976632, 51.20059796742031, 52.098878451756065, 50.64105258669172, 53.010423047201975, 51.559389046260286, 50.31688438143049, 51.86941071919033, 50.10002415520804, 44.769150802067344, 40.68845639910017, 27.882589408329554, 13.9696763583592, 2.895149116005216, 0.20930708652096136, 0.4939680652959006, 0.23984850410904202, 3.5790959128311703, 5.1732143844876965, 13.08273012297494, 6.173218667507172, 3.101645452635629, 6.277404734066554, 1.243318798286574, 0.10199505662811653, 1.1216847194092614, 9.97366486276899, 30.247120448521205, 30.56310020174299, 27.930896759033203, 47.59723438535418, 29.982209954942974, 23.549003158296856, 5.874494331223624, 0.035144795929746966, 0.03385895849870784, 0.03344552032649517, 0.018893254588225057, 0.054480173758098056, 0.028946005340133394, 0.09010111128113099, 0.0881344521684306, 0.0449114932811686, 0.032529942491757016, 0.05192976418350424, 0.03899639479017683, 0.020095605070569685, 0.009543166712059506, 0.026174768240057995, 0.010104349947401454, 0.055174854517515214, 0.01607473716805024, 0.03396343592820423, 0.028751828973846774, 0.02226882890265967, 0.044085933294679434, 0.030925302167556117, 0.06829039699264935, 0.03586518977369581, 0.016086134860025983, 0.023988231550902128, 0.05520620283537677, 0.025330015890566365, 0.022776641117941056, 0.017316926137677262, 0.02508692054211029, 0.009301458967716565, 0.023671506671234965, 0.04059673320235951, 0.06800457090139389, 0.022543761114190732, 0.046817376012248654, 0.028986690299851552, 0.026765231109623398, 0.017269337084144354, 0.03519902105576225, 0.014829323460747088, 0.032325652561017444, 0.030725443070488315, 0.0442580979849611, 0.07132151470120464, 0.03775458410382271, 0.030426816416106055, 0.042666516067194085, 0.0274672196911914, 0.009391224061671113, 0.10556061565876007, 0.08863810835672276, 0.01194229775241443, 0.029143347072282007, 0.029505959578922818, 0.05101998782317553, 0.054420140372323136, 0.04527249426714011, 0.03220123637999807, 0.011026240702319359, 0.033638142847589085, 0.025857329202283705, 0.02428253084820296, 0.00722750396068607, 0.000799124845278649, 0.04301402099164469, 0.040126009711197445, 0.03113370741318379, 0.009744739110049392, 0.024582992939810668, 0.016079809217314635, 0.05024444604558604, 0.01816320519096085, 0.13452488716159547, 4.866443599973406, 27.84184343474252, 39.49899775641305, 29.388729572296143, 15.287822587149483, 24.00658198765346, 52.91321427481515, 43.59412704195295, 13.589583839688983, 1.5398338245494025, 0.14344534277915955, 0.37462700051920755, 0.3287970083100455, 0.6860706657171249, 0.9675950620855603, 3.1110711182866777, 1.4466765033347266, 1.3192376387970788, 1.1395777421338218, 0.6573127774255616, 3.1587802725178853, 13.06157546383994, 30.004023824419292, 51.05696480614798, 59.235810961042134, 61.17834663391113, 57.939405645642964, 56.99202919006348, 56.79643739972796, 56.93408816201346, 54.57162421090262, 54.771575995853965, 53.99082081658499, 54.66804436274937, 53.39642674582345, 57.96871314729963, 55.65552582059588, 57.69993945530483, 54.994015625544954, 52.382865224565776, 49.07411568505423, 48.765094552721294, 48.45940855571202, 51.78326347896031, 52.62173039572579, 59.715208871024, 58.179966177259175, 60.76377541678292, 32.89694799695696, 47.73203291211809, 60.50999941144671, 54.6906989642552, 56.808999742780415, 52.88901717322213, 50.936417034694124, 49.690299306597026, 52.16719314030239, 50.35509252548218, 51.49141829354422, 51.190870489392964, 52.300945963178364, 49.89655658176967, 51.78646312441145, 52.52886077335903, 55.67607511792864, 53.742297649383545, 52.61328486033848, 52.22315045765468, 51.59662444250924, 50.61837019239153, 52.72229514803205, 50.610261644635884, 50.64976910182408, 52.18953159877232, 52.15897689546858, 46.667492457798545, 44.199520111083984, 32.70325653893607, 19.183948516845703, 4.894326720918928, 0.8080296271613666, 0.8046298953039306, 1.6097527870110102, 6.140002369880676, 5.734236257416861, 10.427641919681005, 10.144045114517212, 1.6370186039379664, 1.1363006894077574, 0.13289360755256244, 0.061512015360806666, 0.5789313433425767, 8.975557003702436, 35.70805365698678, 42.377344608306885, 37.486247062683105, 48.462743691035676, 30.135584490639822, 28.66741623197283, 9.562468733106341, 0.04097019887662359, 0.020629834350464598, 0.04621754766308835, 0.017419425637594292, 0.029716264722602706, 0.018647928555895175, 0.04796306882053614, 0.028671663454068557, 0.1744538638740778, 0.027136143795879822, 0.03955495124682784, 0.053533434202628474, 0.10260742769709655, 0.013839802272351725, 0.01946905770871256, 0.02120697927395148, 0.02465987604643617, 0.02271285204083792, 0.017840638124783124, 0.039028618418212445, 0.04062451242602297, 0.04960297939500638, 0.054763835322644026, 0.034997299380068264, 0.03517118076394711, 0.08754133113792964, 0.026918296735467653, 0.0078007956534358, 0.023634787748700807, 0.06875941396823951, 0.028507149246122156, 0.0294260451171015, 0.013709511674408401, 0.016393272039879645, 0.15479536088449614, 0.12186711494411741, 0.0744377885546003, 0.08465062268078327, 0.11416458897292614, 0.07618934528103896, 0.13768918093826088, 0.08233730681240559, 0.09859783535024949, 0.1939285381564072, 0.0958921362512878, 0.12863612600735255, 0.14600867166050843, 0.08973415275769574, 0.09460790016289268, 0.16597167402505875, 0.09207042346575431, 0.11424183339944907, 0.1600252509649311, 0.1398984638175794, 0.2286962111081396, 0.1631668002477714, 0.12323854278240885, 0.15135011289800915, 0.19558295580957616, 0.22941298836043902, 0.10815314190196139, 0.05871412370886121, 0.10992275444524628, 0.28755912397589, 0.10872998487736497, 0.16785523295402527, 0.06325500897530999, 0.09471473550157887, 0.13064908156437532, 0.22655155190399714, 0.1010859486247812, 0.20050624305648462, 0.15216204790132387, 0.14843747418906006, 0.1546257542712348, 0.18839095958641597, 4.101805635860988, 30.125391483306885, 47.17700386047363, 44.15136909484863, 28.351577179772512, 37.66096646445138, 50.83376782281058, 42.04158680779593, 21.554567916052683, 4.174232789448329, 0.3627063344631876, 1.8439796013491494, 1.8355768408094133, 3.1305708033697943, 2.712003069264548, 6.367868976933615, 2.0755000923361098, 3.3019806912967136, 3.4136128383023396, 0.3544356439794813, 2.30193167924881, 11.255631821496145, 28.685158457074845, 49.025822230747764, 61.87984371185303, 64.60328047616142, 60.3439930507115, 60.72552558353969, 60.97173500061035, 58.67138794490269, 57.79320512499128, 57.05264874867031, 56.4975780078343, 57.39958620071411, 55.87064552307129, 59.92456504276821, 59.54147611345564, 60.230515071323936, 57.399752957480295, 55.22053037370954, 52.48825897489275, 52.5095100402832, 51.21012394768851, 53.892535073416575, 54.602748666490825, 62.87498555864607, 60.94503307342529, 61.57010691506522, 34.392808301108225, 49.163577216012136, 61.110518319266184, 55.207238469805034, 58.7852063860212, 54.9237311226981, 53.91635349818638, 53.53592225483486, 54.53411783490862, 53.30804565974644, 54.63518633161272, 55.90459442138672, 55.660368715013774, 51.52235514777047, 53.13819694519043, 54.73142235619681, 57.57382270268032, 55.58326802934919, 52.19353723526001, 51.61294576099941, 52.165602002825054, 51.53127316066197, 54.85887663705008, 51.76637935638428, 50.88615376608712, 54.82261398860386, 52.415563447134836, 47.42172288894653, 43.40695299421038, 30.37056909288679, 17.222258397511073, 3.7185273681368147, 0.7349148190447262, 0.7581417241266796, 2.5198263185364858, 8.546873995235988, 9.950734938894, 23.409208876746042, 14.184377431869507, 8.879233258111135, 11.53230561528887, 3.070697524717876, 0.4161654215838228, 1.739002525806427, 12.575543761253357, 39.02747910363333, 39.397279603140696, 36.43985182898385, 52.24703141621181, 40.15466799054827, 35.05257797241211, 9.219086153166634, 0.1744071263819933, 0.18075159165476049, 0.14285809786192008, 0.08513615519872733, 0.18631069335554326, 0.08416321062083755, 0.17783633380063943, 0.13445691152342729, 0.31166201776691843, 0.09217314688222748, 0.16414488133575234, 0.1786762380174228, 0.2676794592823301, 0.15311372040637902, 0.10277503941740308, 0.0928358720349414, 0.07264325342008046, 0.12718406106744493, 0.07860689769898142, 0.15629052636878832, 0.11068394181451627, 0.16967344896069594, 0.11809446024043219, 0.13292349023478373, 0.19158580100962094, 0.20654858382684843, 0.08082479797303677, 0.13907396234571934, 0.07696790993213654, 0.1348028015345335, 0.11291905652199473, 0.08146599999495915, 0.13164476385074003, 0.0947740598182593], [0.027018282263140594, 0.01629114743056042, 0.06499723584524222, 0.019711189537442157, 0.06293391941913537, 0.04027677679966603, 0.05775789823383093, 0.10786466273878302, 0.03954037631462727, 0.036623629076140266, 0.029518811032176018, 0.05225657718256116, 0.030019101686775684, 0.01992354216054082, 0.03577685808496816, 0.040353468220148764, 0.010841609627407576, 0.004626055406073907, 0.00804497835425926, 0.05492278554343751, 0.0300599596729236, 0.03156478410320623, 0.02866344978766782, 0.031075611244887114, 0.0311263215595058, 0.013001313649250992, 0.054875875024923255, 0.010646492641951357, 0.0361378963903657, 0.04429925452651722, 0.0448957784101367, 0.04360935065363135, 0.026879533726189817, 0.02508676108638091, 0.05143554980999657, 0.048796075728854964, 0.01942757886302258, 0.08155686940465655, 0.045130877223398, 0.033672259588326724, 0.012428789549241108, 0.011713216696599764, 0.07826566922345332, 1.9426005950995853, 16.330134017126902, 37.44753517423357, 32.56043284279959, 22.596795967647008, 12.940785373960223, 23.000378608703613, 34.06452676228115, 20.4069721698761, 5.011250572545188, 0.5094698763319424, 0.29061877408197945, 0.4759479122502463, 0.4543856435588428, 1.0768362688166755, 0.6453104157532964, 1.2311668332133974, 1.0384333580732346, 0.3598352628094809, 0.6663670944316047, 0.17522621314440454, 3.3229269044739858, 15.546370267868042, 36.88402237210955, 50.37816054480416, 58.2043856212071, 60.84778608594622, 57.925950459071565, 56.36312689099993, 57.8543701171875, 57.269039971487864, 56.638497897556846, 54.50318445478167, 56.30370242255074, 55.25501428331648, 56.75480031967163, 55.7384352002825, 55.042416776929585, 55.93008736201695, 55.53441524505615, 54.62273168563843, 55.3343939781189, 53.55439056668963, 54.421470165252686, 56.344147886548726, 57.13847637176514, 53.48013516834804, 29.230352333613805, 43.77281386511666, 57.651982988630024, 55.06042650767735, 56.079998220716206, 51.970673765454976, 52.393944127219065, 52.35947411400931, 53.26310471126011, 52.81114176341465, 53.64078794206892, 53.18560103007725, 54.09323031561715, 52.4865288734436, 53.4916170665196, 54.451792103903635, 55.99494532176426, 52.814532484327046, 54.564134052821565, 56.02987044198172, 54.85619810649327, 52.21310683659145, 52.8914212499346, 48.90334980828421, 45.29779406956264, 37.76065921783447, 33.29901245662144, 24.86121562549046, 17.091717379433767, 8.78425051484789, 1.7942607892411095, 0.08965914749673434, 0.3782023372394698, 0.896029702254704, 2.3171753755637576, 5.333456780229296, 5.55628594330379, 8.1102283511843, 18.550887720925466, 3.7725270305361067, 0.7844051005584853, 0.3962445833853313, 1.808017788188798, 12.460688301495143, 32.51811483928135, 27.204664094107493, 15.082333087921143, 14.80319789477757, 24.57347856249128, 27.29614233970642, 6.0717901672635755, 0.06961169466376305, 0.03543075094265597, 0.006182726697131459, 0.027577468061021397, 0.07993694847183568, 0.018264050761769925, 0.04094142559915781, 0.07905895129910537, 0.0073497573113335025, 0.026806219713762403, 0.021076899021863937, 0.01627366497580494, 0.03445005749485322, 0.040456228956047974, 0.06042169779539108, 0.07493857453976359, 0.05475408138175096, 0.036468733102083206, 0.01657692602436457, 0.07111787277140788, 0.025324475652139102, 0.0652102076315454, 0.012410207019586648, 0.006278867899839367, 0.00703215881782983, 0.04361330312011497, 0.03880475953753505, 0.05589441715606621, 0.043182494451424906, 0.08163072794143643, 0.08421306258865766, 0.009521685989706643, 0.06373506571565356, 0.02121872132244919, 0.045349820117865286, 0.00869542796031705, 0.016553526744246483, 0.0176486992277205, 0.04447601629155023, 0.03303517966664263, 0.04361129804913487, 0.0024321161119067775, 0.02957106162128704, 0.022303232324442694, 0.08532590751669236, 0.03257610662175076, 0.04885678764964853, 0.005509925299390618, 0.04971633884789688, 0.02262560770447765, 0.008116617233359387, 0.0624639999919704, 0.01347757228982768, 0.0049584116121487954, 0.015910825159932886, 0.022633865475654602, 0.05421712948009372, 0.030272877176425288, 0.03904587695641177, 0.019126955619347945, 0.04882160221625652, 0.057947657337146144, 0.04274595555450235, 0.010876581322268715, 0.019228104834577868, 0.02041996516553419, 0.008102563076785632, 0.026817839625956755, 0.02009375436630632, 0.05657897078033004, 0.027335361677355, 0.04186949187091418, 0.039294420941067595, 0.009094499849847384, 0.049446353156651766, 0.04526271657752139, 0.11302764248102903, 0.1267609130591154, 3.8779616015298024, 24.4794659614563, 44.348607608250205, 32.4175500869751, 20.22795878137861, 17.810532842363628, 34.098524297986714, 48.892805916922434, 25.80209377833775, 4.055369087627955, 0.25920781386750086, 0.15894861945084163, 0.25647570618561333, 0.7928720233695847, 2.4724947554724555, 1.204290223973138, 2.3156865068844388, 3.563860684633255, 1.6746713263647897, 1.049124355827059, 1.1783067839486259, 5.12047495160784, 21.14571680341448, 41.177779810769216, 53.294552258082796, 58.298318317958284, 61.351954323904856, 58.73319217136928, 59.81436661311558, 59.39709254673549, 59.080060141427175, 58.53225721631731, 57.072308676583425, 57.52632829121181, 56.35248919895717, 56.85547971725464, 57.3801520892552, 56.83871371405465, 56.78915916170393, 55.537788595472065, 55.31051649366106, 54.58894954408918, 53.11933258601597, 55.90077291216169, 58.952519008091514, 58.13547338758196, 55.11242682593209, 29.258211135864258, 45.02874592372349, 59.02471079145159, 57.483721937452046, 58.4344265801566, 54.37355538776943, 54.092507702963694, 53.64960868018014, 54.45105559485299, 54.41344152178083, 52.964526721409385, 53.71490090233939, 55.0256472996303, 54.15398188999721, 54.58011838368007, 55.7860894203186, 55.79313489368984, 53.38184942517962, 53.886917454855784, 55.21267543520246, 53.40881885801043, 53.60505335671561, 53.15646723338536, 52.24458565030779, 47.30664682388306, 42.6584826196943, 38.099550655909944, 31.56883110318865, 21.04608310971941, 12.004620705332075, 4.14343707050596, 0.813184104859829, 1.2980594209262302, 3.041137716599873, 3.6953268987791876, 6.871193008763449, 7.639817936079843, 5.3326981237956455, 7.401238509586879, 1.7641424110957553, 0.493788334940161, 0.14997198113373347, 1.2845966347626276, 13.156737991741725, 38.194188594818115, 34.61161402293614, 19.529221875326975, 15.397531168801443, 30.153364930834087, 33.49692494528634, 10.792211294174194, 0.3066980184188911, 0.0131718753005511, 0.019735152001625726, 0.028349379676261117, 0.03107539750635624, 0.03243773297539779, 0.03651477848844869, 0.05088722566142678, 0.03784965703796063, 0.044584208700273714, 0.029223427775182893, 0.02565137346807335, 0.052493633569351265, 0.08046626006918293, 0.03755615332296916, 0.036498608998954296, 0.06231154674398048, 0.058730177847402434, 0.09426274975495678, 0.05174598636637841, 0.024475624951134835, 0.009170818076069866, 0.020357760467699597, 0.047753537206777504, 0.018187500137303556, 0.04467276091288243, 0.02471397564347301, 0.026678992701428275, 0.0470678639997329, 0.031055628388587917, 0.059774063261491914, 0.008047628881675857, 0.0720310587702053, 0.015455624853659953, 0.04873584896059973, 0.14458534946399076, 0.0627076822732176, 0.18728245049715042, 0.13427644834986754, 0.11287993897816964, 0.13598258394215787, 0.07378832876150097, 0.17147197388112545, 0.11934775513197694, 0.15992978108780725, 0.16792532562145165, 0.16467189948473657, 0.08963066938200168, 0.13963223381766252, 0.18206321341650827, 0.10376032654728208, 0.15891419058399542, 0.1610996840255601, 0.07090615627488919, 0.0868225929194263, 0.08793773808117424, 0.10166424366512469, 0.12156306340226106, 0.11675172086272921, 0.10088814209614481, 0.1253679349486317, 0.13345804012247495, 0.11562347997512136, 0.09392301405646972, 0.10102547758391925, 0.17170517279633454, 0.161793336804424, 0.13080412681613648, 0.08913112511592251, 0.16540424233036383, 0.14880859213215963, 0.15040823843862328, 0.1524504931377513, 0.1707479634455272, 0.2303408442863396, 0.17521888496620314, 0.21867445244320802, 0.16553534886666707, 3.0893673343317847, 24.644100052969797, 52.52628646578108, 43.53530011858259, 33.322101320539204, 19.062976905277797, 30.02706057684762, 40.92614385059902, 27.087474039622716, 7.103100427559443, 0.8255689974342073, 0.8038059366600854, 1.704259687236377, 2.2049624025821686, 3.706520880971636, 4.652923285961151, 5.809619435242244, 3.3919681140354703, 1.5664249062538147, 0.7666269402418817, 0.5522757736699921, 4.344385053430285, 18.52554416656494, 39.379777090890066, 52.6197258404323, 59.15786606924874, 63.111856596810476, 60.815824372427805, 61.62740870884487, 63.284498487200054, 62.24436010633196, 61.49290548052107, 57.101807253701345, 60.53724329812186, 57.51264033998762, 59.26860645839146, 58.84819180624825, 58.87489373343331, 60.499577113560264, 58.938963072640554, 57.77910375595093, 58.86020524161202, 57.18419204439436, 59.38210528237479, 59.84413964407784, 61.49337795802525, 53.696564606257844, 36.53102261679513, 48.254290785108296, 58.29487895965576, 59.61194474356515, 60.56190940311977, 56.92032378060477, 56.21670402799334, 56.29402010781424, 58.075649397713796, 56.955446924482075, 57.1125248500279, 57.129600048065186, 57.390397208077566, 56.219052519117085, 57.11445297513689, 58.60503264835903, 58.412831578935894, 53.518708092825754, 54.75265605109078, 56.70503037316458, 54.15196691240583, 54.21410812650408, 54.60164737701416, 52.823724951062886, 48.36727891649519, 40.115862301417756, 36.27308464050293, 28.55667063168117, 18.14794431413923, 10.497429626328604, 2.8277874163218906, 0.4576594393168177, 1.1129449712378638, 3.331362234694617, 5.241556865828378, 11.07514020374843, 12.048480340412684, 18.53913484300886, 30.027050154549734, 6.8489644186837335, 2.3195688128471375, 0.5037508032151631, 2.316632547548839, 16.448553902762278, 40.826725551060264, 34.52071074077061, 23.492736646107264, 22.15408628327506, 34.239173207964214, 38.155282156808035, 10.452872565814427, 0.2797425091266632, 0.14026169718376227, 0.09316001499869994, 0.11979025495903832, 0.1417512715395008, 0.12857607565820217, 0.12851755879819393, 0.1432555429637432, 0.12907414750329085, 0.12544048391282558, 0.15204060370368616, 0.13056787449334348, 0.12917334932301724, 0.18348402503345693, 0.23764600657991, 0.1771424367491688, 0.16408700229866163, 0.08362021975751434, 0.17847992426582746, 0.1809179141585316, 0.10972908698022366, 0.1227864891822849, 0.1266114046531064, 0.10795823271785464, 0.10308249041970287, 0.16649232751556806, 0.12011239624449185, 0.16838526379849228, 0.15494168017591747, 0.1196507481592042, 0.32875146503959385, 0.10508848420743432, 0.16666988655924797, 0.10355753278625862, 0.14328856047775063], [0.0650481056155903, 0.008991345563637359, 0.049196197651326656, 0.013155816072997237, 0.04676306267668094, 0.034676935856363604, 0.03438504705471652, 0.058296709321439266, 0.04622464853205851, 0.02794881840236485, 0.04611128568649292, 0.05648910899513534, 0.052002465818077326, 0.08954989657338176, 0.013280145740801734, 0.043786146345415285, 0.009230484204765941, 0.04873128581259932, 0.04187271830492786, 0.03397387858214123, 0.05506969176764999, 0.025721318554133177, 0.06602613920611994, 0.012368028434658689, 0.02408310431720955, 0.06545467701341424, 0.023192547461284057, 0.03351330936753324, 0.0477625244030995, 0.04610111105388828, 0.011819460861650961, 0.06115239180092301, 0.027256992579038655, 0.04595322773924895, 0.11903998521821839, 0.04305416990869811, 0.010007167617524309, 0.09832937297012125, 0.026532742959846343, 0.015125751661668931, 0.05156115342729858, 0.031185001267918518, 0.09354432366256203, 0.02659539209811815, 1.0035976959126336, 11.985634752682277, 34.61820091520037, 31.875375202723912, 26.579675367900304, 15.139099870409284, 16.907904522759573, 35.68804284504482, 27.005019766943796, 8.577959367207118, 0.7042574669633592, 0.13395657337137631, 0.5812685979264123, 2.100996507065637, 4.38624404157911, 1.026501129780497, 1.5196363883359092, 3.030176281929016, 1.1164793244429996, 0.3595890631633145, 0.02598138406340565, 0.6113920243723052, 4.268573258604322, 18.272760016577585, 34.249970708574565, 47.409890106746126, 54.25533526284354, 59.051100049700054, 57.892543520246235, 57.07695354734148, 57.091510023389546, 58.941408838544575, 58.454166412353516, 57.84612955365862, 55.551250730242046, 57.95541082109724, 58.875491278512136, 58.01770142146519, 58.50934900556292, 58.32135854448591, 59.264708518981934, 56.052049091884065, 58.21057994025094, 56.81740011487688, 60.46486391339983, 42.85342822756086, 42.17523193359375, 43.207327774592805, 54.99478687558855, 60.564209256853374, 57.55084848403931, 55.82840742383684, 53.38612604141235, 55.5348356110709, 54.43877117974417, 56.51598031180245, 54.914628982543945, 54.842972210475374, 52.585436480385916, 55.11446612221854, 54.94587503160749, 55.27275650841849, 59.71665409633091, 56.29308557510376, 47.93934283937727, 42.25316292898995, 37.027037143707275, 34.431283950805664, 30.661941800798687, 25.345338310514176, 17.54386966569083, 14.322357365063258, 10.313279782022748, 5.449558138847351, 1.698429171528135, 0.44617705260004314, 0.3500309746180262, 1.1146959172827857, 2.1064890580517903, 2.857109465769359, 3.1936830282211304, 7.002784941877637, 5.9863616313253125, 2.8867654630116055, 0.9572280240910394, 0.10419196981404509, 0.08529018264796052, 3.164426335266658, 16.765007870537893, 28.663577352251323, 24.258713006973267, 18.848006589072092, 23.71357124192374, 36.06445108141218, 27.508361169270106, 8.161001443862915, 0.11059213602649313, 0.05539052687319262, 0.040981204714626074, 0.05622433784550854, 0.055973561480641365, 0.05817488514419113, 0.0321279240639082, 0.043554487704698525, 0.04562470143926995, 0.03367726378408926, 0.0061280579788477296, 0.0255605311997767, 0.02089603042363056, 0.04318295246256249, 0.095834399706551, 0.030471531873834983, 0.021445028018206358, 0.047476328510258875, 0.039078646805137396, 0.04870709943185959, 0.024816001865214536, 0.043176319782755206, 0.043025362704481394, 0.028406524199194143, 0.04871407816452639, 0.04183151087324534, 0.011383181504373039, 0.08129522630146571, 0.01068009963325624, 0.03533386632001825, 0.05005666487185018, 0.1423799613756793, 0.05428923739652548, 0.03982753572719438, 0.04457529275012868, 0.03961314241002713, 0.06931596196123532, 0.04964358971587249, 0.08133681371275868, 0.042330095012273104, 0.031658014814768515, 0.009305458083482725, 0.018656318641400764, 0.004941784959685589, 0.033041873414601595, 0.028575189345117127, 0.015020253036969473, 0.05140121593805296, 0.03721942692728979, 0.041809957208377976, 0.04155282297038606, 0.06770875677466393, 0.03665038031925048, 0.026379733313141123, 0.026707974628412297, 0.026288078499159644, 0.055722601911319156, 0.08350683655589819, 0.12899140694311687, 0.014324233867228031, 0.010888610051811805, 0.04446752781846693, 0.008229870665153223, 0.03708064276725054, 0.02339969402445214, 0.036084885842033794, 0.012881834658661058, 0.056903198560965915, 0.04489017031820757, 0.032347314791487794, 0.0672781788078802, 0.10293534331555877, 0.06456682751221315, 0.05157021526247263, 0.008007343409449925, 0.01967884038042809, 0.0751118181007249, 0.02325857909662383, 0.04079982212611607, 0.09443587117961474, 2.7166805097035, 20.647327729633876, 43.408116817474365, 32.56438289369856, 18.2415417603084, 13.796547225543431, 28.12044014249529, 44.44710527147566, 30.76816933495658, 8.122158408164978, 0.20842014625668526, 0.12671659115169728, 0.3820487622703825, 2.3825737748827254, 2.5532478051526204, 2.9335487697805678, 4.546330102852412, 7.7746129887444635, 3.055868983268738, 1.8813235632010867, 0.19369151230369294, 1.0930806142943246, 7.527878982680185, 22.911057778767177, 39.92823314666748, 52.09668976919991, 55.90593889781407, 58.57871287209647, 60.48252623421805, 60.72480991908482, 60.126986912318635, 61.59696865081787, 61.259640557425364, 59.86706869942801, 56.81250163487026, 57.228625774383545, 58.04238837105887, 58.90012959071568, 58.87986169542585, 58.40454237801688, 61.21538748059954, 59.026920318603516, 59.581740924290244, 57.929570470537456, 62.21846417018345, 46.71222496032715, 38.34698643003191, 44.852015018463135, 57.772773947034565, 59.68265656062535, 58.282000473567415, 56.237659794943674, 55.912789821624756, 56.199687889644075, 56.484977449689595, 57.91346454620361, 57.968442167554585, 57.47218097959246, 54.89910670689174, 56.41390780040196, 54.058635234832764, 55.774548462459016, 60.76901435852051, 55.31067630222866, 52.11103432519095, 47.12770986557007, 42.57169961929321, 39.19289486748831, 37.103064332689556, 32.02007491247994, 23.548058203288488, 19.71985786301749, 14.832248313086373, 8.113128355571202, 4.147765798228128, 2.038417339324951, 1.3033189901283808, 2.3937189025538306, 5.636927170412881, 4.97113037109375, 4.32533700125558, 5.602011169706072, 6.288806293691907, 2.2756883331707547, 1.1116653084754944, 0.1595603051994528, 0.15314413234591484, 2.6631240120955875, 17.708277940750122, 39.65673576082502, 31.647846017565044, 18.21734639576503, 20.451048067637853, 33.28452198845999, 32.015318870544434, 12.847709911210195, 0.26068905581321034, 0.013667578210255929, 0.04238880525476166, 0.08969650763486113, 0.025635600921564868, 0.01649309302281056, 0.06167281458952597, 0.055863801656024795, 0.005988068570981601, 0.01877323870680162, 0.030750932238463844, 0.0019745031895581633, 0.0389525342865714, 0.08389039883123976, 0.03693916482318725, 0.028090599990848984, 0.07018048342849527, 0.011093044171242841, 0.032292394167078395, 0.011074144426467163, 0.03698197699018887, 0.0805774312466383, 0.0487305394240788, 0.039599744736083915, 0.06484843311565262, 0.04641339661819594, 0.00793630164116621, 0.049568343574979475, 0.007504195274252976, 0.025782440988613025, 0.02588695234486035, 0.06689159705170564, 0.06655669930790152, 0.028405981371179223, 0.00986309427701469, 0.006036644892966641, 0.2376216064606394, 0.14700409610356602, 0.12524611077138356, 0.11194301103906971, 0.11226108789976154, 0.11889410018920898, 0.11345846472041947, 0.17516498214432172, 0.11466057093015738, 0.13607179772640976, 0.1579319704324007, 0.1275533741073949, 0.17176461246396812, 0.17550036843333924, 0.13535856242690766, 0.13701869334493363, 0.08752753652100052, 0.11364246306142636, 0.16244189414594853, 0.07575676563595023, 0.10925623628177814, 0.12759027284170898, 0.18653661837535246, 0.1263078823685646, 0.10943862649479083, 0.1557051134960992, 0.18727447092533112, 0.08976024242916278, 0.14047401079109736, 0.10084333842886345, 0.09155295908983264, 0.17431210433798178, 0.1997689333345209, 0.09921035569693361, 0.20119602818574223, 0.20792839835797036, 0.13824731670320034, 0.186504618663873, 0.13277269261223928, 0.15936382859945297, 0.17890174234552042, 0.17556835764220782, 0.3579427200768675, 0.16199285324130738, 2.0609655465398515, 20.870128665651592, 50.45793628692627, 42.53416197640555, 36.44201966694423, 24.397273983274186, 24.143869706562587, 40.018636158534456, 35.48871987206595, 12.48097356728145, 1.1003931590488978, 0.4041917212307453, 2.0480073732989172, 4.719127024923052, 9.748497196606227, 5.147790057318551, 5.533472401755197, 5.743160784244537, 2.4493513916219984, 0.7865191985453878, 0.20152369274624757, 1.1197755932807922, 5.542378689561572, 22.565034014838083, 35.818526540483745, 50.13207619530814, 57.16543190819876, 62.12962450299944, 60.62181677137102, 60.49592236110142, 60.49644347599575, 62.293365750994, 63.05859170641218, 60.986083030700684, 55.86576788766043, 59.09802123478481, 61.80579675946917, 61.06875269753592, 61.606480734688894, 61.055259295872276, 64.1346800667899, 60.10926900591169, 61.76701191493443, 61.514778409685405, 62.36532129560198, 49.63033635275704, 41.80410432815552, 47.828644139426096, 58.81438882010323, 62.399402209690635, 61.400807108197895, 58.69130148206438, 57.34643248149327, 59.137188230242046, 57.27189220700945, 60.63622038705008, 59.11745534624372, 58.13516419274466, 56.144790172576904, 59.72467231750488, 55.6688038281032, 57.96013559613909, 60.28407873426165, 55.432655402592246, 50.06088147844587, 44.940288407461985, 39.99665205819266, 36.629506383623394, 34.393312045506065, 28.76768568583897, 19.925336939947947, 16.61409820829119, 12.420314056532723, 6.685736903122493, 3.229801284415381, 0.9961821224008287, 1.2453889272042682, 2.8756813492093767, 5.1192251443862915, 7.823393685477121, 7.116957306861877, 14.191139766148158, 11.472807322229658, 9.062128952571324, 3.303977212735585, 0.24045671575835773, 0.4981396443077496, 4.256812129701887, 21.960287128176006, 34.76553051812308, 33.82715197971889, 27.079639945711406, 32.060193811144146, 46.61076736450195, 38.578166893550325, 12.576614652361188, 0.36009370322738377, 0.15770147208656582, 0.09977930731007031, 0.17992666949118885, 0.10944512007491929, 0.09903489332646132, 0.13229526180241788, 0.16227565306637967, 0.09376211304749761, 0.07402488642505237, 0.09570636014853205, 0.11398601212671824, 0.10359462829572813, 0.1554249735283, 0.24238155675785883, 0.13114498209740433, 0.0874624853687627, 0.09729955358696835, 0.11712141388228961, 0.12107134264494691, 0.0868138058909348, 0.15911454840430192, 0.10014093254825898, 0.14834064724189894, 0.16240499541163445, 0.153709935556565, 0.08197448735258409, 0.24525832810572215, 0.05254059497799192, 0.14952083677053452, 0.1292100716382265, 0.28462592565587586, 0.14904996060899325, 0.12135110263313566, 0.09014344508094446, 0.0959317966231278], [0.05416027842355626, 0.02980136658464159, 0.05703645944595337, 0.018218826402777007, 0.0266689656501902, 0.062212059939546246, 0.026281858029376184, 0.026628823518486958, 0.03027805100594248, 0.10086999806974616, 0.03211764765105077, 0.052125182268874984, 0.09343269786664418, 0.08696334143834454, 0.053613243491521904, 0.08158774953335524, 0.01989118961085166, 0.018736889585852623, 0.02102450424406145, 0.03823040000029972, 0.05278531202514257, 0.055962542071938515, 0.05988109537533351, 0.07027999058898006, 0.020117124808686118, 0.012707320540877325, 0.044609657156148126, 0.06607715825417212, 0.0706331952075873, 0.02442496213396745, 0.0409579988169883, 0.06836852351469652, 0.028396475095567957, 0.06861782406589814, 0.019856653874740005, 0.08439078448074204, 0.03400486049109271, 0.0714759628421494, 0.02611252961547247, 0.08013807982206345, 0.030050673921193396, 0.07527278017784868, 0.0015114930512416841, 0.014978819992393255, 0.022432891884818673, 0.4256751984357834, 9.30834879193987, 29.94023241315569, 35.65855469022478, 23.27262987409319, 25.267924955913, 23.678825037819998, 27.794272593089513, 34.58324105398995, 16.30421723638262, 2.8478614134447913, 0.41009750004325596, 2.05984080689294, 1.5244971960783005, 1.9269052658762251, 7.454304507800511, 6.794672931943621, 2.8696431475026265, 5.00225612946919, 0.32410621430192676, 0.120406106912664, 0.021777593297883868, 0.5210408525807517, 4.753531898771014, 12.026449339730398, 30.113968644823345, 45.9920129094805, 51.957166467394146, 53.878524030957905, 55.70206832885742, 54.24288409096854, 55.56861080442156, 55.34867600032261, 56.05562046595982, 57.173092297145296, 58.979464122227256, 58.3534939629691, 61.18392603737967, 62.38902160099575, 63.797880036490305, 58.33797863551548, 59.52594688960484, 57.64274535860334, 56.77633626120431, 29.88893038885934, 32.826618330819265, 35.146319593702046, 47.0346074785505, 60.884965896606445, 57.53929015568325, 60.331118038722444, 55.27737011228289, 56.76624400275094, 57.324830532073975, 59.737227712358745, 57.5088848386492, 57.433778285980225, 60.12322793688093, 61.79197679247175, 57.457711356026785, 52.46394375392369, 42.59301321847098, 25.863164969852992, 14.28911805152893, 10.765869804791041, 5.998867954526629, 3.9604110973221913, 3.36147985288075, 2.668985686131886, 1.600816969360624, 1.4310425136770522, 0.26208119254027096, 0.03791176674089261, 0.11133624466934375, 1.1551554948091507, 1.236126761351313, 3.049916765519551, 4.865810011114393, 4.144537057195391, 3.965497612953186, 3.5654479137488773, 5.7388172916003635, 1.2212872547762734, 0.7341246785862106, 0.4736608692577907, 7.531088181904384, 21.87425627027239, 31.861124447413854, 23.65865789140974, 20.58238639150347, 23.37300876208714, 28.67368871825082, 18.800013644354685, 3.1417843273707797, 0.06889487669936248, 0.02852226361366255, 0.04038279111097966, 0.1631208091442074, 0.07471849170646497, 0.021455664054623673, 0.038572693775807104, 0.044064104823129516, 0.043629021383821964, 0.020423702197149396, 0.04132806842348405, 0.022149103094956706, 0.03377954615280032, 0.05088928501520838, 0.029866885926042284, 0.027002818450065594, 0.0634278522006103, 0.03321094059252313, 0.056018361755247624, 0.08981864393821784, 0.06202509640050786, 0.055702880291002135, 0.017014433530026248, 0.0790514534871493, 0.043389532448990006, 0.03583485247301204, 0.032705418432929685, 0.03649773708145533, 0.014095247806315976, 0.04963257030716964, 0.05209670076146722, 0.04010935167648962, 0.07805845141410828, 0.05614741233044437, 0.021573925923023905, 0.02978812836642776, 0.046146108103649955, 0.03854694676452449, 0.014321373842124428, 0.03582104767805763, 0.02428530266375414, 0.03195697055863483, 0.10111273040196725, 0.055381970546607456, 0.032197412835167985, 0.006880479947929936, 0.02451308347683932, 0.06782105432025023, 0.06188035809567996, 0.02103210722894541, 0.018567116731511693, 0.030062778985926082, 0.019264075672253966, 0.03420370517830763, 0.018725827768711106, 0.015132009450878416, 0.018208025821617672, 0.05287828150072268, 0.04246953395860536, 0.07320605072059802, 0.04454008696068611, 0.032151954381593635, 0.04481666122696229, 0.03659139187740428, 0.017672692225979905, 0.04140829161873885, 0.018563505228874937, 0.052173656810607226, 0.10938568719263587, 0.007823051602047468, 0.03914607961529067, 0.0028717637594257083, 0.016640772776944295, 0.016723494677405273, 0.03871304535173944, 0.028880821873566935, 0.022290474169754555, 0.14272150876266615, 0.04008554866803544, 0.028049448538305502, 0.05309179950771587, 0.017198033231709684, 1.1841152608394623, 15.30870018686567, 38.8667186328343, 38.55325412750244, 20.057837350027903, 11.270152688026428, 25.597738572529384, 40.767464365277974, 38.779254708971294, 16.214696645736694, 1.4339716136455536, 0.08792844215141875, 0.4730301573872566, 2.7235501067978993, 4.018037719385965, 3.0076295946325575, 6.147469077791486, 6.394153577940805, 5.301247102873666, 1.792294557605471, 0.44126904596175465, 0.19560967651861055, 1.5171546872173036, 7.833637935774667, 17.57370696749006, 36.80928407396589, 49.44517380850655, 54.900770800454275, 56.19180168424334, 57.423692975725444, 58.045508112226216, 58.92558779035296, 56.47521523066929, 56.17780801228115, 57.02056196757725, 61.073637281145366, 59.40358216421944, 62.19147041865757, 64.43236868722099, 64.1807883126395, 61.8292886189052, 60.39977318899972, 59.34445299421038, 58.17013447625296, 36.028059891292024, 34.55663292748587, 37.764459882463726, 50.53597150530134, 60.76278182438442, 59.29544040134975, 60.897048813956125, 57.37281479154314, 57.134220600128174, 57.97572387967791, 60.12329741886684, 58.922516686575754, 57.3833760534014, 60.36471952710833, 59.68750640324184, 58.10015222004482, 54.49013573782784, 48.99393694741385, 31.796179635184153, 20.37013282094683, 16.17196696145194, 10.563942125865392, 8.108863030161176, 7.017518162727356, 6.17372110911778, 3.6842970677784512, 3.356198136295591, 1.315000866140638, 0.8374975887792451, 0.9364145866462162, 2.4847192423684255, 4.494238589491163, 3.625729399068015, 10.041909200804573, 8.567491906029836, 3.3955258088452474, 3.7708781361579895, 0.9743393744741167, 0.17806095603321279, 0.15308134071528912, 0.49265637568065096, 6.094548123223441, 25.85126096861703, 39.1305695261274, 23.97441530227661, 17.553628410611832, 21.538816349846975, 32.072207246507915, 28.59264840398516, 6.774866657597678, 0.04568654990621975, 0.0566150891993727, 0.015817311160000305, 0.0402077121127929, 0.036962180731019804, 0.02565781106906278, 0.05049344804137945, 0.014397709031722375, 0.03278348049415009, 0.0683584947671209, 0.020513667458934442, 0.07898926575269018, 0.06085215362587145, 0.06440285952495677, 0.11531241238117218, 0.012193166567677898, 0.02855837524735502, 0.0464429875303592, 0.1255048904567957, 0.05292359067659293, 0.05179005043048944, 0.03938817412459424, 0.012860873863766236, 0.0415409553929099, 0.023270796119634594, 0.033338651061058044, 0.028539196455052922, 0.030294827784278562, 0.03092037600332073, 0.02077438945083746, 0.03277818452832954, 0.01323036417098982, 0.05162345312003579, 0.014371809350060565, 0.0628354504172291, 0.021849107496174316, 0.005012696109978216, 0.15404078923165798, 0.11688171460160188, 0.15631461436195032, 0.12899999719645294, 0.17135354237897055, 0.16971767587321146, 0.1336542045963662, 0.12654101343027183, 0.13349424675107002, 0.2574869133532047, 0.13679895656449453, 0.13105894385703973, 0.12100688181817532, 0.11597418758485999, 0.12041009669857365, 0.18470487238040992, 0.12340411889765944, 0.1289740771587406, 0.09503646966602121, 0.10461756054844175, 0.1742300016007253, 0.12039423254983765, 0.14128595936511243, 0.12393273838928767, 0.132120905444026, 0.13837125790970667, 0.19612376179013932, 0.12994112526731832, 0.12552369944751263, 0.10631007794290781, 0.1525082771799394, 0.1704649736306497, 0.0792110517088856, 0.1550724474447114, 0.13208568947655813, 0.13606474096221582, 0.208290749628629, 0.20176542763199123, 0.13713329790958337, 0.15500405111483165, 0.2526470587721893, 0.14712385753435747, 0.08350968640297651, 0.08922297161604677, 0.07169163519782679, 1.0552926191261836, 15.21511663709368, 45.45652219227382, 47.722979409354075, 33.249374525887625, 34.03780051640102, 32.26335913794381, 36.137893540518625, 43.15067911148071, 20.802520956311906, 4.148688171591077, 0.5857048055955342, 3.749837253774915, 3.2031951120921542, 5.376992889813014, 18.015916381563457, 15.518777234213692, 8.945493016924177, 10.271986637796674, 2.2448235665048872, 0.26199363438146456, 0.2065332896475281, 0.7267639849867139, 6.042016702038901, 14.074810419763837, 33.562008721487864, 48.55639845984322, 56.92019176483154, 56.47596911021641, 57.359036513737266, 57.548041411808555, 57.11931324005127, 56.557155336652485, 57.148440088544575, 57.58135454995291, 60.2190158026559, 61.347167015075684, 64.92705958230155, 67.7728819165911, 67.06110150473458, 64.19018922533307, 64.29237638201032, 60.41034834725516, 56.19321911675589, 37.24263627188546, 33.76454871041434, 39.71023341587612, 51.428137574877056, 60.57381166730608, 59.3455160685948, 61.970740045819966, 58.72167900630406, 57.356243337903706, 58.32740347726004, 58.610542569841655, 58.84665625435965, 60.08451952253069, 61.37024198259626, 62.580374990190776, 58.76315975189209, 54.16879197529384, 46.15073408399309, 28.50565869467599, 16.708968911852153, 13.016513790403094, 7.610028403145926, 5.29466802733285, 4.919994235038757, 3.5644449847085133, 2.6282358041831424, 2.1203357321875433, 0.6918929304395403, 0.4085736189569746, 0.42600333797080175, 2.477257094212941, 4.32234753881182, 7.649722593171256, 10.406342216900416, 9.702469723565237, 10.932089822632925, 8.829558849334717, 11.491260000637599, 3.276776535170419, 1.4668856646333421, 0.9812320960419518, 9.998588919639587, 27.538092511040823, 38.37409482683454, 29.703163351331437, 27.680650438581193, 30.85675539289202, 40.14351960590908, 29.790523052215576, 6.186983048915863, 0.2303844333759376, 0.12389688459890229, 0.11370959731617145, 0.16560131604118006, 0.15490981617144176, 0.097819236772401, 0.09699810083423342, 0.13149794244340487, 0.12636038740830763, 0.17554528745157377, 0.09930191042699985, 0.13709775624530657, 0.10119181365839072, 0.18238687462040357, 0.2267620334667819, 0.1044179287606052, 0.11339677910187415, 0.10963261965662241, 0.19433260576001235, 0.21337605746729033, 0.1303377832685198, 0.18866582055177006, 0.13779858792466776, 0.11156296357512474, 0.16572061606815883, 0.11624147609940597, 0.13402427759553703, 0.11184847075492144, 0.10966624785214663, 0.11728667787143163, 0.173376309552363, 0.10288240401340382, 0.21099061332643032, 0.11380487720349006, 0.10514164064079523, 0.1185038611292839, 0.1451394140188183], [0.061206335334905555, 0.05078838346526027, 0.04627564722406013, 0.03721974244607346, 0.050429513079247305, 0.07949532395494835, 0.051331459145460806, 0.02043927796850247, 0.015283765504136682, 0.03747374524495431, 0.05483223165252379, 0.03268353228590318, 0.048076095791267495, 0.026964416760685186, 0.017258502576234083, 0.02200565400666424, 0.05628607774685536, 0.019801210778366243, 0.06316515058279037, 0.04101105347009642, 0.045996562378214936, 0.02294551830605737, 0.00687003178089591, 0.0667952179376568, 0.01130514997722847, 0.021958297351375222, 0.01935622581679906, 0.009899869178687888, 0.044251346561525545, 0.011947835446335375, 0.03618127852678299, 0.0550224453743015, 0.03942608726876123, 0.059522971377841065, 0.038919051976076195, 0.056195489929190705, 0.035781679076275656, 0.04241851491055318, 0.05111415830573865, 0.01984959202153342, 0.06954004815114395, 0.020771524336721216, 0.08978540929300444, 0.07677663769572973, 0.0030497950210701674, 0.04596261187855687, 0.14859387651085854, 7.031366791043963, 32.94477244785854, 40.554192883627756, 31.9244954926627, 19.367426122937882, 21.348835229873657, 22.701965638569423, 29.26630231312343, 23.162865706852504, 6.040078154632023, 0.8026633922542844, 0.4803913395319666, 1.1509283844913756, 1.0882002647433962, 7.117216561521802, 5.021495691367558, 4.729141550404685, 1.4883403990949904, 0.8933068769318717, 0.050615126333598576, 0.21436928345688752, 0.21717765847487108, 0.5497114541275161, 3.0132593725408827, 12.047221847942897, 21.007612671170914, 26.304394687925065, 29.807271684919083, 30.677022865840367, 33.12225375856672, 35.98236158915928, 41.70677048819405, 45.807187352861675, 55.910559449877056, 56.17090150288173, 59.92591994149344, 55.989553519657676, 57.626392773219514, 56.80589737210955, 59.681565693446565, 56.93101011003767, 51.54594428198678, 25.84820376123701, 33.05131612505232, 32.05317265646798, 42.23041105270386, 65.17086492265973, 57.909788949149, 61.22249548775809, 58.306767327444895, 57.535256726401194, 58.306294849940706, 59.34803826468331, 59.68672125680106, 57.722719124385286, 53.29975298472813, 42.423452854156494, 28.539355720792496, 14.55498218536377, 5.870888650417328, 1.413875469139644, 0.6649816344891275, 0.21810588080968174, 0.3397732079029083, 0.03773960205061095, 0.15644380742950098, 0.3819122410246304, 0.3338212344263281, 0.37574376059429987, 0.6733639304127012, 0.8808787752475057, 2.696017869881221, 3.29405431662287, 3.6744349684034074, 1.8046673451151167, 13.142166750771658, 9.92397221497127, 1.664114298565047, 2.24948211652892, 0.6195573519383157, 0.5564294936401504, 1.2525130020720618, 11.02182754448482, 26.30415497507368, 24.8129551751273, 16.520703996930802, 24.848514318466187, 26.882219042096818, 30.166910443987163, 14.227682948112488, 1.5593917007957185, 0.06542445506368365, 0.06440883063312088, 0.02883001317137054, 0.08570852662835803, 0.04094480470355068, 0.024970823200419545, 0.009729213380653943, 0.04536230516220842, 0.0383990973766361, 0.02581879689491221, 0.051436296198517084, 0.026077288202941418, 0.018740205925756266, 0.018937320348673632, 0.02734806215656655, 0.045134174903588634, 0.021357195052717413, 0.027373101795092225, 0.01724245013403041, 0.04517291246780327, 0.020455691730603576, 0.06924312122698341, 0.021383162587881088, 0.025041163533127735, 0.023638714770121232, 0.021970034310860292, 0.03614428140489118, 0.013724043350001531, 0.014180055353790522, 0.035887974979622025, 0.04292149595650179, 0.026665279508701394, 0.010411769567456628, 0.025430147303268313, 0.024806173285469413, 0.08268975147179194, 0.08698894934994833, 0.013954701999734555, 0.041783931997737715, 0.06228245794773102, 0.04561931726389697, 0.049369464961013625, 0.04580992792866059, 0.040444076393863986, 0.025070662843063474, 0.05531808986727681, 0.07377990135656935, 0.09601170090692383, 0.03372720396146178, 0.04141469020396471, 0.030435766293002025, 0.04093909143869366, 0.018086864912350262, 0.03523160430735775, 0.017389597238174508, 0.03178274990724666, 0.00982660605638687, 0.024309249860899787, 0.031180305805589472, 0.04253593539553029, 0.023171324582238282, 0.04102304996922612, 0.01634498409527753, 0.04427162118788276, 0.041473441158554385, 0.023007293830492666, 0.02769560948945582, 0.024703251397503272, 0.019734619351636087, 0.04094503879813211, 0.028068841069138477, 0.03468679157750947, 0.015424758295661636, 0.015264288156426378, 0.029498075002006123, 0.03849658250276532, 0.11518795548805169, 0.08431755698152951, 0.06737754347601108, 0.05512946731011782, 0.07340735170458045, 0.09826206908162151, 0.05035375464441521, 0.017156958114355803, 0.5497387583766664, 11.72436945778983, 41.52034684589931, 41.61133350644793, 30.576920168740408, 13.983314803668431, 21.6439425945282, 35.32202563967024, 40.347212995801655, 22.858510289873394, 5.316132315567561, 0.4816066771745682, 0.2473924835877759, 0.2555901365620749, 0.6463822296687535, 1.2176674604415894, 4.232813051768711, 6.240751683712006, 3.958028733730316, 2.334175011941365, 1.9986582270690372, 1.033105718238013, 0.5665078014135361, 1.1063618787697382, 5.226097992488316, 16.347824130739482, 25.83086105755397, 33.5336913381304, 34.47436973026821, 36.262224606105256, 39.26775128500802, 41.16944892065865, 47.19523593357631, 49.505168029240195, 56.48320913314819, 57.273525033678325, 59.21007483346121, 56.67876270839146, 61.16520759037563, 61.4396892275129, 61.26780469076974, 58.230205127171104, 52.91352694375174, 29.57180765696934, 33.820123876844136, 35.672791549137656, 45.97319718769619, 64.42322485787528, 59.1250010899135, 61.97674328940255, 58.39084053039551, 58.453297887529644, 59.19976370675223, 61.04527473449707, 59.92416204724993, 59.76743153163365, 56.73023843765259, 49.16010659081595, 35.128747599465505, 21.406626871653966, 9.684311475072588, 3.9897581168583462, 1.6100342976195472, 1.3177890479564667, 1.0820202763591493, 0.6489225019301686, 1.1564134444509233, 1.1486567578145435, 0.8326476918799537, 2.011863495622362, 2.994311417852129, 2.130330715860639, 3.0624241743768965, 4.394677417618888, 4.377546199730464, 4.5704459973743985, 7.000887215137482, 5.654663750103541, 2.2952464265482764, 0.22362801592264855, 0.500387712248734, 0.3611990639141628, 1.1324074183191573, 9.651313611439296, 36.05395582744053, 35.46136481421334, 20.136768886021205, 18.629492691584996, 28.03205384526934, 34.58550616673061, 20.73095277377537, 3.2410556290830885, 0.10612223909369536, 0.04069434046479208, 0.04550997134564178, 0.06571062720779862, 0.03436823295695441, 0.01682354975491762, 0.024373820949611918, 0.024537456454709172, 0.04199788087446775, 0.07129641569086484, 0.10311775388462202, 0.08283625396766833, 0.03288756776601076, 0.06852580114666905, 0.09670127569032566, 0.02691986415136073, 0.02418479466411684, 0.010891470076915408, 0.04092879127711058, 0.06343571642147643, 0.03474432795441576, 0.017566654165940623, 0.018853997944721153, 0.12545063479670457, 0.011129533240039433, 0.02103126754185983, 0.05086273054725357, 0.04126926657876798, 0.043305078587893925, 0.025472326736365045, 0.05218053715569632, 0.08365451970270701, 0.017396589541541677, 0.024769562928538238, 0.041105071282280345, 0.07887943807457175, 0.04760585405996867, 0.04708940748657499, 0.13066125448260987, 0.10813549999147654, 0.08780172573668615, 0.1459807295884405, 0.1391130323920931, 0.15440020923103603, 0.09065426659903356, 0.18706207589379378, 0.14584359766117164, 0.14072212390601635, 0.18874322782669747, 0.1724941733160189, 0.188938564487866, 0.1416669703487839, 0.08275104354002646, 0.18882507272064686, 0.09438977151044778, 0.09473417552986316, 0.1452885695866176, 0.23813875871045248, 0.18366128552172864, 0.14616378476577147, 0.11459050540413175, 0.15257081096725805, 0.1402496735432318, 0.12219967852745738, 0.08567427418061666, 0.06962133664637804, 0.09756939339318446, 0.21399494925779955, 0.07511334480451685, 0.10549489954220397, 0.17844675747411592, 0.11780551288809095, 0.1655211810554777, 0.21798900993806974, 0.08057500887662172, 0.13831358243312153, 0.12954164456043923, 0.155069339754326, 0.14402722726975167, 0.06937231429453407, 0.20618285345179693, 0.2155654864119632, 0.12815760954150132, 0.16923854872584343, 0.5459283771259444, 11.979998895100184, 47.650089332035606, 51.153252942221506, 44.70684630530221, 27.406378984451294, 28.37819572857448, 28.314928906304495, 37.7376572063991, 30.110331262860978, 8.878471561840602, 1.0687742957047053, 0.7993738002010754, 2.7163009643554688, 3.6869877576828003, 15.966182163783483, 14.211358155523028, 10.378688386508397, 3.7485401119504655, 2.141088047197887, 1.9737350387232644, 1.043599886553628, 0.4219116361013481, 0.8993155487946102, 3.790965812546866, 13.161406312670026, 21.917743308203562, 29.919829027993337, 33.220080920628135, 34.71890115737915, 37.353133474077495, 38.58922495160784, 44.9196001461574, 49.52874674115862, 58.4184387751988, 59.19740826742989, 60.63012681688581, 56.873492922101704, 62.73138019016811, 59.34749630519322, 61.56675788334438, 58.47363526480538, 54.222404275621685, 34.69194214684622, 37.11598103387015, 39.04001712799072, 49.1393175806318, 62.213621275765554, 59.73091874803816, 62.559467860630576, 60.38522366115025, 57.21042496817452, 58.96780504499163, 58.90920393807547, 59.568921497889924, 58.42573438371931, 54.41427183151245, 44.78969315120152, 31.93742609024048, 16.883370433534893, 7.210716732910701, 2.357018083333969, 1.227302006312779, 0.5937061991010393, 0.7884490607040269, 0.3592688760587147, 0.5997586771845818, 1.0094273430960519, 0.7159563334924834, 1.4152241796255112, 2.057353351797376, 1.9224249805722917, 5.000137363161359, 7.654462133135114, 9.489050592694964, 5.7178424171039035, 23.0820894241333, 19.621264662061417, 8.059271131243024, 6.577305921486445, 1.8195228108337946, 1.0100532237972533, 2.5629739803927283, 13.314480338777814, 33.41142736162458, 30.945053100585938, 24.58615381377084, 33.055797713143484, 37.141328062329976, 41.07591227122715, 21.263440132141113, 3.287169737475259, 0.10455613277320351, 0.25730075048548834, 0.11009297174002443, 0.1725707527782236, 0.11052455393863575, 0.059575483202934265, 0.124971779063344, 0.06595040112733841, 0.10091200617275067, 0.09572884679905005, 0.35250960875834736, 0.13835862358765944, 0.05520298997206347, 0.16091035918465682, 0.12764874898961612, 0.16851365619472095, 0.0949892843408244, 0.10870180531804051, 0.12520378375692026, 0.19405659128512653, 0.13185175774352892, 0.1742772004966225, 0.16352147050201893, 0.16167533956468105, 0.09610717756939785, 0.13180875219404697, 0.13210501415388926, 0.09333330605711256, 0.09371741116046906, 0.08830129714416605, 0.08575656690767833, 0.1658992607678686, 0.09868026378431491, 0.12244253978133202, 0.12362792688821043, 0.1858521665313414, 0.2193631383457354, 0.11588487880570547], [0.03368210173877222, 0.03760469911087837, 0.040744803114128966, 0.05560492019035986, 0.06933046225458384, 0.051678767294756005, 0.07427057716995478, 0.03321946977770754, 0.03561023702578885, 0.015431954159534403, 0.10564494399087769, 0.023408604885584543, 0.025104844044627886, 0.09070869189287935, 0.09907450620085001, 0.020204253794093217, 0.054281905825648985, 0.05237439800319927, 0.03729409970609205, 0.013218426195505475, 0.07786519785544702, 0.05618496585105147, 0.005335645276188318, 0.08047805979315724, 0.028187701744692664, 0.05563465020220194, 0.05871920593615089, 0.047605226415076425, 0.06213624043656247, 0.033144505228847265, 0.06804330846560852, 0.023119503166526556, 0.04065704478749207, 0.030581681856087277, 0.008746998318071877, 0.02461155247874558, 0.033529468679002354, 0.041916195436247757, 0.015650583231555562, 0.0261878928036562, 0.044624042098543475, 0.06185173748859337, 0.04338970208274467, 0.046834997566682954, 0.05461109708994627, 0.02882188092917204, 0.016636637106005634, 0.06049301861120122, 3.3880701746259416, 26.147110053471156, 36.9194894518171, 30.952571051461355, 22.518701689583914, 19.641805274145945, 27.562746456691197, 32.6990077154977, 28.023540564945765, 12.896919659205846, 2.8828890195914676, 0.3810202660305159, 0.24370377723659786, 0.9363976504121507, 4.841778797762735, 4.15885295186724, 2.274046386991228, 2.3132218505655016, 2.135763990027564, 0.5519176700285503, 1.1520854766879762, 0.13069736611630234, 0.09455011612070457, 0.39187408504741533, 1.5787161609956195, 2.458753607102803, 4.415913283824921, 4.833133067403521, 4.4306043812206815, 5.337412476539612, 7.0295650362968445, 11.878948637417384, 24.18292031969343, 38.731954847063335, 53.02124834060669, 57.46457617623465, 55.014460699898855, 52.269543579646516, 52.731206212724956, 54.70759003502982, 43.5475880077907, 28.005169527871267, 28.81923610823495, 27.487480095454625, 32.7425868170602, 59.45986952100481, 61.2902751650129, 60.56489018031529, 55.6508184160505, 54.754375730242046, 55.455268314906526, 52.61889205660139, 47.71005228587559, 34.24143137250628, 21.475797925676616, 10.364285639354161, 2.2413351365498135, 0.49030375906399315, 0.07330311515501567, 0.08379189590258257, 0.2139750546110528, 0.33228066137858797, 0.25573756865092684, 0.5501605900270599, 1.2236158783946718, 0.7061434143355915, 1.3183729137693132, 3.998634006295885, 3.536152354308537, 3.1649524441787174, 2.9835877418518066, 4.094254681042262, 3.7195196577480862, 3.7320941601480757, 3.9775909526007514, 5.5249161294528415, 1.885144203901291, 0.694530260350023, 0.6017600840755871, 3.713293637548174, 20.734531096049718, 30.919945784977504, 24.828067507062638, 17.734790529523575, 22.523549795150757, 27.293858119419642, 25.95033185822623, 8.271619371005468, 0.5354052760771343, 0.10442923315401588, 0.01349775361761983, 0.09138123544731311, 0.06924630355622087, 0.05604370503819414, 0.042968233448586295, 0.013289385691418179, 0.03812243150813239, 0.024652393501518027, 0.021879051246547272, 0.007639831031805703, 0.04855831705832055, 0.0328258482207145, 0.06148304870086057, 0.024445124802046587, 0.007342245928677065, 0.04679119134587901, 0.07655253793512072, 0.018558942080874528, 0.027400185520361577, 0.026512831349724104, 0.037756433111748526, 0.018075933713199835, 0.007446345923069332, 0.032496718024568896, 0.021640049160591195, 0.061810007584946494, 0.09820046488727842, 0.03538472930501614, 0.039950659299003224, 0.038700472097843885, 0.027115100728613988, 0.04500706833122032, 0.02498428533518953, 0.03091339727065393, 0.014794429797413093, 0.029111449141055346, 0.07830921081559998, 0.006277693610172719, 0.027504016645252705, 0.023905077084366764, 0.023523779419649924, 0.04633084944050227, 0.03404058535982456, 0.03272517058732254, 0.021739754792568938, 0.02887755472745214, 0.019753535211618458, 0.015711788786575198, 0.03722486199278917, 0.022050288040190935, 0.021631896562342132, 0.09372512610363108, 0.02413883918364133, 0.0059029264209259835, 0.04778583886634026, 0.024363561500129954, 0.07581540463226182, 0.08982711884060077, 0.021893889111067568, 0.025790527429697768, 0.03376617901293295, 0.028720463692609752, 0.006194982735905796, 0.03880359924265316, 0.039460275255675824, 0.012603652264390672, 0.01924000633880496, 0.04122491413727403, 0.03690258160765682, 0.0103126194860254, 0.016115834337792227, 0.010401628861602927, 0.028330082140330757, 0.0664595195225307, 0.051929730256753306, 0.031445538359028954, 0.05489075190520712, 0.05638664681464434, 0.01854077769842531, 0.05185730342886277, 0.018516095987121974, 0.0035463963535481264, 0.05754051596990653, 0.024250700770478164, 0.07160404311226946, 0.10963183255600077, 9.612709420067922, 37.02504995891026, 40.49399021693638, 29.386474881853374, 16.59858809198652, 14.120110069002424, 31.027802671704972, 42.73607315335955, 29.45385503768921, 12.122969371931893, 1.8799449971743991, 0.4457867592573166, 0.3334201116647039, 0.7496092276913779, 1.6452217123338153, 2.6322095223835538, 4.394843305860247, 4.635431630270822, 5.978503652981349, 4.292373878615243, 2.765188489641462, 0.6111365695084844, 0.19913738008056367, 1.1599189192056656, 2.7671556983675276, 4.438154901776995, 6.865260115691593, 7.854541591235569, 6.858646299157824, 7.67406473840986, 10.287804211888995, 16.98812321254185, 30.61002138682774, 44.98762648446219, 55.536586557115825, 57.951978410993306, 54.00794117791312, 56.004759652274, 57.60654524394444, 57.54828459875924, 48.479165758405415, 32.57740381785801, 31.613334315163748, 31.104628903525217, 37.567249161856516, 59.042484283447266, 61.969906261989046, 61.650205748421804, 59.27574920654297, 55.254962171827046, 57.04177829197475, 55.634121894836426, 51.005982398986816, 40.52829694747925, 26.793846641268047, 14.799880129950386, 4.821959061282022, 1.4724913409778049, 0.3372987263969013, 1.038202981863703, 0.5721863795604024, 1.2461840616805213, 1.592553389923913, 3.0322227435452596, 2.625827167715345, 4.681276713098798, 4.516641753060477, 4.515794941357203, 6.677294841834477, 5.884192279406956, 6.833883787904467, 5.109834653990609, 4.198103325707572, 3.5926690016474043, 1.5945825896092822, 1.0905990217413222, 0.7600504702755383, 0.11424686812928744, 0.4776492980974061, 2.323598333767482, 17.64390288080488, 38.922745432172505, 31.986998013087682, 14.199698209762573, 16.913082667759486, 28.559312684195383, 31.575105326516287, 14.541399325643267, 1.4052806560482298, 0.05986424735082047, 0.021578187122941017, 0.02885632336671863, 0.02212872159933405, 0.030114120338112116, 0.04643069247582129, 0.07095594038920743, 0.10234359971114568, 0.0371131412019687, 0.07090610877743789, 0.036178537245307646, 0.032475106684224944, 0.02885719867689269, 0.01971462631731161, 0.057806976671729765, 0.026381796059597815, 0.09187188411929778, 0.05110933392175606, 0.041395674260067086, 0.044021187483200004, 0.03303089811067496, 0.09035096144569771, 0.05128694046288729, 0.03340351900884083, 0.026509637146123817, 0.037670876631247144, 0.08814662508666515, 0.0677250891125628, 0.03591521137527057, 0.08760197181254625, 0.07049708108284644, 0.039285253932965655, 0.05245950665058834, 0.013341709223043705, 0.03271443955600262, 0.023856183547260504, 0.03630108745502574, 0.01980852029685463, 0.020231300199936544, 0.1394946269158806, 0.102458299270698, 0.15653887018561363, 0.12372651802642004, 0.17242732404598168, 0.11774243627275739, 0.09663938651127474, 0.09206897818616458, 0.14504082288060868, 0.10874278883316688, 0.19216723766710075, 0.10292672592082194, 0.09200961994273321, 0.25352988711425234, 0.20894788365278924, 0.15416213843439305, 0.15515798356916222, 0.1498003796275173, 0.14958493118839605, 0.16378979038979324, 0.16821934841573238, 0.1323499788663217, 0.12886089751763002, 0.14193131402134895, 0.12025387079588004, 0.0867090807961566, 0.11491033967052187, 0.13383199434195245, 0.14420702547899314, 0.1666305043867656, 0.16853237019053527, 0.0915005219035915, 0.15010202915540763, 0.1265696340373584, 0.1274043813880001, 0.14114920741745404, 0.10689291238252606, 0.12488316238990851, 0.12989628767328604, 0.21161715899194988, 0.09205766022205353, 0.09005385131708213, 0.09966823112751756, 0.10852472124887363, 0.11365163685487849, 0.13073555406715187, 0.17397441102990083, 0.14524005433278425, 8.471466932977949, 38.74888065883091, 49.73948907852173, 44.20910515104021, 31.881149155753, 26.790268318993704, 36.89314535685948, 43.74295745577131, 36.19698102133614, 17.124372175761632, 3.895794587475913, 0.6366645225456783, 1.3949745233569826, 1.7844839138644082, 9.52236112526485, 10.8778669493539, 8.543985281671796, 6.742468076092856, 6.808379122189113, 3.9589954018592834, 2.6841653287410736, 0.37145889337573734, 0.18911761630858692, 1.0159236916473933, 2.0754679569176266, 3.454867116042546, 5.391938030719757, 5.922698327473231, 4.615267089435032, 6.507294569696699, 8.234554205621992, 14.188323140144348, 26.882227727345057, 41.594393798283164, 56.78252363204956, 62.74713175637381, 58.21238994598389, 64.27034364427838, 58.60580389840262, 57.032349586486816, 51.17333671024868, 39.37388849258423, 33.192013672419954, 34.74231311253139, 41.75528975895473, 58.614120892116, 62.245847020830425, 61.46312550136021, 57.18766614368984, 54.16595016207014, 56.54859515598842, 54.077930382319856, 49.52260800770351, 37.307066917419434, 23.80486536026001, 12.48752919265202, 3.456651283161981, 0.9079950973391533, 0.4155450777283737, 0.6693445603762354, 0.5079190709761211, 1.2236468195915222, 1.1147569311516625, 2.0321478928838457, 2.8334988355636597, 3.442700820309775, 5.030238262244633, 8.127895014626638, 4.740294711930411, 7.516751442636762, 11.3400958606175, 9.946932537215096, 10.586455157824926, 11.386430791446141, 11.049680267061506, 11.249559095927648, 3.942647159099579, 1.0554814147097724, 0.740073313670499, 5.117684815611158, 24.778942005974905, 39.506595611572266, 30.2963136945452, 22.73179599217006, 29.591137545449392, 37.93206780297415, 38.20851925441197, 14.234681521143232, 1.0437512270041873, 0.1773235106042453, 0.08581259354416813, 0.1129099370113441, 0.11255604028701782, 0.12528466513114317, 0.120310922020248, 0.12511362002364226, 0.19270189612039498, 0.11414283514022827, 0.11168726440519094, 0.12503976827221258, 0.15713762305676937, 0.218523342694555, 0.11111515081886734, 0.10326177972768034, 0.10625491304589169, 0.20511112096054213, 0.14204378798604012, 0.20950774289667606, 0.11529930308461189, 0.11710166851324694, 0.13608364494783537, 0.17377957648464612, 0.11452965438365936, 0.10291698215795414, 0.15033578446933202, 0.21854326448270253, 0.2210277747362852, 0.11222051829099655, 0.20377706683107785, 0.12189270928502083, 0.10816631226667336, 0.1565054048384939, 0.13853382132947445, 0.08591905568859406, 0.09632881424788918, 0.13284308383507387, 0.1339287670063121, 0.07753902607198272], [0.07742872341935124, 0.02854208362155727, 0.015758081838222485, 0.06017962364213807, 0.015536390876929675, 0.010422430200768369, 0.06208284651594503, 0.08301145170948335, 0.0629784313163587, 0.06214827764779329, 0.005299077751780195, 0.044930655110095225, 0.0345657884276339, 0.02552761716235961, 0.02015918380181704, 0.007851169245051486, 0.07072040731353418, 0.057595300887312205, 0.08310546952166728, 0.038688048121652434, 0.08145478381110088, 0.027500537456944585, 0.022470119708616818, 0.008054729750646012, 0.019216954807883928, 0.05924215287502323, 0.056556300925357, 0.04701048029320581, 0.10861094947904348, 0.03293145541101694, 0.04287867700414998, 0.047249874233135154, 0.059056085002209456, 0.00214604235536951, 0.11327830010226794, 0.028953967948577235, 0.0674386794811913, 0.037837168600942404, 0.05312584160960146, 0.04515831717955215, 0.03899652710450547, 0.0819782939340387, 0.034472293087414334, 0.05372974795422383, 0.02245259314908513, 0.011915651682232107, 0.05261669607300844, 0.0386724011041224, 0.08971904178283044, 2.7159218532698493, 20.09212497302464, 37.97412177494594, 36.37559141431536, 29.26385654721941, 19.07654673712594, 25.252376624516078, 29.19108806337629, 28.807465859821864, 20.483532633100236, 8.105118819645472, 1.4394901118108203, 1.0412465099777495, 0.6469021503414426, 2.66432301061494, 5.156518297536032, 5.250953870160239, 6.317482812064035, 5.566475476537432, 2.191443596567426, 1.5683287126677377, 0.3186241127550602, 0.32472650387457436, 0.10066492443106004, 0.07625058306647198, 0.24717223112072262, 0.1553517731704882, 0.056658858100750616, 0.20704580071781362, 0.01564837460006986, 0.2635524735919067, 1.1368018282311303, 5.480758590357644, 16.989886317934307, 26.71885473387582, 36.61884784698486, 39.089189529418945, 40.29822472163609, 27.17624248777117, 21.238866090774536, 32.167109216962544, 32.50277321679251, 27.468587943485804, 37.96908433096749, 45.91935907091413, 33.58977024895804, 37.17362328938076, 36.71860313415527, 34.63763502665928, 30.65746021270752, 25.02025989123753, 18.89486002922058, 13.795293944222585, 3.9934219888278415, 0.7657494044729641, 0.08636882941105536, 0.03357733253921781, 0.05658500974199601, 1.287046634725162, 0.7870960618768419, 1.6341925327266966, 1.9196836990969521, 4.4681520121438165, 3.7247264640671864, 5.265417414052146, 4.510315418243408, 4.815938012940543, 12.361463682992117, 3.638177748237337, 5.122350096702576, 4.043106819902148, 1.8073852849858147, 1.9980743612561906, 1.08147451707295, 0.05615207725869758, 0.8020697012543678, 1.6812101240668977, 13.026295116969518, 28.879720176969254, 24.60918709209987, 16.817350387573242, 19.93005129269191, 28.19321036338806, 33.35932976858956, 29.525008065359934, 6.7417111567088535, 0.13887227459677629, 0.0018909146726530577, 0.06735766239996467, 0.026911926987980093, 0.03597832531003015, 0.07597947439977101, 0.06773677348558392, 0.037000721520079036, 0.0338593825830945, 0.020987653007198657, 0.04948231211996504, 0.07909479830414057, 0.00811356382577547, 0.04055353087772216, 0.018301582229988914, 0.0035597965719976594, 0.029115991933005195, 0.02022124600729772, 0.06966801307031087, 0.03310659547735538, 0.018948629831096957, 0.03562474410448756, 0.013590987721857215, 0.025126265395166617, 0.03424295503646135, 0.075241391147886, 0.009421306063554116, 0.019913306459784508, 0.06263563542493752, 0.0661703957510846, 0.1327166591903993, 0.00549609590754179, 0.027359658320035254, 0.06660516706428357, 0.016846168719764267, 0.07556208036839962, 0.09462121980530874, 0.023086044604757, 0.011905808683617838, 0.021739100006275942, 0.0026937437360174954, 0.029072060183222805, 0.019170235975512435, 0.007936752018784838, 0.07719401815640074, 0.02235430565529636, 0.04413683020642825, 0.09587579034268856, 0.07126824291689055, 0.03917323458673699, 0.007438611472025514, 0.06835476960986853, 0.07960308210125991, 0.033488461415150335, 0.03967708755018456, 0.0430792790970632, 0.03589207333113466, 0.012398766071003462, 0.06615945776658398, 0.03690418295030083, 0.02575047011487186, 0.05643031393576946, 0.016955185548535416, 0.07012637026075806, 0.09747751975165946, 0.045403733117772, 0.038887866506619115, 0.025381306352626, 0.041548663550721746, 0.03053154829623444, 0.03123219677114061, 0.054404947973255596, 0.04494579661903637, 0.042340086440422704, 0.03643373765849641, 0.03587084197040115, 0.01911962404847145, 0.03423249202647379, 0.019062294624745846, 0.022248108139527694, 0.05772656348666974, 0.048445008495556455, 0.033128118608146906, 0.013127312513201364, 0.04781077502827559, 0.005975213300968919, 0.030593009998223612, 0.04869374925536769, 0.02374583000450262, 0.11042807982968432, 6.754463272435324, 29.722840649741038, 43.91140610831124, 34.97002295085362, 24.742547341755458, 18.369885410581315, 31.663986682891846, 39.84373262950352, 39.522639002118794, 25.309848649161204, 8.18871259689331, 1.1368520941053117, 0.2355044414954526, 0.23751108667680196, 0.4997788763472012, 1.3400519447667258, 2.1291475679193224, 3.618828969342368, 4.467570100511823, 3.9034940600395203, 2.709685627903257, 1.5928669273853302, 0.8225139613662447, 0.680057976927076, 0.3154607282153198, 0.9374373831919262, 1.1624532746417182, 0.7621458949787276, 1.1473487594297953, 0.5282964003937585, 1.3137947022914886, 1.680066711136273, 8.927454624857221, 23.6194109916687, 36.026645932878765, 45.911486761910574, 46.746222496032715, 44.19499683380127, 36.77621759687151, 29.19163349696568, 37.88826635905674, 36.07851423536028, 30.67748144694737, 43.50513104030064, 54.16737454278128, 42.358667850494385, 42.04689870561872, 41.40580926622663, 37.82893916538784, 36.4365097454616, 29.390067100524902, 23.98867126873561, 16.726655551365443, 6.406761518546513, 2.08904430270195, 0.29787424047078404, 0.5719758708562169, 1.4638383367231913, 2.880443036556244, 3.107976998601641, 3.791033557483128, 4.327530894960676, 5.125105057443891, 5.4269426209586005, 5.637015325682504, 6.191095948219299, 6.309119786534991, 8.186251197542463, 6.0268049240112305, 4.960249057837895, 3.478772827557155, 1.8868623631341117, 0.760106272995472, 0.39699707872101236, 0.1824364076767649, 0.25561822791184696, 2.008723561252866, 8.344516396522522, 29.10901246752058, 41.17857885360718, 24.371801887239727, 13.748307619776044, 20.514637981142315, 33.66575574874878, 33.53817640032087, 12.524601306234088, 0.425582401986633, 0.03412335306139929, 0.05031591274642518, 0.0750407347721713, 0.031721305168632946, 0.02996976879824485, 0.031535800479884656, 0.0419886154787881, 0.014868125485788499, 0.050944473660950146, 0.031899681847010336, 0.02904080007491367, 0.024590448343328068, 0.03657632839999028, 0.04000398197344371, 0.023703918592738252, 0.021464462957477996, 0.10816454807562487, 0.04260543773749045, 0.0049765823558638135, 0.02399043000436255, 0.05432254668059094, 0.0230217618934278, 0.020085138667907034, 0.03237198632476585, 0.04707005227516804, 0.0465203473078353, 0.033760832156986, 0.07932782758559499, 0.04540417416553412, 0.0533750810926514, 0.053507242750908644, 0.06740139398191657, 0.07085315590458256, 0.038743124809116125, 0.12724759908659117, 0.009372225081148957, 0.02436223835684359, 0.02775843335049493, 0.029836300960076705, 0.04915032529139093, 0.21152562461793423, 0.16158928775361606, 0.09973772668412753, 0.13199647569230624, 0.07484574416386229, 0.10346756582813603, 0.27265521085688044, 0.19868149954293454, 0.15008752207670892, 0.15288654688213552, 0.17377919650503568, 0.18690148022558006, 0.1315142951373543, 0.13222193930830273, 0.1284330811883722, 0.08940354335520949, 0.11757847507085119, 0.1806776449084282, 0.09945576824247837, 0.2358786128461361, 0.23070163492645535, 0.09300457619662796, 0.1464722603559494, 0.26443174641047207, 0.07498946466616221, 0.17135583582733357, 0.10041753056326083, 0.19935632976038115, 0.1405654637409108, 0.1798192166856357, 0.14638342655130795, 0.08512187203658478, 0.1568106777433838, 0.06790886353701353, 0.17498308047652245, 0.14696501248649188, 0.18355828390589782, 0.16317236423492432, 0.13958905184907572, 0.10859658489269869, 0.09055602829903364, 0.11502824191536222, 0.06416189816913434, 0.1526033127946513, 0.07181567139923573, 0.13568202007029737, 0.1255715090249266, 0.18465399582471165, 0.16591794762228215, 5.526553298745837, 28.828979219709122, 52.882273946489605, 48.74912411825997, 40.70296771185738, 29.848283427102224, 33.72878285816738, 38.01498760495867, 37.240412848336355, 26.74268010684422, 10.616552148546491, 2.1540965948786055, 1.760858193039894, 2.330991868461881, 6.146920604365213, 12.493618420192174, 15.854866811207362, 13.787914957318987, 11.923520462853567, 7.715938925743103, 4.002396021570478, 1.1964767575263977, 1.0049231733594621, 0.21443934898291314, 0.2291746325790882, 0.6611404748899596, 0.6017118266650608, 0.4248889120561736, 0.6521341981632369, 0.27216726275427, 0.7416034915617534, 1.698797534619059, 6.4063398497445245, 19.17579827989851, 31.880377905709402, 41.68145472662789, 45.432220867701936, 49.663646016802105, 35.59277956826346, 27.63448487009321, 45.018389633723665, 41.557033334459575, 35.69967760358538, 51.17227710996355, 53.82896947860718, 39.12072045462472, 39.90743024008614, 39.573531082698274, 35.771886757441926, 32.659788608551025, 27.428027834211075, 20.590458461216517, 15.545682396207537, 4.791377867971148, 1.280105927160808, 0.2347481463636671, 0.2836523364697184, 1.079990642411368, 3.3224546441010068, 3.055399545601436, 5.152717632906778, 6.650223791599274, 8.583683814321246, 9.23743634564536, 8.347581420625959, 10.004892672811236, 9.790987168039594, 27.291671173913137, 12.06871349470956, 12.94468765599387, 7.722822853497096, 6.497074203831809, 6.134534571852003, 2.612146816083363, 0.5539889931678772, 1.1731843331030436, 2.616076022386551, 16.09187855039324, 35.86181034360613, 33.249152183532715, 23.026832137789043, 26.685400894709996, 37.04703058515276, 42.87075008664812, 39.99955987930298, 11.538916826248169, 0.44223340707165854, 0.14539773230041775, 0.17802222525434835, 0.16477677385721887, 0.1354600034121956, 0.1709879341402224, 0.19804111176303454, 0.15025925928992884, 0.10030750610998698, 0.18457202879445894, 0.13061687829239027, 0.1233393188033785, 0.10540407084460769, 0.14485650562814303, 0.10943578343306269, 0.09392120236796991, 0.11036599387547799, 0.22009031075452054, 0.16756423642592772, 0.11873651721647807, 0.11825686081179551, 0.125783361228449, 0.13726444515798772, 0.10428959743252822, 0.13413439025836332, 0.20012927614152431, 0.18077861091920308, 0.09590595800961767, 0.21162304867591175, 0.12390411778220109, 0.18594683573714324, 0.14105922010328087, 0.13590764653469833, 0.1254253118698086, 0.14872745291462966, 0.19075849040278367, 0.20629090336816652, 0.08535345603844949, 0.08186961298010179, 0.0894506269001535, 0.0943061759961503], [0.029918030503072908, 0.04371835730437722, 0.01462734054907092, 0.044468949349331, 0.03522556534569178, 0.0379892893667732, 0.07033557617770773, 0.021118208233799254, 0.023114884039387107, 0.07282662750887019, 0.022337167557062845, 0.028463855319257294, 0.03346787127000945, 0.04806545975485018, 0.04990061538826142, 0.03344447198989136, 0.037761983528201065, 0.006959859639339681, 0.1260967222707612, 0.04681681961353336, 0.01850200620745974, 0.04060990695974656, 0.0059433174901641905, 0.01528494106605649, 0.024867234651797583, 0.05660913844725915, 0.016392881882243922, 0.04818547563627362, 0.04248409532010555, 0.04739005617531283, 0.009650569475655044, 0.039854032519672594, 0.031090871497456516, 0.014492707327008247, 0.012346266120273088, 0.04910555215818541, 0.04606374752308641, 0.027844994062823907, 0.053224073124251196, 0.0052406342583708465, 0.051859199934239895, 0.04329205071553588, 0.033716323652437756, 0.05914820970169135, 0.05484046567497509, 0.059108854670609744, 0.03354501730895468, 0.000983798805724031, 0.061147757406745634, 0.04731757167194571, 0.790225411100047, 12.954972726958138, 33.35477522441319, 40.771365778786794, 32.0684552192688, 29.636537075042725, 28.7408013684409, 15.111517259052821, 18.288714817592076, 26.049064023154124, 18.32308234487261, 6.4385981644902905, 1.0341337259326662, 0.31176879203745295, 0.7832628818494933, 1.4427687930209296, 4.026079824992588, 4.57955812556403, 4.554364391735621, 2.3682022946221486, 1.5626699477434158, 0.6579100510903767, 1.2471983901091983, 0.443133605910199, 0.9268001254115785, 1.2588334743465697, 0.6488214273537908, 1.6297550222703387, 0.2612364978662559, 0.3405226634017059, 0.16416725942066737, 0.042466066644660065, 1.0655598853315627, 2.7028294929436276, 4.308469814913614, 7.7938099929264615, 8.925409248897008, 1.159675189426967, 1.2058837498937334, 6.720412756715502, 14.776167665209089, 11.340782863753182, 8.648015448025294, 3.433644494840077, 4.287701649325235, 7.8341990028108865, 9.256813134465899, 8.8183114528656, 9.516775642122541, 5.178842859608786, 3.4941294320992062, 1.9119898719447, 0.6233540539230619, 0.31430971569248606, 0.4586440750530788, 1.3280113680022103, 1.6033303716353007, 1.9742099046707153, 3.973270910126822, 1.964406430721283, 3.3062041103839874, 5.901262700557709, 3.2444489555699483, 6.953854424612863, 4.973558332238879, 3.812215575150081, 4.980139144829341, 6.875635947499957, 4.858597780976977, 2.318722652537482, 1.62320200247424, 0.2169238185243947, 0.4126017013830798, 1.836889616080693, 8.157129560198102, 26.20713206699916, 40.531465326036724, 14.967988320759364, 16.671514647347585, 20.970356430326188, 29.497069358825684, 33.64961855752127, 24.845681190490723, 4.633241644927433, 0.029166983839656626, 0.06562120986304112, 0.03456432618466871, 0.09314555541745254, 0.022355737364185706, 0.024145544805963124, 0.03976327506825328, 0.06454991163419825, 0.09888235865426914, 0.09579996405435459, 0.07020901582602944, 0.033591262863150666, 0.011388448632455297, 0.04839989609484162, 0.037288033603025336, 0.04704732135204332, 0.052224017679691315, 0.054257587130580626, 0.02457038067015154, 0.044836169108748436, 0.03558750610266413, 0.018906906712800264, 0.04869087565956371, 0.08720914074884993, 0.048425493828420124, 0.01955311801949782, 0.022970169483284866, 0.020853755995631218, 0.03999049608994808, 0.004129137070516923, 0.0137965897696891, 0.03710009636623519, 0.00870827941357025, 0.0334910364555461, 0.02624018580120589, 0.05378783055182014, 0.004593618039507419, 0.02429857141604381, 0.055613629187324216, 0.09545023353504282, 0.00946842523158661, 0.04045994393527508, 0.020854534614565115, 0.06788531158651624, 0.018966638150491884, 0.011120059194841554, 0.02643278118089906, 0.05117836468187826, 0.06254546490630933, 0.005288563851666237, 0.02076288149692118, 0.058600258747381825, 0.07600027828344277, 0.015977219811507633, 0.009353037807159126, 0.01161206663320107, 0.07969901338219643, 0.05116847503398146, 0.016150549885683825, 0.020304185038964664, 0.0489211127694164, 0.029267515588019575, 0.023982996653233255, 0.04260828758456877, 0.018856101403278962, 0.044958532721336396, 0.033952263849122186, 0.038189229888043234, 0.022493556308160936, 0.03474812096517001, 0.017751485408682908, 0.03125611513054796, 0.024843886261805892, 0.0611849275550672, 0.017495996618111218, 0.0197193998111678, 0.03378442821225949, 0.04570852765547378, 0.029628689600420848, 0.016492207534611225, 0.031046237463929822, 0.026479783301640834, 0.036878425760992935, 0.01566522940993309, 0.023982248568375195, 0.023269013268873096, 0.03530589710654957, 0.028657689025359492, 0.05056427352662597, 0.023630034610895172, 0.06445740016975574, 0.14013555752379553, 2.644011689083917, 21.909591334206716, 42.36773524965559, 42.28059789112636, 31.097138745444163, 25.467004741941178, 26.40390678814479, 22.63491552216666, 32.53531163079398, 32.54376758847918, 20.94893687111991, 5.661558100155421, 0.750717682497842, 0.10033312080694096, 0.5705183776361602, 0.4128044476466519, 1.1543465725013187, 2.0977918675967624, 2.1577224688870564, 1.3537332734891345, 2.6918261519500186, 1.359802199261529, 4.365664780139923, 3.3558817761284963, 1.7675093561410904, 2.511979413884027, 1.6965897445167815, 3.5117405099528174, 2.458391649382455, 1.8004134190934045, 0.7504497425896781, 0.19952734772648129, 2.8299133479595184, 5.711123074804034, 8.276375412940979, 13.76831408909389, 15.334139278956822, 3.0691376541342055, 2.839067599603108, 12.48012067590441, 22.46057653427124, 17.928747756140574, 15.946770633969988, 7.463547348976135, 6.933041095733643, 11.821923034531729, 13.421312366213117, 12.260793839182172, 12.031877619879586, 7.939460737364633, 5.1196407335145135, 3.205976128578186, 1.4010370437588011, 1.5378525022949492, 1.8134294578007288, 3.5109464611325945, 3.5951914148671285, 4.669978942189898, 4.820452170712607, 5.058535669531141, 7.537692444665091, 5.4323847975049695, 4.825938207762582, 5.469758289200919, 6.421763547829219, 4.79998060635158, 4.163914714540754, 1.978721022605896, 0.24645056841628893, 0.5994656586221286, 0.21262033230492047, 0.1321056384061064, 0.11803648620843887, 1.0671485258000237, 7.923978413854327, 21.091088329042705, 44.43909052440098, 32.04922955376761, 14.335779547691345, 12.53082081249782, 24.338700669152395, 35.762197494506836, 32.875693457467214, 9.376628739493233, 0.13179349872682775, 0.06362256460956164, 0.032502030953764915, 0.06039594739143338, 0.03741420379706791, 0.041629144589283636, 0.016987772192806005, 0.05671706622732537, 0.03269829720790897, 0.04948733327910304, 0.04610338753887585, 0.006979573626137737, 0.05621756606602243, 0.06335498432495765, 0.0260182336039309, 0.017443481400342922, 0.009985043983241277, 0.04219986039346882, 0.01251327055173793, 0.03971113304474524, 0.04790052146251712, 0.02532419066743127, 0.01148339094860213, 0.04857371641056878, 0.025932690694129894, 0.023657294755269374, 0.04039520151647074, 0.0629230560734868, 0.041393743827939034, 0.0727462957480124, 0.04885047048862491, 0.029766394889780452, 0.0402165975288621, 0.06105588376522064, 0.02142571351890053, 0.0542424422289644, 0.06410249921360187, 0.008830046763510575, 0.04939832644803183, 0.1384094458605562, 0.03208395838737488, 0.0452452917982425, 0.09150639123150281, 0.11389894251312528, 0.22006926259824208, 0.1750298993928092, 0.11144125474882977, 0.16142437660268374, 0.15714295634201594, 0.11757975071668625, 0.2189056428947619, 0.12934819422662258, 0.17949569118874414, 0.134402940848044, 0.16117173087384018, 0.08848072215914726, 0.16917593351432256, 0.12970547005534172, 0.10130284234349217, 0.14103904047182628, 0.2047765896256481, 0.09829482875232186, 0.11939209061009542, 0.16004161722958088, 0.1282730419188738, 0.11646983027458191, 0.091754694336227, 0.1297346063490425, 0.057094745604055266, 0.1250855286738702, 0.058903204277157784, 0.12422195715563637, 0.11733456887304783, 0.10547748833362545, 0.07282957235085112, 0.06273718497582845, 0.058824785985052586, 0.16297094789998873, 0.1408887313944953, 0.16029840202203818, 0.1134025805762836, 0.18626458011567593, 0.14129047840833664, 0.17981127782591752, 0.14212228091699736, 0.16084052436053753, 0.108911805120962, 0.15320999095482485, 0.1255334432103804, 0.10844202818615095, 0.11200278997421265, 0.20852730050683022, 1.9969226973397392, 20.54048180580139, 49.478980268750874, 54.07672834396362, 43.89601584843227, 38.12279238019671, 37.48889085224697, 22.581060034888132, 25.332612684794835, 34.33160161972046, 22.69143216950553, 9.11684775352478, 1.2824513784476688, 0.6940345498067992, 1.768860780767032, 5.191372632980347, 10.730299370629446, 12.909080743789673, 9.554156950541906, 8.255520394870214, 6.710279243332999, 1.7242106795310974, 4.050548774855478, 2.1306551098823547, 1.899424923317773, 3.013429820537567, 1.81716921712671, 3.337566758905138, 1.0876282325812747, 0.5549834540912083, 0.5006824678608349, 0.7478653926934514, 3.1776520141533444, 5.918860750538962, 6.701508011136736, 12.350087744849068, 12.848887630871364, 1.9435292652675082, 2.5712121554783414, 10.43127235344478, 21.87753234590803, 16.574302400861466, 13.461846419743129, 5.166049054690769, 5.290673681667872, 9.932287471635, 10.599345803260803, 9.43181654385158, 10.838972670691353, 6.21573816878455, 4.903457522392273, 2.422974726983479, 1.1843686529568263, 0.9682880363294056, 1.6998669058084488, 4.060279726982117, 4.8956160460199625, 6.532787076064518, 7.452325139726911, 9.179978217397418, 10.537016119275775, 14.332788348197937, 10.747629914964948, 16.18753092629569, 12.930020877293178, 11.785000307219368, 15.499513353620257, 12.157127584729876, 9.842767749513898, 6.319570745740618, 3.58836698106357, 0.7721904931323869, 0.6940280901534217, 3.089465694768088, 10.943701131003243, 31.209473746163503, 48.781464508601594, 23.79635555403573, 22.953731877463206, 28.11097148486546, 36.783631324768066, 43.52095903669085, 35.226196084703716, 7.976817727088928, 0.22035921418241092, 0.11903286060052258, 0.10179824076060738, 0.17369049840739795, 0.15692735862519058, 0.10985110114727702, 0.10712262362773929, 0.15733955507831915, 0.1396097878792456, 0.16807480688605989, 0.11473937598722321, 0.17008975733603748, 0.1716176282082285, 0.14694190158375672, 0.09905123923506055, 0.10344602234129395, 0.12279991060495377, 0.15943941740053041, 0.08356559090316296, 0.11811196644391332, 0.10313794708677701, 0.14504610188305378, 0.11624461093119212, 0.11179420152412993, 0.10323163241680179, 0.10265989881008863, 0.14699853211641312, 0.14258657528885774, 0.09092335323137896, 0.26706600934267044, 0.13544012233614922, 0.1208055197660412, 0.15007294714450836, 0.12169239217681543, 0.09066261936511312, 0.1112865080524768, 0.1584145309669631, 0.1126044469752482, 0.1921298232461725, 0.2519942266600472, 0.12779311410018376, 0.13902722485363483], [0.03204009788376944, 0.037416269936199696, 0.01836746628396213, 0.02379949703546507, 0.08291176134454352, 0.02033140616757529, 0.017403317216251577, 0.015592980697484953, 0.016130022505032163, 0.03442766244656273, 0.0728180440408843, 0.006871110651575561, 0.029461966760988747, 0.033052180361534865, 0.013448692991265228, 0.010315271709779543, 0.07738395367882081, 0.04631957218849233, 0.03529598031725202, 0.037368209300828834, 0.03874716209247708, 0.02594518761283585, 0.04920198216236063, 0.009599763317964971, 0.03573645132460764, 0.06461024696805648, 0.021201661255742823, 0.060006766846137385, 0.05268854953880821, 0.05355845857411623, 0.07203171016382319, 0.06076345552823373, 0.06949928176722356, 0.027250239459265555, 0.10548452474176884, 0.05455463279836944, 0.036331302619406154, 0.055932778133345504, 0.03701438721535461, 0.011294062715023756, 0.0250760707671621, 0.07322738386158432, 0.030122205082859312, 0.03464396244713238, 0.038237534796020815, 0.016614155544500266, 0.02676824719778129, 0.015683475216584544, 0.026544593573947037, 0.016275444433891346, 0.03780146408826113, 0.36582824694258825, 7.890624455043247, 27.015316997255596, 39.2167341368539, 36.43904931204659, 34.44324180058071, 20.890924624034337, 22.993906361716135, 17.634123291288102, 27.04744894163949, 28.47483822277614, 17.79653569630214, 6.649472517626626, 1.9652871148926871, 0.0450241979477661, 0.45060139947703903, 1.2261621760470527, 2.382481928382601, 0.6385205058114869, 2.8676794128758565, 0.7366154449326652, 7.0200468727520535, 3.833464903490884, 2.014416741473334, 3.1330215632915497, 1.7829670352595193, 4.740534424781799, 7.260838431971414, 7.7929136753082275, 2.0615982668740407, 0.10933212363826376, 0.43990519057427135, 0.09651738591492176, 0.122287318110466, 0.6179762024964605, 0.6553353635328156, 0.06920852272638253, 0.15026502683758736, 0.13272719005388872, 0.7600086182355881, 0.2858387120068073, 0.06951566160257373, 0.024291911594835774, 0.2721128985285759, 0.4227714485355786, 0.6369079266275678, 1.1278225843395506, 0.9615732537848609, 0.38350801968148773, 0.21032921810235294, 0.3724317768854754, 0.3816441925508635, 2.5839940181800296, 2.445605226925441, 5.905933192798069, 2.698262572288513, 3.917007872036525, 4.444911156381879, 3.3564680303846086, 6.914032561438424, 2.5789320383753096, 3.168781118733542, 3.11138921550342, 6.201959456716265, 3.4567474722862244, 1.7065605180604118, 1.5481309507574355, 0.6483580150774547, 0.6093699357339314, 0.41081701857703073, 1.8262043723038264, 10.818174106734139, 23.0840870312282, 37.72796099526541, 44.69691732951573, 13.90404280594417, 12.388252462659564, 19.89350724220276, 34.34518882206508, 32.19593381881714, 19.507279464176722, 2.279171769108091, 0.0469024473402117, 0.065103982974376, 0.02177552376607699, 0.031715975276061466, 0.042521947396120856, 0.0168327472970954, 0.14135918686432497, 0.03754340025729366, 0.023842753642903905, 0.022663944933031286, 0.05184446893898504, 0.043277112767100334, 0.03566285063113485, 0.06933496094175748, 0.04333038115873933, 0.034494627067553144, 0.04961450431229813, 0.008464540305015231, 0.015065853982897741, 0.008360168048446732, 0.03716601604329688, 0.0627758139744401, 0.07036767088408981, 0.025514087174087763, 0.05646699893155268, 0.02310914872214198, 0.04866198363846966, 0.049410977733454535, 0.0355484631976911, 0.03865419940224715, 0.06591351596372468, 0.02899287175387144, 0.018431077245622873, 0.023912922645519887, 0.05113812755527241, 0.12366215219455105, 0.05893202844474997, 0.016539267330829586, 0.02544265948901219, 0.04360244995249169, 0.027110786942232932, 0.036324829395328245, 0.028875854997230426, 0.06614362075924873, 0.028322859135057245, 0.030733982433698008, 0.04213051411456295, 0.012333956646866031, 0.07495067960449628, 0.025830605100574236, 0.02018954315488892, 0.0707949036732316, 0.014844181681317943, 0.02091813030918794, 0.026937266878251518, 0.036648762013231, 0.02575357271624463, 0.014889528176614215, 0.018330509874171445, 0.08984672171728951, 0.04689451187316861, 0.009479302996104317, 0.007082052770004208, 0.10538271056222064, 0.03742137930489012, 0.07766106738043682, 0.04390384502975004, 0.008770562142931988, 0.045961336232721806, 0.043950904825968404, 0.01567760928134833, 0.02744283144628363, 0.009509572443286223, 0.023800085664593747, 0.046519926616123745, 0.011206750525161624, 0.023059525759890676, 0.046496130393019745, 0.05004629007141505, 0.07223867012986115, 0.08493949539427247, 0.04687771473878196, 0.005910470458080194, 0.06265155385647501, 0.0348250363022089, 0.01964877449375178, 0.0525145528039762, 0.06936476219977651, 0.041253962221422365, 0.06359899908836399, 0.02892329477305923, 0.08644378717456545, 0.10793975620929684, 0.03054016229829618, 1.2780805272715432, 15.260436262403216, 38.115031242370605, 46.94037600925991, 38.730773653302876, 33.627009119306294, 13.159440840993609, 14.510359985487801, 25.899523156029836, 37.09458405630929, 35.76604332242693, 17.777273552758352, 5.719912111759186, 0.6436614128095763, 0.153233210423163, 0.209331160943423, 0.21516175807586738, 0.7425959983042308, 0.6675422628011022, 0.7098113032323974, 0.9580948118652616, 2.7482305424554005, 3.190452767269952, 4.839247482163565, 3.2126585585730414, 5.604052637304578, 6.830278975622995, 8.691584127289907, 13.67401487486703, 4.7083112852913995, 0.7562149560877255, 1.1509097112076623, 0.690565715943064, 1.2008023368460792, 2.1360536430563246, 3.1240796659673964, 0.14948293380439281, 0.2631791707660471, 0.29349435120821, 2.1557448378631046, 1.2117474866764886, 0.2865681100104536, 0.14610621785478933, 0.24886286897318705, 0.6336627379059792, 1.7583896283592497, 1.422513165644237, 1.6285004381622588, 1.061849330152784, 0.8441327384540013, 0.9941132962703705, 1.9874134361743927, 3.853592097759247, 4.611443408897944, 4.885927651609693, 5.855409366743905, 6.074734032154083, 5.850084006786346, 5.269715309143066, 7.253791221550532, 4.817123549325125, 3.1074463299342563, 2.083430592502866, 3.3128014249461035, 0.8951024977224213, 0.6409817423139299, 0.7661637993795531, 0.09736781420984439, 0.18419274128973484, 0.20471785563443387, 1.2856465727090836, 7.5810934986386975, 23.83189558982849, 38.40598358426775, 51.40588249479021, 27.366760356085642, 8.63020634651184, 14.877988304410662, 31.03595290865217, 37.98938001905169, 27.91763264792306, 5.208013568605695, 0.05655101174488664, 0.02696173994003662, 0.07347160218549625, 0.08581078864101853, 0.04084926358024989, 0.03109899695430483, 0.039006508354629786, 0.05001034467880215, 0.009356826577069504, 0.06569287673171077, 0.03152458090335131, 0.018911072917814766, 0.05330994512353625, 0.04965786269998976, 0.014512106643191405, 0.044597531735364876, 0.026121749210038354, 0.060172743297048976, 0.01809600308271391, 0.1342743584620101, 0.043259698165846724, 0.036394134962133, 0.044160782492586544, 0.06436155031302146, 0.011469843148786043, 0.034790831351918836, 0.06300953536161355, 0.04058169686634626, 0.07607740057366234, 0.06223000719078949, 0.032471551160727224, 0.029729238312159265, 0.027536252147651145, 0.07713277358561754, 0.059135385389838896, 0.05089545289852789, 0.03710987066317882, 0.023289019873897945, 0.02927172589781029, 0.035431561792003255, 0.04317596694454551, 0.044529067551983256, 0.012906616453879645, 0.11899982951581478, 0.1189420319029263, 0.10866923563714538, 0.18623399175703526, 0.14762791405831063, 0.1965390523629529, 0.19638795618500027, 0.1647494967494692, 0.16099349329514162, 0.11816082096525601, 0.1889911238104105, 0.13156021838741644, 0.17994212651891367, 0.09101530829710619, 0.1386747123407466, 0.08621416413890463, 0.19343943654426507, 0.09984479272472006, 0.11557423190346786, 0.09273558455918517, 0.2154360626425062, 0.118934052331107, 0.10855397967887775, 0.21354452414172037, 0.06993429735302925, 0.20108210215611116, 0.10952467152050563, 0.11117719606097255, 0.16905538498290948, 0.18109965297792638, 0.2061053511819669, 0.13970346642392023, 0.11782828452331678, 0.08261951631201164, 0.26643315330147743, 0.1520197591079133, 0.14975075157625334, 0.21199381378080162, 0.13946538205657685, 0.14460719829159124, 0.08300486313445227, 0.19098037135388168, 0.1022942837859903, 0.22328057885169983, 0.13785452635160514, 0.09407834429293871, 0.24560576517667088, 0.06997480589364256, 0.1272378960358245, 0.22982040792703629, 0.17733406860913548, 1.0628765778882163, 13.788155538695198, 41.07542242322649, 55.422177519117085, 49.45223665237427, 45.78553329195295, 28.361834457942418, 30.40410109928676, 27.10413408279419, 36.74523210525513, 36.577096121651785, 23.981212377548218, 8.54303685256413, 2.545903559241976, 0.18580126283424242, 0.6727188878825733, 2.6285829969814847, 5.768715390137263, 4.803831211158207, 9.251095635550362, 5.409723247800555, 11.65478411742619, 9.964167543819972, 9.262061629976545, 8.752883740833827, 7.790177822113037, 10.199152146066938, 11.948983005114965, 12.111537848200117, 3.843651831150055, 0.2342867696923869, 1.1893839495522636, 1.1978662886789866, 0.7339359372854233, 2.657885721751622, 5.357775041035243, 0.20234873704612255, 0.29308201904807774, 0.47563361482960836, 1.5025126614740916, 0.8108478273664201, 0.382409362920693, 0.27422629083905903, 0.4099534606294972, 0.5359027779528073, 1.3956105006592614, 1.893339821270534, 1.4207472375461032, 0.6453691497445107, 0.5988249587161201, 0.9447509050369263, 2.1221055686473846, 6.263734153338841, 8.458283594676427, 14.369092685835701, 10.093117424419948, 11.77933839389256, 11.71359714439937, 9.75167339188712, 16.9642231464386, 8.130859289850507, 11.021421074867249, 7.423700298581805, 15.461817639214651, 13.771436435835701, 5.714789986610413, 4.155726262501307, 1.7010367001805986, 1.237969119633947, 0.6596808103578431, 2.7228368307862962, 13.976156422070094, 28.110910688127788, 46.10692916597639, 53.655928066798616, 20.601813554763794, 19.013750655310496, 27.902410881859915, 42.67114571162632, 44.78238364628383, 30.055419649396622, 4.062485345772334, 0.15783686696418694, 0.1573146799845355, 0.18200507653611048, 0.12412747793963977, 0.19999607971736363, 0.14453106666249887, 0.26326746174267357, 0.1340946281062705, 0.09532421601137944, 0.1497598032334021, 0.1983084138482809, 0.09248337987810373, 0.18308656636093343, 0.09606594299631459, 0.06243717071733304, 0.09551584787134614, 0.1298294791153499, 0.17520170445953095, 0.08629754252199616, 0.25723848811217714, 0.08925972785800695, 0.1710975311164345, 0.17422115350408213, 0.12690618740660803, 0.15197340159543923, 0.09880926007671015, 0.1304882959063564, 0.1266586442611047, 0.18079557429466928, 0.15448175556957722, 0.21778663008340768, 0.13751439031745705, 0.15357819119734423, 0.22575134198580468, 0.19857746655387537, 0.2767671602112906, 0.17765261365899018, 0.11882183620972292, 0.08927952072450093, 0.14018631194319042, 0.12020184073065009, 0.1628258228302002, 0.12086810783616134], [0.039001439698040485, 0.03192192083224654, 0.021922747205410684, 0.04873869541500296, 0.056477950486753664, 0.01956187790658857, 0.03871474168928606, 0.0035938865954189426, 0.03644674178212881, 0.03483923464747412, 0.019200678449124098, 0.13617321157029696, 0.0023674247952710304, 0.06335023457982711, 0.03037957680810775, 0.013303081072600824, 0.022361742399100746, 0.01279492280445993, 0.03818345894770963, 0.05614531904991184, 0.031034098472446203, 0.07923332122819764, 0.03220552472131593, 0.04288767098582216, 0.03694913928796138, 0.04319280479103327, 0.057523484740938456, 0.03298327513039112, 0.017738445661962032, 0.031737372877874544, 0.016041980890024985, 0.005758431540536029, 0.03919430649174111, 0.05036075712580766, 0.045284351666591, 0.02986282150128058, 0.01848810981027782, 0.0661888179768409, 0.07897847704589367, 0.1372408185686384, 0.05095029888408525, 0.04826256739241736, 0.04065652231552771, 0.016918744825358902, 0.09610115896378245, 0.05087647766673139, 0.06517012656799384, 0.022704640070774725, 0.025118983018078973, 0.05844216687338693, 0.00936923104537917, 0.04423970290060554, 0.091566835130964, 2.3561393533434187, 17.82585883140564, 37.684941223689485, 37.158517905644004, 37.43455941336495, 30.074916294642858, 18.93738647869655, 20.06364951814924, 22.599933079310826, 31.295058182307653, 28.95899043764387, 21.751300948006765, 10.31177636555263, 5.147547738892691, 1.0278191162007195, 0.37784797911133083, 0.2872822545468807, 0.6213230086224419, 0.7012193128466606, 2.0115160856928145, 4.983746128422873, 3.491310634783336, 2.4739899209567477, 6.23647723879133, 4.327312895229884, 8.861331224441528, 17.614666598183767, 5.238167881965637, 1.1215241508824485, 0.14907461857157095, 0.2645760029554367, 0.5713157919900758, 0.5889372378587723, 2.7939266732760837, 0.49722036506448475, 0.23157100113374846, 0.3031567712979657, 0.045808363905442614, 0.1477924452296325, 0.04881850809657148, 0.3719595436538969, 0.1290586090513638, 0.1626273106251444, 0.14511357540530817, 0.6045231872371265, 0.03415076248347759, 0.4691492084945951, 0.9129547540630613, 0.9268549510410854, 2.334720228399549, 2.7635207048484256, 3.21525023664747, 2.895757734775543, 3.123279103210994, 4.850365468433925, 4.154412618705204, 3.144655019044876, 4.729295713560922, 3.7340730939592635, 1.3688524450574602, 1.3051584171397346, 1.9898563793727329, 0.19152993043618544, 0.30870504357985085, 0.35442085191607475, 0.6164283284119197, 3.110149613448552, 10.557517647743225, 23.984405074800762, 31.840085302080425, 28.817785671779088, 43.98617567334856, 11.985492314611163, 16.646744319370814, 35.314031737191335, 32.76345920562744, 31.973497663225444, 12.42305772645133, 0.18023544363677502, 0.037161113627787144, 0.05516548055623259, 0.008481809869408607, 0.02551099135806518, 0.0223347061712827, 0.049503370454268794, 0.02295188805354493, 0.009686852439439722, 0.028983762421246086, 0.10038758681288787, 0.016312093806586096, 0.02216773057755615, 0.034564916510134935, 0.008748871074723346, 0.024412801090095724, 0.0562987086762275, 0.023723669050793563, 0.025934960393767272, 0.020582740627495304, 0.06302650552242994, 0.029583655231233155, 0.059474442553307326, 0.06876736639865808, 0.014634731491761548, 0.06555982279990401, 0.01464250241406262, 0.03909181038449917, 0.030192402923213582, 0.10889136764620032, 0.03529529160420809, 0.06208395252802542, 0.004375355376396328, 0.03703511646017432, 0.0483379526329892, 0.03441108922873225, 0.004916301728891475, 0.03489419259130955, 0.01977004057594708, 0.0483868003689817, 0.014561356411182454, 0.012897811613843908, 0.07001099216618709, 0.03598570777103305, 0.03661253163591027, 0.03551798001197832, 0.017559817925627743, 0.06944035100085394, 0.032283169483499866, 0.040748463810554574, 0.022163752666009322, 0.037691761939121146, 0.0754704170727304, 0.06529454953436341, 0.041505807278943915, 0.06429604454232113, 0.033245169291538854, 0.08342009942446436, 0.055613384914717505, 0.012418390151911547, 0.051105456094124486, 0.027778283892465488, 0.00929015881514975, 0.05442551776234593, 0.04525668100853052, 0.051606723839151006, 0.004286109785815435, 0.06158468646130391, 0.035874183755367994, 0.011910747570384825, 0.01681211813619094, 0.02382102355893169, 0.022417975988771235, 0.02919573336839676, 0.024516169114836624, 0.04953834554180503, 0.07981640672577278, 0.041628822285149775, 0.02850092708000115, 0.008675739418582191, 0.09019253708954368, 0.0219822564228837, 0.02510333769688649, 0.005597505934669503, 0.03957034042105079, 0.021517353065844094, 0.05530458362773061, 0.006047765233753515, 0.06101921573281288, 0.05123642353074891, 0.041689585096069744, 0.030504640990069935, 0.04214761658970799, 0.034755391467894824, 0.044064179461981566, 0.02277718733863107, 0.062190502882003784, 0.32606001517602373, 6.544869993414197, 27.80798486300877, 44.23085996082851, 42.30772713252476, 33.02125474384853, 26.88638969830104, 15.91229714666094, 20.4423246043069, 34.254368918282644, 42.435681683676584, 38.69248560496739, 25.689496483121598, 7.154433284487043, 2.4954149084431783, 0.7303319392459733, 0.22528991103172302, 0.2566446614052568, 0.10378799720534257, 0.045613017066248825, 0.5511192785842078, 1.3875743661608015, 3.6556114298956732, 2.0073347900594984, 2.065632130418505, 3.8262804661478316, 4.606407267706735, 15.329312017985753, 12.341411181858607, 5.476298715387072, 1.4438426154000419, 1.3218626465116228, 1.4931474668639046, 1.8786945385592324, 4.828602407659803, 1.6928825548716953, 0.6694434093577522, 0.553148803966386, 0.021904138382524252, 0.534425254379, 0.2450217907982213, 0.8362648806401661, 0.8393158454980169, 0.7873952686786652, 1.4175352156162262, 1.1332118894372667, 1.1484564542770386, 0.9533005548374993, 2.0161440202168057, 3.686419742447989, 2.2096437513828278, 3.8925419620105197, 5.235477192061288, 3.2633528326238905, 6.214553935187204, 5.428658826010568, 4.241292459624154, 3.211486918585641, 1.683119467326573, 2.425754657813481, 1.051789858511516, 0.8889291318399566, 1.014563256076404, 0.42643884888717104, 0.12318886044834342, 0.23945943212934903, 0.469791048339435, 1.6330479255744388, 10.028533918516976, 25.076196363994054, 43.82077380589077, 43.42378500529698, 49.59831210545131, 22.846189396721975, 13.085365227290563, 26.64478693689619, 30.964744295392716, 38.972438948495046, 19.15088725090027, 1.3413577718394143, 0.02494724410852151, 0.048224742457802804, 0.06327399438513176, 0.04957753433180707, 0.020257021766155958, 0.09016213193535805, 0.04908443954108017, 0.053072576610637565, 0.05651580256276897, 0.07487923665238277, 0.022121242447091, 0.045649624030504904, 0.036850568505802324, 0.027698815567418933, 0.037198385556361506, 0.03984972042962909, 0.03646196810794728, 0.027944918522345166, 0.055636397429874966, 0.07272819921906505, 0.0505073274751859, 0.0406603424676827, 0.041508758906275034, 0.025131868398083106, 0.04661028373188206, 0.061067914191101275, 0.04043610700006996, 0.026493532117456198, 0.05353591085544654, 0.03349050380555647, 0.08725095207669906, 0.038100986408868005, 0.04089430473478777, 0.010873029191446091, 0.020683584501966834, 0.020707626694015095, 0.06597478767590863, 0.04617017913343651, 0.04459357587620616, 0.046987613663077354, 0.02802546402173383, 0.04506431293806859, 0.0681333839893341, 0.06634848405207906, 0.41387827002576416, 0.07848641023572002, 0.14737841673195362, 0.19164483355624334, 0.14812663729701722, 0.07112678193620273, 0.17663833951311453, 0.13622156397572585, 0.10085708554834127, 0.0998625974836094, 0.0678972334467939, 0.24082749443394796, 0.170945457848055, 0.17083458522600786, 0.16897799127868243, 0.07988685223140887, 0.09842303115874529, 0.09928432279931647, 0.11248658544250897, 0.09000437932887248, 0.1457538003368037, 0.13374964733208927, 0.1692642109202487, 0.2067433912307024, 0.17248043976724148, 0.1090342535504273, 0.2142592929303646, 0.10567367994891745, 0.0837135658200298, 0.1581843447472368, 0.09716346660362822, 0.12820182288331644, 0.10122719925961324, 0.13822337798774242, 0.09940142437283482, 0.1859507712402514, 0.15336049002196106, 0.12174001176442419, 0.07167981511780194, 0.1749450553740774, 0.2047620825469494, 0.18684772668140276, 0.1901225402419056, 0.10745017962264163, 0.16045365083430493, 0.1001435856201819, 0.15116757340729237, 0.17088286977793488, 0.11335678624787501, 0.15163342840969563, 0.0945890097479735, 0.18079064813043388, 0.2483463409755911, 4.964319833687373, 27.754066841942922, 51.21272604806082, 53.18550028119768, 48.99548986979893, 42.12902293886457, 26.946574994495936, 27.94349558012826, 32.592196532658164, 41.92762245450701, 38.323939255305696, 27.88147074835641, 14.451015421322413, 6.272765942982264, 1.6744125059672763, 0.872036378298487, 0.7276937950934682, 1.8319739827087946, 3.714761878762926, 7.3109701190676, 13.336051021303449, 12.419779913766043, 8.700373598507472, 16.051638058253697, 12.096815483910696, 19.39026485170637, 30.77763625553676, 14.114350880895342, 5.282798767089844, 1.8210736704724175, 1.100012093782425, 1.4245495306594032, 2.3845088481903076, 5.267181822231837, 1.8157473334244318, 0.5331985716308866, 0.48445223591157366, 0.0612766994163394, 0.6610517767923219, 0.2051159521298749, 1.7607542957578386, 0.6422083164964403, 0.5476097869021552, 1.3091601452657153, 1.3795466997793742, 0.9212416751044137, 1.3815900129931313, 2.4405280479363034, 3.5884479710033963, 7.16090509721211, 8.030037454196385, 10.617411119597298, 11.798482418060303, 12.594942263194493, 12.893940619059972, 13.42337337562016, 13.11976488998958, 12.367961985724312, 12.292531473296028, 5.478355382169996, 5.172962946551187, 4.860457292624882, 1.553009454693113, 1.0938735774585178, 0.7102820436869348, 0.9173833621399743, 4.2189344593456815, 14.966183526175362, 30.95763976233346, 40.57276889256069, 37.06619371686663, 49.99334498814174, 18.603480373110088, 25.624532563345774, 42.51533235822405, 42.4113004548209, 44.35928698948452, 19.28471997806004, 1.21267865385328, 0.12751614967627184, 0.19621839028384003, 0.19253750065607683, 0.14620750956237316, 0.16678626888564654, 0.12981977606458323, 0.15738748679203646, 0.14614420224513325, 0.1719767903642995, 0.21524240874818393, 0.11861774644681386, 0.10290973540395498, 0.1352396152381386, 0.10255123142685209, 0.09972202538379601, 0.13237159699201584, 0.15177714212664536, 0.05320151862023132, 0.14885146197463783, 0.12446388203118529, 0.10956697139356818, 0.18082500914377825, 0.2967234450791563, 0.07661576382815838, 0.15055496485105582, 0.1414763427206448, 0.1370227374136448, 0.0949169389371361, 0.2757962037410055, 0.06094320624002388, 0.22061135779534066, 0.08180764237684862, 0.09583421650209598, 0.09337758046707936, 0.08995045615094048, 0.08673756569623947, 0.12559482348816736, 0.09667129122785159, 0.19256263359316758, 0.1739580040531499, 0.06438172315912587, 0.20007382625980036, 0.15346702001988888, 0.10864390592489924], [0.02076647773252002, 0.039201441287462196, 0.03075835880424295, 0.011825877258421054, 0.037006614596715996, 0.008178264684309917, 0.008234982578349965, 0.04060559826237815, 0.027536084210234027, 0.019752938100802045, 0.04144400291677032, 0.030590536738080636, 0.03661618893966079, 0.006876495251032923, 0.05326856805809906, 0.03443174044202481, 0.04811949149838515, 0.058560768009296486, 0.012014738151005335, 0.04444348732275622, 0.011772205138445964, 0.06855461852891104, 0.041291529312729836, 0.08976528394435133, 0.013100191468505986, 0.011866924386205418, 0.0795204093945878, 0.031078657867120843, 0.12907437820519718, 0.03530423130307879, 0.003211622018300529, 0.00818108908632504, 0.0034119577862189283, 0.03996865404769778, 0.05608392859409962, 0.03904463184465255, 0.04011896651770387, 0.0495079844923956, 0.07411262778831379, 0.0179717056453228, 0.03157912494082536, 0.04596639131861074, 0.030050921586475203, 0.02652541478164494, 0.042822853928165774, 0.006699695318405117, 0.039162812288850546, 0.043334435405475755, 0.038454591363136253, 0.07741613659475531, 0.042549573949405124, 0.07044581776218754, 0.006949290184171072, 0.12447942048311234, 0.5588983297348022, 10.203601598739624, 27.552902596337454, 41.081693172454834, 38.69063738414219, 29.46595879963466, 20.112267800739833, 25.405950920922415, 15.077125413077217, 14.923518112727574, 22.79562909262521, 33.877251965659006, 25.109038761683873, 18.58511802128383, 10.035764387675695, 3.9134529999324252, 1.9569755494594574, 0.07743430776255471, 0.282283894185509, 0.48281045258045197, 2.2703089075429097, 0.6086029740316528, 1.8311818880694253, 3.8344224521092007, 3.536437447581972, 16.083535500935145, 13.94593002114977, 10.74406201498849, 1.727641026888575, 0.946569270321301, 2.188786562000002, 0.7813590211527688, 0.7291581822293145, 0.3000068488929953, 0.9126594556229455, 0.2346976362168789, 0.21721005173666136, 0.14376238148127282, 0.5997848957777023, 0.4550770978842463, 0.943349323102406, 0.9755226309810365, 1.7724382345165526, 0.6023723940764154, 0.9135366656950542, 1.0971711490835463, 1.775460375206811, 3.75663389478411, 1.9565273906503404, 3.1730523066861287, 4.522496044635773, 1.6635631109986986, 5.420502509389605, 3.0871671438217163, 3.3172089712960378, 2.536984460694449, 1.4673636789832796, 0.992031985095569, 0.7593091843383653, 0.17535514836864813, 0.40247318201831406, 0.8800669216683933, 3.3011275827884674, 7.073889332158225, 18.629510062081472, 25.511007683617727, 29.486897196088517, 27.155753987176077, 17.622370413371495, 32.15978928974697, 20.264853715896606, 20.45911840030125, 34.778982230595176, 35.465023040771484, 30.014734472547257, 4.773716415677752, 0.0394926176273397, 0.033946143463253975, 0.01882753847166896, 0.028605730206306492, 0.0073814813679616365, 0.03549858408847025, 0.08732550950454813, 0.02884274927367057, 0.04532022920570203, 0.05967256799340248, 0.03283313229413969, 0.020323346867891293, 0.022385665847520744, 0.12463092378207616, 0.01353824180218258, 0.05710165987589529, 0.028555369337222407, 0.052705611301852126, 0.0201299609949014, 0.07589130555944783, 0.041563163844070265, 0.1090170391170042, 0.041783725044557025, 0.02830467778923256, 0.09556221216917038, 0.03537069720083049, 0.047763477744800706, 0.06845163726913077, 0.09664190387619392, 0.04265627697376268, 0.061192717137081284, 0.0245864907878318, 0.08384361384170395, 0.09567743420068707, 0.07472432032227516, 0.05103390118373292, 0.07458291362438883, 0.026182299978764992, 0.044505247580153603, 0.03891165594437292, 0.07978788111358881, 0.032419918038483174, 0.029465742808367525, 0.03777568993557777, 0.03525181447288819, 0.045868997794709036, 0.016636168916842768, 0.024882544098155837, 0.04103176235886557, 0.04828022287360259, 0.03605038572901061, 0.027714679716154933, 0.05191545048728585, 0.07144246356827871, 0.05137498377423201, 0.0635629485228232, 0.03485329728573561, 0.019714548285784464, 0.05484064209407993, 0.06688262003340892, 0.05006548582709261, 0.01359438378962555, 0.04809419571288994, 0.044768512382039, 0.0032262173065516564, 0.009988251757541937, 0.023145662387833, 0.10266605312270777, 0.017745622866121784, 0.029351545364728997, 0.044143839473170896, 0.05664808975000467, 0.03624722873792052, 0.050827327982655594, 0.05359269066580704, 0.016964639237682735, 0.02775038931784885, 0.11112965789756604, 0.02611817672316517, 0.02203657484746405, 0.02147591662859278, 0.04932475968130997, 0.060100791443671496, 0.05625641558851514, 0.031072869963411773, 0.02285863020058189, 0.03541116502934268, 0.055902135491903336, 0.05206626168053065, 0.037163831160536835, 0.005451140842134399, 0.03939033865130373, 0.03204043036592858, 0.0246512281176235, 0.06696853613747017, 0.043220838465328724, 0.04023564739951065, 0.06826108427984373, 0.03730568569153547, 0.07842279757772173, 2.7958904079028537, 19.026410273143224, 38.23465837751116, 46.71058171136038, 38.95045484815325, 29.68055043901716, 18.625627756118774, 19.72944811412266, 20.657659700938634, 24.515021630695887, 34.65097904205322, 45.90779032026018, 32.6836383002145, 19.623213631766184, 9.267212850706917, 3.3352936123098647, 0.7527898198791912, 0.07268481368997268, 0.09359799578253712, 0.16591843616749558, 0.49496404613767353, 0.6691603788307735, 0.3813721000083855, 0.9963134867804391, 0.604950989995684, 4.610625258513859, 5.51483907018389, 1.8624492159911563, 1.5684642025402613, 1.5760010438305991, 2.1028134609971727, 1.3800683575017112, 2.8682995396000996, 2.721570521593094, 3.2284982800483704, 1.5193990639277866, 1.2272998350007194, 0.8308298694235938, 1.211711442896298, 1.6437356663601739, 1.9898980685642786, 2.749315764222826, 4.468017390796116, 2.4075951065335954, 2.569308566195624, 1.8520125874451228, 2.083785819155829, 1.6507107892206736, 2.8983826339244843, 2.919371839080538, 2.120802564280374, 2.0108488414968764, 2.350920387676784, 1.2912714651652744, 1.3351225235632487, 0.6606644147208759, 0.5324341612202781, 0.4820200407079288, 0.14689407843564237, 0.11318644003144332, 0.2173066208405154, 0.17715341544577054, 2.373004585504532, 5.949916158403669, 13.14572422845023, 27.563906805855886, 42.318656648908345, 40.531889166150776, 27.07723413194929, 30.29809590748378, 26.677806513650076, 15.628697735922676, 30.464609486716135, 41.089961528778076, 38.04446881158011, 10.139111024992806, 0.3162795842758247, 0.041200195106544664, 0.12579549343458243, 0.028481110464781523, 0.058657201406146796, 0.01967564278415271, 0.11239482036658696, 0.035798754410019944, 0.04889889753290585, 0.053920735205922804, 0.07840796480221407, 0.016214849560388496, 0.036949383560568094, 0.06161931210330554, 0.04201991969187345, 0.054765012580901384, 0.06163166144064494, 0.024879192135163715, 0.01731137402488717, 0.03273241055597152, 0.08308867577995573, 0.06829068197735719, 0.01208201320176678, 0.013838277264897312, 0.02750909887254238, 0.033497384150645564, 0.02836665008882327, 0.05410478782973119, 0.06467899613614593, 0.0448673613635557, 0.01784641245779182, 0.07111420189695698, 0.031480930745601654, 0.02660593992498304, 0.0331394671063338, 0.07343512414289372, 0.044067755341529846, 0.036201006932450194, 0.05616897278066192, 0.04817929757492883, 0.01301804038562945, 0.020505674316414764, 0.06773101272327559, 0.0418696343632681, 0.027780058261539255, 0.022390042398391024, 0.10055126303008624, 0.19116814913494246, 0.14067468073751244, 0.14088168820100172, 0.16802692945514405, 0.1389753847782101, 0.12821787702185766, 0.168109086475202, 0.22685568487005575, 0.16163473602916512, 0.11233364364930562, 0.05955803128225463, 0.09502555203757115, 0.23597325491053717, 0.18370065412351064, 0.10529389032827956, 0.1848772745579481, 0.0856039100991828, 0.0852145870615329, 0.13924263258065495, 0.13954519134547028, 0.21713174879550934, 0.16085950977035932, 0.18774711127792085, 0.19318888070327894, 0.18457938411406108, 0.10961193112390381, 0.08985763934573957, 0.24411429092288017, 0.05711617373994418, 0.18018817688737596, 0.17363933686699184, 0.1367434931120702, 0.07849067143563714, 0.20751236139663629, 0.1383747455797025, 0.10915823546903473, 0.15499100967177323, 0.11697163406227316, 0.11223130021244287, 0.2582749096410615, 0.11218532946492944, 0.09003993456384965, 0.11291978255446468, 0.08653966417270047, 0.11855317705443927, 0.10037280153483152, 0.12338863472853388, 0.13000201699989183, 0.12151456171912806, 0.12868973027382577, 0.1637376653296607, 0.07710423440273319, 0.26103190598743303, 1.73866097841944, 15.799646002905709, 41.58672993523734, 55.20343780517578, 50.438133920942036, 41.29145581381661, 32.2023470061166, 33.49401017597744, 25.950602837971278, 22.233047349112375, 30.843227250235422, 45.589712211063926, 32.89506850923811, 24.715202706200735, 13.632534129279, 6.054978132247925, 2.4923752886908392, 0.21079691872000694, 0.7685869293553489, 1.398745332445417, 5.5338345766067505, 5.46721568277904, 7.486330492155893, 12.29558173247746, 11.08600458077022, 32.35478353500366, 25.165176732199534, 19.171651942389353, 4.442115374973842, 5.469254979065486, 7.255263805389404, 4.186418192727225, 5.804844285760607, 4.2725246122905185, 4.477604167801993, 2.0424635793481554, 1.5188135696308953, 0.4409150949546269, 2.3546166121959686, 2.763625796352114, 4.263100683689117, 4.044760056904384, 5.571316633905683, 2.411399245262146, 3.0629220562321797, 3.6515289289610724, 6.213443960462298, 10.636285901069641, 8.867427400180272, 12.68822009222848, 9.530552182878766, 8.756119864327566, 13.327180777277265, 10.9100900888443, 10.856745294162206, 9.581597123827253, 4.42025807925633, 3.551407124314989, 1.5800672599247523, 0.378663279648338, 0.7004321036594254, 1.226821277822767, 4.813234729426248, 9.828972101211548, 23.55922395842416, 31.391460963657924, 38.12005826405117, 33.55820458275931, 25.672622782843455, 40.63636922836304, 28.741035870143346, 29.810985497065953, 43.810705866132466, 47.60046182359968, 41.50580774034773, 9.320961509432111, 0.3210473784378597, 0.1353260198874133, 0.16472652155373776, 0.20640043249087675, 0.1376050833080496, 0.08095751942268439, 0.19590074090020998, 0.15634024941495486, 0.20633514385138238, 0.1198360017899956, 0.2516877188214234, 0.050702416471072605, 0.08598884980061225, 0.1726246013173035, 0.10454944920326982, 0.14317829853722028, 0.20672011747956276, 0.12499707484883921, 0.08180768987429993, 0.14436825897012437, 0.22459994948336057, 0.19994428035404, 0.08085507420556885, 0.14987961894699506, 0.16153752910239355, 0.11748475581407547, 0.11603174092514174, 0.08964065741747618, 0.15814626536199025, 0.09268192600991045, 0.1246991301221507, 0.1473415315683399, 0.14789983018168382, 0.18837609966950758, 0.1506590521229165, 0.2590408942529133, 0.1452540728662695, 0.1404500449342387, 0.13317871439669812, 0.1384790771241699, 0.13740129210054874, 0.12018993922642299, 0.17208531525518211, 0.12482084573379584, 0.1627021258963006, 0.09392516501247883], [0.07872766336160046, 0.025332499328734617, 0.06109037370021854, 0.01734820320936186, 0.02385076035612396, 0.03787055930921009, 0.009079251471640808, 0.10250000881829432, 0.0613565222759332, 0.011317412801352995, 0.030505981096731763, 0.029067615778850656, 0.024452712519892623, 0.01455073055279042, 0.030284001758056026, 0.08738828756447349, 0.01130026113241911, 0.013282177953182586, 0.0469979850708374, 0.028983290839408125, 0.02667806141211518, 0.04997329666678395, 0.025624890246295502, 0.03237164705725653, 0.05322655316974435, 0.013991252984851599, 0.03713265247642994, 0.01883955702318677, 0.07763124576636724, 0.0048421166471338695, 0.039174822358680625, 0.04136990350005882, 0.03575884637289813, 0.010647220370758857, 0.04357607190364173, 0.07657750802380697, 0.06983035935887269, 0.04215864617643612, 0.04597613847415362, 0.015814678444127952, 0.03226519848353096, 0.006498241664043495, 0.007646098999040467, 0.09351004407341991, 0.06604658346623182, 0.021948745274650197, 0.05531077525977578, 0.007153334994135159, 0.05936850288084575, 0.012206325058027037, 0.0563937442909394, 0.04362761342365827, 0.029192964945520674, 0.02865927679730313, 0.07128540985286236, 0.13215395009943418, 3.438727970634188, 17.871086393083843, 35.44977521896362, 41.856691769191194, 37.707647936684744, 34.60710116795131, 18.444213765008108, 23.787798847470963, 29.152362278529576, 11.732623049191066, 25.01086245264326, 32.167786666325156, 31.578798294067383, 28.779787710734777, 22.45624085835048, 17.00921446936471, 9.812239970479693, 3.150020548275539, 1.663032768028123, 0.30754314735531807, 0.10950088208275181, 0.21486130276960985, 0.3981723285147122, 2.9269581862858365, 6.200894211019788, 2.730332634278706, 1.0222336330584116, 1.5165886261633463, 1.8522824815341403, 2.241898374898093, 1.8040857591799326, 2.6172077102320532, 2.7695543467998505, 1.4006240602050508, 0.7517607808113098, 0.5967557526060513, 0.4511837182300431, 1.03610560297966, 1.0845826417207718, 2.3302151901381354, 4.343001927648272, 3.7965035268238614, 3.073809232030596, 2.2659552097320557, 1.6354081417833055, 1.7599244202886308, 0.7667456567287445, 1.0619536616972514, 1.6797772752387183, 0.7887213432363102, 1.5463062886680876, 1.1590909979173114, 0.7332280352711678, 0.1936726083180734, 0.11519566364586353, 0.2488826279129301, 2.1279722367014204, 4.946650130408151, 10.616976857185364, 19.800238098417008, 25.513606309890747, 35.050351074763704, 63.104825019836426, 20.630080563681467, 17.876559836523874, 17.25929750714983, 23.26313689776829, 27.650889566966466, 28.70516926901681, 44.21199907575335, 38.195456641060964, 20.42332649230957, 1.0921129690749305, 0.03752012989882912, 0.05809225993497031, 0.01700573131841208, 0.0423126295208931, 0.06444736463682992, 0.034853911359927485, 0.06242465174623898, 0.008943617410425628, 0.07053947595081159, 0.03933105504672442, 0.041446330291884284, 0.047872749024203846, 0.057604644314519, 0.09705888400120394, 0.008872277086733707, 0.042998428256916146, 0.027617901962782656, 0.06183784787676164, 0.027509694287021245, 0.012542306761523443, 0.05790708094303097, 0.03844535989420755, 0.04235852223687938, 0.029224245409880365, 0.05546821574015277, 0.03384584920214755, 0.011645366587410015, 0.029055470002016852, 0.0626225939818791, 0.030123151639210324, 0.04821332949878914, 0.03783328738063574, 0.04936181787135346, 0.045480058129344664, 0.05035537634310978, 0.04325596283056906, 0.019037443279687847, 0.03846620109730533, 0.09138483846826212, 0.05867391372365611, 0.0050091779059065235, 0.04433451120608619, 0.05059213078181658, 0.05063820330958281, 0.05556935477735741, 0.08402721184704985, 0.03741916049537914, 0.018666547556806887, 0.026241052629692212, 0.02577039020668183, 0.026005575533158014, 0.03432249630402241, 0.04512603248336485, 0.00234203804367488, 0.01933323365769216, 0.012568911271435874, 0.01820471796340176, 0.07480480136083704, 0.04598773803029742, 0.02431121761245387, 0.019865610536986163, 0.03146064933389425, 0.029700003630880798, 0.04018949684021728, 0.049116686917841434, 0.017635140401710356, 0.0021674244781024754, 0.05305964034050703, 0.021872759530586854, 0.05528314192114132, 0.04081695174266185, 0.04763810822208013, 0.022260862901540737, 0.05624941649979778, 0.03770017238067729, 0.014785639376246502, 0.022525287998308028, 0.029112975844847302, 0.007407550683378109, 0.005255056944276605, 0.015772541419469883, 0.059236256405711174, 0.056363311995353015, 0.03339351400999086, 0.0505503533807184, 0.003805537782942078, 0.037753345777413676, 0.036666040907480886, 0.019235611128221666, 0.057212919262903075, 0.03364718771938767, 0.03156900119834712, 0.03496978817773717, 0.024674087962401763, 0.0641646326652595, 0.05482016729989222, 0.021848359411316257, 0.06992360364113535, 0.06150800521884646, 0.013539072159411651, 0.020646392301257168, 0.06214905796306474, 0.6384967299444335, 7.868331159864153, 28.794443198612758, 45.733004910605295, 44.64046321596418, 36.162709031786235, 31.768706457955496, 16.44205560003008, 16.219405787331716, 24.725525992257253, 23.046300990240915, 32.11927434376308, 41.453352315085276, 42.08081981113979, 37.15519666671753, 25.79854324885777, 14.438672815050397, 6.613392693655832, 2.733826709645135, 0.3034122533031872, 0.024799812019669583, 0.11103097176445381, 0.1391791488443102, 0.3241394896592413, 0.545711028788771, 0.9572480001619884, 0.5059060475655964, 0.5603681994335992, 0.47391941824129646, 0.4262230747512409, 1.3471700485263551, 1.303866160767419, 1.3712870287043708, 2.554427696125848, 1.4754131670509065, 0.9227148017713002, 0.9466939036335263, 1.4346778328929628, 1.2923518014805657, 2.1810760157448903, 2.5986614482743398, 3.0670588399682726, 2.7724048452717915, 2.4433783292770386, 2.3208103690828596, 0.6402409449219704, 1.1617152456726347, 0.7884934097528458, 0.7571467203753335, 0.07291379890271596, 0.07265610487333365, 0.7346457934805325, 0.36571376451424187, 0.23127534985542297, 0.08333450901721205, 0.029907323220478635, 0.12607374707502977, 1.4253546531711305, 2.1067283366407668, 7.8563394376209805, 20.247347729546682, 33.15362140110561, 37.73152542114258, 59.550057138715474, 32.220044067927766, 23.378240755626134, 16.478538853781565, 17.214424303599767, 27.607994862965175, 25.892925841467722, 41.81629146848406, 44.490639209747314, 28.277372155870708, 4.925350861889975, 0.08277125031288181, 0.022300053387880325, 0.05651757353916764, 0.024676115085769976, 0.05239920185080596, 0.026596245355904102, 0.035824721945183616, 0.03789015879322376, 0.15826376048581942, 0.07296508936477558, 0.11736096388527326, 0.003025365639976891, 0.023064964218065143, 0.06649708322116307, 0.032361272256821394, 0.09237306365477187, 0.032010205023522885, 0.0491644964952554, 0.031945781516177316, 0.01642063057183155, 0.05835734321070569, 0.07246464264712163, 0.04616454390010663, 0.020231201812358837, 0.02221131627447903, 0.036982458750052113, 0.03509485235969935, 0.039985064417123795, 0.02900420328868287, 0.02748074459045061, 0.020646550060649003, 0.016484979440325072, 0.0803954888667379, 0.053986963616417985, 0.06450153887271881, 0.01803085863191102, 0.05070237236629639, 0.01911587344615587, 0.1020415091354932, 0.019392846351755515, 0.06254960396992308, 0.036833269255501885, 0.025543550860935023, 0.020684273215010762, 0.017108936494748508, 0.04003280953371099, 0.0497688947777663, 0.16785505653492042, 0.13668773110423768, 0.10563779901713133, 0.16431617071585997, 0.10036978205399853, 0.1624275092035532, 0.08273123031748192, 0.1333164977175849, 0.1505334960030658, 0.08054994379303285, 0.18184910847672395, 0.1342433494116579, 0.125099492924554, 0.08156535787773983, 0.2000333041484867, 0.11642112503094332, 0.08601394881095205, 0.16506022507590906, 0.19783113231616362, 0.10698429069348744, 0.13414976586188587, 0.10702403927487986, 0.11228473484516144, 0.12457714309649807, 0.10420197142021996, 0.10962394797908408, 0.1704610516982419, 0.23981940852744238, 0.15905052183994225, 0.14600780313568457, 0.11989246947424752, 0.13048350544912474, 0.2007497421332768, 0.09845011149133955, 0.1179318018257618, 0.16382884686546667, 0.13794964339051927, 0.23073100192206247, 0.16104336561901228, 0.09624629081892115, 0.13925385554986341, 0.05880970893693822, 0.09700282343796321, 0.1682457977107593, 0.13126567990652152, 0.10315655251698834, 0.15770684608391353, 0.1495031134358474, 0.1969816471849169, 0.10467809944280557, 0.17012177061821732, 0.12738948075899056, 0.0795345568497266, 0.08261789461331707, 0.20206903134073528, 0.36459247182522503, 5.52646210363933, 29.0240672656468, 50.10095868791853, 56.81574991771153, 49.8681697164263, 46.91423341206142, 29.372185911451066, 34.208691460745676, 39.0189015524728, 21.247707673481532, 35.63081748144967, 41.227497645786826, 41.957683835710796, 38.422374384743826, 30.963583946228027, 20.416386978966848, 13.276996544429235, 4.843241827828543, 1.8422703444957733, 0.42384084686636925, 0.3379422218671867, 0.47471683259521213, 1.9397663814680917, 7.670128583908081, 14.817367008754186, 8.844882232802254, 4.632388319287982, 3.645513091768537, 4.793785418782916, 6.361890052046094, 6.782302532877241, 8.797924569674901, 7.38323312146323, 6.961024531296321, 3.84849385704313, 4.399693582739149, 4.367533845560891, 5.999701304095132, 8.234606317111425, 9.741921595164708, 11.484794701848712, 11.23496961593628, 9.916545459202357, 8.745410084724426, 6.055476231234414, 8.559555326189313, 5.4706428817340305, 6.279195197990962, 5.164942554065159, 4.246670365333557, 3.6394844438348497, 3.1827867329120636, 1.617857643536159, 0.41416556175265995, 0.3640479881848608, 0.5960320000137601, 3.3587722267423357, 6.3594329953193665, 14.103336249079023, 26.5301798752376, 36.186572619846885, 43.12244163240705, 71.92694582257951, 27.337136711393082, 23.325321538107737, 23.530220440455846, 32.10673631940569, 38.42546285901751, 38.12535279137747, 54.95998682294573, 53.08777734211513, 29.716653278895787, 3.9338377118110657, 0.13321941292711667, 0.13647515965359552, 0.13146187152181352, 0.13350830599665642, 0.21044831456882612, 0.0914761692817722, 0.13755647305931362, 0.13022294800196374, 0.21194932902497904, 0.25706570595502853, 0.18569698557257652, 0.2156299879508359, 0.16854082473686763, 0.20395411018814358, 0.1474124656191894, 0.19148670775549753, 0.1308841532362359, 0.2704982023153986, 0.14027635354016507, 0.0803708987576621, 0.16944852817271436, 0.16681210749915668, 0.12507624631481512, 0.10844529872494084, 0.12131866865924426, 0.10504479333758354, 0.09614230532731328, 0.13809882609971932, 0.1302586660853454, 0.10810994636267424, 0.1431068895118577, 0.12387601286172867, 0.1765843281256301, 0.15337741268532618, 0.18058309783892973, 0.06265584898314305, 0.09311739621417862, 0.11265993078372308, 0.1298876702785492, 0.12993820756673813, 0.17424483437623295, 0.15088087879121304, 0.18281321174332074, 0.1329940850181239, 0.12206863984465599, 0.13087020255625248, 0.2436207788331168], [0.06679650036884205, 0.02702009734431548, 0.006594891343931002, 0.07214717646794659, 0.02544243387611849, 0.021723856717082005, 0.02991259883024863, 0.0306640017245497, 0.028800846343593936, 0.0501028425725443, 0.09167676458933524, 0.11934198758431844, 0.036876271412308724, 0.0244814671376454, 0.027505412731053572, 0.03480103312592421, 0.05768188874104193, 0.03898522949644497, 0.0099906554678455, 0.043913093462054215, 0.01557867887562939, 0.03864212487159031, 0.033381151101951084, 0.032160429283976555, 0.045277047237115245, 0.05747129861265421, 0.0303844215481409, 0.09756167166467224, 0.07279762692217316, 0.024762144844446863, 0.0344497182273439, 0.03899642871692777, 0.048824811686894724, 0.02987698931246996, 0.032091900639768155, 0.03431181955550398, 0.05752579176000186, 0.09784174377896956, 0.03711070865392685, 0.010909181537239679, 0.019694095543984855, 0.008129588278409625, 0.06332686583378486, 0.04215106015492763, 0.016587597683870366, 0.03114927639918668, 0.053582862086061916, 0.02178626667175974, 0.025667130747543912, 0.05059833259188703, 0.026984268998993293, 0.02052162158569055, 0.13770997125123227, 0.047578193579933474, 0.08769937551447324, 0.06966609960155827, 0.05174411360972694, 0.9298820857490812, 5.608590245246887, 23.701493535723003, 39.223647594451904, 42.534106390816824, 42.036455563136506, 39.61246531350272, 27.7671502998897, 21.49565414019993, 25.558514254433767, 19.68583079746791, 21.750753777367727, 22.60697160448347, 30.489869662693568, 31.719495841435023, 33.08367388589041, 31.627362728118896, 24.64076665469578, 20.653923307146343, 11.741011261940002, 6.300279940877642, 2.3183233482497076, 0.6315593336309705, 0.06347108845199857, 0.1326879843005112, 0.3722128000642572, 0.1977636587939092, 0.7550150347607476, 0.532534910099847, 0.4020893754703658, 0.4236258869724614, 2.4198109081813266, 0.5743465636457715, 0.5567720724003655, 1.2573286465236118, 1.0353111198970248, 1.0635121209280831, 0.7290805578231812, 1.6804436509098326, 2.3650065575327193, 1.0436565577983856, 2.1961108318396976, 1.5131806433200836, 0.6794096231460571, 0.2304422174181257, 0.5971301410879407, 0.6812950276902744, 0.17357235188995088, 0.0337571680678853, 0.5366860244955335, 1.2588879742792674, 4.350566778864179, 9.431559460503713, 15.22772935458592, 23.753669295992168, 27.1834807736533, 36.9789069720677, 37.90337521689278, 30.80847930908203, 23.043523447854177, 42.38725273949759, 61.85068907056536, 35.705430712018696, 27.097889389310563, 25.373577526637487, 30.107051713126047, 32.433298179081504, 42.76154177529471, 25.714126110076904, 8.35722552027021, 0.41455960060868946, 0.050754219227071316, 0.05971615708300045, 0.033774687842066796, 0.04737139646229999, 0.005943568972205477, 0.015005734083907945, 0.07428048378122704, 0.062051674617188315, 0.033441184487726004, 0.04826833154740078, 0.03384975417117987, 0.027341378586632863, 0.01690995610052986, 0.012862090985955936, 0.014505719932328378, 0.044473183407847366, 0.03397968005655067, 0.05034153422872935, 0.04664540131177221, 0.0316517994339977, 0.029589412600866387, 0.08474260488791124, 0.029726089909672737, 0.04693090170621872, 0.06701319052704743, 0.06131049046026809, 0.04476779652759433, 0.06932936302785363, 0.026264859030821493, 0.032104477286338806, 0.011550364051280277, 0.05419699734609042, 0.03764914654727493, 0.023808546996276294, 0.02001318342185446, 0.053034836492900334, 0.062282077968120575, 0.03081938624382019, 0.05032055392595274, 0.07997556389974696, 0.03074717315446053, 0.036428580792354684, 0.020517365474786078, 0.03683226163099919, 0.04927305870556405, 0.04858051872413073, 0.028676942456513643, 0.021711600678307668, 0.12206398509442806, 0.021878201381436417, 0.058817389953349314, 0.06661365553736687, 0.03069845773279667, 0.03906573767640761, 0.03376979560458234, 0.023093413495059525, 0.03232148296332785, 0.008290661465642708, 0.021517929820609943, 0.01891108648851514, 0.025448265884603773, 0.07625600456127099, 0.045567673963627646, 0.018883858574554324, 0.05507292498701385, 0.037238717677869966, 0.037282042138810666, 0.013164220577371972, 0.03204252364646111, 0.02037333115004003, 0.028612607158720493, 0.07057066142026867, 0.028721250793231384, 0.026050984792943512, 0.015569761229146804, 0.04019482673278876, 0.07594241281705243, 0.06672686910522835, 0.06383419968187809, 0.029942651146224568, 0.10793753061443567, 0.027083380912829722, 0.028598266321101358, 0.053101312568677325, 0.05436410355780806, 0.03453831793740392, 0.02848615197997008, 0.04411844190742288, 0.03195120640365141, 0.03172829407932503, 0.034298160645578585, 0.04027773353404232, 0.05056726247338312, 0.00782315168596272, 0.043220502590494494, 0.015078569729147213, 0.009915425442159176, 0.027384270481499176, 0.019311824181516255, 0.021719047600137334, 0.05201605687450085, 0.0645829698603068, 0.03636237273791006, 0.05164208569164787, 0.12807965943855898, 2.8500138350895474, 12.40537542956216, 33.95148304530552, 47.3710948399135, 48.073206833430696, 39.62811960492815, 33.00297750745501, 24.7189199924469, 15.454169409615652, 23.948192800794327, 23.624068021774292, 28.052325214658463, 32.41402040209089, 44.647831780569895, 45.81510135105678, 47.99950034277779, 34.06517989294869, 29.400906290326798, 18.308006490979874, 8.449935334069387, 4.763967224529811, 1.3913834989070892, 0.36015593845929417, 0.05195114482194185, 0.02797341868946595, 0.2925295558358942, 0.5029283102069582, 0.41898614593914574, 0.5147437761936868, 0.03924595657736063, 0.21068911307624408, 0.5283576856766428, 0.6449455810444695, 0.4661567062139511, 0.4737344224538122, 0.19969865067728929, 0.6355042276637894, 0.28137283878667013, 0.7324771412781307, 0.7157771459647587, 0.4388452374509403, 0.7186644481761115, 0.5582080696310315, 0.22676826241825307, 0.12478643043765, 0.14530138032776968, 0.3667578942009381, 0.15596900933555194, 0.030003905895033052, 0.15318213030695915, 0.6114654690027237, 1.9991704395839145, 4.452518999576569, 10.80554141317095, 21.57367546217782, 25.87509502683367, 43.04233932495117, 47.745779923030305, 41.04862322126116, 30.437598364693777, 44.052850587027415, 70.48172051565987, 27.664949246815272, 14.859966414315359, 19.374492440904888, 28.43204426765442, 33.94357252120972, 45.15514407839094, 36.90760455812727, 16.506444556372507, 1.9295874876635415, 0.10413333760308367, 0.07012989864285503, 0.019022851384111812, 0.03161770644198571, 0.0443061925470829, 0.04448681517637201, 0.0031778702021776034, 0.01785998824717743, 0.03865823329293302, 0.028812208412481204, 0.03467597572931221, 0.013916860949913306, 0.017540447447182875, 0.06061108370444604, 0.0061072146553280094, 0.009172800246493092, 0.045036113022693565, 0.05056541685813239, 0.009040746305670058, 0.017005210542785268, 0.02530001107204173, 0.02836807331602488, 0.01190629807700004, 0.009124158615512508, 0.03634700391973768, 0.016083715882684504, 0.095247426203319, 0.07308282876121146, 0.028814990406057665, 0.03847085924020835, 0.038140460183577876, 0.011884046369232237, 0.1091655365058354, 0.00877154856321535, 0.1020696751241173, 0.05186409895707454, 0.05090336800952043, 0.007431072947968329, 0.03202645254454442, 0.14712054628346646, 0.06740959068494183, 0.016348388644733598, 0.07860649057797023, 0.059681144676038196, 0.04357696756986635, 0.056112895254045725, 0.03848359873518348, 0.16142460730459007, 0.16887918300926685, 0.0904615151562861, 0.14507196763796465, 0.1670735063297408, 0.12419572499181543, 0.08343939017504454, 0.11499149245875222, 0.09851877244987658, 0.12428337814552443, 0.12702361467693532, 0.14173094263034208, 0.2245019283145666, 0.12408557161688805, 0.1642132776656321, 0.17160883439438684, 0.13415488201592649, 0.13229477325720446, 0.23480758603130067, 0.12448989706380026, 0.1675370814544814, 0.09361157326826028, 0.1599062630640609, 0.16434120865804808, 0.20428827511412756, 0.12231580301054887, 0.14714481069573335, 0.07477939022438866, 0.2585383712181023, 0.21223497869712965, 0.14508693612047605, 0.2366029896906444, 0.10723574898604836, 0.21272185471441063, 0.07409927421914679, 0.18687062045293196, 0.08899957074650697, 0.14870423344629152, 0.23701092494385584, 0.11415123540375914, 0.11923002930624144, 0.1639354040047952, 0.10172896233520337, 0.18441903271845408, 0.10025136412254401, 0.12713787997407572, 0.11413355278117315, 0.16123130624847754, 0.1215058086173875, 0.08848785356219326, 0.10445952295724835, 0.08708002232015133, 0.11923543044498988, 0.18852320606155054, 0.22619435749948025, 0.25558411117110935, 0.14853765309921332, 0.10873100946524314, 1.7865341752767563, 9.942174758229937, 33.684265749795095, 51.85516691207886, 57.50715821129935, 51.92244284493582, 51.4228777885437, 37.33974082129342, 32.844541209084646, 35.92421211515154, 30.471189430781774, 31.69632359913417, 30.198667185647146, 41.07181978225708, 42.56016213553292, 43.5781774520874, 41.65038933072771, 33.52442938940865, 27.926343951906475, 16.444916520799907, 8.574082272393362, 3.020029306411743, 0.6349753503288541, 0.09839708397963218, 0.40780258604458397, 1.160023576446942, 1.0394566974469592, 2.731061109474727, 1.825312614440918, 3.098771938255855, 3.246067234448024, 7.569663711956569, 3.656256743839809, 4.306266367435455, 6.605058763708387, 5.101709170000894, 6.083793180329459, 6.4041129520961215, 5.831857579095023, 6.406657295567649, 5.303727175508227, 6.554880610534123, 2.866080241543906, 3.168755497251238, 1.1937255965811866, 1.4623189611094338, 1.213046582681792, 0.5556111804076603, 0.24504331392901285, 0.8814100953085082, 2.033025537218366, 5.764287650585175, 12.183629751205444, 19.719472237995692, 29.839535645076207, 34.160446643829346, 45.33098908833095, 47.59620952606201, 39.89734492983137, 28.434516089303152, 47.99671758924212, 69.77541528429303, 41.03485189165388, 34.685872895377024, 35.002992153167725, 39.30023411342076, 43.25644111633301, 54.65952934537615, 40.106840065547395, 14.631461007254464, 1.0401313241039003, 0.1556690697159086, 0.19603017824036734, 0.08106617323522057, 0.10304190045488731, 0.08179723364966256, 0.10742534524095909, 0.14010963748608316, 0.15579933486878872, 0.16154245526662894, 0.11894228974623339, 0.13463228568434715, 0.1448758031640734, 0.08752696655158486, 0.11238466948270798, 0.1862178969063929, 0.17933329061738082, 0.17557450516947679, 0.12697068894548075, 0.13711011915334634, 0.22697345140789235, 0.11442164517939091, 0.1712439725441592, 0.1624133006802627, 0.07217686916036264, 0.1715880712228162, 0.09519959626985447, 0.15677969583443233, 0.1546705782945667, 0.11337978858500719, 0.1899304198367255, 0.1686252209224871, 0.20498127649937356, 0.22730957051473005, 0.10120106887604509, 0.19379466319722788, 0.17391921899148396, 0.20343446092946188, 0.11410983119692121, 0.11258486445461001, 0.240979187722717, 0.161239109401192, 0.10737655857311827, 0.16218120099178382, 0.0965953835153154, 0.14095894619822502, 0.19579533727041312, 0.11334977019578218, 0.21761494715298924], [0.06608343470309462, 0.025818481376128535, 0.04980034148320556, 0.024616049469581673, 0.0539934300551457, 0.04821824887767434, 0.010672019977521683, 0.047146143192159276, 0.03545182963301029, 0.004893877418778304, 0.04640691660876785, 0.07621582171746663, 0.11044222049947296, 0.032684427952127795, 0.014028845521222268, 0.06762176858527319, 0.04080828006512352, 0.02775986845205937, 0.02723682821462197, 0.014496422306235348, 0.023620445214744126, 0.03344381041824818, 0.08303646929562092, 0.024253038323617408, 0.03444436797872186, 0.030382721817919185, 0.04800136533698865, 0.02051104322474982, 0.055032474121877124, 0.06296214647591114, 0.02780976452465568, 0.0642799971891301, 0.02320769236290029, 0.06517100866351809, 0.022364936602701033, 0.04846404140282955, 0.031022844969161918, 0.04181677648531539, 0.02969765929239137, 0.024126472882926464, 0.03250728281480925, 0.017184289504906962, 0.03253775242982166, 0.05493417814640062, 0.04757313510136945, 0.045840051490813494, 0.006806749908719212, 0.06713672461254255, 0.12231501590992723, 0.013489701103286018, 0.031268769808645756, 0.05299365280994347, 0.044331305128123076, 0.011758817642528032, 0.03737608709239534, 0.011839811823197773, 0.08137762759413038, 0.04074221111035772, 0.037680606823414564, 2.0692410681928908, 6.201803122247968, 13.915146895817347, 32.26896286010742, 35.848765100751606, 41.95049592426845, 45.326677731105256, 37.836352893284385, 35.55552680151803, 25.536050728389196, 26.14941511835371, 21.993515150887625, 23.153145177023752, 17.460835218429565, 29.728576387677872, 25.023278883525304, 27.196439164025442, 33.42261743545532, 28.363634041377477, 31.53979458127703, 24.669966459274292, 20.243343830108643, 12.940087080001831, 7.343696134431021, 2.3412517522062575, 0.9722723939589092, 0.3801561381135668, 0.10144770278462342, 0.1035975052842072, 0.07035922990845782, 0.1284077311200755, 0.17075021618178912, 0.18689271355313913, 0.08100106101483107, 0.06238617202533143, 0.02822033758275211, 0.11286121819700513, 0.040508934163621495, 0.0051904671958514625, 0.11152878576623541, 0.6081592121294567, 1.634143352508545, 2.5333186345441, 5.435291750090463, 7.2154740776334485, 10.96084667955126, 18.220983777727398, 20.86339933531625, 30.90270730427333, 31.24839755467006, 30.509331566946848, 28.64498918397086, 24.844685861042567, 30.41769872392927, 19.179121255874634, 18.111386367252894, 31.488089561462402, 31.883605343954905, 34.87016691480364, 37.87750359943935, 31.827345779963903, 34.36641556876046, 35.31325701304844, 38.437215736934114, 28.966532707214355, 12.995266199111938, 2.09079481448446, 0.06011977006814309, 0.09359642158129386, 0.03158739289002759, 0.021543025438274657, 0.01731290072867913, 0.04066372835742576, 0.013860616334048765, 0.05384640847998006, 0.006065156086281474, 0.05960845321949039, 0.02991830530975546, 0.07218493694173438, 0.05671626555600336, 0.04720169485413602, 0.0603764055828963, 0.03981941366302116, 0.030082890763878822, 0.06399486320359365, 0.028016965370625257, 0.037238134137753925, 0.06259913024093423, 0.04548480448180011, 0.04521812325609582, 0.04556533980316349, 0.05319289783281939, 0.0045687200451668885, 0.0917328590793269, 0.04170008542548333, 0.05421617953106761, 0.02523557229765824, 0.01038093354353415, 0.009178510966843792, 0.05382467500333275, 0.02542232718717839, 0.019668989748294865, 0.06227634434721299, 0.03304083525602307, 0.010724949101651353, 0.015615718405959862, 0.046068008723003526, 0.04784176711525236, 0.03609997306817344, 0.02225724291721625, 0.014776034713057535, 0.033346342255494425, 0.018814525866348828, 0.026595882339669124, 0.036063976785434146, 0.09536122331129653, 0.02371663773166282, 0.03917461879817503, 0.007131149443531675, 0.04068827436172536, 0.027101516457540647, 0.12707256419318064, 0.05066271199445639, 0.06866805601332869, 0.042061306935335906, 0.0011832066770044289, 0.025609987920948436, 0.01816975135755326, 0.08252155621136938, 0.022445431211963296, 0.02135794992292566, 0.02438660285302571, 0.04652961948886514, 0.07509349765522139, 0.005590747725883765, 0.021386397503582493, 0.02741679436128054, 0.0037528894026763737, 0.06029255222529173, 0.053531120398214886, 0.018365569778585007, 0.06315515576196568, 0.04010324486132179, 0.020487170666456223, 0.0748173746147326, 0.08425615634769201, 0.022826391305508356, 0.046147512671138556, 0.01112384457207684, 0.01865018977384482, 0.08821021738861289, 0.01119435708304601, 0.03972700737150652, 0.01971067554716553, 0.03635748050042561, 0.05080977088904806, 0.037600349701408825, 0.03441074996122292, 0.017003987483414154, 0.031076805466519933, 0.08684881829789706, 0.029655474770281996, 0.03790243009903601, 0.009037193326678659, 0.049544265759842734, 0.09459935062165771, 0.06494682747870684, 0.014058661198110452, 0.041749486167516024, 0.027861669060907195, 0.03312282942767654, 0.028584071368511235, 0.046355877204665115, 0.1419893694775445, 0.01501881963174258, 0.21427318932754652, 5.113964489528111, 14.983567919049944, 25.79380284036909, 43.82984120505196, 46.43325131280081, 47.13808352606637, 43.50236913136074, 34.39690426417759, 30.656647273472377, 21.210744994027273, 19.29859205654689, 21.230205161230906, 24.94809068952288, 26.048728772572108, 41.83446448189871, 39.43044682911464, 44.84962483814785, 48.559789180755615, 42.16357980455671, 35.632926259722026, 27.458556481770106, 13.56876790523529, 8.690957920891897, 4.485426536628178, 1.0896549352577753, 0.3500825161380427, 0.3274349442550114, 0.05840355144547565, 0.13422356333051408, 0.15226063903953346, 0.14299064289246285, 0.07839638899479594, 0.08561140791113887, 0.026011945280645574, 0.029625503878508295, 0.1156604601336377, 0.05109425687364169, 0.09905047249048948, 0.06641584900873047, 0.17121281421610288, 0.005146152497867921, 1.5512295216321945, 2.154233604669571, 3.6185000155653273, 7.180883339473179, 9.535505379949297, 16.48477486201695, 24.673398869378225, 29.505612168993267, 38.36451326097761, 46.326870918273926, 43.870422158922466, 43.44899654388428, 43.502039091927664, 33.82036358969552, 29.030282429286412, 29.5894387108939, 22.62494833128793, 35.19363682610648, 47.944501876831055, 32.43619210379464, 31.726027148110525, 35.663651193891255, 40.303394181387766, 38.059643677302766, 23.388228791100637, 5.702063492366245, 0.21478795313409396, 0.1315143494201558, 0.011630636440323932, 0.030831847539437667, 0.03150858783296176, 0.07236093535487141, 0.025209262102310146, 0.015557018341496587, 0.020955688918807676, 0.01259124101073082, 0.03282932910536017, 0.06967661689434733, 0.07281600165047816, 0.0715194365807942, 0.042489258971597464, 0.06317001567887408, 0.008077218945670341, 0.01554968168160745, 0.028765043443334953, 0.04905225323247058, 0.016593003911631446, 0.024802531248756816, 0.028301739732601812, 0.026765086920931935, 0.05622886028140783, 0.003364248504762405, 0.015371472940647175, 0.023158747935667634, 0.06625245099088975, 0.04031978574182306, 0.03991831014198916, 0.08180231587695223, 0.04041891970804759, 0.0524424075681184, 0.02342163784695523, 0.02372243920607226, 0.06111581876341786, 0.02818786459309714, 0.051414016501179764, 0.029926128818520477, 0.0301146801295025, 0.03660664873729859, 0.017017641304326907, 0.036695265410734076, 0.07426233975482838, 0.04115211750779833, 0.13173666463366576, 0.034413419996521304, 0.12777038317705902, 0.012751920647653086, 0.1566028017550707, 0.11867458053997584, 0.15162984574479715, 0.1211053372493812, 0.22156578515257153, 0.13786503007369383, 0.12452234460839204, 0.14883827125387533, 0.12982304660337313, 0.07983189768024854, 0.12530936380582197, 0.1729790544403451, 0.2024542899536235, 0.22915745207241603, 0.1700683156294482, 0.11959365622273513, 0.15046956443360873, 0.07550817754651819, 0.15094281546771526, 0.25534700389419285, 0.11513220705091953, 0.14836645871400833, 0.24253219153199876, 0.14474506303668022, 0.1506125589034387, 0.17082089238933154, 0.08909477599497352, 0.1698251829615661, 0.12011333262281758, 0.108549949180867, 0.0998439716973475, 0.1243273743561336, 0.12951117833810194, 0.156174917572311, 0.16143160978598253, 0.20489628320293768, 0.10600960228059973, 0.18142324632831983, 0.15392041711934976, 0.15979805029928684, 0.15788163670471736, 0.04732772934117487, 0.08297278878412076, 0.15292955243161746, 0.15117133249129566, 0.1276708963726248, 0.09116421280694859, 0.16215898575527327, 0.23035351932048798, 0.18041887879371643, 0.11785267107188702, 0.10797238695834364, 0.24366314655968122, 0.09024051630071231, 0.10414025866027389, 0.10413310011582715, 0.20418388928685868, 0.15184883613671574, 0.16268323548138142, 3.566126665898732, 11.367843491690499, 25.933675289154053, 48.163262435368125, 54.541409969329834, 59.73146765572684, 59.99890381949288, 51.201202460697715, 47.54158626283918, 36.31976611273629, 36.39459473746163, 30.52191822869437, 33.229249068668906, 25.112547601972306, 37.79765837533133, 32.69286898204258, 35.72093909127371, 45.84609031677246, 39.541607584272114, 43.05908448355538, 34.264780793871196, 25.576391969408306, 17.638189724513463, 10.208066684859139, 3.3432679729802266, 2.118256049496787, 0.828760663313525, 0.20539420577032225, 0.4754508446369852, 0.35250190060053554, 0.40599855141980307, 0.2879101979945387, 0.27449803054332733, 0.5004726105502674, 0.1992934431348528, 0.4391697943210602, 0.2860930540731975, 0.4417646750807762, 0.21834574293877396, 0.31905137268560274, 1.0680653623172214, 2.7712992131710052, 3.4013236463069916, 7.6460504702159335, 10.842570100511823, 14.628424644470215, 23.333753177097865, 28.5885454927172, 37.98657294682094, 40.18411445617676, 41.112803731645855, 36.98755747931344, 32.9944520677839, 41.90185158593314, 26.05131697654724, 26.417040620531353, 42.79263843808855, 42.77437162399292, 42.395343916756765, 49.76318938391549, 43.99979761668614, 45.513632910592214, 48.936444078172954, 51.55094003677368, 41.19742236818586, 20.46296075412205, 4.109935462474823, 0.18892492593399116, 0.22625320005629743, 0.1294772108750684, 0.08616785412388188, 0.10850223459835563, 0.16200136207044125, 0.11358231093202319, 0.18569870905152389, 0.08380389240171228, 0.1385616005531379, 0.08672986432377781, 0.23350924998521805, 0.14932087250053883, 0.18138058004634722, 0.12315221955733639, 0.20613516601068632, 0.09990193215864045, 0.1944311833275216, 0.09735528166804995, 0.1684586541461093, 0.10249307419040374, 0.10473607347479888, 0.16428392673177378, 0.18880850289549145, 0.20723494913961205, 0.05157874105498195, 0.14038638477878912, 0.11404684957649026, 0.1400309545653207, 0.15750833387885774, 0.12092343558158193, 0.06615529834691967, 0.16480452593948158, 0.17865764615791185, 0.11786560394934245, 0.14452596407915863, 0.12372455027486597, 0.09830820267753941, 0.15365829904164585, 0.1204852783786399, 0.13217395331178391, 0.12933340216321604, 0.09013651045305388, 0.11265366112015077, 0.18793452265007154, 0.07569035741367511, 0.30582259967923164, 0.1637679822742939, 0.1907088216394186, 0.09434606028454644], [0.020488317390637736, 0.03266948661101716, 0.06469568809760468, 0.02664959347540779, 0.031221927143633366, 0.02086802728341094, 0.04119391187227198, 0.049719280297202725, 0.05289084457659295, 0.001887383746049766, 0.037238191813230515, 0.018073730170726776, 0.051168685379837237, 0.02882000817252057, 0.030971825921109745, 0.012508810880327863, 0.029903326649218798, 0.029650473967194557, 0.029302212476198162, 0.02727014258770006, 0.029522159602493048, 0.048623385173933845, 0.030346681430403675, 0.031448795327118466, 0.07049200564090695, 0.024178769273151244, 0.030761076336992637, 0.032088792949382744, 0.0264838426373899, 0.03419525741732546, 0.09693285290684019, 0.014841469237580895, 0.017866505576031547, 0.029616326692381074, 0.0478072059340775, 0.0917121773319585, 0.04024000359433038, 0.03880433884582349, 0.04824317486158439, 0.05105970926316721, 0.06318929964410407, 0.06919381208717823, 0.019466438563540578, 0.009912382212600537, 0.06621594580688647, 0.012319586971508605, 0.0033860623454009847, 0.03467366531757372, 0.019801419427884475, 0.052908842717962604, 0.03128016919695905, 0.04142590978049806, 0.0573291251701968, 0.049429566200290403, 0.09406713489443064, 0.05508717761508056, 0.04056629412142294, 0.05703175041292395, 0.048527939045535665, 0.03203762123095138, 0.11620233819953033, 1.2972191231591361, 6.4643091048513135, 15.141441413334437, 14.348325388772146, 24.637768507003784, 49.449241978781565, 42.31082255499703, 45.61431925637381, 36.50300748007638, 41.734823840005056, 35.91142048154558, 38.679176330566406, 25.975590297154017, 26.749357325690134, 26.518802200044902, 18.70394437653678, 30.600887979779923, 25.758274963923864, 29.62928315571376, 52.19784164428711, 31.934660707201274, 31.442933218819753, 38.0724561555045, 27.29445219039917, 22.125961712428502, 18.11428550311497, 13.81891347680773, 12.238035014697484, 10.247586301394872, 10.59943265574319, 10.674203089305333, 10.11188885143825, 12.026509267943245, 10.120878083365303, 13.093725647245135, 13.076766831534249, 17.39164158276149, 17.74674490519932, 23.38965664591108, 21.51041385105678, 24.737369196755544, 26.903468370437622, 28.839908736092703, 31.32151344844273, 29.234298910413468, 25.234599658421107, 29.54536976133074, 28.69125897543771, 20.592379638126918, 25.014214958463395, 27.281733512878418, 19.37935791696821, 26.029814038957866, 35.9408461025783, 40.86271374566214, 42.89558294841221, 35.197020598820274, 37.26617329461234, 41.81715651920864, 36.26585851396833, 23.88756455693926, 12.053227697099958, 3.203939654997417, 0.07129610356475626, 0.08267124782183341, 0.04181944991328886, 0.048061069633279524, 0.03849806510178106, 0.06005007095102753, 0.04728017760706799, 0.05653094067903502, 0.015663740025567155, 0.03378089643748743, 0.029653822537511587, 0.026867381164005825, 0.02712122959616993, 0.010186698653602173, 0.030620263357247626, 0.026348958357370326, 0.027654215460643172, 0.06306866290313856, 0.013919010209584875, 0.01516216354710715, 0.020021453067394238, 0.05522122560068965, 0.04228782228061131, 0.041881695323224576, 0.07991614458816391, 0.026022923977247307, 0.05188802410183208, 0.009049838674919946, 0.06547780148684978, 0.0220901909883001, 0.04376798874831625, 0.04094009906319635, 0.03540063416585326, 0.06253691536507436, 0.01972034976019391, 0.049567780390913994, 0.015225226591740335, 0.05222029930778912, 0.061218996798353534, 0.019398861564695835, 0.04032922077125736, 0.032083096647901196, 0.06284549952085529, 0.04021134227514267, 0.0062798751002576736, 0.010777483827301433, 0.015834968337523084, 0.05476241379177996, 0.04619915597140789, 0.057434196317834516, 0.04777455822165523, 0.03260247449257544, 0.04900546145758458, 0.05268309411725827, 0.030348808637687137, 0.03605936953265752, 0.052158651008669815, 0.047082578031612296, 0.07377232890576124, 0.09183024242520332, 0.0468971242329904, 0.026124268271295086, 0.029280299187770913, 0.026164442633411715, 0.008876276202499866, 0.019789355075252906, 0.056107673927077224, 0.07917655498853751, 0.01646018577074366, 0.027901098730840852, 0.05823875564549651, 0.031091319330568825, 0.04601550029058542, 0.024782229480998855, 0.016190249273287396, 0.08034590152757508, 0.030446405722094432, 0.044170339658324204, 0.023573061418054358, 0.03897107864863106, 0.012068404333799012, 0.0657709286149059, 0.021228083409368992, 0.03142951475456357, 0.013121181101139103, 0.08047403608049665, 0.06315493863075972, 0.02035813875097249, 0.006840599476293261, 0.019381916848942637, 0.06398661900311708, 0.07730075850018434, 0.06636968148606164, 0.057044778285282, 0.02348450242009546, 0.024336954445711205, 0.04748834536543914, 0.07001409985657249, 0.03444931110633271, 0.04983285688129919, 0.016966817335092595, 0.05351902890418257, 0.07195255905389786, 0.05452818350334253, 0.06978643100176539, 0.08386536767440182, 0.06693876880620207, 0.05441337537818721, 0.060351679766816754, 0.048219582198985984, 0.05329791469765561, 0.04248098423704505, 0.2459353432059288, 3.75481607232775, 13.611122386796133, 25.51586447443281, 28.040956224714005, 41.029136998312815, 56.345690386635916, 47.683062008449006, 44.44790778841291, 34.914923736027305, 35.64913988113403, 31.12904487337385, 22.885337284633092, 22.36855459213257, 18.807338782719203, 21.675793136869157, 23.006788321903773, 29.095084803444998, 37.673879691532676, 40.70394740785871, 53.26658228465489, 46.21789884567261, 47.69559308460781, 36.8663843699864, 30.505489213126047, 23.982859100614274, 16.339022500174387, 12.654212134225027, 10.242404682295662, 8.687111224446978, 7.385707548686436, 8.68147189276559, 8.024985245295934, 7.122553646564484, 7.222838299615042, 8.790001017706734, 14.544686692101614, 18.292788199016027, 21.712794031415665, 18.56191451208932, 27.53361439704895, 37.7372715813773, 41.30842678887503, 41.614171845572336, 44.765569005693706, 43.168793065207346, 37.51147249766758, 46.77249363490513, 36.26881149836949, 25.42968249320984, 23.574822664260864, 19.739314556121826, 20.784243719918386, 14.760758297783987, 23.70739255632673, 39.94302586146763, 37.67976481573922, 37.16487898145403, 39.995012283325195, 41.56004885264805, 42.770748138427734, 36.18224041802542, 22.08246077810015, 7.02291430745806, 0.7317494260413306, 0.06775176910949604, 0.026317111316270063, 0.06394887210002967, 0.03686832237456526, 0.0011834570988347487, 0.025260072500844086, 0.10605802932488066, 0.03787266955311809, 0.04085886145808867, 0.09080264185156141, 0.054094704799354076, 0.02899111434817314, 0.03363538799541337, 0.019424109852739742, 0.029610905197582076, 0.010341704889599766, 0.029753536651177064, 0.03269009032685842, 0.038596235548279116, 0.08483481779694557, 0.014352642432121294, 0.02117769030987152, 0.012308651531514312, 0.007788725363622818, 0.01261389983950981, 0.10773295909166336, 0.011556187578077828, 0.005844734833642308, 0.04675228414790971, 0.05488145936812673, 0.038266565916793685, 0.02209134110515671, 0.04564462322741747, 0.052354649241481505, 0.05800487140991858, 0.07197659954960857, 0.0245943719720734, 0.045188074332794974, 0.022704122687823007, 0.03600845905020833, 0.03712947014719248, 0.02419822456847344, 0.02798346440041704, 0.033098653224962096, 0.023634214386610047, 0.024757440900430083, 0.03064312320202589, 0.03768684256023594, 0.05644483458516853, 0.01885779943716313, 0.03623931023425289, 0.2129154543259314, 0.16494697758129664, 0.17940415681472846, 0.09993553321276392, 0.13292707289968217, 0.09161953016051225, 0.14324589419577802, 0.21376052897955689, 0.08901519062263624, 0.07750518074525253, 0.13234844537717955, 0.103344981691667, 0.10401304691497769, 0.12436037829944066, 0.14334297898624623, 0.09493437728711537, 0.13863353883581503, 0.12146517794047083, 0.09398423827120236, 0.16019136990819657, 0.12120392838759081, 0.16070948567773613, 0.19737495322312626, 0.09876928757876158, 0.16855967443968567, 0.11950242040412766, 0.09833267065031187, 0.14537259936332703, 0.08648973756602832, 0.15390012892229216, 0.16928652115166187, 0.08228501211851835, 0.10386017976062638, 0.21623498334416322, 0.16820613055356912, 0.23112669640353747, 0.11033427914870636, 0.142032103613019, 0.20118165681404726, 0.16403307233537945, 0.13335043803921767, 0.14679470019681112, 0.07640248670109681, 0.039393364917486906, 0.1275234100009714, 0.1682691393154008, 0.1458221695252827, 0.2136733372296606, 0.10763702781072684, 0.16968061429049286, 0.1776151992380619, 0.15243305478777203, 0.1843970346131495, 0.16235107901905263, 0.1922649602804865, 0.2229265599910702, 0.19658150151371956, 0.1474111492612532, 0.17949326203337737, 0.1389653288892337, 0.23748948212180818, 2.57794126868248, 11.257379293441772, 25.506072725568497, 30.319934095655167, 46.3348821912493, 65.91777542659214, 56.822934355054585, 59.5329715183803, 48.90276615960257, 54.904700006757466, 46.414626666477744, 48.25201525006975, 35.62256302152361, 34.74206297738211, 35.2896921975272, 25.74391998563494, 38.80440371377127, 33.344304289136616, 37.938098839351106, 66.82211821419853, 45.2057443346296, 43.974954332624165, 52.467525550297324, 37.8760027885437, 31.259969779423304, 25.25638747215271, 20.394142321177892, 18.388645546776907, 14.217614139829363, 14.423164435795375, 15.108373199190412, 14.308879596846444, 16.066250119890483, 14.420464192117963, 18.30173921585083, 18.39054066794259, 25.268258469445364, 26.669862985610962, 32.485618114471436, 30.38936049597604, 34.835123675210134, 36.43253537586757, 38.32352931158883, 40.84178229740688, 38.19044004167829, 33.611351353781565, 40.55340773718697, 36.96020589556013, 27.152766261781963, 32.34471212114607, 34.852233614240376, 28.229184661592754, 34.02996642248971, 46.66694355010986, 52.77372571400234, 54.44085563932146, 47.07413230623518, 49.77296549933297, 54.84847865785871, 50.35283088684082, 38.38636187144688, 18.619900703430176, 4.568396713052477, 0.357670573251588, 0.2589977394257273, 0.17531031077461584, 0.19862482829817704, 0.12070946634880134, 0.24269004591873714, 0.10543366854212113, 0.2056509091385773, 0.11832674991871629, 0.13265327044895717, 0.20570508337446622, 0.1443666983395815, 0.09650716039219073, 0.0713450802224023, 0.07908377889543772, 0.11589458185647215, 0.07779003653143134, 0.13542219544095652, 0.074531324606921, 0.14640462398529053, 0.13776852882334165, 0.1231149679848126, 0.0731788482517004, 0.09927315411290952, 0.1511952576360532, 0.10887665700699602, 0.19632644020020962, 0.1346252832029547, 0.17131022470338003, 0.17952499033084937, 0.12697295525244304, 0.18117651742483887, 0.1188298836350441, 0.21694439170616014, 0.09259750268289021, 0.16830690657453878, 0.13198401778936386, 0.16771526475037846, 0.13957451762897627, 0.059414073292698176, 0.13345956004091672, 0.11522482708096504, 0.06365980939673525, 0.07407007007194416, 0.14184648357331753, 0.09932838007807732, 0.1307339391538075, 0.12622518252049172, 0.06629637934799705, 0.1819011385419539, 0.11550783046654292, 0.11426521571619169], [0.07022886976067509, 0.027214786004541174, 0.045807780365326574, 0.04727723955043724, 0.05215703609532543, 0.015933939455343143, 0.0858695429882833, 0.059339543006249836, 0.01586758212319442, 0.05005370645916887, 0.007874208053440919, 0.057690899686089585, 0.04384655971080065, 0.09872919972985983, 0.033360991826547046, 0.014213404501788318, 0.0383486890101007, 0.021855419568185295, 0.060391597981963835, 0.02232166303188673, 0.02745642589538225, 0.027270164640088166, 0.01814107477132763, 0.028894575778394938, 0.039013202102588754, 0.015483570318402988, 0.03176398502130594, 0.03232555078076465, 0.07214968026216541, 0.016125252403851067, 0.07844134872513157, 0.05768294047032084, 0.011136561166495085, 0.053363420468355925, 0.05561554944142699, 0.015919228816138845, 0.02293329280135887, 0.03294670548556106, 0.023417010238128047, 0.04489961552566715, 0.06069212792707341, 0.12084917670914105, 0.012969636241905391, 0.02617616093318377, 0.06250169939760651, 0.023176623940733925, 0.06403303758374282, 0.021908518326069628, 0.06333983942334141, 0.018033077441422, 0.04671497829258442, 0.021379479839067374, 0.056738104205578566, 0.06760646762060267, 0.04602374788373709, 0.023617437608273964, 0.012233730239261473, 0.00422158619455461, 0.06551315994667155, 0.06822042646152632, 0.03516160324215889, 0.05545189697295427, 0.06307739564882857, 0.6773557247860091, 4.412088734763009, 7.4858441182545254, 13.185076219694954, 26.379862546920776, 33.77836172921317, 41.448856830596924, 46.39816985811506, 49.59590802873884, 47.03232152121407, 45.66063247408186, 44.786191259111675, 44.69018105098179, 41.622332504817415, 43.678269726889475, 31.813907963888987, 30.627096584865026, 90.51124395642961, 30.947881017412456, 15.334557907921926, 28.987920999526978, 20.128154856818064, 18.591294969831193, 20.567518983568462, 26.867002487182617, 25.4506938457489, 29.29469265256609, 25.384982994624547, 23.855757440839493, 25.15201163291931, 36.55562271390642, 39.62655626024519, 34.32715129852295, 27.647406782422745, 27.622540916715348, 21.429896388735088, 60.47115898132324, 54.17324924468994, 24.910801444734844, 20.88210388592311, 24.20142684664045, 24.10081171989441, 22.852397612163, 29.12599560192653, 26.901093823569163, 34.7003355707441, 35.036468573978965, 37.52464975629534, 44.76006255831037, 40.91888298307146, 43.06250647136143, 43.80384104592459, 34.809700216565815, 38.46750293459211, 42.96679850987026, 34.429046630859375, 23.71849751472473, 6.474569857120514, 0.1529183973159109, 0.07202069754047052, 0.054886860506875176, 0.061206898518971035, 0.013448904185289783, 0.06267086496310574, 0.07993846160492726, 0.029956116673669646, 0.010671081054689628, 0.06839105766266584, 0.03777336934581399, 0.006275397617303367, 0.032582997144865136, 0.08974585748676743, 0.02907805164743747, 0.037117904517799616, 0.04119399329647422, 0.0585000662665282, 0.027918647342760648, 0.08251515762614352, 0.01959635766356119, 0.00807625542594386, 0.03852935913684113, 0.04449485920901809, 0.08817494035299335, 0.01737738530417638, 0.029572710461382355, 0.0942401545388358, 0.030152359179088047, 0.027678646113989607, 0.07082528847136668, 0.006115071666759572, 0.03817218169569969, 0.08389362865792853, 0.07828711771539279, 0.024741254447560226, 0.014511309364544494, 0.05890215254787888, 0.03962774448362844, 0.009557024093477853, 0.01432515837119094, 0.02425119949371687, 0.013895752573651927, 0.044902804640254805, 0.04460884291412575, 0.041480922007134984, 0.030198346889976944, 0.034869117329695394, 0.013185116911440023, 0.0038425959729855613, 0.018679249732355987, 0.033003539578723054, 0.00958565403042095, 0.02290595632179507, 0.018945953010448387, 0.10792987673942532, 0.051221234524356465, 0.011915979923547378, 0.02386238026831831, 0.02638041354449732, 0.03897262231579848, 0.049871034654123444, 0.051152726236198626, 0.0734761483701212, 0.009607892167488379, 0.05921125917562416, 0.023408308026513884, 0.04645890935457178, 0.04885389369779399, 0.01519371203279921, 0.058537433190005164, 0.0738959986982601, 0.06416525691747665, 0.030790728317307572, 0.03281282374103155, 0.03051766546975289, 0.03918349403621895, 0.039103844203054905, 0.015964395499655178, 0.020854057943714515, 0.010627031409447747, 0.01545349764637649, 0.05103159077199442, 0.04679151025733777, 0.06179840463612761, 0.06544464148048844, 0.026956946090129868, 0.020075274465073432, 0.09915048855223826, 0.04772006846698267, 0.008661843869569046, 0.030439654298658882, 0.02460425653095756, 0.06426269454615456, 0.051972159051469395, 0.009159936918877065, 0.06343644923929657, 0.02572691986071212, 0.049771564813064675, 0.02979552439813103, 0.02463224610047681, 0.05134864304480808, 0.0577767886487501, 0.08999962279839174, 0.03325276549107262, 0.07603112448539052, 0.03693122935614415, 0.025153691780620387, 0.018157261224197488, 0.046839584463409016, 0.016276379115879536, 0.026092124371124164, 0.034002326162798066, 0.06277317447321755, 0.06420212172503982, 0.038528531324118376, 0.2503340414592198, 0.4319455405431134, 2.6067652191434587, 8.959072402545385, 14.479719298226492, 25.537372623171123, 37.4626579284668, 45.738997731889995, 47.07053313936506, 53.4666417666844, 53.506100586482454, 49.912363733564106, 42.069605418613975, 39.77596337454659, 34.87409264700753, 27.51853506905692, 33.85428816931588, 24.924555403845652, 27.46919243676322, 83.18989930834088, 32.3407690184457, 25.871195350374492, 46.2371175629752, 39.42806012289864, 33.341267926352366, 38.39093031202044, 41.17339897155762, 40.53897285461426, 41.23156581606184, 37.64257458278111, 41.46778719765799, 41.10965272358486, 47.213158811841694, 47.85658632005964, 49.424714837755474, 41.66136053630284, 42.12049749919346, 34.0723226411002, 56.90092441013881, 48.54982198987688, 28.5529568195343, 25.124039922441753, 24.495785542896815, 22.57906242779323, 20.589407546179636, 20.36655102457319, 20.688754626682826, 27.291744129998342, 24.352942739214214, 32.09625843593052, 36.88963999067034, 33.253592082432334, 41.18736137662615, 48.49832541601998, 43.9156618799482, 50.22951078414917, 46.88628428322928, 43.25836229324341, 35.37842764173235, 16.0196624483381, 2.8808866356100356, 0.3052114839000361, 0.14537293863083633, 0.07224037325275795, 0.023435381573757956, 0.05106322407456381, 0.04539552623672145, 0.03136947119076337, 0.042011658528021405, 0.06146765274128743, 0.028553703533751622, 0.03090918017551303, 0.01063778788583087, 0.12925644272140094, 0.053029883187264204, 0.009280103774342154, 0.019874460329966884, 0.013126259087584913, 0.033253830791051896, 0.041883171136890135, 0.007555590061071728, 0.00545717089802825, 0.02812936300012682, 0.011689845406051193, 0.07681807582931859, 0.04688143650335925, 0.07939410010086638, 0.05588429341358798, 0.048426996783486435, 0.027520667894610336, 0.046488045648272545, 0.04107439810676234, 0.05503352585115603, 0.03045818509001817, 0.044296038270528824, 0.027459365648350546, 0.030232399169887816, 0.05587360987971936, 0.021280903967895677, 0.04763030846204076, 0.01207641274335661, 0.013683743458906454, 0.01638268180457609, 0.03577413037419319, 0.024030623026192188, 0.06969220284372568, 0.027248027435104762, 0.047568446424390586, 0.023718505399301648, 0.005693548749799707, 0.03251549648120999, 0.014258409185068948, 0.06124791596084833, 0.030081374238112142, 0.04864915593394211, 0.2118794127766575, 0.1417346338608435, 0.19269456794219358, 0.13989904735769543, 0.14167287360344613, 0.11747227076973234, 0.17780037144465105, 0.15213705067123684, 0.09020473714917898, 0.14734364859759808, 0.1094707144158227, 0.09714678821286984, 0.14680110556738718, 0.2247101164289883, 0.12487199370350156, 0.09233936082039561, 0.12818053045443126, 0.13557520508766174, 0.14668669099254267, 0.06522744920636926, 0.1151260459529502, 0.08862337057611772, 0.12252091057598591, 0.16984712678406919, 0.08582910230117184, 0.08158504217863083, 0.15355608452643665, 0.10803709884307214, 0.17317901871034078, 0.14423825166055135, 0.21824701609356062, 0.14693857676216535, 0.14743172244301864, 0.19288119221372263, 0.11963487043976784, 0.07057414230491434, 0.1387794917183263, 0.18590482084878854, 0.16069872411234037, 0.13265263262603963, 0.1290264736328806, 0.2344977126589843, 0.1312270305518593, 0.10040390558008637, 0.13353905720370157, 0.08811997901648283, 0.19362048325794085, 0.11609374545514584, 0.12758708372712135, 0.10352465776460511, 0.25056056358984535, 0.13285704808575766, 0.1132860014747296, 0.15967438050678798, 0.1505727967513459, 0.09564133613769497, 0.08666715411735432, 0.116747310385108, 0.21582349256745406, 0.23034906813076564, 0.15664553589054517, 0.3031434177287987, 0.2393473381442683, 1.2328246299709593, 6.28094744682312, 13.134946703910828, 23.153037479945592, 38.03058631079537, 49.29823677880423, 55.56434113638741, 63.531062262398855, 65.0843529020037, 63.04914215632847, 61.57755538395473, 58.00836999075753, 55.43089056015015, 52.05684879847935, 55.38020692552839, 40.241694177900044, 38.68392195020403, 99.99816840035575, 38.721004486083984, 22.823633807046072, 39.9639573097229, 30.266498974391393, 29.03584793635777, 30.422176837921143, 39.58555146626064, 38.673256465366904, 42.669380869184224, 36.91882937295096, 34.71783460889544, 38.18330076762608, 49.11138582229614, 51.08418090002877, 48.152294703892295, 37.54071051733834, 36.502475942884175, 29.40569359915597, 74.56211962018693, 65.80570098331997, 31.213462012154714, 29.433906759534562, 31.763710703168595, 33.80772481645857, 31.597388199397496, 39.620740618024556, 35.288820198604036, 46.40835591724941, 44.56484944479806, 51.34042004176548, 56.61244910103934, 51.37411185673305, 55.82140711375645, 60.19767788478306, 51.38753925051008, 57.24435649599348, 56.202957017081125, 47.1538941519601, 34.27370228086199, 13.52864032132285, 1.7058209691728865, 0.25793368795088356, 0.20257025158831052, 0.1802460423537663, 0.17053691191332682, 0.2005082108080387, 0.12440360098012856, 0.12948235417050974, 0.06948442185031516, 0.1332254790301834, 0.10205970065934317, 0.0910797623385276, 0.09079016359256846, 0.15685308618204935, 0.1728312966546842, 0.07957849199218409, 0.16585515599165643, 0.0759379616273301, 0.17130193300545216, 0.2056508141436747, 0.09785640013537236, 0.08415120733635766, 0.07648399232753686, 0.15245779417455196, 0.15321672202220984, 0.09796054169003453, 0.11401471415800707, 0.14099436572619847, 0.1290612689086369, 0.12150515722376959, 0.21295102313160896, 0.11617264550711427, 0.16611925539161476, 0.13272857426532678, 0.1804217557821955, 0.1656568337764059, 0.21119406526642187, 0.17421500597681316, 0.11478778267545359, 0.10096733391817127, 0.09092352965048381, 0.12309823531125273, 0.09614989134882178, 0.17198198794254235, 0.10263190924056939, 0.1634039075246879, 0.10229161035801683, 0.1363134511879512, 0.13690398021468095, 0.08674087694713048, 0.14142101497522422, 0.19266839006117412, 0.16111819446086884, 0.1093357198738626, 0.1357306031776326], [0.033279034974319596, 0.02158124901221267, 0.03496925552774753, 0.0031467180233448744, 0.05058350660172956, 0.04523458451564823, 0.048603931574949195, 0.05262048908376268, 0.013963395729660988, 0.029860894461827617, 0.027040073415264487, 0.030587534220623117, 0.06161222141236067, 0.033544097894004414, 0.01674485156711723, 0.06935668084770441, 0.05839773640036583, 0.021503164898604155, 0.02635449859579759, 0.028166158257850578, 0.10469641988830906, 0.04805419946621571, 0.023152965120971203, 0.03416495404339262, 0.03531779521810157, 0.02612789673730731, 0.031265061614768844, 0.06444971236799445, 0.037522155325859785, 0.05996431769537074, 0.019571952455277954, 0.027591869966792207, 0.03339484393862741, 0.02720912023713546, 0.01740287447215191, 0.027392540127038956, 0.05429388875407832, 0.033364242009286366, 0.016471793808575188, 0.022526312586186186, 0.044722480566373894, 0.0638740568288735, 0.023693969573027322, 0.0567093207500875, 0.018810761693332876, 0.06468042784503528, 0.0824900654011539, 0.05296320355098162, 0.00501789411230545, 0.02317754165934665, 0.019494813201682906, 0.035658932091402154, 0.006878835348678487, 0.017882362939417362, 0.021882323481674706, 0.023979593800114732, 0.04668559094092675, 0.01584994021270956, 0.02528680338790374, 0.0032890038481647415, 0.03310966245563967, 0.029298249831689254, 0.02751191988188241, 0.037593411680843146, 0.05743590622608151, 0.12486676898385797, 0.18717929960361548, 1.1957493679864066, 3.228413381746837, 10.301955086844307, 15.329555204936437, 17.474978276661464, 19.851864950997488, 14.773428337914602, 24.545828206198557, 45.54992682593209, 49.12421219689505, 43.04384708404541, 46.60547283717564, 43.766303403036936, 70.54280907767159, 48.70899827139718, 33.76961047308785, 23.121450969151088, 27.644057750701904, 31.126171793256486, 21.3772029876709, 24.26921694619315, 30.20883240018572, 35.36204031535557, 21.74377257483346, 27.586967876979283, 25.16540081160409, 31.864633287702286, 29.552588939666748, 26.5822149344853, 32.57355798993792, 34.031380380902974, 29.834592001778738, 78.2390159879412, 73.93575341360909, 31.93259014402117, 43.42770378930228, 33.17430966241019, 42.78613492420742, 40.34995058604649, 47.17330741882324, 49.22791058676583, 48.93236895969936, 47.9679068837847, 46.17136328560965, 37.10350554330008, 38.2199490410941, 28.654200758252824, 23.80936258179801, 14.969263315200806, 11.599083014896937, 8.347954017775399, 3.1648527809551785, 0.9087693329368318, 0.10941370390355587, 0.024246190208941698, 0.05520381439211113, 0.05885306053927966, 0.029243929710771357, 0.011820037616416812, 0.0768794221803546, 0.018563204977129186, 0.013624194377501096, 0.040483550168573856, 0.02486534832444574, 0.00502544705523178, 0.07515695425016539, 0.04807597365496414, 0.00794460012444428, 0.050364088732749224, 0.07035464301173176, 0.05118669369923217, 0.10331363337380545, 0.01770774195236819, 0.06705829274973699, 0.08211602975747415, 0.0026888852132417795, 0.07063416551266398, 0.015825741957607012, 0.02352850541605481, 0.06085854542574712, 0.008606553443574479, 0.029386761332196847, 0.04571465143401708, 0.008634630374477377, 0.059426144430679936, 0.0013656294384938, 0.026956922341404215, 0.04736462468281388, 0.03103476343676448, 0.06453654449433088, 0.013875690837656813, 0.04353590602321284, 0.03136385292080896, 0.041023087288652144, 0.08232739341578313, 0.06292349712124892, 0.02755057262921972, 0.047172687482088804, 0.02020996536261269, 0.043001345957496336, 0.014260594067828996, 0.021570344954462986, 0.014747670252940484, 0.052300380010690005, 0.05111587839201093, 0.06415676844439336, 0.03734561408470784, 0.07343781792691775, 0.037603535423321385, 0.046559607344014306, 0.031006485489862304, 0.05263612253059234, 0.06826942347522293, 0.07000674453697034, 0.023402045148291757, 0.042387868876435926, 0.033740340399422815, 0.009223093262075313, 0.05401860370433756, 0.050261609588882754, 0.03083101972671492, 0.06454288201140505, 0.011594875948503613, 0.07561037170567683, 0.01449321792460978, 0.028649444824882915, 0.09026508605373756, 0.017778752338407294, 0.019309696974232793, 0.07924155185797385, 0.020403972095144645, 0.024287417996674776, 0.033905550105763335, 0.013374184757204992, 0.02768833389771836, 0.07109559646674565, 0.055237323844007084, 0.049360667754496844, 0.031940166638897996, 0.017566493013873696, 0.041054147229130776, 0.02668545744381845, 0.00725813303142786, 0.01321166374587587, 0.06297058066619293, 0.029647865000047853, 0.03549216175451875, 0.060362135991454124, 0.018833736889064312, 0.01488116692884692, 0.0330011070306812, 0.031354879295187335, 0.007359137209797544, 0.059184830236647806, 0.03808565491012164, 0.005381557075972003, 0.03303354100457259, 0.0630614704319409, 0.013214496629578727, 0.04931708884292415, 0.014624733278261763, 0.035622620289879184, 0.01813236577436328, 0.05102145006614072, 0.060847749933600426, 0.013619023940658994, 0.010458492640671986, 0.041143659568790875, 0.006214345156747315, 0.05551090916352613, 0.041476616702441654, 0.06385921048266546, 0.04241826045992119, 0.1521790384181908, 0.4069307771112238, 1.3163854032754898, 4.387787844453539, 9.115147181919642, 20.029803105763026, 27.390240056174143, 32.70629290172032, 36.918078967503135, 35.248430320194785, 41.79741668701172, 52.558157852717805, 54.328472001211985, 44.97491822923933, 39.82362106868199, 39.76394993918282, 86.81028597695487, 41.381619112832205, 14.154405508722578, 21.513507536479406, 16.549572025026592, 20.856485877718242, 15.331057752881732, 23.919140645435878, 25.429216963904246, 29.092329842703684, 22.08498992238726, 22.525663784572057, 21.995820215770177, 32.65362555640084, 34.53558335985456, 27.184123482022965, 22.75557620184762, 22.89115466390337, 19.461694070271083, 84.54755646841866, 70.42639201028007, 21.90178155899048, 24.79763092313494, 21.012907198497228, 31.7081390108381, 33.89613022123064, 43.39939335414341, 46.18810149601528, 46.3005302974156, 48.427516324179514, 49.200166429792134, 46.995742729731965, 48.63122361046927, 38.53996917179653, 34.95528929574149, 25.450468029294694, 21.049671854291642, 17.97119951248169, 8.59811782836914, 2.664883860519954, 0.2403440246624606, 0.06501174292394094, 0.04043455654755235, 0.029469430646193878, 0.0491320659140391, 0.05324519591938172, 0.04783362808770367, 0.048847817416701994, 0.023396608386454836, 0.02927850785532168, 0.04268717406583684, 0.019387083893109645, 0.04197964524584157, 0.04852662608027458, 0.017453912179917097, 0.015553284702556474, 0.05731879108186279, 0.030309952329844236, 0.058227430896035264, 0.02761907922104001, 0.0366823494966541, 0.06551400133009468, 0.04851837848712291, 0.02655023898530219, 0.040342099365911314, 0.052861854167921205, 0.04057945430810962, 0.030698830927056924, 0.07821222102003438, 0.05534097006810563, 0.032597551721015146, 0.03722832930673446, 0.05631714786535927, 0.04879508167505264, 0.04034089157357812, 0.030394368871514286, 0.03212753729894757, 0.05912716154541288, 0.007623236609755882, 0.029838238177554946, 0.0672184880822897, 0.13208378957850592, 0.02675248482929809, 0.04337425523304513, 0.02792962603936238, 0.031981530133634806, 0.021165729433830296, 0.046598025996770175, 0.058282019038285525, 0.037674917307283194, 0.02476099133491516, 0.028115193492599895, 0.08948221270527158, 0.02062402948338006, 0.0584876626463873, 0.03313184715807438, 0.10647652258298226, 0.09420243477714912, 0.12483314078833375, 0.1405386616076742, 0.13783638232520648, 0.21208192833832332, 0.12387252519173281, 0.12562739316906246, 0.07251100015959569, 0.09071260025458676, 0.09673182333686522, 0.0793592030448573, 0.18241936287709645, 0.1661348616970437, 0.16482864107404435, 0.09824250691703387, 0.07277590023087603, 0.16258176735469274, 0.08714144331003938, 0.1887725405395031, 0.18107115450714314, 0.11242344775902373, 0.08615905352469001, 0.10831427361283984, 0.19186913009200776, 0.1827645336410829, 0.2183187779571329, 0.1298307276197842, 0.15546522422560624, 0.10333346695240055, 0.09589653994355883, 0.10221221497548477, 0.15227095277181693, 0.10051874763199262, 0.11605471612087317, 0.15900263083832605, 0.1469804695142167, 0.2265311958534377, 0.1262855857078518, 0.10728018624441964, 0.15601981803774834, 0.14822000371558325, 0.14116386377385684, 0.13525888563266822, 0.08751415581043277, 0.13419749401509762, 0.16186744639916079, 0.18642582717750752, 0.1141066692237343, 0.10808328672179154, 0.11536008625158242, 0.11398251088602201, 0.13745782763830253, 0.10025705024600029, 0.1423903972442661, 0.14507791160472802, 0.10832060434456382, 0.0844598864870412, 0.1076399115845561, 0.05978996812232903, 0.15348314201193197, 0.20777350238391332, 0.10181646621120827, 0.15627368512962544, 0.1274406151579959, 0.155222960082548, 0.6180099121161869, 2.2968095541000366, 6.381284645625523, 15.638006584984915, 23.984929663794382, 28.951420375279017, 35.872611318315776, 38.333388805389404, 46.87811320168631, 63.21657289777483, 66.25734778812954, 58.827187401907786, 59.4969242640904, 56.16219193594796, 79.66760730743408, 58.6349515914917, 47.00191273008074, 32.82484654017857, 38.841573102133616, 40.29061644417899, 30.345840454101562, 35.37922668457031, 40.13304172243391, 46.14310148784092, 32.59622996194022, 37.14872094563076, 34.82165806634085, 40.39925847734724, 40.11296837670462, 37.09021711349487, 43.49867268971035, 41.705888066973, 38.859718322753906, 86.95888710021973, 81.60638400486538, 43.89302464893886, 53.79981483731951, 44.59675209862845, 53.519812856401714, 53.810522011348176, 62.39549037388393, 64.6134317943028, 64.37921496800014, 65.74711377280099, 59.67618778773716, 50.63049479893276, 52.18864917755127, 40.12727819170271, 35.447093214307515, 24.866892303739274, 20.457049574170792, 14.314993143081665, 5.694018346922738, 1.547859862446785, 0.29115981076444897, 0.13308411304439816, 0.13518394822520868, 0.106630278618208, 0.15653790666588716, 0.1132462393226368, 0.16498713328370027, 0.1576245804982526, 0.10547738655337266, 0.1265662820743663, 0.10517644270190171, 0.07583372507776533, 0.22500753189836228, 0.12562651107353823, 0.07337459881923028, 0.1571343932300806, 0.17292245104908943, 0.12595071510544845, 0.21781853479998453, 0.1166923897606986, 0.16005457724843705, 0.1884036889033658, 0.20489542824881418, 0.15579679714781897, 0.15778896239187035, 0.07679853402078152, 0.16615600484822476, 0.11266704183071852, 0.1177069896033832, 0.1574844223048006, 0.10100506046520812, 0.1452331468462944, 0.11368741600641183, 0.1531256761934076, 0.11821323101009641, 0.1317628560853856, 0.16985498421958514, 0.11455626652709075, 0.14180441440216132, 0.18815051391720772, 0.20688467579228537, 0.18092852644622326, 0.18965247832238674, 0.14414367744965212, 0.16232912162584917, 0.16486217427466596, 0.08969979174435139, 0.09164046975118773, 0.11780730422054018, 0.12522004145596707, 0.14380244218877383, 0.15241767918424948, 0.11612938211432525, 0.12671971241278307, 0.22496854327619076, 0.1251712412174259], [0.03001136638756309, 0.002859521927478324, 0.007152485129024301, 0.034515841464911184, 0.016860718206901635, 0.04361227513956172, 0.045394026674330235, 0.004083210427779704, 0.037215705162712505, 0.056196182034909725, 0.029865681526384184, 0.042149906645395925, 0.03013097175530025, 0.040158240124583244, 0.0072876747498022655, 0.040175186536673985, 0.017060382225151573, 0.062165417442364354, 0.044749961234629154, 0.027960443403571844, 0.04068622179329395, 0.034107309100883346, 0.014293043308758309, 0.03083056171557733, 0.006489363881493253, 0.06157043044056211, 0.05375219049996563, 0.04574973847983139, 0.043544964465711794, 0.060630666225084236, 0.058613049132483344, 0.10708227115018026, 0.049130719022027085, 0.01819133894917156, 0.06750347957547222, 0.03381631596546088, 0.06780973635613918, 0.0324863262607583, 0.037419506548238654, 0.037320620247295926, 0.06790954207203218, 0.09484350787741797, 0.01414479612971523, 0.018060446151399186, 0.0032977745494073524, 0.014131246633561594, 0.07890005196843829, 0.03204584846805249, 0.030261521892888204, 0.004830971285368183, 0.08722590734916073, 0.010439330811745353, 0.01724024998423244, 0.011178199467914445, 0.04255928039284689, 0.04428976860695651, 0.08669224634234395, 0.03962866050590362, 0.028814824164978096, 0.05411334076364126, 0.044130947307816575, 0.05293457615854485, 0.03984764071979693, 0.016846245054953864, 0.020589989077832018, 0.02877791185996362, 0.10388972317533833, 0.03206246918333428, 0.024420151320685233, 0.0536776059307158, 0.15765708232564585, 0.2882127974714552, 0.19403073910091603, 1.068683317729405, 4.614850197519575, 16.14287485395159, 24.80488657951355, 38.633141040802, 49.88073900767735, 50.0125914982387, 45.21662868772234, 44.33329030445644, 44.78611135482788, 47.23661593028477, 42.69006565638951, 41.934855529240195, 50.26134743009295, 45.61161640712193, 46.34700332369123, 43.29663644518171, 46.169310092926025, 51.82227413994925, 50.37089620317732, 44.33538171223232, 40.92179775238037, 47.33176803588867, 52.81920167378017, 46.789999621255056, 45.43683099746704, 46.59356015069144, 48.47038670948574, 50.602535247802734, 51.74443347113473, 54.754254136766704, 48.76097079685756, 38.15766191482544, 34.02761098316738, 28.37211605480739, 23.776999609810964, 15.024520601545062, 12.15970710345677, 2.766811545406069, 2.808826650891985, 2.2439676352909634, 0.9005040707332748, 0.09328436332621745, 0.028299324147935425, 0.02198835984537644, 0.02765144534142954, 0.027222758791010295, 0.0329914175506149, 0.03173637882407222, 0.019501040456816554, 0.020079208271844045, 0.027734966216874973, 0.046438468487135, 0.04007496012906943, 0.02078110694752208, 0.005578612551159624, 0.029553328108574663, 0.008582589283053364, 0.013460799752335464, 0.03954608957948429, 0.03660818222644074, 0.03317342439134206, 0.04009011860138603, 0.01579899580350944, 0.030738742356853824, 0.03607342199289373, 0.024631625240934745, 0.0058420597093312866, 0.04837035946547985, 0.0064377413613588685, 0.021370894674743925, 0.017379907758108208, 0.05388682881104095, 0.05478741102186697, 0.08147912964757, 0.022319849647049392, 0.011706283765046724, 0.037584773930055757, 0.03667631053498813, 0.06723156345209905, 0.045171969304127355, 0.04281417207260217, 0.08518966447029795, 0.03166608938149043, 0.016800907041345323, 0.04857003875076771, 0.02182357252708503, 0.0789267998188734, 0.024239784838365655, 0.051193974379982264, 0.024001323884086948, 0.012114699929952621, 0.04877358568566186, 0.08318943823022501, 0.049351168264235766, 0.033142968347030025, 0.03594553849792906, 0.025006522624088184, 0.055807646097881455, 0.01856112526729703, 0.03127379436045885, 0.009602822662730302, 0.03523871874702828, 0.029884894245437214, 0.005727595516613552, 0.021127163199707866, 0.020035563203107034, 0.05049792976517763, 0.03658232664955514, 0.06536857770489794, 0.026760301552712917, 0.02678768552972802, 0.06397116876074246, 0.029763758781233003, 0.040796602477452586, 0.04819928721657821, 0.012146831955760717, 0.044606715706842284, 0.040725322373743565, 0.04483760081763778, 0.07133976729320628, 0.043699928293270726, 0.015207742440647312, 0.00839729918100472, 0.0372805188276938, 0.04317065740802458, 0.0526404583693615, 0.054916716047695706, 0.043933802350823364, 0.011429939352508103, 0.055823900404253175, 0.044299804139882326, 0.024797335366851518, 0.035192157674048624, 0.07581082452088594, 0.03817164904571005, 0.016825956857896278, 0.04090020798945001, 0.07598755575184311, 0.02131732094234654, 0.018214650019737225, 0.023979225694867115, 0.019983505996476327, 0.08347054171775069, 0.043489426374435425, 0.058585066348314285, 0.08179990707763604, 0.0068507359413030955, 0.05956433487257787, 0.06583186784493071, 0.020433335698076656, 0.008682463700616998, 0.020045583468994925, 0.048650160165769715, 0.06679448511983667, 0.04993956329833184, 0.032283878552594354, 0.053463877577866824, 0.058258901350200176, 0.01124450336543045, 0.036836539794291766, 0.005773298242794616, 0.030372509865888526, 0.06030698466513838, 0.015023562591522932, 0.06894206880990948, 0.029758045516375984, 0.04834643092804721, 0.08946676246289696, 0.030180348748607293, 0.13805238716304302, 0.03547453341473426, 0.12280613955642496, 0.9021896060023988, 1.2679717668465205, 2.9354202236448015, 6.012247579438346, 12.795326573508126, 27.55075560297285, 36.15726511819022, 48.90418011801583, 56.811664376940044, 53.97230734143938, 53.72467006955828, 48.06300687789917, 44.64864124570574, 41.07124655587332, 38.044989926474436, 37.8672376360212, 37.63643932342529, 37.48488868985857, 40.606592723301475, 40.688925402505056, 38.1577661378043, 40.58001238959176, 37.482335226876394, 38.83448246547154, 34.453202043260845, 37.05389887945992, 45.30289057322911, 40.98400844846453, 40.13347251074654, 55.93082039696829, 56.51423283985683, 45.624932629721506, 53.70097671236311, 52.41380555289132, 58.21067721503121, 48.134434359414236, 45.53544330596924, 41.27808747972761, 34.75939178466797, 27.284639596939087, 24.56025092942374, 10.540177549634661, 9.428922619138445, 6.781069227627345, 4.064630167824881, 0.8870510554739407, 0.3675805500575474, 0.10427847624357257, 0.07874229257660252, 0.06637317594140768, 0.03916978084349206, 0.048823349443929534, 0.008734363147855868, 0.03651755030399986, 0.020557258244869963, 0.05436738088194813, 0.04118208161422184, 0.02940774502764855, 0.03141793555447033, 0.016113281349784563, 0.029263573299561228, 0.021549476609964455, 0.05673791082309825, 0.011865960866478937, 0.056950733331697326, 0.09449964668601751, 0.029744647842432772, 0.014003432688436337, 0.018857543290193592, 0.017847174113350253, 0.032763412820973566, 0.05350609263405204, 0.007362878482256616, 0.047589039962206564, 0.0356688013832484, 0.057373691350221634, 0.022107520772676383, 0.04188507442761745, 0.022975606245121787, 0.04166528336437685, 0.07336938088493687, 0.054260355553456714, 0.0795307909803731, 0.0571564312226006, 0.02002833510882088, 0.05959284691406148, 0.05127132397943309, 0.010760504336628531, 0.036386715181704075, 0.06607979775539466, 0.05340270086058548, 0.0882934939914516, 0.025174460041203668, 0.06262177973985672, 0.01885901910385915, 0.025083373500300304, 0.026762768027505705, 0.03290593231629048, 0.03241134814119764, 0.02206745497616274, 0.05873042890535934, 0.008193075407429464, 0.02092777398814048, 0.037586039397865534, 0.008400698641448148, 0.043373176362365484, 0.14291048076535973, 0.10301148173000131, 0.09974227965410266, 0.17161027288862638, 0.23110294767788478, 0.14950832458479063, 0.1331563363117831, 0.12333072855004243, 0.07963433542421886, 0.11186936284814562, 0.11744340589003903, 0.11825397025261607, 0.1274018572377307, 0.12107605167797633, 0.1273155068712575, 0.0846553249284625, 0.1871285451842206, 0.19037046336701938, 0.1372590847313404, 0.0932662125144686, 0.13514391465910844, 0.15425194932946137, 0.142380097082683, 0.0954809779567378, 0.13860858231782913, 0.16779511475137301, 0.19297241446162972, 0.16810460814407893, 0.11098717232900006, 0.14239463130278246, 0.1384372522256204, 0.1892536354384252, 0.13340937559093746, 0.07091651750462395, 0.17393840796181134, 0.10142721781241042, 0.09030096020017352, 0.13404559716582298, 0.1059132774493524, 0.0771920368341463, 0.1605387662670442, 0.19285599142313004, 0.12200001281286989, 0.1411943571375949, 0.05856766871043614, 0.1576634741255215, 0.16588427871465683, 0.08086443120347601, 0.10658456571400166, 0.12422016582318715, 0.16824456277702535, 0.18550092966428824, 0.11850559817893164, 0.1892479086028678, 0.10380551697952406, 0.20996378628270967, 0.12992504398737634, 0.08903537025409085, 0.12319519796541759, 0.22152596871767724, 0.12355507936860834, 0.1568686789167779, 0.13816340906279428, 0.1183462238737515, 0.1809239802615983, 0.133956125538264, 0.24245277579341615, 0.16387258523276874, 0.21206290221640042, 0.16524391807615757, 0.3735462299415043, 0.6546761531914983, 1.7889624621186937, 4.258477526051657, 10.91383343083518, 23.838647501809255, 36.64777667181832, 55.57806035450527, 66.46942070552281, 69.58221367427281, 63.472363880702424, 61.78215203966413, 61.21312236785889, 61.27210562569754, 58.88199479239327, 56.081547669001985, 60.86711597442627, 58.560230663844514, 61.613067626953125, 57.35843549455915, 59.77558176858084, 62.28092152731759, 61.60836369650704, 57.50873892647879, 52.87013891765049, 58.720108713422505, 65.41922133309501, 60.57741778237479, 60.45432349613735, 59.63753495897566, 60.194738796779085, 64.98199204036167, 67.36003385271344, 68.84391893659318, 66.81315503801618, 55.63994101115635, 49.43908371244158, 39.963370186941965, 31.98276308604649, 22.553112643105642, 18.419990607670375, 7.234517787184034, 5.466708030019488, 3.4723372757434845, 2.0923199440751756, 0.3186530726296561, 0.22731957212090492, 0.07999182159879378, 0.22120970354548522, 0.14433990977704525, 0.08333336907838072, 0.13285862228700093, 0.04375893709116748, 0.10553141829690763, 0.15463449380227498, 0.21227324807218143, 0.13946034732673848, 0.12823781238070556, 0.16354127015386308, 0.11728700356824057, 0.09715028266821589, 0.10667029861360788, 0.09988750650414399, 0.08104338802929435, 0.12960359480764183, 0.13226293639412948, 0.10560942946800164, 0.05753748970372336, 0.1100321410756026, 0.07939836808613368, 0.08206215407699347, 0.14360631842698368, 0.07437959739140101, 0.10536220523395709, 0.1344105675816536, 0.14243815253887857, 0.11927075497806072, 0.21476229093968868, 0.14555110835603305, 0.1655773501843214, 0.17056665888854436, 0.07390966439353568, 0.1991059367677995, 0.08709754887968302, 0.16768501565924712, 0.16175121335046633, 0.13190115509288652, 0.05795513479305165, 0.10830508624868733, 0.14576994947024755, 0.21085873326020582, 0.17079339815037592, 0.17812720819243363, 0.13914932044489042, 0.13586347390498432, 0.16368089909000055, 0.13167041247444494, 0.13959562006805623, 0.11634757183492184, 0.14913717950029032, 0.187650949295078, 0.11309108550527266, 0.12319476370300565, 0.08447065483778715, 0.07180658581533603, 0.10200382330055748], [0.05110895394214562, 0.005654868861061654, 0.033204928772257905, 0.06747846198933465, 0.05255862365343741, 0.049651124847254584, 0.020288163130836825, 0.08306043515247957, 0.028806396760046482, 0.04253861900152905, 0.019890217609437447, 0.03870242627869759, 0.06519658943372113, 0.014059332947778915, 0.014577702319781696, 0.03837300431249397, 0.061397085099348, 0.019960512141031877, 0.006582631488397185, 0.02167131775058806, 0.007711893995292485, 0.03795840245272432, 0.04613436605515225, 0.008017620670476129, 0.016493193106725812, 0.027912533742242625, 0.03408453407298241, 0.05273825901427439, 0.0636445220027651, 0.1195588338055781, 0.0787605248125536, 0.03865178721025586, 0.021947959870366112, 0.09806459503514425, 0.04732692188450268, 0.0629490575354014, 0.02022279815615288, 0.04008495834256921, 0.0390587148389646, 0.019839578540995717, 0.0813397653400898, 0.08787441040788378, 0.050926065005894215, 0.020328593639922992, 0.04839492243315492, 0.06187227674360786, 0.030105275634144033, 0.07280374730804137, 0.06255098818136112, 0.041380559892526696, 0.026766601750361066, 0.03666054138115474, 0.02856556771855269, 0.061345835349389484, 0.022692882755239095, 0.05246143029736621, 0.04567392236952271, 0.06757879017719201, 0.05797612866652863, 0.027824677028028027, 0.019965251708137136, 0.027536538828696524, 0.01632939136054899, 0.04634506814181805, 0.03153531872002142, 0.03743053274229169, 0.031098396450813328, 0.016998284396582415, 0.020004586383168186, 0.030202506309641258, 0.0107854328650449, 0.10232793912291527, 0.040181293351841826, 0.07450459711253643, 0.12775048853031226, 0.21004837245813437, 0.9606327499662126, 3.409445656197412, 8.27385321685246, 19.669987167630875, 27.29340648651123, 36.17439242771694, 32.0287184715271, 32.10139315468924, 36.48664099829537, 49.76714985711234, 48.55805213110787, 45.8726532799857, 49.599152837480815, 52.71149417332241, 54.10573359898159, 48.63808843067714, 49.050578662327354, 48.52964789526803, 51.813078199114116, 49.3303895677839, 42.64504132952009, 49.429279804229736, 47.54075247900826, 45.417198862348286, 39.168260029384065, 36.960348333631245, 26.7962281363351, 21.527409144810267, 9.57121477808271, 3.8481229969433377, 2.4986942410469055, 0.8783330747059414, 0.390133018472365, 0.07322555181703397, 0.055497094190546443, 0.06365589424967766, 0.039139552108411274, 0.016979926631652882, 0.04294233037424939, 0.0062579088012820906, 0.03390345343255571, 0.030263496429792473, 0.03269094188830682, 0.02696992816137416, 0.018745057451139604, 0.026467813943911876, 0.10401767452380487, 0.14693933672138623, 0.09562670692269291, 0.011980586635347987, 0.1068424836599401, 0.011892879198837494, 0.026754729083872268, 0.03556158606495176, 0.08592708954321486, 0.05272431851231626, 0.022021792962082794, 0.013224177627957292, 0.013784159856316234, 0.08797451467918498, 0.0066640166748714235, 0.0557467238312321, 0.004372007230163685, 0.00977331306785345, 0.049524591636977026, 0.09474862832576036, 0.024671258471374, 0.012094165763950773, 0.04599039449489542, 0.03029165563306638, 0.04089482381407704, 0.016246730528239692, 0.0389649345140372, 0.0469133921100625, 0.055567210606698475, 0.02508601300152285, 0.04428876098245382, 0.022460598165967634, 0.043468476605734656, 0.06613200423972947, 0.03325502162000962, 0.02271778499042349, 0.0416687235369214, 0.03974283420081649, 0.0522936557286552, 0.05983560638768332, 0.025321557951558913, 0.02687811728433839, 0.027145037693636756, 0.0718461104801723, 0.042427787091583014, 0.029679355810263326, 0.06448258738964796, 0.07848033056195293, 0.01760779374412128, 0.022121885359021168, 0.017356776499322484, 0.03711559410606112, 0.05275742084320102, 0.050961671130997796, 0.02526515133545867, 0.012962491268159022, 0.034497605836285014, 0.02360903055939291, 0.05227730982005596, 0.017367105498643856, 0.044782907502459626, 0.04693469810964806, 0.011499345851396876, 0.03580912242510489, 0.06850459692733628, 0.0255902764786567, 0.03791962756908365, 0.08756181611014263, 0.026080738553511243, 0.07137499004602432, 0.031816306856593916, 0.06112507398107222, 0.030737466711018766, 0.02628249245961862, 0.04483067976044757, 0.02219665652540113, 0.029962603468447924, 0.002505304595355743, 0.06002643079097782, 0.03587935758488519, 0.052243627341730256, 0.053934078597064526, 0.031861314084380865, 0.023595390309180533, 0.07825630544019596, 0.05959597496049745, 0.02626526615183268, 0.05966613548142569, 0.04149386166994061, 0.07285170616315943, 0.05617722715916378, 0.013315225153097084, 0.06360519411308424, 0.052344769771609984, 0.03391713269853166, 0.006369018062416996, 0.056081523187458515, 0.010580706975555845, 0.021856379695236683, 0.07090604770928621, 0.005627034082343536, 0.006486958474852145, 0.07300472938056503, 0.11800713278353214, 0.05127343761601618, 0.04240581952035427, 0.034614229042615206, 0.07158701866865158, 0.03680119490517037, 0.08314319606870413, 0.019389945614550794, 0.040486335554825406, 0.07244563688124929, 0.017020715067961385, 0.056463589293083975, 0.04051342945812004, 0.037553412041493824, 0.04200943632583533, 0.02390282434810485, 0.014732896849246961, 0.010146105296111532, 0.035472569055855274, 0.08068713000310318, 0.026843021756836345, 0.024293528204517703, 6.946164311167584e-05, 0.036311156914702485, 0.05575600619028721, 0.23141295675720486, 0.7487387486866542, 3.122339359351567, 8.779978241239276, 17.999353613172257, 33.18125786100115, 40.04040486471993, 47.33232389177595, 44.66036980492728, 46.68027366910662, 46.182153838021414, 54.63167054312569, 59.138390268598286, 56.10649517604283, 59.1546698978969, 60.40657547542027, 62.95375728607178, 59.33802591051374, 61.89173902784075, 56.94634478432791, 61.42353466578892, 60.20389652252197, 56.63510022844587, 56.5417685508728, 56.02121993473598, 55.362725257873535, 51.64771802084786, 50.289703028542654, 39.443155084337505, 34.37696640832083, 20.096024649483816, 10.511250461850848, 6.421495607921055, 3.087790093251637, 1.9257781377860477, 0.44841236408267704, 0.18367263062724046, 0.10069623882217066, 0.009642146311567297, 0.041622908852462254, 0.10341765957751445, 0.04192545743925231, 0.029004668085170642, 0.05766531213053635, 0.026612676081380675, 0.043362418189644814, 0.018868559306221347, 0.023504356354741112, 0.04174603242427111, 0.025554975694311515, 0.01939098207679178, 0.01806629851593503, 0.01697320065328053, 0.026860760358561362, 0.015688496375722543, 0.011942104369934117, 0.01763236688982163, 0.02081419401136892, 0.03764376237190195, 0.011961457036834742, 0.015107178461870976, 0.03154525586536952, 0.04168416699394584, 0.045699431893548796, 0.018226000214261667, 0.05100919233102884, 0.022418439088921462, 0.06918856701148407, 0.023215110446991663, 0.062388784385153224, 0.04946868374411549, 0.03318523429334164, 0.04296901037118264, 0.05032511707395315, 0.05137645619522248, 0.034344429948500226, 0.01583542295598558, 0.04451333911025098, 0.0889536135696939, 0.04888990694390876, 0.011306175413275403, 0.0933402067582522, 0.0704087426087686, 0.058130827865430286, 0.02111350089710738, 0.03414788210232343, 0.0586053409746715, 0.016861081223136613, 0.01104927102902106, 0.056905963591166904, 0.029490580582725148, 0.03525164483913353, 0.04842617575611387, 0.0527828353723245, 0.05627091248918857, 0.07446938793041877, 0.008928506435560328, 0.05914001299866608, 0.06473490742168256, 0.050711712400828085, 0.08125640731304884, 0.04486945125141314, 0.1286607432578291, 0.08461983076163701, 0.12423573141651494, 0.14450131968728133, 0.1813556913818632, 0.10492488262908799, 0.08366234321147203, 0.17640144936740398, 0.10816994242902313, 0.12755026641700948, 0.11034350722495999, 0.09173180735004799, 0.12322183725024972, 0.16695025722895349, 0.15311215977583612, 0.1724827332156045, 0.1364732054727418, 0.16311490588954516, 0.1511538398585149, 0.1600253459598337, 0.11521831314478602, 0.11947408478174891, 0.13674243459744112, 0.10498124853308712, 0.14739038608968258, 0.11568437170769487, 0.09773256749446903, 0.1750566065311432, 0.15214623803538935, 0.12976644321211747, 0.16800187794225557, 0.06813219655305147, 0.12740200651543482, 0.26456047807421, 0.1654950710279601, 0.15054437970476492, 0.11606926391167299, 0.10384768114558288, 0.14990643465093204, 0.10877520923635789, 0.1568791147853647, 0.12345168420246669, 0.15066857875457831, 0.09767119400203228, 0.12826004118791648, 0.14662297655429157, 0.08123423278863941, 0.1444144264927932, 0.13237790736768926, 0.168550188520125, 0.20475073744143757, 0.14382693730294704, 0.16146819639418805, 0.11963637678750924, 0.08815737308136054, 0.13363318358148846, 0.1101532324350306, 0.17891954710440977, 0.33751770321811947, 0.051588481425174644, 0.10799046991659061, 0.13254823322807038, 0.10485533278967653, 0.07164301816374063, 0.1461901254951954, 0.07904923467763833, 0.13049679116478988, 0.1380521428904363, 0.15707348792680673, 0.1830045993306807, 0.06814644578844309, 0.21163967278386864, 0.10664982042674508, 0.11235864766474281, 0.18271324996437344, 0.39274901524186134, 1.5830104734216417, 5.305003472736903, 12.703782320022583, 28.51563630785261, 38.16441903795515, 49.99227843965803, 49.586256980895996, 53.437973499298096, 54.49476671218872, 66.85490676334926, 67.59554999215263, 65.38177749088833, 69.04085867745536, 69.37520599365234, 72.83980015345982, 66.35266317640031, 68.43682398114885, 66.82699584960938, 69.59973008292062, 67.43307331630162, 61.25394303458077, 64.26400688716343, 64.82781846182687, 65.37346049717495, 60.33982413155692, 52.990467820848735, 40.03181341716221, 29.368767397744314, 15.705718517303467, 6.964246324130467, 3.5772151223250797, 1.3213785524879182, 0.855286388524941, 0.3216433764568397, 0.111590844579041, 0.11392543252025332, 0.10614999796130828, 0.16516691792224134, 0.10872104178581919, 0.18591263757220336, 0.09261253901890346, 0.16831954089658602, 0.11917930202824728, 0.1704629244548934, 0.09180082114679472, 0.07669740516160216, 0.126159880310297, 0.17552536566342625, 0.19306187251848833, 0.1435403512524707, 0.19836702570319176, 0.11864065378904343, 0.12563291644411428, 0.11929687857627869, 0.17053624694900854, 0.12425766166831766, 0.11530445995075361, 0.0653360215947032, 0.0831507413781115, 0.14678016597671167, 0.1491123858307089, 0.09251288258071456, 0.09768516503806625, 0.1246209628880024, 0.10588668566197157, 0.17864780740014144, 0.1615094513233219, 0.1128102262903537, 0.16131799588246004, 0.08431455785674707, 0.13683557031410082, 0.10155864326017243, 0.09954231538410697, 0.1951333177941186, 0.19063901395670005, 0.137977286907179, 0.11263344756194524, 0.17248808007155145, 0.15747462425913128, 0.2420355581811496, 0.21686671301722527, 0.12826568659927162, 0.14247701902474674, 0.0924533750595791, 0.14275999526892388, 0.09443296704973493, 0.10167616552540235, 0.15133540225880487, 0.0984276451968721, 0.14764900292669023, 0.14136517154318945, 0.1906879906143461, 0.15673370473086834, 0.17959690147212573, 0.07711666516427483, 0.11359997998390879, 0.06797601814780917, 0.1775303552193301, 0.17903432808816433, 0.14589660481682845], [0.01626097297828112, 0.034021664410829544, 0.052802170227680884, 0.041621212514915636, 0.06585237317319427, 0.031044357921928167, 0.07099642857377018, 0.0985964239974107, 0.05915975158235856, 0.034388242954654355, 0.02120421763642558, 0.017393142583646944, 0.01606906800796943, 0.10200774523296527, 0.029442597978881428, 0.04727358563936182, 0.037173239048570395, 0.02176903697129871, 0.0738499600972448, 0.02808249997906387, 0.12854328884610108, 0.03482121615005391, 0.07207186586622681, 0.008000688677254533, 0.005267226469836065, 0.06993928458541632, 0.05970459484628268, 0.03965869585850409, 0.0067476821630927065, 0.05129543572132077, 0.02554358309134841, 0.029728868510574102, 0.02116714757201927, 0.02748597609544439, 0.037505297123321464, 0.028821032760398727, 0.04953774843098862, 0.02524564684634762, 0.02407550302866314, 0.05082404387316533, 0.01446023433735328, 0.022923491363014494, 0.03981284544404064, 0.05388531567794936, 0.048593658554766855, 0.03696362940328462, 0.025858518334903886, 0.025839648276035274, 0.06820158354405846, 0.0239659552462399, 0.05392286580588136, 0.02230475902823465, 0.009965144247481865, 0.0654680034411805, 0.06971966994128057, 0.030975137172000747, 0.025783173806433166, 0.01727269243981157, 0.020153648652402417, 0.03401319290112172, 0.02352583877343152, 0.027932017875303115, 0.0692252553999424, 0.08772154325353247, 0.06897752226463386, 0.010959583966593658, 0.030475884675979614, 0.00908055849972048, 0.05741229999278273, 0.030541655075337206, 0.07377753326935427, 0.013628732928607081, 0.05938721687666007, 0.054771838643188984, 0.1078255587656583, 0.08475810941308737, 0.03618050499686173, 0.02262939901889435, 0.013955447540086294, 0.04117369831406644, 0.42946549504995346, 1.5112109375851495, 3.116961887904576, 3.3537606213774, 7.7046255213873724, 8.66999694279262, 8.108923826898847, 6.655609514032092, 8.611525246075221, 8.489859683173043, 10.58082103729248, 8.992121509143285, 6.565050167696817, 7.431568264961243, 6.432577550411224, 5.6948786207607816, 4.432514267308371, 6.692957818508148, 6.049228497913905, 4.170703538826533, 2.7431131941931586, 1.1386258389268602, 0.4947835015399115, 0.1126068082771131, 0.022901571289237057, 0.06628875939973763, 0.08594169840216637, 0.07153677993587085, 0.03413011466286012, 0.057090260487582, 0.04931473432640944, 0.0180623714945146, 0.07368354938392128, 0.04693176005301731, 0.010463852219150534, 0.028768578610782112, 0.0867111435426133, 0.03747517016849347, 0.03874402047534074, 0.006750459067656526, 0.021248374999101673, 0.04556831857189536, 0.007150988959308181, 0.008071007805743387, 0.039807400200515985, 0.07739282213151455, 0.02651216638540583, 0.06136032207203763, 0.008940800641929465, 0.01686695564006056, 0.01705929826545928, 0.0760891731562359, 0.046835764311254025, 0.030054463539272547, 0.025149931000279527, 0.055574375936495404, 0.021286603662052324, 0.06564936228096485, 0.010820759942622056, 0.04925547447055578, 0.06400976383260318, 0.03645085031166673, 0.026070731858323728, 0.09104673803916999, 0.021557186464113847, 0.04605785105377436, 0.06192324150885854, 0.06803444679826498, 0.006859168859331736, 0.04200642363035253, 0.02144611537057374, 0.0339867436060948, 0.030565977163080658, 0.04362913334210004, 0.026599551517782465, 0.02976552297228149, 0.011740841553546488, 0.05343141646257468, 0.055757315762873204, 0.04797604919544288, 0.07854635201926742, 0.017150768178648183, 0.05783248280308076, 0.060575718459274085, 0.022395721736497114, 0.008634280928942775, 0.06757644923137766, 0.047737924115998406, 0.08255123533308506, 0.07931760884821415, 0.030918689843799387, 0.03638206043147615, 0.013677712130759443, 0.035284350227032385, 0.0378183460395251, 0.022914719601560916, 0.006045185104345104, 0.03234408496479903, 0.0770922311182533, 0.026728666553805982, 0.048998849133827856, 0.025744643195399215, 0.0374530193928097, 0.01593992074153253, 0.05287352157756686, 0.031272864767483304, 0.012020978976839354, 0.016586708802995936, 0.03235642073143806, 0.01630241111186998, 0.01650567475839385, 0.012497040842260634, 0.026571899519434998, 0.06156282406300306, 0.03956595029948013, 0.04013188921713403, 0.04638762246551258, 0.02125536390979375, 0.036996562100414715, 0.014539256525625075, 0.03650704658191119, 0.040921327391905446, 0.02786718724694635, 0.011369456437283328, 0.026298634807712266, 0.014296086538316948, 0.04454518275867615, 0.016071756702980826, 0.04743779789922493, 0.07270858277167593, 0.011671770081323172, 0.0392930095882288, 0.007249488495290279, 0.03409639486510839, 0.06342308888477938, 0.01282346113917551, 0.02607976146308439, 0.04769918994445886, 0.05104120561320867, 0.014442295567797763, 0.13535141066781112, 0.08005554960774523, 0.027679394198847667, 0.016371764176126038, 0.055794170392411094, 0.03111481699826462, 0.032396369480660984, 0.03235375748148986, 0.04409672539415104, 0.006609771616889962, 0.012779452206034745, 0.041096596379897425, 0.10103964539510862, 0.03471939518515553, 0.07909221987106971, 0.01563562492706946, 0.02125456663114684, 0.01398611647476043, 0.048931518103927374, 0.06300933858645813, 0.05695736261882952, 0.02688263463122504, 0.06516655747379575, 0.007903450368238347, 0.01592688778016184, 0.011419586604461074, 0.06391705559300524, 0.013852056614788515, 0.03612781335998859, 0.10631830857268401, 0.02898176752829126, 0.03758807161024638, 0.03271517237382276, 0.04081288731790014, 0.10477443105940308, 0.5413046766604696, 1.8741571477481296, 6.021844344479697, 8.160220640046255, 9.401667441640582, 16.515082904270717, 19.546562841960363, 18.048638922827585, 15.620533602578298, 18.697098663875035, 19.326720101492747, 21.487014055252075, 19.121465103966848, 15.655324969972883, 16.90199681690761, 14.06526185785021, 13.689564074788775, 11.290989467075892, 14.95530264718192, 13.935979332242693, 10.896248408726283, 7.783662148884364, 4.33293833051409, 2.104448241846902, 0.4285353049635887, 0.10444180640791144, 0.012845644145272672, 0.038180341079298935, 0.0406911174234535, 0.05160660170284765, 0.028766173204141002, 0.01825893291139177, 0.032351226545870304, 0.043275877833366394, 0.05241507278489215, 0.04646360142422574, 0.03162274456449917, 0.08362051152757236, 0.04842615540006331, 0.05421180637287242, 0.04249941324815154, 0.05297510166253362, 0.03564895084127784, 0.033632212451526096, 0.03779984578224165, 0.01926187382611845, 0.08503200685871498, 0.06654957469020571, 0.01995579632265227, 0.029047273298991576, 0.04790129159976329, 0.0352951898239553, 0.011769193291131939, 0.03185814193316868, 0.007109957522646124, 0.045037836501640935, 0.022928800899535418, 0.04656580576140966, 0.07312559682343688, 0.02412233212297516, 0.04476609679737261, 0.0746058209666184, 0.05182364469926272, 0.05575579584443143, 0.016174251113885214, 0.060331235506704876, 0.06764000082122427, 0.040776229463517666, 0.09554791543632746, 0.0760577976969736, 0.014146316896325775, 0.05158697507743325, 0.08081345965287515, 0.016902653367391655, 0.05004727394719209, 0.05468848400882312, 0.029212350691003457, 0.04072251323876636, 0.04112413472362927, 0.058027466626039574, 0.018049465758459907, 0.0639898216884051, 0.007018273022757577, 0.04898487809779389, 0.03324416166703616, 0.03595632041937538, 0.03495023958384991, 0.06654454674571753, 0.037226239418877025, 0.09298820314662797, 0.03493754419365099, 0.041964344281171045, 0.02708738766211484, 0.06463896257004567, 0.050646199844777584, 0.08844419661909342, 0.06988997544561114, 0.13031915069690772, 0.11426404863595963, 0.14878292993775435, 0.1464414820075035, 0.1468310018203088, 0.16462571839136736, 0.260577884635755, 0.14274665527045727, 0.2196695783308574, 0.1213554045451539, 0.07910156329827649, 0.13326623184340342, 0.1456648986786604, 0.1301452557423285, 0.09382002601133925, 0.1081534336720194, 0.15692729077168874, 0.1064452285479222, 0.10455571886684213, 0.12370340712368488, 0.15217375941574574, 0.11160337033548526, 0.1517615629626172, 0.11856605564909321, 0.08783896373850958, 0.13247700062181267, 0.24568569660186768, 0.10804176037865025, 0.08497055872742619, 0.10339880987469639, 0.1122190865821072, 0.09379048938197748, 0.1303162058549268, 0.1312555425933429, 0.14316309935280255, 0.23202038130589894, 0.17201843884374413, 0.1378081552684307, 0.20122478449983255, 0.1317056148712124, 0.14292950688728265, 0.09978818254811422, 0.15344905241259507, 0.09809004688369376, 0.18869300266461714, 0.184228405090315, 0.1750199520694358, 0.1989075466990471, 0.16685816645622253, 0.18630222523851053, 0.12318609202546732, 0.12136451048510415, 0.14205613732337952, 0.1138642965150731, 0.1897269543260336, 0.1711403059640101, 0.14573037730795996, 0.09950444634471621, 0.22777269780635834, 0.09040497283318213, 0.10128753459347145, 0.09476381393947772, 0.09590192072625671, 0.1987664656979697, 0.14707004970737866, 0.0782691433227488, 0.183371632492968, 0.1039786451895322, 0.08591121182377849, 0.12135860723044191, 0.20244597111429485, 0.1875769075538431, 0.1911723017692566, 0.1897530643535512, 0.23425281580005372, 0.12499944972140448, 0.08014386094042233, 0.10787300871951239, 0.1293318143912724, 0.1959517803043127, 0.7691371398312705, 3.174646266869136, 5.347788742610386, 6.443794548511505, 12.319209081786019, 13.584622825895037, 13.313987016677856, 11.700715184211731, 13.86869558266231, 13.555998853274755, 14.934468473706927, 14.115220274244036, 11.334504297801427, 11.495523588997976, 9.76994628565652, 8.910230040550232, 8.318384221621923, 10.151114906583514, 10.009557519640241, 7.981605904442923, 5.227766862937382, 2.859359162194388, 0.9113300698144096, 0.3141747143651758, 0.126235089131764, 0.2174056733825377, 0.2084434200078249, 0.14389385442648614, 0.1020301708153316, 0.10199827288410493, 0.10838219496820654, 0.12567945037569317, 0.29513388180306976, 0.11111730856022664, 0.1338213684835604, 0.09908162403319563, 0.14223661406763963, 0.16868194645004614, 0.15983855883990014, 0.15081898282681191, 0.14304567208247526, 0.09472900509302105, 0.10986941480743033, 0.08518298768571445, 0.14697966884289468, 0.1563437913677522, 0.13256697436528547, 0.14080099681658403, 0.1575346746082817, 0.15824221021362714, 0.09532979356923274, 0.22126541127051624, 0.1169963598783527, 0.19025686303419725, 0.16038023334528717, 0.08763083669223956, 0.11527583934366703, 0.1973908987960645, 0.16036217074309075, 0.13365909004850046, 0.1859404846493687, 0.07716915663331747, 0.12424310030681746, 0.2067040361996208, 0.12739110924303532, 0.18501070168401512, 0.08973735544298377, 0.31788214828286854, 0.11307589310620512, 0.10680229403078556, 0.10748988749193293, 0.21128621032195433, 0.11316486940320049, 0.1499010335121836, 0.13866237657410757, 0.11963678390852042, 0.09170625372124569, 0.0882610600175602, 0.1662513254476445, 0.11864973258759294, 0.21090830702866825, 0.09358326478728227, 0.11425161787441798, 0.18862991247858318, 0.10101524527583804, 0.1124383212466325, 0.17115287243255548, 0.11734424478241376, 0.13805924036673137, 0.1836245089237179, 0.14449878196631158, 0.1058249254045742, 0.12837180947618826, 0.1260342291955437, 0.17720726398485048, 0.12045835410909993], [0.004726893767448408, 0.012058562183353518, 0.04175022237801126, 0.03039287609447326, 0.034361006559005806, 0.03773329167493752, 0.048904919531196356, 0.04548312850030405, 0.013354334215234433, 0.012344359436870685, 0.08199439557003123, 0.07856142906738178, 0.04401805943676403, 0.06544245659772839, 0.0767057172155806, 0.03692682566387313, 0.027051868050226142, 0.04126029295314636, 0.04813716055027076, 0.014480251120403409, 0.05795357416250876, 0.09200398131672825, 0.02912020224279591, 0.05764520035258361, 0.03132581424766353, 0.027370706566476395, 0.0336993806330221, 0.02812248095870018, 0.01596608165917652, 0.02136006355950875, 0.02363183442503214, 0.03118909622675606, 0.012409557322306293, 0.025831840034308176, 0.01871429436973163, 0.06229778605380228, 0.01199662550685129, 0.043510399891861846, 0.0162390461191535, 0.0701628008059093, 0.03695843521771686, 0.07194330383624349, 0.04373990757656949, 0.08623433019965887, 0.011590156737448913, 0.011464256261076246, 0.02060117133493934, 0.03328551159107259, 0.05754998153341668, 0.08062935953161546, 0.03696660477934139, 0.036361253155129294, 0.03488881180861166, 0.017128893905984502, 0.05465935110779745, 0.020341991313866208, 0.03654145848538194, 0.00897873583848455, 0.058404501394501755, 0.08887367535914693, 0.0298082401443805, 0.05527323870254414, 0.05303069403661149, 0.10838247995291438, 0.011512266006320715, 0.05780149410877909, 0.043959813990763257, 0.0233240577259234, 0.06634802943361656, 0.04192870083664145, 0.027946618252566884, 0.07218375629080193, 0.13714228171323026, 0.04968837981245347, 0.06769021241260426, 0.026994380867108703, 0.054834959363298755, 0.07599282118358783, 0.011932429308736963, 0.028180707744987946, 0.02587911017638232, 0.04075257234009249, 0.08708372712135315, 0.06701916163521153, 0.039775505661964417, 0.027786648532907878, 0.05810157622077635, 0.036440010714743815, 0.10342732191618, 0.09145765206111328, 0.0997132451406547, 0.060438016562589576, 0.08812154643237591, 0.12651830964854785, 0.03314945174913321, 0.08865329397044011, 0.20637491957417556, 0.02342624170705676, 0.09601959905454091, 0.06647330056875944, 0.04515872769323843, 0.023442892956414392, 0.029374910718096153, 0.06924574715750557, 0.06669119173394782, 0.05213224242574402, 0.06917505737926279, 0.04042676018018808, 0.021264539399583424, 0.08582625245409352, 0.043144401495477984, 0.03402874492374914, 0.05593772465363145, 0.043175078063671074, 0.024089331572343196, 0.02133061513969941, 0.06526890769600868, 0.01678092757772122, 0.016543889850644127, 0.0640553885272571, 0.014557609201541968, 0.06037787800388677, 0.002442642522510141, 0.0010515112995303103, 0.04126491377662335, 0.06834600972277777, 0.034644963286284886, 0.03368157248145767, 0.054830545493002446, 0.03083495862249817, 0.03992395555334432, 0.057838148570486476, 0.02398562428009297, 0.08158093025641781, 0.01437415199221245, 0.009026064504204052, 0.012131966101670904, 0.06196901548121657, 0.018168317952326367, 0.008025820766176497, 0.06961419845798186, 0.05163367185741663, 0.02510783977673522, 0.030083816964179277, 0.01929491848152663, 0.06338493486068078, 0.017726194712200334, 0.09396642672696284, 0.07641313970088959, 0.03506024707374828, 0.029281578226281062, 0.09672628649111305, 0.02778750009435628, 0.013317175941275699, 0.039854164834001234, 0.04245125761787806, 0.038450557472450395, 0.03592491103336215, 0.022666284182508076, 0.006189768194287483, 0.012405821987028633, 0.014796400941642267, 0.04473103689295905, 0.030029401848358766, 0.021871103905141354, 0.05024032733802285, 0.03470873200733747, 0.015756158191444616, 0.037710686280791245, 0.04251621377521327, 0.015223221520760229, 0.019231711248201982, 0.054882182007921596, 0.04551069737811174, 0.0759402211489422, 0.0323577540527497, 0.04772760699103985, 0.0936610588271703, 0.016417353247691478, 0.05385355684640152, 0.020971322365637337, 0.024577267800590823, 0.09817181713879108, 0.04249420888455851, 0.0549020596912929, 0.05081203041066017, 0.031728897975491624, 0.06072211917489767, 0.05534226267731615, 0.0245671881628888, 0.02753960750331836, 0.05920190896306719, 0.009157489951966065, 0.009542914805933833, 0.035393384019179006, 0.03311181001897369, 0.0740634204287614, 0.042674132622778416, 0.03521689027547836, 0.023811966812770282, 0.053108399866947105, 0.017457086027466824, 0.043131363445094655, 0.04372800946501749, 0.052942650725266764, 0.1016228733850377, 0.029487503426415578, 0.06609538370477301, 0.024071540384154235, 0.05014432141823428, 0.05115222751295992, 0.06461684232843773, 0.0255336968361267, 0.033481167163699865, 0.006525500112080148, 0.042719085567763875, 0.08229842675583703, 0.037676233665219376, 0.026403890856142555, 0.02697939033220921, 0.05715263821184635, 0.01521588655720864, 0.048414420136915784, 0.015628914215735028, 0.04328403043161545, 0.03527450129123671, 0.06683799957058259, 0.04084618642394032, 0.007772953665283109, 0.016716095253026912, 0.036144732630678585, 0.040635063645562956, 0.03476944732080613, 0.027950782761243836, 0.024114016676321626, 0.08090875989624433, 0.007758907990397087, 0.036902873377714834, 0.05720766740185874, 0.04077752546540328, 0.008057244571058877, 0.05181392129244549, 0.041585457112107954, 0.05303296373624887, 0.03914227981918624, 0.04564829410186835, 0.036574241904807944, 0.08248311041721276, 0.030430765489914587, 0.08274002413132361, 0.08494403479354722, 0.04143865606082337, 0.0723293631204537, 0.025112486045275415, 0.004965421727060207, 0.03356629616713949, 0.021873041122619594, 0.01037213803335492, 0.060841405631176064, 0.038640754230852635, 0.03444352320262364, 0.033019047496574264, 0.05554501572623849, 0.10343025318746056, 0.13343954325786658, 0.18977453320154122, 0.17667968943715096, 0.1366246816303049, 0.07629152586949722, 0.0870891757575529, 0.09238632901438645, 0.05333112220146826, 0.057115135581365654, 0.022564011991822293, 0.06245454799916063, 0.06190786590533597, 0.038559078970657926, 0.023597420825223838, 0.03245794653360333, 0.03652301590357508, 0.08489732444286346, 0.05439491244032979, 0.054114138042288165, 0.025033194139333706, 0.06040280059512172, 0.013047477779244738, 0.006923529178103698, 0.09438018381063427, 0.04728890356740781, 0.008259942489010947, 0.021217150513881018, 0.010087390812779111, 0.057373284229210446, 0.027192601302106465, 0.02384385117329657, 0.05368003847875765, 0.028605591106627668, 0.025707045570015907, 0.049086329261107106, 0.07096442886229072, 0.01249851580775742, 0.04218730071027364, 0.06415955043796982, 0.03383209868999464, 0.03246246896950262, 0.019109595300895826, 0.06205187139234372, 0.06052789531115975, 0.046423038600810936, 0.03726971994287201, 0.02118333911390177, 0.0124764744458454, 0.025743313266762664, 0.021877719621573175, 0.007842310122214258, 0.051074284195367775, 0.0366311404587967, 0.008734754153660365, 0.04377331864088774, 0.04086410992645791, 0.028602680191397667, 0.04534050043938415, 0.048430284285651784, 0.028830287978053093, 0.0718424938885229, 0.009699512206550156, 0.033830700907856226, 0.07018494818891798, 0.09549013817948954, 0.0551454434171319, 0.042827959904181104, 0.02829029454317476, 0.0630670887018953, 0.012553617092115539, 0.009534487401002219, 0.029984404798597097, 0.026240014471113682, 0.03579930402338505, 0.03886872503374304, 0.011043267690443566, 0.045777904468455484, 0.02180482290818223, 0.04464479848476393, 0.02614764210634998, 0.05544665528993521, 0.020722450987835015, 0.01967514236457646, 0.033384299504437616, 0.06494998945189373, 0.07897306233644485, 0.05194257492465632, 0.030493580869265964, 0.10054522406842027, 0.22951669565268926, 0.13702306311045373, 0.09683938470802136, 0.11946871078440122, 0.08803797127412898, 0.1958638285951955, 0.22255764050143106, 0.17804957021559986, 0.06743351582969938, 0.18215469350772245, 0.12574293411203794, 0.10794055009526865, 0.0978130010355796, 0.23886017714227947, 0.12913171441427299, 0.08891625343156712, 0.0866843821214778, 0.11673615526940141, 0.09751646766172987, 0.14592236200613634, 0.16944873173321995, 0.1612830241875989, 0.16757852637342044, 0.10621787181922368, 0.0950371753424406, 0.15977493939655169, 0.1313363696847643, 0.17679202769483837, 0.17188115763877118, 0.08979311066546611, 0.14204988123050757, 0.10043528782469885, 0.18595510029367038, 0.1204417028597423, 0.21860635466873646, 0.09779105042772633, 0.10455107090196439, 0.0494467365289373, 0.15815231789435658, 0.15725752019456454, 0.16518293134868145, 0.061714490210371356, 0.11805522734565393, 0.11484659809087004, 0.10536065138876438, 0.10027879050799779, 0.09062846191227436, 0.1115970735305122, 0.18719905854335853, 0.14875747130385467, 0.08821123519114085, 0.1996918110443013, 0.11225662992468902, 0.20558007008263043, 0.05632590775245002, 0.09049690075750862, 0.1109521599220378, 0.12783154632364, 0.17584545777312346, 0.098710540016847, 0.14721543262047426, 0.21241605255220616, 0.17821616413337843, 0.06420739394213472, 0.13292859281812394, 0.14345869634832653, 0.16697928495705128, 0.10234334865318877, 0.12100309559277125, 0.1515993523810591, 0.2516110986471176, 0.21704272500106267, 0.17608674482575484, 0.15981014179331915, 0.18086272212011473, 0.13882253797990934, 0.09878682770899364, 0.06478992304099457, 0.11669054414544787, 0.14236017529453548, 0.15372532473078795, 0.14381945984704153, 0.11632720221366201, 0.10817824769765139, 0.11146374818469797, 0.13024133630096912, 0.12958572219525064, 0.14197351889950888, 0.23645957452910288, 0.18214471904294832, 0.10821226944348641, 0.18450986141605036, 0.15755887116704667, 0.13168273467038358, 0.12337870097586087, 0.32186721158879145, 0.2035044857433864, 0.2139739418136222, 0.15815824829041958, 0.10304681304842234, 0.12673780215638025, 0.148119716239827, 0.16306487071727002, 0.22524576554340975, 0.2191342277718442, 0.16149765838469776, 0.10993967710861138, 0.11673030629754066, 0.14505522139370441, 0.1268773360976151, 0.131850197112986, 0.08862230527613844, 0.1776374823280743, 0.10857922118157148, 0.1230147076504571, 0.18034806687917027, 0.21132559249443666, 0.13857369204717024, 0.15759790050131933, 0.09490281862339803, 0.17699093345020497, 0.12627197429537773, 0.127488248316305, 0.0779041593362178, 0.08094131600643907, 0.08214986829885415, 0.09811247925141028, 0.1018093212374619, 0.09515632609171526, 0.1422581507691315, 0.134518101811409, 0.14973775084529603, 0.10878376556294304, 0.169829254171678, 0.1189991645514965, 0.11300769355148077, 0.1323765367269516, 0.11270026969058172, 0.08378723436700446, 0.143196917538132, 0.11363096867821046, 0.14230822665350779, 0.16781974557254994, 0.10681992237057004, 0.15355132121060575, 0.08228210798863854, 0.10456960847867386, 0.13805227859744004, 0.1112136198207736, 0.07367025688290596, 0.29053724131413866, 0.1608220139252288, 0.09998912390853677, 0.23056565650871821, 0.08361540894423213, 0.16721299955887453, 0.1395726584430252, 0.1062454203409808, 0.12808915892882006, 0.11836978260959898, 0.08300541274781738, 0.2169193944760731, 0.1250847415732486, 0.10226660634257964, 0.17664106722388948, 0.09945475722530059, 0.169363372027874, 0.0958424878439733, 0.0644096245190927, 0.11314120888710022, 0.1470653542450496, 0.15828733279236726, 0.09457396662661008, 0.18605681269296578, 0.10019043167786938], [0.05626447997721178, 0.012268087011761963, 0.03135028900578618, 0.03472129847588284, 0.01797411953365164, 0.0165733721972044, 0.026432575924055915, 0.012899842129887214, 0.0614757001666086, 0.013483014140677239, 0.020296037529728243, 0.034549615545464415, 0.08385509465421949, 0.030079284350254705, 0.022255356589864408, 0.10536190667854888, 0.07664741748677832, 0.04112225178895252, 0.03561796893232635, 0.046834922927830896, 0.03612067177891731, 0.021479361890149967, 0.03688382011439119, 0.02946313044854573, 0.03802903794816562, 0.002055303139578817, 0.04314371617510915, 0.050594247811074765, 0.026921124530157874, 0.08133365173957177, 0.04937883892229625, 0.019085568375885487, 0.02643150044605136, 0.049977683395679505, 0.04827241293553795, 0.028074238815211823, 0.06587618975234882, 0.032493589978132925, 0.037533995761935196, 0.01707887400074729, 0.030330389804605926, 0.05958562730146306, 0.030904247225927453, 0.07655590346881322, 0.033178493047931364, 0.0532115677238575, 0.021457329858094454, 0.019004826101341417, 0.011012510546217007, 0.007632670791021415, 0.05366724470098104, 0.1544730296092374, 0.04260476598782199, 0.016274100934554423, 0.037272033747285604, 0.06293514756751911, 0.03661128313147596, 0.0222523472870567, 0.06557174466018166, 0.03348482107477529, 0.03565503730039511, 0.0006629368238334012, 0.04190117606360998, 0.06280292823378529, 0.034773148729332855, 0.030060241264956336, 0.034329739665346484, 0.006814278254751116, 0.016611529613978097, 0.06719771812536887, 0.02147510408290795, 0.010881611811263221, 0.06428670111511435, 0.06982968760920422, 0.02147479195679937, 0.009729035265211548, 0.060895152390003204, 0.03220850349004779, 0.046513544994273355, 0.011808469442517629, 0.08278279219354902, 0.02781757276638278, 0.026690310665539334, 0.026814413024112582, 0.004708069933777941, 0.05541638245007821, 0.03613864277888622, 0.04150978349415319, 0.019811027483748536, 0.09903543615447623, 0.07547881055091109, 0.023531855682709386, 0.12912707323474543, 0.05144539535311716, 0.01365957488971097, 0.04128940549812146, 0.03650564540709768, 0.10800882428884506, 0.006929172044952533, 0.024095528293401003, 0.023126682067023854, 0.022280162133808647, 0.008238553368885602, 0.022484799813745276, 0.021660924290439913, 0.036920912231185606, 0.08256539635892425, 0.014393291768750973, 0.049706669723881144, 0.11119449870394808, 0.04863346820431096, 0.04428037768229842, 0.011386485969913858, 0.032737316364156346, 0.009051725850440562, 0.0666382863585438, 0.04230685858055949, 0.044196195235209804, 0.0509463023128254, 0.03493473845134888, 0.02523356213766549, 0.00914070469194225, 0.07397905816989285, 0.08931275536971432, 0.0644873846322298, 0.09100933040359191, 0.08335766741739851, 0.0071113637864722735, 0.025099339429289103, 0.009247339862797941, 0.032005998106407266, 0.0311026271166546, 0.018337597172441225, 0.03373834889914308, 0.034129419164466004, 0.025429097270326953, 0.03463072422891855, 0.02073153487539717, 0.08014481088944844, 0.028713288184787546, 0.0644652508199215, 0.0037585950340144336, 0.03145125162388597, 0.06076444618936096, 0.03085163701325655, 0.04181225744209119, 0.04399079929238983, 0.010931972680347306, 0.08936227485537529, 0.015333639524344887, 0.04569409182295203, 0.0305046579534454, 0.0733032033645681, 0.010126460010984113, 0.04658393282443285, 0.0009045756014529616, 0.03913158949996744, 0.08080391945051295, 0.038565942352371554, 0.06044459156692028, 0.005554874851700983, 0.03483015245624951, 0.08366965103362288, 0.022576497036165426, 0.0581102886104158, 0.06856545473315886, 0.01951013961141663, 0.06314225681126118, 0.029999251144805124, 0.045970035051660876, 0.016909635492733548, 0.0786654417003904, 0.04840756693322744, 0.04492455847295267, 0.060008938158197064, 0.03702218358271888, 0.04737175947853497, 0.06582194087760788, 0.04326417310429471, 0.04601426535685148, 0.07164091470518283, 0.01238486628114645, 0.02946743575323905, 0.0307605945771294, 0.020767188497952054, 0.03659708478621074, 0.020756783163441078, 0.028540458530187607, 0.050021442119032145, 0.009824135340750217, 0.06565784396869795, 0.07788239193281957, 0.06179272529802152, 0.027527314145117998, 0.028246454395619885, 0.026665800284328203, 0.022924870485439897, 0.014897952188870736, 0.01625114948754864, 0.04590580831947071, 0.010036040978905345, 0.007531700539402664, 0.02482364047318697, 0.07723850969757352, 0.014626349887943693, 0.02703385124914348, 0.07412258868238755, 0.026250033040664027, 0.04284289785261665, 0.04178920421483261, 0.015132160424920065, 0.03989849013409444, 0.034193082712590694, 0.003123382992011362, 0.0398196918623788, 0.03692995710298419, 0.044868793072445054, 0.006247061570840222, 0.018109721364453435, 0.0365852070307093, 0.0508144222466009, 0.020983868478132144, 0.014718262545232261, 0.06570547034165689, 0.014799508632027676, 0.04215444604467068, 0.02149864924805505, 0.04625486369643893, 0.02115110700417842, 0.04307011208896126, 0.04970865443881069, 0.034209303092211485, 0.05694593608911548, 0.032221154775470495, 0.025305447833878652, 0.023344206823302165, 0.0313746280569051, 0.0375609064607748, 0.022386702309761728, 0.010460209334269166, 0.028111432712259035, 0.022067171687792455, 0.039356038706111054, 0.023891346928264414, 0.06414277026695864, 0.07356117559330803, 0.03568225673266819, 0.044988897163420916, 0.05802249296435288, 0.039394800019051344, 0.02685783587263099, 0.05284826989684786, 0.027136566183928932, 0.002842097360241626, 0.06502118813140051, 0.05744993154491697, 0.046665282387818606, 0.020146340830251575, 0.019271254572751265, 0.0268402584229729, 0.008894686553893345, 0.029844836930611303, 0.01628167338536254, 0.07652661111205816, 0.023700302001088858, 0.1095683623903564, 0.04017675734524216, 0.023385919763573577, 0.02657018112950027, 0.06392745753484112, 0.051446888130158186, 0.0665782902921949, 0.04857412353157997, 0.15003524773887225, 0.032862791059804816, 0.02667727431149355, 0.04574259689876011, 0.053507860217775614, 0.028429270389356782, 0.013445799039410693, 0.012833541625046303, 0.048403013963252306, 0.01779753588406103, 0.014733363342072283, 0.061387253126927784, 0.06962141128523008, 0.023607929636325155, 0.051606978289783, 0.050750585672046454, 0.048846843718950234, 0.018055949160563092, 0.009164925847601677, 0.01023915280321879, 0.05057657536651407, 0.06876090674528054, 0.06612520531884261, 0.036846402300787826, 0.10393282371972289, 0.10799021885863372, 0.022081402263471057, 0.04420122657237308, 0.013558552051628274, 0.009334523979175304, 0.03487654050279941, 0.07195561246148177, 0.021979866283280507, 0.03599659825808235, 0.016415380407124758, 0.04183725127950311, 0.023246935435703824, 0.007874683876122748, 0.029281004864190305, 0.031231874467006752, 0.047460169198789766, 0.06647583828972918, 0.02183790997202907, 0.024875451710873416, 0.006515021410970283, 0.04426589774500046, 0.04969571138332997, 0.05103867128491402, 0.01911175304225513, 0.023107443902907625, 0.05960671616984265, 0.05312797560223511, 0.028388906037434936, 0.021049857705033252, 0.0062062900979071856, 0.030395257752388716, 0.058673757660601816, 0.01908776174033327, 0.01455825041713459, 0.04423694126307964, 0.05888892790036542, 0.02543877317969288, 0.0043158991694716466, 0.059866534013833315, 0.01088070766335087, 0.059974312516195435, 0.020065732566373687, 0.0973430544670139, 0.023252397642603943, 0.01819964252146227, 0.055922077636101415, 0.05183368023218853, 0.024141081741877964, 0.04401367949321866, 0.030464712596897568, 0.013784622108297688, 0.01729068040315594, 0.04209299452070679, 0.032892867124506404, 0.17754611080246313, 0.15950169334454195, 0.2150890598339694, 0.11065960276339736, 0.20792519567268236, 0.10404520947486162, 0.10209704722676959, 0.09683125585849796, 0.1641247152749981, 0.13959984055587224, 0.09278532796140228, 0.2114810991500105, 0.21991344381655964, 0.12721633219293185, 0.13669713559959615, 0.22576837321477278, 0.1376870231969016, 0.0920587255220328, 0.15384438048516, 0.06861783763659851, 0.11185588035732508, 0.13253207052392618, 0.07916914538613387, 0.10293090569653682, 0.10982121167970554, 0.07214415020176343, 0.1578917061643941, 0.15956247651151248, 0.149966688560588, 0.11344888380595616, 0.17580258793064527, 0.07594106253236532, 0.11243866051414184, 0.1370320062019995, 0.1291871778666973, 0.09351043762373072, 0.12114055321684905, 0.10208902015749897, 0.22017638970698628, 0.10364880931696721, 0.20669506596667425, 0.17075164110532828, 0.11296051501163415, 0.10636935476213694, 0.13579590538782732, 0.11545996660632746, 0.052889260197324414, 0.07226600830576249, 0.14261055471641676, 0.10165218609784331, 0.2957365837480341, 0.28229238944394247, 0.07180575121726308, 0.1745940763503313, 0.10089909365134579, 0.11384145702634539, 0.13123049108045443, 0.1359121384365218, 0.09037269492234502, 0.09338078315236739, 0.07606925815343857, 0.1519067016031061, 0.10941773440156664, 0.09655161122126238, 0.06371040775307588, 0.30123814567923546, 0.0931189161326204, 0.18624840384083136, 0.12769891986889498, 0.16209700836666993, 0.09927081995244537, 0.16269695545945848, 0.19027853544269288, 0.11559947340616158, 0.10202804021537304, 0.17677222804299422, 0.20241368641810759, 0.09372908874814, 0.13033706402140005, 0.19238207542470523, 0.10202516322689396, 0.15530974471143313, 0.11493369484586374, 0.07063513581774064, 0.09432460500725678, 0.09033227459128414, 0.16314466643546308, 0.17120551317930222, 0.12212581320532731, 0.2541509366461209, 0.14513315792594636, 0.09455048252961465, 0.21354864963463374, 0.1877438678805317, 0.18475078205977166, 0.1349009448396308, 0.2050734894084079, 0.41285867616534233, 0.09363446025443928, 0.14893207193485328, 0.1455696052206414, 0.14348646200128964, 0.13239816842334612, 0.253665811249188, 0.12438788610909667, 0.13102858620030539, 0.14294170694691793, 0.10374286784125225, 0.17159872422260897, 0.11571339943579265, 0.1526472004396575, 0.12138975198779788, 0.1967800408601761, 0.10579920892736741, 0.10841111413070134, 0.11753605306148529, 0.08847984006362301, 0.1101078452276332, 0.3017000923199313, 0.079651733062097, 0.1253363016460623, 0.15032400510140828, 0.13344506653291838, 0.14570951914148672, 0.18374519316213472, 0.17374957166612148, 0.17433075048029423, 0.1490570716559887, 0.1224287383790527, 0.12001053456749235, 0.11249681096524, 0.15190702729991504, 0.10283356984811169, 0.10019729166690793, 0.13725102373531886, 0.08816656723086323, 0.13223123523805821, 0.0873464083831225, 0.1820607435490404, 0.11661676024752003, 0.10953136866113969, 0.09952740796974727, 0.10929145903459617, 0.11200946675879614, 0.11774668390197413, 0.16326468570956162, 0.09591206482478551, 0.13287930403436932, 0.23963544411318644, 0.09251333041382687, 0.06660277862101793, 0.11961599359554903, 0.16253897893641675, 0.15277509071997233, 0.12333450120474611, 0.1237547043710947, 0.09661935615752425, 0.16849232305373463, 0.1443371277834688, 0.10909513171230044, 0.15146383536713465, 0.17795424961618014, 0.2566257438489369, 0.08069416641124658, 0.11218090541660786, 0.15848197734781674, 0.17092043347656727, 0.269144524953195, 0.13382174846317085, 0.15769829654267856, 0.1104810055611389, 0.1977910173258611, 0.08293845491217715, 0.08277265488037042, 0.15441762043961457, 0.08563768078706094], [0.06114026638013976, 0.01705250612992261, 0.045436977941010676, 0.03114631798650537, 0.06935180218092032, 0.01185283630288073, 0.018898526805319955, 0.05426406374733363, 0.03178541994254504, 0.0549047704386924, 0.04543004331312009, 0.026476914794849496, 0.024207082843141894, 0.06002657328333173, 0.02220935870095023, 0.033021425761814625, 0.014009140864280718, 0.030335163298462118, 0.05409097285675151, 0.006875402809652899, 0.004372759555865611, 0.017950842389836907, 0.01543056994809636, 0.07123954088560172, 0.03218705839078341, 0.004922654088919184, 0.08621772644775254, 0.08234667738101312, 0.008581395061420543, 0.02060534432530403, 0.06105554449771132, 0.01704360544681549, 0.05325103810589228, 0.029321472692702497, 0.011827222454095525, 0.041456247081181834, 0.04533020027780107, 0.014244202358115996, 0.045810511468776634, 0.0077915031163554105, 0.033673742187342474, 0.03938794003001281, 0.05077477205278618, 0.04255292930507234, 0.00795775098127446, 0.010311449013118233, 0.06485535417284284, 0.013354836331148232, 0.047504352006529055, 0.0519685899572713, 0.06967137860400335, 0.027264142641797662, 0.023544135470209376, 0.018185769873006002, 0.04023671948484012, 0.034036425940160236, 0.05214590133566942, 0.028363532220412577, 0.027842481786917363, 0.01949103206529149, 0.022740171557026248, 0.03434803636212434, 0.03675003336476428, 0.09739866041179214, 0.11712415516376495, 0.007015511385231678, 0.052929890874241076, 0.07381304100688015, 0.056771192965762954, 0.03844330732577613, 0.025807543391627923, 0.055626758839935064, 0.05152372204299484, 0.017131195836035267, 0.03641360213181802, 0.04776198836043477, 0.015738156657399874, 0.031074457735355412, 0.06615512192781482, 0.05915140560162919, 0.030470249442649738, 0.03583908313885331, 0.08336849005094596, 0.010123523650690913, 0.037641960861427445, 0.0924190344022853, 0.03659458099199193, 0.009658329371762062, 0.06533077651900904, 0.07266315485217742, 0.005394984011737896, 0.06311668961175851, 0.013655367124426578, 0.07349271140992641, 0.062144783192447255, 0.037465168562318595, 0.017237583341609155, 0.10423300761197295, 0.061504422553947995, 0.05279022801135268, 0.019448493008634875, 0.019102202661867653, 0.038118553680500815, 0.027199805647666966, 0.0435014873343919, 0.060564604055668624, 0.029337272380611727, 0.10063650738447905, 0.023210291152021716, 0.03257230682564633, 0.03977068467065692, 0.05473371854584132, 0.010339263859870178, 0.0764375873176115, 0.01493475423194468, 0.05339886035237994, 0.042193305745188675, 0.024611141965059296, 0.026956566110519425, 0.052102234214544296, 0.02690658182837069, 0.05264251433046801, 0.06938741848404918, 0.013300626472170864, 0.0111260862821447, 0.02442924538627267, 0.008705732362743999, 0.033509787770786455, 0.01677855779416859, 0.028147909058524028, 0.05389303740646158, 0.012567655981651374, 0.04230508081881063, 0.014155821475599493, 0.03695023172934141, 0.0363145631604961, 0.04943209035055978, 0.04314219286399228, 0.016977007234735147, 0.017944874674347893, 0.019712751864322593, 0.013257069612986274, 0.029334235936403275, 0.021194139695061103, 0.027815018082037568, 0.06074459904006549, 0.02114844714690532, 0.02601764158212713, 0.015131363146273153, 0.013997236815547305, 0.03812211259667363, 0.06522929482161999, 0.04709936498797365, 0.014778143260627985, 0.040504890094910345, 0.024727168060573082, 0.07613793946802616, 0.0384457364811429, 0.013217606016301682, 0.04637711535074881, 0.015067482466942497, 0.026480331218668392, 0.021781209889533262, 0.02124271771338369, 0.02248711701083396, 0.058514498706374846, 0.0274516066004123, 0.07411183390234198, 0.021629682841843793, 0.04387823711814625, 0.05959083166505609, 0.11040966438927821, 0.018240118831662194, 0.011126386533890451, 0.013821430936721819, 0.037812734554920874, 0.016431426063978245, 0.01644283902299191, 0.0384476906619966, 0.041421058255114725, 0.052650154634777985, 0.02307803449886186, 0.042528122064790556, 0.03006825815620167, 0.06778001652232238, 0.04598841317264097, 0.030944253650626967, 0.02701302700942116, 0.03441021391855819, 0.02406040223182312, 0.0034641801737182376, 0.04057353409007192, 0.020404754106753638, 0.012212661726932441, 0.05428900669461914, 0.03354850158627544, 0.047745754410113604, 0.039574075756328445, 0.08152170771999018, 0.07795864569821528, 0.012730712187476456, 0.0324768369485225, 0.018291003869048188, 0.06303749778973204, 0.06328698833073888, 0.03092136327177286, 0.017977079642670493, 0.011564776983245142, 0.07297488062509469, 0.005432955679550234, 0.027869082055985928, 0.045598818720983605, 0.03973031183704734, 0.04597382127706494, 0.08526487329176494, 0.023474631431911672, 0.058878960220941474, 0.041946403815277984, 0.008649026343066777, 0.058968235073345046, 0.0357030368676143, 0.045155596254127364, 0.015759477924023355, 0.02102509287319013, 0.03967830552054303, 0.0661909757182002, 0.04406063072383404, 0.03532896390450852, 0.005055873413636748, 0.05173482446532164, 0.03056739530126963, 0.0397179319656321, 0.09824359257306371, 0.03474549503464784, 0.02915500769657748, 0.0322776292450726, 0.04554665294874992, 0.03820915846154094, 0.03736412452001657, 0.06623784891728844, 0.04987899726256728, 0.015850279480218887, 0.017919456752549325, 0.05768001598439046, 0.02598325003470693, 0.04920905588993004, 0.029982403120292083, 0.05931858305952378, 0.0749900278502277, 0.0375501109686281, 0.051901537126728466, 0.06089388352951833, 0.007320149435794779, 0.04924844824043768, 0.09384654315986804, 0.03487046422170741, 0.05006304310102548, 0.025469042626874785, 0.02875049565253513, 0.06680306180247239, 0.0453651753653373, 0.02084287059759455, 0.029342510670955693, 0.061578986767147265, 0.04024740980405893, 0.048306868943784914, 0.04881007390628968, 0.014030727607730244, 0.015904375684580634, 0.03294318388881428, 0.04747061863807695, 0.03537395077624491, 0.04503557698002883, 0.00697563388218571, 0.08382527982550007, 0.04436134048072355, 0.02966994113687958, 0.038598159195056984, 0.03181130266083138, 0.05024454104048865, 0.027920740623293177, 0.06795680203608104, 0.05259571237755673, 0.024344072278056825, 0.015597855971593941, 0.026624708203598857, 0.026153723476454616, 0.0479944137457226, 0.03982061127732907, 0.025400300244135515, 0.009083614451810718, 0.07364062525864158, 0.038041831725942235, 0.05335744936019182, 0.05161133787727781, 0.03712244391707437, 0.04208413963871343, 0.014629452489316463, 0.05083498525034104, 0.048165516528700075, 0.029413987549820116, 0.02021813322789967, 0.05401398288086057, 0.020801479961456995, 0.01696240685747138, 0.04508719313889742, 0.010446205219653035, 0.026257055878107036, 0.030350389624280587, 0.02318604539946786, 0.01459848415106535, 0.04728515126875468, 0.05525231268256903, 0.05713612945484264, 0.057138327908303053, 0.04099970497190952, 0.027142169186845422, 0.044219007582536766, 0.015967453996251737, 0.041580001690558026, 0.012168750333200608, 0.04753343401742833, 0.054779886068510156, 0.029563305966023887, 0.05055113369598985, 0.017374350556305478, 0.04150473180093935, 0.014973181366388286, 0.02076500022251691, 0.03577027968796236, 0.002125529181544802, 0.011289832897351255, 0.026775181825671877, 0.0837440931105188, 0.017867922017882978, 0.028808255945997577, 0.011844758343483721, 0.021960017437647496, 0.062047596621726236, 0.025055545082847987, 0.018384563670094525, 0.012623357769500996, 0.036066514506403885, 0.04706836272297161, 0.031172126065939665, 0.030920423500772034, 0.031490491304014406, 0.06467797833361796, 0.027237896907276342, 0.06130960836474385, 0.04708656442484685, 0.06692939145224434, 0.09552757295646838, 0.07060485958520855, 0.21063219755887985, 0.12374437706811087, 0.12176428974739142, 0.1314288947199072, 0.07940525521657296, 0.14816524593957833, 0.1898095863206046, 0.15089769288897514, 0.1121594976367695, 0.10798526555299759, 0.11441754682787827, 0.10305570185716663, 0.06675052283597843, 0.15313609849129403, 0.08821416646242142, 0.0976768529840878, 0.10303499296839748, 0.13553590433938162, 0.17354250991983072, 0.10790274890937976, 0.11128629092127085, 0.26778761776430265, 0.07098601306123392, 0.09679658950439521, 0.15344932382660254, 0.14179068085338387, 0.19819338859191962, 0.17949586760784897, 0.12553302251866885, 0.19043398781546525, 0.20581620026912006, 0.19780997559428215, 0.11521591113082, 0.1861272310572011, 0.08520471437701158, 0.14911286080522196, 0.1857931746968201, 0.11799187931631293, 0.16499180160462856, 0.13238191072429928, 0.13537695072591305, 0.07582484305437122, 0.10747958054499966, 0.13900680094957352, 0.12038473305957657, 0.0669971906713077, 0.09581147879362106, 0.13457017258874007, 0.1808841231146029, 0.2272932178207806, 0.07710283662059478, 0.1895102709531784, 0.1904571530010019, 0.15849271177181176, 0.201298663392663, 0.2009534654872758, 0.07263149440820728, 0.09394800450120654, 0.11004261765629053, 0.13610591446714743, 0.12497055770031043, 0.18584055001182215, 0.15074773664985383, 0.15372493118047714, 0.22672034427523613, 0.16573998145759106, 0.07012723200023174, 0.1456600267972265, 0.09560805399503026, 0.1467776961092438, 0.15190656589610235, 0.1632696661565985, 0.09875017324728624, 0.1270353804741587, 0.056704374229801555, 0.19048730709723063, 0.16993274433272226, 0.11845206176596028, 0.07704282019819532, 0.1013664821428912, 0.17402023928506033, 0.15113307668694428, 0.16720059593873365, 0.207551865705422, 0.1374246065637895, 0.19352563763303415, 0.10264769875045333, 0.12378358282148838, 0.0888317215389439, 0.19793158264032432, 0.08769258337893657, 0.1817450076341629, 0.1644036474504641, 0.16483834412481102, 0.14659360955868447, 0.14729404768773488, 0.11197263587798391, 0.15027550341827528, 0.09867275918700866, 0.1346630233206919, 0.07957243945981775, 0.10383943015975611, 0.14249856929693902, 0.1280708113419158, 0.1336370783724955, 0.1853495349309274, 0.09006702846714429, 0.132968436394419, 0.12020692974328995, 0.10009703811790262, 0.11742138064333371, 0.1377831580383437, 0.052352257405540774, 0.1713987463819129, 0.18195812191282, 0.15462035313248634, 0.1538463482367141, 0.1381324135831424, 0.10738416495067732, 0.14227872395089694, 0.1479251395378794, 0.15464298906070845, 0.1304281641330038, 0.14068035329026835, 0.08795574640056916, 0.06643748749047518, 0.12368147687188216, 0.15492874729846204, 0.21908051493976796, 0.07069049748991217, 0.12453018847320761, 0.10052148212811776, 0.08605548872479371, 0.166052677535585, 0.147786677681974, 0.18667799793183804, 0.1301894283720425, 0.07719798080090966, 0.1170296488063676, 0.11392517467694623, 0.10886490478047303, 0.14781125422034944, 0.10740224112357412, 0.11562375138912882, 0.12035803949194294, 0.10581948355372463, 0.12080915671374116, 0.05325525180835809, 0.15180009018097604, 0.1621560137718916, 0.1251368530626808, 0.11638375132211617, 0.10145129902022225, 0.1783050929329225, 0.33382297147597584, 0.1350252931671483, 0.07149757418249335, 0.16300952940114907, 0.07779477949121169, 0.10475005129618303, 0.10389517181153808, 0.18435750316296304, 0.08691935201308557, 0.10750643696103777, 0.0831326177077634, 0.20011096926672117, 0.06472907880587236, 0.16103104342307362, 0.10530922521970101, 0.1696654422474759, 0.06093705871275493, 0.17186062516910688, 0.10841842873820237, 0.166372362524271], [0.04083241555573685, 0.04124022867264492, 0.009429444242934031, 0.0448702247813344, 0.023507387709936926, 0.05721268177564655, 0.014607719012669154, 0.030844034028372595, 0.02968241261052234, 0.05495627124660781, 0.027138713747262955, 0.015049893142921584, 0.041715104798121114, 0.046225676512611766, 0.027819437041346515, 0.01788333324449403, 0.031059295870363712, 0.02186840333576713, 0.03420970342787249, 0.0329712379191603, 0.011187850780385946, 0.024562314585117356, 0.031355306772249084, 0.028739713731088808, 0.006486167557471032, 0.015784685499966145, 0.03306467219122818, 0.054667975287884474, 0.0057645922144209695, 0.034086315227406364, 0.06199270313871758, 0.02117041132545897, 0.022877971841288463, 0.04345250049872058, 0.038550339439617734, 0.024868710465463142, 0.014932292846164532, 0.008797859606732215, 0.011059572886941689, 0.04081967606076172, 0.05436692287081054, 0.043214738435511074, 0.02759798865632287, 0.03459954893748675, 0.029735915096742765, 0.023559010654155697, 0.07178993456597839, 0.012797265446611812, 0.013176093243860772, 0.013723273212755365, 0.038632917151387246, 0.05429850618488022, 0.030197091600192443, 0.047922991149659665, 0.05843139173729079, 0.05224664003721305, 0.0021528554830833203, 0.03559407771431974, 0.02532534417696297, 0.09973400152687516, 0.028253728291019797, 0.05027628290866103, 0.03300227750358837, 0.05401984881609678, 0.08516306589756693, 0.056557071062603166, 0.026629715792036483, 0.04034390087638583, 0.054957607960594554, 0.044829471968114376, 0.006921297221976731, 0.04615973647949951, 0.03148519194551876, 0.06747730169445276, 0.031800005052770884, 0.007684584657129432, 0.0274611468027745, 0.038657571721289835, 0.030937590436743836, 0.024429428590727702, 0.013019828325403588, 0.03835658037236758, 0.029496215816055025, 0.058422082236834934, 0.030691733450761864, 0.03661078101556216, 0.012305925517076892, 0.055311090778559446, 0.062247296263064654, 0.053695051066045246, 0.020279594929888844, 0.06654451281896659, 0.04615081374400428, 0.03884748010230916, 0.016194271289610436, 0.006776553828136197, 0.0228746402343469, 0.0245455496811441, 0.0046558888945063305, 0.015884725310440575, 0.02513531705231539, 0.05489385620291744, 0.06371313546385084, 0.07791439842964921, 0.04965356757332172, 0.03080414973997644, 0.0501771930472127, 0.022333437310797826, 0.018167052484516586, 0.044191747438162565, 0.03730915639815586, 0.04555451377694096, 0.064883594800319, 0.011183740554510482, 0.028149965019630532, 0.07191189445023026, 0.08121748654437916, 0.06459768728486129, 0.03150884567626885, 0.049104826125715456, 0.03059535094403795, 0.016959702895422066, 0.04374353773891926, 0.03956377559474536, 0.02381202788092196, 0.04335292209205883, 0.001736816083264005, 0.06599899780537401, 0.021013076018009866, 0.05098938589383449, 0.02323551569133997, 0.09006862980978829, 0.029136992591832365, 0.05162274744361639, 0.06830284132489137, 0.022706804597484212, 0.0035696624711688075, 0.044444695115089417, 0.053679468509341986, 0.029132229276001453, 0.017955744805346643, 0.013064552264820253, 0.012603042431042662, 0.027148594913472022, 0.09517793743205921, 0.021779209907565798, 0.05937330012342759, 0.025786106774051274, 0.04702780668490699, 0.08609877247363329, 0.04544583960835423, 0.03346379327454737, 0.0076539742461006555, 0.043335219113422294, 0.03209261649421283, 0.08930305231894765, 0.06473627127707005, 0.07162139325269631, 0.015206534648314118, 0.024489234667271376, 0.029952730783926587, 0.029508137676332678, 0.04763673758134246, 0.018290815575580512, 0.043436297082475255, 0.012237139029561408, 0.05446012983364718, 0.041055439838341305, 0.04864757155467357, 0.03440796457497137, 0.021960882569796274, 0.03745122127501028, 0.03253004087933472, 0.03805469335722072, 0.06734475666390997, 0.018715486895026903, 0.015014171666864837, 0.04126954138545053, 0.0550836458403085, 0.01883938569309456, 0.013875361748172768, 0.023148094935874854, 0.016154229241822447, 0.052927522787026, 0.06324886823339121, 0.04391329702255981, 0.030387899040111473, 0.013955735069300448, 0.0448448713203626, 0.05372241299067225, 0.0797871822225196, 0.009352460204224502, 0.04339324064286692, 0.006354697156764034, 0.04875341283955744, 0.03195448372779148, 0.02153707977517375, 0.03353413699993065, 0.03328371008059808, 0.05239672859066299, 0.05055601575544902, 0.035907951050571034, 0.022042973432689905, 0.028690353701157228, 0.08893321002168314, 0.03292213233986071, 0.01980988245590457, 0.0369702145856406, 0.038008441017674546, 0.025912582308852246, 0.09728595574519464, 0.04916363475578172, 0.05223718804440328, 0.011711909668520093, 0.00918333959167025, 0.03996586866144623, 0.0672530255147389, 0.02284036234154233, 0.019447035854682326, 0.035662005855036635, 0.02102750336884388, 0.033521930154945166, 0.010123521954353367, 0.0456596663487809, 0.03082105204729097, 0.02228341401288552, 0.06402055253939969, 0.05736593569495848, 0.05435368125992162, 0.021418044376852255, 0.045593207236379385, 0.01258724189496466, 0.05636752909049392, 0.11387284605630807, 0.021188411163166165, 0.03026223774733288, 0.011399982031434774, 0.013073495356366038, 0.03260829293036035, 0.06887833401560783, 0.07409577297845057, 0.051492156593927314, 0.024098098244784132, 0.036267096243266544, 0.05926415098032781, 0.03789177031389304, 0.03698443328695638, 0.011604709617261375, 0.0372670668709491, 0.0630766764017088, 0.03917415739436235, 0.052437243916626484, 0.0772793303642954, 0.07237977148698908, 0.022976154162149345, 0.01827007276006043, 0.06557008224938597, 0.022422311827540398, 0.022326634997235875, 0.02227726478927902, 0.05799730574446065, 0.03957610118335911, 0.04465303250721522, 0.05264573397913149, 0.041766551323235035, 0.021488203201442957, 0.017859618445592265, 0.026138156186789274, 0.005955427643909518, 0.033371298773480315, 0.0066796878652114955, 0.04366216103413275, 0.04043715533667377, 0.11786187200673989, 0.034278184574629576, 0.0038138460201610413, 0.037775041934634955, 0.03194635148559298, 0.03738115235630955, 0.028566799259611537, 0.1252054800944669, 0.01833458447695843, 0.03979612634118114, 0.014270751737058163, 0.013075777778535016, 0.03466216754168272, 0.0439762073968138, 0.00931036049899246, 0.04175526050052472, 0.05595809088221618, 0.05563666884388242, 0.03695023172934141, 0.087113121258361, 0.03790741393874798, 0.03015776371051158, 0.015470896980592182, 0.047486903478524516, 0.03788274919082012, 0.02975227457604238, 0.07417640329471656, 0.004994936304033867, 0.09399765969387122, 0.012922214277620827, 0.022641171601467898, 0.03407542474035706, 0.07677771656640939, 0.07873514760285616, 0.048216033460838456, 0.017973228956439664, 0.07309264037758112, 0.059432780503162315, 0.02279008798567312, 0.04859449654551489, 0.01579601364210248, 0.04357472840430481, 0.02951634455738323, 0.04384792695886322, 0.054277363033699136, 0.00630382526599403, 0.015580639841833284, 0.076545270825071, 0.024975839270544902, 0.04044677357056311, 0.028130355357591594, 0.03535612566130502, 0.08344851647104536, 0.030587164419037954, 0.019196356181055307, 0.037491492328367064, 0.03915363849539842, 0.010187759712737585, 0.022241646789812615, 0.09160069402839456, 0.09478745409952742, 0.03373449482023716, 0.02854436349921993, 0.06996498749192272, 0.09809020973209824, 0.04679648731169956, 0.0003674344786434501, 0.03642088281256812, 0.002376118525197463, 0.01752034415091787, 0.09393900034150907, 0.027653974580711553, 0.061136575149638314, 0.03089948051742145, 0.024113219397674714, 0.03709581820294261, 0.0625287593741502, 0.05600077412756426, 0.024575337368462766, 0.2002243660390377, 0.07188233746481792, 0.14419517825756753, 0.10411235730030707, 0.0706658259566341, 0.14587836579552718, 0.07270659466407128, 0.12495066305356366, 0.13157841669661657, 0.16464276319103582, 0.15309086734695093, 0.08230964972504548, 0.12255793144660336, 0.17139722646347114, 0.21520664995270117, 0.13892501033842564, 0.09418116270431451, 0.050823080353438854, 0.10649848676153592, 0.1463373675942421, 0.13547687179275922, 0.1538392100483179, 0.1327223860259567, 0.0665303992905787, 0.09759194111185414, 0.11147754958697728, 0.09143732315195457, 0.08067631415490593, 0.14984970912337303, 0.1363374984690121, 0.1382114357714142, 0.11476564886314528, 0.1377830087606396, 0.08922139062945332, 0.19712787148143562, 0.09520089905709028, 0.10811018384993076, 0.06235922061439071, 0.10273628149713789, 0.2098706912781511, 0.20084494059639318, 0.09005092683115176, 0.061001824880284924, 0.07921756564506463, 0.1392242442816496, 0.10316282218056065, 0.12480059824883938, 0.11988211502986294, 0.1306468831109149, 0.16546372271009854, 0.11198138219437428, 0.19452364050916263, 0.11493190351341452, 0.18849112492586884, 0.12010319530963898, 0.08468309736677579, 0.1444705549095358, 0.1948729231953621, 0.085575499837952, 0.15983760889087403, 0.08755558037332126, 0.18219771262790474, 0.11093327629246882, 0.11810345761477947, 0.20627327502838202, 0.09955944160797767, 0.06714037513094288, 0.09475071142826762, 0.1053531128647072, 0.08628365291016442, 0.06900105385908059, 0.09850391931831837, 0.15119197352656297, 0.142093850299716, 0.22485391157014029, 0.17310101432459696, 0.12483470141887665, 0.10036284742610795, 0.08161101649914469, 0.12737924845090934, 0.14363508831177438, 0.15267717811678136, 0.16070762649178505, 0.17357875726052693, 0.22706141668770993, 0.13918963899569853, 0.08857056698096649, 0.13689410074480943, 0.1622505879827908, 0.17453957641763346, 0.1843090829040323, 0.12370837400002138, 0.13349663519433566, 0.13576139509677887, 0.11839939387781279, 0.08180614281445742, 0.17912734166852065, 0.12978647356586798, 0.08223275135138206, 0.1011401160753199, 0.1684024307344641, 0.1712233450795923, 0.1352162193506956, 0.15297676489821502, 0.19702884608081409, 0.08955072438610451, 0.1338468271174601, 0.06292453527982746, 0.20134210320455687, 0.11689379252493382, 0.14379674249461719, 0.1312163911227669, 0.1364554414259536, 0.1572234034538269, 0.07845810854009219, 0.1643999290785619, 0.23344628193548747, 0.17819844079869135, 0.1155494653752872, 0.13284624580826077, 0.1400746250791209, 0.13944274612835475, 0.11162363139114209, 0.141485082251685, 0.10062968810754162, 0.14407685532101563, 0.10376005513327462, 0.13526028341480664, 0.09579308370926551, 0.1339112879442317, 0.14646977691778115, 0.15480205123978003, 0.08420002114559923, 0.22985020918505533, 0.12774907717747347, 0.09788508859596082, 0.12301910455737795, 0.09367502307785408, 0.13117414553250584, 0.12739133994494165, 0.15978137190852845, 0.19282623087721212, 0.222586383244821, 0.08627022470214538, 0.19164924403386457, 0.10748559236526489, 0.09687160833605699, 0.11719477708850588, 0.20669932716659137, 0.20415035608623708, 0.10950237485979285, 0.11712339520454407, 0.14884071397994245, 0.09124346569712673, 0.10433937476149627, 0.23655326664447784, 0.12700570135244302, 0.18376877903938293, 0.12506206493292535, 0.12546112494809286, 0.1769829945904868, 0.17711881015981945, 0.10699951023395572, 0.11655278796596186, 0.12322417141071387, 0.16444891930690833, 0.15422488935291767, 0.18048088332372053, 0.0981337513242449, 0.15233128810567514, 0.1624980361333915, 0.14269174821674824, 0.2203810087272099, 0.14343525974878243, 0.16321234351822309, 0.14862192714852945], [0.007826514675148895, 0.028096879832446575, 0.04362362024507352, 0.08269898633339576, 0.03384165246305721, 0.0319876573048532, 0.031086108181625605, 0.03843140582154904, 0.005494609067682177, 0.025775776078392352, 0.017248329639967, 0.02900722955486604, 0.016969283809885383, 0.018056098438267196, 0.040028589045895, 0.026720515651894466, 0.0054111657996795005, 0.013065805858267205, 0.016060666048101017, 0.03212341180603419, 0.025852157069104056, 0.06711403440151896, 0.03704188145431025, 0.015174550203872579, 0.06891659660530941, 0.011039504365596389, 0.07741777864950043, 0.038922716065176895, 0.016841846451695477, 0.02845554835429149, 0.02516556275077164, 0.06344358742769275, 0.05772591209305184, 0.03569263153310333, 0.04813283149685178, 0.0343567419664136, 0.02372757062715079, 0.03684083152828472, 0.03330794395878911, 0.017939295420157056, 0.04936015546055777, 0.11647525855473109, 0.024728170596063137, 0.09441927421305861, 0.03411930560001305, 0.05320038885942527, 0.06601495694901262, 0.023562976691339697, 0.005509307408439261, 0.010367903126669782, 0.07022490033081599, 0.05907612892666033, 0.05597307632810303, 0.0077278175158426166, 0.018624139118141363, 0.05053981912455388, 0.02515167822795255, 0.09092316324157373, 0.03783657488280109, 0.02455773447374148, 0.02792880161931472, 0.01000302007222282, 0.02495251123660377, 0.08039538708648511, 0.050613928719290664, 0.09184246962623936, 0.01273871211534632, 0.09209603816270828, 0.005726936489476689, 0.014640889197055782, 0.03885650461805718, 0.04594726002375994, 0.05969667634261506, 0.04444491224629538, 0.03722517072622265, 0.009331487534966851, 0.046080463233270814, 0.020059418798025166, 0.033328568030680926, 0.03715678118169308, 0.013250026419492704, 0.015065950674137898, 0.06020461408687489, 0.01953630561807326, 0.02127153509562569, 0.0076092274061271125, 0.01155631649973137, 0.03229064015405519, 0.07134111079254321, 0.03817041750465121, 0.0545980793956135, 0.03780523335028972, 0.01811589433678559, 0.08454057108610868, 0.005013405179072703, 0.03611557598092726, 0.05650522420182824, 0.048049622747514925, 0.004975757511731769, 0.00907903688494116, 0.04378314043528267, 0.0690813652638878, 0.009113800778452839, 0.050267224466162067, 0.03086424419390304, 0.01758109508747501, 0.08230119517871312, 0.07335889073354857, 0.011416396641704653, 0.04472028211291347, 0.07849924811827284, 0.02108474288667951, 0.05042734855253782, 0.024314021658418433, 0.03175085536869509, 0.008471009288249272, 0.067790153835501, 0.052617605309933424, 0.07847224242453064, 0.04108532252056258, 0.015447954015274133, 0.019438864596720253, 0.028609533395086015, 0.011433091147669723, 0.022729632211849093, 0.04138257514153208, 0.014377049336742078, 0.022091349586844444, 0.021339317351313572, 0.03101830556988716, 0.07549696136265993, 0.016921981437397853, 0.03600181279970067, 0.03966864657455257, 0.04918005530323301, 0.06532640675348894, 0.009716979394267713, 0.03630835456507547, 0.014767926219584686, 0.0438156049432499, 0.009147943812422454, 0.046981944502996545, 0.009945165632026536, 0.024410967349207828, 0.01598974726428943, 0.023895133153668473, 0.04352872033736535, 0.03064089760716472, 0.033608565506126196, 0.027501204117600406, 0.026383494093481983, 0.015391272592491336, 0.09973501932940312, 0.058168296569160054, 0.036788591117198975, 0.010132257244549692, 0.021395785035565495, 0.048326288616018634, 0.018437090762225643, 0.07735894287803344, 0.027394970978743265, 0.01486926372828228, 0.01224403633802597, 0.017100022240941013, 0.05046748389889087, 0.021688420225733092, 0.05982173713190215, 0.045384503435343504, 0.052748090986694605, 0.022151642512263994, 0.01723269958581243, 0.04000492513711963, 0.04973198925810201, 0.0637894638680986, 0.0890594921740038, 0.052892551092164855, 0.018885880608909895, 0.030259961262345314, 0.0731834147923759, 0.0704892168619803, 0.009643698460422456, 0.025001321653170244, 0.035567513068339655, 0.03167116143075483, 0.017522186373493502, 0.01724376479562904, 0.016765343324680413, 0.01685654521653695, 0.010401626317096608, 0.03419283165463379, 0.044937803476516686, 0.033507450217647214, 0.036440987805170674, 0.03784251884956445, 0.027852843016652123, 0.04243120351540191, 0.053383423680705686, 0.02558827480035169, 0.019806917257873074, 0.004022823355626315, 0.08474045393190213, 0.0327800640703312, 0.05680306375558887, 0.042718396854719946, 0.04096521842958672, 0.05034011948321547, 0.025212902442685196, 0.05989152445857014, 0.01978921258289899, 0.029388942822281803, 0.017464795881616216, 0.03290072116734726, 0.02292549473765705, 0.037424164691141674, 0.07681679339813334, 0.024650848138013055, 0.045533004216849804, 0.08771483254219804, 0.00814850244205445, 0.0936483091541699, 0.06862068069832665, 0.017123394379658357, 0.07280494831502438, 0.03053182310291699, 0.025895849635292376, 0.007980122280839299, 0.0467949606079076, 0.0669397594673293, 0.027063399752868072, 0.05090837899063315, 0.03432911202045424, 0.021963540730731826, 0.011989789266538407, 0.015549785158197795, 0.06861114728131465, 0.027591827558353543, 0.07280597290290253, 0.04365590833393591, 0.04470019408368638, 0.028064423806167076, 0.04993892547541431, 0.041153369404907734, 0.03501472415934716, 0.04434526937880686, 0.013112131988496652, 0.035707552518163405, 0.0016036082088248804, 0.06028791104576417, 0.03425430014197316, 0.036898758062826734, 0.04015134620879378, 0.048378484922328165, 0.0754299017467669, 0.02443121822683939, 0.008321623866712409, 0.038271617610007524, 0.02845897325979812, 0.06216340219335897, 0.03672719726871167, 0.023063870080347573, 0.03784670541062951, 0.07876470458826848, 0.015367277897894382, 0.029765034427068064, 0.05668054747262171, 0.007662293933598059, 0.03750536836949842, 0.03874567949346133, 0.01097771102961685, 0.034804371518215964, 0.004283958829806319, 0.024670362805149386, 0.006996141754955585, 0.022001348701970916, 0.020528697009597505, 0.045329827083540816, 0.06588832195848227, 0.029362771726612533, 0.06404025719634124, 0.04152362560853362, 0.02331458537706307, 0.043560628446617296, 0.043992115650326014, 0.019750780359442745, 0.023159601193453585, 0.034648569699909, 0.02189470674576504, 0.025913959734940102, 0.0033736237382981926, 0.04401060233690909, 0.04044502634289009, 0.031127559885914837, 0.060798454364495616, 0.00942017715091684, 0.009247794481260436, 0.026357431563415697, 0.01847266635325338, 0.027808136040610925, 0.043433579549725564, 0.04229642949732287, 0.017418971019131795, 0.027001624228432775, 0.012608040689623781, 0.034548709701214514, 0.018200051338811005, 0.012247165232630712, 0.035635834759367366, 0.016407565380047475, 0.023113518487662077, 0.0037432084042978075, 0.05862067586609295, 0.05925885162183216, 0.026686383644118905, 0.008888460995097245, 0.030959720856377056, 0.048832570734832964, 0.04817020520567894, 0.0618983121322734, 0.04876506328582764, 0.07469505510692086, 0.018810212079967772, 0.03233879917700376, 0.036356971599161625, 0.033471192698925734, 0.028854046881731068, 0.007097596310943897, 0.03489017227132406, 0.014503363719476121, 0.047000448152955086, 0.029782520274498632, 0.07435682575617518, 0.01463971533147352, 0.020546172679002796, 0.02420888265727886, 0.015296976580949766, 0.05891212022730282, 0.011465635383501649, 0.11033411630030189, 0.026775334496051073, 0.031135546243084327, 0.0331894174617316, 0.030486351078642265, 0.02297322458720633, 0.06402419627244983, 0.03312869875558785, 0.013261272289258028, 0.04832081962376833, 0.02835737112244325, 0.055568262335977385, 0.11453420056828431, 0.07143903018108436, 0.021475551916020255, 0.10623372918260948, 0.09701771049627236, 0.18720093130001, 0.15527765000505106, 0.09519061925155775, 0.15139048573161873, 0.13037697545119695, 0.11552427815539495, 0.11717386463923113, 0.12226792557963304, 0.07529486649270568, 0.10086313129535743, 0.11257180944085121, 0.07878965432090418, 0.16672890553517, 0.2208481122340475, 0.14187073441488401, 0.08109575057668345, 0.11448553603674684, 0.13115857993917807, 0.17137385771742888, 0.12357863810445581, 0.09340867772698402, 0.10907326931399958, 0.1219830901495048, 0.11465004006666796, 0.18634322232433728, 0.08464677538722754, 0.11877980775066785, 0.12317690466131483, 0.09325108796890293, 0.15406715710248264, 0.1296118457934686, 0.09832604136317968, 0.0979613559320569, 0.12803303051207746, 0.14502377808094025, 0.07774722097175461, 0.17433114403060504, 0.09181001529629741, 0.18342966080776282, 0.2526653792176928, 0.10675571938710553, 0.16561734303832054, 0.1555762868374586, 0.1239105367234775, 0.19228226292346204, 0.12075062628303256, 0.15561513975262642, 0.10646811553410121, 0.1539627712752138, 0.1318861594689744, 0.17312525159546308, 0.16450765329812253, 0.08490125316062144, 0.1806996294430324, 0.08200698239462716, 0.16725382022559643, 0.08953123686036893, 0.13062029810888426, 0.1199240077819143, 0.08045914902218751, 0.17764658826802457, 0.17290342492716654, 0.12789002247154713, 0.2363364068525178, 0.1433476201657738, 0.192908822159682, 0.08111322285341364, 0.11088054733616964, 0.1108926727569529, 0.18147143588534423, 0.10656831480030503, 0.14105520317597048, 0.22386235477668898, 0.11610966388668333, 0.1933301245527608, 0.07580266852996179, 0.06474806421569415, 0.1150767978812967, 0.0537021519350154, 0.1436705756932497, 0.08900261058339051, 0.05653638592255967, 0.14471197766917093, 0.1586341591817992, 0.09665787659053292, 0.08687804958650044, 0.1497140292610441, 0.11489078429128442, 0.1401931651468788, 0.06790291278489999, 0.18027433726404393, 0.3103197126516274, 0.07285323286695139, 0.11853073111602239, 0.12592797061162336, 0.12957950681447983, 0.08335198129394225, 0.09004975975091968, 0.15348519118768827, 0.22372427290039404, 0.20010095408984593, 0.12769748137465545, 0.25974640782390324, 0.14390354390655244, 0.1534065082669258, 0.1709592728210347, 0.06245927060289042, 0.08294171188026667, 0.1191905928509576, 0.07656524689602, 0.06697156240365335, 0.11786526468183313, 0.14309175818094186, 0.11808103881776333, 0.1852666993758508, 0.10507435032299586, 0.17866808202649864, 0.13666823000780173, 0.06593351239072424, 0.1505917278783662, 0.18211943682815346, 0.1049391861472811, 0.14009587679590496, 0.1499022413045168, 0.052741712757519314, 0.17656885752720491, 0.09527526649513415, 0.18138553335198335, 0.22274731818054402, 0.13206081438277448, 0.07555326619850737, 0.08220784233084746, 0.1939780983541693, 0.11800904625228473, 0.10721607147050755, 0.0730374822659152, 0.062124841048249176, 0.12172280411635127, 0.09060833656362124, 0.17563131212123803, 0.1316937676497868, 0.19733185267874173, 0.08825010846235923, 0.11582120507955551, 0.14171416924468108, 0.12825398865555013, 0.12514951452612877, 0.09725580843431608, 0.11338226523782526, 0.07938951998949051, 0.16962483871195996, 0.1286428842161383, 0.17019444171871456, 0.10791159022067275, 0.13486236333847046, 0.12216493753450257, 0.11385880038142204, 0.09400557819753885, 0.08263702251549278, 0.18375319987535477, 0.1668570265173912, 0.12419614568352699, 0.1288674793073109, 0.09689516028655426, 0.10015929370586361, 0.22247861831315927, 0.1152429711073637, 0.10972051708293812, 0.06991869104760033, 0.07567756024322339, 0.1080200472580535, 0.13735154191298143, 0.1706974668694394, 0.14659669010766915], [0.038192130625247955, 0.06616732198745012, 0.03521203196474484, 0.019482881163379977, 0.04567153053358197, 0.12173420350466456, 0.014950757480359502, 0.008040929196535476, 0.06509548093059234, 0.01957128070560949, 0.032527957776827474, 0.017831757797726562, 0.007576093692997736, 0.04727876625422921, 0.0470116846928639, 0.05540026045803513, 0.033246587429727824, 0.007642409464876566, 0.043035408415432484, 0.03963326775868024, 0.035572374771748266, 0.058043927885591984, 0.028907922562211752, 0.0312726645996528, 0.005465982099329787, 0.027910603310114572, 0.03184784855693579, 0.03270117419638804, 0.03104183716433389, 0.015666737454012036, 0.0344502203432577, 0.007926449312695434, 0.01726748129086835, 0.05985982330249889, 0.006012693454977125, 0.04731848430154579, 0.008904876453535897, 0.05795311275869608, 0.02543363158058907, 0.017246704548597336, 0.010442800670196968, 0.030155887561185018, 0.09121303340154034, 0.015408319088497331, 0.015218951839155384, 0.045918435856167755, 0.03088214055501989, 0.015874825484518493, 0.030270285172654048, 0.03316092238362346, 0.037008982683931074, 0.06629461515694857, 0.02073839316809816, 0.04991798588473882, 0.009610355249606073, 0.012931831663341394, 0.03395866582702313, 0.03270898074177759, 0.059288211832089086, 0.034989292666848214, 0.04676137990983469, 0.021632403767268573, 0.03038584307900497, 0.04598188227308648, 0.05641009698488882, 0.04702287034264632, 0.03593379984210644, 0.013711366619515632, 0.05286689229043467, 0.02012685500085354, 0.09993216767907143, 0.1004704562947154, 0.011593442543276718, 0.027796288819185326, 0.034083326280649216, 0.05530909588560462, 0.05907409332160439, 0.025180977370057787, 0.046699894459119866, 0.057697685036276064, 0.01503821725158819, 0.051652616555137296, 0.030186896611537253, 0.0382765505595931, 0.02669780338848276, 0.010274012539801853, 0.046726811943309646, 0.018027316679113677, 0.013918758303459202, 0.030138187975223576, 0.02635883104189166, 0.03433965306196894, 0.02320566863220717, 0.04480120759191258, 0.07180184285555567, 0.041160256535347016, 0.03710048652387091, 0.017708427272737026, 0.04810379019805363, 0.017556645774415562, 0.08737423510423728, 0.008242135185615292, 0.04812476710815515, 0.03872876700812152, 0.02545938198454678, 0.022573307921577777, 0.029967814617391144, 0.028828751096235852, 0.05182193818369082, 0.05842744944883244, 0.05078863452321716, 0.04181521924744759, 0.021622235920014124, 0.04262362586866532, 0.021659687660368424, 0.04699805970968945, 0.015023230109363794, 0.04127571266144514, 0.03559066807585103, 0.021564541783715998, 0.00973436261327671, 0.03694967193795102, 0.0596311909279653, 0.03888216341978737, 0.012434723337979188, 0.01807500242388674, 0.005445528085277016, 0.03507732919284275, 0.07184190356305667, 0.020839162403717637, 0.04507373778947762, 0.05178738718054124, 0.03968385932967067, 0.02613236489040511, 0.050294009636023214, 0.021839143209425465, 0.013405173451506665, 0.015260264443765794, 0.022715545824861953, 0.03567163087427616, 0.023316410636263232, 0.05226366108815585, 0.04532879571031247, 0.014330009896574276, 0.02799071285075375, 0.020848354856882776, 0.024453514887552177, 0.027498734250132526, 0.012959581201097794, 0.020259191381878087, 0.035148721254829846, 0.06416951133204357, 0.006983846700417676, 0.019231835080842887, 0.014714130266968693, 0.02480672629150961, 0.031279639939644506, 0.012842686580760139, 0.011125376364881439, 0.030558116334889616, 0.012809274668273116, 0.032613992624516995, 0.020252414513379335, 0.04570845301662173, 0.006754588377329388, 0.0640487592401249, 0.01667015503958932, 0.01153094437904656, 0.021479121010218347, 0.0064699081620866695, 0.04618311540356704, 0.08291021428470101, 0.023210499801539948, 0.015790273235844712, 0.047392505686730146, 0.0929026941635779, 0.0030994722661229646, 0.0366578509898058, 0.033500661474785635, 0.01714035096977438, 0.0044806563777716035, 0.0702841839353953, 0.019288691226392984, 0.04447174830628293, 0.016275897356016294, 0.018205946111785512, 0.05593716486224106, 0.019761082217363373, 0.009615085486854826, 0.042596192697861364, 0.03225134958380035, 0.06859595488224711, 0.021996951795050075, 0.019100619978936653, 0.015721849764564207, 0.048675449165914736, 0.03578650685293334, 0.03279739046203239, 0.07590704757188048, 0.047933861280658414, 0.04091050136568291, 0.0436475759239069, 0.041920979108129225, 0.020121740543150475, 0.029205480523939644, 0.014916862959840467, 0.03284210591976132, 0.009984556286196624, 0.02139336266554892, 0.0057569044126596835, 0.008471018618105777, 0.03611316718161106, 0.041598739435098, 0.07098641339689493, 0.026550627446600368, 0.04065364193437355, 0.027368307945185473, 0.037611314827310185, 0.003032245348939406, 0.03139377970780645, 0.004284125919054661, 0.05612843031329768, 0.044398201895611625, 0.037473422940820456, 0.01844136044383049, 0.055662656735096655, 0.022214142372831702, 0.050052607232438664, 0.024437185942328403, 0.03781750465610197, 0.03719268246952977, 0.02995368412562779, 0.03117101326850908, 0.030848763417452574, 0.04213868367618748, 0.00957335643137672, 0.013726666736017381, 0.026290185350392545, 0.016306570531534295, 0.020176311722025275, 0.030971242380993705, 0.08125304856470653, 0.05074742030618446, 0.06286012195050716, 0.07073198312095233, 0.010638212818386299, 0.07168628155652966, 0.07594755611249379, 0.016418822276006852, 0.044137814082205296, 0.009724271101211863, 0.006079726353553789, 0.01995474798604846, 0.031881907622196844, 0.021049087567787086, 0.03234756924211979, 0.04842410622430699, 0.018188037876305834, 0.031993557166840346, 0.04378007684967347, 0.020035325715850507, 0.04790689629901733, 0.026080104123268808, 0.0616447368104543, 0.039839423660721095, 0.030460943334868977, 0.09625763592443295, 0.04598972274522696, 0.051657905735607655, 0.1044719469334398, 0.02313581684471241, 0.022362911175670366, 0.04198020164455686, 0.04335988046867507, 0.008278077185553099, 0.01286743869007166, 0.014894995472526975, 0.017241181273545538, 0.00734132481738925, 0.016877968263413225, 0.02052813721820712, 0.0382444219264601, 0.02192738838493824, 0.034975121462983746, 0.02542693104727992, 0.040659453586808274, 0.04346315349851336, 0.02130733460320958, 0.024010613028492247, 0.014796351747853416, 0.01999636593141726, 0.02488400294844593, 0.02030584236074771, 0.03948012919032148, 0.045197807917637486, 0.01932205818593502, 0.019008608934070383, 0.02495659432107849, 0.06252982467412949, 0.018523057756413306, 0.009018741415015288, 0.018887973889442425, 0.030810765456408262, 0.035248560897473774, 0.05424740571262581, 0.024210419539096098, 0.023422859209988798, 0.06402600796094962, 0.019002096694228903, 0.03803568419867328, 0.03671132294195039, 0.02985405143616455, 0.03886907108660255, 0.011932649832618023, 0.03771996185449617, 0.02925582103697317, 0.04715991745303784, 0.051640657375433614, 0.051875701905893426, 0.016238766223458306, 0.020445700302453976, 0.05232271059815373, 0.01960900385997125, 0.04176927564133491, 0.015327989023977091, 0.038206291651087146, 0.0059755886156511095, 0.046586107529167614, 0.058521569041269164, 0.043998941712613614, 0.052183122374117374, 0.014984436566010118, 0.04322025492521269, 0.05181235048387732, 0.022335040349779383, 0.01956087537109852, 0.009780680261818426, 0.059806144397173605, 0.027679253402831297, 0.019138110735054528, 0.02760799365517284, 0.018386195546814373, 0.018341227334790995, 0.04136159483875547, 0.03265839595613735, 0.005314524601479726, 0.01601909560018352, 0.06531124828117234, 0.04017439604337726, 0.028637159948370287, 0.12813011530254567, 0.02793317477750991, 0.12241811252066068, 0.13955714713249887, 0.15354646289987223, 0.08271947809095893, 0.1155136658677033, 0.1827623758997236, 0.07399388416005032, 0.15345652986850056, 0.154960801292743, 0.17274570624743188, 0.09847622830420732, 0.18765839960958275, 0.11469388699957303, 0.12002899071999959, 0.14693667686411313, 0.23147451345409664, 0.09832692345870392, 0.08778522376503263, 0.13694408163428307, 0.13779940216669015, 0.08618575387767383, 0.1378916964999267, 0.2083653070564781, 0.2780516270015921, 0.1037970624331917, 0.15904049309236662, 0.13774136028119496, 0.08938930769051824, 0.17001608200371265, 0.11379235823239599, 0.10889796979193177, 0.08219318597444467, 0.10336051335824387, 0.11272410662578684, 0.16358371930462973, 0.10277772641607694, 0.1487707570195198, 0.16109949403575488, 0.16922894066997937, 0.1625322885811329, 0.12315701001456805, 0.08883012698165008, 0.1768550771687712, 0.15155732392200402, 0.11068071877317769, 0.17396459941353115, 0.13048133413706506, 0.10718747121947152, 0.09821332312588181, 0.11803333780595235, 0.1088621092161962, 0.13665351936859743, 0.06911229289003781, 0.25951445741312845, 0.13118417428008147, 0.08613487053662539, 0.1358177135033267, 0.12396059903715338, 0.12530898382621153, 0.0940136799056615, 0.14017230698040553, 0.08494019428534166, 0.10343181381800345, 0.1636575846267598, 0.2035628126135894, 0.18633529703531945, 0.167041167350752, 0.16119501819568022, 0.12817396223545074, 0.1295733864286116, 0.25646075127380236, 0.14784463814326695, 0.07062970753759146, 0.1317047192049878, 0.10249690791325909, 0.1352463055934225, 0.12089554779231548, 0.08173252176493406, 0.08449178441826787, 0.11152722513569252, 0.1390801505850894, 0.18249858862587384, 0.17108982295862266, 0.17755805301879132, 0.0763805496639439, 0.1446297527956111, 0.17877983674407005, 0.1464158333837986, 0.16900072220180715, 0.21088341836418423, 0.1279147889997278, 0.20146289600857667, 0.12660934190664971, 0.1609926519117185, 0.12139294110238552, 0.09046032772000347, 0.08131531772336789, 0.12021741989467825, 0.15045861287840775, 0.10679448409272091, 0.208144661039114, 0.10717230596180473, 0.16185063230139868, 0.09005400738013641, 0.12476580297308308, 0.1186166200786829, 0.15013701442096913, 0.10113508813083172, 0.10133840436381952, 0.1744126903691462, 0.140389655317579, 0.19726769040737832, 0.203878806371774, 0.13077732468289988, 0.1480678083109004, 0.0646826805812972, 0.07238466372447354, 0.09785274283162185, 0.10906048571424824, 0.18394795299640723, 0.13017786613532475, 0.19134266834173883, 0.18214493617415428, 0.12802895930196556, 0.1316789077328784, 0.17757464998534747, 0.14216466221426213, 0.12292010629815714, 0.1027527359713401, 0.13764853669064386, 0.12912661183093274, 0.15998776869050094, 0.06255845885191645, 0.09752375512783017, 0.20651475207081862, 0.1079657848126122, 0.10576883091458253, 0.12760895969612257, 0.1282904531274523, 0.17331521425928387, 0.1329804736056498, 0.1025351637176105, 0.07861535903066397, 0.10686243937483855, 0.10144767564322267, 0.1275680304637977, 0.14571063193891728, 0.10072911384382419, 0.08538287731685809, 0.1369128418820245, 0.0796111702386822, 0.1770609582641295, 0.12270959759397165, 0.14732614239411695, 0.11029911746404, 0.08841700093554598, 0.13639582533921513, 0.0762503252231649, 0.11467093894524233, 0.1015901340703879, 0.09254615115267889, 0.11309911935989346, 0.16314796411565372, 0.11802746169269085, 0.1798378356865474, 0.1457660953913416, 0.13967181955065044, 0.07856532385838882, 0.12376957785870348, 0.09377630121473755, 0.17326475839529717, 0.11189642282468931, 0.08859392894165856, 0.08934033781822238, 0.18395738463316644, 0.1517570982021945], [0.053205101285129786, 0.026873107999563217, 0.02190396874876959, 0.00776289777630674, 0.007816513917142791, 0.038741903446082554, 0.010699100310115941, 0.057348795900387425, 0.01085004975487079, 0.07694762173507895, 0.024227930831589868, 0.035975227797670026, 0.007498119841329753, 0.0184642219849463, 0.06013649595635278, 0.051460126348372014, 0.0521715635300747, 0.016728868674752966, 0.02626232639886439, 0.037753495055117776, 0.044483581957008154, 0.013421448113928949, 0.034912014313574345, 0.0130664733670918, 0.01829856614183102, 0.04042823938652873, 0.027313467048640763, 0.00959238424963717, 0.05656666894044195, 0.012926886839392995, 0.03559538728690573, 0.045363044765378745, 0.01643873388612909, 0.08652758624936853, 0.036436573934874365, 0.04080371691712311, 0.02760659926570952, 0.03729078506252595, 0.05075519292482308, 0.027564055120040263, 0.057018362917006016, 0.05939642459686313, 0.044702969291912656, 0.036468037603689094, 0.0775154876921858, 0.06328610623521463, 0.057862351914601665, 0.034662160756332536, 0.05862752228443112, 0.0896421501945172, 0.007956718759877341, 0.013715919589490762, 0.03409259167632886, 0.024727609108335206, 0.05541661993733474, 0.02079678449912795, 0.04367898191724505, 0.08156958515090601, 0.02505008117961032, 0.08046701324305364, 0.026080799621662924, 0.05542541714385152, 0.021234276737751703, 0.036758338633392534, 0.018960042790110623, 0.036505041510931084, 0.015092101413756609, 0.026359265304303596, 0.027516174296449338, 0.01724162232130766, 0.029530922882258892, 0.06137556196855647, 0.007489416781546814, 0.09939851345760481, 0.03360991579081331, 0.041369835646556954, 0.032214416922735314, 0.004736734645640743, 0.058661184406706264, 0.08246070519089699, 0.11495413232062544, 0.03184734983369708, 0.05145021295174956, 0.02614324350309159, 0.051646906682955365, 0.0509469570991184, 0.02434535131656698, 0.03311798808031848, 0.026288953809333698, 0.04747351258993149, 0.0899941266647407, 0.06543540661888463, 0.012499923767921115, 0.011992868967354298, 0.013642092434955495, 0.05769009222941739, 0.03068234252610377, 0.01840524372112538, 0.013977482964816903, 0.030915426090359688, 0.020858236023091843, 0.036024465691298246, 0.03688801006813135, 0.006257290486246347, 0.029673170963568345, 0.0034401129606911646, 0.032344471729759655, 0.03326725560639586, 0.053835881009165726, 0.06871784691299711, 0.06489148616258587, 0.017170038573177795, 0.058566040226391385, 0.03789693396538496, 0.005086728521356625, 0.04933867643454245, 0.06279355766517775, 0.027604953818289295, 0.03577574868021267, 0.06332871144903557, 0.02659574493632785, 0.013269729380096709, 0.0500568073642041, 0.0036002512538938648, 0.0662585035232561, 0.0655839243637664, 0.0631386809317129, 0.01666292015995298, 0.07035676004098994, 0.0261983863477196, 0.0483377015750323, 0.056364492646285465, 0.015086657866569502, 0.0275713663348662, 0.028575694853706018, 0.031815051566809416, 0.036862656607159545, 0.0432676913083664, 0.011099514002645654, 0.06329120881855488, 0.06074392729039703, 0.03540345687153084, 0.036181682255119085, 0.03273670228996447, 0.07522286035652671, 0.04382267188546913, 0.006122898992284068, 0.06075234112462827, 0.019092743883707693, 0.06936469434627465, 0.027735705820045302, 0.00036840112599228244, 0.015499921316014869, 0.028207942444298948, 0.012159952278515058, 0.053644367892827304, 0.014996648500008243, 0.02152306124168847, 0.021152123110368848, 0.035204866634947915, 0.027624689009306685, 0.0031012809860320495, 0.027272395323961973, 0.05021638183721474, 0.039504413958638906, 0.03608173404687217, 0.05621535064918654, 0.03265029764068978, 0.009215334214137068, 0.03607156959229282, 0.028721718982394253, 0.029348943182932477, 0.008639010318022753, 0.049867950712463686, 0.0008898234019787715, 0.030778419692069292, 0.06368106789886951, 0.00973522350458162, 0.017765076465106437, 0.015368419533063258, 0.03257684622492109, 0.03655260003038815, 0.02017251362225839, 0.02388691609459264, 0.005817612092609384, 0.022768217105684534, 0.006835770427382418, 0.020055491776604737, 0.0127112619811669, 0.024684654448979666, 0.03959537497056382, 0.06415503139474563, 0.0221720732016755, 0.040125948643045764, 0.01839373237453401, 0.037605886547161, 0.07333936249571187, 0.016870020922007303, 0.012429861634570574, 0.017497988118390952, 0.04876440849953464, 0.04171411074431879, 0.02571405653309609, 0.06983337883970567, 0.009643300669267774, 0.015406252949365547, 0.02308203446279679, 0.014023807398708803, 0.02763037852543805, 0.057021504534142356, 0.02940012507938913, 0.03953721773411546, 0.02547429788059422, 0.020069277911846126, 0.01861367780449135, 0.04077044155980859, 0.025859870315928544, 0.09370484469192368, 0.048310760342116864, 0.046655664153929265, 0.03191807014601571, 0.08492179241563592, 0.032011646910437515, 0.011867988838015922, 0.04203517655176776, 0.06501925430659737, 0.03552494517394474, 0.03258631178843124, 0.03879850683733821, 0.004959268686694226, 0.0733845800693546, 0.05828855333051511, 0.060641516000032425, 0.04432029589744551, 0.02249413475926433, 0.04576406913942524, 0.05217066786385008, 0.07505104171910457, 0.03519944514014891, 0.03764281581555094, 0.017858894109459858, 0.057046121784618924, 0.036918452541743, 0.033094385239694796, 0.0393853853456676, 0.02932398666494659, 0.007931523906466151, 0.045508047698863914, 0.022508375512968217, 0.026360773348382542, 0.039921380512948544, 0.04278199594201786, 0.08210586530289479, 0.02713897667958268, 0.03614401677623391, 0.024521083404709185, 0.05232174368575215, 0.03515183573056545, 0.05741075293294021, 0.058317357142056735, 0.055453847761132886, 0.05824545957148075, 0.028149822527276616, 0.02281856949308089, 0.02291122175353978, 0.030934533636484827, 0.02481162192166916, 0.04216497690816011, 0.02926130359992385, 0.0313500786599304, 0.029966318447675024, 0.06837671343237162, 0.021324908660192574, 0.022665405479658927, 0.003039549778415156, 0.06859812619430677, 0.04984854121825524, 0.021574863997687186, 0.012528456165455282, 0.012871395397399153, 0.040212268475443125, 0.032979729784918685, 0.020344953119222606, 0.025482969558132545, 0.054609064877565415, 0.010120646662211843, 0.011696483174871122, 0.04186507460794278, 0.04851904005876609, 0.016488093916060667, 0.04631755693948694, 0.036193078250757287, 0.05222566991246172, 0.04487296945548483, 0.03896163683384657, 0.04734690134812679, 0.038427283721310754, 0.03921718669256993, 0.02952606457152537, 0.03722151002979704, 0.06482203131807701, 0.015304428591792072, 0.04314266783850534, 0.02180250740743109, 0.04154458555525967, 0.02138499802510653, 0.04242983287466424, 0.054159783092992644, 0.026578447382364954, 0.02288635853411896, 0.03656581449987633, 0.017790380732289383, 0.02762285866109388, 0.06305376905947924, 0.028147157580990876, 0.0375343452074698, 0.0340511060452887, 0.06052860777292933, 0.04083693799163614, 0.022732456613864218, 0.014094502265964235, 0.034973041753151586, 0.014799143919455153, 0.01753274946739631, 0.04288220877892204, 0.018535647973684326, 0.022010145908487693, 0.0380159931124321, 0.0362913165507572, 0.024547313872192587, 0.057869218688990386, 0.07441879635942833, 0.05725523270666599, 0.028757175829793726, 0.030536494816520383, 0.05051170741873128, 0.05477465795619147, 0.01605176706133144, 0.02053536191981818, 0.020029181581256644, 0.03014993341639638, 0.020001578776698028, 0.0580570711089032, 0.014395189970465643, 0.05223549509953175, 0.028458930851359452, 0.024085245095193386, 0.012787163756521685, 0.00845217315613159, 0.029078489302524498, 0.006835521913931838, 0.009660182620531746, 0.1584084920052971, 0.08670699090829917, 0.08994931621210915, 0.11026434932968446, 0.1347263849207333, 0.2101671975106001, 0.08709977447454419, 0.14458857929067953, 0.0821532541885972, 0.13198669121733733, 0.09244169747190815, 0.22577932476997375, 0.11585391046745436, 0.1122557817559157, 0.14040131254919938, 0.13520134586308682, 0.14391488901206426, 0.11106982467962162, 0.11941482153322015, 0.12525092837001595, 0.17858425581029483, 0.10994220125888075, 0.06835134300802435, 0.13138302575264657, 0.09271467889526061, 0.08358038296656949, 0.16046779150409357, 0.18219037087900297, 0.12160119707030909, 0.1549309864640236, 0.09842939581722021, 0.1307203820241349, 0.09960863539682967, 0.13991183095744678, 0.23603736289909907, 0.10482737714690821, 0.10431329866072961, 0.26269909366965294, 0.10279311559029988, 0.16368122478680952, 0.09885509511721985, 0.1804659284119095, 0.16087983867951802, 0.14956745212631567, 0.13175227093909467, 0.20662342623940536, 0.10923273861408234, 0.06595758681318589, 0.13661720417439938, 0.15815009229949542, 0.0833158085920981, 0.17334247779633316, 0.12438875463392053, 0.09842166051800762, 0.1765147375741175, 0.11200032689209495, 0.1516628089760031, 0.15213814989796706, 0.1459592878818512, 0.1490362406309162, 0.09474697948566504, 0.1315944301230567, 0.14786096369581564, 0.1570438223757914, 0.11274690540241343, 0.11203119345009327, 0.09260701574385166, 0.1061480777072055, 0.15427932143211365, 0.09762955230793782, 0.09562108186738831, 0.09055044395583016, 0.10800687689334154, 0.13144834153354168, 0.07961408793926239, 0.14449192876262323, 0.17882349368716988, 0.14376710408500262, 0.159389409369656, 0.19017423103962625, 0.17494111987096922, 0.15849970068250382, 0.15912592065121445, 0.15017113116170677, 0.18654119170137815, 0.12127498457474367, 0.18383941453482422, 0.1062657560354897, 0.08821158124400036, 0.17480594212455408, 0.2654834214065756, 0.16600720211863518, 0.14237570017576218, 0.10067161478634391, 0.13200626016727515, 0.11451491660305432, 0.09275570990783827, 0.10985312318163258, 0.070915391136493, 0.19056451081165246, 0.15417372781251157, 0.07512382817055498, 0.16060135433716433, 0.18607016626213277, 0.1205822681742055, 0.1032958896830678, 0.18444903753697872, 0.08945681513952357, 0.1264148601996047, 0.15656048831130776, 0.1968294789216348, 0.13000587107879774, 0.15228886609630926, 0.061954006286604066, 0.14983548702938215, 0.13726994129163878, 0.15349422927413667, 0.14061414184314863, 0.14939114158707006, 0.09712232024009738, 0.13306012004613876, 0.09950499595808131, 0.1349786642406668, 0.09344354085624218, 0.14285401308110782, 0.1371798725532634, 0.12932547687419824, 0.10293374875826494, 0.1692512644720929, 0.056568840252501626, 0.1577844704900469, 0.18497328726308687, 0.11668658150093895, 0.11853819500122752, 0.13217255552964552, 0.07310321195317165, 0.12121622344212872, 0.19707407722515718, 0.10006224962749652, 0.15583060176244803, 0.1485630167382104, 0.10642764770558902, 0.11386226091001715, 0.10058305239570992, 0.13892249975885662, 0.12279809213110379, 0.13438839305724415, 0.15757219759481295, 0.146822275859969, 0.11516219829874379, 0.11087468479360853, 0.22262345839823994, 0.06958700955978461, 0.11671837765191283, 0.16687210356550558, 0.18713625334203243, 0.18003129959106445, 0.135129271873406, 0.08183477699224438, 0.16200932807156018, 0.11151030925767762, 0.0616986532030361, 0.08124351514769451, 0.11645659884171826, 0.15488628457699502, 0.15935674469385827, 0.20364635384508542, 0.0741742251973067, 0.1453775798103639, 0.07038366395447936, 0.08147379636232342, 0.1607481078909976, 0.12563362212053367, 0.13242461771837302, 0.08303921057709626, 0.12670435037996086], [0.013798399761851345, 0.05393090644585235, 0.07146299603794302, 0.05483500346807497, 0.02538869559897908, 0.015252766631809729, 0.018882581232381717, 0.011221692714441036, 0.016436274196686487, 0.04029139583664281, 0.054645563276218515, 0.03586998362360256, 0.07646416553429194, 0.007837915759799736, 0.053381303258772404, 0.03289956087246537, 0.04207040608993598, 0.0394940764776298, 0.013881443118277405, 0.041213945618697574, 0.04401072447321244, 0.06819742412439414, 0.03746731951832771, 0.02098986503135945, 0.04733129843537297, 0.06896982767752238, 0.03961647401696869, 0.010077368850553674, 0.014410916715860367, 0.04905292498213904, 0.021270554612523744, 0.03787239474643554, 0.07342272052275282, 0.08521210362336465, 0.06632896938494273, 0.04418037519125002, 0.04377222619950771, 0.06868846634668963, 0.05108026208888207, 0.06459711053009544, 0.026471449195274284, 0.01679874929998602, 0.017787524099860872, 0.005909717284209494, 0.04781622027180024, 0.03766272064032299, 0.038432352377900054, 0.02380443677040083, 0.04355082700827292, 0.012040514000026243, 0.04594453570566007, 0.08056601828762464, 0.03612437318744404, 0.013615300479744161, 0.02437830776242273, 0.02371703297831118, 0.0448951745139701, 0.09045597152518374, 0.03483568930200168, 0.06612103232847792, 0.027719675430229733, 0.021158782931576883, 0.03339472858767424, 0.04928868875971862, 0.06206120124885014, 0.036810741892882755, 0.041262793354690075, 0.035849468117313724, 0.016643743063988428, 0.021319349762052298, 0.027287642005831003, 0.04478462080338171, 0.05996112858078309, 0.036682481810982735, 0.01740184988427375, 0.015836362726986408, 0.03670065976413233, 0.026666919867108976, 0.007981909372444664, 0.05661205954051443, 0.019168909439550977, 0.028903050680777857, 0.01679613354748913, 0.01932287751697004, 0.019543036685458252, 0.02106072274701936, 0.016326656864423836, 0.03252826311758586, 0.018752495891281536, 0.043333027445312054, 0.04610189815450992, 0.07734567073306867, 0.06012901171509709, 0.04375276920784797, 0.019330360061888183, 0.04648393372605954, 0.02258607795062874, 0.022559772844293287, 0.02016204552325819, 0.017897126165085604, 0.06301346407937151, 0.021121811254748275, 0.025906599326325313, 0.02726810358996902, 0.05064497848174401, 0.037645251756267886, 0.011432637377376003, 0.05962069399122681, 0.010251592894616936, 0.03547271494088428, 0.04244369873777032, 0.05683550112215536, 0.07479365981583085, 0.0406752023845911, 0.04483511737946953, 0.028712914990527288, 0.05978739647460835, 0.05538134290171521, 0.005426046072638461, 0.050995411284800084, 0.0666602233956967, 0.02297492092475295, 0.006308890953992626, 0.0341880072706512, 0.01630487080131258, 0.043134956288018396, 0.050644968303718736, 0.031253428131874116, 0.08619468339851924, 0.011756300277608846, 0.004619408307397472, 0.03422957093321851, 0.041830211478684626, 0.0764841687466417, 0.012868250387587717, 0.14447400186743053, 0.06759413863931384, 0.025224515569529364, 0.0427354382617133, 0.04212683645476188, 0.04094417705865843, 0.01448439188035471, 0.043330001179128885, 0.011608872429600783, 0.0564831039602203, 0.031064771647964205, 0.03312061740351575, 0.01378803259493517, 0.06773493465568338, 0.04256767387102757, 0.0496729533188045, 0.054236203099467924, 0.03707972674497536, 0.010137593074302589, 0.03894684477044003, 0.053976185087646754, 0.07211789089654173, 0.008034911439088839, 0.03476550163967269, 0.03234858704464776, 0.03675742939646755, 0.05715535235192094, 0.059150034960891516, 0.07145498253937278, 0.02008914202451706, 0.011445645741852266, 0.012685043388046324, 0.01750169461593032, 0.0433704045468143, 0.0278003922597106, 0.045463335633810074, 0.0010356876508532359, 0.020352138805070093, 0.02422818019320922, 0.04255854757502675, 0.08151089865714312, 0.06493335177323648, 0.05720948587570872, 0.024627287705828036, 0.02705564070492983, 0.0058199585515207476, 0.018940455180459788, 0.02653053602469819, 0.033305949065834284, 0.029357747174799442, 0.03418928291648626, 0.025467940007469485, 0.05030861510229962, 0.04701203074572342, 0.044540602647300274, 0.0429471445802067, 0.0027857560531369275, 0.010701953549869359, 0.054072811866977384, 0.05757849357490029, 0.041630043648183346, 0.025644852746544138, 0.03885032994938748, 0.05681846650051219, 0.07804541675640003, 0.024971379599134837, 0.029058472519474368, 0.011602910651293184, 0.017768883046561053, 0.027531687303313186, 0.08948353584855795, 0.08098486438393593, 0.03871145418712071, 0.037144713436386416, 0.038370938173362186, 0.040368158503302505, 0.022589348489418626, 0.05061956395262054, 0.08179468235799245, 0.0182342936085271, 0.040088761531348736, 0.03234607307240367, 0.026140098493280153, 0.03267369692080787, 0.02086794755554625, 0.008595282128745956, 0.011453226674348116, 0.04388161961521421, 0.01972220216079482, 0.05826809549970286, 0.05255909862795046, 0.037062916039888344, 0.04831002073894654, 0.04869134384872658, 0.03560121251004083, 0.0564173369535378, 0.0755702227886234, 0.02171927151669349, 0.0681344425039632, 0.03353929386607238, 0.08093615914029734, 0.04732512715937836, 0.08781302334474665, 0.021405488086332167, 0.04518856627068349, 0.048677678153451, 0.04253461225224393, 0.050065465471042056, 0.024122584877269607, 0.03828973449500544, 0.05153147769825799, 0.04073778706203614, 0.04814691449116383, 0.04567866872197815, 0.02595639361866883, 0.042969709262251854, 0.017747892565759163, 0.041883961630186865, 0.012127804137500269, 0.019596931025651947, 0.062027579838676114, 0.039433378127536604, 0.06213990452566317, 0.0058792005958301675, 0.05505996496815767, 0.02555108259964202, 0.04046017463718142, 0.02952312651489462, 0.07740893733820745, 0.037484903753335984, 0.03208364286859121, 0.007388565273556326, 0.03561167212735329, 0.00999015589643802, 0.049231274519115686, 0.03565316454374364, 0.053492820489087274, 0.01606367195823363, 0.019142936815374663, 0.04077739993642483, 0.018669426241623502, 0.0704159215092659, 0.052408589382788966, 0.03611772693693638, 0.030456753381128823, 0.02725779664303575, 0.025571182503231933, 0.007155386714397797, 0.05568244620891554, 0.06757055276206561, 0.01599297539464065, 0.053083609590040784, 0.05781523444290672, 0.027915000217035413, 0.034346635187310834, 0.07929697459829704, 0.025762356352061033, 0.04824622148381812, 0.04792116249778441, 0.06393011739211422, 0.014139800415640431, 0.03547480822141681, 0.03490362083539367, 0.07660860528371163, 0.03016816565234746, 0.05080700585884707, 0.04177479213103652, 0.052656013784664016, 0.014076055443313504, 0.13111874993358338, 0.023487813670986464, 0.044123554668788395, 0.06163538659789732, 0.06497960072010756, 0.035929762558745484, 0.04031190795025655, 0.05445467441209725, 0.007250170422984021, 0.0065395949807550225, 0.07370830912675176, 0.02861785562708974, 0.018818291735702326, 0.040677024251116176, 0.03342691489628383, 0.06639381697667496, 0.038743576034903526, 0.07883824421358959, 0.03254072102052825, 0.009298134994293963, 0.037755452628646574, 0.038367399613239934, 0.045255083058561595, 0.05951174840863262, 0.020274132722988725, 0.04058250771569354, 0.02804625263836767, 0.04914917517453432, 0.026804665868569697, 0.04284966623942767, 0.0272455728346748, 0.03926103701815009, 0.025967530074662397, 0.03402609185182622, 0.0020006390862233403, 0.004411019601060876, 0.03780923331422465, 0.015134881350344844, 0.035794354110424004, 0.025727781600185802, 0.023228871137169853, 0.006090339489414224, 0.0611954177064555, 0.01536230932522033, 0.019041290573243583, 0.016293271245168786, 0.008007889630139937, 0.059657925207700045, 0.10807986690529756, 0.16184734819190844, 0.1695156352860587, 0.14328433998993464, 0.1181720167930637, 0.10432167178285973, 0.2676256650260517, 0.17222370925758565, 0.09648243457611118, 0.07761739686663661, 0.18394253828695842, 0.1874360301132713, 0.18524293707949774, 0.10374692548066378, 0.1278401772890772, 0.0546777495848281, 0.09860915331436054, 0.09482355216251952, 0.1490102255983012, 0.16423843774412358, 0.1567313569997038, 0.13088456035724708, 0.14080440306237765, 0.1635708407099758, 0.12825884696628365, 0.13044731239123003, 0.08215908958975758, 0.24308685319764273, 0.06819631132696356, 0.16544115463537828, 0.16076971244599136, 0.1346577171768461, 0.14624526325081075, 0.10554886343223707, 0.13871182820626668, 0.07679029660565512, 0.14429310443145887, 0.23430091036217554, 0.12910189958555357, 0.19229351303407125, 0.09255429357290268, 0.10552829703582184, 0.10646584244178874, 0.09800376437072243, 0.09946701835308756, 0.1041987415935312, 0.1827689576894045, 0.125362560951284, 0.14007796347141266, 0.09119405477706875, 0.09518749799047198, 0.11774935732994761, 0.1505035726087434, 0.14613226002880506, 0.14396313285189016, 0.18766985328069755, 0.1314497257449797, 0.19540965796581336, 0.06603449875754969, 0.16074177037392343, 0.1255873188908611, 0.2157335595360824, 0.10770707298070192, 0.19810471763568266, 0.10834065505436488, 0.14763776638678142, 0.13255614494638784, 0.13977974733071669, 0.11076698093009846, 0.1687523512435811, 0.12318519635924272, 0.15261160449257918, 0.16608608859990323, 0.1408863022391285, 0.0956897156845246, 0.18398253114095756, 0.13099830996777329, 0.09048810015831675, 0.13033719972840377, 0.16524802999837057, 0.11092206689396075, 0.08967263677290507, 0.13262983384941304, 0.1262159544442381, 0.15973966914628232, 0.10170862664069448, 0.20275891146489552, 0.1832857028182064, 0.0832165049921189, 0.13637989333697728, 0.14184300947402204, 0.24739707048450196, 0.06779716988759381, 0.1276618040033749, 0.13052516749926976, 0.154932275680559, 0.10359631784792457, 0.055680675232516866, 0.17149648256599903, 0.16943027558071272, 0.14235721688185418, 0.10627193748950958, 0.09309290788535561, 0.12118617791150298, 0.12179425385381494, 0.13519120854990824, 0.10599545482546091, 0.17149254706289085, 0.1226133406162262, 0.14947001449763775, 0.21566122770309448, 0.13119889848998614, 0.22771274245211057, 0.13522432105881826, 0.1339308297527688, 0.07896381390414067, 0.15167369267770223, 0.15263080703360693, 0.1956782221261944, 0.0898189153522253, 0.1441392126892294, 0.07752421365252563, 0.11355618733380522, 0.08613154571503401, 0.12984523469848291, 0.09932757940675531, 0.12696220725774765, 0.1564301010221243, 0.24468526457037243, 0.07963519716369254, 0.2280061138527734, 0.12222418721233096, 0.1346685601664441, 0.10704738766487155, 0.169869314879179, 0.2593202606907913, 0.11075633471565587, 0.0842956742271781, 0.1499460610960211, 0.07884452744786229, 0.06038803567311593, 0.1402918105678899, 0.09551705566367932, 0.12533502600022725, 0.15575780852564744, 0.13117052215550626, 0.110383859702519, 0.09990379134459154, 0.2080426500844104, 0.12192018995327608, 0.11351665588361876, 0.12753102316388062, 0.10440443269908428, 0.10199235605874232, 0.11655877264482634, 0.17419289930590562, 0.1236998380294868, 0.126230176538229, 0.08354033582976886, 0.11532420531979629, 0.13593687782330172, 0.17701229373259203, 0.08036668505519629, 0.21114643210811274, 0.14975969466779912, 0.0728465560823679, 0.07927017246506043, 0.07458035554736853, 0.06690894040678229, 0.1409684456884861, 0.1741376936967884, 0.09597532464457409, 0.13431691617837974, 0.10605854501149484, 0.12518717321966374, 0.1385442436273609], [0.0335295942079808, 0.04517541965469718, 0.05024485655927232, 0.013977242933054055, 0.019034919129418473, 0.04127044044435024, 0.0323533876799047, 0.12987590448132583, 0.003256374371371099, 0.017861299516100968, 0.020351802930235863, 0.01199953896658761, 0.04538378418822374, 0.037966422736644745, 0.008738807552228016, 0.06522945088467427, 0.011573140775518758, 0.07279849544699703, 0.06333870626986027, 0.03503835753404668, 0.028137318823220472, 0.06071964930742979, 0.07301061227917671, 0.018005920773638145, 0.016405867346163307, 0.02361428242043725, 0.029197517915495803, 0.04864798206835985, 0.044825370223926644, 0.035293093150747676, 0.02120458404533565, 0.051235809456557035, 0.03990218136459589, 0.055224024557641575, 0.12047432682343892, 0.01486926372828228, 0.04197539083127465, 0.037181076128035784, 0.017823047104424665, 0.0326796069608203, 0.02768331273858036, 0.06364760933709995, 0.02171923589360501, 0.006783793372700789, 0.0358469202183187, 0.01725876720489136, 0.030586475705994026, 0.04605571706114071, 0.0615638079387801, 0.0695018262735435, 0.01667761553211936, 0.0037773688257272753, 0.022028457872303467, 0.09413632511028222, 0.02885678137785622, 0.007204387120769492, 0.04577463732234069, 0.059472909064165184, 0.04750058613717556, 0.05772405290710075, 0.04152374774483698, 0.026053609027128135, 0.026815948209592273, 0.01698449147599084, 0.022219507888491665, 0.040101765654981136, 0.025460523619715656, 0.017544946134356514, 0.01346340702314462, 0.10850828713072197, 0.053326175681182315, 0.011165192799775727, 0.05422490888408252, 0.08135721726076943, 0.014480649759726865, 0.03662216344049998, 0.039857231812285523, 0.015823770813377838, 0.03267736779525876, 0.049387612380087376, 0.05512555216306022, 0.0359775483874338, 0.027455716826287762, 0.033947527674692016, 0.04725343654198306, 0.030972582487655536, 0.049872714028294594, 0.01294092827343515, 0.044066988596958775, 0.053893522558999915, 0.03412780085844653, 0.11588333174586296, 0.02029302144157035, 0.029743748783533062, 0.03540269351963486, 0.03023401747590729, 0.0400286874334727, 0.041810008098504374, 0.024499546703217284, 0.0558539595055793, 0.03138197659115706, 0.015389489741729838, 0.06780573299952916, 0.06163299136928149, 0.017848463329885687, 0.05530183556090508, 0.06417593027332, 0.04499821684190205, 0.04359728290832468, 0.0531509745466922, 0.01958702102170459, 0.022513683353151594, 0.048667442452694686, 0.03903955640271306, 0.011285935561837894, 0.02785516530275345, 0.049519383880708895, 0.016247995996049473, 0.031867919622787406, 0.027805013083187596, 0.04098557448014617, 0.02030788644749139, 0.02436722389289311, 0.05074027533243809, 0.04461935002888952, 0.039539188878344636, 0.028433355170169046, 0.04570255993998476, 0.059465519817812104, 0.023568530500467335, 0.031640210055879185, 0.012603878725453146, 0.0551540268851178, 0.021924343459042053, 0.06863871615912233, 0.01597886186625276, 0.027112754693787013, 0.04260147848565664, 0.05400693290201681, 0.050187150548611364, 0.053260771690734794, 0.01685246213206223, 0.058918586666030545, 0.07937342513884817, 0.012391920500834073, 0.01199428880188082, 0.03539314992459757, 0.06376939280224697, 0.04948261067537325, 0.06703016068786383, 0.02317602513357997, 0.06129978317767382, 0.026652702862130742, 0.06761510537139007, 0.005213528904797775, 0.006038057942142976, 0.03984715895993369, 0.022732437954151204, 0.046306340755628686, 0.04064717210297074, 0.043199573177844286, 0.037962290458381176, 0.05721308211130755, 0.04244079121521541, 0.023376452503725886, 0.03828881847273026, 0.04679056030831166, 0.04242802797151463, 0.04033242006387029, 0.0609125771692821, 0.009645822275030826, 0.06575118324586324, 0.03505644727764385, 0.025108197703957558, 0.026934591753940498, 0.026943824919206754, 0.01747701290462698, 0.07855065393128566, 0.04683092974924615, 0.021846769943035076, 0.04541982796841434, 0.10890062286385468, 0.02505463414958545, 0.04505869806078928, 0.03744035453668662, 0.04604234652859824, 0.010584134425568794, 0.02645892513516758, 0.07030318291591746, 0.02357346853906555, 0.04324898070522717, 0.01900843930031572, 0.03726118057966232, 0.07587889515395675, 0.024826532728703957, 0.029227519341345345, 0.04414983433006065, 0.050750158194984706, 0.05606838674949748, 0.01940629491582513, 0.01111171321411218, 0.03245779386322413, 0.025550392190260545, 0.03723954549059272, 0.03332092094102076, 0.018595019787816063, 0.019625806083370532, 0.046570063568651676, 0.1047982679946082, 0.00760931646384831, 0.06030748678105218, 0.013576230433370386, 0.09141485007213694, 0.0407403179976557, 0.03388056983905179, 0.059702226759067605, 0.023359056562185287, 0.02306422122221972, 0.05396754055150917, 0.05660563720656293, 0.06507929787039757, 0.07877199205436877, 0.03757366291912539, 0.015859166592625634, 0.06369655206799507, 0.04173327935859561, 0.060459546478731294, 0.017040786133813005, 0.013247419148683548, 0.08340604017887797, 0.05050371088353651, 0.013767156616917678, 0.05633216045264687, 0.026454334845766425, 0.06057848688215017, 0.008921915316022933, 0.03605270631877439, 0.0073602864784853795, 0.0026642702952293412, 0.017425561290500418, 0.03283313229413969, 0.07442882510700397, 0.019290017762354443, 0.03281763116163867, 0.026229541283100843, 0.09114743263593741, 0.05114441757489528, 0.0243096468038857, 0.08033794231180634, 0.025540243002719114, 0.02004121200713728, 0.029336454745914255, 0.00648240338445508, 0.01067013619467616, 0.014817912198070968, 0.06570215230541569, 0.03831428389198013, 0.03220939576359732, 0.06135243070977075, 0.009969244295332049, 0.07223816801394735, 0.047401523417127986, 0.026914407033473253, 0.05706643033772707, 0.05828106908925942, 0.0673636267227786, 0.015957479531477605, 0.08011759484985045, 0.086746936264847, 0.009030400342973215, 0.02780827514028975, 0.09333641374749796, 0.0023712421908775078, 0.014977998965020691, 0.02284351922571659, 0.021013057358296852, 0.03078402778399842, 0.02513330689232264, 0.01391474561699267, 0.046546548937580416, 0.05958178000790732, 0.07714042067527771, 0.02670355566910335, 0.04449732568381088, 0.04038298788613506, 0.010305394784414341, 0.026586213215653385, 0.05970321063484464, 0.016245865396090915, 0.04288405439417277, 0.0318992000871471, 0.03938906979081886, 0.06642393714615277, 0.05963089915790728, 0.03026757442525455, 0.06271518687052385, 0.02309361705556512, 0.0623567168201719, 0.005010702065192163, 0.02637876640073955, 0.04735378169321588, 0.004668593614561749, 0.04119016635896904, 0.06489475670137576, 0.03683510469272733, 0.010713532749962593, 0.042580406580652506, 0.0437230324106557, 0.03660469116376979, 0.0456169966741332, 0.033052702833499224, 0.02763070252590946, 0.016861466291759695, 0.0269364475472165, 0.04267385781609586, 0.02814643324485847, 0.06464223310883556, 0.04518232714118702, 0.019827587130878652, 0.057724650017917156, 0.05277385835402778, 0.024853594401585202, 0.0025315880733874758, 0.01604664751461574, 0.11319027375429869, 0.0692460864250149, 0.007069833202487124, 0.032735725199537616, 0.03164248654086675, 0.03989716359813299, 0.02288440435326525, 0.042249895565743954, 0.03787777552913342, 0.04053742584905454, 0.052959342686725516, 0.007617117072056446, 0.04617383982986212, 0.014771028820957457, 0.05252720408939889, 0.03024652287630098, 0.04017589221309338, 0.05591231690985816, 0.038887398317456245, 0.054448652413806746, 0.061024046902145655, 0.04766825892563377, 0.05601608866293516, 0.012594941571088774, 0.057804153966052194, 0.07589192981166498, 0.022580396916185106, 0.026671291328966618, 0.12574578395911626, 0.1944796307278531, 0.1547260960297925, 0.07243738589542252, 0.08497523383370467, 0.15997075103223324, 0.15620268322527409, 0.17450087278016976, 0.1905508315456765, 0.07369026009525571, 0.0672786266409925, 0.0648378004719104, 0.14893272332847118, 0.09930602234921285, 0.14822521486452647, 0.10720910970121622, 0.12628916837275028, 0.1465130674519709, 0.09926218220165797, 0.08587506626333509, 0.14681350918752806, 0.2461498145546232, 0.253317017108202, 0.11863261993442263, 0.07592148001172713, 0.09073514797325645, 0.10133910325488873, 0.07600931636989117, 0.189687599294952, 0.14042521055255616, 0.06832091071243797, 0.11715407855808735, 0.14805753529071808, 0.12344565881150109, 0.2031126996236188, 0.03787766696353044, 0.23505028443677084, 0.07868530242038624, 0.1533662032868181, 0.10687002539634705, 0.14683469305081026, 0.1766346347119127, 0.16271264318908962, 0.068397904081004, 0.1960268941308771, 0.15238741652241775, 0.08521840042833771, 0.07173996724720512, 0.20302955194243363, 0.13473756717784063, 0.20267328034554208, 0.14889552603874887, 0.09636577405035496, 0.17191751354507037, 0.14903647133282252, 0.12998685852757522, 0.25650276616215706, 0.16200889380914824, 0.2215006865028824, 0.09337709192186594, 0.08968494539814335, 0.09685369501156466, 0.08585199607270104, 0.1417460332491568, 0.20264189131557941, 0.2264907280249255, 0.11016594818128006, 0.09458223118313722, 0.07645297649183444, 0.21876168490520545, 0.11171047030282871, 0.11729110191975321, 0.18673518486320972, 0.207647050597838, 0.06332942391080515, 0.13425602444580623, 0.13450632244348526, 0.09696746497814145, 0.045968742442450354, 0.10215375239827804, 0.09916423567171608, 0.080792350428445, 0.14466278388031892, 0.0977171715348959, 0.1423692133809839, 0.13238724400954588, 0.12115781514772347, 0.13891757359462126, 0.1324493299637522, 0.1898856908082962, 0.09468357717352253, 0.1920524159712451, 0.13458409612732275, 0.06872529044215168, 0.1041473832779697, 0.183629570794957, 0.09513069782406092, 0.07474022518311228, 0.10856052754180771, 0.16785831350300992, 0.13268877140113286, 0.09318525650139366, 0.19057068548032216, 0.16090702079236507, 0.14887489857418196, 0.139602161145636, 0.15328182067189897, 0.16427826774971827, 0.10482684788959366, 0.07436204369046859, 0.12314395500080925, 0.09258657826908998, 0.13299655488559178, 0.11412842305643217, 0.09227629099041224, 0.10995852002607924, 0.17838720924087934, 0.19755882264247962, 0.1704881659575871, 0.20857094387922967, 0.11823776683637074, 0.2197499575891665, 0.09490961754428488, 0.16633027978241444, 0.10327995768082993, 0.10530955770186015, 0.14989443815180234, 0.09720856882631779, 0.1565142800765378, 0.06510706352336065, 0.09798217338642903, 0.13506204262375832, 0.11438280583492347, 0.12421328547809805, 0.1337975790458066, 0.14182604609855584, 0.1436417650963579, 0.1472261127616678, 0.0771319864849959, 0.12752505205571651, 0.17349280044436455, 0.10371847450733185, 0.2132427389068263, 0.13724049287182943, 0.12835362473768847, 0.06100736851138728, 0.07833943276533059, 0.14739493227430753, 0.24167509323784284, 0.16723919101059437, 0.07984581443348102, 0.1180795460407223, 0.22576286351042135, 0.12843698955007962, 0.06753915694675275, 0.15768259524234704, 0.10090798246009008, 0.14355198134269032, 0.15012569645685808, 0.09558764366166932, 0.10600664386791842, 0.11828826341245856, 0.15485972671636514, 0.08728831221482583, 0.13241129129060678, 0.11749468956674848, 0.2268027319972004, 0.2125676101339715, 0.1416572401566165, 0.16409848311117717, 0.11402443077947412, 0.20614653825759888, 0.11947054282895156, 0.08361017065388815, 0.10639800929597446, 0.06472748424857855], [0.019948300207033753, 0.022990310098975897, 0.03163901244157127, 0.04309710421200309, 0.04840647788452251, 0.054299849684217145, 0.02289843136843826, 0.032681435612695556, 0.006077691596666617, 0.07575840769069535, 0.0694812395210777, 0.02678579750603863, 0.03326173572401915, 0.0652569519089801, 0.05655928647943905, 0.06634876225143671, 0.00700702503257032, 0.060302703109170706, 0.01664667433526899, 0.03135082844112601, 0.02110958914272487, 0.03158842765593103, 0.041543781491262574, 0.040940251733575544, 0.08177009224891663, 0.001264871547131666, 0.026221880622740303, 0.056189990402864556, 0.04273069530193295, 0.0380614821000823, 0.0024383032910658842, 0.015120603277214935, 0.06803763591285263, 0.0924602011218667, 0.013720211323483713, 0.0047368415149061805, 0.004244452400598675, 0.014457019777702433, 0.06611917992787701, 0.042983500486505885, 0.04208126604290945, 0.029717425017484596, 0.03858965715127332, 0.0455184971381511, 0.019714970673833574, 0.009413945654939328, 0.02264182808409844, 0.08015419502875634, 0.05177072575315833, 0.04758363543078303, 0.06573145823287112, 0.03892481952373471, 0.07668184635362454, 0.041960907501301596, 0.050546170212328434, 0.018608258006029894, 0.024063521796571355, 0.06202393610562597, 0.01867242875908102, 0.050305833108723164, 0.02057581957030509, 0.021733234071039727, 0.06873538704322917, 0.08416927672390427, 0.024019668078316108, 0.04506171754162226, 0.03998669290116855, 0.04084631873826895, 0.04239070854548897, 0.04120748596532004, 0.013551821832412055, 0.015421399547319328, 0.05275675587888275, 0.03625764764313187, 0.08193752755011831, 0.020045719175998653, 0.013036649208515882, 0.026270906474175196, 0.08189970600817885, 0.037141103630087206, 0.06148829377655472, 0.04957267602107354, 0.039617756448153935, 0.08599206605660063, 0.05247179152710097, 0.07534555305859872, 0.013160181597673466, 0.03001578365053449, 0.10275416768022946, 0.021678637447101728, 0.014737487138648118, 0.02337597244020019, 0.009477203778390373, 0.021965428754421215, 0.03293342994792121, 0.07292000749813658, 0.030064862088433335, 0.02667520477968667, 0.017292580301208154, 0.05236831832943218, 0.042023851802306514, 0.027961276305307235, 0.03991210154656853, 0.02476455194742552, 0.037011547546301565, 0.045390209914850335, 0.04514414597568767, 0.026483186154759357, 0.05465216202927487, 0.09489395017070429, 0.0223292337863573, 0.027089379162394574, 0.023898157723514096, 0.04091708654803889, 0.066185656003654, 0.035430401497121365, 0.05827497584479196, 0.0440710394510201, 0.019198571597891192, 0.046796609448002915, 0.04898571948121701, 0.05584181372874549, 0.020617135567590594, 0.007319461570919624, 0.013067602279729076, 0.018856070869203125, 0.03209443496806281, 0.036102140987558026, 0.03428633717287864, 0.07782068595822368, 0.011403610497446997, 0.032540510674672465, 0.043663463821368556, 0.03825263898553593, 0.05792733521333762, 0.010993235062674751, 0.026797471701034477, 0.07571527321955987, 0.07304438975240503, 0.05516327531742198, 0.03150581941008568, 0.013172463929679776, 0.07169119415006467, 0.03736271995252796, 0.03906741026522858, 0.05771771539002657, 0.04633296986243554, 0.01900326207812343, 0.004922020506845521, 0.05721593874373606, 0.07072209008038044, 0.06158665421285799, 0.022217061769749438, 0.03694118346486773, 0.049079085899783034, 0.06568259014082806, 0.017116498767531345, 0.04453479438754065, 0.02017654581660671, 0.020154824214322225, 0.06678855472377368, 0.03561331757477351, 0.11194721117083516, 0.018805496261588166, 0.01692534188207771, 0.020464563575972403, 0.014099827069523079, 0.016525912065325037, 0.04912224072696907, 0.04575656454211899, 0.04107611480035952, 0.01606014696881175, 0.07328486934836421, 0.032877488128308735, 0.031841874056096585, 0.028856730487729822, 0.049263728849057636, 0.038665731104889085, 0.01664400938898325, 0.036127504626555104, 0.03930716043604272, 0.035222186241298914, 0.02090767747722566, 0.04209076553317053, 0.03211155101390822, 0.07053030215735946, 0.025974115257018378, 0.02302555999319468, 0.05039008001663855, 0.028207592998764346, 0.04444941093346902, 0.046158810279199054, 0.00859537542731102, 0.05500133614987135, 0.066754655114242, 0.07292848240051951, 0.024175585247576237, 0.04336524089532239, 0.007861980852404875, 0.0233526240502085, 0.03618104782487665, 0.029712661701653684, 0.04362023774800556, 0.07569096809519188, 0.028425228016983186, 0.02159277392950441, 0.04316461166100843, 0.03299740222947938, 0.05708669139338391, 0.03240566201774137, 0.027279100946283767, 0.006869868508407048, 0.048379774138863595, 0.0630546375843031, 0.03229438227468303, 0.09257186084453549, 0.03542493250487106, 0.025459217439804758, 0.03319184661709836, 0.014040309370362332, 0.06424042502684252, 0.05395442107692361, 0.09486229651208435, 0.034975698217749596, 0.05090624839067459, 0.04178823730243104, 0.05751008367432015, 0.049661394474761825, 0.03012099050517593, 0.013744791254534252, 0.05078602216339537, 0.022002227404820066, 0.057199280709028244, 0.05932994173573596, 0.03438746942473309, 0.026052480962659632, 0.0456333120486566, 0.03883205021598509, 0.08554612605699471, 0.016517177623297487, 0.02027401397936046, 0.042664178514054844, 0.015410520934632846, 0.0580520024523139, 0.03411395535139101, 0.043645350329045735, 0.004107748798560351, 0.025002746576709405, 0.055105097724923065, 0.0143362982198596, 0.06622108910232782, 0.0964750996125596, 0.043413006367960146, 0.05681080584015165, 0.045539216204945526, 0.018843009070094143, 0.04778731128733073, 0.04119833931326866, 0.007902385916427841, 0.02699740543695433, 0.03495367636371936, 0.04221290862187743, 0.020682846595134054, 0.018930960779211352, 0.05774990509131125, 0.08866237276898963, 0.03643609217501112, 0.05106144292013986, 0.02701265042248581, 0.045036822091788054, 0.04741041901122246, 0.02334786412705268, 0.02145529255670096, 0.029201853754264966, 0.04246622270771435, 0.05349832680076361, 0.026838760556919233, 0.014871114432545645, 0.08077235400144543, 0.05347561284101435, 0.02666510987494673, 0.01948815507681242, 0.09570986138922827, 0.03720485199508922, 0.0212585275793182, 0.031673488805868795, 0.024290654608713727, 0.029453108486320292, 0.026915697946346233, 0.02207596380529659, 0.03540541444505964, 0.02585195520493601, 0.03300568035670689, 0.0724711362272501, 0.08933820721826383, 0.02403135414767478, 0.017516057505937557, 0.04827066910054002, 0.06473330607903854, 0.027493543457239866, 0.03731061864112105, 0.019943665812856386, 0.01901643074649785, 0.014309757322605168, 0.03900734295270272, 0.04416766283767564, 0.02857496203588588, 0.022511160899219767, 0.05054219738979425, 0.08115171614502158, 0.05232428479939699, 0.043947556255651374, 0.015786224078120928, 0.02019936834195895, 0.05597145462940846, 0.06841669950102057, 0.029956683250410215, 0.008035729073786309, 0.012161578218053495, 0.05236345662602356, 0.02044128134314503, 0.030472458074135438, 0.016239185218832324, 0.04049478670848267, 0.03282240126281977, 0.09566407384616987, 0.022522969104881798, 0.038764203499470434, 0.013457457119199847, 0.04686931786792619, 0.07665446746562209, 0.019099697171311294, 0.03121241068999682, 0.03809705090575984, 0.022179621903757964, 0.021110873270247663, 0.005273871448090566, 0.017025865148752928, 0.020557119145191143, 0.018312014705900635, 0.0532163378250386, 0.021050368302634785, 0.028439579032627598, 0.009322731888719966, 0.03201191832444497, 0.02991435962862202, 0.01978655781463853, 0.06463790405541658, 0.04356717291687216, 0.04897681710177234, 0.031087875765349184, 0.005814136296976358, 0.10225433842944247, 0.0754291485728962, 0.12148907594382763, 0.1396220557923828, 0.14455834377024854, 0.08383893195007529, 0.15076394006609917, 0.11054786161652633, 0.10035480000078678, 0.16701568157545157, 0.0995386920071074, 0.1329551778201546, 0.1251829391611474, 0.2500414843005793, 0.14325508155993052, 0.1451474478734391, 0.06633961559938532, 0.1371471807360649, 0.15511596868080751, 0.15310422091611794, 0.09552421420812607, 0.11751296930015087, 0.1595044889088188, 0.1101946502125689, 0.17059943212994508, 0.11499062393392835, 0.09986670940582242, 0.2156422965760742, 0.06463109834917954, 0.09729582164436579, 0.13918319291302136, 0.09806838126054832, 0.1643711591937712, 0.17523166856595448, 0.12687459481613977, 0.1181679048708507, 0.10250251261251313, 0.2360181739287717, 0.0948823472218854, 0.1762094646692276, 0.11659837194851466, 0.09734154811927251, 0.11560180756662573, 0.12095547600516252, 0.10605642119688646, 0.1765460316091776, 0.17933999454336508, 0.15355394035577774, 0.12095031913902078, 0.1920225332890238, 0.23881829796092852, 0.12315090319940022, 0.13596699120742933, 0.09948700120938675, 0.15183001357529843, 0.1056619141516941, 0.12874804357332842, 0.13538950362375804, 0.12654516606458596, 0.11994110686438424, 0.16959818585642747, 0.1129227341817958, 0.2608346422868115, 0.14911340363323689, 0.1342584943132741, 0.09568638407758304, 0.11263020416455609, 0.10441918405038969, 0.12005288872335639, 0.10133037050919873, 0.1488991765571492, 0.11952165008655616, 0.16343085893562861, 0.0952926098502108, 0.17870673138116086, 0.2591394989618233, 0.1115621289770518, 0.11589965729841165, 0.19445436208375863, 0.2182466768260513, 0.12889958758439335, 0.11107603327504226, 0.06845472460346562, 0.16103168124599115, 0.16008846328726836, 0.1012891698628664, 0.08118787527616535, 0.11769811436533928, 0.1781205449785505, 0.14889965153166226, 0.06955883678581033, 0.08751719564731632, 0.17206387354859284, 0.21837097087076732, 0.1257881245442799, 0.20311584802610533, 0.14692231906311853, 0.08168364688754082, 0.21572480643434183, 0.23047467853341783, 0.11512061767280102, 0.0841096199250647, 0.196418910952551, 0.09135792098407235, 0.12545338964888028, 0.14978037641516753, 0.15230045547442778, 0.11768527648278646, 0.12781631999782153, 0.1676798045103039, 0.063599799759686, 0.10383691279483692, 0.11243963760456868, 0.16219763510993548, 0.09165910232279982, 0.048312782376472435, 0.15096961760095187, 0.1011821920318263, 0.14351323699312551, 0.18413224310747214, 0.09695735480636358, 0.24311003195387976, 0.1242576345269169, 0.10828470305672713, 0.10983065688716513, 0.11894446105829307, 0.12668134804282868, 0.11449492696140494, 0.08408945386431046, 0.1631991392267602, 0.07515441652919565, 0.20622007788292, 0.08256164406027112, 0.21146527571337564, 0.20157607564968721, 0.16185587059174264, 0.10188041813671589, 0.14792756869324616, 0.22853512689471245, 0.22059305092053755, 0.09604922389345509, 0.11768910342029162, 0.1722596444721733, 0.15595917057778153, 0.16307420735912664, 0.14644406044057437, 0.07539133381630693, 0.20738828448312624, 0.07739823684096336, 0.2048157410962241, 0.08976842556148767, 0.15635060385933944, 0.11901616863906384, 0.08865311076598507, 0.18990026574049676, 0.201867153601987, 0.1511339180703674, 0.09182824074689831, 0.1083866325872285, 0.10378512700221368, 0.1383433158376387, 0.12312400607126099, 0.18777465979967797, 0.11447356667901788, 0.18458376745028154, 0.08733465615659952, 0.12526794602828367, 0.2105138881930283, 0.16784808119492872, 0.15450748561748437, 0.14936648362449237, 0.11193984906588282, 0.1396395077130624, 0.1281125819576638, 0.1346746398402112, 0.06414343523127691], [0.03740441253674882, 0.012139664929626244, 0.06162723060697317, 0.023206878120877912, 0.018895736330055764, 0.057723374372082095, 0.03911169146054557, 0.0678788587184889, 0.016828182452757443, 0.01344963869944747, 0.017160630685144236, 0.009058172781286495, 0.012123729534713286, 0.036237949771540504, 0.020221851599801863, 0.0401895884424448, 0.05803896779460566, 0.02835370703334255, 0.03545138519257307, 0.0412827626402889, 0.021391377950619374, 0.02471751589993281, 0.04250614092286144, 0.05136042241273182, 0.019951275583090525, 0.06374695364918027, 0.05083222361281514, 0.03237667160906962, 0.024743191665038466, 0.028965333410139595, 0.032925121286617856, 0.021310276052515422, 0.05698808668447392, 0.04798090411350131, 0.051003852260432074, 0.012342520606970149, 0.02963160051565085, 0.046183695551007986, 0.013470535881684294, 0.03532476377274309, 0.040051883153085194, 0.042556495006595335, 0.07007374987006187, 0.062251021420317035, 0.048086986278316805, 0.052734584747148414, 0.03681466382529054, 0.04842803833474006, 0.0653589628636837, 0.04509129149041005, 0.026338300268564905, 0.0530134694251631, 0.02659605197342379, 0.09526116653744664, 0.0540567373723856, 0.0678802157885262, 0.03244719175355775, 0.0152010469963508, 0.02106614763449345, 0.04798318738383906, 0.019889825755464177, 0.026772711958203996, 0.03623191759522472, 0.10618127842566796, 0.029862750255103623, 0.02341615019499191, 0.0593099928061877, 0.02495858073234558, 0.07898132010762181, 0.04543429433501192, 0.06261813600680657, 0.03127733970593129, 0.10225210604923111, 0.026036981526496153, 0.0346020832657814, 0.05673646215083344, 0.016987885847421627, 0.03841550096071192, 0.024157037492841482, 0.09751745153750692, 0.07039738393255643, 0.04202026574473296, 0.01535686238535813, 0.041201748951737366, 0.02118579201799418, 0.016478155074375014, 0.07051043465201344, 0.024142126685806682, 0.016378646217552677, 0.03317778058616178, 0.0403127900457808, 0.027222862267600637, 0.07770133843379361, 0.0755304606365306, 0.009948326757044663, 0.05106374315385308, 0.03436026356316038, 0.03762251404779298, 0.04771019917513643, 0.06756586408508675, 0.04940905408667667, 0.02204847804802869, 0.026567212538793683, 0.061595549806952477, 0.03303566821185606, 0.07244537903794221, 0.0495013077078121, 0.028259290581835166, 0.046257116432700834, 0.026627179767404283, 0.01860756759664842, 0.024122556039531316, 0.023345923516899347, 0.043828015348740985, 0.023656994503523623, 0.06260579345481736, 0.030113082179533582, 0.045772571183208904, 0.08778577337839774, 0.06759844733668224, 0.06334161718509027, 0.054336683957704475, 0.053379064093210866, 0.06182460965854781, 0.023782470895509635, 0.023575132646198784, 0.04791784446154322, 0.04357807358194675, 0.06168110628745385, 0.02905147003808192, 0.04565656205107059, 0.031045813379543166, 0.025161941070109606, 0.0246385259420744, 0.0519788833335042, 0.03482004228447165, 0.020279277714767625, 0.011075042637198098, 0.028902389109134674, 0.08036929741501808, 0.005879054286716772, 0.03610545902379921, 0.02883200127897518, 0.02754650141910783, 0.06113240894462381, 0.02454106286833329, 0.008590376320561128, 0.03723135896559272, 0.016584883543795774, 0.03412466602666037, 0.014827652568263667, 0.04002499281029616, 0.014995398299236382, 0.033561461605131626, 0.012695486890152097, 0.02720979877215411, 0.03163019487900393, 0.04514569303553019, 0.06327201306287732, 0.027997030011777366, 0.021691741654649377, 0.02878652586202536, 0.020341092254966497, 0.013393239716866186, 0.0516288644368095, 0.013831856627283352, 0.02230062844630863, 0.04584889280210648, 0.06810147927275725, 0.042104672108377726, 0.09084939969969646, 0.012239372257941535, 0.031625414599797556, 0.0424357734487525, 0.02717751746864191, 0.024488299985283186, 0.054827274954212565, 0.029915726876684597, 0.03878394208316292, 0.039030155300029686, 0.05723913785602365, 0.020078829988571148, 0.05991352256387472, 0.06214073233838592, 0.05037063659567918, 0.013084163623196738, 0.017059545930741087, 0.04387771803885698, 0.014276926405727863, 0.0061540034616232985, 0.03646676195785403, 0.025215502928144166, 0.006287112100315946, 0.02561585046350956, 0.045289036950894764, 0.0172014140324401, 0.02930071291380695, 0.01812453887292317, 0.06263085853840623, 0.02158616839109787, 0.030390273912676742, 0.03863918681495956, 0.022106582698013102, 0.028681424180311815, 0.08723297089870487, 0.05299629570384111, 0.021501412581918494, 0.016322882513382604, 0.0430087453818747, 0.049943658257169385, 0.03977473552471825, 0.014611186326614447, 0.01638425261314426, 0.03240305305059467, 0.049046064993100505, 0.008667779354644673, 0.019419600987540822, 0.02601349912583828, 0.04457938092361603, 0.018457628320902586, 0.01859541842713952, 0.10560454401586737, 0.016660792952669517, 0.044638108129480054, 0.06008349558604615, 0.036876162846705744, 0.025380595587193966, 0.04523122237463083, 0.032701547390648296, 0.019508212571963668, 0.04828727624512144, 0.06418006255158357, 0.03768644222457494, 0.03921282371240003, 0.02388932998292148, 0.02778537119073527, 0.036803990469447205, 0.052741319207208495, 0.011016362928785384, 0.033987764801297865, 0.021833733588989292, 0.02484990656375885, 0.07271121548754828, 0.06428347128842558, 0.04640260112604924, 0.07417886637683425, 0.07027487443493945, 0.023464545008859465, 0.025365415062489252, 0.026304186920502355, 0.024799313296430876, 0.06915966141968966, 0.006576296515829329, 0.04191471283723201, 0.06286327035299369, 0.02442256690535162, 0.029761319447840964, 0.022483169633362974, 0.004331773920317313, 0.03896560626370566, 0.025906879222020507, 0.017200090889153734, 0.03134430093424661, 0.024324040227968777, 0.014831353976790394, 0.02841196265736861, 0.028350585772256767, 0.062159602397254536, 0.05470837187021971, 0.05553292762488127, 0.017802107513749173, 0.03022403622578297, 0.04302292676376445, 0.02352080913260579, 0.017505146662837694, 0.08256540314427444, 0.00864209171517619, 0.04098719617884074, 0.024546294373327067, 0.014908737502992153, 0.014352576274956976, 0.06743507646024227, 0.013189373870513268, 0.057342071618352614, 0.035008600380803855, 0.017947534531620995, 0.049325577316007445, 0.05197749233671597, 0.03434385997908456, 0.05647508028362479, 0.041626786680093834, 0.05560905586129852, 0.0143440046813339, 0.024992459985826696, 0.03203728196344205, 0.01394843912151243, 0.03774965793958732, 0.017666558269411325, 0.0331063342413732, 0.03785600134038499, 0.01588011296865131, 0.015102840926764267, 0.03240463064451303, 0.024950842040457895, 0.03616257131631885, 0.013338503145080591, 0.04629947737391506, 0.014997501757794192, 0.014710696879774332, 0.03918643209284969, 0.03805867635778018, 0.0329855923274798, 0.048381236381828785, 0.03449112243418183, 0.034304281031446796, 0.0658733466906207, 0.055432833531605344, 0.012287949428095349, 0.019307035420622145, 0.08187915318246398, 0.031006085154201304, 0.017493545410356352, 0.08320735155471734, 0.027139254878940325, 0.04527952728260841, 0.0762375687648143, 0.021878125046246817, 0.06356782718960728, 0.036372761109045575, 0.021438556490466, 0.05450609718848552, 0.02072056126780808, 0.05134137932743345, 0.07995264298681702, 0.04228163404124124, 0.025777967746502588, 0.01690696206476007, 0.02920825233949082, 0.01579694832409067, 0.008671177118750555, 0.004137222663432891, 0.01348645261688424, 0.028680216387978623, 0.01563343495529677, 0.04204663700823273, 0.01729832579647856, 0.029193853826395104, 0.027837323224438087, 0.007991407166368194, 0.08541899573590074, 0.04415876045823097, 0.017593659859682833, 0.10803828627935477, 0.06431129122419016, 0.14088749646076135, 0.10695671503032957, 0.12760511918791703, 0.1020335838464754, 0.10868551369224276, 0.1260451671800443, 0.11090490674333912, 0.1025465563205736, 0.09331802544849259, 0.07284395729324647, 0.12091730162501335, 0.08240434607224804, 0.14869909015085014, 0.11320406158587762, 0.21671454475394317, 0.10659893708569662, 0.11092879117599555, 0.1250657561634268, 0.10415854517902647, 0.12473488891763346, 0.10606896052403109, 0.1609593087009021, 0.12684060021170548, 0.1750842093357018, 0.17293011849480017, 0.12501190762434686, 0.13733185082674026, 0.10829171232346978, 0.07463180207248245, 0.15322846067803247, 0.15976349929613726, 0.12720504137022154, 0.10126533292766128, 0.08152797738356249, 0.10388835253460066, 0.1508038786372968, 0.12148268414395196, 0.14676818304828235, 0.10550622429166522, 0.1287170345229762, 0.12863774092069694, 0.14056577586701938, 0.08874226348208529, 0.13958010875752994, 0.11218435915985278, 0.11864125089985983, 0.11360321659594774, 0.10671862387763602, 0.13249969083283628, 0.17553284311933176, 0.07901589146682195, 0.18358957794095787, 0.2807228836630072, 0.23517898895910808, 0.14884459520024912, 0.11804475076496601, 0.16106955707073212, 0.11972408422401973, 0.10541758726217917, 0.08430870888488633, 0.12923072624419416, 0.2590237951704434, 0.13043779933026858, 0.10562774991350514, 0.14120796855006898, 0.09502567417387452, 0.1566702617066247, 0.12592605714287075, 0.16086991849754537, 0.2007256948522159, 0.15237813416336263, 0.12546187133661338, 0.22140647870089325, 0.15535101321126732, 0.1743640394083091, 0.11451398022472858, 0.08562120595680815, 0.17839586734771729, 0.10634827267910753, 0.0672247102484107, 0.08958942123821803, 0.10484539225165333, 0.14713129427816185, 0.1746103476200785, 0.1648626085370779, 0.07518067583441734, 0.09324673855943338, 0.10562015710664646, 0.18105268478393555, 0.17213296198419162, 0.19305739418736526, 0.18111916764506272, 0.1007928147113749, 0.11213308226849351, 0.1660966058926923, 0.15309252297239645, 0.2132368085107633, 0.1521401990737234, 0.06564729953450815, 0.1612328125962189, 0.06914478793208088, 0.1565441627587591, 0.12581074690180166, 0.13341887508119854, 0.2770613187125751, 0.17561783641576767, 0.07550615551216261, 0.09634771144815854, 0.1295230934130294, 0.13653647207788058, 0.13310464551406248, 0.16879834234714508, 0.0904936912868704, 0.1632962647293295, 0.1686707099101373, 0.09632788465491363, 0.20024122084890092, 0.09317401996148483, 0.11458583708320345, 0.10035717487335205, 0.11785159898655755, 0.18349307669060572, 0.07417796392525945, 0.11450705916753837, 0.19655303018433706, 0.09319938360048191, 0.17225549183785915, 0.08517481133873973, 0.16288531678063528, 0.11007735864924532, 0.07601302117109299, 0.20983964151569776, 0.14804604090750217, 0.1720536005284105, 0.12767795313681873, 0.1705510254417147, 0.12929159083536693, 0.1739358702408416, 0.10189438917274986, 0.10303931523646627, 0.129104898710336, 0.11672364308365754, 0.14261250889727048, 0.07976234784083706, 0.19114729096846922, 0.09408172339733158, 0.13265856302210263, 0.10009331974600043, 0.08784832752176694, 0.10815721311207328, 0.13349945790001325, 0.17479285996939453, 0.12503325433603354, 0.06896995659917593, 0.10386283961789948, 0.25065113444413456, 0.17572343003536972, 0.10354628946099963, 0.12652163447013923, 0.11466312222182751, 0.09557103312441281, 0.10289908918951239, 0.1253865132374423, 0.08200855659587042, 0.22470253040747984, 0.11360110635203974, 0.14383354623402866, 0.08923835400491953, 0.11710605184946742, 0.09288936773581163, 0.13773574201124056, 0.18878696619399957, 0.18808384106627532, 0.073543017996209], [0.017870291801435605, 0.043955335659640174, 0.021043011286695088, 0.012265869898588529, 0.08533921358840806, 0.03596835423793111, 0.04005542849855764, 0.0166199129141335, 0.02416633002992187, 0.009234946420682328, 0.021346265549904535, 0.026054352022973553, 0.05585945563923035, 0.05084732440965516, 0.02584425383247435, 0.0063400895700656944, 0.04523629781657031, 0.04221635218709707, 0.04673442171354379, 0.014000339416920074, 0.03943058256325977, 0.04111641299511705, 0.028055472232933556, 0.029871991902057613, 0.04072521720081568, 0.01743680631209697, 0.024004653794690967, 0.022227229617003883, 0.038178057808961184, 0.018456569806273495, 0.04460604056449873, 0.05442066623696259, 0.015619731940595167, 0.021714664263916866, 0.02920912086431469, 0.026991112024656365, 0.04645577113011053, 0.027579356084710786, 0.057487223829541884, 0.07382995009954486, 0.07415373343974352, 0.05118654442152806, 0.02834717952646315, 0.05558373971975275, 0.06439317004489047, 0.014157631467761738, 0.020642528044325963, 0.009878532645026488, 0.017118176445364952, 0.00842086470220238, 0.04596502407054816, 0.027035866498148868, 0.015286549194050687, 0.011343773886827486, 0.021803801712979163, 0.049749380110629966, 0.02655808624279286, 0.023275734158232808, 0.10794610729707138, 0.04236228471355779, 0.04979730164632201, 0.01803734033767666, 0.03514083667791315, 0.026150902467114583, 0.047564612701535225, 0.013510534672864845, 0.05337440934298294, 0.013812434410543313, 0.0639177341280239, 0.02222729747050575, 0.024244480300694704, 0.04241999750956893, 0.01446260412090591, 0.04185975489339658, 0.047915567976555655, 0.028823869036776677, 0.029765200668147633, 0.06929988746664353, 0.08877407320375953, 0.031945778123502216, 0.03172726949144687, 0.0294176618169461, 0.020720106649345586, 0.028903705467070853, 0.027048073343134353, 0.029522336021597897, 0.03709244927657502, 0.042272270257983885, 0.06794595226113286, 0.049086006956973245, 0.05719014762767723, 0.023735760544825877, 0.04277817578986287, 0.04072121723688074, 0.03240210310156856, 0.030231045492525612, 0.055021444535149, 0.01840321659775717, 0.033833035068320375, 0.03735837732840862, 0.02859766242493476, 0.02317702427639493, 0.009921695105731487, 0.042866049467452934, 0.023041076392733624, 0.06191397950585399, 0.009018151937717838, 0.013235554115713706, 0.02271987996729357, 0.0585970085646425, 0.04114314388217671, 0.015804220523153032, 0.08803392720541783, 0.046837918659938235, 0.048611096904746125, 0.06497803330421448, 0.016627646517008543, 0.026315416675060987, 0.018459718208760023, 0.03578357218897768, 0.0175887065540467, 0.013294333908041673, 0.025498065265959928, 0.014898233780903476, 0.045776818812425644, 0.044527188009981594, 0.03842531257708158, 0.011323129458885108, 0.07804686203598976, 0.04921436881912606, 0.05203675219256963, 0.014106851603303636, 0.048357066964464526, 0.047598057692604404, 0.038666830331619294, 0.03858681069687009, 0.04169144428202084, 0.022094732083912407, 0.05458795565313526, 0.025884075356381278, 0.022887469635211995, 0.03613892097824386, 0.019148127608267323, 0.03486946338255491, 0.03041089798456856, 0.0009411384609328316, 0.06206839372004781, 0.004394792436089898, 0.00901201119579907, 0.017150418733113577, 0.03189870475658348, 0.05113609195021646, 0.010720275691710413, 0.017615425566743528, 0.01994176591480417, 0.01914635663186865, 0.037769413486655266, 0.058817396738699505, 0.01417627845824297, 0.05702115848128285, 0.04193124873563647, 0.026015790877863765, 0.021544670885694877, 0.039068339858204126, 0.008337142810757672, 0.022397280670702457, 0.04938338849959629, 0.013413760312167662, 0.03730214034606304, 0.08333655819296837, 0.037389142106154134, 0.04372773126565984, 0.018110016527186548, 0.026621897372284105, 0.08211253530212811, 0.011975548512834524, 0.02310162376878517, 0.02332247165031731, 0.04398658898259912, 0.0192781654519162, 0.01336377433368138, 0.055881236613328965, 0.024622529479009763, 0.05526740669405886, 0.034816999054913006, 0.007847654433654887, 0.0374265633124326, 0.08331011568329164, 0.01881165735955749, 0.010146190961157637, 0.03857955376484564, 0.014405237377754279, 0.01950901324328567, 0.05209943865026746, 0.05898816364684275, 0.039698403727795394, 0.017663465846063833, 0.022976518874721866, 0.024689855419897606, 0.06494331266731024, 0.03764202192957912, 0.03481992014816829, 0.009719934414273925, 0.029239749935056483, 0.03234036998557193, 0.024237396395100013, 0.007984699847708856, 0.06485213113150426, 0.017035525791080933, 0.03521809128246137, 0.02655125848416771, 0.05145551909559539, 0.09384152878608022, 0.047526217797505, 0.07255410748933043, 0.05034470637994153, 0.013968865570080067, 0.02112811484507152, 0.02858391191278185, 0.04649063425936869, 0.05561627208122185, 0.0036333875115295605, 0.012310362287930079, 0.037241910185132704, 0.013597447375234748, 0.023285730675395046, 0.06919043976813555, 0.06837701198777982, 0.004086833804779286, 0.04625533188560179, 0.007886684616096318, 0.03795611918238657, 0.02745242423510977, 0.03208985824936202, 0.05456954360540424, 0.03485487487965396, 0.05129575463277953, 0.03274074635867562, 0.03533678402059844, 0.013387748672227775, 0.05608492264790194, 0.041857936419546604, 0.026805690456447855, 0.06782722898891994, 0.04224171921876924, 0.01715702936053276, 0.02733146519001041, 0.03152548335492611, 0.05374768163476672, 0.021814578545412848, 0.0169090807903558, 0.0358043964287, 0.058220231639487405, 0.046666931227913926, 0.03235771334064858, 0.021691695853535618, 0.01607187883928418, 0.023714915949053, 0.04433194295104061, 0.03419658734596201, 0.020779972097703388, 0.04390716985134142, 0.021705356459798555, 0.027441267423065643, 0.020962942458157028, 0.04932077668075051, 0.07730769991342511, 0.012267969964471246, 0.0652244636522872, 0.0451152166351676, 0.06849402535174574, 0.013889481213742068, 0.03156933368050626, 0.041958546199436696, 0.029061033989169767, 0.025579396169632673, 0.060112279041537216, 0.06642334003533636, 0.08008490303265196, 0.027821104541154842, 0.020290727993207316, 0.055593642938349924, 0.06007263224039759, 0.047126984755907736, 0.021915824451882924, 0.03940826554649642, 0.030950167083314488, 0.023975366526948552, 0.030770477439676012, 0.06708853505551815, 0.022477602253534963, 0.03931734185399754, 0.01598568962487791, 0.010476864824470664, 0.00945106491313449, 0.025773195948983942, 0.06836312237594809, 0.033583439354385645, 0.03724985583020108, 0.029727555545313016, 0.014971841259726455, 0.009253750322386622, 0.028780059423297644, 0.01906991796568036, 0.009705040570614594, 0.03868168346317751, 0.01979518708373819, 0.0026602883548808415, 0.05614145479298063, 0.05214955185406974, 0.03654525488881128, 0.08624378219246864, 0.05916938677962337, 0.0070535055295165095, 0.029675997061921016, 0.025942264823243022, 0.041969864163547754, 0.06852909204150949, 0.038803456750299246, 0.03174775107098477, 0.047135551260518174, 0.005289938733247774, 0.07469745033553668, 0.04448803993208068, 0.03178893814661673, 0.02476952730544976, 0.03305431774684361, 0.04450806689315608, 0.048748239010040245, 0.05163648099239383, 0.026136066298931837, 0.036766216424959045, 0.026285567919590642, 0.019798221831609095, 0.05740517537508692, 0.02618809466782425, 0.024234073269846182, 0.03206228258620415, 0.04078371709744845, 0.042634808125772646, 0.02821850384186421, 0.040710241932954104, 0.0432326517600034, 0.02066599008893328, 0.025879188207909465, 0.06090216165674584, 0.03539514821022749, 0.056026500782796314, 0.040487696017537794, 0.02102007171405213, 0.033574645540543964, 0.02959304954856634, 0.10470329344804798, 0.10716086586139031, 0.15175298627998146, 0.10183445417455264, 0.26403434202075005, 0.12725412659347057, 0.12081443571618625, 0.18443429975637368, 0.09340109849082572, 0.0970039837328451, 0.04231240560433694, 0.21543356563363755, 0.07999148233128445, 0.1271521020680666, 0.18222845026424953, 0.06871074265135185, 0.17303385292845114, 0.11377154077802386, 0.14723410590418748, 0.13378193202827657, 0.06524150166660547, 0.13481911351638182, 0.14261577943606035, 0.10453458250101123, 0.11244963242539338, 0.08376930747181177, 0.09643217548727989, 0.08416637937937464, 0.12005040528518812, 0.10991117185247795, 0.10584612962390695, 0.19945919566920825, 0.11329427960195712, 0.08283401480210678, 0.09505460690706968, 0.17540321578936918, 0.16405659035912581, 0.14411342835852078, 0.13302655970411642, 0.11150355104889188, 0.18547632598451205, 0.108096511369305, 0.11948229505547456, 0.1624247543513775, 0.1314285418816975, 0.0652676931183253, 0.09090338394578014, 0.12052342561738831, 0.09375035403562443, 0.05712357655699764, 0.21273340338042804, 0.09118357819638082, 0.08268647414765187, 0.0927348653120654, 0.09298825064407927, 0.14624953802142823, 0.10615341099245207, 0.1401193676782506, 0.15422098099121026, 0.09208651153104645, 0.16310539282858372, 0.09336174345974411, 0.09094640306596245, 0.14736815728247166, 0.14449487360460417, 0.06969512732965605, 0.10757247198905263, 0.15178231256348745, 0.11865645008427755, 0.0758482457271644, 0.08483705696250711, 0.12764858614121163, 0.14570295092250618, 0.13080048986843654, 0.11168277928871767, 0.1403659473040274, 0.1478967767740999, 0.2586759781198842, 0.08525116688438825, 0.10131817044956343, 0.11121741283152785, 0.0806155309879354, 0.1418420866663967, 0.06372802930751018, 0.1627354012536151, 0.19994949150298322, 0.12966971125985893, 0.0956365049683622, 0.15377245577318327, 0.26049475052527016, 0.19353295224053518, 0.13195190951228142, 0.15931838032390389, 0.12003382188933236, 0.1102374182747943, 0.11668215745261737, 0.09521288198551961, 0.0807490191821541, 0.16944919313703263, 0.20698499040944235, 0.12477751448750496, 0.12407053528087479, 0.15766223919178757, 0.11973612143525056, 0.11904590204358101, 0.1769809318440301, 0.142324172226446, 0.08912950341722795, 0.0756300152944667, 0.11475823926074163, 0.15356338556323731, 0.11144093583737101, 0.1082268375903368, 0.17287656851112843, 0.0874397883723889, 0.08819765092006751, 0.11464169408593859, 0.1312860223863806, 0.10198586247861385, 0.17008614752973827, 0.11225249086107526, 0.16007660249514238, 0.0848127586234893, 0.10039488106433835, 0.11460434751851217, 0.08478860277682543, 0.08885349572769233, 0.08649890457413026, 0.17153077572584152, 0.12992429759885582, 0.12187411742550985, 0.064685292941119, 0.15742990880140237, 0.16378244864089148, 0.2552945395665509, 0.10686617131744112, 0.09518003410526685, 0.16038355816687855, 0.047086316759565046, 0.06860206848276512, 0.198556567675301, 0.18304448361907685, 0.10799779130944184, 0.14577871614268847, 0.1253526814814125, 0.06797460679497037, 0.18751376308500767, 0.14241653441318444, 0.1379103155008384, 0.07746154415820326, 0.13784953233386787, 0.08540346406932388, 0.20442558346050127, 0.07999932619610003, 0.06120783489729677, 0.08015505676823002, 0.151522392939244, 0.05670758370043976, 0.09074713090168578, 0.14185165401015962, 0.10084929596632719, 0.1307542273508651, 0.13594500667282514, 0.10960433153169495, 0.1175389571913651, 0.09233247368995633, 0.07914632625345673, 0.11317203473299742, 0.11806759025369372, 0.14336166584065982, 0.10572805774531194, 0.11480226261275155, 0.08402023650705814, 0.12806319817900658, 0.133672280769263, 0.07644990272819996], [0.0038897567012879464, 0.04472445510327816, 0.02824681232284222, 0.035243889183870385, 0.03987234957250101, 0.07292241629745279, 0.029390700227980102, 0.08744679085378136, 0.002905815191167806, 0.023036518333745853, 0.046591498489890776, 0.03278508862214429, 0.030787820794752667, 0.0280454604487334, 0.06422331237367221, 0.043015242354678254, 0.02081125765107572, 0.04331859500546541, 0.06411976792982646, 0.02824552819531943, 0.05401466480855431, 0.02721058756911329, 0.018585386286888803, 0.0221710944149111, 0.04991986881941557, 0.04770899138280323, 0.05222233152016997, 0.05990214353161199, 0.015041184145957232, 0.06886407799486603, 0.016287498608497635, 0.007491741612154458, 0.028261188783549836, 0.008944868459366262, 0.03500272426754236, 0.06675167634551014, 0.005868860994399126, 0.09365115221589804, 0.01763315059776817, 0.0013753173282436493, 0.07098276966384479, 0.06581096896635634, 0.04283632624096104, 0.008629964598055397, 0.04515072437269347, 0.018252485132377063, 0.034766848531684706, 0.05031989235430956, 0.019010454549321106, 0.04552190338394471, 0.015507057808073503, 0.059903724518205435, 0.017586884687521627, 0.04182517335617116, 0.04298386350274086, 0.03315435416464295, 0.024480968414406692, 0.012218391955164927, 0.018864484703434364, 0.04682107402810028, 0.0059022080219749895, 0.014944835565984249, 0.06508328087095704, 0.021396548387461474, 0.03065167274326086, 0.03779563886512603, 0.02867920197812574, 0.04620218902294125, 0.03005791049716728, 0.031096079253724644, 0.01170077660520162, 0.08481381035276822, 0.034979830496013165, 0.02333617805769401, 0.024830074681501304, 0.033899921657783647, 0.01803005117523883, 0.014228860681344355, 0.02995567223323243, 0.037878291215747595, 0.06508139454360519, 0.007392811206435519, 0.03997042502409645, 0.029664913192391396, 0.05077862273901701, 0.03345603083393403, 0.07301200327596494, 0.0717824435393725, 0.04614698341382401, 0.025827463483437896, 0.04449628073988216, 0.017833555915525982, 0.023652746874306883, 0.0032731865607534666, 0.045127277595124075, 0.0319641121397061, 0.016243610963491455, 0.001065993993376781, 0.021624375001660416, 0.018170797997819524, 0.017231376442526068, 0.07635583063321454, 0.0237488783230739, 0.058022750807659965, 0.04928959121129342, 0.016161418320345025, 0.024726742279848883, 0.04830319467665894, 0.014316456159576774, 0.05282402244795646, 0.03333690383338502, 0.015922943795365945, 0.02987700288317033, 0.06702317856252193, 0.05871901594634567, 0.020373334542715123, 0.06124626712075301, 0.08795225873057332, 0.044692380752946646, 0.083700510806271, 0.049438478757760355, 0.07685149367898703, 0.06027753624532904, 0.09050609490701131, 0.0761243144848517, 0.009448532281177384, 0.0459119897734906, 0.03514746596504535, 0.07382323260286025, 0.027783540842522467, 0.05847657538418259, 0.05782670168472188, 0.060674458875187805, 0.06595118822796003, 0.059510309914393086, 0.05096753367355891, 0.019284694655133144, 0.015792200275297676, 0.04951249335759452, 0.07956363886062588, 0.05431216170213052, 0.03093315281772188, 0.02815565623209945, 0.03897761294086065, 0.0234976354653814, 0.014140068436972797, 0.03496573732367583, 0.032580001412757804, 0.042603456415235996, 0.036372761109045575, 0.017159129426415478, 0.026959046156012585, 0.07071322841303689, 0.03501557572079556, 0.028351026820018888, 0.02197370518531118, 0.04374636044459684, 0.011889965739101171, 0.05097589661766376, 0.02359885592678828, 0.03280033191133823, 0.053840596827545335, 0.04128719686663576, 0.00987196697055229, 0.011404831860480564, 0.03199173530031528, 0.04182471873770867, 0.05188056021662695, 0.03641024338347571, 0.027565159435783113, 0.09272415802947112, 0.035351250387196026, 0.03182271561984505, 0.06259620575500385, 0.07310393120029143, 0.06069673517985003, 0.008980144646817019, 0.05312385010932173, 0.017447880003601313, 0.036036112744893344, 0.04808818389262472, 0.030591581682009355, 0.001782663316199822, 0.035630498081445694, 0.06412151176482439, 0.010057548842658954, 0.02032541809603572, 0.010557479025529963, 0.016122317739895413, 0.029976479509579282, 0.08050359306590897, 0.04465732763388327, 0.020029960200190544, 0.049518508570534844, 0.0148035628787641, 0.041873613971152475, 0.02897249534726143, 0.05063165205397776, 0.021005025200013603, 0.011163966347729521, 0.034866555859999995, 0.0263362951975848, 0.06696398995284523, 0.011752817696625633, 0.007686746639332601, 0.051626665983349085, 0.023301028247390474, 0.03467293589242867, 0.02714834555185267, 0.02197943880621876, 0.0287789771599429, 0.031141425749020915, 0.008997767049420093, 0.014135504440803612, 0.047131900742117844, 0.011363185925542243, 0.005695139914418438, 0.029620652353124957, 0.03192374609144671, 0.007904418976977468, 0.0141699375484937, 0.027372640391279544, 0.05698428688836949, 0.073835704076503, 0.0303707660308906, 0.04543926799669862, 0.049326639223311625, 0.03400634987545865, 0.056028502461101325, 0.010609281781528677, 0.14688689953514508, 0.06671430942203317, 0.008813872185003544, 0.039110039227775166, 0.033559605811855624, 0.02800758632032999, 0.02380276587791741, 0.03453912539407611, 0.031789328304252455, 0.02468427107669413, 0.008234898609641408, 0.05941307584622076, 0.015513807535171509, 0.05600359683324184, 0.012433425639756024, 0.016226196362237846, 0.026217490501169647, 0.029349387623369694, 0.04426207420017038, 0.054665641127420325, 0.025843548156054955, 0.04534726882619517, 0.046886478018547804, 0.01683451996983162, 0.017705048168344156, 0.0353426804899105, 0.01746931322850287, 0.019658867702154175, 0.05393197174583163, 0.013942578275288855, 0.03035203507170081, 0.0362777153163084, 0.03514660083289657, 0.02151574833052499, 0.018062956730968187, 0.05263008696160146, 0.018135174909340482, 0.022037020984238813, 0.03744521963277033, 0.009301865240558982, 0.0267168854895447, 0.01425200211815536, 0.015498537104576826, 0.043579240662178824, 0.03975899351228561, 0.013100407751543182, 0.0301989202520677, 0.036205156174089224, 0.008798347303776868, 0.05587691095258508, 0.06271786029849734, 0.04681441420689225, 0.06921684835106134, 0.011651423360620226, 0.01083502868589546, 0.024691217578947544, 0.03278664246733699, 0.003029159498899909, 0.029426425096711943, 0.03328293315800173, 0.01820630912802049, 0.03496782721153327, 0.007931376325099595, 0.055317021174622436, 0.015593216488403934, 0.032419192006013224, 0.009139848889649978, 0.054847267988537035, 0.04167032487956541, 0.028599050029047897, 0.053394415948007784, 0.03224443870463541, 0.03860202005931309, 0.034855349854167016, 0.049122094841940064, 0.08206513963107552, 0.06991460626678807, 0.07498937645660979, 0.043966341497642655, 0.04894314819414701, 0.03778502318475928, 0.04078925055052553, 0.0539176275155374, 0.06051439924963883, 0.01900844099665327, 0.033058168433074436, 0.053084417046712976, 0.04251314340425389, 0.026883087553349987, 0.030309233082724468, 0.016020060816247548, 0.04660957805546267, 0.02706897900705891, 0.031259809753724506, 0.025984003208577633, 0.025445409252175262, 0.04564376827329397, 0.061038228284035406, 0.050177111623010466, 0.06493242218026093, 0.07078137368495975, 0.08528655248561076, 0.028706906562937156, 0.044211000869316716, 0.012619023627069379, 0.05376349828605141, 0.005588308392491723, 0.03836928933326687, 0.02683712698386184, 0.024920525095824684, 0.04157654455463801, 0.006949879661468523, 0.035162885673344135, 0.0063688433396496946, 0.0642336125352553, 0.03607167476522071, 0.08729828667959996, 0.012300330147679363, 0.08861425106546708, 0.026020230193223273, 0.020049178008256213, 0.03954107181302138, 0.11829977136637483, 0.14256579854658671, 0.11492210546774523, 0.09307752549648285, 0.10386892607701675, 0.16899757379932062, 0.13222478915538105, 0.18331278993615083, 0.1327344232371875, 0.11203585498567138, 0.12431818699198109, 0.1300282355930124, 0.11837013544780867, 0.09508149724985872, 0.2088518573769501, 0.1254723479173013, 0.17983244811849936, 0.10466051860047237, 0.07960939926228353, 0.14052340814045497, 0.16519278367715223, 0.16583754122257233, 0.0826204459049872, 0.1034793791228107, 0.11670445411333016, 0.20383052181984695, 0.1898137525256191, 0.20349979028105736, 0.10372804863644497, 0.12252971796052796, 0.08326215682817356, 0.233506155865533, 0.14258118772080966, 0.09820041738982711, 0.20480221110795224, 0.2142037616244384, 0.0697520360616701, 0.10503795370459557, 0.12018476878958088, 0.09059056573148284, 0.16243709011801652, 0.12136178277432919, 0.1438735526587282, 0.0762694531253406, 0.09063887742481061, 0.11047673079052142, 0.15483972350401537, 0.22596506694597857, 0.11365247145295143, 0.24857492585267338, 0.16888370205249104, 0.15667986976248877, 0.14802550843783788, 0.08748170148049082, 0.1894342071775879, 0.10376717975097043, 0.12703768749322208, 0.11672174318560533, 0.10697131031858069, 0.11985912626343113, 0.08929133401917559, 0.14903260368321622, 0.1681240549577134, 0.1054092412814498, 0.0951252356171608, 0.17791203116731985, 0.1377086684639965, 0.18733646188463482, 0.08003833517432213, 0.10555728405181851, 0.06595690827816725, 0.12647539909396852, 0.14364871329494885, 0.12184199557772704, 0.1338000896253756, 0.17648735190076487, 0.08180576283484697, 0.13419038296810218, 0.08214775805494615, 0.20296323192971094, 0.13080480535115513, 0.08754800792251315, 0.09039005863347224, 0.08728690086198704, 0.1304716310862984, 0.05450822778844407, 0.12458086146840028, 0.12577715941837855, 0.1416968937431063, 0.11354358693850891, 0.1662861750062023, 0.13046181946992874, 0.15690974385610648, 0.07510550093970128, 0.17401452602020331, 0.09887728321232966, 0.22670477868190833, 0.14151668841285364, 0.10397291835397482, 0.08521897039775338, 0.1250054208295686, 0.17440680068518433, 0.08290319823260818, 0.10402937925287656, 0.14120125105338438, 0.07963854234133448, 0.15293225300099167, 0.08409112306045634, 0.07414240869028227, 0.1521050916718585, 0.21338533982634544, 0.10604389544044222, 0.11140676481383187, 0.18462845576660974, 0.1504560208746365, 0.11929518223873206, 0.18950024220560277, 0.2360366029398782, 0.0883667418467147, 0.11501066785837923, 0.1308217415852206, 0.13204446168882505, 0.15510300866195134, 0.15533369699759142, 0.13703641667962074, 0.08448156568088702, 0.11593168415129185, 0.0857504125950592, 0.17009308215762886, 0.11640665866434574, 0.1356205583683082, 0.1943495012819767, 0.08986035348581416, 0.16203363319592817, 0.22068069050354616, 0.1574054408286299, 0.12180337336446558, 0.14854792611939566, 0.09039234529648509, 0.133655507383602, 0.1638590552444969, 0.1005618278203266, 0.09634832891502551, 0.09675627095358712, 0.06842227027352367, 0.10266071305211101, 0.11587414438171045, 0.08538403082638979, 0.12094817496836185, 0.14338841369109495, 0.1674935602183853, 0.07930919501398291, 0.1343086516218526, 0.21814223671598093, 0.1858071389475039, 0.1755699725555522, 0.15208297143025057, 0.11536251540694918, 0.11441951457943235, 0.11140413209795952, 0.06923592197043554, 0.2256695106625557, 0.14433695136436395, 0.12199214180665356, 0.11202790255525283, 0.09118511168552296, 0.2019637091351407, 0.12931547526802334, 0.14413914483572754, 0.12037960333483559, 0.14485058880278043, 0.08638503282730069, 0.1375888256090028, 0.16360377679978097, 0.1629725492426327, 0.21079952429447854], [0.006756961129472724, 0.024298486599166478, 0.02583818433673254, 0.0017360578203806654, 0.047352543366806846, 0.03335933280842645, 0.05483382620981761, 0.01640957045102758, 0.004230345657560974, 0.12745706284684793, 0.034518087415822914, 0.038313686781163724, 0.031265981029719114, 0.07514940894075803, 0.09141740136380706, 0.051695452470864565, 0.005243346278023506, 0.09183160628059081, 0.032906020525842905, 0.07054812048694917, 0.0333738161383995, 0.02849294411550675, 0.025317203453076736, 0.01189582234448088, 0.025545513523476462, 0.022276564201872264, 0.009099285218066402, 0.04993837246937411, 0.004073639691341668, 0.05680654464023454, 0.040127149650028775, 0.045463315277759514, 0.04327420863722052, 0.049444483792675395, 0.03681367316416331, 0.016317615385300348, 0.02165449856381331, 0.01486619166098535, 0.005581932707822749, 0.044531873294285367, 0.036998736805149486, 0.06328585517725774, 0.014214283204637468, 0.05042413229654942, 0.04509120328085763, 0.01992718589359096, 0.05905427331370967, 0.009592720124471401, 0.03890846004443509, 0.02160219708457589, 0.07972714544406959, 0.04907831236986177, 0.03774202781330262, 0.06858783281807389, 0.021526845770754983, 0.02570189718556191, 0.062425676334117136, 0.01595013608623828, 0.014260755219895924, 0.04189914045855403, 0.03670999301331384, 0.01797115772829524, 0.019670324765944054, 0.039370294726852856, 0.01647958847960191, 0.019149204782609428, 0.07281726372561284, 0.0636995986902288, 0.009392662555910647, 0.04209703519674284, 0.06461262184062175, 0.031567935898367844, 0.03366112143599561, 0.02517915889620781, 0.03926703866039004, 0.025106438601921712, 0.046029169378536086, 0.05711359530687332, 0.0777149023488164, 0.0853496358862945, 0.043088544492742846, 0.02415063381860299, 0.0653127207021628, 0.018841246575383202, 0.021266169579965726, 0.027600221036534225, 0.024534830524187003, 0.04079359317464488, 0.049643793276378086, 0.04350617601137076, 0.09212944922702652, 0.022393139910751154, 0.05440542294776865, 0.05204785302547472, 0.028098023163952997, 0.017075196340946213, 0.037765932602009604, 0.05296802793496421, 0.0539677780387657, 0.027426938459809338, 0.03838278878746288, 0.020521302674231783, 0.030623245518654585, 0.014663679491994637, 0.015549797032560621, 0.014620585732960274, 0.04903710833085435, 0.07397092253501926, 0.023610368969717195, 0.02568230957591108, 0.06980538248483624, 0.0044017885562165505, 0.03272060743932213, 0.06942543680114405, 0.04128359045301165, 0.029964259093893424, 0.004330243399765874, 0.053285972481327396, 0.03745543158480099, 0.06219948668565069, 0.006040885312748807, 0.03797469407852207, 0.015566003841481038, 0.011295873555354774, 0.02368084840210421, 0.07203698238091809, 0.03660998034424015, 0.06785200908780098, 0.05536746346790876, 0.028826610318252018, 0.05716745063130345, 0.010901262185403278, 0.06744154289896999, 0.04241243523678609, 0.04028396587818861, 0.02292261435650289, 0.03281009263758149, 0.014877046524946178, 0.0065835903431954125, 0.01679706822947732, 0.008435284419517432, 0.09025209210813046, 0.02927191588761551, 0.034294028367315016, 0.018346368933894804, 0.011242265896206456, 0.03128837268533451, 0.027046409236001115, 0.06445959183786597, 0.02156281830476863, 0.03090486130011933, 0.023424316363941346, 0.02667565261279898, 0.09030976079936538, 0.01729983214421996, 0.033620388978826146, 0.04877056620482888, 0.025077677198818753, 0.02576845129286604, 0.017023279930331876, 0.06652078444936446, 0.03476587144125785, 0.07108858720000301, 0.016154907776841095, 0.09062505566648074, 0.01525407620439572, 0.00817189154414726, 0.013515109695228083, 0.05325517038415585, 0.028566334463123764, 0.024861969220052873, 0.06474057997443847, 0.016927480963723998, 0.02976117356281195, 0.038537131755479744, 0.050264008210173676, 0.015263292406286513, 0.02011441745396171, 0.03908920141735247, 0.02839125207226191, 0.0470944727504892, 0.03683761866497142, 0.029851914050855806, 0.03633569274097681, 0.011768889646711094, 0.031452269426413944, 0.026172303461602757, 0.07526921786900077, 0.023798133180077587, 0.06898806669882365, 0.0185025032343609, 0.030645464147840227, 0.047651957121810744, 0.04250959127343126, 0.03367456660739013, 0.06000080252332347, 0.008773472209993218, 0.032821793973978074, 0.021519526074241315, 0.04053291019850543, 0.02183180654953633, 0.018889853431444083, 0.06442818245185272, 0.021356918549697314, 0.020155246602371335, 0.009089568596599358, 0.029132846742868423, 0.003115940523067755, 0.04113021439739636, 0.019825098603697758, 0.020812621506463205, 0.06207815105361598, 0.05292389601735132, 0.02461724538755204, 0.029090987917568003, 0.026298173403899585, 0.016257571821500148, 0.043073182459920645, 0.027040446609524742, 0.0567176531601165, 0.05044187259461198, 0.03364693666143077, 0.027897682307021957, 0.01093221949746034, 0.02268146979622543, 0.02739399897732905, 0.015800698926406245, 0.0501116770984871, 0.016586464530389224, 0.040190399291792085, 0.034118067273604016, 0.04775727932740535, 0.025027652204568897, 0.02909170716468777, 0.05457570470337357, 0.010896597257150071, 0.07041664754173585, 0.026339365568544184, 0.011151362559758127, 0.041634661078985245, 0.026224710113768066, 0.008685164269991219, 0.034927583299577236, 0.07836221118590661, 0.01662628266162106, 0.04870292983417, 0.006076037243474275, 0.04407361449141588, 0.036335400970918794, 0.029362293359424387, 0.0516320806927979, 0.015281438129022717, 0.010545513908644872, 0.02178230063457574, 0.051592057304722924, 0.09518613413508449, 0.015561671395386969, 0.04047682588653905, 0.032921548799744675, 0.04560552264696785, 0.038749238409634144, 0.060333644306021075, 0.009764032405135887, 0.033695441737238846, 0.06327371618577413, 0.018972602473305802, 0.06110842951706477, 0.0331344459471958, 0.03691479523799249, 0.01751303123975439, 0.014720676433561104, 0.042742668052337, 0.04525570391810366, 0.042172301693686416, 0.02459716414367514, 0.011416581542497235, 0.023130965319329073, 0.01503934701239424, 0.07126915893916573, 0.017303077237946645, 0.030213020209755217, 0.035294250052954466, 0.013235376848440086, 0.060998995389257155, 0.047842306550592184, 0.006686527922283858, 0.030382290948182344, 0.022013955882617404, 0.03330895497596689, 0.02958175533318094, 0.02302429622172245, 0.018627991500709738, 0.00614812650019303, 0.00838469369669578, 0.06115976069122553, 0.04551329277455807, 0.029784301428922584, 0.03537711274943181, 0.03283375654635685, 0.02214457557004477, 0.027426149662850157, 0.014598131312855651, 0.04122310584144933, 0.03068671907697405, 0.09189440469656672, 0.033140071002500396, 0.03222651520211782, 0.021546601317822933, 0.08798084541090898, 0.03450067959991949, 0.047876206160123856, 0.022189721897510544, 0.027129402550469552, 0.03206600095810635, 0.007158135629392096, 0.029124789139521972, 0.028621638459818702, 0.03164655775097864, 0.03214502314637814, 0.009217841401030975, 0.0566475706707154, 0.03878249001822301, 0.01755055083361055, 0.03680912019418819, 0.05785070825368166, 0.055728661229035685, 0.04961484697248254, 0.03863431493352566, 0.036179046146571636, 0.03763091091864875, 0.07009626366198063, 0.0795867226219603, 0.001603220383653284, 0.0314860299362668, 0.023159375580559884, 0.023843813853870546, 0.031599952573222775, 0.07255129835435323, 0.053221247025898526, 0.02910739489431892, 0.05256308502118502, 0.025356556787820797, 0.01784157450310886, 0.05065827098275934, 0.08628791411008153, 0.03968175926378795, 0.021592029237321446, 0.04458525703687753, 0.0227313862248723, 0.03103880411280053, 0.0028954605347410378, 0.0375191358450268, 0.14274269262594835, 0.09855215637279408, 0.15843530770923409, 0.0910906596109271, 0.15425051083522184, 0.14778088299291475, 0.1671380214393139, 0.0783193956262299, 0.07473859669906752, 0.2150272045816694, 0.153730820864439, 0.18869364048753465, 0.06294501346669026, 0.18205517956188746, 0.10936651179300887, 0.11008850697960172, 0.20739893748291902, 0.19307966370667728, 0.12348900362849236, 0.13282795250415802, 0.07206491766763584, 0.16698814662439482, 0.11847593262791634, 0.11961181381983416, 0.0687305015910949, 0.12199757008680276, 0.08527896646410227, 0.12476683434631143, 0.09944589555795703, 0.17882472862090382, 0.1394138948193618, 0.07644814532250166, 0.10132293376539435, 0.18839243879275663, 0.14090770323361668, 0.10088107854660068, 0.13188841220523628, 0.10845173123691763, 0.19172656988458975, 0.0551739079611642, 0.11644456163048744, 0.14705082002495015, 0.08658633381128311, 0.15749963505991868, 0.12963015266827174, 0.057200569925563674, 0.08267328342688934, 0.06107351889035531, 0.08811149054339953, 0.11861701362899371, 0.22475126279251917, 0.1035911338403821, 0.19941633939743042, 0.12076444125601224, 0.10300912042813641, 0.07435605901160411, 0.1263381586010967, 0.09011865819671325, 0.13311383287821496, 0.0958918851933309, 0.1135632780247501, 0.09275300933846406, 0.08969587659729378, 0.07486806796597582, 0.1210144135568823, 0.1601105835288763, 0.1650637805994068, 0.2082207655268056, 0.0865745951554605, 0.10401497395443064, 0.17481705652815954, 0.12668518855103425, 0.1330958924123219, 0.19517191286597932, 0.18194221705198288, 0.156827057578734, 0.07342794524239642, 0.1307778132281133, 0.17460510932973453, 0.28810059492077145, 0.08621912422989096, 0.11991917661258153, 0.1508269759693316, 0.1629932445607015, 0.16508784145116806, 0.18688619961696012, 0.09214802751583712, 0.1239347332822425, 0.2052435167133808, 0.07916743547788688, 0.2069345616868564, 0.11618846894374915, 0.12739721605820314, 0.12814174539276532, 0.09468785194414002, 0.16781552508473396, 0.1165179791195052, 0.17744172497519425, 0.11699227509754044, 0.1469991427979299, 0.11175064636128289, 0.10634707167212452, 0.3195607624948025, 0.16667000869555132, 0.16356511387441838, 0.15033248678914138, 0.1519463144774948, 0.13986552772777422, 0.09548509666430098, 0.1182147916406393, 0.1657068282365799, 0.10855136731905596, 0.0864834204050047, 0.15574820046978338, 0.14196829417986528, 0.1602833249739238, 0.12418778613209724, 0.14270419254899025, 0.12417132487254483, 0.14741066071603978, 0.16537396609783173, 0.11373356995838028, 0.13607360262955936, 0.10957151079284293, 0.07137150237602846, 0.09851618723145553, 0.2029085284365075, 0.13951734426830495, 0.15187679177948407, 0.16965736768075398, 0.0955633588933519, 0.07496544452650206, 0.13722015039197036, 0.12881490641406604, 0.08260074803339583, 0.1535266496773277, 0.10023782734892198, 0.08889130369893142, 0.07915135419794492, 0.1058291866044913, 0.10528690820293767, 0.18640718103519507, 0.18230359123221465, 0.09206411987543106, 0.10373104776122741, 0.1541620162980897, 0.11217631851988179, 0.20647467779261724, 0.1280733219214848, 0.12036447200391974, 0.13013443989413126, 0.16132149712315627, 0.11960794617022787, 0.1561404208519629, 0.15620444741632256, 0.14177951216697693, 0.11273525495614324, 0.10322986822575331, 0.07715368603489228, 0.08556021244398185, 0.11758249199816159, 0.1670376118272543, 0.17517397951866898, 0.20891565323940345, 0.2261152538870062, 0.14657258854380675, 0.11724509724548884, 0.10989994209791933, 0.11602007012282099, 0.0997749443299004, 0.06797731414969478, 0.1205095292202064, 0.11348791314022881, 0.1068132659420371, 0.08796183964503662, 0.08367006493998425], [0.03106200322508812, 0.032677958120724986, 0.028553676392350878, 0.02890981567491378, 0.037905938125082424, 0.01585167386968221, 0.05884215648152998, 0.02075486460567585, 0.011803372796358806, 0.054632491299084256, 0.01590147494737591, 0.019048343944762434, 0.02428220515139401, 0.05702446973217385, 0.03785386395507625, 0.01780850440263748, 0.07300660892256669, 0.01755094268758382, 0.010495255667982357, 0.03411412837782076, 0.029708000166075568, 0.03240914290238704, 0.034505239355244806, 0.04826324592743601, 0.034777691521282704, 0.05802979400115354, 0.12362437136471272, 0.02719822635741106, 0.010807241828713034, 0.04633662038083587, 0.02722629056578236, 0.04451713890635541, 0.04919334101889815, 0.027796544966154864, 0.029576720603342568, 0.05076076369732618, 0.0045221920507693926, 0.040004518016108444, 0.01969819389549749, 0.04143240675330162, 0.016481876838952303, 0.032001787796616554, 0.004155425637561295, 0.020540478073858788, 0.03309463969032679, 0.06032970880291291, 0.06201461303446974, 0.05907427652605942, 0.03612051232318793, 0.02831651652897043, 0.11782151274383068, 0.04256619466468692, 0.01764605294114777, 0.051563789535846026, 0.032433539628982544, 0.05747026723942586, 0.016931625116350393, 0.017715029418468475, 0.05440753997702684, 0.023059174618018524, 0.04023385267438633, 0.03841304127126932, 0.03403276185105954, 0.0667366332241467, 0.01923664250145001, 0.023436467229787792, 0.024012131250596473, 0.043711283576807806, 0.014320824228759323, 0.02470631498311247, 0.008839448714362723, 0.021613455676872815, 0.018838946341669986, 0.008091951637262744, 0.04741588121812258, 0.04732896427490881, 0.0499484181803252, 0.0615530667294349, 0.0640409289460097, 0.04490587501121419, 0.03571491801579084, 0.04729048116132617, 0.03182871047673481, 0.05548520625701972, 0.0031192428681866397, 0.04150004651663559, 0.022032568098178933, 0.05765520195875849, 0.03895710761259709, 0.03093952765422208, 0.023582094415490116, 0.02676716832710164, 0.004874961558795933, 0.03512803950746145, 0.04067785884918911, 0.03388863762042352, 0.04430410944457565, 0.06473477171467883, 0.0058037046692334116, 0.03242022677191666, 0.05176969098725489, 0.055431357717939785, 0.07525646141065018, 0.05605841567739844, 0.017930683114432862, 0.05037766621847238, 0.024143777222239544, 0.03919462201052478, 0.03284295069585953, 0.03868839756718703, 0.01648973936348089, 0.023349253427503363, 0.007983505626076033, 0.030197960125016313, 0.08381089488310473, 0.01390046245485012, 0.0773817552253604, 0.016943691165319512, 0.0260146933474711, 0.03293808130547404, 0.021765213426468626, 0.029799914519701685, 0.0009705055625610319, 0.011139451725674527, 0.030592144866074835, 0.026020876497828534, 0.028713427284466367, 0.007652422097245497, 0.030807800258376768, 0.044902953917958906, 0.05679733692003148, 0.04492199021790709, 0.04237112941752587, 0.06220010415251766, 0.037068269681185484, 0.0215729250838714, 0.03868708799460104, 0.027932820242962668, 0.03091809612565807, 0.03137280958305512, 0.026135072245129516, 0.028334331465885043, 0.029835367974426066, 0.054526229322488816, 0.013601123338698276, 0.04256840329617262, 0.03051608448315944, 0.0336932059643524, 0.013502979185432196, 0.03846813492210848, 0.0826158793643117, 0.04486004336337958, 0.08550845379275934, 0.018532426628683294, 0.09232104716024228, 0.038957921854619465, 0.054536312352865934, 0.09173937301550593, 0.07545825093984604, 0.027983952945630466, 0.04337852321831243, 0.025496528384142687, 0.04144819965586066, 0.02537429878222091, 0.007214477784665567, 0.01085673671747957, 0.007576778165197798, 0.091605694831482, 0.02424763548853142, 0.04867179864751441, 0.023300309000270705, 0.08205858498279538, 0.02164529762896044, 0.04004561348951288, 0.03857521114072629, 0.05049333608310137, 0.08709961841148989, 0.04457063799990075, 0.010266166130479957, 0.03570048896861928, 0.013875379559717007, 0.02402903525424855, 0.03948586620390415, 0.03915878857618996, 0.0720295999199152, 0.05190081109425851, 0.020192019807706987, 0.057395784450428824, 0.057354855218103955, 0.045219504074858766, 0.02663297954547618, 0.025650878137509738, 0.08896748282547508, 0.009082209036153342, 0.029855018348566124, 0.044951855936752896, 0.03310757935313242, 0.034250405350966115, 0.017389285112065927, 0.046101138195289035, 0.04743868338742426, 0.01943840828192021, 0.04268647517476763, 0.03169640293344855, 0.029615532806409255, 0.03019443174291934, 0.027905651700815985, 0.03736831108108163, 0.06573963457984583, 0.04265480116009712, 0.04705101936789496, 0.020202185958623886, 0.006690471482995365, 0.014251523750967212, 0.02506080881825515, 0.032706236067627154, 0.06069349178246089, 0.03752698988786765, 0.028966904218707765, 0.024720991695565835, 0.13518364966980048, 0.08855162228324584, 0.03796978148498705, 0.032969718000718524, 0.031047255266457796, 0.024441511603072286, 0.05289951286145619, 0.029278901405632496, 0.01674495674004512, 0.03815745409311993, 0.03930862946435809, 0.04527371563017368, 0.03752779055918966, 0.10427189445389168, 0.023727043066173792, 0.03665545576118997, 0.05133932336632695, 0.02699924765952996, 0.017674168039645468, 0.01220586704688945, 0.0031247190698715194, 0.02107421202319009, 0.07998436449893884, 0.01120191257047866, 0.0454177923633584, 0.04686128401330539, 0.018740648669855933, 0.03332950780168176, 0.09149765170046262, 0.012777048495731183, 0.040370031259953976, 0.016039263357275298, 0.03552505713222282, 0.020462434672351395, 0.012389238591172864, 0.014729595776381237, 0.03150006543312754, 0.05318412437502827, 0.03873883307512317, 0.010895243579787868, 0.0596376166545919, 0.006390712099216346, 0.008572777666683708, 0.020072048031059758, 0.0404745392235262, 0.024454761695648943, 0.043155081636671505, 0.02059245215994971, 0.02875130989455751, 0.022230651129835417, 0.0841297452737178, 0.015446249196039779, 0.05115262784862092, 0.054898527916520834, 0.039400062058120966, 0.04874110082164407, 0.007100312571440424, 0.034285220982772965, 0.0531363181902894, 0.04176339613539832, 0.03476523022566523, 0.03703084168955684, 0.017637228593230247, 0.035843256129218, 0.01762611249328724, 0.03242294769734144, 0.014001798267210168, 0.0336103704092758, 0.020596586134550825, 0.027021985368004868, 0.029889179194079976, 0.04585532870675836, 0.04256767726370266, 0.03963603278888123, 0.012154736040559198, 0.0268781868341778, 0.045011271855660846, 0.032388115102159123, 0.03314907176952277, 0.027530021499842405, 0.022325929320816482, 0.04663995606824756, 0.030299048272094557, 0.014612989533426506, 0.0169046635273844, 0.06457376214010374, 0.018073278944939375, 0.018351685255765915, 0.029319063893386295, 0.06611732074192592, 0.035409221026514254, 0.01137412730271795, 0.032726422484431944, 0.01405626512132585, 0.040230697486549616, 0.06676557274269206, 0.022298672569117377, 0.015727674987699305, 0.015210358193144202, 0.08704814474497523, 0.05481240825195398, 0.03862615554992642, 0.006568496331705579, 0.030741829691188674, 0.05115272284352353, 0.04489115419398461, 0.014345124264114668, 0.055690853257796595, 0.02361779214282121, 0.021806344522961547, 0.03467460848124964, 0.043131902880434475, 0.028838871446038996, 0.057251738251319954, 0.04625595274514385, 0.047858696563967636, 0.021664963270138417, 0.013032720490757908, 0.011560240976645477, 0.007501353060693613, 0.026426613297579542, 0.01678024904270257, 0.049645771205957444, 0.06319472113890306, 0.039980725185679536, 0.02501462772488594, 0.04799211351200938, 0.010451796348206699, 0.004305362792885197, 0.08698595701051609, 0.03829852491617203, 0.027507631540564553, 0.1474569368043116, 0.10115640091576747, 0.051956315258783956, 0.12351120529430253, 0.09427613725087472, 0.06686761083879642, 0.15107032576841967, 0.10522981626646859, 0.15615335372941835, 0.12289204208978585, 0.08338596232767616, 0.0905844114188637, 0.17256338388792106, 0.13767748299453939, 0.16876673618597643, 0.08348286391368934, 0.1409619181816067, 0.06912013675485339, 0.11952779761382512, 0.13707714235144003, 0.12577190755733422, 0.08217515051364899, 0.12318130156823567, 0.12189747260085174, 0.1403318169925894, 0.08478784960295473, 0.15226572805217334, 0.11247801554522344, 0.16819450046334947, 0.15640452025192125, 0.12077214941382408, 0.11335110012441874, 0.13511784534369195, 0.16430578913007463, 0.15992595415030206, 0.11754293340657439, 0.07221420894243888, 0.08734746689775161, 0.06911260501614638, 0.12879653168576105, 0.10701989342591592, 0.09905924594828061, 0.14299757752035344, 0.11486250295170716, 0.2513401731848717, 0.15803224433745655, 0.1521089050386633, 0.06710474525711366, 0.12951890006661415, 0.12557650304266385, 0.2194649050278323, 0.09259890725037881, 0.08871744945645332, 0.22382437038634503, 0.14349661288516863, 0.16211773082613945, 0.08671043786619391, 0.177883329136031, 0.11625599674880505, 0.10333154669829778, 0.17511320992239884, 0.14094038148011478, 0.1117785070091486, 0.0876999386985387, 0.10275491406874997, 0.12109323218464851, 0.18071682352040494, 0.07389292493462563, 0.14461521857551166, 0.14519563743046351, 0.12874573655426502, 0.09450717163937432, 0.13755930933569158, 0.17294111076210225, 0.1824724514569555, 0.14779209239142282, 0.14394425600767136, 0.19092982049499238, 0.1220723989286593, 0.11189302336424589, 0.12193871395928518, 0.14916733359651907, 0.10894104998026576, 0.13775034408484185, 0.17401452602020331, 0.16371394374540874, 0.10100072462643896, 0.23679409229329654, 0.14288561924227647, 0.08223658507423741, 0.1338591764547995, 0.12746759371033736, 0.09738863166421652, 0.10723350303513662, 0.1479790559304612, 0.05677291305203523, 0.17892561320747646, 0.11855975884412016, 0.1257861160806247, 0.10162967909127474, 0.0708856713026762, 0.14699043040829046, 0.21162070094474725, 0.19403736160269805, 0.11532309252236571, 0.13536510350448744, 0.07304416583584887, 0.13696624258799212, 0.11922128977520124, 0.09665751018162284, 0.10368068010679313, 0.08008319312440497, 0.11014847590454988, 0.06738780292549304, 0.08797678098614727, 0.14693721969212803, 0.139992943033576, 0.12402970104345254, 0.10542456260217087, 0.08013540639408998, 0.15818681461470468, 0.07618053789649691, 0.16181629842945508, 0.1281303595751524, 0.0909306610535298, 0.08821738950376, 0.12539191437619074, 0.18318921513855457, 0.06727146131119557, 0.13392141168670996, 0.0981915896492345, 0.08551399063851152, 0.13728535760726246, 0.1014395807204502, 0.11143575861517872, 0.12007264766309943, 0.13326294773391315, 0.14771296163754805, 0.08297791850886174, 0.1777521411755255, 0.1205006404114621, 0.07087374265704836, 0.10430726648441382, 0.1678937601723841, 0.16436423813658102, 0.1555612776428461, 0.07629113231918641, 0.10936853382736444, 0.12179197397615228, 0.14527440177542822, 0.19915939175656863, 0.16944265205945286, 0.1623484870152814, 0.08879487030208111, 0.2029315172029393, 0.18810962539698395, 0.09026083842452083, 0.21622542957110064, 0.1327079739421606, 0.12335088104009628, 0.14303833033357347, 0.08772515305983168, 0.11187302015189614, 0.17186567346964562, 0.05404992827347346, 0.10238003025629691, 0.06174655777535268, 0.17746928706765175, 0.10604308798377003, 0.0803470957492079, 0.08580039348453283, 0.15258964709937572, 0.1489237802369254, 0.14586237951048783, 0.10249468910374812, 0.14556090640170233], [0.023041537796546305, 0.03975401985059891, 0.11004721133836678, 0.018184565473347902, 0.047722938670111556, 0.0327103819165911, 0.006044898423299725, 0.029208377868469273, 0.04320323387426989, 0.0184979587460735, 0.05559322903198855, 0.049448107169674974, 0.06324626265891961, 0.045852695990886004, 0.047589362266340425, 0.025170773899714862, 0.03702049403052245, 0.03447116671928337, 0.034393437140222104, 0.05625469550224287, 0.0075084471443135825, 0.043027757933097224, 0.03269792062097362, 0.04800540601302471, 0.020565502445346544, 0.06330643514437334, 0.021735242534694926, 0.06503374102924551, 0.01133848725086344, 0.049231742708278556, 0.05548824270122817, 0.07300912628748588, 0.031093226013971225, 0.03811312879302672, 0.04686411350433316, 0.019179406376289468, 0.07260309093232666, 0.03894493130168744, 0.0346503779957337, 0.039729762223682234, 0.03362882656178304, 0.027841029721977453, 0.0917151357446398, 0.027748604770749807, 0.03642815670796803, 0.02311793914330857, 0.02187844904671822, 0.04085634070049439, 0.026242333364539912, 0.06587989455355064, 0.007688340348457652, 0.014665745631126421, 0.04057597681613905, 0.01048609968607447, 0.03293684297906501, 0.024165398740608777, 0.01111613811060254, 0.02105284495545285, 0.07716435939073563, 0.038974763093782325, 0.05064040515571833, 0.03610523849991815, 0.024772942032931105, 0.024948794561039125, 0.06007816908614976, 0.030949227312313657, 0.040606381970324686, 0.01232608818515603, 0.01930082173618887, 0.024784416060096452, 0.03372261367206063, 0.06427317791219268, 0.03378204994701913, 0.1267589588782617, 0.023257060874519602, 0.07609510355229888, 0.03493032458105257, 0.031885486894420216, 0.035460318106093576, 0.03330490751458066, 0.057556298694440296, 0.009956917010380753, 0.026668550047491277, 0.06766730507037469, 0.003962694974948785, 0.006443410521439675, 0.01398738194257021, 0.07534260821661778, 0.053107687405177524, 0.0329336843985532, 0.016133454195888977, 0.0977718885987997, 0.09399848750659398, 0.011227675696967967, 0.04334110879738416, 0.003575212463536965, 0.0474845014645585, 0.021781924047640393, 0.04839701571368745, 0.004240030896783407, 0.00926807928564293, 0.022690733495567526, 0.04954810966072338, 0.06007672380656004, 0.0378969136093344, 0.04617625541452851, 0.044101030698844364, 0.036052411156041284, 0.0048511767859703726, 0.054100764117070606, 0.009416906612126954, 0.02862552646547556, 0.03133577514173729, 0.02547416726260313, 0.05322402901947498, 0.03087704475702984, 0.04994037414767912, 0.016134248081860796, 0.01673849199765495, 0.027396211001489843, 0.01872951051752482, 0.019682835255350386, 0.03256354354588049, 0.034111387096345425, 0.032711050273584466, 0.048147375894976516, 0.030943103533770357, 0.03490518485861165, 0.017738262457506995, 0.050456844469798465, 0.01819756450796766, 0.03891288748543177, 0.049843421671539545, 0.00137653476849664, 0.011157648338537132, 0.012108111354921545, 0.03210745605507067, 0.009119381728981222, 0.029711508192121983, 0.031100791679429154, 0.029268479107746055, 0.035506468665386946, 0.04556349418791277, 0.06876484903373889, 0.01922158072037356, 0.05410281329282692, 0.02764352174874927, 0.03760348792587008, 0.05215612346572535, 0.007062282804067114, 0.030664921139499972, 0.05496743654033967, 0.0373691287157791, 0.004942490212020597, 0.012864897576426821, 0.04711941569777472, 0.0308783204028649, 0.04104491236752697, 0.026541406155696938, 0.02163578287166144, 0.05055323376187256, 0.032232622017285655, 0.014795657945796847, 0.03109697831262435, 0.03228753246366978, 0.061339789602373324, 0.02931435825303197, 0.02377261347802622, 0.03885859450591462, 0.03591035984988723, 0.07857309986970254, 0.016384300110595565, 0.02612282638438046, 0.01006138086917677, 0.029623576839055334, 0.02902809450668948, 0.050978091678449085, 0.0018453873053658754, 0.06976356437163693, 0.010984542180917092, 0.05432382571910109, 0.04045940110726016, 0.02143897209316492, 0.011112429068556853, 0.012333684384689798, 0.03725851393703904, 0.07166518590279988, 0.005068473384848663, 0.03603637398087552, 0.019664184024025286, 0.026493148745170662, 0.03536880408812847, 0.01854349353483745, 0.06973958494407789, 0.025192636298015714, 0.047410442759948115, 0.026258056717259542, 0.04325076864500131, 0.03824649824361716, 0.025551727207909738, 0.03356034880770104, 0.04146787377872637, 0.02031430199609271, 0.05981577280908823, 0.04101128077932766, 0.011637208900148315, 0.0022328121413011104, 0.0727695898552026, 0.045020211554531536, 0.016258978085326295, 0.016169460656653558, 0.03465126009125795, 0.02294360314096723, 0.02373016093458448, 0.056303580557661395, 0.028364548326603005, 0.013951863178850284, 0.022393535157399516, 0.03528701008430549, 0.03402081624205623, 0.06281694676727057, 0.01167431882848697, 0.032173677680215666, 0.052314880304038525, 0.038876545149832964, 0.016222520398774316, 0.016967670592878546, 0.06700607269470181, 0.013934205153158732, 0.019241348141804338, 0.005325440533592233, 0.01224775895077203, 0.03742391363318477, 0.04444817939241018, 0.05707639801715102, 0.03191172245091625, 0.021449336715574776, 0.02470887984548296, 0.014765775263575571, 0.01151696062048099, 0.03345518945051091, 0.04750349705240556, 0.06164200909967933, 0.033674678565668206, 0.021570957332317318, 0.021489924984052777, 0.03525398578494787, 0.008299369614438286, 0.03574101107993296, 0.04661283841622727, 0.008184584389839853, 0.0860674377264721, 0.02241604894931827, 0.005961904260662517, 0.04190812426220093, 0.0006514451441554618, 0.019131420379770652, 0.038211808140788756, 0.001769119651206503, 0.030079925565847328, 0.04771563084796071, 0.025810834286468368, 0.027817815342651944, 0.05140078167564102, 0.010622623476332851, 0.004170712183362671, 0.028015012886109095, 0.005318035172032458, 0.05112621248034494, 0.023018423501136046, 0.09441075181322438, 0.02312794583849609, 0.009882005047984421, 0.023958311549254825, 0.033538187853991985, 0.03548383952251502, 0.024098756423752223, 0.10552603751420975, 0.01650529308244586, 0.025808186303558092, 0.047762276737817695, 0.0612455207322325, 0.0601766991562077, 0.026982246964637722, 0.025377745740115643, 0.028020490360047137, 0.01568584669647472, 0.07214564297880445, 0.0699520953265684, 0.01980525823975248, 0.03260000462510756, 0.02953803732192942, 0.04615202832168766, 0.008106797983470772, 0.026601802557706833, 0.01586796040646732, 0.03133551390575511, 0.010478326219267078, 0.008544181656491543, 0.05594014023829784, 0.01120278109530253, 0.03989873779937625, 0.01693004073708185, 0.03192847208785159, 0.016313454269298484, 0.07043545653245278, 0.014692937921998757, 0.055270812939852476, 0.02349053798908634, 0.046337220884327374, 0.02857298410630652, 0.0435285473109356, 0.031325078037168295, 0.03617149065913899, 0.031185255718550513, 0.027309589221009185, 0.03739198516788227, 0.09961958016668047, 0.03149863711691328, 0.07008080663425581, 0.021457760727831295, 0.011241408397576638, 0.017275722098669836, 0.07569674921355077, 0.05064270199675645, 0.027966960732425963, 0.062109071894415786, 0.01754414207035942, 0.03780153194176299, 0.027439584656219398, 0.023089881720287458, 0.014136234714117433, 0.04806000094062515, 0.03910316227536116, 0.06271627931190388, 0.01236134656106255, 0.057275100212012015, 0.04441394390804427, 0.018070240804393376, 0.048586289664464336, 0.05218040823404278, 0.05360202052231346, 0.0737899708162461, 0.02469657122024468, 0.018768275223140205, 0.017672069670100297, 0.04165549549673285, 0.016204320393236618, 0.013716950114550335, 0.045110324397683144, 0.04220828779840043, 0.013967382122895547, 0.14052779147667543, 0.09961078635283879, 0.2813933848270348, 0.10038590404604163, 0.1728849552039589, 0.08705283342195408, 0.05038943201569574, 0.08079798905444996, 0.10053964651056699, 0.1273453895534788, 0.22602903922753675, 0.0833110927737185, 0.11037500482052565, 0.08922720567456313, 0.08469961969447987, 0.15010296553373337, 0.054392585065215826, 0.12590699030884675, 0.12917727125542505, 0.10392430810523884, 0.11330270700688873, 0.08006112716559853, 0.08389162697962352, 0.1448298663433109, 0.11466300008552414, 0.1475938516003745, 0.11806658602186612, 0.10773142560252122, 0.1358721320118223, 0.1273309774696827, 0.17860059493354388, 0.18921303190290928, 0.08069556419338499, 0.09252289775758982, 0.20233005019170897, 0.0931710276220526, 0.176847246874656, 0.14420710690319538, 0.2486957593687943, 0.11305980504091297, 0.11612221678452832, 0.1293684145701783, 0.1283857872975724, 0.09146099723875523, 0.09474917115377528, 0.10390687654060976, 0.10881475425724473, 0.17033307999372482, 0.22963733917900495, 0.12254583995257105, 0.1388947069644928, 0.14637194573879242, 0.10587248392403126, 0.09410250692495278, 0.09402379686278955, 0.0966490488499403, 0.06639065500348806, 0.11247637349047832, 0.16206983982452325, 0.1542038954794407, 0.14119253866374493, 0.10731915451054062, 0.15320509193199022, 0.10104168100016457, 0.10654025737728391, 0.25421181480799404, 0.14822900108993053, 0.13415078366441385, 0.14036190323531628, 0.09476795978844166, 0.1266852564045361, 0.11326934344002179, 0.11975512041577271, 0.19941543016050542, 0.15212593626763138, 0.2634803588901247, 0.11265747448695557, 0.14570984483829566, 0.13010104240051337, 0.11404543822365147, 0.14662501215934753, 0.08502081103090729, 0.09626463840582541, 0.12564473652413913, 0.07471858670136758, 0.06276142903204475, 0.06446839922240802, 0.22910946607589722, 0.08337573001959495, 0.09592734543340546, 0.09404825805021183, 0.20251706801354885, 0.188300470156329, 0.08554219733923674, 0.25886556080409456, 0.22440781550748007, 0.1292399407497474, 0.09285480994731188, 0.12802214681037835, 0.13029836038393633, 0.10270890260913543, 0.1821367937539305, 0.0987628482814346, 0.11896504781075887, 0.15463084328387464, 0.1133880667122347, 0.19456459688288824, 0.08034002541431359, 0.07719737011939287, 0.11609658173152379, 0.12988905448998722, 0.15853102185896464, 0.13197896948882512, 0.11298069464308874, 0.17526106270296232, 0.14030935748347215, 0.10957810615322419, 0.09561415402484791, 0.09864671022764274, 0.14633295711662087, 0.078172547077494, 0.14333942346274853, 0.06414074144725289, 0.15799647197127342, 0.14038767399532454, 0.14720978720911912, 0.10536911950579711, 0.16701718792319298, 0.13289169408380985, 0.12629841001970427, 0.08574205982897963, 0.16229794972709247, 0.12598374619015626, 0.1146517771163157, 0.035876243109149594, 0.13454993867448398, 0.10524679321263518, 0.16808366855340345, 0.11656874710960047, 0.13365871006889002, 0.1304598924304758, 0.260579703109605, 0.15897432235734804, 0.1983258929103613, 0.12424529876027789, 0.15047835824745043, 0.0806811453242387, 0.11863697612924234, 0.17641120670097216, 0.11161219129072768, 0.16369931453040668, 0.1492116962160383, 0.07662582650248494, 0.136095166472452, 0.14196134598127433, 0.09931892129991736, 0.08906610789043562, 0.13932943078024046, 0.15691694989800453, 0.13605501077004842, 0.15834024495312146, 0.16979342752269336, 0.11946533168000834, 0.1540222516549485, 0.1883805508592299, 0.13280101466391767, 0.09650578975145306, 0.15474897623062134, 0.1169498259467738, 0.1307716385594436, 0.10805590104843889, 0.1012336928397417, 0.1501618895147528, 0.1045922851189971, 0.1018000388784068, 0.11830966440694672], [0.051920132378914526, 0.051928084809333086, 0.022293712478131056, 0.032924259547144175, 0.06965690545205559, 0.043331181830061336, 0.04895859504384654, 0.051333162268357616, 0.029836792897965227, 0.04808768177671092, 0.07340583178613867, 0.03303709652807031, 0.04076859594455787, 0.01532653356636209, 0.01854139516529228, 0.03942868945055774, 0.08072782853352171, 0.015337310398795774, 0.06032918633094855, 0.027625772968998978, 0.018313948530703783, 0.035948283172079494, 0.08113167900592089, 0.01638621697202325, 0.04944751684420875, 0.04490540003670113, 0.01641367219521531, 0.008433305641769298, 0.035888365137257745, 0.026174596909965788, 0.03302562589358006, 0.07332069599734885, 0.02074601990170777, 0.054465578469846926, 0.022652879723214676, 0.018604427675849626, 0.02545207246605839, 0.017510727613366077, 0.03078171397958483, 0.028419073704364042, 0.019595819924558913, 0.014617559466777104, 0.0542052890440183, 0.06645126853670393, 0.04430421461750354, 0.02130899022865508, 0.041717723943293095, 0.06072872132062912, 0.04438669054902025, 0.0026188690930471887, 0.04562222139377679, 0.015709661579291736, 0.01899031562996762, 0.01294923184572586, 0.025220329008464302, 0.022091814383332218, 0.04462869345609631, 0.01596413765634809, 0.016757419732000147, 0.05513425437467439, 0.015299532961632525, 0.03210306932617511, 0.004355131640165512, 0.017058563751301596, 0.016577414569578, 0.01187455705699644, 0.053988405503332615, 0.014494961759607707, 0.013102156675553747, 0.03444778440254075, 0.12439004385045596, 0.06561543553003243, 0.014729505870491266, 0.066739700202431, 0.020918072633711354, 0.04011556366458535, 0.02894947604675378, 0.014540343877992459, 0.04063687194138765, 0.05839354305395058, 0.0187965429920171, 0.030180067156574557, 0.0273841839682843, 0.11826086416840553, 0.034913435844438415, 0.016113115108704994, 0.025951173988037875, 0.017483750757362162, 0.018305965566209385, 0.027924085800935115, 0.054559677706233094, 0.005082682756307934, 0.04025179992562958, 0.0560516574686127, 0.03260898842875447, 0.052742052025028636, 0.07649816013872623, 0.09791138861328363, 0.034235100993620496, 0.027100919346724237, 0.040284610486456325, 0.008140314220716911, 0.004865251298594687, 0.02762189174869231, 0.01880287711641618, 0.022146984369360974, 0.02568288633067693, 0.03216369982276644, 0.025315391764576946, 0.03710884268262556, 0.02356657971228872, 0.025220055898119296, 0.05711554948772703, 0.06396990668560777, 0.001834778834433694, 0.016771933596049036, 0.08161262462713889, 0.023463333823851178, 0.053039311431348324, 0.05767179213996444, 0.05667080370975392, 0.01456825711232211, 0.04693975658821208, 0.030970204222415174, 0.017542679827394228, 0.05890843578215156, 0.018292667976181422, 0.050435250092829974, 0.016086696347753917, 0.04244016357032316, 0.02675387412974877, 0.026947765511327555, 0.028062852997598902, 0.045053904210882526, 0.04394803462283952, 0.03236393889944468, 0.03846897291285651, 0.05396725895947643, 0.0914658826908895, 0.024690830813986913, 0.05386705969327262, 0.09837712826473372, 0.02675764848079, 0.029819507218365158, 0.05440589113693152, 0.07850234223795788, 0.03732111557785954, 0.04673354301069464, 0.03342056720118437, 0.03607612595494304, 0.06887039515588965, 0.02263249653125448, 0.04568544728681445, 0.0364012629725039, 0.015010151346879346, 0.04477065655269793, 0.060901306702622345, 0.029998538683035543, 0.021001629132245268, 0.014547035929613879, 0.004109983299193638, 0.0915283825514572, 0.012739064105387245, 0.026284182011815052, 0.01716345169448427, 0.05708988729332175, 0.02866694763568895, 0.019222342375931994, 0.038371216372719834, 0.019486893001677733, 0.050187768015478335, 0.03055938519537449, 0.0926966570051653, 0.008500112503367876, 0.007371683322292353, 0.047757320039506466, 0.03028043605653303, 0.09617494964706046, 0.008329039406297463, 0.006669596777231033, 0.022841412374483686, 0.020461343927308917, 0.05804130874042, 0.03561661186228905, 0.012828248203732073, 0.002268107624591461, 0.028834484717143432, 0.050409306306391954, 0.03600258632962193, 0.010715381757888411, 0.01312956355312573, 0.026514106995559165, 0.025723274431324432, 0.018375179530786614, 0.03695137845352292, 0.07687268432761941, 0.07310543076268264, 0.041001598084611554, 0.08027105911501817, 0.02849098654197795, 0.02965728985145688, 0.06202057735728366, 0.021883407441366996, 0.03695542930758425, 0.04119124862232378, 0.013502363414902772, 0.011288516539415079, 0.04154812411538192, 0.017977254365437796, 0.01680953461410744, 0.023859586400379027, 0.12379620357283525, 0.01804880249047918, 0.03833123369674597, 0.017331674096307585, 0.037357600405812263, 0.046676393398748975, 0.050536799643720896, 0.04755701310932636, 0.03094186520736132, 0.03355679328420332, 0.018666498363018036, 0.02529910862046693, 0.06463456566312484, 0.012883642106316984, 0.0342440881899425, 0.06504053995013237, 0.046785030247909684, 0.01811278155738754, 0.014150879196157413, 0.044909651058592966, 0.021578904673723236, 0.002870295155194721, 0.03180681415168302, 0.0020444932285629746, 0.04188493872061372, 0.03730880695262125, 0.019614559365436435, 0.004306976858060807, 0.04110638764021652, 0.019892690869580423, 0.06016122855778251, 0.04750612298292773, 0.018195642557527338, 0.02922378061339259, 0.012235320555711431, 0.039468604273029735, 0.12436067685484886, 0.04900973622820207, 0.05260695909549083, 0.04080552860562291, 0.027557376639119217, 0.013507788302376866, 0.05730401937450681, 0.03549662312226636, 0.04482713441497513, 0.05635089819718685, 0.05175092610131417, 0.021103638390611325, 0.047477695758321455, 0.031441419651465755, 0.051082837129277844, 0.01965862512588501, 0.043044989329895804, 0.01770389126613736, 0.043218836787023714, 0.07380856946110725, 0.0480264914887292, 0.02087226303826485, 0.07371104362287692, 0.010022123377504093, 0.01597334537655115, 0.07581928585256849, 0.04297200610328998, 0.013787600028860782, 0.03045017837679812, 0.011810649236265038, 0.0598990765533277, 0.08717148884066514, 0.03495507753853287, 0.024744463918198432, 0.040520604965942245, 0.010319392113680286, 0.03357783126245652, 0.04139821876638702, 0.024891115691778914, 0.014245274443445461, 0.023406881406637173, 0.032003528238939385, 0.013721766016845192, 0.05097635802147644, 0.03596470032685569, 0.058661523674215586, 0.03173960865076099, 0.0310451450225498, 0.02083193600576903, 0.06841279792466334, 0.05632745481229254, 0.016236493131145835, 0.03733889658802322, 0.01658638140984944, 0.013612752580749137, 0.021442809208695377, 0.05378578816141401, 0.043187729349093776, 0.04445371623816235, 0.0703640610777906, 0.02540357587193804, 0.04303100133048637, 0.021628875385171602, 0.009743405788737749, 0.032197918343756876, 0.019293323924232806, 0.005203906005980181, 0.060052656169448576, 0.02739842641832573, 0.040703042676406245, 0.060532957182398865, 0.034834939520806074, 0.04559003847784229, 0.058403958566486835, 0.038782333955168724, 0.042794009404523034, 0.04278194844456656, 0.02724590531683394, 0.03230558828051601, 0.0499681974761188, 0.03811998878206525, 0.015880862749846916, 0.0376607087839927, 0.029279495123773813, 0.08398557693830558, 0.018307205588955964, 0.018116527070690478, 0.080472556874156, 0.0240310674666294, 0.015561601845547557, 0.005160873315097498, 0.018196863920560906, 0.031507963580744605, 0.058220421629292626, 0.02818228194623121, 0.01419782024874751, 0.07780078452612672, 0.05950677474694593, 0.02506562472055001, 0.06119912929300751, 0.0097608127564724, 0.0655667574277946, 0.017109309689008763, 0.03286842968580978, 0.04041642948452916, 0.17450805168066705, 0.1267813912459782, 0.0963817671207445, 0.06958833948842116, 0.10737125242927245, 0.13617497576134546, 0.10405092273971864, 0.10911035125276872, 0.13044641672500543, 0.09216948957847697, 0.21048699106488908, 0.09826558389301811, 0.15633605606853962, 0.14052781861807617, 0.11506856046617031, 0.15575926059058734, 0.09979160236460821, 0.09519785922020674, 0.17953423197780335, 0.17930795411978448, 0.09070865118077823, 0.15581291913986206, 0.2493604522730623, 0.10632482929421322, 0.13038475146251066, 0.11148413816200835, 0.08144750313035079, 0.1374261129115309, 0.21920353333864892, 0.15125074822987827, 0.08476204491619553, 0.15926202120525496, 0.09258978095437799, 0.1484157203563622, 0.11335921540324177, 0.24067243561148643, 0.10267860602055277, 0.08339144489062683, 0.11156577949545213, 0.15340326486953668, 0.11708566865750722, 0.1793352040861334, 0.1588586728487696, 0.10575877502560616, 0.10413765308580228, 0.06040214920150382, 0.10004884177552802, 0.08394718542695045, 0.09658581617155246, 0.075845938708101, 0.12819746668849671, 0.12615404490913662, 0.1783848615097148, 0.09566342923790216, 0.09650165747318949, 0.04805858958778637, 0.11472742020019464, 0.07647811621427536, 0.05681219344426479, 0.14378237112292222, 0.24896687482084545, 0.16004454850086144, 0.09797464843307223, 0.11111411266028881, 0.1459613370576075, 0.15952754552875245, 0.14142310486308166, 0.08883818119232144, 0.07888846937566996, 0.12111817513193403, 0.3658136991517884, 0.18020371533930302, 0.07648777855294091, 0.12937480637005397, 0.09565697636987482, 0.10670751625938074, 0.12743514616574558, 0.08917336392083339, 0.0882022310314434, 0.231148110968726, 0.10543978892798934, 0.15729155551109994, 0.11077886886362519, 0.22304784134030342, 0.21787236976836408, 0.1328351314046553, 0.08573997672647238, 0.16895467681544168, 0.07878049409815244, 0.09577693457582168, 0.17777977112148488, 0.18124751932919025, 0.10093082194881779, 0.19282958284020424, 0.11136012910200016, 0.1075552711263299, 0.18809928452329977, 0.16736121874834808, 0.11226614298565046, 0.08292488421180419, 0.2235894887042897, 0.11456801875361375, 0.18184127818260873, 0.10742702800780535, 0.18865668747041905, 0.08442703182143824, 0.20012437711868966, 0.07369435844676835, 0.1550537877316986, 0.1175182754439967, 0.06890263913997582, 0.10252949116485459, 0.18690936480249676, 0.15510903405291693, 0.13013209216296673, 0.13053740827100618, 0.17028056138328143, 0.08811477465288979, 0.1155438335346324, 0.0976195710578135, 0.1708675484572138, 0.20643731765449047, 0.1571104952267238, 0.1322438017066036, 0.1457947159984282, 0.14258793235889503, 0.10681854494448219, 0.1194101803536926, 0.11534834759575979, 0.16511008382907935, 0.12971587878252777, 0.09210257924028806, 0.1484003040407385, 0.1430493090301752, 0.10345666855573654, 0.11998390885336058, 0.26226708399397985, 0.1039549575320312, 0.14963936326759203, 0.08755665245865073, 0.17276222178978579, 0.19462700853390352, 0.10611322136329752, 0.1671223472803831, 0.09661041985132865, 0.1827594581991434, 0.12097995754863534, 0.17974559563611234, 0.09388068704200642, 0.060920896008610725, 0.14500363916158676, 0.14536419909979614, 0.12660962689135755, 0.10919723766190664, 0.07571436398263488, 0.1828313557697194, 0.16879155699695858, 0.057025697880557606, 0.2314806202692645, 0.0907625336466091, 0.0800130936716284, 0.13897911672081265, 0.09400732881788697, 0.10511847545525857, 0.07513836917600461, 0.11771673336625099, 0.11405533126422338, 0.2014046505625759, 0.14806498560522283, 0.06969830287354332, 0.13455909889723572, 0.1419360637664795, 0.24530530987041338, 0.0986440707264202, 0.14055908551173552, 0.18064453239951814], [0.05607412037040506, 0.04060525560219373, 0.0360559157894126, 0.026973144417362552, 0.06423928508801119, 0.053565243924302716, 0.040076809136995246, 0.02439750182176275, 0.03046837668599827, 0.010766439821704157, 0.040194816554763486, 0.07994375417807273, 0.04601303381579263, 0.07668633147009782, 0.04281803293685828, 0.018738635117188096, 0.028422761542190398, 0.050813726748206785, 0.04323127094124045, 0.03826077122773443, 0.02216580353810319, 0.05124392134270497, 0.04478627642882722, 0.05175023399559515, 0.009768887323194315, 0.03900477130498205, 0.027262631205043623, 0.02211947486336742, 0.03038744781432407, 0.04449091352788465, 0.03190889635256358, 0.05206053484497326, 0.05591140088758298, 0.01905750247117664, 0.05773840392274516, 0.046363341089870246, 0.030766904952802827, 0.015345607185736299, 0.005709580835952822, 0.026983254589140415, 0.02581652719527483, 0.019542275029899817, 0.043026807984071117, 0.047844158951193094, 0.035472643694707325, 0.03831189884138959, 0.028655002026685646, 0.015011255662622196, 0.030136274506470988, 0.06320586946925946, 0.011685839504934847, 0.041033309418708086, 0.060609991263066015, 0.016650940624198744, 0.05986991311822619, 0.015975591327462877, 0.05175966223967927, 0.019127001420461705, 0.008750430857097464, 0.06861785799264908, 0.03312052580128823, 0.023029493799965297, 0.0456696577769305, 0.0578765943646431, 0.014017351138006364, 0.020211982307955623, 0.05615921883976885, 0.05403688004506486, 0.025613132930759872, 0.02766428661665746, 0.07655337253319365, 0.020485085867611424, 0.024528167310303876, 0.03051636946786727, 0.04011913275878344, 0.058449718968144486, 0.02243082913836198, 0.04773779519434486, 0.06852690037339926, 0.019007423194125295, 0.06925644765474967, 0.03022511848913772, 0.05343732310991202, 0.03431957181809204, 0.04678091832569667, 0.05340931657701731, 0.018656997176419412, 0.05277006873594863, 0.021481701139626757, 0.02587149870981063, 0.036398294381797314, 0.02565187049497451, 0.037634456264121194, 0.024661024466955235, 0.03516597979302917, 0.06522282159754209, 0.06491511953728539, 0.043914073945156167, 0.027731867008177296, 0.006866127235947975, 0.012859195337763854, 0.013473260199784167, 0.003789153282663652, 0.014809605233105165, 0.03150958188676408, 0.05981437502694981, 0.035806313290127685, 0.024285362035568272, 0.08123603090643883, 0.041074781479047875, 0.02033576405873256, 0.03095526966665472, 0.010284447560219892, 0.02848981267639569, 0.019930254568212798, 0.05493716709315777, 0.020773293616782342, 0.03894081598679934, 0.026649627402158718, 0.014845596426831824, 0.026469411893880794, 0.02380167513287493, 0.041322395870728154, 0.035250399727374315, 0.0491019423518862, 0.0153670675520386, 0.019773085501843264, 0.03263392798336489, 0.07345839110868317, 0.03495765597160373, 0.03184088339496936, 0.04517312959900924, 0.04890523844265512, 0.04419040393882564, 0.03670895146206021, 0.053736638477338214, 0.01736328873916396, 0.028190298837476542, 0.03886023995333484, 0.0033399298096940455, 0.03911945050848382, 0.061618423222431114, 0.01346837729215622, 0.024129387190831558, 0.05845611076802015, 0.043378034673099, 0.0014217294415824913, 0.04123855947649904, 0.030704588296690156, 0.03193164084638868, 0.04654005875012704, 0.03248966804572514, 0.026034175784194043, 0.03482104651629925, 0.032809526060840914, 0.053506947588175535, 0.0875954714470676, 0.011560936475039592, 0.027508427122873918, 0.039849228491740565, 0.06551115826836654, 0.026589984174019525, 0.027273330005950162, 0.025388597211401378, 0.030704710432993512, 0.038261476904153824, 0.021515839932752506, 0.017823958037687198, 0.05009660344304783, 0.05122803683791842, 0.00925645258809839, 0.03907210572755762, 0.03076469971399222, 0.056585728989115784, 0.0135568574104192, 0.027816290335197533, 0.008151719546211618, 0.024581830948591232, 0.026217790752915398, 0.026263466337695718, 0.06557208392769098, 0.08828195211078439, 0.040502813777753284, 0.030697100662759373, 0.02597065981743591, 0.10983016834195171, 0.03165716664599521, 0.044315593649766276, 0.05207258223422936, 0.01963339210487902, 0.03231235666732703, 0.0530061378542866, 0.016336130909621716, 0.026903796442119137, 0.01485892285459808, 0.03750396040933473, 0.05352118664554187, 0.043417362562779865, 0.021501236162813644, 0.03377190924116543, 0.033520281314849854, 0.021651214454323053, 0.04197127890906163, 0.0396008066433881, 0.007734132132359913, 0.033811413549951146, 0.04013607917087419, 0.08433363826147147, 0.027628232658441578, 0.028355674784896628, 0.06381960439362697, 0.05796407788459744, 0.02064167139386492, 0.015375756192952394, 0.024042529619431922, 0.025841103733650277, 0.03454252824719463, 0.02038196211547724, 0.04713973442890814, 0.007792200311087072, 0.004408853802098227, 0.0413105249005769, 0.05546636673222695, 0.04310589124049459, 0.012352534087507852, 0.025145259286676134, 0.026763490667300563, 0.05808816836880786, 0.013345832171450769, 0.022000471695459316, 0.01709271950780281, 0.026977000192606022, 0.02918958244845271, 0.06915219753448452, 0.055666717767183266, 0.017276695796421597, 0.018147469963878393, 0.03644473331847361, 0.04767802643722721, 0.14706292508968286, 0.052984010827328475, 0.049032219486044984, 0.02197554910422436, 0.03635947878605553, 0.04362052273271339, 0.010143333480560353, 0.0038989169240397003, 0.0158056674990803, 0.0966324315273336, 0.01758064895070025, 0.052956587834549804, 0.06131492807929005, 0.02555183068450008, 0.018458724154957702, 0.035586332237081866, 0.039677535383296866, 0.028309093355866413, 0.003946365181556237, 0.0484508608600923, 0.05275796367121594, 0.06299648713320494, 0.03436722193977662, 0.027490841191528097, 0.020122157842186943, 0.07579023776842014, 0.07275306752749852, 0.00968663954907762, 0.041473685431161096, 0.09800603067768471, 0.025310613181708113, 0.03505598248115607, 0.02354164355035339, 0.07672137101846081, 0.013290506970536495, 0.023517207807994316, 0.011360643963728632, 0.02180895857912089, 0.028222188287015473, 0.029613354708999395, 0.03722768809114184, 0.011510809700536941, 0.035210216883569956, 0.02021202302005674, 0.016294613048168163, 0.018526682829750434, 0.01814825027914984, 0.07393036649695464, 0.01161236349227173, 0.027140807027795484, 0.039019827997045856, 0.029611583732600723, 0.06711651783968721, 0.03770045058003493, 0.017123747217868055, 0.008048533029588205, 0.06971449950443846, 0.05084736512175628, 0.022094073904944316, 0.04649918380060366, 0.07504341498549495, 0.02956191836191075, 0.05076917074620724, 0.013434100247520422, 0.03274536718215261, 0.023979782093582407, 0.013139813672751188, 0.0640960056334734, 0.04779921618423291, 0.03186734286802156, 0.01844533665903977, 0.06360696508948292, 0.03724040383739131, 0.06887188114758049, 0.009757282678037882, 0.020748720471081988, 0.016364797317822064, 0.026107427032132233, 0.007695207971015147, 0.003332377926978682, 0.009421197497951133, 0.0765126875734755, 0.02489834208972752, 0.037294540753854175, 0.0633723276800343, 0.007880694000050426, 0.051982018165290356, 0.06360283281121935, 0.0395863979522671, 0.06180094914244754, 0.015190395692895566, 0.005660430727792638, 0.02396964986941644, 0.040924930412854464, 0.01715987072592335, 0.05773599512342896, 0.021338355527924638, 0.024530272465199232, 0.03569306918819036, 0.06801759877375194, 0.029154227381306033, 0.010274797944085938, 0.04988851710887892, 0.04085169952096684, 0.06139921569930656, 0.021663168545014093, 0.041482360501374514, 0.08141393600297825, 0.06930321228823491, 0.01909887444760118, 0.07080709016216652, 0.018913848126041036, 0.03523702919483185, 0.13563646322914533, 0.12364319392613002, 0.09261987398245505, 0.06125554947980812, 0.19590216582374914, 0.1376214088605983, 0.21026090319667542, 0.0983248267854963, 0.12692099304071494, 0.1395917252770492, 0.13617406652442046, 0.1750140759561743, 0.18584724036710604, 0.12096094499741282, 0.09629549139312335, 0.12150104530155659, 0.11003066186926194, 0.17958875905190194, 0.1126707602026207, 0.12257891174937997, 0.19302980495350702, 0.15435952427131788, 0.05904668050685099, 0.12598217198891298, 0.06764029937663249, 0.08304343785026244, 0.10831550176122359, 0.14454573658960207, 0.07665710696684462, 0.10212237015366554, 0.07261970825493336, 0.1728514220033373, 0.17815201543271542, 0.07859481977564947, 0.1264835008020912, 0.14733995736709662, 0.20775917172431946, 0.07930869968341929, 0.16731963812240533, 0.16986888061676705, 0.15856072812208108, 0.09734564647078514, 0.11126484242933136, 0.07131713815033436, 0.08423152552651507, 0.12017977477184363, 0.198227532474058, 0.11320469262344496, 0.07882845973862068, 0.09257065983755247, 0.11972051512982164, 0.12822551732616766, 0.15227324622017996, 0.07191424896674496, 0.16927613956587656, 0.1325568234814065, 0.1198871633304017, 0.12681096180209092, 0.15314052253961563, 0.1388176525277751, 0.1239782138062375, 0.1264703915055309, 0.15202787438673632, 0.17894700063126429, 0.13947712071239948, 0.09440673488591399, 0.12194346370441572, 0.1503732396023614, 0.11184826719441585, 0.12559533917478152, 0.18911881053021976, 0.1353117027985198, 0.12319008181137697, 0.15085064327078207, 0.10588312335312366, 0.17455834469624928, 0.11929759782339845, 0.10935323964804411, 0.15845069688345703, 0.05590822195102062, 0.15843738402639115, 0.17365034270499433, 0.17181576043367386, 0.11326974377568279, 0.18315523410482065, 0.16121362362589153, 0.05184317632977452, 0.15491744290505136, 0.14329673003937515, 0.17550135909446649, 0.08794303065431969, 0.10724423067378146, 0.1977589497608798, 0.09495057391801051, 0.1563186312892607, 0.07554559875279665, 0.22963326796889305, 0.09865708502807788, 0.1146812933896269, 0.07743726617523602, 0.08282840331750256, 0.13883032756192343, 0.14377918200833456, 0.13091912493109703, 0.15271730667778424, 0.12843449254121098, 0.11789552734366485, 0.09799055329390935, 0.241891193070582, 0.10748154829655375, 0.15165857491748674, 0.07365576337490763, 0.08804785752935068, 0.1145650331995317, 0.10996575999472823, 0.1294112437005554, 0.12870415592832224, 0.13175425226134913, 0.10822819466037409, 0.11687621846795082, 0.165638391194599, 0.1109176224895886, 0.16302529855498246, 0.14517830764608725, 0.11803409776517323, 0.08665178529918194, 0.13225769810378551, 0.09704184598688569, 0.16833509291921342, 0.11242648759590727, 0.1554389920617853, 0.13767601735889912, 0.11814754882029124, 0.06262059908892427, 0.093644237944058, 0.11440434253641538, 0.0952490343313132, 0.08613920637539454, 0.102083781867155, 0.09849015184278999, 0.1928490296538387, 0.1281359371330057, 0.15953262097069196, 0.14807348086365632, 0.23195440056068556, 0.1193601723228182, 0.0642761295395238, 0.1240544675716332, 0.10056874887751681, 0.18265983568770544, 0.13258895889988967, 0.11385495987321649, 0.15555872635117599, 0.11553642393222877, 0.0951619782884206, 0.08662641487483468, 0.1276493053883314, 0.08587317993598324, 0.15265484074396746, 0.11379089938210589, 0.11522975324520043, 0.1533509769609996, 0.1557636439268078, 0.11402723991445132, 0.13464407862297126, 0.1488189465765442, 0.10947516560554504, 0.10945471456008297, 0.09444980150354759, 0.2252511259700571, 0.1977552178182772, 0.1664660410689456, 0.17895491234958172, 0.2119813694485596, 0.09467048823301281, 0.09682550188153982], [0.04277870165450232, 0.02461098420566746, 0.025101607432588935, 0.02157597170610513, 0.049621944448777607, 0.04987785393106086, 0.031029976372207915, 0.004532631736115685, 0.01147516880051366, 0.04516788113063999, 0.0252218862463321, 0.047918017487972975, 0.04714923731184431, 0.021425389518429126, 0.019229758763685822, 0.04608419856854847, 0.017545919832108275, 0.060425239748188427, 0.028082829068547914, 0.0388308899211032, 0.05203489300661853, 0.030290081431823115, 0.07007915100881032, 0.04973674578858273, 0.10148344800940581, 0.047495015364672453, 0.027412624763590947, 0.058321441922869, 0.019574291704754745, 0.07215776161423751, 0.057297084746616225, 0.02447439171373844, 0.023907852292593037, 0.0372555215976068, 0.03572027165708797, 0.037493965588510036, 0.07549955336643116, 0.012847917237585145, 0.03710327869547265, 0.037288796954921315, 0.03207816709099071, 0.02497497244205858, 0.020258451778707758, 0.059663557048354826, 0.033227361139974425, 0.030673321403030838, 0.05375724219317947, 0.017342713861060993, 0.040309190417506864, 0.043104931113443205, 0.05141284602827259, 0.01204729510936886, 0.0326189086107271, 0.04697713368971433, 0.049797118441866975, 0.028242021865610565, 0.02885297140372651, 0.06877550881888185, 0.023898500383698514, 0.089200966725392, 0.03854946412944368, 0.022129396741677607, 0.013306670522849475, 0.026535363801355873, 0.024822955152818134, 0.009715802136010357, 0.042450277134776115, 0.019167135070477213, 0.03134870123384254, 0.050327196783785305, 0.04718134898160185, 0.06978052774710314, 0.0428642072448773, 0.024667872581630945, 0.09861790641610112, 0.0191673929137843, 0.023928069243473665, 0.015629323033083762, 0.01762586652434298, 0.035544503945857286, 0.044124172135655365, 0.08246635738760233, 0.06185090967587062, 0.026165699619533758, 0.02763318257140262, 0.0079770714177617, 0.02600672734635217, 0.028684385985668217, 0.02151701888734741, 0.034953849390149117, 0.024258909347866262, 0.02457789714182062, 0.02892112685367465, 0.041321330570748875, 0.018208979163318872, 0.048974737391940186, 0.04597247099237783, 0.029009190521069934, 0.05293987551704049, 0.04646494831623776, 0.04055145116789, 0.08336070725428206, 0.026285993700314845, 0.020864315696858933, 0.011534549096333129, 0.024355483540732945, 0.032760902241404564, 0.06516015210321971, 0.04105016762124641, 0.013289764822859849, 0.03575659702931132, 0.07154489521469388, 0.04502421151846647, 0.05017246026545763, 0.01893770202462162, 0.024919022140758376, 0.021096008264326623, 0.014590606359498841, 0.05711212967123304, 0.012495217279398015, 0.04888882128787892, 0.04090964301888432, 0.041571055206337144, 0.007193723094782659, 0.014640538055183632, 0.0335297434856849, 0.011414626513474753, 0.038928761812193055, 0.08289387516145195, 0.02304575319534966, 0.07391168642789125, 0.04625736749065774, 0.029581165007714714, 0.016971667164138386, 0.03641175312389221, 0.0409072443975934, 0.05357294190408928, 0.047079639974981546, 0.01747735895748649, 0.0216817654935377, 0.0077997736100639615, 0.01966072179909263, 0.035631376784294844, 0.11630652046629361, 0.038105702227247615, 0.026329252004091228, 0.024101480741852095, 0.04281181077073727, 0.043263718485832214, 0.027947785332798958, 0.034372935204633644, 0.03810447407886386, 0.07749243785760232, 0.03625094710982271, 0.03706351654337985, 0.025794797111302614, 0.034334564049329074, 0.05005267169326544, 0.022148429648950696, 0.009895909926854074, 0.04296885770080345, 0.031197951108749424, 0.03977968543767929, 0.03148818089227591, 0.024555084794493656, 0.029278528211372237, 0.030164148725037063, 0.09716852847486734, 0.028020622674375772, 0.030311740269618373, 0.03070821167368974, 0.08531378209590912, 0.045070182265979905, 0.025608121949647154, 0.0321115577992584, 0.05215771123766899, 0.1023503104224801, 0.02214926085434854, 0.02453577029518783, 0.02828415380125599, 0.022140808004353727, 0.04707246785983443, 0.03647991535919053, 0.024117994587868452, 0.04333678652931537, 0.052456778939813375, 0.0116982507585947, 0.05303975926446063, 0.03244121386004346, 0.035358381790242026, 0.040492676464574676, 0.010040142723093075, 0.030235018315059797, 0.09929678070225886, 0.031708243369523964, 0.027105653824816858, 0.0614924192694681, 0.013135942630469799, 0.029875632242432663, 0.04707460185246808, 0.043181703958128176, 0.049086122307926416, 0.024628487016473497, 0.07060562632977962, 0.047975167099918635, 0.04822325985878706, 0.039163348331515274, 0.018934928512732898, 0.02475082009498562, 0.04977750199447785, 0.022400376486725042, 0.012494942472715462, 0.04007804407072919, 0.028860774556440965, 0.027388468916927065, 0.055933846825999875, 0.019789412750729492, 0.015596283466688224, 0.008595909773638206, 0.026847450894170573, 0.03344628028571606, 0.012024408971358622, 0.022538164896624427, 0.04093608892123614, 0.046927454748323986, 0.027104469781209315, 0.015696202837196842, 0.038191292634499927, 0.045235330904168744, 0.05314356494428856, 0.04659050443608846, 0.05055770870032055, 0.04504145309329033, 0.009984596998297741, 0.024234152997710874, 0.03513870947062969, 0.03447140759921499, 0.033504138966756206, 0.04609958774277142, 0.028907159210315773, 0.017944995114313703, 0.017571122319038426, 0.019339527069990124, 0.041761404635118585, 0.0017519464599899948, 0.03410654914166246, 0.044242702025387964, 0.05203418054484895, 0.027583386582721556, 0.0568278506398201, 0.07996421879423515, 0.03517578123137355, 0.03924655029550195, 0.03931101790762373, 0.05448384463254895, 0.03577133480991636, 0.06045478316290038, 0.07347388206315891, 0.06115908215620688, 0.08380258282912628, 0.031140964345208237, 0.009862743983311313, 0.05402417108416557, 0.02380716787385089, 0.054533038421400955, 0.09818158804305963, 0.03824045928195119, 0.08886207919567823, 0.061529412998684814, 0.04155126912519336, 0.029353458833481585, 0.022387553871210133, 0.0121965159861637, 0.023984637011640837, 0.08358783328107425, 0.04516675476250904, 0.026726856561643735, 0.04158398469111749, 0.10112195169287068, 0.012694641265885105, 0.006756070976345134, 0.03147371791835342, 0.07500354426779918, 0.030216484131025415, 0.04593818122521043, 0.01646965303059135, 0.0456377802017544, 0.03411221490906818, 0.022497904021292925, 0.05347953477342214, 0.05009060858615807, 0.012248455297334917, 0.013821333397312887, 0.05789272992738655, 0.05326680386705058, 0.01189406493878258, 0.053694847505539656, 0.0335165934770235, 0.0583086379670671, 0.11797536377395902, 0.013780558531704758, 0.032466275550957234, 0.018313465074502995, 0.03629644627549818, 0.05127069294186575, 0.03660979035443493, 0.02697167030003454, 0.03376541566103697, 0.022714195540174842, 0.01789923131998096, 0.04645397640498621, 0.013083637758557285, 0.05519703921994992, 0.035030880078141174, 0.03510834502854517, 0.04602354432323149, 0.06514262554368802, 0.013507719600706227, 0.005628275801427662, 0.01672581865984414, 0.041100749014211554, 0.04260178043373993, 0.029209870645510297, 0.015991784565682923, 0.03997055394575, 0.014073616109921463, 0.051329121592321565, 0.03796098767114537, 0.02322732747000243, 0.04661833794255342, 0.07260219526610204, 0.06435998289712838, 0.008878700268853987, 0.05333578034437128, 0.02192284050397575, 0.03129028954676219, 0.0186925965161728, 0.0337209682246404, 0.04807380912825465, 0.03578695468604565, 0.02148450688192887, 0.02933215961924621, 0.03808320200602923, 0.08966809058828012, 0.01479681654434119, 0.055757658423057625, 0.03672417439520359, 0.11360447867108242, 0.016279315476172736, 0.012015611764841845, 0.050467806203024726, 0.026333832115467106, 0.1286588433597769, 0.11043202890349285, 0.05847904525165047, 0.11387474595436028, 0.09492521706436362, 0.11273190299315111, 0.10813264335904803, 0.08506266985620771, 0.14121640952570097, 0.15324572260890687, 0.05910759938082524, 0.10790550376155547, 0.13037673117859022, 0.13748461620083877, 0.13596222789159843, 0.0695995149601783, 0.09660209422664982, 0.1972594801336527, 0.11611186234014374, 0.10313614896897759, 0.09690630183156047, 0.09404014955673899, 0.19250156544148922, 0.10901351073490721, 0.1971725733684642, 0.13760150064315113, 0.14985250468764985, 0.1372812728264502, 0.1664892876786845, 0.14963481708296708, 0.1545226848019021, 0.1258376304592405, 0.11124253219791821, 0.17241972445377282, 0.1150906535663775, 0.14053901444588388, 0.09337472383465086, 0.12639743542032583, 0.09241330078137772, 0.24768107810190745, 0.07342736170228038, 0.1876580739127738, 0.10598489682057075, 0.16076805682054587, 0.08698816903467689, 0.06650475745222398, 0.1274121031165123, 0.09331719763576984, 0.29528068963970455, 0.07377232212041106, 0.12089188370321478, 0.06036352698824235, 0.21910411438771657, 0.18928183535380022, 0.18039279590759957, 0.17361438034900598, 0.07809801679104567, 0.14637516199478082, 0.14328025520912238, 0.26760245912841385, 0.10097726767084428, 0.09759417349206549, 0.09938825400812284, 0.1269640935850995, 0.1880909385425704, 0.06602252261447054, 0.13147069247705595, 0.11521622325692858, 0.10705654788762331, 0.11284128283815724, 0.11241155304014683, 0.1202395808483873, 0.18487574106880597, 0.09729232718901974, 0.1723732990877969, 0.1261534070862191, 0.17150899475174292, 0.07539262303284236, 0.09819662437907287, 0.17050206235476903, 0.1389037993337427, 0.1838648731687239, 0.13607816238488468, 0.14412040369851248, 0.10768521058240108, 0.1380688212811947, 0.10772704226630074, 0.11925809351461274, 0.11672729360205786, 0.11157732137611934, 0.10082796961069107, 0.19030415692499705, 0.14616246840783528, 0.07429903492863689, 0.14656306191214494, 0.09762729957167592, 0.1084193651165281, 0.1419367151600974, 0.1347599181213549, 0.08911856543272734, 0.10496423087481942, 0.22085614608866827, 0.16174050606787205, 0.09969128774745123, 0.13773158937692642, 0.13053430058062077, 0.12713675360594476, 0.16144219493227346, 0.12327964843383857, 0.11921010751809392, 0.15965711857591355, 0.1459133510610887, 0.10386123827525548, 0.13144710659980774, 0.0981949009001255, 0.16634945518204144, 0.12039563033197608, 0.12789517933768885, 0.1630051324942282, 0.07157755989049162, 0.1230960368577923, 0.06297824132655348, 0.1407897331352745, 0.19183194637298584, 0.11387420312634536, 0.15345836191305093, 0.11431412452033587, 0.10837166410471712, 0.1409978126840932, 0.12413855163114411, 0.129032309034041, 0.18845383264124393, 0.17556875119251864, 0.11123448477259704, 0.13311917973416193, 0.19001584739557334, 0.14041066276175634, 0.11620364098676614, 0.1656729964805501, 0.1031313720824463, 0.1273215458329235, 0.1937915962189436, 0.08014627652508871, 0.22226384840905666, 0.15067296209079878, 0.09714507830462285, 0.12589384030018533, 0.0961497285004173, 0.12043959940118448, 0.07421319346342768, 0.11536940932273865, 0.1162474879196712, 0.12374452634581498, 0.12256384827196598, 0.14407494185226305, 0.15645200413252625, 0.18135334365069866, 0.15369671769440174, 0.05774153196918113, 0.12873162302587712, 0.12033002956637315, 0.1369597693639142, 0.14761082854654106, 0.11906602739223413, 0.14191530059490884, 0.09654372664434568, 0.10057035022016082, 0.16014373674988747, 0.115993254418884, 0.16673913784325123, 0.14484674829457486, 0.36062225486551014, 0.10660914903772728, 0.06901494347091232, 0.07495205703058413, 0.1215256896934339], [0.029559051551456963, 0.02870204485952854, 0.07513974660209247, 0.043159780491675646, 0.00744877677477364, 0.011985534851971482, 0.023698234165619527, 0.06562046347452061, 0.027681821657876884, 0.009307861793786287, 0.07913521863520145, 0.014299319757680808, 0.05799035754586969, 0.030979255879563943, 0.043375605517732244, 0.08505536881940705, 0.01740517300952758, 0.10774613624172551, 0.0704554326034018, 0.03845494080867086, 0.036644151367779286, 0.06008244385676725, 0.04944173911852496, 0.03731309190126402, 0.06810554369751896, 0.043885799390929084, 0.03949759468170149, 0.0537789654918015, 0.03528767504862376, 0.03605368001652615, 0.04544402452717934, 0.022062070800789764, 0.04556676472670265, 0.02151004015468061, 0.03533332349200334, 0.029068453769598688, 0.012638645163471145, 0.09615206266088144, 0.037825087284935374, 0.07413851389927523, 0.04697008031819548, 0.020854424352624586, 0.04438539454713464, 0.04251968787450876, 0.02216831242133464, 0.019483020263058797, 0.01755759402710412, 0.05290743136512382, 0.01840347783373935, 0.017274361635957445, 0.06695425976067781, 0.02827928022348455, 0.019866163543026363, 0.02999006038797753, 0.005915925031461353, 0.027302634237068038, 0.014920303132385015, 0.05932913427906377, 0.021938887857166783, 0.05101259518414736, 0.018181289845545377, 0.03174696397036314, 0.05187854157494647, 0.036672863577093394, 0.06073374926511731, 0.033890303423894305, 0.030548257221068655, 0.045581322695527754, 0.03373842353799513, 0.02839121305649834, 0.018939518802134053, 0.01735956867092422, 0.04528333725673812, 0.017209975448037897, 0.0491096267609724, 0.06411205977201462, 0.07228388091815369, 0.01568045573575156, 0.10090170601116759, 0.02632888898785625, 0.03747929905408195, 0.021798709307664206, 0.012321092471081232, 0.0383454795394625, 0.015256736061668821, 0.011889005612049783, 0.07178346812725067, 0.02186101408941405, 0.027142659428396394, 0.05798581136124475, 0.03564113411786301, 0.013128057205384331, 0.019573423179930875, 0.024643041592623507, 0.05052088799753359, 0.06626013879265104, 0.06025249830314091, 0.034206144511699677, 0.003677888382558844, 0.025258483032562902, 0.0625784620642662, 0.005566676696097212, 0.03299291372033102, 0.05476887683783259, 0.015971370839646885, 0.0502563645131886, 0.0875951728916594, 0.021223503297993114, 0.0645093759521842, 0.06135072758687394, 0.05950357884700809, 0.005750947299280337, 0.028102869600323693, 0.046085365648780546, 0.042356106652212996, 0.04691320212025728, 0.052107991584177525, 0.0271536771407617, 0.029893311472343545, 0.031127926294824908, 0.05368601976494704, 0.05133171020341771, 0.035586987023374865, 0.02543484785461, 0.031376300645726066, 0.014897758806390422, 0.031107560066240172, 0.04352817411667534, 0.031812781867172034, 0.07403386344334908, 0.023360288103244135, 0.07370324725551264, 0.03324026009067893, 0.05691358693210142, 0.02489940569336925, 0.06306053405361516, 0.025199513250429715, 0.04315722580733044, 0.06104468793741294, 0.047233385832182, 0.015510833855452282, 0.020057315339467356, 0.053881787295852385, 0.024889872276357243, 0.03479653104607548, 0.032592031838638444, 0.03116405149921775, 0.06018019361155374, 0.026446828552122627, 0.07894416353000061, 0.009546807900603329, 0.04588133356134806, 0.046626687315957885, 0.05526176128270371, 0.01935244128773255, 0.017569899259667312, 0.03048191006694521, 0.03233718087098428, 0.03015441174751946, 0.030824855236070495, 0.0244640457510416, 0.031680447182485034, 0.01891467933143888, 0.04383260903081723, 0.03119011063660894, 0.02675384359567293, 0.004079925470120672, 0.08288092871329614, 0.08063688448497228, 0.041065855350877555, 0.008208083753873194, 0.028579331801405976, 0.04160551121458411, 0.12533166046653474, 0.049086308905056546, 0.08563763328960963, 0.015210928162559867, 0.045546758121677806, 0.032201545113431554, 0.01959205575154296, 0.029463388291852813, 0.022249890990289192, 0.027123068426070467, 0.006235125291693423, 0.031945910437830856, 0.09110218113554375, 0.0330132053100637, 0.040975294674613645, 0.07352386295263257, 0.001711417139241738, 0.05190909600683621, 0.030804183666727374, 0.040063092551593266, 0.05438202027497547, 0.06607103108295373, 0.033199015339570384, 0.023732257607792104, 0.043060314043291976, 0.014155509349490916, 0.02203024072306497, 0.06766290137810366, 0.04226665198802948, 0.022788194872971092, 0.042459986970892975, 0.06403917832566158, 0.030486035559858595, 0.02148599287361971, 0.014598299250272768, 0.02491767524874636, 0.0028768690993144575, 0.0345478649251163, 0.04324553035465734, 0.030824563466012478, 0.035864473919251134, 0.07302554683493716, 0.06355061275618416, 0.06396847497671843, 0.005637099725260798, 0.028621940407902002, 0.047693446145526, 0.008931709120848348, 0.03583492711186409, 0.041886916650193076, 0.022290292661637068, 0.034664905430482965, 0.0407976983115077, 0.07460322217749697, 0.06646579597145319, 0.017696244176477194, 0.0407530167805297, 0.044642827340534756, 0.04549300457750048, 0.02721274022145995, 0.019794903795367906, 0.021616020539243306, 0.048916664972369156, 0.022342195501551032, 0.025509427334847193, 0.08151463738509587, 0.02478715734157179, 0.08474399588469948, 0.0356896832984473, 0.012529389151105923, 0.0026977659643827273, 0.012143157688634736, 0.03326372383162379, 0.03072280017659068, 0.028835526268397058, 0.019336258227537786, 0.014741117300997888, 0.013536991601410722, 0.06921566091477871, 0.022141405115170137, 0.03981608884142978, 0.04108165843146188, 0.06722452704395566, 0.10050555691123009, 0.0444454550743103, 0.0708685518641557, 0.017339962401560376, 0.023885450458952358, 0.03446294626753245, 0.013216643344743975, 0.042646163409309726, 0.04371014703065157, 0.021891108813828657, 0.01757495434555624, 0.015898184052535465, 0.02231076406314969, 0.06329821808529751, 0.018012069997244647, 0.032515727183116336, 0.01561057341418096, 0.03541210140766842, 0.03346234799495765, 0.04204663700823273, 0.03287422776754413, 0.026453537567119514, 0.03757916923080172, 0.05020650236734322, 0.04837935683982713, 0.04100989317521453, 0.028384505737839, 0.021464206810508455, 0.043109158386609385, 0.01077651182588722, 0.05133660922625235, 0.023911526559719017, 0.047642586553203206, 0.05585770501888224, 0.010380383082000273, 0.08682346822960035, 0.049446444758879285, 0.03354195033067039, 0.017607154224866202, 0.0487221561239234, 0.034065833647868464, 0.04335957173524158, 0.05088510523949351, 0.08093056801174368, 0.0030783935757686515, 0.01757746153245015, 0.04733386329774346, 0.03044773225805589, 0.05969445753310408, 0.012307313969358802, 0.0621860788336822, 0.044770598877221346, 0.013110196467355957, 0.06959661083029849, 0.020776128196822743, 0.060349359177052975, 0.028100111355472888, 0.112025907662298, 0.02767108384120677, 0.029503469355404377, 0.05500521397750292, 0.0348530971179051, 0.0649906201288104, 0.03212337109393307, 0.030157726391085556, 0.00922511360009334, 0.02609376812220684, 0.03344854659267834, 0.03812075213396123, 0.06491664624107735, 0.009859388627644097, 0.03385507727840117, 0.0017096752126235515, 0.029549124584134136, 0.03178275669259684, 0.050621786154806614, 0.03375199084569301, 0.011648059523265277, 0.013482196505979767, 0.061063015168266635, 0.01157893885725311, 0.01551909332296678, 0.025254247277708988, 0.06727199056851012, 0.007297500785041068, 0.005230365479032376, 0.013348563274900829, 0.0965497452499611, 0.025736203916104775, 0.023178362686719214, 0.034177266061306, 0.011810650932602584, 0.028289512531565766, 0.06433428677597217, 0.05216954828106931, 0.054394359434289594, 0.10770159041775124, 0.06893212827188627, 0.09219324508947985, 0.10807671850281102, 0.09080764943999903, 0.12612648281667913, 0.1464845554104873, 0.16958819782095297, 0.1281859315931797, 0.1715806887618133, 0.19194325325744493, 0.144297257065773, 0.1171540514166866, 0.08800114717866693, 0.11972641838448388, 0.15966906079224177, 0.10876545190278973, 0.1565738690218755, 0.1449284167694194, 0.1727596569274153, 0.13836625032126904, 0.12201696261763573, 0.19578771053680352, 0.09088458852576357, 0.1312320517109973, 0.18141795375517436, 0.15782140993646213, 0.10310459709061043, 0.14067316081907066, 0.16035835737628595, 0.14324090017804078, 0.10448677970894746, 0.15024157666734286, 0.08440696754093681, 0.09231786483100482, 0.11751621269754, 0.08570775988378695, 0.14531911723315716, 0.15892767986016615, 0.12708694913557597, 0.2685815580189228, 0.07068377999322754, 0.12224003779036657, 0.09743032085576228, 0.072885965396251, 0.10094355805111782, 0.1051062618249229, 0.15329605633659021, 0.11287322148148503, 0.09257037485284464, 0.14938109926879406, 0.12150077388754912, 0.11346050032547542, 0.11065714646662984, 0.09934440707521779, 0.12403039314917155, 0.08450770284980536, 0.19520921872130462, 0.16178979485162667, 0.12296366824635438, 0.09961063707513468, 0.12427201946931225, 0.15767970468316758, 0.11994242322232042, 0.14919329434633255, 0.1983335739267724, 0.07926483239446368, 0.10592272944216218, 0.0789207269304565, 0.1628212495041745, 0.11969855773661818, 0.09262748714536428, 0.1603212279400655, 0.1310336616422449, 0.11682650899248463, 0.12087908653276307, 0.11339599200125251, 0.15981485082634858, 0.2632198285843645, 0.12060544693044253, 0.19030212131994112, 0.12306018306740693, 0.1354418322443962, 0.10903642486248698, 0.1481142472475767, 0.12480283741440092, 0.15538480425519602, 0.11448405683040619, 0.08183925532336746, 0.1545432579836675, 0.11385136363761765, 0.1463658389236246, 0.11564883004341807, 0.11833288387528487, 0.11374222806521825, 0.18778121444795812, 0.16440291463264398, 0.08235078251787595, 0.13260168821683951, 0.159984023177198, 0.19988302221255644, 0.08440505407218422, 0.1532344724982977, 0.11741661732750279, 0.07624524299587522, 0.07859553223741905, 0.10688286327889987, 0.17659342049488, 0.10730276110449008, 0.14344507136515208, 0.09821544015513999, 0.14041929372719356, 0.16198514508349554, 0.13041802681982517, 0.15888190588780812, 0.13172297179698944, 0.1049375305218356, 0.0960985194625599, 0.13026997047875608, 0.17522636242210865, 0.09439219388046435, 0.11748782279235975, 0.11301743731434856, 0.1272866962743657, 0.1013870146125555, 0.08756301033177546, 0.1336793511041573, 0.17152086911456926, 0.10666741483977862, 0.1267693540347474, 0.13405805506876536, 0.20020008805607045, 0.07406435002173696, 0.18004837153213366, 0.15003247931599617, 0.15071233069258078, 0.0936026233913643, 0.17126276796417578, 0.09825493767857552, 0.2346317640372685, 0.18494506020631107, 0.08968002601925816, 0.14257464664322989, 0.12024914819215025, 0.06394009185688836, 0.11354226379522256, 0.1443724116044385, 0.07849012860762221, 0.13439401132719858, 0.11451761717242853, 0.07371732007179942, 0.08929539165858712, 0.1932529615504401, 0.14724469105047838, 0.16865385510027409, 0.11278434017939226, 0.16281318850815296, 0.08040671862129654, 0.17735259261514458, 0.2039017001433032, 0.08329078422061034, 0.0843491427866476, 0.07213562101657901, 0.2211932965687343, 0.136653139388987, 0.0960719141044787, 0.14315924527389662, 0.12478138213711125, 0.13820390403270721, 0.20131378115287848, 0.14862791182739393, 0.09922242683491536, 0.09531627036631107, 0.16633724155170576, 0.19363070199532167, 0.19774946384131908], [0.053234634521816454, 0.017059014977088997, 0.011507758837459343, 0.048230998550674746, 0.05717057867773941, 0.032364566544336934, 0.05524395313113928, 0.016649568287123526, 0.019988874904811382, 0.02151828944416983, 0.05627260882673519, 0.04010749588321362, 0.055303528505776606, 0.04114546786461558, 0.055052209312894514, 0.024623538799850003, 0.0181732967030257, 0.043427313278828344, 0.03522983333095908, 0.02525619467321251, 0.10662822944245168, 0.011086372475671982, 0.06170549962137427, 0.041989300799156935, 0.04217870367158737, 0.0325236762208598, 0.042774979889925034, 0.03645492491445371, 0.05381625438375132, 0.026095827475988438, 0.019895915607256547, 0.031274625565856695, 0.021929198377100483, 0.027985915608171905, 0.043673207584236345, 0.052143180410244634, 0.03873200362016048, 0.0625823772113238, 0.05345210160261818, 0.04676842649600335, 0.05293563128049884, 0.03182059180523668, 0.10193907070372786, 0.08504111279866525, 0.027449335204437375, 0.02377722242714039, 0.014648354778598462, 0.012555455922016075, 0.0211491341636117, 0.0312379744968244, 0.026871201316160814, 0.03354510212583201, 0.053520022957984886, 0.06498772278428078, 0.0875965231763465, 0.00964541345768209, 0.049035812328968725, 0.034789481067231724, 0.004111050295510462, 0.07618202388818775, 0.03165325149893761, 0.04517314316970961, 0.07173575354473931, 0.03641146135383418, 0.06629949382373265, 0.009407568273932805, 0.031757131817617586, 0.04049134314326303, 0.07576931174844503, 0.05527252284809947, 0.008342716975935867, 0.02546371951965349, 0.035021886096468995, 0.01817978689047907, 0.03373404698712485, 0.042897370643913746, 0.06118175879653011, 0.00618950611013653, 0.02295708393545023, 0.014833347173407674, 0.06128032957868917, 0.08660554313766104, 0.018527775271130458, 0.004161797929555178, 0.018263267053823386, 0.017808619753590653, 0.018664761313370297, 0.028469185211828778, 0.0357835145135011, 0.014033969308781837, 0.013361462225605334, 0.05519402991714222, 0.04274636606818863, 0.04824478977492877, 0.05185795482248068, 0.019095383384930234, 0.06737866305879184, 0.009624782600440085, 0.021530189252059375, 0.013325530403692807, 0.06587395058678729, 0.0682299259517874, 0.06462590755628687, 0.03388499728004847, 0.008771675788531346, 0.08126862094338451, 0.08713906165212393, 0.021668554416724613, 0.04494544717350176, 0.03961533747081246, 0.024157130791406547, 0.026030986669606397, 0.0493818753665047, 0.06998968616660152, 0.04271361318283847, 0.0401806012461228, 0.033662739742015085, 0.156075512192079, 0.03693806898913213, 0.015620223878483688, 0.02360300686476486, 0.05941709955888135, 0.05763686115720442, 0.041754171451819797, 0.008287681848742068, 0.043254646472632885, 0.03585017718640821, 0.05559657760230558, 0.011599954783118196, 0.014118636908408786, 0.016232430402721678, 0.019386854887540852, 0.0444410887014653, 0.021130481235949055, 0.03527832483606679, 0.04424505314922758, 0.06053577310272625, 0.025293227418192794, 0.027971347461321523, 0.016516378648313026, 0.035088599659502506, 0.04204704412924392, 0.03177857352420688, 0.02087004592509142, 0.08755750062742404, 0.0745031043354954, 0.040400056434529166, 0.042873272472726445, 0.06446865706571511, 0.023676234363977398, 0.06549930426159076, 0.0280416182441903, 0.04568432431135859, 0.02072541618586651, 0.04703650550384607, 0.0075850571405940825, 0.03319530714569347, 0.006160625115236533, 0.057491512170859745, 0.07772750274411269, 0.01208522352057376, 0.01265882479492575, 0.12480192817747593, 0.0471345877407917, 0.018930095647062575, 0.045639374759048223, 0.07736274945948805, 0.02844964001061661, 0.07186989991792611, 0.008805162339870418, 0.035176371556839774, 0.01511934120208025, 0.04131868428417614, 0.04366674453818372, 0.053693476864801984, 0.007066083024255931, 0.03224050998687744, 0.003456061502220109, 0.02231071826203593, 0.037804490354444296, 0.02454008238523134, 0.02960123268089124, 0.018685302264722328, 0.02728509919584862, 0.03489490844575422, 0.04766229121014476, 0.0434472689937268, 0.005838390107133559, 0.0687976765579411, 0.023170182947069407, 0.034358641864465814, 0.016204617252307277, 0.043117365267659934, 0.059795260695474486, 0.010639764119072683, 0.023028806783258915, 0.04688890038856438, 0.01899678715770798, 0.04939335957169533, 0.020059861542124833, 0.06418890386287655, 0.03448285787765469, 0.01928294912379767, 0.06398881067122732, 0.09015956707298756, 0.03130606209327068, 0.020004788247336234, 0.010972732278917516, 0.02967460945780788, 0.018429401264126812, 0.035046971536108425, 0.05803911028695958, 0.015355829315792238, 0.030064634779202085, 0.017962862637692263, 0.015615798133824552, 0.043407126862023554, 0.03720130664961679, 0.01569491531699896, 0.025618266048175947, 0.049579753141318045, 0.028763462456741502, 0.01623655080662242, 0.0284109618182161, 0.023959295425031866, 0.018315463360132914, 0.04333040151478989, 0.03198870224878192, 0.012487789017281361, 0.0414804606033223, 0.03625805137146797, 0.0286458893013852, 0.08413549925067595, 0.07315489596554212, 0.03445196417825563, 0.047207092600209374, 0.010124538908712566, 0.03693120221474341, 0.07269311217325074, 0.018323648188795363, 0.028306106105446815, 0.07317751153771367, 0.021585939385529076, 0.012891016085632145, 0.021907278303323046, 0.07985792628356389, 0.02193598711996206, 0.041025092359632254, 0.031067143127854382, 0.020348966653857912, 0.03874303999223879, 0.0534171027663563, 0.029507883225700686, 0.0321518695647163, 0.027001291746273637, 0.014399993998397673, 0.04019772407731839, 0.04289882949420384, 0.0469640481418797, 0.008961104106024971, 0.026858212459566336, 0.034133103609617264, 0.03948248031416109, 0.01993084998269166, 0.021179837873205543, 0.039426769196454964, 0.027311336448682205, 0.05240242489214454, 0.05375794108424868, 0.039373982564679215, 0.006420171121135354, 0.006603707634245178, 0.02100330850641642, 0.02975359432665365, 0.04436072301385658, 0.024900457422648157, 0.028747618664056063, 0.03076958516612649, 0.025663346218477403, 0.06316380029810326, 0.0549017577432096, 0.013016087052944516, 0.0982647832216961, 0.057019652133541446, 0.011848687061241694, 0.03665495025260108, 0.003689815755933523, 0.04766791965812445, 0.03882173987637673, 0.02802787791006267, 0.026383002155593464, 0.02358069154433906, 0.053866808635315726, 0.06790906709751912, 0.05900451634079218, 0.02783212734253279, 0.023667776424969946, 0.045007845253816674, 0.03986721306240984, 0.052991104910948446, 0.048509476107678244, 0.068924331904522, 0.026809515697615485, 0.0525151024173413, 0.016899805216650878, 0.03293023744065847, 0.016514582226851156, 0.050247546950621266, 0.05573899192469461, 0.022998991954539503, 0.030090944974550178, 0.016549684539703385, 0.04389007755422166, 0.043247990044099946, 0.019158390450424383, 0.0149704892787018, 0.07119183308844056, 0.03704034457249301, 0.051636542060545514, 0.008663052510071014, 0.060956139117479324, 0.014794685944382633, 0.008446200351629938, 0.06408317453627076, 0.018535308706175004, 0.02784091606736183, 0.018972018933189765, 0.009813970886170864, 0.0525860398608659, 0.061875520140997, 0.018013036909646223, 0.020345253370968357, 0.020560662794326032, 0.012223723544073957, 0.05732044670730829, 0.04220401302778295, 0.035982745965676646, 0.007429947428006146, 0.011610211688093841, 0.018753184604325464, 0.034324728684233766, 0.014058410988322325, 0.02103488752618432, 0.019870774188478078, 0.019133832571761947, 0.008017512104873146, 0.029731426587594405, 0.010869492327661386, 0.05478632536583713, 0.0065272549732721275, 0.017889416310936213, 0.02094415043081556, 0.06794877496681043, 0.06382404201264892, 0.12200947159102984, 0.10697232133575849, 0.13010850628571852, 0.12740047302629265, 0.12231973851365702, 0.13254208570080145, 0.12518577543752535, 0.1364816464483738, 0.16091087487127098, 0.07751822218831096, 0.17340689791100367, 0.06241352377193315, 0.09479993235852037, 0.07875416693942887, 0.10137549308793885, 0.17227881987180027, 0.0669943815363305, 0.12318522350064345, 0.18187721339719637, 0.0670479450907026, 0.14375187775918416, 0.12237579907689776, 0.14262605245624269, 0.11968863755464554, 0.2352488509246281, 0.18553254939615726, 0.16367894490914686, 0.09271807157035385, 0.14007729850709438, 0.11576665086405617, 0.1416699830442667, 0.10369596750076328, 0.1654222642204591, 0.13923945703676768, 0.13113132997282914, 0.17021281644701958, 0.22544325994593756, 0.16016709192522935, 0.11325765906700067, 0.07578036508389882, 0.13784795813262463, 0.15421112866273948, 0.17028518899210862, 0.1010601914354733, 0.08116627072117158, 0.14503542174186024, 0.10774047725966998, 0.15428846808416502, 0.08301077995981489, 0.11254104466310569, 0.15645125774400576, 0.2809700332581997, 0.18485922552645206, 0.13499967168484414, 0.13166317929114613, 0.21216160192021302, 0.11005844109292541, 0.20027756318449974, 0.09386587462254933, 0.17476685850747994, 0.18454255323324883, 0.08957820505435977, 0.19248845614492893, 0.20747270781014646, 0.15826618964118616, 0.0674411900607603, 0.11181591464472668, 0.11838013705398355, 0.12055762378232819, 0.11634411130632673, 0.2613396351890904, 0.09759300641183342, 0.10018067434430122, 0.1762908481593643, 0.1275370485548462, 0.11108668627483503, 0.13434822378414019, 0.08726329462868826, 0.14100987703672477, 0.1963721327483654, 0.12532783352902957, 0.09307466207870416, 0.16113148017653398, 0.12187962712986128, 0.1243115102073976, 0.2512368458722319, 0.0851968637268458, 0.10413807377751384, 0.11540913076273032, 0.10374444882784571, 0.11678988167217799, 0.11473474837839603, 0.11232244782149792, 0.13371376640030316, 0.1171671064304454, 0.047111816105565855, 0.16902091540396214, 0.0857595456764102, 0.16456127113529614, 0.13827151326196535, 0.11013071864311184, 0.09662044859890427, 0.08126484828868083, 0.17784394696354866, 0.12469294188278061, 0.12173633410462312, 0.11361445313585655, 0.08894340161766325, 0.07206699398479291, 0.13303874619305134, 0.17781052232853004, 0.1607779905732189, 0.07499782421759196, 0.13069634831377439, 0.10976812988519669, 0.26627581460135324, 0.14766224793025426, 0.09438363755387918, 0.07264229668570416, 0.18025700747966766, 0.1907072745795761, 0.09374054920460496, 0.1379171008510249, 0.19237648429615156, 0.19478026245321545, 0.11000244159783636, 0.09747935858156, 0.1605521605483123, 0.09362679280872856, 0.07413276670766727, 0.17051940570984567, 0.10544514935463667, 0.13343610987067223, 0.1593739523419312, 0.2070462621216263, 0.0820987338998488, 0.11914670520595141, 0.10020926780998707, 0.10229011079562561, 0.10840949243200676, 0.08990679920784064, 0.11385380636368479, 0.1866321832473789, 0.1313781945833138, 0.09686178993433714, 0.18504622977759155, 0.17685205090258801, 0.06703398084001881, 0.16951225618166582, 0.11316480833504881, 0.08909592271915504, 0.15140674343066557, 0.17069757543504238, 0.09746455973280327, 0.13813761116138526, 0.10217022044318062, 0.1496340978358473, 0.14070273137518338, 0.1634601309363331, 0.13087842640067848, 0.24994990921446256, 0.17307023597615107, 0.12466022292418139, 0.12463214514510972, 0.14124249241181783, 0.08384585300726549, 0.1376817441944565, 0.10374133435211011, 0.09034700558653899, 0.10013513107384954, 0.08122469937162739, 0.14884106681815215, 0.10656406717108828, 0.08978280371853284], [0.058005597442388535, 0.022895184578374028, 0.044188884020383866, 0.023455791907118897, 0.035984656041754146, 0.031805843846606355, 0.04121865465172699, 0.04483309195243886, 0.050789889813001664, 0.031024816113391092, 0.02797962898122413, 0.03171683701553515, 0.047944914616112194, 0.018908167091597403, 0.014153471199928649, 0.014733578776940703, 0.02642551067817424, 0.028428401864532913, 0.04653400961043579, 0.08474331056433064, 0.038508361870689053, 0.05495725172970976, 0.038008668326905796, 0.04608876510922398, 0.06088505578892572, 0.04853642751861896, 0.04749253871185439, 0.0483472383847194, 0.042975846611495526, 0.011597018422824996, 0.0488264299929142, 0.03244163794443011, 0.014808541629463434, 0.06116539253188031, 0.06607602510069098, 0.02914443612098694, 0.046744487780545435, 0.05712743063590356, 0.027508438997236744, 0.06789527248059, 0.021574217693081925, 0.06958078060831342, 0.031082030186163526, 0.01792167216938521, 0.04634798923507333, 0.010208315931127539, 0.018712835519441536, 0.027856076236015985, 0.010379055697870041, 0.04177063949672239, 0.03819499404302665, 0.06021626453314509, 0.024175675153466206, 0.026153297695730413, 0.09035847961370434, 0.0300189931211727, 0.006201742641029081, 0.03035994679001825, 0.049508235550352504, 0.018924943869933486, 0.051265926233359745, 0.06381575710007123, 0.002513298374002001, 0.021112026779779365, 0.007768817994344447, 0.06936464006347315, 0.010896272408509893, 0.06209026968904904, 0.01107939035033009, 0.009960995854011603, 0.04206702698554311, 0.054790284617670944, 0.06238542563681092, 0.037841867455946546, 0.005558123762187148, 0.004526722544272031, 0.05408303060435823, 0.05122804023059351, 0.023566289638568248, 0.13488390003996237, 0.11807371063956193, 0.022888448421976397, 0.042498337770146985, 0.03963741021496909, 0.02948927440281425, 0.10434546800596373, 0.08502445476395742, 0.008148601677800928, 0.03714253533897655, 0.033289301209151745, 0.06049736802067075, 0.03135676562253918, 0.01724593780402626, 0.027671889601541415, 0.013865524686739912, 0.023149796362434114, 0.08752942284835236, 0.03274854951139007, 0.09764489398470946, 0.017947615955823233, 0.0035766021880720344, 0.05474257003515959, 0.008534143579059413, 0.06218308649424996, 0.045419003548366685, 0.04375389218330383, 0.028793843862201487, 0.027368267233084356, 0.008789410997581269, 0.05586478892447693, 0.02960891030462725, 0.027919989145760025, 0.009952990837129099, 0.08563305996358395, 0.01018482250427561, 0.013326943452869142, 0.06045945148382868, 0.04229476030117699, 0.06576534427170243, 0.02635696846326547, 0.042212277584310086, 0.043507533081408055, 0.03128096986828106, 0.03493428722556148, 0.04080818507022091, 0.019872965856588314, 0.03292235625641687, 0.033395244274288416, 0.02810998064731913, 0.022514305909031203, 0.020057308554117168, 0.028400629426219633, 0.014649313209312302, 0.04522257783849325, 0.11500076124710695, 0.032083184857453616, 0.005782238789834082, 0.008112312776834836, 0.034497212285974195, 0.024990236087303077, 0.01736612501554191, 0.014616176951676607, 0.04929181680615459, 0.04218429480014103, 0.05052037231091942, 0.022058898649577583, 0.06274654197373561, 0.05450891310881291, 0.023260389088786075, 0.030179388621555905, 0.04619918989815882, 0.0271053569657462, 0.03493973586176123, 0.028507339235927378, 0.03072332264855504, 0.011916048625218017, 0.014796872523480227, 0.022958430827462246, 0.08446132498128073, 0.08487580809742212, 0.036728262568690946, 0.05736736061849764, 0.04547024651297501, 0.029012172682476894, 0.04094724064426763, 0.05575658633772816, 0.03978473034554294, 0.029467503606740917, 0.08440813462116889, 0.04392083893929209, 0.03430881364537137, 0.06686502562037536, 0.044743304806096215, 0.028431845429752554, 0.052255539023982625, 0.014862156073961939, 0.07451968094600098, 0.03269365602838142, 0.03418014983513525, 0.03595117712393403, 0.017054178718743578, 0.024117702817810432, 0.02722071131159152, 0.0128488561604172, 0.053527805754648786, 0.02641826562051262, 0.03859292429738811, 0.03694728349468537, 0.014119187369942665, 0.054148990993521044, 0.035513070811118395, 0.10380843468010426, 0.03215553365381701, 0.0022920970181335826, 0.0800344335979649, 0.06045014876872301, 0.031771350518933365, 0.015254958299919963, 0.010500064784927028, 0.024966063277263726, 0.036551192070224454, 0.045960939289735894, 0.020229335841057555, 0.026366137167704955, 0.03925253836704152, 0.04456379158156259, 0.04034772102854081, 0.02564878316063966, 0.010234621885631765, 0.022062764602846334, 0.005809596473617213, 0.003932461574939745, 0.047054249194583724, 0.02064233466184565, 0.0063419674157298035, 0.013100989595321673, 0.011834588799891728, 0.03563643526285887, 0.03482144345928516, 0.06499767010765416, 0.05280751708362784, 0.02325378355037953, 0.04535364705537047, 0.030715461820364, 0.011716244659120483, 0.007559531501361302, 0.0029415131305410925, 0.04063510775033917, 0.022064554238958017, 0.04600443338443126, 0.030893356738878146, 0.015657626425049136, 0.017050229644935046, 0.007945930053080832, 0.04474630732355373, 0.03320091184494751, 0.059125343071562905, 0.033425228736762486, 0.018548044808475033, 0.02851231289761407, 0.01885189957517598, 0.047727963221924644, 0.03694299515336752, 0.02277306523839278, 0.024776757096073458, 0.02028294519654342, 0.006917713708909494, 0.01701922059458281, 0.031579783119793446, 0.04310125345364213, 0.020477996873004094, 0.0409632710340832, 0.03631131637043186, 0.06390771895114865, 0.040685682357954125, 0.014427330477961471, 0.05798233726194926, 0.028224958406229104, 0.05002213083207607, 0.026192973334608332, 0.02630030400385814, 0.04205435534406986, 0.037905022102807245, 0.024862199921959212, 0.04462700390389987, 0.01967741036787629, 0.02878951480878251, 0.030840648138629537, 0.057034430626247606, 0.025815506000071764, 0.034523854963481426, 0.041336556896567345, 0.02933956922164985, 0.01177623394011919, 0.04757802394617881, 0.020585851710555807, 0.04751566318528993, 0.0762503252231649, 0.06308549057160105, 0.07015706718500171, 0.021470255950199704, 0.011476341817927147, 0.06536023172416858, 0.036000313237309456, 0.020980524996827756, 0.05443150244121041, 0.06460964307188988, 0.006055116736596184, 0.09889928131763424, 0.061297869708921225, 0.023751675583688275, 0.04749624012038112, 0.027923975538994585, 0.033037384905453236, 0.024405686650425196, 0.03993177906210933, 0.07251133942710501, 0.02257823578215071, 0.03318120040265577, 0.034050495363771915, 0.020364788394155245, 0.030018894733594995, 0.028020525983135616, 0.03944760361420257, 0.010594790818036666, 0.018383598454030495, 0.019721767898382883, 0.012908788614108093, 0.022984902174877267, 0.023591456502409916, 0.029253388488931314, 0.014636897714808583, 0.01970008191918688, 0.022520565394578234, 0.0953739865549973, 0.01931502347412918, 0.02513691160960921, 0.043066597277564664, 0.07158251319612775, 0.04591593545462404, 0.057176325869347365, 0.027382618248728768, 0.09048390002655131, 0.039307883075837574, 0.022135637567511628, 0.019590586723227586, 0.040185232247625075, 0.02000325815086918, 0.025788249248372655, 0.02362125097507877, 0.011563548834861388, 0.043686978452439816, 0.048206299875995944, 0.02311443959894989, 0.042610469074653726, 0.06774493626185826, 0.006934699560848198, 0.059389564607824595, 0.07389272815947022, 0.0885594729334116, 0.00295933209625738, 0.05161552783101797, 0.04479911431138005, 0.03437341696449688, 0.02529438940941223, 0.018806452995964458, 0.025517059157469442, 0.05227030394598842, 0.012031652332682694, 0.040190792842102904, 0.025702312788260833, 0.015136386001748698, 0.23693471189056123, 0.08132147203598704, 0.11905940489045211, 0.12088361914668765, 0.11488505745572702, 0.10403330797063452, 0.1939552995775427, 0.12407007387706212, 0.14369181383933338, 0.13988379389047623, 0.16458515556795256, 0.13195180094667844, 0.12275755644908973, 0.1460909643875701, 0.10257153997996024, 0.11702640540897846, 0.11207964763577495, 0.08808403023119483, 0.19950441324285098, 0.17693817056715488, 0.12457805233342306, 0.1290760338306427, 0.11476042414350168, 0.13552837260067463, 0.12095937079616956, 0.17578006056802614, 0.13384735637477466, 0.09029229530798537, 0.20057123314057076, 0.13430862448045186, 0.11022769486797707, 0.10797703492322139, 0.09731740584330899, 0.2243035246751138, 0.10975796543061733, 0.08547472381698233, 0.1250420074377741, 0.14856484878276074, 0.10163560948733773, 0.20996766750301632, 0.12982710424278462, 0.181174956794296, 0.13881496552910122, 0.11671046593359538, 0.15989153885415622, 0.0628005601465702, 0.1097065256908536, 0.167472118511796, 0.12687600616897854, 0.16680046383823666, 0.11405339065407004, 0.16221548058092594, 0.14753409980663232, 0.11949425084250313, 0.13669372935380253, 0.06786784609513623, 0.08336161649120705, 0.10885037056037358, 0.24621367827057838, 0.10251169997666564, 0.13012996156300816, 0.15221472936017172, 0.09483923310680048, 0.14468198642134666, 0.11194194573909044, 0.18054724404854433, 0.10789134952106647, 0.1538516136684588, 0.06179320027253457, 0.0686058954202703, 0.07250250490116221, 0.134421207010746, 0.11797414241092545, 0.11311117692717484, 0.06334551197609731, 0.1641757275377001, 0.1344527860305139, 0.15454191448433058, 0.17418965590851648, 0.24897656430091175, 0.19973716432494776, 0.085019745730928, 0.17733406860913548, 0.1471526138484478, 0.14200602072690213, 0.16815343552402087, 0.21730037831834384, 0.1841061602213553, 0.12352469457047326, 0.10878742965204374, 0.0801479389358844, 0.17164958720760687, 0.16000138010297502, 0.1175376001213278, 0.0650108540430665, 0.22635180476520741, 0.12368455742086683, 0.11466544281159129, 0.1591786699635642, 0.0735481409355998, 0.16722974580313477, 0.1623599406863962, 0.12259207532874175, 0.12101055947797638, 0.13712371699512005, 0.06528332656515495, 0.20097798774284975, 0.14841159486344882, 0.14568836241960526, 0.2047687050487314, 0.13326104783586093, 0.10437658562191895, 0.21527181645589216, 0.17812654322811536, 0.191306434571743, 0.10629892282720123, 0.13322649683271134, 0.10804925140525613, 0.21888050995767117, 0.09753632838172571, 0.11738281271287374, 0.10019713560385363, 0.12095016986131668, 0.17634313606790133, 0.12822269462049007, 0.09217888050313507, 0.14939004236033984, 0.1881057848887784, 0.10166412831417151, 0.09555582715464489, 0.051787645023848326, 0.0733830262241619, 0.1308316346257925, 0.1228927206248045, 0.17139306025845663, 0.07844105695507356, 0.16075620959912026, 0.13617121667734214, 0.169511170525636, 0.09399025687681777, 0.14957472602171556, 0.08603756182960101, 0.12978316231497697, 0.1853191772741931, 0.14146853956793035, 0.11451642295079571, 0.20284368763012545, 0.11683594062924385, 0.13222620050821984, 0.10096640432519571, 0.12851811519690923, 0.04552516374470932, 0.20707968675664493, 0.12625795576189244, 0.1557080719087805, 0.09543918698493924, 0.13759601808020047, 0.14088056183287076, 0.13063914781170233, 0.16944546119443007, 0.05740292942417519, 0.20956091290073736, 0.1592999648834978, 0.15697762449937208, 0.07398697667356048, 0.1266129652836493, 0.08066301486854043, 0.10627456342003175, 0.1752076619969947, 0.11577529540019375, 0.15074390971234866, 0.14000488524990423, 0.07694564719817468, 0.15661897802991526, 0.10792745436940875, 0.2084450756332704], [0.043576719904584546, 0.03724854286494, 0.010431218925597412, 0.021855389034109454, 0.06465932540595531, 0.022640837422971214, 0.05328686475487692, 0.03456620911934546, 0.03842341946437955, 0.03326508768701127, 0.018980448034458926, 0.03524195196639214, 0.029068667508129562, 0.0775260321263756, 0.042181224429181645, 0.06759941085640873, 0.043061114714613984, 0.016548098464097296, 0.04278407904452511, 0.05966488697699138, 0.02182112810468035, 0.04101228501115527, 0.018337486910500696, 0.07021790463477373, 0.030150442317660366, 0.02760081984368818, 0.03873258716027651, 0.03259671373026712, 0.016469127165951898, 0.008908257254266312, 0.05755769647657871, 0.027420168376660774, 0.02007066721229681, 0.009390006091312637, 0.04119343350508383, 0.0005910073409073188, 0.016530597349628806, 0.03326182732624667, 0.02133462528165962, 0.016241190289812427, 0.029303891850369315, 0.022230988701007197, 0.05014219081827572, 0.05155859535027828, 0.04547960011820708, 0.06320728760744844, 0.048796805154000006, 0.011530716221646538, 0.019584968453273177, 0.011004859215712972, 0.03876793204939791, 0.05690381942050798, 0.012412816834902125, 0.039727909823081324, 0.010755043826065958, 0.0020626627000248326, 0.05522242321499756, 0.03638468975467341, 0.038657161207603555, 0.023566968173586895, 0.02590304719550269, 0.04701742849179676, 0.03396679128387144, 0.007499823812395334, 0.03375746323061841, 0.02109118048766894, 0.006502422712011529, 0.010139777108893862, 0.0791030153632164, 0.04059424976419125, 0.03377556993759104, 0.018564609544617788, 0.0443716067155557, 0.04172669078356453, 0.017838122456201484, 0.02019448628249977, 0.01860882797544556, 0.02047938108444214, 0.040170531786446056, 0.02477187673295183, 0.04483314962791545, 0.03488761419430375, 0.03436136618256569, 0.02581760097694184, 0.010786895108010088, 0.031215647302035774, 0.05470128457194992, 0.023669920595628873, 0.041851354629865715, 0.028813775828374282, 0.06283137242176703, 0.07558840752712317, 0.07364133772041116, 0.020656960484172617, 0.025873997415016805, 0.04606483317911625, 0.007393519427361233, 0.024156984906377535, 0.04957977010469351, 0.03211746444659574, 0.023853437176772525, 0.06122920875038419, 0.0659801752439567, 0.034373240545392036, 0.029574033604668717, 0.02604904757546527, 0.02871339675039053, 0.040721166346754344, 0.00182612263597548, 0.012542937799090785, 0.001441650911666719, 0.024189451110682318, 0.031751479620912244, 0.041939418297261, 0.052373356451945643, 0.056373211821275096, 0.06099847970264299, 0.015038844896480441, 0.023536157594727616, 0.012550537391299648, 0.08394388774675982, 0.028856835660657713, 0.004036018741317093, 0.013569625743132616, 0.021340677814025964, 0.009698418068832584, 0.029352393533502306, 0.0415305127389729, 0.022276250379426137, 0.04337373276108077, 0.031493168124662976, 0.03864501203809466, 0.06825139479977743, 0.030554309753434997, 0.0586222093552351, 0.01882237142750195, 0.08685244167489664, 0.021919525860409652, 0.024221768037282994, 0.012787765956350734, 0.010804216410698635, 0.002859655938144507, 0.029917460533657243, 0.025165255713675703, 0.0361004955401378, 0.035893922339060476, 0.011997321853414178, 0.060055424592324665, 0.10894814067121063, 0.03699152058522616, 0.04164233870272126, 0.04425299879429596, 0.08630052129072802, 0.03872854309156537, 0.00674085398038317, 0.0333848084057016, 0.010427719381238734, 0.04026242917669671, 0.03585920848750642, 0.0797009811337505, 0.008284480011622821, 0.05453641074044364, 0.024787471164017916, 0.03957115127039807, 0.03605814138427377, 0.0334138768459005, 0.08883404891405787, 0.06661598291248083, 0.007571582283292497, 0.019750391898144568, 0.042434243352285454, 0.04117667369012322, 0.05398886690714529, 0.013573129528335162, 0.028740273522479192, 0.04585056539092745, 0.024864854690219675, 0.05538959728021707, 0.018779235260028924, 0.013526675324620945, 0.06129071794982467, 0.03529717793155994, 0.04010916847203459, 0.050840589949595075, 0.07166591872062002, 0.0324766333880169, 0.0275137570154454, 0.06395934189536742, 0.025484723571155752, 0.05311349227226206, 0.008490104960011584, 0.08241207458611045, 0.027929346143667187, 0.04139141984550016, 0.08352122828364372, 0.0362387538355376, 0.03409066124420081, 0.056971326869513304, 0.007012583082541823, 0.10902813994990927, 0.03465580627588289, 0.015396158044625605, 0.02169874243970428, 0.03689231198014958, 0.029130034215216125, 0.05012288988967027, 0.05506611928077681, 0.016608946091894592, 0.03159726557454892, 0.024956314425383295, 0.028937937558761666, 0.022647765265511613, 0.037839828458215506, 0.050882940712784014, 0.04822197403492672, 0.03673990962228604, 0.01958070555701852, 0.05219456925988197, 0.009328090619029743, 0.024725324141659906, 0.029451513929026465, 0.019483997353485653, 0.025158285462696637, 0.01693012216128409, 0.03200971308563437, 0.0658680269760745, 0.03350466483139566, 0.017699626673545157, 0.03701491986534425, 0.038417295685836246, 0.05262407174866114, 0.027248217424909984, 0.05990008757050548, 0.011348348061021949, 0.015230025530659726, 0.021758558694273233, 0.00498924551564934, 0.01630027711923633, 0.06606197264045477, 0.013402455070588206, 0.04121095667194043, 0.043309757086847506, 0.04057623126677104, 0.0805776280217937, 0.06433042591171605, 0.025167574607101933, 0.017862093402072787, 0.04551786949325885, 0.021377089699464183, 0.03413414516087089, 0.0441248574560242, 0.057993573801858087, 0.03528011616851602, 0.03745990652324898, 0.01572901170168604, 0.05371757164331419, 0.03036334625046168, 0.05704963659601552, 0.03183135337063244, 0.017535439858745252, 0.048587059801710505, 0.02541384380310774, 0.054547989940536876, 0.05487792080800448, 0.03877443241487656, 0.03390673414937087, 0.016896778950467706, 0.09786606247403792, 0.04944477556273341, 0.024740085670990602, 0.043131960555911064, 0.06385265583438532, 0.05792075342365673, 0.027086325754810656, 0.057508672321481366, 0.027025367865072827, 0.026642691077930585, 0.07870096300861665, 0.005062755879147777, 0.03455152562154191, 0.02629027864895761, 0.010183977728177394, 0.01520348632974284, 0.03200893277036292, 0.02337271886478577, 0.04217217616470797, 0.029643736114459376, 0.04419269738718867, 0.0552466537005135, 0.023798670919079865, 0.015917367933850204, 0.025482723589188287, 0.06131546412195478, 0.026124627894854972, 0.030477455484547784, 0.018390356662816236, 0.05280435171776584, 0.04265537112951279, 0.010078655522582787, 0.019721508358738253, 0.006572053127456456, 0.018170516405786787, 0.045871325169823, 0.021331931497635584, 0.053524494503757784, 0.046654113701411655, 0.03131474394883428, 0.008361295264746462, 0.11264499622796263, 0.01531691533247275, 0.04946592210658959, 0.03713098667295916, 0.061147594558341165, 0.07376572676002979, 0.02296310763007828, 0.017695360384615402, 0.07982534981731858, 0.045385517845196385, 0.04633016072745834, 0.005958620575256646, 0.05453042945425425, 0.1050657464989594, 0.02863284446565168, 0.018351936313722814, 0.03744845963748438, 0.05304008496126958, 0.008870092203973659, 0.04280984641185828, 0.059474103285798004, 0.02737288296754871, 0.04377633472904563, 0.022074750923950757, 0.016958525637164712, 0.008566238285441483, 0.029295864781098704, 0.01949571056424507, 0.028992230538278818, 0.04413065553775855, 0.0418013601696917, 0.03545912727713585, 0.010414724587462842, 0.02717510188397552, 0.03773468267172575, 0.05322171521506139, 0.030685321294835637, 0.020759599083768468, 0.06695845989244324, 0.015875347956482853, 0.029000349209776947, 0.049726238673818965, 0.035922173144561906, 0.04100811880614076, 0.08158624318561383, 0.10899235401302576, 0.12094103677996568, 0.10371364333799907, 0.2311381229332515, 0.11332784672932965, 0.14416235073336534, 0.07681844902357884, 0.18497514644903795, 0.09903050999024085, 0.10657817391412598, 0.09066526565168585, 0.08442014469099896, 0.14878933530833038, 0.12861453502305917, 0.263234512082168, 0.07874238757150513, 0.11251733664955411, 0.11279536637344531, 0.13810734849955353, 0.11541001285825457, 0.16656342441482203, 0.14548352626817568, 0.2321365736424923, 0.13841652976615088, 0.07359586908881154, 0.10422538087836333, 0.13968613663954393, 0.12701673433184624, 0.15055671547140392, 0.1388380764318364, 0.11311921756714582, 0.09365212930632488, 0.12303160317242146, 0.20956790181142942, 0.06560588175696985, 0.12098500584917408, 0.10674571099558047, 0.1513313717607941, 0.15256559981831483, 0.15264847608549253, 0.18481205377195561, 0.14092683792114258, 0.1190954079585416, 0.21049274504184723, 0.1419143642165831, 0.08926814847758838, 0.1806547918490001, 0.09301305109901087, 0.14192402655524866, 0.10298133441912276, 0.18710774130054883, 0.1131450290392552, 0.1571972391435078, 0.12282380860831056, 0.06516283231654338, 0.1495358595358474, 0.07242650897907359, 0.09719795653862612, 0.20957551497433866, 0.08145377957927329, 0.19336289779416152, 0.1750973593443632, 0.10063293829028096, 0.10311574542096683, 0.07997128912912947, 0.07514358711029802, 0.13668754111443246, 0.2057004286242383, 0.17057359351643495, 0.08107347427202122, 0.09339244038398777, 0.08919988785471235, 0.1654554038707699, 0.1772049433950867, 0.13891647436789104, 0.11595216233815465, 0.12307608792824404, 0.1145081991063697, 0.11946427316537925, 0.14380932253386292, 0.16783742819513592, 0.11630331778100558, 0.13929691538214684, 0.08758489308612687, 0.08614318937595401, 0.15438378868358477, 0.2001474065972226, 0.18343310776565755, 0.1545202149344342, 0.11485970738743033, 0.1297038280005966, 0.1298667306878737, 0.10274911937969071, 0.08364412454622132, 0.08222957580749478, 0.13433347243283475, 0.15797399889145577, 0.11956652839268957, 0.06824833460684333, 0.10795677386756454, 0.159713531977364, 0.0943584299779364, 0.11706215063376085, 0.1429373100399971, 0.055956275801041296, 0.06717758599136557, 0.14805221557617188, 0.0994383841753006, 0.1279472636857203, 0.09153237912271704, 0.13984587735363416, 0.07699397246220283, 0.13235443005604403, 0.12470478910420622, 0.08921521596078362, 0.20130415952631406, 0.09032897691109351, 0.09712214382099253, 0.10316000626023326, 0.1759553397340434, 0.06445403463606324, 0.08429138588586024, 0.0782585513911077, 0.16528277099132538, 0.11547015820230756, 0.12532117031514645, 0.10165259321885449, 0.21327520002211842, 0.11654801107943058, 0.09566906107855694, 0.09191446897706815, 0.3406614916665213, 0.05417273971917374, 0.08213055719222341, 0.09004837553948164, 0.15966602095535823, 0.17644269072583743, 0.1484150146799428, 0.09448543816272702, 0.14593205148620264, 0.13107630078281673, 0.18804770229118212, 0.0997255944779941, 0.11267534709934678, 0.19853209970252855, 0.08254996647260018, 0.15356141781168325, 0.21403190227491514, 0.16201596414404257, 0.0958209986399327, 0.15144114515611104, 0.1353231428989342, 0.14958833743418964, 0.12986891557063374, 0.14264631351189955, 0.06647960415908269, 0.11563448581312384, 0.13113977094846113, 0.12465342400329453, 0.12621451594999858, 0.1754879919545991, 0.11058305722794362, 0.09639854050640549, 0.07965204518820558, 0.17023792224270956, 0.21546946013612406, 0.150660599182759, 0.1372046255107437, 0.1885601319372654, 0.15699943261487143, 0.11401214929563658, 0.09759166291249649, 0.10374543948897294, 0.10250480606087617, 0.11840611137449741], [0.05205996487555759, 0.011944184079766273, 0.010029637304666852, 0.04706818630386676, 0.07008039951324463, 0.02606764791666397, 0.04365183373114892, 0.06398025434464216, 0.016523723789889897, 0.03326614620164037, 0.04422102961689234, 0.047283756879291365, 0.07480655876653534, 0.03562221995421818, 0.013539163761639168, 0.0017795253037807665, 0.0229246923699975, 0.09054040163755417, 0.03790819764669452, 0.011434261620576893, 0.03470598054783685, 0.018034924753010273, 0.032618783081748655, 0.03595316183886357, 0.026946484776479856, 0.04567455001441496, 0.04809658754883068, 0.03468528862244316, 0.08681448442595345, 0.020537361901785647, 0.009072740928136876, 0.042629305206771405, 0.03684319283014961, 0.04283612946580563, 0.06087946466037205, 0.014505436643958092, 0.030235330441168377, 0.04939743756715741, 0.025665600651076863, 0.027216517965176275, 0.03262857773474284, 0.042154710673327954, 0.050254987087100744, 0.010930197463104767, 0.015394492241154824, 0.018668376208682145, 0.051644552166440656, 0.012650264227496726, 0.03892405617183872, 0.03011879205171551, 0.07791178606982742, 0.04435228882357478, 0.02418850116165621, 0.06864638360483305, 0.041242871566542556, 0.02050215780868062, 0.0353138122175421, 0.052666453045925925, 0.015839628176763654, 0.018812914345679537, 0.0259689091970878, 0.06821032986044884, 0.06902468723378011, 0.06721476292503731, 0.010714919505906957, 0.052309156861156225, 0.019761392647134404, 0.03517300263047218, 0.03613031376153231, 0.06879118297781263, 0.011016945620732648, 0.0516071275674871, 0.06913811114749738, 0.044419864126081975, 0.008603863900394311, 0.023036669307787503, 0.044935072373066626, 0.032165514903941324, 0.024456283310428262, 0.01776721385041518, 0.04298259803493108, 0.018569064127015214, 0.051143314955489974, 0.035197138121085506, 0.006266259446939719, 0.03721281799620815, 0.025660762696393898, 0.024725113795804124, 0.031683704150574546, 0.03532564247559224, 0.05731991066464356, 0.05387203674763441, 0.011398222929398929, 0.06088819062071187, 0.08429473106350217, 0.09099235345742532, 0.03285416687971779, 0.019427095406821797, 0.056776882481894324, 0.06366802645581109, 0.01971989344539387, 0.022252555936574936, 0.031117419180061136, 0.03161675310028451, 0.08197821929518666, 0.0481227823932256, 0.007925990453389074, 0.05440287504877363, 0.006556830618397466, 0.025725321910743202, 0.014091615099459887, 0.06920601893216372, 0.053193050503198586, 0.05836222866283996, 0.011234142983864461, 0.013678260895955776, 0.07977480574377946, 0.0590786055794784, 0.030167873882289444, 0.04316482200686421, 0.08915848364787442, 0.02385798336139747, 0.014232044706919363, 0.0027147925284225494, 0.06946528716278927, 0.011241376167163253, 0.0425081697425672, 0.0038708794329847607, 0.054787702791924985, 0.08500498080892221, 0.037348402863634486, 0.02979889671717371, 0.0369015875538545, 0.03449624876624771, 0.030227272837821926, 0.025243097251015048, 0.01577001218018787, 0.02198720463950719, 0.029427276658160344, 0.04432397694992168, 0.05141303262540272, 0.03180844942107797, 0.03025972716776388, 0.007530897323574338, 0.006725093732321901, 0.043477378985179324, 0.017406292592308352, 0.050429004177983315, 0.031905222085437605, 0.11841478305203573, 0.04800518888181873, 0.04309403384104371, 0.01946980748990817, 0.06594532568539892, 0.012932698491827717, 0.015115022326686552, 0.030151958843427043, 0.04187029254223619, 0.09508955824588027, 0.0016131982411025092, 0.018464040476828814, 0.04956960904278925, 0.04329708205269916, 0.026936299965849946, 0.06438333128712007, 0.05192412216482418, 0.015890794806182384, 0.036459640732833316, 0.027644473394112926, 0.03230072996978249, 0.04078270268759557, 0.03056642838886806, 0.041104039909051995, 0.009335083770565689, 0.015501931476007615, 0.019968791964596937, 0.0608094059196966, 0.06683584861457348, 0.0502280017494091, 0.036543789253171, 0.08475296611764602, 0.02448785724118352, 0.029056280851364136, 0.06264345893370253, 0.07012470784996237, 0.025037945580801794, 0.028536869079938958, 0.06902689247259072, 0.0031672445558277623, 0.03898733634767788, 0.023195534711703658, 0.002085905068919861, 0.037768511035080464, 0.03581128016646419, 0.0031318786745292266, 0.03823298182604568, 0.0357863779312798, 0.02281549064043377, 0.009462213243490883, 0.08196598530880042, 0.011718551678183888, 0.027153699193149805, 0.0389378745374935, 0.057280101015099456, 0.05039450406496014, 0.027230857106457864, 0.012074539138536369, 0.01654161506199411, 0.0333176368315305, 0.015635195753670166, 0.05950157716870308, 0.05614180763119033, 0.01853999399047877, 0.061726439212049754, 0.01618758771967675, 0.07981160269784075, 0.0069704028012763175, 0.016494687580104386, 0.035540456484471045, 0.01792070864965873, 0.018888576089271476, 0.01886924123391509, 0.04654517151149256, 0.018819621664338877, 0.04569299938157201, 0.029525905115795986, 0.03506333440808313, 0.04766349900247795, 0.07384592281388384, 0.05920646871839251, 0.048219602555036545, 0.023812757306067005, 0.03138764235856278, 0.020232845563441515, 0.0235851138963231, 0.04404184887451785, 0.026454317882390957, 0.04893839505634137, 0.05795988453818219, 0.05441250006801315, 0.019310317833774855, 0.019846565755350248, 0.022541644084932547, 0.033965505460011106, 0.045285651061151705, 0.04882534772955945, 0.04597711217190538, 0.012639296557089048, 0.002040294369050701, 0.0783381231927446, 0.042677535475896936, 0.009956118883565068, 0.031736589169928005, 0.016617524470867853, 0.0608049886567252, 0.01961351272517017, 0.059518241988761086, 0.02337142964825034, 0.009468988415652087, 0.049475835503212044, 0.0525378944086177, 0.022198127250054052, 0.05035493868802275, 0.03839867329224944, 0.0535590251508568, 0.04215024591290525, 0.07845804747194052, 0.023014499872390713, 0.036323445183890204, 0.052353997847863605, 0.036905533234987936, 0.03352771466597915, 0.04463793171037521, 0.009921724791638553, 0.04217554848375065, 0.04324301638241325, 0.013397847817811583, 0.014459957834333181, 0.048659754650933404, 0.019477656443736384, 0.045199304087353606, 0.06291148705141884, 0.04040986465822373, 0.013434554865982915, 0.04255858828712787, 0.04242203989997506, 0.0341211376445634, 0.03590487389426146, 0.09098733908363751, 0.01948328998072871, 0.026270534976252487, 0.024365702278113792, 0.036041917611977885, 0.058725292395268164, 0.05493974552622863, 0.06184090806969574, 0.08875816155757223, 0.07151098881981202, 0.006013871561403253, 0.007965008761467678, 0.054082650624747784, 0.049548723734915257, 0.03142607118934393, 0.025286735534401875, 0.002816253657718854, 0.028072983525427322, 0.02058829952563558, 0.03926664171740413, 0.018488253998969282, 0.014437167539394327, 0.0359600795033787, 0.010652754672004707, 0.04402913312826838, 0.030061808680849414, 0.06758334993251733, 0.04631269184340324, 0.03098478593996593, 0.019710536447486708, 0.06732435311589922, 0.021072994052831615, 0.01836083360415484, 0.035942519017096074, 0.09466911759227514, 0.059369493541972976, 0.06688741049064056, 0.04382220708898135, 0.02826791985093483, 0.0452270188501903, 0.03901874912636621, 0.024639920331537724, 0.0033912285413992193, 0.0320782213737922, 0.026577607695279375, 0.042137747297861745, 0.02839945556063737, 0.03940908996654408, 0.04594939401639359, 0.12261186140988554, 0.028480140159704855, 0.020794742108721818, 0.012730846198142638, 0.033889102416911294, 0.05261840598125543, 0.05417427320831588, 0.019782428929050053, 0.03091902911130871, 0.03674215557319777, 0.024794902818809663, 0.008682849617408854, 0.020056507882795165, 0.03566636544253145, 0.062305969186127186, 0.14107589849403926, 0.12719936881746563, 0.13696084144924367, 0.16001146313335213, 0.16582904596413883, 0.09542069012033087, 0.13478847087493964, 0.15568820440343448, 0.11281586491635867, 0.093879798161132, 0.05952835216053894, 0.20874748512038163, 0.15413605554827622, 0.13036390686673777, 0.06907939072698355, 0.15077875927090645, 0.15803546059344495, 0.18114265852740832, 0.12469512676554066, 0.1697720672403063, 0.19099747043635162, 0.1335974247860057, 0.10954574003283467, 0.11953946841614586, 0.1326994922544275, 0.12269992168460574, 0.16594165563583374, 0.15507753645735128, 0.25354541199547903, 0.11716698429414205, 0.16820169293454715, 0.10014444735965558, 0.1606708498937743, 0.12024385561900479, 0.09963453507849149, 0.11684689218444483, 0.13989484044057982, 0.11880770911063467, 0.16673521591084345, 0.19916388365839208, 0.07985230801360947, 0.16489221980529173, 0.251125837543181, 0.11856912262737751, 0.06448530152972255, 0.12932371268314974, 0.14421033672988415, 0.15327488604400838, 0.1001534718754036, 0.10580442007631063, 0.16002424673310348, 0.12983663087444647, 0.11896933615207672, 0.2577786019870213, 0.10709101068122046, 0.0805883217336876, 0.12057876693350927, 0.07491583004593849, 0.08757265909974064, 0.20595833978482656, 0.1177637151309422, 0.1888186266379697, 0.19015063159167767, 0.1534768044948578, 0.12712395643549307, 0.13570908004684107, 0.1028027914996658, 0.08365350190017905, 0.12209180503019265, 0.11498333646782807, 0.16979202974055493, 0.12330647770847593, 0.16576979628631047, 0.09358399081975222, 0.07067745604685374, 0.11637768521904945, 0.11131556292197534, 0.09135004997785602, 0.16621349033500465, 0.07523931483072893, 0.2260530050843954, 0.07153917516448668, 0.12828605622053146, 0.11334173634116139, 0.2107527053781918, 0.10746911074966192, 0.11970617089952741, 0.082088189465659, 0.1249376894640071, 0.06511525344103575, 0.1551446435706956, 0.10253523157111236, 0.11371676264596836, 0.11824107808726174, 0.14830726331898145, 0.156067980453372, 0.12515491566487721, 0.1339323361005102, 0.16163230687379837, 0.2128961839314018, 0.07921869879854576, 0.1531181037425995, 0.10992333120001213, 0.12314622130777154, 0.1332414788859231, 0.17336049968642847, 0.09475556973900114, 0.1760728077164718, 0.1666460699800934, 0.10718325073165552, 0.09425753182066338, 0.17405857651361398, 0.19528077702437127, 0.07974113005080394, 0.11846606672874518, 0.0939099658280611, 0.12270391147051539, 0.16771607899240085, 0.10477665665426425, 0.15888387363936218, 0.19234174330319675, 0.09031480231455394, 0.1207399054297379, 0.06131703832319804, 0.20408755088491098, 0.11873917707375117, 0.198572431824037, 0.1498864721506834, 0.06760772291038718, 0.15069441736808845, 0.09207731738154377, 0.12113190868071147, 0.11307765051190342, 0.09004845696368388, 0.09596977422812156, 0.0835242002670254, 0.09703588166407176, 0.13421825718666824, 0.21472873059766634, 0.1595514299614089, 0.12411605140992574, 0.18424967037779943, 0.14214548681463512, 0.04108908838991608, 0.15282026758151396, 0.11835518053599767, 0.12957703694701195, 0.17808165135128157, 0.1669345830700227, 0.20731787968959126, 0.151432229205966, 0.11259202978440694, 0.0773983182651656, 0.11687830835580826, 0.08550227233873946, 0.07456671020814351, 0.08219178140695606, 0.18041270412504673, 0.1981922079409872, 0.1258270317422492, 0.09878280399633305, 0.20481994801333972, 0.10212799520897013, 0.07756839306758982, 0.10583074723503419, 0.14250542250062737, 0.1727077897105898, 0.13559326768985816, 0.09382892160543374, 0.13589609786868095, 0.16239827791494982, 0.13342697678932122, 0.11207948478737048, 0.14041394687124661, 0.14094015077820846, 0.1639674444283758], [0.021898911966543113, 0.013357195088506808, 0.02658420305566064, 0.004867267819853234, 0.023869277576782873, 0.04751802448715482, 0.032929307847682915, 0.03924326618601169, 0.08194296261561768, 0.046730442105659416, 0.033067952908043347, 0.01993328083439597, 0.029037434541221176, 0.022792605350592306, 0.0529228510734226, 0.019184247723647525, 0.017935602493318062, 0.06896811776927539, 0.03684760670044592, 0.012763364988911365, 0.038600011595657895, 0.005175438493357173, 0.020300363190472126, 0.034993092462952645, 0.05874921075467553, 0.037650320412857194, 0.032077179822538576, 0.07507495329316173, 0.0377453017447676, 0.01500763398196016, 0.03121374740398356, 0.02049869219107287, 0.025690256917316998, 0.04791739662843091, 0.03292294658188309, 0.08515744084226233, 0.06917992926069669, 0.010731149215384253, 0.024013087984972765, 0.06317039565848452, 0.018169030414095948, 0.0456604195226516, 0.028986429063869373, 0.11191944551787206, 0.05694833131773131, 0.013229975709691644, 0.02046044995742185, 0.022178510802664926, 0.05297238752245903, 0.08861965220421553, 0.017995267773845365, 0.04560396880177515, 0.04585573582776955, 0.02418593969196081, 0.044215635263494084, 0.02254663470999471, 0.025480704947507808, 0.02922976529225707, 0.06044199277779885, 0.027272744769496576, 0.05401699896901846, 0.018201240471431186, 0.015728246653452516, 0.04969225085473486, 0.01369105467373239, 0.03426076997337597, 0.0579387956698026, 0.02047424966336361, 0.049192933897886953, 0.028775350390268222, 0.027606539893895388, 0.04185239618111934, 0.012441380614680904, 0.0596548853708165, 0.07183735059308154, 0.01307885832751968, 0.009026070441385465, 0.007991859240324369, 0.030928515030869415, 0.02785081080427127, 0.033508868355836184, 0.03722020724256124, 0.014391179828505431, 0.03366876852565578, 0.03510869447407978, 0.017981118622369, 0.03422789155904736, 0.03652815580634134, 0.01992566597514919, 0.010309978288465312, 0.02508498671730714, 0.06339277872549635, 0.11236940244478838, 0.02410169956939561, 0.07102939180497612, 0.010889347110475813, 0.033580389339476824, 0.04078671961490597, 0.02699890499934554, 0.04183811980432697, 0.004265782997078661, 0.06440976701144661, 0.010206103058797973, 0.10144336016050406, 0.03508427060608353, 0.01857716583513788, 0.05389521889654653, 0.047642471202250035, 0.0355934466767524, 0.02465166068369789, 0.03190977844808783, 0.050789631969694576, 0.0645289516874722, 0.028379026567563415, 0.01784482129317309, 0.035688957265977345, 0.01076709884884102, 0.028022849965574484, 0.02337552121441279, 0.020164798679096357, 0.06443626380392484, 0.06346917498324599, 0.08811579924076796, 0.03167597224403705, 0.03544873890600034, 0.014603393351925271, 0.0649963944618191, 0.01714424745711897, 0.02908501002405371, 0.016120945402820195, 0.018993441980066042, 0.05283810544226851, 0.05929579785359757, 0.01672348619571754, 0.03932501269238336, 0.004731419171938407, 0.01914780700047101, 0.057214004918932915, 0.04080192558467388, 0.04768332579572286, 0.03799840887742383, 0.014675523320745145, 0.03339126805907913, 0.07007556834391185, 0.01833210782414036, 0.03500795916521123, 0.030945254489779472, 0.06180227907108409, 0.028962605699364628, 0.06012281669037683, 0.07080161438456603, 0.010801700742116995, 0.02187649656220206, 0.028535257559269667, 0.039345304282116036, 0.05096607143059373, 0.018841428083500693, 0.011672278982587159, 0.020783719307343875, 0.027217588354168192, 0.031806291679718664, 0.038090679461934736, 0.05632242008245417, 0.016646676031606536, 0.017600748854290162, 0.05617722715916378, 0.02286149192202304, 0.04092326121670859, 0.07567003528986659, 0.042693138388650756, 0.08214781912309782, 0.038154492287763526, 0.03695536823943257, 0.04729713758985911, 0.04566134911562715, 0.038063219149730036, 0.010521238470183951, 0.028605631818728786, 0.021953254139849117, 0.01831171615049243, 0.044083168264478445, 0.05580308294988104, 0.040780867250370126, 0.0377903327212802, 0.031031496290649687, 0.018231426798073307, 0.021126118255779147, 0.024569915873663764, 0.04180091233657939, 0.0548319229190903, 0.04316454380750656, 0.025612771610862443, 0.06551092078111001, 0.07767292138721262, 0.050800990645906756, 0.057018715755215714, 0.039221101839627535, 0.08740196683044944, 0.06816605545048203, 0.018449221272021532, 0.027890545814963322, 0.02916805931766118, 0.016483562998473644, 0.049338147177227905, 0.07764589533741985, 0.04030540079942771, 0.05805650792483773, 0.03411032518904124, 0.044794395100325346, 0.036981865031910796, 0.061028124897607734, 0.04514560143330267, 0.008240443937081312, 0.03684996800231082, 0.021124036849609444, 0.018099450040608644, 0.05720268016947167, 0.06649311379130397, 0.030693843694669858, 0.03094111881884081, 0.03764042058693511, 0.02500881437611367, 0.04062453956742372, 0.025212088200662817, 0.03150313241141183, 0.043526484564478905, 0.058866855156208785, 0.05231366911903024, 0.02472282204377864, 0.007044531903894884, 0.02409371660490121, 0.022491250985435078, 0.013689434671375369, 0.04009733821398445, 0.04669772314706019, 0.06425055555467095, 0.05938156467995473, 0.02726810358996902, 0.021090410350422775, 0.014096013702718275, 0.019537109682070355, 0.05951042526534625, 0.055603166177336655, 0.04706693779943245, 0.01327091087919793, 0.025707513759178773, 0.008731717709451914, 0.03239330589505179, 0.007549234732453312, 0.02313645975664258, 0.04732303387884583, 0.024072373285889626, 0.05342107558889048, 0.030747156191085066, 0.042107569452907355, 0.03382099446441446, 0.051314098827008686, 0.03755239084629076, 0.05246109102985688, 0.0525440724699625, 0.052446522883006504, 0.02664604304092271, 0.022199526728530015, 0.010049670202923673, 0.03232697570430381, 0.06892680177198988, 0.027756563986518552, 0.020362294777961712, 0.08401625350649868, 0.025437451732744063, 0.01133359331704144, 0.0435974254006786, 0.01865020504088274, 0.003085568023379892, 0.01737833525320249, 0.017813578148239424, 0.04742695490962692, 0.03980870298775179, 0.027220811395506774, 0.01550369057804346, 0.03984526923990675, 0.06565429523055043, 0.029482828320137093, 0.048028723868940554, 0.029759063318903958, 0.014965025375464132, 0.03530637547373772, 0.020369256547253047, 0.03635739568354828, 0.01402713730931282, 0.02925790413948042, 0.023310436135424033, 0.030149539866085564, 0.056545902376196215, 0.06796982990843908, 0.01462306747479098, 0.041105797314750295, 0.02673118222238762, 0.02230812456192715, 0.022606724074908664, 0.04898711387068033, 0.02838353204008724, 0.021108103151034032, 0.06967801467648574, 0.003716445286824767, 0.013376518917669142, 0.012163079476782253, 0.06097169114010675, 0.006213789606200797, 0.034050234127789736, 0.07432545029691287, 0.04049646268997874, 0.03703702992892691, 0.033331651972340684, 0.03726709061967475, 0.04397555939587099, 0.05589172676471727, 0.03994492907077074, 0.005350637931509742, 0.05500436920140471, 0.013941030367277563, 0.04977782090593662, 0.015102428716740437, 0.013493655266107192, 0.009677637085717703, 0.030420170165598392, 0.038028607078428776, 0.017337992953668748, 0.004426484686389033, 0.0680400582828692, 0.0034745613354191717, 0.042774518486112356, 0.011712293040805628, 0.015309902673055018, 0.011751996669253069, 0.013299448365744735, 0.038571295993668694, 0.03137054327609284, 0.08040772285312414, 0.04147289493786437, 0.029388830864003727, 0.043805057116385014, 0.03785938723012805, 0.04377912350797227, 0.04084717369239245, 0.04224423997636352, 0.013356636145285197, 0.06757729061480079, 0.042034891567059925, 0.037015160745275874, 0.003948724362999201, 0.04724517198545592, 0.12307489370661122, 0.1528913373393672, 0.13478700523929937, 0.11619661136397294, 0.11233557068875857, 0.11513254631842886, 0.07052189510847841, 0.1410257276147604, 0.18427252343722753, 0.2280541541320937, 0.10563467775604554, 0.07621411180921964, 0.07871728856116533, 0.12404180610818522, 0.20781307454620088, 0.08911200399909701, 0.10075813478657178, 0.13054324367216655, 0.15866778737732343, 0.16257825254329614, 0.19367042343531335, 0.19325761630066804, 0.10016494590256896, 0.10800009154315506, 0.23671269523245947, 0.1678305614207472, 0.11878928009952817, 0.16240570108805383, 0.22455394480909618, 0.11514055303164891, 0.24132885038852692, 0.11318580899387598, 0.12538141065410205, 0.20622744677322252, 0.10544475580432586, 0.1251875531992742, 0.1408786212227174, 0.06495828114982162, 0.09796118629830224, 0.12720000664038317, 0.12542168849280902, 0.10404409667743103, 0.13013901322015695, 0.1585243722157819, 0.1170610242656299, 0.07953377653445516, 0.16909916406231268, 0.11617991940251418, 0.16508940208171094, 0.20751291779535158, 0.13724820102964128, 0.12291231671614306, 0.09795668082577841, 0.09869889635592699, 0.09771563804575376, 0.13630400598049164, 0.09156568840678249, 0.18164062180689403, 0.12660498571183, 0.11752772065145628, 0.1840436671461378, 0.1249025956328426, 0.16580324806272984, 0.094772302412561, 0.14635671941297396, 0.09084134548902512, 0.21852524259260722, 0.13538483530282974, 0.08788967744580337, 0.10456344059535436, 0.09943837060460023, 0.11083310416766576, 0.10003316083124705, 0.09545895271003246, 0.15641783310898713, 0.1119773652670639, 0.1082564013610993, 0.07386573603642838, 0.115003855366792, 0.1394622065126896, 0.11086922937205859, 0.07774815056473017, 0.17126242869666644, 0.11836860195866653, 0.12423719705215522, 0.16530331703169004, 0.11550890255187239, 0.08773400115647487, 0.12582002926085675, 0.16159694162862642, 0.08324248609798295, 0.14907517497028622, 0.18529605280075753, 0.1445407425718648, 0.11912203367267336, 0.1614227888307401, 0.13828441899802002, 0.08070279737668377, 0.15086749808064528, 0.1052942228104387, 0.13261220550962857, 0.09622144286653825, 0.13898211584559508, 0.1486794262060097, 0.10985935891845397, 0.18268598642732414, 0.1848429406860045, 0.1394676619342395, 0.11365036120904343, 0.11277789409671511, 0.10566209735614912, 0.09793840109237603, 0.1277457523558821, 0.119176235049963, 0.2350422777235508, 0.10151106438466481, 0.10902336984872818, 0.17490514394428047, 0.11754294697727476, 0.0997445188196642, 0.1616556349077395, 0.1457388997077942, 0.16065064312091895, 0.058025838141994815, 0.0784659863316587, 0.16720816838954175, 0.15850375832191535, 0.2166684857968773, 0.08563633728772402, 0.10404192536537137, 0.10171984282455274, 0.13126346788236073, 0.14344298147729465, 0.12446770896869046, 0.16972728392907552, 0.09362206341964857, 0.17921435699931212, 0.16225714263107094, 0.12306291077818189, 0.07440714591315814, 0.10052199102938175, 0.08024378200726849, 0.1882773321121931, 0.10187109506555966, 0.10983833790357624, 0.09446939759488616, 0.08364512877804892, 0.10663083501692329, 0.2178592061890023, 0.1618383779589619, 0.13164523882525309, 0.07826355897954532, 0.12870274457548345, 0.1095905029880149, 0.12874139393014566, 0.14079064237219946, 0.07872078980186156, 0.11146080334271703, 0.10224275583667414, 0.1537522082882268, 0.10445540424968515, 0.1224636829325131, 0.17774957631315502, 0.1019158580207399, 0.12760650339935506, 0.1213263768170561, 0.10747709032148123, 0.1933045709239585, 0.11803459988108703, 0.1269263263259615, 0.14502259743000778, 0.17213345052940504, 0.14016332317675861, 0.10385846985237938, 0.09787980959351573, 0.15426530289862836], [0.03775540513119527, 0.03713666261839015, 0.015639925142750144, 0.028340589255094528, 0.01491293593842004, 0.04398829210549593, 0.024587567962173904, 0.036803613882511854, 0.05629161459260753, 0.01110075572172978, 0.01410960391097303, 0.011958462152896183, 0.008048709448693054, 0.01408127592211323, 0.019707084400579333, 0.022649066356409873, 0.025572928034567406, 0.028844316689563648, 0.019878857236887728, 0.0619741180645568, 0.05735953710973263, 0.012429954933135636, 0.020697882931147302, 0.0403530509211123, 0.04706207609602383, 0.060535535615469725, 0.08469337038695812, 0.03502868162468076, 0.04816986593816962, 0.04091324603983334, 0.0203392839591418, 0.049688335707677264, 0.06419981470597641, 0.03699089294033391, 0.05584048040743385, 0.020144557979490076, 0.010780461747864527, 0.09558059368282557, 0.045842653672610006, 0.02808972298433738, 0.05048388069761651, 0.03886719832995108, 0.02758539335003921, 0.014686111859711153, 0.035346181730606725, 0.03547272172623447, 0.03494150344548481, 0.050305982386427264, 0.09547506791672536, 0.024286149136189903, 0.03041712354336466, 0.029145511598991494, 0.051045629661530256, 0.10765832702496222, 0.012376136928131538, 0.009959357191941567, 0.005670770753308066, 0.004959401849191636, 0.051166439428925514, 0.0301384763526065, 0.032008077816239426, 0.011897865583055785, 0.023746193020737598, 0.031164696107485464, 0.06652250114296164, 0.01142018795612135, 0.027150330266782215, 0.0031300023131604704, 0.03783468855544925, 0.04986318061128259, 0.035853905736335685, 0.02300846260706229, 0.07185780842389379, 0.014284838124045303, 0.04782594367861748, 0.02267996344848403, 0.0209559772961906, 0.02356718191211777, 0.0669028607330152, 0.0192505779143955, 0.05441346698041473, 0.03154215835300939, 0.027521421068481038, 0.06384235567280225, 0.023333804881466285, 0.04310261391635452, 0.023448920043717538, 0.023765619478321502, 0.08746973890811205, 0.019294881162100604, 0.02880027298150318, 0.04783047629254205, 0.042036818606512885, 0.02627529320307076, 0.02737541899218091, 0.10018642832125936, 0.028333742836756364, 0.0601448690784829, 0.028541588290993656, 0.02101650770886668, 0.037585269260619364, 0.021797747484275272, 0.012213026439504964, 0.07129666674882174, 0.03007413087678807, 0.09196011402777263, 0.02582631675925638, 0.06515750581664698, 0.07901281091783728, 0.013966814697986203, 0.023403001882668053, 0.0296382535515087, 0.026437848141150813, 0.042756666229771714, 0.031529795444969616, 0.060454423539340496, 0.01584594024877463, 0.02531110342325909, 0.04239197062062366, 0.022340606033269848, 0.027020207606256008, 0.05004455980711749, 0.06677236487822873, 0.05614018593249576, 0.022441058053768108, 0.045581739994564226, 0.044662053630288155, 0.02260055619158915, 0.05362189481300967, 0.018524284208459512, 0.02345406842817153, 0.056304479616561105, 0.014355817976008569, 0.011682543521081763, 0.02802622737362981, 0.07570267282426357, 0.006675720555774335, 0.03852127439209393, 0.03665540147838848, 0.021707727939688733, 0.09547907805868558, 0.030178163865847246, 0.009664526940988643, 0.06873153974967343, 0.041881512118769545, 0.03754436716969524, 0.024505923236055032, 0.018486299818115573, 0.047824725708259005, 0.0762453040640269, 0.02239316874848945, 0.01655388806414391, 0.016679734257715087, 0.015415255412725466, 0.018489271801497256, 0.01900720945559442, 0.038635366662804566, 0.02784071081051869, 0.046241815468030315, 0.02485038323460945, 0.014410587626376321, 0.03815041429230145, 0.011175696521864405, 0.034773935829954486, 0.012123324958208417, 0.04715398366429976, 0.0156850782555661, 0.07497520186007023, 0.025912154831790497, 0.06914233163531337, 0.047345656236367564, 0.04551182374624269, 0.013472088878708226, 0.04101442239646401, 0.07654108426400594, 0.01253766643016466, 0.03943993956116693, 0.03920972959271499, 0.04514669726735779, 0.014336763016347374, 0.02142051763699523, 0.024966424597161155, 0.0065324699389748275, 0.03520518893908177, 0.029299070859061818, 0.058608842215367725, 0.02866394172555634, 0.016617967214967524, 0.02227434708869883, 0.025612333955775415, 0.03745395916381052, 0.02813029259310237, 0.005755443017863269, 0.03239384872306671, 0.018349156016483903, 0.057687269523739815, 0.041442774768386564, 0.02686051099694201, 0.028297451391283954, 0.041958471560584645, 0.06066880667848246, 0.051749759021082094, 0.020481940857799988, 0.041533739172986577, 0.02745020542559879, 0.010772862155655665, 0.050384122479174814, 0.006803742726333439, 0.024880601791664958, 0.03822802173505936, 0.035325954601700814, 0.07245628309569188, 0.030744577758014202, 0.0642521365412644, 0.015769128388326083, 0.008074994198977947, 0.05848097229110343, 0.025894104103956903, 0.05013696609863213, 0.008190913425226296, 0.015220663443739926, 0.021676571307969943, 0.08095703087747097, 0.038652821976159296, 0.03299132255571229, 0.03125804556267602, 0.025119434243866375, 0.008503860561177135, 0.021778000418895056, 0.11859239637851715, 0.04085800989664026, 0.05009044913042869, 0.04729401632877333, 0.043114098121545145, 0.04372709344274231, 0.031237418098109107, 0.021984364970454147, 0.017842795866142427, 0.033898459414818456, 0.030661297762500386, 0.012171556075502719, 0.014004042521784348, 0.015698357185881053, 0.06081967893987894, 0.038273324125579426, 0.06310732582850115, 0.018589793371834924, 0.0338235830755106, 0.014473124806370054, 0.014699524800692285, 0.02897426293098501, 0.02133258798026613, 0.04006272953535829, 0.04810792586899229, 0.02553742877872927, 0.059084800604198656, 0.030230329638080936, 0.036265847738832235, 0.03919542268184679, 0.04568168820281114, 0.031589007803371975, 0.04760192194953561, 0.08113604877144098, 0.014248680689239075, 0.05804124088691814, 0.07063694072089025, 0.032634531879531484, 0.039112020550029616, 0.027324323608939136, 0.034013114869594574, 0.058097844278173785, 0.05177049505125199, 0.06961223070642777, 0.0221247318134244, 0.05167765110465033, 0.0413941611269755, 0.026428587834483812, 0.0610760837527258, 0.02757426707207092, 0.060227399292801104, 0.05663033248856664, 0.04965002901319947, 0.039998719934374094, 0.02806152306896235, 0.04804895778319665, 0.035069196950644255, 0.06146669600691114, 0.01780171735611345, 0.028101841619770442, 0.04630365714962993, 0.11475807641233716, 0.03793417875255857, 0.013118171798331397, 0.004651090379671327, 0.032316692506096194, 0.023006893494831662, 0.020617043965363076, 0.0537450794529702, 0.02817829216032156, 0.08018249672438417, 0.10216447325157267, 0.020318003404619436, 0.05240077605204923, 0.0235623727951731, 0.03244486437844379, 0.045288741788161654, 0.030653321583356177, 0.056093926807599406, 0.034054722636938095, 0.05696784598486764, 0.008578272952165986, 0.05314902715118868, 0.030594122795654193, 0.03828204330056906, 0.03597621167344706, 0.04267556433166776, 0.030457876356584684, 0.027117380606276647, 0.04535237819488559, 0.12123543955385685, 0.07792794198862144, 0.003365104307054675, 0.010659819917886384, 0.010927771700413098, 0.022424983559176326, 0.04059347962694509, 0.012403017941064068, 0.044642114878765175, 0.009899484958233578, 0.018700855983687297, 0.020746693347713778, 0.012740896149937595, 0.0385059768200985, 0.01209941677682634, 0.036887497774192264, 0.011734509125484951, 0.04717129648530057, 0.02233130671083927, 0.025469655004729117, 0.028395056957378983, 0.03829052159562707, 0.026815788753862892, 0.08594975939818791, 0.03962474875152111, 0.04148585834939565, 0.011168393788726201, 0.041570773614304404, 0.031620939661349566, 0.010438378318212926, 0.03509305424189993, 0.03979885405195611, 0.029373719889138426, 0.11418086024267332, 0.08867580776235887, 0.09448319899716548, 0.07223696022161416, 0.0831465208902955, 0.08367703349462577, 0.07965201126145464, 0.15798938806567872, 0.12752385783408368, 0.11887655327362673, 0.1238511920507465, 0.09633932475532804, 0.11707606060164315, 0.06362196749874524, 0.10391536501369306, 0.10605604121727602, 0.08230325113981962, 0.10486596543341875, 0.10142522291945559, 0.13140739873051643, 0.19779932259448937, 0.10933206935546227, 0.09326190381710019, 0.22022099659911223, 0.11398993405912604, 0.12964107708207198, 0.17689828627875873, 0.2788281153355326, 0.14483138626175268, 0.12261790037155151, 0.12266649704958711, 0.11914650164544582, 0.21851727659148829, 0.13690792928848947, 0.16238092098917278, 0.1532236702208008, 0.06592743950230734, 0.12946870204593453, 0.15969564579427242, 0.08971349815172808, 0.1232654263398477, 0.13148857866014751, 0.0907759414985776, 0.1778653615287372, 0.12075832087014403, 0.08326698799750634, 0.16370326360421522, 0.15087774395942688, 0.14959995395370893, 0.12303803568439824, 0.10034242352204663, 0.06252892900790487, 0.13613475220543997, 0.2483273148536682, 0.09076136656637702, 0.12958963055695805, 0.18326276833457605, 0.122907729819417, 0.13103512727788516, 0.18547738449914114, 0.07759698653327567, 0.11897992129836764, 0.12177259501601968, 0.09788350082401719, 0.11091917633478131, 0.09765005763620138, 0.12374109295862061, 0.11811058223247528, 0.059944436619324346, 0.1133280706458858, 0.09148543128477675, 0.11440343329949038, 0.12517335824668407, 0.11094232794961759, 0.15402317446257385, 0.09915922129792826, 0.1641108595899173, 0.12044011508779866, 0.12872945171381744, 0.13110262794154032, 0.10740768975977387, 0.11061382200568914, 0.10361959159906421, 0.17514024275754178, 0.0913775170754109, 0.17315799769546303, 0.3635394669004849, 0.0976106890344194, 0.13204252107867173, 0.1574303973466158, 0.14285659151417868, 0.09512370891336884, 0.1474173239299229, 0.07095772493630648, 0.18115796627742903, 0.19526042097381183, 0.20744214659290655, 0.12238684562700135, 0.1762996284025056, 0.11828020241643701, 0.15553275203066214, 0.16116371058991977, 0.08314552344381809, 0.1864325718155929, 0.14714258510087216, 0.13873617404273578, 0.13268801144191197, 0.07308168882238013, 0.15792590432933398, 0.12946335518998758, 0.10675727323229824, 0.12167287750967912, 0.1357910877891949, 0.11527853991304125, 0.11872829337205205, 0.24233164372188704, 0.10957290178963117, 0.12953211792877742, 0.19039109083158628, 0.07956012404922928, 0.10558407261435475, 0.14567249827086926, 0.12145479635468551, 0.1259391392980303, 0.33046479310308186, 0.1337809685085501, 0.16100519123886312, 0.09563015388058764, 0.15280941102121556, 0.07004141767642327, 0.0825796795210668, 0.13712496549955436, 0.15999449975788593, 0.18497169949114323, 0.12239953423185007, 0.11340186811451401, 0.08357291908136436, 0.09459381377590553, 0.15423721154885633, 0.12355421084378447, 0.15917672935341085, 0.11146475920187575, 0.11536693945527077, 0.17833261431327888, 0.09610836500568049, 0.1448446855481182, 0.1813023178172963, 0.09299523276942116, 0.1261511543499572, 0.1978992029492344, 0.06872408264981848, 0.08780116933797087, 0.12458159428622041, 0.11428481180753026, 0.10710791298853499, 0.12296046556106635, 0.13665545997875078, 0.09678616042115859, 0.14466802217066288, 0.14284129733485834, 0.09394894087953226, 0.0891910736848201, 0.07954451774380036, 0.0745806133906756, 0.0747602962489639, 0.07401533943733998, 0.09917431870209319, 0.2365952001086303, 0.08093239327094384, 0.16985749479915413, 0.13304215243884496, 0.1150679090725524, 0.10935727014605488, 0.11872935188668114, 0.12327652717275278, 0.05718415616346257], [0.016248857735523155, 0.04899637248100979, 0.08815692524824824, 0.05375548818015626, 0.1059890358841845, 0.049257391331983466, 0.0388263742705541, 0.024383983707853725, 0.013024373661859759, 0.05722939409315586, 0.06928206913705383, 0.01690445657420371, 0.03414817726505654, 0.028289088447179114, 0.030066704311008965, 0.08609687936093126, 0.04488159024289676, 0.08771544322371483, 0.06624885475529091, 0.04531748792422669, 0.0350887523298817, 0.04867377996976886, 0.040229998595480404, 0.08536480114396129, 0.0162873408491058, 0.04223167350781815, 0.015245553804561496, 0.018324879729854207, 0.13984237611293793, 0.030764869347746884, 0.021852250809648206, 0.04924150343452181, 0.03467867969136153, 0.03584527816357357, 0.051763831837368865, 0.017446044566375867, 0.01603136520965823, 0.05096915537225349, 0.02902649316404547, 0.0582541176783187, 0.017463294622887458, 0.014334057357960513, 0.025411333223538737, 0.023533886198752692, 0.027693879225158265, 0.046188686176070144, 0.02905275925461735, 0.05608721948894007, 0.037409759392695766, 0.06735389653061118, 0.06361117200659853, 0.0765050065570644, 0.0696938041863697, 0.0045790587984291566, 0.0313485689195139, 0.02089200501463243, 0.025078403231288706, 0.010994248624358858, 0.0070831439391310725, 0.03606091998517513, 0.03858709228890283, 0.014599800509001528, 0.058841918994273455, 0.020581846657608236, 0.016293780146432773, 0.02866906805762223, 0.01740748681394117, 0.03227874882785337, 0.03675348371533411, 0.05154073970126254, 0.06719036280576672, 0.03500172682106495, 0.055532754598451514, 0.03070604714698025, 0.00561001557590706, 0.042603415703134875, 0.024949440865644386, 0.02399945960912321, 0.032873393169471195, 0.10195172538182565, 0.043821969601724825, 0.06081553987626519, 0.02257742154012833, 0.027573878610772744, 0.011277136658983571, 0.021096790275935615, 0.04585660095991833, 0.054557659064552615, 0.07361815217882395, 0.05274963126118694, 0.05723739402102573, 0.03499948426282831, 0.037084042227693965, 0.03618425390283976, 0.02911961531000478, 0.031980651430785656, 0.014665620102147971, 0.05378290778025985, 0.026373139649097408, 0.026953312535105006, 0.05110797345904367, 0.026031912869906852, 0.06417613383382559, 0.011189558144126619, 0.050713792110660245, 0.04190278419160417, 0.03347114520147443, 0.032623146061918566, 0.020724864876163856, 0.013512479523862047, 0.0453936941921711, 0.03466345336554306, 0.01706604629621974, 0.07704500508095537, 0.020764058755178536, 0.020104582088866403, 0.014131993022082108, 0.05300678585522941, 0.02160787981535707, 0.060628718829580715, 0.015233223126935107, 0.027643857623583505, 0.06954398365425211, 0.02589931694923767, 0.03482470382004976, 0.06725223841411726, 0.04052710872409599, 0.01165656665606158, 0.036842415907553265, 0.07069031428545713, 0.03450307482853532, 0.06626855941223246, 0.021247460673164045, 0.020642388944647143, 0.010425231702226614, 0.07404469286224671, 0.021964958868920803, 0.016309208336419294, 0.006981885734213782, 0.043805006226258617, 0.05173216800072363, 0.06571011152118444, 0.030060346437884227, 0.029021750204265118, 0.016241683924038495, 0.027177324086161594, 0.02789661700704268, 0.011959754762106707, 0.0353307314882321, 0.0074588080668555835, 0.013696616964547761, 0.05372619243072612, 0.08289659608687673, 0.013024107336864939, 0.03476564073935151, 0.03808685591710465, 0.09487478834177766, 0.013893533764140946, 0.033752313149826865, 0.06562429719737597, 0.1030486858050738, 0.030817309926663126, 0.015759367662082826, 0.03603964451966541, 0.03517760309789862, 0.06828440552843468, 0.010035909512745482, 0.07149667851626873, 0.01281030519333269, 0.011777919251471758, 0.04085271393081971, 0.04524563106575182, 0.04509938641318253, 0.02930209712524499, 0.034528906656695266, 0.022706251591444016, 0.02685993254583861, 0.02934628671833447, 0.044553606770932674, 0.032153338593031676, 0.039025439481650076, 0.026839900495750562, 0.030600667265909057, 0.016847495255725722, 0.007457702054775187, 0.015610715906534876, 0.030303309472011666, 0.014291932207665272, 0.023872052785009146, 0.049319456930139234, 0.016471042331042032, 0.014223439186545355, 0.010756634990684688, 0.026810570819569484, 0.015952994415004338, 0.06867042410054378, 0.05495905324018427, 0.09927527792751789, 0.0019802414753939956, 0.02878707547539047, 0.028992342496556894, 0.01089511635447187, 0.020451006446299807, 0.03572705700727446, 0.11684747572456088, 0.007875692348794212, 0.010314282744989862, 0.013420184342456716, 0.03757909459194966, 0.05267221720090934, 0.050415314733982086, 0.01931590217697833, 0.012900123721919954, 0.012497620141532804, 0.047241270409098694, 0.02585460658052138, 0.006582282466946968, 0.0512555548255997, 0.05680216130401407, 0.04954835393333009, 0.010090865760243364, 0.05355708793337856, 0.017142564690272723, 0.009174481317001795, 0.025077317575258867, 0.05721004905977419, 0.025058150657319596, 0.0235392534107502, 0.026574364297890236, 0.027948448600779687, 0.03439309448003769, 0.03005986467802099, 0.09642511193773576, 0.053775328544101546, 0.044885183085820506, 0.04703725189236658, 0.03127908693360431, 0.012632462013113712, 0.0323524343382035, 0.08124384762985365, 0.027711896026240926, 0.01991917409135827, 0.013850724141645645, 0.027457513247749636, 0.08193190249481372, 0.058283084338264804, 0.0694381118352924, 0.024394657063697065, 0.008570776836547469, 0.053495405707508326, 0.03523053900737848, 0.022570778682295765, 0.028155352587678602, 0.018218911219654337, 0.07811015578252928, 0.07919461759073393, 0.037339290138334036, 0.06160237586924008, 0.028245665598660707, 0.030080006990049566, 0.06105730190340962, 0.01739029273656862, 0.03614293112020407, 0.002801353664835915, 0.018637918468032564, 0.020808309416419694, 0.03368385575179543, 0.02675488853960165, 0.059572395868599415, 0.027722925612969056, 0.012939374428242445, 0.06298934894480876, 0.037795991703335724, 0.062030572178108354, 0.025189542178330675, 0.06999654615564005, 0.05276929859870246, 0.018496063937033926, 0.047824047173240354, 0.03784901582236801, 0.009602929531995739, 0.016309325383710008, 0.06949676440230437, 0.040534677782229016, 0.030995540720011507, 0.05666097852268389, 0.0032087227653911604, 0.009893385776584702, 0.053120725455560854, 0.059637236674981456, 0.10096585471183062, 0.013696706022268959, 0.08149354851671628, 0.04021006662930761, 0.033712544212383885, 0.06818011469606843, 0.012314151057840457, 0.00631656136829406, 0.07891927486551659, 0.01119145973851638, 0.052782981257353506, 0.04351663223600813, 0.010114321867669267, 0.03493363243926849, 0.018837723282298872, 0.042175137970064364, 0.025829797643902044, 0.05883420405111142, 0.04241025374670114, 0.03214364232761519, 0.028242198284715414, 0.05128596676513553, 0.01615062791721097, 0.030178808474114964, 0.0479017869303269, 0.04657884381179299, 0.04116310977510043, 0.04225722374394536, 0.03220281058124133, 0.05298539164609142, 0.0662729631045035, 0.032632923751537285, 0.016161330110792602, 0.03167533442111952, 0.024007043934294155, 0.02661712557476546, 0.02219205945064979, 0.012881447893700429, 0.04748737506036248, 0.07293095226798739, 0.04653866436066372, 0.023138183235589947, 0.05401121785065957, 0.02612557275486844, 0.023613179801031947, 0.06093319106314864, 0.08524782849209649, 0.02632468207074063, 0.03108255605080298, 0.04461507186559694, 0.04480548236253006, 0.0371558142692915, 0.032432308087923696, 0.08269475227487938, 0.0414116334037057, 0.04643744729193194, 0.018412646538178836, 0.024897290360448614, 0.040299144706555774, 0.027446168142237833, 0.04768661329788821, 0.03402368305251002, 0.11404169271034853, 0.16148503763335093, 0.20070660087679112, 0.06196706808571305, 0.15948828549257346, 0.1614450854914529, 0.09365340495215994, 0.09677849976079804, 0.18537591637245246, 0.11819542625120708, 0.16025463651333535, 0.12824619907353604, 0.08881627808191947, 0.17184788228145667, 0.11924171367926256, 0.22811250814369746, 0.14761115424335003, 0.14883392862975597, 0.12001379153558187, 0.20231844724289008, 0.11859740396695477, 0.24114173757178442, 0.10727973162595715, 0.20596444659999438, 0.15926483034023217, 0.08249991094427449, 0.08224337720977408, 0.12968694604933262, 0.2473456103886877, 0.08164077025971242, 0.1492462336484875, 0.10869789695633308, 0.0850580083206296, 0.14531102909573487, 0.16949834621378354, 0.09594394239996161, 0.068437964788505, 0.17478975227900914, 0.21743786308382237, 0.14899038523435593, 0.11865193104105336, 0.09375131077000073, 0.12986934983304568, 0.13251726488981927, 0.2416480061198984, 0.13876490321542534, 0.16118220745452813, 0.20117523787277086, 0.10309507045894861, 0.24312875952039445, 0.12346684267478329, 0.13377799652516842, 0.18658682996673243, 0.11396902160985128, 0.1115408433335168, 0.09729408459471804, 0.16531874691801413, 0.20902024262717792, 0.10968848344470773, 0.1313482711889914, 0.08808128894971949, 0.06730640586465597, 0.0987707803558026, 0.1150726316762822, 0.07505169311272246, 0.09291965075369392, 0.09407546730445963, 0.07888390283499445, 0.15830622320728643, 0.13953316770493984, 0.14659654082996504, 0.0710049509736044, 0.10210170197699751, 0.1430362540164164, 0.12931076623499393, 0.16377890668809414, 0.09287230936544282, 0.07748388153101717, 0.23816465160676412, 0.15703501499124936, 0.10726160795560905, 0.10988738920007433, 0.08046054680432592, 0.10791533573397569, 0.09880526350545031, 0.16362882831266948, 0.13263767771422863, 0.13345839296068462, 0.10070468658315283, 0.11280413304588624, 0.18746226227709226, 0.1370892881282738, 0.15650552697479725, 0.08915132510342769, 0.17084738239645958, 0.13461475233946527, 0.09366094347621713, 0.18953473892595085, 0.09094955146844898, 0.15662855894437858, 0.14645225714359963, 0.171737063942211, 0.13351859258753912, 0.11282455694994756, 0.09088357750858579, 0.13433925355119364, 0.14951084873506001, 0.06380493446652379, 0.09172361064702272, 0.12840762255447252, 0.1538336324904646, 0.13364748709968158, 0.09118443315050431, 0.1628529778016465, 0.15684419737330504, 0.07487764888043914, 0.12932406552135944, 0.16084142002676213, 0.17909515196723597, 0.120384420933468, 0.07814881870789187, 0.0833501492493919, 0.25053518638014793, 0.07873716963721172, 0.18316469288298062, 0.19284992532006331, 0.12075232262057917, 0.1084483317764742, 0.13695685166333402, 0.1467296965420246, 0.0756177134545786, 0.12755963020026684, 0.18546979847763265, 0.08758084223206554, 0.07775043722774301, 0.15637993014284543, 0.06619080608444554, 0.09303825867495366, 0.11316141565995556, 0.13036116558526242, 0.1825161762535572, 0.12809841414647444, 0.07379249496651547, 0.15402268591736043, 0.16904397202389582, 0.12110316593732152, 0.08098282877887998, 0.09811549873224326, 0.09145871057574238, 0.11628974708063261, 0.11374547824795757, 0.13006653210946492, 0.1704908800976617, 0.18099229516727583, 0.16125368433339254, 0.13761133940092155, 0.18579332397452422, 0.10084388125687838, 0.09176466880100113, 0.1480617964906352, 0.2706735629056181, 0.11537699534424714, 0.06157161109149456, 0.16325946098991803, 0.06940071777041469, 0.12839268121336186, 0.17671453899570874, 0.1403348704001733, 0.09821715006338698, 0.17987275309860706, 0.12767403120441095, 0.12154304661921092, 0.12280905725700514, 0.1458317232983453, 0.11037680972367525, 0.13719963149300643], [0.031251575731273205, 0.05586248190541353, 0.014207552985421248, 0.02229344954581133, 0.018193410177315985, 0.08628640097698995, 0.008746985595540276, 0.041712224416966946, 0.013909366530632334, 0.07354195269622973, 0.04156254976987839, 0.032704916317015886, 0.029981490490692, 0.04211050072418792, 0.016591344893510853, 0.018898455559142997, 0.0655271445534059, 0.005569286511412689, 0.027603181145553077, 0.029254467359610965, 0.03455528809822031, 0.028116499672510793, 0.08087454816060406, 0.01078558892809919, 0.019499688475791897, 0.06956351867743901, 0.05304071260616183, 0.015201793384871312, 0.03549212782776781, 0.007227743992448917, 0.04654378730005451, 0.09164586410458599, 0.07146861430789743, 0.033809710427054336, 0.026971249608322978, 0.06401918189866201, 0.024456658201026063, 0.02451406735261636, 0.024866430587800484, 0.048474043009004424, 0.07618210531238999, 0.04227231775543519, 0.015368736748184477, 0.030841859323637824, 0.06522148488355534, 0.03768480016982981, 0.0745373907099877, 0.033276731347931285, 0.02395402151159942, 0.029299006398235048, 0.0661912267761571, 0.020579351345077157, 0.00861147282245968, 0.08421495570135967, 0.017461141970540797, 0.020646760406504785, 0.05202805676630565, 0.07894076406955719, 0.04857450011851532, 0.051779434750122685, 0.005819665933293956, 0.02103640914096364, 0.017190443817526102, 0.04074624500104359, 0.03738919299628053, 0.024161273247695396, 0.02428412201282169, 0.014476839785597153, 0.02658025567818965, 0.004326656494023544, 0.015299034238393818, 0.04376920332599964, 0.041321517167879004, 0.017457618677456464, 0.013834587730733412, 0.03914143843576312, 0.04541641154459544, 0.03749548550695181, 0.020965749896796684, 0.01414895979022341, 0.023265308467671275, 0.08854716430817332, 0.11596027761697769, 0.033770290935145955, 0.01941733298424099, 0.08082295235778604, 0.05041608826390334, 0.05501963623932429, 0.034925032007907114, 0.007181356794067791, 0.03517335546868188, 0.019615566989939128, 0.04723709402605891, 0.03781710432044097, 0.023127324978954027, 0.04421352841226118, 0.02236464822531811, 0.052105036564171314, 0.03688867163977452, 0.0732845775783062, 0.06180075236729213, 0.03197646826239569, 0.05610794194840959, 0.01665272856397288, 0.03412341073687587, 0.029707647327865874, 0.03509604997400727, 0.026953558504049267, 0.01695669528895191, 0.0654193524803434, 0.07307185684995991, 0.009917474617915494, 0.020117759238928556, 0.0017257862844936816, 0.021979080878996422, 0.02956657311213868, 0.05336638227371233, 0.03985462284513882, 0.05695323712591614, 0.010527112038939126, 0.03148972116676824, 0.019903004601863877, 0.04453514383307525, 0.0580619904877884, 0.03220082586631179, 0.041619682418448586, 0.07389607333711215, 0.008125768974423409, 0.01663312059827149, 0.012202799220436385, 0.04724640352651477, 0.023607868568173478, 0.025115916039794683, 0.031078450913940157, 0.027279372360291224, 0.06543096221451249, 0.02937818125688604, 0.052574596367776394, 0.030797350819089582, 0.027328060640554343, 0.004063087623632912, 0.0045347233203106695, 0.053011067411197085, 0.0666660995089582, 0.04729770077392459, 0.01612609887628683, 0.02935288886406592, 0.03855787457099982, 0.02246640303305217, 0.06875635377530541, 0.020376462589151094, 0.019235511044306413, 0.020166171016171575, 0.010084369635608579, 0.03588248223864606, 0.05081123313201325, 0.02814210588777704, 0.03914723312482238, 0.052445444012326856, 0.031217123115701333, 0.030545566829719713, 0.0468838181612747, 0.030701592564582825, 0.040126983408949206, 0.009431483240665069, 0.021672372872542058, 0.09421171035085406, 0.01277803406784577, 0.0795364228210279, 0.024257964487852793, 0.020144954922475984, 0.02887504075520805, 0.007601411530881056, 0.030313463748565743, 0.07214157176869256, 0.09066411214215414, 0.0515763526117163, 0.014206009318253823, 0.014598947251215577, 0.051656932037855895, 0.05429777675973518, 0.03963872318023017, 0.0037198103964328766, 0.04069289857787745, 0.024851338272648196, 0.06664899364113808, 0.05252690892666578, 0.013880089440915202, 0.04003027181274124, 0.07287388747291905, 0.027979651033612232, 0.023864627915567586, 0.04462999963600721, 0.055409641204667945, 0.04267752869054675, 0.027434856963476965, 0.009067731643361705, 0.026418094290420413, 0.08038997916238648, 0.03325216159490602, 0.015343127140243138, 0.0295275539558913, 0.013553766683409256, 0.032010500186256, 0.05329718187983547, 0.018187079445591996, 0.026017683990565792, 0.03865004337525793, 0.044591618302677355, 0.06558384972491435, 0.03538475983909198, 0.006262350237063531, 0.04671356693974563, 0.04450538667983242, 0.0313899391996009, 0.011212856492160686, 0.004153871792368591, 0.04200526672814574, 0.029614535359931842, 0.08213972420032535, 0.03705412901139685, 0.027132729068398476, 0.03073953963550074, 0.030595357729388133, 0.0163326228835753, 0.01857374601864389, 0.0047363101371697015, 0.01420437150435256, 0.04963428700076682, 0.03175725056124585, 0.008690045481281621, 0.030251876517598118, 0.02759361549812768, 0.023498330963775516, 0.0377530336513051, 0.033520305063575506, 0.021224098712471978, 0.01667986317936863, 0.030507090501487255, 0.01863978783200894, 0.028385776294661418, 0.05019214456634862, 0.06650139191853148, 0.026074492638664584, 0.06201168176318918, 0.02574729117830949, 0.01728977625524359, 0.02259691245853901, 0.019992667915565625, 0.01016372854688338, 0.040847597776779106, 0.03372572136244603, 0.049514912334936004, 0.045746230453784974, 0.02073206752538681, 0.06700448492275816, 0.04700931321297373, 0.02126969626572515, 0.0728932935744524, 0.057900736640606604, 0.026545679229976873, 0.04020811923380409, 0.01305455744399556, 0.0024090300181082314, 0.059318345572267256, 0.05033914239278861, 0.06373215480042355, 0.07245951970773083, 0.0352438281157187, 0.0658409127167293, 0.012117478530853987, 0.05508209878046598, 0.024730550557641045, 0.016126638311626654, 0.022713615392733897, 0.015867549892781035, 0.06061313966555255, 0.0620293915271759, 0.05308303962062512, 0.02862237806298903, 0.01537589359629367, 0.07587075273373298, 0.025403458824647323, 0.042547501024923155, 0.03519252747563379, 0.03134406005431499, 0.04812291131487914, 0.013295627365420972, 0.0497047325064029, 0.04504496790468693, 0.044452118288193426, 0.01915930477636201, 0.01725067906746907, 0.03282969890694533, 0.015354082088119217, 0.05102152131231768, 0.013717591330142958, 0.017474812754829015, 0.06140872197491782, 0.04825675913265773, 0.035202410338180404, 0.038601636687027555, 0.02975739073008299, 0.022371491250981177, 0.04531685010130916, 0.0781849981950862, 0.046996560147298236, 0.010491404133582754, 0.05058658036536404, 0.028283388753022467, 0.02610100639451827, 0.05931172307048525, 0.027496942917683294, 0.036433503563914976, 0.07520096403147493, 0.022969764058611224, 0.006380863587505051, 0.031056232284754515, 0.036525933604155264, 0.07981343474239111, 0.0635063179901668, 0.025013481000704423, 0.044802870002708266, 0.05756792878465993, 0.09683653486094304, 0.07244654611817428, 0.021319697511249354, 0.031874742292399914, 0.004702044542812343, 0.00895923559021737, 0.023450416213433658, 0.07693090941756964, 0.05435121139245374, 0.0334621715758528, 0.029908609044338976, 0.041064888438475985, 0.03795666540307658, 0.012014684716372617, 0.012637880963406392, 0.028301617596298456, 0.023358586676684872, 0.02916189143434167, 0.1156842495713915, 0.03731922246515751, 0.03162391843008144, 0.08755789417773485, 0.03204402320885232, 0.010941800411923655, 0.013888150436936744, 0.05332751578784414, 0.024143147881009748, 0.0209484743952219, 0.10387485647307974, 0.15880057668047293, 0.11665175908378192, 0.14707029397998536, 0.07085481153002807, 0.2038823618952717, 0.05636698965515409, 0.18742285296320915, 0.0962659954758627, 0.17620958680553095, 0.12622196626450333, 0.09332894986229283, 0.14343977879200662, 0.1953283558998789, 0.0645589768620474, 0.07016850728541613, 0.08894325912530933, 0.12382576055824757, 0.16343069608722413, 0.1241121566189187, 0.0841347189354045, 0.09453386520700795, 0.21745378151535988, 0.14488345703908376, 0.1687324158847332, 0.13978674981210912, 0.16101600708706038, 0.14502166105168207, 0.11290308380765574, 0.1115942101127335, 0.09609267727604934, 0.20161099306174687, 0.1462146613214697, 0.1546208688191005, 0.11149152062301125, 0.14491582315947327, 0.12132949807814189, 0.08467580311532531, 0.088091677320855, 0.13578772225550242, 0.12856140573109898, 0.07077153492718935, 0.13653313368558884, 0.2846656063837664, 0.17396451798932894, 0.0748305789061955, 0.1701572308582919, 0.08779980548258338, 0.12529470744941915, 0.14982655750853674, 0.1771676918225629, 0.11903452979666845, 0.16020749190023967, 0.11480024057839598, 0.0727238023121442, 0.06937354922826801, 0.14778711194438593, 0.1946003692490714, 0.12734058552554675, 0.18709353277725832, 0.0992871183635933, 0.08248815193240132, 0.10687651219112532, 0.10001816520733492, 0.21088922662394388, 0.1689210214785167, 0.23480153349893435, 0.11206332886857645, 0.1646909256066595, 0.1365323465849672, 0.12174226450068609, 0.0683585965473737, 0.07882516205843006, 0.11274504621646234, 0.10582554965679135, 0.19577975810638495, 0.11496697020317827, 0.08984243337597166, 0.08095091049160276, 0.16382086729364737, 0.08109247325254337, 0.13186887039669923, 0.14031802916101047, 0.20446819545967237, 0.13179150383387292, 0.13124011270701885, 0.09362000745854207, 0.09923299162515573, 0.12097404072327272, 0.10335229629916803, 0.1488174945116043, 0.11618476414254733, 0.11932919041386672, 0.1135761226926531, 0.16156570187636785, 0.1494687795639038, 0.18444157365177358, 0.11664512301129953, 0.1876218808548791, 0.13081415556371212, 0.12787202772285255, 0.18616541900805064, 0.1442801444126027, 0.1385920803461756, 0.10112017393112183, 0.10438014793076686, 0.12592171451875142, 0.16015908521200928, 0.08351874484547547, 0.13620892965367862, 0.22515120490321092, 0.1126628824110542, 0.15910902512925013, 0.10746649838984013, 0.07879004108586482, 0.14746343716979027, 0.12966167740523815, 0.07211592993033783, 0.16256032564810344, 0.07668836707515375, 0.08961183324988399, 0.07919364728565727, 0.10035242512822151, 0.09182022724832807, 0.13911350736660616, 0.17879403169666017, 0.12048744969069958, 0.18560498979474815, 0.11671213512974125, 0.12056853462542806, 0.15904636920562812, 0.12411664852074214, 0.08667640933500868, 0.05968622011797769, 0.12474535192762103, 0.15253564928259167, 0.09477203099855355, 0.15376592826630386, 0.11712233668991498, 0.15036474434392794, 0.08294426317193679, 0.12239379382559232, 0.1141172679407256, 0.1455560480909688, 0.15520138266895497, 0.12263042612799577, 0.1276514224175896, 0.11543924414685794, 0.1869593592626708, 0.15967957808503083, 0.0819353765941092, 0.06568731274455786, 0.09515441940831286, 0.08540294159735952, 0.0843613360609327, 0.1484066415578127, 0.14500616331185612, 0.10559884432171072, 0.135042419391019, 0.13284948920564993, 0.16250493004918098, 0.15828931411462172, 0.09738260627325092, 0.15303163123982294, 0.11273320578038692, 0.15477180214864866, 0.21627703894461903, 0.12799398760710443, 0.14543598810476915, 0.1824564923133169, 0.15838489255734853, 0.09559529753667967, 0.04980539996176958, 0.17237462901643344, 0.17122311437768595, 0.17957087286881038], [0.059243855997920036, 0.019709744257852435, 0.044222050812095404, 0.011540780592310642, 0.015836880109938126, 0.03471316623368433, 0.057900030964187214, 0.03447920735925436, 0.059849244941558154, 0.014640678851200002, 0.03530051971652678, 0.05708452686667442, 0.039235076268336604, 0.04124319726335151, 0.01243601764352726, 0.03747772146016359, 0.017668329245809997, 0.04313807415642908, 0.01460579875856638, 0.06857357679733209, 0.029697523585387638, 0.060330034499721866, 0.04406377912632056, 0.01886772470814841, 0.027168565895408392, 0.036133641975798776, 0.06875208579003811, 0.029064796465848173, 0.021540959299142872, 0.04669596913403698, 0.038960598675268035, 0.005148387422585594, 0.021735966870827333, 0.066245401012046, 0.07185978974614825, 0.026352178006033813, 0.07891386015606777, 0.04847469440262232, 0.04985278545479689, 0.00664840782493619, 0.010844019274892551, 0.043760107564074655, 0.03009333341781582, 0.016869705403223634, 0.03251454313950879, 0.03413270327395626, 0.07174167037010193, 0.02289054000617138, 0.018380119265722375, 0.027675757251147712, 0.051319988510970554, 0.028899162675121, 0.023847876582294703, 0.05990014185330697, 0.06582195444830827, 0.04925934551283717, 0.06779879158628838, 0.012412387661502829, 0.007377673938338245, 0.022572600548820834, 0.03088502772152424, 0.0298625602652984, 0.04569094002779041, 0.028447112467672144, 0.03926221088373235, 0.05701568948903254, 0.024212149803393652, 0.08036119570689541, 0.037106905465147326, 0.043523176706262996, 0.031018851790577173, 0.057225098966487815, 0.032760525654469214, 0.03312532982922026, 0.051018549328936, 0.05573599958526237, 0.1047022281480687, 0.034827458672225475, 0.044468074039156945, 0.06297003783817802, 0.0425727289569165, 0.04757662955671549, 0.009744275161730391, 0.028949353910450424, 0.023901947341593247, 0.03850556969908731, 0.02021416379804058, 0.002501717477571219, 0.04215568776375481, 0.012645902943664362, 0.01804099594508963, 0.023615230673125813, 0.030141672252544334, 0.010907737953987504, 0.04992676612788013, 0.048799892488334856, 0.05032119174887027, 0.06976465681301695, 0.06692043478999819, 0.06808023434132338, 0.034008589041020186, 0.04759532319647925, 0.041611750344080586, 0.04238038802785533, 0.035172609080161364, 0.08465297719729797, 0.05894292571714946, 0.0355593061872891, 0.03992235081802521, 0.01272354431317321, 0.05188574083149433, 0.020188354022268738, 0.008537320819284235, 0.02436242495397372, 0.02888182271271944, 0.05812092125415802, 0.020505126399387206, 0.09013712791992085, 0.01899963021943612, 0.011594781801769776, 0.10048718896827527, 0.06802527300481286, 0.012035203615336545, 0.07415797428361007, 0.0949145844206214, 0.013244028169927853, 0.019834954324843626, 0.03998354110600693, 0.01814770745113492, 0.04130771915827479, 0.031454250748668394, 0.029969605949840376, 0.029063741343894174, 0.004934356273484549, 0.04301282337733677, 0.08473671520394938, 0.03372406234432544, 0.04553253942036203, 0.03037475242412516, 0.016789940219106417, 0.07475757532353912, 0.03682292838181768, 0.04161989276430436, 0.024467764122943794, 0.01695693447254598, 0.028941347197230374, 0.01014469055059765, 0.03728219141651477, 0.004542522656265646, 0.07161200232803822, 0.01615105539427272, 0.05483972607180476, 0.02418385828579111, 0.0196200232686741, 0.01733764520447169, 0.031689783824341636, 0.04171869085569467, 0.04042090103030205, 0.07001517194190196, 0.08924255413668496, 0.12451197659330708, 0.04429355822503567, 0.023669639003596137, 0.020601783712793673, 0.008510562790823835, 0.07205714165632214, 0.06594941046621118, 0.080766844297094, 0.015299792501277156, 0.068569098466209, 0.1011704398053033, 0.017144340755684034, 0.06548523144530398, 0.04342212248593569, 0.07427288418901817, 0.05307635944336653, 0.07886554167738982, 0.06342868001333304, 0.12480754644743033, 0.10191750686083521, 0.06818167532661132, 0.03911787969991565, 0.0877668693927782, 0.02532807528041303, 0.06648533777999026, 0.019397227991638438, 0.014882334009078997, 0.05110676905938557, 0.035782550993774614, 0.03426698874682188, 0.008794389748280602, 0.007601302965278072, 0.017743334506771395, 0.010792601587516921, 0.045908132301909585, 0.0482312224672309, 0.03444744852770652, 0.005866355927927154, 0.04417751177347132, 0.010548888772193874, 0.038201389235577414, 0.03387894814035722, 0.029721431766769717, 0.05002904849659119, 0.06655629218689033, 0.02644268609583378, 0.020520585123449564, 0.026116152992472053, 0.01629366649181715, 0.06138208269008568, 0.019972445875672356, 0.02643838418381555, 0.07582574550594602, 0.015875361527183225, 0.02286519163421222, 0.03375599080962794, 0.042923090513795614, 0.07069277058222465, 0.03774973936378956, 0.04162281385755964, 0.04989517014473677, 0.07042918008353029, 0.04356954778943743, 0.06074284841971738, 0.02864651694627745, 0.014008279972975808, 0.04668284287410123, 0.029072083931948458, 0.04967444609584553, 0.051103098184934685, 0.06019174906292132, 0.04159654098163758, 0.03204492905310222, 0.03463031371523227, 0.010922410425597003, 0.038402004899191, 0.051755540139440975, 0.047814323766423125, 0.06760684081486293, 0.0720462647399732, 0.017831749316038828, 0.07089271449616977, 0.029291084501892328, 0.044595757366291115, 0.01150848571809807, 0.049007982215178866, 0.0352731985040009, 0.05695999533470188, 0.01957363013311156, 0.015291378667045916, 0.07022912760398217, 0.032346364842461686, 0.07565056812018156, 0.006415998978939439, 0.03613927720912865, 0.1150796070162739, 0.04501311747091157, 0.00677037110186315, 0.05385739056925688, 0.03585672504933817, 0.03794955435608115, 0.02545784510272954, 0.032807039229997566, 0.02687898920183735, 0.05174687863992793, 0.0032709743245504797, 0.011397422258076923, 0.024080000019499233, 0.00798204423127962, 0.04295694941122617, 0.05899051816335746, 0.04623126085581524, 0.0031988568662200123, 0.033683170431426594, 0.061442180536687374, 0.03173798695206642, 0.006230383180081844, 0.06749284693173, 0.006467715221723276, 0.05119454095672284, 0.08274807834199496, 0.051791482139378786, 0.04123004386201501, 0.0997885964544756, 0.0535151476838759, 0.036872271448373795, 0.017863840629745806, 0.014110194236439253, 0.010754095573377396, 0.030593915842473507, 0.1107213290940438, 0.12565681444747107, 0.04612415410312159, 0.04919403312461717, 0.042600830484713824, 0.029765394050627947, 0.005000002416116851, 0.02229683373921684, 0.03873154560902289, 0.0758189262290086, 0.05082303624866264, 0.03340355972094195, 0.011286173897263194, 0.039297990035265684, 0.035072559091661654, 0.013933290827221103, 0.012289500728781735, 0.038962566426822116, 0.04316897464117833, 0.020240022767601267, 0.06947296139385019, 0.09645682666450739, 0.01005422486923635, 0.028397793149841682, 0.10448749895606722, 0.013907753313625497, 0.02239529086676027, 0.06017162371426821, 0.021027069106431942, 0.030752075569970266, 0.04152220407766955, 0.02859424939379096, 0.026263829353930693, 0.0407912216947547, 0.00841125495000077, 0.008507494116201997, 0.04731373794909034, 0.06674305216542312, 0.08392077005867447, 0.0560747039105211, 0.03581320381324206, 0.04091987532696553, 0.010433916102296539, 0.003967881526997579, 0.017164011485874653, 0.06273392122238874, 0.03280704940802284, 0.056856688378112655, 0.02789093766893659, 0.05188725057191082, 0.005299692250056458, 0.04385037986295564, 0.09759810220982347, 0.034769410001380105, 0.005427517645460154, 0.03637650322967342, 0.07134263071098498, 0.019633439602330327, 0.015015270893595048, 0.031063078703092675, 0.03927135414310864, 0.03937133288543139, 0.1542880745338542, 0.1499381765191044, 0.09388344189418213, 0.13058916692222866, 0.10157503666622297, 0.08404923030840498, 0.1873142873602254, 0.1163175670163972, 0.1616611581827913, 0.1404437209878649, 0.11948289216629096, 0.15984562917479447, 0.14779426370348248, 0.1329656136887414, 0.12948367052844592, 0.07807374559342861, 0.10299387374626738, 0.20923464612237044, 0.09616927030895438, 0.19809918078993047, 0.13079768073345932, 0.09697477958564248, 0.12878047754721983, 0.12243316242737429, 0.1793851035514048, 0.09990571838404451, 0.12250290225659098, 0.16215357104582445, 0.16382805976484502, 0.07659980468451977, 0.09949314195130553, 0.05982752503561122, 0.11042339793805565, 0.18143417074212007, 0.16004961037210055, 0.15972024947404861, 0.08640704450330564, 0.199599489569664, 0.12619164931987012, 0.09511059283145837, 0.10105325002223253, 0.131021149456501, 0.17722942493855953, 0.2165095457541091, 0.1802231485822371, 0.13937445836407797, 0.1300622166267463, 0.23627316738877976, 0.12753034462886198, 0.07947040814906359, 0.15341868118516036, 0.11240345133202416, 0.09680852493537323, 0.12940779674266065, 0.14174010285309382, 0.12089755625597068, 0.14351998163121088, 0.11361436492630414, 0.11189028208277055, 0.1330763641744852, 0.10412881177450929, 0.10896460193076304, 0.16995899006724358, 0.12361145205795765, 0.07337778793381793, 0.12613334959106787, 0.11815296352974006, 0.17742932135505335, 0.13070649919765337, 0.17775740660727024, 0.07865627469228846, 0.1278274751135281, 0.13701638632587024, 0.07510163329009499, 0.14988074531512602, 0.13471497196171964, 0.18284769489296845, 0.12284477534038679, 0.10139831900596619, 0.15112436429730483, 0.11855458840727806, 0.11952141938464982, 0.1831656564027071, 0.12786882503756455, 0.10794468237353222, 0.08526984695345163, 0.07949440793267318, 0.1316387520304748, 0.11660788500947611, 0.09520728407161576, 0.08208088164350816, 0.13669541212064878, 0.058912445924111774, 0.11593620319451604, 0.11641381042344229, 0.13577065031443322, 0.18255360424518585, 0.09819327241608075, 0.10792381742170878, 0.09490093908139638, 0.07628060824104718, 0.13004946016839572, 0.11033420450985432, 0.12633141396301134, 0.15224115151379788, 0.20617129121507916, 0.11716129817068577, 0.17910345723586424, 0.16437988515411103, 0.11457267350384168, 0.15075410130832875, 0.14535608382097312, 0.09824004383491618, 0.08446549797164542, 0.16806336678564548, 0.2647876515984535, 0.14030349494091102, 0.23591042256781034, 0.15504656811910017, 0.13079175033739635, 0.09981064884258167, 0.11409677618316241, 0.11255497498703854, 0.1496454565120595, 0.22355716329600128, 0.11928902114076273, 0.10893682949244976, 0.08527627946542841, 0.20146361525569642, 0.13911631650158338, 0.14399216057998793, 0.17119680078966276, 0.06183794965701444, 0.11544050622199263, 0.18793107569217682, 0.29024088435939377, 0.13363781119031565, 0.16095677097993238, 0.21177562406020506, 0.08373377937823534, 0.11690060501652104, 0.23999981741820062, 0.10833749308117799, 0.12523070802646025, 0.09110076978270497, 0.09474892688116857, 0.13400188593992166, 0.13329975147332462, 0.09611943869718484, 0.13131424944315637, 0.16099594959190913, 0.1591696318771158, 0.2162215347800936, 0.10735228059015103, 0.15069061757198401, 0.07653203260685716, 0.11867276206612587, 0.1260812652430364, 0.1549626061958926, 0.17013633197971753, 0.21261452404516085, 0.1395626568368503, 0.05865872132458857, 0.14072536730340549, 0.07911387192351477, 0.1559077783354691, 0.21700592126165116, 0.208417662818517, 0.11233341973274946, 0.13848612031766347, 0.23463214401687893, 0.06051013804972172, 0.13098767053868088, 0.16732814695153916, 0.1511905486030238, 0.12072303704917431], [0.009765254616338228, 0.034111536374049525, 0.0418409187612789, 0.05718653103602784, 0.027488381502085497, 0.03773881155731423, 0.035388179655585966, 0.015110489712761981, 0.05209475675863879, 0.032915187533944845, 0.027158014675868408, 0.08901082085711615, 0.02872108794482691, 0.0342059816632952, 0.013913492023545717, 0.0216061597290848, 0.014911802784938897, 0.04920793630714927, 0.07196332740464381, 0.043728803350989304, 0.007269742765596935, 0.02111470529676548, 0.05267645125942571, 0.030849228213940347, 0.038186332543513606, 0.013120915624313056, 0.0659840903910143, 0.02501797629520297, 0.03658558701031974, 0.042553689264293225, 0.06398265635860817, 0.04825966665521264, 0.04513083311862179, 0.05841330877904381, 0.03939591620915702, 0.06488399513597999, 0.023404944189158932, 0.025513412031744207, 0.019420223543420434, 0.058988177217543125, 0.03417052820857082, 0.003689806426077017, 0.11191702993320567, 0.03715579052056585, 0.07942352137927498, 0.024651143300746168, 0.03742365239720259, 0.04444982823250549, 0.00541576965978103, 0.04826252328764115, 0.0494605447165668, 0.0247524384010051, 0.018779118212738206, 0.012862264012385691, 0.04454652286533799, 0.03053991124033928, 0.029053414040910344, 0.06528745205806834, 0.027333090281380073, 0.025136267001341497, 0.037404524495026896, 0.058808752202561924, 0.02948124733354364, 0.04249501973390579, 0.054066264004047425, 0.03273459204605647, 0.009721495044816817, 0.033822935074567795, 0.01757948356680572, 0.0696573532851679, 0.037953920728926144, 0.033528868175510845, 0.007925371290184557, 0.05905303837997573, 0.00409292323248727, 0.015368158297081078, 0.009653789972487305, 0.045407288641269715, 0.045576518667595725, 0.032142543100884984, 0.06851090730300971, 0.05268069549596735, 0.02063644158520869, 0.03920128183173282, 0.014635126738409911, 0.09458795123334442, 0.005244337787319506, 0.025286638843161718, 0.01399305703983243, 0.026517771084659865, 0.02139790715383632, 0.028257166767226796, 0.05535934140373554, 0.021318964693429213, 0.03366552512826664, 0.01120889384765178, 0.018509607496006147, 0.03054500703832933, 0.0327419100462326, 0.08185014581041676, 0.018727113592571447, 0.028121921167309796, 0.04273711424320936, 0.04151011936898742, 0.03579519549384713, 0.032714826320963244, 0.0331189821341208, 0.008151338718432401, 0.09347655837024961, 0.036153468769043684, 0.03137507249734231, 0.031228675174393823, 0.018566894511293088, 0.016732378397136927, 0.06676182044403893, 0.009888408722222915, 0.019236067443021705, 0.025925932485344153, 0.05909244090850864, 0.04936744971200824, 0.048752113444996734, 0.041237280437988896, 0.09680249275905745, 0.01324261087990765, 0.07042607917849507, 0.023310661748317734, 0.05505917786753603, 0.09361745616687195, 0.04990186050002064, 0.018368280525984507, 0.020987720860700523, 0.03242068139037915, 0.015694126520039778, 0.021590505926204578, 0.022797806321510246, 0.05035620754850762, 0.047948907794696946, 0.0321806869469583, 0.05165618904201048, 0.04790364272360291, 0.041375467487211735, 0.020741823162617426, 0.026654629901583706, 0.04836832046774881, 0.012884927082008548, 0.015454023511015942, 0.017720735897975307, 0.02532450618621494, 0.016268769345645393, 0.045015967317989895, 0.004013033367560378, 0.08970650245568582, 0.014246344832437379, 0.035424413425581794, 0.023699168847607713, 0.015524452053276556, 0.0428166147986693, 0.08917159972978489, 0.035811398910092454, 0.023356908998851265, 0.0068353900236875886, 0.06075500776725156, 0.11765574663877487, 0.06014064180531672, 0.03212674002030066, 0.060694516370339055, 0.07362040491508585, 0.004875115077343902, 0.018577423678444963, 0.0672401672761355, 0.0572385611012578, 0.006444400758482516, 0.01874427543953061, 0.08908552756266934, 0.022258013054462414, 0.013125164949867343, 0.020192957882370268, 0.01700430130586028, 0.007818147490200187, 0.05448111352909889, 0.032336858566850424, 0.023832863995007107, 0.022078170740444745, 0.02534954752107816, 0.053071955751095495, 0.024829557298549583, 0.04266254663733499, 0.017704520607367158, 0.043493952203009806, 0.03338284404682262, 0.01881138255287494, 0.009625149009350156, 0.056807189248502254, 0.08023904583283833, 0.01062127064713942, 0.0152205497891243, 0.008588462851808538, 0.047290284386170764, 0.009743409181412841, 0.061479717093919, 0.019839554792270064, 0.03748649831062981, 0.044466208067855666, 0.021751038829929063, 0.02890823808099542, 0.01924208944131221, 0.066735880050276, 0.0027459648512636443, 0.023394367524555752, 0.04048510401376656, 0.06217501871287823, 0.0378329548984766, 0.02422823617234826, 0.06317113526165485, 0.023841359253440584, 0.02600338725772287, 0.019053287072373287, 0.026686069821672778, 0.05798106161611421, 0.02858402387105993, 0.022640942595899105, 0.005636391928419471, 0.023903711532641734, 0.038761835412255356, 0.04130055382847786, 0.025253638292529752, 0.005624480246167097, 0.02286898803764156, 0.012287987595690148, 0.04931203375703522, 0.03445208292188389, 0.019864516399268593, 0.04894444080335753, 0.06725406367331743, 0.028536828367837837, 0.016772798728197813, 0.034010085210736306, 0.06111577805131674, 0.04725897678041032, 0.007968312378839722, 0.015271314386544483, 0.040713967090206485, 0.029998603143862317, 0.018971613508516123, 0.010058167157694697, 0.0476382710704846, 0.025798389954226356, 0.04313411829727037, 0.004361107413257871, 0.031632780097424984, 0.039345524805997095, 0.02501745382323861, 0.029333221526550393, 0.07460202795586415, 0.023268407676368952, 0.010634928708896041, 0.01671487558633089, 0.021115276962518692, 0.04575810142393623, 0.03245080155985696, 0.009516629207480167, 0.03201300398047481, 0.03733366847570453, 0.059632147662341595, 0.06357334367930889, 0.01521226148387151, 0.026952101350096718, 0.021292822435498238, 0.061793471686542034, 0.04797921795397997, 0.03963335257555757, 0.02499781871613647, 0.01875927615245538, 0.05139533303944128, 0.02507638289327068, 0.039958289425287924, 0.028127941469262754, 0.039476777227329354, 0.0429764131882361, 0.05579221960423248, 0.05359383399731346, 0.024242982434641038, 0.051612016412296464, 0.050217104477009604, 0.028853154608181546, 0.03626779852701085, 0.04698633123189211, 0.02987627006535019, 0.010155026335269213, 0.022201212888051356, 0.03210143066410508, 0.022322543431073427, 0.03307422257161566, 0.015811323088460734, 0.00759617324053709, 0.015221304659332548, 0.045262513017015796, 0.016101310295718055, 0.01862580152893705, 0.09858684308294739, 0.031120947562158108, 0.0136414503711941, 0.0377684431815786, 0.011961736084361161, 0.02806458665457155, 0.028911128640174866, 0.004699792230634817, 0.10386163182556629, 0.012758838312168206, 0.03236890238310609, 0.025177223375067115, 0.04744359937363437, 0.012672713558588709, 0.03250645160941141, 0.06861460102455956, 0.11405134147831372, 0.04580205352976918, 0.05822001450828143, 0.061687660935733996, 0.01966508986827518, 0.013878119144854801, 0.07332256875400033, 0.0040427557458834985, 0.01797111362351903, 0.01997723463656647, 0.09125605252172266, 0.029813715921980993, 0.01410793386665838, 0.03341667241017733, 0.024039104713925293, 0.05947909051818507, 0.019610276113131216, 0.025616674883557216, 0.025805087094860416, 0.05230945541656443, 0.02380704743388508, 0.009111115476116538, 0.018959920653807263, 0.03752004508195179, 0.037783744146249125, 0.01462152211128601, 0.036075101367064884, 0.02448613885124879, 0.014049686724320054, 0.009222436779444771, 0.09572167468390294, 0.011875243225534047, 0.06559965280549866, 0.04853634609441672, 0.039714834453271966, 0.0248282443332885, 0.03313552142520036, 0.09902626914637429, 0.11450579709240369, 0.1134524732562048, 0.1324760371020862, 0.15523358594094003, 0.07672673823045832, 0.08147226287318127, 0.1119663662144116, 0.14243554696440697, 0.12761425226926804, 0.10690203867852688, 0.16711746182824883, 0.09826139733195305, 0.14458287959652288, 0.05625389822359596, 0.07500880291419369, 0.16616861202887126, 0.14975668197231634, 0.133723876572081, 0.0886234859270709, 0.06545873465282576, 0.18652857095003128, 0.21609219243483885, 0.1615254104669605, 0.17629662927772316, 0.07475953628974301, 0.19434414085532936, 0.13037681260279246, 0.1554743165948561, 0.11944239719637803, 0.15357878830816063, 0.11382036137261561, 0.08890701178461313, 0.08061614845480237, 0.11450332722493581, 0.09600357205740043, 0.07354531144457203, 0.14191379424716744, 0.12448688436831747, 0.18628212703125818, 0.12259219746504511, 0.059479979399059496, 0.22036958219749586, 0.07911556826106139, 0.16879507180835518, 0.09399187857551233, 0.15518261439033917, 0.19694041939718382, 0.103291167079338, 0.12621341672326836, 0.11538315644221646, 0.09604795503297023, 0.12147617020777293, 0.09107567077236516, 0.12741523794829845, 0.14409034459718637, 0.12984113634697028, 0.11716135245348726, 0.14209169255835669, 0.07463518117687531, 0.09706162528267928, 0.12922319450548717, 0.14119150729051658, 0.12065640491034303, 0.11134558131120034, 0.12675289277519497, 0.11301630416086741, 0.13666671008935996, 0.08791321582560029, 0.1678695771843195, 0.08715752458998136, 0.1721914652734995, 0.0913409236818552, 0.09859109749751431, 0.11181282052504164, 0.11394399723836354, 0.10514088746692453, 0.11503947845527104, 0.19997637506042207, 0.13220007691000188, 0.19788457373423235, 0.15774291700550488, 0.1380971297621727, 0.11865879781544209, 0.06087012801851545, 0.25694088265299797, 0.08977802004665136, 0.12377758457192353, 0.12274660489388875, 0.127469290047884, 0.08535282500088215, 0.14381609431334905, 0.14086424985102244, 0.1424517910927534, 0.12473118411643164, 0.1077970467241747, 0.08544947552893843, 0.13781655553196157, 0.17810430085020407, 0.19214338037584508, 0.05911814381501504, 0.10835949797183275, 0.1415938785565751, 0.1759967032287802, 0.08526342801217522, 0.17288996279239655, 0.1637069276933159, 0.10499919578433037, 0.20630724249141558, 0.1149941658867257, 0.10725493795637574, 0.16391084103712014, 0.12438112790031092, 0.1223953544561352, 0.11697858226086412, 0.22015954846782343, 0.053792631187077077, 0.11682968453637191, 0.09089101425239018, 0.07896479777991772, 0.10354662872850895, 0.08682874044669525, 0.20755490554230555, 0.18977199548057147, 0.12932606041431427, 0.10365086527807371, 0.1031948286773903, 0.15416470329676354, 0.166720464559538, 0.192002055102161, 0.11106635058032614, 0.20799408054777554, 0.08091460886810507, 0.11429792110409055, 0.10149579056139503, 0.1082746810945017, 0.14168140957398073, 0.1621505312089409, 0.1647731504802193, 0.28721119835972786, 0.12926012038120202, 0.108147014730743, 0.1414210285459246, 0.13152260040598257, 0.10631853248924017, 0.1492531547056777, 0.11565096064337663, 0.09201978439731257, 0.07321597090257065, 0.20274382084608078, 0.10313296663974013, 0.16590088925191335, 0.14465679920145444, 0.09928415316556181, 0.18484622479549476, 0.05998919278915439, 0.17075020261108875, 0.1530824399420193, 0.1250972809003932, 0.08517423458397388, 0.12915095766740187, 0.1331649265651192, 0.26491109068904606, 0.15876727418175765, 0.09920523275754281, 0.14406369174165384, 0.16388926362352713, 0.10546226200780698, 0.10364267536039863, 0.3347513702298914, 0.13189359621277877, 0.11245596315711737, 0.11590018655572619, 0.24490861115711077, 0.08490406229559865, 0.09177341511739151], [0.07522031585020678, 0.03235641733876296, 0.034037847471024306, 0.04441408300772309, 0.04710947176707642, 0.012438097353359419, 0.03046958108565637, 0.011244102181600673, 0.008791454236156173, 0.028069570494283522, 0.06867052588079657, 0.0661607062710183, 0.014439213322475553, 0.03470167863581862, 0.02744228352925607, 0.012521253516232329, 0.04663703158231718, 0.019260119813095247, 0.07133300229907036, 0.006722376199572214, 0.032463826039539914, 0.021208458480292132, 0.029217358279441084, 0.058933826562549384, 0.017141178782497133, 0.02085064660890826, 0.026911950736705745, 0.033811952985290966, 0.04914638978828277, 0.010651342470997145, 0.02294787112623453, 0.014061666260074292, 0.021817173941859176, 0.023741545055859854, 0.03086463435153876, 0.0364759153952556, 0.0857735506391951, 0.056270508760852475, 0.07292582254324641, 0.02486577580150749, 0.009801279736815818, 0.04553791681038482, 0.03611873456143907, 0.08532848594976322, 0.01433791482954153, 0.06286158080079726, 0.023515024621571814, 0.0917661887194429, 0.05978871961789472, 0.00862489000428468, 0.04727446434221097, 0.07708493008145265, 0.06480478295790297, 0.007293721344987196, 0.07218752216015543, 0.03610875331131475, 0.01954378646665386, 0.03243697980152709, 0.06991719148520913, 0.05526547286925571, 0.032176965182381015, 0.05535070704562323, 0.058568957926971574, 0.06408473516681365, 0.06393591208117348, 0.06240196153521538, 0.07206045969256333, 0.058985313799764426, 0.013506978301198354, 0.02086686359585396, 0.023752644192427397, 0.054989692488951344, 0.03912198144410338, 0.030798355050917183, 0.04008012378056135, 0.01502808163474713, 0.03576139427189316, 0.027055813731359582, 0.013118205725082328, 0.04239383998460003, 0.038345717026719024, 0.047089309098997285, 0.010304533044940658, 0.013960825778277857, 0.016291464645681635, 0.013907881387110268, 0.04807913223547595, 0.03255663266671555, 0.03795636006231819, 0.026702334306069782, 0.019030043855309486, 0.06838854029774666, 0.08980401472321578, 0.010583941891257252, 0.023518327390775084, 0.019608194706961513, 0.00565725433573659, 0.02176113543100655, 0.04809986148029566, 0.008787145538787757, 0.021197498443403413, 0.01716350597728576, 0.04624904186597892, 0.06307408439793757, 0.06773249192961625, 0.026148096724812473, 0.025471909437328577, 0.04698219556095345, 0.016012747905084064, 0.010047327560771788, 0.05118495664958443, 0.029278697845126902, 0.01748730967353497, 0.03411444389660444, 0.034907342599970956, 0.04815377787287746, 0.025877887117011205, 0.010376629935178374, 0.03058157329048429, 0.059654688595661094, 0.08213318990809576, 0.04077167649354253, 0.022876747085579803, 0.020413259543212395, 0.026869143658716763, 0.039813856461218426, 0.021343237587383816, 0.011254501578930234, 0.09844859835824796, 0.06164758665753262, 0.04061823597710047, 0.03929717579324331, 0.022515520486714583, 0.03837252255263073, 0.0708282875961491, 0.03380367825073855, 0.003976385691203177, 0.0112606550433806, 0.014378555684483476, 0.016099800555301563, 0.057332667122994146, 0.031551067517804246, 0.057953981283519945, 0.030860172983791147, 0.048325243672089915, 0.029677700184817826, 0.06360015938324587, 0.03136841606880937, 0.035867205022701194, 0.01891593122854829, 0.04657313393961106, 0.07991200552455016, 0.023353032867557237, 0.07608007400163583, 0.02931497571989894, 0.02976716841970171, 0.02390756561154766, 0.07932070296789918, 0.028690903314522335, 0.018224314054740325, 0.05743547874901976, 0.04244000072191868, 0.08684319324259247, 0.03526392971564617, 0.04545869445428252, 0.02240950956807605, 0.0017742282777492488, 0.047614783580814085, 0.003986821135705603, 0.038137735865478, 0.012387197048935508, 0.016074518340506723, 0.010738051612861454, 0.043425053757216246, 0.03421280433290771, 0.04233859366338168, 0.082408383355609, 0.033735251386782954, 0.06803305580147676, 0.032912510713296275, 0.04486458954800453, 0.03224247095308133, 0.013791264966130257, 0.02366734725157065, 0.03681983765480774, 0.049479238356330564, 0.05279563254277621, 0.030727919723306383, 0.03709750096978886, 0.009262204868718982, 0.09023602439888886, 0.03692883412752833, 0.04211990521954639, 0.03875255644587534, 0.00817669726841684, 0.03989629168063402, 0.03491857574720468, 0.0134291783241289, 0.04956670830558453, 0.05117375064375145, 0.025989689332033907, 0.0361914158399616, 0.02790668137770678, 0.009611580853483506, 0.010631006776488252, 0.015083210908674767, 0.060893564618059566, 0.015756290505773256, 0.029104928419526135, 0.06979414594492742, 0.02301723606485341, 0.012393312345791076, 0.06409259260232959, 0.02509255238276507, 0.07326707137482506, 0.029395548360688344, 0.06111153720745018, 0.021703040959047418, 0.010112019937618502, 0.030119385769856826, 0.03554156928190163, 0.0443119668800916, 0.003963147472989346, 0.04952518196244325, 0.03248092172933476, 0.022833251294546893, 0.055408684470291646, 0.05523402616381645, 0.015420783776789904, 0.056592253103320084, 0.04377678256215794, 0.014061935977744204, 0.013196738519971924, 0.013353866026071566, 0.07977449361767087, 0.02058504255754607, 0.018681412562727928, 0.06144779880664178, 0.056587167483355315, 0.007184249897753554, 0.04880769903372441, 0.026152926197807704, 0.025773170503920743, 0.016568303540615097, 0.016083488573453257, 0.03727550784658108, 0.06186720808701856, 0.004174699848850391, 0.02462080939273749, 0.06705817061343364, 0.03817873295130474, 0.03613559276397739, 0.018502420113821114, 0.033725582262767215, 0.017649572841557007, 0.0367070006738816, 0.02587547492501991, 0.06440182815172843, 0.0076248481304251724, 0.021454546168180447, 0.013609037601522036, 0.03352594368958047, 0.02465557074174285, 0.03801293631217309, 0.029182379799229757, 0.018506990047171712, 0.025729147151910832, 0.028706377305622612, 0.030603323730507066, 0.024718141848487512, 0.014069018187001348, 0.029634847305715084, 0.029177175435636724, 0.003199135701704238, 0.011189779516176453, 0.052730374437357695, 0.05166772074465241, 0.041305405353861194, 0.032392759674361775, 0.09337934465812785, 0.02928803109430841, 0.05349043543849673, 0.03025019375075187, 0.025193440362012813, 0.0025490645909615394, 0.0524115342247699, 0.039775485305913856, 0.045675038559628386, 0.07523924019187689, 0.040704074049634595, 0.03483485470392874, 0.039439491728054624, 0.01782568490930966, 0.036979317132915766, 0.023982338474265168, 0.028324012644588947, 0.013880907075612672, 0.031391360730464966, 0.00894203981650727, 0.027676666488072703, 0.026809500430577567, 0.03930959637675967, 0.04518373170867562, 0.04199958060468946, 0.036332520589764626, 0.027630765290398682, 0.030160328572882072, 0.04728242355797972, 0.016154370037838817, 0.047525403555482626, 0.03156243297936661, 0.1038140868768096, 0.01596345063964171, 0.04583805659785867, 0.02077190431633166, 0.01563729751589043, 0.040288617235741446, 0.032282290780650716, 0.05181608581915498, 0.045856947012777836, 0.02976047806441784, 0.028427568962797523, 0.037652023535753996, 0.06778022008282797, 0.07476541240300451, 0.03659570396744779, 0.031647053081542253, 0.08325803812061038, 0.08369908588273184, 0.06040996592491865, 0.029072124644049575, 0.01679234901842262, 0.035352054451193125, 0.014130511271235133, 0.040028541548443694, 0.014607568038627505, 0.019749033131769726, 0.008077279165653246, 0.04425023715677006, 0.02478601909907801, 0.05666917183303407, 0.005027576807021562, 0.02405694339956556, 0.04295248125812837, 0.018596792460552285, 0.0305706760180848, 0.003556330530305526, 0.022050778281741908, 0.011925515036896935, 0.034765067377260754, 0.026050404645502567, 0.038296350211437256, 0.2308797367981502, 0.12677708933395998, 0.14047908623303684, 0.11112603452056646, 0.1737034855676549, 0.11757110618054867, 0.07814641669392586, 0.059647563977965286, 0.11060160159000329, 0.13186368638915674, 0.12262885192675249, 0.21797576493450574, 0.15597587610994065, 0.1421019791492394, 0.1347968304263694, 0.16368482102240833, 0.08089334358062063, 0.09937084958489452, 0.1370447762310505, 0.10041761877281324, 0.24085954842822893, 0.13429850073797361, 0.17343003595513956, 0.15217344728963716, 0.14403971231409482, 0.1277887307639633, 0.12851037989769662, 0.11704186243670327, 0.14875262656382152, 0.11764417083135673, 0.14524648684476102, 0.12716807478240558, 0.06851430676345314, 0.115311896694558, 0.113709217336561, 0.10226535105279513, 0.19374154747596808, 0.09894359643970217, 0.17133888602256775, 0.12155220684196268, 0.08171741757541895, 0.09651634775634323, 0.21769953332841396, 0.15584593665386948, 0.09950499595808131, 0.14256236515939236, 0.0886851783309664, 0.1653030320469822, 0.13832169771194458, 0.05733870608466012, 0.12563618698290416, 0.12051833660474845, 0.14499270117708615, 0.1706196931856019, 0.142365250736475, 0.1262079341603177, 0.07657626630472285, 0.09091445763728448, 0.14105495890336378, 0.1468755001468318, 0.14701655400650843, 0.15087809679763658, 0.10422531302486147, 0.12960039212235383, 0.17757834121584892, 0.17032891378871032, 0.09511507116258144, 0.09496960682528359, 0.12848895176180772, 0.09487991128116846, 0.08000354668391602, 0.12875655240246228, 0.11231176768030439, 0.1181822626718453, 0.15031868538686208, 0.09906716445194823, 0.09117304733289139, 0.10513704695871898, 0.13737598274435314, 0.17655098491481372, 0.10560949053615332, 0.12956403621605464, 0.05283299946625318, 0.16630917734333447, 0.08263502083718777, 0.10578721242823771, 0.19067773116486414, 0.10675042681396008, 0.14358856795089586, 0.11427106468805245, 0.11221217909561736, 0.10545212469462838, 0.15924596706671373, 0.12065462714859418, 0.14250105273510727, 0.13164736942521163, 0.0920946743073208, 0.10060988845569746, 0.1396962468113218, 0.11465284920164517, 0.13046225373234066, 0.12879406181829317, 0.15456681671951497, 0.11316731891461781, 0.16495488929961408, 0.12348092906177044, 0.07718137026365314, 0.11679839050131184, 0.1312608623078891, 0.16343967989087105, 0.08816470804491214, 0.12207037689430372, 0.13173329909997328, 0.09691293111869267, 0.09271305719656603, 0.1400718702269452, 0.11045671400747128, 0.14260714847062314, 0.1358464833881174, 0.20209176226386003, 0.18751518800854683, 0.13944166047232492, 0.07915456366858312, 0.08178008028439113, 0.14443414472043514, 0.1473943351634911, 0.14187396424157278, 0.07608885424477713, 0.23580522249851907, 0.18641079084149428, 0.11255671882203647, 0.1548030554716076, 0.1091265750250646, 0.1327563263475895, 0.12277576832899026, 0.21101479631449493, 0.10323780030012131, 0.11025594906615359, 0.09739104724888291, 0.0544549492187798, 0.18675594803478035, 0.1346179550247533, 0.10982956444578511, 0.10306617843785457, 0.13313076911228044, 0.21644321217068604, 0.1216789029006447, 0.1688703213419233, 0.10619465235088553, 0.09810342080891132, 0.1471756026148796, 0.14247513269739492, 0.1411554499396256, 0.12311536153512341, 0.057380015296595435, 0.10547482847635235, 0.09284184992845569, 0.11666553334466048, 0.22924672013946942, 0.10309049034757273, 0.11971793669675078, 0.06292151579899447, 0.25933239289692467, 0.13346842170826026, 0.1338565301682268, 0.11140448493616921, 0.09067045644457851, 0.1719331062797989, 0.08015720093888895, 0.1276052820363215, 0.15750495477446488, 0.09300498331763915, 0.06304629838892392, 0.21104013281209127, 0.14782250433095864, 0.15975133994860308], [0.014094318213340427, 0.03786455088161996, 0.03530801074313266, 0.08859612060976879, 0.024949907358469706, 0.019530639850667546, 0.04517962996448789, 0.05498001318691032, 0.02940851855756981, 0.021402139516015137, 0.04578860496569957, 0.043308352519358904, 0.07353194430470467, 0.036875036478574784, 0.028950778833989586, 0.0417966918487634, 0.02912838537512081, 0.014911600920770849, 0.04395344593961324, 0.008265448800687279, 0.007849081901700368, 0.01667006852637444, 0.01458662505527692, 0.005505318470698382, 0.035232119993971925, 0.0466446549232517, 0.07216601938541446, 0.021810056109513556, 0.02801268720733268, 0.01881123157883329, 0.0351606465077826, 0.00873418927325734, 0.04779080913535186, 0.028537422085979154, 0.03649276341976864, 0.017544128499659042, 0.015671970655343363, 0.0287120566437287, 0.01313846169172653, 0.019282195949926972, 0.019751961010375192, 0.04170862478869302, 0.044648286154759784, 0.005325092360310788, 0.02606918310214366, 0.014993861417419143, 0.02311222587845155, 0.03987771339182343, 0.05524928302371076, 0.02487434569879302, 0.04526187180142317, 0.03622189563299928, 0.03704253284792815, 0.05021416302770376, 0.03689688530617526, 0.035439178347587585, 0.03743300600243466, 0.033330752913440974, 0.025518704604889666, 0.016809587200571383, 0.06522626855543681, 0.06950494753462927, 0.03940291190519929, 0.05110226358686175, 0.013870624725573828, 0.024446122248524, 0.055027422428663285, 0.08703026534723383, 0.01331747873752777, 0.0035545107842023882, 0.03552778484299779, 0.017245545950052992, 0.033595805655100515, 0.046727188530245, 0.06404136999377183, 0.034669214127851386, 0.026703121406691413, 0.04933600639924407, 0.059790395599390776, 0.03622501010873488, 0.034225818634565384, 0.06810886173376016, 0.02498330145941249, 0.061855225158589225, 0.02913880767300725, 0.0253850467769163, 0.005498731592004853, 0.042395892553031445, 0.042757063172757626, 0.016781782531844716, 0.121054026431271, 0.03232078067958355, 0.015430938053343977, 0.028812320370759283, 0.06564185089830842, 0.03817795942138348, 0.028912886045873165, 0.020005219117073075, 0.03778198334787573, 0.02732714461827917, 0.03617256613714354, 0.007603405575667108, 0.015158350180302347, 0.02108604397757777, 0.043627895015691004, 0.07141474541276693, 0.025296816868441444, 0.05190098412068827, 0.07135016244969197, 0.047927293061677895, 0.021990626152338724, 0.01991531322710216, 0.008195061818696558, 0.055467482922332625, 0.07921050888087068, 0.035489291551389864, 0.055050116032361984, 0.011893164183545326, 0.016208333927871924, 0.0237639384078128, 0.014999615394377282, 0.06367962940462998, 0.02535289609139519, 0.04059748298355511, 0.018178187244172608, 0.031945160656635246, 0.04991932938407574, 0.07336971336709601, 0.03286689958934273, 0.03597121087035962, 0.07592046220919915, 0.04384740109422377, 0.015001978392579725, 0.02073104802652129, 0.06251858134887048, 0.00931745458261243, 0.020974206139466593, 0.0021294326662817703, 0.010825440986081958, 0.027211690188518593, 0.04557393005649958, 0.048303449127290926, 0.03815784764343074, 0.024893249684412564, 0.022647529474592636, 0.03313107702082821, 0.0058678703332718995, 0.03785854584670492, 0.03632085996546915, 0.04226710660649197, 0.01578154049015471, 0.05234655771138413, 0.03354604868218303, 0.027237211586907506, 0.017305341848571385, 0.060500665700861385, 0.040004036256245205, 0.02168074938734727, 0.027165456508685435, 0.0409739138558507, 0.009947218200457948, 0.05099375565935459, 0.009612624949243451, 0.019239566987380385, 0.023089189614568437, 0.06832713966390916, 0.02985796658322215, 0.03377340541088155, 0.0074327930342406034, 0.011603092159410673, 0.043794862127729824, 0.023976404685527086, 0.0301578044226127, 0.0212098800111562, 0.05772966439170497, 0.027343375175925236, 0.06977115039314542, 0.01917341660841235, 0.046948625040905814, 0.09278601328177111, 0.044903361038970094, 0.0296210323327354, 0.0177856513432094, 0.006128787403992776, 0.0008381134674501871, 0.11026217801762478, 0.020874836382323077, 0.052565503998526504, 0.03555330115237406, 0.026765733225537196, 0.04151595137747271, 0.014034365403598972, 0.00643852464522102, 0.017275306495970914, 0.05432318111083337, 0.00999025343584695, 0.012306007789447904, 0.03978900172348533, 0.029602606714304005, 0.03008499082976154, 0.0659817833719509, 0.06163371740175145, 0.05545789861519422, 0.03576256813747542, 0.04771514908809747, 0.025580929658774818, 0.050272181164473295, 0.023742483130523136, 0.04224141387801085, 0.020194053716425384, 0.03775033647460597, 0.012270763832410532, 0.02917617798915931, 0.016018693568184972, 0.027796268463134766, 0.058075730821916034, 0.032611845061182976, 0.018700104506154145, 0.0854557655485613, 0.015199145401961036, 0.022244467799152647, 0.03874072279515011, 0.04038765620706337, 0.035348851765905104, 0.03934531106746622, 0.009704713177468096, 0.0314611785912088, 0.040123814650412114, 0.026088972575962543, 0.03245458099991083, 0.04222140388031091, 0.036564715273146114, 0.01176333923025855, 0.018156258688707436, 0.026892872028318898, 0.012140502072205501, 0.034492662708674154, 0.026711891471807445, 0.04918073383825166, 0.0393896024408085, 0.01626715443230101, 0.016071790629731755, 0.07608761931104319, 0.06462396694613354, 0.029045417505715574, 0.04709668477465, 0.08109554023082767, 0.02565390949270555, 0.030281386005559137, 0.025065224384889007, 0.07609181265745844, 0.030326613757227148, 0.033999493279095204, 0.021452154332239712, 0.008806410844304731, 0.04137023598221796, 0.013734846475667186, 0.09540598626647677, 0.02431596566124686, 0.023782576068437526, 0.026268502763871635, 0.03029417639066066, 0.016105754700090204, 0.03284342906304768, 0.048023288803441186, 0.04291415760027511, 0.02918983350640961, 0.03768864407071045, 0.042150897306523154, 0.08859795943966933, 0.035357682899172814, 0.04230879579803773, 0.030292568262666464, 0.027646079825769578, 0.010101137932256928, 0.042191154789179564, 0.02251218379076038, 0.04746875945212586, 0.012505998352675565, 0.023007438019184128, 0.00590304474046986, 0.05336034331204636, 0.008342462525303875, 0.03165214548685721, 0.02366122686570244, 0.03446934485275831, 0.010485949560201593, 0.08388783396886927, 0.07225499568240983, 0.04290255465145622, 0.05827954238546746, 0.10958820275430169, 0.04483886289277247, 0.05932950747332402, 0.025144962427605475, 0.022560397096510445, 0.01506417800140168, 0.07485645823180676, 0.0482602875147547, 0.04526686242648533, 0.039580888247915676, 0.03062400547787547, 0.02322938682378403, 0.07285567559301853, 0.019755591172724962, 0.026004997082054615, 0.008318367746791669, 0.04147153447515198, 0.03814370358096702, 0.016537715181974427, 0.055301638785749674, 0.021481713013989583, 0.021138922211581042, 0.02870061993598938, 0.03639697463118604, 0.04525208393377917, 0.027412034438124726, 0.03922589908220938, 0.0068002915275948385, 0.031913585029542446, 0.010505240310781767, 0.044366381995912106, 0.02865657622792891, 0.046745668431477885, 0.029883099520312886, 0.07193460501730442, 0.022778279780011092, 0.06663722784391471, 0.003765697599322136, 0.012549954699352384, 0.04529613781986492, 0.093606287480465, 0.028981984659497226, 0.02552359175336148, 0.05057868221774697, 0.0209638839254954, 0.03689895483798214, 0.06807969829865865, 0.023703260413770164, 0.09522672409990005, 0.04585998345698629, 0.008317389808196043, 0.0467679549141654, 0.013618308086214321, 0.017650994372421076, 0.011557319035221423, 0.005476227129942605, 0.015145608988989676, 0.03479388815217784, 0.049850098456123045, 0.0718839116660612, 0.03659831971994468, 0.14388412423431873, 0.1280195683773075, 0.1362851019948721, 0.1879086433244603, 0.12615891679057054, 0.10759386619819061, 0.08569163110639368, 0.10561094260109322, 0.10199380812368222, 0.18167714056159767, 0.14504787964480265, 0.1758102010935545, 0.12242724560201168, 0.08885663055947848, 0.12778801151684352, 0.12315596507063933, 0.0950118252741439, 0.09701522027275392, 0.24871285845126423, 0.05508225145084517, 0.050386985896953514, 0.10751588895384755, 0.13450423255562782, 0.1274042592516967, 0.11010133807680436, 0.08845454427812781, 0.17602550025497163, 0.091507599023836, 0.11588243607963834, 0.1308631593627589, 0.23344223786677631, 0.07372578140348196, 0.07105408369430474, 0.13985570254070417, 0.12264504177229744, 0.09330176096409559, 0.10106331269655909, 0.08135874396456139, 0.10962384619883128, 0.10496345055954796, 0.09984114220631973, 0.13011819576578482, 0.16436923215431826, 0.09387308066444737, 0.1635105460882187, 0.10771653854421206, 0.130859888823969, 0.09575414258454527, 0.2176497017166444, 0.1317399623138564, 0.09559637640735932, 0.08019289866622005, 0.06942382867314986, 0.13835608586668968, 0.17215610002832754, 0.11985554359853268, 0.12939569167792797, 0.080460913213236, 0.10459360826228346, 0.06273458618670702, 0.1632717289030552, 0.10651711254779782, 0.11047564513449158, 0.08715551612632615, 0.08014291099139623, 0.08077455245490585, 0.12156062067619391, 0.16876601693885668, 0.1581649522164038, 0.13606958570224897, 0.18193668020623072, 0.08943618767495666, 0.17055140542132513, 0.11964730120130948, 0.17267698422074318, 0.16087210338030541, 0.14172087317066534, 0.180520197642701, 0.1513229307851621, 0.1214645401175533, 0.12146614146019731, 0.23903865899358476, 0.14030869251915387, 0.12914916633495263, 0.13218548840710095, 0.1608070590134178, 0.15572567310716423, 0.15790474760745252, 0.13395403565040656, 0.10100856170590435, 0.18989776873162814, 0.11900514923036098, 0.10052129892366272, 0.1290872703705515, 0.14279993384012155, 0.1124982630301799, 0.10611209499516658, 0.09508274575429303, 0.10118505544960499, 0.11867251779351916, 0.10507184652877705, 0.08923181971268994, 0.0869081426145775, 0.07536290319902555, 0.107437640295497, 0.10343114885368518, 0.0779962365382484, 0.10432729683816433, 0.22824341111949512, 0.15660642513207026, 0.09812635529254164, 0.1634569146803447, 0.19657652106668266, 0.10852729968194451, 0.2067636658570596, 0.270096591008561, 0.17782359091298922, 0.17741229012608528, 0.10704052089048283, 0.08807461895048618, 0.07636303667511259, 0.12399338584925447, 0.13882645991231712, 0.11502011306583881, 0.10521095977830035, 0.09317607592259135, 0.10692499351820775, 0.21595723181962967, 0.09420696060572352, 0.11475461588374206, 0.099628950735288, 0.11975178202348095, 0.1224245178912367, 0.04975048273003527, 0.11163887128766094, 0.11917329020798206, 0.1137770369116749, 0.1385750219758068, 0.1738590057939291, 0.11783045583537646, 0.10691267810761929, 0.12821114595447267, 0.0768233887585146, 0.09176514377551419, 0.13981990303312028, 0.14411401189863682, 0.08663189743778535, 0.11989762634038925, 0.14319812533046516, 0.13382880522736482, 0.10780951141246728, 0.19266837649047375, 0.20637713159833634, 0.1474942426596369, 0.12837563641369343, 0.20902309247425624, 0.12143708659069878, 0.19672338318611893, 0.12427733918385846, 0.11447800429803984, 0.17526598886719771, 0.1330220406608922, 0.12356894862438951, 0.12186502505625997, 0.11842882872692176, 0.17797524348965713, 0.11382450722157955, 0.14160800565566334, 0.09417307456689221, 0.10395976834531341, 0.06436558081103222, 0.11073405841099364, 0.14710774911301477, 0.09087287022599153, 0.18689066437738283, 0.23795986973813602]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.02748899387993983, 0.006878656385067318, 0.06300460241202797, 0.027077632024884224, 0.014819623802655509, 0.08056934310921601, 0.03751783984314118, 0.015937929241252796, 0.03248299465381673, 0.03281353620280113, 0.0404576233455113, 0.005139134749437549, 0.042465337219515016, 0.015889726113528013, 0.03564839444256254, 0.02914392721972295, 0.06026896634804351, 0.034806505510849614, 0.02052576743465449, 0.09011077361979655, 0.05643781853307571, 0.018031730549409986, 0.0479066079216344, 0.06774751469492912, 0.012983658168065761, 0.029403680602886846, 0.02164299400257213, 0.041687793763620515, 0.01201718342157879, 0.05769989027508667, 0.054098219610750675, 0.02184128568374685, 0.08355575214539256, 0.05778783519885369, 0.014894091324614627, 0.09495780031595911, 0.017553817979725342, 0.043339951895177364, 0.05575038452765771, 0.01788067338722093, 0.040727232449821064, 0.07161478432161467, 0.02863048655646188, 0.01564148916596813, 0.02269488273720656, 0.019814739070300545, 0.06055158975401095, 0.050694579391607215, 0.01921987590113921, 0.06948251516691276, 0.044533627307308574, 0.05905544039394174, 0.05781868818615164, 0.03072551770934037, 0.025550359959847162, 0.03583132748359016, 0.021499081814129437, 0.04728229124365108, 0.03613322128408721, 0.021938772506213615, 0.02426923156183745, 0.10555784723588399, 0.03654195720862065, 0.008013718245950128, 0.023425592009776404, 0.025941816990130713, 0.029278731771877835, 0.01440014666877687, 0.008050884153427822, 0.06610044557601213, 0.02918408970747675, 0.023558323637449315, 0.014930789891098226, 0.0375034209739949, 0.046364131583166976, 0.01046736363787204, 0.013686556834727526, 0.023036167191873704, 0.06909437956554548, 0.030549536259578805, 0.03156426502391696, 0.016182726016268134, 0.07055544866515057, 0.05891651713422366, 0.004294143640436232, 0.034434468152799776, 0.023416625169504966, 0.025342679050351893, 0.012462500865305108, 0.02467528048769704, 0.04563927297879543, 0.06774317207080977, 0.02338301733003131, 0.009648368477688303, 0.012608522449487021, 0.03573816801820483, 0.02064149158208498, 0.029101454320230653, 0.00775110992669527, 0.04154820214690907, 0.0787884397432208, 0.05492617482585566, 0.06714785937219858, 0.03359016363642045, 0.07393198819564921, 0.0703331877344421, 0.09791113076997654, 0.031048541090318134, 0.03359209067587342, 0.07421153783798218, 0.0517881607104625, 0.07144979174648013, 0.013125465201613094, 0.08180834126791783, 0.011698218528181314, 0.03832023125141859, 0.053388960526457856, 0.0370394455135933, 0.006942514163841094, 0.016943809908947775, 0.02495374108132507, 0.027794014030535306, 0.0069857355722758386, 0.023716193291225603, 0.06130259231265102, 0.049114742915013006, 0.050281439774802754, 0.022382899120982205, 0.09372341619538409, 0.04991569582905088, 0.05373756467763867, 0.10478251241147518, 0.012738386418537369, 0.06726361066102982, 0.07644840316580874, 0.06808351166546345, 0.03914074972271919, 0.018364180478134325, 0.04091917982857142, 0.03574359629835401, 0.05235269845330289, 0.04478694817849568, 0.05807371557291065, 0.008493070158043077, 0.040591226890683174, 0.0528985527344048, 0.0046640253775486985, 0.01903965530384864, 0.043645357114395926, 0.042315991661910496, 0.0710205640643835, 0.03382743715441652, 0.04047227291656392, 0.04254910236756716, 0.07622046968234436, 0.06948165342743907, 0.04165560066966074, 0.06176173660371985, 0.031246598676911423, 0.02654957232464637, 0.03409024394516434, 0.05779213032552174, 0.011785043869167566, 0.022111184861777083, 0.04575548227876425, 0.00840758577188743, 0.014106449571305087, 0.049727005418390036, 0.04799158764736993, 0.008358245249837637, 0.027816219089020575, 0.05941670600857053, 0.03805695287883282, 0.02843254092814667, 0.0197620983235538, 0.03691473416984081, 0.0145914307795465, 0.06069214828312397, 0.03629976770441447, 0.008506417790028666, 0.02930637528853757, 0.0650710943820221, 0.040327751742941995, 0.032160598917731216, 0.03896922964070525, 0.021559786949572817, 0.021978958742693067, 0.016995241167023778, 0.016677798736574392, 0.015214822953566909, 0.04879499685817531, 0.034417891542294195, 0.02909674189452614, 0.03150973116446819, 0.020217578525521925, 0.08980810628937823, 0.03529130181829844, 0.0687684113425868, 0.04440398301397051, 0.05117554197620068, 0.030595975196255103, 0.016809454886242747, 0.02979240652972034, 0.0007464801227407796, 0.007090472965501249, 0.03319532071639385, 0.05278461313407336, 0.015401499811559916, 0.01958084974570998, 0.08251354949814932, 0.006273965484329632, 0.040169917712254186, 0.008969165950215288, 0.03308298245870641, 0.06977022758552007, 0.03534196463546582, 0.020677901771185652, 0.029144653252192905, 0.039844699270491085, 0.07041233884436743, 0.03775888940851603, 0.013120891875587404, 0.044507551206541915, 0.009761474328115582, 0.04365660383233002, 0.039056702982634306, 0.040263379125722816, 0.023004749324172735, 0.03210961040375488, 0.031231796435479606, 0.04804309524063553, 0.044076976632433276, 0.03393616221312966, 0.01781863153779081, 0.04197383359340685, 0.024629330096234168, 0.03159101287435208, 0.013499228583116616, 0.05079530452245048, 0.006659615103022328, 0.01946058450266719, 0.04831267720354455, 0.03637052533615913, 0.029451544463102306, 0.018459295820710913, 0.02725865668617189, 0.03752500517293811, 0.035698069991277795, 0.06362154002168349, 0.07567203018282141, 0.07444928972316639, 0.015553708786943128, 0.06366010116679327, 0.024250373377331665, 0.029909396144960607, 0.02564223020869706, 0.021886374335736036, 0.018350475767095174, 0.04400972363405994, 0.038432260775672536, 0.0392789537353175, 0.04717452970466443, 0.030977383122912476, 0.034795394499919245, 0.020499172254598567, 0.022419796158958758, 0.0552984632418624, 0.005735641245597175, 0.025027367219861065, 0.03905810076477272, 0.029599176719784737, 0.010697533742391636, 0.05603892815166286, 0.017608943860977888, 0.051591531440083466, 0.05599042307585478, 0.014349544919761164, 0.05644797620230487, 0.011758304500420178, 0.008622683069136525, 0.007309558352322451, 0.024505232826673558, 0.03790900171069162, 0.012755171678561186, 0.023105033407253877, 0.019441685606060282, 0.015599050193226762, 0.006430752450666789, 0.008168656628445854, 0.06178203158612762, 0.01684535278140434, 0.013649368874861725, 0.046766787833933315, 0.050260880163737705, 0.009978227250810181, 0.07168472092598677, 0.02948388344209109, 0.023525385851306573, 0.014216165291145444, 0.02645386496026601, 0.05808643131916012, 0.06695816133703504, 0.01870126649737358, 0.01071135125987764, 0.067734629314925, 0.035405743534543684, 0.03255981160327792, 0.04378531853269253, 0.0310464003123343, 0.024208324562226022, 0.052696498576551676, 0.04099581357357757, 0.049966816657355854, 0.006117015669588, 0.029834099113941193, 0.017541617920090045, 0.00914099476566272, 0.05089526290872267, 0.07749395099069391, 0.040891000269246955, 0.05957141199282237, 0.03066613232450826, 0.04286438366398215, 0.023430323095193932, 0.02765558270870575, 0.01721709836939616, 0.03189901688269206, 0.027365922894594923, 0.05720563858215298, 0.049198793047772985, 0.01015824343942638, 0.051310919890446324, 0.042381378688982556, 0.0489759825036994, 0.052308318870408196, 0.044561257253267934, 0.032693459253226004, 0.10874140462172882, 0.02118541034204619, 0.0353356542597924, 0.027368603107918586, 0.019622650895533816, 0.03262783134622233, 0.025133096546466862, 0.031030522592897927, 0.013885385406735753, 0.016479822574183345, 0.04547481305365052, 0.04305936748694096, 0.04886977820258055, 0.042412126503352604, 0.01317952832739268, 0.13548714481294155, 0.0949292882744755, 0.12830850215894835, 0.128146427284394, 0.10971257143786975, 0.13063295957233223, 0.13651641458272934, 0.09853530834828104, 0.10786149398024593, 0.0985317663954837, 0.084103445256395, 0.10769069314535175, 0.10830350526209388, 0.0844927750793951, 0.17699747452778475, 0.15049009690327303, 0.09562795542712722, 0.0814821898405041, 0.12184409903628485, 0.1619368333901678, 0.12992102706006595, 0.23952343155230793, 0.12452967278659344, 0.17903698794543743, 0.10038446555180208, 0.17289893302534307, 0.13090662631605351, 0.14736051697816166, 0.08703107958925621, 0.08875682484358549, 0.1611869300582579, 0.10518945700355939, 0.11704070892717157, 0.13178676765944275, 0.10375518325184073, 0.14988976983087404, 0.12237978886280741, 0.2188551870307752, 0.13027767863656792, 0.1453028188220092, 0.10921005518840891, 0.16677690510238918, 0.09739351711635079, 0.13848663600427763, 0.06748585123568773, 0.08959598945719854, 0.11839038293276515, 0.16340630953865393, 0.1298400778323412, 0.10669548583350011, 0.12219404668680259, 0.09974605230880634, 0.13765074871480465, 0.15156401427728788, 0.13401756009885243, 0.10131086941276278, 0.15116266081375734, 0.08788004224853856, 0.10578555001744203, 0.06904877522694212, 0.09516049908207995, 0.21069279073604516, 0.14985607378184795, 0.13053503339844091, 0.15607490151056222, 0.07148526555725507, 0.06739545001515321, 0.11325565060334546, 0.11534644769770758, 0.1595629650567259, 0.12609259677784784, 0.10599250998347998, 0.12239511018352849, 0.2007253962968077, 0.1361509963337864, 0.0645654975835766, 0.10783175379037857, 0.08098858275583812, 0.18579975648650102, 0.06916613464376756, 0.19298385456204414, 0.11175924339996916, 0.12608750776520797, 0.14986891166440078, 0.132670328819326, 0.17548881976732186, 0.12920849743698323, 0.11486014164984226, 0.10160767420061997, 0.1412048608596836, 0.17957962597055094, 0.09809335813458477, 0.09649584242807967, 0.0975212241922106, 0.09723265003412962, 0.08131402172148228, 0.17676186002790928, 0.12564511650374957, 0.13364756852388382, 0.10421674991292612, 0.12281962883259569, 0.16312219335564546, 0.10350612697324582, 0.1024786349652069, 0.125926939238395, 0.12440670867051397, 0.11162810293691498, 0.13442530536225863, 0.0689338721068842, 0.16736883191125734, 0.1341295726597309, 0.16573319610740456, 0.09400998188980988, 0.18163524780954632, 0.24962649228317396, 0.15817799365946225, 0.09593845305166074, 0.16493913371648106, 0.11638490483164787, 0.15136588205184254, 0.09300739890230553, 0.10571335389145783, 0.0635024978380118, 0.10609704508845295, 0.21075046621263027, 0.11942809367818491, 0.09356317336538009, 0.06342030010585274, 0.1858122551015445, 0.13547148422471114, 0.16577181832066604, 0.17448100527482374, 0.12552931771746703, 0.15777227043041162, 0.12819199769624642, 0.13429817504116467, 0.1037091107240745, 0.09843400985534702, 0.1313295979052782, 0.12568734852331026, 0.09363620408943721, 0.11321018875709601, 0.2429320386477879, 0.08443323363150869, 0.2692224479147366, 0.07341662727828537, 0.13551480190030166, 0.06752540304192475, 0.0939314550321017, 0.0917149321841342, 0.14210078492760658, 0.13844896374004229, 0.23813018202781677, 0.1433243735560349, 0.1186156158468553, 0.15739187012825692, 0.12362367925899369, 0.14293447376361915, 0.11684489729149, 0.1540394728737218, 0.07061405373471123, 0.2212514877319336, 0.1122403722256422, 0.11098187297050442, 0.1010386615193316, 0.05224958487919398, 0.07101464723902089, 0.18152725217597826, 0.18348068664116518, 0.08736301213502884, 0.13387973606586456, 0.11432130342083317, 0.11833512304084641, 0.11048742450241532, 0.156776045316032, 0.10126198096466915], [0.058121789778981886, 0.05388865067756601, 0.025735043621222888, 0.01984517984757466, 0.03770433858569179, 0.033774389286658595, 0.0288666303136519, 0.03070990801123636, 0.031921737627791505, 0.01331700206667717, 0.03482323818440948, 0.040848215243646076, 0.02170340227894485, 0.020772157070626105, 0.017698417184874415, 0.019089327459888797, 0.034306601621210575, 0.08286378891872508, 0.028046905728323118, 0.04122684117672699, 0.018681076687893698, 0.03706876840442419, 0.018607414926269224, 0.020293214824050665, 0.009170412651396223, 0.05056313019511955, 0.04368761966803244, 0.017374452336558273, 0.017906890284003954, 0.050934112431215386, 0.058009505804095945, 0.059893492210124216, 0.03551218871559415, 0.02554531505198351, 0.02567569725215435, 0.02219138770098133, 0.05401421358276691, 0.00915301586168685, 0.03911435131781867, 0.06979097040104014, 0.02746626126047756, 0.03973654418119362, 0.10785672387906484, 0.06295040103473834, 0.07160748328481402, 0.05103661532380751, 0.039367729864482365, 0.030899402485894303, 0.06129381206950971, 0.02183615935168096, 0.026208956226972595, 0.05417921972860183, 0.028824795237077133, 0.046295677577810626, 0.011837972145128463, 0.017593032214790583, 0.03142339097602027, 0.0791141636935728, 0.0680232916825584, 0.0611892430377858, 0.1171427063111748, 0.01682257605716586, 0.014299482606085283, 0.039730138810617585, 0.035875177809170315, 0.055888666571783166, 0.04644956932004009, 0.016613002034968564, 0.026053863477760127, 0.02001247604909752, 0.017544869799166918, 0.04308744187333754, 0.009250235510990024, 0.044715430587530136, 0.02893697064636009, 0.07891602468277727, 0.07736000139266253, 0.021197225333058407, 0.03959138518465417, 0.01653182549801256, 0.06311343264366899, 0.013268168749553817, 0.04584235172452671, 0.08970893161105258, 0.03891204949468374, 0.048168267988200696, 0.04995164800701397, 0.0941661467243518, 0.0611790514418057, 0.026155404546963315, 0.023638526476653557, 0.02651247681517686, 0.038001238368451595, 0.011428671340192003, 0.005659352281197373, 0.012528610532172024, 0.035684824987713776, 0.04658099137512701, 0.013038712803141346, 0.03154535764562232, 0.02079362591861614, 0.011988098866173198, 0.06457315824393715, 0.053022609291864295, 0.017854760134858743, 0.04270972517718162, 0.061564622180802483, 0.030219147380973612, 0.018696866197777644, 0.037811862637421916, 0.02768170800326126, 0.022948724384020482, 0.020826141316709772, 0.02334327044497643, 0.027175368208970343, 0.022461595612445047, 0.06691306589969567, 0.08456097463411943, 0.05913350584783724, 0.027867331435637813, 0.0022654978092759848, 0.048539050056466033, 0.039788411398019106, 0.042410128217722685, 0.06397159623780421, 0.03913879554186549, 0.015481982546459352, 0.0336944612541369, 0.005845879013317504, 0.024406550086236427, 0.00796923179378999, 0.02298943478880184, 0.043515054642089775, 0.0421091029420495, 0.026361143149967705, 0.020196448945041214, 0.016172715928405523, 0.03571652275110994, 0.02550311865551131, 0.006845443368157638, 0.029152168027524437, 0.04765965510159731, 0.053855782441262684, 0.05208199012226292, 0.02822647662833333, 0.05385820481127926, 0.029722961863236766, 0.026163192432639853, 0.026792542144123997, 0.061505318220172606, 0.032920127268880606, 0.05554352294919746, 0.041131164346422465, 0.03403301290901644, 0.022350843430363705, 0.043003310316375325, 0.09675346181860991, 0.012888123830115157, 0.0646564687735268, 0.031538609614861865, 0.025947530254987732, 0.02625116110513253, 0.019678572359095727, 0.03954504802823067, 0.056556114328226874, 0.010509422631002963, 0.03501463255711964, 0.019256669462525418, 0.03900486969255975, 0.07260536402463913, 0.04618599239204611, 0.0504130993171462, 0.021360114449635148, 0.000690721878657184, 0.01732361818929868, 0.08875256364366838, 0.04399551511076944, 0.08540646997945649, 0.02475438579650862, 0.020280061422714164, 0.06053829725299563, 0.03146613189684493, 0.006193359764958066, 0.03616293093987873, 0.04789218565981303, 0.06654878080423389, 0.04469820936875684, 0.009663515923810857, 0.09805236783410821, 0.03318626227389489, 0.049929398843752484, 0.029127910400607755, 0.037280271162412, 0.04295866610482335, 0.032835188255246194, 0.039170215105904, 0.0957190894654819, 0.01862089572075222, 0.01199808859798525, 0.04065847310370632, 0.014700829284265637, 0.013011016700017666, 0.012990161926219506, 0.010101743524761071, 0.02314840706198343, 0.04284375619941524, 0.013393620544645404, 0.05004762678540178, 0.037853891096476994, 0.011548759315961173, 0.011262779706157744, 0.026084348359810453, 0.030530252294348817, 0.06891064585319587, 0.02185669182134526, 0.041619505999343734, 0.02378470666839608, 0.025741046959800378, 0.08969126934451715, 0.06800442162368979, 0.0361614924456392, 0.056183666456490755, 0.05783375844891582, 0.022083704193521823, 0.04194977613432067, 0.029014571303767816, 0.04984923332397427, 0.02756167176578726, 0.05305316372375403, 0.03711673065221735, 0.02165463427081704, 0.02198753203265369, 0.014746964576521089, 0.0048529693906727645, 0.05270870881421225, 0.04448915612218635, 0.08544503112456628, 0.05502120026254228, 0.006698274635709822, 0.06905243931604282, 0.028505863422261815, 0.06681112958384411, 0.03949793055653572, 0.027142700140497515, 0.06147983244487217, 0.031699001722569974, 0.015928730002737472, 0.019232674767928462, 0.019038332160562277, 0.050021832276667864, 0.05218947346189192, 0.031306367434029064, 0.037198490729289393, 0.030744737213743583, 0.0274690788771425, 0.019334877408774834, 0.03367549620036568, 0.024230090269286717, 0.032623963696616035, 0.11053575655179364, 0.029645982065371106, 0.05799704111580338, 0.11571425438991614, 0.01733149598086519, 0.03350600493805749, 0.01996069704182446, 0.01775089677955423, 0.06707818061113358, 0.021737990601520454, 0.03201981647206204, 0.027641854248940945, 0.03243342427802937, 0.007476127673206585, 0.037179583350994756, 0.01571186342542725, 0.0557082712517253, 0.041917616967111826, 0.02218714346443968, 0.05561028740235737, 0.023128690530679057, 0.029171713228736604, 0.03377494568537388, 0.022966142377949188, 0.02841948252171278, 0.027339843401153172, 0.03827647592074104, 0.06582185945340566, 0.0159317766249712, 0.016154314058699777, 0.044803674066705365, 0.026721217935638766, 0.011589364547814642, 0.06554836234343903, 0.05193842229034219, 0.0355574503940131, 0.04427027429587074, 0.006538716277905873, 0.04602044002552118, 0.03623402105378253, 0.08237678397979055, 0.026032752556992427, 0.05762148555368185, 0.025996160859774266, 0.06893987714179925, 0.018049713423741714, 0.06787811232996838, 0.04352772967623813, 0.023029763517635207, 0.0353649194751467, 0.017684576766831533, 0.016685725721929754, 0.006053697750238436, 0.04023934880803738, 0.011339990205929747, 0.01861129784291344, 0.030433337137635266, 0.01054221622845424, 0.07866850189332451, 0.0695040790098054, 0.05560748166005526, 0.03399324057889836, 0.01925432512403599, 0.050479385403117964, 0.010229158830562872, 0.015731401841289232, 0.02242454929676439, 0.017701825127005577, 0.07697652054152318, 0.09192938996212822, 0.06197568548044988, 0.056588327778237205, 0.05531352671927639, 0.07794202837560858, 0.016029667175774063, 0.04997757143740143, 0.04452988179400563, 0.02067944374201553, 0.024835078877263835, 0.03636908684191959, 0.017220453725063374, 0.03309379491422858, 0.025938020586701374, 0.021220008842647076, 0.03980787517502904, 0.03881102241575718, 0.020478178381121585, 0.056883405694471936, 0.03977029451302119, 0.036694647943867106, 0.04738766433937209, 0.05289336872686233, 0.06714182041053261, 0.10376487951725721, 0.2510440605027335, 0.05850870401731559, 0.1104722728154489, 0.1148670491363321, 0.1291509848088026, 0.12986367728028977, 0.1436312206621681, 0.22167238300400122, 0.12178176880947181, 0.10102260738079037, 0.10114522544401032, 0.1474340566034828, 0.07092355391276733, 0.10421976260840893, 0.0628496114430683, 0.18222082353063992, 0.16303759360952036, 0.10451570565679244, 0.077694620937109, 0.14576848383460725, 0.10095520171203784, 0.12788961535053595, 0.09306221096111195, 0.09807170608213969, 0.10913688875734806, 0.10007644458008663, 0.14835959193961962, 0.12798765009003027, 0.15237992549581186, 0.19083165004849434, 0.1261051089635917, 0.1602256087852376, 0.13470654455678804, 0.13043520732649735, 0.10129832330026797, 0.15877376097653592, 0.13925243062632425, 0.12763933092355728, 0.15996992321951048, 0.08490463226501431, 0.11565712174134594, 0.23806458126221383, 0.10191067401319742, 0.21284982641892775, 0.14355246988790377, 0.11514142155647278, 0.07287263218313456, 0.19067637409482682, 0.09030265653772013, 0.12729194813541003, 0.11953238451055118, 0.17535951813416822, 0.11524890150342669, 0.09722780529409647, 0.10120858025870152, 0.18721380989466394, 0.1486594501350607, 0.14759914417351994, 0.15235291980206966, 0.2197610448513712, 0.14073683454522065, 0.12925577775708266, 0.18352006881364755, 0.10760530629860503, 0.1352477983704635, 0.17497945709952287, 0.1646636484989098, 0.11504912722323622, 0.061125284326928, 0.08386210392096213, 0.11562699478651796, 0.15882470538573606, 0.15480875516576426, 0.15263434898640427, 0.14297442590551718, 0.1482005026191473, 0.11638414487242699, 0.10925618878432683, 0.07922571485063859, 0.17396772067461694, 0.1266632718699319, 0.1810570274080549, 0.2702773798789297, 0.08840750823063509, 0.09365261106618814, 0.18107385507651738, 0.21809259509401663, 0.11817836788083826, 0.11915518689368453, 0.053626749731068096, 0.14826672763696738, 0.19972934760153294, 0.09404484501906804, 0.11642336419650487, 0.11186152576868023, 0.09305982251784631, 0.1158391319747482, 0.09592127933033875, 0.1285826981599842, 0.07650548831692763, 0.15430677495896816, 0.2879727046404566, 0.17258014370288166, 0.1138196149840951, 0.17458224269960607, 0.1301275866904429, 0.12053082164909158, 0.08234189370913164, 0.12285173710967813, 0.12442308850586414, 0.09476076053189379, 0.12094288239521639, 0.1087950360296028, 0.09215684847107955, 0.09995956013777427, 0.13673030239130768, 0.19359216120626244, 0.08340589768652405, 0.13531390125198023, 0.09547808061220817, 0.13046749202268465, 0.12264257190482956, 0.1466981175222567, 0.19311135129204818, 0.1492865521992956, 0.12836088506238802, 0.09420000562178237, 0.12944248345281395, 0.10792108292558364, 0.08431292937270232, 0.13584108224936894, 0.11007992351161582, 0.13695818159197057, 0.1434249867286001, 0.11087868136486836, 0.17734637723437377, 0.1390209687607629, 0.09719739335456065, 0.0946978060528636, 0.1459811231387513, 0.17653680353292397, 0.13442804664373398, 0.12724082730710506, 0.08107432244079453, 0.13149932665484293, 0.1259806520704712, 0.14231450988778047, 0.0826015622754182, 0.1262516589569194, 0.17096692669604505, 0.1169706569718463, 0.15109593368002347, 0.19186751517866338, 0.07602418985749994, 0.11635736988059112, 0.2223373744636774, 0.06953533233276435, 0.1603035588881799, 0.11541925450520855, 0.125018679403833, 0.1081363210188491, 0.12532965200287954, 0.14099531567522458, 0.16657088830002717, 0.19859338498541287, 0.1751216644687312, 0.16383842777992996, 0.11289065983146429, 0.13366671678211006, 0.1291493291833571, 0.15482774057558604, 0.11185577857707228, 0.1162319223263434, 0.15999519186360495, 0.17988422034042223], [0.04051605538864221, 0.014847031528396266, 0.03030001518449613, 0.018881337816960046, 0.02650029880792967, 0.0644799546737756, 0.06343410829348223, 0.004935416908535574, 0.02289262819769127, 0.03230886221198099, 0.025427490838670304, 0.035063755099794695, 0.03476672300270625, 0.011168537129248892, 0.09000940048801047, 0.04269118081512196, 0.04278638267091342, 0.11311257470931325, 0.03637607914528676, 0.03882237430661917, 0.05257205864680665, 0.04765806732965367, 0.04400500442300524, 0.028381269125800048, 0.041738059637801986, 0.06622917045439992, 0.06200298294425011, 0.07609232834407262, 0.02018076291174761, 0.04584550351968833, 0.03280794168157237, 0.012091258241395866, 0.06041472924074956, 0.04605713180665459, 0.009279532108588942, 0.03120337599622352, 0.11074308971209185, 0.04981662293097802, 0.023100154740469794, 0.02544414548070303, 0.02922129038987415, 0.017174113175964782, 0.043028561997094324, 0.07306209951639175, 0.02256851237533348, 0.05451168492436409, 0.043548503025834046, 0.03772248261209045, 0.007976924684563918, 0.019938961868839603, 0.019949082218642746, 0.044790781901351044, 0.0054970072648887125, 0.007052657784827585, 0.05889266662831817, 0.03750076450939689, 0.06747599212186677, 0.026676207315176725, 0.023753012297675014, 0.027227103111467192, 0.02595088561065495, 0.020211006913866316, 0.02070249188026147, 0.024952153309381435, 0.06332947819360665, 0.021241833921521902, 0.038814727216959, 0.0654850210994482, 0.07633191227380719, 0.061589090153574944, 0.03751312741743667, 0.019114048186955706, 0.04781491748456444, 0.03066667854519827, 0.08444202066000019, 0.0446865317810859, 0.05210176602538143, 0.012493640533648431, 0.03908384099070515, 0.0350149039711271, 0.07046775479934045, 0.050230515721653185, 0.013821642130746372, 0.0352593428189201, 0.08129019835697752, 0.015205131777163063, 0.029134295415133238, 0.008381491859576531, 0.017949541298938648, 0.020670219058437005, 0.025876998236136775, 0.030926442106387446, 0.049043520486780574, 0.07166745220976216, 0.01800339492703123, 0.032319783233106136, 0.022102750671495284, 0.02593526743086321, 0.034749203228524754, 0.04345097379492862, 0.005121908017567226, 0.0583437317982316, 0.02279950605173196, 0.04576988757721015, 0.057820560942803106, 0.07063341912414346, 0.1041875457657235, 0.013316504191607237, 0.0523170991135495, 0.04054480491738234, 0.007666785835421511, 0.02424996964899557, 0.005805103723624987, 0.02346413958418582, 0.0290056451755975, 0.04551618333373751, 0.031446603659008227, 0.013830804049835672, 0.02851635018097503, 0.022943226554031883, 0.03200303969372596, 0.0058084891892836565, 0.002430538730030613, 0.024182940567178384, 0.035577277187258005, 0.08376852715654032, 0.041278616791324954, 0.044602770025708845, 0.033335879245506864, 0.09261297328131539, 0.026618372382862226, 0.06762861500361136, 0.0392548589568053, 0.015238235804385372, 0.07570216392299958, 0.0686449518959437, 0.048499633957232745, 0.060507457836398056, 0.034972193584378274, 0.014659603192870106, 0.08360247606677668, 0.019315859768539667, 0.00727881647513381, 0.012447083701512643, 0.023777654993214777, 0.023577376900772964, 0.005573027359787375, 0.04171352720420275, 0.05207084518458162, 0.024795503322301165, 0.024319975803207074, 0.03576559440365859, 0.05064329571489777, 0.03329380668167557, 0.02350520621985197, 0.03286719135940075, 0.06947762971477849, 0.07546661727662597, 0.09167113274868045, 0.06688817723521165, 0.03739315903346453, 0.035114455236388106, 0.03562884245600019, 0.06310444884002209, 0.01975590838784618, 0.019426011447129504, 0.012027344483483051, 0.046304454428276846, 0.03940233175775834, 0.03935812859396849, 0.05137160127716405, 0.042596623567598205, 0.03518869714545352, 0.044452006329915354, 0.014398962625169327, 0.05970958886401994, 0.02030833258426615, 0.07597572888646807, 0.012262601056136191, 0.07533480506390333, 0.04374965133943728, 0.059638899085777144, 0.034918864124587605, 0.04463834222406149, 0.012229382526129484, 0.018678947784272686, 0.027287002486575927, 0.053312893358192275, 0.012696404608764818, 0.02404932345130614, 0.052410139835306575, 0.039692832955292294, 0.005739594560249576, 0.08559766079166106, 0.026927071889596324, 0.1104817587350096, 0.032196574844419956, 0.03485719207674265, 0.041365964604275565, 0.027738045069522092, 0.02491904080047139, 0.056791810252304585, 0.08216447715780564, 0.056608890781977346, 0.04166572780481406, 0.03162270385239806, 0.019721079185338955, 0.014073683115254556, 0.06276827545038291, 0.03938504947083337, 0.00903206953911909, 0.032439001835882664, 0.03955841177542295, 0.050961800052651336, 0.03384595098240035, 0.04742674117109605, 0.027042063219206672, 0.03213269755776439, 0.026651067592735802, 0.013194356013887694, 0.018208667037210295, 0.08410304492073399, 0.016279939728389894, 0.03417465030880911, 0.030422263446130922, 0.04491388172443424, 0.05832072267574923, 0.015284647599660924, 0.03119112165378673, 0.027609942747013907, 0.03829744943816747, 0.022649615969774977, 0.047886665777436326, 0.0439070273589875, 0.008343489657688354, 0.025094584595145922, 0.015868966334632466, 0.03139136751581516, 0.04495599839304175, 0.06525471274341856, 0.009203775370094393, 0.01379670512064227, 0.025759559091446654, 0.026120052872491733, 0.054824167263827155, 0.06928120061222996, 0.036681843988065205, 0.03329810180834361, 0.014719894421952111, 0.0536699758044311, 0.021681714603411298, 0.031671711044119935, 0.04345576764483537, 0.05701844434120825, 0.0336110251955688, 0.018449022800528576, 0.024337921358112777, 0.0355383190991623, 0.06487477384507656, 0.03868403797969222, 0.031170514545270374, 0.024634125642478466, 0.01853946134048913, 0.010080315388872154, 0.028084761197013513, 0.06967791289623294, 0.037518711760640144, 0.05894818436354399, 0.01918960815029485, 0.017720842767240744, 0.02338381121600313, 0.05874782654323748, 0.021212136140093207, 0.005864661710802466, 0.019361935688980987, 0.023941524592893462, 0.019911243713327816, 0.07648218063903706, 0.03784928045102528, 0.08637669363192149, 0.033345012326857874, 0.014218713190140468, 0.0077361541667154855, 0.010826316296256014, 0.03170998041917171, 0.027534467600552098, 0.023642635006191473, 0.04387244921443718, 0.008263157896830567, 0.009942451491951942, 0.02144032407418958, 0.022279295305322324, 0.028707072804016725, 0.03690206592104264, 0.011410850466095974, 0.06472326376076255, 0.0069153015169182, 0.051317369365798574, 0.0249496851382511, 0.03804313451317804, 0.012890881226797189, 0.032897057078246555, 0.053076430689543486, 0.03565539013860481, 0.046506176103970835, 0.048083468074245114, 0.05294110027274915, 0.03597511923206704, 0.0877441248989531, 0.016078559016542773, 0.02053496158415718, 0.08075702589537416, 0.09188205535922732, 0.023547599391479577, 0.017974056769162416, 0.007739089678839913, 0.007271082872258765, 0.017932886656905924, 0.04557538890678968, 0.018631697998249104, 0.023414667595976164, 0.01411146903410554, 0.026546076172962785, 0.0500028366888208, 0.02102984261832067, 0.020986117821718966, 0.05358468734526208, 0.0711237828114203, 0.011195049188765032, 0.023325175612366626, 0.07947433686682157, 0.029215159825980663, 0.0744646517559886, 0.04460949430774365, 0.04775902994775346, 0.06377782020717859, 0.018046738047684942, 0.03139118091868503, 0.045380517042108943, 0.03949047006400568, 0.019025928540421382, 0.04286587304834809, 0.01278607131514166, 0.04030389105901122, 0.06487699943993773, 0.0381751367157059, 0.048954489906983714, 0.020606226420828273, 0.08155963782753263, 0.08550243518714394, 0.018910270550155213, 0.03280277803008046, 0.10731635894626379, 0.09737842649753604, 0.12150815634855203, 0.15559434943965503, 0.12545801725770744, 0.15492506963866098, 0.1649149642991168, 0.10123679374477693, 0.13587333980415547, 0.07884297360266958, 0.16190119673098835, 0.10356659801410777, 0.12512196600437164, 0.07326227413224322, 0.12040145216243607, 0.12311374662177903, 0.1210834477096796, 0.16340538673102856, 0.15431068332067557, 0.17543668113648891, 0.13103239956711019, 0.09454860977296319, 0.10364663121955735, 0.12392838219446795, 0.09823851713112422, 0.17121470054345472, 0.15656379956219876, 0.1802066330398832, 0.149109332423125, 0.11076897582305328, 0.1566061537180628, 0.09937795384653977, 0.14117461176855223, 0.17563235706516675, 0.09424859551446778, 0.10770768366221871, 0.17443873254316195, 0.13264092111161777, 0.14865959941276483, 0.10384218501193182, 0.10631684293704373, 0.11353246574955327, 0.16205700194197042, 0.14091260225645133, 0.11575607928846564, 0.18784400607858384, 0.10488374305090734, 0.12105872189360005, 0.11289485317787953, 0.12885111304266111, 0.1336396975176675, 0.07573033669697386, 0.08323921555919306, 0.08487278861658913, 0.10415786664400782, 0.06629122926720551, 0.11487265383558613, 0.09245991613715887, 0.13074984401464462, 0.14105631597340107, 0.08157909142651729, 0.15606179221400193, 0.16871557464557035, 0.13359789976051875, 0.12806979353938783, 0.18220500009400503, 0.16878880214478287, 0.12370392281029906, 0.1922060770115682, 0.16422591198767933, 0.12732157297432423, 0.1427044639629977, 0.15835984104446002, 0.1251660572098834, 0.16027782884027275, 0.15474733417587622, 0.1994088619415249, 0.19932967690484865, 0.1356088197124856, 0.1511088122746774, 0.18560756822781904, 0.11901509655373436, 0.25063818799597876, 0.2314874870436532, 0.13671811590237276, 0.09697375499776431, 0.0732371344098023, 0.0863598727488092, 0.11853330954909325, 0.15662284567952156, 0.16093831482742513, 0.1022129070812038, 0.10450132749974728, 0.12772292643785477, 0.104815034594919, 0.16946815140545368, 0.11673196192298617, 0.12105550563761167, 0.10579727510256426, 0.0725692795323474, 0.08016611010368381, 0.159677583192076, 0.10381637353982244, 0.18602188171020576, 0.11857710219919682, 0.1286988497844764, 0.15206640160509519, 0.18366344326308795, 0.11631217944834914, 0.17247588001191616, 0.1054786214871066, 0.10269516227500779, 0.14718890190124512, 0.1347420455089637, 0.09881567223263638, 0.14740626380911895, 0.11932887828775815, 0.13308659648256643, 0.1328702795186213, 0.1391984328095402, 0.12973463349044323, 0.15371969289013318, 0.07522278571767466, 0.07484720301415239, 0.11913037965340273, 0.13455536695463316, 0.15385387997542108, 0.09493707785648958, 0.14263085648417473, 0.19756281242838927, 0.13116000486271723, 0.11592641871954713, 0.14702281009938034, 0.09038220798330647, 0.12261636688240937, 0.23817909083196095, 0.18002950825861522, 0.1078132637111204, 0.13441485592297145, 0.24560527663145745, 0.12773170668099607, 0.11126380427075283, 0.06727567501366138, 0.13062907835202558, 0.12006846788738455, 0.13733121300382273, 0.12237976172140666, 0.127041650137731, 0.16507534283612454, 0.08229917992970773, 0.11279988541666951, 0.20726935086505754, 0.09629864658096007, 0.09716377194438662, 0.12500322237610817, 0.13805451776300157, 0.15352702965693815, 0.20587459499282496, 0.17532572709023952, 0.11002659065915005, 0.14020874431090696, 0.08553455703492675, 0.14306161765541348, 0.13390611750738962, 0.09466677664646081, 0.10957530380359717, 0.05925119774682181, 0.12517238115625723, 0.15834591750587734, 0.11351163472448077, 0.16882792647395814, 0.18605401712868894, 0.1322499628045729, 0.15871177001723222, 0.05280645517632365, 0.11219350581190415], [0.013420778908766806, 0.028150979429483414, 0.06194574173007693, 0.006214874838146248, 0.02235118269787303, 0.00985233101528138, 0.014707847032696009, 0.016153284381808977, 0.04508153415684189, 0.026763828238472342, 0.03353430663368531, 0.058407995849847794, 0.02464411367795297, 0.04973842516275389, 0.054557567462325096, 0.07219856871025902, 0.07332844486726181, 0.07681996215667043, 0.0031635781342629343, 0.020362445752003362, 0.03206244882728372, 0.0440931291585522, 0.03998557671106287, 0.0917973199060985, 0.07225039521498339, 0.033023094957960505, 0.01472463907807001, 0.023956403169514875, 0.044276679666446786, 0.061805033923259804, 0.06907265965959855, 0.013787802741197603, 0.04214215777548296, 0.02806831181182393, 0.017093922211123363, 0.03331093629822135, 0.04387215744437916, 0.029330816119909286, 0.035131662884461026, 0.02754049129518015, 0.10145203862339258, 0.06190597279263394, 0.030870167804615836, 0.025115093316084573, 0.035621110549462695, 0.03802280221134424, 0.06542042456567287, 0.08394185214170388, 0.03655591467395425, 0.023977490341556922, 0.03434535275612559, 0.009893991369088846, 0.03384243617100375, 0.02797920659317502, 0.007075123231126261, 0.007386478778373982, 0.05663643930373447, 0.09444379646863256, 0.0811111872483577, 0.07357089221477509, 0.036923829931765795, 0.0868038721382618, 0.07836197369865008, 0.005631412753635752, 0.048416574485599995, 0.041835673685584746, 0.041053475479462316, 0.020151696167886257, 0.004432193286317799, 0.031368965682174475, 0.031877459825149605, 0.033098968743745766, 0.05027463406856571, 0.07918005622923374, 0.044619292353412936, 0.05234490887128881, 0.022425159978281175, 0.048959355003067424, 0.007151512279441314, 0.0424631353733795, 0.04623786300154669, 0.04149520177660244, 0.026998496181996803, 0.012231415586679109, 0.04113668083612408, 0.06106083707085677, 0.034728457020329576, 0.016172627718853097, 0.014606947179085441, 0.05956409738532134, 0.027785566269553134, 0.02334724666018571, 0.05183608903150473, 0.03911930462345481, 0.058463466087622304, 0.03224438442183392, 0.03469769224258406, 0.013905593027759875, 0.04801175710079925, 0.026916680125785724, 0.03423774728019323, 0.027018431540844694, 0.036135660617479255, 0.08304303072925125, 0.03446463581972888, 0.048368310289723535, 0.02169317675621382, 0.07982507161796093, 0.06794369952487093, 0.015524558922541993, 0.06443701697779552, 0.029612628676529442, 0.01880423927546612, 0.030357941719038144, 0.030419210038547004, 0.031091729844255105, 0.038433889259717295, 0.041241239689822705, 0.06000999667282615, 0.024494154046156576, 0.04247124047417726, 0.028651463466563394, 0.07464054838887282, 0.029853902158460448, 0.07454319218439714, 0.046207620695765526, 0.027854649616139274, 0.11113499796816281, 0.019924522643642764, 0.015737147336559634, 0.0214091861021838, 0.024832848193390027, 0.04334136664069124, 0.03588504370834146, 0.07055132995758738, 0.05733935747827802, 0.02057989756576717, 0.019882166791441183, 0.07092264467584235, 0.06580241942512137, 0.018765231993581568, 0.032178105121212344, 0.06334945426455565, 0.1055926289409399, 0.045567874131458144, 0.025630294777719036, 0.039051440943564684, 0.04259684748415436, 0.02681981077018593, 0.0333641775484596, 0.020342447628666247, 0.02443134375581784, 0.034788622720433135, 0.030003325747592107, 0.016367945720308592, 0.039761507484529696, 0.04606939971979175, 0.022377245227939317, 0.01740646731507565, 0.05448979877733758, 0.052020908399884186, 0.021496706941564168, 0.0358398430980742, 0.007330003460603101, 0.022857673466205597, 0.01158058176016701, 0.026928788583193506, 0.021245170617476106, 0.06446893526507275, 0.02105293655768037, 0.0888394975502576, 0.03806333110800811, 0.018246310463707362, 0.00864358025137335, 0.027699746856732026, 0.04453584950949464, 0.04667895147576928, 0.02491242847671466, 0.026125745781298195, 0.05711480309920652, 0.045522826191570075, 0.061586382798850536, 0.016666436667687128, 0.04662599181756377, 0.016648755741438696, 0.04374182443799717, 0.029010832575815063, 0.006502812021478478, 0.026823590210239803, 0.014392528416854995, 0.03949740808457136, 0.017178393035594906, 0.08474066427775792, 0.015244086472583669, 0.045835864929748435, 0.041217243298888206, 0.016860677494800518, 0.018781525315716863, 0.028681393646235977, 0.04526931872325284, 0.018391296433817064, 0.022721594964553202, 0.03946333884128502, 0.01155122324624764, 0.028410849859938025, 0.031099241226911545, 0.01607306457922927, 0.04663161008751818, 0.06887537560292653, 0.016140675504824946, 0.04657835865925465, 0.02676949230954051, 0.020076278696901033, 0.0732744809772287, 0.014075727201998234, 0.0572886641270348, 0.032168564918850145, 0.030602166828300272, 0.014721675576376063, 0.03832339661728058, 0.07659244257956743, 0.016908673669344614, 0.06655714035566364, 0.021210388912420188, 0.042791315620498996, 0.03128241854054587, 0.02574497228488326, 0.02983047573694161, 0.04086947713845542, 0.019439356534608772, 0.023657420284247825, 0.04219621666041868, 0.07739394849964551, 0.031299188533531766, 0.052471218165010214, 0.024056052822353582, 0.03001229598053864, 0.023830769018137028, 0.024965601873451045, 0.0287557814403304, 0.05673388371776257, 0.023082533186035495, 0.018546663989712085, 0.009141006640025547, 0.019599558652511666, 0.02966572404173868, 0.017676247749477625, 0.05816619311060224, 0.02751058995324586, 0.005795946893548327, 0.011309978602054929, 0.051624331822884936, 0.005596472016934837, 0.07675601023116282, 0.009583512404268342, 0.030418205806719403, 0.026966376030551534, 0.015574865508824587, 0.02326155616901815, 0.0174036310386977, 0.05283311142453125, 0.06618544565779821, 0.02833019070593374, 0.04097296729949968, 0.004965056166318911, 0.056083450226911476, 0.08682876080274582, 0.08771286479064397, 0.009457355780926133, 0.013465027025501643, 0.043226490662034066, 0.04801889528919544, 0.06436879028167043, 0.04547575282465134, 0.08416542264499835, 0.04505896608212164, 0.04758527070017798, 0.03891141167176621, 0.04920473701453634, 0.016371297683300715, 0.03554428342197623, 0.06079910575811352, 0.04726558231881686, 0.0396249014219003, 0.04766418432284679, 0.05948363670281001, 0.03963632116626416, 0.09941545647702046, 0.05043047659897378, 0.020679550611280968, 0.024721444617690783, 0.02409257666606988, 0.07665296111788068, 0.08216816160295691, 0.010770382958331277, 0.054304792811828, 0.023618099179917147, 0.002240174458295639, 0.045340503832059245, 0.03325977815049035, 0.02646065709580268, 0.0833754993176886, 0.035019192312444956, 0.059000899749142785, 0.013542290111737592, 0.039084424530821185, 0.02902774845382997, 0.02547216897697321, 0.015884901729545424, 0.014614992908069065, 0.1013784786420209, 0.027295397661094154, 0.035481342513646395, 0.09393613692373037, 0.02806379446493728, 0.03351774359388011, 0.02926431968808174, 0.027760083886927793, 0.05776476500821965, 0.03502416258145656, 0.0494075307755598, 0.05223126104101539, 0.045376720638679605, 0.04277839631374393, 0.017881738687200204, 0.008628236030095389, 0.02454479311459831, 0.03451003320515156, 0.008122442456494485, 0.064214281072574, 0.024808940012007952, 0.03422293146806104, 0.011890400001513106, 0.044052936136722565, 0.03141826464395438, 0.0516786655145032, 0.05603375771482076, 0.03389156889170408, 0.029767137885625874, 0.05938873679510184, 0.018874204717576504, 0.04092671835262861, 0.06565824430435896, 0.018147573440468738, 0.027668646204152277, 0.04221782460808754, 0.03370712271758488, 0.017034496114190136, 0.026430263815979873, 0.04634483404723661, 0.02454181434586644, 0.031844404991716146, 0.11768014675804547, 0.08573764256600823, 0.1451273632368871, 0.1041495478046792, 0.13141844528062002, 0.08932676711784941, 0.08728133008948394, 0.1274543215653726, 0.12205460774047033, 0.08651698074702706, 0.15696602155055317, 0.08944555824356419, 0.11901067250541278, 0.12635304565940583, 0.16758396822427, 0.11439769289323262, 0.21967711006956442, 0.1540629637560674, 0.15017085974769934, 0.1272781603038311, 0.08072662752653871, 0.0884519387036562, 0.1537022545401539, 0.15841826290956565, 0.1894899420440197, 0.10489960041429315, 0.15816385298967361, 0.09682709643883364, 0.07354718420122351, 0.11108332752649273, 0.10833339472966534, 0.08246233367494174, 0.16116451126124176, 0.13200469953673227, 0.11368766706436872, 0.1703607099396842, 0.09448342291372162, 0.16380942719323294, 0.10017969725387436, 0.12056641759616987, 0.23584634172064917, 0.15523924492299557, 0.0797585209033319, 0.17105846107006073, 0.10086554688002382, 0.18751201246465954, 0.21071444957384042, 0.22670993554805005, 0.07699408781315599, 0.12009954479123865, 0.10963581555656024, 0.09004381578415632, 0.12855295118476662, 0.08305915950664453, 0.20175058128578321, 0.08423431430544172, 0.20501138988350118, 0.2225584276020527, 0.21898036317101546, 0.20025401801935264, 0.16923241476927484, 0.14628753598247254, 0.14117641667170183, 0.08173191786876746, 0.11960880112435136, 0.1675191952713898, 0.13984794010009083, 0.11947769458804812, 0.07584148073302847, 0.19160672702959605, 0.18122583334999426, 0.13236258604696818, 0.09142513666301966, 0.12063285974519593, 0.13796467972653254, 0.14324574491807393, 0.16364946934793675, 0.2039356268942356, 0.13141395337879658, 0.21240462602249213, 0.22084941502128327, 0.10073393144245658, 0.13107410232935632, 0.08848253384764705, 0.17286507412791252, 0.18084674940577575, 0.10628103664410965, 0.11809778506202356, 0.15889372596783297, 0.16552582223500523, 0.16443013745759213, 0.10609007653381143, 0.1606181820056268, 0.113216119153159, 0.1292257457971573, 0.12705166531460627, 0.1792744073484625, 0.15300066290157183, 0.1442820985934564, 0.19252528702574118, 0.14549868474049227, 0.17549396306276321, 0.14001382834145001, 0.16255671584180423, 0.1532375801886831, 0.17148382110255106, 0.14067644492856093, 0.17639178702873842, 0.22320456935891084, 0.1506608977381672, 0.1547240875661373, 0.15137192101350852, 0.10383713671139308, 0.11682718752750329, 0.06834134140184947, 0.15525592331375393, 0.14893653669527598, 0.18264990193503244, 0.14498193961169037, 0.11958187685481139, 0.11673543602228165, 0.08786903641053609, 0.13754347232835634, 0.18094390204974584, 0.14811700209975243, 0.08708862614418779, 0.06322921785925116, 0.13884125197572367, 0.08680288826248475, 0.09608429058321885, 0.15928069448896817, 0.08632193585591656, 0.07621428144297429, 0.24514672266585485, 0.1778857854327985, 0.22367695186819347, 0.11987128561096531, 0.14179570201252187, 0.11517716678125517, 0.1550072402294193, 0.1422052386083773, 0.0795257223237838, 0.12498068144278866, 0.11728510367018835, 0.19033859936254366, 0.11817065972302641, 0.15807784189070972, 0.14646468790514128, 0.10711459655846868, 0.11462520568498544, 0.13567444761948927, 0.12936120852828026, 0.05153258031766329, 0.1718419518853937, 0.1582257082419736, 0.08883520242358957, 0.16863571107387543, 0.09059439945433821, 0.10510126780718565, 0.10797962692699262, 0.12614541394369944, 0.0810619934595057, 0.06492710925106492, 0.09956655265497309, 0.061182763028357706, 0.07746068920407977, 0.18922563908355577, 0.10883458783583981, 0.14572085067629814, 0.1591838946832078, 0.13987224522445882, 0.10041725914925337, 0.18000377821070807, 0.14536323558006967, 0.06511812364416462, 0.14696784876286983], [0.03605547813432557, 0.04336250300652214, 0.04981967633856194, 0.05244363571650215, 0.04202115123293229, 0.028929639075483595, 0.03794934061755027, 0.03182412018733365, 0.02476999719095017, 0.005254355084616691, 0.054318461899778674, 0.03438467725313135, 0.0320132109336555, 0.01906703588818865, 0.02250497435618724, 0.05028740409761667, 0.061687287741473744, 0.03292584392641272, 0.03146721416019967, 0.0739099018807922, 0.06679759281022207, 0.044787507969886065, 0.01689494351324226, 0.032901399702365906, 0.01312300466400172, 0.03281233519581812, 0.02053500059992075, 0.026529357070103288, 0.012760224219943796, 0.05096193915233016, 0.016175662466724004, 0.01887695787341467, 0.059882289596966336, 0.05326167753498469, 0.030869550337748866, 0.02303170073511345, 0.04767587208854301, 0.052228560471641164, 0.03147852533896055, 0.03300377367330449, 0.06719816595848117, 0.02625987519110952, 0.06650614166366202, 0.015810836239584854, 0.01816273869813553, 0.05038952701059835, 0.0739458981635315, 0.028412547893822193, 0.09628836677542754, 0.020510714135265777, 0.0234107100404799, 0.0558155069260725, 0.03977271688303777, 0.05457727211926665, 0.023826268634625843, 0.018411335269255296, 0.043579559573637586, 0.0345064980377044, 0.07724813810948815, 0.022499289929068515, 0.03042455010914377, 0.07107321838183062, 0.051127997027443986, 0.07200679435793843, 0.01956757590440767, 0.12244106057499136, 0.06245087033935955, 0.02172372949176601, 0.013604262411328298, 0.017159180316541876, 0.028327306932104484, 0.011240439788837518, 0.024308203220633522, 0.042174822451280694, 0.08926738851836749, 0.03477271107424583, 0.038045631522046666, 0.011208092328161001, 0.02294347930832633, 0.03608163565929447, 0.07387076398091656, 0.02765894145704806, 0.04329360795340367, 0.08207019471696445, 0.06927269178309611, 0.018966129249227897, 0.044333289843052626, 0.014912678095112954, 0.043741695516343625, 0.041233419573732784, 0.0071716495024572524, 0.029035039312605346, 0.022894886022965823, 0.10402719437011651, 0.015262132111404623, 0.02037646428548864, 0.018872929071741443, 0.04125436255708337, 0.012996630909453546, 0.020134895640824522, 0.03431553792740617, 0.047000319231301546, 0.03073982462020857, 0.05132005975714751, 0.025352326121979525, 0.0842476271625076, 0.006683633970429322, 0.053664299859000106, 0.040852663040693314, 0.020107745758390853, 0.029564120208046267, 0.017366715341008136, 0.04827924578317574, 0.03219604558710541, 0.008440711003329073, 0.1537606899759599, 0.02805422542483679, 0.03484366887382098, 0.03360583779535123, 0.04119469218754342, 0.02545746342678155, 0.08775838770504509, 0.04178359951557858, 0.0358397922079478, 0.029075724272323505, 0.02268618391826749, 0.015860216625566994, 0.012434864982164331, 0.03546466751556311, 0.0462594946979412, 0.046549280041030476, 0.0336767413121249, 0.0402015374441232, 0.03998499995629702, 0.04502052028796502, 0.10892682788627488, 0.025752409028687646, 0.045713684521615505, 0.035599726518349986, 0.02168519888073206, 0.06680796761065722, 0.04544978868216276, 0.047086126769759824, 0.033504362883312364, 0.04360769163551075, 0.0654679084462779, 0.07429492979177407, 0.050013832348798, 0.06930847771997962, 0.00982193773545857, 0.011355085065588355, 0.032931367201464515, 0.015514185818444406, 0.09154246893844434, 0.035514322708227804, 0.01846641026038144, 0.023803519051788107, 0.0016137625914000506, 0.01466344200473811, 0.028964777011424303, 0.02669715029852731, 0.0351394083616989, 0.012633093898849828, 0.04861393318112407, 0.022471220631684576, 0.015907737825598036, 0.022019452016268457, 0.024822061182931066, 0.03910224625308599, 0.031240776846451417, 0.020888980444786803, 0.04531759309715458, 0.0626878079825214, 0.07216827890702657, 0.12384074261145932, 0.03957918851769396, 0.1073593780664461, 0.034117395523935556, 0.023635866619380455, 0.025457253080925772, 0.021751749595361095, 0.024620314062173878, 0.023888398693608384, 0.046668162768972773, 0.07483496902776615, 0.03947940315785153, 0.02240698711414422, 0.05153541320136615, 0.02136389728236411, 0.0450614970177412, 0.10259980096348695, 0.0745381981666599, 0.09033349595431771, 0.05610557386119451, 0.02204576221161655, 0.07118339211280857, 0.06286246968167168, 0.03325268067419529, 0.018011108173855712, 0.01668121855306838, 0.04279430117458105, 0.03195381197812302, 0.023102985927835107, 0.04423474959496941, 0.0045174041380440545, 0.036496064492634366, 0.041725764583264074, 0.021964124270847867, 0.04974401968398264, 0.05514898876260434, 0.010531805804930627, 0.07091675499188048, 0.03717121362153973, 0.07340585214218923, 0.02572750679350325, 0.047773275790469985, 0.07541752526802675, 0.03707336887185063, 0.0355057901303683, 0.03710537197600518, 0.018776142836681435, 0.041434058986072025, 0.015527059324085712, 0.002228124948617603, 0.048729647150529284, 0.007797266423170055, 0.07280763531369822, 0.050350039665188105, 0.04621690644749573, 0.046113748768610616, 0.06612677273473569, 0.04674648606617536, 0.032306290564260313, 0.014990950502189142, 0.04956533427217177, 0.06543462630361319, 0.04354490679023521, 0.03244316804089716, 0.009088316699489951, 0.05805856388594423, 0.04458955216354557, 0.06196564994752407, 0.029042889962771108, 0.019798303255811334, 0.02842773011486445, 0.015195801920656647, 0.08689406979829073, 0.04202143961031522, 0.02932535730568426, 0.026119155509929572, 0.12527412069695337, 0.08604839124849864, 0.03378644685393997, 0.04655308322981, 0.04254294126959784, 0.025168483844026923, 0.02676628453523985, 0.026825403595077138, 0.026706313913954154, 0.023030525173193643, 0.07276194276554243, 0.045908111945859024, 0.031432313711515496, 0.014913902850821614, 0.05562998866662383, 0.013864275334136826, 0.03330178964616997, 0.010969303980735796, 0.007140631122248513, 0.06751521823129483, 0.04595505978379931, 0.02260773000307381, 0.09513629573796477, 0.02917591336050204, 0.04285937946821962, 0.04657109494188002, 0.0210780728874462, 0.04571440037606018, 0.0695086455504809, 0.020581882280696715, 0.004475435050803104, 0.009090762818232179, 0.03926664850275431, 0.035016929398157766, 0.04689314462510603, 0.08396439307502337, 0.0747054706194571, 0.05204069787370307, 0.013844656342241381, 0.06719732457505805, 0.03907861966373665, 0.035694070027342865, 0.025197470860023583, 0.027302966719227176, 0.010776343888470104, 0.049962609740240235, 0.11529542186430522, 0.06405572779476643, 0.08186608459800482, 0.034452317016465325, 0.05094335407816938, 0.03712772970486965, 0.02233297929966024, 0.009638960589654744, 0.021972153036456023, 0.018909161145399724, 0.04788023665813463, 0.012619056705651539, 0.04082342835941485, 0.008578646146426243, 0.018096993743841137, 0.045899521692522934, 0.017673369064661007, 0.07681322430393525, 0.013063533614123506, 0.008255158817129475, 0.009910291476574327, 0.0597185455262661, 0.08999285780425582, 0.019818991788529923, 0.053989810070821216, 0.03686917393601366, 0.060886731770421774, 0.052194701574210606, 0.03367255814373493, 0.02849794491859419, 0.013742060999252965, 0.010073310362973383, 0.05279166650559221, 0.03916145182613816, 0.008063071490531521, 0.037495627999305725, 0.03372881548213107, 0.030528233652668338, 0.032359162012913396, 0.022831422642671635, 0.04848917433992028, 0.009929327776522508, 0.0555901925877801, 0.038468029749180586, 0.0181602416892669, 0.04305020387151411, 0.06217085250786372, 0.06958808843046427, 0.011459975553277348, 0.044133491814136505, 0.04995669970022781, 0.038267274985888174, 0.03057231128747974, 0.0353309316560626, 0.060885049003575525, 0.021511332763891135, 0.16477407328784466, 0.12940192062939915, 0.16779560329658644, 0.13469851070216723, 0.12023734168282577, 0.13883348953511032, 0.10012263924415622, 0.11907140138958182, 0.17096330331904547, 0.14174732246569224, 0.15140525065362453, 0.12747275057647908, 0.1183678148580449, 0.09013369453272649, 0.19640515026237282, 0.21129638834723405, 0.2652710942285401, 0.10958878629441772, 0.10044301633856126, 0.16769410802849702, 0.204748715407082, 0.08948406510587249, 0.10145086475781032, 0.07806753021265779, 0.20580442090119633, 0.18048814364842006, 0.10610910265573434, 0.11712091176637582, 0.10139124188572168, 0.1477020779358489, 0.07845745714647429, 0.11432792592261519, 0.17117529122957162, 0.08382852322288922, 0.12002918070980481, 0.10325924879206078, 0.1332087056445224, 0.1368135857794966, 0.10579759401402303, 0.1427659256649869, 0.1413600689598492, 0.06610933438475643, 0.19063513273639338, 0.10987002548894712, 0.10941198720995869, 0.1296130535858018, 0.1703855036092656, 0.15721671309854302, 0.18668612678136143, 0.09709426281707627, 0.18534129751580103, 0.18838197578276905, 0.09352647819157157, 0.2049302099538701, 0.12215507163533143, 0.1854926651077611, 0.07869098854384252, 0.14591242825346334, 0.11898562099252429, 0.06952451648456709, 0.1866862489176648, 0.14185109761144432, 0.08835319828774248, 0.12513398964490208, 0.25318760690944536, 0.2115454649818795, 0.14793952448027475, 0.1060074106124895, 0.06461978717041866, 0.047953952702560594, 0.09829465911856719, 0.061908171246094365, 0.10769835380571229, 0.1231634153851441, 0.19389869618628705, 0.11516711089227881, 0.16200927378875868, 0.06717833916523627, 0.1440265215933323, 0.10807172448507377, 0.15785039695245878, 0.10465022522423949, 0.06977595442107745, 0.2166222504207066, 0.17375616702650273, 0.13200734582330498, 0.16277866464640411, 0.0893344074221594, 0.08822249208710023, 0.13216350387249673, 0.1091025277440037, 0.12932019787175314, 0.06427526780005012, 0.22872001411659376, 0.11667724485908236, 0.1326688631836857, 0.18198959236698492, 0.064801654911467, 0.12515720911324024, 0.08411567245743104, 0.22082075370209558, 0.14896818356854574, 0.11065363844058343, 0.13884849872972282, 0.12856008937316282, 0.20112509413489274, 0.13893037076507295, 0.12914562438215527, 0.13632508127817086, 0.09889936952718667, 0.16080574265548161, 0.08467688198600497, 0.10080745749707733, 0.1635409173156534, 0.13555913737842015, 0.21534615675253527, 0.14876444664384636, 0.08115799259394407, 0.10916210311864104, 0.24685627807463917, 0.2505019653056349, 0.17221498329724583, 0.1272014044225216, 0.10515789155449186, 0.13409400385405335, 0.1471634025552443, 0.1760009237165962, 0.16244962944516114, 0.14902627973684243, 0.10110301378050021, 0.11981055672679629, 0.12580595644457, 0.11117193741457802, 0.15601225915764058, 0.08165242070598261, 0.21902686996119364, 0.12918459943362645, 0.25643876673919813, 0.09585592283734254, 0.07058577918048416, 0.13150699410055364, 0.09723087227238075, 0.13264781502740725, 0.0614193749747106, 0.14868205892188208, 0.1586025394499302, 0.13434928229876927, 0.14478827214666776, 0.10151851469916956, 0.12924283130892686, 0.14752529242209025, 0.12236957012542657, 0.08751483434545142, 0.15793267610882009, 0.051650553808680603, 0.10940268449485302, 0.12900115070598467, 0.04785004184980478, 0.12414653120296341, 0.1288943492940494, 0.13567200489342213, 0.09034008452934877, 0.1461093391158751, 0.12673534585961274, 0.07972032616713218, 0.11176923822079386, 0.16065460576542787, 0.10550576967320272, 0.07673675340733357, 0.12763748530830654, 0.08318625590098755, 0.11604744222547327, 0.17815778298037394, 0.1493724411619561, 0.23699309304356575, 0.11403273604810238], [0.017760981506268893, 0.07435177067028624, 0.051745009275951555, 0.01163491205911019, 0.07029893528670073, 0.026240855854536806, 0.032795307359525135, 0.058399636298418045, 0.01813562274245279, 0.03011702446799193, 0.060782366299203465, 0.09617634742919888, 0.07081447262316942, 0.0032871285470069517, 0.030638461666447774, 0.01047602598555386, 0.05984592690531697, 0.05758176411369017, 0.020233607218999947, 0.08443347111876522, 0.02827831500742052, 0.06312068618301835, 0.03888969515849437, 0.03807652861412082, 0.051859111724687476, 0.0338696216765259, 0.04632519385112183, 0.015953759463237863, 0.06472289735185248, 0.040986836555280855, 0.03369779286107846, 0.05603609526796, 0.027090775248195444, 0.004770323825401387, 0.06816456945879118, 0.0041368354743878755, 0.0041014176427519745, 0.012194107186847498, 0.012037858383597007, 0.02596231722938163, 0.013440429282906865, 0.010920766674514328, 0.007892801609289433, 0.08019089698791504, 0.0518563365164612, 0.09245828086776392, 0.0141612777453182, 0.02746221549542887, 0.03464448831177183, 0.004521809526652629, 0.005753029553618814, 0.015545135496982505, 0.020210755855909417, 0.04719997137518866, 0.01610109655718718, 0.02990492120651262, 0.08791517679180418, 0.12500248955828802, 0.028432708865563785, 0.013485258395251418, 0.035161162194396765, 0.02457024496314781, 0.036736937638904364, 0.025578507288758243, 0.08220791696969952, 0.04514329780691436, 0.08861829513417822, 0.06590410468301602, 0.03089304461276957, 0.006787144063439752, 0.03198880063635962, 0.020702139042051773, 0.04433054856157728, 0.024141624569892883, 0.03934807949034231, 0.0502433603895562, 0.016004819223391156, 0.016899454074778726, 0.024057878081553748, 0.03193125747410314, 0.04355354454102261, 0.0343781802803278, 0.06751202911670719, 0.08942636248788663, 0.01872487273067236, 0.05778663419187069, 0.03151555638760328, 0.057463427606437883, 0.07185990509710141, 0.048340375003005774, 0.05296048601823194, 0.026514738033126508, 0.02947103198883789, 0.0516750014254025, 0.030482971974249398, 0.047838377832834206, 0.02574111142062715, 0.051455020372356684, 0.015659312584570477, 0.02264094938124929, 0.04751190749396171, 0.03422833939215966, 0.02240588279840137, 0.03501173521259001, 0.010529711676229323, 0.0094569087959826, 0.01953140998791371, 0.048063916087682755, 0.01171942614018917, 0.051098999833422046, 0.043917079855288775, 0.020482521005240933, 0.01953514532319137, 0.026349326462617943, 0.015555128621469651, 0.02169933106883296, 0.02951466179053698, 0.03398359859628337, 0.022895311803690026, 0.0473893131794674, 0.019813690733696734, 0.023819747913096632, 0.089719462474542, 0.03568770536886794, 0.0407431780227593, 0.01897532509506813, 0.04192763214398708, 0.04957409755193761, 0.016140232760725275, 0.01835172766420458, 0.02770615222730807, 0.021546899873231138, 0.050397913703428845, 0.03581425554252096, 0.017904364437397038, 0.039380866302443404, 0.022880122797297578, 0.06475026945450477, 0.049979556152330976, 0.03436061300869499, 0.05199803837708064, 0.026623539427029233, 0.019932057775024856, 0.01536971383861133, 0.03973646614966648, 0.07459303058151688, 0.026228491250159483, 0.030545746641499654, 0.014567715980644737, 0.02929610226835523, 0.024383473110252192, 0.025542575466845716, 0.08336106687784195, 0.02473767856801195, 0.08906293913189854, 0.033256056385913065, 0.0279028069427503, 0.00488561879943258, 0.04442586576832192, 0.03760836659265416, 0.03841420156615121, 0.05112755258700677, 0.03418927273846098, 0.017766894938956414, 0.030425435597343103, 0.07729263643601111, 0.03429043891706637, 0.06047783978283405, 0.05490716566730823, 0.03198683627748063, 0.06562055168407303, 0.03462103474885225, 0.030112468105341707, 0.03138779502894197, 0.04161686649812119, 0.008257022243924439, 0.013302079385279544, 0.020262053103319237, 0.04714222465242658, 0.05531475826033524, 0.07581991689013583, 0.02963983453810215, 0.04397682147100568, 0.04839143476315907, 0.03367273456283978, 0.016870707938713685, 0.024069791460143666, 0.05289479025772639, 0.022107396940035478, 0.029061556461134126, 0.03061850255887423, 0.03896479880703347, 0.0328334783469992, 0.059619384418640814, 0.06781833339482546, 0.012316804977932146, 0.044054842820124965, 0.06742259820124932, 0.019987967364223938, 0.035639329214713404, 0.037741817467446835, 0.08708090441567556, 0.011193884653039277, 0.03412950398134334, 0.015252707259995597, 0.010427839821204543, 0.004495503148064017, 0.04545588871198041, 0.03237976233607956, 0.048471013350146155, 0.05146526285846319, 0.04605273829240884, 0.032257446220942905, 0.0306846868645932, 0.04395342558356268, 0.0739425869126405, 0.024454011914453337, 0.032965450015451224, 0.056889899274600406, 0.029464507874633585, 0.03464377585000225, 0.0802232970350555, 0.016159937417666827, 0.05350083738033261, 0.031672589746969085, 0.0377639750284808, 0.05925854628107377, 0.024323130991043787, 0.033471423400832076, 0.0409070408370878, 0.026087812281080654, 0.059896219920899184, 0.06870456119733197, 0.05912636087409087, 0.02606897445262543, 0.018299163252647434, 0.022705851255783012, 0.07563716705356326, 0.057351320050656796, 0.04655308322981, 0.035730134163584025, 0.03765086324087211, 0.05697066190519503, 0.06593937493328537, 0.031894294278962274, 0.05773410201072693, 0.027738799939730337, 0.01821630903785782, 0.0040611830606524435, 0.015964025698070015, 0.03900533788172262, 0.013260221408147897, 0.005392571395662214, 0.02315084809171302, 0.04719841413732086, 0.029724200189645802, 0.067277771686869, 0.048932885351989946, 0.05691338337159582, 0.010175479077068823, 0.01781594453911696, 0.040885795905653916, 0.047517155962330956, 0.06317773062203612, 0.10379848735673086, 0.009426290751434863, 0.05761398774172578, 0.050959459106836996, 0.03442091441580227, 0.03221084104318704, 0.02483721965524767, 0.029812867753207684, 0.05265207149620567, 0.04739692634237664, 0.02744185265951923, 0.020490960284535373, 0.046022957390440364, 0.03437855686726315, 0.011192949122882314, 0.04338293369593365, 0.030846758346472467, 0.05181264903928552, 0.028014334351090447, 0.017025154383320893, 0.013233010457562549, 0.03482504648023418, 0.03565106787053602, 0.0164901871965932, 0.048245810970131836, 0.023425542815987552, 0.029072979598173072, 0.04258862024705325, 0.03348032578027674, 0.012649711221456528, 0.04620077767010246, 0.044223401096782515, 0.015239265481276172, 0.012407737152118768, 0.05256049641008888, 0.046642704135073085, 0.04991279848452125, 0.09140213432588748, 0.014112781999366624, 0.07438860155109848, 0.03805411660245486, 0.020137112753997956, 0.026014725577884486, 0.05422143139211195, 0.03944066559363689, 0.022846823691257408, 0.04223396356350609, 0.02044298785871693, 0.0733873417068805, 0.010131159714157028, 0.02735485089942813, 0.02976910224450486, 0.019675300123968294, 0.022225806389802268, 0.04896087831418429, 0.025767090830153654, 0.03219927202111908, 0.051001304361437044, 0.01106523780617863, 0.019928755005821586, 0.041936263109424284, 0.052795238992465396, 0.02928907603823713, 0.037056931361023865, 0.05643087372715984, 0.021125873983172432, 0.04986441893769162, 0.039425710681825876, 0.016299240656995347, 0.038606016630572934, 0.017244426367272223, 0.055573015473783016, 0.03745107878265636, 0.06242936756461859, 0.01010888595400112, 0.018239253699513416, 0.04201048466243914, 0.05759218641157661, 0.08601737541279622, 0.021019637451640198, 0.015139173084337796, 0.014808012372148889, 0.05766514249678169, 0.018472875002771616, 0.014150192179451031, 0.03606445515262229, 0.025789658904873898, 0.041087914524333816, 0.10501679019736392, 0.11380513504679714, 0.1119906577680792, 0.13548653413142475, 0.176611686657582, 0.09310408335711275, 0.11576747867677893, 0.08738273036267076, 0.12890787928232125, 0.14552531045462402, 0.20023381124649728, 0.13936403606619152, 0.10656743270478078, 0.14830076295350278, 0.10255817284009286, 0.10894130782357284, 0.12171205612165586, 0.14083632134965487, 0.17871502307908876, 0.125570504793099, 0.13741537848753588, 0.12429666386118957, 0.1016951645059245, 0.12113021234316484, 0.13403989747166634, 0.21820893670831407, 0.13610059475260122, 0.10750434707318034, 0.16327761858701706, 0.07704444868224007, 0.06881090799080473, 0.1291820617126567, 0.12839235551655293, 0.1209615556789296, 0.21889547844018253, 0.11752606502601079, 0.12546018856976712, 0.11893397090690476, 0.103623513531472, 0.1378841647612197, 0.1036638252969299, 0.14751132817140647, 0.144593763298222, 0.1562904178031853, 0.13899412591542515, 0.2004970692630325, 0.09043524228036404, 0.11383577090288911, 0.09219103306531906, 0.07105715067258903, 0.10964393083538328, 0.08905232684420687, 0.08284233364143542, 0.1917673498392105, 0.09074936328189713, 0.16142377949186734, 0.28440811591488974, 0.1795122338724988, 0.17494407828365052, 0.11218013867203679, 0.08010686721120562, 0.13858859267617973, 0.12202396509902817, 0.21598079055547714, 0.14225040189921856, 0.1264409159443208, 0.18473206806395734, 0.14531169406005315, 0.151883156437959, 0.20662597753107548, 0.16385293485862867, 0.11043042077549867, 0.11151362050856863, 0.07326897805822746, 0.16377915096070084, 0.10363000711160046, 0.11296377197972365, 0.1114056995138526, 0.1178318400468145, 0.13407842469002518, 0.2700496363852705, 0.13257120842380182, 0.1049083670867341, 0.15960455925336905, 0.09997200447001628, 0.08977755864283868, 0.05958347634545394, 0.13253489322960377, 0.23868527795587266, 0.10989536198654346, 0.11456489749252796, 0.10657573118805885, 0.08156989049166441, 0.15449022368660995, 0.11018734239041805, 0.1388511314455952, 0.08498739318123885, 0.1619430080588375, 0.11015969208840813, 0.13770527578890324, 0.10725037141570024, 0.11401277354785375, 0.1127431531037603, 0.1232290840042489, 0.09871717608932938, 0.16994871704706124, 0.10176434793642589, 0.15118661309991563, 0.1269202602228948, 0.21960521249898843, 0.11512228686894689, 0.0878941829183272, 0.22827568224498204, 0.11528759157019002, 0.0889885581231543, 0.13040845947606222, 0.11956103225903851, 0.09688994913761105, 0.12194511932986123, 0.15726666684661592, 0.10017910692840815, 0.1298126107347863, 0.2302917997751917, 0.1021639575649585, 0.16597126690404757, 0.16248412616550922, 0.06812315846660308, 0.1826727549944605, 0.15747410857251712, 0.1348890976182052, 0.07175505108066968, 0.11535788779812199, 0.14924294953899725, 0.1516841421169894, 0.11346946377307177, 0.12820076436868735, 0.11408260837197304, 0.09727591342691864, 0.22661370571170533, 0.13478825374373368, 0.1352014544286898, 0.16790126476969036, 0.17539594189396926, 0.0709817111492157, 0.14695651722805841, 0.13786897914750235, 0.10633795216147389, 0.07943720064525094, 0.07862680591642857, 0.12805156808878693, 0.08352265320718288, 0.09789730901164667, 0.23379428897585186, 0.14838030082838877, 0.1600571692522083, 0.07298831561846392, 0.07703606877475977, 0.10614045775894608, 0.08733474436615195, 0.15465505341334002, 0.22815552726387978, 0.20577874513609068, 0.1130054679566196, 0.0894357669832451, 0.09322298983378069, 0.18897436399544987, 0.1539929932249444, 0.13164399032081875, 0.09761153041784253, 0.14484920459134237, 0.13947603505636963, 0.17580017234597886, 0.11640663152294499, 0.14362003840506077, 0.07157955478344645, 0.09519830705331904], [0.02770614544195788, 0.03547102878136294, 0.036987846318100176, 0.030420495862407342, 0.017809873347037604, 0.04781081234770162, 0.024802656777735268, 0.04531404435900705, 0.013603249697812965, 0.07674022072127887, 0.02940574334934354, 0.03927250765264034, 0.023602457251399755, 0.05752293512757335, 0.02068662773152547, 0.03488507308065891, 0.023258421337231994, 0.023560481378808618, 0.07374937406608037, 0.051097656334085126, 0.07011847211314098, 0.014973795440580164, 0.061484738253057, 0.050002063158899546, 0.038202457928231785, 0.0032132324787588523, 0.044325544365814755, 0.04503604856186679, 0.009248045539217336, 0.03494771882625563, 0.02936255120273147, 0.02440942877105304, 0.05287478704537664, 0.03522689527432833, 0.03882063047162124, 0.027971581555902958, 0.014102385994712157, 0.016588335590703145, 0.04038384623293366, 0.01216827451051878, 0.024778962334884063, 0.028153272877846445, 0.05290958571380802, 0.04753594120432224, 0.011615035223907657, 0.04433524063123124, 0.03215015287111912, 0.061850882534469874, 0.06646390964410134, 0.03353509373430695, 0.039258889454816065, 0.023141879555104033, 0.02415992465934583, 0.029110058144267117, 0.04046163348747151, 0.043216071756822724, 0.012820985334526216, 0.013265967751587076, 0.039766074025205204, 0.04489936786038535, 0.08838803427559988, 0.07266137030507837, 0.027710350662735955, 0.045261875194098265, 0.027037910584892546, 0.019666299356945922, 0.04316523591322558, 0.00719295465387404, 0.029545952432921956, 0.08161928784102201, 0.009995809789480907, 0.06583914852568082, 0.04536494127075587, 0.029099354254347936, 0.006463426456321031, 0.04340566461905837, 0.025774193395461355, 0.031924092144306214, 0.025393438558759432, 0.0349115868365126, 0.027022238122299314, 0.04560803661921194, 0.037962622940540314, 0.09125407798481838, 0.012213823718151875, 0.10698678091700588, 0.035573009201990705, 0.03847074728193028, 0.02935145715517657, 0.04972616403496691, 0.02576795087328979, 0.014046004823675113, 0.01043625535177333, 0.07377655617892742, 0.05198525477732931, 0.024556441864530956, 0.03755227888801268, 0.010289244802801736, 0.025917705248243043, 0.013306545842039798, 0.038748339350734434, 0.057660650594958236, 0.052639457530208995, 0.02588121872395277, 0.017258212502513613, 0.0038473232416436076, 0.0668518009728619, 0.07924243395349809, 0.02383011932085667, 0.03408950773466911, 0.08698423353156873, 0.010263715770893862, 0.047783026338687966, 0.05139446112194231, 0.049247732385993004, 0.030423712118395736, 0.02896525537861245, 0.011834933156413692, 0.03589121498433607, 0.08972853448774133, 0.06612663024238177, 0.05154120449775031, 0.034538650419563055, 0.04762021864631346, 0.05296102545357176, 0.06324388778635434, 0.026773105508514812, 0.01085013966076076, 0.038715250590550046, 0.07765247712710074, 0.005035658583178052, 0.07568416238895484, 0.01781027198636106, 0.02598362322896719, 0.07006125804036856, 0.043653940582381826, 0.025155420348580395, 0.016976700197639208, 0.017919030971825123, 0.01590292531597827, 0.07282158599368163, 0.0648342856605138, 0.08440986488546644, 0.03629755228757858, 0.025496404551501786, 0.02717839617149106, 0.02253239056361573, 0.022446087694593837, 0.09820033596562487, 0.07529434402074132, 0.015863996065620865, 0.07551902053611619, 0.06446889455297164, 0.03277423545452101, 0.06885885327522244, 0.027147914682115828, 0.0744547044326152, 0.0445019329365875, 0.03302514074104173, 0.04393515942086067, 0.034715812520257065, 0.022558483627757857, 0.02338416575055037, 0.03864043192671878, 0.06549012368278843, 0.04720096882166607, 0.036481920430170636, 0.06565095005290848, 0.04448061336630157, 0.05140660350610103, 0.048705437021063905, 0.01740918824050043, 0.02257017308979162, 0.020321263765384043, 0.03465733297967485, 0.05970177214060511, 0.07013366451220852, 0.009890076222031243, 0.07127875342432942, 0.034834376336740594, 0.05147175304591656, 0.03621500850256, 0.033011661642896276, 0.027694696859855737, 0.03331528910036598, 0.019188329111784697, 0.03617089015564748, 0.03950986598751374, 0.0923274118187172, 0.028015560803136656, 0.02272428705223969, 0.01566300042239683, 0.01903331439409937, 0.009687887205343162, 0.046410634980670044, 0.041681449461196146, 0.046616265018071444, 0.011371673550456762, 0.03010497029338564, 0.008083140011876822, 0.020290146149428825, 0.05678170686587691, 0.031015818739043813, 0.09878650201218468, 0.013370116939768195, 0.0306821762850242, 0.05721688869276217, 0.027823046847645725, 0.04314501556966986, 0.0297208380486284, 0.03415681501584394, 0.056162153503724506, 0.07164621406367847, 0.029805831345064298, 0.06808542513421603, 0.05421619310176798, 0.0065111359498197475, 0.023390469340873615, 0.029854003938713243, 0.018466138846373985, 0.09967142024210521, 0.07747168147138186, 0.0396224451251328, 0.022905863023230007, 0.024229077555771385, 0.05290887325203844, 0.058418139948376586, 0.03700847717534218, 0.022059338001002158, 0.031016751724694456, 0.022495654677706103, 0.052154461054929664, 0.06401511068855013, 0.010832451949162143, 0.04051713086664677, 0.039821069288466654, 0.06078271235206297, 0.08873704554779188, 0.0338269486092031, 0.03057640963899238, 0.025408564800662652, 0.022784150804259946, 0.055249483191541264, 0.04370988579466939, 0.017182750926752175, 0.03397184297708528, 0.026457486640928046, 0.020230633539280722, 0.025929883255490234, 0.016059319156089, 0.04973590101248451, 0.0839672429221017, 0.10245274206889526, 0.028171406726219823, 0.018843819919441427, 0.042890425837997875, 0.039148725901863406, 0.036323672493121455, 0.04823708161711693, 0.0185505723514195, 0.021471611323899457, 0.0575865206441709, 0.07923110920403685, 0.007863545723791634, 0.017595843046105335, 0.012731076900048979, 0.043915658324424706, 0.02989741660920637, 0.044625372027180026, 0.04874045282070126, 0.038902492328946076, 0.025595072024900998, 0.05247545222352658, 0.035314473789185286, 0.043274327380848784, 0.006398318900859782, 0.024864864868244956, 0.034313319117895195, 0.05777549264686448, 0.02587435194956405, 0.04728946675147329, 0.0637851958828313, 0.028773901718003408, 0.05949886981397867, 0.034728833607264926, 0.027030127788228647, 0.05858706124126911, 0.01183273215844695, 0.07498166829879795, 0.005530211800110659, 0.05843544937670231, 0.005121985200925597, 0.03519831198666777, 0.050374344789556096, 0.030208684370986054, 0.05955261657280581, 0.0327501915661352, 0.05235829636720674, 0.008169110398739576, 0.031727086286991835, 0.014686206854613764, 0.02624214337473469, 0.03827701874875596, 0.03533140663057566, 0.0021736809950588004, 0.031845168343612125, 0.04691746671284948, 0.05394454839240227, 0.017598606379968778, 0.011494201707786747, 0.024317276930170398, 0.02332897201579596, 0.028497341022427593, 0.07096100904579673, 0.04159098717250994, 0.027816476932327663, 0.039787570014595985, 0.06724206038883754, 0.04727589605110032, 0.041637989293251715, 0.0625350426084229, 0.060910378715821674, 0.017058497594137276, 0.05271907004394701, 0.023427619133144617, 0.06536730205906288, 0.019476982997730374, 0.056308411726994176, 0.06517256250871079, 0.07728958981377737, 0.056580453379345794, 0.02345633982414646, 0.078289526514709, 0.025906238006427884, 0.04257005213626793, 0.0685397789680532, 0.036015634558030536, 0.02304024518733578, 0.03606024145015648, 0.029502556725804294, 0.07863942666777543, 0.02119944753524448, 0.02278828477886106, 0.02270101330110005, 0.03295071902019637, 0.06427153585744755, 0.02372397099887686, 0.038222905581018755, 0.03249593431662236, 0.05221767337726695, 0.022169487983254448, 0.07733560127339192, 0.17293113629732812, 0.10117470100522041, 0.24042854298438343, 0.09166575196598258, 0.07494279502757958, 0.105974026689572, 0.11277365325284855, 0.15332346915134362, 0.10903087444603443, 0.1837430354207754, 0.1080584048426577, 0.09072051875825439, 0.14342334467385495, 0.08241675647773913, 0.13843381883842604, 0.12186870271606104, 0.11036423646977969, 0.19559700148446219, 0.2331194451877049, 0.12387804846678462, 0.102434503047594, 0.1499941692288433, 0.2558239054466997, 0.058799700545413155, 0.1582583322056702, 0.09054792659091097, 0.08579752328140394, 0.14463490966175283, 0.14813551253506116, 0.09642928492810045, 0.11769485739724976, 0.13310049287974834, 0.1744753055806671, 0.09844266117683478, 0.11588629015854426, 0.1222379207611084, 0.17472455863441738, 0.19480512397629873, 0.11747547345502035, 0.08724177828324692, 0.08842972346714564, 0.1297690894986902, 0.10848820927952017, 0.1064764072320291, 0.1344847586005926, 0.21919834933110646, 0.07068245684994118, 0.11832715703972749, 0.13350593112409115, 0.10651405914021389, 0.13814789775226796, 0.10675725287624768, 0.09932432243866579, 0.10189013475818293, 0.13499961740204267, 0.11407157539256982, 0.16516300956053392, 0.05785568191536835, 0.07465657538601331, 0.11299579883260386, 0.16671753328825745, 0.1416239376579012, 0.133470050192305, 0.12142308162791388, 0.1346814659024988, 0.06708540700908218, 0.09658275597861835, 0.09653071234268801, 0.06631930704627718, 0.15401590056717396, 0.15376128708677633, 0.1282375409666981, 0.2695273272693157, 0.10829543069537197, 0.20792443571346148, 0.16649816291672842, 0.1742734278419188, 0.10616251014705215, 0.10037273368132965, 0.15238158112125738, 0.10751818918756076, 0.16838271250682219, 0.16340202119733604, 0.2181987315416336, 0.08041340897658042, 0.18280392938426562, 0.13406615677688802, 0.11669783161154815, 0.0868308235492025, 0.09960474739117281, 0.1317846913422857, 0.1278916373848915, 0.1254603107060705, 0.1733010464480945, 0.11690364485340458, 0.16450478988034384, 0.12354954252285616, 0.07620793035519974, 0.10590854806027242, 0.15922603170786584, 0.19079515843519143, 0.10567162398781095, 0.1306321724717106, 0.07857252990028687, 0.11719610701714243, 0.14047272157456192, 0.12927772157958575, 0.2474955123450075, 0.09747631195932627, 0.14132017110075268, 0.18763284598078045, 0.1004730211570859, 0.10664931831083127, 0.12309153138526849, 0.19653285055288247, 0.0950292432680726, 0.10751527148698058, 0.1326373384467193, 0.09198882962976183, 0.1761862180594887, 0.13748813101223537, 0.10390360600181989, 0.10714308145855155, 0.10535385925322771, 0.18930856963353498, 0.13611622819943087, 0.10096138995140791, 0.14931112873767102, 0.14374416960137232, 0.16775026358664036, 0.0772166880113738, 0.12529892793723515, 0.1377742692295994, 0.12102364163313593, 0.11596337173666273, 0.0588872315628188, 0.1090712540649942, 0.1110854513411011, 0.1458644015448434, 0.0773266785378967, 0.10766172648540565, 0.15312714182904788, 0.25233976383294376, 0.10886855529887335, 0.11241390077131135, 0.12630073060946806, 0.09866707984890256, 0.169708963483572, 0.23599971777626447, 0.15208371781877109, 0.104716029550348, 0.12658435824726308, 0.1372695748827287, 0.1346540937998465, 0.19022128065781935, 0.22018469497561455, 0.14503592385777406, 0.20153756200202874, 0.12496005397822176, 0.18198910382177147, 0.08868551759847573, 0.08290949503758124, 0.07646708323487214, 0.1460997039186103, 0.12228080417428698, 0.09276012717080967, 0.09424932154693774, 0.11571395583450794, 0.07757631157125745, 0.11171723529696465, 0.10310474636831454, 0.08278102121715035, 0.10648630027260099, 0.1372564655861684, 0.08029441429036004, 0.19448064853038105], [0.04600615347070353, 0.04485553789085575, 0.015387265843206217, 0.012255502731672354, 0.0339216822758317, 0.018803799924041544, 0.03770407395703452, 0.061286178550549915, 0.030475609869297062, 0.03448977554216981, 0.04544757665800197, 0.027474412162389075, 0.02212226703496916, 0.05727398741458144, 0.0983338173744934, 0.022054632360647832, 0.02932125556149653, 0.034508774522691965, 0.07147277372756175, 0.016783214240734066, 0.009497150163432317, 0.040043845905789306, 0.052187464998236725, 0.04875065120203154, 0.01465262276386576, 0.020620780996978283, 0.020582274134669985, 0.0428408656402358, 0.040093864114688973, 0.08495717123150826, 0.04320751203756247, 0.022003720181861093, 0.03989184388358678, 0.022179883139740144, 0.05676894022950104, 0.073997256479093, 0.05017878421183143, 0.005019607413227537, 0.033185831404158046, 0.05050750050161566, 0.017919421129460846, 0.038865247541772466, 0.06769443290042025, 0.03778768304203238, 0.028938287004296268, 0.005879778198764792, 0.05782719022993531, 0.012840710347518325, 0.053479782438703945, 0.03285158505397184, 0.035404644307813475, 0.01961071546455579, 0.008323006381812905, 0.0345724652122174, 0.03306258908872094, 0.05240925773978233, 0.07870795870465891, 0.026601117237337997, 0.01215464189382536, 0.05130377152402486, 0.022607909814853753, 0.03514925390481949, 0.016140729787626436, 0.03589564921068294, 0.07077551114239863, 0.037924743723124266, 0.028754957020282745, 0.017421099922752807, 0.025136295839079788, 0.07955565250345639, 0.02079438418149948, 0.044154085351952484, 0.01374412713838475, 0.027583680049117123, 0.018876325139509778, 0.013594986837623375, 0.026425581924351196, 0.022085461599220122, 0.015749637469915406, 0.023912676676575626, 0.04386551458654659, 0.03710057473342333, 0.007723531719031078, 0.033542079252323935, 0.04159443752307977, 0.06756340100296906, 0.03846766334027052, 0.05213535350880452, 0.04127113933541945, 0.01846898699711476, 0.05591533299801605, 0.05488972392465387, 0.0381759916698294, 0.09323803295514413, 0.020835433853790164, 0.04046034087826099, 0.014465662617502468, 0.02020958877567734, 0.010535150982572563, 0.03448346855917147, 0.08583835073347602, 0.01454026754280286, 0.04349066809351955, 0.07066548668912478, 0.011870211040201997, 0.022686182221929942, 0.03159031059060778, 0.03299388402540769, 0.0168327472970954, 0.04945057025179267, 0.07471137387411934, 0.011638636368193796, 0.0232499837542751, 0.026982677834374563, 0.0008221135056893607, 0.016355374162750583, 0.07750090597463505, 0.06618145587188856, 0.02734226916384484, 0.022682530007192066, 0.09073586722037622, 0.037059384265116284, 0.012589710914263768, 0.04596467123233846, 0.08496885560452938, 0.03737471645165767, 0.03484418795311025, 0.031061823413308178, 0.02332386773611818, 0.02682580393073814, 0.02878253607611571, 0.03573352683867727, 0.049894135378833325, 0.13610600946205004, 0.0256180641840079, 0.03757199372297951, 0.012517685270203012, 0.019215399266353676, 0.055971000010945966, 0.027257786465010474, 0.029956381302326918, 0.016210121867646064, 0.10117271968296596, 0.034333169659865756, 0.001740387615947319, 0.06420141604862042, 0.0338687667224024, 0.06315487756260804, 0.03267992587227907, 0.07946953962423972, 0.020163400896957943, 0.01480757471706186, 0.010562549378456814, 0.031903719130371294, 0.02231764780091388, 0.026615232462063432, 0.11704875635249273, 0.015512896601908972, 0.02916086684646351, 0.09008886372404439, 0.02346978329920343, 0.037323446345648596, 0.02352542825974524, 0.02587852663626628, 0.00854197217683707, 0.017255584875653898, 0.02005750872194767, 0.024408092057066302, 0.032641283302967034, 0.03659808901803834, 0.009319132260446037, 0.02328839392534324, 0.0686739728386913, 0.061703620079372606, 0.015607201095138277, 0.032068962763462744, 0.06269495974161796, 0.042489004520965476, 0.011000981388081397, 0.037577452537204535, 0.014572362249184932, 0.02283156513502555, 0.03381050770570125, 0.04457296537501471, 0.029439989011734724, 0.03363840747624636, 0.04290384386799165, 0.04011307344106691, 0.02284556670513536, 0.03530449253906097, 0.06535541412553617, 0.06179677615208285, 0.012358183739706874, 0.0415391470970852, 0.027231013169512153, 0.021913449579317654, 0.017098258049892526, 0.011072157167031296, 0.062099959169115336, 0.022899011515879204, 0.028939108031668832, 0.021803710110751644, 0.039735916536301374, 0.015850555983238986, 0.05222420088414635, 0.03532887908763119, 0.0565737223119608, 0.03733031312003732, 0.011577541923283466, 0.016075215535238385, 0.03398269953738366, 0.041712109066013775, 0.017417371372825334, 0.023090416066614643, 0.03755927797673004, 0.06279738460268293, 0.023060445174840943, 0.06199035540755306, 0.015070500251437937, 0.03397582597764475, 0.04703475488349795, 0.02082167994896216, 0.0070476938770817855, 0.01804552347000156, 0.050643770689410825, 0.04607087214078222, 0.052484968677163124, 0.02342990749249501, 0.031057718276445354, 0.030000418225037198, 0.08323648106306791, 0.04164419788867235, 0.08350054653627531, 0.01527650687577469, 0.033410616485135894, 0.021601360790165405, 0.018195944505610635, 0.004001952042537076, 0.048538924527487586, 0.0677440134542329, 0.048010637518018484, 0.031156702964965786, 0.031464751078081984, 0.021746236498334577, 0.06886040033506495, 0.03896289212363107, 0.01665143425842481, 0.11642370346401419, 0.010157415626703628, 0.038752156110214334, 0.05103781293811543, 0.06509031049375023, 0.11771857898150172, 0.028375189452032958, 0.014347400749102235, 0.036155942029186657, 0.017930511784340655, 0.020409459747107964, 0.04309589981234499, 0.05321170682353633, 0.03253063459747604, 0.07706899129386459, 0.015137447909052883, 0.018616926290893128, 0.001419494834928108, 0.020384399752531732, 0.05710884556174278, 0.052205252793750594, 0.043196970996047766, 0.009485417444791113, 0.015282145501779658, 0.04721244624150651, 0.06433721126190253, 0.06552525144070387, 0.055415025380040915, 0.027155397227033973, 0.023498515864568095, 0.037053698141660006, 0.044430995493062904, 0.0030409827595576644, 0.02591647201084665, 0.006991594722161868, 0.04247810385589089, 0.011577766688008393, 0.04024227668664285, 0.06421765339161668, 0.03077082009986043, 0.016868385652612363, 0.009574522663440024, 0.009679531894757279, 0.020008929007287537, 0.003853207836592836, 0.0396041178942791, 0.018444948197741593, 0.05023188636239086, 0.02262198263114052, 0.026957958803645203, 0.0619007209315896, 0.03579367557540536, 0.022152075078338385, 0.012442172804315175, 0.02361463865132204, 0.07208173176539795, 0.037107312586158514, 0.018518742273694704, 0.05811813247523137, 0.07226761643375669, 0.01972364744038454, 0.03373460677851524, 0.10024649224111012, 0.03948462109214493, 0.02806691572602306, 0.054512390600783486, 0.02594909767088081, 0.056393303243177276, 0.006979077871489737, 0.019439941771062355, 0.016887934246499623, 0.056087714819503684, 0.021171688667631576, 0.030054575497550622, 0.12065427431038447, 0.052786401073847494, 0.02714310386883361, 0.09070427462990795, 0.023872865330693976, 0.04720335726493171, 0.03915518894791603, 0.09835280956966536, 0.0260783755553088, 0.09126402530819178, 0.035164548084139824, 0.04491553056452956, 0.04667559951277716, 0.0726341949775815, 0.040930341729628186, 0.04493540485522576, 0.01710993903023856, 0.03613093801374946, 0.0326774967169123, 0.027124062479872788, 0.017203836402456676, 0.023237980469795208, 0.047137383305068524, 0.0075911105211291996, 0.020134749755795513, 0.0431663317472807, 0.03387846298781889, 0.014380620127277715, 0.024691363463976553, 0.00867738401783364, 0.08091036123888833, 0.10283613471048218, 0.15907949528523854, 0.08980970763202224, 0.14519839228263923, 0.09409268173788275, 0.10429798412535872, 0.15301085449755192, 0.10470812461738076, 0.12648651349757398, 0.12897212297788688, 0.1976879071444273, 0.13117285631597042, 0.13214104436337948, 0.1308045746492488, 0.21116034207599504, 0.21235528295593603, 0.1325344182550907, 0.14097795874944755, 0.12490213422902993, 0.07483355088957719, 0.12423011314656053, 0.09261371288448572, 0.229276141417878, 0.11555280376757894, 0.20110600015946797, 0.10512796137481928, 0.09989157771425587, 0.10508319163428885, 0.08996141449149166, 0.11997599713504314, 0.13732524189565862, 0.060257302331072946, 0.18537108520311968, 0.13530672235148294, 0.11171646176704339, 0.1783036408679826, 0.12731739319860935, 0.1033644692174026, 0.14161373249122075, 0.2321208044886589, 0.09570194288556065, 0.17206850115742, 0.2156405323850257, 0.07708862809730427, 0.1486708088112729, 0.09155473006623131, 0.09315916682992663, 0.08159787327583347, 0.08969639906925814, 0.14142651110887527, 0.13210434918957098, 0.15456236552979263, 0.079623316015516, 0.08793768379837275, 0.12438612191804818, 0.14645293567861828, 0.11021220391350132, 0.13755826439176286, 0.1519387691680874, 0.11471880280545779, 0.11191561858036689, 0.15365407855382987, 0.14450122469237872, 0.1765986859266247, 0.15498948975333146, 0.18179711912359509, 0.08901107870042324, 0.19457359425723553, 0.13931558866586002, 0.129655122756958, 0.09363114900354828, 0.13369809224137238, 0.11074402609041759, 0.1380653064697981, 0.13014319299587182, 0.11276633185999733, 0.1702928292964186, 0.10897399964077131, 0.1260754841246775, 0.08907605521380901, 0.09958493416862828, 0.10933154009814773, 0.08204745700848953, 0.1632140262850693, 0.1614709919584649, 0.10347821882792882, 0.09858908903385911, 0.13924333825707436, 0.17616364998476847, 0.06950055741305862, 0.19323886159275258, 0.14543395249971322, 0.33036141150764053, 0.1977400050631591, 0.13462841803474085, 0.10512160350169454, 0.0983964190153139, 0.08092466475708143, 0.17018510507685797, 0.10006631405225822, 0.22766451218298503, 0.10644921833383185, 0.09362635854631662, 0.11848609708249569, 0.12635448415364536, 0.20751514339021274, 0.11403094471565314, 0.1264306700655392, 0.09017581798668418, 0.11741754013512816, 0.3235608621367386, 0.11488649594996657, 0.16744296864739486, 0.09370412544480392, 0.12448392595563616, 0.07116081046738795, 0.13140909506806306, 0.12716055661439896, 0.12573226754154476, 0.12616749347320624, 0.1907532385417393, 0.12859421968460083, 0.1821370923093387, 0.06710471811571292, 0.1901045726346118, 0.12012433846082006, 0.1296397200120347, 0.1505441354321582, 0.09895467013120651, 0.1267024776233094, 0.16954068679894718, 0.09394178912043571, 0.1309949851461819, 0.2565053988780294, 0.1461974943854979, 0.1568569809730564, 0.111121542618743, 0.09833222281719957, 0.1762488197003092, 0.11642254995448248, 0.18259907966213568, 0.12331623504204409, 0.2780509484665734, 0.16900354490748473, 0.138851742127112, 0.12808529127921375, 0.09685692483825342, 0.1332517247647047, 0.21737150235899858, 0.14989609377724783, 0.09674704966268369, 0.11464192478784493, 0.2180372809192964, 0.14703727646597795, 0.14828697512192385, 0.11090473032423429, 0.23357816200171197, 0.13947907489325317, 0.11927747247474534, 0.21055693445461138, 0.14141935934977873, 0.10608384758234024, 0.09839834605476686, 0.10482559259980917, 0.05816401501319238, 0.07857651968619653, 0.10044805106839963, 0.08845189120620489, 0.12407852842339448, 0.1116435599646398, 0.13811489380896091, 0.1076636603102088, 0.1316194680652448, 0.14635887715433324, 0.07037884635584694, 0.12755903308945044], [0.06065213507307427, 0.03728004385318075, 0.04053486777203424, 0.04849103691854647, 0.020878436010597006, 0.004424701411543148, 0.007699213023962719, 0.035826007769043954, 0.004923216000731502, 0.08419609242784125, 0.030957424015338932, 0.024675012466364672, 0.014849180788067835, 0.029952676501125097, 0.032677676528692245, 0.03724493984399097, 0.021254634484648705, 0.03258605055244906, 0.027864077860223394, 0.021242956896977763, 0.03030505669968469, 0.030513512835438763, 0.04893373691343835, 0.07440682700169937, 0.04615992307662964, 0.029609120650483028, 0.048689162358641624, 0.021411438838445714, 0.06698424422315188, 0.04824528849816748, 0.04231914006439703, 0.030533431230911186, 0.030472722702792714, 0.04072129526840789, 0.005645931282612894, 0.05693458419825349, 0.07934050940509353, 0.006607283513793456, 0.04162812678675566, 0.04289191522236381, 0.025968975354252116, 0.01289332819370819, 0.049276763506765874, 0.09603675920516253, 0.04702236483405743, 0.04813419195956417, 0.07757825896676097, 0.02009589514429016, 0.021078861684405377, 0.04090017067002399, 0.042390318387853246, 0.072413752520723, 0.02798191225156188, 0.013476110895031264, 0.046307874244770834, 0.024819828802719712, 0.04704852235902633, 0.018958073342218995, 0.065018331498972, 0.01560821889766625, 0.033346355826194794, 0.023862660164013505, 0.05113264499232173, 0.04299998888745904, 0.007782221605469073, 0.02393762980188642, 0.059337032426680834, 0.031763567722269466, 0.0371240350816931, 0.04089025388072644, 0.021438548008778265, 0.030389218790722743, 0.03253565914928913, 0.005832032234008823, 0.05406124623758452, 0.004210965425175215, 0.05103454579200063, 0.058324787100510936, 0.0361369430486645, 0.021852179563471248, 0.011259850131214728, 0.023204477803249444, 0.03364674327895045, 0.05169833285201873, 0.022744828003591726, 0.04751727809863431, 0.01036932465753385, 0.04105376385684524, 0.015304226727624024, 0.048511962938521586, 0.016289803931223493, 0.04302058581795011, 0.016938934634838785, 0.06864356089915548, 0.06513408957315342, 0.03939360919009362, 0.020845223417771713, 0.03014730748587421, 0.023660611095173017, 0.023334742956129566, 0.05119257659784385, 0.01906832680106163, 0.035780478069292646, 0.02350948777581964, 0.034619318055255074, 0.06417466141283512, 0.08063552062958479, 0.04617707644190107, 0.01862566582193332, 0.025412188177662234, 0.03621402462678296, 0.06671905238181353, 0.06298245502901928, 0.03194807157186525, 0.021676525506856184, 0.03758786126439061, 0.01852690165729395, 0.041624225210398436, 0.012566750985570252, 0.020308661673750197, 0.004743758331252528, 0.026587069866114428, 0.08098204167825834, 0.029311630542257, 0.051345019667808495, 0.0114129471393036, 0.0401456600853375, 0.03158175426402262, 0.041764583571680954, 0.02236437681131065, 0.010544765823786812, 0.015991869382560253, 0.05167106592229434, 0.03612237490181412, 0.015679610959653343, 0.01648154266045562, 0.07279176437961203, 0.02592478576116264, 0.05792857014707156, 0.009974915151750403, 0.042837693489023616, 0.019703729044912115, 0.013578891986981034, 0.027161748314808522, 0.03462271073034831, 0.026090210902371576, 0.01885219643424664, 0.0275715410576335, 0.04651235755799072, 0.033853017924619574, 0.010840898861975541, 0.04919435203607593, 0.03100977638470275, 0.010063481783228261, 0.03498294836442385, 0.0075631107735846725, 0.06302841899118253, 0.0396355442436678, 0.02253390708938241, 0.0525586270461125, 0.02772940053338451, 0.02314385578834585, 0.04972387058660388, 0.12372520166848387, 0.009887488459103873, 0.012662603386810847, 0.002292306727862784, 0.07622137891926936, 0.027726133387269716, 0.01679740071163646, 0.00753082353289106, 0.032428542218570194, 0.060206805754985125, 0.06671890988945961, 0.035557480928088935, 0.010576948739721306, 0.004814003669058106, 0.03249165954600487, 0.011587190691248646, 0.03665742690541914, 0.056876834082816324, 0.04010061214544943, 0.011988115829548665, 0.03135674187381353, 0.054268287627824714, 0.049490613995918205, 0.08089091442525387, 0.014098727842792869, 0.04839899025059172, 0.015286411790709411, 0.022898821526073983, 0.021680874916325723, 0.010001673180210804, 0.03472953249833413, 0.021961377900359885, 0.04677732548277293, 0.039669111371040344, 0.01652528272409524, 0.016974177743707384, 0.07425228386585202, 0.018322793234671866, 0.02326133055612445, 0.02310715213284961, 0.020292627891259532, 0.05803112392979009, 0.09297527705452271, 0.019100148397098695, 0.0556648450105318, 0.0424962716310152, 0.06205149141273328, 0.04564714737768684, 0.007876755952435945, 0.06583581013338906, 0.034344704755182774, 0.03326461271249822, 0.030992154830268452, 0.0483673230212714, 0.028906670665102344, 0.010782618641055055, 0.04232179652899504, 0.02350902806834451, 0.0232811081555805, 0.02815403792607997, 0.02333053943168904, 0.02547559218614229, 0.02412480877579323, 0.029317798425576518, 0.021473117671640854, 0.03371162140475852, 0.017544902029580305, 0.021681405869977813, 0.00567012741729351, 0.028882209477680068, 0.04019012109243444, 0.0284340557575758, 0.015849558536761572, 0.10902393981814384, 0.020493564162669436, 0.05196978078622903, 0.0658062667186771, 0.020308344458628978, 0.02361105429008603, 0.033403773459472826, 0.03346246673858591, 0.017416726764557616, 0.056438330827014785, 0.020369614474475384, 0.008572343404271772, 0.052438126012150726, 0.006236754199822566, 0.04385554690712264, 0.009892649566089469, 0.0225386805832386, 0.031415550503879786, 0.014180556621535547, 0.006933845030809087, 0.0017482839612057433, 0.03170618062306728, 0.015380275236176593, 0.04141917532043798, 0.037766553461551666, 0.008987483851212476, 0.02470862878752606, 0.014284900888534529, 0.010586169182455965, 0.07217612277184214, 0.04224923738677587, 0.06488774064928293, 0.04299811952348266, 0.04240860151393073, 0.04080875843231167, 0.0043772111696723315, 0.04792675023366298, 0.011524515259744865, 0.024229871441743205, 0.05072209059393831, 0.053345011813299995, 0.00946000630834273, 0.05918911857796567, 0.060998405063790936, 0.06511866647217955, 0.020744976654116596, 0.04989262903109193, 0.014581573362063085, 0.021094147382037978, 0.026156003354117274, 0.05275240646941321, 0.054401239779378684, 0.06490431725978851, 0.02126278369022267, 0.007579411729238927, 0.027972161703343903, 0.04572221031412482, 0.05817453230598143, 0.050644832596715005, 0.02811917818949691, 0.019919918783541237, 0.036299180771623335, 0.04855881238888417, 0.019448501490322605, 0.030553624433066164, 0.04396532369511468, 0.010151279125628727, 0.04908495183501925, 0.030816933339727775, 0.0727274256891438, 0.024389939548979913, 0.013771629859028118, 0.03676931054464408, 0.005720180401112884, 0.0761027777833598, 0.047287220800561566, 0.00348007761307859, 0.009733883397919791, 0.08627008220979146, 0.017251271089272838, 0.05115199002570339, 0.04516952997073531, 0.02035099547356367, 0.013647545311999108, 0.017811322019302418, 0.03752283725355353, 0.030025354386972528, 0.01699371276689427, 0.016628467544381107, 0.07136682726974998, 0.03002705072451915, 0.0590633928243603, 0.06586049523736749, 0.06163914568190064, 0.01982102569724832, 0.022141953032197695, 0.0505749027776931, 0.03309853448133383, 0.0544936087514673, 0.08383303548076323, 0.010220483760349452, 0.025690112728625536, 0.027966799580359032, 0.050658922376377244, 0.033843850916517634, 0.04057375122127788, 0.03710935836923974, 0.06219840781497104, 0.060189781311367235, 0.03035686963370868, 0.04211819531129939, 0.05577478125425322, 0.06479512740458761, 0.04764769592189363, 0.08619496159787689, 0.007701432681642473, 0.16925821267068386, 0.07942633729960237, 0.10858830676547118, 0.17021315571452889, 0.14204669211591991, 0.13748564757406712, 0.08676010662955896, 0.10234208657805409, 0.11042717737810952, 0.1837070459233863, 0.2027170458542449, 0.12571967393159866, 0.10649147070944309, 0.13147180527448654, 0.07564494985022716, 0.10381134559533425, 0.13269284261124475, 0.12160612323454448, 0.12360166758298874, 0.12349861168435641, 0.1294963862746954, 0.07314817846885749, 0.11293027949120317, 0.2251875472388097, 0.10327362016375576, 0.15051465987094811, 0.09834957974297659, 0.09712357552988188, 0.15294245816767216, 0.12583649052040918, 0.11188564090324299, 0.17943323882562773, 0.0910006994381547, 0.14290533746991838, 0.06100978409605367, 0.1017049557662436, 0.22883756352322443, 0.06980954868985073, 0.17620231291013105, 0.11463363308991704, 0.1646093385560172, 0.1072646952899439, 0.18418709587837967, 0.158121987379023, 0.13209104990320547, 0.06381292082369328, 0.16297092075858796, 0.07727143221667834, 0.05920011084526777, 0.09536207826542002, 0.15989574577127183, 0.18046313284763268, 0.11677442464445319, 0.13117459336561815, 0.12270188943615981, 0.07906762976199389, 0.13919483657394136, 0.0707168382193361, 0.16668636138950074, 0.13120408249752863, 0.21711546395506176, 0.08626990579068661, 0.14444528626544134, 0.11684105678328446, 0.09070607953305755, 0.09891771032874073, 0.16713692221258367, 0.07739838611866746, 0.05461379765932049, 0.15020121740443365, 0.16777384946388857, 0.09350689567093338, 0.20817979558237962, 0.10956503756876503, 0.07574570551514626, 0.1112550850957632, 0.15462587640753814, 0.15065443808478968, 0.16181205080023833, 0.15321083233824798, 0.08718651160597801, 0.09239223905439888, 0.1421663856932095, 0.18513832055032253, 0.10795344226062298, 0.15958755516580173, 0.08727390691637993, 0.10689784533211164, 0.06982736023409025, 0.18420055801314966, 0.08965807541140489, 0.19072655854480608, 0.15176112870020525, 0.09969439543783665, 0.11898661165365151, 0.17375684556152138, 0.13945911239300454, 0.16552800711776527, 0.08343089491661106, 0.07787832072270767, 0.1942328746829714, 0.1036763239119734, 0.12347851347710405, 0.16231658229870455, 0.10333692748099566, 0.09860042735402073, 0.1787446750594037, 0.10489585490099021, 0.06405722057180745, 0.10368284463350262, 0.1272072805357831, 0.14127138443291187, 0.1760736219584942, 0.0713417621861611, 0.11120172510189669, 0.0752528855311019, 0.09155797346362046, 0.07897787314972707, 0.08617048683975424, 0.14175076942358697, 0.06391729986561195, 0.0890728932406221, 0.2060494398964303, 0.0748468433905925, 0.1673489644059113, 0.13106351718306541, 0.15995221345552377, 0.15014787098126753, 0.1547198806490217, 0.09277485816606454, 0.08974302799573966, 0.06601635473115103, 0.11757736227342061, 0.049966775945254734, 0.16239394886153086, 0.15566533777330602, 0.18289264105260372, 0.10246363255594458, 0.14626149380845682, 0.16177545062133245, 0.15315276331135205, 0.19256180578044482, 0.1076707374304533, 0.09810967011643307, 0.10856325525258269, 0.09344185130404574, 0.11329531097518546, 0.07502915896475315, 0.11622136432145323, 0.15617042567048753, 0.09927470117275204, 0.22526211823735917, 0.12697816640138626, 0.1498884263315371, 0.09933435118624143, 0.12886597295956953, 0.14819811417588166, 0.16132558190396853, 0.1112149701054607, 0.15769232543451445, 0.16114691006285803, 0.06033779015498502, 0.08928111528179475, 0.19137830500091824, 0.12110019395393984, 0.09322362087134804, 0.1011085913383535, 0.14728918937700136, 0.12607279712600367, 0.10388677154800721, 0.0743576671395983, 0.15006799383887223, 0.12387821131518909, 0.16821720424507344, 0.14744236187211104, 0.12305821531585284], [0.09973534502621208, 0.0418224931428475, 0.03777174425444432, 0.02142335900238582, 0.036886714066245725, 0.02172865395966385, 0.008133975007305188, 0.04834070409248982, 0.018073563929647207, 0.044617979388151846, 0.029339165493313755, 0.053741578212273974, 0.01487309405846255, 0.013931407892544354, 0.03130364990127938, 0.05785065397088017, 0.03151144107271518, 0.03774262492411903, 0.027445118109296476, 0.08549001799630267, 0.018812644628009627, 0.03458782045968941, 0.03850530507043004, 0.032183950700398, 0.037691962106951644, 0.012780822846772415, 0.03640940539272768, 0.09008591209671327, 0.010408674599602818, 0.019595743589369313, 0.0312970104361219, 0.007483271798784179, 0.056755484880081246, 0.008740839764608868, 0.015355081230934178, 0.06264761835336685, 0.040439940722925324, 0.061787446295576434, 0.09324622287281922, 0.029842764006129334, 0.07417339059923377, 0.04580116804156985, 0.0606845011934638, 0.053347278120262284, 0.016468231499727284, 0.011954917655592518, 0.05732285550662449, 0.01767656157192375, 0.03549129662236997, 0.04689412510820797, 0.013192521424831023, 0.023492142724405442, 0.025352734939328263, 0.06417475640773773, 0.030779478206698383, 0.1044341932450022, 0.03032714979989188, 0.041475368198007345, 0.05570522802216666, 0.02497240588335054, 0.01882346217254443, 0.04399248205923608, 0.02642099672396268, 0.03179948597348162, 0.022204837961388484, 0.01970994103300784, 0.023573332832061818, 0.029309913848659823, 0.02057793320688818, 0.04803048466731395, 0.04216947898800884, 0.009248413644464952, 0.05019043465810163, 0.0365661809087864, 0.022145920765719244, 0.027220176965264336, 0.03285338656444635, 0.032281412077801566, 0.03878707012959889, 0.021026059785591703, 0.0405935746218477, 0.04221402481198311, 0.007501844150413359, 0.05567346579794373, 0.045880312366144996, 0.07310606180024998, 0.07777682545461825, 0.04049674088933638, 0.0063695070317148095, 0.03962457233241626, 0.01873011950270406, 0.04709902572046433, 0.042278953827917576, 0.0701787599495479, 0.01356053167754518, 0.03135868587664195, 0.05411742893712861, 0.02210243176003652, 0.021757098147645593, 0.015769106335937977, 0.04416423623583146, 0.011744885622257633, 0.024003924369545918, 0.03533836839986699, 0.05805389556501593, 0.04211727250367403, 0.043666683470032046, 0.0065837137517519295, 0.022693289876250283, 0.038733194449118206, 0.0269151364586183, 0.05556490019495998, 0.08285382802465133, 0.04416232615975397, 0.012742348214877504, 0.020608004182577133, 0.015519346077261227, 0.04304736420246107, 0.14029715742383683, 0.025216848123818636, 0.01602421005788658, 0.058415629368807585, 0.01660102928456451, 0.11239692382514477, 0.03767883923969098, 0.038452762711260996, 0.03661716263741255, 0.029737258596079688, 0.0541122143955103, 0.0649826405569911, 0.02812195339772318, 0.010082758963108063, 0.032479561266622374, 0.0687916986644268, 0.07136086294693605, 0.04277576359787157, 0.04106930230877229, 0.07586301743452038, 0.017608943860977888, 0.02292461264213281, 0.049753471676792414, 0.047498404647090604, 0.01660215056368283, 0.021993973026318208, 0.014300832890772393, 0.061315382697752545, 0.02043207362294197, 0.017528452644390718, 0.02615012045550559, 0.033963357896677086, 0.03471593465656042, 0.03150761074253491, 0.02111560944467783, 0.038082520078335486, 0.010627799002187592, 0.07279004090066467, 0.04171072146190064, 0.02451759234203824, 0.02911897748708725, 0.007160260292169238, 0.03351357399619051, 0.010339657410180994, 0.04950323474726506, 0.015487141108938625, 0.022473505598359873, 0.031222554788525616, 0.01929713220202497, 0.054592467911009274, 0.03700492504451956, 0.08105494348066193, 0.049852174773280106, 0.013471511275773602, 0.0367834579997829, 0.011029731764990305, 0.02090560455274369, 0.0710788502224854, 0.04334476610113468, 0.03433283378503152, 0.02676939052928771, 0.02989225635038955, 0.021471175365149975, 0.02627398363048477, 0.015693716006353498, 0.011818794200995138, 0.08005153268043484, 0.03726224248696651, 0.015937528905591795, 0.008574897240448211, 0.027439861159239496, 0.06892992981842586, 0.05355432290317757, 0.05572173338649528, 0.011039374595774072, 0.024916192649730613, 0.04420451068186334, 0.041554838219391446, 0.04179912778948035, 0.02693379108261849, 0.03133081505075097, 0.0324694544875196, 0.04380955580355866, 0.024846118642017245, 0.024361427507496307, 0.03267946107579129, 0.043983810381697755, 0.023426234921706573, 0.05083527362772396, 0.04286499773817403, 0.010697023992958878, 0.041114272217133215, 0.03543246763625315, 0.03625683679378458, 0.010440159472636878, 0.05643255988668118, 0.01757072876872761, 0.015361244025241052, 0.10004325064697436, 0.04637653859598296, 0.027219020063057542, 0.04663402906485966, 0.015570890989952853, 0.03931834947850023, 0.026990031457639167, 0.026889801657359515, 0.042900753140981705, 0.04282938822039536, 0.023087644251063466, 0.034569011468972476, 0.006352304472654525, 0.016265529340931346, 0.0391497810238174, 0.0526927225291729, 0.014844392027173723, 0.029991017122353827, 0.04588470248771565, 0.026109725569507906, 0.029722751517380987, 0.045717986433633735, 0.02799922676890024, 0.014463426844616021, 0.012183166657840567, 0.024453504709526896, 0.026017789163493683, 0.05817272061748164, 0.025427314419565455, 0.03455139330721327, 0.06632835191807576, 0.046499512890087705, 0.037993452179112604, 0.05091827203120504, 0.0057844016202060235, 0.058386839127966335, 0.07919003069400787, 0.02516091987490654, 0.004123913199042103, 0.02459762554748782, 0.05258285074627825, 0.03700813790783286, 0.0315724278001913, 0.07725877753858056, 0.0033042064252575593, 0.02945637223975999, 0.1267777950103794, 0.015469224391771215, 0.025921801903418133, 0.02847598074004054, 0.05226956773549318, 0.0342555825731584, 0.08170287656996932, 0.02424649046068745, 0.05171763378062418, 0.05023421373750482, 0.07154285960963794, 0.02675993853647794, 0.05203068269682782, 0.046330679806747606, 0.06879389711788722, 0.058586878036814075, 0.05593005381524563, 0.012806619900012655, 0.051322801038622856, 0.044906824960240295, 0.010603069793432951, 0.019076805096119642, 0.022383916923510175, 0.06042452050106866, 0.023234251919867735, 0.019193270543058003, 0.04350363150505083, 0.004066237722456987, 0.02322368204061474, 0.011819364170410802, 0.016665145754814148, 0.022372914478182793, 0.05284842595990215, 0.013755536704723324, 0.010740876863045352, 0.05414179852232337, 0.04084398118512971, 0.07985705097338983, 0.028060946314196502, 0.028586144292993203, 0.10107080372316496, 0.0302517340252442, 0.06967910033251558, 0.05888316035270691, 0.024258461514753953, 0.02768930420279503, 0.04142475627096636, 0.06634095231337206, 0.03561261868370431, 0.02154276250595493, 0.016176502153809582, 0.014538885027702366, 0.02408855125707175, 0.006779230224700379, 0.08246183834437813, 0.03500568946557386, 0.06745286764843123, 0.027855087271226302, 0.013023898687346705, 0.01546922099909612, 0.04900019263316478, 0.015767847653478384, 0.018564723199233413, 0.051766037076179466, 0.040482274522738795, 0.057507973430412154, 0.027148942662669078, 0.04191730823367834, 0.034706116254840574, 0.09153288802398102, 0.007370343215630523, 0.04816696859363999, 0.028701586848390952, 0.02863466293950166, 0.024187008384615183, 0.05197368236258626, 0.02251319311160062, 0.012997839549955512, 0.04697220752547894, 0.0024830350760437015, 0.018673354959381477, 0.012471758627465792, 0.03502038314140268, 0.04049429477059415, 0.009586344439802425, 0.028435962440978204, 0.020907906482794454, 0.019372787160266722, 0.01686264694269214, 0.06195719540119171, 0.16998723069471972, 0.11459049183343138, 0.11163324623235635, 0.09423903495605503, 0.13607361620025976, 0.11846404469438962, 0.056785805217389546, 0.08692454280597822, 0.11429581764553275, 0.09134266073150293, 0.11618659618709769, 0.1366955071155514, 0.1345014777034521, 0.1826205485101257, 0.10950808812464986, 0.12691662327519485, 0.11506457068026066, 0.18978681468537875, 0.09262539047215666, 0.1821516401001385, 0.1226986324680703, 0.13897625330303395, 0.16766578597681864, 0.19791318077061856, 0.13921861244099482, 0.14401650641645702, 0.11231839018208639, 0.12302084160702569, 0.10699215491435357, 0.13474655098148755, 0.12032572765435491, 0.07305585699422018, 0.1774622303034578, 0.12857195016528877, 0.10437995115561144, 0.11423503447856222, 0.1204959720905338, 0.19021932647696563, 0.16531460785440036, 0.1615927889943123, 0.22306306766612188, 0.15259263265345777, 0.10406958245273147, 0.15199820883572102, 0.1266337013138192, 0.10504071534212146, 0.1261255464383534, 0.10245998882289443, 0.10831217693963222, 0.129704425111413, 0.11458309580172811, 0.17177750462932245, 0.08295195775904826, 0.0898661549602236, 0.11025220355285065, 0.12703224564237253, 0.12410085222550801, 0.09865365842623369, 0.1533168466495616, 0.10616831162146159, 0.13062065094709396, 0.11630377918481827, 0.12717366591095924, 0.05104353638099773, 0.08945275071476187, 0.09700868598052434, 0.0854366376463856, 0.21114834557686532, 0.11426749559385435, 0.0872467587302838, 0.2179058486861842, 0.14210697316697665, 0.2381964341870376, 0.12746582951928886, 0.07328440115920135, 0.23174809877361568, 0.1377940010279417, 0.12116162851452827, 0.09910167474299669, 0.07368758666728224, 0.16742886868970736, 0.12725899847490446, 0.09035602331693683, 0.16839943160968168, 0.1147695572248527, 0.11961272305675916, 0.22217249045414583, 0.13205348620457308, 0.09881176387092896, 0.10040317276226622, 0.11418896195079599, 0.1528083796479872, 0.20423366661582673, 0.14321845423962387, 0.1813872568309307, 0.12322019519550459, 0.15006902521210058, 0.13781038086329186, 0.12220745453877108, 0.12820311209985188, 0.11054786161652633, 0.11744274092572075, 0.07018529424177748, 0.11351373818303857, 0.13671811590237276, 0.13182574271091393, 0.15656837288822445, 0.09230724575796298, 0.07050514207886797, 0.11107814351895026, 0.07495224023503916, 0.10116499116910355, 0.10963246359356812, 0.1337304719324623, 0.08696543132620198, 0.13135516510478087, 0.05980926565825939, 0.09506667125970125, 0.2417698438678469, 0.11176385743809597, 0.08721928484737873, 0.13103800426636422, 0.0639705987913268, 0.23692314965384348, 0.121076621647392, 0.08021367540849106, 0.1400812611516033, 0.13866860552557878, 0.1605308409780264, 0.19252753976200307, 0.2568075640925339, 0.10724236470248018, 0.12416333173002515, 0.13549375374402317, 0.20904845611325332, 0.08237814783517804, 0.11184363280023847, 0.1165560856461525, 0.0759455883609397, 0.14650435506233148, 0.1371685681598527, 0.14541580847331456, 0.1015459071578724, 0.1269594252641712, 0.1456755788198539, 0.12142243023429598, 0.14155258291534015, 0.1375691888055631, 0.11889359807329518, 0.146741353773645, 0.1347561590373516, 0.09606427380016871, 0.12108614827905383, 0.15992314501532487, 0.11229532677680254, 0.1861106748027461, 0.12099545528846127, 0.11470922189099447, 0.13711870940668242, 0.0696406816797597, 0.11388785525092057, 0.14515404323382036, 0.10383078562361853, 0.09101454155253512, 0.04921405330034239, 0.1539566916014467, 0.10324973573109933, 0.16474432631262712, 0.12656925405774797, 0.1376819477549621, 0.1656238298330988, 0.09142716548272542, 0.153887060337833, 0.05606499407440424, 0.08227815891483001, 0.13597682996519975], [0.022636603364454846, 0.025008293600486856, 0.007579456682183913, 0.02644974286002772, 0.03395707126972931, 0.08547789257551942, 0.02810221311769315, 0.02074966872377055, 0.011195307032072117, 0.027708871456395303, 0.023867650789075663, 0.024448117141478827, 0.021668761369905302, 0.04356872336938977, 0.07270590255835227, 0.06380038828189884, 0.03210307950420039, 0.0021342746497664067, 0.05942644298608814, 0.0393520998103278, 0.03190960881433316, 0.026240896566637924, 0.02479339816740581, 0.03371812855558736, 0.04174099090908255, 0.06390535086393356, 0.03982077751840864, 0.025688216223248413, 0.04433618040223207, 0.05195170122065714, 0.017590636986174753, 0.012246598655890142, 0.03890646515148027, 0.13509021539773258, 0.01569794667219477, 0.08007994972701583, 0.06309963802673987, 0.059490530618599484, 0.0468567106872797, 0.03367382361154471, 0.025728387192689946, 0.03650589307237949, 0.02068748607832406, 0.04787165658282382, 0.02911984940458621, 0.018712335099865283, 0.022171277619366134, 0.05132311316473143, 0.03848717122205666, 0.051703119916575294, 0.02129081397184304, 0.02557014604099095, 0.034056218806654215, 0.032026408439768214, 0.026423508999869227, 0.06612883548119239, 0.0094913351183225, 0.021710486184539537, 0.00908317934123001, 0.05039345233568123, 0.030573312126632248, 0.004526387093522186, 0.03363932689119663, 0.047900670740221224, 0.045340690429189374, 0.0833331790885755, 0.018620357981749942, 0.037158779467322996, 0.031198402334536825, 0.038665262915726216, 0.016524042701348662, 0.03307865001261234, 0.042287706929658136, 0.03437353231545005, 0.006424406027820493, 0.022363791574857066, 0.01171247030807925, 0.04072352086326905, 0.03316651351217713, 0.0671292268005865, 0.004608063625970057, 0.03196166602096387, 0.007479020776892347, 0.08772359242928879, 0.03439244308641978, 0.026727976144424508, 0.09069441551608698, 0.06258245185017586, 0.025507890453029956, 0.03881594518731747, 0.013569780958018132, 0.03624224489820855, 0.040995552337595394, 0.030296184854315858, 0.08888973628303834, 0.06126371904143265, 0.013648210276317383, 0.011166265733273966, 0.02391127380542457, 0.004768583383078554, 0.034685414151421616, 0.07543052599898406, 0.03662268930513944, 0.022344207357881323, 0.007388756959699094, 0.019864155079371164, 0.04002173584220665, 0.038478675963623185, 0.02496841609744089, 0.05030075088143349, 0.05567901960707136, 0.006141070584167859, 0.028994456133139983, 0.0087719124276191, 0.017684838002813712, 0.007873850974387355, 0.025128365461049334, 0.03689579625747033, 0.04960176820999809, 0.02454167863886271, 0.028942310716956854, 0.036712510378233025, 0.03209431961710964, 0.002599841486828934, 0.0537366452626884, 0.019654526774372374, 0.04192291293293238, 0.049278208786355596, 0.04706718885738935, 0.08420608724866595, 0.02343735102164958, 0.02356369763479701, 0.016717881496463503, 0.021634349466434548, 0.049717597530356476, 0.07437290025076695, 0.0035852463001252283, 0.02131104449342404, 0.04835871241188475, 0.019591285614296794, 0.04399549475471888, 0.03422441406707678, 0.022935001013268317, 0.016487864910491874, 0.02376502236750509, 0.05935601105115243, 0.08246425392904452, 0.02805017457077546, 0.03514263140303748, 0.02627193445472845, 0.024254117194297056, 0.0527697328611144, 0.025322619858863096, 0.02153219432303948, 0.02169566528339471, 0.011858602154201694, 0.05561677758981075, 0.019213304289483597, 0.010962471133098006, 0.03859291072668774, 0.02537654134045754, 0.021058062889746258, 0.04362723344404783, 0.045016058920217414, 0.038269632895077975, 0.05372139858081937, 0.03495875859100904, 0.07661032197730881, 0.022779682651162148, 0.04242409246840647, 0.01004415625772838, 0.012092140336920108, 0.06181499481733356, 0.024761325513411845, 0.029068379130746638, 0.028333998983725905, 0.0489416452390807, 0.04510330495291522, 0.01471829816832074, 0.024343850057838217, 0.0662348090804049, 0.016422292982627238, 0.054830820299685, 0.05142286799049803, 0.0329476893613381, 0.0602795650650348, 0.017289296191717898, 0.12543171724038465, 0.047251411114952395, 0.04330511251464486, 0.031201750904853855, 0.0814591467912708, 0.03720724722370505, 0.03218853081177388, 0.06223456694611481, 0.022472365659528544, 0.0019768680961403462, 0.03201998271314161, 0.010743114332269346, 0.0382726354125355, 0.05394367647490331, 0.028801029548048973, 0.024671821655439477, 0.016725978115573525, 0.022739959514832923, 0.046554477619273324, 0.026619958458468318, 0.06849973183125257, 0.03252722156633224, 0.07882752336029496, 0.020375348095382963, 0.06530655960419349, 0.022686555416190197, 0.0025217011820391883, 0.009429575709093894, 0.06597096752375364, 0.009204725319120501, 0.03345911477559379, 0.028544295645718063, 0.039508936394538195, 0.048668361867644956, 0.054418057269815884, 0.05067472206428647, 0.025723559416032264, 0.026721178919875195, 0.010778276016935706, 0.0093061484928642, 0.05910181826246636, 0.016129420305203115, 0.12500296453280108, 0.050799229847533364, 0.057650601491332054, 0.019167209709329263, 0.05999293830245733, 0.031074963243944303, 0.07572688295372895, 0.04309110935511334, 0.043796059742037735, 0.06519509665668011, 0.03903077955224684, 0.009916438155674508, 0.03422708410237517, 0.0403245829844049, 0.04027330270037055, 0.04136550320046289, 0.07169048168829509, 0.07081377373210021, 0.035013526545039246, 0.02048611215182713, 0.017719607833506804, 0.02907656565574663, 0.05349590103807194, 0.014450812878619348, 0.041973270409341366, 0.028063641794558083, 0.061202779811407836, 0.041568643014345846, 0.020294724564467157, 0.018040439546374337, 0.005222527127313826, 0.03152295920465674, 0.053126788165952475, 0.0740614187504564, 0.06253319699317217, 0.02737857078734253, 0.05547791539824434, 0.009802602880102183, 0.03067623571093593, 0.03747929226873176, 0.042893479245581796, 0.07009988025363002, 0.05332205018826893, 0.01654558618819075, 0.02980319523651685, 0.02687731322034129, 0.01802179679673697, 0.04608190172751035, 0.05426268971392086, 0.04107997566461563, 0.00838712539656886, 0.01914561872503587, 0.027419184500883733, 0.05111025672938142, 0.04046404228678771, 0.031400320785386224, 0.02694072401417153, 0.030959368018167358, 0.0732242286737476, 0.004318073026037642, 0.03792201940502439, 0.022366729631487812, 0.00596043692868469, 0.05357052631942289, 0.03369604563340545, 0.02174615507413234, 0.03635911576982055, 0.032428844166653495, 0.004870726228026407, 0.04650268843397498, 0.06622093303927354, 0.02185307183702077, 0.013300116722738104, 0.010611593889604722, 0.049877484129475694, 0.036536450896944316, 0.04437033785507083, 0.02887943766212889, 0.004321184533182532, 0.004822184256876686, 0.045872512606105635, 0.029979353105383258, 0.05026045947202614, 0.03723616299352475, 0.040438739715942314, 0.03574376593210867, 0.038369082380086184, 0.03675872200567808, 0.036451650982988734, 0.022962502037574137, 0.007245200153972421, 0.028680857603571246, 0.06578792591712304, 0.05830237508884498, 0.046618117418672354, 0.03329172357916832, 0.01698659493454865, 0.05057906559003251, 0.08659558902893748, 0.02578239858017436, 0.003432252556584509, 0.013876649268370653, 0.006698860296247793, 0.07786442432552576, 0.09921395871788263, 0.02732096316425928, 0.01759421286572303, 0.015960775515330688, 0.014643666101619601, 0.02289679609904332, 0.02364671809066619, 0.051012585006122074, 0.05257578719673412, 0.027105821762233973, 0.02730574192745345, 0.04650238987856677, 0.017376725428870747, 0.0349623412559075, 0.011268891610338219, 0.0377618647845728, 0.05061611020937562, 0.009233543549531271, 0.018983089232019017, 0.0889822273914303, 0.11883129498788289, 0.11894209975642817, 0.09189535464559283, 0.16473080989505562, 0.1597304953528302, 0.12777600144701345, 0.16756354432020867, 0.07369391061365604, 0.1073461737749832, 0.08240147586911917, 0.17346507550350257, 0.11840759058083807, 0.11471135249095303, 0.15691612208528177, 0.1475476705070053, 0.15130615739950112, 0.10584899304168564, 0.19733063131570816, 0.14330348824816092, 0.05348935317514198, 0.10941326285579375, 0.13191327372831957, 0.07077859169138329, 0.19132753701082297, 0.12141937682671206, 0.13078934832343034, 0.0967189311715109, 0.11394000745245389, 0.15635506861976214, 0.1476940983640296, 0.2031797117420605, 0.16999427388821328, 0.15644908643194608, 0.07158380919801337, 0.18774371860282763, 0.15378100531441824, 0.1416403582053525, 0.23138464827622685, 0.1360020036143916, 0.07649277935602836, 0.1317419707775116, 0.1292435098439455, 0.12023157413516726, 0.12935572596532957, 0.18290436613772595, 0.15634137578308582, 0.0838903309777379, 0.07162383597876344, 0.14094110072723456, 0.07699183507689408, 0.11826230266264506, 0.07981873410088675, 0.3049682698079518, 0.09677808585443667, 0.15791819617152214, 0.047014812739299874, 0.1115966189120497, 0.08184255978890828, 0.17359774267034872, 0.11734220917735781, 0.12050492875277996, 0.1766814807696002, 0.12719274631568364, 0.07311687086309705, 0.20272034353443555, 0.08108600002846547, 0.11497215421072074, 0.122597177912082, 0.10727150778153113, 0.1861610221011298, 0.1724411797310625, 0.1425769400915929, 0.14600939090762818, 0.11857902923864977, 0.1445335636713675, 0.09296708035149745, 0.12339950485953263, 0.13887228816747665, 0.13478876943034784, 0.10682756267488003, 0.11426042525896005, 0.07444880796330315, 0.2303857904459749, 0.20054934360086918, 0.07567091060004064, 0.21697017603686877, 0.19288982317915984, 0.11414018885365554, 0.1012810885107943, 0.06279557291418314, 0.11625595603670393, 0.15371473958449705, 0.10569919965096883, 0.22381086753947393, 0.14385156812412397, 0.14694563352635928, 0.13331793621182442, 0.07885016607386724, 0.05566030900393214, 0.1777404568025044, 0.18442508525082044, 0.1296986439930541, 0.11885398519890648, 0.07932467239775828, 0.08800545587603535, 0.26571765169501305, 0.12718273113880837, 0.07530240501676287, 0.1453314937118973, 0.1479567592697484, 0.1617401668003627, 0.06588722951710224, 0.13512161799839564, 0.1123973580875567, 0.07214745466730424, 0.18940697078193935, 0.09003721363842487, 0.16252728099269526, 0.09330362015004669, 0.10568594786205462, 0.13420214876532555, 0.19925009831786156, 0.14873262335147175, 0.2132884721670832, 0.12941566774887697, 0.1477037471319948, 0.08359138201922178, 0.18740468179540976, 0.16033254590417656, 0.14153571453477654, 0.12140419121299471, 0.11654631474188396, 0.16837910270052298, 0.14307965311620915, 0.2192203202950103, 0.1034886139844145, 0.12141677125224046, 0.13685934618115425, 0.13385518666888985, 0.12431091309658118, 0.15760693858776773, 0.06945550268782036, 0.09886127657123975, 0.1297945345618895, 0.17331366719944136, 0.16099620743521623, 0.12241965958050319, 0.09059413482568093, 0.07905303447374276, 0.10973711404949427, 0.2257818489202431, 0.10690150942121233, 0.05161563978929605, 0.13259810555194104, 0.06567737220653466, 0.1284585262515715, 0.1943168637475797, 0.07127804096255984, 0.13568651197212084, 0.09839118072496993, 0.0993088586255908, 0.09982972924730607, 0.12076900101133756, 0.18456658694360936, 0.12689701361315592, 0.08376383169421128, 0.16624829918146133, 0.14575233470116342, 0.2052466786865677, 0.06596573601875987, 0.09110458993485995, 0.1230726952531508, 0.10420218855142593, 0.06833296149436917, 0.11648135179919855], [0.026586243749729226, 0.010156469918521387, 0.025555803507034267, 0.034426661607410224, 0.0581279576623014, 0.024184061846296703, 0.03241018445364066, 0.03489466417314751, 0.035537260584533215, 0.05467546970716544, 0.02546828775666654, 0.013479162606277635, 0.043128371105662415, 0.05586480588785239, 0.038410126963364224, 0.05203126962961895, 0.04718310638730015, 0.053567673079669476, 0.03538211355251925, 0.03669865469315222, 0.0038284268895430224, 0.06672205150659595, 0.08749237483633415, 0.03656826061861856, 0.06175028293260506, 0.033074460058872185, 0.06766936103148119, 0.040220013952680995, 0.042104899417608976, 0.04728073739845838, 0.04792751697823405, 0.05549810181504913, 0.033193648127572875, 0.04843447084671684, 0.026837428931945136, 0.05115170164832047, 0.05906763366822686, 0.019121669831552675, 0.062171239272824357, 0.03342860444848027, 0.012982370647867876, 0.058511825278401375, 0.02536608850849526, 0.012127165466413965, 0.02115164983219334, 0.05262642287250076, 0.02924145645062838, 0.047440600248851945, 0.04641227703541517, 0.04815961327403784, 0.045104190441114564, 0.03220302092709711, 0.09259396073009286, 0.03633625931771738, 0.058816609638077874, 0.021281280554831028, 0.009221421521423119, 0.04051446422402348, 0.03543084593755858, 0.07404005168271915, 0.0295303664835436, 0.021241581167227457, 0.024551227322912643, 0.07042672378676278, 0.03322347991966775, 0.006421888662901307, 0.007364401793373483, 0.02405408337446196, 0.04374463696564947, 0.047604982142469714, 0.04348272244845118, 0.05014428070613316, 0.028299539582803845, 0.059929318859108856, 0.006573372453983341, 0.09927290305495262, 0.04037365802962865, 0.00906396662217698, 0.050502883070813756, 0.012493465810881128, 0.022060367677892958, 0.03809949363182698, 0.04306086365665708, 0.054914622767163176, 0.022781952350799526, 0.02651811544118183, 0.0403596768155694, 0.03526017741699304, 0.06078626109021051, 0.009273013083397277, 0.05376817339232989, 0.05341941996344498, 0.020880369835400155, 0.06978159983243261, 0.00812111931320812, 0.09145299052553517, 0.019657452956640294, 0.012524678421738957, 0.03538057327802692, 0.027670978668278882, 0.037998123892716, 0.04455807153135538, 0.046243627156530104, 0.032837122080049345, 0.029791901021131446, 0.04276062548160553, 0.11676359522555556, 0.017088514287024736, 0.006530564527825585, 0.03389315327097263, 0.049076599068939686, 0.02991878367694361, 0.015223721940336483, 0.028315960130255138, 0.09771851503423282, 0.027284685289487243, 0.08951360852058445, 0.11333737336099148, 0.06943758257797786, 0.030024251767567227, 0.0593513563009245, 0.04006047001374619, 0.05484520184940525, 0.03548342561615365, 0.03588751696848443, 0.005229418498596975, 0.048974998627922366, 0.02087560312689415, 0.08144606463611126, 0.014518805480163013, 0.06559112362031426, 0.027479396002101045, 0.006343556884010988, 0.03314284281805158, 0.013078930421865411, 0.031464242176817994, 0.0316574685940785, 0.01276799599041364, 0.045182052334504466, 0.02688425632991961, 0.04029680036806634, 0.03690065456820386, 0.045065184855567555, 0.023562511894851923, 0.03362316757972751, 0.0551671802864543, 0.033981851368610344, 0.03257500400234546, 0.024237394698762467, 0.040535349531897476, 0.022510674050343887, 0.03934940602630377, 0.028097912902012467, 0.027133809635415673, 0.05308022030762263, 0.06028881349733897, 0.05618263169058731, 0.04384531120636633, 0.07465813601655619, 0.056818395254335234, 0.04058985285727041, 0.024554779453735267, 0.04257134474547846, 0.02774352254346013, 0.016063953550266366, 0.0796352718025446, 0.05624482960307172, 0.015363284719309636, 0.07769308744796685, 0.02735395523320351, 0.045178870005267005, 0.05273331927933863, 0.025809209195098708, 0.05247545222352658, 0.018424459832853506, 0.03648391532312546, 0.0017478137576420391, 0.045544230578733344, 0.04186540709010192, 0.05647490047184484, 0.02826167393608817, 0.02845779600154076, 0.03638943610712886, 0.00861182396433183, 0.02906424685248307, 0.015850637407441224, 0.054641295290951214, 0.07285376212426595, 0.09917273093014956, 0.04671209451875516, 0.046058780646749904, 0.017915645082082068, 0.028465656829731803, 0.04720664815977216, 0.03005696733349136, 0.035431714462382455, 0.031776962003537586, 0.026936681641797935, 0.030407298356294632, 0.02248285581091685, 0.03118676206629191, 0.04552392541830029, 0.021030634807954942, 0.06792806607804128, 0.016181981324085166, 0.04077227021168385, 0.025083363322275024, 0.033541193764124594, 0.02253948973624834, 0.011576753126324286, 0.028347398354006664, 0.03037133939298136, 0.022696326320458735, 0.03168790428233998, 0.01801059248724154, 0.008359725304347063, 0.041203770986092944, 0.011444266619426864, 0.09152640801455293, 0.0125201008548694, 0.03887521182852132, 0.04799699896414365, 0.051461086475423405, 0.02714970601456506, 0.03996947507507034, 0.038206946437380145, 0.045214866288006306, 0.06316185290259974, 0.06184116591300283, 0.03182453748637012, 0.08299777922885758, 0.01884670538960823, 0.060950676910579205, 0.0433462588781757, 0.02995540081922497, 0.0331866592168808, 0.05451724551884191, 0.04503386028643165, 0.04394734590979559, 0.02212772415285664, 0.023758976620488932, 0.07114206254482269, 0.021310404974168966, 0.002175697940401733, 0.020825250739497796, 0.04252629002024021, 0.0787581160132374, 0.01774217251555196, 0.038375915227723975, 0.01908076774062855, 0.033369052822568586, 0.0363438283758504, 0.034979738893785646, 0.02411062060855329, 0.033388411426650624, 0.03659832989796996, 0.014278680418751069, 0.06979722649391208, 0.013233175850473344, 0.023816090609346117, 0.09422984080655233, 0.024816324169348394, 0.03199539938941598, 0.05357794949252691, 0.038314104080200195, 0.020826757087239196, 0.0225129013415426, 0.03928438540814178, 0.08015820517071656, 0.05889808812311717, 0.015513583618615354, 0.012876589582966906, 0.06068131886422634, 0.0350379470203604, 0.03865404673186796, 0.033466425990419726, 0.021959863070930754, 0.003711045844413872, 0.016727935689102327, 0.03736771057759013, 0.010185994673520327, 0.033584338413285356, 0.028705647880477563, 0.03194704698398709, 0.03499014422829662, 0.04286458383181265, 0.014893755449780395, 0.06881869757281882, 0.07049656539623227, 0.010030268342234194, 0.02273736920739923, 0.011425658644709204, 0.039190845963146, 0.0159915436857513, 0.10173328460327216, 0.023736004817432592, 0.044455195444503, 0.011640909460506268, 0.05639866027714951, 0.06682912433253867, 0.04531924532992499, 0.022384420735761523, 0.012173171837015875, 0.03002304397523403, 0.043461287527212074, 0.047944680521530766, 0.026083189761266112, 0.007959256480847086, 0.03593595079811556, 0.0431691951650594, 0.03368836461699434, 0.03669875308072992, 0.040536543753530295, 0.019262208004615138, 0.0436683594515281, 0.03678377012589148, 0.013932442658447793, 0.06372261459806136, 0.037801453910235844, 0.03287039065201368, 0.02866331408066409, 0.06980410683900118, 0.05206771035279546, 0.04849700124136039, 0.032033570376890044, 0.014257813770590084, 0.021535841448764716, 0.044338246541363854, 0.017445786723068783, 0.03234452601256115, 0.0207934715518994, 0.016316477142806565, 0.04941336278404508, 0.07364118165735688, 0.03658032836392522, 0.05584189515294773, 0.030644992566002265, 0.02619385882280767, 0.030857061900730644, 0.055898898879864385, 0.02034054433793894, 0.0703858488372394, 0.010219074952016984, 0.025735949465472783, 0.04979415324383548, 0.03626441942261798, 0.05492466508543917, 0.09204543302101748, 0.02236047014594078, 0.031997166973139556, 0.023715048263381635, 0.06656364072114229, 0.12221846037677356, 0.12064212853355066, 0.1271987852773496, 0.1548395063728094, 0.1406796747552497, 0.11110348680189677, 0.07097323624683277, 0.14201451598533563, 0.07628316631806747, 0.09420641099235841, 0.19219560043088027, 0.1180109190089362, 0.16637585019426687, 0.1540896844651018, 0.1301303008305175, 0.09144134007926498, 0.1408012682305915, 0.10846204496920109, 0.09539483793612037, 0.11825760720031601, 0.1046683896066887, 0.1481945722230843, 0.11584705726376601, 0.10411805699446372, 0.09937880880066327, 0.11335187365433999, 0.1668811687933547, 0.0962278414517641, 0.1241683800305639, 0.1674168450491769, 0.08800430236650364, 0.11230682794536863, 0.1109997048707945, 0.13726011610456876, 0.09476910651262317, 0.14028003119996615, 0.12070897780358791, 0.10371911233024937, 0.11635890336973326, 0.11155697211091008, 0.1511002763041428, 0.1519338022917509, 0.22898494132927485, 0.1274829828845603, 0.09465644934347697, 0.1670418730271714, 0.1326027467314686, 0.09994778755520072, 0.13316846851791653, 0.1024570439809135, 0.12414046509989671, 0.1747775250779731, 0.16527489998510905, 0.13865100432719502, 0.17894926693822655, 0.06205617330436196, 0.13994597483958515, 0.17325520462223462, 0.12826047545032843, 0.15864810986178263, 0.12914281524717808, 0.09839770144649915, 0.07930285071155854, 0.1681310302977051, 0.18458874789731844, 0.08683884383312293, 0.14515002630650997, 0.11236774681934289, 0.10783857985266618, 0.13410654318119797, 0.12898593795086655, 0.1661586511347975, 0.14049815306706087, 0.13711170692528996, 0.08674566740436213, 0.1733912101813725, 0.1790846482451473, 0.10587143219475235, 0.11313356179744005, 0.11125055926718883, 0.1306545098445245, 0.10274140443652868, 0.19175885458077702, 0.1341955398342439, 0.18381882778235845, 0.07567127022360053, 0.14370668732694217, 0.11670304276049137, 0.10220170446804591, 0.11686323130769388, 0.1455397361091205, 0.12669947849852697, 0.16378301861030714, 0.13003303962094442, 0.1473292229431016, 0.24375390740377562, 0.1755938162761075, 0.062247303048414845, 0.0948427411328469, 0.12721603363752365, 0.06334359850734472, 0.13853748541857513, 0.09228322561830282, 0.1357953218477113, 0.14920704146581037, 0.16191554096128258, 0.2466018817254475, 0.0771924846672586, 0.12344118048037801, 0.11573456972837448, 0.1559929751924106, 0.11663418502679893, 0.19700802862644196, 0.19425012304314546, 0.25566024280020166, 0.09790171948926789, 0.2393901129918439, 0.16959727661950247, 0.19450194095926626, 0.17573641719562666, 0.1739101537636348, 0.1280301535235984, 0.09389096006218876, 0.13032155271087373, 0.10720253469688551, 0.15948071304176534, 0.14323940740099975, 0.16350182012787887, 0.1410869721855436, 0.0846373030383672, 0.10283122211694717, 0.05964994563588074, 0.10189133576516594, 0.10423176589288882, 0.1252163773668664, 0.13451537410063402, 0.1109957422262856, 0.09798995618309293, 0.13229019993117877, 0.12303864636591502, 0.17713829768555506, 0.16921408075307096, 0.21827198618224689, 0.09465499049318687, 0.06720318711761918, 0.17257286980748177, 0.1269641885800021, 0.1521753878997905, 0.09915114673120634, 0.08410613225506884, 0.04502268820734961, 0.12799716315099172, 0.09689697197505406, 0.16500773360686644, 0.15125708574695246, 0.1001372616738081, 0.15399209755871976, 0.14756696804293565, 0.1612307634204626, 0.22501331301672117, 0.15557190350123815, 0.10397196161959853, 0.1271036546677351, 0.13761057944170066, 0.1120645570169602, 0.1550771157656397, 0.15241172164678574, 0.1538303755223751, 0.16887777165642806, 0.09905225025223834, 0.20683842684541429, 0.1511361300945282, 0.10514706892094441, 0.1690094753035477, 0.07998497518045561, 0.12527849046247347], [0.049210674195949516, 0.03474290981622679, 0.06726013656173434, 0.010689676306875688, 0.050486944283225706, 0.028511773462274244, 0.021905782133606926, 0.03263922394918544, 0.01875318630066301, 0.01880279738855149, 0.01931548148526677, 0.03764748074380415, 0.06378814751016242, 0.02670255143727575, 0.08113560093832867, 0.03136367310902902, 0.060091590508818626, 0.04850759317300149, 0.024556323120902692, 0.017081189501498426, 0.051282275534634075, 0.088011956241514, 0.06185358988919428, 0.03328939959672945, 0.02914002225069063, 0.0509387739667935, 0.044007141808313985, 0.034408965414123874, 0.041906804511589665, 0.015367642610466905, 0.02983608382887074, 0.0966418224519917, 0.04834330966696143, 0.018316986671249782, 0.025564488755272965, 0.035590294881590774, 0.02393587918153831, 0.04682380513155034, 0.0488896355299013, 0.024001140679631914, 0.016966612078249454, 0.05276518328381436, 0.01638159105953361, 0.017849900127787675, 0.09476441105029412, 0.026615656546450088, 0.03245809241863234, 0.11771202433322157, 0.052406625023909977, 0.026508638003308858, 0.03609317753996168, 0.030763240863702128, 0.0318860941832619, 0.048220145383051465, 0.026128958644611493, 0.009145069368449705, 0.03199780818873218, 0.05410061144669141, 0.025216169588799988, 0.04973490017333201, 0.04188984113612345, 0.1068872669711709, 0.03458162543496915, 0.010988011191199933, 0.03855052264407277, 0.026763168363166705, 0.038358161358961036, 0.018769630596839955, 0.02718065060409052, 0.052881758992693255, 0.10369861378733601, 0.06768453985984836, 0.009310243451701743, 0.057773416329707415, 0.035524002010268826, 0.011131852133465665, 0.062233773060142994, 0.03580578403281314, 0.04665816455547299, 0.03640488634950348, 0.023581056256911585, 0.04331735667905637, 0.053544884481068165, 0.0179703231302223, 0.020204971344875436, 0.012311407231858798, 0.06719300909233944, 0.06705183988170964, 0.014210088161884673, 0.019274582787017738, 0.05125415365078619, 0.058441820820527415, 0.04363323508628777, 0.053766568657010794, 0.017930050380527973, 0.047584330929177146, 0.017288934871820465, 0.030797866505703757, 0.033168437158955, 0.05633872527895229, 0.017862456418307762, 0.004191251014292772, 0.04572158266923257, 0.0022563859321443097, 0.02284128514916769, 0.06699712281780583, 0.027329938486218452, 0.03680342389270663, 0.03925880463793874, 0.08371787451739822, 0.025629193854651282, 0.04714870126917958, 0.058625283118869574, 0.0445661460980773, 0.00989603715217007, 0.031384531275502274, 0.013956517929078212, 0.029753702892256633, 0.035177701485476325, 0.09552468918263912, 0.03689916179116283, 0.0036075158194372697, 0.037967711953180175, 0.014873891337109464, 0.03061870951205492, 0.013778541586361825, 0.028880367255104438, 0.009986536760282303, 0.031441138059433014, 0.03350737557879516, 0.032439056118684154, 0.0362489963216441, 0.003102958239781271, 0.0622958725850497, 0.08784898570073502, 0.015542195744014211, 0.09066790515290839, 0.0414394940515714, 0.014941263079111065, 0.045036051954541884, 0.01318881831996675, 0.03708948068586843, 0.06720951784934316, 0.01675878867640027, 0.022419497603550553, 0.04210078749539597, 0.05533145022179399, 0.011204278961356198, 0.016242160594889095, 0.009392054418900182, 0.03614790817456586, 0.08971377635108573, 0.04186126124113798, 0.03035313429843102, 0.045578706943030865, 0.06315631605684757, 0.013992761877099318, 0.052933242837233205, 0.03187101374247244, 0.01736038800195924, 0.0020562212822759257, 0.03725707883547459, 0.027980533129136478, 0.07346812808620078, 0.0470220289592232, 0.020304429311571375, 0.022426023414092403, 0.031082698543156897, 0.027734029838549237, 0.07365207214440618, 0.09961421295468297, 0.023843406732859354, 0.020043259486556053, 0.05104045583201306, 0.007405090145766735, 0.04868277055876596, 0.040562009172780175, 0.027143438047330295, 0.032708244531282356, 0.047854411615324874, 0.06395448358463389, 0.03781796945258975, 0.02694127193119909, 0.04191211744078568, 0.006615328394608306, 0.04168293884556208, 0.04674622822286827, 0.06427448748477868, 0.03305670619010925, 0.040447292649852376, 0.00444071356573009, 0.0580022522647466, 0.012646292253131313, 0.08846337880407061, 0.02013164885076029, 0.054425022431782315, 0.04018367161708219, 0.05136899909536753, 0.053071901468294005, 0.0780610027057784, 0.048816374103937826, 0.027663380772407566, 0.021595040236466696, 0.05317483862329807, 0.02808830314981086, 0.006660177438919033, 0.03677575662732124, 0.026193906320258975, 0.04752997688150831, 0.0714906666960035, 0.035753747182232995, 0.009111399612655597, 0.04834781513948526, 0.035708533001265357, 0.008996451539652688, 0.03840811510703393, 0.04124965013137885, 0.01801175787113607, 0.04067769260810954, 0.020260265163545097, 0.07114172327731337, 0.008314643437708063, 0.03242786029087646, 0.052956940672759495, 0.030446941764759164, 0.013195565502558435, 0.012701100919262638, 0.044725194706448486, 0.015176870793636357, 0.050938451662659645, 0.007546204225426274, 0.039828163372086625, 0.060630069114267826, 0.04269147597785507, 0.022945833824841038, 0.05225215313423957, 0.05908587268952813, 0.02429623555924211, 0.015041944105178118, 0.017240458633750677, 0.005210122234919774, 0.02112696472821491, 0.0488202044341181, 0.006329213077801147, 0.062395440813686164, 0.07360237623964037, 0.03382481800924454, 0.07482200900890998, 0.03262594501887049, 0.04511699439691646, 0.04901773615607193, 0.022752559910129224, 0.06116803203310285, 0.0518071868323854, 0.024235328559630682, 0.057551453954407146, 0.06534537180726017, 0.03582761250436306, 0.033508797109659226, 0.037032012162464004, 0.028989200879420553, 0.030418711315308298, 0.06942002209169523, 0.03700544412380882, 0.02384961023926735, 0.016062628710642457, 0.02554207165459437, 0.04718455505956497, 0.03004088605354939, 0.022929309800799404, 0.010699811923716749, 0.07931755456541266, 0.05593997399721827, 0.015454651155908192, 0.03218316359977637, 0.05256974823506815, 0.001976915169507265, 0.03748876801026719, 0.07167402721409287, 0.03650744691757219, 0.029269222103591477, 0.016017423011362553, 0.013004463748075068, 0.027418051347402588, 0.06126502861401864, 0.020084687442119633, 0.04209087409877351, 0.02206053731164762, 0.02845497668853828, 0.02132236585021019, 0.019202588525201594, 0.11770624321486269, 0.039918931001531224, 0.04358925923172917, 0.057215355203620026, 0.024251492960112433, 0.0420127645401018, 0.02233323035761714, 0.05795597617647477, 0.006175516414389546, 0.02829435048624873, 0.030407654587179422, 0.01606962101400963, 0.009145783526556832, 0.021043113066947887, 0.017384365733180727, 0.016001759030457054, 0.025540526291089397, 0.013648160234359758, 0.0668527577072382, 0.04228427014978869, 0.03977942080902202, 0.05761964672378131, 0.006239887335271175, 0.012477986730768212, 0.007309398048424295, 0.02033832552842796, 0.03996499674394727, 0.024526503203170638, 0.01899189661656107, 0.008808566889326488, 0.04157446823748095, 0.056960178539156914, 0.040325054566242864, 0.05396591206746442, 0.03723643780020731, 0.0385453352438552, 0.01975946221500635, 0.07631476569388594, 0.04635395355788725, 0.020443819064114774, 0.007045272779318371, 0.0259011337267501, 0.039535836915352514, 0.008072930604352482, 0.036699299301419935, 0.013384754636457987, 0.008219691791704722, 0.06940259052706615, 0.05228119104036263, 0.040611318312585354, 0.0018305165743056151, 0.06751260587147304, 0.04342444986104965, 0.02178657370885568, 0.05212891081880246, 0.052728966477194, 0.01281388192104974, 0.024482586720426167, 0.08121584448963404, 0.06647823351834502, 0.006764499229445521, 0.1433247806770461, 0.21239598148635455, 0.13573076602603706, 0.12809256517461368, 0.17059834647391522, 0.1149415522813797, 0.09261064590620142, 0.11534100584685802, 0.13080865943006106, 0.05974673865629094, 0.2059146828417267, 0.1428990135235446, 0.18989073910883494, 0.20521281978913716, 0.13573548862976687, 0.12431765773466655, 0.15896144376269408, 0.15873243819390023, 0.056115022461329184, 0.109600694583995, 0.13010425865650177, 0.145192380462374, 0.16077166662684508, 0.128763419176851, 0.10298130727772202, 0.10390478665275232, 0.14875851624778338, 0.13645127522093908, 0.09454794480864491, 0.12179433527801718, 0.08293111994862556, 0.14619376244289534, 0.10902229776339871, 0.1418002074850457, 0.07577205302992038, 0.10989928391895123, 0.08866883920771734, 0.11925341162298407, 0.14211411135537283, 0.11051671007382018, 0.11241829767823219, 0.15592327607529505, 0.1126506891367691, 0.1287796361637967, 0.2669024281203747, 0.06961411703377962, 0.16706706024706364, 0.20725785648184164, 0.09980705260698285, 0.08073424068944794, 0.10292346216738224, 0.140389655317579, 0.13717532636863844, 0.1389524367238794, 0.11839871534279414, 0.130332259993468, 0.1847142090222665, 0.26362171130520956, 0.07768993904548031, 0.09141269233077765, 0.10338186685528074, 0.19841214828193188, 0.1657121479511261, 0.1338206356657403, 0.09101340161370379, 0.12514158923711094, 0.14101662167481013, 0.07502086726682526, 0.22932035475969315, 0.18804018412317547, 0.1567717298333134, 0.15670815110206604, 0.15816329659095832, 0.12436438165605068, 0.15569842314081533, 0.08235497586429119, 0.1419010649302176, 0.14366681660924638, 0.13402724957891873, 0.1248749385454825, 0.11004670922245298, 0.10697573436690228, 0.19134140626660415, 0.19478223020476954, 0.1143114510923624, 0.12512200671647275, 0.16350114159286022, 0.14697415913854325, 0.14164365588554315, 0.05144126307485359, 0.10058054181614093, 0.16890241604830536, 0.10149975320590393, 0.1599450752671276, 0.12407980406922953, 0.10186675922679049, 0.13408328300075872, 0.10504153636949402, 0.07647035377366201, 0.13747798012835638, 0.08041588562939848, 0.11034039953457457, 0.11349659838846751, 0.08693546721977846, 0.10825962440243789, 0.15208280858184609, 0.13885090074368886, 0.12224466539919376, 0.1046348021232656, 0.15974858509642736, 0.07424422286983047, 0.09755169041454792, 0.150120526020016, 0.15684250103575842, 0.08526588430894272, 0.273217607821737, 0.17518911084958486, 0.14227815398148128, 0.15765682448233875, 0.17393027911228792, 0.11900601775518485, 0.058235383326453824, 0.18050174149019377, 0.09275085159710475, 0.09243850157197032, 0.1264222969434091, 0.07549573321427618, 0.1236646899155208, 0.18489601569516317, 0.23925983426826342, 0.158365771440523, 0.0914784830861858, 0.18054317283843244, 0.15281312939311775, 0.1926999826516424, 0.0906445092654654, 0.15601725317537785, 0.11101446979280029, 0.11874892083661896, 0.08467060553708247, 0.11481176210301262, 0.12114230383719717, 0.11706371126430375, 0.11053420270660094, 0.09489190099494797, 0.15703709130840643, 0.10810202107365642, 0.16844607410686357, 0.10863234368818146, 0.08176285906561784, 0.12507370859384537, 0.13435129076242447, 0.18926612048276834, 0.13265067844518594, 0.15415280179253646, 0.11752671641962868, 0.07036953685539109, 0.1366529901112829, 0.12972379050084523, 0.09791740043354885, 0.09757884538599423, 0.1322053423417466, 0.14335840887257031, 0.26183388009667397, 0.10058008719767843, 0.14737452194094658, 0.18806273862719536, 0.13241575605102948, 0.1150787113500493, 0.16525501890906266, 0.17258939892053604, 0.09879471907126051, 0.0896315582628761, 0.24387620655553682, 0.15582867472299508, 0.1493569298514298], [0.08280470208930117, 0.06130855663546494, 0.029990888200700283, 0.037492676371974606, 0.05859147850424051, 0.004995689901988953, 0.0473109491701637, 0.07841593758868319, 0.015842695155047944, 0.02059924090281129, 0.014353524527645536, 0.012279069949207562, 0.041641504104648314, 0.07968160895896809, 0.03140017490035721, 0.012755819679503995, 0.048248749026762586, 0.0014891317176599322, 0.03319111379927822, 0.06879046373069286, 0.062100834479289393, 0.04721009851034198, 0.033694864982473, 0.0877983398469431, 0.02613535214082471, 0.04382024612277746, 0.06314735939460141, 0.02768753661907145, 0.0419101971866829, 0.027228712935798934, 0.00442621496871912, 0.012500833004846104, 0.040589676438165564, 0.04636272023032818, 0.026127844150843363, 0.07004464750311204, 0.008150125837086566, 0.08721235700483833, 0.11344408656337432, 0.031110691505351236, 0.041963214520365, 0.06421124802104064, 0.011656834677393948, 0.0949645381686943, 0.024248546421793953, 0.04200858476438692, 0.11501442694238254, 0.026878341200894544, 0.05099665639655931, 0.01835235022008419, 0.0702465388125607, 0.03899287319343005, 0.04761296171428902, 0.0437719785342259, 0.013263151831259685, 0.0480216229999704, 0.06360514661563293, 0.050154730145420344, 0.0943708810955286, 0.024771797005087137, 0.014139202456655247, 0.039010813659323115, 0.014294707415891545, 0.05207198851608804, 0.03521652725924339, 0.028748395586652414, 0.014035667342666005, 0.06651942737932716, 0.015537897224671074, 0.015440556287233318, 0.03779774232368384, 0.05833899562380143, 0.01049449825326779, 0.0870672862178513, 0.038835687163685045, 0.060156166686543396, 0.016390902256327014, 0.026908016929935132, 0.07906021337424006, 0.03646329464390874, 0.036710410312350304, 0.011703299907302218, 0.03013665448608143, 0.04874453081616333, 0.01625043193676642, 0.001846684155420267, 0.09740138133721692, 0.029313391340630393, 0.09546439456088202, 0.02299490038837705, 0.031134633613484244, 0.01687815486054335, 0.047796569897660186, 0.05120972317776509, 0.08616413575197969, 0.04611444426700473, 0.012456402531825006, 0.017777115372674804, 0.04500115829120789, 0.09970409170325313, 0.08372331636824779, 0.02990774730486529, 0.027740838937461376, 0.030894998793623278, 0.06073668732174805, 0.026192198108349527, 0.03714063544092434, 0.011047746021566647, 0.027633423451334238, 0.05397431233099528, 0.030276727862656116, 0.027295648719051054, 0.07435317523777485, 0.03476481292662876, 0.024117572199819342, 0.06781561925475087, 0.024699570345027105, 0.04941025170098458, 0.033022324820714336, 0.07929964124092034, 0.017940070646415864, 0.032489362704966745, 0.08749930267887455, 0.035741587834698815, 0.022177961189299822, 0.02512225186053131, 0.03908347458179508, 0.036354912245380025, 0.028694767571453537, 0.019213165189804773, 0.05045574863574334, 0.014093392013039972, 0.018891685475994433, 0.03830027553652014, 0.007500333561828094, 0.020111771167388985, 0.03330733666994742, 0.003093303746676871, 0.029716220617826496, 0.03987664469916906, 0.03954724308901599, 0.02905832663444536, 0.038924398832023144, 0.029430475950773274, 0.06566895837230341, 0.03352679864370397, 0.06724430633974926, 0.023653793514573147, 0.06081989607108491, 0.02858252770134381, 0.013362153483155583, 0.0569286063047392, 0.07635874833379473, 0.08514938663159098, 0.045100743483219824, 0.08631705040378229, 0.008835601420806987, 0.008384864178619214, 0.038410109999988756, 0.026756520416321497, 0.07691894005984068, 0.014315278901319419, 0.024718649053413953, 0.060502945578524044, 0.034151590296200345, 0.08520442939230374, 0.034803513171417375, 0.04406749749822276, 0.0452860038993614, 0.011988388091724898, 0.020414828655443022, 0.018579091178253293, 0.013699414225162139, 0.03763891084651862, 0.041321886969464164, 0.05882009730807372, 0.031127000094524453, 0.07846169120499066, 0.04996732895129493, 0.014697984526199954, 0.030330304987728596, 0.02263856602699629, 0.017826499151332036, 0.04417228026847754, 0.010344026327532316, 0.020308802469766567, 0.026773456650386964, 0.03022272326052189, 0.027304981968232563, 0.027899471943133643, 0.029037122415112596, 0.07137572286384446, 0.012441466279727007, 0.0354067884784724, 0.02239367425707834, 0.017482449666463902, 0.002388620320873867, 0.015695368239123906, 0.03520453415278878, 0.03561466785946062, 0.029164432547986507, 0.019831225774916153, 0.04533496359363198, 0.02385990700817534, 0.06704597055379834, 0.05971566853778703, 0.021533839770459702, 0.027029859766896282, 0.03345221746712923, 0.02747127054525273, 0.022934032404529195, 0.02872047047795994, 0.01842409512028098, 0.06152308226696082, 0.009448178594798913, 0.012045172142929264, 0.023477647520069565, 0.03169895422511867, 0.0507833962328732, 0.016260533626856546, 0.05103151613314237, 0.030928165585334812, 0.08417811124984707, 0.08596052774893385, 0.07144462809498821, 0.010153609893417783, 0.029905039950140884, 0.06908374013645308, 0.02786143496632576, 0.027966767349945645, 0.023563857090526392, 0.03104455808975867, 0.05638691822865179, 0.018161781963759234, 0.04522492217698267, 0.044813733348356824, 0.016603451654581085, 0.038963105862161944, 0.038182793983391354, 0.03372154158673116, 0.008907984992090081, 0.014107129802661282, 0.014546995217512761, 0.061751572149140496, 0.026910805708861778, 0.05554271549252527, 0.028250250799049224, 0.04866065370983311, 0.002466842473950237, 0.030207116955092976, 0.019133198141519512, 0.04630069195159844, 0.008049564402816551, 0.02452143793925643, 0.019026164331340363, 0.07124921679496765, 0.019910946854257157, 0.028270250618723885, 0.05279769189655781, 0.04416837529944522, 0.04789338666679604, 0.02275888724917812, 0.08522011712193489, 0.02030830205019031, 0.0300395764809634, 0.0583516638725996, 0.03482097527012229, 0.018541442662743584, 0.04488979373127222, 0.003672592416738293, 0.023179085326514075, 0.035693486487226825, 0.040081239970667024, 0.0347634863906673, 0.034772772142397504, 0.03230086228411112, 0.057814236996429305, 0.030098663310387304, 0.040139308997562954, 0.032064196054956744, 0.0140474797891719, 0.05661661929583975, 0.00645017297106928, 0.043528672839914045, 0.022684021087895547, 0.029423246160149574, 0.07330557145178318, 0.04140651385699, 0.017598095782367245, 0.016961283882015517, 0.0745739433914423, 0.02424902648531965, 0.02748236120013254, 0.013552142440208366, 0.018001688411459327, 0.05783291028014251, 0.018569182870643478, 0.020282633070434843, 0.1016850204073957, 0.04565560870936938, 0.03529420934085335, 0.03512753399887255, 0.033667475916445255, 0.08149957390768187, 0.008409755387609559, 0.03827858616464904, 0.037664260914815326, 0.025412486733070443, 0.030209892163319246, 0.04946276352607778, 0.04959153250924178, 0.0223871925513127, 0.01680259489720421, 0.0426002401592476, 0.07660441193729639, 0.05663726033110704, 0.025631209103656665, 0.04569514015955584, 0.02172904581363712, 0.04061271948739886, 0.03928913515327232, 0.05438087694346905, 0.02827958556424294, 0.02515687919887049, 0.05253850169745939, 0.05553127199943576, 0.020460848596745303, 0.04775703166212354, 0.04339068256584661, 0.04425821333591427, 0.05179562120299254, 0.044724930077791214, 0.01432218638780926, 0.04807253687509468, 0.038349106309137175, 0.03861815562205655, 0.03682682317282472, 0.03822180974696364, 0.0068939285119995475, 0.03637535311281681, 0.05658181044938309, 0.044253500910209756, 0.06045712410871472, 0.056476871616074016, 0.023185002151876688, 0.04538690884198461, 0.005602428706229797, 0.045814687851816416, 0.010011768084950745, 0.04081989997731788, 0.024536662568737353, 0.04772543228630509, 0.1809995962040765, 0.1392345308725323, 0.18687790791903222, 0.11145816384149448, 0.14094038148011478, 0.07219160015561751, 0.11954586021602154, 0.149289551324078, 0.12077976257673331, 0.0937703979600753, 0.0927857690091644, 0.10909762193581887, 0.10989621015531675, 0.1853154046194894, 0.1573559891964708, 0.09154122721936021, 0.10069743982915368, 0.10450419770287615, 0.12081332291875567, 0.15640800792191709, 0.17289761666740688, 0.1579149934862341, 0.0886015421045678, 0.2002144187156643, 0.09216737254921879, 0.12228213410292353, 0.12194631355149405, 0.10975643872682538, 0.13025428274912493, 0.10814134896333728, 0.07964161610496895, 0.10795649566820689, 0.11088195190365825, 0.11048745164381606, 0.17965518763022764, 0.1386669906122344, 0.09664957132190466, 0.2008499481848308, 0.2883703261613846, 0.10429651848971844, 0.08891145618898527, 0.08263769426516124, 0.08201144036969968, 0.1380173069025789, 0.08939477668276855, 0.1296963912567922, 0.1640422461288316, 0.2559070666985852, 0.1420222512845482, 0.0884973666231547, 0.10904042143374681, 0.1182497361940997, 0.08969120827636548, 0.10549567985747542, 0.06255368196538516, 0.1072449634916016, 0.16101872122713498, 0.11810368831668581, 0.23757193769727433, 0.11543491509343896, 0.14027195663324424, 0.1544745766690799, 0.10908949308629547, 0.10106439835258893, 0.15078975153820856, 0.135846361251814, 0.10583232822162764, 0.22672702105981962, 0.1474490115152938, 0.13662164179342134, 0.07206376415810414, 0.14532985165715218, 0.06490597288523402, 0.17202179080673627, 0.1122210475483111, 0.11862780233579022, 0.1031525559457285, 0.09917357909892287, 0.17053889323558125, 0.1748461385390588, 0.06650967683110919, 0.0927351638674736, 0.09996610121535403, 0.13443275567676338, 0.12782952428928443, 0.09666945239795105, 0.11317336466163397, 0.08595682294773203, 0.18462308176926204, 0.06281584075519017, 0.10565039262707744, 0.13091027683445386, 0.11384898876505238, 0.13935049250721931, 0.1245112166340862, 0.17732322561953748, 0.10747285626296486, 0.09922100869672638, 0.16300663884196961, 0.1972835816975151, 0.1735727454402617, 0.12940728105604649, 0.12983622375343526, 0.09239088876971177, 0.1747106893786362, 0.12580506077834538, 0.1643167949680771, 0.10338124260306358, 0.10881071018853358, 0.1846002015684332, 0.21629147816981587, 0.16230871129248822, 0.11559145312224116, 0.09082333716963019, 0.17326862604490348, 0.12437504822654383, 0.13874998901571545, 0.10610269049980811, 0.12589358245687826, 0.11756608502141067, 0.08780342207423278, 0.10412347848926272, 0.19413269577281816, 0.09326078423431941, 0.0971770848014525, 0.09941670498145477, 0.0994260348379612, 0.18967139587870666, 0.14495889656245708, 0.18415825814008713, 0.12196532610271658, 0.09239440358110837, 0.12300201904560838, 0.11886036342808179, 0.15510083734989166, 0.15988194436899253, 0.07711896539798804, 0.1596638767846993, 0.1983116301042693, 0.10236405075660773, 0.08323892378913504, 0.11269257510347025, 0.19091638550162315, 0.14765441763613904, 0.24435682647994586, 0.0817399313673377, 0.11185866913625173, 0.09621245906289135, 0.08215520836945091, 0.1742402474795069, 0.11952067299612931, 0.08330731333366462, 0.14545101087008203, 0.17770525440573692, 0.09105837491473981, 0.18530240388853209, 0.08429407966988427, 0.08967292854296309, 0.12118005752563477, 0.11948351641850811, 0.18072043332670415, 0.0899591821112803, 0.10108009965292045, 0.1539257096924952, 0.15670079578246388, 0.1346705686300993, 0.0787096686129059, 0.16653759937201226, 0.15995241701602936, 0.15000616572797298, 0.09147289195763213, 0.10883740375616721, 0.10716241970658302, 0.09829704756183283, 0.11902816513819353, 0.16836167792124407], [0.04254219827375241, 0.05844555276312998, 0.013152046810968645, 0.04943284013175538, 0.030974852187292914, 0.03602489995371018, 0.041043575653540235, 0.019642869542751993, 0.035519784915127924, 0.02866262197494507, 0.06612800766846963, 0.01852781937590667, 0.003606111251948667, 0.054039251524955034, 0.006947193086879062, 0.06497343962213822, 0.0670557278873665, 0.02997298166155815, 0.04826374125799962, 0.046377709068890126, 0.048072448665542264, 0.05958849750459194, 0.04902059278850045, 0.022747436970738426, 0.007040565018542111, 0.05303928428994758, 0.011197315495727318, 0.02790938364341855, 0.004843746827516172, 0.016299512071002806, 0.018909868518156663, 0.03128724292452846, 0.038970549391316514, 0.047369150511388264, 0.04223896436659353, 0.021622403857431242, 0.0676632813577141, 0.026365568894626837, 0.0453952480373638, 0.028215901660067693, 0.028701335790434053, 0.007366402623509722, 0.00743479047170175, 0.05140183340491993, 0.046902884995298724, 0.025825470286820616, 0.02614045811684004, 0.022173708471070443, 0.023425804051969732, 0.006015768490864762, 0.02908435184508562, 0.04038693356726851, 0.0502036016301385, 0.0387229044655604, 0.05495282428871308, 0.014411583376516188, 0.07051534046019826, 0.03616930916905403, 0.0475333966980023, 0.05545367473470313, 0.029479544210646833, 0.05705819292260068, 0.043753841293177435, 0.03274202200451067, 0.023850383769188608, 0.08002264065934078, 0.05227864992671779, 0.03357137839442917, 0.058180048795683045, 0.05324567767924496, 0.020159709666456496, 0.024123885968167866, 0.033271510020962784, 0.07059872562863997, 0.016246331888916235, 0.04193240903051836, 0.035423589005534134, 0.04098675852375371, 0.044695878600967784, 0.03444999303402645, 0.07183913514018059, 0.07257473495389734, 0.05541881499812007, 0.03532933031341859, 0.15701431967318058, 0.004823835641478321, 0.01284684260774936, 0.03172254688771708, 0.02046005810344858, 0.019427684035950472, 0.012530837823370737, 0.03898404545283743, 0.025606218658919846, 0.02352238672652415, 0.09102166617023093, 0.02421182580292225, 0.02222916004913194, 0.05463013338989445, 0.03669884129028235, 0.03868055370237146, 0.021624576865828464, 0.00970305670385382, 0.06978840553866965, 0.04440747068396636, 0.013038770478617932, 0.04253174883446523, 0.017623944573902657, 0.03222760085814765, 0.018377464497461915, 0.04081042084310736, 0.016599219292402267, 0.021441620076075196, 0.031590880560023446, 0.008687748640243496, 0.019734926388732026, 0.024665126211142967, 0.053216568526944945, 0.02176372573844024, 0.036008774568992, 0.05886104011109897, 0.022649059571059685, 0.04663013766652771, 0.010501375205681791, 0.05879974125751427, 0.011947150974135314, 0.005487892843250717, 0.03248727281710931, 0.036028611540262184, 0.03897537038262401, 0.030239109881222248, 0.05194164193900568, 0.03745707703222122, 0.0502084192287709, 0.027756974500204836, 0.03734256067712392, 0.004931427122625921, 0.036211015323975256, 0.027620782343936816, 0.014744862814300826, 0.08361303407166686, 0.038055076729506254, 0.06266724837145635, 0.0114862806596128, 0.03861264591770513, 0.02425975921297712, 0.01969784444996289, 0.08773818093218974, 0.006772562769973385, 0.02157407350439046, 0.023273515348721827, 0.0646740428305098, 0.008406342356465757, 0.053081478990082226, 0.06554030134741749, 0.03320007385419948, 0.03911163717774408, 0.044540870668632646, 0.06863313860126904, 0.05024713304425989, 0.038583529980054924, 0.016138003773189018, 0.028989862451063733, 0.005661383221325065, 0.05983288546225854, 0.008457497959690434, 0.01664893385688109, 0.020490612535338317, 0.024333349728424634, 0.026270640149180378, 0.005457563600170293, 0.07042774158929076, 0.008270756640870656, 0.07855719500886542, 0.04289805257160749, 0.03908297585855637, 0.06228665807949645, 0.05374252137594989, 0.030857485985117297, 0.019233884256599203, 0.034452089707234075, 0.0318573310838214, 0.056369412025170665, 0.04340171554524984, 0.04168697273624795, 0.010521912764358734, 0.03382806819198387, 0.06170965904103858, 0.03381432446518114, 0.013229929060409111, 0.030627516896596978, 0.015231565805152059, 0.028476252154048, 0.01852782955393195, 0.011046638313148702, 0.0066570892564154095, 0.025780846431319202, 0.02810465414742274, 0.012178635740253543, 0.04721920105761715, 0.03484978925968919, 0.03434589219146541, 0.032301313509898524, 0.01724852471878486, 0.028015898374308432, 0.01548114455571132, 0.04573290741869381, 0.04012967040762305, 0.01753568752402706, 0.08184437826275826, 0.0341682279748576, 0.0123296292897846, 0.013390843640081584, 0.03844476278339114, 0.006058801181747445, 0.0738041250567351, 0.005389314427572701, 0.03584780909919313, 0.024635559047705362, 0.036287903519613404, 0.01899803735847984, 0.06720503951822009, 0.016227884218096733, 0.09204724470951728, 0.04123951281820025, 0.018591747552688633, 0.01760508299672178, 0.039597234156514914, 0.05555368061842663, 0.029290110804140568, 0.05384233726986817, 0.05320993584713765, 0.02376417928774442, 0.06947231678558247, 0.021660220310358063, 0.007433984711367104, 0.04316855055679168, 0.021370116055810025, 0.06588987580367497, 0.007636917572069381, 0.022385090789092437, 0.007830175371574504, 0.05494140115167413, 0.047968266398778985, 0.03657164311568652, 0.015083658741787076, 0.04627881258992212, 0.015211024853800024, 0.04796223761513829, 0.051585716394973655, 0.08157841289149863, 0.027793893590569496, 0.022605097287201455, 0.06541027368179389, 0.04666345712861844, 0.032974959683737586, 0.011683054118683296, 0.051210812226470025, 0.07109884664948497, 0.006006356361987335, 0.11636435879128319, 0.026065023682479347, 0.014736935828945466, 0.029778859578073025, 0.020467956251065646, 0.037505371762173514, 0.03835611218320472, 0.03919701384646552, 0.03541504285697426, 0.05703945178538561, 0.03522496484220028, 0.13107897421079023, 0.009907372927825366, 0.013904520094261637, 0.0191894571762532, 0.02165940946101078, 0.05643739105601396, 0.03463463598330106, 0.0682954452931881, 0.062262135823922496, 0.01032102229406259, 0.06647067463823728, 0.06677339625145708, 0.04167532568265285, 0.007648107462695667, 0.027178545449195162, 0.0545224736311606, 0.02343067084439099, 0.021717907661306005, 0.031745922419109514, 0.019444772940395132, 0.03448094101622701, 0.026148949982598424, 0.016431080011118735, 0.02641327160277537, 0.028495071322790215, 0.012773158793736781, 0.03011201009420412, 0.06550300227744238, 0.04487649105223162, 0.04302477237901517, 0.02385770176936473, 0.03270529290395124, 0.036946801734822135, 0.03184525655316455, 0.007711245994349676, 0.028439032811937586, 0.03882221145821469, 0.019897937641612122, 0.015237935552639621, 0.013885683962143958, 0.04671252199581691, 0.03445217452411141, 0.048767322807439735, 0.0848360595160297, 0.013853139726312032, 0.035500467023147006, 0.01604241006342428, 0.047143557973738225, 0.046240824806903086, 0.038902794277029376, 0.027942304466185824, 0.01981261695202972, 0.09663427714258432, 0.05063397264374154, 0.02567971926847739, 0.06151382704930646, 0.02442502829113177, 0.021054977251748954, 0.07206126036388533, 0.051533112967652936, 0.010216105513141623, 0.02392928721383214, 0.0036079085215793122, 0.0433801958071334, 0.019869038835167885, 0.02742788501616035, 0.005706664407625794, 0.08103781725679125, 0.004203087209524321, 0.01928638251099203, 0.06155056972056627, 0.07905534149280616, 0.04157886514440179, 0.03672114134367023, 0.026916710659861565, 0.01172392737186913, 0.05196111589404089, 0.04446576362741845, 0.03793100320867129, 0.019386471515255313, 0.05971310367541654, 0.028849056256668906, 0.12331942415663175, 0.20109743704753263, 0.1251219388629709, 0.14590543934277125, 0.08180339474763189, 0.12961199507117271, 0.15936781838536263, 0.08368653977023703, 0.08295660572392599, 0.10433964617550373, 0.13164259253868035, 0.12750160188547202, 0.07712182203041655, 0.11316343090896096, 0.08272897758122001, 0.16874021903744765, 0.1593670177140406, 0.09027147785361324, 0.1384128656770502, 0.14593203791550227, 0.09747166399444852, 0.15661733597517014, 0.14071630207555635, 0.10668678701456104, 0.06357909087091684, 0.0645025498898966, 0.1212178383554731, 0.09525060174720627, 0.15717457607388496, 0.10500097354607922, 0.11189318621265036, 0.08848432518009629, 0.14118540047534875, 0.1998103375413588, 0.061729662253388336, 0.16772489994764328, 0.1080874732828566, 0.1028073580403413, 0.09485261381736823, 0.14117619954049587, 0.14256134735686438, 0.1007246830101524, 0.13767323536532267, 0.11711127656911101, 0.08362399241221802, 0.10149657766201667, 0.1436744297721556, 0.19113084327961716, 0.09252586974097149, 0.07496630626597575, 0.09575713492397751, 0.12368330891643252, 0.09513972912515913, 0.15965842136314937, 0.20702555323285715, 0.12982086172061308, 0.22032074124685355, 0.1334658839872905, 0.10083222402525799, 0.1433730109461716, 0.11426480859518051, 0.17729479500225612, 0.11824153949107442, 0.12260890299720423, 0.10294638986566237, 0.13836477111492837, 0.15415058976837567, 0.1083239291661552, 0.10627901460975409, 0.12711692681269987, 0.11443894782236644, 0.159067105235798, 0.06135527377149888, 0.1732796590243067, 0.07511813526174851, 0.19750813607658657, 0.14899518926228794, 0.08403251120554549, 0.08366122362869126, 0.12369725959641592, 0.1446134950965643, 0.1323780837867941, 0.09880881902894803, 0.1391065998801163, 0.17874690065426485, 0.10772170898105417, 0.14261594228446484, 0.15477948316505977, 0.13116467318364552, 0.15210719513041632, 0.16065205447375774, 0.06664967217615672, 0.11322482475744826, 0.16895846304084572, 0.18964033254555293, 0.09185741775270019, 0.07186222568686519, 0.1558728880648102, 0.13720826245844364, 0.14331023288624628, 0.13996459384049686, 0.11998456024697848, 0.22744611890188285, 0.09222120073224817, 0.11563968339136668, 0.15526587063712732, 0.0747769135715706, 0.11668936349451542, 0.16608683498842375, 0.09858578456831829, 0.06396521800862891, 0.1325892031724964, 0.20054958787347588, 0.10986198484897614, 0.16954052395054273, 0.15472613674189362, 0.10180816094258002, 0.08904007928712027, 0.12160634036575045, 0.10135688087237732, 0.08156868269933121, 0.10702743873532329, 0.08397898157792431, 0.17880708671041898, 0.07349739330155508, 0.10462359951010772, 0.11572213896683284, 0.1675735730677843, 0.1632307453879288, 0.08922716496246201, 0.15332725537674768, 0.10323015321046114, 0.1905777422445161, 0.13807682799441473, 0.18113391899636813, 0.227856700441667, 0.09816144912370614, 0.17955628436590942, 0.15728980489075184, 0.11963335052132607, 0.09045168996921607, 0.15419432813567774, 0.1195513563496726, 0.09833674186042377, 0.12386051512190274, 0.07770630531013012, 0.21551699829953058, 0.13643120415508747, 0.14569700695574284, 0.10976183308022362, 0.11727583488183362, 0.11577809096447059, 0.1832539066672325, 0.11228109789746148, 0.10730597057512828, 0.11808512359857559, 0.10493554241423096, 0.1344200942133154, 0.18106857607407228, 0.13127144745418004, 0.07217826015715088, 0.12709572937871727, 0.07641743482755763, 0.20193461355354103, 0.21733838985008852, 0.1435995330767972, 0.1063722385359662, 0.12414313852787018, 0.14403120348496096, 0.06576833661113467, 0.15034832379647664, 0.1602553693311555, 0.15714396057384356, 0.10575019834297043, 0.10639115609228611, 0.1958853652966874], [0.01623115306054907, 0.020754932459177713, 0.02230080825808857, 0.04430231471945133, 0.05902562556522233, 0.031009749243302003, 0.01968410750851035, 0.02648661614927862, 0.04140866481299911, 0.041775114435170374, 0.03836897720715829, 0.04647018660658172, 0.0167544053401798, 0.03211143227027995, 0.031639721510665755, 0.018534173856356313, 0.009219569120822209, 0.01371206805509116, 0.03713575338146516, 0.03140823250370366, 0.020589527674019337, 0.027572784473055174, 0.026488694162773233, 0.025560003638799702, 0.01638928903932018, 0.03544262869815741, 0.07959631710712399, 0.016581577381917408, 0.05472346588170954, 0.03790039788665516, 0.09516851936600038, 0.034502990011657984, 0.014654797468600529, 0.05936202287141766, 0.06370394131434814, 0.024970818111406903, 0.03490149023543511, 0.03480290588257568, 0.04028278861993125, 0.06102325301617384, 0.043580234715981145, 0.009242782651978945, 0.06907014229467937, 0.011846082334938859, 0.0253262839479638, 0.0321846529841423, 0.03526383132806846, 0.01312822090195758, 0.007787044293114117, 0.029925657236682515, 0.027703984307923486, 0.06625762821308204, 0.02558158105239272, 0.0411685482332749, 0.012701687003884996, 0.012087423670371729, 0.07145171878593308, 0.00603877634109397, 0.03468324283936194, 0.012331913408291127, 0.021892146972407187, 0.045945774032069106, 0.05100923304312995, 0.08443443463849169, 0.062423993567270894, 0.09881595721734421, 0.018974022307832326, 0.03693410295194813, 0.026256684380184327, 0.1162226806793894, 0.022558308904990554, 0.012666156365802246, 0.0364956438009228, 0.06349653351519789, 0.03191218385472894, 0.022076277627742717, 0.0254254094325006, 0.01264887153437095, 0.018758857157081366, 0.0065573386714926785, 0.07995277190847055, 0.05123787898836391, 0.05691493721678853, 0.05745162788246359, 0.03200651040034635, 0.0061758073362787914, 0.021977433735238652, 0.010673466953448951, 0.030156488064676523, 0.035846628448260684, 0.025938702514395118, 0.020190981649128453, 0.05439734498837164, 0.049269082490354776, 0.003985433531592467, 0.0427172637012388, 0.07541265338659286, 0.04975386522710323, 0.041606529017112086, 0.05623182887211442, 0.02162080760379987, 0.05669145831572158, 0.035287328995764256, 0.08418628759682178, 0.014057538222654589, 0.024645055145291344, 0.030785632519317523, 0.044113475031086376, 0.0181952591852418, 0.014332690109897937, 0.05713089116449867, 0.022339632335518087, 0.12400980639670577, 0.03427072747477463, 0.012653192106102194, 0.03901527841974582, 0.04358287760987878, 0.014104834657960703, 0.019301517234582986, 0.05325990995126111, 0.03307883321706738, 0.04124571802094579, 0.020019022215689932, 0.06976003598953996, 0.019475678514157022, 0.09502058516123466, 0.041867480014583895, 0.009626937797293067, 0.05219565491591181, 0.08390234104756798, 0.020031349500641227, 0.09751924286995615, 0.043444056130413494, 0.03758689774466412, 0.028356383853991116, 0.026906566561332772, 0.06933635872389589, 0.049765240866690874, 0.03993702753047858, 0.036526048955108435, 0.0060881253448314965, 0.06418211851269007, 0.017287338618189096, 0.05381298723763653, 0.027462349506095052, 0.017780930435817157, 0.0692893633885043, 0.07926134472446782, 0.02125681088572102, 0.08619675971567631, 0.08974990834082876, 0.011136582370714417, 0.051236291216420274, 0.011682809846076583, 0.0299016676310982, 0.03450970072299242, 0.027771968427779417, 0.03789327326895935, 0.03279524968404855, 0.01711691776290536, 0.057089147690151415, 0.03041915575574551, 0.06161450129002333, 0.049108520748892, 0.07285515990640436, 0.023735760544825877, 0.010601017225001539, 0.046794902932431014, 0.021146862767636776, 0.013784282840788364, 0.05144876767215984, 0.023933321104518006, 0.04031177224325282, 0.0922432734764048, 0.020412211206608584, 0.030234760471752713, 0.08307075567011322, 0.03998570563271642, 0.03756804804184607, 0.02288789880861129, 0.021211310023708, 0.09236973883318049, 0.033112366417688985, 0.05270614395184176, 0.028781837185046504, 0.05833463264363153, 0.03702407330274582, 0.037301889288106134, 0.015596644786585654, 0.040379177912005355, 0.04288650729826518, 0.028844469359942844, 0.02824434924072453, 0.02593259061021464, 0.05549914675897785, 0.07046255722109761, 0.013397122633510401, 0.05543720668980053, 0.07072786441338913, 0.03394120033564312, 0.04189772910571524, 0.006275909911242447, 0.03271481953561306, 0.05093608357544456, 0.08284616057894059, 0.05029545830828803, 0.0531805451028049, 0.03771672184978213, 0.006619154059860323, 0.03587311506271362, 0.034413793190781555, 0.044299648076828034, 0.040833979578954835, 0.038546749989369085, 0.07486508919724397, 0.05201090679370931, 0.04197231028228998, 0.057246296400470395, 0.015773637253525, 0.03530537124191012, 0.038469281646289995, 0.03482300069715295, 0.049938358898673735, 0.029148558221225227, 0.02844303277587252, 0.026869474444538355, 0.026820735274148837, 0.07805191712187869, 0.03776214298393045, 0.013912625195059394, 0.022475861811212132, 0.04804886278829404, 0.038277921200330765, 0.0096294441360182, 0.040799818733440976, 0.011439018999226391, 0.039652833315942965, 0.06126951373049191, 0.06896515935659409, 0.033360292935477834, 0.044720275327563286, 0.04923425668052264, 0.03863730048760772, 0.038489841257355044, 0.025576483558065126, 0.01656961311320109, 0.03343011758157185, 0.05217090195843151, 0.08406132858778749, 0.046043869839715104, 0.007079594776899154, 0.016640609928539822, 0.0363188786432147, 0.012687802481065904, 0.03954386737729822, 0.04160827285211001, 0.09211532212793827, 0.023992670866261636, 0.05347068328410387, 0.060459342918225696, 0.041896867366241555, 0.05917410259800298, 0.031624620713825734, 0.049398346804082394, 0.030307177121617963, 0.07534155648733888, 0.030775610557092086, 0.02133301376099033, 0.05401756554575903, 0.02287472165854914, 0.05449329662535872, 0.02353476490160184, 0.06942861913038151, 0.03979956651372569, 0.05482073387663279, 0.05970196213041033, 0.011407315298648817, 0.05253064765461853, 0.03171093036819782, 0.04181828283305679, 0.040264631022832224, 0.02618905988388828, 0.03078631105433617, 0.033737833212528906, 0.05077811044507793, 0.032486034490700276, 0.04124497841777546, 0.02871177505169596, 0.07263362500816584, 0.04208211421168276, 0.046430929963077815, 0.021088059226583158, 0.024716384442789213, 0.08197965778942619, 0.10023569674896342, 0.05383380129933357, 0.03509932390547224, 0.05044660198369196, 0.028697664915983166, 0.027967250806146433, 0.009116481839945274, 0.011231207471740032, 0.04762130090966821, 0.05346639155011092, 0.019796746017943536, 0.01124991468220417, 0.04572807964203613, 0.06204573743577514, 0.017497240033532892, 0.015737880154379776, 0.03020288289657661, 0.047863151146365066, 0.010416577836232526, 0.030474561532693248, 0.04410759213247469, 0.06566880230924912, 0.021387194782229405, 0.012130632780359259, 0.034444306910570176, 0.04254015588334628, 0.01679791130923799, 0.05302615124466164, 0.07525125704705715, 0.03203083588076489, 0.005473994325646865, 0.040422899315931966, 0.0790095403790474, 0.015109393878706863, 0.05539219606933849, 0.02262638971608664, 0.031583976466208696, 0.05297494899215443, 0.035414371107305796, 0.02156955615750381, 0.03615961629631264, 0.02785634765002344, 0.053444725926965475, 0.044607743687395535, 0.01706551025355501, 0.041105597146919796, 0.031003418511578014, 0.07527134168360915, 0.044516660539167266, 0.056986071435468535, 0.034900377438004525, 0.07299508061259985, 0.04896913608536124, 0.0296759563498199, 0.02895241749605962, 0.02641100699215063, 0.014757938184110182, 0.03855451921533261, 0.13014890626072884, 0.12767344766429492, 0.17101928245808395, 0.08200529284243073, 0.17417596307184013, 0.19132843267704758, 0.19753306545317173, 0.15681880659290723, 0.11513329270694937, 0.11127777530678681, 0.0985581681930593, 0.1325485860662801, 0.08161960675248078, 0.2005293403885194, 0.1619448536740882, 0.16251176968216896, 0.1287392769008875, 0.09880771301686764, 0.14421181593622479, 0.12721517868340015, 0.1402531883546284, 0.1253466425197465, 0.16473378187843732, 0.16817022248038224, 0.14121179548757418, 0.15103909958686146, 0.15028906054794788, 0.10159476846456528, 0.1350951822740691, 0.15324085072747298, 0.278715044260025, 0.11471857210355145, 0.1923994187797819, 0.1734074814511197, 0.13273891513901098, 0.09456473855035645, 0.1071620329416224, 0.09611355579857316, 0.09886023841266121, 0.09856882797820227, 0.13358822385115282, 0.1239459291100502, 0.15428658175681317, 0.11228748969733715, 0.15955430694988795, 0.1340664146201951, 0.1435961811138051, 0.07200388344270842, 0.13284965205405438, 0.08044302024479423, 0.18992457086486475, 0.16422490775585175, 0.14672966940062387, 0.12082422019115516, 0.1555006437535797, 0.08962767025721924, 0.27816695081336157, 0.16798110119998455, 0.11904987825879029, 0.14400490346763814, 0.10523200793457882, 0.11448743593479906, 0.13723140050257954, 0.18389274738729, 0.19143406700875076, 0.18768236546644143, 0.13328882705952438, 0.09952238002525908, 0.1454865253929581, 0.24813873640128545, 0.1540915707924536, 0.062491921707987785, 0.13421649299561977, 0.15450478504811013, 0.17609301448932715, 0.0830170021259359, 0.08040137176534959, 0.1406897577856268, 0.134513989889196, 0.09454196691513062, 0.2576783959354673, 0.10120614431798458, 0.16398041801793234, 0.15310983918607235, 0.17118740986500466, 0.177358210885099, 0.11546031944453716, 0.16327642436538423, 0.07949001102575234, 0.12977447706673825, 0.08768055295305592, 0.1411444983844246, 0.17279754632285663, 0.12774609162339143, 0.14157036053282873, 0.09583021993083612, 0.24130629588450703, 0.13679462751107557, 0.09654682076403073, 0.14889689667948655, 0.09897423908114433, 0.17183539723711355, 0.13127135245927743, 0.16807468474975654, 0.09386658029896872, 0.1429657677986792, 0.09449904278985091, 0.09842742128031594, 0.07791038828768901, 0.11045318562537432, 0.10606214803244386, 0.11113628039934806, 0.2554538053061281, 0.14601734333804675, 0.16752277793628828, 0.15901749075523444, 0.1447741857596806, 0.189140577933618, 0.19624570810369082, 0.13302364200353622, 0.09790066775998899, 0.12385037780872413, 0.0977471424266696, 0.11919055213885647, 0.11095939989068679, 0.1537382033254419, 0.13604274285691126, 0.2066974544099399, 0.10195786612374441, 0.09969947766512632, 0.11101970129779407, 0.38211493300540106, 0.11965852417051792, 0.11668726003595761, 0.10842336168778793, 0.1354003601840564, 0.1986224398549114, 0.13052081130445004, 0.10913766228726932, 0.13298231922090054, 0.12374725405658994, 0.11248670079346214, 0.07643097838652985, 0.13058129591601236, 0.11237599780516964, 0.13045276781277998, 0.13456475787929126, 0.1781676353088447, 0.10786130399044071, 0.16683907248079777, 0.15179490617343358, 0.08327178524008819, 0.11559221308146204, 0.10571249215198414, 0.09108623556260552, 0.20481865879680428, 0.09731779939361981, 0.07881109602749348, 0.13588997748281273, 0.13547167421451636, 0.11372281517833471, 0.1024898240076644, 0.15917687863111496, 0.09777202430580344, 0.09686090783881289, 0.13479723754738057, 0.146900795932327, 0.17843193826930864, 0.12954270307506832, 0.17424773850611278, 0.18204888275691442, 0.13010341727307864, 0.15002270841172763, 0.10591455988053765, 0.1069142726649131, 0.08095829295260565], [0.05604472623339721, 0.0381363312979894, 0.019104411293353354, 0.014597627500604306, 0.03590042270453913, 0.0792115063273481, 0.027457962777199488, 0.01880348101258278, 0.011912594881973096, 0.02060272009111941, 0.04610408303726997, 0.007419951759012682, 0.07657881081104279, 0.021868036926857064, 0.05116080419559564, 0.04873407119885087, 0.013335177475320441, 0.06661328912845679, 0.06648919185889618, 0.02724128618969449, 0.027683723252266645, 0.08034879887210471, 0.06535262534660952, 0.03223217079149825, 0.04165114947993841, 0.0511997317496155, 0.016506120895168612, 0.009985853136251015, 0.024546979693695903, 0.054678845418883223, 0.024724759261256883, 0.01591113389336637, 0.024898314948326776, 0.016121498408860395, 0.033417388264622004, 0.010698189376853406, 0.07788059381502015, 0.06760143967611448, 0.03871371031605771, 0.03205437086788671, 0.052932693223868094, 0.03168369397254927, 0.01542229690988149, 0.0178912059470479, 0.06231250347835677, 0.05398569136325802, 0.011365216441585549, 0.02762437009784792, 0.05489844649231859, 0.05821036574031625, 0.04423801334840911, 0.040529140936476846, 0.028886586028550352, 0.0224542148477797, 0.044237528195870776, 0.018639258574694395, 0.018400516028382947, 0.008175561570429375, 0.015729354361870458, 0.06030152924358845, 0.043256254600627084, 0.03599605882274253, 0.0363420743628272, 0.05476858167509947, 0.021399364307788864, 0.012919646870744015, 0.009379702537054462, 0.01702268112317792, 0.029268038059983934, 0.017063941141324382, 0.06458304449915886, 0.014718837603660566, 0.026128510811499188, 0.000675674675481527, 0.02442621742375195, 0.014773798940171088, 0.016638615035584996, 0.04992826229759625, 0.121324626196708, 0.04554992009486471, 0.09063874171780688, 0.03588441267077412, 0.00786288924116109, 0.005505320167035929, 0.05726226232945919, 0.1559091354055064, 0.018204711178051572, 0.013206092125203992, 0.048239992532346926, 0.033438433028225384, 0.04060905539829816, 0.006691610573657921, 0.05461523276088493, 0.007379169259885592, 0.03561045076431973, 0.009481921293107527, 0.03801430356023567, 0.04393808051411595, 0.03080447543678539, 0.02370751991734973, 0.03020448763189571, 0.029919482568012815, 0.005432651186960616, 0.03723143021176968, 0.10869291650929622, 0.03525641154763954, 0.009698813315480947, 0.04506317299923726, 0.0205323390463101, 0.050655963963695934, 0.04173025648508753, 0.00979205674957484, 0.029551258576767783, 0.06493204220065049, 0.017875614908656905, 0.04945797646152122, 0.02918399471257414, 0.04052323428913951, 0.07001305491264377, 0.04808826192415186, 0.03233131493574806, 0.049819812045565674, 0.09252549654671124, 0.02804779800187264, 0.006371766129242522, 0.05349987046793103, 0.014616952177935412, 0.03477966945086207, 0.01452778758747237, 0.03802311094477773, 0.00804429133755288, 0.022351220017299056, 0.024447491192924123, 0.01165398398214685, 0.03938128360147987, 0.02970176442925419, 0.04294745331364019, 0.020178169211638824, 0.061958905309438705, 0.027361152793413827, 0.05865451440747295, 0.05278512203533735, 0.07079884596168995, 0.02947482160691704, 0.024017354273902516, 0.025242993774424707, 0.08989584765263967, 0.04143302422016859, 0.05909610499760934, 0.049916774699730534, 0.025555175862142017, 0.016951200851638402, 0.02511774978068258, 0.04440773531262364, 0.07098733620452029, 0.004380794258655182, 0.019872962463913218, 0.02039424529565232, 0.03987774731857436, 0.03150984312274626, 0.024128871504217386, 0.03390572991754327, 0.07436980613108192, 0.05296976498461195, 0.014149863089966987, 0.015688189338626604, 0.03059359353833965, 0.0471715339725571, 0.045898269795413525, 0.04326101791645799, 0.0386576395747917, 0.04640258755534887, 0.07219037879258394, 0.035158526085849316, 0.04077346104064158, 0.03800818995971765, 0.036452095423425944, 0.07929048780351877, 0.011294725983004485, 0.0165164431091398, 0.059084692038595676, 0.0900680191282715, 0.04273184881146465, 0.05137851554900408, 0.056432793981262615, 0.023671657645276616, 0.053863103834113905, 0.00824121746700257, 0.0662790834903717, 0.03230476386046835, 0.027690266026183963, 0.029719284203435694, 0.049679090668048174, 0.054823844959693294, 0.048920373166246076, 0.01819605307121362, 0.06413407144801957, 0.046337991021573544, 0.032561948988586664, 0.009275711956433952, 0.023950579642717327, 0.030119467194059064, 0.011137626466474362, 0.004247296734579972, 0.005199875932053796, 0.01940734834144158, 0.015275234622614724, 0.004468290501141122, 0.034928495929177315, 0.00547429288105507, 0.007931644346431961, 0.004398407331401748, 0.13028763953064168, 0.07343485272888627, 0.0036735771406841066, 0.05585782036983541, 0.03952238495860781, 0.011496849690697022, 0.02867723422657166, 0.025989183823445013, 0.03038910004709448, 0.013948738525089408, 0.009158489094781024, 0.03401301987469196, 0.03068130776020033, 0.035168463231197426, 0.01721694739535451, 0.09875991701015405, 0.04082027317157813, 0.050207791583878655, 0.04924912338278123, 0.07958906356777463, 0.025106141742851053, 0.045779831507908444, 0.0453147228940257, 0.06606750270085675, 0.10087976897401468, 0.048013032746634314, 0.02102021929541869, 0.044116840564778874, 0.03388940775766969, 0.01364015182480216, 0.04285547789186239, 0.005596575493525181, 0.021578930118786435, 0.021557985439098308, 0.044304231580879004, 0.033058144684348784, 0.030269172375223467, 0.03542437610615577, 0.04199153996471848, 0.02430440342452909, 0.07243703984256301, 0.07613577494131667, 0.025729235361463258, 0.02995251026004553, 0.011816962156444788, 0.020876726102350012, 0.019241142884961197, 0.04812056358371462, 0.029489562780197178, 0.043210999707558324, 0.06586304652903761, 0.013802003630969142, 0.04088507326585906, 0.022585372274209346, 0.11972801972712789, 0.027419304940849543, 0.026245551316865852, 0.002633746821499829, 0.06924534682184458, 0.007670395641720721, 0.04969633224287203, 0.04471242128472243, 0.03523300887484636, 0.025507367981065596, 0.050721890426107814, 0.039193661883473396, 0.040587651011134894, 0.044383613392710686, 0.04178316525316664, 0.024467984646824852, 0.03778188496029802, 0.035383762392614565, 0.02616627637429961, 0.013535514939576387, 0.04622973415202328, 0.04454603432012456, 0.0588035953364202, 0.03740995956052627, 0.02897966406973345, 0.03817043446802667, 0.040658595240009685, 0.02454850639748786, 0.08154596534690686, 0.06355357116886548, 0.023002449090459516, 0.026364364494968737, 0.04494017495640686, 0.0615458878289376, 0.013685846917464264, 0.06830697360315494, 0.00964859833142587, 0.042513207865080664, 0.10811909301472561, 0.05791398164417062, 0.049909012259117196, 0.034236953394221406, 0.04739215963387063, 0.023616988078824112, 0.06743740383535624, 0.07393426807331187, 0.028744168313486234, 0.009639559396808701, 0.04192125052213669, 0.04205304916415896, 0.02639497320965997, 0.031222982265587364, 0.01875555608421564, 0.02841613395139575, 0.043565585144928524, 0.01204978278838098, 0.09849410091659852, 0.030550720303186348, 0.02818313011500452, 0.0030778509597959264, 0.033974987986896715, 0.008605824018429433, 0.06959207821637392, 0.03839149439175214, 0.03990357914673431, 0.04111628068078842, 0.08635272098971264, 0.030570350321275846, 0.041655933151819875, 0.08697180277002708, 0.01481857885872679, 0.006346440233755857, 0.04552496696955391, 0.025938824650698473, 0.01871452507163797, 0.09275142156652041, 0.0533175006109689, 0.06448539652462516, 0.02411924139596522, 0.01962175014029656, 0.006831030436192772, 0.053931686761123795, 0.018940477232847894, 0.01979160272250218, 0.04728402490062373, 0.006387921623952154, 0.20973160517002853, 0.08881487351443086, 0.08724608019526515, 0.12495835764067513, 0.16148201136716775, 0.13782631286552974, 0.1654223185032606, 0.1426045564668519, 0.1336181065333741, 0.1073990927210876, 0.1833739937948329, 0.10811451968869992, 0.13887223388467515, 0.11262672327991043, 0.12769701997084276, 0.11382680745529276, 0.11664866496409688, 0.13939243954207214, 0.1696512880069869, 0.10370991139539651, 0.19021867508334772, 0.12534387409687042, 0.125928757712245, 0.048620654070483785, 0.12103286970938955, 0.17100121985588754, 0.09627572566803012, 0.10131684730627707, 0.08191110539649214, 0.16496936923691205, 0.09060269115226609, 0.06351824663579464, 0.14051388150879315, 0.1204944657427924, 0.15243428972150597, 0.06595591761704002, 0.28775845042296816, 0.17170943399625166, 0.061305652505585125, 0.1568673082760402, 0.07093074638396502, 0.09755285749477999, 0.10984245661113944, 0.15406570503754274, 0.14836572589618818, 0.1470627893826791, 0.15626760545585835, 0.08481113692479474, 0.0909068648304258, 0.13280334882438183, 0.06824544404766389, 0.2308834008872509, 0.16421611394201005, 0.0762131754308939, 0.09379327137555395, 0.16300688311457634, 0.07144653477839061, 0.15602186721350464, 0.1545938224132572, 0.1822958830744028, 0.21151982992887497, 0.14734818121152266, 0.09172456738139902, 0.1745002485279526, 0.11004362867346831, 0.14792556022959097, 0.12601372386728013, 0.18547895870038442, 0.08446497549968106, 0.12150887559567179, 0.23482682928442955, 0.12480019112782818, 0.08451893938971416, 0.13235893552856787, 0.1438915609781231, 0.14676935012851441, 0.12375273661954062, 0.2672715240291187, 0.14144172386399337, 0.13345912577850477, 0.1220951434224844, 0.07921413904322044, 0.12091700306960515, 0.15700350382498332, 0.20587740412780217, 0.2554385246975081, 0.10650188622197934, 0.10369573679885694, 0.16924612117665155, 0.11334274735833917, 0.19071766973606177, 0.07829792677823987, 0.1091308972931334, 0.07332536431827716, 0.11614132433065347, 0.05685417440586856, 0.12369504757225513, 0.09858239189322505, 0.06582557782530785, 0.09374505467712879, 0.12057230728013174, 0.1132596946720566, 0.09874269579138074, 0.17813456351203577, 0.1461281752479928, 0.0939959701416748, 0.08634327578225306, 0.11132832616567612, 0.17935765002455029, 0.09140177470232759, 0.08725222093718392, 0.11083594722939388, 0.15260365206216062, 0.10012348062757935, 0.10423663777432271, 0.10368829326970236, 0.09153070992657117, 0.12227283817316804, 0.30274734326771324, 0.12392904715878622, 0.07297289251749005, 0.11842580246073858, 0.17396354089890206, 0.09466695985091583, 0.13409025834075042, 0.17538771804954323, 0.0904019194255982, 0.11609979798751217, 0.16330192371138505, 0.09823457484266587, 0.08799301154379334, 0.09614662759538208, 0.19196426070162229, 0.10107423711035933, 0.1558794155716896, 0.1697888406259673, 0.10638775663184268, 0.10469799408955233, 0.15613830382270472, 0.19156331435910293, 0.12593229966504232, 0.17038832631494316, 0.15902344829269818, 0.08628116947199617, 0.05450266719396625, 0.15077630297413894, 0.1698052611734186, 0.10079046019486018, 0.14097969579909528, 0.21525087686521666, 0.18617265219134943, 0.0724602932376521, 0.1223278809338808, 0.08218154909887485, 0.13847913140697138, 0.1271656999098403, 0.10063165585909571, 0.18326270048107418, 0.21263611502945423, 0.1881911445941244, 0.12788093010229723, 0.16893030383757182, 0.1160170031445367, 0.0734383946816836, 0.10746869684330054, 0.26611217909625595, 0.08241423232746975, 0.125685665756464, 0.12051925941237382, 0.09801503483738218, 0.06681955698877573, 0.1853894463607243, 0.23204988400850976, 0.07308274733700923, 0.20889209450355598, 0.10872665327042341], [0.013962135350863849, 0.017654096973793845, 0.04475939626406346, 0.043849938815193515, 0.05469439404883555, 0.052073403261601925, 0.05325716866978577, 0.03973703272640705, 0.05980818678757974, 0.04377622616344264, 0.034964526138667545, 0.036591921134718826, 0.025503250969839946, 0.0345608656560736, 0.03114442148112825, 0.004708304876528148, 0.017503338367012993, 0.004678562142154468, 0.028444681615967835, 0.05728340548064027, 0.006124859958487962, 0.032688841822424104, 0.04530954906450851, 0.03353147374998246, 0.030573132314852307, 0.05973398219794035, 0.03823004376941493, 0.01763122864732785, 0.03179541137069464, 0.041585195876125775, 0.030128447605030875, 0.017894822538697293, 0.05326469362314258, 0.02938800983663116, 0.006388815593839223, 0.010513526071528239, 0.03609810370419707, 0.06309642177075148, 0.040263189135917594, 0.0490948652316417, 0.039528583376003165, 0.007978464959056249, 0.04787155819524612, 0.007865668690231229, 0.01768742491757231, 0.04597563635823982, 0.04470907610708049, 0.004330030509403774, 0.04259154473298362, 0.041092141797499995, 0.012364107350419675, 0.057792069257370064, 0.04565149339448128, 0.0423441542578595, 0.04724962317517825, 0.055708603733884435, 0.07368612781699214, 0.05587633419781923, 0.006605084212164262, 0.033144338987767696, 0.0875231260433793, 0.029672733308481317, 0.028546022517340522, 0.04796249545844538, 0.03302997869572469, 0.044724421176527224, 0.000988745644073268, 0.04271300250132169, 0.04104589285062892, 0.04713604998375688, 0.03576842728736145, 0.031043842235313993, 0.015999679320624897, 0.07256728463939258, 0.04232345215444054, 0.04719413258135319, 0.01897433104126581, 0.006774922375500734, 0.026146201915772896, 0.09849293383636645, 0.019425363446186696, 0.019179894921502898, 0.02054165872479124, 0.018541403646980013, 0.027656227316973463, 0.09615980474544422, 0.045352978698377094, 0.013739606398823006, 0.04126820806413889, 0.01674325531348586, 0.06225618507180895, 0.06361306511930057, 0.03404747588293893, 0.026560635838125433, 0.011229506045180773, 0.021870018249111514, 0.03365069574543408, 0.04535779968968459, 0.027270100179261396, 0.03546199069491454, 0.01717380783520639, 0.037722777774823565, 0.04274019139951893, 0.04867318285895245, 0.021184526550184404, 0.03874616125332458, 0.022319261017920713, 0.030616612838847295, 0.04440208650859339, 0.044686579278537204, 0.027229830822242156, 0.034152638632804155, 0.03531524392643145, 0.02474788373469242, 0.04958992777392268, 0.03283604320936969, 0.01107448454214526, 0.04045170991282378, 0.04515761150313275, 0.039281752692269425, 0.016524370094495158, 0.031697827856987715, 0.02487737196497619, 0.06595391593873501, 0.003475386603635603, 0.10087408285055842, 0.016643164612885033, 0.017458439704829028, 0.01917651072809739, 0.03586764267778822, 0.018604330984609466, 0.025699086354247162, 0.02760413279091673, 0.018550719932786057, 0.05076119117438793, 0.0858775700575539, 0.02045687916688621, 0.10426097004009144, 0.012324004234480006, 0.010794179181435277, 0.02321106128926788, 0.05124713420601828, 0.015576823082353388, 0.03303899642612253, 0.014635874823267971, 0.040266856617693386, 0.009733067459559866, 0.050136643794498274, 0.036272449884563684, 0.05363868855472122, 0.014108549637187804, 0.012660056335984595, 0.05876293073275259, 0.0654538424153413, 0.02970705021704946, 0.03491582768037915, 0.03799363199089255, 0.03191130854455488, 0.043434197016592534, 0.028956899219857793, 0.05034396677677121, 0.08142822595047099, 0.03055629786103964, 0.02713762130588293, 0.0278705001941749, 0.03265378191801054, 0.07369766291230917, 0.047746524547359774, 0.0701420104929379, 0.0342221986502409, 0.06790849034275327, 0.029735965986869166, 0.04311257141775318, 0.04628341984269874, 0.05620956953082766, 0.007584795904611903, 0.05239077105319925, 0.021168591155271445, 0.021260315519092337, 0.028685142552214007, 0.026336547951879244, 0.05063721264845558, 0.08841903654060193, 0.07767395276044096, 0.019132633261116486, 0.03421201723228608, 0.02312942674117429, 0.07394920262907233, 0.04594949579664639, 0.04485868290066719, 0.03299322245376451, 0.02853166132367083, 0.030217088027192012, 0.05336161217253123, 0.038693795313260386, 0.01933235495484301, 0.08414991811982223, 0.018958039415468062, 0.046576553756105046, 0.06034712001149144, 0.04655472867723022, 0.038765278977475, 0.01367435253424836, 0.06298992569957461, 0.046502827533653805, 0.050197331966566186, 0.07522490274693285, 0.031538005718695264, 0.03569739145625915, 0.04069462205682482, 0.021026136120781302, 0.027615321833374243, 0.05777493624814919, 0.03395618578152997, 0.04002869761149798, 0.04425079355548535, 0.06622271758637258, 0.034534569031425884, 0.00904371150370155, 0.029479652776249816, 0.02614473458379507, 0.0508085970234658, 0.02819206302852503, 0.011196380813739129, 0.03240756191579359, 0.02087083811472569, 0.005465611873660237, 0.06468059747878994, 0.04840975181598749, 0.05004734519336905, 0.039013432804495096, 0.04763045095439468, 0.06382333633622952, 0.07996911103171961, 0.039121862700475116, 0.028316704822438102, 0.03494544912661825, 0.03221893935863461, 0.027230646760602082, 0.02546504944829004, 0.024834122142887542, 0.008668131344685597, 0.06625509727746248, 0.03955846945089953, 0.01149162497105343, 0.04102258178006325, 0.059038782359233925, 0.04601066233590245, 0.018579362592260753, 0.04960966296494007, 0.055574437004647086, 0.03268645337915846, 0.025186655011826327, 0.09037129714020661, 0.01101239095441997, 0.024013259315064976, 0.01117995856995029, 0.028964173115257705, 0.03430152278659599, 0.13681370791579994, 0.007723144105901676, 0.029260553818728243, 0.017476432757186036, 0.08886494939880711, 0.02690782185111727, 0.03861066120277558, 0.04361240066854017, 0.06353235337883234, 0.014638027475614632, 0.08614544211221592, 0.07932035012968949, 0.06529449525156192, 0.012821070151403546, 0.04505085080329861, 0.011500970094597765, 0.019333686579817107, 0.011477608982074474, 0.026588153825806718, 0.04803412840036409, 0.060427485699100156, 0.037191440750445635, 0.010513034133639718, 0.08279495832643338, 0.021558996456276094, 0.049510841124824116, 0.04588564904406667, 0.03144397433581097, 0.04156377113291195, 0.04305178825078266, 0.06949466094374657, 0.05361839696498854, 0.02560681407339871, 0.024470754766038487, 0.022299249323883226, 0.015073080380846347, 0.03884770741154041, 0.060011313030762334, 0.06925791329038994, 0.06273432155804974, 0.04887278750538826, 0.03542156357850347, 0.027382487630737678, 0.049964947293379476, 0.0015272283843452378, 0.029739809887749807, 0.03498696189905916, 0.021008251634027277, 0.013036224275960453, 0.02126783538343651, 0.07112901431641408, 0.05303524361391153, 0.03690462060538786, 0.026399095309898257, 0.021491468651220202, 0.02955481070759041, 0.06162674206175974, 0.014403985480644872, 0.02974276151508093, 0.04052216559648514, 0.01724582923842328, 0.020839800226635168, 0.023696944949084094, 0.04054413316771388, 0.04454115226066538, 0.04082255983459098, 0.044543103048844, 0.052485606500080655, 0.026515357196331024, 0.07067379874310323, 0.038196880370378494, 0.044031100879822455, 0.004807549952861986, 0.027479485907991017, 0.035159516746976545, 0.062181675141411166, 0.009964505576395562, 0.06290934288075992, 0.04214229348248669, 0.007530230662918517, 0.029165216255933046, 0.04608135211414524, 0.02663197022463594, 0.039211656632167954, 0.09841412199395043, 0.02791731232511146, 0.005481697818530458, 0.025316441797518303, 0.03848706604912877, 0.03326899604871869, 0.029773231130093336, 0.048550239098923545, 0.015442982049924987, 0.1199111563286611, 0.19477328711322375, 0.07337073116962399, 0.12294736983520643, 0.17747200120772633, 0.1149923067007746, 0.13544217151190552, 0.16502399130591325, 0.08875274684812341, 0.139359394886664, 0.20487751492432185, 0.14604253055793898, 0.15589443833700248, 0.10279698323990617, 0.13818140381148883, 0.16138853638299874, 0.15396745316684246, 0.05727975496223994, 0.13207927053528173, 0.113407798510577, 0.23478666001132556, 0.1398687982665641, 0.16430395708552428, 0.08111833900745426, 0.13987620786896773, 0.10915413033217192, 0.062115599401295185, 0.15837802578295979, 0.12816256284713745, 0.16698106271880014, 0.12113554562841143, 0.1425357258745602, 0.15011211218578474, 0.17468462006321975, 0.13475830320801052, 0.1398786370243345, 0.16559288863624844, 0.22568579550300324, 0.17717599709119114, 0.16493732881333145, 0.15922406395631178, 0.09185663743742875, 0.11523955129086971, 0.0989780660186495, 0.05692283875708069, 0.11853229174656527, 0.11650615903948035, 0.16930238530039787, 0.10208636030022587, 0.10013367900890963, 0.09866649630878653, 0.09546839113214187, 0.13614582589694432, 0.10020048078149557, 0.15762144566646644, 0.16732932760247163, 0.199793170605387, 0.23571511304804257, 0.13429004619164125, 0.07925374513225895, 0.10602084560585873, 0.07800272333302669, 0.13448595282222542, 0.10844478303832666, 0.07430337755275623, 0.15057308173605374, 0.16836511130843843, 0.14596813597849437, 0.17320261815828936, 0.13127174600958824, 0.11047067825815507, 0.13031497092119285, 0.15442216662423952, 0.18248136740710053, 0.11051071860960551, 0.11824392793434006, 0.10841882228851318, 0.22647133549409254, 0.1905660850128957, 0.23431059984224184, 0.10493850761226245, 0.10237532800861768, 0.09164602016764027, 0.15975200491292135, 0.11488106766981737, 0.15969522510256084, 0.1259309561657054, 0.21283595716314657, 0.12297172924237591, 0.18823545293084212, 0.16552663647702762, 0.16487593496484415, 0.06553634548825876, 0.18002736408795628, 0.13654367811977863, 0.16157594775514944, 0.14894374273717403, 0.2290194109082222, 0.12213410490325519, 0.08688373570995671, 0.099277028547866, 0.14297655650547572, 0.13677584566175938, 0.16160254632788046, 0.06337914695697171, 0.11718105711042881, 0.14876565443617956, 0.08775829949549266, 0.17336287455899374, 0.13946403855723993, 0.13262021222284862, 0.15065484520580086, 0.13342544330017908, 0.18558129535189696, 0.137743653729558, 0.07695511954703502, 0.12509588311825479, 0.14938751821007046, 0.11536676303616591, 0.15326635007347378, 0.1621860321611166, 0.1258700644331319, 0.10961521523339407, 0.14719716645777225, 0.14703494230551378, 0.14234794809349946, 0.12174177595547267, 0.0724669157394341, 0.13999176238264355, 0.11993548859442983, 0.11949711426028184, 0.15419386673186505, 0.11740382015705109, 0.1289898870246751, 0.12692981399595737, 0.10226127305733305, 0.16242001817694732, 0.117969650509102, 0.1379687509366444, 0.10594747561429228, 0.07855090498924255, 0.1835172325372696, 0.15990772869970116, 0.22042748837598733, 0.09952305856027774, 0.1392633550401245, 0.13599529968840735, 0.14020908357841627, 0.11520695446857385, 0.14794709693108285, 0.06734443775245122, 0.19864601216145925, 0.094786565218653, 0.1721049520586218, 0.12080404055970055, 0.12708262008215698, 0.08777671493589878, 0.09919280878135137, 0.14445283157484873, 0.08943316140877348, 0.1567769002701555, 0.14118605186896666, 0.14452088863721915, 0.11724143315638814, 0.130384181493095, 0.10680662986955472, 0.1412937489471265, 0.315275678145034, 0.07717866290892873, 0.1241963899561337, 0.2141102866402694, 0.09030728414654732, 0.11213125022394316, 0.09209033168320145, 0.14823997978653225, 0.06424443516880274], [0.033672225661575794, 0.07441715430468321, 0.01544547057710588, 0.08884068498654024, 0.03908384099070515, 0.007465687563775906, 0.04537814895489386, 0.017169904562511613, 0.0626893618277141, 0.05701957070933921, 0.02867954463831016, 0.022306002443656325, 0.026094509421714714, 0.01753216253460518, 0.01983218590196754, 0.03819739605699267, 0.03324426683996405, 0.012939745077996381, 0.03912982530891895, 0.06367290512259517, 0.01683793300097542, 0.031176020856946707, 0.0624030539765954, 0.04186185156660421, 0.01690234293762062, 0.028653149626084735, 0.07651404464351279, 0.022762909265501157, 0.045118090230971575, 0.04475898914305227, 0.04219666449353099, 0.012052052488018359, 0.017522525641002824, 0.0774846686316388, 0.019611945309277092, 0.009575471764297357, 0.04169843319271292, 0.01022024457675538, 0.02342410771442311, 0.02863866290343659, 0.03906934069735663, 0.014594243307198797, 0.08384912354605538, 0.013917768490500748, 0.026024245424196124, 0.030816200521907637, 0.02206441853195429, 0.02027269931776183, 0.01665728323028556, 0.07251346324171339, 0.007324377557129732, 0.03480066332433905, 0.02537576441786119, 0.025863018718415072, 0.0357732720273946, 0.02480259570958359, 0.07148796612662928, 0.05100164362894637, 0.04103412366073046, 0.02849711710587144, 0.02393672226129898, 0.05769713542291096, 0.025196741434878538, 0.0343442908488214, 0.02301501895167998, 0.04921626193182809, 0.03264786509264793, 0.02239498552600188, 0.0731311065277883, 0.03174951186935816, 0.021138398043279136, 0.0400341089282717, 0.039620938777391396, 0.03837551149938788, 0.015373425425163336, 0.037809280811675956, 0.037124079186469316, 0.03180923991437469, 0.09807512589863368, 0.0077530471441735116, 0.07321937714836427, 0.02297344002207475, 0.03544122413066881, 0.0393163545855454, 0.029387969124530042, 0.02309584604310138, 0.014633659406432083, 0.026327682891860604, 0.009893385776584702, 0.02449791313015989, 0.027350504882633686, 0.06578451967132942, 0.07201151696166821, 0.0376096999139658, 0.004758711546725992, 0.031754305719264915, 0.02243322097430272, 0.015652681601100733, 0.023466276969494562, 0.009267924918926187, 0.03486071367348943, 0.028371645802898065, 0.08691342161702258, 0.01659689361362585, 0.025105622663561786, 0.03285903536847659, 0.045219914588545046, 0.05380573030561209, 0.021136845894423977, 0.03931457003844636, 0.050441947233464034, 0.04989938723987766, 0.07844471425882407, 0.01737293920346669, 0.034027727121221166, 0.019550383523372666, 0.05533883607547198, 0.06582983902522496, 0.029149861008461033, 0.02568338844659073, 0.03959753271192312, 0.05553092933925135, 0.06473059193896395, 0.0020123537812781122, 0.020002864600558366, 0.053386209066957235, 0.05415382555552891, 0.00803781980981252, 0.06145972745226962, 0.0807040865932192, 0.024193985420944433, 0.057399211052273, 0.05902582234037774, 0.029106048002306904, 0.012840904578167413, 0.02081363252364099, 0.017808224506942288, 0.051771760519061766, 0.022236827494842664, 0.03088020333754165, 0.043344776279159954, 0.016082801556746875, 0.022511281339185576, 0.00783200656795608, 0.007227567573344069, 0.028863702435046434, 0.03563042004991855, 0.03246615680732897, 0.022959253551172357, 0.06078240701130458, 0.012304368279209095, 0.052278609214616675, 0.043901236062603335, 0.028025004314258695, 0.034771486318537166, 0.008346051127383751, 0.04053690337709018, 0.054257424282176156, 0.018635572433205586, 0.02947829570621252, 0.031572692428848574, 0.0033271983723222676, 0.03922088131574648, 0.014675061916932464, 0.029257378274840967, 0.022093498846516013, 0.0321051795700831, 0.014398664069761122, 0.08715310054165976, 0.04732935103986945, 0.022887113404327204, 0.03325185625414763, 0.04514722313199725, 0.03453125778053488, 0.04427343966173274, 0.049221188096063476, 0.03594249187569533, 0.07045230455696583, 0.04056855703571013, 0.06483626019741807, 0.08012167284531252, 0.10453693701752595, 0.03184106659942439, 0.013619453962227064, 0.07327133936009236, 0.00841616330269192, 0.007839584107776838, 0.03477389172517827, 0.02234217175282538, 0.07345202645020825, 0.060574992426804135, 0.0457327140362135, 0.059439436931695254, 0.07540305890142918, 0.02464926545508206, 0.05599868084703173, 0.017800187259646397, 0.02498845662921667, 0.05815900742475476, 0.0392263910200979, 0.04427612666040659, 0.02288151209774826, 0.06493145866053444, 0.020707012619823217, 0.0372206754317241, 0.0934204367388572, 0.06301409511693887, 0.05455828670944486, 0.027273189209933792, 0.12490685683275972, 0.008034455124288797, 0.04308155558205076, 0.0124394612087469, 0.053981090895831585, 0.06541348993778229, 0.10468164818095309, 0.06958585605025291, 0.05853222882641213, 0.07244754356465169, 0.036301447078585625, 0.05934916463281427, 0.038216374681464264, 0.01988895214162767, 0.05168042970555169, 0.03939856928107994, 0.028362302375691276, 0.05349503590592316, 0.03750199265778065, 0.06769528106919356, 0.022953877857487117, 0.027133855436529433, 0.033387437728898864, 0.016121944545635154, 0.0422246201362993, 0.010481160799307483, 0.022545180948717252, 0.03982365111421261, 0.05594863210405622, 0.07838767660515648, 0.0384576312000198, 0.042129648982414176, 0.06835205546979393, 0.019893830808411752, 0.08158202948314802, 0.028906802979430983, 0.010310922300310006, 0.05667176044413021, 0.05457941968260067, 0.037625608167478015, 0.013051983251768564, 0.07990036186363016, 0.030753201938101223, 0.0707187449027385, 0.06707898128245558, 0.05257064050861767, 0.017368331950690066, 0.02872574269505484, 0.013238949335313268, 0.06987646581338984, 0.030491799714842012, 0.038080443761178424, 0.026563341496512294, 0.0381361820202853, 0.037070593663624356, 0.02142315374554268, 0.06381132626639945, 0.014429910607369882, 0.0458622361932482, 0.040332012942859104, 0.0335829609871975, 0.0319762104190886, 0.01817264361307025, 0.01761367155372032, 0.007169943835054125, 0.017955059484977807, 0.033000340286110125, 0.04568942350202373, 0.014576343553406852, 0.02284171771524208, 0.015515665024785059, 0.03652750780539853, 0.03370121607024755, 0.05691045888566545, 0.005846229731105268, 0.005982460903136858, 0.05497183005458542, 0.04765247620110001, 0.014323982809271132, 0.03214938612654805, 0.02423381881921419, 0.07244977594486304, 0.02256359638912337, 0.006267183950902628, 0.014194477615611894, 0.03078718975718532, 0.01944384165108204, 0.06451156762029443, 0.016455134077529823, 0.022579304474805082, 0.06419571635446378, 0.03630962681823543, 0.05596016041402306, 0.09491823493902173, 0.05873383515115295, 0.0031812215290431467, 0.07212675256388527, 0.06583462948245661, 0.03060157989550914, 0.019487871788442135, 0.01987546286545694, 0.009749061378118182, 0.04056105583107897, 0.014232487451019031, 0.0236111950861024, 0.06374956600900207, 0.07015123856919152, 0.04099176950486643, 0.051360514014959335, 0.04142781985657556, 0.020280807811234678, 0.013242570167806531, 0.048911986473415575, 0.03751456930435129, 0.030403712298721075, 0.034237794777644534, 0.04187689468796764, 0.05762259156576224, 0.006223135153829519, 0.03462249020646725, 0.06562947441956826, 0.011083370806383235, 0.03938364829601986, 0.035853773422007046, 0.035734422504901886, 0.03516283478321774, 0.04096628712224109, 0.024222879138376032, 0.027372368977272084, 0.030915141105651855, 0.027177132400018827, 0.01994013403808432, 0.031021552359951392, 0.04320811254105397, 0.02711382169010384, 0.03645695034148438, 0.01617608655111066, 0.01700280004713152, 0.02977695289467062, 0.07407450090561594, 0.041931177489459515, 0.03767511408243861, 0.09644960705190897, 0.20349563764674322, 0.1579197703727654, 0.19186267043863023, 0.1301826158804553, 0.1822792182543448, 0.18886058724352292, 0.16845918340342386, 0.09673666807689837, 0.22685702836939267, 0.10488081177962677, 0.10611913818866014, 0.12734956932919367, 0.0643259340098926, 0.10189445702625172, 0.07013047539762088, 0.08646861477089779, 0.09827240995530571, 0.0836965481617621, 0.1589072695268052, 0.1511792577803135, 0.09417053684592247, 0.09738857738141503, 0.17851098759898118, 0.1853787526488304, 0.14560376267348016, 0.07102949358522892, 0.12679944027747425, 0.09384827342416559, 0.06300021229045731, 0.13766164598720415, 0.1344250203775508, 0.08759481326809951, 0.2061363330909184, 0.15438539002622875, 0.06800773965993098, 0.09311734871672732, 0.08092169955904994, 0.2030861960457904, 0.1430342048406601, 0.20003733464649745, 0.16014209469514235, 0.24600775646311895, 0.14053490252367087, 0.14557309289063725, 0.15782615968159266, 0.2027977236679622, 0.13042695634067059, 0.08665825173790966, 0.17725500570876257, 0.12938726427299635, 0.13009041654212133, 0.15617548754172667, 0.1176622605749539, 0.05365650009896074, 0.09752921733473029, 0.09964397350060088, 0.17344767786562443, 0.17451996675559453, 0.10649740110550608, 0.07755822861301047, 0.09219313652387687, 0.11935779745025293, 0.12800918679152215, 0.12994021603039332, 0.14540145067231997, 0.24157230875321797, 0.054855912524674616, 0.1361253477100815, 0.12512367591261864, 0.08504136385662214, 0.14776617235371045, 0.12388130543487412, 0.08103883505931922, 0.11868165087487016, 0.10960238413619143, 0.14248620638889925, 0.11246214461113725, 0.13100973649748734, 0.08331171024058547, 0.08308348498706307, 0.13479909673333168, 0.12926983700266906, 0.0942883440958602, 0.1250924225896597, 0.08733112777450255, 0.10050254421574728, 0.12508014110582216, 0.07531206735542842, 0.13793820329010487, 0.11304590185838086, 0.09448373503983021, 0.18089698813855648, 0.17819491241659435, 0.1231224454407181, 0.09304961056581565, 0.08919492097837584, 0.09144633409700223, 0.14051317583237374, 0.09133450474057879, 0.10833106056920119, 0.1344658410442727, 0.12437093630433083, 0.13763602450489998, 0.07842538958149296, 0.15859443774180754, 0.14921815586941584, 0.1432122660002538, 0.10549803437399012, 0.16268837877682277, 0.15470529214612075, 0.21322433703712054, 0.11419424095324107, 0.18813774388815674, 0.07013211745236601, 0.14775070175528526, 0.13583444617688656, 0.12504058251423494, 0.16327056182282312, 0.0959861201367208, 0.12972754958484853, 0.17681986120130333, 0.15477490983903408, 0.11639557140214102, 0.13544397641505512, 0.16542048645871027, 0.08529996712292943, 0.20028529848371232, 0.1458931714296341, 0.12815743312239647, 0.1668707329247679, 0.09595713312072413, 0.11353371425398759, 0.16499638850135462, 0.09448787410344396, 0.0965234384472881, 0.05359279923141003, 0.13800543253975256, 0.144656419221844, 0.14358250184782914, 0.1441872665392501, 0.14838871466262, 0.1004234134618725, 0.12264147267809936, 0.17046981837068284, 0.09291741837348257, 0.19114977440663747, 0.13722447944538935, 0.18328491571758473, 0.08927494739847523, 0.17529367309595856, 0.0742837678907173, 0.08566890696861915, 0.21878734709961073, 0.12999801364328178, 0.08353291944201503, 0.14616231913013117, 0.11566710977682046, 0.12637581729463168, 0.15315479891640799, 0.09784034599683114, 0.17575946024485997, 0.20673036335834435, 0.12612864055803844, 0.16729537371013845, 0.10233749968132802, 0.11975102206426007, 0.15261180805308477, 0.1298025141337088, 0.20228993520140648, 0.11889215957905565, 0.11558939037578446, 0.11053606867790222, 0.20014557455267223, 0.11652703077665397, 0.1311699114739895, 0.13946272219930375], [0.0507868601541434, 0.03972075467130967, 0.04005058715119958, 0.020044212828257253, 0.047376224238957675, 0.10143941108669553, 0.05140323118705835, 0.025609672402164767, 0.035400176154715676, 0.019293624175978557, 0.015919876817081655, 0.02002104594638305, 0.05237035393448813, 0.02111985707389457, 0.01081481427952115, 0.0005846107170717524, 0.043420171697757075, 0.054020785194422515, 0.02657508184867246, 0.05313944284405027, 0.06733864306339196, 0.06373592745512724, 0.020509329923827733, 0.002105231018504128, 0.02900255105591246, 0.039080183686954637, 0.015052117041445203, 0.028555966448038816, 0.054240491440785785, 0.03169447589399559, 0.02436881505751184, 0.034168597776442766, 0.02931647188961506, 0.041366320835160356, 0.028758271663848842, 0.02832147153094411, 0.04692896109606538, 0.0560606955550611, 0.02755806704850069, 0.007909637759439647, 0.02569464534255011, 0.02343232138082385, 0.020804945579064742, 0.015435418080804604, 0.04782546531142933, 0.0684502666283931, 0.04862175329721399, 0.006481863100946481, 0.03217372178499188, 0.062493421270379, 0.014690257708675094, 0.049078733061573336, 0.02339886112271675, 0.03469182291467275, 0.044205335101911, 0.020276095385530164, 0.0377118635390486, 0.022335620497220328, 0.012148839571247143, 0.11168707441538572, 0.03596661379560828, 0.03770998738972204, 0.03054941412327545, 0.018108751059376767, 0.04075500149545925, 0.0632954089503203, 0.022221222885751298, 0.04287973212610398, 0.08252213296613523, 0.05895262198256595, 0.031341166102460453, 0.05580361220719559, 0.015631194093397686, 0.008286738685066146, 0.03400109801441431, 0.029432039973991256, 0.023274338072431938, 0.012113597310547317, 0.02299273755800511, 0.009961838933772274, 0.00861984764092735, 0.04688625070931656, 0.031554151459464004, 0.04721545893698931, 0.030073476090495075, 0.008332054646286582, 0.0435383351785796, 0.031839027601693354, 0.055538569643561325, 0.027273704896547964, 0.024335181772974983, 0.037189662988696776, 0.04661165776529482, 0.03665557450481823, 0.027697475460757102, 0.032843632623553276, 0.0509321480723364, 0.03271326569042035, 0.0269138302787074, 0.04495584572266255, 0.03626789691458855, 0.005050504929386079, 0.03137253816904766, 0.05314339870320899, 0.02670772187411785, 0.01390504086988845, 0.06730808863150221, 0.01084729829537017, 0.032384115138224194, 0.045554042195103, 0.031760422712458034, 0.05402364521952612, 0.055524578251476796, 0.03564878460019827, 0.018827056711805717, 0.025730461813509464, 0.02170492389372417, 0.030741799157112837, 0.0024786871508695185, 0.07401247601956129, 0.018098547589033842, 0.029186071029731205, 0.022437877420868193, 0.018469989532604814, 0.02053730083363397, 0.04799099053655352, 0.09110724300678287, 0.03667542504678879, 0.05560079809012158, 0.01618415942149503, 0.03969422395208052, 0.018962987632091557, 0.0476502234648381, 0.039541092169071944, 0.012056941332827722, 0.05103865771421364, 0.0217005151124405, 0.05181653365226729, 0.039389449770429304, 0.012707892206630536, 0.04717047545792801, 0.03725917550868221, 0.05536502752719181, 0.006146729566223387, 0.037598839960992336, 0.017491558999089257, 0.12471650061862809, 0.031289142822580676, 0.015156075391652328, 0.023860010484765683, 0.07276950843100037, 0.05699223253343787, 0.06944198627024889, 0.037112720510257144, 0.028670075682124922, 0.022911019889371734, 0.08444848031337772, 0.024797773021938543, 0.05455295681687338, 0.037258995696902275, 0.041934990856264315, 0.018621701481086866, 0.019118904801351682, 0.023755723045074513, 0.06599495373666286, 0.012297229242644139, 0.01379506052139082, 0.07934296570186104, 0.012315581070392259, 0.020864212220268588, 0.027594305907509158, 0.04311128220121775, 0.013109034476136523, 0.02835535248076277, 0.029819127238754715, 0.05261019231485469, 0.049809264218700786, 0.0761904784345201, 0.055444097212914906, 0.07711764904005186, 0.028554622948701893, 0.025558239447751215, 0.026735187275335193, 0.028344577344666635, 0.01702062176939632, 0.08630787661033017, 0.015003153954499533, 0.03169710521719285, 0.07259489422930138, 0.013876335445924528, 0.025630232013229812, 0.024287935379626494, 0.09372433900300946, 0.02347000382308449, 0.021961337188258767, 0.02766693799224283, 0.03113654368956174, 0.021512206377727643, 0.01834631634743086, 0.11112736444920301, 0.019020045641809702, 0.08729558611022574, 0.0493414143233427, 0.032009848792638095, 0.02760348648631147, 0.058861806855670044, 0.026491842565259764, 0.019664932108883346, 0.005868866507496152, 0.01487337056148265, 0.045014956300812106, 0.06309380941092968, 0.04605419375002384, 0.016646163737667457, 0.028149069353405918, 0.0062748993181490475, 0.040550596213766506, 0.026337862613477876, 0.03950844106397458, 0.03801170816378934, 0.01811627601273358, 0.03499858520392861, 0.015444741151960832, 0.02327034998285983, 0.04579437590603318, 0.05119373689272574, 0.06066623503076179, 0.05156507875238146, 0.06120275267000709, 0.0512254346561219, 0.07627866763089385, 0.034327218907752206, 0.041729937573628764, 0.04520552286079951, 0.011968662230564016, 0.13328578722264084, 0.03144176570432527, 0.04035849955731204, 0.029620357190391848, 0.05527574249676295, 0.028308494548712457, 0.07531066957329001, 0.028645387185471397, 0.02331488223613373, 0.030648582016250918, 0.05727976853294032, 0.02409553338241364, 0.05602102839787092, 0.036719584105802436, 0.05384780965479357, 0.01519085031135806, 0.030756764246949127, 0.01866098865866661, 0.01693403730834169, 0.020142459609944905, 0.037274072745016644, 0.020136084773444703, 0.028908940364739726, 0.023708977071302276, 0.020035902470616356, 0.07177818912480559, 0.043568689442638836, 0.02041313740690904, 0.0028646079715274808, 0.0439575341131006, 0.03253131652516978, 0.053136894945055246, 0.03507104595857007, 0.06385173302675996, 0.01665130364043372, 0.006705333520325699, 0.024407959742737666, 0.01912614137732557, 0.010125195391343107, 0.05055186990648508, 0.01884766382032207, 0.06146847376866, 0.0492357358868633, 0.051769874191709926, 0.02787096329432513, 0.019725888302283626, 0.045696137606033256, 0.02783288899809122, 0.03406900240640555, 0.07214252850306885, 0.023523019460429038, 0.043920615022735934, 0.0770696426874825, 0.04615797907380121, 0.033485896552779844, 0.0119659709910463, 0.014092511613853276, 0.013391668908298016, 0.04084753331595233, 0.033567144335912805, 0.033669796506209035, 0.006663291066485856, 0.04383271420374513, 0.03368410002440214, 0.0038089872853431317, 0.026782757669155086, 0.05326521609510694, 0.05125628085806966, 0.08099570737353393, 0.07054698733346802, 0.028616848002587045, 0.02762900958103793, 0.037552326385463984, 0.019890826594616686, 0.02642339704159115, 0.0478860754519701, 0.03652233736855643, 0.032255203662706275, 0.0447927598309304, 0.05375932529568672, 0.044579611625522375, 0.053155150929731984, 0.012611833700378026, 0.02354228646228356, 0.04794136927063976, 0.011549995097863888, 0.023414425019707, 0.06314609731946673, 0.005664272508251348, 0.015649763900520544, 0.02195748989470303, 0.048381365303482325, 0.012990021978371909, 0.05792854979102101, 0.042414094254906685, 0.015831731725484133, 0.003934581572788635, 0.06387341222060577, 0.04790117285613503, 0.025699067694534148, 0.01523077700819288, 0.017572735536045263, 0.018953971598031263, 0.013100188075830894, 0.026324393693357706, 0.03839356392355902, 0.03449363301375082, 0.04690983997923987, 0.014789992178391134, 0.05030228437057563, 0.02622326653051589, 0.046011544431426694, 0.0488010765319424, 0.04976769716345838, 0.03880352460380111, 0.01654147426597774, 0.029370788617857864, 0.1428038286311286, 0.17124816589057446, 0.15450726848627838, 0.13692836676325115, 0.10828199570200273, 0.21222087873944215, 0.10007474145718984, 0.06965121254324913, 0.0838811436135854, 0.12863170195903095, 0.11838086987180368, 0.10679332379783903, 0.19589789105313166, 0.12093412929347583, 0.08773849305829831, 0.11659085378050804, 0.19863853470555373, 0.0832351782758321, 0.13116518887025969, 0.15003199077078275, 0.16555191869182245, 0.15051544697156974, 0.07846787265901055, 0.18312142949019158, 0.12748864186661585, 0.15648348815739155, 0.1556785013526678, 0.06753261586917297, 0.09042808373591729, 0.18774651416710444, 0.12455625778862409, 0.13705116803092615, 0.164341059380344, 0.09721026516386441, 0.1169664907668318, 0.14476046578160354, 0.105204506910273, 0.08536790204899651, 0.1313971257103341, 0.06443097801612956, 0.08413881728691713, 0.18489402080220835, 0.0641415353332247, 0.0866390016994306, 0.10753904056868382, 0.14857588176216396, 0.09524224898112671, 0.10930339446557419, 0.12934443514261926, 0.12915067268269403, 0.1853235877518143, 0.17498925514519215, 0.1175817863217422, 0.13532379429255212, 0.20255970715412072, 0.11721737230462687, 0.12334280647337437, 0.141407579981855, 0.06334580374615532, 0.18808266041534288, 0.13830003887414932, 0.14995754190853663, 0.10073532243924481, 0.133571274046387, 0.11610583694917814, 0.18894745329661028, 0.1315377860196999, 0.07674269737409693, 0.07957183556365115, 0.13698169961571693, 0.12285179139247962, 0.13698098036859715, 0.09515243130070822, 0.09200098219194583, 0.15004653856158257, 0.06365311904145138, 0.10298208759299346, 0.09335133473255805, 0.09858779981732368, 0.1148583096052919, 0.07605878157275063, 0.15610676551503794, 0.11483362450131349, 0.08669328450092248, 0.14577852615288325, 0.10640539175697736, 0.15306938492826053, 0.1223784860755716, 0.12789756778095449, 0.12028694259268896, 0.17066923981266363, 0.11865001757230077, 0.11242794644619737, 0.1173312169100557, 0.07379695972693817, 0.10372544306197337, 0.12194326014391013, 0.1218382500644241, 0.11116039553391081, 0.09511109494737216, 0.15441333209829672, 0.14610841630824975, 0.12875736664448464, 0.09906852830733572, 0.10208089809332575, 0.07718666283679859, 0.11796707207603113, 0.1134797367932541, 0.12717431730457715, 0.08709255486194577, 0.09220159785555941, 0.14353003752018723, 0.13726118818989821, 0.18794585418488297, 0.09412706989262785, 0.1043065268812435, 0.11838359758257866, 0.15423031763306685, 0.150813418839659, 0.219146156417472, 0.060271219084305425, 0.13294019576694283, 0.16247383957462652, 0.0968342481979302, 0.07950706939612116, 0.12957238219678402, 0.15226224038217748, 0.12968410977295466, 0.14339438479925903, 0.08368230571172067, 0.09222833892064435, 0.10014394524374179, 0.12797213877950395, 0.13487597475094454, 0.12005016101258141, 0.11568632588854857, 0.07769102470151015, 0.1645284571817943, 0.16955816586102757, 0.15356668324342795, 0.1383142066853387, 0.10097010912639753, 0.14481900978301251, 0.18181781444166387, 0.12773138098418713, 0.13256649939077242, 0.21454387051718576, 0.10347400512546301, 0.07893310340919665, 0.11109849278415952, 0.19266680228923047, 0.09531368514789001, 0.1281386377023799, 0.1713740884193352, 0.17771250115973608, 0.22302169060068472, 0.19001428676503046, 0.11943660250731877, 0.1219965929963759, 0.09999561070331506, 0.10580214698399816, 0.08597605263016053, 0.07379812680717025, 0.1707702193941389, 0.1270760382924761, 0.0875933069203581, 0.22371064791721956, 0.10597790790987865, 0.11502136157027312, 0.06428033645663943, 0.08904341089406184, 0.15531758857624872, 0.11994930356740952, 0.10170165808605296, 0.17389975860714912, 0.12898776999541692], [0.06348426560206072, 0.0068927482851514855, 0.012575137678400745, 0.04705691244453192, 0.01720722738121237, 0.04946519946679473, 0.06864081283232995, 0.06113871932029724, 0.01748597126321069, 0.06968490180692502, 0.018036112189292908, 0.05973009419228349, 0.03163944670398321, 0.06805138981768064, 0.10497176939887659, 0.042055566529078145, 0.03012638146589909, 0.029523486138454506, 0.07093600503035954, 0.02413710213399359, 0.05660404943461929, 0.01112469782986279, 0.01992759301460215, 0.03935297851317695, 0.002471268642693758, 0.036452567005263906, 0.050970027289752445, 0.042618401149021726, 0.047801916753607135, 0.006632407121027687, 0.02489030484243163, 0.020635539133633887, 0.04837548240487065, 0.027655195943745117, 0.01592428729470287, 0.028704684360751083, 0.00407209008699283, 0.02752759912982583, 0.01727843963141952, 0.05785764288157225, 0.022538577106648257, 0.03404288559353777, 0.0403196161080684, 0.04991661863667624, 0.04736738292766469, 0.04240271182996886, 0.01969195476600102, 0.030929118927036012, 0.06849036804799523, 0.02300153815719698, 0.11981698923877307, 0.013726364787934082, 0.08722629411412136, 0.034446105028369596, 0.048980420122721365, 0.04784912922020469, 0.047325469819562774, 0.025962846486696174, 0.03575186424755624, 0.054257889078663926, 0.014713648507105452, 0.04926004779658147, 0.03878296838541116, 0.024421450715245943, 0.005701449441923094, 0.02305473869533411, 0.02643450296350888, 0.027213927657742585, 0.011837982323153742, 0.025008872051590254, 0.044130608040307245, 0.08020518693540778, 0.020178279473579357, 0.05354225515787091, 0.03344802751338907, 0.007439547850351248, 0.057381759131593366, 0.01357582924954061, 0.0436703713078584, 0.022445834940299392, 0.009339514604237462, 0.03021570381575397, 0.038913223360266, 0.033871158558343134, 0.05953646743936198, 0.054680419620126486, 0.04125926157991801, 0.06883193579103265, 0.023619444375591617, 0.013757691053407533, 0.0460734403958278, 0.02796245356356459, 0.05640762372474585, 0.018684515164100697, 0.04104696154328329, 0.020783357987446443, 0.06338405276515655, 0.048445249375488074, 0.02736741227896086, 0.08200388148959194, 0.02658300713769027, 0.016866701189428568, 0.10113738836454493, 0.039303903467953205, 0.04467886433537517, 0.04319451130660517, 0.028157104904364263, 0.038719698387597284, 0.007190401665866375, 0.02392159093038312, 0.08334617303418261, 0.004778897539446396, 0.031080720613577535, 0.03730844732906137, 0.07932769866394145, 0.10003892837890557, 0.041131761457238875, 0.033384241828961034, 0.04410202135997159, 0.014603715656059129, 0.022667600540444255, 0.049605683357055695, 0.025567964550905993, 0.08272643307490007, 0.03269560342388494, 0.018459855612101297, 0.02413921237790159, 0.005722842802892306, 0.060148886005793295, 0.03935462735327227, 0.010524460663353758, 0.005227516056038439, 0.03111056936904788, 0.02814590398754392, 0.05064499883779457, 0.05056352035275527, 0.03784632882369416, 0.06624860369733401, 0.04728312923439911, 0.07077897167099373, 0.014248716312327554, 0.06893731906477894, 0.04522539036614554, 0.04197404733193772, 0.0423949086772544, 0.06566386935966355, 0.04551101289689541, 0.01142746354785881, 0.05744144307183368, 0.030489489303103516, 0.017596679340515817, 0.03090610301920346, 0.028192777186632156, 0.0882959570735693, 0.01791079355669873, 0.060914795978793075, 0.0309994083696178, 0.04704065813816019, 0.028775947501084635, 0.0341056738314884, 0.014026546135677822, 0.04039602593651839, 0.04811206832528114, 0.042123715193676095, 0.06633743750197546, 0.021061272360384464, 0.09118527453392744, 0.031109870477978672, 0.017829554255253503, 0.061805949945534976, 0.002994529191970027, 0.017002818706844534, 0.04878654570451804, 0.010604073177091777, 0.016177894846935357, 0.00841200812387147, 0.026003098880339946, 0.0482076773020838, 0.02795094221697322, 0.03309557946132762, 0.017360664504979337, 0.051005721624408445, 0.03043053818068334, 0.026059724323983704, 0.032298897925232134, 0.03907957300543785, 0.06328409098620925, 0.053230407248650274, 0.029646205981927257, 0.027542277538616742, 0.040834054217806885, 0.03295751454840813, 0.04276379763281771, 0.032204167651278634, 0.05621342021705849, 0.03387469372579029, 0.032858540037912984, 0.011282811756245792, 0.055585938173213174, 0.018104720561365997, 0.04441505331279976, 0.04224462674132415, 0.03550479268389089, 0.019617717945948243, 0.052431076033306975, 0.01686228731913226, 0.017034782795235515, 0.026377261749335697, 0.01787528581917286, 0.05878668624375548, 0.04328559784750853, 0.014637413401422756, 0.0174175885040313, 0.04271054959722927, 0.09281178404177938, 0.009543177738253559, 0.1183429126228605, 0.04311009476493512, 0.01190403601088162, 0.057801310904324055, 0.046359548079116006, 0.022722382065174834, 0.008315017480137092, 0.058199950227780003, 0.029832911677658558, 0.06756616264049496, 0.04202263383194804, 0.034074949765844006, 0.04279716119968465, 0.06719818631453173, 0.05550707204799567, 0.0825922324189118, 0.019517791790089438, 0.05631400624822293, 0.013725015351415744, 0.048201122653803656, 0.015386538114398718, 0.019342142822487012, 0.014614477221454893, 0.023691983161760227, 0.03858370300648468, 0.03675919019484094, 0.014140150709343808, 0.01439123580764447, 0.034479777328670025, 0.04568020560379539, 0.029714578563081365, 0.0692177711586867, 0.013640634432834173, 0.03928922675549984, 0.06280146938349519, 0.022701668087393045, 0.1297434273042849, 0.043344650750181506, 0.019129335580925857, 0.053448223774986606, 0.04364012221672705, 0.03884805007172482, 0.018213459190779498, 0.023619278134512048, 0.06306654587388039, 0.011891890234047813, 0.035652648857129474, 0.021253304556012154, 0.021124276033203517, 0.038924945052713156, 0.02484454444077398, 0.03936731595812099, 0.09874843619763851, 0.023219587081777196, 0.028318977914750576, 0.019489603749077235, 0.051072791418326755, 0.09905584648783718, 0.015373903792351484, 0.013231611827255359, 0.023528654693758914, 0.049616404210350344, 0.07145922338323933, 0.028496363932000737, 0.005836871460944946, 0.03716725776238101, 0.057621044505919726, 0.03169052342751196, 0.028932078408875635, 0.008266644718657647, 0.07468497886189393, 0.004143846861552447, 0.03983612937320556, 0.035049407476825375, 0.04145128699019551, 0.047310131535466225, 0.07667269970157317, 0.05564947279968432, 0.034244810829737356, 0.05007931097809758, 0.01023137679190508, 0.061868768717561445, 0.056799783038773706, 0.05251774191856384, 0.03723000189555543, 0.01456125293459211, 0.03794744411217315, 0.03623846885082977, 0.03650531292493854, 0.022841444604897072, 0.03610506886616349, 0.028546243041221584, 0.023550963228834525, 0.01703099487349391, 0.03281663032248616, 0.04217458835669926, 0.018085032867799913, 0.021030181885829995, 0.03381616668775678, 0.0027985184486689313, 0.01958524665263082, 0.005024817289917597, 0.023730980265619497, 0.06030259454356773, 0.025665417446621826, 0.06221158496503319, 0.027896533886502897, 0.020055498561954925, 0.03730295458808541, 0.009211245192480939, 0.08131617946284157, 0.01875116426630744, 0.0204074597651405, 0.0603347367474011, 0.011646348766849508, 0.08785352510000978, 0.010053423349745572, 0.06911296463970627, 0.04323433791952474, 0.03720462807853307, 0.014504004935068744, 0.017779902455263903, 0.06168062452759061, 0.04292489541694522, 0.031593177401061566, 0.039154469700796266, 0.057802695115762096, 0.056367318744638135, 0.0626505564099976, 0.0475060856635017, 0.0217327709708895, 0.019413685858515755, 0.0505858475475439, 0.047800043996955664, 0.059384665584989955, 0.02697069151327014, 0.23303975803511484, 0.08002084932689156, 0.08808369096368551, 0.11953883059322834, 0.10101859723883015, 0.12072471981602055, 0.16372250685734407, 0.17009290573852404, 0.1542421512837921, 0.23883724265864917, 0.14844120613166265, 0.11756210880620138, 0.07562456665826695, 0.16091622172721795, 0.15912488927798613, 0.15256504341959953, 0.1281448530831507, 0.10531120654195547, 0.11168024156774793, 0.10181401669979095, 0.08892985127334084, 0.08076947701296636, 0.14115737697907857, 0.09338271019182035, 0.1882336073155914, 0.14931910830949033, 0.16729293098407133, 0.15982842152672155, 0.1266272280897413, 0.06474652394120183, 0.07922517202262368, 0.07132676656224898, 0.09328655499432768, 0.1930913073675973, 0.07388363579022032, 0.06478389765002898, 0.1321746725589037, 0.11055382593934025, 0.16651501772659166, 0.1350697372108698, 0.17774718786988938, 0.11319667912487473, 0.11880142587636199, 0.14082880318164825, 0.10968961659818888, 0.16826561093330383, 0.07959259873522179, 0.15833682513662747, 0.18837107851036958, 0.1380314068602664, 0.13957553543150425, 0.17801132798194885, 0.14133615738579206, 0.16006926074624062, 0.1754078569688967, 0.1855702759431941, 0.13461450806685857, 0.21312578661101206, 0.11665850372186728, 0.21800988167524338, 0.0781804316544107, 0.09732987731695175, 0.1375231977019991, 0.08807239335562501, 0.06804159855736153, 0.11206095399601118, 0.11216248319085155, 0.07276545079158885, 0.1124119194490569, 0.15075585192867688, 0.166796691183533, 0.16786549240350723, 0.06850747391581535, 0.16737926777984413, 0.14009692173983368, 0.10968034102448396, 0.10658743591713053, 0.0815520721620747, 0.10241553120847259, 0.0921903613156506, 0.12334370213959898, 0.08637604902365378, 0.17349214905074664, 0.18403072069798196, 0.1717219054698944, 0.14063413148479803, 0.24166222821388925, 0.15302374666290625, 0.07818596171481268, 0.13827939783888205, 0.07668159529566765, 0.11582089295344693, 0.24017466232180595, 0.08084051962941885, 0.11530961681689535, 0.06949562446347304, 0.2027110747460808, 0.23685222917369433, 0.09683133049735002, 0.10800722973155123, 0.062040410935878754, 0.16190015178705963, 0.2674047883067812, 0.13582365747009004, 0.10745316517672368, 0.22088307035820826, 0.10705331127558436, 0.1547533188547407, 0.12128844670951366, 0.18209879579288618, 0.24690277129411697, 0.06316918108080115, 0.06604686845093966, 0.14214482185031685, 0.22081474188183034, 0.24895536686692918, 0.15281630493700504, 0.13041151288364614, 0.08018048826072897, 0.13309667951294354, 0.0836499599473817, 0.12873862550726958, 0.227007676714233, 0.1433670534087079, 0.17260956498129026, 0.09879986236670188, 0.15878239194197313, 0.13393225467630795, 0.15950070268341474, 0.13287160944725784, 0.14200908770518644, 0.0656495387000697, 0.0880017646455339, 0.11134933360985347, 0.15448057491864475, 0.15202764368483, 0.0916447038097041, 0.1560623079006161, 0.09596977422812156, 0.17948388467941964, 0.13467069076640265, 0.11956519846405302, 0.1839166318199464, 0.10103286683027234, 0.1370247865894011, 0.15313901619187423, 0.11519269166248185, 0.11322045499192816, 0.14964241667517594, 0.17823377890246256, 0.14575202257505485, 0.15844169950910977, 0.11032513249665499, 0.1534221824258566, 0.06746245534824473, 0.1906158487711634, 0.11604357457586698, 0.10204039633806262, 0.11342957269932542, 0.12658255334411347, 0.08620686988745417, 0.1109752504687224, 0.0977514579093882, 0.2028472838657243, 0.18829622252711228, 0.20829144173434802, 0.15801643447152205, 0.1259908979492528, 0.10943877577249493, 0.1802652177533933, 0.17808629253080913, 0.11360831239393779, 0.19994149836046354, 0.1092162841398801, 0.11639274869646345, 0.07880672626197338], [0.04650298698938318, 0.03502143487068159, 0.005648365526992295, 0.006448244235278773, 0.08489488171679632, 0.030827613480921303, 0.07650888777737107, 0.0542687999217638, 0.032812667677977254, 0.05161783824275647, 0.037616400447274954, 0.0576772882736155, 0.06492904307586805, 0.06459415890276432, 0.03496530645393899, 0.02882718707301787, 0.03498775239235588, 0.02845775698577719, 0.06486992910504341, 0.02240470045113138, 0.07746096740343741, 0.05093471632738199, 0.05288113474047609, 0.03074431312935693, 0.03920260836769428, 0.07165572712463991, 0.0493657126623605, 0.003691378506898348, 0.0565837137401104, 0.024022477213293314, 0.02131418780689793, 0.04490931857643383, 0.059845845481114726, 0.05533468683383294, 0.0659074770020587, 0.03837880239422832, 0.02399440961224692, 0.020604643737897277, 0.04417225991242698, 0.009019227415722395, 0.0183909520772951, 0.04175374736743314, 0.03791634685226849, 0.028923142102680037, 0.03989784213315163, 0.07313763403466769, 0.07411104001637016, 0.02555240404659084, 0.015912350167387297, 0.05334341386333108, 0.03555820017520871, 0.02236978303907173, 0.020068385638296604, 0.04097552876919508, 0.0070607026656424356, 0.027824758452230265, 0.03225611289963126, 0.04118838181187, 0.03690239501052669, 0.06407264367278133, 0.01018228817598096, 0.02182422561704048, 0.020829584881929413, 0.01077984004015369, 0.054098596197686026, 0.028644634011600698, 0.024590772343799472, 0.04976459965109825, 0.015925669809803367, 0.021410644952473894, 0.10344105546495744, 0.016473766649141908, 0.02292599176455821, 0.043846369720995426, 0.029616411509258405, 0.03382244313667927, 0.046402984498334784, 0.03710532108587878, 0.025388729525730014, 0.013430932337152106, 0.02591024136303791, 0.014001754162433957, 0.015575213258021643, 0.03968754716749702, 0.03652656124904752, 0.0557781026831695, 0.046855275585715256, 0.050692747347056866, 0.05785285920969077, 0.01157702793300684, 0.03765096502112491, 0.022679508830021535, 0.022316061725307788, 0.009974158585204609, 0.03182065287338836, 0.025811378810820833, 0.04598714770483119, 0.05722546537539788, 0.02871947642415762, 0.02103017340414226, 0.01871709163034601, 0.04072155989706516, 0.04931305834491338, 0.009317608101160398, 0.04096077402521457, 0.022749009475644146, 0.07896768155374698, 0.0435815612519426, 0.031225764259163822, 0.017448263375886848, 0.03583254206127354, 0.0568200678431562, 0.07627772446721792, 0.009325016855395265, 0.05904594768903085, 0.029167862542505776, 0.0190046836089875, 0.03774963758353676, 0.03449427083666835, 0.0033943703705777545, 0.04295181968648519, 0.049025932859097204, 0.015466462754245316, 0.051609885812337906, 0.04111993459186383, 0.021587895262720327, 0.04821901222957032, 0.034132747378732474, 0.010712325805798173, 0.04376485730920519, 0.0587769356955375, 0.03343133555193033, 0.05286563700065017, 0.014822008853246058, 0.08298878185451031, 0.02609558998873191, 0.02812264719977975, 0.026234611636027694, 0.03940160911796348, 0.05089527987209814, 0.037484832507159026, 0.02669469909077244, 0.05195176907415901, 0.027071306382172873, 0.024589842750823925, 0.0714610486424395, 0.010109533106775155, 0.015603075602224894, 0.055155292352927585, 0.03474404636238303, 0.07956676690706185, 0.04237521080566304, 0.010379561206458934, 0.02802175752419446, 0.09013309063655989, 0.011822510876559784, 0.04667794045859149, 0.041694545187056065, 0.0639062804569091, 0.026008617066379105, 0.06821892011378493, 0.028514083874012743, 0.015225036601935114, 0.07241459390414612, 0.01930345275572368, 0.04802340076171926, 0.02650726566623364, 0.03441160830802151, 0.021489443224189535, 0.03771696951506393, 0.022620062377037745, 0.060829544839050086, 0.034960451535880566, 0.05347034401659455, 0.03298620300899659, 0.056289178651890585, 0.032612479491425414, 0.04750432486512831, 0.012087074224837124, 0.01645677613227495, 0.03679945785552263, 0.07645322076444115, 0.07495358373437609, 0.03693132095837167, 0.01970116757521672, 0.013260916058373238, 0.05176225085077541, 0.03863236075267196, 0.030748550580548387, 0.06948702063943658, 0.06980621029755898, 0.008662497807693268, 0.03017568721302918, 0.0357017815778298, 0.016916695649602582, 0.06465473172387906, 0.08390692115894385, 0.036084784061781, 0.030156148797167198, 0.015788349589066844, 0.02197556267492473, 0.024584448397425667, 0.015184970805421472, 0.02459013452088194, 0.02442601725592145, 0.030600738512086015, 0.0322967062571219, 0.04017645878983395, 0.021061669303370372, 0.06136619818529912, 0.06861184617238385, 0.02004390748749886, 0.022098859273163334, 0.013609078313623155, 0.08139381065432515, 0.039843206493450065, 0.04035482868286116, 0.016876363528094122, 0.013200019236787089, 0.03403988307608025, 0.05449178349226713, 0.033207961823791265, 0.09951539789991719, 0.005542536540555635, 0.008818327615569745, 0.05022494834182518, 0.04438990680500865, 0.032587892775024684, 0.04452684195712209, 0.029291037004441023, 0.04076289625040122, 0.027392947248050144, 0.02467665621744735, 0.03517972691250699, 0.05203870637342334, 0.049048521289868016, 0.03469052691278713, 0.06079793189253126, 0.03296703778739486, 0.06058772174375398, 0.023448655415060263, 0.005250277089154614, 0.04476339962067349, 0.07255785978798356, 0.039109567645937204, 0.07193039131483861, 0.030033649477575506, 0.007312113884836435, 0.007815379067324102, 0.023061849742329547, 0.011795485674935793, 0.013609272544272244, 0.03980526960055743, 0.031210890771555047, 0.06523607338645629, 0.014869090701852525, 0.02746591860029314, 0.02283227420412004, 0.03863412494372044, 0.030438161521617855, 0.05258167688069599, 0.01604828787302332, 0.029822499557797397, 0.03207393303247435, 0.04028064105659723, 0.04109894071838685, 0.05199926991813949, 0.029691182675638368, 0.03471737315079995, 0.03537434093388064, 0.018866406653874686, 0.0040978116532122445, 0.042973563341157775, 0.08275854813733272, 0.060490168764122894, 0.015322117999728237, 0.05594389932230115, 0.01773194529648338, 0.05144241997706039, 0.013346167198116226, 0.017826931717406427, 0.02448092430963048, 0.06436744678233351, 0.0759268132969737, 0.05571064951696566, 0.06534845914159503, 0.03208005002566746, 0.020195146157805408, 0.017901843679802756, 0.012199737331164735, 0.046143261649246724, 0.04030736176563161, 0.026974372565746307, 0.03837169134723289, 0.04270147419135485, 0.024506666231900454, 0.058176377921232154, 0.08108899236789771, 0.036201997593577416, 0.05771570014102118, 0.0570193739341838, 0.03067530272528529, 0.08216102341456072, 0.026433220532323633, 0.004923845766045685, 0.002529146195489115, 0.08772370099489178, 0.04182848460706217, 0.006291405530646443, 0.04270283126139215, 0.06046146673283406, 0.0478185001494629, 0.033425323731665096, 0.030826096955154623, 0.07803299956555877, 0.026212918871481503, 0.014575237541326454, 0.027181536092289856, 0.008417501713016202, 0.06471050051706177, 0.024677090479859283, 0.007993845651591463, 0.029700085055083036, 0.028887386699872356, 0.026192796915503483, 0.02974514995834657, 0.012248345035394388, 0.025231255118602088, 0.010567830077239444, 0.011549305536651185, 0.005244269509733255, 0.03066557931846806, 0.06782920352582421, 0.03655128027977688, 0.007251800603366324, 0.007564258345934961, 0.021158017883343355, 0.03920907819909709, 0.008229586528614163, 0.00364257233117574, 0.010436166294052132, 0.01797770389488765, 0.036866568361542056, 0.024147259803222756, 0.02370946731285325, 0.01035754953045398, 0.030140508564987352, 0.0024810900130043073, 0.03742673294618726, 0.04670124474380698, 0.03374925634956785, 0.04376884370243975, 0.18504789897373744, 0.10426523124000855, 0.07151001851473536, 0.07574375811964273, 0.17310467841369764, 0.1941031523581062, 0.1437791684376342, 0.10910850563751799, 0.0974861371463963, 0.15520651239369596, 0.1203620292778526, 0.13896365969308785, 0.15299979437674793, 0.1546464224479028, 0.2050147961292948, 0.08425015131277697, 0.1854965327573674, 0.1247112758989845, 0.13736026787332126, 0.10524187383374997, 0.19759288510041578, 0.12461755664220878, 0.13076926368687833, 0.0948543915791171, 0.09009874997926609, 0.15026205485420568, 0.08365810915295567, 0.11388313264719077, 0.15096163802913257, 0.08802332170307636, 0.09237773876105036, 0.1461689823440143, 0.10082879063806363, 0.18694611425910676, 0.19249407441488334, 0.1077477986525212, 0.12220892017441136, 0.11123719891267163, 0.12014928140810557, 0.1250121926090547, 0.08445992041379213, 0.11362901449735675, 0.10736386996826955, 0.08981647941150836, 0.1145686430058309, 0.11463754145162446, 0.2022680320910045, 0.10804583158876215, 0.11492044984229974, 0.1404527047915118, 0.10210729310555117, 0.07316086707370621, 0.14775733782776765, 0.1868265699595213, 0.13356641573565348, 0.17030931769737176, 0.10245559870132379, 0.1735868996807507, 0.1627623119524547, 0.14895854837128095, 0.12349737675062247, 0.1904117182961532, 0.10733481509877102, 0.19353272153862885, 0.10187883036477224, 0.11885028039770466, 0.09858261580978121, 0.1896885899560792, 0.13981714818094457, 0.20791817962058953, 0.16377749533525535, 0.12135153689554759, 0.08267027073140655, 0.1983227716492755, 0.10182764168296542, 0.14076367739055837, 0.11021390703639813, 0.1253297877098833, 0.16232666532908166, 0.09483278702412333, 0.16946941348058836, 0.09498226150338139, 0.19790818675288133, 0.12863833803151334, 0.12988016568124294, 0.11511365590350968, 0.1796120870858431, 0.0872462091169187, 0.18552891244845732, 0.10716566988932234, 0.10566855022417647, 0.13332919989313397, 0.09190839608865124, 0.11252307705581188, 0.12073704201195921, 0.11468715593218803, 0.10002111683466605, 0.1806476672313043, 0.15932421572506428, 0.12437643243798188, 0.12391101169799056, 0.15833898287798676, 0.12037933192082814, 0.10644837016505854, 0.13288748716669424, 0.08390999492257833, 0.18261480810386793, 0.1263066338641303, 0.12683975882828236, 0.14719058466809137, 0.1980103062731879, 0.11619621781366211, 0.20880966606949056, 0.10157209860959224, 0.17198372499219008, 0.09745997283607721, 0.15325054020753928, 0.14890543265002115, 0.14466524017708643, 0.08054898027330637, 0.12717701787395136, 0.14521189512951033, 0.07471818636570658, 0.21573995133595808, 0.15665622960243905, 0.14982418263597147, 0.10734675731509924, 0.08499667554029397, 0.15531723573803902, 0.13820356476519788, 0.16304961725005082, 0.10749815883381025, 0.06975085541073765, 0.0998058719560504, 0.15779969681586536, 0.10491507779806852, 0.14083965974194662, 0.09054108017257281, 0.24133482149669103, 0.19393293506332807, 0.14839756275926316, 0.0810627466333764, 0.12348189258149692, 0.07760131558669464, 0.07977458861257349, 0.1478632435734783, 0.07901990160878215, 0.140523299574852, 0.1492346306996686, 0.0712542108127049, 0.12542954592832498, 0.18323215283453465, 0.08663055393844843, 0.12580127455294132, 0.18396909614758833, 0.12992766313254833, 0.12983805579798563, 0.10085965041071177, 0.12216637602874211, 0.07844442927411624, 0.269568745046854, 0.12779377906450204, 0.10583637907568898, 0.11797174039695944, 0.08144225805465664, 0.11097149817006928, 0.08160449577761547, 0.07977515858198915, 0.10377606855971472, 0.1288534200617245, 0.10378207359462976, 0.1380224366273199, 0.08491207579416887, 0.1679746551173074, 0.14760678447782993, 0.12606693458344254], [0.018737123680434058, 0.06813256296196155, 0.03670782170125416, 0.03118799700002585, 0.11396040421511446, 0.011974916627098407, 0.0456529420667461, 0.03501039171325309, 0.038985616261405606, 0.054177801590412855, 0.01630625331641308, 0.020975530979090502, 0.016007747101996626, 0.03179138765803405, 0.039804387505033186, 0.032836423188980134, 0.1264882098351206, 0.03461764207375901, 0.02069409331306815, 0.059303024251546176, 0.0745486408205969, 0.034797338502747674, 0.023557695992557064, 0.10259014541017157, 0.012988683568047625, 0.06463372427970171, 0.07172508697424616, 0.06209093465336731, 0.045718885492533445, 0.016221694282389114, 0.01930326615859355, 0.03274332818442157, 0.055683894881180356, 0.10433451645076275, 0.017176435462066104, 0.019065573645223464, 0.020159579048465406, 0.003357045219412872, 0.05879111707742725, 0.013609539717435837, 0.042610540320830684, 0.029079184800918614, 0.028640813859445707, 0.021450788780514683, 0.013364887131111962, 0.016371341788076928, 0.0021632048384552555, 0.023143776060481156, 0.01423328642600349, 0.028425942175090313, 0.028658927351768528, 0.028963043354451656, 0.04026577774701374, 0.017267903678917458, 0.050862292892166545, 0.03296007601810353, 0.046981703623064926, 0.07611723057925701, 0.04851412067988089, 0.008754168736881443, 0.043242035899311304, 0.010616703258295144, 0.05459147724988205, 0.11006631209914174, 0.08298165045146431, 0.032630586198398044, 0.025796644422890883, 0.036708825933081765, 0.01836733227329595, 0.005862290230912289, 0.023739830058600222, 0.031158378946461847, 0.04169283527880907, 0.0994918527347701, 0.015007847720491034, 0.01926713077617543, 0.046409488256488524, 0.01664997371179717, 0.04934525143887315, 0.04196669201233557, 0.05492248020267912, 0.02573306399530598, 0.07086379533367497, 0.08107194078287908, 0.027342196221330335, 0.04746690705152495, 0.0498717572939183, 0.05626327218487859, 0.04113773595807808, 0.030834934873772517, 0.016530760198033283, 0.02003343599582357, 0.009910588335644985, 0.045705189263182025, 0.08051978291145392, 0.014088743199993457, 0.023641566313537102, 0.03804758570290037, 0.04838850349187851, 0.032548408822289536, 0.0686329078993627, 0.03940830625859754, 0.02504307191286768, 0.016154200404084156, 0.012791063636541367, 0.03754597869036453, 0.012972243512714548, 0.028684195995862995, 0.059125438066465516, 0.004171094707479435, 0.010517382694940482, 0.01639553325782929, 0.04415112015392099, 0.0294284539164177, 0.04089330050296017, 0.01973900947320674, 0.03567104733416012, 0.031064225427274193, 0.0026037335212874624, 0.05380809500015207, 0.010648637660779059, 0.016753087285906076, 0.02844898692066116, 0.04712089151144028, 0.04085546539032033, 0.016619275091215968, 0.020663443886275803, 0.010327348784942712, 0.021143500626619374, 0.03219022036397031, 0.004838109049679977, 0.06209408984120403, 0.02835843981509762, 0.04318950371816754, 0.022775111021474004, 0.07304826418736152, 0.05333636049181223, 0.02266262687875756, 0.016754423999892812, 0.02473091866288866, 0.03075134614482522, 0.04481793348012226, 0.05598438072151371, 0.017068780792344893, 0.009609183928530132, 0.02299918364068227, 0.03227544775498765, 0.07310134598187037, 0.029109773159559284, 0.04323196304695947, 0.048503060559076924, 0.02405783736945263, 0.013676750307370509, 0.009535526407749524, 0.054989332865391455, 0.009274675494192966, 0.03311971155926585, 0.03501706849783659, 0.040327208914927075, 0.04796416126191616, 0.03944595138143216, 0.054266659143779955, 0.023876498885718838, 0.054176732897758484, 0.040283375552722385, 0.01730264806454735, 0.008417084413979734, 0.028333814082933322, 0.005935063535746719, 0.008194572425314357, 0.03267148489664708, 0.010112310859507747, 0.04675343765744141, 0.05321426490055663, 0.029777322696255784, 0.012431079604929047, 0.030525896099529097, 0.028504306184394018, 0.04899152774097664, 0.05671184490035687, 0.04395941365510225, 0.012063724138507885, 0.0655597278050014, 0.060756174847483635, 0.0342617063517017, 0.04250889916771224, 0.11967708888862814, 0.052021858348910294, 0.0019221126525995455, 0.04184836568310857, 0.042649142178041596, 0.027430724685213397, 0.01861433937613453, 0.037995979722057066, 0.0065253232688909125, 0.048651619016059806, 0.05967004384313311, 0.04398275525974376, 0.005273868055415473, 0.039487498080624, 0.05073260110137718, 0.05537502574069159, 0.004460466568291719, 0.049331226120037694, 0.07324942946434021, 0.04024963879159518, 0.057289661573512216, 0.028594843111932278, 0.020414621702262332, 0.013745786156505346, 0.01219132264876472, 0.061982212987329276, 0.02252426341042987, 0.02714564498247845, 0.07493028962718588, 0.0100888021656179, 0.04590093304536172, 0.044660703345601044, 0.03077620088255831, 0.016090165358036757, 0.05470343552795904, 0.03977230636935149, 0.03793623810634017, 0.0034057519473468085, 0.03052279180181878, 0.050783287667270215, 0.023295664428068057, 0.02403386472724378, 0.06165486055293253, 0.04614286470626082, 0.06926724314689636, 0.04380460589059761, 0.03799414089215653, 0.04088529718241521, 0.038286548773092885, 0.020630322895678024, 0.04130678277994905, 0.01951451107327427, 0.04744403024337121, 0.10964180023542472, 0.05992094573697873, 0.05025721268196191, 0.04628127906471491, 0.027145414280572107, 0.02150988409162632, 0.0031502266855178668, 0.052454159794641395, 0.03541677312127181, 0.03346369488696967, 0.057292538561991284, 0.026296667056158185, 0.026791419168668132, 0.04433634664331164, 0.03296002173530204, 0.06533403348709856, 0.049109314634863815, 0.048079329010631354, 0.014132678342450942, 0.03615563329575317, 0.05308754848582404, 0.006571775352183197, 0.02747274635891829, 0.09413129716579403, 0.04068753815123013, 0.012588343666201192, 0.06000035469021116, 0.008632026496343315, 0.044714830084038634, 0.0767170623210924, 0.01856918117430593, 0.054660528366054804, 0.03272817310478006, 0.04283026692324451, 0.020244813224832927, 0.04423828136974147, 0.05351751237841589, 0.05679520971274801, 0.03275133150496653, 0.060824476182460785, 0.03897175379097462, 0.016729803356741155, 0.005518843369957591, 0.03886669621403728, 0.02163320274225303, 0.03030721444104399, 0.0376463984804494, 0.010113865552869226, 0.108713503261762, 0.022427197279674665, 0.02460480953699776, 0.016890421077342968, 0.03226695249655417, 0.07268345661993537, 0.022463766924504722, 0.04027236632204481, 0.03237575219411935, 0.010981911161382283, 0.0529769201363836, 0.007461040447066937, 0.056170479128403325, 0.04231839028320142, 0.02259620338944452, 0.031265699437686374, 0.03926889445366604, 0.054946683546794314, 0.06487053300121001, 0.03861648303323558, 0.023516278215018765, 0.023351623211055994, 0.03632120941100376, 0.057532970660499165, 0.051376096571662595, 0.09368593392095395, 0.0522977744362184, 0.0313529420777091, 0.02632769476622343, 0.04114643477701715, 0.03919098845549992, 0.010147147695533931, 0.02835052470410509, 0.03148129036916154, 0.03243490687704512, 0.033074819682432074, 0.06448774425578968, 0.030521645077637265, 0.017465652532077262, 0.04655121386583362, 0.025150845326217156, 0.030012675960149084, 0.031662635638245513, 0.05182243351425443, 0.027415260872138397, 0.04770914066050734, 0.035990488050239425, 0.017095971386879683, 0.08969678583421878, 0.07469546222793204, 0.052480931393802166, 0.019297295050429444, 0.039916596841067076, 0.03834299610129424, 0.04482946179008909, 0.03290170843579939, 0.017832699265064936, 0.010956344810048384, 0.015841791007135595, 0.02451179426030389, 0.014993289751665933, 0.021352282459182397, 0.04097838879429868, 0.03494629729539156, 0.05531059544799583, 0.11013446415641479, 0.14719481872660772, 0.13103698646383627, 0.10690992325544357, 0.16746738233736583, 0.1424968865300928, 0.14947046233075006, 0.14789664106709616, 0.13007831147738866, 0.09238914493471384, 0.17804083068455967, 0.0812848379303302, 0.09225760413599865, 0.17835842578538827, 0.18483616890651838, 0.13731635308691434, 0.28811158718807356, 0.14467889230166162, 0.04538943638492908, 0.1257618245269571, 0.16179917220558437, 0.1321488203746932, 0.1139442143695695, 0.18113059417477675, 0.10903680484209742, 0.209301834659917, 0.11860389076173306, 0.12020113505423069, 0.13351175295455114, 0.07372071953224284, 0.12238947834287371, 0.09849602795605149, 0.11647447145410947, 0.17368949417557034, 0.08382890320249967, 0.09816189017146826, 0.13443419417100294, 0.07218795642256737, 0.28914350324443405, 0.17277159914374352, 0.16331351308950356, 0.20406700484454632, 0.13890309365732328, 0.1388491772647415, 0.18631893077066966, 0.10638142590011869, 0.1207291167229414, 0.07201231084764004, 0.0721253819231476, 0.1002312455592411, 0.09212909638881683, 0.09659063377018486, 0.1657174133828708, 0.09735808401767697, 0.21370729112199374, 0.14917174407414027, 0.08432065788656473, 0.10338397709918873, 0.18027949413018568, 0.11179399796362434, 0.15678293923182146, 0.05743404704013041, 0.18054759688675404, 0.25614756665059496, 0.15932159657989228, 0.17196856651987347, 0.09310796457741942, 0.0661894218730075, 0.163208665858422, 0.10319541900285653, 0.23016078823379107, 0.14408366781260284, 0.12424618085580212, 0.14280514498906477, 0.13833954318293504, 0.08624775162232773, 0.11634721899671213, 0.10386269034019538, 0.10070413696978774, 0.1697585643934352, 0.16626823454030923, 0.09374670351722411, 0.11040271619068724, 0.2275011616625956, 0.09927550862942423, 0.1595797384423869, 0.1341709361544677, 0.13795702585152217, 0.20845032749431475, 0.16573973718498433, 0.08045055876885142, 0.09098238577800137, 0.19260512345603534, 0.09007268744919981, 0.21414580116314547, 0.107853127643466, 0.07716648999069418, 0.14435452542134694, 0.11977292517466204, 0.17898098166499818, 0.18238828597324236, 0.1692684856908662, 0.10061688415173974, 0.10268327434148107, 0.06780354133141892, 0.10518218989350966, 0.21986555281494344, 0.12118935345539025, 0.16929827337818487, 0.06084717317883458, 0.11367411672004632, 0.2640871320452009, 0.12587378280503408, 0.09732605716479675, 0.1829771322331258, 0.10381165093609265, 0.12007103274975504, 0.09464003558137588, 0.1108499996896301, 0.11698843458933489, 0.11950098190988813, 0.11965524006102767, 0.11012056097388268, 0.13969921879470348, 0.14410645301852906, 0.10992679851395742, 0.12359773207988058, 0.1258938674415861, 0.0930273410465036, 0.1591459917170661, 0.07765605300664902, 0.17095995135605335, 0.10912666323461703, 0.13930298148521356, 0.13956493671451295, 0.18601627701095172, 0.27764032621468815, 0.16559564348842415, 0.09343314569975648, 0.15991851740649768, 0.14330552385321685, 0.13668356489922318, 0.14831001817115716, 0.09703103692403861, 0.12471009524805204, 0.0954918684437871, 0.18085134987320217, 0.186635643775974, 0.10935762298426457, 0.14919931973729814, 0.12225279424871717, 0.12746243684419564, 0.10599090185548578, 0.1410799968455519, 0.08633845818362065, 0.06482853168355567, 0.18412156296627863, 0.10378474023725305, 0.10565983104918684, 0.1088396632777793, 0.1525239377681698, 0.17407844401896, 0.0948812954926065, 0.177520272188953, 0.11647368435348783, 0.12470341846346855, 0.06790258708809103, 0.10870576117719923, 0.0696515246693577, 0.11998567304440907, 0.09907978520329509, 0.12995295891804354, 0.1518076490610838, 0.20778506462063107, 0.10384945890733174, 0.11777272607598986], [0.02497807504343135, 0.03171322720923594, 0.04513596284336277, 0.03300648442070399, 0.0038588231379565385, 0.03151437573667083, 0.0023574178880413194, 0.04724548750423959, 0.02898694135780845, 0.051064947553511174, 0.04398638881476862, 0.04234935522877744, 0.013043531249942524, 0.008038712931530816, 0.009529009078895407, 0.04416663485712238, 0.032721316508416615, 0.03823301575279661, 0.06721549574285746, 0.03063104527869395, 0.057728666945227554, 0.06948763132095337, 0.06649285594799689, 0.024626239369224225, 0.02968056020992143, 0.01998282067610749, 0.04496412384989006, 0.022301954982270087, 0.034558310971728394, 0.10810350027999707, 0.0695993656824742, 0.07749387635184185, 0.05225446354597807, 0.01297451151601438, 0.05175413217927728, 0.060561652428337505, 0.057412713899144104, 0.032445719332567284, 0.10287643290523972, 0.023588350508362055, 0.02891476558787482, 0.017205534436340843, 0.02481958961912564, 0.05700955553246396, 0.03592474139960749, 0.02581170790030488, 0.024397741005356823, 0.020353814786566154, 0.05326682422310114, 0.05767167678901127, 0.036730318529797454, 0.014999991981312633, 0.01490747882053256, 0.03374407573470047, 0.04381805784734232, 0.01655695164975311, 0.03848672338894435, 0.07036483460771185, 0.053902706530477316, 0.021229822155354277, 0.0839688510500959, 0.06183958492640938, 0.08752519557518618, 0.020514651334711483, 0.02785400840054665, 0.045041968779904504, 0.011383765044489076, 0.021554984617978334, 0.008569900678204638, 0.05123408258493457, 0.027101010948951756, 0.0266657018967505, 0.02607184465575431, 0.0525569239232157, 0.02666597331075796, 0.0048472951415793174, 0.02881995728239417, 0.02295562847783523, 0.021471351784254824, 0.055939923107091866, 0.030696934421679804, 0.03740042953618935, 0.04162349917792848, 0.011196424070346569, 0.04329210499833737, 0.02258816614214863, 0.022005285901416625, 0.055198185944131443, 0.012326486824479486, 0.019799965666607022, 0.050119042596114535, 0.0811988946848682, 0.032575719856790135, 0.04053400942523565, 0.006516531999555549, 0.010230172392246979, 0.08720222647700991, 0.02017095808072814, 0.01585604533153985, 0.06368000938424043, 0.015232332549723131, 0.0431446423754096, 0.04856506169640592, 0.051498517859727144, 0.025974264534722482, 0.04678285215049982, 0.02686059920649443, 0.02928086237183639, 0.09985113702714443, 0.0723579769421901, 0.022272316572655524, 0.0503293579178197, 0.032826869415917566, 0.017045917554891536, 0.02188197912515274, 0.004688148993799197, 0.007155045750550926, 0.03710237963657294, 0.0478065511477845, 0.031078603584319353, 0.06515342103583471, 0.01546691737270781, 0.08603786038500921, 0.017281182609232407, 0.023625456195856844, 0.04055539006367326, 0.028174999569143568, 0.01676768935950739, 0.0222139422050012, 0.05193377771813955, 0.03419421925874693, 0.03295182503227677, 0.032347369074289284, 0.03732587210834026, 0.024321797669732144, 0.0736537209845015, 0.028062405164486597, 0.03193296738235014, 0.007801071308287126, 0.05409239099494048, 0.043933988947953494, 0.0038796558593665914, 0.0035157666466797566, 0.047892368864268064, 0.00925822526083461, 0.023342761543712447, 0.018579304916784167, 0.01839462973709617, 0.033213573308395486, 0.01871666415328426, 0.02242771296628884, 0.022307383262419274, 0.029085468035191298, 0.05438092104824526, 0.05938457737543753, 0.03851063835567661, 0.025244995452729718, 0.02160171023570001, 0.01725022105633148, 0.012265463625746114, 0.04270430028970752, 0.048133079162133593, 0.03199652575754693, 0.03701160182910306, 0.05427237240863698, 0.011057058914697595, 0.008365771899531995, 0.06484867060290915, 0.031108774643923556, 0.009044240761016096, 0.05037600041500159, 0.03381296739514385, 0.04802461533940264, 0.0312812005701874, 0.057918663535799296, 0.02631785431211548, 0.07272449441786323, 0.05740292263882501, 0.03194455676046865, 0.04940686241856643, 0.0047395586235714805, 0.024875521260712827, 0.029148381802120378, 0.059319899417459965, 0.07034466854695763, 0.04149432646642838, 0.04837819993762033, 0.006850869527884892, 0.01810985367878207, 0.008345585482727205, 0.051369887976241965, 0.07166919604476009, 0.039174561122698445, 0.011461827105709484, 0.036267194630844254, 0.012181144623484994, 0.013678079387838287, 0.04024078390960183, 0.07962094792830092, 0.025864223118073175, 0.038511506880500486, 0.04253166741026299, 0.04882339694138084, 0.03335294100855078, 0.023916593519970775, 0.016817356426534907, 0.00918729036181633, 0.02065134221421821, 0.01831081200258008, 0.08357542966093336, 0.0416356415620872, 0.005709884480373668, 0.040011886906410964, 0.04728743453909244, 0.0238778983641948, 0.028569862845220735, 0.01884138397872448, 0.03554759806554232, 0.019345123287556425, 0.016602764637874703, 0.06119748723826238, 0.029293720610439777, 0.01722366489203913, 0.046975959824132066, 0.0824990017073495, 0.08614578816507544, 0.060432425434035916, 0.03937064077971237, 0.011776246662650789, 0.07188813215387718, 0.05756528928343739, 0.0350365933429982, 0.03527953262839999, 0.025120000820606947, 0.08644157515040465, 0.03767410306526082, 0.05444813672719257, 0.04218191314222557, 0.05266071942501834, 0.06439719375755106, 0.03169988042541912, 0.03452731888475163, 0.04863659625074693, 0.01022580432306443, 0.018534384202212095, 0.03996122408924358, 0.06402889173477888, 0.01512728345447353, 0.035523567747856886, 0.06388286421341555, 0.02433111734821328, 0.03764629330752151, 0.027495146496221423, 0.040947569733751674, 0.009094185179232486, 0.023248385804306184, 0.03828829260809081, 0.008885760425723024, 0.01246296735813043, 0.0496715487513159, 0.02667818863743118, 0.023284131029088582, 0.05598445536036577, 0.0019866203406958705, 0.04415910311841539, 0.022049604416159645, 0.03034409960465772, 0.046477884586368284, 0.07596460091216223, 0.029566118493676186, 0.022563433540718894, 0.045333470816590955, 0.06047347680266414, 0.043804870519254885, 0.013303230350304927, 0.02074420142785779, 0.03874161167602454, 0.04193883475714496, 0.06059492778565202, 0.02773663880569594, 0.026847154035099914, 0.029668522998690605, 0.024692028428294828, 0.02425405103713274, 0.0981600581269179, 0.03040823812729546, 0.02834300314342337, 0.05092634320525186, 0.07084826366709811, 0.039802083878644874, 0.02169707154722086, 0.0473705890056278, 0.010016192133272333, 0.025584782041343193, 0.0165048215006079, 0.07800532890749828, 0.019965753824050938, 0.07009655543203865, 0.06540172414055892, 0.03352149589253323, 0.08247517834284476, 0.006366676692518273, 0.02798581891693175, 0.013898698263801634, 0.03152660293770688, 0.024774210893415978, 0.034774909527706246, 0.006061398274531322, 0.041490801477006505, 0.045385497489145825, 0.0145167529117316, 0.07562392883534942, 0.00853528521422829, 0.03425329591014555, 0.007068415064298148, 0.08035430179110595, 0.05159171125186341, 0.003684174161337848, 0.0416657108414386, 0.021641066963119165, 0.0243839718334909, 0.048279300065977235, 0.07011307097439255, 0.07544848682092768, 0.03893040047426309, 0.026967797561415603, 0.04795566261080759, 0.031566205634070296, 0.022187925476048673, 0.029785295482724905, 0.03086765043969665, 0.024132827363376106, 0.02059013835553612, 0.03538060381210276, 0.015106486356151956, 0.06202916082526956, 0.03227660126451935, 0.02812358527444303, 0.016285876909803067, 0.02673218645421522, 0.03470853523218206, 0.028070467856845686, 0.007674563543072769, 0.039579073166740794, 0.02920783164777926, 0.03908587659576109, 0.056890255505485196, 0.04208178512219872, 0.10926771709429366, 0.0555305018621896, 0.04998985292123897, 0.030540033376642635, 0.19394403589623316, 0.09755586340491261, 0.08494934093739305, 0.1009218856426222, 0.08366685546934605, 0.20249410638851778, 0.0938710586300918, 0.09147219985191311, 0.18630994696702274, 0.13435699045658112, 0.07371795789471694, 0.07648644862430436, 0.1484025296355997, 0.044016644691250155, 0.1291612306875842, 0.1303075613187892, 0.13221425829189165, 0.1378238294273615, 0.12146698284362044, 0.09160602731364113, 0.11382223412926708, 0.12204084705029215, 0.14482962207070418, 0.0592033610280071, 0.0938942034595779, 0.13356120458671025, 0.10811951370643717, 0.13495072216859885, 0.09363027369337422, 0.12776175221162184, 0.123394497271095, 0.1908648439816066, 0.11238876104887043, 0.238801687423672, 0.25755362691623823, 0.12340567952820233, 0.12131178831415516, 0.17496229016355105, 0.13908222690224648, 0.07116961785193, 0.07558487235967602, 0.1000730994024447, 0.07381414701896054, 0.10935832187533379, 0.1520923894963094, 0.0905389292165637, 0.1193458145218236, 0.0842990872583219, 0.1374472017799105, 0.16660552072737897, 0.10934478510171175, 0.16089338223849023, 0.0699457170973931, 0.15312912315130234, 0.17438415118626185, 0.07553574642432587, 0.10893377608486585, 0.16937015737806047, 0.19573910028806754, 0.11695107445120811, 0.19449611912880624, 0.1949505340307951, 0.16879952299807752, 0.1362008957990578, 0.13671917441700185, 0.1277671940624714, 0.08638671559414693, 0.09800054132938385, 0.08548690352056708, 0.16845083742269448, 0.10695551402334656, 0.09200271245624338, 0.15230707797620976, 0.0886975819511073, 0.12244817162198679, 0.10199319065681525, 0.11375241966119834, 0.1029233332457287, 0.10553378638412271, 0.12761129385658673, 0.1515165168259825, 0.10710293254149811, 0.08695094460355383, 0.11355827043631248, 0.06935404813183205, 0.07445548474788666, 0.14894508623651095, 0.1397456984434809, 0.10842481375272785, 0.10876547904419047, 0.14843222232801573, 0.1460322303963559, 0.11151294197354998, 0.09966822434216738, 0.07359027796025787, 0.09854410216212273, 0.15991254629833357, 0.14393851560141357, 0.11887563046600137, 0.11884310149720737, 0.1090984158217907, 0.13367515775774205, 0.11509624469493117, 0.10894316700952393, 0.1281681675463915, 0.1686913916575057, 0.14649994458471025, 0.08494991090680871, 0.26761461847594803, 0.1512803594980921, 0.09642897958734206, 0.1858333439699241, 0.22080478098775658, 0.10188203305006027, 0.06433832405933312, 0.1189710053482226, 0.08518450081880603, 0.10604408543024745, 0.1873036886432341, 0.10186437756887504, 0.17083283460565976, 0.1629500218800136, 0.25152956587927683, 0.14599033764430455, 0.14151306503585406, 0.18254171631165914, 0.14815840630659036, 0.09076728339173964, 0.12492289740060057, 0.13461537659168243, 0.10060450767299958, 0.08423881299261536, 0.11970433885497705, 0.2769130452403, 0.09072857975427594, 0.18447000426905497, 0.13496372289955616, 0.09026476714227881, 0.08273724892309733, 0.102934223732778, 0.15365714553211415, 0.0784486633326326, 0.12116546902273383, 0.1781478492277009, 0.11108647592897926, 0.08162866519497973, 0.1565758910562311, 0.1566446130829198, 0.11645680240222386, 0.18856888503900596, 0.11156677015657936, 0.09208655902849776, 0.08571970888546535, 0.10160899055855614, 0.15942212832825525, 0.10305304199989353, 0.19829683804086276, 0.12289483765406267, 0.10633863069649253, 0.1185715382120439, 0.10003381901021514, 0.12519930542579719, 0.14592952733593328, 0.11467133249555315, 0.19516496466738836, 0.11556855935071196, 0.09523019819919552, 0.1598606112280062, 0.1339002956769296, 0.13828933159155504, 0.12485619740826742, 0.17002357303031854, 0.24199859159333365, 0.09381969352918011, 0.12354068085551262, 0.14237715224070208], [0.015820008336699436, 0.051889672941927395, 0.06687023676931858, 0.015560645111171263, 0.057636196192886145, 0.004800994880497456, 0.03202650682734592, 0.05164939012112362, 0.02817649913153478, 0.0370219223467367, 0.026906614058784077, 0.02750046451443008, 0.03342930333954947, 0.031313200281666856, 0.02713030330570681, 0.06057969467448337, 0.03618969575368932, 0.0591846334614924, 0.02050298562140337, 0.012194664433731564, 0.04122347903570958, 0.03991239670930164, 0.07582868356257677, 0.04993206209370068, 0.03676570752369506, 0.02615343001005905, 0.03011689554633839, 0.045800696459731886, 0.04910830022501094, 0.016515274332570176, 0.012974592940216618, 0.06172382006687777, 0.02101064346996801, 0.02266241144388914, 0.003319882704610271, 0.053576066557850154, 0.08847067305552107, 0.03565118661416428, 0.10144159596945558, 0.11492207832634449, 0.08575746257390295, 0.04992269491776824, 0.01832811634189316, 0.031359164243830104, 0.017234531630362784, 0.031445216054895093, 0.035493484897805114, 0.0669450316844242, 0.0335401386421706, 0.04556214390322566, 0.026750598501946245, 0.014533215867621558, 0.043131197204015086, 0.04757267030488167, 0.006547346395174307, 0.051983402376728396, 0.03642908290826848, 0.02037270859416042, 0.04687320587358304, 0.04484258805002485, 0.039755166574780426, 0.023818787786045244, 0.03289495022701366, 0.035313255818826814, 0.059397218482834954, 0.010125073255039752, 0.005210319858243955, 0.024720455652901104, 0.04526420596188732, 0.01630983598131154, 0.03876330444057073, 0.05275706461231623, 0.025203197695580975, 0.04064874969688909, 0.05834221187978983, 0.06697797455957957, 0.0057559964479878545, 0.01526669186672994, 0.013886024925990828, 0.029463327223701135, 0.022192191764978424, 0.007723982096649706, 0.005570152491730238, 0.05120811844244599, 0.016154325933062604, 0.045787488775593896, 0.03598456443952663, 0.08343060314655304, 0.060332470440438817, 0.028356972483119795, 0.07397481054067612, 0.06623134855180979, 0.057641828033540926, 0.011304867537026959, 0.02485351637005806, 0.05653637574453439, 0.033570401304002316, 0.0943370425541486, 0.02707964218487697, 0.06511720762188945, 0.03860554165605988, 0.021570382273889015, 0.0739785289125783, 0.028072763001546264, 0.03720686385141952, 0.044117926220808706, 0.048364795478326936, 0.041012600529938936, 0.06599028541573457, 0.06979464806084122, 0.019055365085867897, 0.02836410897517843, 0.012184518638865223, 0.07638315523841552, 0.026980403045724546, 0.033505709775324376, 0.009462542332974928, 0.06065408925392798, 0.01163032855505922, 0.0117195236795981, 0.05667205221418824, 0.030158340465277433, 0.061781271626906734, 0.0289455507216709, 0.04423097354759063, 0.002342399151530117, 0.02080704564494746, 0.00246361646402095, 0.045023631371025524, 0.048499464323478084, 0.04990585707128048, 0.055708753011588535, 0.08677886812282459, 0.06435308219598872, 0.0059603071588623735, 0.0720547464277063, 0.020435259344854524, 0.05688039639166423, 0.061533830261656215, 0.02703586480181132, 0.0172510149423033, 0.015346362055944545, 0.024307672266981432, 0.05316224501335195, 0.009274661923492593, 0.047839351530585966, 0.044550387122269185, 0.062019905607615194, 0.04970888853339212, 0.046631063866828165, 0.03118477056601218, 0.02232538310012647, 0.030652296995478015, 0.03372203013194459, 0.06623786248798881, 0.06152747238853148, 0.03670331622873034, 0.04800252223919545, 0.030644520984164307, 0.03602327146966543, 0.042567626373576264, 0.06078447654311146, 0.01601239337053682, 0.06134268016155277, 0.02275200860042657, 0.045646747042025836, 0.04352692221956594, 0.01701715275911348, 0.022155730685751353, 0.03910697903484106, 0.026936766458675265, 0.04003132014934506, 0.05631862707169993, 0.024340201235775436, 0.04806559206917882, 0.034379265936357636, 0.02210081854302968, 0.023812872657020177, 0.05506943053166781, 0.013953544249358987, 0.05661344375195248, 0.015607145115999239, 0.020070287232686366, 0.02175646711007825, 0.014777368034369178, 0.05700737064970391, 0.0201940944285265, 0.07933018210210971, 0.023632884457973496, 0.03732209266828639, 0.013518596517055162, 0.036578296151544364, 0.02254876700629081, 0.07157213839569262, 0.046677930280566216, 0.07252077784921442, 0.01849195540749601, 0.05077246164104768, 0.0030032564245630056, 0.05644028840054359, 0.02007316761384053, 0.07677117548882961, 0.027213484913642918, 0.04292014227913959, 0.047141875206891976, 0.014381322411022015, 0.031561917292752435, 0.06957734043576888, 0.011328270209820142, 0.05097228002601436, 0.03457604109176567, 0.010180511262400873, 0.0682847990787455, 0.053976843266614845, 0.08200519106217793, 0.026956481293642094, 0.06225313166422503, 0.10936515472297158, 0.015222397100712572, 0.023045649718759314, 0.020082322747579644, 0.028443763897355114, 0.044167201433862956, 0.0459663573918598, 0.05490240574415241, 0.009327657204786581, 0.005287900159601122, 0.023924315248482993, 0.06868286843278579, 0.008311822428368032, 0.024825258779206445, 0.12141606557582106, 0.04195885832554527, 0.049887417882148705, 0.010114937638198691, 0.01671085357000785, 0.09179560321250133, 0.049204387569001744, 0.015543547725038869, 0.007457823342909771, 0.03814591221245272, 0.03774697772626366, 0.05009061537150826, 0.035732363151120286, 0.05637439586488264, 0.012982888878988368, 0.06363425576793295, 0.0247759072309626, 0.031195840864841427, 0.04401453784001725, 0.05930533805595977, 0.0539009084126779, 0.031928845282111845, 0.016357798229104707, 0.015561415248417428, 0.029373231343925, 0.019540877247761403, 0.034063065224992375, 0.05927733491574015, 0.040449460569236956, 0.016358486942148635, 0.04674648945885045, 0.023192064005083272, 0.045934208402676244, 0.023894636126767312, 0.030402555396514278, 0.03463993194912161, 0.027478780231571624, 0.03254239021667412, 0.050804841332137585, 0.03213629379336323, 0.028527159243822098, 0.06805764591055256, 0.05827986129692622, 0.026245159462892582, 0.01292367312791092, 0.06713015639356204, 0.02912118611857295, 0.033740716986358166, 0.03815296897664666, 0.029813875377710377, 0.07301423565617629, 0.017298895765894225, 0.0214578845604722, 0.040861063304224184, 0.038286151830106974, 0.014231106632256081, 0.01752267491870693, 0.010914099219787334, 0.010156102661442543, 0.02077053876460663, 0.07843640899019581, 0.03306628371189747, 0.04883842309936881, 0.022934775400374616, 0.019071317444156324, 0.05048897649560656, 0.022096883039921522, 0.05356092844158411, 0.015099315937342388, 0.03521842037194541, 0.03444031712466052, 0.06931769222553287, 0.023092068299385052, 0.014278420879106437, 0.03654407763055392, 0.033636907913855145, 0.03744624422064849, 0.02851352408262236, 0.0324212615378201, 0.05213093285315803, 0.04236509384853499, 0.01198780455160886, 0.015025917108037641, 0.03193001575501902, 0.052043883595615625, 0.027358024746977856, 0.03196114694167461, 0.02638959581963718, 0.04167921029563461, 0.025576481861727576, 0.033164542367947955, 0.05384454590135387, 0.08140506755028452, 0.038721913804433176, 0.04156733683443495, 0.0722834262996912, 0.008368927935537483, 0.07852895438138928, 0.04456969144354973, 0.055917904645736725, 0.030285107770136425, 0.05701174720057419, 0.030977532400616577, 0.055987162715090175, 0.016236052083383714, 0.020831004716455936, 0.007865721276695175, 0.06729967479727098, 0.030682566442659924, 0.05897062351661069, 0.09183273943407194, 0.022396195014672618, 0.04437971181635346, 0.021284683407949548, 0.03775170372266855, 0.03523940406739712, 0.05916668621024915, 0.019139880015115653, 0.041810903764728985, 0.00498020276427269, 0.03393861850989716, 0.14904933635677609, 0.10587181895971298, 0.1503438726067543, 0.0973577651062182, 0.10056026040443353, 0.10009526714150395, 0.08837980364582368, 0.1425903615142618, 0.13430022421692098, 0.12988642177411489, 0.11718390695750713, 0.17798764710979803, 0.07810927368700504, 0.08535115580473628, 0.16674297835145677, 0.10679236027811255, 0.08971357957593032, 0.275189674858536, 0.14118967524596623, 0.10328048015279429, 0.10608465503901243, 0.1676650938710996, 0.13645449147692748, 0.13135127031377383, 0.18225413960005554, 0.1074563746473619, 0.09436684381216764, 0.1591350265911647, 0.15511742074574741, 0.09639077128044196, 0.1628464910068682, 0.13761688981737408, 0.08218211906829051, 0.13509145033146652, 0.1099080913034933, 0.1954945834087474, 0.17168791086546012, 0.15862862233604702, 0.19697480755192892, 0.20788582707090036, 0.20591450642262185, 0.29978903915200916, 0.09815487411937543, 0.11433696400906358, 0.08892115923975195, 0.10104879204716001, 0.1335339274789606, 0.14479851802544935, 0.19148184944476399, 0.12206853127905301, 0.11287948435970716, 0.18504717972661766, 0.11572349603687014, 0.16714676097035408, 0.1274494496839387, 0.25850772857666016, 0.1355677004903555, 0.20181208369987352, 0.09423373559755938, 0.10304308789116995, 0.21015796943434648, 0.10567875539085694, 0.08258626131074769, 0.11083584544914109, 0.20123933229063237, 0.08359551429748535, 0.07741866753037487, 0.07135865770812545, 0.15159230918756553, 0.0964689724413412, 0.13224081615252153, 0.21405803944383348, 0.11810405472559588, 0.14529618274952683, 0.22872555096234592, 0.15186092763074807, 0.12746851651796273, 0.1209870550249304, 0.11095089784690312, 0.13047201106590883, 0.04393430785941226, 0.08670800192547695, 0.08562915838722672, 0.17348231029297623, 0.10447135660797358, 0.14489413718027727, 0.13861933031252452, 0.1013877202889749, 0.18138006435973303, 0.08700846401708466, 0.10774412777807031, 0.12743285271738256, 0.14577701980514185, 0.10950645964060511, 0.096850214126919, 0.10210526428584542, 0.2475900458438056, 0.14199079440108367, 0.11265824801687684, 0.1489771538014923, 0.1635708407099758, 0.11132097084607397, 0.18585230223834515, 0.19245176097112043, 0.1622230801731348, 0.2855508231690952, 0.14143188510622295, 0.16345941168921335, 0.11995007709733077, 0.13749342358538083, 0.11200835396136556, 0.08714147045144013, 0.08623871353587934, 0.1767135076224804, 0.1371218713798693, 0.23141469380685262, 0.21119036046522005, 0.15980852687997477, 0.09273035983954157, 0.13012479112616607, 0.10567166469991207, 0.12301500620586531, 0.10741530970803329, 0.1253827948655401, 0.0866148526381169, 0.05701140793306487, 0.15005932216133389, 0.11321282147296838, 0.26903460228017395, 0.08706600378666605, 0.09846552102161304, 0.128710805571505, 0.15315676666796207, 0.10232017668230192, 0.11302116925695113, 0.11297276256872074, 0.12404931070549147, 0.12298056376831872, 0.09998763113149575, 0.16205386711018427, 0.12889794552964823, 0.1280497903270381, 0.08354821362133537, 0.09646877566618578, 0.10732412138687712, 0.12410372921398707, 0.14557762550456183, 0.15796132385730743, 0.13899667720709527, 0.1693445494664567, 0.19834143136228832, 0.05739889892616442, 0.13910674915782043, 0.1704523257379021, 0.19468659747924122, 0.07173278156135764, 0.14071836482201303, 0.1330034623720816, 0.14933706234608377, 0.145647528182183, 0.12163656231548105, 0.10869215655007533, 0.13272546657494136, 0.1109396613069943, 0.136770118826202, 0.24570979816573008, 0.1585078431027276, 0.1824506162000554, 0.1346125810274056, 0.20493983158043452, 0.10279412660747766, 0.142767676285335, 0.19137507517422947, 0.08040656255824224, 0.11895037788365569, 0.15880156734160014], [0.01155174062919936, 0.007093900415514196, 0.0097863918303379, 0.02412266969414694, 0.012677969660476913, 0.030560776192162718, 0.035624191098447354, 0.0497131158065583, 0.04717727437881487, 0.058585514181426594, 0.05202534941158124, 0.04532884320776377, 0.032134088554552624, 0.022726653443117226, 0.032651149202138186, 0.0402660457683461, 0.05455230203058038, 0.03859581485656755, 0.02439975455802466, 0.0008202199158923966, 0.009492199402302504, 0.04849693338785853, 0.023538037136729275, 0.046358384391559024, 0.021414599115295068, 0.05341912140803678, 0.048574055678078105, 0.05393191746303013, 0.03210811084136367, 0.04381692469386118, 0.040036924848599095, 0.029073580101664578, 0.014111318908232664, 0.00983569588113044, 0.02053513121791184, 0.02032359962218574, 0.009408464788326194, 0.00821076990437827, 0.00795601902063936, 0.021351720971454467, 0.006280934038971151, 0.023863297986931035, 0.011720067355781794, 0.09278836779828582, 0.08872107961880309, 0.013663257638524686, 0.04334584157913923, 0.04173986793362668, 0.030748547187873294, 0.029332960290568214, 0.01935440903928663, 0.021699375173609172, 0.02800466013806207, 0.032638145078505786, 0.01383405932158764, 0.012546025981594409, 0.009167870689582611, 0.028580522630363703, 0.038487910825226984, 0.04193638524572764, 0.047813309356570244, 0.014726462640932627, 0.013488852086343935, 0.020810684288984964, 0.03115983779675194, 0.07775326671877078, 0.030068471894732544, 0.08265052536236388, 0.053389055521360466, 0.02873164934239217, 0.034273224483643255, 0.0774079534624304, 0.0180911634316934, 0.034526504642729244, 0.022078501526266336, 0.02283643023110926, 0.029204113275877068, 0.023821807266878228, 0.01810364847603653, 0.002504287640996543, 0.05772789341530629, 0.04203602132786598, 0.06721250340342522, 0.033084417560270855, 0.018694947640012418, 0.042000303244484324, 0.06827492639422417, 0.03059500489117844, 0.0313364231426801, 0.03771508318771209, 0.06389929833156721, 0.062143005430698395, 0.009846044388333601, 0.05640168654333268, 0.024526625339473997, 0.010672675611983453, 0.015580743318423629, 0.05873088352382183, 0.059390066723738394, 0.03670784205730472, 0.029021821450442076, 0.060405535091246874, 0.04568777126925332, 0.0410833038788821, 0.03747903781809977, 0.1076248548924923, 0.03329583889405642, 0.011572446125293416, 0.08308955109012978, 0.04137594585439988, 0.010683856172753232, 0.06537089829466172, 0.030110279829906564, 0.04729687974655202, 0.04120496181505067, 0.007741482362949422, 0.06711801740207843, 0.022656414890661836, 0.005088572440269802, 0.03426649680893336, 0.06216878976140704, 0.052944913639553955, 0.03458750494090574, 0.026284361823594997, 0.037358838732221296, 0.05552776397338935, 0.020504649728536606, 0.033822412602603436, 0.04827873009656157, 0.020849961288539425, 0.026062255259603262, 0.029178305196442773, 0.052101199448640854, 0.02195550348343594, 0.021668990375474095, 0.024601859606004188, 0.048047682137361596, 0.042343156811382086, 0.031239087294254984, 0.01746439384961767, 0.009132525800461215, 0.024049058822648864, 0.07038423392389502, 0.017306831232937317, 0.04120458862079041, 0.028868635384632007, 0.047624143971396346, 0.013102277115519558, 0.01673014092791293, 0.015423348639160395, 0.0797345686171736, 0.011831874659817134, 0.029275162677679743, 0.0944049706948655, 0.03290141327306628, 0.011547586298547685, 0.04253142653033137, 0.014310897261436497, 0.047589738853275776, 0.008301374685418392, 0.0782340969890356, 0.0653968183323741, 0.011490519807141806, 0.021222076678116406, 0.07272100674786738, 0.016278453736699054, 0.03178251241999013, 0.047756047786346505, 0.07857495227030345, 0.10413957333990506, 0.015857987638030733, 0.04830104372064982, 0.030026575750006095, 0.008371089069571878, 0.0696976650506258, 0.019017597826729928, 0.018506248747663837, 0.01967362583880978, 0.03004166976149593, 0.009353919902683368, 0.017892573195110475, 0.02215193258598447, 0.025478859332257082, 0.06371986653123583, 0.049963505406464846, 0.02495558500023825, 0.02196891133540443, 0.021190565511850373, 0.027406746953991905, 0.019702877483463714, 0.043890437177781544, 0.028593214627887522, 0.05592078502689089, 0.015503156231716275, 0.07148420704262597, 0.06516692388270583, 0.02376113605818578, 0.09599307512066194, 0.047623170273644586, 0.008340761098744614, 0.037090322069291554, 0.02775232823166464, 0.08072413051767008, 0.029763182026467154, 0.1091015710096274, 0.031564197170415094, 0.04705155880323478, 0.028640939388424158, 0.07844343861298901, 0.04777494498661586, 0.05222913722640701, 0.022320216055959463, 0.030654865250523602, 0.01673335548756378, 0.04235075640359095, 0.0034138506868787643, 0.1021653621324471, 0.04282355960458517, 0.037974934958453686, 0.03259226593321987, 0.06376642760421548, 0.012553328714732612, 0.04660375961767776, 0.026766406671543206, 0.07712309089090143, 0.029231770363237177, 0.03361337971208351, 0.027882727395210947, 0.023760611889883876, 0.0078935717465356, 0.026621815948081867, 0.018926655474518026, 0.06993241781102759, 0.04512928605877927, 0.10682007164827415, 0.030618210788816214, 0.02423761861531862, 0.047623967552291493, 0.022726276856181876, 0.09254106214003903, 0.08219736575015954, 0.05645552829706243, 0.0185415597100343, 0.03401617845520377, 0.017243898806295226, 0.033381507332835875, 0.01219791716097721, 0.07920058869889804, 0.045195612856852155, 0.04057643482727664, 0.01690332681339766, 0.036055030301213264, 0.011913100390561988, 0.08114168739744596, 0.04162888674597655, 0.03872725048235484, 0.012953092709981968, 0.05034744766141687, 0.0743691683081644, 0.07459777354129724, 0.07256324057068143, 0.01904206071048975, 0.02302225213497877, 0.04626164226127522, 0.028698292560875416, 0.0290137265276696, 0.0740851606907589, 0.038312699512711594, 0.052331399239067516, 0.0168104319766696, 0.0013728208494805066, 0.0501966228974717, 0.009906502706663949, 0.01419847079419664, 0.035284638604415317, 0.07263390999287367, 0.03689145702602608, 0.06514531254236187, 0.023340413812547922, 0.007387983429777835, 0.012682282598689198, 0.04753172750185643, 0.05230540116982801, 0.026578435508002127, 0.039064709695854356, 0.04068722941779664, 0.03963026524122272, 0.049219430690365176, 0.036771570066256185, 0.018682705171938454, 0.053362300885575156, 0.007080332259647548, 0.061273286385195594, 0.0126589121563094, 0.018641993070819547, 0.01706884186049657, 0.03611521635736738, 0.02232378175748246, 0.015147118729406168, 0.07391732505389623, 0.052881813275494745, 0.05101329068254147, 0.005990968884101936, 0.0676400890307767, 0.01996025938673743, 0.00793133391666093, 0.0404813686784889, 0.028705345932394266, 0.04767203497301255, 0.0443946022673377, 0.11705828298415456, 0.028991630034787313, 0.022885189757549336, 0.0502481813808637, 0.03454956804801311, 0.012484574457630515, 0.043479160139603276, 0.034276651085487435, 0.028611959157777683, 0.030356194491365125, 0.016391475618417774, 0.016490816537822996, 0.025620929298124144, 0.014548143638031823, 0.05050807386370642, 0.04084677674940654, 0.0505201823211142, 0.06143761399601187, 0.039324707351624966, 0.07183534212942634, 0.058428426539259296, 0.0635372931137681, 0.06253070676965372, 0.014607827578272139, 0.03720056026109627, 0.017393237578549554, 0.034720691187041144, 0.018928845446290712, 0.03157802910677024, 0.06749066883432013, 0.02826297502698643, 0.05611986041601215, 0.020334619030888592, 0.06634187512099743, 0.007873819592142743, 0.06775107700377703, 0.04800215922296047, 0.03826864901930094, 0.02033374541705208, 0.013229402347600885, 0.06305836274155549, 0.02423631922075791, 0.10423308903617517, 0.08615979991321053, 0.1367484735591071, 0.0774926549888083, 0.06887625091310058, 0.09120891469397716, 0.0632928983707513, 0.1596548929810524, 0.10722016982202019, 0.13285214906292303, 0.09793949353375606, 0.08047284185886383, 0.11237894264715058, 0.19812496512063912, 0.1619842629879713, 0.09747424242751938, 0.11117791530809232, 0.20092807470687798, 0.1289866707686867, 0.10630583709904126, 0.17591202205845288, 0.12579402779894217, 0.08409894656922136, 0.13827648013830185, 0.09577124166701521, 0.1376881767064333, 0.16359452158212662, 0.16797487224851335, 0.21241688036492892, 0.12284085340797901, 0.1126948617664831, 0.1043284707037466, 0.1264453807047435, 0.16147046270115034, 0.1091315961842026, 0.1493826734700373, 0.1330277267843485, 0.08856960346124002, 0.12863962724804878, 0.07291346642055682, 0.14866010152867862, 0.1082471664994955, 0.12885852264506475, 0.18876191468111106, 0.1658754034766129, 0.09811699829463448, 0.09908974609736886, 0.13936761873109, 0.16623714406575474, 0.13175159240407602, 0.10582892876118422, 0.14504565404994146, 0.1205323144261326, 0.08593567301120077, 0.09654305489467722, 0.14972223953476974, 0.07543198484927416, 0.13336274666445597, 0.14343102569026606, 0.11330717855266162, 0.1279641320662839, 0.06473830009677581, 0.10330210506383862, 0.13546535026814255, 0.1265089594359909, 0.18257311891232217, 0.08474723249673843, 0.18152685862566742, 0.149627027500953, 0.23093855221356663, 0.10460116035704102, 0.26065903742398533, 0.1357290018349886, 0.08039474926356759, 0.06747549000595297, 0.15238772864852632, 0.10868283347891909, 0.1682207461978708, 0.20269743619220598, 0.1529266754431384, 0.1407701913267374, 0.1128348842529314, 0.14781375122921808, 0.137768650959645, 0.1725655144878796, 0.11783582983272416, 0.13522919294025215, 0.1692194411797183, 0.09116977679410151, 0.11828185804188251, 0.3304859362542629, 0.15625399404338428, 0.15623091028204986, 0.11205517966300249, 0.09400488609181983, 0.13810152666909353, 0.09935232557888542, 0.2241022169057812, 0.17700530482189997, 0.09899338733937059, 0.09284729177930526, 0.16900317849857466, 0.1449863908014127, 0.08122034996215786, 0.09808991117669003, 0.216232174209186, 0.17317052345190728, 0.13692474338625157, 0.17321989365986415, 0.09508045230593, 0.1521044402782406, 0.12503679628883088, 0.16268402258200304, 0.13725472853652068, 0.16117314222667897, 0.0960503231201853, 0.1371638455561229, 0.10635014543575899, 0.07877241953143052, 0.11614884249866009, 0.14923726341554097, 0.165750349472676, 0.1335093237991844, 0.08527122437953949, 0.11818167913172926, 0.14966357339705738, 0.0851558055728674, 0.23921249966536248, 0.18872186754431042, 0.04193376610055566, 0.13368336803146771, 0.09814985296023743, 0.13321260043552943, 0.09184776219938483, 0.20194709859788418, 0.04865159187465906, 0.11484613668705736, 0.16311624938888208, 0.12165702693164349, 0.087454600791846, 0.08568990762744631, 0.11089738178998232, 0.15263761952519417, 0.1170563559447016, 0.12136579970163958, 0.05789102001913956, 0.08929677587002516, 0.07743020941104208, 0.09553934553904192, 0.07620018827063696, 0.1879029164889029, 0.1331717933395079, 0.1385539738195283, 0.17560111731290817, 0.13213657960295677, 0.09796569177082606, 0.14781335767890724, 0.10359994801027433, 0.10027796948062521, 0.10647792036512069, 0.15083562050546917, 0.09387114683964423, 0.06467309966683388, 0.07823679077305964, 0.1975133065134287, 0.15339939721993037, 0.059937603771686554, 0.1385215941284384, 0.1207523090498788, 0.2137595654598304, 0.11863616188721997, 0.1548923642507621, 0.11724485297288213, 0.08672292291053704, 0.2098087410309485, 0.18337503873876163], [0.05788816338671105, 0.01765556091309658, 0.05251624574884772, 0.012533490895293653, 0.0825301803914564, 0.018765678130356327, 0.0014154901000438258, 0.01886098176640059, 0.03012768764580999, 0.024472125406776155, 0.02989176780517612, 0.0532006229540067, 0.033560952703867636, 0.03392347360828093, 0.011726441344113221, 0.027453016256913543, 0.042646390718540976, 0.06849076838365623, 0.011186993281756128, 0.034691863626773865, 0.04275504792375224, 0.052779015220169506, 0.057495780156127045, 0.019229729925947528, 0.0633513880893588, 0.01172998160057302, 0.057377077239964686, 0.03191454515659383, 0.0038888856319577564, 0.016108611332518712, 0.03662489454395004, 0.02871659943567855, 0.0334707584365138, 0.02538619010842272, 0.03012709392766867, 0.041889216883906295, 0.01994715178651469, 0.04792507764484201, 0.029932747927627394, 0.05692049102591617, 0.016392016750095145, 0.0375888688888933, 0.04142966547182628, 0.03215981520978468, 0.02215217855492873, 0.026596886571496725, 0.024934747189815556, 0.016422564396634698, 0.059677290597132275, 0.08184476502771888, 0.028273168319304074, 0.06283671249236379, 0.05225361537720476, 0.047225389296987226, 0.03074816720826285, 0.08148315336023058, 0.02287706938971366, 0.02898894642878856, 0.027311268595180342, 0.01394772665974285, 0.02000865080792989, 0.08388868213764258, 0.037545127128916125, 0.02138653490692377, 0.012368868121744266, 0.024328642391732762, 0.09091105817684106, 0.027970151543351154, 0.028764419191117798, 0.04128919175959059, 0.02008838376163372, 0.032739918545952866, 0.029151119690920626, 0.04255830669509513, 0.08228745484458548, 0.02931250924510615, 0.030929369984992912, 0.05646696839747684, 0.031996776815503836, 0.0670446338398116, 0.012010533778396035, 0.022622491532404507, 0.017237245770437375, 0.018808773585728238, 0.026765373601977314, 0.06774840357580356, 0.022920924804306457, 0.03295079365904842, 0.03231589862012437, 0.046586860703038316, 0.017648263268971016, 0.014262682259348887, 0.06610169408044644, 0.062316405054713996, 0.03852290626881378, 0.0494650128696646, 0.024330839148855636, 0.04960503874878798, 0.0028172504680696875, 0.011646232567727566, 0.01323557531993304, 0.021226594025003057, 0.02579483443072864, 0.05054776476962226, 0.04806064894156797, 0.03603068446474416, 0.056946275356624804, 0.01371189418049263, 0.02888589392283133, 0.006842018886735397, 0.014844637996117984, 0.03199837476547275, 0.05223551206290722, 0.04760277351098401, 0.006143693546099322, 0.012868754199839063, 0.007862278559644307, 0.012272119206110281, 0.012540421282340373, 0.014792195720864194, 0.030326294845768383, 0.027568009282861437, 0.036175490623073916, 0.09543881379067898, 0.04982198675030044, 0.023627678398042917, 0.07654041929968766, 0.0513448669974293, 0.02017791985001947, 0.05420935007610491, 0.038715267553925514, 0.10637526480214936, 0.050778690592518876, 0.0014460195109547514, 0.03613591506811125, 0.05733059759118727, 0.014597683479743344, 0.03020747997132795, 0.047128389323396344, 0.045634869286524396, 0.04075551378939833, 0.022958663225706135, 0.04660118118460689, 0.03536676848307252, 0.012078048860920327, 0.022010953365159885, 0.03762655133115394, 0.08399399077253682, 0.002457444763941956, 0.019160432840830514, 0.04350343472989542, 0.025525540845202546, 0.049144432214753966, 0.041328865702130964, 0.027543926378712058, 0.0671382106042334, 0.036417228901492696, 0.013656974404252, 0.02016971296896892, 0.052886603732726405, 0.026804487753127302, 0.04814906883984804, 0.019579546958474175, 0.04771168177415218, 0.04554539765896542, 0.03538491250947118, 0.05401653417253068, 0.07676171671066966, 0.07500676052378756, 0.07208434412521975, 0.035926285066774914, 0.0064814144196654, 0.053118316656244655, 0.04282643659306424, 0.026557473864938532, 0.0728353059717587, 0.026516887292798077, 0.023967368295416236, 0.0468825628714902, 0.02300272898615471, 0.035082028047846894, 0.05185827712661453, 0.03351831017062068, 0.048351299416806014, 0.057246893511286805, 0.030584820080548525, 0.012900591062914048, 0.027436979081747786, 0.030170068943074772, 0.02399077605722206, 0.01312475189167474, 0.0381673098142658, 0.04156290600076318, 0.09012901264109782, 0.017822047961609702, 0.027565318891512494, 0.04229215472670538, 0.03446762476648603, 0.06497329712978431, 0.03244367354948606, 0.02477709636358278, 0.02093157039156982, 0.04283410403877497, 0.024706357391551137, 0.020195850137887255, 0.017711178732237647, 0.05522204662806221, 0.08205403201282024, 0.02156046887726656, 0.04791651792558176, 0.05028680359412517, 0.08536512684077024, 0.06121149220104728, 0.034014743353639326, 0.023978981422260404, 0.08098831812718085, 0.006481897027697414, 0.049796914881361384, 0.0818109197009887, 0.03322929496477757, 0.040261526725121906, 0.029522583686879704, 0.06993990205228329, 0.05712517789964165, 0.0919652505378638, 0.03517676849982568, 0.04731199411409242, 0.03626065694593957, 0.03829405676307423, 0.08999762790543692, 0.03509560553357005, 0.03594523994252086, 0.03850240433322532, 0.026581375260970423, 0.02513599389099649, 0.04676437224926693, 0.012240657233633101, 0.09542073761778218, 0.034148089055504115, 0.038981161679008176, 0.022225590954933847, 0.015194958840895976, 0.0222674837069852, 0.04797537744577442, 0.01921181151244257, 0.01287866335561765, 0.03721771362636771, 0.05789102001913956, 0.03855645304013576, 0.027168082439207604, 0.07139615355325596, 0.03767266457102128, 0.051288823397564035, 0.010373710538260639, 0.0181743263799165, 0.09064596811575548, 0.012792425795591303, 0.035633639698582034, 0.01629863167181611, 0.025441436429641077, 0.03569946777341621, 0.12239722721278667, 0.017220991464065652, 0.05059746406706316, 0.06672477243202073, 0.03935996063851884, 0.02609966289518135, 0.014047867402301302, 0.03166589939168521, 0.007947369395489139, 0.011049131929342235, 0.014679577567481568, 0.012124916122827147, 0.02930774592927524, 0.030513838532247713, 0.019357850908168724, 0.005101877239732338, 0.034369983577302525, 0.02817522857471236, 0.03808026734207358, 0.049233629035630395, 0.0399179878378553, 0.05911478506667273, 0.009909274522215128, 0.03159907726304872, 0.04005561848836286, 0.00829253761496927, 0.08730492275208235, 0.020568783162161708, 0.06526311300694942, 0.031239467273865427, 0.04735188179516366, 0.06682353320398501, 0.07942634408495255, 0.0428916200596307, 0.04295038119224565, 0.00934173256557967, 0.08675300915326391, 0.033593318824257166, 0.08550616034439631, 0.010507588041946292, 0.03440600360876747, 0.04670296822275434, 0.014981686802847045, 0.0348773479594716, 0.04386332631111145, 0.02532887425539749, 0.01895627861709467, 0.053204066519226344, 0.04534962673538497, 0.025407786181728755, 0.06730323710611888, 0.041255702663745196, 0.03126310743391514, 0.031556380447000265, 0.06360955030790397, 0.0938319478716169, 0.01347966811486653, 0.020732189661690166, 0.023921389066215073, 0.024347816095022217, 0.023032827103244405, 0.023124598964516605, 0.072399489714631, 0.0381486806353288, 0.04911866484742079, 0.036444339768162796, 0.03335357204611812, 0.05765342419700963, 0.019593494245782495, 0.038232293113001754, 0.023896566558895365, 0.03807607738833342, 0.0069740774924866855, 0.06718247822885003, 0.022323479809399163, 0.038144500859613927, 0.030809377852295126, 0.013900587135659797, 0.01874626354713525, 0.0676348168136818, 0.013191178773662873, 0.011889564555271395, 0.0687068003628935, 0.07872193652604308, 0.040083954110741615, 0.016119674845997776, 0.054680847097188234, 0.005849457437372101, 0.010044046843956624, 0.04006304844681706, 0.02426169643045536, 0.13140940719417163, 0.08074557222425938, 0.13497955990689142, 0.0867674687345113, 0.10017077451837914, 0.10964340836341892, 0.10154223628342152, 0.10540873916553599, 0.2153192324829953, 0.10370527021586895, 0.0843694649104561, 0.07044359895267657, 0.09178516055856432, 0.07225762839828219, 0.09709213221711771, 0.1267134834613119, 0.1288727990218571, 0.14550036750733852, 0.08763261445398841, 0.13586579449474812, 0.17082124522754125, 0.13918574420469149, 0.1500312036701611, 0.076575289214296, 0.14096717004265102, 0.09794615674763918, 0.17095594799944333, 0.10438734718731471, 0.09182767077748265, 0.08435385181967701, 0.19951767181711538, 0.18133548460900784, 0.12470556263412748, 0.10715311020612717, 0.11408606890056815, 0.18813099925007137, 0.13410780525633267, 0.18931022525898047, 0.123562380405409, 0.1396157182753086, 0.10837309581360646, 0.14756464745317185, 0.13180378531771048, 0.16000186864818844, 0.1295520532876253, 0.12811262266976492, 0.1043033649080566, 0.10557605233043432, 0.12410899464573179, 0.11596804005759102, 0.14012886716851167, 0.14523735376341002, 0.14671392738819122, 0.16391511580773763, 0.09330736566334963, 0.1018449714673417, 0.12181592626231057, 0.08850647256310497, 0.12588028317051275, 0.20351811072656087, 0.0840082128665277, 0.22828455748302595, 0.09473654361707823, 0.13509947061538696, 0.09883109533361026, 0.09475730000329868, 0.11868131160736084, 0.1439777213547911, 0.08284107835165092, 0.07397858998072998, 0.15321676273431095, 0.15713442037148134, 0.17230799687760218, 0.07666904239782266, 0.16530411770301207, 0.2031035665422678, 0.18286494325314248, 0.10080522511686597, 0.11683816622410502, 0.17671848806951726, 0.10119270932461534, 0.07671934219875506, 0.17932862229645252, 0.09730925663773503, 0.16827482543885708, 0.15827555342444352, 0.07771998457610607, 0.1160829703190497, 0.1446804665029049, 0.09573065170219966, 0.09418068772980145, 0.14288420788943768, 0.10411555998559509, 0.1218734931732927, 0.11395447381905147, 0.10462824747498546, 0.0778307689886008, 0.10545307464365448, 0.06677636144948856, 0.06422426232269832, 0.04695472167804837, 0.14060861856809684, 0.15793776512145996, 0.10852200710879904, 0.08856920312557902, 0.16551282150404795, 0.14564196419503006, 0.11425503769091197, 0.15365392927612576, 0.09260994701513223, 0.09559376404753753, 0.1804153232702187, 0.1464347509401185, 0.09249771053769759, 0.10587811576468603, 0.07470374714050974, 0.11974024692816393, 0.1444364653101989, 0.07902387103864125, 0.1390269805810281, 0.14927978041980947, 0.17499134503304958, 0.16593727229961328, 0.18482334459466593, 0.14339974522590637, 0.08499663482819285, 0.10741499079657452, 0.16315151963915142, 0.10524632502347231, 0.1244408796940531, 0.12258987687528133, 0.12931387392537935, 0.1680021086441619, 0.08369583569999252, 0.12399943838162081, 0.16721166963023798, 0.12313768533723694, 0.09277785729084696, 0.16398949681648187, 0.1561876061771597, 0.198210867654, 0.06914732565305062, 0.13140648949359143, 0.10775752884468862, 0.1788631472736597, 0.12406027583139283, 0.05968197248876095, 0.19822500832378864, 0.10072633185024772, 0.13071689435413905, 0.11850076700959887, 0.13062477644000733, 0.1548626444169453, 0.11250697541981936, 0.11720559293670313, 0.1184383417878832, 0.1376813913562468, 0.10344775939094168, 0.09592987636902503, 0.1064348401767867, 0.10606944906924452, 0.14443048063133443, 0.1082720212372286, 0.10050860353346382, 0.11415844144565718, 0.12610878662339278, 0.14184124528297357, 0.15409401351852076, 0.21074720924454077, 0.17237613536417484, 0.09032478356467825, 0.11043343347098146, 0.11889726216239588, 0.09086250221090657, 0.11210902141673224, 0.18345088538314613], [0.00838014920840838, 0.02399736632859068, 0.06235305951642139, 0.014275067219776767, 0.046913307293185165, 0.019329276102195894, 0.03624836528407676, 0.052377478552183936, 0.004773785202165267, 0.04708601141880665, 0.015154163619237286, 0.05380573709096227, 0.07889917665826422, 0.03853438708132931, 0.01921565710966076, 0.034198789192097526, 0.12669813499919005, 0.009830270145487572, 0.05322920963434236, 0.01180924297243889, 0.020739083577479635, 0.022904799419588277, 0.03257677497874413, 0.04212138781856213, 0.10926498259816851, 0.04624993074685335, 0.024155298746856194, 0.013014978496357799, 0.03219793869980744, 0.0533407404353576, 0.03212395463404911, 0.03236430870102985, 0.016808538863967572, 0.03287845504071031, 0.013743702205829322, 0.02723023115790316, 0.02899319745068039, 0.04455840740618961, 0.05535394705033728, 0.036278471882854185, 0.013986901030875742, 0.026529474117394005, 0.014973417157307267, 0.032547095857028446, 0.013764309314345675, 0.004116851769919906, 0.024969362653791904, 0.004684942915836083, 0.031106742431542704, 0.025791373902133534, 0.06096245627850294, 0.035769967561853785, 0.14302739234907286, 0.0093783285036417, 0.024496411871431128, 0.026068309488307153, 0.02143160150652485, 0.03694318853584783, 0.02310969663916954, 0.016163849172049334, 0.026502500654065182, 0.022978698668469275, 0.014683092378878167, 0.00779561758307474, 0.04528888767319066, 0.045661172696522305, 0.0186752514647586, 0.02946129161864519, 0.04951977403834462, 0.0657286083857928, 0.029861600138247013, 0.03518794057890773, 0.014845260551997592, 0.04505649621465376, 0.034943220139081986, 0.08135756331362895, 0.05074974089594824, 0.033499962583716424, 0.016408262574779134, 0.009341191433902298, 0.03565885066719992, 0.02202015769268785, 0.025712886060188924, 0.038038449228874276, 0.060108479245432785, 0.05317042136032667, 0.062006518111697266, 0.06409315578639507, 0.04383505175688437, 0.02174227555016322, 0.08008475375494786, 0.011114610558641809, 0.04207742214202881, 0.03945000223549349, 0.061788667658610005, 0.03147042023816279, 0.04116213268467358, 0.05185965455270239, 0.0294472798705101, 0.003145742417213374, 0.06959608835833413, 0.007289553443635148, 0.05897485078977687, 0.0365881688360657, 0.010738356105451072, 0.022904292214661837, 0.02020665580805923, 0.03308484164465751, 0.03160793553771717, 0.008838227351329156, 0.039298275019973516, 0.030233508574643304, 0.0031405030666584416, 0.04835292790085077, 0.032405852007546594, 0.023553258373535106, 0.01956158104751791, 0.0467879818752408, 0.031484672866229496, 0.014832546502085668, 0.04842372624469655, 0.047364872348095687, 0.022827621150229658, 0.041260510084352324, 0.02494536287018231, 0.025956551378060664, 0.07161738989608628, 0.047340865779135904, 0.03631763013878039, 0.07245593025748219, 0.05009533797523805, 0.0746941255139453, 0.03251421405002475, 0.06365182303956576, 0.008047819719649851, 0.035971424608890495, 0.02638941940053233, 0.02484984040659453, 0.03403179833133306, 0.03201176565406578, 0.02840705176017114, 0.03538060381210276, 0.024906794939722334, 0.028780938126146793, 0.03415853510211621, 0.05513212038204074, 0.03743762004056147, 0.05635340538408075, 0.046563379998717985, 0.049370248668960164, 0.048153991611408334, 0.020944337027945688, 0.020637612058115856, 0.02382010075130633, 0.020815456086503606, 0.0267849086251642, 0.024080245988443494, 0.03507096114169274, 0.039301996784550805, 0.03543352275820715, 0.06852578079061848, 0.025044693611562252, 0.02027824634153928, 0.017855316533574035, 0.046578029569770606, 0.08373573355908905, 0.039977939799427986, 0.019094139969508563, 0.02234473661519587, 0.08591370204729692, 0.03416303718196494, 0.019415528081091385, 0.016677396704575846, 0.00201602274734926, 0.021386248225878392, 0.02277349101911698, 0.03261476615443826, 0.025062055626351918, 0.008902795895534967, 0.028567664391760315, 0.022085575253835747, 0.03861087494130645, 0.03556689899414778, 0.02035754164015608, 0.01163963635917753, 0.047894618207854886, 0.020601458015984724, 0.04431910506848778, 0.023402323347649405, 0.02596384902218623, 0.025079427819166864, 0.0335765861506973, 0.019214283076248, 0.0417040175359164, 0.08961717332048075, 0.012340697892276304, 0.036240233041878255, 0.016507796876664673, 0.04801860012646232, 0.03846800260777984, 0.06131898571870156, 0.0312978687829205, 0.06540919481111424, 0.06732494344136544, 0.012176431349611707, 0.02874436169596655, 0.01820535578631929, 0.03698935266584158, 0.027818712705214108, 0.048107321972825696, 0.04108373474861894, 0.031754119122134786, 0.045740045607089996, 0.06106874200382403, 0.0028247646072746386, 0.022879929414817264, 0.011725281049231333, 0.0442579453145819, 0.020787230726065378, 0.06119190968040909, 0.02892711153253913, 0.05551078363454767, 0.04718925052189401, 0.017122758253078376, 0.05435654467770031, 0.06737402187926428, 0.0027669190728504744, 0.02298926854772227, 0.020824338109897714, 0.04372500016220978, 0.03166850496615682, 0.04239721230364271, 0.030944104372922863, 0.012637167653468038, 0.054258170670696666, 0.030197824418012584, 0.013065461501745241, 0.04929172520392707, 0.024873102283371345, 0.027984163291486244, 0.010976828934092606, 0.020964386041409204, 0.030971164349466562, 0.040344684584332366, 0.04352494089731148, 0.14748639879482134, 0.02936644938641361, 0.04864279127546719, 0.053420970415962596, 0.07640662576471056, 0.025834823892052685, 0.05328828289306589, 0.026979023923299143, 0.03204145495380674, 0.01891892696065562, 0.051909615086125474, 0.06696941144764423, 0.06941872608980962, 0.07947480505598442, 0.008870878456426519, 0.0357868257643921, 0.07184969314507075, 0.03196063804041062, 0.07388687240225927, 0.04343802395409771, 0.02889995656109282, 0.04171015488516007, 0.04118867018925292, 0.07134496487144913, 0.08279773353465966, 0.02488568571529218, 0.017035357853663818, 0.12948635752711976, 0.034975080750882626, 0.05658353053565536, 0.03755663169015731, 0.06185063826186316, 0.035909148664878945, 0.037878477812877724, 0.02762998327878969, 0.01464654309009867, 0.027501953898796012, 0.047648028404052765, 0.04284686728247574, 0.023403074825182557, 0.07043110712298326, 0.01616559300704726, 0.03502131273437824, 0.05718039707945926, 0.011273867816531231, 0.016724833087729554, 0.02002535803642656, 0.04422725856836353, 0.0585268209023135, 0.03530705740143146, 0.03318529196881822, 0.016738507264692868, 0.03447095976610269, 0.06636535243264266, 0.015060167859441467, 0.020945276798946515, 0.04950263085109847, 0.06270230149051972, 0.09699722552405936, 0.02866714441084436, 0.13755837295736584, 0.048630889771240096, 0.05930402848337378, 0.13214857610208647, 0.033907321082162004, 0.03827613326055663, 0.09305013982313019, 0.08929236539240394, 0.01071689573914877, 0.026595526108784334, 0.021078123777572597, 0.05251648323610425, 0.03315972816199064, 0.021046643145382404, 0.02526896639860102, 0.009557286177628806, 0.015707176444785934, 0.11128916790974991, 0.0288596040835338, 0.04529088256614549, 0.0688328111012067, 0.04805600097669022, 0.0640005628977503, 0.00477937505846577, 0.055662887437003, 0.041776295086102824, 0.035243234397577386, 0.031748056411743164, 0.0447384431026876, 0.025251561975372688, 0.08443581206457955, 0.05778674954282386, 0.030015922750213316, 0.05794776590274913, 0.018187637540644834, 0.039812285652650256, 0.06814441696873733, 0.030349653413785354, 0.002310260340371834, 0.027811985030504208, 0.012446551899691778, 0.04199387412518263, 0.012430905730330517, 0.035009614790656736, 0.048634143346654515, 0.06240540849311011, 0.03875171845512731, 0.19447458242731436, 0.08003336151263543, 0.10766083081918103, 0.11006592533418111, 0.11612140254250594, 0.13333464174398355, 0.12414697903607573, 0.16842457811747277, 0.13408096241099493, 0.1564709624009473, 0.10341559004570756, 0.1070817011807646, 0.09379863858755146, 0.14412163863224642, 0.08492483225251947, 0.162581523082086, 0.17422265985182353, 0.1124925429799727, 0.19275161916656153, 0.09092899185738393, 0.17898186376052244, 0.08525669015944004, 0.11392885233674731, 0.139674750821931, 0.22624374127813748, 0.16613042407802173, 0.13010725778128418, 0.1143278716398137, 0.05666174187457987, 0.18056622945836612, 0.1313682065478393, 0.24422456643411092, 0.12592972123197146, 0.13386953089918407, 0.07485634288085358, 0.10874287704271929, 0.14605561271309853, 0.1261512900569609, 0.09929704533091613, 0.09010430039571864, 0.10290398821234703, 0.16165857974972042, 0.14449077525309154, 0.10583707118140799, 0.1355578074497836, 0.23167877963611058, 0.08457830441849572, 0.0824569393215435, 0.18625257004584583, 0.21198177656957082, 0.1061988321266004, 0.14667561730103834, 0.2320843535874571, 0.07689981894301516, 0.14699583154703888, 0.10435903192098651, 0.11884916760027409, 0.12760193007332937, 0.10618217409189258, 0.12948130922658102, 0.08550426723169428, 0.10150876415095159, 0.07922135865581886, 0.04413202278582113, 0.12348801296736513, 0.09885485084461314, 0.11046136197234903, 0.1261335260101727, 0.12384307677192347, 0.2216650683965002, 0.11749828580234732, 0.2701004722288677, 0.1334450122501169, 0.14490867140037672, 0.15505127715212957, 0.12764812473739895, 0.19597765962992394, 0.22444259721253598, 0.08592947798648051, 0.09776301336075578, 0.18410058266350202, 0.12477556030665125, 0.12064409628510475, 0.16044823612485612, 0.14047490645732197, 0.1513753001179014, 0.14658047312072345, 0.21146974047379835, 0.09315514990261622, 0.06143772256161485, 0.19835162295826844, 0.11470778339675494, 0.18730074380125317, 0.12904130640838826, 0.13234007225504943, 0.16502579620906285, 0.21188205906323024, 0.10929062443652324, 0.09108564523713929, 0.09772738348692656, 0.12152757602078573, 0.11243082343467645, 0.16686085345489637, 0.1389764840049403, 0.13610964640974998, 0.06341496682060616, 0.13692364415952138, 0.19728231962238038, 0.10906927274273974, 0.13103493728807994, 0.07935306230293852, 0.11952402495912143, 0.1953842807561159, 0.088520409672388, 0.1369777505419084, 0.10399087239056826, 0.08897371177694627, 0.12153596271361623, 0.10922656394541264, 0.15562831690268858, 0.09314009321055242, 0.1714488629783903, 0.18155953687216553, 0.13859597513718264, 0.15634749616895402, 0.11629079202456133, 0.21111996924238546, 0.12344998786492006, 0.08990371187350579, 0.2526460002575602, 0.14649899463568414, 0.19194363323705538, 0.29148534472499577, 0.1156926905470235, 0.10893959791532584, 0.11557571110980851, 0.11763739905187062, 0.15492517820426396, 0.08025254867970943, 0.08986970369837113, 0.1360703320907695, 0.14279154714729103, 0.08831479999103717, 0.16622049281639711, 0.09773106793207781, 0.11367525665887765, 0.12873874764357293, 0.1271991923983608, 0.3121061867901257, 0.21166633921010153, 0.21507692762783595, 0.2051038063530411, 0.10895774872707469, 0.20146919281354972, 0.1171635916190488, 0.12955227041883127, 0.14999906825167791, 0.11714955951486315, 0.12509933007614954, 0.1723721862903663, 0.1839168896632535, 0.15538184584251472, 0.09772215876728296, 0.22707749796765192, 0.12752494349011353, 0.14821097919983522, 0.10173457381980759, 0.0716362599549549, 0.060238629047359736, 0.18186228562678608, 0.07623723628265516, 0.07107240413980824, 0.08775817735918931, 0.10206746309995651, 0.12430951531444277, 0.10647158963339669], [0.04459118404026542, 0.06717455293983221, 0.012274304937039102, 0.04030038981831499, 0.030107463909579173, 0.07289621127503258, 0.053276262645210536, 0.04702077706211379, 0.02469085286637502, 0.05409306613728404, 0.03993198262261493, 0.030318830960563252, 0.08155600766518287, 0.06333878769406251, 0.012222628558187612, 0.02467428982656981, 0.04427038625414882, 0.03234196115019066, 0.030052499180393558, 0.06095255645258086, 0.015727091447583268, 0.058558650980038304, 0.03991739072703889, 0.04190369003585406, 0.10291705001145601, 0.007555908972530493, 0.04831905882539494, 0.030246027545737367, 0.045915972774050066, 0.010316416737623513, 0.07192180106150252, 0.04026471244703446, 0.018535915995016694, 0.04041476707373347, 0.017176622059196234, 0.050411813493285856, 0.05023795585813267, 0.05285039371145623, 0.039530710583286624, 0.08431657989110265, 0.05884865006165845, 0.02552512863517872, 0.027710053803665296, 0.01650730154610106, 0.009863618445316595, 0.04343633779457637, 0.02972434607467481, 0.09826873908085482, 0.043183498683252504, 0.032134634775242636, 0.021013050572946668, 0.01511514955200255, 0.014873658938865577, 0.01393322297371924, 0.05203469283878803, 0.03902283051450338, 0.0801362409921629, 0.05949560606053897, 0.06519762080694948, 0.017366070732740418, 0.031349844565348964, 0.04958950708221112, 0.018070982103901248, 0.03824580953057323, 0.04012766533664294, 0.01807362330146134, 0.033645325140761476, 0.05054264522290655, 0.06643372162112168, 0.013802640605717897, 0.038320482309375486, 0.002484625392493659, 0.01657775044441223, 0.04060365425954972, 0.04371736664324999, 0.041989433113485575, 0.01105502839865429, 0.03254891772355352, 0.07344311050006322, 0.04200454408835087, 0.01983794496793832, 0.032198216899165084, 0.03635794868958848, 0.03269344228985054, 0.032101179606148174, 0.03132970564599548, 0.01911944423669151, 0.03540438646450639, 0.04490199379090752, 0.028079343094889606, 0.03310777612828782, 0.039079634073589525, 0.017618965823203325, 0.058169775775500705, 0.055369326046534946, 0.0379359734776829, 0.043382384082568545, 0.04050188418477774, 0.022239772336823598, 0.05388379575950759, 0.05080838328493493, 0.04072757511000548, 0.0506085377585675, 0.05404816068974989, 0.09691014912511621, 0.03607870099533882, 0.0402047503074365, 0.02595498226583004, 0.06330754794180393, 0.0551284223661891, 0.01505086853701089, 0.07163106237671205, 0.05909097527286836, 0.015656891910891448, 0.03725505340844393, 0.04847500313605581, 0.04085260197254164, 0.10903272006128516, 0.06567910247083221, 0.016924057754554918, 0.02545394013369722, 0.02714605549616473, 0.05423804532204356, 0.09771085437387228, 0.03575668523886374, 0.033312144090554545, 0.01850256939152522, 0.04509179021364876, 0.006347656083692397, 0.02236964224305536, 0.0031875266036617434, 0.027486405268843685, 0.02565563127531537, 0.01620064612611064, 0.043211335582392554, 0.027317826636135578, 0.06276892005865063, 0.07443152567637817, 0.047384624502488544, 0.11446071522576468, 0.013906057824247649, 0.05425612149494035, 0.02982359878452761, 0.03588188173515456, 0.00557033612026966, 0.016794902006430284, 0.05943120630191905, 0.016982584792588438, 0.04103418472888214, 0.025216420646756887, 0.0609662900013583, 0.051666869183204005, 0.02967412430526955, 0.022800449215407883, 0.05889465473592281, 0.030190896575472186, 0.051338064683867354, 0.06010022825960602, 0.011325175241966332, 0.061176554432937076, 0.07557122023510081, 0.014344878295170409, 0.018609830510935614, 0.024802180106884668, 0.083458436653018, 0.05984765038426433, 0.052308091561176946, 0.0024594983925843345, 0.03024605129446302, 0.010145079011895826, 0.06958525215408631, 0.03855280591441052, 0.002607748540218121, 0.025752200379169414, 0.07022382146013634, 0.03524857786084924, 0.03673416243067809, 0.04801197083933013, 0.04273411172575184, 0.026428655687985674, 0.0315604279083865, 0.06522533217711107, 0.0829871805118663, 0.030179731281740323, 0.027100993985576288, 0.06698360640023436, 0.05220151406579784, 0.02386451426095196, 0.07609155481415135, 0.026093834279371158, 0.038193776072668176, 0.02583749053467597, 0.04290702280455402, 0.01839416324427085, 0.050593535349305184, 0.005903503175691834, 0.018255285785666535, 0.0611055525285857, 0.04114275033186589, 0.025314317982909933, 0.03506160753646067, 0.04292212360139404, 0.024312423708449517, 0.06948914445404496, 0.07879088925463812, 0.02210991091227957, 0.03728646279445716, 0.03532520482050521, 0.041789224570883174, 0.025632725629423345, 0.0218380965691592, 0.027867221173697283, 0.04139795753040484, 0.03028985412259187, 0.031237967711474215, 0.0239915343201054, 0.043688193030123196, 0.004933719298735793, 0.07060752622783184, 0.023248458746820688, 0.04334459986005511, 0.03105855287451829, 0.02400192947659109, 0.05622408339487655, 0.00998863173715238, 0.0023237494045003715, 0.03925484538610492, 0.039761751757136414, 0.007589799252205661, 0.012379152168120657, 0.0627017111650535, 0.11282455016459737, 0.0368506329666291, 0.02798282657749951, 0.011336925772151776, 0.009249843657016754, 0.022993348239521896, 0.035766618991536756, 0.03049979285736169, 0.04780839676303523, 0.012201091856695712, 0.050150974454092126, 0.023282202293298075, 0.046647548875106234, 0.05506271303498319, 0.0625490407858576, 0.03734070149117282, 0.04418848368472286, 0.034290211607835124, 0.0591025510802865, 0.019962276332080364, 0.0165132811359529, 0.04709246089415891, 0.057172526073242934, 0.033961349433021884, 0.07195867943976607, 0.024346180825627277, 0.04607303327481661, 0.024833257010738765, 0.028006648245666708, 0.008731971311915134, 0.0676898460036942, 0.013308894421373094, 0.0512835206463933, 0.050331254423196824, 0.052744552426572354, 0.0222502149907606, 0.051249671926988025, 0.03720555088615843, 0.042803569962935786, 0.04949112289718219, 0.04684959285493408, 0.024610144518581883, 0.06807123696697609, 0.02109720927130963, 0.045990180756364546, 0.03234305019889559, 0.051461361282105954, 0.03310291442487921, 0.015594180008130414, 0.012793843085611505, 0.013283786929345556, 0.03915211518428155, 0.017344968293660452, 0.021950633298339586, 0.05767694900610617, 0.017540790107367293, 0.04340734738590462, 0.03257838649941342, 0.07228122784623078, 0.06802511015640837, 0.042106768781585355, 0.07260589328195367, 0.07985883552048888, 0.006269541860092431, 0.012523026188968547, 0.02251745091884264, 0.027846809143998792, 0.03691242375810232, 0.050383284488426786, 0.07504479919693299, 0.019218617218679616, 0.04016687109002045, 0.050376733232821734, 0.004925705376081169, 0.011915336163448436, 0.035604998735444884, 0.04815219688628401, 0.0057501839473843575, 0.03341270637299333, 0.010963934224231966, 0.08224199299833604, 0.028538643449012722, 0.07256403445665326, 0.07998897853706564, 0.03539051381605012, 0.01052783043789012, 0.010589663637802005, 0.03272112991128649, 0.016494434825809937, 0.06580841767468623, 0.09526913253856556, 0.03831382588084255, 0.01789113470087094, 0.01539894173453961, 0.06870059855282307, 0.03670153507430639, 0.03434450798002737, 0.04374744949330177, 0.026134670213130966, 0.027982711226546338, 0.02908091845789126, 0.01840071110720081, 0.01928879300664578, 0.010779717055681561, 0.05783242852027927, 0.04175386271838631, 0.02133666767206575, 0.03708476486748882, 0.05618485389277339, 0.04000984112332974, 0.019449280109256506, 0.009836884165581847, 0.03502902428486517, 0.077642808003085, 0.03433407211144056, 0.046107044842626364, 0.02884771615000708, 0.04395817193601813, 0.02934636814253671, 0.0703919285110065, 0.026841600225972276, 0.1442800901298012, 0.15295225621334144, 0.06112971516059978, 0.12316699805004255, 0.08040943954672132, 0.18711987350668224, 0.17104845946388586, 0.2182503951979535, 0.10234039702585765, 0.1986385482762541, 0.11085654755256005, 0.09930267038622073, 0.1411239252026592, 0.14213886431285314, 0.16661079972982407, 0.14977496170571872, 0.11576036762978349, 0.08612116412924868, 0.11522554632808481, 0.1164172709520374, 0.14795998909643718, 0.14881155054484094, 0.14625871181488037, 0.13796767885131495, 0.18838531417506083, 0.07050485030880996, 0.10354483061070953, 0.22689916539405072, 0.17091326814677033, 0.12036896390574318, 0.1081345636131508, 0.1030209744349122, 0.1195172667503357, 0.0785376735563789, 0.06741773310516562, 0.16362287077520574, 0.1400566981839282, 0.14561543347580092, 0.14469433575868607, 0.15064028384430067, 0.22957111416118486, 0.13222392063055718, 0.15189047104546002, 0.11000759846397809, 0.1509583539196423, 0.1413225188319172, 0.14900303312710353, 0.18893234910709517, 0.09499475333307471, 0.09077343770435878, 0.07573889980890922, 0.0760933393612504, 0.1083341207621353, 0.12284203405891146, 0.13699864942048276, 0.3035475531859057, 0.11122452387852327, 0.12547921469169004, 0.18621723194207462, 0.11469361558556557, 0.09633399147008147, 0.15254247534487927, 0.12404298675911767, 0.1073840767411249, 0.10535890755376645, 0.11303507922483341, 0.14375167419867857, 0.22392414217548712, 0.14835208734231337, 0.14505071592118057, 0.09938347712159157, 0.10431910692048924, 0.09384213946759701, 0.1310464452419962, 0.1055773686883705, 0.15787802689841815, 0.17648945535932267, 0.0850209060258099, 0.12630379758775234, 0.14754601488155977, 0.10082549974322319, 0.10881211475602218, 0.1569035013339349, 0.12148653822285788, 0.1053248450958303, 0.10587673833859818, 0.1224938505994422, 0.24855427124670573, 0.16212374264640467, 0.1169572084077767, 0.11246712505817413, 0.1405518523284367, 0.11716627861772265, 0.11764810633446489, 0.16748876976115362, 0.17541978561452456, 0.10813542535262448, 0.2722123717623097, 0.08014469553849526, 0.1033467458827155, 0.13740285273109162, 0.10052535656307425, 0.09671547742826597, 0.17231509435389722, 0.11744162812829018, 0.15342971416456358, 0.12185871468058654, 0.12213900392608983, 0.1752976628818682, 0.12978608001555714, 0.20375717218433106, 0.17046282945999078, 0.10601971923772778, 0.149459945037961, 0.15239079562681063, 0.16595770977437496, 0.12347168741481644, 0.18869986943900585, 0.13059773003416403, 0.1390940062701702, 0.10670985720519509, 0.14146995092076914, 0.1180341113358736, 0.23093336820602417, 0.1292752788535186, 0.07646877957241875, 0.14588606038263865, 0.1231696850487164, 0.11792553216218948, 0.1451854051223823, 0.16406781332833426, 0.10013988760433026, 0.14106992738587515, 0.10875781838382993, 0.14786872613642896, 0.15154796013874666, 0.14866514982921736, 0.12359858703400407, 0.21904855594038963, 0.17821714122380528, 0.08140330335923604, 0.15489681544048445, 0.1563219696815525, 0.09625904727727175, 0.13862421576465878, 0.19963264279067516, 0.2037202055965151, 0.10970580644373383, 0.09649951330253057, 0.1847922812615122, 0.1695814938949687, 0.11799415919397559, 0.20375525871557848, 0.10708743480167218, 0.1816166288086346, 0.061345353589526246, 0.16718560031482152, 0.10061047878116369, 0.06997059219117675, 0.18384523636528424, 0.23919854898537907, 0.12588101598833287, 0.12977537273296288, 0.18105541249471052, 0.17024746244507177, 0.18215348571538925, 0.12805295230022498, 0.08134567538010222, 0.14514155818947724, 0.11328367409961564, 0.16394598915108613, 0.14118519691484316, 0.11077633114265543, 0.17696710330035004, 0.20053493151707308, 0.13273250976843493], [0.012266497543480779, 0.0528512113461537, 0.045542544419212, 0.08225067824657474, 0.011518464423716068, 0.028076081037787453, 0.03421234292909503, 0.026679637309695994, 0.04904552555776068, 0.01144627423491329, 0.010615725319699516, 0.009685508940102798, 0.0611062582050051, 0.019618830743378828, 0.045046908514840264, 0.03454015337462936, 0.029086221209061996, 0.023567054686801772, 0.023367008992603848, 0.032053817861846516, 0.028037647117993662, 0.03023172402754426, 0.029338514099695852, 0.015136506441714508, 0.021613935740398507, 0.02769306837581098, 0.07561916551951851, 0.06597661972045898, 0.03300468630290457, 0.028451339740838324, 0.05477642553991505, 0.01588205018612955, 0.011031058300951762, 0.0661911792787058, 0.024541768544752682, 0.05254329554736614, 0.03133798377322299, 0.03174320488635983, 0.0346603694238833, 0.06665208097547293, 0.02634890577090638, 0.0052103940730116195, 0.03855349462745445, 0.01641691559260445, 0.04014748873721276, 0.0064422345354354805, 0.035121277906000614, 0.023420603081051792, 0.02129280547212277, 0.023167395864480307, 0.02521362168980496, 0.07504714692809752, 0.03817160494093384, 0.016951255134439895, 0.0700033518618771, 0.052240383944341114, 0.034795224866164584, 0.02974866476974317, 0.018108330367665206, 0.03199121282835092, 0.030310264455952814, 0.09045221922653061, 0.05687920217003141, 0.03481337567791343, 0.01675047492608428, 0.0842584226546543, 0.027734394551121762, 0.014126356940583458, 0.04713482862072332, 0.0424582159944943, 0.020472102100029588, 0.055344050617090294, 0.02734641162013369, 0.020564123322921138, 0.009748363335217749, 0.016915844088154178, 0.028948519312377487, 0.06263275165110826, 0.04354751915005701, 0.03995987719723156, 0.08994524500199727, 0.03561825730970927, 0.028028627691258277, 0.012344308546744287, 0.010825088996041034, 0.04627937916666269, 0.03856706193515232, 0.03636872382568462, 0.012247524008021822, 0.06817042521600213, 0.03851639911798494, 0.0018696843721305154, 0.021015511958726814, 0.04406359592186553, 0.01379425815373127, 0.032289853053433556, 0.026275118480303457, 0.03284975640209658, 0.02067939454822668, 0.00812252048802163, 0.07745799542005573, 0.03893482791525977, 0.029358992286558663, 0.02145154873973557, 0.07496931217610836, 0.059130337089300156, 0.04475303499826363, 0.04937087292117732, 0.05611397073205028, 0.019672363763675094, 0.04728724115661212, 0.040988800914159844, 0.051840007571237426, 0.02163182701250272, 0.03212030411564878, 0.028805015941283534, 0.03402296380539026, 0.022997801125581776, 0.0328471847543759, 0.03670937554644687, 0.03892845307875957, 0.02643039613030851, 0.022181503142097166, 0.05647308878334505, 0.015790183329954743, 0.04136505536735058, 0.022129749579887305, 0.03684253804385662, 0.035992944347006936, 0.04642025999990957, 0.06284693122974463, 0.08703299305800881, 0.04585130499409778, 0.03548928476603968, 0.019060964696109295, 0.07978786075753824, 0.10385526038174119, 0.01627064888764705, 0.044692451999123604, 0.07459881848522595, 0.03377055895647832, 0.025967531770999943, 0.04726480878889561, 0.08409828160490308, 0.03308772881116186, 0.01604424210797463, 0.019192671735904047, 0.01256680187569665, 0.0515750973219318, 0.02496222616173327, 0.060252566156642776, 0.08091382855283362, 0.02789510557028864, 0.038439571990498474, 0.06624833906867675, 0.02511386007868818, 0.04162693935047303, 0.018061290927497402, 0.03648751834407449, 0.0013883320539857128, 0.029609670263848135, 0.01630606671928295, 0.01712380150066955, 0.022511875057326894, 0.014356835778536541, 0.05326712617118444, 0.008798309984350843, 0.0784817012026906, 0.011091155299384679, 0.013620103659507419, 0.07061441335827112, 0.009489676948370678, 0.04392917813467128, 0.013619159647662724, 0.04875994373911193, 0.020702288319755877, 0.025050257598715167, 0.005930305308928447, 0.053959354026509185, 0.03811942220532468, 0.051238163973071744, 0.044171374424227645, 0.03138688579201698, 0.08020298848194735, 0.021573266047718268, 0.03486061867858682, 0.03466384352317878, 0.017232277197763324, 0.027569425724712864, 0.01931259092608733, 0.03454451296212418, 0.05008649327126997, 0.0576015298387834, 0.042774101187075884, 0.06829667344157185, 0.049729957045721154, 0.0062795298955669356, 0.040097253397107124, 0.02796749847142824, 0.006792647830609764, 0.020844388819698776, 0.02693338056893221, 0.051165635364928415, 0.0574582978816969, 0.04295310890302062, 0.03297281551307865, 0.03221010144001671, 0.07859282488269465, 0.053705900840993435, 0.0647807221061417, 0.012698440213820763, 0.024013817410117815, 0.040835156837212186, 0.03435030945443681, 0.02947995133165802, 0.03199004914079394, 0.011461558236208345, 0.03280359905745302, 0.03760974062606692, 0.02164711949548551, 0.044132538472435305, 0.05853554007730313, 0.04541821644774505, 0.04696032637730241, 0.006585243424134595, 0.019324073434940407, 0.0261037035712174, 0.01303775267608996, 0.02087055143368031, 0.03126756540898766, 0.03914903463529689, 0.014645866251417568, 0.028776022139936686, 0.0285878033111138, 0.032602101298315186, 0.023100943537428975, 0.010606362384610941, 0.02539566924263324, 0.04567714201818619, 0.021697984176820943, 0.05874870863876172, 0.05684972660882132, 0.02295595926365682, 0.022414350915434103, 0.10183928534388542, 0.01903633217859481, 0.01669650085802589, 0.07173689348357064, 0.018376713019928763, 0.004023789419859115, 0.03097381063603929, 0.02552877406456641, 0.032492619673056264, 0.0260224252540086, 0.018557791964017918, 0.04864249950540917, 0.027908382804266045, 0.014912847728867615, 0.019025365356355906, 0.04706815916246601, 0.03653258324733802, 0.013185060084132212, 0.008453262204836522, 0.08342811970838479, 0.017335655400529504, 0.014661184179463556, 0.03868786830987249, 0.04639502867524113, 0.03978864888527563, 0.011013871008929397, 0.028490257116832902, 0.00673144990910909, 0.05189748627266713, 0.04971862890358482, 0.03026150832218783, 0.06290313428533928, 0.0657293615596635, 0.06659356411546469, 0.02504308209089296, 0.025043502782604525, 0.07932647051555769, 0.06309667282870837, 0.03922424006408878, 0.018357722521094338, 0.04104324995673128, 0.021757388221366063, 0.017844000265800526, 0.024320393102243543, 0.022418288114879812, 0.015957903615864258, 0.04714587177815182, 0.01018684877947505, 0.036716184645359, 0.0350309682876936, 0.06630197047655072, 0.04782731431935515, 0.05210126730214272, 0.028571694889771085, 0.01675111783801445, 0.024182794682149376, 0.04492177308670112, 0.01161632189593677, 0.05243657895230821, 0.025543681478926113, 0.03492329156558428, 0.016183599630104642, 0.04531936068087816, 0.06388768181204796, 0.04689409118145704, 0.04308259713330439, 0.03558293277663844, 0.04535273442577038, 0.004897390957921743, 0.0464267705434135, 0.018744940403848886, 0.06587898531662566, 0.01711290083559496, 0.0449226857163012, 0.008303506981714495, 0.01969202940485307, 0.04822153637983969, 0.020775464928842018, 0.04495384743703263, 0.032766466228557486, 0.04895440848278148, 0.06469109441552844, 0.03719031098963959, 0.05086875933089426, 0.019763056754267642, 0.02318702418623226, 0.0040927374835259146, 0.055788508017680476, 0.015784478546785455, 0.03640531721924033, 0.05221595668366977, 0.027252227566870194, 0.04093047743663192, 0.12722150262977394, 0.014791384871516908, 0.07546180646334376, 0.01737933948503009, 0.07072048873773643, 0.03405217473794307, 0.05188977811485529, 0.04836579292480435, 0.053552575675504546, 0.038338738294052224, 0.013017965746777398, 0.03223227935710123, 0.007818110170774162, 0.04608181691063302, 0.04276844220502036, 0.1506707907787391, 0.09533404119844947, 0.13678550800042494, 0.12283486872911453, 0.09951993729919195, 0.06962375223104443, 0.20107622604284967, 0.18882238572197302, 0.1687204193856035, 0.21291150525212288, 0.09087816958448716, 0.09681674199444906, 0.12007131773446288, 0.0630941011809877, 0.09758126775601081, 0.10536344016769103, 0.09373001834111554, 0.1038107688405684, 0.1811817828565836, 0.17590143691216195, 0.07902342999087912, 0.17756105214357376, 0.16776049589472158, 0.19065463383282932, 0.119290595342006, 0.1436500839356865, 0.17073963103549822, 0.1184345284210784, 0.1885916973863329, 0.11906650236674718, 0.12591642194560596, 0.1315083783119917, 0.15444579321358884, 0.13864174910954066, 0.08094474260828324, 0.11737505027226039, 0.15495622796671732, 0.16892184929123946, 0.10457304186586823, 0.16167304611631803, 0.06519984640181065, 0.13663640671542712, 0.07714033246572528, 0.09779068401881627, 0.15049927069672517, 0.1460828898208482, 0.15032156237534114, 0.19420926166432245, 0.08848461016480412, 0.1977526122438056, 0.08065597846039704, 0.17546310329011508, 0.08617248851805925, 0.08044027896331889, 0.18892906499760492, 0.1141640597156116, 0.06928130917783294, 0.15381098299154214, 0.10044120465006147, 0.08021294937602111, 0.14945645736796515, 0.1341391671448946, 0.1341018205774682, 0.07973255336816822, 0.11728768210325922, 0.305567877633231, 0.0633739833054798, 0.1495023127645254, 0.12451294011303357, 0.08762833289802074, 0.11077511656497206, 0.18777527048119477, 0.06703486972089324, 0.15295953010874136, 0.09332761993365628, 0.14110861745263847, 0.14437314442225865, 0.16820519417524338, 0.1430284237223012, 0.0804601057565638, 0.24353172789726937, 0.1278628132172993, 0.09540517880980458, 0.17578447104564734, 0.09874722161995513, 0.08931430242955685, 0.12398668192327023, 0.17824828598116124, 0.0825784242312823, 0.14566301235130855, 0.10105791834316083, 0.11758998302476746, 0.09411790288452591, 0.09561793346490179, 0.1315600419683116, 0.11200994173330919, 0.22478870435484818, 0.17834884487092495, 0.07564560124384505, 0.08643692718552691, 0.16346466355025768, 0.10814242783401694, 0.05638363411916154, 0.09855689254722425, 0.22599660525364534, 0.14347936452499457, 0.12310066446661949, 0.08160087240061589, 0.14613787829875946, 0.09157101490667888, 0.12259288957076413, 0.09150706976652145, 0.19176857120224408, 0.12481468463582651, 0.13331993110477924, 0.13691091484257153, 0.164989779570273, 0.08617607118295771, 0.13159238094730036, 0.14985395675258978, 0.19473784044384956, 0.17218385211059026, 0.12818787220333303, 0.09387803397008351, 0.10439893656543323, 0.06715660568858896, 0.17629376585994447, 0.19805704376527242, 0.12506152210491045, 0.18228782207838126, 0.20413419338209288, 0.238718037626573, 0.15841888716178282, 0.1084465268733246, 0.08025467249431781, 0.15011033442403587, 0.20377678184637002, 0.11501353127615792, 0.09505849491272654, 0.2471600989145892, 0.10219139073576246, 0.1276891625353268, 0.12613446238849843, 0.23047370144299098, 0.14006728333021912, 0.18229827151766845, 0.20850861365241663, 0.08040591794997454, 0.12312292041523115, 0.18057802239699022, 0.10520624395992074, 0.24304752530796186, 0.06488818848239523, 0.1709088712398495, 0.14210007925118717, 0.07031996987227883, 0.12188493327370711, 0.11674062002982412, 0.16593910434416362, 0.11965661070176534, 0.13440706634095737, 0.2177134568669966, 0.08366239749427352, 0.13257974439433642, 0.08589643333107233, 0.20923673601022788, 0.12398482273731913, 0.21394441196961062, 0.1367067436554602, 0.11545451118477754, 0.2595982157758304, 0.12082295811602048, 0.15790249487119062, 0.09133086779287883, 0.12827628531626292, 0.15296323490994318], [0.018159451195970178, 0.04457077370690448, 0.023587982403114438, 0.0610188018264515, 0.02102958138233849, 0.05329754489607044, 0.013864938602117556, 0.036448075103440454, 0.01715975028595754, 0.08999299351125956, 0.05994363594800234, 0.03973192335771663, 0.01699301048314997, 0.05376050594661917, 0.01374602788460574, 0.04189018040363278, 0.08446810354611703, 0.07414795910673481, 0.08045737126043864, 0.01822685686472271, 0.030369544667857032, 0.015161228865118963, 0.019519389740058353, 0.025444233690255454, 0.014168384551469768, 0.03218068016160812, 0.0636316230520606, 0.03561352113527911, 0.04232928755560091, 0.08650529637400593, 0.008997222525067627, 0.039653450782809935, 0.018896989923502718, 0.03255271751965795, 0.014108083144362484, 0.022934554876493554, 0.03147105806108032, 0.0390711659565568, 0.11695051805249282, 0.014141836020696377, 0.042364459418292554, 0.0180341071183128, 0.041177487932145596, 0.02848223683291248, 0.025243877566286495, 0.019351477768006067, 0.010267574938812425, 0.007501639741738992, 0.03435142564454249, 0.0279096838951643, 0.07838962400066, 0.032860657067171166, 0.024964807987479225, 0.018458693620881865, 0.02695815048978797, 0.08575608514781509, 0.05809684683169637, 0.02902504788445575, 0.05597972597128578, 0.00225501274690032, 0.04816880063819034, 0.03169932063402874, 0.01696466637908348, 0.022505907341837883, 0.03803981647693685, 0.012246764048800936, 0.06902885343879461, 0.033725561906716654, 0.028458762913942337, 0.044150081995342455, 0.03448595878268991, 0.040662934471453936, 0.04275103099644184, 0.02546550067407744, 0.05164293386042118, 0.037381586618721485, 0.03493546448381884, 0.04164552103195872, 0.04899355995335749, 0.04632319217281682, 0.04122007278991597, 0.09040535281279258, 0.023851825656103234, 0.03791142747338329, 0.04948529767404709, 0.030791610412831818, 0.02602653039087142, 0.030026748776435852, 0.013476142277275878, 0.0394991451342191, 0.025538237931739007, 0.047196558344044855, 0.04959806680147137, 0.021194967507783855, 0.042223836428352764, 0.06366833858191967, 0.03642171401796596, 0.020404864368694167, 0.01957381164122905, 0.019514695974066854, 0.015758276917040348, 0.0385159173581217, 0.04706309050587671, 0.07611967330532414, 0.023918099867712175, 0.04551810019516519, 0.08041289328996624, 0.0321769753604063, 0.023352546018681357, 0.03668729940961514, 0.04313810129782983, 0.02473882189951837, 0.026384973299822638, 0.050419843955231566, 0.015021951070853641, 0.011053087788500955, 0.035948622439588816, 0.017364247169877802, 0.031160502761070217, 0.05151643118421946, 0.022889001428016593, 0.02304626379295119, 0.023487662696944814, 0.061585711049182076, 0.03786625400451677, 0.09334599466196128, 0.047765920470867834, 0.016300721559673548, 0.06341392866202764, 0.04181779768051846, 0.0874165485480002, 0.054494931894753657, 0.028610839574996914, 0.03412071356017675, 0.025724882559318627, 0.07061516653214182, 0.03630570488582764, 0.0734815223674689, 0.023072290699929, 0.012277429590799978, 0.017033325641282966, 0.024478892097249627, 0.0492261481870498, 0.07098330570650951, 0.034853589055793624, 0.07434811336653573, 0.025019932172394226, 0.05882215326918023, 0.020935507591015527, 0.025831719594342367, 0.05796192692858832, 0.02596325021503227, 0.015623954124748707, 0.05121806915849447, 0.0779787642615182, 0.01095248818663614, 0.004262713898372437, 0.04793257884947317, 0.09061022289097309, 0.0414239827410451, 0.022367806805829917, 0.013620851744365479, 0.025011487804087143, 0.017876262909599712, 0.01006387872621417, 0.05619024146082146, 0.08967188359903437, 0.030646498913743665, 0.035460107760237794, 0.04458876506292394, 0.05137732472004635, 0.038380491946424754, 0.07048383607928242, 0.013924139934325857, 0.055651884991675615, 0.024423264100083282, 0.061072501087827344, 0.03788287132712347, 0.014227914973162115, 0.023589539640982236, 0.0022407261920826776, 0.03778118606922882, 0.06652614487601177, 0.00817761498702956, 0.05117265141702124, 0.032121688327086825, 0.014843604926552092, 0.05121691904163786, 0.02770593679243965, 0.027155602483877113, 0.012821543429579054, 0.07062975503504276, 0.07995186267154557, 0.044745303091726134, 0.03936667134985328, 0.029297622186797004, 0.05070691515824624, 0.015201717049681714, 0.0594360510419522, 0.0252092604059726, 0.001516766646610839, 0.0408260135778359, 0.08086000715515443, 0.03232137439772487, 0.03774195656712566, 0.07308746994073902, 0.0031180764240811443, 0.038828725394393714, 0.028562371818614856, 0.05542564106040767, 0.019093973728428994, 0.020822938631421754, 0.055190331901290586, 0.03419685197461929, 0.019029709676812803, 0.0676121808854597, 0.026368813988353525, 0.03407435944037778, 0.014997009819905673, 0.005943979909976146, 0.0556154951586255, 0.03607086391587343, 0.03672230503122721, 0.022324295747759085, 0.03598531082804714, 0.04729208250397018, 0.05859616718121937, 0.02918424577053104, 0.0019050267167455915, 0.029949158297053406, 0.026218521874397993, 0.03932691937578576, 0.025896502725247825, 0.022254104692755, 0.007303517694318933, 0.01242162930845682, 0.07768229874117033, 0.06577478947916202, 0.020417281559535434, 0.021257930468501787, 0.0229508244499032, 0.03592941989856107, 0.06253740391028778, 0.07201060772474323, 0.02636078861542046, 0.019029572273471525, 0.040153225750795433, 0.056018853693136146, 0.024416741682216525, 0.02947864854442222, 0.04741770986999784, 0.03823207937447088, 0.0266741106419691, 0.012670649963963245, 0.06641979129718882, 0.01602828805334866, 0.04222021305135318, 0.023061554579596435, 0.029548995662480593, 0.0725833387779338, 0.055834207351186445, 0.011972220298568053, 0.042928165955735106, 0.033284738061151335, 0.06562701133745057, 0.02768946365852441, 0.012880700657011142, 0.03345390023397548, 0.007624975355741168, 0.020497837236949375, 0.04693955981305667, 0.04462997927995665, 0.03971548584688987, 0.03350663936829992, 0.01935360667162708, 0.011657160374202898, 0.025218636063592773, 0.008544903448117631, 0.0285630537463086, 0.04764709881107722, 0.04829350519659264, 0.028358970768749714, 0.013698044432593244, 0.04040290628160749, 0.03547425182270152, 0.03205055071573172, 0.028465534693428447, 0.05178897834515997, 0.03808917650686843, 0.05969159411532538, 0.04497156398636954, 0.020658929932064245, 0.046971281325178485, 0.06877120690686361, 0.0028383577841200997, 0.04364805089841996, 0.017269540644649948, 0.0354051803504782, 0.05576666936810527, 0.038876321233276806, 0.04654735639425261, 0.028963735460170677, 0.04693305944757802, 0.05305884984721031, 0.03987161675468087, 0.029324251293603863, 0.07085000071674585, 0.05119451381532209, 0.05091848237706082, 0.03960573280762349, 0.056949328764208725, 0.034442454509969266, 0.05012612310903413, 0.03039317125720637, 0.06950176520539181, 0.08089892792382411, 0.04767037595489195, 0.0379788942102875, 0.08194850624672004, 0.07714148597525698, 0.030609766420509135, 0.02934511285275221, 0.044801970943808556, 0.019972702022641897, 0.028179337104250277, 0.02615342492104641, 0.11754507757723331, 0.03447142795526555, 0.0841772427250232, 0.06098082422145775, 0.04574005578511527, 0.023836227832362056, 0.02974569278636149, 0.04335607049454536, 0.03148101216980389, 0.017643128455217396, 0.03408927024741258, 0.030993857953165258, 0.05189747948731695, 0.008291648734094841, 0.024505232826673558, 0.06597238566194262, 0.013567388273908623, 0.08602380792477302, 0.01867042199176337, 0.025816574692726135, 0.07161618210375309, 0.04528333725673812, 0.003259237153023215, 0.08606574138892548, 0.04365449358842202, 0.07141178700008563, 0.12387236234332834, 0.1834863999060222, 0.0676110205905778, 0.1042256522923708, 0.11455911637416907, 0.2033676795129265, 0.10957344461764608, 0.07411836140922137, 0.08894304877945355, 0.16642262839845248, 0.14193949715367385, 0.07961055277181522, 0.1131426270252892, 0.14293338810758932, 0.056141838165266175, 0.18421737211091177, 0.2613536130104746, 0.1302453125161784, 0.15642476773687772, 0.11495767427342278, 0.18878550055835927, 0.1054427269846201, 0.07462030768926654, 0.11339684017002583, 0.07466135227254458, 0.20361305134637014, 0.16120329632290772, 0.11485517477350575, 0.06300103331782989, 0.21490000640707357, 0.05897645891777106, 0.13094305007585458, 0.06279245165309735, 0.11770887593073504, 0.17107405380478927, 0.07107454831046717, 0.1894540882536343, 0.12166546790727548, 0.2140421617243971, 0.11971801812095301, 0.06767665528293167, 0.07977095166487352, 0.15970249899796077, 0.07426117267459631, 0.1719044449606112, 0.16633090403463158, 0.07697117368557624, 0.11535167241735117, 0.12253943458199501, 0.10020500661006995, 0.16194285878113338, 0.12915292541895593, 0.08783324368830238, 0.15202714156891617, 0.13388768849628313, 0.19844454154372215, 0.2132805875901665, 0.10447007417678833, 0.05961376614868641, 0.06834691217435257, 0.09462269901164941, 0.2101897927267211, 0.05814127730471747, 0.07685024517455272, 0.08483920791851622, 0.1486147211066314, 0.12576295089508804, 0.14618920268757002, 0.09425463447613375, 0.13926066804145062, 0.12136780816529479, 0.17624829044299467, 0.12641537588621887, 0.130799051374197, 0.19561925743307385, 0.07764933550996439, 0.17098866695804255, 0.12015878089836665, 0.1857617042426552, 0.1473841978503125, 0.09900079694177423, 0.1867069306650332, 0.08134347014129162, 0.18133971866752419, 0.1446586719581059, 0.062133763783744404, 0.08540765063038894, 0.09096644699041333, 0.09225544639463935, 0.11919463691966874, 0.12195267820996897, 0.11491806139903409, 0.11750877595373563, 0.14350119978189468, 0.12549963859575136, 0.1396067344716617, 0.14049056704555238, 0.13402241840958595, 0.10223388059863023, 0.1685289910861424, 0.13357750299785817, 0.1712221779993602, 0.1166536318404334, 0.15622378566435405, 0.12451180017420224, 0.10342650767415762, 0.11341858043202332, 0.11597805523446628, 0.14931728983564035, 0.1429678305451359, 0.09095713070460729, 0.14577617842171872, 0.1842592784336635, 0.15605439618229866, 0.1365581444863762, 0.11565963232091495, 0.11954158544540405, 0.1175540206687791, 0.13963772995131357, 0.08691201704953398, 0.06144254016024726, 0.12490327416786126, 0.10518997269017355, 0.13027913070150784, 0.11071533762982913, 0.16575267006243977, 0.11228812073490449, 0.15493779895561083, 0.09817242782030787, 0.08107054300074067, 0.16392754656927927, 0.1514838928622859, 0.20818716447268212, 0.16664524216737064, 0.1261512086327587, 0.1593108078730958, 0.1299509640250887, 0.1310100079114948, 0.11122679697083575, 0.12316489459148475, 0.1758502618010555, 0.12356303179902689, 0.1471259067101138, 0.1410353628120252, 0.11028336188090698, 0.22697281358497484, 0.11570727904992444, 0.2121002080717257, 0.0959273793601564, 0.12711903027125768, 0.13265815590109142, 0.1381195214177881, 0.10213028187198298, 0.13816135988703795, 0.1252465314630951, 0.0747851984841483, 0.13713248366756098, 0.1434261402381318, 0.14438884572259017, 0.09871616507215158, 0.11141975197408881, 0.15618988605482237, 0.09161770490131207, 0.08292179687746934, 0.10101802726941449, 0.3482389636337757, 0.16944172925182752, 0.24365283282739775, 0.09213602423135724, 0.10907546776746001, 0.19735961833170482, 0.0980444425450904, 0.1156656848532813, 0.18157217119421276, 0.16950646149260656, 0.22905282197254045], [0.021194285580090115, 0.032276658939995935, 0.03137756611353584, 0.04361360167552318, 0.019523382918643098, 0.07192263565957546, 0.010420048542852913, 0.03382574760222009, 0.011113117781600781, 0.02253462464016463, 0.031042458023875952, 0.023889720140557204, 0.027433542301878333, 0.0328092308981078, 0.04374465732170003, 0.03698887090597834, 0.08509553809251104, 0.04301448239545737, 0.01589632486658437, 0.05302178826449173, 0.054296575752752166, 0.045742474762456756, 0.040496150563870154, 0.020350033650174737, 0.02496714045160583, 0.044631373669419966, 0.03041259092944009, 0.02335062237190349, 0.03131143269794328, 0.03773532049464328, 0.017532118429828967, 0.0777631461886423, 0.049481582694819996, 0.044319668252553256, 0.04199541100699987, 0.03668614250740834, 0.06018980845276799, 0.07576188178999083, 0.05819110891648701, 0.025362750116203512, 0.07259379500257117, 0.01746964401432446, 0.020551137859001756, 0.040241279240165434, 0.025691206866343106, 0.01783567124844662, 0.025464891688898206, 0.041165403223463466, 0.04760079897407975, 0.045635188197983165, 0.033423715603670905, 0.02173815175358738, 0.06767178340149776, 0.013046173295671386, 0.016902176696541052, 0.03333473252132535, 0.03769367201519864, 0.01599548088519701, 0.06458942951368433, 0.03797831067017146, 0.027740598057529757, 0.025073002092540264, 0.049268651620617936, 0.03354111233992236, 0.025610601995140314, 0.015939511924183795, 0.024116518774202893, 0.005199773727716612, 0.08528755671743836, 0.04407117176534874, 0.02889113560585039, 0.04625660074608667, 0.059709127460207255, 0.05827488763523953, 0.05135706366438951, 0.02274057867803744, 0.0957196865762983, 0.034930816518941095, 0.050703576765954494, 0.0345618189977748, 0.057625047862529755, 0.034843824936875274, 0.040576841948287826, 0.052446933396692784, 0.054857574935470305, 0.02417477948724159, 0.05462031498817461, 0.0070315947855955786, 0.09439295383968524, 0.06690565629729203, 0.035068786436957974, 0.017388070534382547, 0.0525392480859799, 0.04795082465612462, 0.08805889050875391, 0.07846932472395045, 0.01389315293636173, 0.05224886563207422, 0.03552610546882663, 0.056845017575791905, 0.02099220428083624, 0.0022652047669648057, 0.0374088874751968, 0.036223999091557095, 0.04058601913441505, 0.019864412922678248, 0.005644815516591604, 0.0313054989092052, 0.011437589834843363, 0.03781493979373148, 0.09288512689194509, 0.04006103319781167, 0.03479476685502699, 0.07437908849013702, 0.018601806834340096, 0.015337290042745215, 0.0772969044212784, 0.029196025138454776, 0.050283967317747216, 0.04590879726622786, 0.039783342741429806, 0.01571660808154515, 0.01720592120130147, 0.04288329443495188, 0.007063577957783959, 0.04270109421174441, 0.044372068119368384, 0.03671725333801337, 0.015433491041351641, 0.015463755399520909, 0.09494277076529604, 0.05260064532714231, 0.035578396770038774, 0.0671896707000477, 0.017092325957491994, 0.021805569296702743, 0.00401479798269325, 0.03336293582937547, 0.031141317183417932, 0.027103954094595144, 0.047393699908362966, 0.054436957862760336, 0.02160168648697436, 0.0414115316234529, 0.05020137942795243, 0.03379338487450566, 0.04341067560017109, 0.05111991228269679, 0.05867807314332042, 0.022399499480213438, 0.01522220711090735, 0.03865305267806564, 0.025974301854148507, 0.014383274895538176, 0.05096048369471516, 0.055068565399519036, 0.05564439735774483, 0.04570587797622595, 0.060131691928420744, 0.0483871532071914, 0.012669359899259039, 0.01920189133046993, 0.0674382248627288, 0.011639929825573095, 0.013022343993985226, 0.06205997310046639, 0.0696255707048944, 0.05804635704095874, 0.021372180498604263, 0.06432148960552045, 0.015422746439331343, 0.07809426449239254, 0.04888385780421751, 0.02317038311489991, 0.02409725516502346, 0.027064178371801972, 0.05800041343484606, 0.024302807170897722, 0.04209596311141338, 0.039521597857986174, 0.026323891577443907, 0.07536401599645615, 0.021310727278302823, 0.05475563522694366, 0.01903299378630306, 0.0448348323947617, 0.038834645612431426, 0.03075459972023964, 0.020877299464440773, 0.03646192739584616, 0.019498894589820077, 0.021390015791569437, 0.02888523574386324, 0.05444999930581876, 0.023210331864122833, 0.0174566958698311, 0.10668116195925645, 0.049431143794208765, 0.0198565045970359, 0.028533384802618196, 0.020402460658390607, 0.03277766884171537, 0.031152977807713405, 0.01889920194766351, 0.07494341249444655, 0.05529458202155573, 0.03445207274385861, 0.05049991787278226, 0.029741397659693445, 0.05172255315950938, 0.015220660051064832, 0.013887242048180528, 0.07563760131597519, 0.056352272230599604, 0.05830285684870822, 0.027309037911306535, 0.043231837517981014, 0.008006118653741266, 0.011808309986788248, 0.019996223439063345, 0.05097043780343873, 0.012168039567768574, 0.031694102699735334, 0.04206152745921697, 0.037619321540530236, 0.05872185900807381, 0.034562741805400164, 0.024081077193841338, 0.04956812644377351, 0.042372808791697025, 0.026654051450480307, 0.01959902939519712, 0.06105494060154472, 0.038768624155116935, 0.028857887389936616, 0.03280345317242401, 0.04181185032108, 0.034301512608570714, 0.030716744251549244, 0.05410400072910956, 0.02048661426774093, 0.08945320533322436, 0.02344945608638227, 0.03470440634659358, 0.022871183098426888, 0.034672355744987726, 0.011966464625272368, 0.017240004015288184, 0.011371257099589067, 0.038911394708390744, 0.027277285865108882, 0.06332526449114084, 0.05604157783091068, 0.029647111826177155, 0.07187758771968739, 0.04205650290740388, 0.044591770973056555, 0.05088391101786068, 0.06058128923177719, 0.019866925198584795, 0.042100292164832354, 0.007600237665298794, 0.05793354380875826, 0.05122629300292049, 0.0723086745877351, 0.045055773574858904, 0.018948874103703668, 0.013834203510279102, 0.022262633877939413, 0.01072519931143948, 0.06599567298378263, 0.05048492903422032, 0.00810645193061126, 0.046153049516890726, 0.05656521348282695, 0.038622871440436156, 0.050483985870544396, 0.0515819776670209, 0.015270247390227658, 0.0324607692392809, 0.06508222235632793, 0.01775514440877097, 0.011654576003950621, 0.0437069680940892, 0.06815551101629223, 0.04197533994114824, 0.021039828957457627, 0.08632053807377815, 0.03993622685915657, 0.10516979984406914, 0.04578451339953712, 0.03480069725108998, 0.02492122568323144, 0.018857080190043365, 0.05341800182525601, 0.005440876727724182, 0.02707897891689624, 0.025075298933578388, 0.043079842281128676, 0.020067535773185746, 0.03129521231832249, 0.0422046915628016, 0.05336039759484785, 0.042929132868136675, 0.035775073537869115, 0.04143200641764062, 0.038273429298507314, 0.03213256524343576, 0.030182034908128635, 0.013078812526405921, 0.026494465103106837, 0.06208763697317668, 0.10017230800752129, 0.022209811623075178, 0.036077666229435375, 0.002746422862401232, 0.03140416468626686, 0.054031448372240574, 0.0851967144491417, 0.02332176936657301, 0.01955347425038261, 0.0194633647999061, 0.051933862535016875, 0.0362107439099678, 0.030293898191303015, 0.017155290614547472, 0.054834402964583466, 0.09303808225584881, 0.02826859668961593, 0.037039296235889196, 0.023826930206269026, 0.035985273508621116, 0.05582935582580311, 0.03554163035005331, 0.043727870365338664, 0.019645598949864507, 0.023040233312972953, 0.017277530394494534, 0.05361407808959484, 0.03593992022797465, 0.018888808487515365, 0.0063665299593204895, 0.007009696764206248, 0.05032334949022957, 0.04584489283817155, 0.045300470265958986, 0.0563799361033099, 0.04720875501100506, 0.006166795543062368, 0.04647855633603675, 0.04257923610774534, 0.02562248653599194, 0.11346533828015838, 0.08359497825482062, 0.08084838385028498, 0.09881562473518507, 0.11889917563114848, 0.14075562996523722, 0.14567803511662142, 0.16166738713426249, 0.10128317161330155, 0.15646381064185075, 0.11898195690342359, 0.10027252084442548, 0.08899907541594335, 0.10647958956126656, 0.13513320737651416, 0.09267611775015082, 0.1784647386521101, 0.17486785165965557, 0.09757478774658271, 0.16152809746563435, 0.1772197490291936, 0.1533095184713602, 0.0924952474555799, 0.06922824095402445, 0.11227592746061937, 0.17931906852338994, 0.10874070573065962, 0.1388159426195281, 0.13443233498505183, 0.16086777432688645, 0.1117366346131478, 0.09320236915456397, 0.12326416426471301, 0.19040642572300776, 0.15795422638101236, 0.10098461620509624, 0.18014755978115968, 0.13378394049193176, 0.10571046333227839, 0.10419601388275623, 0.21449513813214643, 0.09662114748997347, 0.12314263864287309, 0.19182987005582877, 0.1316063180565834, 0.10502628290227481, 0.11909209670765059, 0.10147691371717624, 0.16835487900035723, 0.13954916756067956, 0.10706526706261293, 0.08120390905865602, 0.1516203733959368, 0.16182254095162663, 0.11350385192781687, 0.1494055265294654, 0.10988987942359277, 0.12424018260623727, 0.1584791817835399, 0.12280411752206938, 0.1515873558819294, 0.15995433048478194, 0.10718591737427882, 0.13601306373519556, 0.06920859057988439, 0.14171635412744113, 0.1023491026301469, 0.1397340004997594, 0.23593995241182192, 0.0967934818140098, 0.1163061676280839, 0.11921719142368861, 0.12353579540337835, 0.1548030554716076, 0.14242998297725404, 0.16292007134429046, 0.16935962651457104, 0.13765899970063142, 0.18962495694203035, 0.11407359742692538, 0.2620187673185553, 0.13029914748455795, 0.13572735978024347, 0.12119943648576736, 0.33742107983146397, 0.10722384748182126, 0.09083462799234049, 0.08584096309329782, 0.20036444280828747, 0.199397367558309, 0.16572000538664206, 0.08810575692249195, 0.12905487710876123, 0.07837021789912667, 0.12365436261253697, 0.1716775292796748, 0.05067615716585091, 0.12524828208344324, 0.1620787557746683, 0.2222626270460231, 0.18388654557721956, 0.18332526140979358, 0.15001466098640645, 0.07023699182484831, 0.14047513715922832, 0.05792621563055685, 0.08788254604275737, 0.12739167921245098, 0.1476884258112737, 0.12722033554954187, 0.11949910915323667, 0.21863741800189018, 0.17352230314697537, 0.17247639569853032, 0.08627992775291204, 0.07830229654375996, 0.24022281116672925, 0.11447478804205145, 0.08408635974462543, 0.12501990076686653, 0.14094883602644714, 0.14705653328980717, 0.15320492908358574, 0.13588137365877628, 0.07784039740051542, 0.09875886528087513, 0.15423600375652313, 0.12424436238195215, 0.12472884995596749, 0.0957103499344417, 0.1319303728107895, 0.10193130826311451, 0.1452386294092451, 0.17159222385713033, 0.09453081858477422, 0.17334870674780437, 0.1851541439869574, 0.10327780672482081, 0.12121430997337614, 0.06359498216105358, 0.24574909891401017, 0.13530604381646427, 0.12130095889525754, 0.12151681445538998, 0.11196025939924376, 0.10157319105097226, 0.16898400309894765, 0.1418430773275239, 0.10023373578275953, 0.1140562676425491, 0.17654734796711377, 0.15291550675673143, 0.08299748745879956, 0.10965204611420631, 0.11641860088067395, 0.11832390007163797, 0.16167324967682362, 0.10899183832641159, 0.10213058042739119, 0.08987865357526711, 0.09752491542271205, 0.10727218631654978, 0.16938341595232487, 0.15453360921570233, 0.10880378234599318, 0.09665380538042102, 0.11107934452593327, 0.1068151726254395, 0.20152762824935572, 0.19935266567128046, 0.09766090062579938, 0.1713940780609846, 0.13579963733042988, 0.14787513150700501, 0.13991621429366724, 0.12207481451332569], [0.045209404081106186, 0.021276617322915366, 0.03870078083127737, 0.015118014666118791, 0.019083800792161907, 0.031325922813266516, 0.030876203373606716, 0.0723148492564048, 0.04835202205660088, 0.02439495053009263, 0.024034287115292888, 0.04951455271137612, 0.052798380609601736, 0.05360004937808428, 0.009786719223484397, 0.02314631887046354, 0.02960438447605286, 0.03748547372275165, 0.01360175437626562, 0.04892000336466091, 0.04675721370482019, 0.022013413054602485, 0.07263147405215672, 0.02220398809627763, 0.06407260974603039, 0.07697865114148174, 0.04370252708239215, 0.006200261314266494, 0.05915254554046052, 0.06722711226237671, 0.04083438669996602, 0.05449915238256965, 0.01839957625738212, 0.02837763387443764, 0.0043321390569742236, 0.019190069554107528, 0.04316397723076599, 0.011406913266650267, 0.025865624292886684, 0.029930030394877707, 0.016261439471106445, 0.01270664285402745, 0.02403927774035505, 0.028563532113496746, 0.02509526821917721, 0.006699047317462308, 0.05027203867211938, 0.0392992894298264, 0.03730400971003941, 0.05325291764789394, 0.029399164952337742, 0.025856871191146116, 0.011956035542035741, 0.015897240888859545, 0.04594946186989546, 0.03328744541587574, 0.048882653404559405, 0.07445225492119789, 0.011676151721206094, 0.016847839612247686, 0.01935676864481398, 0.12248648170913969, 0.002734329884073564, 0.06445011270365544, 0.01703452834460352, 0.07049203956765787, 0.05353275906028492, 0.017544408395354236, 0.031573625414499214, 0.06490624429924147, 0.0792789798496025, 0.07761886928762708, 0.006776151796137648, 0.020078355014058094, 0.05729273533714669, 0.03635733122272151, 0.026540122028174143, 0.039643517030136924, 0.03218668519652315, 0.013817723591013678, 0.050354660488665104, 0.0174894792892571, 0.03803029663062521, 0.022656555686678206, 0.021264527525220598, 0.059262990685445924, 0.013201294882622148, 0.01905962628578501, 0.06283938592033726, 0.05406103928440383, 0.08612035667257649, 0.018446700514427254, 0.023414652328938246, 0.09127439332327672, 0.05373227210449321, 0.02668250412014978, 0.04478766403294035, 0.024615915458915488, 0.0837081443252308, 0.07054280755775315, 0.012953230113323246, 0.052241452636995485, 0.01755450160375663, 0.009147787749368166, 0.07285437959113292, 0.023995598744867102, 0.0520362161499049, 0.02753624875497605, 0.02250911681247609, 0.049853575948093615, 0.007395689043083361, 0.011743792332708836, 0.011028099888270455, 0.04588968972010272, 0.051529686365808756, 0.027717142798272625, 0.023111194505223205, 0.014514021808281541, 0.049231590037899356, 0.047296045148479085, 0.019003904990053604, 0.012082080207099872, 0.025591964334515587, 0.044932283594139984, 0.04498140952949013, 0.03672837113429393, 0.02216035150922835, 0.029118794282632213, 0.038313988729247024, 0.02059857763483056, 0.0707487700773137, 0.037693180077310116, 0.0476215078628489, 0.021897895860352685, 0.01667976818446602, 0.04846336965316108, 0.00775346444320998, 0.030371044230248247, 0.04504486273175903, 0.04728418096367802, 0.0852868849677699, 0.005887964723764786, 0.05068004856418286, 0.024020575618903552, 0.0395072264862912, 0.05114925552957824, 0.05293276786272015, 0.06701317695634705, 0.027158316623951708, 0.012150714872404933, 0.027406641781064014, 0.03809602971055678, 0.0905069498611348, 0.00769658709344055, 0.011903959675692022, 0.040649129676499536, 0.06333747812147651, 0.06021457498094865, 0.03932643761592252, 0.03255655463518841, 0.008323229450200285, 0.03270149989319699, 0.05404616240411997, 0.040276827689792426, 0.027486023592895696, 0.0649387121998838, 0.06398995739540883, 0.03664480954674738, 0.029958220132227455, 0.042309915380818505, 0.04789151730281966, 0.04819645433287535, 0.06382409629545041, 0.04802034056878515, 0.07287951931357384, 0.01934724879850234, 0.03775566975985255, 0.019526470252977948, 0.01769750964428697, 0.005982465568065111, 0.017773597168603113, 0.02940980777410524, 0.06630908830889634, 0.06795730415199484, 0.033654115561928065, 0.015285195516688483, 0.06575990920620305, 0.0854219812899828, 0.03733110022065895, 0.06382495803492409, 0.009460579670433487, 0.04001988344160574, 0.05976967992527144, 0.06728834326245955, 0.045209665317088366, 0.052942348777183464, 0.12479511568588869, 0.03420233453756996, 0.11527993769517966, 0.045477744324931076, 0.042533058407051225, 0.02551142731681466, 0.058556479667978625, 0.044471856871885915, 0.05291805722351585, 0.07369488770408289, 0.06322655121662787, 0.005720571406917381, 0.040962070027100186, 0.04949847821678434, 0.02983048591496689, 0.044855843231614144, 0.03646857364635382, 0.050061628355511596, 0.0491823182175202, 0.029214376118034124, 0.05741635763219424, 0.0299064886224057, 0.03468843702492969, 0.027722559204058986, 0.006727106436820967, 0.02478112346891846, 0.07939603392566953, 0.02210952414731894, 0.07324550753193242, 0.034153571618454795, 0.02658468990453652, 0.016971180315262506, 0.03162387093263013, 0.02744689247837024, 0.05933640817446368, 0.03008496368836079, 0.03410451353660651, 0.054437405695872645, 0.019187355414032936, 0.008731479374026614, 0.03777985614059227, 0.03684812917241028, 0.015498727094382048, 0.05206426000222564, 0.014725695896361555, 0.047001795044967105, 0.07225683451231037, 0.016052421847624437, 0.07365484056728226, 0.04745732613706163, 0.02197471959516406, 0.11614489342485156, 0.01823537756821939, 0.06969353277236223, 0.04652810296309846, 0.04982275010219642, 0.00922236214059272, 0.03873601036944559, 0.041286328341811895, 0.0731166944439922, 0.022477505562294806, 0.009004520169193191, 0.017169940185600092, 0.021120978353012885, 0.030282145964780023, 0.046911678809140406, 0.033262902804251225, 0.030488831124135425, 0.045463898817875555, 0.08875162047999245, 0.07438356682126011, 0.013722358886817736, 0.008088367276026734, 0.020747587317600846, 0.013847864964710814, 0.04350825572120292, 0.010878605052961834, 0.04619582436446633, 0.07513198416147913, 0.06036518939903804, 0.02261436777189374, 0.07381114789417811, 0.03042543220466801, 0.04436075694060751, 0.03067960124462843, 0.008670019368374986, 0.021213890153116415, 0.032006055781883855, 0.0919266486806529, 0.0376328447434519, 0.013810699905401893, 0.05440302432647773, 0.049462926374482255, 0.010553920109357153, 0.03530565622661795, 0.057395770879728455, 0.1135521296943937, 0.06584205944091082, 0.04519786898578916, 0.028142494349075214, 0.031279490661940405, 0.0198677004248436, 0.024910075656537498, 0.017027361318469048, 0.07670553401112556, 0.04179244761222175, 0.04197287007368036, 0.058145531719284396, 0.029679355810263326, 0.029191285571349517, 0.10567704548260995, 0.05668386211618781, 0.06290130224078894, 0.029866804501840045, 0.011235000482494277, 0.01146744452749512, 0.03657347855291196, 0.06966177733348948, 0.027691640059596727, 0.06140206554638488, 0.012309249490499496, 0.016258041707000563, 0.0500810039229691, 0.050823456940374205, 0.017083596604477082, 0.05879094744367259, 0.06572435397122588, 0.013756142297227467, 0.03328519607228892, 0.030389686979885613, 0.029635709045188766, 0.012388340380441929, 0.026276205832670842, 0.03359096430774246, 0.0610304522727217, 0.05718395260295697, 0.0257231387243207, 0.05919155451868262, 0.0039279264165088534, 0.02215590201584356, 0.021846959932840297, 0.055815914047083685, 0.05615321041217872, 0.03283224341326526, 0.029949935219649757, 0.08772906820688929, 0.04787786178556936, 0.050913776736706495, 0.004783042964325952, 0.030348577935780798, 0.040911502204835415, 0.05411255366301962, 0.024410751914339404, 0.02535049238109163, 0.048554259418909035, 0.04616305112306561, 0.1082027903092759, 0.08545668835618667, 0.150947863768254, 0.10099429211446218, 0.12804243500743592, 0.10420204605907202, 0.1799770032188722, 0.12197943963110447, 0.10399389187140123, 0.07914735762668507, 0.13064657098480634, 0.17298801110259124, 0.10985983389296702, 0.20691572555473872, 0.10950993373990059, 0.2097097970545292, 0.20124106934028013, 0.12903743875878199, 0.2317287740962846, 0.1540012170693704, 0.1889136079698801, 0.15417811114873203, 0.22310957445630006, 0.11501677467354707, 0.0698907489755324, 0.1290992804403816, 0.14849571963506086, 0.20774577744305134, 0.17298882534461363, 0.15287022132958683, 0.09820783377758094, 0.19897595659962722, 0.08709034283778497, 0.19563054825578416, 0.16082958637603692, 0.0952991373570902, 0.17098345580909932, 0.19117839501372405, 0.12571496489856923, 0.08999007581067936, 0.15411355532705784, 0.11278372271252529, 0.10400466022214719, 0.1302276841763939, 0.07027982095522539, 0.08213505587939705, 0.16194345589194978, 0.1033607508455004, 0.1626052718077387, 0.11821312244449343, 0.14140202956540243, 0.08813551068305969, 0.08329144239957843, 0.10702022590807506, 0.13464243656822614, 0.08325499149837665, 0.17842138026441845, 0.179871368887169, 0.10332642375890698, 0.12384393172604696, 0.11370523433600153, 0.2092298963772399, 0.10099823440292052, 0.1880046288881983, 0.06799159731183733, 0.15786085996244634, 0.19251254413809094, 0.1002199954486319, 0.17355916116918835, 0.22329001048845903, 0.1220269099410091, 0.14270022990448133, 0.11440157411353928, 0.21695083778883728, 0.12933836903955254, 0.23369104308741434, 0.11500682735017367, 0.15440506754176958, 0.11854074629289763, 0.2034216501883098, 0.20413484477571078, 0.08234368504158088, 0.09902434210692133, 0.08661460836551019, 0.0912356421883617, 0.2167956025472709, 0.1213683509933097, 0.11992342424179826, 0.11075613794050046, 0.16890675867242472, 0.2423114776611328, 0.14582636287169798, 0.11821864571954523, 0.17780729250184127, 0.0906747787126473, 0.18408148868807725, 0.10363998157637459, 0.16010587449584687, 0.21800374771867478, 0.11714339841689382, 0.1373615028070552, 0.09610639046877623, 0.17232588306069374, 0.08649344915258032, 0.11170128293867622, 0.1056579922192863, 0.10364390350878239, 0.09018774663231202, 0.1813219953328371, 0.14544069713779859, 0.08005589566060475, 0.1022313293069601, 0.1728640698960849, 0.10148349550685712, 0.14601637981832027, 0.09341660980135202, 0.1722922141530684, 0.12094816139766149, 0.12802036904862948, 0.09645648739699807, 0.07471811851220471, 0.12644440361431666, 0.168208383289831, 0.1702347466988223, 0.17476187806044305, 0.11905105890972273, 0.0871964046465499, 0.08894621075264045, 0.12058895852948938, 0.14466718078723975, 0.21903554163873196, 0.2257879421647106, 0.1569168684738023, 0.09772024529853038, 0.13143732212483883, 0.09053696146500961, 0.07624998595565557, 0.17632797759558472, 0.15963514761200973, 0.2187949466918196, 0.17254578268953732, 0.08619618974626064, 0.17076886232410157, 0.14132027966635569, 0.12091404465692383, 0.11677118124706404, 0.1046554431585329, 0.23653358912893704, 0.14375081924455507, 0.060565377585589886, 0.09594474307128362, 0.06784655366625104, 0.21247390444789613, 0.10695259632276637, 0.1834830886551312, 0.19091899107609475, 0.12216127344540187, 0.09554504523319857, 0.09039254885699068, 0.11069690861872264, 0.07125142881912844, 0.1782390307635069, 0.14154575685305254, 0.0851603721135429, 0.09385456344378845, 0.21765781699546746, 0.1533305123448372, 0.10590198662664209, 0.0752908427800451, 0.15189291377152714, 0.11004385259002447, 0.11389864395771708, 0.1047631266659924, 0.1693185344338417, 0.1638977045991591, 0.11348581646702119], [0.02535875354494367, 0.03024396819195577, 0.030638573624725853, 0.028699463033782582, 0.027924769424966404, 0.023605349506916742, 0.029498848531927382, 0.04559464233794382, 0.05824013985693455, 0.034675829844283204, 0.05381839516173516, 0.06850161815860442, 0.05251220168013658, 0.012228791352494486, 0.01824488045115556, 0.04274288518354297, 0.03258343819262726, 0.007408928109465965, 0.07653731839465243, 0.024341587143551027, 0.024093926950756992, 0.030940457247197628, 0.061241673438676765, 0.03186692217630999, 0.010787981612208699, 0.02986066715259637, 0.060496472354446135, 0.04055741549070392, 0.0532099629885384, 0.06104072529290404, 0.014353371857266341, 0.036268331177000485, 0.043231410040919266, 0.0378832072019577, 0.03315529393564377, 0.0329670174313443, 0.024725434403600435, 0.07722987873213631, 0.07863481941499881, 0.0844372912709202, 0.02237259047771139, 0.04042441923437374, 0.03937279512839658, 0.0273933713324368, 0.027388524896066104, 0.03297724973942552, 0.047429431562444994, 0.02570923723812614, 0.019163676238219653, 0.09938237110951118, 0.01350293677699353, 0.023937589089785303, 0.041250539012253284, 0.10488505262349333, 0.036441795261842866, 0.02381565634693418, 0.08532864201281752, 0.04073409583153469, 0.005885485102356012, 0.01748879057621317, 0.06683264592928545, 0.05233372322150639, 0.044671240994440656, 0.04902984800615481, 0.029190135454492908, 0.02677780097084386, 0.04273860702025039, 0.017165692556383352, 0.025157830844234143, 0.04451755281271679, 0.05332309852487274, 0.050185379572212696, 0.013402526316765164, 0.018332979741639326, 0.018087931908667088, 0.03536364043663655, 0.04298452507438404, 0.030975469654159885, 0.007780786503904632, 0.015065838715859821, 0.00995157948429031, 0.03848955287997212, 0.028976719227752516, 0.04247061282928501, 0.05728880661938872, 0.005694684871871556, 0.04649318215836372, 0.026861391396128705, 0.0495379587768444, 0.017337232994447862, 0.01528730576059648, 0.061973548095141134, 0.020138620798076903, 0.02953444787168077, 0.058297889972371716, 0.03790139194045748, 0.06367763451167516, 0.012539211793669632, 0.021401077608710954, 0.04000970880900111, 0.1131735003686377, 0.03532899104590927, 0.018267433258837888, 0.031708826909640005, 0.04228405301858272, 0.06794558585222278, 0.035264523433787484, 0.07102008908987045, 0.02295466835078384, 0.04282552396346416, 0.016157387822334255, 0.0631186980754137, 0.049829355640602965, 0.06677266343363694, 0.05236054910346866, 0.022847493744588325, 0.05163160232560975, 0.025079346394964626, 0.0407688300391393, 0.02935188802491341, 0.03809884563088417, 0.015361283041004623, 0.03512547125241586, 0.038462268986872265, 0.021928781078064015, 0.07138500522289958, 0.06171841214277914, 0.05319653817319444, 0.1260554673416274, 0.02899227464305503, 0.029392315141324486, 0.05367143804739628, 0.021920090740812675, 0.011945908406882413, 0.04316792291189943, 0.017601564792650085, 0.03493187164089509, 0.0316110839402037, 0.08945351745933294, 0.05141780272658382, 0.05979358471397843, 0.012458405906467565, 0.0573569383206112, 0.08291761710175446, 0.039404981437006166, 0.03517022742224591, 0.08569331387323992, 0.024499823206237385, 0.026075647844533836, 0.02501612389460206, 0.012433695357425936, 0.050871252947087796, 0.022096313070505857, 0.0206815675566239, 0.033006908505090644, 0.03516389669052192, 0.032112534889685254, 0.00952035012388868, 0.05892345176211425, 0.07246525332863842, 0.04358825160722647, 0.04563797697690981, 0.0723298584510173, 0.02720792092649, 0.010803942452184856, 0.043897008789437156, 0.07177191267588309, 0.024495438173679367, 0.0295384003381644, 0.0331230499515576, 0.062332248847399435, 0.04556533980316349, 0.047804895522339005, 0.0424230237757521, 0.04422232561877795, 0.07359504127608878, 0.036345372043017826, 0.07798958689506565, 0.03416576150006481, 0.04224323235186083, 0.05824128658111606, 0.02731775538995862, 0.028167133651939884, 0.07008261153740541, 0.028193540538528135, 0.04344238693426762, 0.034546260189797194, 0.033914167500500164, 0.045671774806188684, 0.015510245226323605, 0.004119142249692231, 0.010052280866407921, 0.06458592148763792, 0.03994432178192905, 0.026634976134768555, 0.030479959278766598, 0.020656298912529434, 0.0596188415906259, 0.011730919675236302, 0.028590344424758638, 0.0528372572734952, 0.01527984526806644, 0.09615607280284166, 0.011048069173869277, 0.03706689564777272, 0.05218799425555127, 0.033204050069408755, 0.03411090872915728, 0.048142429374690564, 0.008308378863148391, 0.04454638037298407, 0.03525539713778666, 0.036278794186988046, 0.02006958664527961, 0.043910701626113484, 0.03395740714456354, 0.09463130283568587, 0.047925708682409356, 0.04404245277068444, 0.01972766776037003, 0.005574136764542865, 0.02739474197317447, 0.04471155275989856, 0.020416112782965814, 0.01876049073013876, 0.02953451233250754, 0.023822117696649263, 0.022624656059113995, 0.015583024892423834, 0.0384379027943526, 0.016494974261149764, 0.01625956332177988, 0.04152188855888588, 0.041768776918096204, 0.02637084959340947, 0.020931989386943833, 0.03292180664305176, 0.07623219476746661, 0.008665011779937361, 0.03146287492875542, 0.02633794573401766, 0.07034203583108527, 0.03405502797769649, 0.0078325112283762, 0.05036281308691416, 0.02579236456326076, 0.02486079026545797, 0.04281910841486283, 0.033462605838264735, 0.003021112073578739, 0.003152280526202438, 0.034814600433622084, 0.0464425838020231, 0.06689876238150255, 0.03850455868190952, 0.021935118595138192, 0.03410139227552073, 0.05977252298699958, 0.04962150000834039, 0.027266646436016475, 0.043002095738691945, 0.04408547867621694, 0.009524834392193173, 0.03739968993301902, 0.0440792734734714, 0.017165361770561764, 0.04712808058996286, 0.07568074935781104, 0.034596661770982404, 0.06615985810224499, 0.03615510403843863, 0.01513256415325616, 0.08792806895715849, 0.02671293302306107, 0.04170723718457988, 0.05305687870298113, 0.07585060024367911, 0.034657536540180445, 0.014604650338047316, 0.0174627467058599, 0.061276841908693314, 0.029482631544981684, 0.03894967765414289, 0.020777848283095018, 0.025164697618622865, 0.04734825163281389, 0.015412700728380253, 0.03935309725680521, 0.029419894197157452, 0.00902737831763391, 0.06549192858593804, 0.007858147129549511, 0.03404208831489086, 0.03519396936254842, 0.0437701736310763, 0.020327462182779397, 0.006801950545715434, 0.0332600529571729, 0.044312299362250736, 0.012851298886484333, 0.054107084670769315, 0.034431828651577234, 0.06084306125662156, 0.045529428337301524, 0.07420680844890219, 0.053517027225877555, 0.10362648551485368, 0.008426759475176888, 0.024160526859174882, 0.029929925221949816, 0.04896947196019547, 0.03715610943202462, 0.05316154612228274, 0.04811411410836237, 0.004616160245080079, 0.036538377936397276, 0.053060939735067744, 0.03696406027302146, 0.05061311786994338, 0.05523508128577045, 0.08348989353648253, 0.007344686110237879, 0.07423082180321217, 0.07458038947411946, 0.03476611910653966, 0.04856667321707521, 0.07735723296978644, 0.04999574260520084, 0.0346574585086533, 0.02553964249922761, 0.043716725427657366, 0.041635580493935516, 0.025798491734479154, 0.031158976057278256, 0.03871834810291018, 0.07228263241371938, 0.023437751357310584, 0.04245474189519882, 0.003852331678250006, 0.003962146209752453, 0.01705509134834366, 0.042406691437853236, 0.01884500396304897, 0.022074983322194645, 0.05371085075395448, 0.06340692618063518, 0.044706467139933787, 0.04058854328468442, 0.07883105852774211, 0.04884715584505882, 0.03734331385099462, 0.03122591014419283, 0.1481067697916712, 0.18394875366772923, 0.11197367403656244, 0.12925243936479092, 0.08985550874578101, 0.13199752063623496, 0.13456065952777863, 0.13964999786445073, 0.09812569711357355, 0.10739270092121192, 0.16361829744918005, 0.16303493375224726, 0.1379863792764289, 0.110552143172494, 0.05805389556501593, 0.09342383619930063, 0.10276541100548846, 0.17891489235418184, 0.1412174544696297, 0.11029172821768693, 0.15758107283285686, 0.12652232657585824, 0.1698528943317277, 0.06997492124459573, 0.07956143362181527, 0.12664135518882955, 0.19464235699602536, 0.08396470520113196, 0.12320339466844286, 0.1394555297281061, 0.1405753974935838, 0.1783389246889523, 0.09546989747988326, 0.10041067735957247, 0.11387822005365576, 0.15464488895876066, 0.14333626148956163, 0.15501414771590913, 0.16887983440288476, 0.15139670111238956, 0.16398143582046032, 0.12979511810200556, 0.10769057779439858, 0.11370076279022864, 0.09586546982505492, 0.17599301199827874, 0.09048588813415595, 0.10969020013830491, 0.07781096255140645, 0.1211923932922738, 0.12127360036330563, 0.09629871443446193, 0.11474211726869855, 0.2634089770061629, 0.10389116845492806, 0.10829769021698407, 0.11671061521129948, 0.18550661578774452, 0.09943085922194378, 0.08314588306737797, 0.17937674399997505, 0.17085658333131246, 0.19133167607443674, 0.12472323168601308, 0.0934220923643027, 0.12172346908066954, 0.07482384105346032, 0.12395462792898927, 0.11622513697615691, 0.09764642068850142, 0.1571937243321112, 0.13924043412719453, 0.13566806939031395, 0.06576896086335182, 0.17875635943242482, 0.1519032817866121, 0.09972452239266463, 0.14998840168118477, 0.07968021117682968, 0.10512548472200121, 0.08148674959582941, 0.1948662464107786, 0.12195258321506636, 0.10993336673293795, 0.20926056616008282, 0.1896943167916366, 0.1556990745344332, 0.12222960192177977, 0.1653197104377406, 0.20269503417823995, 0.1488439438066312, 0.13791023407663616, 0.13213233197374002, 0.1977643644703286, 0.11189335584640503, 0.17162269007946762, 0.21400655220661843, 0.06663786566683225, 0.11559443867632321, 0.15761642450732843, 0.1815819963812828, 0.09313054622284003, 0.16873465505029472, 0.17997280987245695, 0.10268177477908985, 0.09291473816015891, 0.17647862594042504, 0.12658937940640108, 0.10710627771914005, 0.17911013402044773, 0.11963447688945703, 0.1690878460982016, 0.211139673899327, 0.09385085185723645, 0.1562674290367535, 0.07990463663424764, 0.1744686695081847, 0.08295578469655343, 0.12908204565090792, 0.1713751062218632, 0.0937961551493832, 0.09792386008692638, 0.1844275008354868, 0.09550978176827941, 0.20955213265759604, 0.10006154395107712, 0.21387727771486553, 0.10580969907875572, 0.21206092089414597, 0.20504252107015677, 0.16863823522414478, 0.08173292888594524, 0.1014523303934506, 0.09245788731745311, 0.05126936640590429, 0.14513542423290865, 0.15184179294322217, 0.14182548969984055, 0.16654363833367825, 0.09196430058883769, 0.12587699906102248, 0.09129059673952204, 0.2242219376244715, 0.22946898107017788, 0.20420215544956072, 0.19169640221766063, 0.18003495010946477, 0.1327576291348253, 0.17697091666715487, 0.08414970777396645, 0.11760895486388888, 0.12382596411875316, 0.10040374951703207, 0.1270964757672378, 0.15110613884670393, 0.08634525031915732, 0.08065363072923251, 0.08875539313469614, 0.09376363975128957, 0.19332350205097878, 0.13166663981974125, 0.12698769303304808, 0.16259319388440677, 0.08160446863621473, 0.13844390186880315, 0.16200136207044125, 0.10730428102293185, 0.12084952954735075, 0.09968937427869864, 0.09644650614687375, 0.1695254197610276, 0.08664228580892086, 0.19568089555416787, 0.13853045579578194, 0.22846678484763416, 0.240359793816294], [0.02571059430816344, 0.007409193586292011, 0.01757097304133432, 0.01520062460830169, 0.020803588509027447, 0.03116245354924883, 0.0665294968390039, 0.04934459665258016, 0.0780535184645227, 0.029689669542546784, 0.004055683958410684, 0.037965486358319006, 0.006038740293921104, 0.04100795256506119, 0.021129122469574213, 0.06122971086629799, 0.012551980126383049, 0.01989946773807917, 0.05782415717840195, 0.0220049975240337, 0.02575657014468951, 0.06462275236845016, 0.0513740338252059, 0.02563755170974348, 0.03460703657141753, 0.02437816696640636, 0.03078806846003447, 0.027099984664736048, 0.10126222523727588, 0.048796079121530056, 0.09289472137710877, 0.021909424170319523, 0.01651958472627614, 0.007976906024850905, 0.04143257638705628, 0.04107792988153441, 0.06284133331584078, 0.01780367492964225, 0.028750536364636252, 0.03290563376088228, 0.0753297974754657, 0.00471601727518386, 0.04801059002056718, 0.03613432729616761, 0.05208961346319743, 0.03582454213340368, 0.09472298648740564, 0.008058773819357157, 0.05517960426264575, 0.05635871831327677, 0.05163285083004406, 0.008151500718668103, 0.0552079975605011, 0.04969189123117498, 0.029412420133927038, 0.036665267377559624, 0.0631234681765948, 0.03527102040659104, 0.02198602568491229, 0.03955999954736658, 0.001897145320461797, 0.027871767358322228, 0.06421391466366393, 0.029983071477285454, 0.07025089500738041, 0.023178601870313287, 0.03552159321095262, 0.016858238161408474, 0.10989427633051362, 0.04247290288497295, 0.06871793512254953, 0.033079979941248894, 0.055706547772777934, 0.04508613123159323, 0.028103700805721537, 0.05124464398249984, 0.03572017666218536, 0.20049181740198815, 0.21581073610910348, 0.4699567737323897, 0.7938836376581873, 1.169688737818173, 0.862647353538445, 0.6061320751905441, 0.327048694980996, 0.4215551609439509, 0.19995163567364216, 0.17030919556106838, 0.1359864380210638, 0.04748640136261072, 0.08188733631478888, 0.12254054737942559, 0.1271616286997284, 0.1609950132135834, 0.0406214352697134, 0.0734932135258402, 0.04447709516222988, 0.06422177888453007, 0.05746664386242628, 0.043648369809878726, 0.017744479534615363, 0.03699240946610059, 0.047410293482244015, 0.01542377781255969, 0.03471273536394749, 0.03273898895297732, 0.015308627027219959, 0.018984208814799786, 0.023423627650897418, 0.0523342694421964, 0.03923830270235028, 0.028640986885875463, 0.05055412603542209, 0.016742128945354904, 0.035885277802922895, 0.022331505182332227, 0.04480945518506425, 0.03320757845150573, 0.010067213725830828, 0.058970494594957144, 0.10100238703723464, 0.02112844563089311, 0.06739340762474708, 0.025878209421145063, 0.05596613830753735, 0.05239117478153535, 0.036378501515303335, 0.013365915111665214, 0.022729942641620125, 0.05666913790628314, 0.04878676622839911, 0.009710949762458248, 0.07250345485018832, 0.023039430945313404, 0.021364960886005844, 0.06423202476331166, 0.08984121879828827, 0.03843090709831033, 0.018322426825761795, 0.05177481392664569, 0.07071256344871861, 0.022926512540185025, 0.016817442939749787, 0.13984973143254006, 0.06731587142816611, 0.026181948836892843, 0.03394349378400615, 0.05944386776536703, 0.057771733562861166, 0.03431612146752221, 0.08357306157371827, 0.00366254458536527, 0.07283247648073093, 0.10492514047239508, 0.017564604990184307, 0.004824388223434133, 0.008899610173622412, 0.02881985210946628, 0.07399699185043573, 0.02479528110208256, 0.020054558790954094, 0.04064121117283191, 0.046447411578680785, 0.016163891580488, 0.04676690997023668, 0.03701441774943045, 0.012024237641266413, 0.06690282002091408, 0.12682082770126207, 0.05938393955252, 0.048741915063666444, 0.01253729747674827, 0.03918536340019532, 0.06795296831322567, 0.03408394714019128, 0.006546513069354529, 0.012397240215380276, 0.005820664227940142, 0.014031995620046343, 0.0070411481345737615, 0.04092824844909566, 0.04361862962001136, 0.031226524218384708, 0.026117267486240183, 0.031126806712044135, 0.0577936570293137, 0.0297224936740739, 0.060949740532253466, 0.06458711570927075, 0.07994761504232883, 0.02845472563058138, 0.05258716283632176, 0.04000394465401769, 0.046449077382151566, 0.03023443477494376, 0.09149593500686543, 0.0358867807579892, 0.09299871365406684, 0.03075568876894457, 0.015131697324769837, 0.09654274276856865, 0.03063635142253978, 0.01070233607398612, 0.06994236513440098, 0.06546828164053814, 0.03642747478027429, 0.0786235285922885, 0.01298396266065538, 0.027214840287342668, 0.03745306010491081, 0.040944244912160296, 0.06640195261154856, 0.06502843488539968, 0.03695259642388139, 0.03229266558108585, 0.03433207043313554, 0.05648062391472714, 0.011280088286314691, 0.048684507608413696, 0.02141202237856175, 0.1256710094000612, 0.051861893718263934, 0.03734524767579777, 0.030107959240142788, 0.038042710428791385, 0.03378781410200255, 0.039529424759426286, 0.014897538282509361, 0.026920590183830688, 0.027130271075293422, 0.028207481040486267, 0.05870603557143893, 0.04123115665944559, 0.05414260597899556, 0.03935428469308785, 0.04922020422028644, 0.03190534082906587, 0.028106633773339645, 0.04118583730555006, 0.01613053649530879, 0.012781786366498895, 0.06640653272292443, 0.02744091458485595, 0.06877962074109487, 0.11501510547740118, 0.0023144348150318755, 0.05915669817477465, 0.01244172327486532, 0.024454140836106877, 0.018245129812774912, 0.052607783515538485, 0.056904511526227, 0.1306134041930948, 0.19883045155022824, 0.44296986183949877, 0.4754181663904871, 0.8722390159964561, 1.5327520902667726, 1.0511795026915414, 0.5104426241346768, 0.4868568011692592, 0.4628997381244387, 0.22652443764465197, 0.015678696633715714, 0.06614898797124624, 0.03514213267979877, 0.18579264543950558, 0.1725966049624341, 0.1886074665401663, 0.13215967693499156, 0.08406447699027401, 0.04115132022915142, 0.009435975990657295, 0.0159172949913357, 0.06441776015396629, 0.029925121194017783, 0.006725565738244248, 0.030190089118799994, 0.024557680190939988, 0.05806490818836859, 0.028160930145531893, 0.08635455981961318, 0.03432006036330547, 0.027179252821952105, 0.051019455173185894, 0.05593108179579888, 0.04097285194854651, 0.03130817572985377, 0.08021629455366305, 0.07842656344707523, 0.038765289155500274, 0.08149734831282071, 0.01936397807938712, 0.03137754915016038, 0.024942048226616213, 0.07135278159486395, 0.05859032499470881, 0.024812493839168122, 0.05481586538787399, 0.02348644133391125, 0.021487258341429488, 0.06890729389020375, 0.03612824083705034, 0.031600790563970804, 0.011245826508716812, 0.03570937777736357, 0.03979528156508293, 0.09937173846576895, 0.0708315988470401, 0.022739375974716883, 0.04119326726400426, 0.0123574297176674, 0.03266908288268106, 0.008158165628888776, 0.04226697768483843, 0.029724162870219777, 0.06577421950974635, 0.027061944295253073, 0.07789328241986887, 0.08017803874931165, 0.041087086711611064, 0.04373156498851521, 0.08565352457974638, 0.040587471199354956, 0.016789953789806793, 0.05042985573943172, 0.09360307122447661, 0.013351994117588868, 0.016506860498338938, 0.03247965965420008, 0.014733933311487948, 0.028621149914605275, 0.02869470989597695, 0.05919171736708709, 0.02297856635414064, 0.05772496892937592, 0.035912463308445046, 0.03130591960091676, 0.057119878541146, 0.00882666087376752, 0.0008766684633363703, 0.01458080661749201, 0.02059881851476218, 0.05705882396016802, 0.07319947571626731, 0.015275102308286088, 0.06482092530599662, 0.027182669245771, 0.03227579380784716, 0.06169971850301538, 0.055995518873844824, 0.0794421403801867, 0.11551259378237383, 0.09720485723976578, 0.06951902035091605, 0.09848487962569509, 0.10068586402173553, 0.14556641610605375, 0.18175731625940117, 0.11715873330831528, 0.15240693118955406, 0.1085758488625288, 0.11044610850512981, 0.16449253553790705, 0.11789607017167977, 0.14064861142209598, 0.1495068860905511, 0.12291496300271579, 0.14641272569341318, 0.12795722457979405, 0.11748183811349527, 0.402709067932197, 0.12171244967196669, 0.18405071033963136, 0.1484709938189813, 0.07617357612720557, 0.20666579396596976, 0.12023453254784856, 0.10838232388986008, 0.18292994690792902, 0.15533293703837053, 0.18806980896208966, 0.16785258666745254, 0.10181194716798407, 0.17639397191149847, 0.07947007566690445, 0.10060318452971322, 0.16715605690010957, 0.2049376738390752, 0.20027522902403558, 0.1286953349730798, 0.07262664966817413, 0.21952623102281774, 0.11361298750021628, 0.11356361050690923, 0.07620470731386117, 0.31962685180561884, 0.14318735019436904, 0.12402092080031123, 0.07131314157907452, 0.11314649467489549, 0.20833809780223028, 0.13491020005728516, 0.06536792631128005, 0.09721257218292781, 0.12532239167818002, 0.15341355146041938, 0.12294381431170873, 0.08429697022906371, 0.11173354727881295, 0.1607150360941887, 0.22822316363453865, 0.08186109058026757, 0.10094856563955545, 0.18492509770606244, 0.08588142413645983, 0.12762535310217313, 0.13879967134978088, 0.09394953799034868, 0.08186833733426672, 0.1860767209104129, 0.0988951829661216, 0.16675316994743689, 0.1011694355734757, 0.12335697428456374, 0.18101973512342998, 0.10044055325644356, 0.1405077339815242, 0.36341844339455875, 0.6003216441188539, 0.8559550440737179, 1.0681256162268775, 1.5987908095121384, 3.1532525462763648, 2.123130862201963, 1.301047363451549, 1.019131370953151, 0.588391261441367, 0.5549367165991238, 0.2781153821519443, 0.2615475926016058, 0.18233857649777616, 0.4973172055823462, 0.41300304127591, 0.44299841459308353, 0.36658997035452295, 0.15070045632975443, 0.148502165717738, 0.24356845021247864, 0.16630506542112145, 0.1542922950216702, 0.10580744634249381, 0.11240276601165533, 0.1067245067762477, 0.0764271921611258, 0.1127556517188038, 0.0933233926604901, 0.1688038520514965, 0.13180229254066944, 0.09754654711910657, 0.14817011782101222, 0.16879659172679695, 0.1030809705012611, 0.1220833911959614, 0.1732705259429557, 0.27028682508638924, 0.1607383776988302, 0.20549986724342617, 0.11189271123813731, 0.13499817890780313, 0.10770736475075994, 0.18796486673610552, 0.11552456314010279, 0.1012660793161818, 0.1949964572808572, 0.09915381337382964, 0.14095175372702734, 0.09308280449892793, 0.17622870792235645, 0.07118952606937715, 0.1858671350138528, 0.07800636706607682, 0.1334882349308048, 0.17971708359462873, 0.19139005722744123, 0.1259433597858463, 0.09526711050421, 0.12177137365298611, 0.17833388995911392, 0.10211253818124533, 0.1588403388325657, 0.16742197477391788, 0.25342143007687157, 0.14226404045309338, 0.13623274623283319, 0.24493634966867311, 0.15901160107127257, 0.11829791218042374, 0.21522843092679977, 0.12246235300387655, 0.15366067391421112, 0.17844606536839688, 0.24008034595421382, 0.11796114167996816, 0.12981901610536234, 0.28230498305388857, 0.09656697325408459, 0.09631698738251414, 0.1821338353412492, 0.10721973555960826, 0.23939733260444232, 0.135461509759937, 0.11407712580902235, 0.18498712937746728, 0.16791539186877863, 0.10025070594357592, 0.14122220421476023, 0.2496220682348524, 0.0678192154903497, 0.14994184060820512, 0.27612122201493805, 0.09142379994903292, 0.15261859340327127, 0.10211639904550143, 0.149786469659635, 0.3034422445510115, 0.10496507904359273, 0.13486313686839171], [0.02425003919883498, 0.0382253415217357, 0.04133258407403316, 0.02749835935953472, 0.05005443588431392, 0.06157260175262179, 0.06412989167230469, 0.021052010357379913, 0.035252978160445175, 0.04972212675160595, 0.036848906095006635, 0.01576064500425543, 0.07704474045229809, 0.07693863793143205, 0.09030953009745904, 0.06082506650792701, 0.057180478503661494, 0.1227000845330102, 0.05225525403927479, 0.08103724728737559, 0.06658345394368682, 0.12015617532389504, 0.0533226167650095, 0.04948931460135749, 0.047608910860227685, 0.04701654978894761, 0.07561243445213352, 0.0640995679423213, 0.06269168920282807, 0.06270967038082224, 0.03572836657986045, 0.0758358013949224, 0.029569361891065325, 0.016761261936543242, 0.020452212542295456, 0.03954490553587675, 0.03420678233461721, 0.05123970764023917, 0.05046945843579514, 0.03192745089264853, 0.08016007114201784, 0.059073333362383504, 0.051296273712068796, 0.05700437831027167, 0.09719712194055319, 0.07033392055226223, 0.03503400473190205, 0.036651147063821554, 0.006932484568096697, 0.022950809182865278, 0.03596838816468205, 0.02914945049477475, 0.1009640565940312, 0.016470233178032295, 0.05423488334885665, 0.034544058343661685, 0.03510626871138811, 0.007889101897100253, 0.025747830613649318, 0.049409047301326475, 0.03349315348480429, 0.041808756201394966, 0.010950547576482807, 0.09543043388319866, 0.025945291089426194, 0.03565565137458699, 0.13375857685293469, 0.06603401699768645, 0.03392966863300119, 0.16396760727678025, 0.12063720236931529, 0.2881214123751436, 0.4687962074364935, 1.6798879035881586, 6.419343403407505, 11.895770226206098, 19.333619662693568, 21.374416760035924, 26.21251344680786, 32.27618898664202, 36.732211181095664, 33.62699522290911, 37.14801917757307, 28.255016326904297, 25.566155535834177, 16.13738751411438, 13.546616179602486, 10.083753858293806, 11.1858788558415, 14.312548245702471, 13.85097072805677, 23.091742209025792, 18.750761338642665, 10.702655094010488, 6.2861737949507575, 5.558018216064998, 2.4597363429410115, 2.3624133595398495, 2.0152728898184638, 1.4644140601158142, 0.32372390053101946, 0.2873177012162549, 0.033876848074474504, 0.015002746833488345, 0.03993744143683996, 0.07300438332770552, 0.05912514629640749, 0.037381250743887255, 0.061636065132915974, 0.0397566864932222, 0.020280965570626513, 0.024905975608687316, 0.032277069453682215, 0.03804225581032889, 0.04439813404210976, 0.07130223073597465, 0.02938065112435392, 0.018254159417535578, 0.10699931345880032, 0.040012724897159, 0.03341100325009652, 0.06597759681088583, 0.02719137824273535, 0.027885690896904895, 0.03575502961341824, 0.10666212226663317, 0.02794405847920903, 0.036887779366225004, 0.01263689115044794, 0.026120705962447182, 0.013880997829671417, 0.024055525261376585, 0.009320402817268456, 0.02808363313254501, 0.033477119702313624, 0.035803188636366806, 0.02962444197120411, 0.027878637525386045, 0.006881828960363886, 0.03334118878202779, 0.0509423905584429, 0.06707633499588285, 0.0157739137565451, 0.01597317065378385, 0.06513185040759188, 0.035982349022690735, 0.03464935340785554, 0.022599952295422554, 0.0458854828029871, 0.059045011310705116, 0.07315089260893208, 0.0250904031230935, 0.0441677340838526, 0.008171986539049872, 0.02452402146133993, 0.0194110785877066, 0.02825364177780492, 0.0552323433969702, 0.05092890128227217, 0.06099556878741298, 0.055535221073244295, 0.07018868691687073, 0.00698818126693368, 0.004733287263661623, 0.03553173052413123, 0.04253118225772466, 0.03433187705065523, 0.05415309952305896, 0.021916506379576664, 0.015658706992066333, 0.0567069594482226, 0.017620495919670378, 0.012954978189165038, 0.025594388400869708, 0.014925147872418165, 0.012445388212134796, 0.015438605499054705, 0.015825024406824793, 0.032980605095092735, 0.02543015917763114, 0.03945894193436418, 0.019963506176801663, 0.019830704999289343, 0.09639392646827868, 0.038890913128852844, 0.03464341622644237, 0.040278303503457985, 0.04393136301743133, 0.08202178124338388, 0.05555955673168812, 0.026880381894963126, 0.049342561047524214, 0.04657861650256174, 0.12424626228000436, 0.06858106782393796, 0.06910058816096612, 0.04366947903430887, 0.03018753443445478, 0.0753613764952336, 0.04367178605337228, 0.060799031119261465, 0.08535023978246109, 0.022756911015936306, 0.1777897048741579, 0.0358540482286896, 0.05458285306979503, 0.049489569051989486, 0.06821978185325861, 0.013541588676162064, 0.029991777081574713, 0.02964323739122067, 0.02944425360432693, 0.04849661108372467, 0.04267076030373573, 0.020263359283230135, 0.06258229578712157, 0.05906553699501923, 0.008645731207382466, 0.027237964760778204, 0.06934906089944498, 0.01998702759322311, 0.013170992356858082, 0.097979079266744, 0.030706396592514854, 0.018198047964168445, 0.017983907401295643, 0.11099449372185127, 0.039282536400215964, 0.05386455250637872, 0.019599587490249957, 0.03849732210593564, 0.092968410280134, 0.04182356183550187, 0.02644815848075918, 0.07005794678947755, 0.10114161563771111, 0.06565413238214594, 0.07024863548576832, 0.01966404662068401, 0.05122305978355663, 0.10507620272359677, 0.02700406525816236, 0.10821304297340767, 0.05132688921211021, 0.07437732429908854, 0.21886731923690864, 0.06380763503589801, 0.22628073500735418, 0.6627827467662948, 1.9754397358213152, 6.478629776409694, 13.36124084677015, 20.797850029809133, 23.18557415689741, 26.842001131602697, 32.99766213553292, 37.52649450302124, 38.66969551358904, 41.01167270115444, 31.138914789472306, 28.13174138750349, 18.703193971088954, 15.103733539581299, 11.52195714201246, 12.722822989736285, 16.577621902738297, 18.287387711661204, 27.43633266857692, 22.252809762954712, 13.827700342450823, 9.734262943267822, 7.342243960925511, 4.257284607206072, 3.4484567514487674, 2.95016582097326, 2.379629041467394, 0.5856321752071381, 0.3945759843502726, 0.06845619702445609, 0.07804006990045309, 0.03427195901583348, 0.01199515987121101, 0.04489617196044751, 0.043139203917235136, 0.04683767438733152, 0.05001180013641715, 0.053770612725721936, 0.025003477698192, 0.044089940043964555, 0.042523270539407215, 0.01565769936756364, 0.05630527010985783, 0.02013707543457193, 0.05885109957307577, 0.06830288203699247, 0.02595349118512656, 0.03658522738675986, 0.007352333199898047, 0.014691180516300457, 0.0809925589710474, 0.04351433539497001, 0.0850728207400867, 0.057819495642823834, 0.0073333834131647435, 0.023719767474436333, 0.038817750090467076, 0.03878488863951393, 0.0442157234730465, 0.03095182270875999, 0.055331904840256484, 0.02242613197969539, 0.023325596304078187, 0.06504393941057579, 0.036705134702580314, 0.053175428948764286, 0.05115517574761595, 0.08335185915763889, 0.04705060885420867, 0.04675948340445757, 0.044441024240638526, 0.051307588283504756, 0.058799829467066696, 0.03796981880441308, 0.013424009583624346, 0.07217932545713016, 0.03565932564171297, 0.05985674275351422, 0.046383398585021496, 0.04505608909364257, 0.01844248341928635, 0.04855846972869975, 0.051878283731639385, 0.04997284883367164, 0.04259772618700351, 0.04197522119751998, 0.04879978731540697, 0.10430158036095755, 0.05029915293146457, 0.034068513861192126, 0.04326157092249819, 0.024277871008962393, 0.042872319131025245, 0.026396795076185038, 0.006852137540200991, 0.059919568310890875, 0.0678961274347135, 0.016660402795033794, 0.05091575466628585, 0.10075332397328955, 0.027692864815305387, 0.026311942575765506, 0.019363572654713477, 0.14447434113493987, 0.17399890614407404, 0.10418120824864932, 0.18158804891364916, 0.1271873451769352, 0.11824141735477106, 0.14773018285632133, 0.1827287477041994, 0.15052011529249804, 0.10848363595349447, 0.15222897859556334, 0.12805869270648274, 0.21859439888170787, 0.1530380637517997, 0.2304704173335007, 0.14388200720506056, 0.1862252386552947, 0.26025604190570967, 0.31252180305974825, 0.17062651924788952, 0.20204505191317626, 0.21131652726658753, 0.26322726532816887, 0.21002199101660932, 0.30548884187425884, 0.16729442376111234, 0.24698481974857195, 0.1775730757841042, 0.0977274649111288, 0.20412487031093665, 0.14128293309892925, 0.18332972617021628, 0.1325579769909382, 0.110756667197815, 0.1169707112546478, 0.14522372878023557, 0.11478451213666371, 0.24894784869892256, 0.1976778648261513, 0.18103007599711418, 0.2352456482393401, 0.15362970557596, 0.14334604596453054, 0.2043834464358432, 0.1836416215768882, 0.13382326838161263, 0.14251877606979438, 0.12275005185178348, 0.12733156100979873, 0.17731886942471775, 0.1970057487487793, 0.17098197660275868, 0.2951200125472886, 0.11331361106463841, 0.10656437251184668, 0.1393145030098302, 0.1407075896859169, 0.09297299717686006, 0.1702071710356644, 0.14581554702350072, 0.2848566004208156, 0.15428671746381692, 0.07856691163033247, 0.3208374125616891, 0.17767040484717914, 0.13839014832462582, 0.20290844701230526, 0.2276303411594459, 0.23969618656805583, 0.19989622650401934, 0.2397936513381345, 0.471250875719956, 1.2490277205194746, 4.030669978686741, 11.83797858442579, 21.42689824104309, 30.34581960950579, 34.836506366729736, 39.70419890539986, 46.33113711220877, 53.570218563079834, 53.54791137150356, 55.210875851767405, 44.968525886535645, 39.13792072023664, 28.066318886620657, 21.865039484841482, 17.259884629930767, 19.499115330832346, 25.215639761516027, 29.967108045305523, 37.8793830871582, 31.370970726013184, 20.588794367653982, 14.019565292767115, 11.335576925958906, 7.036985278129578, 5.197507892336164, 3.9349980609757558, 3.4069712289742062, 1.3600108623504639, 0.7315550936119897, 0.1209281717560121, 0.1712232365139893, 0.2694711174283709, 0.21574071129517897, 0.17038804133023533, 0.14733813889324665, 0.222297517316682, 0.1812773205872093, 0.1717502818043743, 0.18135390004941396, 0.18978681468537875, 0.15409025443451746, 0.10158329443739993, 0.25792402561221806, 0.1674121767282486, 0.1400221200393779, 0.2586115172931126, 0.1276301707008055, 0.12636698276868888, 0.19419334323278495, 0.23210199549794197, 0.18696003779768944, 0.16801437655729906, 0.17081264140350477, 0.14304207584687642, 0.12512781497623238, 0.13913843674319132, 0.16992359768067086, 0.1988341020686286, 0.15281927692038672, 0.2151672134974173, 0.15083853820604937, 0.13785517774522305, 0.1636789177677461, 0.1541962551751307, 0.18098898391638482, 0.15394717854048523, 0.19310650655201503, 0.1912501568772963, 0.14468722471169063, 0.14953965933195182, 0.14616575251732553, 0.15711021024201596, 0.11409311209406171, 0.1464214109416519, 0.1654372327029705, 0.20318455648209366, 0.10105049517005682, 0.20454340428113937, 0.18990654897476944, 0.1377560980618, 0.1772375266466822, 0.1589966190180608, 0.07906020658888988, 0.2288357179079737, 0.1672188485307353, 0.15770673751831055, 0.12216993155223982, 0.23670164868235588, 0.23603516444563866, 0.09846573136746883, 0.1459097819668906, 0.11328627288873706, 0.1310985703021288, 0.09616053756326437, 0.11003857358757939, 0.11481866958950247, 0.1868789664336613, 0.10276575027299778, 0.15789503098598548, 0.13512757553585938, 0.10071506138358798, 0.07315300285284008, 0.09076534278158631], [0.023614234922985946, 0.015848919017506496, 0.03148522247959461, 0.016074126486533453, 0.02184726357726114, 0.024938131383221065, 0.0525581249301987, 0.06420598258929593, 0.01917926388393555, 0.03537020865561707, 0.030222356851611818, 0.020511082240513394, 0.006269030414322125, 0.04351505124941468, 0.04146905442965882, 0.029976703426135436, 0.048224426939019134, 0.052895268624914546, 0.017478943336755037, 0.0708760293200612, 0.0203792208340019, 0.07316210200744015, 0.10188998548047883, 0.034802030572401624, 0.039174238818564584, 0.04567822428154094, 0.04651670018211007, 0.04168459786368268, 0.030996253181781088, 0.0354540789765971, 0.032446411438286304, 0.03777313185855746, 0.05248148100716727, 0.08516352051602942, 0.035581708020929775, 0.02072695815669639, 0.0661849028297833, 0.01314911978053195, 0.023368140449747443, 0.03231795797390597, 0.05469554416569216, 0.1081178445102913, 0.043266805820167065, 0.027837228229535476, 0.04991716825004135, 0.010432777011633983, 0.08771589105682713, 0.020836702714275037, 0.036658777190106254, 0.08334243430622987, 0.04969746200367808, 0.04504531056487134, 0.008648723546814705, 0.022385842266625593, 0.01118109850878162, 0.03775836015120149, 0.04580429608800581, 0.0439847908647997, 0.06696818329926048, 0.05889977088996342, 0.019454891593860726, 0.0724261561408639, 0.058517321412052424, 0.07434261044753449, 0.043850369684930356, 0.21346356134329522, 0.05101358245259949, 0.26732197989310535, 3.4945925729615346, 7.783588324274335, 10.995492134775434, 21.235887050628662, 28.195996591023036, 39.31847660882132, 49.064686979566304, 63.366751262119834, 77.71095289502824, 68.45937088557652, 79.05813911982945, 65.45094680786133, 82.31228624071393, 80.59915924072266, 81.65543828691754, 88.26678821018764, 80.12904412405831, 71.83233220236642, 72.0483933857509, 82.2488352911813, 70.03650079454694, 79.72761195046562, 73.44698933192662, 73.58413982391357, 77.52936172485352, 70.39921760559082, 65.05962426321847, 66.24243695395333, 55.594468525477815, 51.7789660181318, 42.03421129499163, 37.049452032361714, 22.426169054848806, 6.954894483089447, 3.2486471874373297, 0.7592266744800976, 0.07677982681031738, 0.04572990829391139, 0.02583098508018468, 0.014494966848620346, 0.07804002918835197, 0.04341394613896098, 0.007629401100400303, 0.05823809068117823, 0.06084723424698625, 0.010430407228081353, 0.057907101299081526, 0.04724384205681937, 0.03709212697244116, 0.051759597778852494, 0.07216812284397227, 0.09041732217052154, 0.048910232460392375, 0.025165851128154566, 0.010230916236261172, 0.0360123877679663, 0.02388273292620267, 0.014789505329515253, 0.04219818101929767, 0.013719923794269562, 0.032429912859307866, 0.017288785594116365, 0.010584854520857334, 0.02662040968425572, 0.08218762877264194, 0.06758001154022557, 0.03968397128794875, 0.059637609869241714, 0.050391850993037224, 0.03987019183114171, 0.050874224930469475, 0.1155894717999867, 0.07919380334871155, 0.015438339174059885, 0.01965133596344718, 0.034023218256022246, 0.025051280490255783, 0.03270877039592181, 0.027615949478266493, 0.0205425306422902, 0.04252004071271845, 0.06724689155817032, 0.01797224677700017, 0.0015381278831877612, 0.053339329082518816, 0.08224206085183791, 0.043382397653268914, 0.0810362837676491, 0.019763233173372488, 0.026719226435359036, 0.026847795250692537, 0.003782826367699142, 0.03146729897707701, 0.020676515863410065, 0.022090691407876353, 0.029548924416303635, 0.020732973369636705, 0.013348075577856174, 0.02741088262493057, 0.04164950742519327, 0.06340634942586933, 0.029473905584641864, 0.056234627829066346, 0.02969376110870923, 0.026599476878930415, 0.05843918810465506, 0.05911102598266942, 0.04687221860513091, 0.05290565699605005, 0.020536987011187842, 0.034912441790636094, 0.03698275391278522, 0.023712968553549478, 0.018539995686816316, 0.09236518586320536, 0.04232410015538335, 0.0023545830959587222, 0.01572229929401406, 0.010063019531246806, 0.09668241920215742, 0.007929655390658548, 0.026564484828018715, 0.05168808697323714, 0.09161560144275427, 0.053816664897437604, 0.016252971354073713, 0.020203118944274526, 0.019112212749730264, 0.030528935936412642, 0.09244954133672373, 0.04235049856028386, 0.06381746022296803, 0.09450164157897234, 0.05699665658175945, 0.018945729093892232, 0.050613986394767246, 0.025629969080910087, 0.04327104327135852, 0.01988710313370185, 0.03960656062034624, 0.004803011401756001, 0.03424807119050196, 0.05371814839808004, 0.052357943528997045, 0.015627959177696278, 0.029174705568168844, 0.016065946746883646, 0.027518837546397532, 0.036495406313666275, 0.06620733519749981, 0.02159461615208004, 0.04224016537357654, 0.038814795070460865, 0.011944614949503114, 0.025067144638991783, 0.013531528546341827, 0.07750102811093841, 0.05343950799267207, 0.023074775834434798, 0.04759129269846848, 0.03548732379983578, 0.02226711729807513, 0.03734787021364484, 0.05029067124373146, 0.05394343559497169, 0.05009418446570635, 0.02629016838701708, 0.04114954586007765, 0.022552580373095613, 0.04295544645615986, 0.08784179322953735, 0.024237186049244235, 0.051314380419041426, 0.08537100295403174, 0.02448557227450822, 0.346037714609078, 3.56195535830089, 9.302329914910452, 14.324898668697902, 23.535937070846558, 31.078875405447825, 44.55168955666678, 58.522807666233604, 72.32211766924176, 87.01938506535122, 77.8826984677996, 89.46860422406877, 78.19182382311139, 94.05058683667863, 93.40377902984619, 95.0572418485369, 96.9888619014195, 92.0420641217913, 82.11121926988874, 82.88665212903703, 92.2244404384068, 78.02890246255058, 88.82059437888009, 83.17529419490269, 86.88513197217668, 88.44892828805106, 81.19928210122245, 77.44262041364397, 78.71634333474296, 69.41385882241386, 61.12136445726667, 50.981232915605815, 47.24290405000959, 31.444760595049175, 11.573848026139395, 4.243198003087725, 0.7325674135770116, 0.14120068108396872, 0.04501204199290701, 0.06387868443770067, 0.06921579662178244, 0.06006176210939884, 0.039171843589948754, 0.03639316126438124, 0.03146039827593735, 0.03888151202616947, 0.008250515941264374, 0.03906957818461316, 0.05078176774882844, 0.035724275013698, 0.08019947367055075, 0.019803468603640795, 0.03562196550358619, 0.010623148492803531, 0.039362084453127215, 0.033057588285633495, 0.020959651563316584, 0.016130163301048533, 0.03249328803004963, 0.060482575957264216, 0.03753251994826964, 0.014271442146439637, 0.04724015761166811, 0.028713274614087174, 0.043568747118115425, 0.05073892844042607, 0.08116359050784792, 0.023967032420582006, 0.08232566993683577, 0.07068300646330629, 0.018843188881874084, 0.021928233161036457, 0.035786985220121484, 0.03976910707673856, 0.04530949817438211, 0.0352812323586217, 0.011460476821022374, 0.061186277839754305, 0.030577230666364943, 0.07236042645360742, 0.04746391471209271, 0.03542849142104387, 0.04773097252473235, 0.04149856391761984, 0.0955950871908239, 0.014685263690937842, 0.018628695480791584, 0.011022102486874377, 0.07206934171595744, 0.04333144645871861, 0.028249097289517522, 0.022400154266506433, 0.046974589183394394, 0.03025438031181693, 0.025350955481241857, 0.031963213080806394, 0.036708639335951636, 0.028101090142237287, 0.019878787687048316, 0.011262378522327967, 0.05036085212071027, 0.048089300082730393, 0.026296782407111356, 0.039690641287182055, 0.022680641983502677, 0.04242845544857638, 0.06242353216345821, 0.03229311341419816, 0.018933342437126806, 0.12579918466508389, 0.1531444037599223, 0.10483129229396582, 0.11745947359928063, 0.051319527107157877, 0.16708068523023809, 0.1886084707719939, 0.08152848628482648, 0.07702976518443652, 0.14858928961413248, 0.1119333758418049, 0.11871244279401642, 0.08737901877611876, 0.07441577009324517, 0.09864700199770075, 0.1667694683585848, 0.17713521713657038, 0.12607826611825398, 0.06235065750245537, 0.16611109940069063, 0.15663037741822855, 0.2334300513778414, 0.2109942367034299, 0.11942227184772491, 0.18125730380415916, 0.08840214780398778, 0.1303515032465969, 0.14435596391558647, 0.08260079553084713, 0.12839392971779617, 0.12897808051535062, 0.12173467847917761, 0.1146618194345917, 0.08704180722790104, 0.09043715574911662, 0.13005762973002025, 0.18082836110677036, 0.03422255827380078, 0.16961185155170305, 0.1371213285518544, 0.15096589922904968, 0.20934241105403217, 0.09047492300825459, 0.14112601509051664, 0.13642078185720102, 0.13091418519616127, 0.1237647466893707, 0.12041427647428853, 0.1403628938964435, 0.28873868925230844, 0.16381697250264032, 0.10832608012216431, 0.11721761657723359, 0.09364567643829755, 0.1535753956330674, 0.11888441070914268, 0.16822701586144312, 0.29249522196395056, 0.15634096866207464, 0.15040606712656363, 0.10597496306789772, 0.1463371640337365, 0.15825536022228853, 0.18831238523125648, 0.0924551324652774, 0.3331203891762665, 0.21149144002369472, 0.7806772834488324, 4.986018189362117, 14.355684399604797, 21.02288133757455, 35.06374372754778, 42.6933000428336, 59.78024400983538, 76.7703127179827, 89.65936006818498, 103.76045812879289, 94.97466250828334, 104.55897290366036, 92.68723215375627, 109.60003689357212, 111.7706332887922, 111.754805292402, 115.54192788260323, 107.58994388580322, 100.29507187434605, 100.14417089734758, 107.41350827898297, 98.56499821799142, 107.2636078425816, 102.77000631604875, 101.35593673161098, 104.54246398380825, 96.06735706329346, 92.95256996154785, 92.38156700134277, 84.91035665784563, 74.10940974099296, 64.83868544442313, 58.350867543901714, 40.12971006120954, 17.765619686671666, 6.024314429078784, 1.2636845111846924, 0.34435934466975077, 0.129987469209092, 0.27997578946607454, 0.16587401926517487, 0.11607371510139533, 0.11280603294393846, 0.13439462200871535, 0.13296420233590261, 0.14525331290704863, 0.08951329639447586, 0.12350809760391712, 0.14466764219105244, 0.09246405520077262, 0.22280945841755184, 0.13460122235119343, 0.20439863204956055, 0.07550840824842453, 0.16605100833943912, 0.08835505747369357, 0.14286770591778414, 0.07753415419054882, 0.10568421759775706, 0.1633060084921973, 0.11908113158174924, 0.11395679440881525, 0.11362932662346534, 0.10725939593144826, 0.13828120274203165, 0.2255767277841057, 0.317869066127709, 0.13714659719594888, 0.17545573439981255, 0.17754829568522318, 0.07704404156122889, 0.11136720622224466, 0.18745635902243002, 0.1217484934521573, 0.12246558283056531, 0.08135223002838236, 0.11882442821349416, 0.1439611922417368, 0.16294844767877034, 0.11091006360948086, 0.25636871478387285, 0.11522786691784859, 0.10338748512523514, 0.1327276107456003, 0.14691817999950477, 0.24195958940046175, 0.16207895933517388, 0.14648849091359548, 0.1712717924799238, 0.05858002483312573, 0.09377550732876573, 0.1441776720540864, 0.11965910771063396, 0.09299935826233455, 0.11894528887101583, 0.09677267793033804, 0.08829314115324191, 0.12256668454834393, 0.1419946349092892, 0.07189643742250544, 0.15713553316891193, 0.1885142493993044, 0.10206326296819107, 0.3623520849006516, 0.09408664956156697, 0.14605817757546902, 0.12742181973797934, 0.09878207117851291, 0.07367834502032825], [0.020026891525568705, 0.01015085504124207, 0.09798182733356953, 0.03515492645757539, 0.06205791713935988, 0.07982516661286354, 0.014583815920299717, 0.047467147931456566, 0.053855059801467826, 0.02746159124321171, 0.03136779520926731, 0.03223304270899721, 0.04084636962839535, 0.03055191452481917, 0.10022554586508445, 0.007892933923618069, 0.019786595134064555, 0.02814785816839763, 0.02560262242332101, 0.03793058930230992, 0.04152452127475824, 0.018967599973880818, 0.027831881373588527, 0.03407688359064715, 0.04236516848738704, 0.07218227708446127, 0.019225670590198467, 0.03970154873760683, 0.010787783988884516, 0.06782661830740315, 0.06411229725927114, 0.05415739125705191, 0.032857213501951525, 0.034705203625240495, 0.021510528699894036, 0.034084880125841925, 0.04209638719580003, 0.01405094625494842, 0.026493657646434646, 0.024551059385495524, 0.08229888815964971, 0.032247400509991815, 0.01502972368949226, 0.026209344688270773, 0.026061100053734014, 0.08318080047943763, 0.08951831755361386, 0.03202060018000858, 0.039706512221268246, 0.06442196707108191, 0.08940369941826377, 0.10289785425577845, 0.06611249635794333, 0.04827401767085705, 0.033089693170040846, 0.07640122462596212, 0.019817268309582557, 0.056801394559443, 0.010427523454252099, 0.11925466012741838, 0.06500866237495627, 0.08548963801669222, 0.051661651248910596, 0.8681840364422116, 0.9591378016131265, 2.4256612913949147, 10.590576308114187, 23.676912546157837, 40.64281715665545, 61.99011162349156, 68.31268746512276, 72.2476885659354, 75.06774003165108, 79.90924480983189, 73.62621116638184, 67.86385468074253, 62.329531124659944, 75.15948404584611, 68.25892925262451, 73.30843530382428, 63.748221261160715, 60.053634779793875, 61.9314410345895, 60.963008063180105, 70.75438172476632, 74.11359255654472, 74.08133901868547, 78.57159846169608, 79.68161487579346, 66.93720817565918, 68.38032123020717, 75.00061348506382, 76.45458657400948, 80.36257307870048, 78.38590090615409, 75.64687238420758, 78.97500392368862, 78.25927693503243, 79.102906363351, 83.09808581215995, 78.16544151306152, 57.8371524810791, 39.922174317496165, 23.268521751676285, 6.433957202093942, 3.783292395727975, 1.2692743369511195, 0.34280582517385483, 0.03696756151371768, 0.06363880873790809, 0.020517099149791256, 0.04146476269566587, 0.030003373245043412, 0.04805668290438397, 0.04564878943243197, 0.01941332284228078, 0.09652925349239792, 0.09880010663930859, 0.07209748056318079, 0.0404405514044421, 0.06155177751289947, 0.04102625265451414, 0.05515107186511159, 0.07915359336350646, 0.02972900082490274, 0.04495884145476988, 0.01747094001621008, 0.02692425766560648, 0.043970490739281685, 0.057634771269346984, 0.06244574061461857, 0.09012777092201368, 0.056793082505464554, 0.03240135671304805, 0.11081955382334334, 0.026775412527578216, 0.06620585599115916, 0.05963238514959812, 0.02361243510884898, 0.03088194038718939, 0.04210853975798402, 0.03782614579956446, 0.06336362207574503, 0.05142487306147814, 0.007221783062310091, 0.034651229557182105, 0.006719744755953018, 0.010503594863361545, 0.028639711240040402, 0.02865090367517301, 0.017903003974684646, 0.018006451727290238, 0.062011939606496265, 0.02149723789521626, 0.031891128913100274, 0.01962518522382847, 0.05283222593633192, 0.03491012120087232, 0.03384017325671656, 0.029074614867568016, 0.057120244950056076, 0.02752636928510453, 0.02722963913609939, 0.01979183342440852, 0.043391659656273465, 0.024509643304294775, 0.0511773400940001, 0.023323121347597668, 0.03651047657643046, 0.060178517630057674, 0.04304819880053401, 0.06363124985780035, 0.03701526252552867, 0.05284630214529378, 0.04047727032697626, 0.03016536669539554, 0.015040113756965314, 0.026140933091353093, 0.0630389227132712, 0.0591229342722467, 0.021239835635891983, 0.11357732369963612, 0.013730477558315864, 0.05985624063760042, 0.0332010136252003, 0.05185801589063235, 0.05597007041797042, 0.05213978773515139, 0.035877233770276816, 0.05737784398453576, 0.058846634812653065, 0.08353467684771333, 0.06104192629988704, 0.025488212937489152, 0.03474838559382728, 0.056224951919700415, 0.025690173796777214, 0.03024818528709667, 0.014342630647921135, 0.0245493409955608, 0.03808694751933217, 0.09239013559584107, 0.05812649202666112, 0.07060927684817996, 0.02630538962382291, 0.017338009917044213, 0.030378681141883135, 0.05573082575574517, 0.028886358719319105, 0.07256933381514889, 0.0329640081285366, 0.04550055667225804, 0.02368965748298381, 0.04116451434258904, 0.01027357658105237, 0.016141354039843594, 0.06204051950148173, 0.03453027729743293, 0.02072832370842142, 0.05482646071219018, 0.03293465470362987, 0.014189196916829263, 0.028243336527209197, 0.02754992462827691, 0.044997887752418, 0.011217367053697152, 0.0507215986560498, 0.02966929313593677, 0.09459657541343144, 0.02040062522116516, 0.06076729603643928, 0.07588249138955559, 0.0230984193871596, 0.021477906432534968, 0.05627407106970038, 0.06416552154613392, 0.04324201215058565, 0.11583168166024344, 0.035808857796447616, 0.9701920598745346, 1.2602235483271735, 4.103442370891571, 13.19676569529942, 28.13103093419756, 48.92914152145386, 70.41262762887138, 76.78125613076347, 83.00356251852853, 83.64392934526715, 90.81474821908134, 82.99607930864606, 81.61401312691825, 74.77819469996861, 87.73537608555385, 81.30775737762451, 83.37473528725761, 75.25398649488176, 74.05180917467389, 77.16185760498047, 74.6952679497855, 83.68958595820835, 87.3411283493042, 89.11189065660749, 91.6562306540353, 97.54829611097063, 82.48988914489746, 80.8275534766061, 82.63614872523716, 90.5396203994751, 90.28278718675885, 89.0995853969029, 87.8477840423584, 88.66299533843994, 89.11699063437325, 90.66613319941929, 96.98101043701172, 92.95648874555314, 73.50381170000348, 50.50725112642561, 28.304060186658585, 9.1823353937694, 3.9563294649124146, 1.1302755155733653, 0.3522131160965988, 0.06024669682873147, 0.027737705802012767, 0.06956680957227945, 0.06537431132580553, 0.011934344473827099, 0.06537982781550714, 0.03145070879587105, 0.08820314026836838, 0.034506525179105144, 0.11144796546016421, 0.08380275246288095, 0.048380785156041384, 0.08184241051120417, 0.0349216257621135, 0.011176421706165587, 0.05834453925490379, 0.02769575367814728, 0.06676338785993201, 0.08148573857865163, 0.029561548560325588, 0.00901322068446981, 0.041650491300970316, 0.03548001597768494, 0.07160982423062835, 0.013712991710885294, 0.03840823724333729, 0.04057146116558995, 0.01938967589688088, 0.01963334291109017, 0.058563570358923504, 0.0384853968529829, 0.01748513157612511, 0.04921964782157114, 0.016136699289615666, 0.04315891196685178, 0.016232506737911274, 0.03482384208057608, 0.01824939949437976, 0.002665161932652284, 0.03182559600099921, 0.012927096337080002, 0.04108943444277559, 0.07693297894937651, 0.04274681729397603, 0.014529516155432378, 0.03372974507510662, 0.02881298872775265, 0.05666896487985339, 0.034247392655483315, 0.025447244689400707, 0.019807877384924462, 0.039581617673060725, 0.06953788362443447, 0.03664645838684269, 0.032914736308157444, 0.033915141198251925, 0.031620865022497516, 0.013274522381834686, 0.028981801455042193, 0.0448686166533402, 0.008182952513120003, 0.06545152861092772, 0.06245624433670725, 0.05672003481803196, 0.021650997323117087, 0.04791335595239486, 0.029410930749561106, 0.028736039463962828, 0.10973749402910471, 0.1196245974195855, 0.1486623678356409, 0.13851582658077988, 0.1586072077708585, 0.16834392744515622, 0.11816174377288137, 0.17544924760503428, 0.15042446899626935, 0.17564862833491393, 0.17588488065770694, 0.1046744624951056, 0.26684665254184176, 0.09771132934838533, 0.1561767631875617, 0.1789408123918942, 0.10597114970109292, 0.091345938055643, 0.15938016772270203, 0.11439382524362632, 0.1267339073653732, 0.15374602004885674, 0.17013344142053807, 0.19057926216295787, 0.09754073885934693, 0.1802467480301857, 0.12111525743135385, 0.16538820176252297, 0.1381968201271125, 0.11650758396301951, 0.1227393988519907, 0.15285777699734482, 0.1428475941398314, 0.10934025927313737, 0.18641609698534012, 0.14010400564542838, 0.20573853515088558, 0.064016379549035, 0.13862232943730696, 0.07540800542171512, 0.15254330315760203, 0.1365050966186183, 0.17249605964337075, 0.0902813912502357, 0.09646592581910746, 0.2198085965854781, 0.18756120625351155, 0.13217518824551786, 0.10257794535053627, 0.11920661984809808, 0.13566866650113038, 0.12588223735136644, 0.2460978387721947, 0.11083469872495957, 0.18857049995235034, 0.2750137985817024, 0.09591279764260564, 0.16419623286596366, 0.08665922882833652, 0.21509108186832496, 0.16621032836181776, 0.2119581771216222, 0.12146074032144887, 1.753057211637497, 1.917152600628989, 6.079357189791543, 18.137923274721416, 37.16485118865967, 61.94402422223772, 85.46388489859444, 94.98864228384835, 98.19234548296247, 98.45798901149205, 104.79760183606828, 97.66355977739606, 93.78312982831682, 83.39513519832066, 99.51893029894147, 92.15856456756592, 95.51699720110211, 85.99880586351667, 82.48720714024135, 81.82905987330845, 83.23021970476422, 93.38762446812221, 99.42128031594413, 98.74107251848493, 102.47564588274274, 102.380907194955, 88.6923167364938, 92.34317125592912, 97.84547056470598, 100.25519616263253, 104.86185182843889, 100.30749525342668, 99.4662699018206, 99.54949542454311, 102.26592145647321, 102.5061901637486, 110.07502964564732, 104.81028924669538, 90.11088875361851, 62.77764824458531, 37.21870667593819, 14.50445488521031, 7.313554848943438, 2.9255457477910176, 1.2645108039890016, 0.17587584257125854, 0.2290017418563366, 0.10383221733250789, 0.23749892732926778, 0.0689617395401001, 0.16568606506500924, 0.13302054788385118, 0.1378454475530556, 0.1406355564083372, 0.23951184217418942, 0.18191473638372763, 0.14192147526357854, 0.14500296062656812, 0.1744233297982386, 0.1451429831130164, 0.13615970872342587, 0.0861053406926138, 0.12515906829919132, 0.11453874675290925, 0.14813863379614695, 0.12995127615119728, 0.14259686187974044, 0.19466420582362584, 0.23980344938380377, 0.1156619121985776, 0.09019566513597965, 0.17567642112927778, 0.1702082431209939, 0.17827616019972733, 0.1898360356156315, 0.08627299991037164, 0.09541984873690776, 0.11180904108498778, 0.1436575342501913, 0.17192865509007657, 0.14205592019217356, 0.13639558106660843, 0.11591712278979165, 0.11619894552443709, 0.14930499478110246, 0.05352051489587341, 0.13962699552731855, 0.2373199840741498, 0.1302804606301444, 0.19545019364782742, 0.19759920904678957, 0.20146356097289495, 0.16056938176708563, 0.145347018593124, 0.14422203467360564, 0.10749886451022965, 0.06776004045137338, 0.17468121381742613, 0.18451599537261895, 0.12030664724963051, 0.11846147983201913, 0.14534644862370832, 0.1449746521455901, 0.12611175860677445, 0.16101736415709766, 0.17412865561033997, 0.2398022280207702, 0.18378704520208494, 0.18088803147631033, 0.09415160571890217, 0.1423582211136818, 0.13480472857398645, 0.22955884624804768], [0.07333732689065592, 0.061360708836998255, 0.03722140485686915, 0.01941776555031538, 0.01708721828513912, 0.0061490013862827, 0.020215329181935107, 0.043004748810614855, 0.03376527995403324, 0.04323385615966149, 0.014185587110530053, 0.025516088852392774, 0.07271815690078906, 0.05593997060454317, 0.015638827612357478, 0.05133184930309653, 0.027286469836586287, 0.04881951232839908, 0.054946327315909524, 0.035802381179694615, 0.045993715923811705, 0.018511922996757284, 0.01857654158292072, 0.0788261934316584, 0.04995698807761073, 0.07005727503980909, 0.06052652467042208, 0.054980990277337174, 0.04183804177279983, 0.019268028138737594, 0.010656437420818423, 0.016227421117946506, 0.039591419111405096, 0.039463891847325225, 0.018177953149591173, 0.03555538425488131, 0.04257532774603792, 0.029130658467433283, 0.09252348808305604, 0.0399417840609593, 0.06011896939682109, 0.061919095659894605, 0.05351691526759948, 0.09702779352664948, 0.027280027146584222, 0.06511877503778253, 0.013185139811996902, 0.03388438320585659, 0.014734542296667184, 0.025455056323802898, 0.08459765623722758, 0.06338002905249596, 0.05828028877398797, 0.01640164855468486, 0.03735173447057605, 0.03660523399178471, 0.044283261456127675, 0.09195871624563422, 0.09050500246563128, 0.04075679961325867, 0.2293693721294403, 1.1187636532953806, 12.236806920596532, 24.83721307345799, 33.86053112574986, 56.83514928817749, 72.35157108306885, 69.79678794315883, 54.80341611589704, 72.45724623543876, 72.77921186174665, 68.04508454459054, 59.689729826790945, 55.714248520987375, 49.72208731515067, 43.461187158312114, 37.016816343579976, 49.681492464882986, 54.70169448852539, 48.44723183768136, 42.83301789419991, 31.123680864061626, 32.1393963268825, 38.68444653919765, 39.404620374952046, 44.600882802690776, 41.20434972218105, 45.60809367043631, 32.2613719531468, 33.51948922021048, 44.54622132437569, 50.38353497641427, 46.517786570957725, 49.23814875738961, 55.102021898542134, 64.7187317439488, 48.016603333609446, 59.12896156311035, 53.368564469473704, 59.71263803754534, 65.26813275473458, 69.50281660897392, 81.19295924050468, 70.01964446476528, 58.72627871377127, 38.01998683384487, 23.618636267525808, 18.39264076096671, 10.191458753177098, 3.6923647948673795, 0.5477820262312889, 0.031526389199176004, 0.0419586445870144, 0.026560574769973755, 0.051864848738270145, 0.04952152465869274, 0.036574109590479305, 0.030645956085728746, 0.04181555172960673, 0.012827721490923847, 0.09935003213052239, 0.14048315744314874, 0.061308685557118485, 0.033949766840253554, 0.01231582703933652, 0.03962635009416512, 0.12516115818704876, 0.021687655177499567, 0.0541307384015194, 0.027829392846407633, 0.10823183839342423, 0.018424013696078743, 0.10782959604901926, 0.03362279777814235, 0.0454376700467297, 0.05912474596074649, 0.04744801663660577, 0.03273290249386004, 0.04813102659370218, 0.00568513576373724, 0.008111572325495737, 0.021421664361176745, 0.08085550846798079, 0.07891870489610092, 0.04922467915873442, 0.04855492099055222, 0.031224512362054417, 0.04798446981502431, 0.029366035480052233, 0.08441810230059282, 0.04135514197072812, 0.08567651334617819, 0.010718926255192076, 0.035801227670162916, 0.012791201039882643, 0.04536630851881845, 0.05639387660526803, 0.032121630651610236, 0.010796005288804216, 0.10856829676777124, 0.05543417703094227, 0.0416237400578601, 0.019418145529925823, 0.041194173108254156, 0.09405368633036103, 0.04978864693215915, 0.06626983505806752, 0.05870123832885708, 0.022738244517573288, 0.04995612633813705, 0.03672101242201669, 0.03514681117875235, 0.025457156389685612, 0.024309353337490132, 0.06914396011935812, 0.021098081188808595, 0.05331717152148485, 0.06844723357685975, 0.09739238396286964, 0.016231970695246543, 0.03356763966647642, 0.040216142910399606, 0.0070712831470050985, 0.02870740867885096, 0.024024633258315067, 0.0410836567170918, 0.03789541404694319, 0.004984571681624013, 0.044815063276993375, 0.023489672856937562, 0.049367083303098164, 0.02735816384665668, 0.03909521323761769, 0.04037265719047614, 0.0389268788775163, 0.052065430475132804, 0.0742359243865524, 0.03741291118785739, 0.02731075630124126, 0.07857946452817746, 0.04432724070336137, 0.037782787411872826, 0.02964861478124346, 0.00556787388632074, 0.04696131703842964, 0.042278651879834275, 0.05357267388275691, 0.027360677818900773, 0.05670873381729637, 0.030235140451363156, 0.0435948130408568, 0.017691967709522163, 0.05569603726533907, 0.03238010499626398, 0.015320180782249995, 0.04063546058854886, 0.048352707376969714, 0.05431720321731908, 0.09348003925489527, 0.03958763288600104, 0.040944987908005714, 0.07518206004585538, 0.05514797096007636, 0.043926158653838296, 0.015084875015808004, 0.07677476493907825, 0.01738358032889664, 0.03637589933350682, 0.06372805644891091, 0.08313243450330836, 0.025855069680671607, 0.04019804638145225, 0.06120181629168136, 0.03625689446926117, 0.07204275671392679, 0.0312743711152247, 0.595261455646583, 1.75314938383443, 15.147653102874756, 31.146533489227295, 43.599762031010215, 64.5672332218715, 84.60003621237618, 80.8642052241734, 65.86621979304722, 84.6954836164202, 82.97809737069267, 79.03602300371442, 74.09902913229806, 68.03000695364815, 63.29025159563337, 61.9953853062221, 49.85291494641985, 66.5096160343715, 73.10072585514614, 62.348458017621724, 60.09754739488874, 46.37763793127877, 49.79663453783308, 55.18083184106009, 53.25517334256853, 63.96100984300886, 62.6526848929269, 63.27868284497942, 44.567052023751394, 46.804260798863, 58.142216614314485, 67.45042991638184, 62.15250492095947, 63.596583775111604, 63.87018993922642, 80.95421913691929, 59.92415509905134, 72.54718371800014, 64.13089329855782, 69.96437849317277, 75.51790687016079, 79.25599602290562, 91.5244928087507, 83.23219994136265, 68.18785612923759, 44.879814761025564, 28.183385610580444, 20.258926902498516, 11.222924045154027, 3.622468522616795, 0.31045788952282494, 0.09844553137996367, 0.02352606438632522, 0.05858451673494918, 0.0424596205619829, 0.04355990241414734, 0.04961769003421068, 0.04798354361472385, 0.027676222047635486, 0.028327322199142406, 0.07845340629241296, 0.16572616648461136, 0.09173755454165594, 0.06230957220707621, 0.04059520310589245, 0.04378652632502573, 0.03381097589486411, 0.057520621323159764, 0.016734973793583255, 0.09608785967741694, 0.07248001825064421, 0.005109648586117795, 0.04307018333513822, 0.05942997136818511, 0.04907832933323724, 0.02091481227294675, 0.027954704693651626, 0.013457956690607327, 0.05386871871139322, 0.05672791939494865, 0.015624473204037972, 0.009137098278318132, 0.03450910361217601, 0.05758791842630931, 0.1241952907294035, 0.023505112921286906, 0.04509258070694549, 0.023417415662801692, 0.04067411333588617, 0.063545476246093, 0.024220935135547603, 0.04522475254322801, 0.056257894794855795, 0.03514194608266864, 0.0964166098939521, 0.03430765674316457, 0.017412073710667234, 0.030302362915660654, 0.02046420395241252, 0.06932498647698335, 0.041100542061030865, 0.04751903211165752, 0.04793943544583661, 0.0485401696392468, 0.052428623129214556, 0.013051519303449562, 0.09695974324962922, 0.031555708697331805, 0.0957351503893733, 0.07211787732584135, 0.037432130692260604, 0.03456747458715524, 0.010603035018513245, 0.054566503768520694, 0.07494630305362598, 0.016536872102213756, 0.11937976841415678, 0.12249501767967429, 0.1318130541060652, 0.1626465945903744, 0.19622763193079404, 0.12221262497561318, 0.13769185436623438, 0.06612812301942281, 0.11844432646674768, 0.19614284219486372, 0.10665051931781427, 0.1674108196582113, 0.16216355908129895, 0.10275152817900692, 0.13581181024866446, 0.1887839806399175, 0.12029769058738436, 0.17914442718029022, 0.19642906183643, 0.18998075356440886, 0.11715198867022991, 0.12526840743209633, 0.11688278668693133, 0.182819698538099, 0.11169836523809604, 0.12972517471228326, 0.16439146096152918, 0.14956392374421867, 0.1661111536834921, 0.19688482023775578, 0.08721510507166386, 0.13448597996362618, 0.13541055178003653, 0.2351954909307616, 0.133303985531841, 0.10965632767017398, 0.09773555304855108, 0.15471718007964746, 0.20123572248433316, 0.1627778775457825, 0.2130494921335152, 0.17024622751133783, 0.14336454282913888, 0.1767792169536863, 0.13043747363345964, 0.12359773207988058, 0.20210564509034157, 0.15677206910082273, 0.1306798192007201, 0.16586012286799295, 0.17428262877677167, 0.11550119439406054, 0.1945177372545004, 0.2825614964323384, 0.16960723751357623, 0.10841851694775478, 0.14576122350990772, 0.1886242806379284, 0.25797141449792044, 0.14303136856428214, 0.9994137947048459, 3.178722905261176, 19.05638827596392, 38.47867216382708, 53.76470906393868, 77.14413275037492, 98.22001320975167, 93.66135569981166, 79.0353490284511, 95.42683737618583, 92.78327710287911, 87.6211268561227, 79.79247338431222, 76.1557515008109, 68.32611833299909, 62.586635317121235, 55.46423496518816, 70.62349850790841, 76.95980398995536, 67.83618000575474, 58.93107686723982, 47.58365065710885, 51.47308547156197, 58.67558465685163, 58.296185220990864, 64.25244508470807, 62.96645164489746, 66.14259134020124, 51.073682171957834, 51.83671249662127, 68.29161357879639, 71.07552746364048, 67.64311735970634, 72.22519029889787, 78.29617881774902, 85.3063553401402, 68.837450163705, 81.80632536751884, 74.61885860988072, 82.71856130872453, 86.54742867606026, 89.88815729958671, 105.33726147242955, 95.56132670811245, 81.68465546199253, 56.38555220195225, 37.53048971721104, 26.99842940058027, 16.087303161621094, 6.468059395040784, 1.6264391030584062, 0.44955116297517506, 0.09374989941716194, 0.18689275426524027, 0.19992925758872712, 0.19076629355549812, 0.17619742745799677, 0.1373977501477514, 0.14422469453087874, 0.11418478217508111, 0.29225363635591095, 0.22687087048377308, 0.19120831840804645, 0.1678509988955089, 0.1981535450156246, 0.09164669870265893, 0.11696788854897022, 0.2260415514132806, 0.1250405960849353, 0.14233553090265819, 0.17708410987896578, 0.12158088173185076, 0.15973847492464952, 0.09982399562639849, 0.1443781927227974, 0.09339959892843451, 0.14631520664053305, 0.1879179256835154, 0.09337856434285641, 0.12708370573818684, 0.12531583702989987, 0.0568012418890638, 0.13953706249594688, 0.18958680970328196, 0.21984879299998283, 0.12733970343002252, 0.18614449298807553, 0.16554906884474413, 0.12024001511079924, 0.25879002628581865, 0.20414811692067555, 0.15608900146824972, 0.1770800929516554, 0.10486098498638187, 0.11852420360914298, 0.11026677848505122, 0.13274747825094632, 0.1750165322529418, 0.10086832887360028, 0.25783008922423634, 0.1394544576427766, 0.14822621909635408, 0.1213435030409268, 0.12494686325745923, 0.175198868183153, 0.094070568281625, 0.17685856483876705, 0.11697510816156864, 0.1583526621439627, 0.2457779502230031, 0.15766607969999313, 0.14793800456183298, 0.10591458702193839, 0.20316117416535104, 0.22587507963180542, 0.19267566395657404], [0.06020738250975098, 0.036305246874690056, 0.037722309585660696, 0.0525650052752878, 0.025927864613809755, 0.012512373189175767, 0.02548257600782173, 0.04961723541574819, 0.0441830927239997, 0.07092636304774455, 0.03130420290731958, 0.01869384671694466, 0.0073539294535294175, 0.0261998672503978, 0.008818772904175733, 0.006399360876197794, 0.06731448721672807, 0.06249262738440718, 0.029147594701498747, 0.028895559654171978, 0.03140165410669787, 0.017409771780616472, 0.02821899238707764, 0.024711439618840814, 0.04148083379758256, 0.024712586343022327, 0.06500389905912535, 0.0637311777099967, 0.02147284965030849, 0.04214637826329895, 0.02928719310356038, 0.019239992768104588, 0.019858940537752848, 0.027348406513088515, 0.016769819959465946, 0.0728265732260687, 0.06066541400338922, 0.03243391960859299, 0.12125314931784358, 0.04497717207829867, 0.028332984573873024, 0.07917624964777913, 0.02362483024730214, 0.038436786604246924, 0.04646620021334716, 0.06869538740387984, 0.010234934859909117, 0.05169415646897895, 0.032810971340430636, 0.027171218967331306, 0.006580963988588857, 0.03478107741102576, 0.0455657367461494, 0.03661982588736074, 0.07917221236441817, 0.12187863646873406, 0.12022173537739686, 0.43197610176035334, 1.657241770199367, 11.225420185497828, 18.283137151173182, 35.0195323399135, 57.01933561052595, 66.62689467838833, 70.80892508370536, 82.00715609959194, 69.33192566462925, 62.19628552028111, 50.18297174998692, 50.04034955160958, 51.697477545057026, 40.94272920063564, 23.636032819747925, 31.350417954581125, 20.915111303329468, 17.079537187303814, 16.406967197145732, 18.481313671384537, 27.01890574182783, 28.879737547465734, 18.85005283355713, 15.364079066685267, 12.634388055120196, 18.19568886075701, 22.70024769646781, 16.951004198619298, 15.882353884833199, 18.26703643798828, 27.70401896749224, 27.741666044507706, 17.10855633871896, 11.138218556131635, 14.485514964376177, 20.955157245908463, 24.5286922114236, 18.535487038748606, 23.950456176485332, 32.515408515930176, 44.803419317517964, 54.51762975965227, 67.99834401266915, 70.27102334158761, 70.76183714185441, 62.65357426234654, 67.8312120437622, 69.01577568054199, 69.65972777775356, 62.949518884931294, 51.81130640847342, 36.43537718909127, 19.240402630397252, 12.807980980191912, 3.96853050163814, 0.28772810633693424, 0.21256898077470915, 0.04176304668986371, 0.056510713550129106, 0.043842027096876075, 0.033926333633384535, 0.015701549693143795, 0.027338908719164983, 0.03672172149111118, 0.05956911854445934, 0.04837256470429046, 0.039852746695812256, 0.05840271006205252, 0.03633464779704809, 0.023398381059191058, 0.02336224906944803, 0.007364942925050855, 0.022922375172908818, 0.044875473249703646, 0.07360876803951603, 0.04785477463155985, 0.040492924129856486, 0.03752358024939895, 0.030232032760977745, 0.03278188254418118, 0.003812111515019621, 0.04528687920953546, 0.040697617788932154, 0.04263713210821152, 0.058952818757721355, 0.021088215289637446, 0.012246233095148844, 0.06589631510100194, 0.037582897780729194, 0.039319245144724846, 0.040162447041698864, 0.043233354043747695, 0.05261370712625129, 0.0439054192309933, 0.0952781502689634, 0.052048653696796725, 0.04143809966210808, 0.030414419581315348, 0.02136116278623896, 0.04682236663731081, 0.0029157192579337527, 0.04423228990552681, 0.030722793391240493, 0.05320471112749406, 0.0736101929630552, 0.06281774743859257, 0.016847094920064722, 0.04365173873624631, 0.026390666208629097, 0.02236812741362623, 0.04184133266764028, 0.05228697555139661, 0.03633848151990345, 0.036511514735008986, 0.029274212728653635, 0.012819268640929034, 0.04811161370681865, 0.0517304275584008, 0.06188890763691493, 0.022007901653913513, 0.04800206083538277, 0.022344448237812946, 0.057207443485302586, 0.040269496118915935, 0.027771389976676022, 0.019782503567902104, 0.09544921573251486, 0.06851579275514398, 0.05935521037983043, 0.04066436618034329, 0.019795158245999898, 0.015504079039341636, 0.02536939297403608, 0.020962333472977792, 0.0922975427071963, 0.07260690429913146, 0.041649174943034134, 0.06991362239101104, 0.048505974866982014, 0.03833661787211895, 0.047340509548251114, 0.06066442334226199, 0.022620428785947815, 0.050538004043379, 0.07038681914231606, 0.09743966428296906, 0.030499107536992857, 0.04607232081304703, 0.02369139962164419, 0.050551279581018856, 0.04349722274179969, 0.04708236429308142, 0.02676373833258237, 0.02353331962201212, 0.06862235667982272, 0.06298742869070598, 0.12913149728306703, 0.05538518340992076, 0.040406617868159495, 0.020595436017694216, 0.0638730525970459, 0.05898917466402054, 0.02621984332134681, 0.05492140133199947, 0.09659786695348364, 0.06039419677108526, 0.04585935241941895, 0.06924140453338623, 0.014366981573402882, 0.07642529904842377, 0.03424161492979952, 0.051563324739358256, 0.10532695533973829, 0.17344375593321665, 0.13392206308032784, 0.31847247374909265, 2.2356013527938297, 13.171720913478307, 21.556480407714844, 41.9434608731951, 71.15791920253209, 81.02850927625383, 82.68184702736991, 91.03450584411621, 78.25303745269775, 72.5321478162493, 59.61695439474923, 59.867311886378694, 64.99891090393066, 52.347158432006836, 36.14215973445347, 41.130323614392964, 35.46007244927542, 32.90111691611153, 26.256985391889298, 36.32189226150513, 43.20460755484444, 36.36694785526821, 27.56346559524536, 27.300458908081055, 25.903777190617152, 33.621005875723704, 32.310134410858154, 31.969554560525076, 31.123576641082764, 33.384853976113455, 35.920963832310264, 39.263075147356304, 32.10110827854702, 28.12148063523429, 27.604129927498953, 36.13695205960955, 41.82031447546822, 34.12884971073696, 34.86523369380406, 47.5790752683367, 58.27902317047119, 66.21861852918352, 75.78004850660051, 79.7728169304984, 81.79127556937081, 72.54587745666504, 77.64019938877651, 78.60091291155133, 79.4320147378104, 71.80635288783482, 58.82375499180385, 41.88986941746303, 20.586788075310842, 14.4094443491527, 3.4581957374300276, 0.20577851443418435, 0.10510312699313674, 0.012248095673775035, 0.03257594716602138, 0.050909590175641437, 0.05297954606690577, 0.060492977899100096, 0.02274550823494792, 0.026942077691533735, 0.03517081096236195, 0.03840965538152626, 0.042128183346773894, 0.03594890742429665, 0.027787401706778576, 0.06034686216818435, 0.03429381123610905, 0.1147381274827889, 0.014498744592336672, 0.01992670413372772, 0.09898259863257408, 0.027075226618243114, 0.027744592932452048, 0.03335744308839951, 0.024262687091582587, 0.024682561168447137, 0.026930093066766858, 0.03919115808925458, 0.0731400428339839, 0.04298041993752122, 0.08186474788401808, 0.03176396466525538, 0.05634669128007122, 0.024284868401342204, 0.03612078034452029, 0.07562859037092753, 0.039919684175401926, 0.022680821795282618, 0.03177437339244144, 0.010496603408163148, 0.045714186637529304, 0.05775898388986077, 0.0626094371878675, 0.02144697541370988, 0.035324743416692526, 0.011833348777145147, 0.03730485787881272, 0.022442973218858242, 0.030347322645996298, 0.02539562513785703, 0.07527491756315742, 0.1109638035829578, 0.08903636091521808, 0.07415009649204356, 0.04792974257309522, 0.0683787761788283, 0.07569972119693245, 0.07115365870829139, 0.04379652114585042, 0.05572160446484174, 0.04523883214486497, 0.017425434065184424, 0.02391177083232573, 0.05107794489179339, 0.13260679080017976, 0.1646227464079857, 0.08623262029141188, 0.11182205538664546, 0.09642943420580455, 0.15614487204168523, 0.10527648590505123, 0.048900705828730545, 0.20274987337844713, 0.19080036958413465, 0.1309220019195761, 0.1066479001726423, 0.08507742799286332, 0.11275238118001393, 0.15681017562747002, 0.1519664262554475, 0.21688081297491277, 0.1437911106539624, 0.17972993504788193, 0.12792415278298513, 0.17660192932401383, 0.1830830651202372, 0.2400935095335756, 0.12847300618886948, 0.13901545905641147, 0.1426773497036525, 0.1029598791418331, 0.2523986878139632, 0.20744704561574118, 0.07959147236709084, 0.07545254446033921, 0.1205116869615657, 0.14105219048048767, 0.12153585414801325, 0.09016336686909199, 0.1765035010342087, 0.19566048522080692, 0.18241549522749015, 0.2898367760436875, 0.139875271490642, 0.15644496093903268, 0.09256781677582435, 0.10461165729377951, 0.16231773580823625, 0.1506146759326969, 0.1847073965306793, 0.20293697262448923, 0.16332196763583592, 0.1266979585800852, 0.12477393182260649, 0.08531713405890123, 0.23729183844157628, 0.2157435611422573, 0.16685747435050352, 0.2287204483790057, 0.2976784424058029, 0.29119596311024254, 0.6038661482078689, 3.9978644933019365, 18.06552825655256, 28.878130776541575, 53.92177309308733, 83.45847497667584, 96.51559230259487, 97.00091007777623, 103.61693613869804, 87.70892429351807, 82.54701028551374, 71.1041123526437, 72.16969503675188, 72.049241065979, 58.199817180633545, 40.60194785254342, 49.16148233413696, 36.541517870766775, 29.999021121433803, 31.135048116956437, 32.777730805533274, 42.61717905317034, 47.01321397508894, 30.82035378047398, 29.864656857081822, 24.544846773147583, 34.24365132195609, 38.04463904244559, 29.115095615386963, 24.99329219545637, 31.98063346317836, 43.59259149006435, 44.10874884469168, 31.046069485800608, 23.167776346206665, 29.79956613268171, 37.180369990212576, 42.81983368737357, 30.777556351252965, 35.522366523742676, 50.415236132485525, 64.23239258357457, 75.19785894666398, 86.53522763933454, 88.99988569532121, 91.05632318769182, 84.11757414681571, 88.07901314326695, 89.64207295009068, 93.7038995197841, 84.29949188232422, 71.68090316227504, 51.79406097957066, 31.24606990814209, 21.48352779660906, 7.6024965558733255, 1.2012919677155358, 0.3921070396900177, 0.12383911412741457, 0.24081525366221154, 0.14028776649917873, 0.1544317068266017, 0.11063195924673762, 0.05863232631236315, 0.12850846642894403, 0.21766009687313012, 0.26933568183864864, 0.10960853166346039, 0.12039355401481901, 0.24874086837683404, 0.13917138640369686, 0.13677288724907807, 0.17449355817266873, 0.10874004755169153, 0.14307251492781298, 0.21464106387325696, 0.12985119223594666, 0.24649866297841072, 0.09840035451842205, 0.11890954364623342, 0.13289320043155126, 0.1141459292599133, 0.23741872449006352, 0.15343002629067215, 0.08619708541248526, 0.14755123960120337, 0.15917321454201425, 0.22066595272294112, 0.16431074243571075, 0.11209386294441563, 0.17558969078319414, 0.12844753398426942, 0.15124873976622308, 0.13425173610448837, 0.12797958909400872, 0.20008157512971333, 0.24455037180866512, 0.11847574263811111, 0.09152009085352932, 0.2330217090036188, 0.1193684097379446, 0.11196897178888321, 0.18811546079814434, 0.1313337641102927, 0.11590874966766153, 0.2104064489581755, 0.22486225755086967, 0.13991290304277623, 0.1630475680742945, 0.12807442114821502, 0.1098828362300992, 0.26599669243608204, 0.16517556245837892, 0.11306473120514836, 0.19758973669792923, 0.1283672090087618, 0.11262795142829418, 0.09452414180019073, 0.12655888604266302], [0.017752627043851783, 0.02560684969648719, 0.007702773636473077, 0.029447398614138365, 0.026414348777117472, 0.02357951089340661, 0.019999516030241336, 0.06924515683203936, 0.0767795689670103, 0.04375010256522468, 0.042831196516220055, 0.08246238795774323, 0.023303055370758687, 0.029060548836631433, 0.037850281290177784, 0.02891205484047532, 0.004185343942871051, 0.018012974145156995, 0.07151538572673287, 0.031234547894980227, 0.040874125103333166, 0.024425201317561523, 0.05099448847717472, 0.038991770574024746, 0.018305834948218296, 0.02218915192809488, 0.027161775456209267, 0.03274210003603782, 0.04849354749811547, 0.02999039626281176, 0.013917665013910403, 0.052483937303934775, 0.026229992508888245, 0.08565935998090676, 0.016197221220604012, 0.029370245789842944, 0.023497280930834155, 0.031177408461059843, 0.047335125372878144, 0.03155775787308812, 0.013036837501983558, 0.026411731328283037, 0.040890674572438, 0.02427602030469903, 0.07901984732598066, 0.03929371865732329, 0.034411157082234106, 0.06957509448485714, 0.014046774112752505, 0.05853243238691773, 0.0420860632854913, 0.01598636307088392, 0.001671726445368092, 0.3329125946121556, 0.7353114634752274, 2.762461538825716, 6.038588634559086, 13.935153365135193, 31.834867204938615, 48.15932628086635, 64.8063485281808, 68.70300252096993, 73.32850864955357, 68.95065021514893, 66.43292876652309, 64.61513410295758, 71.21703447614397, 45.33326114927019, 32.66494069780622, 33.9614919253758, 23.642826420920237, 25.45784875324794, 21.83622009413583, 17.14931447165353, 16.936341762542725, 33.662476199013845, 45.50038269587925, 38.35994482040405, 37.484787940979004, 44.543341296059744, 57.1641777583531, 59.32254532405308, 58.14381469999041, 60.61989906855992, 39.90957028525216, 52.55790771756853, 56.65991571971348, 57.81780522210257, 41.81568002700806, 38.259282793317524, 40.36065428597586, 34.90948677062988, 27.723866496767315, 17.932657854897634, 19.559403112956456, 26.98006010055542, 32.79111303601946, 20.544466597693308, 24.10714152881077, 29.413194179534912, 40.57726437704903, 36.392319202423096, 50.29804086685181, 50.6715030670166, 53.282194886888774, 57.43740177154541, 60.471186774117605, 65.97922529493059, 66.20277663639614, 72.3505219050816, 67.35348864964077, 47.31200041089739, 27.233137811933243, 17.255644491740636, 7.652308191571917, 1.5329529366322925, 0.40889432174818857, 0.0717449951916933, 0.05721474452210324, 0.07008917297103576, 0.012380839175810772, 0.03337033186107874, 0.03895435954577156, 0.010167164478584059, 0.031257183823202334, 0.02672394734275128, 0.016198462939688137, 0.02340564986557833, 0.01729341659561864, 0.006496400713721024, 0.02656797589068966, 0.05358568818441459, 0.018586273471425687, 0.044575252038027556, 0.03860404548634376, 0.021047949325293303, 0.03539148751380188, 0.06714526058307715, 0.05958103361938681, 0.02534177150976445, 0.022811914760885493, 0.05202675397906985, 0.019611224365819777, 0.08331396297684737, 0.05063341624502625, 0.0428233933635056, 0.03142855462751218, 0.02797600221154945, 0.0705368568056396, 0.02418758174670594, 0.04766601297472205, 0.015315678702401263, 0.026052592920937707, 0.1466922956917967, 0.04589921974443963, 0.012905051582492888, 0.0204928533972374, 0.0561212887322264, 0.046558012786720476, 0.06855098158121109, 0.03335317171045712, 0.047269911372235844, 0.07085011606769902, 0.051439855114689896, 0.03814405302650162, 0.031212302124393836, 0.01831686792762152, 0.04111666066039886, 0.027229825733229518, 0.049361271650663445, 0.003506662615109235, 0.09589890803077392, 0.08946214842477015, 0.02190048956046147, 0.03418331520099725, 0.0059545095012124094, 0.04781582332881434, 0.0173566933787827, 0.04720367956906557, 0.014619033584105117, 0.033673928784472604, 0.023748659495530382, 0.08125254644879273, 0.049979311879724264, 0.08873437211981841, 0.0557932136580348, 0.020577977311664393, 0.07960131791021142, 0.03789504424535802, 0.05137719240571771, 0.03692539395498378, 0.07788978117917265, 0.005581418717546123, 0.023315723619556854, 0.02988263811650021, 0.015483034275738257, 0.042110307341707606, 0.05106950730883649, 0.07941187771835498, 0.03068039513060025, 0.019101751436080252, 0.036567934921809604, 0.005095040575335068, 0.030665535213691846, 0.03565756145066448, 0.021052490420905606, 0.03675498327772532, 0.044064498373440335, 0.011769317123772842, 0.06056026143154927, 0.07488107548228332, 0.009595209499821067, 0.013728823629207909, 0.013586217620676118, 0.03442480920680931, 0.021782631420397332, 0.0064956882519514435, 0.1041628403056945, 0.04159930940451367, 0.06950053027165787, 0.031358268577605486, 0.018207240417333584, 0.03252222415591989, 0.07604299206286669, 0.02567822140242372, 0.03650968947580882, 0.07350147808236734, 0.056270471441426446, 0.04250332839520914, 0.16934564869318688, 0.7866807984454292, 2.5388743707111905, 5.690862996237619, 16.276490449905396, 37.11744710377285, 60.41968672616141, 78.37515204293388, 85.61885057176862, 84.2108815056937, 82.8197409766061, 79.58876609802246, 79.18258135659354, 82.12667901175362, 63.6030455998012, 45.23059456689017, 48.279269559042795, 37.2197072165353, 30.706413745880127, 27.667118821825298, 25.137052161352976, 25.63803812435695, 34.484691279275076, 38.35348994391305, 38.44755118233817, 40.029621260506765, 47.929830755506245, 43.63376651491438, 35.26005465643746, 36.58363785062517, 42.36305563790457, 37.4143123626709, 38.091893741062705, 39.2530905859811, 42.88516412462507, 42.65331315994263, 41.09130947930472, 37.27708544049944, 27.46153552191598, 25.64636206626892, 25.502039296286448, 26.856290102005005, 28.710931062698364, 43.31838083267212, 34.73439564023699, 31.034750870295934, 45.79291922705514, 59.68066242762974, 53.80169085093907, 62.65770844050816, 63.09903022221157, 61.64187485831124, 66.60255513872418, 69.52408504486084, 73.42918804713658, 76.74201965332031, 82.05649525778634, 76.3300679070609, 53.5717819077628, 31.066406863076345, 18.05944163458688, 8.917873059000287, 1.7720858305692673, 0.4139258489012718, 0.03639968537858554, 0.04944845322253449, 0.04134364080216203, 0.019993773927646022, 0.08061213831284217, 0.03941872516380889, 0.0201695959216782, 0.026824506232514977, 0.014569502224081328, 0.04626021733773606, 0.060727045339133055, 0.06239126782332148, 0.045868471930069585, 0.006242415302300027, 0.06066694749253137, 0.07231258294944252, 0.08216827016855989, 0.03807959219973002, 0.04074537647621972, 0.007403587190700429, 0.043772714744721136, 0.011300457907574517, 0.024284663144499063, 0.0435096704667168, 0.04164859479559319, 0.03556881246290036, 0.03704047349414655, 0.003471166963988383, 0.004668767913244665, 0.07113812704171453, 0.015615854112963592, 0.04671721067279577, 0.05746054383260863, 0.019236041997958506, 0.058697927077966075, 0.08011317080152885, 0.03975102072581649, 0.034660722262093, 0.03231243130617908, 0.015815368853509426, 0.03983050771057606, 0.010358831961639225, 0.022915944357269576, 0.03725058186267104, 0.023626760679430196, 0.01603769085236958, 0.050690050170357735, 0.04136510965015207, 0.019175905135593245, 0.02519566934954907, 0.016904341223250543, 0.050034422493938885, 0.08903758906360183, 0.049514932690986564, 0.07365540375134774, 0.04491715565589922, 0.04275471883426819, 0.01408792641346476, 0.012604916035862905, 0.07974151003041438, 0.11357644838946206, 0.12944624253681727, 0.10864757001399994, 0.07262382017714636, 0.14535309826689108, 0.1448788565716573, 0.14919503139598028, 0.1787878977400916, 0.15550647915474006, 0.14319998451641627, 0.1875721849501133, 0.11693047412804194, 0.12178144311266285, 0.12379654284034457, 0.1658655647188425, 0.09184422024658748, 0.09245887119323015, 0.13951996341347694, 0.11350253556988069, 0.13549509724336012, 0.203207382400121, 0.20133417791553906, 0.08280791155993938, 0.1753960640302726, 0.09960336996508495, 0.11426470002957753, 0.13154472064759049, 0.16657380600060734, 0.19473684978272232, 0.10707619826176337, 0.12160232343844005, 0.12545191044253962, 0.18665346210556372, 0.12939384606267723, 0.1114771356806159, 0.2563538412962641, 0.14989152045122214, 0.13392431581658976, 0.20591316292328493, 0.19810660396303448, 0.22210864030889102, 0.16648133524826594, 0.13702038968248026, 0.20969043166509696, 0.10968135204166174, 0.13307554993246282, 0.24131546967795917, 0.15970863295452936, 0.12878695077129773, 0.13260338455438614, 0.16337561261441025, 0.10311195919556276, 0.4678194969892502, 1.2418411118643624, 4.383320152759552, 8.75147933619363, 22.046550750732422, 50.662227221897666, 73.58044338226318, 95.48385429382324, 97.7162618637085, 99.37667288099016, 89.70110484531948, 88.97734573909214, 86.20042174203056, 94.54141453334263, 64.95844459533691, 55.15690571921212, 54.96076154708862, 39.32666506086077, 41.76847743988037, 36.97345611027309, 33.39768035071236, 29.370580877576554, 48.87290975025722, 64.8352460861206, 51.284535680498394, 54.69470112664359, 62.664906774248394, 78.92435155596051, 80.10558005741665, 77.48163454873222, 78.15529019492013, 59.685039792742046, 72.9484977722168, 77.67559351239885, 79.14416476658413, 57.366995675223215, 55.48330429622105, 54.94908857345581, 49.90716300691877, 41.69415603365217, 34.51326922007969, 30.12352589198521, 40.28150388172695, 47.73965508597237, 35.474274567195344, 37.44143812997, 43.8610212462289, 57.85756976263863, 52.02954585211617, 69.68993854522705, 69.56532260349819, 73.69094058445522, 77.09885828835624, 77.62759535653251, 85.80438831874302, 86.49044649941581, 96.76688085283551, 89.21491854531425, 69.21694687434605, 42.70814834322248, 28.442631585257395, 15.086349146706716, 4.54319646528789, 1.116657589163099, 0.2818169263856751, 0.11027464949126754, 0.13749431925160543, 0.1911128078188215, 0.17079418525099754, 0.0999745014788849, 0.12981474133474485, 0.09703000555081026, 0.05135818324717028, 0.06018616471971784, 0.11895060858556203, 0.11641739308834076, 0.13079066468136652, 0.11752401585025446, 0.11837846785783768, 0.2041136473417282, 0.2331662369625909, 0.10382815290774618, 0.08575903677514621, 0.09022123233548232, 0.14892886924956525, 0.12104827245431286, 0.13657520285674504, 0.12092187495103904, 0.15679779914872988, 0.09200401524347918, 0.1427775150431054, 0.13672514552516596, 0.10919307145689215, 0.14301182675574506, 0.08567132255328552, 0.17604345429156507, 0.12666499534887926, 0.16249509129141057, 0.10088366376502172, 0.15863970959825174, 0.22482833079993725, 0.1228718353169305, 0.11979451615895544, 0.13015542019690785, 0.11264671970691, 0.13909382985106536, 0.15339947864413261, 0.1549218533826726, 0.17095164608742508, 0.1766426685665335, 0.14454935996660165, 0.10621718649885484, 0.09031727218202182, 0.10683689931673662, 0.05656347643317921, 0.09708659537136555, 0.19235874739076408, 0.09748165881527321, 0.3059425375291279, 0.15269885052527699, 0.09403643118483679, 0.10386108899755137, 0.06411048557077136], [0.034874321693288426, 0.04917811808575477, 0.02239170820186181, 0.0133706919981965, 0.03808666592729943, 0.08815109663243804, 0.05423916829749942, 0.00877164610262428, 0.08045232974525009, 0.015943545814869658, 0.030834755061992576, 0.051008981985173056, 0.03286500308396561, 0.03997703395517809, 0.0541689942058708, 0.008640643042911376, 0.062453028080718856, 0.02485302273583199, 0.06612312221633536, 0.08180393079029662, 0.029108341450669935, 0.04081929947382637, 0.04684315016493201, 0.07091912307909556, 0.019450107921979258, 0.03358786001003214, 0.04360069254679339, 0.06220866047910281, 0.0384850440147732, 0.07921355550310441, 0.02599948737770319, 0.036309623425560336, 0.06747927623135702, 0.026719623378344944, 0.05422545849744763, 0.018018907933895077, 0.06732028190578733, 0.0826091482969267, 0.0477682478459818, 0.0741985235363245, 0.11139627466244356, 0.018157130606206398, 0.050678325085235496, 0.04205480317718216, 0.07179473180856023, 0.023459839368505136, 0.12919038055198534, 0.01922877149523369, 0.011281676906427103, 0.03399167316300528, 0.024981701813106025, 0.5619545600243977, 2.854190353836332, 7.581910780497959, 17.241004637309484, 29.47955642427717, 33.9120693887983, 49.719137804848806, 61.407109124319895, 51.73852750233242, 61.26089123317173, 48.89979233060564, 44.13390132359096, 36.37065471921648, 30.05813292094639, 32.307758126940044, 22.583264350891113, 24.539746795381816, 32.90566103799002, 26.471919230052404, 39.7455233165196, 40.53377907616751, 48.1522981779916, 46.39317062922886, 69.92049367087228, 68.07892227172852, 51.65785196849278, 83.2937957218715, 68.22735663822719, 47.685987200055806, 58.841035161699565, 77.89940193721226, 72.19083145686558, 63.54158183506557, 53.98980637959072, 63.650480951581685, 66.81369004930768, 56.94748081479754, 56.936308111463276, 64.78526074545724, 73.50417300633022, 86.69388280596051, 72.38677065713065, 52.58294555119106, 50.37076071330479, 52.38670063018799, 48.02658789498465, 42.47752373559134, 34.36963605880737, 25.03750705718994, 17.39741553579058, 12.717719537871224, 12.984977654048375, 20.50628103528704, 39.782897676740376, 40.08233724321638, 43.94961077826363, 52.84686940056937, 48.751159940447124, 64.83072975703648, 66.42060266222272, 67.80419744764055, 63.5828332901001, 58.50285243988037, 47.46243238449097, 36.470660141536165, 18.36255506106785, 4.947739260537284, 0.5799878495080131, 0.08821293831403766, 0.29975171972598347, 0.026393994422895566, 0.05963956405009542, 0.030133299130414213, 0.05052651644551328, 0.04152141358437283, 0.0743014912254044, 0.046650972084275315, 0.07384396184767995, 0.023179606102140884, 0.07130277356398956, 0.012926290576745356, 0.003724801445579422, 0.02484060384865318, 0.05136235623753496, 0.01373300764576665, 0.04914483255041497, 0.055063605308532715, 0.024404702774648155, 0.03224903238671167, 0.04336727989305343, 0.03836958110332489, 0.02509149895714862, 0.016815129135336195, 0.0325546513444611, 0.029778316750058105, 0.011060429537402732, 0.026952630607411265, 0.03508812129231436, 0.08113250003329345, 0.021213291345962455, 0.06728071652884994, 0.03540088522381016, 0.01497494216476168, 0.08369608675794941, 0.06827980506100825, 0.02967518281989864, 0.06303093635610171, 0.043421009688505104, 0.046817881520837545, 0.03808367698054228, 0.04301036708056927, 0.03136115235143474, 0.016938676791531698, 0.0003854333356555019, 0.05377225138779197, 0.01295426657556423, 0.05682220522846494, 0.013990146972771202, 0.04814691109848874, 0.05354788699852569, 0.05933965835720301, 0.03731447611270206, 0.059620565069573264, 0.03196589668680515, 0.10414814323719059, 0.069113500682371, 0.0603547196037003, 0.019286270552713956, 0.04172955759401832, 0.05633974986683045, 0.015241531788238456, 0.04891499577622328, 0.03701134059312088, 0.02274548787889736, 0.030465652367898395, 0.011159230173299355, 0.04229654484827604, 0.05957463503416095, 0.031614649641726694, 0.02249381924048066, 0.0010631100075053318, 0.016925153588610034, 0.022052179456555417, 0.009763981515009488, 0.06917135257806097, 0.06909526844641992, 0.03287827522893037, 0.06419602848057236, 0.04355173624519791, 0.029222915481243814, 0.03375738859176636, 0.01690460415557027, 0.02896971335368497, 0.08493015196706567, 0.05194818640926054, 0.03523573319294623, 0.04072795508961592, 0.035437861989651404, 0.031548336414354186, 0.06654356286994048, 0.03016535991004535, 0.017017938163397566, 0.10643896566970007, 0.018118221711899554, 0.07239239223833595, 0.013344361446797848, 0.07451693966452565, 0.04737042276454823, 0.05190244636365345, 0.06747084204107523, 0.09889757819473743, 0.04375824498544846, 0.03897910571790167, 0.021819251955353787, 0.026805223963622535, 0.023492463332201754, 0.5451507217117718, 2.6882886503423964, 8.404935325895037, 18.7320168358939, 32.615643228803364, 41.64053331102644, 58.87808295658657, 75.8403102329799, 64.372405733381, 74.43154212406704, 60.67964662824358, 62.14482021331787, 54.64030020577567, 45.4414758682251, 45.950410570417134, 35.506872040884836, 27.369706392288208, 37.97105761936733, 36.545658997126985, 36.322635718754356, 46.008629526410786, 47.25741883686611, 38.71498734610421, 42.167818205697195, 49.156955582754954, 49.771874632154194, 55.796483925410676, 53.30045822688511, 43.67746026175362, 51.27540227345058, 62.34382356916155, 52.37729624339512, 52.5508622441973, 46.09569045475551, 50.809334482465474, 51.65719883782523, 52.29831607001168, 44.47580827985491, 48.78891297749111, 57.38317455564226, 63.15045383998326, 55.30906432015555, 45.545361859457834, 36.4558014188494, 50.47775949750628, 49.23774576187134, 31.497903891972133, 37.662929330553325, 34.32446929386684, 31.037669113704137, 24.692299706595286, 27.323601620537893, 38.24324982506888, 54.607893807547434, 50.7834142276219, 56.62758575166975, 62.66931193215506, 58.46674960000174, 73.58460535321916, 78.72713388715471, 78.31497369493756, 74.14922291891915, 67.08282157352993, 55.11008875710623, 41.97138220923287, 20.73526065690177, 5.851751574448176, 0.5630751741783959, 0.05081443581730127, 0.2001212422869035, 0.1112072483769485, 0.03772773786580988, 0.020395671915529028, 0.011144844382735235, 0.037445619968431335, 0.03202031858797584, 0.0187454611794757, 0.037147010277424536, 0.08467278363449232, 0.11256958384599004, 0.089649383377816, 0.10617502233279602, 0.05183374130034021, 0.031520007577325614, 0.024536842380517294, 0.042825405219835896, 0.07226996416492121, 0.02608515920915774, 0.044966159454946, 0.06362728042794125, 0.11047455947846174, 0.02318433379488332, 0.032553606400532384, 0.018935233853491287, 0.013794710227687444, 0.038504171916948896, 0.022199502979804362, 0.04317144450864621, 0.05154796949188624, 0.035176897421479225, 0.04912134845341955, 0.01689439220353961, 0.04979889959629093, 0.07288456082876239, 0.03631951646613223, 0.02786603713008974, 0.007843677370276834, 0.052996210886963775, 0.08433728199452162, 0.05525422275864652, 0.017362401554627076, 0.03854803581322942, 0.05081092439857977, 0.03843834723478981, 0.0352078318329794, 0.05572587923545923, 0.05987851694226265, 0.040519933216273785, 0.05703081403459821, 0.07164330993379865, 0.02898721277181591, 0.0631394816030349, 0.07302246628595249, 0.04472400727016585, 0.07826018666050263, 0.19096044956573419, 0.16621467098593712, 0.11648094467818737, 0.13093004934489727, 0.18727058970502444, 0.1497644851250308, 0.2059394900820085, 0.08318112617624657, 0.09558988282723085, 0.10376920857067619, 0.09594377276620694, 0.14933346611048492, 0.2005064466169902, 0.1916265266814402, 0.14226215412574156, 0.10479864797421864, 0.17532095020370825, 0.0649695855432323, 0.15782964735158853, 0.2193067656563861, 0.12871197265173706, 0.19284011370369367, 0.12238371079521519, 0.2164545708468982, 0.12621864144291195, 0.156784377726061, 0.15213061815926007, 0.13912213833204337, 0.2304691688290664, 0.173570791259408, 0.15217062458395958, 0.10726758584912334, 0.1250940239323037, 0.06370530516973563, 0.16168331913650036, 0.1270539587629693, 0.07813989597239665, 0.29547317645379473, 0.13283656989889486, 0.16783885311867508, 0.1202502338481801, 0.17647825953151497, 0.15859351493418217, 0.14721260991479668, 0.1854626874306372, 0.18684326192098005, 0.16442385422331945, 0.17932708880731038, 0.10915919898876122, 0.20551117163683685, 0.1254361141473055, 1.3619431129523685, 5.3496825609888345, 14.399925317083087, 26.64838089261736, 40.74511201041085, 52.396532331194194, 72.73626504625592, 88.37605558122907, 75.91783823285783, 81.9750554221017, 69.09013530186245, 61.00055612836565, 52.57373571395874, 44.704907757895334, 49.81692327771868, 35.536249024527415, 36.7256520816258, 51.21171508516584, 42.42274066380092, 56.120110171181814, 58.83225263868059, 66.62864562443325, 64.09019075121198, 93.203629221235, 92.91124207632882, 73.99805096217564, 106.31059292384556, 85.93839127676827, 66.67650481632778, 76.22150925227574, 98.88907609667096, 93.79587977273124, 83.45753002166748, 71.12911197117397, 82.10711288452148, 85.69006960732597, 73.45520905085972, 71.818206514631, 81.70267908913749, 91.73448821476528, 110.34937926701137, 97.42264488765171, 73.41321413857597, 68.3696071079799, 77.44394751957485, 67.68377126966203, 59.987751960754395, 53.07778583254133, 40.90548685618809, 31.119963577815465, 26.346295799527848, 30.63771343231201, 36.34231996536255, 56.37681484222412, 58.27781070981707, 61.38738318852016, 72.80941568102155, 66.47607013157436, 84.73784678322929, 86.36296095166887, 88.96326868874687, 85.57573699951172, 80.16303471156529, 69.14006505693708, 58.02813414164952, 31.356188433510916, 11.358583280018397, 1.893901756831578, 0.25190628852163044, 0.3759123629757336, 0.30034820629017694, 0.1530156856668847, 0.056798137591353486, 0.06304094474762678, 0.11356855024184499, 0.30348947058830944, 0.16209858256791318, 0.1390139934207712, 0.14400817400642804, 0.18803372446979794, 0.24750400760344096, 0.20534742756613664, 0.11920663341879845, 0.07788978117917265, 0.14763574435242585, 0.15250648584749016, 0.16651817969977856, 0.13494199620825903, 0.11990054404096943, 0.11570172863347189, 0.2303099845136915, 0.07001456126038517, 0.11651964831565108, 0.08584027777292899, 0.1661672821002347, 0.12217890178518635, 0.16200180990355356, 0.12940297914402826, 0.2832065389624664, 0.07277215471757309, 0.21838767640292645, 0.09782813915184566, 0.24907766601869039, 0.18432800046035222, 0.1556819618812629, 0.0754399983478444, 0.13562229541795595, 0.13943706000489847, 0.11407846930835928, 0.09780386116887842, 0.07908379246613809, 0.15239876162792954, 0.18271345352487905, 0.10775210734988962, 0.11877142105783735, 0.12737601862422057, 0.13345892221799918, 0.1654177044651338, 0.13165011070668697, 0.13241496895040783, 0.23880011322242872, 0.15459979352142128, 0.19774668184774263, 0.14821526754115308, 0.16481764880674227], [0.08994651386248213, 0.027433360793760846, 0.07681975181081466, 0.04895180969366005, 0.03015563650322812, 0.04223961915288653, 0.027959634250562106, 0.028460269261683737, 0.045364676642098596, 0.058636994633291445, 0.006287946698388883, 0.021892372585300888, 0.013794816248784108, 0.02017805046801056, 0.05949815056685891, 0.15089478875909532, 0.16174744069576263, 0.11311013876859631, 0.07941588786031518, 0.10173322353512049, 0.09598508197814226, 0.06186765592013087, 0.010261135641485453, 0.047617063458476744, 0.06315666889505726, 0.09221102949231863, 0.0327747409631099, 0.07548400812915393, 0.03704443953133055, 0.0362638562385525, 0.020695094152220657, 0.0402583681446101, 0.047236479951867034, 0.017461077509714023, 0.042902676787759574, 0.08077234721609525, 0.11670716825340476, 0.08304269146174192, 0.04610066661345107, 0.04094129667750426, 0.007922713129249002, 0.03454548326720085, 0.036924528822835, 0.030064339616468976, 0.0739022751471826, 0.09251774767679827, 0.07761038081454379, 0.15542349432195934, 0.12232330760785512, 0.9411485897643226, 5.300662585667201, 12.01187983580998, 33.83366591589791, 47.53462764195034, 54.06757756641933, 54.40184497833252, 55.60139240537371, 54.971757071358816, 50.12275171279907, 52.939798082624165, 34.317653111049104, 25.42535376548767, 11.076454281806946, 28.277606657573156, 30.526924405779155, 17.932925360543386, 28.084205286843435, 42.557063238961355, 40.79443032400948, 37.1787371635437, 59.87075124468122, 49.27222967147827, 56.29915830067226, 50.15355307715279, 65.06238964625767, 62.387388774326865, 39.61885418210711, 47.161842891148154, 47.61974654878889, 29.18802043369838, 14.065782104219709, 9.37084002154214, 8.934685094015938, 5.408776555742536, 7.1750724741390774, 7.46356645652226, 7.683653252465384, 8.471658876964025, 13.46958063329969, 22.07879560334342, 24.29198271887643, 29.299427849905832, 35.778188773563926, 60.47962883540562, 56.34000676018851, 55.11180148805891, 66.31053624834333, 64.87273161751884, 57.10223109381539, 71.08838857923234, 51.24388524464199, 39.574486460004536, 15.522649117878505, 13.194737689835684, 14.77853352682931, 15.577939408166067, 13.422193050384521, 19.051503692354473, 25.055975369044713, 44.7415178162711, 52.124176842825754, 58.47858238220215, 62.40843486785889, 63.094354084559846, 72.4243117741176, 69.51630306243896, 71.46816321781704, 43.6784781728472, 23.452715022223337, 13.044561062540327, 6.219632199832371, 0.3572827497763293, 0.05220416374504566, 0.16882509019758019, 0.09114742585058723, 0.06774607620068959, 0.0777124392666987, 0.10476510120289666, 0.04861059139615723, 0.019571187407044426, 0.05627098373536553, 0.019395794586411545, 0.03001550884385194, 0.0590116341731378, 0.0547063159091132, 0.048454341744737964, 0.044553379461701424, 0.04939323065004178, 0.044013537000864744, 0.06856493904654469, 0.03529812448791095, 0.053046907630882094, 0.02487462050547557, 0.07414132303425244, 0.08503785583057574, 0.13147749139794282, 0.05181047772722585, 0.06528897197651011, 0.17573979630001954, 0.052749848392392905, 0.09422034810164145, 0.09064774587750435, 0.12201072009546415, 0.038235085284603496, 0.15568120192204202, 0.09939598930733544, 0.05764100022081818, 0.06497049478015729, 0.0166193344630301, 0.05397093661927751, 0.03406178279380713, 0.03300746829648103, 0.05963520106992551, 0.06532418115862779, 0.03170182442824755, 0.019514701063079492, 0.11379082474325385, 0.025908321108935133, 0.0559748981946281, 0.021632005127945116, 0.09362641282911811, 0.056859660361494334, 0.11626308065439973, 0.04545094219169446, 0.09731266288352863, 0.029310510959476233, 0.10760011550571237, 0.063800612198455, 0.01696361125712948, 0.009194034151732922, 0.0682544753487621, 0.03001520350309355, 0.011579499496812267, 0.028622398419039588, 0.040474644396454096, 0.016937253564330082, 0.008779430595625724, 0.025708758870937994, 0.050951886656028886, 0.06123940713171448, 0.07297628519258328, 0.09939387227807726, 0.1550348023218768, 0.09645865192370755, 0.03364304865577391, 0.013374572370334395, 0.025879005003454428, 0.04617968540904777, 0.08734487489398036, 0.03292378796530621, 0.02287949345606778, 0.09981051992092814, 0.01021189520335091, 0.010604708455502987, 0.07595943047532014, 0.08526075458420174, 0.07968840109450476, 0.03524368562336479, 0.017392413158501898, 0.041773604694753885, 0.04688871379143425, 0.016924617545945302, 0.11526696410562311, 0.08919547737709113, 0.04686481239540236, 0.032267753167876174, 0.06099837113704, 0.08491383998521737, 0.031371622146772485, 0.011026127895872508, 0.08679731748998165, 0.008614463465554374, 0.1141357376639332, 0.09918594200696264, 0.17419015802443027, 0.8011138896856989, 5.439915341990335, 13.959430371012006, 37.664728913988384, 52.4556302343096, 61.93336568559919, 63.86547906058175, 68.3742207118443, 68.77324186052594, 63.22093636648995, 63.48203577314104, 47.40312256131853, 40.37862580163138, 22.848532676696777, 33.27290460041591, 28.676106691360474, 25.01777069909232, 30.982840878622874, 37.930577414376394, 45.41279717854091, 36.901187896728516, 49.024564606802805, 44.55003588540213, 47.16847842080252, 48.593814509255544, 55.09461511884417, 52.43840912410191, 40.06627300807408, 43.7522680418832, 40.28536360604422, 28.240404265267507, 16.704581124441965, 12.292646987097603, 10.248587710516793, 7.015316886561258, 7.564538546970912, 7.997362681797572, 7.575986572674342, 8.54849466255733, 14.302706122398376, 19.075573989323207, 19.911379746028356, 25.27256808962141, 31.656989846910747, 44.39699486323765, 46.373295307159424, 46.10263170514788, 45.60905252184187, 56.767220224652974, 52.932603222983225, 53.77179970060076, 46.712659222739084, 34.91470486777169, 21.847137451171875, 21.759371280670166, 26.858649015426636, 31.07106910433088, 28.817794357027324, 35.1337433542524, 36.980133329119, 56.00117438180106, 62.416244643075125, 66.40468433925084, 71.66941084180559, 74.60428128923688, 81.75650678362165, 78.91264384133476, 81.02206134796143, 52.26629529680525, 28.139196804591588, 15.04029301234654, 7.815231289182391, 0.3120238669216633, 0.10195745900273323, 0.04034867776291711, 0.040037576242216995, 0.06993126430149589, 0.11358863487839699, 0.12860450627548353, 0.04005509940907359, 0.03555326383294804, 0.030907198853258575, 0.032161552259432416, 0.052600380698485036, 0.07509039675018617, 0.01579524011218122, 0.0207242660690099, 0.091045828802245, 0.0606289766728878, 0.022126219501452785, 0.06974342545228344, 0.03208367679534214, 0.06177749897220305, 0.056117142883262465, 0.1284021128501211, 0.0505293662925916, 0.07710428868553468, 0.052348179410078695, 0.03964537960876312, 0.08779525929795844, 0.041254708609942875, 0.05976364774895566, 0.012275607724274908, 0.1037847673786538, 0.024101977768753256, 0.04942808360127466, 0.0807062036224774, 0.019650248611079793, 0.06583418843469449, 0.04967491767768349, 0.07308618072420359, 0.07374915014952421, 0.05548885677542005, 0.08053647487291268, 0.1612004464758294, 0.00640967715298757, 0.08386666367628745, 0.09122715371527843, 0.03726158770067351, 0.04309131630829402, 0.0626808258571795, 0.07860812584736518, 0.045396401546895504, 0.01277767020344202, 0.015408381852986557, 0.011718000368481236, 0.05003570153244904, 0.34976963007024353, 0.18538357024746283, 0.2211545386484691, 0.08802811216030802, 0.1152599887656314, 0.1748104068849768, 0.1040931683299797, 0.104784907640091, 0.11737741157412529, 0.11046934832951852, 0.0704184795862862, 0.24824806196349009, 0.25105418424521175, 0.11571481078863144, 0.21833244365240845, 0.25341507898909704, 0.30190821258085115, 0.214290016996009, 0.11237177731735365, 0.20937225302415235, 0.24808646206344875, 0.1967117938080004, 0.1624930149742535, 0.16035538539290428, 0.15001224540174007, 0.2128685132733413, 0.21488142811826297, 0.1306620551539319, 0.1298685355910233, 0.21824865814830574, 0.13953354768455029, 0.1440779681184462, 0.1571472039712327, 0.13401503594858305, 0.18429875560104847, 0.21102137810417584, 0.20505463970558985, 0.1877159529498645, 0.254333706838744, 0.15357253221528872, 0.25309377908706665, 0.27387649246624535, 0.1522472176168646, 0.17653033030884607, 0.18164150390241826, 0.17257618105837277, 0.3039506572697844, 0.2660073861479759, 0.38682288037879126, 1.9883755445480347, 9.487767781530108, 21.155758687428065, 47.520029476710725, 64.37027958461216, 74.09723649706159, 78.25570556095668, 80.30673040662492, 78.31929547446114, 72.71726867130825, 69.92951243264335, 51.48768016270229, 41.04694523130144, 21.62688476698739, 41.539402280535015, 45.512674059186665, 34.426541805267334, 44.694120679582866, 61.78677259172712, 58.23148706981114, 55.59612567084176, 79.23162869044712, 66.82468209947858, 77.27279949188232, 69.7706001826695, 90.8756491797311, 84.1791490827288, 55.84274155752999, 62.57526111602783, 61.259126390729634, 40.15402180807931, 21.489242689950125, 13.50477499621255, 12.446882230894905, 7.965964640889849, 9.940613150596619, 10.559918250356402, 10.613516654287066, 12.095482298306056, 20.148872647966655, 29.0759459904262, 31.341930730002268, 36.50364671434675, 46.694771085466655, 75.49468599046979, 78.08677400861467, 71.64260469164167, 88.0785823549543, 85.57894011906215, 77.55244364057268, 90.28020245688302, 66.66306700025285, 54.88451548985073, 29.362847532544816, 23.85878164427621, 28.256557089941843, 28.649786915097916, 23.400054625102452, 34.974813733782085, 39.83282743181501, 63.03120190756661, 67.97308731079102, 75.04362978254045, 81.03431102207729, 81.85829789297921, 89.72946739196777, 88.80514853341239, 91.9506744657244, 67.24048314775739, 39.46210977009365, 22.569065707070486, 13.093665719032288, 1.7848496713808604, 0.3033324304435934, 0.2869658129555838, 0.16961774123566492, 0.1859416924417019, 0.16575431211718492, 0.29766869864293505, 0.1923447831400803, 0.20453754173857824, 0.15922683237918786, 0.15511780072535786, 0.12651650474539824, 0.18766697629221848, 0.1297604042504515, 0.28212935104966164, 0.25576568714209963, 0.216405078502638, 0.20962868497839995, 0.1345181425235101, 0.11578221645738397, 0.14860064829034464, 0.1428501454315015, 0.3501296878925392, 0.19893432169088296, 0.2675968679998602, 0.22477206667619093, 0.17023497740072863, 0.1942585233066763, 0.14303994524691785, 0.19391078768031939, 0.22849251489554132, 0.2677809138383184, 0.10456199531576463, 0.3974066695996693, 0.24542779901197978, 0.17687632888555527, 0.1299086505813258, 0.139578873823796, 0.14759519509971142, 0.16653074616832392, 0.16903707810810634, 0.20185135730675288, 0.36048945199166027, 0.1361851944987263, 0.12814710581941263, 0.32187152707151, 0.1742414009890386, 0.13762402800577028, 0.15702930172639235, 0.17540727342878068, 0.19344616761165007, 0.17296696294631275, 0.13152732300971234, 0.2727929806070668, 0.16030719583587988], [0.06807152195168392, 0.013921371511449772, 0.07756451184728316, 0.048002352605440786, 0.019321603567472527, 0.053092349121080976, 0.10147926823369094, 0.019758717522823384, 0.035235970680202754, 0.02692356047087482, 0.031050495271171843, 0.021072373193289553, 0.03443413567064064, 0.057787082024983, 0.058910824225417206, 0.1290654893964529, 0.032398632394948175, 0.012848438013211956, 0.06635427195578814, 0.05420958756336144, 0.06184561710272517, 0.039761283567973545, 0.0879378602174776, 0.06633127640400614, 0.07466467709413596, 0.04113448238266366, 0.017156983559419, 0.07132561305271727, 0.05115011726905193, 0.07624060860169785, 0.0242101684811392, 0.07269353965031249, 0.11749843508005142, 0.06296867398279053, 0.05459093442186713, 0.06263751496693917, 0.0895568108452218, 0.02895486361480185, 0.06997650223118917, 0.031157327217182944, 0.0912138612142631, 0.12131007840590817, 0.07458006377731051, 0.06522689959300415, 0.016059972246044447, 0.043050675453352075, 0.0766707251646689, 0.39076633591737064, 5.441312364169529, 18.383625473294938, 44.36563764299665, 51.05864627020699, 61.423256737845286, 66.80919456481934, 61.7030884878976, 54.59167323793684, 49.80615356990269, 38.23504400253296, 35.856043338775635, 24.753004380634852, 23.815044471195765, 16.432291643960134, 33.65137645176479, 51.807307720184326, 56.19655425207955, 42.46186597006661, 49.418763705662315, 39.68383720942906, 37.410647187914165, 50.19394990376064, 35.975409916469026, 44.80712965556553, 36.29072264262608, 19.35370864186968, 14.148716671126229, 14.391609191894531, 12.996818252972194, 8.275803923606873, 5.25147932767868, 1.3593089857271738, 0.35461662283965517, 0.36645800886409624, 0.14805112992014202, 0.08280340608741556, 0.04711676601852689, 0.09429825070713248, 0.061216587999037335, 0.11035019758024386, 0.0747369546443224, 0.4526203397129263, 1.4035876840353012, 2.857938906976155, 6.1095193198749, 12.32609908921378, 14.935705253056117, 31.235887323107036, 31.75653668812343, 26.68272236415318, 43.534164088112966, 56.47031675066267, 67.55058819907052, 70.99261460985456, 44.71791478565761, 54.3824907711574, 41.93667595727103, 29.270370483398438, 28.410506589072092, 16.219584703445435, 8.980293069566999, 14.588597570146833, 20.428195442472184, 38.1831305367606, 43.25702823911394, 52.941615036555696, 57.84078638894217, 59.40946728842599, 62.199162074497764, 72.43073190961564, 65.28122316087995, 63.68746621268136, 56.65223796027047, 23.865580456597463, 11.895203079496111, 0.9217867829969951, 0.061999088153243065, 0.18244384442056927, 0.04768614850140043, 0.08120966303561415, 0.02924970065110496, 0.031355612113007476, 0.02832899478796337, 0.025678772712126374, 0.06385590601712465, 0.03423067355262382, 0.03547549693446074, 0.08656855619379453, 0.02050844782830349, 0.013670446717047265, 0.023660146298685243, 0.028846060524561574, 0.116677122722779, 0.05565659402470503, 0.11962317249604634, 0.027833007741719484, 0.09872164084975209, 0.04822722928864615, 0.10291221884212323, 0.019686709690306867, 0.019320606120995114, 0.03331304993480444, 0.013493626428368901, 0.05091553753507989, 0.008688188839836844, 0.0626522120354431, 0.05577485928578036, 0.00936943375771599, 0.04702445811458996, 0.02635128403614674, 0.07259884330310992, 0.014599566414420093, 0.042917146547032256, 0.024393001438251564, 0.04679521505853959, 0.02001904426807804, 0.03103739275996174, 0.03196318254673055, 0.10666993220469781, 0.04253243076215897, 0.031291381988142214, 0.03321254872051733, 0.047164809690522294, 0.04042395104521087, 0.009073510217214269, 0.04096305051020213, 0.02704243132445429, 0.05336846537621958, 0.025579014493684684, 0.031450793612748384, 0.03418654163501092, 0.015676026598417332, 0.027634480269625783, 0.03252551505076034, 0.03568876049082194, 0.012526120308653584, 0.02778266044333577, 0.05063488527334162, 0.02712462905661336, 0.035916147753596306, 0.0410781809394913, 0.0234424128928887, 0.01284611233443554, 0.04859565684039678, 0.02627395309640893, 0.08639751787164382, 0.06436813888805253, 0.05346649333036371, 0.041572432632425, 0.035496422954435856, 0.13132931292057037, 0.09244357701390982, 0.04016247418309961, 0.07572214677929878, 0.00809161236975342, 0.05928339423345668, 0.06222380538071905, 0.05720913303749902, 0.06506458723119327, 0.05293213003980262, 0.06857513064252478, 0.028694754000753164, 0.07717161971543517, 0.020148992205836942, 0.07475019964788641, 0.0585991663060018, 0.03815110979069557, 0.03581727502335395, 0.058600516590688906, 0.17492027527519635, 0.07240039216620581, 0.09000771093581404, 0.043652424056615145, 0.04718115220644644, 0.13995065673121385, 0.5957512493644441, 5.9278890660830905, 20.193754536764963, 48.9407172203064, 58.72617449079241, 71.9205882208688, 77.95242364065987, 70.69007614680699, 65.8268860408238, 57.888906138283865, 48.378225803375244, 47.49927520751953, 37.52555997031075, 34.00840268816267, 24.0234591620309, 33.8431258882795, 46.032149178641184, 54.809075423649375, 37.54139838899885, 49.75056798117501, 44.34960467474801, 43.518384729112896, 46.661704608372276, 43.750687326703755, 45.51569652557373, 37.97272171292986, 24.269003289086477, 18.449119193213328, 16.64626489366804, 14.05062026636941, 9.561522909573146, 6.902279683521815, 2.2005474737712314, 0.5291169935039112, 0.32578417712024277, 0.13718630506524018, 0.02933981010158147, 0.03403198832113828, 0.0884669478982687, 0.05354082005630646, 0.0810559137857386, 0.1588729763669627, 0.4081035570374557, 1.1867935742650713, 2.4604989077363695, 3.903195287500109, 9.940429891858782, 13.309065086500985, 22.51044375555856, 26.013998201915197, 27.419047287532262, 39.22152144568307, 52.01698350906372, 52.82034812654768, 57.11925418036324, 36.70786469323294, 34.50675528390067, 37.38424055916922, 26.471504075186594, 26.29917311668396, 23.736189365386963, 16.67586943081447, 25.558293649128505, 34.21637616838728, 49.43925394330706, 55.62312637056623, 60.237866265433176, 67.7369875226702, 69.33687973022461, 71.81117493765694, 81.26224667685372, 76.712128502982, 71.38213757106236, 65.10792813982282, 28.139997584479197, 13.43204733303615, 1.1565441574369157, 0.07970357313752174, 0.11023601370730571, 0.02578504995575973, 0.08545524986194712, 0.0513717268061425, 0.020728009885975292, 0.05038630736193486, 0.01403319408252303, 0.008578293308216547, 0.049917351454496384, 0.07475204526313714, 0.03579884601224746, 0.025443940223859887, 0.03720776969566941, 0.020272933412343264, 0.08591887926948921, 0.12041344866156578, 0.048040815362972875, 0.10634834053260939, 0.025137975213250945, 0.03374704432540706, 0.018207355768286755, 0.035894611052104404, 0.03793704556301236, 0.05142762452097876, 0.03402428016332643, 0.03083515539765358, 0.06152612888919456, 0.02890692511573434, 0.00973129817949874, 0.055489857614572556, 0.04685175059629338, 0.0164753018346216, 0.07908151258847543, 0.06336396134325437, 0.006316912086081824, 0.028448206605389714, 0.031437178807599206, 0.059811925515532494, 0.03509806522301265, 0.013981843400480492, 0.042053320578166416, 0.0836138143869383, 0.027968816525701965, 0.06657533866486379, 0.058534366211720874, 0.05084180113460336, 0.034557713860911984, 0.0762012739266668, 0.039887728568698676, 0.008946607205351549, 0.03976811980828643, 0.10407332796603441, 0.1861940531858376, 0.22678134457341262, 0.10273666826209851, 0.14893383612590178, 0.1165791286953858, 0.1597109264028924, 0.14317751143659863, 0.1497219002672604, 0.1475280337035656, 0.1754974235913583, 0.1249255979699748, 0.11301608702966146, 0.16092183999717236, 0.2485654263624123, 0.210311426914164, 0.09865041502884456, 0.20537642815283366, 0.161800868543131, 0.15148923971823283, 0.22176486732704298, 0.20734816949282373, 0.3945689818688801, 0.33338876334684237, 0.16683235498411314, 0.13435807611261094, 0.1331364688064371, 0.11900133586355618, 0.15219448187521525, 0.23578725489122526, 0.1277855145079749, 0.1557715285037245, 0.25305005429046495, 0.12655785466943467, 0.16158202742891653, 0.15121104036058697, 0.14685879461467266, 0.16576071748776094, 0.1719468126871756, 0.1306634529360703, 0.22973081416317395, 0.26799163967370987, 0.2239454753164734, 0.24401644617319107, 0.22868093049951962, 0.22710795061928885, 0.2842255899948733, 1.435037185038839, 10.647406492914472, 30.765153816768102, 61.630611828395296, 73.47703334263393, 84.72695200783866, 86.98806953430176, 82.28615406581334, 77.55215876443046, 69.7630613871983, 54.188285146440776, 49.532780170440674, 38.69356952394758, 38.81027841567993, 27.437720571245464, 51.68515491485596, 71.32605171203613, 76.26768003191266, 59.647033146449495, 68.42246205466134, 54.559607301439556, 55.76623494284493, 69.08397224971226, 53.510887895311626, 60.08331053597586, 49.689142431531636, 28.072540998458862, 21.37874722480774, 20.147854736873082, 18.462570905685425, 11.861126508031573, 8.259123035839625, 2.1834722757339478, 0.8659332000783512, 0.8798538073897362, 0.43608175430979046, 0.34921971814973013, 0.10733888630888291, 0.20070989855698176, 0.238830104470253, 0.45024370295660837, 0.3058476783335209, 0.7569580876401493, 2.1505679956504276, 3.7007000276020596, 7.9927681854793, 15.897236926215035, 19.729477643966675, 39.348666531699045, 40.90035561152867, 36.62796040943691, 59.126682553972515, 75.1216788973127, 87.86773232051304, 93.39096655164445, 63.12673963819231, 72.30020999908447, 58.57473850250244, 43.46890313284737, 42.20523425510952, 28.741711582456315, 20.34122657775879, 28.750858885901316, 33.92337410790579, 55.38886438097273, 59.33548286982945, 68.93685109274728, 76.32866437094552, 78.56874970027378, 80.32770006997245, 90.22623579842704, 86.089083807809, 83.47759641919816, 78.4708148411342, 40.1474939755031, 20.51535538264683, 2.701382747718266, 0.282960230750697, 0.30458573890583857, 0.13074174230652197, 0.18080127398882592, 0.2254398672708443, 0.10992904446486916, 0.09267172762858016, 0.16018306463956833, 0.16772355644830636, 0.1655330147062029, 0.1385987571307591, 0.21470298697905882, 0.107974619338555, 0.12270522782845156, 0.20707780042929308, 0.159389517935259, 0.34649428725242615, 0.22464161153350556, 0.23616264760494232, 0.12055362042571817, 0.20240823099655764, 0.15864596569112369, 0.20487774562622818, 0.08657540939748287, 0.1543571086866515, 0.14964255238217966, 0.1444047370127269, 0.14862735542867864, 0.1389910046543394, 0.16178172028490476, 0.2041802659098591, 0.12062397093645164, 0.15158578168068612, 0.18230429690863403, 0.14215656050613948, 0.10521708016416856, 0.20159447751939297, 0.16838724512074674, 0.20877115242183208, 0.1541081949004105, 0.1024034261437399, 0.12076483480632305, 0.3124757169612816, 0.13413692797933305, 0.1273125891706773, 0.11182842683047056, 0.20717620157769748, 0.24386328724878176, 0.23560592319284165, 0.15101631438093527, 0.10407163162848779, 0.16194019892386027], [0.03974681041602578, 0.013056542158925107, 0.014549207241673554, 0.05510125382404242, 0.022827191976830363, 0.02339861515377249, 0.0323224125563034, 0.052477056958845684, 0.031163878472787992, 0.09100001411778585, 0.05264515043901546, 0.03175090965149658, 0.018750685899119292, 0.014414467150345445, 0.06083213684282132, 0.05471677552642567, 0.01508726685174874, 0.04087381297722459, 0.0940595760143229, 0.03298686458063977, 0.05999399681708642, 0.047370667037154944, 0.10083829012832471, 0.02877281266929848, 0.02526425906190915, 0.016264530198116387, 0.1171443619366203, 0.015539006629426564, 0.029558067675679922, 0.031044683618737117, 0.0428002994241459, 0.008606654375658503, 0.022938061206202422, 0.003738558743082519, 0.03789031485627804, 0.04887049066435013, 0.014001598099379666, 0.03359207371249795, 0.0913252088108233, 0.04694439098238945, 0.017302073006119047, 0.01060756593610027, 0.06494934484362602, 0.1609320044517517, 0.16519939260823385, 0.9640273792403085, 7.132098734378815, 24.54146647453308, 48.69279507228306, 56.29014301300049, 62.41017886570522, 62.04615579332624, 60.38755825587681, 44.37717512675694, 46.69464949199131, 34.24069833755493, 29.99247244426182, 30.783035005841935, 15.860623393739973, 24.4401113646371, 36.50367798124041, 58.95470074244908, 74.02525315965924, 55.18831852504185, 42.326657499585835, 51.77787515095302, 42.74632522038051, 35.013275487082346, 31.366687161581858, 23.56900875908988, 17.7090995652335, 9.33574206488473, 4.13024765253067, 2.203902150903429, 1.8379733179296767, 1.0120436655623573, 0.3477552495896816, 0.16786337537424906, 0.11744765351925578, 0.09389675475124802, 0.0123311738051208, 0.03311822217489992, 0.020533246586897543, 0.010080433284331645, 0.05310486130682485, 0.02453479150842343, 0.03629037677975638, 0.038067612663975785, 0.10374547341572386, 0.013969761236304683, 0.0838162349537015, 0.05832672771066427, 0.12425758024411541, 0.0986590731356825, 0.18120455449180944, 0.6129699168460709, 1.0372229601655687, 2.64046094247273, 3.5726030383791243, 8.111578907285418, 23.436105353491648, 32.5167738369533, 51.271605082920615, 69.72823006766183, 61.341045652117046, 84.92546898978097, 84.09622928074428, 51.24136652265276, 38.81405128751482, 23.721990721566335, 17.299206222806657, 13.918409075055804, 17.74853927748544, 32.030705656324116, 50.74550485610962, 45.35661057063511, 48.5704095023019, 55.3948016166687, 69.74409975324357, 68.90928064073834, 72.28755732945034, 71.20359666006905, 47.71752854755947, 26.42662913458688, 8.750684635979788, 1.3002900098051344, 0.030259744131139348, 0.05199690183092441, 0.09154554270207882, 0.06957354063966445, 0.03339989563184125, 0.03425969449537141, 0.06328615373266594, 0.010305404962439622, 0.11493790176297937, 0.027498108301577822, 0.05344767076894641, 0.01180484182467418, 0.013794733976413096, 0.051345284296465774, 0.04354737665770309, 0.07079949735530786, 0.025611088844016194, 0.028490260509507995, 0.02351930787387703, 0.005272831593174487, 0.0450785146760089, 0.04959510499611497, 0.010731000785848923, 0.08979864072586809, 0.013607397243114454, 0.01884327200241387, 0.13526378465550287, 0.09764220698603562, 0.0013707969067451942, 0.05225469424788441, 0.04734490645517196, 0.024573445952098285, 0.017735461804217527, 0.009231089797270085, 0.05470137617417744, 0.015318884780364377, 0.09095251666648047, 0.06210357576076474, 0.04779255636302488, 0.03759164748979466, 0.017871905018442442, 0.059294305076556544, 0.022974235604384115, 0.026325389443497573, 0.06739893089979887, 0.07732553181371518, 0.08084112352558545, 0.092507040394204, 0.09348263125866652, 0.039227388466575315, 0.06200192442962101, 0.024563951550849845, 0.05143649636634758, 0.015779530330161964, 0.012014783952119095, 0.027477338344656994, 0.03491154612441148, 0.030702569655009677, 0.047259434791547913, 0.01733253413944372, 0.025648481212556362, 0.04056452653769936, 0.04154846338289125, 0.0322696496732533, 0.07362783487354006, 0.013100044735308205, 0.01888763122925801, 0.09311791868614298, 0.016871291478829722, 0.03900236929101603, 0.02360578716200377, 0.020772313133680394, 0.03904410937268819, 0.01574149844236672, 0.01672841914530311, 0.04521657958892839, 0.05692164453544787, 0.03986097054023828, 0.03879748564213514, 0.013396620517596602, 0.05213136033021978, 0.03239318715142352, 0.030217342477824007, 0.04438495349937251, 0.02698915614746511, 0.0043551787135324305, 0.015823372174054384, 0.006959504256623664, 0.02166671728316162, 0.049589669930615594, 0.010834485009711767, 0.016057307299758707, 0.061346507099057944, 0.08167956210672855, 0.10761589144489594, 0.8573186280471938, 7.252097163881574, 26.654050622667583, 54.58758074896676, 66.43862628936768, 73.97192573547363, 71.69273594447544, 70.08143479483468, 55.15670769555228, 59.3641094480242, 44.37384346553257, 46.53474364961897, 42.89706638881138, 27.055694716317312, 29.95763417652675, 38.38237707955496, 44.1454735483442, 57.06066002164568, 54.67122663770403, 44.64546591894967, 47.68515689032418, 41.664959703172954, 37.407836641584126, 35.57750047956194, 29.470888546534947, 21.50798545564924, 12.840007833072118, 6.682948504175458, 2.8085795555795943, 2.4236995109489987, 1.3481038212776184, 0.6693961290376527, 0.29693151105727467, 0.09944778867065907, 0.0376557894051075, 0.032590515312871764, 0.01994457165710628, 0.044544253165700605, 0.05159853392147592, 0.12063136696815491, 0.11313606559165887, 0.12409288622438908, 0.07887992661978517, 0.06489150651863643, 0.041354758598442586, 0.1277946475893259, 0.007094145536289683, 0.09609636850655079, 0.07939726207405329, 0.34173170423933436, 0.7083582612020629, 0.9180895813873836, 2.0035586612565175, 4.188780580248151, 9.708281023161751, 20.67247326033456, 31.461471012660436, 45.10236208779471, 57.50879103796822, 53.9555343900408, 65.3872457231794, 68.91092041560582, 45.870791162763325, 32.22908020019531, 25.533988850457327, 23.711839403424943, 25.897271939686366, 28.153263432638987, 46.393344334193635, 63.60861110687256, 53.979967730385916, 57.05792590550014, 65.06380013057164, 78.2612224306379, 78.06041949135917, 83.02409444536481, 81.1047796521868, 56.556109632764546, 31.4229154586792, 9.739493199757167, 0.9180370356355394, 0.040817660811756334, 0.0506320863163897, 0.06664298860622303, 0.06894299840288502, 0.09469427088541643, 0.034764578832047324, 0.03658225879605327, 0.06550934657986675, 0.022917676317904676, 0.013936152548662253, 0.03452615180451955, 0.05257244201909218, 0.09384789344455514, 0.02807499368542007, 0.03455403620111091, 0.0571004995810134, 0.03233939628782017, 0.05185656721836754, 0.02157118633788611, 0.026583485504878417, 0.039304293625588925, 0.015580689035622137, 0.022309958302815045, 0.027441116449023997, 0.037603705057076046, 0.04944478574075869, 0.025341091278408254, 0.05626098891454084, 0.03108552803418466, 0.028306236723437905, 0.026910054231328622, 0.045162374818963666, 0.041878848868821344, 0.01636652079676943, 0.046753712464123964, 0.04390157533011266, 0.08096542435565166, 0.021170010989797965, 0.03688870556652546, 0.012114955228753388, 0.010697347145261509, 0.028415781113186052, 0.018522596352600625, 0.014663204517481583, 0.06288732441940478, 0.08636280402008976, 0.07243942150047847, 0.005992553263370479, 0.06621849709855658, 0.025025754002854228, 0.2099835995052542, 0.11555162311664649, 0.10591870572950159, 0.12779049495501177, 0.050454897074294944, 0.0989591959597809, 0.0728700537500637, 0.17499781825712749, 0.137955709493586, 0.20976249208407743, 0.160586860829166, 0.1904637347906828, 0.11534789976264749, 0.084206562223179, 0.1981252772467477, 0.13262691614883287, 0.06289219630083867, 0.23330552663121903, 0.15949801568474087, 0.09661643167159387, 0.13674016829047883, 0.11581919661590032, 0.1628088458840336, 0.11120521277189255, 0.06165729649364948, 0.229308086846556, 0.32411134402666775, 0.14380746334791183, 0.14411405261073792, 0.11534309573471546, 0.10799357760697603, 0.10957650481058018, 0.08923146687448025, 0.11639131020222392, 0.11957152241042682, 0.07878102335546698, 0.1123758213860648, 0.1272769525114979, 0.09356338371123586, 0.24343467024820192, 0.1417906265705824, 0.1284833877746548, 0.1114163932257465, 0.2447257595402854, 0.1798143040921007, 2.1063694187573025, 12.417297669819423, 37.04411234174456, 67.98876244681222, 77.47062860216413, 82.81271634783063, 81.65288134983608, 79.76327705383301, 63.02474703107561, 68.21208449772426, 48.52194929122925, 45.896061761038645, 44.73604958398001, 25.232171263013566, 37.91893570763724, 50.69847597394671, 75.60756642477853, 90.4257811137608, 70.68851975032261, 58.31928103310721, 70.26120553697858, 61.18554496765137, 52.18467133385794, 46.74092449460711, 35.505086353846956, 26.162439516612462, 14.725355488913399, 7.3292873076030185, 3.463450529745647, 3.7323021718433926, 1.9488185814448764, 0.8473815641232899, 0.4564705916813442, 0.3654366779540266, 0.1332736143044063, 0.11397997316505228, 0.15333637488739832, 0.15275233265544685, 0.16487673563616617, 0.3407952444893973, 0.4083305134304932, 0.15298819142792905, 0.16491231801254408, 0.27476154640316963, 0.2792279081685202, 0.2235704761530672, 0.17107557372323104, 0.2567710317671299, 0.28645433325852665, 0.811266184917518, 1.174431209053312, 1.7833223704780852, 3.6799453241484503, 5.512266933917999, 12.177154898643494, 32.13336181640625, 42.148102692195344, 69.27418613433838, 89.57154873439244, 81.69937869480678, 107.75830568586076, 106.15098585401262, 72.27453640529087, 55.74633877617972, 38.417451586042134, 28.6828863961356, 26.971642357962473, 31.572944436754497, 50.46061829158238, 66.33997576577323, 63.035620961870464, 68.43799127851213, 73.2838247844151, 87.49984604971749, 85.67762538364956, 91.15366744995117, 91.84433228628976, 70.37754617418561, 44.49560022354126, 15.714471510478429, 2.970151662826538, 0.136832557618618, 0.12491734698414803, 0.2617328055202961, 0.14643688154007706, 0.1270051992365292, 0.1685476643698556, 0.15756846565221036, 0.2862322894590241, 0.2731438646359103, 0.0879389119467565, 0.14933691306837968, 0.14038923462586744, 0.21708503844482557, 0.1313340626657009, 0.1692140128995691, 0.13727919650929316, 0.13438643887639046, 0.12166404298373631, 0.10259790106543473, 0.19426784637783254, 0.12236496965800013, 0.13440577712442192, 0.06217281347406762, 0.19746815679328783, 0.13874183302479132, 0.12504419232053415, 0.2100627166884286, 0.1255768830222743, 0.0849737139152629, 0.19548657669552735, 0.09353519058121101, 0.16504266458962644, 0.10054225887038878, 0.11678769678941794, 0.1893172820231744, 0.1085884967552764, 0.16526313418788569, 0.1280048984502043, 0.1532554528010743, 0.15883966029754706, 0.1339289027133158, 0.12747908809355327, 0.09645735592182193, 0.10082972023103919, 0.18742564852748597, 0.26876381252493176, 0.1477996784129313, 0.15097987705043384, 0.14950223134032317, 0.16443941981664725], [0.11735896899231843, 0.008525784027629664, 0.072267155029944, 0.0786335641252143, 0.04462661374626415, 0.03485641854682139, 0.05365722952410579, 0.012437909059891743, 0.013753825948307557, 0.08765710956816163, 0.08086829885308232, 0.04492177987205131, 0.04413671485547509, 0.019926495484209487, 0.0064485228587208045, 0.005870342321161712, 0.038972869981080294, 0.015702290992651666, 0.04443280718156269, 0.034563847817480564, 0.009432110037388546, 0.02686803086128618, 0.032867649370538335, 0.011565575958229601, 0.04687760956585407, 0.021250817725168805, 0.038732047724936686, 0.0066565430357253975, 0.05099959784586515, 0.04707782828648176, 0.02716365160553583, 0.053042924630322626, 0.019947250174092393, 0.03052933287939855, 0.033947432679789405, 0.037767055577465465, 0.043372915126383305, 0.026687789907945052, 0.004228681974512125, 0.057674248436731954, 0.08663169387727976, 0.07518057405416455, 0.03799959970638156, 0.4267437553831509, 2.219784212963922, 23.814514671053203, 50.2679933820452, 64.82431656973702, 61.4605963570731, 66.21690232413155, 56.49833883558001, 57.222129208701, 33.94722032546997, 33.05508204868862, 19.926879440035137, 14.424746019499642, 10.891048550605774, 15.717926502227783, 27.99869728088379, 41.32417140688215, 55.36497300011771, 57.8409983089992, 52.14725528444563, 39.377015181950156, 31.21540403366089, 21.078421763011388, 16.996820620128087, 8.413480741637093, 4.164854024137769, 2.5264416549886977, 1.1263886498553413, 1.161505171230861, 0.4906168622629983, 0.01943160766469581, 0.06431168477450099, 0.012805087259039283, 0.08663843851536512, 0.06815287151506969, 0.04563511695180621, 0.0213048392906785, 0.018600010412878225, 0.039973542892507145, 0.12718848511576653, 0.11076726591480629, 0.04387062056256192, 0.04862126475200057, 0.09596953674086503, 0.10567154256360871, 0.04677336623093911, 0.10614062060735055, 0.05380101448723248, 0.07492984179407358, 0.047557803602623086, 0.05703386065683194, 0.08922153312180724, 0.01489667993571077, 0.1496432851999998, 0.10663088929972478, 0.04323031420686415, 0.45292554476431435, 0.3914552118097033, 2.4741525522300174, 5.83791423695428, 11.767613308770315, 18.388730662209646, 30.41832058770316, 43.935009138924734, 66.13298892974854, 79.33453151157924, 57.046968596322195, 63.6528502873012, 34.886755738939556, 29.496006284441265, 11.175482613699776, 19.2520078590938, 30.662052971976145, 33.20652845927647, 54.34211826324463, 55.108452456338064, 55.27935382298061, 55.464168957301546, 58.68757029942104, 71.98071098327637, 63.96298313140869, 47.11785731996809, 30.611848763057164, 8.008531042507716, 0.9275226294994354, 0.1739216481468507, 0.04706981139523642, 0.08269145459468875, 0.07401900352644068, 0.01059599606586354, 0.017665248696825335, 0.09278279702578272, 0.02841887523287109, 0.019601612917280624, 0.032675841091466803, 0.03571311650531633, 0.044536019143249304, 0.023597476804362874, 0.02890847556825195, 0.03002761390858463, 0.025103846598150473, 0.04367872407393796, 0.03926414131586041, 0.039171192196330855, 0.03174955936680947, 0.08118108992597886, 0.052645014732011726, 0.02819937763602606, 0.022468952628384744, 0.028698699681886604, 0.011771679273806512, 0.07530467810907535, 0.018268427312640206, 0.035137257405689785, 0.039015139320067, 0.08534078100430113, 0.038142590783536434, 0.01621237121123288, 0.007451746213649, 0.04536133146445666, 0.027828398792605315, 0.007965020635830504, 0.08008499124220439, 0.043887465194399865, 0.061323945809687884, 0.0342851022391447, 0.047963028108435016, 0.03346134037045496, 0.03903719510084816, 0.09918464600507702, 0.05782960581460169, 0.10288494173437357, 0.05722819987152304, 0.09603292548230716, 0.03782824247277208, 0.06117381315146174, 0.06627131426440817, 0.10849842123155083, 0.019398325522031103, 0.03778315042810781, 0.01816666402321841, 0.03693908339898501, 0.11656439091478075, 0.014475467448521937, 0.053578651776271205, 0.026074029538514357, 0.04287775080384953, 0.023319967856098498, 0.02907161574278559, 0.018748936975108724, 0.020029544597491622, 0.040274503707353554, 0.036911293997296264, 0.0730550427521978, 0.03511057062340634, 0.025764770240389874, 0.03430683571579201, 0.016933720093220472, 0.05495915162776198, 0.03272216467718993, 0.027273492854354636, 0.011869222075412316, 0.027452899209622825, 0.0635846345020192, 0.05809013612036194, 0.07490275467612914, 0.02224056113378278, 0.005706863303203136, 0.029771148027586083, 0.029842160109962736, 0.048596691606300216, 0.02815933389190052, 0.044051714773688994, 0.06889936181583575, 0.1546201767133815, 0.05322943015822342, 0.4655381536909512, 3.240984410047531, 27.407589708055767, 57.93174178259713, 72.29711805071149, 73.35538428170341, 76.21525587354387, 69.80661269596645, 66.23183400290353, 44.59937851769583, 42.08047934940883, 30.642997537340435, 26.85404235976083, 22.005933318819316, 24.21172755105155, 25.341883318764822, 42.17683349336897, 50.40524114881243, 54.5678721836635, 49.73186690466744, 40.5959689276559, 34.407712187085835, 25.533292293548584, 20.790012461798533, 12.060786468642098, 5.6010249597685675, 3.5496062380926947, 1.5848997320447649, 1.5434095412492752, 0.6045218844498906, 0.05598594813740679, 0.05166513552623136, 0.10149929180209126, 0.06243284844926425, 0.017015831312164664, 0.08133827934839896, 0.016804046962144117, 0.04718432775033372, 0.04544860463855522, 0.1315138337335416, 0.1074561168040548, 0.09007112681865692, 0.11261003131845168, 0.0655859803248729, 0.1675252749451569, 0.07248078499521528, 0.1285843402147293, 0.10679568509970393, 0.104369929193386, 0.04523583302008254, 0.1325731761753559, 0.06277260450380188, 0.20851287485233375, 0.2241865588085992, 0.1700485295483044, 0.16786452888378076, 0.1216933692672423, 0.4176202820880072, 2.4598173328808377, 5.8276256918907166, 11.303052408354622, 17.44403100013733, 32.56053706577846, 40.40948969977242, 55.67886134556362, 64.73080076490129, 48.8293445450919, 43.567452907562256, 30.02616078513009, 40.28824710845947, 25.758033514022827, 35.74254451479231, 46.03009251185826, 43.11346108572823, 63.252891131809776, 67.7841796875, 63.60661697387695, 63.34094565255301, 67.690108026777, 82.87796688079834, 74.23497758592877, 56.59976169041225, 35.64892796107701, 9.471523761749268, 0.805254147521087, 0.03866401441129191, 0.04021010394873364, 0.09565694244312388, 0.06900706567934581, 0.04803060680361731, 0.017834527916940193, 0.06397775055042335, 0.053645870847893615, 0.05785528836505754, 0.011742088361643255, 0.025391579372808337, 0.03244341570617897, 0.03793839245502438, 0.03265128830181701, 0.008924085779913833, 0.023322244341086065, 0.02518795440638704, 0.012153226300142705, 0.08968358832810606, 0.025330367032438517, 0.005497252809748585, 0.013311134435103407, 0.03594414410846574, 0.025999363545062285, 0.010096554428205957, 0.04204929008015564, 0.03378249438745635, 0.015437869288559471, 0.024303899612277746, 0.044915394857525826, 0.07231001808707203, 0.03084396956754582, 0.029708960293126956, 0.03599549563867705, 0.03494207341490047, 0.005631822843237647, 0.027152347212125148, 0.0220384577821408, 0.04859329893120697, 0.029636943978922706, 0.019547935708292892, 0.03455079958907195, 0.023444451890619736, 0.053203900278146775, 0.03568938813571419, 0.026707723570455397, 0.07457690858947379, 0.07385793288371392, 0.15923075431159564, 0.11803887465170451, 0.13352978841534682, 0.15305988543799945, 0.222880378897701, 0.09127193702650921, 0.11985016960118498, 0.1122548793043409, 0.12686742948634283, 0.2000309835587229, 0.1949613770203931, 0.1161542572081089, 0.09031362844897167, 0.19426620432308742, 0.09435319847294263, 0.09496105728404862, 0.11309652057077203, 0.19138233549892902, 0.17744422198406287, 0.1123918348125049, 0.17158034949430398, 0.14222560822963715, 0.12396815791726112, 0.0979116600272911, 0.19803773265864166, 0.20429389338408196, 0.13480291010013648, 0.17261605177606854, 0.15329820050724915, 0.14766912827534334, 0.11901447230151721, 0.16263491021735327, 0.2202969789505005, 0.09461056680551597, 0.09688994913761105, 0.11856060022754328, 0.17368968416537556, 0.1281042902597359, 0.10744452742593628, 0.17350653399314198, 0.15378671857927526, 0.22663579881191254, 0.08474358876368829, 1.0510253395353044, 7.014035812446049, 38.0183470589774, 69.9396915435791, 83.82379041399274, 80.77255848475865, 84.58461815970284, 74.09529794965471, 74.74154295240129, 50.89984171731131, 47.436935969761436, 34.584832191467285, 26.406580107552664, 18.79755050795419, 25.001857587269374, 40.031688349587576, 57.32314211981637, 71.924423626491, 74.65314102172852, 68.17534937177385, 54.36233057294573, 44.767531871795654, 31.447060448782786, 23.724142926079885, 12.810479726110186, 6.430529134614127, 4.192598615373884, 1.74898795570646, 2.1770417179380144, 1.148400325860296, 0.19827090443245002, 0.20195719519896166, 0.14430070402366774, 0.19908045099249908, 0.18767368021820272, 0.2583848051726818, 0.07832457284842219, 0.17235324159264565, 0.16849955623703344, 0.2196134634848152, 0.24244436195918492, 0.11907917740089552, 0.20084584983331816, 0.20509016779916628, 0.23434240956391605, 0.21697199451071875, 0.20414123657558644, 0.2070997849638973, 0.31749223491975237, 0.215368779110057, 0.35268068100724903, 0.28840039883341106, 0.42745049031717436, 0.5308969265648297, 0.29665656866771833, 0.31690826054130283, 0.7993317310299192, 1.033661356994084, 4.053640288966043, 8.240624325616018, 15.064559595925466, 24.22724461555481, 41.28826311656407, 57.55082416534424, 85.08017063140869, 99.9141924721854, 76.28996985299247, 80.82057053702218, 47.110992499760215, 41.47333533423287, 19.572491782052175, 32.935343742370605, 46.934317180088584, 51.736988476344514, 72.79540116446358, 74.41457462310791, 74.36465876443046, 73.5245590209961, 77.19369425092424, 91.2491704395839, 84.92386395590646, 72.24190766470772, 47.61633150918143, 14.424147605895996, 1.3733132971184594, 0.16039431973227433, 0.14582306519150734, 0.23459002056292125, 0.2207585456115859, 0.09207494929432869, 0.10710623022168875, 0.16741266527346202, 0.11393926106393337, 0.10931562845196043, 0.10205231819834028, 0.12789321158613476, 0.18609923470233167, 0.13227415936333792, 0.10611395418111767, 0.12123409605451993, 0.12145903041320187, 0.20511258659618242, 0.26053250421370777, 0.1669330767222813, 0.08731073779719216, 0.16048877180687018, 0.13067815000457422, 0.11006101952599627, 0.11524891507412706, 0.09210026543587446, 0.10818309922303472, 0.20877324230968952, 0.06934357833649431, 0.1302641893603972, 0.07888631163431065, 0.15508314115660532, 0.1342116211141859, 0.0602092824078032, 0.12459368578025273, 0.1215755891587053, 0.06680735014379025, 0.15613750315138272, 0.16332962151084626, 0.1697285052921091, 0.13263580495757715, 0.08486681072307484, 0.11614302066820008, 0.14133287327630178, 0.1312011376555477, 0.18811760496880325, 0.17494914015488966, 0.20932118647864886, 0.20988192781805992], [0.055970942335469384, 0.11695791408419609, 0.07606001650648457, 0.024538486131599972, 0.09652332988168512, 0.06051025340067489, 0.03911976602726749, 0.019318375437121307, 0.042295452406896014, 0.017488961906305382, 0.03217837653521981, 0.07306361264948334, 0.061141060266111574, 0.039253674913197756, 0.05025546545428889, 0.03786947365318026, 0.025509486706661325, 0.02940023025231702, 0.05882085726729461, 0.08961932427648987, 0.00457485272948231, 0.013050066390340882, 0.011042550139661347, 0.04249026998877525, 0.08774586873395102, 0.031462016581956825, 0.03733109004263367, 0.05285238181906087, 0.0537924683386726, 0.031813104171305895, 0.040597978314118724, 0.08434783999941178, 0.035448470884667974, 0.044201250321098735, 0.021853261826825992, 0.06994903513363429, 0.05307263767878924, 0.02191178547218442, 0.006783471916735704, 0.057394400238990784, 0.011492764909884759, 0.10943085048347712, 1.5000901286091124, 15.36761222566877, 42.34956571034023, 54.346061365945, 60.740936688014436, 62.35968630654471, 60.424133573259624, 40.24288579395839, 21.613915954317363, 25.945733887808665, 23.220103229795182, 21.785305431910924, 28.09151652881077, 27.160054922103882, 41.508559226989746, 56.75071825299944, 75.30934279305595, 56.236089502062114, 51.503529003688264, 32.10621520451137, 17.488648857389176, 9.627419625009809, 4.699976486819131, 3.05880720274789, 0.9315082899161747, 0.4594222732952663, 0.22157365615878785, 0.07051799353212118, 0.03469991444477013, 0.6392141857317516, 1.2925833719117301, 0.041728685676519356, 0.14139567847762788, 0.030412889484848295, 0.18694551714829036, 0.05347782486517515, 0.07554674547697816, 0.02431925825242485, 0.08395864588341542, 0.013940608827397227, 0.03674776705780199, 0.042830545122602155, 0.06490667856165341, 0.07230771106800862, 0.01665916107594967, 0.19164617705558026, 0.059540837204882076, 0.1470838782510587, 0.15733585027711733, 0.08893615486366407, 0.06541995637651, 0.13354000715272768, 0.07812150088804108, 0.10167645051011018, 0.1957329391900982, 0.06412390699344021, 0.06428327451327018, 0.01388947103571679, 0.10140569468161889, 0.025187358991908174, 0.12333082354494504, 0.16564056250665868, 0.32796656287142206, 1.0423991509846278, 7.745222977229527, 18.01412374632699, 24.480938979557582, 48.97374200820923, 72.29189995356968, 77.84742941175188, 45.849953515189036, 33.9329765183585, 25.13381951195853, 15.552713973181588, 22.527685710362025, 26.22585572515215, 33.056603704180034, 41.535191672188894, 47.308265754154746, 65.01091044289726, 59.8763792855399, 68.53400843484062, 74.07687827519008, 75.1390493937901, 56.1022116116115, 19.385095391954692, 1.4865300676652362, 0.40975369992000715, 0.016874200697722178, 0.032094597816467285, 0.15354518725403718, 0.059247594725872786, 0.04472314892336726, 0.06373573067997183, 0.05180656258016825, 0.04414631612598896, 0.06037125550210476, 0.022305405332839916, 0.06044120567717722, 0.08040419447102717, 0.032580578167523654, 0.03693366190418601, 0.07473472904946123, 0.08668721161250557, 0.014103605661408176, 0.04914954836879458, 0.023955344654885784, 0.06390942885939564, 0.04648500241871391, 0.03776605813098805, 0.03281782454411898, 0.04066831864682691, 0.05501179576718381, 0.1435694604047707, 0.02195206331089139, 0.028990011728767837, 0.029655413702130318, 0.05424006057104894, 0.04179797427994864, 0.0048204408459631455, 0.021540238355685557, 0.011627360812521406, 0.045859413487570624, 0.029568452654140334, 0.034266883573893986, 0.04515942658430763, 0.03340898460841604, 0.043138566094317606, 0.044557762797921896, 0.05568283297387617, 0.053066228915538104, 0.02940705631460462, 0.04633954825944134, 0.018086369581786648, 0.012990458785290164, 0.027008782772879516, 0.03979712378765855, 0.009440084520195211, 0.06394053969000067, 0.026182420418730805, 0.023748170950316956, 0.03745876319174256, 0.03555382701701351, 0.028278264117294123, 0.05267735371100051, 0.1068292318710259, 0.00964949739032558, 0.016392900541956936, 0.03744565050250717, 0.02371004067494401, 0.01778594820228006, 0.03627322002180985, 0.008585299182284092, 0.028709888724344115, 0.054149347224405835, 0.01675687520764768, 0.04574342131880777, 0.03652326017618179, 0.036927365099212954, 0.04483238627601947, 0.01540985088130193, 0.052859231630074124, 0.0902980085728424, 0.045000975086752854, 0.055058367018188746, 0.033074748436255116, 0.08140501326748303, 0.02258243252124105, 0.01926598065931882, 0.050647193898579905, 0.006284113823702293, 0.015841076849028468, 0.04913067152457578, 0.0015575871012905346, 0.01060306470442031, 0.05127926962450147, 1.7012438433510917, 18.81188290459769, 46.686040673937114, 64.58709812164307, 69.34154197147915, 73.2397940499442, 65.86986759730748, 50.88738707133702, 30.28489433016096, 39.15290451049805, 32.250588348933626, 34.9578913961138, 35.7720604624067, 27.15557333401271, 36.91845417022705, 36.9118846484593, 54.09940031596592, 46.78541381018502, 49.47894205365862, 32.75290836606707, 20.862678459712438, 11.400713682174683, 6.4050344569342474, 3.8468671100480214, 1.0535553523472376, 0.3349146528967789, 0.3375202002269881, 0.12073605135083199, 0.009696747176349163, 0.8057634287646839, 1.53219493159226, 0.11910937220922538, 0.35443610538329395, 0.04578463553584047, 0.08251555796180453, 0.021976249691631113, 0.12507160513528756, 0.019140952100445117, 0.08612485535975013, 0.2127080668828317, 0.1559992041438818, 0.13835825717874936, 0.4941637547952788, 0.5603691765240261, 0.4373862514538424, 0.8508482266749654, 0.4379071220755577, 0.1984775997698307, 0.3937791942485741, 0.03283783793449402, 0.18540331561650547, 0.0865524002750005, 0.11221895766045366, 0.06872267808232989, 0.5096426584890911, 0.027081202815419862, 0.11028761629547391, 0.07206546728100095, 0.05306193378887006, 0.13210642550672802, 0.13675371184945107, 0.22168931923806667, 0.3140476111854826, 1.2479384818247385, 5.847629555634089, 15.074453830718994, 27.43223670550755, 45.988476276397705, 66.14630167824882, 67.90564809526715, 42.119427476610454, 22.875213759286062, 27.616494246891566, 26.066427571432932, 32.30807079587664, 41.40749420438494, 45.90224913188389, 53.185104233878, 56.67475707190377, 75.58027390071324, 68.9899492263794, 79.03832980564663, 84.95840345110211, 85.0938446862357, 65.78081948416573, 24.23427619252886, 1.5006902792624064, 0.3997642530926636, 0.03137509285339287, 0.027056958759203553, 0.1002137189997094, 0.09613368114722626, 0.06726707797497511, 0.03052184185279267, 0.025596008403226733, 0.048865815558071644, 0.03245674891929541, 0.04631323467141815, 0.04706086151834045, 0.0636288139170834, 0.07087289448827505, 0.04518863073151026, 0.006503264095434653, 0.056085523151393445, 0.009480102819257548, 0.06715507219944682, 0.08813658276838915, 0.09391605907252856, 0.059114825778773854, 0.03891110972368291, 0.028100074036046863, 0.04974755824410489, 0.06649171600916556, 0.03979233672310199, 0.020553619600832462, 0.019376948276268582, 0.02227305108681321, 0.0501748860281493, 0.030167497295354093, 0.037487736637038846, 0.03229389372946961, 0.03254414422969733, 0.04530336082513843, 0.025771742187706486, 0.06314994461302247, 0.05736511466758592, 0.022369755897670984, 0.019149957956480126, 0.03472476918250322, 0.018145149374114614, 0.035247424351317544, 0.023888626002839634, 0.10200137378914015, 0.03619093408009835, 0.15227720886468887, 0.1921486458075898, 0.12141671696943895, 0.12310588918626308, 0.20830251542585237, 0.1285376434347459, 0.12476754002273083, 0.15238297890339578, 0.08761537287916456, 0.1391376903546708, 0.12095003415431295, 0.3145778998732567, 0.14765819029084273, 0.131928825750947, 0.16209768690168858, 0.12098246812820435, 0.08824682435286896, 0.11939504902277674, 0.14644195698201656, 0.1863079113619668, 0.23326915715421948, 0.11349304286496979, 0.10341812098132712, 0.10877871047705412, 0.13105342058198793, 0.14378743299416133, 0.1085038562970502, 0.09608361883355038, 0.1560603944318635, 0.16094136823500904, 0.1710972868438278, 0.14674543855445726, 0.18790591561368533, 0.13135398445384844, 0.14307944955570356, 0.11014097130724362, 0.1582674245749201, 0.13365459814667702, 0.102976394684187, 0.1641128680535725, 0.15844794203128132, 0.4056024769587176, 4.1851531863212585, 29.06332458768572, 63.00274208613804, 75.60140337262834, 77.42522212437221, 79.9534353528704, 78.26509257725307, 56.87725189753941, 36.414536067417686, 40.23979384558541, 35.8958808353969, 34.4029735156468, 41.84384107589722, 40.45899908883231, 57.11071137019566, 71.93225424630302, 93.29149614061627, 72.1712166922433, 66.09646224975586, 42.97707142148699, 25.280119044440134, 14.536778773580279, 7.231205667768206, 5.141933594431196, 1.6838932143790382, 0.8244317727429527, 0.4262929638581616, 0.23135188860552652, 0.19195527689797537, 1.0251738067184175, 2.2045142437730516, 0.3196807274860995, 0.48384388855525423, 0.15685803948768548, 0.43694284238985603, 0.12735621897237642, 0.27274184620806147, 0.08319684104727847, 0.1932896567242486, 0.16317444055208138, 0.17521158392940248, 0.14560407479958876, 0.38112497755459374, 0.4288909930203642, 0.29303707288844244, 0.733877746122224, 0.3134707749954292, 0.601093165576458, 0.33495398078645977, 0.19303873447435244, 0.36826684751680916, 0.2320582435599395, 0.43163732279624256, 0.364093368606908, 0.6768123539430755, 0.45146905577608515, 0.30229948301400456, 0.3096176188971315, 0.22332013744328702, 0.2099183380071606, 0.4861206178154264, 0.8407976031303406, 0.6683799007109233, 2.149611532688141, 10.349913290568761, 23.032560927527292, 33.669730118342805, 63.34800502232143, 92.95482812608991, 97.78802285875592, 57.37498957770211, 46.57631472178868, 37.37638562066214, 26.026266983577184, 37.60562058857509, 39.81503656932286, 48.63361726488386, 58.71671799251011, 65.29758616856166, 82.85596888405937, 77.71202986580985, 85.11492552076066, 91.6619073322841, 93.96501282283238, 80.24646868024553, 33.77064228057861, 3.4610477558204105, 0.6196250425917762, 0.10379644496632473, 0.059530828813357015, 0.2274396185364042, 0.35555036844951765, 0.2607269180672509, 0.10935637447983027, 0.11988428634192262, 0.16337801462837628, 0.21761505571859224, 0.13445361384323665, 0.1453007153634514, 0.1569866490151201, 0.12560771565352166, 0.14150086497621878, 0.17830478080681392, 0.19395008842859948, 0.09512813296169043, 0.19481315783091954, 0.14775584505072661, 0.2568430650447096, 0.2144778219184705, 0.132999947560685, 0.15534705056675843, 0.13727015842284473, 0.24562335280435427, 0.2307169155350753, 0.07246004896504538, 0.0739687444376094, 0.10013190803251096, 0.1723672601261309, 0.14799509649830206, 0.08459154263670955, 0.09317031516028301, 0.06728140863456897, 0.21426956595054694, 0.06140403329793896, 0.10851056700838463, 0.11523671501449176, 0.1139234376272985, 0.09972813219896384, 0.12404561947499003, 0.15324112214148045, 0.16186496296099254, 0.07881221561027424, 0.18472440061824663, 0.1301891298166343], [0.1201477614896638, 0.08005749021789857, 0.04876232200435229, 0.04062393227858203, 0.046382438457970104, 0.0790044174396566, 0.041179506573826075, 0.028373991837725043, 0.011297533421644142, 0.005137753082505826, 0.034392093640885184, 0.04240671857925398, 0.0433123728393444, 0.013848063436203768, 0.06821156479418278, 0.05207173067278095, 0.0220281169084566, 0.043006485860262594, 0.0018711854188170815, 0.09596822038292885, 0.041825631367308755, 0.06965824216604233, 0.037407275954527516, 0.048751479014754295, 0.02981449623725244, 0.020821513707882593, 0.019488663978076408, 0.04162883246317506, 0.034115804359316826, 0.08262080552854709, 0.01777338682274733, 0.020060272055811117, 0.03146345168352127, 0.046742638772619624, 0.0051928208641973984, 0.0312570515088737, 0.1484126533780779, 0.08644739698086466, 0.20252609252929688, 0.09986549482813903, 2.4974381370203833, 18.662751981190272, 41.57301419121878, 56.80526161193848, 65.87888635907854, 63.0598840713501, 61.501958983285085, 52.82879366193499, 70.35760484422956, 78.68525709424699, 85.78547532217843, 37.10901199068342, 19.66633415222168, 25.34123192514692, 36.367288316999165, 75.84853690011161, 78.46816757747105, 65.27732522147042, 51.079539503370015, 34.25807925633022, 14.944468668528966, 4.782719978264399, 1.6022506867136275, 0.87507833221129, 0.24117976267422947, 0.24802281547869953, 0.039770060418439765, 0.0715280200487801, 0.04404157406783529, 0.3055615536868572, 0.03679988193990929, 1.2209332223449434, 1.2765834076063973, 0.17116362042725086, 0.06527877359517983, 1.7620523061071123, 0.5120851674250194, 0.09404700954577752, 0.050094696759645424, 0.1512704257454191, 0.17833904682525567, 0.060431807967168946, 0.13551871026200907, 0.1199891200023038, 0.32882786808269365, 0.4160197265446186, 0.34075184538960457, 0.49288061793361393, 0.2848670498601028, 0.15513361059129238, 0.24130032477634294, 0.19799938185938767, 0.08641036932489701, 0.0278795891707497, 0.2078441378793546, 0.11479277669319085, 0.07988162072641508, 0.28070836301360813, 0.07516622303852014, 0.01162770771354969, 0.03883618927959885, 0.030169655036713396, 0.038598830944725444, 0.04884694889187813, 0.08287807886621781, 0.13633705063589982, 0.02953509587262358, 0.03023395301508052, 0.9717550788606916, 5.16670218535832, 14.913561344146729, 31.02705226625715, 71.77950504847935, 77.41633537837437, 52.50367702756609, 28.677310466766357, 15.380464656012398, 29.373714515141078, 25.980235167912074, 23.38023141452244, 28.34917310306004, 32.21490240097046, 50.702127252306255, 59.41250365121024, 56.88560710634504, 69.31511797223772, 72.84139823913574, 69.28997938973563, 28.98615963118417, 6.423636521611895, 0.5837310286504882, 0.15080149019403116, 0.03873148454087121, 0.033495043204831224, 0.07382115628570318, 0.0690812702689852, 0.004377747212337064, 0.03285348155934896, 0.033380350430629084, 0.0770845026043909, 0.025208885515374795, 0.0043050108028442734, 0.023151390919727937, 0.014583038997703364, 0.029998949196721827, 0.06407523567655257, 0.05880107118615082, 0.01305159054962652, 0.01602558578763689, 0.013682785876361387, 0.022178824625111053, 0.008003305277920194, 0.07970664690115623, 0.012351942913872855, 0.034545707183757, 0.003185496087618438, 0.038032725785991976, 0.02713836430172835, 0.037777287885546684, 0.05644258184890662, 0.03096718474158219, 0.022685133885326128, 0.04215105676225253, 0.05330472718924284, 0.0020123533571937253, 0.03778703843376466, 0.03921814003427114, 0.029136439585792165, 0.03425151136304651, 0.020428921827780347, 0.01924295966247363, 0.025252608615638952, 0.04020037714924131, 0.03132636725370373, 0.03825473565874355, 0.0074294470084298935, 0.051542670133390596, 0.01571322897715228, 0.04614927346951195, 0.03080380368711693, 0.035985046199389865, 0.014037609649156886, 0.06101496810359614, 0.042293433765215535, 0.06437057482876948, 0.07929259804742676, 0.03683163398610694, 0.0833886561117002, 0.04681137437000871, 0.020959677008379782, 0.05128371063619852, 0.009609026169138295, 0.04956145644454019, 0.062321643345057964, 0.053114309906959534, 0.054322295622634034, 0.01145069149788469, 0.022395102573292594, 0.0655750830524734, 0.04786008416808077, 0.02459128463773855, 0.0585894768259355, 0.03950640545891864, 0.07105659427387373, 0.005248767348738121, 0.019656267216695205, 0.06207072788051196, 0.012619886214711835, 0.02746341310973678, 0.04957175999879837, 0.023503350426575968, 0.028983531719339744, 0.15679475931184633, 0.1610588226467371, 0.26705067445124897, 0.1385504997202328, 2.9856596078191484, 20.72383087021964, 45.750788824898855, 64.35709885188511, 73.62853186471122, 72.4389933177403, 69.75900363922119, 60.860133034842356, 74.72050380706787, 75.69427299499512, 70.43457004002163, 36.77670397077288, 25.49739268847874, 30.512562479291642, 43.07775429316929, 59.04557623182024, 63.09456947871617, 59.737220764160156, 51.720927715301514, 34.410053730010986, 15.74808863231114, 5.763879009655543, 2.1169291606971194, 0.9812013719763074, 0.35244778064744814, 0.16794409390006745, 0.08780000904308898, 0.07669410069606133, 0.0734306118850197, 0.16082077899149486, 0.023582979903689454, 1.5709145281996046, 2.1302477717399597, 0.09124893468937703, 0.17741485498845577, 1.6057487790073668, 1.184938622372491, 0.037962853642446656, 0.10427687490092856, 0.08625621973936047, 0.5271158580269132, 0.8465209645884377, 1.4824588575533457, 0.760931100164141, 1.2188062050512858, 1.4071302882262637, 0.46384914432253155, 1.3688914201089313, 0.8593329542449543, 0.2609796045081956, 0.1817579133702176, 0.11905021752629961, 0.1298878059855529, 0.05453553203759449, 0.3425481989979744, 0.27985254036528723, 0.49929879925080706, 0.5609949486596244, 0.292483849717038, 0.061601419134863784, 0.2311159484088421, 0.0756359864026308, 0.10085878867123808, 0.08125658373215369, 0.05794685666582414, 0.17403283289500646, 0.03692558055211391, 0.10273703467100859, 0.9477991014719009, 5.291890484946115, 16.993351731981548, 33.805716787065776, 52.59765836170742, 55.66991901397705, 45.960280486515586, 22.8384074143001, 21.73734549113682, 30.058278833116802, 41.153638294764924, 33.66886159351894, 40.714512143816265, 47.53981794629778, 59.821731703622, 70.75591727665493, 65.62368597303117, 80.13458183833531, 82.0028829574585, 81.86459296090263, 37.85705852508545, 10.056831325803484, 1.0386448438678468, 0.11823801110897746, 0.0957736029688801, 0.037932557053864, 0.06925068689244133, 0.06302665480013404, 0.031459940264799764, 0.060897696896323135, 0.022859442746266723, 0.07956982709999595, 0.01902875803144915, 0.014138150727376342, 0.012668917155159371, 0.05777269708258765, 0.06326879002153873, 0.042312548096690855, 0.07697723300329276, 0.01336658007598349, 0.010214534704573452, 0.024031591634931307, 0.021206514477463703, 0.019716641566316997, 0.02332304840508316, 0.011673836220454956, 0.016066779648619037, 0.017384206277451346, 0.07534781936556101, 0.024326370995757834, 0.012579535433490361, 0.058990402812404294, 0.023753366832222258, 0.04866747298677053, 0.025826445680909922, 0.06327254232019186, 0.042556888556906154, 0.010387982674209135, 0.06611265242099762, 0.01061303323201303, 0.028264932600515227, 0.05861227560256209, 0.03709540429658123, 0.014616000532571758, 0.015087675669097474, 0.05399612723184483, 0.047107602403100045, 0.058381770471377034, 0.2979809604585171, 0.14641690546912806, 0.13379474276942865, 0.1499890259334019, 0.18476505843656404, 0.12277762751494135, 0.14582196596477712, 0.19110143557190895, 0.12808793756578649, 0.14076384023896285, 0.09408845446471657, 0.12679025291332177, 0.16092644046459878, 0.16665863644863876, 0.19028272878910812, 0.22019222671432154, 0.1547055635601282, 0.13587992159383638, 0.1450727411678859, 0.16096126288175583, 0.23751119524240494, 0.15793741228325026, 0.1360481847077608, 0.18365630507469177, 0.1615816338786057, 0.19840283878147602, 0.18401130102574825, 0.22382143911506447, 0.1424116353903498, 0.15363289469054767, 0.13559001072176866, 0.09188521054706403, 0.0835039663527693, 0.2473661835704531, 0.0825589434908969, 0.11974039620586804, 0.41734018283230917, 0.2583727001079491, 0.33780298648136003, 0.23551779506461962, 4.776883491447993, 30.957591124943324, 59.47496795654297, 76.13663005828857, 83.49615505763462, 79.9203132901873, 78.14937727791923, 68.55554090227399, 83.17100020817348, 88.72199944087437, 94.81420775822231, 49.53692824499947, 30.007553509303502, 34.18694707325527, 48.061579023088726, 89.35259015219552, 92.69049085889543, 82.31064646584647, 68.47046715872628, 47.527592590876985, 20.308867079871042, 7.981379219463893, 3.1196221794400896, 1.5378229724509376, 0.5230714093361581, 0.5166139272706849, 0.20326319869075501, 0.24597923085093498, 0.24843083215611322, 0.47486160482679096, 0.10783644246735744, 2.6826942648206438, 2.868904250008719, 0.2554447129368782, 0.9589300070490155, 4.702761845929282, 2.5958717465400696, 0.3312904073723725, 0.45850348259721485, 0.3703209087252617, 0.6452842514429773, 0.4387634875518935, 0.9462434649467468, 0.5297880374959537, 0.667673790029117, 1.1260264750037874, 1.231209933757782, 2.8612212794167653, 0.7794123313256672, 0.5337064958044461, 0.3485398260610444, 1.1994724082095283, 0.8890524623649461, 0.36680710156049046, 0.7214785228882516, 0.4460371115377971, 0.47152755515916006, 0.45308008790016174, 0.34353294329983847, 0.2551198846527508, 0.512498965220792, 0.3378117260124002, 0.3439697027206421, 0.3227950946560928, 0.2948354349604675, 0.40767583570310045, 0.1440157193158354, 0.39754761489374296, 1.8417926558426447, 7.3558172668729505, 21.207109349114553, 43.7156023979187, 96.2867533820016, 107.77347360338483, 72.84110641479492, 45.67376456941877, 29.26904685156686, 41.74006278174264, 41.85437454496111, 36.41779129845755, 43.18320710318429, 46.80543851852417, 65.50500379289899, 77.51958560943604, 74.69615731920514, 86.17800685337612, 92.37442425319126, 91.24694006783622, 52.58914681843349, 16.436882666179113, 2.267435610294342, 0.2520637357873576, 0.1542371301246541, 0.1027866287955216, 0.1803097025092159, 0.1746647118457726, 0.1028700682467648, 0.09778552715267454, 0.08444632935736861, 0.3106467122478144, 0.13914303721061774, 0.11453544907271862, 0.10066934847938162, 0.16048679048461573, 0.12638071631746634, 0.1288322497691427, 0.17654204182326794, 0.07979255621986729, 0.06741731241345406, 0.09616193534540278, 0.0831947172326701, 0.134026313200593, 0.13597696567220346, 0.10709433550281183, 0.09998261675770793, 0.12761056103876658, 0.13419491558202676, 0.19641519258064882, 0.10739078066710915, 0.11584893002041749, 0.07989855696048055, 0.10887977148273162, 0.12193314997213227, 0.17716967314481735, 0.1306632086634636, 0.08066359840865646, 0.17369547885443481, 0.10839288868010044, 0.1010355945410473, 0.14099543781152793, 0.13169032069189207, 0.12275192460843495, 0.24926106046353066, 0.08688617165067367, 0.14812453383845942, 0.1264875177294016], [0.011244666213834924, 0.06453711446374655, 0.0339664655870625, 0.04307454292263303, 0.023915991320141723, 0.031018644837396483, 0.050558258313685656, 0.04116857876735074, 0.05385807588962572, 0.06231964845210314, 0.027726616843470504, 0.06961143682045595, 0.021197664684482982, 0.02369447168894112, 0.0387039801238903, 0.10282692699027912, 0.03782414412125945, 0.011081610856178616, 0.034227335160332065, 0.03295172664469906, 0.053451029517288716, 0.055983532552740405, 0.03397517119135175, 0.017863821970032792, 0.025078995253092477, 0.05658236684809838, 0.03241625055670738, 0.05989331579101937, 0.05051130708307028, 0.044892959097134214, 0.05937042313494852, 0.10280733089894056, 0.07569018777992044, 0.020837442317445363, 0.14721649113510335, 0.02588515422706093, 0.11911541117089135, 0.0488841631449759, 0.97654846736363, 10.01384803227016, 35.16348164422171, 59.303750446864534, 64.802659034729, 65.70353467123849, 60.541940280369346, 59.9502386365618, 48.643671308244976, 61.38385350363595, 59.45371341705322, 49.42995377949306, 66.44384438650948, 35.65266261781965, 24.415266343525477, 47.244491713387625, 57.28173433031355, 59.26138728005545, 49.640435559409006, 22.221125977379934, 10.529773490769522, 2.5963142599378313, 0.661308045898165, 0.04734309137399707, 0.02449649159929582, 0.024304552702233195, 0.04921046045741864, 0.04442994715645909, 0.0610276906351958, 0.07408271117934159, 0.03957481535949877, 0.09122677373566798, 0.060126874329788346, 1.7036334808383669, 1.4604056009224482, 0.8260932064482144, 5.21360947404589, 2.722371735743114, 2.769637942314148, 0.06369911014501538, 0.14337295666337013, 0.17291118736777986, 0.21975259030503885, 1.4976707441466195, 2.409321733883449, 0.7739781343511173, 2.2009337501866475, 2.854392720120294, 1.2075572886637278, 1.8334697995867049, 1.8366388295378004, 0.279276002730642, 0.44150409049221445, 0.20034762871052536, 0.18493101453142508, 0.05121123631085668, 0.36960217729210854, 0.09155040779816252, 0.1796874316143138, 0.1232388141964163, 0.11043744361294167, 0.10195289924740791, 0.1649135665169784, 0.061727172029869895, 0.04790378860863192, 0.045493774714746645, 0.08951900965933289, 0.047750192029135566, 0.08098074567637273, 0.010471729162548269, 0.1242402233183384, 0.08638359433306114, 1.2621070529733385, 8.150893551962715, 20.84878032548087, 35.035784176417756, 46.83921023777553, 70.91188349042619, 72.41446617671421, 52.30694225856236, 31.30819375174386, 30.944875921521867, 52.234889439174104, 31.39725923538208, 24.55278856413705, 32.57606281552996, 45.518590450286865, 56.52391862869263, 61.80828421456473, 63.05533994947161, 65.62775761740548, 59.840867042541504, 30.552782126835414, 8.466311369623456, 0.8412602011646543, 0.25629719719290733, 0.03808342592258539, 0.06429665522383791, 0.138643581154091, 0.0408080900753183, 0.02496541866899601, 0.01213298220786133, 0.09395548195711204, 0.01784053973720542, 0.0737069317006639, 0.04948880570009351, 0.0695732624403068, 0.01887088328866022, 0.035510678975177665, 0.040472547723246474, 0.06656170689633914, 0.04074102367407509, 0.01410883038105177, 0.004080002229394657, 0.048217468562402895, 0.013507878208266837, 0.032180388391550095, 0.013951036214296306, 0.0033148653622317526, 0.028279702611533657, 0.02575016816678856, 0.06697226808007274, 0.021201418679473654, 0.08169491056885038, 0.02417260138983173, 0.08047977648675442, 0.015266678296029568, 0.03458168989579592, 0.05941472468631608, 0.009320710702533168, 0.027122852991202047, 0.017638806187148606, 0.03526992117986083, 0.030965349304356744, 0.014583016945315259, 0.06804538478276559, 0.04675355300839458, 0.015615557253892933, 0.006437148067301938, 0.03304754936003259, 0.033050816506147385, 0.04712863698867815, 0.036041541025042534, 0.005561219578209732, 0.03084847843274474, 0.0705826918461493, 0.08414883246379239, 0.02856119116768241, 0.021651312841900756, 0.048615083297980685, 0.04723136719050152, 0.04774354238595281, 0.07973700455789055, 0.05897189237709556, 0.07834246581686394, 0.010991235080707287, 0.023560055598084415, 0.05126814843554582, 0.06229630684746163, 0.01989358483946749, 0.027909174993900315, 0.009890161038908576, 0.02116803136388106, 0.0349762478311147, 0.05148595478385687, 0.02399663351077054, 0.03845739371276327, 0.056164002511650324, 0.05188267046053495, 0.05523477255233696, 0.012010991789533623, 0.03843017767316528, 0.08855533386979784, 0.05903428367206028, 0.01876117435417005, 0.0884771327088986, 1.1563568817717689, 12.378916689327784, 42.239172731127056, 69.72766726357597, 75.90574836730957, 75.25570964813232, 66.23270947592599, 66.9314967564174, 56.96988180705479, 66.91425827571324, 71.9555585043771, 70.01414149148124, 91.32337025233677, 44.805107729775564, 25.329522473471506, 33.68236889157976, 39.58927917480469, 53.012420654296875, 42.78493288585118, 24.746384484427317, 12.599878089768545, 3.744087185178484, 0.7621684766241482, 0.29170939698815346, 0.04413036037502544, 0.041323722406689606, 0.026514307163389664, 0.023946420223053013, 0.04334623173677495, 0.04157864122784563, 0.1102843661127346, 0.514014541038445, 0.29711517691612244, 2.2306412075247084, 1.477541161434991, 0.8639059545738357, 6.859888289655958, 2.825827590056828, 3.777240949017661, 0.09111995875303235, 0.22568526624568871, 0.17081873464797223, 0.9489902832678386, 3.2930053557668413, 3.70720397574561, 2.9522372526781897, 4.360282966068812, 3.9239921144076755, 2.6444539853504727, 2.053384844745908, 1.2179815407310213, 0.17323556781879493, 0.31911241369588034, 0.21632649057677814, 0.058534963322537284, 0.03296304800148521, 0.7456894665956497, 0.1849795976387603, 0.5746099980814117, 0.9819863012858799, 0.3159700094589165, 0.25477820155876024, 0.6121260906968797, 0.2119452713855675, 0.13731222759400094, 0.12065776198038033, 0.17761024593242578, 0.0479614810485925, 0.12605784221419267, 0.11227808520197868, 0.06533403348709856, 0.2052700881447111, 1.2124418722731727, 7.112624670778002, 20.858903850827897, 36.70037106105259, 44.70002317428589, 54.317615440913606, 59.657316480364116, 61.138637678963796, 38.05825056348528, 30.688608986990793, 42.62822321483067, 35.74974979673113, 39.6278520992824, 44.66911063875471, 55.60471017020089, 63.118158612932476, 70.85688155038017, 70.89632647378104, 77.55652918134416, 70.95780413491386, 39.010195459638325, 12.465423498834882, 0.983876211302621, 0.21744498770151818, 0.017510108450161557, 0.12282174586185388, 0.08515801759702818, 0.08779276907444, 0.03078387850629432, 0.03218959950442825, 0.05308835594249623, 0.017622027712474977, 0.03548296421234097, 0.045703034914497814, 0.021788130946723477, 0.03923809914184468, 0.04914137541449495, 0.026835746165098887, 0.0621726709817137, 0.047215733743671856, 0.10274498710142714, 0.025365072402304838, 0.018391807031418596, 0.013981754342759294, 0.022511841130575964, 0.023201285295986702, 0.03596993861719966, 0.04262108475502048, 0.016655659835253443, 0.05038639557148729, 0.07255490816065244, 0.018831918415214335, 0.09555531146803073, 0.017586540330999663, 0.0414591240696609, 0.022910643302436386, 0.06534968728997878, 0.04498520932559456, 0.12825716419943742, 0.028036685294604728, 0.015256673297179597, 0.004801465190082256, 0.025893581631992544, 0.02505698357708752, 0.07067192598645176, 0.030936284256832938, 0.1367783019585269, 0.11852591351738997, 0.14469760629747594, 0.21565069683960505, 0.08290460280009679, 0.15646291497562612, 0.09874331325824771, 0.16742365754076413, 0.1603528205305338, 0.1271150947681495, 0.18149424823267118, 0.1492815310401576, 0.09325819901589837, 0.10055692879749195, 0.182787970240627, 0.2567949433411871, 0.2082202091280903, 0.08237915885235582, 0.1925856223595994, 0.1788379464830671, 0.18430493026971817, 0.1307196356356144, 0.10061122516968421, 0.11748764637325491, 0.13070302509835788, 0.16943965293467045, 0.15791313430028303, 0.12286176585725375, 0.14024856074580125, 0.19294485236917222, 0.17709989260349954, 0.272449289049421, 0.13152923647846493, 0.09479895526809351, 0.23708591663411685, 0.12672800411071095, 0.22395459482712404, 0.15329989684479578, 2.3752249692167555, 18.14896743638175, 52.80821309770857, 78.93475300925118, 81.42092268807548, 82.41701643807548, 76.68949127197266, 77.6249897820609, 64.22848074776786, 73.17824690682548, 69.78116839272636, 58.964080810546875, 71.74422209603446, 46.56232104982649, 35.43924869809832, 60.74527931213379, 72.51392269134521, 75.34060273851667, 61.632473945617676, 32.15949746540615, 15.210930347442627, 4.9972243309021, 1.125080977167402, 0.6207003848893302, 0.21562303975224495, 0.2453130723110267, 0.09974483094577279, 0.19945410665656838, 0.26975699780242784, 0.22767454093056066, 0.26422009776745525, 0.6341790216309684, 0.2693167099995272, 3.697323637349265, 2.1890256234577725, 1.2910262154681342, 10.422528914042882, 3.9350996783801486, 5.781226055962699, 0.41410039524946896, 0.5287521587950843, 0.41443985274859835, 2.242751483406339, 3.528129139116832, 5.101635779653277, 3.540695173399789, 7.054209428174155, 7.645022136824472, 6.483377133096967, 4.050960455621992, 4.137469002178737, 1.6340948236840112, 1.197850980928966, 0.7204229395304407, 1.0631878354719706, 0.2042298261076212, 1.2598488884312766, 0.25576367867844446, 0.9312641258750642, 0.884630693921021, 0.43823670010481564, 0.6453519963792392, 0.36805164335029467, 0.2290587659393038, 0.48178423621824806, 0.3805029237908976, 0.5091495535203389, 0.1774950171155589, 0.309966793017728, 0.2885454153375966, 0.3335019972707544, 0.5498035720416478, 2.1985822192260196, 12.133850250925336, 29.671020984649658, 46.61769124439785, 65.04508168356759, 92.8314072745187, 88.59418732779366, 67.4806615284511, 42.90924310684204, 42.781587328229634, 66.59755243573869, 41.36106634140015, 39.44303349086216, 48.11106409345354, 63.083987372262136, 74.51435075487409, 80.66116496494838, 80.97731494903564, 87.48856912340436, 84.13197081429618, 50.17597838810512, 17.096654074532644, 1.446233338543347, 0.38026996914829525, 0.1559765682156597, 0.18780467818890298, 0.2419503613242081, 0.23317766349230493, 0.1562848538160324, 0.13965712248214654, 0.22767764862094605, 0.1261518057435751, 0.15184089727699757, 0.11198153147207839, 0.1848748725439821, 0.1475842028324093, 0.13826926052570343, 0.1707857714167663, 0.13563616467373713, 0.13126441783138684, 0.16557441891304084, 0.15585289842316083, 0.1622752459453685, 0.08977916677083288, 0.10675386020115443, 0.10841159589056458, 0.1287381641034569, 0.07716867487345423, 0.1434951608202287, 0.1409421999539648, 0.19451353033738478, 0.14121289471430437, 0.220496427533882, 0.21190763983343328, 0.10759949125349522, 0.16479459218680859, 0.26023541444114273, 0.2678698290671621, 0.25819565675088335, 0.10742430708238057, 0.0945408676884004, 0.10091991110571794, 0.12995715226445878, 0.2080207605447088, 0.1287079014416252, 0.26311009590114864], [0.05718141488198723, 0.053261877702815194, 0.032870085311255286, 0.01187909221542733, 0.08416060504636594, 0.017965832924736396, 0.09342746636165039, 0.05101038994533675, 0.054233159869909286, 0.029496918099799325, 0.027676082947956662, 0.02307002608930426, 0.041808776557445526, 0.02886207395100168, 0.07239816657134465, 0.07354767953178712, 0.05440797423943877, 0.07813958384628807, 0.031824961570756774, 0.05953643351261105, 0.03205958201682993, 0.00318876895887245, 0.02779605472460389, 0.07217230940503733, 0.022244172636419535, 0.03502166896526303, 0.04940548499247857, 0.08182681099112545, 0.050675071509821076, 0.03167948027008346, 0.012109540519304574, 0.0863800523802638, 0.036289657532636604, 0.06988578209919588, 0.07399069504546267, 0.04010420838104827, 1.0063786038330622, 6.819789367062705, 31.27309145246233, 61.810563223702566, 64.74268913269043, 66.29074083055768, 64.58241503579276, 59.11471080780029, 51.476601260049, 44.87495449611119, 42.641570704323904, 34.19043159484863, 14.021888596670967, 17.298368964876445, 11.540259565625872, 18.529871157237462, 44.971791539873394, 63.44259779793875, 47.89355073656355, 18.945222309657506, 7.683399643216815, 1.7010754581008638, 0.45888514497450417, 0.11581984800951821, 0.029815096740743945, 0.08522479901356356, 0.033378348752324066, 0.08799017526741539, 0.08130053923066173, 0.074675703288189, 0.07595890800335578, 0.026130831401262964, 0.08884228632918426, 0.16509511534656796, 0.08688252113227334, 0.4040668165045125, 5.259884476661682, 7.244914463588169, 2.612508556672505, 0.07287946503077235, 0.1669302133045026, 0.09527512400278024, 0.2898588962852955, 0.009971546225382813, 1.638231064592089, 3.594655535050801, 2.7812079957553317, 2.7636798620224, 4.061546470437731, 3.3069189063140323, 0.358517412096262, 1.564537601811545, 2.1365691125392914, 0.06466109638235398, 0.12445974296757153, 0.034673902804830244, 0.10455892155213015, 0.024755983746477535, 0.15112524639282907, 0.13206686691514083, 1.219501024910382, 2.617744024310793, 0.33517363614269663, 0.08506925843123879, 0.24850718091641152, 0.2811030532632555, 0.026340534345113804, 0.06046006895069565, 0.08030736073851585, 0.06523880788258143, 0.022821129266438738, 0.04548886212121163, 0.02388322656042874, 0.03466353478974529, 0.029597466811537743, 0.13930873546217168, 0.9404069781303406, 7.304245999881199, 23.684915133884974, 47.00938204356602, 70.39031001499721, 48.7506422996521, 47.609873158591135, 44.461585317339214, 101.60391793932233, 36.942981311253135, 15.416124548230853, 20.251980440957205, 36.16360534940447, 36.13619123186384, 44.62984984261649, 57.678240231105256, 57.9764986038208, 62.63683605194092, 68.55832018171037, 58.61905411311558, 28.979445934295654, 2.647611290216446, 0.2213126373078142, 0.08904906987611737, 0.06205616651901177, 0.02132317330688238, 0.02209076265405331, 0.06377281940409116, 0.02558221887531025, 0.06987500696309976, 0.06387348685945783, 0.024745485113401498, 0.05620164084913475, 0.06263882453952517, 0.02180557438571538, 0.01997073257475027, 0.029880208961133446, 0.02092910391677703, 0.08996649671878133, 0.04840801137366465, 0.049474244338593314, 0.030697969187583243, 0.03256003212715898, 0.09233948295669896, 0.031044690404087305, 0.05093111330643296, 0.04872243432328105, 0.022024474871744002, 0.09254838353289024, 0.04161201836541295, 0.04288046494392412, 0.038595075253397226, 0.03727839162041034, 0.027372133186353103, 0.031160217776362385, 0.03758292492212994, 0.014859944049801146, 0.015077786021200674, 0.04643678232761366, 0.006253903324250132, 0.044051996365721734, 0.02107096353678831, 0.09140825471175568, 0.07154728365795952, 0.06914415689451353, 0.018546024470457008, 0.03291455310370241, 0.009911528954814588, 0.0530894246351506, 0.03102339118985193, 0.02191176511613386, 0.00797958454183702, 0.0226315805089793, 0.03687467006966472, 0.008616175918307687, 0.01769928740603583, 0.05472111136519483, 0.026684193672346215, 0.03770137678033539, 0.02399992270927344, 0.07607520890555211, 0.06688484562827007, 0.03772422644708838, 0.0711394501850009, 0.010112589058865393, 0.05959000385233334, 0.02328831928649119, 0.06044707500508853, 0.03592158621177077, 0.03303517966664263, 0.03761453108329858, 0.07460308647049324, 0.0348678586472358, 0.052225700446537564, 0.021924769239766256, 0.09081124567559787, 0.03366832747789366, 0.0446600757007088, 0.042851294723472426, 0.05573519891394036, 0.7731364795139858, 7.486606683049883, 37.64361681256975, 71.3443671635219, 75.83994197845459, 73.41908536638532, 71.59130614144462, 68.33122525896344, 63.163523401532856, 52.22423437663487, 51.60767207826887, 41.98382990700858, 25.72202968597412, 20.413015365600586, 15.610248531614031, 22.138011625834874, 40.02854428972517, 52.507891110011506, 46.04700442722866, 21.225839955466135, 8.074024762426104, 1.8836344906261988, 0.5109095647931099, 0.15947499977690832, 0.01391611625773034, 0.12771595109786305, 0.10442171498600926, 0.020676746565316404, 0.0761493117149387, 0.08131495809980802, 0.2140477392822504, 0.5462241098284721, 0.22284421298120702, 0.4610933150563921, 0.6987418457865715, 0.9594327743564333, 5.072747341224125, 8.66825555052076, 1.717205701129777, 0.19030642323195934, 0.7248285316995212, 0.403283597103187, 0.09521640358226639, 0.03959624349538769, 1.819621388401304, 4.690982478005545, 4.7193150605474194, 5.640340038708278, 5.586560547351837, 4.084657916000911, 2.3259535559586118, 3.1596105822495053, 1.4498850511653083, 0.5547380415456635, 0.019266698210101043, 0.035454289322452884, 0.08126363371099744, 0.1488829188581024, 0.36358984134026934, 0.21791430323251657, 1.116524270602635, 2.4784139692783356, 1.8807301436151778, 0.4580667774592127, 0.8290977052279881, 0.3677340346787657, 0.07848528386758906, 0.23303788527846336, 0.09024394290255648, 0.13260132180792944, 0.053453906505767784, 0.10119933861174754, 0.02587584642294262, 0.0886413517541119, 0.03215424443728157, 0.10032423878354685, 1.1144837800945555, 6.426794912133898, 21.061320509229386, 49.28741148539952, 66.84674263000488, 39.73567424501692, 32.87360552379063, 40.98658275604248, 95.23298958369664, 34.05007798331124, 17.648900372641428, 23.3424106325422, 44.01486825942993, 48.46631506511143, 52.95286764417376, 64.3683340890067, 66.1264784676688, 71.27930423191616, 80.06525271279472, 69.97979654584611, 37.97837059838431, 5.72552365064621, 0.17676015011966228, 0.04069981963506766, 0.0868826364832265, 0.06462566328368016, 0.05010323951553021, 0.07818100840917655, 0.01680966523209853, 0.006693326843170715, 0.06926743992205177, 0.0808350234957678, 0.06027291542185204, 0.04204556492290326, 0.042329236665474515, 0.03887326104034271, 0.01761128311045468, 0.034667151381394694, 0.07149456827236073, 0.058015327634555955, 0.06742543447762728, 0.062193624143089564, 0.019296733562701514, 0.03877900234822716, 0.050888966103749614, 0.012105495602424656, 0.061594070600611825, 0.024322695032294308, 0.04850581201857754, 0.018987472568239485, 0.023631669880290116, 0.07678208633192948, 0.036281369227383814, 0.10698713375521557, 0.02653634428445782, 0.03352585208735295, 0.04913415240922144, 0.02950101305863687, 0.12722595381949628, 0.023079688427969813, 0.023364288067179065, 0.05255008429022772, 0.032363073767295907, 0.02834904210508934, 0.12425669814859118, 0.14522604936999933, 0.06606623384037189, 0.13044987725360052, 0.1725535179887499, 0.06961929425597191, 0.17990699197564805, 0.14031641424766608, 0.10863961758358137, 0.21319853913571152, 0.05167986312881112, 0.11661043630114623, 0.10500528224344764, 0.16507056594959327, 0.1024888740586383, 0.11360009533486196, 0.28885298169084955, 0.1889179234525987, 0.10093095765582152, 0.14330143907240459, 0.15566548705101013, 0.12057489928390298, 0.1593461866889681, 0.1554574210728918, 0.14681850320526532, 0.10409545499299254, 0.0930908519242491, 0.21802550155137265, 0.17743196764162608, 0.13733812049031258, 0.11799349422965731, 0.2011128669338567, 0.11183971086783068, 0.17879162968269416, 0.13522201403975487, 0.15236829540559224, 1.7747314657483781, 12.798529693058558, 50.12423515319824, 84.04361752101353, 84.33469145638603, 81.95982497079032, 81.54404476710728, 75.4171371459961, 68.9037846156529, 60.04241343906948, 57.93853712081909, 46.79878909247262, 24.712145498820714, 25.80424424580165, 22.00108347620283, 29.192759105137416, 60.197031702314106, 83.99547345297677, 64.27797971452985, 27.37066524369376, 10.942217690604073, 2.8741720701966966, 0.7616191346730504, 0.26171375225697247, 0.16862765007785388, 0.14043882196503027, 0.28638797253370285, 0.22559656814805099, 0.2401539534330368, 0.24995674884745053, 0.2817371849502836, 0.27816350385546684, 0.2240165722157274, 0.5781133558068956, 0.38211373878376825, 0.802853599190712, 9.63155814579555, 11.434779831341334, 3.9381929295403615, 0.18721585907042027, 1.2406303882598877, 0.27100818923541475, 0.7755552668656621, 0.08648549672216177, 5.784254167761121, 11.745452029364449, 8.67850935459137, 11.468160714421954, 14.60024448803493, 12.621177792549133, 5.120625640664782, 5.079652113573892, 4.4184519818850925, 1.5113591296332223, 0.5813054016658238, 0.2544813560588019, 0.30187648428337915, 0.23220320578132356, 0.6518953538366726, 0.9269758931228093, 4.969160991055625, 7.026635502065931, 1.4309156004871642, 0.32929440162011553, 1.0802745414631707, 1.263365545443126, 0.20663108011441572, 0.35014475136995316, 0.312797233994518, 0.20694875663944653, 0.2032275620315756, 0.37750930871282307, 0.10255096001284462, 0.2100459975855691, 0.12626718383814606, 0.3401549517043999, 1.7133813691990716, 10.803453479494367, 32.085078784397666, 59.604371207101, 84.55557468959263, 60.53317165374756, 62.18550886426653, 57.49653441565377, 105.0068746294294, 46.262099811008994, 26.363322360174998, 33.8966235433306, 50.09497628893171, 55.009051527295796, 62.284228869846885, 76.05148683275495, 76.84224741799491, 78.39203616550991, 91.1908403124128, 82.11928612845284, 46.92072997774397, 7.6954434769494195, 0.46983214042016436, 0.18001623611365045, 0.18941756949893065, 0.18138743325003556, 0.1287049294582435, 0.18064888859433786, 0.10179847824786391, 0.19793159621102469, 0.19899743901831762, 0.12170638356889997, 0.18542588369122573, 0.28054383184228626, 0.11420475824603013, 0.11866318115166255, 0.15694772824645042, 0.1595877180142062, 0.17231311303164276, 0.16310441573815687, 0.1664616713034255, 0.13908870012632438, 0.12533400819769927, 0.16282583640090056, 0.13271066094083445, 0.13585529077265943, 0.10836458698447261, 0.1653714148061616, 0.27068954919065746, 0.16717952064105443, 0.13467601048094885, 0.1352572842900242, 0.1614504594888006, 0.24648585223725863, 0.1372066339743989, 0.17328131464975222, 0.1644195658820016, 0.14388663481388772, 0.2312308650996004, 0.10373107490262815, 0.13307523780635425, 0.09637070699994053, 0.08847175192620073, 0.13411579839885235], [0.05148387507402471, 0.024812376791877404, 0.059980894305876324, 0.03340602958840983, 0.0578208662835615, 0.015661434702841297, 0.02505758068790393, 0.021964874052043473, 0.05659841759396451, 0.09236990168158497, 0.05185871817437666, 0.03192294881279979, 0.014334206635664617, 0.06615299811320645, 0.04852138100458043, 0.025563325067715983, 0.048550558010382314, 0.0042393587230305585, 0.03551517426967621, 0.020683833863586187, 0.028197072313300202, 0.08040326487805162, 0.06200575136712619, 0.06032069107251508, 0.01587629790550896, 0.023454085391547, 0.02135431467156325, 0.025933898486463085, 0.043019303386764865, 0.07702082887824092, 0.025207324884831905, 0.07571623673928635, 0.03801203725327339, 0.03393495102812137, 0.17091096112770693, 1.3981687405279704, 20.78498717716762, 51.48506416593279, 66.31270408630371, 64.1077766418457, 65.92884390694755, 60.086624826703755, 53.20084537778582, 36.92969635554722, 24.18079764502389, 32.46447822025844, 20.895737988608225, 29.408323492322648, 31.28078658240182, 43.682779107775005, 61.803969383239746, 52.39443397521973, 48.409464904240195, 20.019712584359304, 4.382577564035143, 0.21098703066153185, 0.019412354233541658, 0.0772141163636531, 0.051568447678749046, 0.0626559779047966, 0.09813945780375175, 0.04302494540544493, 0.059684170942221365, 0.05511337924482567, 0.07345459809792892, 0.024288965056517293, 0.22363796324602195, 0.19912007743758814, 0.2312505426151412, 1.793169922062329, 0.6040090205413955, 0.051938222122511694, 1.5001727470329829, 1.5725640739713396, 0.05643890418910554, 0.16225098153310163, 1.0707398759467261, 0.4104600005916187, 0.13018508574792317, 0.11290798961584057, 0.6615663234676633, 3.817507496901921, 2.7593326781477248, 3.756213528769357, 4.246842767511096, 3.0707997935158864, 2.2039277723857333, 1.9736659909997667, 0.6113761737942696, 0.1967836506664753, 0.09829252173325845, 0.11102080052452427, 0.07396941618727786, 0.025840766162478497, 0.14161458744534425, 0.24825810428176606, 0.8877857189093317, 1.0688731989690234, 0.2731050524328436, 0.20732013242585318, 2.052232095173427, 1.8767577282020023, 0.08996604888566903, 0.08039094946746315, 0.14790764690509864, 0.06395349970885686, 0.025108555631179894, 0.02510395855642855, 0.0949686500909073, 0.1660482127751623, 0.11743250861763954, 0.08468657146607127, 0.008903999447024294, 0.022197718432705318, 0.5226063142929758, 3.8491092068808417, 18.577179704393657, 58.50274821690151, 64.18019076756069, 39.53414869308472, 41.238138811928884, 58.798303740365164, 48.67297880990164, 39.630752972194124, 26.05502384049552, 15.329553467886788, 27.604538134166173, 40.58324677603585, 50.66429083687918, 63.36151232038225, 63.91831316266741, 64.69899885995048, 72.82104696546281, 61.47132437569754, 13.532116157667977, 0.8616307452321053, 0.09751147364399262, 0.010611101103547429, 0.09938370782349791, 0.03277555859780737, 0.07090149473931108, 0.02814632298291794, 0.02778460274982665, 0.051449337641575506, 0.08719142419951302, 0.045372995481427224, 0.010352904958251332, 0.012218115452144827, 0.09789333958178759, 0.05603460588359407, 0.07975398828940732, 0.014147549285553396, 0.010025875676157219, 0.0051996596490166015, 0.06674999357866389, 0.045555640145071914, 0.024837141623720527, 0.019802364287897944, 0.0549481457897595, 0.015315682095076357, 0.012757118225895932, 0.005943574061218117, 0.014998349926567503, 0.03730822341250522, 0.06608777732721396, 0.036640331215624294, 0.019449717764343535, 0.02694012690335512, 0.013618778819883508, 0.01771882751823536, 0.012612893911344665, 0.026322753334950124, 0.04192697396501899, 0.03641658429322498, 0.031146046572497914, 0.010051677818410099, 0.013964455940627625, 0.03807074749576194, 0.018549820873886347, 0.06836021824606828, 0.06944432721606322, 0.008465644620758082, 0.025070299826828495, 0.04194230207109025, 0.07114886146570955, 0.03420013269143445, 0.012733644306925791, 0.037892340283308706, 0.05359385096068893, 0.014340559419776713, 0.02934995759278536, 0.02891553911779608, 0.04603411929149713, 0.012865040068780738, 0.011081165567572628, 0.010204479663765855, 0.0514868402720562, 0.0293377880672259, 0.03202286309429577, 0.04233010519029839, 0.03624737123027444, 0.019772527406790426, 0.08445624275399105, 0.05808014129953725, 0.0739541355786579, 0.03734893551362412, 0.02714638628198632, 0.07575027884117194, 0.0299876651593617, 0.025177454076973454, 0.04247800886098828, 1.8473551230771201, 23.713720628193446, 58.71369552612305, 75.23824882507324, 73.18857192993164, 74.99005917140416, 66.79660442897251, 62.13476616995675, 48.20362104688372, 39.604061467306956, 44.09763172694615, 31.405993121010916, 35.6509325163705, 22.688890865870885, 34.373968260628835, 45.97012955801827, 43.60631765638079, 44.149767535073416, 23.420253038406372, 5.236422147069659, 0.2917599342763424, 0.06418145354837179, 0.0670481486512082, 0.07286856097302266, 0.03366541316998856, 0.05964058863797358, 0.009189535464559282, 0.09276115175868783, 0.1444390301725694, 0.2737866001469748, 0.19592729876083986, 0.5219357045633453, 1.9488142388207572, 2.242699806179319, 2.5875080696174075, 4.503555255276816, 1.1685726834195, 1.7643100363867623, 2.321856290102005, 0.3539322524198464, 1.8813737205096652, 1.2587409764528275, 0.0909363403916359, 0.16526617402476923, 0.09892228365476642, 1.2811714985540934, 1.9025255569389887, 4.195520767143794, 5.598142760140555, 4.182647492204394, 3.050843915769032, 3.0365595051220486, 3.2017715999058316, 0.7566383076565606, 0.0869773735425302, 0.217670790585024, 0.22738230946872914, 0.23869602595056805, 0.3544868326612881, 0.7814768691148076, 0.5893300282103675, 1.5223192615168435, 2.3707826818738664, 2.9416705625397817, 1.4875978103705814, 3.5259091896670203, 2.063761545079095, 1.1204895206860133, 0.5266175419092178, 0.3595165141991207, 0.1756244996296508, 0.20197501352855138, 0.12631097648824963, 0.16226371085005148, 0.11179794703743287, 0.050186254882386754, 0.15145969630352088, 0.08776505770427839, 0.044167374460292716, 0.623854975615229, 5.009434921400888, 18.808844804763794, 47.25139822278704, 47.11207641874041, 42.70491395677839, 55.33045434951782, 47.231519426618306, 37.26283121109009, 37.71833426611764, 34.13869530814034, 23.834992749350413, 37.51232017789568, 47.0513595853533, 59.57420212881905, 69.95607539585659, 70.68817928859166, 74.29717785971505, 84.75046471187046, 75.26535374777657, 21.629830803189957, 0.6493396109768322, 0.06082736674164023, 0.08405739987002951, 0.011785203324896949, 0.025624316884204745, 0.04439760817747031, 0.039534140577805896, 0.047504263796976635, 0.036932413399751694, 0.02564297829355512, 0.1122118533988084, 0.01093444339598396, 0.030383766761847904, 0.02778563921206764, 0.0018335292697884142, 0.06518176344356366, 0.021099867432245185, 0.034263385725872855, 0.012541497608513703, 0.04650096156235252, 0.07151694635727576, 0.03714544964688165, 0.01243861812898623, 0.04055924753525427, 0.0490654948433595, 0.014169300573744943, 0.0081219081101673, 0.03262227075174451, 0.04777485677706344, 0.031955694912799766, 0.050886201073548624, 0.026545855649081723, 0.011792100633361509, 0.012759741611911781, 0.013625458148973328, 0.005688377040704446, 0.027786051422091465, 0.021400361754266278, 0.013814671879767306, 0.06987168892685856, 0.0119888265949807, 0.18138490909976618, 0.09833877746547971, 0.17066375724971294, 0.18913673742541245, 0.13862465002707072, 0.09063783926623208, 0.09594647333558116, 0.1261042540094682, 0.1810205222240516, 0.20834169403782912, 0.1608491688966751, 0.12643679045140743, 0.14348802263183252, 0.1347914021462202, 0.0982493736914226, 0.13663036775376114, 0.1158275833087308, 0.11785539878266198, 0.13276954420975276, 0.09078299147742135, 0.10322642805320875, 0.1274816800973245, 0.10451417216765028, 0.2637964205018112, 0.09569505575512137, 0.09256251063197851, 0.24216545692511968, 0.2044239685471569, 0.18210524187556335, 0.20698774526161806, 0.1348313542881182, 0.19992087089589664, 0.10797175592077629, 0.1243516659098012, 0.21343029955668108, 3.183338680437633, 32.48792839050293, 70.70681435721261, 84.0223560333252, 79.94952351706368, 83.32236671447754, 74.73336492265973, 70.41899912697929, 52.761621952056885, 38.77949442182268, 47.07538993018014, 33.31168597085135, 43.5793308530535, 45.0454216003418, 60.81045341491699, 85.22747938973563, 68.96408108302525, 66.58419799804688, 28.315990243639263, 6.002749391964503, 0.5333672825779233, 0.14664160912590368, 0.13049156644514628, 0.20545775736016886, 0.16255685154880795, 0.1921857481024095, 0.09897102282515594, 0.29767906665802, 0.198306052546416, 0.4274180292018822, 0.147661474400333, 0.49831834329026087, 0.8766157297151429, 1.2288809844425745, 3.633275577000209, 3.8108823895454407, 0.39168816645230564, 4.436230685029711, 4.554167670863015, 0.15566467280898774, 1.182372782911573, 3.844311475753784, 1.164417877793312, 0.5965752622910908, 0.39631870655076845, 5.8762626477650235, 12.636403032711574, 9.251383985791888, 12.957191807883126, 11.67201564993177, 9.343712517193385, 6.525823678289141, 6.213427458490644, 2.524214105946677, 0.36612767087561743, 0.4307364454226834, 0.23412560405475752, 0.38525448739528656, 0.23989700579217502, 1.286178327032498, 1.254134429352624, 3.1454892371382033, 4.1516624348504205, 2.2277136274746487, 0.7457239361745971, 3.8252382363591875, 3.4360685476234982, 0.5471559283988816, 0.406172582081386, 0.46241238713264465, 0.3326975261526448, 0.26867796427437235, 0.32818961090275217, 0.3549320330577237, 0.26080828798668726, 0.39308179595640724, 0.43737756620560375, 0.1683943425970418, 0.11654417057122503, 1.0295437893697192, 6.459622544901712, 26.91981748172215, 77.02352591923305, 82.09593323298863, 53.021380356379915, 55.58678034373692, 68.5199522290911, 62.21356569017683, 54.371519565582275, 39.232454436165945, 26.739803552627563, 43.278331415993826, 54.77380984170096, 68.55880655561174, 81.10795497894287, 81.17490087236676, 81.84307438986642, 93.89583655766079, 86.47037315368652, 28.059897014072963, 1.2464098781347275, 0.23114447402102606, 0.251224333686488, 0.1544217187911272, 0.10596416079040084, 0.18632795528641768, 0.21009631774255208, 0.12541119834142073, 0.12259552228663649, 0.20729191893977778, 0.24063983878919057, 0.08683312378291573, 0.11104843047048364, 0.17461372672447137, 0.12432406310524259, 0.1597426547003644, 0.08713123814335891, 0.05151078238018921, 0.10286071803420782, 0.11487650791449205, 0.15474886766501836, 0.08656071911432914, 0.07547766382672957, 0.18995092516498907, 0.10573395421462399, 0.10389915481209755, 0.11177596250282866, 0.20429841242730618, 0.15792899844901903, 0.13440414864037717, 0.14402863862259047, 0.0924863111493843, 0.12036377989820071, 0.06912495435348578, 0.1134529278746673, 0.08506775886884757, 0.10020436200180224, 0.07943262731922524, 0.09061451123229095, 0.16983017697930336, 0.10003586818597146], [0.04336860303633979, 0.0019014610152225941, 0.028730960629348243, 0.06568827626428433, 0.007348200073465705, 0.04900739528238773, 0.014849401311948895, 0.029360868435885226, 0.050035396191690645, 0.030637918838432858, 0.04133783932775259, 0.01080467357366745, 0.009933929940286492, 0.04921349011627691, 0.056070408783853054, 0.043694801961204836, 0.12378215789794922, 0.062219971657863686, 0.04947049203994019, 0.02887095258172069, 0.018573505138712268, 0.036413917650601695, 0.025838727164747458, 0.036948895015354664, 0.07022899868232862, 0.04463146187897239, 0.004072906449437141, 0.025517495116218925, 0.0038984763003619654, 0.09050890404198851, 0.033957478390740495, 0.03231737104111484, 0.03408130763896874, 0.05147514911368489, 4.888645265783582, 33.821760177612305, 54.84261785234724, 64.4780044555664, 64.18668038504464, 66.96407685961042, 65.73958887372697, 66.3738134929112, 48.425741059439524, 28.86376190185547, 14.867171696254186, 15.278921944754464, 25.61812285014561, 18.44668906075614, 39.136472020830425, 42.7471034186227, 34.55857147489275, 31.536490712847026, 12.147156051227025, 0.7640208229422569, 0.06102480686136654, 0.04942492502076285, 0.2006603790713208, 0.14454828788127216, 0.011799432204238005, 0.04964311813403453, 0.07510264430727277, 0.027714104657726626, 0.08847118195678506, 0.08524311945906707, 0.16257494129240513, 0.0944782185501286, 0.6440944809998784, 3.9816534774644032, 1.3664087418998991, 2.078257441520691, 5.240727424621582, 1.2530080612216676, 0.3726336546242237, 0.036887552056993754, 0.5108382371919495, 0.6832140332886151, 0.7906058792557035, 0.6582797712513379, 0.15849165325718267, 0.43125609468136517, 0.7351798819644111, 1.4121012900556837, 2.1830169515950337, 2.6344429339681352, 2.2519530696528296, 1.3826945594378879, 1.526891067624092, 3.89949016060148, 1.0566205935818809, 0.015290542372635432, 0.40885474958590096, 0.06243576614984444, 0.019903459220326374, 0.1396153247249978, 0.13549527366246494, 0.1389791438622134, 0.4347044367875372, 0.9683846597160611, 4.018482838358198, 1.5488534548452921, 1.1708058778728758, 0.19336801394820213, 0.4453887034739767, 0.47426699101924896, 0.03720367134415677, 0.11229707061180047, 0.06167808002127068, 0.05767416701252971, 0.0299546340746539, 0.09738481151206152, 0.0864967264767204, 0.09344896235104118, 0.06098269697810922, 0.0659937323736293, 0.053287356692765436, 0.03896489040926099, 0.3773619309067726, 2.7828514618532996, 24.05929970741272, 36.96218613215855, 34.45791292190552, 39.55734525408064, 32.12251567840576, 25.663628339767456, 19.152886595044816, 16.40395862715585, 15.28883876119341, 31.96598318644932, 34.78432886941092, 44.94208451679775, 50.32374572753906, 62.84058502742222, 65.84363119942802, 75.71294280460903, 67.5405341557094, 18.787423508507864, 0.8785159534641674, 0.049021637732429166, 0.03793954935723117, 0.02978952954124127, 0.01086880955179887, 0.07124598696827888, 0.041512036230415106, 0.05410861476723637, 0.07651980540582112, 0.048642506290759356, 0.02295420694697116, 0.014528876636177301, 0.02579109400643834, 0.024190102504300218, 0.026979219002117003, 0.02612705705022173, 0.024336837398420488, 0.027492610471589223, 0.04073766153305769, 0.01755920215509832, 0.04222081355484469, 0.04519622014569385, 0.01836690309989665, 0.04479829667668257, 0.03386696521192789, 0.004319869023415127, 0.02232112529288445, 0.012451605289243162, 0.04749556497803756, 0.022109266304011856, 0.07414416609598057, 0.03012284290577684, 0.017887813271954656, 0.0277868639677763, 0.032187346768166335, 0.027895073339875256, 0.004074554441363684, 0.015282196391906058, 0.054613444821110795, 0.04090719350746699, 0.007972984092443116, 0.016018791955762675, 0.0659241486074669, 0.022361523571557233, 0.031149524064468484, 0.06119570269116333, 0.029806279178176607, 0.025685459674735154, 0.07169125521821634, 0.03305549839777606, 0.020448361856064627, 0.04943580532978688, 0.019091648049652576, 0.02303591274124171, 0.04160789965784975, 0.02381894045642444, 0.03404261417953031, 0.030245060633335794, 0.054570524088506184, 0.06160751237933125, 0.06860051463757243, 0.032911950921905894, 0.03998032485001853, 0.012157612180869495, 0.02766051565829132, 0.04763690721509712, 0.02973854781261512, 0.03986873298085161, 0.026059251045808196, 0.08884784353098699, 0.04384173532681806, 0.029822184039013724, 0.018312599942354218, 0.020845795083524923, 6.3740463597433905, 40.80594001497541, 64.19610909053257, 76.36001464298793, 71.86985247475761, 74.75156225476945, 74.10074533735002, 75.49823651994977, 56.757246085575645, 33.5798100062779, 22.264580011367798, 28.788757835115703, 35.1797056879316, 31.30083908353533, 50.74274294716971, 44.78556592123849, 44.60101481846401, 34.91267251968384, 13.38509488105774, 1.0020735434123447, 0.020034338447398374, 0.04937810610447611, 0.045544454495289495, 0.06452732998877764, 0.04686763170840485, 0.09093566864196743, 0.16707639688892023, 0.16921374148556165, 0.4835004412702152, 0.6303089292986053, 0.8028931170701981, 0.6805784947105816, 1.8367004948002952, 5.58027720451355, 3.0397839035306657, 6.1761937992913385, 7.621038692338126, 4.870573435510908, 2.2422879082815985, 1.179668196610042, 2.6295720296246663, 4.538406985146659, 2.3288181679589406, 0.8583070092967579, 0.24304904522640364, 0.49222173328910557, 0.4399620518088341, 0.4686295049531119, 2.082977439676012, 2.9831322005816867, 1.7156071811914444, 0.9441667135272707, 0.673438623547554, 0.013766536605544388, 0.934652349778584, 0.12466873175331525, 0.7064852874193872, 0.4331441590828555, 0.152692228023495, 0.6997099252683776, 1.386816795383181, 0.8589348441788128, 2.398458876780101, 2.577398440667561, 5.9747481516429355, 6.164169073104858, 3.02227965423039, 2.1971002987452914, 1.40571328997612, 2.6470324184213365, 0.8726658959473882, 0.7014354669622013, 0.1670208384415933, 0.2467192140008722, 0.2915976829826832, 0.1877020565526826, 0.2628217456596238, 0.1563933922776154, 0.08347407009984766, 0.07092362176626921, 0.048145893295960765, 0.07056005591792719, 0.42657309025526047, 3.4490569021020616, 24.069319009780884, 37.392185824257986, 45.718597820826936, 49.1489269392831, 38.63173055648804, 37.76055499485561, 21.131228072302683, 25.258828026907786, 29.61654015949794, 43.49710587092808, 44.913318974631174, 56.890950271061485, 59.191967827933176, 69.02186230250767, 72.9713990347726, 83.87458174569267, 81.20117895943778, 30.416048526763916, 1.3880563974380493, 0.09997486110244479, 0.046940903312393596, 0.03044509275683335, 0.011812466861946242, 0.009063849574886262, 0.04295763133891991, 0.05091315587716443, 0.016668845467003326, 0.03258424225662436, 0.016397478956995264, 0.02678393153473735, 0.06338334030338696, 0.024983192893809507, 0.015078481519594789, 0.04950239336384194, 0.022631621221080422, 0.016471647923546176, 0.07937474149678435, 0.0377950519323349, 0.0038237670503024545, 0.03872754564508796, 0.00970713809199099, 0.015572597505524755, 0.02966265706345439, 0.022231026020433222, 0.03110836073756218, 0.05120066812794123, 0.025063792675999657, 0.028443154912175875, 0.0026298547870413002, 0.03615774693233626, 0.019518500859183923, 0.03818400516839964, 0.012695664157425719, 0.011469828729916896, 0.03082715207710862, 0.059314009733498096, 0.0441163248781647, 0.008038779936863907, 0.07060072730694499, 0.18130315920071943, 0.1824064842824425, 0.11957536291863237, 0.08561790827661753, 0.17064036136226995, 0.14654231231127465, 0.09552673157304525, 0.17905465699732304, 0.09228718147746154, 0.07497767172753811, 0.08656737554286208, 0.12709152246160166, 0.16035244055092335, 0.14823586786431925, 0.10612718561398131, 0.20057717710733414, 0.13936061624969753, 0.15564194188586303, 0.07748886197805405, 0.17462581821850368, 0.1674543408943074, 0.08392999813492809, 0.14248943621558802, 0.18242373264261655, 0.1529822881732668, 0.11630975029298238, 0.14201526237385614, 0.08265602149601493, 0.20577043986746243, 0.10664017844413008, 0.14355928237949098, 0.10018026722329003, 0.14428121649793216, 8.763093250138418, 54.66065147944859, 76.07631969451904, 84.78640079498291, 80.99076666150773, 83.61106436593192, 81.11812019348145, 84.89882959638322, 64.7959818158831, 42.80648272378104, 23.924216304506572, 21.94025547163827, 37.217928477696006, 29.57041106905256, 56.13377032961164, 58.48295974731445, 49.58426284790039, 45.51149633952549, 17.44210808617728, 1.7361076240028654, 0.13752063283962862, 0.14858871964471682, 0.4999960618359702, 0.3300534380333764, 0.19983889029494353, 0.20177962258458138, 0.2293304242193699, 0.1800798691276993, 0.45105634363634245, 0.3981802266623293, 0.5372153903756822, 0.29786767225180355, 2.2741212972572873, 10.758381383759634, 3.4465611960206712, 6.373592555522919, 15.78790181023734, 6.7364778603826245, 0.6859984695911407, 0.42989438346454073, 0.7647194968802589, 2.2206503493445258, 2.6858928246157507, 2.40101711664881, 0.531035130577428, 1.1860502255814416, 2.444736484970365, 7.429078204291208, 9.386859961918422, 11.03794823374067, 9.265338574137006, 6.787722562040601, 5.795740408556802, 9.049452832766942, 4.324937045574188, 0.5543792865106038, 1.2433519107954842, 0.5955033398100308, 0.24473783746361732, 0.7282681071332523, 1.0162112819296973, 0.5162532180547714, 1.7652150392532349, 3.439542212656566, 12.171961120196752, 10.847546747752599, 3.0918361161436354, 0.843128886606012, 0.9390185326337814, 1.8487892746925354, 0.7415378636547497, 0.7587163618632725, 0.3569960008774485, 0.17896974512508937, 0.26729652125920567, 0.19606386071869306, 0.3703584452824933, 0.28255221407328335, 0.24505210774285452, 0.26359853254897253, 0.37084859183856417, 0.2164020658071552, 0.8217984054769788, 4.036778748035431, 33.473103046417236, 49.94410310472761, 52.58695466177804, 55.06557512283325, 46.524081638881135, 40.26756579535348, 32.403330598558696, 28.603979178837367, 26.59972265788487, 44.57168647221157, 51.119995389665874, 62.88161414010184, 69.22664655957902, 80.5285655430385, 83.09422261374337, 92.98513616834367, 93.61072417667934, 37.239158698490684, 1.7031952014991214, 0.21488590644938604, 0.10740934538521937, 0.15619369942162717, 0.10761642748756067, 0.0963728850973504, 0.1273459866642952, 0.12287619151175022, 0.21729528930570396, 0.1279776891959565, 0.10968907377017395, 0.16264424685920986, 0.11682595259376935, 0.09345675193305526, 0.11817501591784613, 0.07804705202579498, 0.13716129426445278, 0.124362210343991, 0.15323790588549205, 0.17291232730661119, 0.11591938909675394, 0.134345998189279, 0.09955238484378372, 0.12886183389595576, 0.09955397261572735, 0.13763753085264138, 0.08490899524518422, 0.15319042200488703, 0.09241648989596538, 0.16060195144798073, 0.1917032961334501, 0.10349069030157157, 0.07487564720213413, 0.1382798592426947, 0.15228137506970338, 0.11638358847371169, 0.12540886418095656, 0.15004282018968038, 0.14508241707725184, 0.18448681836681707], [0.019366369915327857, 0.032415772189519236, 0.041800769844225476, 0.059601226821541786, 0.025712938646652868, 0.047175513580441475, 0.08304318679230553, 0.05575205711647868, 0.05863632966897317, 0.04395661469815033, 0.08788985386490822, 0.06548950621592146, 0.03937973654163735, 0.031943420214312415, 0.09072675449507576, 0.10035231656261853, 0.12246134877204895, 0.06983685293900115, 0.023332525842956135, 0.019340755218373876, 0.027336574558700834, 0.018068759901715175, 0.038446028251200914, 0.023793534408988695, 0.019119953137955496, 0.09144672086196286, 0.054401467088609934, 0.03944413290758218, 0.06604627812547342, 0.12393747456371784, 0.010598209786361881, 0.019230535686282173, 0.06893157865852118, 3.047872475215367, 39.931151390075684, 54.62078619003296, 62.78841100420271, 63.57139655521938, 56.37610265186855, 49.21775926862444, 39.96440894263131, 23.89350700378418, 23.635155609675817, 23.88479048865182, 25.701252835137502, 16.057962656021118, 23.722480569566997, 26.64311763218471, 25.13566252163478, 45.467371804373606, 30.498158863612584, 5.976536009992872, 0.20991014130413532, 0.041106306216014285, 0.08982237588082041, 0.027353210541020547, 0.014130759784685714, 0.10671902421329703, 0.03853422423292484, 0.04631690215319395, 0.1055130096418517, 0.3221244306436607, 0.16679777683956282, 0.2551117150911263, 0.8853857134069715, 0.943964347243309, 1.3950534505503518, 4.532455853053501, 5.873067779200418, 4.8309700063296726, 7.969252007348197, 4.934315340859549, 2.8485319146088193, 2.16420578956604, 4.475788082395281, 9.983874372073583, 0.31413264519401957, 0.25339830560343607, 0.16407620002116474, 0.5243243106773922, 0.3446549688066755, 0.9427134543657303, 4.564937812941415, 5.07751076562064, 1.5702627003192902, 1.15578094124794, 5.83780871118818, 11.695291246686663, 14.394259929656982, 13.054783599717275, 5.6297983186585565, 2.1553778861250197, 0.6087563229458672, 0.7293232562286514, 0.6471649333834648, 0.701881400176457, 1.0655554341418403, 0.5301054833190781, 4.769695580005646, 4.976478746959141, 5.17638623714447, 3.923249525683267, 4.126888632774353, 2.984533782516207, 0.9942544315542493, 1.206715579543795, 0.09010655991733074, 0.2242332963006837, 0.29168157705238884, 0.14293948135205678, 0.013773268521098154, 0.15267747667218956, 0.012341503652610948, 0.03922317476410951, 0.0399021270817944, 0.07786069916827337, 0.024422500748187304, 0.1970773341932467, 0.2378921519432749, 10.153682265962873, 26.029384987694876, 37.96880987712315, 28.612228427614482, 23.805789470672607, 31.65182386125837, 16.91876803125654, 17.839326177324565, 14.916931220463344, 21.613551173891338, 21.621703147888184, 43.18359967640468, 48.00089693069458, 50.097060748508994, 60.02734974452427, 72.01832853044782, 67.08264786856515, 34.61997617994036, 1.3744593156235558, 0.2550339006951877, 0.05751336778381041, 0.06700795902205364, 0.043525982448565106, 0.027047925761767795, 0.06394464482686349, 0.08669870599572148, 0.056238271562116485, 0.017773615828316127, 0.0540458434926612, 0.03241429637585368, 0.042732629126736095, 0.07667725945689849, 0.01282125081135226, 0.051597258275640864, 0.043235810340515206, 0.09653211691017662, 0.11758889736873762, 0.05873352981039456, 0.01309880131988653, 0.014757076444636499, 0.03588465355070574, 0.16020343426082814, 0.06122428258614881, 0.03664954911385264, 0.06465731694230012, 0.09045141855520861, 0.08898613575313773, 0.06144078953989914, 0.016652328228311877, 0.013502886735035904, 0.05770592245140246, 0.04445646430498787, 0.04588993399270943, 0.054945506288536956, 0.025797341617622545, 0.060774882057947774, 0.07726754421102149, 0.046437426935881376, 0.038658436853438616, 0.05487348318898252, 0.010565175308978983, 0.03576559440365859, 0.022489619108715227, 0.04103097865091903, 0.03437322697469166, 0.008573676725583417, 0.0238724514243326, 0.09801215106355292, 0.027155997730525475, 0.010443164534600717, 0.013981200488550323, 0.061834441630968025, 0.10322099977305957, 0.08855040770556245, 0.01968276740184852, 0.057379845662840774, 0.049864184843110185, 0.020982762466051748, 0.007492451529417719, 0.03624599380418658, 0.051794494834861586, 0.08210687632007257, 0.05666962645149656, 0.04380136249320848, 0.03761183390659945, 0.04226332377376301, 0.04353936315913286, 0.04570067700530801, 0.03210994627858911, 0.09245549887418747, 4.124134974820273, 48.50455100195748, 66.30789593287876, 69.23490101950509, 71.81790774209159, 62.17635113852364, 54.98288113730294, 49.857129028865266, 38.64588751111712, 42.06956025532314, 32.91441229411534, 20.930930614471436, 15.535946232931954, 23.262695687157766, 23.204028572354996, 30.70486777169364, 46.62946149281093, 32.99512604304722, 7.043132262570517, 0.28549325625811306, 0.03778274669977171, 0.04721408151090145, 0.039025195209043365, 0.10567819220679146, 0.12891205905803613, 0.30676731041499544, 0.36763469715203556, 0.42302698482360157, 0.9873871143375124, 0.7534276970795223, 1.7001450508832932, 2.606021110500608, 3.5448888455118452, 3.693249387400491, 8.326996513775416, 10.056364059448242, 8.856470091002327, 11.316998311451503, 5.527187756129673, 6.221179476806095, 4.626331227166312, 6.580897271633148, 7.61371876512255, 3.803189430918012, 0.822702485535826, 0.5646692972098077, 0.2343463993498257, 0.2446347272821835, 0.47885719899620327, 1.5415791251829691, 0.4942110351153782, 0.3100946018738406, 2.145947660718645, 5.654029726982117, 10.850198354039874, 12.291510088103157, 9.869128346443176, 4.286190416131701, 2.1601923363549367, 0.6627412747059549, 1.7016798428126743, 3.4347959416253224, 3.8907493267740523, 3.333753283534731, 3.9459879398345947, 6.108816249029977, 3.864660143852234, 6.827817142009735, 7.8854619434901645, 6.483549535274506, 3.951817044189998, 2.482436324868883, 2.808057789291654, 1.349750001515661, 1.6398433723620005, 1.2701621864523207, 0.6136955150536129, 0.4765049623591559, 0.33622308554393904, 0.1433826054313353, 0.04791035682761243, 0.049522905477455685, 0.04172440751322678, 0.021439189224370887, 0.15604904932635172, 0.17381860581891878, 8.401121633393423, 25.326757090432302, 37.71634360722133, 27.569319452558243, 19.684382098061697, 27.656104190008982, 12.73796832561493, 16.227048805781774, 20.250505685806274, 31.219489574432373, 31.467342240469797, 53.08966377803257, 60.23485769544329, 58.78214223044259, 67.51474939073834, 79.24818624768938, 79.25034018925258, 45.03117779323033, 2.425627201795578, 0.2275898733309337, 0.07255474531224795, 0.021827170459021415, 0.08175093041998999, 0.02144840033724904, 0.06376490090042353, 0.06405253868017878, 0.0412676991628749, 0.01948526282129543, 0.041137583287698884, 0.02485642389261297, 0.04173062628667269, 0.06274369891200747, 0.04117991369483726, 0.03358188211651785, 0.0938270352780819, 0.0861436507797667, 0.1143064299332244, 0.017921107288982187, 0.019892794346170764, 0.03311315691098571, 0.02768090393926416, 0.1156738137028047, 0.01984130371628063, 0.01796242328626769, 0.132615096068808, 0.10124728389616523, 0.060661288510475836, 0.033130632580391, 0.049014557219509564, 0.04543017902012382, 0.055645299809319634, 0.024643784588468925, 0.0884433484503201, 0.030291611528290168, 0.03790995505239282, 0.012450757968638624, 0.07964032010308333, 0.1422708122325795, 0.18651202826627664, 0.1626389678567648, 0.1322634249393429, 0.10895888866590601, 0.0876655098316925, 0.1910477905933346, 0.15190938860177994, 0.15009105045880589, 0.20693829362945898, 0.2626708394714764, 0.09725496705089297, 0.118097472935915, 0.1514202327068363, 0.15132621489465237, 0.18198245417858872, 0.15565119710351738, 0.13523642612355097, 0.08677430158214909, 0.2379987362240042, 0.12024042223181043, 0.03914738579520157, 0.11898217403462955, 0.1345996210085494, 0.1420704408415726, 0.14650492503174714, 0.15202084476394312, 0.1622401385435036, 0.18388168726648602, 0.17734564441655362, 0.16118155606091022, 0.1474965089665992, 0.19480945302971772, 7.699471695082528, 60.70542444501604, 76.43588202340263, 79.01601219177246, 80.37490613119942, 72.61371271950858, 64.58123384203229, 57.5849016053336, 36.81883784702846, 38.194049630846294, 38.42019612448556, 36.551790782383506, 24.1183819770813, 33.0300407409668, 36.486463819231304, 33.616444383348735, 60.48903669629778, 41.78539282935006, 8.276541301182338, 0.33771507548434393, 0.1469739827194384, 0.18556943455977098, 0.3075141603393214, 0.27438552943723543, 0.32554864404456957, 0.26239296581063953, 0.30801947893840925, 0.5495797640510968, 1.184015380484717, 0.9475285559892654, 0.8686337694525719, 2.288405707904271, 3.4870264189583913, 7.172414788178035, 15.257578815732684, 18.249415806361608, 12.92019178186144, 18.04175673212324, 9.043049199240548, 8.440946102142334, 6.623806306294032, 13.273055178778511, 21.679197754178727, 4.773161428315299, 0.31630892413003103, 1.5380622510399138, 0.9888112779174532, 0.6356387947286878, 1.8256693610123225, 9.078205347061157, 8.488842640604291, 5.733732947281428, 5.351700578417097, 8.233679601124354, 11.27946935381208, 11.660942826952253, 10.393296105521065, 6.072032051427024, 4.187136897018977, 3.4618485357080186, 4.262194378035409, 5.591805568763188, 3.278671222073691, 3.976413232939584, 4.42680458511625, 12.796617201396398, 14.561469197273254, 11.580751929964338, 10.14507692200797, 11.230946608952113, 8.564822929246084, 4.250644300665174, 4.946940651961735, 1.8791027452264513, 1.361264469368117, 0.76436405309609, 0.4878255863274847, 0.295190688754831, 0.2835381254553795, 0.1431269877191101, 0.40182018705776756, 0.19875548700136797, 0.22358754809413636, 0.10269613258008446, 0.5150899376188005, 0.5006586919937814, 14.145644698824201, 36.27096196583339, 51.90750074386597, 42.76874358313424, 38.29317610604422, 49.632219314575195, 26.88287912096296, 26.28025664602007, 25.27444757734026, 35.96211106436593, 35.28962966373989, 58.01976156234741, 65.84462479182652, 69.26042175292969, 77.99478680746896, 89.05538095746721, 90.6476718357631, 50.854000977107454, 2.8225845183644975, 0.26078844762274195, 0.19041901933295385, 0.1413582640566996, 0.16457659245601722, 0.08440195316714899, 0.1501898451575211, 0.13592359210763658, 0.1481556107423135, 0.1349829797233854, 0.1608331147581339, 0.11742508544453553, 0.18872706512255327, 0.1500591186008283, 0.10683477550212826, 0.13323564348476274, 0.1679807212203741, 0.3042110518685409, 0.25575371778437067, 0.12535539562148706, 0.12385644391179085, 0.16835475686405385, 0.150545438219394, 0.22856107407382556, 0.13456296654684202, 0.21202567778527737, 0.22160519446645463, 0.16306204801159246, 0.1375950002776725, 0.08251197529690606, 0.08356366386370999, 0.13316434302500316, 0.2009445902492319, 0.17827149187879904, 0.16600843705236912, 0.1375857586307185, 0.11543076245912484, 0.09984167824898448, 0.10633319563099317], [0.0498235134540924, 0.035250318303172073, 0.051436822063156536, 0.08489912256066288, 0.09743953536131553, 0.032802978197910955, 0.11250029863523585, 0.10967190004885197, 0.06430506905806915, 0.0721192140398281, 0.3366037436894008, 0.19119792325156076, 0.06654372571834496, 0.03857384389266372, 0.13115350449723856, 0.32249689208609716, 0.22410646453499794, 0.10820469020732812, 0.08703790565154382, 0.07790113985538483, 0.055181907889034064, 0.017830270109698176, 0.09018507998968874, 0.12373008712061814, 0.12415453791618347, 0.02339958376251161, 0.03811661307034748, 0.03648312822250383, 0.05467631448326366, 0.14124763570725918, 0.04188739501738122, 0.07935882985059704, 2.6496985724994113, 37.14473615373884, 54.921299253191265, 64.79148633139474, 64.91960416521344, 55.03614255360195, 44.39943020684378, 36.95213556289673, 22.364257131304058, 17.904045173100062, 17.63923716545105, 13.916327221052986, 38.39676679883684, 78.8027650288173, 48.49142585481916, 63.925587926592144, 69.44443089621407, 26.888356038502284, 3.546914679663522, 0.11923397838004998, 0.1523367842393262, 0.13169018498488835, 0.11552373532738004, 0.2577704595667975, 0.36999765464237755, 0.230677316231387, 0.05329566874674388, 0.5821716466120311, 0.19336692829217228, 1.1610151060989924, 0.293163714664323, 2.474790700844356, 2.8476477563381195, 4.611637958458491, 2.329622421945844, 4.978182358401162, 5.894935931478228, 6.8959342411586215, 6.505320847034454, 5.687819250992366, 9.161724431174141, 3.359859185559409, 10.484160304069519, 12.176232525280543, 3.3040723162037984, 3.9314523083823065, 0.328989142285926, 1.9775079105581557, 1.671957511987005, 0.9865424739462989, 3.9181082929883684, 7.5555362871715, 12.984627638544355, 33.83735540934971, 59.83380767277309, 68.21753883361816, 71.16416563306535, 75.21709156036377, 60.577389989580425, 44.92980704988752, 8.832404136657715, 0.6772116039480481, 1.7880170728479112, 3.1090739454541887, 2.709129337753568, 3.327559833015714, 3.6729702012879506, 3.223643877676555, 6.2433047124317715, 9.90160596370697, 3.1128023053918565, 6.325976984841483, 1.7040952103478568, 2.453754812479019, 0.32969669146197184, 1.2348678346191133, 1.1952003517321177, 0.5791625880769321, 0.4907097401363509, 0.37620961559670313, 0.32722533121705055, 0.1901832419846739, 0.10539712264601674, 0.06558134593069553, 0.2412682164992605, 0.07777658796736173, 0.08884284272789955, 0.0380646440732692, 2.3523727783135007, 18.5557792527335, 48.20472581045968, 66.14590563092912, 40.311016355242046, 47.7696852002825, 41.3451132774353, 28.087470940181188, 15.84747392790658, 18.283342123031616, 20.397006716047013, 25.594801221575054, 51.36526332582746, 63.3571766444615, 68.72117900848389, 66.22241919381278, 67.33750084468296, 40.46153518131801, 2.2930295169353485, 0.1099504590300577, 0.09510084906859056, 0.08112252556851932, 0.08993670224611248, 0.07990407345018216, 0.15962784657520906, 0.039484692338321886, 0.06556323583104781, 0.0725012088992766, 0.13071460090577602, 0.07731722654508692, 0.10470665219639029, 0.21823649880077156, 0.3954917623528412, 0.23106589966586658, 0.23349565214344434, 0.2082854299140828, 0.13973283341952733, 0.03525467789066689, 0.13112854797925266, 0.11374885056700025, 0.21841237507760525, 0.018124912067183425, 0.0654469213581511, 0.11949810492140905, 0.507892798100199, 0.46981894969940186, 0.17948323328580174, 0.10022648902876036, 0.03703578481716769, 0.08720428243811641, 0.055526671532009325, 0.018076571536117365, 0.06512115669569798, 0.08592337117131267, 0.15915048361888953, 0.16615555701511248, 0.029077898977058272, 0.025702523134116615, 0.03415701179099934, 0.04688042548618146, 0.038062784887318096, 0.016163983182715516, 0.035028115047940185, 0.028717172797769308, 0.04502222341086183, 0.05910806078463793, 0.15183784386941365, 0.09855630900710821, 0.06566633244178124, 0.06387733415301357, 0.1442235003092459, 0.316265660737242, 0.18796680734625884, 0.14703781929399284, 0.07675001876694815, 0.06652103550732136, 0.05355112700323973, 0.03546581084706953, 0.014133534144743212, 0.059241386130452156, 0.07960035439048495, 0.020434375552992736, 0.01957499568483659, 0.042694241008056064, 0.0699501818578158, 0.030050673921193396, 0.06862055177667312, 0.03586447731192623, 2.9599084981850217, 42.520970821380615, 65.15220900944301, 71.42085293361119, 72.94060461861747, 60.24935163770403, 56.34171254294259, 45.544882433755056, 34.824114254542756, 25.51818690981184, 20.592820848737443, 23.44068421636309, 35.89036743981497, 49.362726484026226, 32.51527302605765, 45.245693002428325, 48.583715302603586, 29.381392274584087, 4.392569073608943, 0.1572618085358824, 0.1595034168234893, 0.22184336025800022, 0.11966392530926637, 0.3333998370383467, 1.033013437475477, 1.5750770419836044, 1.5237622069461005, 2.386603078671864, 2.074983971459525, 1.7520872865404402, 2.071055199418749, 3.6972793425832475, 7.283697136810847, 5.452715660844531, 5.266615109784262, 6.896661196436201, 8.386696304593768, 5.476481539862497, 6.682971954345703, 5.248892426490784, 3.7728744404656545, 3.043949999979564, 5.268130251339503, 8.594410964420863, 4.201487966946193, 2.1274563329560414, 0.3688563315996102, 4.758667486054557, 2.52778873699052, 1.6241980918816157, 4.980880865028926, 8.261296084948949, 15.415615592684064, 36.01275300979614, 60.021082469395225, 73.19487394605363, 78.08384881700788, 78.95600060054234, 56.97027785437447, 40.16180379050118, 10.561777762004308, 1.6911470251423972, 1.2224967841591154, 3.090890509741647, 2.1064328210694447, 2.2986586434500555, 2.2700830910887038, 4.80904974256243, 4.9774927496910095, 5.9636735916137695, 4.102615100996835, 5.313941027436938, 4.083180555275508, 2.772930737052645, 2.3433531480176106, 3.605053948504584, 3.469609022140503, 2.407270495380674, 1.770162699478013, 1.5006303510495593, 0.6657149408544812, 0.21117313924644673, 0.13890662203942025, 0.14818831613021238, 0.04599505942314863, 0.0875501385224717, 0.06533708689468247, 0.043119126066033325, 1.7838189495461327, 16.44347129549299, 37.72925683430263, 47.28845296587263, 37.8493321282523, 25.544725554330007, 20.003919328962052, 27.002120631081716, 21.76544053213937, 27.70730893952506, 35.906431674957275, 38.256454876491, 58.201161657060894, 69.97222300938198, 75.56472383226667, 74.24528871263776, 78.57268932887486, 52.9136381149292, 3.753063823495592, 0.19554468643452438, 0.12222023813852242, 0.07438476104289293, 0.11934979073703289, 0.031829809703465016, 0.13339172010975225, 0.03150218924773591, 0.06914765813520976, 0.07522390530045543, 0.09817962029150554, 0.08748415099190814, 0.14433252731604235, 0.3905513217406613, 0.2469414206487792, 0.23816025469984325, 0.2595672202961785, 0.26452937402895516, 0.18520747683942318, 0.04406623203041298, 0.10597235749342612, 0.05865488081638302, 0.08662328004304852, 0.0785944601520896, 0.036154123555336676, 0.18734433289085115, 0.36450979911855286, 0.3908459687871592, 0.28207371117813246, 0.13243575926337922, 0.03955468661817057, 0.09979452685053859, 0.07463450264185667, 0.02264133614620992, 0.020524544375283376, 0.09182501092020955, 0.049768643719809394, 0.0402581679767796, 0.24138696012752398, 0.17621985982571328, 0.16379213812095778, 0.12340947932430676, 0.18449732208890574, 0.14553239436021873, 0.1837546790816954, 0.26897486405713217, 0.11912157226886068, 0.1310415462191616, 0.4253350081188338, 0.2761564515531063, 0.12435728417975561, 0.16193462136600698, 0.26150381352220264, 0.568816177546978, 0.37745071042861256, 0.26916151547006195, 0.18620979519827024, 0.2492372574550765, 0.19425523919718607, 0.1295668182096311, 0.10762490917529378, 0.17541606724262238, 0.1793634718550103, 0.16570465692452022, 0.17859409456806524, 0.16301550050931318, 0.17572165227362088, 0.29484308883547783, 0.09748500399291515, 0.12147999714527812, 5.880988725594111, 57.77063390186855, 77.3844223022461, 82.34217044285366, 82.85996409824916, 71.18986701965332, 60.15193789345877, 52.136096477508545, 35.52293280192784, 31.004998683929443, 27.637498651232036, 28.056874547685894, 53.52465227672032, 99.20868628365653, 64.23456042153495, 81.41481522151402, 91.80365058353969, 39.645521368299214, 5.9442720498357495, 0.3932129703462124, 0.5335092321038246, 0.5471134249653135, 0.6257605733616012, 0.5525330198662621, 0.8753184250422886, 1.5088549554347992, 1.0282583726303918, 2.394597415413175, 2.262559277670724, 4.82482693025044, 3.2597810242857252, 8.353794847215925, 11.736970015934535, 16.002597672598704, 12.950294852256775, 13.05585709639958, 16.14650355066572, 15.240863186972481, 18.1167243208204, 13.305364302226476, 22.49357179233006, 12.447139314242772, 20.870356219155447, 23.691686153411865, 10.454790268625532, 8.797786474227905, 0.6982822333063398, 6.292958276612418, 3.4078588613442014, 1.8767779214041573, 7.790520020893641, 11.500153694834028, 16.97404268809727, 33.14175387791225, 51.95698928833008, 65.44133744921002, 70.01899133409772, 72.66408021109444, 54.272594588143484, 45.47480637686593, 13.815375975200109, 3.071197577885219, 9.542540431022644, 8.331012572560992, 12.02677243096488, 12.38188704422542, 13.066210780824933, 11.636697956493922, 15.58149514879499, 22.687051330293926, 11.903049332754952, 16.221691744668142, 7.8168007135391235, 6.633322298526764, 2.8444470252309526, 5.408398313181741, 5.301391277994428, 2.4309278087956563, 1.1551307418516703, 1.1847478726080485, 0.8334180191159248, 0.4696061611175537, 0.20976709255150386, 0.17417817509600095, 0.293921665421554, 0.18114810037825788, 0.24376153413738522, 0.13970641126590116, 3.499084149088178, 25.258821078709193, 61.07420703342983, 82.3855619430542, 54.686081886291504, 69.18030207497733, 58.791091510227744, 42.81352472305298, 27.157735960824148, 28.887710605348857, 32.31324372972761, 39.39485468183245, 65.52261747632707, 79.52027770451137, 85.39098439897809, 83.53616973331997, 88.3655846459525, 58.98641926901681, 4.261328024523599, 0.41478707268834114, 0.27399542608431404, 0.2779298163950443, 0.21335973191474164, 0.1641356804008995, 0.2909181165908064, 0.17901819252542087, 0.10183043046189205, 0.2183927654155663, 0.23430471015827997, 0.1646856873163155, 0.16557912794607027, 0.5811361478907722, 0.4813674528683935, 0.4400405990225928, 0.42881019307034357, 0.40120003319212366, 0.30324430231537136, 0.31781586898224695, 0.2681899076061589, 0.25424617582133835, 0.28892143230353085, 0.19278934571359838, 0.11946849365319524, 0.19170396109776838, 0.5257440230676106, 0.5048643606049674, 0.7308552254523549, 0.3101325998348849, 0.1821285563388041, 0.17744542977639607, 0.12046015901224953, 0.08622347363936049, 0.228427809796163, 0.15429498202034406, 0.22550781576761178, 0.2147760244884661], [0.028325666573696902, 0.0518721531677459, 0.0452481009332197, 0.07601549103856087, 0.01585907838307321, 0.025123461349202052, 0.24299869792801992, 0.06958453969231673, 0.18176982844514505, 0.20697409313704285, 0.27823152020573616, 0.3944498039782047, 0.1220321346606527, 0.023277232024286474, 0.04390082894159215, 0.049532296402113776, 0.0851417938247323, 0.04394770214068038, 0.031233818469835178, 0.04743565033589091, 0.06790063969258751, 0.1327055719281946, 0.17830178168203148, 0.266935187791075, 0.2830030055982726, 0.019554039130785635, 0.050792027198310406, 0.07641658665878431, 0.10162117704749107, 0.19427712873688766, 0.07902148938072578, 5.8309056758880615, 39.38825041907174, 56.876108918871196, 57.69182048525129, 63.84429400307791, 53.26890645708357, 56.31179707390921, 18.993835381099156, 23.224975654057094, 16.225207533155167, 14.836938347135272, 30.449243545532227, 26.0553069795881, 28.55826871735709, 70.18622057778495, 64.92798369271415, 42.52760287693569, 25.49993920326233, 3.0878144119467055, 0.4829040361302239, 0.08162405794220311, 0.05836716161242553, 0.010552637678171908, 0.2550138703414372, 0.21375428645738534, 0.27065714235816685, 0.13938059232064656, 1.1116600973265511, 1.738481193780899, 0.7227810387100492, 1.1169451794454028, 0.892867240522589, 5.338365682533809, 3.3369970066206793, 3.9435886400086537, 2.5194697890962874, 8.086806842258998, 11.08847553389413, 4.496402084827423, 6.008229783603123, 4.844648838043213, 4.260402611323765, 4.149465935570853, 5.7417919891221185, 6.861258821828025, 7.430315852165222, 7.556965010506766, 4.340396787439074, 8.040319051061358, 17.830993550164358, 25.816122191292898, 33.26774903706142, 39.71427379335676, 63.70586504255022, 75.58999443054199, 69.89360414232526, 59.09198325020926, 58.34069538116455, 64.26682785579136, 69.85859911782401, 78.5228499003819, 48.54252290725708, 11.525684850556509, 4.089528168950762, 7.583813718387058, 1.267447937812124, 2.847097328730992, 1.8164759171860558, 1.4830952691180366, 5.557966538837977, 5.865743943623134, 5.515541272503989, 2.717943561928613, 1.807276502251625, 1.7400114259549548, 2.1275080101830617, 3.3810707330703735, 3.8130471876689365, 2.757688343524933, 2.407009720802307, 1.4914790306772505, 0.46923160978725975, 0.12878794143242495, 0.3623946154756205, 0.0944034643471241, 0.20471245449568543, 0.08723695389926434, 0.10640417039394379, 0.31335830103073803, 0.013975958805531263, 0.10047536888825041, 4.765627843993051, 21.066588980810984, 40.68527065004621, 43.54601771490914, 41.93113129479544, 20.221490008490427, 25.349168504987443, 21.287810938698904, 15.147901500974383, 19.267316477639334, 25.625894410269602, 46.05138179234096, 49.91731432506016, 57.091405800410676, 58.61858858380999, 66.87417411804199, 43.88263709204537, 4.444477328232356, 0.1281194215906518, 0.09317038979913507, 0.05903736422104495, 0.09298650680908135, 0.19496375189295836, 0.04630926184888397, 0.08044751214661769, 0.03264595501657043, 0.08904801814683846, 0.09924381425870316, 0.11007583873080355, 0.024989844233329808, 0.244586279881852, 0.038676896398620944, 0.08513629769108125, 0.009701569015825433, 0.07075123994478158, 0.027151721263570443, 0.10978533074791942, 0.10353507327714137, 0.2010247659470354, 0.1056277227721044, 0.02421779351841126, 0.1301938931324652, 0.2562362647482327, 0.05683309571551425, 0.23517706191965512, 0.09198842929410082, 0.08974221375371728, 0.01756123945649181, 0.11358500471604721, 0.03831170545890927, 0.00434874535338687, 0.1327108916427408, 0.03559483428086553, 0.10540217094655548, 0.02564525817121778, 0.0609963151759335, 0.0495383591125054, 0.091322250398142, 0.06496108349944864, 0.009787095810419746, 0.1347911443029131, 0.12959835651729787, 0.1670532181326832, 0.20685164470757755, 0.19444160562540802, 0.2919824394796576, 0.06294932216405869, 0.06598714379859821, 0.06329040136188269, 0.0924642655466284, 0.08748638337211949, 0.037003693503460715, 0.03310333172391568, 0.030027976924819604, 0.012992141552136412, 0.059274980399225435, 0.209423943821873, 0.17899894927229199, 0.25636521354317665, 0.03849842133266585, 0.07535514075841222, 0.06585702113807201, 0.0512895426446838, 0.046908913778939416, 0.04338777165061661, 6.3730770860399515, 45.61908572060721, 67.32525811876569, 66.7238289969308, 72.29818112509591, 61.15418774741036, 69.23168400355748, 30.559358596801758, 33.8152288709368, 26.749777691704885, 26.34197575705392, 29.893307753971644, 26.661851712635585, 32.559543473379954, 66.69646004268101, 59.92054203578404, 39.591909067971365, 28.674133402960642, 3.859240983213697, 0.14479850445474896, 0.029856399167329073, 0.10029636456498078, 0.14907981614981378, 0.7199963309935161, 0.7992891190307481, 1.1113045449767793, 1.2036532695804323, 3.247958447252001, 4.9493586250713895, 4.989053683621543, 2.5985294325011115, 4.2246367590768, 5.472696074417659, 4.252645816121783, 3.1191837915352414, 4.446909632001605, 3.507554654564176, 5.097691374165671, 3.2590972781181335, 3.321777411869594, 2.4907379022666385, 3.010557391813823, 2.378692771707262, 5.7218493563788275, 6.75056837286268, 5.753481898988996, 6.384858191013336, 3.8609797699110846, 9.727756823812213, 22.763834135872976, 32.72111688341413, 39.597835881369456, 45.99572672162737, 70.99679047720772, 84.3285631452288, 84.65744917733329, 70.40756934029716, 71.84246267591203, 78.31029060908726, 86.8136419568743, 91.69935812268938, 53.969111170087544, 11.644681436674935, 3.044222716774259, 2.659732856920787, 0.6719021488513265, 1.2832815796136856, 2.3853721618652344, 1.7915375296558653, 1.776068451149123, 2.938801173652921, 1.8368998212473733, 2.0153710331235613, 2.193995539631162, 2.493560173681804, 2.6926888142313277, 5.979826416288104, 4.242209187575749, 4.259091138839722, 5.656356070722852, 5.028827343668256, 1.8663577948297774, 0.8344132942812783, 0.8760864724005971, 0.7651941999793053, 0.1992066992180688, 0.2806012087634632, 0.055131184003715, 0.28248900175094604, 0.034796978879187784, 0.0867894600544657, 4.609434076717921, 22.05184527805873, 39.632906913757324, 43.134472438267295, 39.65288993290493, 20.346771240234375, 24.88299822807312, 25.43675923347473, 22.06445278440203, 27.15991595813206, 38.45635107585362, 61.04645592825753, 58.53725297110421, 62.737591879708425, 66.89674881526402, 75.94210134233747, 60.714860098702566, 8.5190794638225, 0.10207889641502074, 0.05545231427199074, 0.05364002187603286, 0.10724371498716728, 0.12244139984250069, 0.07096284109034709, 0.03593787783756852, 0.04554379292364631, 0.1413370937641178, 0.18307329421596868, 0.040099947181131156, 0.21815778873860836, 0.17683466683541024, 0.08956689387559891, 0.01962591295263597, 0.013001030360880707, 0.03970062932265656, 0.03753683543098824, 0.15103475696274213, 0.12958186811634473, 0.031529351004532406, 0.083884258089321, 0.06081152294895478, 0.11768210093889918, 0.2572502674801009, 0.22329064831137657, 0.014700583315321376, 0.05108783793236528, 0.07069332019558974, 0.14147874473461083, 0.16135142051747867, 0.06260049409632172, 0.04554330437843289, 0.11348989446248327, 0.04705489380285144, 0.07069963057126318, 0.06843172226633344, 0.11987910233438015, 0.14605217932590417, 0.24593347044927732, 0.1518062784203461, 0.07859525403806142, 0.44764599949121475, 0.2629095752324377, 0.29845889338425224, 0.35646351373621393, 0.4302983289318425, 0.589573323726654, 0.26872831157275606, 0.15947915241122246, 0.18116585085434572, 0.29508451159511295, 0.3215092436543533, 0.18892408455056803, 0.18815997269536766, 0.1056926789294396, 0.13777690194547176, 0.2140076378626483, 0.30803663230368067, 0.4199819639325142, 0.3270216892872538, 0.14491198265126773, 0.1420652839754309, 0.31501221656799316, 0.14580599325043814, 0.229104146361351, 0.25102226595793453, 10.999242424964905, 63.09075491768973, 76.85705402919224, 75.75445829119, 82.59497370038713, 70.5527241570609, 73.82251167297363, 31.220920903342112, 36.41428245816912, 27.011304412569316, 24.432098354612076, 48.016533851623535, 40.533834661756245, 41.53632770265852, 83.83494227273124, 78.73627771650041, 57.10005630765642, 38.70195252554757, 5.819169734205518, 0.8849636646253722, 0.3393503177378859, 0.31645532484565464, 0.33857380226254463, 1.0145310120923179, 0.9886783936194011, 1.2374134808778763, 1.8759684562683105, 4.35558728660856, 4.570225392069135, 5.093233236244746, 4.793845346995762, 7.4151626995631625, 13.9332070010049, 12.377447145325796, 15.391140563147408, 12.043859788349696, 16.9429703439985, 21.538456780569895, 15.450839485440936, 15.768485069274902, 13.57450885432107, 12.882286752973284, 9.355986510004316, 14.28693197454725, 13.747286234583173, 14.41816520690918, 16.523276567459106, 5.145537972450256, 12.019003476415362, 25.55825022288731, 35.44457796641758, 42.671128341129844, 48.97027485711234, 71.20884255000523, 78.89116695949009, 80.56597464425224, 70.84664685385567, 70.61287471226284, 77.99787875584194, 82.88338647569928, 87.4587960924421, 58.91317135947091, 16.405320474079677, 7.313235231808253, 12.469487326485769, 5.01671359368733, 7.488461852073669, 7.869172760418483, 11.26213880947658, 15.341097899845668, 17.133366618837627, 15.882503271102905, 8.543367760522024, 7.627613425254822, 7.7311259508132935, 6.831609121390751, 10.555597339357648, 11.32184989111764, 12.19064656325749, 9.466496740068708, 7.241343089512416, 3.1580179248537337, 0.7731599296842302, 1.417777534042086, 0.7200175012860979, 0.4767004890101296, 0.369981478367533, 0.28104469925165176, 0.6157043586884225, 0.13044157198497228, 0.3738904100443636, 7.128255077770778, 29.740148612431117, 57.04979998724801, 59.82642868586949, 58.49605015345982, 34.04049294335501, 39.00247253690447, 34.13406433377947, 24.489771877016338, 30.229249681745255, 38.66699266433716, 62.727892194475444, 67.46158177512032, 76.01345239366803, 76.51295144217355, 84.98306260790143, 67.82685552324567, 9.609840682574681, 0.20689922358308518, 0.25705859490803307, 0.18366015915359768, 0.2544803518269743, 0.34298528411558693, 0.15546302577214582, 0.17348898707755975, 0.34489707010132925, 0.253584305622748, 0.3039724518145834, 0.2504283035440104, 0.44636736810207367, 0.686314124081816, 0.26363772473164965, 0.27923265791365076, 0.21894312516919204, 0.23172793271286146, 0.1106834261279021, 0.240750358573028, 0.2099295338349683, 0.3753208704292774, 0.23722170506204876, 0.22715668300432817, 0.45594242002282825, 0.6928480363317898, 0.32977646003876415, 0.3342921920120716, 0.24041027682168142, 0.2525412344506809, 0.23849697091749736, 0.2931545680122716, 0.16018571092614106, 0.09202827965574605, 0.2934869687472071, 0.20893393297280582, 0.15749029841806206], [0.04958959189908845, 0.018317105414878045, 0.008409701104808067, 0.061246477466608794, 0.05410162585654429, 0.017356896939288293, 0.06617794784584216, 0.10862981953791209, 0.034202809512083016, 0.06312519165554217, 0.05094895199207323, 0.08897918076919657, 0.05709756152438266, 0.07495105958410672, 0.02102554409897753, 0.011430589049788458, 0.0748848006395357, 0.03295373171567917, 0.014283026435545512, 0.09786609640078885, 0.013547497019836945, 0.016716239441718374, 0.26273443177342415, 0.20011634326406888, 0.26104580238461494, 0.04039415657254202, 0.07579524535685778, 0.04421931292329516, 0.1460573904748474, 0.1671948012496744, 6.99611988237926, 46.196442808423726, 65.1177042552403, 67.32783590044293, 60.71433203560965, 56.395974499838694, 45.63593510219029, 16.23572884287153, 31.562456130981445, 18.398718697684153, 22.924978494644165, 30.80198621749878, 28.757805347442627, 52.31818444388253, 47.24933113370623, 31.94529492514474, 22.228367737361364, 17.559777566364833, 4.1669632366725375, 0.06873359571077994, 0.05685275626767959, 0.15014386762465748, 0.1364087989287717, 0.4620468467473984, 0.49393571274621145, 0.31518670863338877, 1.3546900621482303, 2.140169147934232, 1.446906988109861, 2.2952086457184384, 3.12434869153159, 1.1702780319111687, 2.793081815753664, 2.565703971045358, 5.178822883537837, 1.5121936734233583, 2.612240616764341, 4.3998555626188, 5.041175161089216, 4.193958725248065, 9.607707585607256, 11.710424423217773, 10.908094218799047, 10.363834874970571, 21.241923298154557, 23.668781416756765, 23.60368374415806, 21.202797991888865, 19.803484644208634, 24.529560736247472, 26.700042486190796, 35.75325863701956, 40.631203242710654, 39.708180223192485, 49.789728028433665, 50.714939730507986, 41.26933969770159, 52.765464305877686, 48.58255842753819, 53.49034902027675, 48.54272787911551, 55.84554515566145, 48.62154129573277, 30.763065883091517, 13.258279834474836, 13.303418806621007, 8.81594124862126, 9.44785646029881, 10.083084225654602, 10.013380765914917, 8.38057233606066, 6.565691139016833, 3.2484634944370816, 2.959887219326837, 2.641784574304308, 1.0103275690759932, 3.780537869249071, 5.076326532023294, 3.0079492117677415, 1.9202015570231845, 4.29378696850368, 4.310705832072666, 1.0540392292397363, 0.34266743117145126, 0.5088535494038037, 0.2051891389169863, 0.07396559603512287, 0.06366798574370996, 0.21806731287922176, 0.06699752315346684, 0.23769499680825643, 0.1707138874168907, 0.11267175086374794, 0.6246547241296087, 11.192329389708382, 33.42202336447579, 45.23514911106655, 49.52005454472133, 35.1136074747358, 33.66402217320034, 29.297419820513042, 22.761841739927018, 34.87087910515921, 34.422167914254324, 25.14195237840925, 42.265773909432546, 55.08368212836129, 62.821498325892854, 69.88115991864885, 62.67869200025286, 6.604070382458823, 0.24252706180725778, 0.13349933576370987, 0.08581164359514203, 0.13777384853788785, 0.07778967690787145, 0.12358331999608449, 0.038806391414254904, 0.07677087014807121, 0.06402076288525547, 0.0347406943993909, 0.015233582750494992, 0.012030392802054328, 0.12011109345725604, 0.10956276447645255, 0.03634431352838874, 0.024793554230460098, 0.03712281711133463, 0.05934767185577324, 0.03559030505961605, 0.08100358516510044, 0.016817733013470258, 0.07374184911272355, 0.03832767138789807, 0.15908154446099484, 0.01848763313942722, 0.07480835009898458, 0.055074584005134444, 0.04973685435418572, 0.06772842071950436, 0.09857798820095402, 0.031120842389230217, 0.036230937112122774, 0.10544035211205482, 0.06069790226008211, 0.05579273189817156, 0.037489300660256825, 0.0925196407895003, 0.056559744490576644, 0.03684553038328886, 0.009903806378133595, 0.025512640198160495, 0.06063323108745473, 0.10707503118153129, 0.0754112827458552, 0.019333388024408902, 0.018605314860386506, 0.0838998236826488, 0.08693165385297366, 0.106071213260293, 0.04672444724876966, 0.020742225194615976, 0.03969249029510787, 0.12982570646064623, 0.03284438579742398, 0.12270769769591944, 0.034510365687310696, 0.07279211721782174, 0.19942017990563596, 0.21583768752004417, 0.21158087093915257, 0.02226640483630555, 0.028788839666438953, 0.03132825018838048, 0.08186961976545197, 0.2540748864412308, 7.40438517502376, 52.82819611685616, 76.47984327588762, 77.14461912427629, 65.56709289550781, 64.46144689832414, 54.33349207469395, 30.313267299107142, 32.99510867255074, 29.204098565237864, 24.862419400896343, 19.12734501702445, 30.396812438964844, 38.701855250767295, 41.2933144569397, 38.82717643465315, 27.74642382349287, 18.56328330721174, 5.204958098275321, 0.08577720794294562, 0.03726624584357653, 0.2577545547059604, 0.2945637766804014, 1.6449079577411925, 1.65224503832204, 2.044121593236923, 3.0921628986086165, 3.599583544901439, 6.7729350583893915, 6.329572677612305, 4.069026640483311, 3.612891733646393, 2.804523978914533, 3.009195544889995, 2.6830659934452603, 2.020153130803789, 1.3266859991209847, 1.9231002586228507, 4.836567214557102, 5.513051646096366, 8.86307348523821, 12.061340587479727, 12.33150565624237, 13.970527512686592, 20.837048292160034, 23.062969718660625, 23.684201206479752, 22.283765724727086, 20.30258764539446, 26.764582565852574, 29.34802007675171, 39.29040241241455, 49.14707177025931, 45.684899057660786, 60.00032125200544, 59.55578940255301, 48.53424065453665, 58.2665650503976, 56.01351090839931, 60.67543601989746, 56.1848326410566, 65.44180297851562, 57.55044896262032, 37.26981067657471, 16.23016333580017, 15.090591021946498, 10.629639080592565, 11.544014198439461, 11.269893867628914, 11.644993237086705, 10.168757251330785, 8.145678928920201, 4.261826992034912, 0.2683269445385252, 1.266893710408892, 2.0023720392159055, 2.7333694313253676, 4.246071951729911, 5.16141938311713, 1.9925828959260667, 3.598295739718846, 5.559287130832672, 2.503679573535919, 2.7510382660797665, 2.0670565111296515, 1.4011497348546982, 1.1359692386218478, 0.7304862109678132, 0.366800207644701, 0.05671107476311071, 0.11022785771638155, 0.16360414320869104, 0.006347156936369304, 0.6177729134048734, 10.771238156727382, 31.890143598828995, 46.54157372883388, 38.373521600450786, 25.945278780800955, 23.914051089967998, 19.42363010134016, 14.66591191291809, 31.741493838174, 42.47437620162964, 36.4395877974374, 51.58173097882952, 63.68953677586147, 72.30228056226457, 77.48255865914481, 83.07568481990269, 13.012739181518555, 0.16735009077404225, 0.15057557874492236, 0.08260713304792132, 0.2621370495430061, 0.05841754283756018, 0.07436207761721951, 0.11420964369816439, 0.054349932353943586, 0.13585834418024334, 0.03843556524121335, 0.02481964390192713, 0.02084730312760387, 0.1433101650327444, 0.07070455673549857, 0.07472180974270616, 0.05771895032376051, 0.035226695106497834, 0.05224613452862416, 0.024643896546747004, 0.046769485010632446, 0.06222805300993579, 0.11299119157982723, 0.1286058904869216, 0.09199623923216547, 0.020385989220812917, 0.013538468263245054, 0.05343686509877443, 0.03691767222647156, 0.01541954545038087, 0.021681219272847687, 0.0733207706362009, 0.02844214389499809, 0.22387843605663094, 0.04597473390666502, 0.0944682712267552, 0.12165919824370316, 0.1514645546142544, 0.15141470943178448, 0.2153355037527425, 0.10434830428234168, 0.11369870004377194, 0.17718935066035815, 0.34472067813788143, 0.1778638008981943, 0.15862239338457584, 0.15083283851189272, 0.2627475953527859, 0.2549567919756685, 0.26742272877267426, 0.14280274297509873, 0.1304801127740315, 0.09218907209911517, 0.2812474997980254, 0.10150301695934363, 0.3779694640210697, 0.08525996748358011, 0.16319527157715388, 0.3102410297308649, 0.32906882943851606, 0.35286103561520576, 0.14212380083543913, 0.1497832126915455, 0.17342546262911387, 0.1888454287712063, 0.47028741027627674, 11.451155866895403, 64.39325032915387, 85.3942847933088, 88.77265875680106, 77.73746722085136, 72.82711969103131, 60.9135160446167, 29.336208139147075, 44.21314205442156, 30.549860409327916, 34.51359578541347, 43.60359396253313, 41.4363500731332, 72.07396275656563, 61.712093353271484, 47.62218884059361, 33.39349058696202, 27.482173408780778, 7.381513442311968, 0.2835155166685581, 0.1985492937799011, 0.28807581482189043, 0.8043655923434666, 2.3761447370052338, 2.5207491261618475, 2.494188985654286, 4.988417489188058, 8.37057648386274, 7.666897671563285, 10.292957169669014, 10.602762579917908, 5.229554287024906, 10.146822656903948, 9.031604647636414, 15.584644419806343, 8.58147428716932, 10.8834776197161, 13.568125196865626, 12.859814541680471, 11.379023143223353, 15.654414755957466, 17.37820897783552, 15.904923370906285, 16.219668081828527, 27.192263296672277, 31.56588854108538, 34.260938440050396, 28.274578980037145, 24.19709290776934, 29.273931435176305, 33.66557856968471, 46.70851114818028, 55.7425137928554, 55.64585740225655, 62.759450912475586, 63.12889357975551, 53.99823454448155, 64.03487614222935, 61.85692160470145, 66.89460182189941, 62.892418588910786, 71.2644350869315, 62.53402355739048, 39.80270004272461, 17.422338724136353, 17.559944323131017, 11.605860982622419, 12.049707565988813, 14.677300010408674, 16.936718702316284, 13.163089513778687, 12.299436245645795, 9.555473634174891, 8.077227013451711, 7.033968022891453, 5.475245629038129, 11.303659507206508, 13.784156850406102, 9.903805937085833, 7.912030117852347, 11.671088933944702, 10.22082792009626, 7.303598080362592, 4.677702299186161, 4.075857153960636, 1.7178310390029634, 1.5560583025217056, 0.8714004009962082, 0.8685047392334256, 0.34561045467853546, 0.4690776637622288, 0.2967621215752193, 0.1785788003887449, 1.126143291592598, 16.084542989730835, 46.50556468963623, 60.12018462589809, 66.66105202266148, 49.09207330431257, 48.373758111681255, 42.91965498243059, 35.75995670046125, 47.884834221431184, 47.00483097348894, 38.482726437704905, 59.00201102665493, 71.68308489663261, 80.75522272927421, 88.10436017172677, 91.12750053405762, 14.02016110079629, 0.43130022659897804, 0.19317737274936267, 0.2545456268957683, 0.5318172371813229, 0.1689310230846916, 0.22207840478846005, 0.23476909952504293, 0.22970785253814288, 0.3587456712765353, 0.10974790954164096, 0.25796788611582344, 0.15304491695548805, 0.3561922897185598, 0.23749154486826488, 0.16227870647396359, 0.1648115012794733, 0.14242397115698882, 0.2087270069335188, 0.17804886453918048, 0.13100987220449106, 0.1644098221191338, 0.20538694544562272, 0.3556878667856966, 0.31943425642592566, 0.1608320019607033, 0.14194818240191254, 0.2877257450350693, 0.17419572201158318, 0.26532515989882605, 0.24314564147165843, 0.12625815932239803, 0.1266703014927251, 0.2943348932479109, 0.0943869488047702, 0.19808972201177052], [0.05263907755059855, 0.030797737584050213, 0.04648973859314408, 0.05331548196928842, 0.015576899417542985, 0.010882463372711624, 0.003267150779720396, 0.02813908301426896, 0.010120580505047525, 0.015322694754494088, 0.02730212194312896, 0.03852773404547146, 0.03290681101913963, 0.021213398215227892, 0.019478494434484413, 0.04059917592842664, 0.06805561709084681, 0.06785881479403802, 0.0269344899736877, 0.015953628845246773, 0.01281089975964278, 0.06024405054215874, 0.21559954886989935, 0.12101484781929425, 0.22580004722944327, 0.0328436699429793, 0.05778564353074346, 0.012593004353610533, 0.10784193181565829, 1.2882379250867027, 27.51373733792986, 57.92221927642822, 66.14257744380406, 56.35923589978899, 40.001512323107036, 26.30845069885254, 27.733243090765818, 29.216209275381907, 47.8946659224374, 34.140738078526084, 32.64870623179844, 51.34366832460676, 49.35135228293282, 45.14787973676409, 37.135693073272705, 19.997018030711583, 5.4372941340718945, 0.8573452266199248, 0.028016414060922604, 0.017506817555321113, 0.08928349015436002, 0.26204333028623034, 0.1156933962234429, 0.6560453825763294, 0.6362015988145555, 1.1812843041760581, 1.561921387910843, 2.0386772453784943, 4.568519175052643, 6.556530373437064, 4.202061193329947, 1.754472689969199, 2.0150399080344608, 3.6491808720997403, 1.841510602406093, 3.2834576623780385, 7.432690399033683, 14.035591312817164, 27.83479448727199, 37.84534386226109, 44.11000646863665, 43.26670707975115, 44.47894886561802, 46.76661893299648, 43.07080609457833, 49.99371324266706, 42.71882772445679, 47.01441253934588, 45.195888314928325, 51.6752849987575, 53.620221274239675, 53.92651176452637, 52.964544091905864, 46.54897356033325, 37.32510444096157, 41.002820696149556, 40.50219256537301, 49.81994921820504, 44.9615603174482, 51.99421426228115, 45.223833969661165, 40.192129203251426, 30.27793570927211, 38.756325653621126, 41.14089182444981, 38.265292985098704, 34.40994603293282, 37.574913024902344, 31.914559568677628, 32.23495142800467, 30.665054593767437, 35.84514856338501, 27.973933901105607, 10.030590585299901, 2.474963103021894, 0.9455878372703279, 1.1119384595326014, 4.753771611622401, 2.6592888236045837, 0.5878437108227185, 4.157383842127664, 4.20997519152505, 2.1335099509784152, 2.0614747192178453, 0.7752721277730805, 1.105222157069615, 0.7622004491942269, 0.5634310522249767, 0.28190356173685616, 0.16390881900276455, 0.05080952661644135, 0.045580410065927675, 0.13526997289487294, 0.050429177204413075, 0.12486758322588035, 3.780959103788648, 23.170513936451503, 50.870457785470144, 54.570832116263254, 49.729153633117676, 50.131225040980745, 70.10182080950055, 100.87318978990827, 89.7445936203003, 42.50081409726824, 38.347382477351594, 49.104003361293245, 51.78840167181832, 58.34421811785017, 69.8636087690081, 60.85240663800921, 3.5725422416414534, 0.16509970224329404, 0.07394872765455927, 0.07278039213269949, 0.03602215188688465, 0.01917222069044198, 0.08440193281109844, 0.023921918323529617, 0.018331943279398338, 0.03230908612853714, 0.022221204226038287, 0.08854096249810287, 0.032524198692824156, 0.05754184589854308, 0.08314607984253339, 0.03132478965978537, 0.01692969129154725, 0.04762696667707392, 0.03984821747456278, 0.04378718450399382, 0.0489100187218615, 0.04738849554476993, 0.05193742145118969, 0.026066294239301766, 0.015678906979571496, 0.0985914571210742, 0.06741269158997706, 0.05081001516165478, 0.05900739332927125, 0.0269264306740037, 0.004430415100484554, 0.06542637531778642, 0.06205977632531098, 0.06736762329403843, 0.14381025891218865, 0.018905108595000844, 0.1295954388167177, 0.027602243070889796, 0.08740772080740758, 0.018200273559029614, 0.04285414457055075, 0.04779296348403607, 0.07374159805476665, 0.021508281052644764, 0.11617963441780635, 0.06255556150738682, 0.03302207715543253, 0.04744741613311427, 0.047824196450944455, 0.029409146202462058, 0.02099346465963338, 0.01447051583922335, 0.007721538522413799, 0.020942537213808725, 0.016013428136440258, 0.04054651821830443, 0.04676933912560344, 0.11591430008411407, 0.05283431921686445, 0.14193921216896602, 0.04232921970209905, 0.059899409035486836, 0.0916774363390037, 0.11587284159447465, 2.0903761855193546, 35.104220458439414, 69.44395841870988, 74.55586624145508, 64.07669734954834, 50.52020951679775, 38.494052001408164, 34.00934764317104, 26.54376012938363, 53.101861340659006, 36.870275361197336, 27.365139688764298, 42.64210571561541, 41.73306247166225, 48.86417586462838, 39.303218364715576, 20.214724200112478, 5.604913345405033, 1.0343179617609297, 0.07585476644869361, 0.027801866377038614, 0.10494427515992097, 0.36939115290130886, 0.7172799110412598, 1.736356456364904, 2.3129825719765256, 2.282743577446256, 2.9156545528343747, 3.6342420279979706, 3.298130737883704, 2.876566158873694, 2.1349471424307143, 2.3014407455921173, 1.7614468357392719, 2.7742804246289388, 1.7914871552160807, 3.0644189587661197, 6.966120600700378, 15.295401334762573, 27.77303194999695, 37.94912215641567, 46.37915958677019, 46.65488495145525, 48.32662500653948, 49.83325154440743, 46.51103292192732, 50.49722487585885, 44.99511316844395, 47.50094624928066, 47.682565212249756, 52.48067154203142, 57.131159918648855, 57.601980277470176, 58.395391600472585, 51.065219266074045, 43.71284743717739, 47.80947058541434, 47.02102722440447, 57.14906195231846, 50.240937096732004, 59.452608653477256, 53.317380564553396, 47.366703578404014, 36.81791026251656, 42.98430797031948, 44.44451011930193, 40.67537988935198, 37.23387459346226, 41.411340032305034, 35.1569572857448, 35.52138335364205, 33.43023266111101, 38.55358069283621, 30.60315309252058, 11.559550370488848, 3.8895729099001204, 1.201899175133024, 0.4350482369107859, 1.6437179701668876, 0.47938982184444157, 1.0100561550685336, 1.1482824236154556, 4.1801939095769605, 2.408152482339314, 2.3892577247960225, 2.204807153769902, 1.9253002320017134, 1.4885738151414054, 2.4230811212744032, 1.1776135925735747, 0.8215101095182555, 0.3116539296294962, 0.02982544439977833, 0.0598092113754579, 0.042072326344038756, 0.1086687742333327, 4.483861889157977, 23.234515530722483, 47.09904159818377, 45.477540493011475, 36.5861530985151, 31.92090674809047, 57.28506599153791, 87.71921457563127, 79.18310247148786, 46.81498186928885, 48.17962196895054, 56.85748079844883, 57.017237254551475, 67.36500181470598, 75.28817858014787, 78.03589929853166, 8.702240926878792, 0.5370191580482891, 0.04233302628355367, 0.044896456945155344, 0.04416294701929603, 0.027252619420843463, 0.07539041779403176, 0.07050689269921609, 0.027292474871501327, 0.018365520584796156, 0.07132181325661284, 0.05007826264149376, 0.043724674465400834, 0.08389269906495299, 0.08938349264540843, 0.034907960066837926, 0.033866354530411105, 0.0027857002860400826, 0.06563890605632748, 0.03725980315357447, 0.0449424684047699, 0.05661969645214932, 0.07298823419426169, 0.04761299564103995, 0.010317987546191683, 0.04421930953062006, 0.09588633477687836, 0.08295427834881203, 0.05442024215257593, 0.010504891713415938, 0.06251453728015934, 0.05664061229409916, 0.06320455989667348, 0.09059714752116374, 0.1650338979171855, 0.16577024411942276, 0.3027645509157862, 0.12977685193930352, 0.12984311766922474, 0.1192284415342978, 0.2494122652070863, 0.17859238465981825, 0.15755813834922655, 0.09613412898033857, 0.1411135300461735, 0.1293050665408373, 0.19932110022221292, 0.162405416103346, 0.18402707017958164, 0.18225460100386823, 0.11210407489644629, 0.1147458627820015, 0.309317055025271, 0.09257911438388483, 0.17136013773935183, 0.07751286854701382, 0.21830322593450546, 0.32671998547656195, 0.3107468911579677, 0.37786534960780827, 0.12886895851365157, 0.21976815589836665, 0.12487226511750903, 0.1407578827014991, 4.696707793644496, 48.15939923695156, 77.60803617749895, 82.87168570927211, 73.6273923601423, 55.97795350211007, 43.24490710667202, 42.29861109597342, 41.647484983716694, 58.92597688947405, 45.14438826697213, 46.87291594914028, 69.98648071289062, 66.0205670765468, 61.28684275490897, 51.09620475769043, 28.94495333944048, 9.14112823350089, 2.153306020157678, 0.2956235126725265, 0.26242290277566227, 0.4011668392590114, 0.8658330483095986, 1.0457681587764194, 2.801940551825932, 3.001367530652455, 4.496230551174708, 4.532844952174595, 6.6763529266629895, 11.43715524673462, 15.959515367235456, 11.108183230672564, 6.294909417629242, 7.142067228044782, 8.563453265598842, 5.379178532532283, 5.860961845942906, 12.528989962169103, 18.85600570269993, 35.20675502504621, 43.55526576723371, 51.654874665396555, 50.25348206928798, 50.835522242954795, 53.8191169330052, 49.147467817579, 56.74174118041992, 46.60251637867519, 53.831967626299175, 50.86068861825125, 57.37624372754778, 59.223255566188264, 61.39642974308559, 67.93924263545445, 53.28346640723092, 49.93489326749529, 53.29067863736834, 52.082664830344065, 63.81354127611433, 57.308887890407014, 65.43677248273576, 59.4986960547311, 54.88813897541591, 42.15643358230591, 50.20474393027169, 48.14659718104771, 43.300273827144075, 41.316920961652485, 47.82243592398507, 40.257129601069856, 39.16944122314453, 38.31197445733206, 41.80750547136579, 35.05259186880929, 13.847219569342476, 5.732367191995893, 3.403005978890828, 4.021162237439837, 12.221883927072797, 9.924700038773672, 5.198785058089665, 12.344312923295156, 12.645062225205557, 5.312337730612073, 5.500412004334586, 4.568355458123343, 5.819352124418531, 3.122947543859482, 3.837229524339948, 1.4895233299051012, 0.8020834348031453, 0.5093128361872264, 0.31861721883927074, 0.43992872216871803, 0.09242409627352442, 0.3174482929919447, 5.896809339523315, 33.607029574257986, 66.41402966635567, 72.32612677982875, 68.48134108952114, 66.77543326786586, 80.06260544913155, 105.29175077165876, 93.82965496608189, 52.4680049760001, 53.51597397668021, 64.9210980279105, 67.8983872277396, 77.98811653682164, 85.65259797232491, 88.20006465911865, 10.433756334441048, 0.8699046926839011, 0.36794864173446384, 0.14665391775114195, 0.17046614071088179, 0.0842177037681852, 0.10703598149120808, 0.1696676949837378, 0.11477711610496044, 0.1394860502332449, 0.1813308298587799, 0.3079540953040123, 0.16096608048038824, 0.15915588475763798, 0.19248989463916846, 0.15319093769150122, 0.1368574598538024, 0.19096498217965874, 0.20891126990318298, 0.2232104590428727, 0.18508668403540338, 0.20841356446700438, 0.17120750807225704, 0.22478490455874375, 0.170125651838524, 0.21189496479928493, 0.18800114121820244, 0.2081221065350941, 0.1850290492709194, 0.12038956422890935, 0.18906884321144649, 0.15593331839357102, 0.11883380556745188, 0.16398082513894352, 0.22917151131800242], [0.10044332846466984, 0.025714562041684985, 0.020906791989026324, 0.05676235843982015, 0.05086050495239241, 0.024322523702202097, 0.03489907125809363, 0.02430249165211405, 0.08065553062728473, 0.043824161269835064, 0.02808511912423585, 0.03747862730441349, 0.09267714912337915, 0.03977276438048907, 0.04661040586818542, 0.00770971759422017, 0.06527656157101903, 0.018567735894716213, 0.02876272963892136, 0.11114575274820838, 0.07288935807134424, 0.03701721331370728, 0.06340063616101231, 0.06631258276424237, 0.053751678206026554, 0.027391481612409865, 0.03686229698359966, 0.1368198147309678, 0.4610987976193428, 24.397383417401993, 59.04356125422886, 69.07906682150704, 71.39194147927421, 54.51225880214146, 34.899067946842735, 61.06699480329241, 51.57495995930263, 24.106507505689347, 19.6253137247903, 36.38769517626081, 56.99522188731602, 38.846047742026194, 41.50207655770438, 24.244556052344187, 11.325033034597125, 0.7292906865477562, 0.0986443217843771, 0.10173596481659583, 0.03972370969131589, 0.053842934380684576, 0.09019294421055488, 0.199986743075507, 0.3375722574336188, 1.7065961275781905, 1.182881412761552, 2.0398586562701633, 1.5088678747415543, 2.003795334271022, 7.852947848183768, 7.480173519679478, 5.472192764282227, 5.9940975819315225, 7.259251202855792, 8.955453259604317, 12.563007473945618, 23.897493532725743, 39.83979647500174, 61.05205617632185, 63.08905955723354, 65.67531108856201, 67.53544807434082, 65.65601594107491, 61.52342891693115, 70.69893510001046, 69.43104866572789, 65.55859524863106, 64.9114956174578, 56.986265659332275, 55.775764397212434, 63.781037603105815, 63.955937658037456, 66.3569780077253, 62.398665700639995, 60.403837885175435, 27.034539188657487, 35.27939149311611, 48.25944982256208, 46.16682958602905, 42.36060292380196, 47.7637688091823, 44.477930954524446, 32.52776936122349, 32.197319984436035, 35.43374572481428, 49.92321334566389, 51.10174247196743, 50.28896304539272, 51.01401104245867, 45.16897794178554, 48.989938259124756, 50.81542457853045, 46.73289932523455, 56.430635588509695, 48.71160037176949, 41.84384107589722, 33.94943332672119, 19.015937600816997, 7.240898839065006, 1.2737306292567934, 0.7735432748283658, 2.6645206000123705, 3.629821453775678, 0.8277459006224359, 2.8401738830975125, 2.402017657245908, 1.2195329431976591, 1.7819965673344476, 0.8361150601080486, 0.4705509532775198, 0.15764085176799977, 0.1637383031525782, 0.09106596772159849, 0.06528768954532486, 0.06295551040342875, 0.06981448842478649, 0.008378144985597049, 1.596448398062161, 11.280823384012495, 34.099305970328196, 56.469086919512065, 54.0250163759504, 63.771921566554475, 77.2994875226702, 89.74321787697929, 53.14811202457973, 16.733523845672607, 34.17552423477173, 39.38201093673706, 56.18643420083182, 64.26529925210136, 68.86506925310407, 51.9326080594744, 1.694534597652299, 0.1076754532488329, 0.026141328338001455, 0.11895967381341116, 0.07923566217401198, 0.03423475833343608, 0.024226285384169648, 0.059008472199950895, 0.065199568202453, 0.02719444522101964, 0.013730787988086897, 0.16602780244180135, 0.14458344956593855, 0.05779512266495398, 0.018603002752310464, 0.033473330084234476, 0.047480090986937284, 0.11531485510723931, 0.0395781130396894, 0.0729237122993384, 0.062388221201087744, 0.057243222636835914, 0.06448368661637817, 0.03116769523226789, 0.012630116826455508, 0.027999130077660084, 0.015012044459581375, 0.040275199205747673, 0.004452786400049392, 0.04280930358384337, 0.05397502818543996, 0.06795888513858829, 0.11394669780773775, 0.0947205505466887, 0.06165059256766524, 0.0352583385870925, 0.06749663994248424, 0.015622076279084598, 0.0787328677251935, 0.010246781233165945, 0.032199003999786716, 0.016275525858093585, 0.023523223020934632, 0.03255390156326549, 0.003922792026839618, 0.022579394380695055, 0.07769970316439867, 0.055300498846918344, 0.01992167958191463, 0.03504302924765008, 0.062545634540064, 0.03098591909344707, 0.048207874077239206, 0.010847965804194766, 0.04067862559376018, 0.005206732952501625, 0.07631589206201689, 0.04178792517632246, 0.1004517355135509, 0.05041569132091744, 0.05713703190641744, 0.15127464623323508, 0.7027919941714832, 29.86299623761858, 68.65991674150739, 77.94529478890556, 76.5900764465332, 62.10223470415388, 44.00285134996687, 62.21801948547363, 48.561710357666016, 31.181726115090505, 28.595488480159215, 33.731395380837576, 50.081204959324424, 42.58007567269461, 46.54871647698538, 29.13127796990531, 10.710754956517901, 0.4732258468866348, 0.10832534051899399, 0.01874563081323036, 0.03124647993328316, 0.21832046072397912, 0.2944603408021586, 1.2839832391057695, 1.7933943271636963, 1.7234368239130293, 1.5699969317231859, 2.926947112594332, 2.267568060329982, 2.413129129580089, 3.8500393969672064, 5.061332753726414, 4.806783761296954, 6.551862486771174, 7.198185222489493, 7.839045371328082, 12.202506269727435, 24.46207983153207, 43.2211720602853, 63.77677140917097, 66.26444189889091, 68.73945277077812, 69.3661663872855, 69.54105949401855, 65.43877356392997, 73.07324572971889, 70.46034785679409, 66.81232125418526, 65.79677254813058, 61.1813691002982, 59.373941149030415, 63.732956068856375, 64.03832939692906, 71.28381361280168, 68.00312437329973, 60.41858891078404, 32.192584787096294, 41.780647209712434, 52.94756964274815, 50.088118416922434, 47.86812380381993, 54.44418382644653, 48.35553993497576, 38.133037499019075, 37.06524876185826, 40.34414884022304, 53.43776157924107, 54.964562211717876, 56.40126207896641, 55.8246762411935, 49.7886232648577, 51.33289166859218, 52.33623933792114, 51.1067555972508, 59.43717670440674, 51.67621258326939, 45.68257488523211, 37.244425433022634, 20.154509374073573, 9.009310483932495, 2.1091997240270888, 0.7920140836920057, 1.1375727525779178, 1.0786120763846805, 0.4715016079800469, 2.0631305617945532, 3.094503573008946, 2.992056293146951, 3.325677522591182, 1.463439249566623, 1.2533902121441705, 1.2134440413543155, 0.5797799463782991, 0.31715668578233036, 0.07552321388253144, 0.07904747048658983, 0.10010519410882678, 0.07337022905371018, 1.2975688129663467, 11.24795493057796, 34.56232697623116, 53.51759985515049, 52.837871483394075, 69.71465328761509, 83.79941613333565, 93.5501845223563, 61.07197666168213, 31.066313062395366, 48.73486641475132, 50.10849748338972, 60.532643590654644, 70.9230284009661, 77.26896408626011, 69.23426873343331, 5.6063125388962884, 0.328933800969805, 0.004878190537315926, 0.07100899504231555, 0.06037006128047194, 0.07580268210066216, 0.019096253606091653, 0.05258128672306027, 0.03540927530931575, 0.008889565310840095, 0.03501954854332975, 0.06632755803210394, 0.0908035510884864, 0.07484611735812255, 0.03412353626585432, 0.04556946190340178, 0.04652720390419875, 0.04079350496509245, 0.06948991798396621, 0.06585845963231154, 0.02410330091203962, 0.06655819887029273, 0.08513384139431374, 0.028407832075442587, 0.041565257124602795, 0.056484030160520754, 0.04581680827374969, 0.023627351004896418, 0.020087396493181586, 0.05735575766967876, 0.07555268265839134, 0.04786626222942557, 0.18402396248919622, 0.14935578991259846, 0.33046066761016846, 0.1502742413431406, 0.18809662466602667, 0.14556083854820046, 0.2171119355729648, 0.06323392689228058, 0.13983272734497273, 0.09888964612036943, 0.20052263646253518, 0.0933576790349824, 0.06302198647920575, 0.18038872469748768, 0.24179416256291525, 0.14760734087654523, 0.06146377830633095, 0.09154253679194621, 0.18911503787551606, 0.10558694281748363, 0.14930679968425206, 0.261249417173011, 0.17984652093478612, 0.10676972434989043, 0.1552732666688306, 0.1382913129138095, 0.2170497274824551, 0.11329737372164216, 0.16278129736227648, 0.21055959431188448, 1.0664834529161453, 39.567805767059326, 80.42585727146694, 87.22087587629045, 88.77573680877686, 69.62400708879743, 49.2917297908238, 73.9648802621024, 61.917245864868164, 33.890516076769146, 26.165620054517472, 50.25484391621181, 70.93083817618233, 51.58818585532052, 58.514414242335725, 36.030366693224224, 15.988485881260463, 1.165808494601931, 0.21482555754482746, 0.20798634524856294, 0.2561851574906281, 0.4027009797947747, 0.3248201959899494, 0.8404227261032376, 2.6382811622960225, 3.6845207129205977, 3.753106381211962, 6.6139320475714545, 7.929972972188677, 7.389852149145944, 18.426004273550852, 14.297640885625567, 11.3824268920081, 11.756742852074758, 11.468125104904175, 12.584074412073408, 17.118203912462505, 28.493869338716777, 47.646941798073904, 69.95928546360561, 70.40275423867362, 72.35318306514195, 73.31058924538749, 72.03308650425502, 67.21214839390346, 75.09888880593437, 71.56763362884521, 67.70320538112095, 67.90817029135567, 60.82001413617815, 60.268862179347444, 64.53366647447858, 67.01288100651333, 72.07533849988664, 72.46186678750175, 67.20161492483956, 39.48992688315255, 47.360318183898926, 58.30167429787772, 55.774041243961875, 53.329154287065776, 60.43655000414167, 55.080944538116455, 43.0342446735927, 39.83088541030884, 42.68387828554426, 61.82900374276297, 60.02197183881487, 58.974600383213584, 55.65780830383301, 48.406154087611604, 51.114217962537495, 53.60149587903704, 52.018991538456504, 61.897248949323384, 54.7100635937282, 50.71744803019932, 41.20752157483782, 24.424804483141216, 11.44795708996909, 6.1687105894088745, 5.757500563349042, 8.148952398981367, 8.893932172230311, 4.247970546994891, 9.297639012336731, 8.271192056792122, 6.874665371009281, 7.1222427146775384, 3.522793139730181, 3.8062792079789296, 1.7191325234515327, 0.635750834430967, 0.2028276470622846, 0.23103145722831997, 0.23098135420254298, 0.3768884763121605, 0.2891915706651551, 2.3834681383201053, 16.668424436024257, 47.51981060845511, 71.50005544934953, 68.0514143535069, 72.57099519457135, 79.9966323035104, 87.92260224478585, 60.817735127040315, 29.838604586465017, 48.94866943359375, 58.310693059648784, 71.43119880131313, 83.93704605102539, 85.65097904205322, 80.71044158935547, 6.570179675306592, 0.4514459584440504, 0.07711691622223173, 0.15719703558300221, 0.21514635533094406, 0.14347331199262822, 0.1043954421100872, 0.11723436282149383, 0.11667026951909065, 0.12835118201162132, 0.12646580460880483, 0.24515025104795182, 0.26918453137789455, 0.19832127887223447, 0.13619838521948882, 0.12012196358825479, 0.15548239116157803, 0.19156389789921896, 0.17352954990097455, 0.21258530632725783, 0.17414200917950698, 0.12209766757275377, 0.12785119669778006, 0.15157134245548928, 0.23962222625102314, 0.1017691112522568, 0.18331938529653208, 0.19128436861293657, 0.09556417313537427, 0.09668287382061992, 0.16429421332265648, 0.18315127146031174, 0.26828357258013313, 0.23115932036723408], [0.05535520573279687, 0.04230231578860964, 0.0281987788288721, 0.06265593719269548, 0.046413400010871034, 0.10978821452174868, 0.03626780191968594, 0.06801795161196164, 0.03771006202857409, 0.030085448840899125, 0.05134738775502358, 0.03756971723799195, 0.022162521124950478, 0.01577105712411659, 0.01548921742609569, 0.011682871762397034, 0.061991943179496696, 0.05470172901238714, 0.0269270854602967, 0.03669751475432089, 0.15764248025204453, 0.048143738947276554, 0.09253673308662005, 0.08138247911951371, 0.06504741350987128, 0.0558661086750882, 0.01908403997575598, 0.08413050523293869, 14.246694956507001, 55.46038218906948, 66.93333802904401, 63.599467277526855, 64.41205215454102, 53.70152562005179, 36.17771366664341, 78.63795375823975, 86.89406735556466, 30.76443120411464, 30.92246103286743, 38.65767165592739, 35.31032487324306, 43.98008905138288, 23.711815084729874, 9.8913026537214, 0.6699564361146518, 0.0820756908506155, 0.09340363621179547, 0.04906545752393348, 0.08960306657744305, 0.09532917610236577, 0.20740716132734502, 0.5424495552267347, 1.1041264044387, 1.3899997217314584, 2.4354182992662703, 1.7769526094198227, 2.736718245915004, 4.351548211915152, 8.854918905666896, 13.567057779857091, 15.486886739730835, 24.23173836299351, 24.907989161355154, 38.10845824650356, 49.39344794409615, 61.567438806806294, 63.68037210191999, 64.7950507572719, 61.965834617614746, 64.33929756709507, 62.728399412972585, 62.25029386792864, 60.219780104500906, 63.55335208347866, 66.09990855625698, 66.59627396719796, 63.5334107535226, 64.00818116324288, 60.36675534929548, 63.02831145695278, 68.56271144321987, 67.23641845158168, 66.76604625156948, 59.58493709564209, 43.412410804203574, 25.4930066381182, 46.10624476841518, 45.960735593523296, 46.00148330415998, 47.82690014157976, 31.118709427969797, 35.60283708572388, 54.60861642020089, 57.73444768360683, 59.416387694222585, 64.40555558885846, 62.664976256234304, 58.84684385572161, 60.36281572069441, 56.419066837855745, 57.556573799678254, 64.11501666477749, 61.69298580714634, 64.95543602534703, 64.41601957593645, 62.91913441249302, 64.39936474391392, 62.79491451808384, 47.8092690876552, 26.475858858653478, 8.47004863194057, 0.5685890040227345, 1.4642760732344218, 2.122925238949912, 1.0091551691293716, 2.231877335480281, 2.093395394938333, 1.3997714945248194, 1.6416870334318705, 1.3087526985577174, 0.8183015074048723, 0.22147610996450695, 0.12250611851257937, 0.08588039954858166, 0.059693901134388785, 0.05025755534214633, 0.014658604050055146, 0.22260593862405845, 5.654047966003418, 24.813022920063563, 35.07646587916783, 36.1524395942688, 45.20555673326765, 31.95338610240391, 17.2393023286547, 14.27365049294063, 9.684980239186968, 23.385723965508596, 48.977202211107524, 54.01347541809082, 64.98686272757394, 72.61301095145089, 48.557465008326936, 2.678506238119943, 0.5179483613797596, 0.016882175180528845, 0.015505205407472593, 0.13657670920448645, 0.06970642493771655, 0.07035266847482749, 0.09188777540943452, 0.023321737136159624, 0.0500781947879919, 0.05465163616463542, 0.02486918374363865, 0.013992520997167697, 0.053700811828353574, 0.05742266122251749, 0.0556549044725086, 0.046892639116517136, 0.017791788692453077, 0.05640386803341763, 0.03301158361136913, 0.048827576717095714, 0.03573464981413313, 0.06880457725908075, 0.13347933255136013, 0.04837701589401279, 0.025300180705796396, 0.04918116131531341, 0.06334374778504882, 0.01564348066624786, 0.03678970391462956, 0.08581137896648475, 0.09484165547681705, 0.10716883186250925, 0.02297360117414168, 0.0023044597141311635, 0.042826779253248654, 0.020816485763394406, 0.020022501403998052, 0.018399323503087674, 0.05508972551407559, 0.014838510824899589, 0.04922733562333243, 0.05988912244460412, 0.04394723055884242, 0.07927338193569865, 0.026977188486073698, 0.046761888811098676, 0.06137714974050011, 0.058538206719926426, 0.03498767436082874, 0.060387370708797655, 0.013893854371937258, 0.07355538768959896, 0.14470535516738892, 0.08663883206567594, 0.09182052580373627, 0.03297889179417065, 0.06297986981059824, 0.11773897574416228, 0.06086698640137911, 0.038325198127755096, 17.883101565497263, 65.24923365456718, 77.5230736051287, 73.35564831324986, 72.03066158294678, 59.35034506661551, 42.137350354875835, 90.53010831560407, 89.36090019771031, 28.145005498613628, 28.349032402038574, 37.71889707020351, 38.95322717939104, 46.822395597185405, 28.615794590541295, 9.567044121878487, 0.44486368021794725, 0.082335793679314, 0.014074904478288122, 0.07750045814152275, 0.16272132843732834, 0.6839654701096671, 1.3516850748232432, 2.168409449713571, 2.4106672959668294, 2.2589429574353352, 2.9558492302894592, 1.3563456875937325, 2.1232613580567494, 4.847016002450671, 10.789250493049622, 13.880579607827322, 16.663666657039098, 24.067602804728917, 26.480418613978795, 39.11160789217268, 53.18650776999337, 64.60423237936837, 66.53270489828927, 67.38485281808036, 66.84020437513078, 66.97332491193498, 68.86285277775356, 66.79515920366559, 64.6665368761335, 67.01422895703996, 68.7392304284232, 66.3994037083217, 64.8479334967477, 63.68762602124895, 61.179187365940635, 65.62299115317208, 69.79390444074357, 69.80102634429932, 70.51748984200614, 62.30899919782366, 46.462392057691304, 31.937134265899658, 51.910585744040354, 51.19854824883597, 49.70197922842843, 53.059188979012625, 37.09362867900303, 40.04504973547799, 56.69376734324864, 61.55639811924526, 62.92957060677664, 68.24861117771694, 65.44487408229283, 60.04462991441999, 59.70794800349644, 55.893150738307405, 58.98374421255929, 65.78121553148542, 65.56890637534005, 69.65091746194022, 67.50150612422398, 66.0214147567749, 68.92601885114397, 67.19739042009626, 51.94061585835048, 27.90131480353219, 8.520255446434021, 1.4415651261806488, 0.15960725982274326, 0.7195607115115438, 0.6933787049991744, 1.960792716060366, 1.8375792247908456, 1.382526608450072, 2.1578086699758257, 2.369702454124178, 1.4492306177105223, 1.5890309789351054, 0.6962949399437223, 0.3016118013433048, 0.06073192400591714, 0.1521196123212576, 0.04305103846958705, 0.13650213820593698, 6.457661850111825, 29.328707558768137, 39.83629805701119, 44.65852505820138, 56.09455122266497, 37.774920395442415, 19.66448245729719, 18.81017885889326, 17.96030126299177, 35.65174892970494, 57.10496173586164, 60.77787331172398, 71.8448042188372, 79.65922083173479, 65.21663965497697, 4.790902350630079, 0.5311413620199475, 0.023654202331921885, 0.046288943117750544, 0.07885136029550008, 0.1014411820630942, 0.0632623778656125, 0.08343069135610547, 0.06976558640599251, 0.037314594856330326, 0.00039657376744019397, 0.015040721045807004, 0.023269374588770524, 0.0750373692384788, 0.06169353026364531, 0.03213492315262556, 0.12194017959492547, 0.11965297375406538, 0.06697300089789288, 0.003844542520320309, 0.010635577558007623, 0.020746662813637937, 0.02185617952740618, 0.08048745071781532, 0.0753406947478652, 0.00997559623127537, 0.05157123985035079, 0.10432218068412372, 0.062138947791286876, 0.029111089517495463, 0.09006023633160762, 0.043038346472063234, 0.03772071502836687, 0.12017921837312834, 0.15285517142287322, 0.14131485138620647, 0.1457273374710764, 0.07897202417786632, 0.16229448919849737, 0.18163246581596987, 0.14769001358321734, 0.08511863542454583, 0.1792934470410858, 0.0996568181685039, 0.20900726903762135, 0.1482543104461261, 0.12974966982645647, 0.15591613788689884, 0.20144327277583735, 0.20323176894869122, 0.2235185139413391, 0.27616008850080626, 0.15228761759187492, 0.28702278275574955, 0.1096110829551305, 0.18938349347029412, 0.19754213068102086, 0.16556111962667533, 0.21935555232422693, 0.17023777296500547, 0.2376457080245018, 23.117150034223283, 78.19889014107841, 84.83485058375767, 82.97097546713692, 79.11463492257255, 67.31944247654506, 49.3195538520813, 84.0796091897147, 91.79459708077567, 39.96051795142037, 44.21512923921858, 53.06733921595982, 48.028015749795095, 58.81699439457485, 35.05367578778948, 13.813637188502721, 1.040727892092296, 0.11714168850864683, 0.17547051289251872, 0.20622979450438703, 0.14800849077957018, 0.692984340446336, 1.335975632071495, 3.1923372490065436, 4.379999782357897, 4.619849426405771, 6.99930693422045, 7.21701614345823, 9.32574360711234, 9.914554800306048, 12.433456574167524, 15.423131806509835, 20.146744762148174, 28.34712164742606, 28.404468604496547, 43.77046537399292, 53.718142236982075, 68.73954309735979, 69.7587674004691, 68.80491869790214, 68.91465159824916, 69.72576345716203, 69.76743875231061, 67.97099590301514, 67.39212758200509, 70.65433461325509, 71.59928962162563, 66.94750540597099, 62.26456546783447, 64.60826928274972, 61.12613786969866, 65.98087201799665, 71.66953590938023, 71.85223184313092, 73.23790413992745, 64.63982800074986, 50.43558740615845, 36.6975222996303, 55.181127139500205, 56.79914024897984, 55.05698714937483, 57.574281283787315, 42.528749329703196, 43.42509126663208, 57.4349490574428, 61.17551176888602, 63.710645403180806, 70.83319514138358, 63.80834402356829, 63.461483001708984, 59.33861650739397, 56.41819831303188, 59.34103448050362, 67.23792621067592, 66.77052089146206, 70.1436767578125, 72.02008642469133, 68.04781518663678, 71.4207626070295, 71.29175540379116, 57.05529601233346, 29.681120191301616, 8.843323230743408, 2.847973018884659, 3.848354024546487, 4.476019978523254, 3.869110030787332, 6.8137587649481635, 6.064484570707593, 5.619445502758026, 5.483712009021214, 4.965443704809461, 3.275884125913892, 1.3102032435791833, 0.4968549332448414, 0.2995432194854532, 0.20234824850090913, 0.25711184633629663, 0.0964174580627254, 0.4309276837323393, 9.288595931870596, 38.90697302137102, 50.166452407836914, 52.871959345681326, 58.136095251355854, 42.142933232443674, 26.486206463405065, 22.10787034034729, 17.910074472427368, 39.08442653928484, 63.6098061970302, 69.65321036747524, 81.06575856889997, 88.61807523454938, 74.3361086164202, 6.128032795020512, 0.7352011065397943, 0.07927115634083748, 0.11762050352990627, 0.2493100506918771, 0.2462349028459617, 0.1629211434296199, 0.15498547282602104, 0.11399395098643643, 0.21342563123575278, 0.16057736133890493, 0.11546756619853632, 0.07978757577283041, 0.20386929331081255, 0.1905906479805708, 0.10450877102890185, 0.1319882654185806, 0.26871015397565706, 0.26531351623790606, 0.11625161341258458, 0.1739588047244719, 0.1152733423347984, 0.22189365327358246, 0.19938195124268532, 0.1098667753062078, 0.17504577711224556, 0.12727411623511994, 0.2201284851346697, 0.17746746859380177, 0.1313508903341634, 0.16672933979758195, 0.13862203088189873, 0.18115902479205812], [0.03327873981158648, 0.026248136535286903, 0.03573579993098974, 0.028060237245102013, 0.028799261964325393, 0.03111779237432139, 0.06783727130719594, 0.06391208871666874, 0.043053352274000645, 0.04954216230128493, 0.025533126866711036, 0.037120147076036246, 0.05907621035086257, 0.07358849341315882, 0.011730341224132903, 0.024912321607449224, 0.008095282396035535, 0.03655765172360199, 0.012360900424287787, 0.1033328901976347, 0.04592291418729084, 0.0345713083100106, 0.03847626377163189, 0.0952503914013505, 0.05050464726186224, 0.07799188712877886, 0.01822524025504078, 8.052723322595869, 53.49479586737496, 71.88801506587437, 70.93629946027482, 60.80943897792271, 48.90980815887451, 30.933487824031285, 26.39224944795881, 22.794571229389735, 16.934135709490093, 38.02700451442173, 43.9888368334089, 40.52396821975708, 48.49919046674456, 24.0887895992824, 5.374405554362705, 0.04544752916055066, 0.11283077911606856, 0.03678531040038381, 0.09380128487412419, 0.08736369067004748, 0.07299226469227246, 0.6021790387375014, 1.6704993673733302, 2.9231080157416205, 1.6486694301877702, 0.10907202759491545, 0.6167786696127483, 3.501592231648309, 9.390251551355634, 14.8910630771092, 25.654333387102398, 29.334203583853586, 40.12564883913313, 49.72187886919294, 52.53748001371111, 60.3648932320731, 66.75740269252232, 61.744541440691265, 62.080653599330354, 58.659402302333284, 61.46542535509382, 60.99839523860386, 65.98073305402482, 60.01268209729876, 56.947803906032014, 58.1092335156032, 63.22749546595982, 63.70089708055769, 66.68842097691127, 63.18871756962368, 61.06822463444301, 61.90117468152727, 64.53917639596122, 65.7012139729091, 66.18081338065011, 60.562048367091585, 64.06202970232282, 33.442798478262766, 30.96432740347726, 46.466491494859966, 46.01202719552176, 37.17218501227242, 33.454596519470215, 56.10432733808245, 60.862557956150596, 62.81672491346087, 65.76041262490409, 63.294114794049946, 55.84495455878121, 55.126882553100586, 55.289640630994526, 60.10097285679409, 60.38636316571917, 61.892301831926616, 57.70122487204415, 56.2801376070295, 54.20098645346505, 54.32833998543875, 53.527789388384136, 56.029634203229634, 60.96340411049979, 67.82011577061245, 68.58414663587297, 52.99336869376046, 26.074402366365703, 8.681221757616315, 2.9700166072164262, 0.9392027684620449, 1.5580081407512938, 0.8063583139862333, 1.0050145855971744, 1.292002328804561, 1.1817845744746072, 1.4465113750525882, 1.063198474901063, 0.2575986816414765, 0.08265325985848904, 0.13743416033685207, 0.18534641366984161, 0.042412448807486465, 0.13303230011037417, 4.883501427514212, 20.396205936159404, 31.784322534288677, 33.894521713256836, 38.47240488869803, 41.445632866450715, 33.291265215192524, 25.206971883773804, 16.109123979296, 26.358258860451834, 54.77177749361311, 58.3953012738909, 61.830226625714985, 72.14484827859062, 34.41870423725673, 1.0367415802819389, 0.09840348256485802, 0.030378233308770826, 0.030412190593779087, 0.15996738549854073, 0.05413507763296366, 0.11030597745307855, 0.01447363879664668, 0.035856392567179034, 0.07186811537082706, 0.007442103382865233, 0.043013725828911574, 0.045229044277220964, 0.06077345034905842, 0.016589987823473554, 0.12794513308576175, 0.09205143805593252, 0.06778154322611434, 0.011893349084337907, 0.035228194668889046, 0.08683188884918179, 0.0415480359058295, 0.06102310373846974, 0.03599644898037825, 0.09158125400011029, 0.047728098928928375, 0.04194683129233973, 0.09506660340619938, 0.0068607494218407995, 0.05099035619891115, 0.05966666473874024, 0.05627233402005263, 0.09078555633979184, 0.03137348472539868, 0.024620658418695842, 0.0896922532202942, 0.0127883232032348, 0.04751525267160364, 0.0490380854212812, 0.03093423168840153, 0.06675126922449895, 0.029548948165029287, 0.015104301473391908, 0.026775353155764084, 0.06644390643175159, 0.014943329218242849, 0.057036452660603185, 0.05477841704019478, 0.047905953135341406, 0.007325369066425732, 0.025444028433412313, 0.050098065686013014, 0.021423165619905506, 0.010442634429117399, 0.03614952987326043, 0.04223087962184634, 0.047433004049318175, 0.024249043448695114, 0.05840555312378066, 11.428978085517883, 65.59572642190116, 82.1934095110212, 78.40166636875698, 68.79385021754673, 58.72316592080252, 44.21262788772583, 36.912985937935964, 32.1636073248727, 33.48969881875174, 41.255418981824604, 34.711866106305806, 38.72185911451067, 49.036171572549, 27.388654129845754, 5.976273281233651, 0.06902168810899768, 0.06396766752004623, 0.12087976506778172, 0.12197915464639664, 0.4882735280053956, 1.0162367948463984, 1.4172804121460234, 3.0699571073055267, 2.1001507810183933, 2.5759632033961157, 1.4269187578133173, 0.8043315570269312, 2.802239541496549, 8.883035659790039, 17.691711698259624, 26.844622339521134, 32.85357386725289, 43.46175691059658, 49.0581556728908, 54.20212595803397, 60.63472652435303, 69.52360561915806, 65.12845311846051, 64.56873403276715, 62.057759284973145, 64.2674948828561, 64.34933076586042, 68.91624273572648, 61.334389277866904, 58.61760193961007, 61.68663515363421, 64.90843841007778, 64.6785364151001, 66.40889494759696, 63.496230942862375, 62.8520565032959, 62.88976437704903, 65.02675233568463, 66.78635583605084, 69.17672375270298, 62.68637670789446, 66.88591657366071, 36.75917713982718, 35.99868638174874, 51.34873356137957, 51.651452677590505, 42.681171962193076, 36.60607705797468, 58.009037017822266, 62.723306383405415, 63.71359143938337, 67.56556851523263, 65.2628173828125, 58.07714673451015, 57.201194286346436, 56.6472178867885, 60.928996631077354, 63.12377275739397, 63.34919316428048, 62.044495173863, 58.72242941175188, 57.38255616596767, 57.76277548926217, 56.126089096069336, 60.725768770490376, 64.52933774675641, 72.29973752158028, 72.23746081760952, 56.00377300807408, 27.178530182157242, 9.481550012316022, 4.047030815056392, 1.1615577169827052, 0.22784744522401265, 0.3856871213231768, 0.754194550216198, 0.8582940357072013, 1.7622840936694826, 1.4889781134469169, 2.0449829527309964, 1.0826833950621741, 0.46757712428058895, 0.20260742173663207, 0.12306791836661951, 0.07595895550080708, 0.06606712950659649, 4.794016446386065, 22.15681345122201, 35.20534454073225, 36.00904614584786, 35.848323890141074, 28.77065256663731, 26.22453383037022, 28.68813054902213, 25.989422423498972, 37.41205072402954, 66.36887332371303, 65.16004657745361, 70.40095465523856, 79.99484661647251, 49.8036869594029, 1.45748171210289, 0.03650875309748309, 0.0636975902265736, 0.027529583844755377, 0.08025750198534556, 0.050919595174491405, 0.023308921305994903, 0.038981419522315264, 0.06950060491050992, 0.06249108032456466, 0.08253841780658279, 0.08761850092560053, 0.05558675580791064, 0.03803317701177938, 0.06030403303780726, 0.05749044008553028, 0.11786177701183728, 0.062354721927217076, 0.010996886429243853, 0.06813976900385958, 0.05593572297532644, 0.06551355349698237, 0.140328817867807, 0.049009383389992375, 0.033768587812249146, 0.042794101006750546, 0.02632519436467971, 0.042787987406232526, 0.02197377473515059, 0.03213916738916721, 0.08564496146781103, 0.049816707747855356, 0.23104502792869294, 0.11150788688766104, 0.170775973371097, 0.27956877702048843, 0.13922722983573163, 0.14329481657062257, 0.13313596669052327, 0.13841916248202324, 0.10723015107214451, 0.06001259546194758, 0.09652398127530303, 0.0683409207101379, 0.18464826898915426, 0.1469058578035661, 0.09227341400193316, 0.19039368283535751, 0.10258004880909409, 0.20869791135191917, 0.16419062816670962, 0.15620992997927324, 0.1404415089637041, 0.14688510820269585, 0.18530433092798504, 0.18834583700767585, 0.09837105537631682, 0.2129357018108879, 0.13328181100743158, 14.970069306237356, 79.65853296007428, 87.73447976793561, 89.01268427712577, 78.57533659253801, 66.5387498310634, 44.30204425539289, 38.58317654473441, 31.55709559576852, 25.299752916608536, 50.37119150161743, 59.411885261535645, 54.306005001068115, 65.26457527705601, 34.92205606188093, 8.666556715965271, 0.27020059685621944, 0.26522886220897945, 0.16034295463136264, 0.1829405456249203, 0.317937218184982, 0.9509135229246957, 1.81728929068361, 4.1095563513892035, 6.848203156675611, 6.198044146810259, 3.546294552939279, 3.52377696122442, 7.6935822282518656, 12.417074458939688, 19.37616174561637, 31.886839730398997, 39.15810176304409, 47.941733019692556, 52.578703675951274, 55.87149320329939, 60.83928843906948, 72.64399296896798, 68.71612071990967, 67.38591589246477, 64.03147152491978, 68.16721997942243, 64.39451490129743, 71.74648720877511, 66.22056402478898, 63.52064691271101, 62.4393196105957, 69.20871325901577, 67.16611657823834, 67.63771860940116, 63.675966944013325, 63.77593762534005, 64.27222660609654, 67.01505579267229, 68.7862627846854, 68.90732819693429, 64.29703862326485, 68.2979016985212, 40.27261018753052, 41.178464208330425, 56.36723675046648, 56.32270574569702, 47.00306265694754, 40.69535248620169, 60.41139752524239, 64.96664346967424, 66.3421436037336, 68.52235630580357, 66.27019500732422, 62.00259058816092, 58.06376450402396, 58.40534142085484, 61.120447295052664, 66.33343056270054, 67.76585728781563, 64.88514804840088, 61.08131504058838, 58.619665554591585, 60.316068240574424, 58.81173460824149, 61.49244689941406, 65.27394839695522, 75.88625172206334, 77.06593772343227, 61.137185505458284, 29.164584159851074, 10.474268674850464, 5.544791451522282, 4.3339866399765015, 4.279408974306924, 4.407766955239432, 4.5109416246414185, 5.654819216047015, 5.594461517674582, 3.731905690261296, 3.159958209310259, 1.2937888843672616, 0.3633381048483508, 0.2961467445961067, 0.4690021021025521, 0.26708109996148516, 0.4133772397679942, 7.818907754761832, 31.387212140219553, 48.3471291405814, 50.711604595184326, 57.8532167162214, 60.09121758597237, 48.160827091761995, 38.651321002415244, 27.408228942326136, 41.458160468510215, 72.53296075548444, 74.73392077854702, 80.05300303867885, 89.19021769932338, 58.20872129712786, 2.5453129623617445, 0.1636855402695281, 0.20789316881980213, 0.14682098664343357, 0.1908529560480799, 0.16728216941867555, 0.10840572656265327, 0.19723413006535598, 0.15543094463646412, 0.19724874570965767, 0.18827607003705843, 0.16857571500752652, 0.1280837577900716, 0.18891957907804421, 0.12307530082762241, 0.24016432144812175, 0.15938213547425611, 0.1825293805450201, 0.18011594004929066, 0.09994491735207182, 0.14428409348641122, 0.16556832566857338, 0.24257708340883255, 0.08620011167866842, 0.23310611875993864, 0.23106589966586658, 0.18246042781642505, 0.1914412730506488, 0.1611126847565174, 0.12965596414038114, 0.11066360612000738, 0.1075540090511952], [0.04975653186972652, 0.05208323184134705, 0.022173803465973054, 0.04166054379727159, 0.047447551840118, 0.0878047655735697, 0.05426471514095153, 0.04003126247386847, 0.07791791324104581, 0.006379853842580425, 0.009608981216193309, 0.023861084266432693, 0.04245366302451917, 0.0369994323035436, 0.06657349983496325, 0.009408011866201247, 0.0026032748740232948, 0.013881619537382253, 0.052596954096640856, 0.03388651719849024, 0.003075452974631584, 0.05655685732407229, 0.051646798117352385, 0.01813467448976423, 0.028896306042692492, 0.11195525859615632, 0.7690749317407608, 31.226934569222585, 68.49862820761544, 61.10101318359375, 64.83246680668422, 51.09408903121948, 27.298166002546036, 16.87291513170515, 16.621935776301793, 27.424411296844482, 16.618765660694667, 37.01485695157732, 46.27415146146502, 42.766752924237935, 30.842379570007324, 10.23839557170868, 0.2017615871237857, 0.13646263389715127, 0.0599541464554412, 0.2772033768040793, 0.03951280404414449, 0.1311242189258337, 0.3173317206757409, 1.9837758370808192, 1.0692933478525706, 0.8832956084183284, 1.4277746890272414, 1.7577688502413886, 5.890485176018306, 10.837982552392141, 20.87940972191947, 32.41176571164812, 38.14197635650635, 48.998053755079, 56.64884376525879, 57.01720946175711, 57.52614068984985, 62.175607681274414, 63.44638456617083, 62.904723848615376, 52.97103023529053, 51.95920576368059, 59.96451718466622, 66.80448368617466, 66.50572504316057, 62.513408252171104, 54.39038392475673, 54.2232415335519, 58.05700043269566, 60.37519046238491, 63.85301399230957, 63.06738812582833, 61.960234369550435, 62.44413471221924, 62.46695954459054, 61.72166797092983, 65.84311703273228, 63.92578247615269, 56.72178942816598, 61.26993778773716, 36.98506655011858, 35.383576256888254, 36.665480681828086, 29.5379456111363, 55.96229573658535, 60.79893330165318, 60.70620264325823, 57.880022866385325, 53.97043827601841, 58.943757329668315, 58.81721673692976, 57.146637031010215, 59.75051266806466, 61.081523486546104, 56.511943408421104, 55.63889183316912, 53.39714935847691, 49.52852439880371, 47.63343102591378, 49.404770033700125, 51.20831046785627, 52.67440468924386, 51.90484653200422, 54.734740121024, 53.89145115443638, 60.764852387564524, 68.80697536468506, 60.7112192426409, 40.1556442124503, 30.14556210381644, 9.070648312568665, 2.10082671046257, 1.2106115647724696, 2.033207276037761, 1.2012662376676286, 2.67108382497515, 2.1516577771731784, 1.4982195432697023, 0.1600137972938163, 0.11919813816036497, 0.02581326344183513, 0.14921768089490278, 0.20426589702921255, 0.06174551283142396, 1.1999831008059638, 9.561990175928388, 30.222839968545095, 46.850393363407676, 54.20010750634329, 48.837557315826416, 38.38664674758911, 15.883936337062291, 21.166396379470825, 38.27232108797346, 49.04428359440395, 59.528309277125764, 61.72057015555245, 64.09067712511334, 6.510481187275477, 0.49485819467476433, 0.050380234473517964, 0.12186119811875479, 0.0410601624420711, 0.07006062700280122, 0.02881401331563081, 0.09779742187155144, 0.06645255096788917, 0.04788893886974879, 0.03472975980756538, 0.08926843346229621, 0.09008798162852015, 0.04133183429283755, 0.04170663668108838, 0.060672009363770485, 0.0528303260382797, 0.08852862673146383, 0.03669920091384223, 0.05981390005243676, 0.02330943868894662, 0.05964798466967685, 0.026046111215172068, 0.0771630701742002, 0.06427031449441399, 0.09525665427957263, 0.06769123700048242, 0.022594113501587083, 0.04395430089373674, 0.043411018260355504, 0.023572672956756184, 0.03793574956112674, 0.024113344926653162, 0.03928505715781024, 0.024881919845938683, 0.03006279594930155, 0.0518364079429635, 0.0617397724251662, 0.03706206787111504, 0.08157352743936436, 0.024458137407366718, 0.04241833849144833, 0.033908522089145014, 0.031045609819037572, 0.0527186256035098, 0.018623776101906384, 0.005190400614602757, 0.026994689600542188, 0.0501486267229276, 0.025806924228423407, 0.043012772487210374, 0.03900600623871599, 0.011429244702282761, 0.11917757854929992, 0.044362921467317004, 0.01512735300431294, 0.058502149369035444, 0.08965410598154579, 1.441350166286741, 42.072506291525706, 79.35319437299455, 70.71467971801758, 74.20054926191057, 60.674477168491904, 38.656803131103516, 23.45162241799491, 20.693858078547887, 29.97431332724435, 16.34088809149606, 28.276316029684885, 45.65805121830532, 41.06398221424648, 32.951480933598106, 10.121750950813293, 0.05433403767113175, 0.08740042655595712, 0.07031411411506788, 0.2590190997081143, 0.28847862035036087, 1.0283935368061066, 1.9359444379806519, 3.2097001458917345, 2.174151484455381, 2.468932066644941, 1.989501369850976, 2.570391833782196, 5.368391454219818, 12.48903955732073, 24.967201709747314, 35.74034193583897, 43.89536966596331, 55.44722230093819, 61.05110427311489, 59.75742612566267, 58.82752786363874, 63.53221566336495, 66.65880080631801, 63.93791403089251, 56.04013293130057, 54.77035311290196, 62.815488134111675, 69.39577266148159, 68.51569298335484, 64.91269070761544, 58.0648067338126, 57.0664061818804, 59.449204036167686, 62.333915437970845, 64.3664163861956, 64.12986496516636, 60.92969839913504, 63.691350255693706, 63.424428258623394, 64.24897793361119, 66.49452454703194, 65.68842928750175, 57.55123063496181, 61.958816937037874, 42.212898118155344, 40.923545224326, 42.565150942121235, 33.266991683415, 56.86593328203474, 64.85763318198067, 62.170632771083284, 58.722380774361746, 57.84780406951904, 61.21793052128383, 62.52133614676339, 56.893455096653526, 60.8806163242885, 63.827951839991975, 59.27413027627127, 58.0256849016462, 56.122152941567556, 52.58029133932931, 50.76650926045009, 50.98988689695086, 54.375591209956575, 55.499257360185894, 55.70616429192679, 57.36701651981899, 57.584665366581504, 64.09788240705217, 72.06382533482143, 62.96154621669224, 43.08168349947248, 32.48463494437081, 11.730976326125008, 2.9871810461793626, 1.0245952606201172, 1.1591830615486418, 0.49139299775872913, 2.0769175248486653, 2.9922365120479038, 2.7251212682042802, 1.0069122037717273, 0.6520820866738046, 0.36518621710794313, 0.0649717500699418, 0.1240346814904894, 0.045924010021345954, 1.18303525022098, 9.306221774646215, 29.78669806889125, 45.962827001299175, 49.61076327732631, 39.15997082846505, 29.821331364767893, 16.696785245622905, 32.13013437816075, 49.264301776885986, 53.26241683959961, 67.85523196629116, 67.5346907206944, 76.62014825003487, 10.795560325895037, 0.6227879385863031, 0.004368278680236212, 0.19389880475189003, 0.04575134660782559, 0.07932379030223403, 0.04920639603265694, 0.12613632157444954, 0.051695096239979775, 0.0730570580012032, 0.016303403469334756, 0.06297467901770558, 0.14383421119834694, 0.01847158239356109, 0.06888804385172469, 0.08220926046903644, 0.06590743628995759, 0.07859749998897314, 0.07029681147209235, 0.04088283410029752, 0.05685488347496305, 0.03767319382833583, 0.043129619610096724, 0.05121490718530757, 0.044577793151672394, 0.05180256600890841, 0.056211971544793675, 0.01591087774639683, 0.027441920513021092, 0.051177418125527244, 0.021590232815859572, 0.06034848386687892, 0.1576320579541581, 0.1423487759062222, 0.10406890391771283, 0.1375683338514396, 0.16745611865605625, 0.1561118545276778, 0.14557525063199656, 0.20882182541702474, 0.09450679165976388, 0.11570172863347189, 0.09779047367296048, 0.19153808642710957, 0.11654121215854372, 0.07781320850231818, 0.13298423268965312, 0.12570583181721823, 0.08179899105536086, 0.12061548924871854, 0.08530369906553201, 0.1496711458478655, 0.10526159884674208, 0.1459764412471226, 0.13576709479093552, 0.2354394378406661, 0.12805863842368126, 0.1844030600041151, 2.3439639380999973, 58.00260646002633, 88.53045845031738, 79.48345920017788, 82.05791963849748, 67.09300068446568, 41.66342067718506, 26.288425990513392, 24.14744281768799, 38.9447295325143, 23.677850552967616, 51.27338382175991, 61.877578599112375, 56.016540322984966, 43.30030161993844, 14.711565051759992, 0.4625295294182641, 0.34793606560145107, 0.24688673072627612, 0.42170167022517746, 0.22353076828377588, 1.247301201735224, 1.4194165489503314, 5.345622641699655, 7.488441007477896, 6.704138338565826, 5.486943789890834, 6.350178863321032, 10.852905545915876, 13.90594140120915, 30.579480579921178, 41.069387912750244, 47.84168243408203, 58.016537598201204, 62.93448993137905, 61.82270172664097, 60.91850485120501, 65.48106030055455, 68.68384633745465, 68.09483364650181, 57.39875589098249, 56.9708753994533, 66.16956424713135, 70.8742242540632, 69.51324585505894, 68.32964106968471, 60.07562582833426, 60.004788943699424, 62.61734635489327, 66.17424733298165, 66.18441254752022, 66.65272808074951, 63.403667041233604, 65.7255882535662, 64.42844990321568, 65.60348061152867, 68.85354219164167, 65.51405729566301, 62.370282309395925, 63.08514077322823, 45.56373289653233, 46.415974617004395, 46.76659461430141, 37.82600007738386, 60.53114972795759, 66.02570874350411, 63.9926449911935, 62.30899224962507, 60.09233624594552, 64.12536253247941, 64.29166071755546, 60.640556062970845, 60.92725263323103, 66.58967317853654, 61.42545236860003, 62.16279520307268, 57.61662360600063, 55.77371120452881, 53.33864205224173, 52.76573528562273, 57.35992240905762, 57.938453742435996, 58.791230474199565, 61.113811765398296, 59.359704290117534, 64.57503604888916, 74.83423886980329, 63.88703237261091, 45.05204323359898, 34.17945344107491, 13.985829183033534, 3.72057752098356, 3.4411127226693288, 5.750601436410632, 7.10379524741854, 8.535962717873709, 7.655612928526742, 4.765431123120444, 1.3230072536638804, 0.37571756914258003, 0.2439758697790759, 0.36315082918320385, 0.5230834058352879, 0.21023655736020633, 2.553589786802019, 15.071064846856252, 42.80619784763881, 62.793552671160015, 70.1204558781215, 67.3868955884661, 53.28494637353079, 25.704626185553415, 31.916981015886577, 53.728123324257986, 62.77017893110003, 78.41510418483189, 76.90302331107003, 88.74722834995815, 15.476233414241246, 0.9927779393536704, 0.16670412543628896, 0.2960659717874867, 0.12950488153312886, 0.25575876608490944, 0.13050728131617817, 0.198208465640034, 0.17893752828240395, 0.14730896188744477, 0.0958257687411138, 0.23779715704066412, 0.18020484170743398, 0.10473719984292984, 0.10796649727438178, 0.25693621433206965, 0.16453522896128042, 0.15377742264951977, 0.13249332617436135, 0.20125576640878404, 0.14521948115101882, 0.17130611278116703, 0.15213088957326754, 0.16038532235792705, 0.1334970558860472, 0.13974305215690816, 0.15125118249229022, 0.14278957939573697, 0.10674966685473919, 0.18496506341866084, 0.11770175131303923, 0.23984158305185183], [0.03423162010897483, 0.03220972824575646, 0.015265014188896333, 0.0749037249812058, 0.03107196751183697, 0.038307834416627884, 0.04133360187656113, 0.04001303702326758, 0.014019879529119601, 0.020140956654878597, 0.00689431612512895, 0.017993228776114326, 0.003664741342488144, 0.025089376838877797, 0.04910381171586258, 0.06339383045477526, 0.08464891277253628, 0.028830060668821846, 0.022311228859637464, 0.01938689899231706, 0.026102648449263403, 0.06329095097524778, 0.036350515338459184, 0.004316489494937871, 0.05345606763980218, 0.07365441309022051, 13.426082304545812, 60.05792876652309, 65.82123715536935, 65.50756767817906, 53.69642564228603, 39.983297620500835, 24.875485488346644, 24.51023953301566, 31.93450437273298, 32.79965237208775, 53.18930789402553, 61.71064117976597, 44.79053040913173, 32.51191357203892, 6.555868557521275, 0.1783330078635897, 0.07959783024021558, 0.07508909396295037, 0.027983099687844515, 0.12034062828336443, 0.5964894954647336, 2.1868417177881514, 3.4225853511265347, 2.1695070479597365, 2.154045351913997, 0.5109293780156544, 1.946457496711186, 6.384923330375126, 13.028152891567775, 29.588570186070033, 41.56412744522095, 55.62074661254883, 62.533502442496165, 64.37529618399483, 63.27534770965576, 58.81017126355852, 56.52161182676043, 61.398354394095286, 61.76719951629639, 58.13642529078892, 47.90733248846871, 51.03866672515869, 58.72385379246303, 59.46984018598284, 56.212173802512034, 62.35366916656494, 57.07073490960257, 51.27456154142107, 53.45394740785871, 55.84767825262887, 56.49595560346331, 58.75659370422363, 58.25544098445347, 60.507845469883506, 58.903728757585796, 63.633346693856375, 59.899419512067524, 60.6382075718471, 55.58102028710501, 62.624801771981375, 49.41914585658482, 28.664859294891357, 20.466165610722133, 44.072753701891216, 64.34646810804094, 56.538621016911094, 58.2203699520656, 48.8564772605896, 55.71143797465733, 58.943326541355674, 62.0886162349156, 59.93775272369385, 59.061306953430176, 58.87449768611363, 57.77075202124459, 50.98083686828613, 47.48601804460798, 43.29868963786534, 47.12525715146746, 47.315940039498464, 48.38797065189907, 46.315739904131206, 48.30983121054513, 53.36753266198294, 56.88771588461739, 58.62985856192452, 56.2052777154105, 59.14840957096645, 54.15970025743757, 53.988791942596436, 44.157278537750244, 44.89364167622158, 27.689024754932948, 4.808210747582572, 0.4353702967720372, 1.8790562791483743, 1.8653650709560938, 1.5015092981713158, 2.0889363884925842, 0.3552264358316149, 0.1443426510585206, 0.1199215921972479, 0.07439054216125182, 0.255997366138867, 0.05478254931845835, 0.3066814350230353, 2.286398547036307, 20.231795924050466, 32.755691119602744, 51.50318854195731, 63.994583538600374, 41.383401325770784, 25.09534386226109, 20.877014330455236, 44.5481390271868, 50.84178951808384, 61.78542464120047, 60.484742709568565, 33.09829289572579, 0.655700795352459, 0.06207376093204532, 0.08012428520513432, 0.0570717839790242, 0.08281559936170067, 0.034159878601453135, 0.024185464717447758, 0.012389150381620442, 0.03505463898181915, 0.1563810565109764, 0.03129307493301375, 0.06136844413621085, 0.14931152228798183, 0.11788156309298106, 0.03066657337227038, 0.023532427348462597, 0.027251776341082792, 0.07008432144565241, 0.0334218564177198, 0.027271925438461558, 0.023519333318940232, 0.025840867942731296, 0.0542253227904439, 0.029226739026073898, 0.028339871704312306, 0.040828846461538754, 0.04543738166934677, 0.03938519196318729, 0.029436925426125526, 0.0733544056170753, 0.018326520088261793, 0.019949509695704495, 0.029567058264677013, 0.036378521871353896, 0.08207300385194165, 0.08372639691723244, 0.037767225211220126, 0.024667821691504548, 0.04374180068927152, 0.027129329607955048, 0.03740181714030249, 0.02193509484641254, 0.024873875813292604, 0.01787721794763846, 0.029779823097799505, 0.05828289434845958, 0.07126627516533647, 0.11563604644366673, 0.029844060008014952, 0.01370197908753263, 0.03295846789010933, 0.027581040547894578, 0.04324169323912688, 0.04601519155715193, 0.022389396093785763, 0.027744453832773224, 0.1996746441083295, 19.18804795401437, 72.12075887407575, 73.67829486301967, 73.37611075810024, 59.38138266972133, 48.42171457835606, 28.90344306400844, 28.531891618456157, 25.353578874043055, 26.775393962860107, 43.07486384255545, 56.30031517573765, 44.72315372739519, 32.71349123546055, 6.709041161196573, 0.19866053281085833, 0.055179794252450974, 0.07043942596231188, 0.07507418654859066, 0.7093332345996584, 1.4026749730110168, 3.841313328061785, 4.155041430677686, 3.637231707572937, 3.0532023949282507, 1.3658692794186729, 2.818011518035616, 7.283478268555232, 17.365929773875646, 31.889177799224854, 46.12076997756958, 58.140622002737864, 64.61940029689244, 65.0205545425415, 63.878708430698936, 59.96249525887625, 58.656727245875764, 62.70329557146345, 65.09592165265764, 61.1556955065046, 50.83893380846296, 52.512574195861816, 61.732562746320454, 63.40206895555769, 60.18196105957031, 64.09797968183244, 59.174576486860005, 54.52251781736101, 56.49058812005179, 57.063939571380615, 58.15559537070138, 61.8249112537929, 60.519525391714915, 61.16841765812465, 60.72585909707205, 64.55943039485386, 60.66251931871687, 62.430085454668315, 58.591497557503835, 62.1780742917742, 51.98246485846383, 32.76614815848214, 24.911748136792863, 46.17633819580078, 65.56172193799699, 57.76821592875889, 61.1843707220895, 52.06431116376604, 57.81796850476946, 61.676282337733674, 64.04842512948173, 62.6132538659232, 59.014802660260884, 60.786968503679546, 59.76324871608189, 51.51192242758614, 48.66943522862026, 46.63687522070748, 48.534869466509136, 51.23440095356533, 50.649536337171284, 48.85706785746983, 50.67071097237723, 56.40315546308245, 59.855625016348704, 61.6076271874564, 58.65502493722098, 62.82447215488979, 57.98855372837612, 57.136357171194895, 50.308147021702354, 49.2512217930385, 30.80777406692505, 6.418741949966975, 0.6022900470665523, 0.14120577009660856, 1.2382722347974777, 1.7774137961012977, 2.4477865270205905, 1.2095180920192172, 1.3340827907834734, 0.3325080791754382, 0.032783504242875745, 0.14392527059784957, 0.050731583298849206, 0.18510797646428856, 2.1858644102300917, 19.25729717527117, 36.37758902141026, 46.74447849818638, 62.88618605477469, 33.94570561817714, 31.640765803200857, 31.1642062323434, 51.799074104854036, 58.134910583496094, 66.52020508902413, 70.83038112095424, 51.2102837562561, 1.0124300505433763, 0.10968722136957304, 0.04377151034506304, 0.08899876328983478, 0.07320959945874554, 0.040210975866232596, 0.08102960019771542, 0.021043413318693638, 0.053988870299820385, 0.019893316818135123, 0.013106102356687188, 0.06542657887829201, 0.0785016840589898, 0.016657566518655846, 0.03657239628955722, 0.05214800479422722, 0.019393845494570475, 0.05201250813635332, 0.04446819278278521, 0.018230146063225608, 0.04382654632042561, 0.042548922555787225, 0.02044444501266948, 0.023635710556326166, 0.03819638843248997, 0.04440052927072559, 0.06779352615454368, 0.023086875810154846, 0.020875696425459216, 0.09083133709750005, 0.05898926965892315, 0.12062725504594189, 0.12034710150744234, 0.10296562633344106, 0.22348840055721148, 0.13719898009938852, 0.17235945697341645, 0.1023779200123889, 0.08868543617427349, 0.09616796073636838, 0.1853724829852581, 0.08010384773037263, 0.054959745345903296, 0.11632950923272542, 0.0972704105079174, 0.23662114728774342, 0.13158802475248063, 0.14157962932118348, 0.08599611691066197, 0.08243364521435328, 0.09941245735223804, 0.11273408109056098, 0.1537021595452513, 0.15299006418458053, 0.10991697332688741, 0.09415755647101573, 0.3434426981423582, 27.796461275645665, 85.08985642024449, 83.11849961962018, 82.88832664489746, 69.46288531167167, 54.8503338268825, 35.62506784711565, 35.80865315028599, 46.32921246119908, 46.86484909057617, 68.91689586639404, 80.31488759177071, 58.60656125204903, 43.89495972224644, 10.407928143228803, 0.32224200719169205, 0.22280116671962397, 0.17852586108658994, 0.11408279836177826, 0.6006512492895126, 1.6383129230567386, 9.84671345778874, 9.190682785851614, 7.69069698878697, 7.864180479730878, 5.5096635307584485, 6.434007142271314, 11.56372276374272, 19.312724692480906, 37.492764472961426, 47.39906481334141, 62.97752012525286, 67.30419812883649, 67.99641241346086, 65.55675397600446, 59.58058057512556, 58.250212465013774, 64.82273932865688, 68.2722281047276, 64.58277634211949, 52.83300427028111, 56.40886688232422, 64.09990433284214, 64.85736915043422, 61.666937010628835, 66.27778244018555, 63.009245600019185, 57.78615617752075, 59.379249572753906, 60.206238065447124, 61.96022047315325, 62.82894679478237, 63.058758463178364, 63.55190685817173, 62.03355176108224, 67.55669566563198, 61.938229424612864, 62.710167339869905, 60.21596554347447, 63.7510769707816, 54.33423205784389, 39.26978015899658, 29.462290150778635, 49.551738330296104, 68.44926125662667, 60.92999022347586, 62.26618439810616, 54.04306779588972, 60.45538657052176, 64.9340911592756, 66.30285154070172, 63.95830699375698, 64.035154070173, 63.533438546316965, 63.35969884055001, 54.41739852087838, 52.58332770211356, 48.96569946834019, 51.290521553584504, 53.751337255750386, 55.096046447753906, 51.79957090105329, 51.8014086995806, 58.15623460497175, 62.49544715881348, 63.69810390472412, 60.397431646074565, 64.91125937870571, 57.44968966075352, 58.677488463265554, 56.96142584936959, 49.59327466147286, 33.61643743515015, 6.101226644856589, 2.2026523436818803, 6.168906441756657, 5.995828986167908, 4.120490644659315, 5.844964052949633, 1.9136046767234802, 0.8467585061277662, 0.46055526392800467, 0.22346998511680535, 0.578278049826622, 0.24515149955238613, 0.5773205554911068, 3.724775101457323, 29.80944299697876, 46.98759944098336, 66.08724199022565, 76.68159811837333, 56.51081780024937, 36.46638699940273, 31.92151471546718, 59.44620936257498, 67.1035897391183, 78.21128572736467, 77.98204381125313, 59.72689574105399, 1.551733374595642, 0.21502193914992468, 0.10991650513772454, 0.18356316935803207, 0.1627372604395662, 0.13198530700589928, 0.20527350796120508, 0.10575742474091904, 0.18129551889640944, 0.18936913566929953, 0.12368975499910967, 0.18392372929624148, 0.18354263688836778, 0.21114267302410944, 0.13112128765455314, 0.12073314722095217, 0.1411898923771722, 0.10605927782931499, 0.14252537143017563, 0.07412210013717413, 0.09184413882238524, 0.10743859024452311, 0.12580632285348006, 0.23159537411161832, 0.24462452211550303, 0.1877948801432337, 0.10592883625733, 0.1406572423875332, 0.0805664796914373, 0.1420072420899357, 0.1127118319272995], [0.009497410551245724, 0.0203072282685233, 0.04817761820075767, 0.035918631191764555, 0.06854978735957827, 0.04972702916711569, 0.012333842992250408, 0.038047745158629756, 0.033923076665295024, 0.02280926168896258, 0.023930785079885806, 0.042456824997706075, 0.053756136181099076, 0.0691009002870747, 0.04165824017088328, 0.07416902083371367, 0.016375645396432707, 0.05134252265893987, 0.07619562172996146, 0.03528703383303114, 0.041607010776975324, 0.048398891863014014, 0.033342898690274785, 0.01194483123254031, 0.010497012225511883, 4.479069369179862, 53.855806895664756, 72.21183586120605, 65.94234425680978, 60.76000254494803, 44.53781747817993, 29.078079087393625, 19.723681109292166, 24.34702113696507, 39.52174615859985, 48.575412205287385, 39.40735796519688, 33.2721402985709, 25.8346426146371, 6.5268281272479465, 0.2261969902153526, 0.07524558449430124, 0.13382130063005857, 0.14543231044496807, 0.03210163422461067, 0.5312871656247548, 1.105576406632151, 1.5362027393920081, 3.3764868761811937, 1.722503702555384, 1.039505769099508, 2.293527833053044, 16.095604521887644, 27.68900912148612, 37.02360473360334, 54.674203940800254, 61.95209108080183, 60.98587458474295, 60.926099232264924, 59.66813482557024, 60.91571862357003, 58.62114552089146, 58.93292508806501, 60.350663321358816, 58.22995499202183, 53.58232579912458, 47.160421984536306, 46.29460348401751, 57.6296306337629, 58.00051505225045, 60.355054582868306, 61.93083654131208, 59.4823955808367, 54.54706232888358, 52.95817606789725, 53.29162359237671, 55.33875049863543, 54.622196674346924, 58.40388229915074, 57.82366950171334, 60.0473119190761, 56.59833383560181, 61.08518518720354, 59.08004624502999, 59.196366037641255, 53.41171278272356, 61.36241136278425, 28.92216498511178, 24.209253992353165, 63.17113862718855, 56.18736525944301, 57.03295060566494, 48.554772581372944, 46.86830234527588, 46.339989117213655, 55.59965535572597, 56.09706647055489, 61.34944602421352, 60.71569388253348, 56.11155693871634, 50.785425731113975, 46.95801401138306, 43.63981144768851, 45.336874212537495, 50.159608432224815, 54.706509590148926, 56.465835162571494, 55.051230566842214, 50.48218550000872, 43.04949944359915, 45.355773312704905, 55.177868434361045, 59.67857101985386, 61.546754019601, 58.878395625523154, 52.243713651384624, 54.006079060690745, 62.842030252729145, 61.98338576725551, 59.466706548418315, 30.53406367983137, 2.661164402961731, 2.084483244589397, 1.9313030413218906, 0.9222010693379811, 1.7554100453853607, 1.5346365720033646, 0.18518372811377048, 0.08941800293645688, 0.024107117671519518, 0.07748951337167195, 0.033648202129240544, 0.10261637757399253, 1.498629269855363, 13.279421465737478, 42.9012769971575, 35.62780543736049, 32.07188762937273, 33.46286140169416, 16.86068630218506, 31.252830505371094, 46.88376208714077, 47.83487319946289, 60.4775721686227, 62.258596965244834, 7.674756952694484, 0.8066988842827933, 0.06237723571913583, 0.14540613256394863, 0.07809249351599387, 0.09886481852403708, 0.03237198632476585, 0.07436814372028623, 0.04034399926396353, 0.11421550624072552, 0.009396088309586048, 0.008278332484353865, 0.04305825808218547, 0.06589838463280882, 0.033309094075645716, 0.023471245542168617, 0.036139178821550946, 0.038479161116161516, 0.06091617340488093, 0.09955375548452139, 0.043327572023762126, 0.0067054654105699486, 0.03011792352689164, 0.009527909003996422, 0.0982082544692925, 0.045847912319004536, 0.048444411384740045, 0.04771613296387451, 0.02933112485334277, 0.0394299650963928, 0.040913951716252735, 0.010270408670684057, 0.011356850952974387, 0.06853148727012531, 0.04890541146908488, 0.062315692592944415, 0.012571290384845009, 0.03235888720623084, 0.031552468692617755, 0.021033421890544038, 0.045194713797952445, 0.03659982267501099, 0.05660004607800927, 0.07350485040141003, 0.03651250200346112, 0.06535375171474048, 0.04671960250873651, 0.04324687046131917, 0.008973433935482587, 0.152581178982343, 0.03203089694891657, 0.01436305115930736, 0.0876655030463423, 0.023182111592697244, 0.06303985909159694, 0.04664405781243529, 6.053883790969849, 66.88548578534807, 80.70900331224713, 73.28516578674316, 68.83270454406738, 55.602778570992605, 38.35385125023978, 32.48122337886265, 24.27565618923732, 37.57997131347656, 44.94208104269845, 39.81928539276123, 39.497170380183626, 28.597315856388636, 7.629120315824236, 0.2508492666695799, 0.051599561902029176, 0.028056233888491988, 0.27737974162612644, 1.3547503160578864, 1.5016050530331475, 1.812093666621617, 2.940045118331909, 5.364533466952188, 2.669392155749457, 0.5627829155751637, 3.400526123387473, 14.776638405663626, 28.48687423978533, 40.39302594321114, 56.380598136356895, 63.05907808031355, 64.63640948704311, 62.45362595149449, 63.696047237941194, 62.4526948928833, 58.37727069854736, 59.20468997955322, 62.37018503461565, 61.39187172480992, 57.22628075735909, 49.50396599088396, 50.06652341570173, 60.1641389301845, 61.97589560917446, 61.27888011932373, 62.73684842245919, 63.61058439527239, 57.07293054035732, 54.5760953766959, 55.74871506009783, 58.42241314479283, 56.88626718521118, 60.98291465214321, 59.098452023097444, 61.41327912466866, 58.19317470278059, 61.902932575770784, 59.332203320094514, 59.6566355569022, 55.86221040998186, 59.980720383780344, 31.4840179170881, 27.32445798601423, 64.56720542907715, 58.180164200919016, 59.6227422441755, 51.8683545930045, 49.150156770433696, 48.75538444519043, 58.430480003356934, 59.5880776814052, 63.02219704219273, 62.92316436767578, 58.58516080038888, 53.9741381917681, 49.201924324035645, 45.78489753178188, 47.35925163541521, 52.641227040972026, 57.21908589771816, 59.50437273297991, 57.944130420684814, 53.70860236031668, 45.23653875078474, 48.70078897476196, 58.284077984946116, 63.85088784354073, 65.01632308959961, 60.62047576904297, 53.90288094111851, 57.72042274475098, 63.682894298008506, 67.10383292606899, 63.280788149152485, 32.84743513379778, 3.5822653770446777, 0.3193041405507496, 0.49227297625371386, 0.8820470497012138, 3.5728800977979387, 2.9446891205651418, 0.5156626754573413, 0.4812227892024176, 0.12155793367752007, 0.1804483136428254, 0.09890798013657331, 0.06813885298158441, 1.289730919258935, 13.18368397440229, 46.39947959354946, 37.336027009146555, 35.22580698558262, 34.464030810764854, 16.961040871483938, 39.560729026794434, 50.56251014981951, 56.60858242852347, 65.6548000063215, 73.92261437007359, 16.394842590604508, 0.958212496978896, 0.12202180735766888, 0.17079603086624826, 0.09925967840743916, 0.003574511452045824, 0.025164879126740352, 0.07976527911211763, 0.013751992207419659, 0.09227020453129496, 0.04828896240464278, 0.04549084683614118, 0.033556467587394376, 0.09776430257729121, 0.05018991557881236, 0.048929869263832054, 0.04534958263060876, 0.08327169703053576, 0.08348736938621316, 0.052495221341294904, 0.0549707342205303, 0.030792431440204382, 0.033566767748977454, 0.016882283746131828, 0.15848986192473344, 0.020843576274013946, 0.028364779028509344, 0.020458433012078916, 0.029556113494826213, 0.03994970934997712, 0.12991213825132164, 0.09934849185603005, 0.10355402476021222, 0.18984666147402354, 0.12762869149446487, 0.12257680829082217, 0.11430005170404911, 0.09187154485178844, 0.12913312576711178, 0.13329684734344482, 0.1419824484203543, 0.12497502246073314, 0.2143694870173931, 0.20411245312009538, 0.1499995839382921, 0.16323154605925083, 0.12354866042733192, 0.10593071579933167, 0.09965149166860751, 0.2550988500671727, 0.10199757399303572, 0.18460451705115183, 0.21323473219360622, 0.143555753997394, 0.12082872566367898, 0.15746174566447735, 9.678165793418884, 77.34922272818429, 86.69264602661133, 85.42539882659912, 77.70533875056675, 62.609307289123535, 40.2440322467259, 30.515098571777344, 36.07048211778913, 52.58425528662545, 67.43330260685512, 53.75565556117466, 47.89769186292376, 37.38542522702898, 10.153978432927813, 0.456488342157432, 0.15744004611458096, 0.25990236231258934, 0.34028732031583786, 0.9332798634256635, 3.323525535208838, 4.0203349675451, 6.775382561343057, 8.944265791348048, 7.996142404420035, 5.6655976091112406, 6.4651424544198175, 20.662426165172032, 32.5279152733939, 41.631681306021555, 59.03396579197475, 67.60705620901925, 67.77201339176723, 64.4555617741176, 64.70696149553571, 63.065129961286274, 59.14785371507917, 58.31428527832031, 63.87945188794817, 62.9132353918893, 59.262756075177876, 53.304929392678396, 52.13833727155413, 64.3112963267735, 64.2141466140747, 62.54020050593785, 63.42623479025704, 66.85487897055489, 61.38178988865444, 57.76568331037249, 57.490555490766255, 61.442961829049246, 59.2987060546875, 62.11376176561628, 60.14424623761858, 63.18207509177071, 59.07944869995117, 63.81006022862026, 59.96139049530029, 60.87228543417794, 58.18574707848685, 59.31625025612967, 37.25038698741368, 32.20877061571394, 64.91170406341553, 60.192723819187705, 62.70750617980957, 53.76366336005074, 52.85830266135079, 52.46188013894217, 59.99136502402169, 62.15807737622942, 66.52087211608887, 65.75510420118059, 61.06215190887451, 56.371878147125244, 50.79180417742048, 48.981371130262104, 49.57022401264736, 54.78999219621931, 60.12945352281843, 61.296771730695454, 58.78468527112688, 56.56840099607195, 46.642378193991526, 49.71784543991089, 59.911036900111604, 64.6366526739938, 66.2382402420044, 60.5861725125994, 53.16455841064453, 57.42159114565168, 64.45726408277238, 68.89820521218437, 67.58333505902971, 35.93752833775112, 3.2730247250625064, 4.474786673273359, 6.103508259568896, 3.3834958715098242, 6.376916400023869, 3.22475710936955, 0.6494951854859079, 0.5458654090762138, 0.15360464049237116, 0.35786723984139307, 0.3078913443854877, 0.31151412427425385, 2.0741903569017137, 20.0167179107666, 58.70152923039028, 47.3033116885594, 45.691920212336946, 47.59641102382115, 24.095571041107178, 45.208141463143484, 58.222763606480186, 67.00676659175328, 72.73637621743339, 87.63564164297921, 19.381435428346904, 0.8996584532516343, 0.2363665880901473, 0.33056869038513725, 0.1735586861946753, 0.17605657715882572, 0.1262447243290288, 0.19702458488089697, 0.11668555012771062, 0.17138843264962944, 0.11502522921987943, 0.14830666620816502, 0.11767450134669032, 0.19395669735968113, 0.09870429070932524, 0.10010319921587195, 0.08968315406569413, 0.133936149467315, 0.17953864245542459, 0.19272040655570372, 0.10771514754742384, 0.13764948663966997, 0.1480769006801503, 0.07852090017071792, 0.22257897364241735, 0.15812190595482076, 0.18680203413324697, 0.13370890808956964, 0.14184610359370708, 0.1570784683738436, 0.20661726514143602], [0.025217431663934673, 0.05820342432707548, 0.05477441029090967, 0.024743876985407302, 0.05151802234883819, 0.023531260268230523, 0.020818882688347782, 0.015502118073137743, 0.061161904861884456, 0.024472194956615567, 0.03521931603817003, 0.01987726437593145, 0.05661288396056209, 0.06061315323625292, 0.02617320591317756, 0.03799746571374791, 0.022184995901105658, 0.024805655902517692, 0.030628151326839412, 0.012738090407635485, 0.016459826147183776, 0.061590684710868766, 0.017294883927596465, 0.0506305765759732, 0.7832368261047772, 31.00109727042062, 68.19497108459473, 69.66618265424455, 57.91963454655239, 42.760089601789204, 41.14894131251744, 19.750956262860978, 16.738790580204554, 30.126006398882183, 35.02305160249983, 30.05071919304984, 41.558739117213655, 22.548613684517996, 4.112574909414564, 0.07355920784175396, 0.09509361588529178, 0.03111101041681, 0.04402181512809225, 0.23928808846643992, 0.7092203806553568, 1.3205582307917731, 0.506987632385322, 2.0376282845224654, 3.9201858043670654, 2.625406584569386, 7.404393860271998, 19.496560130800518, 38.88643067223685, 46.470427649361746, 61.54557282584054, 61.694069726126536, 62.24058028629848, 57.94284152984619, 60.296578543526785, 60.29512637002127, 62.77328477587019, 58.712535176958355, 58.92930507659912, 57.036945819854736, 59.24622631072998, 51.590475286756245, 45.79541015625, 42.894061292920796, 54.4502009664263, 58.13426440102713, 60.61500058855329, 55.410351685115266, 61.09881060464041, 55.944087982177734, 56.7283867427281, 55.15593991960798, 59.81109401157924, 55.255115032196045, 57.46439899717058, 53.609913621629985, 59.26948193141392, 54.51177590233939, 59.75759288242885, 55.6896345274789, 60.56436906542097, 48.06386498042515, 58.826680183410645, 28.99217677116394, 31.004804134368896, 66.9668561390468, 53.77912310191563, 54.74618033000401, 43.97500991821289, 45.38534484590803, 41.05600915636335, 45.21702126094273, 46.193465505327495, 49.60624694824219, 47.33478702817644, 48.25087227140154, 44.81401532036917, 43.35640484946114, 41.35891934803554, 47.909566334315706, 53.23211921964373, 59.38528060913086, 58.54142883845738, 58.53646782466343, 52.93743569510323, 46.48872920445034, 44.96668808800833, 51.360392638615195, 52.9507588659014, 60.306215694972444, 56.448075566973, 57.11502620152065, 54.59232289450509, 59.51759515489851, 60.792353357587544, 59.016636984688894, 65.84668840680803, 54.90264681407383, 14.20562676021031, 0.6565664431878498, 1.1149556062051227, 0.9443341216870716, 2.8906911952154974, 0.9856522360018322, 0.006954090395343623, 0.24978944925325258, 0.02411977743862995, 0.01895870777246143, 0.07986386346497706, 0.05877573468855449, 0.5061486374054636, 10.870309046336583, 52.247111320495605, 43.902526310511995, 55.91058724267142, 36.95706530979702, 25.1895649092538, 41.436766965048655, 51.118213176727295, 55.99739456176758, 61.63908863067627, 36.56929676873343, 1.252751737833023, 0.12203566304274968, 0.019690344941669276, 0.04992700022246156, 0.02136921530057277, 0.026009154805381383, 0.0633293017745018, 0.03714892374617713, 0.05760959083480494, 0.0521047414014382, 0.021176757324220877, 0.023412133267681514, 0.049012168776243925, 0.05888541308896882, 0.034925300029239485, 0.024108902218618562, 0.09615297868315663, 0.02635916182771325, 0.05463896452316216, 0.04975580922993166, 0.07405461982956954, 0.023254986253700087, 0.07212757359125785, 0.038485613984188864, 0.042780727081532986, 0.025531466152252894, 0.042559171827243905, 0.03197193564847112, 0.03903833843235459, 0.004765334048508001, 0.0061350803922063536, 0.0981892351327198, 0.025837756859670793, 0.05054906416418297, 0.0826035300269723, 0.0433702077716589, 0.024966056491913538, 0.04690377048349806, 0.022184023899691444, 0.05159651188712035, 0.026213990956810967, 0.013815928865889353, 0.05446775995993188, 0.056292876667742214, 0.01309859351853707, 0.03460978463824306, 0.02103039562436087, 0.018149537799347724, 0.025992532393762043, 0.08355822879821062, 0.02475752741364496, 0.07728145417890378, 0.051292714795895984, 0.031157876830548048, 0.7889953085354396, 39.174332754952566, 78.40370219094413, 77.06273460388184, 67.12605326516288, 49.675787993839805, 50.09666122709002, 31.049665178571427, 20.075412818363734, 33.76789426803589, 37.978815283094136, 36.32517181124006, 40.55752454485212, 24.497592074530466, 5.1323424748012, 0.10513973395739283, 0.017562688128756623, 0.039921105706265995, 0.25503865044031826, 0.5760386128510747, 2.4793254860809872, 3.3573645651340485, 2.1145124903747012, 2.248485267162323, 0.5310295937316758, 2.1676012873649597, 8.403678570474897, 21.385836124420166, 40.11716856275286, 50.13382714135306, 61.003036635262625, 63.58620316641671, 65.07163769858224, 61.3903500693185, 61.89803409576416, 62.128658703395296, 63.714126450674875, 59.29258469172886, 58.73198318481445, 58.98553684779576, 60.299607958112446, 54.236783572605674, 46.976989541734966, 46.00450577054705, 57.33975178854806, 60.53184454781668, 61.79952253614153, 56.78615059171404, 63.031333923339844, 57.30522966384888, 59.35510458265032, 57.69914388656616, 60.40176732199532, 58.02708148956299, 59.40042073386056, 55.177149295806885, 60.94471345629011, 57.1430413382394, 60.70924595424107, 57.87617009026663, 60.57090732029506, 49.11847645895821, 58.63769612993513, 32.71917486190796, 33.06944397517613, 68.55388028281075, 56.328434535435264, 57.60651397705078, 47.201041153499055, 46.63734075001308, 41.685575008392334, 48.38851955958775, 49.06458970478603, 50.704708508082796, 49.47314725603376, 51.473860195704866, 47.208930832999094, 44.47114951269967, 43.369140897478374, 49.19942992074149, 53.73280988420759, 60.0054212297712, 60.75094209398542, 60.36397606985909, 55.21215432030814, 50.24297639301845, 47.91109841210501, 53.660628523145405, 55.77045597348894, 62.620806557791575, 59.6811557497297, 59.071235929216655, 57.18252100263323, 61.27188328334263, 63.48381451198033, 62.76355034964425, 69.68583910805839, 59.936773027692524, 16.91682253565107, 0.6649533531495503, 0.6500844252961022, 1.185131760580199, 3.3108808994293213, 1.8138113915920258, 1.0986495954649789, 0.642143937093871, 0.08114826918712684, 0.05039704517860498, 0.04534403560683131, 0.08442363236099482, 0.3810509086719581, 11.714278067861285, 38.642927578517366, 44.46142898287092, 40.5752910886492, 37.83675936290196, 41.268016065870015, 45.63965586253575, 59.46488612038748, 62.066514015197754, 67.79988956451416, 53.668052673339844, 4.125371754169464, 0.3404855068240847, 0.06991331026490245, 0.05458231024178011, 0.042795281657682996, 0.021616509084456732, 0.126828685136778, 0.024051107998405184, 0.05621330486610532, 0.07775904783712966, 0.05123606051451393, 0.04130405506917408, 0.029746659698763063, 0.02128582843579352, 0.04103827629504459, 0.07497937485043492, 0.02099085569248668, 0.03769511390211327, 0.04594513960182667, 0.024774037866986225, 0.05751186143606901, 0.07531819452664681, 0.07421721717608826, 0.057917150402707715, 0.017092985832797628, 0.010601292879852866, 0.05572413879313639, 0.05167518123718245, 0.026129399692373614, 0.020488310605287552, 0.06862017179706267, 0.17390468477138452, 0.17859208610441002, 0.15830926304416998, 0.20219118121479238, 0.18432414638144629, 0.10365588643721171, 0.12477283259587628, 0.09997619103108134, 0.13040370973093168, 0.14014268214149134, 0.19575575153742517, 0.20158889996153967, 0.2264108508825302, 0.1907830669411591, 0.12700340790408, 0.15488472394645214, 0.057375041634908745, 0.1159433006708111, 0.2270566669425794, 0.15191014856100082, 0.19075391707675798, 0.21876385621726513, 0.12964047997125558, 1.2943191187722343, 49.94603817803519, 88.29235063280377, 87.49758093697685, 76.17214230128697, 58.37025301797049, 56.359795229775564, 28.740450484412058, 23.654742581503733, 43.52617365973336, 47.78118794304984, 43.22022015707833, 56.39534221376692, 32.30911302566528, 6.4368641546794345, 0.26817392132111956, 0.1603469987000738, 0.1210384201258421, 0.24067072570323944, 0.5613004522664207, 3.3124029891831532, 6.117279589176178, 5.437777468136378, 8.511069927896772, 10.011039222989764, 6.660756392138345, 12.106615049498421, 23.381853818893433, 41.892461095537456, 50.87400484085083, 64.03338227953229, 65.45191955566406, 67.91818959372384, 62.946954999651226, 65.82498223440987, 64.70711435590471, 66.06705747331891, 59.48876013074602, 59.5080691746303, 61.02228314535958, 63.48054191044399, 56.92941549846104, 51.079761845724924, 47.57097019468035, 60.384904044015066, 63.832273619515554, 63.314514705113, 57.99695757457188, 66.05111830575126, 58.91120501926967, 62.48711626870291, 59.740993635995046, 63.438199588230674, 59.86193398066929, 60.82104941776821, 57.03100858415876, 62.680720874241416, 59.747448512486045, 62.168353761945454, 60.81478214263916, 62.911915234157014, 51.71702282769339, 57.67726748330252, 36.11965104511806, 37.592620509011404, 69.31855733054024, 60.04788167136056, 57.67809084483555, 50.40327828271048, 49.12923574447632, 45.157555103302, 50.228451183864046, 51.69859273093087, 53.10351848602295, 52.1433538709368, 53.97414861406599, 50.376037870134624, 46.343942642211914, 44.320894718170166, 50.64215040206909, 56.45055954796927, 63.677141189575195, 64.22492327008928, 62.73347854614258, 58.18819979258946, 51.87357269014631, 49.15894276755196, 57.11556468691145, 58.65392712184361, 65.01016698564801, 60.14881815229143, 59.142864908490864, 56.93092673165457, 64.13371426718575, 64.41791643415178, 65.66597270965576, 72.89587211608887, 65.73886626107353, 18.254967417035783, 2.8091128298214505, 5.711880428450448, 4.651283511093684, 8.46183933530535, 3.2039138163839067, 0.649624758533069, 0.5672417591725076, 0.36596911081245964, 0.1946596053561994, 0.1356166364359004, 0.25574986370546476, 0.7476053780743054, 17.78503816468375, 71.61735493796212, 58.09686919621059, 69.36622197287423, 54.36341101782662, 37.93221718924386, 54.832365785326274, 65.70409052712577, 72.23126997266496, 74.29295335497174, 61.660718372889924, 3.9175211702074324, 0.3158029541373253, 0.08447959792933293, 0.1598982156387397, 0.10819483787885734, 0.16228323908788816, 0.27228475787809914, 0.10751146490552596, 0.12272979079612664, 0.13790802205247538, 0.1593516149691173, 0.15263737525258744, 0.15955955881093228, 0.22270056711775915, 0.12435936049691268, 0.1754280908831528, 0.12289726680942945, 0.09987642602728945, 0.07733258857790913, 0.11083573009818792, 0.1016350666593228, 0.2278203581060682, 0.1287161795688527, 0.1234993716435773, 0.1855085699685982, 0.08613936243844883, 0.11846143911991801, 0.10493668235306229, 0.09669771338147776, 0.12869279725211008], [0.028855230925338607, 0.08147093972989491, 0.050194824779672284, 0.008503203230377818, 0.010648956572237824, 0.08765052099313055, 0.015350540135321873, 0.04339205999193447, 0.022298518202400634, 0.004660148398085896, 0.04191894011039819, 0.054723113043499846, 0.04206361734707441, 0.026820090665881122, 0.007988649769686162, 0.05789861282599824, 0.07745232965265002, 0.008678181296480554, 0.04643918094890458, 0.021808006933757236, 0.06997203747076647, 0.09050754697195121, 0.03319258622026869, 0.011129113396496644, 6.575641827923911, 45.787826197487966, 68.30273069654191, 65.76711068834577, 50.57324859074184, 37.4385963167463, 30.83679321834019, 17.67615815571376, 37.50164079666138, 29.55872767312186, 33.056655815669465, 42.25471585137503, 17.38500084195818, 1.714134271655764, 0.15671150306505816, 0.03766805731824466, 0.03474416171333619, 0.06303745707763092, 0.07519730672772441, 0.9515561227287564, 2.1531731358596256, 1.3203961423465183, 1.2823731026479175, 0.7088571744305747, 3.5771247957433974, 14.878717865262713, 33.89990656716483, 51.22918285642351, 54.89994396482195, 57.241737025124685, 61.88010079520089, 58.0299198286874, 59.72011429922921, 56.06554249354771, 55.84851898465838, 57.41421563284737, 61.81109128679548, 57.63906281335013, 56.54428727286202, 59.09209442138672, 55.811106409345356, 50.14295012610299, 43.56876611709595, 41.65179286684309, 51.01950706754412, 55.25504902430943, 59.0818875176566, 55.63865212031773, 58.16101149150303, 53.79199811390468, 56.92215463093349, 55.18444837842669, 57.66485800061907, 53.61870656694685, 58.33556066240583, 57.47954607009888, 59.856166975838796, 55.21482937676566, 60.04497732434954, 55.048916816711426, 59.572979245867046, 48.156171798706055, 62.09892736162458, 29.906335626329692, 29.341467925480433, 65.47945526668003, 50.75413451875959, 54.84849950245449, 48.073821749006, 49.22329003470284, 43.230308941432405, 43.27065365655081, 39.192940030779155, 43.07151828493391, 42.15938309260777, 44.0544729913984, 41.649322782244, 42.27697787966047, 45.56745365687779, 53.2462796483721, 58.78986862727574, 59.03001921517508, 58.27679279872349, 61.250816345214844, 53.093592984335764, 43.05410262516567, 41.400066580091206, 46.31859213965279, 56.02234901700701, 58.98360524858747, 61.214338302612305, 57.2798478943961, 54.09925440379551, 60.1936479296003, 63.90862042563302, 60.05225903647286, 59.58233846936907, 60.48816122327532, 63.15904181344168, 28.879803555352346, 2.191593417099544, 1.64313334439482, 3.7436772414616177, 0.8600184374621936, 0.7901546806097031, 0.33023539398397717, 0.16896261567515986, 0.0678632388423596, 0.17357149693582738, 0.03832615825480648, 0.14120093892727578, 0.36381495211805615, 19.43748654638018, 44.958141803741455, 43.20419413702828, 18.28869571004595, 9.626214981079102, 34.17175483703613, 36.72362320763724, 55.936583927699495, 54.682722432272776, 67.02041980198452, 33.658755438668386, 0.6660520913345473, 0.0357486242428422, 0.08828470017760992, 0.05470770690590143, 0.029765448333429437, 0.04675409244373441, 0.025478138388799768, 0.06483569022800241, 0.07727020406829459, 0.08165196608752012, 0.04455202578433922, 0.013101070171355136, 0.04386841532375131, 0.04058502508061273, 0.04744756541081837, 0.03672935840274606, 0.02837024293174701, 0.019094781185101186, 0.02511095255613327, 0.045520268114549775, 0.00292994750114823, 0.08677887490817479, 0.04143285119373884, 0.04110339190810919, 0.02943992455090795, 0.04375571065715381, 0.034251185666237555, 0.06233305630407163, 0.040063262185347934, 0.07591433503798076, 0.028343417049784745, 0.04347450538937535, 0.03887829237750598, 0.012829496708166386, 0.030538360787821666, 0.03709632031885641, 0.049253136917416535, 0.029417054528104405, 0.02197993074410728, 0.011494791185084199, 0.07564809825271368, 0.0457434586382338, 0.023206496444929923, 0.06326891894319228, 0.015021883217351777, 0.038892840168305805, 0.02903074079326221, 0.012620260257140865, 0.02194470968762679, 0.017023922842262045, 0.06585439520754985, 0.05117877519556454, 0.014792877648557936, 8.76369948046548, 60.81569930485317, 76.60614762987409, 75.01126507350376, 58.53723907470703, 48.0494578906468, 38.77486344746181, 20.17882112094334, 27.94583191190447, 22.683585916246685, 34.09803792408535, 38.401269231523784, 18.710110902786255, 1.4895657790558678, 0.029677001293748617, 0.0498312453606299, 0.049175675359687636, 0.22535500968141214, 0.7530967348388263, 2.1862248480319977, 3.52207921232496, 2.983864801270621, 2.090200743504933, 1.104619943669864, 3.081109400306429, 15.095539876392909, 35.19957058770316, 56.42293698447091, 58.44539083753313, 60.0527732031686, 63.68044853210449, 60.0583803994315, 60.41366263798305, 57.6036547933306, 58.070452145167756, 60.11275700160435, 63.55135795048305, 57.75231497628348, 56.97689948763166, 58.877728598458425, 58.7118820462908, 51.35579293114798, 45.057004247392925, 44.425194127219065, 54.43799645560128, 57.00143705095564, 61.39781938280378, 56.26301377160208, 59.41091251373291, 57.39036594118391, 59.28549058096749, 57.712668555123464, 59.498049872262136, 56.7868002482823, 59.499856403895784, 57.53072650091988, 60.505066190447124, 56.88051060267857, 62.487609590802876, 57.96167809622628, 61.528292655944824, 51.08513280323574, 62.453222955976216, 31.29914024897984, 31.600226538521902, 66.48688847678048, 53.220067569187705, 56.60988174165998, 50.64150421960013, 51.12676293509347, 45.009728704180034, 45.009746074676514, 40.92788437434605, 44.76003129141671, 44.28810964311872, 45.43126549039568, 42.597821371895925, 45.27767903464181, 45.9843282018389, 55.11227396556309, 60.8404974256243, 61.89207254137312, 59.98504911150251, 63.523259435381206, 54.70210443224226, 46.52248355320522, 43.90201561791556, 47.87160832541329, 58.21033327920096, 62.689948081970215, 60.54548386165074, 58.17082929611206, 56.06231852940151, 62.413722446986604, 67.28811304909843, 63.28615910666329, 60.883027349199565, 63.5749887738909, 68.35867759159633, 35.638446603502544, 3.5112932196685245, 1.191211542912892, 4.999977120331355, 1.369595359478678, 2.2333169153758456, 1.5462941293205534, 0.6988036738974708, 0.36201330593654085, 0.433484783662217, 0.013912423330891346, 0.08031752519309521, 0.3316471539437771, 20.341391597475322, 43.64785051345825, 39.25306626728603, 22.941494362694876, 13.253073028155736, 45.43820674078805, 44.30324976784842, 59.51765768868582, 61.9662515095302, 75.660692351205, 51.25288316181728, 1.1386732820953642, 0.05998189175235374, 0.028477785643190145, 0.02076606552249619, 0.007538047386333346, 0.03569881298712321, 0.032389428067420206, 0.04406512601833258, 0.06900279090872832, 0.08995678009731428, 0.023204043540837507, 0.037599698307790926, 0.031168512866965363, 0.016042379529348443, 0.04308516199567488, 0.04903911679450955, 0.04817976576409169, 0.04610816103273204, 0.012952326813579669, 0.0383322752479996, 0.08338386565446854, 0.02069880234609757, 0.035045248057161055, 0.0763812485550131, 0.014601303464067834, 0.0715344457754067, 0.06481244361826352, 0.0031135376609329668, 0.045915949025324414, 0.267733633518219, 0.10363402403891087, 0.15020359227699892, 0.12042260888431754, 0.09963762241282634, 0.16751525976828166, 0.10885347825075899, 0.12409617033387933, 0.14103997685015202, 0.10531588164823395, 0.1211557931133679, 0.14640763668077333, 0.1608676386198827, 0.15023325782801422, 0.19869456812739372, 0.1371765070195709, 0.08614833267139536, 0.1299589028848069, 0.11372928840241261, 0.10823915300092526, 0.14555602094956807, 0.23711161954062326, 0.11107551758842808, 0.1920048642371382, 13.609163863318306, 72.92246287209647, 84.85741833278111, 85.05727631705147, 68.09022004263741, 52.962932109832764, 43.44611998966762, 25.981678656169347, 50.70203692572457, 43.16664259774344, 43.02780369349888, 56.86687823704311, 25.109335797173635, 2.7654820510319302, 0.2939407458262784, 0.15156185653592857, 0.13452671920614584, 0.2571812740394047, 0.6526935824326107, 3.98414614370891, 7.8780560323170254, 6.3122647149222235, 5.506257610661643, 4.378382154873439, 8.571387239864894, 19.427651371274674, 39.11731236321585, 56.89957645961216, 59.95382390703474, 63.46536704472133, 65.87026364462716, 62.94155624934605, 63.800332750592915, 61.14268153054373, 60.96907384055001, 61.82461942945208, 65.99030767168317, 58.75070858001709, 57.18245152064732, 62.60540240151541, 61.288454736982075, 56.506534235818044, 49.02706248419625, 46.576922689165386, 56.36715337208339, 60.998416083199636, 61.64648846217564, 56.005871364048545, 60.18810326712472, 58.516651562282014, 61.21399784088135, 59.596269607543945, 61.36328683580671, 57.91298164640154, 60.811002322605674, 60.328213691711426, 61.65072686331612, 59.1874167578561, 64.10696370261056, 60.08299091884068, 63.46557549067906, 52.877146175929475, 61.457358496529714, 34.86829090118408, 34.079385484967915, 67.90383461543492, 56.70736149379185, 58.225608893803184, 53.3152300970895, 53.515654359545024, 47.79205839974539, 48.70172698157174, 43.955495902470176, 47.635341780526296, 46.319307804107666, 49.837903363364084, 45.14180701119559, 46.772608280181885, 48.743666308266775, 58.700591223580496, 63.150752612522666, 61.900945390973774, 61.38809190477644, 65.99770750318254, 57.79554666791643, 47.98906762259347, 45.98619726725987, 49.44393355505807, 61.76794992174421, 63.467562675476074, 61.886076245989116, 59.04484667096819, 55.904048987797324, 64.89967673165458, 68.79578876495361, 67.50854464939663, 63.45871761866978, 65.76388672419957, 72.17731721060616, 36.75975036621094, 3.870957383087703, 9.82819390296936, 13.196344460759844, 3.6005701891013553, 3.154816108090537, 1.2069652804306574, 0.5711836676512445, 0.3283976768808705, 0.6409063435026577, 0.21633953201983655, 0.22924796864390373, 0.6958498752542904, 29.83804873057774, 61.701330593654085, 57.61083228247506, 27.113451617104666, 15.997115543910436, 48.31712334496634, 50.759651388440815, 71.69126292637416, 70.86289174216134, 88.2316164289202, 53.59563854762486, 1.0597907091890062, 0.19277189379291876, 0.0956486032477447, 0.1512774010854108, 0.13540340002093995, 0.09913175420037337, 0.15596911790115492, 0.12104354985058308, 0.2237272991665772, 0.23129690012761525, 0.15243487326162203, 0.14229191467165947, 0.10426882069025721, 0.13329585668231758, 0.16781343519687653, 0.1547128917383296, 0.10911383892276458, 0.1036476625927857, 0.07589857945484774, 0.1410550538982664, 0.19817907150302613, 0.17496314511767455, 0.12985918537846633, 0.22610223958534853, 0.20126348813729628, 0.14351099782756396, 0.15733252545552595, 0.13802656212023326, 0.17657244019210339], [0.031040191716913666, 0.04902496255402054, 0.016015757207891772, 0.0361223850798394, 0.036597946525684426, 0.02837742183224431, 0.024502226916540946, 0.11037095396646432, 0.042818592728248665, 0.026114712801894972, 0.08536949660629034, 0.10865445035908904, 0.037782431180988035, 0.017705697865624512, 0.06585534515657596, 0.08786455129406281, 0.030955293415380374, 0.05250191169657877, 0.04405260365456343, 0.04237513955948608, 0.058914970074381144, 0.06554935300456625, 0.02304581765617643, 0.11814217482294355, 29.55950587136405, 65.03782776423863, 61.95553738730294, 56.5665979385376, 45.31562314714704, 18.832621540342057, 40.014126777648926, 49.18303912026541, 37.180335249219624, 53.14525631495884, 50.404799938201904, 21.21224406787327, 1.7155542011771883, 0.10252289580447332, 0.0821551608719996, 0.04673596877338631, 0.1797972321510315, 0.18883605141724857, 0.6718906408974102, 1.0955537387302943, 2.354882380792073, 2.421820891754968, 1.7055552005767822, 3.9761305281094144, 18.763382741383143, 46.66212150028774, 56.976642404283794, 62.7461381639753, 59.20446068899972, 61.10409123556954, 60.06353596278599, 59.11095183236258, 54.16361904144287, 54.54993540900094, 56.771851199013845, 58.97992270333426, 60.74521677834647, 55.45817961011614, 57.24685089928763, 56.715845244271414, 54.99495710645403, 46.47513157980782, 41.37794004167829, 43.826106548309326, 50.01453699384417, 54.70768730981009, 59.251520838056294, 56.017019748687744, 56.21601268223354, 54.73276335852486, 54.91775567190987, 55.371118681771414, 57.22894539151873, 55.83944811139788, 58.3834684916905, 55.68658079419817, 58.57694108145577, 54.32956634249006, 55.331288133348735, 53.184499740600586, 58.60145432608468, 53.31208256312779, 62.02931335994175, 30.418146882738384, 30.5408034324646, 63.23148373195103, 52.06748301642281, 56.295677253178184, 53.36708797727312, 56.25235176086426, 50.81908975328718, 52.859515122004915, 45.23462104797363, 43.30632223401751, 39.930637223379954, 43.117459774017334, 40.743135247911724, 42.571049962724956, 47.72374718529837, 56.05152450289045, 59.03558472224644, 54.941845076424734, 54.1582168170384, 58.30704525538853, 45.37150750841413, 43.72248111452375, 42.95813063212803, 48.87141241346087, 53.778483867645264, 59.782154764447895, 56.891627720424104, 59.34760052817208, 54.04143844332014, 59.77567209516253, 59.01162733350481, 57.040895870753694, 57.23924609592983, 63.51448386056082, 60.682412011282786, 64.8315565926688, 39.50655392238072, 2.9890333924974715, 2.6897336585181097, 1.0063705699784415, 2.984158362661089, 0.8739935447062764, 0.17815710444535526, 0.130945248529315, 0.050149139016866684, 0.1798199223620551, 0.04343529963599784, 0.02938359257365976, 0.5191525167652539, 28.239975214004517, 33.65809883390154, 38.77750376292637, 36.92321368626186, 18.21496316364833, 32.95359666006905, 46.04739005225045, 55.26350845609392, 54.6818573815482, 57.59609515326363, 22.89913640703474, 1.3551661223173141, 0.030146096300865923, 0.1462282184511423, 0.05074071638020022, 0.0829799473285675, 0.012956212274730206, 0.041020301902400594, 0.0086677530614127, 0.027730747425396527, 0.020324515644460917, 0.07059150601604156, 0.042136380049799166, 0.006129225483164191, 0.06679527222045831, 0.013052029901051095, 0.03931553695084793, 0.14045798379395688, 0.05599955954988088, 0.03449873898976615, 0.0533466674387455, 0.05207850245226707, 0.02648343551637871, 0.042815725917794874, 0.06718003550278288, 0.05263808349679623, 0.04512704350054264, 0.02072599294063236, 0.035197904865656576, 0.09570122363844089, 0.05340410542807408, 0.010626815974579325, 0.02392986905761063, 0.03022179366754634, 0.04311264266393014, 0.01588644539671285, 0.02137003972062043, 0.044210644638431926, 0.03857100083093558, 0.048671354207077196, 0.0771349041855761, 0.027603695135829703, 0.02199769309455795, 0.01199639989395759, 0.024629126535728574, 0.024168285907113125, 0.07836044020950794, 0.08536898770502635, 0.04205430106126836, 0.10708450353039162, 0.04701147095433303, 0.03886250286762204, 0.41908255219459534, 41.340277331215994, 76.90916551862443, 67.272458757673, 63.03304318019322, 54.94024004255022, 34.427844592503135, 45.625623975481304, 35.5878324508667, 35.36333268029349, 44.422689301627024, 41.6416380746024, 19.141032968248638, 1.2160698090280806, 0.00500794466851013, 0.10037772769906692, 0.023272714677399824, 0.31437447507466587, 0.8315288690584046, 1.278769376022475, 2.1115796991756985, 2.118033924273082, 2.819888834442411, 1.8157728463411331, 4.541896283626556, 21.232918432780675, 49.002431120191304, 61.99164717538016, 65.31688131604875, 62.256012235369, 63.064879826136995, 61.863564082554404, 61.7110024860927, 57.61058562142508, 56.94038322993687, 58.008727822984966, 61.250489779881065, 63.183270181928364, 55.98744126728603, 58.15089838845389, 59.98051193782261, 58.21457862854004, 48.928349426814485, 43.81577457700457, 45.49790218898228, 52.334439754486084, 57.740805285317556, 61.27523231506348, 56.475277764456614, 56.341247013636995, 55.873608929770334, 56.61113589150565, 56.21898651123047, 59.805820328848704, 58.620506286621094, 61.144203186035156, 57.60805647713797, 58.965623310634065, 56.28229849679129, 58.36843258993966, 54.1982592855181, 62.03005681719099, 54.053382396698, 65.2013188770839, 32.72852713721139, 32.31354945046561, 64.27205984933036, 55.188005856105256, 58.69604015350342, 54.844389642987935, 58.50799410683768, 53.474065916878835, 53.34810549872262, 47.809185709272114, 45.91855307987758, 42.55374200003487, 44.64962441580636, 43.305915764399934, 44.84692198889596, 50.662491253444124, 59.16416113717215, 60.461549622671946, 56.3897384916033, 57.98425279344831, 59.43135411398751, 48.881897245134624, 45.89369589941842, 46.42355162756783, 51.22314139774868, 57.24109084265572, 60.916538511003765, 58.2593423979623, 57.06314400264195, 56.00796972002302, 61.82930946350098, 62.409866196768625, 60.425703866141184, 58.895752225603374, 66.04629625592912, 63.53924724033901, 67.29803507668632, 45.036500113351, 4.324005986963, 1.2052905474390303, 0.6912394740751812, 1.1175133032458169, 3.1503254004887173, 1.2451926405940736, 0.5958017323698316, 0.14104030254696096, 0.22080961215708936, 0.06768219212868384, 0.024649485978963118, 0.6697363193546022, 28.79304313659668, 38.21119083677019, 27.043186221803936, 30.161629813058035, 31.17407614844186, 43.34561082295009, 53.18061569758824, 61.08365658351353, 58.999572208949495, 66.36537837982178, 39.583237716129844, 0.8699150064161846, 0.014381963626614638, 0.017740503319406083, 0.054512363459382734, 0.03816768300852605, 0.029684315901249647, 0.012242561372529184, 0.04481326176651886, 0.03515540821743863, 0.04966520784156663, 0.07538792757051331, 0.05109510164973991, 0.03741983563772269, 0.025331651159961308, 0.03135749165500913, 0.04799768767718758, 0.08587814002696957, 0.05867174919694662, 0.036467962964837036, 0.0297338896697121, 0.01100747412004109, 0.0707126720143216, 0.01938525354489684, 0.053938584069588354, 0.020435479868735586, 0.07920382531093699, 0.006755299566845808, 0.055361166662935696, 0.15666568838059902, 0.17222638268555912, 0.09546077118388244, 0.09974373171904258, 0.08780338814748184, 0.0863183531910181, 0.12287988274225167, 0.10146033032132046, 0.11382004924650703, 0.1415234873337405, 0.172557195648551, 0.2958516632871968, 0.09857325202652387, 0.12247794573860508, 0.15098668954202107, 0.12907409322048935, 0.1258424480578729, 0.15149911918810435, 0.16358869975166662, 0.14133873581886292, 0.1659583475972925, 0.1716104085956301, 0.15187425405851432, 0.7980492998446737, 55.307045868464876, 86.89515127454484, 79.99962697710309, 72.74147619519914, 62.079805919102256, 30.761992386409215, 50.54407657895769, 60.79050513676235, 53.18303714479719, 68.9375945499965, 66.18483638763428, 28.03245336668832, 2.728950377021517, 0.20077483435826643, 0.20425601755934103, 0.1666172593832016, 0.46605460026434486, 0.675739617219993, 3.1852064430713654, 3.709039168698447, 8.082879373005458, 9.199074472699847, 5.881748250552586, 7.012285300663539, 22.52870535850525, 52.17733056204659, 61.950347082955496, 67.70538711547852, 63.99377754756382, 63.685013498578755, 65.00162070138114, 64.18081610543388, 59.204425948006765, 60.36400386265346, 61.26467105320522, 63.82847990308489, 64.80193642207554, 57.32278776168823, 59.43706553322928, 63.89418206896101, 60.67739541190011, 51.577707971845356, 46.456896032605854, 49.39532743181501, 54.76347439629691, 60.152368681771414, 63.09819643838065, 56.49237380708967, 56.358638354710166, 58.25670903069632, 58.787089347839355, 60.38206917898995, 61.27935259682791, 62.28087288992745, 62.65705530984061, 59.29122979300362, 60.9971376146589, 59.275728361947195, 59.95978546142578, 58.688355445861816, 63.16307176862444, 57.45400101797921, 65.18486554282052, 36.79536683218819, 35.90888091496059, 63.879034996032715, 58.03635038648333, 59.2768748147147, 58.32237992967878, 60.9710054397583, 54.99352577754429, 57.019870621817454, 51.24933958053589, 47.34240920203072, 44.19991268430437, 47.61952073233468, 45.407773630959646, 46.799939019339426, 52.57236691883632, 61.54915114811489, 62.11863940102713, 58.25902625492641, 60.85463006155831, 61.63308538709368, 50.12917879649571, 47.61619601930891, 48.8568559374128, 54.23305933816092, 60.78156280517578, 64.99998092651367, 58.47733865465437, 58.21165343693325, 57.0968462399074, 63.12177167619978, 64.3012283870152, 62.487317766462056, 62.660911560058594, 70.16621671404157, 65.2866427557809, 70.79435471126011, 48.19743367603847, 4.8753954853330335, 10.611819556781224, 9.11789606298719, 8.207783664975848, 4.460733073098319, 0.6739837314401353, 0.5454249041421073, 0.1338936188923461, 0.5042464051927839, 0.11568222753703594, 0.1884771335337843, 1.5906681482281004, 39.05748837334769, 48.592417921338765, 55.61728640965053, 52.68472971235003, 28.387520211083547, 48.72854355403355, 59.00032956259591, 72.59239564623151, 65.80810506003243, 77.81385571616036, 40.885722705296104, 1.4591298465217863, 0.1098515082682882, 0.1825498723025833, 0.16461995084370884, 0.15673712454736233, 0.12763770243951253, 0.19850267842411995, 0.13789012229868344, 0.2005048045622451, 0.1077022689527699, 0.21158792770334653, 0.16433910519949027, 0.08094795886427164, 0.13606299034186772, 0.08426723003919635, 0.11964759975671768, 0.24336640962532588, 0.16374717839062214, 0.10583858431449958, 0.1726227014192513, 0.07321985212287732, 0.1316981916981084, 0.11593078848506723, 0.218712111136743, 0.1148518906640155, 0.18199633700507029, 0.06885256325559956, 0.15346902848354407], [0.04733988529603396, 0.07211405038833618, 0.018919792092804397, 0.044643685687333345, 0.028914422927690402, 0.01633012417836913, 0.020966589583882263, 0.04270542665783848, 0.009345996310003102, 0.015035956033638545, 0.05759633904589074, 0.0323462087794074, 0.03889614463384662, 0.04062596109828778, 0.05266778636723757, 0.027539965430540696, 0.06042412695075784, 0.06470055997903858, 0.0438654094136187, 0.07232217064925603, 0.00810697949158826, 0.03159182033102427, 0.12764992964054855, 10.919045448303223, 61.09258501870291, 61.12918812888009, 62.139053208487375, 46.53804404394967, 39.89087268284389, 15.200160639626638, 27.36567643710545, 46.53569902692522, 33.22078963688442, 35.94012348992484, 25.28403435434614, 1.4408330683197295, 0.060878107590334754, 0.056553573214582036, 0.015649207501805255, 0.020363663722361838, 0.1810808168458087, 0.4899507580058915, 1.3106308834893363, 1.30430682854993, 1.9969150977475303, 2.2107721822602406, 8.313754984310695, 30.350943905966624, 56.611101150512695, 63.397719383239746, 62.15329701559884, 58.55107293810163, 62.24745205470494, 58.56152302878243, 56.85769271850586, 51.908126081739155, 49.43529347011021, 51.67545175552368, 56.77625288282122, 57.08957495008196, 57.20085382461548, 57.69421761376517, 59.03593213217599, 53.76810325895037, 52.485156604221885, 42.56150313786098, 41.945017269679475, 42.73112951006208, 50.477721282414024, 53.24845096043178, 58.09556640897478, 55.403104713984895, 55.343628134046284, 54.37758534295218, 57.015333448137554, 57.216928482055664, 56.92793205806187, 54.96558359691075, 55.44589172090803, 53.145763533455984, 53.73652022225516, 49.25501898356846, 53.160813331604004, 49.74630526133946, 58.39072241101946, 49.922317028045654, 64.73059926714215, 39.06865412848336, 33.589697292872835, 60.08761147090367, 51.3686123575483, 57.22947692871094, 53.32678842544556, 57.51673977715628, 55.41153287887573, 55.834299496241975, 52.36531407492501, 52.107678345271516, 48.359830447605674, 46.29866818019322, 44.10035194669451, 45.064998149871826, 50.135331426348, 56.364297662462505, 57.311830452510286, 50.95335326875959, 54.73724494661604, 55.493017877851216, 42.699900831495015, 40.942562443869456, 43.68941116333008, 52.05994074685233, 55.1625337600708, 58.89978912898472, 56.13227646691458, 54.845786230904714, 58.473440715244834, 60.324746540614534, 60.466065951756065, 59.06882490430559, 52.652521337781636, 54.30081122262137, 61.196981702532085, 59.11307103293282, 63.047266142708914, 45.81704684666225, 9.98187415940421, 0.8617242202162743, 0.6844395218150956, 3.73215799672263, 1.5103508808783122, 1.4121824971267154, 0.4064413362315723, 0.07744680637759821, 0.19203991735620157, 0.04181525656687362, 0.03700091829523444, 4.153201026575906, 39.499039445604595, 44.56871959141323, 29.480820996420725, 13.545943072863988, 17.746334961482457, 33.79045854296003, 42.076647417885916, 56.483261244637625, 56.36648287091936, 59.33104297092983, 18.684923682894024, 1.0118412992783954, 0.10959259966122252, 0.16055631318262645, 0.06712634981210742, 0.02030676177569798, 0.03512375795149377, 0.0428758576911475, 0.05980952350156648, 0.019832319912633727, 0.02507521750937615, 0.026845842766176378, 0.06504045852593013, 0.053580745056803734, 0.0783271716375436, 0.0242929277010262, 0.04597105624686394, 0.03705564553716353, 0.09228462340044123, 0.05618623810421143, 0.06572890015585081, 0.10918106138706207, 0.018685536359303763, 0.08407488571746008, 0.024156740633770823, 0.04687703281108822, 0.02652125875465572, 0.03186978220141359, 0.029863975010812283, 0.020536946299086725, 0.05160386042137231, 0.0290900345758668, 0.009347369495247091, 0.05794845800846815, 0.03146910048755152, 0.019683803864089505, 0.012249243246125323, 0.03160674810143454, 0.08964061670537506, 0.019545554050377438, 0.04326643941125699, 0.06736286676355771, 0.09886878795389618, 0.031519566529563496, 0.026695350484390343, 0.036730094613241296, 0.046269506482141357, 0.015269719829250659, 0.04777601707194533, 0.025442352451916252, 0.11225908622145653, 14.071074894496373, 73.82958493913922, 69.6529324395316, 69.9529834474836, 57.340248584747314, 47.0406037739345, 21.92213109561375, 34.35538182939802, 43.1519193649292, 38.973449911390034, 44.76369994027274, 24.77519518988473, 1.474207654595375, 0.02386862618316497, 0.035494085401296616, 0.08972558286041021, 0.12049357007656779, 0.8240901710731643, 2.760493895837239, 3.8620897446359908, 2.2050106057098935, 1.0043559180838721, 1.2692337334156036, 9.177473391805377, 33.41764947346279, 59.274012156895225, 65.07035228184291, 64.41750649043492, 61.47199140276228, 61.52912643977574, 60.260475703648154, 59.095047405787874, 54.83410283497402, 49.62508004052298, 55.341679164341514, 59.111445154462544, 59.9013580594744, 59.29494707924979, 56.72453396660941, 58.47335038866316, 56.24246447426932, 55.33250754220145, 45.574860436575754, 44.437120710100444, 43.901035921914236, 51.94831793648856, 56.92589276177542, 59.50561646052769, 56.9103878566197, 56.21210432052612, 56.63508285794939, 58.29493454524449, 58.978213446480886, 58.520382744925364, 56.24932582037789, 58.38123117174421, 54.84234687260219, 56.28808287211827, 53.52408947263445, 55.982779026031494, 51.916561194828574, 59.966143063136506, 54.22163997377668, 64.49513871329171, 38.288079602377756, 35.49360792977469, 59.96470478602818, 53.66185140609741, 59.89178344181606, 55.857968534742085, 59.40003858293806, 56.37496314729963, 58.05324840545654, 54.19553211757115, 54.24584402356829, 50.57159144537789, 47.7093574660165, 44.921354566301616, 47.82520825522286, 51.417093413216726, 59.649263518197195, 57.86994103022984, 53.39803177969796, 57.28650426864624, 56.64711018971035, 44.44233185904366, 42.78294570105416, 46.04651457922799, 54.81557893753052, 58.446106501988, 60.74215957096645, 55.48870652062552, 54.0079550743103, 58.769142150878906, 61.616625104631694, 62.4415499823434, 61.649580410548616, 53.170203821999685, 55.96426207678658, 63.55806991032192, 61.226052965436665, 65.29556424277169, 50.61761631284441, 10.676712257521492, 0.5730420393603188, 1.5044632596629006, 2.9163113747324263, 2.9829209319182803, 1.9996238095419747, 0.8890343861920493, 0.6205790628279958, 0.195278619283012, 0.03716170734592846, 0.09003935102373362, 4.615563690662384, 40.33105843407767, 41.484983989170615, 30.948082515171595, 18.633626869746617, 25.405289105006627, 43.87870788574219, 46.52392183031355, 64.40165070125035, 63.43938773018973, 70.83034637996128, 34.01596927642822, 0.7559161835483142, 0.04353992634319833, 0.11790057564420359, 0.05708048279796328, 0.057419078557619026, 0.03978247082393084, 0.0212175864726305, 0.020785459749666706, 0.013959053105541637, 0.01223572004320366, 0.026530949931059564, 0.03779421733426196, 0.0770730014358248, 0.05352921032213739, 0.022557630369971906, 0.11014501537595477, 0.018141931421788673, 0.0857846921842013, 0.03790133426498089, 0.049460717742996554, 0.07520169684929506, 0.03234984233443226, 0.08366342208215169, 0.018237333445410644, 0.02090703965430813, 0.028792588572416986, 0.019371830425890427, 0.25120688176580835, 0.1528576412903411, 0.13332184457353183, 0.09013264280344759, 0.06806225316332919, 0.2535921223461628, 0.10862874066723244, 0.13162672838994435, 0.07718441688588687, 0.13899001399321215, 0.13858452146606787, 0.09480797978384153, 0.07716365371431623, 0.12671071503843578, 0.27883270223225864, 0.0774242722296289, 0.08244527530457292, 0.11116036160715989, 0.12237759040934698, 0.19588035770824977, 0.10994214019072907, 0.1727362067571708, 0.1970297960298402, 17.582904645374843, 85.7608995437622, 78.88151591164726, 82.58778926304409, 64.87687969207764, 53.07100439071655, 24.03438867841448, 34.037724086216514, 57.25874274117606, 44.27447380338396, 50.015151909419465, 36.368031774248394, 2.0154085968221938, 0.15134689664202078, 0.19736549444496632, 0.27668532888804165, 0.2343070986015456, 0.5119585256491388, 3.0755738573414937, 6.563676161425454, 6.949472716876438, 7.606906056404114, 6.86536260162081, 12.607568877083914, 36.2761800629752, 59.78760215214321, 67.68689101082938, 67.01095635550362, 64.18209457397461, 64.88998399462018, 63.21543339320591, 61.70618738446917, 57.637412616184776, 53.310519218444824, 56.61697237832205, 60.46296010698591, 61.67955493927002, 61.301857812064036, 57.32821083068848, 61.15430586678641, 58.472627776009695, 57.17084108080183, 47.36104774475098, 46.79693044934954, 46.43957417351859, 54.035139901297434, 60.05374595097133, 59.834752627781455, 57.791422912052695, 57.20607539585659, 59.04142120906285, 60.013057300022666, 61.25101784297398, 60.31435898372105, 58.92949962615967, 59.13527052743094, 57.1250524520874, 57.971888474055696, 55.88260337284633, 58.11406946182251, 55.88755396434239, 62.907107080732075, 56.14158010482788, 65.96490505763462, 41.70441852297102, 39.681217738560264, 60.51174340929304, 56.907167366572786, 60.65546689714704, 58.06251382827759, 61.95204244341169, 60.152257510593955, 58.728397914341514, 57.187259674072266, 57.93648392813546, 52.92846209662301, 50.96399790900094, 46.97339037486485, 50.84070559910366, 53.881789684295654, 62.1267340523856, 59.84022780827114, 55.60630478177752, 59.52012429918562, 59.63654831477574, 46.74326603753226, 45.24146154948643, 47.82200860977173, 57.93492405755179, 60.59278719765799, 61.72398866925921, 56.2719144139971, 55.80152136938912, 60.451919419424875, 64.66866302490234, 66.65602847508022, 65.29113824026925, 56.15344067982265, 58.874761717660085, 67.4099427631923, 64.37518501281738, 69.16316086905343, 54.26026848384312, 13.590597408158438, 4.5828845756394525, 8.79546924999782, 10.42488261631557, 4.036050055708204, 3.865946429116385, 1.590537543807711, 0.5628326386213303, 0.34579661754625185, 0.23916652213249887, 0.22547751239367894, 7.297170996665955, 55.78375482559204, 61.20764718736921, 42.966194016592844, 22.561924695968628, 26.47154402732849, 49.443985666547505, 57.032450335366384, 73.51651995522636, 70.04870183127267, 83.56924315861293, 34.9599723815918, 1.3055111467838287, 0.23065259041530745, 0.23888465868575232, 0.10896808960075889, 0.13216887786984444, 0.1444056462496519, 0.2009156575160367, 0.1408471914806536, 0.096936557708042, 0.12462134286761284, 0.19198418248976978, 0.12747648251908167, 0.1416267603635788, 0.20046957502407686, 0.11343613413295575, 0.16789652859526022, 0.08352767436632089, 0.15308984954442295, 0.12249252067080565, 0.12117477852318968, 0.17772034502455167, 0.05508075528112905, 0.23397434502840042, 0.09839145892432757, 0.16057030457471097, 0.15188802831939288, 0.06415195084576096], [0.05965170304157904, 0.08304960573358194, 0.06406023326729025, 0.02148673078045249, 0.02365237707272172, 0.035949572388614924, 0.03753636724182537, 0.019213200812893252, 0.03565231298229524, 0.0471361415859844, 0.03560720397425549, 0.03189697109961084, 0.07999735844454595, 0.06099556878741298, 0.04277929197996855, 0.029006985282259326, 0.03436303537871156, 0.03038629430479237, 0.03456314214106117, 0.038533650870834074, 0.07627032843551465, 0.08850443017269884, 0.45985783849443707, 33.18632657187325, 70.32758862631661, 67.55811309814453, 64.38375908987862, 53.916169370923726, 35.782545294080464, 29.86318036488124, 24.139666046415055, 28.022911752973283, 40.593818460192, 34.2899888583592, 3.4242461877209798, 0.046379351123635254, 0.08624287974089384, 0.08341276446091277, 0.053112426972282786, 0.10887215831982237, 0.74398444380079, 2.302348788295473, 0.5208816411239761, 1.4802515017134803, 0.5830730125308037, 11.245109643254962, 36.40496492385864, 59.00119808741978, 61.873805727277485, 57.37879719052996, 57.36494595663888, 56.338203702654155, 57.30149500710623, 55.69198301860264, 52.02181945528303, 46.1367438861302, 51.07161160877773, 54.18447405951363, 58.115076950618196, 59.78895010266985, 57.71643795285906, 54.95386545998709, 60.05464226858956, 54.4346786907741, 48.925528458186555, 40.90884978430611, 42.362902777535574, 43.94056074959891, 50.35903215408325, 54.797954831804546, 58.51178087506975, 52.61305556978498, 55.399192878178184, 55.67537334987095, 55.79684523173741, 52.43793664659773, 51.490084239414756, 49.97868428911482, 53.23539529527937, 50.84314789090838, 50.32823773792812, 48.170071669987266, 50.660820211683, 44.41588354110718, 53.247200284685405, 50.94265651702881, 59.68160738263811, 28.575012138911656, 30.34017072405134, 58.428756850106375, 51.08593184607369, 55.974889346531455, 48.91962596348354, 53.64293493543352, 52.617318289620535, 58.76518862588065, 55.01968574523926, 57.278128215244834, 51.81470060348511, 50.94190263748169, 48.07999174935477, 51.53210694449288, 53.74220037460327, 56.68231323787144, 54.4133859361921, 48.435440744672505, 53.409649167742046, 49.74044792992728, 42.02312544413975, 41.18242468152727, 47.80807747159685, 55.17045818056379, 57.77462216785976, 58.54848820822579, 52.08796283176967, 54.34087800979614, 60.01368958609444, 57.90066596439907, 57.37145641871861, 53.909641538347515, 50.41730669566563, 50.90155097416469, 53.000834533146445, 60.054218428475515, 62.839876311165945, 61.208515712193076, 49.59690856933594, 10.307053327560425, 0.6801773448075566, 2.4762016194207326, 3.2974454717976704, 0.7218507400580815, 1.0743974511112486, 0.30383454635739326, 0.14382609591952392, 0.013975365087389946, 0.13424219590212616, 0.12252461537718773, 11.953527995518275, 39.294710295540945, 41.41779143469674, 36.438496930258616, 19.91125294140407, 25.550124304635183, 45.365118639809744, 49.156476157052175, 54.23740891047886, 52.934618200574604, 57.49644408907209, 15.68393417767116, 1.0746563800743647, 0.13469545729458332, 0.09084927756339312, 0.06462839099445514, 0.0784126263377922, 0.03759455840502467, 0.027104274702391455, 0.04935177894575255, 0.014872685241113816, 0.07814576530030795, 0.031868723686784506, 0.026971987515155758, 0.02045857041542019, 0.007252081347230289, 0.04425386731911983, 0.038586525712162256, 0.050677802613271136, 0.027833869481193166, 0.01602801324666611, 0.031112811927284514, 0.0398812417739204, 0.0694902776075261, 0.02759468079810696, 0.0357963659667543, 0.07539793596203838, 0.055641852851424894, 0.03476381887282644, 0.05535355689270156, 0.021319339584027017, 0.01990623103587755, 0.05171153035813144, 0.030761340965649912, 0.0016621691736093322, 0.026537848935861672, 0.07597850409469434, 0.033088549838534424, 0.031491648206221204, 0.031078165929232324, 0.012247309421322175, 0.034855332890791554, 0.0468442086795611, 0.06042567401060036, 0.04549867034490619, 0.007858254846983721, 0.03170317471293466, 0.016122731646256785, 0.051924396971506734, 0.0601768484339118, 0.46577900648117065, 43.16623960222517, 78.82101099831718, 74.33716474260602, 74.16913645608085, 59.71695981706892, 45.39163643973214, 25.584523098809377, 25.1828407900674, 22.79455212184361, 33.3575301851545, 34.71674721581595, 3.666102341243199, 0.008620087672690195, 0.08947751724294253, 0.03965692488210542, 0.1609763399298702, 0.6640740803309849, 3.7669619577271596, 4.453247257641383, 2.288492343255452, 1.3023721895047595, 0.768522712801184, 11.89886564867837, 40.553341729300364, 60.946492195129395, 63.43048013959612, 60.898924827575684, 58.827333314078196, 59.32571370261056, 58.22544213703701, 57.91338464191982, 54.59451505116054, 48.56034503664289, 53.36939477920532, 58.24424396242414, 60.14644881657192, 61.91006142752511, 56.96346861975533, 56.466790539877756, 61.559788840157644, 56.66880941390991, 51.618841307503835, 44.16228124073574, 43.79865074157715, 47.853331089019775, 52.909691538129536, 57.192585468292236, 59.413059507097515, 52.2900789805821, 55.883134910038535, 57.5689937046596, 57.06660073144095, 54.8326541355678, 53.65644918169294, 52.225398199898855, 54.502993379320415, 52.76809072494507, 52.28683417184012, 51.04663978304182, 51.59463725771223, 46.49938079289028, 55.733286585126606, 52.71035814285278, 62.85853917258126, 33.620012283325195, 30.795857906341553, 60.077654702322825, 52.35081665856497, 55.95546218327114, 50.420502867017476, 54.9377178464617, 53.83029311043875, 60.29678004128592, 58.44954586029053, 59.791576521737234, 53.25374548775809, 52.523437704358784, 49.90655851364136, 52.165560313633506, 55.581228733062744, 57.42896318435669, 53.90358618327549, 49.42260953358242, 57.167175906045095, 52.24327938897269, 43.15982641492571, 45.26518269947597, 51.85635157993862, 57.93516724450247, 59.92811557224819, 57.68164484841483, 51.4602313041687, 54.77169411523001, 61.46787806919643, 60.48626436505999, 60.81387192862374, 56.34442581449236, 53.50008692060198, 52.81634596415928, 57.086236340659006, 62.340578760419575, 64.35698073250907, 65.38618264879499, 55.08148649760655, 13.564341034208026, 0.2649936819715159, 1.3246436629976546, 4.907486609050205, 2.2549062711851935, 2.570653476885387, 1.208011310015406, 0.8018699405448777, 0.1494258554386241, 0.06796752967472587, 0.0723788622500641, 13.571605375834874, 40.0584944997515, 33.47839757374355, 26.23067777497428, 20.187773874827794, 37.235955578940256, 56.28446980885097, 56.12683950151716, 61.527389390128, 57.86100217274257, 65.37554495675224, 28.635939155306133, 1.0463847028357642, 0.05880410423768418, 0.02303215704991349, 0.04386567743495107, 0.062430873912359984, 0.06737767239766461, 0.02868734100567443, 0.10306389177484171, 0.08146524003573827, 0.014427822415849991, 0.02237521980090865, 0.052184727109436474, 0.03594174548717482, 0.023171020937817435, 0.0355713026864188, 0.021010190547843064, 0.06833299542112009, 0.031862494735313315, 0.04177849693223834, 0.04725138736622674, 0.08900035784712859, 0.06766309136790888, 0.0796489714245711, 0.04854784726298281, 0.038093295214431624, 0.04372261171894414, 0.12163870648613997, 0.21814789569803647, 0.1102611127176455, 0.15386160170393332, 0.15598743834665843, 0.09733755154801266, 0.1388208552130631, 0.11076366967920746, 0.16139419536505425, 0.12297581402318818, 0.10800454951822758, 0.14104157819279603, 0.11665564030408859, 0.14000069190348896, 0.16156077571213245, 0.13250563479959965, 0.16952955882464135, 0.1430905368179083, 0.1999121449355568, 0.10148533433675766, 0.16809680499136448, 0.16098905567611965, 0.674840965441295, 53.002807821546284, 88.79057121276855, 83.50541700635637, 82.36764948708671, 70.27575506482805, 48.22747073854719, 40.368401527404785, 34.427872385297505, 37.773961544036865, 53.665447098868235, 48.20213065828596, 5.351235917636326, 0.20098165183195046, 0.421287438166993, 0.18187118800623076, 0.3860389824424471, 0.4434850327670574, 3.695392038140978, 6.0408437592642645, 4.857759654521942, 5.747062632015773, 3.6785157322883606, 14.908423151288714, 43.45044871738979, 62.25310788835798, 64.83419690813336, 63.37522111620222, 61.6731903893607, 62.772416251046316, 61.476389612470356, 59.455019678388325, 56.78515699931553, 50.94187484468733, 57.29832662854876, 59.57383387429373, 62.16892351422991, 63.76557786124093, 58.44466822487967, 57.93920414788382, 62.81728771754673, 59.48919786725725, 54.09020437513079, 45.54428836277553, 46.75768007550921, 50.18387848990304, 55.29099900381905, 60.11968435559954, 61.79090676988874, 52.67594371523176, 59.078594071524485, 59.95778438023159, 60.39769567762102, 56.8596625328064, 56.999067715236116, 53.200303418295725, 58.19400501251221, 55.33073575156075, 54.463951451437815, 52.86702612468174, 55.78269869940621, 48.455138887677876, 57.62387752532959, 55.45509808404105, 64.7386383329119, 38.86689581189837, 33.84830577032906, 60.305110931396484, 53.39924424035208, 57.187207562582834, 51.84013101032802, 55.35348415374756, 54.98880100250244, 61.991070474897114, 58.851985522678916, 62.80280072348458, 58.4351144518171, 55.08626338413784, 53.448263781411306, 55.59322132383074, 58.99925259181431, 61.898089681352886, 56.24507352284023, 51.644327299935476, 58.78201021466936, 54.46851989201137, 45.89221245901925, 46.5303384917123, 53.27113682883126, 59.578614234924316, 63.52940164293562, 59.309962136404856, 50.605408327920095, 54.90116684777396, 63.45154012952532, 63.42228126525879, 63.82717364174979, 59.260386739458355, 55.47461209978376, 55.19745193208967, 57.89767129080636, 65.59586538587297, 68.32707023620605, 67.62310654776437, 55.2569146156311, 13.246070981025696, 3.187827433858599, 8.868803143501282, 9.157225472586495, 3.6933979051453725, 2.7284049434321265, 1.0008911554302489, 0.7633115095751626, 0.2040768436023167, 0.2536504492163658, 0.38554351617183, 18.982516765594482, 53.91936901637486, 54.496621881212505, 48.44182613917759, 32.13040883200509, 37.102129799979075, 61.27042416163853, 61.08642891475132, 70.78427287510463, 65.27986131395612, 78.12345354897636, 28.26482023511614, 1.3957938679627009, 0.17549359665385314, 0.19611536152660847, 0.15430734492838383, 0.21022616220372065, 0.1586425865867308, 0.10866171068378858, 0.18840953787522657, 0.0945334377299462, 0.17812414121414932, 0.1944929707263197, 0.1206314212509564, 0.09486323289041008, 0.19574888476303645, 0.1287830559802907, 0.17840231343039445, 0.11097457193370376, 0.0748698389423745, 0.15247550393853868, 0.13872781449130603, 0.17020016855427197, 0.18182172280337128, 0.12367956340312958, 0.10390747365142618, 0.14009427545326097, 0.14855068097157137], [0.04607723340658205, 0.027134405049894537, 0.03175229386293462, 0.059475901403597424, 0.040056117211601565, 0.02166242215649358, 0.0957070386835507, 0.011871001533498722, 0.03879218289096441, 0.03767433715984225, 0.018404634735946144, 0.048240165558776686, 0.07265909042741571, 0.038345248837556155, 0.05886040907353163, 0.042792883036392074, 0.028055472232933556, 0.05206495550061975, 0.03391989433605756, 0.04244786833545991, 0.023576844250783324, 0.07410368469676801, 4.069836974143982, 48.48156983511788, 57.24585383278983, 54.234108516148154, 53.54060186658587, 49.13835525512695, 24.022641011646815, 25.391832181385585, 38.7680298941476, 54.29595095770699, 71.06662682124546, 12.969919170652117, 0.20441550043012413, 0.04689855254920466, 0.09337311570665666, 0.06422740393983466, 0.048454100864806345, 0.46074313670396805, 1.9070012824875968, 3.2651094240801672, 2.6984933827604567, 0.8200521820357868, 13.373291628701345, 40.8313877923148, 58.26679086685181, 64.2274454661778, 59.42545509338379, 60.242966243198936, 54.35954434531075, 54.17476742608206, 50.42816325596401, 50.867338044302805, 43.571156297411235, 48.43814359392439, 55.52702236175537, 58.0998569216047, 58.107322760990684, 57.72323676518032, 52.004973547799246, 58.14487777437483, 54.466317313058035, 53.95051084245954, 44.66856173106602, 40.826332977839876, 41.035515444619314, 47.54149941035679, 52.15586410249983, 55.591793469020296, 56.218288217272075, 53.52859885351998, 58.52266870226179, 53.89596400942121, 50.20801305770874, 47.96245949608939, 46.96854748044695, 47.344837597438264, 51.39087438583374, 50.291822229112896, 50.72463941574097, 46.32184737069266, 47.50671672821045, 43.76943356650216, 51.515184606824604, 52.24545070103237, 56.787276199885774, 29.488460540771484, 26.90143081120082, 57.617175987788606, 48.831286566598074, 56.58558736528669, 49.92439801352364, 54.06404440743582, 48.769159248897004, 53.50798007420131, 51.41663135801043, 53.91399458476475, 56.50708314350673, 57.180655411311555, 52.80520452771868, 55.94491829190935, 56.28303847994123, 56.63566998073033, 52.40811150414603, 52.93681035723005, 53.684217657361714, 48.606189250946045, 38.146982533591135, 43.487427030290874, 51.72737564359392, 57.74921260561262, 57.15616995947701, 54.78577811377389, 51.62556021554129, 56.57905953271048, 57.01813357216971, 58.65098108564104, 54.10799176352364, 51.75374753134591, 48.941606589726035, 49.656812463487896, 50.79879059110369, 54.72232716424124, 57.2024484361921, 59.66557788848877, 60.498069354466026, 58.90538937704903, 12.210139734404427, 0.7981403321027756, 4.131209543773106, 1.3823699482849665, 0.2287570892700127, 0.973916728581701, 0.26673662130321774, 0.1300334467419556, 0.08071744016238622, 0.06333677244505712, 0.9333575963973999, 26.29786859239851, 46.37763098308018, 47.10483986990792, 24.375001532690867, 16.200946160725184, 22.69235975401742, 40.92383704866682, 45.377785205841064, 57.97372279848371, 53.80231966291155, 57.65969548906599, 6.805006206035614, 0.9820245163781303, 0.03182347557906594, 0.1423582618257829, 0.050554292276501656, 0.037669794367892404, 0.04427392142159598, 0.08066378839846168, 0.055857185939592977, 0.027450554871133397, 0.02264464570076338, 0.019287368083106618, 0.008645541217577244, 0.02801912141564701, 0.08825478356863771, 0.044179547378527265, 0.06378873105027846, 0.03719355777970382, 0.028910595990185226, 0.04232712642156652, 0.021210969059861133, 0.05306865467822977, 0.02332513659660305, 0.00899685187531369, 0.021909658264900957, 0.04431882008377995, 0.01363026472141168, 0.04703591178570475, 0.03798782712380801, 0.06487737941954817, 0.018993492870192443, 0.026052133213462572, 0.03499134184260454, 0.03000240633264184, 0.012694172228553464, 0.041642986703664064, 0.03250663820654154, 0.012795332469977438, 0.034881280069904666, 0.013458709016309252, 0.04694544949701854, 0.0882531279431922, 0.05300568323582411, 0.03824923273974231, 0.03180643756474767, 0.03638072032481432, 0.12040945887565613, 0.07160244176962546, 6.46743449143001, 60.75260966164725, 66.1331695829119, 63.31098502022879, 60.443984576633994, 58.66462734767369, 31.67528792790004, 26.978196246283396, 36.01587275096348, 57.215198380606516, 59.72590214865548, 14.17014752115522, 0.2913930911038603, 0.07981120914752994, 0.05856175867042371, 0.06401918868401221, 0.3737428422485079, 2.2867657159055983, 4.598460699830737, 2.726011506148747, 2.191605576447078, 1.0543301850557327, 15.148731810706002, 45.710235663822715, 61.091904095241, 68.12774726322719, 62.44430841718401, 61.787828717912944, 56.51543835231236, 55.262438433510916, 53.43778242383684, 52.21635511943272, 45.475893769945415, 50.459791455950054, 57.735941546303884, 59.259136063711985, 60.50349589756557, 58.25133112498692, 53.09169960021973, 58.71002687726702, 57.733179637363975, 55.6173072542463, 48.11396149226597, 42.836401666913716, 44.282881123679026, 49.194232668195454, 54.25117676598685, 58.576378277369905, 56.75541523524693, 54.14530011585781, 60.48647975921631, 55.00194699423653, 53.1383706501552, 50.584449086870464, 49.488499300820486, 48.18571901321411, 52.73843928745815, 52.32764789036342, 53.9124242918832, 48.933091572352815, 49.94922392708914, 45.87704801559448, 52.94703810555594, 54.266309942517964, 60.81107875279018, 33.21858010973249, 28.762856687818253, 59.040219170706614, 48.440936769757954, 56.45113277435303, 50.07289143971035, 53.85505301611764, 48.257761410304475, 53.54965884344918, 50.64131661823818, 56.44117947987148, 58.44892747061593, 59.258767809186665, 55.422399861471995, 57.81627661841256, 58.715641021728516, 57.26525320325579, 52.148787362234934, 56.52711132594517, 56.84348712648664, 51.38643796103341, 39.866967405591694, 45.773419107709614, 54.80774136951992, 60.1773613521031, 56.71328830718994, 55.28791400364467, 50.65212801524571, 58.24771111352103, 59.00053106035505, 60.64018086024693, 55.98337657111031, 54.30849593026297, 51.41460248402187, 52.68224573135376, 52.068480082920615, 57.17804636274065, 58.96937533787319, 62.23461178370884, 61.39615181514195, 63.06815937587193, 15.843553406851631, 0.41816433146595955, 0.8379535643117768, 1.4681195127112525, 2.4698976491178786, 2.7696670378957475, 1.120859295129776, 0.5745122347559247, 0.10877596919557878, 0.042161282284983566, 0.7659271263650486, 29.281980923243932, 42.74058253424508, 39.70008904593331, 26.061822652816772, 20.79439503805978, 36.43246589388166, 49.82078300203596, 51.33109555925642, 66.74836308615548, 59.793042591639924, 69.67544460296631, 14.76631338255746, 1.277261182665825, 0.004743279115895608, 0.12666476464697293, 0.01804207990478192, 0.0753787944891623, 0.04563555460689323, 0.06750397490603582, 0.04106187235031809, 0.06145942211151123, 0.018611762639401213, 0.07472807262092829, 0.03030045283958316, 0.059911134120609076, 0.04821974165471537, 0.006609590956941247, 0.02352031889105482, 0.06544264658753361, 0.015234145934560468, 0.037329719401896, 0.08844032218413693, 0.0613025516005499, 0.008816726272925735, 0.02102814119176141, 0.035129172660942586, 0.014728932508400508, 0.0898628979921341, 0.08940287160554103, 0.14751948416233063, 0.16906098968216351, 0.07210302419428315, 0.14160021607364925, 0.23185424879193306, 0.09773978710706745, 0.09934194399310009, 0.10052189603447914, 0.14878991884844645, 0.12883888584162506, 0.17486910016408988, 0.0841959227940866, 0.14261370311890328, 0.19353772912706646, 0.17097943888178893, 0.22265784655298504, 0.15533157996833324, 0.14030025154352188, 0.17130334435829095, 0.20785998845739023, 8.82207042830331, 74.25283445630754, 73.52098069872174, 74.50328922271729, 70.25763416290283, 62.96047619410923, 33.39770466940743, 36.79271609442574, 52.36535576411656, 64.2692597252982, 90.21651526859829, 19.751460007258824, 0.4531465843319893, 0.26871873065829277, 0.30567416335855213, 0.12464559370917933, 0.47153808602264946, 1.7847305749143874, 8.388477649007525, 10.457825762884957, 8.659175992012024, 3.663804224559239, 16.342010225568497, 48.18776525769915, 63.05946717943464, 70.28568404061454, 62.81044374193464, 64.62247834886823, 61.254915782383506, 56.833429609026226, 54.44043527330671, 55.153198855263845, 46.630722590855186, 53.50588171822684, 61.95281369345528, 63.08381366729736, 61.25457532065255, 57.13512734004429, 55.17188603537423, 60.66331836155483, 59.55294758932931, 58.546167509896414, 49.06544780731201, 45.77632345472063, 46.53855126244681, 51.8605135508946, 56.67992305755615, 60.30685492924282, 58.20218651635306, 55.5412140573774, 61.46115916115897, 58.38018199375698, 55.35425887789045, 52.61112397057669, 52.08905717304775, 51.52351549693516, 54.92617688860212, 56.31212363924299, 55.72326380865914, 50.01446056365967, 52.56409856251308, 47.66778639384678, 56.320419788360596, 58.33128752027239, 61.46447345188686, 36.627713748386924, 32.23067133767264, 59.533173016139436, 49.690014430454795, 58.3242837360927, 52.013214111328125, 56.01777710233416, 49.207396030426025, 53.62292412349156, 50.60278538295201, 57.82513209751674, 61.78526483263288, 63.0790958404541, 56.53591121946062, 61.608196939740864, 61.4938017981393, 57.01712955747332, 53.492975439344136, 57.3712340763637, 59.82062694004604, 53.202043942042756, 42.486059597560335, 48.27869633265904, 57.51331778935024, 63.065498215811594, 59.93523052760533, 55.55990818568638, 50.246460914611816, 61.06388895852225, 61.27744879041399, 64.31857803889683, 58.42481027330671, 56.31418725422451, 53.583159582955496, 55.30737590789795, 54.90416152136666, 60.820034980773926, 62.42939758300781, 65.8178881236485, 63.21038205283028, 69.29806014469692, 14.74201032093593, 4.432531637804849, 11.088615366390773, 7.850832121712821, 3.8934682437351773, 3.0481343354497636, 1.22655431500503, 0.6106274511132921, 0.3970431105366775, 0.17054189236036368, 1.495008715561458, 38.84763887950352, 60.55149405343192, 63.75036130632673, 35.058275495256694, 25.38646122387477, 34.727867807660786, 56.47204337801252, 57.533825397491455, 75.72526890890938, 65.1688985824585, 80.44789000919887, 15.016099384852819, 1.7571523061820438, 0.16552324380193437, 0.28217779844999313, 0.10578580107539892, 0.1927878800779581, 0.2316584235855511, 0.13306549404348644, 0.14287940386150563, 0.14673148787447385, 0.1266114046531064, 0.14594986981579236, 0.06655393767037562, 0.17863771079906396, 0.22300654569906847, 0.11432275548577309, 0.10782849682228905, 0.14876306243240833, 0.07034750482333557, 0.18790394786213124, 0.1347805591566222, 0.153962852699416, 0.11733460958514895, 0.08012915030121803, 0.183663009000676, 0.13228216607655796], [0.06031324075801032, 0.03536239532487733, 0.05349724114473377, 0.004263479794774736, 0.05720591678151062, 0.027351709282291786, 0.04900229948439768, 0.031950378590928655, 0.07668102532625198, 0.035657568236014674, 0.05612794855343444, 0.015494325098448565, 0.008177329154152955, 0.014863368955307772, 0.031502467447093556, 0.05011779069900513, 0.023046713322401047, 0.0067100654539119986, 0.04241479653865099, 0.037655877614659924, 0.06483916432729789, 0.18611836938985757, 19.857399191175187, 65.91077859061105, 62.3570807320731, 55.46459974561419, 41.73350715637207, 25.57568151610238, 18.601342064993723, 31.252361501966202, 37.5116913659232, 29.65885121481759, 26.542071717126028, 0.6513193590300423, 0.086427251276161, 0.010670673933678439, 0.055753349725689204, 0.09363935927727393, 0.15495065040886402, 1.8843330017157962, 4.667399423463004, 3.1250057305608476, 0.8960418616022382, 14.284973451069423, 43.64056880133492, 55.62697914668492, 62.98305089133126, 61.2460846219744, 60.927739007132395, 53.39583962304251, 49.609700202941895, 49.955296652657644, 47.16648776190621, 44.96890803745815, 47.229358536856516, 55.15457459858486, 55.977154459272114, 59.739451135907856, 57.959214959825786, 53.05853237424578, 58.404945373535156, 57.81131560461861, 53.725156443459646, 50.48293243135725, 44.41835362570626, 38.14263643537249, 42.573596477508545, 48.92447233200073, 53.20896087374006, 56.12529352733067, 53.99172060830252, 55.78179195949009, 56.511345863342285, 51.87017502103533, 47.05296114512852, 42.17890058244978, 43.007775511060444, 44.76883813313076, 52.13692331314087, 47.101139954158235, 50.928075722285676, 44.238537720271516, 46.778531619480674, 40.54690074920654, 50.872962611062185, 49.510201999119346, 61.54883847917829, 38.39553696768624, 28.791604859488352, 54.76536430631365, 48.20727232524327, 54.56907074792044, 49.96910967145647, 51.955863680158345, 50.204156807490754, 47.71259880065918, 51.79489128930228, 52.02793039594378, 51.58978394099644, 54.614188875470845, 54.032173020499094, 55.87287242071969, 53.13709912981306, 49.69959599631173, 55.05002852848598, 56.559802600315635, 50.31087418964931, 42.91536794389997, 38.89663062776838, 44.87093843732561, 53.588579177856445, 56.17973266329084, 56.706267152513774, 49.87551743643624, 53.32162938799177, 58.18490287235805, 55.76773575374058, 54.13973460878645, 50.805012702941895, 49.044929776872905, 51.71242312022618, 52.76750707626343, 51.44023091452462, 52.4336530821664, 53.41481862749372, 56.68988677433559, 59.475016593933105, 59.6986791065761, 64.1860272543771, 18.890343700136455, 2.9392573663166592, 1.3807737082242966, 3.0242763928004672, 1.8718642422131129, 1.0628132841416766, 0.2854021968586104, 0.09117643322263445, 0.10548640428377049, 0.02013911952131561, 5.420344872134073, 35.724097047533306, 34.817906039101736, 27.219267470496042, 28.129676035472325, 22.310858488082886, 35.84006248201643, 46.91708564758301, 44.07837132045201, 51.333371094294954, 52.54400437218802, 52.41361447743007, 2.955360685076032, 0.24586482984679087, 0.03517649708581822, 0.043878915653164895, 0.008384327287785709, 0.023490626198638762, 0.0215205370914191, 0.026681437123832957, 0.03184299703155245, 0.03320353777546968, 0.016225568717345595, 0.03140813411612596, 0.06288455599652869, 0.022856944041060548, 0.03673678496852517, 0.009693782826486443, 0.005225058487017772, 0.0325586682717715, 0.05006086839629071, 0.06288883755249636, 0.014874805663047093, 0.0275949369450765, 0.07703262860221521, 0.028524343323494707, 0.04317982102345143, 0.024282685214919702, 0.030464146020156995, 0.03504103435469525, 0.0206257156429014, 0.017117653973400593, 0.02885071188211441, 0.0064735149997951725, 0.03064785259110587, 0.03827205187241946, 0.049440049566328526, 0.03264640963503292, 0.0591358875057527, 0.033201671804168394, 0.0152892531561, 0.01546115321772439, 0.029174776814345802, 0.058494013734161854, 0.02259474793182952, 0.03628495528495737, 0.03702626497085605, 0.05885731495384659, 0.12504944418157848, 27.0535147190094, 78.84849112374442, 68.59290136609758, 65.21973160334996, 49.56317506517683, 37.01379040309361, 25.282196555818828, 35.94678333827427, 40.369575772966655, 35.80344894954136, 31.569574560437882, 0.8324320805924279, 0.1277209993984018, 0.0841170498835189, 0.19486545931015695, 0.39014919474720955, 1.8471041194030215, 4.46979786668505, 2.2982871319566454, 2.4690979548863004, 0.8036157297236579, 17.06908709662301, 47.23356914520264, 58.17435550689697, 64.11307116917202, 61.98769365038191, 62.4838228225708, 57.0375885282244, 52.73258890424456, 51.171797684260774, 49.6500483921596, 47.38430683953421, 48.33347593035017, 56.694271087646484, 59.16039521353585, 59.48898942129952, 56.4823579788208, 55.71687841415405, 59.548987116132466, 58.536134311131065, 58.02432305472237, 53.26309428896223, 45.67420230593, 41.14607170649937, 45.02193668910435, 51.38004214423043, 55.88381583350045, 57.88194751739502, 53.77188655308315, 55.03066389901297, 58.75386306217739, 54.5915446962629, 49.46130405153547, 44.97075973238264, 43.928846086774556, 47.629140513283865, 54.6748640196664, 50.365660735539024, 51.965268066951204, 45.96421316691807, 47.86648750305176, 43.851693289620535, 52.911334787096294, 51.379962239946636, 63.68855013166155, 40.731490067073274, 31.418353966304235, 57.07552916663033, 49.02100018092564, 55.0132725579398, 50.11154079437256, 53.51036330631801, 51.23410218102591, 49.36102417537144, 50.830582073756624, 52.00466087886265, 51.83823067801339, 55.96252850123814, 55.058606079646516, 58.04915591648647, 54.78860950469971, 49.71316582815987, 55.81728335789272, 58.860441480364116, 53.442997046879356, 45.56079728262765, 40.86242886951992, 48.252129895346506, 56.469093867710654, 60.63936097281319, 56.197725023542134, 49.42152908870152, 53.01472398212978, 61.00135517120361, 58.88661534445626, 57.49246277127947, 51.71035255704607, 51.52416167940412, 53.618355682918, 55.25977379935128, 54.0882693018232, 54.937453814915244, 54.20050355366298, 58.20801258087158, 62.862110546657014, 61.732243129185264, 65.94839613778251, 23.970468725476945, 1.3076891899108887, 0.4160730322556836, 2.922730641705649, 2.738101588828223, 3.322270082575934, 1.0278647137539727, 0.3170645407267979, 0.1719372724848134, 0.05035760533064604, 5.888125394071851, 38.41691657475063, 32.33825724465506, 25.09515973499843, 21.25697830745152, 28.142660481589182, 45.45587600980486, 55.72409759249006, 49.02135453905378, 57.42232070650373, 57.26234538214547, 65.26784787859235, 6.478060892650059, 0.3560021642063345, 0.07288717997393437, 0.03363523532503417, 0.03028749282072697, 0.059954682498105934, 0.038278087441410334, 0.021318873091201698, 0.024088586880160228, 0.0569001926508333, 0.02827014883847109, 0.013284478186895805, 0.030549034143665006, 0.04228975949808955, 0.07409449054726533, 0.013901096885092556, 0.02655681229329535, 0.050233569129237106, 0.0661862124023693, 0.07003250172627823, 0.04550163893561278, 0.007405844167806208, 0.023320100170427134, 0.0490983291529119, 0.05519575000341449, 0.15313292294740677, 0.06566004242215838, 0.10022935244653906, 0.09622139536908694, 0.14586166026336805, 0.0934619020138468, 0.09093782638332673, 0.1279902420938015, 0.09579974013779845, 0.12238494572894913, 0.1428486526544605, 0.145060554678951, 0.10093750551875148, 0.10706677341035434, 0.1063082730397582, 0.16405952163040638, 0.11232185749603169, 0.09989860055169889, 0.22587547318211623, 0.1303836250943797, 0.16394982965929167, 0.1947608563516821, 35.74267653056553, 90.10877650124687, 77.21462917327881, 73.76493195125035, 56.87885693141392, 38.2322473526001, 27.733392477035522, 42.91595506668091, 45.79165118081229, 43.48660019465855, 37.07193987710135, 1.608558673943792, 0.2248379388558013, 0.21907333603927068, 0.21073249860533647, 0.4826403302805764, 1.32465951357569, 6.302540276731763, 11.549811601638794, 10.424181716782705, 4.658818398203168, 18.089450904301234, 50.14390550340925, 59.823510442461284, 65.60375159127372, 63.26288958958217, 65.36526162283761, 59.1602840423584, 54.27461998803275, 54.621144022260395, 50.47724185671125, 49.15534012658255, 52.03595903941563, 58.54208196912493, 61.48710373469761, 61.69276346479143, 57.75041116986956, 57.33660078048706, 59.02993583679199, 59.21527208600725, 59.78917939322335, 54.51795285088675, 48.643893650599885, 43.33679008483887, 47.0870246887207, 53.355203083583284, 58.30865028926304, 58.46056570325579, 54.43354960850307, 57.14196784155709, 62.289050919669016, 56.60017510822841, 50.750910554613384, 48.27907500948225, 46.932260513305664, 51.284417561122346, 58.06831210000174, 51.78194679532732, 55.22559561048235, 49.007809025900706, 51.25005871909005, 46.321037905556814, 56.67820337840489, 53.599602494921, 65.4208402633667, 42.99659585952759, 35.83774873188564, 58.34432234082903, 49.890004430498394, 56.13947132655552, 53.514469691685264, 55.47098166601998, 52.78898048400879, 51.0206743649074, 52.08276210512434, 51.589780466897146, 53.08552265167236, 56.880927494594026, 57.43423686708723, 58.935704367501394, 56.15025840486799, 49.7308281489781, 59.12306949070522, 61.79820932660784, 54.793831075940815, 46.922470501491, 42.84688997268677, 49.623523644038606, 60.677986008780344, 61.61165714263916, 59.05111394609724, 48.567626748766216, 53.85734592165266, 64.44625118800572, 61.54116766793387, 59.64155796595982, 56.39701672962734, 54.385728631700786, 57.15659032549177, 57.881641796657014, 57.233649321964805, 57.72567210878645, 58.69834000723702, 61.48779855455671, 66.34088597978864, 63.86231763022286, 71.70736885070801, 23.563476255961827, 6.872127107211521, 8.692644596099854, 9.97400619302477, 6.221306281430381, 3.2323354227202277, 1.2841244829552514, 0.38226809192981037, 0.3215786713574614, 0.10348345711827278, 9.091888087136404, 50.81599085671561, 46.041230474199565, 39.20652028492519, 41.52662106922695, 33.553983552115305, 46.873245988573345, 62.29948016575405, 57.90541853223528, 68.21511391230992, 64.93942042759487, 73.98267459869385, 6.317205318382808, 0.4484846144914627, 0.08266218937933445, 0.24276085783328327, 0.10433229085590158, 0.1520902453256505, 0.1062623430043459, 0.10285800389413323, 0.11708249311361994, 0.15540505174015248, 0.0691949859527605, 0.08458059786685876, 0.1399666837283543, 0.17013068656836236, 0.10549206326582602, 0.1446541936269828, 0.13677965902856418, 0.18375097428049358, 0.12551189293818815, 0.17237899878195354, 0.13329897794340337, 0.11711853689381055, 0.12813483790627547, 0.16450967533247812, 0.0976940267054098], [0.04140668688341975, 0.015583752621231335, 0.04319599051294582, 0.016808739031798074, 0.06736028154513665, 0.04122828306364162, 0.030597220308014324, 0.011542142751360578, 0.014938414928370287, 0.03623430943116546, 0.03473095742187329, 0.03684824452336345, 0.052108327459011755, 0.0584369625097939, 0.01031581623413201, 0.01915523865526276, 0.05778912441538913, 0.09078047411250216, 0.038787127805075476, 0.0880779776988285, 0.09307897077607256, 1.4330621595893587, 41.551905563899446, 67.08934593200684, 58.81406920296805, 52.634709630693706, 34.47141327176775, 20.304939610617502, 20.438334601266043, 32.21489545277187, 35.11653961454119, 50.55453709193638, 9.545059153011866, 0.055471859473202906, 0.09171146487018891, 0.10610122486416783, 0.05907000854079213, 0.2918286020202296, 0.5556647575327328, 3.5202661667551314, 1.3641528572354997, 1.2968020141124725, 11.189009019306727, 42.39782789775303, 59.736859457833425, 62.978993143354145, 61.76205090114048, 64.61341789790562, 58.7852133342198, 55.64103882653372, 51.09378678458077, 47.23212391989571, 44.683976309640066, 43.07155302592686, 49.386840207236155, 56.14412314551217, 58.33179473876953, 60.397028650556294, 51.0107592855181, 52.484576429639546, 56.92745263235909, 49.79626628330776, 58.19032941545759, 53.54349231719971, 50.07044914790562, 39.114237785339355, 41.18434238433838, 48.442823205675396, 56.55974006652832, 53.13921138218471, 49.362299169812886, 53.95916134970528, 56.43760115759713, 48.73562029429844, 43.53691210065569, 38.65863398143223, 41.23962920052664, 47.11948667253767, 50.921645164489746, 49.070738860539024, 49.032881600516184, 43.08575166974749, 44.087744440351216, 39.71396459851946, 48.07669135502407, 49.784273692539756, 57.67501974105835, 36.972549370356965, 25.05603963988168, 54.11684029442923, 48.43606260844639, 51.087436131068635, 47.95433357783726, 50.67778423854283, 50.329700333731516, 50.04263898304531, 47.72002642495291, 51.07307767868042, 49.0788300377982, 52.724216324942454, 51.42530965805054, 52.407930850982666, 46.567685059138704, 52.30704648154122, 53.05687175478254, 54.8956812449864, 46.5911352293832, 41.70433514458792, 39.03430918284825, 45.465534005846294, 54.53526428767613, 57.345247813633506, 55.11929164613996, 49.442345891680034, 53.39576666695731, 55.05287381580898, 54.86027322496687, 51.372871603284565, 47.980733258383616, 48.92017139707293, 50.715408733912874, 51.70047221864973, 53.82692323412214, 54.517202445438926, 51.619880063193186, 52.66571249280657, 53.682414599827354, 57.74901805605207, 59.1966370173863, 60.986604145595, 22.533357177461895, 0.2496276322220053, 2.129009689603533, 3.651840729372842, 2.7251421128000533, 0.43094223152313915, 0.11662643615688596, 0.0657502468675375, 0.11411783791014127, 0.4196117552263396, 16.58105778694153, 34.59391348702567, 43.72150141852242, 31.166318484715053, 19.82789019175938, 21.513076748166764, 34.53943961007254, 38.506197452545166, 50.938470227377756, 52.47955635615757, 55.26942137309483, 32.820479597364155, 0.3083148588027273, 0.028551674714045863, 0.015926467088450278, 0.0051400567088941375, 0.13272917137614318, 0.035463347764951844, 0.06553270854055882, 0.03636306823630418, 0.061499611740665774, 0.014677326527557202, 0.02694438471059714, 0.043456161195146184, 0.01939673605374992, 0.03316746685387833, 0.01972736750862428, 0.012148077067519938, 0.05521242839417287, 0.007926562119142284, 0.036465605055647235, 0.04484149221596973, 0.06033963577023574, 0.0997506934883339, 0.014870856589238559, 0.02689311121191297, 0.03146281046792865, 0.02909052312108023, 0.06182339508086443, 0.04229680947693331, 0.045068082200097184, 0.059401839306311946, 0.05316547823271581, 0.008850820113106497, 0.012452416138590446, 0.03784608455108745, 0.042234187480062246, 0.03185248634378825, 0.08018766037587609, 0.024889120798824087, 0.019642494652154188, 0.02895503324855651, 0.05529919945235763, 0.05164438931803618, 0.012369401619902678, 0.0806556459782379, 0.13758803850838117, 1.4397990895169122, 53.961214542388916, 76.29586887359619, 64.78328745705741, 60.14476040431431, 40.93750415529524, 25.724131516047887, 25.053727626800537, 31.679498536246165, 37.01351942334856, 45.991870471409385, 9.593577555247716, 0.03681911162233778, 0.15553846529551915, 0.15635149952556404, 0.23677710177642958, 1.5615198037454059, 3.3447822460106442, 4.417720683983394, 1.4486937608037675, 1.6458163261413574, 15.559940099716187, 45.27905477796282, 62.926631518772666, 63.361658232552664, 62.63661370958601, 65.22202450888497, 61.79850809914725, 57.37889446531023, 52.03931154523577, 49.726117270333425, 46.20439849581037, 44.939162799290244, 52.23368392671858, 57.78452335085188, 60.2652074268886, 60.091057777404785, 55.46642017364502, 55.040631089891704, 56.33856153488159, 52.00223248345511, 60.40932696206229, 56.41408150536673, 51.34968546458653, 40.549013001578196, 42.29050254821777, 51.67269679478237, 59.0185546875, 54.56835855756487, 49.78055988039289, 53.20928396497454, 58.3531812940325, 52.65205928257534, 46.0769476890564, 40.79568794795445, 44.11408853530884, 49.643642153058735, 52.982922077178955, 51.566875730242046, 50.97290897369385, 44.99064200265067, 46.345109939575195, 41.62721014022827, 50.54631042480469, 52.05231162479946, 59.60505213056292, 39.05659900392805, 29.398349353245326, 54.87890134538923, 47.762698786599294, 53.46785422733852, 49.07258013316563, 53.29694243839809, 51.739486353737966, 51.59444618225098, 49.80478824887957, 50.40673501150948, 49.58505841663906, 54.41534185409546, 50.96553693498884, 52.268230370112825, 46.25831651687622, 53.771719796316965, 55.18378482546125, 57.1332791192191, 50.6837284224374, 43.909901823316304, 41.096940994262695, 47.283248765128, 55.754336152757915, 56.991858959198, 55.219158104487825, 49.77408068520682, 55.84122685023716, 57.94349466051374, 56.617788791656494, 54.202605383736746, 50.335873808179585, 51.8760393006461, 52.0624212537493, 53.63696643284389, 57.13972357341221, 57.46176215580532, 53.17588744844709, 56.979432106018066, 54.08580616542271, 59.26629270826067, 60.92044339861189, 63.424129486083984, 27.64946171215602, 0.9224880082266671, 1.2254128562552589, 2.2454623665128435, 4.226712099143437, 2.493860249008451, 0.6486546705876077, 0.2250043699251754, 0.03418370535863297, 0.24563540358628544, 18.903849261147634, 37.948517663138254, 44.438989775521414, 34.71791103907994, 19.670548234667095, 34.663027218409944, 47.58957052230835, 47.83474118368966, 56.216797828674316, 59.77691582271031, 62.95734255654471, 46.81394311359951, 0.13453673438302108, 0.036521896320794306, 0.044627991172352006, 0.06150989833154848, 0.06471303145268134, 0.03376929348866854, 0.016499211712341224, 0.0075695339557049525, 0.07821282491620098, 0.016812231790806566, 0.03535627154633403, 0.037438474994684966, 0.030877143144607544, 0.038471266361219544, 0.0364609536980944, 0.015662545803934336, 0.04709239304065704, 0.06646828619497162, 0.015108599992735046, 0.009051987934591514, 0.041432861371764114, 0.021412858672972237, 0.0670102863971676, 0.06937196824167456, 0.08631060432110514, 0.12467280296342713, 0.08418508658983878, 0.10731798064495836, 0.13690896066171782, 0.12092479265161923, 0.1441804404769625, 0.10040653829595872, 0.16489075416965143, 0.15893180535307952, 0.07116020657122135, 0.10244559030979872, 0.12595429777034692, 0.20894542735602173, 0.08617476839572191, 0.1036343090236187, 0.1021255049854517, 0.23635508013623102, 0.13175887987017632, 0.16061810058142456, 0.25528723852975027, 2.4447412618568967, 65.59448964255196, 86.29948220934186, 74.31591715131486, 69.65680953434536, 48.33293744495937, 31.769950185503276, 28.13922459738595, 44.57046011516026, 45.87862178257534, 64.0487516948155, 13.82166930607387, 0.1750666352787188, 0.40182113700679367, 0.4043125547468662, 0.4423441711281027, 1.3392553989376341, 3.7330456290926253, 11.633730207170759, 7.3157496111733575, 6.3266192589487344, 16.474866730826243, 47.40394244875227, 63.04203414916992, 66.04765115465436, 64.33878340039934, 68.11160659790039, 63.00472232273647, 59.973132950919016, 54.53803661891392, 51.172339643750874, 49.11738211768014, 47.80935246603829, 54.748629570007324, 59.006166049412315, 62.34310095650809, 62.56196921212332, 58.31425748552595, 56.411965778895784, 54.96341575895037, 53.67353132792881, 63.05993965693882, 58.82528359549386, 54.108123779296875, 43.34768486022949, 44.560301848820274, 53.99134540557861, 60.995310238429475, 54.62979800360543, 49.80204371043614, 56.22125857216971, 60.583976881844656, 53.71067987169538, 47.205748558044434, 43.4662697655814, 45.94608531679426, 52.79532766342163, 55.32658767700195, 55.105106898716514, 53.275107724326, 48.19660684040615, 47.521738733564106, 44.08027860096523, 52.1386673109872, 55.31882306507656, 62.140922273908345, 42.45416041782924, 32.44346686771938, 57.4543171610151, 49.658174310411724, 54.40286636352539, 50.42744064331055, 55.047287464141846, 53.359698568071636, 52.85731949125017, 52.796383789607454, 53.06663744790213, 50.42921243395124, 54.43173960277012, 53.21692698342459, 52.99108968462263, 45.865903105054585, 55.36488962173462, 57.49562072753906, 60.02869074685233, 52.607371943337576, 46.65160540172032, 43.72502415520804, 50.20258304050991, 58.53701673235212, 60.83749580383301, 55.2753655569894, 49.2963399205889, 57.31825058800833, 60.635615893772666, 59.575723784310476, 56.825807435171946, 53.330165249960764, 55.217007637023926, 54.91831847599575, 56.214890548161094, 61.481600761413574, 60.23535796574184, 55.51965727124895, 59.75363935743059, 58.16470445905413, 62.17421804155622, 63.59516634259905, 65.65302126748222, 29.11631155014038, 1.549302156482424, 7.358954378536769, 10.927038482257299, 6.377787096159799, 2.339629347835268, 1.3511770963668823, 0.5172667322414262, 0.20769638009369373, 0.6901810680116925, 25.06415687288557, 50.084217003413606, 57.53099053246634, 47.47777053288051, 31.576481069837296, 32.19253962380545, 46.21145786557879, 53.082291739327566, 63.51235771179199, 69.3391170501709, 71.16730621882847, 56.825275897979736, 0.6059510420475687, 0.1487015871597188, 0.07353243963526827, 0.18842891683535917, 0.20964787394872733, 0.09249309649957077, 0.10696727982056992, 0.11601264694971697, 0.15274286030658654, 0.06644858832338027, 0.09341601947588579, 0.12654196337929793, 0.1320236578051533, 0.0984152958595327, 0.09830402968717472, 0.10535725871367113, 0.1387860599373068, 0.11234680044331721, 0.10511709802917071, 0.15632739796170167, 0.18762729556432792, 0.13552891542868956, 0.15596223755606584, 0.13497398234903812], [0.026630899835644022, 0.02571717440150678, 0.0721279467855181, 0.040048741535948854, 0.09923354802387101, 0.044916422838079076, 0.00963576723422323, 0.05765280673014266, 0.020227909221180847, 0.00472845058123182, 0.06949265926544156, 0.04440908220463565, 0.03493210234280143, 0.0367881772108376, 0.040993123182228634, 0.04022737266495824, 0.014184777957520314, 0.031573574524372816, 0.027256051111700277, 0.08907073549926281, 0.253901154335056, 5.054104021617344, 63.18209593636649, 62.342336654663086, 62.16479628426688, 47.95175232206072, 40.3135142326355, 24.833596536091395, 30.246814727783203, 31.218631471906388, 39.18682909011841, 29.293706008366176, 0.2133150300277131, 0.0740484655169504, 0.14238221411194119, 0.22689776761191233, 0.423957419182573, 0.4329166870032038, 4.349714756011963, 3.8625240070479254, 0.20608745142817497, 9.425980925559998, 47.30548994881766, 60.78755215236119, 65.20277799878801, 60.10623959132603, 60.531795910426546, 59.14954907553536, 61.164088930402485, 53.53307349341256, 49.26923847198486, 43.87675544193813, 44.749310220990864, 43.53648131234305, 51.24793951851981, 54.957367352076936, 55.174644470214844, 56.225635937282014, 57.85089601789202, 54.3945563180106, 52.52614402770996, 50.23441621235439, 53.79038960593087, 53.378323214394705, 51.67850201470511, 42.78136151177542, 37.73714303970337, 45.24819087982178, 53.05639232907976, 52.52139145987374, 50.60234069824219, 52.750473567417686, 53.884885106767925, 48.82385546820504, 40.673840863364084, 37.18908997944423, 39.965333053043906, 47.34850624629429, 51.55070727212088, 49.00011737006051, 47.41942998341152, 43.83710902077811, 41.05368150983538, 39.293939045497346, 48.12925795146397, 51.10807922908238, 59.628898348127095, 39.75731093542916, 29.21428462437221, 47.7261894771031, 44.79897941861834, 51.275867802756174, 47.677291529519216, 53.49063389641898, 50.25420815604073, 50.50028903143746, 48.071157114846365, 49.7526524407523, 52.116457394191194, 53.70747675214495, 54.287328243255615, 51.849712576184956, 42.72571338926043, 55.47153057370867, 52.00591502870832, 51.29825142451695, 40.65544203349522, 40.79378761563982, 38.70148352214268, 44.20123284203665, 51.79919917242867, 54.43500525610787, 53.05589900697981, 50.65643242427281, 51.41015911102295, 57.45003359658377, 52.189819949013845, 46.039455209459575, 44.98544127600533, 45.93823732648577, 50.39076110294887, 54.219215052468435, 54.844424383980886, 57.462891238076345, 53.86581924983433, 56.62181874683925, 50.0844532421657, 54.71055344172886, 59.000558853149414, 61.03285830361502, 57.17443329947335, 20.861234971455165, 1.2327406001942498, 2.269531794956752, 5.143457855497088, 1.1941619217395782, 0.5694619257535253, 0.07801297599715845, 0.05441166546994022, 0.048459881983165226, 1.6237502587693078, 25.542799166270665, 28.201794862747192, 22.110672201429093, 20.332054955618723, 9.635198133332388, 12.416292786598206, 30.721262046269008, 38.747226987566265, 51.174080167497905, 50.84342234475272, 56.06102269036429, 10.955160447529384, 0.2506921451006617, 0.03693139559722372, 0.028051133001489297, 0.07236080643321786, 0.09148361959627696, 0.028585204521992376, 0.01141028558569295, 0.04371039469593337, 0.02929524052888155, 0.04273555361266647, 0.053527710759746175, 0.034564936866185496, 0.029661669795002257, 0.07673614951116697, 0.04375018059675183, 0.01078590699138918, 0.08261199814400502, 0.044979414636535306, 0.017513299261086752, 0.03640249790623784, 0.04003031252484236, 0.05474369640329054, 0.03918577391388161, 0.058094587310084274, 0.0366676897475762, 0.04037370213440486, 0.06621505014066185, 0.022482406281466995, 0.0195811924058944, 0.04481386227001037, 0.01903644244053534, 0.07022603348429714, 0.029520266489791017, 0.06026667968503066, 0.042677834031305144, 0.017311229836195707, 0.041547133454254696, 0.015694364007296305, 0.0772288812856589, 0.01827074959874153, 0.030594292429408858, 0.03402376447671226, 0.09091624896973372, 0.21642745658755302, 9.874380316053118, 76.817428452628, 69.62022726876395, 71.66185814993722, 54.717915058135986, 49.15243230547224, 31.73694624219622, 26.64054332460676, 28.541912657873972, 36.15782444817679, 30.707198892320903, 0.5706584815468106, 0.10318633341895682, 0.17266672477126122, 0.6581779909985406, 1.270675158926419, 3.076960240091596, 5.104171437876565, 1.8598238825798035, 0.37241443353039877, 11.465662837028503, 49.16774960926601, 63.81197098323277, 67.22169521876744, 61.375654629298616, 62.167651993887766, 59.950690269470215, 61.310508319309776, 56.815805503300254, 54.259851591927664, 46.30371257237026, 45.83419847488403, 45.51482105255127, 53.75423812866211, 56.583325726645334, 56.5769681249346, 57.735830375126426, 60.94754137311663, 56.134628432137625, 53.372476305280415, 53.04812397275652, 56.35351753234863, 55.22273642676217, 54.005828925541465, 43.67739077976772, 39.740663051605225, 47.23932225363595, 56.36535726274763, 54.92135483877999, 51.85281147275652, 52.459243297576904, 57.492553097861155, 51.04124798093523, 43.458519050053184, 40.00711604527065, 42.90155839920044, 49.667203494480674, 54.4660359110151, 51.45524944577898, 49.702569825308665, 45.199685505458284, 42.94945580618722, 40.42601599012102, 49.54624925340925, 53.333621978759766, 61.46065889086042, 42.709006445748464, 31.774626323154994, 50.38942010062081, 47.338073526109966, 52.16853414263044, 49.07992785317557, 53.3390519959586, 51.826394421713694, 52.17806012289864, 50.80360221862793, 52.55426338740757, 54.02777828489031, 54.82294055393764, 56.14757987431118, 51.064729418073384, 43.17560229982649, 56.5640583719526, 56.19716569355556, 53.93710081917899, 42.05917617252895, 42.88182551520211, 40.86559724807739, 46.937739167894634, 54.58906418936593, 57.8386880329677, 53.040442739214214, 49.90995270865304, 55.073534284319194, 60.13239261082241, 54.131997789655415, 49.04668072291783, 47.33442572184971, 48.6242858341762, 51.15013667515346, 56.0487938608442, 56.74564606802804, 60.24391119820731, 57.14002234595162, 59.062300545828684, 53.88343293326241, 58.2688753264291, 60.76117679050991, 61.99656649998256, 59.68300397055489, 26.253222942352295, 2.057842331273215, 1.4624224241290773, 3.147205659321376, 5.183036965983255, 1.6190735782895769, 0.9288246567760194, 0.08537299106163637, 0.048251961890075884, 1.3745904628719603, 29.078002657209122, 29.282338755471365, 31.775949954986572, 21.482793024608068, 8.66958178792681, 19.71355410984584, 40.672253199986045, 47.64421463012695, 57.98774078914097, 56.77116680145264, 65.64808109828404, 18.97600630351475, 0.2757144538419587, 0.0405562212690711, 0.12367797563118593, 0.036309246838624985, 0.035112317851079364, 0.04442699892180307, 0.014724145443843943, 0.06301548611372709, 0.032536449642585855, 0.037599769553967884, 0.049499122825052054, 0.02157129829616419, 0.08919540952358927, 0.009308832947031727, 0.016467529215982983, 0.0145609068817326, 0.05831217991986445, 0.03924071489434157, 0.041616924173597775, 0.029133386178208247, 0.03228337982935565, 0.028276767947578003, 0.04114236695958035, 0.09819812394146409, 0.09022925940475293, 0.17977615685335227, 0.11463599439178195, 0.25872173852154184, 0.09162983032209532, 0.09736429261309759, 0.1460405628063849, 0.14860024116933346, 0.10475087910890579, 0.2476327121257782, 0.13333960862032004, 0.05545945924573711, 0.14811575359531812, 0.1409987083503178, 0.13612141220697335, 0.07627744626786027, 0.10384123506290571, 0.14261876499014242, 0.18655138329735824, 0.4590460934809276, 12.891659004347664, 90.15487085069928, 76.992356300354, 81.82375839778355, 62.80324540819441, 55.72177342006138, 36.12663745880127, 43.73344189780099, 40.10104874202183, 51.57799284798758, 42.824704374585835, 0.7431248213563646, 0.1604912281036377, 0.25642413752419607, 0.8302593571799142, 1.6791069912058967, 3.606294636215482, 14.130022542817251, 9.429785932813372, 4.801999492304666, 12.200242894036428, 50.536437034606934, 65.61502156938825, 70.88202708108085, 64.13355445861816, 64.5509535925729, 62.823429925101145, 63.927040100097656, 59.130226135253906, 56.09388419560024, 47.52225637435913, 47.34745706830706, 47.634389877319336, 55.05169262204851, 58.78355271475655, 60.38309056418282, 60.70122078486851, 64.58210236685616, 56.1676219531468, 54.06090382167271, 51.64782224382673, 59.297510964529856, 57.20870181492397, 57.018637316567556, 46.45072603225708, 40.95984608786446, 49.36663831983294, 59.44459043230329, 55.901408672332764, 53.6507169178554, 55.03420748029436, 58.38489287240164, 53.58457701546805, 45.27998236247471, 42.636269228799, 45.528297083718435, 53.023318903786794, 56.90534346444266, 54.070023332323345, 51.68013136727469, 48.4052369253976, 44.90955999919346, 43.866204602377756, 52.83017635345459, 57.48358992167881, 64.1325261252267, 45.08714900697981, 36.481131076812744, 53.50101450511387, 49.97297286987305, 53.8751437323434, 50.45865889957973, 55.84457588195801, 53.25563539777483, 54.055411270686555, 52.65965713773455, 53.80614117213658, 55.01390831811087, 58.28734711238316, 56.80844388689314, 52.46699748720442, 44.72057594571795, 59.16919163295201, 58.0112430708749, 56.235557964869905, 43.54432930265154, 45.725792680467876, 42.49675982339041, 49.11543662207467, 58.1746369089399, 58.38993031638009, 53.69401114327567, 51.852008955819265, 54.72953592027937, 63.37944562094552, 56.9747177532741, 50.23028203419277, 51.19085659299578, 50.495953355516704, 56.397346769060405, 58.89821883610317, 60.093579973493306, 62.70940998622349, 59.52154173169817, 61.710217339651926, 54.706148283822195, 60.91039630344936, 63.06994506290981, 66.54842172350202, 62.8715739931379, 27.91684229033334, 4.228109121322632, 7.333113159452166, 12.078731060028076, 7.630888632365635, 2.023650028875896, 0.8541593147175652, 0.252249572958265, 0.18391047072197708, 2.529255675418036, 38.21227822984968, 39.1380284173148, 35.300354208265034, 32.55093812942505, 18.242460659572057, 21.373626402446202, 43.10125657490322, 54.44297136579241, 66.25192819322858, 64.12901033673967, 75.15274429321289, 21.76989085333688, 0.6538426950573921, 0.1310581024736166, 0.31050343279327663, 0.15345939328627928, 0.20043750745909555, 0.11896252366048948, 0.11590817969824586, 0.15588453172573022, 0.16172257917267935, 0.10187691011066947, 0.11353218755019562, 0.08635242243430444, 0.16518407128751278, 0.16968544545982564, 0.12068313919007778, 0.1553126759827137, 0.2267799060791731, 0.11139417120388576, 0.10509248756404434, 0.07582175572003637, 0.09084631236536161, 0.12691134427274975, 0.12298397001411233], [0.04070447438529559, 0.03954112948849797, 0.00922765301740063, 0.019674119473035847, 0.02644808723458222, 0.0575835079486881, 0.12402723117598466, 0.06762771933738675, 0.044476012898875136, 0.023377741720261316, 0.06021089053579739, 0.017027030532647456, 0.09233187657913991, 0.09082043982510056, 0.03662450099363923, 0.06214251010013478, 0.02138365961478225, 0.05032363108226231, 0.033762304577976465, 0.02632428682409227, 0.11591921267764908, 33.606678690229145, 71.57196235656738, 62.58339745657784, 63.78221879686628, 50.15238925388881, 31.747365065983363, 18.135548727852957, 37.63836744853428, 31.549226760864258, 51.667437008449006, 10.447658811296735, 0.042433605529367924, 0.07461009573723588, 0.0851614238428218, 0.3113363752407687, 0.14935809693166188, 3.0335342160293033, 4.016408801078796, 1.5281685590744019, 6.381797509534018, 46.458817209516255, 62.63170828138079, 61.79298428126744, 59.12190914154053, 57.771811621529714, 57.88694674628121, 56.18711512429373, 54.20472111020769, 50.903996740068706, 44.9723230770656, 46.21280581610543, 44.46287420817784, 42.14360720770699, 43.30986928939819, 49.575751304626465, 52.25530672073364, 52.61238854272025, 54.73726579121181, 54.19501447677612, 53.84638861247471, 51.20324523108346, 51.69416672842843, 53.26125649043492, 52.08281421661377, 44.173707553318565, 38.60237441744123, 38.71243735722133, 47.88887807301113, 53.38319737570626, 54.86952475139073, 53.36737632751465, 53.615590299878804, 46.004922662462505, 38.92911345618111, 37.815157413482666, 41.332252161843435, 45.64663880211966, 50.06374413626534, 47.90843030384609, 47.020037106105256, 44.01167903627668, 43.00935622623989, 39.879230976104736, 45.8135484286717, 47.821543080466135, 55.63947548185076, 39.34534529277256, 30.424066747937882, 49.731081758226665, 48.05582244055611, 50.67194775172642, 46.678623471941265, 51.01266656603132, 47.48228338786534, 50.53283091953823, 49.97564445223127, 54.435251917157856, 51.09711497170584, 52.092138699122835, 53.085498332977295, 53.90238414491926, 48.759369237082346, 54.109822613852366, 51.787293434143066, 47.61915247780936, 39.54442160470145, 41.378568853650776, 36.68208340236119, 41.134575911930625, 49.40109096254621, 54.993633474622456, 54.41582475389753, 47.45815576825823, 53.306058474949424, 56.2347172328404, 54.1400021144322, 49.01553542273385, 41.614616530282156, 45.67477205821446, 46.6489303452628, 55.20237473079136, 53.12357793535505, 59.14138494219099, 59.36664554050991, 58.895383971078054, 57.85524559020996, 57.803307805742534, 54.18985891342163, 59.28754724775042, 59.817131996154785, 55.67199999945504, 13.969685912132263, 0.9704025685787201, 2.3525254215512956, 4.850475771086557, 0.11817356385290623, 3.00241670863969, 0.5044717873845781, 0.04067917520712529, 0.020961783859612684, 5.227988771029881, 42.98950522286551, 23.662793806621007, 26.48232068334307, 66.17958354949951, 34.770140647888184, 21.852103676114762, 30.449809823717388, 43.1490740776062, 51.426018374306814, 53.10897977011544, 38.70237289156233, 0.3850542924233845, 0.07618612902505056, 0.06833652380321707, 0.007252485923735159, 0.01258260156360588, 0.06573811466140406, 0.020596221421978304, 0.02636682248807379, 0.032079371490648816, 0.053438252702887566, 0.06698446135435786, 0.043501209135034254, 0.03440346588779773, 0.036491871146219115, 0.04465551933805857, 0.034524913478110514, 0.048445008495556455, 0.015348197493169988, 0.026434489392808506, 0.02146723646936672, 0.02638528712226876, 0.01546629990584084, 0.052421454406742535, 0.04215182350682361, 0.05348098683836205, 0.028910514565982988, 0.02841297537088394, 0.06977921817451715, 0.07038169620292527, 0.07770945371261664, 0.05808629561215639, 0.04830866027623415, 0.07829042218093361, 0.007634864155469196, 0.024296659643628767, 0.06517568376979657, 0.029790849291852543, 0.03544530891148107, 0.017396233310656886, 0.04308705171570182, 0.025772003423688666, 0.021026013984477947, 0.08347833129976477, 0.17900721382881912, 44.23766919544765, 79.88265405382428, 71.23402976989746, 71.12120492117745, 58.31183951241629, 40.25374582835606, 19.710408312933787, 34.95841251100813, 29.41316291264125, 45.60650948115757, 10.56734848022461, 0.050188164958464246, 0.05782726486878736, 0.14185154544455664, 0.7732629041586603, 1.4663161294800895, 4.4171774217060635, 1.874595535652978, 0.2759779968432018, 7.923937593187604, 48.39419971193586, 66.30429676600865, 65.54405266898019, 60.58250386374337, 60.631057875497, 58.92748464856829, 58.03935548237392, 58.63242939540318, 52.60554109300886, 45.62073244367327, 47.80567339488438, 46.708490303584504, 43.71943432944161, 45.14585781097412, 52.17429419926235, 52.93043538502285, 55.30997453417097, 57.710000446864534, 57.37082065854754, 54.135624749319895, 50.21158790588379, 51.97838626589094, 54.72663852146694, 54.896688733782085, 47.01505872181484, 40.971484320504324, 40.159038407461985, 48.9379448890686, 55.42221573420933, 56.32177816118513, 55.95643840517317, 55.79893316541399, 46.74289778300694, 42.434642927987234, 39.50920466014317, 42.80248056139265, 48.33346550805228, 52.585092544555664, 49.79808323723929, 48.908060686928884, 44.9231333051409, 43.042513029915945, 41.33714369365147, 49.18648542676653, 50.025320598057334, 56.95230286461966, 41.96879053115845, 33.49878011431013, 52.7578456061227, 49.43038804190499, 52.803203446524485, 47.720373834882466, 53.117970739092144, 49.68030432292393, 51.53551503590175, 51.32007571629116, 57.489937101091655, 53.722213881356375, 54.49200132914952, 56.53438261577061, 54.721187659672324, 49.92581197193691, 55.287719454084126, 53.30052423477173, 49.18839618137905, 41.154670102255686, 42.91988427298409, 39.07910769326346, 43.435565676007954, 52.340366567884175, 57.36687755584717, 57.46926621028355, 48.230194432394846, 53.14317185538155, 59.32773562840053, 54.791659763881135, 51.46996920449393, 43.70366191864014, 47.04225397109985, 48.63883883612496, 55.813486167362754, 56.89073487690517, 60.081719398498535, 60.594155992780415, 61.64245850699288, 59.189848627362935, 60.14076519012451, 58.735123770577566, 62.06843171800886, 62.29050309317452, 56.527802671704976, 18.59373552458627, 1.25733440050057, 2.346117011138371, 5.045257227761405, 2.851545912878854, 6.011264843600137, 0.8010640580739293, 0.013597701825866742, 0.0371842822059989, 5.587165474891663, 43.80943087169102, 21.192214148385183, 26.82434228488377, 48.32672575541905, 27.979049512318202, 30.80911159515381, 37.728391783578054, 48.33770390919277, 59.26230444226946, 58.22548035212925, 48.96234348842076, 0.9139104570661272, 0.09314651215182883, 0.13339191009955748, 0.009950658373002495, 0.028917232062667608, 0.07164966780692339, 0.03334612173161336, 0.02285315272664385, 0.02161241412561919, 0.09605948334293705, 0.040361332441014905, 0.031676708454532285, 0.09796033812952892, 0.027051399861063277, 0.06695960661662476, 0.027752954180219343, 0.08841251581907272, 0.041658026432352405, 0.05165166660611119, 0.07615381718746253, 0.014704357666362609, 0.029603119008243084, 0.04334129200183919, 0.13995421225471155, 0.11212506876992327, 0.10421546069639069, 0.14615609017866, 0.13067977848861898, 0.11591545359364577, 0.23038614328418458, 0.14622463578624384, 0.23324728118521826, 0.21670670088912758, 0.1017837676086596, 0.23135484701820783, 0.1566361313951867, 0.139421942244683, 0.16440526236380848, 0.1175949906132051, 0.09846475427704197, 0.14875219230140957, 0.17219985196632998, 0.25462607400757925, 0.3823062798806599, 54.4251492364066, 90.53290149143764, 79.58110223497663, 78.90637656620571, 62.942883355276926, 44.318382944379536, 25.72462136404855, 51.16228212629046, 42.87356063297817, 70.69619056156704, 15.093304293496267, 0.259925052523613, 0.24755215644836426, 0.5306152531078884, 0.8759412659066064, 1.8727890040193285, 11.078497052192688, 10.525222420692444, 5.847266512257712, 9.174167786325727, 51.38627120426723, 67.74993896484375, 67.39031410217285, 63.68295683179583, 62.86075564793178, 61.62726279667446, 59.89401381356375, 60.300386156354634, 55.38763802392142, 47.737118993486675, 50.6936400277274, 48.981266907283235, 45.46355376924787, 47.79392051696777, 54.44707427706037, 55.85081189019339, 56.91120426995413, 60.52357619149344, 59.13930743081229, 54.79506785529, 52.87285566329956, 53.53375094277518, 57.58458546229771, 57.17357867104666, 49.86163493565151, 43.91540479660034, 42.5029228755406, 50.65887819017683, 57.55794259480068, 59.318716866629465, 57.53687913077218, 58.32599994114467, 50.247162682669504, 44.47679839815412, 42.38822896139962, 47.38486964362008, 52.730219568525044, 53.87864909853254, 52.712786538260325, 51.079907757895334, 47.33686106545584, 45.86353029523577, 42.87395668029785, 50.465829440525596, 52.5584705216544, 58.93751089913504, 44.69473212105887, 37.24052054541451, 55.52188416889736, 52.56563411440168, 55.37017025266375, 50.77152933393206, 53.74039036887032, 48.98952831540789, 53.09375626700265, 52.677524430411204, 58.67529283251081, 54.01104702268328, 56.49718196051461, 58.898093768528526, 56.873406069619314, 48.99398211070469, 57.662547724587576, 54.93236773354666, 51.21771485464913, 44.393062182835166, 45.607075759342735, 41.556748458317344, 45.68546533584595, 53.19459547315325, 59.981679235185894, 59.66675213405064, 49.815575327192036, 53.659134660448345, 60.98701408931187, 57.22015592030117, 54.28589344024658, 46.60051877158028, 49.87652839933123, 51.23048216956002, 58.22809634889875, 59.48304871150425, 62.965117590767996, 60.90940965924944, 64.16046483176095, 61.99826186043875, 64.0603551864624, 59.459973743983674, 66.44081497192383, 64.77724252428327, 60.94174657549177, 19.333935805729457, 3.467255102736609, 7.716403586523874, 11.472623194966998, 4.496827227728708, 4.94643907887595, 0.9128649703093937, 0.17395964610789502, 0.17724328062364034, 8.427912150110517, 58.537044525146484, 33.8692615372794, 38.367792810712544, 78.09359019143241, 45.6024169921875, 32.203708853040425, 43.60370513371059, 55.81685256958008, 67.77045004708427, 67.14837087903703, 56.78092207227434, 1.4825336592538017, 0.3442755863070488, 0.2112778236291238, 0.09232224816722528, 0.0737794738795076, 0.14063428076250212, 0.19122608245483466, 0.09679962255592857, 0.11721026125763144, 0.23224665916391782, 0.19657623608197483, 0.10814392739640814, 0.13604032727224485, 0.06931311889950718, 0.18123571281986578, 0.08530000104968037, 0.21667745602982386, 0.11695741196828228, 0.11508627023015704, 0.1575282420963049, 0.07882833081696715, 0.22891315232430184, 0.1441062765994242], [0.029275291599333286, 0.06269153992512397, 0.07330715922372681, 0.0020290525280870497, 0.031522833675678284, 0.06185480446687766, 0.034595369161771874, 0.03531043989849942, 0.03178225118400795, 0.07738537181700979, 0.023149287461170127, 0.04872806277126074, 0.07587855588644743, 0.0650404788819807, 0.04729906462931207, 0.07312081993690558, 0.028715279685067277, 0.05843242311051913, 0.013264330785854586, 0.17340350523591042, 3.1203712821006775, 60.28355067116873, 63.217698505946565, 64.95989676884243, 51.55802719933646, 50.048808983394075, 25.636914253234863, 39.49721206937517, 30.144384384155273, 36.864279065813335, 37.55594444274902, 0.13870707846113614, 0.03463494132405945, 0.09093858634254762, 0.15991550471101487, 0.5689737605197089, 0.9466489574738911, 3.065885462931224, 2.131754445178168, 2.556771844625473, 44.31996365955898, 62.11783340999058, 61.89799240657261, 57.713905334472656, 54.4593482698713, 48.71442828859602, 46.859095982142854, 44.56403650556292, 44.31240749359131, 43.19090918132237, 41.954098565237864, 46.92717790603638, 43.840576171875, 40.444213322230745, 41.77508865083967, 41.15322835104806, 45.50950568062918, 49.949647767203196, 55.620930739811485, 55.51802791867937, 54.8027560370309, 49.71988126209804, 50.08377579280308, 51.427408014025005, 52.63122163500105, 44.817371300288606, 40.281774861471995, 38.370127405439106, 39.015055724552695, 42.17086846487862, 50.45266260419573, 48.462451866694856, 48.55953904560634, 43.21567950929914, 39.343698569706504, 36.134110246385845, 40.55409908294678, 44.13703843525478, 48.68383189610073, 46.04536117826189, 44.70583534240723, 40.295914445604595, 42.68514633178711, 39.14584166663033, 46.876376152038574, 47.39470829282488, 57.18441091264997, 41.67474971498762, 36.80415630340576, 54.87617417744228, 51.39907326017107, 54.919833183288574, 49.033215114048545, 46.88653441837856, 45.51467514038086, 51.40649741036551, 50.1702287537711, 51.251976421901155, 50.691767488207134, 48.17221171515328, 49.19651862553188, 53.7191948890686, 49.911717551095144, 51.55050924846104, 53.32705593109131, 47.64637204578945, 43.46775320598057, 38.19523082460676, 38.24886744362967, 39.46925599234444, 46.51015050070626, 52.08042056219918, 52.988411154065815, 51.57284770693098, 48.69393457685198, 53.99823801858084, 55.5828789302281, 50.58098540987287, 43.76369088036673, 40.66623606000628, 45.444258621760774, 53.129720142909456, 56.21551936013358, 53.90792185919625, 58.144506045750205, 62.66950648171561, 56.6974846294948, 57.93889147894723, 60.75160217285156, 55.05140079770769, 54.51305437088013, 57.50428860528128, 47.07093266078404, 7.88094561440604, 1.5052068254777362, 3.7342576554843356, 1.7682295803512846, 2.20074245759419, 0.3648971883313996, 0.05694724566170147, 0.04036910845232861, 0.14674469216593675, 14.853605338505336, 46.838046414511545, 57.36997992651803, 74.53657109396798, 81.39834104265485, 25.586148977279663, 21.324679817472184, 35.138488973890034, 49.75106825147356, 49.87853990282331, 51.203439780644004, 4.090800992080143, 0.36496306051101, 0.04367561299087746, 0.12387876771390438, 0.031027547216841152, 0.036763264797627926, 0.06736938069973673, 0.01437918672205082, 0.044925888401589224, 0.016290713168148483, 0.06749653137688126, 0.07326810274805341, 0.053199954597013335, 0.011791582402241017, 0.03222986716510994, 0.027129480581996695, 0.07055147923529148, 0.05882660445890256, 0.0654728210398129, 0.018673796007143598, 0.022169477805229168, 0.04961773753166199, 0.03142025275155902, 0.015578275147293295, 0.06056596112570592, 0.06185515730508736, 0.03787891886063984, 0.023693504776539545, 0.00681820697250909, 0.022882984518738728, 0.038897745976490636, 0.02418857580050826, 0.02686375778700624, 0.03506750061309763, 0.02886983978429011, 0.09819028007664851, 0.049990205759448667, 0.03548442645530615, 0.02303422149270773, 0.0236419191517468, 0.060310166994375844, 0.06101520559085267, 0.1820868942886591, 4.970280953816005, 73.46484620230538, 71.24358354296002, 71.54687935965401, 59.69249520983015, 57.632326534816194, 33.166187218257356, 32.76568610327584, 24.326946054186138, 35.171579769679475, 35.99214465277535, 0.6399936324783734, 0.01413462234527937, 0.06444167172802345, 0.4880840267453875, 1.1140228105442864, 3.65520669732775, 1.4249164823974882, 1.0029949396848679, 3.6438741854258945, 45.966266359601704, 66.07278278895787, 63.05969646998814, 60.451926367623464, 55.67957353591919, 50.141105379377095, 48.08744716644287, 45.674977030072895, 46.090983050210134, 45.82067033222744, 44.06967217581612, 48.68574265071324, 45.57928991317749, 43.2228604725429, 44.09118727275303, 42.04966756275722, 47.24890381949288, 52.50614711216518, 57.29490116664341, 57.256272656576975, 55.85407754353115, 49.804614543914795, 50.52259274891445, 53.86949832098824, 54.273317200796946, 47.79838820866176, 44.22166749409267, 40.524562290736604, 40.11011266708374, 43.941519601004465, 52.508808272225515, 52.02650948933193, 50.50490958350045, 44.40637493133545, 41.011839457920615, 38.15281902040754, 43.25500283922468, 45.79774475097656, 51.12153788975307, 47.474668162209646, 47.04153135844639, 43.58272852216448, 44.18384150096348, 41.75379242215838, 48.04455941064017, 49.41153757912772, 59.24395424979073, 43.23910188674927, 40.004625116075786, 57.773708479745046, 53.70511436462402, 57.502836431775776, 51.49181086676461, 47.94147941044399, 47.292788641793386, 52.1157660484314, 52.514835834503174, 52.15865727833339, 52.73311349323818, 49.42554514748709, 52.66249200275966, 53.95985269546509, 49.79535954339163, 54.02400541305542, 56.04877301624843, 50.17424828665597, 43.338089397975374, 39.03851979119437, 40.80907365253994, 40.91694096156529, 50.01515885761806, 53.921057428632466, 55.06152432305472, 52.75815827505929, 49.62248488834926, 56.668399470193044, 56.5812794821603, 53.40785305840628, 45.848313740321565, 43.02068526404244, 47.90589768545968, 53.997709955487935, 60.530399322509766, 55.374832493918284, 58.53709316253662, 62.19533361707415, 59.25662776402065, 60.398925508771626, 63.21968569074358, 58.201352732522146, 59.56718444824219, 60.14491326468331, 48.67526476723807, 9.930968182427542, 0.38229919597506523, 1.8843514578683036, 6.461039977414267, 7.672119242804391, 1.5180188694170542, 0.11779384208577019, 0.04735302851934518, 0.15517740324139595, 17.17606851032802, 45.270074231284006, 53.207626819610596, 73.96089894430978, 73.01863288879395, 28.869485480444773, 27.548705884388514, 42.11245148522513, 56.32967478888375, 54.91895423616682, 62.01397173745291, 8.460346341133118, 0.6231966337987355, 0.054389311133750846, 0.10110334626265935, 0.04499896662309766, 0.05225362216255494, 0.01444703683124057, 0.07445758142109428, 0.05527917927663241, 0.020755802680339133, 0.11332106816449336, 0.08008293528109789, 0.038753787986934185, 0.039038684485214095, 0.04362173391772168, 0.0731103230001671, 0.008583400980569422, 0.02665137462983174, 0.009621438270966922, 0.020167010703257153, 0.021797435358166695, 0.011071638935910804, 0.025757940785427178, 0.11005365063569375, 0.115817948111466, 0.12583247359309876, 0.10531833794500146, 0.13373478741518088, 0.15590097941458225, 0.1267505314733301, 0.13988027907907963, 0.14487817803663866, 0.16771666253251688, 0.1259628473115819, 0.14908561083887303, 0.16226885414549283, 0.12022515519389085, 0.10331104137003422, 0.2107442236904587, 0.1617175308721406, 0.2020581340683358, 0.12725013680756092, 0.21322424204221793, 7.4327720403671265, 87.5734761101859, 75.81841645921979, 80.94503361838204, 63.58817645481655, 65.22453280857631, 35.339472566332134, 55.99560192653111, 41.638549600328716, 50.425321442740305, 52.04233748572213, 0.5701828013573373, 0.16201204221163476, 0.22633357931460651, 0.8325685475553785, 1.1393063281263625, 5.635174921580723, 11.585498418126788, 7.181979852063315, 4.4578673754419595, 49.50028691973005, 67.98134177071708, 66.75797939300537, 62.47862557002476, 58.5897605078561, 52.63620696749006, 50.31297254562378, 48.19519635609218, 49.74291106632778, 48.11493076596941, 45.95607682636806, 50.418633801596506, 46.56503779547555, 45.623292854854036, 45.948207991463796, 43.68126440048218, 48.46383455821446, 53.93901852199009, 59.255182538713726, 59.53491701398577, 57.438503061022075, 49.985764503479004, 51.46432726723807, 54.491143226623535, 57.60149390356881, 49.942598819732666, 46.79489115306309, 42.25650153841291, 42.07845742361886, 45.506378991263254, 54.54632581983294, 54.35007395063128, 52.97267001015799, 46.698040212903706, 44.088960375104634, 40.790341309138704, 45.47378846577236, 48.12543296813965, 55.725952761513845, 50.69261169433594, 49.93986817768642, 45.95192180361067, 47.586624486105784, 42.95394434247698, 52.398599420275005, 51.32396323340279, 62.047760827200754, 46.32537358147757, 43.45498936516898, 60.4209999356951, 56.82898276192801, 60.170017106192454, 52.989960602351594, 48.79749052865164, 48.91939319883074, 51.31663635798863, 53.86744165420532, 54.15833493641445, 55.15012427738735, 52.91498953955514, 53.368401186806814, 56.48543603079659, 51.30507108143398, 55.41435037340437, 58.42548424857003, 51.8276937348502, 47.30410378319876, 41.73627601351057, 42.33066661017281, 42.72544240951538, 51.37370538711548, 57.23312473297119, 58.10989359446934, 52.873817988804404, 49.28122411455427, 58.17680474690029, 59.75202737535749, 54.798211915152415, 48.07105984006609, 46.88697910308838, 50.49676629475185, 56.63804973874773, 60.79251316615513, 58.28195183617728, 59.75618934631348, 63.28265026637486, 60.85400472368513, 60.778040068490164, 66.39115619659424, 59.234747886657715, 62.851194926670615, 62.50765514373779, 52.711146763392854, 11.409176588058472, 3.842134952545166, 9.82623451096671, 8.53019050189427, 7.6792550427573065, 1.0570488848856516, 0.175337533599564, 0.17276725651962416, 0.3932692344699587, 23.400881460734777, 60.59330136435372, 61.4927248273577, 76.61003862108502, 88.09538309914726, 34.55600411551339, 33.768189566476, 48.22217273712158, 65.4192143848964, 62.52104432242257, 71.62996591840471, 11.406114169529506, 0.6826830932072231, 0.14797680319419929, 0.2587553124342646, 0.10555711441806384, 0.10850895888039044, 0.13332917275173323, 0.21939296674515518, 0.10190716598715101, 0.15317609134529317, 0.17109443699674948, 0.1818581601338727, 0.21887892218572752, 0.1497871753360544, 0.10775309122566666, 0.2124513363731759, 0.07417541263358933, 0.08858531154692173, 0.12927181832492352, 0.1217648054340056, 0.10223586192088467, 0.1529948410711118, 0.10045542674405233], [0.05566559139905231, 0.020624987914093902, 0.024476062606221864, 0.03681010746264032, 0.048282926835651906, 0.014813627249428203, 0.02109781825648887, 0.011242270985219096, 0.030850011921886886, 0.04147852338584406, 0.026462485747677938, 0.025456859530614953, 0.09468084267739739, 0.011602844494128866, 0.06100035245929446, 0.006683253566734493, 0.05296037066727877, 0.0680994979505028, 0.008041661166186844, 0.043448849980320246, 11.182290979794093, 65.77633789607457, 56.403975350516184, 54.979921204703196, 35.99184588023594, 34.54919835499355, 18.93567201069423, 41.64114127840315, 68.38364246913365, 51.84603697913033, 14.660551377705165, 0.052454234433493445, 0.20324189269116946, 0.15026430759046758, 0.10619713578905378, 1.0424672216176987, 1.2761753095047814, 1.1754875523703439, 0.9688695136989866, 33.57085725239345, 66.65059498378209, 57.50708525521414, 58.00967277799334, 49.23438630785261, 49.74893862860543, 46.887232712336946, 51.43713896615164, 49.75568880353655, 48.27507284709385, 45.19795887810843, 44.87391921452114, 43.31704330444336, 44.01002883911133, 44.5850304876055, 46.37957647868565, 42.59406239645821, 43.88063948495047, 45.5044195992606, 53.56974261147635, 50.7437504359654, 54.95127725601196, 53.486610889434814, 50.10703141348702, 51.59179891858782, 52.822856426239014, 45.5911921773638, 43.622392313820974, 38.445817606789724, 41.76313080106463, 37.33832686288016, 41.733003411974224, 41.56148018155779, 44.90466846738543, 38.444334166390554, 37.37190750667027, 36.05721453257969, 40.049507004874094, 43.89797524043492, 46.2729355267116, 42.90290634972708, 43.811963490077424, 39.66014732633318, 41.90934869221279, 40.22966684613909, 45.12664951596941, 47.75123773302351, 55.69463375636509, 39.133206367492676, 36.61900418145316, 53.42370537349156, 46.91802365439278, 50.83483784539359, 51.63509314400809, 51.20201539993286, 43.77796942847115, 46.72373465129307, 52.68998602458409, 55.58678381783621, 48.379271507263184, 45.58237143925258, 48.472012587956016, 53.471835545131135, 51.12633214678083, 49.21466384615217, 54.72541911261422, 50.67737429482596, 41.84665857042585, 40.15830189841134, 38.56872081756592, 39.61738811220442, 40.52378061839512, 47.55027845927647, 50.15841334206717, 53.555220876421245, 51.836847986493794, 51.00237280981881, 55.40257665089199, 52.0306784084865, 46.601807662418906, 40.02966294969831, 42.9346352985927, 49.684014660971506, 56.508823667253765, 52.77435105187552, 53.60877411706107, 53.939893995012554, 56.28039469037737, 54.18478672845023, 57.474022252219065, 55.45583806719099, 55.304516724177766, 49.12458739961897, 56.699690682547434, 33.738159452165874, 3.0307264924049377, 2.6998035524572646, 1.923172346183232, 3.2376633882522583, 0.4572746828198433, 0.03158793571804251, 0.12616594641336373, 0.043926586130900044, 4.246000298431941, 26.474726302283152, 56.321309157780235, 73.27129718235561, 73.74384416852678, 39.47500215257917, 22.00187383379255, 35.8977255821228, 43.72614628928048, 45.999648979731965, 51.53820398875645, 23.398090021950857, 0.12126425015074865, 0.046560594612466435, 0.06317513861826488, 0.030252052936702967, 0.026160807382049303, 0.023673362464510968, 0.03968852086524878, 0.04792214298088636, 0.05407085090077349, 0.03713954299954431, 0.01239563717639872, 0.07444109980549131, 0.0688869853370956, 0.06426522548177413, 0.04570966759430511, 0.020534780076039687, 0.030192769332123653, 0.03419971878507307, 0.059848369631384096, 0.02095498833140092, 0.013492932626312333, 0.032266558946243355, 0.03631249023601413, 0.040967623836227825, 0.08500618181590523, 0.03935796235288892, 0.05161518517083355, 0.01998501573689282, 0.02357186719642154, 0.04756995277213199, 0.03659360729424017, 0.03261241163792355, 0.0038748658262193203, 0.06908916163125209, 0.0470906593836844, 0.033312948154551644, 0.02087022064785872, 0.06897927288498197, 0.03846911879788552, 0.05450865526550582, 0.042463973364127536, 0.039590014543916495, 17.59574839047023, 77.58284895760673, 62.27893434252058, 64.45618711199079, 43.365430559430806, 46.50492892946516, 25.000926528658184, 46.66581794193813, 55.22452211380005, 44.20889670508248, 16.37234432356698, 0.15856118952589376, 0.11230308243206569, 0.2670122965105942, 0.512284548154899, 1.9583821254117149, 2.6616275438240597, 1.4884313770702906, 1.7633316431726729, 36.47829621178763, 69.00726413726807, 60.41622652326311, 59.80102607182094, 51.917961256844656, 51.38799088341849, 49.853578499385286, 52.86724846703665, 51.84979942866734, 50.69821541649954, 47.130555152893066, 46.72352967943464, 44.57587276186262, 46.192454542432515, 46.240543024880544, 49.086288928985596, 45.25883552006313, 45.78684302738735, 48.154969760349815, 56.6313099861145, 53.85887452534267, 56.208220277513774, 55.06247970036098, 51.1338917868478, 52.664996828351704, 54.85898086002895, 48.669508184705464, 43.93177475248064, 41.36756638118199, 42.809046609061106, 39.518164362226216, 44.853943143572124, 43.35435513087681, 45.630341802324565, 40.056177275521414, 39.80999565124512, 38.14895582199097, 41.92749391283308, 45.536235400608604, 49.1888929775783, 46.2821557862418, 45.67395911897932, 42.17637143816267, 43.97130305426461, 42.11145789282662, 47.08781678336007, 50.6725800377982, 57.526571478162495, 41.02324145180838, 40.75040306363787, 56.79665279388428, 48.62370218549456, 53.206549848829, 53.28849342891148, 52.497701576777864, 44.577773094177246, 47.14226981571743, 52.2909266608102, 56.578257015773225, 51.76683793749128, 47.22534247807094, 52.129964692252024, 56.281892027173726, 52.45541136605399, 50.85114179338728, 56.09368964603969, 52.00815234865461, 43.893420696258545, 42.06118420192173, 40.032674993787495, 42.48802246366228, 43.037103857312886, 51.39769751685006, 52.141755785260884, 54.84420204162598, 51.985310145786826, 54.011762687138145, 58.581172534397666, 55.03174434389387, 48.310790061950684, 42.31972319739205, 44.73604958398001, 50.4672121320452, 58.05295658111572, 55.54578249795096, 55.9845403943743, 53.90125853674752, 56.21784005846296, 56.5075660433088, 59.19242640904018, 57.321057660239084, 58.31302070617676, 54.27805239813668, 59.436572211129324, 36.90267481122698, 4.065701058932713, 0.7028868805084909, 2.0835252617086684, 6.635908331189837, 4.318431794643402, 0.6851245707699231, 0.17219278163143567, 0.04547325920845781, 4.225542196205684, 32.66969673974173, 60.797217096601216, 75.46494770050049, 79.60265554700578, 42.29250362941197, 28.144416638783046, 44.93480280467442, 48.576655932835166, 52.698320388793945, 58.58072090148926, 31.52081557682582, 0.11244929315788404, 0.03144002865467753, 0.03770992971424546, 0.05453474832964795, 0.02365841773072524, 0.01857463998853096, 0.012547431397251785, 0.1038417439641697, 0.051903515056307824, 0.02511854705932949, 0.0340870514379016, 0.06754273961165122, 0.013953478940363442, 0.03552373059626136, 0.05033072177320719, 0.02182283462025225, 0.017872229018913846, 0.054832832156015296, 0.04762485643316593, 0.019091648049652576, 0.033280358117605956, 0.017856717708387544, 0.12091464176774025, 0.14307840461177485, 0.18958796321281365, 0.07287553631301437, 0.22638262382575444, 0.0877182184319411, 0.09908343572169542, 0.18232827633619308, 0.08130657140697752, 0.13362072567854608, 0.10684586954968316, 0.11427482377205576, 0.16469376188303742, 0.11183576857937233, 0.15274454307343277, 0.13961050712636539, 0.11579250304826669, 0.14104668077613625, 0.15403016337326594, 0.16108440341694014, 26.32963228225708, 88.9127413885934, 69.12923976353237, 74.51062652042934, 49.09040226255144, 50.24053757531302, 26.598616157259258, 54.245232582092285, 81.80570697784424, 69.19325351715088, 19.977946962629044, 0.33874009762491497, 0.4314610936811992, 0.3420511313847133, 0.41958453240139143, 2.600724628993443, 9.193973626409258, 7.056090218680246, 2.711889943906239, 38.10187135423933, 71.03119100843156, 62.40476621900286, 63.49338218144008, 53.23322050912039, 54.290114470890586, 50.970435414995464, 55.749319553375244, 54.60439886365618, 55.06451204844883, 49.56423813956124, 50.484447138650076, 47.13720110484532, 50.223201819828574, 48.76419823510306, 51.33307579585484, 48.300989627838135, 48.7234331539699, 49.787188461848665, 57.88851009096418, 56.80932630811419, 59.25090939658028, 56.20465932573591, 50.24207660130092, 55.21801165172032, 58.61146668025425, 50.61300270898001, 47.07663018362862, 41.75087417875017, 45.85916682652065, 41.7370159966605, 46.34788227081299, 45.64078841890608, 49.398311683109824, 41.32695416041783, 41.63268532071795, 40.60910102299282, 44.65363700049264, 49.294109548841206, 51.594963823046, 48.58650500433785, 49.262988567352295, 44.933701515197754, 46.85330465861729, 42.67628043038504, 47.72266674041748, 54.73187051500593, 59.983291217258994, 44.049789905548096, 43.818366255079, 59.50623485020229, 50.589611598423545, 56.30259418487549, 56.166836806706016, 53.17825678416661, 46.77421678815569, 49.65759413582938, 54.09707614353725, 60.36879117148263, 52.97636297770909, 50.4361571584429, 54.53845698492867, 58.98743370601109, 53.11417702266148, 50.63430935995919, 58.90458338601248, 55.49504327774048, 46.14814935411726, 44.8108434677124, 43.07794884272984, 44.840126650674, 45.061464990888325, 53.06539372035435, 55.31057207924979, 58.91195542471749, 53.23128890991211, 53.426515919821604, 62.3347144808088, 57.36176715578352, 51.23554045813424, 44.408376012529644, 47.81115204947335, 52.41206155504499, 59.85139356340681, 56.24640410287039, 58.87107917240688, 56.088829381125315, 57.07988568714687, 58.11801603862217, 61.08560902731759, 59.90929290226528, 59.21916307721819, 57.06208440235683, 63.300972666059224, 41.78458683831351, 5.187106004783085, 7.144509954111917, 10.917198096002851, 9.889041015080043, 3.509766787290573, 0.5985752035464559, 0.3514663204550743, 0.16057106453393186, 5.992273245538984, 41.82577575956072, 65.87888635907854, 72.96504143306187, 78.22329221452985, 49.26441294806344, 32.2380815914699, 47.422212736947195, 57.15899787630354, 59.779187883649556, 65.30384649549211, 39.813004221235005, 0.29621728509664536, 0.14824743010103703, 0.2276267720652478, 0.08750343495713812, 0.09916285824562822, 0.17806300520896912, 0.10593862073229891, 0.22016610311610357, 0.15812947840562888, 0.1234685932951314, 0.12124207562633924, 0.09603825198220355, 0.21374547907284328, 0.10186546322490488, 0.2029295630220856, 0.12153247504362039, 0.1557065655610391, 0.10835740808397532, 0.15769734659365245, 0.09007118110145841, 0.10570846843932356, 0.10604753917349236], [0.014519365271553397, 0.06295350872512374, 0.028459078432726007, 0.035707298067531416, 0.0126447672456769, 0.021541600514735495, 0.04263487597927451, 0.03825704607048205, 0.021944585854985883, 0.034180268578763516, 0.011670589430390723, 0.0254447120574436, 0.10591437667608261, 0.01656212378293276, 0.02110056801965194, 0.051686553484094996, 0.05269942645515714, 0.04924862126686743, 0.031169364428413764, 0.26208358098353657, 48.37471696308681, 68.41965498243059, 57.14366667611258, 44.33051102502005, 32.04365015029907, 19.560009343283518, 20.71991729736328, 28.72778912952968, 45.22100952693394, 42.59592451368059, 1.5027288155896323, 0.04338012456095644, 0.014869794681934374, 0.1078966013821108, 0.245812148387943, 2.077441462448665, 4.027481189795902, 0.49672470880406244, 24.968169246401104, 66.90139021192277, 58.26428951535906, 58.34864412035261, 51.799716813223704, 52.98239401408604, 53.1648919241769, 56.29783466884068, 58.25548962184361, 55.52104343686785, 55.95478473390852, 51.311341830662315, 44.66388559341431, 40.27520186560494, 45.3742207799639, 49.46832173211234, 47.93110227584839, 47.565915380205425, 44.50289930616106, 44.588362148829866, 46.59570714405605, 51.77269179480416, 51.512165614536826, 54.89197785513741, 50.828647000449045, 49.61734669549124, 51.80263505663191, 45.31037725721087, 42.58409867967878, 43.553441865103586, 44.34222221374512, 41.46208620071411, 40.239647933415, 38.62029034750802, 39.93720327104841, 38.72169235774449, 37.68628570011684, 36.75729070390974, 39.11373404094151, 40.567543847220286, 44.122190134865896, 39.888850757053916, 41.359513419015066, 38.430024351392476, 40.36726202283587, 40.41367598942348, 45.07097707475935, 44.61990349633353, 56.3782878603254, 40.849494797842844, 34.96891818727766, 54.04066719327654, 45.29607786451067, 46.851550238473074, 49.1611453465053, 54.27781615938459, 51.46318776266915, 46.934834820883616, 46.8403844833374, 52.389243670872276, 46.78724118641445, 43.135212421417236, 43.717759813581196, 49.94736180986677, 50.14627831322806, 48.16989796502249, 51.48117317472185, 50.63005358832223, 40.88342979976109, 39.63587032045637, 38.02012579781668, 40.38155446733747, 39.88369171960013, 44.80764382226126, 47.639938013894216, 49.76009743554251, 52.58171224594116, 49.03688723700387, 53.97671944754464, 53.918834005083355, 48.09556613649641, 40.65080411093575, 39.207107407706125, 44.295846462249756, 53.29658113207136, 52.9366957119533, 52.02650601523263, 50.03089305332729, 55.83242000852312, 56.545861039842876, 57.77567481994629, 58.5008305140904, 56.43948064531599, 54.206847258976524, 48.047300474984304, 45.32319320951189, 17.97947481700352, 1.1049775587660926, 3.50163739493915, 10.462721637317113, 4.31315290076392, 0.4484104641846248, 0.11666036290781838, 0.028628328815102577, 0.04599219600536993, 12.44839346408844, 24.979275941848755, 44.4512985093253, 40.230417251586914, 25.017181839261735, 18.785271303994314, 26.353514977863856, 40.40547364098685, 46.514666829790386, 51.94753279004778, 39.66537584577288, 2.8229931592941284, 0.1021848428728325, 0.07028415000864438, 0.060470905154943466, 0.018533178106216446, 0.04860242861988289, 0.019130034471995065, 0.03212723195818918, 0.0112182584790779, 0.011083371654552008, 0.018947820678087215, 0.03479023084842733, 0.02918168090816055, 0.06379436967628342, 0.024854391680232117, 0.04872426976050649, 0.045649199946118255, 0.01983119354450277, 0.03077549520613892, 0.04029307521081396, 0.018233311429087604, 0.01986321191569524, 0.027673070252473866, 0.02981688468051808, 0.030216429848223925, 0.05257247594584312, 0.05122763989493251, 0.008940347719804516, 0.030844037421047688, 0.052341777432177744, 0.013056754201118435, 0.008177351206541061, 0.019976732520652667, 0.03429333965427109, 0.025020936404221823, 0.030064614423151528, 0.030618309176393917, 0.05254199615280543, 0.03687228841174926, 0.03051621001213789, 0.03194169334268995, 0.7290552077548844, 58.208693504333496, 76.42804445539201, 63.887025424412315, 52.27633196966988, 36.79622840881348, 29.121804101126536, 29.50067547389439, 28.268030302865164, 53.97103929519653, 43.24234669549124, 2.6688497619969502, 0.0780863527740751, 0.01269762427546084, 1.1327308352504457, 1.4321421746696745, 3.5524020195007324, 1.0310239728007997, 0.7477667065603393, 28.943244082587107, 69.17639023917062, 59.18520723070417, 59.52227129255022, 55.239095960344585, 56.28035300118582, 56.56732055119106, 57.61181197847639, 59.76801518031529, 58.78815937042236, 59.86704090663365, 54.019850390298025, 46.4731513432094, 42.68642827442714, 47.482022830418174, 50.50943980898176, 52.126893588474815, 48.832085609436035, 44.98419754845755, 48.051452023642405, 50.03604514258248, 53.420015880039756, 54.608383655548096, 56.0209697995867, 51.845790318080354, 51.817997523716514, 53.98161792755127, 48.64056198937552, 45.28756979533604, 44.956665311540874, 46.11912325450352, 43.88007320676531, 40.88075474330357, 40.580814906529014, 40.621326378413606, 40.78493561063494, 39.545946734292166, 38.19711378642491, 42.01638569150652, 44.75044277736119, 47.66528156825474, 42.994681630815776, 43.15410109928676, 41.005318573543, 43.47508702959333, 42.073868138449534, 47.28115388325283, 46.77663823536464, 58.884836605616975, 41.809683731624055, 37.57151882989066, 56.36797325951712, 48.48156636101859, 49.01228019169399, 52.822609765189036, 56.16141373770577, 51.6298611504691, 47.892098563058035, 47.5479542868478, 54.96499300003052, 47.717525073460166, 44.84872504643032, 46.17958995274135, 52.18400778089251, 51.621377399989534, 49.18510273524693, 53.81147391455514, 52.749479975019185, 42.983001708984375, 41.07285506384713, 40.23257466724941, 41.61929266793387, 42.53813982009888, 47.859862395695274, 52.151000363486155, 53.41427319390433, 52.860004970005576, 48.17497362409319, 54.86904532568795, 56.413313729422434, 50.40520988191877, 42.906905038016184, 41.915056637355256, 47.45314611707415, 55.291652134486604, 55.26356404168265, 54.211961133139475, 52.06243167604719, 56.507562569209504, 58.73742362431118, 59.55945805140904, 60.24111107417515, 56.88149724687849, 55.58895860399519, 52.38181952067784, 49.42070920126778, 21.777440071105957, 1.0833373942545481, 1.118265988571303, 1.3406020466770445, 7.568966286523001, 2.9815712443419864, 0.42328447529247826, 0.01780995986025248, 0.05237131406153951, 15.30338134084429, 33.95200763429914, 48.10536657060896, 49.58475964409964, 33.38729279381888, 27.563422169004166, 33.021616050175254, 46.15796715872628, 51.327781268528526, 58.35516153063093, 48.79125452041626, 4.127084485122135, 0.1811623496136495, 0.07652977987059525, 0.07720703245805842, 0.05146432648013745, 0.026161314586975744, 0.027706309986699904, 0.029092819962118353, 0.0218939230378185, 0.050297358206340244, 0.05083481561658638, 0.012076267706496375, 0.07174600620887109, 0.06463521705674273, 0.028085366789517657, 0.029103642595665793, 0.04704213055915066, 0.021657758924577917, 0.03757682489231229, 0.02391092775256506, 0.046776629984378815, 0.03992159425147942, 0.13708780892193317, 0.11721370821552617, 0.12718581168779305, 0.15431993853832993, 0.1844375567244632, 0.18384830334356853, 0.17148587027830736, 0.13974252289959363, 0.10014617083860294, 0.08615833427757025, 0.06521704726453338, 0.15374139244002955, 0.16167171618768147, 0.16735771750765188, 0.10001526786280529, 0.07252083891736609, 0.2327916313494955, 0.10070221671568495, 0.13230029653225625, 1.3143696657248904, 70.74683598109654, 82.24586841038295, 75.22350474766323, 61.55194432394845, 46.37470579147339, 28.198339870997838, 31.780838012695312, 39.237335545676096, 55.813093594142366, 58.3636383329119, 3.053674872432436, 0.1337297119732414, 0.11882349183516842, 1.3132535027606147, 1.647454472524779, 7.296980789729527, 11.273843050003052, 2.2892479598522186, 33.23326860155378, 74.26985754285539, 62.74320602416992, 62.222848483494346, 57.205481324877056, 59.0993344443185, 58.645881107875276, 59.81993906838553, 62.013047627040315, 60.52145004272461, 62.153894560677664, 56.213038853236604, 48.76567472730364, 43.877179282052175, 49.50156191417149, 52.819111347198486, 53.01451553617205, 52.3419577053615, 47.67882013320923, 50.40861102512905, 52.16381631578718, 55.040349687848774, 56.825585092817036, 58.76313195909773, 53.41899102074759, 52.60385962894985, 56.10096093586513, 50.479350634983604, 46.46640464237758, 47.56402547018868, 48.98543930053711, 45.39529466629028, 43.43895639692034, 42.99052313395909, 42.84259598595755, 42.729451520102366, 41.741091115134104, 41.9363146509443, 44.61067281450544, 46.68376166479928, 50.74319805417742, 43.55334806442261, 44.99790981837681, 43.98920161383492, 44.78259556634085, 45.22645691462925, 50.16150876453945, 49.26887369155884, 60.89659023284912, 46.44883612224034, 41.014531884874614, 58.732240268162315, 51.19997957774571, 51.28129781995501, 55.30943604878017, 59.18037128448486, 55.06394229616438, 50.16978406906128, 51.5360917363848, 58.175807680402485, 50.957265104566304, 47.099152769361226, 48.08580044337681, 54.91487216949463, 52.97359759466988, 49.72467204502651, 55.36454221180507, 55.30542346409389, 44.37032420294625, 43.25120564869472, 42.869019985198975, 44.22697244371687, 45.80750696999686, 50.059443201337544, 53.06757892881121, 55.52512550354004, 54.758148602076936, 48.90541342326573, 56.98753023147583, 59.164404324122835, 52.566759722573416, 45.14947434834072, 43.451567377362935, 50.935732637132915, 58.85617528642927, 58.202999455588206, 57.06400557926723, 54.72162192208426, 58.17866339002337, 60.453677313668386, 61.679971831185476, 62.98173073359898, 60.420027187892366, 57.02233028411865, 54.06496851784842, 53.009908880506245, 25.174112115587505, 3.1561054331915717, 10.178387454577855, 21.113063744136266, 10.691261785370962, 1.722983562520572, 0.4830445200204849, 0.07297467706458909, 0.13005795542682919, 20.48516024862017, 39.174562045506065, 51.85627514975411, 49.61585283279419, 32.8910802432469, 27.430862699236187, 37.91155672073364, 53.318450587136404, 60.37815039498465, 64.66819749559674, 57.87207760129656, 4.9984259349959235, 0.32717397968683926, 0.22147938050329685, 0.25033330864139963, 0.08386883498834712, 0.1385291258671454, 0.1319901246045317, 0.12881880120507308, 0.12688683558787617, 0.13888670025127275, 0.1744454771812473, 0.12717431730457715, 0.1180577107838222, 0.1723237388900348, 0.08675257489085197, 0.09702445513435773, 0.09647839729275022, 0.08250717126897403, 0.12659141501145704, 0.17569483656968388, 0.1204880875136171, 0.11786877949322973], [0.008391132994022752, 0.04494811720880015, 0.038607621365892034, 0.01972541502410812, 0.06561502840902124, 0.03134203123460923, 0.011233612030212368, 0.03191512191135969, 0.010990872064472308, 0.027706781568537866, 0.03625139494293502, 0.03043545755956854, 0.06302539272499935, 0.10073496281568493, 0.015275843607793962, 0.07810124661773443, 0.026709531866280094, 0.044251909745591025, 0.07701964822730847, 7.0422437616756985, 66.37490436008999, 56.965657302311485, 53.177971908024375, 44.46345785685948, 34.959816047123496, 20.836558444159373, 26.743960312434606, 36.05380991527012, 32.88410077776228, 15.984805073056902, 0.06686630126621042, 0.05878435208329132, 0.2069887359227453, 0.1961496411157506, 1.0635684664760316, 2.730278351477214, 1.5420238098927905, 7.838804789951869, 59.816041128976, 62.87259537833077, 61.73195825304304, 57.367825984954834, 55.60721846989223, 58.38318361554827, 59.73531000954764, 57.628459862300325, 58.191430704934255, 57.4362553187779, 56.90670183726719, 55.38958351952689, 48.55907004220145, 42.609893866947715, 49.032777377537315, 51.64412580217634, 53.270730359213694, 47.898914745875764, 45.375040667397634, 39.403307165418354, 44.32456684112549, 46.30126333236694, 51.01469196592058, 51.63622917447771, 50.44396693365914, 51.55093656267439, 51.14129161834717, 48.00183841160366, 47.48368692398071, 45.91476631164551, 48.651904923575266, 45.00107819693429, 42.03674043927874, 37.96647875649588, 40.64506837299892, 35.70874152864729, 38.31513588769095, 35.52964128766741, 37.35206692559378, 38.87915243421282, 41.98214149475098, 39.716344356536865, 40.59933532987322, 38.040400641305105, 41.849559443337576, 37.99620662416731, 44.740843841007774, 45.76868738446917, 56.77855968475342, 36.105796337127686, 34.85381085532052, 52.753638471875874, 44.42023311342512, 42.21971777507237, 44.13691336768014, 55.82820245197841, 48.5139136995588, 52.29388311931065, 49.33076824460711, 53.264522143772666, 49.27807658059256, 40.36271095275879, 41.46343762534005, 52.67801080431257, 51.103222438267295, 48.00263745444161, 48.82253531047276, 52.51563140324184, 43.24719653810774, 39.134644644601, 36.99282768794468, 41.08912774494716, 41.1086174419948, 46.4645459992545, 48.58544887815203, 50.68462821415493, 49.982550961630686, 46.94389527184622, 50.835609095437185, 53.796750681740896, 50.84140041896275, 45.00085238048008, 40.23746967315674, 41.33621263504028, 50.19899777003697, 55.569927488054546, 52.05426754270281, 53.27763686861311, 54.00208732060024, 57.03986406326294, 54.9726151738848, 56.493638379233225, 54.194312708718435, 55.23183856691633, 55.660455567496165, 50.80276148659842, 42.87825066702706, 16.95591310092381, 0.225275865356837, 2.3630343547889163, 7.876421468598502, 3.5501419007778168, 0.0792240524398429, 0.07475838278021131, 0.06508158453341041, 2.0022189617156982, 22.279899052211217, 23.72317017827715, 31.02681255340576, 25.83249388422285, 15.700053998402186, 23.97792935371399, 38.84497077124459, 46.691512380327495, 46.15355505262102, 49.486835207257954, 9.09701498917171, 0.2727357122514929, 0.09694512760532753, 0.03195741499907204, 0.0049076173288215485, 0.03288155594574554, 0.018622466529320394, 0.02689978290748383, 0.07375782182706253, 0.04042670589738658, 0.05309520575350948, 0.05456301270584975, 0.037623962720057795, 0.024170737114867995, 0.0616228472707527, 0.03134102700278163, 0.009139729297852941, 0.02472735465770321, 0.10865341898586069, 0.029805125668644905, 0.025392649761800255, 0.05152987974828907, 0.03286588178681476, 0.030086127375917773, 0.03107708366587758, 0.04446735818471227, 0.05334133754617401, 0.01573255704715848, 0.009260547546935933, 0.04814053286931344, 0.019200237401361977, 0.0317681206922446, 0.04872812044673732, 0.03630953521600791, 0.04840906310294356, 0.11632916996521608, 0.05806553244058575, 0.00928567030600139, 0.03823431854003242, 0.10701834636607341, 0.04178727039002946, 9.275749581200735, 76.95302949632917, 62.38757637568882, 62.67265401567732, 49.81194836752755, 44.18518945149013, 26.469028779438563, 26.49325541087559, 36.56511047908238, 38.0327194077628, 20.236590181078228, 0.05020026323784675, 0.1931367963552475, 0.2576698192528316, 0.865132528756346, 2.7776917730058943, 2.928051224776677, 0.2200767264834472, 8.19091430732182, 62.917466844831196, 63.74943024771554, 64.75025572095598, 58.88375963483538, 59.06364154815674, 59.878213609967915, 61.79187951769148, 58.24339280809675, 59.590641566685264, 59.29120200020926, 58.816466331481934, 57.941153117588584, 51.93274702344622, 44.177720138004844, 50.10641302381243, 52.77351726804461, 54.67408234732491, 52.1734048298427, 46.806824684143066, 41.715424469539094, 46.27033690043858, 48.303372859954834, 53.06433412006923, 54.05799947466169, 52.007641656058176, 52.94411291394915, 54.2171688079834, 49.25656148365566, 49.040420395987375, 47.595962865012034, 51.1909955569676, 48.03410584586007, 45.622948919023784, 38.889533042907715, 41.95868785040719, 38.46086393083845, 40.63295766285488, 38.34943567003523, 41.70786830357143, 42.384435244968955, 44.60539218357631, 42.393884795052664, 42.46815756389073, 40.385396821158274, 44.629359994615825, 39.98781047548567, 46.78436115809849, 49.21077632904053, 58.66771929604666, 38.3894225529262, 38.89956971577236, 54.2168596131461, 47.13703434807913, 44.55913455145699, 46.11143854686192, 56.281641892024446, 50.765439237867085, 55.392977714538574, 50.847907406943186, 52.63229513168335, 50.80437694277082, 42.4326731136867, 42.85158000673567, 52.93403802599226, 53.646589687892366, 48.319426672799246, 51.64099563871111, 54.34835774557931, 44.421105112348286, 39.97324357713972, 39.562695366995676, 42.196528162275044, 44.43168027060372, 48.12152113233294, 51.968870707920615, 52.49650648662022, 53.01753452845982, 47.42672906603132, 53.53097513743809, 55.48282834461757, 52.64975248064314, 46.20206390108381, 42.70149196897234, 43.5636487688337, 51.88981063025338, 57.04446724482945, 54.36638137272426, 57.22546434402466, 56.318345751081196, 58.66997051239014, 56.736658573150635, 58.01841361182076, 57.490777833121165, 56.28517157690865, 54.135614327022004, 51.74237333025251, 47.634636538369314, 21.812802927834646, 0.4785535952874592, 0.8702433087996074, 1.7717281069074358, 4.516015112400055, 2.089311156954084, 0.04401653612564717, 0.17700324207544327, 1.8796043183122362, 29.016116789409093, 26.063196659088135, 29.598697185516357, 27.347195965903147, 19.27057691982814, 27.091603006635392, 45.205296175820486, 51.12838533946446, 52.47795132228306, 58.78891672406878, 13.927844728742327, 0.33725038756217274, 0.03122088559237974, 0.06177449984742062, 0.05230790496404682, 0.056231876369565725, 0.029534966950970035, 0.037644091461385996, 0.050417017856878896, 0.058396664315036366, 0.04640550186325397, 0.0037667366060694413, 0.04397287578987224, 0.06447829226297991, 0.0544105187457587, 0.048228267447224686, 0.021131741614746194, 0.016130465249131833, 0.028175918984093835, 0.033874737830566506, 0.11031091040266411, 0.041353075831596336, 0.18047882057726383, 0.10233194247952529, 0.16936760608639034, 0.1025667902348297, 0.2147618702479771, 0.11926711803036076, 0.0904945055288928, 0.2488471269607544, 0.0725545688931431, 0.07220819033682346, 0.1314896914575781, 0.17152301328522818, 0.09966016334614583, 0.25291489011475016, 0.11173400189727545, 0.16689058685941355, 0.14463100130004541, 0.2651125613067831, 0.17826268449425697, 12.59010110582624, 86.61360331944057, 70.94019045148576, 70.90250342232841, 57.91579566683088, 49.33371775490897, 29.552675792149135, 36.10434416362217, 50.08747223445347, 48.61103214536394, 24.185650961739675, 0.18004368964050496, 0.4313031035874571, 0.4927972938333239, 1.2366166093519755, 4.604543847697122, 9.111682636397225, 3.8765654478754317, 10.34519372667585, 66.3089381626674, 65.43941279820034, 66.13056400844029, 62.87517316000802, 61.55962903159005, 61.62974330357143, 63.2447269984654, 60.3487525667463, 61.19263907841274, 60.38079071044922, 59.90730571746826, 61.676796504429404, 54.23468174253191, 46.46203075136457, 52.81448037283761, 54.9805326461792, 57.38017988204956, 52.67154203142439, 49.83211203983852, 43.261530671800884, 48.12351179122925, 51.22520153863089, 54.53047350474766, 57.08852229799543, 51.693781103406636, 55.39046941484724, 57.09713111604963, 52.33508593695504, 51.21407399858747, 49.36209419795445, 53.34194939477103, 49.51874828338623, 46.639477321079795, 41.369230474744526, 44.17653547014509, 39.103544507707866, 42.787187576293945, 40.21924107415335, 43.42163453783308, 45.08970594406128, 46.19220093318394, 44.77953488486153, 44.73800202778408, 42.448039054870605, 48.20630305153983, 42.14182152066912, 48.918344020843506, 52.23295783996582, 60.63049507141113, 40.69921568461827, 43.06071036202567, 57.293719972882954, 49.67595822470528, 46.925246306828086, 48.81254380089896, 60.053780691964285, 53.58028302873884, 56.15583780833653, 52.381270612989155, 55.94477932793753, 53.749381337847026, 43.364263262067524, 45.84635434831892, 57.537254333496094, 54.782408237457275, 50.040620531354634, 53.05575656890869, 56.69797795159476, 47.438085896628245, 42.348120485033306, 41.06791142054966, 45.808010714394705, 46.02324506214687, 50.134845052446636, 54.86159338269915, 54.39745371682303, 53.622229303632466, 47.68593856266567, 53.84800754274641, 57.92414392743792, 54.797319071633474, 49.086125646318706, 44.73370804105486, 46.713746615818565, 54.356563568115234, 59.68399061475481, 56.54301575251988, 59.498640469142366, 59.455387932913645, 61.326245989118306, 58.901109286717, 61.13642120361328, 59.093900953020366, 59.20222336905343, 55.416945525578086, 54.30515384674072, 48.51668950489589, 24.45901915005275, 0.7215644525630134, 7.060777647154672, 19.379170315606252, 9.254586236817495, 1.1143742374011447, 0.10025918763130903, 0.2598157269614083, 2.672358819416591, 35.48585721424648, 37.37293584006173, 41.09151097706386, 34.402070249829976, 23.187160083225795, 34.74597481318882, 51.40095969608852, 61.70688220432827, 57.56878178460257, 66.47069917406354, 17.86875179835728, 0.4585181932364191, 0.12305141639496599, 0.09546192469341414, 0.15819826828581945, 0.1555741290960993, 0.08213156142405101, 0.12049783127648489, 0.15661851662610257, 0.08343219091849667, 0.11563519148954324, 0.1998420794095312, 0.06022999808192253, 0.1312276276626757, 0.177209611716015, 0.17222058799649986, 0.07911008569811072, 0.06391176980520998, 0.1709272866802556, 0.18184021966797964, 0.2391082766864981, 0.11453975098473684], [0.03206938345517431, 0.04037074711439865, 0.009993405231008572, 0.01939442564201142, 0.005276709420806063, 0.022175420075654984, 0.04578190443239041, 0.0880631652793714, 0.01467199154597308, 0.04236989787646702, 0.05658733033175979, 0.03624406676473362, 0.015817569003307393, 0.012361979294967438, 0.014538009717528309, 0.021776673882933598, 0.08209854391004358, 0.08482055499085359, 0.0817140249003257, 20.325612238475255, 77.42669514247349, 60.27567836216518, 58.28337274278913, 39.6692772592817, 24.04499510356358, 24.04660882268633, 40.18594878060477, 34.28731032780239, 39.54421315874372, 5.4359570401055475, 0.04422564026234405, 0.036016740570110936, 0.17714215176446096, 0.5141055732965469, 1.8163036235741206, 1.6014952872480666, 1.130365516458239, 39.092677525111604, 67.25068310328892, 57.86315611430577, 61.397485869271414, 57.504233019692556, 60.12436744144985, 57.61247205734253, 59.09722219194685, 56.052445139203755, 57.72362239020211, 53.48391151428223, 55.46478387287685, 55.84585435049874, 49.6846330506461, 44.98967967714582, 50.725921358381, 52.67702416011265, 54.900631836482454, 52.95911060060774, 47.11756896972656, 42.36992393221174, 41.581358977726524, 44.88743346078055, 50.47406652995518, 52.120438711983816, 52.849808488573345, 49.572329316820415, 53.69825301851545, 50.63947187151228, 49.68675225121634, 50.990786688668386, 51.54283496311733, 49.54612071173531, 45.19100373131888, 37.318600927080425, 38.216867515019004, 36.88871588025774, 38.26561260223389, 35.303508690425325, 37.48354421343122, 37.672507422310964, 40.177850655147004, 37.18695340837751, 38.74994373321533, 38.50008651188442, 42.14377743857247, 40.912487166268484, 47.69162566321236, 45.25422886439732, 55.474167415073936, 35.61379439490182, 31.869062764304026, 54.27017314093453, 46.11823388508388, 50.73119504111153, 38.94027921131679, 43.689605712890625, 48.913316999162944, 51.73111030033657, 48.76179068429129, 50.45149530683245, 46.49692807878767, 40.232647623334614, 40.060697078704834, 48.56302356719971, 50.086086068834575, 47.683180127825054, 49.407653536115376, 51.91771112169538, 42.50844669342041, 37.85944523130144, 38.22980853489467, 39.98445102146694, 44.319734369005474, 49.085139002118794, 50.5530605997358, 50.251220430646626, 51.464229992457796, 48.54945373535156, 50.01445708956037, 53.09955106462751, 50.458450453622, 46.368546213422505, 40.4678441456386, 40.825005871909006, 46.4265011378697, 52.76720482962472, 51.94215488433838, 52.16861057281494, 50.798488344464985, 51.63116046360561, 54.22451652799334, 55.675213541303364, 56.19335460662842, 53.4969984463283, 53.95152875355312, 60.80743094852993, 60.40563746861049, 53.64811481748308, 19.415891545159475, 0.03298237607149141, 3.1660463511943817, 6.560503874506269, 1.4905710965394974, 0.2208346908113786, 0.08348773579512324, 0.07299831043928862, 8.864260758672442, 29.238092626844132, 31.249839305877686, 26.239178895950317, 25.105316264288767, 22.383677346365793, 26.603636230741227, 42.10304709843227, 49.557581765311106, 53.419449601854595, 26.862689392907278, 1.005692469222205, 0.1306809727102518, 0.01259579906971859, 0.07408356613346509, 0.03348847159317561, 0.06749102167252984, 0.04708572643409882, 0.0934998117653387, 0.051562666560390165, 0.03264892360727702, 0.037669533131910224, 0.0269136046658137, 0.05703234752374036, 0.0721075093107564, 0.011679817506644343, 0.018109972422410334, 0.010527697275392711, 0.05022826637806637, 0.03955068326156054, 0.02071166906638869, 0.033308513928204775, 0.07370244658419065, 0.021348828715937476, 0.00313771259139425, 0.06591688828276736, 0.026853661185928752, 0.033419054068092785, 0.021158284208338176, 0.022678292556000606, 0.015655589123655642, 0.030476339294442108, 0.07513363978692464, 0.042744751154844246, 0.01589735284713762, 0.03632683107363326, 0.013856255898385175, 0.019280438544228673, 0.07585441361048392, 0.013723947506930147, 0.1236356757581234, 27.68896222114563, 87.78768907274518, 66.80316352844238, 64.84532792227608, 45.341880389622276, 30.581158569880895, 26.04343945639474, 30.264275550842285, 32.07083150318691, 43.09251226697649, 6.572562038898468, 0.13076192193797656, 0.2075007991599185, 0.7237244195171765, 2.065325975418091, 4.8771064792360574, 1.0400038680859973, 1.5852450792278563, 42.09371566772461, 69.6245698928833, 61.685912540980745, 62.337327003479004, 59.934174401419504, 61.62806183951241, 58.6200407573155, 61.327753748212544, 59.24850531986782, 60.51286901746477, 54.923435824257986, 57.55888407570975, 56.76781776973179, 51.608842849731445, 47.5710084097726, 52.46904025759016, 55.775225911821636, 55.75816808428083, 54.86251401901245, 49.42936665671212, 45.09077944074358, 43.90934944152832, 45.57956436702183, 52.15324810573033, 54.40023647035871, 54.284430844443186, 50.34493773324149, 54.869788782937185, 52.34739119665963, 52.1946941103254, 52.0924756867545, 53.065122740609304, 52.3859988621303, 47.09191969462803, 39.06606592450823, 39.332664830344065, 38.5163904598781, 41.25053787231445, 37.07929801940918, 40.20645291464669, 40.277984619140625, 43.17265278952462, 39.846925326756065, 42.08392913000924, 40.349432945251465, 44.17292240687779, 41.85914100919451, 50.482842104775564, 47.27958359037127, 58.428319113595144, 38.1076592036656, 34.66453150340489, 57.06338024139404, 49.3925655228751, 51.546791962214876, 41.54247685841152, 46.06076880863735, 51.11019842965262, 53.678481919424875, 52.85259819030762, 53.309025355747764, 47.19832788194929, 41.89203725542341, 42.05587577819824, 50.80280317578997, 52.76171922683716, 49.1928117615836, 51.9843339238848, 54.50633198874337, 44.26803282329014, 39.09282691138131, 39.42552055631365, 40.94266319274902, 46.79256698063442, 51.13328381947109, 52.47749274117606, 52.37375961031233, 54.0011110986982, 48.13475745064871, 49.31565938677107, 54.72245223181588, 53.21524551936558, 48.80641548974173, 43.2343875340053, 42.63463640213013, 49.036508560180664, 55.084776469639365, 54.93743644441877, 55.41929749080113, 52.32645280020577, 53.17526905877249, 55.993670327322825, 57.81222929273333, 58.08096824373518, 53.59923424039568, 55.37563501085554, 61.57412297385079, 61.613428933279856, 56.1483268056597, 22.672621658870153, 0.07117028281624828, 0.661023983997958, 2.959643380982535, 4.909453817776271, 0.8654020428657532, 0.03261284250766039, 0.0774203570825713, 9.296923347881862, 36.6669328553336, 34.29493597575596, 21.973839589527675, 22.552881615502493, 30.5245099067688, 35.55530098506382, 48.45215463638306, 54.864000933510916, 59.59526906694685, 36.39167301995413, 1.4782333757196153, 0.03009889740496874, 0.029786523631108657, 0.06601222245288746, 0.028518423105457, 0.018085643549316695, 0.04556557729042002, 0.06785242299416236, 0.040933897253125906, 0.03245611788172807, 0.03844632002125893, 0.03467893414199352, 0.026290544973952428, 0.026624279030199562, 0.04279845380889518, 0.04400708752551249, 0.02025643313702728, 0.020395614240052443, 0.008410471242054232, 0.048905421647110155, 0.06655287915574652, 0.12227220035025052, 0.10196096024342946, 0.0628893735951611, 0.10402169145111527, 0.1147276373314006, 0.1369643969727414, 0.08706137617783886, 0.15391212542142185, 0.13020050206354686, 0.13783640946660722, 0.18472691119781562, 0.10565484381679978, 0.09591203768338476, 0.10120102816394397, 0.08927916110094104, 0.1413050533405372, 0.1777579765766859, 0.17084238837872232, 0.1643465148018939, 38.05012117113386, 96.07064356122697, 75.45477553776333, 74.17978109632219, 54.07431384495327, 33.5253951890128, 34.18519612721035, 56.1776099886213, 46.83098357064383, 56.75683961595808, 8.185327955654689, 0.1840657059635435, 0.46992100136620657, 1.1211887917348315, 2.706708541938237, 6.665515039648328, 8.101326840264456, 2.5214372149535587, 45.15625579016549, 70.84244319370815, 63.93958854675293, 65.07334000723702, 62.83433859688895, 64.178724697658, 61.32434218270438, 64.0406778880528, 61.57917431422642, 62.6619815826416, 56.56572246551514, 59.77975763593401, 60.22604043143136, 53.139239174979075, 48.692239216395784, 55.22967420305525, 57.96546139035906, 57.84974261692592, 57.68671008518764, 51.92120259148734, 46.344970975603374, 46.44559826169695, 47.86992686135428, 53.71746131352016, 56.73489373070853, 56.164391040802, 50.582718985421316, 57.698726994650706, 55.874380179813926, 52.57516704286848, 54.74353654044015, 55.59885631288801, 55.41826915740967, 48.870536940438406, 41.47268220356533, 41.28014414651053, 40.191948550088064, 44.448467118399485, 39.10108484540667, 42.16530990600586, 43.33532748903547, 45.87289299283709, 42.40528678894043, 45.01643371582031, 42.177816663469585, 46.6533111844744, 45.4403988974435, 53.54125152315412, 49.894062178475515, 59.592204911368235, 41.767681871141704, 39.644979408809114, 59.8683888571603, 51.04111596516201, 53.4791658946446, 42.68060220990862, 47.91637904303414, 53.84583970478603, 56.56005620956421, 54.22253629139492, 56.27067068644932, 51.233671392713276, 45.04186412266323, 44.544279302869526, 51.774564334324424, 53.92383323396955, 49.184637205941335, 53.39382464545113, 57.85966117041451, 46.69837720053536, 41.951704910823274, 41.56096601486206, 43.28269141060965, 49.635022912706646, 54.09364720753261, 54.570675781794954, 55.34363508224487, 55.053064891270225, 50.651721545628135, 50.73961278370449, 56.964184284210205, 55.509155069078716, 50.55426263809204, 45.98152807780674, 44.90756934029715, 51.51807158333914, 58.1156883920942, 57.48215511866978, 58.17619677952358, 55.99321869441441, 55.39239753995623, 59.20011806488037, 59.464441435677664, 59.64972904750279, 54.64495897293091, 56.30214602606637, 65.04923670632499, 66.09899139404297, 59.050870759146555, 25.6891872882843, 0.22542536019214562, 6.608567603996821, 17.390847751072474, 4.838578283786774, 0.8566437842590469, 0.14555668591388635, 0.6087316242711884, 13.00698607308524, 41.83818176814488, 47.20144762311663, 38.595231669289724, 36.6759272984096, 33.10553639275687, 38.10634599413191, 55.18399327141898, 61.76201616014753, 67.39974280766079, 42.40980659212385, 1.7442410332815987, 0.22416861834270613, 0.12333720177412033, 0.1423631879900183, 0.1065446814256055, 0.13612704404762813, 0.17192523527358258, 0.20592810426439556, 0.1742156980825322, 0.13029973102467401, 0.11847882318709578, 0.05283679926235761, 0.12739946879446507, 0.13028736811663422, 0.047195713567946634, 0.10481740268213408, 0.14488572334604605, 0.10099071623491389, 0.10873465319829327, 0.12131033624921526, 0.13043988921812602], [0.04778211710176297, 0.052438746871692796, 0.045959032606333494, 0.008731732976489832, 0.016935742127576044, 0.0873119727309261, 0.05561626868854676, 0.026480343093031218, 0.02587261320357876, 0.04251096530684403, 0.07250437765781369, 0.025157839325921874, 0.032407276931085756, 0.028619579106037105, 0.02137265886579241, 0.02043063343236489, 0.13277658740324633, 0.04453791564862643, 0.825040228664875, 36.63070494788033, 65.80462401253837, 50.02424015317644, 40.74241263525826, 37.988580976213726, 20.862840005329677, 24.783262048448833, 36.45827497754778, 42.63707174573626, 19.81728376661028, 0.14405831774430616, 0.06126578178788934, 0.16098600226853574, 0.5944004218493188, 0.3678515026611941, 2.7796615873064314, 1.7141848632267542, 14.111975465502058, 61.0345675604684, 58.60192680358887, 58.303216797964915, 61.58298192705427, 60.48997470310756, 59.13835552760533, 58.536933353969026, 56.79111507960728, 54.987338406699045, 57.02962589263916, 55.31524821690151, 55.7638760294233, 56.21990714754377, 52.946444034576416, 50.02937139783587, 52.317298548562185, 52.70315286091396, 57.028677463531494, 52.12173802512032, 49.07242032459804, 43.477112429482595, 43.991744654519216, 44.13281740461077, 50.67468534197126, 51.97746910367693, 51.38374900817871, 49.72432116099766, 52.065221377781455, 51.32257011958531, 51.844557012830464, 50.20302077702114, 50.6818767275129, 50.449383054460796, 46.51252678462437, 39.49778182165963, 39.71460035869053, 38.00388438361031, 37.73297759464809, 36.15564966201782, 37.17071199417114, 36.593605041503906, 39.99050290243966, 35.9010329246521, 38.7498916217259, 37.50973197392055, 42.53544739314488, 40.73721885681152, 47.34051929201399, 46.27059398378645, 56.502983706338064, 33.74841499328613, 27.984449999673025, 51.45585741315569, 47.23321826117379, 51.33689035688128, 44.938058035714285, 40.60814911978585, 40.22014086587088, 46.7565336227417, 46.63331079483032, 49.54645422526768, 45.88134895052229, 37.99952438899449, 39.78315476008824, 49.03653635297503, 50.995914459228516, 47.38929912022182, 48.212955951690674, 50.812061650412424, 41.939847809927805, 38.0594664982387, 36.05768353598458, 39.903275217328755, 47.64891856057303, 50.5028737613133, 51.510355608803884, 50.08903905323574, 51.39607858657837, 45.626124245779856, 46.06519133704049, 50.64994280678885, 52.63041911806379, 48.88658727918352, 40.8598232950483, 38.41713891710554, 42.579505920410156, 46.68257004874093, 49.94198737825666, 48.30957760129656, 47.394114221845356, 47.474727221897666, 51.88717378888811, 54.803579398563926, 56.510032653808594, 51.926709038870676, 60.81105095999581, 52.491913727351594, 56.14704138892037, 54.81263290132795, 52.38009984152657, 13.20115087713514, 0.10828846214073044, 1.8998963151659285, 4.0607417821884155, 0.3324701354971954, 0.05618075554126075, 0.038339583070150444, 2.0953061495508467, 15.190676348549978, 31.463055201939174, 37.411609513419016, 33.835660048893516, 23.031671558107647, 16.94987337929862, 41.9368496622358, 43.87957293646676, 47.96787561689104, 45.64602736064366, 4.092948853969574, 0.14856891999287264, 0.028145771673215286, 0.014449306530877948, 0.020294359851894633, 0.01785353198647499, 0.07967966156346457, 0.04857045944247927, 0.07039035430976323, 0.09174458416444914, 0.05887500436178275, 0.060011048402105055, 0.049017671695245166, 0.023152354439454417, 0.06199271670941796, 0.08270208045308079, 0.018564551869141202, 0.022337523787947636, 0.028532523063144515, 0.02341408744853522, 0.08231286598103386, 0.016734838086579527, 0.033556454016694, 0.027213456075904623, 0.055483835616282055, 0.0319872569691922, 0.08595765754580498, 0.015912211067708473, 0.01862426464711981, 0.021436532759772878, 0.03671598108485341, 0.03919368223952396, 0.040314038550215106, 0.04850443459248968, 0.03407186582418425, 0.029430805040257316, 0.09001125288861138, 0.07392972867403712, 0.06780814179884535, 1.2880229651927948, 48.518645422799246, 74.01906926291329, 58.254885128566194, 47.8237942968096, 45.66176503045218, 26.194258792059763, 23.6696013041905, 30.11727598735264, 39.62700094495501, 22.87534056391035, 0.08429623062589339, 0.07024750911763736, 0.4953028251017843, 0.7706500557916505, 2.995040544441768, 2.777219512632915, 0.3342452102473804, 14.753926481519427, 64.963759967259, 59.81447778429304, 62.39933967590332, 63.18420818873814, 63.40733569008963, 61.13599736349923, 61.12482466016497, 60.16153335571289, 58.9586056300572, 57.85108361925398, 58.07921382359096, 58.236458505902974, 57.830155645098, 54.65423829214913, 51.444785458701, 55.42990739004952, 54.42900548662458, 57.86137042726789, 54.63538782937186, 49.836016927446636, 45.321654183524, 44.98514597756522, 46.15515661239624, 53.033539703914094, 53.43796655109951, 54.285466126033235, 49.68007850646973, 53.22809968675886, 51.03175674165998, 52.53145592553275, 52.554642064230784, 53.150866985321045, 53.85471255438668, 48.418237004961284, 41.54312651497977, 40.37067706244332, 39.33533293860299, 40.84822327750069, 38.89401115689959, 38.89770065035139, 37.733564717429026, 41.45705917903355, 39.08310638155256, 41.850219522203716, 40.298057964869905, 44.375868865421836, 42.85745470864432, 49.14411531175886, 48.04334347588675, 57.79591839654105, 36.47019113813128, 31.08981534412929, 54.15067107336861, 48.175647599356516, 54.49161570412772, 47.17122990744454, 42.79304838180542, 41.61638832092285, 48.78438622610909, 48.08870479038784, 51.29218217304775, 47.38309437888009, 39.899450234004426, 41.27366842542376, 50.23610462461199, 53.289528710501536, 48.90089362008231, 50.058842182159424, 53.39911569867815, 43.05380037852696, 39.592871393476216, 38.87277398790632, 41.53458023071289, 49.78459678377424, 53.001178468976704, 52.27849285943167, 52.35469027927944, 50.999412877219065, 47.40973029817854, 47.39912039893014, 52.61124208995274, 55.55917167663574, 52.077867099217, 42.386898381369456, 40.679732935769216, 45.33443192073277, 47.04238946097237, 51.38845293862479, 51.94002178737095, 49.22412729263306, 49.96247066770281, 54.66816595622471, 57.39749131883894, 58.82636056627546, 52.157851287296836, 61.91084657396589, 54.576439312526155, 58.39603778294155, 56.61232055936541, 56.49785246167864, 16.20125882966178, 0.15161645146352903, 0.9641783939940589, 6.16385510138103, 1.346068324787276, 0.3491373982812677, 0.05262766798425998, 0.9300669729709625, 20.593460083007812, 32.55786200932094, 28.9980080468314, 32.196580001286094, 23.423798356737407, 22.588275739124843, 45.279412610190256, 47.772165707179475, 53.68656962258475, 54.41260773794991, 6.286535535539899, 0.19271453044244222, 0.08071810512670449, 0.0266268710339708, 0.0546274463912206, 0.08943200789924179, 0.05824635523770537, 0.04149015686873879, 0.05394732699330364, 0.057750671835882325, 0.07064305432140827, 0.05013507977128029, 0.04415763069742492, 0.03888194289590631, 0.09877749785248723, 0.024862018413841724, 0.07630613472844873, 0.03643134582255568, 0.015960938363735164, 0.011510888580232859, 0.07468616629817657, 0.1392511006976877, 0.17590123335165636, 0.117513810683574, 0.08028761536947318, 0.06691642464803797, 0.17079087400010654, 0.12107274042708532, 0.12369073208953653, 0.07698957555528198, 0.10768562448876244, 0.12394596982215132, 0.15244032868317195, 0.20448800868221692, 0.09906337144119398, 0.15067151002585888, 0.18243848399392196, 0.2531402994479452, 0.16137356790048735, 1.698751068540982, 59.258038248334614, 79.75224331447056, 67.36613437107631, 55.598105907440186, 52.327390807015554, 28.93354787145342, 34.07170425142561, 47.66070965358189, 58.76445211683001, 29.990547793252126, 0.5356451517769268, 0.18162304774991103, 0.7315508595534733, 1.6386164724826813, 4.0503464085715155, 11.613896574292864, 4.371899051325662, 17.607428312301636, 65.0055672781808, 63.930771282741, 62.79720047542027, 66.72648320879254, 65.19088963099888, 64.260192326137, 63.92890221732003, 62.135718073163716, 60.48055294581822, 60.24101379939488, 59.58488845825195, 60.53021172114781, 59.69708102090018, 58.583375113351, 54.9166648047311, 59.06279386792864, 56.48524495533535, 59.94174098968506, 56.99733413968767, 53.02814442770821, 48.5647953578404, 46.91258321489607, 46.627825192042756, 55.45431988579886, 56.14754165921892, 55.2665239742824, 52.11869124003819, 54.570651463099885, 54.264277594430105, 55.0790650503976, 52.38788182394845, 53.78451142992292, 57.54785033634731, 50.021120412009104, 44.10955136162894, 43.488604749952046, 42.32291242054531, 41.983340059007915, 40.947825704302105, 42.228361334119526, 39.962564195905415, 44.07922942297799, 41.18950489589146, 43.20145654678345, 41.538366998944966, 45.62879582813808, 45.87023183277675, 51.6001923424857, 50.382829734257285, 59.903782980782644, 38.99726138796125, 36.12636995315552, 55.988309792109895, 52.27977132797241, 56.099435806274414, 49.67412737437657, 45.087343556540354, 44.69796303340367, 51.50472409384591, 51.49767862047468, 52.66193962097168, 52.23211015973772, 42.100813252585276, 43.77937643868582, 53.558351039886475, 55.55959899084908, 50.94628347669329, 51.27003479003906, 55.26248707090105, 45.12724706104824, 41.73976748330252, 40.201509271349224, 43.10120446341378, 53.35559218270438, 55.95314495904105, 54.977322578430176, 52.778224672589985, 54.386131627219065, 48.979689666203086, 48.65622322899954, 55.24555083683559, 56.87669604165213, 53.68072271347046, 44.58930362973894, 43.08916670935494, 47.87055219922747, 49.55678619657244, 55.05913414273943, 53.74594892774309, 52.31685038975307, 52.444252559116904, 58.145277295793804, 58.651168687003, 60.99662344796317, 52.59849909373692, 66.00308540889195, 57.15885543823242, 61.3273229598999, 58.874178068978445, 59.92506531306675, 17.082293885094778, 0.571070922272546, 6.574338606425694, 15.07929151398795, 2.9523015235151564, 0.21013728768697806, 0.10280827406261649, 3.291392070906503, 25.93937976019723, 43.93360560280936, 51.01566471372332, 43.23525605882917, 30.251546451023646, 25.914060524531774, 53.36907516207014, 56.076128074101035, 61.38097694941929, 61.14375850132534, 7.640340788023813, 0.29065533354878426, 0.19904151665312902, 0.10855279224259512, 0.11363710263477904, 0.16480217820831708, 0.16348592883774213, 0.11389895608382565, 0.1549921360399042, 0.2905320573065962, 0.15146475817476, 0.17838971982044832, 0.20598069072834083, 0.08844713467572417, 0.2253904834921871, 0.1694935014737504, 0.16166604363492557, 0.08807590138167143, 0.055593354560967, 0.057567786292306015, 0.201808826731784], [0.01675868689614747, 0.011202231481937426, 0.03427156885819776, 0.03710166038945317, 0.07218166640294449, 0.06938673994903054, 0.05205199548176356, 0.027630782253774147, 0.027911349698635082, 0.12313822816525187, 0.03677742921614221, 0.04569607314520648, 0.05889120777802808, 0.021230799245781133, 0.07542119614247765, 0.015755460996712958, 0.04403537225776485, 0.0676918476819992, 4.663475428308759, 48.818880558013916, 60.73697621481759, 56.71611622401646, 47.52722781045096, 26.84774555478777, 20.910191978727067, 36.59874323436192, 40.980343273707796, 34.352717195238384, 5.714779998574938, 0.023892149295923964, 0.06001729770962681, 0.06529332138597965, 0.6491522810288838, 3.0674292658056532, 3.100011323179517, 0.8011340828878539, 40.9037115914481, 61.717221123831614, 59.7857608795166, 59.82280172620501, 60.76153809683663, 56.751628467014854, 57.27937194279262, 58.66548892429897, 57.99871894291469, 52.30962773731777, 52.28144236973354, 54.853908675057546, 56.43007973262242, 54.84112398965018, 51.83359970365252, 50.19670139040266, 54.24117136001587, 56.06763390132359, 55.063476766858784, 53.34040342058454, 50.29342726298741, 44.75553233282906, 45.87016582489014, 48.64461278915405, 50.917194843292236, 54.008444922310964, 50.48800114222935, 50.4024201801845, 52.78151117052351, 50.347199371882844, 50.07646976198469, 47.41889844621931, 50.66619464329311, 49.176087447575156, 47.54451840264456, 38.00810888835362, 39.58927570070539, 37.50483349391392, 38.663087776729036, 36.56637157712664, 37.81380251475743, 35.06563711166382, 37.33142382758004, 35.9031069619315, 36.87085553577968, 39.83627373831612, 42.090814794812886, 42.99103730065482, 47.841762338365825, 46.22033418927874, 56.87601164409092, 36.60819625854492, 27.01774886676243, 48.97845983505249, 46.06485087530953, 51.19322592871529, 46.64359065464565, 49.10527835573469, 38.40227672031948, 40.478096212659565, 43.71009942463466, 44.15173387527466, 43.08708572387695, 37.38460533959525, 38.46410526548113, 49.22674676350185, 48.826012883867534, 45.00850582122803, 48.59254993711199, 49.534409523010254, 39.296572412763325, 37.95610162190029, 37.61442395618984, 42.58283758163452, 49.06498922620501, 50.52407271521432, 49.025954246520996, 50.48123707090105, 50.71744108200073, 49.64615045275007, 49.412204606192454, 52.019644669124055, 51.72266476494925, 50.37118455341884, 42.30817529133388, 39.56333807536534, 38.64091607502529, 43.86550978251866, 47.00708218983242, 45.24596398217337, 45.77190440041678, 46.5983544077192, 51.91127014160156, 54.20069462912423, 55.657488686697825, 53.34291172027588, 54.75134631565639, 52.701596464429585, 51.128708430698936, 53.32335948944092, 58.09077910014561, 44.941445282527376, 7.452207020350865, 0.28887111214654787, 2.753213486501149, 2.0512778035231998, 0.24807739683559962, 0.036935035937598774, 0.055618507854108296, 9.859293171337672, 32.00449357713972, 31.68550177982875, 51.06984329223633, 49.502767426627024, 18.86354970932007, 29.607570035117014, 38.15232917240688, 47.77733516693115, 48.17930235181536, 14.595278263092041, 0.2269875377948795, 0.03735222980113966, 0.041717737513993464, 0.05144793985943709, 0.10422897032861199, 0.03775050610836063, 0.04313485111509051, 0.09342357157064335, 0.01891225526508476, 0.05528058384412101, 0.08375890552997589, 0.013370705568896872, 0.03420942862118993, 0.04949172679334879, 0.052478475097034655, 0.06378972849675588, 0.049994280362235646, 0.07119399082979985, 0.01898532670124301, 0.03095490325774465, 0.012898703887393432, 0.031177734157868793, 0.02373577920453889, 0.042218957761568685, 0.04387778589235885, 0.05479808098503521, 0.04394977167248726, 0.10112641645329339, 0.03023946950478213, 0.015745893652950014, 0.048696158054683886, 0.0315027931439025, 0.053706321532705, 0.05383629152285201, 0.0538795718790165, 0.02165735180356673, 0.05225040590656655, 0.02890145612348403, 6.10066340650831, 62.384672028677805, 67.42452008383614, 63.99172782897949, 53.18560103007725, 34.43782220567976, 25.962579795292445, 32.943368911743164, 33.54070554460798, 40.959008829934255, 7.57749433176858, 0.10104246810078621, 0.02438498624334378, 0.9629492142370769, 1.0971638751881463, 3.7785215888704573, 2.3640950407300676, 0.5360106378793716, 44.21105064664568, 64.59905597141811, 61.66623524257115, 61.23149340493338, 62.272541999816895, 59.7137428011213, 59.56894929068429, 61.02758462088448, 59.23421287536621, 54.55884299959455, 54.870723315647666, 56.35953119822911, 58.22943735122681, 56.07639210564749, 54.916195801326204, 51.74427713666643, 55.3004937171936, 57.84002556119646, 56.29039314814976, 54.946399620601106, 51.556234564099995, 48.00228657041277, 46.99749367577689, 51.35805456978934, 52.31691639763968, 54.50526891435896, 52.48209244864327, 51.78416327067784, 51.72887298039028, 50.013043131147114, 51.56413466589791, 49.56324107306344, 52.394680636269705, 53.042339597429546, 49.59220116479056, 41.53186001096453, 40.87554012026106, 39.18683951241629, 39.72120462145124, 38.94447244916643, 39.86983701160976, 37.044383321489605, 39.245635168892996, 38.84280988148281, 38.968989167894634, 41.93708937508719, 44.96675756999424, 45.76450456891741, 50.27722406387329, 48.45861298697335, 57.295470918927876, 38.571941307612825, 30.214363166264125, 51.82986504690987, 47.927447523389546, 54.04138980593, 50.65932634898594, 51.825716972351074, 40.175373622349326, 42.28695549283709, 45.27827310562134, 45.019814014434814, 44.8542697089059, 41.50241354533604, 39.431443895612446, 51.1631714957101, 51.322688238961355, 48.13751935958862, 51.15744618007115, 52.18071780885969, 41.71056073052542, 40.11243683951241, 40.02856860842024, 43.74409348624093, 50.78812163216727, 52.162979057856965, 50.84910944529942, 51.88719810758318, 52.288908209119526, 52.14999287469046, 51.209067821502686, 54.16893788746425, 53.436642919267925, 52.75224535805838, 42.53998109272548, 41.501225403376985, 41.11441918781826, 47.22327538899013, 48.68784448078701, 47.05961751937866, 46.47343969345093, 48.56227316175188, 53.03243841443743, 56.6305387360709, 57.02205235617501, 53.256941659109934, 57.12972164154053, 53.1853335244315, 53.45686217716762, 56.09536763599941, 59.239034925188335, 48.48128495897566, 9.546961222376142, 0.5850240992648261, 3.6665908864566257, 5.157666487353189, 0.6909731083682605, 0.19827682125781262, 0.07388985117099114, 9.357565488134112, 36.90986272266933, 30.91409887586321, 42.393707615988596, 46.17321845463344, 22.487087385995046, 34.21621983391898, 45.02270099094936, 51.903665338243755, 56.03791993004935, 19.965626069477626, 0.16327767286981854, 0.04563991419438805, 0.04294857968177114, 0.036194364074617624, 0.04253815081236618, 0.03482064278796315, 0.12648069166711398, 0.08940302088324513, 0.036495179004435024, 0.05583080789074302, 0.02852561218397958, 0.03756997847397413, 0.06512734493506805, 0.03133455717137881, 0.05842012805598123, 0.13730177815471376, 0.05765875069690602, 0.07119084921266351, 0.030122503638267517, 0.05477901754368629, 0.09019276779145002, 0.06720245429979903, 0.14355717892093317, 0.10859515996915953, 0.1575003271656377, 0.14418804006917135, 0.12388708655323301, 0.14699942778263772, 0.17638394316392286, 0.21296152685369762, 0.14755665431065218, 0.1354017308247941, 0.2602994410055024, 0.1152411119214126, 0.13986539202077047, 0.08502324697162424, 0.16039502540869371, 0.16123657168022223, 9.247069154466901, 76.17406695229667, 75.07708535875592, 73.16685880933488, 62.026339530944824, 39.50534493582589, 28.12820128032139, 50.90717206682478, 52.47680139541626, 50.916979449135916, 9.235738379614693, 0.42420562729239464, 0.16410954323198113, 1.1169965309756142, 2.788660590137754, 8.464404957635061, 9.75502416065761, 2.3543375985963, 46.14624554770333, 66.12698568616594, 63.26591205596924, 62.48990249633789, 65.25946835109166, 61.68483557019915, 62.26582309177944, 64.41948672703334, 62.65271963391985, 57.37779664993286, 57.780448232378276, 59.35817568642752, 60.853038924080984, 59.43225737980434, 57.41816220964704, 54.93928466524397, 59.13508987426758, 59.10219015393938, 59.259358406066895, 57.11785759244646, 53.95503759384155, 51.295135157448904, 49.42212315968105, 54.860519886016846, 55.39622252328055, 56.60411473682949, 52.79047087260655, 52.92825017656599, 54.85043110166277, 51.96891239711216, 52.84199871335711, 50.41195658275059, 52.74002347673689, 53.79660824366978, 51.669476304735454, 44.10859945842198, 43.25788981573922, 41.26004648208618, 43.62024532045637, 42.4138434955052, 41.64811379568917, 40.296796866825645, 41.29833453042166, 41.91748850686209, 40.36487879071917, 46.00241436277117, 45.693414075034006, 47.67495346069336, 51.64343098231724, 49.65526301520211, 59.94276237487793, 41.904783725738525, 34.72423389979771, 54.74340105056763, 52.45679405757359, 56.059237003326416, 51.283938135419575, 53.12582915169852, 41.665974140167236, 44.20206315176827, 48.03695808138166, 48.576919964381624, 47.62910577229091, 43.14318895339966, 41.42134543827602, 54.20573207310268, 52.06900119781494, 50.28564180646624, 52.53827210835048, 54.98215505055019, 43.68813616888863, 40.878187383924214, 41.93233333315168, 46.5637697492327, 54.27254942485264, 54.696518080575125, 51.681868416922434, 54.04910578046526, 53.62886830738613, 53.96979904174805, 53.4637165750776, 54.32696076801845, 55.952071462358745, 54.91557741165161, 46.461638178144185, 43.79020520618984, 43.287155628204346, 49.781768866947715, 53.07598277500698, 49.786966119493755, 51.92302301951817, 51.443736280713765, 56.40726184844971, 59.02523190634591, 59.12848908560616, 54.37371172223772, 60.89736843109131, 55.721151556287495, 56.13148089817592, 59.2093939099993, 62.96477018083845, 51.50599561418806, 11.782313091414315, 2.434665722506387, 11.835985319955007, 9.134484887123108, 0.692302439893995, 0.31496770467076984, 0.2745176266346659, 13.559760434286934, 47.53857421875, 44.54246234893799, 59.61309119633266, 53.656768798828125, 28.34616105897086, 41.017953872680664, 52.64945718220302, 57.83695445741926, 62.31464113507952, 23.0994998727526, 0.30831572732755114, 0.20000112801790237, 0.18128688793097222, 0.11151066209588732, 0.25773474148341585, 0.16926041112414428, 0.31847076384084566, 0.1891277264803648, 0.11029004545084067, 0.17086411507001945, 0.16068085149994918, 0.09508314608995404, 0.16487141592161997, 0.15955521618681295, 0.10247604296143566, 0.19450986624828406, 0.1606439527656351, 0.186995498037764, 0.10161511094442435, 0.09055849138115134], [0.017918120038562586, 0.017790099140256643, 0.03671291410656912, 0.053115283604711294, 0.04119464808276721, 0.01809468842111528, 0.03779991024306842, 0.029147560774747814, 0.04101850717727627, 0.042358837755663056, 0.010513555757435305, 0.05036445853433438, 0.04539522768131324, 0.08310472313314676, 0.03311618317716888, 0.021294554396133338, 0.07354827664260354, 0.04789292187030826, 22.789076941353933, 61.08761705671038, 54.51926953451974, 50.65710987363543, 33.170293603624614, 25.56382962635585, 18.957935776029313, 36.6593245778765, 43.29967280796596, 27.453692742756434, 0.8774546161293983, 0.02453275420702994, 0.08741341371621404, 0.25501368035163197, 0.269979828702552, 2.651572197675705, 1.3637496445860182, 7.686267512185233, 58.35432774680001, 59.528809547424316, 58.598605564662385, 55.70725515910557, 56.47810220718384, 54.06294311795916, 53.538621629987446, 53.08385508401053, 48.12233754566738, 43.496011529650005, 48.09193570273263, 53.70343637466431, 56.10502910614014, 57.166328225817, 51.87886026927403, 54.03357308251517, 54.839244501931326, 52.523705210004536, 53.71269484928676, 52.349680628095356, 49.34367104939052, 46.006767409188406, 47.521523339407786, 48.738625390189036, 52.84940896715437, 52.53501340321132, 51.007198333740234, 51.26820393971035, 50.6668929372515, 49.91993727002825, 52.513633796146934, 47.30349581582205, 48.893483366285054, 50.59876585006714, 45.70989172799246, 39.683156285967144, 38.155772004808696, 38.66509928022112, 36.56211233139038, 36.45038529804775, 37.645958355494905, 35.802972997937886, 37.860682010650635, 35.905907085963655, 38.48072188241141, 40.78064162390572, 45.8541259084429, 44.14164161682129, 49.313401222229004, 47.51936592374529, 55.177500179835725, 35.5825275012425, 26.336180959429058, 46.617798941476, 41.930165495191304, 49.05403886522566, 47.65854181562151, 51.003692967551096, 44.76237978254046, 39.44649369376046, 40.10703808920724, 39.950113024030415, 38.70151131493704, 36.35433340072632, 38.13145678383963, 49.3735066141401, 50.76821851730347, 48.14965091432844, 49.12792600904192, 48.08158983503069, 38.485314641680034, 38.519993100847515, 37.01868193490164, 42.04074607576643, 49.18198994227818, 51.53015102658953, 47.1539740562439, 52.646379130227224, 50.52325977597918, 50.33266374043056, 49.571832520621165, 51.424156257084434, 50.550715582711355, 50.547140734536306, 40.70246049336025, 39.03033133915493, 38.853061948503765, 41.8219507762364, 42.44860533305577, 44.2014273915972, 42.86716134207589, 47.19605582101004, 50.85885081972395, 55.110512597220286, 55.03730637686593, 53.554466996874126, 54.68569278717041, 51.28069680077689, 47.74161795207432, 54.21999325071062, 53.03823668616158, 57.636769907815115, 32.75744901384626, 4.790510645934513, 2.066668280533382, 0.9417658937828881, 1.5722194867474693, 0.1267847024968692, 0.1045244112610817, 1.9904506674834659, 24.311772925513132, 31.528757367815288, 33.01801688330514, 15.491724422999791, 19.745682580130442, 23.9260801587786, 40.41156373705183, 47.29995223454067, 46.73796108790806, 32.209573132651194, 1.7610825981412614, 0.10130150562950543, 0.04094734920987061, 0.016973256632419567, 0.03503895803753819, 0.10391124630612986, 0.03826473047956824, 0.020939826466409222, 0.06410702504217625, 0.015078758022614887, 0.02288942551240325, 0.06998988972710711, 0.019952194998040795, 0.08743902841316802, 0.0450718378914254, 0.04002142032342298, 0.03974210816834654, 0.019169070591617907, 0.059375105026577196, 0.033816441494439325, 0.04193812568805047, 0.05268537738759603, 0.036296978925487826, 0.02225228282622993, 0.06547048009399857, 0.039861971379390786, 0.022979451842339974, 0.055961347850305695, 0.022816849406808615, 0.010088050688084747, 0.04815620363556913, 0.015311290277168155, 0.052489124704152346, 0.05250399140641093, 0.0071515317873231, 0.06924168273274388, 0.07825515193066426, 0.04388988417174135, 30.276288986206055, 70.02985831669399, 60.21054594857352, 58.157669407980784, 40.52399948665074, 31.455481665475027, 22.020793778555735, 34.93711280822754, 44.181711878095356, 33.55409819739205, 0.9179742847170148, 0.06969399417617492, 0.1235937015818698, 0.8634297315563474, 2.2142606122153143, 3.509414166212082, 1.3181449260030473, 8.216838904789515, 62.01295730045864, 62.850312505449565, 62.01891885484968, 57.6091126033238, 59.15510068620954, 57.820167609623496, 56.65711212158203, 54.97116300037929, 51.344734873090474, 45.62951149259295, 50.62888281685965, 57.88039806910923, 57.65080526896885, 57.537400245666504, 54.42670215879168, 55.02850995744978, 57.18259048461914, 54.16495656967163, 54.74693073545183, 54.56930698667254, 52.5733813558306, 47.45329897744315, 49.00430713381086, 50.678246293749126, 53.31410796301705, 52.07015112468174, 52.88859333310808, 51.25689574650356, 51.72375563212803, 51.417701380593435, 52.363851479121614, 49.321315220424104, 51.0025360924857, 52.53469378607613, 48.08950730732509, 41.66531753540039, 39.22106286457607, 40.51526212692261, 39.67644085202898, 36.40985645566668, 40.50054236820766, 38.16632284436907, 39.9666462625776, 38.02325596128191, 40.895936557224815, 44.25370216369629, 48.19723217827933, 46.45835862840925, 50.73195934295654, 49.08243267876761, 57.550942284720286, 36.01964214869908, 28.079878296170914, 50.3840526172093, 45.01744467871529, 51.69421189171927, 48.88919980185372, 54.168277808598106, 48.80439008985247, 40.960047585623606, 42.54289933613369, 40.664123807634624, 40.4813688141959, 38.38409675870623, 39.97495630809239, 50.90585538319179, 52.83611706324986, 50.66025740759713, 52.746933460235596, 50.68749782017299, 40.045998164585654, 40.223642757960725, 38.945615427834646, 42.796894209725515, 51.54592343739101, 53.35396977833339, 48.436298847198486, 52.94082989011492, 52.071825640542166, 50.8350636618478, 50.6559008870806, 53.562328883579795, 52.21401357650757, 51.22163711275373, 42.10439852305821, 41.11854294368199, 40.96794073922293, 43.52847351346697, 44.5346873147147, 46.27155630929129, 45.58447674342564, 48.195581981113975, 52.42277567727225, 55.715447085244314, 55.60373394829886, 55.088351317814414, 56.45125436782837, 51.86411966596331, 49.88855920519148, 57.49111829485212, 55.999357427869526, 59.08539635794503, 36.44156108583723, 6.336704569203513, 1.132795648915427, 4.664081658635821, 4.446851440838405, 0.43309687876275604, 0.03382870262222631, 1.046993755868503, 26.694471767970494, 34.48514291218349, 35.61243254797799, 23.431873900549753, 25.021878821509226, 30.668949059077672, 44.21666479110718, 53.77457203183855, 53.593682629721506, 41.99848018373762, 2.4467896776539937, 0.11032604173357997, 0.03130357865510242, 0.05354776486222233, 0.021365310331540446, 0.012605280748435428, 0.03578669684273856, 0.00526691519189626, 0.033804489100085836, 0.023122219002938697, 0.04126817074471286, 0.04254083102568984, 0.07923874950834683, 0.05814906010138137, 0.017474215644012605, 0.031448252499103546, 0.04138801699238164, 0.023139747258807932, 0.050004906220627685, 0.02383738982358149, 0.1113717049094183, 0.1396312838686364, 0.11975570395588875, 0.18082344851323537, 0.2239843960851431, 0.12956115922757558, 0.09864369753215994, 0.13478777876922063, 0.12364684444453035, 0.09170577196138245, 0.1545846757612058, 0.09436744092298405, 0.13104487104075296, 0.1610297542065382, 0.12660164731953824, 0.16213284858635493, 0.11555891058274678, 0.10685245812471424, 36.42860269546509, 79.73386532919747, 68.33143370492118, 65.55336325509208, 47.244269371032715, 37.57075800214495, 26.341600554330007, 49.80580268587385, 54.977690832955496, 41.88079159600394, 1.8817806243896484, 0.15449513628014497, 0.23077849937336786, 1.9721391243594033, 3.769489799227033, 8.697440590177264, 4.673832152570997, 9.324049983705793, 62.432246344430105, 63.39883804321289, 64.55020318712506, 59.46272523062569, 61.04703262874058, 58.28265013013567, 57.45398017338344, 57.20275068283081, 52.645128454480854, 48.108277865818565, 53.57682977403913, 59.83403696332659, 60.567308153424946, 58.82086454119001, 57.007009506225586, 58.47940921783447, 58.01226793016706, 54.91918700081961, 54.96669183458601, 57.3318065234593, 54.06074748720442, 50.361623832157676, 50.81783560344151, 51.89421231406075, 56.67940541676113, 53.91728455679757, 53.67670318058559, 55.182183265686035, 55.10832044056484, 54.43122543607439, 54.77712760652815, 49.06513166427612, 52.29774284362793, 55.29461554118565, 48.519982951028005, 43.33583470753261, 41.06567062650408, 43.771573611668174, 42.63582801818848, 39.52005079814366, 42.68609823499407, 40.55886902127947, 41.33439220700945, 41.13691050665719, 42.548892157418386, 46.74156720297677, 48.95264727728707, 48.35385847091675, 52.711671352386475, 52.51121582303728, 58.60553291865757, 38.813950538635254, 31.98717519215175, 52.64964130946568, 47.416629859379356, 54.39262124470302, 51.1491812978472, 55.83284384863717, 50.6200829233442, 43.128590788160054, 44.63204894747053, 43.157832281930105, 43.4833345413208, 40.281524726322715, 42.29022114617484, 54.65478719983782, 55.48364128385271, 52.05365610122681, 54.11861555916922, 52.53996399470738, 43.72035843985421, 41.777930464063374, 40.353515011923655, 45.57572896139962, 54.49137599127633, 56.10229498999459, 49.55264854431152, 55.348505769457134, 54.279129368918284, 53.69881929670061, 53.62370579583304, 55.92086015428816, 54.487137590135845, 54.37035921641758, 44.53981508527483, 43.29919685636248, 43.27292571749006, 44.711571080344065, 47.593416350228445, 48.746323994227815, 48.272279671260286, 51.78814458847046, 54.82974978855678, 59.1881810597011, 58.714341708592, 57.36523083278111, 60.00739451817104, 55.228256770542686, 51.58888414927891, 59.87551770891462, 58.72314507620675, 61.047894205365864, 39.98334278379168, 7.728854758398874, 5.892962643078395, 9.143649561064583, 4.763353177479335, 0.47061511554888313, 0.16642326622137002, 2.847329224858965, 33.655145849500386, 44.983360290527344, 45.60830211639404, 23.90349677630833, 28.762662138257706, 34.954806395939414, 53.122758047921316, 60.59926986694336, 61.61001736777169, 46.689813545772004, 2.298423924616405, 0.22368107736110687, 0.14312499282615526, 0.09086018840649299, 0.11267230047711305, 0.13110862619110517, 0.17178038161780151, 0.12110060107495103, 0.17111667937466077, 0.1173352338373661, 0.16902407737714903, 0.11425079006169524, 0.1274405744458948, 0.17073082365095615, 0.0650441904685327, 0.15594288573733397, 0.09238321453865085, 0.12928652896412782, 0.150868543024574, 0.19346465090555803], [0.057290801512343545, 0.01148690830450505, 0.028623253373163085, 0.01389939121768943, 0.04242513741233519, 0.035830693053347726, 0.02447921270504594, 0.03192196154434766, 0.03062370352979217, 0.02445525024086237, 0.03490594481783254, 0.03307557964165296, 0.02915992707546268, 0.03361373933564339, 0.03118880106402295, 0.05823908134230545, 0.21943143968071255, 0.9155937667403902, 48.483682087489534, 60.56246525900704, 59.10729707990374, 53.08144058500017, 42.63728713989258, 19.77716486794608, 31.22382525035313, 34.77951029368809, 35.14014611925398, 17.33551229749407, 0.06182435181524072, 0.0859619594578232, 0.31946975737810135, 0.6369820769344057, 1.135562009045056, 2.2998750124658858, 0.8223390078970364, 17.446615730013164, 66.96922547476632, 58.72293663024902, 60.47980254037039, 53.361216749463765, 50.79252331597464, 43.81253671646118, 45.51013796670096, 42.07631390435355, 42.619534492492676, 40.520111969539094, 43.022738456726074, 51.41337265287127, 55.75034441266741, 51.845192773001536, 56.19119371686663, 49.40797315325056, 52.86625140053885, 51.078844683510916, 49.883004120418, 51.9247670173645, 48.92414576666695, 48.708463260105674, 50.148102215358186, 50.17119107927595, 55.18763412748064, 52.55428075790405, 51.92712245668684, 47.929153306143625, 50.22926412309919, 47.901506423950195, 50.22739505767822, 50.77547243663243, 48.989861828940256, 49.41568217958723, 46.99836914879935, 38.2297807421003, 38.37657880783081, 35.68741055897304, 37.732157707214355, 34.7413056237357, 39.28726182665144, 35.678958075387136, 37.486254010881694, 34.82338816779, 41.19184643881661, 42.92701659883772, 47.46216140474592, 45.45955508095877, 49.49618748256138, 46.903585297720774, 56.864376885550364, 33.23432125364031, 28.027377707617624, 49.74984884262085, 44.81677375520979, 48.9660017149789, 42.5052296774728, 51.05430364608765, 48.7920674596514, 45.85349709647042, 36.18753147125244, 40.95242888586861, 36.04885932377407, 37.35315431867327, 37.245325224740164, 47.63650212969099, 50.13588728223528, 49.02291093553816, 49.813358851841514, 45.96885803767613, 38.95596129553658, 37.621003900255474, 36.52955307279314, 41.802805015019004, 49.681141580854145, 51.4058130128043, 48.590257031576975, 50.24026312146868, 50.36830105100359, 47.49659320286342, 47.039339201790945, 47.66653919219971, 49.36300441196987, 46.821203981127056, 39.92057275772095, 38.77051387514387, 38.55644335065569, 40.75923074994768, 41.91998985835484, 42.1616655758449, 41.37809985024588, 45.68569115230015, 51.5765198298863, 52.2030736378261, 56.898926803043906, 54.204199995313374, 52.4873001234872, 46.45950855527605, 45.15602649961199, 52.211901324135916, 54.47264017377581, 56.10146120616368, 51.63211236681257, 22.253853729793004, 3.2354180344513486, 4.0612285903521945, 0.7241047248244286, 0.10381173914564507, 0.09292393909501177, 0.013234100354436253, 12.32330765042986, 36.24540649141584, 24.923612185886928, 32.64852557863508, 14.391908832958766, 25.439006975718907, 33.12351138251168, 43.85472617830549, 45.110213552202495, 47.245582580566406, 7.0867882285799295, 0.3292102632778031, 0.026578345602112155, 0.07294012606143951, 0.024181927853663052, 0.0017836408307110624, 0.05935158021748066, 0.07658260382179703, 0.021859110798686743, 0.034300688188523054, 0.05081959607611809, 0.018283339816012552, 0.041455592294888835, 0.013928722590208054, 0.06584841731403555, 0.09142557092543159, 0.013358490242223655, 0.012133459726880704, 0.01351063814945519, 0.010856316025768007, 0.037747808931661506, 0.004660229822288134, 0.01694574373375092, 0.021149464949433292, 0.025920494027169685, 0.024867268578548516, 0.022406327238838588, 0.01853988881755088, 0.06615787677999053, 0.024666863260790706, 0.022748205411647047, 0.02140050594295774, 0.02683372243440577, 0.04220651003665157, 0.027408982726878355, 0.07853510190865823, 0.14915464499167033, 1.843348183802196, 57.994612557547434, 67.95966339111328, 64.29321711403983, 59.711957114083425, 50.76655094964163, 28.172932045800344, 26.708052022116526, 33.88752835137503, 44.121693338666645, 20.10273139817374, 0.017361870600974987, 0.05683240021712013, 0.48519759305885857, 1.659304408090455, 3.0322996079921722, 2.0894933300358907, 0.3310554714075157, 19.517477682658605, 68.19509615216936, 60.127278736659456, 63.49556391579764, 55.36578941345215, 53.55118744713919, 46.001441614968435, 46.353753498622346, 44.21765143530709, 43.8944525037493, 42.06737157276699, 44.49116727284023, 53.45394393375942, 58.14526687349592, 54.04799059459141, 57.676937443869456, 52.575590882982524, 53.85576868057251, 51.29942914417812, 52.56913948059082, 55.733008657182964, 51.89205837249756, 50.91482203347342, 51.218687602451865, 52.33909157344273, 55.62417902265276, 52.885171345302034, 53.53369535718645, 49.28603574207851, 51.12286499568394, 49.71073743275234, 53.041790689740864, 52.14960030147007, 50.62695469175066, 52.44898428235735, 48.30145515714373, 40.23630584989275, 40.24673857007708, 38.844564301627024, 39.219652380262104, 36.346836294446675, 40.41465221132551, 36.12910059520176, 38.77407135282244, 37.02067606789725, 43.35279526029314, 45.22966350827898, 49.726561955043245, 45.51737451553345, 51.31892926352364, 48.170561517987935, 58.40258298601423, 34.850218636649, 30.615044934409006, 51.53281218664986, 46.25161845343453, 50.50606993266514, 45.46815695081438, 53.0966397694179, 49.57313878195626, 47.405672550201416, 38.92477083206177, 42.52879101889474, 38.66434192657471, 39.73341608047485, 39.03171750477382, 50.78681884493147, 51.80564362662179, 51.712499550410676, 50.697892325265066, 47.71356807436262, 40.11563995906285, 40.02653973443167, 37.02691207613264, 43.08318083626883, 50.54387160709926, 52.54951776776995, 49.12058176313128, 52.038401331220356, 52.54492500850132, 51.48548105784825, 48.36813701902117, 50.79584455490112, 52.17414133889334, 48.49740130560738, 41.79910857336861, 40.73903233664376, 39.659337861197336, 43.75106600352696, 43.992755617414204, 44.78673321860177, 44.44219289507185, 49.22779941558838, 53.53399412972586, 54.65917498724801, 57.40356404440743, 56.287440163748606, 54.32963582447597, 48.34717777797154, 47.59382281984602, 53.58149896349226, 56.402106285095215, 58.90251977103097, 53.633659090314595, 24.943982567105973, 2.0297896308558325, 2.046905432428632, 3.2544938794204166, 1.5655074183429991, 0.12189751331295286, 0.057355771240379126, 12.478597283363342, 42.163506848471506, 26.373398985181534, 30.5112110546657, 15.995573043823242, 29.44872031893049, 39.31046186174665, 47.73395756312779, 49.490059171404155, 56.68680872235979, 9.97087516103472, 0.23988769629171916, 0.041962698833750825, 0.09129311410444123, 0.04715684029672827, 0.0576301979433213, 0.0730581572279334, 0.10215262603014708, 0.021423265703820756, 0.0111972620610946, 0.06571892569107668, 0.02208697303597416, 0.051007855617042096, 0.009332456143705972, 0.04282482507239495, 0.05486733226903847, 0.033660049350666146, 0.025171859555744698, 0.0517450364173523, 0.016911202908626626, 0.146907418434109, 0.06792899567101683, 0.09698355304343359, 0.14910629258624145, 0.08285553114754812, 0.1264800809855972, 0.07918629196605512, 0.1322587566184146, 0.12379347586206027, 0.11404515323894364, 0.40299535542726517, 0.19118112272449903, 0.11557807241167341, 0.09461969988686697, 0.1162094763879265, 0.13859465877924645, 0.328576457287584, 2.4222885923726216, 67.22724682944161, 74.73950713021415, 74.31986372811454, 67.08815084184918, 55.6699607031686, 27.682335376739502, 43.72357892990112, 47.721350056784495, 51.11164712905884, 24.24294059617179, 0.18746226227709226, 0.16614005927528652, 1.029713043144771, 4.066097974777222, 4.160619965621403, 8.59960126876831, 3.082432380744389, 21.38989908354623, 70.35668768201555, 61.47331156049456, 66.30367837633405, 56.59022181374686, 56.00739301953997, 47.8529246194022, 49.78142493111746, 46.11705616542271, 45.91886922291347, 44.623426233019146, 46.18583985737392, 55.4370744568961, 60.307271821158274, 55.60711424691336, 58.53395257677351, 55.88406596864973, 53.923332963671, 52.22006893157959, 53.53277472087315, 57.467716761997764, 53.791209493364605, 53.9729118347168, 53.785970551627024, 54.83539867401123, 58.7453167779105, 55.89376565388271, 55.378674847739084, 51.96603236879621, 54.04089995792934, 51.31674058096749, 55.80236904961722, 53.81262731552124, 51.040237018040244, 53.45505911963326, 51.85100146702358, 41.54714604786464, 42.53480468477522, 41.31272077560425, 41.66966363361904, 38.84428637368338, 43.550791127341135, 39.60914060047695, 40.96403932571411, 38.33256196975708, 46.28500802176339, 47.60467938014439, 52.11805547986712, 48.67041839872088, 52.36170448575701, 50.90401063646589, 59.7521732875279, 37.87318181991577, 34.19799470901489, 53.57467235837664, 47.948128836495535, 52.77130079269409, 47.302950382232666, 56.37880897521973, 51.806268964494976, 49.7535001209804, 40.81007766723633, 45.91062865938459, 40.675914900643484, 41.85982540675572, 40.852093424115864, 52.609685693468364, 54.16663455963135, 52.723754269736155, 54.64279808316912, 50.323241983141216, 42.92293105806623, 41.81759078162057, 39.12866224561419, 47.4919240134103, 53.894900935036794, 54.399611132485525, 48.9692291532244, 53.36443723951067, 56.02200160707746, 53.62226057052612, 51.29407555716378, 52.60681956154959, 53.309216431209016, 51.238719258989605, 44.3878128187997, 43.72570160457066, 42.79134259905134, 46.13347823279244, 46.48264953068325, 45.95754984446934, 46.66955607278006, 51.25545399529593, 56.762676102774485, 57.18441786084856, 60.01567677089146, 58.06720733642578, 56.917551449366975, 50.7568165234157, 50.86583375930786, 56.3950434412275, 60.66452734810965, 61.0628536769322, 55.3903408731733, 26.700028589793614, 4.893390451158796, 9.792391572679792, 7.154362065451486, 2.1356910339423587, 0.1356032421546323, 0.142288332006761, 16.167804990495952, 49.90255287715367, 35.062006677900044, 44.435209955487935, 21.734920569828578, 36.279160840170725, 44.98050110680716, 57.03246423176357, 54.53379821777344, 64.61752428327287, 11.210649183818273, 0.38194725343159264, 0.07217034843883344, 0.14518195816448756, 0.08196456038526126, 0.22220956560756477, 0.16960867600781576, 0.2323163039982319, 0.08160908267434154, 0.08790018795324223, 0.16981486922928266, 0.09603656243000712, 0.13472270726093225, 0.08188110736331769, 0.1341502679777997, 0.17677205162388937, 0.15499269243861946, 0.056175001564302614, 0.1441070365586451, 0.17303192588899816], [0.05552519911101886, 0.033845269054706605, 0.02521995920687914, 0.03145412861236504, 0.02508648288702326, 0.051234910397657325, 0.04967430021081652, 0.008646859271850969, 0.04585479944944382, 0.03972700737150652, 0.042296127549239566, 0.007237138309782105, 0.027124133726049746, 0.030191408869411265, 0.04012911400890776, 0.020041919379894222, 0.0891213406409536, 10.885947704315186, 57.14470543180193, 53.72580262592861, 55.05281823022025, 35.834562982831685, 26.49953137125288, 13.276405079024178, 38.83480903080532, 36.98993723733084, 38.499704360961914, 6.391464625086103, 0.1355463537786688, 0.07728747956986938, 0.1480590823505606, 0.5985830745526722, 1.8455149361065455, 1.4832977439676012, 0.2411108235163348, 40.18312086377825, 61.84746510641915, 62.47174685341971, 58.06755127225603, 54.16031864711216, 55.66229336602347, 54.239462103162495, 48.95145913532802, 46.99022238595145, 41.5709992136274, 40.48538139888218, 40.24573108128139, 49.48091881615775, 53.742950780051096, 55.9810836655753, 54.14761734008789, 59.929699761526926, 49.59579685756138, 48.383697509765625, 49.63348388671875, 51.26796422685896, 52.07327781404768, 50.613478660583496, 50.78706898008074, 50.85506405149187, 53.420050621032715, 52.81400442123413, 49.75834648949759, 47.321470805576865, 45.796459334237234, 46.21470614842006, 47.83911854880196, 49.86222900663103, 49.638952119009836, 48.57959154673985, 46.07159062794277, 39.24982145854405, 37.66428075517927, 35.023204462868826, 37.336968490055625, 37.410386630467, 38.079015254974365, 34.696138858795166, 36.85407216208321, 35.67059244428362, 44.721739768981934, 47.13718720844814, 50.332149573734824, 48.33065843582153, 49.195851598467144, 44.759531021118164, 54.950481687273296, 33.219181128910606, 25.37143053327288, 50.6652774810791, 44.02628067561558, 49.81138556344168, 46.659526348114014, 47.27352476119995, 47.763136523110525, 48.69116224561419, 39.691389901297434, 38.07231371743338, 38.37513358252389, 36.274057388305664, 35.51729433877127, 43.62872907093593, 48.20766837256295, 48.87375395638602, 45.13187803540911, 42.14176593508039, 37.45471266337803, 37.37566300800869, 37.37284551348005, 39.09217725481306, 47.50808204923357, 52.334363324301584, 48.72161272593907, 49.4921783719744, 49.76305736814226, 46.41779851913452, 43.488302503313335, 45.77864415305001, 45.26428985595703, 41.738339628492085, 38.07041685921805, 38.151398113795686, 38.63221345629011, 37.21614626475743, 40.377593994140625, 42.01784133911133, 41.95427227020264, 47.573752948216026, 51.362313815525596, 55.08326523644583, 53.616507462092805, 55.144742897578645, 50.55172654560634, 43.93081937517439, 43.308531761169434, 50.6300813811166, 53.80691589627947, 55.9823134967259, 56.48126711164202, 47.286424091884065, 12.282276800700597, 2.9048527095999037, 4.756281648363386, 1.3413855646337782, 0.2897058187850884, 0.1010715908237866, 0.9558108087096895, 29.510062490190776, 40.442705563136506, 34.33858455930437, 23.279275826045446, 11.372973867825099, 20.7210168497903, 41.49400969914028, 45.77967596054077, 47.410122871398926, 20.906773465020315, 0.22821987952504838, 0.044851151161960194, 0.04144001652353576, 0.06098214736474412, 0.1097433158595647, 0.041908728158367534, 0.046808283642998764, 0.029228130022862127, 0.02864798597459282, 0.0066260182897427255, 0.06141287460923195, 0.040225866317216835, 0.0634985351935029, 0.022568629422624196, 0.026429746433028152, 0.03427583684346505, 0.04490148149696844, 0.04240714944899082, 0.020948426897770593, 0.012319659065854336, 0.036179734859615564, 0.004924280452542007, 0.019805997842922807, 0.032801051158457994, 0.020855202971558486, 0.028872940689325333, 0.06299865165991442, 0.03822978253343275, 0.011927989145208682, 0.011260034183838537, 0.010875932473157133, 0.011078608338721097, 0.02943076772083129, 0.0659451356955937, 0.09840792018387999, 0.10050014898713146, 14.10778830732618, 67.18325778416225, 58.9057993207659, 62.692880221775596, 43.559545857565745, 36.26102604184832, 18.040323666163854, 41.21869775227138, 34.27322285515921, 45.36555985042027, 8.211556536810738, 0.45765091691698345, 0.03374246421403118, 0.72828330631767, 2.6857742709772925, 3.818094185420445, 1.1225982989583696, 0.9701673069170543, 41.77428265980312, 63.920022419520784, 64.01838111877441, 61.316039085388184, 57.06601013456072, 56.90824433735439, 53.69149936948504, 52.34120035171509, 48.35651963097708, 43.9759236063276, 42.83700616019112, 42.801414012908936, 52.35700402941023, 55.10027095249721, 58.0007860319955, 55.014554500579834, 60.977613176618306, 52.77471235820225, 50.215631757463726, 51.663011005946565, 53.243788719177246, 54.77273634501866, 53.35648850032261, 53.365194593157085, 53.21207019260952, 54.5835542678833, 55.07150193623134, 52.86735616411482, 49.26010159083775, 47.44344643184117, 48.187084334237234, 49.33113302503313, 52.61387545721871, 52.153133460453574, 51.00492279870169, 49.4053293636867, 40.18637956891741, 38.10707902908325, 37.47342416218349, 39.55581317629133, 39.62215110233852, 39.26101500647408, 36.85466275896345, 37.97460814884731, 37.04352174486433, 45.43003913334438, 49.0709090914045, 53.575433186122346, 49.50405979156494, 51.607282979147776, 48.09022991997855, 57.90968472617013, 33.655830247061594, 27.934056452342443, 52.752728257860454, 44.86330236707415, 50.44986942836216, 46.110080174037385, 50.31501184191023, 49.546124185834614, 52.42227193287441, 40.8947240965707, 40.49792637143816, 41.11631257193429, 38.63343981334141, 38.30507837023054, 45.678774220602854, 51.43620790754046, 49.894628456660676, 47.1892535345895, 43.19874674933297, 38.55359806333269, 39.99027361188616, 40.13723496028355, 41.61171565737043, 49.46546254839216, 53.79403741019112, 50.32768535614014, 50.98143788746425, 52.274706091199604, 47.90878118787493, 45.189370904650005, 47.158268042973106, 48.17598806108747, 44.04833773204258, 40.68480512074062, 40.06637028285435, 41.81615250451224, 41.209498337336946, 42.348009313855854, 42.51722921643938, 44.34449427468436, 50.23157092503139, 51.91242354256766, 56.91423715863909, 56.695170879364014, 56.93803473881313, 53.21798310961042, 45.59163686207363, 46.179787976401194, 53.64808007649013, 58.066019194466726, 56.99565962382725, 57.59254114968436, 50.18625477382115, 16.607808351516724, 1.351527329002108, 0.7281766406127385, 2.393916057688849, 0.4200526944228581, 0.05660631913425667, 0.7196719912546021, 31.89333282198225, 42.2080135345459, 32.34503868647984, 24.10025065285819, 21.669237511498586, 27.023411648614065, 47.02551923479353, 50.75158452987671, 54.241657733917236, 29.509162698473247, 0.380368600998606, 0.047688720149121115, 0.028101015503385236, 0.016215974232181907, 0.020627841153847318, 0.020216513225542646, 0.029798397993935005, 0.02115430629679135, 0.01791858483505036, 0.0706747622628297, 0.02084741847855704, 0.04526439255901745, 0.06432356592267752, 0.04266822936811617, 0.011105960085322815, 0.060378149417894225, 0.03377460981053965, 0.07892707801823105, 0.03204198421112128, 0.1125279828639967, 0.21939027974648134, 0.09865705788667713, 0.09492749015667609, 0.08177958495382752, 0.12503212796790258, 0.18084737365799292, 0.14713831033025468, 0.1274864434131554, 0.13156909362546035, 0.1001900720543095, 0.09328766100640808, 0.0767078749569399, 0.11919769032725266, 0.11372846737504005, 0.186092842902456, 0.15413866112274782, 17.671937125069753, 75.0971656526838, 67.23994813646588, 72.75553240094865, 50.705684729984824, 39.63771506718227, 20.208515984671457, 52.36625902993338, 47.71039274760655, 53.37466498783657, 8.891450796808515, 0.42695553973317146, 0.1943770633744342, 1.3894241069044386, 4.059865006378718, 8.631450942584447, 6.863622077873774, 0.8724328598805836, 45.538201740809846, 63.826555252075195, 68.30286271231515, 63.05744525364467, 59.288255964006694, 59.47766385759626, 57.78872006280081, 53.19591563088553, 52.29339327130999, 45.56456668036324, 44.6093213898795, 43.520194734845845, 55.27270439692906, 56.96669953210013, 61.67555972508022, 54.85784830365862, 61.46763488224575, 58.46563788822719, 51.95386954716274, 52.01583010809762, 55.53863280160086, 58.54322842189244, 54.6720187323434, 53.994878564562114, 53.667812960488455, 56.28798907143729, 57.58656569889614, 53.65106780188424, 51.737735407693044, 49.12389257975987, 50.49548782621111, 52.049511500767295, 54.284781728472026, 52.16531017848423, 51.407463209969656, 51.72311292375837, 43.58296823501587, 41.75587340763637, 38.49969046456473, 41.248918942042756, 42.72399023600987, 42.92074932370867, 38.67329468045916, 39.21634503773281, 39.76061480385916, 46.82556050164359, 51.63407870701381, 56.36213329860142, 53.25415890557425, 53.363144874572754, 50.57103211539132, 58.76238850184849, 37.12326969419207, 31.758301530565532, 53.51606777736119, 46.49699408667428, 52.734343324388774, 48.578087261744905, 49.824371746608186, 52.288828304835725, 53.63323525020054, 43.19937556130545, 42.74954571042742, 43.66242436000279, 40.6051162311009, 40.20791551045009, 48.53928852081299, 52.614726611546104, 52.81991733823504, 48.91260133470808, 46.17466715403965, 41.00103153501238, 43.39846576963152, 42.18848214830671, 43.578128814697266, 52.42635399954659, 56.57154158183506, 50.28272008895874, 52.103724820273264, 56.12497043609619, 50.9912348474775, 47.80172681808472, 51.2904485974993, 49.70043325424194, 46.964701652526855, 43.43377651487078, 42.41886704308646, 43.85987479346139, 42.95818274361746, 45.98435599463326, 46.58139385495867, 47.158584186008994, 54.31969295229231, 54.666324683598106, 59.99303259168352, 58.398719787597656, 60.57112966264997, 55.961006845746724, 47.8827462877546, 47.80881398064749, 56.415064675467356, 58.853562763759065, 59.878220558166504, 59.890636989048545, 52.341269833701, 17.068630252565654, 5.255596569606236, 11.068589789526802, 6.160261579922267, 0.5447110853024891, 0.1646521134035928, 1.1050829759665897, 39.855829443250386, 53.997973987034385, 48.95765345437186, 34.13334172112601, 19.676829406193324, 31.19668906075614, 57.05937807900565, 58.80253519330706, 64.44486154828752, 32.77374948774065, 0.4718107485345432, 0.15742256705250057, 0.1064834843522736, 0.1417748031339475, 0.19435117047812256, 0.20885375727500233, 0.16968457693500177, 0.1318105435264962, 0.08127523665981633, 0.19639930129051208, 0.1042668597240533, 0.14933869083012852, 0.22424139800880635, 0.10702215973287821, 0.04132374954809036, 0.10653545334935188, 0.1296232044696808, 0.21887679158576898, 0.17132910154759884], [0.013950669805386236, 0.03087092437116163, 0.007205653436748045, 0.03374319024650114, 0.029368437494018247, 0.0368427008922611, 0.07335655657308442, 0.03692035243979522, 0.09180738258042506, 0.0493878023698926, 0.03108149753617389, 0.04908302140289119, 0.04215043251003538, 0.05554986046627164, 0.03187679486083133, 0.003870596144614475, 0.30484795197844505, 21.610957758767263, 63.045542989458355, 56.11324882507324, 53.62317773274013, 44.68209334782192, 25.273507833480835, 25.163969482694352, 28.098798240934098, 39.11072547095162, 29.16590084348406, 0.7167552134820393, 0.0768554766795465, 0.09280619291322571, 0.20135990796344622, 1.4723343551158905, 2.9315151189054762, 0.676628552377224, 11.640877297946385, 57.52558135986328, 56.57076685769217, 59.22397123064314, 63.26081902640206, 59.275721413748606, 56.770152364458355, 54.640102182115825, 55.769163608551025, 54.959965978349956, 47.51796933582851, 39.414264474596294, 39.82301657540457, 43.25450951712472, 53.17711727959769, 53.59067405973162, 50.933582169669016, 56.01771804264614, 61.570801734924316, 50.02519900458199, 49.29492596217564, 48.01780884606497, 53.3167656489781, 54.573639188494, 52.62004198346819, 50.38326399666922, 52.90667601994106, 56.52676044191633, 49.94027117320469, 46.11903987612043, 40.400137424468994, 42.31652007784162, 49.34348692212786, 49.17348882130214, 49.167450836726594, 48.94956227711269, 45.79542057854788, 38.523526259831016, 36.268339020865305, 34.550539357321604, 38.5007882799421, 36.789419174194336, 36.55635922295706, 35.02090808323452, 37.10959563936506, 38.90076480593, 47.93941232136318, 46.565499850681846, 52.80304363795689, 47.91706691469465, 52.71827561514718, 47.17771257672991, 55.68490627833775, 31.985340867723735, 24.248438358306885, 49.36581495829991, 44.626118659973145, 48.824873379298616, 45.15465423039028, 48.87494557244437, 44.352477754865376, 51.963923590523855, 44.570800576891216, 38.51282603400094, 38.277059759412495, 38.33636958258492, 34.12675135476248, 40.759206431252615, 43.87438610621861, 45.07988466535296, 42.47787809371948, 39.286480154309956, 35.73600278581892, 37.243584700993125, 37.138343811035156, 39.27802072252546, 43.36603505270821, 51.03599166870117, 49.550126348223, 50.55994973863874, 49.960382734026226, 46.82285417829241, 40.80727406910488, 40.55084385190691, 39.24985619953701, 40.96774966376168, 37.175342968532014, 38.87061309814453, 38.08854123524257, 39.48270770481655, 39.31675692967006, 39.7770368712289, 42.05010182516915, 45.85497011457171, 48.28503656387329, 54.65083367483956, 53.54365907396589, 52.22723599842617, 43.83271081107003, 42.95648043496268, 44.26020220347813, 51.069207532065256, 53.801732540130615, 55.30293253489903, 55.26832355771746, 57.79804801940918, 37.13111073630196, 6.189686332430158, 1.3830097253833498, 1.1859036620174135, 0.39287581986614634, 0.09729811509272882, 0.04464975179040006, 14.591725996562413, 37.25701209477016, 31.54700333731515, 22.2676910672869, 10.092119489397321, 31.20594753537859, 39.22757332665579, 47.39565324783325, 46.222724369594026, 42.224293163844514, 3.260570513350623, 0.21123339315610273, 0.024210204104227678, 0.031123481890452758, 0.0576377771794796, 0.10479732483093228, 0.03923368527154837, 0.041126567271671126, 0.03909427346661687, 0.0463089938275516, 0.029728512279689312, 0.05529246159962245, 0.013422775498059179, 0.03125151127044644, 0.035035222702260525, 0.08463277042444263, 0.05163006205111742, 0.07833640649914742, 0.042614526714065244, 0.00258411983044685, 0.06049932220152446, 0.06144378866468157, 0.009257488202170601, 0.026255958347714374, 0.05205059091427496, 0.07761204322533947, 0.03271431402702417, 0.03674571109669549, 0.060797802970877717, 0.06641662253865174, 0.04991826408409646, 0.012853792502677866, 0.06716470061136143, 0.01057284529919603, 0.018436286698228548, 0.5009373256138393, 29.53681305476597, 73.88872800554547, 62.307658195495605, 59.43995598384312, 48.42100586209978, 30.28898334503174, 22.725533928189957, 24.4037219115666, 40.82995298930577, 34.84298208781651, 0.7428421708089965, 0.047662827252809487, 0.1379798517695495, 1.4832538834639957, 2.1215460215296065, 1.084074011870793, 0.5885130177651132, 13.851893101419721, 58.06074898583548, 55.84896714346749, 61.605855396815706, 64.29022938864571, 61.48886857713972, 59.12759971618652, 58.37365068708147, 59.34357057298933, 58.17864254542759, 48.6494904245649, 42.653792585645405, 41.24744244984218, 45.68524299349104, 54.85416923250471, 54.98328413282122, 52.689433642796104, 55.01247698920113, 62.66487203325544, 52.416008131844656, 51.7552170753479, 49.09309121540615, 54.618819849831716, 56.077045236315044, 54.30247531618391, 50.75400250298636, 54.29495736530849, 56.59362643105643, 51.37517840521676, 49.31867143086025, 42.311381884983604, 44.298948832920615, 50.91546821594238, 51.74466276168823, 48.927619865962434, 51.580087729862754, 48.23367895398821, 39.37020247323172, 37.79180799211775, 37.707015650612966, 39.64085912704468, 37.89496442249843, 38.9413492338998, 37.85003737040928, 38.583371094294954, 41.06622995649065, 50.21856737136841, 49.07371963773455, 54.34740236827305, 48.35394532339913, 54.95199292046683, 48.29906497682844, 57.996071679251536, 33.4959591456822, 26.95568755694798, 52.34815897260393, 45.99510138375418, 50.33440773827689, 46.244764055524556, 49.51886640276228, 46.96541731698172, 53.04593529020037, 46.84873969214303, 40.785505362919395, 38.58258247375488, 40.34843240465437, 35.157071931021555, 41.061446121760774, 46.09331069673811, 46.918162618364605, 43.761422293526785, 40.58553968157087, 38.301670278821675, 38.227897780282156, 38.75310516357422, 41.742609296526226, 46.504324436187744, 52.05252007075718, 51.19937508446829, 51.19021735872541, 50.887317589351106, 48.729311329977854, 43.67945439474923, 41.614248275756836, 40.83912461144583, 42.32023736408779, 39.370918137686594, 40.209280831473215, 39.88435179846627, 40.75263343538557, 41.80163771765572, 42.42902878352574, 44.22393260683332, 47.63846499579293, 50.37812580381121, 56.73717621394566, 54.73309687205723, 55.451217515128, 46.1668678011213, 44.335138525281636, 46.65068129130772, 52.45215613501412, 55.57125111988613, 57.86424003328596, 57.57127966199602, 59.09576307024275, 40.66295998437064, 8.182411449296133, 1.3415597038609641, 4.3359399523053845, 1.2891351112297602, 0.06720841862261295, 0.04075027549905436, 15.159041200365339, 42.74507801873343, 27.387994050979614, 24.701907328196935, 15.6067362172263, 38.84387295586722, 45.11974648066929, 52.01609066554478, 52.63606105531965, 52.4034457887922, 5.550518069948469, 0.22361532731779984, 0.07355835288763046, 0.08471852368009941, 0.04775748288791094, 0.10137058049440384, 0.06238323396870068, 0.030058039418820823, 0.02162075332099838, 0.059468797141952176, 0.06474908201822213, 0.01676412365798439, 0.008566105971112847, 0.02888217894360423, 0.050607380856360705, 0.024049189440639954, 0.046237703545817306, 0.03392341932547944, 0.0585971578423466, 0.06549403204449586, 0.13876600244215556, 0.19511947567973817, 0.11222169215657882, 0.13283874121095451, 0.12218608068568365, 0.16211516596376896, 0.13421215037150042, 0.1592603520091091, 0.22994034577693256, 0.14244013386113302, 0.15443930641881057, 0.10949577949941158, 0.15714302419551782, 0.15773518170629228, 0.13391012086399964, 0.7430513767259461, 37.56468180247715, 82.19961425236293, 72.21882574898856, 69.02685805729458, 58.09638977050781, 37.42359168188912, 36.595147541591096, 39.80540984017508, 52.814942428043906, 40.79217563356672, 1.3110584148338862, 0.24692337161728314, 0.23753176842417034, 1.9923640276704515, 4.901546333517347, 10.140959245818001, 3.749011286667415, 14.244845867156982, 60.01068101610456, 55.60227482659476, 62.866119657244, 63.667295592171804, 63.77650737762451, 62.435942786080496, 60.733613286699565, 61.02208859579903, 60.55282115936279, 50.80571794509888, 43.4144674709865, 43.5130797794887, 47.9878134727478, 57.51850809369768, 58.266797815050396, 55.53062152862549, 57.097732135227744, 61.78696019308907, 56.64692258834839, 51.99735484804426, 49.2576766695295, 55.97324957166399, 60.211324146815706, 54.97121511186872, 52.665365082877024, 54.631646224430625, 59.13295677730015, 55.410025119781494, 50.98356056213379, 43.24132183619908, 45.88016775676182, 54.46129029137747, 53.560261794498985, 50.526928424835205, 54.54859093257359, 49.6794045312064, 42.47064501898629, 39.25788484300886, 40.17781244005476, 43.26077331815447, 41.05248294557844, 40.809758050101145, 39.80821691240583, 41.17535488946097, 43.09016030175345, 52.00064134597778, 51.65427712031773, 57.00542879104614, 51.170814514160156, 57.11986909593855, 51.181438309805735, 58.43264784131731, 34.64406558445522, 29.217355728149414, 53.06633867536272, 48.63098042351859, 51.848743302481516, 47.63244090761457, 50.975101130349294, 48.920056751796174, 56.341924462999614, 49.5363723891122, 42.15426574434553, 41.25678082874843, 42.71368258340018, 36.33048718316214, 44.598016670772004, 48.42213841847011, 50.53199366160801, 46.971132210322786, 43.783726011003765, 39.55309990474156, 41.61380359104702, 40.94571345193045, 44.89834908076695, 47.91570159367153, 55.47010966709682, 52.40441506249564, 52.56290694645473, 54.860947200230186, 51.510192326136995, 45.63713019234793, 44.94609362738473, 43.1632136617388, 45.35420649392264, 41.41350787026541, 44.80405855178833, 42.16100549697876, 43.13535485948835, 44.05689096450806, 45.04232965196882, 47.65522405079433, 49.656169755118235, 52.54203455788748, 59.4659491947719, 58.15569611958095, 58.029273646218435, 51.028508458818706, 46.988249097551616, 48.363460881369456, 55.77875907080514, 58.340716225760325, 60.93184539249965, 59.89629977090018, 62.343629019601, 42.69302211488996, 9.006534678595406, 3.5067404125417982, 7.5634320463453015, 1.2644634693861008, 0.19482292873518808, 0.09682833137256758, 19.16108546938215, 49.49760144097464, 43.71325738089425, 33.08806167330061, 14.559157184192113, 44.25476523808071, 50.41841493334089, 61.628708021981375, 57.003313064575195, 59.99854251316616, 6.141139703137534, 0.35799507583890644, 0.1566099263727665, 0.13099376378314836, 0.13094592706433364, 0.27598567785961287, 0.16493513035987103, 0.2544554088796888, 0.11800540930458478, 0.1441519284354789, 0.1731721790773528, 0.08780961709895305, 0.04464067638452564, 0.1273318324238062, 0.18215474779052393, 0.14689377988023417, 0.10781183878758124, 0.11225540177630526, 0.12334922541465078], [0.041444725556565185, 0.023096692515537143, 0.05856523955506938, 0.03856810687908104, 0.029193918287221874, 0.043782516183065515, 0.040493032695459466, 0.036102697386273315, 0.10066079893814665, 0.03713464397670967, 0.04813295702583023, 0.03753326294411506, 0.036752808572990556, 0.050631947216710875, 0.02245243708603084, 0.08523497025349311, 3.7345807467188155, 48.69685282026018, 54.30887460708618, 56.39094400405884, 42.606405871255056, 30.57056256702968, 16.019533906664165, 25.421422822134836, 49.14495604378836, 39.57861021586827, 17.997050285339355, 0.6675441626991544, 0.026470709592103958, 0.10795565428478376, 0.6473648026585579, 1.8999694883823395, 1.6536101422139575, 2.780345767736435, 55.25620937347412, 63.75617694854736, 59.82699843815395, 54.497865608760286, 55.015867710113525, 55.29402494430542, 58.40135315486363, 58.87879862104143, 58.169728006635395, 53.871780804225374, 54.85341535295759, 43.74901628494263, 40.21706976209368, 39.28228344236101, 48.169144085475374, 51.9349113873073, 53.46232346126011, 49.31971366064889, 55.087632179260254, 53.02632399967739, 52.02008587973458, 51.96323224476406, 51.425563267299104, 49.787000860486714, 50.04117291314261, 50.71120854786464, 51.374636445726665, 49.458177362169536, 50.066037041800364, 41.43177121026175, 38.94545909336635, 42.144170011792866, 47.736003807612825, 49.74940415791103, 50.76672812870571, 49.68813146863665, 46.6280197416033, 38.135611806597026, 37.47720398221697, 36.42857142857143, 37.538264751434326, 34.98203638621739, 35.75351224626814, 35.0903205871582, 38.237861497061594, 45.288295882088796, 50.354324749537874, 46.67773757662092, 52.286719526563374, 47.42200081689017, 53.62594658987862, 45.222128186907085, 53.8594651222229, 30.178152629307338, 25.683913605553762, 50.87532499858311, 42.434927804129465, 47.819225856236045, 44.37324939455305, 46.078764642987935, 43.88640301568167, 46.37950004850115, 49.66539001464844, 45.138246059417725, 37.00720698492867, 39.05967010770525, 34.8956355367388, 36.01273911339896, 37.91341188975743, 41.27205644335066, 38.4251571382795, 36.684699399130686, 35.94100243704659, 36.422168663569856, 36.60877643312727, 36.820998736790244, 42.77805069514683, 51.139985357012065, 48.88074731826782, 52.048646450042725, 48.47792897905622, 47.92100306919643, 39.08551393236433, 38.14419283185686, 37.68260315486363, 38.36208833966936, 37.45308331080845, 38.831856046404155, 37.86586536679949, 38.518158776419504, 38.462753840855186, 41.79928227833339, 40.27053615025112, 43.75468601499285, 44.926412854875835, 48.3796432358878, 47.3364337512425, 42.985068798065186, 41.001250403267996, 43.05811868395124, 48.370944091251914, 52.86963517325265, 52.91882841927664, 55.19564887455532, 54.2964894430978, 56.655580043792725, 51.52595084054129, 20.257278442382812, 1.1629330260413033, 1.2699711109910692, 0.6345742547086307, 0.06734979817909853, 0.15973686001130513, 1.3243949392012186, 37.022020544324604, 35.27137327194214, 36.65815033231463, 21.63673904963902, 16.898020710263932, 28.422216040747507, 39.8028598512922, 44.31581211090088, 45.2721517426627, 12.54292631149292, 0.2794117640171732, 0.0879521637356707, 0.05387536496190088, 0.035571906582585404, 0.05461878149903246, 0.04051277127915195, 0.060191389439361434, 0.040981337028954706, 0.01613667723722756, 0.030186258788619722, 0.04299551055633596, 0.012238039784798664, 0.02365291820439909, 0.03196251079706209, 0.07114058333848204, 0.018601313200114027, 0.04581123410857149, 0.04691418938870941, 0.029922956667308296, 0.03380272490903735, 0.03643274360469409, 0.047308601438999176, 0.06755679885723762, 0.0022875035480995265, 0.035664770885237625, 0.046096798963844776, 0.04428642003663948, 0.02485818469098636, 0.03710658655368856, 0.02905148360878229, 0.03275131454159107, 0.034786302130669355, 0.027182014459478, 0.06497787045581, 4.313487717083522, 59.66138117653983, 63.06968797956194, 61.62604686192104, 47.21718181882586, 40.77132061549595, 28.624606643404277, 30.41374519893101, 40.250104972294395, 43.620061193193706, 18.75955949510847, 0.15333942829498223, 0.025126014337209717, 0.2606006291295801, 2.2937510439327786, 3.563768186739513, 1.0722743421792984, 3.9008263860430037, 57.795796803065706, 64.16663483210972, 60.5469707761492, 54.81917463030134, 56.00497504643032, 56.817872592381065, 59.80379145486014, 59.229439462934224, 58.26152065822056, 58.584396498543875, 57.89636155537197, 44.92344944817679, 41.7032025882176, 41.1833244732448, 50.623414584568565, 53.427193369184224, 55.25585501534598, 52.03258221490042, 55.41706364495413, 55.04904188428606, 55.0253450529916, 51.59443228585379, 53.72583041872297, 51.12300395965576, 52.220663002559114, 50.1297277041844, 54.488245827811106, 53.49586936405727, 52.07859318596976, 43.144102641514365, 39.352884088243755, 43.771000385284424, 49.53588254111153, 51.15805067334856, 52.81638765335083, 51.15672009331839, 48.7180552482605, 40.84440176827567, 39.45994193213326, 38.24768624986921, 41.11929682322911, 37.048774582999094, 37.67950773239136, 37.0550731250218, 40.18132128034319, 48.23089272635323, 52.03681019374302, 49.3732773235866, 53.663147245134624, 49.44911343710763, 55.58897597449166, 47.26487077985491, 55.17300122124808, 31.61354970932007, 27.612203734261648, 52.73123400551932, 45.248659883226665, 48.35124594824654, 44.9150664465768, 47.375941208430696, 45.65484809875488, 49.54561696733747, 50.72796412876674, 45.8904823575701, 39.049015045166016, 39.974011353084016, 36.88815655027117, 38.31788042613438, 40.80052736827305, 44.00519636699131, 40.35922295706612, 37.68582017081124, 37.141324588230674, 38.37639815466744, 38.820485319410054, 39.57109921319144, 44.503528118133545, 51.730085441044395, 51.9164673941476, 52.12009825025286, 49.38974802834647, 49.19445848464966, 41.1634977885655, 39.66052600315639, 39.57513264247349, 40.175279821668354, 39.0164384160723, 40.53038140705654, 39.39817592075893, 40.87499816077096, 40.620621136256624, 43.179246629987446, 42.81308003834316, 44.94178921835763, 47.59662989207676, 51.1600969178336, 48.90641743796212, 45.028971740177695, 41.772792271205354, 43.89994158063616, 50.66606957571847, 53.24227053778512, 55.181943552834646, 56.85271780831473, 56.609186921800884, 58.05843870980399, 54.31975201198033, 22.466991458620342, 1.982128028358732, 1.6790596566029956, 3.7541429655892506, 0.21566951940102236, 0.15201967768371105, 1.0689985922404697, 41.54127482005528, 38.20005634852818, 30.805884156908306, 20.28558714049203, 24.364917959485734, 34.17198065349034, 44.668179580143516, 49.95923628125872, 53.33601563317435, 19.20472536768232, 0.3034018852881023, 0.019018091460955993, 0.03407016948663762, 0.05290815739759377, 0.04723948586199965, 0.05587122482912881, 0.0493572784720787, 0.010986693136926209, 0.022977704614666954, 0.026384700189477632, 0.03136408023004021, 0.03571572886513812, 0.012872423377952405, 0.0618289319266166, 0.03108419132019792, 0.009234806472834731, 0.02926613816193172, 0.04855542989181621, 0.20418942613261087, 0.08393241371959448, 0.16436396672257356, 0.16961957328021526, 0.158675522676536, 0.10624011419713497, 0.11101885312902075, 0.20060241861002787, 0.12505635166806833, 0.10786819112087999, 0.11286195780017547, 0.11907397982265268, 0.08406829714242901, 0.12948671036532947, 0.13936433462159975, 0.20707777328789234, 6.462316708905356, 70.50315570831299, 69.80200604030064, 71.6061544418335, 56.06452458245413, 44.63723577771868, 24.678550958633423, 36.56082344055176, 63.74878406524658, 54.22799062728882, 23.620706830705913, 1.2508697531052997, 0.21258285003049032, 0.47377133475882666, 2.2718952681337083, 9.895895412990026, 6.635205260344914, 3.7319091643605913, 60.55170944758824, 64.1273775100708, 61.93765272412981, 54.385360377175466, 58.37753473009382, 55.93857111249651, 60.57437447139195, 60.07140132359096, 61.62968076978411, 59.889983858381, 59.17838409968785, 48.26698514393398, 44.21029329299927, 42.468584878104075, 53.377652713230674, 56.92105334145682, 56.9721816607884, 54.63470343181065, 58.69179480416434, 54.61074604306902, 57.05643899100167, 53.89877108165196, 55.61180428096226, 52.661713804517476, 53.83012982777187, 51.46235745293753, 53.16224813461304, 54.44536502020699, 54.48848901476179, 45.01804569789341, 41.29226180485317, 45.319062505449565, 50.36332266671317, 54.07887881142752, 52.588865416390554, 53.18623331614903, 50.73335940497262, 41.65976939882551, 41.570325238364084, 40.40653671537127, 42.24469307490757, 39.16590806416103, 39.94600663866316, 38.66253539494106, 42.52191925048828, 50.36282239641462, 54.153839451926096, 51.69582734789167, 55.93892894472395, 51.05820158549717, 58.12653105599539, 49.71728263582502, 56.03568261010306, 33.535365853990825, 31.12302773339408, 54.08013990947178, 46.74780668531145, 49.0463159424918, 46.893562521253315, 47.967552525656565, 47.78696537017822, 52.29112121037075, 52.573190280369346, 49.24128586905343, 41.515392780303955, 41.673036984034944, 39.18661022186279, 40.451331751687185, 42.2016350882394, 47.4242068699428, 42.286489963531494, 41.09988008226667, 40.543291160038535, 41.07847615650722, 40.36150891440255, 40.894678933279856, 48.219532421657014, 56.10281263078962, 53.19146530968802, 54.6691004889352, 52.86160652978079, 51.853270053863525, 44.95205865587507, 42.528353282383506, 41.26773813792637, 43.14936590194702, 40.90683133261544, 43.46489749635969, 41.48700244086129, 42.81104074205671, 42.15925455093384, 46.69069249289376, 44.94508613858904, 47.86024454661778, 49.742879799434114, 53.2566567829677, 51.61236558641706, 47.249688965933665, 45.063959394182476, 47.837020192827495, 53.52777549198696, 57.42268548692976, 58.3029180254255, 60.01955386570522, 59.37626879555838, 61.00699710845947, 56.995468548366, 25.535529613494873, 2.6877195494515553, 4.9267439757074625, 4.3522308724267145, 0.15248682190264973, 0.20192652541611875, 1.8393590492861611, 50.181613377162385, 48.594707352774485, 50.84086193357195, 28.40245188985552, 25.644253287996563, 40.44640547888619, 54.1989506312779, 55.48676102502005, 61.7993140901838, 22.49726128578186, 0.3861971896673952, 0.13892970580075467, 0.20627391285129956, 0.0969262168343578, 0.12688283223126615, 0.14190094279391424, 0.1393724770418235, 0.15689769307417528, 0.15015332640281745, 0.08882158422576529, 0.10085520600633961, 0.09047963204128401, 0.07847604222063508, 0.14833827236933367, 0.21569086611270905, 0.09764179986502443, 0.11754467045622212, 0.08415092913700001], [0.0491562115826777, 0.024315575503611138, 0.04404879028775862, 0.01939545531890222, 0.04357015507827912, 0.009832519489074392, 0.07292925593044076, 0.01613379007072321, 0.04261336981185845, 0.07377046293445996, 0.020322805736213923, 0.05457534847248878, 0.015674723811181526, 0.04827358680112021, 0.100685226198818, 0.016616018123126457, 8.734931332724434, 49.46739762169974, 58.83982617514474, 56.9683393069676, 41.881872040884836, 18.486839226314, 14.098882453782217, 29.283592905317033, 30.372740404946462, 42.60060065133231, 13.416096874645778, 0.035381350200623274, 0.053296842612326145, 0.19761659311396734, 0.9047976774828774, 1.8531041060175215, 0.6700610933559281, 39.097120898110525, 67.1518588747297, 58.20689739499773, 61.43902220044817, 60.98218509129116, 58.77193532671247, 50.01660755702427, 50.075719356536865, 51.93758644376482, 59.16140965053013, 53.681619031088694, 52.31377928597586, 48.08841296604702, 40.224903856004985, 37.82715695244925, 41.98635557719639, 50.23999561582293, 54.42128603799002, 52.63349717003958, 49.58621529170445, 46.361632755824495, 53.95580536978585, 50.97703272955758, 51.94255093165806, 50.88765457698277, 52.273702076503206, 52.75459732328142, 49.459907463618684, 49.19046674455915, 50.38336821964809, 38.20644869123186, 35.52172381537301, 41.00552701950073, 47.69288328715733, 51.85524681636265, 53.92986079624721, 48.97412763323103, 45.52405520847866, 37.48889432634626, 37.651610715048655, 36.53079332624163, 37.98810849870954, 35.37518630708967, 36.70233392715454, 34.668287004743306, 41.93698515210833, 48.490876947130474, 49.00896937506539, 46.19041524614607, 51.770947796957834, 50.23925910677229, 51.87425708770752, 45.37612458637783, 51.408071177346365, 30.801499843597412, 23.35535338946751, 47.68088722229004, 44.45177446092878, 49.96752200807844, 45.294392926352366, 48.364249501909526, 44.75631400517055, 46.53311429704939, 47.749073369162424, 47.12801211220877, 36.48873588017055, 36.926719052451, 36.29249790736607, 35.681306566510884, 36.60747364589146, 37.03099414280483, 37.25091505050659, 36.115589823041645, 36.049526350838796, 36.469100270952495, 36.619038922446116, 36.33483328138079, 40.42858682359968, 49.19708142961775, 48.955079146793906, 48.613279887608115, 47.98494039263044, 47.19613572529384, 39.3086588042123, 37.871205057416645, 37.40142692838396, 35.90045622416905, 37.293983459472656, 37.66403062002999, 39.77124902180263, 40.17899015971592, 39.19438525608608, 41.01211738586426, 40.916920116969514, 39.824871744428364, 40.66155644825527, 40.03265067509243, 40.41390527997698, 38.834770815713064, 40.99073430470058, 42.98676415852138, 48.3647324017116, 48.29403795514788, 51.06829731804984, 49.81094087873186, 51.920876026153564, 52.97310427256993, 58.12521437236241, 40.48135839189802, 4.166860750743321, 3.192951947450638, 2.7707298951489583, 0.1578778097672122, 0.09004775807261467, 0.0708600158936211, 17.299091577529907, 37.04791995457241, 33.77020454406738, 40.75264385768345, 15.937074422836304, 26.608512129102433, 34.75712667192732, 48.30535657065255, 46.93194784436907, 34.0046888760158, 1.4687562499727522, 0.06281769994114127, 0.08940781134047679, 0.011250774725340307, 0.013095092277840843, 0.03480479560260262, 0.06656644307076931, 0.03524409952972617, 0.0480830236338079, 0.044611825075532706, 0.04744668670796922, 0.04880914431331413, 0.02951019024476409, 0.0170675221098853, 0.04719143540465406, 0.032853467988648584, 0.023319129865350466, 0.021367958314450722, 0.07644969238234417, 0.02043866559064814, 0.08490305806377105, 0.01619692945054599, 0.026728442637249827, 0.03908735919477684, 0.02389992361090013, 0.023558908873902898, 0.047120776160487106, 0.0584180313827736, 0.029900079859154563, 0.0589766421222261, 0.04525995833267059, 0.01958954008296132, 0.017579661682248116, 0.07201461108135325, 12.258067539760045, 61.68245233808245, 63.69806916373116, 64.75181906563895, 49.68890271868025, 27.409726279122488, 16.81482298033578, 26.698272432599747, 34.12966612407139, 49.19047369275774, 12.483802352632795, 0.12133123512778964, 0.08527794866157429, 0.5623050640736307, 2.39888271689415, 0.9216962392841066, 1.0550067658935274, 40.94778054101126, 69.21553639003209, 62.316114153180806, 64.15721307482038, 61.676608903067454, 58.38132149832589, 52.06654500961304, 51.450965881347656, 54.20908110482352, 59.73072419847761, 55.32922451836722, 55.84157426016671, 48.545399461473735, 42.50900254930769, 39.74499177932739, 45.168036460876465, 54.07502603530884, 55.74456351143973, 52.59261744362967, 52.39093903132847, 48.32498870577131, 54.549254485539024, 53.09553500584194, 53.308882917676655, 53.84123304912022, 54.61974743434361, 53.76007114137922, 51.265560150146484, 50.86152935028076, 53.500288418361116, 40.06522383008684, 38.31208215441023, 43.72662571498326, 50.2945111819676, 52.43020330156599, 52.94241407939366, 51.6602213042123, 47.531591279166086, 39.43646049499512, 38.98109292984009, 38.36870302472796, 40.29533427102225, 37.28721591404506, 38.67772763116019, 35.87183312007359, 44.66063731057303, 50.20425408227103, 51.76288441249302, 49.03726243972778, 52.57711253847395, 51.45516954149519, 53.81702552522932, 47.952433245522634, 52.980323450905935, 32.01305375780378, 26.075019018990652, 49.48519195829119, 46.4418705531529, 51.19979545048305, 45.93640995025635, 49.590036800929475, 46.116632325308665, 48.25827210290091, 49.339040075029644, 49.864838055201936, 38.70196642194475, 38.86169508525303, 37.35527351924351, 37.44957447052002, 37.44174037660871, 38.619018827165874, 39.76823697771345, 38.584917068481445, 38.02419744219099, 39.090370723179404, 38.16274452209473, 39.173089027404785, 42.27690144947597, 52.12068884713309, 49.81241042273385, 51.46336841583252, 48.61076463971819, 49.82123116084507, 42.07410437720162, 39.77321188790457, 40.08399786267962, 38.370426177978516, 40.30639232907976, 38.734424931662424, 40.13570635659354, 41.76221711294991, 41.202859333583284, 41.29134464263916, 42.60779551097325, 41.294523443494526, 43.12704133987427, 41.862319810049875, 41.723220348358154, 40.697294507707866, 42.36671386446272, 44.695347036634175, 50.286069120679585, 50.73464829581124, 52.243244647979736, 53.22534472601754, 54.64965942927769, 54.931811877659385, 59.81118433816092, 42.95090103149414, 4.408608990056174, 0.3968115672469139, 5.23179030418396, 1.160430263195719, 0.25852230350886074, 0.052459320053458214, 18.15694570541382, 42.36761713027954, 29.365206445966447, 35.27929074423653, 20.51201503617423, 35.468924454280305, 41.44878387451172, 54.95498759405953, 52.88252060753958, 45.91543681280953, 2.19865864941052, 0.07000365720263549, 0.016633503970557025, 0.016969524689817002, 0.030442785737769942, 0.04060182900034955, 0.030586041443582093, 0.01986107792306159, 0.02337556701552655, 0.026956114884732024, 0.024961444150124277, 0.02612435139183487, 0.04079300963452884, 0.03981326274307711, 0.05744834377297333, 0.013431009520510477, 0.022855956772608415, 0.051059281786105463, 0.22280237451195717, 0.1390240764511483, 0.15326673005308422, 0.10345267876982689, 0.1457853793565716, 0.09109876131904976, 0.1800284226025854, 0.17557872565729277, 0.1623458814408098, 0.1403977841671024, 0.1170056015253067, 0.19801625023995126, 0.09905586684388773, 0.13163746281393937, 0.21280023907976492, 0.09867938168879066, 16.26460381916591, 71.93208054133824, 73.47801303863525, 72.33905042920793, 56.339773995535715, 30.609733036586217, 20.382050718579972, 39.19489247458321, 41.690744468144004, 57.306306634630474, 16.99353412219456, 0.2439658274607999, 0.23376150216375077, 1.106430600796427, 3.332331508398056, 6.101955337183816, 1.3824171743222644, 43.7559540612357, 70.3544225692749, 63.96863896506173, 65.96022891998291, 64.3432719366891, 60.160164560590474, 53.30278239931379, 52.823867389133994, 53.95474576950073, 57.609543391636436, 57.733120577675955, 58.37919534955706, 52.122443267277305, 44.17992966515677, 42.49387632097517, 46.7238701411656, 55.39628158296858, 58.421836444309776, 54.07309791019985, 55.177587032318115, 50.47503580365862, 57.689027309417725, 55.60713856560843, 54.71049785614014, 56.12155887058803, 56.46020017351423, 56.76726886204311, 55.82330397197178, 53.02187715257917, 55.964616434914724, 41.581695965358186, 39.65895223617554, 45.62164960588728, 51.824980463300435, 54.8550203868321, 54.445806230817524, 53.500177247183665, 50.80903223582676, 40.19251135417393, 40.8821895463126, 40.64194515773228, 41.78584793635777, 40.3729248046875, 42.45977456229073, 38.66559607642037, 45.33837502343314, 53.429312569754465, 52.90966027123587, 49.75921154022217, 55.68941913332258, 54.992018018450054, 55.567620686122346, 49.22035442079817, 53.04906892776489, 34.07933684757778, 29.665243557521276, 50.237292766571045, 48.37597458703177, 52.63782589776175, 47.48241192953927, 49.953830582754954, 46.90652091162545, 51.13587549754551, 52.4282717023577, 50.38899278640747, 41.94483661651611, 40.499190943581716, 40.03563492638724, 40.59851196834019, 40.542485169001985, 41.17065790721348, 42.297287464141846, 40.501212869371685, 39.31262275150844, 41.186687401362825, 40.02120699201311, 40.1118358203343, 45.20630019051688, 54.910314151218955, 52.143857615334646, 52.54888548169817, 52.29896572657994, 52.73397854396275, 44.21731097357613, 41.21816621507917, 41.31692443575178, 39.822255747658865, 40.619439942496165, 39.796846185411724, 42.7505601474217, 44.083294119153706, 43.63702522005354, 44.58619431086949, 44.73073421205793, 43.34217841284615, 46.0960065977914, 44.51779971803938, 44.82228715079171, 43.53769029889788, 44.13706622804914, 46.57324014391218, 53.22346871239798, 53.33107198987688, 54.86269467217581, 54.323361601148335, 56.93255261012486, 57.657093388693674, 62.770005226135254, 46.021080698285786, 6.594844477517264, 9.108241541045052, 11.303753307887487, 0.6037572569080761, 0.3215090536645481, 0.12301615971539702, 21.266342742102488, 50.894974504198345, 50.633447783333914, 54.66212102345058, 23.98665107999529, 38.74763693128313, 48.53075960704258, 62.209375926426475, 58.73037815093994, 53.601391656058176, 2.8335136004856656, 0.14467997795769147, 0.1773242298513651, 0.08731494471430779, 0.16276449683521474, 0.13742016894476755, 0.1742243426186698, 0.09425960813782044, 0.11172400707645075, 0.16265570053032466, 0.1363962867430278, 0.10524800779031855, 0.18343206282172883, 0.09313320608011313, 0.18768407537468842, 0.15664132897342953, 0.09725285002163478, 0.07046223830963884], [0.017450393975845406, 0.06813356040843896, 0.009512111012424742, 0.035322836733290126, 0.04348529748884695, 0.012764553273362773, 0.07627859299204179, 0.04161595386852111, 0.006929219966488225, 0.01117838012786316, 0.02664824149438313, 0.017384021376658763, 0.06461277790367603, 0.020138237425791364, 0.07788276512707983, 0.14451324833290918, 26.231117248535156, 59.217106410435264, 50.83245113917759, 45.983570848192485, 30.752921513148717, 19.99563012804304, 27.3471542767116, 47.04663481031145, 41.72572864804949, 43.17322254180908, 2.7424815595149994, 0.03983895547155823, 0.35752935654350687, 0.3373296675937516, 4.838547885417938, 1.6602640194552285, 11.979274545397077, 65.36312852587018, 58.44222245897566, 59.345342363630024, 55.03009762082781, 57.866578102111816, 58.442931175231934, 56.71386848177229, 54.21899618421282, 47.914822646549766, 52.20917763028826, 58.76901708330427, 48.881160736083984, 52.400649138859336, 42.941736357552664, 39.55695962905884, 38.58658811024257, 49.062585149492534, 54.04650368009295, 52.24346351623535, 48.961468015398296, 43.6604128565107, 43.13130405970982, 47.24639204570225, 47.31957394736153, 49.763092109135215, 48.19165277481079, 49.52371971947806, 50.9209885597229, 52.172327859061106, 42.99690505436489, 36.21960435594831, 35.50416224343436, 42.29756539208548, 48.604997634887695, 48.80573456627982, 49.7775547845023, 48.05501644951956, 42.72863163266863, 36.90732315608433, 35.22283315658569, 36.79793766566685, 36.51041425977434, 36.94347810745239, 36.15019185202462, 35.426057543073384, 46.016713755471365, 48.279919215611045, 47.90732206617083, 49.37132140568325, 50.287232943943565, 49.13505138669695, 50.89064577647618, 46.1551114491054, 50.19305011204311, 31.175368513379777, 23.377995831625803, 48.62371955599104, 43.8083677973066, 52.12737996237618, 44.97311864580427, 50.13823924745832, 45.63534450531006, 47.05388525554112, 45.12343944822039, 50.650453499385286, 41.169865812574116, 36.007840633392334, 36.047751086098806, 36.41977153505598, 36.17628581183297, 36.36459936414446, 35.69599158423287, 36.36353281566075, 36.234998089926584, 37.252203941345215, 36.02558980669294, 38.77421031679426, 40.55021851403372, 48.400397505079, 48.25593055997576, 52.06323071888515, 47.60022211074829, 48.26900012152535, 39.134543895721436, 38.67087670734951, 37.868922574179514, 38.9461087499346, 37.18080425262451, 38.47314139774868, 36.79704829624721, 39.06023985998971, 38.04001154218401, 40.38794681004116, 37.54933670588902, 38.36481550761631, 38.40788391658238, 39.24223402568272, 38.37467152731759, 40.57597548621041, 41.8265609060015, 44.15142468043736, 47.10764346803938, 46.33410051890782, 46.64732183728899, 50.5549887248448, 51.99335963385445, 52.54539053780692, 53.87686341149466, 53.33092607770647, 14.423315559114728, 0.42389686671750887, 4.523986867495945, 0.933911606669426, 0.07256518118083477, 0.07958790327289275, 3.6570692488125394, 41.84849289485386, 30.393682275499614, 33.41016973767962, 14.319212436676025, 20.657988003322057, 34.31844520568848, 43.09014293125698, 41.294752734048025, 48.41121932438442, 9.291703513690404, 0.4778638780117035, 0.034873755116547854, 0.04292804042675665, 0.017426187239055122, 0.03789810443829213, 0.0363689341715404, 0.051510100452495475, 0.07343542269830193, 0.014041957362288875, 0.029305720502244573, 0.025098160474694202, 0.026556408564959253, 0.008306345802598765, 0.031171142190162624, 0.04012569079973868, 0.0183469728300614, 0.01866224903746375, 0.019608177743586044, 0.03621792959581528, 0.0032248284301853603, 0.019952495249786546, 0.036111226571457725, 0.06344609800726175, 0.0318104918114841, 0.07239482817905289, 0.03684569323169334, 0.003382339944697118, 0.07575207695897136, 0.048047848378441164, 0.024982590693980455, 0.05526407847979239, 0.02964265045842954, 0.1914903854152986, 33.014508043016704, 67.79070404597691, 58.644206592014854, 52.64960656847273, 38.85517767497471, 25.325831242970057, 26.40237992150443, 35.6767589705331, 40.969392912728445, 50.0274988583156, 2.7321200583662306, 0.08680195866950921, 0.17861808756632463, 1.5795439737183707, 3.4469470381736755, 1.779494347316878, 14.165910857064382, 66.86137553623745, 60.68521908351353, 60.66562516348702, 57.0090765953064, 59.98040771484375, 60.459541593279155, 57.295571667807444, 51.88673605237688, 49.533749444144114, 53.651752199445454, 58.706087248665945, 53.894685540880474, 53.816542625427246, 44.8896290915353, 42.03868246078491, 40.392977305821006, 50.67548091070992, 54.88168062482561, 54.05062396185738, 51.886996609824045, 46.60020957674299, 45.272335869925364, 48.6089129447937, 50.11494541168213, 51.50524173464094, 50.11199590138027, 52.18113122667585, 52.52945831843785, 52.887686593191965, 45.344788210732595, 39.05309363773891, 37.32060200827462, 45.13740880148751, 51.701316424778526, 51.63349158423287, 51.67016070229666, 50.324794905526296, 46.13917922973633, 38.50602722167969, 38.96782881872994, 36.95993491581508, 39.481700216020855, 37.29527929850987, 39.220434052603586, 37.055934701647075, 47.50476081030709, 51.195612634931294, 50.51291390827724, 49.75722435542515, 52.694613524845664, 52.083925928388325, 53.57839659282139, 48.035630975450786, 52.58822270802089, 33.10095058168684, 25.564595665250504, 50.830550806862966, 45.43125854219709, 53.27539954866682, 47.05310705729893, 52.67604793821062, 47.066583088466096, 49.355806078229634, 47.39636196408953, 51.54854985645839, 43.536161695207866, 37.381978920527864, 37.923452036721365, 37.96798651559012, 37.77220017569405, 38.82093000411987, 37.4802542413984, 39.055695738111226, 38.159141881125315, 38.572927951812744, 38.61084427152361, 40.32591329302107, 41.810583523341585, 50.33335856028965, 50.35642310551235, 52.26052481787545, 49.95931618554251, 51.36820936203003, 41.97680180413382, 41.258934770311626, 40.994673933301655, 40.56328112738473, 38.120103427342, 40.76194749559675, 38.43909869875227, 41.2864670072283, 39.61055108479091, 41.297316619328086, 39.50704377038138, 40.24002661023821, 38.996629101889475, 40.981319495609824, 40.19023929323469, 44.166960852486746, 43.883165155138286, 46.48643977301461, 48.27427380425589, 49.72445665087019, 48.62936496734619, 52.46973507744925, 52.889305523463655, 54.40727499553135, 54.56778533118111, 55.95543091637747, 16.927854537963867, 0.5903931025947843, 4.462952154023307, 2.6310328883784155, 0.29247505590319633, 0.05673017891656075, 3.2148856733526503, 48.538899421691895, 30.31146076747349, 32.555951254708425, 22.188606670924596, 28.821197237287247, 41.605507441929404, 48.72399248395647, 46.98546634401594, 55.35325486319405, 14.797288451875959, 0.34665748849511147, 0.008217390709822732, 0.06433656665363482, 0.027946485938238244, 0.024745737867695943, 0.13241070775049074, 0.10414926281997136, 0.04194623418152332, 0.0057662698922545785, 0.012589700736238487, 0.023358605336397886, 0.02523420674593321, 0.04584466213626521, 0.03325374936684966, 0.048374929398830445, 0.020477209772382463, 0.03869116599006312, 0.11982648872903415, 0.12067548531506743, 0.09562682227364608, 0.08704827366662876, 0.18502847930150373, 0.08405238549624171, 0.14226322621107101, 0.16578690893948078, 0.11074509139039687, 0.09478894687656846, 0.12318720482289791, 0.11102163512259722, 0.09789695617343698, 0.13690658578915255, 0.17150044521050795, 0.36302511021494865, 39.941948890686035, 76.52531228746686, 65.10637869153703, 60.333855628967285, 44.54477262496948, 29.941139153071813, 40.54051535470145, 62.99963624136788, 54.29389429092407, 54.46010214941842, 3.7271053535597662, 0.17626209184527397, 0.5504874267748424, 1.389514650617327, 12.290602479662214, 5.644474651132311, 14.009533831051417, 71.79588890075684, 62.14398642948696, 63.33610275813511, 59.94321400778634, 62.23000512804304, 61.577249663216726, 58.77786214011056, 53.55011395045689, 52.72776338032314, 54.35207503182547, 60.24533557891846, 54.06026806150164, 55.57852588381086, 46.88821588243757, 43.57468250819615, 42.25600126811436, 53.78563008989607, 57.87799399239676, 57.9926392691476, 53.33594962528774, 47.93074791772025, 47.559304169246126, 50.718198435647146, 51.457062925611226, 54.45153154645647, 51.42506647109985, 55.45161703654698, 54.89308261871338, 55.36322900227138, 46.64960432052612, 39.46270384107317, 40.0767891066415, 47.511378969464985, 54.68237502234322, 53.74070303780692, 54.33273819514683, 51.382147448403494, 48.83030687059675, 39.481769698006765, 40.74283300127302, 40.104703494480674, 41.01066868645804, 40.14037554604666, 40.63649429593767, 39.934111322675435, 49.79019355773926, 52.722614765167236, 51.68729496002197, 51.87296124867031, 55.81880153928484, 53.18468039376395, 54.96779659816197, 50.397587708064485, 53.183349813733784, 34.35903658185686, 29.858726569584437, 52.11444936479841, 47.476596287318635, 54.90954637527466, 46.91851697649275, 55.04988956451416, 48.05026388168335, 51.05987957545689, 49.5609655380249, 53.01718711853027, 45.8733480998448, 40.17706550870623, 40.352802821568076, 40.26503665106637, 39.99319880349295, 40.8178631237575, 39.42154271262032, 41.22251926149641, 39.643127713884624, 40.99121373040335, 41.07224014827183, 42.548555169786724, 44.11092363085066, 54.609418937138145, 51.57535253252302, 55.043351309640066, 51.98916639600481, 52.30985007967268, 44.279097829546245, 43.44139174052647, 43.8540244102478, 43.297848905835835, 41.184905188424246, 42.94196217400687, 40.30517292022705, 44.253938402448384, 42.773398876190186, 44.80141476222447, 40.59123025621687, 41.811038630349294, 42.289620126996724, 43.467412744249614, 41.99063914162772, 44.751856735774446, 46.582265853881836, 48.73131241117205, 51.34015948431832, 51.48118359701974, 52.30013302394322, 54.372186592647004, 57.314102513449534, 56.18834842954363, 57.41984714780535, 57.878136430467876, 19.659240041460308, 2.3681925237178802, 12.634989942823138, 5.53986474445888, 0.3223745386515345, 0.1613576766103506, 4.825114846229553, 54.696973187582834, 44.24479109900338, 45.64126784460885, 20.01344530923026, 30.4283572605678, 45.54316970280239, 56.03535951886858, 52.07934359141758, 64.56860201699394, 17.112086023603165, 0.49188507135425297, 0.1363404161695923, 0.19680571662528173, 0.1267319938966206, 0.23837602883577347, 0.17563421625111783, 0.19319956084447248, 0.1217529039297785, 0.19817224544073853, 0.1120212325560195, 0.0822821758421404, 0.08381635709000484, 0.10784126006598983, 0.1685899371015174, 0.061926498476948054, 0.09224766359797545, 0.09595838162515845], [0.026403458290068165, 0.025868735375947187, 0.04168153427807348, 0.05091519487489547, 0.014872028758483273, 0.017459169129974077, 0.06334610908691372, 0.03510239088375654, 0.01230233776316579, 0.018985769445342675, 0.02269795480450349, 0.05397763715258666, 0.011120538410198475, 0.08394189285380499, 0.08121198362537793, 0.9314246944018773, 39.77360793522426, 59.2904029573713, 53.47730377742222, 47.907721587589805, 29.724657603672572, 16.961895499910625, 26.96038453919547, 39.04299790518624, 40.56811359950474, 30.138565267835343, 0.05401955365336367, 0.09116660125021424, 0.17698276388858045, 1.7417696458952767, 0.691100184406553, 0.08634448357458625, 37.394586426871165, 66.06305531093052, 58.09861319405692, 58.092224325452534, 52.80124405452183, 56.36034066336495, 54.883629594530376, 59.357869965689524, 55.134160791124614, 50.26600967134748, 46.52820539474487, 51.09383542197091, 54.430207524980815, 51.49557679040091, 46.54634714126587, 41.16505071095058, 40.0083771433149, 39.3844393321446, 49.32961484364101, 51.03888559341431, 42.654890401022776, 37.71039942332676, 38.808360712868826, 40.2275823865618, 40.8938764163426, 42.67113528932844, 45.10160820824759, 47.149537631443565, 46.658101967402864, 44.40781668254307, 38.886851038251606, 37.27926022665841, 36.074984550476074, 40.25512157167707, 51.527104241507395, 49.21052966799055, 52.2773950440543, 46.11251204354422, 39.081299849918906, 36.81368228367397, 37.10201515470232, 37.08663879122053, 35.40070704051426, 36.48047794614519, 36.83814689091274, 35.72752250943865, 48.164547852107454, 48.22231864929199, 49.546516759055, 47.7698415347508, 49.33912345341274, 47.600663321358816, 51.06236355645316, 46.74572222573416, 54.58760854176113, 32.46025024141584, 22.819272075380596, 48.39175394603184, 44.48433024542672, 50.38695349012102, 45.7466025352478, 49.31244584492275, 46.16808026177542, 50.42178133555821, 45.007988180433, 47.08264037540981, 44.822241987500874, 38.67787701742989, 33.84880951472691, 35.81271437236241, 34.360624245234895, 35.58418117250715, 35.46464088984898, 36.90285199029105, 35.385619027274, 36.60349580219814, 35.51115560531616, 39.430610111781526, 39.98504161834717, 47.51189661026001, 48.6241329738072, 50.18224913733346, 46.852005345480784, 47.887210505349294, 38.12337950297764, 37.262132917131694, 36.66018615450178, 36.749112674168174, 36.881917067936485, 37.499007429395405, 36.947080748421804, 38.50473485674177, 38.51853397914341, 39.23834998267037, 38.14520379475185, 38.93122918265206, 37.42570740836007, 40.817665100097656, 39.61507436207363, 41.212996755327495, 37.76192378997803, 42.2577417918614, 41.19991329738072, 44.609345708574565, 42.83978196552822, 46.18547855104719, 46.43837213516235, 54.03122806549072, 51.896918637411936, 58.109032017844065, 30.57857731410435, 1.046799206307956, 2.677235803433827, 3.0847126926694597, 0.09411382488906384, 0.045416794916880984, 0.10278625560126134, 24.769391707011632, 37.69179214750017, 32.24272646222796, 22.79390593937465, 27.321725606918335, 31.810072558266775, 36.54466887882778, 52.400597027369905, 42.19324861254011, 27.991551058632986, 1.436794753585543, 0.0911579838554774, 0.013008439115115573, 0.08515997856323208, 0.06448050428714071, 0.050795352019901784, 0.03658623840393765, 0.03142210854483502, 0.03839587094262242, 0.06917540343212229, 0.03692424383812717, 0.04417594775025334, 0.03196167280631406, 0.03221062391198107, 0.024893509224057198, 0.03897423044379268, 0.05052217382139393, 0.04567385112334575, 0.012864045166809644, 0.04809098284957664, 0.039598920316036255, 0.05295826381604586, 0.027523945218750408, 0.05047773995569774, 0.04790643150252955, 0.030619367691023008, 0.035941460502466986, 0.04029363500220435, 0.03973324650100299, 0.03450525292594518, 0.062168206221290996, 0.051902615997408114, 1.3262392516647066, 48.965591771262034, 66.13137694767543, 59.64765848432268, 53.61820977074759, 35.86835207257952, 22.026433978761943, 18.01482551438468, 34.64658778054373, 46.985032081604004, 32.82727493558611, 0.07472226436116866, 0.17845969035157136, 0.2876778947455542, 7.274892466408866, 2.7760984642165045, 0.49518693132059916, 39.725005286080496, 67.39418424878801, 60.71227536882673, 59.90519346509661, 54.35673379898071, 59.16391100202288, 56.578496728624614, 61.505947249276296, 55.588552134377615, 51.67022671018328, 47.09387561253139, 53.192594391959055, 56.87501457759312, 52.89083065305437, 48.33619267599923, 42.55950205666678, 40.80183710370745, 43.691009249006, 52.39825895854405, 53.515518869672505, 44.91081067493984, 38.744089875902446, 40.893258026668, 42.26263679776873, 42.352459635053364, 45.677641664232524, 47.68293694087437, 48.850460120609824, 49.39654336656843, 47.03511469704764, 39.30908611842564, 39.29938990729195, 37.86753640856062, 42.962473256247385, 52.550559997558594, 50.66464866910662, 54.358620234898154, 49.180256366729736, 41.64392055783953, 39.72522415433611, 38.811146940503804, 38.62733929497855, 38.938229492732454, 37.11596713747297, 39.00211123057774, 38.22653593335833, 50.167911529541016, 50.82490539550781, 49.97688817977905, 50.3993490764073, 51.287325382232666, 50.01288332257952, 53.16858836582729, 47.38344178880964, 55.11245461872646, 33.108485903058735, 25.734831741877965, 49.59781183515276, 44.91839810780117, 52.63105835233416, 46.25464786802019, 50.753846168518066, 48.58600125994001, 51.577860832214355, 46.61232376098633, 49.182365145002095, 47.20996264048985, 41.29540239061628, 36.057019983019146, 38.25063576017107, 36.29766389301845, 37.37255368913923, 37.51254946844918, 38.93361241476876, 36.87118557521275, 38.02396467753819, 38.07423142024449, 41.93984433582851, 42.380533831460134, 49.15727172579084, 51.09150430134365, 51.03118004117693, 49.32484837940761, 49.03403500148228, 39.78032684326172, 39.36009979248047, 39.475492000579834, 38.223079204559326, 38.3586802482605, 39.52933359146118, 38.704523359026226, 39.98686899457659, 39.5190988949367, 39.41319792611258, 39.98674740110125, 40.84818506240845, 39.527808461870464, 42.32479190826416, 41.046698570251465, 43.52552400316511, 39.7968670300075, 44.76323788506644, 43.97396074022566, 47.87042713165283, 44.9846978187561, 49.633668013981406, 49.17915160315377, 55.00594220842634, 54.67471810749599, 60.496464320591514, 34.898692744118826, 1.0998552164861133, 2.0515998091016496, 6.7072155220167975, 0.9886432183640343, 0.03015874419361353, 0.059036963885383945, 26.610626118523733, 42.87734740121024, 25.414820296423777, 19.458279030663626, 28.73839729172843, 36.651424476078574, 42.1044019971575, 56.51974970953805, 49.22166763033186, 37.26103857585362, 2.750399031809398, 0.07144508949880089, 0.038156711097274504, 0.05125147683013763, 0.0214983964937606, 0.06779634207487106, 0.05420570634305477, 0.07722423332078115, 0.04408293416989701, 0.07332292159221002, 0.05017809210611241, 0.05391136463731527, 0.036831637378782034, 0.03460077369319541, 0.011058180193815912, 0.07362351260547127, 0.02883077991594161, 0.08720888290554285, 0.17307391363595212, 0.15128710413617746, 0.11885275026517254, 0.14354263113013335, 0.11553134849028927, 0.1106135438063315, 0.14556134066411427, 0.13263606280088425, 0.15258648512618883, 0.09419795644602605, 0.14826258857335362, 0.08956832558448825, 0.2321580967732838, 0.1659949884882995, 1.9468270540237427, 57.77742576599121, 73.99123477935791, 66.86029161725725, 61.251768248421804, 43.50472109658377, 25.68604322842189, 36.69439213616507, 52.75296797071184, 52.88232953207833, 36.5802332333156, 0.407391719520092, 0.3771421941263335, 0.2783469797245094, 4.458409334932055, 6.175708293914795, 0.5831480313624654, 43.82257686342512, 68.63206141335624, 62.778961454119, 62.15829971858433, 58.05350201470511, 61.928230966840474, 59.10544885907854, 63.557534899030415, 56.8203843661717, 50.205143451690674, 50.06878852844238, 56.91418852124895, 59.00727776118687, 56.185711588178364, 50.021763120378765, 46.25244876316616, 44.30007096699306, 43.223562240600586, 53.2276063646589, 56.13965892791748, 47.03180040631975, 41.26206145967756, 43.00307852881295, 45.016221795763286, 45.19230304445539, 48.372427531651084, 48.92838764190674, 51.232125418526785, 50.845590182713096, 48.207887240818565, 41.71032796587263, 40.91876833779471, 39.36374412264143, 45.151940958840505, 56.280286993299214, 55.574377809252056, 58.04961102349417, 52.45919813428606, 43.058893408094136, 42.05371836253575, 40.727564334869385, 41.5663161277771, 39.06426634107317, 40.601458004542756, 41.48459836414882, 40.66093805858067, 51.059525217328755, 52.42770542417254, 52.986632415226524, 51.645748206547324, 52.712390490940635, 51.61880309241158, 54.47953973497663, 49.56213630948748, 57.69540228162493, 34.77930532182966, 28.890335287366593, 51.57504333768572, 48.58839838845389, 54.72169140407017, 47.916125433785574, 54.15207460948399, 51.72226524353027, 52.87301894596645, 49.47052083696638, 51.19754423413958, 49.73994418552944, 44.240709032331196, 39.27465779440743, 40.05422830581665, 37.47891671316964, 39.627695764814106, 39.97066926956177, 40.933411666325156, 38.91491133826119, 40.00921092714582, 40.38162742342268, 44.0791460445949, 44.04895612171718, 51.982179982321604, 54.15424592154366, 52.90239940370832, 51.77941417694092, 53.19707945414952, 43.006729807172505, 40.74910722460066, 40.32092101233346, 39.601014682224815, 42.03199481964111, 42.43614373888288, 40.205945696149556, 42.21987410954067, 42.600489480154856, 41.714191164289204, 41.342191559927805, 42.18920128686087, 41.94177940913609, 45.380359513419016, 43.617643220084055, 44.84723118373326, 41.82122816358294, 47.97981262207031, 46.16520370755877, 50.920606408800396, 47.679768562316895, 50.98487377166748, 51.52231693267822, 59.04310267312186, 57.21252679824829, 62.033287729535786, 37.074920654296875, 2.8844792885439734, 10.16900304385594, 7.844801953860691, 1.3742488069193703, 0.28376937018973486, 0.3579924431230341, 31.383835315704346, 52.281299931662424, 45.160671370370046, 28.955564975738525, 35.3227413041251, 41.66638060978481, 49.76614236831665, 63.67955221448626, 55.68157114301409, 43.30540854590279, 2.7596136459282468, 0.19777911582163402, 0.10782017798296042, 0.21583718540413038, 0.15829240823430674, 0.17343287223151752, 0.13955017179250717, 0.23236738411443575, 0.1276502146252564, 0.28147746888654573, 0.26854779411639484, 0.13175353301422937, 0.11368688674909727, 0.20383570582738944, 0.09188724615211998, 0.18507238051721028, 0.06918402082685914], [0.06973195142511811, 0.04138146912945168, 0.03621016376252685, 0.07519183773547411, 0.048017243056425025, 0.013141928157503051, 0.04145111396376576, 0.044522685930132866, 0.07252317986318044, 0.02002455566876701, 0.030958611451621567, 0.009538989480850952, 0.05579108984342643, 0.01661599098172571, 0.04273126866402371, 5.020402652876718, 51.853492396218435, 58.28292805807931, 49.68636315209525, 37.21177237374442, 27.180295024599346, 20.834058829716273, 44.53874158859253, 36.95726333345686, 48.737062045506065, 13.611146705491201, 0.30159779638051987, 0.2633373779909951, 0.2701232438640935, 9.468010578836713, 1.7154864562409264, 3.0989217587879727, 59.86626270839146, 57.620820317949565, 59.99924428122384, 51.71221814836775, 49.2609840120588, 50.99170732498169, 55.62119824545724, 56.199052129473, 57.56073577063424, 54.85290813446045, 45.76292732783726, 50.15359476634434, 53.46396323612758, 51.05978577477591, 48.716036796569824, 41.56549971444266, 39.24622923987252, 37.79339565549578, 40.76955229895455, 39.91639689036778, 38.693110942840576, 37.81833968843733, 37.72586611339024, 36.95450837271554, 39.004629952566965, 36.818872588021414, 39.33871671131679, 39.7882582119533, 39.033065455300466, 37.173859528132844, 37.726675578526084, 37.87049981525966, 38.25154250008719, 36.54433536529541, 44.02939346858433, 47.916743823460166, 45.929548604147776, 38.741800444466726, 36.690160683223176, 35.74091168812343, 38.169157709394185, 35.2073768888201, 35.86230019160679, 35.92998954227993, 36.240417684827534, 38.38163014820644, 45.48800448008946, 47.02166645867484, 47.59664726257324, 46.5476325580052, 49.63450179781233, 46.51099123273577, 50.36720323562622, 44.986900397709434, 53.332753453935894, 33.38949884687151, 22.200724329267228, 50.65086691720145, 43.387525830950054, 48.32286603110177, 44.92926509039742, 47.385244846343994, 44.62814058576311, 48.646269934517996, 47.187064852033345, 45.85132925851004, 44.68878793716431, 42.81382002149309, 36.02963365827288, 36.253125940050396, 34.77306931359427, 35.85840572629656, 36.114387784685405, 35.55910859789167, 35.96456725256783, 37.29477902821132, 35.91038172585623, 38.600720746176584, 41.89640072413853, 46.49650771277291, 47.667188848767964, 51.393038749694824, 47.461932114192415, 44.81467539923531, 37.77798802512032, 37.12642070225307, 37.99779428754534, 38.32118082046509, 36.44222116470337, 37.17966474805559, 36.68661362784249, 36.89736986160278, 36.58321748461042, 40.359344550541465, 38.46846873419625, 38.085668155125205, 38.398003578186035, 38.64953531537737, 37.62502343314034, 37.980357783181326, 39.0400344984872, 39.96383919034685, 40.040144307272776, 43.58896453039986, 42.08582946232387, 45.66569423675537, 46.2353527205331, 50.9782521384103, 53.86647932870047, 54.11729192733765, 50.74898937770298, 6.528523921966553, 1.3815143427678516, 2.6122134753635953, 1.4160978070327213, 0.06482647572244916, 0.17225368693470955, 8.221436875207083, 40.756239550454275, 39.55897460665022, 46.892384801592144, 43.422437054770334, 42.03727197647095, 34.5480831691197, 44.99494293757847, 42.400902475629536, 44.67772987910679, 9.717874748366219, 0.09908340179494449, 0.0829359714740089, 0.020812680878277336, 0.026309725462592075, 0.04064329766801425, 0.05773079754518611, 0.08457759874207632, 0.02116260986908206, 0.019106474039810042, 0.026483411767653058, 0.02094206054295812, 0.02965074198852692, 0.02603014019717063, 0.05022016466994371, 0.022321064224732772, 0.012823109997303357, 0.0630595637485385, 0.03126080720020192, 0.039339838682540824, 0.023942820594779084, 0.027084624328251396, 0.037751588371715376, 0.09017228281923703, 0.03670797776430845, 0.08520997980875628, 0.03406142317024725, 0.03161938242348177, 0.06250701232680253, 0.045832173699246984, 0.07077291913862739, 0.07503364408122641, 8.028858866010394, 64.43601649148124, 63.23565265110561, 58.52878311702183, 44.358487946646555, 35.318277086530415, 24.361567190715245, 39.62035846710205, 35.94517830439976, 54.992455754961284, 14.63002620424543, 0.3383590594998428, 0.16455559858254024, 2.0313603579998016, 7.223046311310359, 1.216988274029323, 3.6017450860568454, 61.213094575064524, 60.690583092825754, 60.816053662981304, 55.15134368624006, 51.271101338522776, 53.2680344581604, 57.38949046816145, 57.694644927978516, 59.79720456259591, 55.23389523369925, 47.5412631716047, 51.24705709729876, 57.284499713352744, 54.0679076058524, 51.385611125401084, 44.16487986700875, 40.65671355383736, 38.79603460856846, 42.80921336582729, 41.94453089577811, 40.551010608673096, 38.0453234400068, 38.897085734776084, 38.62854133333479, 42.40378597804478, 39.46024417877197, 41.84059279305594, 41.195296219417024, 41.13612188611712, 38.48806960242135, 37.679188115256174, 39.14153378350394, 39.73023380552019, 38.85808549608503, 45.72882209505354, 49.667206968579976, 48.75820541381836, 40.13170766830444, 38.75201429639544, 37.77895729882376, 39.83658293315342, 38.36633368900844, 38.327694756644114, 37.36629336220877, 37.99418817247663, 40.01379326411656, 48.03276136943272, 49.936612946646555, 50.6104006086077, 48.0182500566755, 52.977895055498394, 48.32835510798863, 51.69671324321202, 47.152042457035606, 54.66707508904593, 35.71268810544695, 24.522869621004375, 52.46945367540632, 45.84642035620553, 51.369817870003835, 45.50833143506731, 48.69306605202811, 47.641678537641255, 49.71079649244036, 49.11642326627459, 48.92690767560686, 46.934386662074495, 44.05541099820818, 35.730187143598286, 38.293617316654746, 36.68862860543387, 38.335198811122346, 36.36567633492606, 38.743103231702534, 36.15726164409092, 39.29506812776838, 36.96548652648926, 40.54755735397339, 44.16825669152396, 47.917275360652376, 50.84532962526594, 52.9356951713562, 49.046190874917166, 47.228920800345286, 40.02878747667585, 38.50783722741263, 38.701059682028635, 39.020131383623394, 39.129586356026785, 40.79797737939017, 39.23139483588082, 39.1910605430603, 39.1351101739066, 42.30978727340698, 41.648565428597585, 39.8591194152832, 39.56938648223877, 40.72201272419521, 39.034660066877095, 40.195054394858225, 40.49184322357178, 42.77256509235927, 43.047710282461985, 46.105039255959646, 45.63458367756435, 48.41680220195225, 47.51331056867327, 53.47794648579189, 56.1033650125776, 56.62490027291434, 53.14077125276838, 9.189598866871425, 0.8865498080849648, 3.761216231754848, 2.259759370769773, 0.06740096650485482, 0.19833043909498624, 8.728090831211635, 49.058256421770366, 34.00844437735421, 37.50249195098877, 46.638389928000315, 47.71225833892822, 39.42323807307652, 48.124957016536165, 48.07209859575544, 54.81219169071743, 13.92859252861568, 0.20152696328503744, 0.029883720379854952, 0.04249514187020915, 0.03882894591827478, 0.014204579305702021, 0.03448217934263604, 0.0436676605604589, 0.03003909472110016, 0.02931768646729844, 0.011591017628753824, 0.02422646519594959, 0.004789563685855163, 0.04877977053235684, 0.03734836554420846, 0.034251450294894834, 0.015080964957763041, 0.20604905991681985, 0.09025771037808486, 0.0771490109286138, 0.14944826066493988, 0.1422550973615476, 0.09774057420768908, 0.1840276401489973, 0.15601015569908278, 0.15734486122216496, 0.10889009200036526, 0.11981922840433461, 0.10285661968269519, 0.10463543994618313, 0.2015018846307482, 0.142389338729637, 10.880314452307564, 74.70246628352574, 69.8650678907122, 64.93634932381767, 51.267703669411794, 38.82093000411987, 30.292999403817312, 57.35079942430769, 49.367030893053325, 61.687517574855256, 17.12732516016279, 0.49220821687153404, 0.5648882197482246, 1.2111794714416777, 15.090464217322213, 5.335865633828299, 4.464933693408966, 65.49792357853481, 61.60101250239781, 64.29751804896763, 56.502066544124055, 53.43845987319946, 54.99617998940604, 61.00426646641323, 59.14866665431431, 62.57446207318987, 56.57730163846697, 48.359472615378245, 52.76232372011457, 58.32086522238595, 55.03101825714111, 53.94324650083269, 46.17618533543178, 42.38412605013166, 42.251074995313374, 46.097278118133545, 44.45231989451817, 42.38835750307356, 41.14269835608346, 41.57190942764282, 39.78374188286917, 43.89852067402431, 40.946644510541645, 43.23109061377389, 43.72342259543282, 43.023520129067556, 39.84298569815499, 40.81027569089617, 41.71970803397042, 43.77712174824306, 40.374248436519075, 48.28526585442679, 50.70268310819353, 49.950745582580566, 41.340336390904014, 40.45046670096261, 38.657008102961946, 42.16495207377842, 39.600048882620676, 40.45135954448155, 39.886665548597065, 39.244297640664236, 42.02643278666905, 50.494813850947786, 52.157799175807405, 51.83020898274013, 49.413740158081055, 54.42720937728882, 50.98314019611904, 54.00824689865112, 49.8780083656311, 55.411935874394004, 37.920613697596956, 26.065894297191075, 53.50028147016253, 47.98249462672642, 51.93893092019217, 48.3865566934858, 50.802122252328054, 49.83080577850342, 52.47640882219587, 51.6760527747018, 49.85591656821114, 48.62799964632307, 48.42257962908064, 40.4882162639073, 40.13034234728132, 39.32142959322248, 41.387320109776084, 39.21109914779663, 40.8179360798427, 39.600792339869905, 42.55762256894793, 38.87199231556484, 42.814678124019075, 47.13627699443272, 50.21654544557844, 52.45311846051897, 56.74090739658901, 52.08564213344029, 48.89984444209507, 42.346637044634136, 40.44575582231794, 40.900654384068076, 41.31845998764038, 40.69390378679548, 41.45466205051967, 39.78921011516026, 39.61766256604876, 40.872639247349326, 44.32288885116577, 42.74609245572771, 42.18606764929635, 41.936366762433735, 43.778667722429546, 40.04923602512905, 41.09775740759713, 42.519803524017334, 44.873213972364155, 45.236646447862896, 48.41113942010062, 47.066788060324534, 50.52303048542568, 50.56718628747122, 55.565862791878835, 60.37823377336775, 59.78255081176758, 54.71581670216152, 10.069175669125148, 6.485197995390211, 11.421276007379804, 1.7971108534506388, 0.1996957736888102, 0.21180021416928085, 10.645178726741246, 52.96946689060756, 52.01440920148577, 64.15796348026821, 48.33753020422799, 51.33213431494576, 44.49012156895229, 58.89649568285261, 54.762710094451904, 64.273254939488, 17.03263337271554, 0.3479229834462915, 0.12895427750689642, 0.21112549251743726, 0.11214722293828215, 0.11203025707176753, 0.17095550016633101, 0.1450210367994649, 0.08246831156845603, 0.07054452425135033, 0.07691871614328452, 0.1254321379320962, 0.09382299120937075, 0.1742344256490469, 0.10877730590956551, 0.08563302603683301, 0.09810781771583216], [0.03750104270875454, 0.020883928751572967, 0.06271921058318444, 0.006136440430834357, 0.03428721587572779, 0.039036665843533616, 0.07958052081188985, 0.021841412909062843, 0.004817860716554735, 0.02252011756146593, 0.016642599732482007, 0.017334556173799292, 0.029912887207631553, 0.09307992751044886, 0.14854346135897295, 17.55837403024946, 56.50903558731079, 51.63397795813424, 52.71443673542568, 37.47391401018415, 23.076987709317887, 27.238564355032786, 29.89539221354893, 36.80095665795462, 44.564290114811485, 4.135268594537463, 0.08121498953551054, 0.06212349754891225, 1.1019159001963479, 11.788318072046552, 1.3565341574805123, 18.436760084969656, 66.09521157400948, 56.229547773088726, 57.82365213121687, 49.320495332990376, 47.62846653802054, 45.462869371686665, 53.95958171572004, 50.45047739573887, 56.411726066044395, 54.931599957602366, 58.3079137802124, 52.66089391708374, 53.39259828839983, 52.66086265019008, 52.21044567653111, 44.697497504098074, 39.23484461648123, 36.824406828199116, 39.12177658081055, 38.677640778677805, 39.0544867515564, 37.642717020852224, 39.22060775756836, 38.024159227098735, 39.52218736921038, 36.378315108163015, 36.08819307599749, 38.676747935158865, 37.50488907950265, 34.88645001820156, 38.16860185350691, 35.52362414768764, 38.423281124659944, 35.514674867902485, 36.47573927470616, 36.68429292951311, 38.79143142700195, 35.13931233542306, 37.77417346409389, 37.027276856558665, 37.13767678397042, 36.54200424466814, 37.355527128492085, 35.584347929273335, 38.099759101867676, 38.73546021325247, 45.93292542866298, 44.43752023151943, 48.57513427734375, 44.470350469861714, 48.41434253965105, 42.94841357639858, 49.8940726007734, 44.3781270299639, 55.20226355961391, 30.77092776979719, 21.783735139029368, 51.32136460712978, 45.76075254167829, 49.94328669139317, 44.08758463178362, 43.54833493913923, 41.19764123644148, 45.221475056239534, 43.32173333849226, 44.843885626111714, 43.02446160997663, 42.127421379089355, 35.523325375148225, 35.51740550994873, 34.67996692657471, 35.65622704369681, 36.151963642665315, 36.208362170628135, 35.80294173104422, 35.93295989717756, 35.680003779275076, 39.140390804835725, 41.70388003758022, 45.58523409707205, 47.9191826411656, 48.29747036525181, 48.41773673466274, 38.93574551173619, 36.4237493787493, 36.148534706660676, 36.557245118277415, 38.98006459644863, 37.33719083241054, 37.91302973883492, 36.997899872916086, 38.24801628930228, 38.67174175807408, 39.48281192779541, 42.4002354485648, 41.06018154961722, 38.33329153060913, 37.56092282703945, 38.13454178401402, 38.622868129185264, 39.09570346559797, 39.054674352918354, 42.37680264881679, 42.59103298187256, 45.744792529514854, 46.77293831961495, 50.02735294614519, 52.45403214863369, 53.038351331438335, 52.66145672116961, 58.8420079095023, 25.049687249319895, 1.3446914958102363, 2.0557005490575517, 2.4310224780014584, 0.10458349130515542, 0.11146988892661673, 0.3391001011644091, 24.149428265435354, 35.53820841653006, 33.59681919642857, 15.15873200552804, 17.75596169063023, 29.544695786067418, 33.81987026759556, 45.65598412922451, 48.70431865964617, 28.596181562968663, 0.34757885762623375, 0.028877147606440952, 0.032964089552738836, 0.023189036042562554, 0.13130503493760312, 0.04044094495475292, 0.04180799963484917, 0.03205685091337987, 0.051111495055790455, 0.03836711123585701, 0.040804327598639896, 0.0296986974509699, 0.05530587284426604, 0.05154280923306942, 0.024016059968354445, 0.047017302962818315, 0.03916269015254719, 0.020300417473273616, 0.06658393570355006, 0.021718009441558803, 0.01514435709188027, 0.05869773030281067, 0.0276598489976355, 0.028344926790201237, 0.008335709405530776, 0.027899633095200573, 0.019441358212913786, 0.03432189580053091, 0.0907942076612796, 0.05393337292064514, 0.11048152803310327, 25.38918318067278, 65.948166847229, 57.53177915300642, 58.69877774374825, 42.45474059241158, 27.401628153664724, 25.62080659185137, 28.74916352544512, 39.53815432957241, 51.113290378025596, 3.69206645659038, 0.06473048337336097, 0.04220349055581859, 5.396965486662729, 13.23754814692906, 0.857159959418433, 21.61501203264509, 68.1947556904384, 60.429469789777485, 59.80118588038853, 52.235712800707134, 47.70226335525513, 48.02182490485055, 55.19561413356236, 52.83205236707415, 57.171831199101035, 57.112681184496196, 58.99287414550781, 52.722347259521484, 53.16703544344221, 54.656027453286306, 53.423180784497944, 46.39607497623989, 41.88370983941214, 38.857797145843506, 41.024085657937185, 39.743115765707834, 42.15324435915266, 39.1620066506522, 40.8928758757455, 39.24095555714199, 40.857547760009766, 37.14767871584211, 38.63350929532732, 39.11440454210554, 38.82961177825928, 37.81636292593819, 39.60004193442208, 37.07576486042568, 39.5591413634164, 37.31474815096174, 37.82484320231846, 38.980679512023926, 39.839466435568674, 38.06617498397827, 39.478587423052105, 38.79917866843087, 38.74870000566755, 37.08972726549421, 39.06065327780587, 36.73559495380947, 38.72923115321568, 40.9550587790353, 46.589485032217844, 46.51066814150129, 50.19179943629673, 46.89166913713728, 50.70913798468453, 44.62952675138201, 50.901474543980186, 45.703454221997944, 56.74097340447562, 34.14543158667428, 24.037782873426163, 53.31728328977312, 46.86283758708409, 51.96531670434134, 45.6931847844805, 43.768561567579, 42.965954303741455, 47.746318408421104, 45.292694091796875, 47.423439093998496, 45.50713634490967, 43.90738310132708, 37.12810911451067, 37.52231863566807, 36.90583624158587, 37.45178052357265, 37.810363156454905, 38.1363205228533, 40.37089940479824, 36.895459106990266, 37.83450814655849, 40.16584416798183, 43.472609996795654, 46.36883108956473, 50.863631180354524, 49.09038141795567, 49.966170583452495, 40.86296388081142, 39.31973075866699, 37.91878979546683, 37.94312586103167, 40.4106639453343, 39.01767519542149, 39.48610189982823, 38.27510731560843, 41.058916977473665, 40.317422594342915, 41.67466286250523, 44.5252342905317, 42.72119011197771, 40.95631987707955, 39.82344388961792, 40.372910908290315, 40.89745473861694, 40.61152247020176, 40.61665718896048, 44.55072375706264, 44.18566540309361, 47.202962330409456, 49.51161595753261, 53.4079920223781, 53.63864094870431, 54.88298341206142, 54.32543216432844, 60.30661869049072, 28.483443566731044, 0.9897861970322472, 4.428732710225241, 5.201390198298863, 0.1926364717738969, 0.22183637134730816, 0.30628229358366554, 28.768458672932216, 38.140558923993794, 29.958155291421072, 18.08531325204032, 24.331005539212907, 34.9052448953901, 39.598211084093364, 50.44064222063337, 53.31788430895124, 38.46070064817156, 0.67706867733172, 0.03576361308140414, 0.09276035108736583, 0.04439333001417773, 0.07970175466367177, 0.03341556300542184, 0.04396062823278563, 0.03344507249338286, 0.05372521534029927, 0.06431506387889385, 0.012515255266667476, 0.024557064420410564, 0.014476451324298978, 0.03134227889989104, 0.035797186994126866, 0.016388849687895606, 0.10802018296505723, 0.11531666001038891, 0.12065168230661324, 0.09481251239776611, 0.11492659736956869, 0.20715045795908996, 0.1559788752347231, 0.11110161404524531, 0.13990628054099424, 0.10837816447019577, 0.10206744952925614, 0.2020439798278468, 0.3048934409660952, 0.16042581732783998, 0.1868624101792063, 33.748824937003, 74.18303285326276, 63.39405073438372, 66.64217376708984, 48.07207775115967, 32.41362088067191, 36.982867445264546, 40.83397947038923, 48.253971167973106, 57.77582768031529, 5.093156371797834, 0.13088548316487245, 0.08112281733857733, 3.85943466424942, 28.013448306492396, 3.796243837901524, 23.268579074314662, 70.30279050554547, 62.68359742845808, 62.13568333217076, 54.978072983878, 50.4749767439706, 49.329625265938894, 57.96639939716884, 54.59097146987915, 61.7415189743042, 59.717487880161826, 60.506087575639995, 54.14403901781355, 55.40832281112671, 57.492184843335835, 54.87840802328927, 49.35608748027256, 44.52857289995466, 40.42760712759835, 44.5838041305542, 41.70594365256173, 43.675841331481934, 41.18710776737758, 43.33289909362793, 42.81145415987287, 43.174289090292795, 38.63358572551182, 40.7044164112636, 41.29814692905971, 40.960843154362266, 38.27225508008684, 41.266463143484934, 37.70504583631243, 42.21372495378767, 39.077627726963584, 40.497294085366384, 40.8761237689427, 42.18921170915876, 38.60860347747803, 41.45423821040562, 41.52407455444336, 41.51771347863333, 41.53977400915963, 41.22393321990967, 39.93771743774414, 40.70342629296439, 43.86182376316616, 50.534877164023264, 48.984560353415354, 52.56942088263375, 47.39817544392177, 54.18060391289847, 47.23647696631295, 54.28803695951189, 48.888331277029856, 57.949369362422395, 37.02996233531407, 25.592035838535853, 54.43324736186436, 48.81504167829241, 54.27643346786499, 48.22799185344151, 46.23049940381731, 46.45062528337751, 49.638743673052105, 47.07406629834856, 49.168548652103965, 47.37280757086617, 45.52017116546631, 40.034766401563374, 40.41852930613926, 39.10271767207554, 39.127331665584016, 39.809780257088796, 40.034002099718364, 42.25711645398821, 39.89715732846941, 39.19002873556954, 43.67566762651716, 45.38742583138602, 49.70723206656319, 53.58878762381417, 51.29686178479876, 53.948992661067415, 42.54057516370501, 41.13679586138044, 39.6205530166626, 39.78999178750174, 41.69492380959647, 41.30839204788208, 43.06846802575247, 39.56753478731428, 42.4422025680542, 42.39527790887015, 42.364876065935405, 47.27249295370919, 45.24320902143206, 43.12859773635864, 40.87351819447109, 42.290683201381135, 44.26885618482317, 42.228211947849815, 43.56401702335903, 47.26895979472569, 47.141804286411826, 50.21738965170724, 51.37855870383126, 56.01421267645699, 56.44270460946219, 58.594603402274, 57.717549664633616, 62.0823142187936, 29.976957116808208, 3.947617292404175, 19.162801674434117, 8.099560260772705, 0.1698810535350016, 0.35475279124719755, 0.5327462873288563, 32.628083978380474, 49.088988304138184, 46.32716621671404, 20.535199437822612, 26.382431643349783, 41.35786322184971, 46.765260560171946, 58.42959063393729, 60.36644268035889, 44.688065324510845, 1.2246392177683967, 0.09123176096805505, 0.12903867369251593, 0.16893712989985943, 0.3348168624298913, 0.11429455557039805, 0.20751198141702584, 0.07576012438429253, 0.15522289222904614, 0.21542926372161933, 0.10304002769823585, 0.06459191973720278, 0.12219874214913164, 0.12646841018327645, 0.11935190776629107, 0.18671930714377336], [0.012241379873427962, 0.07376171661806957, 0.025951947517959133, 0.03224963628287826, 0.021378399272050177, 0.011112525759797012, 0.029263393487781286, 0.010821684446584965, 0.040807676168956926, 0.08690503492419209, 0.017404038159708892, 0.0148467635070639, 0.0786595248750278, 0.12460537015327386, 0.8520816404904638, 29.874523299080984, 57.42713580812727, 59.45054503849575, 43.520417077200754, 31.245350769587926, 19.129031692232402, 33.749401637486045, 42.75753961290632, 40.231292724609375, 37.67557852608817, 0.4890332158122744, 0.056128647444503646, 0.08723491829420839, 4.082176540579114, 5.442661617483411, 2.6761618724891116, 40.91984183447701, 61.55222225189209, 55.87427943093436, 55.318416595458984, 50.18558079855782, 44.28078971590315, 41.06533363887242, 46.52570751735142, 52.173397881644114, 54.456040927342, 51.14405700138637, 53.81241886956351, 52.040183544158936, 48.558066027505056, 49.07847220557076, 50.826586859566824, 48.225744111197336, 40.26324054173061, 38.88975885936192, 38.79359579086304, 37.64678519112723, 37.780333042144775, 36.76358229773385, 37.77142892565046, 36.01727976117815, 38.31555625370571, 37.460924352918354, 37.16455589021955, 37.67796523230416, 36.8606173651559, 37.174839224134175, 37.853761604854036, 35.753456660679404, 36.405138628823416, 36.38852201189314, 36.43660702024187, 35.66568006787981, 37.74796485900879, 36.63744470051357, 37.739230973379954, 34.156079701014924, 39.13547148023333, 36.213173798152376, 37.48098380225045, 36.37396553584507, 35.973290715898784, 37.39229004723685, 43.680406297956196, 42.59582029070173, 46.131511892591206, 42.46651084082467, 46.93748555864607, 43.79081317356655, 50.13119377408709, 44.314856733594624, 53.99688311985561, 32.70998239517212, 24.724158934184484, 47.74559926986694, 44.430082184927805, 48.95688220432827, 45.433068547930034, 44.38000651768276, 39.86572715214321, 41.39759302139282, 42.73059797286987, 43.33078336715698, 42.35344280515398, 42.45533118929182, 38.556085518428254, 35.89859063284737, 35.487986837114605, 36.06676483154297, 36.300856590270996, 36.25052383967808, 35.686597619737896, 37.494348662240164, 36.16920212336949, 37.407148769923616, 39.058506284441265, 43.65798793520246, 45.37811524527413, 45.41428061894008, 42.40163203648159, 37.48027508599417, 36.6815310205732, 36.184884207589285, 38.42034551075527, 36.8949727330889, 37.122481073652, 37.78052759170532, 35.96079090663365, 38.89597054890224, 41.014344283512656, 44.97007186072213, 45.151788098471506, 45.48352984019688, 42.53205667223249, 39.927277769361226, 38.15043926239014, 38.0517018863133, 39.76775060381208, 40.01425531932286, 44.17427035740444, 44.172012192862375, 46.66955607278006, 49.720551763262065, 51.0989909853254, 53.294698170253206, 53.132909366062705, 54.218416009630474, 53.993617466517854, 47.81985119410923, 7.495092170579093, 2.076010133538927, 4.68270891053336, 0.39366226909416063, 0.03667874986838017, 0.12283286026545934, 10.577213185174124, 41.708625657217844, 35.12788602284023, 25.09196182659694, 10.332965765680585, 20.413567747388566, 31.59541491099766, 44.19545888900757, 46.96183552060808, 49.35980476651873, 5.673833830016, 0.2161869023527418, 0.07493410977934088, 0.03652580128982663, 0.014093302107150001, 0.03377058949055416, 0.06906601680176598, 0.025859324095238532, 0.04567593761852809, 0.04461650696716138, 0.021409018164766685, 0.030633725492017608, 0.040493796047355445, 0.042382345601384125, 0.056367054115980864, 0.03288066027952092, 0.014333112497947045, 0.02711447817273438, 0.027227583174992884, 0.009402775272194828, 0.033818836723055155, 0.07569521572440863, 0.04939300334081054, 0.013900819533903683, 0.024150428561759845, 0.07560407490070377, 0.026213792485318015, 0.014985225362969297, 0.014063498304624642, 0.04899532075173088, 1.2727998963424136, 42.116085393088206, 66.46540464673723, 63.03347396850586, 51.57128436224801, 37.15873677389962, 25.243312699454172, 32.44467238017491, 40.0372816494533, 45.0536447933742, 42.272572721753804, 0.22638347877987794, 0.05308004728119288, 0.34890159379158703, 8.12330572945731, 6.288845377308982, 2.209655693599156, 46.538488728659495, 61.09511416299002, 60.59850556509835, 57.03132472719465, 52.78480461665562, 45.51691246032715, 43.43200472423008, 47.95420503616333, 55.07079321997506, 55.53955691201346, 54.92109775543213, 55.372817516326904, 56.07968207768032, 52.1544223512922, 51.755974428994314, 53.302869251796174, 49.79752390725272, 41.18142066683088, 38.96413585117885, 40.04731484821865, 38.09338065556118, 38.679353509630474, 39.857816628047395, 38.95862940379551, 38.800898347582134, 39.77589389256069, 40.40609897886004, 38.84020778111049, 38.43392923900059, 38.75618321555001, 37.94438695907593, 38.79983874729702, 37.56094714573452, 38.18050411769322, 37.11652646745954, 38.61320318494524, 37.408375126974924, 39.852285861968994, 37.72027281352452, 39.47009672437395, 36.694944517953054, 40.31921522957938, 37.34868662697928, 39.063165051596506, 38.045243535723, 37.04590845108032, 38.49234274455479, 44.158067158290315, 44.15020874568394, 47.188145296914236, 44.69559717178345, 47.496242318834575, 45.84094517571585, 50.94013432094029, 44.73486839021955, 56.27599648066929, 34.025498730795725, 24.582728351865494, 48.94426080158779, 46.312172004154746, 50.989911215645925, 46.07675313949585, 47.00799240384783, 41.13563551221575, 45.968941416059224, 44.46583414077759, 46.591010161808555, 43.49776247569493, 45.105249064309255, 38.996465819222585, 37.141060556684224, 37.68399626868111, 38.35835715702602, 37.222034863063264, 38.1098826272147, 38.11352695737566, 39.51375573022025, 38.14709023066929, 38.59998076302664, 40.709495544433594, 46.34629808153425, 47.45116588047573, 48.30093056815011, 44.05025543485369, 38.53745739800589, 39.35752895900181, 38.01045390537807, 39.414250578199116, 38.75374092374529, 39.6783481325422, 38.94317661012922, 38.362654617854524, 40.71184056145804, 42.13510608673096, 48.075847148895264, 46.008070196424214, 47.58350127083914, 43.06420530591692, 42.11689485822405, 39.14044986452375, 41.54372753415789, 41.91122123173305, 42.01750782557896, 46.1711756842477, 47.50428833280291, 47.75440263748169, 50.86835248129708, 52.819486549922395, 55.40669693265642, 55.66805689675467, 57.394538334437776, 55.33189262662615, 49.55170358930315, 10.000119260379247, 0.8283052848918098, 4.850449281079428, 0.9478370994329453, 0.03879985712202532, 0.23666617487158093, 10.153794305665151, 49.333238329206196, 31.86796494892665, 26.380062307630265, 18.074216978890554, 28.729350737163, 36.93761382784162, 49.326505524771555, 51.94388498578753, 59.70409870147705, 11.047171098845345, 0.31904640580926624, 0.015687073148520927, 0.04220732767134905, 0.02114234711708767, 0.035246708496872864, 0.04430394320349608, 0.011442320072092116, 0.06523045511650187, 0.02034431359996753, 0.029827045742422342, 0.05408161925151944, 0.06902700782354389, 0.02742431083294962, 0.030923551547208, 0.018680886698088477, 0.09782810522509472, 0.12179394172770636, 0.08172912230449063, 0.07083959198955979, 0.13573379229222024, 0.12320350323404584, 0.11299370215939623, 0.12833717704883643, 0.10647002221750361, 0.19673453830182552, 0.11083551975233213, 0.08126277197152376, 0.2534563610596316, 0.2954505948083741, 1.784565989460264, 53.68815033776419, 73.25654615674699, 71.68726076398576, 57.90323679787772, 43.70659753254482, 29.035655123846873, 45.33667966297695, 56.612456049237935, 52.59089081627982, 46.99214703696114, 0.6226545657430376, 0.1774982198008469, 0.35995278507471085, 9.54621342250279, 11.379814369337899, 3.9768448897770474, 48.54263060433524, 64.24615696498326, 62.90482807159424, 58.798956871032715, 55.21084805897304, 47.927617754255024, 45.28539500917707, 49.758429867880686, 57.404262338365825, 58.57999134063721, 56.87181493214199, 57.89488158907209, 59.629266602652415, 55.14427389417376, 53.56971134458269, 55.02344124657767, 53.268347127096995, 42.82499967302595, 41.14903858729771, 42.78226130349295, 40.4508627482823, 40.84440524237496, 41.81780964987618, 40.65590756280081, 40.95846687044416, 42.40630122593471, 42.52547672816685, 40.60063116891043, 41.347361019679475, 40.29463250296456, 41.364547388894216, 41.58477749143328, 40.62476226261684, 39.24833106994629, 40.57105963570731, 40.24662045070103, 38.70417594909668, 41.28897530691964, 40.857401847839355, 41.642131396702354, 36.98475388118199, 42.42461667742048, 39.587861742292134, 39.746496064322336, 40.985248701913015, 38.13967997687203, 41.41112116404942, 46.43217781611851, 47.45692593710763, 50.566494941711426, 46.490320341927664, 49.94636821746826, 48.50135135650635, 54.46369089399065, 47.88131495884487, 57.58022199358259, 37.827462673187256, 28.48488358088902, 48.030159269060405, 48.15155472074236, 52.85744455882481, 50.81355551310948, 48.834434100559776, 44.24343272617885, 47.7419445174081, 47.87368583679199, 48.5831663949149, 46.31873457772391, 46.40405150822231, 42.407058579581125, 39.4981118610927, 38.786011832101, 40.729554993765696, 39.14376762935093, 41.20185879298619, 39.28143923623221, 41.864918436322895, 40.838572229657856, 41.35969754627773, 43.18795967102051, 48.654416697365896, 50.494831221444265, 49.54234436580113, 47.16768285206386, 41.03747831072126, 39.95459461212158, 40.187852587018696, 41.348861830575125, 40.42070409229824, 40.61799471718924, 40.91020120893206, 39.00193405151367, 42.71502358572823, 44.24593407767159, 49.59641524723598, 47.713279724121094, 50.374290398189, 46.55090863364083, 44.1717585836138, 41.91742249897548, 42.54802015849522, 43.91146169389997, 43.38267946243286, 49.37051541464669, 49.08912031991141, 48.87032502038138, 54.10895756312779, 55.01101091929844, 58.74217619214739, 57.65214279719761, 59.05526202065604, 56.81333194460188, 51.380434717450825, 10.550102182797023, 6.346101139272962, 12.76518702507019, 1.704720982483455, 0.3210670830948012, 0.39129046350717545, 12.765093224389211, 57.997100012642996, 49.568848269326345, 35.81703267778669, 16.68232430730547, 31.140391281672887, 43.06059571674892, 57.48724814823696, 56.59876462391445, 68.18069948468889, 13.361911347934178, 0.6470145700233323, 0.12656575281705174, 0.11787477774279458, 0.14840805291065148, 0.2256756853312254, 0.1218251543385642, 0.14101865727986607, 0.12978732851999147, 0.12190481434975352, 0.0929445597742285, 0.16657145826944283, 0.13212800292032106, 0.09533756958054644, 0.2635257664535727, 0.095583083906344], [0.018579074214877825, 0.015230446222371288, 0.07117678318172693, 0.047628110008580346, 0.029517379323286668, 0.040852798747697046, 0.04877083422616124, 0.02596807629535241, 0.024692898649456244, 0.03538147233692663, 0.018294328690639565, 0.1055198832015906, 0.12271134821431977, 0.17221282555588655, 5.940060138702393, 50.520324162074495, 51.54982485089983, 54.882333755493164, 42.61066511699131, 29.88130474090576, 28.09415684427534, 40.29804754257202, 34.374201025281636, 46.710404532296316, 23.572838953563146, 0.1974240927291768, 0.2905120812356472, 0.24917453367795261, 12.140302521841866, 7.97006060395922, 4.652971489088876, 43.06824220929827, 60.701380593436106, 57.36448390143258, 56.311362811497276, 51.009112562452046, 46.509493895939414, 42.334974493299214, 40.41788312367031, 42.897010803222656, 47.02301440920149, 51.771451541355674, 54.5417434828622, 52.056098393031526, 54.500995772225515, 50.40998329435076, 52.14833572932652, 45.668793133326936, 40.71996995380947, 37.27607100350516, 38.547125816345215, 37.044581345149446, 38.31845365251814, 37.01953656332833, 37.36368431363787, 37.116331917899, 35.29906184332711, 37.36800956726074, 37.78524194444929, 38.33716862542288, 37.55489526476179, 34.95677621023995, 37.8607063293457, 37.9087427003043, 36.056651728493826, 35.8796637398856, 38.41485643386841, 35.04074171611241, 36.53658812386649, 36.397353172302246, 36.81584317343575, 36.217144693647114, 37.865517956869944, 36.4709415435791, 39.162395749773296, 36.49849809919085, 37.04485927309309, 35.57167441504342, 40.53808348519461, 40.318812234061106, 42.57052884783064, 42.96949093682425, 46.544036865234375, 42.068570137023926, 48.08203451974051, 43.6202210017613, 55.32867561067854, 27.950549738747732, 21.798423630850657, 45.744066442762104, 42.2525132724217, 51.23977885927473, 45.62671136856079, 47.73826197215489, 39.43300724029541, 38.76468781062535, 39.18490443910871, 41.623138495853965, 40.780318532671245, 42.54126303536551, 36.77835069383894, 36.25019032614571, 34.42892503738403, 35.509349073682515, 35.19022873469761, 36.293738160814556, 34.96624313082014, 38.65314490454537, 36.23709297180176, 37.6451940536499, 37.18248919078282, 39.212964739118306, 39.770821707589285, 38.76230110440935, 36.16880260195051, 38.94596978596279, 36.64975690841675, 37.13236141204834, 36.824490206582205, 37.44861561911446, 37.669464111328125, 37.32752936226981, 36.98356573922293, 41.73276717322213, 45.246200220925466, 47.69534294945853, 49.267018522535054, 47.32642139707293, 45.14362049102783, 41.96691451753889, 41.39624159676688, 38.79427324022566, 38.3791948046003, 42.72300706590925, 43.475114822387695, 47.6650071144104, 51.049696990421836, 52.27477557318551, 51.84476545878819, 53.005604471479145, 52.50777646473476, 54.448609828948975, 53.386539459228516, 58.48524570465088, 30.42407022203718, 3.8169138601848056, 3.158033992562975, 0.9786625653505325, 0.0749335465952754, 0.037668898701667786, 2.604679673910141, 31.421279157911027, 34.84254435130528, 32.356312138693674, 16.474533217293875, 19.928373302732194, 37.36781849179949, 44.7961619240897, 45.71174342291695, 50.678246293749126, 21.31456845147269, 0.2743106463125774, 0.01761103205249778, 0.049326137107397826, 0.04431261148835931, 0.04594289365091494, 0.019147097931376526, 0.06092064495065382, 0.01659923286310264, 0.03985164746908205, 0.0390163912171764, 0.03589056019804307, 0.0344598589331976, 0.04416374769061804, 0.060115698858031204, 0.030590529952730452, 0.01707476716754692, 0.07276220739419971, 0.023797315545380116, 0.10038935100393635, 0.0646048119025571, 0.04031571792438626, 0.023120241073359336, 0.0038171411558453527, 0.009228552924469113, 0.025373074026512246, 0.048896946744727235, 0.07666688465646335, 0.07620879209467343, 0.0992594612762332, 8.597806027957372, 60.91249465942383, 56.59302888597761, 62.351320675441194, 47.374388286045615, 36.8160411970956, 25.87624842779977, 39.847286633082796, 38.010394845690044, 53.05875819069998, 26.230398109980992, 0.12508248883698667, 0.10735346124108348, 0.4965089889509337, 11.73286189351763, 7.561356272016253, 5.492736416203635, 45.33887529373169, 63.30966486249651, 58.954304695129395, 58.23682676042829, 53.52575356619698, 47.97934709276472, 43.81696271896362, 43.22372899736677, 45.1115927696228, 51.54015643256051, 52.76705891745431, 56.43343571254185, 53.46307039260864, 56.43621499197823, 52.77567120960781, 53.88742119925362, 47.439260142190115, 43.198607785361155, 40.17832660675049, 39.95107882363455, 38.991636821201865, 40.113520758492605, 38.63009425571987, 38.954453536442344, 38.45124067578997, 37.89119849886213, 38.535831519535606, 39.71112625939505, 38.49426392146519, 39.3624587059021, 37.36846814836775, 40.46876130785261, 39.20201785223824, 37.707338741847444, 36.837372166769846, 39.63972657067435, 37.32590000970023, 38.36860227584839, 36.909907885960166, 38.79561076845442, 37.91037900107247, 39.36654772077288, 39.03624425615583, 39.75600119999477, 38.59924077987671, 37.67499835150582, 36.463913440704346, 43.729523113795686, 41.98536893299648, 44.49422795431954, 43.85752630233765, 47.75646277836391, 43.46761424200875, 49.51141445977347, 45.10116352353777, 57.11505399431501, 29.81003359385899, 21.865503277097428, 46.55402142660958, 43.690710476466585, 52.91959966932024, 46.94154678072248, 48.75123289653233, 42.97995144980294, 41.22980097361973, 40.4052860396249, 44.07106876373291, 42.2666528565543, 43.902536732809885, 39.185762541634695, 39.03691128322056, 36.001100880759104, 37.47221517562866, 36.9354008265904, 38.12688486916678, 37.41559083121163, 40.82204941340855, 37.529311997549875, 39.07165575027466, 37.9997467313494, 40.939453125, 42.59881149019514, 40.37324094772339, 38.88300173623221, 40.79156766619001, 38.8125331061227, 38.86540542330061, 38.26110669544765, 40.07633399963379, 38.88919952937535, 38.79372433253697, 38.76625115530831, 43.718906266348704, 46.97292137145996, 48.94430596487862, 50.118019989558626, 49.628866808755056, 46.99755620956421, 44.686231000082834, 43.18514565059117, 42.86562579018729, 40.2345757484436, 46.08680023465838, 45.07903003692627, 49.20223699297224, 53.042124203273225, 54.060615471431184, 54.894013677324565, 55.68335335595267, 54.447331360408235, 55.975354875837056, 54.600681577410015, 59.26879405975342, 34.48587247303554, 4.7446746826171875, 2.3752310488905226, 2.10893742953028, 0.2641210045133318, 0.05999938438513449, 1.6987422747271401, 36.70860467638288, 37.37489175796509, 30.04520927156721, 18.77590686934335, 27.902697495051793, 45.930886132376536, 50.93257120677403, 50.334432056971956, 57.64486803327288, 31.07186814716884, 0.22587700667125837, 0.06116126025361674, 0.029862271887915473, 0.0289981134368905, 0.06696232754204955, 0.05164579727819987, 0.029756545953984772, 0.044369903592658896, 0.043014607924435816, 0.04316854377144149, 0.05839218598391328, 0.04599516798875161, 0.05187584100557225, 0.03358367344896708, 0.044355474545487335, 0.11622648047549383, 0.09585740882903337, 0.09096834688846554, 0.11615021313939776, 0.2315360972923892, 0.11537083424627781, 0.1425222773104906, 0.18456579984298774, 0.1903470674795764, 0.11694074714822428, 0.1169586061899151, 0.2203423593725477, 0.1681722038026367, 0.19767983257770538, 9.55109018938882, 69.52817058563232, 62.83907726832798, 70.96100725446428, 53.566181659698486, 42.45719330651419, 37.286298751831055, 48.28314665385655, 46.12584563664028, 59.7507141658238, 29.118712152753556, 0.3474917065884386, 0.49383040411131723, 0.5300091313464301, 25.570027419498988, 18.234484127589635, 6.576382679598672, 47.93199511936733, 64.99494348253522, 61.62094688415527, 60.5153842653547, 53.97016382217407, 49.076127188546316, 46.934730597904746, 45.31807933534895, 48.42167983736311, 51.961787019457134, 55.94963264465332, 58.97219630650112, 56.847218309129985, 58.75296674455915, 55.860323974064414, 56.125359535217285, 50.08848319734846, 46.52301161629813, 40.98928560529436, 41.51077570234026, 40.86225169045584, 42.23020608084542, 41.45420694351196, 40.50539915902274, 41.03154454912458, 39.61927454812186, 40.94628667831421, 41.647683007376536, 40.680879388536724, 41.4443405015128, 38.14866052355085, 41.3536491394043, 41.8746771812439, 40.5167281968253, 38.49677569525582, 41.69054644448416, 39.61782584871565, 40.512402943202424, 41.080432074410574, 40.42169768469674, 40.47194358280727, 41.7958151272365, 40.95670550210135, 43.023228304726736, 40.91167075293404, 40.10777807235718, 40.43306493759155, 46.113700185503276, 44.86586972645351, 45.554999010903494, 47.467105048043386, 51.25959512165615, 45.79520171029227, 51.51524019241333, 47.47278867449079, 58.4297365461077, 31.883310045514786, 24.453429324286326, 46.54314054761614, 46.572427204677034, 55.13088124138968, 49.8555656841823, 50.82876511982509, 44.76758745738438, 43.398483140128, 43.74213062013899, 46.46025896072388, 44.95321205684117, 46.934070519038606, 40.006581033979145, 40.602607931409565, 37.56039476394653, 39.20784044265747, 39.14914206096104, 38.93649244308472, 38.716536794389995, 42.67048215866089, 38.87109252384731, 42.11598811830793, 40.73638159888131, 42.43155445371355, 44.95302792957851, 42.99101645605904, 41.010536670684814, 43.21335186277117, 40.82392195292881, 41.430002893720356, 40.80123955862862, 41.81952585492815, 42.27294445037842, 40.39000000272478, 40.982806410108296, 45.87168400628226, 49.84943042482649, 52.030793053763254, 53.316564151218955, 52.063678877694265, 48.943340165274485, 46.41236850193569, 45.582468714032856, 45.13691895348685, 42.70376402991158, 48.49010222298758, 47.09303140640259, 51.5383186340332, 57.15084069115775, 55.746533325740266, 57.216973645346506, 57.709222248622346, 56.06060927254813, 58.99866199493408, 56.485696588243755, 62.04994256155831, 36.20607968739101, 8.344217623983111, 9.842133726392474, 3.1994654493672505, 0.38876514615757124, 0.09709081585918154, 3.5002043289797644, 40.790240560259136, 48.96071413585118, 43.35870470319475, 23.633474145616802, 31.18687125614711, 50.467330251421245, 57.40141705104283, 58.0567364011492, 64.00075353894914, 36.96885640280587, 0.46816115294184, 0.16928988668535436, 0.1616740096360445, 0.10913648842168705, 0.1114127766340971, 0.10116083174943924, 0.13197982444294862, 0.14844306531761373, 0.08004615868308715, 0.10773217199104172, 0.19438663071819715, 0.1360373960009643, 0.12832919747701713, 0.1375490498862096, 0.16501745022833347], [0.020958791520180445, 0.005858001889594431, 0.02877025119960308, 0.03583812979715211, 0.048365596149648936, 0.06581384595483541, 0.024780022545850704, 0.03969976079783269, 0.032138315827718804, 0.027454461536503265, 0.04843532240816525, 0.04333100201828139, 0.037238714285194874, 0.05974939851356404, 15.34908138002668, 47.80463811329433, 51.5109601020813, 50.53074298586164, 35.046178681509836, 25.88593421663557, 37.94347674506051, 32.91546842030117, 34.93377072470528, 52.71600355420794, 14.892499617167882, 0.3676266632974148, 0.34728062791483744, 0.7646596229502133, 8.597468171800886, 6.287315905094147, 2.9102959718023027, 51.85468748637608, 57.60596854346139, 56.98703343527657, 56.784215518406455, 57.71171317781721, 49.24936662401472, 42.91205712727138, 39.595338003976, 40.39981780733381, 40.05281434740339, 41.46096059254238, 48.9882151058742, 51.413852078574045, 50.9096873147147, 52.65713494164603, 49.136392389025005, 40.44518607003348, 39.74617297308785, 38.38975954055786, 37.964210169655935, 37.065641335078645, 36.65498195375715, 37.92952128819057, 38.06383344105312, 36.161909988948274, 38.30545704705374, 38.19998686654227, 37.82967220033918, 35.76190219606672, 39.02138205936977, 37.06678778784615, 37.54718623842512, 35.86578818729946, 36.92091383252825, 36.948341846466064, 38.321246828351704, 35.401137828826904, 37.27497318812779, 35.05652107511248, 36.988363470349995, 36.50440059389387, 36.37257589612688, 34.61195795876639, 37.70497982842581, 35.99519143785749, 38.08774219240461, 35.84289387294224, 39.532759053366526, 37.320101737976074, 42.206345966884065, 38.456767967769075, 44.10429852349417, 40.423882893153596, 47.00168343952724, 44.47852155140468, 55.006143706185476, 30.233522823878697, 22.64566785948617, 47.73929030554635, 38.94063356944493, 49.90589148657662, 46.43443945475987, 48.23298066002982, 41.14006151471819, 41.07309477669852, 38.62907634462629, 40.294149603162495, 38.010440008980886, 39.22709390095302, 35.23714297158377, 36.82187768391201, 35.82597153527396, 36.292716775621685, 35.17598145348685, 36.70492907932827, 36.073490687779014, 37.52354499271938, 37.538803236825125, 36.406837463378906, 36.97685030528477, 37.0785927772522, 35.94471277509417, 37.00706107275826, 36.04267195292881, 36.381153447287424, 36.61542933327811, 36.91723823547363, 35.604257992335725, 38.39667994635445, 37.952349594661165, 38.02205739702497, 39.70081165858677, 46.86596427645002, 48.00966903141567, 52.378421851566856, 50.36318370274135, 47.38281297683716, 47.47338621956961, 43.79289763314383, 41.7583087512425, 39.83254950387137, 40.068534646715435, 42.11203111921038, 46.1775541305542, 47.789463247571675, 48.56167561667306, 50.08035033089774, 53.81001131875174, 51.680426665714805, 49.70252466201782, 54.15530204772949, 55.073440483638215, 55.16578204291207, 54.034848076956614, 14.09615875993456, 0.6852330820901054, 0.5536645448633603, 0.2724948866026742, 0.08173799754253455, 0.17422009498945304, 18.818191868918284, 40.05938734327044, 36.501874923706055, 46.74434995651245, 15.840770653315953, 21.70986189161028, 35.26918111528669, 41.279532705034526, 48.52934912272862, 40.984143938337056, 1.8899897038936615, 0.0818340645304748, 0.0815193396327751, 0.04216481066708054, 0.04663068049454263, 0.06726655550301075, 0.02550335444643029, 0.02860624250024557, 0.024131458418975984, 0.02244496132646288, 0.02029546756031258, 0.019249634750719582, 0.028152709693780968, 0.037627796442913156, 0.06664098692791802, 0.07564923140619483, 0.05736560321279934, 0.04296612999002848, 0.025230020184868147, 0.04175569815561175, 0.02012595085294119, 0.06270781798022133, 0.02198641075353537, 0.043648814250315936, 0.04604775445269687, 0.07018230868769543, 0.025384286817695414, 0.10860881209373474, 0.090815398309912, 20.568854774747575, 58.640788078308105, 56.487770625523154, 57.93916245869228, 39.23731817517962, 36.6700838633946, 45.484975065503804, 32.793920108250205, 36.53438207081386, 59.0155530657087, 14.61508584022522, 0.40767686707632883, 0.1943540746080024, 2.047434364046369, 8.431075317519051, 4.131092292921884, 4.581352063587733, 51.758170059749055, 60.69557884761265, 58.198632512773784, 58.49930191040039, 57.05036973953247, 52.785186767578125, 44.072548730032786, 41.96932554244995, 41.62579270771572, 41.836430822099956, 44.63115610395159, 49.99136127744402, 52.890823704855784, 53.0015675680978, 54.7314327784947, 51.88691323144095, 42.62549604688372, 41.95686742237636, 40.4811429977417, 39.83603055136544, 38.94145345687866, 38.33837761197771, 39.93853037697928, 39.01882859638759, 37.05703946522304, 38.54093497140067, 38.83522939682007, 38.712232385362896, 39.009507587977815, 40.20197132655552, 38.67967312676566, 38.984407220567974, 37.21139717102051, 38.780446325029644, 38.16702113832746, 39.085416657584055, 36.647755827222554, 38.074648312159944, 36.95694719042097, 39.74585683005196, 38.30767004830496, 37.89517286845616, 37.14551087788173, 39.877646786826, 36.67287009102957, 39.35612194878714, 38.17835365022932, 41.32346616472517, 39.83238622120449, 42.494199412209646, 41.2443505014692, 44.701332909720286, 41.34617635181972, 49.17463527406965, 44.618607657296316, 56.675722871507915, 31.008903571537562, 24.261989082608903, 48.592775753566194, 41.72192798342024, 50.74964598246983, 45.96398040226528, 50.27042872565133, 43.82370247159685, 42.16385425840105, 40.34962054661342, 42.2957067489624, 40.42252452032906, 41.87694229398455, 37.54705769675118, 38.20924186706543, 38.17478575025286, 38.68737173080444, 37.64415529796055, 37.50478138242449, 38.209519795009065, 39.56505080631801, 38.63077170508248, 38.54263728005545, 39.490441049848286, 39.385651792798726, 37.88222142628261, 37.83112089974539, 38.302014214651926, 37.78261552538191, 37.830050877162385, 38.26637690407889, 37.41047695704869, 40.14272403717041, 39.37923860549927, 39.96385656084333, 42.38186093739101, 49.303145681108745, 50.60187864303589, 53.359045437404085, 49.936432293483186, 49.379638399396626, 48.96773876462664, 45.995591231754844, 43.21669742039272, 39.72955635615757, 41.23632880619594, 44.33719171796526, 46.861343724387034, 50.38593905312674, 51.48678037098476, 52.73869637080601, 55.4708948135376, 55.662651198250906, 51.23132637568882, 54.813372884477886, 56.6929474558149, 56.47593436922346, 57.769067083086284, 17.754365342003958, 1.5772427086319243, 2.8974164000579288, 0.9069007017782756, 0.10681368663374867, 0.17508209230644362, 18.25978078160967, 46.50445645196097, 32.66292919431414, 36.55162055151803, 19.934284482683452, 31.6189797265189, 41.903751918247764, 46.941341808864046, 52.486598355429514, 52.793778215135845, 3.6438429185322354, 0.12194145524076053, 0.03814746266497033, 0.0633842223989112, 0.09969243447163276, 0.06423303578048944, 0.01596833948445107, 0.05149154930508562, 0.029700336113039936, 0.030665453789489608, 0.03825310717469879, 0.04727024046171989, 0.03685502987354994, 0.0643651397632701, 0.006699541799857148, 0.14009895734488964, 0.16017606215817587, 0.14190688676067761, 0.24790608031409128, 0.1273691789912326, 0.1490001289972237, 0.11472359326268945, 0.09201707704258816, 0.09571140166372061, 0.22655698018414633, 0.2060183629925762, 0.17286966102463858, 0.2208709381520748, 0.16591078229248524, 23.51486665861947, 68.20112024034772, 61.20894650050572, 65.68124485015869, 44.786535194941926, 34.47301830564226, 45.241861070905415, 43.33501829419817, 46.67015014375959, 65.05511488233293, 17.571504388536724, 0.5773712556277002, 0.4845481536218098, 1.8798496765749795, 18.95319710459028, 11.607003092765808, 4.634147950581141, 57.15771245956421, 61.87907246180943, 61.60671697344099, 60.178368840898784, 62.95429229736328, 53.22351387568882, 48.24992036819458, 43.367435114724294, 43.922738620213096, 43.84853185926165, 46.38345009940011, 52.92965718678066, 57.943967138017925, 55.16372537612915, 59.405256680079866, 53.14992897851126, 44.4884227343968, 43.27749068396432, 42.82117816380092, 41.43576989855085, 40.13534157616751, 38.012531416756765, 41.55685268129621, 42.24399825504848, 40.35257005691528, 41.374399934496196, 42.089689186641145, 40.858669894082205, 41.45583629608154, 41.27840709686279, 40.73826803479876, 42.560099601745605, 40.07930088043213, 40.060287134987966, 39.848572049822124, 42.470867361341206, 38.73430681228638, 40.071880204336985, 38.890887941632954, 40.38876322337559, 40.434079374585835, 40.821993827819824, 38.75777087892805, 42.01467990875244, 38.82377181734358, 40.74698454993111, 40.54666798455374, 43.77010406766619, 42.18463979448591, 46.67701843806675, 42.48219639914376, 47.27906594957624, 43.41489131110055, 51.85340206963675, 48.06460148947579, 58.016874585832866, 34.18268435341971, 26.504949229104177, 49.17277315684727, 42.702405657087056, 52.27264595031738, 49.80916213989258, 52.92060020991734, 44.95242691040039, 44.70134333201817, 43.31595243726458, 43.983907086508616, 42.49283756528582, 42.6589481489999, 38.60284342084612, 40.681608949388774, 39.161134651729036, 40.173230103084016, 39.997558798108784, 40.302122661045615, 41.47811916896275, 40.080162457057405, 40.96819087437221, 39.83509601865496, 41.15293305260794, 41.57518550327846, 40.44230604171753, 39.33146974018642, 39.754674094063894, 38.88806002480643, 40.6747510773795, 40.54191541671753, 39.86253098079136, 42.15909821646554, 42.343319279806956, 41.465973717825754, 43.819741998400005, 51.50902850287301, 53.24856560570853, 54.917595863342285, 51.77659668241228, 51.50284808022635, 51.8508277620588, 47.69878578186035, 45.641747270311626, 43.19133996963501, 43.8235878263201, 47.159341539655415, 50.46155629839216, 51.7388471194676, 52.972117628370015, 54.58859518596104, 58.89593287876674, 55.63264192853655, 53.941276686532156, 57.46719912120274, 58.916548183986116, 60.84229006086077, 61.76141166687012, 20.77950852257865, 9.307699135371617, 6.000400032315936, 0.6797145839248384, 0.25288970289485796, 0.26562314533761566, 23.139356476919993, 54.49358204432896, 48.886177335466655, 58.12566600527082, 24.798037392752512, 33.88070522035871, 45.58067260469709, 53.646245752062114, 60.5992351259504, 61.645585196358816, 5.434049325329917, 0.2318689322897366, 0.15672326886228152, 0.17171018038477215, 0.1860347060220582, 0.1861634919685977, 0.08102986482637269, 0.26986382635576384, 0.1225356754979917, 0.1277408804744482, 0.17146678987358296, 0.12858531730515615, 0.13589414368782723, 0.17440462937312468, 0.12562887237540313], [0.09322438083056893, 0.0053563325366537485, 0.00889795454817691, 0.030804539897612164, 0.06008838103818042, 0.025130816668804203, 0.037400032593203444, 0.01717351097613573, 0.03652846114709973, 0.03861875273287296, 0.008079480163619986, 0.06380334669458014, 0.02177729643881321, 0.13848522465143884, 30.484116554260254, 54.194878986903596, 51.3521659714835, 46.03003345217024, 30.470803805759974, 16.996831042425974, 18.214662654059275, 38.98744010925293, 41.94676126752581, 47.7425594329834, 3.6988153287342618, 0.3043789214321545, 0.22985384613275528, 0.990489159311567, 6.1016665526798795, 2.201744083847318, 10.724426405770437, 53.31521620069231, 56.10878808157784, 56.54035806655884, 56.821166038513184, 53.79922424043928, 49.43326459612165, 44.327797753470286, 39.805739879608154, 38.73725979668753, 39.24874101366316, 38.30693006515503, 37.791523115975515, 40.071115902491975, 41.56749732153756, 40.915558270045686, 39.505195549556184, 36.60535791942051, 37.934548309871126, 37.7759348324367, 38.485161781311035, 37.70492771693638, 38.23772600718907, 37.72101974487305, 39.031839098249165, 36.66990668433053, 38.35485526493618, 37.553682804107666, 37.62971346718924, 35.9765112059457, 39.19675459180559, 37.43497977937971, 37.351511069706504, 34.65726716177804, 35.805408341544016, 35.56594215120588, 36.47520773751395, 36.420469829014365, 36.994133949279785, 36.919701371874126, 35.12831333705357, 36.05153785433088, 37.342200483594624, 34.96924475261143, 36.88126046316964, 35.19103472573416, 37.239082268306184, 38.0164988381522, 39.52987902505057, 39.57344423021589, 42.02275718961443, 40.837971210479736, 44.59136029652187, 38.95854255131313, 48.76745694024222, 44.901871817452566, 54.093581199645996, 27.08761821474348, 26.97837863649641, 57.19974558694022, 44.74503013065883, 51.38553122111729, 46.02573946544102, 47.717695304325645, 42.62108046667916, 40.52900218963623, 35.78418854304722, 36.23506409781319, 36.5284309387207, 37.21974195752825, 35.872069358825684, 35.76165900911604, 34.98674726486206, 35.21246297018868, 36.173979009900776, 38.08961820602417, 35.197837012154714, 37.79124171393258, 36.995256083352224, 35.59652464730399, 34.91192558833531, 36.756241525922505, 36.72246980667114, 37.87194504056658, 36.57153408867972, 37.32567419324602, 36.59863553728376, 37.92166634968349, 37.43548699787685, 38.87564706802368, 36.39457736696516, 39.539189611162456, 47.65422351019723, 49.671424525124685, 49.75170053754534, 49.07021427154541, 49.33190427507673, 47.94360555921282, 48.415544578007285, 45.55408879688808, 42.74886131286621, 39.96468687057495, 37.8490264075143, 41.22408608027867, 47.20437281472342, 48.01962232589722, 50.61212028775896, 48.815903254917686, 51.3473265511649, 47.77768952505929, 52.730091026851106, 52.889024121420725, 53.275104250226704, 50.9548054422651, 63.047849791390554, 31.73750557218279, 0.3033346017556531, 1.5549708008766174, 0.8100634951676641, 0.06704481025891644, 0.09430427609809808, 6.3111686365945, 41.63322728020804, 35.29688705716814, 41.16745826176235, 24.92651653289795, 11.804957270622253, 21.747736522129603, 34.47893469674246, 44.24375581741333, 45.783382824489046, 9.028074094227382, 0.15420261983360561, 0.07896092334496123, 0.017634614537070905, 0.05465181936909046, 0.0442776771129242, 0.0728706508608801, 0.05030012323654123, 0.05250645448852863, 0.028031158626877835, 0.06197261850216559, 0.015324949187093546, 0.04645556078425475, 0.0425212213636509, 0.06280433958662407, 0.017816852079704404, 0.021933072812056968, 0.034782987487103255, 0.011206887080334127, 0.035404718946665525, 0.04379697576431291, 0.05984957742371729, 0.019317060775522674, 0.051624345393585305, 0.027391288229929547, 0.061874848391328535, 0.06819658274097101, 0.020248078674610172, 0.1774782980126994, 39.270384652274, 63.425588607788086, 56.49002879006522, 53.03224039077759, 32.61356224332537, 23.80858612060547, 19.823229687554495, 32.229417187826975, 44.19551794869559, 53.649136202675955, 3.886548706463405, 0.28632812574505806, 0.4329762080950396, 2.396898789065225, 7.349848764283316, 2.768670839922769, 12.51510398728507, 55.19103179659162, 59.002719742911204, 58.67643233707973, 59.235762323652, 55.585661683763774, 51.90282808031355, 45.87261506489345, 42.72063773018973, 40.45617464610508, 42.1130941935948, 40.125971930367605, 39.51021214893886, 41.687409332820344, 43.77663884844099, 42.895259857177734, 41.62052249908447, 37.59349250793457, 40.75382852554321, 39.22118098395211, 39.98095260347639, 39.18397685459682, 40.760457106998985, 39.70098188945225, 40.69750990186419, 38.820982115609304, 40.18499687739781, 40.0138384274074, 39.17203984941755, 38.39425155094692, 41.037144797188894, 38.449983051845, 39.35737609863281, 37.16201284953526, 37.02596017292568, 37.83694349016462, 39.40361288615635, 38.09706667491368, 37.708645003182546, 37.91260589872088, 37.908186844417024, 37.676579066685264, 38.075429984501426, 37.28529126303536, 39.567823137555806, 37.07563631875174, 39.13865375518799, 38.457737241472515, 41.08385753631592, 40.269896915980745, 43.87404564448765, 43.092779772622244, 46.01689788273403, 41.130125590733115, 50.325093678065706, 47.554808684757774, 56.49055337905884, 28.788144656590053, 27.451599597930908, 58.39246640886579, 46.1860066141401, 53.260311535426546, 47.1840250151498, 49.77664457048689, 45.485840116228374, 42.637283665793284, 37.686039039066856, 37.53976903642927, 39.84664739881243, 40.97629942212786, 37.21756717136928, 37.143548011779785, 37.047694138118196, 38.139488901410786, 36.87699426923479, 38.5850247655596, 36.99396024431501, 39.521773951394216, 38.36573614392962, 37.96374464035034, 37.10765709195818, 37.21249846049717, 37.405898094177246, 39.66642502376011, 37.96207707268851, 38.592709473201204, 37.09309714181082, 38.34429400307791, 39.02304267883301, 40.15657179696219, 38.56224857057844, 40.94753040586199, 49.00286190850394, 51.620394229888916, 51.26717560631888, 50.44380712509155, 51.273554052625386, 50.373414925166536, 50.40259735924857, 47.66794620241438, 43.46679435457502, 41.60701520102364, 40.70597628184727, 43.38059152875628, 48.58632435117449, 50.48292200905936, 52.29695769718715, 52.2988406590053, 53.64480747495379, 49.092952251434326, 53.80663449423653, 55.732084546770366, 54.64443785803658, 54.84539018358503, 61.55335480826241, 37.02928141185215, 0.3034980744123459, 4.170598013060434, 0.960209886942591, 0.19620813083435806, 0.0968574405248676, 5.522659267698016, 48.01879549026489, 37.764261858803884, 41.16005495616368, 23.38439164842878, 15.941580329622541, 26.246521404811315, 40.78245162963867, 49.23622063228062, 54.936793736049104, 15.770289863858904, 0.26751861934150967, 0.0365639213871743, 0.021872981750805463, 0.07776434041027512, 0.050757659399615865, 0.05772370006889105, 0.05190233779805047, 0.026814937192414488, 0.019025590969249606, 0.041230298312647004, 0.03515777291197862, 0.06763742238815341, 0.08263639147792544, 0.026234219782054424, 0.21062001106994493, 0.10945446350212608, 0.1066895690081375, 0.06375444467578616, 0.12613003834017686, 0.08854651291455541, 0.134995627616133, 0.07960421525474105, 0.17413913219102792, 0.06982152483292989, 0.15782265844089644, 0.18609893614692347, 0.13545893132686615, 0.39139001816511154, 47.310965129307334, 71.67173154013497, 65.58134365081787, 60.30140059334891, 40.64021505628313, 25.808121340615408, 25.479681730270386, 52.589601925441194, 53.96572044917515, 58.100284235818044, 5.611480695860727, 0.6277394528899873, 1.145621806383133, 3.1956209242343903, 15.750089713505336, 8.713653343064443, 14.082093000411987, 58.91908427647182, 60.34265899658203, 61.195946420942036, 62.006780351911274, 58.55376883915493, 52.78107690811157, 47.78503377096993, 43.0699862071446, 43.89167322431292, 44.6233081136431, 42.876874923706055, 40.977814129420686, 43.18798746381487, 45.76225682667324, 44.9431163242885, 43.21649592263358, 40.85558489390782, 43.719712257385254, 42.22519642966134, 42.12461083275931, 41.674968583243235, 41.790562289101736, 41.1383626801627, 44.18874345506941, 41.83225148064749, 41.334086486271445, 42.224053450993125, 39.41828053338187, 40.483272620609824, 42.57930094855172, 40.61689690181187, 40.37014552525112, 38.459957190922324, 38.5825685773577, 39.263950620378765, 40.89381388255528, 40.507164001464844, 39.34890277045113, 41.483378955296104, 39.24868195397513, 39.551904814583914, 40.28527675356184, 39.21366998127529, 42.88320473262242, 39.353912421635215, 40.95701469693865, 42.77788046428135, 43.40451070240566, 42.90377140045166, 45.16719920294625, 45.62113543919155, 48.797664233616416, 42.55669151033674, 53.581974915095735, 50.2339437348502, 57.820647035326274, 31.37306908198765, 30.4995311328343, 61.23742716653006, 50.08206653594971, 55.00081096376692, 50.42327172415597, 53.01559945515224, 46.9243152482169, 44.85548564365932, 39.31078495298113, 39.32698815209525, 41.77712099892752, 42.47782250813076, 40.741019521440776, 39.58869900022234, 37.9524746622358, 40.14310966219221, 39.17238031114851, 40.590448583875386, 40.110414913722444, 41.932927404131206, 40.879045486450195, 38.89651598249163, 39.4378536088126, 39.74247305733817, 39.737678800310405, 42.250150884900776, 39.564588751111714, 40.42966379438128, 38.998831680842805, 40.5221825327192, 41.44713020324707, 42.14054305212838, 40.278147901807515, 43.18553474971226, 50.81288153784615, 54.69761937005179, 53.949499879564556, 51.80521978650774, 53.35287543705532, 51.707781723567415, 53.18552459989275, 49.89972496032715, 48.12809760229928, 45.04996919631958, 42.312215668814524, 46.51531648635864, 52.61399705069405, 53.25687912532261, 55.35443953105381, 52.136513369424, 55.104446819850374, 50.77170303889683, 56.864043372017996, 57.46321432931082, 58.07606976372855, 56.66278879983084, 66.70628479548863, 38.756190163748606, 2.1032438150474, 8.396138906478882, 2.390110399041857, 0.23121699584381922, 0.18194879884166376, 8.160637531961713, 53.13890566144671, 47.21593461717878, 56.376912117004395, 33.31682416370937, 20.05671000480652, 30.406133447374614, 48.26739856175014, 57.447994300297324, 62.326050077165874, 19.99777364730835, 0.5183506512216159, 0.19248604056026253, 0.18555681380842412, 0.134447222043361, 0.14287841320037842, 0.17619277270776884, 0.1862064568059785, 0.14210994515035832, 0.08866583329758473, 0.2223251879747425, 0.09890267399272748, 0.09314236630286489, 0.15671161163066114, 0.11644110110189233], [0.0030151958843427046, 0.06767289619892836, 0.038199818427009244, 0.03417648574603455, 0.02102480279946966, 0.07823029719293118, 0.031880116289747615, 0.037761895318648646, 0.024277859134599566, 0.03208617380421076, 0.02215054158919624, 0.015091411004375135, 0.08920629322528839, 1.6881592997482844, 45.160171100071494, 55.733884130205425, 51.44227715900966, 45.1443361554827, 26.711227348872594, 14.42368641921452, 43.30780220031738, 41.69555956976754, 45.12552738189697, 38.31175211497715, 0.22611388324626855, 0.06694201898894139, 0.1349801298763071, 4.903054526873997, 5.589616017682212, 1.3549825378826685, 17.223477806363785, 51.30017260142735, 57.11414725439889, 56.120103222983225, 55.57671935217721, 53.69971908841814, 49.15245662416731, 43.25725058146885, 39.46220704487392, 40.068142073495046, 38.37492166246687, 36.930815015520366, 37.57508325576782, 35.9977240562439, 37.70303780691964, 38.3961067199707, 38.33903421674456, 37.01892164775303, 37.231717177799766, 39.46988133021763, 37.303269726889475, 36.596585818699424, 37.967760699135916, 37.2537499155317, 38.81478084836687, 39.169889381953645, 41.187048707689556, 40.67180156707764, 41.445959431784495, 37.71999488558088, 36.55238137926374, 38.34949820382254, 37.32087646211897, 35.25243248258318, 36.86686726978847, 36.02298075812203, 37.67658601488386, 36.414390155247276, 35.94885042735508, 35.295723233904155, 36.39641516549246, 36.3216039112636, 37.52760968889509, 36.89307240077427, 36.11558287484305, 38.83219998223441, 40.51469932283674, 41.51571587153843, 42.35514858790806, 39.74273361478533, 42.5634104183742, 41.18414436067854, 42.88949632644653, 41.12479632241385, 46.21036352430071, 43.11793572562081, 53.852641991206575, 27.214059795652116, 30.00362777709961, 53.890544414520264, 41.71810300009591, 49.659640380314414, 45.768357345036094, 46.381355217524934, 41.25482838494437, 40.71967118127005, 34.18897247314453, 37.608976568494526, 36.27519341877529, 37.66320031029837, 34.51939753123692, 36.06523970195225, 34.78285237721035, 36.45707988739014, 35.77647256851196, 36.13251910890852, 35.443636485508506, 37.23163727351597, 36.49619824545724, 36.429106439862935, 36.49804646628243, 37.39616366795131, 36.29849420275007, 37.40152767726353, 36.52726016725813, 38.45803253991263, 35.91417891638619, 36.69791834694998, 35.066352776118684, 37.796171460832866, 37.774416651044575, 44.58125761577061, 47.177552768162315, 48.575318404606406, 49.240135942186626, 50.048173223223, 49.17030654634748, 51.86653763907296, 47.83865301949637, 45.80565527507237, 41.044228485652376, 36.34329271316528, 39.58458914075579, 43.26334067753383, 46.2756279536656, 47.76627710887364, 44.562525272369385, 47.927471842084614, 47.32599408285958, 49.88423047746931, 52.0917044367109, 53.15131861822945, 47.90051630565098, 52.57546581540789, 58.1785626411438, 50.187981401171, 0.9899050763675145, 2.3320599368640353, 0.4683536940387317, 0.09439431090972253, 0.05507241269307477, 1.254889503121376, 34.776050090789795, 39.41331604548863, 32.39070224761963, 43.109886237553184, 25.0473370211465, 14.286578484943934, 36.08731065477644, 45.54791184834072, 48.17757225036621, 29.58330692563738, 0.8113749133689063, 0.03178684147340911, 0.12520443515053817, 0.032145742393497906, 0.04339623298229916, 0.035879327050809345, 0.027753281573365842, 0.04315169235425336, 0.053289731565330706, 0.027852551246594106, 0.05904395958142621, 0.011463669328285115, 0.03723475842603615, 0.01326928663599704, 0.03537585745964732, 0.07000832552356379, 0.04397682825635586, 0.03399011931781258, 0.02486099043328847, 0.012606534341882383, 0.017696388365168656, 0.021180663989590745, 0.02907051651605538, 0.02033195408460285, 0.04577436251565814, 0.027551332588440607, 0.09322259628346988, 2.942389266831534, 57.41321161815098, 61.49897125789097, 57.94096551622663, 50.421513829912456, 36.850643226078574, 16.951646906988962, 35.651971272059846, 41.672071184430806, 49.63849353790283, 40.664116859436035, 0.1858159870441471, 0.04871631393741284, 0.1425140398953642, 3.63570180109569, 4.573451961789813, 2.799089619091579, 17.938636779785156, 54.12675884791783, 57.90176377977644, 58.41525650024414, 57.355951513562886, 55.99042204448155, 49.86288561139788, 45.98168093817574, 41.86465093067714, 42.427156244005474, 38.9405015536717, 38.7740227154323, 39.37302344185965, 38.710901805332725, 39.36963619504656, 40.32420751026699, 40.61508689607893, 39.201979637145996, 40.315157481602256, 39.94916459492275, 39.04271650314331, 39.71753944669451, 39.06308862141201, 40.692270960126606, 40.082392828805105, 40.78724936076573, 43.38923161370413, 42.47070060457502, 43.886878967285156, 39.528392110552105, 39.8758020401001, 39.71267223358154, 38.546208654131206, 36.959823744637625, 38.34639583315168, 38.68915741784232, 38.64787122181484, 38.114746366228374, 36.80332946777344, 36.48789167404175, 40.19196939468384, 38.31014708110264, 38.845269543784006, 38.06077970777239, 38.35858992167881, 39.427455629621235, 41.40076834814889, 43.24366685322353, 43.42433043888637, 41.48259033475603, 43.92006008965628, 43.23506498336792, 46.647325311388286, 42.06259816033499, 47.8241799218314, 46.503792898995535, 56.14745133263724, 29.408587523869105, 31.597714764731272, 56.38530554090227, 42.645645822797505, 50.72035585130964, 44.934128829411094, 49.054132665906636, 42.83752727508545, 41.56123352050781, 36.91886758804321, 40.33999729156494, 38.766720158713206, 39.767038413456504, 37.085735525403706, 37.63704034260341, 35.54097032546997, 38.512318815503804, 36.495864731924875, 38.05005168914795, 38.556293964385986, 38.3548378944397, 39.35663958958217, 37.4795628956386, 39.100584575108115, 39.47306360517229, 36.535736969539094, 39.19233553750174, 39.19935669217791, 38.82363632747105, 37.326379435403005, 37.54403870446341, 37.2881052834647, 39.73258924484253, 39.25914246695382, 47.97649138314383, 49.22466230392456, 50.32203647068569, 49.20854248319353, 51.696890422276084, 51.313120569501606, 52.887669222695486, 50.692403248378206, 47.70391355242048, 42.65130513054984, 39.639132499694824, 41.13072313581194, 44.97551924841744, 49.501138074057444, 50.87063149043492, 46.18834120886666, 48.58594914845058, 48.94899599892752, 51.51765816552298, 54.913444314684185, 56.04416636058262, 50.97974252700806, 55.989494459969656, 59.06133474622454, 51.609666211264475, 1.096779118691172, 2.829628688948495, 3.991609811782837, 0.4632872630442892, 0.06962308048137597, 0.8761817930000169, 37.03053903579712, 43.22856146948678, 34.94789293834141, 45.84666006905692, 27.88818791934422, 16.909999404634746, 40.544371604919434, 50.46109076908657, 56.18038231985909, 40.68080643245152, 1.444789198892457, 0.038005838835878034, 0.0251285571471921, 0.04743608459830284, 0.051462487650236914, 0.0596328465534108, 0.01112666049240423, 0.004227349501369255, 0.011154379496084792, 0.01031504524871707, 0.07424230940107789, 0.05902673836265292, 0.03170890494116715, 0.02332211202675743, 0.07293138653039932, 0.15081488447529928, 0.09329781867563725, 0.11814544536173344, 0.10962371049182755, 0.22509395011833735, 0.14381439797580242, 0.14298236476523535, 0.07976436308984246, 0.08303689677268267, 0.18171365931630135, 0.14694787269192083, 0.16754331040595258, 3.4687895689691817, 68.82797282082694, 68.99696690695626, 67.29312270028251, 56.5641313280378, 37.97319419043404, 21.176693609782628, 56.942756039755686, 54.64144318444388, 55.2531486919948, 46.82989617756435, 0.42733166526470867, 0.10489552241883107, 0.5139363738042968, 11.87374096257346, 11.948907443455287, 4.170899391174316, 20.915611573628016, 53.492218085697715, 61.19502925872803, 59.23023155757359, 58.97731018066406, 57.36554002761841, 54.113081318991526, 47.43467433112008, 42.78404004233224, 44.45017984935215, 41.0445932660784, 39.968463216509136, 41.70375844410488, 39.76153891427176, 41.966695649283274, 41.95348712376186, 44.329819679260254, 41.097687925611226, 42.581434045519146, 42.574103696005686, 42.05370099203927, 41.46772813796997, 41.12210042136056, 42.20568241391863, 42.28335632596697, 42.64917550768171, 46.151362895965576, 44.13128185272217, 45.767381123134065, 41.48100961957659, 41.07375832966396, 42.85341433116368, 40.30753183364868, 38.82948671068464, 41.41066605704171, 39.77378511428833, 41.10630716596331, 39.81595025743757, 38.11025782993862, 38.808874879564556, 40.8635926927839, 39.73239469528198, 40.973089354378835, 40.296223640441895, 39.01940529687064, 42.04740939821516, 43.543439933231895, 46.09055226189749, 45.835358824048726, 43.22553205490112, 46.757155486515586, 45.94963584627424, 48.70249475751604, 43.70256757736206, 49.99050317491804, 47.98737573623657, 58.74430928911482, 31.226340498243058, 34.32521275111607, 57.60516255242484, 45.53804193224226, 53.19844477517264, 48.49661615916661, 52.05270072392055, 44.87965842655727, 44.972958837236675, 39.07207611628941, 41.34566913332258, 40.63738366535732, 42.5167532648359, 38.70673288617815, 39.40987321308681, 38.33710609163557, 40.40822860172817, 38.578382287706646, 40.47332280022757, 40.05310617174421, 39.727593490055625, 40.28397396632603, 39.633987358638215, 39.71325935636248, 41.17953423091343, 39.36677006312779, 42.1686554636274, 40.57555512019566, 41.348090580531526, 38.93630484172276, 40.863352979932515, 39.20461300441197, 41.70541558946882, 41.810809339795796, 48.94706439971924, 51.34324101039341, 52.122384207589285, 51.825675283159526, 53.70980439867292, 52.91883536747524, 56.39430693217686, 52.97833626610892, 50.466121264866416, 46.21285792759487, 41.96778999056135, 44.244551386152, 47.39741461617606, 50.63575805936541, 53.12539488928658, 49.02376903806414, 54.15312378747122, 51.036585739680696, 54.12049157278878, 56.33718579156058, 58.770788873944966, 52.349027497427805, 59.009424754551475, 61.21140616280692, 57.041180746895925, 1.4010872010673796, 7.466651456696646, 4.343332835606166, 0.371197195989745, 0.16248039422290667, 1.923792038645063, 41.144299915858674, 51.630538599831716, 44.15908506938389, 54.896577562604634, 36.93862131663731, 21.37676351411002, 49.470663275037495, 57.96766744341169, 63.8074129649571, 47.61316313062395, 1.9415844210556574, 0.1556248835154942, 0.23702984250017575, 0.16453121203397, 0.13602742153619016, 0.13430935729827198, 0.1514695757733924, 0.11410544786070075, 0.11873160462294306, 0.11139155884406396, 0.19285363012126513, 0.10324744906808649, 0.13296519299702986, 0.09800984404448952], [0.0597122690773436, 0.016809093566345315, 0.06000906029450042, 0.0736828369221517, 0.033664836415222714, 0.04419691108965448, 0.03588465015803065, 0.10134192596056632, 0.1008608378469944, 0.020966077289943184, 0.07810319401323795, 0.057025060057640076, 0.179587741249374, 8.284716725349426, 54.990534578050884, 51.54494374138968, 50.64355393818447, 25.256783519472393, 12.775668382644653, 22.330134528023855, 33.80733919143677, 31.2027131489345, 52.0363655090332, 20.46340196473258, 0.03817530295678547, 0.029862743469753435, 0.15714075788855553, 1.1006816178560257, 3.2507644338267188, 4.327348070485251, 20.621513434818812, 51.245966230119976, 54.139783246176584, 57.67809779303414, 55.80298743929182, 50.5915709904262, 49.132081031799316, 49.732033661433626, 47.76272657939366, 47.93665388652256, 42.52107851845877, 39.64858899797712, 36.75802026476179, 36.847617285592214, 37.75398894718715, 37.620611327035085, 37.615629468645366, 37.2665867124285, 37.005049569266184, 39.13043751035418, 37.52542448043823, 36.579993520464214, 37.15351867675781, 36.35100868770054, 37.22103084836687, 38.24272871017456, 42.23203345707485, 43.164408751896445, 45.346271651131765, 44.033923694065635, 39.53023338317871, 38.0568539755685, 37.170885699135916, 37.2542849268232, 36.95281648635864, 35.40244409016201, 38.23001003265381, 36.04466608592442, 36.146064622061594, 35.52136598314558, 36.459546497889924, 35.65914528710501, 36.45545053482056, 35.671255997249055, 41.84286485399519, 42.484364237104145, 43.72812305177961, 40.47260366167341, 42.36578975405012, 39.73956871032715, 42.69075352805001, 40.30360262734549, 44.10422556740897, 40.6749838420323, 47.35831710270473, 42.857023920331685, 52.670895848955425, 29.738161427634104, 30.601888520377024, 55.277547291346956, 43.34070192064558, 45.94181912285941, 39.9252975327628, 43.96640804835728, 36.27289703914097, 38.10775647844587, 35.28644738878523, 36.547941480364116, 36.19673783438546, 36.870737416403635, 34.32427821840559, 35.936906473977224, 33.853711468832834, 37.02181557246617, 35.72028248650687, 37.603265149252756, 37.58065571103777, 36.70952878679548, 36.16824674606323, 37.55092436926705, 36.765836988176616, 36.81658663068499, 36.27017681939261, 36.930926186697825, 36.829225403921946, 36.89623383113316, 36.839001519339426, 38.0514725957598, 38.36192158290318, 36.33714703151158, 39.79243755340576, 47.478302070072715, 49.21387869971139, 49.81712824957711, 47.64540277208601, 51.71406289509365, 46.78590018408639, 47.67895909718105, 43.29237372534615, 41.616450854710166, 40.542273248944966, 39.534857409340994, 37.97777305330549, 42.31592948096139, 46.13557658876692, 50.851482255118235, 45.76863179888044, 40.40122481754848, 42.91498926707676, 54.38477325439453, 49.91847120012556, 55.367175579071045, 43.314903259277344, 52.52541446685791, 51.1461831501552, 61.901021821158274, 6.714355664593833, 2.2647073566913605, 0.4002675360866955, 0.7912020672644887, 0.15969032607972622, 0.04982218352545585, 23.14182482446943, 47.4252803666251, 29.067903450557164, 67.61363615308488, 36.252764633723665, 21.10381916591099, 35.698294912065776, 39.789036410195486, 44.00840990883963, 43.01838541030884, 5.270449212619236, 0.21757276941623005, 0.02480087392697377, 0.01076148821240557, 0.028262795215206485, 0.03021928308797734, 0.022974657992433225, 0.0246048400710736, 0.04557031346485019, 0.07877572399697133, 0.033274634674723656, 0.02917783361460481, 0.011955047425414835, 0.0196911608800292, 0.022997332936418906, 0.03786585706153086, 0.023257279702063118, 0.008034372003749013, 0.04197849512898496, 0.04875640178631459, 0.020731784237016524, 0.05037021251129253, 0.018402253078030686, 0.03308081453932183, 0.03195310290902853, 0.024800337884309034, 0.10472227207251958, 11.49520310333797, 66.62961142403739, 57.85500587735857, 57.10131393160139, 32.54037339346749, 18.37527894973755, 16.769475562231882, 35.1490432875497, 34.532084941864014, 57.535402638571604, 23.831476960863384, 0.020598073822579215, 0.016510521194764545, 3.13192309652056, 4.449054888316563, 6.745421494756426, 4.0291900123868665, 22.899292741503032, 53.23976223809378, 55.309463841574534, 59.31586810520717, 55.84242194039481, 53.045709473746165, 51.56820631027222, 53.16045202527727, 49.97163881574358, 50.13291692733765, 44.636332511901855, 40.05930743898664, 37.72884341648647, 39.133352279663086, 40.21479422705514, 39.511834553309846, 39.9216809953962, 38.84578023638044, 38.482055936540874, 39.397349085126606, 39.37586872918265, 39.588247367313926, 39.61802387237549, 39.25218384606497, 39.00502947398594, 39.313234192984446, 46.24677903311593, 44.79899678911482, 46.32538400377546, 45.462362153189524, 42.266190801348, 39.902441433497835, 38.824619497571675, 37.87227507999965, 38.75505065917969, 37.20298637662615, 38.60690116882324, 38.69160318374634, 37.075049195970806, 37.67303548540388, 38.62584890638079, 37.09692907333374, 39.09700625283377, 37.288219928741455, 42.44843857628958, 44.31412717274257, 44.982331957135884, 43.67315237862723, 45.102282183510916, 40.99936049325125, 44.85955033983503, 41.960136549813406, 46.14931665148054, 43.5485850742885, 49.18369919913155, 43.90359285899571, 55.2875839642116, 32.22966037477766, 32.89769492830549, 56.953431946890696, 44.617509841918945, 48.21639878409249, 41.348493576049805, 45.91284166063581, 37.30007355553763, 39.57793624060494, 36.273567540305, 39.096512930733816, 38.03861148016793, 38.24483748844692, 37.32587569100516, 38.87857920782906, 34.836916310446604, 37.36547000067574, 37.429462909698486, 38.50035401753017, 38.33358335494995, 39.49243170874459, 38.30753803253174, 39.58512762614659, 38.72889763968331, 38.4101733480181, 38.922436237335205, 40.0591858455113, 39.56626326697213, 39.18774972643171, 39.15362712315151, 39.17985657283238, 39.826688698359895, 38.57181971413748, 43.1067977632795, 49.889372144426616, 51.708657196589876, 51.16957426071167, 50.738525390625, 51.653450284685405, 48.07859863553728, 49.981015409742085, 44.82559101922171, 42.16484785079956, 43.263469219207764, 41.25552667890276, 40.343582562037874, 44.01446526391165, 48.558288369859966, 52.02203137534005, 48.1478339603969, 43.162497997283936, 45.894251755305696, 53.831675801958355, 52.43335778372628, 56.87300654820034, 44.3061888558524, 54.34488364628383, 52.9240847315107, 64.37974303109306, 9.602768284933907, 4.8963199853897095, 3.4646017593996863, 1.341186563883509, 0.13910988398960658, 0.01781935417758567, 24.515846729278564, 53.8410975592477, 31.679057325635636, 62.55769606998989, 37.01086173738752, 26.924203532082693, 40.33170461654663, 46.23531103134155, 48.326704910823274, 52.578856536320274, 8.681801063673836, 0.4287578915911061, 0.11517707178635256, 0.06332335780773844, 0.08809928369841405, 0.05264295877090522, 0.04501246268461857, 0.06781450645732028, 0.02712383177796645, 0.08248676093561308, 0.048148383519479206, 0.05651809261845691, 0.01739795339692916, 0.06425962756787028, 0.15358629290546688, 0.11777271250528948, 0.09933043603918382, 0.07606982133750405, 0.1819415927997657, 0.09065898241741316, 0.08749800667698894, 0.30695692024060656, 0.16583028089787277, 0.16094959207943507, 0.13147214454199585, 0.17145178067897046, 0.27712675662977354, 14.753518274852208, 74.9534421648298, 63.0754827771868, 66.31510121481759, 35.936823095594136, 21.777526923588344, 31.722862243652344, 46.57705470493862, 42.88004330226353, 62.627066884722026, 25.57795183999198, 0.21548376365431718, 0.1770849512623889, 4.437480926513672, 10.070194448743548, 12.638817531721932, 9.49774886880602, 24.636747121810913, 53.81996808733259, 56.08513988767351, 59.349448748997276, 60.7917697089059, 54.60078580038888, 53.235881669180735, 53.53312907900129, 52.30527121680123, 53.51687029429844, 47.19079256057739, 42.15258775438581, 41.305206298828125, 40.965772901262554, 42.6959090914045, 41.74636827196394, 40.94761725834438, 40.57766389846802, 40.42880916595459, 42.603522368839805, 40.91592999867031, 40.94176687513079, 41.92988409314837, 39.81929234095982, 40.768697670527864, 41.634398051670615, 49.249696663447786, 46.12975399834769, 49.642304624829976, 47.763977255140034, 43.591705594744, 42.32370104108538, 40.426721232278005, 40.36281517573765, 40.910388810294016, 39.33130298342024, 40.20234305518014, 39.65871252332415, 38.993207114083425, 39.6576737676348, 41.77572093691145, 39.00687074661255, 40.15529680252075, 39.75931201662336, 44.9948456627982, 47.091322149549214, 47.51361281531197, 45.24460560934884, 46.6477039882115, 42.51824712753296, 47.87262276240757, 45.01985570362636, 48.090382780347554, 44.35364505222866, 51.9550507409232, 46.8265506199428, 56.439466748918804, 35.08113506862095, 33.637702396937776, 57.32967690059117, 46.829170090811594, 49.94906759262085, 43.69189167022705, 47.82692446027483, 39.9345942224775, 43.688688550676616, 39.62473930631365, 40.264925479888916, 40.72834948131016, 40.97854369027274, 39.916719981602256, 40.74910722460066, 37.3894864491054, 40.951428345271516, 39.42289066314697, 41.8128034727914, 40.43728249413626, 40.624387059892925, 41.23793731416975, 41.338126863752095, 41.28623424257551, 40.093207699911936, 40.334289346422466, 40.77184173039028, 40.97366605486189, 39.87682689939226, 40.5860538482666, 40.512840679713655, 41.37023448944092, 40.72227675574166, 44.44054617200579, 52.43091549192156, 54.06566333770752, 53.16890798296247, 51.084924357278005, 55.993354184286936, 49.437228543417795, 51.60347884041922, 46.72813980919974, 44.97798933301653, 45.02247864859444, 43.885110650743755, 42.18563686098371, 47.03696986607143, 51.84192711966378, 55.39040688105992, 47.883951800210134, 47.033353328704834, 50.49281276975359, 56.19296203340803, 54.33266871316092, 61.10783631461007, 47.80591658183506, 57.04331036976406, 53.86141061782837, 69.24792194366455, 9.134821874754769, 7.856914401054382, 7.173832654953003, 2.267709412745067, 0.39972519661699024, 0.10184353975845234, 28.855986867632183, 58.21561043603079, 38.630872453962056, 75.9076452255249, 43.75194495064871, 33.94903380530221, 47.45144380841936, 55.03806720461164, 56.36204992021833, 61.15150574275425, 10.19058849130358, 0.4921934519495283, 0.243552708200046, 0.1481155636055129, 0.13832382831190312, 0.09263563635093824, 0.11551403227661337, 0.18551474463726791, 0.09012031382215874, 0.11410061669136796, 0.14379068996225083, 0.054393049861703596, 0.11850485179041113, 0.10946800027574811], [0.04208189029512661, 0.04234437817441566, 0.015668586461937854, 0.030969681750450815, 0.04145746165886521, 0.03638720033424241, 0.019321612049160258, 0.02111744657824082, 0.015618558075012905, 0.024194131305973445, 0.03546225532357182, 0.045091993774154356, 0.3743003266198294, 16.126624754496984, 57.55087627683367, 48.642889635903494, 50.03014612197876, 28.20285098893302, 25.41213481766837, 24.82277819088527, 33.50682612827846, 37.7670897756304, 56.62365307126726, 11.647411210196358, 0.11752835847437382, 0.043981421938432116, 1.6032253886972154, 3.4245907749448503, 4.227212803704398, 5.381402390343802, 24.58790475981576, 54.83593715940203, 51.24483019965035, 56.09935590199062, 50.70234612056187, 54.9982852935791, 50.36825588771275, 51.3602363041469, 50.005744048527305, 54.15317242486136, 49.05559526171003, 48.4033157484872, 41.47164344787598, 38.06342002323696, 35.856324740818565, 37.91359601702009, 36.045392172677175, 38.14758702686855, 37.01813302721296, 38.22272137233189, 36.9809810093471, 36.984795570373535, 36.89239842551095, 36.11843511036464, 37.7618682043893, 40.22485869271414, 41.34435592378889, 44.74777119500296, 45.74459103175572, 47.220826148986816, 45.04910067149571, 41.058986459459575, 38.30366441181728, 37.48754637581961, 36.12268393380301, 36.627859660557334, 36.0063294001988, 35.58621004649571, 36.923269271850586, 37.38096100943429, 36.92263698577881, 35.5307286807469, 34.60274117333548, 41.44024453844343, 46.13769578933716, 46.58739709854126, 45.173671449933735, 45.19577019555228, 42.42119468961443, 40.52822399139404, 42.676832812173025, 40.28538792473929, 44.499293191092356, 41.518950257982524, 45.970080920628135, 45.681991236550466, 53.50103882380894, 32.29917362758091, 30.05987344469343, 53.66495030266898, 43.54693487712315, 45.72386108125959, 36.57341705049787, 39.30967671530587, 34.832525048937114, 36.96289832251412, 36.594820976257324, 37.36290611539568, 36.13501351220267, 34.9100912639073, 32.79919031688145, 35.137359891619, 33.6509804044451, 35.51437609536307, 34.34001588821411, 37.548954554966514, 36.70412308829171, 37.34893676212856, 35.391361713409424, 37.93510069165911, 35.42127023424421, 36.63285541534424, 35.98843084062849, 38.476115226745605, 36.71814802714756, 37.673014640808105, 37.071429184504915, 39.35294662203108, 37.94336557388306, 38.96901001249041, 43.14164645331246, 47.94372367858887, 48.79403032575335, 45.28545406886509, 48.72478805269514, 49.237280232565745, 46.103493281773154, 40.430879729134695, 36.74462066377912, 37.782792704445974, 38.16874081747872, 37.420791557856965, 38.40708834784371, 39.96497869491577, 46.35227353232247, 51.42277009146554, 49.650972502572195, 47.312014307294575, 48.30214997700283, 54.24474968229021, 49.00868102482387, 48.670296805245535, 40.99744279044015, 51.54356104987008, 51.65968976702009, 60.535131045750205, 22.225447756903513, 2.2846234994275227, 4.063004723617008, 1.1683074576514108, 0.190417350136808, 0.0831548058028732, 10.013725570269994, 49.30235358646938, 38.87726947239467, 92.76835932050432, 41.94099078859602, 15.828578301838466, 25.562412193843297, 41.08382626942226, 44.64222458430699, 52.61349678039551, 13.992125119481768, 0.49037785508802956, 0.02226304608796324, 0.06303642570440258, 0.03717396168836525, 0.120028678593891, 0.04964064826656665, 0.05203471319483859, 0.055898339088474, 0.09175763917820794, 0.039668738176780086, 0.09671319755060331, 0.009067452595835286, 0.030721884154315506, 0.019752648027081574, 0.01770080053912742, 0.08138278446027211, 0.020389046021071926, 0.03293938748538494, 0.035935285833797286, 0.015863945175494467, 0.018213299735050117, 0.07746022780026708, 0.020493978069030812, 0.03718456379803164, 0.01692558785102197, 0.19559385308197566, 21.663413184029714, 65.99772834777832, 54.450023787362234, 56.767921992710654, 32.625408921922954, 20.726684842790874, 23.56496490750994, 34.33269943509783, 40.95216832842146, 63.39187594822475, 11.863038999693734, 0.10717421943055731, 0.05926921285156693, 9.966864313398089, 17.073157003947667, 5.123307645320892, 7.614424007279532, 26.302928618022374, 56.12653030667986, 51.2112842968532, 57.64954417092459, 54.728726455143516, 57.50071723120553, 52.58781623840332, 54.41796479906355, 52.28978368214199, 55.6435992377145, 51.42305844170706, 51.225670542035786, 42.27270473752703, 40.70690039225987, 37.692136083330425, 39.530493940625874, 38.71065167018345, 39.82373571395874, 38.831453050885884, 39.14120026997158, 38.09762947899954, 39.022938455854145, 38.56584078924996, 39.197793347494944, 40.46302209581648, 40.53882694244385, 44.96760525022234, 45.66618755885533, 46.03763130732945, 49.27683285304478, 46.9918725831168, 42.289568015507285, 37.4791772706168, 38.00618076324463, 37.5532728603908, 39.057314668382915, 37.083727496010916, 37.29347971507481, 37.08740656716483, 37.77511147090367, 37.89004509789603, 36.9663724218096, 37.09579651696341, 42.5953026499067, 48.64231293542044, 47.747777530125205, 45.404952662331716, 45.35796546936035, 44.20613479614258, 41.98686626979283, 45.70397533689226, 42.90304183959961, 45.96069737843105, 43.52788291658674, 48.93097237178257, 47.64870664051601, 54.22971378053938, 32.848390511104036, 30.914144039154053, 56.51071010317121, 44.09971271242414, 46.445344652448384, 38.61555862426758, 41.61227151325771, 37.313775403159006, 39.28038658414568, 38.523314339774, 39.92392873764038, 36.805264541081016, 37.074250153132844, 34.821550369262695, 38.23184435708182, 34.33022240230015, 37.00796086447579, 36.51215478352138, 39.405339513506206, 37.08122614451817, 39.17817163467407, 37.98069477081299, 38.74717487607683, 37.95768233707973, 38.50223697934832, 37.85295213971819, 40.64942141941616, 37.97249937057495, 39.64456599099295, 38.395481382097515, 40.95310286113194, 39.20670093808855, 39.930828298841206, 45.57348121915545, 51.271691935403005, 51.04191848209926, 47.37672288077218, 50.967975752694265, 50.92027984346662, 47.70141567502703, 41.46911430358887, 38.03997680119106, 40.69447701317923, 38.73342439106533, 40.06959772109985, 39.84168985911778, 42.27634906768799, 47.99244792120797, 54.218752997262136, 50.6798026902335, 52.99968808037894, 52.910521847861155, 56.17588683537075, 49.794084548950195, 51.083149092538015, 42.984707491738455, 55.578623158591135, 52.2826999936785, 64.66214561462402, 25.18701492037092, 0.7116193547844887, 4.004262915679386, 2.64820926955768, 0.40098773315548897, 0.15504119412175246, 10.597979613712855, 54.79743719100952, 39.48976360048567, 81.31250299726213, 41.79247651781355, 22.91376062801906, 32.223987170628135, 45.792293889181956, 50.6130930355617, 63.23045539855957, 19.9003929070064, 0.43099865849528995, 0.03628748282790184, 0.05423118533300502, 0.023746484790795615, 0.02612067203569625, 0.030755970360977308, 0.006608635070733726, 0.017775437694841197, 0.05847078748047352, 0.03048727727894272, 0.0734447186280574, 0.025114930467680097, 0.03088033225919519, 0.21587457268365792, 0.1213625291628497, 0.19098707527986594, 0.11342593575162546, 0.11245335079729557, 0.15743886546364852, 0.09848428251487867, 0.15577614254185132, 0.09996525983193091, 0.13057396773781094, 0.13429300460432256, 0.15648586302995682, 0.40945908001491, 27.30732372828892, 75.72421278272355, 60.09302411760603, 65.56158992222377, 38.07667023794991, 36.5933062689645, 31.41705812726702, 46.3236643246242, 50.37089967727661, 69.69799845559257, 15.09592376436506, 0.19126403970377787, 0.15197770350745746, 4.452106884547642, 9.49684647151402, 9.059592860085623, 9.828045385224478, 29.515982355390275, 57.06085804530552, 52.437300886426655, 60.078981808253694, 55.980103969573975, 59.85663945334298, 53.76611607415335, 55.47511237008231, 54.55498674937657, 56.776867798396516, 53.89651986530849, 53.954106535230366, 46.11022956030709, 42.826667240687776, 39.59383371898106, 42.3463591166905, 39.08811603273664, 41.94579894202096, 41.42042827606201, 40.939439228602815, 40.28709718159267, 41.62994078227452, 40.31493166514805, 40.18205084119524, 41.732979093279155, 43.907056535993306, 46.513798304966514, 47.84660523278372, 48.35999720437186, 51.34027065549578, 48.95054544721331, 43.73578691482544, 39.79012032917568, 39.77577577318464, 38.31882190704346, 41.42598336083548, 38.76160281045096, 38.7072296823774, 40.28408861160278, 41.047007765088765, 40.00128650665283, 37.92437614713396, 39.08623307091849, 46.03987904957363, 51.530498436519075, 50.98000308445522, 47.489287172045024, 49.03087704522269, 48.03932046890259, 44.82142904826573, 47.423532894679475, 44.95597743988037, 48.88432911464146, 45.74377809252058, 50.42968838555472, 50.28845930099487, 55.863832814352854, 36.224322182791575, 34.80044869014195, 57.774549211774556, 47.70781149183001, 49.6678010395595, 41.37168666294643, 43.84500912257603, 39.755344595227925, 41.03212124960763, 41.646241256168906, 43.57169130870274, 39.54443897519793, 39.62338440758841, 38.05771207809448, 40.707848821367534, 36.79410573414394, 39.27125317709786, 38.944003445761545, 41.68669714246477, 39.51707002094814, 41.41012062345232, 39.79359095437186, 41.47030939374651, 38.85627201625279, 39.88946219852993, 38.49414232798985, 41.48511947904314, 39.461018902914866, 40.73641981397356, 41.465716634477886, 43.95350871767317, 41.1431291443961, 42.706314018794465, 47.12686913354056, 52.581792150224956, 53.13146414075579, 47.16792951311384, 53.30698953356062, 53.3711769921439, 50.75390522820609, 45.090748173849924, 41.101631028311594, 43.3135518346514, 41.804726191929404, 42.48225198473249, 41.863073689596995, 44.35013273784092, 50.84488146645682, 58.36677197047642, 54.22787250791277, 52.58747925077166, 51.90392589569092, 60.181849888392854, 53.04716164725167, 54.420202119009836, 44.59324673243931, 57.05005359649658, 55.545101574489046, 65.08592319488525, 28.095166070120676, 5.332996027810233, 13.379445127078466, 2.757835341351373, 0.466711693576404, 0.18313827072935446, 12.784019248826162, 61.23699637821743, 50.34888431004116, 94.27553476606096, 48.00361367634365, 26.10551813670567, 35.81834936141968, 52.187082358769004, 57.68734931945801, 72.73525755746024, 24.292146001543315, 0.5776117284383092, 0.23934581822582654, 0.16687308065593243, 0.12165903539529868, 0.21447052088166985, 0.1564206015318632, 0.10378469273980175, 0.12161259645862238, 0.17170372073139462, 0.1018728796126587, 0.2776320752288614, 0.11965619001005377, 0.22349944710731506], [0.06549019832164049, 0.12138173170387745, 0.05528885857867343, 0.007327101027060832, 0.024748543609998057, 0.06841796157615525, 0.028246842856918062, 0.06389432466988053, 0.08833651311163392, 0.04542617905618889, 0.03051829311464514, 0.08249472693673202, 0.5084047392010689, 29.475814819335938, 53.79340859821865, 51.941463538578574, 41.39344147273472, 25.79734468460083, 26.53368697847639, 23.048965624400548, 37.24328245435442, 42.191803387233186, 49.5880982535226, 4.984523023877825, 0.0612139959952661, 0.24759949105126516, 6.8122314640453885, 5.994114952428, 4.803357430866786, 6.260847611086709, 34.4264132635934, 51.209797382354736, 51.88508585521153, 54.04486737932478, 55.50693164552961, 53.52783455167498, 54.4505101612636, 53.14805991309029, 54.898825304848806, 54.234977040972026, 52.13423783438546, 52.84106765474592, 50.30613899230957, 45.42422349112374, 40.58348648888724, 38.2797452381679, 36.94465930121285, 37.31510945728847, 36.38834135872977, 37.47472347532, 39.164580958230154, 37.62462043762207, 38.80233662469046, 36.56335605893816, 37.10614585876465, 37.32805047716413, 38.74394743783133, 43.66419962474278, 46.39159686224801, 49.30969088418143, 47.721461227961946, 45.53494650976998, 41.46541786193848, 38.21781594412667, 36.43655143465315, 35.368224212101524, 35.323130403246196, 36.54436663218907, 37.03414862496512, 35.667635985783164, 35.21079887662615, 34.5135679926191, 39.570119517190115, 46.74929012571062, 49.08288083757673, 47.89344998768398, 44.98683786392212, 44.17692109516689, 43.30246250970023, 40.698666776929585, 43.062579427446636, 41.21563359669277, 43.41509280885969, 40.44450862067086, 44.76545436041695, 43.67773124149868, 50.19129916599819, 35.15104784284319, 29.963644368307932, 52.986344064985005, 43.69087723323277, 46.34461661747524, 38.26599127905709, 38.46296228681292, 34.36754812513079, 38.39575931004116, 35.60164894376482, 38.85113034929548, 34.120004653930664, 36.47919600350516, 33.85544157028198, 35.345691204071045, 34.013759749276296, 35.35571050643921, 34.66739068712507, 36.160332747868125, 37.56094019753592, 38.95939370564052, 35.297071184430806, 36.67234550203596, 35.022791045052664, 37.33835465567452, 35.50032336371285, 36.939138957432334, 36.519867283957346, 37.33010366984776, 36.17986066000802, 37.19869933809553, 36.77081537246704, 43.01622799464634, 46.228178705487935, 48.16951928819929, 47.758540289742605, 49.47092035838536, 48.95226165226528, 47.63315657206944, 41.60727228437151, 35.6619245665414, 37.09340633664812, 36.80670281818935, 36.831410612378804, 36.66036333356585, 38.61194903509957, 38.01894460405622, 42.91636848449707, 48.93923725400652, 51.91503953933716, 51.60799169540405, 51.90495770318167, 50.628622259412495, 45.13492134639195, 40.53765617098127, 41.48838513238089, 49.57667541503906, 54.89438888004848, 56.00120217459542, 51.359287875039236, 0.17430162775729383, 2.4489097467490604, 1.2727202091898238, 0.15450995548495225, 0.028418047420148338, 2.3037642666271756, 44.59045703070504, 44.93099519184658, 42.172268526894705, 29.130447660173687, 16.912016119275773, 26.31445220538548, 41.41818053381783, 43.68269225529262, 53.15814869744437, 19.823408603668213, 0.22556536910789354, 0.025306009321606586, 0.026521937289674367, 0.026148424117958972, 0.09253652274076428, 0.026997948264969245, 0.11941236523645264, 0.04168837730373655, 0.09616135180528675, 0.06704757868179254, 0.0078072943225769055, 0.05714956444821187, 0.05206302846116679, 0.042547724941479306, 0.04814584240583437, 0.04631655949300953, 0.06977322671030249, 0.018320888247607008, 0.01504796271079353, 0.045553058319325955, 0.04144289351201483, 0.026579633122310042, 0.086847651217665, 0.0818971140044076, 0.06172480394265481, 0.5298017167619297, 37.552421706063406, 63.46900790078299, 56.184492179325645, 50.12343611036028, 26.834530081067765, 28.93128796986171, 24.837444101061138, 34.01780360085623, 47.57725484030587, 54.914302417210166, 5.167555510997772, 0.1551602091640234, 0.12876426056027412, 5.295723719256265, 7.692388006619044, 4.936154876436506, 8.58663158757346, 34.96084090641567, 54.28897844042097, 52.23640762056623, 54.389449392046245, 55.15309463228498, 54.278563090733115, 54.85062912532261, 55.36241953713553, 54.89878708975655, 56.07646853583199, 53.88190432957241, 53.697509561266216, 52.255428314208984, 47.99929189682007, 42.76535981042044, 39.59400394984654, 39.51203605106899, 39.04513100215367, 37.252811908721924, 38.97810867854527, 39.787122181483674, 38.89812101636614, 41.62008823667254, 38.49897827420916, 38.58880805969238, 37.9400234903608, 41.070701122283936, 44.69698681150164, 47.363969462258474, 49.34548800332205, 49.21514327185494, 47.40052740914481, 44.122996125902446, 39.57591778891427, 37.488887378147666, 37.95557703290667, 38.109816619328086, 37.010656765529085, 38.24524048396519, 36.61964341572353, 38.044910022190635, 36.35418054035732, 41.46684224264962, 49.51524986539568, 52.06796939032418, 50.71890367780413, 47.67849704197475, 46.728977067129954, 46.315687792641775, 43.84878894260952, 44.38666636603219, 43.29077216557094, 44.41235385622297, 42.670836516789024, 47.21218258993966, 44.633073806762695, 53.19464758464268, 37.33490834917341, 31.24451003755842, 55.31145797457014, 46.2394243649074, 48.28396654129028, 40.699695110321045, 40.17359140941075, 37.615851811000276, 40.657324995313374, 38.25008685248238, 39.12689740317208, 36.561361925942556, 38.08658879143851, 35.000831263405935, 35.76186398097447, 36.38858107158116, 38.31711612428938, 36.359878063201904, 38.62028687340872, 38.68631560461861, 40.2392692565918, 37.23992994853428, 38.18384272711617, 37.13596405301775, 38.36289085660662, 38.14104529789516, 37.892265047345845, 38.23810120991298, 38.47366598674229, 37.3867940221514, 38.58451754706246, 39.12094627107893, 44.93792601994106, 47.05198492322649, 50.817241532461985, 49.08462483542306, 50.4318562235151, 51.380622318812776, 49.349271297454834, 43.395637852805, 38.13031727927071, 39.66752631323678, 38.80068295342581, 39.65049280439104, 38.179284708840505, 40.588089670453755, 40.621343748910085, 45.33128438677107, 51.68059342248099, 53.098842348371235, 54.297472613198416, 52.71839720862252, 53.83879770551409, 46.77051339830671, 43.46878848757063, 42.54960087367466, 50.96437658582415, 55.725945813315256, 58.032469817570274, 53.56459747041975, 1.416299739054271, 3.653163058417184, 1.850969272000449, 0.3760694574032511, 0.03628001215734652, 2.4823142971311296, 48.43085493360247, 48.375825200762065, 47.346407890319824, 29.8948016166687, 20.001065356390818, 30.903680052076066, 47.35651751926967, 48.59725386755807, 59.408334732055664, 26.09540155955723, 0.238422440631049, 0.03610696197886552, 0.018338972902191535, 0.08791171626320907, 0.08002498839050531, 0.024178221356123686, 0.042420160357973406, 0.0332073918543756, 0.08365746454468795, 0.037184916636241336, 0.025778625925470675, 0.015302679667781507, 0.055938912089914083, 0.14114722609519958, 0.185642824907388, 0.10186864555414234, 0.13566933146544866, 0.101106535377247, 0.16828511202973978, 0.11092987683202539, 0.1961310085441385, 0.1502552016505173, 0.23169680152620586, 0.18077315549765313, 0.1878070259200675, 0.723928088588374, 46.24686935969761, 71.52807753426688, 63.895696776253835, 56.30816316604614, 36.13389137813023, 36.326280048915315, 31.591836588723318, 51.23458508082798, 53.56460094451904, 61.32953943525042, 7.428186229297093, 0.3002498187124729, 0.8536580130457878, 12.084141101155963, 8.314322999545507, 11.58606469631195, 8.63454897063119, 39.01186997549874, 53.97850513458252, 53.00445107051304, 54.21389273234776, 56.84842382158552, 56.23125008174351, 57.48478848593575, 56.749168804713655, 56.08829089573452, 57.36511271340506, 57.528492655072895, 55.57238367625645, 55.487587860652376, 49.86630759920393, 44.168882029397146, 41.82366003308977, 40.962045192718506, 40.726664543151855, 39.86666168485369, 40.14577777045113, 42.54598086220877, 40.01672887802124, 43.08424391065325, 39.97898973737444, 41.66204840796334, 39.294255188533235, 43.23936939239502, 47.544587884630474, 51.587369441986084, 50.92881570543562, 51.44811017172677, 48.815493311200825, 45.50397491455078, 41.351665428706575, 39.9226051058088, 39.071471623011995, 38.95843138013567, 40.02860682351248, 40.53852469580514, 39.263926301683696, 39.02250419344221, 39.908590589250835, 44.01195696422032, 50.07404136657715, 54.32544606072562, 52.747781140463694, 49.229501724243164, 49.58674335479736, 48.39396347318377, 45.62973730904715, 47.13847957338606, 46.74758781705584, 47.322374071393696, 45.23107399259295, 47.394642284938264, 47.78398806708199, 54.34104129246303, 39.698414530072895, 34.39180081231253, 56.48471341814314, 48.38259622028896, 50.7429062298366, 42.91944653647286, 40.89385209764753, 38.5670428276062, 43.09268944604056, 41.53185306276594, 42.10382877077375, 39.661231245313374, 41.07475539616176, 37.22583205359322, 39.34571007319859, 38.4694310597011, 40.38727630887713, 38.66135420118059, 40.501393522535054, 41.39518199648176, 42.62938008989607, 39.341478620256694, 41.1490490095956, 38.87715482711792, 39.62045921598162, 40.61048024041312, 39.28102929251534, 40.49079404558454, 40.5898962020874, 39.22589533669608, 39.963377135140554, 40.0869265283857, 48.12104518072945, 49.25298663548061, 52.79607459477016, 50.62937266486031, 51.13850539071219, 53.89872244426182, 52.438568932669504, 45.158698081970215, 39.57211365018572, 42.208277566092356, 40.66067055293492, 42.375826426914756, 39.333196367536274, 42.466406617845806, 42.532616002219065, 47.57620218821934, 53.80112109865461, 56.379260608128135, 56.37788833890642, 54.76283516202654, 56.4436982018607, 48.73175709588187, 45.120983260018484, 45.988236563546316, 54.09459911073957, 59.905061449323384, 59.7736154283796, 58.1827906199864, 2.3608969151973724, 9.478814159120832, 5.310443912233625, 0.34773578920534676, 0.09260178423885788, 3.0665255657264163, 54.59211097444807, 54.4422869682312, 51.79905673435756, 37.89209829057966, 25.61448199408395, 36.08900948933193, 54.31105286734444, 54.584252561841694, 67.84295449938092, 36.136847836630686, 0.4592396116682461, 0.10868961882910558, 0.07796737165855509, 0.1434917002916336, 0.202537084796599, 0.10630230871694428, 0.2254439384809562, 0.12512516868965967, 0.15096120376672062, 0.21548877124275478, 0.1157252195158175, 0.20306446935449327, 0.15468329404081615], [0.03377623829458441, 0.03681849076279572, 0.029793051137988056, 0.006363634311128408, 0.05489475865449224, 0.037769545800983906, 0.040767469576426914, 0.06589406915009022, 0.07716245949268341, 0.022032622380980423, 0.034227487830711265, 0.04056033319128411, 0.5397563140307153, 40.58284725461687, 56.821047919137136, 49.49422114236014, 32.9604788507734, 26.62923686844962, 15.4376848084586, 31.18313659940447, 40.153316565922324, 47.44821637017386, 44.51708057948521, 0.8987675639135497, 0.0830942058403577, 0.08412093788917575, 11.3847519329616, 16.594709260123118, 5.753262596470969, 14.570821472576686, 39.61595678329468, 55.93179314477103, 57.4529309953962, 54.74787221636091, 53.81450680324009, 55.731295926230295, 53.945271900721956, 52.41256529944283, 50.19744832175118, 49.84048114504133, 51.83181749071394, 49.17425659724644, 50.0807637487139, 50.45128338677542, 48.16461385999407, 39.681884765625, 37.035329818725586, 36.66012709481375, 36.76749413354056, 35.60429968152727, 37.42549548830305, 38.868042264665874, 42.16354506356375, 39.3916654586792, 38.51106466565813, 39.31447792053223, 40.43951981408255, 42.351198537009104, 46.78628928320748, 46.957565852573936, 49.83390814917428, 47.11840622765677, 45.51086752755301, 40.5278765814645, 37.30818557739258, 34.574465479169575, 36.64442416599819, 35.20346852711269, 36.42845678329468, 35.04530668258667, 36.05276768548148, 34.72745786394392, 43.37929221561977, 47.98360633850098, 46.39617225102016, 46.666912283216206, 47.39462144034249, 45.883242334638325, 46.09960229056222, 43.06611258643014, 44.42596885136196, 42.61354514530727, 44.27746500287737, 42.69696174349104, 45.30923080444336, 43.815232617514475, 51.47379418781826, 34.94219194139753, 32.29416397639683, 52.59674119949341, 43.41580499921526, 44.989731788635254, 38.32138926642281, 40.675682135990684, 36.15625415529524, 38.49289512634277, 36.0186311858041, 38.67239488874163, 35.3588684626988, 34.79445586885725, 33.53512266704014, 35.42799956457955, 33.752893107278005, 34.53262690135411, 34.65202822004046, 36.43667997632708, 36.75626931871687, 37.31822919845581, 35.12808404650007, 35.61977331978934, 34.60697957447597, 36.15821702139718, 36.96858889716012, 37.896242891039165, 38.899934496198384, 39.07847193309239, 38.59121561050415, 39.139077595302034, 45.316609791346956, 45.92920119421822, 46.628912585122244, 50.365747588021414, 43.61796283721924, 47.825305530003135, 48.77483245304653, 47.58993182863508, 42.018626485552105, 36.73127664838518, 37.53325162615095, 35.85817296164376, 37.588521071842735, 37.5688020842416, 37.54898582186018, 37.59563602719988, 39.1611659186227, 39.1211199760437, 43.51512254987444, 42.37191459110805, 40.88553510393415, 39.7580509185791, 37.8444162777492, 37.835727555411204, 42.99161400113787, 43.659249033246724, 53.956986563546316, 51.89398649760655, 61.86748286655971, 10.330353243010384, 3.9176206162997653, 2.022233030625752, 0.6628343697105135, 0.01970513191606317, 0.16455173093293393, 30.403864860534668, 49.452629225594656, 31.163525308881486, 32.368874481746126, 16.895383868898662, 17.25240315709795, 33.80899633680071, 47.30152947562081, 49.27184404645647, 25.765890189579554, 0.28588960213320597, 0.01791477994993329, 0.03062680782750249, 0.02084469416045717, 0.017794640235868946, 0.020360471215099096, 0.07249898330441543, 0.04715428900505815, 0.022978523945701972, 0.041523954698017666, 0.014424093865922518, 0.03384821389668754, 0.06429906402315412, 0.03312423060249005, 0.04306543019733258, 0.039166958137814484, 0.024346006102859974, 0.06802125607750245, 0.0656741355944957, 0.06120046600699425, 0.0839242170165692, 0.046851024563823424, 0.044866095895745924, 0.05172220032129969, 0.03418970021552273, 1.4227079323359897, 49.77138825825283, 60.78514807564871, 55.195200715746196, 38.579719815935405, 29.15693071910313, 26.139807496752056, 32.41627509253365, 40.220418793814524, 51.53822830745152, 46.47725078037807, 0.802502335182258, 0.05104412670646395, 0.5672712347337178, 8.029847247259957, 5.0682297093527655, 4.354291447571345, 15.894501073019844, 41.09339393888201, 56.035679136003765, 58.74296828678676, 56.67243637357439, 54.12258298056466, 56.66230937412807, 55.54832901273455, 50.89138923372541, 50.92795760290963, 50.39924137932913, 53.57586397443499, 51.32650627408709, 51.339572361537385, 52.964373861040386, 50.50701488767351, 40.766220637730186, 38.890964371817454, 38.62588712147304, 38.617347785404746, 37.958592551095144, 39.283818994249614, 40.29754032407488, 45.24855218614851, 41.709713050297324, 39.31821952547346, 40.50064311708723, 42.54535552433559, 45.18901654652187, 48.40882566996983, 49.02208757400513, 50.09598725182669, 47.522919927324565, 47.310530866895405, 41.41844456536429, 37.782705851963584, 37.04011712755476, 38.33764110292707, 36.7194264956883, 37.95673738207136, 35.81629269463675, 38.13352039882115, 35.22981262207031, 45.865309034075054, 48.59085805075509, 48.60096767970494, 48.524544443402974, 48.18667786461966, 46.43509258542742, 46.972025053841726, 45.349401814596995, 47.29802063533238, 44.36858715329851, 46.04997478212629, 45.578744479588096, 48.45904377528599, 46.4842962537493, 52.29939998899187, 36.77827078955514, 32.690016746520996, 53.955589975629536, 45.540543283735005, 47.08978312356131, 40.75428710665022, 42.4305990764073, 38.87453188214983, 40.84028843470982, 38.44267007282802, 39.90719052723476, 38.57163211277553, 37.65504312515259, 36.05494247164045, 36.59944500241961, 34.935684953417095, 37.39033760343279, 36.25450863157, 36.92002098900931, 38.12068707602364, 37.77703612191336, 37.463839122227256, 37.192553656441824, 36.25056900296892, 37.022232464381624, 37.036253929138184, 39.451312269483296, 40.532976559230256, 40.94297933578491, 40.30148690087454, 39.18673528943743, 46.292765685490195, 48.05065992900303, 48.08072131020682, 53.66177150181362, 44.47146565573556, 49.18316766193935, 51.64551196779524, 49.1842793737139, 43.935714381081716, 36.51087978907994, 38.68639898300171, 37.209277970450266, 39.16084630148751, 39.705675397600444, 38.7421304838998, 38.90371779033116, 40.35768045697893, 41.82346200942993, 46.451424326215474, 45.47270802089146, 42.746540614536826, 40.70465612411499, 40.74439982005528, 40.529228006090435, 45.59712593896048, 45.30423852375576, 58.17505727495466, 52.985819475991384, 65.70163086482457, 12.033903888293676, 1.3050022998026438, 3.736926632268088, 1.3124210217169352, 0.17921639260436806, 0.10175241929079805, 33.35081475121634, 53.469778878348215, 36.7691582271031, 32.19365133558001, 19.55373511995588, 23.726988213402883, 38.12723227909633, 50.37273052760533, 56.3696026120867, 36.59750992911202, 0.30535921454429626, 0.009393470860751612, 0.01180935577888574, 0.010099061615099865, 0.040616838194962056, 0.07243071589618921, 0.022671758263771023, 0.01843802714055138, 0.035778981899576526, 0.04108156682923436, 0.046560743890170536, 0.017606570684750165, 0.023423839693090746, 0.14458975994161197, 0.11363689907427345, 0.14736465604177543, 0.06732318603566714, 0.2772243028240544, 0.10108414372163159, 0.11396762382771287, 0.16298602494810308, 0.15837626159191132, 0.09820916370621749, 0.09112919361463614, 0.143916517496109, 2.717355353491647, 60.16291604723249, 67.19420119694301, 64.33271762302944, 43.45721973691668, 37.48776871817452, 22.16310157094683, 44.807827949523926, 53.58380576542446, 57.48116500037057, 52.903771672930034, 1.4618781847613198, 0.18469902340854916, 0.8156660231096404, 22.686582326889038, 27.053778750555857, 12.585937397820608, 18.76746654510498, 45.75244944436209, 57.96314416612898, 62.17342594691685, 58.80926104954311, 57.69967194965908, 57.60805647713797, 57.28397512435913, 52.66514621462141, 52.66164779663086, 52.44117798124041, 54.69395766939436, 53.41802174704415, 53.69622414452689, 55.44363703046526, 53.193761689322336, 43.142789431980674, 39.730150427137104, 41.25623886925833, 40.05105297906058, 39.03358309609549, 41.407918044498985, 43.81235258919852, 47.12780019215175, 43.1380855015346, 41.97899396078927, 41.09123999731881, 45.2162778036935, 47.199568135397776, 49.35056366239275, 50.492361136845176, 51.368480341775076, 51.08005714416504, 49.50576557431902, 44.670708724430625, 40.80517223903111, 37.941597257341655, 39.857868739536826, 37.54809297834124, 39.28135238374983, 37.94898666654314, 39.94391870498657, 37.83890635626656, 47.10714667184012, 49.31710461207798, 50.83666174752371, 51.687399183000835, 50.95259244101388, 48.88759476797921, 49.40548917225429, 48.33273942129952, 49.120015484946116, 46.05294861112322, 49.00533199310303, 47.46810558864048, 49.68313571384975, 48.59743799482073, 54.637743268694194, 39.72348015648978, 37.35247686931065, 56.265598501477925, 48.672019958496094, 49.94196653366089, 43.48224367414202, 46.05871214185442, 41.020225933619905, 42.91588905879429, 41.05740574428013, 44.04672227587019, 40.624421800885884, 39.772590024130686, 39.135141440800254, 39.905710560934885, 38.253845827920095, 38.176109382084434, 37.61903408595494, 38.25832394191197, 39.3609162058149, 41.26585170200893, 38.83144610268729, 39.08597251347133, 36.95614467348371, 38.882921831948416, 40.61271408626011, 42.74653019223894, 42.41065774645124, 42.7255778993879, 42.275925227573936, 41.83467640195574, 49.144018036978586, 49.99796206610543, 49.419809409550254, 56.670063563755576, 45.30504451479231, 51.05078785760062, 53.861792768750874, 52.293209144047324, 45.17889302117484, 38.90781722749983, 41.01429912022182, 38.92164414269583, 42.14945411682129, 41.60504886082241, 40.76034246172224, 40.78633219855172, 43.04582732064383, 43.552566392081125, 48.33747461863926, 47.991912909916465, 44.71383619308472, 44.146470614842, 42.34533773149763, 42.63332666669573, 49.05374009268624, 48.387546811785015, 59.72651359013149, 56.47157090050833, 71.04632418496269, 12.76377306665693, 7.421450819287982, 9.913559470857892, 2.551574592079435, 0.21586777376277105, 0.34157051146030426, 38.533448287418906, 60.505288532802034, 44.17904724393572, 42.24344934735979, 26.126842158181326, 28.370252200535365, 44.53010845184326, 59.727090290614534, 64.32370580945695, 43.32545409883772, 0.6461942483271871, 0.1732006911188364, 0.08692229006971632, 0.08799143734255008, 0.07016684487462044, 0.11754837525742394, 0.17847456383918012, 0.15749541457210267, 0.10685583044375692, 0.21263474438871655, 0.16510723398200103, 0.10872009183679308, 0.1335725632629224], [0.06816627258168799, 0.07785644475370646, 0.02638596565728741, 0.029581236253891672, 0.10309808993978159, 0.025091519313199178, 0.06454539259097405, 0.03489909839949437, 0.05918550198631627, 0.02479855333720999, 0.0733176561604653, 0.13006095455161162, 3.130955559866769, 45.655577659606934, 52.85638148444039, 46.495854582105366, 41.31501715523856, 32.923646450042725, 20.283916098730906, 35.048339571271626, 32.07997185843331, 54.63787528446743, 27.637837375913346, 0.08993902962122645, 0.030587381550243924, 0.350611610604184, 3.265187157051904, 4.755691920007978, 8.632060647010803, 28.79449357305254, 51.09510694231306, 59.14983395167759, 52.76767035893032, 53.438734327043804, 52.18972267423357, 51.44783224378313, 51.82534176962716, 53.640492643628804, 50.68397160938808, 52.07077646255493, 50.20462233679635, 49.22759444372994, 47.23026180267334, 50.76537670407976, 50.62696858814785, 41.808200291224885, 36.53643178939819, 36.176636695861816, 36.248686041150776, 35.49883992331368, 39.31676040376936, 42.71971014567784, 44.90096160343715, 44.842787810734336, 47.34105430330549, 44.482124192374094, 45.263143403189524, 45.19075012207031, 47.5303510257176, 48.9183474949428, 47.87772968837193, 51.06173127038138, 49.28816883904593, 43.92593131746565, 37.647667612348286, 35.48127835137503, 36.21219757625035, 36.735042572021484, 36.57702316556658, 36.447491373334614, 33.74104642868042, 37.25045299530029, 45.07719223839896, 49.30657809121268, 48.313885484422954, 47.511583941323416, 49.06574657985142, 46.3504878452846, 48.29765101841518, 46.44820383616856, 46.832265513283865, 44.121453625815256, 47.539838790893555, 44.79566165379116, 48.27707045418875, 44.49590941837856, 50.418546949114116, 37.45880862644741, 29.573065280914307, 52.938589096069336, 44.86427164077759, 44.76723657335554, 39.27443197795323, 39.90164239065987, 36.0688145501273, 38.62901381083897, 35.89845166887556, 37.34956210000174, 34.73534059524536, 34.96630219050816, 33.934102126530235, 33.50554071153913, 34.696729455675396, 35.39111157826015, 35.956139087677, 36.08837720326015, 35.33339636666434, 38.744732584272114, 35.97510419573103, 36.428411620003835, 35.36959300722395, 36.86688116618565, 38.88921342577253, 40.832944188799175, 44.729354994637625, 44.56959853853498, 43.58461148398263, 45.523812021527974, 45.263779163360596, 48.66945954731533, 49.84844378062657, 46.25109733854021, 42.18663045338222, 47.60923739842006, 48.70104258401053, 45.67448718207223, 39.22390815189907, 37.10613891056606, 36.75375059672764, 36.9921988759722, 38.204332964760916, 36.53801250457764, 36.05801010131836, 37.25148132869175, 37.400193623134065, 35.613075256347656, 37.09884330204555, 35.618810994284495, 38.44432374409267, 40.60424075807844, 43.34071929114205, 44.92194863728115, 46.015452657427105, 44.725373676845, 51.46551193509783, 54.01488242830549, 62.18258367265974, 27.588456528527395, 0.7305207891123635, 0.4462722103510584, 0.7018701636365482, 0.04659562737547925, 0.10458121142749276, 13.077336583818708, 52.86911753245762, 35.412181990487234, 33.69642162322998, 18.67256110055106, 15.902455023356847, 27.519452231270925, 37.609900678907124, 48.578834193093435, 43.00013944080898, 0.9783173267330442, 0.12080744680549417, 0.06594833838088171, 0.09487057463931185, 0.036578523460775614, 0.021653285682467476, 0.038998857872294526, 0.0513171556272677, 0.035167669345225604, 0.02086816299041467, 0.020416241704619358, 0.08942702066685472, 0.029537365572260957, 0.01853089313954115, 0.06317762205643312, 0.020986910011353235, 0.034414692249681265, 0.09115013999066182, 0.04290186593841229, 0.03473892681566732, 0.03450750566220709, 0.04348643742767828, 0.05472787975200585, 0.10164866450109653, 0.14752534670489176, 5.15124591759273, 55.22081177575247, 58.79853997911726, 54.794876779828755, 45.38015454156058, 42.04940005711147, 22.231449263436453, 33.75891719545637, 36.366034167153494, 59.453518867492676, 30.25231770106724, 0.07805329454796654, 0.010758715548685618, 0.6649135095732552, 4.85566520690918, 3.633970396859305, 6.690200686454773, 27.37073646272932, 54.47722251074654, 59.24861649104527, 54.85828604016985, 53.913053103855674, 53.122671195438926, 54.18067339488438, 54.84663738523211, 55.95289134979248, 53.02349608285086, 53.43917553765433, 51.97528389522007, 50.92617538997105, 50.42392485482352, 51.53320128577096, 52.373030049460276, 43.69947215488979, 38.672314984457834, 38.75253888538906, 37.57861641475132, 39.66064412253243, 41.70835815157209, 45.30850124359131, 48.54975945608956, 46.15838057654244, 49.40203244345528, 46.51200219563076, 45.926185676029746, 47.08834832055228, 49.459025042397634, 50.05335310527256, 48.26041562216622, 50.97250597817557, 51.418809618268696, 45.71739925657, 38.7166861806597, 37.68651499067034, 37.685191358838765, 37.90499414716448, 38.41796922683716, 37.409823826381135, 35.520024980817524, 38.50456462587629, 46.942602906908306, 50.79564305714199, 49.36333097730364, 49.12776967457363, 50.162568364824565, 48.46450505937849, 49.2827353477478, 47.53008699417114, 49.05571685518537, 45.2092045375279, 51.23512009211949, 46.91385473523821, 49.71473264694214, 46.711286953517366, 55.001349449157715, 38.52234506607056, 32.451769965035574, 54.59690523147583, 48.066553933279856, 46.13592747279576, 40.27609123502459, 41.81463432312012, 39.60842841012137, 40.0126085962568, 38.00300891058785, 38.698596545628135, 38.449934414454866, 37.70182882036482, 36.0742723601205, 36.446417876652305, 36.5245885848999, 35.578824111393516, 37.28208119528634, 37.731112003326416, 37.99917697906494, 39.87909548623221, 37.76691607066563, 37.635497842516216, 37.93019526345389, 38.076055322374614, 40.627802099500386, 43.46921232768467, 46.59111091068813, 45.14358227593558, 45.19096204212734, 46.3482574735369, 48.04493113926479, 48.94515017100743, 51.53903429848807, 47.584154401506694, 41.33062628337315, 50.222114426749094, 50.15847587585449, 47.5638552393232, 41.2048465183803, 38.26572029931204, 38.2649108341762, 38.165589809417725, 39.44559390204293, 39.44670908791678, 37.65600197655814, 38.28709295817784, 39.149367877415244, 38.55147191456386, 38.08646719796317, 37.9422538621085, 40.82845217841012, 42.44077123914446, 47.885428292410715, 45.82245601926531, 48.065146923065186, 44.87020887647356, 53.0669709614345, 54.34806939533779, 65.13895184653146, 30.56996849605015, 0.8505343092339379, 2.6983366140297482, 2.1142197975090573, 0.12809873984328338, 0.05127199572910156, 13.512523106166295, 57.11568628038679, 38.35248245511736, 37.277217456272666, 23.464827469417028, 21.27888424055917, 32.31339659009661, 43.685172762189595, 53.518999917166575, 52.304684094020296, 2.808047584124974, 0.20975029202444212, 0.020659957912617495, 0.13994917752487318, 0.04555451038426586, 0.053387026701654704, 0.05206370360351034, 0.02708249372829284, 0.039869489547397406, 0.014138539188674517, 0.05997940831418548, 0.022740303871354887, 0.018815250202481235, 0.15571155957877636, 0.1363613421895674, 0.09500653948634863, 0.15451899357140064, 0.15523277169891767, 0.13825179503432342, 0.11506002449563571, 0.15633773883538588, 0.12355107601199831, 0.1222743173795087, 0.20783317275345325, 0.2201075048318931, 7.776933687073844, 63.60366398947579, 67.26808834075928, 62.25372627803257, 53.09493398666382, 41.39072125298636, 25.783568143844604, 46.71362154824393, 44.306650911058696, 64.6494790485927, 33.44102668762207, 0.28324706107378006, 0.15023394993373326, 0.7924066026295934, 10.305072222437177, 12.481643199920654, 14.936283690588814, 33.48969187055315, 55.51988308770316, 62.99652344839913, 57.11094413484846, 56.83125482286726, 56.5445374080113, 55.96251460484096, 56.54719161987305, 58.67505659375872, 55.95731735229492, 57.023309980119976, 54.14762428828648, 52.13738189424787, 52.36698511668614, 53.385240146092, 55.196555614471436, 44.69189725603376, 40.817526136125835, 39.22491216659546, 39.72593981879098, 39.41325351170131, 43.964198521205354, 46.89485141209194, 50.657571928841726, 48.67197479520525, 51.849556241716655, 48.23085103716169, 48.55229902267456, 49.99966090066092, 52.763199193137034, 53.43593420301165, 49.52762460708618, 51.508872168404714, 53.509585108075825, 48.05515193939209, 40.705482959747314, 39.59174231120518, 39.163160051618306, 39.38933086395264, 40.565688678196494, 39.29406411307198, 37.35215377807617, 41.72392559051514, 49.43533168520246, 52.52379553658621, 49.80703946522304, 51.5766726902553, 50.22608879634312, 50.27717195238386, 52.07946171079363, 50.70792899812971, 50.85767657416207, 47.15322017669678, 53.29091140202114, 47.901291029793875, 52.055601596832275, 49.4608211517334, 56.64585256576538, 41.80283628191267, 34.51236942836216, 57.34046050480434, 49.306473868233816, 49.72892781666347, 43.047307286943706, 44.207218715122764, 41.273786544799805, 41.766688278743196, 41.158922399793354, 40.179910796029226, 40.08613443374634, 39.071266651153564, 39.1861446925572, 38.93057605198452, 39.16232279368809, 39.27410193852016, 40.354182038988384, 39.43504653658186, 39.70055457523891, 42.639719009399414, 40.26250055858067, 38.30613102231707, 38.625734261104036, 40.64927898134504, 42.999903202056885, 44.85335602079119, 50.199769020080566, 47.258488859449116, 47.30814068658011, 49.598458017621724, 49.995908873421804, 52.428459303719656, 54.64939887183053, 47.034225327628, 42.100177492414204, 51.775210516793386, 53.02303750174386, 49.712731565747944, 44.318827629089355, 40.17774643216814, 39.84261049543108, 40.71391807283674, 42.23389210019793, 41.23724249431065, 39.32394484111241, 40.516877583095, 42.341627393450054, 39.855228424072266, 40.8921080998012, 40.32131705965315, 44.14864192690168, 45.45209271567208, 49.20008999960763, 48.77081986836025, 50.79111630575997, 48.9544711794172, 57.1975291115897, 57.073347432272776, 68.41040693010602, 32.762931142534526, 4.220707552773612, 6.504047155380249, 2.6599960199424197, 0.4227908546371119, 0.19571821498019354, 16.790231568472727, 62.50392396109444, 46.85434341430664, 45.445068086896626, 27.631214005606516, 25.939518724169048, 38.52237285886492, 53.90116821016584, 60.52035222734724, 62.96051093510219, 4.2968524268695285, 0.3530188357191426, 0.13705844192632607, 0.312156045543296, 0.11485638256583895, 0.17157566760267529, 0.10830589370535952, 0.2023586979401963, 0.1690449762557234, 0.10042867210826703, 0.09575373546353408, 0.16203363319592817, 0.13865360990166664], [0.035105356081788025, 0.05212474461378796, 0.09901744140578167, 0.03744901603619967, 0.004066245780060334, 0.008609712872255062, 0.020218874527407543, 0.12584704852529935, 0.07839441445789166, 0.04641781048849225, 0.026176686797823225, 0.03018545133194753, 6.637525524411883, 51.19050570896694, 49.604520320892334, 43.184120791299, 31.906475339617046, 22.657247032438004, 39.954605034419465, 35.27443047932216, 36.978424072265625, 57.033530780247276, 19.32664888245719, 0.09435181426150457, 0.12943250898803982, 0.6229795568755695, 4.998085907527378, 2.657966277429036, 12.246774111475263, 43.48962960924421, 55.83291333062308, 53.81283228737967, 50.819214820861816, 49.59704753330776, 46.49754646846226, 47.930661065237864, 48.095159666878835, 48.831321307591026, 49.85824074063982, 51.5509261403765, 52.18735681261335, 51.413859026772634, 50.79830421720232, 50.49336862564087, 47.98867504937308, 39.0404930795942, 38.972060271671836, 38.88845954622541, 38.2898131779262, 38.02614293779646, 45.86993653433663, 48.333062512534006, 47.24121216365269, 49.670326709747314, 47.50256517955235, 49.17278010504586, 48.41276182447161, 48.0619021143232, 48.300013405936106, 47.970373494284495, 50.34848826272147, 51.1502617427281, 50.92871495655605, 46.85474640982491, 39.80100120816912, 34.35421800613403, 35.573807512010845, 35.935937200273784, 36.436669554029194, 34.754517623356406, 33.11424248559134, 36.50894471577236, 47.93763358252389, 46.89790167127337, 43.80425793784005, 44.98666068485805, 48.95590945652553, 46.369435582842144, 48.703199999673025, 48.76437888826643, 47.96937642778669, 46.93590136936733, 47.193846293858115, 44.77877753121512, 49.61087097440447, 45.5014214515686, 50.436039039066856, 33.54017053331648, 31.432764530181885, 52.00894791739327, 44.779972621372764, 44.53081716809954, 37.504503454480854, 38.73003714425223, 37.620986529758994, 40.40104763848441, 37.51779883248465, 38.93497078759329, 34.58245938164847, 34.64644534247262, 33.31301655088152, 34.46058797836304, 33.65342269624983, 33.38441971370152, 35.20558772768293, 34.98057379041399, 36.04608004433768, 36.06752913338797, 36.14504671096802, 34.88000208990914, 37.169339724949424, 37.376031262534006, 42.089921951293945, 46.64246504647391, 46.32001652036394, 47.013870579855784, 49.01653596333095, 47.698410579136436, 47.836061341421946, 47.95110961369106, 47.28518731253487, 45.42474113191877, 49.63804537909371, 50.05323151179722, 47.63999359948294, 42.73833131790161, 36.06539256232125, 38.641572679792134, 36.91499744142805, 38.094725131988525, 36.51648003714425, 36.97373056411743, 37.95139421735491, 38.21796185629708, 39.513429164886475, 41.054313795907156, 45.27149861199515, 45.44681903294155, 49.82922853742327, 50.31536272593907, 52.69737195968628, 50.92839881352016, 52.99072143009731, 52.359891005924766, 51.96837043762207, 51.11553117207119, 56.782520157950266, 46.722056661333355, 1.3764675621475493, 3.798148078577859, 1.0971370594842094, 0.3074309990874359, 0.06517306462462459, 4.390440319265638, 51.38961328778948, 38.45280402047293, 34.094073976789204, 21.824032953807286, 12.956558653286525, 24.04507327079773, 42.63601909364973, 47.97017199652535, 46.37291663033621, 4.379189882959638, 0.25234771626336233, 0.027374089063544358, 0.016278779433508004, 0.07010659775031464, 0.017361012254176394, 0.03301371421132769, 0.03589232438909156, 0.03838831206251468, 0.07160293031483889, 0.007426700637941914, 0.0214541695812451, 0.01568635559773871, 0.07161875375147377, 0.01482823780471725, 0.03291225626266428, 0.027276894011135613, 0.022134831807176982, 0.004003208180490349, 0.03251578485859292, 0.07206566405615636, 0.027066171568419253, 0.06471499920423542, 0.10152931019131627, 0.1321323998272419, 10.708668759890966, 59.77722154344831, 55.47384432383946, 49.655721596309114, 35.198427609034944, 23.105742829186575, 30.48103502818516, 36.670017855507986, 40.192111832754954, 63.86059447697231, 19.909097262791224, 0.045569672249257565, 0.038904100456940274, 1.3766246565750666, 5.452076426574162, 1.6716623221124922, 12.949496677943639, 43.565229484013145, 57.6360889843532, 54.75078003747122, 52.83955989565168, 51.7606714112418, 48.64818416322981, 50.41139725276402, 50.172445229121614, 50.40456369944981, 51.929828780038015, 52.514193126133506, 53.90622649874006, 52.91054964065552, 52.705119201115195, 51.02914074489048, 51.11711188725063, 40.79347842080252, 40.49100249154227, 40.351739747183665, 40.300201484135215, 40.55021851403372, 49.37323563439505, 50.35826090403965, 49.747229371752056, 50.52993699482509, 50.86370413643973, 51.56719534737723, 50.48309223992484, 49.84182562146868, 50.11075217383248, 47.71448523657662, 50.528919083731516, 51.42105736051287, 52.10456902640206, 47.92792347499302, 42.90594966070992, 38.230333123888286, 37.23738343375069, 37.536076068878174, 37.16676541737148, 36.285712991442, 35.144610336848665, 38.47616039003645, 49.289339610508506, 49.65870932170323, 43.655955587114605, 45.44369234357561, 50.71478339603969, 48.46768038613455, 49.39955888475691, 48.95060798100063, 51.23883390426636, 49.00861849103655, 50.41589273725237, 47.98383910315377, 51.19876364299229, 47.154436111450195, 51.41449131284441, 34.12895393371582, 32.92684956959316, 54.69196701049805, 45.78793042046683, 46.029088497161865, 39.661137444632395, 40.149175439562114, 39.76368938173567, 42.348881312779014, 40.05069167273385, 40.48815720421927, 37.00935050419399, 37.77826942716326, 35.354772499629426, 36.79441840308053, 34.967928068978445, 36.12470585959298, 36.58804995673043, 37.282421657017295, 37.86884961809431, 38.41764266150338, 38.17918743406023, 37.138385500226704, 36.516452244349885, 39.71007708140782, 43.385615076337544, 48.694684982299805, 48.589346817561555, 48.64362614495413, 50.65504625865391, 49.06810201917376, 50.16889122554234, 49.53760916846139, 48.49913140705654, 46.46902411324637, 51.520791803087505, 50.55377973828997, 49.97705146244594, 44.557321071624756, 39.02117361341204, 40.441194329942974, 38.606922013419016, 37.85922983714512, 38.814231940678184, 39.50307982308524, 41.403314862932476, 40.453457900456016, 40.49537638255528, 43.83000796181815, 46.37340300423758, 46.5212641443525, 50.54459769385201, 52.27968794958932, 54.07120105198452, 53.6928334236145, 54.76851878847395, 54.26930114201137, 52.98331117630005, 54.327707699366975, 58.38571970803397, 49.077548095158164, 1.5532349454505103, 0.5614074979509626, 1.9728871413639613, 0.560984417796135, 0.01766909090136843, 4.546700962952205, 56.757607391902376, 42.19159494127546, 35.68269273212978, 24.491184098379954, 16.575290782111033, 29.95226321901594, 49.319831780024934, 54.2009517124721, 55.21943255833217, 6.999217476163592, 0.3381705624716622, 0.08331329122717891, 0.06365731238786664, 0.053174553638590236, 0.030264202106211866, 0.033159677271864245, 0.025968383332448344, 0.034111146216413805, 0.04914198948868683, 0.06995514194880213, 0.019571207763094987, 0.01262280052261693, 0.22658504439251764, 0.11817580301846776, 0.17714409237461431, 0.14045867589967592, 0.1763737651386431, 0.09118230933589594, 0.10189812790070261, 0.2112463531749589, 0.1886527519673109, 0.31505841123206274, 0.1697629748710564, 0.21030873991549015, 14.99073324884687, 69.7098868233817, 60.59018162318638, 57.18194430215018, 42.237362725394114, 31.4415922164917, 50.30743830544608, 49.73145696095058, 48.48718745367867, 68.78662409101213, 23.193486418042863, 0.3882768452167511, 0.3352475150355271, 2.6629057952335904, 14.970751966748919, 7.123287550040653, 14.424625294549124, 44.97982713154384, 59.84937858581543, 58.04117938450405, 53.97066409247262, 53.606811250959126, 51.30303873334612, 52.75985363551548, 53.33683899470738, 52.89831386293684, 52.27147517885481, 55.48013939176287, 56.91847208568028, 56.1318804195949, 54.57361486979893, 53.75633301053728, 53.71490437643868, 43.49541398457119, 41.357137135096956, 42.20257656914847, 42.81694323675973, 42.181256021772114, 50.66888359614781, 53.18371459415981, 49.463381562914165, 53.52630247388567, 52.00440032141549, 54.09280300140381, 52.83607537405831, 51.82234362193516, 51.248342514038086, 48.02170678547451, 51.30832283837454, 53.536304405757356, 54.669753619602744, 51.262155532836914, 41.892339502062114, 39.07964617865426, 38.65712622233799, 38.11255768367222, 40.04098503930228, 37.85472740445818, 36.997837339128765, 40.96864250728062, 51.15306534085955, 52.47629765101841, 44.25188173566546, 46.48256267820086, 52.61110312598092, 50.37732676097325, 50.25389896120344, 53.49283994947161, 51.666672706604004, 51.60465656008039, 51.07599939618792, 49.562177998679026, 52.629418577466694, 49.14509153366089, 52.39836318152291, 36.29586778368269, 36.2914765221732, 55.48688956669399, 49.736518723624094, 49.04722268240792, 41.263180119650706, 42.85287931987217, 41.66570316042219, 45.766120025089805, 42.32208211081368, 43.17020007542202, 38.847197668892996, 39.599611146109446, 37.56129802976336, 38.413584913526265, 37.07057455607823, 37.59336396626064, 38.517474378858296, 37.90282283510481, 39.907791546412874, 40.22730098451887, 40.37560680934361, 39.21984345572335, 39.10630294254848, 41.5105915750776, 45.40914937428066, 51.140225069863455, 49.44554901123047, 50.08177123750959, 51.452240875789094, 50.968069553375244, 53.04388209751674, 50.358802863529746, 51.04923146111624, 48.18551056725638, 52.966312408447266, 53.72396830150059, 52.13741316114153, 47.06492941720145, 40.5215676171439, 42.15411983217512, 41.42294699805123, 40.23939779826573, 40.224115235464915, 41.74582283837454, 42.24890715735299, 43.22192593983242, 43.39752776282174, 46.11324160439627, 49.757477964673726, 49.39251341138567, 54.45140300478254, 54.83439118521554, 56.41970607212612, 55.77721657071795, 56.960960320064, 57.30813748495919, 55.589014189583914, 57.349868365696494, 61.76506641932896, 52.3994505746024, 2.4270554908684323, 9.40034988948277, 5.183562857764108, 0.7684810236096382, 0.14701029791363648, 6.0351132324763705, 62.38210119519915, 50.276414598737446, 47.311507088797434, 29.465017318725586, 23.464830943516322, 35.18139410018921, 57.791002546037944, 60.00444848196847, 65.18695000239781, 9.567784105028425, 0.5530514749033111, 0.3227582366338798, 0.1630072495234864, 0.17880422329264029, 0.09982631621616227, 0.1963749961661441, 0.10737274520631347, 0.07409850747457572, 0.11325227828430277, 0.17419177293777466, 0.07305198934461389, 0.11931840170707021], [0.025947906841923083, 0.012296531199743705, 0.047454126844448705, 0.028435358544811606, 0.03519211696194751, 0.025581628549844027, 0.0690150520365153, 0.01928359373206539, 0.03261903753238065, 0.06083172293645995, 0.08631068574530737, 0.10740991535463504, 11.616389240537371, 55.56913539341518, 46.44965253557478, 53.81846380233765, 33.63880716051374, 28.303346259253367, 27.211449010031565, 31.008847985948833, 38.94668892451695, 53.76232235772269, 11.91051777771541, 0.16535579493003233, 0.056845655398709435, 0.34295515716075897, 3.228885207857404, 5.611445086342948, 27.28459095954895, 51.270003523145405, 57.34457383837019, 52.839726652417866, 51.0395039830889, 47.72135700498308, 46.518095765795024, 42.646667207990376, 43.55936173030308, 43.10097517286028, 44.906193596976145, 43.63673686981201, 47.09088441303798, 47.24925817762102, 47.88861404146467, 44.424440247671946, 40.209065437316895, 35.99653591428484, 36.86382048470633, 35.634958607809885, 37.59396151133946, 41.57680095945086, 43.80904177256993, 47.48132453645979, 50.15948336465018, 48.53685317720686, 47.756695543016704, 45.807781423841206, 46.58886316844395, 44.61075619288853, 46.682174001421245, 44.49005903516497, 46.424267292022705, 43.60212441853115, 47.70558112008231, 47.847234044756206, 41.67049394335066, 35.01183720997402, 35.42348670959473, 36.675899505615234, 36.38390493392944, 35.02517775126866, 33.64636680058071, 36.880496161324636, 47.80974503925869, 45.240495749882285, 44.968637057713096, 42.86297852652413, 44.704077448163716, 46.10158947535923, 46.5410977772304, 46.05262551988874, 48.29670606340681, 45.94529322215489, 47.71435669490269, 45.70816510064261, 48.39166014535086, 42.21932520185198, 43.92687627247402, 31.830430780138286, 31.44717856815883, 49.13849769319807, 44.57078668049404, 43.21664183480399, 39.31762892859322, 44.13874421800886, 42.278266770499094, 43.70148365838187, 40.99301331383841, 41.048988001687185, 38.46013784408569, 35.5068234034947, 35.268805912562776, 35.30815356118338, 33.85484055110386, 34.262574740818565, 32.403285435267854, 34.94047226224627, 35.70292936052595, 36.048744678497314, 35.327803066798616, 37.009781292506624, 34.25231919969831, 38.70387370245797, 44.169806139809744, 46.84558173588344, 48.03722211292812, 48.09304394040789, 48.169112818581716, 48.357773780822754, 47.1731093951634, 46.64453213555472, 48.55520336968558, 49.79598488126482, 48.584913866860525, 47.47252811704363, 42.68544510432652, 38.23129544939314, 36.57101992198399, 39.155902658190044, 38.6933263369969, 40.38650853293282, 40.63535131726946, 40.25835248402187, 37.24354648590088, 39.18772540773664, 47.382997104099815, 49.579729148319785, 49.04604843684605, 49.906016554151265, 51.680899143218994, 51.5520031111581, 51.492331981658936, 52.13711091450283, 52.569493838718955, 53.84215021133423, 53.41003826686314, 56.71059935433524, 55.470481395721436, 51.99286978585379, 4.53191476208823, 1.7693251158509935, 1.2750346107142312, 0.08146065992436238, 0.02621874918362924, 0.7199223435350827, 44.73451055799212, 43.84512029375349, 41.04260608128139, 31.743390696389334, 16.222202437264578, 24.362974200929912, 36.68979590279715, 49.09707600729806, 48.20570550646101, 11.422615272658211, 0.29431725133742603, 0.013975952020181077, 0.12750856365476335, 0.06116332300007343, 0.06097692943045071, 0.032420630500252755, 0.06494205737752573, 0.04383968275838664, 0.01798964780755341, 0.037607219868472645, 0.022747625264206102, 0.015520692969273244, 0.025234691898471544, 0.018612164671399763, 0.040124096242444854, 0.009554395618449365, 0.031098477875015566, 0.01830299019015261, 0.03562685774107065, 0.0038712661979453905, 0.05478319053405097, 0.04605578152196748, 0.0944376014439123, 0.0615458335461361, 18.23746837888445, 62.935087476457866, 52.06671871457781, 60.55801146371024, 40.66232769829886, 33.237944739205496, 29.59388903209141, 36.41885437284197, 44.58752489089966, 57.63826724461147, 13.211435948099409, 0.3205132899539811, 0.17591599827366217, 3.344823500939778, 1.697734677365848, 6.463995567389897, 30.010801792144775, 54.31613894871303, 57.85092033658709, 55.05940164838518, 51.675601141793386, 48.66587775094168, 48.659551416124614, 45.965887682778494, 46.687517166137695, 45.112648895808626, 47.26046909604754, 45.294458934238975, 47.182906355176655, 49.76965468270438, 50.09248883383614, 47.88880859102522, 40.73401573726109, 38.68922689982823, 38.34089285986764, 38.29418012074062, 39.91908236912319, 43.43987355913435, 47.002131598336355, 50.91303634643555, 50.675074441092356, 50.201499121529714, 50.66460697991507, 48.31212759017944, 48.12071861539568, 46.023592472076416, 46.02455479758126, 44.993925026484895, 48.374418190547395, 46.31235613141741, 49.439646516527446, 49.23331281117031, 42.06803512573242, 37.41579580307007, 37.2938722882952, 37.92820460455758, 37.16670635768345, 37.1239332471575, 35.59872375215803, 39.11068378176008, 47.687588759831016, 48.83876282828194, 46.894865308489116, 43.15877028873989, 46.38393299920218, 47.72885063716343, 47.77825927734375, 47.330037934439524, 49.63263273239136, 46.62513971328735, 49.62003217424665, 46.97052771704537, 48.70728554044451, 43.460871015276226, 43.74766833441598, 32.23988117490496, 32.02262142726353, 52.28618104117257, 46.66911833626883, 44.7668822152274, 42.45435496738979, 45.146976470947266, 45.04034941537039, 45.76287521634783, 44.77452870777675, 43.1788957459586, 41.477431297302246, 37.338316440582275, 37.404129777635845, 36.2310654095241, 36.30813830239432, 35.803983960832866, 35.68596880776541, 36.4372775214059, 36.92758757727486, 37.63406998770577, 37.00139134270804, 38.243906429835725, 36.265980107443674, 40.63583421707153, 45.65274279458182, 48.13398967470442, 48.1533647264753, 50.42734336853027, 49.37389918736049, 49.48548378263201, 49.87328011648995, 48.19565841129848, 49.43598828996931, 51.994339329855784, 49.85892513820103, 49.30639396395002, 44.461508887154714, 38.708629744393484, 39.28066451208932, 40.21636799403599, 41.38743475505284, 41.382227080208914, 42.144923891339985, 41.03041894095284, 39.12398958206177, 41.39800991330828, 48.832530294145855, 51.75848967688424, 50.91228246688843, 53.05454758235386, 53.228547845567974, 52.79523038864136, 52.353853021349224, 54.18990755081177, 55.32666410718645, 55.93101494652884, 54.282732009887695, 58.73777798243931, 58.00691434315273, 53.19198295048305, 5.792053520679474, 0.8785213817443166, 4.85822822366442, 0.5205057870064462, 0.03505070347871099, 0.86815195530653, 48.556315081460134, 49.160360200064524, 39.661231245313374, 24.237635646547588, 18.198813813073293, 26.709771701267787, 41.479727676936555, 51.41670778819493, 55.79653951099941, 16.44297797339303, 0.3224318341485092, 0.05984022721116032, 0.007448803068005613, 0.03174047039023467, 0.03977379236104233, 0.04367306848455753, 0.030021218716033866, 0.030327126051166227, 0.08723209558853082, 0.04610847315884062, 0.03907441274662103, 0.05445114942267537, 0.1506678866488593, 0.08888517652771302, 0.22409958418990883, 0.09042899975819246, 0.11253365541675261, 0.13857215855802807, 0.19643203381981167, 0.10759846666561705, 0.10387822200677224, 0.12079982007188456, 0.14665762255234377, 0.16459690779447556, 23.312370095934185, 71.99062606266567, 59.37806837899344, 69.68371295928955, 45.287211963108604, 40.73715284892491, 35.10209083557129, 43.83853340148926, 49.96198081970215, 61.984664235796245, 14.24624158654894, 0.2707901623632227, 0.16425160132348537, 5.510129928588867, 7.6536005565098355, 8.853985241481237, 30.878607477460587, 56.072716508592876, 61.80143329075405, 57.260062898908345, 55.956976890563965, 50.94067280633109, 51.94372517721993, 47.9116473197937, 49.846126556396484, 48.16717427117484, 50.40215614863804, 45.99107142857143, 50.46979686192104, 51.61232737132481, 52.05630683898926, 48.93682622909546, 43.114545004708425, 39.52946560723441, 39.62893601826259, 39.89893954140799, 41.82261432920183, 45.10770525251116, 48.26672806058611, 51.68532861982073, 54.2050198827471, 53.33145066670009, 51.94579921449934, 47.29119403021676, 47.02194438661848, 45.86284589767456, 47.79855496542794, 44.926551818847656, 49.32503250667027, 48.433818340301514, 50.8017817905971, 52.29888582229614, 44.797766957964214, 38.45594808033535, 37.95125872748238, 39.769491127559114, 39.26371785572597, 38.08082526070731, 38.499516759599956, 40.86621216365269, 50.92268739427839, 49.07380301611764, 48.16583674294608, 45.29783228465489, 47.84183529445103, 49.72808013643537, 47.944199630192344, 47.027634961264475, 50.58136061259678, 47.79218346732003, 49.52963958467756, 48.42771087374006, 49.64604275567191, 44.95153406688145, 44.38749320166451, 32.7658702305385, 34.82119601113455, 53.13676561628069, 49.81250074931553, 47.20529692513602, 45.229375158037456, 48.43000725337437, 46.53696707316807, 47.13313293457031, 45.84375919614519, 46.186204637799946, 43.127534661974224, 40.38438238416399, 41.09103502546038, 39.6027968951634, 38.49075508117676, 38.337460449763704, 37.67003386361258, 39.29117366245815, 38.70184482846941, 39.33054910387312, 39.13662140710013, 40.872510705675396, 39.124319621494834, 43.00528458186558, 48.58412177222115, 50.943424292973106, 51.57985149111067, 52.68003967830113, 51.2375693321228, 52.16964585440499, 51.63089990615845, 49.21375363213675, 51.71048109872, 55.89603076662336, 51.002748012542725, 51.440957001277376, 46.89912108012608, 40.59537138257708, 39.94822311401367, 42.95250259126936, 43.53623465129307, 43.66307749067034, 44.35988800866263, 44.033221926007954, 41.39495618002755, 44.19012267248971, 52.88022770200457, 53.717617647988455, 53.45824139458792, 54.69006667818342, 56.56978716169085, 54.93691880362374, 54.5093857220241, 55.76995570319039, 57.704879624503, 57.190098013196675, 56.332134451184956, 61.05307756151472, 60.918734141758506, 54.886450563158306, 5.812688367707389, 4.107543979372297, 6.647880511624472, 0.4615271974887167, 0.09245733091873781, 1.0422741919755936, 54.364984784807476, 54.57689094543457, 55.11336135864258, 40.46418244498116, 25.879217045647756, 34.30056749071394, 50.31691912242344, 59.46519184112549, 65.79641819000244, 20.64446680886405, 0.4176967122725078, 0.18852233753672668, 0.1940706776721137, 0.12589582162243979, 0.14624284766614437, 0.1264935838324683, 0.18705410989267485, 0.14584542970572198, 0.13074136232691153, 0.1212148799427918, 0.14858677903456347, 0.1759425832756928], [0.04976566834375262, 0.030529370198824575, 0.06150977619524513, 0.051676511165819, 0.034705709133829386, 0.034851119188325744, 0.03228292181821806, 0.029029468540102243, 0.09256837995988981, 0.026527363873486007, 0.03303776488506368, 0.0665859238111547, 28.873565810067312, 51.905287742614746, 49.91379506247384, 35.4361115864345, 18.830839327403478, 16.81992643220084, 28.49255265508379, 30.887136391230992, 43.997987610953196, 51.51124150412423, 4.796276347977774, 0.08638070377388171, 0.15583204025668757, 0.7411944706525121, 2.698979539530618, 10.170717511858259, 35.747147696358816, 54.745259693690706, 56.76145669392177, 52.24291808264596, 49.39230496542794, 47.21810940333775, 47.544528824942454, 44.17377356120518, 42.89891460963658, 37.6062250818525, 39.55880437578474, 37.32264477866036, 37.7826189994812, 37.41574369158064, 37.10037190573556, 35.333556175231934, 36.74864714486258, 37.45552560261318, 37.456824915749685, 37.6269793510437, 38.84276819229126, 39.617249148232595, 46.31550019127982, 47.3817846434457, 48.45175511496407, 46.7039600781032, 49.13227210726057, 45.105919565473286, 45.03228950500488, 44.49192115238735, 46.694847515651155, 46.958809580121724, 47.56497042519705, 48.69194391795567, 46.774692739759175, 47.22087826047625, 39.454199245997835, 35.711218561444966, 36.20588861192976, 34.194840226854595, 36.98413896560669, 33.94951670510428, 34.62468705858503, 36.02398477281843, 43.947668756757466, 45.59768874304635, 47.82996777125767, 45.08558218819754, 46.58993319102696, 45.330648626599995, 44.56398786817278, 45.834980147225515, 46.88818114144461, 46.129451751708984, 48.468343939099995, 47.14868300301688, 48.558382170540945, 47.51976891926357, 49.12735973085676, 37.37327977589199, 32.7297500201634, 50.10852527618408, 44.750706808907644, 45.946182591574534, 42.62933145250593, 43.810136113848, 45.97382252556937, 44.49449545996529, 44.25741250174386, 44.48657103947231, 41.43616247177124, 37.441184520721436, 33.89450781685965, 34.794219630105154, 35.02886029652187, 34.063349042619976, 33.8747228213719, 34.4883634022304, 34.975706577301025, 37.013376985277446, 37.296436173575266, 36.08614335741316, 34.75156116485596, 37.854713508060996, 45.05738639831543, 46.8652868270874, 46.671067305973594, 46.36350529534476, 46.95491164071219, 43.469782079969136, 47.52816581726074, 50.10769844055176, 47.83024222510201, 45.56663376944405, 45.96276446751186, 42.63317380632673, 38.32633638381958, 37.21086910792759, 39.772100176130024, 43.11272805077689, 44.11269542149135, 43.726076807294575, 41.579493386404856, 38.76408679144723, 41.06714711870466, 45.707122870853965, 49.5957864352635, 50.326723030635286, 50.39392948150635, 49.94624662399292, 49.41626582826887, 49.57438945770264, 49.352821826934814, 51.534879275730674, 52.81867708478655, 52.24287639345442, 55.19845594678606, 52.05008125305176, 56.934668336595806, 59.56263337816511, 11.082058003970555, 0.5354186296463013, 1.5874756681067603, 0.41100155296070234, 0.10063008165785245, 0.37156778467553003, 31.483204977852957, 53.15477534702846, 38.849143164498464, 48.279481479099815, 24.750873020717076, 29.205373559679302, 39.5610625403268, 44.64108507973807, 48.26157249723162, 21.488221304757253, 0.3641515054873058, 0.08006235531398229, 0.060470002703368664, 0.013723992459875132, 0.032034242126558504, 0.023854912990438085, 0.13944328895636968, 0.008030065850886916, 0.049332474624472, 0.035902417597493956, 0.02465788454615644, 0.04795183567330241, 0.05142033366220338, 0.019763216209997023, 0.04695826702352081, 0.04654006214280214, 0.0387127637597067, 0.035366140838180266, 0.03990945186732071, 0.048707275850964446, 0.07581516714500529, 0.025914931736354316, 0.09282536831285272, 0.22530770221991198, 37.127185004098074, 59.13486058371407, 55.159500871385845, 41.076395171029226, 26.472343070166453, 22.629716532570974, 32.22100639343262, 35.02195726122175, 49.23780134746006, 55.80702434267317, 5.375703130449567, 0.19169117749801703, 0.3069803975522518, 2.827235903058733, 0.6131045381937708, 11.330417888505117, 35.96823590142386, 54.748414175851, 57.9273088318961, 53.32374164036342, 51.90714291163853, 50.657895020076204, 47.61665807451521, 45.69971261705671, 45.20776973451887, 39.5056471824646, 40.461125237601145, 38.43823364802769, 39.89676822934832, 39.90698902947562, 38.83595895767212, 37.07089417321341, 38.941411767687114, 38.84801408222744, 39.49061822891235, 39.04174028124128, 39.37548310416085, 43.0211820602417, 47.05131094796317, 48.79354395185198, 49.08327341079712, 47.96476977212088, 48.585445404052734, 44.94866793496268, 45.621517590114046, 43.90458297729492, 48.34891135351998, 47.29695756094796, 50.20895801271711, 50.55797645023891, 48.932876178196494, 49.19008111953735, 41.95928539548601, 37.02410847800118, 37.41483000346592, 36.65209150314331, 38.38884932654244, 36.21134989602225, 36.04424919400896, 38.64787817001343, 44.29244531903948, 46.43632241657802, 49.2579094341823, 46.02425602504185, 48.40434060777937, 46.29006631033761, 45.40993799482073, 46.511870179857524, 47.393513202667236, 48.3429845401219, 49.29575627190726, 48.39574221202305, 50.5117952483041, 47.661081382206504, 50.59410013471331, 37.64751475197928, 33.465779645102366, 52.579853602818076, 47.95653963088989, 47.978440352848594, 45.508300168173655, 46.2567913872855, 47.151931285858154, 47.79442426136562, 45.548078605106895, 46.488392216818674, 43.82439729145595, 40.193028994968955, 35.392014844076975, 37.990390981946675, 36.38302946090698, 36.411301680973594, 35.11092547007969, 36.80918679918562, 38.186986786978586, 38.49251644951956, 37.7810035433088, 38.116438252585276, 37.73429775238037, 40.58484486171177, 47.08262995311192, 50.89491197041103, 49.56900460379464, 49.82048075539725, 47.805586542402, 45.4318665095738, 48.06850290298462, 50.95060178211757, 50.89366476876395, 48.12480068206787, 48.64838566098894, 44.926551818847656, 39.336607933044434, 38.86982100350516, 41.36142069952828, 44.59249632699149, 47.303085872105186, 46.11628144127982, 43.91562019075666, 42.061211994716096, 43.358756814684185, 47.23645612171718, 51.384798186165945, 53.46432801655361, 52.87903956004551, 50.90726586750576, 50.75662544795445, 50.670554637908936, 49.47099331447056, 53.11345788410732, 53.26415736334664, 54.99681574957711, 56.888671261923655, 54.559298106602256, 56.80626562663487, 58.86434636797224, 13.955241475786481, 0.5734289128865514, 1.2865820825099945, 2.0488613503319875, 0.09132379745798451, 0.3363503787134375, 33.290921279362266, 57.60564545222691, 42.220659255981445, 42.47958040237427, 27.060297897883824, 35.21220588684082, 46.912513732910156, 51.154590470450266, 56.511790548052105, 27.9702114037105, 0.4041850173047611, 0.08820832427591085, 0.006777091567138476, 0.02598364358501775, 0.03185599436983466, 0.004722951054905674, 0.05847312164093767, 0.013412315880746713, 0.033045690174081495, 0.028561038497303213, 0.04393468444634761, 0.02439282332280917, 0.14023283230406897, 0.10191340850932257, 0.13415068866951124, 0.11862196693462984, 0.1283486850027527, 0.17086950263806752, 0.14136376019035066, 0.09918549417385034, 0.19484629748123033, 0.10727711926613535, 0.14608522398131235, 0.5089316080723489, 44.47457150050572, 66.22966616494315, 61.95034013475691, 49.53566714695522, 27.818143129348755, 23.668074437550136, 36.23278161457607, 42.54805142538888, 55.09365974153791, 61.61825098310198, 5.821404882839747, 0.15613423261259282, 0.39617615991405075, 2.645263667617525, 6.676636500017984, 13.78808605670929, 38.60572344916207, 55.3725916998727, 61.56218596867153, 56.03694370814732, 54.0214832169669, 52.45556075232369, 51.880545207432334, 48.46260125296456, 47.574680532727925, 41.21902779170445, 44.2095741544451, 39.82724802834647, 41.14183677945818, 40.974993160792756, 41.16853175844465, 38.825321265629356, 40.2530197416033, 41.637726238795686, 40.25608389718192, 40.63850579942976, 42.73633023670742, 44.555055958884104, 50.72149188177926, 51.769370555877686, 51.160875116075786, 48.89238207680838, 49.278236389160156, 46.08127294267927, 46.9585941859654, 45.08438014984131, 50.270213331495015, 50.50014659336635, 51.76370429992676, 53.04636607851301, 50.04498747416905, 50.5698196547372, 43.73957020895821, 39.567368030548096, 39.554684094020296, 38.00991889408657, 40.093214648110525, 37.2604410307748, 37.58970921380179, 40.244619369506836, 46.31120273045131, 47.34537260872977, 51.204127652304514, 47.97514690671648, 49.98861673900059, 47.99532447542463, 47.671013832092285, 48.436066082545686, 49.40535715648106, 49.41219418389456, 49.48435470036098, 49.93189859390259, 53.81095627376011, 50.44145515986851, 50.99564347948347, 39.1013697215489, 37.85641581671578, 52.68924951553345, 50.83708211353847, 49.94221319471087, 46.32831614358084, 47.24630866731916, 49.960254192352295, 50.825377873011995, 47.13812174115862, 48.41293552943638, 44.58774723325457, 43.62739849090576, 37.48518051419939, 39.49705226080758, 38.26597390856062, 39.020697661808555, 38.098376410348074, 39.80694539206368, 40.07139035633632, 40.18759897777012, 40.98014177594866, 39.30595595496041, 39.29444278989519, 42.13398742675781, 49.36646114076887, 50.53826093673706, 51.11239406040737, 52.059631552015034, 51.66007191794259, 46.34425531114851, 50.11963891983032, 54.51586839130947, 52.71428040095738, 50.138138498578755, 50.08472769601004, 47.37148741313389, 42.35308149882725, 41.31369699750628, 43.79395375932966, 47.048170362200054, 48.93102100917271, 47.67389733450753, 47.17484644481114, 44.48068591526577, 46.03460536684309, 49.4356860433306, 54.60189403806414, 54.8586299760001, 53.703915800367085, 53.310408047267366, 51.432528836386545, 49.85753549848284, 49.31259175709316, 55.55170236315046, 55.87765972954886, 57.03046662466866, 59.41165597098214, 59.484799657549175, 58.31325694492885, 61.656500816345215, 15.781519889831543, 1.488100794809205, 6.5725507480757575, 3.1154745391436984, 0.31204294732638765, 0.6870828771165439, 38.636139188494, 63.55172620500837, 53.80826384680611, 62.850173541477744, 34.49287278311593, 40.478454044886995, 53.0525986126491, 56.81997094835554, 64.14114189147949, 35.67259005137852, 0.7746806623680251, 0.21060755316700253, 0.23577257139342173, 0.12201857753098011, 0.11505269631743431, 0.15047196644757474, 0.20997986756265163, 0.04749758361971804, 0.1250588215355362, 0.07607655240488903, 0.08552779204079083, 0.0905783928132483], [0.008595014955582363, 0.0618802902421781, 0.04098006138311965, 0.005617088455307696, 0.03632542650614466, 0.01760324077414615, 0.031209672801196575, 0.05860494742436068, 0.0598643355603729, 0.05202869458922318, 0.018333746486210396, 0.9070336403591293, 36.57109982626778, 51.60504218510219, 42.490864276885986, 29.55880410330636, 14.709289516721453, 25.6810405254364, 40.09035199029105, 31.872213772365026, 51.309052399226594, 39.34653343473162, 1.6460414912019457, 0.2441573100430625, 1.0054816348212106, 4.859653907162802, 1.3432412764855792, 20.796543768474034, 44.210626806531636, 57.254650252205984, 51.792504583086284, 53.43317576817104, 50.3675263268607, 48.50738934108189, 46.232594285692485, 44.26070247377668, 41.01049498149327, 40.19094453539167, 39.408639907836914, 37.78229938234602, 37.343503270830425, 36.71567446844918, 36.296131815229145, 37.98748663493565, 38.95559304101126, 39.92805596760341, 38.346267291477744, 37.231890882764546, 36.50727367401123, 39.26253318786621, 42.237338406699045, 46.42764759063721, 47.54240615027291, 49.287838799612864, 48.26819065638951, 44.49716009412493, 45.74766560963222, 47.42594044549124, 49.501353468213765, 49.437502997262136, 47.217136655535015, 46.927886622292654, 46.89000504357474, 41.63219199861799, 35.35698897497994, 35.76217317581177, 35.24591507230486, 36.64145033700125, 36.784829889025005, 35.77571521486555, 34.75366299492972, 36.2893260547093, 40.26156602587019, 43.900615555899485, 46.01474394117083, 46.12107917240688, 47.48622301646641, 45.15675606046404, 47.91282156535557, 46.51953404290335, 48.17929540361677, 47.95231860024588, 47.83223635809762, 47.58373403549194, 48.05288682665144, 46.514760630471365, 50.660177503313335, 41.50949028560093, 30.019365446908132, 50.288865770612446, 45.9540479523795, 48.88546861921038, 45.114302567073274, 46.162198611668174, 44.35236310958862, 45.85486936569214, 45.58962883268084, 44.6575870513916, 39.95355238233294, 36.87300252914429, 36.69211312702724, 36.8965082849775, 36.286946296691895, 34.2912951196943, 34.36815956660679, 37.293952192579, 36.75823565891811, 37.52608108520508, 35.936958585466655, 37.92659262248448, 35.154601846422466, 37.18691519328526, 42.42935534885952, 49.22112219674246, 47.54485191617693, 45.789257526397705, 48.620200293404714, 46.000524452754426, 47.32796389716012, 46.703081130981445, 45.10459245954241, 44.19739396231515, 40.385122367313926, 36.09590210233416, 37.042542048863, 37.97816562652588, 42.0856488091605, 46.875406878335134, 47.482470989227295, 45.225102015904014, 42.649425642830984, 41.1677257674081, 41.55635935919625, 47.48879732404436, 48.08541134425572, 48.51770741598946, 45.78246913637434, 45.17424120221819, 48.1541359765189, 50.838860852377756, 52.10536459514073, 52.80381488800049, 51.18504442487444, 51.942724636622835, 47.78578070231846, 53.34698683874947, 52.86592483520508, 48.02041094643729, 17.525618485042028, 0.6357016542128154, 3.2570840375764027, 1.3620614494596208, 0.08762968318270785, 0.06770366097667388, 17.85492835726057, 57.083505698612754, 38.58709532873971, 32.061496598379954, 16.967346361705236, 19.13012603351048, 35.992415632520405, 45.48483262743269, 52.78070517948696, 29.55647645677839, 1.1100066431931086, 0.009121915209107101, 0.022725686530715654, 0.017258310890091316, 0.09151680674403906, 0.08883984360311713, 0.02681335450948349, 0.05205411929637194, 0.061943149726305685, 0.025197442022285292, 0.033338070913617096, 0.086516505772514, 0.04120069043710828, 0.03722948620894125, 0.0583675280213356, 0.009025240932325167, 0.0750663358984249, 0.028267777358580912, 0.048936138927404366, 0.047568823011325936, 0.03408053410904748, 0.050759922313903055, 0.011831632083547967, 1.5984902999230792, 43.60089111328125, 58.86178248269217, 49.11190346309117, 35.707897322518484, 17.845662934439524, 22.236665623528616, 41.86269153867449, 35.51445252554757, 56.29811954498291, 43.080443246024, 1.604036699448313, 0.32266066329819815, 1.4214611649513245, 3.1190773972443173, 2.150510455880846, 22.975912264415197, 43.1073431968689, 58.49844033377511, 55.09668220792498, 55.74223239081246, 52.2903082711356, 52.277527059827534, 49.06921720504761, 46.40678562436785, 44.61213541030884, 42.50365243639265, 41.62016119275774, 39.70483813967024, 38.61129937853132, 39.06424897057669, 37.74553646360125, 39.411384446280344, 40.23639270237514, 40.8918753351484, 39.30933277947562, 39.0807648386274, 38.817535809108186, 41.544067995888845, 44.705036299569265, 46.8003420148577, 50.06592239652361, 50.44551290784563, 49.669777802058626, 44.98391614641462, 46.066657406943186, 48.55735036305019, 49.52201393672398, 50.28078154155186, 48.78994131088257, 48.27499294281006, 48.183235032217844, 43.70778220040457, 37.30759498051235, 37.42118065697806, 36.85155691419329, 36.93681478500366, 37.52146053314209, 37.77282203946795, 36.56333521434239, 36.69240147726876, 42.78755235671997, 46.10835007258824, 47.8476231438773, 47.11105850764683, 50.54578583581107, 47.724504538944785, 51.077566214970176, 48.14028474262783, 49.676955291203086, 49.68639441898891, 49.70852790560041, 49.2959577696664, 50.352309771946494, 47.38720423834664, 52.10762275968279, 42.130318777901785, 32.316061224256245, 51.430427006312776, 47.797300815582275, 50.82066004616873, 46.579031467437744, 48.56351341520037, 48.01013456072126, 49.15029573440552, 47.05946465900966, 45.875599316188264, 42.95447587966919, 39.5875004359654, 38.1871292250497, 38.30906663622175, 37.4368314743042, 37.51249040876116, 36.83539193017142, 37.19042403357369, 38.242937156132285, 39.504243646349224, 37.575677326747346, 38.78922189985003, 38.47203663417271, 39.64998211179461, 45.10432147979736, 49.45308085850307, 49.5411388533456, 48.260078634534565, 49.365717683519634, 46.810243197849815, 50.10201481410435, 49.38410609109061, 46.42289502280099, 46.10511221204485, 43.47547265461513, 37.692566871643066, 38.60330547605242, 38.66005836214338, 45.09201274599348, 48.26470613479614, 49.47424159731184, 47.21212353025164, 43.65040397644043, 43.17749220984322, 43.04346145902361, 48.686006682259695, 51.40113340105329, 50.074715341840474, 46.98513977868216, 45.3422451700483, 48.628809111458914, 52.763088021959575, 54.149746962956016, 53.386522088732036, 52.60665627888271, 52.22953585215977, 49.856760774339946, 55.53415468760899, 52.191070624760215, 51.445108549935476, 18.14275574684143, 1.4988384757723128, 5.07054215669632, 4.461731008120945, 0.0640260758144515, 0.09555622070495572, 19.729116337639944, 62.262543542044504, 42.7563271522522, 36.19581719807216, 21.646483898162842, 25.877052681786672, 41.3224378313337, 51.24172782897949, 60.17369270324707, 37.898994377681184, 1.9612892951284135, 0.06248139762984855, 0.06328599088426147, 0.0023200899803279234, 0.04316094757190772, 0.07478646734463316, 0.03516392383192267, 0.04339221266231366, 0.04114672315440007, 0.016819179989397526, 0.07248236598180872, 0.029948306735605, 0.10796258891267435, 0.16686010706637586, 0.08617089396076542, 0.11938451815928731, 0.15186966716178826, 0.10140978624778134, 0.15276267352913106, 0.09670411196670362, 0.1119315709386553, 0.12615769542753696, 0.11899923240499836, 2.2985444324357167, 53.200456278664724, 64.35871083395821, 56.56100116457258, 41.098431382860454, 22.894126755850657, 34.16216284888131, 48.71094724110195, 43.65011215209961, 62.042042459760395, 47.19404084341866, 2.0594365085874284, 0.38974014669656754, 2.534240573644638, 13.265618869236537, 3.4578544071742465, 24.80570994104658, 45.47111340931484, 59.90497807094029, 57.45175327573504, 59.106136730739046, 55.201777185712544, 53.09892920085362, 50.568124294281006, 49.568181242261616, 46.53347560337612, 44.11917461667742, 43.98899664197649, 41.08786317280361, 40.772685936519075, 40.69883700779506, 39.56033992767334, 41.9483767236982, 42.87897327968052, 43.26203441619873, 42.36558825629098, 40.802528449467246, 39.37353760855538, 43.21512712751116, 47.38886833190918, 49.989520004817415, 51.62614733832223, 51.81284890856062, 50.28196620941162, 45.69597101211548, 46.64693621226719, 51.32246242250715, 51.72945315497262, 52.93278040204729, 50.48604869842529, 49.767622334616526, 49.90820871080671, 46.965677874428884, 38.43710109165737, 38.509112221854075, 37.87328256879534, 38.88562815529959, 40.135595185416086, 39.92931011744908, 39.8770283971514, 39.69445058277675, 44.35100473676409, 46.84065546308245, 48.224337100982666, 48.48845202582223, 51.99562822069441, 50.63427461896624, 52.51700367246355, 48.87287153516497, 51.422203813280376, 52.32920776094709, 52.575788906642366, 51.950642108917236, 52.34029013769967, 50.84002120154244, 53.78305925641741, 43.54234906605312, 34.65997001102993, 54.639671393803184, 50.04317052023751, 53.345583302634104, 48.517641408102854, 50.92928123474121, 49.319824831826345, 50.563955375126426, 50.68156405857631, 48.644512040274485, 45.357333183288574, 41.83557619367327, 40.150565079280305, 40.43244654791695, 39.55165120533535, 38.58020618983677, 38.76030349731445, 41.19890233448574, 40.21233803885323, 41.90436683382307, 39.391067913600374, 41.82165200369698, 40.50464527947562, 41.41028390611921, 45.954697608947754, 51.27672937938145, 52.21989175251552, 50.2306398664202, 52.56558200291225, 49.924074922289165, 50.474903787885395, 50.57508986336844, 48.24297911780221, 48.81583029883248, 45.44315038408552, 39.54808330535889, 40.896117210388184, 41.293852942330496, 45.810216767447336, 49.864924907684326, 52.051828724997385, 50.54229089191982, 45.96520675931658, 45.67319481713431, 44.86953490121024, 51.257687841142925, 54.81837558746338, 51.513343334198, 46.67220333644322, 47.02373354775565, 50.719181605747764, 53.69636310849871, 56.867652961185996, 56.658453123910085, 54.552499294281006, 52.96146603993007, 50.653350898197715, 56.87098114831107, 53.33469200134277, 52.53122663497925, 21.40643753324236, 2.501603147813252, 7.857533659253802, 5.225579917430878, 0.23050434408443315, 0.17504131235182285, 23.36685265813555, 66.719069480896, 49.85431848253523, 45.450185435158865, 24.55305085863386, 29.450043950762065, 48.339097023010254, 58.21641295296805, 67.75453172411237, 45.9647342818124, 2.5027396125452857, 0.1344301908143929, 0.11418472789227962, 0.06876885239034891, 0.19850060210696288, 0.22293743012206896, 0.11397022940218449, 0.15115451839353355, 0.14268268298889908, 0.12854942280266965, 0.1526834884924548, 0.10024227853864431], [0.045098897867969105, 0.03622444013931921, 0.015000222683218973, 0.009103264825950776, 0.01975302291767938, 0.007128265669702419, 0.025806579871901443, 0.07717628125101328, 0.0023432125453837216, 0.03199107712134719, 0.027837184124759266, 3.3152923541409627, 45.864840030670166, 48.26716232299805, 48.26485552106585, 35.45422206606184, 21.03574592726571, 40.10809768949236, 45.683370453970774, 32.710948194776265, 55.2277877671378, 33.78789118358067, 0.47823354388986317, 0.05445737498147147, 2.1044643095561435, 3.1783240352358137, 4.335328076566968, 37.10522869655064, 45.09603227887835, 46.085427965436665, 52.87622553961617, 52.55106374195644, 53.46369573048183, 50.37565919331142, 47.620187759399414, 43.220088141305105, 40.62111793245588, 38.90073701313564, 37.749427454812185, 37.780906268528526, 36.119883809770855, 35.89151736668178, 35.62759351730347, 37.324972425188335, 38.12516866411482, 36.4518826348441, 37.51310185023716, 37.2199330329895, 36.406559535435264, 37.578755378723145, 39.08249494007656, 40.49633870806013, 44.86559874670846, 47.40524523598807, 49.33859886441912, 45.487907205309185, 47.4351224899292, 48.17225340434483, 45.374217305864605, 44.06139687129429, 43.11316578728812, 43.58177661895752, 39.70153079714094, 36.05956302370344, 35.33383757727486, 36.18982785088675, 35.267965180533274, 34.80032014846802, 36.6541759627206, 35.89768041883196, 34.62280062266758, 34.26461056300572, 38.4473740032741, 42.38972977229527, 48.29900591714041, 48.743228571755544, 44.55539294651577, 47.37212317330496, 47.00953837803432, 48.43916497911726, 47.21869305201939, 47.778005668095176, 46.632772309439524, 46.09970303944179, 45.54608447211129, 45.69184725625174, 47.6210423878261, 44.43663086209978, 29.03977540561131, 45.511934076036724, 44.89149815695626, 47.839834213256836, 46.55968420846121, 46.83042424065726, 45.205313546316965, 46.60891566957746, 45.51671096256801, 42.87702430997576, 38.2144912311009, 36.28051921299526, 37.23617444719587, 36.053247111184255, 34.777540479387554, 36.09515517098563, 36.19128349849156, 36.53713355745588, 35.24407727377755, 36.483910356249126, 35.23430115836007, 36.203776359558105, 37.062459060123985, 36.53683825901577, 36.39831549780709, 41.95876775469099, 45.73171601976667, 48.11372872761318, 46.033959184374126, 47.888617515563965, 47.83698892593384, 48.27305786950247, 45.36037302017212, 41.668941020965576, 38.407043184552876, 37.595556122916086, 35.63069936207363, 40.223531586783274, 46.16647522790091, 50.467469215393066, 48.45869289125715, 46.777409485408235, 42.881856782095774, 43.74341951097761, 44.91808543886457, 47.667737756456646, 49.2111028943743, 48.97702155794416, 47.77681752613613, 49.166919299534385, 51.3808377129691, 52.899383885519846, 48.025253840855186, 51.37600176674979, 50.4174838747297, 55.25751216070992, 47.84067147118704, 50.64333854402815, 41.23920883451189, 51.83606284005301, 19.576221227645874, 0.3881191536784172, 2.0105392123971666, 1.9022115852151598, 0.11202658619731665, 0.04765537354562964, 7.929480518613543, 55.51096160071236, 42.9102714402335, 33.13883910860334, 15.821051665714808, 15.8920761517116, 27.5021390574319, 44.41989959989275, 50.78977182933262, 35.71041257040841, 2.597352364233562, 0.06380450020411185, 0.03969252082918372, 0.047014174916382344, 0.04716863662802747, 0.09105854454849448, 0.043452198550637276, 0.012572147883474827, 0.09025792750929083, 0.05512095508830888, 0.02733308349602989, 0.04574715665408543, 0.04039770191801446, 0.07238000218889543, 0.054893404977130036, 0.048298869015915055, 0.048549078804041655, 0.048993668518960476, 0.01391235038837684, 0.05173071932845882, 0.007700824544632009, 0.09281551598438195, 0.02331643777766398, 5.504102366311209, 56.32121535709926, 53.634534563337056, 54.662492752075195, 40.99522631508963, 26.00021471296038, 37.22872945240566, 39.08355801446097, 36.85883167811802, 60.28202901567732, 37.12389155796596, 0.5048921533993312, 0.07091978804341384, 1.5539068579673767, 1.83245883669172, 5.01777970790863, 35.59286642074585, 48.25339446749006, 48.87622404098511, 55.57048681804112, 53.972276074545725, 55.07451398032052, 51.87651872634888, 48.64351844787598, 44.02039555140904, 42.60968542098999, 40.65309006827218, 40.00424296515328, 39.05976390838623, 38.2082656451634, 38.45234891346523, 37.39682027271816, 38.2460047858102, 39.06356457301548, 37.60426221575056, 38.28853470938546, 39.229762009211946, 38.42706789289202, 38.65697683606829, 40.371642862047466, 43.18808821269444, 47.864222390311106, 48.73494631903512, 50.751581055777415, 44.83580487115042, 47.69570772988455, 50.28507205418178, 48.19297293254307, 45.071091720036094, 45.472909518650596, 46.05352531160627, 42.53283487047468, 37.98373460769653, 36.95649903161185, 37.9994410106114, 37.19696576254708, 36.57598440987723, 37.340543338230674, 37.682804652622764, 36.074762208121165, 35.33731515066964, 41.7403997693743, 43.855004106249126, 50.02723830086844, 49.68599489756993, 46.21174274172102, 46.92320006234305, 47.72938912255423, 48.790709086826865, 48.47591052736555, 48.44019331250872, 48.192615100315635, 48.469191619328086, 48.31234993253435, 48.08955247061593, 48.838672501700266, 45.69575214385986, 30.5894547189985, 46.237722056252615, 47.09625537054879, 47.87372752598354, 48.72190107618059, 48.59390483583723, 46.7493839263916, 48.337432929447715, 46.812508310590474, 44.39940936224801, 39.09696108954293, 39.007912976401194, 39.838719504220144, 37.27499055862427, 36.08822086879185, 37.13189588274275, 37.590813977377756, 38.28041573933193, 37.88304131371634, 37.872156960623606, 38.320458207811626, 36.88143764223371, 38.057593958718435, 37.4221499306815, 37.72362184524536, 43.12782301221575, 47.785065037863596, 50.346393380846294, 49.35912731715611, 50.379803793770925, 47.48886680603027, 49.96053212029593, 47.41869000026158, 43.612960134233745, 39.65095138549805, 39.15311990465437, 36.87485769816807, 42.02060324805123, 47.712063789367676, 51.00054890768868, 49.746937547411235, 48.88964101246425, 45.37827157974243, 44.26881102153233, 46.94900219781058, 50.445259298597065, 49.9025285584586, 48.56240170342581, 48.26334081377302, 49.938395159585134, 53.26464373724801, 55.16977030890328, 51.050176416124614, 53.14497143881661, 52.95290238516671, 56.70070511954171, 49.1251779964992, 51.20837647574288, 40.60985837663923, 51.66050965445382, 22.70933072907584, 0.8274163497345788, 3.929353518145425, 5.0354324749537875, 0.6938311521496091, 0.06892645571913038, 7.934713380677359, 59.17639691489083, 47.62326928547451, 37.942653383527485, 18.768840551376343, 20.68578600883484, 30.55960873195103, 51.34887947354998, 55.30536787850516, 43.86866079057966, 3.684483800615583, 0.05633647254269038, 0.04140277173636215, 0.08073579453464065, 0.03095463862908738, 0.11493368127516337, 0.09064493674252715, 0.0702218876353332, 0.007921555378873433, 0.057974486611783504, 0.03213873312675527, 0.038195774358298094, 0.1378056446888617, 0.12178674925650869, 0.1176962958914893, 0.12922295023288044, 0.08077787049114704, 0.13571121064679964, 0.07659033912100963, 0.19997207314840384, 0.06757652387022972, 0.23026191709297045, 0.17233238342617238, 6.904305083411081, 64.96241896493095, 59.37985406603132, 60.22984804425921, 47.616963795253206, 30.63636200768607, 45.8268472807748, 53.2765668460301, 43.70500292096819, 66.83894675118583, 41.791076455797466, 0.8085468879767826, 0.1674157322517463, 4.435865470341273, 7.810240745544434, 5.98455423116684, 39.411426135471885, 48.37793745313372, 51.494253158569336, 57.16780471801758, 56.2719908441816, 56.36632653645107, 54.9465594291687, 51.730300835200715, 46.635020051683696, 44.612920556749614, 43.42958675112043, 42.137402466365266, 41.103173528398784, 39.906822272709434, 41.31391933986119, 39.08962379183088, 40.67399372373308, 42.49379294259207, 41.747275011880056, 39.9501964024135, 41.8231007031032, 39.311674322400776, 40.60353204182216, 42.62192119870867, 45.150749342782156, 49.394643034253804, 51.52704518181937, 52.555583545139854, 46.720076424734934, 48.655538831438335, 52.65934794289725, 49.6603490965707, 47.618301323481965, 47.386102948869976, 49.42006649289812, 43.49575097220284, 39.70487982886178, 38.288635458265034, 41.30180515561785, 39.232885224478586, 38.00279004233224, 39.22415133884975, 40.27528176988874, 38.10166638238089, 37.950216497693745, 43.66263280596052, 46.081533500126426, 50.83492122377668, 49.57846805027553, 48.16693803242275, 49.144427980695454, 50.04246875217983, 52.195600850241526, 50.73475251879011, 51.4480094228472, 51.606327601841514, 50.94016211373465, 49.90484578268868, 49.529076780591694, 51.510682174137656, 47.61521979740688, 32.700234072549, 47.684295313698904, 47.847466809409006, 51.948814732687815, 49.52398027692522, 50.03456517628261, 48.38247462681362, 51.16234118597848, 50.04889236177717, 46.00823695319039, 41.99238313947405, 40.426936626434326, 42.77619900022234, 40.82791369301932, 38.3088755607605, 40.2749274117606, 40.031917640141074, 41.48954895564488, 39.96850143160139, 40.83579295022147, 40.1554079736982, 39.85990456172398, 39.09566525050572, 41.29182059424264, 39.54886497770037, 45.092867374420166, 48.604695388248985, 52.608469758714946, 51.93476547513689, 52.87933138438633, 50.14484698431832, 51.87437520708357, 50.69814593451363, 44.64520536150251, 42.26129232134138, 41.065152985709055, 38.86086130142212, 45.286194052015034, 49.80096673965454, 53.41504444394793, 52.122092383248464, 50.83525126320975, 46.92155681337629, 48.791386536189485, 48.827395575387136, 51.23282718658447, 52.004834583827424, 50.62837559836251, 49.7710999080113, 52.27897228513445, 56.786101954323904, 59.515774726867676, 53.27587897436959, 55.782240118299214, 53.746567317417686, 59.60284955160958, 49.83739614486694, 52.09459488732474, 43.51993070329939, 53.54522589274815, 22.796511513846262, 1.9627822893006461, 6.697355593953814, 3.2253857042108263, 0.6011703557201794, 0.09475833137652703, 9.998748728207179, 65.97321510314941, 53.419081347329275, 47.351295948028564, 23.69755217007228, 24.417534930365427, 39.42032330376761, 58.77693802969796, 62.907037598746165, 51.24476071766445, 5.046812755720956, 0.15535201744309493, 0.10522447619587183, 0.12502561403172358, 0.32958470604249407, 0.23340608552098274, 0.17604428210428782, 0.11785712226160935, 0.17582939006388187, 0.15251312191997254, 0.12922395446470805, 0.13593075743743352], [0.012100801836433155, 0.015301229299179145, 0.04887600376137665, 0.0829539933641042, 0.03217166582388537, 0.060578792222908566, 0.033542096215699396, 0.014312588509970477, 0.005085738284313785, 0.028551980054804256, 0.046994348123137436, 6.285060346126556, 51.781151226588655, 47.467191900525776, 41.148750237056184, 20.231952258518763, 15.840860979897634, 36.45066670009068, 47.6669282913208, 31.884494713374547, 57.0885466166905, 27.357119730540685, 0.48201081263167517, 0.05102760777143495, 0.390355116554669, 1.3256155422755649, 13.234520469393049, 44.93683515276228, 40.70111601693289, 52.176142420087544, 53.708150727408274, 52.78505475180489, 50.24263940538679, 51.528862135750906, 46.50730521338326, 40.60949012211391, 38.37644679205758, 39.1069004876273, 35.926942757197786, 36.9868174961635, 34.98987742832729, 36.06885276521955, 36.0689674104963, 35.596635818481445, 35.00488901138306, 36.38610403878348, 34.55772379466465, 36.8136579649789, 36.71410764966692, 36.3319046156747, 36.412135464804514, 37.813184125082834, 42.39013276781355, 45.58923625946045, 49.08163363592965, 49.1430835042681, 45.144909381866455, 48.41129922866821, 48.289858613695415, 45.441069398607524, 40.79776198523385, 37.052908761160715, 34.349785055433, 35.484026363917756, 36.393962451389854, 34.91192558833531, 35.45393718991961, 34.65350471224104, 36.177262033735005, 37.327855927603586, 35.67564378465925, 33.125161579677034, 37.16278757367815, 41.43160792759487, 43.61087914875576, 49.643496240888325, 45.36164454051426, 44.711432116372244, 48.41070515768868, 47.317948068891255, 48.50170224053519, 45.700025285993306, 45.39116048812866, 44.30085611343384, 45.92833614349365, 46.71355554035732, 46.14238582338606, 46.83383233206612, 24.062730380467006, 45.60253511156355, 45.61533716746739, 44.61465065819876, 45.09685216631208, 47.14632061549595, 46.78008801596505, 46.165752615247456, 46.61690957205636, 41.28940609523228, 37.44345310756138, 35.22465705871582, 34.55464226858956, 35.07423203332083, 35.32094519478934, 35.858315399714876, 35.68855701174055, 35.85831192561558, 35.61709826333182, 37.66476712908064, 36.91048111234392, 36.3591901915414, 36.68947975976126, 37.112565994262695, 35.76582792827061, 35.879830496651785, 38.47179692132132, 46.336223193577354, 47.889208112444194, 47.87048966544015, 46.48535932813372, 48.13849210739136, 47.053103583199636, 43.9224294253758, 37.62266451971871, 35.920133522578645, 37.229969705854145, 41.56687198366438, 46.467665740421836, 47.44469015938895, 47.74714176995413, 47.557039056505474, 46.98648425510952, 49.374739919389995, 46.68398748125349, 48.73257350921631, 50.18582051140921, 48.73332044056484, 52.13339710235596, 50.39923790522984, 47.11575548989432, 48.46807643345424, 44.366367203848704, 47.25266279493059, 48.709665298461914, 53.63109173093523, 52.81370217459542, 44.86503594262259, 46.902754987989155, 59.18141351427351, 22.681629998343332, 0.8698227256536484, 4.542307530130659, 5.429258976663862, 0.027128296538389156, 0.012535107504975582, 2.597151517868042, 45.80576297215053, 47.665250301361084, 35.130925859723774, 31.66093294961112, 15.74646622794015, 26.714131695883616, 44.01164776938302, 48.793891361781526, 39.619976316179546, 3.9839819925171986, 0.11273919724460159, 0.020481201254629662, 0.024560453702828715, 0.06578160197074924, 0.022152120879452144, 0.015941991969676952, 0.019553324972678508, 0.04608204761253936, 0.0336873841338924, 0.04875884111970663, 0.01985436212271452, 0.03040690141330872, 0.043104798799114566, 0.02561346541291901, 0.0211695173555719, 0.005922623020264187, 0.06981385060186897, 0.05546707919399653, 0.047832186200789044, 0.053670715407601426, 0.06163485734058278, 0.07722967517163072, 9.164180619376046, 62.391231128147666, 50.962847982134136, 48.91751718521118, 24.46047306060791, 20.916466202054703, 39.58525616782052, 42.36655752999442, 37.52464280809675, 62.77962153298514, 33.86735773086548, 0.32059748257909504, 0.12227887713483401, 0.4177194839077336, 0.6387117984039443, 14.33110167298998, 47.99651261738369, 43.07014601571219, 51.60268327168056, 55.57578829356602, 56.57095445905413, 52.8314721924918, 53.5101374898638, 47.72468866620745, 41.96619190488543, 40.29485484531948, 41.39366034099034, 38.00857441765921, 39.14876338413784, 36.44626154218401, 37.38235412325178, 37.95340919494629, 36.87530585697719, 37.081438064575195, 38.101225171770366, 36.705019405909944, 39.624735832214355, 37.349499566214426, 38.352788175855366, 37.00859315054757, 39.31900119781494, 43.655896527426584, 48.258817536490305, 49.95947599411011, 49.98696654183524, 46.22960308619908, 50.98356751033238, 48.18443012237549, 48.17456368037632, 41.93207277570452, 37.8753114427839, 37.08707652773176, 37.25544875008719, 37.544334002903526, 35.864405495779856, 36.86095435278756, 36.49028532845633, 37.27797480991909, 38.39210108348301, 37.14997162137713, 35.857766492026194, 39.64700828279768, 41.37026228223528, 45.24720423562186, 51.444900103977744, 46.72385277066912, 45.218278884887695, 48.61677483149937, 48.76291281836373, 48.83199528285435, 48.186097690037315, 47.38318817956107, 45.87912205287388, 48.08478600638253, 49.17209570748465, 47.62782382965088, 47.417960439409526, 25.48755577632359, 43.90185580934797, 48.14033685411726, 45.52261693137032, 46.020392826625276, 47.53902585165841, 47.953221866062705, 49.22751453944615, 48.20229394095284, 42.06824704578945, 38.959987776620046, 37.02338586534773, 37.28610420227051, 37.29534183229719, 36.412316117967876, 38.12012774603707, 37.08964736121041, 37.7099095753261, 37.13753434589931, 38.71382004874093, 36.975422450474326, 38.76389224188668, 37.5967755317688, 38.232500961848665, 36.73221812929426, 37.506706033434185, 39.25202751159668, 47.75749111175537, 50.47854116984776, 48.90904038293021, 47.32334334509713, 51.387970038822715, 47.85358469826834, 44.0118909563337, 40.23694161006382, 37.78158719199044, 38.84749296733311, 43.354872771671836, 48.4602701323373, 49.85280377524239, 49.75886760439192, 49.774146693093435, 47.25785657337734, 51.02841118403843, 48.9176596232823, 50.336165632520405, 52.298896244594026, 50.773078782217844, 52.72593600409371, 53.88043131147112, 48.192701952798025, 49.31421763556344, 46.50701686314174, 49.430478368486675, 51.17321859087263, 55.72847148350307, 53.07114682878767, 47.252141680036274, 47.62850475311279, 60.3160890851702, 23.792204005377634, 2.5141105566705977, 5.976154293332781, 7.137936958244868, 0.7108679179634366, 0.01870498147660068, 2.537507529769625, 50.445113386426655, 51.310435090746196, 39.07065520967756, 31.767855303628103, 20.171560253415787, 33.23546423230852, 48.71583529881069, 55.6246132850647, 49.59270143508911, 6.857409954071045, 0.12158536006297384, 0.025742264930158854, 0.025115865149668286, 0.01291781906703753, 0.0350980889717383, 0.017612796243546263, 0.03875489399901458, 0.029263027078871216, 0.07093401013740472, 0.030191395298710892, 0.009441785946754473, 0.10984954730208431, 0.07685178544904504, 0.09473794818456684, 0.14466677366622857, 0.06239844672381878, 0.1024660820673619, 0.10061688415173974, 0.15121834139738763, 0.10085715340184313, 0.1252028609492949, 0.14896157463746412, 13.002952643803187, 68.4724473953247, 56.94555268968855, 56.550498962402344, 29.088041067123413, 24.59630513191223, 43.66729504721505, 56.692186628069194, 43.532208170209614, 68.16760213034493, 35.450317178453716, 0.6860093261514391, 0.22960794504199708, 3.601794809103012, 4.1483950444630215, 15.460047585623604, 48.15978833607265, 47.030292647225515, 55.23322473253523, 57.275685923440115, 58.53637749808175, 54.30493150438581, 56.32166351590838, 50.58476175580706, 43.85742555345808, 42.967281409672324, 43.71305240903582, 40.55434226989746, 42.16617843082973, 38.31908246449062, 38.938427516392295, 38.95291451045445, 39.30061279024397, 39.253121852874756, 39.734138693128315, 38.2690623828343, 40.67840930393764, 40.196322441101074, 40.00047704151699, 38.68961252485003, 42.04401520320347, 46.97769825799124, 50.562558787209646, 51.33337456839425, 51.15687642778669, 47.72337545667376, 51.154142311641145, 51.76852634974888, 49.94420385360718, 43.5349040712629, 39.504365239824565, 38.35431330544608, 38.443785258701865, 39.03536530903408, 37.12023680550711, 38.033129351479666, 37.768472467150005, 38.685485294886995, 40.15200335638863, 39.25190244402204, 37.63259696960449, 40.47112716947283, 41.706457819257466, 48.832446915762766, 53.58662673405239, 47.49048226220267, 47.67060736247471, 48.874170848301475, 50.84290817805699, 52.95124176570347, 50.47911787033081, 49.39428520202637, 48.635361262730186, 51.18216439655849, 49.99756949288504, 50.032286167144775, 49.62169279370989, 29.045662266867502, 46.280623708452495, 48.683998652866904, 48.83420828410557, 47.608764920915874, 49.92174727576119, 50.10257761819022, 50.11663382393973, 51.080258641924175, 46.336810316358296, 41.836465563092915, 38.38624722617013, 39.39087683813912, 39.43550859178816, 38.48686408996582, 41.08021668025425, 39.59817634310041, 39.24431848526001, 38.62334755488804, 41.264875480106895, 39.8550477709089, 40.774384771074565, 40.425244740077424, 40.2363475390843, 39.87044497898647, 39.89774445125035, 41.77138178689139, 50.20622737067086, 52.94697209766933, 50.66832774026053, 48.45836285182408, 52.887908935546875, 50.824957506997244, 48.40412521362305, 42.22809730257307, 39.9863235609872, 40.79610136577061, 44.901812757764546, 49.96482958112444, 51.35443108422415, 51.72538845879691, 51.1254323550633, 52.22973387581961, 53.45840120315552, 51.10724891935076, 52.14123119626726, 53.405737331935335, 52.88044309616089, 55.955493450164795, 56.68832342965262, 50.65054382596697, 51.38164022990635, 49.54994222096035, 53.043642384665354, 52.681272983551025, 58.34395408630371, 55.796560355595176, 48.22600466864449, 49.66974653516497, 57.38769088472639, 26.23776146343776, 2.7600848206451962, 11.205855795315333, 13.296041556767054, 0.7450812278049332, 0.1866366344371012, 3.3059294394084384, 54.977159295763286, 57.69475262505667, 49.231276988983154, 43.74997166224888, 24.923514911106654, 40.35406044551304, 57.00927114486694, 63.554797308785574, 59.031943866184776, 9.479294453348432, 0.4245095024151461, 0.14984312733369215, 0.16592718926923616, 0.08416817749717406, 0.09177981370261737, 0.15118764447314398, 0.15111120071794304, 0.13072947439338478, 0.125214762453522, 0.1090724075745259, 0.11152501989688192], [0.06929525985781636, 0.05676387157291174, 0.05320085704858814, 0.015617519916434373, 0.050591408142021725, 0.05282542701544506, 0.06186156946101359, 0.06412712324942861, 0.025950751599988768, 0.06781101200197424, 0.06992795983595507, 11.77965714250292, 56.488955293382915, 47.26895979472569, 40.96470635277884, 30.335463319505962, 33.48420279366629, 42.44360957826887, 46.43378284999302, 38.02823087147304, 59.82758903503418, 20.48330855369568, 0.11299650450902325, 0.035044562736792226, 0.9932423830032349, 1.6043499112129211, 22.73926877975464, 41.64605018070766, 48.32317522593907, 51.207445417131694, 51.617614950452534, 52.20133311407906, 50.7482077053615, 48.291394165584016, 40.84303297315325, 37.569552489689414, 35.23770924976894, 38.292898178100586, 40.647378649030415, 41.02246672766549, 39.76685776029314, 37.13417836597988, 35.38404526029314, 34.4537787437439, 36.510528905051096, 35.343144689287456, 36.53580297742571, 36.33500351224627, 37.24348047801426, 36.2534316607884, 35.11449684415545, 36.6208940914699, 38.465936115809846, 44.53401681355068, 44.08335665294102, 48.32027782712664, 47.4915314401899, 46.34252173560006, 47.71851519175938, 46.03115211214338, 43.06074162891933, 36.043325083596365, 35.7899729183742, 36.74000358581543, 36.560066086905344, 34.71581615720476, 35.31578268323626, 35.805655002593994, 36.79647159576416, 36.68213203975132, 35.011646134512766, 34.16759286608015, 34.61766937800816, 39.62119919913155, 44.68109975542341, 43.894313539777485, 46.92576047352382, 45.55762542997088, 42.963810784476145, 48.256972789764404, 47.28684793199812, 48.07914754322597, 44.783867086683, 46.02455479758126, 44.09683615820748, 45.79401356833321, 47.29010663713728, 45.698694705963135, 27.300427641187394, 46.92724391392299, 47.12387793404715, 47.4868483543396, 45.89232363019671, 47.00627967289516, 45.00935697555542, 46.85928358350481, 47.52872862134661, 42.80110134397234, 37.88341304234096, 36.590902192252024, 36.52775348935808, 35.94935417175293, 35.46450539997646, 35.810560430799214, 34.13834095001221, 37.67825010844639, 35.14880010059902, 36.20714276177542, 37.25422934123448, 36.62048067365374, 36.38536752973284, 36.63815689086914, 36.14818034853254, 36.526169300079346, 37.82618767874581, 48.024086543491904, 48.06637675421578, 46.02271352495466, 45.76153768811907, 48.89466456004551, 46.26771395547049, 41.36805970328194, 36.83976929528372, 37.6253638948713, 37.15501601355416, 39.76151459557669, 44.96516643251692, 48.92735236031668, 48.13626520974295, 51.27926894596645, 50.28642347880772, 47.82349899836949, 48.79027482441494, 50.90851306915283, 47.69818128858294, 49.450777530670166, 48.62037399836949, 49.42787626811436, 44.76931755883353, 39.18003722599575, 41.34701360974993, 48.40905843462263, 50.41964476449149, 55.507841859545024, 50.95785222734724, 49.6540436063494, 41.29467282976423, 56.91201720918928, 28.945981672831945, 1.203742293374879, 2.5331421068736484, 8.082697851317269, 0.967490513409887, 0.14361203169184072, 0.46395206451416016, 34.7191721371242, 56.02147701808384, 34.98447520392281, 33.71218013763428, 15.820468017033168, 21.870208944593156, 38.5386038507734, 49.46307931627546, 44.035118784223286, 10.2202034507479, 0.10828436378921781, 0.04872611876843231, 0.019090618372761776, 0.062404092135173936, 0.04639648413285613, 0.03185315809345671, 0.009009455663285084, 0.05143602478450962, 0.00809655210468918, 0.011714184457170112, 0.028570653338517462, 0.018031935806253126, 0.04743487002061946, 0.020370493177324533, 0.027651879603841474, 0.03505809272506407, 0.026401515983577286, 0.021638369786420038, 0.04628911953685539, 0.029164544506264583, 0.01715282753242978, 0.08212879300117493, 16.67878941127232, 64.12367412022182, 50.95736585344587, 46.98546634401594, 33.24584484100342, 39.9973156111581, 46.09169176646641, 46.1302091053554, 41.83425951004028, 63.306169918605256, 22.549612488065446, 0.08766818325966597, 0.027629208052530885, 1.3643951756613595, 1.3034943235771996, 25.016290732792445, 43.10135384968349, 48.66238975524902, 52.75083139964512, 53.76619250433785, 54.489444392068044, 53.05940784726824, 51.15793602807181, 42.41252333777291, 40.19807686124529, 37.57268960135323, 39.83784403119768, 43.272362913404194, 42.496016366141184, 40.81473296029227, 39.49914714268276, 37.604679107666016, 35.68683385848999, 36.54655531474522, 36.16243805204119, 37.81447301592146, 39.14619255065918, 39.36715221405029, 38.079289708818706, 36.550338608878, 38.48755890982491, 39.799333640507285, 46.55392762592861, 48.20098073141915, 49.54665919712612, 48.67410094397408, 47.152935300554546, 48.97169576372419, 48.576853956495015, 45.28842789786202, 37.77909278869629, 37.04131916591099, 37.089609146118164, 38.314823218754356, 36.00046859468733, 36.150223118918284, 37.19086177008492, 38.516796929495676, 37.28400584629604, 36.94896023614066, 36.792257513318745, 35.83394111905779, 41.05570343562535, 46.1434280531747, 46.76932178224836, 46.91219064167568, 46.01682492664882, 44.23427152633667, 48.65507330213274, 49.05773530687605, 51.7536815234593, 47.63541126251221, 45.59891162599836, 46.26081786836897, 47.21454497746059, 49.70175688607352, 47.02320548466274, 29.166943073272705, 48.7415714263916, 48.706955501011436, 50.46901518957955, 47.733321802956716, 49.091044970921104, 46.53013004575457, 47.41804729189192, 48.19394220624651, 45.8029420035226, 39.052409240177695, 38.66292449406215, 38.780310835157124, 38.107235363551546, 37.95557355880737, 37.739196232386995, 37.31578343255179, 38.62221152441842, 36.432570116860525, 38.06305871691023, 38.28020034517561, 38.886409827641074, 37.95713690349034, 38.083750452314106, 38.35467461177281, 37.83046429497855, 40.280343532562256, 48.126662799290244, 51.07263994216919, 47.614160197121755, 46.432945592062815, 51.63509661810738, 47.92627675192696, 43.87915257045201, 39.29972342082432, 40.630115849631174, 38.11714696884155, 42.13041605268206, 46.48808649608067, 50.97699104036604, 49.79082236971174, 53.24939244134085, 51.18378332683018, 49.20938321522304, 51.234029224940706, 52.29751007897513, 49.031029905591694, 51.61348077229091, 51.22497572217669, 51.342351640973774, 46.7330904006958, 41.1179210799081, 43.09800481796265, 51.26309701374599, 51.80979864937918, 58.108121803828645, 53.275343963078086, 51.40419755663191, 44.79425116947719, 58.03175415311541, 30.627107007162913, 1.7559554789747511, 6.2700687391417365, 11.695103645324707, 1.787858567067555, 0.20964218782527105, 0.39658990342702183, 38.17925344194685, 61.24512577056885, 39.29163919176374, 36.47369997841971, 21.07455509049552, 27.940325464521134, 44.53489923477173, 55.10758740561349, 51.561998094831196, 15.418578999383108, 0.1500020945178611, 0.01218518614768982, 0.051277898983763795, 0.029712695628404617, 0.03843936164464269, 0.026451021898537874, 0.014702635883752788, 0.007437709868619484, 0.012889276491478086, 0.008174499663125192, 0.07138505272035088, 0.15095333276050432, 0.1382809720401253, 0.11049159749278001, 0.07621289044618607, 0.12639238711978706, 0.13724065572023392, 0.15240737902266638, 0.10774057903992278, 0.07227540601577077, 0.1680337419467313, 0.12486059431518827, 21.35509729385376, 73.98704501560756, 58.09540660040719, 55.44126074654715, 40.53682238715035, 45.549270221165244, 47.17516606194632, 56.419737339019775, 48.56998218808855, 68.71167387281145, 25.66475394793919, 0.21216595811503275, 0.1589434625846999, 3.215916612318584, 3.1204902700015476, 25.499628271375382, 48.46176399503435, 51.68436976841518, 55.191605022975374, 56.584878649030415, 55.07286030905587, 55.65290287562779, 53.29290900911604, 44.46011577333723, 41.817695004599436, 40.53971631186349, 43.37558535167149, 46.93175676890782, 43.50874410356794, 42.92009619304112, 40.40338223321097, 39.028931277138845, 37.992086342402864, 39.33481182370867, 38.58097396578108, 38.31335367475237, 40.3094356400626, 41.41122538702828, 39.199679783412385, 38.387550013405935, 41.177967412131174, 41.78079659598214, 48.54003197806222, 48.35178095953805, 51.298522404261995, 48.730256284986226, 48.2200083732605, 51.126342569078716, 50.707195963178364, 47.86001525606428, 39.23014416013445, 38.862184933253694, 39.98936339787075, 40.333420821598594, 38.05629811968122, 39.052374499184744, 40.46463755198887, 40.09188754217965, 39.2928203855242, 38.31752259390694, 38.080575125558035, 37.882454190935405, 42.53147649765015, 47.96165003095354, 50.238262040274485, 49.28387137821743, 47.62513140269688, 45.359452383858816, 51.63075051988874, 51.91478245598929, 53.010808672223774, 48.613460540771484, 48.69775608607701, 48.08066572461809, 49.3955671446664, 51.18257086617606, 49.29520041601998, 32.560554436274934, 51.42544167382376, 50.89092023032052, 50.85415383747646, 48.5623322214399, 50.611658232552664, 49.007447719573975, 49.842103549412315, 51.62427479880196, 47.032436166490825, 41.83273090635027, 40.14973476954869, 41.23589106968471, 39.43993806838989, 40.501966748918804, 39.990499428340364, 39.16238185337612, 41.81316130501883, 37.680584703172954, 39.434289182935444, 40.10581520625523, 40.26904576165335, 40.904736450740266, 41.10258640561785, 40.55962290082659, 40.27845362254551, 42.521637848445344, 50.91429744447981, 53.816910879952566, 49.46320785794939, 48.24861758095877, 53.25644833700997, 50.2593081338065, 45.41724749973842, 41.35114083971296, 41.520965235573904, 40.650001593998496, 43.551836831229075, 50.65922212600708, 52.9598297391619, 53.23346717017037, 54.54045806612287, 56.76617104666573, 52.384244441986084, 53.124908515385215, 54.74071557181222, 50.71270588466099, 52.32654660088675, 53.449625628335134, 54.52831261498587, 50.00118950435093, 42.6064510345459, 46.72596502304077, 53.72766126905169, 54.555490493774414, 60.30201203482491, 55.56938205446516, 54.15826198032924, 48.923419679914204, 59.28055041176932, 31.61114910670689, 2.881452045270375, 8.348267555236816, 16.003863981791906, 2.980290387357984, 0.2925262988678047, 0.7293131596275738, 43.23558957236153, 66.95983151027134, 47.1453652381897, 44.618281091962544, 24.37591174670628, 33.70677791322981, 54.13117790222168, 61.84152439662388, 61.87281213487898, 19.024079152515956, 0.2508615074413163, 0.14284475786345346, 0.10110504938555614, 0.20494664407202176, 0.2097466415060418, 0.12609081901609898, 0.09281554991113287, 0.08420449269137212, 0.16598426763500485, 0.10196748096495867, 0.13483758323958941], [0.007108051263328109, 0.03819803387991019, 0.08306487277150154, 0.013923748080352587, 0.023723129615453736, 0.08959037118724414, 0.05680998142010399, 0.02241143660752901, 0.012819970076504563, 0.07170720079115459, 0.12708289149616445, 19.468135050364904, 54.36076375416347, 43.62952811377389, 40.4580054964338, 20.64516510282244, 27.651535749435425, 51.52958474840437, 36.77778788975307, 43.05537414550781, 56.544822284153526, 21.73107647895813, 0.13255694561770984, 0.12502059287258557, 0.6590457558631897, 2.4677925620760237, 26.869793925966533, 48.01452234813145, 51.28661666597639, 51.282642296382356, 52.898431982312886, 51.521170479910715, 48.56070981706892, 40.28266423089163, 36.810934271131245, 36.0222373008728, 42.680004664829795, 45.138100147247314, 45.17933075768607, 46.60141856329781, 42.493563652038574, 38.10987915311541, 37.52363879340035, 35.405577727726524, 36.499575069972444, 37.248934813908164, 37.51357085364205, 36.51090063367571, 38.38604572841099, 39.34305586133684, 36.88227490016392, 35.8863513810294, 36.411096709115164, 37.57733447211129, 44.59526865822928, 47.208097049168174, 49.010713372911724, 48.43491268157959, 47.62336656025478, 47.271898882729666, 45.60036032540457, 37.425860268729075, 33.64523424421038, 36.73504604612078, 36.49550689969744, 35.587818554469514, 35.78570325034005, 37.45638370513916, 35.73114252090454, 36.51016412462507, 35.14855343954903, 33.78180456161499, 34.30657073429653, 36.09913648877825, 42.945801053728374, 45.528529848371235, 43.87802348818098, 45.98024613516671, 44.55464948926653, 47.4249016898019, 48.008977685655864, 48.68870605741228, 45.669481004987446, 45.546553475516184, 44.56647879736764, 46.533128193446565, 45.33858346939087, 48.26403215953282, 30.342223916734966, 45.32345724105835, 45.88826935631888, 43.47455549240112, 47.48374598366873, 49.157153606414795, 47.31850045067923, 46.088050910404746, 46.07457487923758, 42.000113010406494, 37.31776714324951, 36.62107474463326, 37.94557162693569, 38.03838913781302, 38.94513600213187, 36.50046443939209, 36.64471599033901, 36.458278451647075, 34.86934355327061, 35.86138997759138, 37.82564919335501, 37.22704798834664, 36.42256818498884, 37.34800222941807, 35.45589310782296, 37.216865403311594, 37.98795911243984, 45.69094051633562, 49.310323170253206, 45.365684917994905, 47.47114889962332, 48.19108649662563, 46.45024313245501, 43.35237489427839, 36.79424817221505, 38.421505859919954, 37.709690707070486, 37.59734180995396, 38.67970439365932, 47.764164856501985, 46.67850882666451, 50.63110971450806, 49.92794854300362, 50.921266487666536, 49.19276312419346, 46.750064849853516, 49.82070657185146, 51.10808617728097, 48.31622355324881, 45.92573404312134, 38.55629049028669, 39.82386425563267, 48.457650661468506, 51.61072581154959, 50.10756295067923, 53.508306639535085, 49.604871204921174, 49.75955547605242, 39.29755210876465, 49.07010310036795, 42.553279944828574, 4.253609010151454, 5.313972728593009, 3.9385820286614552, 1.2742303567273277, 0.1318847888282367, 0.07756555000586168, 25.800712823867798, 59.13855702536446, 39.11008276258196, 41.67210939952305, 23.158319847924368, 21.291064432689122, 36.92070191247122, 48.47675820759365, 45.04721770967756, 18.751113959721156, 0.4216258371514933, 0.033602302627904077, 0.07941425937627043, 0.020657886684473072, 0.01943778063702796, 0.03638635555814419, 0.034424442797899246, 0.05461923272481986, 0.04207404303763594, 0.039628687647304366, 0.0704527727461287, 0.042112325983388085, 0.058653367683291435, 0.034236614126712084, 0.05519508843177131, 0.042255021897809844, 0.012373867228494158, 0.06647132603185517, 0.02830265066586435, 0.02703367652637618, 0.060245027632585595, 0.06028020967330251, 25.616646357945033, 61.176831926618306, 51.91430303028652, 47.22064896992275, 26.638078451156616, 30.426439557756694, 46.89550454275948, 41.015869413103374, 45.19135114124843, 61.126881326947895, 21.470020498548234, 0.19331466752503598, 0.20973881121192658, 0.6983603462576866, 2.9686855929238454, 28.877067702157156, 49.30007457733154, 52.96458578109741, 54.24535070146833, 54.66465016773769, 54.17077568599156, 50.562051568712505, 43.19449445179531, 39.00856958116804, 38.46451868329729, 43.20635502679007, 48.70371764046805, 48.1100948197501, 47.465260301317485, 44.6761144229344, 39.797721658434185, 39.040628569466726, 37.355902331215994, 38.56070259639195, 38.612786293029785, 39.19026844842093, 38.07170227595738, 41.60535110746111, 41.401119232177734, 38.51264885493687, 37.747336047036306, 38.76607397624424, 40.158816065107075, 46.84382036754063, 48.658196517399375, 50.852562699999126, 48.19652346202305, 46.71091522489275, 49.7232163974217, 47.572057587759836, 39.78369671957833, 35.121809823172434, 38.15544891357422, 37.658023902348106, 36.121943950653076, 35.797362327575684, 39.2431720324925, 38.373393058776855, 37.64564916065761, 36.89686264310564, 35.397434438977925, 36.742914881025044, 39.235414368765696, 44.709906986781526, 46.83621209008353, 43.89793355124337, 48.45628881454468, 45.7780431338719, 48.27545847211565, 49.99364376068115, 49.41821479797363, 47.50064747674124, 47.37666729518345, 46.82128388541085, 48.981926986149375, 46.297601631709504, 49.48020315170288, 32.01939398901803, 47.478072779519216, 46.87598705291748, 46.11329024178641, 48.804723603384836, 52.21193606512887, 49.50931262969971, 48.49342346191406, 48.20387813023159, 44.581202030181885, 40.16478109359741, 37.973534652165, 38.80519233431135, 41.15782458441598, 40.63434730257307, 38.274992670331685, 38.342032364436555, 37.573704038347515, 36.861364296504426, 37.95541027614048, 40.63214472361973, 37.87929623467581, 37.52056074142456, 38.22514281954084, 36.6069073677063, 38.07716008595058, 40.63525751658848, 48.157877581460134, 52.63123900549752, 47.165789467947825, 47.767878668648855, 50.62531839098249, 48.09696272441319, 45.05501706259591, 37.07152993338448, 38.783038003104075, 40.88701159613473, 40.09171731131417, 39.86954171316964, 50.07893637248448, 49.281512464795796, 52.718848841530935, 51.53334024974278, 53.057622160230366, 50.652871472494944, 49.12856871741158, 48.93530109950474, 53.45105695724487, 50.16264826910836, 48.199674470084055, 41.13833488736834, 42.17299461364746, 49.86417102813721, 53.96401119232178, 51.610986368996755, 53.72056368419102, 50.349860531943186, 51.94861323492867, 44.71385703768049, 49.13992207390921, 45.24199308667864, 3.4646024107933044, 3.317320793867111, 6.408526795251029, 2.398221118109567, 0.031473429540970495, 0.05076371193198221, 27.477780410221644, 63.94548061915806, 43.02518422263009, 38.41974796567644, 26.438121455056326, 26.323703731809342, 44.446521622794016, 54.85376623698643, 55.77028226852417, 25.832148211342947, 0.6970341631344387, 0.0225422208396984, 0.10417964083275624, 0.06894425369266953, 0.00992999698168465, 0.05861027392425707, 0.032108925083386045, 0.10643395808126245, 0.012219643852274333, 0.009631021729936557, 0.010657854710838624, 0.13289343113345758, 0.20084118151238986, 0.1495374608784914, 0.17111292029065744, 0.11920553419206824, 0.1053427652056728, 0.18094726758343832, 0.12905179655977658, 0.20094796935362474, 0.1885765524847167, 0.32075625977345873, 31.617333003452845, 69.29578808375767, 57.851792335510254, 55.85564088821411, 30.804716859545024, 35.24671411514282, 55.330315385546, 46.772392886025564, 52.31732286725725, 65.387099811009, 26.389586550848826, 0.21892955446881907, 0.44479284116200035, 0.9950687821422304, 3.7956667031560625, 31.044488770621165, 50.5009560585022, 55.68996109281267, 55.783688817705425, 57.71395397186279, 56.743766580309185, 52.70312506811959, 43.12279599053519, 41.78852646691458, 40.923576491219656, 46.851181983947754, 49.28510120936802, 50.42895187650408, 51.161722796303884, 47.17283146721976, 41.4032175881522, 41.54185846873692, 38.7920880317688, 40.807673590523855, 41.0091678755624, 41.402415071214946, 39.2284904888698, 43.94097416741507, 44.04206003461565, 40.59051806586129, 39.333932876586914, 41.44512217385428, 41.265330587114605, 49.44356182643345, 51.12671777180263, 52.33801460266113, 50.08534608568464, 48.873656681605745, 51.09423494338989, 50.08426216670445, 41.741803305489675, 37.46094867161342, 40.3267297063555, 39.69697972706386, 37.083046572549, 38.00511074066162, 41.290893009730745, 39.6513717515128, 39.16705451692854, 37.31233365195138, 37.16173144749233, 38.79235553741455, 40.71128470557076, 46.71873194830758, 48.86044468198504, 46.480502537318635, 51.15998574665615, 45.4083503314427, 49.25596741267613, 52.374291147504536, 52.096443108149934, 49.758179732731406, 50.80001694815499, 49.46127625874111, 49.69579880578177, 49.1116498538426, 50.28591626031058, 34.80430146626064, 50.945474011557444, 50.63486521584647, 48.77240405763899, 51.138526235307964, 54.670194830213276, 51.42884629113333, 50.83140543528965, 51.02064657211304, 46.044044494628906, 41.744391509464805, 41.40404094968523, 40.80197606767927, 41.835350377219065, 43.53423357009888, 40.505819525037495, 41.545388153621126, 39.85290425164359, 37.935552324567524, 39.97030796323504, 41.783829484667095, 39.808237757001606, 40.00144631522042, 40.872878960200715, 38.01128421510969, 41.03905207770211, 43.28771843229021, 49.51773732049124, 54.296204566955566, 46.85179342542376, 51.051729338509695, 51.72406830106463, 51.23317459651402, 47.07801634924752, 38.353291920253206, 41.89241245814732, 42.374068532671245, 43.54156044551304, 42.09339952468872, 51.76687962668282, 50.378619125911165, 54.62354462487357, 51.77630833217076, 53.4616425377982, 51.86580113002232, 49.59943771362305, 51.31662246159145, 54.49058737073626, 52.73049749646868, 51.06620243617466, 43.284247807094026, 45.106200967516216, 52.45273630959647, 56.63387039729527, 55.72381271634783, 54.97442517961775, 54.17707075391497, 53.65760605675833, 49.72072546822684, 54.223373549325125, 46.02350214549473, 6.314201525279453, 13.072088088308062, 11.673726643834796, 2.4562635464327673, 0.25755919090339113, 0.2855735405215195, 30.5629369190761, 68.88651834215436, 51.537331989833284, 52.18466785975865, 32.91015304837908, 32.02929169791085, 51.71198885781424, 62.64267948695591, 63.39992891039167, 32.402993610927034, 1.0611501676695687, 0.14186379978699343, 0.19789264830095427, 0.07935451436787844, 0.0913600040865796, 0.14756806726966584, 0.0993674433391009, 0.18998703679868154, 0.1129008446420942, 0.12212202697992325, 0.2789148049695151], [0.07654347270727158, 0.042048811712967496, 0.06263173384858028, 0.12492539440946919, 0.10761587787419558, 0.031043265480548143, 0.07981510393853698, 0.015698111216936792, 0.02462143703762974, 0.13464247728032724, 0.05401369111080255, 25.8180034160614, 53.31595270974295, 45.87116289138794, 37.51291772297451, 21.14876879964556, 28.51046163695199, 65.5847065789359, 40.2514841897147, 42.12748738697597, 57.5362503187997, 14.932271105902535, 0.18127755128911563, 0.2637435761945588, 0.9918427552495683, 4.9893194522176465, 32.019675391060964, 52.80835900987898, 52.711268356868196, 51.30610636302403, 49.871313776288716, 46.82309736524309, 39.347867488861084, 37.035996845790315, 36.38539184842791, 43.20604235785348, 45.72050510134016, 49.21876328332083, 48.694539070129395, 49.21587978090559, 46.010536806924, 40.425321170261924, 37.90688753128052, 36.995016370500835, 36.185030119759695, 38.91316039221627, 42.122995376586914, 41.561799798692974, 41.59487322398594, 42.03438152585711, 41.27048962456839, 41.511824880327495, 39.165147236415315, 36.60670586994716, 37.214617661067415, 44.39646680014474, 45.52775859832764, 48.17841298239571, 46.786525521959575, 47.35241460800171, 46.127138001578196, 38.21011734008789, 34.966958795275005, 35.376471723829, 35.92444487980434, 37.57188013621739, 33.37011684690203, 36.64715828214373, 36.11956071853638, 35.6377135685512, 35.68787956237793, 34.36580760138375, 34.67815344674246, 35.867087500435964, 40.284818172454834, 43.50676734106881, 44.80725472314017, 46.09068080357143, 41.72345658711025, 43.780769552503315, 47.729562827519004, 48.41470732007708, 47.90241316386631, 47.6261180468968, 48.23918192727225, 44.63863583973476, 46.114033699035645, 48.168598651885986, 31.79489074434553, 45.19281721115112, 47.4925354548863, 42.640903677259175, 42.60063191822597, 46.48620006016323, 46.826706954411094, 46.020632539476665, 43.5510447365897, 40.50606618608747, 38.94596283776419, 38.601971421922954, 40.948065417153494, 39.7886403628758, 40.31114142281668, 39.40860169274466, 36.535000460488455, 36.13435343333653, 35.995552744184224, 36.549209526606965, 36.62625115258353, 36.69424622399466, 36.394316809517996, 37.375138419015066, 37.23551089423043, 36.20256389890398, 37.09343065534319, 43.98049899509975, 48.41758734839303, 47.6680816922869, 45.79497241973877, 49.66037688936506, 46.943450587136404, 43.25866106578282, 35.097928864615305, 36.53475727353777, 35.668598311288015, 36.9377111026219, 36.583689962114605, 41.069165570395334, 47.48090417044503, 46.841242585863384, 46.06410394396101, 43.016186305454795, 45.61645930153983, 49.130177225385395, 49.528031076703755, 47.841025829315186, 45.40256248201643, 39.100594997406006, 40.28298384802682, 46.21049901417324, 51.04805721555437, 50.12945672443935, 53.535609585898264, 46.478206157684326, 47.801740714481895, 43.5160744530814, 43.255437101636616, 35.12090655735561, 47.450321674346924, 12.369301251002721, 4.483968717711313, 37.6547269821167, 3.8330810155187334, 0.6872076732771737, 0.08031046842890126, 15.47497752734593, 60.46714987073626, 43.7215187890189, 45.51987934112549, 28.432652235031128, 17.03385625566755, 31.500978469848633, 40.221919604710166, 51.68506806237357, 30.486583164760045, 0.7796554097107479, 0.04996244010648557, 0.03777843800240329, 0.02932650742254087, 0.045259296761027405, 0.07971512858888932, 0.03298500878736377, 0.028083987667092254, 0.01578544206651194, 0.04898350067170603, 0.04416475531512073, 0.02781857530187283, 0.0066983344316083404, 0.04245886399543711, 0.026567192182743123, 0.04258595021175487, 0.0371128935366869, 0.029343480976032357, 0.04644506045484117, 0.04371548370857324, 0.05526642621095691, 0.15062876231968403, 31.827856472560338, 60.08783381325858, 51.69544867106846, 43.08725595474243, 26.695687702723912, 29.14492075783866, 59.39215932573591, 46.46959386553083, 46.853009360177175, 63.00206116267613, 15.945380994251796, 0.2858214500759329, 0.040498474546309025, 0.9922306601490293, 5.12070815052305, 35.22165891102382, 53.53899335861206, 54.60427379608154, 53.75011089869908, 51.09923069817679, 50.260187080928254, 40.56902381352016, 39.860425676618306, 38.99169935498919, 44.30951704297747, 48.51813473020281, 50.76656484603882, 51.905527455466135, 50.74210371289934, 47.83809716360909, 42.68250254222325, 39.327842780521934, 37.199123178209575, 38.12372691290719, 42.280702114105225, 44.51164708818708, 45.16200195040022, 43.3187768799918, 43.78579657418387, 42.95403119495937, 43.63807439804077, 39.97311850956508, 37.92084298815046, 39.58397422518049, 45.60981682368687, 48.60719673974173, 50.68812663214547, 47.44229997907366, 50.57037203652518, 47.73531593595232, 39.833678586142405, 35.39721557072231, 36.93592888968331, 36.532085691179546, 37.79014389855521, 34.77625853674752, 38.06489304133824, 37.7604056085859, 37.84734494345528, 37.28712906156267, 35.930003438677105, 36.170796734946116, 36.61077751432146, 40.389788082667756, 47.096682684762136, 46.1616392816816, 47.42192786080496, 43.870533330099924, 46.944051606314524, 50.16590697424752, 49.63254240580967, 48.43743487766811, 51.20733077185494, 48.479877948760986, 47.17170933314732, 47.823523317064556, 48.496939250401084, 35.07251582826887, 46.342417512621196, 48.87903806141445, 44.562969957079204, 44.57132863998413, 47.940326009477886, 48.68860183443342, 48.381647791181294, 44.92131287711007, 42.93468393598284, 40.31307649612427, 41.25907373428345, 42.631454127175466, 42.4880085672651, 43.18056331362043, 41.22565984725952, 38.30547789164952, 38.07463094166347, 38.34866441999163, 38.6074709211077, 37.989498138427734, 38.53013399669102, 38.41923032488142, 37.79843657357352, 37.55272742680141, 37.35675001144409, 39.52768686839512, 45.64235176358904, 50.44152116775513, 48.87349339893886, 47.046937056950156, 51.052014214651926, 49.704320771353586, 45.83569581168038, 37.52392366954258, 39.93583795002529, 37.81298610142299, 37.73442281995501, 39.94524233681815, 44.01548317500523, 50.19077805110386, 49.797350202287944, 47.69995307922363, 43.81618799482073, 46.862698623112266, 49.93767602103097, 52.94115992954799, 51.59677035467965, 48.59693077632359, 41.22799791608538, 42.445673193250386, 49.388768332345144, 51.71641138621739, 52.78135136195591, 55.51922300883702, 48.49896812438965, 52.20140607016427, 46.73819385256086, 48.04937103816441, 37.77533381325858, 49.648408617292134, 13.396896396364484, 0.7537227241056306, 28.91653173310416, 7.72017993245806, 0.10276362645838942, 0.0806338582187891, 15.9351167678833, 64.46812411717006, 47.8898925100054, 44.624833243233816, 28.46260244505746, 21.967336075646536, 38.104449135916575, 47.83738497325352, 59.455902099609375, 37.29898268835885, 1.0507867123399461, 0.027331702677266936, 0.04425264256341117, 0.05649908345990947, 0.0730656889666404, 0.03565551566758326, 0.009310156938486865, 0.06418287847191095, 0.06017038878053427, 0.05531865644401737, 0.04283859594059842, 0.16528423662696565, 0.2502082682081631, 0.17209503187664918, 0.1768727055085557, 0.25090713213597027, 0.11324682964810304, 0.14229788577982358, 0.1328136082738638, 0.1434627404170377, 0.18624858025993618, 0.3189932900880064, 37.36768300192696, 68.23225511823381, 59.09067004067557, 49.1737493787493, 29.57799850191389, 37.21474272864205, 69.61493968963623, 51.139804703848704, 50.53787531171526, 69.0035468510219, 17.76056660924639, 0.33957257866859436, 0.629071335707392, 3.2277913008417403, 6.833505979606083, 35.87273291179112, 56.48994888578142, 56.587904589516775, 55.78068719591413, 53.725823470524375, 51.32870537894112, 42.42896972383772, 40.990282671792166, 41.321353912353516, 47.01260600771223, 49.0422477722168, 53.992425850459504, 52.691486835479736, 53.63999932152884, 51.36933497020176, 44.23988914489746, 40.462650367191856, 40.87985495158604, 40.735658986227854, 43.70602430616106, 46.60060909816197, 46.836792264665874, 45.85260077885219, 47.85872983932495, 44.6841778073992, 47.23250259671892, 42.34677948270525, 40.175776617867605, 41.25656196049282, 48.27193226133074, 49.78958906446184, 52.01951265335083, 48.8576271874564, 51.45718799318586, 49.18739216668265, 41.85198783874512, 37.65778071539742, 37.96914339065552, 38.47367640904018, 40.90694945199149, 35.25096641268049, 41.06620911189488, 38.916061265128, 38.68605504717146, 39.4058814729963, 36.70630482264927, 37.93793903078352, 38.9872281891959, 42.73305416107178, 49.86532095500401, 47.33696528843471, 52.24409927640642, 45.842911515917095, 49.54481445040022, 51.162306444985525, 50.3512328011649, 49.694989340645925, 51.352753094264436, 53.149202891758506, 48.45801196779524, 48.30852147511074, 51.45660434450422, 36.71862397875105, 49.74537072862898, 52.008378165108816, 47.29617241450718, 46.33448614392962, 50.71671152114868, 48.969802379608154, 49.559381348746165, 49.44834566116333, 45.098783765520366, 42.287886551448274, 42.73614263534546, 45.82776096888951, 44.37704658508301, 45.338065828595845, 44.82851273672921, 41.7394027028765, 40.40587663650513, 39.04478011812483, 40.88277319499424, 39.48590735026768, 40.73256703785488, 39.707513196127756, 42.15837212971279, 39.81752402441842, 38.262840270996094, 41.796280656542095, 47.24752460207258, 51.106491565704346, 50.743555886404856, 47.734822613852366, 54.92994281223842, 51.30641903196062, 47.5149816104344, 37.846302713666645, 41.9835832459586, 39.69355426515852, 40.4151976449149, 41.243377753666465, 44.88390724999564, 51.7330002103533, 51.74523251397269, 49.730713503701345, 46.80079364776611, 47.34739800861904, 52.535055092402864, 53.04642513820103, 53.57393932342529, 49.84203059332711, 42.7910646711077, 44.83375515256609, 50.68087271281651, 55.17156989233834, 54.231871196201865, 56.766216209956575, 53.16375936780657, 55.50195326123919, 54.0707494190761, 51.995249543871196, 42.13563414982387, 52.211984702519004, 14.56026107924325, 8.580789021083287, 50.5420685495649, 10.291211434773036, 1.045158020087651, 0.17074377009911196, 17.866066319601877, 69.5590831211635, 55.37409945896694, 59.275471278599326, 38.884558132716585, 26.884902783802577, 45.562030587877544, 56.67704997743879, 65.6347405569894, 45.60312223434448, 1.6721593354429518, 0.11248207318463496, 0.1615849451294967, 0.1640724137957607, 0.1432569000337805, 0.1641131258968796, 0.07499774957873992, 0.18427504758749688, 0.09190674046320574, 0.17342333202915533, 0.10607285531503813], [0.04493837005325726, 0.04923530501712646, 0.05102702083864382, 0.06429605132767133, 0.027613813789295297, 0.011639055363567812, 0.03860850006874118, 0.05751129146665335, 0.031895156018435955, 0.04438718927225896, 0.15767411355461391, 26.35387281009129, 50.27265909739903, 42.38864585331508, 31.25288609095982, 18.253998143332346, 22.76525330543518, 33.09409965787615, 39.52918420519148, 43.61003146852766, 54.39723832266671, 11.088385207312447, 0.2722917603594916, 0.11293080196316753, 0.487252197095326, 4.366239743573325, 35.338864598955425, 52.2291328566415, 51.635958194732666, 50.97308267865862, 47.05642134802682, 38.424163545881, 36.92746250970023, 39.89515972137451, 43.33265938077654, 47.940204416002544, 47.53763968603951, 51.44717216491699, 48.01916374479021, 47.94889661243984, 44.84472983224051, 42.58413342067173, 37.7618682043893, 35.19287947246006, 37.531007358006065, 39.442699977329795, 43.413605894361226, 42.725970472608296, 43.62222555705479, 43.03299399784633, 44.4875750541687, 45.664068358285085, 43.140923840659006, 40.720362527029856, 37.27656432560512, 37.22155891145979, 42.62260212217058, 49.04057673045567, 47.18059607914516, 47.10429096221924, 46.37457724979946, 38.572827202933176, 34.463294301714214, 36.33280440739223, 35.320257323128835, 35.756218569619314, 34.02108662469046, 36.32982363019671, 37.54096065248762, 36.92796972819737, 36.47582265308925, 35.0920159476144, 34.1693229675293, 36.22226204190935, 36.147593225751606, 41.67343650545393, 43.96828406197684, 48.65994051524571, 44.501659052712576, 44.23468841825213, 43.626741886138916, 42.29287188393729, 44.85892152786255, 46.852811336517334, 50.39481885092599, 51.89287478583199, 45.87767335346767, 46.641124044145855, 32.391615935734336, 45.61013296672276, 45.40339626584734, 40.213428906032014, 39.25249304090227, 40.360015051705496, 43.92727926799229, 43.020594937460764, 39.99703768321446, 39.67215033939907, 38.41626691818237, 38.88619443348476, 41.379149028233115, 42.44118813105992, 42.21028559548514, 40.80943843296596, 35.9042568887983, 36.20699684960501, 37.74985476902553, 36.53252690179007, 38.6249213218689, 36.63181318555559, 37.03492682320731, 37.41545534133911, 36.16836486543928, 35.409395762852256, 37.26022563661848, 40.09732103347778, 45.75622231619698, 48.35703379767281, 47.79617520741054, 48.27715730667114, 48.46336555480957, 46.367781911577495, 38.438167640141074, 35.571955817086355, 35.8869628225054, 34.42847687857491, 36.4290578024728, 38.88020856039864, 46.108169419424875, 50.00747067587716, 42.95997190475464, 44.14511571611677, 51.23763186591012, 48.649323667798726, 48.885364396231516, 47.10361698695591, 41.09257057734898, 37.04634618759155, 44.68172509329659, 49.3324670791626, 52.02253859383719, 51.68912928444998, 44.76530497414725, 42.744939054761616, 46.599869115012034, 47.501404830387656, 42.66142865589687, 34.23451096670968, 39.09279217038836, 24.15933813367571, 0.03973620830635939, 9.077600853783743, 9.418423022542681, 0.22850375143545015, 0.10568632105631487, 7.0280190621103555, 55.574231897081646, 47.267361709049766, 38.59026370729719, 35.170544488089426, 18.7901246207101, 33.20848437717983, 45.720981052943635, 49.519873891557964, 35.09488902773176, 2.8791630480970656, 0.006629151001106948, 0.044800546020269394, 0.02936338580080441, 0.03873940643721393, 0.02934194409421512, 0.03881341764437301, 0.05707856932921069, 0.10085383536560194, 0.07118347353701081, 0.04642950164686356, 0.03818408998527697, 0.010717540347416486, 0.004395633395428636, 0.040591169215206585, 0.026503126602619886, 0.042972518397229056, 0.0304065621457994, 0.034623392658042054, 0.05108798721006938, 0.03416400409436651, 0.4233064598270825, 33.86016634532383, 58.34231431143624, 49.22892502376011, 37.20362908499581, 23.830841200692312, 27.73284704344613, 40.917145933423726, 44.54497759682791, 47.812211649758474, 60.853622572762625, 11.929195404052734, 0.28455511374132975, 0.307047572519098, 1.586055955716542, 6.594614318438938, 37.61485127040318, 54.86434834344046, 53.87782226290022, 52.39098072052002, 48.952970368521555, 41.94711215155465, 38.75769444874355, 41.88012456893921, 44.90856293269566, 50.08444629396711, 49.97588416508266, 52.27559198651995, 48.59988376072475, 49.537643909454346, 46.255078656332834, 45.44519315447126, 39.947667258126394, 38.24988188062395, 40.41878638948713, 41.63834115437099, 44.404116766793386, 44.25429623467581, 44.548965862819124, 44.27131584712437, 46.00885534286499, 46.23370252336775, 45.75577415738787, 42.6899927003043, 38.05724654878889, 38.92424624306815, 43.974516596112935, 50.56656789779663, 48.7909904888698, 49.848836353846956, 47.536562715257915, 41.192193848746165, 36.23935113634382, 36.195157119206016, 35.66019793919155, 37.39565992355347, 35.84834473473685, 37.98997756413051, 38.46663440976824, 38.396235261644634, 38.111102036067415, 35.944848264966694, 35.48794862202236, 37.303912435259136, 39.92546081542969, 43.54853296279907, 46.82312863213675, 49.59958709989275, 46.300502504621235, 45.37177153996059, 45.11171088899885, 44.56329652241298, 46.45128188814436, 49.38571112496512, 52.697118350437705, 52.16679014478411, 47.18576553889683, 47.95036268234253, 35.05664961678641, 48.7198235648019, 48.49283286503383, 42.265714849744526, 40.68953684398106, 43.87212099347796, 44.30593524660383, 46.49849489756993, 41.1893172945295, 42.09315633773804, 41.24541357585362, 40.98866721561977, 43.596385206495015, 44.966639450618196, 44.92086819240025, 42.74089172908238, 36.83409609113421, 37.92338950293404, 39.258068970271516, 37.800646100725444, 39.261543069567, 38.88260916301182, 38.21319539206368, 38.18770592553275, 37.9035975592477, 36.699516432625906, 38.399942125592915, 42.753478390829905, 49.243394647325786, 49.42298126220703, 49.26727907998221, 49.91402782712664, 49.61807625634329, 49.34922613416399, 41.2365893636431, 36.98083162307739, 38.21297652380807, 37.26346002306257, 38.6375983101981, 40.23083414350237, 48.19074256079537, 51.55965307780674, 46.72356789452689, 46.77235467093331, 52.461737700871055, 49.87174456460135, 50.538872378213064, 48.889505522591726, 43.849977084568565, 39.34521327699934, 46.12999023709978, 51.07665947505406, 53.85377107347761, 51.490918023245676, 49.18764577593122, 46.0398199898856, 52.005032607487266, 53.14776808874947, 47.8730639730181, 40.47011620657784, 38.05507871082851, 28.19029038293021, 0.4781129817877497, 6.6667261975152154, 14.966588258743286, 0.8533430099487305, 0.13927902919905527, 7.157583424023219, 60.529808725629536, 52.97015128816877, 41.563557692936485, 38.86843483788626, 24.636741910661968, 39.57558427538191, 51.783603940691265, 56.28185728618077, 41.23672832761492, 3.858593497957502, 0.015830651158466935, 0.08548570929893426, 0.01863202030238296, 0.055492310518664975, 0.010204393998719752, 0.0596014710941485, 0.06192717022661652, 0.048473018421126265, 0.053399698343127966, 0.0644054040312767, 0.08729554539812462, 0.11503166173185621, 0.18576907313295773, 0.1688637395522424, 0.10353842524013349, 0.11148849435682807, 0.14322575527642453, 0.1569561149392809, 0.15149546866970404, 0.06674961359905345, 0.7595126905611583, 42.49824326378958, 63.81387478964669, 56.053386620112825, 44.28382955278669, 26.57258299418858, 30.659099987574987, 43.38939142227173, 50.1885997908456, 54.523469720567974, 65.03351988111223, 14.056274362972804, 0.49423774225371225, 0.5716418687786374, 2.634049709354128, 6.511287612574441, 38.08757890973772, 55.38506024224417, 57.18848255702427, 55.54048102242606, 51.202119622911724, 43.253436020442415, 41.71072748729161, 44.37206472669329, 47.64592041288103, 52.92256307601929, 51.2438748223441, 54.63628762108939, 50.67830535343715, 53.23607621874128, 47.09481014524187, 46.94028568267822, 40.93981095722744, 39.585683482033865, 42.725866249629426, 43.42385796138218, 46.905704498291016, 46.31200177328927, 48.61696243286133, 46.22470808029175, 49.029390130724224, 48.11738000597273, 47.485823495047434, 44.88450132097517, 40.72303410938808, 40.76539727619716, 43.939726965767996, 54.905512945992605, 50.075128759656636, 51.569147791181294, 51.245872429439, 43.70828594480242, 38.50229256493704, 39.45830910546439, 37.49427918025425, 38.87489666257586, 38.145919459206716, 40.655917985098704, 41.043259211948936, 39.97217355455671, 39.467522416796, 37.590949467250276, 37.68834931509835, 40.38135296957833, 41.26804385866438, 45.08006879261562, 48.13989216940743, 51.70616626739502, 47.30555943080357, 48.382943630218506, 47.852420875004356, 45.603466170174734, 49.97326816831316, 52.02917412349156, 54.3048620223999, 54.1116360936846, 48.925229685647146, 48.12382446016584, 37.121706349509104, 50.04147515978132, 49.91287095206124, 45.70949568067278, 44.14015817642212, 44.57240561076573, 47.487581389290945, 48.45294673102242, 43.6531137738909, 44.27685703550066, 42.431780270167756, 43.58774164744786, 44.41166598456246, 46.455096449170796, 47.936108452933176, 45.90618528638567, 39.46200902121407, 40.62040226800101, 42.24140657697405, 39.85160493850708, 42.10136216027396, 39.828568186078755, 41.323375838143484, 40.23354046685355, 40.04883997780936, 37.20421620777675, 41.13811949321202, 44.35270357131958, 50.283470494406565, 52.046568938664024, 52.0618827683585, 51.49314839499337, 52.3264284815107, 51.149949073791504, 42.54194743292672, 40.04093640191214, 39.33881746019636, 38.470917974199565, 40.98870890481131, 41.76539938790457, 50.18546962738037, 53.63464573451451, 47.22491863795689, 47.9340170451573, 54.787087849208284, 52.454202379499165, 53.0715845652989, 50.210451875414165, 46.096023968287874, 41.76478099822998, 48.30838598523821, 54.510987281799316, 55.23778622491019, 54.03818321228027, 53.33566474914551, 50.044257913317, 53.7349534034729, 55.19558981486729, 54.14254168101719, 46.99073307854788, 45.235315867832725, 30.442232813153947, 2.3890256115368436, 13.038878304617745, 17.138348477227346, 0.7069527709058353, 0.1780914765383516, 9.046431234904698, 64.66095747266496, 58.75065994262695, 52.65984126499721, 47.839542388916016, 29.562757628304617, 46.729098660605295, 59.00893838065011, 66.12081568581718, 51.058330127171104, 5.172480046749115, 0.12853727702583584, 0.11486482354147093, 0.08289833992187466, 0.10387321441833462, 0.08515204648886408, 0.17096938299281256, 0.14946402981877327, 0.2017008310982159, 0.21584429645112582, 0.23709405905434064], [0.011100649700633116, 0.08135993140084402, 0.051415943540632725, 0.03118274174630642, 0.08698985858687333, 0.0986810644556369, 0.08346262321408306, 0.0828394770090069, 0.07139856913792235, 0.04805814175467406, 0.2842589739177908, 27.98684365408761, 52.20771156038557, 45.00502129963466, 32.156113692692344, 18.557858501161846, 26.800688879830496, 27.529099805014475, 40.10993201392037, 48.7145915712629, 52.97221142905099, 8.4089982850211, 0.23872254309909685, 0.09435946135116474, 1.136343247124127, 4.870750180312565, 37.64951235907418, 55.77253001076834, 50.18926681791033, 51.95695454733712, 41.667704241616384, 41.866836139133994, 44.331501143319265, 46.789475032261436, 46.57224655151367, 46.479998792920796, 50.16194302695138, 45.422298840114046, 43.73269496645246, 47.39347846167428, 47.426225321633474, 43.01635306222098, 38.09310620171683, 35.6144232068743, 35.65883609226772, 39.3195674760001, 42.34426770891462, 44.4785076550075, 43.73211479187012, 46.09985589981079, 45.19422422136579, 46.54419667380196, 45.760794230869834, 47.35329008102417, 43.25019121170044, 40.032167775290354, 39.99326828547886, 43.94345467431204, 46.52428661073957, 46.12540790012905, 41.58203990118844, 37.69247307096209, 33.47268615450178, 36.11700030735561, 35.168109144483296, 36.24451017379761, 36.131084305899485, 37.04131916591099, 34.54376833779471, 39.82374961035592, 36.307981967926025, 35.376596791403635, 35.49865232195173, 34.568281582423616, 33.62747464861189, 40.12955025264195, 44.195045471191406, 47.23177303586687, 46.333773953574045, 43.49626166479928, 46.16134745734078, 48.377023765019004, 47.22141327176775, 46.50853157043457, 41.08393049240112, 47.316575799669536, 50.48606954302107, 45.31481368201119, 36.51099443435669, 44.631291593824116, 47.69081967217581, 40.82000664302281, 38.43994985307966, 34.17686871119908, 37.624401569366455, 37.333935601370676, 38.611525194985525, 39.063154629298616, 40.29559482846941, 40.94949674606323, 41.68437991823469, 43.87519557135445, 44.51914072036743, 40.218970094408306, 35.67149223600115, 35.62132624217442, 35.56548704419817, 35.725229603903635, 36.938624790736604, 37.71486016682216, 38.71009234019688, 37.46286984852382, 34.645462172372, 36.992049489702495, 35.594732012067524, 35.56474011284964, 42.362725598471506, 47.62094858714512, 46.23048550742013, 47.410602297101704, 47.30594852992466, 47.64004571097237, 42.724803175245015, 36.30796112333025, 34.76233434677124, 36.11467613492693, 38.02843236923218, 36.32927472250802, 42.79147114072527, 48.589218275887625, 48.57209096636091, 51.207601751599995, 48.80847215652466, 49.13034050805228, 45.96159022194998, 40.641305923461914, 34.798506668635774, 40.41200147356306, 49.66093274525234, 53.26554700306484, 49.15328345979963, 41.43280301775251, 43.83630302974156, 48.28669023513794, 51.82904863357544, 53.17755501610892, 50.383705207279746, 42.95148468017578, 27.281089067459106, 29.962772369384766, 0.5208280639989036, 2.098441089902605, 6.069362640380859, 0.6368816537516457, 0.09826240834913083, 3.7606990252222334, 51.031621251787456, 52.517837456294465, 44.57262447902134, 29.42136526107788, 21.28142033304487, 38.92954771859305, 48.169213567461284, 46.509639808109824, 32.64961297171456, 6.45239120721817, 0.019597234670072794, 0.05851230703826461, 0.012619247543625534, 0.044712960720062256, 0.021826527547091246, 0.04392378038859793, 0.013074806625289577, 0.01037926774006337, 0.056808237585106065, 0.01653859218848603, 0.02668959311475711, 0.04953096308080213, 0.04011522439707603, 0.018835187257666672, 0.016640832148758427, 0.07524363709879772, 0.010255468177742191, 0.015170329716056585, 0.022800092984523092, 0.03361158498695918, 0.7046163305640221, 37.85124635696411, 58.53555761064802, 51.65991905757359, 36.56166764668056, 19.300237042563303, 26.528376817703247, 30.714633464813232, 44.9506516456604, 53.17979233605521, 55.676019532339915, 9.30743510382516, 0.33075881589736256, 0.3907520595405783, 4.016176036425999, 6.074872127601078, 40.03334549495152, 56.68002380643572, 54.80867937632969, 53.9496944291251, 44.75739445005144, 42.47594996861049, 45.82990796225411, 48.44848946162632, 49.15789358956473, 49.400990213666645, 51.82056140899658, 47.89211245945522, 45.2619309425354, 49.76289061137608, 48.54922097069876, 45.46865027291434, 40.435406480516704, 37.85168061937605, 38.00501693998064, 40.838054588862825, 43.58554949079241, 46.215845652988975, 46.7928136416844, 48.17237499782017, 48.360080582754954, 48.314469133104595, 47.03485761369978, 48.14425563812256, 46.209331716809956, 41.78638294764927, 41.572065762111116, 46.294558320726665, 48.76103680474417, 47.08250835963658, 43.41657624925886, 40.544475827898296, 36.14769744873047, 37.950643811907085, 36.87832484926496, 37.965978486197336, 36.982429708753315, 39.19310678754534, 36.91967010498047, 39.91411440713065, 37.469946588788716, 37.99885041373116, 37.69545384815761, 36.80682788576399, 34.347797870635986, 42.60555124282837, 45.661038943699424, 48.22801617213658, 47.069258144923616, 45.683585848127095, 46.270239625658306, 48.31656401497977, 48.88066741398403, 46.658379895346506, 44.522573130471365, 50.00853722436087, 50.29971538271223, 45.76372984477452, 39.151014600481304, 46.66240290233067, 50.5583620752607, 44.36308070591518, 38.703126771109446, 36.99910885947091, 39.095474175044465, 38.65288087299892, 40.00638995851789, 41.87273863383702, 42.25900983810425, 43.10311869212559, 43.2721266746521, 45.121559960501536, 45.865732874189106, 42.943278857639854, 36.66738796234131, 37.3794150352478, 38.02578510556902, 37.46815742765154, 38.22239133289882, 39.231572014944895, 39.28840480531965, 40.18165826797485, 35.71233374731881, 38.3860422543117, 37.87948383603777, 38.980026381356375, 43.95065300805228, 50.08375147410801, 47.78919574192592, 49.317681312561035, 50.414419719151084, 49.43475498471941, 44.280737604413716, 37.96268504006522, 36.89403125217983, 38.160545417240684, 38.645018986293245, 38.25700378417969, 44.44698715209961, 50.67435530253819, 51.86278561183384, 52.16918379919869, 50.10586411612374, 52.490242685590474, 47.5165935925075, 42.13601630074637, 37.59435061046055, 43.137456689562114, 52.52240242276873, 54.34884064538138, 50.32777568272182, 47.02563040597098, 48.23148332323347, 50.519587653023855, 51.10670348576137, 54.52263593673706, 54.80333621161324, 48.59260204860142, 29.353231225694927, 33.34878935132708, 0.7853921790208135, 2.4471386075019836, 5.783643160547529, 1.4292211085557938, 0.11640057899057865, 3.8057368142264227, 55.12355089187622, 56.74532992499215, 46.38546160289219, 35.084018571036204, 26.19176959991455, 45.55257061549595, 53.38267626081194, 56.02924510410854, 41.23822219031197, 8.226184231894356, 0.09245304257741996, 0.014661223195227129, 0.05195070716685482, 0.03429538883002741, 0.04122735007799097, 0.03900597570464015, 0.03445715157847319, 0.04070387727447918, 0.021304898662492633, 0.020967719344688312, 0.1614629581038441, 0.22900974856955664, 0.12644582853785583, 0.08311724888959102, 0.19165582582354546, 0.2556031101516315, 0.16583633343023912, 0.20249021159751074, 0.10853780340403318, 0.1502018959394523, 1.417702080948012, 47.02221189226423, 66.58009856087821, 57.85397406986782, 43.520761013031006, 26.598558834620885, 37.01483610698155, 38.01032883780343, 52.016035079956055, 58.14401619774954, 61.977785519191194, 10.356162326676504, 0.3431911516402449, 0.20758858802063124, 3.125028963599886, 8.197753940309797, 38.84189966746739, 60.04075281960623, 55.956445353371755, 56.384638513837544, 45.75173377990723, 45.69413321358817, 49.0088859966823, 51.28823559624808, 52.78079898016793, 51.35068253108433, 54.702014105660574, 49.86977822440011, 47.087351254054475, 50.523833002362935, 52.1990019934518, 47.41937092372349, 42.796345302036826, 40.549620968954905, 38.8405829838344, 43.333041531699045, 46.69595922742571, 48.205014160701204, 49.27125344957624, 49.5097017288208, 49.7508875983102, 50.04461921964373, 48.99331855773926, 51.555435521262034, 47.87595789773123, 44.477295194353374, 44.295770032065256, 48.15573753629412, 51.56770951407296, 49.222814083099365, 44.39913490840367, 42.821866035461426, 37.72272552762713, 38.86751420157296, 39.01220348903111, 38.41782331466675, 39.59876693998064, 40.181686060769216, 38.829712527138845, 43.10950756072998, 38.92490284783499, 39.18097870690482, 40.850300788879395, 37.64723334993635, 36.458827359335764, 44.37345436641148, 47.56453268868582, 50.776980195726665, 50.177611214774, 44.908792223249165, 48.01458488191877, 51.60710232598441, 49.90365416663033, 50.8628043447222, 46.75440052577427, 51.887382234845845, 50.60164587838309, 48.516508851732524, 42.69118084226336, 48.66834088734218, 52.4966767174857, 46.23944868360247, 40.559567315237864, 38.35665832247053, 40.614739486149375, 41.51713330405099, 42.74680812018258, 44.39816563470023, 44.56265728814261, 45.11772802897862, 45.45017501286098, 48.02353763580322, 47.645493098667686, 45.227540833609446, 38.873531341552734, 39.611777441842214, 37.54007823126656, 38.98233665738787, 39.732971395765034, 42.067378520965576, 41.730550697871614, 41.24758488791329, 37.70598384312221, 41.391770430973594, 38.534879616328645, 39.871803351810996, 46.203078338078086, 51.64935084751674, 49.75921154022217, 52.226864269801546, 52.10964468547276, 51.55368110111782, 47.608740602220806, 41.003463404519216, 38.245775495256694, 39.963043621608186, 42.5629483631679, 40.41825137819563, 46.18136869158064, 52.602938992636545, 53.31741183144705, 54.0027300289699, 54.37885686329433, 56.004971572331016, 50.32752207347325, 44.17777919769287, 38.573296206338064, 44.46391643796648, 54.70305980954851, 57.01759508677891, 54.38798679624285, 51.32392849240984, 50.80048247746059, 52.407732827322825, 53.0974839755467, 58.436920983450754, 55.0991210256304, 54.6115277154105, 34.411835942949565, 36.391579219273154, 1.091954571860177, 6.303359295640673, 12.490012305123464, 1.7775032541581561, 0.20269185863435268, 4.945298705782209, 60.87025656018938, 62.06600679670061, 56.90008020401001, 38.71690852301461, 30.92541401726859, 52.8167211668832, 60.36474731990269, 62.9708776473999, 49.935282366616384, 10.099282213619777, 0.14231065580887453, 0.12650491536727973, 0.13334078927125248, 0.1740637876625572, 0.09990220357264791, 0.17200302252812044, 0.0894885773637465, 0.17502101058406488, 0.1268668866583279, 0.09660129355532782], [0.0647284070562039, 0.014928986684286168, 0.08960270695388317, 0.004364217648149601, 0.01886205724440515, 0.02153578886230077, 0.021168667490461042, 0.014432489040440746, 0.047845373528876474, 0.1770657758627619, 0.2876909226179123, 26.71830061503819, 49.46472256524222, 45.50231082098824, 35.26441812515259, 21.515336649758474, 28.041096925735474, 32.16634144101824, 37.56477560315813, 48.59291819163731, 46.79078476769583, 5.928429288523538, 0.16805223881133965, 14.58779157911028, 2.687795979636056, 12.32570651599339, 40.71688495363508, 53.77220964431763, 49.90381050109863, 49.43764543533325, 44.59959043775286, 48.21304975237165, 48.84213270459856, 48.85119315556118, 48.850463594709126, 49.48446239743914, 43.336675439562114, 40.51913922173636, 45.826086453029085, 48.25237308229719, 48.27909585407802, 43.96207584653582, 38.663456031254356, 34.459458896092, 35.83611937931606, 41.100060735430034, 44.10397890635899, 43.636782033102854, 44.60664633342198, 45.94146129063198, 48.14701059886387, 47.80042403084891, 46.53138419560024, 49.026193959372385, 47.687547070639475, 45.46193831307547, 43.13993372235979, 42.86487191064017, 42.40768044335501, 44.86834328515189, 41.803604057856965, 37.042444774082725, 34.34646034240723, 35.52569123676845, 33.95286226272583, 35.16609069279262, 35.072373390197754, 35.719448702675955, 35.01291070665632, 36.81071192877633, 36.29509653363909, 35.360893862588064, 36.37398638044085, 34.423651354653494, 36.02539873123169, 35.774808474949424, 42.39792169843401, 48.054127080099924, 45.42343487058367, 44.52038097381592, 47.94143077305385, 49.79521710532052, 49.178943157196045, 48.33948264803205, 49.16610288619995, 40.03086151395525, 48.2529741014753, 50.11666856493269, 35.26372677939278, 46.82787772587368, 46.060841764722554, 45.368505886622835, 43.98302813938686, 37.2112512588501, 35.13982302801949, 35.52131387165615, 36.84316349029541, 38.779306820460725, 40.081225531441824, 42.20394536427089, 43.00947087151663, 44.02721520832607, 43.06457008634295, 37.25098105839321, 34.02122558866228, 34.96736873899187, 35.43005623136248, 37.100208623068674, 37.10168858936855, 36.439163957323345, 36.30899640492031, 35.86039291109358, 36.10088743482317, 35.33103397914341, 35.66595799582345, 34.4722192628043, 37.350784982953755, 45.447767462049214, 47.181037289755686, 46.93294838496617, 47.190757819584434, 47.82291187558855, 45.16291216441563, 40.97426012584141, 35.16233171735491, 37.58403253555298, 36.63204595020839, 35.60425451823643, 38.335292611803325, 48.01544298444475, 49.319258553641184, 48.0144806589399, 45.749388762882774, 43.40596982410976, 37.72784982408796, 36.39541809899466, 37.74954904828753, 44.822002274649485, 48.778806822640554, 51.02352312632969, 41.6503198487418, 48.24178402764456, 49.568556444985525, 49.288193157741, 52.131851128169465, 56.87505279268537, 50.37566614151001, 50.968034812382285, 32.710458346775596, 32.79034873417446, 4.166007425103869, 3.7589888998440335, 13.812662703650338, 2.3042695309434618, 0.062276011865053854, 1.3538655063935687, 43.98311151776995, 51.960348742348806, 41.53926331656319, 33.10867697851998, 22.05037920815604, 29.133560453142437, 40.24824980327061, 47.774548939296174, 42.588594164167134, 11.291806748935155, 0.011941267227354859, 0.016952822550332973, 0.03827882704458066, 0.06133955890046699, 0.02848859131336212, 0.06027859475995813, 0.02557095349766314, 0.03643040944422994, 0.023009329435548613, 0.05702309909143618, 0.06450065677719456, 0.030353063052254062, 0.05810975256775107, 0.03512321173080376, 0.008459812612272799, 0.021016070053779652, 0.007267290709673294, 0.015162996448842543, 0.04968232049473694, 0.07521762885153294, 0.5818782480699676, 36.73909337180001, 58.30379349844796, 51.97737530299595, 42.63668959481375, 24.136000871658325, 31.083867686135427, 41.0920216696603, 42.625843456813264, 53.40739795139858, 51.75996616908482, 6.320889600685664, 0.1567892360367945, 14.042838283947535, 3.321236103773117, 13.924202135631017, 45.04086358206612, 54.58948802947998, 54.124441623687744, 51.80533790588379, 46.925621509552, 48.61783790588379, 48.97062921524048, 50.138541494097026, 50.12386342457363, 51.332533836364746, 47.40831286566598, 42.311819621494834, 47.14929444449288, 50.20813812528338, 49.37567097800118, 44.634626729147776, 39.77881213596889, 36.703515120915, 37.2429906300136, 42.11476523535592, 45.16930798121861, 45.848417963300435, 46.758638926914756, 46.00221981321062, 48.495150089263916, 50.56912136077881, 49.30639048985073, 50.05812999180385, 48.48353270121983, 45.729958125523154, 45.55351904460362, 44.769459996904644, 45.369683606284006, 45.74592855998448, 44.54290703364781, 40.39147996902466, 36.51737982886178, 36.832192284720286, 34.581847940172466, 36.73402118682861, 35.58086688177926, 36.625424316951204, 36.57220458984375, 38.207445757729666, 37.892212935856406, 38.259758744921, 37.31776714324951, 36.033910274505615, 36.538182735443115, 36.89724826812744, 44.7665730203901, 49.39836032049996, 47.30112648010254, 46.237652574266704, 49.94191442217146, 51.047741072518484, 48.24729742322649, 49.78945010049002, 49.81625277655465, 41.98782164709908, 51.70731272016253, 49.587087290627615, 37.77006360462734, 48.726625851222444, 48.938003948756624, 47.663287435259136, 44.77866983413696, 37.64775446483067, 36.13171311787197, 38.36368989944458, 39.33183799471174, 40.4605450630188, 42.810915674482075, 44.9405072757176, 44.58489152363369, 48.063225746154785, 43.21141331536429, 39.07333026613508, 36.65183441979544, 35.9665162222726, 36.8875207901001, 37.16372210638863, 37.41187007086617, 38.13147415433611, 36.91969442367554, 36.582362856183735, 38.00665324074881, 37.019276005881174, 37.65002652576992, 36.97561700003487, 38.80221503121512, 47.58940723964146, 49.681593213762554, 48.84489113943917, 50.092113631112234, 50.13297946112496, 47.98670176097325, 42.69381420952933, 36.910463741847444, 39.19226605551583, 38.496497767312185, 37.067896025521414, 40.89650978360857, 49.676020758492605, 50.8005484853472, 51.5624532018389, 47.790595803942, 44.917255129132954, 39.824392318725586, 38.27367946079799, 39.77390670776367, 47.321519442967, 52.16060972213745, 51.82415015356881, 46.056964669908794, 50.84248086384365, 50.16527121407645, 52.782212938581196, 52.72247927529471, 59.33265495300293, 51.59176765169416, 54.24051128114973, 34.83133690697806, 34.68484108788626, 4.556913946356092, 1.8762075177260806, 15.72196340560913, 4.638699020658221, 0.03976225048037512, 1.1910725789410728, 48.18015350614275, 55.33867406845093, 46.92652130126953, 29.755875859941753, 25.574182442256383, 33.9661819594247, 46.74801860536848, 54.64346858433315, 51.75588410241263, 14.307082618985858, 0.1110650681491409, 0.027190660691953132, 0.018275136327637092, 0.022966193268075585, 0.0463560875505209, 0.0418846978406821, 0.04309729759448341, 0.02070648336250867, 0.06350294567112412, 0.012210036644579043, 0.16130358379866394, 0.09548517808850322, 0.17124790804726736, 0.07280477189591952, 0.09150202146598271, 0.14686102020953382, 0.12289494621966567, 0.09625888442886726, 0.14046604478997843, 0.3017859405704907, 1.12196774993624, 46.71977765219552, 64.51196725027901, 58.93975516727993, 47.78562436785017, 31.285931723458425, 36.55598054613386, 44.791972160339355, 47.85374450683594, 57.610787119184224, 57.00452899932861, 7.65072226524353, 0.28849599084683825, 19.417215176991053, 7.321779779025486, 16.39906014714922, 47.7411003112793, 54.161871569497244, 56.39600229263306, 54.35765790939331, 49.28475379943848, 52.631888662065776, 52.56786796024868, 52.31953934260777, 52.608330794743125, 54.074046339307515, 49.404408727373394, 42.08462742396763, 47.3604154586792, 51.85315193448748, 51.93143033981323, 48.07319641113281, 41.71210323061262, 37.679615429469514, 40.17290701184954, 45.81582396371024, 48.36367974962507, 48.06562982286726, 48.7810823576791, 48.382985319410054, 51.468183517456055, 51.225152901240754, 49.86677312850952, 53.93273735046387, 50.37096568516323, 48.40312467302595, 46.68276112420218, 47.44954695020403, 46.228296824863975, 48.260763032095774, 45.18989201954433, 40.36319037846157, 38.215960775102886, 38.85954114368984, 36.51702894483294, 39.17932503564017, 37.09545258113316, 37.7342734336853, 37.24684688023159, 40.07220329557146, 38.83521202632359, 39.43750619888306, 41.01221118654524, 38.54087591171265, 38.218628883361816, 37.50649411337716, 46.153037411826, 52.09194762366158, 49.18733658109392, 47.54316350391933, 53.13490349905831, 53.778966767447336, 52.24187237875802, 52.50439616612026, 52.267803055899485, 45.53373752321516, 51.781588963099885, 49.82627902712141, 40.1485709462847, 50.44115291322981, 51.649163246154785, 50.2124981198992, 47.32709189823696, 40.67025906699044, 38.01754454204014, 40.73478351320539, 42.02281972340175, 43.174931798662456, 44.03055381774902, 47.17712892804827, 46.068456990378245, 48.3718021937779, 46.22078929628645, 41.10823876517159, 39.16599491664341, 37.33343880517142, 38.87271492821829, 40.17047166824341, 40.264657974243164, 39.25192328861782, 39.398099490574424, 39.282422406332834, 40.37342160088675, 38.221654823848176, 39.74825743266514, 38.69169698442732, 41.770343031202046, 49.7807092666626, 52.12638636997768, 49.339067867824006, 52.27649872643607, 53.004638671875, 50.20703683580671, 46.74993283408028, 38.79278285162789, 42.15553379058838, 40.38050528935024, 39.84377431869507, 43.08688422611782, 52.29735721860613, 53.31426082338606, 53.72184910093035, 50.293451581682476, 46.2617141859872, 41.81788260596139, 40.45541034426008, 42.49512004852295, 50.140796184539795, 54.07879195894514, 56.15542786461966, 49.384241580963135, 53.958872999463765, 52.20287561416626, 56.8467458316258, 56.53005041394915, 61.57156603676932, 55.179806981767925, 57.80906438827515, 39.939794949122835, 39.772367681775776, 5.924969954150064, 6.40397355386189, 26.05061173439026, 4.658923055444445, 0.11774269411606447, 1.9692866717066084, 52.42693417412894, 61.862535749162944, 53.85356610161917, 42.008190291268484, 32.65412930079869, 39.48088032858712, 56.132689884730745, 61.80326066698347, 59.97222968510219, 18.27626711981637, 0.20017293308462414, 0.09799018688499928, 0.11966615090412752, 0.15503955206700734, 0.19898810237646103, 0.1270799059420824, 0.087742666048663, 0.06431522672729832, 0.08801354401345764, 0.1873767397233418], [0.057245991059712, 0.030946676020643542, 0.025268572848290205, 0.08990283656333174, 0.03307715384289622, 0.040531308855861425, 0.0775724235656006, 0.06382488339607205, 0.019971295758815746, 0.11275388074240514, 0.7134927628295762, 35.69529676437378, 49.78244979040963, 47.14410761424473, 33.83202614103045, 17.45207875115531, 22.891826902117046, 22.219979524612427, 37.34715107509068, 49.13533626283918, 44.01652887889317, 3.562150776386261, 0.20499629926468643, 36.09657607759748, 29.637388229370117, 0.057609916531613896, 20.651642560958862, 53.866972650800435, 51.29018804005214, 50.54181841441563, 51.15038333620344, 50.003378186907085, 53.99377727508545, 50.24589811052595, 49.52394206183297, 47.13334485462734, 44.005043506622314, 45.267492975507466, 48.667705127171104, 48.44401829583304, 46.38738625390189, 40.43407242638724, 37.83676283700125, 35.233269350869314, 37.15760074343, 38.693642480032786, 42.810168743133545, 44.554722445351736, 47.42209809167044, 45.49115201405117, 46.62382302965437, 45.15934426443917, 45.41544096810477, 47.8955066544669, 45.8932512147086, 45.583205223083496, 45.155807631356375, 44.822568552834646, 44.58209834780012, 40.614902768816265, 38.3027229309082, 35.52523960386004, 33.75976834978376, 35.92191573551723, 34.90743705204555, 35.63747385569981, 36.55154412133353, 34.91126898356846, 34.72457783562796, 35.20190518242972, 36.46964223044259, 36.81601687840053, 35.48113938740322, 34.459292139325825, 34.21238442829677, 35.08230931418282, 37.91565268380301, 46.41303205490112, 46.6718350819179, 47.871431146349224, 47.69268526349749, 45.86106021063668, 44.649012974330354, 45.477068015507285, 46.66788155691964, 47.164521421704976, 39.19134194510323, 50.93008375167847, 37.32181794302804, 42.41977725710188, 49.52820825576782, 45.10477311270577, 45.493979930877686, 45.82124703271048, 38.37867716380528, 36.2401328086853, 41.236304487500874, 39.66701214654105, 42.30813012804304, 41.22442306791033, 44.42389133998326, 43.46361902781895, 40.514247689928325, 35.238946029118125, 35.559219769069124, 35.34999213899885, 36.58514560971941, 36.739510263715474, 36.25634643009731, 35.948888642447336, 36.95248992102486, 35.182349477495464, 36.69946779523577, 35.79301275525774, 35.98976142065865, 36.17804023197719, 35.212449073791504, 39.27836465835571, 47.08997767312186, 48.00397150857108, 47.226346492767334, 47.87977940695626, 46.406403473445344, 43.155285767146516, 37.930716378348215, 35.65591784885952, 35.88739708491734, 35.81062643868582, 35.89555079596383, 37.721645082746235, 40.797734192439485, 40.73242112568447, 38.814218044281006, 36.877793312072754, 37.54134975160871, 36.64931222370693, 42.6492588860648, 48.25567347662789, 50.168939862932476, 43.452811104910715, 43.46572780609131, 51.08599437986101, 48.25269617353167, 50.73787225995745, 52.25310066768101, 55.2490805217198, 53.972043309892925, 53.41953298023769, 45.22262498310634, 46.749095576150076, 11.232510822159902, 3.2725057814802443, 20.431980473654612, 7.282763906887599, 0.42554749814527376, 0.9637200300182615, 33.202349117824006, 55.91913005283901, 42.08128534044538, 52.06237609045846, 18.694555623190745, 27.868574891771587, 47.774635791778564, 48.03968872342791, 47.75050469807216, 17.634540183203562, 0.21873526275157928, 0.07344710707132306, 0.024560253534998213, 0.04306099257831063, 0.04771610921514886, 0.048921024559863975, 0.030857469021741833, 0.021434719374935542, 0.03097763078819428, 0.04316330208842244, 0.04292074278263109, 0.04634266273517694, 0.032187587648097954, 0.030921478622726033, 0.06614977507186787, 0.020651784958317876, 0.026624779449775815, 0.05929264945111104, 0.034470237126307826, 0.10755447045500789, 0.8960645518132618, 45.02610213415963, 55.29611982618059, 54.49602781023298, 39.446729932512554, 21.667870453425817, 22.692995514188492, 27.574669565473283, 43.69174575805664, 52.507408210209434, 49.24552427019392, 3.4153957026345387, 0.21804369986057281, 33.54060132162911, 22.87234241621835, 0.4714412997875895, 22.50416258403233, 56.631768567221506, 53.35809006009783, 54.40992225919451, 52.069473675319124, 53.600797585078645, 55.89729881286621, 52.02070426940918, 50.904219082423616, 50.022937365940635, 45.70912742614746, 45.061979157584055, 48.618949617658345, 49.84918028967721, 48.85217979976109, 42.81376096180507, 38.98166615622384, 36.9645276750837, 40.27113716942923, 40.93520082746233, 44.18925762176514, 46.23582867213658, 49.216140338352744, 46.97581877027239, 47.861109597342356, 47.213947432381765, 47.27399376460484, 48.62503276552473, 47.772679873875205, 47.14030000141689, 46.906475748334614, 46.97133718218122, 45.74630028860909, 42.21712262289864, 39.29861865724836, 37.12480524608067, 36.02744150161743, 36.221261501312256, 36.88032940455845, 37.22673879350935, 38.36481203351702, 36.00209099905831, 37.649894509996685, 36.1532038961138, 37.73747655323574, 37.17447444370815, 36.26387480327061, 36.5188250541687, 36.919708320072715, 36.702834197453086, 41.05800328935896, 48.32597882407052, 49.14890956878662, 49.77499784742083, 49.13215051378523, 45.764278752463206, 47.59018891198294, 47.78674302782331, 48.81190456662859, 48.60337175641741, 42.12849834987095, 50.56407002040318, 39.442144121442524, 45.08660009929112, 51.224322591509136, 47.27523054395403, 48.0790467943464, 46.64819383621216, 40.435750416346956, 37.97931555339268, 41.93174621037075, 42.560415744781494, 44.00484200886318, 45.26336921964373, 45.7665890284947, 46.39301776885986, 43.804924964904785, 37.01878963197981, 37.200967924935476, 35.898413453783306, 37.80577039718628, 37.99998297010149, 39.0849997656686, 38.64543240410941, 39.05588681357247, 37.43592473438808, 38.652745383126394, 37.73486055646624, 37.46115364347185, 37.61048085348946, 36.02044119153704, 40.72786658150809, 48.63782092503139, 48.207220213753835, 49.15051807676043, 49.680815015520366, 47.56353562218802, 47.193366868155344, 40.1762421471732, 38.496445655822754, 37.939460686274934, 38.7521949495588, 37.846063000815256, 39.029351643153596, 42.91023669924055, 43.41819517953055, 40.65468120574951, 38.676438740321565, 38.050114222935264, 38.49511507579258, 43.54949876240322, 51.25761488505772, 52.656797954014365, 47.692786012377056, 45.73757335117885, 50.868606090545654, 49.33967236110142, 53.758368832724436, 52.831972462790354, 57.496833188193186, 55.32784877504621, 55.70562580653599, 48.24957990646362, 49.391728264944895, 12.25455435684749, 0.9849619758980614, 27.064795119421824, 12.644922392708914, 0.14339557902089187, 0.8954969165580613, 37.77864462988717, 59.13242871420724, 47.181634834834504, 52.084662437438965, 28.026285103389196, 35.96729442051479, 53.00674397604806, 54.289266790662495, 55.41262027195522, 22.068859679358347, 0.19379801516022, 0.01934500115125307, 0.011492420553362795, 0.006613667680150164, 0.05868905862527234, 0.079365778049188, 0.030911100429615805, 0.05961377971938678, 0.035799259918608835, 0.08872330521366426, 0.09811129860047783, 0.10851150338671037, 0.19091437703796796, 0.24119173203195843, 0.18881170558077948, 0.07537766133568116, 0.14009905233979225, 0.15045215322503022, 0.2167562475161893, 0.2571152661527906, 1.4680102957146508, 56.05135427202497, 60.374759674072266, 63.44539097377232, 44.85123682022095, 26.141945804868424, 31.536997931344168, 32.873918192727224, 48.035596234457834, 59.14816638401577, 51.840304715292795, 4.353286564350128, 0.17119610868394375, 46.400170939309255, 37.61095680509295, 0.2540855530117239, 26.91779555593218, 57.373725005558555, 56.02159513745989, 56.53320142201015, 55.53332437787737, 55.22337566103254, 58.99383299691336, 55.48682355880737, 54.438851084027974, 51.47930758340018, 46.503706046513145, 45.86367620740618, 51.65495456968035, 52.28932857513428, 50.46823699133736, 44.809165477752686, 41.336778913225444, 38.71836069652012, 41.82354538781302, 43.0090331350054, 46.253199168613975, 48.24549783979143, 50.288323811122346, 48.00155006136213, 48.00683069229126, 47.07643910816738, 47.68248183386666, 51.61606550216675, 48.82120125634329, 49.08546209335327, 48.445359298161094, 50.07967288153512, 48.68581908089774, 43.27032361711775, 43.11188037054879, 39.48796401705061, 36.329538754054475, 38.02947807312012, 37.46635089601789, 39.31172643389021, 40.50414848327637, 36.581212929316926, 38.52550649642944, 38.09449584143502, 38.603295053754536, 39.41754402433123, 38.573942388807026, 38.066407748631065, 38.3754358291626, 37.98165709631783, 43.1881959097726, 51.1052235194615, 50.93267542975289, 52.289592606680735, 50.95307534081595, 48.68598236356463, 49.768136501312256, 49.46197802679879, 50.49534886223929, 50.71284484863281, 44.60203620365688, 52.02925750187465, 40.61623682294573, 47.35128205163138, 52.25058889389038, 48.91532850265503, 50.458582469395225, 51.3477121761867, 42.528224740709575, 40.48495061056954, 45.89534957068307, 43.905878816332134, 46.70500578199114, 45.75346735545567, 46.75174631391253, 48.35268769945417, 45.5317051751273, 38.31435074125017, 39.2232654435294, 37.74786063602993, 39.36217730385916, 39.6545227595738, 40.223444734300884, 40.11008487428938, 41.71448993682861, 39.20470333099365, 40.961228779384065, 40.79092148372105, 38.46283027103969, 39.73831456048148, 38.26359762464251, 42.96637119565691, 52.0122309412275, 51.314663069588796, 51.51377064841134, 51.84738492965698, 50.20338903154646, 48.953467164720806, 40.83459786006382, 40.9842585836138, 40.13383034297398, 41.09914009911673, 39.39348241261074, 41.54435634613037, 45.54593161174229, 45.46800409044538, 42.98719842093331, 40.57590600422451, 40.16567046301705, 41.56232786178589, 45.29318046569824, 52.914579595838276, 54.61320570537022, 50.34117528370449, 48.68374156951904, 53.240630762917654, 51.59332752227783, 56.27571160452706, 57.20073570523943, 59.5029969896589, 58.1440544128418, 59.71467385973249, 50.08872291019985, 51.72524949482509, 14.159007821764265, 4.497193310941968, 29.91703932625907, 10.99414244719914, 0.37553927728107994, 1.6222175295863832, 43.15771068845476, 65.61125564575195, 55.195148604256765, 64.76347814287458, 29.450801304408483, 41.11960254396711, 60.72899273463658, 62.45855222429548, 64.19288512638637, 27.45842272894723, 0.374735810394798, 0.18003804422914982, 0.1561276643936123, 0.0825222008196371, 0.17248153899397167, 0.17806026392749377, 0.14494152606597968, 0.13628462702035904, 0.07561636995524168, 0.1796248706855944], [0.006890523114374706, 0.04066946537100843, 0.06362703615533453, 0.01796714758633503, 0.011775097393962954, 0.05788026523909398, 0.01657447312027216, 0.05659735907933541, 0.10284887081278221, 0.18446791438119753, 1.7354202951703752, 35.779526301792686, 53.402746132441926, 45.45404168537685, 34.87163993290493, 24.982487746647426, 35.71114560535976, 26.688444205692836, 40.12454407555716, 48.79781709398542, 43.22642489842006, 1.2289706596306391, 0.08625865568007741, 2.556857394320624, 20.304385491779872, 5.981104016304016, 5.34596049785614, 53.71967431477138, 49.72128479821341, 57.101890632084434, 50.92417083467756, 49.47379343850272, 46.01213836669922, 47.137232371738975, 44.66520227704729, 49.22315801892962, 46.899187088012695, 45.4667603628976, 47.822939668382915, 49.68139866420201, 44.12165512357439, 42.07091167994908, 37.51666975021362, 37.2791872705732, 34.55309976850237, 39.05550118855068, 41.81297370365688, 45.469136646815706, 44.61345556804112, 47.456300599234446, 45.51617247717721, 46.21233681270054, 42.505757740565706, 46.74142476490566, 46.597270488739014, 48.57677405221121, 44.50021382740566, 44.83478001185826, 41.4986788885934, 41.6380250113351, 33.9285956791469, 34.87993608202253, 34.92349433898926, 36.62172440120152, 35.162567956107004, 36.711880752018516, 35.71584258760725, 35.899639810834614, 33.86595072065081, 36.107519490378245, 33.78357287815639, 37.32880088261196, 35.97331850869315, 35.60566847664969, 33.857428755079, 36.407077176230295, 33.7183119228908, 40.13837793895176, 41.27146932056972, 42.635011604854036, 38.937552043369834, 39.992497035435264, 40.720814159938264, 46.69190842764718, 45.4045844078064, 48.31129033224923, 43.55467169625418, 43.65124470846993, 43.32839666094099, 36.37732151576451, 46.23018673488072, 45.309706756046836, 48.99161277498518, 47.3087660244533, 45.43996116093227, 37.14146702630179, 38.7694160597665, 39.74139608655657, 41.54590579441616, 40.95817852020264, 41.23794773646763, 44.35180377960205, 39.36301456178938, 37.12163686752319, 35.54705694743565, 35.0479747908456, 35.71720096043178, 35.8184883253915, 36.00481121880667, 35.000761781420024, 35.5666196005685, 37.469078063964844, 35.739223275865825, 34.152153968811035, 36.36166722433907, 36.11378329140799, 35.93932792118618, 35.8400833266122, 40.32014628819057, 44.84812750135149, 46.3979093006679, 47.838142326899934, 47.81336505072457, 44.42786223547799, 41.751457827431814, 40.828278473445344, 35.76632125037057, 36.79534946169172, 36.09638500213623, 37.21780341012137, 35.04432003838675, 34.71197727748326, 36.12875665937151, 37.91976949146816, 34.937022481645855, 39.23378154209682, 42.34137725830078, 49.12692199434553, 47.03583383560181, 42.64189032145909, 48.29784556797573, 49.910751751491, 52.14665079116821, 51.78443772452218, 51.50518267495291, 54.569706508091514, 51.98641490936279, 56.21729115077427, 54.21888501303536, 48.37902137211391, 23.663554634366715, 0.305810386048896, 10.481396658079964, 37.755514076777864, 0.18378886367593492, 0.1723969799599477, 31.543042864118302, 55.12012542997088, 43.03292798995972, 39.69812617983137, 10.114593437739781, 19.266095331736974, 51.7274694442749, 48.50567661012922, 50.85662739617484, 25.504945380347117, 0.3720479703375271, 0.025143873378900543, 0.013161690489921187, 0.09444193728268147, 0.07056124335420982, 0.057183715115700445, 0.05156521445938519, 0.035773685933755975, 0.06629900527851922, 0.04277425725013018, 0.030513614615691558, 0.05617017039496984, 0.020791223904650127, 0.003319595387438312, 0.020053844632846967, 0.043329139439655204, 0.02323834178969264, 0.01897173734115703, 0.05703772830643824, 0.07817480659910611, 2.7336308572973524, 46.38708053316389, 58.057941913604736, 50.74071059908186, 36.992556708199636, 26.21438251222883, 31.877748012542725, 27.703567334583827, 45.16942957469395, 52.58309146336147, 46.737766538347515, 1.6099508106708527, 0.11265778661306415, 3.3752600848674774, 29.943897587912424, 4.800641988004957, 6.6146672538348605, 55.62218141555786, 52.6689190864563, 57.05108887808663, 53.00972127914429, 52.38978910446167, 48.835851533072336, 49.50213166645595, 45.500580719539094, 48.59140001024519, 46.97791365214756, 48.31345469611031, 48.43846321105957, 49.35765429905483, 45.8665840285165, 43.75802115031651, 38.869320733206614, 37.91868209838867, 35.80798612322126, 39.97987910679409, 43.727525506700786, 48.242138385772705, 46.65977300916399, 47.819149426051546, 46.15747731072562, 47.16077634266445, 44.370928696223665, 47.76878888266427, 46.9996371950422, 49.94059773853847, 46.33787339074271, 47.407023974827354, 43.58965240206037, 43.12198999949864, 35.63636909212385, 36.94927985327584, 35.62932014465332, 36.858182021549766, 36.45893505641392, 37.314751625061035, 37.3957884652274, 38.23559291022164, 35.868383339473176, 36.73132528577532, 35.32281078611101, 40.128056389944895, 37.388051646096365, 37.393898555210654, 35.53323698043823, 36.38321706226894, 35.61301967075893, 41.651994364602224, 44.69241142272949, 43.82463353020804, 42.166855880192344, 40.40186752591814, 42.252249240875244, 48.58560521262032, 47.27176339285714, 50.85046434402466, 46.33665745598929, 45.35901117324829, 41.54144157682146, 36.927229745047434, 47.97329521179199, 45.79189436776297, 49.41302796772548, 47.34361818858555, 46.473470960344585, 37.65417807442801, 40.50561455317906, 41.388643741607666, 43.45125470842634, 42.76151398250035, 43.411948748997276, 45.953335762023926, 41.71731785365513, 39.316791670663015, 38.54070220674787, 37.1231689453125, 37.2561366217477, 36.41645377022879, 37.69918850490025, 36.73266976220267, 36.884592124394004, 37.73219244820731, 37.803734574999126, 36.50808661324637, 37.949393136160715, 37.353442668914795, 37.62279306139265, 38.25802516937256, 43.23768098013741, 47.73978015354702, 46.51753990990775, 50.0679269518171, 48.83075850350516, 46.52024275915963, 44.96546867915562, 42.171024799346924, 38.08829110009329, 39.403366225106375, 37.62459264482771, 36.62999275752476, 35.54419428961617, 37.264193058013916, 37.646038259778706, 39.03214829308646, 38.19632863998413, 40.96454654421125, 45.54272154399327, 51.01870107650757, 49.61849662235805, 46.24412829535348, 49.122228486197336, 52.21966246196202, 52.69463784354073, 52.62676089150565, 53.196728570120676, 56.03145810535976, 53.95532941818237, 58.799901826041086, 56.10843024935041, 49.489124638693674, 25.87021565437317, 0.32888006099632805, 10.775174311229161, 35.37741667883736, 0.33312880301049774, 0.2763201141996043, 33.35816247122628, 59.669809341430664, 47.85078110013689, 44.20313664845058, 13.746739932468959, 23.46066723551069, 55.03745576313564, 55.85497733524868, 58.63702910287039, 32.82988051005772, 0.482222244143486, 0.09050000844789402, 0.01165508575338338, 0.03562895441427827, 0.06950581605945315, 0.04921527127070086, 0.03369194049654262, 0.05389579565131238, 0.0952890950388142, 0.07752896339765616, 0.16255865645195755, 0.08519115724733897, 0.23372697830200195, 0.1502371933311224, 0.1298073995858431, 0.1337216374065195, 0.21160263834255083, 0.1554756329527923, 0.27815791272691315, 0.30923234671354294, 4.388272047042847, 59.18442208426339, 65.35436684744698, 58.33387919834682, 45.96607181004116, 34.05169343948364, 46.74262680326189, 36.085788999285015, 50.776167256491526, 55.7807115146092, 53.27549682344709, 1.6046420612505503, 0.17142808623611927, 3.45598794732775, 29.05147269793919, 7.426787904330662, 7.58534666470119, 61.7533517565046, 53.0470643724714, 62.2955196925572, 54.070846693856375, 53.346243381500244, 51.01897553035191, 49.68370546613421, 46.31869288853237, 50.353709833962576, 48.04952389853341, 50.110561098371235, 49.27649239131382, 52.03436095373971, 47.10487808500017, 45.89405025754656, 41.12237140110561, 41.21367073059082, 37.13198273522513, 40.94756514685494, 45.63965933663504, 50.75160190037319, 47.96817438943045, 50.089789458683555, 46.838286127362935, 48.583506856645855, 45.07660511561802, 49.20305688040597, 47.75579227719988, 53.33018609455654, 49.18212890625, 48.96349688938686, 44.49567665372576, 45.949340547834126, 36.743255342756, 38.847180298396516, 37.33586720057896, 39.08925206320626, 37.8910664830889, 39.60530172075544, 38.91373014450073, 39.73705693653652, 35.54603556224278, 39.14067568097796, 36.20642362322126, 42.262918199811665, 39.54063483646938, 38.99726138796125, 38.88040310995919, 38.98314612252371, 36.235505308423726, 44.05088424682617, 45.53112152644566, 44.97805881500244, 43.8891475541251, 42.13091632298061, 44.94482210704258, 50.694734369005474, 50.10959529876709, 53.29873854773385, 48.100572313581196, 47.22920567648751, 44.021420410701204, 38.757013525281636, 49.5691157749721, 47.70463963917324, 51.282520702907014, 51.48501900264195, 49.06850848879133, 39.52495275224958, 42.79597357341221, 45.36549384253365, 44.688072272709434, 44.84315606525966, 44.80885975701468, 49.07140588760376, 43.342369488307405, 43.10853828702654, 38.637706007276265, 39.903257846832275, 39.52901744842529, 38.34505830492292, 39.48100887026106, 38.195678983415874, 38.653544425964355, 40.6198742049081, 40.367123058864046, 37.5683330808367, 40.49561262130737, 39.68745722089495, 39.0980623790196, 39.913530758449006, 46.02859170096261, 49.870712757110596, 49.63670785086495, 51.462770870753694, 52.81684276035854, 48.54137298039028, 47.01426315307617, 43.95755951745169, 39.32223558425903, 41.389543533325195, 39.18801723207746, 40.656974111284526, 37.9617018699646, 38.00684084211077, 39.43877077102661, 40.8808138029916, 40.60614456449236, 44.103058270045686, 47.83700977052961, 53.35282332556588, 53.955579553331646, 49.68720041002546, 51.268520082746235, 54.09527308600289, 55.19927930831909, 55.01686825071062, 56.96951355252947, 58.62268107278006, 56.48885454450335, 61.445352009364534, 58.9920403616769, 52.792826311928884, 30.138666016714915, 0.633863584271499, 17.880770444869995, 43.86582245145525, 0.39259183939014164, 0.41469096498829977, 37.7616354397365, 67.00675964355469, 53.27424267360142, 52.00192328861782, 16.778664554868424, 29.25618921007429, 64.99827861785889, 63.820989745003835, 66.61697265080043, 41.08535834721157, 0.7863898426294327, 0.16673845930823258, 0.1392637893025364, 0.15227746670799597, 0.22577209158667497, 0.23394731219325746, 0.10861979079033647, 0.11026776236082826, 0.21525342815688678, 0.2537167285169874], [0.042506626075399775, 0.024317931716463397, 0.02847718513969864, 0.007641897170937487, 0.039327774329909256, 0.03338308831942933, 0.03332168429291674, 0.060787862432854514, 0.08302017088447299, 0.09512993107948985, 2.311181034360613, 45.47373635428292, 51.68987621579851, 41.27455084664481, 31.43042298725673, 21.35956151144845, 20.105446406773158, 21.421720096043178, 44.7934000151498, 47.24580144882202, 42.990592615945, 0.8871696633952004, 0.026968143614275113, 1.071868958217757, 32.91291148321969, 4.915814893586295, 11.11874622958047, 52.92699602672032, 44.7633455821446, 51.77482836587088, 44.21147796085903, 50.28801114218575, 46.56875508172171, 52.35420043127877, 49.76181711469378, 52.027739320482524, 48.322341442108154, 50.823679038456504, 47.39001131057739, 47.227666650499614, 40.15532112121582, 38.38031346457345, 35.353535720280235, 36.17963484355381, 36.04055970055716, 39.24939761843, 41.39711706978934, 44.44090747833252, 44.31317179543631, 47.56910807745797, 47.71243551799229, 45.796504497528076, 44.648252146584646, 46.31361722946167, 47.02189227512905, 47.33626004627773, 45.00855793271746, 44.31698983056204, 40.4109696660723, 37.24386957713536, 33.82970196860177, 35.26774978637695, 35.989455699920654, 36.14097854069301, 36.02244227273123, 35.732198647090364, 35.23577765056065, 35.54775871549334, 34.57937438147408, 34.82956511633736, 34.49771567753383, 36.871543407440186, 34.04093067986624, 36.107047012874055, 33.62739127022879, 34.6466920035226, 35.28495005198887, 35.91449505942208, 34.607153279440745, 36.68155186516898, 33.688208852495464, 35.017312390463694, 38.73477928979056, 43.650966780526296, 43.32630525316511, 47.29860775811331, 45.41771650314331, 46.92924846921648, 37.4558938571385, 38.0337164742606, 46.49784871510097, 45.2608504976545, 46.980394159044536, 46.821436745779856, 43.72011872700283, 38.964385986328125, 36.82837772369385, 37.82434640611921, 38.451084341321675, 39.8115416254316, 39.12176268441336, 39.56226110458374, 36.42129666464669, 37.121456214359824, 36.52016258239746, 34.790113244737896, 34.71502406256539, 35.310119901384624, 35.48238658905029, 35.75185857500349, 36.7108975819179, 37.96158375058855, 36.26362466812134, 34.71979052679879, 36.18299429757254, 36.35729333332607, 35.899896894182476, 37.312152998788015, 36.922855854034424, 41.630795410701204, 43.25181361607143, 45.79782465526036, 44.856430598667686, 46.83391571044922, 44.10115098953247, 44.707454272678916, 37.60378973824637, 37.72339602879116, 36.40906088692801, 36.68602303096226, 36.44349615914481, 38.19756889343262, 35.12216418130057, 36.39753035136631, 36.092236927577424, 43.22950642449515, 44.953399658203125, 47.6108215876988, 45.102219649723594, 44.787966523851665, 47.399290629795615, 51.435186522347585, 52.78485325404576, 53.839676652635845, 51.86915710994175, 50.01467595781599, 52.79071058545794, 55.881352697099956, 53.325937271118164, 38.216353348323274, 33.92207479476929, 0.7771456443837711, 3.9080264568328857, 13.746658291135516, 1.2307104234184538, 0.08017357398888894, 24.35748164994376, 58.5915253502982, 44.9033830506461, 42.87672553743635, 33.31530598231724, 22.79349078450884, 33.907896995544434, 43.22561543328421, 48.19904218401228, 30.184378215244838, 0.7525529840162822, 0.15711056308022567, 0.04141535856095808, 0.015440050778644425, 0.017502997403166125, 0.010949722308266376, 0.03818377107381821, 0.028048841249463812, 0.033232575681592734, 0.03553093663815941, 0.007981404712024544, 0.06368777182485376, 0.032285323832184076, 0.008888522911417698, 0.014769208650769932, 0.05798832194081374, 0.026857248939839855, 0.03540803698290672, 0.07692190525787217, 0.0992698021499174, 3.65822525535311, 57.51522854396275, 57.8168637411935, 49.27332401275635, 36.557752336774556, 24.489420992987498, 21.416705233710154, 21.63988832065037, 47.9199469430106, 52.34520251410348, 46.97391496385847, 0.7775811010173389, 0.028705315398318425, 1.340598681143352, 28.93203490121024, 4.600800505706242, 11.700822881289891, 54.43234062194824, 45.556218419756206, 54.23363951274327, 45.77340521131243, 51.43196255820138, 47.39093542098999, 52.31318868909563, 49.72277518681118, 52.10973153795515, 49.65279640470232, 53.35607508250645, 49.114158153533936, 49.4676581791469, 42.0293927192688, 39.438329560416086, 36.865387303488596, 38.478696482522146, 37.437401226588655, 41.946802956717356, 43.167848110198975, 47.26823718207223, 46.25952202933175, 48.86680575779506, 47.50471912111555, 47.49933079310826, 46.36043071746826, 47.23261376789638, 49.36970247541155, 48.98410177230835, 46.54827526637486, 46.171974727085654, 41.92477021898542, 37.99026938847133, 36.08724117279053, 37.53062868118286, 38.019347599574495, 37.83359445844378, 37.242865562438965, 36.551078592027935, 36.850507736206055, 37.333025387355256, 36.20266464778355, 36.468936988285606, 37.059339318956646, 38.39834403991699, 36.55388913835798, 36.26317650931222, 34.02641936710903, 36.85660130637032, 35.632290499550955, 37.55487094606672, 36.56602416719709, 38.4727384022304, 36.77916710717337, 35.84513814108712, 41.36253588540213, 45.3068927356175, 45.057612214769634, 47.8816727910723, 47.531077112470356, 47.361002581460134, 37.97487218039376, 38.272015367235454, 45.35871934890747, 46.80253069741385, 48.55064187731062, 48.7006812776838, 45.75784819466727, 39.056585107530864, 38.477108819144114, 41.059517996651785, 39.633695534297395, 42.38723189490182, 39.42956093379429, 41.17628594807216, 38.004530566079275, 39.54593978609358, 38.363238266536165, 36.34653057370867, 36.820185797555105, 37.09505305971418, 36.12856905800955, 37.80222334180559, 37.6554183278765, 40.512010369982036, 37.63745723451887, 36.692040170942036, 36.69896057673863, 37.468108790261404, 37.26727110998971, 38.629705156598774, 39.278503622327534, 44.95660972595215, 45.765529428209575, 48.12609652110508, 48.64497756958008, 46.182626315525596, 46.38954366956438, 45.773832525525776, 40.85907636369978, 38.93047877720424, 38.07936266490391, 37.76437650408064, 38.98180512019566, 39.595845222473145, 37.646542004176546, 38.797188009534565, 37.97334010260445, 43.21937942504883, 47.67351518358503, 49.54332753590175, 47.171104839869905, 50.16874531337193, 49.295179571424214, 51.58006688526699, 55.53980357306344, 54.73766531263079, 53.786898136138916, 52.75134209224156, 54.3323004586356, 56.45897034236363, 53.7954409463065, 44.55646991729736, 38.85386446544102, 0.46608771277325495, 0.5890992720212255, 10.828931655202593, 1.461777110184942, 0.03693010638068829, 25.44311683518546, 63.19062832423619, 49.088731220790315, 46.34936571121216, 30.971258231571742, 28.047689029148646, 41.44076912743704, 50.760627610342844, 55.73231383732387, 39.21666465486799, 1.3569338960306985, 0.12572730066520826, 0.06328704261354037, 0.03702803933992982, 0.06745678958083902, 0.0025976243736555, 0.08995053757514272, 0.047673677027757676, 0.05370248780984964, 0.09040924760379962, 0.14866291066365583, 0.14005671175462858, 0.06418422197124787, 0.08938297695879426, 0.12405498325824738, 0.18271622194775514, 0.10993043546165739, 0.10615749577326433, 0.33060112435902866, 0.240069109414305, 5.412097794669015, 69.26116521017892, 63.14964090074812, 56.550019536699565, 42.477607113974436, 30.67759609222412, 26.54528178487505, 31.028695515223912, 54.49801499502999, 58.72658443450928, 50.45512226649693, 0.9500490150281361, 0.16522646615547792, 1.912311008998326, 41.50618641717093, 6.138982721737452, 14.267911280904498, 59.71878024509975, 50.80889327185494, 55.09393072128296, 46.912176745278494, 52.63928849356515, 47.230095045907156, 53.88784156526838, 51.34614883150373, 55.67093692507063, 51.466536794389995, 55.57609054020473, 51.822312355041504, 51.69740458897182, 42.55137613841465, 42.45307649884905, 39.41042906897408, 40.98538419178554, 39.894374574933735, 44.72374432427542, 45.28296661376953, 49.67784118652344, 47.81163842337472, 51.98466048921858, 51.749853066035676, 49.61878844669887, 47.84811299187796, 49.569087982177734, 51.459727559770855, 52.32485818862915, 48.715084893362864, 47.28544092178345, 45.395638602120535, 39.62394026347569, 36.28237785611834, 39.793948786599294, 38.484244619097026, 39.19456243515015, 38.84337963376726, 38.165534223829, 38.472727979932515, 38.790496894291465, 37.74161073139736, 37.05785240445818, 38.51555667604719, 41.55365650994437, 38.7130001613072, 38.81507267270769, 36.90969596590315, 38.56057752881731, 37.136440004621235, 40.96194096973964, 39.399569034576416, 40.08341768809727, 38.74765082768032, 36.80676882607596, 43.667437485286165, 47.6103595324925, 46.99998460497175, 51.41015911102295, 48.0034955569676, 51.990771429879324, 42.4050748688834, 39.9574989591326, 46.83695902143206, 48.25176164082119, 50.76015860693795, 51.08030033111572, 47.26422459738595, 42.13425145830427, 40.1508777482169, 41.15561853136335, 42.00982311793736, 43.32798324312483, 42.50380182266235, 44.03877353668213, 41.70748267854963, 41.60467365809849, 39.58791732788086, 38.27211959021432, 37.729774475097656, 38.75352552958897, 37.55911976950509, 38.45154987062727, 39.98183849879673, 43.596503325871055, 40.84574971880232, 37.181648458753315, 39.71705307279314, 39.33783776419503, 38.07685783931187, 40.70942606244768, 41.70807327542986, 46.87580292565482, 46.55876357214791, 50.160278933388845, 49.6455077443804, 49.85244246891567, 48.126621110098704, 49.727899483272004, 43.21697882243565, 41.89886038643973, 41.44731085641043, 40.20473323549543, 39.6276193346296, 42.29822199685233, 38.830886772700715, 41.322218963078086, 39.10051509312221, 46.892231941223145, 49.542007378169465, 52.40572827202933, 51.84472376959664, 52.916351386478965, 50.90978111539568, 54.5453565461295, 58.00391966956002, 57.73558718817574, 57.318226269313264, 54.25892400741577, 56.921272209712434, 59.63292135511126, 57.592589787074495, 42.72090176173619, 38.87500088555472, 0.9276999171291078, 8.379238281931196, 21.133562667029246, 2.6438853187220435, 0.11692102892058236, 28.594864879335674, 70.89537457057408, 56.519183431352886, 57.89398179735456, 43.825394357953755, 33.75617960521153, 46.964771134512766, 59.34946959359305, 63.48574611118862, 48.68114641734532, 2.0895328479153767, 0.23584886587091855, 0.1578281952866486, 0.10250330649848495, 0.14370899434600556, 0.10739318946642534, 0.19071373423295362, 0.11982020549476147, 0.19990937651268073, 0.17074462505323545], [0.037945523858070374, 0.049849535272057564, 0.03957999258169106, 0.03744446985157473, 0.03504052884610636, 0.034966215690863986, 0.01810701740240412, 0.08219009864010982, 0.011088497986617898, 0.06616048913981233, 5.218173571995326, 54.29420348576137, 47.31498466219221, 46.17606374195644, 42.21231099537441, 18.10677797453744, 20.22064753941127, 36.71314532416207, 38.20774800436837, 52.46828637804304, 38.96946511949812, 1.118521226303918, 0.12035448396844523, 1.7510738266365868, 10.242681741714478, 0.5701132650886263, 21.356240272521973, 20.68160493033273, 29.910171031951904, 51.46321555546352, 49.40992907115391, 51.9489745412554, 51.424003396715435, 49.38264002118792, 46.377137660980225, 48.16691023962838, 48.678169114249094, 49.04580872399466, 44.91327033724104, 40.085418769291465, 36.104681151253835, 34.75970445360456, 34.71101842607771, 35.686316217694966, 34.09190613882882, 35.82164280755179, 39.69359942844936, 43.005288055964876, 45.67754091535296, 43.76242978232247, 44.971260002681184, 45.61112308502197, 45.54972880227225, 47.406058175223215, 44.95258671896798, 42.35163279942104, 39.68880517142159, 35.94673817498343, 36.09375163487026, 35.06207615988595, 36.47919600350516, 36.58376291819981, 35.06300721849714, 35.4067519732884, 35.22420195170811, 36.07766308103289, 36.72593695776803, 36.08173819950649, 34.659633023398264, 34.985635553087505, 35.677207129342214, 35.28082282202584, 35.971199308122905, 34.08697291782924, 34.51932804925101, 35.227790696280344, 33.04127945218767, 37.620927470070974, 35.25561128343855, 36.60273844855172, 35.026258196149556, 38.248297691345215, 38.652804442814414, 44.84889875139509, 44.142287799290244, 46.060344968523296, 44.26044539042881, 51.5446206501552, 31.363553524017334, 41.10521977288382, 48.91999421800886, 43.921804087502615, 46.47221681049892, 42.950911453792024, 41.605431011744905, 35.411118916102815, 36.72170203072684, 35.82917465482439, 37.03429453713553, 36.9474698475429, 37.100844383239746, 38.16400214603969, 36.623385020664756, 38.30539798736572, 37.951029436928884, 35.85348640169416, 34.94839320863996, 34.66756091799055, 36.76485729217529, 37.16609491620745, 38.60865906306675, 35.935655798230854, 35.566775935036794, 37.06888266972133, 36.93163142885481, 35.28019748415266, 37.01539543696812, 37.69066653932844, 35.94398668834141, 37.389750480651855, 40.25569827216012, 44.03120347431728, 44.27155555997576, 44.99170855113438, 43.245660986219136, 43.3110921723502, 41.64871481486729, 37.52350330352783, 37.18691866738455, 34.92077759334019, 35.8059537751334, 35.08853490012032, 35.46296637398856, 34.6561450277056, 38.14225428444998, 40.72965921674456, 46.50529023579189, 45.42161096845354, 44.209278856004985, 48.484783376966206, 50.19839675085885, 49.48822137287685, 52.23413208552769, 50.89272328785488, 52.26959916523525, 49.79834379468645, 52.24595097133091, 53.61576747894287, 58.41479097093855, 57.92242424828665, 58.9134840284075, 3.915986052581242, 1.5601843382631029, 5.65712080683027, 1.0648480206727982, 0.03837066336667963, 14.950588294437953, 60.6466635295323, 46.89002588817051, 41.86804165158953, 25.025514466421946, 14.940296275275093, 32.612186500004356, 48.28055150168282, 50.58130155290876, 40.42566510609218, 4.329615354537964, 0.12905191869607993, 0.0064298589048641065, 0.015514330007135868, 0.03247945609369448, 0.018986566723989587, 0.03991503281784909, 0.090787781934653, 0.04481548057602985, 0.0025792415877471542, 0.022260136869070784, 0.027900752677981342, 0.05330515805897968, 0.04696151381358504, 0.04334479324253542, 0.03484119222100292, 0.010969639855570026, 0.10749836239431586, 0.07101803991411414, 0.07943160273134708, 7.236356019973755, 59.89519500732422, 52.888072218213765, 51.49971791676113, 50.04812111173357, 27.375318799700054, 17.144815513065883, 38.967926093510215, 43.10218415941511, 58.455597741263254, 41.18666655676705, 1.0155687906912394, 0.07447324200932469, 4.210832859788622, 10.224356736455645, 0.5957728539194379, 24.643168994358607, 20.873392581939697, 32.15319892338344, 52.342405864170615, 50.77046625954764, 53.67004680633545, 52.85043730054583, 49.389841829027446, 47.521092551095144, 49.07415042604719, 50.695019245147705, 50.47603981835501, 47.51987314224243, 42.221857820238384, 38.099390847342356, 36.933507442474365, 35.835438455854145, 38.01952477863857, 35.67438268661499, 37.35702099118914, 40.96436241694859, 45.05741766520909, 47.71155309677124, 46.954084805079866, 48.8862190246582, 47.79478209359305, 47.055452074323384, 48.513962336948936, 46.18136521748134, 43.82703760692051, 41.786195346287315, 38.46408789498465, 37.13381705965315, 36.90070847102574, 37.002819197518484, 38.480093070438926, 36.391648701259065, 36.41402884892055, 37.141849177224294, 38.39383118493216, 37.30879701886858, 37.70679678235735, 36.07828147070748, 36.257652691432405, 35.85955217906407, 36.06111594608852, 36.85936321531023, 34.936952999659944, 34.75117206573486, 36.5582526070731, 35.303665024893625, 37.663169043404714, 37.51685735157558, 37.472663334437776, 36.02542652402605, 39.33569424492972, 41.92707702091762, 47.79503917694092, 45.51870162146432, 49.53191859381539, 45.484057903289795, 49.51242542266846, 34.25714124952044, 41.58572939464024, 51.96827663694109, 46.378603730882915, 49.76575674329485, 44.906638281685964, 42.68664714268276, 37.01914746420724, 38.66654103142874, 37.773499488830566, 38.97307818276541, 39.525366170065745, 39.57240547452654, 39.277801854269846, 39.31467594419207, 39.30447598866054, 38.19228826250349, 37.29127366202218, 37.27329172406878, 36.595540114811485, 37.131155899592805, 38.473335947309224, 40.7640562738691, 39.12638323647635, 36.896942547389436, 36.32256971086775, 38.5947904586792, 36.666251931871685, 37.91563183920724, 39.25143344061715, 37.785408701215474, 37.55323117119925, 42.50309310640608, 45.333254201071604, 46.2420368875776, 46.66969156265259, 46.616874831063406, 44.68869761058262, 43.88647249766758, 39.666504928043906, 39.79182611192976, 37.82526009423392, 37.50941930498396, 36.89226640973772, 37.14178316933768, 37.677635192871094, 40.01197631018502, 42.970276083265034, 47.891362054007395, 48.194254875183105, 45.766585554395405, 50.46809107916695, 52.36885070800781, 51.08674131120954, 53.225403785705566, 52.128686223711284, 53.353507723127095, 51.680006299700054, 55.45984022957938, 54.77029057911464, 59.235637256077354, 59.71340233939034, 60.67350442068917, 4.401770659855433, 1.1228108704090118, 4.942947609083993, 0.5573540925979614, 0.0316714260594121, 16.31532219478062, 65.25395148141044, 50.205744470868794, 46.11287334987095, 24.920568874904088, 20.423156261444092, 39.272868633270264, 55.444265842437744, 56.57659292221069, 49.798236097608296, 6.4321532760347635, 0.06587325169571809, 0.05913501898092883, 0.024622386986655847, 0.015003218415326305, 0.0372333776072732, 0.0035207589680794626, 0.10635608261717217, 0.06149448201592479, 0.04573403039414968, 0.08915773047400372, 0.08980205375701189, 0.15234746438051971, 0.11767830114279475, 0.18453150668314525, 0.11550876684486866, 0.1362111416778394, 0.160864883767707, 0.2542560010084084, 0.15392005071043968, 9.542651602200099, 70.2957033429827, 59.79532160077776, 58.448128427777974, 53.606877258845735, 26.822916167122976, 27.270296777997697, 49.941542693546836, 46.92450632367815, 63.87367098672049, 44.798642430986675, 1.2814091486590249, 0.25585775077342987, 6.129774187292371, 14.594343730381556, 2.2482073392186845, 27.75660640852792, 21.0912481376103, 33.876181943076, 56.219052519117085, 51.79439101900373, 56.77070474624634, 54.904800755637034, 53.37037794930594, 49.6096168245588, 51.5405524798802, 52.73526048660278, 52.15851831436157, 48.476567132132395, 43.97236612864903, 40.00791161400931, 38.447891644069124, 37.41019902910505, 38.393226691654746, 38.16482898167202, 39.99437999725342, 43.657800333840505, 47.042691707611084, 50.19453355244228, 48.6614065851484, 50.82728862762451, 49.83314037322998, 48.51354544503348, 52.24845232282366, 49.597763197762625, 46.142597743443076, 43.272842339106965, 39.40263319015503, 38.63004214423043, 38.05215351922171, 39.24212980270386, 40.6390095438276, 38.166635513305664, 39.16164534432547, 38.63008383342198, 40.56828383037022, 39.20962265559605, 39.674926144736155, 36.65137236458914, 38.03952169418335, 37.925734519958496, 36.00154903956822, 41.17365952900478, 38.88426283427647, 37.94087464468819, 39.80752556664603, 36.86773579461234, 39.851393018450054, 39.2048214503697, 40.01045118059431, 39.33156354086739, 42.92092650277274, 42.92648506164551, 49.48481328146798, 49.14850309916905, 50.513344696589876, 48.672662666865754, 52.35913712637765, 36.06267581667219, 44.39041491917202, 53.333114760262625, 47.66824497495379, 50.811273029872346, 46.83940131323678, 46.01172494888306, 38.09792825153896, 41.33666774204799, 40.0699451310294, 41.879589557647705, 41.23222936902727, 42.032713958195274, 40.92962489809309, 40.747040135519846, 40.86947086879185, 40.9117819241115, 40.825123991285054, 38.61688225609915, 36.971211842128206, 40.582274028233115, 41.50772196905953, 43.8477988243103, 40.755339758736746, 36.77151714052473, 40.19125720432827, 41.197801045009065, 38.116316659109934, 40.37456805365426, 41.415842464991975, 39.73910665512085, 40.45838417325701, 44.94719839096069, 46.66704429898943, 48.25010102135794, 49.525765963963096, 48.63980463572911, 47.17322404044015, 45.891250133514404, 41.92016356331961, 43.734143665858674, 39.85402291161673, 39.578704016549246, 38.47130012512207, 39.21047033582415, 39.60869591576712, 42.15720483234951, 45.40981640134539, 51.23669385910034, 51.10578284944807, 48.8239666393825, 52.65796872547695, 55.00084570475987, 52.301682472229004, 55.87625619343349, 53.53042275565011, 55.78984839575631, 54.46332263946533, 57.28922101429531, 56.592792647225515, 63.55688871656145, 57.69709069388253, 59.22495787484305, 5.883972108364105, 4.686515654836382, 14.312348484992981, 1.419826166970389, 0.10468202816056353, 17.864509923117502, 73.48069504329136, 56.96719980239868, 54.428956849234446, 35.49136366162981, 25.10485942023141, 44.632920946393696, 64.57503604888916, 64.95645046234131, 58.5316527230399, 8.067848682403564, 0.3237176851502487, 0.14534575651798928, 0.10330274288675614, 0.20920089579054288, 0.11927299414362226, 0.20383103750646114, 0.18840410959507736, 0.16235072618084295, 0.08711700247866766], [0.07840704199458871, 0.03526666760444641, 0.010428904273015047, 0.048821317231548686, 0.030202312927160944, 0.07559323869645596, 0.057889737587954314, 0.036299723599638255, 0.06623610508229051, 0.05457262076171381, 8.021925432341439, 56.00108058112008, 43.98004388809204, 47.99081856863839, 23.9703141280583, 16.39532027925764, 44.479379653930664, 38.680830001831055, 39.174419607434956, 51.64378881454468, 39.40276868002755, 0.9070305462394441, 0.016583141405135393, 4.507861835615976, 1.2156164390700204, 2.5033786296844482, 25.973172324044363, 19.105251482554845, 35.51367780140468, 53.30881690979004, 48.984021868024556, 49.292848450796946, 47.18831205368042, 45.85581432070051, 46.7753632409232, 45.2072034563337, 43.37048189980643, 39.6370758329119, 36.50556789125715, 35.63744258880615, 34.77761690957205, 35.95656640189034, 35.88725812094552, 34.178032534463064, 35.16378041676113, 36.20871305465698, 39.384081499917166, 42.286483015332905, 43.02045944758824, 45.68931463786534, 45.8837947164263, 47.79836041586739, 45.388822419302805, 45.523864133017405, 40.854931763240266, 34.282908643995015, 35.04081119809832, 35.32060125895909, 35.44741630554199, 34.185828413282124, 35.05038234165737, 34.238214356558665, 33.97276537758963, 33.841458320617676, 34.515551703316824, 35.53557504926409, 34.75939525876726, 36.13869258335659, 34.40796232223511, 36.25617272513253, 34.7877265385219, 34.79542861665998, 34.9406008039202, 34.26738289424351, 35.757893085479736, 35.9221693447658, 37.61864498683384, 35.182478019169395, 35.79356166294643, 36.86197921207973, 34.9841034752982, 37.421253613063264, 38.74821710586548, 43.6246018409729, 43.28324031829834, 46.499172346932546, 40.61724778584072, 50.003600529261995, 38.688059602464946, 39.43874992643084, 49.70954234259469, 42.844169752938406, 44.07491111755371, 39.84693922315325, 37.5608811378479, 35.62898663112095, 36.46450056348528, 39.528923647744314, 40.435990129198345, 39.90521029063633, 42.566839354378835, 40.90450021198818, 45.0408079964774, 47.21691083908081, 42.44099358149937, 37.32388155800955, 33.99132054192679, 34.678490434374126, 35.47665779931204, 34.96377304622105, 38.604469299316406, 38.28949008669172, 35.758928367069785, 34.65532166617257, 37.99238511494228, 35.131655420575825, 37.65258346285139, 37.95599045072283, 36.348465647016255, 34.71254355566842, 37.61459418705532, 39.09239264896938, 42.61856869288853, 43.43421425138201, 41.52928917748587, 42.561284269605366, 41.34130913870675, 38.46940326690674, 37.42736455372402, 35.1574193409511, 36.485032490321565, 35.89095456259591, 37.583633014133994, 35.98794446672712, 38.87414973122733, 41.378336088997976, 44.63370609283447, 45.24278170721871, 47.84922122955322, 47.44464152199881, 50.33878857748849, 48.908877100263325, 51.139255796160015, 50.507376194000244, 51.70268521990095, 48.81741796221052, 52.7664474759783, 50.417654105595176, 57.20778117861067, 51.38649007252285, 62.654977798461914, 16.95273082596915, 0.7195349814636367, 1.5594844158206667, 0.24166225535529, 0.1405597369053534, 11.86647835799626, 56.05095822470528, 47.6532438141959, 49.49898760659354, 53.67694984163557, 28.950808933803014, 27.806178331375122, 46.901056153433665, 46.23401171820504, 46.958406584603445, 7.694666147232056, 0.09028729450489793, 0.10378052653478724, 0.08580550963857345, 0.013833793844761593, 0.03368407627567649, 0.027434390470651642, 0.05969487822481564, 0.06286057656896965, 0.047934868905161104, 0.09490095265209675, 0.009839199666332985, 0.0947547826383795, 0.05659802743632879, 0.033304917692605934, 0.01255896479623126, 0.014324221992865205, 0.02414261523102011, 0.14688445680907794, 0.004211954814049282, 11.07568997996194, 64.23572771889823, 50.183475494384766, 52.65921940122332, 28.994493995394024, 18.06502972330366, 39.200572626931326, 44.44010843549456, 40.968312467847554, 56.48321955544608, 41.54804236548287, 1.0672773931707655, 0.11963636321680886, 0.7117530533245632, 0.9543658005339759, 3.1706497498920987, 29.69944953918457, 19.96582235608782, 40.30765342712402, 56.220046111515586, 50.66917542048863, 49.791187150137766, 48.609104020254954, 47.661640712193076, 47.63798904418945, 47.74668666294643, 45.42314999444144, 42.0722005707877, 38.23611749921526, 37.85489068712507, 36.72855642863682, 36.53406940187727, 38.18460355486189, 37.04192018508911, 38.2140291758946, 38.11428083692278, 41.56398153305054, 42.66254384177071, 44.32671383449009, 46.99507917676653, 47.4934595652989, 48.21611043385097, 47.09441409792219, 47.178025245666504, 41.961481026240754, 36.599417209625244, 36.77596746172224, 36.898467676980154, 35.48476982116699, 36.54533243179321, 35.48821265356881, 36.492630345480784, 36.28850269317627, 36.18432487760271, 36.71805770056588, 37.274069922310964, 36.05261829921177, 35.85342386790684, 37.40085717609951, 36.84740536553519, 36.32694360188076, 36.75389650889805, 36.221567222050254, 36.28135994502476, 37.5425135748727, 37.58528668539864, 38.611236844744, 36.970517022269114, 36.67762265886579, 37.93696975708008, 37.30940498624529, 38.221345629010884, 40.78168732779366, 45.94355617250715, 44.60466262272426, 49.053531646728516, 42.84107780456543, 50.64883804321289, 41.103336811065674, 41.01084239142281, 51.04766116823469, 44.147033418927876, 45.609691756112234, 41.0772567476545, 39.382434776851106, 38.03124291556222, 39.500574997493196, 41.22563205446516, 41.8115736416408, 40.98205253056118, 43.77803543635777, 43.037221976688926, 45.84716381345476, 46.840961183820454, 45.34812682015555, 39.47220550264631, 34.74563782555716, 35.905608313424246, 37.27285746165684, 36.776519843510215, 39.21513952527727, 39.229411125183105, 36.49234199523926, 37.45924636295864, 38.37329230989729, 37.174272945949006, 39.090527057647705, 39.24705260140555, 38.489466190338135, 36.8957439831325, 38.55293451036726, 41.968231201171875, 44.715514183044434, 45.62751735959734, 45.17733662469046, 43.72415910448347, 42.71225125449044, 40.96716601508004, 39.26204333986555, 37.24289682933262, 38.0141955103193, 37.48935290745327, 39.52696425574166, 38.38709143229893, 40.41666718891689, 43.09910263334002, 47.054482800619944, 48.20095641272408, 50.8296788079398, 49.03859649385725, 52.865233489445274, 51.65455157416207, 53.424938678741455, 51.51113033294678, 55.22315331867763, 50.940019675663535, 53.97466278076172, 51.50481789452689, 59.62661933898926, 53.314858368464876, 64.81215722220284, 18.665277651378087, 0.5688369135771478, 0.27471043914556503, 0.5145795707191739, 0.05416198154645307, 12.59139347076416, 62.137330055236816, 50.812721729278564, 46.53972898210798, 42.88849925994873, 32.97638675144741, 33.98921176365444, 53.41879994528634, 51.5094975062779, 55.811050823756624, 9.862099375043597, 0.12646076987896646, 0.030599954804139476, 0.04556099378636905, 0.05078653106465936, 0.034064354441527805, 0.03216522991923349, 0.037588739967239757, 0.023195746753896986, 0.02187078499368259, 0.15889273530670575, 0.0722638980618545, 0.1873940016542162, 0.17004842098270143, 0.16070849501660892, 0.17390857956239156, 0.13464865194899694, 0.08676556883645908, 0.27762216861758915, 0.18524014151522092, 14.040028606142316, 73.10304655347551, 54.449947357177734, 62.20868110656738, 32.529145104544504, 24.174347979681833, 51.6214781488691, 49.31676067624773, 48.281934193202424, 62.19789750235421, 45.59768874304635, 1.1965706667729785, 0.3404981275754315, 7.884255562509809, 6.591762517179761, 4.9880010315350125, 32.54856879370553, 21.49791751589094, 44.04002768652779, 57.71034785679409, 52.835067885262625, 52.72616876874651, 49.799580574035645, 49.3032603263855, 49.841770035879954, 48.18378741400582, 45.86782775606428, 44.48553923198155, 41.3348195212228, 40.63296461105347, 38.57060030528477, 40.044285433632986, 40.23490578787667, 38.60599790300642, 39.8130007471357, 39.33208465576172, 43.363224506378174, 45.54501444952828, 46.148479393550325, 49.07941716057913, 50.01212249483381, 50.434520857674734, 49.97722864151001, 49.751766545431956, 43.30536685671125, 36.824361664908274, 39.53148405892508, 39.234177589416504, 38.74762303488595, 37.69692686625889, 37.09871823447091, 37.66184541157314, 38.74078948157174, 38.422357014247346, 38.54082727432251, 38.991490909031455, 37.9241920198713, 39.05067219052996, 39.519498416355674, 39.63410200391497, 38.26228788920811, 38.38224506378174, 37.57381173542568, 37.75842884608677, 40.07197053091866, 41.07128824506487, 41.551082202366416, 40.271158014025005, 39.13305698122297, 39.95400401524135, 39.147842747824534, 42.04697166170393, 42.19503082547869, 47.383118697575156, 47.55491638183594, 52.218717506953645, 44.26583024433681, 51.88023601259504, 44.43019683020455, 45.23524291174752, 52.71263367789132, 46.60929782049996, 47.235966273716514, 44.29506131580898, 40.57595116751534, 39.59105096544538, 41.085827350616455, 44.381399631500244, 44.260514872414724, 42.65561648777553, 45.79071317400251, 45.67040164130074, 48.93529762540545, 49.18742690767561, 47.26898758752005, 42.119135652269634, 36.10863120215279, 37.28211246218, 39.21286746433803, 37.98738241195679, 39.57750545229231, 40.31076969419207, 38.97983877999442, 38.420623438698904, 40.316314356667654, 38.7766352381025, 40.77064316613333, 41.14896215711321, 39.65910857064383, 38.60102646691458, 40.816490854535786, 43.348063537052695, 47.717028277260916, 48.20754330498831, 47.2876296043396, 46.31923137392317, 45.46263313293457, 43.57604782921927, 42.28274488449097, 39.474807603018625, 40.26522077832903, 38.88511051450457, 41.961557456425254, 40.32689298902239, 42.85196910585676, 45.974704946790425, 49.499397550310405, 50.91087893077305, 53.32247012002127, 51.92883518763951, 54.7865424156189, 53.57714244297573, 56.31959295272827, 54.85534347806658, 56.836611883980886, 53.944914068494526, 56.80656787327358, 54.78875541687012, 60.98720863887242, 56.36721937997, 66.00291170392717, 21.26795472417559, 1.0481406428984232, 6.958096299852643, 0.8295328361647469, 0.16395848776612962, 14.913651670728411, 68.03351579393659, 56.183248451777864, 62.68487589699881, 65.4930876323155, 40.94513675144741, 41.89042179925101, 60.0496951511928, 58.92557389395577, 64.96126556396484, 13.03547716140747, 0.2435546080980982, 0.19704955496958323, 0.11915943452290126, 0.16912992884005817, 0.19587285311094352, 0.07584154858653035, 0.15148785550679478, 0.10141248003180538, 0.10824363811739854], [0.03107195733381169, 0.021523366582446864, 0.061483130125062804, 0.020987298472651413, 0.019662401173263788, 0.0588534948016916, 0.05419438159359353, 0.031273913104087114, 0.06503765617630311, 0.13325912079640798, 12.243057693753924, 53.80216332844326, 40.89151750292097, 36.84903471810477, 26.20698094367981, 43.53763471330915, 53.54254041399275, 48.21283088411604, 37.422823905944824, 54.746468680245535, 32.903785024370464, 0.4148569346538612, 0.1441787305687155, 1.9495941741125924, 0.7947920060583523, 2.6575915089675357, 43.95044456209455, 46.732072489602224, 54.54607221058437, 50.31772511345999, 49.67836577551705, 46.19196122033255, 44.14024155480521, 40.888658319200786, 40.68686873572213, 36.82170050484793, 36.55925662176949, 34.60523905072893, 35.174623080662315, 37.66305439812796, 37.900995458875386, 38.221765995025635, 39.76958840233939, 37.18829788480486, 37.2104800088065, 36.81572505405971, 37.72000183377947, 40.09073761531285, 41.62451771327427, 44.79769400187901, 44.166662079947336, 44.93734237125942, 43.63582665579659, 41.756474426814485, 34.801681995391846, 33.76774140766689, 34.72805540902274, 33.98615803037371, 36.46257938657488, 33.73892027991158, 35.97413492202759, 36.709667750767295, 34.45672130584717, 36.428189277648926, 35.402819292885916, 35.88587890352522, 34.730678353990825, 34.292889731270925, 33.75234419958932, 36.74793495450701, 36.1633517401559, 36.15856443132673, 35.956090450286865, 36.12132556097848, 37.513987745557515, 37.34965590068272, 38.041939667293, 38.94694948196411, 35.81795678819929, 35.90494128635952, 34.338157245091026, 37.050480365753174, 34.663096700395855, 39.60728543145316, 40.615118162972585, 45.48877573013306, 44.125389780317036, 49.047674315316335, 40.50879682813372, 39.917105606624055, 47.71061508996146, 43.151881149836946, 40.74375711168562, 34.02687447411673, 36.501350334712434, 37.810258933476035, 40.206991400037495, 43.110473360334126, 42.984467778887065, 45.23261301858084, 45.52355146408081, 48.30999101911272, 48.09502765110561, 46.070214884621755, 48.241030148097444, 39.781556674412315, 35.59858478818621, 34.78859853744507, 34.02906663077218, 35.86866126741682, 35.93005207606724, 36.68037414550781, 37.06563786097935, 36.55139126096453, 35.2017696925572, 34.874082224709646, 35.550610951014924, 37.2731979233878, 37.098193645477295, 35.33332341057913, 35.73049633843558, 36.33571917670113, 37.377924646650044, 38.55864940370832, 40.372285570417134, 39.47008630207607, 38.29177604402815, 36.70573854446411, 35.9081027167184, 34.38963644845145, 34.25748865944998, 36.49442992891584, 36.03042575291225, 37.14911004475185, 37.27272891998291, 40.62257358006069, 44.586381912231445, 46.18573216029576, 45.73679862703596, 46.447033064705984, 47.33300828933716, 49.558255740574424, 48.99004595620291, 48.06821455274309, 47.53744861057827, 48.6513421194894, 49.780396597726, 49.722653593335835, 55.36254807880947, 57.27399056298392, 65.97261060987199, 39.8957051549639, 0.04587462285001363, 1.5897299242871148, 0.6245854049921036, 0.20485430902668408, 9.512373089790344, 56.06615393502371, 51.04212692805699, 57.47012778690883, 62.983439990452354, 42.79694979531424, 29.927194118499756, 43.370009422302246, 50.88205780301775, 53.486301694597515, 9.850434218134199, 0.17812921665608883, 0.027556302857452204, 0.08175967673638038, 0.07529376726597548, 0.08627939171024732, 0.02151685094993029, 0.09098672161677054, 0.02495206001081637, 0.024246727947943976, 0.028484316542744637, 0.043019028580082316, 0.029520375055394003, 0.010796369153207966, 0.01528208952264062, 0.037256379944405386, 0.05470017177451934, 0.029807134132300104, 0.01951053485806499, 0.06701704460595335, 16.135146720068796, 62.921093804495676, 46.35041488919939, 47.146598543439595, 33.24399662017822, 38.10337563923427, 55.97368730817522, 51.17043236323765, 40.96233354296003, 59.02268886566162, 35.92665440695626, 0.4271856445286955, 0.1036930430148329, 2.158481342451913, 0.5379977141107831, 2.941253670624324, 45.634517669677734, 49.59675570896694, 56.7885616166251, 52.24719817297799, 51.74660478319441, 47.51563126700265, 46.48642240251814, 44.7340658732823, 43.461642265319824, 39.26878309249878, 38.44944109235491, 36.27343552453177, 36.71306194577898, 39.030998366219656, 39.608862672533306, 39.447084290640696, 40.7307049206325, 37.92808995928083, 38.219966411590576, 38.19029760360718, 38.94176265171596, 43.225636277879985, 45.30188308443342, 46.04473236628941, 44.763303892953054, 46.82364974703108, 46.53889867237636, 42.17944254193987, 37.02442809513637, 35.88474287305559, 36.02365125928606, 36.485716887882774, 36.301679951804026, 36.42259250368391, 36.371283531188965, 37.450213704790386, 35.25848436355591, 36.738739013671875, 36.73617512839181, 37.6531844820295, 36.17122752325875, 35.64481462751116, 35.588617597307476, 37.193925925663535, 37.70624092647007, 36.775998728615896, 38.11989845548357, 36.702420779636924, 39.887099811008994, 39.243293625967844, 39.264336245400564, 40.32189723423549, 37.93786954879761, 38.13838413783482, 37.09554985591343, 38.14211879457746, 37.66103942053658, 40.888613155909944, 43.00107397351946, 46.80899599620274, 46.10483775820051, 50.36791542598179, 41.61249385561262, 42.211081164223806, 49.81860474177769, 44.92411300114223, 44.063370159694124, 36.81371007646833, 39.28278718675886, 40.30335944039481, 42.19966527393886, 45.228506633213584, 46.189470291137695, 47.265972069331575, 46.95070103236607, 49.54978241239275, 48.8825295312064, 46.73313556398664, 50.092930044446675, 42.391501562935964, 35.32319988523211, 37.45608145850045, 36.28419133595058, 37.694950103759766, 37.81785331453596, 39.08173758643014, 38.57797581808907, 38.0453234400068, 37.230122566223145, 36.113633905138286, 37.26754903793335, 38.77625308718, 38.345687116895405, 36.53259290967669, 37.36441387448992, 36.972045625959126, 39.08677155630929, 40.816275460379465, 43.04371854237148, 40.99942650113787, 41.35799176352364, 38.94817931311471, 38.0501628603254, 36.83770220620291, 36.8253378868103, 37.5068484715053, 37.582153047834126, 40.346962860652376, 39.518685477120535, 41.959809984479634, 45.66066026687622, 48.43286643709455, 47.83766290119716, 48.07447835377285, 48.621454443250386, 50.014894826071604, 51.17254114151001, 49.0150386265346, 50.357816219329834, 49.592934199741904, 52.37735182898385, 52.05861016682216, 56.80441393171038, 59.1170870917184, 68.81736292157854, 41.97556502478463, 0.016439061279275587, 3.180352474961962, 0.8842212387493679, 0.05425438105261751, 9.775438836642675, 62.00014482225691, 56.21818399429321, 63.380001476832796, 67.915452003479, 46.41430704934256, 34.39594888687134, 53.212386335645405, 54.20395680836269, 62.74251815250942, 12.559092164039612, 0.13218839253698075, 0.027246273422081555, 0.07959436292627028, 0.06501032478575196, 0.08425006988857474, 0.04906160005235246, 0.07312647891896111, 0.04599306113751871, 0.053601287704493315, 0.07114964856633119, 0.17946002738816397, 0.1748798345880849, 0.11777700084660735, 0.08808897675148078, 0.11506622630570616, 0.12505723376359257, 0.14254913372652872, 0.15856099953608854, 0.23912410012313298, 20.388590710503713, 74.1105284009661, 52.71065691539219, 53.498683384486604, 35.93663549423218, 56.90910243988037, 60.84039320264544, 57.46526057379586, 46.745545046670095, 63.41101128714425, 37.22570003782, 0.6716722069042069, 0.22048365750483104, 6.1768708143915445, 7.528790065220424, 3.7239122220448087, 49.11089250019619, 49.256078583853586, 58.46765981401716, 53.185416902814595, 53.57484606334141, 49.41362203870501, 48.513833795275005, 46.7181066104344, 45.67860746383667, 40.292280537741526, 39.025811535971506, 37.48070934840611, 38.55530732018607, 41.30858659744263, 42.904417582920615, 40.49325023378645, 43.2423015322004, 41.25413703918457, 39.80159527914864, 39.92244182314192, 42.30506249836513, 44.26972470964704, 47.5580187525068, 48.23218856539045, 46.771913460322786, 48.20414910997663, 48.34563527788435, 44.72886514663696, 38.71762071337019, 37.456515720912385, 37.801382609776084, 38.18201535088675, 39.75524732044765, 38.65425314222063, 38.77561732700893, 38.68429715292794, 37.50159215927124, 40.596073150634766, 38.681431021009175, 40.61635494232178, 37.36237110410418, 37.697847502572195, 36.5481846673148, 40.516495432172505, 40.97460058757237, 38.10306991849627, 39.01637240818569, 38.46999733788626, 41.85657017571585, 41.020302363804404, 41.8472317968096, 42.2807993888855, 40.08634982790266, 39.05742931365967, 38.19974715369088, 41.37343413489205, 40.31698138373238, 44.89060878753662, 46.0325973374503, 49.355024405888145, 48.31007439749581, 52.8916540145874, 44.99296964917864, 44.73337452752249, 50.826493058885845, 47.34325688225882, 45.813447679792134, 37.44093438557216, 41.700461523873464, 42.3936242376055, 43.99723025730678, 48.3443672316415, 48.71312550136021, 49.6331399508885, 49.153141021728516, 51.33925969260079, 50.50091436931065, 49.8842339515686, 53.01615878513881, 43.12693016869681, 38.399024963378906, 39.002048696790425, 38.032750674656455, 39.697049209049766, 39.53975936344692, 41.038826261247905, 39.746760095868794, 40.434378147125244, 38.15955877304077, 38.21690225601196, 38.1669933455331, 41.71038702556065, 39.64182840074812, 38.78141559873308, 40.54979814801897, 39.91706739153181, 40.92434426716396, 43.56436095918928, 45.39307819093977, 43.7388927595956, 43.08295501981463, 41.191078662872314, 39.80329758780343, 38.93184062412807, 38.44559873853411, 41.183293206351145, 40.031629289899556, 42.36936460222517, 41.90871293204171, 44.78895664215088, 49.351741382053916, 50.932981150490896, 49.66093274525234, 50.08592626026699, 50.32370056424822, 52.71291160583496, 51.959122385297505, 50.938049861363, 50.719473430088584, 52.88693618774414, 53.7378751209804, 54.54678092684065, 59.37515013558524, 63.26106916155134, 70.36524786267961, 48.35352495738438, 0.120669174939394, 10.094712904521398, 1.8541074693202972, 0.32747780052678926, 11.70912424155644, 67.91836329868862, 62.080868993486675, 71.03688158307756, 67.4460733958653, 50.42644010271345, 42.023240089416504, 59.500982012067524, 61.286995615277974, 71.32556533813477, 17.00728460720607, 0.4836807687367712, 0.12429557820515973, 0.245185914848532, 0.2513141988643578, 0.15281139234347002, 0.17439408493893488, 0.19266962499490806, 0.09968233108520508, 0.10961114402328219], [0.018487741705030203, 0.0016207603018431524, 0.06222946436277457, 0.005099484555622829, 0.03527313404317413, 0.06270435066627604, 0.022705057369811193, 0.07518599554896355, 0.08073780299829585, 0.1017312557835664, 16.717141730444773, 58.21634694508144, 42.003184114183696, 31.677751064300537, 17.692623649324688, 38.99909223828997, 60.97195039476667, 45.6468368257795, 38.58120673043387, 56.29379429136004, 31.956842831202916, 0.3763284949319703, 0.10220876123223986, 0.2167319016797202, 0.8602071787629808, 6.2546862959861755, 53.41308157784598, 54.22436714172363, 53.805213587624685, 49.84660945619856, 47.84292963572911, 40.112645285470144, 38.161938531058176, 36.09636068344116, 36.682260581425254, 35.93545082637242, 36.89785623550415, 38.19031497410366, 39.77850988933018, 42.58616924285889, 45.35783345358712, 45.67078379222325, 46.24376698902675, 42.964488233838765, 43.69662339346749, 39.23396914345877, 40.09027903420584, 39.20284816196987, 43.20130021231515, 44.113664695194785, 43.71957329341343, 43.13251304626465, 42.57350615092686, 37.46663229806082, 35.07832799639021, 33.944548743111746, 33.06226996013096, 33.78375005722046, 34.92623192923409, 34.66382278714861, 34.972062247140066, 34.79187808718, 34.46331514630999, 33.88166059766497, 33.97195938655308, 36.39127002443586, 35.75803552355085, 36.14297614778791, 34.72343485695975, 34.75443424497332, 33.49932554789952, 36.07479347501482, 36.85380118233817, 36.7474798474993, 39.687881061008994, 41.04211623328072, 42.98471443993704, 39.84387854167393, 41.25171211787632, 36.16846908841814, 34.64208882195609, 34.2696202141898, 35.62074954169137, 36.78639323370797, 40.374429089682444, 45.25655651092529, 43.984942368098665, 49.483402797154014, 42.99697801045009, 41.03130831037249, 48.10456057957241, 45.07965884889875, 39.195093972342356, 35.969125270843506, 38.777465547834126, 39.7263879776001, 43.60546997615269, 46.39586305618286, 50.15748923165457, 49.50971562521798, 48.520875794546946, 46.16182688304356, 43.267592975071494, 44.91680349622454, 46.28546660287039, 38.47614301953997, 33.03942428316389, 36.499113014766145, 34.639146259852815, 35.852253096444265, 34.810787609645296, 35.06331293923514, 36.56866100856236, 35.92835324151175, 35.252727781023296, 33.42323235103062, 36.32756893975394, 36.03071410315377, 36.74351590020316, 36.90990093776158, 36.58364132472447, 35.79405845914568, 34.533401625497, 36.614671979631694, 37.414326259068076, 37.99946880340576, 36.62636579786028, 35.742638315473286, 36.05460895810808, 35.990758487156455, 36.000267096928184, 35.82894883837019, 34.96499940327236, 36.69172750200544, 37.27674845286778, 40.54000466210501, 43.066161223820274, 44.136225496019634, 43.26840591430664, 45.65141568865095, 44.97366755349295, 49.263040678841726, 47.13362625667027, 48.46314321245466, 48.42075572695051, 48.42678328922817, 46.573629243033274, 49.73941959653582, 53.227151257651194, 53.52010815484183, 55.58919831684658, 56.68709012440273, 2.100246101617813, 3.4470469185284207, 0.3080100608723504, 0.06449007841625384, 5.136985174247196, 51.387257848467144, 53.333681038447786, 43.62689822060721, 26.54195359774998, 43.95740665708269, 49.55054324013846, 33.05098261151995, 49.56974458694458, 52.607028007507324, 12.470037971224103, 0.22299118366624626, 0.03335469162889889, 0.07663560419210366, 0.013457567381140376, 0.03531663831589477, 0.06431022592421089, 0.0711848781044994, 0.01829991303384304, 0.05314570911494749, 0.01661649140130196, 0.06591200283063309, 0.12052802608481475, 0.021799740680892552, 0.09641112733100142, 0.025383352135707225, 0.029956703606460775, 0.052803747821599245, 0.10720255505293608, 0.0700067648930209, 21.76331090927124, 66.01769052233014, 46.40684468405587, 43.125745500837056, 26.758320501872472, 43.525270393916536, 65.54284368242536, 52.288682392665315, 40.71126038687569, 58.98190293993269, 34.07682507378714, 0.28361458278128077, 0.10552123348627772, 0.54269789904356, 0.43575879878231455, 6.721862758908953, 56.15783541543143, 54.59386886869158, 55.26255655288696, 52.25093630381993, 50.893765517643516, 43.115521226610454, 38.930899143218994, 37.19701092583792, 38.84083659308297, 36.538259165627615, 38.50726400102888, 40.34699412754604, 42.31220524651663, 45.75296013695853, 47.548808915274485, 47.51567990439278, 46.893774441310335, 45.19778169904436, 44.00022145680019, 42.264537130083355, 41.16680860519409, 42.121657848358154, 43.74287060328892, 44.90801749910627, 44.66142245701381, 44.38919203622, 44.262720925467356, 38.78522668566023, 36.33969702039446, 35.31707852227347, 34.54328891209194, 35.25470106942313, 36.73555326461792, 36.179593154362266, 37.397886821201865, 35.78823586872646, 35.5326429094587, 35.42240626471383, 36.92090688432966, 38.130157470703125, 37.095365728650776, 38.24233961105347, 35.38004657200405, 36.801971094948904, 36.16538061414446, 38.4538288797651, 36.710439000810894, 38.74081727436611, 40.69174984523228, 42.79686641693115, 43.81475666591099, 41.22912005015782, 41.744110107421875, 38.17673124585833, 36.38614225387573, 36.09471048627581, 36.63236904144287, 38.36990853718349, 41.93570320946829, 46.31216158185686, 46.155896595546174, 50.95306839261736, 44.24355779375349, 44.00902482441494, 49.18669387272426, 47.87625319617135, 39.709757464272634, 38.038257122039795, 41.18840708051409, 43.017551626477925, 45.211924757276265, 47.303711209978374, 52.23914521081107, 49.054361956460134, 49.46375676563808, 48.076722621917725, 44.833022117614746, 47.48453460420881, 47.863722120012554, 40.22599124908447, 35.08706188201904, 37.20050934382847, 36.136715820857454, 36.92341865812029, 35.96865279333932, 37.411331585475374, 38.5920216015407, 38.54495103018624, 36.539509841373985, 34.98604897090367, 36.85635811941964, 38.248579093388145, 37.98587465286255, 38.46380301884243, 37.00536918640137, 37.79841225487845, 36.64424351283482, 38.34150430134365, 39.48248536246163, 40.4539338520595, 38.183887890407014, 38.24777657645089, 37.57922090802874, 38.467600209372385, 36.24863740376064, 37.225217138017925, 37.44834116527012, 38.37722846439907, 40.008964266095845, 43.171391691480366, 44.8766359601702, 46.522768429347444, 46.34580128533499, 48.315355028424946, 48.514031818934846, 50.51042297908238, 49.56393241882324, 51.162313393184114, 49.52996267591204, 50.817161628178184, 48.04969760349819, 52.50082131794521, 54.949460302080425, 56.78446217945644, 55.76977505002703, 60.75477749960763, 2.1225713150841847, 1.9226811953953333, 0.5520240100366729, 0.09694443549960852, 5.909070738724299, 56.97777496065412, 56.61019788469587, 52.01037229810442, 35.899785723005024, 48.60077313014439, 52.08485003880092, 39.64644547871181, 55.54861388887678, 60.79443086896624, 17.44654277392796, 0.21002668647893838, 0.05254042873691235, 0.035375606401690414, 0.017276253052321926, 0.03589548296960337, 0.03623223650668349, 0.03204691716070686, 0.03563412485112037, 0.02207742435192423, 0.1838783353034939, 0.1671701432870967, 0.17991584007229122, 0.09918641698147569, 0.12210002887461867, 0.1190347062157733, 0.17091131396591663, 0.20187935366162232, 0.2167173946010215, 0.16022782080939837, 27.001206942967006, 75.86412865774972, 53.54683787482125, 47.37400266102382, 25.50922199657985, 47.44861936569214, 65.08394990648542, 54.06857810701643, 48.57052067347935, 65.61604990277971, 39.06395714623587, 0.5290988630482129, 0.2577260562351772, 1.9976131745747157, 2.0550752111843655, 8.054907662527901, 57.7918050629752, 56.61188629695347, 58.16812644686018, 54.62207160677229, 52.32079349245344, 44.576664856501985, 41.54442235401699, 38.95958478110177, 40.06485557556152, 38.712611062186106, 41.34179898670742, 41.842166560036794, 44.94040652683803, 47.536743368421284, 50.73811197280884, 49.39776277542114, 50.46380056653704, 47.183128697531565, 48.28945561817714, 44.193423066820415, 43.59097603389195, 43.30274738584246, 45.160052980695454, 47.93335001809256, 46.709581170763286, 47.133528981889995, 46.897995471954346, 40.36152628489903, 39.947198254721506, 36.563821588243755, 35.727852548871724, 36.7789934022086, 38.54839038848877, 37.724087374550955, 38.83906480244228, 37.594604219709126, 38.59374475479126, 35.85690491540091, 38.63286311285836, 40.322685854775564, 39.08595514297485, 39.715854508536204, 35.77930743353707, 37.676933424813406, 37.72774560110909, 40.67019305910383, 40.38964564459664, 40.99514988490513, 42.71802173342024, 46.54044812066214, 46.85802248546055, 43.694545882088796, 44.4407685143607, 40.205660820007324, 37.738383293151855, 40.23054926736014, 40.352253913879395, 40.4719956942967, 44.85094846997942, 49.827818053109304, 49.40677458899361, 53.511693886348176, 47.60323068073818, 45.891010420663015, 50.90860686983381, 49.73155770983015, 41.546906335013254, 41.37366342544556, 42.88564702442714, 43.91340371540615, 48.988746643066406, 49.906728744506836, 54.208598205021445, 50.3633713041033, 50.453986236027305, 51.360931124006, 45.34864446095058, 49.35238756452288, 50.78015899658203, 42.043709482465474, 35.45875576564244, 38.32170193535941, 38.667829922267366, 39.246097224099294, 38.27716745649065, 38.50023242405483, 41.20298440115792, 41.373156206948416, 37.30685499736241, 35.95411368778774, 38.16169881820679, 39.75670644215175, 39.82919004985264, 41.504477160317556, 39.46617794036865, 39.1734607560294, 38.55568947110857, 42.11241674423218, 42.13286529268537, 42.34133209500994, 39.9030876159668, 40.29622711454119, 40.1654828616551, 40.88469089780535, 39.409515380859375, 39.220055375780376, 40.02204424994332, 40.65756818226406, 40.83551502227783, 44.994004930768696, 47.43048456736973, 49.003417764391216, 47.837697642190115, 51.5663719858442, 51.14961903435843, 52.438558510371614, 52.88161734172276, 53.48825066430228, 51.62564011982509, 54.775050095149446, 50.23466287340437, 55.0704527582441, 57.3993638583592, 59.06815092904227, 57.62567710876465, 62.560523986816406, 2.6409355912889754, 5.738610148429871, 1.5057174095085688, 0.18048940572355474, 6.650579452514648, 62.568410192217144, 62.347839627947124, 56.867086683000835, 38.30392149516514, 54.80003581728254, 56.621478285108296, 48.13832535062517, 62.9447454724993, 71.91943481990269, 24.03178484099252, 0.2911784297653607, 0.08895446173846722, 0.21140513036932262, 0.15064078596021446, 0.12290819122322968, 0.19783318149191992, 0.15671706705221108, 0.1523563667599644, 0.11440322973898479], [0.005212632390404386, 0.013213929204669381, 0.02099777166066425, 0.024866746106584157, 0.0718187451628702, 0.025587406275527816, 0.0401286424270698, 0.029970806956823384, 0.07690062639968735, 0.05361960814999683, 21.852048090526036, 55.54095697402954, 42.77139779499599, 36.358446734292166, 19.157560995646886, 45.50331136158535, 60.1210948399135, 39.035104751586914, 39.58523184912545, 54.8577857698713, 32.30232810974121, 0.40524871594139505, 0.046157636413616795, 0.7658839715378625, 0.3613944005753313, 13.160970313208443, 57.89481210708618, 51.32507494517735, 51.70907408850533, 47.42841053009033, 43.72337743214199, 40.57176487786429, 40.68703201838902, 41.3106814793178, 44.05476481573922, 43.66965743473598, 44.83635030473982, 46.09556538718087, 46.60782132829939, 45.35521745681763, 47.09541463851929, 46.85912377493722, 48.189127104622976, 47.283766405923025, 46.195549964904785, 44.722069808415, 44.43930244445801, 42.35862963540213, 44.34111745016915, 42.19773020063128, 41.764638560158865, 43.33650173459734, 39.30715799331665, 36.77110024860927, 32.93376997538975, 35.3420329775129, 34.66741500582014, 34.280007771083284, 35.70185933794294, 35.644362994602744, 33.51195042473929, 33.631184986659456, 33.540733337402344, 34.61044672557286, 34.75105047225952, 35.12760462079729, 34.955716609954834, 35.148101806640625, 34.25241300037929, 34.48772416796003, 34.64044904708862, 35.26666586739676, 35.24585253851754, 36.070892061506, 42.25156831741333, 41.86094406672886, 45.13884013039725, 44.37695278440203, 40.83201660428728, 39.73802968433925, 34.10786962509155, 35.61807101113455, 34.41774191175188, 36.53071689605713, 45.419297218322754, 49.01814794540405, 46.28022766113281, 50.0753858430045, 40.25261674608503, 42.07347903932844, 48.10439382280622, 44.15778228214809, 40.54456615447998, 35.27115440368652, 38.29877635410854, 40.45749480383736, 43.084549631391255, 45.20356260027204, 48.4900918006897, 44.98866524015154, 50.97905118124825, 48.398299149104524, 46.01385109765189, 46.271149839673726, 45.97793238503592, 37.55148369925362, 33.991574151175364, 34.11064543042864, 32.82219927651541, 35.63522611345564, 34.81705488477434, 36.01165519441877, 36.059601238795686, 36.137257780347554, 35.93046201978411, 34.29758323941912, 35.155949796949116, 35.46633277620588, 35.545510973249165, 36.45130940846035, 34.593562602996826, 36.640244824545725, 34.95594242640904, 35.957271644047324, 35.97537864957537, 36.48863165719168, 36.296044962746755, 36.58166456222534, 35.36535808018276, 36.35040766852242, 34.73880079814366, 36.42741107940674, 35.008616719927105, 35.26224333899361, 36.62000124795096, 38.46773222514561, 39.27779838017055, 43.479846545628135, 42.00929505484444, 43.66060045787266, 41.49479137148176, 44.85686486107962, 44.542715958186555, 43.95089619500296, 42.782813685280935, 45.880282402038574, 42.63574811390468, 45.20956931795393, 46.53589357648577, 58.813277108328684, 57.5937431880406, 65.2991703578404, 9.184785502297537, 2.193376281431743, 0.6221890364374433, 0.15408999659121037, 2.9421052592141286, 49.669270583561485, 55.1017404964992, 48.41610738209316, 28.647346360342844, 45.60859741483416, 47.46098715918404, 37.17583629063198, 48.18346432277134, 54.938218116760254, 17.69347654070173, 0.13968450815549918, 0.01706170876111303, 0.029863591638526747, 0.0452176279255322, 0.07523510112826313, 0.08002095789249454, 0.013438113782155727, 0.02552433983821954, 0.038820236921310425, 0.01845662578541253, 0.04144655081576534, 0.018708508162360107, 0.031494345382920334, 0.0638386644423008, 0.025919550863493766, 0.09297233221254178, 0.018098218499549797, 0.05006557742932013, 0.04442238149100116, 25.857361486979894, 62.315023286002024, 48.43030602591378, 39.784447125026155, 19.870958600725444, 50.586894852774485, 67.10908576420375, 43.208658354622976, 43.985911641802105, 60.29355607713972, 36.39167301995413, 0.23059602773615293, 0.05662977608985134, 0.3820762565093381, 0.3882617274565356, 15.269743374415807, 59.00032956259591, 53.07384967803955, 54.213941369737896, 49.71185261862618, 44.31109080995832, 41.46072782788958, 41.73226342882429, 42.39398206983294, 44.54416465759277, 44.64572300229754, 46.79592990875244, 46.63619777134487, 47.7745315687997, 48.186639649527415, 48.21548162187849, 47.64769220352173, 49.92977244513375, 48.44752713612148, 49.75650521687099, 46.8766645022801, 47.12492363793509, 44.61573110307966, 45.267173358372276, 43.313927037375315, 44.063071387154714, 44.37114756447928, 40.813186986105784, 37.61348247528076, 35.15220471790859, 36.80226639338902, 36.667898654937744, 36.083120891026084, 35.64068044934954, 35.819752897535054, 34.68528924669538, 34.34055437360491, 35.32060125895909, 35.94917699268886, 35.944702352796284, 36.09582914624895, 36.72915744781494, 36.6126708984375, 36.889042445591514, 35.9121014050075, 36.62008115223476, 37.06146894182478, 36.115117345537456, 38.33442408697945, 43.43678508486067, 43.37359469277518, 47.837423188345774, 46.27963011605399, 43.45096983228411, 40.69318812234061, 35.88400983810425, 35.79465600422451, 35.35681874411446, 37.75739009039742, 46.56505169187273, 51.47036872591291, 47.72885063716343, 51.34592301504952, 41.76531253542219, 43.45829323359898, 49.90500211715698, 46.212767601013184, 43.14893511363438, 37.6119191305978, 39.82437494822911, 43.67773471559797, 44.70782600130354, 48.36934947967529, 50.14729969842093, 47.616081374032156, 53.6030661719186, 49.208785670144216, 46.159405435834614, 48.547553403036936, 47.104502882276265, 38.75261184147426, 34.99196883610317, 36.69796003614153, 35.2016133580889, 36.438934666769846, 36.620084626334055, 37.11943081447056, 36.86528655460903, 36.986647265298025, 37.776567118508474, 36.66591494424002, 37.01156003134591, 37.674925395420615, 36.78565672465733, 37.78111818858555, 35.662511689322336, 37.43359361376081, 37.335203647613525, 36.54349115916661, 37.63917691367013, 38.639943327222554, 38.231052262442454, 38.19476529530117, 36.845286164964946, 39.442342145102366, 37.117245606013704, 38.414244992392405, 36.114627497536794, 37.66201911653791, 39.1362635748727, 39.918067932128906, 41.883456230163574, 45.0378098487854, 43.94539669581822, 44.52617924554007, 43.52761541094099, 47.00560917173113, 45.80434206553868, 46.64144713538033, 45.184937953948975, 47.50889151436942, 45.0141408102853, 47.56928873062134, 47.13018689836775, 61.924207959856304, 57.50268357140677, 68.62841360909599, 10.60473586831774, 2.1520850913865224, 0.28130254255873816, 0.14864175394177437, 3.233288194452013, 55.68026140757969, 57.83249371392386, 52.770060539245605, 38.96369811466762, 52.81593949454171, 54.75745725631714, 42.845677512032644, 56.21449450084141, 63.240175928388325, 23.003135306494578, 0.10309837492448942, 0.04057458921202591, 0.03280085099062749, 0.01263539498073182, 0.09326920485390083, 0.05037762211369617, 0.059047535460974486, 0.09558688370244843, 0.044640262478164265, 0.06985561443226677, 0.09799146931618452, 0.107974619338555, 0.13245873445911066, 0.22066355070897511, 0.10047880227544478, 0.14837043492921762, 0.10963019050125565, 0.20330642137144292, 0.18751247386847222, 30.90305471420288, 71.08133615766252, 53.78023828778948, 47.01140744345528, 25.596513952527726, 54.391592911311555, 64.55915941510881, 47.29467855181013, 49.38523864746094, 65.80093451908657, 40.99813066210066, 0.48056537019354956, 0.1376837119460106, 3.63316462295396, 1.8421570020062583, 17.054106780460902, 61.011047908238, 55.948882239205496, 57.550716468266074, 52.2156776700701, 48.516501903533936, 44.16903141566685, 44.78806379863194, 44.88597433907645, 47.261803150177, 47.206846373421804, 49.304431097848074, 49.38444307872227, 49.99355690819876, 49.70811448778425, 50.844148431505474, 49.16251414162772, 52.25022063936506, 50.506768226623535, 50.11638368879046, 49.54501942225865, 50.96630818503243, 46.58285992486136, 48.648722648620605, 45.896190302712576, 45.16063315527779, 47.535002844674246, 43.06092575618199, 39.68509135927473, 37.1282376561846, 39.79212141036987, 38.42501817430769, 38.02408627101353, 38.02513197490147, 38.524360043661936, 36.75466775894165, 37.21288061141968, 37.79164123535156, 38.052476610456196, 38.9040721484593, 36.897800649915425, 37.858066013881135, 38.282597473689485, 38.32561724526541, 38.347358158656526, 38.772455896650044, 38.098293031964985, 38.397763865334646, 40.039842060634065, 46.37689099993025, 45.27143260410854, 49.1924261365618, 47.5373443875994, 45.753901617867605, 42.42902183532715, 39.16061701093401, 39.201823302677695, 37.19805662972586, 40.46139621734619, 49.4054023197719, 53.52188341958182, 49.26354442323957, 52.717014517102925, 43.66989714758736, 45.487160273960654, 53.06488650185721, 49.067455836704795, 43.55400466918945, 39.60933167593819, 41.17381933757237, 45.363259996686665, 47.2297545841762, 51.04882499149868, 52.27240971156529, 47.87201132093157, 54.514645508357454, 48.603993620191304, 49.318136419568745, 50.779356479644775, 48.517547607421875, 41.945642607552664, 37.316585949489046, 37.91359601702009, 37.61705732345581, 39.53097684042794, 37.8768504687718, 39.29753821236746, 38.251983710697715, 39.50922203063965, 39.57568849836077, 38.46175677435738, 39.38041285106114, 38.185347012111116, 38.976673875536235, 40.30600322995867, 37.91199445724487, 38.798060008457725, 39.53488172803606, 39.38892786843436, 40.37566934313093, 40.6865109034947, 40.195429597582134, 40.633864402770996, 39.812351090567454, 40.00379480634417, 38.544440337589805, 41.880916663578574, 38.88942881992885, 39.72963973454067, 40.909211090632844, 42.97092226573399, 43.35937173025948, 47.84633077893938, 47.436953340257915, 47.54847887584141, 46.04202256883894, 49.51124422890799, 47.945686544690815, 50.46276528494698, 47.68257563454764, 48.91087123325893, 47.06002746309553, 50.60631506783621, 51.10603993279593, 65.40190642220634, 61.40639345986502, 70.32355172293526, 12.932569129126412, 3.903662553855351, 2.6513285764626096, 0.258301453930991, 3.807193330356053, 59.61988653455462, 63.207839012145996, 59.39188139779227, 41.00669084276472, 57.509676933288574, 56.68146903174264, 51.32536676951817, 62.78130299704415, 72.56140668051583, 29.89212656021118, 0.28075849318078583, 0.12697305024734565, 0.15806923806667328, 0.12680438001241, 0.23176308082682745, 0.1734749956854752, 0.08855348825454712, 0.1514875976634877, 0.11822883731552533], [0.07354777452668973, 0.021408914688176343, 0.03990208297701819, 0.06335360689886979, 0.09573413258684532, 0.016640467436185906, 0.04661876541961517, 0.03273362174097981, 0.08754823183906929, 0.01894748310691544, 23.070710011890956, 50.90026208332607, 46.1574182510376, 38.02449968882969, 28.17461177280971, 41.29180669784546, 42.77398599897112, 34.98221009118216, 41.507537841796875, 55.21182428087507, 29.195027691977366, 0.14447463969034807, 0.07583918728466545, 0.09068760980984994, 0.17284964424158844, 29.274216311318533, 55.36154406411307, 52.56727041516985, 52.677705083574565, 46.896751744406565, 46.62470892497471, 46.89433029719761, 47.87595789773123, 47.91419383457729, 48.45105334690639, 48.570284434727256, 46.58094917024885, 47.810926233019146, 47.24404008047921, 48.93272679192679, 48.13775559834072, 46.00837244306292, 47.42786162240164, 46.65059443882534, 47.445982524326865, 45.9521233013698, 45.44919531685965, 45.44601304190499, 45.8816477230617, 42.144830090659006, 42.72383042744228, 39.61112083707537, 35.00415597643171, 34.8666615486145, 33.753389903477256, 34.58473491668701, 33.82408782414028, 35.12784085954939, 36.01038019997733, 34.61586284637451, 33.06558772495815, 33.60996866226196, 34.78445741108486, 34.66051891871861, 34.15160853522164, 34.082786628178184, 36.21712384905134, 37.005230222429546, 36.38949128559658, 34.65144804545811, 32.99163457325527, 33.88785491670881, 34.11935152326311, 37.59491341454642, 41.20435667037964, 42.78855637141636, 42.408163343157085, 47.03922803061349, 41.41948332105364, 39.443773474012104, 36.32439708709717, 35.363089493342805, 34.52873938424246, 36.82787050519671, 45.03078522000994, 49.37426396778652, 45.892195088522776, 51.50593308040074, 40.93917172295706, 41.46766907828194, 48.64085381371634, 43.266839095524375, 39.25073862075806, 35.05820253917149, 37.24443238122122, 37.74862493787493, 39.99699599402291, 42.45831196648734, 45.92461885724749, 42.63228096280779, 40.05537475858416, 42.402667318071636, 48.927817889622276, 48.47303744724819, 45.35356378555298, 38.77780948366438, 34.85931382860456, 35.04829788208008, 33.452814306531636, 34.9699638911656, 34.94554097311837, 35.52943631580898, 35.38944053649902, 36.3425110408238, 35.35964666094099, 35.30000332423619, 35.953801018851145, 36.551756041390554, 35.30784784044538, 37.174453599112375, 36.23212848390852, 36.249370438711985, 34.6978793825422, 36.551877634865896, 35.533351625714985, 37.43611233575003, 35.79813010351998, 35.82405730656215, 35.70670918055943, 35.20436831883022, 33.93331698008946, 36.480985164642334, 34.93565021242414, 36.45618009567261, 34.90549155644008, 38.278602259499685, 35.8008051599775, 38.72249487468174, 38.08030414581299, 38.37521696090698, 37.55552060263497, 39.49040978295462, 40.2182822227478, 41.31243589946202, 40.572946071624756, 40.93729223523821, 40.70209918703352, 49.04023279462542, 50.619704246520996, 56.296347754342214, 52.9412294115339, 65.51858057294572, 11.496728232928685, 0.6213973760604858, 0.1685660933809621, 0.09609239907669169, 3.5179259266172136, 52.216514928000315, 52.7118797983442, 50.865114620753694, 29.478274481637136, 23.559267384665354, 28.73398344857352, 34.86526148659842, 49.148680278233115, 54.281161717006135, 19.114304985318864, 0.007626434206031263, 0.041050181191946776, 0.012449546783630337, 0.025862328309033598, 0.08667440765670367, 0.03682551020756364, 0.030284904209630828, 0.05205434660560318, 0.039233675093523095, 0.026670636542673622, 0.023005863817940866, 0.03166268652837191, 0.0010492975790319698, 0.13744763604232244, 0.09609889265682016, 0.06761509858603988, 0.041186593872095854, 0.12812200002372265, 0.08556460256555251, 26.536009413855417, 57.587059020996094, 50.84625373567854, 43.00853633880615, 28.853056464876445, 49.7771691594805, 49.245784827641074, 37.49577651705061, 48.04948915754046, 57.264197077069966, 32.56890269688198, 0.13110840905989918, 0.07564990994121347, 0.5022256193416459, 0.1432398280927113, 31.130260808127268, 57.40731259754726, 54.21700552531651, 53.08705472946167, 47.080990178244456, 47.95398964200701, 47.21992288316999, 49.565436703818186, 50.0960567338126, 49.95464352199009, 51.08296149117606, 47.9488479750497, 49.696274757385254, 49.258684158325195, 50.66053186144148, 49.85453387669155, 46.83889756883894, 46.321246351514546, 49.025943824223106, 47.674342019217356, 48.65566389901297, 47.349683965955464, 46.65702847072056, 46.648061820438926, 44.47726740155901, 43.15994800840105, 41.30543211528233, 36.965972900390625, 36.225899423871724, 35.208273206438335, 36.183331285204204, 35.755704402923584, 35.28076376233782, 37.31840290342058, 36.289826325007844, 34.93765476771763, 35.051289081573486, 35.739077363695415, 36.5325859614781, 35.72017131532942, 36.10614374705723, 35.567074707576204, 37.1938772882734, 36.66734627314976, 35.810251235961914, 34.56729146412441, 36.39193705150059, 35.609017508370535, 39.96228626796177, 43.32283810206822, 44.14525120598929, 44.931995732443674, 48.78702654157366, 45.82691328866141, 40.646767207554404, 38.23364394051688, 36.72875097819737, 35.93541955947876, 39.38281692777361, 46.74326603753226, 50.717785017830984, 48.164447103227886, 52.944324834006174, 42.79225628716605, 42.82925544466291, 49.068195819854736, 45.81472962243216, 41.50314310618809, 37.48730666296822, 38.25645835059029, 39.45548466273716, 43.58239500863211, 45.42406368255615, 47.85914673124041, 44.59358719417027, 43.03476578848702, 45.25215482711792, 51.4826774597168, 49.329910142081125, 46.257222175598145, 40.21494361332485, 36.64183596202305, 35.96117305755615, 36.18647187096732, 35.82558938435146, 37.16343028204781, 37.12776517868042, 36.353325911930625, 38.175049781799316, 38.53684595652989, 36.12052304404122, 37.073968751089915, 37.324517318180625, 37.15260846274239, 37.54329872131348, 37.75561482565743, 38.20832123075213, 36.47148697716849, 38.69501822335379, 37.846882888248985, 39.20920923777989, 37.39001798629761, 38.724502904074534, 36.18266773223877, 37.29614087513515, 35.84628111975533, 38.800074986049104, 38.06642164502825, 39.183601651872905, 36.30610595430647, 40.105981963021414, 37.585634095328196, 42.31863580431257, 40.23785877227783, 42.029774870191304, 40.13318068640572, 42.875846590314595, 41.82787411553519, 43.10478278568813, 41.28841945103237, 42.64723001207624, 43.30415439605713, 51.62429564339774, 52.908565929957796, 57.6480781010219, 53.722710677555625, 69.0373706817627, 15.815751927239553, 0.813313786472593, 0.5296668782830238, 0.05473445136366146, 3.9430041228021895, 57.03641428266253, 57.19201224190848, 55.945390769413535, 32.12980433872768, 30.830494676317485, 34.183340958186555, 39.34217344011579, 56.920511381966726, 62.33390848977225, 23.99291835512434, 0.095711306668818, 0.030821377744099925, 0.07506007980555296, 0.01573624658132238, 0.029005594285471097, 0.03312676153810961, 0.04428394338382142, 0.035070170648396015, 0.05954310351184436, 0.21556644993168966, 0.14070627332798072, 0.13460960904402391, 0.14672120128359112, 0.21803721306579454, 0.22524660692683288, 0.1499750345413174, 0.10054191281752926, 0.23242986361895288, 0.23806694256407873, 32.0274886403765, 67.18228503635952, 56.92528479439871, 49.46045637130737, 37.52147790363857, 45.88508013316563, 43.8651693207877, 44.360655784606934, 53.22908980505807, 63.42201723371233, 35.33998325892857, 0.127379818420325, 0.14927899331918784, 2.053555727005005, 0.98471086365836, 32.80577373504639, 59.01276683807373, 58.69069698878697, 56.866992882319856, 49.86831562859671, 51.42184598105294, 49.583227566310335, 52.833653926849365, 51.26188802719116, 53.46223313467843, 53.87976428440639, 50.34655318941389, 52.59145014626639, 50.70738009044102, 51.279922076633994, 50.92999689919608, 46.855906758989605, 48.28323003223964, 50.96729135513306, 50.155620166233604, 49.43489742279053, 49.90940032686506, 49.722427776881624, 49.368660245622905, 47.14941256386893, 45.32041393007551, 43.2459910256522, 38.64793028150286, 39.23962150301252, 37.82188326971871, 37.88190875734602, 36.91120025089809, 36.64583465031215, 39.27838897705078, 37.70479917526245, 36.33689342226301, 38.49130398886544, 38.182706696646555, 38.429739475250244, 38.569266251155305, 37.68095990589687, 38.32820544924055, 40.05164705004011, 39.88682883126395, 38.19072144372122, 36.039545263562886, 36.60233545303345, 37.555833271571565, 40.743034499032156, 45.14000742776053, 46.68537712097168, 47.515381131853374, 48.67504242488316, 46.403342791966026, 42.66798080716814, 39.699296951293945, 39.168621335710796, 39.201993533543174, 42.34737007958548, 48.496984413691926, 52.807893480573384, 50.18271466663906, 56.04340900693621, 43.008821214948384, 47.22228874479021, 51.19443144117083, 48.409200872693745, 43.156255040849956, 39.85149029323033, 40.670839241572786, 41.61107989719936, 44.46477106639317, 47.064884253910606, 49.28134223393032, 47.46397141047886, 45.969962801252095, 47.82749421255929, 49.97394561767578, 50.71027054105486, 48.12202140263149, 42.84612567084176, 39.24220623288836, 38.728414739881245, 38.143216609954834, 37.36883292879377, 38.03373384475708, 39.14492450441633, 37.5898551259722, 39.50682142802647, 40.26261520385742, 38.773981026240754, 38.8676357950483, 38.76346492767334, 37.50124822344099, 39.724720409938264, 39.23172834941319, 40.03038903645107, 37.95257888521467, 40.155119623456685, 40.91079527991158, 41.07121181488037, 39.913777419498985, 40.14700412750244, 39.26652145385742, 39.58285209110805, 36.90876143319266, 41.93390710013253, 39.047239780426025, 42.54187100274222, 38.30171544211251, 42.06448459625244, 39.67418268748692, 43.91864960534232, 42.06125020980835, 44.386054924556184, 42.56931291307722, 44.83592993872506, 45.42534909929548, 45.62442193712507, 44.26348522731236, 45.732344831739155, 45.97073752539498, 54.9526286806379, 55.27285378319876, 60.58516502380371, 56.8158471924918, 71.79694502694267, 21.50426295825413, 1.4434478708675929, 1.2670524333204543, 0.12569469027221203, 4.263527997902461, 63.30585724966866, 61.35148879459926, 62.623294012887136, 39.352515833718435, 34.60264042445591, 39.656753131321494, 46.647502490452354, 63.70935998644148, 71.99045235770089, 29.241198471614293, 0.3727420302374022, 0.13937570686851228, 0.13283526711165905, 0.1241415236145258, 0.21081709835146153, 0.13537277095019817, 0.1424560115805694, 0.21293564752808639, 0.08835049771836825], [0.06986692561102764, 0.016112351756809012, 0.007635232260716813, 0.04592018647651587, 0.0633165995989527, 0.05394447375355022, 0.020575492177158594, 0.017800976056605577, 0.0446215213409492, 0.08134424367121287, 21.55433167730059, 56.814454078674316, 48.54879365648542, 35.55575609207153, 19.0945634160723, 28.576035261154175, 40.09589317866734, 32.12390879222325, 45.64743784495762, 55.122345379420686, 26.066208703177317, 0.016266033153182695, 0.18563312185662134, 0.5371889546513557, 0.9408476459128516, 39.23336812428066, 54.958010060446604, 53.22408710207258, 50.53135095323835, 50.40008558545794, 49.747093881879536, 48.93677759170532, 49.66457707541329, 48.64704813276018, 50.8686477797372, 51.65010820116316, 49.36841705867222, 49.86989286967686, 47.342909472329275, 46.02208471298218, 44.26169606617519, 44.018866947719026, 41.597447531563894, 44.31216083254133, 43.17022092001778, 45.353011403764995, 44.684730189187185, 46.38877589362008, 43.09503793716431, 43.113610471997944, 40.77923113959176, 36.44809239251273, 32.16201271329607, 33.478383677346365, 33.28987904957363, 34.32590757097517, 35.23030941826956, 35.69157600402832, 34.17803948266165, 35.43461077553885, 33.469535146440776, 33.801068442208425, 32.87286901473999, 35.59745223181588, 33.95939704350063, 34.23082494735718, 34.34457390648978, 34.31709030696324, 34.44387756075178, 34.11415427071707, 33.43624980109078, 34.56411613736834, 33.384492669786724, 35.6882860319955, 41.49875184467861, 44.578252519880024, 44.00484200886318, 44.08858169828142, 44.44601093019758, 40.546747888837544, 36.89216218675886, 34.22060762132917, 33.435766901288716, 35.302025250026155, 40.86730650493077, 49.05234350476946, 47.033516611371724, 49.53681707382202, 44.90658269609724, 44.22543689182827, 48.02926295144217, 45.20098829269409, 44.985486439296174, 41.215612752096995, 33.86351190294538, 35.95234884534563, 37.03142840521676, 41.07715252467564, 44.45590516499111, 48.62724576677595, 47.168231759752544, 42.43329150336129, 38.458852427346365, 44.37995440619332, 48.58049133845738, 39.65954630715506, 35.80691262653896, 34.62820284707205, 34.3736104284014, 36.06894309180123, 36.31669500895909, 35.27266216278076, 35.09907531738281, 36.33642789295742, 34.84778676714216, 34.16667570386614, 34.58050693784441, 35.22717925480434, 34.46675450461251, 35.40256915773664, 35.99025126865932, 35.57051406587873, 36.372760023389546, 35.99614334106445, 36.206229073660715, 36.11579826899937, 34.98217535018921, 35.41549628121512, 35.87154129573277, 34.16545976911272, 35.550107206617085, 35.37358822141375, 34.52739838191441, 34.94764280319214, 35.80239977155413, 36.12922913687569, 34.925009046282085, 36.79897294725691, 37.48811265400478, 37.641466345105854, 37.46267877306257, 39.21455587659563, 37.69203880855015, 39.96310268129621, 37.674522399902344, 44.97469936098371, 51.382192611694336, 55.41846718106951, 52.773916789463584, 58.754168782915386, 57.81383432660784, 59.776193210056846, 12.326353566987173, 1.0317309520074298, 0.10832850927753107, 0.058097823922123225, 3.19707961167608, 50.792578901563374, 54.07792343412127, 51.30438320977347, 47.7007486479623, 37.14350632258824, 24.62122310910906, 38.57921607153756, 48.03527314322335, 51.06830774034773, 18.01931405067444, 0.02361409243063203, 0.05373558335538421, 0.048053907696157694, 0.030605359335563014, 0.01824083468610687, 0.07542206466730152, 0.016385160153731704, 0.039703499525785446, 0.013100299185940197, 0.005760018040226507, 0.030238628121359006, 0.02470093759308968, 0.045979425976318974, 0.03313251890774284, 0.023267671465873718, 0.04450492527601974, 0.04060928270752941, 0.05324343512100833, 0.10009141984794821, 26.101024389266968, 62.93047387259347, 52.80934565407889, 40.12519720622471, 21.83276162828718, 29.765853473118373, 38.052028451647075, 36.45999118259975, 48.53387587411063, 58.35769762311663, 28.932467426572526, 0.1105482280254364, 0.07432650881154196, 0.18511045990245684, 1.1316446363925934, 41.280088560921804, 55.6684946332659, 55.3041067804609, 53.311992236546104, 52.02940688814436, 51.257594040461946, 51.336494309561594, 50.17046846662249, 51.350936140332905, 50.61181109292166, 52.09476859228951, 50.637925897325786, 50.38303818021502, 47.38030815124512, 46.31810923985073, 44.20171226773943, 42.98200464248657, 43.179184096200125, 45.512416975838796, 44.03957952771868, 47.735559122903005, 47.10902615955898, 48.012375354766846, 45.82715647561209, 44.67922374180385, 41.39487974984305, 39.04171943664551, 34.9718016896929, 35.76809998920986, 35.2047643661499, 36.018516540527344, 36.71631717681885, 37.641747747148784, 35.63330841064453, 35.58397967474801, 34.64508696964809, 34.92866379874093, 34.58524213518415, 37.21894986288888, 35.9788874898638, 37.138531412397114, 35.99786996841431, 35.687841347285676, 35.809334073747905, 36.58120945521763, 35.41255371911185, 36.09250790732247, 35.95390524183001, 37.86225577763149, 44.36030142647879, 44.79025248118809, 46.553726128169465, 47.56106206348964, 46.95784378051758, 42.3927765573774, 38.59356410162789, 35.96657180786133, 35.711586815970286, 37.110491956983296, 43.135983671460835, 49.173815386635916, 49.468724727630615, 49.01712656021118, 45.64698273794991, 45.56377458572388, 49.39055749348232, 46.83035128457205, 47.154429163251606, 41.3775509425572, 37.01676423209054, 37.93024042674473, 40.11010224478585, 42.389941692352295, 46.05513381958008, 51.12398712975638, 47.82042442049299, 42.09644283567156, 42.388458251953125, 49.06482941763741, 49.31807735988072, 42.62033353533064, 37.245891502925325, 36.31615652356829, 35.07959951673235, 37.99253102711269, 36.93694680077689, 37.38370902197701, 37.16450725282942, 37.204167570386616, 37.22095441818237, 35.04693603515625, 36.46560880116054, 36.43325798852103, 35.31050552640642, 36.47611447743007, 36.595397676740376, 37.720613275255474, 37.37569080080305, 37.64789342880249, 37.086617946624756, 38.249180112566265, 36.27680887494768, 38.37546362195696, 37.91397816794259, 36.58957161222185, 37.611856596810476, 37.988563605717246, 37.50678593771798, 37.110641343253, 37.644554819379536, 37.763619150434224, 38.32103490829468, 38.75030503954206, 40.11955179486956, 39.29577684402466, 39.50055415289742, 41.327107020786826, 39.20405714852469, 41.883345058986116, 39.585624422345845, 47.06086124692644, 53.994287967681885, 56.93976831436157, 54.59695039476667, 61.99336338043213, 60.46978323800223, 61.311564445495605, 19.389919178826467, 1.0932283720799854, 0.30712128856352394, 0.05579749182132738, 3.6860645157950263, 55.110939911433626, 61.000653403145925, 55.174036502838135, 43.26367766516549, 38.92208882740566, 31.13274826322283, 45.92151648657662, 53.268896034785676, 59.845293045043945, 23.329012768609182, 0.11098080767052514, 0.02782034288559641, 0.07040072911019836, 0.02610698089535747, 0.0417460358169462, 0.053413296184901676, 0.040072167957467694, 0.04846175813249179, 0.036113944104207416, 0.15664241462945938, 0.10294972825795412, 0.1654260368751628, 0.1278131173125335, 0.1474367028900555, 0.2461013671542917, 0.14865893444844655, 0.14778419424380573, 0.12322999324117388, 0.22206986881792545, 31.007840497153147, 72.08256462642125, 59.58511080060686, 47.81451497759138, 27.895969901766094, 36.20268896647862, 47.4587185723441, 42.47870492935181, 53.97155346189226, 63.2347354888916, 33.30781929833548, 0.24655487281935556, 0.2425313230071749, 1.4169641605445316, 1.9824040021215166, 42.59941250937325, 57.037630217415945, 57.883048806871685, 54.37504577636719, 53.5758570262364, 53.10890333993094, 53.65082114083426, 53.45277663639614, 54.03604316711426, 53.48049994877407, 54.86172539847237, 51.57863903045654, 50.81336791174752, 47.42007269178118, 47.67911195755005, 46.7898884500776, 44.880315031324116, 42.68101215362549, 45.46889693396432, 43.34202902657645, 49.122176374707905, 48.39760780334473, 49.755341393607004, 48.475229603903635, 46.375473567417686, 44.56204237256731, 40.40265614645821, 35.92188099452427, 37.21329402923584, 36.152033124651226, 36.9598445892334, 38.95690277644566, 40.458012444632395, 38.13979809624808, 39.795612880161826, 36.27468272617885, 36.93791954857962, 35.42041213171822, 39.81565843309675, 38.21711417606899, 38.55538027627127, 38.315003871917725, 36.89966971533639, 36.4335150718689, 36.180218492235454, 36.72914702551705, 36.894326550619944, 38.26310082844326, 39.48547656195504, 46.40391254425049, 46.66498415810721, 48.68943909236363, 47.952666010175435, 49.232426915849956, 44.25211450031826, 41.69471883773804, 38.68850776127407, 39.22707305635725, 38.64680814743042, 44.904248101370676, 52.993511131831575, 50.3244092805045, 52.89022963387625, 49.023303508758545, 49.67119870867048, 52.451885155269075, 50.161762373788015, 50.65965986251831, 45.48595476150513, 37.02887494223458, 38.707128933497835, 41.13661868231637, 43.53436211177281, 49.13880341393607, 53.120482512882774, 49.37624420438494, 46.19886425563267, 46.052823543548584, 47.14215169634138, 50.058373178754536, 44.496694564819336, 38.53427859715053, 38.75927168982369, 36.48344135284424, 40.1825441632952, 41.095756326402935, 39.228962966373985, 39.03192942483084, 39.09838547025408, 38.80265276772635, 36.85161597388131, 38.203474862234934, 37.87557200023106, 36.882236685071675, 38.769256251198904, 39.063429083142964, 38.84779521397182, 40.17891372953142, 40.60237864085606, 40.167466572352815, 40.078018937792095, 37.985270159585134, 39.87727505820138, 38.52150780814034, 38.273106234414236, 39.764512743268696, 40.671217918395996, 39.700307914188926, 39.963575158800396, 40.36086620603289, 41.153561864580425, 40.65661627905709, 42.00786372593471, 44.055928639003206, 41.82306248801095, 41.014841079711914, 42.76530769893101, 41.12818009512765, 44.009966305324006, 41.595304012298584, 50.38395881652832, 56.6080230985369, 58.57398809705462, 58.08573818206787, 62.3600754056658, 62.47165652683803, 63.18812002454485, 27.951616287231445, 1.2093904188701083, 0.8839209462915147, 0.12653775646218232, 3.9172649553843906, 62.517028263636995, 65.43441009521484, 64.59356689453125, 57.530410357883994, 45.89231668199812, 37.28975895472935, 53.130053656441824, 60.96427958352225, 68.40475109645298, 29.02459532873971, 0.19862402762685502, 0.0909245949504631, 0.2666529715061188, 0.18026244933051722, 0.05333142075687647, 0.1290383887078081, 0.14464268567306654, 0.17579836744282926, 0.17139099751199993], [0.04977223317005804, 0.01659216931355851, 0.021655731801209704, 0.01968390734067985, 0.06247875134327582, 0.03816604773913111, 0.021490318534363593, 0.007391008847792233, 0.04268501971715263, 0.05997748127473252, 20.159765686307633, 58.57696887425014, 46.920264448438374, 40.99555288042341, 21.278880766459874, 20.658832209450857, 26.15114869390215, 31.75781168256487, 45.17532164709908, 56.26997586659023, 22.879083905901226, 0.07131751134459462, 0.10975286963262729, 0.45033256390265053, 1.8574215429169791, 44.637951442173545, 50.79089048930577, 51.89469173976353, 52.63184002467564, 51.647113527570454, 50.415750299181255, 49.63991444451468, 50.11026579993111, 50.04632500239781, 49.89456592287336, 47.55947092601231, 45.26117358888899, 45.567922660282676, 45.409573214394705, 44.60441943577358, 44.06485360009329, 46.28760664803641, 46.44392374583653, 46.355560030256, 46.425528390066965, 47.56935126440865, 45.39323105130877, 45.4211801801409, 42.93833174024309, 39.523590905325754, 35.4720025062561, 32.039752210889546, 32.270679065159385, 33.94764069148472, 33.65860257829939, 34.28805031095232, 33.3785137448992, 33.939719745091026, 34.27019691467285, 33.270048890795024, 32.180237838200156, 33.59083332334246, 35.796215874808176, 33.841920375823975, 33.91338954653059, 33.69114794049944, 34.824670110430034, 34.11920213699341, 33.894622462136404, 33.79842465264456, 33.65831075395857, 33.04137672696795, 32.396743706294465, 34.63399764469692, 41.84542179107666, 44.58975873674665, 42.366727760859895, 42.16100549697876, 45.058949742998394, 41.80534110750471, 37.279833453042166, 34.00079788480486, 33.12729467664446, 35.42071785245623, 37.35517971856253, 44.67227554321289, 45.475799969264436, 47.65938254765102, 45.72524029867989, 45.754742349897114, 47.35515219824654, 45.703495911189485, 47.76548501423427, 46.29337017876761, 40.094031061444966, 36.33872079849243, 36.8098156111581, 37.53419310706002, 41.441060951777864, 44.660376753125874, 45.186164311000276, 47.48471873147147, 45.65820060457502, 34.18970550809588, 48.42312853676932, 43.03227833339146, 34.199763025556294, 35.516370228358674, 33.72970002038138, 34.053871699741904, 35.01940379823957, 34.232054778507774, 34.533773354121614, 34.57898875645229, 35.77479805265154, 35.05223751068115, 35.84191765104021, 35.29696348735264, 34.53288745880127, 37.7384215082441, 37.09962844848633, 34.734871591840474, 35.20747763769967, 36.95933737073626, 34.265791756766184, 35.737138816288535, 35.74839489800589, 35.36402750015259, 35.932619435446604, 36.28428166253226, 36.669159752982004, 36.234536034720286, 38.16611439841134, 36.93127359662737, 37.42870208195278, 37.793590205056326, 36.76061194283621, 37.52174540928432, 37.90704386574881, 37.68380171912057, 36.83989436285836, 38.60458394459316, 36.62011589322771, 39.252229009355815, 40.16580595288958, 48.79686519077846, 52.19145277568272, 56.285063879830496, 56.80622393744332, 58.25758450371878, 54.45729160308838, 56.07284157616751, 18.96169475146702, 0.5196820454938071, 0.32073210392679485, 0.1809529944189957, 2.082115645919527, 47.46626431601388, 57.110725266592844, 51.49725478036063, 48.054571764809744, 37.651530810764854, 22.668546540396555, 36.578930446079795, 50.592647961207796, 57.448664801461355, 16.895396028246196, 0.08682350894170147, 0.04183446589325156, 0.04488747653418353, 0.04628106871885913, 0.015321831318682857, 0.02467395395173558, 0.04297293908894062, 0.0377488131634891, 0.03165432019159198, 0.015843768936714957, 0.06373767807547535, 0.02878316372100796, 0.02461239555850625, 0.06380247138440609, 0.04447175509163311, 0.008310076048863786, 0.01984014511773629, 0.03207366840381708, 0.1259186611111675, 24.49058829035078, 65.17894567762102, 53.683515889304026, 47.72325733729771, 28.780062164579117, 23.20541647502354, 32.06842047827584, 37.9354897907802, 49.36779172079903, 58.945695877075195, 25.221573523112706, 0.03354094609884279, 0.06033462139644793, 0.4130802314196314, 2.326085137469428, 46.9479113306318, 52.39009829929897, 52.88980579376221, 52.45626252038138, 55.017802783421104, 50.102403913225444, 51.0005384853908, 49.61792687007359, 50.65040833609444, 50.342373847961426, 48.49791199820382, 46.85024050303868, 47.54674530029297, 44.70811782564436, 46.39678021839687, 45.848032338278635, 45.60999747685024, 46.19058200291225, 47.344677788870676, 47.82208851405552, 47.23265545708792, 47.11681509017944, 47.13606507437569, 44.69375589915684, 42.100451946258545, 36.662409578050884, 34.75980520248413, 34.046120984213694, 35.49004002979824, 35.13863836015974, 36.24798427309309, 35.6527008329119, 35.66766725267683, 34.86553594044277, 36.25430365971157, 33.29496513094221, 34.5283329146249, 35.47465671811785, 35.551708766392295, 35.66074684688023, 36.086973667144775, 36.121985639844624, 36.957089628492085, 36.13355786459786, 36.205857345036094, 35.31852374758039, 34.2520204271589, 36.112629890441895, 36.74062544958932, 42.7803053855896, 45.696471282414024, 42.88910027912685, 46.023901666913716, 47.95461845397949, 42.68799161911011, 39.85185159955706, 35.4933682169233, 35.51032529558454, 36.11130278451102, 40.06176362718855, 45.47975696836199, 44.7093893459865, 48.957024642399375, 47.69407837731497, 46.19834661483765, 50.163485527038574, 48.026824133736746, 48.88642747061593, 47.753937108176096, 40.50784839902605, 37.76745455605643, 38.69122798102242, 39.74570744378226, 43.69064794267927, 48.03951154436384, 48.26688092095511, 48.679232188633506, 44.64947502953665, 38.74170316968645, 50.882439953940256, 44.37644904000418, 35.45214455468314, 36.19360419682094, 35.56845392499651, 35.875835282461985, 37.06531476974487, 36.90399496895926, 37.281386375427246, 37.36541441508702, 37.190246854509624, 36.6234301839556, 37.34646667752947, 36.17791863850185, 36.910741669791086, 39.125994137355256, 37.661136695316856, 38.42976031984602, 37.69071170261928, 37.53044802801949, 35.95350224631173, 38.43304334368025, 37.71470035825457, 38.21898324148995, 37.853862353733604, 38.162681988307405, 37.71238660812378, 38.018517289842876, 39.21654306139265, 39.182701860155376, 38.21358101708548, 39.76676395961216, 38.91791990825108, 40.673660210200715, 40.64972366605486, 40.323175702776226, 39.44923823220389, 40.482980796269004, 40.16048015866961, 41.0273825781686, 42.66363818304879, 50.68586499350411, 55.11393805912563, 58.57708004542759, 59.50936848776681, 59.74528762272426, 55.67757592882429, 56.419504574366975, 25.51833282198225, 1.141406855412892, 0.4449625020580632, 0.04438879740025316, 2.1040111567292894, 52.3009146962847, 59.99531854901995, 57.81484528950283, 49.27456079210554, 44.993848596300396, 27.516815389905656, 42.45405272075108, 57.649168968200684, 65.56021417890275, 20.980809995106288, 0.11300200064267431, 0.04109288818602051, 0.07573864196560212, 0.022267300502530167, 0.02163941812302385, 0.0344069433797683, 0.07613543567380734, 0.07025086108062949, 0.04726608443473067, 0.11647908549223628, 0.14525165728160314, 0.11692184316260473, 0.16454140362995012, 0.09281454567930528, 0.10386793541588954, 0.07985166340534176, 0.12982021032699517, 0.19937429736767495, 0.1676586749298232, 28.73841118812561, 72.17995057787213, 59.304118701389854, 54.86558164869036, 30.73002025059291, 28.278221573148453, 36.6010674067906, 41.17799520492554, 54.33553484507969, 63.89619009835379, 27.8302138873509, 0.1987636158508914, 0.4584148930651801, 1.6526775636843272, 3.4105610592024664, 48.77059752600533, 53.7831461088998, 54.514999866485596, 55.990050315856934, 57.26249476841518, 51.4214950970241, 52.2852395602635, 50.99525090626308, 51.56084816796439, 50.52418041229248, 48.77925498144967, 46.30451161520821, 48.83811664581299, 48.05082321166992, 49.31249795641218, 48.44715193339756, 48.480423382350374, 48.685336181095664, 49.385252543858115, 48.99383272443499, 49.71024063655308, 47.904198850904194, 49.513794217790874, 46.8918011529105, 44.97073541368757, 38.56536831174578, 36.1339156968253, 35.206358977726524, 38.015077931540354, 37.11172178813389, 37.32576451982771, 37.92786761692592, 36.36537061418806, 36.392465114593506, 38.21829884392874, 36.17738362721035, 36.579100676945274, 38.683779512132915, 37.29499094826834, 37.4697242464338, 37.605783871241975, 38.25810507365635, 37.53715998785836, 37.4726494380406, 36.35062306267874, 36.987463678632466, 35.161084515707834, 36.402154377528596, 37.77073757989066, 45.3897465297154, 46.870932238442556, 45.17675297600882, 45.65232937676566, 49.49424198695591, 45.65158591951643, 41.539256368364605, 38.26800625664847, 37.4838673046657, 38.962061813899446, 41.06940875734602, 47.376636028289795, 47.409907477242605, 51.17244734082903, 49.36010006495884, 51.194608620234895, 52.012157985142295, 50.69808687482561, 52.452861377171104, 49.21305186407906, 43.803062847682405, 40.612793990543906, 41.556296825408936, 41.89710596629551, 46.75526557649885, 50.63404185431344, 49.584394863673616, 48.6861560685294, 48.06646013259888, 38.28315680367606, 51.784771238054546, 45.70732436861311, 36.17576469693865, 38.74534055164882, 37.401822975703645, 39.00628014973232, 38.072445733206614, 38.09839030674526, 38.77794844763619, 37.839639391217915, 38.78227717535836, 38.9765488079616, 40.07628536224365, 38.26304176875523, 38.29120976584298, 40.227116857256206, 40.05321734292166, 39.670482771737234, 39.407569885253906, 40.06571020398821, 37.61596993037632, 40.02737351826259, 40.260534218379426, 39.047316210610525, 40.81981904166085, 40.6998028073992, 40.41357871464321, 40.74556016921997, 42.30947807856968, 40.45296457835606, 42.09866278512137, 40.81577866418021, 40.59620516640799, 41.4993702343532, 43.67431967599051, 41.49469757080078, 40.70459706442696, 42.52841929027012, 42.33967842374529, 42.47951092038836, 44.299713134765625, 52.59737001146589, 56.15121030807495, 59.48359761919294, 62.851959228515625, 62.122252464294434, 59.554816654750276, 56.82854502541678, 32.363041469029014, 1.3855144424097878, 0.9881077728101185, 0.24184958530323847, 2.5606552362442017, 58.32677813938686, 65.13937568664551, 64.15592070988247, 60.300566809517996, 47.154873847961426, 33.36351258414132, 50.8003191947937, 63.856404713221956, 74.89376408713204, 28.445779119219097, 0.4325767952416624, 0.09085484833589622, 0.12069958687892982, 0.09645549673587084, 0.16362367144652776, 0.08844923134893179, 0.14385052318019526, 0.19985942276460783, 0.11613285621362072], [0.007876576140656002, 0.008829971276489752, 0.0186925965161728, 0.03248304893661823, 0.04704731795936823, 0.04356146304469023, 0.00950895921726312, 0.06605975383094378, 0.035735206212848425, 0.03370612866378256, 17.184764180864605, 50.81225272587368, 41.894750526973176, 35.61987754276821, 18.559571232114518, 23.553807837622507, 23.08780084337507, 32.78553015845162, 44.889514446258545, 56.040782587868826, 23.492682797568186, 0.05728814844042063, 0.06468987983784505, 0.43065648685608593, 3.5742445502962386, 46.75358063834054, 52.4911459514073, 49.981751918792725, 50.79153667177473, 48.68419320242745, 46.93693317685808, 48.19068002700806, 48.24637678691319, 46.70007950919015, 45.54047727584839, 47.02775308064052, 48.55879558835711, 48.551333223070415, 46.589005606515066, 50.06562014988491, 48.87759978430611, 48.58809266771589, 47.31934118270874, 47.04863936560494, 46.188379423958914, 46.8521408353533, 45.06018999644688, 41.46220779418945, 37.27408034460885, 34.39230803080967, 32.69052049091884, 33.53141927719116, 32.814973149980815, 32.96131958280291, 35.12562438419887, 33.98738438742501, 34.83915710449219, 34.1030718939645, 33.39144434247698, 31.581198896680558, 33.73545660291399, 33.82601594924927, 34.012154715401785, 33.126631123679026, 33.43733719417027, 34.1602520942688, 34.56960868835449, 33.5319264956883, 33.70321348735264, 33.80045005253383, 34.220687525612966, 33.112488065447124, 34.474390574863975, 34.414365087236675, 39.71673692975725, 45.30569764545986, 45.56285742350987, 43.055916104997905, 45.26520701817104, 43.42572355270386, 36.96842214039394, 34.436043466840474, 32.71481139319283, 35.02999980109078, 35.02448640550886, 39.91886350086757, 45.21597555705479, 49.68058919906616, 47.10628162111555, 40.748245647975374, 43.0486204964774, 45.176680019923616, 48.17142309461321, 47.29140942437308, 44.973320143563406, 35.73780584335327, 35.74536200932094, 36.76893935884748, 37.86209944316319, 42.06478336879185, 44.876899991716655, 44.2812830380031, 47.947750159672324, 41.2870853969029, 40.58879491261074, 44.183254378182546, 36.699617181505474, 36.67126505715506, 33.42499024527413, 34.021468775612966, 36.09938314982823, 35.43346432277134, 35.10890007019043, 33.673666272844585, 36.29992553165981, 33.87189837864467, 34.44708068030221, 34.32539687837873, 33.637935161590576, 36.87238413946969, 36.570509229387554, 36.277163233075825, 35.772651059286936, 34.683427129473, 34.92983109610421, 36.59224319458008, 34.03909982953753, 35.495053155081614, 35.384371825626914, 36.320374080113, 36.63068757738386, 37.172386510031565, 37.29230546951294, 37.56336164474487, 36.93561274664742, 36.98298903873989, 36.94921384538923, 35.88979421343122, 35.78992428098406, 35.94277770178658, 36.75666536603655, 38.10743686131069, 37.75500338418143, 39.143889222826274, 41.2002398627145, 48.96234001432146, 52.66518790381295, 55.40019341877529, 54.88105876105172, 56.618511404309956, 56.96304825374058, 59.69332204546247, 29.812382084982737, 1.0964222635541643, 0.3943526920463358, 0.06426863172756773, 0.7489682020885604, 40.39281054905483, 59.426316670009065, 48.39055190767561, 45.258453369140625, 20.077672719955444, 23.58858530861991, 35.82369947433472, 44.08951275689261, 54.157188483646934, 18.777624811444962, 0.09704528615943023, 0.03190225349473102, 0.024030434732724513, 0.019221748657790676, 0.06095246824302843, 0.05435304682967918, 0.022262038463460546, 0.04874046978407672, 0.014701658793325936, 0.04740571337086814, 0.04797226297003882, 0.007019803119224629, 0.03345481286357556, 0.04783412002559219, 0.04682118598637836, 0.0516464893839189, 0.047631170201514444, 0.031240434186267, 0.09004118306828396, 22.69515814099993, 58.67933668409075, 48.983198506491526, 42.24916076660156, 18.67513367107936, 23.997624022620066, 22.120564699172974, 34.946155888693674, 50.369676794324604, 58.41082354954311, 26.405171360288346, 0.03822987074298518, 0.05303223431110382, 0.3056116024298327, 4.100520219121661, 47.298361097063335, 53.82727411815098, 51.05000965935843, 50.98402956553868, 49.60650750568935, 47.43524060930525, 48.92453486578805, 49.37659856251308, 48.331936904362266, 46.68547786985125, 49.529806341443745, 48.32554108755929, 51.447206905909944, 49.46644571849278, 49.658441816057476, 49.339967659541536, 50.617619786943706, 49.10328074863979, 49.418499674115864, 46.75121130262102, 47.637808391026084, 45.94527932575771, 43.04065786089216, 38.78060960769653, 35.45511838368007, 34.44995723451887, 34.82670245851789, 34.97960104261126, 34.437860420772004, 36.66207953861782, 36.262679713112966, 35.92953790937151, 35.58666862760271, 34.28416279384068, 34.4706837109157, 34.07428898130144, 34.982651301792686, 35.04360089983259, 35.16924170085362, 36.02566276277815, 36.1512827192034, 35.80379983357021, 35.09251274381365, 35.88233879634312, 34.7955675806318, 34.56342131750924, 36.13015324728829, 34.794118881225586, 36.16899020331246, 41.51075485774449, 47.57765088762556, 46.90073306219918, 46.748272214617046, 47.29173251560756, 44.98307194028582, 39.345039572034565, 35.89217397144863, 34.62100798743111, 37.360936301095144, 37.583796296800884, 42.42100361415318, 47.294074058532715, 49.31844908850533, 48.18147018977574, 42.42539487566267, 44.48482009342739, 46.95724276133946, 49.78146314620972, 49.12497302464077, 47.16700192860195, 38.13723421096802, 37.52616793768746, 38.44756507873535, 41.445497376578196, 43.13751574925014, 47.459951877593994, 45.593606676374165, 48.96923957552229, 42.15257385798863, 43.97924484525408, 45.91044800622122, 36.8076616695949, 36.12510885511126, 34.671973024095806, 34.33475957598005, 37.22535262789045, 36.95394556862967, 37.13460220609392, 35.84251867021833, 36.7767665045602, 35.54421166011265, 35.83568511690412, 35.72612244742257, 35.20741162981306, 39.06594433103289, 39.502822739737375, 38.33191578728812, 37.26654849733625, 37.13344185692923, 37.27530322756086, 38.75959825515747, 36.19049140385219, 37.462543283190044, 36.65842826025826, 38.53607818058559, 38.5073994909014, 39.18621417454311, 39.89569125856672, 38.92221736907959, 38.15533079419817, 38.196863651275635, 38.82761764526367, 37.361210754939485, 38.130671637398855, 38.905534744262695, 39.27857310431344, 39.44572939191546, 39.622220584324424, 40.611070837293354, 41.74471460069929, 50.03395026070731, 55.12175825663975, 57.822585582733154, 57.75784226826259, 58.34059115818569, 59.32621397290911, 60.53659016745431, 32.81787402289254, 1.4282198079994746, 0.20072642767003604, 0.022878796261336123, 0.7524049005338124, 46.18046542576381, 63.640148980276926, 52.88718284879412, 46.79741334915161, 25.240628957748413, 26.79693511554173, 39.60301228931972, 51.629739556993755, 62.57947172437395, 23.788665635245188, 0.16415174811014108, 0.03386759285682014, 0.1295643076300621, 0.04884760367817112, 0.01733087851399822, 0.04080955910363367, 0.06949376527752195, 0.03498405098382916, 0.09928165615669318, 0.14833390260381357, 0.09331031050533056, 0.09566937320466552, 0.10094712714531592, 0.17398950164871557, 0.08123450420264687, 0.1598358175584248, 0.09551323551152434, 0.14866400989038603, 0.18187576133225644, 26.310081788471766, 66.54671246664864, 54.65177862984793, 47.27957664217268, 26.930020911352976, 33.58783170155117, 31.632452283586773, 43.11176919937134, 54.65799726758684, 63.32629884992327, 29.495002269744873, 0.10848305241337844, 0.19568982507501329, 0.9815778774874551, 4.7928977864129205, 49.418353761945454, 54.0780485016959, 52.96651043210711, 52.28192874363491, 51.4019706589835, 48.555130413600374, 50.144207750047954, 49.2864213671003, 48.78733573641096, 48.74252332959856, 51.51898874555315, 50.44704845973423, 53.55933768408639, 50.25280114582607, 53.570955072130474, 51.51140478679112, 53.50070183617728, 50.740467412131174, 53.15726627622332, 48.48994241441999, 49.6130805015564, 48.03066301345825, 43.81930078778948, 39.70726653507778, 36.95791646412441, 35.55635363715035, 37.12513528551374, 36.55236400876726, 35.807565757206504, 38.07814673015049, 38.146329402923584, 39.63525193078177, 37.84792511803763, 35.93047939028059, 34.35466616494315, 35.59409972599575, 36.7837563923427, 36.81318548747471, 37.91857440131051, 37.23666776929583, 37.908280645098, 38.55222579411098, 36.95539426803589, 37.65702336175101, 36.592958859034944, 36.24294682911464, 36.3066930770874, 37.048465388161794, 39.597318240574424, 42.91571535382952, 48.44721099308559, 49.23350388663155, 47.16816227776663, 48.82331003461565, 46.72467960630144, 40.675873211451936, 38.68008654458182, 37.06032248905727, 38.348584515707834, 39.2662296295166, 44.391314710889546, 49.144900458199636, 51.78124850136893, 51.144150802067344, 43.48730196271624, 44.94392926352364, 49.64667851584298, 51.00052458899361, 50.81051220212664, 49.79552977425711, 39.75124168395996, 39.60759115219116, 41.869632789066856, 42.042646408081055, 45.73652764729091, 48.75234808240618, 47.67333105632237, 50.882294041769846, 44.1608429636274, 44.769150802067344, 47.65911504200527, 39.118889604296, 39.78575686046055, 36.07947656086513, 36.57606084006173, 40.303630420139854, 39.05828046798706, 39.13105590002877, 37.675561155591694, 38.98879848207746, 37.5186882019043, 37.900873865400044, 37.10266481127058, 35.8753593308585, 39.904303550720215, 40.79353748049055, 39.471910204206196, 40.15511267525809, 40.39012854439871, 37.96501268659319, 41.876056398664204, 38.51432684489659, 38.24182544435774, 39.03176614216396, 39.58767761502947, 40.72635187421526, 40.94607475825718, 41.92036853517805, 40.20177330289568, 39.73611198152815, 40.18824168613979, 41.203786918095176, 39.51855346134731, 40.46514824458531, 41.099067143031526, 41.418329920087544, 41.6377158164978, 42.311555589948384, 42.96948051452637, 44.83764961787632, 52.64636870792934, 56.722543307713096, 58.23756674357823, 59.660505703517366, 60.488730975559776, 63.47090475899832, 61.61799389975411, 39.70838866915022, 2.0442646827016557, 0.47629097955567495, 0.13352444155939988, 0.8153796270489693, 50.61973203931536, 67.48004313877651, 59.237971850803916, 57.474261965070454, 28.742760760443552, 36.968140738351, 51.83716412952968, 60.753756114414756, 70.97318049839565, 31.63740634918213, 0.4398574217089585, 0.16208750887640885, 0.16218987266932214, 0.1044307259310569, 0.12051526962646417, 0.09807485448462622, 0.13519741035997868, 0.13663492750908646, 0.17021744405584677], [0.02414818261084812, 0.02285687788389623, 0.06073643626379115, 0.012809081285792803, 0.020418177225760052, 0.041534051299095154, 0.06984165018158299, 0.04234902953196849, 0.11210553374673639, 0.06907003372907639, 20.695911271231516, 52.53915105547224, 42.58516175406319, 34.31120865685599, 26.30596498080662, 51.8363025529044, 59.47645487104143, 40.96811097008841, 40.96605430330549, 54.92268541881016, 29.2959919657026, 0.13690803785409245, 0.06398603546300105, 0.21341773308813572, 3.9890550460134233, 42.80026756014143, 52.463050910404746, 49.58440181187221, 50.22815588542393, 50.86094570159912, 48.89241681780134, 48.31082132884434, 47.91842181341988, 50.09340252195086, 49.19255815233503, 48.510043552943635, 49.81577682495117, 47.931682450430735, 45.103602341243196, 42.436049938201904, 41.04527766363961, 41.113370009831016, 38.941130365644185, 38.43910912105015, 37.958137444087434, 37.34782157625471, 35.96894809177944, 34.275925704411094, 32.9485626901899, 33.33661263329642, 33.75195510046822, 31.80710220336914, 34.62833138874599, 33.91354588099888, 34.41138431004116, 33.31942278998238, 33.87933989933559, 33.37130151476179, 33.173854555402485, 33.3400867325919, 33.2560065814427, 32.76787478583199, 33.21198974336897, 32.9231253351484, 33.26858629499163, 34.825965949467246, 34.29857335771833, 33.34131308964321, 31.968460219247, 34.17565972464425, 34.46706369944981, 34.0148332459586, 35.160535608019146, 34.05895778111049, 38.11842196328299, 44.41664089475359, 44.265566212790354, 42.671027592250276, 44.604217938014436, 44.01565340587071, 37.23918301718575, 34.78133766991751, 33.08024842398507, 35.27089384623936, 34.31903232846941, 41.14479671205793, 45.68300914764404, 45.01141711643764, 48.768766675676616, 41.66091932569231, 41.127620765141074, 46.403050967625205, 46.682646478925435, 46.36360951832363, 41.768463543483186, 36.02543347222464, 36.912239006587434, 36.0467574937003, 37.319278376443044, 39.04837581089565, 41.918339661189485, 44.323125089917866, 44.20027051653181, 43.85002224785941, 44.10306174414498, 41.83909893035889, 36.73558105741228, 35.418553488595144, 34.24089983531407, 32.87832335063389, 33.90996755872454, 34.131083556583945, 35.54352378845215, 34.78357151576451, 35.96225002833775, 34.82410035814558, 33.58217239379883, 34.71386023930141, 33.91342428752354, 34.47013827732631, 35.258394036974224, 34.51404047012329, 35.216590200151714, 34.50905166353498, 35.005865233285085, 35.66374499457223, 35.23875147955758, 36.79033286230904, 34.7355420930045, 33.74893263408116, 35.549926553453716, 37.12136241367885, 37.00369814464024, 36.949748856680735, 38.74203668321882, 37.92866318566458, 36.63432843344552, 37.472190856933594, 37.821389947618755, 38.01925727299282, 37.388103757585796, 38.21750327519008, 39.32063055038452, 40.09002195085798, 39.73461811883109, 43.46939298084804, 48.885301862444194, 51.93851055417742, 53.54555245808193, 57.25941671643938, 54.74269233431135, 62.74713175637381, 25.71226225580488, 0.4701205992272922, 0.24644302310688154, 0.007437312077464802, 0.9877166109425681, 38.88930722645351, 60.452280725751606, 51.27312673841204, 49.5359068598066, 26.58437235014779, 20.075153997966222, 36.973150389535085, 48.67299965449742, 49.60020201546805, 19.96056604385376, 0.17513956422252314, 0.06140540393867663, 0.013665881872709309, 0.060290055216423104, 0.04114089793126498, 0.055189117323607206, 0.030911816284060478, 0.07219064342124121, 0.014993917396558183, 0.02134397379787905, 0.03857968607917428, 0.03712977209527578, 0.028231277263590267, 0.03987183388588684, 0.031881541213286776, 0.0679861893877387, 0.016106606261538606, 0.029409400653094053, 0.0807526425591537, 24.32900619506836, 56.925482818058555, 47.72009938103812, 37.58059665134975, 32.657857009342735, 45.934315068381174, 46.217964853559224, 40.20051915305001, 45.778734479631694, 58.388144629342214, 31.643520763942174, 0.05542040955541389, 0.05108738670657788, 0.38268902791397913, 4.583453025136675, 44.097902706691194, 52.76609311785017, 50.490610190800254, 51.93220158985683, 50.79389558519636, 49.54526955740792, 49.86524452481951, 48.70195974622454, 51.93271228245327, 49.830340249197825, 50.594207831791465, 50.41437455586025, 48.95057324000767, 47.83129140308925, 45.34608404976981, 44.30937807900565, 43.97039631434849, 41.119845730917795, 40.85157578332083, 40.497287137167795, 40.02494164875576, 37.96620430265154, 35.57652773175921, 34.580878666469026, 34.87916830607823, 34.67322022574288, 34.44507959910801, 34.575417382376536, 35.94047089985439, 35.1226783479963, 34.50966657911028, 35.00070966993059, 35.786498819078716, 34.998781544821604, 34.48370116097586, 34.700898374829976, 33.67006363187517, 35.46326862062727, 34.58926166806902, 34.636874198913574, 36.052225725991384, 35.133455004010884, 35.24938917160034, 33.885499477386475, 34.656641823904856, 35.444331305367605, 35.52756725038801, 37.614100864955354, 35.357551779065815, 39.7888696534293, 45.87681872504098, 46.74945340837751, 44.94160509109497, 46.24599388667515, 46.70992858069283, 39.738356249673025, 36.13984251022339, 34.27659273147583, 37.87334510258266, 36.82363905225481, 42.760353633335654, 47.85631186621529, 47.97186040878296, 50.131749629974365, 43.91772549492972, 43.064295632498606, 48.35372992924282, 48.6185987336295, 48.16849790300642, 44.26461083548409, 38.73399066925049, 36.802853516169954, 39.90472044263567, 39.39487205232893, 41.27892126355852, 42.84788703918457, 47.02203123910086, 46.61648920604161, 47.53018079485212, 46.89500079836164, 44.854683126722065, 38.71065167018345, 37.2748099054609, 35.502230644226074, 35.280319077628, 36.89576135362898, 36.637173720768516, 36.72722584860665, 35.527706214359824, 37.70413909639631, 35.957632950374055, 35.20014728818621, 36.12097120285034, 34.86772462299892, 37.189569405147004, 37.093312535967144, 36.8945106778826, 37.27513647079468, 36.90925822939192, 36.39124570574079, 36.98496927533831, 37.053224904196604, 38.078716482434956, 36.84227759497506, 36.61538069588797, 37.777091707502095, 38.42327070236206, 38.92322833197457, 38.45407901491438, 39.546314988817485, 38.292922496795654, 39.24196999413626, 38.532538073403494, 40.50638232912336, 41.40341908591134, 40.056024415152415, 40.000345025743755, 40.6869660105024, 42.430706773485454, 41.52481453759329, 46.43895925794329, 50.121143204825266, 54.895514488220215, 55.651169300079346, 58.24898263386318, 56.41485275541033, 65.5076163155692, 28.805082627705165, 0.35568270991955486, 0.3252605109342507, 0.054341101220675876, 0.9525988953454154, 42.29247236251831, 63.93953990936279, 54.274269104003906, 53.600728103092735, 30.069006851741246, 27.366748196738108, 44.41296182359968, 54.67230013438633, 57.777873924800325, 24.402478184018815, 0.30681757628917694, 0.038199747180832286, 0.04470684372686914, 0.034192112407514026, 0.005497773161291012, 0.01531579066067934, 0.025250425429216454, 0.05192788124882749, 0.02785414071487529, 0.14481568496142114, 0.10870074001806122, 0.12626985726611956, 0.0934982511347958, 0.12489172550184385, 0.26332274877599304, 0.21838631933288916, 0.12892352629985127, 0.22691903289939674, 0.09717096441558429, 28.96643716948373, 66.01478617531913, 55.525313104902, 46.14638451167515, 37.040301254817415, 61.38414532797677, 66.46714864458356, 50.06618990216936, 49.289888518197195, 61.847041266305105, 35.099318504333496, 0.21422679110297135, 0.22647662806723798, 0.613647094794682, 5.224621066025325, 46.773407323019846, 54.1283916745867, 52.58018364225115, 53.891583170209614, 54.11197655541556, 52.04313652856009, 52.14821413585118, 51.14338302612305, 55.343207768031526, 52.65980652400425, 50.94384118488857, 54.43802077429635, 52.211995124816895, 49.85043791362217, 46.761512007032124, 45.13116931915283, 44.674971444266184, 41.3063770702907, 42.27527904510498, 40.909110341753276, 41.28980909075056, 39.30629641669137, 37.55921009608677, 35.56837749481201, 36.98953424181257, 36.59651633671352, 35.785324573516846, 38.051437854766846, 38.42106464930943, 38.418761321476524, 36.24397168840681, 37.493285587855745, 37.162148339407786, 36.84481021336147, 37.29081508091518, 36.51067134312221, 35.61205039705549, 38.39945575169155, 35.73912252698626, 36.76195294516427, 37.59318331309727, 37.071825231824604, 36.60002517700195, 35.42732211521694, 36.65626389639718, 38.23048251015799, 37.15942464556013, 40.309317520686555, 38.1358619417463, 42.34011268615723, 49.143184253147666, 47.889920302799766, 45.20910031454903, 47.73227957316807, 48.35985476630074, 42.599527154650005, 37.465416363307405, 35.85063416617257, 40.16106380735125, 37.387544427599224, 45.44606167929513, 50.11775943211147, 49.536587783268516, 53.7967472076416, 46.851456437792095, 46.32261167253767, 51.11629894801548, 51.3784544808524, 50.44919197899954, 47.187714508601594, 40.73244891847883, 39.22377266202654, 41.2808598109654, 41.10075902938843, 44.21194349016462, 45.830804279872346, 49.01107815333775, 48.456156798771445, 47.18712738582066, 48.73667294638497, 46.993078095572336, 40.9885699408395, 39.38632576806204, 36.635700702667236, 36.94157082693917, 38.584041595458984, 37.87472084590367, 37.90087733949934, 38.95312990461077, 39.87387391499111, 38.42059217180525, 37.18831525530134, 38.509334564208984, 37.39305087498256, 38.58469820022583, 38.96211739948818, 38.05101401465279, 38.23801783152989, 38.378590311322895, 37.460469245910645, 39.278538363320486, 38.4872601372855, 40.09112671443394, 39.623825618198936, 39.65603051866804, 39.78798723220825, 40.455611842019216, 40.78507457460676, 41.11637510572161, 43.19637393951416, 40.353153705596924, 41.079455852508545, 40.563239438193186, 42.80208451407296, 43.3769610949925, 40.91206332615444, 41.39056839261736, 44.09051677158901, 44.4739670072283, 42.87606198447091, 48.789013726370676, 53.200449330466135, 55.45725897380284, 58.152388777051655, 61.24928079332624, 59.404846736363, 69.28676237378801, 32.84325231824602, 0.6139903792313167, 1.4288374377148492, 0.12005853413471154, 1.0504523302827562, 46.358280250004356, 68.28247669764927, 61.43499224526541, 63.59524277278355, 37.87803166253226, 28.631888355527604, 53.807013171059744, 62.95219394138881, 66.62396253858293, 32.059019565582275, 0.5014406357492719, 0.1828020294862134, 0.1712371464818716, 0.13527120782860688, 0.13350758674953664, 0.17036467258419308, 0.09187173484159367, 0.15128054948789732, 0.08088429192347185], [0.05685932109398501, 0.012205715224679028, 0.0032307297764678617, 0.016671554518065283, 0.007833947178109415, 0.06610724449689899, 0.059524484510932646, 0.06290723263685193, 0.045682946885270734, 0.034391007984855344, 16.788416351590836, 57.92656190054757, 43.225379194532124, 41.31647627694266, 13.810135296412877, 55.26928588322231, 70.075348172869, 44.00342110225132, 38.920865944453645, 49.704859256744385, 35.33623817988804, 0.22946613122309956, 0.013871771449755346, 0.15102900298578398, 5.437512133802686, 40.899434975215364, 49.698084763118196, 53.32061495099749, 54.06327315739223, 51.14837530681065, 51.261102880750386, 50.41336359296526, 49.43241344179426, 48.729415552956716, 45.71287597928728, 43.03160783222744, 40.37409210205078, 37.99425070626395, 36.897543566567556, 34.75253391265869, 34.822140966142925, 34.357751165117534, 34.337584018707275, 33.424215521131245, 32.85784353528704, 34.162941047123496, 32.72841249193464, 33.46827057429722, 33.02447523389544, 33.66934101922171, 33.371562072208945, 35.19147593634469, 33.26640108653477, 32.40097515923636, 33.0720773424421, 31.952131952558243, 33.3617651121957, 33.81900174277169, 33.5544490814209, 31.85615301132202, 32.156655652182444, 32.773554938180105, 34.097228458949495, 34.12095308303833, 33.72135870797293, 33.97582605906895, 33.76355859211513, 33.73393842152187, 33.90394694464547, 32.641247340611045, 34.67849390847342, 35.032688753945486, 34.90091964176723, 34.5862774167742, 36.577019691467285, 41.80009869166783, 46.22781045096261, 40.07457610539028, 42.77208914075579, 44.42000034877232, 38.13370105198452, 34.1521817616054, 31.42353732245309, 34.909146308898926, 34.83684682846069, 43.50594745363508, 47.373967920030864, 46.84444917951311, 44.540006160736084, 42.84874166761126, 49.18524864741734, 47.20053046090262, 45.54609489440918, 44.22477681296212, 39.47214991705758, 34.44710847309658, 36.33535439627511, 35.604112080165315, 37.926325116838726, 39.55624049050467, 43.02759872164045, 41.72236919403076, 42.81707872663225, 46.423753125326975, 42.30905076435634, 42.749319893973215, 34.75432654789516, 34.11977883747646, 35.48845584051949, 33.90102522713797, 34.84084204265049, 35.20895760399954, 34.639010769980295, 33.92149114608765, 34.349364689418245, 34.2872964314052, 33.801857062748496, 33.77070134026663, 33.52901520047869, 34.47126041139875, 34.83940029144287, 34.8141644341605, 35.05371400288173, 34.19485412325178, 35.162001677921836, 34.949928760528564, 35.44878510066441, 34.08461747850691, 34.381788458142964, 34.73286703654698, 35.4389568737575, 35.66624982016427, 35.13210357938494, 36.734417234148296, 36.495058740888325, 37.35212598528181, 36.98545217514038, 38.82739530290876, 36.43848303386143, 37.9790688923427, 39.266017709459575, 38.1493171283177, 38.16048288345337, 41.109854221343994, 41.169202259608674, 41.718839509146555, 42.7995171546936, 46.324185439518516, 46.51628576006208, 56.192673683166504, 54.02266093662807, 64.6670093536377, 27.262198652539933, 0.25415245656456265, 0.049863737009997876, 0.06948718348784105, 0.6136390066572598, 37.39806400026594, 61.573997906276155, 48.79877594539097, 43.4474401473999, 20.69809647968837, 18.02596000262669, 37.82177904673985, 45.22996922901699, 53.725069590977256, 23.699174574443273, 0.04905543216903295, 0.014241489914378949, 0.03611088391127331, 0.05048027428399239, 0.013558737800589629, 0.053108701815030405, 0.01781557304119425, 0.06280418352356978, 0.08989247533359698, 0.08354058010237557, 0.015941990273339406, 0.025601814966648817, 0.02792736651775028, 0.07370252122304269, 0.04515679047576018, 0.05693566306893315, 0.017331684274332862, 0.05927003387893949, 0.03855781689552324, 21.655236891337804, 64.95801380702427, 48.98973328726632, 46.401491097041536, 20.893839393343242, 58.832829339163645, 68.64760453360421, 48.30220903669085, 44.358769348689485, 53.93991136550903, 38.66917439869472, 0.1825216588165079, 0.09144614410719701, 0.09987697564065456, 5.844057747295924, 44.68660967690604, 51.32630477632795, 54.792500495910645, 54.51767144884382, 53.354671546391074, 51.40595197677612, 52.86243336541312, 50.285766874040874, 50.68023695264544, 47.450537068503245, 46.579681124006, 43.44150291170393, 40.719115325382774, 39.36865649904524, 37.84473589488438, 37.41535806655884, 36.785291944231304, 35.28831992830549, 35.21131999152047, 33.27785519191197, 35.73267459869385, 33.71959039143154, 35.56291273662022, 33.25653811863491, 35.27102238791329, 34.82635852268764, 36.49695907320295, 34.88514028276716, 34.61081845419747, 35.62342112404959, 34.51706641060965, 34.87393978663853, 36.219785009111675, 34.14256892885481, 33.146419593266074, 33.554497718811035, 34.818430628095356, 35.24630069732666, 34.89665344783238, 35.389113971165244, 34.40795884813581, 35.552448749542236, 35.951768670763286, 36.00820541381836, 34.51914392198835, 35.79976987838745, 36.53707102366856, 36.2402127129691, 36.640415055411204, 38.08772482190813, 43.89626945768084, 47.50339201518467, 42.329982212611604, 46.48939275741577, 46.364575317927766, 39.61484507152012, 37.03790065220424, 34.62014641080584, 37.48801537922451, 36.3460476739066, 44.773962429591585, 48.86159808295113, 47.709190709250315, 45.68844263894217, 44.97790248053414, 48.66118424279349, 49.12831858226231, 47.96608298165457, 46.015358856746126, 42.791363443647114, 36.36900799615042, 37.77591746194022, 37.7953758920942, 40.24046434674944, 41.320933546338765, 43.75255291802542, 44.374204771859304, 44.56967496871948, 48.560869625636506, 45.040137495313374, 44.86754076821463, 36.98231506347656, 36.06600052969796, 36.450072629111155, 36.0180127961295, 37.33546420506069, 35.79478801999773, 34.98310988289969, 36.19635220936367, 36.34800706590925, 35.92119312286377, 35.85680069242205, 33.976447922842844, 36.007600920540945, 35.755388259887695, 36.86378921781267, 34.63758986336844, 37.02780491965157, 36.191776820591514, 36.74618053436279, 36.90543672016689, 36.83577060699463, 35.26892750603812, 36.292949540274485, 35.84535353524344, 38.979734557015554, 38.94224555151803, 38.73192358016968, 38.90248448508126, 38.615520409175325, 38.82197570800781, 38.64105156489781, 39.952100208827424, 38.642566272190635, 40.10806294849941, 41.19125236783709, 39.43548427309309, 40.45552846363613, 42.00455290930611, 43.56056029456002, 44.293487548828125, 44.796592712402344, 49.4378399848938, 47.18952104023525, 58.809504236493794, 57.04263986860003, 65.97543157849992, 28.833243676594325, 0.3040439694055489, 0.9231264825378145, 0.0969867150166205, 0.5158213983689035, 41.660227979932515, 65.0442201069423, 55.66882814679827, 50.79472936902727, 22.28368408339364, 21.55453143801008, 46.184874057769775, 51.5613797051566, 61.24922520773751, 28.986385447638376, 0.13721523779843534, 0.03954744664952159, 0.03098048742062279, 0.007158895588612982, 0.017724267672747374, 0.06246863438614777, 0.008073218981735408, 0.03143886157444545, 0.01066678253534649, 0.17231655998953752, 0.20106740508760723, 0.04216396589098232, 0.09116909147373267, 0.18764193835003035, 0.17921089647071703, 0.16326004453003407, 0.0965666136305247, 0.12909283435770444, 0.08780220071119921, 23.35552535738264, 74.34176445007324, 54.83713572365897, 52.342253003801616, 24.9501508304051, 63.09767532348633, 73.05831405094692, 50.91600670133318, 50.576972825186594, 56.39760732650757, 42.96740647724697, 0.2955605989055974, 0.17540793839309896, 0.2352443454521043, 6.481586234910147, 46.91931949343, 54.04759802137102, 57.58138929094587, 56.89820419039045, 55.44948741367885, 54.51923826762608, 55.98660748345511, 51.71556370598929, 53.2636536189488, 49.88279220036098, 48.38797065189907, 45.31863866533552, 42.509308270045686, 41.2166098185948, 38.836691992623464, 37.97964906692505, 38.48193781716483, 39.621150561741416, 36.57238524300711, 35.48780618395124, 37.640632561274934, 36.51931142807007, 38.276010581425254, 36.0878769329616, 37.67371640886579, 37.13560274669102, 37.24620764596121, 35.74272516795567, 37.03012214388166, 38.154528277260916, 37.273941380637034, 36.623419761657715, 38.82795115879604, 36.53045286451067, 34.08228983197893, 36.38394662312099, 37.045515877859934, 37.101879664829795, 37.35857391357422, 38.06049830572945, 37.126594407217844, 36.81898375919887, 38.0764513696943, 37.32582010541643, 36.16648537772042, 37.95989533833095, 38.59565550940377, 38.40089055470058, 37.72907965523856, 39.94908121653965, 45.91540207181658, 50.06538738523211, 41.96254062652588, 46.43666287830898, 47.6951379776001, 42.036987100328716, 38.018920285361155, 35.178955282483784, 39.95789153235299, 38.16894926343645, 47.70654344558716, 52.32601853779384, 49.96495464869908, 47.910407066345215, 46.909039633614675, 50.73304673603603, 51.65690353938511, 50.45255143301827, 48.21133007322039, 43.95315088544573, 38.065810203552246, 40.33829150881086, 39.293980734688894, 41.79348400660923, 44.154304708753315, 47.74998010907854, 44.453414235796245, 46.9988694190979, 49.534958430698936, 47.81860399246216, 46.60602869306292, 37.04013797215053, 38.32734734671456, 39.00250380379813, 38.88610063280378, 38.627141271318706, 38.92837347303118, 36.89592811039516, 36.78325612204415, 37.95114408220564, 38.17176328386579, 37.160063879830496, 36.50386905670166, 38.376505851745605, 38.77400881903512, 38.51105771745954, 37.47551556995937, 39.387135233197895, 38.185586724962505, 38.8339717728751, 39.421709469386506, 40.50162976128714, 37.45379202706473, 39.21928065163748, 38.057816301073345, 41.229821818215505, 40.16003894805908, 40.646544865199495, 40.82199730191912, 41.20391198566982, 41.067973954336985, 41.011127267565044, 42.038102286202566, 40.09396505355835, 43.21292107445853, 43.809597628457205, 42.74984448296683, 41.483802795410156, 44.58027791976929, 46.171290329524446, 45.92338555199759, 47.78427989142281, 51.36996030807495, 50.851343291146414, 61.14284133911133, 59.36850765773228, 69.34161145346505, 32.71289716448103, 0.5647318309971264, 2.302717694214412, 0.19142595172992774, 0.6970629330192293, 45.33377184186663, 71.42435482570103, 60.20274312155587, 58.19482837404524, 30.429361275264196, 26.24358752795628, 52.228528363364084, 60.251533372061594, 69.40281118665422, 36.56532934733799, 0.3953967945916312, 0.11688613864992346, 0.12599308283201285, 0.2306164109281131, 0.14396218290286406, 0.16216267698577472, 0.08254226510013853, 0.13137694607887948, 0.15810590609908104], [0.05767418736858027, 0.02745458876181926, 0.01530242691348706, 0.02139614805180047, 0.01033855224626937, 0.031026410670684915, 0.07078336179256439, 0.018478785042784045, 0.05759630511913981, 0.02369514513494713, 9.426847713334219, 53.6073705809457, 46.14731209618704, 37.877566133226665, 25.532896246228898, 21.181739739009313, 47.05992324011666, 34.26752185821533, 40.78687763214111, 48.27241516113281, 37.91836942945208, 1.103244526045663, 0.05658649234101176, 0.013108148987937187, 3.503967647041593, 44.19406924928938, 53.42891304833548, 53.37603030885969, 49.09293835503714, 49.42627123423985, 45.623087882995605, 44.04196275983538, 40.52459008353097, 40.02426072529384, 36.06736585072109, 36.449985776628765, 35.70154319490705, 35.71691608428955, 33.997261251722065, 33.76346131733486, 35.171076025281636, 35.301518031529014, 35.05009399141584, 34.833768776484895, 32.741037368774414, 32.679330417088096, 34.180596419743125, 36.30908325740269, 33.7703469821385, 33.728452818734304, 32.63253082547869, 32.02686677660261, 34.6032657623291, 33.73285102844238, 31.99978617259434, 32.37530156544277, 31.586948531014578, 34.04441172736031, 31.56960235323225, 32.57049036026001, 31.6464980670384, 32.67811795643398, 33.829754080091206, 33.215040002550396, 31.504918098449707, 32.050983973911826, 33.5981775692531, 33.703303813934326, 34.44514560699463, 33.95036785943167, 33.40429503577096, 32.8145249911717, 34.051377296447754, 34.11986568995884, 37.49161802019392, 39.96292897633144, 45.026682308741975, 37.01614931651524, 43.76077611105782, 44.214337144579204, 37.124853883470806, 35.012837750571116, 33.3440819467817, 33.85499688557216, 35.25732748849051, 41.96117877960205, 48.362060819353374, 47.354770047324045, 42.8358736038208, 43.307958534785676, 46.412431035723, 44.208688259124756, 41.750283581869944, 39.23212439673287, 36.63360929489136, 35.31268378666469, 35.448792048863, 37.14438526970999, 37.98233107158116, 40.968708515167236, 42.13347673416138, 43.54425982066563, 46.41249704360962, 42.126750877925325, 41.93733951023647, 40.98676340920584, 34.044088636125835, 35.54808528082711, 33.441467898232595, 35.16355460030692, 34.312011173793245, 33.88680573872158, 33.73625564575195, 34.03025824683053, 34.087170941489084, 33.381744657244, 34.60337345940726, 32.22611331939697, 34.51068449020386, 33.410795075552805, 34.371755259377615, 34.41787392752511, 35.29465668542044, 34.62046602794102, 34.5732877595084, 35.56102630070278, 35.43513536453247, 34.01661893299648, 34.6435409954616, 34.80797358921596, 34.90123231070382, 37.40521717071533, 37.56175661087036, 37.700668471200125, 36.627713748386924, 38.72292218889509, 37.331642695835654, 39.63320221219744, 37.70887776783535, 39.200048037937705, 39.266198362622944, 39.79804474966866, 39.48773125239781, 41.99336978367397, 40.05286993299212, 42.540168694087434, 42.730789048331125, 43.43966858727591, 48.0114859853472, 56.4050418989999, 50.20904833929879, 67.57421207427979, 26.165290015084402, 0.40881987288594246, 0.1046108566224575, 0.13645336510879652, 0.14973529454852852, 34.31509269986834, 58.31405598776681, 53.083542415073936, 44.831556047712056, 28.68925963129316, 23.31049755641392, 27.975564990724834, 45.38235364641462, 50.215965270996094, 23.007894822529384, 0.05102967391056674, 0.008681765657716563, 0.0665072612464428, 0.06320548948964902, 0.07366835698485374, 0.054086979678166766, 0.04123348742723465, 0.009659139372940575, 0.06957415810653142, 0.048763377126306295, 0.03713822324893304, 0.017776850744017532, 0.009560382841820163, 0.050443711424512525, 0.02152294080172266, 0.04203909509150045, 0.01427456340752542, 0.03183928205232535, 0.046069423468517404, 11.854791487966265, 60.38259029388428, 50.19338015147618, 44.143757343292236, 25.05985072680882, 32.201075485774446, 56.59490837369646, 40.971838678632466, 45.4665275982448, 51.88385254996163, 43.02884939738682, 1.107425821678979, 0.052474156221640963, 0.011578155997475343, 4.127011094774518, 46.78292635508946, 54.814307417188374, 55.33294527871268, 51.39822210584368, 50.86378056662423, 47.782945837293354, 47.21842554637364, 41.571843419756206, 42.64946385792324, 38.76206833975655, 38.13456262860979, 37.145906925201416, 35.93136528560093, 35.78247581209455, 35.16349901471819, 36.45811169488089, 37.148383957999094, 37.250960213797434, 35.58646018164498, 34.99279914583479, 35.09480912344796, 35.0900113923209, 37.03647974559239, 34.52292026792254, 35.614489214760916, 34.90517193930489, 33.27708741596767, 35.10402590887887, 33.933521951947895, 34.345008168901714, 33.8368238721575, 34.29768398829869, 35.42971576963152, 34.63364676066807, 33.860433850969585, 33.36161225182669, 34.73599720001221, 35.32503768375942, 35.161289487566265, 33.29261316571917, 34.87116050720215, 34.85989052908761, 36.383647850581575, 35.23782736914498, 35.492722034454346, 35.12861558369228, 35.97346789496285, 35.580727917807444, 34.32233272280012, 38.6847939491272, 42.47407048089163, 46.40879365376064, 40.959891251155305, 45.667917660304475, 45.73396723611014, 40.27418048041207, 35.54099464416504, 35.59257459640503, 36.53115463256836, 36.47231381280081, 43.47894327981131, 48.67344433920724, 48.71927465711321, 44.47686093194144, 45.822907652173726, 47.379293714250835, 44.61750636781965, 45.37235171454293, 39.69406148365566, 39.1266507421221, 37.96459232057844, 37.91398164204189, 37.38838168552944, 40.59264421463013, 41.30915634972708, 43.19146156311035, 44.821196283612935, 46.9240859576634, 44.665393352508545, 42.52607774734497, 42.98023285184588, 35.54552486964634, 36.653449875967844, 35.74474361964634, 36.55666841779436, 35.383267062050955, 36.32009962626866, 34.81403589248657, 36.01496253694807, 35.53576612472534, 35.14457212175642, 34.79682867867606, 35.69209017072405, 35.87934759684971, 35.59917885916573, 35.94723149708339, 34.76346342904227, 35.469320501599995, 36.27707290649414, 35.84883805683681, 35.66697243281773, 36.81110102789742, 36.21015133176531, 37.39416258675711, 37.1091822215489, 37.152851649693076, 39.799257210322786, 38.63216481889997, 38.090504101344514, 38.84118400301252, 40.62638814108712, 40.243674414498464, 42.095487458365305, 40.003742694854736, 40.85556057521275, 39.81637062345232, 42.39182118007115, 40.99651868002755, 44.90810782568795, 43.3847257069179, 44.13155630656651, 45.13236093521118, 46.260317598070415, 49.6381322315761, 59.48728711264474, 53.14754574639456, 72.04537091936383, 28.310025215148926, 0.30113712538565907, 0.39043225241558893, 0.047256778326949904, 0.1201592558728797, 35.57626370021275, 64.97158363887242, 57.73430177143642, 54.402425152914866, 28.46911464418684, 26.440838200705393, 37.01177542550223, 51.18437392371041, 58.52845655168806, 28.082061767578125, 0.14496235709105218, 0.06648743445319788, 0.05393883852022035, 0.0806276835501194, 0.02404550669182624, 0.03140652598813176, 0.0424067084012287, 0.023874185081305246, 0.07173489180526563, 0.14099478641791002, 0.22764256836048194, 0.07911780064127275, 0.18246007497821534, 0.1773706687880414, 0.17411494920296328, 0.18663235966648373, 0.12567109082426342, 0.21303506647901876, 0.19005330252860272, 15.052226543426514, 67.33164351327079, 57.27927466801235, 49.83050353186471, 37.28190401622227, 30.180820737566265, 56.237625053950715, 43.38344723837716, 51.38927630015782, 56.24443081447056, 46.144133295331685, 1.424669278519494, 0.32265759631991386, 0.22393265100462095, 4.948013714381626, 49.805496965135845, 57.01982545852661, 59.50426851000105, 52.89315135138375, 53.65065090996878, 50.22531754629952, 48.129792962755474, 44.09300422668457, 44.950794083731516, 38.61867141723633, 40.22072104045323, 38.82180200304304, 39.58874068941389, 37.36550126756941, 38.07421752384731, 38.88922732216971, 39.32285744803292, 37.45937490463257, 38.158488750457764, 35.61352341515677, 35.996626240866526, 36.859297207423616, 40.24287189756121, 35.90835632596697, 37.50326667513166, 35.1563458442688, 35.42696080889021, 37.66844967433384, 36.40032352719988, 36.85601418358939, 36.328149114336284, 35.95167487008231, 37.541127409253804, 36.45167418888637, 36.46982288360596, 35.01057611192976, 36.34957388469151, 37.20826005935669, 36.62717873709542, 33.966449465070454, 35.588179860796245, 37.68663311004639, 36.36419636862618, 37.903298786708284, 37.158212184906006, 36.403491905757356, 35.80722876957485, 37.26810141972133, 36.11097274507795, 41.17768253598894, 44.43079090118408, 48.966442925589426, 41.11603464399065, 48.98789896283831, 47.21242230279105, 41.47399193899972, 38.2483081136431, 37.29405641555786, 38.15779740469796, 40.30798346655709, 46.44943714141846, 51.57326807294573, 51.690873282296316, 45.638957568577354, 47.0853397505624, 50.41561828340803, 47.68485116958618, 47.32914856501988, 41.47275515965053, 41.85347127914429, 39.155784538814, 39.446097646440776, 39.95014776502337, 42.806910037994385, 43.8315052986145, 45.10533939089094, 46.85392304829189, 47.2333676474435, 46.1539580481393, 45.0726237978254, 45.436490535736084, 38.392643042973106, 39.13259145191738, 37.49312925338745, 39.22304310117449, 37.955643040793284, 37.186473982674734, 37.72065149034773, 37.694039889744346, 37.465134961264475, 36.56895630700247, 36.4077650478908, 37.093340328761506, 38.7722543988909, 36.13581255504063, 37.25752626146589, 37.47507088524954, 38.12662083762032, 37.847921643938335, 38.59130246298653, 38.1181822504316, 39.497941630227224, 38.850439003535676, 39.319973945617676, 39.161443846566335, 39.28637593133109, 42.065662315913606, 40.618213585444856, 40.205070223127095, 41.05110372815813, 42.42642668315342, 41.52747222355434, 43.972425188337056, 41.29375219345093, 41.44758531025478, 43.68585021155221, 44.2560749735151, 44.301710741860525, 47.188701152801514, 44.3473082951137, 48.19222947529384, 49.23056479862758, 47.859480244772776, 52.938898290906636, 62.456599780491416, 55.14749091012137, 74.82544939858573, 30.662042549678258, 0.4288152956536838, 1.6540499414716447, 0.24655191440667423, 0.293976789606469, 40.361884117126465, 69.97956725529262, 63.70373889378139, 59.46375356401716, 39.67168481009347, 33.14713525772095, 42.58227825164795, 58.808510644095286, 67.45026315961564, 36.1012487411499, 0.31680200195738245, 0.13064429110714368, 0.13956910291952745, 0.09589162056467362, 0.11948741120951516, 0.09932078048586845, 0.10368805578244583, 0.10266658916537251, 0.17819894291460514], [0.05958879606000014, 0.014236653656033533, 0.027348255539046865, 0.032150068054241795, 0.06912939875785794, 0.0150123582820275, 0.09791423846036196, 0.08119399566203356, 0.10861217084207705, 0.04052613502634423, 5.356489624295916, 48.322358812604634, 49.961136613573345, 38.17144019263131, 38.9955278124128, 29.852351597377233, 37.05274200439453, 33.696074213300435, 39.30263819013323, 48.244702271052766, 41.23640176228115, 2.0899623334407806, 0.16733719860868795, 0.10744285822979041, 2.3918539626257758, 43.9860714503697, 50.609928131103516, 52.22092703410557, 47.62938717433384, 45.41104275839669, 38.25705936976841, 37.93648338317871, 35.100301674434114, 36.185415744781494, 33.856893743787495, 35.23761544908796, 34.11218793051583, 33.83089358466012, 34.40868146078927, 36.16190651484898, 33.82615491322109, 33.73627996444702, 34.217797074999126, 34.36459166663033, 34.595601899283274, 34.16935076032366, 35.089344365256174, 34.106361865997314, 32.773683479854036, 32.23119592666626, 30.991751943315776, 31.84770052773612, 31.926607745034353, 33.91065195628575, 32.41396481650216, 33.34573214394705, 31.51828990663801, 34.468449865068706, 32.34580298832485, 33.28768341881888, 32.93263741901943, 33.280853339603965, 32.14965534210205, 33.827461174556184, 32.27250296728951, 33.02356154578072, 33.52941819599697, 34.72000592095511, 34.72980982916695, 34.656141553606304, 33.22896766662598, 34.327807903289795, 33.854524408067974, 34.265319279261995, 34.98892552512032, 38.08816950661795, 43.91688128880092, 41.174837248665945, 42.00852727890015, 42.46827915736607, 35.982611724308555, 34.825347559792654, 32.75043828146798, 34.09295531681606, 32.755041463034495, 41.458024978637695, 48.22955519812447, 45.11269058500017, 46.406928062438965, 43.523606300354004, 47.21485764639718, 45.70366961615426, 39.07268408366612, 36.76814726420811, 35.72120312282017, 35.11847816194807, 36.02325521196638, 38.049877984183176, 41.53241586685181, 42.91935968399048, 42.115595545087544, 44.270985807691304, 43.22643184661865, 40.92917326518467, 44.32658181871687, 37.86646638597761, 33.701184613364084, 33.70690645490374, 34.9286082131522, 33.72870295388358, 33.89773178100586, 34.08959238869803, 34.29615191050938, 33.908977440425325, 33.29172379629952, 32.201221397944856, 33.3579957144601, 34.3168158531189, 33.697342259543284, 33.71846825735909, 34.52337884902954, 34.59556368419102, 34.01018837520054, 34.135690212249756, 32.75761924471174, 34.2188149860927, 35.66928618294852, 35.82023579733712, 33.415047373090474, 35.75619772502354, 36.552923338753835, 36.812244006565635, 36.643854413713726, 36.52553006580898, 37.196302209581646, 38.81477737426758, 36.302930627550396, 39.375034945351736, 37.29705456324986, 38.673867906842915, 39.3346346446446, 39.99380677086966, 41.21759646279471, 44.713398456573486, 43.34634038380214, 45.63691827229091, 43.469250542776926, 47.719703333718435, 47.56558186667306, 57.942313466753276, 49.933781555720735, 68.2677812576294, 24.875784260886057, 0.4397441063608442, 0.20004975183733872, 0.05579509320003646, 0.23572898230382375, 33.02330098833357, 58.90994739532471, 52.73367282322475, 45.595948219299316, 23.54072959082467, 18.014867203576223, 33.324286528996055, 42.639899662562776, 48.94437197276524, 18.935809237616404, 0.09559383868638958, 0.014385112029101168, 0.017971184869695987, 0.03859588271006942, 0.031099461750792604, 0.08434459660202265, 0.03426205240456121, 0.022219943847241144, 0.03652064781636, 0.015289853659591504, 0.04156630206853151, 0.017402217989521365, 0.056061204456325085, 0.04730415024927684, 0.017522659651669006, 0.13803338818252087, 0.005543896579183638, 0.10395883196698767, 0.04010098873238478, 5.930173720632281, 57.107365812574116, 54.36286905833653, 44.0735353742327, 36.62233584267752, 25.095746857779368, 45.016906193324495, 37.304589884621755, 45.649275643484934, 50.924104826790945, 44.263662406376426, 2.2750312941414967, 0.15516892155366285, 0.10420288744249515, 2.758266346795218, 45.37751422609602, 52.03192213603428, 53.21717711857387, 48.139252935137065, 48.156463623046875, 41.10712705339704, 39.83480419431414, 36.302854197365896, 38.48624570029122, 36.339769976479666, 36.42460748127529, 36.59757941109793, 35.97532653808594, 34.45912538255964, 36.59327500207083, 35.224111625126426, 34.66980171203613, 34.36901419503348, 36.54308468954903, 36.10352427618844, 35.08151721954346, 34.76191398075649, 36.77805886949812, 33.83683429445539, 33.655871936253135, 32.70814459664481, 33.55815941946847, 33.408203397478374, 35.15102699824742, 33.15993731362479, 35.29012993403843, 33.27450268609183, 35.5196602003915, 34.24882772990635, 34.886224201747346, 32.67973688670567, 35.51997981752668, 33.83594145093645, 36.1648907661438, 34.81343487330845, 33.67155054637364, 34.34342745372227, 36.02856363568987, 35.944212504795615, 35.11658130373274, 35.55440466744559, 35.9540650503976, 34.235521929604666, 35.376971994127544, 36.2326009614127, 41.01079027993338, 45.55707304818289, 42.78865017209734, 43.224531514304026, 44.22844546181815, 37.49019711358206, 37.156829493386404, 33.949537549700054, 35.84695162091936, 35.47496938705444, 43.02814415522984, 49.548997265951975, 47.13835103171212, 47.35623959132603, 46.52916077205113, 48.761366844177246, 47.28994335447039, 41.179718358176096, 38.18910946164812, 37.662561076028005, 36.23633909225464, 37.1651360648019, 38.02992623192923, 42.35224076679775, 44.66858604976109, 44.022372313908164, 46.013875416346956, 46.16309492928641, 42.313820702689036, 45.14322444370815, 39.65881674630301, 35.81382261003767, 35.96873617172241, 36.38881731033325, 34.65823296138218, 35.59211254119873, 35.481632709503174, 35.66989415032523, 34.95257602419172, 35.7752879006522, 34.279580456869944, 33.68232372828892, 36.39198568889073, 35.2317407471793, 35.58607455662319, 36.230151721409385, 35.20965937205723, 34.44086899076189, 36.35741492680141, 34.81608213697161, 36.36542967387608, 36.86615855353219, 37.497589996882844, 35.808229310171946, 37.737629413604736, 38.01390021187918, 38.653322083609446, 39.59452853884016, 38.86044788360596, 38.89504296439034, 41.24994032723563, 39.621998241969514, 40.0378201348441, 39.53702524730137, 39.743706362588064, 40.0740966796875, 42.57811280659267, 42.50628580365862, 45.4574601990836, 44.7005547114781, 47.54690163476126, 45.160112040383474, 50.22251047406878, 49.25859383174351, 60.755569594247, 52.67304284232003, 69.87212726048061, 27.632428203310283, 0.36037247255444527, 0.6549210771918297, 0.10009191517851182, 0.24870164905275616, 35.49433054242815, 63.034808022635325, 57.870392663138254, 51.47287007740566, 24.36314443179539, 21.018196514674596, 35.804522446223665, 49.777200426374165, 59.11390481676374, 24.711144958223613, 0.1379901926432337, 0.010663401734616076, 0.04523181948544724, 0.018359442607366612, 0.014206795570706683, 0.0377618681772479, 0.01865321604002799, 0.08495706266590528, 0.013759734291982437, 0.1846281707819019, 0.12752442780349935, 0.13040864946586744, 0.2079505185995783, 0.10408962637718235, 0.10726563166826963, 0.22113999085766928, 0.14916182389216764, 0.20636011394006865, 0.2794361098536423, 7.107276729175022, 62.411735262189595, 62.28693866729736, 50.16882174355643, 46.7416227885655, 38.05845206124442, 47.7856000491551, 45.578796591077534, 50.40622779301235, 56.59676006862095, 48.87074886049543, 2.6150895953178406, 0.33868331781455446, 0.17905787325331143, 3.311710774898529, 49.42367608206612, 53.303908007485525, 55.774402550288606, 51.21283027103969, 49.8682461466108, 42.523208141326904, 41.13547222954886, 37.92246191842215, 40.46390104293823, 37.19838319505964, 39.629999092647004, 37.91629886627197, 37.246131215776714, 37.089807169778005, 38.64853824887957, 36.927789075034006, 36.231645584106445, 37.02591153553554, 37.807653359004426, 37.99827371324812, 36.68291023799351, 37.90626914160592, 38.20210954121181, 36.09161853790283, 36.03218364715576, 35.20135280064174, 35.57288687569754, 35.712014130183626, 38.225281783512656, 34.66180433545794, 36.332394463675364, 35.35625941412789, 38.95630175726754, 36.476816245487754, 37.245985303606304, 35.02206495829991, 37.00712360654558, 36.24242918831961, 37.58455712454659, 35.447864464351106, 34.9095458303179, 35.44852801731655, 38.00576039722988, 38.13188757215227, 36.185697146824424, 36.669451577322825, 38.44254847935268, 35.929996490478516, 38.05118771961757, 38.714976923806326, 42.73699031557356, 47.655613149915425, 46.059931550707134, 45.330245631081716, 46.70929282052176, 38.418976715632844, 39.43003341129848, 36.508673736027305, 38.4089435168675, 37.69900785173689, 46.68319191251482, 51.42757824489048, 48.8557824407305, 50.05414172581264, 48.79304368155343, 49.69791453225272, 50.52275603158133, 44.73247473580496, 40.06545659473964, 39.44705649784633, 39.04563822065081, 40.47139120101929, 41.3863855770656, 44.67893191746303, 47.68945435115269, 45.68010132653372, 47.094546113695415, 47.541853768484934, 45.822150298527305, 47.7866770199367, 42.33354663848877, 37.79605334145682, 37.61865888323103, 38.622767380305696, 37.19724716459002, 36.93036685671125, 37.508696692330496, 38.164259229387554, 37.47625207901001, 38.487152440207346, 36.71142911911011, 35.660211835588726, 37.844569138118196, 37.69032955169678, 36.70194830213274, 38.14058671678816, 36.45082998275757, 37.059596402304514, 38.12712458201817, 36.83467626571655, 38.3029522214617, 39.35396105902535, 40.298447063991, 37.07863794054304, 40.3345742225647, 40.2988326890128, 40.24499804633004, 40.70246744155884, 40.08852113996233, 41.67048699515206, 43.93237577165876, 40.147306374141145, 42.85978930337088, 41.643917083740234, 42.0776549066816, 43.152523858206614, 43.92544494356428, 45.947923115321565, 48.352062361580984, 47.25635576248169, 49.13451290130615, 46.89838457107544, 53.17378214427403, 53.26443876538958, 64.34406403132847, 54.97989688600813, 73.57441929408482, 30.466023445129395, 0.5210208222270012, 2.491929518324988, 0.14862005439187798, 0.4291222648961203, 39.648140839168, 67.55318682534354, 62.9619631086077, 59.35105378287179, 34.67939370019095, 30.441451140812465, 47.47125659670149, 58.4635534286499, 67.95210375104631, 33.22617449079241, 0.3385363199881145, 0.05904766438262803, 0.12587762331323965, 0.10134641786238976, 0.07732946053147316, 0.16553138622215816, 0.130459281748959, 0.22717024013400078, 0.13469334026532515], [0.04126942603449736, 0.026191628138933862, 0.027771227128271545, 0.010904618389239269, 0.02356506827553468, 0.023197982526783432, 0.02205323627484696, 0.05828936757253749, 0.037688311588551314, 0.020208745695916668, 1.103644264595849, 38.34675713947841, 52.21350635801043, 38.77572849818638, 37.725341524396626, 32.861098766326904, 32.59757096426827, 35.92801277978079, 40.29807186126709, 48.62875005177089, 44.83018030439104, 3.7274518949644904, 0.19181271669055733, 0.06967059828873191, 0.5464718022516796, 39.36884757450649, 53.88515608651297, 49.755615847451345, 47.820024899074006, 43.6751777785165, 39.077749320438926, 36.5577175957816, 35.4312686920166, 35.10103818348476, 35.376082624707905, 35.84115334919521, 35.53102050508772, 36.08520187650408, 35.52412094388689, 33.560045855385916, 32.834466321127756, 35.68987022127424, 37.93432249341692, 37.98907777241298, 33.17596680777413, 33.119606494903564, 33.188369342258994, 33.81564923695156, 34.447671277182444, 36.327079091753276, 37.668939522334504, 37.43456636156355, 35.64477988651821, 36.50204168047224, 32.50715058190482, 32.236886501312256, 31.990840366908483, 32.61460794721331, 33.49911362784249, 32.08254616601126, 32.30104964120047, 33.340399401528494, 32.47380270276751, 35.50163657324654, 32.115032468523296, 34.199891567230225, 34.290009702954976, 33.56950582776751, 34.07695361546108, 33.86653784343174, 33.14281347819737, 33.074012415749685, 33.945827211652485, 34.2001382282802, 34.46739026478359, 35.123515605926514, 40.35618312018258, 41.96248851503645, 42.44163976396833, 39.82991961070469, 36.27021850858416, 34.26008381162371, 34.06800780977522, 33.03113508224487, 31.86518566949027, 37.2155521937779, 44.70389679500035, 47.62398842402867, 45.05601760319301, 43.27601766586304, 47.436119556427, 44.68421949659075, 39.04786164419991, 35.68027823311942, 35.485002585819785, 37.047186919621055, 41.1747920853751, 40.54579251153128, 42.886598927634104, 42.90193707602364, 44.334930079323904, 44.595925262996126, 41.400125639779226, 41.86190291813442, 40.08165979385376, 34.61798204694475, 34.82652875355312, 33.64571366991316, 33.316535813467844, 33.36620153699602, 33.9426623071943, 33.38196699959891, 34.43193013327462, 34.430227824619834, 34.10322822843279, 34.9679593358721, 31.76529836654663, 34.1770076751709, 32.50614309310913, 32.85745791026524, 33.82418162482125, 33.82464715412685, 33.481145586286274, 33.61350529534476, 33.295527935028076, 35.11689397266933, 33.61037860597883, 34.434157030923025, 33.663101536887034, 35.23835890633719, 34.3115109034947, 36.18690613337925, 36.63692705971854, 36.1625839642116, 36.575397287096294, 36.35290902001517, 35.87549134663173, 37.460604735783164, 36.44416666030884, 38.44851003374372, 37.08492258616856, 41.35818631308419, 39.334071840558735, 43.03093385696411, 41.28587988444737, 44.94818156106131, 43.71573093959263, 48.59629154205322, 47.302530016217915, 56.41042675290789, 50.96417508806501, 68.05785533360073, 21.16344686916896, 0.46255308815411156, 0.30526674379195484, 0.0469321671740285, 0.26872771446193966, 29.507689680371964, 62.54304926736014, 49.566249643053325, 55.13798924854824, 27.33696300642831, 19.170297043664114, 41.10837772914341, 45.875995363507954, 51.83502755846296, 20.86751093183245, 0.04850731836631894, 0.0814663256917681, 0.015417670997391855, 0.03949349633018885, 0.021835036376225095, 0.0298467470066888, 0.03556134857769523, 0.015973430193428482, 0.0628483018704823, 0.02689848351292312, 0.027983801971588815, 0.02784945543057152, 0.024627654114738107, 0.03375826050926532, 0.04570735039721642, 0.0016721470310585573, 0.05120944158573236, 0.01817782931695027, 0.05759533481406314, 1.6451740520341056, 44.53793559755598, 56.872231824057444, 43.3644369670323, 40.11969075884138, 42.142332213265554, 44.90697526931763, 40.696401664188926, 45.03756318773542, 51.11817496163504, 50.16556651251656, 3.440871489899499, 0.12433424113052231, 0.031034298640276705, 0.852470793894359, 42.615098067692344, 57.031411579677034, 52.821769033159526, 49.521409443446565, 45.767888341631206, 39.8754928452628, 38.94925628389631, 36.18543658937727, 36.32840272358486, 36.77434158325195, 38.06035239355904, 35.599241392953054, 38.016731602805, 36.54644066946847, 35.88799115589687, 34.887982095990864, 37.74845470700945, 39.76036466870989, 39.85235186985561, 35.31264557157244, 35.4646269934518, 34.918140751974924, 36.04159150804792, 34.93340247017996, 37.89635058811733, 39.215768337249756, 38.867503779275076, 36.72395672116961, 38.51610558373587, 35.38427802494594, 35.589062282017295, 34.121317863464355, 34.69547183173043, 34.47194133486067, 34.15603453772408, 33.85797071456909, 35.36349596296038, 34.917960098811555, 36.66809320449829, 34.29020077841622, 34.571641036442344, 35.12842103413173, 35.12513106209891, 34.38265698296683, 35.70206430980137, 33.37734644753592, 35.11112001964024, 35.04692561285836, 36.433101654052734, 35.876179218292236, 36.79317467553275, 41.84098536627633, 44.68745388303484, 42.391313961574006, 42.45356287275042, 38.148465973990305, 35.37862913949149, 35.74921825953892, 35.4356495312282, 35.02009514399937, 39.419215066092356, 46.537484713963096, 48.795392172677175, 46.86300086975098, 45.50432232448033, 48.41939040592739, 46.186520780835835, 41.33797400338309, 36.95089878354754, 38.05710411071777, 38.80610602242606, 41.49263742991856, 42.40021112986973, 44.01931163242885, 45.53274393081665, 45.19877181734358, 46.35721370152065, 43.66877848761422, 44.219989504132954, 42.42163937432425, 36.92212281908308, 37.547078541346956, 36.9858968598502, 34.83457129342215, 34.41525445665632, 36.388178076062886, 35.8819705418178, 35.63699095589774, 35.685277462005615, 35.27135590144566, 35.87711027690342, 33.983760901859824, 35.07216494424002, 33.77945259639195, 34.864552770342144, 36.32543236868722, 35.66561753409249, 35.22311108452933, 35.1787086214338, 35.12286247525896, 37.01586444037301, 35.01978942326137, 36.64117240905762, 37.50526775632586, 37.726008551461355, 35.958001204899375, 38.80043976647513, 37.72567851202828, 38.55264616012573, 38.02823781967163, 38.459373542240684, 38.534810134342735, 39.417071546827046, 38.02155017852783, 39.87638916288103, 40.17722531727382, 44.770328521728516, 42.43525089536394, 44.52020032065255, 44.3960360118321, 46.382032666887554, 47.21094233649117, 49.755160740443635, 49.77150290352957, 58.8581485748291, 53.132301398685996, 69.34398773738316, 23.861442804336548, 0.71519393154553, 1.6636231477771486, 0.03950344365356224, 0.20590005362672464, 32.09671354293823, 66.10536984034947, 55.46016679491316, 56.898662771497456, 30.293534415108816, 24.885939053126744, 48.5036928994315, 51.62375020980835, 61.031558990478516, 25.58541246822902, 0.09595472432140793, 0.059378490916320255, 0.03716871321999601, 0.013341662573761173, 0.02419525258509176, 0.08427002560347319, 0.023905433315251554, 0.006528753263410181, 0.016456828718738895, 0.155062608686941, 0.11910764873027802, 0.1343147312956197, 0.10970085313809769, 0.19537746826452868, 0.08905067121876137, 0.1255675328097173, 0.10720195794211966, 0.08131026263747897, 0.19247037997203215, 1.9192418370928084, 50.66194234575544, 64.37765162331718, 51.00414112636021, 49.62781763076782, 41.84752014705113, 41.05004065377371, 46.95377908434187, 49.14806883675711, 56.84160763876778, 56.10981641496931, 4.223569342068263, 0.223698583564588, 0.13338716035442694, 0.9366451799869537, 45.864530835832866, 58.68492303575788, 55.207676206316265, 52.447591168539866, 48.66044078554426, 43.15941994530814, 40.72549377168928, 38.28065892628261, 38.77043397086007, 39.310427120753694, 40.848226751599995, 38.31792906352452, 41.41087450299944, 39.48883949007307, 38.218198095049175, 36.63747249330793, 39.78744179861886, 40.729478563581196, 41.882111753736226, 35.305214473179404, 36.447772775377544, 36.12289932795933, 38.32766696384975, 37.525254249572754, 40.53086083275931, 42.63647072655814, 41.32836464473179, 38.37815604891096, 41.14914281027657, 36.43550573076521, 36.888872214726035, 35.63283245904105, 36.172585896083284, 37.5747150012425, 35.84217473438808, 36.16670077187674, 37.020974840436665, 37.45906570979527, 40.0486558505467, 36.458879470825195, 37.195548330034526, 37.15946633475167, 36.39336838041033, 36.049317904881065, 37.32265520095825, 34.360794476100374, 37.24577685764858, 35.208891596112935, 37.46642732620239, 38.77603421892439, 39.0105949810573, 44.12883608681815, 45.762416635240825, 45.173747880118235, 43.593338421412874, 41.314228534698486, 37.435420989990234, 37.66741091864449, 37.39949532917568, 35.84399168831961, 40.00334317343575, 48.39917114802769, 50.61940547398159, 49.64923545292446, 46.63128192084176, 50.005323682512554, 48.42743294579642, 44.9403509412493, 38.120398725782124, 40.27748087474278, 40.75426626205444, 45.19717025756836, 43.05818469183785, 45.5592165674482, 46.46627262660435, 47.71619101933071, 48.586140223911826, 47.02877793993269, 46.75531768798828, 45.08226442337036, 38.60095351082938, 39.892272744859966, 38.09944643293108, 36.17047364371163, 36.47484295708792, 36.986560412815635, 37.697718960898264, 36.520225116184776, 38.078928402491975, 37.574527399880544, 37.48095600945609, 34.05125570297241, 37.35231358664376, 35.241065229688374, 36.62277010508946, 38.304765701293945, 38.11507640566145, 37.03838702610561, 38.19506754193987, 37.30560779571533, 38.565340518951416, 37.60251126970564, 38.49621636526925, 39.2912848336356, 40.6039628301348, 38.715035983494346, 41.13837310246059, 40.195481709071565, 40.023378304072786, 40.09590012686593, 39.906155245644705, 40.175863470349995, 41.22890813010079, 40.00729322433472, 42.842411858694895, 41.85119227000645, 46.09241437911987, 44.25462974820818, 48.1997126851763, 47.4879218510219, 49.22967890330723, 49.06608356748308, 52.66587577547346, 53.457695960998535, 61.14806638445173, 55.31184012549264, 71.50678825378418, 25.8106643812997, 0.9142162863697324, 2.9478909373283386, 0.18641562201082706, 0.37013276453529087, 34.6696766444615, 71.85722759791783, 60.14080687931606, 68.56978470938546, 39.89444753101894, 30.30781991141183, 55.76417132786342, 59.82187761579241, 69.66851030077252, 33.836372239249094, 0.23886595826063836, 0.11661334043102604, 0.07100356676216636, 0.046036127755152326, 0.11406412507806506, 0.15465974887566908, 0.13083430805376597, 0.10246644169092178, 0.1468884873070887], [0.012319112845164324, 0.04454362891348345, 0.04769724254895534, 0.0478244746503021, 0.0343940444290638, 0.08552475898925747, 0.107492364144751, 0.00901717908813485, 0.03109743632376194, 0.05953945977879422, 0.01676488192086773, 29.008197580065044, 54.617051533290315, 42.23871067592076, 29.673560551234655, 7.860696826662336, 23.660632916859218, 33.9868597984314, 46.23115948268345, 47.1375276701791, 48.6679413659232, 4.64570323910032, 0.14513883047870227, 0.12552212524626935, 0.27899221224444254, 36.82235016141619, 55.66640669958932, 51.549692835126606, 46.853832721710205, 42.2291464805603, 41.76834889820644, 40.46758706229073, 39.74524538857596, 40.45867599759783, 44.469673020499094, 43.97059433800833, 45.9867913382394, 43.60460145132882, 44.52880913870675, 39.48162031173706, 34.96383210590908, 34.47608246122088, 34.69304691042219, 33.30301114491054, 33.40693882533482, 35.349995613098145, 38.219587734767366, 40.732365540095735, 42.52787733078003, 41.50887189592634, 43.32228224618094, 42.073663166591096, 42.139716216496055, 39.23945127214704, 35.98777423586164, 34.092941420418875, 31.94686869212559, 31.705158233642578, 32.78966433661324, 31.820011956351145, 32.48500319889614, 33.363946846553254, 33.65755687441145, 33.187059606824604, 33.77973052433559, 32.640066146850586, 32.66555213928223, 33.33653620311192, 34.50869730540684, 33.9501941544669, 35.48785482134138, 34.018957001822336, 34.29570027760097, 34.006015981946675, 33.37984779902867, 33.54718126569475, 39.12794658115932, 40.702113083430696, 40.53652361461094, 38.123476777757915, 35.96351112638201, 33.795221533094136, 31.91387517111642, 34.419030802590505, 35.430198669433594, 36.076537472861155, 43.36208152770996, 48.366556303841726, 46.09675700323922, 42.844635282244, 46.149886403764995, 46.998779092516216, 38.052261216299875, 36.538610049656455, 37.432898793901714, 40.46585348674229, 41.47918224334717, 39.83769464492798, 41.933424200330464, 44.89021621431623, 43.827246052878245, 41.958455085754395, 41.68725299835205, 41.506651946476524, 35.420551095690044, 34.51949480601719, 32.30783108302525, 34.11484909057617, 34.476527145930696, 32.78927871159145, 33.08039433615548, 34.284030778067454, 33.35888508387974, 35.1697211265564, 33.79769509179251, 33.25094134466988, 33.66552298409598, 32.67340012959072, 33.43574258259365, 33.58248853683472, 33.81801509857178, 34.30516372408186, 33.89767272131783, 34.405224731990266, 33.295027664729524, 33.773574420383994, 35.083796228681294, 35.23696231842041, 33.84177098955427, 35.89340727669852, 34.45568255015782, 35.12910195759365, 35.49545962469918, 38.283584117889404, 36.38551344190325, 38.55588402066912, 36.4242114339556, 37.69113901683262, 36.5732433455331, 38.230006558554514, 36.50726325171334, 41.450468812670024, 41.326429571424214, 45.04923963546753, 43.84682607650757, 45.623608997889924, 41.17362131391253, 48.650949546269004, 48.18190445218767, 58.34929725102016, 53.801405974796836, 67.3700531550816, 17.144245760781423, 0.5310709029436111, 0.3426900670996734, 0.03648855310997792, 0.10739859060517379, 29.06050361905779, 59.492887360709055, 51.08740486417498, 43.80703026907784, 24.062716484069824, 13.725377695901052, 27.87379125186375, 48.94519880839756, 47.69320637839181, 16.99667991910662, 0.04137781861105135, 0.03305069097716894, 0.07618868710207087, 0.01582474620746715, 0.031030027262334312, 0.043987735706780634, 0.07684921380132437, 0.019546376774087548, 0.030481526694659675, 0.025740963839260594, 0.01650373075556542, 0.036464597431144545, 0.010900525126739271, 0.02804201009816357, 0.01967022637836635, 0.11390424865697112, 0.026834833535498807, 0.0335177469865552, 0.038938074705324004, 0.08822104002216033, 34.012585503714426, 61.70743111201695, 46.87311397280012, 37.42009673799787, 11.875125391142708, 25.47177815437317, 40.396691117967876, 50.295174734933035, 51.19200651986258, 52.29508168356759, 4.9287910887173245, 0.2051440299089466, 0.07471356554222958, 0.22368490429861204, 40.36035898753575, 56.30063131877354, 53.480892521994456, 49.310573305402485, 44.37893302100045, 42.66958236694336, 41.292557103293284, 41.391242367880686, 42.3807179587228, 44.071211201804026, 44.4945718901498, 45.92589037758963, 45.44149323872158, 46.0701836177281, 40.9329947744097, 35.748339312417166, 37.5223742212568, 35.38713720866612, 35.14763280323574, 35.06155851909092, 35.5666196005685, 41.301030431474956, 42.22870874404907, 45.032977376665386, 44.67151818956648, 44.90325798307146, 44.5208534513201, 44.06094176428658, 40.981406348092214, 38.52226168768746, 36.78332212993077, 33.74848794937134, 32.74228457042149, 33.54196316855294, 33.437893050057546, 33.78909322193691, 34.83042669296265, 35.92963171005249, 35.30521099908011, 34.718734400612966, 35.46413367135184, 34.430373736790244, 35.08610303061349, 34.73564979008266, 35.41590275083269, 36.246643270765034, 36.22027833121163, 35.64337635040283, 35.9130220413208, 34.56104155949184, 35.450539520808626, 40.024090494428364, 41.47260924748012, 42.17241791316441, 38.4086377961295, 37.7524916103908, 36.685623509543284, 35.10891396658761, 35.473683970315115, 37.7591757774353, 37.88367359978812, 45.35117360523769, 50.045894214085166, 48.45074415206909, 45.051654134477886, 47.96123661313738, 49.517869336264475, 38.66106237683977, 38.69237790788923, 37.96872302464077, 42.540460518428254, 43.70492649078369, 41.42029973438808, 44.65063190460205, 47.02804837908064, 46.23379979814802, 45.09126581464495, 43.63710512433733, 43.45897763116019, 37.79958997453962, 35.83117921011788, 35.34221363067627, 35.55867086138044, 35.80095107214791, 35.7102701323373, 35.22406298773629, 35.89933409009661, 35.77122320447649, 36.045621463230674, 34.677872044699534, 35.174247877938406, 36.89157853807722, 34.46726867130825, 34.64788014548165, 34.93538270677839, 35.606505734579905, 36.33362429482596, 34.34015137808663, 35.85511228016445, 34.61585242407662, 35.49394839150565, 37.31038815634591, 37.47768688201904, 35.96842350278582, 37.32196038109915, 35.880327292851035, 35.81811312266758, 37.20014803750174, 39.11326156343733, 38.29205397197178, 39.529128619602744, 39.028486592429026, 40.57663903917585, 38.81905746459961, 39.88633550916399, 38.17565080097744, 42.75537872314453, 42.98339428220476, 48.36829335348946, 45.273187024252756, 48.9527827671596, 43.49404518944876, 51.72695527757917, 49.34696102142334, 59.9387880052839, 54.162378787994385, 68.85588373456682, 18.475442443575176, 0.57842825033835, 1.7415500176804406, 0.05809931669916425, 0.04663839543770466, 31.412778036934988, 65.57493046351841, 55.15734345572335, 51.36735125950405, 34.55887719563076, 17.604906116213115, 34.8684298651559, 55.44571106774466, 57.35610089983259, 21.38949087687901, 0.1739453968725034, 0.047573443834802935, 0.05094714030357344, 0.09716229952339615, 0.029415103739925792, 0.037252573362950764, 0.06780372453587395, 0.029380135437739745, 0.042553841934672425, 0.11041245316820485, 0.09251800552010536, 0.13972630591264792, 0.12843290476926736, 0.11070216726511717, 0.14317082108131476, 0.2484931488122259, 0.11024159126515899, 0.12467069950486932, 0.12035903015307017, 0.32195048140627996, 39.96728202274868, 69.72445719582694, 53.07042421613421, 42.31786455426897, 14.792700903756277, 31.73042188371931, 45.62638827732631, 56.3897454398019, 57.095015389578684, 57.80291175842285, 5.664612701960972, 0.3648511293743338, 0.32441386207938194, 0.613814828651292, 42.91193553379604, 58.015134062085835, 55.98625659942627, 51.13973869596209, 46.34354659489223, 44.95959397724697, 44.44144596372332, 43.946338176727295, 44.61801011221749, 47.746241978236604, 47.16577557155064, 49.86055449077061, 47.61690126146589, 48.37148952484131, 44.36957727159773, 37.343503270830425, 37.98084763118199, 36.817073004586355, 37.17690978731428, 36.90554094314575, 38.431052684783936, 42.925943102155415, 45.162686347961426, 47.51310212271554, 45.65069655009678, 47.253906522478374, 46.880208083561485, 47.22794805254255, 43.78683532987322, 40.640836920057026, 39.5400060244969, 36.66963223048619, 35.5527787889753, 36.88118403298514, 35.368432658059255, 35.34524999346052, 37.378859179360525, 37.55974163327898, 36.71321480614798, 35.665947573525564, 37.3119341305324, 35.68231405530657, 37.74836785452706, 35.735030038016184, 37.57747343608311, 38.43700729097639, 38.49054316111973, 37.241125038691926, 37.42941427230835, 36.56626388004848, 36.450809138161794, 42.20384461539132, 43.72708082199097, 44.053878920418875, 40.11112362997872, 41.843934876578196, 38.71235397883824, 35.691888672964915, 38.40307923725673, 40.36887400490897, 40.187661511557444, 47.44313028880528, 53.22841582979475, 49.10308967317854, 47.242202281951904, 48.70804984228951, 52.22985894339425, 41.80106796537127, 40.15721103123256, 39.64033801215035, 46.1742502621242, 45.75396762575422, 42.87750720977783, 45.829862798963276, 48.7925295148577, 48.519861357552664, 47.27055093220302, 45.38563667024885, 46.21634592328753, 40.25452055249895, 37.44568347930908, 36.96181092943464, 36.42866175515311, 38.67540693283081, 36.56415510177612, 36.36546094076974, 37.903986658368794, 37.476755823407856, 39.06528772626604, 37.40531097139631, 37.51791000366211, 38.05224731990269, 36.0570581981114, 36.271166937691824, 36.764353547777446, 38.708681855882915, 39.53359631129673, 37.60234798703875, 38.826248850141255, 37.670492444719585, 37.60428653444563, 39.700790813991, 38.915620054517476, 37.66480534417288, 40.52875900268555, 37.57734489440918, 37.70701217651367, 38.54489891869681, 41.55559505735125, 40.172962597438264, 44.15392255783081, 40.88663986751011, 42.594545296260286, 41.167805671691895, 43.01360157557896, 39.65018013545445, 45.199678557259695, 45.48287670952933, 52.95887783595494, 49.13502011980329, 50.25032411302839, 46.11119883401053, 54.504862444741384, 52.57885306222098, 62.74372713906424, 57.80342245101929, 70.3776365007673, 20.657458203179495, 0.9205153712204525, 2.913225940295628, 0.15208773474608148, 0.1718481265540634, 35.483956881931846, 69.88450895036969, 59.52272292545864, 57.07582793916975, 33.972546509334016, 23.644487040383474, 43.31205102375576, 63.72749478476388, 63.605220385960166, 29.001756599971227, 0.3002668906535421, 0.09526643196919135, 0.17896856447415693, 0.20600479229220323, 0.17325186622994287, 0.13361191829400404, 0.2628799096814224, 0.12423915123300892, 0.12194647639989853], [0.03590745572000742, 0.0684924375798021, 0.043034122591572146, 0.01684457416247044, 0.0478974714476083, 0.02070742822252214, 0.0393192688934505, 0.03462767082133463, 0.016231478757358024, 0.040689984269972355, 0.023918476454647522, 15.189055681228638, 53.23093107768467, 45.11664063589913, 40.01992504937308, 34.25120401382446, 40.182776927948, 33.7140075138637, 42.01359598977225, 48.11913790021624, 50.42443902151925, 8.217888082776751, 0.20302978264433996, 0.09246391949376889, 0.11677120838846479, 26.030514069965907, 55.66210923876081, 50.344249861580984, 47.289641107831685, 45.55442925861904, 46.701149531773154, 43.80495623179844, 45.334171363285606, 46.30385848454067, 48.114677156720845, 47.140570981161936, 47.052235058375764, 46.863386494772776, 46.05144085202898, 44.8121532031468, 36.046722752707346, 35.18629258019583, 34.23769671576363, 36.0598270552499, 41.173190525599885, 46.66398014341082, 43.50901508331299, 43.89497709274292, 43.210089683532715, 46.66262871878487, 44.04395341873169, 43.396951062338694, 40.47709567206246, 40.596354552677695, 38.726441451481406, 34.9689633505685, 33.064229352133616, 31.339679513658794, 32.14375979559762, 31.041028567722865, 32.49416092463902, 31.703817231314524, 31.62116493497576, 33.3419314793178, 32.71033327920096, 32.29347957883562, 32.59869657244001, 34.31625999723162, 34.82826927730015, 34.5404714175633, 34.66128322056362, 33.58838060923985, 33.356769357408794, 33.500996589660645, 35.40762744631086, 34.12425000326974, 35.23145934513637, 36.84166962759835, 38.17413261958531, 38.453735079084126, 36.55878414426531, 34.2909129687718, 33.74528135572161, 34.147634165627615, 33.532200949532644, 36.08129698889596, 44.54512698309762, 46.96377406801496, 45.74534143720354, 43.19960485185896, 47.37249142783028, 45.021460737500874, 36.61893122536795, 36.82456316266741, 38.90009083066668, 40.762628419058665, 41.1104621887207, 42.61332975115095, 43.03918831689017, 41.331685883658274, 41.711352825164795, 42.351097788129536, 40.53956692559378, 36.04458965573992, 34.57392004558018, 34.866449628557476, 35.23362718309675, 34.64984648568289, 34.428744384220664, 34.722892897469656, 32.92810719353812, 33.328608308519634, 34.980754443577354, 31.34252827508109, 33.59446028300694, 33.348077160971506, 33.07894563674927, 34.9707281930106, 33.094697202954976, 33.20613241195679, 33.29291888645717, 33.253432273864746, 33.28380632400513, 33.06137016841343, 36.434491293770925, 40.26965025493077, 39.407437869480674, 38.78344447272164, 37.68760238374983, 36.80460098811558, 33.65049403054373, 35.22160332543509, 35.823887075696675, 36.11426271711077, 35.48331764766148, 38.39168766566685, 36.129746777670725, 38.17741216932024, 35.345006806509836, 37.79106453486851, 37.13048192432949, 40.88097013745989, 38.86681590761457, 44.26516669137137, 43.55732938221523, 46.47250863483974, 43.703008787972585, 47.20541851861136, 48.37957375390189, 56.355789593287874, 52.74576268877302, 61.27951240539551, 11.908924903188433, 0.632180274597236, 1.6457156858273914, 0.057856163675231595, 0.008641074760816991, 25.648279769080027, 60.81464317866734, 49.65052434376308, 43.75965745108468, 32.12293257032122, 14.983276094709124, 24.452628544398717, 43.31430571419852, 46.492825167519705, 10.649342434746877, 0.06886117386498622, 0.03263005015573331, 0.016192529150950055, 0.05372492017756615, 0.08319800812751055, 0.02835598012565502, 0.04971547032307301, 0.053799962757953575, 0.02844534318761102, 0.018679555073114376, 0.03838730104533689, 0.04001640594963517, 0.0636750492932541, 0.05143213677885277, 0.03220122620197279, 0.02083387322324727, 0.048638221342116594, 0.06201655364462307, 0.015095088664176208, 0.04430379053311689, 19.085035698754446, 60.12786933353969, 49.90707268033709, 43.73008591788155, 26.835283960614884, 36.2342129434858, 39.36692987169538, 48.11388853618077, 51.34621136529105, 56.161365100315635, 7.966069732393537, 0.21019292755850724, 0.04251698391245944, 0.3262569531798363, 29.76863275255476, 58.67647402627127, 53.53822905676705, 49.862496512276785, 47.714902128492085, 46.84185750143868, 46.45908471516201, 46.12096105303083, 47.805214813777376, 49.25008576256888, 48.97152205875942, 49.01968697139195, 48.294840472085134, 48.592897347041536, 47.09090525763375, 36.5468019757952, 36.01866940089634, 35.9809650012425, 37.870423385075156, 41.31514222281319, 47.10532971790859, 44.70114878245762, 45.15105506352016, 45.26106936591012, 47.3694828578404, 45.657175745282856, 45.07842901774815, 42.58324057715279, 42.27107885905674, 39.1469464302063, 37.056157044001985, 34.39172438212803, 32.44351550510952, 33.82839223316738, 33.35118300574166, 33.86077431270054, 34.16710301807949, 34.00506755283901, 33.81467301504952, 33.265504768916536, 33.7476715360369, 33.573834555489675, 36.28035593032837, 36.4119165965489, 35.04653303963797, 35.50208125795637, 34.7159412247794, 34.65723589488438, 34.60907098225185, 36.283020564488, 35.87993124553135, 36.455895219530376, 38.3226329939706, 40.80419601712908, 40.85989277703421, 37.87517247881208, 36.95190627234322, 35.04870087759835, 36.33595888955252, 36.45186873844692, 38.24973249435425, 46.41409512928554, 49.381264277866904, 47.74108641488211, 44.75863470349993, 48.276146343776155, 47.2970027242388, 38.43801825387137, 37.86623362132481, 41.711557797023225, 40.84778554098946, 44.47499186652047, 43.773366246904644, 45.49127360752651, 43.57893133163452, 43.76204763139997, 42.88669272831508, 42.55908169065203, 38.558409690856934, 34.96429763521467, 36.874183722904746, 36.758082798549104, 35.98085035596575, 35.595683915274485, 35.98917429787772, 34.43126310620989, 35.4806147984096, 36.03520958764212, 34.45863553455898, 34.6050306047712, 34.911143915993826, 33.95677409853254, 34.7775821685791, 34.25316687992641, 35.171725681849885, 34.25358724594116, 35.05798019681658, 34.569799763815745, 36.17639698301043, 38.30404656273978, 40.33108970097133, 41.13628169468471, 40.87280600411551, 38.68206330708095, 37.65591859817505, 36.531571524483816, 36.669194493974956, 37.10998126438686, 37.88956567219326, 37.78955330167498, 39.56394256864275, 37.36014768055507, 39.09096132005964, 38.59972020557949, 40.60471323558262, 38.9333553314209, 43.889870166778564, 40.60168382099697, 46.3337287902832, 46.42294366019112, 48.83755384172712, 45.91603088378906, 48.8510924066816, 49.96214757646833, 60.27380929674421, 54.9043630191258, 64.8430072239467, 12.519921694483076, 0.6597404671566827, 0.8570035706673349, 0.06335697243256228, 0.042556328765515766, 27.66491797992161, 66.74784197126115, 54.155545234680176, 48.62301778793335, 29.111788272857666, 18.001832383019583, 30.563617842538015, 50.35862915856497, 55.26884814671108, 15.19697836467198, 0.04166123251031552, 0.015737824175240736, 0.06567955708929471, 0.02572017182995166, 0.026426134930391396, 0.015239077187808496, 0.03047382871487311, 0.037107913089650016, 0.03395033680966922, 0.33291975994195255, 0.17103822715580463, 0.11775327926235539, 0.11528381891548634, 0.1321390766118254, 0.11716085033757345, 0.09306237380951643, 0.12426693045667239, 0.08837710307644946, 0.16266403294035367, 0.12903270258435182, 20.92238085610526, 67.87472166333879, 57.24910906382969, 53.990077359335764, 44.511306626456125, 51.988954475947786, 42.95419795172555, 51.893100602286204, 56.03597443444388, 61.23427268436977, 9.568694319043841, 0.3058854048805577, 0.21570092200168542, 0.5450540440423148, 33.147322859082905, 60.59025805337088, 57.15942519051688, 51.54303993497576, 49.20030539376395, 50.640197958265034, 48.89557824816023, 49.59469556808472, 51.015689032418386, 51.70735788345337, 51.30661358152117, 50.08886534827096, 50.76299694606236, 49.61377879551479, 49.26752921513149, 39.31008665902274, 38.749620641980854, 38.62907634462629, 39.31742395673479, 43.51230158124651, 48.028245040348594, 46.19528245925903, 48.36413138253348, 46.6843626839774, 51.04694550377982, 46.751402378082275, 47.658691201891216, 44.50260748182024, 43.7121456691197, 42.155273233141216, 38.50052424839565, 36.25972672871181, 34.735069615500315, 35.07804659434727, 34.842954295022146, 34.964832646506174, 34.862617697034565, 35.806659017290386, 35.981215136391775, 35.03784779139927, 35.121431146349224, 35.1816338130406, 38.233334745679585, 36.69533014297485, 37.18911082404, 37.679521628788535, 36.833606243133545, 37.38509518759591, 37.209489890507285, 40.94511938095093, 37.59484045846121, 38.8046885899135, 40.718517780303955, 43.14934505735125, 43.27223089763096, 40.25668839045933, 38.74701506750924, 38.50974798202515, 39.31021867479597, 37.98657989501953, 40.02120351791382, 49.445896421160015, 50.26506471633911, 49.74083008084978, 45.63610533305577, 50.947523730141775, 48.39380019051688, 41.082346303122385, 39.91164779663086, 43.29875564575195, 44.823853969573975, 45.63714408874512, 46.395352363586426, 48.29642813546317, 46.34193808691842, 47.43216255732945, 44.342340333121165, 43.732875619615825, 39.007801805223735, 37.62599270684378, 38.97744859967913, 39.72641577039446, 39.1553224836077, 37.03127554484776, 38.2868914604187, 35.04839168276106, 36.95203481401716, 36.95367806298392, 35.49033185413906, 35.666420051029746, 36.863250732421875, 35.90342657906668, 37.72317368643624, 35.35652691977364, 36.64665106364659, 36.49539920261928, 38.306711196899414, 37.51104518345424, 37.79304477146694, 42.01952280317034, 44.74596118927002, 43.22635889053345, 42.15845550809588, 42.14875929696219, 40.23241833278111, 38.14039216722761, 40.173118931906565, 38.62766933441162, 39.219343185424805, 39.23084940229143, 41.62736994879586, 38.242586272103445, 41.502048764910015, 39.277801854269846, 42.97745704650879, 41.55133581161499, 46.38798032488142, 43.415388107299805, 48.22816555840628, 48.9444067137582, 52.491976261138916, 48.97832781927926, 51.875274998801096, 54.2280809538705, 62.203622817993164, 56.33538620812552, 65.45155824933732, 15.26711174419948, 0.9406853403363908, 6.190416327544621, 0.17593765711145742, 0.34422716604811804, 29.948611940656388, 73.31722477504185, 58.47521250588553, 58.280673367636545, 44.49471780232021, 25.961450713021414, 39.206815583365305, 56.713917119162424, 64.1341450554984, 23.677628210612706, 0.08924332088125603, 0.21965892533106463, 0.14987945609859057, 0.15863828467471258, 0.12449752379740987, 0.09099997340568475, 0.09665250937853541, 0.21502636319824628, 0.13973086566797324], [0.013581156597605773, 0.05774453787931374, 0.04042490099423698, 0.07460692019334861, 0.058326320589653084, 0.08259463443287782, 0.06125109829008579, 0.02683095570786723, 0.012951962101007146, 0.018403618629755716, 0.04856608628428408, 6.215324750968388, 56.82711717060634, 44.998427459171836, 41.970468521118164, 24.69493133681161, 31.23403910228184, 36.78977700642177, 44.526999132973806, 48.47807489122663, 54.138341494968955, 14.235077568462916, 0.11831262281962804, 0.16444050547267708, 0.4747014705623899, 13.550154549734932, 54.43032564435686, 52.63797875813076, 50.75248779569353, 49.011092049734934, 46.82058211735317, 47.39068875994001, 48.41300848552159, 47.07785306658064, 49.05094344275338, 45.94010986600603, 48.023916312626426, 46.44601515361241, 46.1428096635001, 42.565887451171875, 34.684139319828574, 33.21632889338902, 35.61268615722656, 40.21500614711216, 43.593717098236084, 43.35394171306065, 42.613746643066406, 44.411165714263916, 44.07881253106253, 43.646780490875244, 44.672647271837505, 44.78473908560616, 42.123929909297395, 39.3340197290693, 38.50967155184065, 36.267651149204795, 32.45050886699131, 33.08359745570591, 32.26578753335135, 33.10648829596383, 33.60968031202044, 32.523742880140034, 31.60063648223877, 33.8113100869315, 33.15042175565447, 32.97625126157488, 33.02784858431135, 34.519901275634766, 33.40462507520403, 34.6605988230024, 35.21397420338222, 34.15146609715053, 34.69890076773507, 32.402927603040425, 35.218216078622, 34.76503719602312, 34.83313649041312, 34.13515520095825, 35.456191880362375, 35.463376317705425, 35.383482456207275, 33.964347634996685, 32.41172054835728, 32.78598179136004, 34.425694125039236, 35.399275711604524, 41.653821740831646, 46.93142672947475, 45.679486410958425, 45.45451416288103, 48.3407541683742, 46.02788993290493, 35.26753439222063, 35.610862255096436, 40.57072959627424, 39.789505413600374, 40.16036203929356, 41.4132125718253, 42.445919854300364, 40.469272000449045, 40.170204162597656, 38.92304073061262, 37.17556183678763, 34.84005689620972, 34.488283497946604, 33.35842302867344, 33.4762019429888, 34.30410759789603, 35.20008475439889, 33.630174023764475, 33.68921981539045, 35.399407727377756, 33.789586544036865, 32.84612887246268, 33.71575151171003, 32.887157985142295, 32.74828086580549, 32.018490723201204, 33.621349811553955, 34.120862756456646, 33.25058698654175, 33.44087035315377, 33.45143856321062, 35.21071202414376, 39.20176076889038, 42.448945794786724, 44.7584227834429, 43.54070929118565, 43.97868551526751, 43.622614656175884, 40.909478596278596, 38.60898910249983, 38.42337145124163, 37.46605907167707, 35.880893571036204, 36.88110065460205, 35.254443986075266, 35.53130190713065, 35.57085452760969, 35.84325170516968, 35.69694001334054, 35.982028075626914, 39.43642922810146, 43.11568798337664, 43.234675884246826, 46.09658677237374, 46.54668412889753, 49.012241976601736, 47.30874170575823, 57.113358633858816, 52.495995794023784, 59.341673714774, 7.006457933357783, 0.3616075691367899, 1.5083473026752472, 0.0524095257611147, 0.07121335621923208, 26.23046064376831, 61.432518686567036, 52.84412138802664, 47.339060170309885, 36.67051465170724, 28.369498320988246, 31.475850309644425, 45.48623616354806, 50.458575521196636, 13.601196885108948, 0.042343438403414826, 0.08994235444281783, 0.04298874556220003, 0.042562856272395165, 0.044526502689612765, 0.07886121262397085, 0.06419777910092048, 0.07927945482411555, 0.05262500473431178, 0.03049304143392614, 0.03534247014405472, 0.05052763602829405, 0.04381936063457813, 0.02443953706616802, 0.06141883214669568, 0.07366854018930878, 0.0674119180600558, 0.03157872460516436, 0.042419990724218745, 0.061053271405398846, 7.955141953059605, 63.42790930611746, 50.3889719418117, 48.34634052004133, 28.771430764879497, 35.72436107907976, 39.54703065327236, 48.428311892918174, 52.10826546805245, 57.133313860212056, 14.512032764298574, 0.2111845114933593, 0.1791332992059844, 0.9011528587767056, 15.609234094619751, 54.534927300044465, 52.112952028002056, 51.694663524627686, 51.14362621307373, 48.49702957698277, 48.71099935259138, 50.81455952780587, 50.35687126432146, 48.98955263410296, 47.96932084219796, 48.799199785505024, 49.16243076324463, 49.14317035675049, 44.68032503128052, 36.1942503792899, 34.60509313855852, 37.1465357371739, 41.97842073440552, 45.33860083988735, 45.01524904796055, 42.691701957157676, 46.41909088407244, 45.131051199776785, 45.64651720864432, 46.0788688659668, 47.074684688023154, 43.71409811292376, 41.8511505808149, 41.20683022907802, 37.87019756862095, 34.68683174678257, 35.03792074748448, 34.261487347739084, 34.9038656779698, 35.58879130227225, 33.30720785685948, 33.623587131500244, 34.202267851148335, 34.939905984061106, 35.29156126294817, 33.61615603310721, 34.8980187688555, 35.389131341661724, 35.10486316680908, 37.268410614558626, 34.04806647981916, 35.24417107445853, 34.91727570125035, 36.332582065037315, 35.5656920160566, 35.23323808397566, 38.08989265986851, 37.25305162157331, 37.94865662711007, 37.83622087751116, 37.29568229402815, 34.338699204581125, 33.850796699523926, 37.1629056930542, 37.875988892146516, 42.56253841945103, 50.30215767451695, 47.88894060679844, 47.62821640287127, 50.41361025401524, 46.595978123801096, 37.895495959690635, 39.24427679606846, 42.287681579589844, 41.508284773145405, 42.184358392442974, 43.28993490764073, 43.62456709997994, 43.005579880305696, 41.94008404867989, 40.77102879115513, 37.22217730113438, 36.45359883989607, 36.27814987727574, 34.57767902101789, 36.44848843983242, 34.822776726314, 37.46374184744698, 34.711761883326936, 35.27107102530343, 36.6618606703622, 35.2638692174639, 35.69449077333723, 35.61631659099034, 34.114140374319895, 33.04822070258004, 32.735378061022075, 35.12226840427944, 36.609137739454, 34.91221393857683, 35.2333527292524, 35.7158008984157, 37.795921325683594, 42.345334257398335, 43.82747881753104, 46.90456846782139, 46.12541137422834, 45.247624601636616, 45.689245155879426, 43.12107631138393, 41.673912457057405, 39.13199043273926, 37.92501538140433, 38.025034700121196, 39.09553670883179, 36.05435534885952, 37.32686928340367, 37.49791308811733, 38.71732541493007, 37.709107058388845, 37.882693903786794, 41.10060616901943, 45.50614275251116, 45.25917598179409, 48.6668643951416, 47.1119270324707, 51.26974296569824, 51.39335836683001, 59.14109311785017, 55.72220768247332, 60.52188083103725, 7.631204775401524, 0.3636410843048777, 2.514469691685268, 0.09358397046370165, 0.024805791609521424, 27.027000393186295, 64.21293067932129, 55.2596105166844, 54.635884625571116, 39.30311761583601, 29.773482595171245, 38.36461748395647, 48.88696595600673, 57.8714314188276, 17.618095534188406, 0.030104261224291155, 0.054968440772167275, 0.00870113359165511, 0.019343311599056636, 0.0730043426156044, 0.0777144952278052, 0.06896181417895214, 0.08672982361167669, 0.01518243647712682, 0.09382187162658998, 0.18303255497344903, 0.11313684590693031, 0.14399188916598046, 0.1392961825643267, 0.13502305400158676, 0.23688935860991478, 0.127576919272542, 0.17809533061725752, 0.10422547587326594, 0.13080629812819616, 9.56817580972399, 73.27525070735386, 56.69305862699236, 54.77063798904419, 33.49626834051949, 41.810833658490864, 47.231637545994346, 57.04721178327288, 55.67359113693237, 63.362742151532856, 17.274892738887242, 0.2427531768168722, 0.33602793887257576, 1.0200105352061135, 18.131322486060007, 57.43369838169643, 55.087913581303184, 54.30352796827044, 54.14531748635428, 50.66790042604719, 52.427583830697195, 51.96612964357649, 52.47218779155186, 49.598579611097065, 48.19247613634382, 48.95047943932669, 49.74544021061489, 50.84867865698678, 47.133032185690745, 38.133047921316965, 37.038932459695, 38.31352390561785, 45.08786814553397, 46.797208377293174, 46.729456492832725, 44.18003388813564, 46.840943813323975, 46.16152116230556, 47.97386843817574, 48.289865561894004, 48.776885645730154, 46.764864512852256, 43.488378933497835, 42.76024941035679, 39.18350090299334, 36.264250005994526, 38.03207322529384, 36.055390630449565, 37.15190322058541, 37.59502805982317, 35.238800116947715, 34.58521434238979, 36.20218522208077, 35.68985979897635, 37.15444278717041, 35.225021839141846, 36.97981023788452, 36.13271713256836, 38.89646734510149, 38.74347496032715, 36.40350580215454, 37.5619581086295, 36.27741684232439, 38.8622578893389, 38.29428781781878, 38.73406362533569, 39.141078676496235, 39.76944596426827, 39.247066497802734, 39.96717779976981, 38.32867792674473, 37.096143926892964, 36.56126812526158, 38.7306729044233, 40.41590288707188, 45.72615398679461, 49.89105708258492, 49.180871282305034, 49.25313254765102, 53.53290673664638, 47.92136090142386, 38.893827029636924, 40.91049998147147, 46.37493508202689, 44.57407317842756, 46.311786379132954, 45.00305495943342, 46.08583443505423, 44.192634446280344, 44.40958847318377, 43.04613651548113, 40.79377024514334, 37.40298332486834, 38.86002056939261, 36.3519675391061, 36.98672716958182, 36.72212587084089, 39.19223478862217, 35.53163194656372, 36.98885679244995, 38.558479172842844, 37.012390341077534, 36.432417256491526, 37.27205841881888, 35.76441049575806, 35.34490605763027, 35.030055386679514, 37.61204072407314, 38.09268930980137, 37.27575486046927, 38.47944688796997, 36.73182903017317, 38.64548451559884, 44.4599802834647, 46.92880031040737, 49.212447370801655, 47.26875482286726, 48.074509620666504, 48.2461370740618, 45.57150445665632, 42.572252001081196, 42.109644412994385, 41.322055680411204, 39.672608920506065, 41.300207069941926, 38.38845675332205, 38.80504642214094, 39.93361105237688, 39.91857862472534, 39.77064800262451, 39.321182932172505, 44.354683807918, 48.04383332388741, 47.86235332489014, 50.30343961715698, 50.21725416183472, 54.146814823150635, 53.347890104566304, 62.43463652474539, 56.95290388379778, 62.789154461451936, 9.805068561008998, 1.0569297884191786, 4.606501936912537, 0.20619091444781848, 0.16967158977474484, 30.82489790235247, 70.71699346814836, 61.63674708775112, 60.44484615325928, 51.06592103413173, 40.324478490012034, 45.50079958779471, 58.636396816798616, 65.49778461456299, 24.600983006613596, 0.0866368439580713, 0.2004369374896799, 0.13029849609094007, 0.1296639030000993, 0.22521877342036792, 0.21389550316546643, 0.099076216109097, 0.15289671133671487, 0.13709213797535214], [0.0017180257522600836, 0.04396529994638903, 0.01590455719269812, 0.04605869243719748, 0.0869945879759533, 0.010908529295453002, 0.014280539604702165, 0.021971377810197215, 0.032343168942523856, 0.045553937022175105, 0.058068416214415004, 2.6526693616594588, 46.82930210658482, 44.43225697108677, 42.13463708332607, 29.38494975226266, 38.91400112424578, 31.144758224487305, 40.79699420928955, 48.645599433353965, 51.7831140926906, 21.916311979293823, 0.06449399356331144, 0.03183817943292005, 0.40757552108594347, 3.2589214018412997, 37.964734758649556, 56.06376028060913, 49.329291752406526, 51.47865445273263, 47.29082577569144, 48.519843987056184, 46.724596227918354, 46.13250201089041, 39.44555916104998, 40.878659861428396, 49.2932653427124, 45.91040631702968, 44.469860621861045, 35.85673121043614, 32.70584126881191, 35.825797830309185, 39.96826866694859, 44.66436849321638, 44.68585579735892, 41.70161839893886, 45.99932241439819, 43.16268907274519, 43.85158906664167, 44.039249488285606, 43.37969521113804, 42.79748133250645, 40.40581062861851, 36.445552825927734, 37.921308517456055, 36.557311126164024, 34.783022608075825, 32.391032287052695, 31.620827947344097, 32.889329297201975, 32.742889063698904, 33.206969669886995, 33.1090521812439, 33.6534400667463, 33.34012842178345, 32.05471168245588, 33.20038972582136, 34.38928556442261, 35.28332417351859, 33.625105312892366, 34.38526603153774, 34.124705110277446, 34.03573342732021, 35.11129372460501, 33.91094378062657, 32.43310015542166, 34.565717697143555, 35.10673223223005, 34.33121599469866, 33.74786955969674, 35.606109687260215, 33.8761055128915, 34.446976457323345, 33.12145471572876, 36.717679023742676, 35.50701100485665, 40.718945094517295, 47.48437132154192, 47.02878141403198, 45.96299375806536, 48.63987759181431, 44.59027637754168, 36.79111453465053, 35.523429598127095, 39.886286871773855, 37.88017865589687, 38.50211191177368, 38.037339959825786, 38.05079862049648, 36.90105240685599, 35.68226194381714, 36.028970105307444, 35.1733272416251, 35.88807453427996, 34.27493558611189, 32.63730076381138, 35.26142692565918, 33.91283369064331, 34.009326798575266, 34.095797130039756, 34.014273915972026, 34.61692244665963, 33.388345445905415, 33.68518986020769, 32.48555905478341, 33.72775452477591, 33.45868900844029, 33.43639918736049, 34.12037638255528, 33.01810373578753, 33.45795597348894, 33.5728166443961, 33.74618114743914, 37.536826474326, 40.055030822753906, 42.796671867370605, 43.01613071986607, 45.0099892616272, 43.6834009715489, 43.450691904340474, 43.884322030203684, 43.95208433696202, 43.7922306060791, 40.647204944065635, 38.00353349958147, 36.906888893672395, 36.190081460135325, 38.96579647064209, 42.7361877986363, 43.74780035018921, 42.706425189971924, 39.67499910082136, 36.12908322470528, 38.486697333199636, 42.17538826806204, 46.57417120252337, 45.94404949460711, 48.61958190373012, 49.827227456229075, 54.041726793561665, 52.00324692044939, 55.81589371817452, 3.5150617488792966, 0.31373730355075424, 0.10536397621035576, 0.04698646354622074, 0.05254435406199523, 23.81936798776899, 64.05522046770368, 49.225617681230815, 51.43843480518886, 25.654342072350637, 22.279716661998204, 41.29107018879482, 47.26996380942208, 48.62189565386091, 12.122516870498657, 0.07917715888470411, 0.04099172879276531, 0.045353246719709465, 0.055985534231045415, 0.01775407401977905, 0.0327609361681555, 0.011294516485317476, 0.023431865066023808, 0.03138914192095399, 0.05808601062744856, 0.056991764344275, 0.04048103619632976, 0.023758549143427184, 0.019322902962033237, 0.015497314045205712, 0.029381163418293, 0.031229784579149315, 0.00875902789578374, 0.03007184082110013, 0.0643922540226153, 4.211000050817217, 54.67832769666399, 50.214165687561035, 49.376018387930735, 29.693279538835796, 40.83781835011074, 41.57314968109131, 45.87967790876116, 52.166630336216514, 56.94229051045009, 23.089657749448502, 0.05513868860102125, 0.05505420759852443, 0.884016864001751, 3.952271716935294, 39.745603220803396, 57.648696490696494, 51.14293834141323, 54.22533988952637, 49.75706454685756, 51.52310555321829, 47.73098373413086, 47.395604610443115, 39.52297946384975, 42.00859328678676, 49.96643461499895, 47.76248686654227, 45.15440756934029, 38.04288462230137, 34.08818537848336, 37.52788414273943, 40.57626036235264, 47.531674657549175, 46.198061738695415, 42.5717899458749, 46.24861683164324, 44.945176465170725, 45.596504075186594, 45.13120058604649, 46.35313858304705, 44.88820471082415, 42.130370889391216, 38.90143183299473, 39.068136487688335, 38.769033908843994, 37.29749577386038, 34.20315374646868, 32.48289442062378, 34.412641933986116, 33.75245884486607, 34.61608518872942, 34.47894859313965, 34.4705308505467, 34.885512011391775, 33.51291275024414, 34.475464071546284, 35.95179646355765, 37.383180958884104, 35.223767689296174, 36.44979817526681, 37.678673948560444, 36.433615820748464, 35.97597272055489, 37.17767408915928, 34.042903968266074, 36.35745661599295, 36.20754228319441, 35.78133283342634, 36.74023287636893, 37.561801774161204, 34.78392587389265, 35.43613243103027, 34.75790139607021, 38.38507298060826, 37.50674424852644, 42.05386080060686, 48.35272938864571, 48.981061935424805, 46.85497222627912, 49.57344102859497, 46.99800784247262, 39.35102891921997, 38.12167719432286, 41.79179559435163, 39.01260648454939, 40.48448160716465, 41.31727531978062, 42.21244995934622, 39.19224868501936, 38.21415771756853, 37.94790274756295, 36.962999071393696, 36.54588828768049, 36.68856259754726, 33.5257773399353, 35.77496133531843, 35.39701754706246, 34.99604742867606, 35.399268763405935, 35.14775092261178, 35.4627023424421, 34.95741891860962, 34.86049502236502, 34.898675373622346, 34.908117975507466, 35.51591512135097, 35.38263477597918, 34.95042208262852, 35.19046149935041, 35.38092204502651, 34.45639821461269, 35.497679574149, 40.05870294570923, 41.19221469334194, 44.29794829232352, 46.316872460501536, 46.96205786296299, 44.5652802331107, 44.718508856637136, 46.275787762233186, 46.486290386744905, 44.57879795346941, 42.767308780125205, 39.89003542491368, 38.58442027228219, 38.06184278215681, 39.17183140345982, 44.63623523712158, 46.6911997113909, 43.195418562207905, 41.93175663266863, 36.804260526384624, 40.928481919424875, 45.668879985809326, 48.62655789511544, 47.543528284345356, 50.81222840717861, 49.72605126244681, 56.92835242407662, 54.161093371255056, 59.36264337812151, 4.550871184894016, 0.47935247527701513, 1.1739956438541412, 0.025127997355801717, 0.0982132281309792, 25.8648898601532, 67.89038985116142, 53.75156307220459, 55.90218339647566, 32.250459807259695, 32.18417051860264, 48.7768474306379, 52.760704789842876, 56.31556299754551, 15.546352897371564, 0.09183162663664136, 0.04163271029080663, 0.05583384433495147, 0.01468408982535558, 0.006299229039411459, 0.025605959119275212, 0.017285065525876622, 0.06271305627056531, 0.03695900857980762, 0.10808089827852589, 0.20867328053074224, 0.18296012814555848, 0.14795016390936716, 0.19042877666652203, 0.2026761844754219, 0.08704881649464369, 0.08568381438297884, 0.06279532185622624, 0.1692918272955077, 0.17396013465310844, 4.661996330533709, 61.9554956981114, 58.19375140326363, 53.382995877947124, 39.96914413997105, 50.03117445537022, 40.44587046759469, 52.63581786836897, 55.385577883039204, 62.245840072631836, 26.196133068629674, 0.13497808070055076, 0.27801018208265305, 1.3631198555231094, 4.743252907480512, 41.157282624925884, 58.6808305467878, 54.81022882461548, 56.81199789047241, 51.461589676993235, 52.06570080348423, 49.03399331229073, 46.44837754113333, 39.145605427878245, 43.40195723942348, 51.91680785587856, 50.07844999858311, 47.458461488996235, 38.744604042598176, 36.26089402607509, 39.40149368558611, 44.4802759715489, 48.6496467590332, 47.61800602504185, 44.756307056971956, 48.28804165976388, 46.959726742335725, 46.54210179192679, 48.791011333465576, 48.48813588278634, 48.77714272907802, 44.6299193246024, 40.79520157405308, 41.32678392955235, 39.60903985159737, 39.934368406023296, 36.97739921297346, 35.83212069102696, 37.01830325807844, 35.772803919655935, 37.03433970042637, 36.41480009896414, 36.183897563389365, 36.16111094611031, 35.363773890904014, 36.4295198576791, 38.21541881561279, 39.112959316798616, 36.5330410684858, 38.39033971514021, 38.20408630371094, 37.21323149544852, 38.85863092967442, 38.53387212753296, 34.94785124914986, 37.671058722904746, 38.909682818821494, 38.09211608341762, 37.78550597599575, 38.95729534966605, 37.46562828336443, 38.022804328373496, 38.74185255595616, 40.71151052202497, 39.92667327608381, 44.221094267708914, 50.65238509859358, 51.195279121398926, 49.362733432224815, 52.42526660646711, 49.34644685472761, 41.67209897722517, 39.520151547023225, 43.94786330631801, 40.891006810324534, 41.02968938010079, 42.60266774041312, 42.40055159160069, 40.60932336534773, 39.04130949292864, 39.632291998182026, 37.60163927078247, 39.89907503128052, 38.88645151683262, 35.941853591373985, 39.70393139975411, 36.7634676524571, 36.32367100034441, 36.69024058750698, 36.866783891405376, 39.37789412907192, 35.99225582395281, 36.61444616317749, 36.17465993336269, 36.03860378265381, 37.19774396078927, 36.67809861046927, 38.35450438090733, 36.59880576814924, 36.36731958389282, 36.48089483806065, 36.578364167894634, 42.94253192629133, 43.60242666516985, 47.6547863142831, 47.52310405458723, 48.622798919677734, 46.72188990456717, 47.775535583496094, 48.11372177941458, 48.48157330921718, 47.51426247188023, 45.217000416346956, 41.170463357652935, 39.74626677376883, 41.14541162763323, 42.75854710170201, 47.308901514325825, 48.53591169629778, 45.97892597743443, 45.44909109388079, 39.07188504082816, 43.31229073660714, 47.82388809749058, 51.12542193276541, 50.370465414864675, 53.72253002439226, 52.71006631851196, 60.14082077571324, 55.12312705176217, 61.488048689705984, 5.0737596069063455, 0.7325119365538869, 2.2101368563515797, 0.13572280002491816, 0.2022108044475317, 28.895369257245743, 76.29960005623954, 57.70269441604614, 63.944473130362375, 36.92214713777815, 34.32883971078055, 54.20872327259609, 60.58890315464565, 65.25090817042759, 21.633178097861155, 0.18803308664688043, 0.089894477011902, 0.13919738786561148, 0.10325737603540931, 0.10426360954131399, 0.12358748620109898, 0.1022898665230189, 0.06627941597253084, 0.1659945813672883], [0.05587367434054613, 0.09184433559754066, 0.01881998128789876, 0.060185289409543784, 0.10757454152085952, 0.07903868345809834, 0.04714665548609836, 0.035319359241319556, 0.017122546210885048, 0.04587934206106833, 0.05600223297785435, 0.4685247934290341, 35.33282314028059, 50.94209371294294, 40.47264535086495, 27.533572707857402, 36.622030121939524, 26.96029942376273, 37.00796433857509, 50.89076736995152, 51.24434035164969, 30.622476032802037, 0.02183169968027089, 0.09248423483222723, 0.5931272730231285, 0.9610264088426317, 21.42966362408229, 47.39274542672293, 51.26276350021362, 48.923437050410676, 46.52917466844831, 47.57379116330828, 48.30908080509731, 47.94440460205078, 43.32690279824393, 47.98201520102364, 47.06237595421927, 42.893957069941926, 34.66673060825893, 30.260089261191233, 35.1667994090489, 40.09608425412859, 44.72205243791853, 46.29523924418858, 43.09000744138445, 38.530960832323345, 45.29871470587594, 44.85581568309239, 42.765999044690815, 42.95274230412075, 41.33279064723423, 40.11850609098162, 37.56179830006191, 37.19745561054775, 35.72142546517508, 34.85236215591431, 32.286090169634136, 32.613155773707796, 33.14466864722115, 32.3619818687439, 32.818909304482595, 32.71410962513515, 33.24282932281494, 34.72472374779837, 33.08138445445469, 32.624783584049766, 32.938157762799946, 33.88776111602783, 35.22038044248308, 35.75161191395351, 34.73349584851946, 34.75134924479893, 34.647619588034495, 33.77762522016253, 33.74199833188738, 33.671755518232075, 34.634484018598286, 33.310900824410574, 34.29165642602103, 34.3669992174421, 36.13566664287022, 33.39297989436558, 32.93900891712734, 34.37280443736485, 33.668854645320344, 34.9995562689645, 41.01258291516985, 46.91943761280605, 46.03640147617885, 44.365519523620605, 49.02867099217006, 44.81031193052019, 36.973904269082205, 35.093916279929026, 36.22703545434134, 36.5356570652553, 35.090400491442, 37.688234669821604, 37.10983535221645, 34.97359085083008, 34.937366417476106, 33.99124411174229, 33.952778884342735, 34.583209787096294, 33.582967962537495, 32.639868123190745, 36.392413003104075, 34.10893269947597, 32.87564482007708, 33.20167166846139, 34.31707293646676, 34.318170751844136, 33.06847470147269, 32.824328899383545, 32.01077822276524, 32.85609606334141, 31.89437505177089, 33.327889169965474, 33.69081442696707, 34.41219030107771, 33.45188324792044, 34.39543472017561, 33.73937191282, 35.893765108925955, 38.42288160324097, 40.765508447374614, 44.70603336606707, 44.58467960357666, 42.74503285544259, 43.19191319601876, 42.20840610776629, 44.58333512714931, 41.44508048466274, 43.61510712759835, 41.46853065490723, 37.83093329838344, 36.79754856654576, 43.22582735334124, 47.865566866738455, 48.090622493198936, 49.158345222473145, 47.82067802974156, 44.90019382749285, 41.53078998838152, 42.4680290222168, 46.74975218091692, 48.75821931021554, 50.943288803100586, 50.353219985961914, 53.00764029366629, 56.131814411708284, 45.920449938092915, 1.1891976509775435, 0.23740398670945848, 1.9856047332286835, 0.12900903528290136, 0.04261060817433255, 24.65725299290248, 61.587366240365164, 50.85670035226004, 47.552349022456575, 30.20571960721697, 13.870314512934003, 30.466488974434988, 47.52660247257778, 47.0623516355242, 8.639371020453316, 0.08753284945019654, 0.055920988587396483, 0.04290403385779687, 0.03861720228035535, 0.10704079908984047, 0.04718267212488821, 0.07946415884154183, 0.049824168240385394, 0.058904215294335566, 0.08756485594702618, 0.06427931186876126, 0.010282117640599608, 0.0468373826172735, 0.10650789804224457, 0.015700162089030658, 0.03451251664331981, 0.06109494702624423, 0.013468250066840222, 0.029601320890443664, 0.02950878906995058, 0.7726697559867586, 41.68395607812064, 55.915061882564, 45.577577182224815, 32.575760568891255, 40.61934266771589, 31.146641186305455, 43.02962759562901, 55.784942967551096, 56.33362831388201, 31.044846602848597, 0.01948922885847943, 0.09174916427582502, 0.6286874477352414, 1.1438157090118952, 22.384021282196045, 48.646728515625, 50.712657247270855, 51.66343484606062, 47.72616515840803, 48.058330740247456, 48.42450775418963, 48.79093837738037, 44.71975258418492, 49.21618550164359, 47.73226567677089, 45.07526411328997, 36.67037916183472, 32.70034524372646, 35.43313775743757, 41.336778913225444, 44.5218574660165, 47.1155435698373, 45.39116048812866, 41.47705609457833, 45.34882164001465, 45.37572506495884, 43.7105302129473, 44.95155143737793, 43.663348470415386, 42.14689717973982, 39.8005495752607, 37.77592441013881, 37.23434359686715, 37.99325016566685, 33.56368671144758, 35.10804891586304, 33.71151311056954, 35.93512773513794, 35.09459720339094, 34.93484422138759, 35.102723121643066, 35.78901406696865, 35.00929069519043, 35.18848821095058, 34.482419218335835, 35.0077759878976, 37.36986821038382, 36.69478470938546, 36.23736047744751, 35.650237696511404, 35.33270154680525, 35.29603590284075, 35.56745685849871, 35.02816547666277, 35.61614983422415, 35.2059976713998, 36.04431520189558, 36.293248312813894, 37.18311105455671, 34.733801569257466, 34.937769412994385, 35.57358864375523, 35.56711292266846, 38.296841280800955, 43.04209613800049, 49.12672049658639, 48.77905695778983, 46.03336163929531, 49.31926550183977, 47.08844212123326, 38.728275775909424, 37.46655934197562, 38.22581679480416, 38.76452800205776, 37.9064393724714, 38.93716294424874, 39.04985230309622, 38.04131432941982, 38.79489510399954, 35.23998825890677, 35.859163079942974, 36.280112743377686, 34.977506160736084, 35.92253759929112, 37.502120222364155, 35.11677932739258, 35.342654841286794, 34.98998165130615, 35.909363814762656, 35.94788462775094, 34.591683115277974, 34.65512016841343, 34.43431683949062, 35.39939383098057, 33.43706621442522, 35.073096002851216, 35.70827947344099, 35.45987095151629, 35.08418532780239, 35.2318241255624, 35.822386264801025, 37.52443436213902, 39.91151578085763, 44.965857778276714, 46.279320921216694, 46.86469275610787, 44.227090563092915, 45.96445287976946, 43.9494092805045, 45.863363538469585, 44.2493908064706, 44.89574350629534, 43.74487515858242, 39.47241742270333, 38.356825079236714, 44.87653521129063, 49.363251073019846, 50.74776649475098, 50.8270662852696, 50.481428146362305, 46.67094223839896, 45.55048268181937, 43.146631785801475, 47.86654656273978, 50.79400328227452, 53.975850922720774, 53.1301509312221, 57.2939110483442, 57.3417945589338, 48.71978187561035, 1.557299098798207, 0.23034931240337236, 1.9538692704268863, 0.12384725654763834, 0.015422520826437643, 27.111902168818883, 65.70446572984967, 55.950372627803254, 54.78571905408587, 28.238693271364482, 15.438581126076834, 36.4173709324428, 53.90929412841797, 56.15106092180525, 12.171840395246234, 0.06199096608906984, 0.08092308377048799, 0.037675521203449795, 0.06449384428560734, 0.07373481948993035, 0.06716146399932248, 0.09257171835218157, 0.06901965928929192, 0.050115246192685196, 0.09377834360514369, 0.18451419046946935, 0.12988837595496858, 0.11903162566678864, 0.23624160193971225, 0.18320856695728643, 0.10938242343919617, 0.17514819518796035, 0.17487110862774508, 0.07931494899094105, 0.12153890755559717, 1.0376524456909724, 47.647518498556956, 64.84606443132672, 52.665055888039724, 38.43771948133196, 45.81791189738682, 36.24800164358956, 47.75169978822981, 60.11577251979283, 61.442815916878835, 35.15212481362479, 0.20303489879838058, 0.30115270454968723, 2.6234378559248785, 1.9439442030021121, 25.55085907663618, 49.73579611097063, 50.26257726124355, 52.584623541150776, 47.09468160356794, 49.02219179698399, 50.142588819776265, 49.89703253337315, 46.59934452601841, 52.98075076511928, 51.53515372957502, 48.25598961966378, 39.07417794636318, 33.519218240465435, 38.984768526894705, 43.84478678022112, 47.86910697392055, 48.8715409551348, 46.749498571668354, 43.55244132450649, 48.95610748018537, 48.34627798625401, 46.17972196851458, 48.27692801611764, 44.93505641392299, 45.153038774217876, 41.66639103208269, 40.62661395754133, 40.338472161974224, 41.334267139434814, 35.47537585667202, 36.18810469763619, 37.10950183868408, 37.91925185067313, 36.820442880902974, 36.35521929604666, 36.452712944575715, 37.42270578656878, 36.553444453648154, 36.66752692631313, 37.104179518563406, 36.135277543749126, 38.417399474552695, 39.36213561466762, 37.702742508479524, 37.45129067557198, 37.777157715388704, 37.51327902930123, 37.847692353384836, 37.03067452566964, 38.1171087537493, 35.90086964198521, 38.18305063247681, 38.951170512608115, 39.836172989436555, 37.22968830381121, 36.630357537950786, 38.95008659362793, 36.91541085924421, 39.28307901109968, 42.92787817546299, 50.60777071544102, 50.65019294193813, 48.48828526905605, 52.6978930745806, 48.40008136204311, 41.29531553813389, 39.51429074151175, 41.25901814869472, 41.61806978498186, 39.11401196888515, 42.0506020954677, 42.6666328566415, 39.344299588884624, 40.59520809991019, 38.20313092640468, 37.96335554122925, 38.46539763041905, 37.1619815826416, 36.74849081039429, 42.64125108718872, 37.53945984159197, 36.235897881644114, 36.490504196711946, 38.01071793692452, 37.767187050410676, 36.28982285090855, 36.40928322928292, 35.86727857589722, 37.452760219573975, 34.91867923736572, 37.60360213688442, 37.39320026125227, 37.994952474321636, 36.107484749385286, 38.17925691604614, 36.78965541294643, 38.97687884739467, 42.41995791026524, 46.10784632819039, 48.14812231063843, 49.04895625795637, 45.32501016344343, 47.66637243543352, 45.87383099964687, 49.390314306531636, 46.29247038705008, 48.74784564971924, 44.83251142501831, 41.26206145967756, 39.61833654131208, 48.03754867826189, 52.0017009462629, 51.800130231039866, 51.2145881652832, 50.49674197605678, 49.87831061226981, 48.08982345036098, 46.78805759974888, 51.01246506827218, 53.40790516989571, 56.15823841094971, 55.77036564690726, 58.56818635123116, 59.95033591134207, 54.03603274481637, 2.2924430455480302, 0.6874074339866638, 5.691491373947688, 0.39597585637654575, 0.14869955155466283, 30.52155692236764, 72.29243496486119, 60.802164213997976, 61.761821610586985, 40.24528292247227, 22.86302661895752, 45.07832826886858, 61.23719787597656, 63.145228794642854, 16.30138237135751, 0.21594128624669143, 0.18255234217005117, 0.2523235875580992, 0.2123243689004864, 0.2132168867226158, 0.11212887535137789, 0.248944917427642, 0.15405752190521785, 0.16763151995837688], [0.023143511431823884, 0.03688306694052049, 0.08507995214313269, 0.02241024068955864, 0.009234758127214653, 0.006860601416389857, 0.02089327048244221, 0.06023560956652675, 0.005331356086701686, 0.10719532186963729, 0.07300250378570386, 0.2724922810282026, 19.49054993901934, 50.98196595055716, 38.27688258034842, 27.806966951915197, 45.85500832966396, 34.257540770939414, 34.43181896209717, 48.573501450674875, 50.45140845435006, 35.604574135371614, 0.5660269100751195, 0.024943795454289232, 0.1970568560063839, 0.3323472663760185, 6.9290801882743835, 36.8855162348066, 42.10360642841884, 43.71274668829781, 46.12930931363787, 52.65964324133736, 49.09544318062918, 48.4186087335859, 47.62387030465262, 43.73455013547625, 39.2699225970677, 33.01837124143328, 31.606483391353063, 34.35564933504377, 40.93913698196411, 47.96635743549892, 45.17726714270455, 45.061600480760845, 46.39165244783674, 44.09460578645979, 40.41924844469343, 41.93166978018624, 39.93057468959263, 40.045133113861084, 39.44358934674944, 34.27931295122419, 33.13183185032436, 33.97284528187343, 32.84186962672642, 33.62249973842076, 33.33853728430611, 32.74580383300781, 31.482200963156565, 32.09475415093558, 31.969530241830007, 33.15537582124983, 31.87959623336792, 33.72971044267927, 32.38158968516758, 32.8263577733721, 32.80522830145699, 34.1290477343968, 35.08731549126761, 34.64110565185547, 34.409775802067344, 34.151733602796284, 34.2783853667123, 37.338451930454795, 35.98679106576102, 33.941581862313406, 34.810659067971365, 34.865626267024446, 34.60719149453299, 34.09470278876168, 33.33650493621826, 31.9012086050851, 32.15971980776106, 31.87331853594099, 34.559422629220144, 35.985495226723806, 41.08948905127389, 46.78741141727993, 46.15719938278198, 45.91081278664725, 46.67627150671822, 45.75596175874983, 36.9257150377546, 35.46453319277082, 36.03179802213396, 35.51661341530936, 35.77097306932722, 36.55685601915632, 35.276164054870605, 33.59721524374825, 33.40288455145699, 35.74914877755301, 34.19764729908535, 33.34433208193098, 32.91824769973755, 35.198636054992676, 34.2816093308585, 34.91764742987496, 35.398834500994, 34.65088176727295, 35.23518010548183, 33.04818248748779, 33.516536235809326, 33.051871980939595, 33.60944754736764, 32.75489902496338, 32.819656235831125, 33.34349134990147, 33.6998609815325, 33.50907039642334, 33.50821924209595, 34.467702933720176, 33.524200098855154, 32.752425466264995, 36.07018334524972, 43.22755398069109, 45.31124925613403, 44.6196220942906, 44.656204359872, 46.62380913325718, 44.65896279471261, 44.234573772975374, 44.05592169080462, 42.39749091012137, 40.71188572474888, 39.08455855505807, 38.35160003389631, 43.75787871224539, 45.6676709992545, 49.66574437277657, 50.115754876817974, 51.45471790858677, 49.67004530770438, 49.44311366762434, 46.38811581475394, 46.96430560520717, 47.16555322919573, 51.094641413007466, 51.59220538820539, 50.093082904815674, 55.69918482644217, 37.75001457759312, 0.29819790167467936, 0.4083552935293743, 0.4558235949703625, 0.28998597232358797, 0.04477423243224621, 24.181516783578054, 59.83457197461809, 50.294969763074604, 46.768449783325195, 33.768568243299214, 34.48045982633318, 41.40136241912842, 46.58834205354963, 43.51652956008911, 3.5927582425730566, 0.09347086546144315, 0.024832234119198153, 0.08264018448867969, 0.04939694223659379, 0.015949008021769778, 0.026002788450568914, 0.036754827214671035, 0.028397043368646076, 0.0238814386206546, 0.054530629622084756, 0.011047198952707862, 0.023552361010972942, 0.010294556035660207, 0.011624710285104811, 0.018426709176440324, 0.037624573401574574, 0.05594717325376613, 0.04645584916163768, 0.07382077630609274, 0.1211437423314367, 0.25433699094823425, 26.187946353639873, 57.24870606831142, 44.06281082970755, 34.20819813864571, 45.99806479045323, 33.56031683513096, 42.856398582458496, 52.11894832338606, 53.41496801376343, 39.275964055742534, 0.4067365803888866, 0.05372596851416996, 0.8267788525138582, 0.5428161269852093, 10.417662569454738, 38.73723547799246, 44.21958998271397, 43.65882519313267, 47.49858733585903, 51.6138733455113, 51.70464808600289, 49.722215856824604, 49.76584359577724, 46.25245223726545, 42.77753305435181, 35.05177198137556, 33.47794941493443, 36.133245195661274, 42.32423257827759, 46.92930058070591, 47.481571197509766, 47.14007765906197, 48.67738744190761, 42.71199417114258, 42.8740747996739, 44.64878715787615, 43.91217041015625, 44.25411558151245, 41.292015143803184, 36.553746700286865, 34.526064327784944, 35.456730365753174, 34.502871240888325, 34.26341894694737, 34.203535897391184, 33.70024313245501, 34.150872026171, 34.892991747174946, 34.76466546739851, 34.865900720868794, 33.24079350062779, 35.65284674508231, 33.27355773108346, 34.18279205049787, 34.6658308165414, 34.78387723650251, 35.54982233047485, 36.23950399671282, 36.39044318880354, 36.08853006362915, 35.5091302054269, 40.06199639184134, 36.85587174551827, 35.00619179861886, 34.694860390254426, 37.05725833347866, 36.22569792611258, 35.38290922982352, 34.48265893118722, 34.522482531411306, 34.48917981556484, 35.37566225869315, 36.15395082746233, 38.04310001645769, 43.96101624625069, 48.05905335290091, 46.41308069229126, 46.63417584555489, 48.565208775656565, 46.482243061065674, 39.2909061568124, 36.65388413837978, 38.1650686945234, 37.70978798185076, 37.13040549414498, 38.77745165143694, 37.305267333984375, 36.19589710235596, 36.2979279245649, 35.83594567435128, 34.89557647705078, 33.84952517918178, 35.06580386843, 37.40328209740775, 36.27001353672573, 36.76211275373186, 36.50024904523577, 36.78803300857544, 36.018784046173096, 36.18834441048758, 36.241626671382356, 34.668078558785574, 34.724755014692036, 33.56271048954555, 35.19986588614327, 34.977641650608604, 35.328265122004915, 35.220741748809814, 35.707119124276296, 35.428305285317556, 35.3371136529105, 36.27371345247541, 36.99862595966884, 43.75397729873657, 47.42700004577637, 45.69268798828125, 44.70348685128348, 46.58735540934971, 46.07831301007952, 46.26656750270298, 45.18851975032261, 44.46470505850655, 42.193835735321045, 42.00577579225813, 40.650533131190706, 44.82011236463274, 47.75279760360718, 51.43879958561489, 51.249103341783794, 53.050545419965474, 51.85170323508126, 51.65910611833845, 49.84866264888218, 48.08624860218593, 50.20649835041591, 54.17445475714547, 53.26999385016305, 54.1871143749782, 57.32130432128906, 40.85050228663853, 0.7241201954228538, 0.6945632100105286, 1.5537404268980026, 0.257367871169533, 0.01455088661584471, 25.463120698928833, 65.76103101457868, 55.875391142708914, 51.02471126828875, 33.048905100141255, 33.23153155190604, 44.761511257716585, 53.51097822189331, 51.99249110903059, 5.75167406456811, 0.05375756110463824, 0.07239250758928911, 0.055946772918105125, 0.09602930210530758, 0.015086737594434192, 0.040870437265506813, 0.02198306387955589, 0.019594707127128328, 0.006263547851371446, 0.21431865117379598, 0.14808287178831442, 0.13032179698348045, 0.06927125328885657, 0.18316233158111572, 0.07965563463845424, 0.13297841085919312, 0.23315969588501112, 0.10393253194966487, 0.19603624434343406, 0.147494391937341, 0.4554196766444615, 31.106550080435618, 65.30511106763566, 51.73286819458008, 38.402127334049766, 52.6659973689488, 43.58921119144985, 44.76276888166155, 57.10171692711966, 58.603142738342285, 43.87553950718471, 0.8492005808012826, 0.14822889252432755, 2.061989103044782, 1.3894895719630378, 8.739024690219335, 42.44841078349522, 43.432254859379356, 44.3456963130406, 48.774022987910676, 54.775453090667725, 52.49131270817348, 52.03483690534319, 51.75024216515677, 48.67619235174996, 43.58456284659249, 36.6612457547869, 35.029721873147146, 38.60244042532784, 45.51902123859951, 50.84440551485334, 47.72279528209141, 49.92637130192348, 50.60928889683315, 47.34902736118862, 44.071450914655415, 45.907470703125, 46.15278727667672, 45.921075275966096, 44.09725652422224, 39.22764975684029, 36.61015912464687, 37.753356661115376, 37.065161909375874, 36.76599679674421, 36.26979119437081, 35.42217697416033, 35.73099660873413, 35.48068080629621, 36.05181230817522, 37.772193227495464, 35.943295342581614, 39.282095840999055, 35.514751298086985, 36.17677913393293, 35.68607303074428, 35.75782012939453, 37.80123322350638, 37.615500926971436, 37.633944920131135, 37.883944579533164, 36.155444690159385, 42.14423949377877, 39.73285327638899, 37.512570313044954, 36.59646422522408, 38.6586583001273, 38.35308000019619, 38.08842658996582, 36.05892378943307, 36.20722614015852, 36.64417403084891, 38.18685129710606, 38.82996613638741, 39.765325682503835, 45.59512833186558, 49.807890619550435, 47.079204491206575, 47.65208346503121, 50.86271749223982, 48.515327657972065, 42.326337882450645, 38.6846410887582, 40.03304672241211, 39.599996771131245, 40.29840537479946, 40.690269878932405, 38.84633261816842, 37.76028748920986, 38.36173745564052, 37.43930503300258, 36.84313222340175, 35.431348596300396, 37.54379899161202, 38.98065171922956, 37.609421253204346, 38.45455844061715, 38.88663216999599, 38.351551396506174, 38.67697375161307, 36.810694558279856, 37.89307451248169, 37.37193529946463, 37.10667739595686, 36.18261909484863, 37.46733406611851, 37.27113083430699, 37.93124444144112, 37.032884052821565, 37.41560125350952, 36.5393500328064, 37.47432047980172, 37.08829246248518, 38.79527725492205, 47.645347186497276, 48.862991196768625, 49.08315529142107, 46.55483089174543, 50.37051057815552, 47.28727872031075, 47.56019353866577, 46.17726578031267, 47.35976232801165, 44.452024596078054, 43.31048420497349, 41.86997325079781, 46.91718987056187, 48.73675285066877, 54.195778778621126, 54.67875501087734, 55.44381768362862, 54.13191441127232, 55.414211409432546, 52.99800661631993, 50.95725120816912, 51.86048575810024, 57.56889990397862, 56.483827522822786, 56.023971421378, 59.146019390651155, 42.73927627290998, 0.8148789224880082, 1.1497780233621597, 2.451357466833932, 0.5146774968930653, 0.1653905359229871, 28.22057236943926, 70.18421254839215, 60.55459989820208, 58.92503888266427, 45.76083244596209, 44.95756162915911, 54.745971884046284, 60.02622413635254, 62.51574979509626, 8.398462210382734, 0.3349808507731983, 0.15071630690779003, 0.13577983767858573, 0.2114672977477312, 0.12997127936354705, 0.14508723467588425, 0.15362026036850043, 0.0854521489569119, 0.07196429092437029], [0.06986852695367166, 0.05605930795094796, 0.03535264816933444, 0.050428298501563926, 0.02160003934321659, 0.0632591683949743, 0.05358284851536155, 0.013369256896632058, 0.022578875301405787, 0.032466021100325246, 0.10308801369475466, 0.02800748623641474, 11.005264776093618, 52.333838735307964, 40.25020572117397, 30.430636269705637, 32.05235276903425, 30.190614223480225, 28.39564265523638, 50.61224882943289, 48.080512864249094, 43.07994644982474, 0.9478376422609601, 0.11400319263339043, 0.06741195198680673, 0.5991409389036042, 3.994219728878566, 24.53399542399815, 44.31115681784493, 46.939069747924805, 53.21086468015398, 47.91425289426531, 47.750633239746094, 44.83603416170393, 38.43278278623308, 34.44825839996338, 33.74760552815029, 34.0471111025129, 37.97396544047764, 42.35948426382882, 47.222910608564106, 46.84451866149902, 45.4515438079834, 43.56578186580113, 42.71824407577515, 42.5320531981332, 39.30792229516165, 41.48279530661446, 40.43571220125471, 36.76900884083339, 33.63964441844395, 32.50804342542376, 34.073271070207866, 33.56565305164882, 32.53093079158238, 33.502094405038015, 33.301520756312776, 30.53369195120675, 32.45890576498849, 33.201894010816304, 33.53928116389683, 32.6063882282802, 32.82472147260393, 34.20992476599557, 32.397428103855674, 32.77953386306763, 32.38044670649937, 34.17131362642561, 34.2417197227478, 34.92956706455776, 35.73874037606375, 34.781660761152, 36.026062284197124, 36.136187757764546, 37.16606364931379, 33.46746458326067, 34.63494259970528, 35.01683643886021, 33.51189831324986, 32.49401501246861, 34.01781054905483, 32.91635084152222, 33.355886936187744, 33.654322487967356, 33.16802501678467, 35.544611181531636, 41.54176466805594, 47.996356282915386, 46.28781509399414, 46.86657919202532, 46.9707396371024, 45.10991825376238, 35.952230725969585, 33.773643902369905, 34.56866373334612, 34.470992905753, 34.711417947496685, 34.83767713819231, 36.19998959132603, 33.98736354282924, 33.19922590255737, 32.61367688860212, 34.44663599559239, 34.71887336458479, 34.662085737500874, 32.86098412105015, 34.476259640284944, 36.83203942435128, 34.57370465142386, 36.39287853240967, 34.67019081115723, 32.95245368140084, 32.04971940176827, 32.04680463245937, 32.53028460911342, 32.98126786095755, 33.08039781025478, 33.33887079783848, 32.755555629730225, 33.83231796537127, 35.13623080934797, 34.24573578153338, 34.7100248336792, 32.880418232509065, 36.58956813812256, 43.544777461460654, 45.69208002090454, 43.19591188430786, 43.46305274963379, 44.703611918858115, 44.457041195460725, 45.746647698538645, 43.075100081307546, 42.74926083428519, 40.29618542534964, 38.441454138074604, 39.48944398335048, 41.691331590924946, 44.55457305908203, 46.853384562901084, 50.675175189971924, 52.14932237352644, 52.37955093383789, 50.22565800803048, 49.30280521937779, 49.94301223754883, 48.77895968300955, 50.56329182216099, 51.75162833077567, 56.92463861192976, 53.78699541091919, 26.144181387765066, 0.8184531192694391, 0.29798106902412, 0.8505961373448372, 0.061555808010910235, 0.07453450693615846, 24.228267737797328, 61.28755841936384, 49.36617626462664, 49.29674986430577, 35.305231843675884, 19.211852482387, 37.390101364680696, 45.28856686183384, 43.38745982306344, 2.299356068883623, 0.09289850081716265, 0.042599039152264595, 0.04101496522447892, 0.05367381970531174, 0.035200914168464284, 0.006280203341572944, 0.052202952560037374, 0.015597744013315864, 0.02142415288835764, 0.007738175352902285, 0.04030029482341238, 0.049068626282470565, 0.03384152693407876, 0.057589146574693065, 0.06087596341967583, 0.04211461943175111, 0.025754765241539905, 0.05657951360834496, 0.043918918685189316, 0.11422820841627461, 0.011353588895872235, 15.038931165422712, 61.49728979383196, 44.144365310668945, 35.283428396497456, 36.70608942849295, 32.43439252035958, 35.17330639702933, 54.482027190072195, 52.28200169972011, 46.936068126133506, 1.070305722100394, 0.08964477612503938, 0.3384957435939993, 2.0137573140008107, 4.297429127352578, 25.53747684614999, 44.251398835863384, 47.34721040725708, 55.81831169128418, 50.36193650109427, 50.34642464773995, 46.926542145865305, 42.62944957188198, 37.572057315281455, 35.90475715909685, 35.053158146994456, 40.16568783351353, 44.76144872392927, 48.83782134737287, 47.78418261664254, 46.42578547341483, 46.86261524472918, 44.110510213034495, 44.36290005275181, 42.24480077198574, 43.36364139829363, 42.73369686944144, 38.25650003978184, 37.057032517024446, 34.21280479431152, 35.53523806163243, 34.555024419512065, 34.9679662840707, 35.132822717939106, 36.065722601754324, 32.833351135253906, 34.74212898526873, 33.83061218261719, 33.55134671075003, 33.83260978971209, 34.92616244724819, 35.35998364857265, 33.56317949295044, 34.75332600729806, 33.746907234191895, 33.994739055633545, 36.32292059489659, 36.29065316064017, 36.99215023858206, 36.52490472793579, 37.13291379383632, 36.77598830631801, 38.12652703693935, 35.58559513092041, 36.176445620400564, 35.97686556407383, 34.7621293749128, 34.57950292314802, 35.442754064287456, 35.41829293114798, 34.32792949676514, 34.53323834283011, 36.21205513817923, 37.51415797642299, 43.26501519339425, 48.87174245289394, 48.7261186327253, 47.19894627162388, 49.380288055964876, 46.68510266712734, 38.97120564324515, 36.28067902156285, 36.52961213248116, 36.42377022334507, 36.90661096572876, 36.25352198737008, 38.27649695532662, 36.45940405981881, 35.42102357319423, 34.752492223467144, 35.5650041443961, 35.478926386152, 35.023291315351216, 34.30390957423619, 36.50259753635952, 36.302725655691965, 37.41433320726667, 38.206938539232524, 36.971375124795095, 35.29336084638323, 35.221394879477366, 34.168402331215994, 34.77572005135672, 34.56865331104824, 34.59590762002127, 35.46912595203945, 35.11741508756365, 35.93967880521502, 37.2586727142334, 35.731257166181294, 35.78855548586164, 35.51298645564488, 38.5813422203064, 45.617769036974224, 48.802587032318115, 45.693653787885395, 45.091922419411794, 46.7554601260594, 47.29580763408116, 47.287230082920615, 44.94182048525129, 43.7687873840332, 42.75648348672049, 41.27952228273664, 39.039899008614675, 43.36508314950125, 47.07386132649013, 49.766239643096924, 51.57250724520002, 54.19083513532366, 52.92395618983677, 52.82203653880528, 53.170005798339844, 51.423551763807026, 51.6430800982884, 54.25216688428606, 53.528987952641074, 57.523962429591585, 56.238688128335134, 29.374968664986746, 1.096002766064235, 0.6225881235940116, 2.564962685108185, 0.10611596943012305, 0.04471546790695616, 26.7722099508558, 65.45704732622418, 54.535837514059885, 55.828066962105886, 39.41491413116455, 23.959311655589513, 44.96999543053763, 50.68165438515799, 52.43335083552769, 3.5212191556181227, 0.14076090896768229, 0.0633183027218495, 0.09904698482049362, 0.035245368390211036, 0.044427239801734686, 0.058414285869470665, 0.03542274762211101, 0.06304046977311373, 0.03899359583322491, 0.08549725796495165, 0.19019279575773648, 0.10054265920604978, 0.11059601724679981, 0.14117911724107607, 0.1037396312292133, 0.1268731698926006, 0.06453847831913403, 0.118821293381708, 0.12041882265891347, 0.250758342977081, 0.07532314104693276, 18.17801090649196, 68.24406705583844, 50.116032804761616, 39.24089649745396, 37.65421976361956, 40.70953375952584, 38.765306200299946, 60.47497354234968, 57.065020016261506, 51.711488587515696, 1.234389060309955, 0.2436745459479945, 0.8883142162646566, 3.755946023123605, 5.30833773953574, 28.344634192330496, 48.09437799453735, 50.59662927900042, 57.54489735194615, 52.61502538408552, 51.38877255575997, 49.21767589024135, 42.91087940761021, 38.694611753736226, 37.21430846623012, 37.74883338383266, 42.13000610896519, 47.43739455086844, 50.719320569719585, 49.37048414775303, 47.94229929787772, 48.16907460348946, 46.521493434906006, 46.00467600141253, 43.449687889644075, 45.79754672731672, 45.47478205817086, 40.474305970328196, 37.50573328563145, 35.71916035243443, 39.22517272404262, 36.3358268737793, 36.353523935590474, 37.712529046194895, 37.77146714074271, 34.9556644984654, 36.02629852294922, 36.917943477630615, 34.652438163757324, 34.98884562083653, 36.08477108819144, 37.141404492514475, 36.33714355741228, 36.09799698420933, 35.83999647412981, 35.84266110828945, 37.67727388654436, 38.04542766298567, 38.471828188214985, 38.036634717668804, 39.084687096732004, 38.272744928087505, 41.04266166687012, 37.6036125591823, 38.00685126440865, 38.59039224897112, 37.33572128840855, 35.50294630868094, 37.837554931640625, 37.72458764484951, 35.9273943901062, 39.338786193302695, 37.89942169189453, 39.46156086240496, 45.46907411302839, 50.98291437966483, 50.949969496045796, 49.34179850987026, 51.36135149002075, 48.350613662174766, 40.529012611934114, 38.1549972806658, 38.701521737234934, 39.07839550290789, 38.86013521466936, 39.91588272367205, 42.3836327280317, 38.699336528778076, 38.13033464976719, 36.893812383924214, 37.55676780428205, 37.931914942605154, 37.66238737106323, 35.75912986482893, 37.91236271177019, 39.74738890784127, 38.03722531454903, 40.89052391052246, 38.92003216062273, 36.74750416619437, 36.69686916896275, 34.37319701058524, 36.58390188217163, 36.23410872050694, 36.90614543642317, 38.1327144077846, 37.44360249383109, 37.965554646083284, 39.525195939200266, 37.45814159938267, 38.649795872824534, 37.13848624910627, 41.60211672101702, 48.945758138384136, 50.05679593767439, 48.98032890047346, 46.78933606828962, 49.89864451544625, 48.89288582120623, 49.234011105128694, 47.44425242287772, 46.13309955596924, 44.49612133843558, 42.80882774080549, 41.84831918988909, 44.90037448065621, 48.847100666591096, 52.24135473796299, 53.89819090706961, 56.455374649592805, 56.00878960745675, 55.03180340358189, 55.4084027154105, 55.27122443062918, 54.08400658198765, 56.2098183631897, 55.95929758889334, 62.03955500466483, 57.468474115644185, 32.98906373977661, 1.3346785988126482, 1.699352196284703, 5.100201845169067, 0.6163305108036313, 0.15064993261226586, 30.772362572806223, 70.33562074388776, 60.687289646693635, 61.237302098955425, 45.86787639345442, 29.37187671661377, 53.043694496154785, 57.64706366402762, 64.30451488494873, 6.108954344476972, 0.30982891470193863, 0.357132684971605, 0.13214827754667827, 0.12837438790925912, 0.0968505126823272, 0.14187883612300667, 0.19453001873833792, 0.15836929982262, 0.11623391721929822], [0.02946750699941601, 0.01419509932332273, 0.07066868937441281, 0.09816910978406668, 0.056996493733354976, 0.02305418568929391, 0.08297823742032051, 0.026986448792740703, 0.05801267456263304, 0.019933184143155813, 0.08713370801082679, 0.03436183437172856, 8.734328576496669, 47.24147619519915, 39.87550326756069, 32.01342896052769, 20.315113510404313, 36.49765736716134, 30.22201313291277, 50.47833967208862, 45.73511716297695, 50.36154045377459, 3.6484612992831638, 0.10147925466299057, 0.3923700941460473, 0.8995367512106895, 1.949424377509526, 15.098362582070486, 49.22557251793997, 53.238848549979075, 48.942284039088655, 47.41637625013079, 42.611154964991975, 36.64212431226458, 34.90711743491036, 34.413465295519146, 39.11626665932791, 44.42026090621948, 47.96719816752842, 46.17782858439854, 45.9222286769322, 43.40817240306309, 44.009424345833914, 41.28434433255877, 40.8965653691973, 40.32637187412807, 40.3288072177342, 37.210761410849436, 34.461897713797434, 32.9449531010219, 31.800796713147843, 32.69527653285435, 31.3402909551348, 32.17959860392979, 33.35109267915998, 32.426638330732075, 30.717728887285503, 31.962113039834158, 33.49460424695696, 32.59803996767317, 32.870190484183176, 32.21803256443569, 31.81662470953805, 33.45027821404593, 31.555038928985596, 34.594451972416465, 33.33296830313546, 34.52941335950579, 34.383185046059744, 34.54392467226301, 33.98853431429182, 33.87626532145909, 35.47351026535034, 33.270719391959055, 34.40984875815255, 32.765178884778706, 33.677036149161204, 34.85241426740374, 33.84285838263375, 32.39739336286272, 33.33115134920393, 32.97598375592913, 33.5479907308306, 31.353968484061106, 31.941178117479595, 33.44952433449881, 37.77333273206438, 46.20940119879586, 45.63757835115705, 46.669260774339946, 46.00652422223772, 44.869215284075054, 37.038525990077424, 33.14221245901925, 35.296966961451936, 35.707674980163574, 34.00086041859218, 35.46412672315325, 36.0223172051566, 33.03405679975237, 34.16790553501674, 33.77870566504342, 33.043329170772004, 35.23275171007429, 35.116845335279194, 35.227544035230366, 36.102846826825825, 34.8213905606951, 33.948036738804404, 34.091388498033794, 34.87900502341134, 32.02557093756539, 32.55956779207502, 32.940832819257466, 32.051762172154014, 33.95896972928728, 32.694783210754395, 32.83784661974226, 32.97951691491263, 33.71641159057617, 34.07895817075457, 34.298146043504985, 35.87470620019095, 37.43107489177159, 37.263376644679475, 43.47737646102905, 44.735865456717356, 44.17390210287911, 45.46443619046892, 45.10776778629848, 44.2188777923584, 46.81564542225429, 44.43494939804077, 40.512625285557334, 39.97168370655605, 39.37024416242327, 37.761861256190706, 42.386828899383545, 42.839444977896555, 45.299941062927246, 47.514926024845664, 50.50211640766689, 49.68798903056553, 52.3771607535226, 50.98853199822562, 53.374824796404155, 52.759624344961985, 53.40749870027815, 53.752827644348145, 53.99644538334438, 45.27088022232056, 30.94207579748971, 0.8282902485557965, 0.3362070178346974, 1.4804781866925103, 0.05924745901886906, 0.20350977831653186, 27.893190622329712, 59.5446583884103, 49.008469104766846, 41.21097482953753, 37.17609684807913, 26.902903829302105, 35.86663586752755, 49.517713001796174, 46.02026081085205, 3.6977123022079468, 0.28207707671182497, 0.08963233179279737, 0.06072009035519191, 0.09703810725893293, 0.051548057701438665, 0.07581549284181424, 0.03612970647269061, 0.0206782054156065, 0.039807413771216354, 0.040941245787377865, 0.0542250683398119, 0.005390332654185061, 0.0417691806464323, 0.010633208622623767, 0.04254621520106282, 0.11951801313885621, 0.03148394004840936, 0.07468980324587651, 0.021661044730405723, 0.08856118284165859, 0.0622902000322938, 10.46503278187343, 53.99553516932896, 45.38409764426095, 35.531868185315815, 23.77154701096671, 38.044850962502615, 34.87630912235805, 55.57978350775582, 49.82954468045916, 54.99619388580322, 3.656134716102055, 0.0818542984447309, 0.10325719283095428, 3.3757740344320024, 3.997240023953574, 15.821993146623884, 51.9730361529759, 55.3808148929051, 50.50705657686506, 49.00518608093262, 45.46994958605085, 38.514969553266255, 35.813193798065186, 35.55668020248413, 40.384326798575266, 43.9395671572004, 50.11691175188337, 47.83372327259609, 48.035054274967735, 44.449589252471924, 45.36498662403652, 43.19930260522025, 41.39001253673008, 42.218428884233745, 42.89752844401768, 39.806761264801025, 38.17484480994088, 34.67507539476667, 33.986189297267366, 33.334733145577566, 32.86108486992972, 33.1586206299918, 34.7169417653765, 34.54328543799264, 32.96998398644583, 34.02080174854824, 35.447280815669465, 35.16855035509382, 35.339139052799766, 34.00981664657593, 33.696338244846885, 34.98207460130964, 33.77540874481201, 33.967443057468955, 34.15519380569458, 35.90919358389718, 36.157313755580354, 35.97774451119559, 36.4558743749346, 36.361292021615164, 36.11473866871425, 34.61216293062483, 36.21887479509626, 34.254782336098806, 34.385596070970806, 36.531074728284565, 35.68477719170706, 35.12934514454433, 34.86513989312308, 34.374534538814, 34.997152192252024, 32.68079996109009, 36.02932793753487, 35.544361046382356, 40.04224613734654, 47.51713555199759, 47.10836260659354, 48.64066621235439, 48.373612199510845, 45.99837745938982, 38.659099510737825, 35.78024891444615, 36.62941605704171, 36.670479910714285, 37.28313037327358, 37.18924283981323, 36.70947320120675, 35.81102596010481, 35.885097231183735, 35.622590814317974, 35.21203218187605, 35.279961245400564, 36.325852734701975, 37.092680249895366, 36.37820046288626, 36.34042310714722, 37.33235141209194, 35.377496583121165, 36.223550932747976, 34.32208258765084, 33.66805560248238, 34.24712889535086, 33.3966520173209, 34.74773965563093, 34.9488205228533, 34.938342639378135, 34.58851473672049, 35.46364382335118, 34.690205097198486, 35.40672070639474, 37.65661341803414, 37.87264333452497, 38.53370884486607, 45.9181535584586, 47.79572704860142, 46.1372059413365, 47.54227760859898, 47.87630878176008, 45.11470208849226, 47.56253855569022, 44.75157185963222, 43.11746324811663, 41.8682153565543, 40.080558504377095, 39.362642833164756, 43.39784043175833, 44.65968540736607, 48.23526661736624, 48.29612936292376, 52.03814077377319, 51.76511478424072, 53.425133228302, 53.51344830649239, 55.10359219142369, 55.26760789326259, 55.73012515476772, 57.32656758172171, 55.82141753605434, 48.36326633180891, 33.35374689102173, 1.0228560396603175, 0.7700569076197488, 1.9834329869065965, 0.11001036688685417, 0.099692407330232, 29.90533855983189, 64.96120997837612, 54.1572197505406, 48.94194705145699, 45.975604738507954, 31.051826068333217, 43.03067677361624, 55.92321211951119, 54.53477096557617, 4.891113179070609, 0.39254784317953245, 0.1224363244005612, 0.024238193673746924, 0.028949442120002847, 0.017718135412516337, 0.01993045812871839, 0.046181761726204834, 0.08081082015165261, 0.03119435826582568, 0.16634803025850228, 0.07000870550317423, 0.21241389481084688, 0.1899882038789136, 0.19628127690936836, 0.14596798670079025, 0.22355526339794907, 0.1445081593202693, 0.1468024897788252, 0.1067540773323604, 0.11462570780089923, 0.16793234167354448, 11.28784019606454, 61.78325680324009, 51.26087359019688, 44.03700522014073, 27.42720968382699, 46.736335209437776, 39.78543724332537, 58.87188516344343, 53.706059319632395, 59.41062068939209, 4.505159854888916, 0.20112103649548121, 2.035260251590184, 3.3569696034703935, 3.440936412130083, 18.003864731107438, 52.9188631602696, 57.100921358381, 52.56380673817226, 50.76512656893049, 46.81683356421334, 40.438050270080566, 38.84871932438442, 37.59644201823643, 42.531698840005056, 48.187942436763215, 51.759431157793315, 49.708065850394114, 48.32220942633492, 46.08975321905953, 47.51653800691877, 45.929684094020296, 44.66664055415562, 44.92569024222237, 45.875283173152376, 41.91836397988455, 38.987384523664204, 36.40214742933001, 35.24358742577689, 37.12411390032087, 35.4436434337071, 35.90876279558454, 37.649946621486116, 36.28023781095232, 35.01679474966866, 36.41916356767927, 36.76949174063546, 37.49304934910366, 36.93575865881783, 34.748542172568186, 34.83444275174822, 36.751179763248985, 34.46334988730294, 35.58134283338274, 37.255754470825195, 38.60281562805176, 37.99120044708252, 38.87642526626587, 38.02935300554548, 37.553314549582346, 38.42663710457938, 36.105494090488975, 38.26733922958374, 35.608117716653005, 36.402550424848286, 38.66700308663504, 39.407507351466585, 36.2429016658238, 37.79425375802176, 36.59070764269148, 37.83704423904419, 34.69018425260271, 36.87795312064034, 37.447847843170166, 41.10917329788208, 50.39579159872872, 48.39944560187203, 49.905036858149934, 48.37429659707205, 48.63723727634975, 40.88219649451119, 37.33604437964303, 39.377015181950156, 40.61163016727993, 39.36174998964582, 39.99784367425101, 39.15776824951172, 37.561100006103516, 37.767409392765586, 36.783954416002544, 35.9110244342259, 38.72933885029384, 38.06799193790981, 39.220843996320454, 39.57844345910208, 38.21690225601196, 38.48484563827515, 37.59514965329851, 38.80424737930298, 35.232282706669395, 36.207643032073975, 36.277660029275076, 34.80174452917916, 37.21117830276489, 36.51938785825457, 37.27732515335083, 36.72204596655709, 37.416580949510845, 36.77308743340628, 37.17723287854876, 39.04646158218384, 41.105000904628206, 40.01336942400251, 48.62219442640032, 48.473933764866416, 49.96021597726004, 50.6090978213719, 49.403800759996685, 46.23540135792324, 48.78027636664254, 47.49250418799264, 44.68863507679531, 44.20833737509591, 41.648582799094065, 40.94914238793509, 44.79075622558594, 47.3588799067906, 48.194133281707764, 50.9804755619594, 53.90149824959891, 53.18229716164725, 55.80671862193516, 55.11426115036011, 57.72291019984654, 56.846249035426546, 57.99801022665841, 59.62731415884835, 58.6808305467878, 50.518257072993684, 35.923468657902305, 1.5260286224739892, 2.615666512932096, 3.5547954567841122, 0.38122583499976564, 0.1851985337478774, 34.6755131312779, 69.99546473366874, 58.84079197474888, 54.04717418125698, 49.44399608884539, 37.918334688459126, 50.98614876610892, 63.76454257965088, 64.65015997205461, 6.803092845848628, 0.42521099905882564, 0.3358638962464673, 0.14563417461301598, 0.16841951624623366, 0.16764483281544276, 0.14874240782644066, 0.12323186599782535, 0.1791017066155161, 0.0976463799764003], [0.016569080463211452, 0.023123635444790125, 0.05855620825397117, 0.04186139694814171, 0.044013068811701875, 0.02353293794606413, 0.05880302536700453, 0.012109995137767067, 0.12441175697105271, 0.039626574010721276, 0.05849007823105369, 0.02534520998597145, 3.5395806389195577, 42.60594729014805, 43.54498938151768, 39.88166979381016, 23.27066353389195, 34.54813528060913, 33.9510383605957, 47.48737294333321, 45.49709619794573, 49.01362466812134, 9.95466935634613, 0.16771778890064784, 0.3008945898285934, 1.0371380618640353, 1.4062325592551912, 10.46505536351885, 52.08019127164568, 50.565817492348806, 49.10567787715367, 41.46196460723877, 36.844643456595286, 34.5177230153765, 37.544667516435894, 44.30098465510777, 47.700675691877095, 46.99091720581055, 48.0359262738909, 44.00832305635725, 45.95828982761928, 43.41182368142264, 41.1272177696228, 40.692138944353374, 39.22589881079537, 37.21769223894392, 36.969728401729036, 34.732769761766704, 34.59340279442923, 31.891811166490825, 31.76902607509068, 30.973130771092006, 30.737989834376744, 31.584183147975377, 33.34481150763375, 32.35060766765049, 34.10294335229056, 33.11031675338745, 33.291598728724885, 32.97899580001831, 32.3937212399074, 33.17551517486572, 33.52223375865391, 31.626772131238663, 33.06547655378069, 32.80846963609968, 32.564035483769004, 34.78281416211809, 34.54375444139753, 34.73887028012957, 36.2575797353472, 34.3270331791469, 35.711499963487896, 33.50193807056972, 35.167233671460835, 34.274855681828086, 34.51563508169991, 33.77801431928362, 34.18257665634155, 33.38390902110508, 35.071800163814, 31.341711861746653, 32.52924585342407, 32.27042893001011, 33.68199716295515, 33.031683989933555, 37.67313623428345, 44.69899831499372, 47.36393472126552, 46.41565499986921, 47.73691749572754, 45.44449486051287, 35.721894468579976, 32.63452843257359, 34.58702087402344, 34.912627356392996, 35.293159348624094, 35.93988030297415, 35.96432753971645, 34.25808620452881, 34.528183528355186, 35.30215726579939, 34.4330974306379, 34.810238701956614, 34.44894279752459, 35.24961846215384, 34.89088991710118, 34.27036714553833, 35.21911934443882, 34.98899153300694, 33.57345935276577, 33.43136869158064, 34.32784611838204, 33.73441089902605, 33.78818300792149, 32.5069317136492, 33.097483430589946, 33.23269190107073, 32.62861898967198, 32.47445583343506, 33.42797449656895, 31.074605737413677, 33.7631208556039, 33.547601631709504, 39.31985582624163, 46.38054575238909, 45.238894190107075, 43.32725020817348, 42.12488528660366, 45.24757596424648, 44.41514008385794, 44.106101581028526, 42.51871960503714, 42.05309649876186, 39.9916285106114, 38.57486997331892, 35.7817462512425, 40.34882845197405, 44.19656017848423, 47.320734296526226, 48.19431046077183, 45.14782067707607, 48.69034930637905, 49.595842020852224, 49.251867975507466, 51.53347226551601, 51.187757696424214, 53.258699553353445, 52.13331719807216, 49.62563589641026, 50.388867718832834, 32.63255514417376, 1.4234531266348702, 0.7356045906032834, 2.193794910396848, 0.07189619993524891, 0.10193799861839839, 27.916020665849956, 59.97748252323696, 47.739564759390696, 42.51999112537929, 35.45039708273751, 21.834179060799734, 37.82655940737043, 51.39532470703125, 36.19941636494228, 1.3737533135073525, 0.02416439790145627, 0.058532364533415863, 0.008930637883687658, 0.04283087081941111, 0.01253496586079044, 0.05699344711112125, 0.016932427484009947, 0.030700757966509888, 0.05283943197822996, 0.021245988252173578, 0.025398683634453585, 0.0380631852229791, 0.0694624644571117, 0.05541057758299368, 0.0373939291707107, 0.02135479643142649, 0.010492001244399165, 0.008263739740609058, 0.030166482885501215, 0.011972059994669897, 0.0580134955900056, 4.57853022643498, 49.36765970502581, 49.62085206168038, 41.66766950062343, 24.401571444102697, 37.672952107020784, 36.85486078262329, 53.092762674604145, 49.06538527352469, 54.93672425406319, 9.89040286200387, 0.04255471724484648, 0.47665711705173763, 3.58366413627352, 1.4446613086121423, 10.531877057892935, 52.89302975790841, 50.40652309145246, 52.398727961948936, 44.28436803817749, 38.79306425367083, 34.63122878755842, 38.781888076237266, 43.42257949284145, 50.771800313677105, 48.157207080296104, 48.10165623256138, 46.7528441292899, 47.029993874686106, 45.74684919629778, 45.02312135696411, 42.72038412094116, 41.05183328901018, 37.68274906703404, 38.944277899605886, 37.83172539302281, 36.37196792875017, 33.399285384586875, 32.96241044998169, 32.23087283543178, 32.69468246187483, 32.41433654512678, 34.23268011638096, 34.332539626530235, 35.644536699567524, 35.38785287312099, 35.810688972473145, 35.748836108616416, 33.57791314806257, 35.53323350633894, 34.10894659587315, 32.99733209609985, 33.77747235979353, 34.533759457724436, 34.39285693849836, 35.875227315085276, 35.65418079921177, 36.66279520307268, 37.089317321777344, 35.771473339625764, 36.65987001146589, 35.25267219543457, 35.3165956224714, 35.06328167234148, 36.017915521349224, 36.25229563031878, 36.1518246786935, 35.92689411980765, 35.643275601523264, 33.913240160260884, 35.53510257175991, 35.18304429735456, 36.13935613632202, 34.99500519888741, 40.57134451184954, 46.43662813731602, 47.820188181740896, 47.14652211325509, 48.95000696182251, 47.29419912610735, 38.25790010179792, 35.479530879429404, 36.42320741925921, 37.718282154628206, 37.73183461597988, 37.97788769858224, 36.97727414539882, 35.72260318483625, 35.47639724186489, 36.68275390352522, 36.15607350213187, 35.85295833860125, 35.879538672310964, 38.135396412440706, 36.497132778167725, 35.90192576817104, 36.5195163999285, 36.30094344275338, 34.88005072729928, 34.05456304550171, 35.518437317439485, 35.06530359813145, 35.55612087249756, 33.554212842668804, 34.33298431124006, 33.85654285975865, 34.01563923699515, 34.80089684895107, 34.81645733969552, 33.08338553564889, 35.43483311789376, 35.32850136075701, 41.08703286307198, 46.566357953207834, 46.74954720905849, 45.96287563868931, 45.23091418402535, 46.306179182870046, 46.67686210359846, 45.41121298926217, 43.97373144967215, 43.641430377960205, 42.79781832013811, 40.643974031720845, 38.15563998903547, 42.91540615899222, 46.19500800541469, 47.74150330679757, 50.02175269808088, 47.324611391339985, 49.265364851270405, 50.818714550563264, 50.21601390838623, 53.13666834150042, 51.712440490722656, 56.27000365938459, 52.68540368761335, 52.7769010407584, 50.52389901024954, 35.3127497945513, 2.0272125005722046, 0.953603452869824, 1.9959788279873985, 0.07193008597408022, 0.08026504050940275, 30.684752736772808, 66.43050384521484, 53.44403232846941, 47.484854221343994, 36.61698920386178, 25.724101986203873, 43.93666628428868, 57.264572279793875, 45.41516651426043, 1.8687924870422907, 0.09934621876371758, 0.0456415426784328, 0.05256672875423517, 0.023277435584792068, 0.04160109055893762, 0.023299923931647624, 0.046383619108902555, 0.10017190767186028, 0.04687707352318934, 0.08694346036229815, 0.11619336796658379, 0.09907002786972693, 0.11536916505013194, 0.18406698160937854, 0.09554956427642278, 0.10135168329413448, 0.14231761757816586, 0.2556310657943998, 0.1387054499770914, 0.15641425044408866, 0.125582148454019, 5.251296503203256, 57.69313022068569, 54.25286170414516, 51.62830127988543, 31.103478976658412, 44.80570180075509, 44.93942335673741, 56.14240346636091, 52.75073759896414, 57.52025556564331, 12.419697403907776, 0.24362721134509358, 0.9652186696018491, 3.9065447534833635, 2.5496484211512973, 11.39855192388807, 56.7696590423584, 53.40208952767508, 55.32933221544538, 45.7310003553118, 40.825596468789236, 37.39626441683088, 43.614453996930806, 47.2697240965707, 52.06175422668457, 49.43866334642683, 50.339097772325786, 48.67516054425921, 49.617485659463064, 46.610440799168174, 47.548412867954795, 45.40525490897042, 44.09762825284685, 39.89630964824131, 41.08586209160941, 38.95909145900181, 39.206523759024485, 36.08159923553467, 34.46383626120431, 33.42434753690447, 34.38840314320156, 35.933324677603586, 37.176510265895296, 37.0765187399728, 38.27702154432024, 37.79900285175869, 37.78271280016218, 38.13456262860979, 34.52445929391043, 36.9956556047712, 36.26643868855068, 34.3294164112636, 35.34880747113909, 36.030272892543245, 37.044400691986084, 37.59234952926636, 36.978424072265625, 37.86229051862444, 40.0810136113848, 36.796165875026155, 39.041757651737754, 36.79163564954485, 37.25784935270037, 36.62047719955444, 36.61982406888689, 37.33970955439976, 37.95921094076974, 38.575509207589285, 39.80820301600865, 35.72915186200823, 38.85904087339129, 36.70446702412197, 38.62368106842041, 35.98315020969936, 42.24610703332083, 46.956030300685335, 48.78618928364345, 48.3443672316415, 50.910590580531526, 48.659019878932405, 41.52715260641915, 36.8142728805542, 38.71268401827131, 40.8512144769941, 39.99989339283535, 40.611338342939106, 40.425307273864746, 38.10221529006958, 37.127219745091026, 39.14292689732143, 37.65500143596104, 37.71492270060948, 38.41033315658569, 39.79045384270804, 37.40775326320103, 38.25208098547799, 38.12332739148821, 37.37363065992083, 36.86188541139875, 34.859056745256694, 37.92771128245762, 36.92426981244768, 37.77020256859915, 35.04336813517979, 35.93978302819388, 36.80867263248989, 35.88762290137154, 36.03255884987967, 38.5524446623666, 33.11594826834542, 38.59619746889387, 37.16069616590227, 42.94865676334926, 50.07093899590628, 49.185530049460276, 48.340924399239675, 45.78633233479091, 47.858389377593994, 47.309877736227854, 47.590286186763215, 47.37878996985299, 46.69452789851597, 44.348993233272004, 41.737960951668875, 40.158652782440186, 45.09765468324934, 48.05341141564505, 50.74381991795131, 52.64079277856009, 49.16239602225167, 52.657485825674875, 51.94980832508632, 51.37294108527047, 54.03958674839565, 52.81247581754412, 57.977693693978445, 54.30414983204433, 54.276892048971995, 51.36982134410313, 37.706678662981304, 2.8123500389712195, 3.018580607005528, 5.446248625005994, 0.5558251089283398, 0.1432936902024916, 35.206414563315256, 72.03877707890102, 59.18112863813128, 54.54324081965855, 45.410653659275596, 31.41369867324829, 51.306662218911306, 63.05778571537563, 55.69294534410749, 3.378154878105436, 0.18745764823896544, 0.09660825532461915, 0.1679491964834077, 0.1388736180961132, 0.1124488724661725, 0.146547455606716, 0.13008839450776577, 0.1772860283298152, 0.09987308084964752], [0.04968916691307511, 0.061895408002393584, 0.029517677878694873, 0.04640568167503391, 0.020920883465026106, 0.04729392472654581, 0.01926642170708094, 0.04626295183386121, 0.0755370899236628, 0.04173155927232333, 0.034281512788896046, 0.030753517456884896, 0.8817913777061871, 40.30589553288051, 47.98071241378784, 47.005473681858604, 26.276933670043945, 23.79066150529044, 32.322721072605674, 44.64898518153599, 45.99583441870553, 53.05838993617466, 14.040846756526403, 0.10329768780086722, 0.2265220627720867, 5.543225501264844, 3.8697188666888644, 4.632595896720886, 51.94433314459664, 48.31863110406058, 47.32780408859253, 37.59246417454311, 37.117759772709434, 39.32744673320225, 49.875402791159495, 48.096848079136436, 46.99927241461617, 47.4438077381679, 47.36503253664289, 46.220615591321675, 45.80931350163051, 40.6303242955889, 41.828808648245676, 37.01033020019531, 35.87370565959385, 33.43113592692784, 34.184904302869526, 31.53279079709734, 32.652677127293174, 30.299753052847727, 33.272272314344136, 32.106284686497276, 32.69795853751046, 32.075698716299875, 32.712046010153635, 32.12335293633597, 33.50285523278372, 33.70891795839582, 34.53252615247454, 32.698187828063965, 33.612904276166645, 32.30728217533657, 33.770016942705425, 33.02512836456299, 32.218956674848286, 32.93068150111607, 32.42572464261736, 34.00782598767962, 34.88376453944615, 35.189818790980745, 36.74929680143084, 34.22115305491856, 34.6711357661656, 33.635284423828125, 37.27707849230085, 33.07464470182146, 34.988532951899934, 34.40751763752529, 33.581922258649556, 32.58583893094744, 33.549849373953684, 31.562442234584264, 32.32075820650373, 32.79301336833409, 34.07246160507202, 32.81512253625052, 36.06345401491438, 44.12752635138375, 47.97337164197649, 46.90530845097133, 47.529016971588135, 45.36746365683419, 34.79766246250698, 34.65998043332781, 33.349206243242534, 35.52665703637259, 37.51083326339722, 36.90480790819441, 34.687828813280376, 34.13462713786534, 32.48953342437744, 34.695864404950825, 33.253876958574565, 34.17866134643555, 34.79720735549927, 33.81728553771973, 34.88736718041556, 35.13391705921718, 35.27331181934902, 34.90950761522566, 34.617683274405344, 33.38580240522112, 33.62671034676688, 34.047441141945974, 32.57295002256121, 32.98393596921648, 34.55106394631522, 33.47338792255947, 32.30324179785592, 32.84209891727993, 33.8253767149789, 31.966441767556326, 35.647263867514475, 33.33960035869053, 38.737099988119944, 46.03344849177769, 44.81773608071463, 45.174546922956196, 43.831748485565186, 46.31349911008562, 45.299812521253315, 44.00263248171125, 42.52722420011248, 42.421601159232004, 39.455151149204795, 39.2075903075082, 33.915220396859304, 40.2698517526899, 44.07199287414551, 50.686042172568186, 43.0738320350647, 41.647759437561035, 50.043330328805105, 48.163133893694194, 48.82212536675589, 46.15439578465053, 45.651926381247385, 48.408592905317036, 47.95237071173531, 52.96783058983939, 49.32741573878697, 37.469661712646484, 4.132224415029798, 0.8951932585665158, 0.7383178078702518, 0.17237207772476332, 0.10480216957096543, 27.953374181474956, 59.8080507005964, 46.37609543119158, 45.05707720347813, 36.36353628976004, 24.840853929519653, 33.21391439437866, 50.68023347854614, 34.50744662966047, 1.1941881946155002, 0.06409207013036523, 0.07885253416108233, 0.00773326275936727, 0.020655354052515965, 0.044990410296512504, 0.04943444486707449, 0.05679693997704557, 0.03474750349830304, 0.05516448989510536, 0.04288546235433646, 0.013748820904376251, 0.03144504302846534, 0.02957780286669731, 0.05011483567899891, 0.016568042304632918, 0.004456473389706973, 0.028521998985005275, 0.02575800015724131, 0.046649886428245475, 0.025776120434914316, 0.0068327042972669005, 1.6708116020475114, 46.800588675907676, 52.99223613739014, 50.00882904870169, 29.662637983049663, 32.16585506711687, 36.484980378832134, 50.028742585863384, 48.89742646898542, 57.27232646942139, 15.565674100603376, 0.17613479867577553, 0.5024006813764572, 8.745715805462428, 1.646079597728593, 5.8596408196858, 54.02500942775181, 51.3823732648577, 49.05896166392735, 39.992139203207834, 38.83957896913801, 42.28217165810721, 50.41758809770857, 49.636384759630474, 49.36216367994036, 47.42757674625942, 48.69440705435616, 46.39710330963135, 47.29546022415161, 43.289101123809814, 43.884235177721294, 39.50799567358834, 38.00516632625035, 35.65559128352574, 35.72719941820417, 33.71091556549072, 34.41072770527431, 33.40535463605608, 33.04924208777291, 32.96740273066929, 34.76499203273228, 33.1480142048427, 34.7587490762983, 34.77979169573103, 35.991686071668354, 33.69157178061349, 36.08939858845302, 34.89474964141846, 35.243834086826865, 33.28461578914097, 34.83492912564959, 33.90217515400478, 34.79293073926653, 34.27528647014073, 34.20260831287929, 34.90600572313581, 36.86655460085188, 36.8476311819894, 36.315767424447195, 36.14711380004883, 36.978733267102925, 34.91066796439034, 39.21482685634068, 36.41200344903128, 36.09431791305542, 36.063940388815745, 34.92102425439017, 35.03587450299944, 34.26929712295532, 34.14726938520159, 35.395488943372456, 34.49184444972447, 35.73725346156529, 35.260693890707834, 37.71010065078735, 45.55844531740461, 48.153118065425325, 48.239532811301096, 50.082921164376394, 47.16397598811558, 36.981828689575195, 35.57578774860927, 36.076666014535085, 37.622685364314485, 38.81293610164097, 39.32219042096819, 35.6710718699864, 34.88743666240147, 35.697822434561594, 36.29459626334054, 34.61181204659598, 36.08806453432356, 35.831304277692524, 36.17736973081316, 36.643409729003906, 36.17208562578474, 37.13995231900896, 35.62426880427769, 35.55071864809309, 34.40648930413382, 35.02821063995361, 34.620573725019185, 33.64463322503226, 34.74448095049177, 36.51875557218279, 34.07804100854056, 33.76113714490618, 34.61051273345947, 36.8120425088065, 35.382332529340474, 37.38731861114502, 34.98441961833409, 40.72097396850586, 48.04173149381365, 46.16312619618007, 46.64548751286098, 46.22410011291504, 46.57833317347935, 47.453924315316335, 45.46763236182076, 44.72102757862636, 43.873475892203196, 41.89984008244106, 41.38996737343924, 34.426809310913086, 43.44632496152605, 47.01669154848371, 52.15194879259382, 45.64392900466919, 44.73216554096767, 51.404739516122, 49.20732307434082, 50.19242477416992, 47.32312100274222, 48.21438033240182, 49.73132494517735, 48.625731059483115, 54.69993659428188, 51.38166454860142, 39.731873580387656, 4.237087062426975, 0.40474372303911615, 1.1804849356412888, 0.020082103920036128, 0.07696776065443243, 30.20009504045759, 64.08491706848145, 51.05805914742606, 49.35419757025582, 42.789629868098665, 24.816080127443584, 39.27938951764788, 55.2575295312064, 42.517291750226704, 1.7391279190778732, 0.07435162139258214, 0.030497862425233637, 0.04257560594539557, 0.026077710590990524, 0.049682649584220986, 0.08505470385508877, 0.07786530642105, 0.04344311635941267, 0.07384165482861654, 0.2438415198453835, 0.07705711014568806, 0.12072442126061235, 0.17241158203354903, 0.15132982470095158, 0.16522141785493918, 0.10031711416585104, 0.12228559463151864, 0.12282783910632133, 0.12710999218480928, 0.2396319428724902, 0.07594818036471095, 1.7561487257480621, 52.46348169871739, 61.044489588056294, 57.62413460867745, 34.70327465874808, 31.106935705457413, 41.83244603020804, 53.09003898075649, 54.27216727393014, 64.18253231048584, 17.223481280463083, 0.2364526263305119, 0.7818966923015458, 12.40116308416639, 7.989577225276402, 6.265931955405644, 56.070135252816335, 51.58843946456909, 51.19805492673601, 41.22028888974871, 40.37709024974278, 44.86243731634957, 53.23259517124721, 50.18833575929914, 49.32027299063546, 49.556192125592915, 50.1258818762643, 48.59802164350237, 50.212442534310476, 45.24128784452166, 46.27319955825806, 42.432784284864155, 41.206514086042134, 36.776922839028494, 38.75859424046108, 35.531190735953196, 36.458208969661165, 34.53634418760027, 37.84070246560233, 34.6323196547372, 36.1133177621024, 35.270143440791536, 37.57613590785435, 36.01526825768607, 38.29049757548741, 35.61016048703875, 38.634714807782856, 36.439594745635986, 37.843558175223215, 34.91528851645333, 37.24082974025181, 35.52751861299787, 34.90441458565848, 35.73126411437988, 35.50383915219988, 37.11827046530587, 38.61721576963152, 38.78653989519392, 39.01975270680019, 36.5483375276838, 38.13610512869698, 36.578100136348176, 40.44756930215018, 37.12572240829468, 37.7533392906189, 38.83767168862479, 37.320984159197124, 35.81292281832014, 39.712415150233674, 35.985724517277305, 37.05446515764509, 36.85980790002005, 39.46964509146554, 37.2006378855024, 39.36256292888096, 47.18515757152012, 51.28655413218907, 49.62209578922817, 50.81355551310948, 49.41974687576294, 38.97776126861572, 38.04705701555525, 37.7992981501988, 41.31262697492327, 42.82962369918823, 41.431639194488525, 38.40493788037981, 37.629272256578716, 37.11051280157906, 38.18373850413731, 35.98632206235613, 38.43504442487444, 38.85739067622593, 38.394710132053916, 39.15090342930385, 37.94081905909947, 38.47048371178763, 38.14136838912964, 38.434335708618164, 36.08108506883894, 35.87675591877529, 37.81993777411324, 34.78210891996111, 36.22563886642456, 38.455242838178364, 37.22599533626011, 35.71677017211914, 37.4429007257734, 39.03368384497506, 36.9717572757176, 38.94352402005877, 37.60494313921247, 41.774998324257986, 50.21162959507534, 48.253783566611155, 49.88467863627842, 47.88309022358486, 49.64216218675886, 48.47151231765747, 47.076623235430034, 47.198383467538015, 46.228828362056184, 43.78278453009469, 43.338631357465474, 36.87103966304234, 45.386369705200195, 49.37129361288888, 54.64590392793928, 47.66987085342407, 46.98332977294922, 52.90410171236311, 51.218628542763845, 52.11657203946795, 48.41330030986241, 48.150377001081196, 50.46218858446394, 49.72893476486206, 55.734631061553955, 52.59191220147269, 43.71566145760672, 5.593404522963932, 2.6897171565464566, 4.4494565810476026, 0.5138100577252251, 0.3008149026760033, 32.52458708626883, 70.68431609017509, 55.71916437149048, 57.81400803157261, 48.612911633082796, 32.36204440253121, 47.78774356842041, 64.10551847730363, 51.05035359518868, 2.788767852953502, 0.17011026266430104, 0.13309211975761823, 0.09444265652980123, 0.08008843141474895, 0.1538338360509702, 0.12323566579392978, 0.15603678141321453, 0.14593300143522875, 0.13448302155094488], [0.07786626994077649, 0.04002026002854109, 0.018611028125243526, 0.07221935902323041, 0.07058119906910829, 0.01710146921686828, 0.03552786287452493, 0.011254805223351079, 0.05995242976184402, 0.06364076970411198, 0.03043414798698255, 0.029268329830041954, 0.08959155862352677, 26.057106563023158, 51.46122489656721, 40.21649653570992, 24.14851631437029, 18.295801980154856, 32.55724014554705, 44.863410064152305, 47.008965151650564, 50.663675921303884, 23.7586806842259, 0.06846153709505286, 0.5218543889267104, 4.4041330473763605, 1.316811523267201, 2.0299583418028693, 47.20624882834298, 51.30842706135341, 45.78824308940342, 39.77500452314104, 41.09611415863037, 46.81684398651123, 49.26093537466866, 45.00621638979231, 48.05418961388724, 45.94261816569737, 45.47793654033116, 41.48332336970738, 42.37100090299334, 40.46324096407209, 36.05325058528355, 33.34769153594971, 32.31922960281372, 30.814864703587123, 31.5675630569458, 31.09152807508196, 33.00299487795149, 30.808976105281285, 32.20375401633126, 33.585993903023855, 33.50287955147879, 32.3659006527492, 33.37986864362444, 32.856631074632915, 33.36074372700283, 33.272769110543386, 32.429792812892366, 33.49479184831892, 34.15923418317522, 31.984482765197754, 34.87479094096592, 32.81385449000767, 33.26685619354248, 33.75700296674456, 32.5435973576137, 32.518399715423584, 34.25110673904419, 34.835321698869976, 35.666909899030415, 34.6185622215271, 35.14041362489973, 35.85622746603829, 36.58450984954834, 34.42281757082258, 34.51047257014683, 33.65185240336827, 32.240607261657715, 33.61366510391235, 33.01322957447597, 31.141089575631277, 32.47697455542428, 32.556114537375315, 33.65656328201294, 34.22498846054077, 38.298154490334646, 45.39212628773281, 48.809173924582346, 46.99589559010097, 47.670551776885986, 45.65642533983503, 35.7622252873012, 31.809843267713273, 33.97749710083008, 34.28253691537039, 35.88292939322335, 34.14084924970354, 35.02680362973894, 33.22343690054757, 34.32040112359183, 34.40606198992048, 35.0838657106672, 33.882730620247976, 34.49645110539028, 33.62106146131243, 35.42879513331822, 34.350274903433665, 36.297306060791016, 34.827046394348145, 32.76037767955235, 34.39708144324166, 34.54981327056885, 32.53066676003592, 32.49750648226057, 33.1189603124346, 33.39127063751221, 33.18139335087368, 31.979518277304514, 33.39801386424473, 32.17727443150112, 34.74919877733503, 35.6029760496957, 33.717624051230295, 38.68173674174717, 45.05483988353184, 47.510649408612935, 45.76711361748831, 41.96776567186628, 44.821547167641775, 46.06328405652727, 46.505783557891846, 41.911436625889365, 41.00612456457955, 39.81132275717599, 39.701937266758506, 31.956811564309255, 38.42967346736363, 46.094300815037315, 51.46755123138428, 41.03241654804775, 41.85743522644043, 51.94987085887364, 48.02581317084176, 48.54568781171526, 48.38228702545166, 46.878863607134136, 48.38568122046334, 51.82752002988543, 53.18883194242205, 50.87205934524536, 43.780613218035015, 6.332242088658469, 0.4328586315470082, 1.136842974594661, 0.05997761698173625, 0.07155716991318123, 25.394166776112147, 61.585712569100515, 48.708525793892996, 45.051122597285676, 19.49068716594151, 24.485938208443777, 39.96709789548601, 53.78218725749424, 29.50461162839617, 0.42341214844158714, 0.008931957634298928, 0.024206772413370863, 0.011050644214265049, 0.04968312116605895, 0.008212446734043104, 0.03467626410669514, 0.060403031297028065, 0.02215120316083942, 0.010387210840625423, 0.03238896666360753, 0.021046889114326665, 0.05056434816547802, 0.015361462852784565, 0.039112037513405085, 0.0075347683658557275, 0.04419835976191929, 0.01945981945443366, 0.030019122042826245, 0.04731806700250932, 0.02710046642459929, 0.03567084038097944, 0.0668674615610923, 32.11566475459507, 55.4403018951416, 46.652699742998394, 28.796737841197423, 17.956608295440674, 37.60464089257376, 49.06201887130737, 52.099899836948936, 54.29017353057861, 25.02424120903015, 0.06252689340284892, 0.5885531327554158, 5.719237267971039, 1.40684888618333, 2.474474774939673, 48.09269653047834, 51.84539427076067, 47.001756395612446, 40.67435850415911, 42.447472776685444, 47.73757062639509, 51.27671200888497, 46.7573813029698, 49.59027303968157, 48.50684043339321, 47.926116943359375, 43.89235067367554, 43.78309719903128, 42.91206407546997, 38.04079668862479, 35.36178323200771, 34.54522398539952, 33.40863071169172, 34.37056016921997, 33.29675429207938, 34.27732229232788, 32.99608836855207, 33.76145328794207, 35.171287945338655, 35.274680614471436, 34.930883748190745, 34.378039905003135, 35.23931428364345, 34.466844831194194, 34.94712863649641, 34.55301291601998, 34.26325913837978, 36.544828687395366, 35.00873483930315, 36.30581760406494, 35.15689822605678, 34.83339704786028, 34.47850043433053, 34.21995101656233, 34.1275121825082, 36.080011572156636, 35.67544576099941, 35.93900830405099, 36.17218290056501, 35.742172786167686, 37.552282742091585, 37.234263692583355, 35.68034771510533, 35.309657846178325, 35.36980145318167, 35.1516558102199, 34.421705859048025, 35.79752908434187, 33.59076731545584, 34.37264462879726, 35.67573063714163, 35.88992970330374, 35.95947422300066, 39.117281096322195, 45.87201404571533, 49.94920308249337, 48.476515020642964, 48.615201064518516, 46.73454604830061, 36.79336922509329, 35.26175349099295, 36.86401503426688, 35.94781167166573, 37.84460735321045, 36.78051505770002, 37.68969031742641, 35.02355187279837, 36.616895403180806, 35.533778939928325, 35.917312553950715, 35.72525044849941, 35.63368361336844, 35.33110693522862, 36.21590444019863, 36.133140972682405, 38.12178141730172, 36.45435619354248, 34.952801840645925, 35.726883275168284, 35.37527315957205, 34.442310741969514, 34.51993601662772, 33.84824671064104, 33.474318981170654, 35.28966440473284, 33.69949272700718, 34.72749955313546, 34.051370348249165, 36.358814988817485, 37.20019320079258, 35.71452242987496, 39.79783630371094, 47.34956584657942, 48.822285175323486, 46.27473511014666, 44.31939738137381, 46.85112292425973, 48.51617881229946, 47.99808291026524, 45.007911750248496, 42.52990967886788, 42.50098432813372, 40.12809460503714, 34.00469929831368, 39.87207085745675, 47.46248797007969, 52.38132619857788, 44.682225363595144, 44.76635067803519, 52.599680287497385, 49.4924875668117, 50.39684772491455, 49.50134652001517, 47.73650407791138, 49.86478246961321, 51.73985113416399, 55.45299972806658, 52.017588002341135, 45.79668515069144, 7.418685436248779, 0.7435347107904298, 1.247021102479526, 0.08714766547616039, 0.0900180246680975, 28.56020031656538, 66.63976274217877, 50.943594523838584, 51.823771476745605, 27.058237757001603, 27.554961000170024, 45.591685499463765, 60.25463921683175, 36.65358189174107, 0.4983723003949438, 0.048962126818618605, 0.024676807191488997, 0.009546131061922227, 0.05150791556973543, 0.008873165119439363, 0.05872278181569917, 0.05738064633416278, 0.04975777698148574, 0.040251816889005046, 0.12720911258033343, 0.11201705956565482, 0.137563217697399, 0.1407275250447648, 0.11371000443718263, 0.056059538652854304, 0.13551782816648483, 0.13495658471115998, 0.11777620017528534, 0.12698041913764818, 0.145406146134649, 0.2361910103687218, 0.3043445875602109, 34.856329577309744, 64.21096433912004, 52.54908697945731, 33.865158626011436, 25.596369777406963, 44.154801504952566, 55.07298190253121, 57.024723938533235, 59.49536091940743, 29.029481649398804, 0.17272799648344517, 1.1826355116707938, 12.049929908343724, 2.012866424662726, 2.5890744541372572, 52.45852415902274, 53.87394516808646, 49.93225295203072, 43.68252897262573, 44.611412797655376, 48.115167004721506, 52.27192333766392, 48.7664737701416, 50.766526630946565, 50.25533029011318, 49.72071852002825, 45.36574397768293, 47.47881623676845, 44.42334590639387, 41.27814653941563, 36.38014595849173, 35.8948837688991, 34.53444038118635, 35.97442674636841, 34.75384712219238, 35.87748547962734, 34.76591614314488, 36.03605726787022, 36.9617657661438, 37.36547000067574, 37.318833691733225, 37.1713581766401, 36.66874633516584, 37.40730857849121, 36.05491467884609, 36.24473599025181, 36.22875165939331, 39.34824269158499, 36.95800331660679, 39.62893254416329, 35.38865886415754, 36.53956542696272, 36.12854126521519, 35.273350034441265, 35.22364956992013, 38.26328842980521, 37.411540031433105, 37.87043033327375, 38.45658384050642, 37.40531097139631, 39.82785946982247, 38.53500120980399, 37.06108679090227, 36.95798594611031, 37.44075720650809, 36.98914166859218, 38.38589981624058, 38.14876127243042, 34.690743582589285, 36.43333094460623, 37.590021882738384, 37.71579122543335, 38.250225816454204, 42.98410299846104, 48.90406894683838, 52.88264914921352, 49.49505492619106, 51.3658504486084, 48.88388442993164, 39.00769410814558, 37.05056027003697, 37.57364845275879, 38.68834447860718, 40.49748516082764, 36.93303843906948, 39.46446520941598, 37.753568581172395, 39.014430386679514, 37.18890585218157, 39.38673223767962, 38.117192132132395, 37.58093711308071, 36.77318123408726, 38.16334901537214, 38.52971363067627, 40.03309188570295, 39.88165242331368, 35.56859983716692, 37.97025857652937, 37.300361905779155, 35.87445259094238, 36.110416889190674, 36.12264919281006, 36.523501191820415, 36.57035289491926, 34.24595464978899, 37.23982572555542, 35.2568758555821, 38.60589715412685, 38.94154725755964, 38.20357213701521, 42.80068097795759, 48.35061018807547, 50.97088704790388, 48.49060249328613, 44.726301261356895, 48.18405491965157, 49.09160777500698, 49.7898530960083, 46.38851881027222, 44.62987763541085, 44.31365816933768, 42.647778919764924, 35.20526116234915, 41.936140945979524, 50.42858362197876, 55.53501973833357, 45.703495911189485, 45.46212591443743, 54.00754860469273, 50.40110697065081, 52.057536670139854, 51.62828738348824, 48.11746685845511, 50.191646575927734, 53.24806186131069, 57.06815365382603, 54.59542873927525, 48.57619040352957, 9.115655268941607, 3.706789255142212, 4.282275106225695, 0.4860743688685553, 0.21786471589335374, 31.207827023097447, 73.019668170384, 55.79791178022112, 58.76284013475691, 31.05071783065796, 35.87637029375349, 53.749878134046284, 68.12860883985246, 45.04051269803728, 0.9226191554750715, 0.08815248084387609, 0.07773280210260834, 0.12239672509687287, 0.11351630983075925, 0.055741119131978066, 0.13490201692496026, 0.12537367535488947, 0.11235564853996038, 0.06868358089455537], [0.034940621349960566, 0.0721628845536283, 0.027339899380292212, 0.0404148993880621, 0.0356925976063524, 0.032018177809992006, 0.03139579834948693, 0.016260966192930937, 0.05022979308185833, 0.02169397912387337, 0.021900501434824297, 0.07379174179264478, 0.013897599037071424, 14.106145058359418, 49.79049233027867, 38.99479477746146, 39.95009912763323, 31.51207821709769, 29.8446877343314, 38.54046596799578, 48.45436416353498, 50.04758957454136, 32.58639478683472, 0.2703969377492155, 0.6717979801552636, 6.581223402704511, 3.164703828947885, 0.8165290110877582, 38.39284454073225, 54.444590296064106, 43.47698041370937, 43.41689934049334, 46.59468923296247, 49.97832645688738, 46.29284906387329, 47.7241918700082, 45.9810278075082, 45.13063430786133, 43.66143076760428, 40.43176909855434, 37.23500714983259, 33.700204917362754, 32.233551365988596, 32.22833326884678, 31.814839022500173, 32.22796501432146, 31.717359270368302, 32.14447546005249, 33.01482766015189, 32.190691402980256, 33.03889969417027, 33.97754921231951, 33.028581619262695, 33.52524927684239, 31.039260251181467, 33.325627531324116, 31.711206640516007, 32.36334024156843, 32.57270336151123, 32.52404512677874, 34.46709844044277, 32.81705413545881, 33.491932664598735, 35.10854223796299, 33.04119954790388, 34.34231921604702, 33.44245801653181, 32.86718191419329, 36.008354800088064, 36.44660895211356, 37.45502533231463, 35.316477503095356, 35.62760393960135, 34.6801302092416, 33.226469789232524, 33.9035439491272, 32.33896596091134, 34.17173746653965, 33.30200365611485, 31.66091557911464, 32.81151989528111, 32.32907172611782, 31.61228166307722, 33.26015813010079, 32.6496581350054, 32.843589305877686, 37.31547771181379, 46.13807794025966, 46.169678347451345, 46.84952136448452, 48.24335779462542, 47.00157921654837, 36.69447204044887, 35.19075679779053, 34.72325072969709, 33.93338646207537, 35.984842096056255, 35.81811312266758, 33.33035578046526, 32.88568844114031, 32.9212076323373, 33.539850916181294, 33.735724108559744, 34.707867418016704, 34.5762094770159, 33.83627496446882, 35.69550173623221, 34.19075468608311, 36.48519924708775, 35.17259420667376, 33.310299805232454, 32.34595237459455, 33.626366410936626, 31.94406509399414, 33.24167244774954, 32.749427318573, 32.952714238848, 34.99463694436209, 33.42676551001412, 33.334955487932476, 31.398270198277064, 33.775360107421875, 34.59024831226894, 32.84223093305315, 36.62374980109078, 42.54471629006522, 45.95877620152065, 46.764454569135395, 42.16060250146048, 44.46673393249512, 46.24097033909389, 45.60835770198277, 43.52874101911272, 42.00361490249634, 40.23051800046648, 39.44266871043614, 34.68430955069405, 35.10411276136126, 44.170751094818115, 47.58027383259365, 48.011347021375386, 42.516871384211946, 46.72919940948486, 50.92576544625418, 47.45112419128418, 49.35551772798811, 47.60501636777605, 50.54013695035662, 50.402117933545796, 52.22104862758091, 51.68841709409441, 42.16952051435198, 7.69046596118382, 0.2473652879042285, 0.6488163790532521, 0.14016732653336866, 0.1366603182894843, 28.129681246621267, 59.938600403921946, 48.42993082318987, 40.72061613627842, 28.316655533654348, 30.75761502129691, 36.818994181496755, 51.124959877559114, 28.95263978413173, 0.12311704430196967, 0.008215031952464154, 0.04237479350662657, 0.006261347277489091, 0.016495793592184782, 0.020797042342435037, 0.04779344524389931, 0.011390582625088947, 0.04977939849985497, 0.03689516521990299, 0.020018654110442315, 0.039689596343253336, 0.022398191603964994, 0.019910597408722554, 0.04810043144971132, 0.05187962383830121, 0.04130787182865398, 0.015647405991330743, 0.07210780786616461, 0.062027858038033755, 0.029942260988588845, 0.027395596927297965, 0.04211442944194589, 17.216868332454137, 57.569778851100374, 43.06949635914394, 38.845797606876914, 31.41062409537179, 40.13831193106515, 44.37584802082607, 53.637397221156526, 54.14626244136265, 36.96833528791155, 0.13760873382644995, 0.30065102289829937, 4.694318916116442, 1.528180609856333, 1.9271651719297682, 41.23517887932913, 57.61486223765782, 45.490488461085725, 44.142829758780344, 47.649978160858154, 50.57661846705845, 48.09348167691912, 48.575891630990164, 48.17269114085606, 46.620835304260254, 45.72488246645246, 43.90107066290719, 40.42071451459612, 36.41414696829659, 34.195312704358784, 34.7437618119376, 33.46663774762835, 33.51559475490025, 33.68971313749041, 33.61090666907174, 35.15658555712019, 33.78529603140694, 35.13963542665754, 33.717228003910606, 34.1618640763419, 35.38001877920968, 33.8109244619097, 35.2164477620806, 34.703649861471995, 33.85188756670271, 33.02771309443882, 35.02600458690098, 35.10365418025425, 34.70420224325997, 35.13954162597656, 35.84744841711861, 34.70334414073399, 35.192479951041086, 33.06748458317348, 35.90958268301827, 36.93490750449044, 36.93755824225289, 37.4230740410941, 35.82411984034947, 36.23301785332816, 35.87263216291155, 35.182349477495464, 36.252535343170166, 36.64553240367344, 35.88437114443098, 36.03285762241909, 35.06675924573626, 35.67864193235125, 34.864229679107666, 34.52439676012312, 35.129442419324604, 35.21226494652884, 34.89669861112322, 38.6741805757795, 46.73248938151768, 47.46081345421927, 47.5240455354963, 49.27371311187744, 49.0254157611302, 38.27796649932861, 36.325998646872385, 35.956441334315706, 35.81437151772635, 37.65143701008388, 37.06131608145577, 36.448339053562705, 35.3726988519941, 36.221595014844624, 35.19726725987026, 34.501763003213064, 36.037829058510916, 36.07892765317644, 35.757024560655864, 37.904757908412385, 36.959438119615825, 37.496186460767476, 36.58644492285592, 36.28161702837263, 35.030031067984446, 36.396408217293875, 34.74006537028721, 34.01446499143328, 34.457079138074604, 34.261709690093994, 36.60826921463013, 34.60028498513358, 35.38344424111502, 33.455239227839876, 34.61440372467041, 36.62387834276472, 35.534817695617676, 38.91688462666103, 44.23236077172415, 49.4104015486581, 46.70414073126656, 44.219791480473106, 45.06518227713448, 47.53350550787789, 47.577682154519216, 44.61588396344866, 44.46323204040527, 41.83218894686018, 41.6360239301409, 35.645763056618826, 37.25810991014753, 47.65927485057286, 48.9842164175851, 50.71152816499983, 44.55157838548933, 47.75110919134957, 52.377136434827534, 49.46307931627546, 51.16383852277483, 49.34802409580776, 50.75913027354649, 50.591713428497314, 54.266282149723594, 53.459832532065256, 45.54209620612008, 9.158153925623212, 0.3084043168595859, 1.0436851105519702, 0.2083412462047168, 0.10377406688140971, 30.39703130722046, 64.06308582850865, 51.19152362006051, 47.618558406829834, 29.482457297188894, 30.766724109649658, 44.6396815436227, 58.33992413112095, 33.56081363133022, 0.19085242679076536, 0.061921076982149055, 0.03741158804457102, 0.022309281464133943, 0.04035662340798548, 0.006507431148617927, 0.04483392315783671, 0.013257717613929083, 0.03019768192565867, 0.003174372566198664, 0.20966020971536636, 0.16740798338183335, 0.2734466812440327, 0.10156301302569253, 0.21622874082199164, 0.10805657279810735, 0.10664771018283707, 0.0858353041112423, 0.1702834383717605, 0.17824582968439373, 0.15950720304889338, 0.2044123113155365, 0.1279534926371915, 20.091153962271555, 64.17140824454171, 49.092170579092844, 52.96033695765904, 40.32521847316197, 43.34120913914272, 47.965374265398296, 57.904907839638845, 59.211930002485005, 40.77333211898804, 0.378210859639304, 1.3278700155871255, 12.883452313286917, 5.66044465133122, 2.4458785951137543, 44.46978071757725, 60.03823062351772, 48.35721445083618, 46.47503777912685, 51.24009152821132, 51.606845242636545, 49.09061418260847, 50.34320068359375, 49.797221660614014, 49.498205934252056, 48.138016155787874, 45.8493663924081, 41.27350166865757, 38.39903538567679, 35.223468916756765, 36.650972843170166, 34.93927717208862, 36.10206168038504, 35.02984346662249, 36.37812403270176, 37.68547623498099, 35.650442668369834, 36.363119397844585, 36.81484610693795, 35.921540532793315, 38.25749363218035, 35.00294698987688, 37.84646252223423, 36.14968810762678, 35.18484040669033, 33.94982589994158, 35.19864647729056, 36.21609204156058, 36.84758601869856, 37.06269529887608, 38.12161118643624, 37.30667781829834, 37.45350020272391, 35.52493388312203, 35.91768428257534, 40.226432459695, 40.0292113167899, 41.143768378666465, 37.914037227630615, 36.880298137664795, 37.10270997456142, 36.66265276500157, 37.081135817936485, 35.97161620003836, 36.88748604910714, 37.75150496619088, 36.484097957611084, 38.252063614981516, 37.65486594608852, 35.53575570242745, 39.0298866544451, 38.018232413700645, 36.96111958367484, 41.849027906145366, 48.378038202013286, 47.66966240746634, 50.09134932926723, 51.132714067186626, 51.16479737418038, 40.779342310769216, 38.91276781899588, 38.765010901859824, 38.650730405535015, 40.476067338671, 40.17633942195347, 37.43966981342861, 37.80753523962838, 38.10952132088797, 36.949988569532124, 37.69450889314924, 38.20185245786394, 37.22155891145979, 37.059794425964355, 39.039169447762625, 38.29960666384016, 40.31796455383301, 39.466567039489746, 37.151333468300955, 36.73884323665074, 38.5763395173209, 33.85107462746756, 36.453675270080566, 36.449909346444265, 35.52985668182373, 38.477873120989116, 37.95402063642229, 38.185051713671, 35.300267355782644, 37.648831435612266, 38.86830629621233, 37.35701404299055, 41.02249452045986, 44.812507561274934, 50.36548703057425, 49.545231342315674, 46.48050948551723, 46.34572485515049, 48.99710880007063, 49.950040340423584, 47.55974885395595, 46.627557686397004, 45.17286893299648, 44.12222834995815, 37.04802417755127, 39.28305121830532, 49.05987535204206, 52.30430889129639, 50.77901949201311, 45.332114696502686, 50.158778122493196, 53.044378893715994, 50.49286140714373, 52.393693992069785, 49.28225244794573, 51.000243186950684, 52.88147490365164, 56.06688002177647, 55.0400960786002, 47.22251803534371, 11.315234337534223, 1.096437897000994, 2.0657024809292386, 0.37880745476910044, 0.24201205372810364, 34.843364238739014, 69.10603278023856, 57.94569376536778, 55.18479578835623, 39.7499805859157, 40.4347950390407, 51.33762339183262, 66.9590185710362, 43.57139948436192, 0.6818448039037841, 0.15486328223986284, 0.06526947088007416, 0.10428994348538773, 0.14729429196034158, 0.10649013399545636, 0.1223786353532757, 0.05461386212014726, 0.1503233808491911, 0.14608017568077358], [0.019120892908956324, 0.032574956504894156, 0.024422500748187304, 0.03709269015650664, 0.03491167504606502, 0.016727711772546172, 0.04271379638729351, 0.05848972539284399, 0.10164305980184249, 0.12145593629351684, 0.07112588626997811, 0.05311925981992057, 0.029329703322478702, 8.374421443258013, 47.07784611838204, 43.20342983518328, 36.03038753782, 16.88304213115147, 29.577532972608292, 35.39051750728062, 48.47898857934134, 44.716844763074604, 39.218940189906526, 0.6207369714975357, 0.1787417980709246, 2.4848393159253255, 3.4812635396208083, 0.2482529202742236, 29.34860372543335, 55.66301250457764, 43.735095569065635, 48.922217641557964, 48.91025979178292, 48.210392066410606, 44.006818771362305, 46.21116951533726, 42.586707728249685, 42.16124868392944, 36.54782683508736, 35.653687477111816, 31.304327079227992, 32.87715605327061, 31.515170165470668, 33.26065840039934, 31.425211838313512, 33.29233523777553, 31.53208555494036, 34.33488116945539, 31.206180300031388, 31.705752304622106, 34.239808968135286, 33.86998067583357, 30.774690219334193, 33.26157208851406, 32.173480715070454, 34.99716261454991, 32.97190863745553, 33.45062214987618, 31.92517294202532, 32.44986963272095, 32.345823832920615, 32.94411931719099, 33.613203048706055, 34.03303057806832, 32.97292307444981, 33.05291421072823, 33.705909388405935, 34.91527809415545, 34.60561077935355, 36.62403120313372, 35.02822453635079, 34.175281047821045, 33.66547434670584, 34.96097987038748, 33.536428928375244, 33.32116331372942, 33.859791142599924, 32.917042187282014, 32.71333490099226, 33.81332506452288, 32.81719657352993, 31.083978857312882, 32.3505277633667, 31.75569248199463, 32.43588638305664, 32.53151791436331, 37.338521412440706, 45.80428300585066, 46.768321241651265, 47.35351242337908, 48.1849616595677, 46.218805585588726, 36.46516759055001, 33.44043609074184, 35.73229244777134, 34.44986343383789, 35.4446439743042, 35.84433215005057, 32.47200311933245, 33.78789118358067, 32.91856731687273, 34.45768710545131, 35.68729938779558, 36.558728558676584, 35.83122437340872, 35.84398126602173, 35.536078793661936, 35.7521573475429, 35.25184188570295, 35.725973061152864, 34.063314301627024, 33.87669610977173, 33.25509289332798, 35.0561215536935, 33.76060560771397, 34.94207729612078, 33.226480211530415, 33.664696148463655, 33.830421107155935, 32.63722085952759, 31.909650666373118, 33.13511140005929, 33.625431878226145, 33.777580056871685, 32.63422966003418, 40.708706923893516, 46.249676431928364, 45.335380349840435, 43.510126795087544, 43.02305459976196, 41.38922044209072, 45.25019890921456, 45.10072578702654, 43.36575365066528, 42.63611636843, 38.48216363361904, 35.65337480817522, 32.16617121015276, 37.49450499670846, 43.70866462162563, 46.65365859440395, 52.32547310420445, 46.99238674981253, 49.791124616350444, 50.843669005802695, 51.8912593296596, 51.44822481700352, 51.72021205084664, 52.76809072494507, 50.86507640566145, 53.43806035178048, 38.88484648295811, 5.0301114576203485, 0.2672546420778547, 0.9129822211606162, 0.12695147283375263, 0.23438228028161184, 30.776288305010112, 60.50372518811907, 46.714038440159385, 43.02655301775251, 25.406334808894567, 27.870873008455547, 36.0196977342878, 51.143417767116, 24.19806218147278, 0.16858932642000063, 0.017801724141463637, 0.01699935139289924, 0.02328244486956724, 0.07110496703535318, 0.018213409996990646, 0.035098139861864705, 0.03241574165544339, 0.05978960171341896, 0.048476475557046275, 0.03463850024023226, 0.0536798654523279, 0.03853645661313619, 0.031028541270643473, 0.022792235549007143, 0.03139460073517902, 0.05272376550627606, 0.04460923307176147, 0.06276733228670699, 0.023391193677006022, 0.07595299117799316, 0.030151904560625553, 0.06221702681588275, 10.336537139756338, 54.23356308255877, 47.95505966459002, 42.83457081658499, 22.857330833162578, 33.706843921116416, 39.975004945482524, 53.45865828650338, 51.403919628688264, 41.38624661309378, 0.6993126294442585, 0.6894168204494885, 2.056726494005748, 5.148568255560739, 0.1720699125102588, 33.81006635938372, 59.221122469220845, 48.11194998877389, 50.36289882659912, 52.096283299582346, 49.51091766357422, 46.814120292663574, 48.26707199641636, 46.0432002885001, 44.495370932987754, 38.46041924612862, 38.29562882014683, 34.56226791654314, 33.09356117248535, 33.74626452582223, 34.55842208862305, 33.13052211488996, 35.70244298662458, 33.51603943961007, 35.379049505506245, 33.290150029318674, 34.07517487662179, 35.450615950993125, 34.468088558741975, 33.25682299477713, 34.65986578805106, 32.96230970110212, 35.43792506626674, 34.57143259048462, 35.25740739277431, 33.18485702787127, 34.93479905809675, 34.11813906260899, 35.49901015417916, 34.11927509307861, 35.71663815634591, 34.26313754490444, 35.03632961000715, 35.00616747992379, 36.57300015858242, 36.04340846197945, 37.39501026698521, 37.60037817273821, 35.105241843632285, 34.98113659449986, 35.791352135794504, 35.72149494716099, 34.06339768001011, 36.505244800022666, 35.65180451529366, 35.499006680079866, 35.57731982639858, 33.94778312955584, 33.90900870731899, 33.14514112472534, 34.549236570085796, 33.89243377958025, 33.09228270394461, 38.31638656343733, 45.963730267116, 49.319609437670024, 47.4493385042463, 49.824868542807444, 47.70861748286656, 37.272638593401226, 34.531622886657715, 37.49213566098894, 36.4611827986581, 36.81636428833008, 37.838816029684885, 35.113131523132324, 34.93420498711722, 34.45930256162371, 37.022833483559744, 37.258436475481304, 38.073387214115684, 36.514756883893696, 37.494411196027485, 37.73023305620466, 37.23014341081892, 37.593179838997976, 37.29698160716465, 36.215633460453574, 35.912066664014546, 35.066047055380686, 35.94529642377581, 35.75535699299404, 36.19431291307722, 36.113984789167134, 35.897847175598145, 35.48772975376674, 35.18364184243338, 34.474400997161865, 35.653472082955496, 36.60901614597866, 35.36255100795201, 34.530396529606406, 42.02699906485421, 48.392966406685964, 46.69874545506069, 44.92763226372855, 43.27622263772147, 43.0223319871085, 47.627132483891074, 47.398460320064, 44.58353662490845, 43.216221468789236, 40.947374071393696, 37.302248341696604, 35.14080967221941, 40.157770361219136, 47.29856259482247, 49.56359543119158, 54.01577179772513, 48.88438122613089, 51.45434617996216, 52.46504504340035, 54.12232937131609, 53.24754074641636, 53.18934958321707, 55.241197790418354, 52.047326292310444, 54.53385727746146, 41.6218079158238, 5.736781469413212, 0.17657225020229816, 1.333597719669342, 0.18768243331994328, 0.23362052972827638, 33.695758070264546, 66.34233120509556, 50.28237615312849, 47.548756803785054, 27.864798545837402, 31.44410399028233, 41.82189866474697, 58.16271380015782, 31.235612869262695, 0.25911208614706993, 0.0174482871246125, 0.07528031870190587, 0.021022889330717068, 0.014113033905492296, 0.06604763519551073, 0.028653984224157672, 0.012810782712352062, 0.04291291588119098, 0.026290358376822302, 0.1050253329532487, 0.1660002132079431, 0.08052405768207141, 0.14680603173162254, 0.09875015289123569, 0.18288230017891952, 0.12055923869567257, 0.12514027287917479, 0.14810108366821492, 0.08506476652941533, 0.1594576971339328, 0.10149777866899967, 0.17244645873350756, 11.54937560217721, 61.94059181213379, 53.64558914729527, 47.26804610661098, 24.533071313585552, 38.45396089553833, 44.986869130815776, 58.08098908833095, 54.384116649627686, 48.71332005092076, 0.9872578127043588, 1.1750163776533944, 8.271207690238953, 5.489998825958796, 1.1686251206057412, 36.40792833055769, 63.51818030221121, 49.87765053340367, 53.703005586351665, 52.071895122528076, 52.57540675571987, 48.495605196271626, 52.24223368508475, 47.50587599618094, 46.220400197165354, 39.313894271850586, 40.03011110850743, 35.24303156988961, 34.88013757978167, 36.41050958633423, 36.69674062728882, 35.432241439819336, 37.86152621677944, 35.28212908336094, 38.20445455823626, 34.50036988939558, 34.279622146061485, 36.93696417127337, 36.695288453783306, 35.11858238492693, 36.3941604750497, 35.58112049102783, 38.13201263972691, 35.54209245954241, 38.03591905321394, 34.85646159308297, 37.03559037617275, 35.4989059312003, 37.738956519535606, 37.420440673828125, 37.871271065303254, 36.51845679964338, 36.727239745003835, 35.998939990997314, 39.20356035232544, 37.62777491978237, 39.52953856331961, 39.34272929600307, 36.921139648982454, 36.11443989617484, 38.36268588474819, 36.59157616751534, 35.431279114314485, 36.72484609058925, 37.4678829738072, 38.66238948277065, 37.63462584359305, 36.55547680173601, 35.94100938524519, 36.2552034514291, 36.338019030434744, 37.00532749720982, 36.248039858681814, 41.63438415527344, 47.757723876408164, 49.60591343470982, 48.693545477730886, 53.27311359133039, 50.88100167683193, 39.94412020274571, 35.68960966382708, 41.438986914498464, 39.410175459725515, 39.404540470668245, 41.04096630641392, 37.654285771506174, 37.82777534212385, 36.672838824135916, 38.699763842991416, 41.0778751373291, 40.24777037756783, 38.64877448763166, 38.94611917223249, 38.270688261304585, 38.23687137876238, 37.91008022853306, 38.9506459236145, 37.345115252903526, 36.692012378147666, 37.02124582018171, 39.198505537850515, 37.435997690473286, 39.29035724912371, 37.13303886141096, 36.93018620354788, 38.403569085257395, 36.83766746520996, 36.603120599474224, 37.647493907383506, 38.353524684906006, 36.97876453399658, 37.227232115609304, 43.73134354182652, 50.996307032448904, 47.892921924591064, 46.514375005449565, 43.90125131607056, 42.60980006626674, 47.97122812271118, 48.40381949288504, 46.73840229851859, 46.284903798784526, 42.07782861164638, 39.87148720877511, 37.12510401862008, 42.302773066929404, 48.903318541390554, 50.84631974356515, 54.788189138684956, 49.913777691977366, 53.33574117933001, 54.24610458101545, 55.43729679925101, 54.7836137499128, 56.20310640335083, 58.502359117780415, 54.24691752025059, 57.13950817925589, 43.95054531097412, 7.625356129237583, 0.49280223356825964, 3.762677959033421, 0.3238354245466845, 0.29582273055400166, 37.164753913879395, 70.8365650177002, 54.35180057798113, 55.61397211892264, 35.56264175687517, 37.79837056568691, 48.98450476782662, 64.5312693459647, 37.398727553231375, 0.6392171170030321, 0.10824768218610968, 0.16619542773280824, 0.18731075897812843, 0.13808346406689712, 0.20304115489125252, 0.11508115407611642, 0.09351820684969425, 0.15683925763836928, 0.12163102546972887], [0.07093568611890078, 0.018963686523160765, 0.02948594618854778, 0.007957946908261095, 0.06117813541953053, 0.02277707538035299, 0.04104789113625884, 0.02831834178817059, 0.06578735594770738, 0.05320045332025204, 0.0816908325733883, 0.035251220754746876, 0.05243095728967871, 3.7018569026674544, 45.145732743399485, 46.029474122183665, 31.265229565756663, 18.527116196496145, 31.344567571367534, 31.715260914393834, 48.074613843645366, 44.97217716489519, 48.14898041316441, 3.6075646366391863, 0.16423841060272285, 2.011997248445238, 0.48574829207999365, 0.6546977577464921, 14.509755492210388, 58.815542221069336, 44.49837950297764, 50.878597600119456, 50.382572650909424, 48.52609389168875, 43.29830401284354, 44.88377870832171, 39.097405774252756, 38.309497424534385, 34.3709214755467, 34.980361870356965, 32.63142258780343, 33.974561486925396, 32.784762382507324, 33.73515435627529, 33.63898433957781, 35.26643310274397, 33.90182079587664, 35.704871382032124, 34.1257438659668, 36.1222357749939, 35.56363534927368, 37.968445096697124, 34.85785123280117, 36.28493479319981, 34.98588221413748, 35.14871672221592, 32.987670625959126, 33.15114784240723, 31.69698715209961, 33.18426643099104, 32.467271396092, 32.256369250161306, 33.06534801210676, 34.10585464750017, 32.94599880490984, 33.02007007598877, 32.371619020189556, 35.274249826158794, 34.103308132716585, 34.72407756532942, 35.38545574460711, 33.73722491945539, 32.48082038334438, 35.963455540793284, 35.29344769886562, 34.78660440444946, 32.68887376785278, 33.588120051792686, 32.662772859845845, 33.834572655814036, 31.397092478615896, 33.55292395183018, 32.64616666521345, 31.448748861040386, 32.1639860016959, 31.226906776428223, 36.92027807235718, 45.34337772641863, 46.084114755902974, 47.95698084150042, 48.17019673756191, 45.17579412460327, 37.08471761431013, 33.95369952065604, 34.58952569961548, 35.48657635280064, 35.18379817690168, 34.9908640725272, 33.320729051317485, 34.06889023099627, 34.79021399361746, 35.34110539300101, 35.824908460889546, 35.858763558524, 33.91169766017369, 36.719391754695344, 35.60861798695156, 36.5404235294887, 35.2754032271249, 33.68665593011038, 34.82386759349278, 34.269554206303184, 33.38359635216849, 33.52927228382656, 34.77302067620413, 34.97754437582833, 32.554099559783936, 33.74703924996512, 31.733920301709855, 34.503427096775596, 34.37890842982701, 33.96059908185686, 35.01691286904471, 34.0139855657305, 30.631265504019602, 37.53266102927071, 42.33624253954206, 46.53369099753243, 39.34983382906233, 39.74288647515433, 41.757572242191856, 40.96879884174892, 46.27914374215262, 44.425989695957725, 42.591356073107036, 41.22891855239868, 37.94296605246407, 35.88845321110317, 34.73344373703003, 38.21860803876604, 41.37526151112148, 42.306761332920615, 46.474294321877615, 47.31766319274902, 44.988776411329, 49.356219496045796, 49.84161022731236, 49.15865789140974, 48.05924442836216, 52.99330963407244, 53.19305297306606, 34.30329813276018, 2.177130307470049, 0.2314662624682699, 0.20966721219675882, 0.21044709320579255, 0.20304620319179126, 33.533830302102224, 59.01867280687605, 43.09504835946219, 33.53703689575195, 29.756306648254395, 29.881693840026855, 34.81027691704886, 48.94808578491211, 13.290778296334402, 0.0768984415169273, 0.044023711633469374, 0.07750664638089282, 0.04412228920097862, 0.039260310985680134, 0.022579579281487634, 0.0810510961871062, 0.02060344273091427, 0.037633611488022974, 0.020051546095471297, 0.0186026838408517, 0.02501905007686998, 0.05300320658300604, 0.01270540028677455, 0.07490569273275988, 0.018117762004424418, 0.06895352248102427, 0.057279334270528386, 0.011145717148402972, 0.03409597756607192, 0.030159561828311, 0.06384376024029084, 0.07662936166993209, 4.827369970934732, 52.20164578301566, 51.17228058406285, 35.444400787353516, 19.635364294052124, 36.60234587533133, 35.67435141972133, 51.286741733551025, 47.556920937129426, 52.13931696755545, 3.2579603791236877, 0.19856580932225498, 1.4671327599457331, 2.778340343918119, 0.8817493085350309, 18.736666917800903, 61.98244776044573, 46.38820961543492, 52.73272092001778, 51.73621722630092, 49.94115012032645, 45.17854561124529, 48.00063984734671, 40.82164294379098, 39.17289795194353, 35.85112748827253, 36.87330477578299, 34.138879435403005, 36.15285996028355, 33.446880544934956, 34.738859857831685, 33.47537858145577, 37.28641339710781, 35.3617068018232, 36.75161402566092, 35.89471353803362, 37.77673387527466, 36.01198523385184, 37.59029286248343, 36.934174469539094, 39.04772615432739, 36.97480058670044, 37.08853564943586, 35.04238843917847, 34.83619717189244, 33.107429776872905, 35.24938917160034, 34.572971616472515, 34.03789431708199, 35.00314848763602, 35.19345964704241, 33.71774217060634, 34.24599633898054, 34.1213595526559, 36.06924533843994, 36.962252140045166, 36.58588211877005, 35.807857581547324, 36.00511693954468, 34.994973931993755, 35.99164090837751, 35.08103084564209, 35.78829492841448, 34.20608588627407, 36.475937298366, 34.679167883736746, 34.8449136870248, 35.06097139630999, 34.311257294246126, 34.510476044246126, 34.65844488143921, 34.78083392551967, 34.7247758592878, 38.674621786390034, 48.23512070519583, 48.43339450018746, 49.52250031062535, 50.32972812652588, 48.57765647343227, 38.82948323658535, 35.69679062707083, 35.827607836042134, 37.76532145908901, 36.82706104006086, 38.06942326681954, 35.375120299203054, 34.981108801705496, 35.02354145050049, 36.82398298808506, 36.350206170763286, 35.76024157660348, 35.57552024296352, 37.4697277205331, 36.56652096339634, 37.315394333430696, 35.872934409550254, 35.75507211685181, 35.58370522090367, 34.971885068076, 34.90732935496739, 35.5803735596793, 35.9038782119751, 37.29703719275338, 35.030336788722444, 35.96214233125959, 34.706505571092876, 35.52992268971035, 35.100499698093955, 35.70909936087472, 36.41979585375105, 34.43968084880284, 33.16772277014596, 37.913523060934885, 43.9720048223223, 48.282799243927, 40.105221135275706, 40.10490151814052, 41.28115858350481, 41.47045530591692, 48.98445265633719, 45.90660217830113, 44.738814967019216, 42.34603255135672, 40.18386779512678, 37.801452091761995, 36.752371379307334, 41.01269408634731, 42.95871775490897, 44.629384313310894, 49.28533744812012, 48.21656206675938, 47.43155458995274, 50.49465751647949, 53.28615188598633, 51.26766892841884, 50.21389818191528, 54.295603547777446, 54.20142418997628, 35.749239104134695, 2.771406910249165, 0.1803499532065221, 1.607617627297129, 0.1213993736143623, 0.1480725309146302, 35.58808258601597, 63.10437338692801, 47.328589235033306, 42.22825711114066, 30.892858232770646, 32.092162472861155, 42.26584339141846, 55.729298319135395, 19.377341202327184, 0.06687500687049967, 0.034960685630462, 0.026141514935131584, 0.039588257138218196, 0.04548607673496008, 0.04956267102222357, 0.04423995056588735, 0.0848992650530168, 0.02950731325628502, 0.027182185789570212, 0.16392967716923781, 0.12282390360321317, 0.18254913948476315, 0.10000580908464533, 0.11813646155808653, 0.121987609192729, 0.14075671562126704, 0.14003026245960168, 0.10256398788520268, 0.18399986092533382, 0.12137645270143237, 0.201852999361498, 0.12672704059098447, 5.756452688149043, 58.81216539655413, 57.89421108790806, 43.65721321105957, 27.47878268786839, 42.674508639744346, 41.08496229989188, 57.98424237115042, 52.34903791972569, 58.24741581508091, 4.633302007402692, 0.45251831518752234, 5.795812496117183, 2.0603590990815843, 1.0276696213654108, 18.699957847595215, 66.08669308253697, 47.26294265474592, 56.07624271937779, 54.21813113348824, 52.81597770963396, 46.62309346880232, 49.60025760105678, 44.51142821993147, 40.55766003472464, 39.07063089098249, 39.53374917166573, 35.88203307560512, 38.37100635256086, 36.32077360153198, 36.64644609178816, 37.14469793864659, 39.364154066358296, 35.77474594116211, 38.861069747379844, 37.8251246043614, 40.16351304735456, 38.547032015664236, 41.365214415958945, 38.421346051352366, 40.58195788519723, 38.861483165196006, 38.91823605128697, 37.261618750435964, 36.82424007143293, 34.72253506524222, 36.34526947566441, 34.946131569998606, 35.44323696408953, 35.26153809683663, 36.64159624917166, 36.16402224131993, 35.67139843532017, 35.58039787837437, 38.04961395263672, 38.46565123966762, 38.2682911327907, 39.120154176439556, 37.06333800724575, 35.255677291325156, 37.097241742270334, 37.72662346703665, 38.07494361060006, 35.59839718682425, 38.460488728114534, 37.45218699319022, 37.37333188738142, 37.47805166244507, 37.59014695031302, 37.65993118286133, 37.1057949747358, 36.95210429600307, 36.51225553240095, 39.709208556583945, 48.839176246098106, 48.78527212142944, 51.964885916028706, 52.34056806564331, 50.177333286830354, 42.57472903387887, 38.12236854008266, 37.9569354057312, 39.742292404174805, 39.60303660801479, 38.418747425079346, 39.26650408336094, 38.096705368586946, 37.569778306143625, 39.27480370657784, 37.83463321413313, 37.4077775818961, 37.52447952542986, 38.51069988523211, 36.96938793999808, 40.09124830790928, 39.15997430256435, 37.507008280072895, 37.81138106754848, 36.175622258867534, 37.230035713740754, 36.53644915989467, 39.00668314525059, 40.43876246043614, 36.087126527513774, 38.89862476076399, 35.15181214468819, 37.431415353502544, 38.04442017418997, 36.791211809430806, 38.74277319226946, 37.002298082624165, 35.48715305328369, 40.79829004832676, 45.84993267059326, 49.86992413657052, 41.46830831255232, 39.52686350686209, 41.48737416948591, 41.048491205487935, 50.251220430646626, 49.05724893297468, 46.351008960178916, 45.447885581425254, 42.585599490574424, 40.08474479402815, 38.377791268484934, 42.56224659511021, 46.07449844905308, 47.08322054999215, 50.13568231037685, 51.203648226601736, 48.74169996806553, 53.230013915470664, 54.562129497528076, 54.386868136269705, 52.62008367265974, 56.87629304613386, 56.53264209202358, 37.843332358769004, 3.629201978445053, 0.6880534536072186, 2.4253972598484586, 0.3844073499952044, 0.28518023448331015, 40.074624742780415, 68.55466542925153, 52.08430807931082, 47.15735782895769, 38.6160797391619, 40.97068875176566, 48.090441840035574, 64.75513335636684, 26.372943878173828, 0.28593101991074427, 0.15991949449692452, 0.1164473979068654, 0.1295034158974886, 0.14238093846610614, 0.18860939357961926, 0.13420775346457958, 0.24501991804156983, 0.1544480323791504, 0.14433438650199346], [0.029334327538630793, 0.05215226260146924, 0.06184391397982836, 0.00976491958967277, 0.03873919609135815, 0.044707885278122764, 0.04890202218666673, 0.027883768946464573, 0.03461849024253232, 0.06446136959961482, 0.08971581874149186, 0.05892364175191947, 0.022949380866651024, 0.8131677657365799, 34.09158999579293, 45.55434588023594, 36.26389912196568, 17.50098364693778, 25.537388256617955, 30.6965959412711, 46.74160194396973, 44.39336790357317, 49.017136982509065, 8.34094328539712, 0.3512184109006609, 0.32823583270822254, 4.58643684216908, 0.22137906588613987, 5.591182836464473, 49.04580177579607, 47.170969349997385, 53.336303983415874, 49.69427020209176, 48.34304359980992, 43.53280224118914, 41.634717668805806, 36.715181146349224, 37.05384676797049, 35.71788535799299, 37.158973012651714, 35.56849561418806, 36.37091180256435, 36.52961908067976, 39.132612296513145, 37.25026191983904, 40.15061024257115, 37.52940927233015, 39.910914761679514, 38.20238746915545, 38.1244147845677, 38.460773604256765, 40.03559671129499, 38.49405894960676, 37.908992835453574, 38.231542110443115, 37.94468920571463, 35.95732028143746, 36.48232964106968, 32.92404249736241, 33.05720124925886, 32.08226128986904, 33.32998405184065, 32.22026293618338, 32.6497415133885, 32.89957094192505, 32.87564829417637, 32.85846539906093, 35.458196435655864, 35.35677358082363, 36.31674712044852, 34.643391609191895, 35.34312731879098, 34.96775088991438, 32.56087752750942, 32.975149972098215, 34.0573353767395, 33.988666330065044, 33.8256060055324, 33.46683924538748, 32.46969631740025, 32.94698544910976, 32.41243621281215, 32.074507100241526, 32.13264962605068, 32.40572772707258, 32.30503095899309, 37.011181354522705, 47.50482334409441, 46.49145289829799, 47.133897236415315, 48.95483248574393, 45.90105404172625, 36.48265273230416, 36.51568446840559, 35.66611780439104, 36.83804266793387, 34.988817828042166, 34.89145966938564, 31.515555790492467, 34.159553800310405, 33.41381059374128, 33.837668078286306, 34.902489934648784, 34.59470905576433, 33.793230874197825, 37.28355768748692, 35.07836968558175, 35.624074254717144, 34.59992715290615, 35.82500226157052, 32.80390119552612, 34.488557951790945, 34.377074105399, 34.31145531790597, 32.972679887499126, 33.03897959845406, 32.67654071535383, 33.30118029458182, 33.365037713732036, 33.8664162499564, 32.690916538238525, 33.41446719850813, 33.7342962537493, 34.525894096919465, 33.01726647785732, 32.91954353877476, 38.75933769771031, 44.3164096559797, 46.5169632094247, 46.74083764212472, 45.34719923564366, 45.04681471415928, 44.23738431930542, 47.7191162109375, 44.23630734852382, 44.499008314950125, 40.89668001447405, 40.59790052686419, 37.161793981279644, 36.38645492281233, 37.62760468891689, 38.900570256369456, 35.71581826891218, 40.02899244853428, 42.38895852225167, 44.45801394326346, 46.178134305136545, 46.14251783915928, 47.30276278087071, 50.93273101534162, 50.876290798187256, 28.56976624897548, 0.47475993313959663, 0.13107144247208322, 0.5905505770019123, 0.04926260248092668, 0.3002726174890995, 35.01129525048392, 59.09989030020577, 44.756425176348, 34.481227602277485, 23.617211886814662, 31.520228454044886, 39.70581088747297, 47.40701355252947, 11.136195761816841, 0.10538617109081574, 0.018117889229740416, 0.02587297621981374, 0.028568451492381946, 0.04061820205034954, 0.034786074821438105, 0.03880524808274848, 0.020627527331401194, 0.05740841877247606, 0.06493517024708645, 0.0024632212173725876, 0.01626650134234556, 0.04305063134857586, 0.060981801311884604, 0.12378823757171631, 0.017970236617007425, 0.034319850017449686, 0.023508207040971944, 0.05352504411712289, 0.07383417058736086, 0.07702919521502086, 0.008288774290122092, 0.04455764066161854, 1.5205996909311839, 40.009982177189414, 51.32048566000802, 41.01270450864519, 21.69209361076355, 30.802357946123394, 35.66226155417306, 50.80518640790667, 49.023011684417725, 53.29413884026663, 9.231165596417018, 0.3299998337669032, 0.7177071166890008, 3.6250573779855455, 0.9482032912118095, 6.86739798954555, 53.857464041028706, 49.401427950177876, 55.08870220184326, 50.89329651423863, 49.27613803318569, 43.55536304201399, 44.686206681387766, 38.54492323739188, 38.20873812266758, 37.26868159430367, 38.841930934361045, 36.12313904081072, 38.01856592723301, 37.50010177067348, 39.711685589381624, 38.37630435398647, 42.24792398725237, 38.86841746738979, 41.59804160254342, 40.92779752186367, 40.386751719883506, 39.89374228886196, 42.0403847694397, 40.401207447052, 40.26036051341465, 40.79105002539498, 39.031759193965364, 38.25588512420654, 37.69159759793963, 33.59076036725725, 35.716857024601524, 33.52727467673165, 33.745107650756836, 33.68334858758109, 33.812918594905305, 34.02268818446568, 34.366491998944966, 34.67356416157314, 35.81846400669643, 36.833845955984934, 37.48531600407192, 37.023410184042795, 37.39230046953474, 36.65151827675955, 35.079620361328125, 35.45124128886631, 33.819762570517405, 35.42976788112095, 34.887836183820454, 34.502485615866526, 34.23239871433803, 34.478722776685444, 34.5134915624346, 33.792782715388704, 34.397324630192344, 33.66114214488438, 34.445621558598106, 37.97396196637835, 49.28902694157192, 47.90491451535906, 47.592096192496165, 48.910787854875835, 46.9152443749564, 37.691469056265696, 38.55801016943795, 37.513463156563894, 38.83718531472342, 37.92160381589617, 36.78812680925642, 33.743492194584434, 35.46348748888288, 36.21320159094674, 35.29126249040876, 36.98691824504307, 36.3681047303336, 35.90207168034145, 39.94132007871355, 35.55365078789847, 36.73207916532244, 37.2671981539045, 37.71616642815726, 34.62765046528408, 35.85715505055019, 36.284194810049875, 35.88834203992571, 35.09453814370291, 34.827758584703716, 34.56982060841152, 35.445078236716135, 35.29657091413225, 35.16669866016933, 35.77010801860264, 35.0813296181815, 35.451369830540244, 35.78832619530814, 33.50717006410871, 34.25470590591431, 42.098787852696006, 46.819223744528635, 48.33057505743844, 48.14318561553955, 46.941129888807026, 45.55316121237618, 43.554074151175364, 49.308342933654785, 46.68681192398071, 45.66825812203543, 43.09078563962664, 42.22912911006382, 39.374562467847554, 39.67368589128767, 40.89048569543021, 40.7413078716823, 37.67844465800694, 42.513647420065745, 45.20795038768223, 46.870845385960166, 47.339376313345774, 48.49029677254813, 48.117241042000906, 54.317108222416465, 51.72866106033325, 30.56670979091099, 0.5944153496197292, 0.4891693027956145, 2.7377999935831343, 0.08751217448817832, 0.3340440381850515, 38.55662400381905, 63.522606304713655, 49.12579986027309, 42.62325177873884, 31.092278480529785, 37.39807442256382, 43.437142917088096, 55.07490307944161, 15.23289360318865, 0.042160495184361935, 0.0032891425237591776, 0.001741325478568407, 0.022374047631663934, 0.05573774681293538, 0.044694999898118634, 0.06755310762673616, 0.1022778700238892, 0.0020680419984273612, 0.029052036614822488, 0.0668623454070517, 0.1012440404987761, 0.2032197317374604, 0.21832440979778767, 0.2653215772339276, 0.08605844035212483, 0.21290554771465914, 0.09839940456939594, 0.12914440301912172, 0.15611428368304456, 0.173305212653109, 0.11452991222696644, 0.1065249021298119, 1.7295959677015031, 45.653100626809255, 58.45024068014962, 48.9038987159729, 27.020007031304495, 34.99231972013201, 41.51537888390677, 56.022293431418284, 52.06944588252476, 58.60308020455496, 11.266464931624276, 0.6117350916777338, 2.7120999097824097, 10.431630185672216, 0.6254537126847676, 7.815423233168466, 55.67707913262503, 51.268280369894846, 57.580791745867046, 51.858533314296174, 52.75732101712908, 45.901679379599436, 46.99596854618618, 40.982344354902, 40.4503173146929, 38.838262285505024, 42.201329367501394, 38.45458623341152, 41.44027927943638, 40.23146295547485, 42.79100213732038, 41.18657970428467, 44.86171817779541, 40.746241092681885, 43.343828610011506, 43.0015082359314, 42.38544620786394, 42.37567009244646, 43.48768411363874, 42.41841541017805, 42.40173625946045, 42.418703760419575, 40.17180572237287, 39.8814821924482, 40.25719560895647, 35.390024185180664, 36.333613872528076, 35.73273713248116, 35.2480342728751, 35.78675937652588, 36.25013821465628, 36.12355593272618, 36.326478072575156, 36.430933816092356, 37.34279802867344, 38.12366785321917, 39.76033340181623, 38.17799234390259, 39.68622391564505, 38.9213627406529, 35.03957094464983, 37.72093984058925, 35.48710094179426, 37.050824301583425, 37.99424375806536, 36.29473522731236, 36.77650594711304, 36.90206336975098, 36.658886841365266, 35.87342773165022, 36.870410851069856, 36.05190263475691, 36.358377252306255, 40.734220709119526, 51.79282767432076, 51.09913689749581, 49.77505343300955, 50.5419921193804, 50.16590697424752, 41.19693946838379, 41.38272040230887, 39.78724030085972, 41.67613240650722, 41.046045439583914, 39.444714954921174, 36.337539604731965, 38.18573611123221, 38.10049908501761, 37.734242166791645, 38.58278744561331, 37.410775729588096, 37.05901622772217, 42.04904569898333, 38.3220910344805, 39.27796513693673, 38.775002411433626, 39.56635706765311, 36.71594197409493, 38.11298847198486, 38.20444761003767, 38.39745814459664, 37.01875836508614, 36.29986647197178, 36.25451210566929, 38.35152012961251, 37.026324953351704, 37.28216804776873, 37.90584182739258, 36.339700494493755, 37.67264986038208, 37.912536416734966, 36.11195591517857, 36.683070046561106, 42.428667477199006, 49.997083118983674, 50.840358189174104, 50.5402307510376, 48.45757075718471, 47.264283657073975, 44.55033813204084, 51.102958406720845, 48.94162048612322, 47.67975466591971, 45.65936442783901, 45.0952262878418, 42.06598540714809, 41.11711508887154, 42.54137768064226, 43.29417678288051, 39.205915791647776, 45.12479434694563, 47.48019198008946, 48.827916690281455, 50.927825587136404, 50.68002503258841, 51.9933248928615, 56.12282691683088, 53.19702386856079, 32.505212034497944, 1.1600879558495112, 0.47351235151290894, 3.3208252915314267, 0.1379128803632089, 0.40625739895871704, 41.61709703717913, 67.85763604300362, 53.56229414258684, 47.49315731866019, 34.17345367159162, 41.71216229030064, 52.14088378633772, 63.371906825474326, 20.94165689604623, 0.16807000285812787, 0.08585171787334339, 0.08538789847599608, 0.11289044270025832, 0.1533768427159105, 0.1860840626593147, 0.08016592689922877, 0.1498879784984248, 0.1763071601412126, 0.18875439651310444], [0.030463735506470715, 0.018869448187095777, 0.04197283275425434, 0.00806437258142978, 0.05909900912748916, 0.09929246521954026, 0.004184085684495845, 0.11651119376931872, 0.036059016694447825, 0.02565013344532677, 0.06515397743455001, 0.03472368013379829, 0.02165277169219085, 0.15367773228457995, 23.03249839373997, 47.781736850738525, 40.591845171792166, 26.378302676337107, 24.902923924582346, 32.17933804648263, 43.0182603427342, 46.697744914463584, 49.12922184807913, 20.758729934692383, 0.11625891444938523, 0.3550293892621994, 3.3960334616047994, 0.4663168947611536, 0.7839695896421159, 31.67552764075143, 45.46314035143171, 52.9695919581822, 46.92983211789812, 46.65324517658779, 42.573148318699424, 40.951702799115864, 37.30102893284389, 38.76559107644217, 36.76520470210484, 41.70929268428257, 39.08137280600411, 41.626209599631174, 41.72139644622803, 41.358697005680625, 40.55824368340628, 42.085985796792166, 39.82075146266392, 41.3427335194179, 42.28553111212594, 40.773200103214805, 38.5962495803833, 40.7071852684021, 40.567158222198486, 39.62612199783325, 39.375479630061555, 39.92055191312517, 38.18991545268467, 38.56086587905884, 36.40464530672346, 33.14608955383301, 33.116761207580566, 34.08976261956351, 32.49077020372663, 31.93623447418213, 31.520624501364573, 32.68169975280762, 32.79893323353359, 34.44019154139927, 34.21237400599888, 34.47474840709141, 33.208797046116416, 34.51905359540667, 34.253392696380615, 32.54354524612427, 33.16576337814331, 32.553043433598106, 33.30576263155256, 33.17391014099121, 31.889844826289586, 33.79474210739136, 32.80664573396955, 31.360944475446427, 32.2658292225429, 33.174556323460166, 30.794694083077566, 32.56928137370518, 37.22555412564959, 45.88078267233712, 47.16336454663958, 45.28680549349104, 44.90898677280971, 47.63600533349173, 36.03154788698469, 36.93498740877424, 36.43178844451904, 35.31658867427281, 35.372462613242014, 35.3253607749939, 32.21558332443237, 32.857249464307515, 34.32036985669817, 35.41621541976929, 34.84755400248936, 34.963092122759136, 33.9372809273856, 36.30498729433332, 35.20191560472761, 35.57046890258789, 35.809327125549316, 32.70894711358206, 33.8909364427839, 33.47083445957729, 33.616677148001536, 34.211297035217285, 33.24696697507586, 33.79277229309082, 33.52629498073033, 34.655363355364116, 34.40187917436872, 34.115915639059885, 33.7100122996739, 34.501384326389854, 33.79807376861572, 34.33371039799282, 33.99415193285261, 32.94104821341378, 33.12909426007952, 39.457819257463726, 43.28990364074707, 43.97174426487514, 46.49242912020002, 47.90993806294033, 44.91354826518467, 45.94339288984026, 46.301735809871126, 47.08131326947893, 44.66000155040196, 45.8881755556379, 42.36246156692505, 41.12661327634539, 38.660721915108816, 38.187744140625, 36.78044557571411, 37.258068220955984, 36.995780672345845, 39.12774855749947, 39.90589468819754, 43.084702491760254, 46.378329277038574, 50.78995943069458, 48.43040330069405, 19.96632957458496, 0.0075996185020942774, 0.5754537156649998, 0.5574210775750024, 0.0919111780822277, 0.6344843623893601, 36.96950953347342, 55.58308390208653, 43.55567223685128, 37.374905654362266, 25.337502479553223, 30.844272954123362, 42.996488162449424, 43.841830321720664, 7.056832373142242, 0.028648572907383953, 0.05142621995349016, 0.07996533159166574, 0.026148322337706174, 0.027310710500127504, 0.03286493523046374, 0.013056945887261202, 0.04377646365069917, 0.005109108302609197, 0.03431287467745798, 0.08263117354363203, 0.05234323628246784, 0.0691339313717825, 0.014551936648786068, 0.05448229418003133, 0.05421414053333657, 0.07264346376593624, 0.039284731461001296, 0.06701688854289906, 0.041752481899623356, 0.08032292633184365, 0.07037969452462026, 0.07022443214165312, 0.26279015306915554, 28.652378593172344, 53.55193785258702, 45.57479790278843, 28.20458803858076, 26.103960003171647, 38.03916733605521, 46.62007795061384, 49.293369565691265, 54.59929888589041, 21.333088874816895, 0.034086484861161025, 0.6308247787611825, 5.173413276672363, 3.6129666439124515, 1.0205375126429965, 35.6818276814052, 46.968585695539204, 53.71386562074934, 49.081390448978965, 50.283727577754426, 44.911588873182026, 42.47545664651053, 38.70590952464512, 40.32685824802944, 39.74066652570452, 42.62963022504534, 41.166461195264546, 42.90659931727818, 42.609751428876606, 44.417328766414094, 42.92605079923357, 44.03405570983887, 41.295447553907124, 42.907822200230186, 42.83920873914446, 40.68265812737601, 39.77596684864589, 42.58565507616316, 41.46950340270996, 42.45422642571585, 41.25729152134487, 41.885366984776084, 40.80979626519339, 40.38687331335885, 37.06000287192208, 34.803703921181814, 35.51828793116978, 35.6782945224217, 33.26598072052002, 33.88168491636004, 32.966186795915874, 33.88805641446795, 34.20252840859549, 36.30889565604073, 35.0485132762364, 36.794348921094624, 35.59421784537179, 34.791819027491975, 36.32676642281668, 34.53360659735543, 33.59431784493582, 35.27031019755772, 34.89979403359549, 36.08496911185128, 35.15656123842512, 36.528184277670725, 33.72271013259888, 33.4027282169887, 34.199735232761924, 35.27429151535034, 32.73539890561785, 35.824932779584614, 38.30102409635271, 48.75171232223511, 48.73852464130947, 46.76632710865566, 47.01025056838989, 49.275807993752615, 37.61003964287894, 38.567800181252615, 38.1674519266401, 38.66538068226406, 37.42852142878941, 38.08159303665161, 34.51902232851301, 35.74195391791207, 36.36855983734131, 36.729167870112825, 35.82396003178188, 36.60830742972237, 35.169154848371235, 37.99785334723336, 36.21911450794765, 36.37220764160156, 36.81952224458967, 34.830381529671804, 35.51795441763741, 34.22846950803484, 36.417513370513916, 36.201556410108296, 35.33725609098162, 35.95617730276925, 35.58103363854544, 35.45599733080183, 35.637932436806814, 35.93905694144112, 35.36710555212838, 36.16538756234305, 35.33687741415841, 36.15694897515433, 35.203110694885254, 34.798266955784385, 36.06078938075474, 42.23257541656494, 44.529364994594026, 45.59815079825265, 48.907393659864155, 49.20688533782959, 45.310401575905935, 46.548782484872, 47.57120990753174, 47.966600622449604, 47.608396666390554, 46.41246230261666, 44.42494746616909, 43.411726406642366, 40.20036629268101, 38.74081380026681, 39.14696032660348, 39.28623349325997, 38.36659772055489, 41.20495074135916, 41.826946531023296, 45.8714199747358, 48.09807791028704, 53.413960524967735, 50.01316819872175, 20.424676179885864, 0.13076505676976272, 1.018330156803131, 3.4226865342685153, 0.11686225421726704, 0.5579040316598756, 40.458981718335835, 60.8029146194458, 50.80593681335449, 42.116332054138184, 24.420649460383824, 32.50127935409546, 48.198757307870046, 52.64377008165632, 11.606242265020098, 0.01754557208291122, 0.08310238897268261, 0.05334478450406875, 0.016566407035237977, 0.038138343154319694, 0.05948511590915067, 0.05454333519030895, 0.051508600890104256, 0.03267992926495416, 0.061256981188697476, 0.13747012269284042, 0.13109938454415115, 0.1339231894484588, 0.06650747159229857, 0.187521634091224, 0.21612044663301536, 0.10524903237819672, 0.16638368048838206, 0.13085912886474813, 0.18903543214712823, 0.16026112330811365, 0.24787904747894832, 0.1479335126600095, 0.29723989165255, 31.68329225267683, 60.69042328425816, 52.38746493203299, 37.24880627223423, 35.418313775743755, 43.18047646113804, 50.9858569417681, 54.74169874191284, 58.72254753112793, 25.64281153678894, 0.21542046990777763, 2.2829963181700026, 7.5525685378483365, 2.1588042165551866, 1.177597090601921, 36.2466675894601, 48.656146798815044, 56.21758992331368, 51.06949240820748, 50.941305092402864, 46.14069741112845, 45.71792731966291, 40.9026380947658, 42.444863728114534, 41.35349975313459, 45.58828783035278, 42.816891125270296, 45.19473838806152, 45.71646472385952, 45.05870655604771, 44.3272453716823, 46.059153352464946, 43.94497285570417, 45.4208779335022, 46.798000471932546, 43.43809829439436, 42.23679992130825, 44.89336722237723, 42.614893095833914, 45.25033787318638, 43.953599044254844, 43.750419821058, 42.20770781380789, 40.92130790437971, 39.66032450539725, 35.35315704345703, 37.122734682900564, 38.62141942977905, 35.163974966321675, 36.09019763129098, 34.199530260903494, 35.92898205348423, 34.97003337315151, 37.495053904397146, 36.95441804613386, 37.11098180498396, 37.32543795449393, 36.910380363464355, 36.52746166501726, 36.09719794137137, 36.258114746638704, 36.98890542984009, 36.64351395198277, 37.51345273426601, 37.04654768535069, 39.605002948216026, 36.265000411442344, 35.4597875731332, 35.994489669799805, 38.02213382720947, 34.3799923488072, 36.50786427089146, 40.29270437785557, 50.361203466142925, 49.920232568468364, 49.955355712345664, 49.7680253301348, 50.83293056488037, 39.96245302472796, 41.82255179541451, 40.59952640533447, 40.372302940913606, 40.23265109743391, 41.063506262642996, 36.33826221738543, 38.08391720908028, 36.32018647875105, 38.36518028804234, 36.13601057870047, 38.23102099554879, 36.35985027040754, 40.285540785108296, 38.17649153300694, 36.880579539707725, 39.781987462724956, 35.86040333339146, 37.002871309007915, 35.101111139569966, 38.931722504752024, 38.00251906258719, 36.9868974004473, 37.267159938812256, 37.50817905153547, 36.975422450474326, 38.44088438579014, 38.46191658292498, 37.821758202144075, 38.50212928227016, 37.95246771403721, 38.06808573859078, 37.895812102726524, 36.47638545717512, 37.697795391082764, 43.55319172995431, 47.230317388262065, 48.150529861450195, 51.30775656018938, 51.17825950895037, 46.69216898509434, 47.96573904582432, 49.58695180075509, 49.769765853881836, 49.329232692718506, 50.81564344678606, 45.21630907058716, 46.31432941981724, 43.72641726902553, 41.43360900878906, 40.320945331028526, 42.868144512176514, 40.71826069695609, 42.75166491099766, 44.14578621728079, 47.817631244659424, 50.216830321720664, 55.512823717934744, 51.66912194660732, 22.155587094170706, 0.3031993018729346, 1.3964044409138816, 3.00833375113351, 0.23363293334841728, 0.7966800704598427, 44.001930713653564, 66.12055165427071, 57.09187480381557, 48.707205636160715, 35.91868829727173, 41.07855953489031, 55.00761325018746, 61.45938737051827, 15.300848722457886, 0.12223771720060281, 0.2480895019003323, 0.1938755852835519, 0.13088166979806765, 0.13244155395243848, 0.09288506582379341, 0.11091513226607017, 0.12498999094324452, 0.1413917022624186, 0.09584279318473168], [0.050849234485732656, 0.013370318803936243, 0.04655377872820411, 0.012605002549077784, 0.009850724583624728, 0.018389649290059294, 0.009075018261293215, 0.08922406405742679, 0.11601004137524537, 0.055796250102243254, 0.126564015767404, 0.024057677913723246, 0.020485879753583243, 0.011508932703041604, 14.145840116909572, 48.138738768441335, 40.82122605187552, 26.58016347885132, 18.007290193012782, 30.830904620034353, 39.46717153276716, 46.18555498123169, 47.72920152119228, 33.81990153448922, 0.3852053614599364, 0.49418096244335175, 1.1337032573563712, 1.7120587144579207, 0.2084643053156989, 13.99550541809627, 42.46453407832554, 51.32814952305385, 48.2309969493321, 46.12288917813982, 43.10671785899571, 39.37792887006487, 36.16203505652291, 38.82869461604527, 39.6683531488691, 40.75562116077968, 41.735647201538086, 44.35057394845145, 41.53601155962263, 42.63136380059378, 40.0973835672651, 40.187585081372944, 40.30633674349104, 41.476427282605854, 39.189295700618196, 37.565025738307405, 39.82465287617275, 38.808291230882915, 39.19966588701521, 40.77160896573748, 42.41112674985613, 42.521022932870046, 42.50874546595982, 42.58668688365391, 39.674241747174946, 37.38044684273856, 34.06362002236502, 32.98512411117554, 33.0441004208156, 33.14957754952567, 33.086335045950754, 32.31094735009329, 32.65539387294224, 34.647831508091514, 35.655306407383506, 35.980252810886924, 33.58045966284615, 33.17299992697579, 35.19542598724365, 34.68655729293823, 33.533660071236746, 32.47028691428048, 32.847654002053396, 33.22727925436837, 33.51272167478289, 32.87209776469639, 32.97034181867327, 30.644599097115652, 32.26294572012765, 32.669443130493164, 32.88975313731602, 32.387790952410015, 36.748223304748535, 46.343008109501426, 46.84625571114676, 44.9333575793675, 48.04417725971767, 46.42475019182478, 37.39015347617013, 35.73749664851597, 36.59738138743809, 36.6008311680385, 34.84814807346889, 34.31679153442383, 32.51239994594029, 32.990661825452534, 33.39259079524449, 34.16703353609358, 34.51740339824131, 35.75314399174282, 35.6671530859811, 34.90228148869106, 34.7377689906529, 34.81046451841082, 36.12789855684553, 34.05267660958426, 33.28409467424665, 34.793750626700266, 33.577933992658345, 33.993460587092805, 33.64174624851772, 34.603147642953054, 32.8155255317688, 33.25241436277117, 34.15301554543631, 33.107738971710205, 33.009460176740376, 34.655509267534526, 34.667668615068706, 33.51842267172677, 34.68190894808088, 33.980109623500276, 33.22561168670654, 32.521616731371196, 38.2675268309457, 42.28803593771798, 43.161615576062886, 45.76209354400635, 44.722375529153005, 45.194095679691856, 46.27719824654715, 47.49612767355782, 45.93232440948486, 47.13683632441929, 46.5974372455052, 48.02735914502825, 42.49249015535627, 42.8452536719186, 42.01515586035592, 44.61065196990967, 40.417323793683735, 40.23671579360962, 37.216573578970774, 42.33932406561715, 45.13424737112862, 51.989023957933696, 44.92491899217878, 11.237288577216011, 0.08011262118816376, 2.386811307498387, 6.624627062252589, 0.08019830659031868, 0.7481271986450467, 39.07790912900652, 50.87839610236031, 43.855740615299766, 36.882698740277974, 22.85740900039673, 29.026744059153966, 42.819944858551025, 36.864869662693565, 3.459000208548137, 0.12997560841696604, 0.023065561328881552, 0.02929659081356866, 0.021368998169366802, 0.047015019692480564, 0.030285484357071773, 0.05481894254418356, 0.039274685750050206, 0.053617640398442745, 0.029860232890184437, 0.06143413989671639, 0.06310169398784637, 0.023642524744250944, 0.04950522964021989, 0.06218844013554709, 0.020220630236768296, 0.01708596638802971, 0.05262895720079541, 0.07330454007855483, 0.04660019052347966, 0.04620768176391721, 0.04121541125433786, 0.0388992183974811, 0.018891364868198122, 17.648585966655187, 53.898277759552, 45.97661917550223, 30.48401927947998, 24.69099518230983, 40.27566739491054, 44.404877594539094, 51.286526339394705, 52.10104628971645, 35.442649841308594, 0.2532391755708626, 0.6534242289406913, 3.030524343252182, 4.724238293511527, 0.42745366586106165, 17.279845067432948, 43.199472836085725, 52.71812970297677, 49.21818658283779, 49.48102651323591, 43.381901264190674, 42.08241094861712, 37.53643042700631, 39.921858174460276, 42.439742905753, 43.3203124318804, 44.72890683582851, 46.67916195733206, 43.792011737823486, 44.786173888615195, 42.02584566388811, 43.05684716360909, 41.839276109422954, 43.110487256731304, 41.69792195728847, 40.489602429526194, 42.1206225667681, 41.00959518977574, 40.78770794187273, 42.143586363111226, 43.640811988285606, 43.40311758858817, 43.980231489454, 43.92783512387957, 41.14357382910592, 38.33657455444336, 35.86200489316668, 34.358925410679404, 34.864229679107666, 33.058611733572825, 34.35708066395351, 34.66142913273403, 35.61801195144653, 36.40406165804182, 34.912095819200786, 38.01891333716256, 34.639980043683735, 35.4731559072222, 36.714274406433105, 35.646009717668804, 35.670175552368164, 34.041069643838064, 34.996613706861226, 34.95173181806292, 34.733207498277935, 34.278149127960205, 33.993471009390696, 33.19689130783081, 32.98860168457031, 33.99576391492571, 33.805775846753804, 35.01539121355329, 39.405586174556184, 48.760560853140696, 46.82923262459891, 44.70775651931763, 48.659551416124614, 48.01351138523647, 39.33730622700283, 37.94704811913626, 39.24140024185181, 37.67875732694353, 35.79492698396955, 35.03092738560268, 35.171868119921, 34.91926288604736, 36.01666137150356, 35.424257959638325, 35.64425877162388, 37.27062014171055, 37.11600187846592, 37.11343451908657, 37.34355885641915, 37.75539248330252, 37.28763280596052, 34.441504750932964, 35.363485540662495, 36.09534624644688, 33.670407567705425, 35.66324472427368, 34.58243158885411, 35.09481259754726, 34.89814036233084, 35.705653054373606, 35.162567956107004, 34.54788861955915, 34.76009007862636, 36.47127505711147, 34.913902350834434, 36.44108166013445, 35.91905655179705, 36.12347255434309, 34.94879967825753, 34.23167610168457, 41.00832714353289, 44.73404502868652, 46.154482637132915, 47.18930564607893, 45.402680601392476, 46.91285419464111, 48.242086274283274, 49.73471219199044, 47.86062669754028, 48.582909311567036, 47.91791459492275, 49.89081389563424, 44.98721306664603, 46.53292669568743, 42.708124024527415, 45.849112783159526, 42.48706361225673, 40.57188299724034, 39.53558349609375, 45.549502985818044, 48.10258729117257, 55.50283220836094, 47.51767403738839, 13.544689791543142, 0.07997877337038517, 3.3862875274249484, 2.125302391392844, 0.07948522735387087, 0.8945646094424384, 43.849754742213655, 54.6192923273359, 51.216054235185894, 43.18061195101057, 33.00314426422119, 37.91518368039812, 46.65991544723511, 46.12040172304426, 6.7689467923981805, 0.14675966064844811, 0.04803352789687259, 0.08247632506702628, 0.0406534655152687, 0.054156811109610965, 0.07625051521297012, 0.09031244101268904, 0.08687929809093475, 0.06518095598689147, 0.014265094451340181, 0.11303497065923043, 0.09339164649801594, 0.07483634645385401, 0.09854078412588153, 0.0858372107946447, 0.15046448899166925, 0.1080432395849909, 0.18154999666980334, 0.31953389250806397, 0.20935197839779512, 0.16705042256840638, 0.11703739767628056, 0.19388128497770854, 0.09891004288303, 19.38219451904297, 61.5575167792184, 52.42808757509504, 35.41218546458653, 27.07656363078526, 43.00817155838013, 48.25845275606428, 55.93000398363386, 56.70290422439575, 41.55982303619385, 0.5371091589331627, 1.7430893693651472, 4.849257665021079, 4.072822528226035, 0.32339915367109434, 18.035656213760376, 43.90789379392351, 52.83635677610125, 52.130916595458984, 51.2577851159232, 45.89891399656023, 43.58241237912859, 39.42913709368025, 42.34809964043753, 44.11301851272583, 44.686307430267334, 46.66976451873779, 49.80762658800398, 47.47803456442696, 46.756460666656494, 43.82524497168404, 44.20575611931937, 45.791845730372835, 45.94995198931013, 43.64680480957031, 42.644975321633474, 43.84151070458548, 44.42240442548479, 43.25509316580636, 44.899710927690776, 45.91714259556362, 46.668642384665354, 45.57748685564314, 46.00355386734009, 44.10259968893868, 41.28026573998587, 38.033362116132466, 36.08788388116019, 36.88197265352522, 35.463984285082134, 35.86852577754429, 35.796146392822266, 36.1647379057748, 37.20142650604248, 37.640427589416504, 39.53398888451712, 36.11346367427281, 36.144942487989155, 38.41591950825283, 38.11522926603045, 37.392939703805105, 35.978501864842, 38.240786688668386, 37.52650145121983, 37.130798067365376, 36.59975072315761, 35.47290577207293, 35.08165270941598, 36.72593348366873, 37.785210677555625, 36.946479729243684, 37.75069897515433, 41.12448712757656, 50.02009207861764, 49.24943610600063, 47.610908440181184, 51.465164525168284, 50.28025695255825, 41.34276826041085, 39.13524913787842, 39.96548938751221, 40.32195976802281, 37.08730581828526, 38.037235736846924, 36.68677691050938, 35.73409897940499, 37.47101313727242, 36.47119515282767, 36.74752501079014, 39.26909228733608, 40.02189833777291, 37.914989130837576, 38.55133295059204, 38.88229649407523, 39.2827593939645, 36.47487422398159, 36.876952580043245, 38.43716362544468, 35.53540481839861, 37.97808919634138, 38.30684321267264, 37.34419114249093, 36.89114080156599, 37.548509870256694, 37.37587145396641, 35.43023688452584, 35.339017459324424, 39.55478484289986, 36.99468980516706, 37.90807567323957, 37.61730745860508, 37.2577486038208, 37.075803075517925, 36.141544818878174, 42.60512740271432, 47.542402676173616, 47.76790993554251, 50.462021827697754, 47.701533794403076, 48.67064421517508, 50.573318072727744, 51.46463646207537, 49.00741645268032, 49.75902393886021, 50.073058196476524, 52.33307095936367, 47.74287210191999, 48.49841226850237, 46.084156445094514, 50.1560822214399, 44.31552376065935, 43.9098219190325, 40.43654598508562, 48.395332268306184, 50.22991030556815, 57.82729993547712, 48.7230475289481, 15.742467539651052, 0.14061430469155312, 7.788086414337158, 18.187568153653825, 0.18880041475806916, 1.0806582123041153, 47.76214640481131, 60.43256173815046, 57.397470474243164, 48.350280148642405, 33.951014041900635, 44.351227079119, 54.424419675554546, 55.347470487867085, 9.43462882723127, 0.26388804987072945, 0.17910077023719037, 0.2088969528142895, 0.1068330452378307, 0.17301897944084235, 0.1369654554873705, 0.17075674368866853, 0.1852612303836005, 0.12197155505418777, 0.1326139968420778], [0.15393828973174095, 0.060440466074006896, 0.01725831258642886, 0.06223361021173852, 0.01950837202769305, 0.030844105274549553, 0.034624502062797546, 0.023383821394028406, 0.04192602740866797, 0.0552659783778446, 0.04854640198339309, 0.03247625340840646, 0.041720153098659854, 0.028488550601261, 6.420538927827563, 46.23874691554478, 41.91117606844221, 27.971039976392472, 17.342927762440272, 30.665242195129395, 37.98290082386562, 51.11677489961897, 46.193868500845774, 41.266376291002544, 2.8678131656987325, 0.396692335073437, 3.9989045517785207, 10.01264078276498, 0.10813275192465101, 4.2757668154580255, 28.482349225452968, 46.90826838357108, 46.57447692326137, 47.07140861238752, 41.53487205505371, 39.35721629006522, 37.06950453349522, 39.17327315466744, 40.209666456495015, 41.83552755628313, 40.344510146549766, 42.989519119262695, 42.4695645741054, 42.31304597854614, 41.100706917899, 38.101885250636506, 38.589666162218364, 37.868304184504915, 36.345575196402415, 37.46765715735299, 35.52807099478585, 39.53114707129342, 39.97221524374825, 42.86127969196865, 43.196505955287385, 44.33755649839129, 44.292646816798616, 44.48732491901943, 44.26093871252877, 42.09155477796282, 36.065861565726145, 32.48481559753418, 32.57291875566755, 33.01680442265102, 32.933294023786274, 32.84491293770926, 33.70333855492728, 33.70946339198521, 35.162970951625276, 34.65127434049334, 34.40483563286917, 33.38153273718697, 34.19123411178589, 34.11749635423933, 33.78066158294678, 32.86382940837315, 34.04523856299264, 34.9123146874564, 33.104633126940044, 34.201135294778005, 32.91191789082119, 31.840672424861364, 32.48091418402535, 31.55744300569807, 33.46170800072806, 30.912420885903494, 36.38176141466413, 46.53985752378191, 45.67893402917044, 46.62520572117397, 46.383568218776155, 45.52353061948504, 36.99469327926636, 37.56040518624442, 37.048260416303364, 37.15434898648943, 34.27228137425014, 33.890807901109966, 33.78895425796509, 33.132811546325684, 34.03420829772949, 33.871641295296804, 34.40552697862898, 35.55440814154488, 35.84294598443167, 35.09004960741316, 36.141374588012695, 35.466711453029085, 35.352437904902864, 34.46163368225098, 33.830560071127756, 33.63849449157715, 33.38693148749215, 34.42744854518345, 34.92366804395403, 33.92286688940865, 32.48450640269688, 34.780465670994346, 33.756527015141074, 33.764906542641775, 34.45435891832624, 33.257305894579204, 33.744728973933626, 32.49772187641689, 35.03566953114101, 34.22736474445888, 33.96927738189697, 33.85476412091936, 31.502698148999894, 36.5412677356175, 40.27543115615845, 42.6214382989066, 41.49822378158569, 42.29523427145821, 43.867642879486084, 46.44170379638672, 46.27230324063982, 47.20725631713867, 46.6451644216265, 45.581617559705464, 45.64703484943935, 43.33885717391968, 49.36309126445225, 46.07101740155901, 44.816495827266145, 41.60911008289882, 39.135315145765034, 41.080828121730256, 47.69263315200806, 51.10719680786133, 36.9068854195731, 5.1642017023903986, 0.04410940721364958, 0.771467771913324, 1.9006977464471544, 0.10612673778086901, 1.72466122678348, 41.631757736206055, 53.67845760072981, 42.49159731183733, 38.798035689762656, 21.082017455782207, 25.37545701435634, 49.03356947217669, 28.604036501475743, 2.3996333394731795, 0.15759423641221865, 0.02811068293106343, 0.05339798843488097, 0.02316787762434355, 0.0749218011541026, 0.02965330345822232, 0.09314531793019601, 0.03490015012877328, 0.0059582736742283616, 0.023718834488785694, 0.045378593395331075, 0.03941431807886277, 0.017438835131802728, 0.006403811217751354, 0.073543526897473, 0.033079009636172226, 0.012148086397376443, 0.014604227949998208, 0.09656668826937675, 0.038024101605904956, 0.040214232834322114, 0.02657927180241261, 0.08310916075216872, 0.02292447184611644, 9.2223014320646, 53.186316694532124, 48.52456876209804, 32.84650754928589, 19.806343827928814, 37.40396996906826, 42.03019871030535, 53.91082273210798, 50.03803580147879, 45.95929036821638, 2.764698858772005, 0.16622026211449079, 1.799199872783252, 6.949901333877018, 0.8090180084109306, 4.670559985297067, 31.69327333995274, 47.61892318725586, 48.67357635498047, 47.70352792739868, 45.69305624280657, 39.49845927102225, 39.15522868292672, 40.031851632254465, 42.69895587648664, 43.73168052945818, 43.79418999808175, 44.08381175994873, 44.763262203761506, 43.35546336855207, 42.74000235966274, 40.608618123190745, 39.70897926603045, 39.20357772282192, 38.473540919167654, 38.347754205976216, 37.62216772351946, 40.162880761282786, 41.27306393214634, 44.007631710597444, 44.42927966799055, 46.19133240836007, 45.51589107513428, 46.47604874202183, 44.97418866838728, 41.99099349975586, 37.22213213784354, 34.282324995313374, 34.92631183351789, 34.079899651663645, 35.83266959871565, 34.68056099755423, 34.85336964470999, 35.36508362633841, 35.44468913759504, 37.86633437020438, 35.72298880985805, 34.65822948728289, 36.04884195327759, 35.63725846154349, 35.61446489606585, 33.65400634493147, 36.160944189344136, 35.63595220020839, 35.211035115378245, 35.4249701499939, 33.90580906186785, 34.06985255650112, 34.08161238261631, 33.41867780685425, 34.086632456098286, 33.69551488331386, 38.47340890339443, 48.484567982809885, 47.43162407193865, 48.7929116657802, 48.280099868774414, 47.3142203603472, 39.13120528629848, 39.237144470214844, 39.29546070098877, 37.89370332445417, 37.91630234037127, 35.883464404514854, 34.74636738640921, 35.556624616895405, 35.63478490284511, 36.43521738052368, 36.16815989358084, 35.63997173309326, 38.03136798313686, 35.55110774721418, 37.5626494543893, 36.76542009626116, 37.33423089981079, 35.84450238091605, 35.75577735900879, 34.794143199920654, 36.03258316857474, 35.5072020803179, 35.75139651979719, 36.34595734732491, 35.269320079258506, 36.343789509364534, 33.84774991444179, 34.98570156097412, 35.616941928863525, 34.889792101723806, 36.02067048209054, 36.293745109013145, 35.94834668295724, 36.42369031906128, 36.01944759913853, 34.55340896333967, 34.52322251456124, 39.07428911754063, 43.53317049571446, 43.999693393707275, 43.93925448826381, 44.84056091308594, 46.30880560193743, 47.818496295383994, 46.78715433393206, 48.89191654750279, 47.09499774660383, 46.54158067703247, 46.55633865083967, 46.24819646562849, 51.25352239608765, 48.59761864798409, 46.149681431906565, 42.58140277862549, 41.58507626397269, 44.29531839915684, 49.53756400517055, 52.98785529817854, 39.778676646096365, 6.346337812287467, 0.04831739641459925, 1.9408776589802332, 3.3217144438198636, 0.1752186542642968, 1.8217931347233909, 45.736913272312705, 56.73046425410679, 49.25999736785889, 40.16787304197039, 20.09716589110238, 31.696858610425675, 53.879090309143066, 36.50672129222325, 4.416778334549495, 0.10853479070855038, 0.011399347601192338, 0.0140380668121257, 0.0044303171369912365, 0.034203057177364826, 0.00873092551981764, 0.05293223521273051, 0.005009079094244433, 0.03689183022028633, 0.052884245823536596, 0.1776979397982359, 0.1668577864766121, 0.057130572253039906, 0.21888562611171178, 0.0911868487351707, 0.11894771802638258, 0.06293840453560863, 0.11993862342621599, 0.2728015844311033, 0.1068561357845153, 0.1474796270153352, 0.1427510521773781, 0.22878072943006242, 0.1327457276305982, 11.503367236682347, 61.89187799181257, 54.23740196228027, 40.617414542606895, 27.96631520135062, 41.98578235081264, 48.13814122336251, 59.50740909576416, 54.418440750667024, 49.84170402799334, 3.7771827578544617, 0.7972675732203892, 10.838189261300222, 19.65410532270159, 0.41320581468088285, 5.538765626294272, 30.871096474783762, 49.750564507075715, 50.265992300851, 51.852745464869905, 46.202126434871126, 42.352126121520996, 39.99955293110439, 41.91435486929757, 45.22268404279436, 47.307039397103445, 44.15076807567051, 46.41139922823225, 47.81009592328753, 46.61436653137207, 45.24621411732265, 43.282910278865266, 41.75203800201416, 41.86574527195522, 39.78129959106445, 40.225796699523926, 38.730745860508506, 42.62699338368007, 43.945566926683696, 46.7303250176566, 46.06525387082781, 48.75087506430489, 47.92597450528826, 48.148907457079204, 48.176384108407156, 45.19077444076538, 40.20115491322109, 36.55867644718715, 35.51994507653372, 36.776554584503174, 37.43628256661551, 35.92558091027396, 38.1972006389073, 36.93192672729492, 38.33638000488281, 38.71051270621163, 36.9049642426627, 35.52528824125017, 37.56581435884748, 36.5231294631958, 37.530159677777974, 35.00872789110456, 38.699437277657644, 37.66965518678938, 36.8623092515128, 38.017402103969026, 36.35960013525826, 36.14199297768729, 36.62845025743757, 35.686667101723806, 37.81729398454939, 34.999417304992676, 40.30256387165615, 49.357786314828054, 48.7129795891898, 48.810424600328716, 48.84086813245501, 50.43202992847988, 42.29039485113961, 40.60308388301304, 42.186039856501985, 40.57520771026611, 40.039310523441856, 38.456615107400076, 37.29065874644688, 36.49796308789934, 37.64182070323399, 38.30797924314226, 37.602810042245046, 38.794957637786865, 38.749509470803396, 37.62990801674979, 40.40876361301967, 38.819415296827046, 39.96366548538208, 37.265589645930696, 37.17851482118879, 37.936212403433665, 36.742279120853965, 37.24914673396519, 39.183601651872905, 37.63570976257324, 36.52888257162911, 38.31387826374599, 35.78617572784424, 36.930085454668315, 37.89131314413888, 35.84591633932931, 36.96018157686506, 36.78695603779384, 38.37209721973964, 38.473137923649375, 39.08999899455479, 37.64422825404576, 36.068741594042095, 41.41306665965489, 45.220960889543804, 46.16518981116158, 46.451997552599224, 46.695351260049, 47.681543827056885, 49.74079533985683, 48.9478634425572, 50.556802204677034, 49.59283345086234, 46.56890794209072, 49.10589674540928, 47.3538042477199, 52.74415070669991, 50.25100156239101, 48.54476717540196, 46.021653924669536, 43.67443779536656, 45.98503344399588, 53.13789817265102, 56.11774778366089, 40.7214047568185, 7.487613303320749, 0.15757440961897373, 4.792400555951255, 6.119796139853341, 0.30236508377960747, 2.293600354875837, 50.66819225038801, 61.078403745378765, 53.16374199731009, 49.382303033556255, 30.35879189627511, 39.05574090140206, 60.57791110447475, 44.71878331048148, 6.1739877462387085, 0.23934798953788622, 0.13586498025272573, 0.16698646385754856, 0.09626466554722615, 0.1300372736794608, 0.06493755190500192, 0.1807269879749843, 0.14621505487178052, 0.12309020145663194, 0.16181157582572528], [0.008062675395714385, 0.05695508952651705, 0.0704593477504594, 0.0246898079224463, 0.09106069550450359, 0.03509331887055721, 0.03541010990738869, 0.023815904012215987, 0.08311524721128599, 0.061491157194333415, 0.02643724254864667, 0.011835442057677677, 0.021573622278603058, 0.09171581427965846, 2.3131367351327623, 37.16421890258789, 45.54744284493582, 29.922337327684673, 19.334811278751918, 35.300430638449534, 39.069491386413574, 51.26274265561785, 44.2716771534511, 48.775016580309185, 6.0302998679024835, 0.18009274772235326, 0.7816126846841404, 4.095612185341971, 1.7909819994653975, 0.4888281353882381, 12.930650557790484, 40.352615220206125, 51.49465267998831, 44.70620707103184, 43.21374443599156, 38.7020081111363, 36.588157653808594, 35.89714193344116, 38.97006961277553, 39.26126514162336, 40.8237030846732, 42.69826800482613, 41.06239455086844, 38.465953486306326, 36.47956773212978, 36.55097436904907, 36.509736810411724, 36.21255888257708, 36.46235704421997, 38.31319039208548, 41.64544916152954, 43.98267378125872, 44.32323973519461, 44.84156492778233, 45.83108220781599, 45.29982989174979, 46.40446492603847, 45.47073820659092, 44.55452789579119, 43.580067362104145, 41.577759810856406, 33.497953278677805, 33.21968139920916, 32.60820518221174, 32.40953533990042, 32.131805419921875, 33.02731009892055, 35.86317219052996, 34.76788248334612, 34.647397245679585, 34.23760291508266, 33.773577894483296, 34.86891276495797, 33.72448192323957, 34.438812323978965, 33.85677562441145, 33.97316142490932, 34.50955540793282, 33.97821971348354, 33.47295018604824, 33.558645793369834, 32.121146883283345, 30.792644364493235, 32.94097178322928, 31.60735191617693, 32.11918749128069, 36.9101128578186, 46.185926709856304, 47.825545242854524, 48.004450934273855, 48.596430506025044, 44.85948085784912, 39.173158509390696, 38.507694789341514, 38.00547552108765, 37.05394751685006, 35.777341093335835, 30.68485001155308, 32.88518817084176, 34.077353136880056, 33.34047583171299, 34.37129667827061, 33.84010342189244, 38.74800865990775, 33.36300189154488, 35.960342747824534, 35.79248469216483, 35.0190737588065, 35.535870347704204, 35.00002874646868, 33.97989075524466, 33.77791704450335, 32.063108580453054, 33.225285121372764, 34.147126947130474, 33.552687713078086, 33.459303924015586, 33.4028810773577, 33.33920431137085, 33.63142817361014, 34.09014824458531, 33.57393183026995, 33.6706577028547, 33.820380960192, 33.142118658338276, 33.37718663896833, 32.969799859183176, 34.43599830354963, 33.0189653124128, 34.28886672428676, 35.66716003417969, 37.22952502114432, 38.58215863364083, 41.22794580459595, 41.05820826121739, 43.66791691098894, 44.51303325380598, 45.333889961242676, 48.07069853373936, 48.06222173145839, 44.69825485774449, 46.969211033412385, 46.528274876730784, 48.351951190403526, 49.24273109436035, 47.57926286969866, 42.08639574050903, 44.454838616507395, 47.97434786387852, 53.28905275889805, 28.59969561440604, 1.6479393265077045, 0.08917843257742268, 1.123878830245563, 1.3980289080313273, 0.11072448428188052, 4.5236872264317105, 52.44511413574219, 47.80976588385445, 36.721973010471885, 31.678789819989884, 28.579368659428187, 27.512109722409928, 44.03343732016427, 22.659746646881104, 1.1303606310061045, 0.07207957402403865, 0.004668922704045794, 0.05948075971433094, 0.02800314700497048, 0.02663282348242189, 0.032017858898533244, 0.028734780781503235, 0.01840710629975157, 0.0204614524929119, 0.0334747210810227, 0.03292108739593199, 0.03564221298854266, 0.056295092084578106, 0.015995358748893653, 0.047007012979260514, 0.04208037376935993, 0.010899514109561486, 0.0427209277903395, 0.03439167634184871, 0.03599647951445409, 0.05575298331677914, 0.023130637926182578, 0.06495391816965171, 0.060057840176991055, 3.2904371278626576, 46.050061634608674, 50.56863498687744, 34.42921338762556, 21.399742943899973, 38.89394514901297, 45.40654379980904, 55.13643632616316, 48.534688813345774, 50.746290002550396, 6.352575991834913, 0.16831302696040698, 0.4816978722810745, 5.782147560800825, 2.9226101338863373, 1.234756663441658, 15.08028336933681, 40.99980170386178, 52.94456107275826, 46.104396547589985, 44.63919169562203, 41.31737606866019, 38.14536707741873, 38.99940838132586, 41.04442650931222, 40.16597270965576, 42.09461545944214, 43.23769835063389, 43.51131493704659, 42.370302609034944, 38.96782534463065, 37.71330724443708, 38.443587235042024, 36.819584778376985, 37.14019898005894, 40.16438504627773, 42.66735894339425, 45.43305812563215, 45.57366534641811, 46.465470109667095, 48.06449726649693, 46.821572235652376, 49.450270312173025, 47.09303488050188, 47.275011675698416, 45.05000046321324, 42.938230991363525, 34.781907422201975, 35.516345909663606, 34.86709928512573, 34.236842087336946, 33.27250507899693, 34.83827468327114, 34.283398491995676, 36.00558246885027, 35.722168922424316, 35.79076153891427, 35.81340224402291, 36.15212345123291, 35.47620269230434, 36.45070491518293, 35.345750263759065, 35.811133657182964, 36.3419690813337, 35.3934531211853, 35.162036418914795, 35.01354994092669, 33.08574444907052, 32.975799628666465, 34.80476699556623, 33.78115837914603, 34.13999809537615, 37.67819104875837, 46.49865470613752, 50.04008204596383, 48.444025244031636, 48.36267573492867, 47.730139528002056, 40.33036014011928, 39.25130142484392, 39.67989758082798, 38.679124219076975, 36.71185295922415, 32.50836304255894, 36.20761176518032, 36.013260228293284, 35.255917004176546, 37.13874680655343, 36.78602497918265, 38.63139009475708, 35.7296347618103, 37.791290351322715, 37.840143135615754, 36.90282072339739, 37.34295088904244, 36.52466154098511, 36.39150973728725, 34.72613770621163, 33.18145588466099, 35.46126059123448, 35.858648913247244, 35.236468996320454, 34.9824880191258, 34.37929058074951, 35.53800344467163, 35.65110969543457, 35.110800402505056, 36.622853483472554, 35.25376306261335, 36.22757393973214, 35.84395694732666, 34.93681056158883, 35.22250311715262, 35.68547895976475, 34.58782339096069, 35.67679371152605, 38.020480155944824, 39.98696279525757, 41.25321640287127, 42.5611765725272, 44.35712262562343, 46.676754406520296, 47.461348465510774, 46.39873266220093, 49.83928952898298, 49.44586515426636, 46.23416110447475, 46.79056589944022, 48.02544491631644, 49.821592467171804, 50.42560631888253, 49.86098527908325, 45.29308319091797, 45.33504336220877, 51.53326381955828, 54.395977224622456, 32.24049261638096, 1.846280106476375, 0.4936160413282258, 4.399648419448307, 2.0478458276816776, 0.12120687322957174, 4.561645669596536, 56.75921589987618, 54.25101695741926, 41.42767872129168, 34.486654145377024, 29.226523876190186, 30.4633275440761, 50.38007477351597, 29.415528774261475, 1.930613215480532, 0.04418086373646345, 0.005610633466858417, 0.059077635274401734, 0.039152973531080146, 0.08160984263356243, 0.009707817475178411, 0.021580653597733805, 0.03865179738828114, 0.04677431957264032, 0.014347543241456151, 0.10245419413383518, 0.1533816603145429, 0.28621182484286173, 0.0947982631623745, 0.1437665612569877, 0.22102812757449491, 0.09912450744637422, 0.06875925111983504, 0.13873185856001718, 0.10955300714288439, 0.1477571614086628, 0.08098561077245645, 0.16838880575128964, 0.16905450288738522, 4.180938235351017, 53.209395136152, 56.84773594992501, 42.79024478367397, 27.76927297455924, 45.202482155391145, 49.76573937279837, 59.67057364327567, 52.36121116365705, 56.373559611184255, 8.393139021737234, 0.5395723496164594, 2.931390485593251, 10.196337257112775, 4.388656369277409, 1.4991978279181888, 16.69569264139448, 42.586005960192, 54.19297170639038, 49.686088698250906, 47.115880557468955, 43.6591135433742, 40.05381836209978, 41.02802528653826, 42.040871143341064, 43.378232615334646, 45.51593623842512, 46.94463872909546, 45.20073815754482, 43.036287443978445, 40.87863901683262, 40.83792952128819, 40.85016182490757, 38.576238768441335, 39.5687507220677, 42.90286466053554, 44.6842611857823, 47.39712626593453, 47.44890076773507, 48.96403537477766, 48.15148523875645, 48.68816409792219, 50.90237086159842, 47.756560053144185, 48.84703465870449, 47.12364169529506, 45.847907270704, 36.80161326272147, 36.65982832227434, 35.882710524967735, 36.38165371758597, 34.67547491618565, 36.06856441497803, 38.04884965079171, 37.81583833694458, 37.07476084572928, 37.181672777448384, 36.92668431145804, 38.42861039297921, 37.442219802311485, 38.76146732057844, 36.96144267490932, 36.86677346910749, 39.21581697463989, 38.425580978393555, 36.81488084793091, 37.796650886535645, 35.45922129494803, 33.62604331970215, 37.37140028817313, 35.33676276888166, 36.42443377631051, 41.06616742270333, 49.36711079733712, 51.510577951158794, 51.35080759865897, 50.87712805611746, 49.00407089505877, 42.36022424697876, 41.62510136195591, 42.36948619570051, 41.26029314313616, 40.58050571169172, 34.81597791399275, 37.793923718588694, 37.467629364558626, 36.25944185256958, 38.40763030733381, 38.18185206821987, 42.50676870346069, 36.26600095203945, 39.91395807266235, 40.15198598589216, 37.57666049684797, 39.100303173065186, 39.144187995365684, 38.069829736437114, 36.78386408942086, 34.53535059520176, 36.7689984185355, 38.05088894707816, 37.19018084662301, 35.88308572769165, 37.040019852774485, 37.28654193878174, 37.390643324170796, 36.31566320146833, 38.888042654309956, 37.026898179735454, 38.52158423832485, 36.72856337683541, 36.848510129111155, 36.54191391808646, 38.21115262167794, 37.32264825275966, 37.57331146512713, 39.50642538070679, 42.44162239347185, 42.851611273629324, 45.36647353853498, 46.06840487888881, 50.218021937779014, 50.116467067173545, 49.4705798966544, 52.07015459878104, 51.27426624298096, 47.55490595953805, 47.48766129357474, 49.479477064950125, 52.01191827229091, 52.17503070831299, 52.79010261808123, 47.09908676147461, 48.55740247453962, 53.69046756199428, 56.74533339909145, 32.83036340985979, 2.9462687500885556, 0.6691216751933098, 6.145074120589665, 4.1961652125631055, 0.26963847130537033, 6.007557111127036, 61.565931047712056, 58.113635199410574, 47.78238998140608, 44.02396692548479, 39.370077405657085, 39.12063012804304, 56.86247655323574, 38.4954868044172, 2.762274805988584, 0.13090606991733822, 0.0733896487259439, 0.12142175169927732, 0.13923880564314978, 0.13299594420407498, 0.08032015790896756, 0.07750833593308926, 0.10410426237753459, 0.08132839309317724, 0.07122096938214131], [0.02414871865351285, 0.07087689784488507, 0.04229663645050355, 0.05359508250174778, 0.054546548053622246, 0.025864650595134923, 0.059008567194853506, 0.03607819887942501, 0.022669481778783456, 0.04333491037998881, 0.03218180313706398, 0.09425938422126429, 0.034105477056332996, 0.035143262440604825, 0.6485738977789879, 29.517299039023264, 46.78679650170462, 38.093172209603445, 22.77280252320426, 29.03008266857692, 34.02984830311367, 52.57735572542463, 45.09658466066633, 50.21721942084176, 12.759943740708486, 0.020670556629608785, 0.3167972522122519, 1.9125329170908247, 3.476509668997356, 0.2790835430579526, 4.470633821828025, 25.603625433785574, 49.88283736365182, 44.270367418016704, 45.23238720212664, 37.78393220901489, 38.4419161932809, 35.503481319972444, 36.66925702776228, 39.339182240622385, 40.021533557346885, 39.25320175715855, 36.34765270778111, 34.75798824855259, 34.05616807937622, 33.757722105298726, 35.54395110266549, 35.63044922692435, 39.63157980782645, 42.75023705618722, 43.92780385698591, 43.72937372752598, 45.00373935699463, 45.3078932762146, 45.34367649895804, 42.037456103733604, 44.463172980717246, 44.801241057259695, 46.61290740966797, 45.656383650643484, 43.367195401872905, 36.57629707881382, 33.32046154567173, 32.88256522587368, 33.54507943562099, 33.18249464035034, 34.082265513283865, 35.331482137952534, 34.87815039498465, 36.345703738076345, 35.5765312058585, 35.450410979134695, 34.43942723955427, 34.53697647367205, 35.162543637411936, 33.24007783617292, 34.3794503893171, 33.97109433582851, 35.080811977386475, 33.92991583687918, 33.296271392277305, 31.43053068433489, 34.19488539014544, 31.89571257999965, 32.07275268009731, 31.801727771759033, 36.60131754193987, 45.674195357731406, 48.68552378245762, 45.668174743652344, 48.544669900621685, 45.72828013556344, 40.144151891980854, 37.814514705113, 38.34651047842843, 36.21565430504935, 35.94074535369873, 31.908545902797155, 32.079916272844585, 32.08672898156302, 33.26265600749424, 33.7924040385655, 34.24998460497175, 36.516049248831614, 35.72184235709054, 34.903372355869834, 36.00380025591169, 34.83332061767578, 33.39981344767979, 35.43210594994681, 34.88123539515904, 32.62644420351301, 33.55931976863316, 33.545298303876606, 33.67881836209978, 33.12591545922415, 34.35430833271572, 34.708482333592, 34.41126619066511, 34.332101890019004, 33.74609429495675, 34.313133307865684, 33.273453508104595, 32.27708877835955, 32.86630991527012, 35.3939916065761, 33.52198709760393, 31.890758514404297, 32.673660687037874, 32.634962694985525, 31.89697367804391, 34.97945860454014, 36.054060050419395, 35.19103472573416, 37.84061908721924, 39.06565945489066, 42.635671683720176, 44.14880173546927, 44.76860884257725, 45.46556179864066, 48.57986947468349, 49.419416836329866, 49.51835918426514, 47.44632298605782, 48.12266411100115, 47.48268290928432, 46.713611125946045, 45.61728266307286, 48.436416966574534, 49.9865392276219, 15.913485288619995, 0.158734867349267, 0.17162103445402213, 1.5099164013351714, 1.4086400015013558, 0.13606379101318972, 6.729127534798213, 54.730675424848286, 47.208545207977295, 39.55193608147757, 23.579922642026627, 18.67210946764265, 29.262862954820903, 45.15581110545567, 16.86946013995579, 0.8847849113600594, 0.1999531148799828, 0.04144564836419054, 0.02887776168063283, 0.006949298241774419, 0.059182007530970235, 0.08411652062620435, 0.03395005861031158, 0.0815523232200316, 0.0646733371540904, 0.015109098715973752, 0.024162386045125977, 0.0364386638227318, 0.07419484587652342, 0.04979630759251969, 0.03683085706351059, 0.006628262968401292, 0.04287718083443386, 0.027191147540829012, 0.03821971307375601, 0.0047539685869456404, 0.029381465366376296, 0.07116160435335976, 0.03209666395559907, 0.05959777986364705, 1.0345334644828523, 36.165033204214915, 50.18893330437796, 42.9008983203343, 24.19371782030378, 32.9609409059797, 40.26047168459211, 54.359711102076936, 50.42896924700056, 53.209270068577354, 14.018884369305201, 0.12388209253549576, 0.09874188154935837, 4.637194735663278, 6.449505533490862, 0.911213144659996, 5.067629558699472, 30.010311944144114, 49.98244326455252, 48.01469257899693, 45.64169863292149, 39.90166670935494, 39.263283593314036, 37.854946272713796, 38.466304370335166, 40.167862619672505, 41.81944595064436, 41.784062249319895, 39.86562640326363, 36.304160458701, 35.74616800035749, 35.09266907828194, 38.10231256484985, 36.92792803900582, 40.98196220397949, 43.219959599631174, 46.160579681396484, 45.417257922036306, 46.58133132117135, 46.61409902572632, 47.53380428041731, 43.20137316840035, 46.27355739048549, 46.0602650642395, 46.39153780255999, 46.87883234024048, 44.7691890171596, 38.45916857038225, 35.29897499084473, 34.789915221078054, 34.316291264125276, 34.25083575929914, 36.08148806435721, 37.55095911026001, 37.15901470184326, 37.932283197130474, 36.341100556509836, 35.92789813450405, 36.344699723379954, 35.0501252583095, 37.046596322740825, 35.42508479527065, 35.14849437986101, 35.52686548233032, 36.84121104649135, 36.19502510343279, 35.35870518003191, 35.230979919433594, 35.62038476126534, 33.680312224796836, 33.84801047188895, 33.96594572067261, 38.125922543661936, 46.622079031808035, 47.867283071790425, 47.4591007232666, 50.56422288077218, 47.36801331383841, 41.82737384523664, 39.40338012150356, 40.19809423174177, 39.70313583101545, 38.58705016544887, 33.98128039496285, 34.885366099221365, 33.81191805430821, 37.18867308752877, 35.77559362139021, 37.730073247637065, 38.311161518096924, 35.34115750449044, 35.362002100263325, 37.2403016771589, 36.43854556764875, 36.15965877260481, 35.815250464848106, 36.03705433436802, 33.035724367414204, 34.502631528036936, 34.42854983466012, 35.98853158950806, 35.493323053632466, 36.52925082615444, 35.466798305511475, 35.97012233734131, 36.197790486471995, 35.11586216517857, 35.392838205610005, 35.437042645045686, 35.052334785461426, 34.35827228001186, 36.52741302762713, 35.828122002737864, 34.38933767591204, 34.000638076237266, 34.40305341993059, 35.28687122889927, 37.860664640154155, 36.43476227351597, 38.42782872063773, 38.38621595927647, 42.22881644112723, 44.55350651059832, 46.376168387276785, 45.021290506635395, 47.2478928565979, 49.40469012941633, 51.17390993663243, 51.342111928122385, 49.72639519827706, 49.7732503754752, 49.83208424704415, 49.724442754473, 48.3174638066973, 51.14167376926967, 51.916828700474326, 18.694645949772426, 0.4298711232841015, 1.327279961534909, 3.7277706435748508, 1.845511244876044, 0.2138567181038005, 7.094653155122485, 59.97626658848354, 49.89910657065255, 43.182272570473806, 30.655611991882324, 23.579224348068237, 34.45606470108032, 51.38689306804112, 23.00748314176287, 0.968773541705949, 0.2005177510104009, 0.04179773000734193, 0.08372404918606792, 0.010559966704542083, 0.019845013606495092, 0.030834982371223823, 0.03134707614247288, 0.07453903276473284, 0.02883809452344264, 0.023098639911040664, 0.12281798677785055, 0.16177854474101747, 0.12877164302127703, 0.1746077420456069, 0.1632948669471911, 0.0682996589956539, 0.1068428907809513, 0.15691798127123288, 0.18358843800212654, 0.16631543343620642, 0.06847873117242541, 0.24643935901778086, 0.10482869350484439, 0.11299548670649529, 1.516090527176857, 42.03763675689697, 58.09112998417446, 49.33831398827689, 31.314026764460973, 40.466155733381, 45.19061115809849, 60.91314084189278, 54.14016192299979, 60.670808519635884, 15.198328052248273, 0.17327014596334525, 1.2091588484389442, 10.027327537536621, 9.092397042683192, 0.4028952307999134, 7.035351148673466, 31.626608848571777, 56.27848046166556, 49.759611061641145, 48.532357692718506, 41.46644272123064, 43.13585860388619, 38.75270216805594, 40.79583386012486, 41.9197154045105, 44.88170119694301, 43.3135518346514, 40.65584850311279, 37.51969916479928, 36.94176537649972, 36.8309520312718, 40.4509391784668, 39.91758503232683, 43.48988321849278, 45.62498474121094, 48.38596262250628, 46.97366830280849, 48.79152202606201, 48.70584031513759, 49.13237285614014, 42.62653827667236, 45.976264817374094, 47.33199037824358, 48.50303976876395, 50.350579670497346, 46.57021420342581, 39.406788212912424, 37.82826171602522, 36.95893437521798, 36.90678119659424, 36.98255477632795, 37.75511455535889, 38.90885945728847, 39.08856419154576, 40.24776342936924, 36.82900653566633, 38.09527056557791, 36.94116088322231, 37.37835890906197, 39.17096982683454, 36.98975658416748, 37.77095297404698, 37.071387495313374, 39.03330864225115, 37.68634475980486, 37.12999207632882, 36.31467308316912, 39.522691113608225, 37.10830327442714, 36.33392654146467, 34.755591120038716, 40.63587243216378, 48.617004122052876, 50.65923254830496, 48.493159430367605, 52.44840063367571, 49.29600293295724, 43.77423824582781, 41.90192106791905, 41.76271390914917, 40.59163325173514, 40.807433877672466, 35.46185466221401, 35.78764179774693, 36.63953263419015, 38.712010043007986, 37.89695855549404, 39.31764282499041, 38.85566404887608, 38.0981262751988, 36.96932193211147, 38.57729489462716, 38.070396014622276, 37.25104706627982, 38.45893233163016, 37.60347012111119, 34.737060274396626, 35.9957195009504, 36.758374622889924, 36.97838238307408, 37.290210587637766, 38.23448814664568, 37.23398576463972, 38.00045197350638, 37.0988815171378, 36.96055677958897, 38.16672931398664, 36.72143799918038, 35.286273683820454, 37.11719349452427, 38.61252226148333, 37.285398960113525, 34.920565673283164, 35.913008144923616, 34.71348851067679, 35.55856663840157, 39.54413325445992, 39.24029895237514, 40.05079589571272, 40.09682771137783, 43.36177928107125, 47.06637464250837, 48.96083920342581, 47.738004888807026, 49.254438808986116, 50.65141582489014, 54.44695963178362, 53.472898619515554, 49.057012694222585, 51.437191077641074, 50.885010787418906, 52.98568746021816, 49.509628772735596, 55.38393463407244, 52.858254023960654, 20.94450739451817, 0.7843054916177477, 1.2455821739775794, 7.587369459015982, 6.5723292742456705, 0.22654274451945508, 7.599068488393511, 65.2070233481271, 53.81062970842634, 50.80893496104649, 34.94462033680507, 29.818260260990687, 41.3301294871739, 58.57285554068429, 28.15639533315386, 1.3183971238987786, 0.30742649361491203, 0.13057141644614084, 0.19890631176531315, 0.10338576164628778, 0.1333456611526864, 0.19097179467124598, 0.09754957338528973, 0.2543029284902981, 0.09591866697051696, 0.10979230608791113], [0.023955660173669457, 0.01016828406136483, 0.07457917489643608, 0.03147037274071148, 0.0044793264491350526, 0.02841765895885016, 0.028613523180995668, 0.027189588606623665, 0.044281670291508944, 0.04872845971424665, 0.030130076089075634, 0.08048976452222892, 0.019826625307489718, 0.06954842805862427, 0.2804482669702598, 22.251576457704815, 50.06366075788225, 35.71567930494036, 29.34336130959647, 33.776572568076, 34.142808641706196, 47.08631944656372, 46.451966285705566, 49.3187061718532, 17.255938053131104, 0.09786655101925135, 0.23569334564464434, 3.1861809279237474, 3.940821085657392, 1.0572815409728458, 0.3539225086569786, 12.041747535978045, 45.48170941216605, 48.137460299900596, 45.47149556023734, 42.13354621614729, 35.085543700626914, 36.021306242261616, 35.42176703044346, 35.787346499306814, 35.05172334398542, 34.56984840120588, 33.96647725786482, 34.20663479396275, 32.991457394191194, 34.26388447625296, 37.15722554070609, 42.153206144060405, 43.11006341661726, 44.93493482044765, 48.043374742780415, 47.29343829836164, 43.70533990859985, 45.28308820724487, 44.23297916139875, 44.94944960730416, 45.869846207754954, 44.450020040784565, 43.82624898638044, 44.59351771218436, 45.34118209566389, 41.00896290370396, 34.193193503788535, 33.7948637008667, 33.85665055683681, 32.91083744594029, 34.000912530081614, 33.62956953048706, 35.80130543027605, 34.95795045580183, 34.13033315113613, 34.61493526186262, 33.57918814250401, 35.33770424979073, 34.12222112928118, 35.676915305001394, 34.92651333127703, 33.40298530033657, 34.61895826884678, 33.79911252430507, 31.782335349491664, 31.277868338993617, 32.79125199999128, 32.31036717551095, 31.98136302403041, 32.64621877670288, 35.79280430930001, 48.3656530380249, 47.84951305389404, 48.176443168095176, 48.74527134214129, 46.15637949534825, 40.720744677952354, 39.46674769265311, 39.33339091709682, 38.55832631247384, 35.94418123790196, 30.860684599195206, 32.949139390672954, 31.79463366099766, 32.83031129837036, 34.14752994264875, 34.30245392663138, 33.607800824301584, 34.4762978553772, 35.223854541778564, 34.54775660378592, 35.52041060583932, 34.51631253106253, 34.38328232084002, 33.44095720563616, 34.76371356419155, 33.49574375152588, 32.91849783488682, 34.03621285302298, 35.59177207946777, 35.719893387385774, 35.080940519060405, 33.09251546859741, 33.697505542210166, 36.967001233782085, 37.8751585824149, 37.01214368002755, 34.30199881962368, 34.47153833934239, 33.494538239070344, 33.0432562146868, 34.6548352922712, 32.82341521126883, 34.28291211809431, 33.13745641708374, 32.25477811268398, 31.865175247192383, 33.45749044418335, 34.297760418483186, 35.913025515420095, 37.155432905469624, 40.48481512069702, 43.40436826433454, 43.806338923318044, 44.29202495302473, 46.59942443030221, 46.800897870744976, 48.223770822797505, 48.47304439544678, 48.869282790592735, 46.5683798789978, 50.513765062604634, 49.18058293206351, 44.2699887411935, 9.192960926464625, 0.07394973188638687, 1.324827898825918, 3.233791938849858, 0.8363977649382183, 0.03657347516023687, 9.021455935069493, 55.79658120019095, 46.5404828616551, 40.74013710021973, 23.308298451559885, 26.102910825184413, 31.777040822165354, 42.837360518319265, 13.518189362117223, 0.38362825608679224, 0.04263087262266448, 0.04524512216448784, 0.07400528354836361, 0.04118779148640377, 0.042007526249757836, 0.029475893692246506, 0.015441457042470574, 0.009179968968965113, 0.02255502818817539, 0.04250814938651664, 0.04798183370647686, 0.0034047835506498814, 0.04421621880361012, 0.03285901161975094, 0.008367547964943307, 0.0037267361185513437, 0.03717036884544151, 0.0415332234863724, 0.05098841219608273, 0.039300816133618355, 0.0805833005745496, 0.06035098766109773, 0.04954214194523437, 0.07898731157183647, 0.3313298166862556, 28.312992095947266, 55.9887683732169, 40.481816973005024, 30.15338577542986, 37.05855417251587, 41.06778635297503, 52.50332266943795, 49.0437833241054, 54.44024419784546, 18.189963545118058, 0.08794097469321319, 0.20285828970372677, 4.023738282067435, 6.915145141737802, 2.404539853334427, 0.9496516649212156, 14.7060638155256, 49.09834752764021, 49.732273374285015, 48.018392494746614, 43.18859543119158, 37.213068212781636, 37.94453634534563, 36.60923501423427, 37.796101978846956, 37.8647050176348, 36.31091758183071, 36.667572089603965, 36.48430640356881, 34.536271231515066, 35.04610225132534, 38.77861547470093, 42.473712648664204, 44.865494523729595, 44.82376364299229, 47.78051049368722, 47.58978591646467, 45.086777278355186, 46.016258648463655, 45.531323024204795, 45.661709444863455, 46.10190909249442, 44.82908248901367, 45.36832870755877, 45.64128521510533, 47.15157345363072, 42.072256156376426, 35.25055994306292, 35.87259047372, 33.95934493201119, 33.62394496372768, 35.900890486580984, 34.8612836429051, 36.350206170763286, 35.73091670445034, 35.75001035417829, 36.0692001751491, 35.44940001623971, 37.418126923697336, 35.68038593019758, 36.42675447463989, 36.76349891935076, 35.10451923097883, 36.27557209559849, 35.793624196733745, 35.22017894472395, 33.41262592588152, 33.83131047657558, 33.85336058480399, 34.65579066957746, 33.97197675704956, 37.28623274394444, 49.45480401175362, 50.4595239503043, 48.88054929460798, 49.780757904052734, 47.965475014277864, 41.955040046146934, 40.47249596459525, 41.853572028023855, 41.40967246464321, 38.989743437085835, 33.16943202699934, 34.032186371939524, 34.33171279089791, 34.7463048526219, 35.60598461968558, 36.05710336140224, 36.12391376495361, 36.63045481273106, 36.37975338527134, 36.78086594172886, 37.084422315870015, 35.6281806400844, 36.223842757088796, 34.22955690111433, 35.98644712993077, 34.71382549830845, 35.046279430389404, 36.93405982426235, 36.75466775894165, 37.08982801437378, 37.431929520198274, 35.37890706743513, 34.73649747031075, 39.22278254372733, 38.09915113449097, 37.10855688367571, 36.47556209564209, 36.2695688520159, 35.170492376599995, 35.119537762233186, 34.606527941567556, 34.13134411403111, 35.87503276552473, 34.49557910646711, 34.363900320870535, 34.47591570445469, 36.07893112727574, 35.88835941042219, 38.13938120433262, 39.03499010631016, 43.28431034088135, 45.153115204402376, 46.175921303885325, 47.91476706096104, 47.97416721071516, 48.34479454585484, 50.13043989453997, 50.55089623587472, 49.91291611535208, 49.01278741019112, 52.82548631940569, 51.502792494637625, 46.706218242645264, 10.069620353834969, 0.10852833105517284, 2.118575666631971, 4.726826063224247, 1.7319838681391306, 0.09045101143419743, 10.002789974212646, 61.32571792602539, 50.5371526990618, 47.90621382849557, 25.47862560408456, 29.227406297411235, 36.832946164267405, 48.89259052276611, 18.031707899911062, 0.4523754428539957, 0.03726281924173236, 0.010454638561766063, 0.0741115217762334, 0.047011650766112974, 0.06540330512715237, 0.02124870239224817, 0.043396053170519214, 0.03555010525243623, 0.0529155703926725, 0.08620726343776498, 0.10303361554230962, 0.13649854197033814, 0.16691981814801693, 0.19106733240187168, 0.11667535853173051, 0.09496471458779913, 0.17069608265800135, 0.09950935893825122, 0.09977690529610429, 0.09974792506545782, 0.1708716739501272, 0.17589420372886316, 0.08319348908428635, 0.18300096238298075, 0.6189404821821621, 32.288601943424766, 62.479341234479634, 48.37475865227835, 38.27678183146885, 45.661195278167725, 44.827251638684956, 55.64182397297451, 54.198102951049805, 58.7128061567034, 20.780608075005667, 0.24734533897468022, 0.7310661141361509, 8.437346935272217, 11.15241893700191, 2.1359596252441406, 0.8994494644658906, 17.342788798468455, 51.416131087711875, 52.55866854531424, 50.21538509641375, 45.36834607805525, 41.22905056817191, 38.988850593566895, 39.45288603646414, 39.09787130355835, 39.32767949785505, 38.32560682296753, 38.51233966009957, 39.93294402531215, 36.15572261810303, 38.52925157546997, 42.39830732345581, 47.03572266442435, 47.48435742514474, 48.31655706678118, 52.89846672330584, 48.80642243794033, 46.339047636304585, 46.959084033966064, 47.00721767970494, 48.11239467348371, 48.98310123171125, 46.62142242704119, 47.05777277265276, 48.424539021083284, 49.83884137017386, 45.30675377164568, 38.74207837241036, 37.76795482635498, 36.7601637840271, 34.63356685638428, 38.648090090070454, 37.1592161996024, 38.59856333051409, 37.02700240271432, 38.27923107147217, 38.39420638765608, 36.98245055334908, 39.28212710789272, 37.45885031563895, 38.66975804737636, 38.865815367017476, 36.58208492824009, 39.24381126676287, 38.54512473515102, 36.81102459771292, 34.952586446489605, 36.92896679469517, 35.54420818601336, 35.57724339621407, 35.87884732655117, 39.72399084908621, 50.88291243144444, 51.97765670503889, 50.58758272443499, 52.142012868608745, 50.066440037318635, 46.30427885055542, 42.61227362496512, 43.67897149494716, 42.91108437946865, 40.27076196670532, 34.877657072884695, 37.05953734261649, 35.427224840436665, 36.06431559153965, 37.91063608442034, 37.912501675742014, 36.609836033412385, 37.3344532421657, 38.44203431265694, 38.063003131321494, 38.61645841598511, 38.050510270254954, 37.36898231506348, 36.0531359400068, 36.944697516305105, 36.73358345031738, 35.97115414483206, 39.560551847730366, 37.38724912915911, 38.62698493685041, 37.23848124912807, 36.54318196432931, 36.12026596069336, 42.855582169124055, 40.26045431409563, 41.012037481580464, 38.069746358054026, 38.60904816218785, 35.560303688049316, 36.47947045734951, 37.37712560381208, 34.90892744064331, 37.60498135430472, 37.30156741823469, 35.95429086685181, 36.88155228751046, 36.4458863394601, 37.74531759534563, 39.99315364020211, 40.71046134403774, 44.68413264410836, 47.801810196467805, 48.21433169501168, 49.58252232415335, 49.93207924706595, 51.720080035073416, 52.04678085872105, 53.13253763743809, 51.71657119478498, 50.933349405016216, 53.24819735118321, 52.796470642089844, 46.85847064426967, 13.293946674891881, 0.1966966489063842, 4.141094659055982, 8.6506244965962, 3.5858408766133443, 0.10257368415061917, 10.388182231358119, 66.17676258087158, 54.84605026245117, 52.62256417955671, 34.06838648659842, 36.49335643223354, 42.64845984322684, 58.179528440747944, 22.361906903130667, 0.390450084315879, 0.12781143454568727, 0.06950922230524675, 0.2088843999164445, 0.13661416433751583, 0.18137893799160207, 0.10619210105921541, 0.19876578716295107, 0.11132961538221155, 0.20143407184098447, 0.1678724406020982], [0.03747893264517188, 0.04359205818868109, 0.014365319162607193, 0.009103524365595408, 0.021479487419128418, 0.006068476242944598, 0.017811023463894213, 0.06224025985492127, 0.03666812400998814, 0.0408085446937808, 0.02942288653658969, 0.011331553471141627, 0.03403374233416148, 0.06392888924373047, 0.06108886735247714, 11.837350640978132, 42.720113141196116, 38.48126036780221, 29.203243936811173, 28.38230906214033, 30.25129631587437, 45.13998310906546, 50.24098573412214, 51.03569637026106, 24.532710007258824, 0.006894737665009285, 0.17311876480068478, 1.7371875260557448, 6.47455335514886, 3.340956828423909, 0.15418830274471215, 7.698983584131513, 45.67572743552071, 49.13858454568045, 46.16721868515015, 42.18123517717634, 36.7134302003043, 34.69243546894619, 35.09449992861067, 33.116775103977744, 33.34865733555385, 33.36964784349714, 34.43470246451241, 34.76350859233311, 37.596230098179404, 41.20242159707205, 43.29648011071341, 43.7937661579677, 44.398068359919954, 46.18891790934971, 45.755805424281526, 43.18783460344587, 44.730727263859336, 44.95415006365095, 45.09493793760027, 44.42781012398856, 45.04882969175066, 45.56146083559309, 44.70847218377249, 42.61097431182861, 44.28314862932478, 39.89127915246146, 31.72431789125715, 33.176331588200156, 34.52432380403791, 32.90687002454485, 33.46976791109358, 34.17328691482544, 35.575343063899446, 36.64766550064087, 33.89752680914742, 34.8452194077628, 34.74736097880772, 35.36090428488595, 34.591829027448384, 34.390140192849294, 35.17877115522112, 35.25795630046299, 33.655514104025706, 32.446840218135286, 32.182930265154155, 33.307232175554546, 31.929140363420757, 33.03476551600865, 31.911696910858154, 31.92136880329677, 35.76632125037057, 44.95913192204067, 48.444622789110454, 47.08420372009277, 48.0506078175136, 47.71629524230957, 41.306887762887136, 39.469325474330354, 39.8664219720023, 38.71728719983782, 35.38055031640189, 32.528158460344585, 33.01680442265102, 32.81503220966884, 32.992864404405864, 34.72161790302822, 32.740797655923025, 35.37997709001814, 34.6061110496521, 35.90581675938198, 35.41399894441877, 34.49826805932181, 33.31814432144165, 34.23683513913836, 34.85497120448521, 33.95370299475533, 33.864891120365684, 34.035959243774414, 34.78267867224557, 33.85304791586739, 34.983262743268696, 33.33197818483625, 35.83473321369716, 40.394915853227886, 44.072684219905305, 42.633312770298545, 43.07780987875802, 41.608182498386924, 38.613446371895925, 34.891060147966655, 34.71137625830514, 34.65335185187203, 33.373868874141145, 32.83799253191267, 32.533199378422324, 34.03011580875942, 33.563287190028596, 32.573401655469624, 29.867165156773158, 32.54287821905953, 33.003311020987375, 34.8197021484375, 36.96085555212838, 38.188091550554546, 41.26454891477312, 43.504741941179546, 43.93821920667376, 44.88188879830496, 45.85024186543056, 48.035227979932515, 47.9368553842817, 50.92738785062517, 45.30734436852591, 31.511390345437185, 3.451661390917642, 0.03313860197418502, 1.4216067514249255, 1.3090096733399799, 0.8677088990807533, 0.22878539775099072, 11.91883737700326, 53.84890038626534, 44.67819888251168, 36.706443786621094, 30.082128524780273, 24.196024622235978, 36.47464493342808, 45.09636926651001, 6.4672777226993015, 0.13576797688645975, 0.05744674243032932, 0.09130665087806326, 0.03960301188219871, 0.023388640688998357, 0.057208563068083355, 0.043913656646119695, 0.0827434439478176, 0.020837325270154645, 0.0609339103102684, 0.0642090088554791, 0.044386344496160746, 0.016918778752109835, 0.029290785946484123, 0.02567553610008742, 0.0016367838002874383, 0.028069845300966074, 0.01915013267924743, 0.030031746186848198, 0.04029657984418528, 0.03722693830994623, 0.03742050399471607, 0.03423946397379041, 0.05099054958139147, 0.06246282612638814, 0.030215164380414144, 17.22557095118931, 51.406605107443674, 43.38031012671334, 34.65937941414969, 32.97619915008545, 35.091908250536235, 49.79327508381435, 52.28366926738194, 56.183102539607454, 24.72854151044573, 0.08981800611530032, 0.18263448561940873, 2.95906320640019, 7.741617730685642, 3.705232424395425, 0.3897398481411593, 8.12347161769867, 48.388679368155344, 50.59896387372698, 48.433964252471924, 42.153112343379426, 38.890210492270334, 36.382695947374614, 36.54222311292376, 34.31909486225673, 35.81588275091988, 33.99144213540213, 35.58366353171212, 36.936182498931885, 38.9675543648856, 43.146857602255686, 44.108272893088206, 44.85929673058646, 45.863071714128765, 46.507986136845176, 48.03171566554478, 44.46273871830532, 45.05488852092198, 46.11345699855259, 46.75402184895107, 46.00781658717564, 45.669849259512766, 48.26233679907662, 45.73056609289986, 44.918394633701865, 46.517341886247905, 40.255312647138325, 34.088852405548096, 34.60766397203718, 34.87326233727591, 35.87918084008353, 35.17782967431204, 35.67709248406546, 36.30292367935181, 36.974143981933594, 35.80079126358032, 35.62113516671317, 35.05570813587734, 37.180984905787874, 36.416912351335796, 37.756424290793284, 36.519127300807405, 36.71818276814052, 35.44986554554531, 34.41847494670323, 34.04499190194266, 34.09179496765137, 34.41055400030953, 33.804104804992676, 33.777503626687185, 35.246602943965364, 38.77045828955514, 46.82099553516933, 48.9141195161002, 47.672358308519634, 49.34811094829014, 47.047941071646555, 43.32036106927054, 41.94659103666033, 42.09595646177019, 39.9109217098781, 36.53504214968, 34.37026139668056, 34.3170416695731, 36.54405048915318, 33.668924127306255, 36.622655459812705, 34.624586309705464, 37.32499326978411, 36.40191466467721, 36.786400181906565, 36.84483800615583, 35.42754445757185, 34.137034688677105, 35.907296725681846, 36.0077155658177, 36.764985833849224, 35.18768916811262, 35.70562526157924, 35.94852386202131, 35.756656306130544, 36.16585309164864, 34.47655841282436, 35.9373059953962, 42.78480781827654, 43.81342608588082, 44.96094192777361, 45.27714054925101, 42.41832855769566, 38.833718163626536, 36.720927306583945, 36.48851701191494, 35.75867823192051, 34.716434546879356, 34.11594343185425, 34.487769331250874, 36.06640699931553, 35.466068744659424, 34.774695192064556, 33.13689013889858, 34.44513518469674, 34.55114037649972, 37.803612981523784, 38.932201930454795, 41.48028700692313, 45.56730427060808, 46.32076692581177, 45.750695024217876, 48.41391869953701, 47.19067791530064, 50.93184164592198, 50.52320071629116, 52.24528741836548, 47.38579722813198, 35.262007100241526, 4.64145919254848, 0.2441866770386696, 3.612391463347844, 4.7930337105478555, 1.770890848977225, 0.20932782255113125, 11.909525053841726, 59.4856264931815, 47.76954623631069, 42.750726904187886, 29.81417124611991, 26.932841879980906, 39.5964948790414, 52.52476828438895, 8.716040049280439, 0.06482231630278484, 0.021825782854908278, 0.09844610134937934, 0.03963747128312077, 0.02458358326527689, 0.06798869318195752, 0.021369669919035265, 0.05419311612578375, 0.03800100088119507, 0.012387831479177942, 0.04196951811068824, 0.23113535451037542, 0.1403081632618393, 0.14151355358106749, 0.12322360144129821, 0.09177807665296964, 0.08294031409812824, 0.06071140510695321, 0.10523477635745491, 0.21372296528092452, 0.09251909796148539, 0.1421034854969808, 0.12566187631871018, 0.09337633196264505, 0.12167855006243501, 0.18071326799690723, 20.165654284613474, 59.266237122671946, 50.34520871298653, 39.26064675194876, 38.6757230758667, 41.889021737234934, 52.746221269880024, 56.97668409347534, 60.367769786289756, 29.468873568943568, 0.17143169604241848, 0.5846157297492027, 7.405365739549909, 13.135024871144976, 6.720849624701908, 0.34890865055578096, 10.971002340316772, 49.720930440085276, 52.32026195526123, 52.094935349055696, 46.41911172866821, 40.80832324709211, 37.8920704977853, 38.02420439038958, 36.34859071459089, 36.9932723726545, 36.16702733721052, 37.81395190102713, 40.48296342577253, 40.4318733215332, 45.59699739728655, 46.7426997593471, 48.61154978615897, 48.59542996542794, 49.737144061497276, 47.28405475616455, 45.74802344185965, 47.037626470838276, 48.24575144904, 49.310142517089844, 48.77553769520351, 46.98038373674665, 50.127983706338064, 47.88919769014631, 46.39902448654175, 48.71237857001168, 43.07248408453805, 36.26612254551479, 36.57637698309762, 37.554075377328054, 36.09098972593035, 36.759781633104595, 36.20898403440203, 38.593234062194824, 38.85352052961077, 37.07596288408552, 37.99972588675362, 36.13765035356794, 38.51332630429949, 37.807601247514995, 38.70328310557774, 39.35494422912598, 38.85767207826887, 38.31569521767752, 36.38307809829712, 36.26060567583357, 37.25596639088222, 36.211648668561665, 36.68939290727888, 36.51169272831508, 36.47776467459542, 40.07357209069388, 49.84390313284737, 51.72463110515049, 49.566610949380056, 49.936783177512034, 51.621137687138145, 43.84148985998971, 43.990952559879844, 45.12640632901873, 42.93075472967965, 38.289510931287495, 36.48530694416591, 37.10750423158918, 38.63108784811837, 36.157383237566265, 38.678248746054514, 35.036256653921946, 39.34813152040754, 37.283203329358784, 38.78817967006138, 38.86680895941598, 36.89468090874808, 36.271212100982666, 38.47872427531651, 38.60970824105399, 37.697031089237754, 37.55210903712681, 37.52355541501726, 37.035715443747385, 35.30970300946917, 37.93677520751953, 37.30400971003941, 39.21816546576363, 45.88793584278652, 47.96487052100045, 47.036921228681294, 46.770600250789094, 45.29552895682198, 40.44767699922834, 39.78955405099051, 38.01768698011126, 38.44951752253941, 35.769819668361116, 36.84703711100987, 35.910642283303396, 37.72551870346069, 37.94676671709333, 36.88071155548096, 32.85860783713204, 35.36241551807949, 36.723560673849924, 40.38909673690796, 40.395593302590505, 41.98367704663958, 46.72984559195382, 47.12616736548287, 47.82682023729597, 50.14044182641165, 49.70210429600307, 54.69326284953526, 52.06659712110247, 52.850246225084575, 46.87103646142142, 37.10124390465872, 5.420935903276716, 0.4518303892442158, 6.104571333953312, 8.58837558541979, 4.1387205464499335, 0.22878805760826382, 14.835357631955828, 64.63128171648297, 51.470267977033345, 47.98761197498867, 39.70437261036464, 34.200982434409006, 48.31187745503017, 61.10719013214111, 11.326585956982203, 0.20089778490364552, 0.1504572829497712, 0.2345626348895686, 0.10635332776499645, 0.1507770765040602, 0.18235590628215245, 0.09831785144550459, 0.252742162240403, 0.11518629986260619, 0.13489675149321556, 0.2362101450562477], [0.08997104968875647, 0.03613807280947055, 0.1014975615377937, 0.019210778442876678, 0.03470764635130763, 0.031183898648513213, 0.02244820981286466, 0.02810843019480152, 0.013365772619311298, 0.06908804204847131, 0.03386388127026813, 0.024210380523332527, 0.039234048287783346, 0.08341254054435662, 0.022691607109404037, 6.627908783299582, 39.041236536843435, 39.64412478038243, 34.41988543101719, 32.52379151753017, 31.387472697666713, 40.38386474336897, 43.5990811075483, 48.728418486458914, 33.43767070770264, 0.7917394127164568, 0.14399410119014128, 1.3009744073663438, 4.277437857219151, 3.9654667803219388, 0.20271442670907291, 7.32065851347787, 47.3863912991115, 49.84006077902657, 45.86941194534302, 44.644538334437776, 36.64013365336827, 34.33722966057913, 35.9841160093035, 31.918436663491384, 34.08289085115705, 35.334250995091026, 39.51336663109915, 41.57646744591849, 41.68396650041853, 42.4155284336635, 45.30876874923706, 47.55105318341936, 46.87092181614467, 46.1455785206386, 41.923880849565776, 43.85628604888916, 45.48074013846261, 41.69669212613787, 41.318154266902376, 40.06814554759434, 42.11597074781145, 42.070935998644146, 43.43433237075806, 43.199618748256135, 44.40434258324759, 37.35550280979702, 33.169814177921836, 33.69226312637329, 31.880659307752335, 34.63222932815552, 33.944993427821565, 33.70396736689976, 34.713870661599294, 33.67468070983887, 36.2522018296378, 34.28988116128104, 35.608204569135395, 33.436941146850586, 34.75536182948521, 36.91661637169974, 36.66605043411255, 36.64293377740042, 34.42016683306013, 32.18650163922991, 31.068064008440288, 31.84208290917533, 32.703006403786794, 31.839626720973424, 32.16272142955235, 33.796409675053184, 37.24808365958077, 45.23330783843994, 48.33296871185303, 46.21087074279785, 48.43946375165667, 46.21417808532715, 44.138501031058176, 42.17978647777012, 41.07353251320975, 41.16359853744507, 36.55303103583199, 33.37702335630144, 32.84968287604195, 33.238424164908274, 32.64048651286534, 34.03916931152344, 34.140088421957834, 34.936157430921284, 35.79815789631435, 34.09860072817121, 35.66374152047293, 33.44358015060425, 34.72962917600359, 34.412152085985454, 34.71899495806013, 35.36936371667044, 33.105956758771626, 33.33196776253836, 33.55898625510079, 32.71168122972761, 33.0145914213998, 34.09250020980835, 40.20456647872925, 47.44663912909371, 46.31452396937779, 45.16353055409023, 42.506598472595215, 45.07520505360195, 42.33497101919991, 42.328422342027935, 40.38547672544207, 37.950292927878245, 36.728945527757915, 35.29457678113665, 33.92020572934832, 33.31693533488682, 32.73929337092808, 33.46586649758475, 33.40229048047747, 32.56375755582537, 33.73896891730172, 33.38534729821341, 33.43779577527727, 34.06941481998989, 35.60341726030622, 36.91878073556082, 37.78206314359392, 40.59014286313738, 45.168380396706716, 45.32411731992449, 48.50483587809971, 48.424274989536826, 48.10712793895176, 18.169282232012065, 1.171606332063675, 0.07609169052115508, 1.3309754260948725, 3.9013679112706865, 1.0233522930315562, 0.12494158425501414, 15.661620037896292, 55.59642791748047, 43.03905282701765, 35.46765988213675, 20.14040800503322, 30.75402627672468, 42.214134897504536, 39.691827637808665, 2.780337299619402, 0.08143944213432924, 0.03389394037159426, 0.03404659039473959, 0.027511577221697996, 0.018842780064525347, 0.04475508078134485, 0.03391283078651343, 0.03058351729331272, 0.02671399323402771, 0.030195239199591533, 0.10684638523629733, 0.05351928335481456, 0.02697766346058675, 0.05905860915247883, 0.022189536996717964, 0.03757916583812662, 0.03492792595976165, 0.011064069029609007, 0.025704490885670696, 0.02304759032891265, 0.04804673218833549, 0.07294613788170473, 0.04115461790934205, 0.01760615168937615, 0.030784448475709984, 0.008609413468678082, 9.648027982030596, 46.627995422908235, 46.969099862234934, 39.025731631687705, 34.91452421460833, 40.802410330091206, 45.173608916146414, 51.19000891276768, 52.10708774839129, 34.48030349186489, 0.6154240965843201, 0.07781203463673592, 1.774318590760231, 6.176042675971985, 3.1578726640769412, 0.4829657556755202, 7.519587176186698, 48.86450590406145, 50.42558200018746, 47.47377184459141, 47.12120982578823, 40.34842198235648, 35.5035160609654, 37.40941040856497, 33.21387617928641, 35.06551551818848, 35.509133679526194, 40.28808382579258, 41.29782731192452, 43.42208269664219, 44.008448123931885, 46.644546031951904, 49.20748288290841, 47.94593320574079, 45.99128334862845, 42.998763697487966, 46.08902713230678, 47.74208695547921, 42.57035861696516, 43.93696853092739, 42.613684109279085, 43.383589676448274, 44.15511417388916, 46.42302009037563, 43.97972427095686, 47.098312037331716, 39.743459701538086, 34.470763615199495, 35.176700592041016, 33.89959389822823, 34.808498178209575, 35.7359367779323, 34.5658358165196, 35.59763983317784, 33.83009454182216, 36.25229563031878, 36.437611034938264, 36.94273117610386, 35.57924100330898, 35.92579630443028, 38.337470872061594, 37.55067423411778, 37.71627065113613, 35.80063145501273, 35.58623783929007, 32.393082005637034, 33.9116907119751, 34.55213744299752, 34.305323532649446, 33.35264212744576, 34.85525608062744, 38.70406477791922, 46.25183384759085, 49.350754737854004, 48.00647980826241, 49.669246264866416, 47.19047294344221, 45.356252738407676, 42.699119159153526, 43.452595710754395, 42.113837650844026, 38.38061571121216, 35.00863061632429, 34.73257173810686, 34.95142262322562, 34.889733042035786, 36.06301975250244, 35.9228572164263, 36.21536595480782, 36.928713185446604, 35.79196357727051, 36.28526135853359, 37.067263739449636, 36.31534358433315, 36.32096120289394, 36.11280359540667, 37.1326184953962, 34.67765317644392, 34.49896287918091, 35.43666744232178, 34.27798931939261, 33.1944385937282, 34.48307582310268, 41.174462045942036, 47.83121149880545, 46.33573334557669, 48.85730757032122, 45.38808938435146, 46.31045232500349, 45.085550921303884, 43.58289180483137, 41.830900056021555, 37.74707896368844, 37.6663304737636, 36.747921058109824, 36.081640924726216, 35.083018030439106, 34.83317123140608, 36.201417446136475, 33.67157139096941, 35.759126390729634, 34.82092503138951, 34.95114469528198, 35.19852488381522, 35.78761747905186, 37.37716381890433, 39.65424483163016, 41.29966163635254, 44.31397431237357, 46.570182936532156, 48.363304546901155, 49.97156933375767, 51.848465374537874, 49.392294543130056, 20.691108328955515, 1.5291164453540529, 0.6919277799980981, 5.540416257722037, 4.124222695827484, 1.9672478096825736, 0.09172087615089757, 17.113991567066737, 62.33354718344552, 46.44304479871477, 42.554089409964426, 28.925680773598806, 33.86891760144915, 45.03207063674927, 45.180546692439485, 4.110486541475568, 0.12873893763337815, 0.07135774847120047, 0.010352214548869856, 0.027648670133203268, 0.042537679230528216, 0.04791200906038284, 0.02505984020951603, 0.065679713152349, 0.017578255418421965, 0.06891878148806946, 0.0871228582358786, 0.15713148910020078, 0.1346306572003024, 0.15000366871910437, 0.1735561349030052, 0.08567620122006961, 0.11790745598929268, 0.10813267050044877, 0.11282222278948341, 0.0718164381438068, 0.1444989312440157, 0.2005298017923321, 0.1445245798677206, 0.10290181011493717, 0.17463610480938638, 0.09424856837306704, 11.473031401634216, 55.870923451014924, 52.904046126774375, 45.11198534284319, 40.83328465053013, 41.76711559295654, 49.69671596799578, 53.73943846566336, 56.86491189684187, 40.00758157457624, 1.2305645112480437, 0.36907207859413965, 6.6669350777353555, 10.623979772840228, 8.105679886681692, 1.6205704808235168, 9.669231278555733, 51.176154204777305, 53.51708221435547, 48.935391426086426, 48.622722489493235, 41.31683758326939, 36.91286434446062, 40.673378808157786, 34.517910616738455, 37.69312620162964, 37.226280212402344, 43.801357064928325, 44.056682518550325, 45.23079606464931, 45.967510087149485, 49.171519007001606, 50.51310845783779, 49.60906791687012, 47.160293442862375, 45.888335364205496, 48.08987208775112, 50.140427930014475, 43.85864496231079, 43.640916211264475, 45.65870782307216, 46.30523075376238, 46.80420173917498, 47.567999839782715, 46.43812200001308, 49.662360600062776, 41.14486966814314, 36.448742049080984, 37.74619654246739, 34.75195026397705, 35.97341578347342, 36.60618475505284, 37.09924977166312, 37.558904375348774, 37.15240696498326, 38.10387590953282, 38.52704899651663, 38.17442096982683, 36.70664528438023, 38.101430143628804, 40.228343214307515, 39.129930291857036, 38.4918007850647, 37.504169940948486, 35.96550178527832, 35.00550740105765, 35.43512841633388, 36.91412196840559, 36.03205163138253, 35.5062814440046, 37.640316418239046, 41.04038265773228, 47.620194707598, 50.34501416342599, 48.93137884140015, 51.75753429957798, 49.01696675164359, 50.17576994214739, 45.56985773359026, 45.213237966809956, 44.6976329939706, 40.783601556505474, 37.91256420952933, 37.309262548174175, 37.375378131866455, 37.23950263432094, 39.261199133736746, 38.06172118868147, 38.130678585597444, 38.96479940414429, 38.17125953946795, 38.73606123243059, 38.24678645815168, 38.147340365818565, 38.127173219408306, 38.16942868913923, 38.334410190582275, 37.29908343723842, 36.97611379623413, 36.79015915734427, 35.81374270575387, 34.5280202456883, 36.64263847896031, 44.06829295839582, 50.683433123997276, 48.99802943638393, 49.300196170806885, 45.90514653069632, 49.29028456551688, 46.62231527056013, 47.831051690237864, 44.836649077279226, 41.21297591073172, 39.34459488732474, 37.84135559626988, 37.65855196544102, 36.22625725609915, 36.85189042772566, 37.74069356918335, 36.125654288700645, 36.492672034672324, 37.867876870291575, 37.50330489022391, 37.57181065423148, 38.024697712489534, 39.27148594175066, 41.52072204862322, 42.561291217803955, 44.94092069353376, 50.042010171072825, 49.196271964481895, 53.20130048479353, 54.21351752962385, 52.473025049482075, 23.67670410020011, 2.351848406451089, 0.9275290348700115, 7.82905125617981, 11.888740386281695, 3.859896719455719, 0.1813372623707567, 19.181136233466013, 68.26589134761265, 51.604545388902935, 47.05836336953299, 31.70477955681937, 43.06965964181082, 52.53643430982317, 54.308311803000315, 5.579479030200413, 0.2096050583890506, 0.16856199502944946, 0.08939105831086636, 0.12081358076206275, 0.19599196314811707, 0.12694459248866352, 0.120569769559162, 0.11741982001279082, 0.11865976133516856, 0.21762488090566226, 0.1661780300949301], [0.08001678490212985, 0.0031233776909565286, 0.01674057849283729, 0.012031883034589035, 0.026115927379578352, 0.020292994300169603, 0.05904460418969393, 0.04998695896938443, 0.09180021725062813, 0.02302231320313045, 0.05632925971544214, 0.05564903514459729, 0.0470919621709202, 0.03723454808018037, 0.03648855650265302, 3.77204977614539, 34.36393158776419, 37.35261583328247, 50.98433876037598, 24.570035730089458, 25.238758155277797, 38.41307769502912, 44.83663518088204, 47.60524565832955, 43.42848546164376, 5.106131264141627, 0.3413563115256173, 1.1763357754264558, 5.071129279477256, 1.3806857700858797, 0.6149692067078182, 16.31294764791216, 47.04856988361904, 49.54323720932007, 45.224956103733604, 43.86943204062325, 37.82398509979248, 35.21734060559954, 35.65104021344866, 34.08086197716849, 38.852110045296804, 42.53601367133004, 43.356175558907644, 42.35207053593227, 45.93024342400687, 47.97722789219448, 48.10719742093767, 45.23796313149588, 45.71717344011579, 44.95573425292969, 44.91097048350743, 44.45304945537022, 41.889647075108115, 41.59929575238909, 38.640457493918284, 38.687510694776265, 38.83679968970162, 41.003487723214285, 42.79879106794085, 40.73737519127982, 36.767858913966585, 31.336677891867502, 31.62610857827323, 33.107884883880615, 34.643367290496826, 34.47487694876534, 35.13998631068638, 33.42264870234898, 35.16918611526489, 34.755598068237305, 33.975099972316194, 34.6188644681658, 33.67285680770874, 34.81070075716291, 34.55685179574149, 34.85813610894339, 35.3224390574864, 36.62197801045009, 35.5279598236084, 33.43945639474051, 33.3542297908238, 33.4246324130467, 34.11700998033796, 33.46821846280779, 32.84199816840035, 32.84807436806815, 38.05295603615897, 45.256667682102744, 47.34852361679077, 47.81137439182827, 45.63499014718192, 47.09274653026036, 45.9985476902553, 42.91559376035418, 42.26403338568551, 42.5942256791251, 37.889520508902415, 31.700534207480295, 31.780070236751012, 32.18071378980364, 33.91101673671177, 33.18298101425171, 34.58376564298357, 34.028986726488384, 34.85317162105015, 32.64115701402937, 33.86177485329764, 35.27171720777239, 34.84985385622297, 35.93433911459786, 34.706290176936555, 33.74946764537266, 33.225552627018516, 34.86903783253261, 34.18072843551636, 35.41140726634434, 33.06782157080514, 34.66277708326067, 42.378828048706055, 44.549775327954976, 44.130524499075754, 45.20940950938633, 47.245624269757954, 44.939447675432476, 45.60461957114083, 44.96711540222168, 41.95464052472796, 42.19242525100708, 40.418136732918875, 41.47613893236433, 40.48763608932495, 39.17954042979649, 35.26427568708147, 35.15229157039097, 33.137004784175325, 32.96555798394339, 31.714837074279785, 33.06843301228115, 32.35353980745588, 33.40037625176566, 32.833444935934885, 34.56901114327567, 34.647310393197195, 36.128947734832764, 38.70964765548706, 44.3295521736145, 44.23814862115042, 50.01597874505179, 45.11509813581194, 14.449537192072187, 0.026027707649128776, 1.0373658324990953, 2.792863598891667, 2.424058428832463, 1.8318295904568263, 0.05665910237335733, 21.027373347963604, 54.105928148542134, 40.88007034574236, 33.2138866015843, 23.7763569014413, 28.405476093292236, 41.896713393075125, 27.69068190029689, 1.9284091166087558, 0.15281505643257073, 0.09155852307698556, 0.05707078653254679, 0.034467146399297884, 0.0727468521467277, 0.05996606831571885, 0.09014171481664691, 0.02727560479460018, 0.02066196976894779, 0.031210877200854675, 0.07853083392339093, 0.04681999855009573, 0.020798996523288742, 0.043030302439417155, 0.0339232361210244, 0.035876317748001645, 0.01862448008198823, 0.046649811789393425, 0.08469491066145045, 0.0044767225710009885, 0.080047536109175, 0.0860584539228252, 0.05359603923612407, 0.10475626667695385, 0.06122067956519978, 0.031794359641415734, 5.6407287035669595, 42.77790478297642, 43.798546518598286, 52.55132777350289, 30.171805449894496, 30.741234643118723, 41.365679945264546, 48.86087894439697, 51.83694526127407, 47.28461061205183, 4.565851501056126, 0.2072255853563547, 0.8376100627439362, 4.8763981972421915, 3.352980903216771, 0.9501246852534158, 18.766523327146256, 48.43388087408883, 51.9111659186227, 47.918939454214915, 45.66793155670166, 38.39153480529785, 36.830621991838726, 37.28825119563511, 35.39909505844116, 39.74063525881086, 43.02159547805786, 45.39161212103707, 45.0702475139073, 46.341284956250874, 48.60257966177804, 50.36821072442191, 45.855268887111116, 45.16081380844116, 45.75747994014195, 46.320343085697715, 46.204527037484304, 44.733273778642925, 44.20225075313023, 41.463486262730186, 39.34114858082363, 40.82980360303606, 42.67038835797991, 45.08655841009957, 44.68484830856323, 39.36862175805228, 33.94665404728481, 33.130417891911094, 35.050180843898225, 35.22765173230852, 35.508053234645296, 35.78322621754238, 35.80301816122872, 37.20810719898769, 35.430396693093435, 35.7234126499721, 35.97468382971627, 35.81677906853812, 36.27035747255598, 34.87889732633318, 36.54150397436959, 37.44714607511248, 37.52297871453421, 36.05420248849051, 36.407890115465435, 36.01184974397932, 34.39087322780064, 37.142151423863, 35.52761241367885, 35.37928227015904, 34.41927746364048, 38.75628049033028, 47.35819550922939, 48.4438967023577, 49.08361039842878, 47.46570151192801, 49.27138199125017, 46.501496519361226, 45.278759479522705, 43.620009081704275, 42.68568134307861, 40.08238935470581, 34.24857064655849, 33.19226033346993, 35.011420318058555, 36.17163051877703, 35.57101433617728, 36.05919129507882, 35.600391319819856, 35.57916457312447, 34.88823570523943, 36.29664945602417, 35.63359328678676, 36.00122594833374, 36.28781829561506, 37.02232279096331, 35.658384459359304, 35.0771780695234, 36.85953344617571, 35.98636375154768, 34.39882544108799, 35.10731588091169, 35.89717320033482, 44.36566890989031, 47.90747840063912, 45.56163106645857, 46.82437930788313, 46.775634220668245, 47.617384161267964, 47.329996245247976, 46.744937079293386, 43.519208090645925, 43.19373709814889, 42.284217902592246, 42.7730028288705, 42.17023270470755, 40.06840263094221, 37.63540056773594, 37.1438433102199, 34.96470063073294, 33.564263411930625, 33.06384025301252, 34.82640716007778, 33.63269621985299, 35.10716996874128, 34.83812182290213, 35.47298567635672, 35.67170763015747, 37.709270341055735, 41.00283111844744, 46.869858741760254, 48.82682234900338, 50.760071754455566, 46.517470427921836, 15.452706813812256, 0.44117698233042446, 2.410836224045072, 6.95412540435791, 5.063186185700553, 1.3542265955890929, 0.09536078226353441, 22.398463112967356, 59.078302247183665, 45.4716032573155, 39.70692607334682, 21.528711932046072, 31.901778357369558, 47.695092814309255, 33.98860032217843, 2.4737695327826907, 0.04429863705965025, 0.01070364734290966, 0.1012579436813082, 0.027124903863295913, 0.06036590186080762, 0.051850952341088226, 0.08711752495063202, 0.03086124506912061, 0.02593781702619578, 0.04287904341306005, 0.05729386170527764, 0.16344270615705422, 0.10856177604624204, 0.23671521938272885, 0.14782368498189108, 0.19887758259262356, 0.10711203169609819, 0.21658687160483428, 0.14704140195889132, 0.16368339609886917, 0.19524799021227018, 0.12426402632679258, 0.139584587088653, 0.1932588376637016, 0.2006147408059665, 0.1293776019343308, 7.110483757087162, 51.40528494971139, 49.41206564222063, 59.30812781197684, 32.73861592156546, 35.1169947215489, 47.87588841574532, 53.63688652856009, 55.64570801598685, 51.4775253704616, 6.931874232632773, 0.6371894915189061, 3.7434388313974654, 18.904780319758824, 7.914558393614633, 1.4906530635697501, 22.858201095036097, 49.83328628540039, 52.3300450188773, 49.373402391161235, 47.51457861491612, 40.0413532938276, 37.86889478138515, 39.36380318232945, 37.45790188653128, 43.93269191469465, 45.86552790233067, 47.328992230551584, 46.770249366760254, 48.6916104044233, 50.79051876068115, 49.89357580457415, 46.122934341430664, 47.419252804347444, 46.61979307447161, 49.36944886616298, 47.26957471030099, 46.46075228282383, 46.01600156511579, 42.66723387581961, 41.5944493838719, 42.25774526596069, 44.54770476477486, 46.87821742466518, 46.84288930892944, 40.886601652417866, 35.02911043167114, 35.11494847706386, 38.305279867989675, 36.69658776691982, 37.336464745657786, 37.78808028357369, 36.04777887889317, 39.14306933539254, 37.82610777446202, 36.78276974814278, 39.023890359061106, 37.19622925349644, 38.15759938103812, 36.71428830283028, 38.14875085013253, 38.90812989643642, 39.225568771362305, 37.64952278137207, 37.89558628627232, 37.454594544001985, 37.26813268661499, 39.271524156842915, 37.75376313073294, 37.926995618002756, 37.94134364809309, 41.381028515951975, 48.43936995097569, 50.16743210383824, 50.09783547265189, 47.40106936863491, 51.781203338078086, 50.18611233575003, 47.619423457554404, 44.944523334503174, 45.06314298084804, 42.08403335298811, 35.601471764700754, 34.901461601257324, 36.70717682157244, 38.08329881940569, 37.20112773350307, 38.443743569510325, 37.531288760049, 37.988692147391184, 36.59548800332205, 37.99994475500924, 37.66791466304234, 37.145743642534526, 37.72096068518502, 38.65093537739345, 37.40303543635777, 37.79607766015189, 39.82408659798758, 37.51802117483956, 36.13955068588257, 36.54548529216221, 37.19563865661621, 46.30957337788173, 48.4970052582877, 47.7932847567967, 48.71511616025652, 49.09745121002197, 49.25805187225342, 49.60807432447161, 48.401783670697895, 46.14984471457345, 46.2980636869158, 44.30856166567121, 45.98665237426758, 43.294725690569194, 43.62878813062395, 39.244374070848735, 39.941639695848735, 35.99578898293631, 35.63786990301949, 34.21824870790754, 36.483215536390034, 35.51647097723824, 36.58704594203404, 36.73692205974034, 37.85967104775565, 37.74301079341343, 39.460296290261404, 42.355718340192524, 49.81931345803397, 49.7827798298427, 53.01367480414254, 46.91145065852574, 18.95399441037859, 0.5478195899299213, 2.4158046203000203, 9.39176104749952, 9.980878829956055, 5.696878399167742, 0.23411138196076664, 26.682977710451397, 64.11042390550885, 48.567171641758506, 46.92375939232962, 34.25966691970825, 38.503605774470735, 54.89609118870327, 40.06108617782593, 3.412402766091483, 0.2277147780571665, 0.1350066334541355, 0.2280561083129474, 0.10751735458948783, 0.18873336192752632, 0.10234033595770597, 0.15344226706240857, 0.10698981396853924, 0.11710998735257558, 0.08247173817030021, 0.11753960858498301], [0.02096937157745872, 0.066438172810844, 0.08440237385886055, 0.05788340685623033, 0.09021550549992494, 0.08678082230367831, 0.07035618328622409, 0.04078551860792296, 0.05644276844603675, 0.0742907975135105, 0.03309655994442957, 0.03192277239369495, 0.02334675472229719, 0.03585400412391339, 0.024549086544928805, 2.11545592546463, 26.32060830933707, 38.94558763504028, 48.43989453996931, 33.63035467692784, 35.325093269348145, 38.51783915928432, 47.65528311048235, 44.83655875069754, 45.96494620186942, 14.873164517538887, 0.06353903016341583, 0.5889816411903926, 2.8502468168735504, 1.893432536295482, 0.8887568925108228, 22.51410719326564, 48.01411587851388, 49.884636947086875, 45.643831729888916, 44.15612513678414, 38.29213735035488, 36.40884549277169, 35.83153356824602, 36.677282197134836, 41.58336353302002, 45.06938941138131, 44.84040457861764, 47.45002637590681, 45.97782816205706, 42.04741634641375, 39.36039856501988, 42.07333312715803, 42.713217054094585, 43.16062198366438, 43.64941733224051, 43.31671673910958, 39.84748813084194, 38.15657104764666, 34.70997619628906, 34.156406266348704, 34.12632404054914, 34.5873578616551, 35.462417466299875, 33.99140044621059, 31.970086097717285, 34.21130745751517, 32.23684481212071, 33.67344740458897, 33.420887334006174, 34.70674875804356, 33.411993639809744, 35.214575222560335, 32.92774241311209, 34.56011397497994, 34.8152448790414, 34.738105978284565, 33.46545655386788, 33.364530495234895, 33.871262618473594, 33.67528520311628, 34.098951612200054, 34.99778100422451, 34.99969175883702, 34.973990372249055, 33.59206315449306, 35.13825273513794, 34.12537908554077, 33.69363192149571, 33.976798806871685, 36.48104769842965, 37.66497557503836, 46.12347630092076, 49.16417128699166, 48.04906184332711, 47.57101535797119, 48.797751086098806, 43.86046886444092, 44.357424872262136, 44.18092325755528, 42.94717332295009, 38.22113023485456, 34.986757687159944, 32.63531010491507, 31.425392491476877, 32.98480101994106, 33.04198122024536, 34.016521658216206, 33.73074572426932, 34.38135072163173, 34.3522447177342, 33.930690561022075, 34.75002908706665, 34.5692925453186, 34.09235429763794, 33.494291578020366, 34.34787777491978, 34.2678518976484, 34.81790256500244, 33.901122501918245, 34.5824350629534, 33.229943888528005, 34.28695249557495, 44.32264219011579, 44.34952824456351, 43.5703398840768, 42.42236198697771, 41.45116015842983, 44.10901982443673, 48.516140597207205, 45.6218650000436, 44.008576665605815, 43.41572509493147, 44.010216440473286, 42.856106758117676, 42.87590217590332, 42.7134359223502, 44.10511841092791, 42.48757430485317, 42.003423827035085, 37.784123284476145, 35.436177594321116, 32.64019816262381, 33.46852765764509, 33.246706417628694, 33.65795292173113, 34.46288783209664, 36.022702830178396, 35.586918762751985, 39.40124355043684, 43.70242166519165, 47.181419440678184, 48.71602290017264, 47.72882979256766, 12.629803112574987, 0.08854467408465487, 2.3699947127274106, 6.898516365459987, 3.147239314658301, 0.9303455523082188, 0.15473065578511783, 26.7385858808245, 52.75074454716274, 39.08477047511509, 27.619575772966655, 29.724379675728933, 36.70376525606428, 38.099345684051514, 21.9752813407353, 0.2638943466757025, 0.040815774484404495, 0.04451539846403258, 0.006172345111346138, 0.04197682932551418, 0.013323867992897118, 0.006847807214528854, 0.025679534367684807, 0.07814676953213555, 0.040162806665258746, 0.04146050488842385, 0.04991843711052622, 0.009561704288768982, 0.04752868766497288, 0.09443250564592225, 0.0546723280900291, 0.056876067338245254, 0.06715549289115838, 0.03284711350819894, 0.03690120418156896, 0.030618638265877962, 0.08675832886781011, 0.0702297722122499, 0.027498802103634392, 0.03151055558451584, 0.05073114225108709, 0.0872948057949543, 2.867413644279752, 36.42985337121146, 43.11116470609392, 56.28592893055507, 33.07374143600464, 37.696878228868755, 48.09438146863665, 49.841735294886995, 49.75817625863211, 50.84728901726859, 14.694845948900495, 0.1282989890979869, 0.2568589156227452, 3.8515619209834506, 2.118069750922067, 1.329202549798148, 24.775424480438232, 49.747024399893625, 52.00816624505179, 48.37128455298287, 46.52115297317505, 40.2843839100429, 37.808803285871235, 36.9895133972168, 38.79664952414376, 42.553144454956055, 47.44969981057303, 45.191292081560405, 47.884243624550955, 48.90719563620431, 44.84461866106306, 40.5282552582877, 43.26204136439732, 46.05049589702061, 44.859039647238596, 45.68718501499721, 44.805837290627615, 42.778870582580566, 39.93994780949184, 36.51845679964338, 36.73158931732178, 36.32543584278652, 36.64112377166748, 36.643277713230674, 37.82920319693429, 32.98416525976998, 37.133323737553184, 34.726613657815115, 35.243490150996614, 36.43162168775286, 35.456858907427105, 35.566372939518516, 36.25979273659842, 35.3511038507734, 35.78219093595232, 36.80009160723005, 36.5120609828404, 34.4743002482823, 36.62791524614607, 34.37441989353725, 34.79788827896118, 34.38366099766323, 36.50159699576241, 36.719162464141846, 36.6949896812439, 35.18617098672049, 36.44877331597464, 35.4533257484436, 35.67678328922817, 37.26249074935913, 37.87415109361921, 39.03701203210013, 46.708875928606304, 50.081910201481406, 49.120689460209434, 49.4592855998448, 48.84034354346139, 47.07813446862357, 45.16777242933001, 45.1372628893171, 45.28488084248134, 40.44067668914795, 35.96796492167881, 35.118877683367046, 34.44811596189226, 35.17177779333932, 35.930931023189, 36.76506921223232, 36.732186862400596, 35.96022810254778, 36.63665607997349, 36.264100619724815, 35.64392178399222, 36.09567975997925, 36.978371960776194, 34.178668294634136, 36.51851238523211, 36.04765381131853, 36.047629492623464, 35.670311042240684, 35.83301700864519, 34.57670627321516, 36.81848348890032, 45.00477463858468, 47.26225825718471, 44.756185463496614, 43.67812728881836, 43.12245205470494, 45.63155426297869, 49.14287505831037, 48.15812771660941, 46.152356488364084, 46.17336089270455, 45.17472757611956, 44.593934604099815, 45.20313876015799, 46.186135155814036, 44.75094999585833, 45.464113099234446, 41.688395977020264, 39.608956473214285, 34.77802685328892, 34.10922452381679, 33.65617070879255, 36.287151268550325, 34.98063979830061, 35.727741377694265, 37.479858194078716, 35.70908893857683, 40.30915771211897, 46.31254373277937, 49.41264929090227, 51.279341902051655, 47.93554564884731, 15.185048307691302, 0.08749493291335446, 4.524400719574519, 10.804655517850604, 3.988577357360295, 1.6249821526663644, 0.1425513864627906, 28.861420358930314, 57.195045130593435, 44.07774945667812, 37.23697001593453, 35.45836666652134, 39.90247617449079, 44.65932410103934, 25.52212827546256, 0.6578985431364605, 0.05303516558238438, 0.04382664131532822, 0.022579848999157548, 0.006816896975838712, 0.06600251940212079, 0.05804574635944196, 0.02650876353228731, 0.05742140593273299, 0.05725874751806259, 0.038844891491213014, 0.055847174155392816, 0.06932895590684243, 0.16992191491382463, 0.1796754758272852, 0.1934716940990516, 0.17572561491812977, 0.22912827506661415, 0.15649403259158134, 0.1613292052809681, 0.09111550756331001, 0.14837468255843433, 0.1534313562193087, 0.09628508266593729, 0.1336309037038258, 0.2254216011081423, 0.14973866008222103, 3.732554478304727, 41.81051056725638, 50.71498836789812, 57.22290045874459, 42.691934721810476, 47.35637508119856, 49.2586042540414, 55.76958744866507, 52.986649785723, 55.666879177093506, 17.851949317114695, 0.17060842950429234, 2.5328622247491563, 11.219529850142342, 5.453182058674948, 1.7487718015909195, 27.698062624250138, 50.91039603097098, 52.91081714630127, 50.28396381650652, 48.24164506367275, 42.26996714728219, 40.66598245075771, 39.86500106539045, 40.90176262174334, 46.12881599153791, 48.65142897197178, 46.66788503101894, 48.77986642292568, 48.288159779139924, 45.5013484954834, 41.71419811248779, 44.499008314950125, 47.7189633505685, 48.411413873944966, 46.501948152269634, 47.43762036732265, 44.90246588843209, 41.475517068590435, 37.85807991027832, 39.09892742974417, 37.431682859148296, 38.21876089913504, 38.727761609213694, 39.25909382956368, 35.23377309526716, 38.42490005493164, 35.53851066316877, 38.17786380222866, 36.96981178011213, 37.17160831178938, 36.98348930903843, 36.99480445044381, 35.59239394324166, 37.12377691268921, 38.71524790355137, 39.209678241184776, 36.0818042073931, 39.169229303087505, 36.89290911810738, 36.99438755852835, 37.56876734324864, 38.41525248118809, 38.132002217429026, 38.6222288949149, 37.2844227382115, 39.522159576416016, 38.233300004686626, 38.55365712302071, 40.398414271218435, 40.58786037990025, 40.5772157396589, 48.4937812941415, 53.50536060333252, 50.299993310655864, 49.680471079690115, 52.442248003823416, 49.62845686503819, 47.37905747549874, 47.12060533251081, 47.71578107561384, 42.48249169758388, 38.594401359558105, 37.47559200014387, 36.02228593826294, 36.748129504067556, 37.54886770248413, 38.49405894960676, 37.34260695321219, 37.567617416381836, 39.688037395477295, 37.50061593736921, 39.07663760866438, 38.304758753095356, 39.62581975119454, 36.08796378544399, 38.46080139705113, 38.28367444447109, 38.632800579071045, 37.50642810549055, 38.38407244001116, 36.16257701601301, 38.25064965656826, 48.06787061691284, 48.160142694200786, 45.783184800829204, 46.39658914293562, 43.71987206595284, 45.72030707768032, 51.91237490517752, 49.03177683694022, 47.65725987298148, 46.940904072352815, 47.17061151776995, 46.25200407845633, 46.60608427865164, 47.57249185017177, 47.077953815460205, 47.35837268829346, 45.577431270054404, 42.34840188707624, 38.489063194819856, 36.33641052246094, 37.07379504612514, 38.225452014378135, 36.555400371551514, 37.95840147563389, 39.75335046223232, 38.09380449567522, 42.06096880776541, 48.463719912937705, 51.67905439649309, 52.12279762540545, 50.47676937920706, 17.078654766082764, 0.42883299184697016, 4.918799144881112, 17.207913841520035, 9.353445206369672, 3.6850149035453796, 0.26313864865473335, 33.85080712182181, 63.29993043627058, 48.652933256966726, 40.75272028786795, 41.538280146462576, 47.12341935294015, 50.99534470694405, 31.842048168182373, 0.8854919448494911, 0.13686652508165154, 0.11442419647106103, 0.09620651509612799, 0.13987805348421845, 0.15494777342038496, 0.1789835872394698, 0.16860699547188623, 0.1511681026646069, 0.10621270138238158, 0.11231056667332139, 0.13188978284597397], [0.044192755062665255, 0.017858164684314812, 0.06529932642089468, 0.037284495042903085, 0.009304492867418697, 0.09660387198839869, 0.0431228546159608, 0.037865324411541224, 0.015117251314222813, 0.04663544720304864, 0.03798069911343711, 0.01646935617152069, 0.03822265452306185, 0.062095636901046546, 0.10143244253205401, 1.6391114230666841, 24.518163953508648, 44.64953408922468, 29.935062953404017, 35.74493816920689, 36.966480118887766, 26.75576182774135, 43.494253635406494, 45.699862003326416, 45.92026233673096, 28.06298896244594, 0.11499510226505143, 0.08142172558499233, 0.4951289030058043, 1.112088822892734, 0.9923618073974336, 21.579819406781876, 51.53779404503958, 48.462990352085654, 49.08203315734863, 42.28429085867745, 38.099818161555696, 34.03458002635411, 38.86702782767159, 40.17892067773001, 47.27284383773804, 46.76095267704555, 50.212407793317524, 40.5149564061846, 39.80383954729353, 42.41293675558907, 45.58957324709211, 45.769979749407085, 43.455830097198486, 43.94591086251395, 43.72218929018293, 39.93443788800921, 39.56984853744507, 36.90464462552752, 33.53274290902274, 34.25337185178484, 36.31634759902954, 33.0247357913426, 33.14116675513131, 32.70024102074759, 33.1427891595023, 34.159519059317454, 33.32213953563145, 33.36987713405064, 33.6418331010001, 34.93173142841884, 33.2998879296439, 34.51786197934832, 34.70707532337734, 34.90346268245152, 33.25128180640084, 33.88576003483364, 34.12432990755354, 33.99355091367449, 34.17058406557356, 33.752754143306184, 35.66881023134504, 35.13723829814366, 34.6054926599775, 35.140854835510254, 35.90705353873116, 33.317796911512104, 34.1935270173209, 35.29006740025112, 34.85012483596802, 38.209144592285156, 39.61654390607561, 45.11550113133022, 46.59903185708182, 49.4489814213344, 47.004883084978374, 45.023937770298545, 46.283625330243794, 47.59256867000035, 46.45392220360892, 44.69742454801287, 38.90573624202183, 34.46116815294538, 33.984799657549175, 31.739961760384695, 33.21616561072213, 33.534764834812705, 33.817695481436594, 33.86121899741036, 35.3162134715489, 35.35829871041434, 36.07075309753418, 34.2669277872358, 35.76071058000837, 34.79400423594883, 34.17138658251081, 33.18584714617048, 33.065316745213096, 34.03483363560268, 32.35233082090105, 32.77120644705636, 33.71150268827166, 34.4012816292899, 42.390157086508616, 44.88487999779837, 45.396333421979634, 42.63004016876221, 41.84007862636021, 42.30632707050869, 45.844429697309224, 45.936597551618306, 44.178922176361084, 46.37939235142299, 45.04602609361921, 43.600491591862266, 46.48336519513811, 44.857014247349326, 46.178526878356934, 45.631602900368826, 45.09102610179356, 44.726447173527305, 44.24642392567226, 38.84487349646432, 36.271802697862896, 33.78458384105137, 33.04980141775948, 35.10448101588658, 35.46318524224417, 37.225800786699565, 40.71529729025704, 45.927412033081055, 47.42031240463257, 50.056493691035676, 44.90924038205828, 10.527058482170105, 0.415679970490081, 3.749797735895429, 7.997693589755467, 2.009286799601146, 0.5015621749418122, 0.23049850868327276, 34.27919135774885, 50.857013021196636, 37.40386922018868, 22.379867996488297, 17.837045431137085, 31.256596429007395, 38.8321339743478, 12.46582041467939, 0.03431479832423585, 0.03832442120515874, 0.05789319133119924, 0.08173366170376539, 0.04591961311442511, 0.04485195522595729, 0.026158702227153947, 0.01912405318580568, 0.02600352805373924, 0.06749720312654972, 0.04263085226661392, 0.02152534281568868, 0.0725002521649003, 0.031629132971699746, 0.01841219191971634, 0.011546134233607777, 0.03741216819201197, 0.033561902652893744, 0.005810994679840016, 0.05637142048882587, 0.06908964339111533, 0.06818169568266187, 0.06214991970253842, 0.043384908232837915, 0.029804718547633717, 0.07736671888934714, 0.08985421952924558, 2.0566231395517076, 32.729162897382466, 51.515809944697786, 38.08684240068708, 38.45786925724575, 41.72219548906599, 33.96772793361119, 47.77458020618984, 49.431068965366904, 51.71453537259783, 28.51494148799351, 0.12027554320437567, 0.17570675164461136, 4.346574170248849, 3.026695885828563, 0.8289993447916848, 24.19430841718401, 51.7253155027117, 50.5642854145595, 49.03996181488037, 46.14501224245344, 39.13119486400059, 36.36332089560372, 39.07860394886562, 42.10577426637922, 47.48110219410488, 47.204831395830425, 50.0047539302281, 44.80774457114083, 40.9240003313337, 42.81480666569301, 44.927312646593364, 47.58238608496529, 45.8255410194397, 46.31433636801583, 44.363973549434114, 43.005211625780376, 41.122065680367605, 39.27594321114676, 35.047307763780864, 35.42054762159075, 36.16099282673427, 34.68010241644723, 35.28914328983852, 33.43110466003418, 34.24393967219761, 35.873452050345286, 36.26273529870169, 34.98872750146048, 34.75705024174282, 36.48787777764456, 34.45289979662214, 36.009160791124614, 35.47186006818499, 36.45543663842337, 34.74535294941494, 34.560812268938335, 35.10742705208914, 35.042551721845356, 35.131057875497, 35.70364155088152, 36.92398493630545, 35.44332729067121, 36.35395124980381, 36.921132700783865, 37.1124826158796, 35.67736693790981, 36.64337151391165, 36.780094691685264, 36.04433604649135, 40.031327043260845, 40.20294407435826, 47.254260880606516, 46.88936928340367, 49.48960753849575, 49.80578531537737, 47.448761803763254, 47.54813494001116, 47.2512731552124, 48.9476306779044, 46.049471037728445, 40.422041620527, 36.15015016283308, 35.5863733291626, 33.97536400386265, 34.54981674466814, 35.420123781476704, 35.413116523197715, 35.72889130456107, 36.9942763873509, 35.622788837977815, 35.8079513822283, 37.30767488479614, 36.12743650163923, 35.112221309116904, 35.71225731713431, 33.74869639532906, 33.59921979904175, 35.43723719460623, 33.30620731626238, 34.240357875823975, 35.56962469645909, 35.71450853347778, 43.04702935900007, 47.44262307030814, 46.433553559439524, 44.56594031197684, 42.52248900277274, 42.47013085229056, 45.85355268205915, 47.896302223205566, 46.56838682719639, 46.96000467027937, 47.39199849537441, 44.935306549072266, 47.70692907060896, 46.05840294701712, 47.03171355383736, 46.58387088775635, 47.33417558670044, 46.36265761511666, 45.06337921960013, 39.684177671160015, 37.5077725819179, 35.634451389312744, 35.3793934413365, 35.80962242398943, 37.19214718682425, 38.656646796635215, 41.80819681712559, 48.12967136928013, 49.88845845631191, 51.21995217459542, 46.408626896994456, 12.811950138636998, 0.15233636354761465, 4.583493845803397, 9.797698259353638, 5.683284248624529, 0.9197813591786793, 0.19337397148566587, 37.24244867052351, 55.7171493938991, 43.78241974966866, 28.947887216295513, 21.12958656038557, 37.09794698442732, 44.43914610998971, 16.978103910173687, 0.15856783916907652, 0.008707461778872778, 0.0169034082375999, 0.012393705896101892, 0.03142659705398338, 0.02789963818421321, 0.056520270715866766, 0.020042821831469024, 0.045206516914601834, 0.0433009225609047, 0.047073668866817436, 0.018160446946110045, 0.16807418263384274, 0.15231163773153508, 0.08908659964799881, 0.042989821040204594, 0.24612701577799662, 0.13134542134191307, 0.1941136832215956, 0.09063534225736346, 0.15989117244524614, 0.1607209529195513, 0.1557383481413126, 0.14745795460683958, 0.2103336557213749, 0.19154844087149414, 0.2075810291405235, 2.5703421107360294, 39.41438954217093, 59.797579765319824, 41.42349590573992, 46.36552722113473, 47.56469249725342, 36.56179966245379, 51.53659200668335, 53.31230837958199, 54.83628804343087, 34.614469732557026, 0.18726331580962452, 1.007335501057761, 7.746869700295584, 5.0416037780897955, 2.123888215848378, 25.2029801436833, 54.83569744655064, 52.287560258592876, 53.18764727456229, 47.80117443629673, 41.755369663238525, 38.18665674754551, 42.63084268569946, 45.14977312088013, 50.69082948139736, 48.48026009968349, 52.3931450843811, 43.648573126111714, 42.199085099356516, 42.825826508658274, 47.48981523513794, 49.664531912122456, 47.71635430199759, 47.81113467897688, 48.721946239471436, 44.657135418483186, 43.38413858413696, 42.15201800210135, 36.4300513948713, 38.4748089654105, 39.909490380968364, 36.44468082700457, 38.76192937578474, 36.010397570473806, 36.604211466653005, 37.92210061209542, 38.53397635051182, 36.12264919281006, 38.428530488695415, 38.49697024481637, 36.314728668757844, 37.08644076756069, 38.17331968035017, 38.16634021486555, 35.911479541233604, 37.72770043781826, 37.06688158852713, 37.35810143607003, 36.748720100947786, 37.0598361151559, 38.09378365107945, 37.424161434173584, 38.09014279501778, 37.90155478886196, 38.86240380150931, 37.089960030147004, 38.9734777041844, 38.82143374851772, 40.62568984712873, 42.60136147907802, 43.04254082271031, 49.19585854666573, 49.15690347126552, 49.56460986818586, 48.82788889748709, 49.32044322150094, 47.92074945994786, 48.698836530957905, 49.17924887793404, 46.47140039716448, 43.37400116239275, 38.7354393686567, 37.30110536302839, 35.78096110480172, 37.0871251651219, 37.0079573903765, 35.95626762935093, 37.76095451627459, 39.614282267434255, 38.58507687704903, 38.97790370668684, 38.76545558656965, 37.90264218194144, 38.288156032562256, 37.514046805245535, 35.960026604788645, 35.58463280541556, 37.858830315726145, 34.70781183242798, 35.99899557658604, 36.18277890341622, 38.8588011605399, 45.51151371002197, 49.80392667225429, 50.0494065284729, 46.24047701699393, 44.78261293683733, 44.686283111572266, 47.555454867226736, 48.922863824026926, 47.236612456185476, 49.56241423743111, 48.672363894326345, 45.62491873332432, 50.04239927019392, 47.12703589030674, 50.41009446552822, 48.33392756325858, 48.81662586757115, 49.494638034275596, 48.29129341670445, 42.15940046310425, 39.70576919828142, 37.992242676871165, 36.63950136729649, 38.35801322119576, 38.88415166309902, 39.387579917907715, 44.65755231039864, 49.9806923185076, 53.070389475141255, 52.38998712812151, 48.39348404748099, 14.066260661397662, 1.528461251940046, 10.558905550411769, 15.087255886622838, 9.981042112622942, 2.3384192756244113, 0.37393052503466606, 42.470787457057405, 61.48763179779053, 46.879231861659456, 33.49813045774187, 27.175179413386754, 43.60099186216082, 52.107765197753906, 19.813523054122925, 0.3307828903198242, 0.15437194146215916, 0.13410099276474544, 0.1873535473964044, 0.18633119868380682, 0.1414781069116933, 0.11548917075353009, 0.16050489379891328, 0.10928530472197703, 0.17315493071717875, 0.09744967267449413, 0.10791389045438596], [0.02523178607225418, 0.04230702821431415, 0.04383072270346539, 0.017823885095172694, 0.04912288872791188, 0.03227016196719237, 0.02771670344684805, 0.02825276816396841, 0.039531236447926076, 0.04888315212779811, 0.026741658803075552, 0.08495432816978012, 0.027303580793419054, 0.03265018228973661, 0.05087540897407702, 0.30241114273667336, 25.849153927394322, 37.32032755443028, 39.505925110408235, 51.22093187059675, 60.421743392944336, 47.471058573041645, 32.21042776107788, 51.09915426799229, 41.954536301749094, 39.83246612548828, 1.216193465249879, 0.18565265009445803, 1.9201107961790902, 1.2291890936238425, 0.5904463540230478, 23.163101945604595, 50.9140681539263, 50.84531920296805, 47.89711863654, 43.59213638305664, 37.97460814884731, 35.10381398882185, 39.68445559910366, 46.1505742754255, 46.28778730119978, 48.297946316855295, 44.58970315115792, 37.88518483298165, 44.62747008459908, 46.43851457323347, 44.81222268513271, 43.76019246237618, 43.27833489009312, 41.34570387431553, 39.133453028542654, 40.35322666168213, 38.99733781814575, 36.98283617837088, 34.315784045628135, 32.64840745925903, 32.701609815870015, 33.82630429949079, 31.715142795017787, 33.25412014552525, 32.602514607565745, 32.82131685529436, 32.32719571249825, 33.378663131168906, 33.49412829535348, 34.82897104535784, 34.909299169267925, 33.957830224718364, 35.06655774797712, 34.075362477983745, 34.17087588991438, 34.16228444235665, 34.002892766680034, 33.4817396572658, 33.94422912597656, 35.68667752402169, 35.808305740356445, 34.92806625366211, 34.18686716897147, 34.805169991084504, 33.026333877018516, 34.17134141921997, 35.34069892338344, 36.113640853336875, 37.92514739717756, 41.2468136378697, 42.103992053440635, 45.922728947230745, 47.070519242967876, 49.715156487056184, 43.949089663369314, 44.23265259606497, 47.24494334629604, 46.45496095929827, 46.60216549464634, 45.5427701813834, 40.279527119227815, 36.04036167689732, 33.91347292491368, 32.37641327721732, 33.04091814586094, 32.380846227918354, 34.66625813075474, 33.88393265860421, 33.4818160874503, 33.9632602419172, 33.714434828077046, 34.293438638959614, 34.58672557558332, 33.99485717500959, 34.474477427346365, 34.255828039986746, 34.84366301127842, 33.262263434273855, 34.18373353140694, 33.24180793762207, 31.968731198992046, 32.5160824911935, 37.594482626233784, 42.615674768175396, 43.659353256225586, 45.03658696583339, 45.36667503629412, 45.41378729684012, 44.89147731236049, 44.51694161551339, 45.29731116976057, 45.210295404706685, 44.336097376687185, 43.846725327628, 44.14868014199393, 43.19320903505598, 46.417423316410606, 46.5181930405753, 46.06177977153233, 45.92834309169224, 45.632648604256765, 45.24689851488386, 43.916804858616416, 40.184583459581646, 36.03786379950387, 34.553395066942485, 35.18923166819981, 36.796989236559185, 41.87800536836897, 45.031004088265554, 47.519953046526226, 51.680888720921104, 41.945378576006206, 7.610699772834778, 0.1819076660488333, 3.8333854334694997, 7.47518037046705, 2.927449119942529, 0.7149588870150703, 0.4799999062504087, 36.622151715414866, 49.22879648208618, 35.69931977135794, 26.65587626184736, 29.367461136409215, 38.01270512172154, 35.8482335635594, 3.3843520198549544, 0.1876724317137684, 0.03125167751152601, 0.05381890406299915, 0.07060367214892592, 0.047005720370049985, 0.02519219694659114, 0.041758805845997164, 0.04066195738102708, 0.024334208075223223, 0.03832796994330628, 0.0640095059892961, 0.008701382953274463, 0.028667704202234745, 0.043179732813899, 0.06672281825116702, 0.025577864376828074, 0.032847710619015355, 0.021145152859389782, 0.04351712417389665, 0.009954023906694991, 0.03378097786168967, 0.006784764950030616, 0.03179745036842568, 0.03186036752802985, 0.06034291309437581, 0.027864254279328243, 0.08557108936033078, 0.7376029576574052, 31.097982951572963, 45.96149294716971, 42.10236964906965, 51.12362582342965, 52.268748010907856, 44.628349031720845, 39.33510364804949, 53.094579628535676, 46.788471017565044, 40.59669154030936, 1.2830101656062263, 0.4041930783007826, 4.403494681630816, 3.107522977249963, 0.5979893292699541, 24.518712861197336, 52.835119996752056, 50.74113096509661, 50.23894991193499, 46.07377583639962, 40.62553698675973, 37.39067111696516, 40.68315839767456, 46.29654550552368, 48.002126761845176, 48.83766501290457, 46.51336056845528, 39.57275288445609, 43.792036056518555, 46.26673078536987, 46.306477955409456, 45.48551007679531, 44.95440019880022, 42.511066164289204, 41.00466544287545, 42.06743063245501, 41.54913323266165, 38.03405693599156, 35.79093524387905, 35.79192188807896, 33.98609897068569, 35.81612246377127, 33.127013274601524, 34.986681256975444, 34.158834661756245, 33.624368803841726, 33.01081507546561, 34.4986641066415, 35.08960839680263, 36.62923192977905, 36.509882722582134, 36.25405005046299, 36.18802826745169, 35.16226918356759, 36.61560998644148, 35.48749698911394, 35.83585187367031, 34.71931457519531, 35.874188559395925, 36.75221504483904, 36.85982527051653, 36.0326908656529, 34.98865107127598, 35.88570867265974, 34.64074781962803, 35.91595418112618, 37.137819222041536, 36.910234451293945, 40.49922568457467, 42.91315146854946, 42.99892350605556, 47.89580890110561, 50.449546337127686, 50.87885468346732, 44.230484758104595, 45.432175704411094, 47.18742963245937, 47.51287630626133, 49.7221359525408, 46.131442410605295, 41.05903162275042, 38.064187799181255, 35.7859777041844, 33.54772669928414, 35.20867272785732, 34.691747597285676, 36.36199378967285, 35.386070660182405, 34.715628555842805, 36.027101039886475, 35.98776728766305, 35.8389299256461, 36.07047516959054, 35.898594106946675, 35.73588119234358, 36.02419669287545, 36.33811630521502, 35.099488735198975, 33.84090941292899, 34.45281294413975, 33.849705832345144, 33.55007866450718, 40.28838954653059, 45.240822315216064, 45.069462367466514, 46.284799575805664, 47.35896675927298, 46.12526546205793, 44.89550379344395, 47.161123752593994, 47.127612590789795, 45.56676231111799, 46.81078863143921, 44.9289037840707, 45.729798316955566, 44.654484680720735, 47.07508420944214, 47.27889919281006, 47.33554438182286, 48.2210054397583, 47.709902899605886, 47.34539692742484, 45.45052242279053, 41.9012644631522, 38.50060067858015, 36.59289632524763, 37.5730995450701, 38.64494603020804, 43.61580194745745, 46.91403538840157, 51.8734267779759, 52.023994241442, 44.056863171713694, 9.090400304113116, 0.1855370955807822, 5.508113648210253, 8.32684017930712, 6.126630127429962, 0.20470530273658888, 0.4795415965574128, 41.21515417098999, 53.84550966535296, 42.446392331804546, 31.979570388793945, 27.50343142236982, 40.7739748273577, 41.816965443747385, 5.002477603299277, 0.17077464344246046, 0.08113180792757443, 0.02380131890199014, 0.02505052731638508, 0.0787394902269755, 0.04381462446014796, 0.03286779525556734, 0.010632530935773892, 0.020388584617259245, 0.016277878678270748, 0.022202101768925786, 0.02174705752570714, 0.1571435263114316, 0.10576915661139147, 0.18888783720987185, 0.10836662258952856, 0.1868256607225963, 0.12048605190856115, 0.10504925809800625, 0.07339116185903549, 0.100824692286551, 0.08992615781192269, 0.1529038223837103, 0.2178865782916546, 0.2073110264859029, 0.09063622435288769, 0.11179412688527789, 0.8111065391983304, 37.37107024874006, 52.447660650525776, 52.404036385672434, 61.54300199236189, 63.37086459568569, 57.26442984172276, 42.14822775976998, 59.04610429491316, 51.157109192439485, 46.81357833317348, 1.597503764288766, 0.6049034925443786, 7.19205995116915, 4.6095000846045355, 1.2473735064268112, 26.73225780895778, 52.41857549122402, 53.52268246241978, 52.54301077978951, 47.590157645089285, 43.023603507450645, 38.349956784929546, 44.255223819187705, 50.48000723975045, 50.431932653699604, 49.81351866040911, 47.54747486114502, 40.562561988830566, 46.199288095746724, 48.630792822156636, 47.812211649758474, 48.30129534857613, 47.15021160670689, 44.541687624795095, 42.60899754932949, 44.638423919677734, 43.21759373801095, 41.157001222882954, 38.329615933554514, 37.490610531398225, 36.52688149043492, 37.94973359789167, 35.26234408787319, 37.459482601710725, 36.414348466055735, 34.75523328781128, 36.69934272766113, 36.23751333781651, 37.3442918913705, 37.847782679966514, 39.93295792170933, 37.715923241206575, 38.564096791403635, 38.01609584263393, 37.9485558782305, 35.86128575461251, 37.11510556084769, 36.897123200552805, 37.15011058534895, 39.14308670588902, 39.49835852214268, 38.169730935777935, 37.29902785164969, 39.078246116638184, 36.533312048230854, 37.13960838317871, 39.816631180899485, 39.658889702388215, 42.48399598257882, 45.5905043057033, 46.13726847512381, 50.726977484566824, 52.11293813160488, 51.09212963921683, 43.759417738233296, 47.665413584027974, 49.2841215133667, 48.58336441857474, 51.55227061680385, 49.210078035082134, 43.2147102355957, 40.760460581098286, 37.39504848207746, 37.207884856632774, 38.186503887176514, 36.54347378867013, 37.5112293107169, 37.78082636424473, 37.03950221197945, 37.11736372538975, 37.664419719151084, 37.62527356828962, 38.55163172313145, 37.15039198739188, 37.557778767177034, 37.37921353748867, 37.07909999574934, 35.86466605322701, 36.383286544254844, 36.96319362095424, 34.48351008551461, 35.253050872257774, 41.3872332572937, 45.86155005863735, 46.61870568139212, 49.16697488512312, 48.49790505000523, 49.602144036974224, 47.43716526031494, 47.99024534225464, 49.2653683253697, 47.31049960000174, 47.495530128479004, 46.05446679251534, 46.91804449898856, 44.962275981903076, 49.75766904013497, 47.884396484919954, 48.89317069734846, 49.20344945362636, 49.20794146401541, 49.670524733407156, 48.090177808489116, 44.6718030657087, 40.78926086425781, 37.72185352870396, 40.007084778376985, 41.236467770167756, 45.79439919335501, 49.51396097455706, 52.71972778865269, 56.21765940529959, 45.43173449380057, 11.829400164740425, 0.39189229692731586, 9.776019879749843, 14.474793025425502, 11.123952167374746, 1.9920771973473685, 0.7747844510844776, 44.67790705817086, 59.65299470084054, 46.307909284319194, 37.24619027546474, 39.29616594314575, 47.18666533061436, 48.97967576980591, 7.404874154499598, 0.2660254623208727, 0.1435150554669755, 0.08415919369352715, 0.183844245704157, 0.14482595798160347, 0.1077186284320695, 0.11082576241876398, 0.09455736966005393, 0.15796170383691788, 0.11591556215924875, 0.15809756011835166, 0.16188508830964565], [0.011978437375676419, 0.025010973813810518, 0.0713790205440351, 0.029422150326094458, 0.08654516709170171, 0.02743637009656855, 0.03521704973120775, 0.04792038218251296, 0.026863856174583946, 0.013847186429692166, 0.0186404850267406, 0.03797754392560039, 0.02912952870662723, 0.005037885874376765, 0.03239454082878573, 0.11565668747893401, 12.164604714938573, 43.36348853792463, 36.21968078613281, 48.12368202209473, 53.719333853040425, 59.57907976422991, 35.85936805180141, 43.31917987551008, 47.97270461491176, 41.070228644779746, 4.487193984644754, 0.4141253653381552, 4.489882937499455, 2.9595276500497545, 0.15144289577645914, 19.523204735347203, 50.356555121285574, 50.75104604448591, 47.679553168160574, 42.73709453855242, 37.04371976852417, 36.9706768308367, 44.161256381443565, 47.29918098449707, 48.444376128060476, 46.40071289879935, 38.30161816733224, 43.703470843178884, 43.75747224262783, 42.99355949674334, 44.35505206244332, 43.58845731190273, 40.856731346675325, 41.73321533203125, 39.134613377707346, 40.569986139025005, 37.973308835710796, 39.60913017817906, 36.369928632463726, 31.967786243983678, 32.90981606074742, 32.811294078826904, 32.760794571467805, 32.97238458905901, 33.63292898450579, 33.784250327519004, 33.97519377299717, 32.97908265250069, 33.30549512590681, 34.4239501271929, 33.70181342533657, 33.68715967450823, 35.74401753289359, 35.402138369424, 35.34692450932094, 34.48361778259277, 33.600477422986714, 34.58271993909563, 34.5025759424482, 34.06278623853411, 34.903691973005024, 34.823600087847026, 31.835680144173757, 33.64257655824934, 33.563999380384175, 34.19420099258423, 35.08668320519583, 38.02220678329468, 42.300038950783865, 44.02970961162022, 46.22678211757115, 45.426526818956646, 45.882443291800364, 48.81023352486746, 43.792532852717805, 42.555673599243164, 46.63096577780587, 46.7365506035941, 46.23518943786621, 47.430891036987305, 42.74971941539219, 35.493027755192344, 32.85466820853097, 31.23196506500244, 32.55479090554373, 32.535756315503804, 35.21520750863211, 33.0328825541905, 34.05773489815848, 34.671167033059255, 33.94829729625157, 34.17184863771711, 34.21378796441214, 35.662980692727224, 34.35630593981062, 34.39899567195347, 34.04460975102016, 33.872971875326975, 33.88521807534354, 32.26039573124477, 33.16754559108189, 31.50397661754063, 34.36230223519461, 40.78840970993042, 43.587105887276785, 43.00540617534092, 43.05951527186802, 44.581879479544504, 46.26436839784895, 45.199299880436485, 45.51424782616751, 44.85444688796997, 44.576967103140696, 45.16807815006801, 45.3281055859157, 43.16756670815604, 42.39399944032942, 42.15803861618042, 43.14936590194702, 46.08816902978079, 47.96044104439871, 46.31895692007882, 45.28399494716099, 46.6927422114781, 44.637180192129954, 38.82245513371059, 37.23070274080549, 37.69131966999599, 42.07702956880842, 44.44902992248535, 49.527207715170725, 47.27122490746634, 40.26008605957031, 5.9127011724880765, 0.11923274344631604, 4.184420585632324, 9.362974660737173, 3.2710944286414554, 0.008755344298801251, 0.9910365470818111, 41.860878058842246, 43.78658519472395, 35.489317417144775, 23.42715607370649, 23.15238434927804, 39.41796439034598, 30.669484070369176, 1.5991028270551135, 0.027714823904846395, 0.043943780208272595, 0.0314399913352515, 0.03374543619741287, 0.0421405801815646, 0.046996444796345065, 0.019318003939198594, 0.037783778073000054, 0.033479670993983746, 0.022726921464449594, 0.016698261656399285, 0.005342526469446186, 0.02183992861370955, 0.01757581778136747, 0.03531955601647496, 0.035838638698416095, 0.05353499483317137, 0.024287358624860644, 0.029946827529264346, 0.07766184769570827, 0.052711307603333674, 0.02029068049575601, 0.014716820658317633, 0.010905969522095152, 0.0433414378868682, 0.029765058175793717, 0.01437223852345986, 0.2141790222376585, 18.999340091432842, 48.369693415505544, 44.047069685799734, 55.32926620755877, 57.06847674506051, 58.898420333862305, 37.78340762002127, 50.17817401885986, 50.07475355693272, 45.09169660295759, 3.6151924559048245, 0.48460059080805096, 4.535355857440403, 3.5571715235710144, 0.7082571323428835, 22.3890517779759, 52.0504321370806, 51.917745862688335, 49.09382425035749, 45.76325041907174, 39.040937764304026, 38.85438905443464, 44.97974722726004, 49.24794224330357, 48.8089793750218, 47.96469334193638, 39.829071930476594, 42.86729335784912, 45.36508042471749, 45.35912234442574, 46.9361515045166, 44.06493697847639, 42.49422025680542, 42.7714638028826, 39.83955676215035, 41.787696157182964, 39.861582551683696, 41.334086486271445, 38.120520319257466, 32.680633204323904, 34.59674487795149, 35.125283922467915, 34.740857464926584, 34.22755581992013, 35.42079080854143, 34.08249480383736, 35.69537666865757, 33.180764538901194, 34.523983342306956, 35.513035093035015, 34.975251470293315, 35.314347880227224, 36.227837971278596, 37.005049569266184, 36.98862055369786, 36.18380376270839, 34.95773506164551, 35.51575183868408, 34.79689121246338, 35.4408016204834, 36.43730184010097, 35.76477180208479, 33.80732529503958, 36.051892212459016, 34.84973226274763, 36.365408829280305, 37.203368527548655, 38.32033314023699, 44.01387119293213, 45.398237228393555, 47.30356877190726, 47.137148993355886, 48.50981078829084, 51.555769034794395, 44.801970618111746, 45.531562737056184, 47.88939918790545, 47.68535143988473, 48.10859053475516, 48.29437146868025, 42.58543620790754, 37.23528160367693, 35.461010456085205, 34.80826888765608, 34.807921477726524, 34.84221083777291, 35.22017199652535, 35.83190529687064, 33.756846632276265, 35.54723065240042, 36.48200307573591, 35.145947865077424, 35.87670728138515, 37.64109114238194, 35.46142387390137, 36.7181966645377, 35.47959688731602, 34.37901612690517, 35.66179949896676, 34.63795811789376, 35.261722224099294, 33.79354006903512, 36.74515220097133, 42.860119342803955, 45.03190387998308, 43.95129919052124, 44.5127831186567, 46.6191851070949, 45.98468950816563, 46.733118193490164, 47.765050751822336, 45.948232310158865, 46.43419279370989, 46.01796095711844, 45.26290021623884, 43.50904287610735, 42.913721220833914, 44.42417969022478, 46.10525465011597, 46.21648836135864, 50.69701337814331, 48.07068116324288, 46.61809423991612, 48.12658984320504, 45.74265595844814, 40.35960858208792, 39.843360900878906, 39.686692919049946, 45.55081966945103, 46.22083098547799, 51.609735693250386, 49.256359985896516, 41.969999517713276, 7.373578599521092, 0.288928570491927, 7.321723324911935, 7.982877424785069, 6.184516438416072, 0.1415107444460903, 1.2443037054368427, 45.31656115395682, 49.71402045658657, 39.72613089425223, 26.180044514792307, 27.47483263696943, 43.8933755329677, 36.03911100115095, 2.8348565569945743, 0.06712371709623507, 0.06880847205008779, 0.05807068930672748, 0.03931835287117532, 0.028295517566480806, 0.05550658689545734, 0.010849663838078933, 0.05630007931696517, 0.03379987845463412, 0.060403689475996156, 0.013009033681425666, 0.0464477067414139, 0.15567175671458244, 0.1191235671618155, 0.13639716883855207, 0.10218510071613959, 0.25216114627463476, 0.0687572630122304, 0.11085941775568894, 0.17882947836603436, 0.1319969913789204, 0.1571687271020242, 0.10988639175359692, 0.14972504866974695, 0.09102511991347585, 0.0886666543249573, 0.10895641879843813, 0.3511182319905077, 21.714155878339493, 58.495084353855674, 50.022732394082205, 56.04967975616455, 58.809330531529014, 63.4495529447283, 44.57026209150042, 52.14567804336548, 55.50900568280901, 48.87651933942522, 6.205026652131762, 1.003782257437706, 11.92103213923318, 6.7236401949610025, 0.6214258202484676, 24.58262586593628, 53.57052428381783, 54.17253705433437, 51.728921617780415, 46.62017869949341, 40.7330881527492, 40.963546003614155, 47.8286406653268, 51.627432755061555, 51.268388066973, 46.57461936133248, 41.169726848602295, 42.616772583552766, 48.058553082602366, 49.259000301361084, 48.70827565874372, 47.255838121686665, 43.33609873907906, 45.90617833818708, 43.71194417136056, 43.42737374986921, 41.742762156895225, 44.838997568402974, 39.83251823697771, 34.33838306154524, 35.93101787567139, 37.28882442201887, 36.79374442781721, 36.45218488148281, 36.920069626399446, 36.00931365149361, 37.176152433667866, 35.97113330023629, 36.56119169507708, 36.62656382152012, 35.91351188932146, 36.48663405009678, 38.88030930927822, 38.85961062567574, 38.96547337940761, 37.782167366572786, 37.91651426042829, 36.80050155094692, 36.30589056015015, 36.93661676134382, 37.996470655713765, 37.39234215872628, 36.301318645477295, 38.354268142155235, 37.365327562604634, 37.54064450945173, 39.564769404275076, 40.14791086741856, 47.106021063668386, 48.88715703146798, 49.12367718560355, 49.353120599474224, 49.92786169052124, 51.5543863432748, 44.36573144367763, 45.67112077985491, 48.65053265435355, 49.50388956069946, 48.359858240400044, 49.95722130366734, 44.787469727652415, 40.208096163613455, 36.08786998476301, 36.286484241485596, 36.51701504843575, 36.39399371828352, 38.92350973401751, 37.474292687007356, 36.70452608380999, 37.57531949451992, 38.83078949792044, 37.47789532797677, 36.19247164045061, 40.20089088167463, 37.96172966275896, 38.130362442561555, 37.74165589468819, 36.19875281197684, 37.46373837334769, 36.57853439876011, 37.425558022090364, 34.383581093379426, 37.25247144699097, 44.00015892301287, 48.756631646837505, 45.395878314971924, 45.02088751111712, 48.291352476392476, 48.62191302435738, 47.909163338797434, 49.50695719037737, 48.233307225363596, 47.473132610321045, 48.17599848338536, 46.12103053501674, 44.373895577022004, 42.440347399030415, 45.080270290374756, 46.10787412098476, 49.14800977706909, 51.93483148302351, 50.482362679072786, 49.052715233394075, 51.80356958934239, 49.584488664354595, 42.66620554242815, 42.44962671824864, 42.373939990997314, 46.32178136280605, 48.73809037889753, 53.95359584263393, 50.11566802433559, 43.2799642426627, 10.389756866863795, 0.46583850043160574, 12.561884471348353, 19.96051393236433, 11.527593868119375, 0.7637884382690702, 1.4839211276599338, 50.87828145708357, 52.35885572433472, 46.74159846987043, 32.53959172112601, 32.815188544137136, 50.52690410614014, 44.26528133664812, 4.690488287380763, 0.11716838207628046, 0.17446469329297543, 0.19302517734467983, 0.1358877790293523, 0.20370732700186117, 0.09893687894301754, 0.11559891700744629, 0.12114237169069902, 0.11123429478279181, 0.12320556598050253, 0.09956961963325739, 0.09181068026061569], [0.038948887160846164, 0.033745670291994295, 0.016997205525902764, 0.018293594176481878, 0.08082840099398579, 0.03729329564209495, 0.027790977586326853, 0.010355719182241176, 0.02664803454120244, 0.03955812339804002, 0.004312901741026768, 0.017169317629720484, 0.053224327574883185, 0.02056491211988032, 0.04167521033169968, 0.05373171231310282, 6.134526755128588, 37.412901878356934, 34.53069877624512, 33.142125606536865, 55.758734362465994, 65.75540297372001, 40.96952492850167, 41.606170994894846, 44.98226942334856, 46.06099462509155, 10.515891858509608, 0.18454499595931598, 2.4882120149476186, 2.2263100913592746, 0.27854356489011217, 14.66310657773699, 49.58284888948713, 49.62972143718174, 48.96391378130232, 43.2470679964338, 38.99160555430821, 38.69246128627232, 46.00943204334804, 44.482784271240234, 49.902003969464985, 40.359080518995015, 40.66833094188145, 46.00212253843035, 45.49698850086757, 43.226261615753174, 41.09192092078072, 40.33153785978045, 40.921446868351524, 41.21323994227818, 41.23577989850725, 40.06711026600429, 40.75773341315133, 41.26030356543404, 38.25789662769863, 34.536802768707275, 32.75436748777117, 33.29682377406529, 33.27658019747053, 32.838315623147146, 33.33853381020682, 33.999977997371126, 31.701934269496373, 31.759857927049907, 35.60844428198678, 34.17167840685163, 35.15212828772408, 33.68131276539394, 33.44606760569981, 34.94057648522513, 33.61239010947091, 35.62839256014143, 33.46583523069109, 33.534389632088796, 34.99099956239973, 34.37560108729771, 35.71798610687256, 33.16649988719395, 33.61870602199009, 33.60759585244315, 33.14890010016305, 35.769288131168906, 35.88598312650408, 40.643063817705425, 44.45691612788609, 45.874091557094026, 45.92031792231968, 46.445018087114605, 48.89164209365845, 43.93358128411429, 43.59764977863857, 43.23887954439436, 44.00616216659546, 45.92249618257795, 45.782945087977815, 46.27231018883841, 42.3080085345677, 35.37672880717686, 32.91129950114659, 32.835432120731895, 32.13042272840227, 32.447465556008474, 33.919208662850515, 33.2898199898856, 33.160784993852886, 34.064703941345215, 33.805081026894705, 33.68002734865461, 33.87721027646746, 33.12452581950596, 33.69017519269671, 33.56608731406075, 34.01062958581107, 33.55000223432268, 34.65069416591099, 33.609857491084504, 32.34673057283674, 32.77652529307774, 33.921282700129915, 39.03656039919172, 41.79741668701172, 42.59367329733712, 44.9112206186567, 43.42023794991629, 44.032756396702354, 44.165477412087576, 42.8165854045323, 43.05982446670532, 43.0224848474775, 44.53093876157488, 45.36173139299665, 46.06634473800659, 44.630131244659424, 42.89231382097517, 41.535389695848735, 43.983830656324116, 43.993818691798616, 47.56149632590157, 50.36247846058437, 44.13319260733468, 45.49408415385655, 46.508364813668386, 41.68974392754691, 40.23198059626988, 41.27615935461861, 44.78839383806501, 47.95686967032296, 46.17926686150687, 37.061284814562114, 4.511862695217133, 0.3265012800693512, 3.937831623213632, 4.244691865784781, 5.145392494542258, 0.2585934954030173, 2.928730628320149, 45.60628366470337, 37.696860858372276, 31.186207703181676, 24.317619834627422, 23.709609031677246, 39.93850605828421, 22.812693868364605, 0.086445517438863, 0.0330358005261847, 0.05725498164870909, 0.012452852945508701, 0.14367582755429403, 0.021675757065947567, 0.05439525170783911, 0.012415854975448122, 0.011239765494662737, 0.018503531214914153, 0.07003940921276808, 0.04526744257392628, 0.04952214212555971, 0.03987192888078945, 0.054020300041884184, 0.027719298843294382, 0.005490147699934563, 0.014832315800179328, 0.06452545044677598, 0.03411186885620866, 0.03267888771370053, 0.06494657642074994, 0.020130385079288056, 0.06689819919743709, 0.03921065579301544, 0.011486295078481947, 0.02020749549514481, 0.02148664596357516, 0.04570918583444186, 8.11025788102831, 46.520197595868794, 37.494088104793, 39.43843378339495, 59.336406980242046, 63.717016901288716, 42.3755658694676, 45.15573467527117, 47.40673909868513, 48.0030335017613, 9.51935168675014, 0.33171242901257103, 2.2783012901033675, 3.2318903037479947, 0.34946333936282564, 16.378526483263286, 51.19540766307286, 50.47506012235369, 50.934318678719656, 44.00673539297921, 39.7461382320949, 39.4174154826573, 49.68049192428589, 47.765297412872314, 51.43435621261597, 41.868312631334575, 42.4348201070513, 46.34811503546578, 47.656780447278706, 44.79395934513637, 44.408146721976145, 42.77209608895438, 43.98632158551897, 44.49904653004238, 42.15340069362095, 41.37628289631435, 43.459919112069265, 42.53438779285976, 39.36958755765642, 35.164641993386404, 35.28569003513881, 32.98457867758614, 34.221406664167134, 34.76673603057861, 34.59501130240304, 34.19957889829363, 34.47412306921822, 34.082487855638774, 36.341708523886545, 35.650032724652974, 36.161739758082796, 36.52820859636579, 36.051419734954834, 35.64812544413975, 36.419236523764475, 35.65906885692051, 34.783741746629985, 35.448653084891184, 35.42767994744437, 37.227044514247346, 37.32610845565796, 34.987643582480295, 35.017562525612966, 35.22589383806501, 35.52776179994856, 36.27139622824532, 36.49989121300833, 41.71904795510428, 45.05175835745675, 46.540906701769146, 48.24833965301514, 48.14639220918928, 49.88297632762364, 46.6244865826198, 44.51034777505057, 44.30084221703665, 45.3649206161499, 49.00341429029192, 48.83535473687308, 46.75596039635794, 42.076508453914094, 37.357267652239116, 33.43691682815552, 34.4143511908395, 33.82646410805838, 33.854868343898225, 35.587888036455425, 35.52202953611101, 34.386478492191856, 35.566692556653706, 34.93099839346749, 36.587893622262136, 36.21603993007115, 34.731494767325266, 34.76711123330252, 34.8848032951355, 35.52432591574532, 35.52790423801967, 36.115760053907124, 33.7283798626491, 33.52225112915039, 34.40015949521746, 34.29669386999947, 41.723880427224294, 43.8155973979405, 44.30840185710362, 47.650766781398225, 44.710369041987825, 45.699903692517964, 46.60130739212036, 44.46402413504464, 43.92329100200108, 44.333877427237375, 45.81865535463606, 46.64974675859724, 48.41479417255947, 45.54052243913923, 43.04282917295183, 42.30786609649658, 43.81750815255301, 46.241213526044575, 48.204055309295654, 51.94157818385533, 45.59230041503906, 47.83572087969099, 48.08882290976388, 43.89500488553728, 41.52082627160208, 42.613017082214355, 46.877602509089876, 49.250467913491384, 47.59987817491804, 38.486353397369385, 6.250093102455139, 0.8776672961456435, 9.803459184510366, 8.025274464062282, 5.695588639804295, 0.18390942577804836, 2.812141158751079, 52.69648606436593, 42.05004276548113, 39.5529123033796, 26.951926844460623, 24.703566210610525, 45.460715430123464, 28.275216477257864, 0.2866864465177059, 0.05151720471414072, 0.008710934181830712, 0.03033720568886825, 0.11092372251940624, 0.016857825951384645, 0.061469661204942634, 0.01657111776460494, 0.035661944786884954, 0.02738855543014194, 0.01207716082821467, 0.04005609346287591, 0.034171586723199913, 0.07385777682065964, 0.12718605596039975, 0.0447350775689951, 0.0856691240998251, 0.24137528932520322, 0.29573123689208713, 0.09346462293927159, 0.13019488379359245, 0.1129526032933167, 0.09214405130062785, 0.2122062902365412, 0.13718903277601513, 0.07143786310085229, 0.08718038443475962, 0.12470736753727708, 0.10582579392939806, 10.25019187586648, 53.09679957798549, 46.68740252086094, 44.24107033865792, 60.80507550920759, 68.3356443132673, 47.664169856480186, 50.90754726954869, 52.046725273132324, 53.517669337136404, 12.7568405015128, 0.4416774697601795, 5.837563352925437, 7.485799823488508, 0.6344829510365213, 18.916461978639873, 52.66800192424229, 52.71605913979666, 52.20225027629307, 46.63485676901681, 42.22959116527012, 43.24113770893642, 51.913371971675325, 49.13515213557652, 53.3252980368478, 40.6290145601545, 42.79619244166783, 47.51344953264509, 50.540734495435444, 47.4096816607884, 44.85237285069057, 44.86231572287423, 46.066435064588276, 47.317089966365266, 44.60472863061087, 43.855629444122314, 44.53417662211827, 44.37154361179897, 42.23310695375715, 37.77903720310756, 36.726416383470806, 35.48254639761788, 37.21818208694458, 36.036953585488455, 36.901101044246126, 36.627262115478516, 35.56338174002511, 35.6528536932809, 40.184962136404856, 38.55724934169224, 38.99237680435181, 37.31730161394392, 37.58381714139666, 38.73377527509417, 37.09514338629586, 39.724713461739675, 36.366972173963276, 37.50563601085118, 36.87607363292149, 38.42303793770926, 39.01667812892369, 35.75376238141741, 36.267300265175955, 36.70796891621181, 36.71517072405134, 40.206525870731895, 38.42903423309326, 43.81568425042288, 47.77557727268764, 49.0892071723938, 48.99665021896362, 48.80961166109358, 49.86266674314226, 47.60860858644758, 43.71542869295393, 45.826003074645996, 46.78969737461635, 48.81402724129813, 49.76850822993687, 49.27287585394723, 45.48727491923741, 40.069872174944194, 36.2154667036874, 36.40207099914551, 35.165079729897634, 35.616924558367046, 37.720991952078684, 37.47212137494768, 35.91759048189436, 36.45055552891323, 36.85030623844692, 37.941166469029014, 37.948785168784006, 35.863863536289756, 36.434432234082905, 36.84864214488438, 37.97436843599592, 36.84218379429409, 38.18633018221174, 35.949562617710654, 34.44992944172451, 37.369006633758545, 37.010135650634766, 43.66150719778878, 45.65089109965733, 45.96239621298653, 48.568123544965474, 46.10780463899885, 47.85035726002285, 47.687168393816265, 45.102806772504536, 47.39596244267055, 45.63936056409563, 47.20054088320051, 48.23180988856724, 49.84052978243147, 47.67436981201172, 43.80373682294573, 42.018497943878174, 44.946934359414236, 46.49931131090437, 48.46082946232387, 51.547855036599294, 48.14936603818621, 50.251665115356445, 49.83757332393101, 45.80219159807478, 43.918375151497976, 44.80473600115095, 48.8574778011867, 51.54767785753523, 48.47472933360508, 39.51644468307495, 7.905103632381984, 1.1767327998365675, 10.985889724322728, 12.727419223104205, 12.701855063438416, 0.477322949894837, 3.6729189583233426, 57.00353193283081, 46.50352886744908, 44.25803089141846, 33.95816026415144, 33.426136698041645, 52.004834583827424, 35.29364572252546, 0.6934167029602187, 0.13410932517477445, 0.1248680582003934, 0.12651144287415914, 0.2051981362913336, 0.24020750341670855, 0.15404667891561985, 0.08173267104263816, 0.09725912647055728, 0.09495311842433043, 0.13146651270134108, 0.14448616121496471, 0.10932697355747223], [0.01859248037050877, 0.03298493414851172, 0.064088677455272, 0.02502213741120483, 0.05287196773237415, 0.025036788678594997, 0.018395983414458375, 0.010801984878656055, 0.060983735136687756, 0.029993897503507987, 0.08740085403301887, 0.03374638953911407, 0.05913210128034864, 0.08908072353473731, 0.08855671808123589, 0.0184452213080866, 1.6743060031107493, 25.800780568804058, 44.339998790196006, 35.722929750170024, 35.34932858603341, 50.04042598179409, 43.17475461959839, 41.007920673915315, 42.906297070639475, 50.0404120853969, 18.558445623942784, 0.07531811988779477, 3.1273672495569502, 1.161626547574997, 0.11568769652928625, 12.80353934424264, 49.37462527411324, 49.988724436078755, 48.37184040887015, 42.182815892355784, 40.665659359523225, 42.88554627554757, 46.65125451769148, 45.9351419040135, 46.11657673971993, 40.893004417419434, 46.214824267796104, 44.44168567657471, 43.992213657924104, 40.98846919195992, 39.531136648995535, 40.27402067184448, 40.69875710351126, 39.69177205221993, 42.2044734273638, 40.482536111559185, 42.922135489327566, 42.13308763504028, 42.59846060616629, 35.725837571280344, 32.925560678754536, 34.6767429624285, 33.33684539794922, 33.40256493432181, 34.20968852724348, 33.1973603112357, 34.09358065468924, 33.38441276550293, 32.988139629364014, 34.8018661226545, 34.4314090183803, 34.1249726159232, 34.724091461726594, 32.514310700552805, 35.008078234536306, 33.61435297557286, 34.22870227268764, 33.2535469191415, 34.87201166152954, 34.69775431496756, 35.56314550127302, 32.25421183449881, 35.48853921890259, 32.29176337378365, 34.22008303233555, 34.337653500693186, 35.464644363948274, 42.08154589789254, 45.06428943361555, 44.524355343409944, 48.42232601983206, 45.74643925258091, 52.35395377022879, 41.221880027226035, 41.470312867845806, 47.52179084505354, 44.08520139966692, 47.0269992010934, 45.272301128932405, 45.55158397129604, 40.62139238630022, 38.18731335231236, 34.53413813454764, 33.63798379898071, 32.53572504861014, 33.612105233328684, 32.11647769383022, 33.33338866915022, 33.11030633108956, 31.226343972342356, 34.297055176326204, 32.3350054877145, 33.62638030733381, 35.95778233664376, 33.857974188668386, 34.36180196489607, 32.97563982009888, 33.31376348223005, 33.67473629542759, 33.39768729891096, 34.106910773685996, 33.8843217577253, 32.40101337432861, 36.025110380990164, 43.44830172402518, 43.46078763689314, 42.87966462544033, 42.878281933920725, 44.537612506321494, 43.8349655015128, 42.18672425406319, 39.982380458286826, 42.06635366167341, 41.51772390093122, 43.0899727003915, 43.864512716020855, 45.739949635096956, 43.19753081457955, 45.85358394895281, 42.63277775900704, 40.455326965876985, 38.39327532904488, 44.77685635430472, 49.520228249686106, 48.04869358880179, 43.76040438243321, 45.31320169993809, 42.615230083465576, 42.82820279257638, 44.97275039127895, 48.549651759011404, 47.87265402930123, 29.49739592415946, 2.790022437061582, 0.659641509609563, 9.82430464880807, 6.731716173035758, 4.012377108846392, 0.13833545840212277, 2.9315989315509796, 44.96550689424787, 33.476841177259175, 22.906270469938004, 22.2776825768607, 30.221387795039586, 40.72909641265869, 13.502070409911019, 0.1834439778966563, 0.06370493197547537, 0.05944830538438899, 0.028341600272272314, 0.0518544773305101, 0.06705680675804615, 0.041324428083109, 0.01921796752139926, 0.025995796147201742, 0.025446576332407336, 0.025681921114612902, 0.022681145795754025, 0.011915677127295306, 0.02997249990169491, 0.0337325677807842, 0.030122741125524044, 0.02688500441477767, 0.028558120796723024, 0.02787228813394904, 0.06679926879171814, 0.03349325865773218, 0.07766674671854291, 0.06679054283137832, 0.050429340052817545, 0.1078441913372704, 0.05107747670263052, 0.0308531162195972, 0.019614608559225286, 0.03199332646493401, 3.009200756038938, 34.69967201777867, 47.07091876438686, 35.310404777526855, 44.959041595458984, 61.88027450016567, 46.36168834141323, 47.22364016941616, 47.4410388810294, 55.74682167598179, 18.81704889025007, 0.14730250223406724, 2.1056483260222842, 3.0902252197265625, 0.2212022803723812, 14.514109407152448, 49.9984484400068, 51.871644565037315, 52.04942812238421, 44.83500582831246, 42.68095309393746, 43.512683732169016, 49.01723773138863, 49.1738292830331, 46.693218163081575, 42.7148220879691, 46.367180892399375, 46.54790006365095, 46.53315946034023, 43.264980452401296, 41.57754789079939, 42.53248398644583, 42.01977293831961, 41.70021138872419, 44.28691107886178, 42.5359650339399, 44.31739977427891, 44.40140002114432, 44.495079108646934, 37.68848133087158, 36.46630709511893, 36.13051802771432, 35.71929931640625, 35.05492993763515, 35.26847587312971, 35.072494983673096, 36.54946313585554, 35.20603936059134, 35.94279159818377, 36.74236944743565, 36.25952870505196, 35.73798302241734, 36.04246698107038, 34.99503646578108, 36.7939841406686, 35.89705508095877, 35.50099039077759, 34.2508670261928, 37.213005678994314, 35.01665925979614, 36.41321243558611, 34.851649965558735, 35.335442611149375, 34.603078160967144, 35.640812465122764, 36.95765938077654, 37.32765442984444, 43.57040589196341, 46.96890531267439, 47.01671239307949, 48.550457750047954, 46.86876440048218, 47.41139439174107, 43.81869282041277, 42.404220240456716, 45.86947447913033, 46.178672790527344, 47.827553272247314, 46.61623559679304, 45.9093154498509, 40.64245237622942, 39.10779333114624, 36.19157879693167, 34.44487115315029, 34.21740797587803, 36.539450781685964, 35.53816325323922, 36.12505326952253, 34.73370776857649, 33.38434675761631, 35.95389829363142, 34.63514757156372, 35.19911200659615, 36.09925808225359, 35.957657269069124, 36.28638349260603, 34.38005835669381, 34.30736630303519, 35.61028208051409, 34.42669119153704, 35.55102436883109, 35.26298679624285, 33.4222526550293, 37.64253636768886, 44.4346992628915, 44.39270087650844, 46.406233242579866, 45.331993103027344, 46.06855773925781, 44.32042224066598, 43.60350711005074, 42.316735471997944, 44.42350918906075, 43.13518115452358, 45.90929113115583, 46.21104792186192, 47.03204706736973, 44.82062653132847, 45.626798221043174, 43.66673919132778, 41.030672550201416, 39.85337325504848, 46.389915398189, 49.73429530007498, 49.820977551596506, 45.58337892804827, 46.8609858921596, 44.708208152226035, 44.226541655404226, 47.89328670501709, 49.51818895339966, 49.20715979167393, 31.332039969308035, 4.03570134299142, 1.1327528740678514, 9.778426562036787, 7.631415826933725, 1.7144367354256767, 0.0851775933323162, 3.025586779628481, 50.30737229755947, 37.00627940041678, 31.989172799246653, 24.187063183103287, 33.95262254987444, 47.1480507169451, 17.05012025151934, 0.15339182476912225, 0.037005640898964236, 0.08839401216911418, 0.026717072086674825, 0.0019280097580381802, 0.04902050118627293, 0.03843265093330826, 0.010099406819790602, 0.026869815408385227, 0.017396089121965424, 0.044921959683831246, 0.08560567429023129, 0.010590231910880123, 0.14059530571103096, 0.14440134433763369, 0.23076606861182622, 0.11737699088241373, 0.13510322969939026, 0.10826317992593561, 0.1904300387416567, 0.14352426997252873, 0.19792718573340348, 0.10124545185161488, 0.12669900352401392, 0.10833041596093348, 0.09141613928867237, 0.1245437456028802, 0.16360579883413656, 0.22188272885978222, 3.084809750318527, 38.634791237967356, 56.41727767671858, 45.78169788633074, 45.73608991077968, 59.04150458744594, 50.002992561885286, 50.392324447631836, 50.441055638449534, 59.34675284794399, 23.305006742477417, 0.3709693710718836, 8.387337275913783, 5.3564700824873785, 0.28512106622968403, 17.371444906507218, 52.009878976004465, 54.90533229282924, 54.86745071411133, 46.160451139722554, 43.42272193091256, 45.52710199356079, 51.55032164709908, 49.29448822566441, 47.41184949874878, 41.89805439540318, 48.49474709374564, 47.052690165383474, 49.11117042813982, 45.34672328404018, 43.4401410647801, 44.34931632450649, 44.04158408301217, 42.642651149204795, 45.860104833330425, 43.8635573387146, 45.35027381352016, 46.806984492710654, 47.75767523901803, 41.08086633682251, 36.80302722113473, 38.47629935400826, 37.527828557150706, 37.00116205215454, 37.703763893672395, 36.467477866581504, 38.64048181261335, 36.406271185193745, 36.79052741186959, 38.611233370644705, 37.639253343854634, 37.62962661470686, 38.32889679500035, 36.39219413484846, 38.38590676443917, 36.91377803257534, 37.527251856667654, 35.72206122534615, 39.05522673470633, 36.72847999845232, 38.47484370640346, 36.340541226523264, 37.38203798021589, 35.42324004854475, 38.024315561567036, 38.49282217025757, 39.322510038103374, 46.942012310028076, 47.33102805273873, 48.00815085002354, 51.458879879542756, 47.53371742793492, 46.58379793167114, 46.92417975834438, 44.49000692367554, 46.26388202394758, 48.289101260049, 49.4594349861145, 49.40629516329084, 49.45230613436018, 44.3750524520874, 41.87036582401821, 39.04796239307949, 37.81091206414359, 36.91575132097517, 38.70205674852644, 37.060145309993196, 36.84637008394514, 35.67477525983538, 32.477856976645334, 38.524589334215435, 36.58329044069563, 36.59128086907523, 37.5029296875, 36.84566136768886, 37.42025307246617, 35.51980611256191, 36.422255516052246, 37.573120389665874, 36.99127129146031, 36.686551094055176, 37.0546875, 34.91727917534964, 39.38629797526768, 46.533816065107075, 46.23737812042236, 48.244434765407014, 45.63282578332083, 46.84754112788609, 46.57119042532784, 45.829584871019634, 43.57408496311733, 46.39015858513968, 43.83540323802403, 47.45694330760411, 48.7941449710301, 48.41601358141218, 46.40186282566616, 46.452942507607595, 44.275411810193745, 41.24023369380406, 40.699858392987935, 46.081627300807405, 50.536614213671, 50.892316818237305, 47.26414816720145, 48.70414842878069, 46.16734375272478, 46.26678984505789, 49.499929087502615, 52.61318758555821, 51.03499460220337, 35.15225682939802, 4.8706550768443515, 1.564223738653319, 21.09279932294573, 13.616794722420828, 10.110680733408246, 0.38373608887195587, 3.746046142918723, 56.70960576193673, 42.29234382084438, 34.53438479559762, 32.292941093444824, 41.1000885282244, 52.65218087605068, 22.393627166748047, 0.31391271842377527, 0.10538547219974653, 0.21720374136098794, 0.25789761702929226, 0.1944203810500247, 0.20032347286386148, 0.08797167840280704, 0.09822621529123612, 0.1414040108876569, 0.1220949941447803, 0.10488747499350991, 0.20997628489775316, 0.055337129559900076], [0.029930953202503066, 0.013897607518759156, 0.02058046414250774, 0.037584210745990276, 0.04017615684175065, 0.03711482396881495, 0.020692067886037484, 0.04321802254500134, 0.04159183534128325, 0.037317997709448845, 0.03465997926624758, 0.026238932207758938, 0.018941145589841262, 0.01229271528843258, 0.04165641151900802, 0.06171924674085208, 0.06526308586554867, 10.92385447025299, 44.7888628414699, 42.77491358348301, 25.399655852999004, 27.688882316861832, 32.375245979854036, 36.75129788262503, 38.13530608585903, 45.74624122892107, 25.634631769997732, 0.31779507866927553, 0.450940694127764, 2.1065915439810072, 0.31141416249530657, 7.133550039359501, 46.35153702327183, 48.2315354347229, 49.58178928920201, 43.860225677490234, 46.2386600630624, 43.82012414932251, 47.90259381702968, 44.23184313092913, 44.865796770368306, 41.44619219643729, 45.93594094685146, 44.57205125263759, 43.92031022480556, 40.57494715281895, 36.6690798486982, 39.42743478502546, 38.790962423597065, 41.44299602508545, 42.04648181370327, 42.474192074366975, 42.63134643009731, 44.267674991062705, 41.83175815854754, 40.90505954197475, 35.71982043130057, 33.581088474818635, 35.82614871433803, 35.62195158004761, 35.802507468632285, 33.99321740014212, 34.87674338476998, 35.533487115587505, 33.33915914808001, 35.463015011378694, 34.88230194364275, 33.134399209703716, 33.50650651114327, 36.08074113300869, 35.6671461377825, 33.68143783296858, 34.04345982415335, 34.110047885349815, 33.150407859257285, 34.57358653204781, 35.14999519075666, 34.16584192003523, 33.226977007729666, 32.65004028592791, 34.67888648169381, 32.901318413870676, 36.00874389920916, 43.2981025150844, 45.361922468457905, 47.07578945159912, 45.948663098471506, 48.35631813321795, 65.02607836042131, 34.57798474175589, 38.2081857408796, 46.95395973750523, 45.07743195125035, 46.299533230917795, 43.24093621117728, 40.775902952466694, 39.82468066896711, 37.62050362995693, 34.0206732068743, 32.67329590661185, 31.186402252742223, 32.547589097704204, 31.551988669804164, 32.17623567581177, 33.45826864242554, 31.39526162828718, 32.37380075454712, 33.5774302482605, 33.68274409430367, 34.02011387688773, 33.71346208027431, 33.727097920009065, 34.16938202721732, 35.254603794642854, 34.279768058231895, 33.11346776144845, 32.19504792349679, 32.83562319619315, 31.90309156690325, 34.529177120753694, 43.125874042510986, 44.08147369112287, 44.588594913482666, 45.32446125575474, 45.573762621198384, 41.22851208278111, 40.84294612067086, 40.5686069216047, 38.59620789119175, 39.111844130924766, 40.758160727364675, 41.87628221511841, 43.95392908368792, 44.708319323403494, 44.96009772164481, 44.78781018938337, 42.919321468898225, 44.015708991459434, 38.87798513684954, 40.945588384355815, 46.36591979435512, 46.09475939614432, 45.81259652546474, 42.92791291645595, 45.918278626033235, 45.678381647382466, 47.39811985833304, 44.387291703905376, 28.958170550210134, 9.46111970288413, 0.9199292255299432, 6.134645743029458, 5.556522182055882, 0.4919008676494871, 0.08191253710538149, 4.726641935961587, 46.17994778496878, 37.75051832199097, 25.816209043775284, 24.30333607537406, 34.68014757973807, 38.55239602497646, 7.7684334346226285, 0.15151958380426678, 0.022076713586492196, 0.02167425750355635, 0.04256826758916889, 0.04909698226089988, 0.008708401549873608, 0.04177976579272321, 0.04956721381417342, 0.010111192973064525, 0.01954311641332294, 0.025807175286380307, 0.027446207158001404, 0.03153148160449096, 0.013889158061439437, 0.039190961314099174, 0.03532811234306012, 0.05547163216397166, 0.014747627844501818, 0.05215114980403866, 0.020044097477304082, 0.058282751856105666, 0.07971117951508079, 0.0035160295789994833, 0.03934362490794488, 0.05346519054312791, 0.03410449318055596, 0.0514414089598826, 0.029885365827275173, 0.03345558978617191, 0.0353088928386569, 18.2164466040475, 53.14102486201695, 44.785736152103965, 28.060777698244365, 36.34067324229649, 39.14067220687866, 40.04195778710501, 45.545865603855674, 50.7456750869751, 28.630717584065028, 0.05198163140032973, 0.2819970095796244, 2.748855011803763, 0.4995524084993771, 8.361290216445923, 50.016423429761616, 48.47436802727835, 50.91866091319493, 45.27855103356497, 47.34095008032662, 45.856338909694124, 47.86977400098528, 45.6303174836295, 46.585983140128, 41.40424244744437, 47.5123621395656, 46.76974214826311, 46.56168181555611, 42.36900329589844, 38.988086291721885, 40.39785841533116, 39.63305977412632, 42.31510959352766, 43.25994995662144, 43.92207159314837, 44.78292213167463, 45.47320481709072, 42.40682234082903, 42.09562642233712, 37.11411544254848, 36.05516133989607, 36.64207220077515, 35.79321077891758, 38.45878641945975, 35.505256584712434, 36.51432956968035, 37.24670444216047, 36.092598233904155, 37.189440863473074, 37.05049078805106, 34.74277169363839, 36.10536207471575, 36.19467421940395, 36.73390654155186, 34.33730609076363, 35.31983348301479, 35.31712021146502, 35.216291427612305, 35.83938503265381, 36.99970987864903, 35.77669838496617, 34.82530239650181, 33.09415871756417, 36.90133033479963, 34.61649860654558, 38.120381355285645, 44.51322085516793, 46.6283324105399, 47.79247876576015, 47.83158322743007, 46.13579198292324, 57.9455999646868, 37.219651630946565, 41.826432364327566, 48.75993551526751, 47.13902848107474, 46.89281211580549, 44.130145822252544, 42.6238944871085, 41.79548856190273, 39.6592892238072, 34.78889730998448, 34.14788430077689, 33.69359370640346, 35.57220942633492, 34.171661036355154, 34.585405417851035, 34.840828146253315, 33.133902413504465, 34.48040076664516, 36.15794256755284, 35.44692645754133, 36.14409828186035, 35.16969680786133, 33.74885620389666, 35.32988405227661, 36.68398026057652, 35.09715414047241, 34.17850153786795, 33.99308885846819, 35.09138713564192, 33.69247852052961, 35.11379507609776, 44.701468399592805, 46.16989721570696, 46.269381523132324, 45.26182671955654, 46.81375898633684, 43.54998166220528, 42.45261096954346, 40.87231963021414, 41.219232763562886, 40.53792715072632, 42.918901102883474, 43.40477820805141, 46.03039475849697, 45.070511545453755, 47.16829776763916, 45.71925095149449, 43.95761857713972, 42.8199587549482, 38.89758253097534, 42.70080409731184, 49.04791750226702, 46.9954126902989, 49.01571954999651, 45.26457125799996, 47.41734899793352, 47.94991452353341, 51.46042585372925, 48.25450617926461, 30.374189104352677, 9.833383338791982, 4.454196555273874, 9.576901010104589, 7.687583327293396, 3.6333793657166615, 0.030461621869887625, 4.594018629619053, 52.32110268729073, 40.865281105041504, 29.610710620880127, 27.225599016462052, 39.06804616110665, 45.02348961148943, 11.392090099198477, 0.3153724100972925, 0.04781859175169042, 0.01966105428125177, 0.07097233379525797, 0.03881803507517491, 0.008381891347068762, 0.022168918013838784, 0.05520876091239708, 0.02765606277223144, 0.02399982262535819, 0.030801486490028243, 0.09726637322455645, 0.024808397183993032, 0.09622056077101401, 0.14577407496316092, 0.12945803547544138, 0.13866846981857503, 0.2084440171186413, 0.18679598160088062, 0.1352525752569948, 0.18052274893437112, 0.17782867992562906, 0.10360028049243347, 0.12698493818087236, 0.1596719649221216, 0.07552597552005734, 0.08663490334791796, 0.11770487257412501, 0.21315898054412433, 0.10514947093491044, 21.558651719774517, 60.926828793116975, 52.14523335865566, 36.50802755355835, 38.738041469029014, 40.483557496752056, 46.4449451310294, 47.26980400085449, 54.53526081357683, 32.573384284973145, 0.4538135842553207, 2.7264976629189084, 5.092796802520752, 0.6863101071545056, 8.868009311812264, 52.70329877308437, 49.78448908669608, 53.01156949996948, 48.48238624845232, 50.28657981327602, 47.483054637908936, 50.568148612976074, 48.17435870851789, 47.10341201509748, 42.19363423756191, 50.212442534310476, 47.250442845480784, 49.05185713086809, 42.90475109645298, 40.01756961005074, 42.391022137233186, 40.90538610730852, 45.824252128601074, 45.78260115214756, 46.4977444921221, 46.91714818137032, 48.889359610421316, 44.27320923124041, 44.88411569595337, 38.58784226008824, 37.341582093920024, 39.59646361214774, 38.57202468599592, 40.28200415202549, 37.82499953678676, 38.93174682344709, 38.561668395996094, 36.64148160389492, 39.08759491784232, 38.44080448150635, 36.610315459115164, 36.596356528145925, 38.254728249141145, 38.69096047537667, 36.67916168485369, 36.569609437670024, 37.72196469988142, 35.67880521501814, 37.349430084228516, 39.04919222423008, 37.86279773712158, 36.540934222085134, 36.71595587049212, 39.32223211015974, 36.376230648585725, 40.30640275137765, 46.495406423296245, 46.817302567618235, 47.64318977083479, 48.98273645128523, 46.539961746760774, 60.45856189727783, 39.03298902511597, 45.13487270900181, 48.635389055524556, 48.308007308415, 50.168793950762065, 46.463997091565815, 44.18231289727347, 42.980618476867676, 41.69920737402779, 38.46816301345825, 36.376032624925884, 35.089566707611084, 37.159410749162944, 35.52545152391706, 35.76025547300066, 37.54011297225952, 34.84188774653843, 35.71167714255196, 37.45107875551496, 37.52299608503069, 37.795903955187114, 36.95006499971662, 36.26999616622925, 35.76055424554007, 38.77439444405692, 35.78839220319475, 36.35492747170584, 34.670934268406455, 36.64035946982247, 35.81834588732038, 36.418909958430696, 47.43100915636335, 48.663779394967214, 46.80521617616926, 47.0574357850211, 48.18035152980259, 43.629878997802734, 44.59508453096662, 43.658554213387625, 42.16715465273176, 41.810215268816265, 44.883896827697754, 45.367540087018696, 47.84258222579956, 46.65556934901646, 49.594118867601665, 46.05827440534319, 45.23211622238159, 43.25864369528634, 41.571791308266775, 41.679787158966064, 48.86695514406477, 48.95989772251674, 49.376737526484895, 47.48339857373919, 48.65050138745989, 50.29477521351406, 51.65530545370919, 48.06993423189436, 33.870508738926475, 12.384289383888245, 4.596987681729453, 16.377251488821848, 16.423404897962296, 7.670944997242518, 0.19527078898889677, 5.3954134328024725, 57.33807727268764, 46.44706085750035, 37.56338248934065, 33.353083338056294, 45.23548262459891, 51.53660242898123, 14.966112307139806, 0.4021402384553637, 0.1422725628529276, 0.10691366876874651, 0.18208721998546804, 0.13998746047062532, 0.09396298655441829, 0.09835371880659036, 0.18631948716938496, 0.07905671213354383, 0.10112512723675796, 0.1384660221104111, 0.15592787654272147, 0.10971888859889337], [0.03435577844668712, 0.09438917439963136, 0.03724932996556163, 0.03624628896691969, 0.05879391942705427, 0.08274898079356977, 0.06022540439984628, 0.08770040688770157, 0.029701845853456428, 0.025373165628739765, 0.04215740445735199, 0.05359315546229482, 0.021092564699106982, 0.019307391651506935, 0.023142882090594088, 0.04319974959694913, 0.052008039983255525, 1.2137207750763213, 33.117685317993164, 43.07704905101231, 30.54105704171317, 34.34457043239048, 32.75937713895525, 38.000851494925364, 46.60821042742048, 45.4943516595023, 34.433198179517476, 1.431676211101668, 0.35827137529850006, 2.8324244703565324, 3.3991186789103915, 24.145179441996984, 34.32270792552403, 47.328683035714285, 48.61193541118077, 44.385627610342844, 44.540040901729036, 46.76421138218471, 45.2284197807312, 42.006929193224224, 41.83498559679304, 41.619313512529644, 45.42207997185843, 44.58762216567993, 42.083077975681846, 38.615746225629536, 37.37928649357387, 39.412826197487966, 38.59915392739432, 41.287036759512766, 39.38226107188633, 41.582314355032786, 41.277559416634695, 43.7686379977635, 43.71174962180001, 42.037278924669536, 39.51820257731846, 37.16692522593907, 33.316525391169954, 33.955745765141074, 34.58972372327532, 34.54563045501709, 31.872905118124827, 34.96161215645926, 34.21734891619001, 35.29197120666504, 35.51265294211251, 35.040397780282156, 35.50471462522234, 35.24393483570644, 35.577434471675325, 33.71386160169329, 31.833866664341517, 33.54949501582554, 33.36541639055525, 34.28647654397147, 33.20183147702898, 34.08993979862758, 34.25448703765869, 35.11003262656075, 33.61634363446917, 35.2538742337908, 35.78326095853533, 40.33096463339669, 44.70745774677822, 46.47937345504761, 45.20886754989624, 44.25122513089861, 34.31513091496059, 40.552125794546946, 32.542034012930735, 45.85076992852347, 46.94831780024937, 43.903797830854145, 44.169927733285085, 40.110706738063264, 39.85480458395821, 38.47269671303885, 33.88354703358242, 32.899164472307476, 32.88140140260969, 32.97353799002511, 31.805399894714355, 33.38259581157139, 33.07570777620588, 32.967774459293906, 33.60957261494228, 35.12489134924752, 33.48764910016741, 33.263093744005474, 32.037949153355186, 33.84509917667934, 33.21554027284895, 33.30784361703055, 33.19480684825352, 33.784396239689414, 31.94031306675502, 31.622089045388357, 33.114186900002615, 35.01828513826643, 42.02771125520979, 45.130384172712056, 43.567974022456575, 44.32781164986746, 45.24584238869803, 43.32111494881766, 41.185016359601704, 38.33918360301426, 35.44900049482073, 35.32940810067313, 36.15033776419503, 38.67701891490391, 41.566302231379915, 42.822463580540244, 44.37207167489188, 44.541833536965505, 43.32639210564749, 44.21883610316685, 44.38312973294939, 43.897200516292024, 44.18662772859846, 43.015689509255544, 46.283823353903635, 48.19599539893014, 47.59243318012783, 47.762691838400706, 48.378132002694265, 38.8806289264134, 23.558589935302734, 5.579494229384831, 3.1402685344219208, 7.644398536000933, 4.933980958802359, 1.176882620368685, 0.05692834846143212, 4.148016801902226, 45.562450953892295, 37.242066519601, 22.98110604286194, 16.351567472730363, 31.41326788493565, 32.262542724609375, 2.865675074713571, 0.0870210983391319, 0.0515251978566604, 0.052634463512471745, 0.07713427993335895, 0.06667736997561795, 0.027523553364777138, 0.12201355637184211, 0.04491495720243879, 0.04592163175610559, 0.03636128708188023, 0.006901798670047096, 0.022125803898753862, 0.02549318320650075, 0.010297608595075352, 0.043818719418985505, 0.019403294094705155, 0.0542422386684588, 0.034499197000903745, 0.004900990586195673, 0.04631426265197141, 0.08723560361457722, 0.020556891835959892, 0.011742624404307987, 0.026391650084406137, 0.05517425062134862, 0.02330101976570274, 0.08238358968602759, 0.027603247302717397, 0.019097839681697742, 0.1011099959058421, 2.571867891720363, 42.70768281391689, 48.25483621869768, 33.147534779139924, 36.13466957637242, 40.088997091565815, 42.93943302971976, 47.85138559341431, 49.21416704995291, 35.78257308687483, 1.0446351681436812, 0.804633369403226, 1.6793548464775085, 3.9034667015075684, 20.87073837007795, 38.4408392224993, 50.52581671306065, 51.4089674949646, 46.00826474598476, 47.180641242435996, 47.21500703266689, 47.585839339665, 43.14833409445626, 43.399831090654644, 41.62846776417324, 47.14767551422119, 47.099503653390066, 44.14540754045759, 41.03847885131836, 39.23224251610892, 41.29190397262573, 40.23939779826573, 43.21643338884626, 42.799485887799946, 43.35485887527466, 43.20223821912493, 46.08021681649344, 44.8343631199428, 42.16073799133301, 41.50592238562447, 38.32216051646641, 33.97291823795864, 35.96122169494629, 36.17678260803223, 36.499217237745015, 33.62402139391218, 37.31189244134085, 35.6255646433149, 36.04261289324079, 36.34682934624808, 35.337151868002756, 36.58584042957851, 36.272257804870605, 37.064046723502024, 36.30387210845947, 33.32185465948922, 35.376544679914204, 35.207706928253174, 36.03434106281826, 34.140362875802175, 36.62465654100691, 37.255556447165354, 36.54837226867676, 36.26303407124111, 35.86874117170061, 37.93669877733503, 41.81285558428083, 45.595055375780376, 46.22833503995623, 46.59337602342878, 44.85059411185128, 38.716717447553364, 40.82817077636719, 35.322487694876536, 46.72030224118914, 49.21307965687343, 45.89917802810669, 45.011024543217246, 41.95402908325195, 42.07599081311907, 41.07875755855015, 34.66093928473336, 35.27569505146572, 34.84117555618286, 34.908183983394075, 33.55544267381941, 34.87417949948992, 35.046314171382356, 34.80752543040684, 34.60920647212437, 37.42771543775286, 36.02757699148995, 35.08812148230416, 32.972867488861084, 35.78910786764962, 34.56893818719046, 34.1487979888916, 34.90867035729544, 35.03118794304984, 34.24851506096976, 34.22856330871582, 34.775629724775044, 35.56118263517107, 44.15079239436558, 45.5210987499782, 45.96891014916556, 46.10821805681501, 46.40997832162039, 45.74023103713989, 42.264075074877056, 39.97475133623396, 37.90842655726841, 37.47538355418614, 38.52424887248448, 41.35249573843819, 43.14301872253418, 44.51802206039429, 46.247446060180664, 45.277137075151714, 45.42621415002005, 45.33937208993094, 45.92461538314819, 44.406875201633994, 43.93177475248064, 42.98195253099714, 48.106134346553254, 49.61396639687674, 49.720784527914866, 50.560575076511924, 49.025370597839355, 40.75788974761963, 26.810518843787058, 7.061228845800672, 3.3382012162889754, 9.420421498162405, 8.738130978175572, 3.0423460517610823, 0.05068992803405438, 4.844145962170192, 50.81562955038888, 42.15638147081648, 31.029654366629465, 19.300579241343907, 38.028842312949045, 39.172651290893555, 4.2509022525378635, 0.16948687897196837, 0.034902324833508046, 0.04474196130675929, 0.05877435047711645, 0.0382950236754758, 0.01114084865964417, 0.06315611928169217, 0.03915584373420902, 0.06193236780485936, 0.01092615254622485, 0.01858943374827504, 0.059217922389507294, 0.12188421402658735, 0.11718511474984032, 0.22684271128049918, 0.08963769900479487, 0.2323396456028734, 0.14870967529714108, 0.11292088856654507, 0.15819265001586505, 0.2016124315559864, 0.1153349397437913, 0.11180226252015148, 0.08707901808832373, 0.15741951364491666, 0.11369834720556225, 0.21600690058299474, 0.11480447463691235, 0.11587936910135405, 0.1941242819385869, 3.3300079873629977, 49.19512551171439, 54.20146240506853, 40.10115991319929, 43.11336381094796, 43.777038369859966, 47.13653755187988, 54.223526409694124, 54.006610597882954, 40.982966218675884, 1.7240881089653288, 1.3332664860146386, 8.51114809513092, 4.560473595346723, 32.161439486912315, 42.23028598512922, 50.315849099840435, 53.10185439246041, 47.03918981552124, 50.75772326333182, 48.96218367985317, 48.6436574118478, 45.65594244003296, 42.68301323481968, 41.82953473499843, 49.96903671537127, 49.2377735546657, 45.69451189041138, 42.61369105747768, 41.28310407911028, 43.708866119384766, 42.838989870888845, 46.819171633039204, 44.167509760175435, 45.0371949332101, 46.49494089399065, 48.606835433415, 47.996828760419575, 44.75920792988369, 43.29445471082415, 40.61998190198626, 36.74273075376238, 37.49992111751011, 38.80373321260725, 37.94861493791853, 34.45504331588745, 39.13923045567104, 37.77649416242327, 38.84138550077166, 39.08504145486014, 37.47583171299526, 38.7038493837629, 38.67444460732596, 39.48759923662458, 37.51900087084089, 34.95225640705654, 36.769404888153076, 36.6771571295602, 37.59720632008144, 36.86356340135847, 37.895926748003276, 38.27771289008004, 38.811852182660786, 38.085442338671, 37.87065267562866, 39.77991342544556, 42.85853167942592, 47.76535299846104, 47.687786783490864, 47.30136619295393, 47.20690195901053, 43.62231240953718, 40.662178312029155, 38.74394048963274, 48.95792096001761, 49.904421942574636, 48.441013199942454, 46.40486444745745, 43.16077136993408, 46.36374848229544, 42.430029324122835, 36.93012366976057, 37.12822723388672, 36.63476964405605, 37.414215087890625, 34.60576016562325, 36.549244267599924, 36.612736906324116, 36.52480397905622, 36.07959120614188, 39.59369475500924, 37.92950391769409, 36.13135181154524, 34.29104151044573, 37.06916407176426, 35.8087990624564, 35.596045221601216, 35.19363682610648, 36.97529738289969, 35.514570644923616, 36.39319814954485, 35.08651992252895, 37.14381899152483, 45.20456314086914, 47.909569808415, 47.85164615086147, 47.8388614654541, 48.82643672398159, 47.078315121786936, 44.731147629874094, 42.11341381072998, 40.00321115766253, 38.8300529888698, 39.814272267477854, 42.48460742405483, 44.731363024030415, 47.69934163774763, 48.55693347113473, 47.67135429382324, 47.294417994362966, 48.46405690056937, 48.592838287353516, 47.21185255050659, 45.327587945120676, 43.31924588339669, 48.240192890167236, 52.3364234651838, 51.44931221008301, 53.89201395852225, 49.6291377885001, 43.15013367789132, 30.203308582305908, 7.698382564953395, 8.113485319273812, 14.674491201128278, 12.504002502986364, 5.387668362685612, 0.16590825814221585, 5.130381345748901, 56.615252699170796, 46.841520513807026, 33.735560825892854, 22.56665641920907, 42.10205350603376, 46.02028512954712, 5.965999066829681, 0.25300836509891916, 0.1663202103227377, 0.15290842285113676, 0.15684811930571282, 0.11892318220010825, 0.08937147579022817, 0.21456901702497685, 0.13234208071870462, 0.12774254967059406, 0.06411982221262795, 0.1228627972304821, 0.13126420070018086, 0.18794556920017513], [0.021602487158296362, 0.015151383321998375, 0.04588395270652004, 0.07964383491447993, 0.036606584276471815, 0.03978864888527563, 0.01918387961839991, 0.017743458339412297, 0.03144492767751217, 0.08140018888350044, 0.030064149626663754, 0.06968123093247414, 0.014555599041549223, 0.07098110046769891, 0.09039295597800187, 0.04996362075741802, 0.07761953425194536, 0.18072766651000294, 13.883152178355626, 47.43274968011038, 39.06286975315639, 25.98289806502206, 25.118307658604213, 37.64868899754116, 45.8438286781311, 45.837491921016145, 40.956684657505576, 6.902512013912201, 0.6066104152372905, 1.069258606859616, 4.668677892003741, 29.35968610218593, 23.266791650227137, 37.447715827396934, 50.57675395693098, 49.04712540762765, 47.26685101645333, 46.05029787336077, 43.113968304225374, 45.07851587023054, 43.239873136792866, 40.973002501896445, 46.93348339625767, 41.70835815157209, 39.085989883967805, 36.93533829280308, 39.072048323495046, 39.215698855263845, 39.505848680223735, 40.24485213415963, 40.6799761227199, 41.11470406396048, 43.664255210331504, 40.97882161821638, 43.23011786597115, 41.99338715417044, 40.81498656954084, 39.7213123185294, 37.42629453114101, 34.34131867544991, 35.150769914899556, 34.45805883407593, 34.238718100956504, 33.45831380571638, 35.23903635569981, 35.50094870158604, 34.53997809546334, 33.68387317657471, 34.93046685627529, 34.295985153743196, 34.417985098702566, 33.54725769587925, 33.9508055959429, 34.254275117601665, 32.88734906060355, 34.14134604590279, 35.18391629627773, 35.218942165374756, 37.13182292665754, 36.29155642645699, 38.3091847555978, 33.407595430101665, 35.99060215268816, 36.52852126530239, 46.047688824789866, 44.370570863996235, 48.97261987413679, 36.96986389160156, 23.04125486101423, 42.35472127369472, 35.60909046445574, 39.381243160792756, 47.26927593776158, 44.67174053192139, 43.92779343468802, 43.57070466450283, 41.11961644036429, 39.106021540505544, 37.81422635487148, 35.70832463673183, 34.04793446404593, 33.60059206826346, 31.48731483731951, 31.584294319152832, 33.07365458352225, 32.76652683530535, 33.78473670142037, 33.97262988771711, 35.065136841365266, 34.377338136945454, 35.06086022513253, 32.56630754470825, 33.74561139515468, 35.558260917663574, 33.59529754093715, 32.824259417397634, 33.121235847473145, 32.96382440839495, 33.62117958068848, 35.70603173119681, 41.48857273374285, 42.7554030418396, 44.14815902709961, 44.20308106286185, 42.889402525765554, 40.55661085673741, 39.079934528895784, 37.55255024773734, 34.84764085497175, 34.73859930038452, 34.16283335004534, 34.01750135421753, 38.32353973388672, 38.83083118711199, 40.652402196611675, 41.922953265053884, 41.33216878346035, 43.463101387023926, 42.921680382319856, 45.46717030661446, 46.691682611192974, 45.053516251700266, 43.550558362688335, 45.95893253598894, 47.320477213178364, 48.5435026032584, 44.38738897868565, 30.264796665736608, 5.849611529282161, 0.10538330767303705, 8.605541110038757, 5.4752451947757175, 4.879264763423374, 2.801946197237287, 0.06110096563185964, 8.612886224474225, 47.80963734218052, 28.919842549732753, 19.042394604001725, 20.841599362237112, 35.99146025521414, 21.69057195527213, 0.43630385239209446, 0.04369957545506103, 0.06343325333935873, 0.009222634402768952, 0.008169721928425133, 0.02807094113502119, 0.040437138373298306, 0.015611587824033839, 0.011299865885770746, 0.042474538154367886, 0.02763941152287381, 0.0809598264417478, 0.06955328636935779, 0.029062268922903707, 0.07450758945196867, 0.07098074084413902, 0.04936172966180103, 0.01471759588457644, 0.07448685342179877, 0.043272939776735644, 0.024154175771400332, 0.07226121106318065, 0.008464376608441983, 0.018495938408055475, 0.026516846580696956, 0.02706157279733036, 0.0069610322326687825, 0.0040615596475877935, 0.040717634571982284, 0.01927232665808073, 0.16071082917707308, 0.18778821692935058, 19.811290945325577, 52.35171297618321, 41.55857236044747, 32.90169709069388, 35.7440071105957, 42.694773060934885, 51.4894380569458, 49.953729833875386, 44.20052759987967, 6.2609809296471735, 0.49881188252142494, 2.7365766763687134, 5.105522862502506, 36.369859150477815, 29.611516611916677, 41.20529120309012, 52.303621019635884, 50.83353158405849, 50.22635282788958, 48.25623280661446, 45.42098910467965, 44.16723183223179, 42.97931221553257, 44.951075485774446, 48.85211379187447, 45.1162063734872, 41.016248089926584, 39.941476413181846, 40.12748663766043, 40.266888345990864, 41.14438329424177, 42.689523696899414, 43.528786182403564, 43.63616016932896, 44.24613904953003, 43.77042368480137, 44.695604119982036, 42.65782601492745, 43.327399594443186, 41.892245701381135, 39.20624235698155, 35.68147332327706, 35.98350804192679, 35.828097684042795, 35.83435106277466, 35.4316543170384, 36.517491000039236, 36.567448547908235, 36.736046586717876, 35.55491883414132, 35.88840804781233, 35.118662289210725, 36.778784956250874, 35.48865039008004, 35.770889690944124, 34.80067450659615, 34.35496493748256, 35.083316802978516, 36.718731675829204, 37.92698866980416, 38.79549959727696, 37.60802813938686, 39.03587947572981, 36.126196248190745, 38.0975148337228, 39.06466586249215, 48.71031148093087, 47.31739221300398, 50.13039820534842, 36.814696720668245, 23.652413197926112, 43.62373679024832, 38.15293713978359, 42.44755615506853, 48.06040130342756, 46.473832266671316, 46.73451478140694, 45.02728680201939, 41.924523557935444, 41.134892054966514, 40.14262676239014, 37.98336287907192, 36.37157188143049, 34.3062059538705, 34.224811281476704, 33.922707080841064, 34.71181399481637, 33.92257506506783, 34.05531692504883, 34.82928718839373, 36.30285767146519, 34.71956123624529, 35.29419463021414, 34.184146949223106, 34.82314498083932, 36.619049344744, 33.416652406964985, 33.87046010153634, 32.98578071594238, 33.85362809044974, 34.86072431291853, 37.194551263536724, 42.14859601429531, 44.66660581316267, 44.826813902173726, 45.92475087302071, 44.67997762135097, 42.25333315985543, 39.437332493918284, 38.50120517185756, 37.141515663691926, 34.828891141074045, 36.78994376318795, 36.19279473168509, 39.639476435525076, 41.63920273099627, 43.45217187064034, 44.3831227847508, 43.709456716264995, 45.31617900303432, 44.45988300868443, 46.7005033493042, 47.359880447387695, 45.23978703362601, 44.88344866888863, 46.40056003843035, 47.848356178828645, 49.57532746451241, 46.57442133767264, 34.74177810123989, 8.765687533787318, 0.8340150756495339, 11.292152421815054, 9.26603513104575, 9.100693191800799, 2.0688593515328, 0.059933953253286223, 8.968474183763776, 50.99089091164725, 34.7941049848284, 25.427188089915685, 18.6600786617824, 41.579371792929514, 28.21373360497611, 1.0881821342876978, 0.09847167533423219, 0.046662829483726194, 0.04098819362531815, 0.043612838323627195, 0.02238770484525178, 0.05316042993217707, 0.043214629869908094, 0.0654714232576745, 0.05298754260210054, 0.06831146550497838, 0.07028021450553622, 0.07645245401987008, 0.03916094971022435, 0.15918169622974737, 0.1029950204704489, 0.17174283148986952, 0.25233034576688496, 0.22101672818618162, 0.14593244503651345, 0.07426947794322457, 0.19653023140771048, 0.07763693867517368, 0.09205584174820355, 0.12486136784510952, 0.16379003466239997, 0.14506193889038904, 0.1399999183735677, 0.1799659023859671, 0.1502101740666798, 0.3457067795097828, 0.37926169325198444, 22.397042206355504, 61.16396386282784, 50.84541647774832, 36.489354269845144, 36.15726859228951, 47.969678674425396, 55.07528175626482, 54.208160468510215, 48.735641138894216, 8.483142512185232, 0.9868829356772559, 7.104252091475895, 10.194067801748004, 33.68324089050293, 30.821677412305558, 40.507636478969026, 51.910276549203054, 51.87338508878435, 51.78491367612566, 49.620907647269114, 45.1843056678772, 45.3546268599374, 44.79604033061436, 45.36266939980643, 51.47894627707345, 46.549077783312114, 42.62116037096296, 41.531564712524414, 42.78530808857509, 42.39993667602539, 43.09761571884155, 44.49793829236712, 44.67327608380999, 45.93593052455357, 47.090352875845774, 44.75346524374825, 46.53449004037039, 45.62358815329415, 44.73887055260794, 44.50630044937134, 40.45744964054653, 38.49092183794294, 37.33057267325265, 37.78824009214129, 38.23162201472691, 37.187262603214805, 38.25218173435756, 38.92003910882132, 38.77435622896467, 36.11147996357509, 38.62170778002058, 38.29331507001604, 38.42934342793056, 36.999237401144846, 37.92976794924055, 37.01025029591152, 36.14273990903582, 38.20223808288574, 39.22693061828613, 39.11250420979091, 40.51806919915335, 39.370094776153564, 41.88784054347447, 38.56626115526472, 39.62535074778965, 41.67513186591012, 48.44865274429321, 47.92200360979353, 51.601192883082796, 40.39293909072876, 29.455223832811626, 42.607451575142996, 39.285243374960764, 46.23612744467599, 49.95320177078247, 46.47411019461495, 49.07654755456107, 46.45688908440726, 44.7272218976702, 43.027001176561626, 41.84760699953352, 39.57703644888741, 38.723953996385845, 37.39646244049072, 36.13877943583897, 33.88740675789969, 37.00338894980294, 36.24267932346889, 36.9571521622794, 37.542652538844514, 39.053232601710725, 37.33315740312849, 36.91447980063302, 35.546237060001914, 37.41037620816912, 39.111604418073384, 34.91660172598702, 34.65473454339163, 34.46380499431065, 35.58563682011196, 36.88599566050938, 39.834432465689524, 44.771287373134065, 46.39878477369036, 46.430312224796836, 47.97101967675345, 47.04120479311262, 44.09061404636928, 42.375201089041575, 40.861035755702424, 38.89884015492031, 37.91665669849941, 38.158325467790874, 37.79598385947091, 41.32054444721767, 42.615897110530305, 45.162762778145925, 46.871481146131245, 44.30144323621477, 46.640609877450125, 45.714557443346294, 49.04979351588658, 50.17703104019165, 45.1362658228193, 44.73500735419137, 45.67373330252511, 48.25202219826834, 51.387997831617085, 46.40371799468994, 38.74371467317854, 9.224654265812465, 0.6510818717735154, 15.827009746006556, 15.35191103390285, 15.77771748815264, 7.027186581066676, 0.19975177996924945, 10.474273885999407, 57.873863288334434, 37.70471927097866, 29.331122057778494, 28.292962176459177, 48.159791810171946, 34.43077325820923, 1.5676272703068597, 0.1897364402455943, 0.161397750888552, 0.13158631484423364, 0.16057571928415978, 0.11200912070593663, 0.13516030806515897, 0.15365502850285598, 0.10655294598213264, 0.18987130586590084, 0.17655930375414236, 0.13497558369168214, 0.1558024968419756, 0.09440967972789492], [0.0120755772971149, 0.02544017944351903, 0.09873914026788302, 0.06501221111310379, 0.04465142098654594, 0.02742910129018128, 0.017730355828202198, 0.07156933604606561, 0.05476705836398261, 0.01889899160180773, 0.06000505015254021, 0.028453210801152245, 0.04303181557250874, 0.039982964351241074, 0.03646561862634761, 0.01641216584747391, 0.10573769294257675, 0.019265271590224335, 2.176231167146138, 33.349928855895996, 45.95995739528111, 27.58602465902056, 25.512037754058838, 36.670024803706575, 43.0852027620588, 44.89629936218262, 44.47254957471575, 11.00653542791094, 0.3677077075200421, 0.4093307283307825, 5.25626620224544, 2.3641000347478047, 4.7628563812800815, 31.450670037950786, 48.340177467891145, 46.678786754608154, 47.85237571171352, 44.27961894444057, 43.79151841572353, 42.73689998899187, 39.56419617789132, 41.050172669546946, 44.19551794869559, 42.07533768245152, 38.64799976348877, 38.04723072052002, 37.25889505658831, 37.10559695107596, 39.13857732500349, 38.11078936713082, 40.45179728099278, 41.7822140284947, 41.09057991845267, 42.09425415311541, 42.41167565754482, 42.426419734954834, 42.104884896959575, 43.37085015433175, 42.2028614452907, 34.568100929260254, 33.85223497663225, 36.08061259133475, 32.23149469920567, 33.72047628675188, 33.17013726915632, 35.40339251926967, 35.34144238063267, 35.57786178588867, 35.74179758344378, 34.28090408870152, 36.04407548904419, 32.29900687081473, 34.5968143599374, 32.19015986578805, 33.5323121207101, 34.048222814287456, 34.937915325164795, 38.934734548841206, 39.98417656762259, 38.36763300214495, 38.548977511269705, 37.32641070229666, 35.05030591147286, 33.31221055984497, 39.38692331314087, 44.615005016326904, 45.71396337236677, 45.004531451633994, 44.485306467328755, 41.3241331917899, 39.210150718688965, 39.320557594299316, 47.149693965911865, 47.75214794703892, 46.19759620938982, 44.88782950810024, 45.050813402448384, 42.135582038334434, 40.418042932237896, 37.737789222172324, 35.67018597466605, 33.94076892307827, 31.740739958626882, 30.98495660509382, 31.97880608694894, 33.604385784694124, 32.573665687016074, 33.03547075816563, 34.24722964423043, 32.21885940006801, 32.76437636784145, 33.392615113939556, 32.79944045203072, 32.152024677821565, 34.492733819144114, 31.805285249437603, 33.163699763161794, 31.31610427583967, 33.054682527269634, 35.32761893953596, 37.45856891359602, 40.35833011354719, 41.6509347643171, 39.76263325554984, 40.3132814679827, 41.25255632400513, 38.15252719606672, 35.03318555014474, 34.895374979291645, 33.17463275364467, 33.63751826967512, 34.169072832380024, 32.627347469329834, 34.17012895856585, 34.644051688058035, 36.71139785221645, 37.42164271218436, 40.17489767074585, 40.493066106523784, 41.77408463614327, 41.70533568518502, 44.99328926631382, 47.01265117100307, 44.31150075367519, 44.08453089850289, 45.56957285744803, 34.29614496231079, 12.573871850967407, 0.18013135636491434, 3.7281601769583563, 5.710458653313773, 8.604640449796404, 9.02925441946302, 1.4735114233834403, 0.05810586456209421, 10.258594853537423, 47.82875878470284, 25.825481414794922, 27.56518701144627, 23.2581741469247, 38.17327104296003, 12.666069235120501, 0.06575449449675423, 0.03831895899825862, 0.01939987767088626, 0.06423363289130585, 0.033287126504416974, 0.07790117378213576, 0.06854775853987251, 0.03581962953986866, 0.06361923978797027, 0.05671357177197933, 0.037686197951968224, 0.061284292223198075, 0.062467935495078564, 0.0916350143296378, 0.021274232272324816, 0.03927297584180321, 0.06277377836938415, 0.03387408643694861, 0.05448996501841715, 0.03254035121894308, 0.012915453524328768, 0.04370679846033454, 0.033731661936534305, 0.03981388020994408, 0.044668788090348244, 0.02328518275836749, 0.04185992113447615, 0.021825928739937286, 0.05803908993090902, 0.06989297457039356, 0.13228804218981946, 0.04532110790855118, 4.058541374547141, 42.0047995703561, 50.547550678253174, 28.775538887296403, 29.463940347943986, 43.277876308986116, 46.02845621109009, 50.92325367246355, 45.99876308441162, 11.852561116218567, 0.5579620056918689, 1.9886510840484073, 10.656420912061419, 3.5957954738821303, 7.116344996861049, 35.45487172263009, 48.70189721243722, 48.17211444037301, 48.8497896194458, 45.68901586532593, 43.94565030506679, 43.336383615221294, 40.173247473580496, 41.60177973338536, 47.13066632407052, 44.13536044529506, 40.54720299584525, 39.53330448695591, 38.84885481425694, 38.66641248975481, 41.07161133629935, 40.55209452765328, 42.02641541617257, 43.18144226074219, 44.19749471119472, 44.95774923052107, 44.64803327832903, 44.44900560379028, 43.959619658333914, 44.17151192256382, 43.624983991895405, 36.21278469903128, 34.820271900721956, 36.48203781672886, 34.09930944442749, 34.83419609069824, 35.68702493395124, 37.18008858816964, 35.75089277539934, 35.915922914232524, 37.413193702697754, 35.77698673520769, 36.994443144117085, 33.73722839355469, 35.68618420192173, 34.96876185280936, 36.37351042883736, 35.01162528991699, 37.84549672263009, 39.29409537996565, 41.431416852133616, 41.52769456590925, 40.332899706704275, 37.91433252607073, 37.023931298937114, 35.04757874352591, 42.20327138900757, 45.83581393105643, 48.59835515703474, 45.39158432824271, 43.74159560884748, 41.61005503790719, 39.7373765536717, 39.65530790601458, 48.22532374518258, 48.71254880087716, 48.10610655375889, 46.189908027648926, 45.369999749319895, 43.74930810928345, 41.58070584705898, 39.75270427976336, 37.21400274549212, 36.88439062663487, 34.74267789295742, 32.67084666660854, 33.7265351159232, 34.403484208243235, 34.64813028063093, 34.077002252851216, 35.938664368220735, 34.38446004050118, 34.74323722294399, 34.23351042611258, 33.46330261230469, 34.051429407937185, 36.39599132537842, 33.36331456048148, 34.35202237537929, 33.182675293513704, 34.507748876299175, 36.900656359536306, 39.19248839787075, 40.9695006098066, 42.026318141392295, 41.14596053532192, 41.654773644038606, 42.08557932717459, 39.999882970537456, 37.52505970001221, 35.43291541508266, 35.10497433798653, 34.96449565887451, 35.40381635938372, 34.767740045275005, 37.01313727242606, 36.33752223423549, 39.96641002382551, 39.86398662839617, 43.52251543317522, 43.148115226200645, 43.82225029809134, 44.364633628300254, 47.399915967668804, 46.79138926097325, 44.15858479908535, 45.59300913129534, 47.574732644217356, 36.90144845417568, 15.689084529876709, 0.5619362124374935, 4.75198939868382, 5.53698558466775, 4.09399151802063, 4.065326724733625, 0.5636700593999454, 0.07657578454485961, 12.416387455804006, 51.2896009172712, 30.371948310307094, 26.542877708162578, 25.696533271244594, 45.239036628178184, 17.56992367335728, 0.050991414713540247, 0.05809389520436525, 0.013739606398823006, 0.018098835966416767, 0.007859253989798682, 0.049310666508972645, 0.10735418727355343, 0.031221058618809496, 0.01461250607722572, 0.031980671786836216, 0.04476928591196026, 0.0224682961457542, 0.05516431008332542, 0.07229059841483831, 0.09547967516950198, 0.11385949248714106, 0.14157525955566339, 0.10656769733343806, 0.22372082594249929, 0.144324873441032, 0.1034550807837929, 0.16709099896252155, 0.16092893747346743, 0.11136076013956751, 0.21443272648113115, 0.08427647168615035, 0.16049685994429247, 0.1200000172747033, 0.17582814155944756, 0.09663454855659179, 0.1929828639009169, 0.12114450229065758, 4.517020429883685, 48.695775849478586, 55.650960854121614, 36.58896017074585, 36.76130676269531, 45.87971264975411, 52.150451455797466, 52.545817852020264, 53.42162091391427, 14.148801786558968, 0.7053740641900471, 4.293862095900944, 8.530507513454982, 2.9477489335196356, 7.430696266038077, 39.363646847861155, 48.50972740990775, 48.052848611559185, 50.24676316125052, 47.47233704158238, 44.49022926603045, 44.1262652533395, 42.243692534310476, 44.428518840244834, 48.57886893408639, 46.88132674353463, 41.173517090933665, 42.842891284397666, 41.35517079489571, 41.01381622041975, 44.45797572817121, 42.45788812637329, 44.20125368663243, 44.805750438145225, 45.71798637935093, 46.35685586929321, 46.76834903444563, 45.898299080984934, 46.117747511182515, 47.344469342912944, 46.43162890842983, 39.29364027295794, 36.87569843019758, 38.50581530162266, 35.68255724225725, 36.83908837182181, 36.62393740245274, 38.57485955102103, 38.395662035260884, 39.071402141026084, 39.345039572034565, 37.51867083140782, 37.86260666166033, 35.139364446912495, 37.79043919699532, 36.06175865445818, 38.367337703704834, 36.97893476486206, 37.96474518094744, 41.581414563315256, 43.5485850742885, 42.95495530537197, 43.16300521578108, 40.378347873687744, 40.17992469242641, 36.915747846875874, 43.08976078033447, 48.83356557573591, 50.094705309186665, 46.44189139774868, 46.0464312008449, 42.36950009209769, 40.57809468678066, 41.60875225067139, 48.91040570395333, 48.736016341618125, 50.0495593888419, 48.18036195210048, 47.46897758756365, 45.74608489445278, 43.14457859311785, 41.38637515476772, 39.05181516919817, 37.76420974731445, 35.36967291150774, 33.932747227805, 35.18220009122576, 36.88288981573922, 35.19352912902832, 36.64477852412632, 37.627719334193635, 35.5330285344805, 35.96887860979353, 35.96778079441616, 35.37868472508022, 35.82185820170811, 38.63639627184187, 34.36091954367501, 36.4085328238351, 34.75427443640572, 35.83356591633388, 39.194201128823416, 39.86174930844988, 42.697781630924766, 44.69495446341378, 43.69959374836513, 43.445487703595845, 45.694817611149375, 42.81886093957083, 39.40560007095337, 37.26361288343157, 37.66559396471296, 36.03201689038958, 38.135274818965364, 35.72726195199149, 37.64325203214373, 37.74596030371529, 41.21148552213396, 41.86524152755737, 45.14422151020595, 44.500630719321116, 46.71237434659685, 46.17733873639788, 49.7759428024292, 49.328649044036865, 44.825313091278076, 44.9020003591265, 49.31157732009888, 39.60835197993687, 18.962637969425746, 0.6806775065405029, 7.571070722171238, 10.949067745889936, 15.964410373142787, 16.2598078250885, 2.905778339930943, 0.33411205453532083, 13.702512042863027, 57.21973555428641, 34.67557219096592, 40.82112182889666, 32.010114669799805, 51.44940948486328, 22.008135897772654, 0.16257464273699693, 0.20223413248147282, 0.10638882193182196, 0.11362649713243757, 0.12217816896736622, 0.19767953402229718, 0.18338476893092903, 0.13084056414663792, 0.15749677164214, 0.10407979440476213, 0.1848031242511102, 0.21572435860122952, 0.11691705270537309, 0.22960368384207996], [0.036280161435050626, 0.02607512876524457, 0.0576619737382446, 0.03880408100251641, 0.042584372617836506, 0.04327396097193871, 0.05227204438831125, 0.05165152411375727, 0.044717992057225535, 0.0682573387665408, 0.0170673219420548, 0.013787356604422842, 0.023980101005041173, 0.0485500626798187, 0.07669589202851057, 0.035029495866703134, 0.04279596358537674, 0.061165908218494484, 0.08275826315262488, 14.150848031044006, 47.67497083118984, 40.48981087548392, 29.209049156733922, 28.916729756764003, 40.960047585623606, 44.43136412756783, 44.843208176749094, 13.190469758851187, 0.15015346210982117, 1.9112045083727156, 0.37846316610063824, 0.1130355881260974, 1.21552654675075, 23.498566184725078, 47.29119055611746, 50.59744916643415, 44.42491272517613, 46.816392353602815, 44.9257493019104, 45.047589438302175, 42.632732595716206, 42.508134024483816, 44.27406733376639, 40.23646565846035, 37.21652494158064, 36.437979289463584, 37.629348686763215, 37.034461293901714, 39.07989631380354, 40.01600626536778, 41.7467052595956, 40.06410864421299, 42.59616770063128, 40.75748675210135, 44.333884375435964, 44.60894966125488, 45.518281255449565, 45.33591883523123, 44.74098627907889, 41.57979563304356, 34.06023277555193, 35.18148095267159, 34.55363825389317, 31.844500882284983, 36.33011892863682, 36.253820759909495, 35.05502026421683, 35.72013310023716, 33.51398624692644, 35.245567662375315, 35.350277015141074, 31.499845913478307, 35.0242258480617, 32.73814344406128, 35.2738607270377, 33.13250582558768, 36.895931584494456, 43.32451261792864, 43.15401424680437, 42.46878637586321, 41.21501868111746, 38.86384555271694, 37.34350674492972, 34.77052279881069, 37.87775720868792, 40.698229040418354, 45.59490251541138, 45.64586060387747, 47.16921840395246, 45.50913395200457, 39.818764277866904, 36.87395790645054, 36.326460702078684, 45.89062132154192, 44.83944920131138, 46.74824442182268, 46.10888508387974, 45.13475806372506, 41.517091614859446, 39.821981293814524, 37.5016234261649, 32.34609828676496, 31.914639472961426, 31.57201337814331, 33.218468938555034, 33.92728246961321, 32.666434560503276, 32.64952959333147, 33.99881764820644, 32.704402991703574, 32.154022284916465, 31.69468035016741, 34.38381385803223, 34.188340187072754, 34.320415019989014, 32.50093541826521, 32.07196405955723, 32.63927752631051, 34.53420761653355, 34.78582968030657, 35.4214300428118, 38.11654942376273, 36.82781144550869, 37.77622318267822, 37.69334854398455, 36.96757446016584, 37.404438972473145, 34.43501165934971, 35.25744908196585, 34.57883937018258, 33.37789535522461, 32.29556056431362, 32.92279182161604, 31.904925891331263, 31.959371975490026, 30.768902369907924, 30.995757579803467, 31.686922686440603, 32.9871495110648, 33.97351230893816, 40.05697284426008, 41.12209694726126, 43.24058185304914, 45.82270268031529, 42.21981157575335, 37.975966521671836, 21.01139943940299, 2.9759047712598528, 3.299826749733516, 2.280895790883473, 9.161100830350604, 4.172364592552185, 2.88212536914008, 0.82862767044987, 0.07132075474198375, 13.63329929964883, 38.53250333241054, 25.938049180167063, 34.360033648354666, 26.131707634244645, 39.01735210418701, 4.868047765323094, 0.07516861148178577, 0.029051062917070727, 0.03651482937857509, 0.03530454342918737, 0.08143267035484314, 0.016676633352679864, 0.010689329405847405, 0.011590644434493567, 0.030557023893509592, 0.01887742945525263, 0.09128993856055395, 0.044813977620963535, 0.030481781145291667, 0.051216019982738156, 0.04576055772070374, 0.07012523710727692, 0.06655832100659609, 0.025164768864799823, 0.04866902343928814, 0.032589914809380255, 0.05815555368150983, 0.023878688857491528, 0.07302404048719577, 0.04944309279588716, 0.024296059140137265, 0.053139113754566224, 0.06498224700668029, 0.11237164839570012, 0.06960663957787411, 0.10557352818016495, 0.02969273312815598, 0.06429725912000452, 0.27097808942198753, 20.88981464930943, 54.28866229738508, 43.31321832111904, 30.038316658564977, 37.649467195783345, 47.64130680901663, 48.00048003877912, 49.412677083696636, 13.802047593252999, 0.07702657606984888, 0.6793201650891985, 2.555916564805167, 0.9094142126185554, 1.7114714831113815, 27.29283847127642, 47.865914276668, 50.593686716897146, 45.56990984507969, 46.467665740421836, 45.37953267778669, 46.121794836861746, 43.77961267743792, 44.39461857931954, 45.48441573551723, 42.910660539354595, 38.44709260123116, 37.41953393391201, 38.099613189697266, 38.5501309122358, 41.708445004054475, 41.52386610848563, 42.78314025061471, 42.2093962260655, 43.405004024505615, 43.791580949510845, 45.468810081481934, 44.509385449545725, 45.98575605664934, 46.16476597104754, 46.03812115533011, 41.69387810570853, 35.45273167746407, 36.279254640851704, 35.878697940281455, 33.80579669134957, 37.58960846492222, 38.26546321596418, 36.04221337182181, 37.72244412558419, 36.49888719831194, 36.37231533867972, 36.71548686708723, 33.149841581072124, 36.5929970741272, 34.987924984523225, 36.27932412283761, 34.7476840700422, 38.59287970406668, 44.359662192208425, 45.03654875074114, 43.898093359810964, 42.97509118488857, 40.075368200029644, 38.43124028614589, 35.42908000946045, 40.49400758743286, 42.55112600326538, 46.40312739780971, 47.8712921823774, 49.42605584008353, 47.361217975616455, 39.41996199744088, 38.32681233542306, 38.18016365596226, 46.93292754037039, 46.75443526676723, 48.48116683959961, 47.67704834256853, 45.96162148884365, 42.652906690325054, 40.40968424933297, 37.79180799211775, 34.060896328517366, 33.70574263163975, 34.19656685420445, 35.1284418787275, 34.87411001750401, 33.94276653017317, 35.08369547980172, 34.96987009048462, 33.76751906531197, 34.13123294285366, 34.274060113089426, 35.93087196350098, 35.60055112838745, 36.67960636956351, 34.02504709788731, 33.26518515178135, 35.065908091408865, 35.850533417293, 35.65895768574306, 37.260402815682546, 39.37889119556972, 39.30899926594326, 39.458291734967915, 39.72373029163906, 39.40372405733381, 38.5769579069955, 36.28022391455514, 36.28274958474295, 36.240400314331055, 34.98505885260445, 34.434518337249756, 33.54721253258841, 34.38734354291643, 33.63755301066807, 34.31444304330008, 32.55482564653669, 34.19602142061506, 34.70508813858032, 37.939401626586914, 41.89869710377285, 45.0076060295105, 44.64318690981184, 48.01919501168387, 42.70242302758353, 42.862933363233296, 24.075087751661027, 5.348616446767535, 2.852681291954858, 5.910554179123469, 6.14706825358527, 2.252300262451172, 0.411606779055936, 0.05315981925066028, 0.03157833444752863, 15.201110805783953, 45.516950675419395, 31.285445349557058, 33.31980494090489, 27.159905535834177, 45.913237707955496, 7.76313282762255, 0.06886769458651543, 0.03573397806446467, 0.01941447126279984, 0.013542068739687758, 0.03868321355964456, 0.03188706109566348, 0.06633463515234844, 0.026142376674605266, 0.023104568610766103, 0.01813141073632453, 0.04915679173011865, 0.0076808459291766796, 0.015479821412424957, 0.03590633274455156, 0.10138394763427121, 0.10622876230627298, 0.12088250634925705, 0.09284896776080132, 0.16390264433409485, 0.12609707510897092, 0.09549011782343898, 0.11409446916409902, 0.1940684520772525, 0.17185807387743676, 0.16394456422754697, 0.1499605138919183, 0.2188604660332203, 0.1803012072507824, 0.1944019113268171, 0.1252790740025895, 0.14478966992880615, 0.17253796596612248, 0.6267100338424955, 23.913536923272268, 61.03285830361502, 49.7747094971793, 39.189987046378, 36.514746461595806, 52.111333097730366, 52.50191913332258, 55.08816371645246, 17.221766812460764, 0.2544494920543262, 4.757288702896663, 1.768873157245772, 0.42083257543189184, 2.062206668513162, 29.535854203360422, 49.12822478158133, 52.56931665965489, 45.647389207567485, 47.2393604687282, 46.85131399972098, 45.40852403640747, 44.13035774230957, 46.57559558323452, 47.240017073495046, 45.23155689239502, 39.675714765276226, 40.603479930332725, 40.79170315606253, 41.34274046761649, 44.46211685453142, 45.28972373689924, 44.39661271231515, 44.37525742394583, 46.10475785391671, 45.72758878980364, 48.57637800489153, 47.59062664849417, 48.25264753614153, 48.74824169703892, 49.38985572542463, 47.04663828441075, 37.338083675929475, 37.77115447180611, 37.67968838555472, 35.89628383091518, 39.603297165461946, 39.03412158148629, 38.60567133767264, 40.28898014341082, 36.95482798985073, 38.277615615299766, 37.35946328299386, 35.096497535705566, 38.71739837101528, 37.749368395124165, 38.88848039082119, 36.38306072780064, 40.79692472730364, 48.34972776685442, 46.95333439963204, 45.50407566343035, 46.07309143883841, 42.52833243778774, 42.04156943729946, 37.80127491269793, 42.50420829227993, 43.62054756709507, 49.22950867244175, 49.421893869127544, 50.01430075509207, 48.37233720506941, 39.274345125470845, 39.05696031025478, 39.7425216947283, 48.095236097063335, 48.707890033721924, 51.33603572845459, 49.807306970868794, 47.394628388541086, 45.15167345319475, 44.28941590445382, 40.44881650379726, 35.67063760757446, 36.43354981286185, 35.591598374503, 36.72254971095494, 37.285638672964915, 35.73380020686558, 36.47551345825195, 38.02363116400582, 35.29005350385393, 35.648875849587576, 34.40056596483503, 36.90086133139474, 36.706426416124614, 39.488971505846294, 35.443594796316965, 35.55156980242048, 35.98302166802542, 38.56741108213152, 38.04526438031878, 37.97099508558001, 41.66362564904349, 41.46684224264962, 40.95057371684483, 41.49720239639282, 41.11702128819057, 41.58731358391898, 38.523244857788086, 38.18884890420096, 38.491206714085166, 36.55586242675781, 35.55687822614397, 36.14119740894863, 36.75855527605329, 35.980562005724224, 35.38290922982352, 35.14991181237357, 34.60040657860892, 36.70179196766445, 38.85463571548462, 44.62709140777588, 46.454801150730674, 47.019495146615164, 47.75228691101074, 41.815482003348215, 43.31307588304792, 27.19949116025652, 6.031992622784205, 6.606465773923056, 8.864384089197431, 17.681812252317155, 11.869624154908315, 8.27644315787724, 2.9419330741677965, 0.15258379812751496, 17.540461574281963, 49.718929358891074, 35.773533480507986, 46.083652700696675, 35.45085218974522, 53.79762615476336, 10.53618928364345, 0.30832286551594734, 0.14333812067551271, 0.11253232548811606, 0.15188306144305638, 0.1419948927525963, 0.12614754454365798, 0.11183376011571713, 0.15680520875113352, 0.13909312417464598, 0.11625321475522858, 0.1537609071071659, 0.14253685224269116, 0.11657617028270449, 0.1301829551479646], [0.04178674113271492, 0.016453994138698493, 0.030025948105113845, 0.02542169954228614, 0.019694154915798987, 0.07113955196525369, 0.005949892494494894, 0.02218983555212617, 0.020333070274708525, 0.0482200266394232, 0.019432898577568785, 0.03864274573113237, 0.029262694596712078, 0.06037016984607492, 0.04986047325655818, 0.008212283037469854, 0.0165056001195418, 0.06306557556880371, 0.016985197152410234, 5.342867246695927, 37.291718346732004, 36.86681515829903, 22.018698896680558, 26.33243935448783, 35.40531022208077, 40.283386843545095, 48.23370674678257, 25.297477381569998, 0.020685360567378144, 0.5953163898416928, 2.515505624668939, 1.1711764122758592, 0.347121606447867, 8.715041245732989, 36.89862401144845, 47.21808508464268, 47.1515109198434, 45.12913697106497, 46.03906263623919, 40.834205286843435, 42.96200772694179, 46.486325127737864, 44.47780588694981, 43.205792222704204, 40.07946416309902, 38.252946036202566, 37.33465473992484, 39.94653122765677, 38.9019182068961, 40.54136650902884, 41.470903464726035, 43.4617360660008, 43.01899337768555, 44.77937855039324, 45.668511731284006, 45.25756399972098, 45.95886305400303, 45.25171709060669, 44.74887595857893, 44.2851288659232, 38.88547876902989, 34.34058216639927, 34.481741768973215, 34.89511789594378, 34.113094670431956, 35.68723685400826, 33.91490772792271, 34.9970132282802, 34.168541295187815, 34.09117310387747, 33.31807483945574, 33.43120888301304, 32.832347120557515, 33.79544040134975, 33.65967607498169, 34.487237794058665, 41.93357706069946, 46.50630119868687, 45.440933908735005, 44.94852202279227, 43.37746831348964, 43.62649869918823, 43.75913981028965, 38.17386163984026, 35.633318832942415, 37.09525803157261, 40.46556166240147, 45.93631962367466, 46.666919231414795, 46.079355239868164, 43.238156931740896, 37.42890705381121, 38.22558055605207, 42.882680143628804, 44.808564458574565, 46.02142463411604, 45.725740568978445, 46.35064417975289, 44.5205512046814, 40.488101618630544, 37.83602285385132, 32.204264708927695, 31.42642777306693, 31.782311030796595, 31.134520053863525, 33.29485395976475, 33.261311531066895, 33.05096524102347, 34.33153213773455, 33.95529065813337, 34.49182707922799, 32.500428199768066, 33.402759483882356, 33.79602057593209, 35.26077726909092, 32.96836505617414, 33.16275133405413, 32.91648285729544, 32.93129294259207, 38.479075159345356, 40.45982592446463, 39.75217621667044, 40.91279288700649, 39.488808223179404, 40.39282097135271, 39.2929801940918, 38.4177051952907, 36.41740219933646, 33.492971420288086, 33.87569209507534, 32.735489232199534, 31.99476957321167, 31.2392988886152, 32.18046365465437, 31.491560186658585, 33.3168762751988, 33.53992734636579, 36.44347531454903, 37.24154887880598, 38.3486887386867, 38.82181242534092, 41.31726837158203, 41.94803278786795, 46.2717091696603, 43.24777323859078, 34.308540548597065, 7.512424451964242, 1.3233540121998106, 5.498581154005868, 3.0604372067110877, 1.4872504004410334, 1.1494859818901335, 0.7118549421429634, 0.24463024895106042, 0.045766135278557024, 18.372223479407175, 37.69394261496407, 23.216601337705338, 23.869492292404175, 29.42855317252023, 32.960975646972656, 1.2627345621585846, 0.09920150760029044, 0.046674279762165885, 0.04880636910508786, 0.020126992404194813, 0.041074330253260474, 0.017877652210050395, 0.029528707465423003, 0.020046173794461147, 0.019473162845575383, 0.024785959727263877, 0.061704033985733986, 0.052718181163072586, 0.012812797113188674, 0.02358472204234983, 0.03643212613782712, 0.024959676566400697, 0.05285948268803103, 0.05505420420584934, 0.056711084941135984, 0.029422649049333165, 0.010515312314964831, 0.029078255207943063, 0.01773402839899063, 0.026872163139549748, 0.031265733364437304, 0.033405744603702, 0.03843918861821294, 0.059825224801898, 0.017750050307118466, 0.032929684434618266, 0.033801910667014975, 0.07930707798472472, 0.0792596008894699, 8.155366454805646, 46.135361194610596, 41.40790067400251, 27.130492074148997, 32.612624236515586, 41.587139878954204, 44.17205735615322, 51.16043043136597, 25.455896309443883, 0.07565600318568093, 1.0561336768524987, 5.232322709900992, 2.155593280281339, 0.37073709496429985, 12.065090009144374, 40.84520081111363, 49.668534074510845, 46.882963044302805, 45.480705397469656, 46.78547286987305, 42.323464802333284, 43.967780317579, 48.843105452401296, 45.504645415714805, 43.65975972584316, 41.33638981410435, 39.0136730330331, 39.19617094312395, 40.998325211661204, 40.8924172946385, 41.325286592756, 43.54061549050467, 44.165956837790354, 45.15815612248012, 44.92063890184675, 47.07130091530936, 47.47499820164272, 47.587388787950786, 46.06091472080776, 46.59145484651838, 44.51387398583548, 39.942240715026855, 35.380814347948345, 35.04881204877581, 35.77735151563372, 36.1572824886867, 36.23308386121477, 35.6715304510934, 35.05430112566267, 36.17934996741158, 35.75821965081351, 33.91761405127389, 36.02260555539812, 36.25667299543108, 34.823565346854075, 35.467757156917024, 35.757326807294575, 43.57186848776681, 47.94837202344622, 46.92592028209141, 47.53873750141689, 44.66400718688965, 46.390704018729075, 44.50396932874407, 38.637309959956575, 38.331460680280415, 39.05985770906721, 44.31870950971331, 47.18491785866873, 49.741629123687744, 48.009714194706504, 42.42545393535069, 36.61169120243618, 39.62118877683367, 43.60009207044329, 44.77662011555263, 48.47895383834839, 47.02375439235142, 48.278282914842876, 45.39307124274117, 42.12679951531546, 41.0575863974435, 34.70250688280378, 34.213301590510774, 33.77443252290998, 32.73631606783186, 34.85564170564924, 35.029499530792236, 33.64869792120797, 35.27366617747715, 35.23236608505249, 35.676091943468364, 33.947456564222065, 33.9306766646249, 35.61094215938023, 35.401499135153635, 34.76183407647269, 34.588966369628906, 34.23719991956438, 34.06470046724592, 38.859082562582834, 41.83998135157994, 41.94937726429531, 41.93129457746233, 41.252889837537495, 41.04007346289498, 40.04972587312971, 39.978093419756206, 38.01173932211739, 34.56533554622105, 34.817329338618684, 33.70044115611485, 33.1310258592878, 32.53262962613787, 34.23114456449236, 32.741475105285645, 34.31055552618844, 35.57726076671055, 37.167463711329866, 38.35374355316162, 39.58495739528111, 40.87407405035836, 42.9065819467817, 45.31598792757307, 47.386950629098074, 44.08316557747977, 37.11639097758702, 9.860559480530874, 2.2077822855540683, 7.0046127523694715, 0.6379335458789552, 1.5930312957082475, 0.21675554183976992, 0.46841063669749666, 0.1954190353197711, 0.039025944990238974, 20.788190296718053, 41.148236070360454, 30.07983214514596, 29.890142849513463, 33.205642563956125, 41.03136389596121, 2.5789389865739003, 0.15396990946360997, 0.1003557431644627, 0.04290158434637955, 0.0260390171315521, 0.01579489914833435, 0.042716893899653635, 0.045414172379033904, 0.014597037175138081, 0.03697347155373011, 0.006250672225308205, 0.1133606538974813, 0.0529980056120881, 0.003914791674885366, 0.0831138426437974, 0.16574368625879288, 0.07754726348710911, 0.14877235836216382, 0.22025694538440022, 0.128196421744568, 0.13885339775255748, 0.09086129441857338, 0.09113489330879279, 0.11398973049862043, 0.12326448996152196, 0.1872353194547551, 0.13921015789466246, 0.13060116342135838, 0.20452741799610002, 0.12410961889794894, 0.11241953939731632, 0.08664740874831166, 0.1571255044213363, 0.10529159009456635, 8.814862540790013, 52.17280728476388, 48.18719550541469, 32.49043321609497, 35.57824741091047, 44.69760867527553, 47.8812906401498, 58.02574743543352, 32.006161144801546, 0.09270157638405051, 3.2115422870431627, 12.276545405387878, 3.268353581428528, 0.6673761031457356, 12.797813160078865, 42.415194920131135, 49.13831009183611, 47.55790063313076, 44.69195978982108, 47.25625501360212, 42.61507722309658, 45.148845536368235, 51.22554200036185, 47.46657003675188, 46.22271047319685, 44.309805393218994, 42.16272865022932, 40.81565359660557, 44.33384268624442, 43.22844682421003, 44.10444790976388, 45.0684757232666, 46.93472712380545, 47.75629254749843, 46.89944069726126, 49.508659499032156, 48.49836015701294, 50.26775366919381, 49.0902806690761, 48.52900171279907, 47.30048724583217, 43.42272540501186, 36.12412221091134, 36.988568442208425, 37.895350047520225, 36.86227103642055, 37.39211981637137, 35.48160144260952, 37.453121525900706, 37.30249847684588, 37.60202489580427, 36.686620576041086, 38.40977035249983, 36.21432025091988, 37.201190267290386, 37.75530563082014, 36.869681290217805, 44.76752839769636, 51.03225006375994, 49.26115424292428, 49.188813073294504, 48.39088542120797, 46.65676096507481, 47.02635996682303, 41.35694258553641, 39.80487482888358, 39.61464009966169, 46.29645865304129, 49.10492399760655, 51.21742997850691, 49.09179885046822, 44.015187876565115, 39.91670608520508, 42.15239667892456, 45.07581302097866, 45.80484928403582, 49.57445893968855, 49.20322363717215, 48.54752908434187, 47.579711028507774, 43.96897540773664, 43.331179414476665, 36.79726021630423, 35.012313161577495, 35.264980929238455, 33.58006361552647, 35.88630969183785, 37.061413356236045, 36.037245409829275, 37.32252665928432, 36.427466664995464, 37.97857557024275, 35.29194688796997, 35.08607176371983, 37.27817630767822, 38.38435731615339, 36.338356018066406, 37.5080018724714, 36.58767475400652, 34.48927361624581, 40.93471792766026, 42.71149737494332, 43.97750084740775, 45.041586194719585, 43.28263235092163, 43.50819866997855, 41.766038622174946, 43.24217993872506, 38.63022627149309, 35.90158878053938, 37.354523113795686, 36.7361820765904, 35.53463356835501, 34.83108329772949, 35.98393188204084, 34.471743311200825, 36.490538937704905, 37.09261771610805, 39.937363079616, 41.880267007010325, 43.07093463625227, 42.58458505358015, 45.60611343383789, 46.805664334978374, 48.12387309755598, 44.743588379451204, 38.04489959989275, 11.476592353412084, 4.557010352611542, 9.630275334630694, 7.6958760023117065, 6.851745869432177, 3.351048218352454, 2.4681736273424963, 0.6626105617199625, 0.13373117760888167, 22.393927676337107, 48.83423955099923, 33.252042634146555, 35.30612121309553, 40.33681501661028, 47.49374444144112, 4.130037035260882, 0.30284013971686363, 0.19818118853228434, 0.12765522221369402, 0.10046548263302871, 0.1601255927234888, 0.1510065027645656, 0.0805417335193072, 0.08349926410509007, 0.12140980948294912, 0.13438736168401583, 0.1738079392484256, 0.13440485431679658, 0.11008125344025237, 0.17279146664908954], [0.050166448445192406, 0.031393114743488174, 0.051778871566057205, 0.02643832141932632, 0.07861153209315878, 0.05235602327489427, 0.029574406798928976, 0.0121853964935456, 0.02027162553609482, 0.05866722336837223, 0.028209036582016518, 0.044084175888981135, 0.06310520201389279, 0.047340194029467444, 0.011033438262529671, 0.07833149390561239, 0.0660729513370565, 0.014957888883405497, 0.027988692512735724, 0.7054671049118042, 25.43048848424639, 46.454297406332834, 22.234299761908396, 23.219847883496964, 32.33198996952602, 32.00834287915911, 48.822069781167166, 22.705444949013845, 0.09071818459779024, 1.0491554055895125, 3.388114686523165, 1.5235417102064406, 0.12340998144022056, 2.3973973223141263, 24.332205840519496, 47.53416211264474, 48.94774532318115, 46.64461203983852, 43.837630135672434, 41.27815696171352, 43.13206488745553, 47.21605273655483, 44.669982637677876, 40.83645650318691, 39.413364682878765, 37.67144782202584, 36.03918048313686, 37.56430312565395, 39.374458244868684, 41.809204305921284, 45.32605586733137, 46.203328473227366, 44.528746604919434, 44.91442721230643, 42.38642937796456, 42.482800892421174, 43.12148625510079, 44.254511628832134, 44.42991195406233, 46.243631499154226, 45.117203439985005, 44.57614026750837, 34.77236059733799, 33.48686395372663, 34.60077830723354, 36.050217696598594, 34.0810877936227, 35.040508951459614, 33.99840075629098, 35.545938287462505, 33.457914284297395, 33.802937507629395, 34.38485608782087, 34.38259792327881, 31.71421868460519, 36.27386631284441, 44.661766392844065, 45.977473803928916, 47.43252386365618, 46.80614723478045, 47.26980400085449, 43.36609411239624, 45.303644452776226, 44.75503206253052, 40.379299776894705, 37.50717156273978, 38.99013948440552, 44.39663355691092, 46.19712025778634, 46.46941668646676, 43.10646424974714, 45.361314501081196, 47.064446517399375, 46.12770080566406, 45.59661872046334, 45.367262159075054, 46.727684702192036, 44.564616680145264, 43.847955158778596, 40.66903618403843, 33.906114782605854, 31.83719137736729, 31.971635546003068, 30.95278297151838, 34.124736377171104, 34.295342445373535, 33.12833343233381, 32.432116985321045, 32.69659669058663, 33.029867036002024, 33.81652123587472, 33.533017362867085, 33.7777989251273, 33.08416025979178, 33.94395467213222, 33.98045008523123, 32.3853417124067, 33.871641295296804, 32.684920242854524, 39.40755598885672, 44.2658371925354, 42.88292680467878, 44.238853863307405, 44.03881869997297, 43.756388323647634, 42.75320046288626, 42.608129024505615, 40.70135225568499, 40.021405015672954, 37.62455790383475, 36.18468270983015, 32.977977888924734, 32.374808243342805, 32.23814412525722, 32.63464307785034, 33.86719444819859, 38.77904626301357, 41.30670016152518, 42.08497830799648, 43.358767236982075, 42.0861108643668, 42.672948769160676, 45.58052669252668, 44.41378171103341, 38.883651392800466, 19.576474836894445, 0.8830718547105789, 0.4480064372931208, 0.5643675391163144, 4.0476222804614475, 1.528113407748086, 0.20329065221760953, 0.21446224275444234, 0.062227394830967696, 0.14345299665416988, 21.395537546702794, 31.238357407706125, 19.986418553761073, 20.68541775430952, 34.45551926749093, 20.773041486740112, 0.17369729732828482, 0.027192024547340612, 0.03298974496179393, 0.022560207106705223, 0.05113578321678298, 0.027286812496770705, 0.03934452396684459, 0.07080623520804302, 0.03202559080507074, 0.014226538395243031, 0.04663525042789323, 0.07478633842297963, 0.04874722460018737, 0.023428273919437612, 0.03616218455135822, 0.016616735673908676, 0.03584334433877042, 0.121704456529447, 0.03627832599782518, 0.05786021452929292, 0.015794234184016074, 0.015137620935482638, 0.04018307450626578, 0.04812070946874363, 0.05710256911282029, 0.03613153173189078, 0.01288213745491313, 0.11915369411664349, 0.029538159458232776, 0.03815991717523762, 0.02848311892843672, 0.08473849296569824, 0.05193931456389172, 0.01487993708412562, 1.6265373549291064, 33.25241436277117, 48.64814942223685, 26.352592604500906, 26.846274273736135, 39.10883208683559, 36.76398876735142, 55.09040451049805, 25.376784120287212, 0.07038932972188507, 0.1426926167415721, 5.873535914080484, 4.956543496676853, 0.7307490482926369, 3.6532386200768605, 29.10188361576625, 48.72924879619053, 47.8971985408238, 47.08125420979091, 44.718738147190635, 43.06435816628592, 45.12545095171247, 48.48720135007586, 46.67188719340733, 43.6086105619158, 41.16839974267142, 39.520221029009136, 37.160543305533274, 40.734588963644846, 41.782363414764404, 42.994028500148225, 45.173789569309776, 47.56684296471732, 45.764063358306885, 46.61962284360613, 44.21789114815848, 44.60584034238543, 44.29294906343733, 46.983454840523855, 46.71513278143746, 47.79793310165405, 46.8028781073434, 43.94083520344326, 36.33899872643607, 34.61155148914882, 35.321309975215364, 37.679924624306814, 36.44523320879255, 36.50001628058297, 35.756048338753835, 36.5721629006522, 34.89067799704415, 34.64628553390503, 36.574035440172466, 34.94007968902588, 33.740348134722026, 36.80183213097708, 46.75530726569039, 47.43951375143868, 48.34385306494576, 48.68316486903599, 46.99319274084908, 44.09104483468192, 47.31818778174264, 45.52726527622768, 41.2166063444955, 39.88540097645351, 40.63541385105678, 46.00956058502197, 47.818145411355154, 46.72441904885428, 43.918270928519114, 46.00237267357962, 48.00081007821219, 49.207625320979524, 47.56994880948748, 47.203031812395366, 48.23425912857056, 47.40905284881592, 45.15524135317121, 44.164654050554546, 36.095651967184885, 32.61468437739781, 34.03856829234532, 33.14833034787859, 34.54872587748936, 35.98506096431187, 35.988152912684846, 35.187032563345774, 34.495016302381245, 34.414768082754954, 35.76792628424508, 34.8676620892116, 35.72658797672817, 34.67004142488752, 33.75576966149466, 36.25603723526001, 33.63898433957781, 34.935469559260774, 33.08554295131138, 41.48052671977452, 45.70428453172956, 44.94337688173567, 45.184705189296174, 45.492204666137695, 44.870827266148154, 43.79192835944039, 44.12454904828753, 41.68021099908011, 41.32063477379935, 38.28606462478638, 36.678421701703755, 33.84698908669608, 34.81879540852138, 35.112745898110525, 34.656999656132285, 35.33931623186384, 40.686257294246126, 43.657265322549, 43.254054410117014, 44.37922831944057, 43.90202604021345, 44.27661384854998, 46.71104376656668, 44.85663557052612, 40.91045829227993, 20.795022112982615, 1.8736223535878318, 2.2035325935908725, 1.3266135858637946, 2.107308728354318, 0.6682462021708488, 0.047502241762621064, 0.07966011296957731, 0.05213812193168061, 0.17385079552020344, 22.690968377249582, 37.5558819089617, 25.287444182804652, 24.536623580115183, 39.548851081303184, 28.22458495412554, 0.3845384158194065, 0.026061966882220337, 0.02377157023043505, 0.01659845594050629, 0.03576681237401707, 0.07346542751682655, 0.03299811469124896, 0.027723985823935697, 0.0300439937439348, 0.04181103947173272, 0.029138132530663694, 0.14671331670667442, 0.03710379098941173, 0.024570073633055602, 0.04094282677397132, 0.0963401457827006, 0.08813943261546747, 0.18590465800038405, 0.15131632185408048, 0.1605633156640189, 0.11470656203372137, 0.10393094417772122, 0.08973048188324485, 0.1310242707175868, 0.20638796101723397, 0.15770002002162592, 0.0821486401504704, 0.1824521632598979, 0.15564785871122563, 0.12877335292952402, 0.1660132139389004, 0.1934807321855, 0.13344346519027436, 0.09134211111813784, 1.9917035145418984, 37.12092120306832, 56.62421587535313, 32.72437558855329, 31.865470545632498, 41.351752281188965, 40.334160804748535, 56.63082708631243, 28.51212051936558, 0.32268682760851725, 2.5667223164013455, 9.219694989068167, 6.847439723355429, 0.9063205271959305, 4.773611324174063, 30.60312877382551, 49.44856105531965, 49.218714645930696, 47.734596797398154, 44.8639554977417, 45.43850898742676, 48.040081296648296, 50.21214376177107, 48.468541962759836, 45.12777165004185, 43.498533725738525, 41.12744358607701, 39.63358783721924, 41.42265864780971, 43.36199467522757, 45.060579095567974, 48.2471410887582, 47.98711517878941, 47.054295199257986, 49.55241577965872, 46.886444091796875, 46.483264446258545, 46.383929525102886, 48.7703161239624, 47.88918031964983, 50.119673660823274, 47.777929237910676, 47.76894869123186, 37.701380661555696, 36.75441762379238, 37.98985597065517, 39.23121418271746, 38.29806416375296, 37.20755481719971, 37.33200747626168, 38.92799827030727, 36.516959462847026, 35.59588541303362, 39.239725725991384, 36.96078954424177, 34.77971873964582, 39.49527699606759, 48.39536700929914, 49.217272894723074, 51.77182674407959, 49.77936826433454, 48.49205814089094, 46.02409969057356, 49.243641308375764, 48.28944519587925, 43.214821406773154, 41.31630604607718, 41.28181171417236, 47.04754155022757, 50.60576268604824, 47.865396635872976, 44.62531614303589, 46.58088663646153, 49.32771798542568, 49.91486855915615, 49.29475573131016, 47.7141239302499, 49.62441996165684, 49.02117388589041, 47.68111651284354, 45.60197230747768, 37.47283703940255, 34.94886916024344, 36.36500930786133, 34.8495203426906, 37.753346238817485, 37.81685277393886, 37.87514121191842, 36.913055419921875, 35.49702296938215, 35.321619170052664, 37.46721594674246, 36.1739616394043, 37.416796343667166, 36.22025053841727, 36.2871721131461, 38.616472312382285, 36.28010926927839, 38.05530105318342, 35.4837658064706, 43.087815284729004, 47.0458322933742, 46.57999379294259, 46.727743761880056, 47.582827295575825, 47.81438296181815, 46.24159915106637, 47.252562046051025, 44.29732295445034, 42.98162249156407, 41.86527974264962, 38.70041002546038, 35.962753772735596, 36.78939832959856, 36.64708185195923, 36.38866444996425, 36.56368957247053, 42.51632595062256, 46.436881746564595, 44.99089561189924, 47.37667771748134, 45.09182514463152, 46.04572943278721, 47.04213237762451, 47.095508439200266, 41.42615359170096, 25.071120704923356, 1.8752525746822357, 1.7252700626850128, 2.951608006443296, 9.460383193833486, 4.299614770071847, 0.4491884724370071, 0.5583638612713132, 0.31144092391644207, 0.27492990451199667, 27.978068079267228, 40.8364634513855, 28.4453934941973, 30.66449178968157, 45.97643504823957, 35.29921817779541, 0.6232411999787603, 0.08415054237203938, 0.09747143329254218, 0.08679401980979101, 0.14786046157990182, 0.09775856895638363, 0.1607439959687846, 0.14038730758641446, 0.13565069889383657, 0.1094186097117407, 0.1451414224824735, 0.2557978225605828, 0.16456036189837114, 0.12859324259417398, 0.09597944335213729], [0.03377536976976054, 0.0509390759148768, 0.07132257321583373, 0.05690424350489463, 0.02755486945222531, 0.04469044353546841, 0.08826953491994313, 0.07929011460925851, 0.042824594370488606, 0.009737517801113427, 0.0457152451521584, 0.05134891445881554, 0.07441724251423563, 0.04842376695679767, 0.030053286281015192, 0.09387314173259906, 0.06303647998720407, 0.009861228305713406, 0.07360545678862504, 0.06893277966550418, 9.608157481466021, 45.18520545959473, 34.17716400963919, 21.456676483154297, 37.81708901269095, 37.5688750403268, 40.371361460004536, 32.19245624542236, 0.6116959537778581, 0.2687574071543557, 10.71686589717865, 3.7333309394972662, 0.8451736654554094, 0.2164632696658373, 9.048262085233416, 38.01983397347586, 49.116138390132356, 48.51081132888794, 46.6131123815264, 42.20300040926252, 45.523537567683626, 43.86390127454485, 44.11487715584891, 40.2541001864842, 36.99824033464704, 37.44456829343523, 38.76765121732439, 39.57086992263794, 42.58359146118164, 43.279661996024, 46.30826711654663, 45.52444083350045, 44.787101473127095, 45.437213148389546, 44.90687799453735, 46.11826862607683, 43.84490489959717, 43.15872165134975, 42.99107551574707, 44.775900976998464, 45.59459679467337, 46.5146564074925, 42.14170340129307, 35.70326634815761, 35.61878320149013, 35.09291573933193, 34.49601684297834, 33.39226770401001, 34.49903930936541, 36.08814096450806, 35.153267792293, 34.70404590879168, 35.33136054447719, 33.82228476660592, 32.90663725989205, 34.59915937696184, 43.409086091177805, 46.24148450578962, 47.716514110565186, 42.72305222920009, 43.183412075042725, 46.04770619528634, 48.68922022410801, 44.418291091918945, 44.75562613351004, 42.499778815678184, 42.08856357846941, 44.1656094278608, 46.36667019980294, 44.74327918461391, 42.9570814541408, 46.79828882217407, 46.184547492435996, 43.75916065488543, 43.114551952907014, 45.38403511047363, 43.1003463608878, 45.36621298108782, 42.55081333432879, 36.65289749417986, 32.41820669174194, 32.96696499415806, 31.92121246882847, 33.09636129651751, 33.277313232421875, 34.12548678261893, 33.51216581889561, 32.45392738069807, 33.13496201378958, 33.517238003867014, 33.990941865103586, 33.5342332976205, 32.95657743726458, 33.41000992911202, 33.04004267283848, 33.59429700034005, 33.48900747299194, 33.35290615899222, 32.277832235608784, 36.77604389190674, 44.71647650854928, 43.22920765195574, 44.38549212047032, 43.186729839869905, 42.22728783743722, 44.25832618985857, 44.213722229003906, 42.53423840659005, 40.19649614606585, 41.219514165605815, 37.5329076903207, 36.00404691696167, 33.64995901925223, 31.899787698473247, 32.71461336953299, 33.71112401144845, 38.837136677333284, 41.8872777393886, 43.778914383479524, 43.200535910470144, 44.43142318725586, 45.16034827913557, 44.12974282673427, 42.1197783606393, 31.274432454790386, 4.703851844583239, 0.11352269484528474, 0.3582075115825449, 0.941032316003527, 0.9236061253717968, 0.3683373065931456, 0.028794692030974796, 0.07648602114724261, 0.03911958282281246, 0.9642400592565536, 27.13923638207572, 27.647905315671647, 20.640297889709473, 25.127727678843907, 30.378983361380442, 8.36135709285736, 0.08403201587498188, 0.009839587279462388, 0.0780672248718994, 0.011346415932556348, 0.06643895991146564, 0.019656012766063213, 0.0562606021495802, 0.033131372183561325, 0.01710460235231689, 0.085747094558818, 0.03231590201279946, 0.035099184805793424, 0.05740509395088468, 0.024134267553953186, 0.019584803908531154, 0.04098662281674998, 0.028034551301971078, 0.03167024201580456, 0.02157856201353882, 0.046682211836533885, 0.027473462213362967, 0.06227744357394321, 0.032881722186825106, 0.05102018459833094, 0.03659888629668525, 0.038799748556422334, 0.01642576708192272, 0.02654944679566792, 0.03219399641134909, 0.030367244434143816, 0.017407089870955263, 0.06348845894847598, 0.06470711462731872, 0.06591564656368323, 0.1232397234333413, 15.124494756971087, 54.826654366084504, 35.18674421310425, 23.762248584202357, 40.636324065072195, 42.06581517628261, 45.29719305038452, 33.6945595060076, 0.24346292444637843, 0.16829721709447248, 4.197198322841099, 4.485939834799085, 0.42999868786760737, 0.4894217178225517, 13.124344621385847, 42.03801195962088, 49.29786505017962, 48.38403449739729, 46.93990005765642, 45.08211851119995, 47.300761699676514, 47.36017574582781, 45.57861941201346, 43.2674366406032, 39.04653801236834, 39.83127103533064, 39.269592557634624, 42.07683849334717, 44.111667088099885, 45.32208844593593, 47.22565514700753, 46.09580857413155, 46.6506986618042, 46.31478105272566, 46.659811224256245, 47.34619944436209, 43.65541362762451, 44.77376440593174, 43.86167090279715, 47.19348151343209, 47.42211198806763, 48.07338401249477, 42.765894821711946, 36.59662403379168, 36.42243269511631, 37.02791609082903, 35.30023956298828, 35.34112623759678, 36.02432176045009, 37.486608369009836, 36.046361446380615, 35.524200848170686, 36.42424617494856, 34.62247058323452, 35.014071055821006, 37.3289919580732, 46.04553835732596, 47.00715862001692, 47.53783423560006, 44.94222348076956, 45.46021515982491, 48.05112893240792, 49.58614233561924, 46.44512231009347, 46.21139185769217, 42.18626914705549, 43.89682878766741, 45.96896573475429, 47.64991215297154, 46.53267308643886, 44.306675229753765, 47.48844991411482, 46.39803089414324, 46.15976326806204, 45.42432771410261, 46.072341033390586, 45.70690400259835, 47.07977076939174, 44.81793063027518, 39.244245529174805, 34.49825068882534, 34.659136227199006, 33.997858796800884, 35.72879402978079, 33.747713225228445, 35.447134903499055, 34.49700696127755, 34.864743845803396, 35.82888977868216, 35.42026621954781, 35.610355036599294, 35.43518052782331, 33.997198717934744, 34.14474024091448, 34.82828664779663, 34.205019337790354, 34.974574020930696, 34.78459984915597, 34.32747438975743, 37.2848014150347, 45.68033061708723, 44.24838331767491, 46.59600591659546, 43.992814677102224, 45.61647319793701, 44.952944551195415, 46.12233679635184, 43.60306589944022, 41.92310612542288, 41.4833859034947, 39.589251382010325, 36.574824060712544, 35.3602511542184, 32.896239280700684, 34.26095928464617, 36.400274889809744, 39.21226991925921, 43.60225643430437, 44.56819500241961, 44.88277816772461, 45.63973576681954, 46.688844272068565, 44.48379176003592, 42.95011935915266, 34.340901783534456, 6.539950668811798, 0.615487661744867, 1.5576468344245638, 0.5057695263198444, 0.4012725278735161, 0.14193921216896602, 0.0537086285517684, 0.09113251165087734, 0.08049092481711081, 0.7670119138700622, 29.73746313367571, 30.273805005209788, 22.138532740729197, 27.50918800490243, 38.37625919069563, 14.171205384390694, 0.09750286981995616, 0.03137701989284583, 0.08288363606802054, 0.037818196761820994, 0.09279657128666129, 0.03342967992648482, 0.026095062427754914, 0.01468955712126834, 0.06425660808703729, 0.05573756360848035, 0.0430166231734412, 0.034974347933062484, 0.021165086521900127, 0.039967839805675406, 0.03897159433524523, 0.18905893660017423, 0.1325712219945022, 0.15458117452050957, 0.13779242682669843, 0.15710486338606902, 0.10354907145457608, 0.1778286120721272, 0.11339196150324174, 0.23512443474360875, 0.14052739792636462, 0.1598540022969246, 0.17014444725854055, 0.19327478323663982, 0.12742377391883306, 0.117228256006326, 0.1496373140918357, 0.1104672516563109, 0.10466927848756313, 0.1864152013191155, 0.2543375609176499, 16.90166504042489, 57.50630010877337, 44.54156950541905, 31.464066164834158, 47.5282735143389, 47.725473812648225, 48.52410323279244, 38.368056842258994, 0.754932090640068, 0.658208389367376, 24.482220922197612, 12.744398883410863, 1.8614369503089359, 1.4547998160123825, 12.511219944272723, 43.69153036390032, 48.8199679510934, 49.715020997183665, 47.745258808135986, 47.893283230917795, 50.57216814586094, 48.86288349969046, 47.004869188581196, 45.31961836133684, 41.01117590495518, 43.531297956194194, 42.31706551143101, 44.95247207369123, 46.14941392626081, 47.71746948787144, 50.11103357587542, 48.35330956322806, 47.06709030696324, 48.30306713921683, 45.88268300465175, 49.0103485924857, 44.274657930646626, 45.94655432019915, 44.98790093830654, 49.07458816255842, 50.41911322729928, 51.41424812589373, 44.9977639062064, 40.64827149254935, 38.26758936473301, 39.70327826908657, 36.317980425698416, 36.23835754394531, 38.707893235342844, 39.46531636374337, 38.54251568658011, 36.19272872379848, 38.89673832484654, 36.79856647763933, 35.87908703940255, 38.546285084315706, 46.423426559993196, 49.41046755654471, 50.14028549194336, 45.782875605991904, 46.33671304157802, 48.90345055716378, 51.348181179591585, 47.37084470476423, 47.55490943363735, 45.69110727310181, 48.4167605127607, 47.23332248415266, 49.02252531051636, 47.13117354256766, 45.228388513837544, 50.58729437419346, 49.14564391544887, 47.812374932425364, 46.322736740112305, 48.18962737492153, 46.437548773629324, 48.23565919058663, 46.58386393955776, 41.04116780417306, 35.28227152143206, 36.46815879004342, 34.7731283732823, 37.67530754634312, 37.09717920848301, 37.34292657034737, 37.41189438956124, 35.79103946685791, 37.04840285437447, 37.79673079081944, 36.93437596729824, 36.01075540270124, 36.39814179284232, 35.67904840196882, 36.21024513244629, 37.38243750163487, 36.58831051417759, 37.376441206250874, 36.42280442374093, 40.07219287327358, 47.54711702891758, 46.540993554251536, 47.373967920030864, 45.24799633026123, 45.66657318387713, 45.99167592184884, 48.26418849400112, 46.07503693444388, 42.55478770392281, 42.72305222920009, 42.14720984867641, 38.44234698159354, 37.169034004211426, 35.07640334538051, 35.8921913419451, 38.37549488885062, 41.69244677679879, 46.153523785727366, 46.82995523725237, 46.99276890073504, 46.84370224816458, 46.98796074731009, 44.37206472669329, 43.31046683447701, 35.52852610179356, 7.757005384990147, 0.27848979777523447, 1.0115875814642226, 2.4727566157068526, 3.0075429592813765, 1.2133468751396452, 0.21283580788544246, 0.49391959075416836, 0.21329662815800735, 1.8073002781186784, 33.79445375714983, 38.0634617124285, 29.587566171373638, 32.62173332486834, 44.689701625279014, 19.84813724245344, 0.1381741299160889, 0.13067543586449964, 0.21438373625278473, 0.2525376517857824, 0.26579389188970837, 0.0828034875116178, 0.12781721566404614, 0.086415899385299, 0.11474685344312872, 0.17346109928829329, 0.10098284522869758, 0.100973291455635, 0.14815286946083817, 0.07303033050681863, 0.09620232174971274], [0.013238074873307986, 0.029744162689894438, 0.018366660523627485, 0.027338506687166433, 0.03373493586799928, 0.03490753598245127, 0.06719116347708873, 0.0222171041781881, 0.021172365506312678, 0.10538222201700721, 0.04354987366657172, 0.049308332348508496, 0.061098237921084673, 0.03314244926774076, 0.060240216819303374, 0.013232366697463607, 0.052991573100111315, 0.11192492808082274, 0.06153674117688622, 0.03612688037433794, 2.6350832538945332, 33.248731817517964, 41.04687922341483, 24.448485680988856, 27.627175365175518, 29.28926263536726, 32.613009861537385, 40.9595125743321, 0.726532577403954, 0.23383581531899317, 0.2678354951952185, 5.202573997633798, 0.5143937606896672, 0.10828139180583612, 4.705300543989454, 24.83506086894444, 48.92256505148751, 47.839420795440674, 47.19888721193586, 46.48239939553397, 48.27584062303816, 45.517784459250315, 39.187332834516255, 36.22648654665266, 37.655821323394775, 33.64925377709525, 37.08511713572911, 39.235344886779785, 42.29533849443708, 43.70935249328613, 45.229990073612754, 44.195208753858296, 46.54992198944092, 44.21859291621617, 47.31666612625122, 47.29291023526873, 48.65454871313912, 45.66931424822126, 46.06099462509155, 45.644953863961355, 46.44199909482683, 46.00061477933611, 45.278776850019185, 36.53778321402413, 33.90236275536673, 32.98863295146397, 34.69136544636318, 34.05642516272408, 35.98424455097744, 35.153299059186665, 34.29249368395124, 34.425489153180806, 35.353469712393625, 34.00777040209089, 35.84072256088257, 32.30620173045567, 42.837968485695974, 42.47229869025094, 48.152586528233115, 41.66296557017735, 45.591247762952534, 22.302918434143066, 33.721129417419434, 50.18433707101004, 43.18007346561977, 47.38818046024868, 42.42489113126482, 45.459739208221436, 47.43176998410906, 44.374479225703645, 42.75384317125593, 46.73566470827375, 45.07434695107596, 43.34412390845162, 43.07827888216291, 42.40633944102696, 41.83590275900704, 39.63550206593105, 35.60278844833374, 32.87786824362618, 31.45372724533081, 32.57519776480538, 31.83519377027239, 32.334130014692036, 32.605839320591514, 33.7611197744097, 33.423305307115825, 33.33975669315883, 33.10547385896955, 34.25187104088919, 36.27534627914429, 34.46677187510899, 32.573523248944966, 33.838866642543245, 31.762195995875768, 32.41134187153408, 32.57069533211844, 33.27395725250244, 32.96612078802926, 32.91761541366577, 39.03121028627668, 44.96099403926304, 42.715464796338765, 44.758683340890066, 43.93307406561715, 42.41315909794399, 44.05445214680263, 44.401851654052734, 44.58295297622681, 42.92767667770386, 41.62415293284825, 38.387233870370046, 37.222559452056885, 33.06313501085554, 31.601598807743617, 33.3197215625218, 36.39760330745152, 38.30461631502424, 41.50564098358154, 43.20522594451904, 45.44420998437064, 43.459061009543284, 44.83787543433053, 39.00245516640799, 17.408258199691772, 0.36890589179737227, 1.1095728150435855, 3.377281576395035, 0.4845060301678521, 0.053894886414387395, 0.33193300717643326, 0.008696673920245042, 0.08104811741837434, 0.8250586848173822, 7.153920420578547, 25.674337250845774, 31.139338629586355, 29.86278431756156, 27.665300130844116, 29.183802877153667, 3.0776852411883215, 0.10184119202728782, 0.05423077821199383, 0.07587429468653031, 0.029264251834579875, 0.028210534448070184, 0.042779230911816866, 0.03411560419148632, 0.008383472333662212, 0.037148241818483384, 0.03897190646135381, 0.010617087478749454, 0.0761600122121828, 0.08306842829499926, 0.045495813712477684, 0.04719540483451315, 0.004819399294709521, 0.029170498651053225, 0.05062362837738224, 0.022376142608534013, 0.02481072286276945, 0.02345800562761724, 0.05610380967014602, 0.0653561537287065, 0.048964328664754114, 0.05109958676621318, 0.04128980244110737, 0.020011454853894453, 0.049008182383009365, 0.05981845302241189, 0.04654765155698572, 0.0353564377874136, 0.1056184336276991, 0.02484864109594907, 0.0790295639474477, 0.03225342250828232, 3.6617627569607327, 40.49680423736572, 45.871836866651265, 26.354392187935964, 37.800785064697266, 36.14663437434605, 35.51886463165283, 44.82025827680315, 0.8374941146799496, 0.11788287945091724, 1.0252780296972819, 0.5278700632708413, 1.2332690975495746, 0.18456550128757954, 5.126974122864859, 26.99469300678798, 49.293807302202495, 48.21452971867153, 47.26451642172677, 47.9170286996024, 50.79527480261666, 46.25212914603097, 41.97327559334891, 39.11357075827462, 39.09711742401123, 36.31258862359183, 39.09240307126726, 41.82834659303938, 43.70033025741577, 46.60207516806466, 47.0273883002145, 44.97533164705549, 47.59295776912144, 45.79405525752476, 48.85581023352486, 48.24764135905674, 47.20105504989624, 46.87610169819423, 46.26835666384016, 46.514666829790386, 47.22194480895996, 47.28322444643293, 47.16876677104405, 38.73903158732823, 36.01905155181885, 34.74905981336321, 36.44142212186541, 35.9134840965271, 37.09872170857021, 35.141309942517964, 36.367131982530864, 35.26726688657488, 36.91218342099871, 35.67256920678275, 36.854846886226106, 33.513155937194824, 44.174214771815706, 44.65365089688982, 49.03550454548427, 44.214236395699636, 43.980415616716655, 26.346660579953873, 37.20910079138619, 51.993491649627686, 45.50163337162563, 47.981237002781455, 44.95460517065865, 46.67078242983137, 47.63770069394793, 46.07191024507795, 44.09847593307495, 48.0390807560512, 45.65550470352173, 45.32801873343331, 44.25779117856707, 45.01415123258318, 43.93486670085362, 42.805707999638145, 37.89405420848301, 35.43207468305315, 32.76142338344029, 34.41833945683071, 34.08591331754412, 33.762488569532124, 34.50950329644339, 36.154555320739746, 34.7845790045602, 34.27036019733974, 35.853274481637136, 36.28167608806065, 37.399217401232036, 35.884256499154226, 33.0816901751927, 34.48289169584002, 33.346162932259695, 34.21495873587472, 33.820123876844136, 33.389689922332764, 33.910606792994905, 34.745530128479004, 40.986141545431956, 46.46928119659424, 44.42835208347866, 45.565904208592, 44.34920515332903, 43.5033175604684, 44.95078018733433, 46.439324038369314, 45.498815877096995, 44.58153206961495, 42.21223109109061, 40.61294685091291, 37.85023191996983, 34.171362263815745, 33.04757104601179, 36.36132328850882, 39.05821793419974, 41.426302977970664, 43.08052315030779, 44.85670852661133, 45.7843416758946, 45.19440834862845, 42.925289971487864, 40.48473869051252, 19.508309534617833, 0.8572914866464478, 1.7231428282601493, 6.58270206621715, 0.8647443524428776, 0.05367556354030967, 0.15587102887885912, 0.051601407517279894, 0.06408499301012073, 1.3985233157873154, 8.199931332043239, 27.581193923950195, 38.21957383837019, 29.252100195203507, 29.892963818141393, 36.212478978293284, 5.754721283912659, 0.07702955483858075, 0.049557290239525695, 0.07277328108570405, 0.02100268764687436, 0.014230272034183145, 0.06077283288219145, 0.019978118428428258, 0.02652965732184904, 0.029092996381223202, 0.04818771819451025, 0.016472412971779704, 0.03383549815043807, 0.05519718849765403, 0.033386894900883944, 0.013611397207049387, 0.1113866666065795, 0.11333422495850495, 0.14755459156419548, 0.10933329750384603, 0.18359016148107393, 0.07551554643682071, 0.2100795307861907, 0.11595687137118407, 0.14673262781330518, 0.26598217178668293, 0.19495850003191403, 0.14242033420928887, 0.13576907611318997, 0.15803607127496175, 0.08801513857075147, 0.09545315123562302, 0.2552016888345991, 0.12316094551767622, 0.21651277558079787, 0.20090077045772756, 4.363830889974322, 46.57570675441197, 50.35635362352644, 33.99479464122227, 37.9050566809518, 39.426264013562886, 39.20102078574044, 49.21228756223406, 1.3332622519561221, 0.44802122935652733, 2.393501554216657, 14.498284884861537, 2.825993912560599, 0.752179735473224, 8.172115956033979, 29.704789229801722, 51.89689779281616, 47.68179743630545, 49.10915892464774, 49.616662297930034, 52.87018060684204, 48.878701073782786, 42.703673703329905, 40.030812876565115, 42.02496671676636, 37.66152926853725, 40.78701312201363, 42.69627387183053, 45.575072356632774, 46.92441252299717, 49.25441101619175, 46.734785761152, 49.554389068058555, 47.13856642586844, 50.67349720001221, 50.00433703831264, 51.299554211752756, 49.465577193668906, 48.38891908100673, 48.918642793382915, 48.797250815800254, 49.124121870313374, 49.55439601625715, 41.165266105106895, 37.42112507138933, 35.74982622691563, 38.87497309276036, 37.748802116939, 39.32308326448713, 37.41733830315726, 38.65623337881905, 36.75598096847534, 39.46930462973458, 39.020100116729736, 39.64996474129813, 36.676646436963765, 46.75168030602591, 45.886052880968364, 51.26222154072353, 44.94075741086687, 46.59671810695103, 26.264612776892527, 37.30914790289742, 54.63972350529262, 47.00185367039272, 51.59133338928223, 47.62940107073103, 48.89440747669765, 49.9735426221575, 46.48648146220616, 47.37752192361014, 51.32497419629778, 48.429135254451204, 48.12329639707293, 46.31177943093436, 47.353474208286826, 45.21504102434431, 44.84521273204258, 38.6827893938337, 36.913270814078196, 34.944741930280415, 35.6039696420942, 35.333580493927, 35.16168900898525, 36.252841063908164, 36.69408988952637, 36.5202876499721, 37.0433098248073, 37.241948400224956, 37.16802304131644, 38.8405065536499, 38.13805062430245, 35.42215265546526, 37.40706886563982, 34.469502517155235, 35.285808154514854, 34.5362434387207, 35.82722915921892, 36.456246103559224, 36.64467082704817, 42.22170843396868, 48.941418988364084, 46.116976261138916, 46.58045584814889, 44.927767753601074, 43.71539395196097, 45.643272399902344, 46.63466221945626, 47.93882172448294, 46.66429628644671, 43.61803579330444, 43.24228763580322, 40.98205600466047, 37.160887241363525, 34.029195172446116, 37.59974936076573, 40.69423035212925, 42.39666060038975, 46.25304283414568, 46.86011389323643, 48.713789054325645, 45.90270076479231, 45.25784192766462, 40.75747980390276, 21.524325881685527, 1.7413504741021564, 2.115020577396665, 11.864403452192034, 1.1585146231310708, 0.5917636347668511, 0.683478227683476, 0.12499479497117655, 0.20145528284566744, 3.4734502903052737, 13.084782447133746, 32.48315497807094, 41.8861208643232, 38.01668643951416, 35.58557081222534, 47.17335953031267, 9.109342830521719, 0.2312092605446066, 0.13735851725297316, 0.20526615264160292, 0.13089752037610325, 0.15644616873136588, 0.14099543781152793, 0.1065723452983158, 0.10762285999953747, 0.09286074712872505, 0.12338744050690106, 0.235157737242324, 0.19543009544057505, 0.20991403609514236, 0.1635982942368303, 0.12551597771900042], [0.041788793701146326, 0.015667429559731057, 0.022704589180648327, 0.08359678315797023, 0.06999796429382903, 0.05926904321781226, 0.029651851393282413, 0.0034831526489662273, 0.004015451496733087, 0.052866997463362556, 0.0236763327515551, 0.04281770384737423, 0.03197277703189424, 0.02867186701457415, 0.0391939604388816, 0.08563017618975469, 0.046043761274112124, 0.026293425355106592, 0.06556891516915389, 0.06124934766973768, 0.5042198066200528, 19.09224271774292, 45.38279138292585, 30.77722978591919, 23.632859230041504, 36.16567243848528, 30.079790455954416, 42.132531779153005, 2.541349232196808, 0.4190492768372808, 0.1990269281502281, 0.616870678961277, 0.28518957112516674, 0.14747334378106253, 0.7346931823662349, 6.797516047954559, 37.013255391802105, 49.12784610475813, 47.85988324029105, 49.085712228502544, 46.022880281720845, 44.23681456702096, 40.86186259133475, 37.858475957598, 37.17353991099766, 35.44523804528372, 38.06875971385411, 37.92807953698294, 39.22746215547834, 42.12487486430577, 45.119680472782676, 44.16708592006138, 45.33987930842808, 45.14267553601946, 44.26907157897949, 45.37602036339896, 45.843727929251536, 45.71169825962612, 45.07690736225673, 47.09145763942173, 47.77274588176182, 45.29330553327288, 46.017888001033235, 40.96289982114519, 33.5499883379255, 32.79060581752232, 33.74537863050188, 33.876769065856934, 34.55644185202462, 34.929907526288716, 36.79272304262434, 33.331787109375, 33.04004267283848, 32.91937330790928, 35.237848213740754, 31.915938786097936, 36.846356187547954, 40.63632753917149, 45.33454656600952, 44.43146487644741, 49.57980210440499, 28.63381126948765, 31.82356595993042, 48.54806409563337, 43.93136133466448, 46.230322224753245, 45.72934668404715, 43.68283469336373, 46.52329996653965, 42.698014395577566, 42.50043889454433, 46.89478887830462, 44.3683682850429, 41.73099190848214, 38.94077600751604, 39.23690823146275, 34.89130333491734, 35.00094243458339, 33.25180639539446, 34.40459244591849, 32.85360860824585, 33.40656362261091, 32.53754547664097, 32.16631712232317, 32.2163267816816, 33.02398191179548, 31.46079008919852, 33.240894249507356, 32.49556793485369, 33.897186347416465, 32.696575845990864, 33.685036999838694, 32.17120170593262, 34.73741463252476, 34.07924999509539, 33.197502749306814, 33.987707478659495, 32.70439951760428, 33.57732949938093, 32.72479942866734, 32.02029725483486, 38.997212750571116, 41.73331608091082, 43.6518874168396, 45.69442156382969, 43.52256754466465, 43.682317052568706, 44.60277966090611, 44.64264495032174, 43.519961970193044, 41.93347978591919, 39.89689677102225, 38.49519498007638, 34.61177730560303, 32.13871192932129, 31.50199638094221, 33.68309497833252, 35.26674229758126, 36.94408260072981, 40.73480783190046, 41.43110418319702, 44.11502306801932, 43.71477903638567, 33.258438450949534, 5.164921709469386, 0.1043984005227685, 2.7887498310634067, 3.483875193766185, 0.284938811723675, 0.10219538052167211, 0.16830440956567014, 0.03297477647928255, 0.0747901178630335, 0.50657057762146, 7.627493568829127, 24.428924764905656, 25.867354733603342, 43.52992221287319, 30.276393209184917, 24.314712013517106, 1.0122356095484324, 0.08919214577014957, 0.058417407130556445, 0.03515314530315144, 0.03912188305652567, 0.01562072429805994, 0.06509810007576432, 0.05606293472062264, 0.05343794396945408, 0.003389226014925433, 0.028453989420086145, 0.08367189019918442, 0.010210195473129196, 0.044853563353951485, 0.029468579084745476, 0.045077666507235596, 0.08024716789701156, 0.010453139847543622, 0.0871772292469229, 0.08355565036513976, 0.07112545200756618, 0.042991673440805504, 0.0358613255167646, 0.021335490413808396, 0.01028602515413825, 0.04687803704291582, 0.017436562039490257, 0.031699303670653274, 0.03544526141402977, 0.06991172249295882, 0.12128569185733795, 0.022745511627623012, 0.05458678857290319, 0.06837477960756846, 0.04368552638749991, 0.12639153216566357, 0.9293994030782154, 27.033748831067765, 48.280759947640554, 32.10341855457851, 25.862822771072388, 39.68636982781546, 32.54931572505406, 47.33262266431536, 2.4008900948933194, 0.5373905609760965, 0.298292055193867, 0.5861582841191972, 0.562539837190083, 0.5731351343648774, 1.2481423680271422, 10.489721468516759, 40.29348605019705, 49.312133175986155, 49.865247998918804, 51.08342702048165, 48.3918581690107, 46.50960506711687, 43.50337662015642, 38.61609016145979, 39.81242404665266, 36.48613725389753, 40.32138654163906, 39.70608881541661, 41.46966668537685, 44.48392030170986, 47.2892415864127, 47.62087563105992, 46.93242032187325, 46.279904569898335, 47.47043670926775, 46.75166640962873, 47.81307322638375, 46.67668839863369, 46.912649222782676, 48.1892591203962, 46.88223000935146, 46.17979492459978, 46.74572569983346, 42.18569939477103, 35.528984682900564, 35.2460401398795, 35.27690403802054, 36.199617862701416, 35.479530879429404, 36.32672125952584, 37.545087882450645, 35.30289724894932, 35.33339636666434, 33.74396119798933, 37.798665864127024, 34.43496649605887, 39.0877616746085, 43.73990372249058, 47.83447715214321, 44.704369272504536, 50.3943498475211, 29.442126478467667, 31.757585866110666, 50.167463370731895, 46.02068812506539, 46.677688939230784, 45.80457830429077, 46.090458461216514, 47.14911726542881, 44.57289545876639, 44.47264684949602, 48.997636863163535, 46.439966746738975, 44.48001194000244, 41.616193771362305, 40.47433376312256, 37.0473119871957, 37.264853136880056, 34.011647496904644, 34.817697593144004, 33.8080861227853, 35.04318748201643, 33.565489768981934, 34.3113545690264, 33.55602979660034, 33.97182389668056, 33.2161134992327, 34.93189123698643, 34.446615150996614, 37.09897531781878, 34.281484263283865, 34.93038347789219, 33.04454857962472, 35.174341678619385, 34.50862782342093, 34.384439195905415, 33.223006112234934, 32.90379197256905, 34.47846221923828, 35.013341494968955, 33.598452023097444, 40.89311906269619, 43.31694255556379, 44.58853932789394, 46.30490071432931, 44.32055425643921, 43.77122620173863, 44.25174624579293, 44.461303915296284, 44.94062539509365, 44.04257072721209, 42.09137412479946, 40.181418555123464, 37.324673652648926, 32.871858051845, 34.69423852648054, 35.8603755405971, 37.23881823675973, 38.72732734680176, 42.5430452483041, 44.05643238340105, 46.49724074772426, 43.56248147147042, 36.18992165156773, 6.60934363092695, 0.5572232167635645, 4.4241364768573215, 8.0138464144298, 1.6810567208698817, 0.1779018531420401, 0.04810594115406275, 0.07481588862304177, 0.08944808239383356, 1.3573994253362929, 11.034303035054888, 29.09752709524972, 31.464712347303117, 44.12595953260149, 34.10009459086827, 32.66406175068447, 1.5087443270853587, 0.15522457499589237, 0.032280591050429006, 0.05632609095690506, 0.02573689941449889, 0.039053500297346284, 0.05024083284661174, 0.04129894909315875, 0.051541017900620184, 0.02785303470279489, 0.00981918373145163, 0.0648714897355863, 0.00558288604952395, 0.05367736165810909, 0.06792282778769732, 0.011073894216679037, 0.19062757385628565, 0.08239042931901557, 0.169029315667493, 0.12181755474635533, 0.1778894630925996, 0.1559968428420169, 0.0924906741295542, 0.16289994599563734, 0.06972895230033568, 0.16048060224524566, 0.182424804727946, 0.18587780158434594, 0.08970620390027761, 0.12196115989770208, 0.2407952504498618, 0.19754455983638763, 0.12967382318207196, 0.14258821734360286, 0.20060372139726365, 0.2505732386239937, 0.7272477533136095, 29.09585084233965, 56.12379271643502, 40.24749592372349, 32.37698302950178, 47.15237249646868, 38.11089359010969, 50.71994938169207, 3.297621782336916, 0.9277441033295223, 0.47336334522281376, 3.7529018436159407, 2.9837558014052252, 1.540371115718569, 1.8848990627697535, 9.775893943650381, 41.83927958352225, 48.935818740299766, 51.41284458977835, 52.201687472207205, 50.7673465183803, 48.667552266802105, 45.993211473737446, 40.66763612202236, 41.39558499200003, 38.33026211602347, 42.04682574953352, 40.553633553641184, 42.01577772412981, 45.390020983559744, 49.306414808545796, 48.21250431878226, 48.93571104322161, 48.90041766847883, 49.33894280024937, 48.88033390045166, 50.15787138257708, 49.58601726804461, 50.59101166043963, 50.157252992902485, 49.04737206867763, 48.10305629457746, 49.10258592878069, 45.44484574454171, 37.586249010903494, 35.962958744594026, 37.73247732434954, 37.878448554447715, 38.75845875058855, 37.35000678471157, 40.40676948002407, 36.55644260134016, 36.2354462487357, 35.84101438522339, 39.04850435256958, 36.48728370666504, 40.68502746309553, 44.882764271327424, 49.76406833103725, 46.62113407679966, 54.23379584721157, 30.839364051818848, 31.301255975450786, 51.52052777154105, 46.79355362483433, 48.131766251155305, 48.442104067121235, 47.78599609647478, 49.05051612854004, 43.64090926306588, 46.63618734904698, 50.64480461393084, 48.913893699645996, 46.11896692003523, 43.021237645830425, 42.95558411734444, 39.58905335835048, 38.29797731127058, 36.12543542044503, 36.654530320848735, 35.0741799218314, 36.569977692195344, 36.075627258845735, 35.872618266514365, 36.01261057172503, 36.215094975062776, 33.62751981190273, 36.4069937978472, 36.42622988564627, 38.35269437517439, 35.20171410696847, 36.426431383405415, 34.37811633518764, 37.390716280256, 36.58246013096401, 35.20835311072213, 35.12541593824114, 34.58738565444946, 37.2595203944615, 35.39873027801514, 34.571213722229004, 42.33830615452358, 44.92971672330584, 46.893201214926584, 46.79599939073835, 46.308485984802246, 45.22653681891305, 45.60651295525687, 46.65650388172695, 45.94710670198713, 45.08435583114624, 43.150192737579346, 42.27228437151228, 39.13927909306118, 35.56713376726423, 35.92204775129046, 38.16281747817993, 38.57416125706264, 39.89441973822457, 43.52436017990112, 45.93324851989746, 48.823348249707905, 46.03523070471627, 37.124509947640554, 8.39252758026123, 0.1887868576283966, 6.621737914425986, 9.033872365951538, 0.9350846580096653, 0.2300949160541807, 0.3784555665084294, 0.28635203731911524, 0.5355955915791648, 3.529126205614635, 14.468047193118505, 33.56160920006888, 34.075216565813335, 47.367221219199045, 43.122914109911235, 38.56501047951834, 2.2714145396436964, 0.28874873157058445, 0.15078287119311945, 0.11602241785398551, 0.1796301089759384, 0.10969367423760039, 0.21426468049841269, 0.18433672642069204, 0.1680551836533206, 0.08160644995846919, 0.08705256879329681, 0.16578779103500502, 0.12981474133474485, 0.1298895701766014, 0.1513126034821783, 0.1456893395100321], [0.05055302680869188, 0.032633768527635505, 0.029477922511952262, 0.041834028238164525, 0.01129206782206893, 0.02250189211086503, 0.0558905087943588, 0.08119730691292457, 0.033070365100034645, 0.024186289137495414, 0.009578465800067144, 0.035904358207647286, 0.08422423806041479, 0.08003965153225831, 0.03485492916245546, 0.12807405473930494, 0.044272092769720724, 0.06735417472996882, 0.03982589367244925, 0.06215038789170129, 0.050374358360256465, 6.1277240344456265, 39.802748680114746, 40.84551348005022, 28.293363434927805, 32.596820558820454, 30.568815095084055, 36.49544436591012, 3.710002362728119, 0.21567223354109696, 0.31426037262593, 0.08037743983524186, 0.6713587780083928, 0.5100599303841591, 0.2777137708451067, 0.7084225863218307, 12.257456966808864, 39.76752826145717, 50.28530829293387, 48.364496162959504, 46.901476519448416, 43.67583090918404, 40.73752805164882, 37.71243177141462, 37.80831343787057, 36.90824031829834, 36.65841783796038, 37.611332007816856, 39.75292314801897, 39.20181288037981, 39.51265096664429, 39.006540707179475, 37.419995989118306, 38.21930285862514, 38.83449636186872, 40.613426276615684, 42.44152511869158, 42.413367543901714, 41.61116327558245, 44.3241742679051, 44.73872464043753, 43.94703994478498, 45.18470866339547, 43.81126867021833, 34.45593268530709, 31.796759809766495, 33.27619457244873, 34.5757543700082, 34.215299197605674, 34.62851204190935, 36.100171770368306, 33.63635444641113, 33.22550746372768, 33.17779418400356, 32.325458662850515, 33.40652540751866, 33.97964409419468, 36.331828185490195, 44.59004013878958, 43.396541118621826, 44.846741335732595, 50.795743806021555, 44.072934355054585, 40.416344097682405, 44.95789514269148, 44.81603724615914, 47.49465812955584, 43.6937711579459, 45.40835380554199, 42.9380190713065, 45.87508167539324, 46.50300775255476, 43.16870968682425, 41.38980409077236, 38.56936352593558, 36.40378720419747, 33.95805604117257, 32.96981028148106, 33.66221564156668, 33.41143083572388, 34.26683746065412, 33.404791831970215, 31.492793491908483, 33.399500778743196, 32.323040689740864, 32.315991742270334, 32.23303025109427, 33.557558400290354, 32.65991020202637, 33.30439383643014, 33.65316908700125, 33.733834198543, 33.04661566870553, 32.91966165815081, 31.58258158820016, 33.19251046861921, 32.032949924468994, 34.0274372782026, 33.318140847342356, 32.231998443603516, 32.21628509249006, 32.807743549346924, 36.23370572498867, 41.16658973693848, 43.399858883449006, 44.33162273679461, 45.63913822174072, 43.52716377803257, 43.051757608141216, 43.699159485953196, 43.644390310559956, 43.606435775756836, 40.70074428830828, 38.14200414930071, 36.04300546646118, 32.25584118706839, 31.52495322908674, 31.974602426801408, 35.2230589730399, 38.95404359272548, 41.875601291656494, 44.43478264127459, 43.907414368220735, 23.13506075314113, 0.38157948745148523, 0.6844865307211876, 2.4041763756956374, 7.252628266811371, 3.098984509706497, 0.225145640916058, 0.034936896192708185, 0.12115469388663769, 0.1749653842832361, 0.14817403975342, 13.64188119343349, 25.38934472629002, 24.879633562905447, 39.55265522003174, 30.94064794267927, 13.03924482209342, 0.09277856975261654, 0.010510024830832012, 0.0852509904652834, 0.059971204825810025, 0.05161499857370343, 0.031460055615752935, 0.08331095028136458, 0.06001893297902175, 0.04984212227697883, 0.02858051923768861, 0.05512106365391186, 0.05825848065848861, 0.07202715040849787, 0.038037400892270465, 0.034988943221313615, 0.03491415509155818, 0.03061551700479218, 0.00923457068191575, 0.06568896837000336, 0.03944190052737083, 0.05257254719202008, 0.03031464439949819, 0.023342876894665614, 0.009261606061565024, 0.03637995358024325, 0.00461784640460142, 0.01214094736081149, 0.025473819513406073, 0.029615359779979502, 0.06867485493421555, 0.027255606671263064, 0.11333647090941668, 0.016513082664459944, 0.02498561526382608, 0.024355412294555987, 0.0647030637732574, 0.02132292733793812, 9.777348722730364, 46.71574422291347, 41.1527350289481, 28.735027415411814, 42.39607695170811, 34.10073035103934, 42.57804332460676, 4.032623291015625, 1.116476610302925, 1.9091454531465257, 0.15768646289195332, 0.38444928345935686, 0.6007614433765411, 0.38454275844352587, 0.9688342298780168, 16.291479451315745, 42.590755053928916, 49.88720083236694, 50.45192609514509, 49.33141095297677, 45.246801240103586, 43.372013977595735, 40.57369647707258, 39.495388167245046, 38.747525760105674, 39.00650249208723, 40.06030797958374, 41.31994342803955, 41.12190587180001, 41.15405171258109, 41.67872755868094, 40.686479636601035, 40.304509367261616, 41.990482807159424, 42.63901376724243, 45.184861523764475, 44.53946420124599, 45.03376947130476, 45.6824254989624, 46.20496824809483, 46.23840992791312, 46.86578362328665, 43.59493998118809, 36.44115114212036, 34.432253224509104, 33.34226846694946, 35.22540051596505, 35.6422472681318, 37.421409947531565, 36.81928947993687, 36.29188299179077, 34.913151945386616, 35.414815357753206, 33.72733415876116, 36.004137243543354, 35.57161882945469, 40.60115923200335, 45.51590149743216, 45.72553212302071, 45.84729930332729, 53.63597284044538, 44.43006828853062, 40.62923342841012, 45.59429802213396, 45.21657657623291, 48.942231927599224, 45.073245661599294, 45.737962450299946, 43.12548494338989, 46.217923164367676, 47.730379240853445, 44.93878064836775, 43.74739735467093, 39.79518904004778, 37.95964172908238, 34.93212400163923, 35.702238014766145, 35.53346627099173, 35.220741748809814, 35.83915226800101, 34.87095553534371, 33.44375385556902, 33.8993124961853, 34.4043527330671, 34.12484407424927, 33.910909039633616, 35.09371130807059, 33.907212597983225, 34.96939761298043, 34.62190777914864, 35.07888732637678, 34.30354131971087, 35.70989840371268, 33.250010286058696, 34.617221219199045, 34.37348883492606, 34.56802797317505, 34.32435117449079, 32.52170010975429, 34.154075145721436, 34.144222600119456, 38.29266193934849, 43.81866502761841, 44.93498345783779, 46.60349954877581, 46.09157017299107, 46.62854780469622, 44.534732478005544, 44.4257048198155, 44.41950355257307, 46.04526737758091, 42.4147606577192, 39.56575952257429, 36.534083298274446, 33.89279856000628, 33.54625368118286, 33.858811446598594, 37.020012514931814, 42.24056237084525, 44.39482355117798, 45.78868430001395, 44.458166803632466, 25.31958133833749, 1.1139695048332214, 1.87956480043275, 5.835917932646615, 7.735030838421412, 2.3514853630747115, 0.11467572940247399, 0.07001065289867775, 0.05258324768926416, 0.14817132561334542, 0.9849500336817333, 15.349159547260829, 32.3927241734096, 27.48914245196751, 42.177681173597065, 36.02927582604544, 17.530761889048986, 0.04544363436954362, 0.04976783287046211, 0.06072906737348863, 0.02807920569154833, 0.026485004628609334, 0.06249857135117054, 0.024983727240136692, 0.0978908697143197, 0.006501484637348247, 0.021926016047863022, 0.08752081223896571, 0.08234468248805829, 0.01846118045172521, 0.056647743697145155, 0.014968748836378967, 0.03117636012445603, 0.11672669649124146, 0.1005683010444045, 0.11462570780089923, 0.19671229592391423, 0.13885522979710782, 0.18350890012724058, 0.20683018943028791, 0.12006094971937792, 0.1444836642060961, 0.1361740936658212, 0.14665047079324722, 0.10765564681163856, 0.19971724253680023, 0.1694139635988644, 0.1023043261042663, 0.18369059823453426, 0.14456371776759624, 0.1121157660548176, 0.08133025227912835, 0.13868991152516433, 0.26467903171266827, 11.094400610242571, 50.73816755839756, 51.76770646231515, 38.34431832177298, 42.12609427315848, 37.98331424168178, 44.83873701095581, 5.133027306624821, 2.013301989861897, 3.887312574045999, 0.7524944128734725, 2.0817680188587735, 1.680066711136273, 0.7361088778291429, 1.1848886821951186, 16.958285910742624, 42.79626887185233, 51.912173407418386, 52.53997441700527, 52.149499552590505, 47.93388850348336, 45.56549079077584, 42.41511154174805, 41.94813353674752, 40.01163237435477, 40.09603214263916, 41.01137392861502, 44.57161004202706, 42.799260071345735, 42.193561281476704, 42.847452776772634, 42.900516169411794, 41.09767402921404, 41.79698589869908, 44.22385270254952, 48.05488790784563, 45.30817467825753, 45.83233983176095, 46.670038972582134, 48.095760686056956, 47.1790257862636, 48.75748627526419, 46.30820458275931, 38.225479807172505, 35.52287026814052, 35.71018327985491, 37.099083014896934, 37.91125447409493, 38.30029453550066, 39.728597504752024, 35.26123932429722, 36.07575580051967, 37.54877390180315, 35.613999366760254, 36.506325244903564, 37.711087294987266, 40.93435314723423, 49.113883699689595, 47.83587721415928, 47.74344880240304, 51.8566711970738, 44.33167832238333, 41.99199056625366, 45.818617139543804, 46.8779672895159, 51.042835644313264, 46.96535478319441, 47.82379082271031, 46.09663540976388, 48.146249771118164, 50.7183895111084, 47.032651560647146, 46.680562019348145, 41.66231938770839, 40.80229568481445, 37.227499621255056, 36.73099872044155, 37.36397961207798, 37.25072397504534, 36.96816158294678, 36.60849155698504, 35.103775773729595, 36.27628081185477, 35.84694814682007, 35.80648878642491, 33.71761015483311, 36.42194284711565, 36.32634605680193, 36.156448704855784, 36.49750798089163, 36.756161621638704, 36.25928899220058, 36.97921616690499, 34.87079225267683, 36.62645265034267, 34.279038497379844, 36.13628155844552, 36.72915397371565, 34.53957857404436, 35.28842067718506, 35.25013262884957, 39.8767991065979, 44.32619619369507, 46.93972635269165, 47.29390035356794, 49.30143642425537, 47.01029920578003, 44.34972974232265, 44.622071334293906, 45.72541052954537, 48.10762126105172, 45.03513479232788, 42.4289801461356, 40.46166024889265, 35.76315287181309, 34.936268602098735, 35.153160095214844, 39.19210972104754, 43.83660180228097, 46.87598705291748, 48.85261058807373, 44.825611863817485, 26.48555506978716, 0.8898768009884017, 1.3731319925614764, 6.8503475444657465, 14.380013516971044, 8.582248142787389, 0.3535547969596726, 0.15301025738673552, 0.21400402805634908, 0.99159793981484, 2.0511056184768677, 22.92587307521275, 36.30386863436018, 33.45471463884626, 44.885637351444785, 45.68431888307844, 22.249809878213064, 0.11999312335891382, 0.0936311897156494, 0.18825392265404972, 0.10513746086508036, 0.17191104032099247, 0.13939052607331956, 0.12833314655082567, 0.1725766696035862, 0.1325131393969059, 0.1507656771157469, 0.12944062426686287, 0.12994090813611234, 0.09779951175940887, 0.14041538536548615, 0.06129980353372438, 0.14665912890008517], [0.01782626675308815, 0.01284619206230023, 0.017342267724286233, 0.040144157130271196, 0.028594649729451964, 0.056845166853496006, 0.040467180511248965, 0.026174261035131555, 0.10046994060810123, 0.06355348974466324, 0.02742606823864792, 0.08717438618519477, 0.09249426357980285, 0.07172495126724243, 0.011838434397109916, 0.014360275951081088, 0.038264282646455934, 0.015347356109746864, 0.01604246604256332, 0.03857799991965294, 0.06289284090910639, 0.9794468432664871, 19.183340549468994, 45.71803501674107, 25.39492412975856, 32.934457847050254, 32.66760533196585, 34.78375564302717, 10.191886067390442, 0.10109353464628969, 0.8919276595115662, 0.13281925368521894, 0.20537732381905827, 0.1295026016554662, 0.06133316031524113, 0.8089069457990783, 1.0403175141130174, 18.716510193688528, 47.4662504196167, 49.67268214906965, 48.86117076873779, 44.61609240940639, 42.573176111493794, 38.06250286102295, 36.70278903416225, 36.08943680354527, 37.717920848301475, 36.00097928728376, 35.82046161379133, 34.59030737195696, 34.8823436328343, 36.69831439426967, 36.33788354056222, 34.23935038702828, 34.44054937362671, 35.4540170942034, 37.272346769060405, 39.70134319577898, 40.85112762451172, 43.668097564152305, 46.241529669080464, 47.210313524518696, 44.2656044278826, 43.50497817993164, 34.7004189491272, 32.792516572134836, 33.71498720986502, 34.23424693516323, 34.76038537706648, 34.58243158885411, 34.096853256225586, 34.70911809376308, 34.72464731761387, 32.88810641424996, 34.27196523121425, 32.79174184799194, 33.4088773727417, 34.03703621455601, 39.39587606702532, 44.722486700330464, 45.78500175476074, 44.23607110977173, 46.518602984292166, 47.00573771340506, 46.55270821707589, 43.10940681185041, 44.113261699676514, 43.39508547101702, 44.7239145551409, 42.41210297175816, 43.3675080708095, 45.23863015856062, 45.147428103855674, 41.498790059770855, 39.12163414273943, 36.856580461774556, 34.55694212232317, 33.64219440732683, 34.23428167615618, 35.055687291281565, 33.85477106911795, 31.36699983051845, 32.903993470328196, 33.995416504996165, 33.60362148284912, 33.6701192174639, 32.23044899531773, 33.748967375074116, 32.97964545658657, 34.916348116738455, 33.372823170253206, 35.53888586589268, 32.37443651471819, 33.316733837127686, 32.75143187386649, 32.35017687933785, 33.35836396898542, 31.942901270730154, 32.57036529268537, 33.0314998626709, 32.2221736907959, 31.892926352364675, 32.98434591293335, 32.51293495723179, 37.60738890511649, 38.8166811806815, 44.644124916621614, 44.369379247937886, 44.18755531311035, 42.63266658782959, 43.1635228565761, 43.10516493661063, 43.12717335564749, 39.97278847013201, 39.58670834132603, 36.79422385351998, 34.49303953988211, 33.517710481371196, 36.3942369052342, 38.55860424041748, 41.01515374864851, 44.76001739501953, 42.34853390284947, 9.892789568219866, 0.08572122201855693, 4.825072288513184, 5.399684837886265, 7.3017507280622205, 3.1380655212061743, 0.33026256252612385, 0.05917224341205188, 0.048346515744924545, 0.23014729895762034, 2.428727401154382, 21.423957415989467, 25.270000730242046, 27.198803288596018, 41.99290772846767, 29.952749592917307, 3.1935568749904633, 0.07627886440604925, 0.01005956154715802, 0.07515207558338131, 0.04572535193126116, 0.005333401021614138, 0.02698533938798521, 0.046958467191351314, 0.04190948472491332, 0.022397764126903245, 0.023538752991173948, 0.029905219761920825, 0.04346753344205873, 0.03808863028617842, 0.013337276693034385, 0.05596966329695923, 0.06310831648962838, 0.04387483765770282, 0.021133236088124768, 0.016088133145655905, 0.036362287921032736, 0.011541297127093588, 0.019030817385230745, 0.004634018014517746, 0.021768819840092744, 0.02577978791669011, 0.031191691623202393, 0.038945799826511314, 0.08685320163411753, 0.028409438507099236, 0.012240911684265094, 0.015025710154856955, 0.020325355331546495, 0.0564535876869091, 0.01520210042196725, 0.020945934977914606, 0.01704092862616692, 0.02386422249089394, 1.4790830101285661, 26.22966854912894, 51.33177995681763, 28.756040505000524, 33.38221713474819, 38.65967968532017, 37.71409239087786, 9.765301414898463, 0.05732546786644629, 2.057880763496671, 0.46539707268987385, 0.07421173461313758, 0.3895484741244997, 0.21354351990989276, 1.090592507805143, 2.755221515893936, 22.63109401294163, 49.905262674604145, 51.13868951797485, 50.96580444063459, 47.25751263754708, 44.1548501423427, 40.29417044775826, 38.348344802856445, 37.36553600856236, 38.30717325210571, 38.222655364445274, 37.28614936556135, 35.64891059058053, 36.88332060405186, 37.64413792746407, 37.224994795663015, 35.936374936785015, 36.32854516165597, 37.71660763876778, 39.75724145344326, 40.831161975860596, 43.39783695765904, 44.874301365443635, 47.62561777659825, 47.908683913094656, 46.750638076237266, 45.56126628603254, 35.77173042297363, 34.77316311427525, 36.81928947993687, 34.85087176731655, 35.98124640328543, 36.82594585418701, 35.771921498434885, 36.56630209514073, 36.397523403167725, 33.914122581481934, 35.59465905598232, 33.915897846221924, 35.538090297154014, 35.87696089063372, 41.602207047598704, 44.81371307373047, 46.938889094761436, 45.39293227876936, 46.98212773459298, 46.48232643944876, 45.75477014269148, 44.11061096191406, 45.00324603489467, 44.2420882497515, 44.81060722896031, 42.654668058667866, 45.95695924758911, 47.47402892793928, 45.9312231200082, 43.25404051371983, 39.883611815316335, 38.650970118386404, 35.35649912697928, 35.387588841574534, 35.6160386630467, 35.1253707749503, 36.23139197485787, 33.6857213973999, 34.1889967918396, 35.012622356414795, 34.79845108304705, 36.02473170416695, 35.45543452671596, 34.525379930223735, 34.675085817064556, 34.85217455455235, 33.81071254185268, 36.908587728227886, 34.4165746143886, 34.15827185767037, 34.704223087855745, 33.68490498406546, 34.31190347671509, 33.237145696367534, 33.82649884905134, 34.37814065388271, 33.36725071498326, 32.34180430003575, 35.026814052036826, 34.079969133649556, 39.8090090070452, 40.594169344220845, 46.04902982711792, 46.19804089409964, 44.825413840157644, 42.648904527936665, 44.07729434967041, 44.82526445388794, 43.70173726763044, 40.61347838810512, 40.71570723397391, 38.295270987919395, 36.78112302507673, 34.4904339654105, 37.99527209145682, 39.58040632520403, 42.72800976889474, 45.51283734185355, 43.38315541403634, 11.296416010175433, 0.44303654826113154, 5.471320765359061, 8.112399663243975, 8.023653796740941, 0.9269026113407952, 0.15266689152589866, 0.009795664859536504, 0.18115635136408464, 0.6796247458883694, 2.8782949575356076, 27.197224310466222, 30.586428778512136, 27.334388698850358, 44.450165952954976, 35.91536358424595, 5.74793723651341, 0.11957351730338164, 0.03547589387744665, 0.02577239697399948, 0.034090040384658744, 0.006324236447523747, 0.025489982217550278, 0.040376317886901755, 0.039831064109291346, 0.015640296640672853, 0.03288237018776791, 0.025168587320617268, 0.05757121289415019, 0.052435954700091054, 0.04466277627008302, 0.015993168777120963, 0.08999122932021107, 0.16516485517578466, 0.08674364537000656, 0.11577039637735911, 0.16742178478411265, 0.12315968344254152, 0.1175347909863506, 0.11980983747967652, 0.09387292460139308, 0.20842215472034045, 0.1384182668157986, 0.09974814219666378, 0.3026992758469922, 0.20499138667115144, 0.21963673723595484, 0.059429917085383616, 0.07434053413037743, 0.14576848383460725, 0.09140934036778552, 0.10316124797931739, 0.16990257666579314, 0.3133050224610737, 1.3928518486874444, 29.736306258610316, 58.38944394247872, 35.80840648923601, 41.880506719861714, 42.117078985486714, 43.78265251432146, 13.057527269635882, 0.1895781380257436, 5.713782497814723, 1.0432986170053482, 0.28754742603216854, 1.0049011345420564, 1.5075896233320236, 1.5504068114927836, 3.1888008330549513, 23.41805045945304, 50.58061020714896, 53.563968658447266, 54.16743360246931, 48.97400256565639, 46.64428547450474, 42.63262142453875, 40.364302090236116, 39.44688279288155, 40.81699807303292, 39.99902834211077, 38.47436080660139, 37.50296442849295, 39.629238264901296, 40.7792763028826, 40.86455154418945, 37.82534694671631, 37.773398739951, 38.75820861543928, 40.40021732875279, 42.83066245487758, 45.33887529373169, 47.841849190848215, 51.20143175125122, 50.40532800129482, 47.87043060575213, 47.088991028921946, 37.9377236366272, 36.41415044239589, 37.62568351200649, 38.16406120572771, 37.514859744480674, 38.56326995577131, 37.26859474182129, 38.2636775289263, 39.503858021327424, 36.32003709248134, 36.774160930088584, 36.25993864876883, 37.32189784731184, 37.66436413356236, 44.313665117536274, 47.62513835089547, 49.359346185411724, 46.21641540527344, 50.19380051749093, 48.52500649860927, 49.46579606192452, 44.83315413338797, 46.531439781188965, 44.74255657196045, 45.35677037920271, 43.78238500867571, 45.4908949307033, 48.75582912990025, 48.866635526929585, 44.581646714891704, 44.11771202087402, 40.00892605100359, 37.78565536226545, 36.928240707942415, 37.29105131966727, 37.48030982698713, 38.568880626133506, 34.60447474888393, 35.51161766052246, 36.095325401851106, 36.650396142687114, 37.733846119471956, 37.54838827678135, 35.866093908037456, 35.99536861692156, 37.879803453172954, 36.09250095912388, 38.66805921282087, 35.498964990888325, 36.161989893232075, 35.86394344057356, 35.66919585636684, 36.621026107243125, 35.25054604666573, 35.31246839250837, 35.91856670379639, 35.70872415815081, 33.39852455684117, 37.26849051884243, 35.197579928806846, 41.24204369953701, 41.47876535143171, 48.98916353498186, 47.2780237197876, 47.059860706329346, 44.64637265886579, 44.84526136943272, 46.47265454701015, 45.93681641987392, 43.12349428449358, 43.63000406537737, 39.75990261350359, 39.26443004608154, 36.0279278755188, 40.31529297147478, 41.65429769243513, 43.1584471975054, 48.39051021848406, 45.328557218824116, 11.524036390440804, 0.25883882652435986, 8.45775032043457, 13.839714646339417, 17.476475613457815, 8.171382921082632, 0.4438958992915494, 0.11829958137656961, 0.4710251678313528, 2.8820096382072995, 6.577126136847904, 31.501207760402135, 34.656485489436555, 35.254805292402, 47.358053071158274, 42.42272329330444, 6.607854110854013, 0.18221327822123254, 0.09870567492076329, 0.12903404608368874, 0.1891193397875343, 0.037281407708568234, 0.11873236458216395, 0.1206484389092241, 0.1409143800182002, 0.1738355013408831, 0.10532069924686636, 0.08528106313730989, 0.1204263408269201, 0.15171002144260065, 0.10586977656930685, 0.20771369630736963, 0.21012211564396108], [0.03620395516710622, 0.025311897309230905, 0.012546778307296336, 0.05318752722814679, 0.007971120665648153, 0.043425708543509245, 0.055351083632558584, 0.03564386522131307, 0.05443039642913001, 0.019849249361349002, 0.014081484571631466, 0.02790234553893762, 0.012972092538672899, 0.04691331407853535, 0.04256794528503503, 0.0719618753397039, 0.030423874966800213, 0.023720580020121167, 0.019141735808391656, 0.045866599173418114, 0.057706797761576514, 0.03942907960819347, 5.6257080010005405, 35.45176935195923, 35.09648016520909, 29.924988065447124, 32.384969983782085, 33.89840923036848, 15.787571770804268, 0.11060237511992455, 0.13869612690593514, 0.14416363994990075, 0.03631065140611359, 0.04343399006341185, 0.19655558147600719, 1.7492775001696177, 0.05217991290347917, 3.0554297268390656, 36.223505769457134, 53.01842737197876, 48.05494696753365, 46.08558429990496, 43.406984261104036, 41.407174587249756, 39.36651645387922, 37.39654234477452, 35.367247990199495, 36.803499698638916, 40.122584683554514, 38.97141408920288, 41.489573274339946, 44.79262529100691, 45.449560097285676, 43.755564962114605, 38.48551613943917, 35.29704686573574, 35.461722646440776, 35.924955572400776, 39.57647711890084, 45.684899057660786, 44.707033906664165, 45.79995427812849, 45.97198472704206, 41.9739738873073, 34.14330543790545, 35.78630426951817, 35.89202111107962, 33.7293039730617, 34.80653183800833, 34.29869842529297, 33.88365125656128, 34.005192620413645, 34.41447625841413, 33.45480496542794, 35.19118758610317, 32.60426207951137, 33.18382174628121, 33.95052766799927, 34.74035719462803, 40.813669885907856, 43.032858507973806, 45.78890664236886, 44.64391647066389, 45.18404858452933, 45.9477424621582, 46.11088963917324, 46.72172314780099, 45.28584664208548, 43.60299641745431, 40.168050221034456, 43.70154619216919, 45.61053943634033, 44.97346952983311, 41.94710520335606, 37.78076383045742, 35.68479108810425, 37.55751126153128, 37.24948719569615, 40.13855859211513, 38.72089678900582, 39.35923474175589, 35.01379312787737, 32.527199608939036, 32.406776905059814, 32.110238211495535, 33.09048312050955, 30.68171637398856, 32.63123151234218, 33.42935023988996, 31.9244954926627, 32.57191126687186, 32.077498299734934, 34.38722194944109, 31.81291437149048, 31.91233614512852, 31.373888969421387, 31.998233250209264, 32.99144002369472, 34.69056987762451, 33.813227789742605, 34.56362281526838, 33.066928727286204, 33.33923210416521, 31.405861105237687, 32.96559967313494, 35.51555381502424, 39.50074870245797, 41.57343455723354, 42.82241494315011, 43.23816735403878, 41.147242477961946, 40.72500739778791, 43.15763078417097, 41.23608561924526, 41.53422587258475, 40.99495880944388, 39.510000228881836, 37.56502226420811, 38.03093024662563, 40.90966272354126, 43.70904677254813, 44.27917078563145, 32.65961837768555, 2.5725075602531433, 0.8304968444364411, 4.079917507512229, 4.733614018985203, 5.433813955102648, 0.3144675972206252, 0.0951816625893116, 0.05167523891265903, 0.11377177826528038, 0.2160134416605745, 4.068567625113896, 28.439779349735804, 23.01843523979187, 34.78291491099766, 33.20989833559309, 13.63756115095956, 0.1660851522215775, 0.01689643120127065, 0.01342455665248313, 0.029967044480144978, 0.03166064074529069, 0.09768046279038702, 0.022596215263807347, 0.023801620850073438, 0.012825566294070865, 0.051963521300682, 0.017487168877518604, 0.03172318131795951, 0.0521578062325716, 0.026889104462627853, 0.07443854851382119, 0.03822839492931962, 0.03812708625836032, 0.022320119364719306, 0.044713422123874934, 0.033620612895382304, 0.05500766009624515, 0.010073898143933287, 0.07359297174428191, 0.03969123500532337, 0.02571677915485842, 0.06620611383446626, 0.02903534804603883, 0.013895493882176067, 0.0340065229018884, 0.05792616813310555, 0.08243414733026709, 0.06571999099105597, 0.03692214377224445, 0.07336079741695098, 0.059653433305876594, 0.06815416073160512, 0.03733271513400333, 0.04344896872394851, 0.07471315163586821, 9.163075855800084, 43.50057997022356, 34.91411427089146, 33.07649292264666, 40.46320274897984, 39.00138861792428, 19.629260301589966, 0.18129546461360796, 1.191491316471781, 0.5367123516542571, 0.13976088405719825, 0.16790388391486236, 0.3078998667853219, 2.2680754959583282, 0.3213628429387297, 4.088233198438372, 39.703764642987935, 53.63070263181414, 50.029343605041504, 47.28534712110247, 44.44820656095232, 41.87622315543038, 41.514989784785676, 38.33709566933768, 37.91417619160244, 37.18240581239973, 41.08041817801339, 40.43511813027518, 42.59245388848441, 45.67917026792254, 46.24843965257917, 44.780000414167134, 40.83585895810808, 35.28763900484358, 36.427914823804585, 38.55512319292341, 41.323334148951936, 46.60303749356951, 46.61392879486084, 47.46606281825474, 47.11539070946829, 43.90040363584246, 35.768714904785156, 35.64716311863491, 37.00978476660592, 35.62029096058437, 36.164876869746614, 36.23111057281494, 35.23033026286534, 34.6422312600272, 36.0529066494533, 34.92282036372593, 36.74521473475865, 33.94552149091448, 34.545154503413606, 35.94666869299752, 36.449565410614014, 42.71379722867693, 45.08957740238735, 46.76599359512329, 46.38717780794416, 47.0715024130685, 47.95322534016201, 48.122368812561035, 47.2097680909293, 45.49411889484951, 44.483788285936626, 40.040304115840364, 45.065981319972444, 48.949607440403526, 46.73176676886422, 43.27493722098214, 39.09138863427298, 36.37102992194039, 39.42711864198957, 38.72751842226301, 40.30850110735212, 41.570547580718994, 39.89684813363211, 36.39206211907523, 34.027263573237825, 34.303214754377095, 33.269451345716206, 34.89451687676566, 32.17037487030029, 33.07362331662859, 34.284527574266704, 33.402186257498606, 33.596225125449045, 34.03752606255667, 34.889955384390696, 34.1772334916251, 33.70274795804705, 33.477740968976704, 33.93495328085763, 34.82379811150687, 36.32119396754673, 35.04323959350586, 35.619769845690044, 33.336088044302805, 34.053958552224294, 34.18236821038382, 34.414726393563406, 37.21808481216431, 40.71218797138759, 43.01156227929251, 45.643915108272004, 44.813487257276265, 42.17820923668997, 42.15473822184971, 44.95942027228219, 43.08532782963344, 44.25151348114014, 42.63284724099295, 40.45691115515572, 38.87081807000296, 39.69760159083775, 42.9540068762643, 45.14221000671387, 45.07192202976772, 36.545419284275596, 3.0130309505122046, 1.4910625730242049, 6.846960297652653, 6.843978651932307, 5.020538577011653, 1.7561962774821689, 0.08069588310484375, 0.08389923335718256, 0.3702176356954234, 0.5445796666400773, 5.4729470780917575, 31.83689955302647, 26.212440490722656, 35.32531908580235, 40.56845753533499, 20.595629658017838, 0.6374166650431496, 0.027466822748205492, 0.07833513763866254, 0.009758002773326422, 0.041742958660636625, 0.02706372375333948, 0.014356021536514163, 0.03536402041624699, 0.005196783508706305, 0.035458838899752924, 0.01631010400264391, 0.010331084968389144, 0.11756327588643346, 0.026392540661618114, 0.0210564852958279, 0.017150333916236247, 0.06340299067752701, 0.13272599583225592, 0.1477376874536276, 0.08174702205828258, 0.0811469799705914, 0.14298779304538453, 0.20560896210372448, 0.19964249511914595, 0.07438307149069649, 0.10969921108335257, 0.11144002660044602, 0.08065668413681643, 0.1336735835564988, 0.16543719199086937, 0.15941203172717774, 0.14377117529511452, 0.1073866416034954, 0.15835625837956155, 0.10537319750125919, 0.13384990766644478, 0.15416103920766286, 0.10812739828335387, 0.1412331693406616, 10.407460008348737, 49.91739770344326, 45.024392877306255, 38.58875594820295, 41.642030647822786, 42.90276738575527, 21.853305714471, 0.667266343321119, 1.2955984558377946, 0.8300915147577013, 0.41783882464681354, 0.4539876420583044, 1.2752187379768916, 3.896389961242676, 0.42457016344581333, 4.787016136305673, 40.960485322134836, 54.74452665873936, 51.8464469228472, 48.36001110076904, 46.069794518607004, 45.15538379124233, 43.590364592415945, 40.60369185038975, 39.284454754420686, 39.149437359401155, 44.871000971112935, 43.35624156679426, 45.98416839327131, 49.073545932769775, 48.16894258771624, 48.352270807538716, 41.46666506358555, 38.02337408065796, 36.860273429325645, 39.66200596945626, 43.719302313668386, 49.21083886282784, 48.22194692066738, 48.747963769095286, 47.96695498057774, 44.36608232770647, 37.38069002968924, 38.65789747238159, 40.82807697568621, 38.0805264881679, 38.86206681387765, 37.503954546792166, 37.818655831473215, 37.148359639304026, 38.97898415156773, 36.46898215157645, 38.65113687515259, 36.22784491947719, 38.02621589388166, 38.254412106105256, 38.245546204703196, 44.47345284053257, 45.77761581965855, 47.68949951444353, 47.94947331292288, 48.61688947677612, 48.66219173158918, 48.41468300138201, 48.97434997558594, 47.952332496643066, 46.440053599221365, 41.41581119809832, 46.89105422156197, 49.91046340124947, 49.61176381792341, 44.895232813698904, 40.80097205298287, 37.76149647576468, 41.939625467572895, 39.2411709512983, 43.17963572910854, 44.37906503677368, 42.71518339429583, 38.59223004749843, 35.08349745614188, 36.623127937316895, 34.899731499808176, 35.60763829095023, 33.69582755225045, 34.87392241614205, 36.1015614100865, 34.37668153217861, 36.22761215482439, 34.657385281154085, 36.25434534890311, 34.54504680633545, 35.456876277923584, 35.58279848098755, 35.2750905581883, 36.29016331263951, 37.97090128489903, 37.01943234034947, 38.02537516185215, 36.01115492412022, 36.07985176358904, 35.65091514587402, 36.226309367588584, 39.258531025477815, 42.4511136327471, 44.381007058279856, 45.973513330732075, 45.96875034059797, 42.34686286108834, 43.59756987435477, 44.691039153507774, 44.91712311335972, 45.07305111203875, 44.40559325899397, 43.1072667666844, 40.987718786512104, 41.88481460298811, 45.06270524433681, 46.428133964538574, 48.41124711717878, 35.39387696129935, 4.435677868979318, 1.6862608130489076, 8.116471307618276, 13.384708387511116, 15.560676608766828, 4.093375733920506, 0.4672053413731711, 0.227913425969226, 0.7372893659131867, 1.4369934286390031, 7.764076914106097, 40.92168658120291, 32.82958173751831, 43.48617288044521, 44.086403438023154, 22.78027704783848, 0.9656371900013515, 0.1254398189485073, 0.12825907766819, 0.1229825858026743, 0.10193570517003536, 0.21611200565738337, 0.10836758610925504, 0.1305853399847235, 0.11848727773342814, 0.13183279947510787, 0.09110095977251019, 0.09341698978096247, 0.2153039111622742, 0.0841048498238836, 0.19876509505723203, 0.15133320380534443, 0.19163363772843564], [0.08425271617514746, 0.028872523390288864, 0.059097373858094215, 0.03372521585385714, 0.0812712875860078, 0.045016153915120025, 0.027581474810306515, 0.05175822035276464, 0.01723054184445313, 0.06576988367097718, 0.007827538414858282, 0.01290622035906251, 0.05312126149822559, 0.02905739364879472, 0.012664227630011737, 0.046758838796189854, 0.07937820202537946, 0.051001046518129964, 0.026889805050034608, 0.020395765214094093, 0.04036280486200537, 0.030487073718437126, 0.9660141297749111, 22.795962606157573, 38.56132793426514, 24.745745250156947, 30.80339322771345, 31.980324268341064, 15.089939628328596, 0.8382476142474583, 0.3596086049718516, 0.07214319346738712, 0.0672437906531351, 0.045464180409908295, 0.24289914327008383, 2.2790925162179128, 1.713946670293808, 0.011389548707354282, 15.107287543160574, 46.864063944135395, 49.13354710170201, 48.62206588472639, 46.17170027324131, 43.03946277073452, 40.31956958770752, 41.4930682182312, 42.64390182495117, 43.52608680725098, 45.27214132036482, 45.11299283163888, 46.86444956915719, 45.44867072786604, 47.37170628138951, 46.624229499271934, 42.89055592673165, 37.6281327520098, 35.71192727770124, 39.879290035792756, 42.71096583775112, 44.41143669400896, 45.939383779253276, 45.66437407902309, 47.31343521390642, 39.03326347896031, 33.04967287608555, 35.46380015781948, 32.7578763280596, 34.01085887636457, 33.61810500281197, 34.25743654796055, 32.85248647417341, 33.17392751148769, 32.71203906195504, 32.91930035182408, 32.71017347063337, 32.30006994519915, 31.908789089747838, 32.20269789014544, 33.74948501586914, 35.75542994907924, 40.58039106641497, 41.48446634837559, 44.15391560963222, 44.52293791089739, 44.36933408464704, 44.16441781180245, 45.346792766026084, 45.311217989240376, 46.45001036780221, 41.16235133579799, 43.53134659358433, 46.46911096572876, 44.02591242109026, 42.70851312364851, 39.60374185017177, 38.958990710122244, 41.90754216057913, 42.73767818723406, 41.85397849764143, 43.22960717337472, 42.891632897513254, 41.77009637015206, 33.814874512808665, 32.371420996529714, 31.997468948364258, 32.33483178274972, 32.87675653185163, 33.66774640764509, 33.3421607698713, 32.48486770902361, 33.05514110837664, 32.5635803767613, 33.296719551086426, 32.36579990386963, 32.238154547555105, 32.80479056494576, 37.594149112701416, 42.804544176374165, 41.55001217978341, 40.211038725716726, 36.33810240881783, 37.043184757232666, 36.934184891836985, 37.801452091761995, 37.9548613684518, 37.69608613422939, 38.73875713348389, 40.45297500065395, 42.926255771092, 42.61460474559239, 40.474243436540874, 42.604863371167866, 41.37979521070208, 42.29339647293091, 42.9947441646031, 41.116680826459614, 40.98792723246983, 39.65796211787632, 40.52791479655674, 41.561261313302175, 44.16686010360718, 42.599749497004915, 19.460469450269425, 0.16611616127192974, 1.4024414483989989, 5.492036819458008, 5.650981204850333, 3.8253398537635803, 0.6919568755796978, 0.1255778329713004, 0.09626983598406826, 0.0716366602906159, 0.28864540425794466, 8.950149178504944, 35.3165990965707, 23.41487339564732, 32.94285127094814, 29.27487986428397, 4.875849289553506, 0.029946271130549054, 0.09886582275586468, 0.001712308670643584, 0.04283462990341442, 0.010522586210364742, 0.05915936481739793, 0.020943483770159737, 0.06270923611841031, 0.00352121952372337, 0.03182338736951351, 0.016067354707047343, 0.01655324175953865, 0.03608231419431312, 0.07139766668634755, 0.028257063290636455, 0.024883153083335077, 0.04348893104387181, 0.05717959640813725, 0.004647491175481784, 0.052410628380520005, 0.057395316261265955, 0.02922043204307556, 0.03065525201548423, 0.023112488810771277, 0.0672389187717012, 0.06753134700868811, 0.11444284261337348, 0.07008795160800219, 0.04119201875956995, 0.038310674085680924, 0.06453465138162885, 0.048545896474804194, 0.007016514768890504, 0.03953809304428952, 0.004765172048272299, 0.027448397129774094, 0.0039042803192777292, 0.023608791375798837, 0.03694312746769615, 2.146362598453249, 29.559269632611954, 43.378402846200125, 25.39353449004037, 33.968592984335764, 37.51993192945208, 17.007388830184937, 1.2098647419895445, 0.14520110642271383, 0.39786546783787863, 0.19381941615470819, 0.11339244326310498, 0.12796557056052343, 2.3079928968633925, 1.865618463073458, 0.14349870277302607, 18.27752126966204, 49.55134923117501, 50.267913477761404, 50.838926860264365, 47.728433745247976, 42.664002963474815, 41.39966358457293, 43.708299841199604, 44.534440653664724, 45.40979208265032, 47.32978432519095, 48.72283213479178, 48.13140147072928, 47.7930519921439, 48.685586316244944, 46.47417272840227, 44.143010411943706, 37.743115016392295, 38.89475808824812, 40.86186606543404, 44.194614682878765, 45.176207542419434, 47.20137466703142, 47.39218609673636, 47.803081716809956, 42.25928429194859, 35.162293502262656, 36.77569648197719, 35.89408125196184, 36.212006500789094, 35.8653678212847, 36.21248940059117, 34.20501586369106, 33.99496487208775, 34.665111677987234, 33.672380856105256, 34.01494789123535, 33.035449913569856, 34.416501658303396, 33.5372314453125, 36.16386243275234, 37.64575685773577, 42.67658962522234, 42.85136808667864, 45.543638706207275, 45.590167318071636, 45.14618437630789, 46.349407400403706, 47.04285151617867, 47.47804151262556, 47.57595552716936, 43.05470364434378, 46.567535672869, 48.04890898295811, 45.63348238808768, 44.299678393772666, 40.93175104686192, 40.4212703704834, 41.9861992427281, 44.137111391339985, 44.109242166791645, 45.481511388506206, 45.35091304779053, 42.823957443237305, 34.80238028935024, 33.782829420907156, 32.673594679151265, 33.47871719087873, 34.11699955804007, 35.023433753422324, 35.32119185583932, 33.19522026606968, 35.32562133244106, 34.406089782714844, 34.149871485573904, 32.8282789502825, 34.0315888268607, 34.8951734815325, 37.89180646623884, 43.216614042009624, 41.312606130327495, 40.43827608653477, 36.7297237260001, 38.390878200531006, 37.152955872671946, 38.934286390032085, 39.82813739776611, 38.89181205204555, 39.703524930136545, 40.47217634746006, 44.34945181437901, 44.42242874417986, 42.207179750714985, 43.93436990465437, 42.96813256399972, 43.84196581159319, 44.12132855824062, 43.34412043435233, 42.44411332266671, 40.39200803211757, 41.592809609004426, 40.93002789361136, 45.70153651918684, 43.464421544756206, 21.670352697372437, 0.5733938461967877, 3.0533650262015204, 8.910786764962332, 7.275110900402069, 4.443760360990252, 1.6949317306280136, 0.07684280843074832, 0.11917581435825143, 0.05043497189347233, 0.15335899724492005, 10.700760841369629, 40.46221957887922, 26.265406608581543, 35.30150066103254, 33.906406606946675, 7.926926187106541, 0.059839019418827126, 0.020836427907592485, 0.005952299173389162, 0.023761127576498047, 0.015631489256130796, 0.006231811496296099, 0.04846866561898163, 0.03539572835766843, 0.06346616228776318, 0.02963066753000021, 0.01921691239944526, 0.03294269195092576, 0.05439984199724027, 0.03659898807693805, 0.06711931340396404, 0.03466106492227741, 0.04797785409859248, 0.11679658559816224, 0.11840543283947877, 0.10645178319620234, 0.22192230102206978, 0.1827643843633788, 0.13236249105206557, 0.0949174410530499, 0.24213619849511556, 0.11065572154309068, 0.2886957515563284, 0.17025802044996194, 0.10448699005480323, 0.15563002681093557, 0.17157629185489245, 0.08418097466762577, 0.06748845002480916, 0.1380146470453058, 0.11438290082982608, 0.09098048587994916, 0.14245226606726646, 0.14813039638102055, 0.1056519193308694, 2.345063490527017, 34.057724475860596, 49.69123731340681, 33.31636905670166, 38.79653140476772, 42.747363976069856, 22.272099699292863, 2.6469049624034335, 0.9137409861598695, 0.6995082646608353, 0.3305008368832724, 0.4390970825084618, 0.45703909546136856, 5.413669390337808, 3.9089627265930176, 0.20882452598639897, 18.84389672960554, 48.692148889814106, 52.50526816504342, 52.142665999276296, 50.99595962251936, 45.327355180467876, 43.87637676511492, 46.63528060913086, 46.39797183445522, 47.95181138174874, 50.66588544845581, 50.68230404172625, 49.62369734900338, 50.08434901918684, 51.31736939293997, 49.44963107790266, 46.365912846156526, 40.03272015707833, 41.41023179462978, 43.78836740766253, 46.14003733226231, 46.53405925205776, 48.81692116601126, 47.94934477124895, 49.97733981268746, 43.083726269858225, 36.374080181121826, 38.28495291301182, 37.12406178883144, 38.06517791748047, 36.98978437696184, 37.261927945273264, 35.983660902295796, 35.63084527424404, 36.78566714695522, 35.72184583118984, 36.25762489863804, 33.61898742403303, 35.940224238804404, 35.49565417425973, 37.96374464035034, 39.451892444065635, 44.143479415348594, 44.41350725718907, 46.59505748748779, 48.01337242126465, 47.20835760661534, 48.81052882330758, 48.25734451838902, 48.89146144049508, 49.58488471167428, 44.44550371170044, 46.80678994315011, 48.50328990391323, 48.00566686902727, 44.61668995448521, 42.93819972446987, 42.478642395564485, 44.94238328933716, 46.512582370213096, 46.936109815325054, 47.092718737465994, 47.366929394858225, 45.085318156651084, 37.561614172799246, 35.69942399433681, 34.31992864608765, 34.600917271205354, 35.6739935874939, 36.19698796953474, 36.60074431555611, 33.53959035873413, 36.503188133239746, 36.941355432782856, 34.96626397541591, 34.38380690983364, 36.48383392606463, 37.02483803885323, 41.168618610927034, 46.57248279026577, 43.306808607918875, 42.83275386265346, 39.69634049279349, 40.409930910382954, 39.09210777282715, 42.40417160306658, 41.416526862553184, 40.73308120455061, 41.0766453061785, 42.11991385051182, 46.85008069447109, 45.268031460898264, 42.650301115853445, 45.561662333352224, 43.4755734034947, 45.349332332611084, 46.80959006718227, 45.80143771852766, 45.27556678227016, 43.798028877803254, 43.142052922930034, 44.831743649074006, 47.11973680768694, 45.086221422467915, 22.35888269969395, 0.646321921476296, 4.254345084939684, 14.345041496413094, 11.539079240390233, 11.697267140660967, 3.1037325177873885, 0.18816282254244598, 0.2902552421603884, 0.23843932258231298, 0.6661259159445763, 15.537290709359304, 46.60840845108032, 33.58632741655622, 40.59547560555594, 40.85642910003662, 9.430789078984942, 0.13933932382081235, 0.2505101891500609, 0.07136629122708525, 0.07391516731253692, 0.19101256105516637, 0.158353218542678, 0.09030014595815114, 0.13568776047655515, 0.13858545784439358, 0.14649376991604054, 0.092635663492339, 0.1466398992176567, 0.18778285650270327, 0.15136281507355825, 0.09578564018011093, 0.12508430731083664, 0.11239797555442367], [0.043353159579315355, 0.0372631517238915, 0.09956502595118114, 0.025396761684013263, 0.0472125480217593, 0.06734584910529, 0.020647272700443864, 0.053383698487388234, 0.03571394092536398, 0.06295796670019627, 0.033758433535695076, 0.04703441222331353, 0.02430452556083245, 0.018038110474922826, 0.04930925176345876, 0.04634663216503603, 0.03438474510663322, 0.06471545382269792, 0.023743051403601254, 0.04770356649532914, 0.02140032104216516, 0.015608502186036535, 0.050499775380428345, 8.308145182473318, 35.63372182846069, 33.93211146763393, 28.670115607125418, 32.195388385227744, 18.842510563986643, 3.660879901477269, 0.8597629825983728, 0.2500214268054281, 0.10936065603579793, 0.08021182300789015, 0.046588020997920206, 0.38998403932367054, 1.0489257893392017, 0.023679810243525674, 2.9589793937546864, 33.85519143513271, 50.026557377406526, 49.81829554694039, 47.26236595426287, 44.86982672555106, 45.41122341156006, 46.11101123264858, 44.8507330758231, 46.78677913120815, 45.36625119618007, 48.14813273293631, 46.09693765640259, 47.782164164951865, 45.54051896503994, 47.137027399880544, 42.80122988564627, 35.71415417534964, 37.73190409796578, 41.861777850559776, 45.841077191489084, 46.96699455806187, 46.935494899749756, 46.479627064296174, 46.404854025159565, 40.15831579480852, 33.859329087393625, 34.39400339126587, 34.352383681706016, 36.32022469384329, 33.39675276620047, 34.67015954426357, 34.11675289699009, 33.59079858234951, 33.912708623068674, 33.7856364931379, 33.790125029427664, 33.37752710069929, 32.25415972300938, 31.847189835139684, 33.80322585787092, 34.57612262453352, 35.21245949608939, 38.30439397266933, 39.91777263368879, 40.77510738372803, 42.31652355194092, 42.84736245019095, 42.5394287109375, 44.94053506851196, 46.345617158072336, 46.94947467531477, 42.20230906350272, 45.791272503989084, 43.03144454956055, 43.718333039964946, 41.41121843882969, 42.18769005366734, 43.10488700866699, 44.17743526186262, 43.43177195957729, 45.25466660090855, 45.75429419108799, 43.959310463496614, 35.15072822570801, 32.67543942587716, 32.77510438646589, 32.062775066920686, 33.38481228692191, 33.324373381478445, 32.972207409994944, 34.01899174281529, 32.24341433388846, 32.861835275377544, 33.52268886566162, 31.80772406714303, 32.015020098005024, 34.73350279671805, 42.83312211717878, 44.09195157459804, 41.7074305670602, 42.74814217431204, 38.4710499899728, 36.69624383108956, 39.97888898849487, 43.388845988682334, 42.47372654506138, 42.43202345711844, 41.59852450234549, 42.35554116112845, 43.73453276497977, 41.204488686152864, 42.50212730680193, 43.09203631537301, 42.07614714758736, 41.52423783711025, 42.61814137867519, 44.17085184369768, 41.59237534659249, 42.12345395769392, 41.26232549122402, 41.9511525290353, 44.79773221697126, 32.34090798241751, 7.3755301748003275, 0.172352345926421, 3.656829970223563, 6.495500871113368, 6.419592670031956, 1.6334556979792458, 1.1015074763979231, 0.1557525023818016, 0.04448783976425018, 0.1329529657959938, 0.9046191956315721, 19.43302753993443, 27.502022675105504, 22.19495906148638, 37.71453012738909, 18.398386921201432, 1.1893435631479536, 0.043660413806459734, 0.025122920217524682, 0.039610292562948804, 0.057283649753246985, 0.053484325230653794, 0.085231509724898, 0.027453457304675664, 0.014833106293476053, 0.02765303141703563, 0.05539337332759585, 0.07663512243224041, 0.015080934423687202, 0.023696325785879577, 0.023889720140557204, 0.07168472771133695, 0.009440656185948422, 0.01663770410232246, 0.0278797130033906, 0.06508625285433871, 0.07133461721241474, 0.02981227742774146, 0.02897582695420299, 0.045986998427127085, 0.02266496273555926, 0.029900391985263144, 0.04060388156878097, 0.024534830524187003, 0.06908161632184472, 0.04695580394140311, 0.02420722194282072, 0.03338693900566016, 0.06389195658266544, 0.043077443659837754, 0.03106580302119255, 0.05941285192966461, 0.04358641617000103, 0.021755591799904193, 0.04516907535227282, 0.07127859057592494, 0.07984952602003302, 12.537295665059771, 42.03770971298218, 34.25580024719238, 32.46613883972168, 37.9437963621957, 22.501628228596278, 6.1442511933190485, 1.9292884979929243, 0.2489876922752176, 0.05040088229413543, 0.08446108070867402, 0.10360049083828926, 0.3722763652248042, 1.7344543870006288, 0.11793550662696362, 3.9880649277142117, 37.470964499882285, 50.901141030447825, 51.69820015771048, 49.43757247924805, 47.807393074035645, 46.136313097817556, 47.38622106824602, 46.47128922598702, 48.75073957443237, 48.8669308253697, 48.48296642303467, 47.03718178612845, 48.22771045139858, 45.9307610648019, 46.97850424902779, 44.515670095171245, 37.87279272079468, 38.45117466790335, 43.520597730364116, 45.926071030753, 48.41054882322039, 47.41395132882254, 48.24645669119698, 47.08102491923741, 42.0739688873291, 33.9114579473223, 36.635613850184846, 36.10584497451782, 36.151751722608296, 34.60652446746826, 36.16213927950178, 34.5187200818743, 35.62462316240583, 35.173612117767334, 35.69112089702061, 35.1705653326852, 35.045695781707764, 33.08309718540737, 33.09077147075108, 35.49862800325666, 35.07803269795009, 36.54866756711687, 39.99214267730713, 40.8837285723005, 43.072577885219026, 44.67206709725516, 44.07930932726179, 45.48008005959647, 44.98130362374442, 47.63019316537039, 48.12414060320173, 43.62773200443813, 46.94141476494925, 45.703367369515554, 45.64624970299857, 43.31150559016636, 44.45625952311924, 44.346224376133506, 45.387630803244456, 45.47998973301479, 47.654049805232454, 47.224546909332275, 44.60128927230835, 37.116491726466585, 34.00681502478463, 33.859165804726736, 32.352230072021484, 33.97727823257446, 34.05275651386806, 35.68700756345476, 35.680021149771555, 34.93818283081055, 33.851498467581614, 34.40180969238281, 32.86096675055367, 33.66455718449184, 35.01059695652553, 44.17466293062483, 46.13153968538557, 44.611412797655376, 44.378210408346995, 41.02348116465977, 38.97840397698538, 40.51898636136736, 45.55435977663313, 43.745163508823936, 43.6964670589992, 43.20024061203003, 42.27630043029785, 46.00390822546822, 42.47945533479963, 41.85798066002982, 43.88669831412179, 43.8268187386649, 42.9306400844029, 44.77237476621355, 44.91294724600655, 42.899744919368196, 42.96122258050101, 42.20963593891689, 43.55460221426827, 45.62627363204956, 34.21245738438198, 8.326039399419512, 0.41321292572787827, 6.7988340343747815, 10.5861668075834, 9.477604304041181, 5.961706817150116, 1.0677001476287842, 0.35520616120525766, 0.09466831013560295, 0.03914281925452607, 0.9272698887756893, 22.233886344092234, 36.16432448795864, 25.402254479272024, 41.74145589556013, 25.03624595914568, 1.7503899719033922, 0.09672383019434554, 0.025731413458873118, 0.038833349610545805, 0.07968941889703274, 0.029789587216717855, 0.03514802236376064, 0.021063004321019565, 0.04818465800157615, 0.04566590887095247, 0.021092854772827456, 0.05336668761447072, 0.05526679601254208, 0.037062732835433314, 0.037665563702051125, 0.02073925151489675, 0.008587126985990574, 0.045705504781965695, 0.06842806496258293, 0.13059247817311967, 0.20724189733820303, 0.10190564606870924, 0.09160471095570497, 0.10304716588663203, 0.11845279458378043, 0.15616885146924428, 0.15649469755589962, 0.14806584055934632, 0.18102139074887547, 0.1088843448087573, 0.14320012022342, 0.06451195438525506, 0.1220349980784314, 0.12231778433280331, 0.0778971297134246, 0.1291393954306841, 0.1924349604440587, 0.23080010392836162, 0.08866950417203562, 0.1238424660904067, 0.1338704265654087, 13.056247064045497, 49.42235245023455, 42.63952445983887, 38.92645577022007, 42.33319228036063, 29.15699325289045, 9.795954261507307, 3.2444956387792314, 0.8927189941917146, 0.1591656692326069, 0.7622153226818357, 0.23527368530631065, 1.4095230741160256, 4.400067916938236, 0.060188471738781245, 4.61295724766595, 37.087792192186626, 54.28404521942139, 53.66082654680525, 52.1669464792524, 49.67999860218593, 48.887532234191895, 48.15125247410366, 47.574979305267334, 52.22217076165335, 51.08171428952898, 49.142746516636436, 47.90635626656668, 51.007986954280305, 48.1698944909232, 49.96055991309029, 46.94167184829712, 39.49684034075056, 40.6978052003043, 46.237353801727295, 47.87923744746617, 50.145399366106304, 50.04211786815098, 50.33312232153756, 48.50002077647618, 43.991032464163645, 36.76458283833095, 38.60000508172171, 37.997328758239746, 39.50091545922415, 35.765223434993196, 37.86432981491089, 36.26563964571272, 37.79179409572056, 38.08106844765799, 37.6588785307748, 37.20600536891392, 36.71488584790911, 35.394665581839426, 34.49131638663155, 37.37162610462734, 37.37598957334246, 38.49886015483311, 40.23861960002354, 42.34801626205444, 44.434866019657676, 46.19982310703823, 46.12923288345337, 46.16620772225516, 47.26628473826817, 49.27136809485299, 50.139594146183555, 46.22068854740688, 47.17464147295271, 46.98046364103045, 46.515431131635395, 44.50867325919015, 45.6784337588719, 45.91459608078003, 47.95786326272147, 45.775976044791086, 50.22532796859741, 49.38721888405936, 46.9167868750436, 37.96656560897827, 35.578309944697786, 35.25873449870518, 34.772242477961946, 36.53479201453072, 35.78787803649902, 37.57199478149414, 38.098848887852256, 36.29180656160627, 37.182975564684185, 37.901019777570454, 34.433462211063926, 34.097461223602295, 36.97589145387922, 46.43669414520264, 47.452062198093955, 45.46364409582955, 46.266432012830464, 42.788080419812886, 40.57027448926653, 42.62937661579677, 47.01150819233486, 46.40461083820888, 47.01389837265015, 45.076445307050435, 44.67765692302159, 46.907778535570415, 43.54675769805908, 44.52486603600638, 44.338543142591206, 45.300972870418, 44.901639052799766, 45.564236640930176, 47.583470003945486, 45.07751185553414, 45.55058690479824, 44.999483585357666, 45.10649626595633, 49.135579449789866, 34.22341816765921, 9.421715600149971, 0.6158705183437893, 8.529854382787432, 14.502765604427882, 17.286590031215123, 7.853632245744977, 2.2338666915893555, 0.4433754900736468, 0.11974030121096543, 0.20617389678955078, 2.176575320107596, 28.651671613965714, 38.753160749162944, 31.743383748190745, 46.15248850413731, 29.25073140008109, 1.8093366431338447, 0.24842988220708712, 0.13988953429673398, 0.13102541065641812, 0.1324448652033295, 0.14684690668114594, 0.13515429624489375, 0.12326682412198611, 0.14708010559635504, 0.08090538757720164, 0.10479978112769978, 0.15154710518462317, 0.2554289437830448, 0.10127705122743334, 0.11318481154739857, 0.18275335138397558, 0.12293039288903986, 0.1501070096024445], [0.039341952319123914, 0.017256958909066658, 0.01013549046391355, 0.0356439975356417, 0.020461493205013018, 0.045477710398180146, 0.015603864399184073, 0.03299271355250052, 0.06925992853939533, 0.039364442362317016, 0.02993064107639449, 0.08447400001542908, 0.023124604053529244, 0.008175919497651713, 0.04064052924513817, 0.051414762889700275, 0.010189533233642578, 0.03926176644329514, 0.031080113324735845, 0.01266859145835042, 0.0394343823593642, 0.06986711560083286, 0.02784965050938938, 1.4018571483237403, 21.12667873927525, 34.22741338184902, 22.965952021735056, 29.064325128282817, 27.333801576069423, 8.319666164261953, 0.2712870128452778, 0.18905962870589324, 0.05430721518184457, 0.024987214910132543, 0.041723488098276515, 0.06820651649364404, 0.7553470283746719, 0.8188089973160199, 0.05845903525395053, 11.319294691085815, 39.247486863817485, 51.73136043548584, 48.59323780877249, 46.564336027417866, 46.52498490469796, 47.590647493089946, 46.47887665884835, 47.74287557601929, 48.34565959657942, 48.805091857910156, 48.304244858878, 44.91074119295393, 47.46761574063982, 43.03360891342163, 36.746746812547954, 34.741507121494834, 40.1311240196228, 42.00081825256348, 45.499861580984934, 45.60924359730312, 46.010925906045095, 45.974916866847444, 46.52351188659668, 37.21176542554583, 33.49810266494751, 33.52864694595337, 35.12670135498047, 36.2127742767334, 33.25319603511265, 34.447320393153596, 33.657939025333945, 33.742981501988, 33.634398528507774, 34.18990005765642, 32.90796783992222, 33.65235614776611, 33.68950121743338, 32.76284776415144, 34.35653175626482, 33.47301271983555, 35.51738119125366, 35.615732942308696, 37.70784248624529, 39.0828423500061, 39.224693298339844, 39.56354999542236, 43.48977552141462, 44.61580753326416, 46.33440623964582, 44.42572219031197, 40.96682207924979, 47.14134223120553, 43.91369901384626, 44.65154211861746, 42.587548460279194, 46.411909920828684, 44.00260468891689, 45.30740690231323, 46.39861454282488, 46.92225510733468, 44.96100098746163, 44.435543469020296, 34.950717381068635, 31.999185153416224, 32.84300218309675, 32.88726915631975, 32.25209958212716, 33.89743300846645, 33.192899567740305, 32.908648763384136, 31.97732264654977, 33.53414644513811, 31.988147939954484, 35.24207271848406, 32.1310133252825, 34.2584787777492, 42.45017562593733, 44.30404881068638, 44.49157721655709, 43.969371455056326, 41.41768373761858, 36.287880829402376, 41.095294271196636, 43.603382042476106, 43.9037526675633, 42.56804486683437, 42.22424105235508, 43.804786000932964, 40.87386213030134, 41.63434246608189, 42.96351548603603, 44.3771264893668, 42.39507641111101, 41.57544953482491, 43.196370465414866, 43.156261989048545, 41.75577960695539, 43.67309331893921, 42.016781738826204, 42.77898175375802, 36.974564347948345, 19.871549197605678, 0.972815004842622, 0.4243179112672806, 4.129391287054334, 8.40425179685865, 6.868591342653547, 3.42587662594659, 0.6394294713224683, 0.07293297430234295, 0.10005059239587613, 0.08309979018356119, 3.1925917267799377, 32.401485851832796, 28.58305467878069, 27.274427482060023, 31.980244364057267, 6.197307637759617, 0.14567027267600807, 0.0414729288646153, 0.03937913943082094, 0.03993955846609814, 0.03514598675870469, 0.006857919930813036, 0.010052561610271888, 0.03365381022116967, 0.041838598171515126, 0.08707694177116666, 0.06835998754416193, 0.029789505792515616, 0.059624256300074716, 0.024048916330294948, 0.07582356740853616, 0.042133486097944636, 0.029165942288403, 0.08208915298538548, 0.013723399589902588, 0.029437145950006585, 0.03302603979994144, 0.026808219695729867, 0.03835351339408329, 0.11708699858614377, 0.011993588214474065, 0.06433230545371771, 0.06616897082754544, 0.06092168310923236, 0.008158134246644164, 0.030898394861391613, 0.0559661111661366, 0.0053039475127921575, 0.04802007254745279, 0.04191301649968539, 0.030927290275160755, 0.03325133378218327, 0.035148202175540585, 0.07377772325915949, 0.0358714662226183, 0.06007979078484433, 0.07353178824165038, 2.523628068821771, 30.93465859549386, 39.225996085575645, 26.947691917419434, 36.559027331215994, 30.55108676637922, 10.115825874464852, 0.2385254693882806, 0.2527484590453761, 0.08918493972825152, 0.05346636440871017, 0.05320196984601872, 0.04162728879600763, 1.0097101564918245, 1.391211313860757, 0.18199008091219834, 14.24557455948421, 43.82148947034563, 51.35942336491176, 50.14150490079607, 48.84709024429321, 47.780559131077354, 48.03338670730591, 48.28367819104876, 47.526189054761616, 47.77618176596505, 50.31359788349697, 48.88379757744925, 47.31163910457066, 48.65093912397112, 46.2410363469805, 39.09441804885864, 36.12957654680525, 41.52137517929077, 44.05142273221697, 47.752022879464285, 48.18117489133562, 46.42316252844674, 47.402764729091096, 46.617190974099294, 38.8980758530753, 35.046407972063335, 34.541836738586426, 36.95834377833775, 36.44691467285156, 35.330874170575825, 34.28680310930525, 36.36235509599958, 35.097029072897776, 35.35122544424874, 35.32824775150844, 35.49720362254551, 35.112763268607004, 34.542427335466655, 34.00576932089669, 35.6485458101545, 35.43376309531075, 37.55956792831421, 36.93723515101841, 40.318666321890696, 40.03457185200283, 40.58253805977957, 43.23137896401541, 45.43975271497454, 46.83610091890608, 47.30064010620117, 45.809553214481895, 43.22233588354928, 47.06957081386021, 46.15926994596209, 45.54480947766985, 42.835362911224365, 46.569213662828716, 45.536152022225515, 47.108206272125244, 46.68707595552717, 47.81245483670916, 46.395060539245605, 45.382767064230784, 34.86065135683332, 33.6210857800075, 33.945174080984934, 32.73420034136091, 32.97948564801897, 35.386654308864046, 33.99265807015555, 35.00138711929321, 34.26574659347534, 35.19518280029297, 34.6732827595302, 35.63766145706177, 33.947661536080496, 35.717503207070486, 43.67698431015015, 44.0932891028268, 46.895921434674946, 45.494872774396626, 42.17163971492222, 36.990274224962505, 42.58226088115147, 43.318009104047505, 45.19571808406285, 43.66549893787929, 44.18458843231201, 44.62583030973162, 43.41019432885306, 43.14399494443621, 44.26519448416573, 45.03476653780256, 44.41949313027518, 44.061785970415386, 45.25856801441738, 45.34482295172555, 43.41852521896362, 44.2247177532741, 44.40017713819231, 43.61137247085571, 39.75748464039394, 22.722982202257427, 2.2468960838658467, 1.157518099461283, 8.3882075377873, 10.393989188330513, 7.4710071086883545, 6.724879579884665, 1.6108726412057877, 0.36819910258054733, 0.12566616466002806, 0.07102672516235284, 3.718399694987706, 33.673228536333355, 31.8072863306318, 28.036637919289724, 38.44131517410278, 9.363457560539246, 0.39104401958840235, 0.026019906192751865, 0.01492259997342314, 0.028590592090040445, 0.023768398079222867, 0.04363132161753518, 0.059411583069179735, 0.03196972023163523, 0.013185986284432667, 0.018910881231672, 0.05699432920664549, 0.02748636286040502, 0.027827805074463998, 0.014463399703215276, 0.044070913922041655, 0.006338059902191162, 0.0794612139995609, 0.012205241098334747, 0.07494847436568566, 0.13826768632446015, 0.16973915829190186, 0.1395270066069705, 0.16901974832373007, 0.14183824615819113, 0.1086810217904193, 0.14247381633945874, 0.11745992143239294, 0.14245871214994363, 0.12584710280810082, 0.09303741050618035, 0.13836914088044847, 0.09874990861862898, 0.20462458421077045, 0.11702333843069417, 0.1496163880718606, 0.16515839552240713, 0.08087585094783988, 0.18502434023788997, 0.1192944629916123, 0.1421378736517259, 0.19562262296676636, 2.3934190443583896, 34.11143752506801, 44.78931794847761, 33.18886613845825, 38.774804387773784, 39.67784438814436, 16.599887405123027, 1.1963487586804797, 0.5238224118947983, 0.3426346443593502, 0.3072590854551111, 0.2593968537236963, 0.37896308356097763, 2.467664671795709, 2.044167842183794, 0.2653125391474792, 14.753361940383911, 43.97360985619681, 54.210571493421284, 51.91596712384905, 51.82764162336077, 50.53119114467076, 50.64298071180071, 49.22266469682966, 50.29943050657, 49.74494341441563, 52.233965328761506, 51.838657992226736, 48.28160762786865, 51.37973294939314, 47.0170111656189, 40.1727854183742, 37.90737737928118, 43.18552085331508, 46.199409689222065, 48.042738982609336, 51.12893424715315, 47.59908260617937, 49.871028900146484, 48.14773668561663, 41.41895178386143, 36.16815641948155, 36.3607292175293, 37.753860405513215, 39.19901623044695, 36.139376980917795, 36.65237290518624, 38.01480695179531, 36.39658539635794, 38.14004475729806, 37.81200987952096, 37.07980523790632, 37.51738888876778, 37.14793579918997, 35.78052336829049, 38.38933570044381, 36.56022936957223, 38.90106010437012, 38.76109906605312, 41.56937680925642, 43.51134967803955, 42.1276194027492, 45.50744901384626, 49.689722606113975, 47.22148970195225, 49.29836532047817, 47.96144158499581, 43.6780925478254, 48.978147166115896, 47.712303502219065, 48.21296637398856, 44.4283902985709, 49.4546685218811, 46.53948926925659, 48.18239082608904, 47.55055638722011, 49.813952922821045, 48.16613551548549, 47.744244371141704, 37.09955896650042, 35.359823840005056, 35.354411193302695, 34.56301484789167, 34.98543405532837, 37.8169778415135, 35.927175521850586, 36.176129477364675, 34.083877495356965, 37.18305546896798, 36.32228136062622, 38.65040384020124, 36.33455535343715, 36.9577636037554, 45.092582498277935, 46.10990299497332, 49.10602528708321, 47.31690583910261, 44.88061032976423, 39.15379735401699, 44.98357221058437, 44.98344019481114, 47.23029654366629, 44.098555837358745, 45.587818826947895, 45.18627895627703, 43.31383671079363, 43.88258498055594, 45.36655691691807, 47.12617778778076, 45.00874553407942, 45.01069450378418, 46.860047885349815, 46.411659785679404, 44.210171699523926, 46.574358803885325, 44.286386489868164, 44.48735271181379, 39.47609996795654, 22.058619771684917, 2.011224261351994, 2.2648324242659976, 10.493423121316091, 16.516674041748047, 14.15732375213078, 11.705230644771031, 0.7765368627650397, 0.29145386070013046, 0.30488440287964685, 0.19547831213900022, 5.841905542782374, 41.92274481909615, 37.36299991607666, 36.25326490402222, 42.252850260053364, 11.139312897409711, 0.4571264907717705, 0.09013716184667178, 0.1054454818367958, 0.1489985819373812, 0.16319126822054386, 0.08292780191238437, 0.09712044748344592, 0.11531227667416845, 0.1151400509157351, 0.1617127675563097, 0.18516348062881402, 0.11770868594092981, 0.13976822580610002, 0.27820627870304243, 0.11111784460289137, 0.0751409815358264, 0.23129931571228163, 0.18991348360266003], [0.011968058334397418, 0.047876881302467415, 0.10659359701509986, 0.0649512108149273, 0.09894452603267771, 0.014160453325270541, 0.026673284525583898, 0.04096804452793939, 0.05019333878798144, 0.0166738547517785, 0.034214147832244635, 0.0507378631404468, 0.043589920803372345, 0.007068244158290327, 0.10082946917308228, 0.028512828584228243, 0.01809320242942444, 0.01241740457979696, 0.03940866927483252, 0.07416461714144264, 0.050305609192167006, 0.0366236630028912, 0.04581220441364816, 0.06948501217578139, 6.285773839269366, 32.36279133387974, 32.5940899167742, 20.659732001168386, 31.66057859148298, 15.603262117930822, 2.2710662611893246, 0.22283930038767202, 0.03768518693479044, 0.0008478428644593805, 0.018237423351300613, 0.15818517255995954, 0.9685542391879218, 0.435234969747918, 0.12966513793383325, 1.179682201572827, 16.24913191795349, 39.77791581835066, 49.273862498147146, 49.269307953970774, 47.667661326272146, 50.15675619670323, 47.807743958064485, 47.45237486703055, 48.99892575400216, 46.000489711761475, 44.4536018371582, 43.60609878812517, 42.05053261348179, 37.778873920440674, 36.902431624276296, 39.434779030936106, 41.82677282605852, 45.048857484545024, 46.16378974914551, 46.7587570462908, 45.09446893419538, 47.13064547947475, 46.622808592660085, 41.49785205296108, 33.50061443873814, 34.38377911703927, 36.258038316454204, 36.37445885794503, 33.24329832621983, 34.332327706473215, 34.2589373588562, 35.40011644363403, 32.46936627796718, 34.748028005872456, 32.54564707619803, 32.16539648600987, 33.05853877748762, 32.87007236480713, 32.820194721221924, 32.61610528400966, 34.34375401905605, 35.958473682403564, 38.273509229932515, 38.52324138368879, 37.33652033124651, 39.19848121915545, 44.27003737858364, 44.23141234261649, 45.735294342041016, 43.59063557216099, 39.511688641139436, 46.93685327257429, 43.339996678488596, 43.75775364467076, 47.511729853493826, 44.99743734087263, 43.42120374952044, 46.36495746885027, 45.41900191988264, 44.26951278959002, 43.28800678253174, 41.31085171018328, 32.61182171957833, 31.34235804421561, 32.44081960405622, 31.970353603363037, 31.47120543888637, 33.13551786967686, 33.95373773574829, 33.84629774093628, 32.95259959357125, 32.52643878119332, 32.166869504111155, 32.494081020355225, 33.64074223382132, 32.56681823730469, 42.44037866592407, 44.03032800129482, 43.45545836857387, 42.054361070905415, 40.973440238407676, 36.50494950158255, 38.29767159053257, 42.89707333700997, 44.586673736572266, 43.57259457451956, 44.233958857400076, 43.45951264245169, 41.56394679205758, 44.05149221420288, 42.69808040346418, 41.91626214981079, 40.53352894101824, 39.953583649226594, 39.561434268951416, 39.93245070321219, 41.61637095042637, 43.34435667310442, 44.019725050245015, 39.77959033421108, 30.077539239610942, 6.732373212065015, 0.1526278214795249, 1.2263902723789215, 8.113425391060964, 8.31355001245226, 6.493821578366416, 4.832668840885162, 1.4238120445183344, 0.684153180037226, 0.29600612499884194, 0.04683996783569455, 11.196627719061715, 30.072727612086705, 20.413501739501953, 36.63652059010097, 22.136804376329692, 0.8493040981037276, 0.02611640913944159, 0.0779707304068974, 0.009956843219697475, 0.015963238597448384, 0.040131285320967436, 0.023721804775829827, 0.029217853610004698, 0.018179025234920636, 0.019564291794917414, 0.038419541636747975, 0.01695492770522833, 0.040598524534808736, 0.11268017826867954, 0.012422824378258415, 0.006667392386589199, 0.019175579438784292, 0.03040024498477578, 0.048268263693898916, 0.016079006849655082, 0.08290743907647473, 0.040526891592890024, 0.03133596513154251, 0.0340649617303695, 0.03234569987814341, 0.028539990341024737, 0.012903822585940361, 0.010205426220116871, 0.06045780264373336, 0.023347188984709125, 0.0624904085748962, 0.021024565312213132, 0.04330206589241113, 0.03540848820869412, 0.022428898706233928, 0.008119651133061519, 0.031588651572487185, 0.016342884029394815, 0.02565028441936842, 0.05314522056973406, 0.08638576564512082, 0.031150026180382286, 0.23968554713896342, 10.131420237677437, 38.77438054765974, 32.274385929107666, 25.66363181386675, 40.26830577850342, 19.670619453702653, 3.6040343003613606, 0.07237966970673629, 0.13916485889681748, 0.025303770156045045, 0.3311070129275322, 0.5782832066927637, 4.532354235649109, 3.7182620338031223, 0.6014055630990437, 1.4362584395068032, 19.365913152694702, 42.17066696711949, 50.6234701701573, 49.539273262023926, 49.525929246629985, 50.35011414119175, 49.582404204777305, 48.87494209834507, 49.7486572265625, 47.81746448789324, 46.529699257441926, 46.24883222579956, 44.075129985809326, 38.740872859954834, 36.7212747165135, 39.968188762664795, 43.779352119990754, 46.91472673416138, 48.450910908835276, 47.936466285160606, 46.757773876190186, 47.92989328929356, 48.960457052503315, 40.895474502018516, 35.783104624067036, 35.24086373192923, 37.508491720472065, 36.98759569440569, 35.26278529848371, 35.21370669773647, 35.446860449654714, 35.80244493484497, 35.370437213352744, 36.64770024163382, 35.309973989214214, 33.85982240949358, 34.60478394372122, 35.252616609845845, 34.24261951446533, 34.42806346075875, 36.58474261420113, 38.75261184147426, 41.93422671726772, 40.30837951387678, 39.597637857709614, 40.07679952893938, 45.81355537687029, 46.251663616725374, 48.5129965373448, 44.88450479507446, 41.13453769683838, 48.29219320842198, 45.437709944588796, 44.13455098015921, 47.899696418217246, 47.64114005225045, 45.22693286623274, 47.48125158037458, 45.98670448575701, 46.82391030447823, 44.581441743033274, 42.50165482929775, 35.66327599116734, 33.59468262536185, 33.73691919871739, 33.82246541976929, 34.4769857270377, 34.49332094192505, 34.70270143236433, 36.3654922076634, 34.92865685054234, 34.33599288122994, 33.75759356362479, 35.03668744223458, 35.429187706538606, 35.247488839285715, 44.15048319952828, 45.64137206758772, 44.676951680864605, 44.84336451121739, 43.78886072976248, 37.889958245413645, 39.58453355516706, 44.98376676014492, 45.437570980616975, 45.964011669158936, 45.966068335941856, 43.81806400844029, 41.31422506059919, 44.46124138150896, 43.60274280820574, 44.09457104546683, 42.098548139844624, 41.747830867767334, 41.49023682730538, 43.44584900992257, 42.21478107997349, 45.180942739759175, 45.111106395721436, 41.73712369373867, 31.59107576097761, 9.449703812599182, 0.6471415917788232, 3.171327850648335, 7.399229611669268, 9.186299341065542, 7.5714728491646905, 8.424374648502894, 2.2709741975579942, 1.3867735862731934, 0.13609980765197957, 0.06890353480620043, 11.965552721704755, 41.92494739804949, 25.45157105582101, 38.094415937151226, 28.318884168352398, 2.0846914734159196, 0.06788622760879141, 0.044952174848211665, 0.02304635539517871, 0.02959849818476609, 0.011663212906569242, 0.05790754234684365, 0.038636866225195785, 0.025517749566850916, 0.03138764914391296, 0.010522704105824232, 0.030800210844193186, 0.08580958084868533, 0.032521895066435845, 0.017226938823504106, 0.07544841896742582, 0.09574873466044664, 0.019958771698709046, 0.04006486352799194, 0.071539114096335, 0.22314427473715373, 0.17586219044668333, 0.11238976528069802, 0.25613616726228167, 0.08383725596857922, 0.15730547904968262, 0.10939444029437644, 0.10959555128855364, 0.13639868875699385, 0.16478642262518406, 0.19708372599312238, 0.09715483563819102, 0.0701014476695231, 0.1355272733739444, 0.14523187120045933, 0.09145614571337189, 0.10260045914245502, 0.18288745704506124, 0.14060127681919507, 0.15980558203799383, 0.16205074584909848, 0.10968916197972638, 0.37976538336702753, 11.50850282396589, 43.916658946446006, 41.90569741385323, 29.296572140284947, 41.99827868597848, 27.523652417319163, 6.4884028519902905, 0.35537223943642204, 0.23020084894129209, 0.1806765321109976, 0.30492742199982914, 0.5420309262616294, 4.980231208460672, 3.167679177863257, 0.47178881828274044, 2.047931811639241, 17.828704118728638, 43.39087833677019, 51.43916784014021, 52.40985550199236, 49.873311383383616, 52.11270884105137, 49.07513359614781, 50.04209007535662, 51.08802325384957, 50.318277495247976, 47.439996651240754, 49.58089297158377, 44.99843788146973, 42.29848950249808, 37.76890672956194, 42.694241523742676, 45.33498082842146, 48.475288663591655, 49.577123573848176, 49.268331732068745, 47.15218142100743, 50.38955211639404, 50.31952469689505, 44.55349956239973, 36.44377408708845, 36.71885674340384, 40.11574418204171, 39.00989668709891, 36.29985952377319, 36.12660271780831, 37.30975934437343, 39.27499825613839, 36.41903155190604, 38.69487231118338, 36.89476081303188, 36.57845449447632, 36.26961054120745, 36.8546210697719, 36.37658848081316, 36.29022584642683, 38.620724609919954, 40.76963220323835, 43.314826829092844, 44.471344062260215, 39.80574682780674, 41.95872606549944, 47.35665648324149, 46.484893798828125, 48.78951399666922, 46.81519378934588, 44.35425649370466, 49.675857475825715, 47.103085449763704, 46.126769747052876, 49.23737750734602, 49.442543915339876, 46.70562417166573, 49.0352509362357, 46.248637676239014, 48.3861015864781, 46.52438735961914, 43.88675389971052, 35.63447918210711, 36.00453676496233, 34.97257988793509, 35.34139721734183, 35.15638753346035, 36.096937383924214, 36.39958701814924, 38.39460938317435, 37.074406487601145, 35.91967841557094, 35.34146669932774, 35.89323009763445, 37.193481240953716, 35.13778373173305, 46.01600156511579, 47.63186420713152, 46.25889669145857, 45.610188552311485, 45.58910424368722, 40.191111292157856, 41.85920354298183, 46.64673818860735, 48.50868170601981, 46.49275915963309, 47.92905950546265, 46.029825006212505, 41.68147209712437, 44.983909198216026, 44.17349910736084, 45.84983886991228, 43.81328364780971, 43.39704486301967, 43.274482113974436, 44.529323305402485, 44.414997645786826, 47.25759949002947, 45.96976130349295, 42.025272437504356, 31.571843147277832, 8.740039995738439, 0.4989970954401152, 4.6310829264777045, 14.681072882243566, 18.16578033992222, 16.310201372419083, 15.411549159458705, 4.580050579139164, 2.739716176475797, 1.0666161200829913, 0.1604618068252291, 17.83157546179635, 41.05049923488072, 28.325328622545513, 46.578704902103965, 32.365334374564036, 2.2593166402408054, 0.2058292417121785, 0.14630120167774813, 0.11073224672249385, 0.11586821398564748, 0.13222508771078928, 0.10337782957191978, 0.0791746550904853, 0.16022096760571003, 0.08860541653952428, 0.10094692358481032, 0.07691662625542708, 0.12546545400151185, 0.16134255885013513, 0.0827065927109548, 0.1528841448681695, 0.1792155240795442, 0.12532624575708592, 0.22124680584030493], [0.02017643046565354, 0.0450964890686529, 0.04259113421929734, 0.08266254900289433, 0.02837530819566122, 0.021807084126131873, 0.004113590136902141, 0.012605590330037688, 0.0429124544773783, 0.0391700149380735, 0.023657310022307292, 0.020040358749351332, 0.03393854047837002, 0.013094769125538213, 0.059284988790750504, 0.052780738699116876, 0.009097343759744294, 0.025525914039462805, 0.0989047706659351, 0.05831348949245044, 0.016581629968381355, 0.028397621819749475, 0.056682783245508156, 0.037762506000165424, 1.1202565389020103, 16.20752263069153, 32.07847104753767, 20.673169817243302, 25.857543877192906, 29.022809641701834, 6.530085529599871, 0.17305277048477105, 0.04047813545912504, 0.07819834497890302, 0.04200674932716148, 0.185596033132502, 1.5190651161330087, 2.793685874768666, 0.6591267458030156, 0.12345751960362707, 3.0750887862273624, 21.283410991941178, 39.80152232306344, 46.60683468409947, 48.12407112121582, 48.06469529015677, 44.85684749058315, 49.24404082979475, 48.34064299719674, 46.666762896946494, 42.604449953351704, 39.54091623851231, 36.60140439442226, 39.87996053695679, 39.12387841088431, 40.514230319431846, 42.55739327839443, 45.80130222865513, 46.16520370755877, 46.75743688855852, 45.94008902141026, 45.693351541246685, 46.73498378481184, 41.85897077832903, 35.88668489456177, 35.58120386941092, 34.92596789768764, 35.735235009874614, 34.26971401487078, 35.41107375281197, 34.262428828648154, 35.06471300125122, 35.5218071937561, 33.771628924778526, 32.19216094698225, 34.84219346727644, 33.07752473013741, 33.32332420349121, 32.69976159504482, 33.17755447115217, 34.27304220199585, 35.69198942184448, 35.9414575440543, 37.83713109152657, 37.20964275087629, 39.32520246505737, 42.50908245359148, 44.75778354917254, 47.41588640213013, 45.694980893816265, 39.100525515420095, 48.920213086264475, 43.356898171561106, 47.88965974535261, 46.721337522779194, 45.74710627964565, 46.34181996754238, 44.42588894707816, 44.23961121695382, 45.12387023653303, 43.220286164964946, 39.09707573481968, 33.01259381430489, 31.06795631136213, 32.17810126713344, 31.788005079541886, 32.428694997514995, 32.27770021983555, 33.61073643820626, 34.48635189873831, 36.7441794531686, 37.37150798525129, 34.33557251521519, 31.980838435036794, 32.2071065221514, 33.20383603232247, 39.28596598761422, 43.68712520599365, 44.489968708583284, 44.48985058920724, 42.98363746915545, 38.99627126966204, 35.56518827165876, 36.42422185625349, 41.68107604980469, 42.76515136446272, 42.20900365284511, 41.05956315994263, 44.411533968789236, 43.19530391693115, 42.95904432024275, 40.67801325661795, 39.90229204722813, 37.577025277274, 37.174144404275076, 39.49151454653059, 41.250134876796174, 42.99945156914847, 43.25400229862758, 31.50602286202567, 14.923024790627615, 1.4296520054340363, 0.5365509146026203, 1.9317234073366438, 6.076406810964857, 8.822548985481262, 4.587235450744629, 5.9224846703665595, 3.675264843872615, 1.019781461783818, 0.054666682678673945, 0.26892725804022377, 23.086244446890696, 20.033011436462402, 20.323499986103602, 39.232687200818745, 6.945982984134129, 0.16238477506807872, 0.010208836706754352, 0.06245323164122445, 0.039947833200650554, 0.0364960475292589, 0.03714187376733337, 0.04485806882647531, 0.031674313225916455, 0.03253372871716108, 0.0690610363547291, 0.019534102075600197, 0.04027621700827565, 0.032819816044398716, 0.03824641003406473, 0.09135392441281251, 0.06262412747102124, 0.07236617364521537, 0.0808632369818432, 0.04311661548646433, 0.009858446312136948, 0.008832346149055021, 0.025029988061370592, 0.024991199607029557, 0.04909824772870966, 0.06807494855352811, 0.04605079089690532, 0.03419048392346927, 0.002524192041684208, 0.1372270035956587, 0.08838833961635828, 0.010997214670559126, 0.01880003066201295, 0.03183214386392917, 0.04817568098327943, 0.07175506465137005, 0.01316699493742947, 0.022659617575949857, 0.044090072358293195, 0.04730473718206797, 0.00373814653305869, 0.019018398498051932, 0.03533956940685, 0.05467989036281194, 2.6876798144408633, 23.721066611153738, 35.96917390823364, 22.17473111833845, 32.28461020333426, 33.434797627585276, 6.832586646080017, 0.3445792985813958, 0.13914092018135957, 0.07381916139274836, 0.5668914179716791, 0.46576467582157677, 5.131909515176501, 7.321403707776751, 2.6085554659366608, 0.4311416122530188, 5.406148399625506, 23.493665967668804, 42.99291678837368, 48.25702142715454, 47.01532622746059, 48.39901828765869, 44.55049794060843, 49.09091642924717, 49.849770886557444, 47.603209836142405, 46.39339644568307, 41.90199402400425, 38.18918589183262, 40.132840224674766, 40.261166504451204, 42.50936038153512, 43.63722671781267, 46.752705165318076, 48.993005888802664, 48.75940745217459, 47.64738995688302, 46.337220260075156, 47.5507926259722, 42.98826844351632, 38.06124523707798, 36.05120086669922, 37.45060280391148, 35.912949085235596, 34.51789672034127, 37.12052862984793, 35.462400095803396, 35.860177516937256, 37.63849599020821, 35.19989020483834, 34.68684564317976, 35.19055530003139, 34.78387376240322, 34.42804609026228, 33.69051218032837, 34.89489207948957, 36.04827567509243, 36.09783717564174, 37.77866200038365, 38.80839545386178, 39.65373761313302, 40.775294985089985, 44.68084614617484, 46.01748847961426, 48.634659494672505, 45.88139411381313, 41.40774433953421, 49.97839593887329, 44.93407324382237, 47.901892048971995, 47.79021365301949, 47.908392088753835, 48.8138952255249, 46.081043652125764, 46.51143939154488, 48.36259235654558, 44.92085429600307, 41.02494028636387, 33.758166790008545, 32.499424185071675, 33.984955992017476, 33.552670342581614, 33.16195229121617, 33.499648639133994, 34.21686601638794, 35.59368978227888, 37.7508796283177, 37.12054600034441, 35.868511881147114, 35.04193333217076, 33.43065997532436, 34.960073130471365, 40.83130093983242, 44.58909170968192, 45.475817339760916, 44.779083251953125, 44.33928312574114, 39.2875189099993, 37.27920811516898, 40.56171430860247, 43.46851403372628, 43.20098754337856, 43.03315033231463, 43.21324416569301, 44.638562883649556, 43.5990046773638, 44.41090515681675, 42.51933799471174, 41.92413098471505, 38.97591652188982, 39.4719796861921, 41.41503994805472, 42.49024241311209, 44.411756311144146, 44.01978758403233, 33.369720799582346, 18.134056602205547, 2.740513048001698, 1.6644727821860994, 4.3731410418237955, 7.111443911279951, 5.62232813664845, 7.130891919136047, 8.038420455796377, 2.7373494463307515, 1.1846427811043603, 0.15919712611607142, 0.15297912620007992, 26.139378445489065, 24.961860282080515, 19.81675222941807, 44.213882037571494, 11.783588085855756, 0.16171047410794667, 0.02706339127118034, 0.026377668870346885, 0.041547951088952165, 0.02835731005429157, 0.036795715734894784, 0.04650871382494058, 0.02337680703827313, 0.03319322743586131, 0.07292739674448967, 0.010431597208870309, 0.015949661111725227, 0.03511453326791525, 0.015434359566175511, 0.03861724977780666, 0.045763068300272734, 0.04709704100553479, 0.043254124000668526, 0.06137536519340106, 0.10628453788480588, 0.15200799331068993, 0.062463111111095974, 0.07661817941282477, 0.15435100187148365, 0.16552498085158213, 0.06028077964271818, 0.11242453341505357, 0.11999690958431788, 0.178561375609466, 0.1491856947541237, 0.05216671200469136, 0.09185197590185062, 0.09629681453640972, 0.19818026572465897, 0.12111505387084824, 0.11848341008382184, 0.13234111719897815, 0.1862886952502387, 0.1656480806746653, 0.11677479105336325, 0.11245433467307261, 0.1415037555353982, 0.1057567937033517, 2.41564633165087, 26.013711588723318, 44.548642771584646, 30.68421425138201, 36.09328610556466, 39.76963356563023, 12.82547220161983, 0.5271377339959145, 0.20509084633418492, 0.2606725538415568, 0.31961311825684136, 0.3493688330054283, 4.362113816397531, 12.65633133479527, 2.4061205685138702, 0.2589486134903771, 4.360156161444528, 23.580547979899816, 43.128788811819895, 48.56695972170149, 47.052457400730674, 49.05237477166312, 45.147421155657085, 50.743201528276714, 52.905477455684114, 49.264916692461284, 48.60880524771554, 44.577258927481516, 40.2006824357169, 43.46023178100586, 42.08232409613473, 44.91037293842861, 45.63349281038557, 49.12056786673409, 50.35771199635097, 49.82333646501814, 48.62315327780587, 48.11307559694563, 50.178938320704866, 45.286607469831196, 40.28656564440046, 39.484215463910786, 38.819001879010884, 38.86695487158639, 36.6239651952471, 38.700458662850515, 38.10679415294102, 37.90905884334019, 39.71884570802961, 36.41718680518014, 35.24492495400565, 37.78027745655605, 35.74648414339338, 36.00036784580776, 35.74744299479893, 36.37479931967599, 39.437822341918945, 39.63860443660191, 40.168150969914024, 41.506773539951865, 42.00230516706194, 43.20480210440499, 47.99478251593453, 49.575383050101145, 48.91907358169556, 48.83906854901995, 43.85626173019409, 50.94539063317435, 47.23445504052298, 48.442701612200054, 49.27071843828474, 47.99201365879604, 49.88810409818377, 47.699046339307515, 46.27208437238421, 49.52843754632132, 45.58758953639439, 42.61312130519322, 35.90469809940883, 34.33884164265224, 35.661351340157644, 35.359935011182515, 34.992514269692556, 36.31740025111607, 35.931323596409385, 37.806503432137625, 39.88527590887887, 40.71812520708357, 39.384897913251606, 35.67931590761457, 34.718741348811555, 36.16616228648594, 42.889395577566965, 46.73191268103463, 47.37069879259382, 47.64105667386736, 47.63145078931536, 41.00899764469692, 39.46116828918457, 40.82868146896362, 45.363228729793, 45.62082971845354, 45.674820695604595, 43.941602979387554, 45.65924283436367, 43.706052098955425, 44.79006487982613, 43.41996349607195, 44.35170997892107, 39.5576822417123, 40.60086393356323, 42.5796275138855, 44.4746618270874, 46.513808727264404, 45.83381632396153, 34.0590307371957, 16.862749917166575, 2.986425429582596, 1.7329432623726981, 5.445314960820334, 12.83539422920772, 16.429461990083965, 13.160941651889257, 13.122740456036158, 11.247605783598763, 4.350927650928497, 0.41905923773135456, 0.4653150513768196, 33.577777658190044, 27.940047536577495, 27.641910757337296, 50.09626865386963, 14.206022807529994, 0.2905808575451374, 0.1305441800504923, 0.09578810326222863, 0.1321312870298113, 0.1497749209936176, 0.1998988999319928, 0.13710538297891617, 0.10416087933949061, 0.07737344317138195, 0.14935619703360967, 0.07318098563700914, 0.09100538811513356, 0.12084369414619037, 0.18526927780892166, 0.13460386863776616, 0.10271878886435713, 0.13755730087203638, 0.14216486577476772, 0.1714904164629323], [0.031100130107785975, 0.10428729719881501, 0.03420865169859358, 0.013878512695165617, 0.04356731201655098, 0.006149138789623976, 0.08574467897415161, 0.026866923152868236, 0.012679285170244319, 0.014552113067890917, 0.02342044362532241, 0.03186172799074224, 0.06387624849698373, 0.03673266286828688, 0.004871626559179276, 0.029251339313174998, 0.01953363388643733, 0.03262265073135495, 0.02429598450128521, 0.05225577311856406, 0.04672375853572573, 0.006702177060235823, 0.029910515727741376, 0.0034947195506122497, 0.0782857606453555, 3.7697538307734897, 27.492656503404888, 32.69120488848005, 24.745731353759766, 36.07596772057669, 13.530928015708923, 0.4630933648773602, 0.3104071622448308, 0.14628928660282067, 1.0892451001065118, 0.6871854716113636, 3.9656370111874173, 6.18348810502461, 2.7657384829861775, 1.1724103689193726, 0.358686095901898, 7.594042335237775, 26.991444723946707, 40.27733843667166, 49.630141803196494, 44.53332199369158, 48.265282835279194, 47.0687370300293, 46.80175597327096, 43.319919858660015, 43.542779854365754, 38.67259291240147, 40.31490387235369, 37.509940419878276, 40.29865550994873, 41.69657053266253, 44.47170189448765, 45.06907674244472, 47.54446281705584, 46.81989424569266, 46.2321982383728, 46.3567134312221, 45.2836023739406, 38.09125450679234, 36.324275493621826, 33.68484245027815, 34.321436405181885, 34.638468810490195, 34.896993909563335, 36.60846029009138, 35.8978054864066, 33.29884222575596, 34.91021285738264, 34.204095227377756, 34.50752305984497, 33.06775903701782, 33.85922139031546, 31.851438658578054, 32.763417516435894, 32.81674494062151, 34.369670799800325, 34.446993827819824, 36.603912694113596, 35.73644399642944, 39.20267793110439, 40.27991621834891, 42.74269131251744, 43.91040556771414, 46.378176416669575, 44.242105620247976, 38.53774574824742, 45.73442234311785, 45.88039009911673, 46.706485748291016, 43.27250187737601, 45.837012495313374, 43.96747807094029, 45.54269027709961, 43.07426282337734, 43.685506275721956, 41.60368353979928, 37.844423225947786, 31.28398970195225, 32.15665217808315, 32.66129289354597, 32.028721945626394, 33.27300534929548, 32.07351350784302, 33.364214352199006, 36.56810515267508, 41.42975623267037, 39.482867513384136, 36.656520979745046, 32.97919382367815, 31.11311960220337, 33.16103512900216, 35.39724336351667, 42.7724643434797, 44.20139265060425, 44.96602800914219, 42.564515181950156, 42.5687883240836, 38.05747931344168, 34.33283839906965, 33.9782509803772, 39.86881215231759, 40.828855173928396, 44.04558971949986, 42.09721408571516, 43.65110574449812, 41.90568699155535, 38.58788742337908, 36.07150002888271, 36.365513052259175, 37.10940456390381, 41.075234821864534, 41.263940947396414, 44.04793473652431, 36.10139465332031, 20.21387651988438, 4.301642341273172, 0.21025201438793115, 2.6359061811651503, 2.9761688028063094, 4.295306886945452, 3.5075867899826596, 5.0010979516165595, 6.080656068665641, 0.9897997677326202, 0.6644834812198366, 0.07227062912923948, 3.164065028939928, 28.71130105427333, 20.216940675462993, 31.50725964137486, 26.3980199268886, 2.179015657731465, 0.13381036264555796, 0.02903985691123775, 0.02831626377467598, 0.02119053158509944, 0.022936919571033547, 0.04247817849474294, 0.031605825293809175, 0.026725945628381202, 0.07360036777598516, 0.07321545521595649, 0.036497109436563084, 0.047702148357140164, 0.03012260202584522, 0.07550727509494339, 0.06445092694567782, 0.013626185029612055, 0.026139681194243685, 0.01626092378449227, 0.06716460561645882, 0.04154286886166249, 0.0366479104517826, 0.015322842335860645, 0.018031825544312596, 0.03723521643717374, 0.017850132526031563, 0.05149412773815649, 0.07014737091958523, 0.04128032669957195, 0.021270569879561663, 0.028029618352385502, 0.06567892605172736, 0.045981353015771935, 0.029698378539511135, 0.005904110464533525, 0.04169155963297401, 0.020092597464099526, 0.03809902883533921, 0.06310315283813647, 0.05107006710022688, 0.058350693567522934, 0.009573524368793836, 0.04699407670912998, 0.023741053117971336, 0.09638630652001925, 7.305862324578421, 35.75771590641567, 33.54802894592285, 26.11113749231611, 42.64114686420986, 18.10966842515128, 0.38774085683482035, 0.2059279821280922, 0.3348576288138117, 0.7342273816466331, 3.895633041858673, 6.527305381638663, 6.928887810025897, 4.960561726774488, 1.860648329768862, 0.8415025738733155, 9.923027259962899, 28.624884571347916, 44.92195211138044, 49.30042893545968, 45.860403605869834, 48.5050755909511, 48.83150543485369, 47.331858362470356, 44.13846629006522, 44.85382849829537, 40.8913368497576, 40.888835498264854, 39.689958572387695, 41.74629531587873, 44.04145206723894, 45.81970453262329, 46.698304244450156, 47.77190514973232, 47.868672711508616, 46.780539648873464, 48.07142462049212, 47.49912234715053, 41.96024424689156, 37.063212939671104, 36.37247167314802, 36.137233461652485, 36.98374291828701, 36.9578400339399, 38.175904410226, 36.7610045160566, 37.01588181086949, 36.94305774143764, 36.36911916732788, 36.65201159885952, 35.210923944200786, 34.39529228210449, 34.23140859603882, 33.65423910958426, 35.55440466744559, 37.28026424135481, 37.12736913136074, 38.226730482918875, 38.02342619214739, 41.04187304633004, 43.69473000935146, 44.951985699789866, 45.700692313058035, 47.238352979932515, 47.61093623297555, 38.108374868120464, 47.66726875305176, 47.53437055860247, 47.27111373628889, 44.80507298878261, 46.77258048738752, 44.82970782688686, 47.90541478565761, 44.69779975073678, 44.86127349308559, 42.792836461748394, 39.71374920436314, 33.401602608816965, 33.10469218662807, 33.96901682444981, 34.83426209858486, 33.43801464353289, 33.77828877312796, 34.33960247039795, 38.77903584071568, 42.49379989079067, 41.14498083932059, 38.99042088644845, 33.82288578578404, 32.952460629599436, 34.4415533883231, 38.59446389334542, 43.752101285117014, 44.70328187942505, 45.318461486271445, 44.615741525377544, 43.06303106035505, 38.75594697679792, 35.27549702780587, 36.10391337530953, 42.68178340366909, 41.97422749655587, 44.62997491019112, 43.004113810403005, 45.02932609830584, 42.90623106275286, 41.204843044281006, 38.621575764247346, 37.980382101876394, 39.21107830320086, 42.98500279017857, 43.33387878962925, 46.14764213562012, 37.87582213538033, 23.604710340499878, 6.168358836855207, 1.230254773582731, 6.55283306326185, 4.942439956324441, 7.742643458502633, 6.069049537181854, 8.45632072857448, 6.9216764484133035, 1.324673627104078, 0.13548622200531618, 0.10668882940496717, 2.7305814666407446, 37.87764951160976, 22.438912051064626, 30.850825105394634, 33.88640621730259, 2.9609177240303586, 0.17924839231584752, 0.04967686168051191, 0.01746298758579152, 0.00546720897546038, 0.03287557805223124, 0.06711249412702662, 0.024991862875010287, 0.027598770667931864, 0.06244564561971596, 0.058156306855380535, 0.051152536246393404, 0.033078578766435385, 0.020394455641508102, 0.05140104969697339, 0.024576161788510423, 0.01424855346392308, 0.024545395314427357, 0.03556544353653278, 0.033446500809597116, 0.13891233530427727, 0.10924957985324518, 0.14733139425516129, 0.10311123316309281, 0.09007120824285916, 0.14362470672598907, 0.18544216853167328, 0.1082420978429062, 0.08372332315359797, 0.14304787053593568, 0.09633001525487218, 0.17403364713702882, 0.1210803807313953, 0.07943376725805656, 0.10096468763159853, 0.063480309742902, 0.08154652853097234, 0.17074519502265112, 0.13546833582222462, 0.147933675508414, 0.13170051228787216, 0.06686330892677818, 0.11476965221975531, 0.11722176921154771, 0.2115887962281704, 7.586946487426758, 39.43483461652483, 41.85567733219692, 34.00298656736101, 45.698479311806814, 23.311734335763113, 1.2112716436386108, 0.5433079834495271, 0.2533228253679616, 2.1852490603923798, 5.634397157600947, 11.595133832522801, 14.314867206982203, 7.791803700583322, 2.7536080139023915, 0.6482465182031903, 8.72475482736315, 29.431488786424907, 43.46943814413888, 49.460286140441895, 45.50118521281651, 47.77538619722639, 50.54750204086304, 48.94884313855852, 47.01143871034895, 48.42161382947649, 42.820698738098145, 44.29020799909319, 41.01149899618966, 43.711694036211284, 45.882220949445454, 48.612998485565186, 47.86751236234392, 50.27916261128017, 49.50639091219221, 48.90874855858939, 49.982342515672954, 49.22143139157976, 42.17695508684431, 39.114296845027376, 37.79466717583792, 37.92667947496687, 37.345785754067556, 38.23748629433768, 39.67412710189819, 39.275303976876394, 37.65491458347866, 39.28220353807722, 39.045224802834646, 39.45151029314314, 37.342019830431255, 37.27859319959368, 36.76076480320522, 35.87831926345825, 37.1972645350865, 40.15801354816982, 38.83116817474365, 39.73595217296055, 41.37081813812256, 42.854869978768484, 45.07745974404471, 47.20852088928223, 48.205083642687114, 48.74608080727713, 48.40856163842337, 40.643202781677246, 47.419391768319265, 48.67537941251482, 47.933440344674246, 46.403009278433665, 48.32294593538557, 46.08457333700997, 50.284842763628276, 44.60832779748099, 46.00037506648472, 44.85064622334072, 41.19980560030256, 34.14271484102522, 34.519616399492534, 36.014340673174175, 35.18464585712978, 35.53662770135062, 35.40238503047398, 36.234775747571675, 40.92452144622803, 44.54203503472464, 43.19837154660906, 40.08247620718819, 36.127363545554026, 33.88352271488735, 36.72214324133736, 39.46485778263637, 45.122682094573975, 46.738659381866455, 46.910290309361045, 45.17436626979283, 45.973846844264436, 40.25057397569929, 36.54777472359793, 37.34689746584211, 44.23265607016427, 43.652234826769146, 47.021253040858674, 44.442008767809185, 47.87966128758022, 44.53387090138027, 43.088819299425396, 39.404001985277446, 40.505579812186106, 41.850820541381836, 45.85585600989205, 44.642547675541465, 47.931682450430735, 37.88715117318289, 23.735956600734166, 5.7454836538859775, 1.6225778588226862, 7.823069725717817, 9.5201507295881, 11.731975998197283, 13.025809611592974, 13.005990743637085, 15.384743009294782, 6.085221035139901, 1.3664060277598244, 0.3541957139968872, 4.760440145220075, 41.24684143066406, 26.991257122584752, 39.90679447991507, 37.98945644923619, 4.154585455145154, 0.3947434739342758, 0.1491558663547039, 0.13759406389934675, 0.10835058880703789, 0.18065842879670008, 0.17093454700495514, 0.1036694028547832, 0.06272176187485456, 0.16846667443002972, 0.19698153861931392, 0.1528760703014476, 0.10297867456184966, 0.09844768233597279, 0.2072335784988744, 0.09097251309348003, 0.08747921125697238, 0.1153296200292451, 0.12814881572765963, 0.14786926896444388], [0.034559997131249735, 0.026333762565627694, 0.019430946093052626, 0.07246104641152279, 0.02849564129220588, 0.027553648089191744, 0.10319951735436916, 0.031260875053703785, 0.015621782812689031, 0.003985048462969384, 0.08012473303824663, 0.07568603514560632, 0.05739549946572099, 0.044505943078547716, 0.01603992153624339, 0.014640892589730876, 0.1357166932097503, 0.04690871700378401, 0.07139885412263018, 0.0674906891903707, 0.02506070025265217, 0.06736017976488386, 0.05518487987241574, 0.07097544827099357, 0.041595323011279106, 0.3832221121660301, 8.816335558891296, 33.2286411012922, 22.577848230089458, 33.56959615434919, 22.09310368129185, 0.17457908072641917, 0.09473112212227923, 0.25240493033613476, 0.865630139197622, 1.686138133917536, 7.928195970399039, 7.203208770070757, 3.99186863218035, 1.2412815647465842, 1.180416322180203, 1.1158908988748277, 12.148778455598013, 30.750941276550293, 41.88878549848284, 48.54413488933018, 48.45610121318272, 49.5018606867109, 46.81905351366316, 45.1412615776062, 40.737701756613596, 39.73773785999843, 38.07659033366612, 39.529267583574565, 40.72529574802944, 42.70040804999215, 44.592770780835835, 45.55659709657942, 44.01840836661202, 44.849037715366904, 44.92949090685163, 43.18111569540841, 40.641924313136506, 37.3777300970895, 34.63452223369053, 34.79898609433855, 36.30696753093174, 35.16088301794869, 35.12250811713082, 35.596215452466694, 38.176255294254844, 37.349575996398926, 36.82015105656215, 34.55842208862305, 36.59546715872628, 34.03117193494524, 34.1935304914202, 33.09478752953665, 32.76953540529524, 32.847671372549875, 33.3680671283177, 34.292323453085764, 34.65657581601824, 34.861439977373394, 37.44513457162039, 40.026268754686626, 43.8179041998727, 44.07684966496059, 46.07890708105904, 45.83862795148577, 39.472268036433626, 44.157552991594585, 46.55060291290283, 44.200670037950786, 43.332523890904014, 46.66907317297799, 42.67176757540022, 43.13481289999825, 43.68443277903965, 43.18851900100708, 40.09157487324306, 38.273293835776194, 33.22816514968872, 32.62031936645508, 32.232067925589426, 33.224343640463694, 32.57463148662022, 31.623322350638254, 33.17690134048462, 40.31659575871059, 43.72057383401053, 44.6339145387922, 41.83345004490444, 36.142180579049246, 32.37878261293684, 32.0423960004534, 31.916077750069753, 39.76433209010533, 45.08605119160244, 44.15847362790789, 43.67123120171683, 42.38482434409005, 41.935164724077495, 39.69819566181728, 34.74702399117606, 32.573950563158306, 35.099627699170796, 38.89030081885201, 39.60908154078892, 41.147120884486604, 41.11626393454415, 37.83968802860805, 34.48269714627947, 34.32739101137434, 38.52034745897566, 41.1020062310355, 43.71962887900216, 44.77838495799473, 29.343173708234513, 10.928031206130981, 1.2478387100355965, 0.8505361005663872, 4.566986228738513, 3.0711278787681033, 8.003250411578588, 3.486823401280812, 4.938356152602604, 6.281436426298959, 0.9351757445505687, 0.02613458369991609, 0.02254088412571166, 11.82682238306318, 29.755014283316477, 18.08827839578901, 35.08267756870815, 14.728138242449079, 0.12668398075870105, 0.016626157132642608, 0.03634815064391919, 0.06239710322448185, 0.019467839738354087, 0.035035877488553524, 0.03988881761740361, 0.033288442862353156, 0.06014246706451688, 0.0462667753786913, 0.003303364829792242, 0.04441174206190875, 0.0308128553442657, 0.05005910759791732, 0.03936581978840487, 0.009338121911111687, 0.011622556784589375, 0.05457645448456917, 0.04795665327193482, 0.034935077718858204, 0.03364482302484768, 0.03259447795738067, 0.0213765044630106, 0.051726902568978925, 0.023955461702176502, 0.04165414860472083, 0.042416194320789406, 0.00843264237378857, 0.04491879431796925, 0.03861278501738395, 0.055962409757609875, 0.01492244391036885, 0.03864350908302835, 0.07725108973681927, 0.05474612216598221, 0.039402993329401524, 0.0726462389741625, 0.019225718087649772, 0.027502233794491206, 0.08374351635575294, 0.012374714549098696, 0.03960484392674906, 0.04729511894817863, 0.016376887115516832, 0.008019763144797512, 0.9130943694284984, 15.497705084936959, 38.010617188044954, 25.68902747971671, 38.116222858428955, 24.729430879865372, 0.3442148438521794, 0.19181898635412964, 0.9301501342228481, 1.9110840005534036, 3.433327917541776, 8.883125117846898, 9.81236503805433, 7.149836182594299, 3.417558112314769, 1.3953786045312881, 2.612077985491071, 15.332947662898473, 32.64558301653181, 43.1213264465332, 49.058572564806255, 49.246764523642405, 50.80047900336129, 47.521738733564106, 46.68194471086775, 42.80041694641113, 42.38911485671997, 39.823961530412944, 42.34781476429531, 42.98481518881661, 44.188149384089876, 45.50892898014614, 47.533682686941965, 47.47825343268258, 47.703316007341655, 46.555459703717915, 44.12121391296387, 43.22939872741699, 38.990024839128765, 36.89083160672869, 37.11699199676514, 36.44047369275774, 36.278396538325715, 37.165935107639854, 37.72976057870047, 40.381623949323384, 38.34301553453718, 38.81115388870239, 36.80452108383179, 38.110056332179475, 34.72527265548706, 35.092210497174946, 34.20771871294294, 33.75107267924717, 34.485730034964426, 35.70109503609793, 36.43235124860491, 36.57970864432198, 38.074144567762104, 39.37246758597237, 41.66030788421631, 45.57093123027256, 45.30345685141427, 47.85240003040859, 46.938176904405864, 42.526741300310405, 44.0408684185573, 46.68732609067644, 45.64926174708775, 44.13967875071934, 48.260808195386616, 45.76689822333199, 45.682324750082834, 46.65709795270647, 43.76602894919259, 41.18348775591169, 40.09645250865391, 34.10492011478969, 33.88796608788626, 32.64777864728655, 33.96698447636196, 33.31636905670166, 33.75925418308803, 35.177975586482454, 41.321062088012695, 45.412762437547954, 43.320725849696565, 42.37826524462019, 35.661928040640696, 33.992140429360525, 33.16508592878069, 33.54733760016305, 42.19005938938686, 45.941645417894634, 44.16404260907854, 44.33487449373518, 43.68090309415545, 42.806291648319785, 40.489946365356445, 35.093461172921316, 33.99625376292637, 36.98173141479492, 41.16939333506993, 40.04779774802071, 44.433417320251465, 43.51167971747262, 38.91973686218262, 36.045624937329976, 36.624833720070974, 39.9142290524074, 42.838180405753, 44.25815595899309, 44.64904076712472, 31.240615572248185, 13.032152448381696, 2.716814479657582, 2.0914273176874434, 4.752753266266414, 5.365612609045846, 6.9306535209928235, 5.425172567367554, 6.646424429757254, 3.648941593510764, 0.5663368105888367, 0.05257580755278468, 0.06886287020253283, 12.77366816997528, 35.9513760975429, 17.19379162788391, 39.5984160559518, 19.740026746477398, 0.6172858881098884, 0.09499098067837101, 0.04672087136922138, 0.04771282849833369, 0.028439100665439452, 0.05292034727920379, 0.05604132677295378, 0.04121506520147834, 0.050525892193296125, 0.026804321512047733, 0.032125613652169704, 0.02083834646535771, 0.01881569973193109, 0.006991031962180776, 0.04400879743375948, 0.036778321489691734, 0.0401188511667507, 0.07630393627498831, 0.10981395135500602, 0.03179631382226944, 0.13451008152748856, 0.1305150030446904, 0.10217882426721708, 0.20596421589808805, 0.07892397711319582, 0.10785561786698443, 0.15135969381247247, 0.13120942935347557, 0.15745611382382257, 0.17446769241775784, 0.19551359595996992, 0.13136230329317705, 0.16402425138013704, 0.1427972875535488, 0.20203179333891186, 0.1326646562665701, 0.24881409587604658, 0.12703095642583712, 0.1316991416471345, 0.2155329031603677, 0.2453942522406578, 0.1630908450377839, 0.12300891296139785, 0.14833843521773815, 0.10466926491686276, 0.9749438677515302, 17.21639585494995, 44.18946259362357, 32.51107631410871, 42.3640318598066, 31.15741436822074, 0.8706899476902825, 0.768555608178888, 1.3055843200002397, 2.2254033514431546, 5.572149983474186, 15.340317964553833, 16.351167951311382, 10.977331280708313, 3.993104977267129, 2.456882804632187, 1.8280743062496185, 14.084609116826739, 34.34154796600342, 43.75348745073591, 47.9669098172869, 51.52458551951817, 53.09044892447335, 50.76067277363369, 48.20054646900722, 44.676635537828716, 43.76598031180245, 41.64364957809448, 44.782185622623985, 45.08631522314889, 46.17288841520037, 47.38663796016148, 48.19584601266043, 48.53483125141689, 49.82568148204258, 47.788115297045024, 44.765370982033865, 43.96462236131941, 40.69941370827811, 37.45966672897339, 38.348636627197266, 38.462701729365754, 37.74213184629168, 41.077715328761506, 38.00553805487496, 42.53582954406738, 40.673764433179585, 41.69618490764073, 39.00911848885672, 40.50393656321934, 36.48730107716152, 36.89530624662127, 35.93644094467163, 35.58718974249703, 36.13334247044155, 37.625610555921284, 39.06119523729597, 39.00785044261387, 39.22928605760847, 41.77121850422451, 43.81644855226789, 47.746825626918245, 48.75762176513672, 49.54207338605608, 48.239744731358115, 43.93025309698922, 45.13715866633824, 47.972200870513916, 46.682114941733225, 46.37885734013149, 48.730016572134836, 47.24398449489048, 46.45763948985508, 49.362813336508616, 46.34714576176235, 42.46211610521589, 41.777183532714844, 36.54528032030378, 36.48352125712803, 34.3685417175293, 35.75540910448347, 34.74200391769409, 35.301090717315674, 37.116186005728586, 42.62165021896362, 47.25351047515869, 45.838033880506245, 44.73365592956543, 37.90147835867745, 34.21883930478777, 34.320835386003765, 35.98559250150408, 44.42921366010393, 47.748680795942036, 45.47940608433315, 44.42290122168404, 45.65988554273333, 45.36658818381173, 41.7722989491054, 38.808419772556846, 35.627968720027376, 38.538506575993125, 41.878234658922466, 42.1065559387207, 46.198867729731965, 45.87221901757376, 40.21753181729998, 37.061757292066304, 38.671175479888916, 41.26951340266636, 45.34646967479161, 46.69415964399065, 46.01880863734654, 31.603158678327286, 13.78708985873631, 2.336698727948325, 3.126866762127195, 9.663139445441109, 10.32183735711234, 15.38537529536656, 11.270712886537824, 12.564396245138985, 13.001301578113011, 3.9474118862833296, 0.08260492102376052, 0.17025179149849073, 18.03104955809457, 38.4544472694397, 24.99523769106184, 45.141188621520996, 22.919590166636876, 0.709275911961283, 0.16323785643492425, 0.09964171397898879, 0.19971744609730585, 0.09835386808429446, 0.15768410159008844, 0.16079677242253507, 0.1412927040031978, 0.1619491691568068, 0.10099464495267187, 0.06034113533262696, 0.15476562747997896, 0.08034212208752121, 0.07913050960217204, 0.14374897362930433, 0.0759271118523819, 0.10585460452628986, 0.18445931055716105, 0.15599484794906207, 0.08141991389649254], [0.058788172235446315, 0.03532317600079945, 0.03342069951551301, 0.039391230924853256, 0.027569656426619207, 0.04139920603483915, 0.05512286177171128, 0.045103966524558406, 0.013429390366322227, 0.08067767122494322, 0.05159980956731098, 0.03894352673419884, 0.075175423973373, 0.04090541913839323, 0.03208590239020331, 0.059294250793755054, 0.12444767861493997, 0.034557693504861424, 0.020241120297993933, 0.039361952138798575, 0.026018963029075946, 0.06233732428933893, 0.019163710164970586, 0.030642868751393895, 0.04292541788890958, 0.09128909039178065, 1.6638735000576292, 23.988207476479666, 29.515006133488246, 28.818011488233292, 37.94789579936436, 2.8768060888562883, 0.10980950695063386, 1.2236838404621397, 0.9427662172487804, 4.961120622498648, 6.429981095450265, 4.7889538151877264, 3.769630934510912, 5.87628218957356, 0.7494943652834211, 0.8490115138036864, 3.1438485937459126, 16.01450514793396, 34.41663714817592, 45.15597786222185, 51.64570999145508, 48.522727489471436, 46.94150161743164, 44.272966044289724, 42.09416382653372, 40.62149313517979, 38.34957810810634, 38.45170620509556, 40.68096276691982, 39.836978980473106, 42.53087200437273, 40.720299993242534, 40.956497056143625, 40.128098079136436, 38.44810356412615, 36.22810895102364, 36.08365242821829, 35.01293502535139, 35.798967361450195, 35.61798415865217, 35.53747190747942, 34.29603379113333, 35.89118037905012, 37.08136510848999, 39.24678856985909, 40.898535183497835, 37.97604295185634, 35.069371768406455, 34.54998697553362, 32.358723163604736, 33.417809282030376, 33.006284849984304, 32.190545490809846, 33.165415968213765, 33.17707851954869, 34.952965123312815, 35.73199020113264, 34.63438326971871, 38.0826804297311, 38.22252682277134, 42.89275503158569, 43.75773974827358, 47.72953156062535, 44.24563530513218, 39.091194084712434, 42.11767653056553, 43.87255872998919, 41.231836795806885, 42.241281509399414, 45.66522870744978, 43.00555903570992, 45.75230005809239, 43.24216604232788, 43.46787827355521, 40.96068334579468, 37.25092199870518, 34.76566253389631, 32.52410418646676, 31.8311117036002, 31.45429352351597, 31.894090175628662, 33.591482979910715, 35.16824810845511, 42.4705616406032, 43.72372136797224, 43.93183033806937, 42.15917812074934, 41.373250007629395, 32.85621418271746, 31.239886011396134, 33.2659946169172, 33.85087660380772, 41.222807611737935, 43.93237229755947, 43.22288826533726, 44.945801803043906, 43.17950371333531, 41.57198585782732, 41.29685456412179, 38.499336106436594, 33.49718202863421, 31.908160277775355, 32.59106397628784, 34.935539041246685, 33.87085267475673, 34.50925316129412, 33.855247020721436, 35.79478454589844, 39.617120606558665, 42.04185083934239, 43.16281066622053, 40.3444823537554, 22.288301161357335, 5.515776642731257, 1.1548884234258106, 1.9411486387252808, 3.5622139615671973, 2.6827366054058075, 5.678661090987069, 3.371455729007721, 5.939233303070068, 1.9790058987481254, 0.1868347938039473, 0.08754842182887451, 1.013012939265796, 27.72187236377171, 26.517449038369314, 30.69508818217686, 28.848887545721873, 4.449315445763724, 0.08708929110850606, 0.012483651650005152, 0.049485206071819575, 0.035736644707087956, 0.03408455442903297, 0.029321625363081694, 0.023425412197996463, 0.01139939170596855, 0.07577647707824196, 0.0018511272875392543, 0.04967966063746384, 0.06475836437727724, 0.018489200555320297, 0.04072080333051937, 0.04371603671461344, 0.04049151956236788, 0.011137903817663235, 0.04387692754556026, 0.01624130903344069, 0.024370377384392277, 0.07499749173543283, 0.04233418657843556, 0.034162341683570824, 0.010061927089866782, 0.025505435852599994, 0.027273920331416384, 0.03650441386603883, 0.0038837045930059893, 0.012270697675246214, 0.023388828982466033, 0.04433741194329091, 0.04748411809227296, 0.029805207092847143, 0.009414510535342353, 0.009789375688082405, 0.026245451232950603, 0.040100941234933477, 0.03275279714060681, 0.08532881843192236, 0.025768732884898782, 0.013224210706539452, 0.029684261618448154, 0.05323913660166519, 0.05458692427990692, 0.04984565744442599, 0.09025844319590501, 3.3517923269953047, 30.81919343130929, 30.39149706704276, 33.15756797790527, 43.552222456250874, 2.3230407408305576, 0.1728990687323468, 0.7030788787773677, 0.8398830464908055, 0.9931843004056385, 6.03585147857666, 7.357737575258527, 5.5728886638368875, 9.261496220316205, 4.954680945192065, 1.140036974634443, 4.020902548517499, 18.477881261280604, 35.448413372039795, 47.17565590994698, 50.220912388392854, 50.524044922419954, 48.08067267281668, 46.862792423793245, 44.352227619716096, 42.38950048174177, 39.943279470716206, 41.35934318814959, 40.71757282529558, 42.43452133451189, 42.47637728282383, 42.716930866241455, 43.3439884185791, 42.31147568566458, 40.15189913340977, 38.72564588274275, 36.741987296513145, 36.664563519614084, 37.46013920647757, 36.928438731602256, 36.130132402692524, 36.35415622166225, 36.73358345031738, 37.81287145614624, 41.29488474982125, 41.73835352488926, 39.71134512765067, 37.73553453172956, 36.079480034964426, 35.620110307421, 35.06732552392142, 34.72406019483294, 33.016154766082764, 34.13138927732195, 35.62163891111101, 36.29233809879848, 36.59317077909197, 37.29643269947597, 39.932926654815674, 40.56327417918614, 43.93475900377546, 45.8754221371242, 49.10199533190046, 46.75794758115496, 40.57209839139666, 43.42274972370693, 44.331150259290425, 42.335238524845664, 42.72639431272234, 47.10277625492641, 44.20714575903756, 47.363069670540945, 47.21589987618582, 44.78166798182896, 42.65670388085501, 38.84055866513933, 36.469624859946116, 34.33043084825788, 33.381716864449636, 33.27201870509556, 33.385590485164094, 34.23196792602539, 36.51898486273629, 43.28819785799299, 45.133271149226594, 46.72354704993111, 44.22488451004028, 42.82430485316685, 34.402942248753135, 33.501965863364084, 34.1678603717259, 36.96172060285296, 42.730650084359304, 45.04302794592721, 45.04953840800694, 44.89456231253487, 43.372416973114014, 44.13836554118565, 42.98708724975586, 38.80115195683071, 34.66949251719883, 33.07687854766846, 34.89770262581961, 36.2787960597447, 36.99826465334211, 36.123896394457134, 34.94178894587925, 36.59283379146031, 41.36023603166853, 43.458143847329275, 44.00736420495169, 41.05031510761806, 24.116078649248394, 6.706021734646388, 1.7162009264741624, 2.1090145111083984, 3.058170356920787, 6.549682489463261, 8.246301003864833, 5.794568768569401, 7.822678889547076, 3.3484324387141635, 0.5165522620081902, 0.09653234761208296, 0.6722121579306466, 32.228722367967876, 27.129931007112774, 28.19866817338126, 36.39212465286255, 7.232689108167376, 0.09233018024159328, 0.047419891360082796, 0.07862933685204812, 0.016585132905415127, 0.05384070539314832, 0.04162449662440589, 0.03906702010759285, 0.06141742757920708, 0.025231012542332922, 0.040457918508244414, 0.039277128476117334, 0.01457274392513292, 0.03584198387605803, 0.03509612800553441, 0.04337318993306585, 0.0487899824843875, 0.014093386924027331, 0.03603846386873296, 0.03408400820834296, 0.021999501390382648, 0.22464679554104805, 0.11297909330044474, 0.12370670480387551, 0.13964070193469524, 0.17732424342206546, 0.09938923788389989, 0.11638703543160643, 0.23696557166320936, 0.10677783962871347, 0.16618823526161058, 0.09539877343922853, 0.17233220700706753, 0.1473172807267734, 0.092188556412501, 0.10886073179010834, 0.11569445473807198, 0.2717858446495873, 0.11916545991386686, 0.11402695492974349, 0.07609216549566813, 0.07427465516541686, 0.13801770045288972, 0.27551914432219093, 0.11020841090274708, 0.10894095498536314, 0.2031602513577257, 4.337219289370945, 35.953724588666645, 39.13423817498343, 37.07227686473301, 47.26804263251168, 5.004228983606611, 0.4529667996934482, 3.623142280748912, 3.1851838614259447, 11.832641499383108, 13.510893753596715, 12.761363778795515, 10.671300479343959, 10.995436549186707, 2.8494099932057515, 1.8730921191828591, 3.7955524921417236, 19.95059711592538, 36.02442250932966, 46.95747900009155, 52.27818019049508, 52.71071250098092, 51.13355827331543, 48.352208273751394, 46.336379528045654, 45.82796246664864, 43.51258298328945, 42.686907700129915, 43.75054488863264, 43.74168940952846, 44.75692892074585, 43.39754860741751, 45.80217770167759, 43.94442742211478, 41.7040467943464, 39.494460582733154, 38.33211381094796, 39.02897644042969, 39.64725146974836, 39.38257026672363, 37.145965984889436, 37.6156051499503, 38.65093537739345, 40.795455183301655, 43.18810210909162, 46.02309567587716, 43.003366879054475, 40.23982858657837, 37.86942284447806, 35.86431169509888, 35.65098115376064, 37.323780809129985, 35.05933856964111, 36.666012219020296, 37.63975708825247, 38.685547828674316, 39.055549825940815, 39.150972911289756, 42.24269546781267, 41.17466354370117, 45.72419112069266, 47.73284237725394, 51.58422538212368, 49.45444965362549, 43.36544792992728, 42.81669657570975, 46.92648656027657, 44.919690472739084, 45.02163791656494, 47.51596825463431, 46.69226278577532, 49.48208958762032, 48.71801355906895, 46.73906932558332, 45.508428709847585, 40.30803210394723, 37.84481232506888, 36.34654794420515, 33.87925999505179, 35.463136604854036, 35.03188623700823, 35.99353081839425, 39.21308980669294, 45.630178519657676, 47.10779980250767, 46.10521643502371, 44.97104113442557, 45.93743828364781, 36.994484833308626, 34.56750338418143, 35.8484593800136, 37.08847311564854, 44.32729400907244, 47.84129680906023, 45.569447789873394, 46.41853502818516, 45.82185500008719, 46.081721101488384, 46.24056734357561, 41.79569353376116, 37.05188042776925, 35.29635899407523, 34.99314655576433, 37.41596950803484, 38.33487919398716, 36.37328461238316, 36.43239293779646, 38.605744293757844, 43.860944816044395, 45.03554821014404, 45.32361357552664, 42.34363194874355, 24.942057916096278, 7.406837020601545, 2.868411145039967, 5.367730072566441, 8.748675738062177, 10.315577898706708, 15.103292328970772, 11.475461534091405, 15.815936054502215, 8.126998697008405, 1.4462377897330692, 0.2747958259923117, 1.681501405579703, 37.46586799621582, 35.53837864739554, 38.31805760519845, 39.95660958971296, 8.768974031720843, 0.1373446887092931, 0.1598968721394028, 0.19743811126266206, 0.10388981138489076, 0.14898233780903475, 0.13942783192864486, 0.10843717666076762, 0.10914572328329086, 0.1433556947324957, 0.10214788307036672, 0.08977371813463313, 0.14342235401272774, 0.1184736934623548, 0.13025744472231182, 0.11289445284221854, 0.174613713153771, 0.09772242339594023, 0.11886007844337396, 0.1296041240649564, 0.11248936743608542], [0.01737609608764095, 0.05753512840185847, 0.03076735617859023, 0.03146782823439155, 0.06498422154358455, 0.01790692929976753, 0.04604916919821075, 0.04122084292716213, 0.058894111907907894, 0.006375152018985578, 0.06016063823231629, 0.03818396784897361, 0.04462891397997737, 0.04915285622701049, 0.042717087282133956, 0.03683420902650271, 0.042590116416769366, 0.04111947997340134, 0.019065040995233824, 0.02471274240607662, 0.05556625047964709, 0.07996853427695376, 0.04143510732267584, 0.02073531431545104, 0.07571780415517942, 0.03062704870743411, 0.2288760771708829, 11.068448219980512, 37.163339955466135, 24.50561203275408, 39.83434213910784, 12.927744473729815, 0.006251958473252931, 0.8774980966533933, 1.469097797359739, 1.6427095042807716, 4.751543411186763, 5.702801738466535, 8.734963468142919, 12.453841720308576, 4.40699657372066, 0.28178489953279495, 1.0175318739243915, 6.121744241033282, 20.77646173749651, 41.44855458395821, 50.12363065992083, 49.460782936641145, 47.98408923830305, 45.22246517453875, 42.37027481624058, 40.10355356761387, 40.23785529817854, 39.70575877598354, 38.99505533490862, 37.40374762671334, 37.603032384599956, 37.42719084875924, 35.710402148110525, 35.32259539195469, 34.44649703162057, 35.17261505126953, 35.121775082179475, 35.284171853746685, 33.906208583286826, 36.40950557163784, 37.4886337688991, 35.833482537950786, 35.99568823405674, 38.25584690911429, 44.12670646395002, 42.24009336744036, 41.194980076381135, 37.36993074417114, 34.8891042300633, 33.388112681252615, 33.61498178754534, 33.448336192539756, 33.56521531513759, 33.9300582749503, 33.37028360366821, 34.049747943878174, 33.977743761880056, 36.98680707386562, 36.09997374670846, 38.64542893001011, 41.03827387945992, 43.56966590881348, 46.98581722804478, 45.829279150281636, 41.1219927242824, 45.831061363220215, 45.14997809273856, 42.926089014325825, 45.96970224380493, 44.841801166534424, 45.11693593433925, 45.291724818093435, 42.21402720042637, 44.78725780759539, 41.034393310546875, 40.10541915893555, 35.23944629941668, 32.91306781768799, 31.0848890713283, 31.77963250023978, 31.917342322213308, 33.23158366339547, 33.909717423575266, 43.24842984335763, 44.32081133978707, 45.041673047201975, 44.12636252811977, 41.96443053654262, 38.72108786446707, 32.37564550127302, 30.74088028499058, 32.23196370261056, 35.67015470777239, 41.91944095066616, 43.06546640396118, 44.791954789842876, 44.79057557242257, 40.73809780393328, 42.71198374884469, 43.37794426509312, 39.956637382507324, 37.80202184404646, 32.6320618220738, 30.910173143659318, 31.950054441179546, 31.861638614109584, 35.741623878479004, 36.600428172520225, 38.81644146783011, 40.586734771728516, 44.34790931429182, 36.082325322287424, 16.519739934376307, 2.657381760222571, 1.1506860660655158, 1.5541813118117196, 1.1841759490115302, 5.690695805209024, 5.138372208390917, 4.476351755005973, 5.022391140460968, 2.0347384853022437, 0.03140030721468585, 0.0755115837923118, 7.087771832942963, 34.01931830814907, 27.96584619794573, 32.7956154687064, 15.201710087912423, 0.35324774629303385, 0.05210054466234786, 0.04308935194941504, 0.03037800599953958, 0.037882454028087, 0.06474906166217156, 0.016268852466185178, 0.03968842247767108, 0.030410039637769972, 0.026258552047823156, 0.05913056100585631, 0.06263274486575808, 0.018392214152429785, 0.01717557881160506, 0.06105685407029731, 0.03272302980933871, 0.0532750243188015, 0.04173306901273983, 0.053805631918034384, 0.0028623087980252293, 0.03307312334488545, 0.057706261718911786, 0.0650797321328095, 0.040916292662067075, 0.04741064632045371, 0.04896503434117351, 0.037130549017872126, 0.011552738075676774, 0.006414791610690632, 0.07530256786516734, 0.05500514612400106, 0.0839874768363578, 0.012835296486238284, 0.04278107652706759, 0.05503905591155801, 0.015936383877747824, 0.022386091628244946, 0.06941886179681335, 0.03477643283882311, 0.05772363900073937, 0.02154958517556744, 0.03877335354419691, 0.020527719919170653, 0.017946129964132394, 0.06963872071355581, 0.061851316796881814, 0.034456900520516295, 0.43456411574568066, 16.60135347502572, 40.09317990711757, 27.050942148481095, 45.839892523629324, 14.538774643625532, 0.028556312500898327, 0.29994578074131695, 0.3901360583092485, 0.8264186318431581, 5.158710019929068, 5.843314290046692, 5.928432762622833, 13.153840592929296, 9.389589735439845, 2.429787652833121, 1.73457923744406, 8.246314900262014, 22.78323003223964, 42.278044428144185, 50.49408081599644, 50.53434215273176, 49.37804378782, 46.96844325746809, 45.05221693856375, 41.67828982216971, 41.081436089106965, 40.263466358184814, 40.23405463354928, 40.38630356107439, 39.106476647513254, 39.178327969142366, 38.7501973424639, 36.536028793879915, 36.31488847732544, 36.49620519365583, 37.38099922452654, 36.45975841794695, 36.08093915666853, 37.95720638547625, 40.07692459651402, 36.923884187425884, 37.52925293786185, 40.63271795000349, 45.01195560182844, 42.68311398369925, 41.27376570020403, 38.91645383834839, 35.88395425251552, 35.73533575875418, 34.306626319885254, 36.686936719076975, 35.32018436704363, 35.47932938167027, 35.93035779680525, 35.60902098246983, 36.07625259671892, 38.492724895477295, 38.149219853537424, 40.239977972848074, 43.2672073500497, 46.39180530820574, 48.05539860044207, 47.62984575544085, 41.24014336722237, 45.29547337123326, 45.77087606702532, 43.86714955738613, 46.90772989818028, 46.74704933166504, 46.8838072504316, 46.70008298328945, 43.64860091890608, 45.389489446367534, 42.71895974023001, 40.48549257005964, 36.845140252794536, 34.95446246010916, 32.34961754935128, 32.96142380578177, 33.297456060137065, 34.84409032549177, 35.78577273232596, 43.46868079049246, 45.26604427610125, 47.12802948270525, 45.37758370808193, 43.94065107618059, 40.444901193891255, 34.04885857445853, 32.33591570172991, 32.90619257518223, 36.954042843409944, 44.47441169193813, 44.29426574707031, 45.36249916894095, 45.86440576825823, 43.1030387878418, 43.93130922317505, 45.656272479466026, 41.76313080106463, 38.09301587513515, 33.11851215362549, 31.583700248173304, 33.89968075071062, 33.52157020568848, 36.22806378773281, 38.729793957301546, 41.21071079799107, 41.80870056152344, 45.15716600418091, 38.0784524508885, 17.386769158499582, 3.7481353793825423, 1.9995371741907937, 3.4601260338510786, 5.081777828080313, 6.895100023065295, 6.434064030647278, 7.059970353330884, 6.1565603613853455, 0.37739268211381777, 0.007148410526237318, 0.020440234702878764, 7.8756745372499735, 37.63761356898716, 29.086917196001323, 37.74103403091431, 21.189936876296997, 0.8291550278663635, 0.06600106733718089, 0.029496565261589627, 0.06862469762563705, 0.06166322010436228, 0.06912257948092052, 0.08845489033098732, 0.04893849005124398, 0.041409496018396955, 0.0192555990735335, 0.018057007675192187, 0.03673885789300714, 0.023565473700208322, 0.020359673936452185, 0.07430400859032359, 0.024490357642727237, 0.014855738829023071, 0.03852064674720168, 0.05045736015641263, 0.06643074285238981, 0.07124840255294528, 0.0945738987731082, 0.1343582525317158, 0.14832647943070956, 0.13436787415828022, 0.17344885851655686, 0.10184047278016806, 0.13400704280606338, 0.11261460464447737, 0.2248335148074797, 0.18321510803486618, 0.13303958757647447, 0.09563512075692415, 0.09408529249152967, 0.13778025390846388, 0.09789447952061892, 0.18841888808778354, 0.15838586964777537, 0.15627603286078998, 0.17825682195169584, 0.17741542495787144, 0.11201800951468092, 0.16989132655518396, 0.13887234245027813, 0.1610779437635626, 0.18468527628907136, 0.1773144318056958, 0.38629704288073946, 17.808745418276104, 47.67441497530256, 33.34573214394705, 48.786352566310335, 19.830971717834473, 0.07759573802884136, 2.8827257369245802, 5.385380234037127, 4.408181241580418, 11.878136566707067, 15.171362093516759, 20.720518316541398, 17.591511726379395, 10.046848501477923, 2.6176756279809132, 1.8143787554332187, 7.795107569013323, 23.01323798724583, 43.48635005950928, 52.457176208496094, 52.71041372844151, 51.90336309160505, 48.70397124971662, 47.16519539696829, 44.03029326030186, 42.96347727094378, 42.58735391071865, 43.08932304382324, 42.500511850629536, 40.5462441444397, 40.8428384235927, 39.51115362984793, 38.16375548498971, 38.80487271717617, 38.30881650107247, 38.988225255693706, 39.0198951448713, 37.88595608302525, 40.29713038035801, 41.42515652520316, 39.38764245169503, 38.61282798222133, 42.76897634778704, 48.71033927372524, 46.27834469931466, 44.84370149884905, 40.76880189350673, 38.03311892918178, 37.8709306035723, 36.96942615509033, 37.62192106246948, 36.44394431795393, 37.948361328669954, 38.18555893216814, 38.72417981284005, 38.44411877223423, 40.717402594430105, 40.70101874215262, 42.52323940822056, 44.157476561410085, 46.48439005443028, 50.35591241291591, 49.15610095432827, 44.245610986437114, 47.53066716875349, 48.150880745479036, 44.779444558279856, 49.669503348214285, 48.23198706763131, 47.93142189298357, 48.950277941567556, 45.676390988486155, 47.61617170061384, 44.89225551060268, 42.728635106767925, 39.27097872325352, 36.66221155439104, 34.18806225912911, 33.438302993774414, 34.536219120025635, 36.10102639879499, 36.52301481791905, 45.34750148228237, 45.85767991202218, 46.714486598968506, 46.096805640629356, 45.440162658691406, 43.28729459217617, 36.465112004961284, 33.33721365247454, 35.53629418781826, 38.600352491651265, 46.18123320170811, 47.135561329977854, 46.54620817729405, 47.04284109388079, 43.375057288578574, 44.765423093523296, 49.34846878051758, 44.16446644919259, 41.1620317186628, 36.070235456739155, 33.21556806564331, 34.94098990304129, 34.269092151096885, 39.286212648664204, 40.49329192297799, 42.09449734006609, 43.87320143835885, 46.67945725577218, 38.93823296683175, 18.225795405251638, 4.191119951861245, 3.774339641843523, 5.843781556401934, 6.587387757641928, 11.318177768162318, 13.369151370865957, 10.669592091015407, 11.056884680475507, 5.527339313711439, 0.13612517129097665, 0.1500974151172808, 11.093592013631548, 46.11634744916643, 36.35301671709333, 40.20863117490496, 25.941773414611816, 1.0351023482424873, 0.2254275315042053, 0.14169602521828242, 0.2205918159868036, 0.17114116091813358, 0.2345984343971525, 0.17631471902132034, 0.14618766919842788, 0.08099656232765742, 0.10042062468294587, 0.20502205645399435, 0.09227745128529412, 0.12792921465422424, 0.11743852043790476, 0.18568348272570542, 0.08712500919188772, 0.11854479036160878, 0.12397619177188192, 0.21687292839799607, 0.1793234111475093, 0.17672627765153134], [0.05301092491884317, 0.02821932147656168, 0.049924744093524556, 0.02320734122102814, 0.052725923247635365, 0.03569656703621149, 0.03196076356938907, 0.045780638964580636, 0.03026796119021518, 0.0721279942829694, 0.009963280820686902, 0.027336523668574433, 0.024966290586494973, 0.028821080257850032, 0.049131431483796666, 0.010393836735082524, 0.03158532675089581, 0.018838067638820837, 0.06439230830541678, 0.03904365814690079, 0.044839626244668446, 0.04676305249865566, 0.014716267652277435, 0.02315378954101886, 0.021038098693160073, 0.03917237963261349, 0.03899381974978106, 2.169113823345729, 32.4044839995248, 27.567297526768275, 34.28215823854719, 32.69624580655779, 1.402819799525397, 0.13840538822114468, 0.09350148096148457, 0.46679110931498663, 3.3442298642226627, 2.8804632297583987, 2.9358067171914235, 7.2416965791157315, 9.226574574198041, 1.436126423733575, 0.7299401802676064, 1.5702453298228127, 9.667835559163775, 30.744031293051584, 51.591124943324495, 49.86320522853306, 48.82805218015398, 47.82494074957711, 45.28599255425589, 42.12640346799578, 37.65858323233468, 37.1976432119097, 36.61347688947405, 36.77947282791138, 33.73594645091465, 34.05074501037598, 34.70977469852993, 38.56178304127285, 39.50779070172991, 42.62856020246233, 43.52311992645264, 43.11493410382952, 38.176463740212576, 34.274813992636545, 37.0888101032802, 34.02260480608259, 36.24338803972517, 39.78647599901472, 45.39833797727312, 43.944847788129536, 42.77370112282889, 39.969046865190776, 35.67619616644723, 34.56920221873692, 33.694024494716096, 32.85019356863839, 33.1927501814706, 34.91542748042515, 34.47791331154959, 34.77403163909912, 35.62445987973894, 36.304156984601704, 37.27981260844639, 39.87973124640328, 44.04198360443115, 44.79283373696463, 46.490296023232595, 47.31843791689192, 40.001957007816856, 44.11353267942156, 46.62016827719552, 44.977853843144004, 44.82180772508894, 45.24757249014718, 44.74735082898821, 43.74137674059187, 42.848644392830984, 43.40277712685721, 43.08723163604736, 38.043273721422466, 36.8574663570949, 33.09912667955671, 31.1842656816755, 31.426122052328928, 32.15805918829781, 33.429186957223074, 33.02238382611956, 41.95628377369472, 44.42568397521973, 43.284470149448936, 43.78947217123849, 44.13005896977016, 40.767002310071675, 38.61839001519339, 32.54956933430263, 31.013864585331508, 32.006383487156455, 35.879007135118755, 42.35483244487217, 43.2665160042899, 41.8839738709586, 45.28537763868059, 42.06757654462542, 41.652466842106406, 40.97757094247, 41.425705432891846, 40.80505411965506, 34.48461137499128, 31.230936731610978, 33.86661774771554, 35.72368710381644, 38.73412963322231, 39.28422198976789, 41.76696968078613, 42.681026050022666, 31.976867539542063, 9.370637655258179, 0.9082267763359206, 0.9231148660182953, 1.668229803442955, 4.048521203654153, 4.861355347292764, 6.021732304777418, 7.23487605367388, 6.012469921793256, 0.9131684111697334, 0.07313594448247127, 0.5379153128181184, 22.887802158083232, 53.26110710416521, 26.74792425973075, 29.083265917641775, 7.059701110635485, 0.12699013575911522, 0.042828485768820555, 0.022737852663600018, 0.039531402689005644, 0.022903077636978457, 0.017929365060159137, 0.01623813179321587, 0.04464902236525502, 0.07534227573445865, 0.05458305663030062, 0.051087417240653715, 0.012317220580631068, 0.059792587267501016, 0.03179947579545634, 0.01671635139999645, 0.04691713083801525, 0.00830291411174195, 0.032284831894295554, 0.021089421385633092, 0.024432076573637978, 0.03614364018929856, 0.025065132782661488, 0.03683103008994034, 0.0545647938602737, 0.02189912909774908, 0.03163619991391897, 0.050193084337349446, 0.049740789857293875, 0.05731870287231036, 0.0749622689826148, 0.09118978000645127, 0.045338390195476155, 0.04536026616447738, 0.027345102047547698, 0.02696409954556397, 0.03357204675142254, 0.028946629592350552, 0.007994315537091876, 0.0591690203707133, 0.019670465561960424, 0.043471017719379494, 0.041461095213890076, 0.00932856389720525, 0.026846275332250764, 0.04736992743398462, 0.015158926935068198, 0.030542479495384862, 0.0440837925166956, 3.6311965457030704, 40.75669118336269, 28.47418509210859, 37.76782281058175, 35.80889981133597, 0.9857319231544222, 0.08046374948961393, 0.1901644737060581, 0.2511783018708229, 2.630144170352391, 5.488259170736585, 8.098880205835615, 10.516129834311348, 8.385383095060076, 4.102383639131274, 1.3291351305586951, 2.727146885224751, 11.193105850900922, 33.09480142593384, 52.31508207321167, 51.31679269245693, 49.05435153416225, 48.68827179500035, 45.17124652862549, 43.26012713568551, 41.395178522382466, 38.72811944144112, 38.05225774220058, 39.104899406433105, 35.379775592258994, 35.49796792439052, 36.56966849735805, 38.79249102728707, 39.32666853496006, 42.726713929857524, 42.7882193837847, 43.34969983782087, 38.623323236192974, 35.795948369162424, 37.052992139543804, 36.77090917314802, 36.785010542188374, 42.545779364449636, 46.22329412187849, 46.94592067173549, 45.44751385280064, 39.85571827207293, 37.296595982142854, 36.10093607221331, 35.933296884809224, 34.41276352746146, 35.22048119136265, 36.1232328414917, 35.71660688945225, 36.72974109649658, 36.08603913443429, 38.03575924464634, 39.59213835852486, 41.50322995867048, 44.47411986759731, 45.67672797611782, 48.5817037991115, 47.827810355595176, 41.15486812591553, 45.138367652893066, 47.03961018153599, 45.67848934446062, 45.97722019468035, 47.26685449055263, 45.966464383261545, 45.92191253389631, 45.82640607016427, 45.00871079308646, 45.51179163796561, 41.01207569667271, 38.703578404017854, 34.81145463671003, 32.926853043692454, 34.081529004233225, 33.33158213751656, 33.934404373168945, 34.41129745755877, 42.93439905984061, 46.35966641562325, 43.54369354248047, 45.995876107897075, 46.629326002938406, 42.478840419224326, 39.736435072762625, 32.6134614944458, 33.72564574650356, 32.90519550868443, 37.742927415030344, 44.27792010988508, 44.08548280170986, 43.97099733352661, 44.11476598467146, 43.519173349652974, 43.76274592535836, 42.64088978086199, 43.3484456879752, 41.49595519474575, 34.26595503943307, 33.03504344395229, 35.95547553471157, 36.96279409953526, 39.747472286224365, 39.59151649475098, 43.39739922114781, 44.15997443880354, 32.90794699532645, 10.999000975063868, 1.5268389561346598, 2.4536052090781073, 3.1326289900711606, 3.8462113738059998, 9.562050972666059, 7.733020203454154, 6.233302780560084, 3.6688955170767645, 0.47473680866616114, 0.04601236206612416, 0.24800099379249982, 22.94542530604771, 49.31444692611694, 29.479295866830007, 34.92111458097185, 10.211286306381226, 0.09118661803326436, 0.006519431040422725, 0.010636624198273888, 0.10979681156043496, 0.017693392633061324, 0.032636706584266255, 0.09017849820000784, 0.0385619525664619, 0.010025087727366813, 0.0274114950027849, 0.009176557634158857, 0.05322945051427398, 0.005382809821250183, 0.011991034378297627, 0.07316858880221844, 0.020170627294906547, 0.0345148304477334, 0.01376618376733469, 0.032296977671129365, 0.046083007739590745, 0.04765930226338761, 0.2588850754712309, 0.13649916622255528, 0.13308572795774254, 0.1180822058979954, 0.11985888199082442, 0.18905652101550782, 0.12110388518444129, 0.17903364955314569, 0.12660045309790544, 0.22855469584465027, 0.11349711407508169, 0.16978829779795238, 0.13466444824423107, 0.08115934966398136, 0.2181003303932292, 0.09093128530574696, 0.09139743207820825, 0.21658651876662458, 0.18098394918654645, 0.08725220736648355, 0.08955992532095738, 0.10263786677803312, 0.1450166670339448, 0.15666279782141956, 0.06655573578817503, 0.09274005610495806, 0.21421167334275587, 4.567552941186087, 45.761207648685996, 36.81671864645821, 42.83329234804426, 42.81287159238543, 2.7267419355256215, 0.5995144045778683, 0.2867790258356503, 1.0013116300106049, 9.627234629222325, 9.731819782938276, 9.658501522881643, 14.818310226712908, 16.624237367085048, 4.012832650116511, 1.582513677222388, 2.640736047710691, 11.518755759511675, 34.672744274139404, 53.626763003213064, 52.268609046936035, 52.191706384931294, 51.997941970825195, 48.418223108564106, 45.52359315327236, 42.44907086236136, 40.7989501271929, 40.41761909212385, 41.35709197180611, 37.8997552054269, 36.94297783715384, 37.47822189331055, 42.98340470450265, 42.37343277250017, 45.516085624694824, 46.08285018375942, 46.80750560760498, 42.869224957057405, 37.78931706292288, 40.52585812977382, 37.592297417776926, 39.495857170649934, 43.90128605706351, 48.98502935682024, 47.75672333581107, 47.16298586981637, 43.722269194466726, 39.06592696053641, 38.411705425807405, 37.37000370025635, 36.36570412772042, 36.094905035836355, 39.66990954535348, 37.946210861206055, 38.3046475819179, 38.80176339830671, 40.54879413332258, 41.941862787519185, 42.40170151846749, 46.08565378189087, 48.01009634562901, 50.40785019738333, 50.849165030888145, 42.88889183316912, 45.59807784216744, 49.81479712894985, 48.45617069516863, 47.77200242451259, 47.7570811680385, 48.99308231898716, 47.35792800358364, 47.45140559332711, 45.421749932425364, 48.57635368619646, 42.28844935553414, 39.51157399586269, 36.14728055681501, 34.66572659356253, 34.95915944235665, 34.66338505063738, 36.763502393450054, 36.30156530652727, 45.144169398716514, 47.20647464479719, 45.1218170438494, 46.120078631809776, 47.74761424745832, 44.358140536717, 42.85288626807076, 34.733732087271555, 34.86268023082188, 34.690066133226665, 38.55471324920654, 45.890134947640554, 45.784730775015696, 45.9937812260219, 45.84015308107649, 45.43342638015747, 44.58287307194301, 44.708611147744314, 44.60718134471348, 44.39409051622663, 38.79058027267456, 34.38891383579799, 38.52638891765049, 39.66894721984863, 42.8644619669233, 42.19377667563302, 44.83293873923165, 45.31264584405081, 34.47154876164028, 11.164199607712881, 1.8606715628079005, 4.181839329855783, 5.528434089251927, 9.2572534765516, 11.862193925040108, 13.713719487190247, 14.931635345731463, 13.842696292059761, 2.811967670917511, 0.24264319986104965, 0.737795173057488, 31.645011152539933, 59.91933304922921, 31.477323327745708, 40.22198908669608, 13.049176403454371, 0.10335877630859613, 0.10696620773524046, 0.1286604039903198, 0.25718328250305994, 0.07254343413348709, 0.16074011474847794, 0.20711412919419153, 0.09882232187581913, 0.16932678541966847, 0.11064797267317772, 0.12077358790806361, 0.09287471816475902, 0.2187725007534027, 0.11896289006939956, 0.10526987018861941, 0.09447622365717377, 0.07730832416564226, 0.15808075959128992, 0.09586037402706486, 0.10185813504670348, 0.07663690019398928], [0.024735486899901713, 0.03790843174127596, 0.017041045673457638, 0.01979772650104548, 0.05691330194739359, 0.04808018396475485, 0.020705136470496655, 0.007758426230533847, 0.038486194131629806, 0.04566989865686212, 0.03487408081335681, 0.025244025147653053, 0.029932015109807253, 0.031122962811163495, 0.06915343925356865, 0.05590805570994105, 0.04102979799998658, 0.017401520794789706, 0.026220574442829405, 0.0196232870221138, 0.025656974774652293, 0.03804829816466995, 0.07588265423796006, 0.06166805127369506, 0.05244332019771848, 0.016127279527219276, 0.06235496619982379, 0.1236931069621018, 18.68940700803484, 34.251822403499055, 20.31432488986424, 39.19699083055769, 12.611006498336792, 0.03151450805099947, 0.08169045937912804, 0.18985971648778233, 2.4379305073193143, 2.8908171313149587, 6.831422822816031, 6.5906382117952615, 7.637093373707362, 6.267224320343562, 0.7246149831584522, 0.49151090000356945, 3.350894055196217, 19.47287198475429, 42.60017681121826, 50.30380092348371, 49.08783490317208, 49.359794344220845, 46.025847162519185, 43.52973461151123, 40.963466099330354, 39.44150488717215, 37.25283970151629, 35.784139905657085, 37.97655017035348, 41.48976782390049, 43.89523417609078, 45.788427216666086, 48.14996010916573, 48.72695241655622, 47.87755250930786, 48.841639382498606, 46.68507487433297, 36.98262425831386, 33.93848991394043, 35.03758723395211, 35.16390201023647, 40.98422384262085, 47.75159556525094, 46.24198477608817, 45.17637429918562, 42.85424811499459, 36.068835394723074, 34.72354602813721, 33.887858390808105, 32.07230799538748, 35.13698468889509, 34.045332363673616, 36.40076126371111, 34.42104230608259, 36.208827699933735, 36.41355984551566, 37.74342768532889, 38.731235708509175, 41.57029397147042, 46.3983713558742, 47.600739751543315, 46.85018491744995, 40.945828097207205, 44.436290400368826, 45.23744896480015, 45.06341743469238, 48.41125406537737, 44.980094637189595, 45.533716678619385, 43.098088196345735, 45.03347764696394, 43.73331683022635, 43.89235067367554, 38.646811621529714, 36.716272013528005, 33.87128693716866, 31.764242240360804, 31.652358872549875, 30.854837690080913, 32.45771414893014, 31.965027809143066, 38.6851761000497, 44.902035100119456, 44.402751445770264, 43.63342605318342, 45.39886951446533, 44.54636376244681, 42.06678097588675, 40.802253995622905, 34.00726318359375, 32.15868105207171, 31.175938265664236, 35.88163008008684, 40.203190735408235, 42.68266582489014, 42.55321046284267, 42.036198479788645, 42.2160769190107, 42.31041261128017, 42.24787187576294, 41.38206727164132, 39.784603459494456, 34.93574401310512, 34.26930407115391, 38.835861682891846, 41.53064407621111, 40.4819872038705, 40.75220612117222, 40.61387096132551, 23.280696732657297, 4.1192529967853, 0.5349288359284401, 2.7801416644028256, 2.342535214764731, 3.8943406769207547, 7.848222204617091, 4.368632095200675, 4.356569153921945, 2.9737634233066013, 0.07482445852032729, 0.08544332800166947, 4.223376095294952, 38.932160241263254, 28.527116468974523, 25.47993881361825, 24.812138761792863, 0.907161856336253, 0.04326273121738008, 0.06018207315355539, 0.007073972266100879, 0.04854299234492438, 0.027997352315911224, 0.05784805518175874, 0.0828429443229522, 0.05508220734606896, 0.030601942911744118, 0.015483722988782185, 0.0528260580530124, 0.03354371791439397, 0.047518835336502106, 0.07441944096769605, 0.044365432046886, 0.01879368635958859, 0.023319077278886522, 0.01398587813933513, 0.07312581395464283, 0.052054696051137786, 0.03790049288155777, 0.024378216160195212, 0.008347461632053767, 0.05474451403798802, 0.013156914451558675, 0.06727155630609818, 0.05875353302274432, 0.047647767168070586, 0.06489322999758379, 0.025105729532827224, 0.0326539040543139, 0.00823116921154516, 0.04077372227662376, 0.09115176168935639, 0.006132198738799031, 0.055050021037459373, 0.008810646599158645, 0.03383260080590844, 0.040646771767309735, 0.03394815531958427, 0.014497769198247364, 0.02549622643605939, 0.04683962517551013, 0.04765173659792968, 0.05694481650633471, 0.009387460736823934, 0.007002943220348763, 0.015256970156250256, 0.3674435131251812, 23.806199414389475, 38.32767391204834, 23.85839949335371, 48.43784482138497, 10.869128721100942, 0.06287630501070193, 0.07213650311210326, 0.2521832665162427, 0.5093993629728044, 4.311500532286508, 8.68972201006753, 5.950104194028037, 6.150900619370597, 5.461671454565866, 2.4799855649471283, 1.4598032789570945, 4.147187794957842, 21.08574342727661, 45.298474993024556, 50.978008951459614, 49.71656697137015, 49.7359732900347, 48.53406694957188, 45.35776744570051, 41.906781332833425, 39.64011219569615, 38.26107890265328, 37.65091242109026, 39.54087802342006, 40.73353631155831, 45.06060341426304, 46.99282448632376, 48.77093798773629, 49.45188924244472, 48.889015674591064, 50.00506659916469, 47.61391701017107, 37.846566745213096, 35.50939423697335, 36.92465196337019, 36.297184467315674, 43.45623656681606, 49.03703314917428, 48.72058091844831, 46.643559387751985, 44.137257303510395, 36.69288437707083, 35.80068356650216, 36.93044328689575, 34.39069952283587, 35.9144047328404, 36.66108594621931, 38.539701666150776, 36.196588448115754, 37.60388701302664, 38.854528018406455, 39.56532873426165, 39.699974400656565, 43.62013067517962, 48.27332884924752, 47.92916372844151, 47.58302879333496, 42.159501211983816, 46.12840952192034, 46.74964100973946, 45.6095632144383, 49.20670468466622, 47.60083702632359, 47.656631061008994, 45.90261738640921, 46.52808380126953, 45.90515347889492, 45.14723355429513, 40.775715351104736, 38.98561273302351, 34.65825380597796, 33.76397548403059, 33.34856353487287, 33.02424941744123, 34.20216710226876, 33.26954167229788, 40.40754073006766, 46.5633076940264, 44.982529980795725, 44.07832268306187, 45.08230611256191, 46.472407885960166, 42.781559535435264, 40.95083774839129, 34.63245167051043, 33.13613278525216, 32.99682487760271, 39.21185302734375, 42.86756433759417, 44.02332421711513, 44.70396280288696, 43.76719624655587, 44.019655568259104, 43.61486741474697, 43.8883033479963, 43.835288592747276, 41.2487348147801, 37.113517897469656, 36.63009350640433, 39.30267293112618, 42.94306346348354, 41.21457747050694, 42.26733725411551, 41.08845376968384, 25.119528804506572, 5.638282069138118, 1.1881886422634125, 3.989058954375131, 3.4738925865718295, 5.805190827165331, 9.518686396735054, 7.4004116739545545, 3.9349941526140486, 1.2513208431856973, 0.08502782029764992, 0.03365377290174365, 3.6369329350335255, 44.84350347518921, 39.51528780800955, 27.94960825783866, 30.448475769587926, 1.6326443872281482, 0.04960771896211164, 0.015027659246698022, 0.022906984302348325, 0.011743830500303634, 0.010941451814557825, 0.021974795930353657, 0.028585384333772317, 0.06579932530543633, 0.04404651719544615, 0.013664054069002824, 0.021134627084912996, 0.007568968227133155, 0.04864925771419491, 0.04982629544766886, 0.01659230332422469, 0.019175140087359717, 0.02051226967679603, 0.04984431055241397, 0.019419807940721512, 0.03758001061422484, 0.025008023882816945, 0.10255918385727064, 0.09960448276251554, 0.1117559592904789, 0.09340546825634581, 0.1493200311171157, 0.17920130198555334, 0.09959363298756735, 0.15026604464011534, 0.14760643163962023, 0.16644103026815824, 0.12881306079881533, 0.1348859356450183, 0.1976521619196449, 0.09437212281461273, 0.1261855425047023, 0.14669291994401387, 0.11638808037553515, 0.08605677794132914, 0.09682193278734173, 0.13103001112384455, 0.20641784369945526, 0.1538773708577667, 0.17856265125530107, 0.10517130619181053, 0.12629972637764045, 0.08524664105581385, 0.1460019134517227, 0.4367498398891517, 26.28361783708845, 45.68954045431954, 28.011141504560197, 49.646237305232454, 16.94044988495963, 0.16824817258332456, 0.45162582450679367, 1.2637064414364951, 5.844280523913247, 10.242635709898812, 16.508532490049088, 12.595084701265607, 15.495186362947736, 14.759707382747106, 2.6901868113449643, 1.6855743527412415, 4.918167727334159, 22.296119621821813, 46.18186896187918, 52.56704807281494, 52.33349479947771, 52.36891324179513, 49.9265901701791, 47.402865477970664, 43.38677542550223, 42.89066014971052, 41.3461138180324, 38.81626776286534, 41.26352058138166, 45.30864020756313, 48.103177888052805, 49.53933579581124, 53.15227746963501, 52.038255419049946, 50.85992431640625, 51.568974086216514, 51.79216412135533, 40.77846336364746, 36.9479284286499, 39.26763663973127, 37.927603585379465, 45.1315028326852, 50.62816367830549, 50.29448686327253, 48.280468123299734, 46.804413659232004, 40.07484013693673, 37.63950000490461, 38.33972208840506, 35.15887498855591, 38.11455529076712, 37.91500302723476, 40.12460313524519, 37.53945289339338, 40.15101671218872, 41.193111010960166, 40.60453953061785, 42.44941479819161, 44.42961318152291, 51.03499460220337, 50.30617373330252, 49.57030739103045, 43.851780142102925, 47.75494112287249, 48.80896895272391, 47.14676877430507, 50.9159893308367, 48.1087121282305, 49.47748293195452, 46.74602099827358, 49.59404591151646, 47.76920230048043, 47.782122475760325, 42.203934941973, 40.463637011391775, 37.720595904758994, 34.85243163790022, 33.91319152287075, 34.10080678122384, 35.57465171813965, 35.07139369419643, 42.46221685409546, 48.168775830950054, 46.75787115097046, 45.54694257463728, 46.59983784811837, 48.59541259493147, 44.33948809759957, 43.50879274095808, 38.11409323556082, 35.78900711877005, 33.91250017711094, 40.793791089739116, 43.60668591090611, 45.43274893079485, 46.62047399793352, 45.03938708986555, 45.15663794108799, 44.426451751164024, 44.828373772757395, 45.457053729466026, 43.28236484527588, 39.103117193494526, 38.55508150373186, 42.524590832846506, 45.69166660308838, 44.079767908368794, 43.800683089665, 42.1592823437282, 25.59229987008231, 5.416315785476139, 1.8491540551185608, 6.77485145841326, 6.2912920117378235, 11.106931686401367, 14.38043909413474, 8.433048605918884, 12.709860256740026, 8.351625272205897, 0.5365104196327073, 0.16093549212174757, 6.418851818357195, 49.27739218303135, 35.30113935470581, 32.82063940593174, 36.27142054694039, 1.9563951577459062, 0.20535350723990373, 0.14892361738852092, 0.14120857923158578, 0.12533783513520444, 0.1121284207329154, 0.1847875722284828, 0.15017256965594633, 0.1337964255362749, 0.1170647426375321, 0.0944947815899338, 0.10018792109830038, 0.11759013230247156, 0.09770719707012177, 0.19332044864339487, 0.07071724534034729, 0.08392034936696291, 0.10379065706261567, 0.16077695919999055, 0.07848493102937937, 0.08018667650009904, 0.1608518287539482], [0.10849209728517703, 0.0489719689690641, 0.02519222578432943, 0.03316490199150784, 0.04776496373649154, 0.05015256901138595, 0.0918391380192978, 0.04431463691538998, 0.058674110498811514, 0.03695342762927924, 0.02235979669993477, 0.07026755982743842, 0.09663270972669125, 0.004018306008739663, 0.026771281945652196, 0.10120968627078192, 0.013830268855339714, 0.07707953572805439, 0.02455888289426054, 0.019553538711209382, 0.03283391260941114, 0.04331953477646623, 0.014001467481388577, 0.028201584571174214, 0.014597897218274218, 0.033501479109483104, 0.07270919345319271, 0.10058996666754995, 3.008433631488255, 29.671997206551687, 24.349114281790598, 30.128535543169292, 34.077068260737825, 0.8368259476763862, 0.03992505817274962, 0.1402730287185737, 0.1421945584671838, 3.412848319326128, 5.2252272963523865, 4.560146161488124, 4.071909274373736, 3.2184514020170485, 2.195895654814584, 1.1921357618910926, 0.5599006073815482, 5.838292479515076, 30.33563702447074, 51.10256583350045, 51.19549104145595, 49.450013228825156, 49.3668224470956, 44.101283005305696, 42.15833044052124, 38.29775496891567, 39.25575174604143, 42.60469314030239, 45.639106954847065, 47.066437176295686, 48.18287025179182, 47.454754625047954, 49.02289009094238, 48.54546546936035, 48.763388769967214, 48.2161625453404, 46.166419642312185, 39.77353845323835, 35.278950282505576, 35.023718629564556, 35.49511916296822, 42.55260944366455, 46.76979773385184, 48.981447560446604, 48.86075040272304, 43.47152260371617, 38.38877984455654, 34.309002603803364, 35.4367230279105, 33.41203532900129, 33.628381388528005, 32.74123886653355, 33.63490922110421, 33.7530494417463, 36.41434151785714, 38.52237980706351, 37.76837171827044, 39.458514077322825, 42.02710328783308, 44.7066239629473, 46.7033451625279, 46.42602866036551, 40.78562348229544, 44.87660469327654, 49.16407748631069, 47.546637603214805, 40.780558245522634, 44.06971386500767, 42.50698062351772, 45.142234325408936, 43.4499762398856, 45.84562826156616, 43.31205102375576, 38.75090953281948, 35.603837626320974, 33.8355210849217, 31.445455414908274, 33.394536290849956, 33.25923401968819, 33.48290695462908, 32.83995539801461, 37.787750244140625, 43.60135316848755, 44.98503828048706, 45.21054206575666, 43.49427795410156, 45.081468854631694, 43.80010986328125, 44.68731491906302, 42.33875778743199, 39.10225214276995, 33.5861154964992, 31.16763516834804, 34.041688033512656, 37.24915715626308, 42.896562644413535, 43.94913830075945, 44.5741982460022, 44.93409756251744, 44.30435800552368, 43.99009793145316, 41.82053681782314, 38.62846490315029, 37.41157477242606, 40.90086283002581, 39.60706308909825, 40.792314597538535, 42.29493202481951, 35.74373960494995, 12.550244501658849, 0.8022269042474883, 0.8281962850264141, 2.609195351600647, 2.006627376590456, 2.6594253991331374, 9.035367965698242, 8.888965078762599, 2.0848059015614644, 0.45475541800260544, 0.05632476781361869, 0.23808108323386737, 13.597229463713509, 37.627653326307026, 15.103903770446777, 31.067035675048828, 10.171028443745204, 0.04489190736785531, 0.01779037225060165, 0.05473763030022383, 0.03575934509613684, 0.01845643749194486, 0.06579536944627762, 0.05069344284545098, 0.0329711870290339, 0.020124279960457767, 0.06995233281382493, 0.03093667102179357, 0.061576442260827334, 0.014740145299583673, 0.06752815110875027, 0.016581502743065357, 0.033998224418610334, 0.04539964494428464, 0.03895244946969407, 0.032298490804220946, 0.011098607310226985, 0.01353517482389829, 0.03759882299761687, 0.012985121259199721, 0.006875725113786757, 0.031696989866239686, 0.06518533932311193, 0.07048230937549047, 0.033139640132763555, 0.036808607900249105, 0.03595527886812176, 0.08192970404135329, 0.04375363094732165, 0.04844555471624647, 0.04136606977720346, 0.07324670853891543, 0.03773793285446508, 0.032695559319108725, 0.04718658048659563, 0.033373035823128054, 0.030707502604595253, 0.033318763199661455, 0.02116547159052321, 0.023601074736299257, 0.06091798509338072, 0.0383257986312466, 0.012284596616934453, 0.05196907850248473, 0.024569664815706865, 0.0023858597435589346, 0.09260919384126153, 5.135950326919556, 36.79425164631435, 25.22534986904689, 37.22872250420706, 36.45751414980207, 0.5470428030405725, 0.026028303063607643, 0.10541889683476516, 0.0879028138837644, 2.3511970128331865, 6.854589853967939, 4.75009731735502, 5.852491991860526, 4.356917432376316, 2.849973882947649, 2.0442114855561937, 1.2546710691281726, 7.833607537405832, 33.17779418400356, 50.0473290170942, 51.120450496673584, 51.08949627195086, 49.964548179081504, 45.31148549488613, 42.94802795137678, 40.02766534260341, 39.20370626449585, 43.429392201559885, 46.76213387080601, 48.08107219423567, 49.36834062848772, 49.75149209158761, 49.964034012385774, 51.06774146216256, 51.52638162885393, 49.780962875911165, 46.809944425310405, 41.90800421578543, 35.84551681791033, 37.44885880606515, 36.452730315072195, 44.791586535317556, 49.510347911289756, 50.51070785522461, 50.984602791922434, 44.89967271259853, 40.85386174065726, 35.69322967529297, 35.40422977719988, 35.511714935302734, 35.05956786019461, 35.146833760397776, 35.73814977918352, 35.48327943256923, 37.848599093300955, 40.41584382738386, 39.74064915520804, 41.73957640784127, 43.50628096716744, 46.0501971244812, 48.48226465497698, 48.759324073791504, 41.63622890199934, 45.128751346043174, 50.993100438799175, 47.308522837502615, 43.67408691133772, 46.2823086466108, 45.82084403719221, 47.252485615866526, 44.982220785958425, 46.25749315534319, 44.77409097126552, 40.01411288125174, 36.85053900309971, 34.91811990737915, 33.57076345171247, 34.91072007587978, 33.58332926886422, 35.10906335285732, 33.35981961659023, 39.769862856183735, 45.16890845979963, 46.53780780519758, 45.76752356120518, 45.339841093335835, 46.78072725023542, 45.65927757535662, 47.149857248578755, 44.440817151750835, 39.4627559525626, 34.48327037266323, 33.426400729588096, 35.077372619083945, 39.32758569717407, 44.52049214499337, 44.2719099181039, 45.462379523685996, 45.08823292595999, 43.205020972660606, 43.90721981866019, 42.74657882962908, 40.887793268476216, 38.18910598754883, 42.4297513961792, 41.92288725716727, 43.064174039023264, 42.8503223827907, 37.49134356634957, 13.998715485845294, 1.6643894038030078, 1.5627194536583764, 3.6177092237131934, 3.319444988455091, 4.103777621473585, 9.51293763092586, 6.410961270332336, 2.073170925889696, 0.3105688707104751, 0.0379716678123389, 0.13231731419052395, 14.454317552702767, 45.635546003069194, 18.637542179652623, 32.58258022580828, 15.128251995359149, 0.040604081736611466, 0.03116069614355053, 0.021992805946086134, 0.009310148456799132, 0.059704398071127276, 0.035176130676908154, 0.016107808964859163, 0.03703866859099694, 0.06522634319428887, 0.07912618054875306, 0.03446964340816651, 0.018453752189608555, 0.07547808451844112, 0.04186303221753665, 0.01861656836367079, 0.06603044111813818, 0.06206675845065287, 0.001748890825963047, 0.06564782200647251, 0.02137854346074164, 0.10006975422480277, 0.03811792264293347, 0.15578256148312772, 0.09957374512617077, 0.09162465309990303, 0.17926516570150852, 0.16639072368187563, 0.08103033980088574, 0.15016327372619084, 0.1476313610162054, 0.2002192905970982, 0.2445822629545416, 0.09190266246774367, 0.11249622063977377, 0.19022484975201742, 0.06877846044621297, 0.0857586907222867, 0.2466028316744736, 0.1109723938362939, 0.16293461913509028, 0.10729166705693517, 0.07670665359390633, 0.10276361967303924, 0.11008282085614544, 0.08489227614232472, 0.1507575482662235, 0.12176956874983651, 0.154741213790008, 0.11265970008181674, 0.14595924716975006, 6.442901270730155, 44.3729818889073, 32.630519321986604, 37.787972586495535, 42.418179171425955, 1.7678107342549731, 0.2028696755213397, 0.45603182379688534, 0.8211671507784298, 9.429241367748805, 12.591666187558856, 11.207703147615705, 12.316342949867249, 9.095787763595581, 5.313294844967978, 2.9142162757260457, 1.3274467183010918, 7.648606538772583, 34.5343257359096, 52.91287728718349, 53.9057366507394, 53.71384825025286, 52.81896890912737, 47.74050971439907, 45.99775559561593, 42.093385628291536, 42.3596579687936, 47.31971985953194, 49.931853430611746, 51.07201113019671, 52.091746125902446, 51.569328444344656, 53.01057938167027, 52.92194816044399, 52.51244912828718, 52.014235496520996, 49.75386490140642, 44.56567628043038, 38.44119358062744, 38.31343010493687, 38.4382266998291, 46.534045355660574, 51.215171813964844, 52.75056389399937, 51.85286705834525, 46.782957621983115, 43.088364192417686, 37.396274839128765, 38.75393894740513, 36.45851469039917, 37.7929231779916, 37.26984541756766, 37.029145921979634, 37.66401324953352, 40.02133900778634, 43.80094017301287, 42.73756354195731, 45.278749057224815, 45.92930541719709, 48.305217606680735, 50.514640535627095, 50.968034812382285, 45.04874978746687, 45.33301101412092, 52.51148680278233, 48.98187140056065, 45.17605120795113, 49.580854756491526, 48.703707218170166, 48.23644781112671, 47.35908487864903, 49.36427593231201, 46.631469522203716, 42.35046897615705, 38.244222572871614, 37.493612153189524, 35.63798107419695, 36.86580766950335, 35.992971488407676, 36.33107083184378, 35.74801622118269, 42.378425053187776, 47.14224202292306, 50.07443741389683, 47.05414581298828, 44.76619781766619, 48.75463056564331, 48.41187940325056, 49.07749250956944, 45.82609340122768, 42.53872694287981, 36.61414739063808, 35.1134546143668, 36.464820180620464, 40.461774894169395, 46.98763418197632, 45.82249076025826, 49.289648805345806, 46.27974476133074, 45.055968965802876, 45.71896260125296, 45.636789730616975, 43.389895166669575, 41.39109298161098, 43.870936325618196, 44.159644399370464, 44.74133368900844, 45.03229645320347, 38.379333768572124, 13.492810198238917, 1.4522826139416014, 2.508949565035956, 5.694031374795096, 6.344964240278516, 5.939412219183786, 19.561461516789027, 18.702704123088292, 7.271157375403813, 2.344754295689719, 0.12847848875182016, 0.3617410776870591, 18.62121217591422, 47.230796813964844, 22.993852513177053, 42.066871302468435, 17.495960099356516, 0.11048934475651809, 0.11177790989833218, 0.16481112129986286, 0.0950679536908865, 0.14130381840680326, 0.19993065537086555, 0.12897426714854582, 0.13990881826196397, 0.16836334711738996, 0.15896837839058467, 0.188862446429474, 0.1555426586419344, 0.09964372244264398, 0.12795294980917657, 0.12484483873205525, 0.17252541306827748, 0.19487371029598372, 0.08899325358548335, 0.15332661755383015, 0.15159195634935582, 0.146970074357731, 0.14301041540290627], [0.12350523418613843, 0.06712735404393502, 0.03586044681391545, 0.023346961675477878, 0.03638192472447242, 0.04257377729352031, 0.10424155715320792, 0.030719865512635027, 0.009863123962921756, 0.02204168421615447, 0.017901660475347723, 0.023106356550540243, 0.041450167407414744, 0.04081430884876421, 0.05608087179384061, 0.03125656296366027, 0.01176819414831698, 0.04645673464983702, 0.04001114730324064, 0.00542900787799486, 0.04833463459674801, 0.035390255972743034, 0.0611111775838903, 0.029436660797468255, 0.03235968787755285, 0.03581949044018984, 0.06036987129066672, 0.12085455070648875, 0.14216517790087632, 21.862117767333984, 31.87190110342843, 22.8125444820949, 45.3274107660566, 9.479417783873421, 0.014771111941497241, 0.05219645558723381, 0.05507660264681492, 1.0228485486337116, 6.009960753577096, 3.1263237169810703, 3.119345554283687, 2.6734577204499925, 2.2704205129827773, 1.4573062700884682, 0.33771816960402895, 1.2670098756040846, 8.605364799499512, 40.49872194017683, 54.555851800101145, 49.90053789956229, 51.85514954158238, 45.90837744304112, 41.60956866400582, 40.12747621536255, 43.27519430433001, 44.52142320360456, 47.93956865583147, 46.202519008091514, 47.25231885910034, 49.27404662540981, 48.30464438029698, 47.407986300332205, 47.47022826331002, 47.49094779150826, 42.29316370827811, 37.72203070776803, 36.24438510622297, 35.429865155901226, 38.05941786084856, 46.8708210672651, 48.88523932865688, 47.522061824798584, 47.27472332545689, 45.25827966417585, 38.77949094772339, 34.391109466552734, 34.189823627471924, 33.726764406476704, 33.81103563308716, 33.10621036802019, 34.98841483252389, 35.13399696350098, 39.055462973458425, 39.07625545774187, 39.17095940453665, 39.890678133283345, 43.50503723961966, 45.47294078554426, 47.15575974328177, 47.408260754176546, 39.855825969151084, 44.281498432159424, 43.40742547171456, 39.383275508880615, 45.96790266036987, 44.77530343191964, 43.64198970794678, 43.056610924857004, 45.12118475777762, 42.94459554127285, 40.889790875571116, 41.01228414263044, 34.14724159240723, 32.485923835209434, 33.06566762924194, 33.11756372451782, 32.01552731650216, 31.84962865284511, 33.99973828451974, 42.04540484292166, 44.523903710501536, 45.02669620513916, 45.4762863431658, 45.17562736783709, 43.75508901051113, 45.44523136956351, 44.11943517412458, 43.013674531664165, 43.25164685930525, 41.1859404700143, 38.15582759039742, 33.63819224493844, 33.335983821323936, 35.57511724744524, 40.70400646754673, 41.481659276144846, 42.735743113926475, 43.99146672657558, 43.141625608716694, 42.83444922310965, 41.34510285513741, 38.55757590702602, 40.75257437569754, 41.46231549126761, 42.03179332188198, 41.00150053841727, 24.504441261291504, 3.9349259734153748, 0.5178479381969997, 1.2405989042350223, 3.006641213382993, 2.3691850304603577, 4.381325151239123, 7.933280314717974, 3.4916339431490218, 2.02397181732314, 0.1584994699805975, 0.12272865085729531, 0.8733904627817017, 29.53085150037493, 31.316135542733328, 21.650454793657573, 31.279191970825195, 1.5008956853832518, 0.10941138331379209, 0.03633791833583798, 0.07354626817894833, 0.04337604995816946, 0.036897940428129265, 0.023439542689759816, 0.05313202306362135, 0.049590155083153925, 0.014890517141403896, 0.010218111432290502, 0.05420070214729224, 0.022044428890304904, 0.01317444016292159, 0.030832549823181968, 0.03862282394298485, 0.05639814459053533, 0.033881787809410265, 0.03125897176297648, 0.10662300472280808, 0.02009970342208232, 0.02037410807263638, 0.015047930480380143, 0.05754536749528987, 0.06046429622386183, 0.012254337347777826, 0.04016831636961017, 0.016508658616138355, 0.024782456790230105, 0.02834377158433199, 0.05138147396168538, 0.023240574169903994, 0.044671804178506136, 0.03197431730638657, 0.0481054627868746, 0.02471672710297363, 0.01037592934777162, 0.002517550244062607, 0.053979459019111733, 0.014216393448545464, 0.042128359765878746, 0.0383641528231757, 0.009433289840152221, 0.04537740256637335, 0.03470742243475147, 0.048331455660185645, 0.04058716246592147, 0.04090711208326476, 0.03205116139724851, 0.012407897456016923, 0.10580241161265544, 0.13994411565363407, 27.650090524128505, 33.79352617263794, 24.18442460468837, 51.83509356634957, 8.293230005673, 0.04023202741518617, 0.045275608742875714, 0.16587743908166885, 0.8940373605915478, 5.219347383294787, 4.370232352188655, 3.8577957579067776, 2.7830067106655667, 2.8974437585898807, 2.837949808154787, 1.7321390083857944, 1.0798657919679369, 11.941340855189733, 43.6913913999285, 56.1536282811846, 53.302518367767334, 52.329551696777344, 48.37785407475063, 42.13309458323887, 42.69727441242763, 44.400298731667654, 47.15344251905169, 49.669048241206575, 49.54333101000105, 47.32545559746878, 50.65205158506121, 49.870660645621165, 49.72876453399658, 49.89909267425537, 47.96272700173514, 43.70351600646973, 40.80014174325125, 37.38922241755894, 36.45944227491106, 38.633985246930806, 47.96837936128889, 50.30644471304757, 49.6191532271249, 50.045098645346506, 46.155312946864534, 41.43703447069441, 36.69565323420933, 36.11626727240426, 34.7311577796936, 34.54557139532906, 35.133781569344656, 36.25578015191214, 36.521864891052246, 40.354251520974294, 41.146915912628174, 40.86116429737636, 42.406026772090364, 45.54262774331229, 47.29251766204834, 47.161860261644634, 48.77584341594151, 42.64304024832589, 44.04925489425659, 45.22122492109026, 43.83956173488072, 47.24134417942592, 45.38908297674996, 45.48962688446045, 44.80631671633039, 46.46922561100551, 44.25436224256243, 42.750313486371724, 42.21685511725289, 37.33956364222935, 33.26902403150286, 33.794036865234375, 34.49932418550764, 33.76675476346697, 33.408196449279785, 35.999506269182476, 42.438700675964355, 46.79915387289864, 46.48025935036795, 45.17494297027588, 45.18401731763567, 44.17124094281878, 46.78565352303641, 45.27012286867414, 44.661835874829976, 44.319942814963206, 42.45866979871477, 38.44747127805437, 34.459590911865234, 33.55861452647618, 38.315167154584614, 42.180630683898926, 43.705041136060444, 44.262564590999055, 44.799295561654226, 44.744182450430735, 45.150002411433626, 42.600951535361155, 39.91254758834839, 41.578815937042236, 43.42039428438459, 43.662858622414724, 42.52755423954555, 26.47221279144287, 5.0323574628148755, 1.3376562276056834, 2.5892118981906345, 2.575172845806394, 3.9421251756804327, 6.131706655025482, 7.164948948792048, 3.7143575804574147, 1.1729859837463923, 0.1142396078045879, 0.00869912512799991, 0.9371338337659836, 30.929468291146414, 37.059485231127056, 22.0004529271807, 36.071263790130615, 2.6088557583945136, 0.19014090139951023, 0.0123433102520981, 0.045820988049464564, 0.013901151167894048, 0.017601459619722197, 0.04247926075809768, 0.02284433855675161, 0.036597719216453176, 0.018015479635713354, 0.035197592739548, 0.026459354308566878, 0.06314919143915176, 0.04702560144609638, 0.049467621836811304, 0.09965718457741396, 0.013382478151470423, 0.053132874625069756, 0.024628804231594716, 0.09103888738900423, 0.027908160584047437, 0.008504667169680553, 0.011949767574800976, 0.3075585908123425, 0.15473898819514684, 0.09510035373802696, 0.1350394066955362, 0.10921806868697916, 0.11010047633733068, 0.21240254970533506, 0.20189528566386017, 0.11473962025982992, 0.1626128035464457, 0.0792952443339995, 0.0766756445435541, 0.08593529981694051, 0.1272681722683566, 0.14093674453241484, 0.14548203349113464, 0.07759280675756079, 0.11645950297159807, 0.17945096216031484, 0.14384235361857073, 0.13518001272210053, 0.15192415352378572, 0.15178487742585794, 0.12907770302678856, 0.12057978473603725, 0.13016253124390328, 0.1530489610241992, 0.21485672944358417, 0.4722065787230219, 32.555944306509836, 43.545969077519004, 29.877295630318777, 56.097507681165425, 13.737298199108668, 0.23945093687091554, 0.2961018255778721, 0.3451021233839648, 4.34219593661172, 12.24798744065421, 8.226747035980225, 8.074774299349103, 9.367953045027596, 8.256084067480904, 5.153618727411542, 2.5907832767282213, 2.086672144276755, 11.109619770731245, 43.51737029211861, 58.15543903623308, 55.12866824013846, 56.6198593548366, 51.57150323050362, 44.46760940551758, 43.79601737431118, 46.404784543173655, 47.927284240722656, 51.55365330832345, 50.05765751429966, 50.28672572544643, 51.834207671029226, 51.77591923304966, 50.63094643184117, 50.28769499914986, 50.95227977207729, 44.259107862200054, 41.53269379479544, 39.41906220572335, 37.40622465951102, 41.67927994046892, 50.80140311377389, 53.84495728356497, 49.06995023999895, 51.191943986075266, 48.796139104025706, 43.802892616816926, 37.82245649610247, 39.360440254211426, 36.56582266943795, 36.67832442692348, 37.41225569588797, 38.720757825034006, 39.29424129213606, 42.92763498851231, 43.34417601994106, 43.247272968292236, 44.749369280678884, 47.31721155984061, 48.89738130569458, 49.08842202595302, 50.42264291218349, 44.13997752325875, 45.36862400599888, 48.111480985369, 47.11174290520804, 49.76269606181553, 46.39759315763201, 47.45033209664481, 45.7056359563555, 50.19749695914132, 46.5421712739127, 43.987523623875205, 44.171480655670166, 37.70644242422921, 36.11712537493025, 35.8860421861921, 34.76675340107509, 35.508445807865684, 34.8293080329895, 36.76367957251412, 44.73717519215175, 48.98761756079537, 48.02961383547102, 46.49415922164917, 45.982969829014365, 46.133301053728374, 47.96205302647182, 46.56350571768624, 45.7047882761274, 46.26554611751011, 43.166604382651194, 42.08430085863386, 36.644438062395366, 35.24962541035244, 39.722038405282156, 43.076298645564485, 44.68975026266915, 46.91295494352068, 46.40750476292202, 44.680950369153706, 46.307061604091096, 45.48677464893886, 42.761427130017964, 42.90878452573504, 46.01277412687029, 45.513177803584504, 43.34482567650931, 25.90489411354065, 4.813144402844565, 1.3911060052258628, 3.933399975299835, 6.673733455794198, 6.431251747267587, 11.589095847947256, 18.52240879195077, 8.861583965165273, 5.327721042292459, 0.40508347909365383, 0.172422642154353, 1.8985388108662196, 38.42238480704171, 40.326545579092844, 28.637651886258805, 42.37382534572056, 3.6552909442356656, 0.2573810618902956, 0.12994526433093206, 0.17702593228646687, 0.21209221492920602, 0.1242436838469335, 0.08647924741464001, 0.24109679141214915, 0.16742660238274507, 0.14865372329950333, 0.11536763156098978, 0.18168047895388945, 0.16574106711362088, 0.1830775961279869, 0.07013914707515921, 0.1410297445420708, 0.18957536960286753, 0.18207530491054058, 0.07973460254392453, 0.25175079543675694, 0.13085758180490561, 0.10656931224678244, 0.06255879133407559], [0.05989153802927051, 0.022785553675411, 0.055113477632403374, 0.041604333956326754, 0.001218578071399991, 0.06468644645065069, 0.031866722008479495, 0.02364646703270929, 0.038744193501770496, 0.11927029357424804, 0.03695438775633063, 0.011173438696589853, 0.016158332682347724, 0.03698183110515986, 0.02893623782853995, 0.0425890952215663, 0.04645946914596217, 0.027405338993828212, 0.04705224412360361, 0.019433078389348726, 0.03485301908637796, 0.023394050309434533, 0.05832235115979399, 0.019481602124869823, 0.025943489578951682, 0.03253911628520914, 0.08277454799307243, 0.02881871895598514, 0.14411067350634507, 5.364146539143153, 35.62129497528076, 22.673167092459543, 36.348910331726074, 30.097675119127544, 0.8059539613979203, 0.07814613849456821, 0.16005293519369193, 0.7157313855631011, 4.196231654712132, 3.1605970093182156, 4.04852728332792, 1.595799284321921, 1.75058636707919, 1.7306897661515643, 1.640186873929841, 0.7951737770012447, 1.1790853078876222, 19.04078609602792, 55.65262842178345, 51.15860652923584, 49.324188300541465, 49.176215989249094, 43.27052858897618, 42.54065159388951, 44.23887818200247, 48.150981494358604, 48.68579823630196, 48.683863162994385, 47.758165087018696, 50.65550136566162, 47.08034399577549, 45.84911625725882, 44.46513932091849, 42.54339613233294, 40.07047666822161, 36.349219526563374, 35.100096702575684, 35.65958302361624, 40.826221806662424, 47.654574394226074, 46.66247238431658, 48.47534772327968, 50.206446238926475, 46.07658290863037, 38.85315227508545, 36.78390230451311, 34.05813789367676, 34.77970484324864, 33.71410826274327, 34.28488540649414, 32.687570980616975, 35.96467842374529, 38.02405500411987, 41.319012369428364, 40.2677777154105, 40.95650053024292, 41.879728521619526, 44.990812233516145, 46.146850040980745, 46.71337488719395, 41.14909764698574, 43.99799108505249, 37.5017728124346, 49.06611483437674, 49.79980639048985, 46.342358452933176, 42.967138971601216, 44.22521802357265, 46.928411211286274, 43.752014432634624, 40.75047949382237, 38.39660004207066, 35.011524541037424, 31.422317913600377, 32.10520771571568, 32.259645325796946, 33.472071238926475, 31.968755517687114, 37.59420469829014, 43.55338280541556, 44.552287101745605, 44.06159142085484, 45.10284498759678, 43.986127035958425, 44.61768702098301, 44.985340527125764, 43.58300992420742, 46.3607885496957, 43.17765549251011, 41.90020138876778, 42.717889717647004, 38.825345584324424, 37.461344718933105, 34.421063150678364, 35.64454364776611, 39.6505240712847, 42.69843823569161, 44.3562263080052, 40.572748047964915, 43.806245122637065, 42.129881041390554, 40.13261093412127, 41.72045496531895, 42.10400594983782, 44.76175444466727, 34.03301320757185, 11.648115583828517, 0.957256902541433, 0.6589375702398164, 1.6390169709920883, 2.174974411725998, 2.3082523686545233, 4.216637211186545, 4.916971334389277, 2.2845266589096616, 0.6131944847958428, 0.0820689122857792, 0.05353996849485806, 5.832960605621338, 37.346539633614675, 20.512676852090017, 26.65878755705697, 14.63745903968811, 0.12151762869741235, 0.03400950167062027, 0.027285068661772778, 0.022966641101187894, 0.0913922819974167, 0.0025270828129058437, 0.07175055917884622, 0.02973855459796531, 0.026477308345160315, 0.08005160731928689, 0.027721098657431345, 0.03530413630817618, 0.03697669459506869, 0.02235219710772591, 0.022230793622189333, 0.036441584915987084, 0.025035584278936898, 0.045281953045300076, 0.05956703544195209, 0.024039001237334948, 0.005796016867472125, 0.026668195512944033, 0.03304328816011548, 0.05347429309040308, 0.02397239115089178, 0.05370929351608668, 0.03887277249512928, 0.045791994248117716, 0.02268400412452008, 0.03934760790850435, 0.043544184150440354, 0.04299775989992278, 0.05305533164313861, 0.045783763618341515, 0.03139107235308204, 0.02340014185756445, 0.026185679083157862, 0.024259978040520633, 0.021057028123842816, 0.02755177702887782, 0.06071148653115545, 0.04895110062456556, 0.021081455384514163, 0.036693647104714594, 0.0347641920670867, 0.04980586815093245, 0.028254428878426552, 0.019881408528557847, 0.04573991668543645, 0.04786593992529171, 0.02683997174192752, 0.18052072690001555, 8.149869561195374, 40.77828965868269, 22.90505106108529, 46.90276888438633, 31.654248782566615, 0.42300065766487804, 0.08214686917407171, 0.1444958099829299, 0.4241759074585778, 1.383688586098807, 5.712292109216962, 5.987803382532937, 4.73772474697658, 4.3807849287986755, 3.123086507831301, 3.5708777138165066, 1.622560054063797, 1.3615379461220332, 23.74216307912554, 55.990693024226594, 52.026846476963584, 51.84878499167306, 48.74410057067871, 44.72384854725429, 44.3217910357884, 47.66014337539673, 49.51138319287981, 50.97566046033587, 49.05411182131086, 49.28797776358468, 52.19736221858433, 49.63756595339094, 46.80275651386806, 46.57497024536133, 43.496543066842214, 42.312337262289866, 38.00790391649519, 37.97921827861241, 36.32647459847586, 42.46957499640328, 48.05636092594692, 50.553991658346995, 50.6763459614345, 50.90456301825387, 47.58926132747105, 42.070859568459646, 37.66630268096924, 35.01210124152047, 36.78782108851841, 35.48992191042219, 36.64309358596802, 34.481165068490164, 37.46753208977835, 41.13174104690552, 41.21356998171125, 41.48855536324637, 42.602983883449006, 43.91754136766706, 47.823387827192036, 47.76158012662615, 47.44622571127755, 41.64429576056344, 43.91139221191406, 40.41778932298933, 49.97866691861834, 50.83608852113996, 47.136787687029155, 44.76883118493216, 44.83250447681972, 48.40050867625645, 45.471968037741526, 43.255683762686594, 41.83396768569946, 35.868828024183, 31.92578785760062, 33.85395465578352, 33.543682847704204, 35.469087736947195, 34.03768934522356, 38.076732771737234, 44.53251600265503, 47.274712903159006, 46.002727031707764, 45.48368270056588, 45.32370737620762, 45.37854950768607, 45.79581662586757, 45.40437248774937, 46.59123945236206, 44.06428384780884, 43.42358003343855, 43.559090750558035, 40.36952713557652, 37.59028244018555, 35.10212557656424, 37.07378462382725, 41.73089810780117, 45.666726044246126, 44.228692122868125, 40.82947703770229, 44.285556180136545, 43.95112895965576, 40.676119872501914, 44.30961084365845, 42.350642681121826, 44.75920098168509, 35.89886161259243, 15.031529596873693, 1.9819380385535104, 2.1335277557373047, 3.510049057858331, 2.970105848142079, 4.397329892430987, 5.925266121115003, 4.630022457667759, 2.5719258657523563, 0.70787313580513, 0.13444248586893082, 0.039509234949946404, 5.439019458634513, 43.88775444030762, 24.119712557111466, 28.064651318958827, 19.938389131001063, 0.09247345969613109, 0.011931598103339118, 0.030559347875948464, 0.019423982627423744, 0.01724218380903559, 0.04310050027977143, 0.04834688215383461, 0.04574681060122592, 0.02296449862686651, 0.021989121500934874, 0.0055548349877686375, 0.023566527125824775, 0.023989680223166943, 0.06831236795655318, 0.036734844358371835, 0.025568090079884444, 0.0357371264669512, 0.024322289607620666, 0.025710319501480887, 0.0065211163517752925, 0.02418777173651116, 0.04801940758313451, 0.03200794550191079, 0.13968872864331516, 0.10721520294568368, 0.17994779907166958, 0.08125473133155278, 0.16262201805199894, 0.10298974146800381, 0.11746829455452305, 0.13230648477162632, 0.1325537022203207, 0.1295639547918524, 0.1289252226373979, 0.07071418514741318, 0.10648804410759892, 0.18497051884021076, 0.07153787237725087, 0.1823708340525627, 0.13498763447361334, 0.09416167517857892, 0.09856460070503609, 0.11220244211809975, 0.09599591818239007, 0.09030753520450421, 0.1673263284776892, 0.21199185959994793, 0.12009463219770364, 0.14256487573896134, 0.17630497525845254, 0.14271359704434872, 0.23222641167896135, 9.02787607056754, 48.549703870500835, 30.21557215281895, 45.96901784624372, 38.36206749507359, 1.626319246632712, 0.28495221957564354, 0.6377313967261995, 1.2778891261134828, 11.115898336683001, 11.39625380720411, 14.34358845438276, 8.196524977684021, 6.592330966676984, 6.255918732711247, 4.031786033085414, 2.3521741032600403, 2.0871196516922543, 22.23273468017578, 58.536460876464844, 56.12167004176548, 54.24697657993862, 52.54788841520037, 47.7529296193804, 46.492550713675364, 49.709156717572895, 52.20395258494786, 52.60241787774222, 50.58496672766549, 49.08577823638916, 53.565073422023225, 51.2554018838065, 48.33172845840454, 48.84849725450788, 45.78466476712908, 44.51408243179321, 39.25247567040579, 38.376068115234375, 38.21259437288557, 44.4137087549482, 50.446673257010325, 51.21779128483364, 51.5991918018886, 53.59094851357596, 50.05218580790928, 43.32107673372541, 40.88448245184762, 36.89970793042864, 40.11511189596993, 37.28927952902657, 38.70919949667794, 35.55396345683506, 38.82529694693429, 42.14125871658325, 44.502722127096995, 43.74590001787458, 45.02270793914795, 46.8472249848502, 49.441890784672324, 50.3819751058306, 49.08066783632551, 44.97150666373116, 43.6600341796875, 42.09714460372925, 49.973674637930735, 51.419031960623606, 48.59886237553188, 47.169107232775005, 48.80374043328421, 51.27026408059256, 46.8676700592041, 44.16053376879011, 44.2098833492824, 38.094860621861045, 32.73483262743269, 36.06611517497471, 34.77845764160156, 36.2839481489999, 36.272566999707905, 40.924253940582275, 47.43987158366612, 48.540956088474815, 46.24370445523943, 46.8714359828404, 46.85948855536324, 47.16060611179897, 47.01516989299229, 45.544778210776194, 48.91632904325213, 45.879521574292866, 45.75333881378174, 46.028101852961946, 42.74590832846505, 40.91973761149815, 36.87100492204939, 40.04297569819859, 43.30822604043143, 48.134458678109304, 46.34211526598249, 42.08745534079415, 45.53244168417794, 44.16821500233242, 43.62941346849714, 46.12838520322527, 45.23631640842983, 46.08538280214582, 36.116600785936626, 13.91299295425415, 2.264201440981456, 2.9275353210312978, 5.962944899286542, 6.482522070407867, 6.5273314373833795, 11.521576728139605, 11.215643201555524, 9.040700708116804, 1.778726462806974, 0.23886264700974735, 0.17708436772227287, 8.657443284988403, 48.55275065558297, 27.991589273725236, 36.626772267477854, 23.8777345929827, 0.28232729328530176, 0.14114859673593724, 0.13541254667299135, 0.15633494327110903, 0.13343924470245838, 0.15438568858163698, 0.20921855127172811, 0.1396979567195688, 0.07443659433296748, 0.14038419989602907, 0.05360051756724715, 0.1718429018344198, 0.1162327772804669, 0.11664825784308569, 0.23505690693855286, 0.10658105090260506, 0.1122569420507976, 0.13711679593792983, 0.1400071651275669, 0.08512767351099423, 0.0685999718095575, 0.14084511516349657, 0.17271107382008008], [0.012014183448627591, 0.013264456314833035, 0.068114459647664, 0.04114707599260977, 0.06648378393479756, 0.048824228146778684, 0.030123297524239336, 0.027345741566802775, 0.026379085312198316, 0.01485557428428105, 0.02598632888735405, 0.0038601471294116762, 0.06862977985292673, 0.06907259859144688, 0.11525595826762063, 0.01580131978594831, 0.041452338719474416, 0.03361078770831227, 0.012740627280436456, 0.0324290952246104, 0.007717892244857336, 0.0653639365253704, 0.04371347863759313, 0.05613170424476266, 0.003917259421931314, 0.007318665988610259, 0.06651294736989907, 0.05134831056264894, 0.07419319703642811, 0.2560232590351786, 23.44901510647365, 33.56930085590908, 24.816743680409022, 42.959308351789204, 8.510254383087158, 0.04549778824938195, 0.020352179517171214, 0.10044404771178961, 0.6377804140959467, 3.081277242728642, 2.0594441081796373, 2.7480099371501376, 2.6490567326545715, 2.3714822786194936, 1.644429726260049, 1.1285714698689324, 0.3065477636243616, 2.9440103684152876, 34.64821713311331, 53.65195369720459, 51.067234243665425, 49.1350861276899, 46.573167187826975, 45.99066495895386, 46.009442465645925, 47.081486974443706, 49.71518775394985, 47.81010981968471, 49.728886127471924, 48.21945946557181, 47.46330438341413, 43.43392937523978, 42.267858369009836, 39.93718590055193, 38.69359731674194, 36.68152059827532, 36.2841739654541, 36.342674323490684, 45.40495613643101, 47.955299377441406, 49.213107449667795, 49.2117212840489, 47.796974250248496, 43.96978139877319, 39.956199645996094, 35.817960262298584, 34.483294691358296, 33.7226128578186, 35.53211832046509, 34.02591562271118, 33.22486128125872, 35.20117562157767, 39.92148297173636, 40.13655056272234, 41.6007513999939, 40.07567392076765, 43.614752769470215, 44.978517396109446, 47.67505768367222, 44.586055346897666, 43.33752311979021, 40.61587899071829, 41.402356011526926, 52.113629477364675, 39.44816820962088, 44.68995523452759, 43.41224752153669, 46.335719449179514, 45.22238179615566, 48.27318641117641, 41.747976779937744, 38.77490513665335, 31.943707261766704, 32.87559618268694, 30.864151750292095, 34.0724755014692, 32.44466543197632, 35.73658643450056, 40.788326331547324, 45.19408178329468, 45.13314955575125, 46.297066620418, 43.88923788070679, 42.786447593144004, 41.613946029118125, 42.65938588551113, 43.327107770102366, 44.31301893506731, 44.39466721670968, 44.972642694200786, 43.164221150534495, 42.71704551151821, 40.059564522334504, 38.63740723473685, 36.75229147502354, 35.44328212738037, 40.39786883762905, 41.90932089941842, 45.86914791379656, 42.562191009521484, 42.975515025002615, 43.18785892214094, 42.808761732918875, 45.0120598248073, 39.78929696764265, 18.1743300982884, 2.578273045165198, 0.5317056317414556, 2.2045090326241086, 3.0226837354046956, 1.5798283070325851, 3.6905539206096103, 4.851464152336121, 3.1910422784941535, 0.2828845333840166, 0.3467251520071711, 0.049860856628843715, 0.26900119121585575, 14.351801225117274, 35.71666247504098, 19.8086610521589, 28.236110278538295, 4.381581366062164, 0.08090390837086098, 0.041189104451664856, 0.024841277294659188, 0.058384613533105166, 0.044266389682888985, 0.015423789686922516, 0.013474422191003603, 0.01327203300648502, 0.013623827120422252, 0.0182743797610913, 0.017124561459890435, 0.04949225265798824, 0.10099536419979163, 0.029330429354948655, 0.03619729534589818, 0.1165595461747476, 0.05236325306551797, 0.026522390211799314, 0.011314326315186918, 0.02744350489228964, 0.035138936779860935, 0.03830685732620103, 0.0907354261726141, 0.015222280053421855, 0.01885872903013868, 0.029310378645147597, 0.04710529877671173, 0.03560128375621779, 0.03469193487295082, 0.02619026937255902, 0.03829610933150564, 0.025294039963877628, 0.04484112919973476, 0.035171862691640854, 0.06118150095322302, 0.028563878166356256, 0.07540910464844533, 0.020256366979862963, 0.04043195436575583, 0.01263362739700824, 0.04703437490388751, 0.01757750563722636, 0.04199817942987595, 0.01846971472592226, 0.050430968536862304, 0.05673677766961711, 0.015362182099904333, 0.06646701733448676, 0.054519498255103827, 0.059995191038719246, 0.02683045868096607, 0.16188780244972023, 0.674497518156256, 31.966219425201416, 35.12954316820417, 28.66544120652335, 48.45063992909023, 7.588818158422198, 0.011361732164264789, 0.057293339233313284, 0.09254667362464325, 0.21085656194814614, 2.9567698666027615, 4.938960645880018, 4.224307588168553, 4.827223190239497, 3.0724979766777585, 3.3961481068815504, 2.678878835269383, 0.9374955743551254, 4.137662248952048, 41.78955132620675, 53.65400341578892, 52.798023564474924, 50.800802094595774, 47.94606522151402, 46.884658404758994, 48.20250586100987, 48.18005970546177, 50.86093875340053, 48.59465176718575, 49.950325216565815, 48.95030573436192, 49.832251003810335, 46.42592443738665, 43.77367196764265, 41.44112001146589, 40.48501314435686, 37.25065796715872, 38.67878375734602, 37.9864513533456, 46.84252800260271, 51.01741565976824, 49.389737606048584, 49.863021101270405, 49.5767240524292, 45.98381403514317, 42.19060134887695, 37.06440108163016, 35.77825130735125, 36.415668623788015, 37.457408564431326, 35.66554805210659, 34.29745122364589, 36.32840967178345, 40.26221915653774, 41.60139063426426, 43.424570151737754, 43.0253301348005, 44.76392228262765, 46.830552782331196, 48.92648383549282, 47.12513555799212, 45.166903904506135, 39.51058387756348, 42.81422301701137, 53.204607827322825, 41.437117849077495, 45.30084432874407, 45.29592153004238, 47.20247595650809, 46.511734689985005, 49.66552897862026, 43.04471560886928, 40.60139547075544, 33.9771705354963, 35.078435693468364, 32.08424500056675, 33.9292105947222, 34.32953800473894, 36.00376551491873, 42.80214009966169, 46.88920600073678, 45.843863419124055, 46.60886008398873, 46.069110121045796, 45.43213401521955, 44.56661081314087, 44.29620429447719, 44.41954871586391, 45.01196949822562, 45.4792150088719, 45.66926213673183, 44.37675823484148, 43.29238067354475, 40.64608975819179, 39.931116649082725, 39.60865075247628, 36.990722383771626, 41.09731272288731, 44.26415572847639, 46.34051023210798, 43.44734634671892, 44.2709059034075, 44.047851358141216, 41.831320422036306, 44.996224880218506, 40.443469864981516, 21.188715730394634, 4.569212257862091, 1.0186352261475153, 2.7851107120513916, 3.8539742486817494, 3.206984920161111, 5.833824787821088, 6.99139814717429, 3.311117789575032, 0.20657047336655004, 0.26644368416496683, 0.05400642739342792, 0.2622870872063296, 15.51219207899911, 42.70058870315552, 20.46938783781869, 31.650507177625382, 7.973070910998753, 0.17347552494278975, 0.021941283085782613, 0.03853733531598534, 0.055720654515815635, 0.018944221049813286, 0.03665561521691935, 0.06128079776785203, 0.01080008243609752, 0.045213672066373486, 0.050304170697927475, 0.043505775675709756, 0.07321902431015458, 0.03819189653066652, 0.01535413128190807, 0.035213283861854246, 0.07340474613010883, 0.08380792289972305, 0.021210667111777833, 0.020958564210949198, 0.03522387918617044, 0.02329612922455583, 0.0599980748125485, 0.018515261389049034, 0.09815377489264522, 0.13047758862376213, 0.2403005441384656, 0.11792422937495367, 0.10810732721750226, 0.11633200624159404, 0.1482483529086624, 0.1678235860807555, 0.13513117177145823, 0.22383566120905535, 0.11330531258136034, 0.13879813786063874, 0.12360378461224691, 0.16027096206588404, 0.22804229333996773, 0.13564163366598742, 0.08491917327046394, 0.13431920962674276, 0.08460106248302118, 0.10234960474606071, 0.15890835518283503, 0.20394763696406568, 0.17353144979902677, 0.12151165758924824, 0.09637801482209138, 0.11392457756612982, 0.1235092104013477, 0.11843146144279412, 0.22490060835012368, 1.0846284564052309, 37.2990973336356, 44.2148026738848, 33.786147185734336, 54.14239576884678, 12.451574870518275, 0.16682798521859304, 0.31944942846894264, 0.24386925835694584, 2.7822517454624176, 11.17612271649497, 8.24515802519662, 8.884217722075325, 8.330088462148394, 6.723721836294446, 4.949528421674456, 2.788984549897058, 0.8294561345662389, 4.042888820171356, 38.783920424325125, 56.667628220149446, 57.99966042382376, 51.57109676088606, 49.16456733431135, 50.9345132282802, 51.353121348789756, 50.351211956569124, 52.75919703074864, 50.257178510938374, 52.21263435908726, 50.7582756451198, 51.79135813031878, 46.86858374731881, 46.80790165492466, 43.80442122050694, 41.777742862701416, 40.48064620154244, 40.012052740369526, 40.361745153154644, 49.72013487134661, 51.973536423274446, 51.57873283113752, 50.90155444826399, 51.591639110020225, 46.97656570162092, 43.99287026269095, 38.05552339553833, 37.633687836783274, 37.394044467381065, 38.931764193943565, 38.363342489515034, 36.54241418838501, 38.54147693089077, 43.93485280445644, 43.78807210922241, 45.48650366919381, 43.75643696103777, 46.82540764127459, 49.44866875239781, 49.83052090236119, 47.154891218457905, 45.6446134022304, 40.90827655792236, 43.22250958851406, 53.942416191101074, 45.09773806163243, 48.86160503114973, 47.76951149531773, 49.08410024642944, 47.04849345343453, 52.219165665762766, 45.42844104766846, 42.20402179445539, 34.97418144771031, 37.30406876972744, 33.05431079864502, 35.89229209082467, 35.52329410825457, 37.69520371300833, 44.03944403784615, 48.36866160801479, 47.88175964355469, 47.35421071733747, 46.98370150157383, 46.57831927708217, 44.92804568154471, 45.88536153520857, 47.413079329899375, 47.97468485151018, 47.72610609872, 47.40173292160034, 46.10757882254464, 45.860285486493794, 43.990080560956685, 42.783404282161165, 41.06467703410557, 38.65103612627302, 42.98099020549229, 46.39487641198294, 48.15371561050415, 44.47072219848633, 44.34511266435896, 45.078870228358674, 43.91294860839844, 45.54686267035348, 39.8029328073774, 20.991956642695836, 4.164795398712158, 1.3233088489089693, 6.389035361153739, 7.00835348878588, 5.6057527746473035, 11.42351940699986, 14.101114562579564, 10.191562976155963, 2.6040050472532, 1.1846065201929636, 0.25743211486509865, 0.61679728861366, 20.032200234276907, 46.03418500082833, 25.439408234187535, 39.06290102005005, 9.426907641547066, 0.44665840534227236, 0.11491886207035609, 0.09571563572223697, 0.09197879409683601, 0.08628199049936873, 0.23383543533938272, 0.17046383369181836, 0.12144068282629762, 0.08609305242342608, 0.15754569401698454, 0.12911783158779144, 0.17322081646748952, 0.20908482559025288, 0.13647040990846498, 0.12750147974916867, 0.22592641759131635, 0.13798373298985617, 0.16958469658025674, 0.0791204401424953, 0.14345389232039452, 0.14413564359503134, 0.1292076696242605, 0.09768557894442763], [0.06522620070193495, 0.03246818562703473, 0.02407858527398535, 0.017463476131004945, 0.0036254452591362807, 0.054252986663154194, 0.034662849469376464, 0.05677526078319975, 0.027183990692719817, 0.015198957108493363, 0.04236853062840445, 0.05370607726009829, 0.03728274442255497, 0.06733096204698086, 0.060979711424027166, 0.04286369155826313, 0.07927371441785779, 0.07628273205565554, 0.02076024199569864, 0.04212825120027576, 0.02700845877240811, 0.05705166541572128, 0.04717367814321603, 0.07939086348882743, 0.07448241580277681, 0.06436135353786604, 0.022757212964019606, 0.07749039546719619, 0.10738362890801259, 0.04397574260032602, 7.1191194994109015, 36.846401350838796, 26.47984712464469, 33.31740781239101, 29.226047924586705, 1.3966520790542876, 0.07206019506390605, 0.06322370136954955, 0.13567771815827914, 1.8048994583742959, 2.6884999190058028, 2.7486387491226196, 4.117317054952894, 1.8992008439132144, 4.0632340141705106, 2.650395997932979, 0.48671376598732813, 0.3405781675662313, 10.070540121623448, 48.64745807647705, 50.4163304737636, 50.0284229687282, 51.08213465554373, 46.776672976357595, 46.176425048283164, 46.74464178085327, 47.35672943932669, 50.23783820016043, 49.17949206488473, 47.75249188286917, 45.39530508858817, 42.598773275102886, 40.38601868493216, 41.34078802381243, 38.934150900159565, 38.10174281256539, 36.40354749134609, 39.58623586382185, 45.6796601159232, 49.16196175983974, 46.212090151650564, 45.75942196164812, 49.53363479886736, 47.72194412776402, 39.77191604886736, 34.82556990214756, 36.12552227292742, 35.33962542670113, 34.21376017161778, 34.62422152927944, 35.1872410093035, 38.554365839277, 39.62436410358974, 42.920950821467805, 43.53402859824044, 43.667145660945344, 45.4643806048802, 46.01023803438459, 46.86686059406826, 47.19034440176827, 41.92577770778111, 42.73448201588222, 43.88557965414864, 41.3033059665135, 44.16073179244995, 47.45682518822806, 47.811989307403564, 47.03874165671212, 44.69618082046509, 41.7825996535165, 41.52332067489624, 36.901931353977744, 32.523649079459055, 32.24100678307669, 33.17117255074637, 31.570613316127233, 32.72354875292097, 36.29611097063337, 42.408899852207725, 43.1581449508667, 44.944721358163015, 45.90343379974365, 40.76651593617031, 40.15774604252407, 36.64780446461269, 35.87645714623587, 38.416815825871055, 41.422446727752686, 42.12943983078003, 42.96663522720337, 43.64449800763811, 44.18518597739083, 41.45287636348179, 39.313216822487966, 37.170534815107075, 36.39355250767299, 38.66954265322004, 42.42143440246582, 43.3314642906189, 44.0532431602478, 44.90443917683193, 44.204022543770925, 43.74188395908901, 39.208194800785606, 25.04955349649702, 4.422617426940373, 0.8538151617561067, 1.4989279338291712, 1.1879339473588126, 2.7620376987116675, 2.0896815827914645, 3.383666970900127, 3.9154770970344543, 1.1701329882655824, 0.4413392607654844, 0.21230371429451875, 0.08839618348117385, 2.3394417464733124, 29.66770669392177, 34.1685517174857, 22.901797567095073, 20.902340514319285, 0.304602675139904, 0.054796666239521334, 0.012567114001805229, 0.015389430369915707, 0.061871279297130446, 0.042560036959392686, 0.03987238010657685, 0.04071401798033288, 0.00413307681446895, 0.01259707726005997, 0.0487468581912773, 0.025916638251926218, 0.04373122572100588, 0.02011574398992317, 0.027758665748738816, 0.047402307125074525, 0.008450766044136668, 0.054966401774436235, 0.042273807139801126, 0.04343464145702975, 0.0323858691512474, 0.04768130715404238, 0.08066180029085704, 0.05008333469075816, 0.05846582060413701, 0.03476778491001044, 0.015494725434109569, 0.010008097210499858, 0.0050495193572714925, 0.02189030814250665, 0.03595596758116569, 0.03758011917982783, 0.028017177412818586, 0.008633498917333782, 0.03972891066223383, 0.04913560447416135, 0.004440099491538214, 0.026290511047201495, 0.04110565821507147, 0.03964823284851653, 0.08172270336321422, 0.03791549868349518, 0.04174043111769216, 0.06403004524431058, 0.01304242354152458, 0.03457437528829489, 0.03447054585974131, 0.032765621452459266, 0.029184656284217323, 0.017606280611029694, 0.04495335549914411, 0.03940448610644255, 0.08667289452361208, 0.024305451761132905, 12.02098284448896, 42.034318992069785, 25.50384930201939, 42.65331663404192, 30.146465369633265, 0.9145913805280412, 0.03389300738594361, 0.054384649598172734, 0.06002039861466203, 0.2358544027166707, 3.538035750389099, 4.421556958130427, 4.741699116570609, 5.018805001463209, 2.9478568477290015, 3.429222183568137, 1.502342864871025, 0.5727083629795483, 12.877655778612409, 50.75644826889038, 51.517310755593435, 50.7363714490618, 51.784871986934114, 47.80318593978882, 48.17641537530081, 48.229916504451204, 48.549429416656494, 50.45780427115304, 48.514785698481965, 49.23805843080793, 47.82461071014404, 43.97112587520054, 42.72014093399048, 42.856690406799316, 40.071272236960276, 39.756355558122905, 37.87540871756417, 40.20600128173828, 48.02398579461234, 51.247519152505056, 48.07253285816738, 47.8819819859096, 50.565094879695344, 49.59052664893014, 41.61445672171456, 36.12191268375942, 38.62816613061087, 36.755838530404226, 35.6590758051191, 37.006310667310444, 36.16276809147426, 38.18556240626744, 42.719699723379954, 44.56997374125889, 44.94914041246687, 44.3958866255624, 45.938525676727295, 46.946007524217876, 47.75988129207066, 47.54170438221523, 42.5577962739127, 42.19157409667969, 46.02055263519287, 43.08901037488665, 47.09082882744925, 48.69649498803275, 48.38994741439819, 48.08112777982439, 45.296234198978965, 43.934262207576204, 43.22907216208321, 37.30937371935163, 33.27340834481375, 34.00967073440552, 34.491295542035786, 33.748064109257285, 35.029635020664756, 37.90386159079415, 43.469806398664204, 45.57198735645839, 45.75539548056466, 47.093448298318044, 44.68080793108259, 41.41770110811506, 39.44920349121094, 37.98086500167847, 41.31795971734183, 43.60345152446202, 43.12867069244385, 44.487793922424316, 45.368714332580566, 45.259954180036274, 41.71092203685215, 40.58664444514683, 39.26534373419625, 38.09232800347464, 40.58402497427804, 43.4415202822004, 45.19692012241909, 42.562458515167236, 44.43239940915789, 44.46401718684605, 44.80513552256993, 39.96687207903181, 27.15877992766244, 6.5334150195121765, 1.228905737400055, 2.04096103140286, 2.094279770340238, 4.674272494656699, 4.067624407155173, 4.512568805898939, 5.276703459875924, 1.1169779662575041, 0.10712802476648774, 0.1360271094100816, 0.04270123331142323, 1.9241290262767246, 31.68552609852382, 36.40094191687447, 24.195656367710658, 26.089483431407384, 1.1232457842145647, 0.06897695908056838, 0.033617172722837756, 0.030490900655942302, 0.01800143565716488, 0.06871526847992625, 0.03211126942187548, 0.07608317490667105, 0.005088062690837043, 0.006990485741490764, 0.03432376177183219, 0.026854227762669325, 0.024372472361262356, 0.030087844069514955, 0.05478431690218193, 0.04552955725895507, 0.02017424049388085, 0.029519207975161926, 0.056792841625532935, 0.035247553272971084, 0.03835232595780066, 0.01920561818405986, 0.05614014522039464, 0.020451242237218788, 0.1425752980368478, 0.186737559735775, 0.14292698273701326, 0.34687776810356546, 0.1179778336414269, 0.1327223724552563, 0.1479507474494832, 0.16377522902829306, 0.12283782714179584, 0.04111207376367279, 0.085471073298582, 0.11849265173077583, 0.1072954193555883, 0.1728934911744935, 0.18000578667436326, 0.10379465363387551, 0.2618909313210419, 0.1929406454520566, 0.13205405617398874, 0.1687331758439541, 0.08353789310370173, 0.08584951941988297, 0.15945777855813503, 0.19616124406456947, 0.18827354588678905, 0.12613504592861446, 0.2215683093028409, 0.1297523161130292, 0.2071778436324426, 0.09977731920246567, 14.201364040374756, 50.22208663395473, 35.18743903296334, 42.78619745799473, 37.173814364842, 3.152390535388674, 0.13717962828065666, 0.33365903741547037, 0.4402854415987219, 5.748273355620248, 11.600267682756696, 10.350174716540746, 10.921589357512337, 8.601769106728689, 8.384332180023193, 5.912951307637351, 2.0953884422779083, 0.6465893728392464, 11.744269967079163, 52.309221267700195, 53.558719294411794, 53.2349853515625, 56.103931290762766, 50.40940311976841, 51.75509548187256, 51.09030226298741, 49.79367113113403, 51.917464460645405, 50.51607881273542, 51.17566088267735, 48.568081855773926, 46.601105894361226, 44.41628653662545, 45.79852989741734, 41.77995238985334, 42.635699476514546, 39.66958992821829, 43.482754366738455, 48.51261786052159, 53.30668728692191, 48.76336097717285, 48.452495098114014, 54.444253308432444, 53.09234925678798, 43.762210914066856, 38.24795375551496, 39.965367794036865, 38.72634417670113, 37.39295360020229, 38.37552962984358, 38.27376283918108, 41.277413504464285, 44.36540140424456, 46.98151976721627, 46.98515714917864, 45.89453315734863, 50.48505858012608, 49.54218108313424, 49.568403584616526, 48.93692350387573, 44.97690541403634, 41.75504657200405, 45.68366922651018, 48.292370387486045, 48.83752952303205, 50.21899468558175, 51.168816907065256, 49.98410388401577, 47.46477740151541, 44.88582147870745, 45.01489816393171, 39.654105867658345, 35.35760389055525, 35.46009676797049, 36.37429557527815, 36.17466688156128, 35.993881702423096, 41.134534222739084, 44.25341381345476, 46.9206257547651, 47.95223522186279, 49.81714909417288, 44.61798579352242, 43.562658650534495, 41.25281340735299, 40.04310771397182, 41.46206535611834, 44.75278779438564, 44.52422680173601, 46.60520880562918, 47.05500044141497, 45.798373562949045, 44.20947687966483, 41.40834188461304, 41.367590699877056, 40.24795797892979, 42.17961277280535, 46.066132817949565, 46.65967920848301, 45.09299939019339, 46.560038566589355, 45.127639634268625, 43.98684964861189, 40.84052119936262, 26.633506536483765, 5.831094580037253, 1.66408748286111, 4.068842947483063, 4.746096457753863, 7.152275434562138, 8.398785301617213, 9.091333099773951, 14.66331328664507, 5.100389012268611, 0.6060108616948128, 0.6583702063986233, 0.19906264623360975, 3.6587368164743697, 38.30915001460484, 42.121470246996196, 31.96680654798235, 31.773796013423375, 1.3916974706309182, 0.10302587345774684, 0.06376929102199418, 0.1525246977273907, 0.1947821487805673, 0.14609308141682828, 0.16736239939928055, 0.1525667126157454, 0.1691609921732119, 0.04538908354671938, 0.11902208546442644, 0.08053768266524587, 0.09230909137321369, 0.17549257885132516, 0.15314124178673538, 0.18961480605815137, 0.10845348864261593, 0.0948491193620222, 0.17943030755434716, 0.09482898044266871, 0.11040825303643942, 0.11738050569381032, 0.1720939190792186, 0.0937993171225701], [0.0489283900574914, 0.05891933983990124, 0.012280513532459736, 0.012986558905270482, 0.007464522179881377, 0.029545962610947232, 0.05362935530553971, 0.06229942810854741, 0.06227745035929339, 0.0014041278191143647, 0.022950388491153717, 0.04333907658500331, 0.06594039273581334, 0.02419457065739802, 0.03301625193229743, 0.042397575319877694, 0.04609037323721817, 0.01196714146395347, 0.0358452137027468, 0.03878097688513143, 0.019979841907375624, 0.040546501254928966, 0.01593320833386055, 0.0442895243343498, 0.015309604117646813, 0.05570890228929264, 0.038004189995782714, 0.02722029061987996, 0.02280890545807779, 0.009092716150917113, 0.7156659205045018, 28.064376865114482, 29.334874085017614, 20.943439108984812, 37.047120911734446, 14.498079913003103, 0.6773863402860505, 0.05519729367058192, 0.04186015183638249, 0.14874954601483686, 2.5724243990012576, 2.6991148122719357, 2.5954922011920383, 3.5619870594569614, 1.856066644191742, 2.39825325352805, 2.1912620748792375, 0.3082314804196358, 1.531800729887826, 22.47408035823277, 53.09374237060547, 49.963571957179475, 50.05949878692627, 47.842088903699604, 48.172086647578645, 46.7607546533857, 49.29269906452724, 49.631781578063965, 52.353040082114084, 48.71879870550973, 47.502315044403076, 43.803156648363384, 44.95150279998779, 44.81551613126482, 42.35136529377529, 38.887973172324045, 33.86690609795706, 40.70871387209211, 46.934310231889995, 50.722304821014404, 48.526302337646484, 45.93054914474487, 48.783326625823975, 46.55561603818621, 44.48918008804321, 36.70145150593349, 35.20091506413051, 35.05851173400879, 34.83547108513968, 34.225460938044954, 35.056500230516704, 38.7767151423863, 40.80257361275809, 44.171504974365234, 46.09122276306152, 47.05008111681257, 46.869851793561665, 46.330369336264475, 48.274475302015034, 46.605556215558735, 41.490914276668, 41.52388347898211, 42.76410218647548, 46.987912109919954, 45.438196318490164, 46.45741367340088, 44.92868838991438, 46.933865547180176, 45.12955386298043, 42.203695229121614, 39.23746408735003, 33.60917656762259, 33.18084444318499, 32.79771729878017, 34.165393761226106, 33.343626839774, 33.25593709945679, 35.41472503117153, 39.94340801239014, 40.706427914755686, 42.68226282937186, 39.69645513807024, 38.295743465423584, 35.08968482698713, 34.47416475840977, 31.587302889142716, 31.19741862160819, 33.14396687916347, 36.808627469199045, 39.55064719063895, 39.66008479254586, 39.98514584132603, 40.6182587487357, 37.925526074000764, 36.687801769801546, 34.71561813354492, 39.07269103186471, 42.24103137425014, 44.710660866328645, 41.365242208753315, 41.35573707308088, 38.984375953674316, 39.45959104810442, 26.573923996516637, 6.7511581012180875, 0.011842572612554898, 0.6234806956989425, 0.6378998362592289, 1.826246930020196, 2.1516506118433814, 3.5263434520789554, 2.7846957743167877, 3.824031855378832, 1.1175247026341302, 0.023025556600519588, 0.08511613841567721, 0.3646564983895847, 9.188732079097203, 35.706330503736226, 23.32800006866455, 26.723586457116262, 9.657539197376796, 0.0816265210243208, 0.012469392236588257, 0.019967723271942565, 0.07426829050694193, 0.008811479500894035, 0.025090608379936645, 0.03714774309524468, 0.03641716444066592, 0.03493690297805837, 0.03059835685417056, 0.024641713360324502, 0.0268896591650056, 0.03195028020335095, 0.005436911538708955, 0.027411791861855557, 0.03055288822257093, 0.031719344202429056, 0.03443782350846699, 0.04903660621494055, 0.028883617437843765, 0.0756509006023407, 0.05759456128414188, 0.04151371560458626, 0.018823760727952634, 0.04658593450273786, 0.0027388054586481303, 0.015833818220666478, 0.05800363647618464, 0.01696033902200205, 0.019257644856614724, 0.04020410569916878, 0.02512991930624204, 0.03034893755934068, 0.028275963883580904, 0.02249606010237975, 0.052842471815113506, 0.024026802874037197, 0.01188472829692598, 0.035735131573996375, 0.034374733322433064, 0.07008947152644396, 0.02317124994338623, 0.019899920660204122, 0.023094351569722806, 0.020338162680023482, 0.014035038001436208, 0.019193436784137572, 0.06560014813606228, 0.014071094504158412, 0.04292903108788388, 0.036749585531651974, 0.052979953187916956, 0.065121448465756, 0.04125548892521432, 1.5553960523435046, 34.575657095227925, 31.086535794394358, 25.698633364268712, 44.87413460867745, 14.154990025929042, 0.3573088598038469, 0.08688458387873002, 0.07838597348225967, 0.10714829939284495, 0.9938853085041046, 2.8261917190892354, 5.314988034112113, 5.2027524794851026, 3.3825218209198544, 3.193449612174715, 1.9528246521949768, 0.8743127275790487, 2.4272721878119876, 28.777114391326904, 54.32382713045393, 52.12553521565029, 52.07015112468174, 49.06951945168631, 49.10612256186349, 48.13968372344971, 50.223802839006694, 50.13704763139997, 51.46680777413504, 50.0959803036281, 48.322779178619385, 46.70012467248099, 46.064882142203196, 46.629881858825684, 43.74747725895473, 40.20970467158726, 36.57360117776053, 41.12339278629848, 49.165925707135884, 52.063129970005576, 49.372064862932476, 47.52095706122262, 51.22524670192173, 48.33924640927996, 46.045937878744944, 38.06888825552804, 37.088195187704905, 35.93045507158552, 35.78686012540545, 35.24347972869873, 37.54231902531215, 40.02299615315029, 42.52340269088745, 45.537239415305, 48.372934750148225, 47.005484104156494, 47.748121465955464, 46.793136732918875, 49.901830264500205, 48.57744107927595, 42.81805842263358, 43.7153696332659, 43.82048545564924, 48.916568756103516, 47.514780112675254, 47.91614280428205, 46.759924343654085, 46.143087591443745, 46.85987070628575, 45.46325847080776, 40.97884593691145, 34.22103493554251, 35.08624199458531, 33.9933112008231, 34.96735831669399, 35.43644509996687, 34.95387533732823, 37.44019440242222, 40.69415392194475, 42.74498074395316, 45.68206419263567, 42.51658650806972, 41.674589906420024, 36.487940311431885, 36.96889809199742, 33.645213399614605, 34.51846299852644, 35.24725260053362, 39.838608333042686, 41.844931943076, 40.72567095075335, 40.76427166802542, 43.24057837894985, 38.93198653629848, 39.0022189276559, 37.536864689418245, 41.54860169546944, 43.65733480453491, 45.2929025377546, 42.61548716681344, 43.515136446271626, 40.9114796774728, 39.60100078582764, 28.516122681753977, 10.03082161290305, 0.6518460107701165, 2.030502472605024, 2.945427800927843, 2.8761579522064755, 6.534382121903556, 5.63797721692494, 4.528981753758021, 2.0678195101874213, 0.19712390883692674, 0.02496005654601114, 0.045304660219699144, 0.41113498008676935, 10.466044613293239, 41.09544365746634, 26.453016655785696, 29.840338162013463, 14.400700041225978, 0.15086952011500085, 0.014953419033970152, 0.03317358045439635, 0.0034513312649713562, 0.03259842024583902, 0.019315378008676425, 0.0021182039719341056, 0.003886733403695481, 0.06917431099074227, 0.025645573690001453, 0.03735453003485288, 0.026378347405365536, 0.027722927309306603, 0.02733441681734153, 0.030784031176673513, 0.03942396006147776, 0.029855961512242044, 0.05935402972889798, 0.05047722087640848, 0.030779753013380935, 0.01866050689880337, 0.047514665738812516, 0.038650766015052795, 0.031126029789447784, 0.14373125029461725, 0.14513527495520456, 0.1118801176281912, 0.1344209084553378, 0.06225664647562163, 0.1663731224834919, 0.16712449145104202, 0.11150009730564696, 0.13574452671621526, 0.11848909620727811, 0.17381283827126026, 0.10801651887595654, 0.1100757165945002, 0.08562880554901701, 0.22216202744415828, 0.10745201166719198, 0.14740732232374804, 0.0855895048007369, 0.11711764122758593, 0.08187025758836951, 0.14309777000120708, 0.13495962454804353, 0.07061825386647667, 0.1445645862924201, 0.07792566889630896, 0.13314075714775495, 0.12384488167507307, 0.14432465630982602, 0.09059171245566436, 0.14656010349946363, 2.0119429656437466, 40.17966760907854, 38.659023080553325, 28.38215967587062, 45.50788675035749, 19.868992260524205, 1.0770131221839359, 0.289567940469299, 0.23950945373092378, 0.6340828325067247, 7.398699811526707, 9.954780527523585, 9.225202304976326, 9.30546702657427, 7.085106764520917, 5.969016756330218, 4.932768498148237, 0.8730062491127423, 2.316731993641172, 26.387370075498307, 57.67590911047799, 54.04049696241106, 53.93329668045044, 51.65522902352469, 52.81092636925833, 51.00216088976179, 51.62369115012032, 49.14432028361729, 54.18995271410261, 53.154785769326345, 50.58521686281477, 47.94074637549264, 49.183883326394216, 49.67682327542986, 47.858080182756694, 42.17461701801845, 38.12468229021345, 43.98112780707223, 51.96901314599173, 55.10246658325195, 51.77987970624651, 47.94448103223528, 52.26754249845232, 50.122640541621614, 48.523335456848145, 40.40060642787388, 38.46030460085188, 38.79720190593174, 38.87756477083479, 36.46899604797363, 39.568139280591694, 42.710420404161724, 44.56499883106777, 47.58625970567976, 51.69385058539254, 50.36011259896414, 49.79403591156006, 49.79109334945679, 51.537933009011404, 49.21341664450509, 44.553902557918, 44.978969029017854, 46.49879714420864, 51.85648706981114, 48.53375080653599, 50.331190722329275, 48.48898703711373, 48.84457499640328, 49.790756361825125, 46.70385932922363, 41.823034695216585, 36.00090633119856, 37.63967023577009, 35.04261425563267, 38.527858461652485, 35.84519372667585, 37.25703293936593, 39.58133390971592, 42.45790202277047, 44.07816982269287, 46.626254899161204, 43.519055230276926, 42.63399716785976, 39.16204833984375, 38.73178114209856, 35.91797958101545, 35.988521167210166, 35.03138249261038, 40.25034815924508, 42.426926953451975, 42.61183588845389, 42.22613443647112, 44.60144560677664, 40.58270481654576, 40.19916425432478, 38.56337417875017, 43.416322640010286, 45.21358190264021, 47.23070648738316, 43.20151560647147, 43.02048029218401, 44.167631353650776, 43.77889701298305, 29.39638648714338, 8.727091159139361, 0.47246952461344854, 1.6771029787404197, 3.085156943116869, 5.3024309022086005, 6.646853915282658, 9.717002749443054, 9.173759579658508, 9.347272600446429, 2.864768769059862, 0.3504424925361361, 0.20029612790260995, 0.8780199715069362, 13.519345368657794, 45.225748198372976, 30.23243890489851, 37.09545258113316, 16.215085744857788, 0.1717680322804621, 0.0970389215009553, 0.12093251438013145, 0.19145214318164758, 0.113523468375206, 0.09717208399836506, 0.1421995253435203, 0.11662725039890834, 0.20576848568660872, 0.12176654248365334, 0.06368116289377213, 0.21965900675526687, 0.12058129108377866, 0.11378887734775033, 0.10262179228344134, 0.19826681965163775, 0.20520553232303687, 0.14451520251376287, 0.12727391267461435, 0.09264070500752755, 0.07492296144898448, 0.13223488575645856, 0.10638276261410543, 0.11675109661051206], [0.08935446491731064, 0.07780210766941309, 0.06400184532893555, 0.014447291281872561, 0.05428397196478077, 0.04415437372933541, 0.03531506411465151, 0.01813937334476837, 0.05100294641618218, 0.058907119424215386, 0.05188064842617937, 0.06297875022781746, 0.012158280537862862, 0.008064132549666932, 0.034830579933311255, 0.01786204251194639, 0.007941676486682678, 0.006209736631717533, 0.03370570118672081, 0.03842102423576372, 0.06169352347829512, 0.0022353013046085835, 0.01847733637051923, 0.030398877736713206, 0.0314720724709332, 0.033428502668227465, 0.01944844890385866, 0.05922548805496522, 0.06727616355887481, 0.04949543159455061, 0.01489620326486017, 11.257386241640363, 37.11370897293091, 22.363260064806255, 31.630055155072892, 30.810667991638184, 9.181691816874913, 0.6304198833448547, 0.04467382621286171, 0.006909632780921778, 0.6613059288689068, 1.505382810320173, 2.9504105278423856, 2.550504569496427, 2.1826206871441434, 2.663359599454062, 1.116342966045652, 0.6258252784609795, 0.35651437672121183, 6.2237672465188165, 37.02544948032924, 50.039241313934326, 50.8908611706325, 48.520420687539236, 49.35015024457659, 48.41818836757115, 49.78512484686715, 48.522428716932026, 49.662343229566304, 48.85124526705061, 46.58748395102364, 47.70035260064261, 48.154466015951975, 44.42027480261666, 42.226009368896484, 37.597654478890554, 35.38494505201067, 39.37554563794817, 45.1611716406686, 50.03580890383039, 48.22513961791992, 45.43331173488072, 47.95098107201712, 48.51989957264492, 46.796190466199604, 45.16607359477452, 34.89217185974121, 35.32831375939505, 34.70873941693987, 36.53744970049177, 34.80032362256731, 37.81093985693795, 45.2756883757455, 45.805978366306846, 46.160715171269004, 48.13033492224557, 46.29345703125, 48.31518827165876, 44.935469831739155, 43.40878731863839, 37.62560708182198, 47.238196645464214, 47.69298751013619, 47.06141015461513, 47.84087296894619, 44.51335287094116, 45.554015840802876, 44.03470884050642, 43.19386911392212, 36.17656026567732, 34.23631749834333, 33.12227807726179, 33.57208708354405, 32.702791009630474, 34.17397826058524, 34.09718329565865, 34.63541160311018, 33.61175782339913, 35.46341800689697, 39.38494655064174, 37.595264298575266, 37.78966794695173, 36.06940862110683, 33.973918778555735, 34.51558297021048, 35.598171370370046, 35.52730321884155, 34.599941049303325, 33.43365117481777, 30.915856770106725, 33.363589014325825, 34.15921333857945, 35.44398389543806, 34.48149510792324, 36.272942202431814, 38.34482206617083, 41.33191864831107, 41.4692428452628, 42.408378737313406, 42.62468310764858, 43.569287231990266, 36.837069920131135, 28.486339228493826, 5.562468537262507, 0.29683863318392206, 0.1884053988116128, 3.5854417894567763, 2.4034919781344275, 1.5474028012582233, 7.381255490439279, 2.1893122366496494, 2.800117518220629, 1.373836257628032, 0.08655593544244766, 0.012216354653771435, 0.06628500031573431, 3.3962783856051306, 23.36433914729527, 31.14074911390032, 22.023105791636876, 23.199090140206472, 2.152023426124028, 0.09588822788958039, 0.06891137867101602, 0.04204230795481375, 0.006195683747396937, 0.022954083114330257, 0.014529039484581776, 0.03735801770484873, 0.029703243635594845, 0.024419466000316397, 0.06484906415321998, 0.02721096245971109, 0.03172241796606353, 0.058664516013647826, 0.017893821699544787, 0.008373033072400306, 0.03437554417178035, 0.05669656429173691, 0.029740780192826475, 0.027226999634876847, 0.04766930386956249, 0.07519342550741774, 0.022694450171132172, 0.01766074831331415, 0.03879255947789975, 0.05930069009108203, 0.07736343477985688, 0.022151106469599263, 0.03249260610235589, 0.036967659901295385, 0.036376822141132185, 0.04953209962695837, 0.02414823180463697, 0.02930337277108005, 0.042868427732693296, 0.08926204844777073, 0.018866898591763208, 0.05408186013145106, 0.021156267262995243, 0.013808242760465612, 0.029707294489656175, 0.018493259891069362, 0.027577552877898728, 0.007345874394689287, 0.012751862124007727, 0.021822057697655897, 0.0440876092761755, 0.010261805694816368, 0.022235451765092354, 0.07543385082057544, 0.02902816914554153, 0.0240344330003219, 0.05216861868809376, 0.00987675488327763, 0.033387682001505575, 0.08271444336112056, 15.879623242786952, 41.69018166405814, 20.516430616378784, 36.1117057800293, 34.77873904364449, 8.547803316797529, 0.4835825711488724, 0.08112863238368716, 0.048710597279880724, 0.12143910862505436, 1.2261876889637537, 3.591693648270198, 5.535062236445291, 3.0463156444685797, 3.801714675767081, 3.5847398042678833, 1.9066432331289564, 0.6043296147670064, 8.819364973476954, 43.0369371005467, 51.991296018872944, 53.22134951182774, 49.365967818668906, 51.08468117032732, 48.761099338531494, 51.060834952763145, 49.189758028302876, 51.30917051860264, 49.8909250668117, 49.913200991494314, 48.64609622955322, 48.41168485369001, 46.33327368327549, 44.34494590759277, 39.59696735654558, 36.78730344772339, 40.9213878086635, 48.50348097937447, 51.52408177512032, 48.60535199301583, 46.3646274294172, 48.8242758342198, 47.80793155942644, 47.9809764453343, 45.22617551258632, 36.393879073006765, 35.90147066116333, 37.279909883226665, 37.807239941188264, 35.60009602137974, 39.6711984361921, 46.497046198163716, 48.27260276249477, 48.08657169342041, 48.09108107430594, 48.891999925885884, 48.47289500917707, 47.1424435206822, 44.80711228506905, 39.67554800851004, 48.87231567927769, 49.41951411111014, 49.416991915021626, 48.813923018319265, 47.57068531853812, 47.301654543195454, 45.519670895167756, 44.11006900242397, 38.54107393537249, 35.79508331843785, 34.73186649594988, 35.34484004974365, 34.05534471784319, 36.24619163785662, 34.65508542742048, 36.539801665714805, 35.8084169115339, 37.825676986149375, 40.06439699445452, 41.37327085222517, 39.30451767785208, 38.546542167663574, 35.2499589238848, 35.438560826437815, 36.6650846345084, 35.53638798849923, 35.63246420451573, 34.06967885153634, 33.481048311506, 35.01626321247646, 36.81480441774641, 37.54052291597639, 37.60961580276489, 37.35073981966291, 39.348527567727224, 42.32553536551339, 42.56697831835066, 44.95866986683437, 42.5571848324367, 42.668376854487825, 40.54461131777082, 32.28662518092564, 9.38204312324524, 0.5936913256134305, 1.1518778992550713, 2.383000437702451, 4.965473668915885, 4.814081975391932, 5.432044770036425, 5.959798668112073, 4.320907524653843, 0.4496468906956059, 0.11798193199293953, 0.046988963947764466, 0.09204493090510368, 2.7605216886316026, 25.351213012422832, 34.39838770457676, 23.20085324559893, 28.818645511354717, 3.9305794409343173, 0.09116998713995729, 0.013052828876035554, 0.03387396769332034, 0.02722891479996698, 0.05031409427257521, 0.015542697859928012, 0.011253936698527207, 0.029931977790381228, 0.07395410165190697, 0.14274008705147676, 0.00945442620598312, 0.019145074200683405, 0.03263522059257541, 0.05145484395325184, 0.02764709762829755, 0.02925847750157118, 0.070597307490451, 0.06179340383304017, 0.007583631368886147, 0.031398471777460406, 0.06715528254530259, 0.07832387395735298, 0.038078835633184226, 0.023111808579415083, 0.15618563842560562, 0.1716816412018878, 0.16180933666016373, 0.07392959296703339, 0.13017570839396544, 0.10305095211203609, 0.12604374225650514, 0.062391315320772786, 0.16611048871917383, 0.1542065553367138, 0.1954550655292613, 0.12981711620731012, 0.09268430088247571, 0.05513831879943609, 0.10883597204727785, 0.10193558981908218, 0.1558038539120129, 0.1317989541483777, 0.07081228774040937, 0.15938999290977204, 0.13072256690689496, 0.230906036815473, 0.09662347486508743, 0.10117026338619844, 0.19019316216664656, 0.08026134249355112, 0.1340541738484587, 0.13590818936271326, 0.19039160651820047, 0.2069904458309923, 0.15057735650667123, 16.825865404946462, 50.74324321746826, 30.2732560975211, 39.75138412203108, 40.35243109294346, 12.558040380477905, 1.0186632360730852, 0.32514790126255577, 0.1258371283433267, 1.421097253050123, 6.354250941957746, 9.156567999294825, 7.776145935058594, 8.082905428750173, 9.001190645354134, 5.436923273972102, 2.941608028752463, 0.7622447982430458, 7.4650967972619195, 40.77052852085659, 54.50041559764317, 55.65912846156529, 50.88352734701974, 53.848945549556184, 50.560988494328086, 53.19058983666556, 50.212682247161865, 52.94375160762242, 52.36802387237549, 50.11444514138358, 50.82850456237793, 53.18670579365322, 48.47525044849941, 46.70495367050171, 41.84486940928868, 38.69303798675537, 42.80618742534092, 49.94211591993059, 53.23812941142491, 48.797990798950195, 46.84078400475638, 51.64211777278355, 51.52362666811262, 49.602213518960134, 49.64618519374302, 38.58094964708601, 37.73825127737862, 40.569256578172954, 42.280545779636924, 37.01446785245623, 41.561122349330354, 49.30280869347708, 49.503531728472026, 49.414184842790874, 50.52305480412075, 50.49391058513096, 51.36171279634748, 46.49173777444022, 45.60927139009748, 40.789236545562744, 52.564949716840474, 50.95325599397932, 51.31434692655291, 51.636128425598145, 49.13766738346645, 48.758108139038086, 47.18885748726981, 46.83687564304897, 39.48096023287092, 36.50923306601388, 36.264409814562114, 37.13542556762695, 35.879601206098286, 37.37330756868635, 36.97979981558663, 37.94321618761335, 37.42129530225481, 39.45859398160662, 41.920920916966026, 41.40450300489153, 41.347892556871685, 40.10264335359846, 37.2098650932312, 37.32386418751308, 40.82848344530378, 38.12913955960955, 37.7091383252825, 36.53535829271589, 34.51673984527588, 35.97818572180611, 37.94986908776419, 39.421528816223145, 39.46197428022112, 38.532367842538015, 41.58679941722325, 44.21362842832293, 45.33902815410069, 45.50763314110892, 43.54445437022618, 43.75865691048758, 39.999591146196636, 30.607429708753312, 7.070940256118774, 0.6985153779387474, 1.7304000045572008, 7.768713099615915, 6.950701679502215, 6.522555419376918, 17.73885175159999, 7.618384480476379, 10.825038926942007, 4.3429029158183505, 0.48335572332143784, 0.16707961314490863, 0.23942086419888906, 4.847655670983451, 30.037746906280518, 40.585018566676546, 29.126872811998638, 36.09751755850655, 4.745828517845698, 0.25369129702448845, 0.1375104005315474, 0.1312539955335004, 0.1249761488288641, 0.117613107498203, 0.08473475423774549, 0.12407825700938702, 0.09325542380767209, 0.2020240444689989, 0.24040544565234864, 0.11056874013905015, 0.09616580299500908, 0.15992094656186445, 0.1344226590756859, 0.17572376930287906, 0.06891537524227585, 0.18056020406740053, 0.22726002388766833, 0.09668946918100119, 0.13808872949864182, 0.16720442287623882, 0.13101572117635182, 0.09775862323918513, 0.1053592332505754], [0.033499742059835365, 0.02583849985551621, 0.025196848304143975, 0.012141961770664369, 0.02409926362867866, 0.012693643819407692, 0.0687446626169341, 0.0383327773639134, 0.09592730472130434, 0.02278528904675373, 0.012239973609601813, 0.003545145516649687, 0.03519555034914187, 0.013123522895122213, 0.05313082205663834, 0.028379116473453384, 0.015024202110778009, 0.04124056115480406, 0.03534411219879985, 0.01744439233360546, 0.03626735408657363, 0.016701941012537906, 0.09964298962482385, 0.04372718504496983, 0.0040392672277188724, 0.020280689067606415, 0.06942997620041881, 0.04294291052169033, 0.01974466845526227, 0.01425758985403393, 0.03044384085972394, 0.9972991538899285, 23.38865610531398, 34.58595779963902, 30.22917672566005, 33.68139961787632, 28.581060545785085, 9.163332070623126, 1.1528045066765376, 0.06902936912540879, 0.050178285488592725, 0.34594828369362013, 4.024566420486995, 5.480433762073517, 1.3879437063421523, 1.8063717165163584, 1.5088402990783965, 1.0126522843326842, 0.778515416596617, 1.2447923592158725, 15.984214476176671, 38.847069127219065, 48.874334130968364, 53.625564438956125, 50.378553118024556, 51.07821934563773, 50.79282903671265, 47.68503877094814, 49.697535855429514, 49.95199973242623, 48.19629764556885, 50.306191103799, 46.884505544389995, 46.695226192474365, 43.906591006687705, 38.44635956627982, 37.29499789646694, 39.49981069564819, 44.31231369291033, 49.58157736914498, 49.987668309892925, 48.97694512775966, 46.10968065261841, 50.3526154926845, 48.79988070896694, 47.56715563365391, 42.318621907915386, 33.8161495072501, 35.04204797744751, 36.735317025865825, 36.103128228868755, 39.12733513968331, 45.413036891392295, 48.565062863486155, 49.708864893232075, 49.43600566046578, 47.40316425051008, 47.17594426018851, 45.09886714390346, 46.324383463178364, 41.43002026421683, 49.9657814843314, 47.42572157723563, 46.30465752737862, 45.78661373683384, 40.196760177612305, 38.9979944229126, 36.35231147493635, 34.7438382421221, 33.27085835593087, 34.32578250340053, 34.10642439978463, 34.192748819078716, 34.960562978472026, 35.449570247105186, 34.86384752818516, 35.140889576503206, 34.456933225904194, 33.094839641026084, 33.29009096963065, 34.0700227873666, 36.154597009931294, 37.68468066624233, 38.14886202130999, 40.379445689065115, 42.97342709132603, 43.78701598303658, 44.048296042851035, 40.38844360624041, 34.09735700062343, 30.794617652893066, 31.83907433918544, 33.994791167122976, 34.599805559430806, 36.86261149815151, 40.454882281167166, 42.877382142203196, 43.02142177309309, 44.02808025905064, 41.70209435054234, 42.42276150839669, 28.400341374533518, 5.393453172274998, 0.22686883487871715, 0.1400475108197757, 1.265102703656469, 1.4869946198804038, 5.017468776021685, 3.684109900678907, 6.262130856513977, 14.643811430249896, 2.2456428025450026, 0.43083127747688976, 0.1281280389853886, 0.0065921521828775954, 1.6523926875420978, 15.32652405330113, 33.14061437334333, 27.42779333250863, 24.42699490274702, 14.20793616771698, 0.03019477779577885, 0.027870610456115434, 0.0588965682046754, 0.04705447650381497, 0.03748721755774958, 0.03550359167690788, 0.04840686804215823, 0.0319990058030401, 0.05206020575548921, 0.05596200263659869, 0.03502960782498121, 0.07847711430596453, 0.015376790958855833, 0.02351014595478773, 0.02603703920197274, 0.03168987881924425, 0.03482211520895362, 0.012210992530786564, 0.031321257885013304, 0.026310120709240437, 0.09534334391355515, 0.031611945679677386, 0.006950059049164078, 0.05371378202523504, 0.02686090624359037, 0.041711060729409964, 0.029530339342142855, 0.02899958925055606, 0.032898814483944855, 0.031419536897114346, 0.04387259849214128, 0.04887046352294939, 0.12086236742990357, 0.0755303588562778, 0.04335169394367507, 0.020558052130841782, 0.04581998381763697, 0.03474002943507262, 0.04311450184988124, 0.046124204993247986, 0.04454592575452157, 0.05431422105591212, 0.0534311552265925, 0.035689245643360276, 0.03558716004980462, 0.04458422227097409, 0.0192975189669856, 0.039694010213549645, 0.03722134378871747, 0.0292402927630714, 0.0179385727803622, 0.04530461272224784, 0.06907985891614642, 0.012140917674904423, 0.06978765915014915, 0.0748784699078117, 2.2103720094476427, 30.998679297310964, 35.65704345703125, 29.206325462886266, 41.57026965277535, 32.46822329929897, 8.215688977922712, 0.8957535656435149, 0.03157941331820829, 0.0711660555430821, 0.06940160665128912, 2.651179624455316, 6.171618844781603, 4.070498790059771, 3.7924470816339766, 3.0599914363452365, 1.7390584370919635, 1.4451337861163276, 2.155067388500486, 19.072530678340367, 42.47850343159267, 50.856599603380474, 54.974088191986084, 51.326443740299766, 53.30055202756609, 50.136019298008506, 47.47122185570853, 48.934199810028076, 51.53964226586478, 49.72215679713658, 52.12828670229231, 48.4931629044669, 47.38292762211391, 44.24137258529663, 39.82523652485439, 40.00141504832676, 41.246997765132356, 45.90128680637905, 50.15345580237252, 49.025506087711875, 48.25707006454468, 47.520185811179026, 51.37087747028896, 50.32539592470442, 48.987176350184846, 42.26390831811087, 35.705361230032786, 36.83488471167428, 37.85164935248238, 37.78967489515032, 40.72233928952898, 46.39502579825265, 50.77946765082223, 50.67370217187064, 51.58519465582711, 49.1666830607823, 47.30484029224941, 45.80375146865845, 46.6828236579895, 42.34778002330235, 50.08020094462803, 48.916815417153494, 48.33397620064871, 47.16386134283883, 43.37198618480137, 40.92936781474522, 38.4234687260219, 36.578433649880544, 36.04952982493809, 35.46640920639038, 35.11781808308193, 36.03389637810843, 36.11671890531267, 36.88516535077776, 36.20642014912197, 36.62463917051043, 36.30253110613142, 35.740699768066406, 34.71289096559797, 35.745473180498394, 37.709020205906455, 39.517479964665, 39.36300066539219, 40.3843754359654, 41.935585090092246, 43.78668941770281, 44.55447578430176, 41.002956186022075, 34.62207106181553, 32.10387366158621, 34.04420328140259, 35.7686836378915, 35.274524280003135, 37.9784574508667, 40.77768863950457, 43.592223235539024, 44.82913112640381, 44.803540910993306, 42.1682003566197, 43.00144917624337, 31.36663157599313, 8.591580442019872, 0.8256900480815342, 1.1603883568729674, 2.87565746477672, 3.3870772336210524, 6.093453781945365, 5.546212358134134, 12.609948635101318, 14.110442519187927, 2.040276199579239, 0.10339551897985594, 0.04091658443212509, 0.01591261479604457, 1.277594587632588, 17.198113407407487, 36.646185534340994, 30.835031849997385, 26.66381631578718, 19.624090841838292, 0.26781584482107845, 0.03513733543721693, 0.07032539815242801, 0.05558208409430725, 0.012766819580325058, 0.020105845860338638, 0.024969766382128, 0.059930363803037574, 0.0331148668192327, 0.07493343124432222, 0.05895931233784982, 0.02702831949240395, 0.025450650935194323, 0.027564631874806116, 0.02175030092309628, 0.03865920699068478, 0.023716803972742388, 0.010120728934582855, 0.033364072375531705, 0.021452223882079124, 0.022324651978643875, 0.003693244478199631, 0.038310076974864514, 0.048669522162526846, 0.006454919747609113, 0.15906744450330734, 0.13517984987369605, 0.08357691565262419, 0.19968497141131333, 0.07383072362946612, 0.1304646557463067, 0.1817882303148508, 0.18797356555504457, 0.28477026362504276, 0.07139901697103467, 0.07750540466180869, 0.07333364244550467, 0.08372223749756813, 0.11977373941668443, 0.1062800120562315, 0.1445679111140115, 0.1284408571996859, 0.14657390490174294, 0.08481739301766668, 0.129478907212615, 0.15908486928258622, 0.11570964035178934, 0.17677141380097183, 0.12057902477681637, 0.10753795491265399, 0.1959549422774996, 0.15699802126203263, 0.14899166088019097, 0.08717207916613136, 0.17490013635584287, 0.19365511568529264, 1.9574847221374512, 34.03806802204677, 45.16642795290266, 38.43851157597133, 42.93885980333601, 36.97035026550293, 13.147349238395691, 1.8781538818563734, 0.3370706300650324, 0.3658286269221987, 1.4548133867127555, 13.112362452915736, 18.264251947402954, 7.01851783479963, 6.130271417754037, 5.161090212208884, 5.235512367316654, 2.2608519749982015, 2.2804558830601827, 17.526716300419398, 40.085144315447124, 51.22949205126081, 57.0659476007734, 52.697514397757395, 54.392186982291086, 52.70797838483538, 49.929407664707725, 49.54709345953805, 54.49279342378889, 51.58296428407942, 53.605327810559956, 50.72769314902169, 50.59321771349226, 46.05678749084473, 43.17705447333199, 41.3890780040196, 43.5655699457441, 47.410498074122835, 53.172795500074116, 53.22874934332711, 50.634476116725374, 48.677773066929404, 55.34888097218105, 52.575823647635325, 51.16472094399588, 45.65017196110317, 37.26054177965437, 37.919515882219585, 40.017177036830354, 40.67500121252877, 43.81145627158028, 48.2155441556658, 51.83374214172363, 51.92624350956508, 52.47325086593628, 50.803518840244834, 47.94747917992728, 46.50693695885794, 48.62855550221035, 46.932833739689414, 50.58376816340855, 49.217418806893484, 51.655312401907786, 49.260219710213796, 44.83627734865461, 41.80308641706194, 40.44010693686349, 36.5175187928336, 36.81792763301304, 37.0949627331325, 37.34511872700283, 38.720532008579795, 38.614089080265586, 38.755366802215576, 39.12005690165928, 37.75604561397007, 39.50370863505772, 36.462145124162944, 37.030980246407644, 38.21012428828648, 41.620491232190815, 42.140970366341726, 42.409372329711914, 42.64505870001656, 45.822390011378694, 46.05637754712786, 47.32483720779419, 43.863091809409006, 37.65480688640049, 33.925295284816194, 35.519569873809814, 37.50188398361206, 37.59877661296299, 40.02886390686035, 44.427851813180105, 45.58945165361677, 47.58414397920881, 45.808601311274934, 41.47208118438721, 43.426699774605886, 30.340118612561906, 6.9031542880194525, 0.5872146817190307, 0.9571584335395268, 3.7352998852729797, 5.859298186642783, 12.269749198641096, 10.043917230197362, 11.236173391342163, 23.3133602142334, 5.369962181363787, 0.8047280386090279, 0.2837207870823996, 0.12992796168795653, 2.5601827587400163, 19.689426490238734, 42.342940602983745, 36.10359375817435, 33.71396235057286, 23.940648794174194, 0.3665764810783522, 0.29263901710510254, 0.12439260871282645, 0.12931833868580206, 0.18362665309437684, 0.1457204706966877, 0.20428828868482793, 0.10556765206690345, 0.16031497184719357, 0.0856794717588595, 0.1486909884427275, 0.23048762498157366, 0.13241222766893251, 0.19611545652151108, 0.11817660368978977, 0.11162956857255527, 0.12369685247540474, 0.029801057851208106, 0.07872707303613424, 0.09311905183962413, 0.14883151304508957, 0.13671480465148175, 0.13111386448144913, 0.20607149228453636, 0.08429399824568204], [0.02652462089567312, 0.005658026169320303, 0.025649471873683587, 0.044810683333448, 0.013360710748072182, 0.015515666721122605, 0.043819967923419814, 0.057859936329935274, 0.004576278925274632, 0.0280766357401652, 0.02036713951799486, 0.023399848391168883, 0.05903977302036115, 0.030514238867908716, 0.047992439208818335, 0.015253377313326513, 0.0045750240595745185, 0.029204907161848884, 0.06908236271036522, 0.05609928384157164, 0.04118497556607638, 0.013522175789278532, 0.02070038842170366, 0.024814290260629993, 0.029169942252337933, 0.013750971860385366, 0.012159535827647363, 0.0683962009581072, 0.013323113970857645, 0.023336943105927536, 0.013202828371764293, 0.0668225289721574, 4.441785769803183, 28.665861572538102, 29.671715804508754, 22.108681542532786, 31.880409172603063, 29.693175315856934, 10.737869432994298, 1.4748452603816986, 0.018447165310915028, 0.07544090758476939, 0.45207536752734867, 4.487398956503187, 2.449701189994812, 2.2520622866494313, 2.5251977103097096, 0.6490339445216315, 0.500525427716119, 0.22877777101738112, 2.614202614341463, 18.277580329350062, 35.159000056130544, 49.3180113519941, 51.23559604372297, 50.920325006757466, 49.24573966435024, 47.87923049926758, 47.203792640141074, 48.02304778780256, 49.089495522635325, 49.7457389831543, 47.55337388174874, 45.55011095319475, 42.76319892065865, 36.33285999298096, 36.23509883880615, 39.03622688565935, 42.6424948147365, 45.67576912471226, 48.53517518724714, 49.55765472139631, 48.0071051461356, 46.56563534055437, 49.34818737847464, 48.30886888504028, 48.215453829084126, 40.67028685978481, 33.78245769228254, 36.095412254333496, 35.88062259129116, 35.04055758884975, 45.833583559308735, 49.70006152561733, 48.416274138859336, 49.01403113773891, 49.7661771093096, 48.22614363261631, 46.40904031481062, 46.02785866601126, 42.288119316101074, 52.628053256443565, 49.66427482877459, 46.41946956089565, 43.133204392024446, 38.831717082432334, 34.595146792275564, 34.17988075528826, 34.09846523829869, 33.0351094518389, 33.50001341956002, 34.39706754684448, 34.15093803405762, 34.0097610609872, 37.92768348966326, 38.249249594552175, 36.54086126599993, 36.17451054709298, 34.750383445194785, 34.50384051459176, 34.90472725459507, 39.93525430134365, 41.24616745540074, 42.175520283835276, 45.29791566303798, 45.205674852643696, 44.03470189230782, 44.84077630724226, 43.63249499457223, 39.45820140838623, 34.33206367492676, 32.82331793648856, 35.72583062308175, 37.30305085863386, 39.983916010175435, 42.69347027369908, 41.06458670752389, 43.38985000337873, 44.43780510766165, 43.68396724973406, 28.117155381611415, 5.043741217681339, 0.23603570727365358, 0.8773557671478817, 2.562089822122029, 2.1724259427615573, 0.9508421953235353, 3.857310252530234, 6.453736986432757, 8.789219345365252, 8.730983018875122, 2.4398720945630754, 0.1006601271884782, 0.06413246332002537, 0.6910126262477466, 9.436114873204913, 24.388628687177384, 32.942312785557334, 21.19791340827942, 23.670502832957677, 3.3912706886019026, 0.08894372052912201, 0.033071379509887526, 0.04196960971291576, 0.0844241955450603, 0.02671727055816778, 0.13817556841032846, 0.08153194681342159, 0.016490662171106254, 0.025343793544120023, 0.031184119172394276, 0.057086508188928874, 0.05100671907088586, 0.04460284805723599, 0.021389447518491318, 0.021351145913026164, 0.05724871877048697, 0.0182294217270932, 0.016093485090615492, 0.056004482321441174, 0.03987895171823246, 0.03520325172160353, 0.014491341775283217, 0.06124237911509616, 0.017456449900886843, 0.03370198620749371, 0.011124814877153506, 0.04381022076787693, 0.022480635305068324, 0.059003349260560105, 0.025745613500475883, 0.027573768348832215, 0.040486332162150314, 0.05646270719755973, 0.018141519211764847, 0.03291825111955404, 0.012151234799862971, 0.07719437777996063, 0.020314590373475636, 0.01591866054306073, 0.06900656356343202, 0.01772001325818045, 0.016351128229871392, 0.0134683365800551, 0.024623026505910924, 0.058470312505960464, 0.10092878634376184, 0.020873867773583958, 0.05991821802620377, 0.07219474177275385, 0.042062317952513695, 0.039136393527899466, 0.050343420556081195, 0.020604402857965658, 0.011036039596157414, 0.03172711342839258, 0.017822921575446213, 0.00940382615330496, 8.373517308916364, 36.253254481724326, 33.47255066462925, 26.858942576817103, 38.791518279484336, 32.77751888547625, 9.293342420033046, 1.6544673762151172, 0.05131814968107002, 0.03400816495663353, 0.26889012860400335, 2.0151688839708055, 4.084094677652631, 3.3024433978966306, 3.9793523209435597, 2.359885952302388, 2.1940882546561102, 0.7258393317461014, 4.662536987236567, 21.291253771100724, 38.10084996904646, 51.762036732264924, 51.57886484691075, 52.10049390792847, 49.004119532448904, 46.82596002306257, 48.44495630264282, 48.88539218902588, 50.04061358315604, 49.76750421524048, 50.36695657457624, 46.80723810195923, 44.7062383379255, 37.2083295413426, 38.789770807538716, 40.788242953164236, 44.62975951603481, 47.755128724234446, 49.71047340120588, 51.89397260120937, 49.27033976146153, 48.42272206715175, 51.182237352643696, 49.40272031511579, 50.24048893792288, 41.174528053828645, 36.04062223434448, 39.158150400434224, 38.62896864754813, 37.24430383954729, 47.28586823599679, 51.80944429125105, 50.314400400434224, 50.68840456008911, 49.86774935041155, 49.64503526687622, 45.32469402040754, 44.83164290019444, 44.746197428022114, 52.50200251170567, 51.47258172716413, 47.193408557346885, 43.7775490624564, 40.42996604101998, 36.477007320949006, 36.304636410304475, 35.2317407471793, 34.55754314150129, 35.362954003470286, 35.35198974609375, 34.01650776181902, 35.81503507069179, 38.4346900667463, 39.5835851260594, 37.776403835841585, 36.95234400885445, 36.205568994794575, 36.36983483178275, 36.92455121449062, 40.5737555367606, 41.80950655255999, 42.58235815593174, 46.53468458993094, 48.06854806627546, 44.999858788081575, 45.906223501477925, 45.1787679536002, 41.22765050615583, 35.61793204716274, 34.32628277369908, 37.62336976187569, 38.178829601832796, 40.59908866882324, 42.30513892854963, 43.60729040418352, 44.126880168914795, 45.5718275478908, 43.40021324157715, 31.307769911629812, 7.884514382907322, 0.6468702320541654, 2.1897319512707845, 5.094028804983411, 2.760398792369025, 2.691282021147864, 3.7827126554080417, 7.510984437806266, 9.857225213732038, 7.01751903125218, 1.258082091808319, 0.05220811960420438, 0.2462340071797371, 0.6776276273386819, 10.21106309550149, 26.960419280188425, 35.66168485369001, 24.314147472381592, 28.95088015283857, 6.34346125807081, 0.13442458611513886, 0.053830927703529596, 0.022476984786667993, 0.06514712423086166, 0.0204944869702948, 0.06937529984861612, 0.040949513736580095, 0.07888526669038193, 0.04369588761723467, 0.06893949037683861, 0.0075708375911095315, 0.028433557034337094, 0.00649480233966772, 0.06268094120813267, 0.015428753170583929, 0.0736447846783059, 0.04561586691332715, 0.043459048361650536, 0.013138591461548848, 0.030938394500740936, 0.01356476912873664, 0.0211628660160516, 0.03191676735877991, 0.03012816601299814, 0.03558746539056301, 0.11063405591994524, 0.0783815426485879, 0.1949190500059298, 0.1311270416315113, 0.1134944474324584, 0.07923724994595562, 0.1673536870096411, 0.14062365490411008, 0.07817608903029136, 0.19214882222669466, 0.103845611613776, 0.12842521018215589, 0.11760896843458925, 0.13604627123900823, 0.11877474587942873, 0.14004107830779894, 0.07722579395132405, 0.08801908085920981, 0.15654253427471432, 0.3294593670538494, 0.16060773256633962, 0.1479705199599266, 0.1403918537710394, 0.12246969475277833, 0.12747802957892418, 0.10345510113984346, 0.11207116594804184, 0.22139032956744942, 0.0636765556409955, 0.08581143324928624, 0.1281718723475933, 0.14900909923017025, 7.632030742509024, 42.27761711393084, 41.08218649455479, 31.26305477959769, 40.62073578153338, 38.07198715209961, 14.261699591364179, 2.8363443400178636, 0.18476777257663862, 0.33846515523535864, 1.6359706201723643, 10.031360966818673, 8.497342893055507, 7.33031564099448, 7.609448228563581, 4.004260310104915, 2.6057772721563066, 0.6016627550125122, 3.5601082231317247, 19.667199202946254, 38.90346418108259, 51.90449912207467, 53.696060861860005, 52.7520751271929, 50.222329820905415, 47.525535924094065, 48.09943280901228, 49.23329544067383, 50.76196166447231, 53.59961291721889, 52.29500872748238, 49.30763421739851, 47.28188691820417, 39.35183143615723, 39.94769157682146, 42.974417209625244, 47.47867032459804, 48.81536476952689, 51.72774389811924, 53.446933201381135, 51.97410617555891, 47.53623962402344, 52.395761081150596, 51.539666584559846, 53.25288391113281, 44.04619421277727, 37.5783280645098, 40.91023594992501, 39.320786884852815, 38.393699169158936, 48.928196566445486, 52.61555344717843, 51.71356609889439, 52.00115898677281, 52.88830845696585, 50.965241636548726, 45.5962678364345, 45.11627238137381, 46.581484181540354, 54.94972433362688, 53.96192325864519, 50.3966566494533, 45.66848393848964, 41.771798678806846, 38.073380265917095, 37.26310913903372, 37.650787353515625, 35.74749510628836, 36.54583270209176, 37.26441192626953, 36.21357331957136, 38.41448817934309, 40.85855524880545, 42.3726406778608, 39.7342255456107, 39.14120374407087, 38.295364788600374, 38.541181632450645, 37.82272400174822, 42.50964525767735, 43.95334543500628, 44.9785521371024, 48.95136533464704, 48.95772293635777, 46.86281326838902, 46.2738596371242, 46.93500852584839, 42.93965884617397, 37.38447332382202, 35.444383416857036, 40.06198249544416, 39.22963694163731, 43.1183317729405, 45.233241830553325, 45.04977464675903, 46.549241065979004, 46.17675856181553, 44.781449113573345, 32.318124839237754, 6.693401634693146, 0.544287190905639, 3.0203052801745276, 6.7422961081777295, 5.808558097907475, 5.646141784531729, 8.750735878944397, 16.32623781476702, 16.470506736210414, 13.21757902417864, 5.687493988445826, 0.2298041773693902, 0.3007773389773709, 1.3156604021787643, 12.323298965181623, 31.626209327152797, 41.04317930766514, 28.885723420551844, 34.23852007729666, 7.459833536829267, 0.20299776936216013, 0.18369637935289315, 0.09947614464908838, 0.14922487336610044, 0.08272458067429916, 0.24329212361148425, 0.18152855496321404, 0.21906089170702867, 0.10032049327024392, 0.1261205252792154, 0.18522502375500544, 0.11923488761697497, 0.12261958313839776, 0.1736337457384382, 0.07167331475232329, 0.18253854076777185, 0.12177414207586221, 0.15734879672527313, 0.13643144842769417, 0.10712035053542682, 0.11810786809240069, 0.0648360498515623, 0.16929303508784088, 0.12672876406993183, 0.12491095518427235], [0.0424670030229858, 0.040803279262036085, 0.03821571310982108, 0.016595731622406414, 0.026827490090259483, 0.04419831904981818, 0.020599444463316883, 0.03925634834117123, 0.047913528978824615, 0.032178440996046574, 0.029495150516075746, 0.04490560020453163, 0.048568742748882086, 0.019440386211499572, 0.015195038568760668, 0.008547081545527493, 0.021346575979675566, 0.03476180362382105, 0.013509032565967312, 0.05082472240818398, 0.03124427469447255, 0.05139247301433768, 0.0325055016603853, 0.052404884581587145, 0.06335443471159254, 0.0469618836151702, 0.04168984293937683, 0.05122445756569505, 0.004331296825382326, 0.1143820865878037, 0.010769675585574337, 0.022483600503099815, 0.24260126639689716, 11.59662856374468, 30.75443274634225, 29.75196749823434, 26.548637764794485, 35.06561279296875, 32.98542635781424, 10.073821408408028, 1.175184654338019, 0.05608122463205031, 0.09957320908350603, 1.3660171457699366, 2.317802667617798, 2.6076654451234, 2.75507321528026, 1.633040760244642, 1.393663268004145, 0.743830280644553, 0.5819870308041573, 3.9471508945737566, 14.718066828591482, 28.492333786828176, 40.87549148287092, 47.80053520202637, 49.46558066776821, 47.72738456726074, 48.27799456460135, 49.24635110582624, 50.308063643319265, 50.5107148034232, 49.078503472464426, 46.63019105366298, 41.44998591286795, 40.752577849796836, 37.76626293999808, 38.448339802878245, 41.247331278664724, 45.4001201902117, 49.32466425214495, 49.642902169908794, 50.709527083805625, 48.587366580963135, 49.07363625935146, 49.85305391039167, 48.43614946092878, 45.48721585954939, 36.703758307865684, 35.038844857897075, 36.45433187484741, 35.57775061471121, 38.37969160079956, 47.287987436567036, 48.39811849594116, 49.84985773903983, 49.810249532972065, 49.50635617119925, 46.93836450576782, 47.27265623637608, 42.85549184254238, 49.39340625490461, 47.74206263678414, 44.3302435193743, 46.430937562670024, 43.43091038295201, 38.74849850790841, 36.69872086388724, 34.75555637904576, 35.62742328643799, 35.57354695456368, 34.13645451409476, 33.90371070589338, 37.759425912584575, 39.39206845419747, 39.92125368118286, 40.31405619212559, 36.66847882952009, 34.92389733450753, 35.44185774666922, 40.28952905109951, 43.94111313138689, 43.45239421299526, 45.591136591775076, 45.570854800088064, 44.67968232291085, 45.135407720293315, 47.03358261925833, 44.870306151253835, 43.10355295453753, 35.84741020202637, 34.2794623374939, 36.84221853528704, 39.14503220149449, 41.58632346561977, 43.10611683981759, 42.31078086580549, 44.20508214405605, 44.43199988773891, 31.969776902879985, 7.64516544342041, 0.33314777484961916, 0.5177690110036305, 1.7644766845873423, 3.973387292453221, 1.4123646702085222, 2.138335040637425, 2.965001093489783, 2.4450293949672153, 9.31189411027091, 4.67763238293784, 0.28820975763457163, 0.10032037113394056, 0.8446441910096577, 7.925323758806501, 23.99669122695923, 36.63761840547834, 25.105260678700038, 25.086260829653057, 14.209724460329328, 0.054886517846690755, 0.060907854565552304, 0.03321078113679375, 0.03299967532179185, 0.044524738498564274, 0.015826508702178086, 0.02690953515203936, 0.044133943039923906, 0.05359650403261185, 0.024507658589365225, 0.045699109589414935, 0.020012177493689314, 0.02206942272771682, 0.008599628145540399, 0.03193139996645706, 0.054821415804326534, 0.05750732882214444, 0.014370833955971258, 0.008280716686775642, 0.029886536300182343, 0.05469991732388735, 0.0269161152453827, 0.020106449756505232, 0.05325021707851972, 0.023714434189189757, 0.01887155673466623, 0.05882194292332445, 0.007132232555055192, 0.006669522562463368, 0.026260265348745242, 0.03891032601573637, 0.004463071718678943, 0.0099715784557962, 0.028807550269578184, 0.01123514467118574, 0.030149404159081832, 0.009627749494809126, 0.029100056538092237, 0.04793390877810972, 0.06771887373179197, 0.014116112758139414, 0.0149126797914505, 0.015435311211539167, 0.0418919751287571, 0.026366985336478268, 0.010781108900638563, 0.06314408207046134, 0.024289543507620692, 0.01983196707442403, 0.04058723710477352, 0.03569766965561679, 0.021773762967703596, 0.022117703886968747, 0.0048236744894113925, 0.009681728651880153, 0.017477727062734108, 0.06858682858624629, 0.03592605436486857, 0.37728189091597286, 17.683419023241314, 35.30840369633266, 27.495949949537003, 28.367577144077845, 42.56847218104771, 36.22669846670968, 9.228619950158254, 1.038537472486496, 0.023237525851332715, 0.1273051252854722, 0.1177369129977056, 1.8808406633990151, 2.230236909219197, 6.707263290882111, 8.037862862859454, 4.0484035185405185, 2.0830558240413666, 1.2564291805028915, 6.687332383223942, 18.687812396458217, 31.443916388920375, 44.2749844959804, 48.845711026872905, 49.01548678534371, 48.03433861051287, 48.157630920410156, 49.61159706115723, 52.00695031029837, 51.09028489249093, 51.00885547910418, 48.66759395599365, 44.74918515341622, 41.293491636003765, 39.338150433131624, 41.38075753620693, 43.61646202632359, 46.94017798560006, 50.870159012930735, 51.963399001530235, 51.664143562316895, 48.99364512307303, 50.55070168631417, 51.332464354378835, 51.32105541229248, 46.84695747920445, 38.403843539101736, 36.094818183353965, 37.699563707624165, 36.73860352379935, 41.11499241420201, 49.231259618486675, 49.33691392626081, 51.227897439684185, 50.458669321877615, 52.58712836674282, 48.007848603384836, 47.16551154000418, 44.138806751796174, 49.814870085035054, 49.53889111110142, 46.15607724870954, 47.10079254422869, 44.456398487091064, 40.399810859135215, 37.997551100594656, 36.858852522713796, 37.4026254926409, 36.14769744873047, 35.658214228493826, 35.004527705056326, 40.369516713278635, 40.81848151343209, 41.17145347595215, 40.00743566240583, 37.326327323913574, 36.50976807730538, 37.93038633891514, 41.253577709198, 44.602734497615266, 44.67233460290091, 47.456675801958355, 46.442565373011995, 46.22414180210659, 46.54296684265137, 46.78134216581072, 46.07053797585623, 43.860809326171875, 38.503039496285574, 35.15214565822056, 38.51718602861677, 41.995930194854736, 42.44997065407889, 44.44992276600429, 43.79726110185896, 44.468985148838584, 43.23337657111031, 36.57445928028652, 10.718969464302063, 0.9835916608572006, 1.1740530750581195, 3.6084568287645067, 5.303948215075901, 2.7724595623356953, 4.671109761510577, 4.360459710870471, 6.060333022049495, 3.9886264290128435, 0.3942733848733561, 0.16300818590181215, 0.0705147704907826, 0.5017007046512195, 8.051831347601754, 25.3672650882176, 36.94000053405762, 30.623685019356863, 26.216321059635707, 19.909359557288035, 0.783685962004321, 0.08273482655308076, 0.10203834037695612, 0.08473712911031075, 0.010892598989552684, 0.024173525893794637, 0.009145888699484723, 0.0364785752525287, 0.060938592201897075, 0.057922687248459885, 0.034949734075261016, 0.03757177659177354, 0.055031242580818276, 0.018574310899046913, 0.013771568790876439, 0.03741011901625565, 0.01845688871773226, 0.03590509441814252, 0.038910872236426385, 0.021712606606472815, 0.027839362222169126, 0.005339196982926556, 0.0412831629759499, 0.029959787548120533, 0.03111858286761812, 0.02917249354400805, 0.16141996612506254, 0.06738808791020087, 0.07095300233257668, 0.07718402333557606, 0.09893780175064291, 0.12253323277192456, 0.12042836286127567, 0.1276188391659941, 0.09180664976260491, 0.1355388763227633, 0.0982657874535237, 0.14985030623418943, 0.0870461498520204, 0.17334023863077164, 0.13426525252205984, 0.06430478407336132, 0.18831888559673512, 0.14386182757360594, 0.114686463826469, 0.09125995409807988, 0.15546622845743382, 0.0637086842741285, 0.1786888859101704, 0.21300257822232588, 0.13130884830440792, 0.1403342732893569, 0.11416579676525933, 0.08160967299980776, 0.19013859438044683, 0.19398138246365956, 0.09911339304276875, 0.07686123744185482, 0.6100289832268442, 19.045496974672588, 43.92055688585554, 38.142830984933035, 35.0082345690046, 44.47544002532959, 42.229181221553254, 14.702890225819178, 1.7341577857732773, 0.16043929303331034, 0.3946685365268162, 3.863629639148712, 7.90654364653996, 6.9205556171281, 7.7682371480124335, 6.642389263425555, 3.3911619058677127, 2.296388102429254, 1.4461777529546191, 5.823118916579655, 17.21444341114589, 31.088304110935756, 42.4239114352635, 47.76162528991699, 49.67268909726824, 48.87635258265904, 49.41617202758789, 52.24210861751011, 55.17327914919172, 52.71381834575108, 52.519286155700684, 50.48093135016305, 45.85172183173043, 45.29100567953927, 41.52278913770403, 44.33911289487566, 45.25143916266305, 49.784325804029194, 52.97163125446865, 53.27528837748936, 53.34294646126883, 51.46221848896572, 51.04285648890904, 52.821769033159526, 52.63606800351824, 50.24091625213623, 40.648406982421875, 38.02952323641096, 39.2470178604126, 39.09318821770804, 42.575799056461875, 50.39835895810808, 52.41253750664847, 52.488905157361714, 53.069701603480745, 54.41516120093209, 48.959915093013215, 48.755165576934814, 46.19917345046997, 51.712628092084614, 52.38358783721924, 47.78854955945696, 50.72691147668021, 46.962273257119314, 43.2808883530753, 41.22890813010079, 38.314764159066335, 38.84976502827236, 39.077655519757954, 37.25800568716866, 37.11415713174002, 42.015489373888286, 43.398913928440635, 42.3521226474217, 44.26958227157593, 38.707267897469656, 38.03642627171108, 37.784929275512695, 43.74389546258109, 46.7485397202628, 47.02869456154959, 50.11468832833426, 47.63161407198225, 46.33816521508353, 48.40433365958077, 49.53940180369786, 47.71085827691214, 46.6079672404698, 39.685497828892295, 37.47251047406878, 41.132286480494905, 43.65036923544747, 43.92569855281285, 46.815346649714876, 46.28148181097848, 46.33016089030674, 44.30738394601004, 35.13952425548008, 8.943531019347054, 1.0364185976130622, 1.3582215926476886, 4.674658553940909, 8.35752602985927, 4.945078534739358, 7.302151118006025, 9.069355947630745, 11.03110338960375, 19.07714949335371, 8.468834434236799, 1.0765334793499537, 0.25634523747222765, 1.2759348366941725, 10.402447751590184, 31.08892250061035, 45.56414631434849, 33.947592054094585, 33.970635754721506, 23.146528754915508, 1.0133120375020164, 0.20294208877852984, 0.23646996968558856, 0.15183643251657486, 0.07374974047499043, 0.08034888029630695, 0.08566326155726399, 0.10610421041824988, 0.14377615574215138, 0.08777126629969903, 0.12661418664668286, 0.2015926047627415, 0.10293940774032048, 0.13195820631725447, 0.08921694622508117, 0.21746409524764332, 0.17071576017354215, 0.10900443872170788, 0.07461622969380446, 0.07422538673771278, 0.1188482583633491, 0.08117205862488065, 0.1296964862516948, 0.22420082161469118, 0.06598046701401472, 0.10219360954527344], [0.0424357259513012, 0.0933307276240417, 0.010177765740081668, 0.03532853303477168, 0.03976614187870707, 0.015242505485990217, 0.058152602054178715, 0.029050557408481836, 0.03286107775888272, 0.042311465833336115, 0.047398174846810956, 0.037319995995078764, 0.031362869045031924, 0.019038191364545907, 0.1452199832669326, 0.048262550429041894, 0.050457760492073636, 0.041279549776975594, 0.033244158274361064, 0.06988245049225432, 0.015645602784518684, 0.02360772098680692, 0.055863184189157825, 0.0029691971472597545, 0.06115828148488488, 0.03434335107782057, 0.02619878837971815, 0.025169455845441138, 0.05998947098851204, 0.03832204633259347, 0.019759630152423466, 0.05538839627323406, 0.04168921529448458, 1.2612722920519965, 24.005339997155325, 33.10875688280378, 28.146389927182877, 23.84672999382019, 31.276384898594447, 33.45435333251953, 9.076398815427508, 2.0006608281816756, 0.06697080244443246, 0.19852234236896038, 1.6835389648165022, 0.43114269790904863, 4.282959503786905, 6.274123013019562, 2.9866273616041457, 2.926279651267188, 0.814613045326301, 0.7605402639933995, 1.8433801020894731, 8.470050368990217, 19.732788460595266, 32.27080065863473, 42.74372659410749, 48.631400789533345, 49.1829696382795, 49.791690894535606, 48.396954672677175, 49.128151825496126, 49.046576499938965, 47.47804498672485, 42.41978073120117, 42.77889837537493, 38.030985832214355, 39.2715345791408, 39.99789925983974, 43.35092966897147, 46.615631103515625, 49.776891231536865, 48.94065121241978, 50.24937915802002, 48.54193925857544, 51.40570878982544, 48.57583257130214, 48.31910358156477, 38.082694326128276, 37.173713615962434, 36.33368335451399, 35.99277693884713, 35.83796065194266, 41.82684578214373, 45.822768688201904, 48.160236494881765, 48.44196857724871, 49.97189242499215, 49.20407479149954, 50.70779003415789, 40.96774271556309, 46.19156864711216, 50.54314204624721, 46.8977175440107, 47.59510823658535, 48.98766619818551, 45.35272305352347, 43.3460624558585, 36.39113106046404, 35.159062589917866, 34.15153905323574, 33.591920716421946, 34.74888958249773, 40.752379826136995, 41.880027294158936, 43.300343309129985, 41.39122499738421, 40.00357941218785, 35.41125093187605, 38.44437238148281, 43.65677547454834, 44.88197565078735, 46.226525034223286, 46.49118539265224, 45.42116628374372, 44.29798650741577, 44.85574620110648, 47.0624280657087, 46.0192220551627, 42.695221219744, 36.936630657741, 36.653561047145296, 40.31901025772095, 41.11491250991821, 41.10455969401768, 43.33939913340977, 43.495438303266255, 45.92786019189017, 31.498911380767822, 10.613549658230372, 0.5701939293316433, 0.1639105560524123, 0.6700800923364503, 1.780283402119364, 2.676480838230678, 1.5338075650589806, 3.2151119240692685, 2.2190318533352444, 4.1732748065676, 1.8874166991029466, 0.24705625591533525, 0.09673785551318101, 0.7268209276454789, 7.170886618750436, 24.313680206026348, 32.8780871118818, 24.09844238417489, 22.855967249189103, 22.82498870577131, 3.6325536157403673, 0.059631530195474625, 0.06938488076307944, 0.04546471305989793, 0.02226323268509337, 0.028807892929762602, 0.034112866302686076, 0.08680972111012254, 0.008245963819458016, 0.029880656794245754, 0.07092351998601641, 0.05564794609589236, 0.028439414487885575, 0.022337459327120866, 0.05150500465450542, 0.04720926730494414, 0.027421727310866117, 0.022248399909585714, 0.03166029808510627, 0.04794766946828791, 0.05946127897394555, 0.056406697524445396, 0.04583450446703604, 0.022893657874582068, 0.08389662099736077, 0.058045203531427045, 0.03516567784494587, 0.02059509844652244, 0.015306832302095634, 0.020556014829448292, 0.023920337336936166, 0.02916531464351075, 0.03138098593002983, 0.04962682990091188, 0.019435002036126595, 0.0602828763159258, 0.011215669019812984, 0.02317375034492995, 0.03609280434570142, 0.021682927484757135, 0.02298642718233168, 0.09418258762785367, 0.0015265141202170135, 0.046756351965346506, 0.04552021722442337, 0.07376335867281471, 0.038787253334053924, 0.0133947138341942, 0.11022144556045532, 0.009476250436689173, 0.05308541788586548, 0.053327637924147506, 0.050841356694166145, 0.03829098639211484, 0.04926252105672445, 0.020951973939580575, 0.027713563526049256, 0.022549628745764494, 0.0943191224443061, 0.05725293925830296, 3.0508276309285844, 29.919585841042654, 37.86099815368652, 29.77886050088065, 27.7618853024074, 41.92351259504046, 35.15361172812325, 9.247446962765284, 1.0438099609954017, 0.11834882944822311, 0.19732064328023366, 0.7242327779531479, 0.838793427816459, 9.210075208118983, 14.128697173936025, 8.63612881728581, 2.242552808352879, 1.3274295649358203, 1.5950086010353905, 3.078262810196195, 12.169574413980756, 24.24703308514186, 36.63241420473371, 45.08759716578892, 50.572821276528494, 50.930622237069265, 50.47455985205514, 49.43758290154593, 51.81127861567906, 50.25600773947579, 49.4108566556658, 43.89670024599348, 43.04135268075125, 40.907849243709016, 40.14410325459072, 42.91737249919346, 45.91318907056536, 48.19623858588082, 51.73759296962193, 51.60206140790667, 48.24264213017055, 49.362594468253, 52.152105127062114, 51.2048294203622, 48.67172466005598, 40.25106034960066, 37.8222793170384, 37.65329565320696, 37.80997405733381, 38.28685324532645, 43.38502447945731, 48.290407521384104, 49.559860774448936, 49.458382334027974, 51.450476033346995, 49.925447191510884, 49.652549743652344, 42.92707913262503, 47.45731851032802, 52.10937023162842, 47.862874439784456, 49.46375676563808, 49.339554241725374, 46.29306445802961, 44.3868852342878, 37.45599808011736, 37.275615896497456, 35.225911208561485, 35.716061455862864, 36.743561063494, 41.54949801308768, 42.990693364824565, 46.64391721997942, 41.96675818307059, 39.39884989602225, 36.63740995952061, 40.11711645126343, 44.50037711007254, 46.22896037782942, 46.90681621006557, 47.48924200875418, 46.17518826893398, 46.36915765489851, 46.79996681213379, 48.194192341395784, 46.47628845487322, 44.335145473480225, 37.77327019827706, 37.55290460586548, 40.909426484789165, 42.2403678212847, 43.71319832120623, 44.26011535099575, 45.09758172716413, 46.593257904052734, 35.26620033809117, 13.519787447793142, 1.2295036081756865, 0.8765867426991463, 1.455657809972763, 3.3414217063358853, 4.511478807244982, 3.8147855401039124, 3.5197893466268266, 5.573884427547455, 5.494585939816066, 1.4472693800926208, 0.3692797917340483, 0.0672800379938313, 0.4547318864081587, 7.146243529660361, 24.639112983431133, 34.92164959226336, 32.20432724271502, 25.01397524561201, 27.976815666471207, 6.326731298651014, 0.06893828258450542, 0.08662614346082721, 0.0297071316412517, 0.026603763523910726, 0.00495034086218636, 0.014418397564440966, 0.06766049257878747, 0.025763591285794973, 0.01249491617948349, 0.03074576858697193, 0.05690367692815406, 0.026680349771465574, 0.03357331221923232, 0.0192861229713474, 0.038782595191150904, 0.0019423940643069468, 0.04184456927967923, 0.008975497530108052, 0.044165315106511116, 0.04669139580801129, 0.044130869276289425, 0.031699788823191605, 0.017168079303311448, 0.026127674517088702, 0.03258702764287591, 0.046387493543859036, 0.1317332312464714, 0.1705295973058258, 0.058007470199040005, 0.11470254510641098, 0.19596484888877186, 0.19156244583427906, 0.20635148297463143, 0.1073434596349086, 0.11168571055999824, 0.07368376651512724, 0.1588212177157402, 0.09675097838044167, 0.11155906199876751, 0.14275310135313443, 0.21224833226629666, 0.10930055140384606, 0.132057448849082, 0.1363417732396296, 0.20382531067090376, 0.12965064442583493, 0.06944958586245775, 0.2295690785561289, 0.13596745261124202, 0.176013178059033, 0.15973890918706143, 0.11239518677549702, 0.18110007366963796, 0.09793264711541788, 0.12433824448713235, 0.15996199793049268, 0.12084644899836608, 0.18253216253859655, 0.15296782180666924, 2.556224673986435, 32.90100921903338, 45.179535729544504, 38.41523163659232, 31.037724699292863, 39.980417592184885, 41.27015611103603, 12.79745272227696, 2.7858639402048926, 0.2979019789823464, 0.7676680300916944, 3.621428681271417, 3.7077455009732927, 11.698435306549072, 12.343935983521597, 7.377283726419721, 6.5300829240253995, 3.0261669542108263, 1.9442347245556968, 3.2761670478752682, 10.731436269623892, 22.724175555365427, 34.82663297653198, 45.06264965874808, 51.37134647369385, 50.86761597224644, 51.85408994129726, 49.73947865622384, 54.53210285731724, 51.61505453927176, 51.28508806228638, 46.227028778621126, 46.39410168784005, 42.40925768443516, 43.72758109228951, 45.26917791366577, 46.842316082545686, 51.27505833762032, 53.46859073638916, 51.523956707545686, 50.16175195149013, 49.04349149976458, 53.64691277912685, 53.37278202601841, 51.47137968880789, 42.10523925508772, 40.97388144901821, 39.134311131068635, 39.99476909637451, 40.20550101143973, 45.62822954995291, 49.27191352844238, 50.90686982018607, 53.09245695386614, 53.30586739948818, 52.01982184818813, 51.99857078279768, 44.27701684406826, 47.315537043980186, 53.654837199619834, 50.87829187938145, 52.34513998031616, 52.47357048307146, 49.68854488645281, 47.73374564307076, 40.22030414853777, 39.0331905228751, 36.36254964556013, 37.317298139844624, 37.92406347819737, 44.19396850040981, 45.249861921582905, 48.19311537061419, 44.885053702763145, 42.70069292613438, 37.763146672930034, 42.503030572618755, 46.602210657937185, 48.10586336680821, 48.16193880353655, 48.55260474341256, 47.704816818237305, 46.43700334003994, 47.07992015566145, 49.88979945863996, 47.61150598526001, 46.64153746196202, 40.02126257760184, 39.50891283580235, 43.35178082329886, 44.770679405757356, 44.215205669403076, 45.58983033043997, 45.97583402906145, 47.74390738351004, 33.563919476100374, 12.672329562050955, 1.2193658607346671, 0.6802340703351157, 1.9279244797570365, 5.38700133562088, 9.293563893863134, 7.023933087076459, 7.898111139025007, 6.06192763362612, 9.436107925006322, 5.223102016108377, 0.8959162511995861, 0.2586591775928225, 1.338821245091302, 10.086153592382159, 30.72485773903983, 41.351536887032644, 32.30624689374651, 31.577957562037877, 32.36121756689889, 7.115984993321555, 0.17613600646810873, 0.1710840282695634, 0.09485914810959782, 0.1337435540876218, 0.12878701862479958, 0.1264016559081418, 0.21290299642298902, 0.07402882871351071, 0.08884614719344036, 0.09057109856179782, 0.15133555153650896, 0.1580882099057947, 0.08197928459516593, 0.15884731417255743, 0.13641238159367017, 0.09657978399523667, 0.16825858131051064, 0.058328919378774505, 0.18246775599462645, 0.14901939939175332, 0.1651988769216197, 0.23604686238936015, 0.04987605920593653, 0.1777185129800013, 0.104782397060522, 0.15405155079705374], [0.007952812094507473, 0.02878523664548993, 0.10760535379605633, 0.08023791946470737, 0.026890610810369253, 0.04516252748934286, 0.06336326245218515, 0.022060581416423832, 0.05649356697020786, 0.01335587618606431, 0.028129878686740994, 0.01095909542138023, 0.06898077244737319, 0.08348216502262013, 0.040580933514450274, 0.028151257628841058, 0.03060124402067491, 0.02155051816121808, 0.04709671191605074, 0.03326401220900672, 0.04081316890993288, 0.037183749556009255, 0.03181406429835728, 0.05662167438172868, 0.03327827501509871, 0.0187582871876657, 0.01732213728662048, 0.03696932570476617, 0.036324439237692525, 0.036673165525176694, 0.033553862012922764, 0.09257474461836473, 0.03635042712890676, 0.032423534630132575, 4.321329193455832, 25.250078507832118, 33.328986985342844, 28.087939943586075, 21.775897571018763, 31.956033366067068, 36.02897705350603, 12.883129222052437, 2.354749930756433, 0.09129882736929826, 0.16041881484644754, 0.9893288101468767, 14.946164028985159, 29.47620391845703, 14.385990704808917, 1.910747230052948, 1.4049406285796846, 0.8182320254189628, 0.2886124003146376, 0.957370787858963, 4.157361260482243, 10.433437585830688, 22.818042244229996, 38.72845295497349, 48.433502197265625, 49.09338303974697, 47.863791601998464, 51.3551641191755, 49.6963928767613, 50.97031729561942, 46.923436301095144, 43.41260535376412, 40.68621907915388, 39.41931928907122, 39.54614128385271, 43.291157790592735, 47.50057104655674, 51.80190202168056, 51.4629237311227, 49.987661361694336, 47.89793157577515, 49.535267625536235, 49.567861625126426, 46.842392512730186, 37.72918387821743, 35.467903069087434, 35.77960273197719, 36.08359684262957, 36.68006842476981, 36.74255704879761, 41.0043944631304, 45.289949553353445, 47.38072851725987, 49.51582309177944, 48.43945680345808, 50.86519105093819, 40.97648702348982, 40.21531534194946, 51.14949744088309, 49.789985111781526, 48.974825927189414, 48.33467102050781, 47.33643027714321, 47.84283236094883, 43.3991744858878, 34.84285354614258, 35.080655642918174, 35.081454685756135, 37.28130994524275, 41.606598309108186, 44.06721598761422, 45.46630872998919, 45.072971207754954, 39.60647249221802, 36.140558174678254, 39.518084457942415, 45.961173330034526, 46.241331645420615, 47.54779100418091, 44.90035016196114, 44.275488240378245, 46.45884500231062, 47.35660784585135, 42.83998693738665, 45.44702747889927, 39.9927020072937, 38.505082266671316, 39.499925340924946, 42.6964510508946, 43.34372091293335, 42.34294407708304, 43.226984228406636, 44.21608114242554, 36.08346830095564, 15.089032888412476, 1.7746680634362357, 0.3330955005117825, 1.190549292734691, 1.4764078451054437, 3.09212772335325, 2.625507550580161, 2.363364394221987, 3.9637570892061507, 5.227923197405679, 5.555015291486468, 0.6319064178637096, 0.18083981477788516, 0.3370944873562881, 7.552971533366612, 22.145850930895122, 35.48432861055647, 31.843291895730154, 17.891427244458878, 26.176464455468313, 11.621479664530073, 0.18830551845686777, 0.030145010644836084, 0.014228890367251421, 0.02702754087347005, 0.01515279128216207, 0.013612977345474064, 0.0259304023347795, 0.03389139586527433, 0.020293452311307192, 0.02780028708678271, 0.08440870459058455, 0.01517066389455327, 0.08859166942004647, 0.04254241201228329, 0.05040585595582213, 0.006494765020241695, 0.0419575894650604, 0.02933268209121057, 0.014027376492906894, 0.0637927276215383, 0.05835209134966135, 0.03984262973868421, 0.016083895694464445, 0.05126577356298055, 0.024978487253455178, 0.031060500270021812, 0.03171235189906188, 0.05408033003498401, 0.009955699888191052, 0.017653845915836946, 0.024381350991981368, 0.006127464684790799, 0.028634048865309784, 0.03415086765640548, 0.058110736443528106, 0.015802432583378892, 0.0638929268877421, 0.05690979052867208, 0.04947381346885647, 0.03836387123114296, 0.0107591133398403, 0.038498970946030955, 0.03289737259703023, 0.02697959219637726, 0.018079881090670824, 0.07124661800584622, 0.024528262305206487, 0.019850048336333463, 0.005071633237613631, 0.04686491756833025, 0.05831037501671484, 0.03372623026371002, 0.03911817825532385, 0.023572415113449097, 0.04223898811531918, 0.02964449268100517, 0.05199304775201848, 0.08578326047531196, 0.06417516352874891, 0.03594702788229499, 0.04382653274972524, 8.466437305722918, 30.558729784829275, 37.58379282270159, 25.0782721383231, 23.752609695707047, 44.483788285936626, 35.985460485730854, 13.509864551680428, 1.370844623872212, 0.07957991691572325, 0.03798882796296051, 0.501884289085865, 4.4194755383900235, 9.375479681151253, 7.742782422474452, 2.633876004389354, 2.589593831981931, 1.4723955861159732, 0.37859900881137165, 1.8029939149107252, 5.421037086418696, 13.518799935068403, 27.12984241758074, 42.314685753413606, 49.459667750767295, 48.85760981695992, 48.67567471095494, 54.193343435014995, 50.389545168195454, 50.6780378477914, 46.60971818651472, 45.08047178813389, 42.73490585599627, 42.21299191883632, 41.375136443546836, 44.72218792779105, 48.1890298298427, 52.4427170072283, 52.551435470581055, 51.708236830575125, 48.073644569941926, 51.82143340791975, 51.034758363451274, 48.59185511725289, 39.37265518733433, 38.493701117379324, 37.92377860205514, 37.18068265914917, 38.04037979670933, 38.87612301962716, 43.73006854738508, 48.68411329814366, 48.726104736328125, 50.919946329934255, 50.1248813356672, 51.70644766943795, 43.255659443991526, 41.71961423328945, 52.35050398962838, 50.33994892665318, 50.491951193128315, 50.57379749843052, 48.815048626491, 49.82368040084839, 43.11124461037772, 37.48967947278704, 36.688281195504324, 36.46365635735648, 38.600797176361084, 42.97576168605259, 44.47955683299473, 46.2371175629752, 46.01320838928223, 41.86576959065029, 37.13016925539289, 40.20559481212071, 46.49783481870379, 47.59640407562256, 47.49326848983765, 45.769962378910606, 45.714025906154085, 47.0412186895098, 48.55308069501604, 46.952174050467356, 46.71726935250418, 42.963793413979666, 40.0916200365339, 40.33600207737514, 44.01686239242554, 44.77897555487496, 44.401104722704204, 46.3874557358878, 44.208128929138184, 39.89135210854666, 17.797062022345408, 3.4564044049807956, 0.7432666080338615, 2.572958758899144, 3.544816106557846, 1.7886634724480766, 3.561554968357086, 3.468971307788576, 3.5357827969959805, 4.644055647509439, 1.8251102481569563, 0.10094593970903329, 0.06900313017623765, 0.33684294085417477, 5.648267499038151, 25.977136271340505, 40.11915227345058, 33.64954560143607, 20.431316920689174, 29.601003987448557, 16.63389536312648, 0.3413037114909717, 0.06974193946059261, 0.0038103566538276418, 0.040976475325546095, 0.033021130599081516, 0.05613576866952436, 0.037367985384272676, 0.01085326261818409, 0.008354375903893794, 0.03580481372773647, 0.026951173453458717, 0.05798633383320911, 0.05968482233583927, 0.018377598508128097, 0.07644403340028864, 0.01805718070162194, 0.03267070458137563, 0.06413968293262379, 0.06444378875728164, 0.038992106448858976, 0.024750151737992252, 0.04154359828680754, 0.026698417462674633, 0.03634100567017283, 0.026568924143378223, 0.02577154541255108, 0.029512154603643075, 0.19221297092735767, 0.087696274609438, 0.18885966443589755, 0.13702199102512427, 0.0842835216649941, 0.11853738075920514, 0.16316009632178716, 0.13039613728012356, 0.2604363422308649, 0.11229456681758165, 0.11574792329754148, 0.09381419061017887, 0.1408536239926304, 0.1954547126910516, 0.12096144711332661, 0.0762137725417103, 0.0710651980979102, 0.14938933668392046, 0.24438024950878962, 0.07290775994104998, 0.15498554067952292, 0.14825565394546303, 0.14718606562486716, 0.13266492768057755, 0.1614346360521657, 0.13741946326834814, 0.07118370423891715, 0.08415719880057232, 0.10794791898557118, 0.15408099921686308, 0.13296238386205264, 0.19364664756825992, 0.12370313570967742, 0.12223849073052406, 7.02143303837095, 34.10279744012015, 46.46252407346453, 35.72399629865374, 29.739828995295934, 40.60979584285191, 43.11000435692923, 17.637727669307164, 3.048011439187186, 0.2724748019661222, 0.5181873142719269, 2.104593502623694, 21.685885395322526, 43.9443370955331, 24.278013365609304, 5.9764005201203485, 3.55562533225332, 3.6629035643168857, 0.5912979968956539, 1.650226803762572, 5.31837397813797, 11.402987480163574, 26.228619371141704, 42.087160042354036, 50.58801351274763, 49.02638850893293, 50.09422240938459, 56.16024991444179, 52.67894186292376, 54.85130657468523, 50.556392260960166, 47.6993659564427, 43.6976968901498, 44.94617700576782, 43.591795921325684, 46.34869868414742, 51.46783263342721, 55.088799476623535, 54.78242908205305, 51.0855392728533, 47.432391847882954, 50.89769124984741, 54.22460338047573, 50.68093524660383, 41.37627247401646, 39.69304009846279, 40.66017375673567, 39.45820140838623, 39.37278025490897, 39.324879373822895, 44.966305937085835, 49.803732122693745, 51.39357376098633, 53.97530548913138, 52.17410659790039, 54.721945013318745, 45.17978586469378, 41.58071279525757, 52.58645786557879, 54.79916729245867, 51.578743253435405, 52.785058225904194, 49.37723084858486, 52.01824460710798, 45.986106940678184, 38.21976491383144, 38.15566430773054, 39.47626325062343, 40.25882496152605, 44.85836567197527, 46.781731264931814, 48.90298850195748, 48.56511844907488, 44.16054766518729, 39.55650104795183, 41.95769773210798, 49.33622258050101, 48.20735222952706, 49.58862631661551, 46.28840569087437, 45.84443664550781, 48.22378124509539, 51.40042468479702, 46.68740946905953, 49.63685723713466, 43.93193803514753, 41.2440447807312, 41.56536422457014, 45.25926283427647, 47.0167019707816, 45.68959951400757, 47.348089354378835, 46.021695613861084, 38.69214514323643, 17.217458929334367, 2.6902495622634888, 1.4959087244101932, 3.0368893274239133, 5.507804453372955, 7.239561310836247, 7.502632703099932, 6.920394505773272, 7.913854888507298, 12.976367098944527, 10.602797320910863, 2.1216634895120348, 0.4402199222573212, 0.7494691237807274, 10.010772585868835, 29.07891287122454, 44.21221099581037, 39.81213569641113, 25.95184482846941, 36.00821236201695, 18.61129535947527, 0.32967668824962204, 0.16895331974540437, 0.16112048790923186, 0.09717129011239324, 0.0704758632928133, 0.14633862966937677, 0.12235621655625956, 0.09533888593848262, 0.09659438606883798, 0.07029677754534142, 0.1726821953696864, 0.17772309987672738, 0.13588866112487658, 0.13463696757597582, 0.22039683216384479, 0.13882194086909294, 0.07805014614548002, 0.11945238523185253, 0.16818023765725748, 0.1649647280573845, 0.10226213479680674, 0.14704647740083082, 0.1289116112249238, 0.14512569404074124, 0.1383118046713727, 0.10383268552167074, 0.1725210433027574], [0.05176813714206219, 0.028142784422795688, 0.0387405260199947, 0.04731380580259221, 0.028479135927877257, 0.03179562171655042, 0.03385444624083383, 0.02536633617377707, 0.01748208325755383, 0.033491267157452445, 0.04961601405271462, 0.041416495107114315, 0.02341393817083112, 0.029900958562003713, 0.0329363951459527, 0.035456915252975056, 0.018917781932811652, 0.020063464563073855, 0.08517809544822999, 0.062446222374481816, 0.07211263903549739, 0.05795792357197829, 0.04945917407582913, 0.027124807172055756, 0.0507473999501339, 0.04292055279282587, 0.04616635558860643, 0.024828985632796372, 0.01621442547600184, 0.05462871864438057, 0.04905506915279797, 0.027261523496625677, 0.071380872944636, 0.002029968550362225, 0.018399384571239352, 6.981067478656769, 28.38656309672764, 33.39955983843122, 21.929324218205043, 21.37011582510812, 32.549510274614605, 34.71605239595686, 16.738634245736257, 1.5644031975950514, 0.20622290058859757, 0.1712183239204543, 2.5297370553016663, 5.999459419931684, 8.499492491994586, 0.6107549614139965, 0.9965262753622872, 2.0452569723129272, 0.2297173791698047, 0.34424708783626556, 0.007259944719927651, 1.7460316057716097, 9.077057157244, 22.94603153637477, 35.51861449650356, 47.32569183622088, 50.940189906529014, 53.10745464052473, 49.612830366407124, 49.96237339292254, 45.98888622011457, 44.73465299606323, 45.01485300064087, 41.83282470703125, 41.28853062220982, 44.365648065294536, 48.41369983128139, 49.407584054129465, 51.55249295915876, 48.487586975097656, 47.40762151990618, 49.6389034816197, 50.72380910600935, 45.051490851810996, 39.221038545881, 36.7379469190325, 35.769698074885774, 36.98915556498936, 37.88050174713135, 36.6529426574707, 38.6284510067531, 39.31439801624843, 43.13637277058193, 47.46334259850638, 48.3754152570452, 50.6332289150783, 42.81334406988961, 40.995559828622, 47.34375715255737, 49.693016052246094, 50.30008363723755, 50.721995626177105, 49.183383056095664, 47.57041086469378, 44.584905420030864, 35.02821411405291, 35.138634886060444, 35.14837973458426, 37.05443736485073, 44.00680487496512, 46.180996962956016, 47.713349206107004, 44.386047976357595, 42.28568049839565, 37.70849561691284, 37.15356036594936, 44.704470021384104, 47.96111849376133, 46.36996364593506, 46.51203693662371, 48.10442508969988, 47.14560842514038, 45.35943501336234, 44.10814435141427, 41.72920274734497, 40.452610220227925, 41.06875215257917, 41.978434630802695, 42.612200668879915, 45.375676427568706, 43.33225291115897, 45.98087842123849, 36.685435908181326, 17.59211621965681, 2.8557289455618178, 0.29756092014057295, 0.7850869468280247, 1.740323769194739, 2.6010811584336415, 1.1529854855367114, 2.2743712152753557, 2.1720229472432817, 1.9277590257780892, 3.529699866260801, 1.6330330520868301, 0.036982234833495956, 0.6304687378661973, 6.153172246047428, 24.73991744858878, 28.717729875019618, 33.27267183576311, 46.568227018628804, 21.234346287591116, 20.012356179101126, 1.4141276670353753, 0.07280865990157638, 0.012909289033684348, 0.045080859014498334, 0.026926237291523387, 0.018721622547933033, 0.013002849682899458, 0.04149934762556638, 0.032038289587944746, 0.026650280492114167, 0.020925192162394524, 0.05837362805115325, 0.023812994793323532, 0.020688203629106283, 0.06380205747804471, 0.04221917489277465, 0.04307358618825674, 0.014691782716129507, 0.021371714005778943, 0.048332615955067534, 0.09542046620377473, 0.011090777864280556, 0.0198129799682647, 0.030254990993333713, 0.04532393739957895, 0.012445502714919192, 0.04015295433678797, 0.038449339502091916, 0.020858992589637637, 0.03505667797955019, 0.0474584966099688, 0.03314189286902547, 0.0417891601100564, 0.04314536501520446, 0.003979373365707163, 0.03873511131054588, 0.027147156419232488, 0.03826537508783596, 0.06358536053448915, 0.017387839832476208, 0.057203718328050206, 0.024633338541856835, 0.021584377058648636, 0.049516316902424605, 0.009474297952173012, 0.06844505547944989, 0.011194119595789483, 0.045483074217502556, 0.026715504670781747, 0.04150469448151333, 0.015163654627810632, 0.0321762221865356, 0.04706192681831973, 0.09530071834368364, 0.019736431040135876, 0.04434254506070699, 0.03763837141117879, 0.05330785184300371, 0.037364338258547444, 0.023487376015899435, 0.06488100279654775, 0.04940756130963564, 0.15556563383766583, 11.770853774888174, 35.5886037009103, 34.488933154514854, 21.564311027526855, 23.916665349687847, 43.11610834939139, 40.491273471287315, 15.170863560267858, 1.406133655990873, 0.2304116833422865, 0.06434135032551629, 0.6057780970420156, 1.8897567221096583, 8.446458629199437, 3.781742513179779, 3.158343404531479, 3.205376846449716, 1.0540785299880164, 0.5576201868908746, 0.44446812144347597, 2.5726445700441087, 11.042475853647504, 25.243008715765818, 39.324584075382774, 48.74837371281215, 50.857200622558594, 52.328815187726704, 51.137935638427734, 51.41959129061018, 49.703737122671946, 46.03545304707119, 45.65988206863403, 43.621416091918945, 42.48723384312221, 45.457227434430806, 49.683198247637065, 52.364435127803254, 52.88803052902222, 49.30489662715367, 47.93631342479161, 51.215453216007774, 51.805633204323904, 47.152806758880615, 40.65940945489066, 37.86594179698399, 37.799652508326936, 37.49504000799996, 38.84524522508894, 38.33512238093785, 40.455233165196006, 42.71838651384626, 46.13811615535191, 49.623096329825266, 49.362299169812886, 52.52236073357718, 45.66757719857352, 42.32436111995152, 48.44263560431344, 50.09487901415144, 49.72276823861258, 51.5716769354684, 49.47469670431954, 48.81198794501168, 47.02273995535714, 36.95320211138044, 35.92356593268258, 35.9732003893171, 38.003571714673726, 44.00050285884312, 46.42080708912441, 47.66276979446411, 45.103682245527, 44.129041058676584, 39.10501057761056, 39.72873994282314, 46.06893294198172, 48.97237321308681, 48.396669796534944, 46.06388507570539, 47.85497433798653, 47.99790573120117, 46.72589554105486, 45.14109829493931, 42.92186450958252, 42.86320086887905, 42.21797030312674, 43.763840266636436, 43.696637289864675, 46.80908284868513, 44.60936655317034, 47.048618521009175, 38.81873089926583, 21.31310064452035, 5.092630045754569, 0.6654915128435407, 1.2757482124226434, 3.609455849443163, 3.9754747918673923, 2.433166865791593, 3.411935933998653, 3.975530811718532, 3.411205070359366, 1.1627929764134544, 0.5526066273450851, 0.01518865694691028, 0.6539280276213373, 4.552365481853485, 27.207118545259746, 36.116461821964805, 39.09320558820452, 45.89615903581892, 23.414109093802317, 24.950322798320226, 3.0375122768538336, 0.09970116043197257, 0.03600944631866046, 0.02438423646214817, 0.04022581881976553, 0.049385312146374157, 0.03755720165957298, 0.044025754023875506, 0.03860139241442084, 0.01878005459106394, 0.030230234643178325, 0.04202666772263391, 0.015250047402722495, 0.013684003846719861, 0.029552004965288297, 0.042974072242421765, 0.010387925846901323, 0.007609024693790291, 0.04442167242190667, 0.0661622126187597, 0.014773712426956211, 0.01307524852122047, 0.04925096560535686, 0.036661511686231406, 0.009213632787577808, 0.12711069786122867, 0.062642420775124, 0.025178186894793595, 0.2588503887610776, 0.09291263470160109, 0.15414818775440964, 0.13341035268136434, 0.11725823368344988, 0.11724021179335457, 0.11029858820672546, 0.08623599261045456, 0.06549151467957667, 0.12095633095928601, 0.22327349494610513, 0.19223658394600662, 0.14125351182052068, 0.12273265421390533, 0.08782620049480881, 0.12033503715481077, 0.10888298095336982, 0.14911841122167452, 0.15360206205930027, 0.14561973538781914, 0.14437716134956904, 0.11976238074047224, 0.07329299141253744, 0.07240472800497498, 0.18185803799756936, 0.216156164716397, 0.17748036075915608, 0.1097247511414545, 0.1111877201391118, 0.10369813202747277, 0.1535423102655581, 0.11211463290133647, 0.20239741514836038, 0.1495037241173642, 0.2608788827700274, 10.563054493495397, 39.827453000204905, 44.268387181418284, 30.77759109224592, 29.517375469207764, 39.172505378723145, 43.774481432778494, 20.847140550613403, 2.3464427079473222, 0.39449301308819223, 0.675145763371672, 5.844756475516728, 15.253703457968575, 20.709904943193706, 4.821107472692217, 2.735227857317243, 5.2726383294378, 1.694602559719767, 1.1067539091621126, 0.5974669658711979, 2.332597987992423, 10.657434480530874, 24.64981320926121, 39.86307641438076, 49.97097873687744, 53.31188453946795, 57.582824093954905, 52.5932115146092, 55.3813533782959, 51.035703318459646, 50.08248690196446, 50.62218822751726, 47.00866290501186, 44.594629423958914, 48.63172388076782, 51.598809650966096, 53.5614012990679, 54.44070625305176, 48.23050710133144, 47.133230209350586, 53.68170240947178, 52.83018330165318, 47.52264199938093, 41.697512013571604, 40.066175733293804, 40.04874617712838, 40.531802313668386, 41.01818316323416, 40.04671382904053, 42.64707715170724, 42.96380383627755, 47.67114584786551, 51.12229176930019, 51.18590600149972, 54.45101043156215, 47.83741276604788, 42.20238201958792, 47.79038735798427, 50.12194224766323, 50.27903754370553, 54.09494652066912, 51.74586132594517, 50.80533232007708, 48.949642181396484, 38.356276171548025, 38.264796188899446, 38.29311357225691, 40.5001254762922, 45.935319083077566, 50.2078914642334, 50.557695048195974, 47.1040929385594, 46.560931410108296, 40.95666381290981, 40.79312406267439, 46.97544009344918, 50.822859151022776, 48.31836012431553, 48.18643467766898, 49.89892591748919, 49.40699693134853, 47.424519538879395, 46.708775179726736, 45.43859583990914, 43.97097996303013, 44.98957545416695, 45.12037876674107, 45.09782838821411, 49.20402268001011, 46.66457421439034, 48.00771311351231, 38.74163716179984, 20.445027453558787, 4.0606540611812045, 0.711897282728127, 1.2899590155908038, 4.733462027141026, 6.099781853812082, 4.18756377696991, 6.184470406600407, 5.926658800670078, 8.722884024892535, 8.383617384093148, 3.5626532179968695, 0.32379216115389553, 1.1487315595149994, 7.886029958724976, 31.94050066811698, 37.43610191345215, 38.58280829020909, 51.96964543206351, 30.069701671600342, 28.86309834889003, 3.28251422728811, 0.2154637197298663, 0.17523021650101456, 0.15788805564599379, 0.1062232254605208, 0.14026684047920362, 0.10215745041412966, 0.09575649031570979, 0.16107721094574246, 0.09613661241850682, 0.07976652761655194, 0.1683149811412607, 0.1080707541799971, 0.0922189276399357, 0.14156837921057427, 0.08720755976225648, 0.13409561876739773, 0.07256395303245101, 0.12889793195894786, 0.15317283437720366, 0.19736317385520252, 0.08611232960330588, 0.15993183026356356, 0.06560026348701545, 0.07721600269100495, 0.15026062993066652, 0.15316864103078842, 0.1660151138369526], [0.015023230109363794, 0.028696850673960786, 0.023788274066256623, 0.038349964655935764, 0.027501131175085902, 0.054195066913962364, 0.008516930841973849, 0.01022440314825092, 0.03587553064738001, 0.014547454924987895, 0.023362130325819765, 0.031019292838339294, 0.0329146073865039, 0.044308614917099476, 0.03875364888725536, 0.007512800794626985, 0.022152485592024665, 0.03739149322999375, 0.015564811316185763, 0.044758904326174936, 0.03757814125024846, 0.04234351982761707, 0.029634134843945503, 0.030896844408874, 0.06475614556776625, 0.057223097288182805, 0.030704944527574947, 0.05439191670822246, 0.04585906743471112, 0.04095431776451213, 0.04592980131773012, 0.04151336955172675, 0.023197992704808712, 0.020590294418590407, 0.035089960122214894, 0.0865067212975451, 8.471700566155569, 31.691102027893066, 32.03334249768938, 22.739385162081035, 20.213242496762955, 32.30600718089512, 33.52374846594674, 17.480455194200786, 2.5282733738422394, 0.2716127910784313, 0.0912685850635171, 0.38566489251596586, 2.6642309469836096, 5.156199548925672, 2.4558989831379483, 0.6173848999398095, 0.9086856288569314, 0.647030312035765, 0.09360863521162953, 0.15870004493210996, 2.936505879674639, 9.599882176944188, 23.083531175340923, 37.427840505327495, 52.28103590011597, 56.430465357644216, 53.1097023827689, 49.69433273587908, 50.758536202566965, 45.352882862091064, 47.07546983446394, 46.67519106183733, 48.92782483782087, 50.393067904881065, 49.70906639099121, 52.313952990940635, 49.57502521787371, 49.86546686717442, 49.717529296875, 52.28668131147112, 49.02493633542742, 48.165562289101736, 41.26378113882882, 37.83817679541451, 37.86302007947649, 36.9759053502764, 35.32553447995867, 40.092332226889475, 38.25865398134504, 40.70721653529576, 43.03431762967791, 48.02081741605486, 49.28207526888166, 52.49566922869001, 41.940490518297466, 42.89091375895909, 45.10918174471174, 48.949805464063374, 49.179130758558, 50.22959763663155, 48.51396581104824, 47.37250879832676, 42.90171820776803, 35.59780311584473, 35.92922524043492, 35.84955719539097, 37.80349138804844, 45.44743047441755, 45.91850791658674, 47.71456861495972, 45.093329429626465, 43.74075835091727, 37.80102130344936, 39.26196343558175, 44.78531926018851, 47.6298804964338, 48.46957377025059, 47.53702824456351, 45.23655959538051, 48.37336553846087, 43.625008310590474, 44.02203532627651, 41.45820563180106, 41.427522386823384, 43.06170048032488, 43.59384911400931, 43.508334159851074, 45.94626596995762, 44.98135920933315, 38.004728589739116, 18.35920081819807, 4.241510025092533, 0.417725645005703, 0.7584815344640187, 1.5469014453036445, 3.072719450507845, 3.5661818172250475, 1.0552083722182681, 2.170445489031928, 1.9460536326680864, 1.9813300711768014, 0.8237865130816187, 0.2539466976055077, 0.2845774239727429, 6.351572411400931, 22.653845889227732, 29.285295213971818, 20.957128797258648, 20.08729771205357, 37.71981075831822, 23.20538173403059, 8.15301535810743, 0.033605362820838175, 0.05115354726357119, 0.01490028465299734, 0.012665861203069133, 0.05091087939217687, 0.025443163301263536, 0.0664697043331606, 0.05210682450394545, 0.024983961334718124, 0.0401654902712575, 0.035390028663511784, 0.04205561063385435, 0.03944542212411761, 0.02864283589380128, 0.05726813844272068, 0.06668222150100128, 0.010106921595122133, 0.01324645902163216, 0.031947182690990825, 0.03319743435297694, 0.04375302705115505, 0.03543059487960168, 0.018560731716986214, 0.013286778420609022, 0.10163085974220719, 0.016047594070966755, 0.011638828054336565, 0.023853267543017864, 0.04419389160882149, 0.019046873220109513, 0.0007761475291252801, 0.024707080031345998, 0.057544566823967865, 0.030293874442577362, 0.04945150323744331, 0.01435873906926385, 0.03522702419598188, 0.039696008499179564, 0.011110499484597572, 0.036544684919395616, 0.03610569651105574, 0.02598390312466238, 0.02028898585454694, 0.06511902609573943, 0.027142825669475963, 0.028123266362984265, 0.06696848185466868, 0.01841670078491526, 0.02646587503009609, 0.04697857218395386, 0.028175925769444023, 0.013697254787465292, 0.02563462552747556, 0.013461143260688653, 0.0822117371218545, 0.08877527421074254, 0.017839372656973343, 0.024575620656833053, 0.06603777608168976, 0.045298899457390816, 0.08933594091130154, 0.035842927039733956, 0.005623603239655495, 0.46151748086724964, 13.34239559514182, 37.94578007289341, 32.68144614355904, 22.009732246398926, 22.13949854033334, 39.6938738822937, 38.81002480643136, 15.321929556982857, 2.0123511723109653, 0.1747488094759839, 0.03813940506162388, 0.16668374224432878, 2.6495109711374556, 7.132325853620257, 4.3433814729963025, 4.786318276609693, 3.401933567864554, 1.6889950377600533, 0.7457917896764619, 0.7991631286484855, 3.6756226761000494, 11.383034859384809, 23.849868842533656, 40.58886439459664, 53.60145418984549, 56.967349188668386, 53.2563475881304, 52.00152376719883, 51.01928472518921, 46.90327957698277, 48.37213223321097, 47.67482491901943, 48.74337100982666, 51.06876284735543, 51.61339044570923, 53.58735629490444, 50.80461318152291, 48.573713370731895, 49.039381640298025, 53.200449330466135, 51.784427302224294, 50.72623055321829, 43.5777153968811, 38.42387866973877, 39.18619680404663, 38.614217621939524, 37.13310834339687, 40.82014908109392, 39.005495003291536, 40.94666535513741, 45.15288938794817, 49.76907450812203, 49.89101191929409, 52.96293558393206, 44.65135451725551, 46.198259762355256, 45.46031590870449, 50.01383522578648, 49.90956013543265, 51.67338119234358, 50.08676699229649, 49.47716678891863, 44.3730583190918, 36.79856300354004, 36.83455467224121, 36.31448548180716, 39.02562393460955, 46.80216939108712, 47.346776144845144, 49.194062437329976, 48.20988137381417, 44.05450425829206, 39.499126298086985, 40.743103981018066, 44.88336181640625, 49.29376908711025, 48.15914215360369, 47.93792193276541, 45.17923348290579, 48.40840877805437, 45.95597607748849, 45.06277125222342, 42.56198256356375, 41.94219282695225, 43.85916607720511, 44.23220443725586, 44.851389680589946, 45.86556264332363, 45.74572706222534, 40.451786858694895, 21.917203085763113, 6.395947515964508, 0.7502308200512613, 1.5177456097943443, 3.38445993406432, 4.6297540834971835, 3.9264535137585233, 3.135056516953877, 3.332611607653754, 4.021467523915427, 2.5112185861383165, 0.15276268709983143, 0.07420682880495276, 0.25772108935884064, 4.436086075646537, 23.474963154111588, 37.77983972004482, 24.603637218475342, 24.311500208718435, 46.82814870561872, 26.585166181836808, 11.775064383234296, 0.03533596299322588, 0.04379599867388606, 0.024221393146685193, 0.020652137796527574, 0.05693950357713869, 0.024848198351849402, 0.05117077866036977, 0.055073593344007216, 0.09206141930605684, 0.021459175473345176, 0.011467814329080284, 0.046425935945340564, 0.04001216171309352, 0.017588131495618393, 0.04872272948601416, 0.06401492069874491, 0.0046900586457923055, 0.026906203545097793, 0.0428102399621691, 0.012933399079234471, 0.0190836294620697, 0.04446184848036085, 0.005984689890673118, 0.020542863124449338, 0.06912848952093295, 0.022405433268951516, 0.027313092158042958, 0.041624259137149365, 0.11133150849491358, 0.07083000428974628, 0.09544272893773657, 0.09370151308498212, 0.10780608481062309, 0.2337540654199464, 0.14039325155317783, 0.07571604674948113, 0.12394202074834279, 0.12796782329678535, 0.11836476145046097, 0.09203168590153966, 0.14608351407306536, 0.09872446355542966, 0.1425009441695043, 0.15865062044135161, 0.1254832994725023, 0.11973091028630733, 0.11515126031424318, 0.10943988856992551, 0.15521776250430516, 0.15503781501735958, 0.10753024675484214, 0.123135649732181, 0.18499893588679178, 0.14007744778479847, 0.20503497576074942, 0.17509028900946888, 0.07591635707233634, 0.18171038877751144, 0.10506783638681684, 0.09480003413877316, 0.17411648269210542, 0.09692917524703912, 0.06972230944250311, 0.3950799730207239, 12.334497724260602, 41.90896306719099, 41.057193824223106, 30.601655755724224, 26.534967184066772, 38.479749134608674, 42.655849252428325, 22.940806491034373, 4.252636696611132, 0.4552528384540762, 0.31944025467549053, 2.4457370255674635, 6.675117015838623, 11.311622142791748, 8.00212914603097, 3.4909931889602115, 1.7884904188769204, 1.5527198016643524, 1.3925969366516386, 0.6909136144178254, 3.696617526667459, 11.470464042254857, 24.237979582377843, 41.177265644073486, 53.82102768761771, 58.28120837892805, 56.08257252829415, 53.27090753827776, 54.82700872421265, 48.23853574480329, 51.289493220193044, 51.70652757372175, 52.808966977255686, 53.06833975655692, 53.76779406411307, 55.57939093453543, 51.637688296181814, 49.5846380506243, 49.960563387189595, 55.19643749509539, 54.16808673313686, 53.78801679611206, 46.396182673318044, 40.9515951020377, 42.61499384471348, 40.29855823516846, 39.78592014312744, 44.23111704417637, 40.9322304725647, 44.33635098593575, 47.16214166368757, 50.53333813803536, 53.435048307691304, 55.469143867492676, 48.67699486868722, 44.47483900615147, 45.66456862858364, 49.317313058035715, 51.48332016808646, 54.59452199935913, 52.59789112636021, 51.805480343954905, 47.046447208949495, 39.39685576302664, 38.535550117492676, 38.73538030896868, 41.16988665716988, 48.94846098763602, 49.82295778819493, 50.65383727209908, 49.63579763684954, 46.626546723502024, 40.42484521865845, 43.74715069362095, 47.07583808898926, 52.13407802581787, 51.47057022367205, 47.84833186013358, 46.85407938276018, 49.95037732805525, 47.42534984861101, 48.1614420073373, 45.15223625728062, 44.27035699571882, 46.46067237854004, 46.46495246887207, 47.116196700504844, 47.76025996889387, 47.06645802089146, 40.17335169655936, 20.337729896817887, 5.4179364527974805, 0.772763828081744, 2.167564157928739, 6.220477274485996, 8.793392607143947, 8.080998148236956, 4.43259026323046, 6.670827805995941, 7.438985466957092, 7.890101603099278, 2.5972585635525838, 0.5404313749500683, 0.4803226717880794, 7.68942894254412, 28.65653361592974, 39.05926363808768, 28.689448969704763, 27.775693110057286, 47.66148785182408, 33.09845617839268, 12.192068338394165, 0.1080230667388865, 0.15337737197322504, 0.1140601895749569, 0.12027099701975073, 0.13450238694037708, 0.08406926744750567, 0.18057742528617382, 0.18660669747207845, 0.250234133963074, 0.09956018121114799, 0.11318721356136457, 0.1750049835869244, 0.17067641871316092, 0.05923548287578991, 0.19072841773075716, 0.15770848813865865, 0.0935829933732748, 0.0855919678828546, 0.14851554642830575, 0.11033673544547387, 0.1721707699554307, 0.13635109631078585, 0.10402289245809827, 0.11420796093131814, 0.22649896544005188, 0.1318435338991029, 0.11996789542692048, 0.1252426773841892], [0.014895005650552256, 0.06437278685293027, 0.030379193435822214, 0.0288873663438218, 0.01948906940275005, 0.017556214904678718, 0.09130663052201271, 0.036602373966681104, 0.05351241997310093, 0.030626478738018444, 0.08211633509823255, 0.010194997985049017, 0.01407649225023176, 0.027538818706359183, 0.01341132606778826, 0.05323612390618239, 0.0652616134445582, 0.07561572534697396, 0.008073666814847716, 0.03910007494102631, 0.07808041559266192, 0.024217092931004505, 0.029330995931689228, 0.05610076304791229, 0.09450442357254879, 0.014803316909819841, 0.06230339075305632, 0.036536186268287044, 0.013736088194751313, 0.047249741918806515, 0.027949191596625105, 0.05921289444501911, 0.07125729814703975, 0.02353699558547565, 0.03744454788310187, 0.02452901717541473, 0.226693596424801, 7.6985857997621805, 32.35703475134713, 32.70524372373308, 24.40674958910261, 19.66079991204398, 25.38727763720921, 35.18114396503994, 21.690521580832346, 4.118399236883436, 0.36764430520789965, 0.08440508799893515, 0.9809807666710445, 4.33534631558827, 4.414358624390193, 5.217694580554962, 2.9127158990928104, 0.5733374463660377, 0.37462233219827923, 0.47473132610321045, 0.8830819513116563, 3.8531022497585843, 11.843256609780447, 24.707926205226354, 40.846441064562114, 55.42357758113316, 53.07270669937134, 51.50133684703282, 50.56829105104719, 48.823699133736746, 49.2703640801566, 50.871486118861604, 49.85103893280029, 50.261510712759836, 51.440408093588694, 53.060655048915315, 48.54687247957502, 50.2060467175075, 48.59898049490792, 52.6041236604963, 50.24500526700701, 50.10241780962263, 48.21022878374372, 44.71706363133022, 38.704558100019185, 36.615821906498496, 37.09753704071045, 37.03013604027884, 40.092398234776084, 47.11021082741873, 49.65116705213274, 51.04785571779524, 50.59842191423689, 54.104462078639436, 37.63399008342198, 46.76802246911185, 52.5387932232448, 47.087882791246685, 49.225478717258994, 48.981319018772666, 50.34170682089669, 44.50197866984776, 39.28820678165981, 33.26661648069109, 36.692245142800466, 35.69652312142508, 38.23323399680001, 41.14551932471139, 44.57984365735735, 47.63361167907715, 45.647020953042166, 43.919386114392964, 40.69297967638288, 39.311990465436665, 45.046321392059326, 47.02270174026489, 48.60365315846035, 48.5707152230399, 47.37941530772618, 46.541882923671174, 46.20286989212036, 44.56135450090681, 43.98630421502249, 42.70680734089443, 44.83963680267334, 43.912465708596365, 44.05724879673549, 46.15527820587158, 37.953773975372314, 20.50427300589425, 4.198579711573465, 0.49066213411944254, 0.19348639116755553, 0.3523940406739712, 2.489141119377954, 3.3749927963529314, 3.374729416200093, 2.132989921740123, 2.3858057728835513, 6.002157058034625, 1.184890853507178, 0.04249974912298577, 0.12722347038132803, 5.458421868937356, 22.229324851717266, 29.72651277269636, 24.235059601919993, 21.103815691811697, 18.719150509153092, 22.281997408185685, 10.449779748916626, 0.4432177171111107, 0.039750996977090836, 0.04505854878308518, 0.00820299728573965, 0.030552131656025137, 0.030547066392110925, 0.025074009717042958, 0.02866818935477308, 0.05536069168842264, 0.027938721801287363, 0.06773290583597762, 0.022697238950058818, 0.0775187039481742, 0.04404484799930027, 0.027532944289435233, 0.03855444796915565, 0.04743655278746571, 0.02922952441232545, 0.004790949593630752, 0.03920311726895826, 0.038057380355894566, 0.04602864690657173, 0.017302395310252905, 0.016598807082378438, 0.04568228192095246, 0.0381951704621315, 0.007333614115071083, 0.02464541307251368, 0.021074541112674133, 0.053778768716646094, 0.016719275885926824, 0.038856100889721086, 0.06973528303205967, 0.0351033102987068, 0.027822670260710374, 0.04664045479148626, 0.01687259426606553, 0.05685300732563649, 0.03921746828460267, 0.05555568229673164, 0.018199454227994596, 0.14066417701542377, 0.00519600064892854, 0.015025588018553597, 0.07132868003100157, 0.059434707542615275, 0.025750797508018355, 0.04820146531398807, 0.0426409556530416, 0.07541525896106448, 0.056926787830889225, 0.043595664602305205, 0.0830527880628194, 0.10739869238542658, 0.014173597396750535, 0.08010861104620354, 0.04013235401362181, 0.07584601334695305, 0.04522899338709457, 0.04645135047446404, 0.08981219107019049, 0.036259184524949105, 0.019971835194155574, 0.06021418821598802, 0.02226830643069531, 0.8141193975295339, 13.5916075025286, 38.23822627748762, 33.57510954993111, 21.68107029369899, 22.01853735106332, 37.64885228020804, 43.25206027712141, 21.055006333759852, 4.138184666633606, 0.1778173076787165, 0.10239724468972002, 0.28294253455741064, 2.9690920625414168, 5.29471058504922, 8.828598260879517, 10.667720420019966, 3.5702517245497023, 2.3250057782445634, 1.0998548907893044, 1.7992657721042633, 4.683818450995854, 14.283051405634199, 26.26932712963649, 43.86690984453474, 54.58664274215698, 55.61665064947945, 52.70093291146414, 53.65191200801304, 50.63389941624233, 51.751732553754536, 52.23465667452131, 53.472658906664165, 51.997615405491416, 53.103521960122244, 53.03773988996233, 48.873451709747314, 49.28651516778128, 48.799748693193706, 53.09523623330252, 51.863671507154194, 51.86954273496355, 49.20660393578665, 44.93398986543928, 39.569966656821116, 39.06880004065377, 38.60837071282523, 39.88165937151228, 41.45496082305908, 47.27384785243443, 48.951452187129426, 53.52013594763619, 51.97406448636736, 56.069318839481895, 38.69100216456822, 47.97979177747454, 52.14662299837385, 48.43042067119053, 51.44321516581944, 50.4309321131025, 50.21890435900007, 47.0867953981672, 41.03113807950701, 33.90311663491385, 38.5110889843532, 36.31249482291085, 39.252923829214915, 42.8829858643668, 45.405122893197195, 47.57947131565639, 46.59411948067801, 46.35388898849487, 42.646236419677734, 41.61184767314366, 46.70014551707676, 48.405848366873606, 49.1281726700919, 48.86583648409162, 47.97720357349941, 47.78073631014143, 46.79961940220424, 45.27692862919399, 46.65881068365914, 44.8355130468096, 45.97903714861189, 46.06884956359863, 44.67390489578247, 45.86608723231724, 40.27165828432356, 24.621111937931605, 6.8025087629045755, 0.908744634262153, 0.9080301097461155, 1.554933780006, 3.10648552434785, 3.7573360971042087, 4.065297194889613, 4.603200674057007, 3.6787610905511037, 3.022876547915595, 0.27987582768712727, 0.04936055579621877, 0.1470441296696663, 4.765554453645434, 24.604048899241857, 36.5401942389352, 26.8032614503588, 21.25390546662467, 21.410939965929302, 29.265183653150284, 15.564696141651698, 1.030153928058488, 0.06715672782489232, 0.07318205093698842, 0.041367352208388705, 0.0419574401873563, 0.028769189292298894, 0.051921251961695294, 0.002918862995492028, 0.028116255399904082, 0.06343234410243374, 0.03871877218729683, 0.017690985530082668, 0.0017442143414103026, 0.018140662561303804, 0.07291984464973211, 0.024245185977114097, 0.02271917089819908, 0.02066859566340489, 0.03812976307900889, 0.05310672388545104, 0.032427127473056316, 0.04344180678682668, 0.015729819158358232, 0.013473054942941027, 0.04358755610883236, 0.025857127338115658, 0.0470832260325551, 0.017285937443375587, 0.04083417974678533, 0.13285444251128606, 0.16959606882716927, 0.17437717584627016, 0.11239107485328402, 0.11646723827081067, 0.1982037837484053, 0.11142867470958404, 0.1328931732901505, 0.12609638300325188, 0.19134623743593693, 0.15464155056646892, 0.08717966518763985, 0.16645400385771478, 0.08882347055311714, 0.22696553968957492, 0.1857376162494932, 0.14059732774538652, 0.09941783813493592, 0.11379151006362268, 0.11588482452290398, 0.18375029574547494, 0.09874967113137245, 0.14618144024695667, 0.17743620170014246, 0.17954432857888086, 0.09468549064227513, 0.152709802080478, 0.15452334976622037, 0.12791280767747334, 0.14691858712051595, 0.10346717227782522, 0.23503940073507174, 0.21054354017334326, 0.10497715696692467, 0.1287793376083885, 0.11965357086488179, 0.9945246513400758, 12.074945160320826, 43.25846651622227, 44.2337087222508, 32.53664915902274, 26.374175446374075, 34.35975572041103, 43.90102202551705, 28.698785611561366, 6.076237882886614, 0.8315976453678948, 0.16345643970583165, 3.6785947680473328, 9.85273494039263, 9.381090351513453, 9.764280898230416, 8.4924669946943, 3.1904440820217133, 1.5351156720093317, 2.2074819930962155, 1.7768913784197398, 4.127278166157859, 12.997417535100665, 27.36528560093471, 42.61234310695103, 57.34622403553554, 56.895984240940635, 55.15002005440848, 55.93085861206055, 53.51546675818307, 52.939419405800955, 54.95987565176827, 54.58565262385777, 54.70020062582833, 54.89071328299386, 55.92839200156075, 49.02649968011038, 50.26059702464512, 48.861268043518066, 55.56059258324759, 53.65426744733538, 54.19066490445818, 53.024427141462056, 48.89547055108206, 42.53145912715367, 41.84069006783621, 40.363350187029155, 41.06489937646048, 42.36279855455671, 50.22401475906372, 52.941253730228965, 55.908270018441335, 54.65861218316214, 57.94694791521345, 41.70279611860003, 48.43168871743338, 50.53179563794817, 51.22525017602103, 52.19379431860787, 52.42653117861067, 53.26397671018328, 47.81438643591744, 44.197651045663015, 35.68946722575596, 40.28201804842268, 39.43070043836321, 41.256131172180176, 45.1614738873073, 46.968439783368794, 50.79750517436436, 48.36091436658587, 48.845926421029226, 44.06024694442749, 43.11519813537598, 49.082307611192974, 51.42155763081142, 50.04071085793631, 50.77137647356306, 49.00038834980556, 48.85828379222325, 48.77932446343558, 47.934409618377686, 48.304564476013184, 47.6112037386213, 47.800542150224956, 47.02380650384085, 47.166525976998464, 47.78622191292899, 38.53105810710362, 23.4088545186179, 5.71581050327846, 1.0913308624710356, 0.961424953171185, 2.771715453692845, 6.258061383451734, 5.329371239457812, 9.846112438610621, 6.618938224656241, 9.59018075466156, 12.32976860659463, 3.547371957983289, 0.2783250223313059, 0.5672221630811691, 7.574284264019557, 28.662568126405986, 38.28062765938895, 32.27000856399536, 29.778731959206716, 30.094346932002477, 33.631657464163645, 16.84611245564052, 0.757363743015698, 0.21744516412062304, 0.12937988181199345, 0.10310051909514836, 0.11729494242795876, 0.1564058366098574, 0.2006802058645657, 0.07020987078015294, 0.13868398112910135, 0.09087804066283361, 0.10673907492309809, 0.13383014872670174, 0.15725167122270378, 0.15698344632983208, 0.19426813136254037, 0.13873236067593098, 0.1668981864516224, 0.09674150603158133, 0.18839690355317934, 0.1476605244513069, 0.12142476439476013, 0.15506235084363393, 0.16528635365622385, 0.06896356479930026, 0.14881020704550402, 0.20507718063890934, 0.09071683431310312, 0.1276204405086381, 0.16079496751938546], [0.03787378574322377, 0.034179895384503264, 0.014159637386910617, 0.011459861898661723, 0.08733631856739521, 0.01551725618940379, 0.020352147286757827, 0.08098822313227824, 0.02123788993672601, 0.02984088785680277, 0.012167328802336539, 0.009807454405485519, 0.06035655164825065, 0.059728153582130156, 0.042272612918168306, 0.025604235640327846, 0.008964533252375466, 0.0667686600770269, 0.014793004873873932, 0.048053069705409665, 0.06358601192810706, 0.005207856352041874, 0.02420924906618893, 0.06026558045830045, 0.09076146834662982, 0.03795330665473427, 0.042527016052710157, 0.024444293596648743, 0.017858861879046475, 0.03263175667130521, 0.03702446685305663, 0.05890452742044415, 0.02622900524043611, 0.019429098781464354, 0.022318953980824778, 0.03866009587155921, 0.041084267398608584, 0.20024341930236134, 7.175336939947946, 28.446989842823573, 30.459613731929235, 26.17240149634225, 17.828143051692418, 23.834742614201136, 33.58997869491577, 21.64042854309082, 4.725561056818281, 0.5932398012706211, 0.10037319508514234, 2.211900613137654, 2.5861299378531317, 10.262303454535347, 19.170726094927105, 4.4881345970290045, 3.210453591176442, 0.5550710665328162, 1.3781337184565408, 0.46558646538427895, 3.994292684963771, 10.938683663095746, 25.47278216906956, 44.14282281058175, 53.44994177137102, 54.207441329956055, 51.416534083230154, 52.35442277363369, 53.589572770254954, 53.54133490153721, 51.62165185383388, 53.31741530554635, 52.408281735011506, 50.53349447250366, 52.02549852643694, 49.218672956739155, 47.30824490955898, 51.519728728703086, 51.79445007869175, 52.56543609074184, 50.41515622820173, 50.6953319140843, 45.58969136646816, 40.550274099622456, 38.74696295601981, 40.28471047537667, 41.28634541375296, 48.33326053619385, 50.20306246621268, 55.1403933252607, 48.719886098589214, 53.67044980185372, 39.788084506988525, 44.77219411305019, 54.67234182357788, 49.22379725319998, 53.18698719569615, 47.743559973580496, 48.37859753199986, 44.913454464503694, 42.80206366947719, 43.021675382341655, 36.36793449946812, 35.96880217960903, 38.5429881640843, 41.0155428477696, 44.8053891318185, 45.21954345703125, 47.47428601128714, 42.86381231035505, 43.0234089578901, 42.40995945249285, 44.17430509839739, 45.85856580734253, 47.77570581436157, 50.38659218379429, 47.82399926866804, 48.82495675768171, 47.15351547513689, 44.07196855545044, 45.321084431239534, 45.339771611349924, 43.583531039101736, 46.474534034729004, 44.720909459250315, 34.27516835076468, 17.634757314409526, 4.039003474371774, 0.19718494984720433, 0.13101988738136633, 0.9788126030138561, 1.4202048437935966, 1.6644995978900363, 2.909784193549837, 2.8162644803524017, 3.759045788219997, 2.6677780023642947, 0.9001635547195161, 0.2528587616980076, 0.32011672694768223, 5.700429362910135, 24.001935379845754, 28.627339022500173, 23.1783185005188, 22.248288222721644, 21.134622267314366, 17.530461379459926, 8.58134835106986, 0.4805105988468443, 0.08290621092809097, 0.049600909863199504, 0.023671211508501853, 0.012400951801932283, 0.10648369469812938, 0.029820141648607593, 0.024577496806159616, 0.05717355744647128, 0.06621519263301577, 0.0354144186047571, 0.018396176796938692, 0.04425367393663951, 0.06481075406606708, 0.049295457146529637, 0.03527762255232249, 0.05289319230775748, 0.04613410481917007, 0.02320014705349292, 0.048589655198156834, 0.05805944598146847, 0.01120139773203326, 0.03592611543302025, 0.07635075519127504, 0.00760617823938706, 0.06300914859665291, 0.09847109857946634, 0.011788858084141143, 0.06075489241629839, 0.02257980659071888, 0.02460816489266498, 0.029210915589439015, 0.06593255565634795, 0.026167650407712375, 0.03696750723091619, 0.012748594977892935, 0.04876160954258271, 0.06309861343886171, 0.02746042246664209, 0.055158905551901886, 0.008482928604020603, 0.01166984558637653, 0.01232094913055854, 0.06934869449053492, 0.026853971615699784, 0.03825482726097107, 0.016175175617848123, 0.016282173804938793, 0.02684189538870539, 0.08142589857535702, 0.0979630658403039, 0.016294322974447693, 0.014125380698325378, 0.039515463901417594, 0.023580272548965046, 0.08537926072520868, 0.04117887892893382, 0.04222804334546838, 0.042931677374456606, 0.025088630450357283, 0.023368174376498376, 0.032998956074672084, 0.012149992232610072, 0.01081394321019096, 0.03356997721961566, 0.023267476387055855, 0.0022328165941871703, 0.5210278247083936, 12.738287074225289, 35.17263242176601, 33.46776335580008, 23.698646511350358, 19.805100100381033, 35.25345039367676, 44.22684737614223, 21.36689533506121, 4.691916576453617, 0.3381632885762623, 0.05198589938559702, 0.6005751990846225, 2.144061876194818, 10.498507465635027, 15.93304967880249, 6.986573491777692, 6.5678667937006265, 1.720652007630893, 1.561573000890868, 1.0281921476125717, 5.838270766394479, 13.820234503064837, 29.912422248295375, 47.349795137132915, 55.90165533338274, 55.90480286734444, 52.20222248349871, 54.53000102724348, 54.458146231515066, 55.97190856933594, 52.61955908366612, 55.43825912475586, 53.24104070663452, 50.937945638384136, 51.923217569078716, 49.19306189673287, 47.01271023069109, 52.75934989111764, 53.214974539620535, 53.46340390614101, 52.31337629045759, 51.865960938589915, 46.738940783909385, 40.5878985949925, 40.48261948994228, 41.4592478615897, 42.685295718056814, 49.8576466696603, 51.71157891409737, 56.70444672448294, 50.88741486413138, 53.8244948387146, 43.28812837600708, 45.31893048967634, 55.16014705385481, 48.84925808225359, 53.1694221496582, 49.90884447097778, 50.37838288715908, 45.87780884334019, 42.90159314019339, 43.89697469983782, 38.048926080976216, 37.33251469475882, 40.54394429070609, 43.30473109654018, 46.57394886016846, 47.63908338546753, 48.71726662772042, 44.46472590310233, 44.56542614528111, 42.04623515265328, 45.26785428183419, 47.78776788711548, 48.01116289411272, 49.462860448019846, 47.03209570475987, 49.048317023685996, 48.1161710194179, 44.976012570517405, 46.39054421016148, 46.27975170952933, 45.93054914474487, 46.29024696350098, 47.014033862522666, 37.134577887398855, 22.236436332975114, 6.8859692215919495, 0.6993509531021118, 0.7841214186378888, 2.725712299346924, 2.6478544771671295, 3.096961498260498, 5.027365616389683, 4.164946956293924, 3.6169735831873755, 2.5974954536982944, 0.3032168080764157, 0.07681459494467292, 0.0535051562557263, 4.551463518823896, 23.608978271484375, 32.47172866548811, 27.116781541279384, 24.59854245185852, 24.77504059246608, 23.435189928327286, 13.42849680355617, 1.610061221889087, 0.03216861580897655, 0.10418326420975582, 0.03131876426881977, 0.0604727982676455, 0.01071959630852299, 0.04331601317971945, 0.07171832198011023, 0.04896856950862067, 0.06862927773701293, 0.04211871439058866, 0.020477711888296262, 0.044329008287084956, 0.043637082379843505, 0.038506377155759504, 0.04463520739227533, 0.04833357947479401, 0.03150797375876989, 0.001816241257724219, 0.04388184013909527, 0.013783940180603946, 0.02788659674115479, 0.05043698035712753, 0.07264963164925575, 0.05499887985310384, 0.043014852197042534, 0.05360638350248337, 0.03367016970046929, 0.01914798002690077, 0.010314843384549022, 0.1135318957801376, 0.1521907499326127, 0.153654919937253, 0.130760700574943, 0.20663144652332577, 0.14582881916846546, 0.10586681137127535, 0.22565321225140775, 0.2137739775436265, 0.1296867017767259, 0.08791175018996, 0.09205998759716749, 0.18193596095911094, 0.15392944163509778, 0.11734945593135697, 0.09211585138525281, 0.20537679456174374, 0.14133499030555996, 0.1623031065932342, 0.13451059721410275, 0.1843922170145171, 0.14994646821703228, 0.06225805104311023, 0.1457959780735629, 0.1785068078232663, 0.143235159771783, 0.19975705897169455, 0.08411566567208086, 0.14822182218943322, 0.17942114733159542, 0.11751165294221469, 0.12260955439082213, 0.09977765168462481, 0.1258683545248849, 0.07138657263879265, 0.09437436876552445, 0.1133156263136438, 0.5142104476690292, 11.029335941587176, 37.93122707094465, 41.69676160812378, 34.41579294204712, 24.746445281164988, 30.343717779432023, 43.87789494650704, 27.80180617741176, 6.27227783203125, 0.9313207971198219, 0.3956532265458788, 4.793593040534428, 7.935863307544163, 15.622329711914062, 25.186688355037145, 10.048132181167603, 6.693087228706904, 2.17342192360333, 2.8033147752285004, 1.229192784854344, 4.771816951887948, 12.532967805862427, 28.88448143005371, 47.57498277936663, 58.31718267713274, 57.492980412074495, 54.45877504348755, 56.441009249006, 57.51817110606602, 58.77814701625279, 54.8447961126055, 57.40104879651751, 54.55030713762556, 52.531952721732004, 54.14975391115461, 49.04085118430001, 47.50740112577166, 51.04752567836216, 57.062077454158235, 56.57200711114066, 54.67045886175973, 53.7869085584368, 51.17459086009434, 42.876395498003276, 42.685073375701904, 44.07404259272984, 44.679011821746826, 52.06371709278652, 53.6791524205889, 58.621166365487234, 53.13164826801845, 52.78846631731306, 45.76387575694493, 47.937445981161936, 54.57432011195591, 51.83806044714791, 54.994995321546284, 50.44229589189802, 52.05748803274972, 48.53081519263131, 45.04556751251221, 48.33797141483852, 39.717529024396626, 40.26828840800694, 42.94625268663679, 45.532952376774375, 48.15227733339582, 49.163104738507954, 50.5423812185015, 46.7207920891898, 47.49995265688215, 44.576157638004844, 48.31458377838135, 49.82781457901001, 50.72334705080305, 49.828676155635286, 47.49055174418858, 50.05938414164952, 50.218195642743794, 45.88306515557425, 49.45884438923427, 48.61731679098946, 45.27055365698678, 47.8330215045384, 46.197752543858115, 36.74091727393014, 19.698657172066824, 5.254686789853232, 0.5253440131034169, 0.6811849421688488, 4.001513600349426, 4.892445930412837, 6.477379534925733, 9.499757766723633, 8.076085771833148, 9.87980512210301, 6.060086360999516, 3.8411552565438405, 0.8075935734169823, 0.534882478415966, 7.583296077592032, 29.48588275909424, 36.580302715301514, 30.78553635733468, 31.022376128605433, 33.31838403429304, 28.348726681300572, 13.684918335505895, 1.558146887591907, 0.14161610736378602, 0.1618846133351326, 0.19416814244219235, 0.0877151039562055, 0.23392597905227117, 0.09622123252068247, 0.17725024239293166, 0.24683730623551778, 0.2566028636481081, 0.11031133109437567, 0.12642887873309, 0.12021024099418096, 0.09620165000004427, 0.1836672837712935, 0.16559149085411004, 0.08406196641070501, 0.18330894942794526, 0.120310922020248, 0.12032332564038889, 0.14094990811177663, 0.05218243705374854, 0.10571970497923237, 0.22038962612194674, 0.12590703102094786, 0.19878090492316655, 0.08397942262568645, 0.131163234689406, 0.15925496444106102, 0.13980679373656], [0.013646264577151408, 0.06386713577168328, 0.05224526261112519, 0.036007960326969624, 0.019275712547823787, 0.014846987423620053, 0.03935393524755325, 0.04578405538839953, 0.0187956371477672, 0.04054033676428454, 0.037307487202009985, 0.05328034403334771, 0.044203737151942084, 0.02807512430341116, 0.03543772967532277, 0.09856760661516871, 0.042309559149933715, 0.024044855298208337, 0.01879781694151461, 0.0586427418248994, 0.058614189071314673, 0.02886760061872857, 0.08127387280442885, 0.013864162527689976, 0.03278102759005768, 0.04234419836263571, 0.043872391538960595, 0.02175853155287249, 0.018940187159127424, 0.04248311483700361, 0.009275807799505336, 0.07038929579513413, 0.0687610763790352, 0.05193056146215115, 0.06725953266556774, 0.014567110388140594, 0.01995071579170014, 0.01190021331422031, 0.25595334278685705, 6.5774431484086175, 26.158124685287476, 32.27232231412615, 19.161768129893712, 19.27528953552246, 24.604962587356567, 30.650525910513743, 23.540696586881364, 7.015230902603694, 0.4362205554332052, 0.05530382366850972, 1.6320687724011285, 11.34008891241891, 14.202104892049517, 6.096079766750336, 7.522587060928345, 0.9358660046543393, 1.5183699705771037, 1.0474226985658919, 1.3798009604215622, 2.2359164101736884, 11.18723462309156, 27.43813920021057, 45.54435089656285, 53.73035022190639, 54.75622395106724, 53.46441486903599, 55.1200316292899, 55.013352462223594, 52.97888169969831, 50.958585262298584, 48.98511620930263, 51.88297707693917, 52.32644932610648, 50.4327768598284, 50.722957951681956, 51.30965689250401, 52.01403399876186, 51.37014096123831, 52.151754243033274, 51.737255981990266, 50.83738088607788, 44.83947352000645, 40.003586360386436, 41.26051548549107, 40.72321128845215, 49.59726987566267, 50.913567883627756, 56.29783466884068, 50.23722675868443, 42.60746199744088, 35.026563916887554, 43.70127173832485, 52.09166969571795, 50.698632308415, 54.24058771133423, 49.300342082977295, 50.37511028562273, 47.26975883756365, 50.254545143672395, 48.60577583312988, 45.19395324162075, 37.33433512278965, 39.027680601392476, 40.36481973103115, 44.11758000510079, 45.47856535230364, 46.449940885816304, 45.055159500667024, 43.26155846459525, 45.267114298684255, 47.75925595419747, 47.04824331828526, 48.04429190499442, 48.960755825042725, 49.571144648960654, 47.679330825805664, 47.41841902051653, 47.97335079738072, 46.95823982783726, 47.87242473874773, 46.87247126443045, 41.870772293635774, 30.06752688544137, 14.168446949550084, 3.800513505935669, 0.5146735342485564, 0.0488902394260679, 0.38510339121733395, 1.4293326054300581, 1.4636961157832826, 2.088483669928142, 2.202054364340646, 2.3375366372721533, 3.0959418501172746, 2.6214478484221866, 0.16996445905949387, 0.47354899240391596, 6.480045906135014, 22.411159208842687, 29.21432978766305, 25.13485826764788, 23.708071742738994, 24.243175097874232, 16.225914512361797, 4.754801247801099, 0.2956589050590992, 0.018771096232480237, 0.03715791094249912, 0.03419878579942243, 0.05252213543280959, 0.05581725076107042, 0.022732281891096915, 0.04451290824051414, 0.03677907805623753, 0.056317907824580155, 0.045986180792429616, 0.0210309316670256, 0.010301637396748577, 0.07013411913067102, 0.02548322400876454, 0.06657418515533209, 0.034017644090844054, 0.008967260114981659, 0.03350344346836209, 0.002666273245787514, 0.02827609789424709, 0.022979982795992067, 0.0062921612490234625, 0.034823082121355195, 0.018535491910630038, 0.06696023086884192, 0.0681103952229023, 0.03509124255340014, 0.021985369202281748, 0.019982783356681466, 0.04918113417391266, 0.018752802928377475, 0.018618866901046464, 0.08482595612960202, 0.07143770703779799, 0.03362591903922813, 0.04712342244705983, 0.011099723500332661, 0.029627522520188774, 0.025008456448891332, 0.06285626108625106, 0.08234878083957092, 0.05000655845339809, 0.032494170125573874, 0.032462387545300384, 0.028191252179177742, 0.0474817398270326, 0.04121622549636023, 0.03960167856088706, 0.02083169173316232, 0.027682177888761674, 0.024620772073311464, 0.022171447253120796, 0.060868194193712304, 0.044744970609566996, 0.009995677475152271, 0.03560565352173788, 0.04174089930685503, 0.03089729224198631, 0.10894687859607594, 0.02577334861936314, 0.04998622954423938, 0.04893437473635588, 0.055465946040515385, 0.041535679783139906, 0.03431404175769005, 0.012518323941289313, 0.08629452304116317, 0.06346053044710841, 0.602809479194028, 11.030336482184273, 32.35779905319214, 35.61448226656233, 18.43668712888445, 18.610070739473613, 31.08074794496809, 36.846648011888774, 23.85828311102731, 5.330372214317322, 0.4257586582430771, 0.06516353799296276, 0.23736088616507395, 1.7249317722661155, 6.551263638905116, 4.094710222312382, 8.845692566462926, 3.8522788882255554, 1.8942005293709892, 1.2722672734941756, 2.0598127969673703, 3.8619234221322194, 13.14284246308463, 31.359346389770508, 49.617940766470774, 54.81777804238455, 54.871703011649, 54.31858124051775, 54.4226861000061, 56.80220093045916, 54.67335626057216, 51.56536102294922, 50.05506236212594, 51.60916594096592, 52.53147677012852, 48.41114289419991, 50.514324392591206, 53.433908803122385, 53.2402903011867, 53.26891687938145, 54.11631570543562, 54.134731905800955, 51.25225782394409, 46.02105985369001, 42.09750938415527, 42.74199301855904, 43.371656145368306, 52.50478526524135, 51.53668928146362, 57.773656368255615, 51.67668158667428, 44.083453927721294, 38.57785769871303, 45.2553961617606, 52.153664997645784, 49.29569721221924, 54.251586709703716, 50.46961273465838, 51.11141089030674, 48.23425218037197, 50.28747960499355, 48.69347946984427, 45.61415249960763, 38.8604930468968, 41.14169086728777, 42.428264481680735, 45.97821031297956, 46.28770392281668, 47.528398581913535, 46.418830326625276, 44.75403847013201, 46.92473561423165, 48.85045664651053, 48.90687949316842, 48.68006249836513, 50.22501877376011, 49.35894318989345, 49.08640010016305, 48.84218481608799, 47.274052824292866, 48.25921010971069, 48.42510182516915, 48.34314087459019, 44.72056552342006, 32.846545764378135, 18.34110770906721, 5.683750646454947, 1.3629109753029687, 0.8935269394091198, 1.3975292891263962, 3.976418878350939, 3.998082058770316, 3.7465025527136664, 2.691161730459758, 2.3996413733278, 1.6975164605038506, 0.5324317727770124, 0.09139320480504207, 0.11538768905614104, 5.3530459233692715, 25.511860574994767, 32.46311289923531, 27.95839946610587, 25.272446496146067, 27.9101859160832, 22.614043133599417, 8.959238290786743, 1.0355116405657359, 0.01141324230203671, 0.052593476604670286, 0.024162369081750512, 0.0579006891431553, 0.020765921333804727, 0.07896629734230892, 0.027889745143641318, 0.05863051462386336, 0.052148700292621336, 0.0930096244971667, 0.027991282820169414, 0.04392643685319594, 0.018965442232521515, 0.038785872515290976, 0.005796498203250978, 0.03610891955239432, 0.03745685650834015, 0.022483826115993515, 0.025872094124289494, 0.0615867017103093, 0.033339848675365956, 0.022938989102840424, 0.0536389497907034, 0.05669528525322676, 0.027238602583695735, 0.0828553004456418, 0.08626887441745826, 0.012243158483345593, 0.008316714665852487, 0.05623020717341985, 0.12080836961311953, 0.15164310431906156, 0.22834481139268192, 0.1236217657902411, 0.10991309889193092, 0.146304580782141, 0.1259041540324688, 0.2219014157141958, 0.08427831730140106, 0.2076410252068724, 0.15096973973725522, 0.12783378548920155, 0.1281561167644603, 0.11707671199526105, 0.1565359253436327, 0.1821462389613901, 0.1638306246272155, 0.16106336883136205, 0.08280095657599823, 0.1633613362376179, 0.116903441292899, 0.0895565055044634, 0.2306159766657012, 0.12818796719823564, 0.11404428471411977, 0.10548746279839959, 0.1273003483989409, 0.07878267219556229, 0.26037418842315674, 0.16944406341229165, 0.17534243262239865, 0.17152439749666623, 0.20528341457247734, 0.14620399475097656, 0.18614213168621063, 0.07734662746744496, 0.17900245051298821, 0.1605576023991619, 0.5071743652224541, 10.359550442014422, 36.712203843253, 44.9338960647583, 28.612096411841257, 25.50120724950518, 30.653187070574077, 39.4379335130964, 31.399357591356548, 8.687460371426173, 1.1173896470240183, 0.3110932968556881, 3.5216714399201527, 18.19449029650007, 23.47796998705183, 12.456121597971235, 14.061350890568324, 4.1421633788517545, 3.5603353423731665, 3.1770494750567844, 2.071161593709673, 2.820282927581242, 12.95999106339046, 31.28395148686, 49.08025441850935, 56.6226282119751, 58.21411657333374, 55.93122686658587, 58.013838223048616, 58.48198699951172, 55.367168630872456, 52.93282209123884, 49.980706214904785, 51.99710471289498, 53.134340694972444, 49.285222802843364, 51.32773263113839, 53.8950503213065, 52.61529983792986, 54.41403906685965, 55.06888593946184, 56.65633739743914, 53.404340744018555, 48.06281927653721, 44.29036085946219, 44.66017525536673, 44.5632826260158, 54.459775584084646, 54.208907399858745, 59.13124752044678, 52.77647720064436, 43.89487634386335, 40.61243268421718, 47.06690270560128, 52.12495504106794, 51.084048884255544, 55.160702909742085, 53.63287394387381, 54.36654812949044, 51.51035213470459, 52.657760279519216, 52.600632190704346, 48.56732797622681, 40.428135190691265, 42.66972827911377, 44.74318190983364, 48.26308025632586, 50.04136746270316, 49.85711860656738, 48.7624750818525, 46.00417225701468, 50.751014777592246, 51.045298780713765, 50.73020144871303, 49.75136354991368, 50.610511779785156, 50.30782740456717, 50.64176477704729, 50.21139683042254, 49.33113649913243, 49.121780327388215, 50.828011240277974, 50.187477656773154, 44.45966414042881, 31.83590943472726, 16.447146892547607, 4.946811241762979, 1.040313171488898, 0.580251826771668, 1.7236660059009279, 4.801778018474579, 3.8919318233217512, 6.5677395548139295, 9.802365711757115, 5.240303150245121, 8.839014479092189, 5.460085962499891, 0.47822990694216316, 0.8704994150570461, 8.455379247665405, 29.59418433053153, 36.42761952536446, 31.38523190362113, 32.37449210030692, 35.102208954947336, 24.842022963932582, 8.408140182495117, 0.7982617084469114, 0.10616627601640564, 0.18867840059101582, 0.07031473836728505, 0.14593369354094776, 0.1711272916623524, 0.1279899842504944, 0.08637775893190078, 0.15907151571341924, 0.1591908564524991, 0.17415777833334037, 0.11814290764076368, 0.2124880858297859, 0.20844769477844238, 0.12006906499820096, 0.14744792585926397, 0.17438786955816404, 0.14831389939146383, 0.1410031731107405, 0.10031844409448759, 0.25235906136887415, 0.05765609083963292, 0.10769444544400487, 0.13410217341567787, 0.1358613297343254, 0.15859131648072175, 0.22209551744163036, 0.17367683271212236, 0.1544052982436759, 0.0909218740250383, 0.13913650970373834], [0.02370187789866967, 0.0211529763681548, 0.019223638377817612, 0.023692064585962465, 0.021923218787248646, 0.04237450512924364, 0.0607692434319428, 0.050784430998776636, 0.023069527366065552, 0.028621482396764413, 0.06644125335982867, 0.015338027949577995, 0.017341894530025975, 0.07833085608269487, 0.039171809663197825, 0.020044577540829778, 0.023090024212641374, 0.029811198557061807, 0.07235611097088882, 0.04849597326080714, 0.059990889126701016, 0.009778430918231606, 0.028816435685647384, 0.029373909878943647, 0.023377402452751994, 0.03933189982282264, 0.02093374339996704, 0.014143235499172338, 0.027231303243232623, 0.032743989756064754, 0.02632522998776819, 0.03540353151038289, 0.022504918377048204, 0.023086880899167488, 0.028848079166242054, 0.018814210347565155, 0.06768901140562125, 0.0956118537911347, 0.04630178778565355, 0.23613653757742473, 6.625780897481101, 26.816164255142212, 32.78436286108834, 22.35029125213623, 16.29322692326137, 18.933179344449723, 32.67437982559204, 28.970736367361887, 8.073818053518023, 0.8563035396592957, 0.016013811508725797, 1.9372350658689226, 5.869494233812604, 5.0244395562580655, 10.011482170649938, 4.357889311654227, 1.4089308487517493, 0.7636519713061196, 0.46110438874789644, 0.5464535089475768, 2.8080881876604895, 12.290651985577174, 26.37990771021162, 44.876472677503315, 52.53908504758562, 59.0231682913644, 53.20583071027483, 52.597748688289094, 51.11978694370815, 52.83133670261928, 52.87675360270909, 55.104509353637695, 52.69687516348702, 53.03718055997576, 52.07311453138079, 52.964398179735454, 50.2053553717477, 52.00945513589041, 52.727638312748496, 53.6945218358721, 51.49497924532209, 51.913382393973215, 41.61849362509591, 41.79815667016165, 41.314742701394216, 48.74096693311419, 51.90460681915283, 55.06094414847237, 54.32281616755894, 58.3571000780378, 37.94751017434256, 40.5448579788208, 55.55300862448556, 49.329548835754395, 54.59861101422991, 51.65520470482962, 52.130701201302664, 50.467938218797954, 50.70780045645577, 50.273472036634175, 48.26139531816755, 40.91116006033761, 39.37820332390921, 41.6150403703962, 43.01015874317714, 45.03598594665527, 44.56507526125227, 46.0615747996739, 46.503243991306846, 45.93984236036028, 47.39263425554548, 49.29912614822388, 48.571861675807405, 48.562311376844136, 48.76752642222813, 47.72450801304409, 48.048433031354634, 49.04267856052944, 47.84863063267299, 45.30572196415493, 35.4190468106951, 24.64783297266279, 9.379542640277318, 2.1775956196444373, 0.24958583446485655, 0.4053384725536619, 1.0107301303318568, 1.7530140025275094, 3.747688089098249, 4.962740855557578, 2.6784888676234653, 1.4849532608475005, 2.174120217561722, 0.4955062227589743, 0.023372635744245987, 0.30203195022685186, 6.13124373129436, 23.835223776953562, 27.74482226371765, 24.072322368621826, 22.90166207722255, 21.017348834446498, 15.585096052714757, 3.751615558351789, 0.08066564758441278, 0.00241107346872533, 0.019509869893746715, 0.05210613239822643, 0.022064398175903728, 0.04509159004581826, 0.06515726832939045, 0.04651070871789541, 0.03035328018346003, 0.03466464758717588, 0.016087846464610527, 0.05365375203213521, 0.03311329261798944, 0.019199628416182737, 0.039607283260141096, 0.06786738469132356, 0.023440365413469926, 0.07095927878149919, 0.012229975396102028, 0.022785431539107646, 0.0554929517342576, 0.01811536168679595, 0.050048997426139455, 0.08988108273063387, 0.07889436584498201, 0.015355654593024935, 0.026755443241979395, 0.046730272471904755, 0.028486426786652634, 0.05963343009352684, 0.0379442041074591, 0.01807136377984924, 0.02424035480778132, 0.06936926088695015, 0.033123684381800036, 0.07248447622571673, 0.039869808458856175, 0.018934156679149185, 0.03997332915397627, 0.01970699110201427, 0.044058696899030886, 0.03449392139113375, 0.06775417790881225, 0.024939264536702206, 0.05354886408895254, 0.07516150043479033, 0.029669204926384345, 0.0395729459955224, 0.07334992050060204, 0.02846267127564975, 0.0465695987721639, 0.004784150248659509, 0.04587173229083419, 0.039735709583120685, 0.057500679178961685, 0.023172194803399698, 0.054236097926540036, 0.021538340153970888, 0.0428643090251301, 0.01198121767291533, 0.0336333625683827, 0.00585951841536111, 0.018313436236764704, 0.03427198276455913, 0.03968445983316217, 0.05689920198970607, 0.025779776042327285, 0.02691087356236364, 0.03975459660536476, 0.04434949325929795, 0.05825499298849276, 0.47524934687784737, 11.566575867789131, 34.29139934267317, 34.93790142876761, 19.80944446155003, 17.71862554550171, 26.923696313585552, 47.41386447634016, 31.416710717337473, 7.244469778878348, 0.3935316375323704, 0.021373746218159795, 0.5980648366468293, 0.5433375132935387, 1.5896194045032774, 5.939213326999119, 5.961880956377302, 3.794915863445827, 2.325596809387207, 1.9657118235315596, 1.003575548529625, 3.723321190902165, 14.784458603177752, 30.80428954533168, 48.45338099343436, 55.551799637930735, 59.41571371895926, 55.11382688794817, 53.270653929029194, 51.07104533059256, 55.0516995702471, 53.32668072836739, 53.919890131269185, 52.007117067064556, 53.91306005205427, 52.720554624285015, 51.93604394367763, 49.96207114628383, 51.90526342391968, 53.455868584769114, 54.88532148088728, 53.7567846434457, 53.05457190104893, 41.82760313579014, 43.15339585712978, 42.692671230861116, 50.08851793834141, 54.21003648212978, 57.39207172393799, 55.902652399880544, 56.028560706547324, 37.71623938424246, 42.16895423616682, 54.42329059328352, 51.03540454592024, 54.84838833127703, 52.480209486825125, 54.28614704949515, 50.98038523537772, 52.34781156267439, 53.17706864220755, 49.91388191495623, 41.53443431854248, 39.86198902130127, 42.988497734069824, 44.98076513835362, 46.64337526048933, 46.516518524714876, 47.331642968314036, 47.61303458895002, 47.44024331229073, 48.52235228674752, 50.6984030178615, 48.70719868796212, 49.220799105507986, 49.443297794886995, 47.84674767085484, 49.088449818747385, 50.55126101630074, 50.51230594090053, 47.515374183654785, 39.00012404578072, 28.6649808883667, 13.139438714299883, 4.016374060085841, 0.5720906789813722, 1.3515963767256056, 2.0665670973914008, 3.358948754412787, 3.8967378054346358, 5.78395539522171, 3.409862982375281, 2.8439456692763736, 1.2560043632984161, 0.4688285599861826, 0.12138781137764454, 0.2928540041404111, 4.846632983003344, 25.363162176949636, 32.78810446602957, 27.979032141821726, 24.689296347754343, 25.57446210724967, 22.58385147367205, 7.300031917435782, 0.31810929466571125, 0.002195242081402934, 0.042363957302378755, 0.0738449932209083, 0.012239707284606993, 0.07879728105451379, 0.10506487797413554, 0.07244558938379798, 0.047297785590801916, 0.02060702709215028, 0.029188995515661578, 0.02922382132549371, 0.006595892183083508, 0.015794914415372268, 0.0684099548629352, 0.025131652963214686, 0.01990260765887797, 0.04996446892619133, 0.035254589681114466, 0.038439293791140826, 0.027360721923676983, 0.004034696022115115, 0.061747412729476175, 0.06595367845147848, 0.05537906641672764, 0.016620952769049575, 0.0749673308538539, 0.038311576537255726, 0.0636597415432334, 0.03882214699738792, 0.031900933744119744, 0.018256636070353643, 0.13428856698530062, 0.1326422103281532, 0.08406592905521393, 0.18163539708725043, 0.07999276476246969, 0.1405104345508984, 0.1465123210634504, 0.08260840190840618, 0.08862420517419066, 0.14691387808748654, 0.15687055167342934, 0.12443560069160801, 0.07231610454618931, 0.1745620494974511, 0.07107918948999473, 0.1101653239290629, 0.19572780946535723, 0.08821784412222249, 0.1756509082125766, 0.13924830513341085, 0.13994129294795649, 0.14006904752126761, 0.19619698928935186, 0.17061672120222024, 0.08243279026022979, 0.12864927601601395, 0.09291752015373536, 0.09218724005456481, 0.09772912053657429, 0.12436816788145474, 0.11331642019961562, 0.14818800400410378, 0.11530850401946477, 0.1749242107783045, 0.1831176704061883, 0.10404915854867015, 0.23500525685293333, 0.1567556621240718, 0.19184719984020504, 0.517832413315773, 11.202735185623169, 38.735838890075684, 44.91160971777779, 31.33047662462507, 24.382012265069143, 28.002411093030656, 43.424452032361714, 35.93202883856637, 10.232726710183279, 1.2863083886248725, 0.08806319920612232, 3.9450425505638123, 11.88516901220594, 9.473774978092738, 18.648900747299194, 10.749086431094579, 3.955812692642212, 1.5827726061855043, 1.6730602128165108, 1.4059621223381586, 3.4941878403936113, 14.2554383959089, 29.49277537209647, 46.99474913733346, 55.54208605630057, 62.30745669773647, 55.837203843253, 52.912974561963765, 51.21406705038888, 54.105386189052034, 54.007142135075156, 55.29989617211478, 54.11941807610648, 53.840388842991416, 52.79091903141567, 51.936707496643066, 50.68486792700631, 52.59043223517281, 53.47721692493984, 56.95113556725638, 54.79572098595755, 56.51281540734427, 45.305652482169016, 45.13454614366804, 45.50798055103847, 51.395439352308, 55.8909273147583, 59.412684304373606, 57.53666721071516, 59.66930212293352, 43.04706062589373, 44.33310617719378, 54.79481424604143, 51.09846987043108, 55.16681385040283, 53.848330633980886, 55.07312086650303, 53.22203390938895, 53.46895899091448, 55.52794647216797, 51.61138241631644, 44.34219094685146, 43.14327580588204, 45.3257987839835, 46.34689562661307, 50.19988366535732, 47.533189364842, 49.63912582397461, 51.416871070861816, 49.99784394672939, 51.435916083199636, 53.01481778281075, 50.355262756347656, 49.43498427527291, 49.989881311144146, 49.79905251094273, 49.02915736607143, 52.80586460658482, 52.19604206085205, 47.89301225117275, 37.67587729862758, 27.948835270745413, 10.690249953951154, 3.2002911993435452, 0.5167252070137432, 1.1195417429719652, 2.709807872772217, 4.305990610803876, 8.099029592105321, 12.088017327444893, 9.15664529800415, 5.6186877148492, 8.177515574863978, 3.0910312107631137, 0.5799749844840595, 0.8720936466540609, 8.042767422539846, 31.065333366394043, 35.278102602277485, 31.860801356179373, 30.035297666277202, 31.32715538569859, 24.793210131781443, 6.531278882707868, 0.3055558811341013, 0.15165358089974948, 0.18082519913358347, 0.18604033786271298, 0.10293811852378504, 0.1880404691078833, 0.15525813533791474, 0.1767402554729155, 0.13121985165136202, 0.11200680011617285, 0.0893573486911399, 0.08121486739920718, 0.0999163171010358, 0.10276891903153487, 0.19524763737406048, 0.2281278973179204, 0.11044594565672533, 0.1267378700098821, 0.15961730214101927, 0.1131594954058528, 0.20259678230753966, 0.1295736035598176, 0.1923402776675565, 0.2910066246986389, 0.1175861018044608, 0.11700010539165565, 0.12109942042401858, 0.16322169373078005, 0.11697323540491716, 0.132179232314229, 0.1580162580524172, 0.16820120438933372], [0.03398270293005875, 0.0694736602849194, 0.04751443503690617, 0.029863639135978053, 0.011684292445092328, 0.023295269181419696, 0.04315602819302252, 0.023333362137366618, 0.0656607820253287, 0.03943336455683623, 0.03429869668824332, 0.029120039394391433, 0.062198061762111526, 0.05778302438557148, 0.029704468391303505, 0.009862227448528367, 0.03917291567527822, 0.054562558087387254, 0.08849205369395868, 0.06618661952338048, 0.008761111846459764, 0.0796510816684791, 0.011808921516473805, 0.02120994447198297, 0.01607135297464473, 0.023687411532072083, 0.031325376592576504, 0.041337472918842516, 0.056308035140058825, 0.058871089214725156, 0.03027589326458318, 0.06491345034113952, 0.06972577675644841, 0.013078573342811848, 0.060925292915531566, 0.011568357951806059, 0.016613558433683853, 0.06730374600738287, 0.02199194420661245, 0.03570528621120112, 0.054101099991904836, 3.942673214844295, 23.075311456407817, 32.54273578098842, 26.12305886404855, 12.39528317110879, 15.359074626650129, 27.5733893598829, 26.72352044922965, 11.538156867027283, 1.698922602193696, 0.027409915712528994, 0.08851809586797442, 0.3753739318677357, 3.705746591091156, 4.469298464911325, 3.3698808763708388, 2.8373596455369676, 2.113559284380504, 0.4982609120862824, 0.2464119190616267, 1.7838228579078401, 8.240588716098241, 21.65033667428153, 36.84474767957415, 50.851840087345664, 52.590185574122835, 51.59505067552839, 52.47780193601336, 51.626824787684846, 52.335923194885254, 52.52198553085327, 53.42154448372977, 51.64880888802664, 51.973022256578716, 52.25671720504761, 52.372369970594136, 54.48227037702288, 52.04430382592337, 55.386651379721506, 52.90158299037388, 51.991261277879985, 46.18451622554234, 42.80118819645473, 43.92514269692557, 44.644555704934255, 49.89371476854597, 55.08721876144409, 52.34190559387207, 57.28042459487915, 41.17790835244315, 39.569671358381, 57.81315687724522, 50.808108125414165, 52.97369834354946, 50.90650503976004, 51.11123023714338, 50.403222697121755, 52.87778888429914, 50.110766070229666, 52.39165122168404, 45.39775432859148, 39.95022766930716, 42.21773059027535, 46.03171839032854, 46.371589524405344, 47.64331136431013, 45.42393166678292, 47.906623772212434, 48.075239181518555, 49.81271961757115, 47.984520026615684, 49.50523403712681, 49.518915040152415, 48.83311741692679, 49.32230186462402, 48.118123463221956, 45.97980839865548, 41.372402327401296, 33.38248464039394, 21.221535546439036, 8.082654425076075, 0.9468251594475338, 0.1916237718292645, 0.49351491246904644, 1.9008556008338928, 3.0024431986468176, 2.2106078139373233, 2.794982148068292, 3.609202023063387, 2.763650115047182, 1.7335739199604308, 0.9852337156023298, 0.10698587846543108, 0.44528038214359966, 7.687689287321908, 27.370022535324097, 31.192617416381836, 21.460994788578578, 21.3477235180991, 24.691438129970006, 14.310287475585938, 4.388044059276581, 0.07986112218350172, 0.0024102407790321323, 0.03344688757455774, 0.03352207264729908, 0.050048885467861376, 0.016330665310046504, 0.04221604684633868, 0.0214469652356846, 0.04778393218293786, 0.051689712064606805, 0.020165981026366353, 0.018644188131604875, 0.027560109438906823, 0.08312239897038255, 0.04284838720091751, 0.028839271781699996, 0.022121549484186938, 0.03673242198835526, 0.010887386992440691, 0.030671058488743644, 0.023954219983092377, 0.011679379851557314, 0.03407152655667492, 0.025903735908546617, 0.07945832344038145, 0.04818409142483558, 0.057491736087415896, 0.08027627026396138, 0.023816794589427964, 0.01809121262548225, 0.03183688343103443, 0.03237664107499378, 0.020079610303842595, 0.06110340157257659, 0.06951704581401177, 0.03152522551161902, 0.02886794667158808, 0.0291991769336164, 0.024973569570907524, 0.007833933607409043, 0.018121675455144474, 0.08672717732510396, 0.015622403672231095, 0.00711881706956774, 0.016266262158751488, 0.027845779467107992, 0.049945995810308626, 0.024125051352062395, 0.012850047837543701, 0.02315690740942955, 0.032852273767015765, 0.023030277507911836, 0.02625252665685756, 0.014492882049775549, 0.07203822410000221, 0.028783245145210197, 0.02942334794040237, 0.07282394051019635, 0.022557996778881977, 0.015324489479618413, 0.029040409917277948, 0.04891906698633518, 0.04533626638086779, 0.06396054968770061, 0.04566122019397361, 0.049469905107149055, 0.024104291573166847, 0.02123218006454408, 0.050294050348124335, 0.012324857492265957, 0.029677866425897394, 0.07832358897264514, 0.04437890435968127, 0.26933380908199717, 8.952256219727651, 31.696862084524973, 34.75082812990461, 25.494906970432826, 15.574564320700508, 23.96094969340733, 43.4563546861921, 31.47816753387451, 10.014298796653748, 1.155486402767045, 0.046577842972640476, 0.14469183874981745, 0.14821540324815682, 2.5440040954521725, 3.694643804005214, 4.248592410768781, 3.094049551657268, 2.8649344401700154, 1.1562702464205878, 0.26308037606733187, 2.5799486466816495, 12.001251697540283, 25.696670498166764, 41.87188400541033, 51.77884789875576, 53.59832055228097, 52.759676456451416, 53.76618555613926, 52.54277801513672, 53.88357189723423, 52.93140465872628, 51.86567606244768, 53.424184799194336, 52.46814741407122, 53.15286806651524, 52.0466696875436, 54.28373602458409, 52.154616900852744, 56.052924564906526, 54.09466164452689, 54.80786991119385, 48.36755684443882, 43.60278797149658, 45.32036529268537, 47.13636384691511, 51.73908335821969, 56.49183184759957, 55.50131402696882, 59.99476964133126, 41.90393604551043, 40.1153689793178, 56.49950960704258, 49.638358048030305, 53.69732543400356, 51.45657655170986, 52.283297538757324, 52.00580038343157, 54.04651757649013, 52.56512689590454, 52.53695542471749, 45.818558079855784, 41.47681638172695, 44.586972509111675, 47.409236976078574, 48.155119146619526, 50.03921699523926, 46.16032607214791, 49.16219105039324, 48.6859267779759, 51.12386553628104, 49.51289095197405, 50.058095250810894, 48.968294620513916, 50.34510449000767, 49.95396259852818, 48.32601703916277, 46.84984792981829, 43.76611927577427, 34.7668194089617, 24.482113225119456, 10.97320578779493, 2.309866739170892, 0.6281764837247985, 1.3912590827260698, 3.7748989718300954, 5.021981196744101, 5.257024424416678, 3.816589031900678, 2.6602602686200822, 2.5725657514163425, 1.2884576618671417, 0.29542885454637663, 0.05067971947469881, 0.1610867375774043, 5.6816965852464945, 26.048947640827723, 36.45197296142578, 24.898885284151348, 23.200665644236974, 28.15388182231358, 19.552701575415476, 7.565843071256365, 0.26583126559853554, 0.047299634598727734, 0.008361837244592607, 0.09636482410132885, 0.02732306153380445, 0.05858949039663587, 0.004044969890466226, 0.05363832214581115, 0.012744996197787779, 0.039848329432840855, 0.04512619533176933, 0.023393310706264207, 0.054798593278974295, 0.04720554214769176, 0.04365834766732795, 0.08569851823683296, 0.022122224626530494, 0.03874667015458856, 0.045682122465223074, 0.027512751087280254, 0.0687355227502329, 0.06044181635869401, 0.04336633672937751, 0.04024752854768719, 0.021407503335337554, 0.07064691518566438, 0.1029257895424962, 0.03349852408947689, 0.028431002349991883, 0.0478598670368748, 0.015141183244330543, 0.024452631095690385, 0.008222170140860336, 0.1414655947259494, 0.243091738649777, 0.1239474897405931, 0.11338618717023305, 0.06577869784086943, 0.07082378890897546, 0.12689322738775186, 0.09801188643489565, 0.17943211245749677, 0.1593950954931123, 0.06648375000804663, 0.095839420865689, 0.1702173219195434, 0.17030053745423043, 0.10220177232154778, 0.15089786930808, 0.08674925685461078, 0.18350185693374702, 0.13690165962491715, 0.19285164879901068, 0.06157773147736277, 0.19231639323490007, 0.13571752102247306, 0.1312672541077648, 0.19603673288864748, 0.09815027365194899, 0.09359291355524745, 0.14037588105670043, 0.10901710018515587, 0.16673727865730012, 0.1183978875300714, 0.17395527634237493, 0.12567774046744618, 0.039982428308576345, 0.13968663875545773, 0.09122806295220341, 0.1131235941180161, 0.17263853842658655, 0.1464545370212623, 0.08092489545898778, 0.3779215051659516, 7.687442626271929, 34.061942032405305, 42.790300369262695, 35.75101089477539, 20.162265300750732, 22.41041054044451, 35.52707045418875, 34.41671010426113, 14.148925985608782, 2.263015470334462, 0.18735976277717523, 0.9130281444106783, 4.418270460196903, 7.451821395329066, 9.076536910874502, 11.401335545948573, 6.80355794089181, 6.827224808079856, 1.0717674493789673, 0.6542860769799778, 2.5767533438546315, 10.087628347533089, 25.24957823753357, 40.80054126467024, 52.36513689586094, 53.89832987104143, 51.679089137486045, 52.28753593989781, 53.52314451762608, 52.60089274815151, 53.86419684546334, 54.126817907605854, 53.58448321478707, 53.031114782605854, 53.52940484455654, 52.565901620047434, 54.55392367499215, 52.57282549994332, 58.169488293784006, 56.10740886415754, 56.77948032106672, 51.01058210645403, 45.3000487600054, 47.518247263772146, 48.32607609885079, 54.73503541946411, 59.1502161026001, 57.80334254673549, 58.944639750889365, 45.17459208624703, 42.79579986844744, 54.117152963365825, 50.511750085013254, 52.971773692539756, 50.89753838947841, 52.30947835104806, 52.67621469497681, 55.032998493739534, 53.65613303865705, 56.597236020224436, 48.65707090922764, 43.72174807957241, 47.7407112121582, 50.391355173928396, 51.46016877038138, 52.529757090977256, 49.20235858644758, 51.118581431252615, 51.66165958132063, 52.08608681815011, 51.53396558761597, 49.636617524283274, 51.0797792162214, 50.65894419806344, 50.3101098878043, 48.136372906821116, 48.53238895961216, 43.32914706638881, 35.312485763004844, 24.553417376109532, 10.326468331473214, 2.292980879545212, 0.4709633397204535, 1.6664732119866779, 5.589647284575871, 6.970189205237797, 7.31395263331277, 7.970945630754743, 8.429807271276202, 8.665249586105347, 6.50839238507407, 2.589937116418566, 0.5022866332105228, 0.6653167222227369, 9.35480271066938, 33.708869321005686, 40.764660767146516, 29.468244756971085, 30.14168153490339, 34.45398371560233, 24.64843920298985, 6.8278184447969705, 0.2956255482775824, 0.11675079805510384, 0.16754378538046563, 0.213169592831816, 0.09109763495091881, 0.07964268140494823, 0.10279886956725802, 0.13250301565442765, 0.09791242677186217, 0.08434363986764636, 0.12171253109616892, 0.08310236183128186, 0.10940390585788659, 0.22858200009380067, 0.11803473558809076, 0.17881560911025318, 0.07318016460963658, 0.1477828507444688, 0.10688685985015971, 0.22300892057163374, 0.23587456877742494, 0.09223096485116652, 0.17203133100909845, 0.1516824457794428, 0.20537055203957216, 0.15680607727595738, 0.1043935761387859, 0.12934013323060103, 0.08621193175869328, 0.1369026909981455, 0.07934255858084985, 0.10129588057420083, 0.09430259333125182], [0.058045427447983196, 0.022364139324054122, 0.04133411417050021, 0.03868590055831841, 0.042588135094514916, 0.027375558091859733, 0.008118115099413055, 0.034814885418329916, 0.02340490178072027, 0.044128497796399255, 0.0017330877453787252, 0.006086055388940232, 0.010119721310080161, 0.022393331596893922, 0.02512220266674246, 0.0017198593871268842, 0.0074438361916691065, 0.0288838515324252, 0.011992407563541616, 0.06299114027725798, 0.029159228184393475, 0.03765635937452316, 0.01483418686049325, 0.0691964855151517, 0.024098915879481604, 0.0255431352582361, 0.029466319563133374, 0.004728797906344491, 0.1223638297191688, 0.04756349990410464, 0.02259321783536247, 0.023009458357202153, 0.06611656756805522, 0.04471176989110453, 0.0709862301924399, 0.014023377377140735, 0.049410882738551924, 0.015910474018060734, 0.006385329620180917, 0.07416575029492378, 0.06046449299901724, 0.011718397311467146, 4.303678163460322, 22.378865718841553, 31.430172852107457, 25.690106187547954, 19.73290136882237, 15.169774430138723, 24.814325707299368, 27.208605459758214, 13.724210398537771, 2.842064444507871, 0.20766554746244634, 0.0847148663763489, 1.6855982371738978, 2.683315477200917, 3.9311326912471225, 2.2247041889599393, 2.2240875363349915, 1.4092354838337218, 0.15661053705428327, 0.21527172146098955, 0.5010059933577264, 5.898043513298035, 15.469625677381243, 31.348250116620743, 43.19195141111101, 49.10071686335972, 51.5028862953186, 53.391865253448486, 52.73472547531128, 54.440216405051096, 53.02482666288103, 55.02121434892927, 51.8827234676906, 55.90065826688494, 51.78551122120449, 54.30219044004168, 52.276780128479004, 54.51532643181937, 54.44224875313895, 55.76905591147286, 49.436592783246724, 48.03835119519915, 46.048362800053184, 47.9777455329895, 47.47171170370919, 54.64973585946219, 53.95710468292236, 61.60176985604422, 42.79750565120152, 36.30484485626221, 58.31739807128906, 50.25805050986153, 56.018784591129844, 52.372821603502544, 52.91514239992414, 52.4455692427499, 53.08580405371529, 53.090806756700786, 52.76520027433123, 47.949303082057405, 45.50041743687221, 47.61599799564907, 48.631584916796, 47.13317462376186, 49.07888214928763, 48.708609172276084, 50.615406785692485, 48.25529132570539, 49.73575789587838, 51.521691594805034, 50.196277550288606, 50.88533387865339, 48.33643238885062, 44.358540058135986, 41.198249203818186, 33.481437410627095, 24.725564207349503, 14.891627618244716, 5.048269271850586, 0.7312947532960347, 0.31588635966181755, 0.5262608496206147, 1.3507566217865263, 2.1616657887186324, 3.2320357816559926, 5.3007533465112955, 2.4846037285668507, 1.2387888985020774, 1.0723159228052412, 1.5770397995199477, 0.30738971701690126, 0.46933007878916605, 6.734121552535465, 22.00891409601484, 26.17404474530901, 18.119673831122263, 15.332030500684466, 24.192553997039795, 18.594890662602015, 3.782601918492998, 0.08352303997214351, 0.041541515184300284, 0.009397044195793569, 0.020998577420998896, 0.051889622051801, 0.0019810974897284594, 0.039202954420553784, 0.0039131101802922785, 0.05128059955313802, 0.025529447510572414, 0.017412816706512655, 0.07454074267297983, 0.03302745454545532, 0.01896515385513859, 0.05569137233708586, 0.018373201601207256, 0.017538014899141023, 0.02561719565918403, 0.01807568435158048, 0.0570542167073914, 0.03635499366958227, 0.061880351310329776, 0.004540551087952086, 0.03323589371783393, 0.018746777537411878, 0.03904118827943291, 0.01521033953343119, 0.02874421581093754, 0.01580110265474234, 0.010796487048667456, 0.06951878286365952, 0.034115037614745755, 0.07162167145205395, 0.034412056141133816, 0.06249817780085972, 0.011882413644343615, 0.04937765148601361, 0.03356628259643912, 0.04609938757494092, 0.043813162217182774, 0.04752900996910674, 0.04881912556343845, 0.022326003959668533, 0.031073300833148614, 0.019250204720135247, 0.022576039025027837, 0.008110321276555104, 0.03389983344823122, 0.0055874810038533595, 0.010488823156005569, 0.03468949553955879, 0.05023692787757941, 0.01968134247830936, 0.00308701499930716, 0.014535797693367516, 0.06830459194523947, 0.02434754298467721, 0.011125429799514157, 0.05333977352295603, 0.071000133374972, 0.017653013014101555, 0.07273807868893657, 0.0785436514498932, 0.029939655414117233, 0.01320439578765737, 0.03917122273040669, 0.029022961389273405, 0.032336600723543336, 0.01965020620264113, 0.043123580648430755, 0.030698267742991447, 0.03560254243867738, 0.020052557112649083, 0.06760081542389733, 0.051416279415466955, 0.061646412791950364, 8.382233824048724, 30.696338857923234, 36.25425154822213, 23.64874628611973, 14.41558916228158, 17.38092746053423, 35.94440705435616, 32.88737685339791, 15.11111773763384, 2.417134548936571, 0.029213568661361933, 0.2079322524368763, 0.39959611211504253, 1.9828124259199416, 2.682705338512148, 4.9583878091403415, 2.820596465042659, 3.6181243785790036, 0.7902213941727365, 0.472436140690531, 1.22475722857884, 8.401130318641663, 20.142409086227417, 34.52329199654715, 45.46333490099226, 50.916242940085276, 54.11459602628435, 54.6196744782584, 52.960687841687886, 53.64642293112618, 53.942853927612305, 54.78696278163365, 53.42317731039864, 56.32609299251011, 53.44103765487671, 55.34209953035627, 53.57288319723946, 55.79558413369315, 56.38620185852051, 56.62678670883179, 50.91058363233294, 49.304552691323416, 47.82499286106655, 47.992350646427695, 48.68796607426235, 57.55477769034249, 54.75263173239571, 61.3780517578125, 43.70417955943516, 38.39461980547224, 56.919583797454834, 50.578591755458284, 54.93155826841082, 52.43211753027779, 53.31706094741821, 52.29088844571795, 53.0580598967416, 54.18547807421003, 53.25072302137102, 50.88264145169939, 46.27052797589983, 48.07683726719448, 50.667424474443706, 48.13343729291643, 50.63784946714129, 50.35992847170149, 52.029438155038015, 48.666874817439485, 50.45372915267944, 50.69982392447335, 50.203858034951345, 51.51358304704939, 49.699988569532124, 44.98479856763567, 42.00667558397566, 36.72444656917027, 28.409643275397165, 17.46473663193839, 7.701392871992929, 1.3606437998158591, 1.1639489829540253, 1.0582422379936491, 2.325868223394666, 4.85902943781444, 5.350290094103132, 5.869208054883139, 4.797815373965672, 1.2579631039074488, 0.9608567208051682, 0.4282645152083465, 0.06260534562170506, 0.4980039915868214, 6.857493332454136, 26.566317456109182, 33.40024076189314, 23.29591849872044, 18.209454979215348, 29.426732744489396, 24.50862581389291, 7.123998437608991, 0.27406602086765425, 0.015619150096816676, 0.04114724901903953, 0.03413512225129774, 0.07918241074574844, 0.04949093290737697, 0.026794124827054993, 0.013267977911579822, 0.029905803302036862, 0.047967241810900826, 0.020141604655821408, 0.04847066390461155, 0.043489555296088965, 0.06293328838156802, 0.025528037854071175, 0.022936805916417922, 0.03360893530771136, 0.023763834931222454, 0.010853588314993041, 0.013857657921367457, 0.023158800522131578, 0.02135028417355248, 0.0569765515891569, 0.009395049302838743, 0.03304126273308482, 0.06541161039578063, 0.0379454593972436, 0.0696802945541484, 0.008814641474080937, 0.02338949903579695, 0.03443638840690255, 0.02414504947539951, 0.03247313214732068, 0.025895323770652925, 0.23097899290067808, 0.12944635110242025, 0.1491978812430586, 0.11832129449716636, 0.22720028566462652, 0.10024428700229951, 0.13971610074596746, 0.11072029093546526, 0.0883301959506103, 0.14294250761823996, 0.04432493707697306, 0.09347373566457204, 0.08099688123911619, 0.09595731632517916, 0.08133117508675371, 0.09553713351488113, 0.1664156937705619, 0.09726575575768948, 0.12666042202285357, 0.13311575991766794, 0.09227513748088054, 0.19464207201131753, 0.10851429216563702, 0.15263977726655348, 0.17468305943267687, 0.10427281726151705, 0.11689938365348748, 0.12828380348426954, 0.22706924698182515, 0.12563637697270938, 0.14642177735056194, 0.11449810250529222, 0.12882009042160852, 0.11291448319596903, 0.1346087676606008, 0.253380148006337, 0.17031155686293328, 0.15006905235350132, 0.07345688476094178, 0.1189955004623958, 0.09540956893137523, 0.07467767782509327, 7.560641476086207, 32.27431297302246, 44.770721094948904, 35.59815747397286, 27.358947106770106, 21.343792574746267, 31.168774672916957, 36.07240676879883, 18.37394663265773, 4.320979177951813, 0.4224871423627649, 0.6045408834304128, 5.025764490876879, 10.232797929218837, 7.672468389783587, 8.870996168681554, 5.472883241517203, 3.276849925518036, 1.2362906954118182, 0.6481989664690835, 1.2098892778158188, 7.155740414346967, 17.40768323625837, 33.46038784299578, 45.62269183567592, 51.63537802015032, 56.58031715665545, 55.79055363791329, 55.86990206582205, 55.19653476987566, 55.33506447928292, 56.75925064086914, 53.61848075049264, 57.40599243981497, 55.23848451886858, 56.50335543496268, 53.69018268585205, 56.075228282383506, 58.77297755650112, 60.40119062151228, 53.52619825090681, 51.191676480429514, 52.03692831311907, 50.77882841655186, 51.825237546648296, 58.62307712009975, 57.12168604987008, 64.39558492388043, 47.26240069525582, 41.49489906855992, 57.080834116254536, 50.87499843324934, 56.58521911076137, 52.93090786252703, 52.976481097085134, 53.03838954653059, 54.70739548546927, 57.21432638168335, 56.43737881524222, 52.640584332602366, 48.733084201812744, 51.52864326749529, 53.4232884815761, 49.515579904828755, 51.34162902832031, 52.00365686416626, 55.29029376166207, 50.548519951956614, 53.686552252088276, 52.05398614065987, 49.61542899268014, 52.01390893118722, 50.00890547888619, 45.561578954969136, 43.55611344746181, 35.225553376334055, 26.713607106889995, 16.85432001522609, 6.287542590073176, 1.3602946528366633, 1.161325495157923, 1.8973862784249442, 3.2564667335578372, 5.694349254880633, 7.796242730958121, 11.06720449243273, 9.199131795338221, 7.037584560258048, 6.027457620416369, 3.6766926986830573, 0.6360704515661512, 0.8245353986110006, 10.01059627532959, 29.190445355006627, 35.704485757010325, 26.624927248273575, 23.051741429737636, 35.432522841862266, 28.601799181529454, 6.395376460892813, 0.30182838972125736, 0.1847082921969039, 0.09869445195155484, 0.14343227419470037, 0.17774991558066436, 0.19502977335027286, 0.19428058926548275, 0.1078670308259981, 0.12317279273910181, 0.17461458167859487, 0.1736707394676549, 0.1491098209683384, 0.08737185344632183, 0.10504174671534981, 0.107710350304842, 0.06936579357300486, 0.12178689853421279, 0.07737376208284072, 0.07067574613860675, 0.11693086767835276, 0.1507583082254444, 0.10205326814736639, 0.1084398025912898, 0.08351281444941248, 0.13096031200672897, 0.14997694801006997, 0.15851054367210182, 0.15358492226472922, 0.09938121759997946, 0.13605497005794728, 0.14768721801894052, 0.12663659187299864, 0.07753640692681074, 0.12270202514316354], [0.0206703717288162, 0.022891851275094917, 0.02621334295586816, 0.08369800022670201, 0.08924046424882752, 0.041175428578363996, 0.058782017922827175, 0.08501264825463295, 0.021233057071055685, 0.03485450168539371, 0.02311049052514136, 0.012465403298847377, 0.023920376352699738, 0.037060843115406375, 0.03699681655104671, 0.015969045160870467, 0.03034212506775345, 0.05129768506490758, 0.013575014159349459, 0.020075693460447446, 0.015560785907187631, 0.032656350173056126, 0.014328613810773407, 0.03610764051388417, 0.045193590822496583, 0.04197123141161033, 0.14790899040443556, 0.012012113916820713, 0.02887324263740863, 0.028450790127473216, 0.04884130008784788, 0.09179747596915279, 0.028172685764729977, 0.03643888773928795, 0.03652655446369733, 0.05716657532112939, 0.16647518772099698, 0.060275168158113956, 0.0394879526990865, 0.04334555998710649, 0.06038618327251502, 0.06259185634553432, 0.11674610259277479, 3.505309517894472, 17.17174325670515, 30.18680661065238, 26.440122536250524, 21.183007785252162, 22.50751335280282, 29.65295566831316, 25.453172615596227, 19.240829944610596, 3.543664876903806, 0.3658105507493019, 0.14514301025441714, 0.44119608987654957, 0.9316813434873308, 2.7170157602855136, 0.9351213531834739, 3.891859301498958, 0.9303802933011736, 0.19382488514695848, 0.38850472441741396, 0.22003302882824624, 2.6699920892715454, 12.10532442161015, 22.097470624106272, 31.925155571528844, 39.746270247868125, 44.70048175539289, 50.09446907043457, 55.070206097194124, 54.26664693014962, 53.29100867680141, 51.77447748184204, 51.93417140415737, 47.48466314588274, 55.069386209760395, 53.18586506162371, 55.35435962677002, 54.237530503954204, 55.496488503047395, 54.525074754442485, 54.77574838910784, 50.69071136202131, 54.64577191216605, 51.78585515703474, 56.1554730279105, 52.75282900674002, 59.63964721134731, 37.40496356146676, 33.161917550223215, 58.30287633623396, 50.413186413901194, 53.70691742215838, 52.49655512401036, 55.645954677036826, 52.945568561553955, 54.504271847861155, 51.0697842325483, 53.34108781814575, 52.79929161071777, 51.40619516372681, 48.72100823266165, 50.48651075363159, 50.40253135136196, 51.5972706249782, 51.40219300133841, 51.396554538181846, 53.3948529788426, 52.703291824885774, 49.591923236846924, 46.66254186630249, 41.091014180864605, 36.41778087615967, 26.54658283506121, 22.22368986266, 14.632004703794207, 8.506479774202619, 2.064457016331809, 0.6311801682625497, 0.12764376854257925, 0.34724436700344086, 1.3775148945195335, 2.633742034435272, 4.953713842800685, 5.990614797387805, 3.452020743063518, 3.2708868512085507, 0.5702491892235619, 0.25709708141429083, 0.33298161519425257, 0.9136747611420495, 11.591314928872244, 34.582438537052695, 44.00462661470686, 28.20355623109, 26.102884769439697, 21.316764082227433, 14.573167358125959, 4.833220788410731, 0.03625315234863332, 0.07009413306202207, 0.003506951416576547, 0.02032930270901748, 0.033021466473915746, 0.04853412049955555, 0.04409350235281246, 0.06090959840055023, 0.06889725835727793, 0.032711945939809084, 0.05801271527473416, 0.06356195786169597, 0.012201498129538127, 0.10291518404015473, 0.05865721497684717, 0.06884410192391702, 0.0074086592399648255, 0.009472628756027137, 0.023977900855243206, 0.02423956770715969, 0.06715033602501665, 0.05613437767273613, 0.11590812541544437, 0.02211498126520642, 0.04582202960071819, 0.026248738735115955, 0.025477105319233875, 0.0194213685712644, 0.033530886817191324, 0.048046179182295284, 0.014992509436394488, 0.05689426225477031, 0.07926494774541684, 0.07267301396599837, 0.029688963866127387, 0.010032957037245589, 0.059554265412901125, 0.06143299995788506, 0.04445135832897254, 0.033415376408291717, 0.04136294512344258, 0.058409454700137885, 0.04164821481598275, 0.02399139352408903, 0.038241239597222636, 0.02739276404359511, 0.04429604166320392, 0.02182941640993314, 0.051914514108960114, 0.058515285806996484, 0.012050925271718629, 0.014822510969159859, 0.04815623077696987, 0.031061579140701463, 0.05653944950816887, 0.0042310831403093675, 0.0896421501945172, 0.030652137539748634, 0.04616798746532627, 0.003931977694654571, 0.04680056869983673, 0.03279142953189356, 0.10063463462782757, 0.028139440941491296, 0.0629694950101631, 0.04180831854630794, 0.02558514166490308, 0.039557187019714286, 0.041163812058844736, 0.0748400173283049, 0.011665888030880263, 0.02997180779597589, 0.04210490620295916, 0.01183620371323611, 0.040506393049976656, 0.02260511933958956, 0.01920710756842579, 0.3694116718002728, 7.465121115956988, 24.68483907835824, 36.033479486192974, 26.605738060814993, 16.64463380404881, 21.14866805076599, 37.05075134549822, 30.347799846104213, 19.56289631979806, 3.06936086501394, 0.1604563378329788, 0.16087172340069497, 0.5901499156441007, 0.41963813666786465, 3.684712656906673, 3.192115123782839, 6.254239874226706, 1.6694063288824899, 1.134986394218036, 0.5545668878725597, 0.2190417434488024, 4.699059324605124, 15.239039284842354, 25.85046887397766, 35.911472593035015, 43.053824697222026, 48.06181526184082, 51.317560468401226, 55.84073352813721, 54.07509551729475, 53.49996532712664, 54.06108447483608, 52.967281682150706, 50.022655963897705, 55.35504402433123, 54.374100821358816, 54.39318404878889, 56.12348352159773, 57.64629936218262, 57.00823238917759, 54.468968050820486, 53.38458701542446, 55.41676834651402, 53.61590644291469, 56.3716801234654, 54.740996973855154, 60.3641219820295, 41.07010357720511, 35.35128102983747, 56.933990887233186, 50.40021760123116, 55.17063535962786, 53.71363633019583, 56.3712979725429, 54.16233362470354, 55.682748862675254, 51.660259519304546, 54.798264026641846, 52.41319758551461, 52.39064025878906, 49.65646505355835, 51.25572150094168, 51.599587849208284, 52.70968416758946, 51.48280947549002, 51.73057528904506, 53.5077542577471, 53.775475297655376, 50.38345159803118, 48.36934947967529, 43.31582736968994, 39.31099687303816, 31.02700710296631, 26.590585776737758, 19.270561286381312, 11.270346369062151, 2.781141770737512, 1.3715548600469316, 0.7799696528485843, 2.5682850096906935, 2.713072440453938, 4.720916186060224, 3.395048120192119, 5.279603464262826, 5.671127506664821, 2.8485023847648074, 0.3757086124803339, 0.1668969786592892, 0.09966365101614169, 0.8935174942016602, 7.02143303837095, 29.04050496646336, 38.78489664622715, 28.747912849698746, 23.9294205052512, 22.9417827129364, 21.326932770865305, 8.792775954519, 0.47240194252559115, 0.009450951258518865, 0.02610568828614695, 0.05233981307329876, 0.07773838644581181, 0.030591965054294894, 0.031243840432060615, 0.048128064788345776, 0.056068614058728726, 0.01749460562132299, 0.007475127682222852, 0.04143891390413046, 0.025981945551133583, 0.0524552590213716, 0.12884641758033208, 0.053435351965682845, 0.01094794285017997, 0.014923312435192721, 0.0019041200243269227, 0.022309422260150313, 0.04995954276195594, 0.026834261869745593, 0.045378121813493114, 0.015260177930550916, 0.04086217610165477, 0.07012959330209664, 0.03827210615522095, 0.08082867240799324, 0.0359526495449245, 0.04587185103446245, 0.04681240913591214, 0.03864461509510875, 0.03840874953727637, 0.07607226406357118, 0.05672891344875097, 0.17252387957913534, 0.2264422263417925, 0.16677959210106305, 0.14989256539515086, 0.1776385544134038, 0.13779203327638762, 0.15321208084268229, 0.19188861761774334, 0.08486554186258997, 0.09445926028170756, 0.1645327726645129, 0.11940939325307097, 0.1515533612774951, 0.11709142263446536, 0.18676210913274968, 0.04770450287365487, 0.14742296934127808, 0.12576557004026004, 0.09101304199014391, 0.05822333932987281, 0.0813622994880591, 0.12974015676549502, 0.11043450555631093, 0.14669232283319744, 0.14153707160481385, 0.19974837372345583, 0.18186134924846037, 0.12057825124689511, 0.10462224922542061, 0.11572640016674995, 0.09673959256282874, 0.1363931383405413, 0.12358303501137666, 0.1372822363461767, 0.1688221182141985, 0.15966801584831306, 0.21551998385361262, 0.07581562176346779, 0.09820079736943756, 0.10538621858826705, 0.11441680043935776, 0.2028092180511781, 0.2911764213017055, 5.856627472809382, 26.595819507326397, 43.21377917698452, 35.13939223970686, 29.34146445138114, 30.335383415222168, 38.61514173235212, 31.25678403036935, 24.274207489831106, 5.162984464849744, 0.9338923905576978, 0.5184223588023866, 1.1497586986848285, 4.60558477469853, 5.613259434700012, 7.003807629857745, 8.254551121166774, 1.3655162240777696, 0.9272087663412094, 0.9450384953192302, 0.753860168159008, 4.051888040133885, 13.814601251057216, 24.373879398618424, 34.193287304469514, 42.227089813777376, 47.424186025347026, 52.17034067426409, 57.18804134641375, 56.79679870605469, 54.02505111694336, 54.77947262355259, 56.237875189099995, 52.71607998439244, 59.022348403930664, 53.092769622802734, 54.514840057918, 57.54135029656546, 59.98570919036865, 60.854935782296316, 58.918264389038086, 55.65510892868042, 58.28453656605312, 56.120238712855745, 58.417660576956614, 56.53702987943377, 60.397653988429475, 41.98661266054426, 39.04858078275408, 55.385928767068044, 51.410395349775044, 53.71011011941092, 54.7594826562064, 57.8365410396031, 55.57989815303257, 56.629923820495605, 54.63223682131086, 57.90908718109131, 55.799801690237864, 54.083572319575715, 51.75659629276821, 54.59604365485055, 53.2879445212228, 54.104034764426096, 54.189494132995605, 54.470124925885884, 55.812134742736816, 53.12572840281895, 50.33195849827358, 47.44043091365269, 42.69355365208217, 39.13899074281965, 29.006498745509557, 25.050521033150808, 17.02764630317688, 9.871408224105835, 2.4730827467782155, 1.6940791649477822, 0.5941836163401604, 2.419493462358202, 4.248904645442963, 7.90756242615836, 8.604961803981237, 13.279837489128113, 10.366277166775294, 9.147701229367938, 4.01675751379558, 1.1662144213914871, 0.4829093558447701, 1.5549836116177695, 13.949575219835554, 41.205322469983784, 51.82970176424299, 35.36042833328247, 33.998372963496614, 31.589519364493235, 25.02491692134312, 8.25148262296404, 0.4418563315910952, 0.1293226813099214, 0.11331086978316307, 0.10376151398356472, 0.09842359434281077, 0.0828588627544897, 0.09201470217002289, 0.1601862944662571, 0.15172716123717173, 0.10489428748509713, 0.20691491131271633, 0.08200148626097611, 0.0965949288968529, 0.13026718848517962, 0.218687113906656, 0.19044096315545694, 0.171947518363595, 0.09262680182499544, 0.07634981881294932, 0.1368688185300146, 0.15685284190944263, 0.1463179886341095, 0.2889671655637877, 0.08458751213869878, 0.12848711971725735, 0.18075909625206674, 0.1826274288552148, 0.14576020570737974, 0.1801949350961617, 0.1778911730008466, 0.12408135112907205, 0.13567804385508808, 0.1463537338588919, 0.15577387623488903, 0.2670386236693178], [0.038922118954360485, 0.0056642423982598954, 0.055125189146825244, 0.061644743595804484, 0.042581953640495024, 0.04261090333706566, 0.02124036319686898, 0.023816838694204177, 0.14249460665243013, 0.060128814939941676, 0.029986423440277576, 0.022308887913823128, 0.0187942580253418, 0.010446049156598747, 0.008860034618659742, 0.004907595276433442, 0.03398816852963396, 0.030409249144473245, 0.011931009474210441, 0.055038574151694775, 0.034923596906342676, 0.019741933959137117, 0.04367329579378877, 0.058218433521687984, 0.09114034873034273, 0.015755440640662397, 0.03779435304126569, 0.0346704592396106, 0.048193767334201505, 0.012689253697837037, 0.016432494756632617, 0.051905818682696135, 0.01713754183479718, 0.012323424087039061, 0.07946290355175734, 0.04837380303069949, 0.07903768601162092, 0.05575940904340573, 0.04616361430713108, 0.05373191248093333, 0.046996370157493014, 0.023005343042314053, 0.11509975950632777, 0.018985207957614745, 2.2019620835781097, 16.01044566290719, 22.649423360824585, 25.423759153911046, 26.598178420748027, 22.41371440887451, 20.45155007498605, 23.803046669278825, 23.24601479939052, 7.829469885144915, 1.1939329568828856, 0.12654360543404305, 0.4594875212226595, 4.375917715685708, 1.8075472648654665, 7.876816647393363, 3.4852958832468306, 1.4168443041188377, 0.09201428826366152, 0.21556486215974602, 0.07925564503031117, 0.7849407632436071, 5.013063183852604, 10.773371253694807, 22.23913744517735, 31.547837121146067, 40.07424259185791, 45.20105430058071, 49.21352086748396, 52.064432757241384, 52.99002661023821, 50.37042372567313, 48.175199440547395, 48.106367111206055, 46.89738055637905, 52.240149225507466, 57.454067025865825, 55.74075937271118, 52.42382485525948, 56.804111685071675, 56.54512105669294, 57.357827527182444, 55.76909065246582, 56.43100731713431, 55.53219182150704, 54.729181562151226, 32.989657810756135, 43.9703893661499, 51.65161943435669, 53.59798009055001, 55.66456542696272, 53.47631365912301, 54.148871489933555, 53.38998923982893, 54.31964431490217, 56.227240971156526, 55.726793493543354, 52.99247932434082, 53.707688672201975, 53.442062514168875, 53.744937964848106, 51.10764844076974, 53.55105890546526, 53.90530586242676, 52.771620409829275, 48.92962442125593, 42.38323320661272, 35.00926637649536, 25.41403341293335, 19.27144718170166, 11.679883616311209, 7.475411398070199, 4.763859961714063, 2.547177468027387, 0.5946180958833013, 0.04926014957683427, 0.6360827737620899, 0.7288566955498287, 3.2350100449153354, 1.4457206917660577, 1.861003122159413, 3.1573682682854787, 3.8532585842268805, 8.616218754223414, 3.8350629891668047, 0.3948682429535048, 0.1527766513505152, 2.792082360812596, 17.796377624784196, 35.103192125047954, 30.64088875906808, 31.515288284846715, 36.08998571123396, 34.06530843462263, 22.389927250998362, 7.344120843069894, 0.20684707138155187, 0.061578186095825264, 0.032589504295693975, 0.07340785382049424, 0.03087278694978782, 0.042972369119524956, 0.033590625040233135, 0.031611996569803784, 0.01323296720095511, 0.021036297182685564, 0.0828959107665079, 0.07453572151384183, 0.07442689128220081, 0.020089776454759494, 0.054391906530197175, 0.031964994235230346, 0.028631049740527357, 0.06240252471928086, 0.06990510677652699, 0.03108517519597496, 0.05492939447451915, 0.024004389166033695, 0.0150443376374564, 0.05192581171702061, 0.024453516583889723, 0.021062420780903528, 0.002217008212548015, 0.05763029972357409, 0.013859993778169155, 0.0936162823012897, 0.05770947118954999, 0.034147960133850574, 0.037815435124295096, 0.029704838192888668, 0.12971807723598822, 0.06832678004034928, 0.026440976187586784, 0.02025899799939777, 0.06989642152828829, 0.06483094048287187, 0.012705085616159652, 0.027642520909596766, 0.037153877051813264, 0.021948392436440502, 0.1090956541842648, 0.018587537242897918, 0.014470970457685845, 0.024044821371457407, 0.04022863134741783, 0.028958157902317386, 0.04594666291294353, 0.03721143039209502, 0.03433476421715958, 0.10230154411068984, 0.027717241185850332, 0.06991413129227501, 0.02360867432850812, 0.02813107630104891, 0.04187845531851053, 0.02991475657160793, 0.04285405636099832, 0.035243102083248753, 0.03723497555724212, 0.027989199717662165, 0.034646476419376473, 0.027962143133793558, 0.0626856977386134, 0.0740499718646918, 0.01469640014693141, 0.01821206310497863, 0.04229293843465192, 0.00324813907666664, 0.007622127205000392, 0.02525642198244376, 0.04263850614162428, 0.03156676881813577, 0.04042288574523159, 0.010332718541446542, 0.05769790895283222, 0.09630397986620665, 4.537643986088889, 22.587924855096, 33.15103667122977, 28.283906936645508, 26.194852863039287, 24.876413072858536, 26.03775235584804, 33.47443362644741, 27.071263892310007, 7.162859712328229, 0.43441532658679144, 0.07639549779040472, 0.31969253399542397, 0.4722215064934322, 1.9986082868916648, 1.8105265221425464, 4.906651088169642, 5.186660885810852, 1.5049136983496803, 0.8045905945556504, 0.17088957370391913, 1.6130665349108833, 8.450125541005816, 14.211808919906616, 24.88359751020159, 33.89549446105957, 41.6939753804888, 48.123431886945454, 51.34106969833374, 54.132313932691304, 53.96628672736031, 53.46252843311855, 50.462657587868826, 51.752114704677034, 51.24422918047224, 56.42742552076067, 59.789561544145855, 58.648632594517295, 55.13901063374111, 58.01845530101231, 58.48227882385254, 59.26226275307791, 56.54725762775966, 59.09024620056152, 57.27560601915632, 58.77897385188511, 33.78723805291312, 41.17713015420096, 54.255290099552695, 52.87640619277954, 56.074807916368755, 52.79608154296875, 55.01390831811087, 54.32167666299002, 55.51609284537179, 56.202116285051616, 55.590584482465474, 53.69320167813982, 55.816685812813894, 54.243964535849436, 54.38583632877895, 52.05898536954607, 55.44751065117972, 55.329606669289724, 54.18161487579346, 49.54678773880005, 45.66016347067696, 38.39934458051409, 30.32696567262922, 22.79446874346052, 16.178520849772863, 10.080771344048635, 6.924159560884748, 4.810111079897199, 1.9645916436399733, 0.5276891386934689, 1.4553454667329788, 2.87091749055045, 4.190347833292825, 4.791431282247816, 6.906592343534742, 5.190288714000157, 4.655544928142002, 3.7841092433248247, 1.0784324003117425, 0.2734297178685665, 0.06523719296923705, 1.986522329705102, 11.691583514213562, 39.10418374197823, 43.90641382762364, 40.417296000889365, 39.06422812598092, 37.79018906184605, 27.084845883505686, 11.765317797660828, 0.6838035987956184, 0.018380629863323908, 0.016805254754477313, 0.052004484459757805, 0.02470900707079896, 0.038741883090032, 0.030326233777616705, 0.014808931787099158, 0.06437766551971436, 0.05711686584566321, 0.10333298519253731, 0.07729156435068164, 0.03170199066932712, 0.04837146208488515, 0.06300632589097534, 0.018163183138572743, 0.019084224876548563, 0.009944775474390813, 0.014321699538933379, 0.012495643060122217, 0.014512735984421201, 0.039621481605406315, 0.032373560526009114, 0.03664051102740424, 0.011050864738146109, 0.08424551013324942, 0.054894602591437955, 0.045150751514094215, 0.030857031366654804, 0.04764772306329437, 0.007642847968132368, 0.02296801343826311, 0.022783021043453897, 0.0040990050266762924, 0.04122733311461551, 0.026958503327997665, 0.1513190767062562, 0.12171145901083946, 0.22654545865952969, 0.21687951018767698, 0.15962388393070015, 0.16874590516090393, 0.06214497996760266, 0.21475142080868992, 0.3122357055544853, 0.23199171998671123, 0.09750479685940913, 0.058809919282794, 0.1695726050862244, 0.11446372792124748, 0.16545585170388222, 0.11924856688295092, 0.06679435619818312, 0.1807745804211923, 0.07568370098514215, 0.10446056790117707, 0.08132481042827878, 0.11039030578519617, 0.1880320417029517, 0.16710374185017177, 0.13835272033299717, 0.11269206620220627, 0.13082829623350076, 0.12477957723396164, 0.22432203511042254, 0.20277176291814872, 0.12630922586790153, 0.11229702989969935, 0.11874410323798656, 0.12192534681941782, 0.13251280012939656, 0.10019722381340605, 0.1813612553690161, 0.1257349138281175, 0.12520372947411879, 0.10916715820452996, 0.21886802491332802, 0.10104948415287904, 0.16509241477719375, 0.13049946459276335, 3.7099928089550565, 26.23560231072562, 40.01580824170794, 36.82192979540144, 37.44876847948347, 32.149690083095, 29.24313007082258, 31.78615685871669, 28.736418792179652, 10.302885276930672, 1.714774700147765, 0.442415498729263, 1.425799337880952, 9.369298389979772, 6.239575266838074, 15.79915268080575, 12.861887710435049, 4.202762961387634, 0.47728245492492405, 0.6790613446916852, 0.649995781481266, 1.294808532510485, 7.007980457374027, 11.612364496503558, 24.566511256354197, 33.83632012775966, 42.265687056950156, 47.438367298671174, 51.50595045089722, 54.63725689479283, 54.70304938725063, 53.443323612213135, 52.77123131070818, 54.607800006866455, 55.83799941199166, 56.90947069440569, 61.73700959341866, 62.43395560128348, 58.06960793903896, 60.94325433458601, 61.02744565691267, 61.47913415091378, 59.71116501944405, 60.568670000348774, 58.99369403294155, 56.57770115988595, 38.88598946162632, 49.046336787087576, 53.44409486225673, 53.90144961220877, 55.519865717206685, 55.26539141791207, 55.92683907917568, 56.40762315477644, 56.12456744057791, 60.01778902326311, 58.44052709851946, 57.311625480651855, 58.79177243368966, 58.163707392556326, 56.994804995400564, 52.67808723449707, 56.22813728877476, 56.9996965272086, 54.29366152627127, 50.233287130083355, 44.9964576448713, 37.37082706178938, 26.167049646377563, 20.56854557991028, 13.584767001015798, 8.723093339375087, 5.546702206134796, 4.0551076616559705, 1.0680295356682368, 0.22373875283769198, 1.7067309660570962, 1.9449857813971383, 8.622013551848275, 5.2151806354522705, 7.772819484983172, 14.394740223884583, 12.458047117505755, 17.036069256918772, 7.42721608706883, 1.535849358354296, 0.2760757601686886, 3.697255023888179, 20.453945466450282, 42.95973914010184, 35.99598700659615, 37.520640645708355, 42.96877179827009, 43.63894639696394, 32.00607776641846, 12.346074291637965, 0.6798926857965333, 0.12107465389583792, 0.12787642462977342, 0.13363156866814407, 0.15799092155482086, 0.1728001247559275, 0.08458690145718199, 0.12817199448389666, 0.13283791339823178, 0.17520352293338093, 0.20816847761826857, 0.146343040146998, 0.16591382212936878, 0.1573280742658036, 0.19155500909047468, 0.15811037085950375, 0.12286855120744024, 0.1383432208427361, 0.14574082674724714, 0.15499455162457057, 0.11644978635013103, 0.15184787261698926, 0.23241352449570382, 0.1725074861730848, 0.11743739406977381, 0.16356815371130193, 0.19409760194165365, 0.12921259578849587, 0.1108877533780677, 0.23876314663461276, 0.1153083818831614, 0.0802347439208201, 0.12761672213673592, 0.16307063826492854, 0.20396005415490695, 0.14018796756863594], [0.07369992921927146, 0.02414687303826213, 0.042210160555051904, 0.02611368482134172, 0.04638216704396265, 0.020581938259835755, 0.013943847135773726, 0.027502259239554405, 0.004287943950787718, 0.03086043761244842, 0.12189326568373612, 0.07890358035053525, 0.04206866564761315, 0.05272263235279492, 0.07115799454706055, 0.023964274175731198, 0.02000508680274444, 0.0717981584104044, 0.04935219624478902, 0.0236587875323104, 0.025132557111127034, 0.052351538158421, 0.04312314299334373, 0.0167459457048348, 0.0784654842157449, 0.038322823255189827, 0.01899764720084412, 0.04141459181638701, 0.0703728481062821, 0.004537974775303155, 0.030083793215453625, 0.03899806059364762, 0.09419051291687147, 0.04107119542147432, 0.025124701371948634, 0.025608926013644253, 0.032257537823170424, 0.042621641153735776, 0.03492978514571275, 0.04182603848831994, 0.025726460153236985, 0.050836362676428895, 0.024633745662868023, 0.041728502472064326, 0.042386684832828384, 2.291870036295482, 12.04486814567021, 28.464219638279506, 30.355842385973247, 24.167050634111675, 18.793694257736206, 20.95741193635123, 21.203294788088115, 23.821784223828995, 10.908015183040074, 3.022669187613896, 0.14591838579092706, 0.9505379945039749, 1.1435054285185677, 1.5124482597623552, 3.0395504874842505, 5.6008451751300266, 10.228947758674622, 0.4894378398145948, 0.1289158859955413, 0.36828161243881496, 0.5031453871301242, 1.3123512140342166, 5.426759796483176, 11.313644068581716, 18.75876566341945, 23.46883831705366, 28.825121232441493, 28.92397846494402, 33.73241676603045, 41.282892159053254, 44.97242382594517, 45.10608284814017, 46.58263063430786, 47.197268281664165, 49.60481561933245, 52.57726887294224, 60.7859332220895, 56.89448690414429, 59.471181188310894, 57.03862033571516, 58.35165269034249, 55.148609570094514, 59.65719141278948, 41.25477627345494, 43.00005258832659, 45.33268444878714, 43.10994529724121, 54.63238273348127, 53.81021976470947, 57.00437961305891, 53.995309352874756, 53.49696370533535, 54.493394442967, 53.80301448277065, 52.8029602595738, 55.6578117779323, 54.14834342684065, 54.37823152542114, 53.04693235669817, 54.01406601497105, 48.37961891719273, 42.11181919915335, 27.71621479306902, 20.58754195485796, 11.672590613365173, 7.627329417637416, 5.78940886259079, 3.409110188484192, 1.614938640168735, 0.5150756069592067, 0.1721928630556379, 0.3228966306362833, 1.0290004185267856, 0.7502937881009919, 1.5606161036661692, 5.336825353758676, 2.541272367749895, 5.644577137061527, 6.868457155568259, 2.5196269920894077, 2.614170913185392, 2.2250930709498267, 0.5165088357669967, 0.6899452092392104, 4.824618050030299, 24.607847826821462, 26.79802077157157, 13.676776783806936, 12.013533507074628, 12.579711811883108, 24.215714079993113, 20.103794472558157, 8.879492947033473, 0.5730547958186695, 0.030836241053683416, 0.038941477558442524, 0.09883548545518092, 0.06368262174406222, 0.11778077350131103, 0.03225410443597606, 0.014273891657856959, 0.06418112785156284, 0.15163631896887506, 0.11096615809947252, 0.007929121044331362, 0.013362795546916979, 0.01848914796885635, 0.05352285584168775, 0.015651539965931858, 0.02356169086747936, 0.030821201324995075, 0.032434045137571435, 0.022857678555218235, 0.042191721365920136, 0.019501673190721443, 0.021181714022532105, 0.030752584471234252, 0.013950687616930475, 0.013236092702884759, 0.021821450408814207, 0.04054265056869813, 0.025923089423616017, 0.01528124644287995, 0.0766250868993146, 0.04663795099726745, 0.10207656903990678, 0.017512590191992264, 0.0417114474943706, 0.009502748077336167, 0.038931601481246095, 0.051168685379837237, 0.027265682916289995, 0.07649636202092681, 0.09609581889318568, 0.02645174114565764, 0.04708184860646725, 0.054198866710066795, 0.04724732294146504, 0.032282216141798666, 0.06548510252365045, 0.04691759902717812, 0.052064402494579554, 0.06774874284331288, 0.06253000787858452, 0.09678797210965838, 0.019372217190851058, 0.05865315733743565, 0.058355280464248996, 0.01799864518190069, 0.04282402440107294, 0.022545862876410996, 0.035883201485765834, 0.016479074489325285, 0.024661000718229582, 0.1328297166952065, 0.03974447625556162, 0.01456112740561366, 0.07534970569291286, 0.06528259374733482, 0.042641389915453534, 0.022129193181172013, 0.05239226722291537, 0.04493783740326762, 0.10630046310169355, 0.03279360762930342, 0.049549449767385206, 0.1175778643893344, 0.14910991596324102, 0.004077872053520488, 0.0334548908951027, 0.060410420543381145, 0.0415885987292443, 0.08855090982147626, 0.042655985203704665, 0.13359944682036126, 4.9996227622032166, 19.50374804224287, 35.16843918391636, 35.9404604775565, 24.406652314322336, 16.619957276753016, 26.19697901180812, 32.48611838476998, 32.75469057900565, 13.109740376472473, 2.1934624825205122, 0.13822141023618834, 0.5209203447614397, 0.7571100794843265, 0.6322886230690139, 3.2175411880016327, 8.169708405222211, 9.482441987310137, 1.224329805799893, 0.7562557767544473, 0.624291680753231, 0.5857600112046514, 2.5362271070480347, 7.109628260135651, 15.118560995374407, 21.79594486100333, 26.945015123912267, 32.70034176962716, 33.81495789119175, 38.43333516802107, 45.735999584198, 49.57256555557251, 50.12719161169869, 50.37424176079886, 50.7625800541469, 54.64518826348441, 57.04016283580235, 61.86162553514753, 59.3873233795166, 62.4141115461077, 59.65071569170271, 60.388023785182405, 58.858315331595286, 59.95961175646101, 46.64475795200893, 40.74694286073957, 46.60800892966134, 47.12175178527832, 55.750639711107524, 54.49682685307094, 56.960015365055625, 54.14429610116141, 54.90964017595564, 55.27257238115583, 55.940297739846365, 55.98496076038906, 57.022229535239084, 55.835741247449604, 56.74650069645473, 54.83247348240444, 55.9972243309021, 51.59841707774571, 46.68925421578543, 34.88700934818813, 26.371208565575735, 17.951037577220372, 12.039446813719612, 9.150030612945557, 5.097714390073504, 3.279193856886455, 1.6907460923705782, 0.6862115838697979, 1.310024544596672, 3.932719486100333, 3.538603982755116, 2.369177430868149, 6.126188916819436, 3.7003387212753296, 6.091079669339316, 4.291735947132111, 4.174240171909332, 1.957419148513249, 1.4328955113887787, 0.4495727946715695, 0.8486880425895963, 3.517388961144856, 19.25219198635646, 38.38393695013863, 27.123967715672084, 16.501839637756348, 15.786696297781807, 27.966521910258702, 27.671202625547135, 14.720738410949707, 1.9561982197420937, 0.03597456283335175, 0.06454402195023638, 0.025058055662416985, 0.02683937463111111, 0.08768782006310565, 0.034271565465522666, 0.04738296548436795, 0.09845412841864995, 0.0607195950246283, 0.0937886234106762, 0.07768625460032906, 0.03445474956450718, 0.01674414928337293, 0.0684740628514971, 0.046059733988451104, 0.026442528336441944, 0.11594805041594164, 0.012565614439414015, 0.03333619476429053, 0.0710675526144249, 0.053728333208709955, 0.0425048042088747, 0.02351650722058756, 0.010429131582246294, 0.00702310461617474, 0.02243020827881992, 0.05561631279332297, 0.017444409296980927, 0.012505480969723846, 0.04292440687173179, 0.018556769072477306, 0.08389132163886513, 0.03981060967115419, 0.03885742403300745, 0.06657826315079417, 0.06268113119793789, 0.22303437920553343, 0.12517201474734715, 0.13916582241654396, 0.2572056198758738, 0.08552327978291682, 0.0966582837115441, 0.1723686714789697, 0.15417399922651903, 0.09842199978551694, 0.13236397025840624, 0.12903152193341935, 0.22496730834245682, 0.1050473242732031, 0.16952438838779926, 0.23818693469677651, 0.13876741379499435, 0.10705070570111275, 0.1511576532253197, 0.10904659610241652, 0.14330556456531796, 0.13348307806466306, 0.13735312968492508, 0.11920343073351042, 0.08843680737274033, 0.3570967497570174, 0.16550229064055852, 0.13172090905053274, 0.2177379791225706, 0.12200549537582056, 0.11269635454352413, 0.09058893046208791, 0.15640171111694404, 0.12246936905596938, 0.19064930054758275, 0.1181034983268806, 0.10716600915683167, 0.20288661175540515, 0.17571944024946007, 0.19307306834629603, 0.1462565947856222, 0.12014195322990417, 0.0946953429707459, 0.16532710646944387, 0.11601309478282928, 0.1595662220248154, 4.87192051751273, 22.496769700731548, 44.05651576178414, 43.66769456863403, 34.099552631378174, 26.472570623670304, 27.49921212877546, 28.60746717453003, 31.719224861689977, 14.980326584407262, 3.8364152823175703, 0.38325275480747223, 1.6069859926189696, 2.8189293316432407, 7.017797827720642, 7.369317616735186, 14.86904423577445, 16.26880747931344, 0.4660929782049996, 0.34553163605076925, 1.0470753972019469, 1.1648461690970828, 2.4146206038338796, 6.7850813780512125, 12.676698241915021, 21.02942827769688, 25.03540349006653, 31.80503511428833, 30.939841951642716, 36.77983066013881, 43.169091837746755, 46.838723863874165, 51.23382077898298, 55.850405420575825, 56.82096454075405, 61.20200525011335, 59.24019527435303, 64.93126324244908, 61.50405733925955, 63.14215769086565, 61.521406991141184, 63.03803893498012, 59.14591516767229, 61.453620365687776, 46.431392669677734, 45.289428438459126, 47.27626582554409, 49.01252337864467, 55.00498683112008, 54.95027324131557, 57.50713389260428, 54.15757758276803, 55.33089208602905, 57.175416469573975, 56.74361024584089, 56.51503535679409, 58.705788476126536, 55.971185956682476, 57.139786107199534, 56.54658712659563, 57.90451179231916, 51.3660033089774, 44.451322828020366, 30.429330008370535, 23.37356809207371, 13.994411076818194, 9.348215818405151, 6.627038955688477, 4.895164847373962, 2.3159546639238084, 1.1022908857890537, 0.3950646109879017, 1.5709542632102966, 3.0229180199759345, 4.368847055094583, 3.980862251349858, 11.133347868919373, 5.621393603937967, 11.351193870816912, 15.885494470596313, 5.782196198190961, 5.002491499696459, 3.7010943378720964, 0.9815330398934228, 1.1550515975270952, 6.574689490454538, 29.39300618852888, 34.84210661479405, 19.00702827317374, 19.250967366354807, 20.229912962232316, 32.909840379442485, 30.954669407435826, 15.103054353169032, 1.2677066496440341, 0.13130044804087707, 0.17163419803338392, 0.14637909749788897, 0.09527342766523361, 0.16781150815742357, 0.14759845206780092, 0.12429962227387087, 0.21522919088602066, 0.19868444438491548, 0.1726563296147755, 0.12509280256927013, 0.11781280035419123, 0.1583640751029764, 0.11503244883247785, 0.0878497999427574, 0.08149129578045436, 0.18655986498509133, 0.08329565610204424, 0.15375188259141787, 0.08773002494126558, 0.1712461302855185, 0.2153100994016443, 0.1434736784015383, 0.11786288980926786, 0.07410605278398309, 0.13571756173457417, 0.2783310477222715, 0.1195811168955905, 0.12865855837506907, 0.1686692985572985, 0.10347804240882397, 0.21626232830541475, 0.10434637724288873, 0.12571295643491404, 0.09344309302312986, 0.13253953440913133], [0.022482738763626133, 0.04448343946465424, 0.023534410367054597, 0.03543115806366716, 0.05590135517663189, 0.07011477409728936, 0.1008890988305211, 0.06813421180205685, 0.05077525041997433, 0.02797802085322993, 0.028010110470599363, 0.061372623911925724, 0.15771376714110374, 0.04196501263816442, 0.10959770224456276, 0.0446182541948344, 0.056114561057516506, 0.029927245008626153, 0.08019938546099833, 0.06288541773600237, 0.05557928513735533, 0.030509299132972956, 0.015009435492434671, 0.06154727204037564, 0.11215169448405504, 0.019292484237147228, 0.11126338357904128, 0.05238058963524444, 0.09035248136413948, 0.14784717586423668, 0.017385157922815, 0.03816839547029563, 0.04703199663864715, 0.04875681569267597, 0.028024573444521854, 0.08522806276700326, 0.06280402067516531, 0.06361704811986003, 0.042082277060087235, 0.141893329631005, 0.08991158287972212, 0.07727604625480515, 0.02181499245177422, 0.05119362832712276, 0.023873733855517845, 0.0422415427996644, 1.0319225702966963, 12.645393133163452, 26.12845414025443, 31.92660427093506, 23.593551533562795, 17.400064536503383, 19.930909395217896, 17.0502644266401, 27.526462963649205, 19.149454184940883, 5.475159645080566, 0.7397618389555386, 0.7893207882131849, 0.28195673174091745, 1.4875049867800303, 15.624026809419904, 7.441307902336121, 3.093193620443344, 1.4379407720906394, 0.07796334116054432, 0.11021337777908359, 0.08269889812384333, 0.07661739231220313, 0.8159983967031751, 2.0621747502258847, 5.69786764894213, 10.062692131314959, 13.694111670766558, 13.778248276029315, 18.66025584084647, 21.901807614735194, 30.776597499847412, 39.76722254071917, 44.74460629054478, 52.59247153145926, 52.023563453129356, 53.47358301707676, 61.47279044560024, 62.90489755358015, 60.001516342163086, 57.998729365212576, 53.98683255059378, 56.49033451080322, 35.837793895176475, 41.73679712840489, 35.62394918714251, 32.92760692323957, 57.16583142961775, 57.0640298979623, 56.635402475084575, 55.575138636997764, 55.10239362716675, 53.06225313459124, 57.41823863983154, 58.07739339556013, 55.66047293799264, 55.88132490430559, 52.982869965689524, 41.929745129176546, 26.581787620271953, 16.364369528634207, 6.49795184816633, 2.0950805502278462, 0.38966159948280876, 0.24635918331997736, 0.3914717680641583, 1.1380234083959033, 0.33687833324074745, 0.32917693363768713, 0.9089085683226585, 0.6012237157140459, 0.8067148977092334, 6.458124339580536, 3.8902551361492703, 3.3535295937742506, 5.018183137689318, 3.119190522602626, 4.975940261568342, 3.698244273662567, 3.690415390900203, 0.8959980553814343, 0.3916342093476227, 1.2024341864245278, 9.823599406651088, 31.43381370816912, 24.441021578652517, 12.749748127801077, 19.512850182397024, 24.853579555238994, 33.445702825273784, 26.79405508722578, 7.841902817998614, 0.3072648937148707, 0.07521165774336883, 0.05702774705631392, 0.06838969380727836, 0.016854292480275035, 0.05191208834626845, 0.1006965713043298, 0.02222331446994628, 0.01520910968870989, 0.0658425140593733, 0.09439864674849169, 0.07840575277805328, 0.0968962459425841, 0.05699339282831975, 0.005857106647454202, 0.025810249050014784, 0.02729446637178106, 0.06080711925668376, 0.022204793856612275, 0.047446717242045064, 0.021496014835845147, 0.014779647912031837, 0.025676133210903833, 0.04357766306826046, 0.093736912256905, 0.03270522165777428, 0.060133082925208976, 0.04065212880128196, 0.01189621419845415, 0.07865742820182017, 0.054164926388434, 0.051752177998423576, 0.040207861390497, 0.017754513371203626, 0.09725747084511177, 0.06575651653110981, 0.025192509072699716, 0.04855857829430273, 0.01350526839295136, 0.04876261377441032, 0.02721903533009546, 0.023547143076679537, 0.040145351351904016, 0.08220043272844382, 0.10531733371317387, 0.06655407337737934, 0.024723468348383904, 0.057889737587954314, 0.04421719928671207, 0.08606583638382809, 0.03879703102367265, 0.09033352309571845, 0.1659312333379473, 0.025076430390721986, 0.02683175977186433, 0.04160326187099729, 0.08504742317433868, 0.027574450276525955, 0.025464771248932396, 0.09415567692901407, 0.03430139725761754, 0.025186967137934904, 0.07793564336108309, 0.023440205957740545, 0.08213180569665772, 0.11437521981341497, 0.02210572944022715, 0.0818194013887218, 0.06539552911583867, 0.05011030985042453, 0.026337321481800506, 0.11595883912273816, 0.023758014797099998, 0.011299275560304523, 0.06360724328884057, 0.06985486804374627, 0.10157462275986161, 0.16332012202058518, 0.022579453752509186, 0.04259979571881039, 0.010221214033663273, 0.12271802499890327, 0.026825788663700223, 0.04160288528406194, 2.6371460003512244, 19.160130092075892, 35.089309624263215, 37.088452271052766, 22.200243166514806, 13.316249523844037, 18.042859758649552, 26.20650499207633, 33.5928760937282, 18.543055364063807, 5.8608220134462625, 0.696975049163614, 0.07968456058629922, 0.05757435451128653, 0.6794300877622196, 7.548570718084063, 9.476483038493566, 3.2530039250850677, 1.5019229331186839, 1.1191456956522805, 0.4893983762179102, 0.2169559132307768, 0.35838645483766285, 1.758814879826137, 3.4486827850341797, 7.042777470179966, 12.746371303285871, 16.258798599243164, 17.429175751549856, 21.49783934865679, 26.78960997717721, 35.74829067502703, 46.23080512455532, 50.68148762839181, 54.19742897578648, 52.08858469554356, 57.24606922694615, 62.11026682172503, 64.26422922951835, 62.44436400277274, 60.62558964320591, 54.479112420763286, 58.524120875767295, 40.71239641734532, 41.696747711726594, 38.53956617627825, 38.636076654706685, 57.204178537641255, 56.68375498907906, 56.018110615866526, 55.71933112825666, 54.10988514763968, 52.5886013848441, 56.84245184489659, 59.064273834228516, 59.101405007498606, 56.25262968880789, 55.104491983141216, 47.55957514899117, 33.22189787455967, 23.71931219100952, 11.047746930803571, 4.093346204076495, 1.7109589448996951, 0.7058300940053803, 1.0271847673824854, 2.224395211253847, 1.348800703883171, 1.7262559469257082, 1.6486681274005344, 2.3470554522105624, 2.199281381709235, 6.808664432593754, 4.0334349274635315, 3.474281902824129, 5.251845410891941, 4.810887975352151, 4.093983267034803, 1.27096046933106, 0.11665443251175539, 0.7308002912572452, 0.15838394260832242, 1.2498498878308704, 7.5036454030445645, 25.813179629189626, 37.13775668825422, 19.13829016685486, 11.630771143095833, 17.38367199897766, 30.67502178464617, 30.69695724759783, 12.608977624348231, 1.1349786860602242, 0.078792958786445, 0.16052761115133762, 0.05374574441728847, 0.03659503561045442, 0.0817219637600439, 0.12180846237710544, 0.05369551586253302, 0.006942402205563017, 0.025881393446720073, 0.07660148745136601, 0.04126799093293292, 0.08880973021898951, 0.15865382312663964, 0.0771885152373995, 0.05487583770549723, 0.03941622815494027, 0.07450385072401591, 0.0172727518116257, 0.008635041736332434, 0.027885022539911524, 0.017916242192898477, 0.04661527435694422, 0.06752965745649167, 0.040634646346526485, 0.029211994460118667, 0.03330970136448741, 0.05702442902007273, 0.04725824396259018, 0.01025046652648598, 0.03826926648616791, 0.1138634415609496, 0.041633894334414175, 0.02834999544679054, 0.020682849987809147, 0.03596036448808653, 0.04666063103026577, 0.019230515330231616, 0.08078705106994935, 0.1235458105802536, 0.06918052637151309, 0.18710129521787167, 0.17001400568655559, 0.14266166197402136, 0.20486686192452908, 0.19026415050029755, 0.11730080497051988, 0.12386276785816465, 0.14645221643149853, 0.15522861906460353, 0.2772652320563793, 0.14007853344082832, 0.20170540442424162, 0.10709162136273724, 0.15700753432299408, 0.11873244600636618, 0.2520759494176933, 0.15479038043745927, 0.13801924751273223, 0.18722097522446088, 0.09210603976888315, 0.1312372764306409, 0.1931623906961509, 0.19041827294443334, 0.1275518677596535, 0.22861961807523454, 0.16289960672812803, 0.27595359672393116, 0.10197606443294457, 0.15287803805300168, 0.19409263506531715, 0.13326270346130642, 0.18424751263644013, 0.19059653766453266, 0.07101628929376602, 0.17335479999227182, 0.23833678237029485, 0.2752522900700569, 0.1268174485968692, 0.22616564189749105, 0.20844597129949502, 0.2064338842672961, 0.09096848938081946, 0.12500870493905886, 2.2673976123332977, 19.321976218904766, 40.47622019904, 45.95538200650896, 33.76252678462437, 25.420571667807444, 27.205437081200735, 23.588668687003, 35.79668835231236, 24.106940031051636, 7.517135330608912, 1.0302930005959101, 1.431443989276886, 1.6868558611188615, 4.433906512601035, 25.48489809036255, 16.097539595195226, 9.649540083748953, 2.335904027734484, 1.3925234377384186, 0.3734115814524037, 1.4535434948546546, 0.3226148214723383, 1.3240023659808295, 2.5317248914922987, 6.421259803431375, 10.741880280630928, 15.767988273075648, 15.193056106567383, 21.151023490088328, 24.67006025995527, 33.15289184025356, 45.46486350468227, 50.02667897088187, 58.10507501874651, 58.58957290649414, 59.19543497903006, 64.36619404384068, 66.86307089669364, 63.16857474190848, 59.33896391732352, 56.28578649248396, 58.19374098096575, 46.11901208332607, 44.185971123831614, 40.620106969560894, 40.855720383780344, 58.93831689017159, 56.474593366895405, 56.689282281058176, 57.0681015423366, 55.22082567214966, 54.321628025599885, 57.95973607472011, 60.44256714412144, 57.53679575238909, 56.4347836630685, 54.27343879427229, 44.9069196837289, 27.934853758130753, 19.119446652276174, 8.278670924050466, 3.095726890223367, 0.7475836649537086, 0.5860011896916798, 0.7408075971262795, 2.090332976409367, 0.4814280867576599, 0.836328771497522, 1.4719317938600267, 1.5387582651206424, 2.7004519062382832, 10.594679219382149, 7.746778505189078, 7.486177631786891, 12.18150099686214, 10.387348447527204, 9.543071968214852, 7.921614289283752, 7.755475912775312, 1.5460745011057173, 0.731479749083519, 1.8946760467120578, 11.775470852851868, 37.85013811928885, 33.142657143729075, 18.087237903050013, 25.599965470177786, 33.39661380222866, 43.73219122205462, 36.52484219414847, 12.705603616578237, 1.0143450392144067, 0.1460075724337782, 0.19099445774086884, 0.11731597701353685, 0.11132136439638478, 0.18653190934232303, 0.15962780586310796, 0.14317624936146395, 0.16768243722617626, 0.1445566474327019, 0.16175846010446548, 0.1627807952463627, 0.1844404065715415, 0.32838462186711176, 0.19724117325884954, 0.12530415265687875, 0.16886703723243304, 0.19252118867422852, 0.1723035049757787, 0.1456814549331154, 0.07197469286620617, 0.08019747199224574, 0.09761552698910236, 0.11803020297416619, 0.14175471849739552, 0.11401873108531747, 0.15650657191872597, 0.22564904604639324, 0.09277670378131525, 0.12482904243682112, 0.07713521631168467, 0.19410533724086626, 0.1725810800812074, 0.15000186381595476, 0.13998592698148318, 0.18873855950576918, 0.2829570823482105, 0.10713216383010149], [0.0660254063882998, 0.005639508948661387, 0.023716961732134223, 0.01146307900281889, 0.0568994394769626, 0.030442911266748394, 0.023713144972654324, 0.042301962950399945, 0.06190556567162275, 0.008328773081302643, 0.04836447656686817, 0.08051128086767026, 0.03491546466414418, 0.01884564687497914, 0.034688833967915604, 0.015143454640305467, 0.036976511390613656, 0.02568669630480664, 0.02253997149611158, 0.015968332699100887, 0.04051946163443582, 0.013968611967616847, 0.04947202892175742, 0.06633099141929831, 0.11140928217875105, 0.024552194235314215, 0.016500139608979225, 0.07071497224803482, 0.08498202596924134, 0.018854986909510832, 0.036737741702901464, 0.018545910815841386, 0.008014877692663243, 0.048451892233320644, 0.03245323410789881, 0.0428448825675462, 0.004789535272201257, 0.07343120221048594, 0.1289371648537261, 0.05376186980200665, 0.06740761614803757, 0.046857501180576425, 0.03914646298757621, 0.016423785759668266, 0.05259861311476145, 0.04792571886043463, 0.10048137392316546, 0.49922204336949755, 10.097254208156041, 27.46977608544486, 34.978020327431814, 29.374610832759313, 22.022490876061575, 21.13777674947466, 18.2611426285335, 32.13776697431292, 21.462127344948904, 9.70533846105848, 3.4899194751467024, 0.12299059251589434, 2.7896997800895145, 2.8837251918656484, 5.19448412316186, 4.4077869313103815, 3.19106833423887, 0.35305550375155037, 1.0526704341173172, 0.055676950075264485, 0.23962260623063358, 0.03516753363822188, 0.1533688088612897, 0.23507167186055863, 1.0999988487788608, 2.5043974093028476, 2.2096580820424214, 2.810141380344118, 4.007035681179591, 5.940971221242632, 9.200855817113604, 23.299234526497976, 41.613303320748464, 52.33671528952462, 58.44275747026716, 48.86111518314907, 53.93862247467041, 59.03511224474226, 58.035815375191824, 53.868747915540425, 47.05029651096889, 29.73442677089146, 32.803122997283936, 31.39078004019601, 33.82976450238909, 53.13549409593855, 53.24133253097534, 54.725888116019114, 52.42684037344796, 49.6414395741054, 54.23181561061314, 49.98183529717581, 48.809764521462576, 41.49094901766096, 32.02794374738421, 18.42492209162031, 6.914921062333243, 1.175560399889946, 0.27708216330834795, 0.10025214443781547, 0.06137316673994064, 0.13097514478223665, 0.4877272258911814, 1.1560120774166924, 1.773670996938433, 2.477655964238303, 4.318643714700427, 1.7934415532009942, 3.5333567900317053, 1.8984456615788596, 6.876495352813175, 3.012822938816888, 0.8817168474197388, 3.7851532101631165, 2.3751385509967804, 4.413360255105155, 0.5531847391809736, 0.7917463609150478, 0.5857818871736526, 3.971464378493173, 15.028691257749285, 41.73059238706316, 29.264106682368688, 10.438944033214025, 21.14599473135812, 25.695035934448242, 30.690422466823033, 19.274969918387278, 3.6616989203861783, 0.06667183991521597, 0.04258124457140054, 0.044185905251652, 0.04983107911955033, 0.03777385110567723, 0.04775178658642939, 0.03559953313586967, 0.07481664858226265, 0.06056339626333543, 0.03699298282819135, 0.09648309275507927, 0.09307340000356946, 0.028489117178001573, 0.03861742280423641, 0.03141380327620676, 0.04628170654177666, 0.019586218654045036, 0.04111519841743367, 0.06818309346480028, 0.01405076983584357, 0.03602615185081959, 0.05240407373223986, 0.060160339676908085, 0.015140794783032365, 0.09223947368030037, 0.03842072907303061, 0.06623730608927351, 0.014985562934141074, 0.027054894316409315, 0.03907697760899152, 0.044474509943808825, 0.01610669956010367, 0.08347847379211869, 0.04566993597628815, 0.006352684876349355, 0.08866432016449315, 0.08596568461507559, 0.03726773522794247, 0.0585847067247544, 0.0759097481412547, 0.014886561282245176, 0.08486966735550336, 0.025130848899217587, 0.05626399143199835, 0.006551972307663943, 0.015661511038030897, 0.011420184563446258, 0.03494691476225853, 0.006803616349186216, 0.03985494854194777, 0.021547091559373906, 0.039970153610088995, 0.011227707927381354, 0.029986118099519184, 0.03901807737669774, 0.06285053425069366, 0.017289213071178113, 0.016857323835470846, 0.027043808750542145, 0.020750946065943156, 0.038751786308629174, 0.007804604779396738, 0.04980445679809366, 0.06591926994068281, 0.07642685967896666, 0.017524973456082598, 0.18474110615040573, 0.0742968161191259, 0.025298557310764278, 0.01603425576883767, 0.03001616702282003, 0.0357011301842119, 0.03381265526903527, 0.03926813788712025, 0.06395375755216394, 0.030801737547985146, 0.061720230616629124, 0.11710514261254243, 0.08657908027193376, 0.029492711182683706, 0.09422346257737704, 0.010712187554288124, 0.016841100063174963, 0.03386405768937298, 0.03237076496173229, 0.09522014231021915, 1.9428253258977617, 15.734077589852468, 33.808040959494456, 37.70343385423933, 24.465557404926844, 16.621831553322927, 13.979568856103079, 26.83000680378505, 37.679514680589946, 23.919079848698207, 13.046369331223623, 2.321133460317339, 0.11272697682891573, 1.2505156121083667, 2.380316044603075, 0.8202879865254674, 2.368248326437814, 3.3250068042959486, 3.010223226887839, 1.678350071821894, 0.3193845605211598, 0.8588194389428411, 0.4310943047915186, 0.3922029302588531, 0.9123256163937705, 1.9931300665651048, 3.964048913546971, 3.801522731781006, 4.303784557751246, 5.609647674219949, 9.05171707698277, 14.097837618419103, 28.35526841027396, 47.858156612941194, 55.962608405521934, 58.371149335588726, 53.349279744284495, 59.0459931237357, 62.107383319309776, 58.46205956595284, 55.201297760009766, 49.65106282915388, 35.74450043269566, 35.87484516416277, 34.30394778932844, 39.56768764768328, 55.24381726128714, 53.73305654525757, 57.103308064596995, 54.4876309122358, 53.31163787841797, 56.30962576184954, 53.71439020974295, 53.4436536516462, 48.31870753424508, 38.111265318734304, 25.121618475232804, 11.425278169768196, 3.517880980457578, 0.8341684245637485, 0.36852455511689186, 0.12582445330917835, 0.8160514852830342, 1.3185140490531921, 2.8399257021290913, 3.6295126932007924, 6.046024509838649, 4.9886467797415595, 4.911373691899436, 6.826863067490714, 3.2291831118719916, 7.356725743838719, 5.9600448948996405, 7.050761818885803, 3.965704321861267, 3.314470946788788, 1.5570568889379501, 0.4473252424171993, 0.5088188084108489, 0.28375506667154177, 3.994769505092076, 14.438014473233904, 34.24663209915161, 45.39706993103027, 16.835002286093577, 13.833984988076345, 21.747811215264456, 33.459397724696565, 26.198620523725236, 8.084690247263227, 0.28453150072268074, 0.01733995900888528, 0.06231332450572934, 0.08338825577603919, 0.05008414214743035, 0.033167551670755656, 0.04593028986294355, 0.07302317874772207, 0.11967020854353905, 0.0507730044690626, 0.053910655568220785, 0.07553873197840792, 0.07343979246382203, 0.053087500988372734, 0.0822791631466576, 0.07210287491657905, 0.030768367195768014, 0.034159223815160136, 0.07451511440532547, 0.04723424417898059, 0.05962430379752602, 0.05342425113277776, 0.037869741674512625, 0.06175966028656278, 0.03323790557416422, 0.0190686168747821, 0.053117773828229735, 0.06778832179095064, 0.04559516480990818, 0.022940057795494795, 0.021381417056545615, 0.0391428565739521, 0.061422292675290785, 0.015550724929198623, 0.017536527211112634, 0.033724907120423656, 0.061384525416152816, 0.017416798010734574, 0.037324674494032345, 0.1737283199493374, 0.10825075594974415, 0.1658035601888384, 0.10671041360391037, 0.1130831330748541, 0.06829959114215203, 0.1619227741445814, 0.14773174348686421, 0.16752876261515276, 0.07420497640435185, 0.06446608541799442, 0.15134946150439127, 0.12879506605012075, 0.060315215294914584, 0.10689096498702254, 0.11954755655356816, 0.21591014148933546, 0.09909909630992583, 0.0992122148828847, 0.11979773241494383, 0.2020276678459985, 0.12702567742339202, 0.1041063726214426, 0.25742047120417866, 0.18700851233942167, 0.18756953866354056, 0.15992258861660957, 0.21442243989024842, 0.17760146568928445, 0.15061022474297456, 0.11712176672049932, 0.11389837254370962, 0.054880665482154915, 0.1553309421454157, 0.12529894150793552, 0.10946441082549946, 0.11513938595141683, 0.21447600344462053, 0.20876319999141352, 0.11413702688046864, 0.13042888338012354, 0.14959512278437614, 0.1183527513806309, 0.10526343767664262, 0.217965695474829, 0.13076634598629816, 0.269034385148968, 1.27946560723441, 15.715847253799438, 39.04514489855085, 47.88804081508091, 39.62157440185547, 31.372096334184917, 29.191793305533274, 25.702277694429668, 40.74420527049473, 28.147175073623657, 13.855437551225934, 4.309471224035535, 0.24154082472835267, 3.6302272719996314, 4.456735253334045, 11.550707050732203, 13.181414519037519, 7.766384584563119, 5.164780139923096, 2.7772876918315887, 0.2406498539660658, 0.7065750711730548, 0.3978138177522591, 0.32327832015497343, 0.6522506347724369, 1.5615709381444114, 3.425309262105397, 3.191108286380768, 3.3099111914634705, 4.500565792833056, 7.447142652102879, 11.657612034252711, 25.82312250137329, 43.304519176483154, 53.781846795763286, 62.30764429909842, 57.52644988468715, 56.658091817583355, 61.167639459882466, 58.76926721845354, 55.78263963971819, 51.82241310392107, 40.7918039049421, 38.362870012010845, 37.75553144727434, 44.51725428444998, 57.71720225470406, 55.03043808255877, 58.60271889822823, 55.79459054129464, 52.8998007774353, 55.87362282616751, 51.466168539864675, 51.875452177865164, 45.397122042519705, 34.80559035709926, 20.648859807423182, 9.101957763944354, 2.3930301623685017, 0.6660117049302373, 0.25671764463186264, 0.1492363948907171, 0.6125404856034687, 1.1063827233655112, 1.8608645924500056, 3.1405959682805196, 5.456307010991233, 7.246996317590986, 5.098136058875492, 8.459833911487035, 3.995311898844583, 14.699188573019844, 7.774637307439532, 5.697951461587634, 10.211696250098091, 8.702068958963666, 9.787412319864545, 2.195699151073183, 1.215904789311545, 0.8224690152066094, 5.067215706620898, 18.513355289186748, 47.51462377820696, 38.586921623774934, 17.25307365826198, 29.334773336138042, 33.811907632010325, 40.610907554626465, 28.25583621433803, 7.395958747182574, 0.25447109660931994, 0.07729152363858052, 0.24973994333829197, 0.253897843084165, 0.15035126863845757, 0.09695947183562176, 0.09801091612981898, 0.15928918974740164, 0.20134397596120834, 0.11347359605133533, 0.15327736948217663, 0.10425513463893107, 0.13984471027340206, 0.12037876195141248, 0.18126524266387734, 0.1917529920382159, 0.13922993040510587, 0.18226051782923086, 0.29443200517977985, 0.13745751551219396, 0.12311392304088388, 0.15825612018150942, 0.3942035771906376, 0.1267205945083073, 0.19576032486345085, 0.1341055796614715, 0.12704835406371526, 0.0986570714573775, 0.23402203246951103, 0.12365323624440602, 0.11224142395492111, 0.09016354328819684, 0.1278495682137353, 0.13769218006304332, 0.14134790961231503, 0.1604298342551504, 0.16088484626795563, 0.1240940804460219, 0.12333729676902294], [0.007549681717396847, 0.0745838839294655, 0.023396784805559685, 0.023454729999814714, 0.021985462500846813, 0.03993859155369656, 0.05476227469210114, 0.05131159842546497, 0.12036695544208799, 0.06308050333921399, 0.16070692081536564, 0.04376417198883636, 0.014635577964197313, 0.05416793229856661, 0.0376397759786674, 0.006805788933499051, 0.03868077761892762, 0.01575688592025212, 0.016375253542459438, 0.019516548374667764, 0.06584682275674172, 0.011486793801720654, 0.1062422108703426, 0.04904573590361646, 0.020746610227173994, 0.11022560498011963, 0.0287413252517581, 0.06809159301753555, 0.023236962667267238, 0.0653110650767173, 0.011497201680737947, 0.03856480580621532, 0.03310699581301638, 0.055049613916448185, 0.07048010413667985, 0.011689015896990895, 0.02702704893558153, 0.0324210579773145, 0.023276545007580092, 0.04042681785566466, 0.043810498967234573, 0.03817688055070383, 0.06160009599157742, 0.04887749993109277, 0.03295500057616404, 0.05693057405629328, 0.07630099821835756, 0.07179180053727967, 0.3037775494158268, 7.133575226579394, 24.863810777664185, 35.022245611463276, 29.9705091885158, 23.689954314913066, 20.983439888272965, 24.990125553948538, 20.149471930095128, 22.173355375017437, 17.563288143702916, 10.087016906057086, 1.0514664415802275, 0.25153431562440737, 1.0238902355943407, 2.33343220608575, 1.6171520756823676, 1.9519037987504686, 1.7714424708059855, 0.8255447330219405, 0.4874642257179533, 1.0470910306487764, 0.19151707898293222, 0.14183425637228148, 0.03593007468485406, 0.11420638673007488, 0.23642667915139878, 0.0604551224304097, 0.2710354934845652, 0.32047963461705614, 0.36655729210802485, 1.1732743339879173, 5.752888262271881, 20.402410677501134, 41.31768873759678, 52.001207624162944, 47.341502462114605, 49.38321672167097, 48.29910666601998, 39.48159946714129, 34.37694556372506, 35.021411827632356, 29.253910200936453, 29.88609552383423, 36.70902156829834, 54.64660569599697, 47.25755085263933, 36.13220296587263, 24.609362534114293, 20.388245037623815, 17.230490275791713, 17.202664477484568, 12.697453379631042, 8.028381177357264, 3.55392758335386, 0.6768971436790058, 0.06606571815375771, 0.018161098339727948, 0.0383568246449743, 0.2760098879890782, 0.6506039117063794, 1.3022723091500146, 1.5323133766651154, 3.9725000943456377, 4.872460305690765, 8.002374070031301, 5.016046566622598, 4.963237217494419, 7.096768447331019, 3.4245816554341997, 3.2998558453151157, 6.217664122581482, 9.74867524419512, 2.457374606813703, 3.21321810569082, 0.6711420810648373, 0.622037587421281, 1.3277174809149332, 12.182855027062551, 18.103536639894756, 38.527823720659526, 29.121196133749827, 9.805329118456159, 20.787373883383616, 24.219905580793107, 31.927392891475133, 16.03112002781459, 2.6815888498510634, 0.04694298641490085, 0.12207976781896182, 0.053913369708295376, 0.03626508438693626, 0.03979573618354542, 0.03640725104404347, 0.0795092067814299, 0.07315297571143933, 0.057714268432131836, 0.03789888136088848, 0.0434490263994251, 0.04899028262921742, 0.025014157839385525, 0.062221654424709935, 0.048378410283476114, 0.03787256098751511, 0.009543495801543551, 0.03865625875602875, 0.016596584880192364, 0.05819765677941697, 0.046059041882732084, 0.009257048850746026, 0.03555497034851994, 0.051463837934924025, 0.04064339266291686, 0.01692908230636801, 0.08195202105811664, 0.10289956416402544, 0.03395529690065554, 0.024482004876647676, 0.029608917089977434, 0.049585161065416675, 0.06939505200300898, 0.0168278279182102, 0.07002832873591355, 0.010062166273460856, 0.037579060665198734, 0.06251142958977393, 0.08857704699039459, 0.03793820246521916, 0.019567691255360842, 0.03287576464936137, 0.0077979958483151025, 0.06374206141169582, 0.024535515844555836, 0.060651992580720356, 0.024113460277606334, 0.03404715357880507, 0.09954680728593043, 0.06588858658713953, 0.019206406981019036, 0.02216697401101036, 0.0144892417094005, 0.07615957794977085, 0.04524085417922054, 0.022846467460372617, 0.06276153759764773, 0.06454812030174903, 0.02473371253082795, 0.036682257894426584, 0.04985941813460418, 0.0712686703939523, 0.049797433960650644, 0.06400874603007521, 0.030034738526280438, 0.06875107477286033, 0.03888814131330166, 0.09248445196343319, 0.03877575895083802, 0.042935585736164024, 0.010568336433997112, 0.03217766407345023, 0.028089629685772315, 0.03893265999587519, 0.0669173678117139, 0.06291459474180426, 0.056085322983562946, 0.08302794689578669, 0.020791437643181, 0.038895737512835434, 0.004190750170632133, 0.03485900715791753, 0.05651173474533217, 0.06184969509818724, 0.038373536962483606, 0.0761582480211343, 0.05719158612191677, 0.0645698673490967, 1.223252835018294, 12.420301897185189, 32.37128550665719, 41.13857807431902, 30.414773532322474, 21.430415766579763, 14.444280879838125, 30.559160573141916, 27.272327389035905, 28.774355956486293, 23.536998408181326, 7.541419284684317, 1.1838259335075105, 0.09791036402540547, 0.13991466723382473, 0.668509093778474, 1.479024384702955, 1.889057559626443, 1.3192200511693954, 1.4613466475691115, 2.873389312199184, 1.843068084546498, 0.3553565245653902, 0.33455584357891766, 0.2583797297307423, 0.6410347766109875, 0.807178581399577, 0.24963086204869406, 1.1987434987510954, 1.5761854967900684, 0.9322326396192823, 3.112632291657584, 10.357807312692914, 29.593732697623118, 47.5355031149728, 57.364782673971995, 52.435591629573274, 54.33344343730381, 52.841432435171946, 45.53300101416451, 41.32963963917324, 38.94766862051827, 32.06862545013428, 32.153157234191895, 43.44365685326712, 56.29158476420811, 52.16014419283186, 43.112040179116384, 30.1109288079398, 26.732169219425746, 24.986029590879166, 22.549212966646465, 17.99292826652527, 12.484432901654925, 5.720052378518241, 1.5514595721449171, 0.20475881200815949, 0.0723862922085183, 0.2541904002428055, 1.1767523416451044, 2.2686858517783026, 2.5610380385603224, 3.315125814505986, 6.863455321107592, 7.364270618983677, 6.4197728889329095, 9.060869591576711, 8.286590133394514, 6.1031895109585355, 6.695477409022195, 4.5643393993377686, 3.8673013278416226, 3.2738307160990576, 2.466575107404164, 0.443882057177169, 0.37683536059090067, 0.3528899683484009, 1.1432671270200183, 9.481296403067452, 21.434772287096294, 35.803838048662456, 43.31530278069632, 15.776916708265032, 13.684368559292384, 23.863605431147985, 33.655375140053884, 22.92310769217355, 4.370378264359065, 0.04138473966824157, 0.031751184458179135, 0.026340108564389602, 0.030174224970063994, 0.056062419034008465, 0.041455517656036785, 0.05388701201549598, 0.028556183579244783, 0.05374572406123791, 0.05112895376182028, 0.0569557680615357, 0.03693988746298211, 0.03228933397414429, 0.04654341071311917, 0.03753677775551166, 0.07363042687731129, 0.028710105855550085, 0.06647636076169354, 0.012600539484992623, 0.022581938887014985, 0.05377956260261791, 0.054395350095416815, 0.03199045965448022, 0.026749137955318605, 0.022362931531720927, 0.0346900383675737, 0.0878726462168353, 0.0692653636048947, 0.03544754807704261, 0.029572259235594953, 0.03182728894587074, 0.04406157049483486, 0.04359813786244818, 0.02313595594439123, 0.016376710696411983, 0.009343817364424467, 0.03163418127223849, 0.07328872342727014, 0.04532313333558185, 0.014347907954028674, 0.08618485142609902, 0.12422305638236658, 0.12305645112480436, 0.09771454560437373, 0.19116850197315216, 0.1206228309976203, 0.06127074187887566, 0.10731182633233921, 0.23232892474957875, 0.21367998687284334, 0.2582027135150773, 0.14544844600771153, 0.09924682016883578, 0.2487512906747205, 0.1513585267322404, 0.07287824366773878, 0.09988405954624925, 0.10782182003770556, 0.11631474431071963, 0.12896832318178245, 0.2105828816337245, 0.1266650360609804, 0.14039680707667554, 0.11940190222646509, 0.13018153022442544, 0.16560424731246062, 0.10708691911505801, 0.14446982209171566, 0.17459717047001633, 0.1832341341567891, 0.08733683425400939, 0.09918889363429376, 0.04656256236402052, 0.16652383868183407, 0.20254844347281115, 0.123263363593391, 0.13957378481115612, 0.19085804506071977, 0.1198760624974966, 0.11002374759742192, 0.14159504563680717, 0.15220864968640463, 0.08891016018709966, 0.1475964571748461, 0.09649299258100134, 0.15282855927944183, 0.17373952934784548, 0.14857209553675993, 0.9669220639126641, 10.912703480039324, 35.0598909514291, 49.495975562504356, 42.063897473471506, 35.38806479317801, 28.031058515821183, 33.32928923198155, 28.127952882221766, 29.954250403812953, 23.96308105332511, 13.064713444028582, 1.6919587701559067, 0.6501498903547014, 2.2209328370434895, 4.903031510966165, 6.671393649918692, 8.305106214114598, 6.873835495540074, 4.547013631888798, 2.836060549531664, 2.5158337099211554, 1.0434563628264835, 0.34030197667224066, 0.23825242689677648, 0.41644139534660746, 0.6595559599144118, 0.2141051840569292, 0.8486630725009101, 0.9128974314246858, 0.6944798859102386, 2.231892534664699, 8.521512201854161, 26.900270462036133, 45.127191475459504, 59.394083976745605, 57.178821086883545, 52.911029066358296, 52.10505540030343, 46.63343586240496, 43.078244141169954, 45.742805344717844, 36.17061608178275, 39.86898238318307, 48.901449475969585, 61.803983279636924, 53.30535670689174, 41.452914578574045, 26.983238901410783, 23.92016724177769, 20.903335843767437, 19.694906881877355, 15.201928956168038, 9.578675406319753, 4.3881595730781555, 1.3405122629233768, 0.3346206029610974, 0.1831725910305977, 0.24632360094359942, 0.3340191495205675, 1.5895764125244958, 4.053236424922943, 2.8522778621741702, 10.27225501196725, 11.38572381223951, 14.799468449183873, 14.319400038037982, 13.611798099109105, 13.230673772948128, 7.98984386239733, 10.4299122435706, 9.737106493541173, 16.806801285062516, 7.447162628173828, 6.0782515576907565, 1.6294417019401277, 1.0079152413776942, 1.983798201595034, 15.428792851311819, 24.66171199934823, 46.08255141122, 39.74928229195731, 16.12820199557713, 28.46932135309492, 33.7621203150068, 42.940923418317524, 24.84351682662964, 4.326635880129678, 0.18545896905873502, 0.13587320409715176, 0.10734932217746973, 0.111628394706973, 0.14624450329158986, 0.07931499648839235, 0.18570649863353797, 0.13058272083955152, 0.23176745059234755, 0.1827737210052354, 0.12124440978680338, 0.13678613225264208, 0.12828216142952442, 0.11697805300354958, 0.12502250634133816, 0.1559406737131732, 0.13907643221318722, 0.19723163305648736, 0.0411720121545451, 0.13357541311000073, 0.17643578323934758, 0.2196623451475586, 0.29020554625562256, 0.1407935872141804, 0.09543660176651818, 0.1306170682821955, 0.1605689339339733, 0.18232826276549272, 0.11474745055394513, 0.11335795332810708, 0.1414290624005454, 0.1860848090478352, 0.0963363324158958, 0.15507271885871887, 0.1340566708573273, 0.10068269526319844, 0.13620882108807564, 0.14679839142731257, 0.14922423554318293, 0.0776181093284062], [0.011138185409695973, 0.03675665586654629, 0.05264160170086792, 0.08856451444860015, 0.011855114484205842, 0.06126135773956776, 0.04267587985045143, 0.11514029518834182, 0.0361627986255501, 0.041501909095261774, 0.03484575876167842, 0.017336953098752668, 0.03159836480127914, 0.04304877894797495, 0.011841467448643275, 0.02583042868146939, 0.06169323849358729, 0.028736080176063945, 0.11338266557348625, 0.10871188156306744, 0.05148942209780216, 0.12367532934461321, 0.04924170020967722, 0.04372722914974604, 0.06791898727949176, 0.05375206157831209, 0.025793748774698803, 0.1198801744197096, 0.049403249219592126, 0.009853749153470355, 0.039235208582665236, 0.07070100799735103, 0.032770798674651554, 0.0857451878754156, 0.05216178584045597, 0.04476102814078331, 0.07133387760924441, 0.004202086370371814, 0.0842838202204023, 0.047099487124277015, 0.03575588796021683, 0.035807266631828885, 0.039229054270046096, 0.0528981015086174, 0.003721512671160911, 0.011462498855377947, 0.011199597069727523, 0.0334584057064993, 0.05151121664260115, 0.13038604067904608, 3.8605945791516985, 15.887853384017944, 37.8062915120806, 32.43669932229178, 33.90948118482317, 29.23925645010812, 19.683315549577983, 19.100822005953106, 22.205113853727067, 20.065237181527273, 18.326559918267385, 6.323044845036097, 1.054774435503142, 0.24204000937087194, 1.090585885303361, 0.6625151325549398, 0.9457492743219648, 0.9793849608727864, 3.3466026740414754, 0.6142616303903716, 0.21485690586268902, 0.8311850417937551, 0.42140018354569164, 0.9856043585709163, 0.2989797911473683, 0.33244736386196955, 1.0874664698328291, 0.768682738499982, 0.2909375769751412, 0.17732034863105842, 0.12187353388539382, 0.9602043500968388, 6.63235649892262, 9.52486595085689, 15.558255161557879, 18.389996971402848, 14.420509355408804, 6.975188434123993, 6.359102087361472, 18.703254767826625, 24.637457575116837, 19.186892815998622, 22.311172894069127, 25.553867646626063, 14.779660872050695, 6.344260735171182, 3.9714782748903548, 3.613983903612409, 1.9530593710286277, 0.7055094997797693, 0.10463384538888931, 0.1452204446707453, 0.08835187514445611, 0.029791619429098706, 0.4024795873888901, 0.0920678178912827, 0.05281278930072274, 3.3604968999113356, 2.999001886163439, 2.420557405267443, 4.5875624503408154, 6.912086631570544, 7.2441723091261725, 4.64440392596381, 6.661773434707096, 7.611960002354213, 5.584285880838122, 6.087334590298789, 2.5337231499808173, 5.031396005834852, 3.9452787893159047, 1.836012840270996, 0.30415739331926617, 2.0832147640841345, 7.0205797127314975, 21.468959161213466, 24.31223498071943, 34.155113901410786, 35.13404212679182, 9.988857967512947, 23.304624591554912, 28.427774599620275, 28.35301719393049, 13.202094963618688, 0.40123374281185015, 0.10323594111417021, 0.04180585885686534, 0.14486786430435522, 0.004781884789865996, 0.016743328256000365, 0.023044906722913896, 0.03588940329583628, 0.06664369428264243, 0.02252581386294748, 0.05069050818149533, 0.02485079544463328, 0.011530769656279256, 0.01056223810051701, 0.031098711969596998, 0.04748253371300442, 0.030140020019773926, 0.02522260549345187, 0.006754600675776601, 0.006264068626998258, 0.10656699844236885, 0.02581579437745469, 0.02150229467744274, 0.11112354429704802, 0.09766151809266635, 0.0783680398017168, 0.05101480720830815, 0.07240143032478434, 0.043887634828154526, 0.04503260838932224, 0.02956951456144452, 0.026709316431411674, 0.030330824067017863, 0.04673861845263413, 0.03754876407661608, 0.07730545396251337, 0.02187455425571118, 0.028552061479006494, 0.03172551887109876, 0.0378099627393697, 0.06081083084323576, 0.01756225386634469, 0.011354950206753398, 0.04173725896647998, 0.03302178877804961, 0.0845738532287734, 0.016497562872245908, 0.003028716966842434, 0.07835635542869568, 0.0412470683056329, 0.012068327998609414, 0.02864149578713945, 0.018109566997736692, 0.04610049358702131, 0.025690049964136312, 0.08272823797804968, 0.03975088841148785, 0.026361831863011633, 0.054547521751374006, 0.029289679934403727, 0.1128664564873491, 0.08600037811057908, 0.05170451769871371, 0.06412592224244561, 0.07065369375050068, 0.05812179656433208, 0.028459660276504498, 0.09794819913804531, 0.080213308999581, 0.09972195753029414, 0.058491693144398074, 0.05254955164023808, 0.04258113261312246, 0.04332723614892789, 0.0416709830585335, 0.07071117245193038, 0.026255878619849682, 0.028290413286803023, 0.06254182795860938, 0.026603471753852706, 0.044369781456355534, 0.039470812904515436, 0.03239456797018647, 0.013560760683113975, 0.029724949970841408, 0.06004980632237025, 0.012714940489136746, 0.030363193580082486, 0.024675302540085146, 0.07068608022694077, 0.009664273338525422, 0.4419261935566153, 7.674578905105591, 23.85036563873291, 41.784892559051514, 35.28712831224714, 33.27601044518607, 29.05516913958958, 17.993214879717144, 24.276180778230938, 31.762974194117955, 33.84291396822248, 16.2732195854187, 5.021145675863538, 0.780660021517958, 0.17112636885472707, 0.27776151256901876, 0.6663235053420067, 0.8569663869483131, 1.8654868815626418, 1.4357785795416151, 2.7716359836714606, 2.1944167741707394, 1.7954676044838769, 1.601918475968497, 1.7239088671548026, 1.153497155223574, 1.2593225623880113, 1.7175569108554294, 1.9148642548492976, 1.0943019773278917, 0.8077989795378276, 0.2524705853845392, 2.0311797048364366, 18.988923004695348, 21.996311800820486, 23.295562403542654, 25.911051954541886, 21.124774932861328, 12.418416329792567, 10.888266665594918, 27.340492691312516, 30.220151015690394, 26.435731274741038, 30.43346766063145, 35.34531947544643, 21.610872643334524, 10.749628390584673, 6.091238175119672, 5.533362967627389, 3.2482361580644334, 2.346318074635097, 1.1173369927065713, 0.24773660940783365, 0.304018429347447, 0.21745500287839345, 1.1806138030120303, 1.7232764725174223, 1.7636522373982837, 4.649225975785937, 5.497059064252036, 4.027667922633035, 5.792258926800319, 7.067370619092669, 9.580813714436122, 7.496801427432469, 6.045025272028787, 5.999591435704913, 3.992843117032732, 3.679635695048741, 2.0773643808705464, 0.8504564134137971, 0.687168861074107, 0.2575910006250654, 0.4019864281373364, 1.0490955859422684, 5.584866489682879, 20.155666249138967, 31.087883744921, 31.24194962637765, 41.262370654514854, 16.436182635171072, 16.245284352983745, 31.524049963269913, 33.22163036891392, 20.50664928981236, 1.5415330933673042, 0.04821798085634198, 0.06941597802298409, 0.038883411924221685, 0.04915197752416134, 0.013910537851708276, 0.03310916373240096, 0.0909663112834096, 0.0692115489925657, 0.02171878975683025, 0.05383201675223453, 0.021557072809498225, 0.04493948285068784, 0.033822782404188595, 0.01584762640829597, 0.027004611478852372, 0.0499926959829671, 0.047961141781083176, 0.06355249229818583, 0.04115355260936277, 0.04946918586002929, 0.015939379609855156, 0.020045298484287093, 0.05803134784634624, 0.11459013899522168, 0.018926180500004972, 0.05579429592138954, 0.05866516740726573, 0.06904141990733997, 0.014425394956820776, 0.01329215326612549, 0.046679687686264515, 0.0411269302879061, 0.027446522676785077, 0.021162514874179448, 0.03169707468311701, 0.03778825640412314, 0.01656159113294312, 0.020918640906789472, 0.02042665212814297, 0.040532146846609454, 0.006835918432833361, 0.1089444901528103, 0.14752735516854695, 0.13355561345815659, 0.2738081232777664, 0.06987589584397418, 0.16215141330446514, 0.0956038674339652, 0.11570928751357965, 0.1339030098170042, 0.1104838689789176, 0.1162685225052493, 0.11521399766206741, 0.14926175852971418, 0.17299793128456387, 0.138927643054298, 0.11725022697022983, 0.13729310647717544, 0.16776311503989355, 0.21096199271934374, 0.26219339509095463, 0.13434493967464992, 0.19925927211131367, 0.1824587993323803, 0.20837097960923398, 0.15548790086592945, 0.17655840808791773, 0.24155113846063614, 0.16197470921490872, 0.14269926638475486, 0.09891071463269846, 0.15373736194201879, 0.20275764938976082, 0.11044275654213769, 0.14224050885864667, 0.19684904787157262, 0.10492177493870258, 0.1362137065402099, 0.1515263555837529, 0.14478994134281362, 0.15428417974284717, 0.11892801336944103, 0.17564029592488492, 0.1506161687097379, 0.13604264786200865, 0.1239126944648368, 0.11628027473177228, 0.10934758745133877, 0.18969864584505558, 0.15147325343319348, 0.2628325750785214, 6.270543387957981, 24.173029558999197, 51.55936125346592, 44.74416160583496, 45.439415727342876, 38.1305569921221, 27.580646753311157, 26.701281002589635, 29.344716208321707, 28.53652606691633, 22.14100456237793, 8.327650512967791, 1.403195002249309, 0.6777519892368997, 2.5436899065971375, 3.029195500271661, 5.050590404442378, 6.564411801951272, 9.773388249533516, 4.510582489626748, 2.6534473427704404, 2.5997392875807623, 1.3064862830298287, 2.4633376811231886, 0.9212523145335061, 0.928861460515431, 1.4998068809509277, 1.6888415259974343, 0.732985716845308, 0.4578224505696978, 0.341450139347996, 1.6611800960132053, 19.153569255556377, 21.382987362997874, 19.690380130495342, 23.631598131997244, 18.756210463387625, 10.385828529085432, 10.033891848155431, 26.15503968511309, 33.033184800829204, 27.145515816552297, 32.237775870731895, 33.012965542929514, 17.308692250932964, 8.587055427687508, 4.418838041169303, 4.435440761702401, 2.5528135427406857, 1.2309261432715823, 0.6602868235536984, 0.20024613344243594, 0.2631662243178913, 0.19614257078085626, 1.14459271303245, 2.0149684718676975, 1.1177014474357878, 7.0771267584392, 8.085849727903094, 7.241868112768445, 11.04006656578609, 18.011097805840627, 13.855709399495806, 12.640191537993294, 11.773864081927709, 14.67093024935041, 11.580256002289907, 13.45086305482047, 9.2027040379388, 11.310979434422084, 7.662295358521598, 3.389104804822377, 0.4919468994651522, 2.943102542843137, 9.79055551120213, 28.019472394670757, 33.58854736600603, 42.23702573776245, 43.698377813611714, 17.514820984431676, 31.86870493207659, 39.27518238340105, 40.81216907501221, 20.04076736313956, 1.5546415214027678, 0.19397238508931228, 0.15424016996153764, 0.3037841719176088, 0.08937177434563637, 0.1251428106001445, 0.18890781328082085, 0.1557354847235339, 0.22311450062053545, 0.10636914441628115, 0.1608478661094393, 0.15344784462026187, 0.11196836110736642, 0.10155385958829097, 0.21414301916956902, 0.13875997705118998, 0.12313155138066836, 0.22773583978414536, 0.1318642156464713, 0.1661368158778974, 0.15306865211044038, 0.0886094266814845, 0.15648951354835713, 0.16758844655539307, 0.1469364868743079, 0.1409416435552495, 0.13015107757278851, 0.1698038905326809, 0.15439749509096146, 0.09991549607366323, 0.12484113393085343, 0.18864820578268596, 0.14119473711720534, 0.19218661662723335, 0.15175546971814974, 0.1623857385878052, 0.1317899024912289, 0.10028674972376653, 0.13370399549603462, 0.14276942690568312, 0.15929441446704523, 0.05625336218093123], [0.006858911440109036, 0.03842019981571606, 0.039144698796527724, 0.08060023680861507, 0.019348174998802797, 0.02025068424908178, 0.019633400586566756, 0.046168072282203605, 0.022339259141257832, 0.07610987525965486, 0.04525790576423917, 0.042475247223462374, 0.009547962258303804, 0.01827532971011741, 0.02394058312555509, 0.022825558403772966, 0.05618814139493874, 0.023174089612439275, 0.035065454830016406, 0.047179086067314656, 0.06326036940195731, 0.0035715962959719555, 0.03254358443830695, 0.06059242399143321, 0.023919713084719012, 0.00806433186932866, 0.019337469412546073, 0.0216308075136372, 0.08574104202645165, 0.0477269827388227, 0.03587990041290011, 0.02972539441127862, 0.04308094150785889, 0.03065255144611001, 0.05769412272742816, 0.05508349995527949, 0.04542333599446075, 0.02693711081519723, 0.004535751724948308, 0.029285333917609284, 0.06205421233815806, 0.017936199604134475, 0.02543710059087191, 0.017773726090256656, 0.033276894196335755, 0.07041252204882247, 0.04540008259937167, 0.06794779109103338, 0.06662273433591638, 0.01212155313364097, 0.040176760737917254, 1.6537425922495979, 12.126475606645856, 27.138326168060303, 36.82296855109078, 35.16014303479876, 24.867514167513164, 17.879764693123953, 20.256005184991018, 18.42060031209673, 23.66613415309361, 25.032499143055507, 16.87914592879159, 5.357350766658783, 2.30000615971429, 0.6653026629771505, 0.2604335738079888, 0.7003703298313277, 1.7892446241208484, 3.0772503273827687, 1.9555594197341373, 1.494140082171985, 2.502305784395763, 2.0402592633451735, 1.3656751641205378, 2.2430917280060902, 2.855468822377069, 4.077250267778124, 2.503183428730283, 3.5289594488484517, 0.576143487223557, 0.3443547577730247, 0.5909495555928775, 2.713358836514609, 2.8397296326501027, 0.19327939727476665, 0.4767442409481321, 0.08542038673268897, 0.11744104458817414, 0.9942908010312489, 3.4878558601651872, 2.589113537754331, 3.33985293337277, 1.1647419461182185, 0.18837922093059334, 0.11089958024344274, 0.08835157658904791, 0.13098301578845295, 0.03791865387133189, 0.431789830327034, 0.4477184127484049, 0.55302851327828, 0.6639170944690704, 0.22326736098953656, 1.1234346883637565, 1.016835208450045, 3.388086676597595, 7.311213306018284, 4.126128673553467, 2.200354878391538, 3.7705328975405012, 3.110430581229074, 7.45863584109715, 4.637096158095768, 5.88104908806937, 2.56596821972302, 3.389169509921755, 3.9897989375250678, 1.1496656579630715, 0.2350565269589424, 0.21372905852539198, 0.7581292390823364, 6.012761311871665, 14.348684089524404, 28.144199507577078, 23.758791855403356, 25.133722237178258, 37.90888861247471, 13.883421421051025, 18.956381116594585, 29.57303053992135, 20.184044429234095, 5.649785246167864, 0.24804048453058514, 0.011727942602841981, 0.02464206110952156, 0.07705717121383973, 0.03016351768746972, 0.039540033654442856, 0.039649939364088435, 0.02360507470023419, 0.013180720004519182, 0.06574150055114712, 0.05949027956064258, 0.06306507345288992, 0.027577637694776058, 0.054064452315547636, 0.026382459327578545, 0.029181226289698055, 0.054119508646960766, 0.021334738936275244, 0.018927167768457105, 0.08160695207438298, 0.04321636352688074, 0.03577358415350318, 0.053800373271639855, 0.03820681073037641, 0.023078558667163764, 0.030635323441986526, 0.016785500903746912, 0.015738553600385785, 0.044205850788525174, 0.04148443681853158, 0.0066369223474924055, 0.06712240752364908, 0.010860487319795149, 0.04699330657188382, 0.03942120860197714, 0.06052278594246932, 0.03833159671298095, 0.026799215536032404, 0.07609230798802205, 0.044991214360509596, 0.03432361588680318, 0.04792053146021707, 0.014874206855893135, 0.034293336261595996, 0.025195552302258353, 0.051734515731888156, 0.05822480496551309, 0.03983898261295898, 0.05677112511226109, 0.012545137100719979, 0.017074461826788526, 0.025304072104128342, 0.07042118015566043, 0.03855708747037819, 0.018002938612231185, 0.0457090670908136, 0.047976910934916565, 0.04480014907728348, 0.015230235876515508, 0.02912543374778969, 0.004328999560259814, 0.05209292810676353, 0.021446174742387872, 0.10605255354728017, 0.061035364866256714, 0.05664814742548125, 0.037901395333132575, 0.05656970199197531, 0.056841180460261445, 0.009085323511888939, 0.012966888175079865, 0.06970601103135518, 0.07199986651539803, 0.04774365773690598, 0.009781942336953111, 0.037226429408682246, 0.030397636017629077, 0.04457017998876316, 0.020877277412052666, 0.042548997194639275, 0.021601749251463583, 0.030898123447384154, 0.034498070632772784, 0.04304078919813037, 0.07651831262878009, 0.03648184918399368, 0.04448293734874044, 0.037339941531951935, 0.02220287699518459, 0.012657522007689943, 0.038742432703397105, 0.04264058245878134, 0.07693897041359118, 0.03956883746598448, 4.064781725406647, 20.39833034787859, 37.62686817986624, 42.08193152291434, 38.909102644239155, 24.04882182393755, 15.429324388504028, 16.155537945883616, 22.81276682444981, 35.986850125449045, 30.61770609446934, 15.746186562946864, 4.192619025707245, 1.114653685263225, 0.2214208636432886, 0.32534872048667496, 0.4065651281603745, 0.302066121250391, 1.4200461208820343, 1.7231808262211936, 1.2611853310040064, 4.012768379279545, 2.975328287908009, 2.3242104266371046, 4.034351221152714, 6.512603427682604, 5.306688845157623, 4.7709809967449734, 5.1601448229381015, 1.5381360756499427, 0.3040156066417694, 0.26636901817151476, 2.2464709409645627, 3.8383898735046387, 0.5357766247221402, 1.1060197885547365, 0.10178954194166831, 0.41221032238432337, 2.326172424214227, 7.496886542865208, 4.358636243002755, 6.777841789381845, 2.8183819438729967, 0.656347954911845, 0.38730588874646593, 0.5905948717679296, 0.6781430968216487, 0.558017971260207, 0.7220360615423748, 1.631717562675476, 2.1528179092066626, 2.378484760011945, 1.0144647870744978, 4.603918075561523, 4.405743292399815, 7.048620905194964, 9.743596111025129, 6.902925865990775, 5.510205924510956, 5.178408597196851, 3.7501169187682013, 6.868164462702615, 4.671251331056867, 3.9936508451189314, 4.429163932800293, 2.0502581553799764, 0.9676480420998165, 0.13157406050179685, 0.4665380428944315, 0.15334537226174558, 0.9266207750354494, 4.051508494785853, 14.248147998537336, 32.159580843789236, 36.12026596069336, 28.10394685609, 38.916561535426546, 20.96567508152553, 17.53937939235142, 31.50287185396467, 27.941529239927018, 11.662924800600324, 0.8964427943740572, 0.05541451308610184, 0.056999859267047474, 0.12743862026504107, 0.022276939092470065, 0.04627354715817741, 0.037082678372306485, 0.005268935953998672, 0.02583224036996918, 0.10775850593511548, 0.049067611872617684, 0.03581646756668176, 0.08264361109052386, 0.01443578502429383, 0.07073056498276335, 0.08838698933167116, 0.09616907353379897, 0.016217801187719618, 0.04219038804460849, 0.0820365868774908, 0.052131787807281525, 0.05713455525359937, 0.042438809892960956, 0.026301560989980186, 0.03246387014431613, 0.0170416190355484, 0.0821982885577849, 0.05715664156845637, 0.012543189705216458, 0.0034379136590619703, 0.011708101390727928, 0.1021194795944861, 0.012990491863872324, 0.05450697249865957, 0.02860809150817139, 0.009576262257594084, 0.028380539700655, 0.02914401882195047, 0.05716506897338799, 0.11975064208464963, 0.01694464959603335, 0.04824187546702368, 0.006282405611792845, 0.20584083109029702, 0.14096866281969206, 0.1083093203072037, 0.17049505987337657, 0.08740394136735372, 0.10925948646451746, 0.07747822933431182, 0.1306925213762692, 0.15535431089145796, 0.20949377864599228, 0.29499299079179764, 0.105098479028259, 0.14539150334894657, 0.2689919631396021, 0.15119931527546474, 0.12868221210581915, 0.14585382996925286, 0.15998785011470318, 0.14168837134327206, 0.07991963225815978, 0.201205989079816, 0.14905894441264017, 0.1292134914547205, 0.10362360852637462, 0.10092222491013152, 0.16672041027673654, 0.12057584923292909, 0.1355693018329995, 0.17007637662546976, 0.2014129694019045, 0.0898465792249356, 0.10108815386359181, 0.11144267967236893, 0.08284544811717101, 0.11029699364943163, 0.15699445216783456, 0.1364514244986432, 0.09151636569627694, 0.14837532038135187, 0.07659336538719279, 0.17267680780163833, 0.11162194862429585, 0.1629414316266775, 0.07739225216209888, 0.17469813648079122, 0.16749714288328374, 0.1428301693605525, 0.14192575003419602, 0.14410938428980963, 0.17983042608414376, 0.156847725755402, 3.1042060809476033, 18.661452668053762, 41.112202712467735, 49.83249419076102, 48.267930098942344, 35.59160532270159, 27.308767216546194, 29.339605808258057, 25.035127299172537, 32.890142236437114, 31.10240547997611, 19.843303033283778, 7.06622850894928, 2.688110602753503, 1.2592286531414305, 1.236352794936725, 2.197931911264147, 8.60147293976375, 8.608761600085668, 6.220977110522134, 6.66634578364236, 5.858520856925419, 5.219549315316336, 5.083399363926478, 4.786494152886527, 8.362697226660591, 8.857111930847168, 6.650276771613529, 7.913942609514509, 2.540171946798052, 1.5761061353342873, 0.30477084325892584, 8.121216927255903, 5.348774952547891, 0.3716634309717587, 0.8189493726406778, 0.22907586502177374, 0.5575555903570992, 1.770666009613446, 5.35809986931937, 4.079523631504603, 5.458274219717298, 2.1052455476352145, 0.4971030056476593, 0.35639799439481323, 0.45719249865838457, 0.36702971532940865, 0.2956646318946566, 1.1372548724923814, 0.9951223049845014, 1.4802627925361906, 2.0550656574113026, 0.8392792588898114, 4.245292016438075, 6.318223229476383, 10.217506681169782, 18.670235191072734, 13.553209151540484, 11.572357637541634, 8.947587030274526, 8.365658027785164, 15.651142154421125, 9.227373617036001, 14.96214141164507, 9.234726548194885, 10.094596522194998, 8.982173425810677, 2.588628032377788, 0.7045305637376649, 0.6133760607668332, 1.243800503867013, 7.586716328348432, 17.890457970755442, 35.53872258322579, 30.523790768214635, 32.596202169145855, 47.426569257463726, 22.705728088106426, 29.889618260519846, 40.40980931690761, 33.298963819231304, 12.50242178780692, 0.9445961990526744, 0.12430468414510999, 0.10588098596781492, 0.22236196457275323, 0.09301156510732003, 0.10393093060702085, 0.15210912216986927, 0.11037641617336444, 0.11485814675688744, 0.15712648151176317, 0.17462212698800222, 0.1982690588171993, 0.19769216834434442, 0.10814052115061454, 0.25733695711408344, 0.13368807706449712, 0.23687529936432838, 0.10465625740055527, 0.09515755424009902, 0.16030577091234072, 0.17472811415791512, 0.1336715208100421, 0.10549906574721847, 0.11549088066177708, 0.09654123642082725, 0.1269192559910672, 0.19749856873282365, 0.17497534517730984, 0.20090609017227376, 0.08230061842394726, 0.1707315021859748, 0.20586285633700235, 0.15985602433128016, 0.1287797854415008, 0.09489591113690819, 0.1556523913251502, 0.08963545983923332, 0.19332845535661491, 0.1920979456709964, 0.16894007474184036, 0.1039213700486081, 0.1497492587992123, 0.09567760383444172], [0.009909676554213678, 0.04338333403159465, 0.04529486217402986, 0.021510895108804107, 0.09374020315174546, 0.019816258988742317, 0.018791253811546733, 0.014569020464218088, 0.03727196589378374, 0.023931928411392227, 0.08363708135272775, 0.032604004589042494, 0.009103562533190208, 0.030406453580196415, 0.052320732668574364, 0.029903540387749672, 0.08123939644013133, 0.06796338382576193, 0.05556886623214398, 0.01826454439599599, 0.04644964735156723, 0.03595668343561036, 0.04195539779695017, 0.0206141703695591, 0.05258297288258161, 0.07868586560445172, 0.05435936738337789, 0.053460569719650915, 0.0415355338981109, 0.047579126565584114, 0.08572188698287521, 0.01387019724851208, 0.01312718868056046, 0.01932002936622926, 0.02444315026514232, 0.02661932572456343, 0.04400041074092899, 0.029889274188982587, 0.02829811635560223, 0.00806780342411782, 0.04571139107325247, 0.04007095677245941, 0.019664893093119775, 0.06479280002947364, 0.0744994402463947, 0.0473895676300994, 0.059377914161554406, 0.005407360066393656, 0.04747485608926841, 0.07215430787099258, 0.06253382803073951, 0.03278203182188528, 0.3288342463118689, 5.6212203332356045, 19.740940434592112, 37.97887086868286, 39.404182638440815, 29.170087133135112, 21.16815948486328, 22.108405351638794, 12.877268416540963, 20.911805697849818, 25.25235751696995, 26.071327788489207, 14.9297628062112, 8.033955369676862, 2.1116185656615665, 1.0893863439559937, 0.2602835361446653, 1.3996927844626563, 1.6143134108611514, 1.1475728388343538, 2.5451514167445044, 1.7486093874488557, 2.596877932548523, 4.259173214435577, 4.18053263425827, 4.204028836318424, 2.8418531758444647, 2.990325540304184, 0.30974314787558144, 0.24866346110190662, 2.0562768152781894, 4.301211552960532, 16.574988535472325, 0.0481084720896823, 0.11976926108556134, 0.03423909756488033, 0.03604836369465504, 0.043573836130755286, 0.11432594460036073, 0.09544692228415183, 0.06766707436846835, 0.03384189673566392, 0.07092233254973378, 0.036032489367893765, 0.11253603028931788, 0.907349457698209, 0.979346745780536, 1.5290708478007997, 1.956709997994559, 2.4907266114439284, 3.323540300130844, 1.2801036472831453, 4.856672261442457, 2.554192977292197, 5.432641880852835, 3.482158120189394, 5.380869550364358, 3.810544099126543, 6.288714230060577, 2.612059529338564, 6.897052466869354, 4.982799002102443, 2.0370713429791585, 3.757256192820413, 0.8388977593609265, 0.13287517854145595, 0.1848632831658636, 1.695896444576127, 5.754472885813032, 14.778158324105398, 23.887686150414602, 33.07642344066075, 26.104637452534266, 21.36249017715454, 29.16816943032401, 16.68679026194981, 20.56703782081604, 30.175477572849818, 25.39826100213187, 5.949660377843039, 0.2729155511728355, 0.023562198072405796, 0.05203287097226296, 0.08058209278221641, 0.062295356898435524, 0.025330392477501715, 0.017260999585102712, 0.07144888250955514, 0.02702005154320172, 0.030613627284765244, 0.04239625556926642, 0.010610749961675277, 0.05031815530466182, 0.018500345493001596, 0.028859034114118134, 0.017393654877586023, 0.06422521227172442, 0.028974127223981277, 0.041019036434590816, 0.03425144011686955, 0.00654749948963789, 0.04299641640058585, 0.030823620302336555, 0.0269240982098771, 0.049557829674865515, 0.03552402575899448, 0.04256309375965169, 0.027170280892668024, 0.03727673938763993, 0.03726994385942817, 0.03574196781430926, 0.06308038798826081, 0.0529071870925171, 0.04515464969777635, 0.033756411501339505, 0.04625891115782516, 0.08248914259352855, 0.04090582965207951, 0.0370980811172298, 0.05504932214639016, 0.0922545168016638, 0.016346040913569074, 0.04972901388204523, 0.062177352873342376, 0.0481000887895269, 0.003892456422493394, 0.011992352432571352, 0.06677488224314791, 0.051663350979132314, 0.04371392307803035, 0.09813317456947905, 0.0488840647573982, 0.027511095461834754, 0.02821603397439633, 0.029538359626063278, 0.00845841907097825, 0.016366600524634123, 0.035219645127654076, 0.03127839482788529, 0.005824873689562082, 0.049856480077973435, 0.029470723255404403, 0.04894075635820627, 0.01602749077470175, 0.06696863791772298, 0.029993917859558548, 0.06386920530349016, 0.028881985561123917, 0.009219324848215495, 0.03655810294938939, 0.02782737081205206, 0.08760442810931376, 0.03195704859016197, 0.006562918773852289, 0.027409135397257547, 0.013680421181821396, 0.052018309610762765, 0.03526230801695159, 0.03402260757450547, 0.04743026276784284, 0.052547675490911515, 0.02539611029039536, 0.0681405153923801, 0.036694139042603116, 0.04036025696301034, 0.06281909093792949, 0.04019303879301463, 0.04108133952000311, 0.008594325394369662, 0.06901512667536736, 0.050426028801926544, 0.010017074228796576, 0.04796264473614948, 0.06294418565396752, 0.03766665614343115, 0.004487511277797499, 1.0547467512743813, 11.125569360596792, 29.38974400929042, 43.9151268686567, 39.72405685697283, 26.154499462672643, 18.8968437399183, 16.445289986474172, 17.018941947392054, 28.94231823512486, 36.613713128226145, 31.44486481802804, 16.118596111025127, 7.320917333875384, 1.6393144407442637, 0.46809601358004976, 0.04984720450426851, 0.5744948099766458, 0.534211163009916, 0.6807926946452686, 1.6450477902378355, 1.5983814086232866, 2.7041659355163574, 3.5578509271144867, 4.107730712209429, 3.0550217373030524, 4.854219113077436, 6.616746936525617, 2.1980745664664676, 1.730626798101834, 6.357778455529894, 9.237511907305036, 19.28489715712411, 0.11421957745083741, 0.6581372246146202, 0.0959650312683412, 0.2892402080552918, 0.10978186343397413, 0.19323332474700042, 0.09741789009422064, 0.24619511355246815, 0.02162565234383302, 0.24689169760261262, 0.6238650179335049, 0.686654151550361, 2.1764528581074307, 2.2556890291827063, 2.166871726512909, 3.913334012031555, 4.549664803913661, 6.2992828743798395, 4.176371531827109, 6.383660929543631, 4.674784924302783, 6.65981708254133, 4.9276902335030695, 3.699459339891161, 3.7920410462788174, 2.300787614924567, 2.424700051546097, 1.9835454608712877, 2.68242632491248, 0.7683143211262566, 0.49818893309150425, 0.07499884202011994, 0.1775450115757329, 0.3478992075792381, 0.5740003479378564, 5.059286943503788, 13.926529782158987, 26.638962609427317, 37.804867131369456, 33.99352659497942, 20.447150128228323, 28.29687922341483, 24.670063734054565, 20.35963930402483, 33.367737088884624, 32.056799616132466, 9.659451689038958, 0.3641070750142847, 0.02251064351626805, 0.009036139901062208, 0.06113586268786873, 0.12785853844668182, 0.06788569156612669, 0.04166715612102832, 0.047091904495443614, 0.05602892654548798, 0.06152281763830355, 0.07807219853358609, 0.06067012982176883, 0.03352566888289792, 0.06944260373711586, 0.020916807165901576, 0.009625564612049078, 0.0316744387548949, 0.0339236398493605, 0.03294509396489177, 0.03215447174651282, 0.025743311570425118, 0.010085219500719436, 0.06180673026080642, 0.023951553340469087, 0.08449988612639052, 0.03907444328069687, 0.028016627799453478, 0.05143937335482665, 0.03851218880819423, 0.06356501126927988, 0.053670633983399184, 0.02817783923819661, 0.02089285827241838, 0.025820712060002343, 0.02328254664982004, 0.029245079827627966, 0.03221792834145682, 0.009608159340651972, 0.06629899170781885, 0.035510190429964235, 0.04622794960492423, 0.024121448331113373, 0.028448746040729538, 0.032970671342419725, 0.10625339312744991, 0.21352857856878213, 0.0696218116208911, 0.13756876811385155, 0.14456073221351418, 0.15300139571939195, 0.24389167715396198, 0.18275394849479198, 0.13373660588903086, 0.05994951884661402, 0.24550984746643476, 0.06898505400334086, 0.08644911367446184, 0.12275607724274908, 0.11846970367644515, 0.12790070261274064, 0.16217206791043282, 0.19935297779738903, 0.21177064361316816, 0.11857415735721588, 0.1505230465637786, 0.19423841152872356, 0.1515192309660571, 0.10242277796247176, 0.11525263344602925, 0.21448178456297942, 0.08763790702713387, 0.2415642206157957, 0.1134334539196321, 0.18992925275649342, 0.2912805899977684, 0.08221808820962906, 0.15134776516684464, 0.1064548162477357, 0.08395553819303002, 0.17888868733176164, 0.19258113045777592, 0.15365364429141792, 0.14769595754998072, 0.09602437594107219, 0.15968518278428487, 0.1695266818361623, 0.14267008937895298, 0.1256451979279518, 0.12048739540789809, 0.19774455124778406, 0.1417036790932928, 0.1408387097929205, 0.15096220799854823, 0.252353415957519, 0.1159533972718886, 0.0841665965105806, 0.8496051505208015, 9.847299712044851, 30.093137945447648, 50.59669181278774, 52.30430889129639, 40.25244304112026, 30.450751304626465, 30.582311970846995, 18.972080571310862, 29.579693862370082, 35.83768619809832, 33.26912130628313, 19.408450024468557, 10.025413308824811, 3.2324042533125197, 1.5478817926985877, 0.2503013089299202, 3.182823645217078, 5.160179998193469, 4.653943368366786, 8.419228638921465, 4.897255386625018, 9.967796240534101, 11.262043271745954, 11.004605565752302, 9.077482734407697, 7.416504570416041, 11.472773449761526, 2.3200577923229764, 3.407139071396419, 11.747309803962708, 18.04099416732788, 27.03616680417742, 0.14654327583100113, 0.3799761634852205, 0.19197471014090947, 0.21095727011561394, 0.13721909187734127, 0.4055902904697827, 0.22869395837187767, 0.2871898380773408, 0.1826689959104572, 0.35996993843998226, 0.5838272177747318, 0.46285794036728994, 2.3801221464361464, 2.3641497577939714, 2.6064410422529494, 7.283396627221789, 6.075421903814588, 8.449185797146388, 5.068101601941245, 10.509129524230957, 9.279914157731191, 13.402649504797798, 9.048894371305193, 13.151989766529628, 11.39717618056706, 17.858826296670095, 10.878009387425013, 13.87611973285675, 11.081795709473745, 6.319256774016789, 7.197688860552652, 2.336731949022838, 0.7086036194648061, 0.5885431447199413, 2.387304629598345, 7.388815999031067, 18.60863072531564, 31.21822500228882, 41.53104707172939, 33.378902844020296, 28.025015320096696, 36.65155301775251, 25.392478363854543, 30.89838205065046, 42.168856961386545, 35.858933789389475, 9.893968156405858, 0.46235783291714533, 0.11805218750877039, 0.13862372721944535, 0.17453724225716932, 0.2762447696711336, 0.14504602045885154, 0.12077220369662557, 0.1449267611439739, 0.14984502723174437, 0.12214531430176326, 0.1885500896189894, 0.20855501187699182, 0.0631347115018538, 0.1660940817424229, 0.08478662145457097, 0.15457558339195593, 0.15230931714177132, 0.12088845031602041, 0.14654318083609852, 0.15943067786949022, 0.10419854481837579, 0.11095804960599967, 0.19719622709921428, 0.14327446052006312, 0.20014799013733864, 0.16310030381594384, 0.09896815940737724, 0.1506923817630325, 0.10701334556298596, 0.15079842321574688, 0.15353765551533016, 0.12380605590130601, 0.17177093641034194, 0.25142672711185043, 0.08176677421267543, 0.10471710163567748, 0.1459951281015362, 0.21375933475792408, 0.12843887587743147, 0.10032500552811793, 0.20263036979096277, 0.16328375254358563, 0.16885402293077537, 0.12451023954365935], [0.057772032118269374, 0.04042387640635882, 0.07190191320010594, 0.03866746476186173, 0.007005497480609587, 0.07301693622555051, 0.059006735150303156, 0.039974591229110956, 0.026997337583452463, 0.056281168545995436, 0.0345072512115751, 0.026394437166995237, 0.06483672160123076, 0.019860932038032582, 0.017125387576275637, 0.033853336836078336, 0.012565155580107654, 0.04737881963540401, 0.04451938146459205, 0.0622371860912868, 0.0494637066897537, 0.03590025985613465, 0.07344416222934212, 0.03629417657586081, 0.01775326147409422, 0.060430980154446194, 0.019835176545062234, 0.043126406746783426, 0.02853029068293316, 0.04706975371975984, 0.03420098425288286, 0.06266921612301043, 0.05465794654030885, 0.051638754084706306, 0.0347184045240283, 0.05332016386091709, 0.022920056279482584, 0.009127726861541825, 0.027121076925790737, 0.022402084698634486, 0.03948764396565301, 0.01767318755654352, 0.07240919955074787, 0.009868837227778775, 0.03695424187130161, 0.018114455842546055, 0.011045865631396217, 0.05571740433307631, 0.052822638236518414, 0.03311826967235122, 0.022339774827872003, 0.07527003889637333, 0.03608993414257254, 0.1830492876470089, 2.141614590372358, 15.012748616082327, 35.5180412701198, 40.26215314865112, 34.84992333820888, 28.409658908843994, 20.90093524115426, 21.84230845315116, 20.45530210222517, 17.429038524627686, 25.21352403504508, 21.88095780781337, 19.659999132156372, 11.13897590977805, 6.082150799887521, 1.5073913825409753, 0.17124395897345884, 0.04067145008593798, 2.0945107979433875, 1.6398948324578149, 1.3623769411018916, 1.9442961726869856, 2.6927211667810167, 3.3096095962183814, 3.834806340081351, 2.98011776804924, 2.6443803778716495, 0.6246904964957918, 4.790314793586731, 0.9196673652955464, 0.8921453335455486, 1.0832572728395462, 0.8379396136317934, 1.0212557826723372, 0.31775290093251635, 0.19569274277559348, 0.15157488440828665, 0.22217235474714211, 0.16720280796289444, 0.2665407418140343, 0.2592213031436716, 0.9230193282876695, 0.9871044095073427, 1.8552089759281702, 1.891663134098053, 0.9517339531864438, 2.087994907583509, 6.251273427690778, 5.62450509411948, 4.193329479013171, 6.611286520957947, 3.0997360008103505, 6.335056109087808, 5.193823175770896, 2.5319463653223853, 1.8868117715631212, 1.0050487837621143, 0.6284977836268288, 0.6486388200095722, 1.668402531317302, 0.38085087654846056, 0.9999901694910867, 1.6534159183502197, 4.006937972136906, 9.576831528118678, 19.789763689041138, 18.554071732929774, 25.819988863808767, 23.83413985797337, 22.751508031572612, 18.05402030263628, 24.421247005462646, 20.677467278071813, 24.52119857924325, 34.07436193738665, 22.443301575524465, 4.857575527259281, 0.07152291068008967, 0.09056313256067888, 0.076504300880645, 0.014664419095164962, 0.009984976977908185, 0.08907087799161673, 0.026156364674014703, 0.018141631170042923, 0.06453758265290942, 0.043465664078082354, 0.07698353659361601, 0.0428077836654016, 0.00677062470432637, 0.012972147669643164, 0.09678905098033802, 0.09954894467123918, 0.013488560316285916, 0.02237006463110447, 0.029674958903342485, 0.056784475288752995, 0.06547231213854891, 0.0425982316955924, 0.07295230576502425, 0.019772350987685577, 0.02721114396782858, 0.03665607662073203, 0.03967201889359525, 0.03747380970578108, 0.0524981322565249, 0.06647962451513324, 0.08050940132566861, 0.004001790890470147, 0.04421390839187162, 0.05233362822660378, 0.01427888058658157, 0.030669833733034984, 0.0163493165413716, 0.04640894203579851, 0.05770884693733283, 0.057622876550470076, 0.032678830038223944, 0.009440187996785556, 0.043521415907889605, 0.03133383113890886, 0.046245540625282695, 0.020168610349563614, 0.03320109844207764, 0.031437640211411884, 0.030622295569628477, 0.020106514217332006, 0.049725994401212247, 0.04894639837688633, 0.0169016253868384, 0.06420849995421511, 0.002319652325240895, 0.05843464192003012, 0.036697392618017535, 0.04772024827876261, 0.04727894945868424, 0.01572798372113279, 0.050291784041162045, 0.012868055308769857, 0.025807065024439777, 0.06975080112793616, 0.0217367115630103, 0.026464690986488546, 0.02133197390607425, 0.0226489764505199, 0.009687514011082905, 0.02892699957426105, 0.05368997901678085, 0.03896003209852746, 0.0984542980524046, 0.029173562236662422, 0.02641787376653935, 0.052212061892662726, 0.018463852183361138, 0.050314613351864476, 0.03466018282675317, 0.029768712086869136, 0.061326626023011546, 0.023674855241551995, 0.030289620028010437, 0.03677406707512481, 0.014881441735529473, 0.06132330798677035, 0.02636518212966621, 0.07963113273893084, 0.07841945240007979, 0.024483616397316967, 0.04579954634287527, 0.04028643574565649, 0.09600184179310288, 0.05261161384571876, 0.0463325898828251, 0.0379840680398047, 0.04399222421592899, 0.059559171221085956, 0.4626136677605765, 5.13278238262449, 23.683247566223145, 42.491788387298584, 43.37815618515015, 33.84787845611572, 24.699713434491837, 13.34810961995806, 18.21453411238534, 24.176825012479508, 29.29596069880894, 32.49782262529646, 28.902595383780344, 23.169857331684657, 11.091648255075727, 4.028310631002698, 0.8926982581615448, 0.42514572399003164, 0.09224169927516154, 0.21884757386786596, 0.40720172971487045, 0.6208096018859318, 0.6195012235215732, 2.2710326058523993, 0.8401462637952396, 4.563059628009796, 4.834200484412057, 3.534315207174846, 1.8477850428649356, 9.701343246868678, 5.256470305579049, 3.775629835469382, 1.7808614053896494, 1.5871986086879457, 2.560137161186763, 1.779528654047421, 0.9182782684053693, 0.6019494767699922, 0.9801976829767227, 0.6521477145808083, 0.9813697572265352, 1.0673168024846484, 2.1512369768960133, 2.6436723130089894, 4.765186199120112, 3.4513302658285414, 4.105514236858912, 5.302563786506653, 4.61820661170142, 6.312248647212982, 4.342426964214869, 2.531307782445635, 1.6447667138917106, 4.464534606252398, 1.9222501899514879, 2.9520876492772783, 0.9037553391286305, 1.5572995330606187, 0.3437605510864939, 0.5590791457465717, 0.4691554510167667, 0.1449937189796141, 0.4921909549406597, 1.3486307987145014, 4.606667825153895, 7.417248027665274, 16.407552582877024, 26.498294591903687, 34.57693208966936, 30.291918958936417, 30.162081445966447, 17.9394097668784, 23.174184322357178, 27.97526274408613, 24.352828093937465, 36.96223129544939, 29.21827983856201, 9.848281145095825, 0.22082175793392317, 0.10518756389085736, 0.021648517277623926, 0.0006345063655836773, 0.035073122275727134, 0.01766633435285517, 0.024964546751497046, 0.036159490767334185, 0.029978240307952677, 0.03477484845955457, 0.07932966641549553, 0.030972511241478578, 0.04784963812146868, 0.047430082956062894, 0.06908268162182399, 0.04273941447692258, 0.036141760647296906, 0.04272341462118285, 0.007987620940964137, 0.03445585896926267, 0.022864774335175753, 0.07601764877992016, 0.08819345078830208, 0.01989247034569936, 0.0413740323856473, 0.046624444757721255, 0.06957197322377137, 0.07105695389743362, 0.040728555593107424, 0.07268363982439041, 0.03717766309689198, 0.004978030179959855, 0.04017359197938016, 0.04478581502501454, 0.045835691903318675, 0.03296954158161368, 0.03437302680686116, 0.03386559457119022, 0.07851224206387997, 0.019481909161965762, 0.010593032564169593, 0.006459411649432565, 0.0663089593872428, 0.007374653609336487, 0.04681551004094737, 0.15318544155785016, 0.12306641201887812, 0.1378921986158405, 0.16320132410952023, 0.12924141995608807, 0.11999287908630711, 0.15523282598171914, 0.1147570586098092, 0.18463752099445888, 0.08723415154963732, 0.12093832263989107, 0.1498306965721505, 0.16724563709327153, 0.14386326606784547, 0.0887122858049614, 0.07030798694384949, 0.20074533165565558, 0.13188472097473486, 0.11459754859762532, 0.1456227209419012, 0.09960404850010361, 0.1128922543887581, 0.16508309170603752, 0.09148433205804654, 0.21810601651668549, 0.2103925118488925, 0.12853446789085865, 0.18404659841741833, 0.09556122829339334, 0.11419546231627464, 0.12005149094121796, 0.16475991904735565, 0.20315746936414922, 0.18655092189354555, 0.129474903856005, 0.18039834632405213, 0.08103954073573862, 0.09129665605723858, 0.1236960653747831, 0.16517596957939013, 0.09991365045841251, 0.14950866385229997, 0.2811395584472588, 0.15731066305722508, 0.13207449364875043, 0.12318868402923856, 0.1304008870252541, 0.18756440893879958, 0.2389591618307999, 0.11575287660317761, 0.11487128319484846, 0.0857079363028918, 0.13951665216258594, 0.31286001205444336, 4.403804744992938, 23.633272647857666, 47.939367158072336, 54.11949798039028, 46.497275488717214, 39.86005047389439, 30.100437028067454, 31.06470455442156, 29.90870843614851, 25.84771043913705, 34.32755776814052, 29.096530028751918, 25.402766908918107, 15.580800328935895, 7.902128066335406, 2.140913039445877, 0.7581880273563522, 0.5325323045253754, 4.144200503826141, 5.807837222303663, 5.956573835441044, 6.201497401509966, 8.2920766047069, 9.968344279697963, 10.836268952914647, 10.433497514043536, 6.323704055377415, 1.3309934479849679, 10.919433678899493, 6.723787844181061, 4.440971527780805, 2.341439787830625, 2.09373368535723, 2.8993579873016904, 1.0200629723923547, 0.9422082986150468, 0.7753732023494584, 1.0391637874501092, 0.6990529405219215, 1.0789916217327118, 1.3603016010352542, 3.127775890486581, 4.388583413192204, 6.494295792920249, 6.820902815886906, 5.689545878342219, 9.150243401527405, 14.8904481615339, 14.992324386324201, 12.650534800120763, 18.909777811595372, 13.735463874680654, 13.769357187407357, 11.492170214653015, 9.638948423521859, 5.437592038086482, 4.753702998161316, 3.5370797216892242, 2.526746941464288, 3.246322363615036, 1.0539160072803497, 1.9487145755972182, 1.9495542219706943, 5.201769743646894, 11.772141797201973, 24.709114347185405, 25.04713899748666, 33.5054886000497, 31.1761189188276, 31.777554988861084, 27.38414474896022, 33.48640884671892, 31.79623522077288, 34.44981132234846, 46.37335784094674, 31.09605482646397, 7.97882228238242, 0.18827298948807375, 0.25505536954317776, 0.13175666784601553, 0.13240401739520685, 0.07842277722167117, 0.1577150970697403, 0.159139002806374, 0.12687227422637598, 0.11999886376517159, 0.0824425747351987, 0.18778239509889058, 0.1258412945483412, 0.06707930697926454, 0.13277411753577845, 0.12600973408137048, 0.22459262130515917, 0.10073760910225765, 0.08349447364785842, 0.08698833188308136, 0.16070033902568476, 0.11254717861967427, 0.16617585878287042, 0.21986541710793972, 0.13372125742690905, 0.10820875463208982, 0.0776109779253602, 0.14876412094703742, 0.19508744882685797, 0.09087031214897122, 0.1552641742995807, 0.13063827928687843, 0.15012226306966373, 0.1716310903429985, 0.16575588631842816, 0.11421845108270645, 0.06168189338807549, 0.1277735587209463, 0.1556885979537453, 0.22076296965990747, 0.16513122698026045, 0.10438079932438475, 0.10843690524676017, 0.1367204093507358, 0.19453092797526292, 0.12061246298253536], [0.03702579678169318, 0.0652093051799706, 0.07397758574890238, 0.06471508062843766, 0.02835647206354354, 0.004454548470675945, 0.03942593799105712, 0.04058758315763303, 0.05089541218642678, 0.0781727981354509, 0.10912601184099913, 0.025885308593777672, 0.07095948912735496, 0.041560582018324306, 0.027943700551986694, 0.02439065879609968, 0.054672562184610536, 0.04173736413940787, 0.038160548212804964, 0.0371093787252903, 0.05991056415119341, 0.016106528230011463, 0.06816331416900669, 0.049288179858454635, 0.015760192082130482, 0.02620777896871524, 0.029410822183958123, 0.057242645882070065, 0.03775365111817207, 0.06983762646892241, 0.0422463095081704, 0.05238730713192906, 0.02472213502707226, 0.045793096867523024, 0.036161631545318026, 0.06771069738481726, 0.03459641410570059, 0.01473389599206192, 0.04401067697576114, 0.02427568782253989, 0.041966362922851524, 0.021159266387777667, 0.04278702388650604, 0.03047813062689134, 0.033124881996107955, 0.027379212002935152, 0.11009588944060461, 0.04488211271486112, 0.03668178631258862, 0.05753884677376066, 0.01661525816390557, 0.04577862371557525, 0.08195205498486757, 0.020621478191709945, 0.018595357358987843, 0.9803448979343686, 6.307731015341623, 21.21247509547642, 38.229457650865825, 37.030525139399934, 34.171765259334016, 26.96816999571664, 23.037759917122976, 16.17509365081787, 21.424620968954905, 23.792732068470546, 21.03972029685974, 26.695385456085205, 24.359298603875295, 22.59940849031721, 13.93195719378335, 7.354389412062509, 1.7342502836670195, 0.45296601259282654, 0.3846155245389257, 0.4769131690263748, 1.519089000565665, 0.23391295117991312, 2.938027535166059, 5.241163424083164, 4.0062470606395175, 0.9945733972958156, 0.17496283299156598, 0.9227214242730821, 1.0647370666265488, 0.9779786020517349, 1.720960116812161, 2.9398761902536665, 3.8043497800827026, 1.0198108830622263, 0.058536985356892855, 0.5449583434632846, 0.2707464104252202, 0.24452868582946913, 1.1413538753986359, 2.3846827702862874, 2.327227681875229, 4.709434287888663, 1.7509071784360069, 2.7684908381530215, 4.742010482719966, 2.5486194363662174, 4.642578286784036, 4.224290217672076, 0.9559378304651805, 0.4574914883290018, 2.5769203177520206, 1.6964065943445479, 1.1100685255868095, 0.5454162731766701, 0.4245769759374005, 0.3076202560748373, 0.7968753799796104, 1.328400467123304, 5.474579470498221, 8.87491842678615, 15.899003505706787, 13.804593239511762, 41.516146659851074, 42.715909481048584, 17.864737476621354, 14.259352837290082, 15.854078190667288, 19.376255546297344, 19.263194458825247, 24.03938443320138, 27.859453644071305, 30.12098285130092, 13.994204367910113, 2.5706771441868375, 0.052228896346475394, 0.04646448012707489, 0.018773963042934026, 0.005381378960529608, 0.020607149228453636, 0.05551346724054643, 0.019870378941829716, 0.0713859483865755, 0.02892065527183669, 0.028342343268117735, 0.04010820155963302, 0.04535648672442351, 0.030872780164437633, 0.002310224717283355, 0.06425053519862038, 0.03830600915742772, 0.03144939922328506, 0.07704392621027571, 0.04941379365378192, 0.0211856325622648, 0.01568606891669333, 0.10698890473161425, 0.04602899295943124, 0.0192564031375306, 0.006513496827600258, 0.04570029363302248, 0.06570875445114714, 0.0799604325688311, 0.008481180528178811, 0.04036536293902567, 0.023799800679885914, 0.04275678836607507, 0.05326145361842854, 0.06694260252905743, 0.058019534551671574, 0.02460738966640617, 0.049508160911500454, 0.06457747372665576, 0.01469141969989453, 0.03546744950913957, 0.03190031288457768, 0.09261540922203235, 0.010138807651985968, 0.03288385278678366, 0.05537993833422661, 0.0785169918090105, 0.047973501296447854, 0.0333684930311782, 0.0763356713578105, 0.07870700197028262, 0.05183842997731907, 0.03731055078761918, 0.05544712347909808, 0.038997548299708536, 0.024138635623135736, 0.08926403655537538, 0.09847698147807803, 0.007433701422996819, 0.07020226440259389, 0.038618192941482575, 0.0167179069415267, 0.02508861348698182, 0.017732189569090093, 0.07279170331146036, 0.11344309590224709, 0.0229519779594349, 0.03521619816975934, 0.01835072003970189, 0.007051300290705902, 0.06531366386583873, 0.04594944829919508, 0.02374956364344273, 0.06069265039903777, 0.034013230220547745, 0.08196806162595749, 0.07358896838767187, 0.05897818239671843, 0.03148577209295971, 0.033620260057172606, 0.018643921806610057, 0.009288545598142912, 0.024452419053497057, 0.030216233073068515, 0.026109099620953202, 0.02166248152830771, 0.003226136094391612, 0.031308094305651527, 0.007658054786069053, 0.022772379918023944, 0.05320335405745676, 0.049250521164919646, 0.055239437480590174, 0.016343491318236505, 0.038426649291068316, 0.014594991392056857, 0.04185729520395398, 0.010370437454964434, 0.029011578964335576, 0.04759507892387254, 0.008396381462391998, 0.11033383131559406, 2.2126377735819136, 13.34277948311397, 31.194799150739396, 46.899548394339426, 40.39138616834368, 32.56103733607701, 23.939557926995413, 19.038204840251378, 13.541088887623378, 23.403526987348283, 28.147955008915492, 28.378266947610037, 38.40929440089634, 32.33565167018345, 25.84146227155413, 10.903601339885167, 5.12003721509661, 1.2388468725340707, 0.28888161586863653, 0.3171562243785177, 0.13604111437286648, 0.3071684603180204, 0.4195093778627259, 1.0641387615885054, 2.117841111762183, 1.5739780323846, 1.133331528731755, 0.1414003875106573, 1.2740324416330882, 1.269137978553772, 2.4078563153743744, 2.321106318916593, 2.6114504763058255, 2.2990336290427615, 1.7414816213505608, 0.856609368962901, 0.2992446097944464, 0.6012806583728109, 2.046453365257808, 1.3957073411771228, 2.8065009585448673, 2.8029925525188446, 3.6891742689268927, 2.7276156714984348, 3.2646343410015106, 2.420778444835118, 2.0174207517078946, 2.2743034703390936, 1.2398821541241236, 0.9992395469120571, 0.48636537896735327, 0.7844011379139764, 0.6703544918979917, 0.5689939537218639, 0.2844058360372271, 0.06896996338452611, 0.17802663573196956, 0.3424568681844643, 1.4901944824627467, 3.9092367461749484, 9.565126419067383, 18.123780216489518, 23.557175976889475, 37.43281194141933, 43.89910084860665, 26.19443075997489, 19.036186388560704, 20.76931377819606, 19.745871918542043, 22.8461685521262, 29.518435069492885, 29.623637744358607, 36.09498841421944, 21.918274845395768, 5.163706208978381, 0.007939651907820786, 0.01206826523412019, 0.029203567055187056, 0.04220322592716132, 0.023703565754528557, 0.08053915508623634, 0.029344858402120214, 0.024956614677129046, 0.04403977255736079, 0.023436781052233915, 0.013776293090943779, 0.02823594388818102, 0.07795995527080127, 0.056567076061453135, 0.0424942122772336, 0.00583238125545904, 0.04642077229384865, 0.06341844770525183, 0.044320903186287196, 0.07962165360472032, 0.04667871059583766, 0.05610959757385509, 0.02109081407875887, 0.016466262051835656, 0.013544009349841093, 0.0068634177608016345, 0.018193374554227506, 0.05668954823964408, 0.017537495819851756, 0.032556636059390645, 0.07433450195406165, 0.008466486004181206, 0.024664898901911717, 0.002972619932344449, 0.04420120282364743, 0.021091419671263014, 0.09199859374868018, 0.01582364528439939, 0.022182385237621408, 0.03164720914459654, 0.038709618749895265, 0.04403884635706033, 0.00827571249101311, 0.05538273050582834, 0.04568194604611822, 0.023481101263314486, 0.20889581287545816, 0.12009320727416448, 0.1920332812837192, 0.25320014623659, 0.15380706105913433, 0.1573049362216677, 0.14772916505379335, 0.0986584285274148, 0.10374061510499034, 0.18279599052454742, 0.28881338238716125, 0.06782330705651216, 0.2736314870417118, 0.17061936748879297, 0.07892133761197329, 0.14404903538525105, 0.1488131247460842, 0.12951682374945708, 0.21055286324449948, 0.1344397717288562, 0.09914302466703312, 0.10248759841280324, 0.15061665725495132, 0.12888521621269838, 0.1044470446982554, 0.0958551357367209, 0.1056637190548437, 0.17572481424680778, 0.23107504631791795, 0.1740480727915253, 0.11962789509977613, 0.23484900380883897, 0.1514669566282204, 0.09288414301616804, 0.10034593833344323, 0.16471223160624504, 0.12926617291356834, 0.11934677804155008, 0.1545109325753791, 0.11321733373084239, 0.1592975492988314, 0.06914417046521391, 0.17133647043790134, 0.09918712265789509, 0.16898610655750546, 0.10412163965936218, 0.17135447875729629, 0.11716227526111261, 0.09084084337311131, 0.1838560522134815, 0.09492892186556544, 0.08097005196447883, 0.1329226895634617, 0.11218024045228958, 0.14715846282030853, 1.6784815447671073, 10.949597546032496, 31.184769426073345, 53.02533735547747, 50.83098159517561, 46.38296719959804, 37.36199937547956, 32.72422620228359, 23.588481085641043, 31.36248697553362, 31.494495800563268, 27.47533985546657, 35.99806799207415, 33.90977300916399, 30.06971209389823, 18.124520199639456, 9.845810191971914, 2.553003749677113, 1.0083795764616557, 0.9795725622347423, 1.4727403904710497, 3.79967668226787, 2.4493581226893832, 7.742222223963056, 11.39062750339508, 9.615660667419434, 5.211130269936152, 1.6147331254822868, 4.347886511257716, 3.6783806766782488, 5.146349608898163, 6.425817387444632, 8.777991924967084, 8.790020993777684, 4.316341255392347, 1.342173533780234, 2.7733207046985626, 2.2051015836851935, 2.807283933673586, 4.803872900349753, 7.737942133631025, 9.452642900603157, 10.354189906801496, 9.648453559194293, 12.528113620621816, 11.258121013641357, 7.642790028027125, 12.433826565742493, 11.242094125066485, 7.010894358158112, 5.8455776657376965, 9.56495531967708, 5.413155657904489, 3.3446769373757497, 1.3510571313755853, 0.7681307366916111, 0.5232973886387688, 1.1217117522444044, 1.9524309933185577, 7.079965966088431, 11.295788935252599, 20.729821954454692, 19.35875998224531, 46.9210843358721, 50.560748781476704, 23.819055318832397, 19.789633410317556, 24.762862137385778, 28.969423157828196, 30.21738910675049, 35.7577680179051, 39.21269375937325, 42.6253570829119, 20.44173574447632, 3.344508009297507, 0.11546952037939004, 0.11251603386231832, 0.18562317453324795, 0.17197170135165962, 0.11706791818141937, 0.11969185381063394, 0.1366009329046522, 0.09836404610957418, 0.17820723461253302, 0.12666936511439936, 0.13415328067328247, 0.10238950939050742, 0.14279366417654923, 0.0735173150897026, 0.13537650289280073, 0.20650766816522392, 0.12905573206288473, 0.12254212158066885, 0.18766574135848454, 0.16517899584557327, 0.17298373633197375, 0.23194674668567522, 0.07682335483176367, 0.09839185925998858, 0.18808233471853392, 0.06814243564648287, 0.2749899412904467, 0.19314750363784178, 0.08955935535154172, 0.13774587932441915, 0.16434880825025694, 0.0660225497558713, 0.12364653231842176, 0.10837952832558326, 0.23094099493963377, 0.17010259521859034, 0.13882369148944104, 0.1760698493037905, 0.09747072761612278, 0.10336153116077185, 0.15222033405942575, 0.0823214358783194, 0.13031406168426785, 0.14395477330046041, 0.14144922846129962, 0.17468240803905896], [0.022065044480508993, 0.012058920958744628, 0.022127325513533184, 0.025514319572331648, 0.027658819320744703, 0.04359146447053977, 0.046533375180193355, 0.051684830005147626, 0.04630537045055202, 0.0981580021658114, 0.038550380151718855, 0.009389887347684374, 0.03850171562018139, 0.03538181838978614, 0.03756391915625759, 0.07160955281662089, 0.045790735565658124, 0.008070703313153769, 0.10793624139790024, 0.026885057001241615, 0.038703142133142264, 0.03805647451164467, 0.044528779174600325, 0.039310804169092856, 0.050511955084013085, 0.021938451898417304, 0.03439173741000039, 0.02978734126580613, 0.04112565803474613, 0.05092814132305128, 0.02421141698557351, 0.025874823531402007, 0.025317866721057465, 0.06967896462551185, 0.016658178896510174, 0.01932478420037244, 0.05333602800965309, 0.018941400040473257, 0.015289946958156568, 0.04434914042108825, 0.023888975448374237, 0.04225196170487574, 0.04193887207657099, 0.04381800017186573, 0.04469661820413811, 0.06934378868235008, 0.042435101699084044, 0.00933783607823508, 0.045062189123460224, 0.09645612098808799, 0.01973783560762448, 0.013856365312156933, 0.07056553169552769, 0.046208255126007965, 0.015427506362487162, 0.0981739680948002, 0.12406620622745582, 1.492122824702944, 11.279378158705574, 31.13290807179042, 39.69061517715454, 39.75269038336617, 34.24119513375418, 26.017239536557877, 24.766674961362565, 26.501148564474924, 23.974759238106863, 17.90594376836504, 21.96914781842913, 25.82787159511021, 33.42454208646502, 29.59075539452689, 29.293243953159877, 20.991409472056798, 10.017785923821585, 4.592272894723075, 1.4453074910811015, 0.4485539064875671, 0.5439973207456725, 1.6060028225183487, 1.4553648999759128, 1.7093875663621085, 0.2515091826873166, 0.3164298119289534, 1.116703295281955, 2.4382286284651076, 1.5102752106530326, 2.0218265610081807, 2.3486359502588, 1.680902123451233, 0.6561821209532874, 0.5241500086018017, 0.5483073209013257, 2.1751224952084676, 1.0813497751951218, 1.5105807142598289, 1.5703284910746982, 2.7181404999324252, 1.5861661498035704, 2.1766117981501987, 1.510265331183161, 1.3551716591630663, 0.14120498299598694, 0.8498901352286339, 0.23843327004994663, 0.04971750932080405, 0.5497434266975948, 0.08331804097230945, 0.32126391253301073, 1.851215498788016, 4.1273702297891885, 7.355011275836399, 14.344298039163862, 21.356346232550486, 27.374967915671213, 28.75630279949733, 24.097007581165858, 26.922350100108556, 58.19589492252895, 39.6452990259443, 21.089783804757253, 19.082715000425065, 19.462131806782313, 26.806938784463064, 28.390452350888932, 29.481251784733363, 18.036371878215245, 5.5524340357099256, 0.28722235347543446, 0.05386620813182422, 0.026932797028816173, 0.034166423071707995, 0.02624456404841372, 0.008397205034270883, 0.03881266447050231, 0.07784078416547605, 0.021772142965346575, 0.019180827907153537, 0.02173734938592783, 0.0498543392999896, 0.014155324448698332, 0.04310730259333338, 0.06874648109078407, 0.09364729135164193, 0.020619308575987816, 0.014461080809789044, 0.005483749114708709, 0.0645328668345298, 0.023300773796758482, 0.056009371166250536, 0.07174739720565931, 0.05634998217491167, 0.03725476163838591, 0.07563703134655952, 0.022970108415133188, 0.025309025409764478, 0.08070125710219145, 0.00800105169348951, 0.03189860636900578, 0.026430413093683974, 0.04024749801361135, 0.0234145997424743, 0.05629547545686364, 0.09370812880141394, 0.04066154347466571, 0.028377873058031713, 0.024452230760029385, 0.03247440100780555, 0.015831066761165857, 0.03763669542968273, 0.027423689973407557, 0.011471532700982476, 0.03754143929108977, 0.006131067281655435, 0.019925654100786363, 0.028768307196774652, 0.07782283691423279, 0.008663903223350644, 0.035257934858756404, 0.01912310323677957, 0.08577395776020628, 0.04956870998388954, 0.04179265795807753, 0.08179168323321001, 0.08183325707380261, 0.02508652359912438, 0.054621169942298105, 0.04303415651832308, 0.1042236438287156, 0.042243110215557475, 0.024123765528202057, 0.041841173211910894, 0.08597769468490567, 0.013714258026863848, 0.03391864583162325, 0.02850814669259957, 0.02156490649628852, 0.05421776730301125, 0.013882684837361532, 0.02308719981062625, 0.03024651948362589, 0.036365483820970566, 0.03529029419379575, 0.034432520757296255, 0.009636179444247057, 0.0403747877904347, 0.05592199281922408, 0.031089029274880886, 0.04656335285731724, 0.018276054046249816, 0.05606738591034498, 0.018091874197125435, 0.041278226633689234, 0.04506059795884149, 0.027762095743258084, 0.07827257670994316, 0.038172629528812, 0.036262163293680975, 0.0068777573261676085, 0.024131755278046643, 0.028120316431990693, 0.030392679319317852, 0.09610545409045049, 0.04692186022709523, 0.03146876461271729, 0.016323272671018327, 0.026538289983623793, 0.0144096953528268, 0.07681211829185486, 0.06022575045270579, 0.018637350194954445, 0.057305580005049706, 0.3067483114344733, 4.183096085275922, 19.43165874481201, 38.27269629069737, 46.441005502428325, 40.47995138168335, 35.495904309409006, 22.09991291591099, 23.266663108553203, 22.218873023986816, 20.041689736502512, 21.898778200149536, 31.43033266067505, 40.08927501950945, 44.90711075919015, 35.214606489454, 25.853178671428136, 17.596762827464513, 6.52912711245673, 3.5116482291902815, 0.5244978527937616, 0.012636262657386916, 0.10289279238453933, 0.462560416332313, 0.6535508707165718, 0.34868595536266056, 0.7109838660274233, 0.6455238557287625, 0.7906032193984304, 0.5163107578243528, 0.46014987996646334, 0.8220935410686901, 0.757313531424318, 0.6035057104059628, 0.9330411276647023, 0.43478626811078613, 0.5855268122894424, 0.75484556385449, 0.7041910790971347, 0.8242940029927662, 0.23444991665227072, 0.9116281909602029, 0.47184114690337864, 0.9775921085051128, 0.5411871001124382, 0.7216281262891633, 0.059190557072205205, 0.7342918696148055, 0.20501377832676682, 0.036522103273974996, 0.22765114504311765, 0.1035887725385172, 0.20970094895788602, 0.5067212666784013, 2.413220976080213, 5.471803230898721, 12.001423665455409, 19.87402101925441, 32.277224268232075, 35.28087493351528, 35.530468123299734, 27.83115189416068, 59.31029564993722, 47.652302333286826, 15.582667657307216, 14.184250627245222, 18.459941012518748, 27.429935114724294, 31.834061213902064, 33.55350065231323, 27.559756994247437, 11.65017225061144, 1.0237055655036653, 0.05155238336218255, 0.017718364418085133, 0.08517762725906712, 0.008886732427137238, 0.03712219964446766, 0.039910646088953526, 0.050826859793492725, 0.02486237294838897, 0.026443759877500788, 0.04591157925980432, 0.014815264215160693, 0.07231312577745744, 0.017965378306273903, 0.030010616606367484, 0.05968267137983015, 0.07326010282018355, 0.02935658348724246, 0.06519963605595486, 0.006088830597166504, 0.1076720877151404, 0.03083706208105598, 0.0720157442348344, 0.07174303422548942, 0.034235660785010884, 0.011382153523819787, 0.012026755854354372, 0.038138217625341246, 0.040798037579017024, 0.04375534085556865, 0.01991663806672607, 0.09231023809739522, 0.024540743956874524, 0.013288656266273131, 0.07369594621871199, 0.04764622350090316, 0.02712785549062703, 0.011178419991795505, 0.014454728025676948, 0.06737008637615613, 0.03601588561598744, 0.0336684055094208, 0.0495736531115004, 0.07546653585242373, 0.020837254023977687, 0.037755808859531365, 0.010721285860719425, 0.055054007430693934, 0.1368777344801596, 0.1035410308146051, 0.14840103685855865, 0.0739256167518241, 0.14479440610323632, 0.12687557190656662, 0.18096600872065338, 0.24891807458230428, 0.23469820618629456, 0.21295286874685967, 0.11937765138489859, 0.10808243176766805, 0.2075443882495165, 0.2297085039317608, 0.08569868108523743, 0.14845018993530953, 0.11160193184124571, 0.10799065990639584, 0.16132712896381105, 0.13074238012943948, 0.07381469663232565, 0.12274435215762683, 0.11030907835811377, 0.062110042199492455, 0.14718416572681495, 0.1742516468678202, 0.17018838918634824, 0.10979076581341879, 0.09850531710045678, 0.1556335687637329, 0.15726639543260845, 0.11430007884544985, 0.14253868428724153, 0.25900870455162867, 0.20132591335901193, 0.13938181368368013, 0.10985154219503913, 0.13624566553958825, 0.08315513149968215, 0.1523635863725628, 0.1413381387080465, 0.10735690819897822, 0.13336475512811116, 0.13978243432939053, 0.11692123248108796, 0.12286484640623842, 0.18127334437200002, 0.10942223308874027, 0.11862975651664392, 0.2032865131539958, 0.14984152599104814, 0.09834580708827291, 0.1659464460930654, 0.12127262327287879, 0.20813901562775883, 0.1785540474312646, 0.20710966443376883, 3.2476344874926975, 17.698013714381627, 41.89478874206543, 55.09557397024972, 54.34386920928955, 47.88669981275286, 37.29654387065342, 34.90237181527274, 36.8618471963065, 31.580663885389054, 24.849752834865026, 28.66325773511614, 33.89107193265642, 44.140644550323486, 37.85831962312971, 38.309900420052664, 25.362297126225062, 13.057150329862322, 7.093186216694968, 2.4618616231850217, 1.0995651291949409, 2.0154274872371127, 4.174494649682726, 3.120588413306645, 4.870378451687949, 3.4189701165471758, 3.2261308985097066, 3.4162125502313887, 8.205385667937142, 6.717893600463867, 4.639837222439902, 7.632632630211966, 6.664742052555084, 5.598378564630236, 1.472712706242289, 3.6377660674708228, 6.42129020180021, 4.705195886748178, 7.893017240933009, 6.243113202708108, 8.70201597894941, 7.177874769483294, 7.20898402588708, 6.742826342582703, 5.317710425172534, 2.6588384934834073, 2.509645253419876, 1.0986437329224177, 0.6330724667225565, 1.2386601396969386, 0.42410273424216677, 0.7032618118183953, 2.6269252002239227, 5.316576566014971, 10.188627362251282, 19.32203527859279, 28.33523849078587, 34.618197441101074, 39.16886452266148, 31.719683442796978, 32.99647399357387, 63.95123372759138, 45.43954426901681, 28.674875123160227, 26.91353283609663, 30.36873824255807, 36.890449455806184, 38.85275970186506, 41.79760776247297, 29.263655049460276, 9.515133261680603, 0.7159553564020565, 0.11488781230790274, 0.1754403452255896, 0.0720057561993599, 0.12391422795397894, 0.12259925422923905, 0.11603775274540697, 0.26200237391250475, 0.08998714453939881, 0.1305442750453949, 0.18674083027456487, 0.12143192972455706, 0.1319515566740717, 0.1152515070778983, 0.15085893496870995, 0.1647965870797634, 0.07772185054740735, 0.14771852562470095, 0.1154688825564725, 0.17173649397279533, 0.11168770545295306, 0.17084945871361665, 0.18283108435571194, 0.1869881155767611, 0.1442111509719065, 0.13296222101364816, 0.13086501854871, 0.14306821301579475, 0.11660867211009775, 0.15862315334379673, 0.12821552929069313, 0.12963811866939068, 0.09688561329884188, 0.09626898781529494, 0.2037621797727687, 0.2588713690638542, 0.1899096430944545, 0.10302857402712107, 0.11826629244855472, 0.23953350101198467, 0.15316891244479588, 0.10308454638080937, 0.14155693911015987, 0.1637903739299093, 0.057979894535882134, 0.1308963397251708, 0.15336984023451805, 0.19435668018247398], [0.02944600422467504, 0.03263852845079132, 0.0666744387043374, 0.08995599299669266, 0.051468923554888794, 0.01661182986572385, 0.04263435350731015, 0.07671508778418813, 0.012625422212295234, 0.022167381132021546, 0.03614350787496992, 0.07877291486199413, 0.03763629848669682, 0.06647709357951369, 0.045126955290990214, 0.04454671964049339, 0.054638564187501154, 0.12902143890304224, 0.05902224646082946, 0.0391374825766044, 0.010586201412869351, 0.034295154735445976, 0.017869725224695036, 0.0177339690271765, 0.037894545522119315, 0.05569893800254379, 0.039435325523040125, 0.0641751228166478, 0.017585156119561622, 0.03805919543706945, 0.04655713408387133, 0.010627545399724372, 0.09139450759227787, 0.03594745196668165, 0.044745676285986385, 0.015126401358949286, 0.029905419929751327, 0.04771007703883307, 0.0184394724201411, 0.04579647936459098, 0.018105419452435205, 0.04420533170923591, 0.011967731789419693, 0.04021031429458942, 0.04128276603296399, 0.06559448915400676, 0.057745691388845444, 0.0200702193791845, 0.038846913525568585, 0.022517944553068707, 0.04925946764914053, 0.020846845116466284, 0.03382229385897517, 0.09676493584577527, 0.05391858424991369, 0.06814996059983969, 0.016213750333658287, 0.053669816348701715, 0.47084017204386847, 4.071242681571415, 12.83396029472351, 26.849119561059133, 32.66415555136544, 38.676344939640586, 38.178975514003206, 32.047228472573416, 26.271778106689453, 28.0108323097229, 20.604803017207555, 20.598216124943324, 20.056520666394913, 28.750910997390747, 31.684007917131694, 28.31877473422459, 40.59006643295288, 33.941915375845774, 26.57044816017151, 15.678570168358938, 9.901269844600133, 6.476555304867881, 3.39627035175051, 0.630206931914602, 0.26975536931838306, 0.1591410655528307, 0.026870453231302754, 0.25627173855900764, 0.6544307949287551, 1.1384915432759692, 0.06607032540653433, 0.6307203929339136, 0.6509682578699929, 0.08978525322995015, 0.12550361481096062, 0.7862571211797851, 0.45931278488465715, 0.6351938928876604, 0.15742530833397592, 0.34634009695478846, 0.3527732603251934, 0.5116866230964661, 0.29900815391114777, 0.4280006193688938, 0.12104321058307375, 0.518890982227666, 0.9269400664738247, 1.9629916037831987, 4.870626415525164, 11.177021639687673, 15.258162464414324, 22.142451524734497, 28.334875447409495, 33.29275560379028, 30.6505571774074, 32.80808401107788, 22.939321313585552, 19.763888597488403, 15.102062497820173, 28.07726056235177, 42.09560210364205, 22.559498037610734, 25.413967405046733, 31.575501373835973, 34.12010192871094, 30.38028267451695, 23.052880934306554, 9.52110697541918, 1.0142726259572166, 0.00320649441398148, 0.08445945900997945, 0.037482885111655505, 0.01839673489199153, 0.03191570884415081, 0.03143553675285407, 0.03830640270773854, 0.029698880655424933, 0.016952208476141095, 0.02212612111387508, 0.019160945134769593, 0.05172459215724042, 0.06332843324967793, 0.04544531713638987, 0.03962302187989865, 0.08068119282169, 0.056483324484101365, 0.07215666917285748, 0.09023222460278443, 0.028614608837025504, 0.0430948412977159, 0.041629633134497065, 0.03102442595575537, 0.008613423610638295, 0.038716556770460944, 0.03523903087313686, 0.05803233850747347, 0.05313176182763917, 0.05549898391057338, 0.01791293772735766, 0.08320540415921382, 0.058266120962798595, 0.021104376297444105, 0.07675507385283709, 0.03585503549714174, 0.04268034461087414, 0.026008506804438572, 0.08502419692065034, 0.0264483230255012, 0.03884254715272358, 0.01160768753782447, 0.025584413936095576, 0.07712158454316002, 0.04663387639448047, 0.04697699459003551, 0.022058776513274227, 0.06066291020917041, 0.032358931311007054, 0.019255322570513402, 0.031729495086308034, 0.02892032278967755, 0.04918675244386707, 0.02054688344443483, 0.07307980928037848, 0.018147027219778726, 0.022271931504032443, 0.06804687077445642, 0.028777833828436475, 0.05580297438427806, 0.08381200089518513, 0.07917134383959429, 0.03201045608147979, 0.00706317592578541, 0.11397554911673069, 0.04035382105835846, 0.06463616700576884, 0.0162515226818089, 0.030869577479149615, 0.0054438919677133, 0.04944151180929371, 0.09460549136357647, 0.02743590360374323, 0.03299971942656806, 0.03377340880355664, 0.011343205613749368, 0.0392853794619441, 0.00512918021662959, 0.029486068324851136, 0.04625429372702326, 0.01581007119135133, 0.02076514101853328, 0.03382363735831209, 0.07501811919999973, 0.0312898349282997, 0.054980488161423376, 0.04469775475029435, 0.02074102418763297, 0.037569788484168906, 0.010144268162548542, 0.012352346642208951, 0.01172567714404847, 0.02710494475572237, 0.05344719918710845, 0.03631818314482059, 0.012731697759591043, 0.026459310203790665, 0.03680944589099713, 0.03870027532268848, 0.08014989311673812, 0.03357468285996999, 0.0612668063757675, 0.030263876409402916, 0.034352711468402825, 0.035959082056901286, 0.06685293412634305, 0.054008632632238526, 0.07407305562602622, 1.400522442800658, 9.022140332630702, 22.32345383507865, 38.210482120513916, 38.523192746298655, 42.52686636788504, 37.27921506336757, 33.63992234638759, 24.110476664134435, 18.549284424100602, 17.27223331587655, 19.104483706610544, 26.786806379045757, 35.57667711802891, 45.67368466513497, 44.06740706307547, 49.58601031984602, 36.16355671201433, 27.903777939932688, 17.10105923243931, 10.678963473864965, 3.921216309070587, 0.9628181755542755, 0.3835537800831454, 0.0341021115226405, 0.041212690328913074, 0.3723148245896612, 0.038283831240343194, 0.2863450619791235, 0.38241538831165856, 0.34865230002573555, 0.32568177261522835, 0.38801159230726107, 0.21643676608800888, 0.20416305826178618, 0.151218463533691, 0.5178997239896229, 0.21865545346268586, 0.3714743639741625, 0.15303775162569114, 0.11854529247752257, 0.25063978933862274, 0.0417359934986702, 0.0012404111018570671, 0.06455366393285138, 0.3010169161217553, 0.656572414296014, 1.748254269361496, 5.105239723409925, 10.887411168643407, 15.492773600987025, 24.004426309040614, 30.96232979638236, 37.62472813470023, 40.72875942502703, 41.88399818965367, 33.4088773727417, 28.26053145953587, 16.686479330062866, 22.99748989513942, 49.97896221705845, 27.053134305136545, 17.723537921905518, 28.23809920038496, 37.06366804667881, 34.90420266560146, 30.97450304031372, 16.276605095182145, 3.1627778751509528, 0.06774339598736592, 0.054425955417432954, 0.05559156322851777, 0.032736698897289376, 0.05146379383014781, 0.050296815378325324, 0.05768615672630923, 0.05719782864408834, 0.03540826089946287, 0.05666384194046259, 0.020712215287078704, 0.05546123022213578, 0.07817441983414547, 0.06538706099880592, 0.015466929247070636, 0.04309046135417052, 0.05502883717417717, 0.024574655440769026, 0.04853833759469645, 0.02173184646692659, 0.028303295274132063, 0.08748505344348294, 0.026285773176433783, 0.03642246040648647, 0.06310764473995992, 0.024043476175782934, 0.07427319631512676, 0.06623054788048778, 0.0083137333526143, 0.023981966976342455, 0.06648972111621074, 0.08226868656596967, 0.0022825733550624655, 0.026048358862421343, 0.05028076802513429, 0.019620523688250353, 0.04130337992683053, 0.06640314683318138, 0.039257454353251627, 0.05335282514403973, 0.09389421703027827, 0.039872369928551574, 0.09716045390814543, 0.08312733870531831, 0.06409450607108218, 0.009180503315292299, 0.09423897388790335, 0.029088619830352918, 0.04022682644426823, 0.10845760056482893, 0.08941165184868233, 0.14168158599308558, 0.24769806861877441, 0.1927362164216382, 0.14795165668640817, 0.19977100965167793, 0.13073368131050042, 0.1660430287676198, 0.14074636117688247, 0.17030975195978368, 0.08717304947120802, 0.14273011258670262, 0.1630510828856911, 0.2915140874683857, 0.11491802068693296, 0.12594091705977917, 0.16053388081490993, 0.12826377313051904, 0.1217768562159368, 0.13391077225761755, 0.12624423578381538, 0.11812437006405421, 0.2172017464680331, 0.13926980112280163, 0.1613625077796834, 0.19824494368263654, 0.12300307756023747, 0.1754739869918142, 0.13432495003300055, 0.11784887127578259, 0.10217308386095933, 0.10805566356118236, 0.09326682319598538, 0.10405500073518072, 0.1841795505689723, 0.19896733920489038, 0.10381402580865792, 0.13973522186279297, 0.12888528406620026, 0.08383910158382994, 0.0899819266051054, 0.10585068259388208, 0.13332610577344894, 0.18514042400888034, 0.09205153305083513, 0.1238469308508294, 0.06545727580253567, 0.09298910559820277, 0.13214392135185854, 0.21349581889808178, 0.16558771819940635, 0.15275083987840585, 0.1514332198670932, 0.1691466886550188, 0.17416921843375477, 0.09159052957381521, 0.14421184307762555, 0.9476622002465385, 6.4818263820239475, 21.98735557283674, 42.04949385779244, 45.7507540839059, 55.452617577144075, 50.72057124546596, 43.55376843043736, 36.48833635875157, 37.7953793661935, 30.763159683772496, 29.978398868015834, 27.001484870910645, 40.36463907786778, 42.61176988056728, 39.87058741705758, 50.96752411978585, 43.669153690338135, 34.194558824811665, 20.623523201261246, 14.074542914118085, 8.34739989893777, 4.675906624112811, 1.254749127796718, 0.4439147082822663, 0.3237217835017613, 0.9379797769444329, 1.1081498456852776, 2.2528094351291656, 3.1571035853454044, 1.3391472675970622, 2.2152159895215715, 1.9282490909099579, 1.3092409180743354, 1.4907563094581877, 2.280574219567435, 2.3774464385850087, 2.4135992186410085, 1.1113753297499247, 1.8849583395889826, 0.9210681872708457, 1.9055089397089822, 0.2992428184619972, 0.6556142142840794, 0.17505481519869395, 1.0587489136627741, 1.705369227698871, 2.6925502845219205, 7.868373717580523, 15.064530066081456, 20.379844665527344, 29.18761396408081, 35.471384116581504, 43.02488545009068, 40.00977373123169, 40.89132642745972, 30.388557979038783, 27.6893686907632, 21.897390297480992, 36.1216208594186, 50.11090850830078, 32.796612535204204, 33.054237842559814, 41.05415398733956, 45.876492159707205, 42.99014098303658, 32.90571314947945, 14.496145708220345, 2.1716968161719183, 0.10233205783047847, 0.1184137516788074, 0.09057694074830838, 0.22036639308290823, 0.13100025057792664, 0.1409725576106991, 0.1793026208345379, 0.15546522422560624, 0.09813650617642061, 0.09959244555128471, 0.14006284571119718, 0.08296203400407519, 0.1290909480303526, 0.133204688717212, 0.1774113673184599, 0.36950837661113056, 0.18357462302914687, 0.23615776215280804, 0.2523786574602127, 0.15298391665731156, 0.08822242423359837, 0.24290742139731133, 0.07657062767871789, 0.0968069846608809, 0.13426621604178632, 0.14040995708533696, 0.1674568107617753, 0.21737299513603958, 0.15319384182138102, 0.1392865473670619, 0.2304588279553822, 0.1892007775604725, 0.08384971387152161, 0.18920951709151268, 0.12398258357175759, 0.169466780764716, 0.1600687722010272, 0.12690747662314347, 0.2288257841553007, 0.11691752767988614, 0.13695587457290717, 0.1924374031701258, 0.20664908843381063, 0.18023623073739664, 0.12693852638559683, 0.07288914094013826, 0.2860886843076774, 0.124251161302839, 0.1514210740902594], [0.04463905468583107, 0.03156246690611754, 0.023085401692826833, 0.04557431682146021, 0.05556141591763922, 0.026640331472403238, 0.07709922681429557, 0.016774415337879742, 0.06802011613867112, 0.02395121068028467, 0.018405070694695626, 0.08489096656973873, 0.038645432729806216, 0.025197805038520267, 0.013139615201258233, 0.04546276566439441, 0.06181731540709734, 0.06540648067103964, 0.082137491820114, 0.027263718557411006, 0.05962551158985921, 0.06229239170040403, 0.06053265184164047, 0.09925761566098247, 0.051211260059582334, 0.06508947589567729, 0.06484867738825933, 0.028419222982068146, 0.010356468963436782, 0.0739426819075431, 0.03644976804831198, 0.006954599296607609, 0.035485607106238604, 0.02871201593162758, 0.02091313459511314, 0.04166859122259276, 0.060928841653679094, 0.06362455950251647, 0.0312164377953325, 0.0065830657508091205, 0.04237058658951095, 0.04392036396477904, 0.05755754041352442, 0.015988514026893035, 0.015900996580187763, 0.013862176964591657, 0.019298658905816928, 0.039212107857955356, 0.02235371363349259, 0.06413704343140125, 0.0984281405274357, 0.0221844734291413, 0.03173790892053928, 0.02530816536662834, 0.00621752833415355, 0.051908023921506743, 0.07130398814167295, 0.057616634028298516, 0.020963213872164488, 0.07115879521838256, 0.4874345873083387, 4.887022427150181, 12.979469469615392, 24.446142401014054, 34.9428277015686, 37.823404925210134, 38.06903069359915, 36.71541043690273, 35.1074617930821, 28.52777133669172, 27.516846656799316, 24.33430940764291, 18.375673260007584, 26.20023945399693, 16.036313806261333, 22.044897079467773, 26.879436288561138, 33.782700879233225, 29.68576853615897, 24.24183062144688, 32.09449706758772, 20.50686468396868, 15.304091794150215, 10.422477671078273, 6.579541504383087, 4.644591527325766, 2.576603089060102, 1.2276402967316764, 0.8320821193712098, 0.6675495909793037, 1.0087231865950992, 0.6188223085233143, 0.7000188486916679, 1.1753021223204476, 0.638806684740952, 0.9522191328661782, 1.4334330196891512, 1.7299733417374747, 3.1206563753741126, 5.1038409641810825, 7.6138759681156705, 10.068226371492658, 12.982277410370962, 15.839599881853376, 19.502837828227452, 25.523200035095215, 29.136190346309117, 25.538715362548828, 27.636861154011317, 26.48936789376395, 22.960369144167217, 19.597656420298986, 21.187016895839147, 20.355776105608257, 21.00507484163557, 19.676214490618023, 23.64967039653233, 24.184516668319702, 30.676130022321427, 37.85238586153303, 37.13375799996512, 34.018001624516074, 24.45738284928458, 11.886747990335737, 2.685458779335022, 0.3652715225304876, 0.0337815139043544, 0.053334664154265604, 0.04560784662940672, 0.06647911561386925, 0.042253505372043164, 0.048508916316287856, 0.04562677775642701, 0.0407561312562653, 0.04072154632636479, 0.01796113237339471, 0.008797098799342555, 0.08924863381045205, 0.01224300920564149, 0.04436319288132446, 0.02223605226858386, 0.04825711875621762, 0.015734762285969088, 0.01921553327701986, 0.05498040673722114, 0.03237941628322005, 0.016945365450478027, 0.09774959872343711, 0.04300531878003052, 0.010532594601889806, 0.046476127180669985, 0.019974030254940902, 0.03151231977556433, 0.04920178199453013, 0.012207869573363235, 0.04593408626637288, 0.0568334214123232, 0.01588799924190555, 0.020256870792114308, 0.10888981380100761, 0.01654940634034574, 0.03621524938249162, 0.06367894408426114, 0.04249859222077897, 0.04410356841981411, 0.030755349501435245, 0.03713396544169102, 0.01408891792276076, 0.004878133710008115, 0.03134918299370578, 0.08129370638302394, 0.005948216937083218, 0.05992655043623277, 0.032739650524620495, 0.020439735979640057, 0.015846640836181383, 0.03391723787145955, 0.033300395256706646, 0.04297471685068948, 0.05965352151542902, 0.03210684537355389, 0.06447479780763388, 0.12850002545331204, 0.060494063555129936, 0.07646327665341751, 0.054017697860087664, 0.03133234175454293, 0.056370178769741736, 0.005059805099985429, 0.0251728383425091, 0.019640905183873007, 0.03454442135989666, 0.022509861504659057, 0.02163070234070931, 0.004676655034667679, 0.06406587867864541, 0.07948402634688786, 0.07128581697387354, 0.07731818327946322, 0.042656616241272004, 0.015559791853385312, 0.053988351220531125, 0.0682844462405358, 0.0176003027175154, 0.05686642196295517, 0.03923835019980158, 0.015265663886176688, 0.03498632407614163, 0.06117979783032622, 0.028387509951634065, 0.0100476354460365, 0.024261352073933398, 0.010957958027055221, 0.059512196241744926, 0.022401205995785337, 0.04484985516007457, 0.025721556041389704, 0.05295507130878312, 0.044910468693290434, 0.07275416675422873, 0.023002667918003032, 0.031585598164903264, 0.1154993080667087, 0.041044661309570074, 0.07997419325900929, 0.03151961063433971, 0.09047587974263088, 0.017099776271996752, 0.015982836385124495, 0.029384447527783256, 0.02207682724110782, 0.06028426731271403, 0.017226131366831914, 0.0983075580692717, 0.03461620018684438, 0.18193258185471806, 1.3692474067211151, 9.563309465135847, 20.030735901423864, 34.14486183438982, 41.32237529754639, 42.44331080572945, 39.66085604258946, 36.37294067655291, 30.55902508326939, 23.171643018722534, 20.666704518454416, 25.90536137989589, 22.796759911945887, 23.882219655173166, 24.788865770612443, 35.25643811907087, 38.89562313897269, 43.80681140082223, 38.37777042388916, 38.54706328255789, 30.345218590327672, 19.376512629645212, 16.703221014567784, 8.121657269341604, 6.839176143918719, 2.6522040494850705, 2.149096714598792, 1.4059877438204629, 1.3295247725078037, 0.6886474160211427, 0.7903771315302167, 0.5060415917209217, 0.6961686781474522, 0.4183195802782263, 0.9109520443848201, 0.5626905262470245, 0.6094199844769069, 1.2909900631223405, 1.388097869498389, 4.292266615799495, 7.1690370951380045, 9.482038123267037, 16.167759827205114, 20.51627254486084, 26.53166331563677, 32.346827847617014, 33.01624161856515, 36.502243178231375, 37.2901063646589, 38.78129053115845, 34.331118719918386, 30.097299916403635, 27.50402201925005, 26.064016546521867, 20.001871347427368, 16.90157297679356, 17.04364800453186, 22.809096438544138, 36.847301142556326, 34.78084782191685, 37.128411361149375, 38.99347809382847, 32.99310411725725, 19.104747738157, 6.047220468521118, 0.7998266273311206, 0.042002600085522444, 0.055489090870001485, 0.03919002154309835, 0.07879846170544624, 0.01542670399482761, 0.008261847476075803, 0.019687447597139647, 0.08336089724408728, 0.04011129567931805, 0.01705535258432584, 0.06524272302963904, 0.028834756131150892, 0.049085705008889945, 0.05954988207668066, 0.051221570399190695, 0.03735495411923953, 0.06207097215311868, 0.015479828197775143, 0.05118148594296404, 0.01342407743712621, 0.041015497874468565, 0.04768545300300632, 0.018018025838370835, 0.11341930646449327, 0.07965661172888108, 0.04191329130636794, 0.03897735509755356, 0.00537226877973548, 0.016617918021178672, 0.02285233509194638, 0.07872348358588559, 0.07669920327940158, 0.013714088393109185, 0.10268182906189136, 0.08327220593179975, 0.04218343645334244, 0.022091410654996122, 0.036281471007636616, 0.03526788218212979, 0.03567998703303082, 0.036122225624110015, 0.04251523668478642, 0.029676346507455622, 0.013094653774585043, 0.032127917278558016, 0.04699959319883159, 0.029589816329202483, 0.0784287890419364, 0.02580273088200816, 0.031272060703486204, 0.11177059529083115, 0.13378172846777098, 0.16864362279219286, 0.15782587469688483, 0.09694543294608593, 0.09336755171950374, 0.2376830003091267, 0.20331684366932937, 0.19100329226681165, 0.15571432800165244, 0.13412775418588094, 0.17592445281999453, 0.12963543167071684, 0.1577115279755422, 0.12288802516247545, 0.1986123975366354, 0.21278851399464266, 0.13496388574796064, 0.13874894407178673, 0.2985404532934938, 0.11986623731042657, 0.17601586505770683, 0.21511188575199672, 0.22731277320001805, 0.1480491893099887, 0.16398492349045618, 0.13060860016516276, 0.12573228111224516, 0.11915262203131403, 0.2723376021853515, 0.08712416780846459, 0.20467574575117656, 0.16479381865688733, 0.0969525236370308, 0.11684130105589118, 0.1310576003577028, 0.131428596164499, 0.24736922340733664, 0.08981534625802721, 0.25233837962150574, 0.1826162873102086, 0.23185739719441958, 0.1879152251141412, 0.1287818889000586, 0.09745276000882898, 0.10270596455250468, 0.21424105390906334, 0.09322803134896926, 0.1756624975906951, 0.11745504955095903, 0.2857433371245861, 0.18728844874671527, 0.10486360413155385, 0.11387889858867441, 0.04849989858589002, 0.2058856144015278, 0.13402004353702068, 0.18123240156897477, 0.13387326284178666, 0.2094902502638953, 0.8346121864659446, 6.63792895419257, 19.054937839508057, 35.18671989440918, 49.1008106640407, 53.41565588542393, 51.542821066720144, 48.786988326481406, 45.482445921216694, 38.48274033410208, 37.23926986966814, 37.496030126299175, 27.955981492996216, 35.776885986328125, 24.730452265058243, 33.108544962746755, 38.365708351135254, 41.59535264968872, 39.73305130004883, 34.81026649475098, 42.26917505264282, 28.14951661654881, 22.052882296698435, 15.032528400421143, 9.251586352075849, 6.1145272340093335, 3.5996944989476884, 2.393909760883876, 1.2461358585527964, 1.309183052607945, 1.3811814806291034, 1.1416486310107368, 1.4198161789349146, 1.4473523242133004, 1.398030970777784, 1.651577576994896, 2.382721641233989, 2.7567266694137027, 4.15309202671051, 7.320534314428057, 10.951085329055786, 14.811636481966291, 19.479229586465017, 22.951769011361257, 27.03166958263942, 34.82202284676688, 36.21173552104405, 35.489164556775776, 36.34249019622803, 36.72817427771432, 31.71755381992885, 27.70720992769514, 29.295644555773052, 29.098015206200735, 29.45361532483782, 28.80823710986546, 31.72373424257551, 35.54183537619454, 41.52210126604353, 47.68111303874424, 48.18858514513288, 46.177248409816194, 36.1525924546378, 16.950549091611588, 4.3564401779856, 0.4637233167886734, 0.13120007914091858, 0.11234984028020076, 0.18004381177680834, 0.1442355510911771, 0.08519838364528758, 0.10520146028803927, 0.1815561441970723, 0.17707908871982778, 0.13301689736545086, 0.11488117623542037, 0.16310712987823145, 0.17579189421875135, 0.1161374431103468, 0.23598145161356243, 0.08363722384508167, 0.14105924724468163, 0.1784658514495407, 0.08023551745074135, 0.22892751012529644, 0.1374593068446432, 0.09915024427963154, 0.2598091316010271, 0.08026071145598378, 0.15717103412108763, 0.21704401421759809, 0.19048500007816724, 0.1264637690037489, 0.13430014279271874, 0.10736797510513238, 0.18290352475430283, 0.14778964966535568, 0.25690777014408794, 0.09294740962130682, 0.356217911200864, 0.22503080564950192, 0.13837694403316292, 0.15319529388632092, 0.11072415858507156, 0.0921766549082739, 0.12185997675572123, 0.10197778791189194, 0.1688953728548118, 0.1508669959647315, 0.07503625644104821, 0.17553109249898366, 0.16175851438726696, 0.13807074832064764, 0.15894699096679688, 0.08385003956833056, 0.17467237929148333], [0.045524624309369495, 0.11015711365533726, 0.10183168575167656, 0.09058333254818406, 0.03253412226747189, 0.02418258772896869, 0.03966081967311246, 0.052500249285783084, 0.021125753543206623, 0.05221181422738092, 0.0816621712542006, 0.032965806246336014, 0.07921825096543346, 0.013331020600162446, 0.028167774867532507, 0.056656221992203167, 0.04188024665095976, 0.0707540355090584, 0.008322526318287211, 0.04320053330489567, 0.013411953712680509, 0.018845392424347143, 0.05001786284680877, 0.051095240749418736, 0.05478284787386656, 0.027193661513073102, 0.042448126178767, 0.031177696838442768, 0.09526234718837909, 0.030584714907620634, 0.0461423727683723, 0.04805894581867116, 0.024350572643535476, 0.0588882357946464, 0.012150121154263616, 0.081936279045684, 0.012387381101559316, 0.018915335814069425, 0.017119428342474357, 0.04820163155506764, 0.037599993470524035, 0.055308210397405286, 0.032101294957101345, 0.04737738114116447, 0.05897574645600148, 0.046009712386876345, 0.059191344172826836, 0.03168670327535697, 0.02080689975991845, 0.026790993387943933, 0.03416313896221774, 0.02216515044814774, 0.051351703237742186, 0.0934311304507511, 0.10859897333596434, 0.01912508625537157, 0.038907825614192655, 0.017601088121799485, 0.03307680439736162, 0.009757942553343517, 0.005691413060828511, 0.04759120109624096, 0.47808985731431414, 1.3018015686954771, 6.552704521587916, 19.808770486286708, 29.7462317602975, 36.15143557957241, 39.300866399492534, 43.83577496664864, 43.331770011356895, 35.66620118277413, 36.23005444662911, 34.41666841506958, 30.357034002031597, 17.59806387765067, 18.50108998162406, 20.212068251201085, 34.555340562547954, 35.72787339346749, 47.36215598242623, 40.05029909951346, 22.89500744002206, 35.83699137823922, 26.085116488592966, 26.698281117847987, 21.294396093913488, 22.384356532778057, 18.01463965007237, 18.367481333868845, 13.55616387299129, 18.45098304748535, 16.730982542037964, 14.47808734008244, 18.054131473813737, 21.101376874106272, 20.677786895206996, 25.282590866088867, 30.573741367885045, 29.53408588681902, 22.48141939299447, 19.99767463547843, 19.99688080378941, 20.355756998062134, 19.9299453326634, 21.671153477260045, 25.96514889172145, 35.24005774089268, 24.25061140741621, 23.785950626645768, 23.280510868344987, 26.633987699236187, 32.83240270614624, 32.26207719530378, 32.81758219855172, 39.88802392142159, 34.50913156781878, 36.114610127040315, 32.91481181553432, 30.720504692622594, 22.90102631705148, 9.915577922548566, 1.8976466187408991, 0.036921455059200525, 0.05312235393960561, 0.1032067776790687, 0.08585566694715194, 0.0644525418590222, 0.018317753415820853, 0.05399258527904749, 0.07781398203223944, 0.05667212685304029, 0.03463710585076894, 0.013563557943728353, 0.019002198474481702, 0.041527228629482646, 0.028460499963590076, 0.020292907786954726, 0.026865672952096378, 0.028345632466620634, 0.024054887438459054, 0.028105705876701643, 0.012994607178760427, 0.023871691465111713, 0.04466621644262757, 0.05487360871796097, 0.06168040061103446, 0.0869457945227623, 0.02785165049135685, 0.005351242251760725, 0.02961127499916724, 0.06976310975317444, 0.02383360868719007, 0.03570904190252934, 0.05097533343359828, 0.029246820269950798, 0.03580482729843684, 0.04768522908645017, 0.03245106279583914, 0.054479817527213266, 0.002145585828527276, 0.0755816153915865, 0.024864220259977237, 0.050191021590892754, 0.05447672680020332, 0.004268013256868082, 0.04141482591096844, 0.037667192186095884, 0.04016959880079542, 0.026144994123439704, 0.024984237837738225, 0.03265126794576645, 0.03312995743804744, 0.03928124379100544, 0.03330592192443354, 0.017889831913635135, 0.017207846544416885, 0.049423808830657175, 0.03085205770496811, 0.032175414729863405, 0.03796086214216692, 0.12311964987644128, 0.01595389686657914, 0.023943997853036438, 0.03605956291513784, 0.014998575539461203, 0.048492319349731715, 0.1058964633515903, 0.030191045853176286, 0.021069818508944342, 0.08231081001992736, 0.024343193575207676, 0.04249429709411093, 0.040564031207135746, 0.061122285202145576, 0.09708702963377748, 0.04104000995201724, 0.05317699975733246, 0.06291024533233472, 0.04015943095354097, 0.09403259067663125, 0.05559762593890939, 0.05391678613211427, 0.04226853492270623, 0.031445986192141256, 0.02490107319317758, 0.027297791193372438, 0.021494349032374363, 0.038400888709085326, 0.027698973326810768, 0.047678036615252495, 0.032631186701889546, 0.07181501322026763, 0.024165603997451917, 0.029955214222094843, 0.035721923889858384, 0.108903072375272, 0.06050855027777808, 0.014438841824552842, 0.09357716475746461, 0.025561934070927755, 0.07002243226660149, 0.03756663329633219, 0.03844566523496594, 0.012513044938844229, 0.02702141709492675, 0.020050156795020615, 0.038503500167280436, 0.05151920299977064, 0.12375215307942458, 0.04297051332624895, 0.03254031050684197, 0.031778139261794944, 0.025865995790809393, 0.04696599214470812, 0.024099462100171616, 0.049335134481745105, 0.05343334350202765, 1.6413420119455882, 4.576916507312229, 13.815640006746564, 28.901879719325475, 38.07880680901663, 43.16403354917254, 45.90784590584891, 46.0226857321603, 42.53056975773403, 34.613010610852925, 30.69170788356236, 31.98303406579154, 21.078010082244873, 15.36972621509007, 18.029091903141566, 22.627996853419713, 31.363595213208878, 33.54302624293736, 50.77964135578701, 47.360523155757356, 37.839177336011616, 45.85656125204903, 37.23183877127511, 35.92220755985805, 28.668256964002335, 23.587617771966116, 18.40995740890503, 21.009594644818986, 20.822936500821793, 21.87117648124695, 23.130843196596416, 20.525715146745952, 21.482469933373586, 23.373243263789586, 30.69203097479684, 32.469394070761545, 32.17539841788155, 29.374454498291016, 37.271763120378765, 34.34969472885132, 34.66042511803763, 33.525933674403596, 28.768936361585343, 28.979112420763286, 33.518120425088064, 30.799929550715856, 23.479161603110178, 20.519180365971156, 19.721396889005387, 19.7377199445452, 26.952969074249268, 25.39688352176121, 28.45523909160069, 35.794225215911865, 35.373046261923655, 37.84265490940639, 39.00503989628383, 39.91546583175659, 32.00955881391253, 18.30459839957101, 5.138719184058053, 0.6753905245235988, 0.05336169020405837, 0.11535539078925337, 0.031116886530071497, 0.048638611499752314, 0.048054470880223174, 0.05767660295324666, 0.0772443450987339, 0.06120593499924455, 0.017146883565666418, 0.01378085878345051, 0.02533812608037676, 0.07790356901075159, 0.014018130605109036, 0.020117733793865358, 0.05610207262049828, 0.07980633048074585, 0.021538979673225964, 0.11077590366559369, 0.04257186043209263, 0.039655415141688924, 0.030689619814178774, 0.0824933834373951, 0.014039446782719876, 0.07123890984803438, 0.11225086237703051, 0.0546522502388273, 0.05251376909602966, 0.006199045888414341, 0.011393226367155356, 0.038150505894528966, 0.0062540610836419675, 0.08560413401573896, 0.05226288755823459, 0.007827719922975769, 0.01597095014793532, 0.05233472745333399, 0.07143956622374908, 0.025492477530081357, 0.061132999270090034, 0.06329629104584455, 0.015509693916620952, 0.01053215270595891, 0.015468330421884145, 0.056243526815835915, 0.044047830160707235, 0.06114224770239421, 0.03784079197794199, 0.0382051076074796, 0.010913686161594731, 0.01829470697391246, 0.02411652386321553, 0.007774936683875109, 0.1258941659969943, 0.21751907015485422, 0.10495156941137143, 0.14612160702901228, 0.10177360315408025, 0.2510331768010344, 0.12081330934805529, 0.11977322373007025, 0.11421889891581875, 0.10637392808816262, 0.16476052972887242, 0.32151760320578304, 0.19269787919308456, 0.09333992855889456, 0.16217878540711744, 0.19005936863166945, 0.12303351664117404, 0.22325992424573216, 0.11644815786608628, 0.18344059879226343, 0.12200290337204933, 0.1719614283314773, 0.2100173905491829, 0.17373760230839252, 0.13603530611310685, 0.19795240009469645, 0.12241208712969508, 0.09741536594395127, 0.1769280739660774, 0.11499286309948989, 0.16631050727197103, 0.12931316824895994, 0.08305858953722886, 0.13742339877145632, 0.12772644124925137, 0.13891405878322466, 0.15667180876646722, 0.09591087738850287, 0.103575921085264, 0.23619065753051213, 0.18011223524808884, 0.14752941791500362, 0.1589378850268466, 0.1522988405610834, 0.21099254036588327, 0.16752569563686848, 0.18150676041841507, 0.10956160418157067, 0.12254478143794195, 0.2213505402739559, 0.10276607596980673, 0.10791590570339135, 0.19112628352429184, 0.25546515041163986, 0.1559889039822987, 0.13140969217887946, 0.1692162249237299, 0.18815606433366025, 0.1120099960161107, 0.10153873504272529, 0.16293654617454323, 0.086274723389319, 0.9012828660862786, 3.231498599052429, 11.893440842628479, 27.88655682972499, 41.539582933698384, 50.04718310492379, 55.57709455490112, 58.65856851850237, 56.86851453781128, 47.29945196424212, 47.068966320582796, 45.20043591090611, 38.967172213963096, 27.426344633102417, 27.49324188913618, 28.03566517148699, 41.892905780247276, 43.02722699301583, 60.463898113795686, 51.38403041022164, 33.43135479518345, 47.422205788748606, 36.96340554101126, 38.074436392102925, 31.02922010421753, 32.4486780166626, 25.57389756611415, 26.727883917944773, 21.159237997872488, 25.881593329565867, 23.6011962890625, 21.706354788371495, 25.5103371824537, 29.842839513506206, 30.532184192112513, 34.294432231358115, 40.59938744136265, 41.34309482574463, 31.854537555149623, 28.906437737601145, 27.47433062962123, 27.78475877216884, 26.88589116505214, 29.13285173688616, 34.2639331136431, 43.68180635997227, 31.438194547380718, 32.650002070835654, 32.58461952209473, 35.556770529065815, 42.50180074146816, 41.69485780170986, 44.436495372227256, 50.67384808404105, 47.48489591053554, 48.48036432266235, 47.253222124917166, 44.31977258409773, 32.5418290410723, 16.036166157041276, 3.1847441707338606, 0.4119252291108881, 0.3342883922159672, 0.2599584093051297, 0.15231355120028767, 0.1347070059606007, 0.22221488532211098, 0.14510326167302473, 0.22174881318850176, 0.17299631637121948, 0.06583735719323158, 0.16748790123632976, 0.12608387081750802, 0.17405107191630773, 0.07073933844055448, 0.1942595411092043, 0.16079105915767805, 0.21732707188597747, 0.07447841923151698, 0.34203723498753136, 0.13113553688994475, 0.19236792118421622, 0.09151694923639297, 0.20275227539241314, 0.14652882303510392, 0.18303283995815686, 0.1695218099547284, 0.30254386418632095, 0.18263914036963666, 0.11668037969086852, 0.10056453517505101, 0.16935190478605883, 0.10821547891412463, 0.16125684630657944, 0.10379951872995921, 0.09832479285874537, 0.09475100998367582, 0.1163367966988257, 0.1592709778675011, 0.1375504205269473, 0.14984628930687904, 0.23214984578745707, 0.16132297632949694, 0.09986689261027745, 0.15822463615664414, 0.13681389790560516, 0.10550336087388651, 0.1326245412762676, 0.12568296518708977, 0.1158021789576326, 0.1068226025838937, 0.1451135618346078, 0.17313789948821068, 0.0848838012399418], [0.07081360409834556, 0.008212768190008189, 0.028828520394329513, 0.049939169748021026, 0.041845777072012424, 0.0063552840895551655, 0.06975794610168252, 0.028870986508471624, 0.029384349140205553, 0.03341328312775918, 0.05662526722465243, 0.005242831439578107, 0.038216635917446444, 0.06063911398606641, 0.018640001570539813, 0.048690248014671464, 0.06841455533036164, 0.04562065737055881, 0.038705652712711265, 0.09642277777727161, 0.058425882032939365, 0.0369235754811338, 0.04324519447982311, 0.015927057413916503, 0.04488395833011184, 0.06919790365334068, 0.011580636891137277, 0.10541327856481075, 0.0717829999380878, 0.015237424955038088, 0.03274523486782398, 0.019319084506215792, 0.054853144101798534, 0.008514879969879985, 0.014940038323402405, 0.02327485545538366, 0.028857049399188588, 0.04627875152177044, 0.04750195338523813, 0.014024599588343074, 0.05656469101086259, 0.034233604823904376, 0.009226116135583391, 0.042885129872177324, 0.03157000203749963, 0.0035143508409549084, 0.019019942165219357, 0.04074134597820895, 0.022242435586771796, 0.03424602880009583, 0.006463539262767881, 0.041491096639739614, 0.03910305370975818, 0.09677247436983244, 0.024589035294151733, 0.027240912995434234, 0.04343830554613045, 0.004314520895215017, 0.02077042341365346, 0.04043607307331903, 0.0370584207453898, 0.03628157278788941, 0.01600041383478258, 0.05702045280486345, 0.031081704489354576, 1.0180478862353732, 3.179328267063413, 6.636365175247192, 14.51213698727744, 21.24309754371643, 31.992872714996338, 36.464299065726145, 38.4854952948434, 43.692947796412874, 44.7276839528765, 45.99840872628348, 37.220923151288716, 29.77096039908273, 31.03406994683402, 54.219385283333914, 74.25575269971574, 41.055435929979595, 18.34293508529663, 23.989435570580618, 20.73815631866455, 18.970789943422588, 19.518504279000418, 27.697188888277324, 34.43244777406965, 25.40712516648429, 22.092408861432755, 22.62198145048959, 24.99692436626979, 23.86297835622515, 30.620794568743023, 26.133378676005773, 19.82600028174264, 21.86620330810547, 37.36108568736485, 87.38219220297677, 33.1985901423863, 19.730716160365514, 28.540033170155116, 22.549970320292882, 24.895781176430837, 35.95538173403059, 30.64835807255336, 38.369095597948345, 33.5648956980024, 39.75656747817993, 43.233268874032156, 45.43636199406215, 41.65091739382063, 40.22458076477051, 35.167747838156565, 34.234573500497, 28.245016132082256, 21.77925876208714, 10.99126763003213, 5.806474941117423, 1.7162150400025504, 0.1497457032757146, 0.04329098880823169, 0.025986568070948124, 0.03682461454133902, 0.06649472870464836, 0.07107617000916175, 0.08305126814437763, 0.030757296896938766, 0.09860002701835972, 0.07184165250509977, 0.009852081653662026, 0.020839846027748923, 0.10806604514696769, 0.026734673285058567, 0.026047067949548364, 0.02195843305837895, 0.030740299594721625, 0.017396711677845036, 0.03268008193533335, 0.029670270226363624, 0.028358536506337777, 0.046333560187901766, 0.03392964488427554, 0.03374691879642861, 0.010710970432098423, 0.05295624517436538, 0.016921102734548703, 0.024131802775497948, 0.06660250042166029, 0.06674881971308164, 0.011530265844027911, 0.06940525038433926, 0.06327161951256649, 0.03447997749650052, 0.06189339953873839, 0.10039992936487709, 0.030072617743696486, 0.1074910613575152, 0.019102672547368065, 0.10484759749046393, 0.027684089661176716, 0.05216993843870504, 0.053540959155985286, 0.07967128165598426, 0.06404483730771712, 0.033426368675593815, 0.023660706090075628, 0.014983488313321556, 0.045475871568279605, 0.036583330881382735, 0.02593096042983234, 0.07865672931075096, 0.066462077599551, 0.04025597630866936, 0.04281130186947329, 0.015152112747143422, 0.02260208798439375, 0.01949059101752937, 0.06381273083388805, 0.05991029952253614, 0.053439915113683255, 0.04017770390159317, 0.04972329722451312, 0.031061138092939342, 0.0733964272907802, 0.02677339218956019, 0.017948362344343747, 0.02796056045086256, 0.024305360158905387, 0.09204629476049117, 0.06033129657485655, 0.05362141305314643, 0.015854306585554565, 0.009150911554960268, 0.09548836720309087, 0.037469925092799325, 0.03297182485195143, 0.0585461998624461, 0.039126931357064416, 0.03370117535814643, 0.016026790187294995, 0.015092079361368502, 0.0793174799265606, 0.015858157271785394, 0.034484757775706906, 0.029038818752659217, 0.017790630093908737, 0.047825865647090335, 0.05198659149131604, 0.01790387589218361, 0.0628560846671462, 0.045165044854262044, 0.00273695751093328, 0.10599386026816708, 0.02785094820761255, 0.07158458272793464, 0.017644149650420462, 0.06984557889934097, 0.09768601999218975, 0.04198914812877774, 0.032317591564995904, 0.08674870045589549, 0.021925093240237663, 0.02356491221248039, 0.02065693843178451, 0.0637402632938964, 0.06440370769373008, 0.016918201997343982, 0.032142078304397206, 0.07586750255099364, 0.04504430972571884, 0.03534253460488149, 0.02748541291137891, 0.05637101336781468, 0.029985656695706502, 0.013673723193018563, 0.01502002912041332, 0.03266361728310585, 0.08295634788061891, 0.19648501383406775, 2.857763899224145, 7.530756405421665, 15.018658058983938, 23.87713531085423, 32.85532133919852, 41.98184619631086, 47.51756634031023, 48.38039364133562, 46.51853697640555, 46.684883798871724, 38.77822290148054, 32.59387799671718, 20.979733024324688, 28.015322583062307, 41.95159373964582, 73.72229085649762, 41.71620266778128, 18.87918836729867, 30.696429184504918, 25.4073839868818, 27.90013882092067, 27.561257805143082, 37.81055423191616, 37.592964444841655, 35.527647154671804, 26.481502532958984, 32.57375948769705, 31.204467569078716, 30.234787396022252, 36.24293293271746, 39.40013878686087, 28.139820405415126, 30.46994570323399, 47.49593659809658, 71.7966115134103, 26.773429359708512, 16.150246892656597, 17.40945676394871, 14.898923226765223, 15.07343418257577, 23.804563113621303, 23.49647651399885, 36.11005558286394, 30.937014034816197, 34.892706871032715, 41.1300630569458, 44.544637135096956, 45.144902433667866, 45.47288867405483, 41.760316780635286, 42.79203394481114, 36.16609280450003, 31.779750619615825, 19.539586850575038, 11.67444578238896, 4.161285689898899, 0.5446517542004585, 0.06693606823682785, 0.0599309541285038, 0.06378953850695065, 0.025141598590250527, 0.060681678487786224, 0.09522344677575997, 0.010286696903806711, 0.04155299938949091, 0.028571684711745808, 0.013319751829840243, 0.01707522348234696, 0.0065597330519397345, 0.014543817977287939, 0.014118900688897287, 0.05429429587508951, 0.06205568475914853, 0.07297570165246725, 0.036389330934200964, 0.033221315392958264, 0.02476394465858383, 0.03168413502031139, 0.014737407410783427, 0.020559346436389854, 0.022478835490931357, 0.05148827198094555, 0.05920094544334071, 0.013129384589514561, 0.044204181592379294, 0.0417783137277833, 0.019987558546875204, 0.04279714423630919, 0.018001091300642917, 0.02576844111484076, 0.051671113419745646, 0.09615297189780644, 0.07730818845863853, 0.057607894497258325, 0.007166324698898409, 0.029925280649747168, 0.02433166526524084, 0.05662958610004612, 0.04951247978689415, 0.028708528261631727, 0.02523191160123263, 0.026463045539068322, 0.02572013620686318, 0.02130005561879703, 0.06273837241211108, 0.032488389007214985, 0.03286337459992085, 0.05169303349352308, 0.019376225636473725, 0.033808265147464614, 0.04799936705135873, 0.14435548894107342, 0.08463063303913389, 0.19741010133709225, 0.16435667925647326, 0.1215508904840265, 0.10499993538750069, 0.1895566556070532, 0.196762901065605, 0.11037903531853642, 0.14869386543120655, 0.09172006869422537, 0.14751705500696385, 0.12356029051755156, 0.2176218003566776, 0.1563704985060862, 0.17254123650491238, 0.15686863820467675, 0.17308570657457623, 0.15325201941387995, 0.24702925022159303, 0.08440838567912579, 0.12871273261095795, 0.16571115728999886, 0.08162966264145714, 0.1305771975644997, 0.13774790135877474, 0.06301828167800393, 0.17428952269256115, 0.17062061599322728, 0.12868708398725304, 0.14035814415131295, 0.12603831397635595, 0.12615981245679514, 0.17446558895920003, 0.09766193878437791, 0.11065331952912466, 0.09338463723127331, 0.134040467441082, 0.16309522837400436, 0.13502046199781553, 0.1978840580476182, 0.16617535666695663, 0.14498013470854076, 0.13024871876197203, 0.10293788103652851, 0.13135220669209957, 0.21206584705838136, 0.08275816137237207, 0.06947106149579797, 0.07106874683605773, 0.09425839356013707, 0.1297250525759799, 0.17256046618734086, 0.21109114507479326, 0.12313491691436086, 0.09684739142124142, 0.1124696492084435, 0.23128997907042503, 0.10623414987432105, 0.13181025854178838, 0.09700399051819529, 0.14325552939304284, 0.07814199943095446, 0.15556682805929864, 0.1640072472925697, 1.6321037305252892, 5.337726448263441, 11.900693893432617, 21.474616731916154, 30.988274369921, 43.83037621634347, 51.15567438943045, 56.47371094567435, 58.483724049159456, 58.24604007175991, 56.41553715297154, 47.26648276192801, 41.16948366165161, 42.72469547816685, 62.426757267543245, 81.93640259334019, 48.7191287449428, 28.863240786961146, 32.51901463099888, 27.928230387823923, 27.82231899670192, 28.691283294132777, 40.55844170706612, 48.253936426980154, 36.392232349940706, 31.719478470938547, 33.75727047239031, 34.3536239351545, 32.893032687050955, 41.070649010794504, 38.79005568368094, 27.160803590502056, 29.2016111101423, 46.85673359462193, 98.39316231863839, 39.64992652620588, 24.973983151572092, 36.71688345500401, 30.38958283833095, 33.88975177492414, 47.002218450818745, 38.40634141649519, 51.49119595118931, 47.04276813779558, 52.64938422611782, 55.96006189073835, 57.952586378370015, 56.16889347348894, 56.38309948784964, 49.431979179382324, 46.680999755859375, 39.1932179587228, 31.445775032043457, 18.949608360018047, 9.821285656520299, 2.7939902927194322, 0.41590985815439907, 0.1568634949092354, 0.0834681261330843, 0.19494236446917057, 0.1455303451844624, 0.13763060979545116, 0.2545834348670074, 0.13447068578430585, 0.21583926172128745, 0.19777678166116985, 0.12662171838538988, 0.10759662105036633, 0.21309863163956574, 0.08706601057201624, 0.08485817297228745, 0.14577331500394003, 0.2115962194012744, 0.14882339776626655, 0.07223001202302319, 0.062798151347254, 0.10527692695281335, 0.1395345383456775, 0.11272726859897375, 0.07822140838418688, 0.11179217948977437, 0.2455240695604256, 0.14786701622818196, 0.09182219499988215, 0.13219923552657875, 0.15897304671151297, 0.10266823800546782, 0.29078786500862663, 0.13080618956259318, 0.09764575572418314, 0.127946815852608, 0.2215023556990283, 0.14284390290932997, 0.2170947143541915, 0.10996069133813892, 0.15326240099966526, 0.09847633008446012, 0.1452428770384618, 0.16364177476082528, 0.20944444915013655, 0.1493440783981766, 0.08619787929845707, 0.09228606189468078, 0.05705034227243491, 0.09804305154830217, 0.17953793677900518, 0.1606938929430076, 0.1074946711638144, 0.12114957773259707, 0.11742463761142322, 0.10855916368642024], [0.06912975838141781, 0.0554562497750989, 0.03128187571253095, 0.002559027393415038, 0.06329429615288973, 0.010938739370820778, 0.04707247464518462, 0.03228923897924168, 0.021154199427525913, 0.0012272733916428738, 0.05679954215884209, 0.03419913524495704, 0.035844718372183185, 0.06931575840072972, 0.1015438511967659, 0.03203692912523236, 0.031176699391965355, 0.08998413862926619, 0.07684949200068202, 0.06091571878641844, 0.03482596589518445, 0.06523299283747162, 0.05254420478429113, 0.022478134903524603, 0.04598406715584653, 0.02330846499119486, 0.036248711336936267, 0.08920475295079605, 0.008328701835125685, 0.056635187406625064, 0.043371252715587616, 0.029540720927928175, 0.022648878062942197, 0.032455975389374156, 0.005043857830709645, 0.06813985721341201, 0.018430512365219847, 0.03936858481860586, 0.04055048425548843, 0.020790999988093972, 0.030073238603238548, 0.045970805188907046, 0.02630993920112295, 0.03688458685896226, 0.04278677622122424, 0.04366769787988492, 0.07749420883400099, 0.03373786035392966, 0.05951801807220493, 0.0514678141501333, 0.09197023777025086, 0.05548827662797911, 0.0486337497963437, 0.032829746404396634, 0.032179845563535175, 0.05403409465881331, 0.021249694749712944, 0.03227599397567766, 0.058329407923987935, 0.022719250626063774, 0.058662534691393375, 0.06948347868663923, 0.07880161689328295, 0.020820119318419268, 0.03019055730796286, 0.06509335711598396, 0.0425693159257727, 0.0986855902842113, 0.2283091747335025, 0.9359060653618404, 2.73949578830174, 4.645440076078687, 4.814038983413151, 19.758453369140625, 32.14867564610073, 33.8190712247576, 52.62928308759417, 57.34347949709211, 53.32959202357701, 46.50788191386631, 51.37252766745431, 43.44483804702759, 26.04117955480303, 34.62737601143973, 27.60693178858076, 30.959317752293178, 26.219829899924143, 28.57001117297581, 26.375042234148296, 31.821509293147496, 34.956060545785085, 31.712471212659562, 33.263430731637136, 35.57727118900844, 34.428813866206575, 31.11007281712123, 36.41842358452933, 29.499998024531774, 33.39912905011858, 90.41628987448556, 52.153383595602854, 35.82049635478428, 45.83442429133824, 39.70376116888863, 43.2566043989999, 45.5301696232387, 43.28877803257534, 45.18654646192278, 41.053935119083945, 34.070481368473594, 26.83599441392081, 21.379075527191162, 15.51152331488473, 10.134895205497742, 8.818724870681763, 3.1279142030647824, 2.7813293720994676, 1.0154554482017244, 0.2296575866639614, 0.027023276280877844, 0.03509592444502881, 0.022295734512486627, 0.014809208290119256, 0.013146872133282679, 0.04163902405915516, 0.05465588040117707, 0.12857564139579022, 0.04333975512002196, 0.01773205555842391, 0.0663722124216812, 0.007668785817388977, 0.014443990209006836, 0.03301946140293564, 0.047168704481529336, 0.014316255991746272, 0.013263117904508752, 0.06701555182891232, 0.01862352334761194, 0.036428506153502634, 0.02667405635916761, 0.01165265659801662, 0.0732610799106104, 0.03634181651952011, 0.03873188826920731, 0.05746937835855143, 0.09776554429637534, 0.01721574129935886, 0.07163452969065734, 0.055956611675875526, 0.07270790423665728, 0.015526009291144354, 0.01250674219668976, 0.025281995967296616, 0.00930252087502075, 0.03417833814663546, 0.028065039576696496, 0.021988049415605407, 0.03344524212713752, 0.017368995218670795, 0.051663354371807406, 0.056243197726351876, 0.056340173951217105, 0.05472466688869255, 0.025352095420073186, 0.061318524314888885, 0.01337422801381243, 0.013398101420274802, 0.024606660241261125, 0.03396642826763647, 0.012856326830972518, 0.029055225729410137, 0.013003705485191728, 0.050520918531609435, 0.013687283715366252, 0.026627356186509132, 0.03730438290429967, 0.07104923895427159, 0.0669948293694428, 0.03379534923338464, 0.07488965895026922, 0.045362166062529595, 0.03705295853848968, 0.05070655892736145, 0.06209835782647133, 0.08224111768816199, 0.015092384702126895, 0.01030581971696977, 0.07537118132625308, 0.03629946575633117, 0.011578213672951927, 0.053475741762667894, 0.01727011570307825, 0.02430712434995387, 0.04316676261701754, 0.011699177807063928, 0.046082709184182544, 0.007298801875939327, 0.009560638988789703, 0.07415297348052263, 0.06459884079439299, 0.02450602501630783, 0.03156852622383407, 0.07817180747432367, 0.047491972135113816, 0.06913667265325785, 0.055862977235977135, 0.05695520487747022, 0.02172874047287873, 0.03477523861719029, 0.016764313647789613, 0.024669962469488382, 0.03284210931243641, 0.05160351097583771, 0.054773168571825535, 0.047611882843609364, 0.022330928427566375, 0.02297539420292846, 0.032246386100138934, 0.022552159681384052, 0.02438683694760714, 0.035908005333372524, 0.016259054420515895, 0.11045115680566855, 0.038115761508899074, 0.06001250725239515, 0.02047819025548441, 0.04435190884396434, 0.018840934449274625, 0.028273743377732377, 0.011668727699933308, 0.04032359571595277, 0.037601852656475136, 0.020900501969403455, 0.055421386645840745, 0.03196396625467709, 0.044802456096346886, 0.008896397310309112, 0.039563412578510385, 0.029073620813765695, 0.05665345356932708, 0.050024047693503756, 0.024704440530123453, 0.06736735188003097, 0.16686990511204514, 1.0655791014432907, 3.1367911781583513, 7.397737486021859, 10.530819194657461, 13.807847602026802, 31.434578010014125, 42.2319153376988, 45.936434268951416, 57.61636652265276, 55.447514125279014, 48.86758048193795, 49.67232084274292, 63.19948032924107, 40.93944617680141, 18.638546194349015, 26.901675735201152, 19.307021958487375, 23.089279072625295, 19.710184233529226, 24.82136423247201, 31.994658402034215, 26.104510647909983, 28.959756476538523, 24.916525023324148, 24.941790410450526, 25.985184022358485, 28.4761757510049, 23.855858189719065, 19.942208903176443, 18.83598099436079, 32.02985102789742, 102.45587825775146, 39.22232048852103, 23.37111016682216, 34.82710197993687, 29.997120789119176, 36.50321592603411, 46.13449961798531, 44.01205423900059, 47.2883174760001, 45.478117193494526, 43.92718546731131, 38.127815927777974, 33.227782998766216, 26.1861571925027, 19.868894985743932, 15.654067346027919, 9.023159112249102, 6.760549025876181, 2.9138599634170532, 0.7954977367605481, 0.2427406103483268, 0.038724753473486216, 0.06114625105900424, 0.036787488497793674, 0.02027106744104198, 0.05821986523057733, 0.042590903517391, 0.02973842228363667, 0.018632809099342142, 0.047115446267915626, 0.11718364911420004, 0.047715247475675175, 0.02011229024667825, 0.0603637034073472, 0.02659440822234111, 0.032036114883209975, 0.031243894714862108, 0.0745205223294241, 0.03225837242124336, 0.025085980771109462, 0.029120249740247215, 0.0419011116027832, 0.07375625441116945, 0.010860562806815972, 0.026113379480583326, 0.04683168292311685, 0.05690191612978067, 0.0682068829025541, 0.022874942182430198, 0.037322903517633677, 0.009012635448016226, 0.022247380410720195, 0.07087195132459913, 0.027173683745786548, 0.02421914041042328, 0.01400858276922788, 0.0726169737588082, 0.04062071941526873, 0.01030934470639165, 0.01979290890241308, 0.026608699866171395, 0.0751643299258181, 0.029592435474374464, 0.010308234453467386, 0.011856836266815662, 0.023030357235776525, 0.03975079341658524, 0.022021424856835177, 0.04140137395422373, 0.010010090407117136, 0.05970591798956905, 0.015123933187818952, 0.020006706805101464, 0.01697711071132549, 0.02692193368316761, 0.06807036844215222, 0.052173734842134376, 0.21686258752431187, 0.11932331430060522, 0.17307033097105368, 0.13983757208500588, 0.12822842145604746, 0.12909052733864101, 0.12331771424838475, 0.16463387438229152, 0.13797886110842228, 0.10568451615316526, 0.20516039617359638, 0.17100909086210386, 0.08265971951186657, 0.10911512813930001, 0.20682257626737865, 0.07387229068470852, 0.17963901135538304, 0.20456883577363832, 0.1889386051999671, 0.0947011173037546, 0.22463046998849936, 0.1233293850507055, 0.1413137928715774, 0.19668561592698097, 0.13605440008853162, 0.13719830156436988, 0.16658410616219044, 0.17092803306877613, 0.1367181430437735, 0.14639771649880068, 0.18730957832719597, 0.16879414900072984, 0.13518864368753775, 0.09780691457646233, 0.13056286690490587, 0.1459869449692113, 0.14863703133804457, 0.09497546258249454, 0.05435459728219679, 0.08280993359429495, 0.12146078103354999, 0.08370564053101198, 0.10917789262852498, 0.1028729248791933, 0.09824298867689711, 0.11346607109797852, 0.15516771376132965, 0.1065519078235541, 0.17506892872708185, 0.13694923850042479, 0.15981630289128848, 0.1837323417088815, 0.11997675709426403, 0.1372601025338684, 0.12666399111705168, 0.14608204843742506, 0.15230192111006804, 0.12184394975858075, 0.11926415961767946, 0.10565871146640607, 0.09798657029334988, 0.11365267501345702, 0.10499993538750069, 0.15089797787368298, 0.16231055690773896, 0.17470986156591348, 0.15440297765391214, 0.2658358524952616, 0.5584200982536588, 1.9840641873223441, 4.6819676245961865, 8.398284162793841, 12.840296183313642, 28.992359161376953, 44.08724069595337, 51.89697422300066, 70.09880529131208, 72.82602187565395, 67.31191757747105, 61.4246255329677, 61.842128889901296, 54.291771616254536, 37.50579234531948, 46.89389256068638, 38.72018807274954, 41.27998086384365, 37.76065574373518, 39.29481451851981, 41.40254708698818, 42.80510698046003, 49.232315744672505, 42.34137378420149, 43.71622078759329, 46.530856132507324, 44.7580441066197, 40.60662399019514, 46.89891958236694, 38.488840852464946, 40.85317734309605, 96.42568261282784, 60.14216872623989, 46.05802774429321, 57.46611172812325, 50.70462165560041, 55.17153862544468, 57.84691817419869, 57.81881618499756, 61.08815206800188, 54.84751285825457, 46.792897020067485, 38.05894538334438, 30.41445391518729, 22.2445170879364, 15.971362045833043, 12.472738214901515, 5.610968700477055, 4.416556426456996, 1.9971081273896354, 0.40115123295358246, 0.15595794921474798, 0.1453481721026557, 0.13106290650154861, 0.14537144585379533, 0.12350987536566597, 0.16747312274362358, 0.20531583497566835, 0.16521821516965116, 0.1137679513277752, 0.07983746166740145, 0.34908838091152056, 0.12533039839140006, 0.11719253792294435, 0.17101510268236908, 0.08758118828492505, 0.1096666142610567, 0.08266353287867137, 0.16313699898975237, 0.12448719649442605, 0.07395554693149668, 0.20498365137193883, 0.11155367443071944, 0.13418517181915895, 0.13145231774875096, 0.112741904599326, 0.09648147784173489, 0.1741478717220681, 0.12323648003595215, 0.12667107502264635, 0.13629678636789322, 0.1535383476210492, 0.14769512973725796, 0.1808182509349925, 0.13938394428363868, 0.11192862609667437, 0.1238406476165567, 0.17556161300412246, 0.08174114594502108, 0.11885230243206024, 0.07205513997801713, 0.12750088263835224, 0.136036731036646, 0.13850794200386318, 0.19424780245338166, 0.1437742422733988, 0.17367111944726535, 0.11289405929190771, 0.11817645441208567, 0.0998188251895564, 0.14225196252976144, 0.17351160943508148, 0.12882355095020362, 0.07917748458151307, 0.08285395016095468, 0.11380624784422771, 0.15971345055316175, 0.12430437201900141], [0.02882801488574062, 0.09127017283546073, 0.025266248865851333, 0.037118206465882916, 0.0283032783107566, 0.057979480629520755, 0.023186600101845603, 0.017982726750363196, 0.04922589034374271, 0.03686178808233567, 0.07067871133663825, 0.017224972768287574, 0.04577309704784836, 0.017109579406678677, 0.03648157776998622, 0.024311891058459878, 0.02675958230559315, 0.028876774412180697, 0.023030046806005493, 0.06767464003392629, 0.008399612137249537, 0.06330885072903973, 0.032929009292274714, 0.03089373671848859, 0.05946053937077522, 0.05872989964804479, 0.012939420229356204, 0.01181473910608994, 0.04189611079969576, 0.0196257212664932, 0.02818693669645914, 0.07266686643872942, 0.1361399090715817, 0.0069627595283756295, 0.03988426125475338, 0.032862696064902205, 0.03773645364812442, 0.06284908897110394, 0.015654703635456305, 0.03206189242856843, 0.04733693706137793, 0.08627416699060372, 0.029924266239894286, 0.03469683050311037, 0.04207495905991111, 0.028350986107917767, 0.03150628759924855, 0.030592053263847317, 0.07069251952426774, 0.023019018915614912, 0.02549847069063357, 0.064880575319486, 0.03068384887384517, 0.019556473375165036, 0.023215269902721047, 0.043409952960376225, 0.002815718887307282, 0.039804818374770026, 0.0287357510865799, 0.04593928045194064, 0.019461787205987742, 0.026167477381282618, 0.11524991930595466, 0.03578198102435895, 0.02959761948191694, 0.05469469599691885, 0.03509041813335248, 0.03986534369843347, 0.0074668079947254485, 0.014347237900697758, 0.07340549930397954, 0.05340713508693235, 0.06480369051652295, 0.3080506644078663, 1.4696241234030043, 5.079428902694157, 13.573531763894216, 21.169962542397634, 35.820600577763145, 43.50559656960623, 47.98406491960798, 48.112283502306255, 51.98336812428066, 50.7244587625776, 49.342753887176514, 51.00233112062727, 46.60651159286499, 43.95223024913243, 42.08770547594343, 50.521870136260986, 51.609878131321494, 47.395767893110005, 44.8155335017613, 48.86936616897583, 48.64678062711443, 53.57578754425049, 52.98893574305943, 50.138326099940706, 46.63892841339111, 45.925619397844585, 52.08103200367519, 45.799916063036235, 42.69747591018677, 42.13987602506365, 42.068799427577424, 27.605889558792114, 20.997614213398524, 14.7917229448046, 8.059169513838631, 4.009037630898612, 1.5730542476688112, 0.6681309597832816, 0.3521291948854923, 0.06779443539146866, 0.042214689776301384, 0.08748471417597362, 0.0038156407452853663, 0.01286529960842537, 0.009246031138380724, 0.07310032817934241, 0.06711859415684428, 0.05620110819914511, 0.03669373192159193, 0.060492584348789284, 0.03564865907121982, 0.01694415426546974, 0.04794389681358423, 0.07407728968454258, 0.021585912244128327, 0.05540356831625104, 0.025740334498030797, 0.014852252855364765, 0.027611566142046025, 0.05481374157326562, 0.023134408884548714, 0.03532447539536016, 0.04575954331085086, 0.023741684155538678, 0.05650095282388585, 0.050472593267581294, 0.04329046294359224, 0.03783288025962455, 0.028686072145189558, 0.03064533183351159, 0.06388593119169984, 0.077567198845957, 0.024941047387463704, 0.0319349419192544, 0.02681501692027918, 0.030721049556242566, 0.042246757341282706, 0.037502623695347986, 0.031699982205671925, 0.012651223506379341, 0.01031983146510486, 0.028782529290765524, 0.01765954730633114, 0.02645534586294421, 0.018076108435967138, 0.034075034582721334, 0.04662168990554554, 0.03593988630122372, 0.09754848772925989, 0.01205033324991486, 0.04681610036641359, 0.05594240315258503, 0.03929839376360178, 0.023037515780223266, 0.057258828942264826, 0.06184715737721749, 0.07400846587760107, 0.037412958685308695, 0.013655325564156686, 0.00378351762524939, 0.022653919578130757, 0.047423816685165675, 0.10690301576895372, 0.046289214531758, 0.05819862029914345, 0.020697424920009713, 0.04528651280062539, 0.027541800867766142, 0.022113298498360173, 0.0336377357265779, 0.04581802285143307, 0.02464080073072442, 0.05770675026412521, 0.02855044317298702, 0.015691727898748856, 0.04324498752664242, 0.04397546440096838, 0.015976926345112066, 0.03607662807085684, 0.03530992760456034, 0.035369044968060086, 0.02615446307962494, 0.028112815227359533, 0.049987545902175565, 0.03775446196751935, 0.02669977962172457, 0.011255315820952612, 0.013159625198958176, 0.02230844516972346, 0.04369981972766774, 0.055483123154512475, 0.01901542312199516, 0.05091358335422618, 0.05283659230917692, 0.022700624839801873, 0.047582644769655805, 0.06106319158737149, 0.019691489969513247, 0.09876693984759705, 0.018427872863997306, 0.10018515946077448, 0.09164310246706009, 0.0561598973747875, 0.024159290229103396, 0.022122394260285155, 0.04678565789280193, 0.07741610945335456, 0.027164447187845196, 0.046557246042149406, 0.04623505725924458, 0.023833920813298652, 0.05906745046377182, 0.009039738681167364, 0.04827674877430711, 0.011488729322861348, 0.03494253481871315, 0.024645343522674272, 0.03031295823997685, 0.014318082947283983, 0.013830496164570962, 0.04391549208334514, 0.03337122752730336, 0.03194592400853123, 0.0665767907298037, 0.015381581416087491, 0.028910877582217966, 0.0112059091417385, 0.10562901198863983, 0.010735456216415125, 0.027799472844760333, 0.09509715783808913, 0.07095885130443744, 0.036723112487899404, 0.106145512844835, 0.3124300108424255, 1.1725122034549713, 4.532769824777331, 9.264685443469457, 22.964432103293284, 35.08455358232771, 50.79111977985927, 53.93162563868931, 55.57640320914132, 55.14243956974575, 50.534484590802876, 49.40947049004691, 44.9828565461295, 50.62251826695034, 44.97597088132586, 45.57895987374442, 42.356875215257915, 47.12703589030674, 50.357722418648855, 46.41363307407924, 44.31240054539272, 48.87234347207205, 48.464181968144004, 50.29868010112217, 48.72997488294329, 44.992097650255474, 42.79822826385498, 56.71031795229231, 54.015552929469514, 49.209178243364605, 51.358266489846365, 50.17740624291556, 50.56516783578055, 38.821996552603586, 32.99016155515398, 25.75367178235735, 16.628936086382183, 10.09172865322658, 5.127664600099836, 2.544420335974012, 1.528668395110539, 0.27868624723383356, 0.1966485543442624, 0.0445105706873749, 0.06775243407381432, 0.03405457675190909, 0.031325841389064274, 0.0519348056986928, 0.08782161359808274, 0.03525089505793793, 0.015547846244382007, 0.050489003637007306, 0.013846775916005884, 0.03502516681328416, 0.05539999922205295, 0.04919147165492177, 0.049280732936624966, 0.036965939815023115, 0.016651919410963143, 0.07008986507675477, 0.021652432424681525, 0.08161717081176383, 0.031078060756304433, 0.029298032700483288, 0.053199767999883206, 0.06024603186441319, 0.048991870401161056, 0.020288931571745446, 0.02341839444956609, 0.04887093849746244, 0.022695920895785093, 0.019929016241803765, 0.07527200664792742, 0.05507244322715061, 0.03733016723500831, 0.027948499490906085, 0.03425686161166855, 0.04847100656479597, 0.03444490062871149, 0.0473009068518877, 0.03489885073421257, 0.05791707576385566, 0.07506669552198478, 0.043869863996016126, 0.05077222415379115, 0.04123304977214762, 0.0371456226733114, 0.017595162814749137, 0.022995353310502002, 0.06061746871897152, 0.08032705861010722, 0.023118354746007493, 0.06081025408846991, 0.02595886348613671, 0.024418599171830074, 0.0394724854933364, 0.020971186658633605, 0.06542571035346814, 0.12418679547097002, 0.037187830944146426, 0.06325443222054414, 0.026822261977940798, 0.03878479025193623, 0.11274791641959123, 0.12566878380520002, 0.21217477907027515, 0.1853798518755606, 0.10109723944749151, 0.18571005415703568, 0.1580329771552767, 0.09604345634579659, 0.15008277233157838, 0.2024897909057992, 0.08494872347052608, 0.19298685368682655, 0.08256965077349118, 0.13441758363374642, 0.09861403876649481, 0.10588513181677886, 0.10038941207208804, 0.0887033020013145, 0.19198560741330895, 0.1230631550507886, 0.14591940359345504, 0.08143936071012702, 0.18173189833760262, 0.12431338296404906, 0.08202313152807099, 0.10835785591708762, 0.14883076665656908, 0.07971430077616658, 0.08906209096312523, 0.14369667215006693, 0.0722151453207646, 0.11980520987084933, 0.12591806400035108, 0.2668984926172665, 0.10893350467085838, 0.13325928364481243, 0.10779115704021283, 0.14993538095482759, 0.21552724417831215, 0.15989281449999126, 0.1430844028613397, 0.12306600489786693, 0.1762890839683158, 0.08044225350022316, 0.12817498003797873, 0.09774122560130698, 0.12152570326413427, 0.2203060034662485, 0.1242732544030462, 0.1320784698639597, 0.15113018612776483, 0.08401290154350655, 0.15501470411462442, 0.0714407672307321, 0.16851326264441013, 0.09828691024865423, 0.10245798714458942, 0.12308470532298088, 0.097420923145754, 0.18674545788339206, 0.09023074539644377, 0.13961217632251127, 0.12048299850097724, 0.1743390421782221, 0.10503890365362167, 0.0722996907840882, 0.17794165600623402, 0.08142534896199193, 0.14140346805964196, 0.18705314637294837, 0.13527120782860688, 0.17947952848459992, 0.15990346749978407, 0.1679995030696903, 0.8214432331068175, 2.7337637415954044, 7.66997572353908, 19.163131713867188, 33.33812039239066, 52.074080330984934, 61.545531136649, 65.98334557669503, 64.40201895577567, 67.06309563773019, 65.94492898668561, 64.07208374568394, 67.40629495893205, 62.598287446158274, 62.22088214329311, 56.97205311911446, 65.93205397469657, 66.92925943647111, 62.8479014805385, 61.01501532963344, 65.10675389426095, 63.772324562072754, 68.42747170584542, 67.11113548278809, 62.77926022665841, 58.96574143001011, 59.94042083195278, 66.79727145603725, 63.52213382720947, 60.669307708740234, 59.17891216278076, 54.029181821005686, 39.08109835215977, 30.754842690059117, 21.137636048453196, 12.411611437797546, 6.848436789853232, 2.8405473487717763, 1.2690351669277464, 0.684457543705191, 0.14649211429059505, 0.1521878729441336, 0.13605678853179726, 0.2906993297593934, 0.09663074197513716, 0.1201202536800078, 0.10213019366243056, 0.2515444665082863, 0.14111445285379887, 0.14388515560754708, 0.2030064138982977, 0.15044087597302028, 0.13185154061232293, 0.24641976292644227, 0.1651719526520797, 0.2079210158969675, 0.13518257758447103, 0.16546651827437536, 0.10226977510111672, 0.0770873117393681, 0.1333524736442736, 0.09001697293881859, 0.08083528133907489, 0.21201008505054883, 0.11456993222236633, 0.08962817915848323, 0.09218022400247199, 0.2004752747182335, 0.17192271112331323, 0.12391717279595987, 0.10186644031533174, 0.17720461769827775, 0.18257238609450205, 0.13985381621335233, 0.09689062088727951, 0.08667617863310234, 0.2455331619296755, 0.1289413989122425, 0.10773567323173795, 0.09308098602507796, 0.19675184094480105, 0.17022802920213767, 0.1341080902410405, 0.11937575148684637, 0.05705814542514937, 0.15347676378275665, 0.0732085205880659, 0.25649779928582056, 0.15061312887285436, 0.2653607965580055, 0.15880363008805684, 0.14189419815582888, 0.15323580242693424, 0.19623992698533194, 0.11076768660651785, 0.17050043387072428, 0.1251474924917732, 0.3137355393597058, 0.12832944174962385, 0.17858699709177017, 0.1155775702957596, 0.07991849231932845, 0.20417738892138004], [0.03687807631545833, 0.03828224686107465, 0.07366182947797434, 0.03512266551011375, 0.037576122608567984, 0.033429361015026055, 0.12909890046077116, 0.0391478234502886, 0.0839151314326695, 0.021989476035482118, 0.04555922280997038, 0.040764982745583565, 0.04437110799231699, 0.02286978192361338, 0.035012739444417615, 0.11091535618262631, 0.07448711126510586, 0.05663645626710994, 0.054818124909486086, 0.034143671792532714, 0.08958539074020726, 0.05093381726848228, 0.02516322350129485, 0.09154426705624376, 0.05070575147068926, 0.05563996991674815, 0.015861090239403502, 0.06519570733819689, 0.06251864241702215, 0.021013713840927397, 0.04924599194367017, 0.02247890504077077, 0.04651574684040887, 0.048050613408642154, 0.026621625958276645, 0.019298429900248135, 0.02264211306880627, 0.02381657067287181, 0.06523216502474886, 0.03591471265203186, 0.03872642606230719, 0.06393437180668116, 0.010730715801141091, 0.09052325505763292, 0.034073226286896637, 0.04626803406115089, 0.016216491615133624, 0.03406935863729034, 0.027912783103861978, 0.04011385714901345, 0.044999478917036734, 0.02292208679552589, 0.017652195379404084, 0.05803572439721652, 0.030084224085190465, 0.063976318841534, 0.04555326866518174, 0.0734342352620193, 0.03793090482109359, 0.006921731060304279, 0.07422466070524283, 0.023559568749208535, 0.08046305059854474, 0.04382398485073021, 0.011969884441766356, 0.031179861365152255, 0.07303478848189116, 0.020718479861638377, 0.10006309101091963, 0.06210509567920651, 0.020002844244507805, 0.0843103780810322, 0.03344586637935468, 0.03476457543937223, 0.030850334226020744, 0.0536611412784883, 0.17897677474788257, 0.3548151621861117, 1.9031037773404802, 4.591647556849888, 6.876782834529877, 6.937688572066171, 20.94077273777553, 29.689920084817068, 29.549677644457134, 28.329186609813146, 33.04444088254656, 38.467016560690745, 40.181213583265034, 42.13856976372855, 42.10645866394043, 35.81724112374442, 36.22285263878958, 32.427159445626394, 32.53402621405465, 34.19218601499285, 36.25484561920166, 38.49105732781546, 34.68380928039551, 43.94932590212141, 30.76583821432931, 24.466658694403513, 16.332093409129552, 8.214760524885994, 4.254915705748966, 0.8913599699735641, 0.7005494630762509, 0.07815470160650355, 0.06525968640510525, 0.08739901520311832, 0.0618317953443953, 0.02840303992187338, 0.020267272733950188, 0.037418624452714405, 0.05741418632013457, 0.03927525571946587, 0.04550693829410842, 0.041260547403778346, 0.04518372153065034, 0.0092513135335009, 0.028586001800639287, 0.03276907858837928, 0.01741409574502281, 0.05377746932208538, 0.05901777491505657, 0.09885836565600974, 0.0262701024101781, 0.00842618102407349, 0.032746724252189906, 0.048912213782646825, 0.054065778851509094, 0.03583752250831042, 0.027809384545045238, 0.013117740080425782, 0.007382785851534988, 0.04217444247167025, 0.027037995401769876, 0.03303522037874375, 0.02035935502499342, 0.021545425755903125, 0.037323124041514735, 0.058478841691144874, 0.03322926103802664, 0.06051478601459946, 0.06711573752441577, 0.04447965323925018, 0.007269154984637031, 0.0347261873206922, 0.038182271511426995, 0.09104870579072408, 0.029578121778156077, 0.04353555997035333, 0.053561104860688956, 0.047042239124753644, 0.05708591786346265, 0.039815440840486965, 0.05765201284417084, 0.03279558555888278, 0.03324177661644561, 0.05643979985533016, 0.02233211586384901, 0.06407116446644068, 0.03681295391704355, 0.05582333043483751, 0.08437000773847103, 0.04301540520308273, 0.010854622232727706, 0.025391906765954833, 0.015075065095775893, 0.06926154345273972, 0.12582380191556045, 0.04916133112939341, 0.024735079778890525, 0.033209237469626326, 0.07227567064442805, 0.02907235873863101, 0.023497101119054214, 0.023970467504113913, 0.05333182787788766, 0.010063744715547987, 0.10481401679239102, 0.057641210566673956, 0.032411181900118075, 0.016016754654369185, 0.026017270084204416, 0.03260311570816806, 0.05625298559399588, 0.023068387427234223, 0.06936102347182375, 0.04467280162498355, 0.018907005100377967, 0.09011890246931996, 0.04736068578703063, 0.0806953606328794, 0.03277632534237845, 0.037635613166327984, 0.05838259828409978, 0.018168317952326367, 0.022760871964107667, 0.06443846904273544, 0.02829534962906369, 0.012624250043050518, 0.041247095447033644, 0.02090420337793018, 0.05178774341142603, 0.036814707930066755, 0.03977011809391635, 0.01616085513627955, 0.035046018194407225, 0.08402855534638677, 0.015375289700127073, 0.029492792606885945, 0.049846878807459555, 0.05664685481627073, 0.018619019571425657, 0.057960739492305687, 0.03553872961284859, 0.047585321590304375, 0.04027728909360511, 0.030411719011941125, 0.026687046912099634, 0.020649189561871544, 0.01318040448573551, 0.03262954803981951, 0.043953561290566406, 0.00744891502628369, 0.0742880833734359, 0.04225432639941573, 0.03406109068808811, 0.033090307244232724, 0.028084583081571118, 0.07216074038296938, 0.04607826817248549, 0.09608740505895444, 0.05551673438666122, 0.02125343687034079, 0.012565655999683907, 0.025576658280832425, 0.009350370316367065, 0.05622737428971699, 0.039402379255209646, 0.020902842915217792, 0.13021651548998697, 0.05233388946258596, 0.0673993651622108, 0.0358334139787725, 0.020414947399071286, 0.08016327382730586, 0.03119788325524756, 0.03839689213782549, 0.11112260791872229, 0.16193022445908614, 0.43375247929777416, 1.45125504050936, 5.317442919526782, 11.81212260041918, 17.36406765665327, 20.50213643482753, 35.07758453914097, 42.27382339750017, 42.71245275224958, 40.826718602861675, 45.44525221415928, 49.34665877478463, 51.19985451017107, 53.328518526894705, 53.040512221200125, 47.86258608954293, 47.652712277003694, 45.35759374073574, 44.906923157828196, 46.787658078329905, 48.41709402629307, 51.95964697429112, 48.65268659591675, 51.81150095803397, 45.415500027792795, 35.9105658531189, 26.130861691066197, 17.10526462963649, 9.733742696898323, 3.1540033859866003, 1.8698727147919791, 0.5619344753878457, 0.11110005341470242, 0.05004133676577892, 0.04499098365860326, 0.08519232432757105, 0.04057189542800188, 0.01278572526228215, 0.037612512441618104, 0.049221167740012915, 0.028587223163672855, 0.033057364369077344, 0.045242849072175365, 0.0386325371717768, 0.0674955067890031, 0.047343695270163674, 0.038371647242456675, 0.05769756289997271, 0.05789181390511138, 0.049808643359158716, 0.030627788310604434, 0.06202427537313529, 0.026351231449682797, 0.010110315966552921, 0.02001205026837332, 0.016466966031917503, 0.03264210093766451, 0.039077147242746184, 0.013427751704252191, 0.0263154607798372, 0.030897027613329034, 0.02993901419852461, 0.022979943780228496, 0.05381900245057685, 0.07514502560453755, 0.021506767919553176, 0.02677734804871891, 0.08488669858447143, 0.08202569639044148, 0.08462322343673025, 0.00970666905465935, 0.04612536189545478, 0.022877064300701022, 0.02146831194737128, 0.045863393095455, 0.03949725541419216, 0.06752977280744485, 0.08704347642404692, 0.11943143207047667, 0.06492132813270603, 0.021966253174468875, 0.04895502594964845, 0.04093190236017108, 0.09673465961324317, 0.01339387329893985, 0.033604898024350405, 0.0351051694846579, 0.030442263265805583, 0.01815353097793247, 0.06177252531051636, 0.051250815258494446, 0.044824905427438874, 0.025988428953236768, 0.0034271578188054264, 0.05950866107429777, 0.04261633500988994, 0.058505786316735406, 0.015784408996946046, 0.055783917728279314, 0.038145993636654954, 0.09052391323660101, 0.10980673852775778, 0.15350798996431486, 0.09297082586480038, 0.20597799015896662, 0.109100973898811, 0.2294836374265807, 0.14465388150087424, 0.1655227281153202, 0.12141037945236478, 0.11621714383363724, 0.1356523409485817, 0.14474925638309546, 0.16510948671826295, 0.06793449180466787, 0.2362467045230525, 0.14130623399146966, 0.18571183191878454, 0.1413305662572384, 0.1472394663308348, 0.17958660131054266, 0.11747038444238049, 0.08882879705301353, 0.2587252397622381, 0.10720296895929746, 0.14109747590763227, 0.08984353260270186, 0.09185758738645486, 0.1563703492283821, 0.2014820442668029, 0.17455143720975944, 0.1473255724247013, 0.10262530030948774, 0.19057486525603703, 0.10972730921847479, 0.18201252685061522, 0.15658495628408023, 0.16883479324834688, 0.1617952095610755, 0.16716912548456872, 0.16795381052153452, 0.13185167631932668, 0.09934866148978472, 0.20774095984441893, 0.1465454064309597, 0.1782564419720854, 0.1256136731909854, 0.07171861375016825, 0.08573924390865223, 0.11983757599123887, 0.22901989945343562, 0.14835732563265733, 0.10325082138712917, 0.12785412796906062, 0.13733039876180037, 0.15474752416568144, 0.14053495680647238, 0.1839644821094615, 0.15953400518212998, 0.13463202784104006, 0.18331547693482467, 0.10762039691741977, 0.18638639072222368, 0.21313296551150934, 0.11330687999725342, 0.12670124268957547, 0.23444389126130513, 0.13778769065226826, 0.2034511257495199, 0.12485531531274319, 0.10627317242324352, 0.17873961318816456, 0.1583537749413933, 0.13758164670850548, 0.136995311028191, 0.27983609267643517, 0.3123610445431301, 0.7600009100777763, 3.763900407723018, 9.457154018538338, 14.540292825017657, 19.46463315827506, 32.22427552086966, 40.116650921957834, 42.712035860334126, 42.65783643722534, 47.857909951891216, 53.30837917327881, 56.04844297681536, 55.85666922160557, 56.997070108141216, 49.554715633392334, 49.53205755778721, 45.54900966371809, 47.93143578938076, 49.091844013759065, 50.487858704158235, 54.19639022009713, 52.80211952754429, 58.296991212027415, 46.81044122150966, 35.40931585856846, 24.239586353302002, 13.654068333762032, 6.225454355989184, 1.6383933701685496, 1.1112908657108034, 0.3533710768180234, 0.10531578665333134, 0.14603818793381962, 0.18260716779955796, 0.13216153612094267, 0.1437209772744349, 0.04649477671565754, 0.20455470867455006, 0.20643737193729195, 0.13153471904141562, 0.1811009557651622, 0.16894265317491122, 0.12497016414999962, 0.18552652400519165, 0.1408753642546279, 0.15932629204222135, 0.1351411190948316, 0.18397385946341924, 0.22274378979844706, 0.09636902423309428, 0.12056242781026022, 0.12659517409546034, 0.1303146316536835, 0.13117500048662933, 0.13820964443896497, 0.16476882142680033, 0.1076682743483356, 0.13251702061721257, 0.08443239224808556, 0.11814024778349058, 0.09971268195658922, 0.1140434704720974, 0.13073748110660485, 0.16258981478001389, 0.14347394981554576, 0.18188053821878775, 0.16081517429224082, 0.13174791474427494, 0.11193404759147338, 0.16738994792103767, 0.14051697562847817, 0.06468760674553257, 0.1597064480717693, 0.1243677336190428, 0.19162108483059065, 0.15017608446734293, 0.2104471746299948, 0.24168934247323445, 0.17844777527664388, 0.1284557849700962, 0.14243911605860504, 0.1676148008555174, 0.15198820722954615, 0.21791411324271134, 0.11609989298241478, 0.15580298538718904, 0.11322407158357756, 0.18790079945964472, 0.16031237984342234, 0.11263278259762696, 0.12937051802873611, 0.10981605481356382, 0.1361941783023732, 0.19638506562582084, 0.10876988952181169, 0.12682428822985717, 0.16605813295713492, 0.2384673325078828, 0.13805088081530162], [0.07104545272886753, 0.03049132813300405, 0.019301050741757666, 0.016762210189231803, 0.032198797046606026, 0.052890657979462824, 0.07768685849649565, 0.027084855030157735, 0.05475127224677375, 0.022864285789962326, 0.015535803944138544, 0.06772618155394282, 0.008921285126624363, 0.03974465946001666, 0.039653905401272435, 0.029108945346836532, 0.046009973622858524, 0.034823794583124776, 0.0797469722373145, 0.027817811949976852, 0.08974078883017812, 0.013021429668047597, 0.01501349822085883, 0.09789228785250868, 0.011336331205841686, 0.03745660884305835, 0.01044037236299898, 0.03803957220433014, 0.05480748208771859, 0.048185350107295175, 0.004737886458834899, 0.005439031960642231, 0.009713635912963321, 0.03683639730193785, 0.049032090564391444, 0.06003517710736819, 0.03877027638788734, 0.01313530226304595, 0.06165946102035897, 0.06919772723423583, 0.05996916243540389, 0.06774291422750268, 0.025893439139638628, 0.025357467721083334, 0.05542546124862773, 0.04698153738198536, 0.010067055966438991, 0.009654707691100026, 0.030890815625233308, 0.023745024244167974, 0.07190144501094307, 0.05797086323478392, 0.054807180139635286, 0.0818381289552365, 0.04005161173907774, 0.015004097118175455, 0.028103592240118554, 0.012974704898494695, 0.049756284204444716, 0.0046336702653206885, 0.03262954803981951, 0.03323698955188904, 0.033029062673449516, 0.05176009989476629, 0.031254384866250415, 0.00952129837657724, 0.07467085176280566, 0.0411130746028253, 0.0156618859286287, 0.0505290677371834, 0.0582578360502209, 0.027462278259918094, 0.028481677041522095, 0.11968774188842092, 0.06784691328981093, 0.03858157919187631, 0.04732546642688768, 0.05276115617847868, 0.1417903687272753, 0.05395812248545034, 0.09289433461214815, 0.37902382601584705, 0.1381764912179538, 0.4553721791931561, 0.398422327956983, 2.2520444818905423, 2.5807672313281467, 3.3423924999577657, 3.6435927833829607, 4.024674986089979, 3.2799572902066365, 3.2347475332873206, 2.2847377104418616, 1.8880906743662698, 1.823048153093883, 2.1021783522197177, 1.8492656605584281, 2.1970308167593817, 1.8128224675144469, 2.8128340244293213, 1.0581595110041755, 0.3516478421432631, 0.03701763739809394, 0.029345391052109853, 0.05268518400511571, 0.09237342327833176, 0.0942022040752428, 0.03896931106490748, 0.025788440934515426, 0.05037446353318436, 0.023151105935020105, 0.057088462369782586, 0.04206053340541465, 0.11861119179853372, 0.045201261660882404, 0.01621415915100702, 0.028842691598193984, 0.030882354293550764, 0.0978652210906148, 0.028065531514585018, 0.03615010662802628, 0.025180616050160358, 0.0665147861997996, 0.05305185415116804, 0.05739353171416691, 0.057901639092181406, 0.0459747406920152, 0.024273823547576154, 0.09174102864095143, 0.037148584478667805, 0.03308928944170475, 0.0016569043779912005, 0.06056623253971338, 0.07335695690874543, 0.04613054251032216, 0.05014207885999765, 0.014702108322775789, 0.03992995380290917, 0.05288852737950427, 0.07099790778011084, 0.046092547941952944, 0.029450089005487304, 0.02729579121140497, 0.018836666464007328, 0.03702529466577938, 0.02039079664142004, 0.05210463622851031, 0.04323839895161135, 0.003776226766474013, 0.010280374653770455, 0.07406789197453431, 0.011210328949216222, 0.010361919295974076, 0.031058691974197115, 0.034586785693785975, 0.07268317163522754, 0.061626429935651164, 0.06629391626587935, 0.06625899206846952, 0.03424902453220316, 0.045903470766331465, 0.03907477576285601, 0.02816591059256877, 0.03281044547579118, 0.05341691277655108, 0.02211794307056282, 0.09079171743776117, 0.06111531664750405, 0.03464890218206814, 0.002968101737289024, 0.06434949953109026, 0.05576755485630461, 0.05721502272146089, 0.03450485937563436, 0.034842142170029025, 0.007616345238472734, 0.041523598467132876, 0.030615564502243484, 0.026083478138649037, 0.007230012843917523, 0.03260562289506197, 0.03618193331307598, 0.06387168195630823, 0.029883432002472024, 0.020375169979940568, 0.06786836856710059, 0.017445052208911096, 0.03192618542483874, 0.020422976164679443, 0.029119191225618124, 0.008904569416439958, 0.0032581105728500654, 0.05103613695661936, 0.017859774508646557, 0.06556345974760396, 0.0343088509647974, 0.040900109601872306, 0.04460330267569848, 0.03354188586984362, 0.10046974383294582, 0.049865867609956434, 0.04841268647994314, 0.036399271472224166, 0.0465082015310015, 0.0805918840425355, 0.07767089256750685, 0.04776524193584919, 0.013793784027386988, 0.02565344299988023, 0.051325678027101924, 0.012295029941014946, 0.04415163244786007, 0.01855973935952144, 0.03288365601162825, 0.014279620189751898, 0.01379992307296821, 0.035131622172359905, 0.03569860603394253, 0.005896491364442876, 0.09100042123879705, 0.02897410686793072, 0.017171475371079784, 0.014654078221480762, 0.10132330017430441, 0.043539953484599075, 0.03072096813204033, 0.020386364111410718, 0.027722014679706523, 0.026983805898843066, 0.03261153972042458, 0.014549125817471316, 0.03691747884399124, 0.11085532618952648, 0.05579169373959303, 0.04846659269449966, 0.022148687492257783, 0.046277750682617934, 0.03565346649182694, 0.0458410014398396, 0.03309074150664466, 0.06206031236797571, 0.036403424106538296, 0.0477286383642682, 0.06564098237348454, 0.019203005824238062, 0.030007719261837856, 0.09330262270356927, 0.0169433196673968, 0.02585792800943766, 0.049961764964142015, 0.03798773891425558, 0.0645930121785828, 0.07259472459554672, 0.07202143714364086, 0.05283888236486486, 0.0932512576026576, 0.2296128033527306, 0.7908519431948662, 0.9000655199800218, 2.489353907959802, 3.3707296422549655, 5.806258678436279, 7.441364356449672, 8.637876289231436, 8.980047277041844, 9.566202521324158, 9.044986878122602, 7.708076170512608, 7.549530438014439, 5.591087732996259, 5.532101001058306, 6.582763297217233, 5.790092391627176, 6.259291648864746, 5.553813687392643, 7.232519745826721, 3.5988783027444566, 1.6675696160112108, 0.29647211570824894, 0.07920058869889804, 0.120386931513037, 0.023647523851000836, 0.10576680209487677, 0.010019303216332836, 0.0675497285223433, 0.04778442412082638, 0.08528657284166132, 0.06779325474053621, 0.03867523738050035, 0.06560236694557325, 0.024960465363359878, 0.05659466529531138, 0.04225116103355374, 0.07755472058696405, 0.04746685276872345, 0.022802802035585046, 0.05504049440579755, 0.02431378247482436, 0.029559231363236904, 0.03836659215656774, 0.038061139439897876, 0.013538270639920873, 0.01855201254199658, 0.06995474161314112, 0.026555070154634968, 0.03591372538357973, 0.036042904880430014, 0.04203014521460448, 0.05622101980926735, 0.008036763839689749, 0.03488765151372977, 0.06649189921362059, 0.12314339860209397, 0.019105249284101383, 0.02959894941055349, 0.013991056209696191, 0.03338032668190343, 0.03667501453310251, 0.013892580422439745, 0.02090692430335496, 0.01224374711247427, 0.011166418403653162, 0.038741903446082554, 0.054355353848742585, 0.03376255902860846, 0.04868524721158402, 0.05698896199464798, 0.0034595190622245093, 0.06069855365370001, 0.03716810593115432, 0.0397598009689578, 0.07743331710142748, 0.020482766974185194, 0.07336921125118222, 0.10251530978296484, 0.06558918979551111, 0.0422578581741878, 0.02870592607983521, 0.03794503192018185, 0.04481711584542479, 0.03836732158171279, 0.018187656200357845, 0.060295327433518, 0.06348275925431933, 0.020814541760565977, 0.005292903931279267, 0.03963286403034415, 0.04422834422439337, 0.03912778291851282, 0.09191400757325546, 0.09363221430352756, 0.023742238857916424, 0.1557506431958505, 0.15241544001868793, 0.09454586170613766, 0.09792227231498275, 0.23791568353772163, 0.15424456686845847, 0.20671870612672397, 0.12350916968924658, 0.15576231399817125, 0.09860271401703358, 0.09448589956653969, 0.12320519957159247, 0.15242504807455198, 0.13152695660080227, 0.13488733342715672, 0.09827688828642879, 0.12397942159857069, 0.14055117379341805, 0.24016111876283372, 0.11649182837988649, 0.20289730546729906, 0.16054351601217473, 0.11958235182932445, 0.19805625666465076, 0.131527892979128, 0.13422082204903873, 0.13754932130021708, 0.07971201411315373, 0.2969277926853725, 0.11921287594097, 0.1344929010208164, 0.1323573613273246, 0.1588213805641447, 0.11555190810135432, 0.16433774812945298, 0.13005267642438412, 0.1495755131223372, 0.07478732229875666, 0.1494833002133029, 0.1990154744791133, 0.10786920213805777, 0.1398340029908078, 0.08547801471182279, 0.12451432432447161, 0.1582291823412691, 0.10813048561768872, 0.14196885057858058, 0.2852213537054402, 0.2592276270900454, 0.1621459714536156, 0.10568621249071189, 0.09193571390850203, 0.235757263643401, 0.19770811391728266, 0.16060022796903337, 0.1597267905516284, 0.1758370575095926, 0.19442145313535417, 0.19615990056523255, 0.08937448848571096, 0.11998860431568963, 0.11863902530499867, 0.2427307851612568, 0.14963782977844986, 0.16262330726853438, 0.18847686211977685, 0.1517753236527954, 0.0961260883403676, 0.13856877945363522, 0.11069094429590873, 0.21513864717313222, 0.10864099500966923, 0.12186423795563833, 0.18945875657456263, 0.16562672039227827, 0.13114055804908276, 0.12950104102492332, 0.17114559853715555, 0.20714573535536016, 0.16912509767072542, 0.1618540792592934, 0.662112679864679, 0.5242831643138612, 1.2285156611885344, 1.9533212312630244, 3.906495681830815, 4.578431214605059, 5.185612142086029, 5.712613897664206, 5.940658118043627, 5.934508093765803, 4.686087472098214, 4.671177072184427, 2.9948038714272633, 3.095510627542223, 3.810300043651036, 3.633477726152965, 3.9047864249774387, 4.032531227384295, 4.501952392714364, 2.436267282281603, 0.8341187558003834, 0.1762855691569192, 0.1305138495351587, 0.1926728683922972, 0.13242506555148534, 0.24738165416887828, 0.15672066328780992, 0.11429180071822234, 0.25997279424752506, 0.2333237656525203, 0.1444511759494032, 0.1730248284127031, 0.14959411855254853, 0.10032674936311585, 0.10790827218443155, 0.10932160634547472, 0.21097050154847757, 0.22772514607225144, 0.07496153616479465, 0.29560481224741253, 0.13761716123138154, 0.1873592742319618, 0.20275758153625897, 0.08358848467469215, 0.14342920721641608, 0.09801536053419113, 0.1116158960919295, 0.11388340406119823, 0.06825092661061458, 0.15534163585730962, 0.07678523473441601, 0.16195955074259213, 0.19807779336614267, 0.15643008745142392, 0.15141158817069872, 0.17214699408837728, 0.1815997739987714, 0.13222382563565457, 0.08386074006557465, 0.1666583786053317, 0.11734583255435739, 0.1125702080982072, 0.0673288789444736, 0.14094741110290798, 0.11627220016505037, 0.1337094237761838, 0.09848768876067229, 0.10005898587405682, 0.19191892099167618, 0.13049069792032242, 0.10710013697722129, 0.10866484551557473, 0.15980071015655994, 0.10836563871375152, 0.20379868495677197, 0.12109556634511266, 0.23773459611194475, 0.23698283359408379, 0.16299210462187017, 0.12323728070727416, 0.1255039812198707, 0.1181698590517044, 0.1733042084212814, 0.21439367000545773, 0.10114793958408491, 0.13688282349279948, 0.22930192574858665, 0.11161154668245997, 0.05407964810729027, 0.14657911605068616, 0.17874558429632867, 0.136372497305274, 0.1747091423187937, 0.13540733552404813, 0.11741539596446923], [0.028739184473774264, 0.03867277429838266, 0.03481180486934526, 0.0720161377851452, 0.022115512218858515, 0.014562905167362519, 0.06338102649897337, 0.03026740818417498, 0.006613129092979112, 0.0370129385430898, 0.033137808088213205, 0.018561964954382608, 0.041297459708792825, 0.07000787769045148, 0.023349348422405974, 0.030391010123171976, 0.00831864764248686, 0.04283914555396352, 0.03486727849979486, 0.026501370893259133, 0.016582393320277333, 0.034012887560363324, 0.00913036975543946, 0.06592361935015235, 0.09899743819343192, 0.027995282784104347, 0.03445542470685073, 0.038076162205210755, 0.002756569505436346, 0.02188143290446273, 0.013717413214700562, 0.042352920930300436, 0.02502713991062982, 0.013630081516956645, 0.008937077181014632, 0.025153708743995855, 0.020055464635203992, 0.030989230344338075, 0.03154211424823318, 0.1349270955792495, 0.01452444919518062, 0.030337660307330743, 0.04519439149381859, 0.021230395517445037, 0.06702050513454846, 0.01148730015847832, 0.015035794881571616, 0.023540878502119864, 0.015464430541864463, 0.06341104488819838, 0.02965344934325133, 0.0350999990478158, 0.012515299371443689, 0.0880977027118206, 0.0517606020106801, 0.04544445539691618, 0.028423697920516133, 0.023509609912123, 0.006686679320409894, 0.020401332593922104, 0.039361070043274334, 0.02920165697910956, 0.025479239311867526, 0.090017570049635, 0.034883190145982165, 0.03508375831214445, 0.03448805206322244, 0.042139637017888684, 0.04374506105003612, 0.02749109055314745, 0.0266757187699633, 0.045304694146450074, 0.06662022375634738, 0.05957829912326165, 0.01601080220591809, 0.0017438736956267218, 0.0981993181630969, 0.027621913801080415, 0.017925385452274765, 0.03194867207535675, 0.010892058706044086, 0.05481002659403852, 0.07047734928450414, 0.05173970991745591, 0.023476468565474664, 0.06086537827338491, 0.0911608404879059, 0.07216070645621844, 0.024177468182252984, 0.06485692158873592, 0.02842121448234788, 0.0747896700299212, 0.08018611331603356, 0.028723523885543858, 0.010337687114120593, 0.055681048426777124, 0.006929851852224341, 0.03617498172180993, 0.039250099033649476, 0.09917934664658137, 0.03407916346830981, 0.028376300553125993, 0.03624851116910577, 0.029918573331087828, 0.06560584783021893, 0.06659480583454881, 0.023333502933382988, 0.06488086708954402, 0.0726982011858906, 0.07802447716572455, 0.036007566776658805, 0.02022590415020074, 0.08296588129763093, 0.029381309303322008, 0.07860900115753923, 0.06383563817611762, 0.0073673271274726304, 0.010337961920803147, 0.05506122365061726, 0.03236921111653958, 0.004052580508869141, 0.025877434194886258, 0.0061327928810247356, 0.060109001717397144, 0.028874352042164122, 0.005440958576010806, 0.011741029847014164, 0.02218306716531515, 0.01161703944671899, 0.02928206677149449, 0.04291990139920797, 0.00638050862887342, 0.020798574135239636, 0.03417225847286837, 0.024852388305589557, 0.027543529435726147, 0.023468541580119302, 0.0403460212983191, 0.009025693854450114, 0.062323346467954774, 0.055503438492970805, 0.0817266795784235, 0.03033555345609784, 0.07366600246833903, 0.044428193143435886, 0.03925134753808379, 0.0323143787016826, 0.036914381331631115, 0.04759032239339181, 0.006722670514136553, 0.04559642688504287, 0.05988268993262734, 0.03639420960098505, 0.06905072940779583, 0.020132149270336543, 0.06651693037045853, 0.023942768008315136, 0.02412759925105742, 0.081678632513753, 0.02678726314167891, 0.023426309560558627, 0.014862330796729242, 0.025742938376164863, 0.0417423717278455, 0.08422858746988432, 0.05384718879525151, 0.04152170874710594, 0.02382211260763662, 0.00950682268012315, 0.02452921395057014, 0.008361173128443105, 0.025679312147466198, 0.04604659415781498, 0.008774607059811907, 0.03415993627692972, 0.010995732919712151, 0.011043645973716463, 0.0793639731460384, 0.02295069383191211, 0.02049227155345891, 0.038092827025268755, 0.02443333525609757, 0.029313445623431886, 0.016272903320246508, 0.011292347717764122, 0.018607301271653602, 0.04611559777653643, 0.020982859157291905, 0.02353831872876201, 0.03153744592730488, 0.04471279787165778, 0.052184676219310076, 0.02655647641846112, 0.019558748163815056, 0.023949164897203445, 0.06139827932098082, 0.048304063201482804, 0.01982772962323257, 0.03647061264408486, 0.02361585831801806, 0.06620812908347164, 0.044154407656086345, 0.030586407852492163, 0.05598093715629407, 0.009665959498046764, 0.009572338628848749, 0.03348967938550881, 0.060755706658320766, 0.022717917304752127, 0.030948416462966373, 0.021170241691704308, 0.046153483779302666, 0.01530971607592489, 0.04916046938991972, 0.016448094276711345, 0.05662605432527406, 0.026891452193792378, 0.020794050003002797, 0.0208724394573697, 0.05676675534674099, 0.04398998165769236, 0.0036649105521584196, 0.016091323956581097, 0.0033088639320340008, 0.055221364700368473, 0.059851694452975474, 0.026689107962218777, 0.015451489182721292, 0.027614010564450706, 0.048051437828689814, 0.042654804552772214, 0.03362636347966535, 0.053993606474250555, 0.03181308720793043, 0.010994749892103885, 0.01992539456114173, 0.019385506299191287, 0.050654844380915165, 0.014190719379777355, 0.02412247291899153, 0.001864639252224671, 0.04288640891068748, 0.017523855569639375, 0.0033786338712421377, 0.007668886749473001, 0.03134498964729054, 0.04575112947661962, 0.04800193869907941, 0.10015483573079109, 0.052217785335545025, 0.08822550478258304, 0.05314055224880576, 0.03602592454158834, 0.02879756223410368, 0.0478175468077617, 0.010539788769425025, 0.01756865414790809, 0.0101212963594922, 0.041344343085906336, 0.020430431568196843, 0.023407593868406754, 0.012286978274849909, 0.030934282578527927, 0.035641907647784264, 0.0344028789550066, 0.0921749992828284, 0.0226679550749915, 0.022386135733021156, 0.09123748101826225, 0.04180504122216787, 0.06733347941190004, 0.020555086932810288, 0.061249435879290104, 0.10948309089456286, 0.022205390967428684, 0.07430216297507286, 0.04063986428081989, 0.0764873307198286, 0.03789536315681679, 0.0330514102242887, 0.025438930939084718, 0.0544199062777417, 0.03228046552145055, 0.049208207721156735, 0.05166152571993215, 0.04179691576531955, 0.03260073405025261, 0.07976826466619968, 0.041209287475794554, 0.05556646082550287, 0.09029959634478603, 0.03164216762940798, 0.050899558035390716, 0.03873892467735069, 0.016237421027783836, 0.03481773187273315, 0.019165749162701622, 0.06624109231467758, 0.004180216338552002, 0.014152296486177614, 0.05421025252767971, 0.04905672477824347, 0.027693684146340405, 0.024008804732667546, 0.022837709269619415, 0.005406085692811757, 0.01194170573061066, 0.013295832622264112, 0.040206039523971934, 0.010168764973059297, 0.0479229232961578, 0.027924297843128443, 0.014299005935234683, 0.020870442868077328, 0.024790604299466525, 0.05458794208243489, 0.0026937161705323626, 0.05552366562187672, 0.02465884467320783, 0.019790590008986846, 0.034099448272692304, 0.10795321834406682, 0.029164795564221482, 0.045846595961068354, 0.07904519739427737, 0.03745853588251131, 0.0346199049880462, 0.0301102119764047, 0.025213960957314287, 0.02222701587847301, 0.06150322833231517, 0.015334938918905599, 0.0029806472136572537, 0.06002146391464131, 0.10211928960468088, 0.044658973081303496, 0.01200160849839449, 0.022501578288418905, 0.0512960192614368, 0.020648290502971837, 0.023119106223540645, 0.08685108460485935, 0.014972770852702004, 0.04644018518073218, 0.025670621810214858, 0.035473132239920754, 0.04284949321299791, 0.02265989238263241, 0.033625304965036254, 0.007073979899619839, 0.042041347827762365, 0.06966251015130963, 0.10870118106582335, 0.12078645293201719, 0.1134270689051066, 0.1945702422942434, 0.19747190230659076, 0.0918509309579219, 0.17606709445161478, 0.11517382838896342, 0.05086989248437541, 0.13017641407038483, 0.0989423275792173, 0.08882195742002555, 0.09449672898543732, 0.12545706730868134, 0.10779474649046149, 0.09826687310955354, 0.1108385528038655, 0.12558121207569325, 0.11312639646764312, 0.1400965146188225, 0.19056387298873492, 0.11961029390139238, 0.2450507235314165, 0.14046338493270533, 0.18102330421762808, 0.16139718091913632, 0.10234329437038728, 0.1632153426430055, 0.07610294063176427, 0.08641044396374907, 0.10568752884864807, 0.12714856011526926, 0.1628417819738388, 0.12632564641535282, 0.12305774034133979, 0.06823652131216866, 0.1454389329467501, 0.16105974545436247, 0.10555268358439207, 0.159985624519842, 0.08160991048706429, 0.12088797534150736, 0.1217155573623521, 0.13397754010345253, 0.12234933621117047, 0.08703386158283268, 0.09593432755874735, 0.1446732333196061, 0.09314308554998466, 0.18513020527149948, 0.14988915914935724, 0.13446509465575218, 0.09473735107375042, 0.2214682118168899, 0.16405205774520124, 0.07800566138965742, 0.1983990389853716, 0.17136483320168086, 0.17877560268555368, 0.062373612342136245, 0.09589401579328946, 0.16611419352037565, 0.11077684004391943, 0.11033716292253562, 0.08576375937887601, 0.18644368621919835, 0.11516270041465759, 0.12490843103400298, 0.11826427041419915, 0.20273751047040733, 0.12502782605588436, 0.13966073228844575, 0.18907402721898897, 0.267634920243706, 0.19825717088367256, 0.12571697336222443, 0.142473680632455, 0.1760166928704296, 0.1578660982527903, 0.14769803386713776, 0.15047747615192616, 0.17419549130967685, 0.10847566995237555, 0.11233363686395542, 0.16586944593914918, 0.12147731014660426, 0.20024533277111395, 0.1429048760661057, 0.0933974886845265, 0.28438371579561916, 0.12838725293321268, 0.15806060710123607, 0.15842317550310067, 0.10735850954162222, 0.17353150408182824, 0.15457844680973462, 0.12382246287805693, 0.16778526242290223, 0.16902376525104046, 0.15183287699307713, 0.16437037209314959, 0.22651343180664948, 0.1516334962631975, 0.1326864372406687, 0.16663304210773536, 0.12352283538452216, 0.21681145312530653, 0.16646184772253036, 0.1314489250736577, 0.10759068386895315, 0.12498681539935724, 0.24320068423237118, 0.17356494228754724, 0.13630378884928568, 0.13313724233635835, 0.10911921970546246, 0.1273051659975733, 0.13089158998004027, 0.25656141872916904, 0.1674811023154429, 0.1257041354796716, 0.19639404942946775, 0.1036485650443605, 0.12192411188568388, 0.20459711711321557, 0.12545176116483553, 0.1424175657864128, 0.09395666939339467, 0.06270606735987322, 0.10781954694539309, 0.0722415064062391, 0.1409482524863311, 0.10465952115399496, 0.1238639485090971, 0.07641636952757835, 0.15430250018835068, 0.11330333804445607, 0.15749293113393442, 0.10417677062962737, 0.20759787037968636, 0.16899131770644868, 0.09642958348350865, 0.08747846486845187, 0.08588001956897122, 0.16281131575150148, 0.10173014298613582, 0.1139753455562251, 0.1649589062269245, 0.09144868861351695, 0.14269393309950829, 0.16411315303828033, 0.1414383447596005, 0.06678272610796349, 0.126841346600226, 0.139597139986498, 0.10420271780874048, 0.15624350389199598, 0.10719465011996882, 0.26244765573314255, 0.18743565013366087, 0.11013256425836257, 0.1592172650354249, 0.14773092924484185, 0.12063862729285445, 0.19772921635636262, 0.1216499430260488, 0.23258104122110776, 0.16854060760566167, 0.17767758374767645, 0.09851292347801582, 0.09398330867822681, 0.1445109277431454, 0.07861756426947457, 0.08796237568770136, 0.10935553988175732, 0.06776249674814087], [0.021464798832312226, 0.027230132770325457, 0.01512386872699218, 0.012629825904566263, 0.028575104528239796, 0.01477892866491207, 0.01689083837637944, 0.024629001006750122, 0.02752508346124419, 0.01834916789084673, 0.02287108471084918, 0.06625972488628966, 0.07387002437774624, 0.013163306251434343, 0.07964788576854126, 0.06252702232450247, 0.03620848778103079, 0.08421164445046868, 0.03388069876070533, 0.025967904965260198, 0.055160099773534706, 0.032977256524775705, 0.008737519183861358, 0.030578116154564277, 0.012576576172640281, 0.01664054037870041, 0.06562034133821726, 0.047886852374566455, 0.035175608204943795, 0.04162677310939346, 0.013655628360408758, 0.013028594997844525, 0.056279278825968504, 0.019915806861328225, 0.03353266118626509, 0.014912284544802137, 0.0696312500430005, 0.026781449792906642, 0.10352729726582766, 0.03404257346742919, 0.023041532707533667, 0.015585801796987653, 0.11326634431523935, 0.05992745967315776, 0.048632195951150994, 0.013624725331153189, 0.03967549977824092, 0.017480229160615375, 0.06772913318127394, 0.05853837635368109, 0.012236494421293693, 0.04870010034314223, 0.0241468866089625, 0.009912957271028842, 0.03252792724275163, 0.037667141295969486, 0.02314156573265791, 0.03554447341178145, 0.02626459440216422, 0.03329348437754171, 0.0653363201501114, 0.025724441511556506, 0.04195379645430616, 0.07030363074902977, 0.010564174469826477, 0.0383279054824795, 0.013559685205109417, 0.03760038023548467, 0.049132228762443574, 0.05045988091400691, 0.016178363036098223, 0.03554342507517763, 0.04147167018215571, 0.02280361288493233, 0.017106877140966908, 0.010530236692700003, 0.05766535284263747, 0.0029177408682049383, 0.022654718553115214, 0.024061784746923616, 0.031156747069742, 0.03674972802400589, 0.030910693308604614, 0.08178516929703099, 0.07985368543969733, 0.011428198910185268, 0.02573537271070693, 0.02840983884276024, 0.07933678424784116, 0.023807736146929007, 0.034536088949867656, 0.07192199105130774, 0.029001590928861072, 0.03620082372799516, 0.010331950948706694, 0.026989393634721637, 0.04452879613797579, 0.045323031555329046, 0.04132314565192376, 0.05758587603590318, 0.04364439359466944, 0.008364522546928908, 0.04483324123014297, 0.06651060642408473, 0.06476250344089099, 0.032022215093352964, 0.030409459490329027, 0.04777968455372112, 0.0387421816454402, 0.020394348772242665, 0.015675093612766693, 0.04036541043647698, 0.0735312250575849, 0.035212534080658636, 0.049906430433371236, 0.03407120764521616, 0.02120180714077183, 0.03874421385782106, 0.02505222535026925, 0.04996518138796091, 0.03977528853075845, 0.052941249550453255, 0.02664959686808288, 0.024198492589805807, 0.033051227019833665, 0.028834216695811068, 0.018367206744317497, 0.02292021912788706, 0.01644965660359178, 0.058819262710000784, 0.05960951851946967, 0.05375442627285208, 0.02716217070285763, 0.04069016747442739, 0.061116151245577, 0.037654381444943805, 0.03626216668635607, 0.03731458128562995, 0.02307804806956223, 0.03219257488048502, 0.04015347680875233, 0.11612691224685737, 0.024597055578072156, 0.004338594045423503, 0.0061224464942435065, 0.02224582995820258, 0.021488571306690574, 0.01715464939895485, 0.022037682555881993, 0.03445477670590792, 0.025300581041457396, 0.0024084246376462814, 0.05537762452981301, 0.11061026648219142, 0.04728129718984876, 0.04088934803647654, 0.02094185528611498, 0.038968255942953486, 0.04645198829738157, 0.02810232337963368, 0.010407981645715023, 0.03542581120772021, 0.03825245578108089, 0.05537608764799578, 0.07037502620369196, 0.006779484675332371, 0.020471348926158886, 0.02749595225655607, 0.09892497065344028, 0.06589173498962607, 0.02296612032556108, 0.009173607703165283, 0.035649785439350774, 0.020408599703971828, 0.006440481370581048, 0.0660337387983288, 0.049505036257739575, 0.03639390765290175, 0.056949308408158164, 0.05338558481474008, 0.04304974586037653, 0.009034924475210053, 0.049975420481392314, 0.01496857580994921, 0.02975766553676554, 0.06736996423985277, 0.02988172209422503, 0.03371226601302624, 0.05104644390355263, 0.03864475419478757, 0.07107596644865614, 0.04108770078580294, 0.0587330548358815, 0.046001458008374484, 0.01725725407179977, 0.04064759618735739, 0.050718314546559534, 0.056364116059350114, 0.024877843546814153, 0.018189890276906744, 0.06765005671020065, 0.013927019467311246, 0.031043770989137034, 0.048648039743836434, 0.03422926559246012, 0.012624760640652051, 0.028298464104799286, 0.03590829710343054, 0.018427932235811437, 0.042412072220551114, 0.031189299787261655, 0.05195334327540227, 0.013536591265749718, 0.03342585638165474, 0.03290364904595273, 0.025676352038447346, 0.007317128258624247, 0.013667872524820268, 0.047023158720029254, 0.02348793750362737, 0.05352866070877228, 0.02883653389289975, 0.0553963588816779, 0.05135528590264065, 0.023694414013464535, 0.09273781015404634, 0.00834424707240292, 0.033268741598086696, 0.011782602839437979, 0.07657812549067394, 0.05136818824602025, 0.02172758357067193, 0.04825844529217907, 0.06818177032151393, 0.004556412692181766, 0.0371228849648365, 0.08619099895336799, 0.050256578251719475, 0.02301308173420174, 0.03617149065913899, 0.0034359170697695974, 0.04005279239001019, 0.02392628469637462, 0.01770219492859074, 0.033496977029634376, 0.051186174619942904, 0.027245014739621962, 0.007865705161488481, 0.008741020424557584, 0.03020192955487541, 0.03759475178750498, 0.03003650950267911, 0.05348678831277149, 0.009803477342107465, 0.05005036806687713, 0.025432208353387456, 0.030088481892432486, 0.0055702156803038505, 0.024305826651730707, 0.01055321273660021, 0.057951830327510834, 0.036500291765800545, 0.05188910297251173, 0.038773764057883194, 0.00926918105687946, 0.08972307228084121, 0.039463196348931105, 0.08071254113955156, 0.056747060867824724, 0.023779402220887796, 0.03339974974681224, 0.05086721905640193, 0.034167434088885784, 0.035750639491847584, 0.07415319061172859, 0.030567900809858526, 0.03661272841106568, 0.07614815142005682, 0.03886209235393575, 0.08040274240608726, 0.024785698491281698, 0.019185855851641724, 0.05433883491371359, 0.05280902003869414, 0.006112120039428451, 0.034762298954384666, 0.035156205496085544, 0.013835280684621205, 0.046677346740450175, 0.020063766511157155, 0.060449911281466484, 0.011746658294993852, 0.04717968996348126, 0.02081637889412897, 0.008474988896133644, 0.0183934372118009, 0.03683905715921095, 0.020106995977195244, 0.013335155422932335, 0.03839838491486652, 0.014927522744983435, 0.05878490169665643, 0.04512337262609175, 0.02827083076616483, 0.01604786718131176, 0.013386996346525848, 0.06630716805479356, 0.08680691876049552, 0.023709541951705302, 0.043476836157164404, 0.03148033702746034, 0.019981346558779478, 0.05279092690242188, 0.05975631278540407, 0.05099387440298285, 0.036421870081020255, 0.03579165354104979, 0.047620534165097136, 0.05080742994323373, 0.027655273975272263, 0.06370342562773398, 0.031164499332330058, 0.009015342802740633, 0.015927025183503116, 0.03995184673528586, 0.07273620593228511, 0.020287460847092525, 0.03330412719930921, 0.08096085102962595, 0.017522082896903157, 0.040950914911393604, 0.023982937281419123, 0.01220621564425528, 0.04010252561420202, 0.04283854165779693, 0.008757213662777628, 0.05578155642641442, 0.07127742349569287, 0.015603603163201894, 0.04446858972577112, 0.08707946592143603, 0.029222165700048208, 0.030626831576228142, 0.03335680865815707, 0.027822824627427117, 0.04125047115875142, 0.03275605071602123, 0.016839812542977076, 0.021379081199743917, 0.030069801823369095, 0.012147021097397166, 0.01436665587659393, 0.12403165522430624, 0.08077436246510063, 0.16683080792427063, 0.10248340506638799, 0.16431355157068797, 0.11137228166418416, 0.10157898574003152, 0.15864831342228822, 0.146395545186741, 0.27532502902405603, 0.09843660185911826, 0.1367518933756011, 0.20351109467446804, 0.15546325647405215, 0.21337266479219708, 0.08972698064254862, 0.1484819860862834, 0.10946130313511405, 0.16317878317620071, 0.14831567715321267, 0.14856244676879474, 0.08236774589334216, 0.07337555555360657, 0.08551795328302042, 0.14576867382441247, 0.08337668675397124, 0.12871605743254932, 0.14335763534264906, 0.14090839533933572, 0.059948195703327656, 0.09346894520734038, 0.12896320702774183, 0.1503410634717771, 0.12409691672239985, 0.08432963490486145, 0.16548820425357136, 0.08075781978134598, 0.06924168273274388, 0.1147006723497595, 0.10284777837140219, 0.12724567204713821, 0.11498668843082019, 0.2106573712080717, 0.14227039154086793, 0.149358938315085, 0.12505389537130082, 0.1473855956324509, 0.09817670937627554, 0.1801271630184991, 0.11943756602704525, 0.06326883073363986, 0.11402950622141361, 0.11638771396662508, 0.08902165706136397, 0.15549209421234472, 0.0983617255198104, 0.12597487095211232, 0.09544892396245684, 0.09111537185630628, 0.07332191057503223, 0.23142994727407182, 0.12123139548514571, 0.07956928427198104, 0.1811221396284444, 0.08726625304136958, 0.11125782637723855, 0.1692530693752425, 0.10114390908607415, 0.17831936930971487, 0.10534211381205491, 0.20660453582448618, 0.055729889377419434, 0.1159697092537369, 0.10181518378002302, 0.06569224569414343, 0.07388214979852949, 0.2022401171603373, 0.0677353757034455, 0.15416782455784933, 0.10209533053317241, 0.1178913339972496, 0.11822826734610967, 0.14496188211653913, 0.12639496555285795, 0.12947874436421053, 0.06890048139861651, 0.10048075645629849, 0.1180549423609461, 0.10937965501632009, 0.14984973626477377, 0.13813330924936704, 0.19438441869403633, 0.11857178248465061, 0.12344128904598099, 0.13401210467730248, 0.16030510594802244, 0.13809820184750216, 0.13038910765733036, 0.19512499895478996, 0.17252309247851372, 0.14575157474194253, 0.1876152583530971, 0.1624127442815474, 0.29318610631993836, 0.20224125709916863, 0.12945678697100707, 0.1204300049160208, 0.1603760128574712, 0.07911313232034445, 0.15144782194069453, 0.08382534767900195, 0.13178813830018044, 0.23264438925044878, 0.13090754912367888, 0.12019421399704047, 0.10755818882691008, 0.13701032022280352, 0.11911356555564062, 0.10276987576591116, 0.0698840179081474, 0.12539346143603325, 0.1343716468129839, 0.09573979156890086, 0.06742388063243457, 0.05460856615432671, 0.11510488923106875, 0.0964521515582289, 0.0893018716680152, 0.16976545830922468, 0.09511904737779073, 0.1882417904479163, 0.1517533798302923, 0.09074038626360041, 0.20353168142693384, 0.12000260927847453, 0.08708106726408005, 0.13011415169707366, 0.1169118279857295, 0.1335308469299759, 0.18357190888907227, 0.1772249330367361, 0.14120647577302797, 0.16394320715750965, 0.08379382294203554, 0.2062352227845362, 0.07252638254846845, 0.10953746190560715, 0.08984335618359701, 0.09018003847450018, 0.1452662322138037, 0.07916502667857067, 0.11835413559206895, 0.11878990435174533, 0.14896084181964397, 0.10662347969732114, 0.1716794427484274, 0.03828498814254999, 0.1255986639963729, 0.09551736100443772, 0.13510470890573092, 0.18780359253287315, 0.14740696948553833, 0.09730889701417514, 0.07923175381230456, 0.27210307334150585, 0.14397815561720304, 0.20891549039099896, 0.09732807919915233, 0.18630773494286196, 0.11267467534967832, 0.05846832439835582, 0.10415507786508117, 0.10705327734883342, 0.08997753648353474, 0.07485594254519258, 0.1067670848486679], [0.05646163511223026, 0.07038466818630695, 0.005859588813369295, 0.04861284073974405, 0.013850616424211433, 0.04233501099848321, 0.04027854099071451, 0.10390527519796576, 0.040550952444651296, 0.06934952908860785, 0.01843448349141649, 0.02023960886123989, 0.014347127638757229, 0.06439614202827215, 0.06341179806206908, 0.06029422820678779, 0.040368921855198484, 0.030436916409858635, 0.07058265791939837, 0.030938190940235342, 0.019290216233847395, 0.021823911794594357, 0.03780212226722922, 0.04020864509844354, 0.05561019240745476, 0.05762335831033332, 0.057303537614643574, 0.029799724529896463, 0.015891676901706626, 0.06119470524468592, 0.04771487428141492, 0.03331302618607879, 0.004547095134122563, 0.018098727400813783, 0.050231285858899355, 0.020515574142336845, 0.0324750286526978, 0.0489865778280156, 0.024131784115784934, 0.025731213291042616, 0.04791894029559834, 0.10694213331277881, 0.04134107593979154, 0.047589677785124095, 0.03351820160501769, 0.043181198449539285, 0.033453123311379125, 0.05174823570996523, 0.11630022366132055, 0.02612852438219956, 0.01099707726721785, 0.023025556600519588, 0.037307972354548316, 0.033354528780494413, 0.005833418989953185, 0.019478346853117858, 0.049744735538427315, 0.02825817439172949, 0.02156060967328293, 0.047050038884793005, 0.02826941093163831, 0.049046400867934735, 0.03305479272135666, 0.056056359716291936, 0.016242733956979852, 0.047378619467573505, 0.050603038232241354, 0.007576790887729398, 0.021338553999417594, 0.024911015427538326, 0.048719530193401236, 0.031643633265048265, 0.04056376997115357, 0.03063401047672544, 0.057547694870403836, 0.05377516230302198, 0.037169313723487515, 0.055632349968488724, 0.04266180024881448, 0.014066566131077707, 0.017606870936495916, 0.04695449436881712, 0.04674626893496939, 0.031138830352574587, 0.07687571059380259, 0.03336233193320887, 0.023596112948975394, 0.07469802709030253, 0.010220554158357638, 0.019715873125408376, 0.06419771803276879, 0.04566512516300593, 0.01782203439090933, 0.021758784307166934, 0.08763316406735353, 0.035952493481870205, 0.01463773740189416, 0.01991844636255077, 0.05640231758090002, 0.08772872215402977, 0.018602434479232346, 0.030282637902668545, 0.08590609566973788, 0.05887083137141807, 0.02955775215689625, 0.03961244012628283, 0.06931786185928754, 0.0512079623793917, 0.03762800678876894, 0.022421645166884576, 0.022845585364848375, 0.0055411731092525375, 0.022510012478700707, 0.01850402824181531, 0.009711893774302942, 0.003750212157943419, 0.06445953076971428, 0.052426095586270094, 0.051158280045326264, 0.016114399236227785, 0.005678146004876388, 0.025806430594197342, 0.026243737932028513, 0.024883360036515763, 0.044902577331023555, 0.03047950126762901, 0.012579523559127535, 0.03755405664976154, 0.023878135851451328, 0.0659240468272141, 0.025582471629604697, 0.040897585451602936, 0.040153408955250464, 0.021535395311989954, 0.03886018906320844, 0.00799170063276376, 0.014293743896165063, 0.03419756443638887, 0.036090819630771875, 0.002387009224288964, 0.028295461587341766, 0.04687683264325772, 0.010339856729842722, 0.027310980217797414, 0.04047744335340602, 0.00620957208697551, 0.015161990520677395, 0.0034430370225371526, 0.16180290414818696, 0.05727101543119975, 0.04634989591847573, 0.09076759551784822, 0.0057055554269546905, 0.022990013239905238, 0.035550145964537344, 0.062968436495534, 0.024787437237266983, 0.08116137169833694, 0.07579525214220796, 0.027164962874459367, 0.0598528343918068, 0.06234852011714663, 0.027438873890787363, 0.03109528197507773, 0.03779205959290266, 0.06809294330222265, 0.06652543919959239, 0.06493562486554895, 0.003502656501950696, 0.04498305158423526, 0.07293520668255431, 0.03154326436508979, 0.05039790352540357, 0.03220094121726496, 0.02011593397972839, 0.043430271691509655, 0.02557643606061382, 0.05366386898926326, 0.047592877077737024, 0.053835979396743436, 0.03897296158330781, 0.040158019600702186, 0.014602731780282088, 0.05066510043772204, 0.036841757728585174, 0.05390866746061614, 0.022971453610807657, 0.009611155072759305, 0.05387201299890876, 0.07657220187996115, 0.04487705762897219, 0.08498640930546181, 0.020925146361280764, 0.031552448336567195, 0.027067455695942044, 0.03411240829154849, 0.05505220252754433, 0.023016445571556687, 0.005429751297924668, 0.07436311577579804, 0.03782680397853255, 0.05560260299327118, 0.04693020281514951, 0.036323967655854564, 0.03956744986187134, 0.018485612801409194, 0.03433712212634938, 0.014495925279334188, 0.02975830335968307, 0.012501539529434271, 0.05976315920374223, 0.01127602216521544, 0.044148684213204045, 0.01549389592504927, 0.029270060094339505, 0.02715417756033795, 0.04190149497506874, 0.024898876436054707, 0.07826676845018353, 0.04087336175143719, 0.01927328678513212, 0.022703325409176092, 0.04917747008481196, 0.024579695259620036, 0.1273528127265828, 0.08078256595347609, 0.02689622568764857, 0.037096686727766476, 0.02204602344759873, 0.031122369093022177, 0.012439724141066628, 0.013763898800659393, 0.03601188225937741, 0.014076700899749994, 0.03137900800045047, 0.05117414080138717, 0.06124450971505471, 0.048174479976296425, 0.011814893472806683, 0.03416276916063257, 0.016477759827726653, 0.010853956420240658, 0.04730987708483424, 0.015569771407172084, 0.0347308556416205, 0.013421191118790634, 0.025188271621508256, 0.013556645368225873, 0.09070092945226602, 0.02974354861570256, 0.007902335026301444, 0.0366954011177378, 0.05078174400010279, 0.056814371541674645, 0.04221936148990478, 0.007853681520958031, 0.04133969512102859, 0.027006965995367085, 0.01201742684601673, 0.08917484312717404, 0.03755306938130941, 0.054463220560657125, 0.036955856784645996, 0.018490048724093607, 0.038593294098973274, 0.06234094088098832, 0.013317183574794658, 0.03084116382524371, 0.05336007529071399, 0.010273093973020357, 0.02155662836906101, 0.03434566148955907, 0.016720931511372328, 0.06255042499729566, 0.028476873013590063, 0.0711348293615239, 0.035367528442293406, 0.04185583974633898, 0.011121668171004524, 0.038865546097180674, 0.05156355883393969, 0.03772329006876264, 0.028656331955322197, 0.029782730620354414, 0.0440841928523566, 0.01708543034536498, 0.031146463871534382, 0.031203308142721653, 0.025474691430905035, 0.041470727018479786, 0.016743794748825685, 0.03683441937235849, 0.04898892555918012, 0.034236220576401265, 0.038172822911292315, 0.09220414914722953, 0.025326073602108017, 0.002224576846596652, 0.07473021000623703, 0.06888385729065963, 0.031147105087127005, 0.05602643292929445, 0.014806673961824604, 0.032849166076630354, 0.03960708987766078, 0.08783492645514862, 0.027601496682369282, 0.030820302266095365, 0.03634459512042148, 0.062471681008381505, 0.03178183049229639, 0.020297491291005696, 0.023865415016189218, 0.01828417950309813, 0.026090344913037758, 0.013299571350216866, 0.018792509101331234, 0.05020412749477795, 0.030552338609205823, 0.021378967545128295, 0.06519774294325284, 0.03906830593145319, 0.0097610256468345, 0.027552343605618392, 0.015557978468547975, 0.06369516785655703, 0.01667278436278658, 0.0583180288917252, 0.0331288242845663, 0.056410419289022684, 0.06110111490956374, 0.022555265675431917, 0.023904720853481973, 0.089057388715446, 0.04229231078975967, 0.013524163896883172, 0.04225067248834031, 0.012401253750015582, 0.04266782903245517, 0.03769274242222309, 0.03424878704494663, 0.026209139431427633, 0.07614973240665027, 0.07087325411183493, 0.022222659683653286, 0.003956499526144138, 0.028697200119495392, 0.07276792065905673, 0.027509193867444992, 0.04439758103606956, 0.0018698898410158499, 0.11313742944704634, 0.12366968393325806, 0.10862901886659009, 0.10813497073416199, 0.15641152273331368, 0.08582188268857342, 0.1737255243850606, 0.153459528993283, 0.2154065870812961, 0.1070781456572669, 0.12849072952355656, 0.1194821729191712, 0.10156154739005224, 0.10723296020712171, 0.1408531897302185, 0.12810745223292283, 0.1597240085580519, 0.11123654751905374, 0.12286370646740709, 0.23245529511145183, 0.09671245116208281, 0.08769543322601489, 0.1955362590295928, 0.10361560181315456, 0.14666125950004372, 0.10587814969143697, 0.15878041061971868, 0.1781519611499139, 0.1909690805311714, 0.17264058760234288, 0.1660344520849841, 0.14013753884604999, 0.08324488811194897, 0.1328905134328774, 0.13317557956491197, 0.16861515146281036, 0.17296605370938778, 0.1708816077028002, 0.10272590669670276, 0.15299040345208986, 0.1221376604267529, 0.1793120524712971, 0.15473095434052603, 0.1989857139331954, 0.13521452301314899, 0.12069689988025598, 0.12434116218771253, 0.10152245020227772, 0.09177659066127879, 0.1798196238066469, 0.14508051717919962, 0.08899668697267771, 0.15760171386812413, 0.08320933966232197, 0.062463748934013505, 0.16404225969953196, 0.089498673964824, 0.0852318557777575, 0.11592526521001544, 0.20348985652838433, 0.12620091810822487, 0.19109108112752438, 0.14958482262279305, 0.11477328916745526, 0.17850963052894386, 0.0645483306476048, 0.09982066401945693, 0.19225988483854703, 0.24215983865516527, 0.1497474131839616, 0.09664348486278738, 0.09240134499434914, 0.1659757045230695, 0.20626097997384413, 0.1427613387682608, 0.10193841931010995, 0.1175064282225711, 0.12721026608986513, 0.19946402683854103, 0.13691673667303153, 0.12788140507681028, 0.16343184959675583, 0.17332693934440613, 0.09931260413889374, 0.1488264783152512, 0.15896936905171188, 0.12013256230524608, 0.1519087100667613, 0.12097500424299922, 0.08044978523893015, 0.1402375413370984, 0.10844322919313397, 0.1318339801260403, 0.10117909791214125, 0.07442696592105286, 0.1659520643630198, 0.1889186291290181, 0.06614663345473153, 0.08625763109219925, 0.12891716164137634, 0.24047403197203363, 0.1687803475984505, 0.12014473522348063, 0.11546756619853632, 0.11643280940396444, 0.11095038894563913, 0.10788098150598151, 0.14303387914385113, 0.09825242709900651, 0.11770632463906493, 0.10800756899906055, 0.11063784893069949, 0.0500383308556463, 0.11421191000512668, 0.08458105248532125, 0.07765551017863409, 0.10727102602166788, 0.15757255043302262, 0.17644942179322243, 0.11061009684843676, 0.11057643472616162, 0.06695544719696045, 0.09511106780597142, 0.23596665955015592, 0.1516892718417304, 0.0636421199887991, 0.16148939382817062, 0.08495829759963922, 0.15466216446033546, 0.13810135024998868, 0.10679102356412581, 0.11263555780585323, 0.07883820350148849, 0.09322111029177904, 0.121753758883902, 0.14744209045810358, 0.05165387863027198, 0.07474426925182343, 0.11263736949435302, 0.1821255436433213, 0.11128391604870558, 0.0908423565062029, 0.18641862113560947, 0.07438257616013288, 0.1539631105427231, 0.11746312411768095, 0.10159606446645089, 0.06952718991254057, 0.08241422554211957, 0.2681748169873442, 0.10212703168924366, 0.0876527533733419, 0.210328200299825, 0.07479551900178194, 0.1635858906166894, 0.09736009926668235, 0.09553091134876013, 0.1276811015393053, 0.17552581349653856, 0.1859761213085481, 0.08526732280318226, 0.12897542065807752, 0.20079535325723036, 0.1490209193101951, 0.11668924135821206, 0.11213280406913587, 0.14414081403187343, 0.21273428547595227, 0.15627786490534032, 0.10872399341315031, 0.15267702883907727, 0.20297179504164628, 0.1262802252812045, 0.07188748076025929, 0.07881302985229663, 0.10366103651800326, 0.16490374132990837], [0.044303617506687126, 0.047287200444511006, 0.051318346456225426, 0.013479847926646471, 0.03844952270654695, 0.020707424829847047, 0.04584451964391129, 0.0733645497156041, 0.03775492676400712, 0.051552471571734974, 0.03133136127144098, 0.028941452370158265, 0.02537559308776898, 0.01332161610480398, 0.022264947682353, 0.06245261417435748, 0.04191052966884204, 0.020861552362995486, 0.012163948001606124, 0.01951488426753453, 0.05447498296520539, 0.02405537598367248, 0.048453954979777336, 0.1206096809889589, 0.025915250647813082, 0.009558701771311462, 0.01199973065273038, 0.031765325127967765, 0.04496712976002267, 0.006351047910616866, 0.050154323024409156, 0.028838243801146746, 0.0670179199161274, 0.08200525213032961, 0.006066385082834001, 0.05515282927080989, 0.03609829708667738, 0.11916837761444704, 0.06535446417651006, 0.023864302218758633, 0.05848778478269066, 0.0231994040576475, 0.03848763262586934, 0.012855647447785097, 0.05331149557605386, 0.03811006520741752, 0.05362131127289363, 0.09711569773831538, 0.021724927106073925, 0.013380385719106665, 0.06184995972684451, 0.024694399908185005, 0.08826920922313418, 0.02782536404473441, 0.1556410597903388, 0.013077301937820656, 0.05463585683277675, 0.03423715356205191, 0.04695299480642591, 0.031929781660437584, 0.037253418139048984, 0.016109233888398324, 0.0024118020457016037, 0.03333879016073687, 0.039389113895595074, 0.03294160968757101, 0.032200856400387626, 0.047674949280917645, 0.04150387006146567, 0.034916373901069164, 0.0808907447914992, 0.016965019217293178, 0.015801876184663603, 0.02996087659682546, 0.040805898407208066, 0.057834328418331485, 0.05189963383600116, 0.013131063115516943, 0.02033349944810782, 0.06535829789936543, 0.04995150551466005, 0.05025890901950853, 0.03628088068217039, 0.046190406262342415, 0.003894852923362383, 0.024861380590924194, 0.0479264889976808, 0.04936989922342556, 0.04833774228713342, 0.039955171556877236, 0.02983149353946958, 0.041229494248649905, 0.0271740603327219, 0.026563467025490742, 0.03772580743368183, 0.12902390877051012, 0.020141781074926257, 0.0673102056607604, 0.034718316314475875, 0.01101105084775814, 0.011895341432786413, 0.053454079532197545, 0.041292889775442224, 0.07281115012509481, 0.03517205607412117, 0.05119911767542362, 0.048183426460517306, 0.03263570913778884, 0.017808151564427784, 0.028300177405721376, 0.02344371228744941, 0.03960006364754268, 0.030462449682610374, 0.006500615264355604, 0.06215025218469756, 0.08736354139234338, 0.03612567936735494, 0.05423376715875097, 0.04819280042179993, 0.05750658921897411, 0.05214920240853514, 0.033194808422454765, 0.038590881906981976, 0.024445408090416874, 0.05875598931951182, 0.034106671277965815, 0.014063841812977833, 0.02080036377135132, 0.051855064263301234, 0.03831381570281727, 0.030968779298876013, 0.023988828661718538, 0.03488843861435141, 0.0682958931263004, 0.046460805859948905, 0.018576896117467965, 0.00755167321767658, 0.15357767551073007, 0.03590468051178115, 0.038870821706950665, 0.04421189992821642, 0.02504973003773817, 0.0487761267993067, 0.017125932100628103, 0.02914816467091441, 0.01705942888345037, 0.043612448165991476, 0.00856103137734213, 0.016393892899421707, 0.015836805471086075, 0.023622102536527172, 0.022883172812206403, 0.019838645555345074, 0.03316950245893427, 0.043432907800057104, 0.07503082137554884, 0.03634933129485164, 0.03932195928479944, 0.014717940241098404, 0.03034825563164694, 0.06544924873326506, 0.06903384067118168, 0.044094258919358253, 0.06074461939611605, 0.022560017116900002, 0.03921822824382356, 0.05420640862679907, 0.06316179861979825, 0.02982694735484464, 0.01930065719144685, 0.033995534027261395, 0.022671325697696636, 0.005345297436828592, 0.011703039519488811, 0.024625979829579592, 0.07279369820441518, 0.019519023331148282, 0.10138881273035492, 0.039219229082976065, 0.026192459344331707, 0.009651531299043978, 0.0440685322641262, 0.03873349300452641, 0.053323685457663875, 0.039122890681028366, 0.03912765738953437, 0.03523484091939671, 0.07763932711843934, 0.05883199202695063, 0.05022880581340619, 0.009844206406601837, 0.037535946550113816, 0.05245464155450463, 0.031471967298005304, 0.04203253026519503, 0.03207650128751993, 0.09812475394989763, 0.0620162890159658, 0.07847893277981452, 0.020896770026800886, 0.017489638744986484, 0.052171614420201094, 0.016920877121655003, 0.04119794237028275, 0.062471172107117515, 0.0514206254322614, 0.06631978880614042, 0.02960493748209306, 0.023057714071390883, 0.053740753792226315, 0.02667833282612264, 0.024706908701253787, 0.011968884450782622, 0.02029896031932107, 0.052216662360089164, 0.04834206455520221, 0.07600218496684517, 0.012664703452693564, 0.02276573366751628, 0.049524248976792605, 0.01200542610604316, 0.022950848198628852, 0.020929090346076658, 0.11602306924760342, 0.03983767304037299, 0.008058560928995056, 0.029978114778974226, 0.038554553142083545, 0.025429609564266036, 0.04288023424201778, 0.15470427434359277, 0.010898054411102618, 0.023582708489681994, 0.03437345428392291, 0.038953341743243594, 0.06227090249636343, 0.027028441628707305, 0.014015536056831479, 0.025155508558132818, 0.048687513518546305, 0.06227314166192498, 0.04296966176480055, 0.05231832047658307, 0.017084051222939576, 0.02745178641219224, 0.035720407364091704, 0.03432741229023252, 0.0081934969473098, 0.08250941721988575, 0.037295226074223004, 0.048654085490852594, 0.036765887335475, 0.05371238763577171, 0.043663199192711284, 0.035528670331197124, 0.0448403047796871, 0.10869290972394602, 0.022603334792490517, 0.030525214171835353, 0.030844003494296755, 0.014666054364559906, 0.033365890849381685, 0.013113032743733908, 0.030180362319307666, 0.08999830644045557, 0.04881439617435847, 0.08942849308784519, 0.03553484160719173, 0.019689678281013454, 0.017014104440542202, 0.01872095249460212, 0.042414168893758736, 0.022101325747956122, 0.03131826215290597, 0.04202653540830527, 0.0023510222714061713, 0.06447561204965625, 0.05194984203470605, 0.054141656029969454, 0.07172743470541068, 0.09098727801548583, 0.02301289513707161, 0.015236246000443186, 0.050268215127289295, 0.0364533235718097, 0.03125684116301792, 0.03019497457093426, 0.017831929127818773, 0.005892524055005717, 0.09295295325240918, 0.05530306031661374, 0.06383678490029913, 0.04249636662591781, 0.062418022459106784, 0.0168126660532185, 0.03495057545868414, 0.009315169615937131, 0.040489232899355035, 0.004500160018713879, 0.03248673338176949, 0.03767472731747797, 0.051860957339938195, 0.03455085387187345, 0.019873832685074637, 0.08606630457299096, 0.027264637972361276, 0.03555893638570394, 0.05553230337266411, 0.0375568861407893, 0.06431652272918395, 0.029700797516852617, 0.03390562135194029, 0.06803135946393013, 0.018414493849767104, 0.03160853264853358, 0.03286675370431372, 0.031324311292597225, 0.023823376379108856, 0.03049689551283206, 0.040734004229307175, 0.013247287682523685, 0.03671470543901835, 0.04186439607292414, 0.017711475591308305, 0.025782764989084432, 0.06320816291762249, 0.03632793030036347, 0.05522431632769959, 0.010261684406681784, 0.05575484250273023, 0.016808101208880544, 0.09630079753696918, 0.0634921637496778, 0.01873320005168872, 0.051626679554049454, 0.011313351769266384, 0.05118508217856288, 0.0362213324489338, 0.020274539843999913, 0.016069761810026, 0.05408686771988869, 0.03074041833834989, 0.053608619275369813, 0.04636744622673307, 0.04073522559234074, 0.02957636776513287, 0.05781151607100453, 0.008062470138871243, 0.0456361720737602, 0.027706203117434467, 0.03359400075195091, 0.026745311017813425, 0.11363830364176206, 0.18664099063192094, 0.14824133685656957, 0.07210663400058236, 0.09476691484451294, 0.09509863704442978, 0.1205984308783497, 0.17417073835219654, 0.17018468438514642, 0.18827955770705426, 0.1549946330487728, 0.164598088445408, 0.08551103222583022, 0.08737394333417926, 0.11432367829339844, 0.17062029029641831, 0.12044114646102701, 0.13073155071054185, 0.07917492650449276, 0.12222593783267907, 0.294467777545963, 0.06927655264735222, 0.2759622276893684, 0.17017027230135032, 0.07928263715335301, 0.09543985194925751, 0.07394735022847142, 0.05608555707814438, 0.22661593130656651, 0.0962727265432477, 0.1453182894204344, 0.14244655280240945, 0.12369656749069691, 0.14455146342515945, 0.06887158937752247, 0.2976217440196446, 0.10323666714664016, 0.1710514450179679, 0.1631650903395244, 0.10545855042125497, 0.15683821269444057, 0.13241130486130714, 0.17464734134929522, 0.10454908957970993, 0.12033844340060439, 0.06697889058185474, 0.07741883037877934, 0.2244880726294858, 0.16731336845883302, 0.08457637737904276, 0.1249292620590755, 0.11864078949604716, 0.1973861354802336, 0.165630968021495, 0.3211433504308973, 0.0930804635531136, 0.1495832891336509, 0.11967149776007448, 0.14697432198694774, 0.1751065602792161, 0.10339572254036154, 0.10541421494313649, 0.10898955844874893, 0.21414896313633236, 0.1533323172479868, 0.08196385470884186, 0.165448021409767, 0.1341406192098345, 0.10691757034510374, 0.14793930734906877, 0.19813377250518116, 0.12801878127668584, 0.10181393527558871, 0.14767400015677723, 0.2062807117721864, 0.10980039422533341, 0.10100418515503407, 0.08924315124750137, 0.17151227886123316, 0.16892170001353535, 0.13866802198546274, 0.10095214151910373, 0.1569521115826709, 0.17569434802447045, 0.0770565876737237, 0.11747102226529803, 0.16343579867056438, 0.16950119606086186, 0.1763400962310178, 0.10884619757000889, 0.2025376276246139, 0.15444739455623285, 0.13281183051211493, 0.2668208953525339, 0.11232766575579133, 0.2158725235079016, 0.12351653857954911, 0.2399251242833478, 0.157488113535302, 0.114652333515031, 0.12635364277022226, 0.12375745922327042, 0.12601920643023082, 0.15163972521466867, 0.1885341169046504, 0.1290519865495818, 0.14154073569391454, 0.21053771834288323, 0.11006676671760422, 0.13525120461625711, 0.12007141272936549, 0.14568680178906235, 0.10865709664566175, 0.21558635814913682, 0.16697059970881256, 0.11498154513537884, 0.13089399199400628, 0.13390397333673068, 0.12525719803358826, 0.1653381394488471, 0.15490863552050932, 0.11604229893003191, 0.15457295067608356, 0.09921833526875291, 0.17509863499019826, 0.14345598220825195, 0.16207453528685228, 0.16814073334847177, 0.14586645072059973, 0.19133000687829085, 0.1828750262835196, 0.07967556999730212, 0.1332769255552973, 0.13735737731414183, 0.11214406775044543, 0.15213686068143162, 0.13739693590572902, 0.3270765149167606, 0.09284567008061068, 0.1349027497427804, 0.15176741193447793, 0.13523543546242373, 0.12823148843433174, 0.08173276603754077, 0.0700337705867631, 0.10171472667051212, 0.224228831540261, 0.06183538479464395, 0.138919202078666, 0.1450789158365556, 0.1426205291811909, 0.17255017959645816, 0.09037473052740097, 0.1652012789355857, 0.08299275128436939, 0.20878667730305875, 0.1081936504425747, 0.08252115587570838, 0.12939920648932457, 0.07255187510911908, 0.14357296164546693, 0.15756974129804543, 0.16933066663997515, 0.15442451435540402, 0.08694238827696868, 0.11735024303197861, 0.11831962530102048, 0.11957989553255693, 0.11425669331635747, 0.12847764736839704, 0.11430520857019083, 0.08623899173523698, 0.1461322464581047, 0.10820728899644953, 0.10957824864557811, 0.0958712984408651], [0.0076618019957095385, 0.03632444602304271, 0.035064145257430415, 0.005137738239552293, 0.02085510967299342, 0.05684621858277491, 0.024320043656708937, 0.04329493109669004, 0.06857043518019573, 0.0223020245321095, 0.04229074676654168, 0.038691434011395485, 0.03731273227770414, 0.016893187803881507, 0.023288992732497196, 0.039662621183586974, 0.013326303933614066, 0.1213066993015153, 0.03161619330889412, 0.043877141284091134, 0.0772590082404869, 0.03130862695564117, 0.06785191409289837, 0.06569214391389064, 0.02096812816203705, 0.05076664998861296, 0.030310345880155052, 0.0249690895434469, 0.052036043123475144, 0.06147943889456136, 0.019988230296543667, 0.044887578314436336, 0.03951522641416107, 0.018422926343711357, 0.04802773999316352, 0.034546545174505026, 0.027317553525790572, 0.04038508455934269, 0.030205396868820702, 0.027117272040673664, 0.03531827697796481, 0.00894244948202478, 0.041969019387449534, 0.0668949286586472, 0.02239840364615832, 0.0778951755325709, 0.029956791816013198, 0.03394565152536545, 0.009823140438779123, 0.035358381790242026, 0.06893204684768404, 0.04892019674714122, 0.06582743022590876, 0.042843274439552, 0.03471961570903659, 0.06728406170649187, 0.03126355526702745, 0.04034010447295649, 0.02791492048917072, 0.03567749680951238, 0.0349349284411541, 0.03722849554781403, 0.03613911096804908, 0.013554159385551299, 0.018300276050078015, 0.015663185323189412, 0.059889583848416805, 0.05973500678581851, 0.022449717856943607, 0.018189323700166175, 0.031357481476983855, 0.06346085614391736, 0.012716373894363642, 0.0414637957832643, 0.01828395389020443, 0.014787099922874143, 0.024278008412303667, 0.04080539629129427, 0.013887225932973837, 0.039686305448412895, 0.026588949408116083, 0.010186355145248984, 0.036939110540385754, 0.0468976263489042, 0.060617923337434015, 0.05243805815864887, 0.021822909259104302, 0.041850343612687926, 0.01270993544520544, 0.016565031305487667, 0.04181599956271904, 0.020234316288094436, 0.03638292556362493, 0.08146829344332218, 0.017584660788998008, 0.0342047263735107, 0.033192806744149754, 0.05969413862164531, 0.007535804828096713, 0.024036960543266365, 0.024043179316712276, 0.05412391912458198, 0.03811088962746518, 0.018485838414302895, 0.0440603966292526, 0.032827391887881925, 0.052308763310845406, 0.05366311581539256, 0.03446259342932275, 0.01949739333109132, 0.03156194782682827, 0.03908354243529694, 0.09538760475282158, 0.025394206999668052, 0.02048294848230268, 0.03167432340394173, 0.03387220689494695, 0.03614413891253727, 0.09376085775771312, 0.10203840823045798, 0.041496524919888804, 0.015252495217802269, 0.05054674696709428, 0.041944887289511304, 0.017912221872912984, 0.02688885001199586, 0.06731859913894109, 0.018763540745047585, 0.0469897985458374, 0.05675008713400789, 0.030714986845850945, 0.023340995656326413, 0.01667012450551348, 0.08447321970015764, 0.025897442496248653, 0.022756293549069335, 0.06735171164785113, 0.040893375141812224, 0.029856860571141754, 0.06799520711813654, 0.05567874140771372, 0.0025958701485901004, 0.04363773038078632, 0.021507543145811985, 0.10147913252668721, 0.05669142099629555, 0.02567736984097532, 0.06105296606464045, 0.03624534919591887, 0.03354217763990164, 0.010955078494069832, 0.01611761549221618, 0.027119416211332594, 0.046659090755773444, 0.027977277857384512, 0.04059965429561479, 0.06855275255760976, 0.046074383559503725, 0.05270254432356783, 0.015650964907503555, 0.03895404402698789, 0.009894629192006375, 0.036834147958351035, 0.050655913073569536, 0.014452782326510974, 0.031405087493892224, 0.04406401661357709, 0.018956663685717752, 0.048665610408144336, 0.05040174742628421, 0.07171749416738749, 0.08041644881346396, 0.015297529586989964, 0.007826849701814353, 0.02354750270023942, 0.10473221939589296, 0.025910433049180677, 0.01943942269177309, 0.010180043073238006, 0.009741342194112284, 0.018664416956848333, 0.025811226140441637, 0.014471635422004121, 0.03621878454993878, 0.03283361405400293, 0.028290136783782924, 0.02271572733297944, 0.06060254094856126, 0.01744678756222129, 0.009793373955679792, 0.021466517222246954, 0.010614439495839179, 0.025968569929578474, 0.09101452119648457, 0.008588832653393703, 0.041509189776011875, 0.0462625582835504, 0.0708431000156062, 0.029429190126912932, 0.08769317370440279, 0.037740131307925494, 0.0014664829608851246, 0.07749871430652482, 0.01992268381374223, 0.05361215105014188, 0.0571752537840179, 0.05617316273440208, 0.06760912069252559, 0.05199763125606945, 0.05132273318512099, 0.02395616568225835, 0.03977380932441779, 0.019708941890192882, 0.03290594249431576, 0.03712149736072336, 0.06649411802313157, 0.011939385140846883, 0.027061642347169772, 0.04115294532052108, 0.03484494112698095, 0.04988907350759421, 0.06494623036789042, 0.014866149252546685, 0.06221013290009328, 0.03079200057046754, 0.039126086580966196, 0.010762204066850245, 0.03083225466044886, 0.06854216741131884, 0.03382142872682639, 0.013867746888925987, 0.03536815269451056, 0.01877485870915864, 0.043165805882641246, 0.020669708460835472, 0.02519439879272665, 0.01819938637449273, 0.011523711195747768, 0.03955859158720289, 0.04020495726061719, 0.03390593008537378, 0.022114623337984085, 0.031936614508075375, 0.055045084695198705, 0.03009441228849547, 0.011737182553458427, 0.054102816685502014, 0.02619213025484766, 0.02573280954467399, 0.028118979718003954, 0.042407621030828783, 0.029498061431305747, 0.03423325877104487, 0.03601541403414948, 0.004803904523474297, 0.0640050344435232, 0.009963230778729277, 0.06408102358026163, 0.07126271285648857, 0.014175386184693446, 0.01613665179216436, 0.03059974785095879, 0.013939250061022384, 0.02292137942276895, 0.032013499311038425, 0.04874625090243561, 0.06181284386132445, 0.0749739601409861, 0.0075971223413944244, 0.031457171841923676, 0.022907445706161003, 0.01761772240778165, 0.04580282705969044, 0.03804847119109971, 0.03482961641358478, 0.042056876101664135, 0.015534736947821719, 0.058790791380618296, 0.06577764611159052, 0.032638236680733304, 0.006619053127776299, 0.013395300766985332, 0.023758255677031617, 0.08426796285701649, 0.062211401760578156, 0.002431519001090367, 0.018915541070912565, 0.03521754166909626, 0.022418759696717774, 0.027481141533436518, 0.029717421624809504, 0.027145068227712597, 0.04160679364576936, 0.02460223788927708, 0.053039772835161, 0.0670075315449919, 0.05991290509700775, 0.03150762431323528, 0.0799337729279484, 0.04824646236374974, 0.03497492129515324, 0.03805357716711504, 0.04852975412671055, 0.05214345521692719, 0.06058102460311992, 0.013620962854474783, 0.038566787128469775, 0.021570495928504636, 0.01384659780056349, 0.035118434844272475, 0.03810804995841213, 0.01939376237403069, 0.03605414481301393, 0.03893503486844046, 0.06308312248438597, 0.019329476270026395, 0.03764980133356793, 0.10117903005863939, 0.021363457930939536, 0.030533410874860625, 0.05267974215426615, 0.03655366533036743, 0.04668400316898312, 0.03469733601169927, 0.03106061222829989, 0.013432220705518765, 0.013385482365265489, 0.04125854233279824, 0.00939918412560863, 0.004934287147729525, 0.009945124071756644, 0.020692927929173623, 0.02280496825863208, 0.013415979969847416, 0.029478438198566437, 0.07675867008843593, 0.025957977997937372, 0.010989628649050636, 0.02740514900402299, 0.04436268737273557, 0.03480262429054294, 0.016234457526089888, 0.04170661971771291, 0.016264625193018998, 0.019970905601180027, 0.04698872306783285, 0.03144004561805299, 0.0763981237209269, 0.009772387715721769, 0.04338557658983128, 0.033541142873998196, 0.05065752798691392, 0.08612695203295775, 0.1059833565460784, 0.12820860823350294, 0.10437904191868645, 0.07758857948439461, 0.18331479839980602, 0.07256710143493754, 0.16695758540715488, 0.22684630751609802, 0.12541198544204235, 0.07272589898535184, 0.19066797383129597, 0.08862203386213098, 0.06642008306724684, 0.08708811045757361, 0.08780328636722905, 0.1678520981222391, 0.1645742990076542, 0.08738295427922692, 0.13773035444319248, 0.13977715532694543, 0.2023708979998316, 0.12245513339127813, 0.11521106639078685, 0.18883943052164145, 0.1735037655702659, 0.13049931531505926, 0.18639078762914452, 0.11318819743714162, 0.13062020311398165, 0.10983050082411085, 0.14273286743887834, 0.2566840164363384, 0.10191698438887085, 0.14098357701940195, 0.13472396933606692, 0.10482734322015728, 0.15023165648537024, 0.10165525307612759, 0.22645169869065285, 0.1194838285446167, 0.13146405640457356, 0.11233734845050744, 0.11363574556474175, 0.18020930646785668, 0.19464304910174438, 0.10119167795138699, 0.11680392734706402, 0.08922545505421502, 0.21520586285207952, 0.15625482185610703, 0.1491489860096148, 0.21147539945585386, 0.10034943278878927, 0.0923482971265912, 0.2667827345430851, 0.1827427933790854, 0.2804592592375619, 0.14796005694993905, 0.13827510949756416, 0.0755560142653329, 0.14063581425164426, 0.08526442545865263, 0.11141462224934782, 0.09096660305346761, 0.06346626406801598, 0.12038322671183518, 0.22615770303777286, 0.09742848202586174, 0.06938045671475784, 0.09651222226342984, 0.167266576683947, 0.1452848512147154, 0.12071085056023938, 0.11339490634522267, 0.12082187245999064, 0.19186319969594479, 0.10825682883816105, 0.05933190270193985, 0.15955926025552408, 0.08598287190709795, 0.14793667463319643, 0.20467631572059222, 0.07458883723510162, 0.1588725692459515, 0.07835562261087553, 0.13245569462222712, 0.16934431876455033, 0.09104368463158607, 0.15163687536759035, 0.1705317414764847, 0.19300355921898568, 0.09349757259977715, 0.16573493315705232, 0.0933015506182398, 0.11001219893140451, 0.07441317808947392, 0.13009566840316567, 0.1038493299856782, 0.11929489725402423, 0.08682610094547272, 0.1497942049588476, 0.15873824645365986, 0.06708656730396406, 0.09056633524596691, 0.08524183702788182, 0.16253653621034964, 0.2776863308889525, 0.19100103953054973, 0.1134508176307593, 0.07503802063209669, 0.1689698759998594, 0.17639684889997753, 0.12916151567229203, 0.1431623258228813, 0.16768827262733663, 0.1486393790692091, 0.16173362572278294, 0.1358257337872471, 0.13834205376250402, 0.17961894028953143, 0.07586790967200484, 0.19028452012155736, 0.1254203449934721, 0.11937861490462508, 0.09821875819138118, 0.1980996693351439, 0.17880148201116494, 0.1696892859680312, 0.1183867866971663, 0.12339544722012111, 0.12031522393226624, 0.11631846268262182, 0.1163537600742919, 0.14560839028230735, 0.06815988756716251, 0.1424939145467111, 0.057331710388617854, 0.148853796135102, 0.2605700136295387, 0.12859560389603886, 0.2159184060458626, 0.20232734962233476, 0.11227258906832763, 0.19586074804621084, 0.16844616910176619, 0.12952681178493158, 0.11778120776372296, 0.1031155079337103, 0.10782428311982326, 0.10301935273621764, 0.08317585395915167, 0.06827013593699251, 0.08554388010608298, 0.13557109316544874, 0.09726175240107945, 0.17364327237010002, 0.1193357314914465, 0.15101502516439982, 0.2143010092633111, 0.11211564391851425, 0.11303153048668589, 0.15325607705329145, 0.12439471217138426, 0.07290244701185397, 0.11455727075891835, 0.08515410244997058, 0.15280050864177092, 0.08397169411182404, 0.15800454653799534, 0.1389758733234235, 0.1609765434903758, 0.10034171784562723, 0.15986206329294614, 0.08841632240052734, 0.4152396284043789], [0.05936961567827633, 0.03323237212108714, 0.027365162935374037, 0.07068789191544056, 0.014729902813477176, 0.05266958109236189, 0.02480650576762855, 0.004822416655120573, 0.04551040900072881, 0.041659658309072256, 0.007909842168114014, 0.04945757273318512, 0.015551031966294562, 0.08935012907854148, 0.023231564921193888, 0.011491615641196924, 0.019997797640306608, 0.038678341678210666, 0.005183840877309973, 0.016702383756637573, 0.016864838610802377, 0.06783830268042428, 0.022318256786093116, 0.01673403232624488, 0.02418989555111953, 0.04413473692589572, 0.07965595354991299, 0.058056521495538096, 0.03683176290776048, 0.018208332858713608, 0.01606714096851647, 0.04262712032401136, 0.006479463631486786, 0.009856303837815565, 0.002384515184011044, 0.024553196770804267, 0.027105830243921707, 0.015571235346474817, 0.03237990143575838, 0.044479710914726765, 0.03473480810810413, 0.01959882413835398, 0.01453039316194398, 0.03556173194998077, 0.06720725154238087, 0.022306935429306965, 0.014435379599620188, 0.024998860267390097, 0.06586528569459915, 0.05478204380986946, 0.05273684087608542, 0.013361101753876677, 0.011838353821076453, 0.0482055195607245, 0.034330825321376324, 0.03659987695781248, 0.009128642883817, 0.03406694644529905, 0.04674260484586869, 0.024491623110537018, 0.00646964438159817, 0.013344374169329447, 0.01068116832591061, 0.02600275113114289, 0.05034994806296059, 0.06973800395748445, 0.07622059181864772, 0.031044659870011464, 0.013212713778817227, 0.06833266293896095, 0.06919778830238751, 0.0638972966532622, 0.03130932245403528, 0.015429279035223382, 0.0306147027627698, 0.049028178810008934, 0.039917570538818836, 0.005070841047979359, 0.031076734220342975, 0.025946822882230793, 0.049743432751191516, 0.02270672656595707, 0.007018285745289177, 0.036561594012060335, 0.004783775358061705, 0.029870254852409874, 0.024046312452160885, 0.054212186352482865, 0.017068863912884678, 0.025956721011815325, 0.01806446986405977, 0.10613645440233604, 0.050787725286292176, 0.02150642017035612, 0.03850979697225349, 0.04868127778172493, 0.0062771355151198804, 0.05615665737007346, 0.013797093581940447, 0.052548520267009735, 0.05232788442767092, 0.04646369981180344, 0.017481469183361957, 0.034063808220837793, 0.02993685645716531, 0.05284235646416034, 0.03724480413698724, 0.020199431106448174, 0.012445327992151891, 0.05255595701081412, 0.06553675260926996, 0.05684468848630786, 0.04642876543636833, 0.013076384219207933, 0.03370101929509214, 0.02793990245221981, 0.02914777790595378, 0.013040920586458274, 0.016325849407751645, 0.03800117051494973, 0.047456257444407256, 0.037714916946632523, 0.06169143359043768, 0.05020525047023382, 0.033833842524992566, 0.047497492017490525, 0.007385849437144185, 0.0020640910162390874, 0.01817754433224244, 0.03406087016420705, 0.01997916676503207, 0.014662122254126837, 0.02432546854418303, 0.02273388153740338, 0.003236487994269867, 0.027534046908840537, 0.025676061964726875, 0.011411205848811992, 0.011796393215523233, 0.0320920804515481, 0.03765878852988992, 0.036311699742717404, 0.023752320191955993, 0.0685587100950735, 0.011088982290987457, 0.02507277308697147, 0.01892213473495628, 0.03797515208965965, 0.028623297477939298, 0.04068191309592553, 0.010033137697194303, 0.008288801431522837, 0.030963517259806395, 0.02088494485776339, 0.03794051626963275, 0.02914539285536323, 0.008974827476777136, 0.02866326319053769, 0.04195715859532356, 0.05120486147435648, 0.010464004041360957, 0.07646958702909094, 0.05759616941213608, 0.04523984994739294, 0.008774873384806727, 0.06512478685804776, 0.0900274630902069, 0.02403072819912008, 0.0532594146206975, 0.048195752049131055, 0.021249411461342658, 0.02937967742660216, 0.09378370403179101, 0.04401935883132475, 0.04061802563124469, 0.04212460746722562, 0.07718866451510362, 0.08177957138312714, 0.013122187877473022, 0.0914042309990951, 0.021951084524126988, 0.020739685777308683, 0.03333452556814466, 0.025906623075050966, 0.08740519665713821, 0.061151367213044844, 0.023008320114708374, 0.03846220452604549, 0.0635661104960101, 0.05999413252409015, 0.04041099102635469, 0.03548891496445451, 0.06600243119256836, 0.023666948612247194, 0.018172840388225656, 0.02507076631965382, 0.052863533542092354, 0.022933693137019873, 0.003698668941589338, 0.014845092614580477, 0.03997784819720047, 0.01545376906038395, 0.018005101442603127, 0.0571789178731186, 0.02920933799552066, 0.05207311827689409, 0.04924667047868882, 0.056535798989768536, 0.03665661605607186, 0.030118272972426245, 0.037706665960805755, 0.04416528117976018, 0.04010897508955427, 0.06166857374565942, 0.04496674978041223, 0.011320087077495242, 0.010618615030710186, 0.025154400849714875, 0.029120572044381073, 0.03471701013456498, 0.01225720246189407, 0.043347246146627834, 0.02448582842147776, 0.06776042043098382, 0.055158023456377644, 0.04728069668635726, 0.03279780097571867, 0.01398467882868967, 0.0176763597077557, 0.016805451529632722, 0.06944176913904292, 0.060245122627488205, 0.026823018544486592, 0.026161048261980926, 0.01670068402641586, 0.02178778828653906, 0.022988939458238225, 0.059921176438885074, 0.05585318258298295, 0.020846505848956958, 0.04198766892243709, 0.026504807673128586, 0.06123807041772774, 0.029811605678073, 0.03292521967419556, 0.007018800583734576, 0.029171451992754425, 0.036128512251057794, 0.056603533748005114, 0.03366624437538641, 0.02561574529058167, 0.09101430406527859, 0.0034497252573990928, 0.007868972307603275, 0.06776046114308493, 0.010030829829962125, 0.05585834623447486, 0.043041491481874666, 0.03761233602251325, 0.05139789450913668, 0.030041306745260954, 0.03893533003117357, 0.02448361300464187, 0.01594755256415478, 0.029844165180942843, 0.08565028118235724, 0.06704755154039178, 0.04812218528240919, 0.013769832589397473, 0.09107714997870581, 0.05874968572918858, 0.0901900672220758, 0.040831692915941985, 0.01450396591930517, 0.01987798701572631, 0.0414561113741781, 0.0488444518830095, 0.05557749719758119, 0.030744279202605997, 0.008108384907245636, 0.030200921930372715, 0.030812319301600968, 0.054631853476166725, 0.02915591693350247, 0.03525725293106266, 0.03014286986685225, 0.02573310979641974, 0.025718784225838523, 0.07715213897504977, 0.010956317668647637, 0.033165923186710904, 0.04452353070623108, 0.06764763434018407, 0.02560899725982121, 0.01235561294015497, 0.06408635008015803, 0.047209545504301786, 0.03513711830601096, 0.05230648682585784, 0.040259433444589376, 0.009168522931369287, 0.03613612541396703, 0.018832169473171234, 0.013958301628008485, 0.07440669808004584, 0.025484048428812196, 0.027861711469345858, 0.11348083601998431, 0.02872570537562881, 0.09535599859165293, 0.07570525125733443, 0.06683248986623117, 0.05542925086670688, 0.034874016352530034, 0.03621912042477301, 0.09312216631535973, 0.042091203188257556, 0.01557472301647067, 0.06363167054951191, 0.02604033348948828, 0.025039324703227197, 0.05843656217413289, 0.03232937093291964, 0.02421554926383708, 0.06475248147866555, 0.04363093824524965, 0.04743291923244085, 0.031345525689955266, 0.04605464158313615, 0.05445524438151291, 0.015519944884415184, 0.04056465206667781, 0.047638620516019206, 0.03768869835351195, 0.03344636849526848, 0.02403981039034469, 0.04275598430207797, 0.08724875362323863, 0.032737221369253736, 0.021281212701329162, 0.008003018596874816, 0.067157989900027, 0.02774127319987331, 0.03275868343189359, 0.030219405224280696, 0.02928300654249532, 0.016308919959036366, 0.01975074812902936, 0.013417730590195527, 0.009709407791628369, 0.02987968988184418, 0.03963136446795293, 0.11850015632808208, 0.2017336721931185, 0.11793803077723299, 0.26075560652783936, 0.18948919565549918, 0.13695964722761086, 0.19875332926000866, 0.10919567024601357, 0.1324562103088413, 0.11251137232674019, 0.10396101684974772, 0.13545125031045505, 0.08815360721200705, 0.22093045924391064, 0.10879491389329944, 0.15141557795660837, 0.08349279766636235, 0.1645912081003189, 0.15020338871649333, 0.07927570252546243, 0.08557612409016915, 0.10740801545658282, 0.1547507404216698, 0.12901074519114836, 0.08065937113549028, 0.1774466104273285, 0.0873780891831432, 0.1295017467013427, 0.12877222656139306, 0.17849527272794927, 0.10774907429835626, 0.16613919075046266, 0.11443187748747212, 0.1539020695324455, 0.12411283515393734, 0.12272205549691405, 0.11483718002481119, 0.06177507660218647, 0.19465149007737637, 0.10208549177540199, 0.08416521229914256, 0.10480018824871097, 0.1629471584622349, 0.07955966943076678, 0.11243023310921021, 0.14417446936879838, 0.11116484672363315, 0.15882911586335727, 0.20752137234168394, 0.09541943483054638, 0.10711769067815372, 0.06322862753378493, 0.0840249794668385, 0.10750730548586164, 0.18276112739528927, 0.13488740128065857, 0.08569963103426353, 0.11271257831582002, 0.10307567792811564, 0.08470046786325318, 0.04290695495105215, 0.1487239245325327, 0.09935189810182367, 0.08920788099723202, 0.12807636175836834, 0.10631061398557254, 0.2538345493376255, 0.1475904317838805, 0.1193131362753255, 0.13524053804576397, 0.1957404302167041, 0.14244982334119932, 0.23891882970929146, 0.09826723273311343, 0.11772625999791281, 0.27309308307511465, 0.12236361258796283, 0.08942751599741833, 0.17441437313599245, 0.08562071741159473, 0.14027842985732214, 0.12754804082214832, 0.06617536941277129, 0.09335598948278598, 0.05907830023872001, 0.14624370262026787, 0.19071551199470246, 0.12404856431697096, 0.138810663617083, 0.19968577208263533, 0.12915915437042713, 0.1515720888440098, 0.12523225508630276, 0.23003865193043435, 0.10148002140756164, 0.1621377476091896, 0.15709837659129075, 0.13470898728285516, 0.14442681654223374, 0.129254407116345, 0.1526162049600056, 0.1628393256770713, 0.1416920218616724, 0.13702633364924363, 0.09104590344109706, 0.15802339624081338, 0.12673592939972878, 0.07654364912637643, 0.09843350095408303, 0.18838184007576533, 0.11304485012910195, 0.16912017150649003, 0.22882920397179468, 0.06654354929924011, 0.11030796556068317, 0.13223628353859695, 0.09901396052113601, 0.08614219871482678, 0.1133839480046715, 0.13246481413287775, 0.11199278158268758, 0.12452309099691254, 0.19045392317431314, 0.12128307271216597, 0.0874046470437731, 0.11837322956749372, 0.126238291817052, 0.07996079219239098, 0.16044321496571812, 0.07710038710917745, 0.1444476204259055, 0.18129600744162286, 0.061705771035381725, 0.10691235241081033, 0.16382170867707047, 0.1324008418513196, 0.19349059808467114, 0.10968296695500612, 0.16387749782630376, 0.21716547198593616, 0.11601878090628556, 0.16512881139559404, 0.15615590502108845, 0.1707228033670357, 0.16422299428709916, 0.10488986343677555, 0.14329599722155503, 0.1073416004489575, 0.18713685045284884, 0.16453019423144205, 0.14982003000165733, 0.11334466761244194, 0.19478560930916242, 0.08795752416231803, 0.11615783987300736, 0.08965103900326149, 0.1678393009517874, 0.1321746182761022, 0.1318380106240511, 0.10605431095297847, 0.12003502968166556, 0.17995246739259788, 0.0904462549037167, 0.14761169707136496, 0.06393746592636619, 0.1532074532338551, 0.26947103600416866, 0.09879576401518923, 0.14259398489126138, 0.2354294498051916, 0.10220031347125769, 0.08882547223142215, 0.2311384757714612, 0.11968015586691243, 0.09618010651320219, 0.1546478880835431], [0.00810910330619663, 0.014271201266508018, 0.012606808300396162, 0.020578964580116526, 0.0547028010977166, 0.04344760826123612, 0.02067533690881516, 0.016552405465128164, 0.029059347829648426, 0.008217779171120907, 0.02976066805422306, 0.035099703885082684, 0.026003636619342223, 0.03208038590050169, 0.035808203010154624, 0.07954282819160394, 0.04565360703106437, 0.015797475885067667, 0.02972742323098438, 0.037206853673394234, 0.03807261346706322, 0.04248766441430364, 0.01569442846812308, 0.05089736636728048, 0.03120804770982691, 0.021825100927214538, 0.06756412703543901, 0.004969085816160909, 0.10495010377573115, 0.04004921651046191, 0.05762861695672784, 0.04331052383141858, 0.019471425795927644, 0.05815622543117829, 0.015219421724655798, 0.03841185722766178, 0.03594467675845538, 0.014001995890534349, 0.01102219578543944, 0.08764307067862578, 0.06700644588896207, 0.037540489342063665, 0.02674152309607182, 0.03552679757454565, 0.029764206614345312, 0.11190716403403453, 0.05557479662820697, 0.07805816642940044, 0.06218950543552637, 0.04067179274612239, 0.0602545135521463, 0.051454070423330577, 0.034811703089092455, 0.048377640146229944, 0.05549534696287342, 0.020383444714492986, 0.061425502145929, 0.0785622772361551, 0.0241697294903653, 0.029501416786972965, 0.03166913600372417, 0.035000464745930264, 0.09681995825043746, 0.018322823768747703, 0.058725916647485325, 0.05120849163670625, 0.023905051639303565, 0.05316777168107884, 0.15343740875167505, 0.04300489808831896, 0.006034758565614798, 0.012115170663621808, 0.04511686547526291, 0.05406392305823309, 0.039696819348526854, 0.058340630893196375, 0.0369453123504562, 0.08480475191026926, 0.0366219055971929, 0.01834590413740703, 0.008624714433348604, 0.035020966681518724, 0.009566369217022188, 0.03568403110174196, 0.023822326346167495, 0.03676933090069464, 0.05420259525999427, 0.03150208407480802, 0.036533421238086054, 0.07329253000872475, 0.021189033719045774, 0.03910458380622523, 0.030470792270664657, 0.06795597422335829, 0.07574863000107662, 0.0675363681678261, 0.10987186431884766, 0.05720067849116666, 0.016475447719650607, 0.03495036172015326, 0.07318790669419936, 0.048751424731952805, 0.035392403536077054, 0.022900802848328437, 0.0368768854865006, 0.02794960550298648, 0.03544502053409815, 0.0364201398167227, 0.02854717941954732, 0.028361084405332804, 0.018766680665846382, 0.030534581347767795, 0.041792946335460456, 0.020943242890228118, 0.04467858274334243, 0.042425412219017744, 0.07831833032625062, 0.03116105237443532, 0.03274334514779704, 0.005154139703206185, 0.03154368844947644, 0.07004501391202211, 0.03233344214303153, 0.03944943565875292, 0.07293699801500354, 0.05316249607130885, 0.036877452063241174, 0.0027011476132819162, 0.05834094301930495, 0.03628399855058108, 0.009868645541636007, 0.025433407664032917, 0.02198510118094938, 0.04967122644718204, 0.06429091481758015, 0.06240224651992321, 0.06807533531848874, 0.011254813705038811, 0.03108427274440016, 0.012278074199067695, 0.0238291269633919, 0.051843990571796894, 0.03450695265616689, 0.0077367733299200025, 0.05103637444387589, 0.009477141013901149, 0.004774763564845281, 0.06464228060628686, 0.013065062862421786, 0.06971240283123084, 0.04648300752575908, 0.05870364712817328, 0.07960714652602162, 0.03862914788935866, 0.022307929483109286, 0.005482810191876654, 0.04219185707292386, 0.030078677061413015, 0.03219179456521358, 0.061221880572182794, 0.029676109020199095, 0.0189271966061954, 0.027855718308793645, 0.01929210256119924, 0.049859190825372934, 0.026950425368600657, 0.004373087797180882, 0.06606212870350905, 0.07154881036175148, 0.056523602322808335, 0.0655613766450967, 0.05484626375670944, 0.03747613029554486, 0.017239702067204883, 0.01803003590820091, 0.05096971855631896, 0.03781911278409617, 0.03255488204636744, 0.014870116986068231, 0.058241822623780796, 0.040189574871744425, 0.05556133110076189, 0.020721741918740526, 0.03435582594413843, 0.0123227268923074, 0.009333934501877852, 0.03778981364199093, 0.06993723540966, 0.01589778541321201, 0.04493582893961242, 0.017033312070582594, 0.021785932493263056, 0.03431654894458396, 0.08040572796016932, 0.08004853355565242, 0.0033014657799088, 0.082324842124113, 0.01984213152900338, 0.045129425158458095, 0.04162369595308389, 0.05033713053645832, 0.03652504472328084, 0.039383882390601296, 0.014644207233296973, 0.03574499408049243, 0.013739580953759807, 0.0321110556833446, 0.05083631517897759, 0.07924235931464604, 0.027341229308928763, 0.052900014977369986, 0.044642820555184565, 0.003994818519069148, 0.02256841229141823, 0.04784334470917072, 0.06630110195172684, 0.03335589602855699, 0.06651569543672459, 0.05608757911249995, 0.01872521878353187, 0.022352049526359354, 0.004682496797093856, 0.021953557784269963, 0.021053123154810498, 0.031304891620363505, 0.06394869568092482, 0.051613553294113705, 0.006912825288184519, 0.012382398958184888, 0.0601447672982301, 0.01679674762168101, 0.05619109980762005, 0.014732021539072906, 0.02655247475818864, 0.06603840033390693, 0.0378894327607538, 0.052989289829773564, 0.036281952767499855, 0.04799226278971348, 0.04663521989381739, 0.046096140784876685, 0.0294411560919668, 0.015097631474158593, 0.011049062379502823, 0.018385223545400158, 0.05035575632272022, 0.055262443210397444, 0.03945912853149431, 0.03248422280220049, 0.045228857680090835, 0.08164407472525324, 0.021032685680048804, 0.027866235601582696, 0.06159029794590814, 0.02865411653848631, 0.014426948802013482, 0.042799695527979305, 0.0698578128857272, 0.026289282898817743, 0.060990377994520326, 0.09083441764648471, 0.024186625012329648, 0.021987720326121365, 0.051239846739917994, 0.003634014308253037, 0.0322360621898302, 0.014767790512580956, 0.06581493839621544, 0.004009294639607626, 0.019364442875874893, 0.04615212331659027, 0.05729844181665352, 0.045137343662125726, 0.06533579767814704, 0.04469344944560102, 0.019121133788887943, 0.023463605237858634, 0.05290029996207782, 0.04435662126966885, 0.08934069744178227, 0.06210184549646718, 0.01772721081839076, 0.024957157505143965, 0.02415082889742085, 0.01890892705081829, 0.07754649674253804, 0.008029694352964205, 0.020880095028717603, 0.04838292932670031, 0.024644768464245966, 0.05419206439650484, 0.020143212783815603, 0.03382884172190513, 0.024079063641173497, 0.007253507118938225, 0.036002501512744596, 0.005349285950485084, 0.06179054720061166, 0.04896265607593315, 0.03665861773437687, 0.06501511524298362, 0.05537472379260829, 0.02788388090474265, 0.043874444107392004, 0.0022333905924045083, 0.06125082687607833, 0.031916051504335234, 0.03600225045478769, 0.018521763450865234, 0.019528110611385534, 0.02269004308618605, 0.0553574007935822, 0.08370441916797842, 0.014250349885384952, 0.027169958588534167, 0.02015047480485269, 0.023263004841282964, 0.004547092589616243, 0.0362851927722139, 0.056619458964892795, 0.05147854857412832, 0.02102146271084036, 0.03392461354711226, 0.05362971832177468, 0.03224743104406765, 0.03880495631269046, 0.04877071887520807, 0.0449470858355718, 0.0547588277342064, 0.05316619069448539, 0.0321743630005845, 0.07362864233021225, 0.050690667637224705, 0.02570897769848151, 0.04772064182907343, 0.02228777699305543, 0.026086165137322884, 0.07863430372838463, 0.027028765629178712, 0.02198025644091623, 0.07094935859952654, 0.01922053747278239, 0.023446367055709873, 0.032687386364809105, 0.0416765538310366, 0.02110679866746068, 0.07493811992130109, 0.0264884091780654, 0.03448902236829911, 0.027985610267413513, 0.026178639282339385, 0.04365345882251859, 0.07621123482074056, 0.09809320207153048, 0.08026258421263524, 0.14509003024016107, 0.18905239552259445, 0.11150138652218239, 0.09481165744364262, 0.11096803764147417, 0.11204284389636346, 0.11094240258846964, 0.10782004906130688, 0.15813747154814856, 0.12981172863926205, 0.1997644007205963, 0.11561187702630248, 0.1155458419982876, 0.17230871612472193, 0.22715665586292744, 0.13966112583875656, 0.1548718317810978, 0.14792474598756858, 0.07579723346446242, 0.08965979210500206, 0.12241391917424542, 0.14979189793978417, 0.13735967076250485, 0.11076433464352574, 0.11432280976857458, 0.20141566997127874, 0.13795463740825653, 0.14406175113150052, 0.1927752728973116, 0.23301704068269047, 0.11116615629621915, 0.17118575423955917, 0.13310269133320876, 0.12887522817722388, 0.10260612490986075, 0.11580843505050455, 0.17517943494021893, 0.22197709951017583, 0.1637229004076549, 0.1536243044372116, 0.08246793837419578, 0.18845687247812748, 0.20706336120409624, 0.0972113236784935, 0.12495108374527522, 0.13000626462910855, 0.24555954337120056, 0.12644673777478083, 0.12657935065882547, 0.21120113560131618, 0.19660892789917334, 0.1449166238307953, 0.12238809413143567, 0.10300539527088404, 0.14633227858160222, 0.17646635802728788, 0.1124406350510461, 0.18272991478443146, 0.12149469421378203, 0.19515418953129224, 0.08760281998131957, 0.1690332240292004, 0.14364249791417802, 0.06621095178914921, 0.11346932128071785, 0.12101340932505471, 0.12685337024075644, 0.12006640514092785, 0.06682108369256769, 0.1731985876602786, 0.12225998671991484, 0.1346206148820264, 0.11219085273998124, 0.0799164092168212, 0.1542034883584295, 0.079040963335761, 0.13062894264502184, 0.11882798373699188, 0.1774514958794628, 0.09710864097412143, 0.17314173999641622, 0.11413366134677615, 0.1279702524521521, 0.25667144996779306, 0.06827030557074718, 0.1221191364207438, 0.1398541419101613, 0.1521936133503914, 0.19841858079390867, 0.23977443522640637, 0.11195071919688157, 0.22194598189422063, 0.10696308647415467, 0.1450890124376331, 0.1321639245642083, 0.09604583121836185, 0.10213249389614378, 0.2825722444270338, 0.19526526571384498, 0.15967750176787376, 0.13624117363776478, 0.1373697402221816, 0.07494681874024016, 0.14353626647165843, 0.14162848384252616, 0.13164008195911134, 0.09963393796767507, 0.08785297548664467, 0.11492091124611241, 0.15557019359299115, 0.10233325883746147, 0.13537433158074105, 0.08080898132175207, 0.1300828983741147, 0.10120874310710601, 0.09468359074422292, 0.09993862733244896, 0.10459564386733941, 0.21018323807844094, 0.09104257183415548, 0.13406785311443464, 0.178250023030809, 0.14056595228612423, 0.11283425321536404, 0.11916020805282251, 0.09764393046498299, 0.09724221737789256, 0.06561973744205066, 0.08672860224864312, 0.09843362987573658, 0.14072681936834538, 0.08772718187953744, 0.16141186441693986, 0.214616650183286, 0.06519262000386204, 0.09403288244668927, 0.1249811157052006, 0.16118007685456956, 0.09743497560599021, 0.0987275576751147, 0.12358298072857515, 0.12546309269964695, 0.09898692090064287, 0.17047634587756225, 0.10038411949894258, 0.12496252384568964, 0.15178757799523218, 0.12359610359583582, 0.1292347160301038, 0.14094260707497597, 0.10069275115217481, 0.10077332040028912, 0.09138508274086884, 0.1182475241699389, 0.072255511369024, 0.17817627984498227, 0.15095620974898338, 0.0763985240565879, 0.16571593417653016, 0.08400999741362673, 0.10086461728704826, 0.11665873442377363, 0.0836967449369175, 0.12530958093702793, 0.11925331662808146, 0.16692747202302727, 0.1630975218223674, 0.12712969684175082, 0.14787932485342026, 0.09340636392257043, 0.16038039619369165, 0.10733716282993555, 0.12885359648082936], [0.012614223839981216, 0.02651840721123985, 0.05215471889823675, 0.01655074644700757, 0.032437414063939025, 0.019404795353433917, 0.04236608450966222, 0.0493256010647331, 0.009996829288346427, 0.04548745076837284, 0.058876157871314456, 0.024885107264188782, 0.04491077742672392, 0.026810073792668324, 0.03921869643298643, 0.012724080355837941, 0.03895067849329539, 0.04798659702230777, 0.02766045628647719, 0.022835215653425882, 0.007161507948434779, 0.014189111251783158, 0.07541401724198035, 0.013617027351366622, 0.014013119623996317, 0.055466044428093095, 0.025054842799103687, 0.04904152559382575, 0.07658963344459023, 0.0310979079055999, 0.03367688041180372, 0.04670440671699388, 0.04411219259990113, 0.04806048948583858, 0.017392664216458797, 0.00524295145545953, 0.052090933213808706, 0.02756733074784279, 0.06206575421882527, 0.015278006438165903, 0.06863256184650318, 0.051677023459758074, 0.028618347564978257, 0.042600871196814945, 0.04170884531257408, 0.03707657155713864, 0.05162988563201257, 0.07994480590735163, 0.024144616909325123, 0.0403621840024633, 0.017695757327601314, 0.02732011499548597, 0.14667426023100102, 0.03830440442210861, 0.05384101073390671, 0.05626379465684295, 0.09110912254878453, 0.020287175862384692, 0.029768070871276513, 0.013950672349892557, 0.03234083817473479, 0.025769670959562063, 0.019918583765892044, 0.022701486579275558, 0.030558889864810874, 0.02463927402693246, 0.05648588595379676, 0.01337713553636734, 0.0369334142389042, 0.10847505927085876, 0.03107970281104956, 0.06993968492107731, 0.03300076437049678, 0.02026647036629064, 0.011252841712640864, 0.0044033288307088825, 0.0785316549507635, 0.03727889373632414, 0.05116070920069303, 0.04051948877583657, 0.036632270219602754, 0.041635353184704266, 0.015490250495661582, 0.025981792880754386, 0.023302161400871615, 0.043850705559764586, 0.02009311823972634, 0.029609829719577516, 0.03367964204932962, 0.027547329231830578, 0.02607994806021452, 0.02296383196621069, 0.003476529511057639, 0.029211465202804123, 0.03417402605659195, 0.0455174929063235, 0.05358008687783565, 0.07173200124608618, 0.04854935021804912, 0.042080818209797144, 0.018466238930289234, 0.022264233524245874, 0.00988038080478353, 0.05091015335970691, 0.02653661909114037, 0.05588534853554197, 0.04742813556055937, 0.029901192656585147, 0.005606399408342051, 0.048304982616433075, 0.04304993924285684, 0.023407137553606714, 0.02935819500791175, 0.020545229515326873, 0.01901806771223034, 0.03805362466456635, 0.048505265797887526, 0.007278294003169451, 0.020424299307965806, 0.004627432832161763, 0.0040250807568164805, 0.012373667060663658, 0.01000562310218811, 0.023959400597959757, 0.030241515287863355, 0.04160866640242083, 0.010663664666935802, 0.03608873652826462, 0.018231123153652464, 0.05770649242081812, 0.010414512545269514, 0.0330776661368353, 0.0846431791516287, 0.021133366706115857, 0.058537283912301064, 0.08226034737059049, 0.03622169207249369, 0.04952446950067367, 0.0569174104769315, 0.06517805864236184, 0.014352337091362901, 0.04077034656490598, 0.06742162111082248, 0.03821945183777383, 0.08386102505028248, 0.02839351668288665, 0.05442480190790125, 0.018833324679040482, 0.04187480140743511, 0.0334230133199266, 0.022607311007699797, 0.006000129955022463, 0.020107825486255542, 0.05384788768632071, 0.023318653194499866, 0.024994453182443976, 0.04690474078857473, 0.03070058154740504, 0.023568900302052498, 0.023883915273472667, 0.01069120894784906, 0.016003865881689956, 0.05990626223917518, 0.0489972715399095, 0.08733122276940516, 0.04507301175700767, 0.07755724473723344, 0.016830647231212685, 0.05104772972741297, 0.016434308141469955, 0.035119897087237666, 0.017939912887024026, 0.030314647792173282, 0.04386384878307581, 0.05018490120502455, 0.026915499474853277, 0.06690889969468117, 0.06509098902876888, 0.01825556398502418, 0.03874894663957613, 0.03494530324158924, 0.007419235056399235, 0.024838686987225498, 0.04318579891696572, 0.04211106730092849, 0.0795869736799172, 0.02633571165746876, 0.006942236812652222, 0.015141486888751388, 0.02919952298647591, 0.0329857958879854, 0.011582932884006627, 0.08565532948289599, 0.04952911068020122, 0.015521900761606438, 0.005906464981048235, 0.03489770061735596, 0.07291353427405868, 0.05424160423821636, 0.012352528150326439, 0.060109639540314674, 0.033260904518621306, 0.05302184933264341, 0.043745793867856264, 0.014418969230194176, 0.04435844313619392, 0.03655600627618177, 0.0401864773593843, 0.03632243416671242, 0.0417704868263432, 0.017634378746151924, 0.033488349456872256, 0.046220187164310894, 0.017775980522856116, 0.03200776229745575, 0.025237959044586335, 0.05443915292354567, 0.022046898757772784, 0.017120344364749532, 0.029799120633729866, 0.028496123052069118, 0.07386021276137658, 0.04663823598197528, 0.06671865204615252, 0.024904806832117692, 0.06316191397075142, 0.06074240058660507, 0.024461436783894897, 0.10833526748631682, 0.01175724683395986, 0.015231309658182519, 0.04588544548356107, 0.02656084788031876, 0.058106393819408755, 0.043369251037282605, 0.05578552585627351, 0.01228642017979707, 0.013680038657704634, 0.010162340942770243, 0.009256848682915526, 0.050723854784986804, 0.03142471411930663, 0.014933972220335687, 0.06943410847868238, 0.022662385998825942, 0.0713615957647562, 0.01895670609415642, 0.04042023606598377, 0.03999524244240352, 0.013547064453762556, 0.022281237611813203, 0.07126928786081926, 0.01451343996450305, 0.03950726719839232, 0.01451172327090587, 0.05888413744313376, 0.05631558723481638, 0.04684084993121879, 0.024620424324114407, 0.04093918643359627, 0.018531466501631906, 0.02301934121974877, 0.00839396333321929, 0.08324116974004678, 0.08034054788627795, 0.044119083123015504, 0.007063030464840787, 0.005824910584903721, 0.017386900061475377, 0.029161596271608557, 0.042649732503507815, 0.07591450467173542, 0.04755174428490656, 0.03384408501109906, 0.022801585761564117, 0.02576841736611511, 0.02683697600982019, 0.05326035439169832, 0.017612741960744773, 0.023520410493282334, 0.016290160162108283, 0.04253232219655599, 0.023793766807232584, 0.023076760549364344, 0.027242032578215003, 0.005311391466031117, 0.00965581794402429, 0.014319716520341379, 0.06365237943828106, 0.05345948745629617, 0.020139816716047268, 0.09005936102143355, 0.01815601611243827, 0.016401489098955477, 0.03109307334359203, 0.019552363149289573, 0.03326089773327112, 0.040480086247303655, 0.035581518031124554, 0.031231976247259548, 0.0331319387603019, 0.06030947488865682, 0.032930709022496424, 0.05327795559008207, 0.005753043548403574, 0.0532372265255877, 0.009572062973997422, 0.022880451886781623, 0.021658573166600296, 0.04239030142447778, 0.04336324260969247, 0.059515154654426236, 0.052490305355084796, 0.04840402498043009, 0.056748540074165375, 0.011425613691764218, 0.04336675402841397, 0.004887786718817162, 0.043078010236578326, 0.011094648906561946, 0.039080794368471415, 0.020979030523449183, 0.017211205292759196, 0.05759978600378547, 0.05414767463558486, 0.03767472053212779, 0.018479370279237628, 0.01830064076265054, 0.017454198860962476, 0.04031136851491673, 0.07016010023653507, 0.022812611955617155, 0.06174174017672028, 0.03197399500225272, 0.09516661946794816, 0.03798792211871062, 0.060785541843090735, 0.02721522535596575, 0.024947369637499963, 0.0186149822880647, 0.09157514039959226, 0.02199811378626951, 0.027944874417568957, 0.011631967217129256, 0.039154222035514455, 0.04451780726334878, 0.06597616510199648, 0.0824587917221444, 0.07744734242026295, 0.043843614868819714, 0.009377071517519653, 0.10463322113667216, 0.15458957478404045, 0.11613398258175169, 0.10286532528698444, 0.07805596119058983, 0.10244953938360725, 0.12858748861721583, 0.1280974777681487, 0.0977824330329895, 0.08398721220770053, 0.12537286111286708, 0.13234233856201172, 0.16296290047466755, 0.0968158734696252, 0.12860551050731114, 0.1034492114558816, 0.0621310021462185, 0.10350651373820645, 0.18101225766752446, 0.07333991889442716, 0.10708236614508287, 0.15939980452614172, 0.20589918510190078, 0.13587015068956784, 0.18935392291418143, 0.11936334786670548, 0.10948555397668056, 0.13637092310403073, 0.0966809739225677, 0.20420930720865726, 0.09994277996676308, 0.21306231644536766, 0.09950973891786166, 0.16896904818713665, 0.20342197588511876, 0.07062372964407716, 0.075631372364504, 0.24909446654575212, 0.08566036421273436, 0.180410858509796, 0.12792019013847622, 0.223802100867033, 0.11869451589882374, 0.12754144546176704, 0.1345660335251263, 0.20260636322200298, 0.1668122432061604, 0.1522234688912119, 0.15683746630592005, 0.11695882332112108, 0.14064682008964674, 0.18058256858161517, 0.17427726835012436, 0.21870713068970613, 0.1409561370632478, 0.12260048916297299, 0.16868360207549163, 0.17775181547871657, 0.11485380413276808, 0.15280652046203613, 0.13232879500303948, 0.10363690781274013, 0.09192274710429565, 0.06859111692756414, 0.10017462859728507, 0.13725001950349125, 0.12339894846081734, 0.14398538880050182, 0.1017969244026712, 0.07703840293522392, 0.2702194872711386, 0.09264421303357397, 0.15034509396978787, 0.1889781230794532, 0.10747137705662421, 0.10796689082469259, 0.19390018896332809, 0.11825931710856301, 0.11191359654601131, 0.13741015376789228, 0.1259984839707613, 0.11054220941982099, 0.18625722479607376, 0.07372263300099544, 0.09523255271571023, 0.08999454735645226, 0.0991821422108582, 0.13878158160618373, 0.10638136483196702, 0.2529242810394083, 0.08177769184112549, 0.09173764953655855, 0.11697464675775596, 0.13380820490419865, 0.10671666969678231, 0.11961125742111887, 0.16778305039874145, 0.18432700979922498, 0.13887589797377586, 0.17215042747557163, 0.16207264895950044, 0.1801746604698045, 0.13352687071476663, 0.09027564405862774, 0.15140412428549357, 0.1408126676189048, 0.16289833108229296, 0.07424589885132653, 0.14925322255917958, 0.15094170267028467, 0.2594644086701529, 0.10918011143803596, 0.07978653761425189, 0.21836748320077146, 0.10291649361274072, 0.08530993480235338, 0.2136213750179325, 0.09872742875346116, 0.09859563011143889, 0.09163580821560961, 0.11585186129169804, 0.14812776366514818, 0.13963977912706987, 0.1514841914176941, 0.09679636558783905, 0.14260252086179598, 0.10501022876373359, 0.06208053271153143, 0.18660862451153143, 0.04351176374724933, 0.12128391409558908, 0.1056599531854902, 0.12163801438042096, 0.1790553762444428, 0.11927489404167448, 0.1739774780081851, 0.17701222587909016, 0.10320490492241723, 0.13430873304605484, 0.30039697938731735, 0.09531179882053818, 0.06530676995004926, 0.1213409381785563, 0.13187267019280366, 0.10582505432622773, 0.12816081222678932, 0.11829202249646187, 0.12105621131403105, 0.12541255541145802, 0.1575256772339344, 0.14654015456991537, 0.12948019642915043, 0.1356932023274047, 0.12263354738908154, 0.13437650512371743, 0.15199822240642138, 0.17124891227909497, 0.1223280844943864, 0.06968931906989642, 0.21024190421615327, 0.13745204651994364, 0.19958802232784884, 0.1126894877691354, 0.10441314508872372, 0.1941415574401617, 0.23914323481065886, 0.09684300129967076, 0.12157530417399746, 0.10175558126398496, 0.13548649341932364, 0.1154579445719719, 0.133195447070258, 0.10153615660965443, 0.1336153923932995, 0.11063233922634806, 0.12417277693748474, 0.17170642130076885], [0.027770641891817962, 0.03878685299839292, 0.03887131364483919, 0.05953606031835079, 0.024561720866976038, 0.030059786646493843, 0.09235263296536037, 0.006929238202116851, 0.04098018351942301, 0.03746073094329663, 0.07168007974645921, 0.021808649845687405, 0.043212444987148046, 0.014863759112943496, 0.03107423721147435, 0.021053248683788946, 0.024628870388759033, 0.054301942964749675, 0.011554762654538666, 0.011621923202515712, 0.04517095150159938, 0.034882325013833385, 0.040001712273806334, 0.036601403661604436, 0.05099510594404169, 0.07446828870368855, 0.0884229720437101, 0.12927371822297573, 0.0669550197198987, 0.011891039520768183, 0.016075339367879287, 0.05337210910926972, 0.025819723095212663, 0.02994771980281387, 0.08131753653287888, 0.019523138646036386, 0.04286490613594651, 0.06362803360181195, 0.018683012209034393, 0.010790238589314478, 0.040474474762699435, 0.07039549760520458, 0.061147879543049, 0.040318954536425214, 0.037201208262039084, 0.04475524362974933, 0.019508390687406063, 0.028833911355052675, 0.02657465267527316, 0.10227111181510345, 0.024388134645830308, 0.022945158682497482, 0.10137935395219497, 0.023201088520831296, 0.02294627487260316, 0.06528048350342683, 0.04644523348127093, 0.09033731610647269, 0.009866966167464852, 0.028860414932881082, 0.02033849007316998, 0.031699062790721655, 0.05035936273634434, 0.006657786451147071, 0.022141442434596162, 0.039808407825018675, 0.03904522895546896, 0.05491729619513665, 0.018390784139877984, 0.03396048090819802, 0.014520447534908141, 0.03101315548909562, 0.0016451009432785213, 0.022547102899157574, 0.01194146739518536, 0.025988744472020438, 0.0024746000375931282, 0.04252211702987552, 0.0391711684476052, 0.03329560140679989, 0.04346029347340975, 0.04970726004934736, 0.011131349169383091, 0.0202306182722428, 0.06899893004447222, 0.05628896152068462, 0.07089300626622778, 0.025217776020456637, 0.030319295757051026, 0.07311342390520231, 0.06699481579874243, 0.02872009389102459, 0.05496209646974291, 0.03148559567385486, 0.044281599045331986, 0.04298627230205706, 0.060595870949327946, 0.03435194133115666, 0.052108649763145616, 0.05545336600126965, 0.008560583544229823, 0.060821592408631525, 0.01563344513332205, 0.03650014248809644, 0.010343810044495123, 0.04284223967364856, 0.02089170815556177, 0.037624858386282406, 0.024132922358278717, 0.03330397792160511, 0.05786762413169656, 0.02468782151117921, 0.017482483593214835, 0.018256037263199687, 0.02206442192462938, 0.0653735717226352, 0.020387219065534215, 0.033044645230152776, 0.03897800309849637, 0.01323904941922852, 0.027929734604965364, 0.022138309299147556, 0.02208705785285149, 0.05227088748610445, 0.07393428842936244, 0.017301818555487052, 0.018243621768695966, 0.007259515546528357, 0.037234805923487456, 0.018409562596519078, 0.0295976873354188, 0.022819763714713708, 0.0068701704564903465, 0.019103303584935408, 0.0314815583904939, 0.041442815480487685, 0.015774032500173365, 0.030607008175658326, 0.059254366505358896, 0.013522820397546249, 0.03295111935585737, 0.03564584315089243, 0.0359326700813004, 0.04540356687669243, 0.0481808174933706, 0.05559363615299974, 0.013046952762774058, 0.028953218167381625, 0.06301550646977765, 0.0384692782536149, 0.02911675189222608, 0.02044746618984001, 0.059822273174566884, 0.014607802133208938, 0.003001039947516152, 0.030658637905227284, 0.004440325528516301, 0.056901865239654265, 0.01936005275430424, 0.020703935463513647, 0.07102310178535325, 0.037663456850818226, 0.020411985593714883, 0.054273356284414015, 0.029491652668054615, 0.04519926676792758, 0.007066022804273027, 0.04549895193693893, 0.05635677431044834, 0.03904437739402056, 0.0819440075595464, 0.021763629047200084, 0.019124287280387113, 0.029334317360605513, 0.03481888198958976, 0.03550191230273672, 0.029134034179151058, 0.06800946992422853, 0.017153879261708686, 0.026887314826516167, 0.02126212720759213, 0.04750410094857216, 0.05800628276275737, 0.06500378370817218, 0.008153036752316569, 0.016516621224582195, 0.05569669883698225, 0.025475885652537857, 0.04840311235083001, 0.027876581564279537, 0.0332853589206934, 0.04241633342046823, 0.05612171620928815, 0.0628564850028072, 0.04001598186524851, 0.03254096868581005, 0.04207433820036905, 0.010572558618150651, 0.03539907692798546, 0.06347099345709596, 0.04558226925187877, 0.08270444175494568, 0.01940134330652654, 0.03591669736696141, 0.0319993043584483, 0.02542013212639306, 0.039996904853199206, 0.0397088938791837, 0.04708137363195419, 0.04334638440715415, 0.029402693334434713, 0.042484902776777744, 0.029134241132331744, 0.05707451168979917, 0.03834048552172525, 0.011452297081372567, 0.05270911932789853, 0.05132548464462161, 0.03698242821597627, 0.03990132641047239, 0.0160050499252975, 0.03752976170341883, 0.013050074023859841, 0.03554401540064386, 0.0237593939195254, 0.043691599275916815, 0.05201582617259451, 0.030620924928890805, 0.08642455749213696, 0.06755944514381033, 0.08513405174016953, 0.08834061824849673, 0.015781555757192627, 0.01969305399273123, 0.05721251214189189, 0.005113487822070185, 0.023646073482398475, 0.08308314571955375, 0.029766690052513565, 0.0043036261673218435, 0.047242505342832634, 0.015079709667978542, 0.017340479784512093, 0.08853066912186996, 0.013913674379831978, 0.02824466984852084, 0.02142797304051263, 0.030659431791199104, 0.01392187362736357, 0.04129527482603278, 0.008408131144408668, 0.05853428478751864, 0.05127440792109285, 0.021872532221355608, 0.040067920328250954, 0.03284879627504519, 0.040358950783099444, 0.02877745045615094, 0.02848627750894853, 0.05274447439504521, 0.05137955370758261, 0.04804782123704042, 0.03188272525689431, 0.002306201428707157, 0.03278957713129265, 0.037077155097254684, 0.05409777517031346, 0.04996005844857011, 0.017277677975861088, 0.03259214718959161, 0.030584379032786404, 0.01057611414164837, 0.12749301163213594, 0.04903437722740429, 0.058961347942905765, 0.01621914129438145, 0.021399576349982193, 0.03038724764649357, 0.013020877510176172, 0.08368591551801988, 0.01606768379653139, 0.04427266952448657, 0.013178294241827513, 0.0167630396982921, 0.027809852734208107, 0.02997502065928919, 0.06924046815506049, 0.03048863774165511, 0.01968350021966866, 0.015757533921194927, 0.0250012690667063, 0.07365722901054791, 0.015617760796365994, 0.015445733509425606, 0.032472341654023955, 0.016464099221463715, 0.020125275710597634, 0.014518995469968234, 0.02786104311235249, 0.048604325125260014, 0.012454436476608472, 0.008249254714298462, 0.06797704273568732, 0.046025108346449475, 0.01172176284515964, 0.03186072375891464, 0.02398230624385178, 0.04453741692538772, 0.015377293074769633, 0.023325260429243957, 0.06345188591097083, 0.07777898998132773, 0.012740814725735357, 0.036649525365126986, 0.023564745971400822, 0.05182900173323495, 0.06909313784646136, 0.06644966040870973, 0.04510010905297739, 0.028512781086776937, 0.032798879846398316, 0.038095748118524037, 0.033226926877562485, 0.0159504533013595, 0.0694994649716786, 0.04990578243242843, 0.022503917537895695, 0.009678084070661237, 0.07579612066703183, 0.019273369905671904, 0.0403808640715267, 0.05948730079191072, 0.06759071882281985, 0.056926190720072815, 0.02568775142676064, 0.01663118677346834, 0.008986807860700148, 0.040230154658534696, 0.07251086445259196, 0.005169824888331017, 0.022347269247152975, 0.01732554522875164, 0.04280905591856156, 0.04453115743984069, 0.009675207930350942, 0.006773614923336676, 0.035543153661170175, 0.06380608797605548, 0.014381066264052476, 0.028921561116086583, 0.04368304634200675, 0.035911974763231616, 0.09058492032012769, 0.17686415596732072, 0.11979864165186882, 0.0925910294588123, 0.069805301060634, 0.11963335052132607, 0.1471259067101138, 0.11343209006424461, 0.11578854040375777, 0.1583192375089441, 0.12091583598937307, 0.12554853382919515, 0.06887375390423195, 0.1573729118598359, 0.08055208796369177, 0.06186182051897049, 0.17480212875774928, 0.24196895318371908, 0.09178536411906991, 0.09518660910959754, 0.14055193375263894, 0.08523710763880185, 0.1208586897701025, 0.09753755653010947, 0.14783268235623837, 0.16561819799244404, 0.1629216591162341, 0.20996104500123433, 0.1831102200916835, 0.09023858247590916, 0.11590557412377425, 0.09017729040767465, 0.10478393054966416, 0.14481679775885173, 0.0622006876926337, 0.10000878106802702, 0.10371447115072183, 0.1480004840663501, 0.11330997411693845, 0.08450272240276847, 0.15620204540235655, 0.20359960278230055, 0.10855796267943722, 0.14628004495586666, 0.17406685464084148, 0.13681136018463544, 0.08566606390689101, 0.08885740408939974, 0.09525773315025227, 0.16083249050591672, 0.137447147497109, 0.10855040379932948, 0.29215655156544273, 0.13060015918953077, 0.12488735573632376, 0.24017338667597088, 0.09516357963106462, 0.13363082227962358, 0.21324640299592698, 0.13011781578617437, 0.12267165391572885, 0.1392619843993868, 0.09269751874463898, 0.0967734989577106, 0.08666713376130376, 0.17309222051075526, 0.0960547946659582, 0.14300875977746078, 0.08047339147222893, 0.11746110208332539, 0.1712860552860158, 0.0804408760741353, 0.12759998946317605, 0.17160233402890818, 0.06164255192769425, 0.1523774013455425, 0.15184498205780983, 0.10095216866050448, 0.20726922872875417, 0.09788797915514026, 0.0932188711262175, 0.1545111904186862, 0.10194541500615222, 0.09057409768658024, 0.19888480220522198, 0.14800565450319222, 0.13233209268323012, 0.14886846606220516, 0.11027649510651827, 0.1982296902154173, 0.11170176469853946, 0.11573471900607858, 0.0941088715834277, 0.2380378469824791, 0.10484672896564007, 0.12655801751783916, 0.17504914264593804, 0.12472002900072507, 0.10084250383079052, 0.20618650397019728, 0.09879970630364758, 0.22192934421556337, 0.09053806069173984, 0.16026005122278417, 0.07248535832124096, 0.14830102079680987, 0.08377724633152996, 0.11311936684484993, 0.09445617294737271, 0.1155069348003183, 0.14002840327365057, 0.11200725473463535, 0.1382181261266981, 0.056681358321968994, 0.09433250315487385, 0.18642715710614408, 0.13398526183196477, 0.20667309500277042, 0.18766639275210245, 0.12412352886583124, 0.12352123404187815, 0.1070785392075777, 0.08480562722044331, 0.10359192094100372, 0.25294705267463413, 0.08957917535943644, 0.09131859987974167, 0.15833995996841363, 0.1703082320413419, 0.12899783945509366, 0.08687404622989041, 0.06031001093132155, 0.0714062230129327, 0.09306367659675223, 0.16169929185083934, 0.15970974575195993, 0.12958819206271852, 0.09260915991451059, 0.2152836908187185, 0.13484348649425165, 0.1366377637854644, 0.11673702379422528, 0.1334732257361923, 0.0986851831632001, 0.10876758928809847, 0.15651225804218225, 0.1284600868821144, 0.07145430400435414, 0.19274940714240074, 0.09565556501703602, 0.09397468449813978, 0.11164196540734597, 0.19051556129540714, 0.1606470468853201, 0.07417942956089973, 0.1024245625095708, 0.22298647463321686, 0.12052757825170245, 0.06255088640110833, 0.07463031608079161, 0.21153604691582067, 0.14217477238604, 0.15083970528628143, 0.13728975451418332, 0.07870418604995523, 0.09180236142128706, 0.126099843531847, 0.10701401731265442, 0.14090079574712686, 0.10226792270051581, 0.1998494075877326, 0.09365168825856277, 0.10687537225229399, 0.17921093718281814, 0.14299281420452253, 0.16302345293973172], [0.03274153006662216, 0.036803037127746005, 0.012914274569733866, 0.0012041378920132826, 0.03876658855006099, 0.045100020843424966, 0.001604537059652752, 0.00414113187330908, 0.12542429406728062, 0.019907177592228566, 0.02405201893166772, 0.034372192208788226, 0.0371918105520308, 0.04306364904290863, 0.10213712150497095, 0.06506451259234122, 0.07531245412038905, 0.0171598215321345, 0.008121022621967962, 0.04156135554824557, 0.05215413535812071, 0.011088566688288535, 0.024050867118473564, 0.004965724947396666, 0.03950999490916729, 0.021325113917035714, 0.0501597207704825, 0.008011735227358128, 0.021697163149448376, 0.054480150009372404, 0.037269265324409516, 0.06812663935124874, 0.09360669460147619, 0.04751399059646896, 0.050227689623300514, 0.024323534719379883, 0.055677587898182015, 0.04701793400038566, 0.022664431781907166, 0.07845421374908515, 0.03852165776437946, 0.034496727133435864, 0.028700826889170066, 0.03252491793994393, 0.052585914331887446, 0.028040697132902484, 0.018891332637784735, 0.009528474732568222, 0.017058836861646602, 0.07430889404245786, 0.055464731462832005, 0.013193570609603609, 0.05491855148492115, 0.045268012543341944, 0.010425688017026653, 0.05926294318799462, 0.04255402174645236, 0.010788437078839965, 0.040046166495553086, 0.03278473578393459, 0.038924012067062516, 0.030131545117391006, 0.02571910822630993, 0.043019920853631835, 0.036278064761843, 0.024150630425927893, 0.01010357472114265, 0.02667109964282385, 0.0371492867624121, 0.05394691647961736, 0.07135445757636003, 0.03513314209080168, 0.05900702013501099, 0.03288852110771196, 0.04766772627564413, 0.05425952774073396, 0.026354851434007287, 0.04786997042330248, 0.05143200446452413, 0.07879063141133104, 0.03048184560611844, 0.09690866991877556, 0.07968523912131786, 0.03489229269325733, 0.005338454411165523, 0.04842591791280678, 0.015107806106763226, 0.024812697399673716, 0.07115481900317328, 0.034836116779063425, 0.02080998200524066, 0.07980569265782833, 0.04266318446025252, 0.07430550815271479, 0.03803996914731605, 0.031622581716094694, 0.02412856785979654, 0.06117259178842817, 0.04607962863519788, 0.08379032170133931, 0.058115092638347826, 0.017215091602078507, 0.04289193557841437, 0.031172159992690598, 0.029732712411454747, 0.1295069307088852, 0.017157173549224223, 0.036286726261356046, 0.060506616452974935, 0.035403592578534565, 0.031153239043695585, 0.046448761863367896, 0.04698470274784735, 0.038976856374314854, 0.04463791474699974, 0.022374514124489257, 0.04028457995238049, 0.05498200807986515, 0.042553726583719254, 0.01809275459631213, 0.0609301987237164, 0.04071085600714598, 0.04451822116971016, 0.05497417100039976, 0.013375175418332219, 0.03758187319285103, 0.04547116253525019, 0.010882420116104186, 0.002885221441309633, 0.022522558591195514, 0.014333863975480199, 0.007095027631813926, 0.01510877810817744, 0.07299991178193263, 0.00823330829319145, 0.07456200117511408, 0.00381835742986628, 0.07295643125793763, 0.03642127636287894, 0.0844832348770329, 0.00277898194118669, 0.033430433100355525, 0.06294039942856346, 0.04374986507796815, 0.0376084955143077, 0.02926947994689856, 0.02117944093021963, 0.0361071723247213, 0.007659198117575475, 0.017146902225379432, 0.02258973864705435, 0.012397181691734918, 0.047292754253638644, 0.06196702737361193, 0.03445476313520755, 0.04388201995087521, 0.06491540452199322, 0.00883155141491443, 0.06447309468473707, 0.062454052668597014, 0.018574662040919065, 0.04858758566634996, 0.03846226559419717, 0.04048727532582624, 0.022234391554125717, 0.015041408062513386, 0.027467368968895504, 0.05248654627108148, 0.07589753451091902, 0.06360545195639133, 0.03687896519633276, 0.03310245980641671, 0.012892155176294702, 0.046466851606965065, 0.03528707793780735, 0.011599146478277231, 0.06150433434439557, 0.0570691784045526, 0.02131182311235794, 0.07213312400771038, 0.021300354174205234, 0.04111957157562886, 0.015850742580369115, 0.04387660184875131, 0.021731071240667785, 0.03434401943481394, 0.03347468715427177, 0.01691426140522318, 0.03305998012157423, 0.049927868747285435, 0.04308164718427828, 0.01261832473600017, 0.06949869144175734, 0.011662816811752106, 0.040992000206772766, 0.07021065788077456, 0.02068901956746621, 0.04338796164042183, 0.0696738688275218, 0.012166531523689628, 0.04548427522448557, 0.03802766052207776, 0.06296861969998904, 0.050782415749771256, 0.009678058625598038, 0.06120534467377833, 0.019827127423403517, 0.05929134666387524, 0.021859424621132866, 0.012277437224318939, 0.047626104937600236, 0.053432251060647626, 0.01995313646537917, 0.02432738370927317, 0.011781727529263921, 0.026931531561006392, 0.035067999336336336, 0.06764795325164284, 0.048062419917966635, 0.027503039554825852, 0.06630000951034681, 0.0756638538358467, 0.032826923698719056, 0.025521054032391736, 0.012706846414533044, 0.08017647811876875, 0.02393091400153935, 0.034011282825044224, 0.049430278662059984, 0.01029193858682577, 0.031962147780827115, 0.023042131514687623, 0.02580637631139585, 0.015778232631938796, 0.05615782105763044, 0.07153794701610293, 0.038885098083743026, 0.06384211818554572, 0.040275575792683024, 0.021618346218019724, 0.021915142524189184, 0.04930404739986573, 0.016064591373183897, 0.008082765121279019, 0.05343824591753738, 0.017966467354978834, 0.020588374164487635, 0.02674148916932089, 0.03403445818860616, 0.027214943763933012, 0.023176800359838774, 0.008573389196369265, 0.05370834356706057, 0.03387945704162121, 0.012907875984508013, 0.017629493294017654, 0.06572244050247328, 0.05864693517131465, 0.05615797033533454, 0.05717863967376096, 0.08615686864192997, 0.044872477517596314, 0.024093317965577756, 0.02530218068776386, 0.042318176544670544, 0.009841105501566614, 0.051712269961301766, 0.04746741256011384, 0.03464029835803168, 0.024958231286810975, 0.015114206388326628, 0.025960028870031238, 0.02598659521234887, 0.0814337492255228, 0.030483541943665062, 0.0333898295648396, 0.09643590064453227, 0.016682095559579984, 0.07228589616715908, 0.02306837894554649, 0.012139884605338531, 0.04068810812064579, 0.014859864321936454, 0.027944382479680435, 0.039752622068460496, 0.07537918125412293, 0.007810357908186103, 0.05980560156915869, 0.02715351089968213, 0.047821088760559044, 0.02910233980842999, 0.0074105031588780025, 0.051793816299842935, 0.03440836491063237, 0.030477024614810944, 0.014354723838290997, 0.027555408887565136, 0.021597812052017877, 0.0751209036846246, 0.04641928290948272, 0.007408123197300094, 0.015609060281089373, 0.048641552949058156, 0.03634871382798467, 0.1059213588014245, 0.021097363638026372, 0.021493807900696993, 0.020722819093082632, 0.04375701005171452, 0.016803451547665254, 0.042156020245913944, 0.023498159633683305, 0.010432486937913512, 0.01505527222928192, 0.022409155033528805, 0.016603868953617554, 0.039190421878759346, 0.0837778773690973, 0.049372830494706116, 0.026397307370124117, 0.06092170346528292, 0.013800334434823265, 0.04619367340845721, 0.023114800918847322, 0.03271680085786751, 0.05908870218055589, 0.024850778481257812, 0.05136788629793695, 0.0462835419790021, 0.04855524668736117, 0.09752409439533949, 0.03927598514461091, 0.07979939585285527, 0.0580002912985427, 0.03129298672346132, 0.03277734314490642, 0.01308646724958505, 0.05196929902636579, 0.03241675606529627, 0.03226738336629101, 0.03463716691892062, 0.027908618595185022, 0.037367724148290496, 0.0629033242751445, 0.06946133808898074, 0.07051182564880167, 0.016352137550711632, 0.023863277630880475, 0.07106527273676225, 0.012604762517314936, 0.04443236952647567, 0.017999283004818217, 0.15717779232987336, 0.12435511286769595, 0.116696298122406, 0.19586685486137867, 0.13296322524547577, 0.1129089734916176, 0.09109120243894202, 0.17180889365928514, 0.3264385020094258, 0.09895937916423593, 0.09897192527673074, 0.08587492377098117, 0.10102473119539873, 0.15757237401391777, 0.2127947293754135, 0.19604787443365368, 0.21113814041018486, 0.11236197248633419, 0.07383817394397088, 0.13873416557908058, 0.09036933617400271, 0.1235965649996485, 0.12893664916711195, 0.08470975700765848, 0.10085652914962598, 0.10511799369539533, 0.15066967798130854, 0.13143458084336349, 0.07691811903246812, 0.11656329168805055, 0.13282222566860064, 0.2218794176088912, 0.12959989000644, 0.13914151729217597, 0.11345264967530966, 0.10743053603385176, 0.1771516241133213, 0.1327837255916425, 0.12106695930872645, 0.16654130417321408, 0.0857981000361698, 0.11761503453765597, 0.11134393247110502, 0.1647158142711435, 0.11875301918813161, 0.13161348338638032, 0.11788211949169636, 0.08529586198606662, 0.10163026941674096, 0.12235481877412115, 0.08722640267972435, 0.09182406097118344, 0.17632820829749107, 0.19359106197953224, 0.09495739319494792, 0.12791981015886578, 0.16572927417499678, 0.14171623199113778, 0.19830422050186566, 0.15943111213190214, 0.16356011985668115, 0.19881879431860788, 0.18944575584360532, 0.10653312597423792, 0.09068955042000328, 0.13269859658820288, 0.09727396603141512, 0.08601760611470256, 0.13622925856283732, 0.11354704746710402, 0.17122292438788073, 0.12019943871668406, 0.10548798527036395, 0.12670939868049963, 0.12206017172762326, 0.1999868652118104, 0.10801906338227646, 0.1416918725839683, 0.16470650477068766, 0.1204610818198749, 0.22758873339210237, 0.11626202213977065, 0.16433419260595525, 0.2115691594247307, 0.23470396016325268, 0.14325236741985592, 0.08645849102841956, 0.058101956200386794, 0.08207771288497107, 0.15581726176398142, 0.1227461299193757, 0.1560344472527504, 0.1302437518856355, 0.12090765285704817, 0.05789253993758133, 0.21689226664602757, 0.14539428534252302, 0.15704908780753613, 0.13528518564999104, 0.1232396691505398, 0.14502988489610807, 0.0672295753444944, 0.17636421136558056, 0.10535609841878925, 0.0752297949844173, 0.22763600014150143, 0.08507034408726863, 0.20331817359796592, 0.14232578713979038, 0.17527335775750025, 0.07660156887556825, 0.1552020204918725, 0.10246760877115385, 0.1791998092085123, 0.1109715863796217, 0.06412795784750155, 0.158666389595185, 0.12438939245683805, 0.08500018356634037, 0.10506335805569376, 0.10995014011859894, 0.10409083416951553, 0.1680315299225705, 0.1520739197731018, 0.11810743382998876, 0.1580847900893007, 0.14979298359581403, 0.08609673008322716, 0.1570889042424304, 0.0875448663053768, 0.1151974821197135, 0.1592072769999504, 0.19223175277667387, 0.18960431590676308, 0.10816040901201111, 0.11202362099928515, 0.09795186322714601, 0.11180246608065707, 0.1589034968721015, 0.1515873015991279, 0.10757335408457688, 0.14914807677268982, 0.1933285232101168, 0.10146963982177631, 0.1821863403809922, 0.09903130387621266, 0.14077176552798065, 0.08030935563147068, 0.1731454583683184, 0.24416607671550342, 0.10852717076029096, 0.15491892211139202, 0.1422508225909301, 0.15294435806572437, 0.20957856838192257, 0.11436269405697073, 0.15767438496862138, 0.1526233431484018, 0.11728029964225632, 0.136130314586418, 0.11988400135721479, 0.1687427974705185, 0.07998232889388289, 0.10143443063965865, 0.16752215368407114, 0.09355849825910159, 0.10515293824885573, 0.16713853712592805, 0.19457181649548666, 0.15086973724620684, 0.08305367694369384, 0.09749969427606889, 0.20264096850795404, 0.13165499615882123, 0.1199362078415496, 0.1363936268857547], [0.0418443317924227, 0.027066008720014776, 0.016929687898872153, 0.02853075208674584, 0.020158189748014723, 0.03101125219836831, 0.016014829311253767, 0.07130912465176412, 0.014029721679565097, 0.008751402858511677, 0.029079978686890433, 0.03838598468740072, 0.043072863548461876, 0.04830102336459926, 0.010646779322996736, 0.04062128938468439, 0.01826417968342347, 0.02548181265592575, 0.04091901019481676, 0.04410076607018709, 0.09808476788124867, 0.03571193924705897, 0.01653911805312548, 0.0528682290044214, 0.08661581615784339, 0.030276391987821887, 0.0044796814077666825, 0.06990383791604213, 0.03541260352358222, 0.024603854498959014, 0.026381436436037933, 0.019574006720046912, 0.01120490999892354, 0.01634348962189896, 0.01566301060042211, 0.049036992979901176, 0.08699705784342118, 0.038094421582562585, 0.04083510933976088, 0.02546198247000575, 0.045516542957297394, 0.05016040948352643, 0.036611395089754036, 0.04960306081920862, 0.030918652524373362, 0.03193380876577326, 0.012988642007777733, 0.015948628042159334, 0.016417254860113775, 0.024178925336205533, 0.02689625452538686, 0.010651767403552575, 0.04415088945201465, 0.012423027090595236, 0.02692743999484394, 0.005570113475966666, 0.0482383979750531, 0.03775101500962462, 0.018874766205304434, 0.028892323042133024, 0.03223838956494417, 0.02433835731686226, 0.017916447449741617, 0.0872983206063509, 0.051692090329847167, 0.035460168828389475, 0.047429560484098535, 0.011944089933032436, 0.03352921422837036, 0.02725492643990687, 0.017156844459740177, 0.0194111040327698, 0.026036669400387576, 0.033318145732794485, 0.026411812752485275, 0.019719162323911275, 0.038036800388778956, 0.00759813335857221, 0.03236505848222545, 0.025738081761768887, 0.05550387275538274, 0.0379340634016054, 0.10941299144178629, 0.04389682558498212, 0.06185415307325976, 0.023652297344857028, 0.056432346148150306, 0.0491312652427171, 0.042315374195043526, 0.019687927660665343, 0.03414558186861021, 0.028815797862729857, 0.0072752321138978004, 0.02206233373310949, 0.019948527516265, 0.0361273044587246, 0.013123717973940074, 0.035755667436335764, 0.058743986035031934, 0.012570851033420434, 0.05833933489131076, 0.026107907095657926, 0.030880759736256938, 0.04257197917572089, 0.00965435485289033, 0.09125835275543587, 0.04353304599810924, 0.0481559152581862, 0.07112193719616958, 0.052071062315787585, 0.05175623224516, 0.03656273055821657, 0.02809374500066042, 0.02389879385009408, 0.03955974509673459, 0.04097564072747316, 0.03218810333471213, 0.057523315107183795, 0.008600427968693631, 0.03507468629894512, 0.03421960664646966, 0.03724265657365322, 0.020984175515228083, 0.016540317363770943, 0.020465862970533114, 0.012412914374311055, 0.032717767770269086, 0.014920830693362015, 0.015528309524857571, 0.021074999123811722, 0.025255373645839945, 0.04202368895390204, 0.04670865773888571, 0.025307228988302604, 0.046020300925842354, 0.028960101905145814, 0.020491442044398615, 0.02443108251983566, 0.12909345860992158, 0.02895539626479149, 0.040146867877670696, 0.06358967601720776, 0.048218086029269865, 0.01538717932999134, 0.07006467785686255, 0.01142495805730245, 0.04208153745691691, 0.04663140991968768, 0.03521510572837932, 0.04958368864442621, 0.031189924039478813, 0.04336013152663197, 0.007138119694510741, 0.02133190435623484, 0.04403004915054355, 0.04978432466409036, 0.0467114736592131, 0.017852790686967115, 0.03444504312106541, 0.05701670729156051, 0.036926340511334796, 0.012721885295052613, 0.05982190676565681, 0.02804225097809519, 0.03474438223721726, 0.07540233286895923, 0.04249017499387264, 0.01921263593249023, 0.03394470836168953, 0.033130042254924774, 0.06336250927831445, 0.027466071270672337, 0.032638820220849345, 0.057734393780784946, 0.04951847464378391, 0.04399339808151126, 0.01471185208564358, 0.041214471483337026, 0.02089808468839952, 0.07117879843073231, 0.04635304771363735, 0.009225111055587019, 0.03542903424905879, 0.0854197149830205, 0.023796134894447665, 0.013906294463335403, 0.05599387003374951, 0.023643281310796738, 0.03719778505287, 0.026179584142352854, 0.05509295194808926, 0.06440115640205996, 0.019493646121450832, 0.02723912675199764, 0.040083021125090976, 0.03427228471264243, 0.07365564802395445, 0.0401119742143367, 0.026507084158116152, 0.035346066379653554, 0.1029947219150407, 0.04101071759526219, 0.006876263276873422, 0.0695302365347743, 0.028441434825903604, 0.03990565546389137, 0.01768288042928491, 0.03497332673785942, 0.006058768527249673, 0.030640595659081424, 0.029514122355197157, 0.030479256995022297, 0.045052143412509134, 0.01797943076651011, 0.01687869768855827, 0.006565521379733192, 0.046686886942812374, 0.03129082219675183, 0.025780418954257454, 0.0269915208420051, 0.04607863797407065, 0.027927865240988985, 0.028000901054058756, 0.016713072379518832, 0.05014234348865492, 0.004429971084131726, 0.03295176735680018, 0.0523880365570741, 0.028044629243335555, 0.02292185609361955, 0.05082272072987897, 0.0410823505371809, 0.0796799465481724, 0.03877667836578829, 0.03951186427314367, 0.039534435740539005, 0.026438221335411072, 0.013632927123191101, 0.02714314458093473, 0.014932710145201002, 0.04862866417637893, 0.012961627832347793, 0.05273497490478413, 0.02094626915641129, 0.015685661795682142, 0.025043848835464035, 0.021589542406478097, 0.06271387729793787, 0.006248086158718381, 0.03504090204036661, 0.010598844216604317, 0.00653682486154139, 0.03088989621028304, 0.007531789597123861, 0.029038269139294113, 0.02109793869645468, 0.05086067797882216, 0.060344365159315724, 0.03426816261240414, 0.018939232121088674, 0.05076579503448946, 0.00961136881129018, 0.029913623418126787, 0.06033707769321544, 0.020220343555722917, 0.04714913213891642, 0.006788451939688197, 0.01222605855270688, 0.0163581765123776, 0.024429442161428075, 0.040539722690092664, 0.05311596553240504, 0.05295216039355312, 0.05468273003186498, 0.037172323026295216, 0.03970300080254674, 0.09329555915402514, 0.025402101754610027, 0.059578590893319676, 0.012032216364916946, 0.06978284833686692, 0.009672511601820588, 0.07493325482521739, 0.01898397472021835, 0.06683484438274588, 0.00507614464731887, 0.022279188436056887, 0.03624250613419073, 0.03451689997954028, 0.017579023859330585, 0.021720263874158263, 0.049314130430242846, 0.06167317421308585, 0.009294482779556086, 0.07564570980944804, 0.015712050022557378, 0.0732418027307306, 0.052997035307011435, 0.02566464222036302, 0.01683280666890953, 0.02409969110574041, 0.024497763852455785, 0.022974471395303096, 0.024298569719706262, 0.019987911385084902, 0.049136371218732426, 0.0024739611544646323, 0.07423441125346081, 0.03842468832486442, 0.04433131191347327, 0.03331711096689105, 0.08323504935417857, 0.047562251399670324, 0.021321173324914913, 0.06387415860912629, 0.01825186936184764, 0.003966156775797052, 0.02494595489198608, 0.02724310805621956, 0.03733523249892252, 0.08535484703523771, 0.014957434264943004, 0.03418837028688618, 0.03488208074122667, 0.03746096843055316, 0.04592733145026224, 0.04867334231468184, 0.07115038138415132, 0.018863117455371788, 0.036088573679860146, 0.017112205337200845, 0.046479401112134965, 0.07600283636046307, 0.02576314514902021, 0.01395597679740084, 0.07509863416531257, 0.02685229733054127, 0.06552284942673785, 0.017025042425042818, 0.04802763482023563, 0.05598479802055018, 0.024092105084231923, 0.03587579866871238, 0.03194015985354781, 0.039408065378665924, 0.06999942314411912, 0.021373147411005836, 0.03837641055828758, 0.06787385791540146, 0.010188540876177805, 0.02703116594680718, 0.06850928560431514, 0.11630901747516223, 0.12825222446450166, 0.07567718026361295, 0.14798529845263275, 0.1262123989207404, 0.07719350925513677, 0.14997917360493115, 0.16406159794756345, 0.10381348976599318, 0.09081896061875991, 0.0892372140660882, 0.1665938092129571, 0.11822144128382206, 0.1356661966336625, 0.11856043737913881, 0.10330440529755183, 0.16844185361904757, 0.10648562173758234, 0.13081845747573034, 0.14960314306829656, 0.36633193705763134, 0.09867267776280642, 0.12694619383130754, 0.19942364043423108, 0.2233014777302742, 0.10046967597944395, 0.08691306877881289, 0.1686480332698141, 0.09842792339622974, 0.1525307638304574, 0.12438416773719446, 0.1290804443082639, 0.09477028037820544, 0.11752075888216496, 0.0971736174875072, 0.17160487174987793, 0.13204611731427057, 0.12039116557155337, 0.0787670048219817, 0.07573516108095646, 0.12072189711034298, 0.14139049447008542, 0.1171890909650496, 0.10190321691334248, 0.08729844274265425, 0.08045239759875195, 0.1383430172822305, 0.11361986105995518, 0.1516681829733508, 0.09039843175560236, 0.13601211378616945, 0.1651678407298667, 0.13199803632284912, 0.08642286793994051, 0.10320766655994312, 0.0861562986725143, 0.15580312109419278, 0.15528419108263083, 0.13427676047597611, 0.09695676448089735, 0.09085157101175614, 0.10316112584301404, 0.1310468659337078, 0.1257375736853906, 0.10580596035080296, 0.15236497058400086, 0.11338288949004241, 0.12562523542770318, 0.22232721000909805, 0.0769587904214859, 0.06546944193542004, 0.1534383451300008, 0.08751393189387661, 0.10920624182160411, 0.10553059048418488, 0.1093505322933197, 0.13448610209992953, 0.15890549176505633, 0.10227060969918966, 0.06996430217155389, 0.09933409334293433, 0.17682827503553458, 0.11767011801046984, 0.09897598291614226, 0.10748610126652888, 0.19089270462947233, 0.28352067353469984, 0.16460779149617466, 0.10371139738708735, 0.14340247293668135, 0.09580704795994929, 0.06619014112012726, 0.14538353734782763, 0.10743493972612278, 0.1393426622131041, 0.14636152344090597, 0.15150894437517437, 0.1399927937558719, 0.12550027641866887, 0.1057369669101068, 0.2336316577025822, 0.09786769774343286, 0.11522775835224561, 0.08383870124816895, 0.12417410686612129, 0.24183528178504535, 0.19296648406556674, 0.10479320612336908, 0.17604482493230275, 0.1630775457514184, 0.11316341733826057, 0.10539250860788993, 0.104560298978218, 0.04463510221934744, 0.09834784269332886, 0.10210107772478036, 0.13803770366523946, 0.09924121546958174, 0.11747662696455206, 0.13627619961542742, 0.10022642796060868, 0.08433217262583119, 0.09209541391049113, 0.2981368606644017, 0.11160643052841936, 0.08350756258836814, 0.1254775726369449, 0.06939667370170355, 0.14785136921065195, 0.1402157060801983, 0.1186589878052473, 0.12958465010992118, 0.20824869402817317, 0.06211302096822432, 0.16388839509870323, 0.15911828034690448, 0.09371562661337, 0.15375965860273155, 0.23617317846843175, 0.09480868546026093, 0.1560751050710678, 0.18501994333096913, 0.20953493858022348, 0.15837721154093742, 0.14318238331803254, 0.09559898198183094, 0.12018366956285068, 0.14258525893092155, 0.1162758506834507, 0.11562167507197176, 0.12884782893317087, 0.20420106979353086, 0.07745376814688955, 0.12721292594713823, 0.1725778231131179, 0.12025654422385351, 0.08287393980260406, 0.11299626702176672, 0.09512623306363821, 0.12488940491208009, 0.14741413481533527, 0.14778641983866692, 0.11963598323719841, 0.17006021392132553, 0.2117129409951823, 0.1191900907350438, 0.10477378645113536, 0.12035385971622807, 0.12859241478145123, 0.17172369680234364, 0.11279359539704663, 0.11896909187947001, 0.17093466914125852, 0.12024403203810964, 0.07567371294966765, 0.12966027962309973], [0.027658125518688133, 0.03399406499894602, 0.005470924802856254, 0.11804697635982718, 0.03685834790979113, 0.061330106907657216, 0.02728447494363146, 0.04437019197004182, 0.13986858113535813, 0.003988459797775639, 0.00252214159367473, 0.03386172013623374, 0.031243358672197376, 0.022004568350634406, 0.09174965960638863, 0.048428974713065794, 0.021171810803934932, 0.018500040152243206, 0.09727851900139026, 0.05704548396170139, 0.01848889691089945, 0.014907633187249303, 0.05962405273956912, 0.03337987545611603, 0.07849700216736112, 0.03035456600732037, 0.019221724909065024, 0.11404541108225073, 0.052835832349956036, 0.07383845892867871, 0.004158818736738924, 0.052174891744341166, 0.008660881198011339, 0.014271264030997242, 0.07639428999807153, 0.02316180812860174, 0.027706159012658254, 0.028087438017662083, 0.04303614801860281, 0.03163714647026999, 0.05150598513760737, 0.03161988114672048, 0.04551617315571223, 0.03499598302213209, 0.06190254619078977, 0.028186468507296274, 0.035934983885713985, 0.010153976302327854, 0.04901992782418217, 0.0218024785696928, 0.011408174493616181, 0.004749394412751177, 0.009202189294488301, 0.05023729428648949, 0.06266019160726241, 0.011387212850552584, 0.1079836506396532, 0.024187145787956457, 0.06402539727943284, 0.03982611419633031, 0.041899408479886394, 0.050317398738116026, 0.0181960378041757, 0.005534205402779792, 0.04671492400978293, 0.05279290143932615, 0.07211295794695616, 0.02111060355257775, 0.011632540579220014, 0.004744075970458133, 0.06377214765442268, 0.04811516583764127, 0.04011147888377309, 0.07306155668837683, 0.03601393143513373, 0.04291047994047403, 0.02609769005461463, 0.09172348851071936, 0.03956748378862228, 0.017420808152694787, 0.06297752207943372, 0.045257790413286, 0.06180316795195852, 0.03441139456949063, 0.04530722168939454, 0.006544694595504552, 0.028586500523877994, 0.026503253827935884, 0.016380300146660635, 0.06155750434845686, 0.017675514931657484, 0.03242088495088475, 0.004775314450463546, 0.08760644335831914, 0.03372737020254135, 0.009415860820029463, 0.02066414108100746, 0.037129049455480914, 0.05090923055208155, 0.0649689816470657, 0.036851060443690846, 0.01262294895215226, 0.02532238237160657, 0.03971697183858071, 0.05339781201577612, 0.026029977348766158, 0.014085806839700257, 0.012895750563724764, 0.02961970240409885, 0.03299926480810557, 0.0834173174308879, 0.02607504734104233, 0.016830189220075096, 0.0051864184622120646, 0.05629010145951595, 0.032700665295124054, 0.009010806796140969, 0.015481209016538091, 0.04134445843685951, 0.031723866638328345, 0.0030498649949939655, 0.03720413953331964, 0.025292801637468592, 0.05702194558190448, 0.04053647250735334, 0.021895246181104864, 0.03479454293847084, 0.053729978656130176, 0.05181152606382966, 0.05369675758161715, 0.05395571707880922, 0.02133642339945904, 0.03682518111807959, 0.06015577992158277, 0.04768406879156828, 0.043314713785158734, 0.028516984611217464, 0.021322708510394608, 0.08200543533478465, 0.009415704756975174, 0.030370623538536683, 0.036716717295348644, 0.025768264695735912, 0.03876818310735481, 0.07394110092094966, 0.015573725569993258, 0.023131874556254064, 0.05888819508254528, 0.08126333515558924, 0.009411420656501182, 0.04609751142561436, 0.053210061376116106, 0.0239929897777204, 0.05320140666195324, 0.007446387483339224, 0.09510306109275136, 0.08364843324358974, 0.03680289802806718, 0.03127635243747916, 0.026333324910540665, 0.020573171587394815, 0.016944965114817023, 0.05712596500026328, 0.018900168860065084, 0.023765130933108072, 0.02913755238322275, 0.02623459297631468, 0.02936196426994034, 0.023268136262361492, 0.03232154742415462, 0.025592444398041283, 0.01094048744666257, 0.06204148302120822, 0.044300380894648175, 0.035201141477695534, 0.026703214705256478, 0.03438971537564482, 0.031426044047943184, 0.03187579741435392, 0.056638783642223904, 0.014862632744812539, 0.05419216278408255, 0.01653281955181488, 0.06439547027860369, 0.03383167799828308, 0.040701678821018765, 0.02903602658105748, 0.013343756702462477, 0.036746633904320855, 0.02214587326826794, 0.006118043226056865, 0.02445624429466469, 0.09649978471653801, 0.04902666906959244, 0.04089989586334143, 0.03503319727522986, 0.01797611273026892, 0.05258340035964336, 0.020138678473553488, 0.06357123343540089, 0.06710078261260476, 0.04920072347990104, 0.025085456602807556, 0.04592144176630037, 0.03860742459073663, 0.03325268067419529, 0.05372553764443312, 0.01843006962112018, 0.05074720656765359, 0.028863169785056795, 0.042825771628745964, 0.030806874058076313, 0.06953096935259444, 0.053410999343863556, 0.05207925223346267, 0.027343987553779567, 0.036689253590468845, 0.04871433940050857, 0.031805287447891066, 0.03717695402779749, 0.07179733738303185, 0.035525342116930654, 0.028961418263081993, 0.04464003177625792, 0.010483879180225943, 0.051706712759499035, 0.031380789154874425, 0.01111381667266999, 0.028577414939978292, 0.046514203173241446, 0.07702922235642161, 0.0034492579164049986, 0.05731571053287812, 0.05159535159223846, 0.04215384214850409, 0.0326113293745688, 0.033298508929354806, 0.030728435409920554, 0.043712905275502374, 0.03556689899414778, 0.0725571812529649, 0.04349292761513165, 0.02795992771695767, 0.03175450588709541, 0.04152234657002347, 0.013415567759823586, 0.0500993311538228, 0.03346932672762445, 0.021623798246894563, 0.034011001233011484, 0.015314057003706694, 0.057401382364332676, 0.025446776500237838, 0.015022551574345146, 0.03055641321199281, 0.031298214835780006, 0.0562220477898206, 0.11578488988535744, 0.018778804390292083, 0.05304787115060857, 0.012860733915918639, 0.045283031915979724, 0.036313552143318314, 0.018164960900321603, 0.02066146256402135, 0.037887044317488155, 0.04647142154031566, 0.02312275504560343, 0.04099672959585275, 0.035537206301731725, 0.06692674516567163, 0.04328808467835188, 0.04162129733179297, 0.019281230733862946, 0.031207908610148088, 0.031159936184329644, 0.03201500565877982, 0.02332527399994433, 0.01505086344799825, 0.03610146584521447, 0.06295439082064799, 0.0427536637123142, 0.028050220371889215, 0.01854642989513065, 0.03137331509164401, 0.010525046747976115, 0.03091950747849686, 0.05138378098074879, 0.04281575645187071, 0.0391406445497913, 0.02457965794019401, 0.026660558601309146, 0.02306525598812316, 0.04673433689666646, 0.02490020466835371, 0.01620711256483836, 0.0189321159850806, 0.09324431618941681, 0.04495715868792363, 0.04420918578814183, 0.057905418532235284, 0.011920912024964179, 0.026074282292808806, 0.0347113274037838, 0.0422224115048136, 0.04860646251056876, 0.03974453393103821, 0.018039386120757887, 0.07178293208458594, 0.06256550204541002, 0.0051510816306940144, 0.11690372627760683, 0.011840081540867686, 0.026794783006023084, 0.06918392583195652, 0.009813725765395378, 0.009404477546922863, 0.019250060531443784, 0.05782381112554243, 0.0371236347460321, 0.05711222466613565, 0.03263295428561313, 0.022328509450224892, 0.035237253111388, 0.06423431821167469, 0.02094048634171486, 0.026807098416611552, 0.012302645648430501, 0.07594799037490572, 0.01790338904330773, 0.04291479881586773, 0.08107302643890892, 0.022435410946075405, 0.03251477384141513, 0.02896975745846118, 0.06897246717874493, 0.04134945584727185, 0.02042759020280625, 0.009537235467827745, 0.026382384688726494, 0.04795624275824853, 0.02559704316913017, 0.050376682342695336, 0.06707868272704737, 0.022578631028799073, 0.07077748567930289, 0.043182379100471735, 0.08201692971800055, 0.07414749091757195, 0.05367731076798268, 0.09961451151009117, 0.028419604658016136, 0.0712399547919631, 0.20587398431130818, 0.07022169764552798, 0.19776835425623826, 0.17129033005663327, 0.11034267262688705, 0.1263171782983201, 0.16408327035605907, 0.277381071554763, 0.09792644530534744, 0.1589895893952676, 0.09652987774461508, 0.1769070393804993, 0.10188715598945107, 0.1777961373861347, 0.1476968125041042, 0.16867731884121895, 0.10335511900484562, 0.18414992573005812, 0.1539468935557774, 0.10182399116456509, 0.11051228602549859, 0.09731298858033759, 0.17517141465629849, 0.1662244147488049, 0.13985692390373775, 0.09709477850369044, 0.1410437359341553, 0.23454480298927852, 0.2076109389641455, 0.24935179416622433, 0.1536105844591345, 0.16291278387819016, 0.15616877004504204, 0.09478457032569818, 0.1813901202487094, 0.19294996852321283, 0.16084333349551472, 0.16449429972895555, 0.07577518786170653, 0.12322102300822735, 0.11434209373380456, 0.11448096271072115, 0.08748493809252977, 0.14786465492631706, 0.11069028611694064, 0.09999341903520481, 0.14338097694729054, 0.10142563004046679, 0.18046978249081544, 0.15211913734674454, 0.07644150925001927, 0.13204653800598212, 0.15224985033273697, 0.12974159525973455, 0.08458724751004151, 0.16893084666558675, 0.12709933918501648, 0.22877671250275203, 0.13604863254087313, 0.18780151621571609, 0.10826015365975243, 0.12090749000864369, 0.2053230410175664, 0.22995372648750032, 0.13600925036839076, 0.2147691170019763, 0.08070688215749604, 0.15603853203356266, 0.06642703126583781, 0.1454731175409896, 0.12222464861614363, 0.11274172818022114, 0.12554009285356316, 0.1604645209653037, 0.24963167629071645, 0.11677613455270018, 0.16880237284515584, 0.15077179750161512, 0.11703966398324285, 0.17318792108978542, 0.32933695933648516, 0.08331406475710017, 0.1911841897027833, 0.15138087767575467, 0.08651764571134533, 0.08900003215031964, 0.1380259378680161, 0.06462354625442199, 0.10166953623827014, 0.07281881078545537, 0.10895662235894374, 0.0871968592650124, 0.14742846547492913, 0.17689292585211142, 0.16318228441689694, 0.2006027985896383, 0.11836443575365202, 0.12759940592306002, 0.09794123736875397, 0.11872764197843415, 0.08992045811776604, 0.15043998030679567, 0.13858563426349843, 0.13378259699259484, 0.1009897052177361, 0.09138871968856879, 0.10938488652131387, 0.08285679322268281, 0.14354259041803225, 0.1543600128165313, 0.17418375265385422, 0.08200169660683189, 0.1298760130469288, 0.13160344106810434, 0.08763806309018816, 0.07940410170704126, 0.13212547877005168, 0.17468820272811822, 0.14826815256050654, 0.05663894309795328, 0.19763480499386787, 0.17032120563089848, 0.09074040661965098, 0.12517991289496422, 0.09685912329171385, 0.08484749283109393, 0.13206583554191248, 0.1622145849147013, 0.163350642525724, 0.2235981332404273, 0.15034692601433822, 0.19787051448864595, 0.2009712973875659, 0.1661631158952202, 0.22737951390445232, 0.16289892819310936, 0.11812485860926764, 0.09294069890997239, 0.15065128968230315, 0.10084742999502591, 0.09815391059964895, 0.1217290059264217, 0.08521190684820924, 0.20684361085295677, 0.08663584651159388, 0.08237765250461442, 0.12036116075302873, 0.1864673128085477, 0.08008345096771206, 0.09720337803342513, 0.12289476980056081, 0.15620355175009795, 0.20653030409344605, 0.11705707519182137, 0.15887155144342355, 0.12378474990172045, 0.11873297526368073, 0.08545683763389077, 0.17602921862687382, 0.0777474313176104, 0.11720883633409228, 0.13780788385442325, 0.1394254977681807, 0.2693478140447821, 0.08269036215330873, 0.13277729307966574, 0.1477009787091187, 0.12347657286695071, 0.1342619684125696, 0.11225959512272052, 0.18215010661099637, 0.17039416171610355, 0.11243981402367353, 0.19661872594484262, 0.1083168520459107], [0.05370137161974396, 0.02983606347282018, 0.028924733267298768, 0.054153828948204, 0.06255558186343738, 0.05571220336215837, 0.03874079743400216, 0.033317996455090385, 0.07972923533192702, 0.0026078761896185043, 0.028788819310388396, 0.03829804654898388, 0.01555105232234512, 0.028582503952618157, 0.06502446545554058, 0.007615696389361152, 0.04075234163818615, 0.006243033193251384, 0.019888097187504172, 0.016843371459149888, 0.01592423640457647, 0.03701027190046651, 0.03870798008782523, 0.003172375128737518, 0.03110349564147847, 0.011048637446947396, 0.006329713921461786, 0.023327094170131853, 0.02979883225634694, 0.03293145201834185, 0.08738568199000188, 0.029321605007031133, 0.06747084204107523, 0.019368447928822467, 0.014062994492373295, 0.04679182916879654, 0.0021821289680831668, 0.10647746574665819, 0.06382296314196927, 0.01222741138190031, 0.03081859914319856, 0.07348030100443534, 0.03706263444785561, 0.052475112956017256, 0.02585676941089332, 0.015401109653924192, 0.042289186135998795, 0.060138389069054804, 0.02249852827351008, 0.0037602239421435763, 0.055165076827896495, 0.037336216374699555, 0.041084528634590764, 0.04433655359649232, 0.0037256122949267073, 0.022993366899234906, 0.017615208435537558, 0.01859543708685253, 0.021095977730250785, 0.05884943716228008, 0.039039956738374064, 0.03585172085357564, 0.012115436988616628, 0.030851026331739764, 0.021196378860622644, 0.022603780929265276, 0.03566685398774488, 0.044938047749123404, 0.04858305644510048, 0.04195980827457138, 0.06286320249949183, 0.011539085102932794, 0.013592387200333178, 0.06577286243970905, 0.014595152544123786, 0.03651852060907653, 0.01729467697441578, 0.05161866605547922, 0.05877824526812349, 0.06817689165472984, 0.018387013181511844, 0.0391841216811112, 0.10071486460843257, 0.02101131182696138, 0.029041200410574675, 0.06351391758237566, 0.01183274233647223, 0.05583561531135014, 0.030333005557102815, 0.07656355734382357, 0.016702429557751333, 0.052292970408286364, 0.02366119124261396, 0.020638726551883986, 0.020060110903744186, 0.057487474887498786, 0.04600152246920126, 0.025760383511494313, 0.008600609476811119, 0.024327288714370558, 0.08995394382093634, 0.05104765848123601, 0.007304305643109339, 0.06014322702373777, 0.0204763124098203, 0.04740596442882504, 0.05615039109917624, 0.03715904748865536, 0.020137752273253033, 0.03693944980789508, 0.04130976494135601, 0.03156522854364344, 0.014550262363627553, 0.03232602236260261, 0.04055597699646439, 0.08763265516608953, 0.021116791791947823, 0.027421818913093636, 0.04370124125853181, 0.008797240443527699, 0.020410871099946753, 0.06056642931486879, 0.029125437140464783, 0.04964078397357038, 0.027154638964150633, 0.004587206731749964, 0.033519236370921135, 0.04319150200379746, 0.04807477943333132, 0.06458060177309172, 0.04785074074087398, 0.041316122814480744, 0.057810681472931585, 0.03358217727925096, 0.026111742514850836, 0.03241761101941977, 0.028781704870717864, 0.06525560840964317, 0.01979588427846985, 0.007095726946967521, 0.020466675516217947, 0.025652386181588684, 0.021116912231913636, 0.030468475073575974, 0.09072669342692409, 0.0200484061746725, 0.026891291041725447, 0.04524133593908378, 0.021946674046505774, 0.06254364643245935, 0.049505168572068214, 0.007916972722991236, 0.031420242573533735, 0.015934477194345424, 0.027584699547982643, 0.02792171262470739, 0.02265226056001016, 0.033205994072237184, 0.04566888085433415, 0.06282301287033729, 0.029979695765567676, 0.06281187132533107, 0.06731214627091374, 0.034823641912745576, 0.021956183714792132, 0.01288231132951166, 0.07476178902600493, 0.008897877364818538, 0.07049088605812617, 0.01756389083207718, 0.012421700554633779, 0.02948077575170568, 0.04012779425829649, 0.07843668718955346, 0.04286763384672148, 0.008303074415640106, 0.064430156988757, 0.023450986182849323, 0.03019902542499559, 0.04710573982447386, 0.030572494491934776, 0.07235560206962482, 0.028291125748572604, 0.0014033942591465476, 0.09092496814472334, 0.06828196958771773, 0.05236561097470777, 0.03510742222091981, 0.029811921196856668, 0.042865099518426826, 0.013568498526832886, 0.0421976619400084, 0.0478872798516282, 0.014091386093891092, 0.013966713765902179, 0.021676274448899285, 0.030914516853434697, 0.056557664780744484, 0.06578524570379939, 0.022613483980031948, 0.041683244186320474, 0.033469476005328555, 0.019140551764784113, 0.028337210150701658, 0.01531432502503906, 0.03671901074371167, 0.026808587800977484, 0.012085340567864478, 0.015334228153473564, 0.004821662208996713, 0.06284237147441932, 0.03341115592047572, 0.048896800859698226, 0.0841676550252097, 0.01532851149594145, 0.027361459830509763, 0.002359150060718613, 0.04905578839991774, 0.023424024593883326, 0.014080730549591993, 0.05707531236112118, 0.03188738679247243, 0.02431409968994558, 0.018730312885184373, 0.0235467342593308, 0.03650542827589171, 0.024733330854879956, 0.02146873772809548, 0.04114157307360854, 0.04061323178133794, 0.031565717088856866, 0.05398888047784567, 0.005397841068250793, 0.024140745867043734, 0.028888211119920015, 0.07518465204962663, 0.01828595726484699, 0.02643551567702421, 0.01558604946226946, 0.03300859127193689, 0.02958992150213037, 0.012637012438582522, 0.0715925826558045, 0.04598249634727836, 0.032441620981054645, 0.037404778945658884, 0.0362237446409251, 0.015840003067361455, 0.004402752500027418, 0.06506808168653931, 0.03405168280005455, 0.07924540593687977, 0.0512520942970046, 0.04968894638919404, 0.04326239534254585, 0.0451363530009985, 0.050781180816037316, 0.01750858683538224, 0.02296314325316676, 0.02820290262544794, 0.05424846761992999, 0.032320658543280194, 0.041110852400639226, 0.06903175756867443, 0.02996281042162861, 0.057429833337664604, 0.05641274666413665, 0.04565188355211701, 0.032191743675087175, 0.03618827083015016, 0.02194619907199272, 0.03398044340844665, 0.03583640631820474, 0.05281534737774304, 0.012620103345917804, 0.036977179747607024, 0.07103994980986629, 0.0615555230262024, 0.03224410282980118, 0.08257292131228106, 0.018135129108226726, 0.0334546907272722, 0.04844389909080096, 0.02464799489825964, 0.060109775247318406, 0.03444202024755733, 0.036579812677311044, 0.03716118148128901, 0.02559745029014136, 0.01020236433084522, 0.038177274101014645, 0.04867087583988905, 0.015095139554302608, 0.026912201794662645, 0.0074808926853750434, 0.023252913329218115, 0.028912170191428492, 0.03771249796929104, 0.04713186342269182, 0.01446335220576397, 0.028099631291947195, 0.03604494048548596, 0.06767763237335853, 0.02181213073033307, 0.025059054805231944, 0.06430257204920053, 0.04550304689577647, 0.030820054600813558, 0.04213446658104658, 0.026603704152096595, 0.014509155015860285, 0.01540009185139622, 0.022760069596448114, 0.017176813745339, 0.0179189682073359, 0.030481255280652216, 0.016073980601504445, 0.047750694145049365, 0.03465702424624136, 0.005435894584349755, 0.021394505997055342, 0.01703869115694293, 0.02800654137640127, 0.05316761561802455, 0.054774047274674685, 0.028447631546961408, 0.016675303424043313, 0.024149444685982804, 0.016370726017547504, 0.023141316371038556, 0.035192083035196574, 0.013995559985882469, 0.06706734440688576, 0.018550097376906445, 0.04993247600006206, 0.032543207851371596, 0.03232091299391218, 0.058361319425914965, 0.02237771850611482, 0.028087019022288065, 0.02082849244054939, 0.022945837217516134, 0.10916350768612963, 0.05505303034026708, 0.03244672017171979, 0.028513184815113033, 0.015439602945532118, 0.011177797435915895, 0.030094442822571312, 0.004832511135776128, 0.06635357985006911, 0.07280919594424111, 0.15988298931292125, 0.09003623654799801, 0.09146119401391063, 0.13413627658571514, 0.11092115765703575, 0.20492715654628618, 0.08332253287413291, 0.11758194917014667, 0.17075283532696112, 0.1456325596996716, 0.13761109512831482, 0.07898174758468356, 0.09649827158344643, 0.1799301571611847, 0.16907521177615437, 0.13077936028795584, 0.1333855725824833, 0.12232827448419162, 0.12841353937983513, 0.11384658675108637, 0.11940089799463749, 0.29798999854496544, 0.11058513354510069, 0.08144009352794715, 0.161739922527756, 0.11900390072592668, 0.14433821343949862, 0.17328135536185332, 0.11478266652141299, 0.12380031549504825, 0.1460226901939937, 0.0907837242952415, 0.09505923451589686, 0.11643705703318119, 0.18124085611530713, 0.15212912538221904, 0.18097458540328912, 0.12601406313478947, 0.15914348113749707, 0.19073147113834107, 0.16075789236596652, 0.17345860227942467, 0.05549697883959327, 0.19567040540277958, 0.09231335935848099, 0.1180201063730887, 0.12464628581489835, 0.13737497851252556, 0.09374216411794935, 0.10896605399570294, 0.14487686167870248, 0.10524104602102723, 0.20266573503613472, 0.15903305634856224, 0.053842428872095685, 0.1239510995468923, 0.10283561223851782, 0.14246492753071444, 0.08547378065330641, 0.13597395297672066, 0.10907217687261955, 0.0928887841956956, 0.11796760133334569, 0.08996151627174445, 0.07467917060213429, 0.12275590082364422, 0.1397102924862078, 0.14375744174633706, 0.10194859055003949, 0.09564445061343056, 0.14594269091529505, 0.14840468737695897, 0.0876992398074695, 0.15316538406269892, 0.12973689979740552, 0.07563500931220395, 0.12783678461398396, 0.14749606113348687, 0.20283458169017518, 0.24443184531160764, 0.09840867335775069, 0.15015184719647678, 0.1618131771683693, 0.16444072260388307, 0.13397652230092458, 0.09142970320369516, 0.17602446888174328, 0.12588309230548994, 0.1059489683913333, 0.1626003456435033, 0.13377707371754305, 0.18832567094692163, 0.11300567151712519, 0.17360451444983482, 0.07185674312391452, 0.17880349047482014, 0.22326162058327878, 0.09157731849700212, 0.08820072468370199, 0.09616326527403933, 0.16751732251473836, 0.1263380636061941, 0.12405537680855819, 0.12276298472923891, 0.08598540284271751, 0.12907657665865763, 0.15688837000301906, 0.1061371329373547, 0.09766282087990216, 0.13337661592023714, 0.12770847364195756, 0.10034692220922027, 0.10920637752860785, 0.09761459739612681, 0.12623625621199608, 0.30400312159742626, 0.13674864997821196, 0.0855985903846366, 0.09541577752679586, 0.1567203647324017, 0.11087390447833709, 0.12765189739210264, 0.05868647340685129, 0.11348496829824788, 0.14535490317004068, 0.1360595840960741, 0.14046221785247326, 0.16943752233471188, 0.11681814944105488, 0.14953383750149182, 0.17060662460114273, 0.11621622102601187, 0.08028982739363398, 0.12394530485783305, 0.13433442238186086, 0.08838146605661937, 0.1353207951677697, 0.15163887026054518, 0.07870704268238374, 0.21775070843952044, 0.1247336675545999, 0.12315315593566213, 0.1048414363924946, 0.09986727937523808, 0.15818864665925503, 0.11001935069050107, 0.09824691739465509, 0.10394101363739797, 0.13352957128414086, 0.11535681571279253, 0.10520788601466588, 0.09173710670854364, 0.09878978612167494, 0.1446681578776666, 0.0768104355250086, 0.10361927947295563, 0.15752776712179184, 0.14608819596469402, 0.13575348337846144, 0.11997664852866105, 0.12794927214937551, 0.17751021629997663, 0.141722243811403, 0.16654624390814984, 0.06582111985023532, 0.0696575500603233, 0.1946486538009984, 0.12811145558953285, 0.18261832291526453, 0.09162871752466474, 0.1393701157399586, 0.10076883528381586, 0.11200601301555123, 0.20287005550095014, 0.2193494319383587, 0.14389359658317907], [0.025847425983686532, 0.05242967146581837, 0.059905522636004856, 0.020577112179515616, 0.008262661718098181, 0.055581822858325074, 0.01604528196289071, 0.029399816345955645, 0.07545814915959324, 0.03925863500418408, 0.02643862845642226, 0.07021054931517158, 0.047864793201110194, 0.03673971284713064, 0.02841712800519807, 0.008274370688013732, 0.0012884484125866688, 0.017320893871198808, 0.06053704874856131, 0.0085908792846437, 0.020244131297139183, 0.06130339976932321, 0.011546854328896319, 0.05141235069770898, 0.037208485550114086, 0.033404818403401544, 0.030091538692691495, 0.02520274307711848, 0.016184200133596147, 0.03244558362556355, 0.03147970598989299, 0.058158179612032006, 0.016071010314460312, 0.0014740568959885941, 0.03794477068419967, 0.01887965335377625, 0.029362503705280166, 0.031582687249673266, 0.012650610280356236, 0.026647902226873806, 0.05030697983290468, 0.09462629524724823, 0.054562147573700974, 0.01300014741718769, 0.07808175230664866, 0.03922416203256164, 0.05675389710813761, 0.03498332155868411, 0.05366778413632086, 0.07399061362126044, 0.011711550044960209, 0.0710764889206205, 0.020918798666181307, 0.02342440457349377, 0.0033324061285903944, 0.04485716637490051, 0.03897481059123363, 0.04137972529445376, 0.07736536860466003, 0.07462543741400753, 0.04530878231993743, 0.028042264548795562, 0.04139610512980393, 0.03251732174041016, 0.044971964322030544, 0.008403933557149555, 0.019569066985111152, 0.07922369960163321, 0.042427115341914554, 0.05573195551655122, 0.04479565717546003, 0.05876324964421136, 0.055681594647467136, 0.09832315758935042, 0.007230650666835052, 0.06032107105212552, 0.014853363956457801, 0.009972548760872866, 0.05284149133201156, 0.0467384793529553, 0.05329782309542809, 0.02150680693531675, 0.05955139520977225, 0.01661585527472198, 0.0682893181219697, 0.05292801133223942, 0.039543863984623125, 0.042472030967473984, 0.06429312684174095, 0.01916200195306114, 0.03679795490045633, 0.055951129112924845, 0.06476068496704102, 0.029514746607414315, 0.024996337813458273, 0.05160397577232548, 0.029611390350120406, 0.028498409715081965, 0.04381028183602861, 0.0610185032710433, 0.054887640822146616, 0.0469964753304209, 0.033082398918590376, 0.045459447628153224, 0.040223457517900636, 0.04781750270298549, 0.0579994906272207, 0.017851667711511254, 0.024567261105403304, 0.04572253261825868, 0.04771888442337513, 0.0749750661530665, 0.01588463201187551, 0.01856226859880345, 0.012814912446109312, 0.007132411518666361, 0.06082811313016074, 0.04974181105249694, 0.038445560062038045, 0.0486244606519384, 0.02376507834664413, 0.046330639094646485, 0.04268657016967024, 0.042780723688857894, 0.03865921716871006, 0.03232885863898056, 0.02918470378166863, 0.02757189898485584, 0.030589118599891663, 0.01445741841702589, 0.07625517674854823, 0.03603464710925307, 0.03605421266651579, 0.026916827707152282, 0.04459153348580003, 0.05816587419914348, 0.04674261163121887, 0.0419157713518611, 0.06353326940110751, 0.018868384583454047, 0.01049263313013528, 0.0954779109784535, 0.019167414966172407, 0.02663957151318235, 0.05408082197287253, 0.021135987547625388, 0.031001986802688668, 0.026530198453526412, 0.03235749960211771, 0.08921324142387935, 0.03540487161704472, 0.02428808805000569, 0.06332635693252087, 0.026665452535131147, 0.01006447583703058, 0.01437662185968033, 0.035797112355274815, 0.0276102480877723, 0.008819325062047158, 0.04925629889060344, 0.03025603593726243, 0.03766584190140877, 0.030745914472000938, 0.005725197319407016, 0.07553300514285054, 0.03886967837544424, 0.021884532113160406, 0.03317461861297488, 0.025622579834557006, 0.07367831787892751, 0.008916113841613489, 0.025726153116141046, 0.02624743594788015, 0.07099384335534913, 0.030641755953963314, 0.032274806539395025, 0.042499494672353776, 0.0645607342677457, 0.03272297552653721, 0.04463779600337148, 0.016493245693189756, 0.07642700895667076, 0.021588251493605118, 0.012867762690543063, 0.0410834531565862, 0.05098408314266375, 0.03746461894895349, 0.02887525110106383, 0.054215236367391687, 0.05855419300496578, 0.013002667326613196, 0.0287505126159106, 0.03191724233329296, 0.06740189609783036, 0.0360569709113666, 0.004903183526559067, 0.027640800823324492, 0.0709628275196467, 0.016105254280513952, 0.016262604855000973, 0.03807020806042211, 0.020864490419626236, 0.03233574916209493, 0.007872424354510648, 0.03857521453340139, 0.030112708985273327, 0.049800453441483636, 0.040763221947210174, 0.025500869311924492, 0.028571043496153185, 0.08155406705502953, 0.0808058057778648, 0.03259224557716932, 0.030306932849011252, 0.026375595945864916, 0.05021467871431794, 0.059063901725624285, 0.03921268122004611, 0.03154868585988879, 0.0014462549838104419, 0.03817040393395083, 0.03732778896976795, 0.02172435204764562, 0.0382612869143486, 0.03685678727924824, 0.04620507958212069, 0.04407913098111749, 0.07543320621230773, 0.03576456642310534, 0.06156153484646763, 0.01208313532905387, 0.04734498109402401, 0.04449680660452161, 0.01666894894359367, 0.058515285806996484, 0.05920121007199798, 0.03817700947235737, 0.01739694068341383, 0.01888322244797434, 0.01308210681392146, 0.03905297104003174, 0.016667412061776434, 0.017466502397188118, 0.03945050435140729, 0.03716047919754471, 0.06491400673985481, 0.030309928581118584, 0.02884670513282929, 0.0743173078766891, 0.0440019103033202, 0.02733500375013266, 0.0447077665344945, 0.06258194294891187, 0.025354941874476414, 0.014010684531448143, 0.026301766246823326, 0.03452590074656265, 0.03480428670133863, 0.028419575820277845, 0.008244870529909219, 0.08562577249748365, 0.01904546865262091, 0.022759993261258517, 0.027902021538466215, 0.05326126702129841, 0.018893975531682372, 0.02366455677630646, 0.06323417795023747, 0.014665050132732307, 0.029459673312625716, 0.05080191006085702, 0.007818552914873829, 0.02947940511096801, 0.04294119043541806, 0.05105325300246477, 0.09613158447401864, 0.024359705724886486, 0.058787615836731026, 0.03289389849773475, 0.01672159817202815, 0.057703540793487, 0.09128378424793482, 0.049521046291504583, 0.07988149859011173, 0.026775670370885303, 0.033540898601391485, 0.0468988782460136, 0.02781878734406616, 0.039510602198008976, 0.03319939871185592, 0.022883357712998986, 0.017000598200996007, 0.05169005472479122, 0.023536510432937315, 0.025369757686608603, 0.024327541468665004, 0.023146949908030883, 0.00674468431056344, 0.036306722688355615, 0.0026065738264670862, 0.0195540815392243, 0.02113293414004147, 0.03466019979012864, 0.02063359004179282, 0.04411616202976022, 0.07233786516423736, 0.037091506112899096, 0.05127969370888812, 0.008135065752347665, 0.027240359989394034, 0.07463997163410697, 0.01942240503350539, 0.05182834016159177, 0.024548207842079655, 0.08841252260442291, 0.06719484792223998, 0.013217876582140369, 0.013933099989247109, 0.03939330045666013, 0.022802478035113642, 0.006752979401166418, 0.055264302396348546, 0.015382175134228808, 0.05439195742032357, 0.12127826868423394, 0.02572713529558054, 0.032011646910437515, 0.011466874558079456, 0.023616323114505837, 0.02910836859207068, 0.03244196703391416, 0.017438896199954406, 0.008236468570040805, 0.05260779369356377, 0.01215777248476765, 0.00904101602333997, 0.038669924451304336, 0.04315301549753972, 0.013111271945360516, 0.02215638547204435, 0.025522261824724928, 0.010394409249004508, 0.033632850274443626, 0.02220371668227017, 0.03994442695485694, 0.03152813642684903, 0.04261514757360731, 0.025856445410421917, 0.030157098746193305, 0.033376292791217566, 0.07191798090934753, 0.03325895373044269, 0.10438565084976809, 0.18247459562761442, 0.10466759572071688, 0.11718333698809147, 0.07472050695547036, 0.14165637163179262, 0.07940313140196459, 0.141419115077172, 0.12466776823358876, 0.12903741161738122, 0.10425643742616687, 0.1379431973078421, 0.15920989614512238, 0.0911479958200029, 0.12548597290047578, 0.11064473606113877, 0.0668638992522444, 0.09925411442028624, 0.18784140050411224, 0.12634051990296158, 0.10539069013403994, 0.22259821689554624, 0.11537394193666321, 0.12950846419802733, 0.08722414315811225, 0.1769597479807479, 0.11078462284058332, 0.10534811884696994, 0.08232807195080177, 0.1343615094998053, 0.10733459796756506, 0.19060301088861056, 0.13461606869740145, 0.09344357478299312, 0.20747287065855094, 0.1639154279338462, 0.0792689375313265, 0.11565039067396096, 0.13883199675806931, 0.09865407911794526, 0.23677474047456468, 0.17360595294407435, 0.17500016598829202, 0.10612352152488061, 0.13190620339342526, 0.11080729948090655, 0.1602132594478982, 0.1037799972774727, 0.08721399905958346, 0.17575158923864365, 0.1331255715340376, 0.2080865241587162, 0.06687264556863479, 0.15370148101023265, 0.13690915065152304, 0.14483901299536228, 0.09467989951372147, 0.14177233326647962, 0.2031952773353883, 0.16832009729530129, 0.12089239938982896, 0.15579363517463207, 0.09905583291713681, 0.0955792230420879, 0.20621758087405137, 0.1298735567501613, 0.13917548475520952, 0.24157448006527765, 0.09219275654426642, 0.19386105106345244, 0.1831900022391762, 0.1834305836153882, 0.1682990219976221, 0.23209960705467633, 0.08009320151593004, 0.1523037531546184, 0.2173281575420073, 0.16297725827566215, 0.14873681669788702, 0.1599169974880559, 0.12857497643147195, 0.07710838025169713, 0.18678748634244713, 0.09464781837803976, 0.13680644759110042, 0.20173292580459798, 0.13052994438580104, 0.14207548914211138, 0.10475505888462067, 0.11190638371876307, 0.13070856194411004, 0.14738790265151433, 0.13458157197705337, 0.13815747866673128, 0.10605035509381976, 0.1104076084281717, 0.1584753684167351, 0.11050366184541158, 0.131464436384184, 0.17099929281643458, 0.1219461914151907, 0.10927258219037737, 0.07830550601439816, 0.08935042763394968, 0.13003333817635263, 0.29503842549664633, 0.12595925107598305, 0.13661229158086435, 0.1410942053688424, 0.15173402801156044, 0.14814886610422814, 0.16901338366525515, 0.11067444910960537, 0.06823062484285661, 0.08138231627110924, 0.13098429143428802, 0.12520633504859038, 0.13246214070490428, 0.0692753584257194, 0.10540564504585095, 0.16267353243061475, 0.10292244436485426, 0.1292010878345796, 0.10612938406744174, 0.13685698487928935, 0.12354157652173724, 0.1493561834629093, 0.11127193312027625, 0.19679168452109608, 0.11018880802605834, 0.14990400549556526, 0.1357544468981879, 0.11723149940371513, 0.08086584934166499, 0.10113673018557684, 0.12160856596061162, 0.11691471854490892, 0.10196470575673239, 0.21196402609348297, 0.1429653199655669, 0.10219271387904882, 0.19321203231811523, 0.14348057231732778, 0.1029139491064208, 0.09665328969380685, 0.1246230663465602, 0.14513071519987925, 0.1469509939530066, 0.15612626661147389, 0.12191449025911943, 0.09591951513929026, 0.11444293760827609, 0.17219920057271207, 0.17369598097034863, 0.08960598427802324, 0.053396193709756644, 0.09624450627182211, 0.18845552897879056, 0.07746294194034167, 0.10866205673664808, 0.2649849424404757, 0.13340724499097892, 0.084661201041724, 0.08136645890772343, 0.11452284189207212, 0.14066374275301183, 0.11130480814192976, 0.11619769702000277, 0.11690679325589112, 0.1897210239299706, 0.1792306282690593, 0.14073979295790195, 0.1257135264043297, 0.11001669761857816, 0.13603470900229045, 0.08948919483061347], [0.008213920003202344, 0.02349384923997734, 0.014741300505452921, 0.04511164754096951, 0.043076646381190846, 0.042251208531005044, 0.05391531031844871, 0.05280857559825693, 0.0024459983022617443, 0.05871477510247912, 0.02575149300641247, 0.01903242720956249, 0.024430773786402175, 0.03521117701062134, 0.03977073895345841, 0.03266367495858243, 0.016414343944883773, 0.0329335826183004, 0.007372982716853065, 0.03166646596842578, 0.02944425360432693, 0.018814435960458856, 0.011674971918442419, 0.02717180929279753, 0.0452177772032363, 0.024536309730527655, 0.02753848283152495, 0.05233798102874841, 0.026286962309053967, 0.05174296688554542, 0.05547576444223523, 0.07309426207627569, 0.043601615354418755, 0.036403987290603776, 0.036844081711024046, 0.027729582041502, 0.03549731522798538, 0.057030074431427887, 0.05908475310674735, 0.031968753319233656, 0.046679277172578235, 0.01514920183191342, 0.025890022715819732, 0.02761793928220868, 0.04278853701959763, 0.0554177463054657, 0.08062004324580942, 0.029139984931264604, 0.13131063963685716, 0.028652823929275786, 0.042734966679875336, 0.02320917326557849, 0.020562097895890474, 0.016666316227721314, 0.01755925813423736, 0.015171659644693136, 0.04530169162899256, 0.0375275700353086, 0.04480257823265024, 0.0482297161194895, 0.044318921864032745, 0.026165222948683158, 0.061857586460454125, 0.020129311297621046, 0.07135514968207904, 0.013793397262426359, 0.01104788257673915, 0.0163672400438892, 0.031025443758283342, 0.014209446098123277, 0.03076193468379123, 0.011817002020377134, 0.03769011649170092, 0.030729704270405427, 0.025855054413633685, 0.02849719174472349, 0.02797468754995082, 0.0285900119425995, 0.03661198880789535, 0.0478872289615018, 0.0063395068781184295, 0.0341243030104254, 0.014162164929855083, 0.026805751524599533, 0.011679473998291152, 0.024631589617846266, 0.05561715417674609, 0.023734210092308264, 0.033093357259141545, 0.05413362896069884, 0.023502649839169214, 0.036774657400591035, 0.0204646144660988, 0.031610965196575434, 0.021977866301313043, 0.030923405662178993, 0.006171508816935654, 0.06918942196560757, 0.04583654685744217, 0.043026617994265895, 0.06593429949134588, 0.05125041492283344, 0.04357067076489329, 0.03840480724881802, 0.03910684332783733, 0.032064796558448246, 0.024929456313007643, 0.08628379540251833, 0.04156949457579425, 0.026713896542787552, 0.03522923622014267, 0.01959304471633264, 0.06917233645383801, 0.022521121793293526, 0.06488590181938239, 0.01931558156918202, 0.05630801139133317, 0.02217191713862121, 0.03381216333114675, 0.028781029728374312, 0.020017179993114302, 0.03061572735064796, 0.020552035221563916, 0.060059224388429096, 0.047318155212061744, 0.054132584016770124, 0.08137800078839064, 0.03934573515185288, 0.0025869594994998935, 0.04001063161662646, 0.05775484482624701, 0.016657035565003753, 0.04255907004699111, 0.02487512262138937, 0.04342825983517936, 0.05777264279978616, 0.05475946555712393, 0.013217901179034795, 0.014720942758555924, 0.024377042294612954, 0.0406473926268518, 0.03174475873155253, 0.011342320125550032, 0.05437248685796346, 0.022889824151726704, 0.0473935336672834, 0.01654874307236501, 0.03627346090174147, 0.021083782759628127, 0.0723571762708681, 0.007594685552508703, 0.08136723243764468, 0.025965988103832518, 0.018399513492892896, 0.022830660987113203, 0.04374375147745013, 0.00854046582909567, 0.021609257241444926, 0.10644083842635155, 0.026994374081758515, 0.03859777921544654, 0.02411505313856261, 0.01616079915714051, 0.008844356218885099, 0.005761316162534058, 0.03790885582566261, 0.05278889469004103, 0.03271569484578712, 0.09127191667045866, 0.06057542668921607, 0.03725763862686498, 0.051307252408670526, 0.05359340991292681, 0.05527053813316992, 0.026319684660328285, 0.07276254666170903, 0.017020077245043855, 0.03611112139852984, 0.023219734663143754, 0.03561527854097741, 0.01020574089073177, 0.04885039584977286, 0.04045156742046986, 0.007334823603741825, 0.02665742376952299, 0.038141674761261256, 0.027614818021122898, 0.034168689378670285, 0.0731247350839632, 0.07004514961902585, 0.08339649319116559, 0.022193793107622435, 0.024260661664551923, 0.013062014543850507, 0.03651475813239813, 0.0200618360790291, 0.031015001104346344, 0.030906968151352236, 0.023263099836185575, 0.038088335123445304, 0.018418576934241822, 0.058752175952707014, 0.014734175887757113, 0.07255633986954178, 0.03357772948220372, 0.016215277037450244, 0.049152924080512354, 0.06197624866451536, 0.02134378211173628, 0.01611211766222758, 0.04286406814519848, 0.028611345083585808, 0.023088807938620448, 0.01646093724827681, 0.01321351360197046, 0.026747702853754163, 0.02114812484277146, 0.021139076578297784, 0.02730773512407073, 0.06660617129611117, 0.020391095196828246, 0.04776088574102946, 0.035514251462050846, 0.022836749142568027, 0.036189855209418705, 0.02407652252752866, 0.04721948604232498, 0.028474772947707346, 0.040971104720873494, 0.03245771922437208, 0.016034299873613884, 0.022237214259803295, 0.028839010545717816, 0.02723657206765243, 0.007841271115466952, 0.00900594933357622, 0.035029444976576736, 0.012792136570039605, 0.052538674723889144, 0.03148947350148644, 0.08123778152678694, 0.023811663168349435, 0.05522181253348078, 0.06584072272692408, 0.06181072683206626, 0.04045766405761242, 0.019813865456464033, 0.010962751028793198, 0.0521909899876586, 0.03461326552288873, 0.03148193497742925, 0.0273028547609491, 0.036757500642644506, 0.027065352237384235, 0.07399039649005447, 0.04068050852843693, 0.05519616051710077, 0.05622986451323543, 0.019077536217602234, 0.05504573269614151, 0.04873156061928187, 0.026706302039591328, 0.03916100399302585, 0.04175213245408876, 0.012947852723300457, 0.05254390283620783, 0.04448619431682995, 0.009234488409544741, 0.01914936932735145, 0.030453964602202177, 0.050949376076459885, 0.035937942298395295, 0.012335898953356912, 0.04881625875298466, 0.06239578008119549, 0.08294004946947098, 0.09581603854894638, 0.07884559953319174, 0.04773452804823007, 0.026422328348936777, 0.02743201899076147, 0.002030517315558557, 0.010173172058005418, 0.021864169277250767, 0.033669548840927224, 0.0376075930627329, 0.02488289524002799, 0.02938082754345877, 0.0604946335245456, 0.032145277597010136, 0.03158536746299692, 0.044679454660841396, 0.02004558007631983, 0.010745432377526802, 0.011425872383240079, 0.017015809259776558, 0.05339120647736958, 0.023404543853497932, 0.021114898679245795, 0.0418348967629884, 0.029520744856979166, 0.029595987605197088, 0.03972559941134282, 0.030509295740297863, 0.014180099458566733, 0.022788054076954722, 0.01083194898507957, 0.027452417449759584, 0.04094673852835383, 0.0556476237917585, 0.03597769427246281, 0.05213760963774153, 0.07376772165298462, 0.034100913908332586, 0.028850002813019922, 0.011465638776176741, 0.010809077265938478, 0.036276867147535086, 0.05217644898220897, 0.03614277844982488, 0.04289301105641893, 0.037596180103719234, 0.06289537184472595, 0.056778683992368836, 0.04303926249433841, 0.043566840434713025, 0.016217436475147094, 0.0220523898024112, 0.040894572756120136, 0.029081396825079407, 0.03395768873659628, 0.023767741596592323, 0.024691848616514887, 0.02943388558924198, 0.050005425299916945, 0.04052400103371058, 0.016482428148654953, 0.016981899472219602, 0.024006231388609325, 0.005320978317675846, 0.031024412385054996, 0.038566722667643, 0.06172765378973313, 0.004909960395057819, 0.04087929554017527, 0.02824448325139071, 0.028361130206446563, 0.028152680856042674, 0.020614094034369503, 0.019535503250413706, 0.049937130750289986, 0.08567776863596269, 0.10674336326441594, 0.07230796212596552, 0.14890161928321632, 0.11366562824696302, 0.13370041283113615, 0.14012992568314075, 0.16979781085891382, 0.12158595717379025, 0.05512574893821563, 0.13051247889442102, 0.06973565622631993, 0.06001863442361355, 0.19430272307779106, 0.116586958989501, 0.19024663072611603, 0.10629608655082327, 0.20788479569767201, 0.12460602154689175, 0.12892157211899757, 0.17551193067005702, 0.1663978618702718, 0.09868828406823532, 0.11478888190218381, 0.17632755690387317, 0.13010135452662194, 0.103094174792724, 0.13477982633880206, 0.1509123221039772, 0.17859866789409093, 0.08407160160796982, 0.167843507868903, 0.1319486525441919, 0.08689921309373208, 0.14169928218637193, 0.07085791243506329, 0.11604846002800123, 0.1208410207182169, 0.09433495945164136, 0.16498534195125103, 0.1227360333182982, 0.1388633315052305, 0.07665341573634318, 0.17314457627279417, 0.18546859068529947, 0.12844247211303028, 0.18748762591608933, 0.18509982047336443, 0.09691688697785139, 0.253178351691791, 0.09921144135296345, 0.18948850354978017, 0.11562540701457433, 0.11511947773396969, 0.1034674369064825, 0.1306311818105834, 0.07877531009060995, 0.12431260943412781, 0.06672416175050394, 0.10612833912351302, 0.13709321006068162, 0.1010091384606702, 0.0979454917833209, 0.13569245593888418, 0.0909773985456143, 0.15184874114181313, 0.1256487670221499, 0.1470056160220078, 0.12296483532658645, 0.14880004259092466, 0.1580458828913314, 0.0890421284628766, 0.18907287370945725, 0.16980403981038503, 0.07697903790644237, 0.12689478801829474, 0.062205322086811066, 0.12922270596027374, 0.08363037064139332, 0.16387618146836758, 0.09821854106017522, 0.09491520867283855, 0.1447656633598464, 0.1362367495894432, 0.15635101098035062, 0.10464039325181927, 0.14473143805350575, 0.0983596220612526, 0.1540737117507628, 0.13115952988820417, 0.1428943316319159, 0.11148117974932704, 0.0777539045416883, 0.13850857982678072, 0.08596456503229481, 0.13685823338372366, 0.11630323635680334, 0.19182415679097176, 0.15795688623828547, 0.15731284793998512, 0.22436470139239514, 0.20522020225014004, 0.11875713111034461, 0.15980270504951477, 0.1579192275447505, 0.0953138954937458, 0.1762498782149383, 0.08585308851408106, 0.19190795586577483, 0.2300484771175044, 0.09982000584048883, 0.28842878873859135, 0.19219820600535187, 0.14718506139303955, 0.1479451156088284, 0.17265820237142698, 0.10339084387357746, 0.11278640292584896, 0.06182507106236049, 0.1290616760296481, 0.09736453688570432, 0.11435641082269804, 0.09564109865043845, 0.09809028437095028, 0.1569630495671715, 0.11174731475434133, 0.13570392318069935, 0.22351763184581483, 0.12675878245915684, 0.10097133727478129, 0.0911527591358338, 0.06125804648867675, 0.11960224647607122, 0.18730676919221878, 0.15135650469788484, 0.13715243259710924, 0.19617687751139912, 0.19954071486634867, 0.08688212758196251, 0.06947298853525094, 0.06039469888699906, 0.11876877477126462, 0.11487067251333169, 0.17636615197573388, 0.08936792705208063, 0.09924170401479517, 0.12668402147080216, 0.09511588540460382, 0.12302185940955367, 0.11998694869024412, 0.14011046529880591, 0.07237508959536042, 0.17591198134635175, 0.18792072124779224, 0.09021472518465348, 0.16641696941639694, 0.09097317805779831, 0.11172733189804213, 0.10787262873990194, 0.23971890392048018, 0.15758910668747766, 0.12173484132758208, 0.11930830510599272, 0.129489858767816, 0.08522566075303725, 0.15222494809755258, 0.10971112615828003, 0.1603414211422205, 0.0696936956207667, 0.2208016732973712, 0.1471364918564047, 0.1602271015622786, 0.09682022966444492, 0.16656737348863057, 0.1318799848003047, 0.18559240975550242, 0.16486935317516327], [0.04415155102365783, 0.026597709295206835, 0.055364365955548625, 0.01731731799165053, 0.039421463052609136, 0.06036938953080347, 0.05364425593454923, 0.08813527319580317, 0.03200098712529455, 0.04257550755781787, 0.06898490472563676, 0.03523273067548871, 0.03201732964121869, 0.03731276959713016, 0.07158039616686956, 0.03341291332617402, 0.019258233485743403, 0.019194775194461857, 0.08258002557392631, 0.03915875464943903, 0.042486080035035095, 0.03336966350408537, 0.02034907352312335, 0.026017115717487674, 0.060803672298789024, 0.04023880258734737, 0.09691819655043737, 0.0749398705416492, 0.007839171049584235, 0.03950172017461487, 0.04616915115288325, 0.04071090689727238, 0.04134629387408495, 0.011227198177948594, 0.013821885555184312, 0.03696160397625395, 0.0210797539579549, 0.0400779897879277, 0.042950404940971305, 0.08552606177649327, 0.02188857109285891, 0.032500643349651775, 0.03457695032869067, 0.042153384137366495, 0.024829369005081908, 0.0648959916351097, 0.07645183655300311, 0.04894002693306122, 0.044034395167337995, 0.048480329635952196, 0.06065604343478169, 0.06476915308407374, 0.03314424738554018, 0.00678263435007206, 0.04442451209095972, 0.017091586354321668, 0.055486023891717196, 0.048332799159522565, 0.005430573597550392, 0.031765901882733615, 0.0055945364957941425, 0.05670374997758439, 0.07293437886983156, 0.0380612785395767, 0.025587577605620027, 0.032987906131893396, 0.020207919579531466, 0.02421099290118686, 0.03508402633347681, 0.03899950248056224, 0.05029136334945049, 0.01795587033432509, 0.02746741477000926, 0.006453970646751779, 0.014460817877469319, 0.06531545519828796, 0.006329119355151696, 0.011755553889088333, 0.021468469706763114, 0.056186618083821874, 0.036681077243494134, 0.04607302988214152, 0.04369844230157988, 0.016182580131239126, 0.031088170928082297, 0.00575417118878769, 0.020402345307437435, 0.03038791600348694, 0.015452359403882707, 0.02955485481236662, 0.046186290947454314, 0.04172865514244352, 0.05092845344915986, 0.046898304883922846, 0.062183826097420285, 0.03950230032205582, 0.03584096946620515, 0.07506871077099017, 0.020320860037047948, 0.04386431697223868, 0.009314774369288768, 0.018749082860137736, 0.046159970574080944, 0.04270506024892841, 0.04762383184528776, 0.05372931708448699, 0.004806608909607998, 0.032746910849320035, 0.030769011804035733, 0.028134458798116872, 0.009470302229081946, 0.056254196779004166, 0.015612739637227995, 0.027369223967460648, 0.06255407551569597, 0.04166282706760934, 0.017827080995110527, 0.02442740316369704, 0.040628271510026286, 0.039998309420687814, 0.04478793544694781, 0.01809517526999116, 0.053542044812015126, 0.08008338311421019, 0.03926144413916128, 0.05224590043404272, 0.02260400484582143, 0.027134635751800876, 0.03360116947442293, 0.02190645388327539, 0.027581781847402453, 0.0056236643078071726, 0.027607118344998786, 0.0212288077455014, 0.018928331456014087, 0.08679382981998579, 0.030362806815121855, 0.030467772789831673, 0.028174298981736814, 0.02519364222618086, 0.03080543895651187, 0.02403980021231941, 0.03777602241773691, 0.026930415370900716, 0.030062185267784765, 0.06333857056285654, 0.06034289952367544, 0.08295933343470097, 0.025963268874745284, 0.020427010055365305, 0.031050766685179303, 0.022347040241584182, 0.0056346561510248905, 0.03353219638977732, 0.029296081912304674, 0.04785674238311393, 0.0414155485507633, 0.027645767699660997, 0.030060319296483482, 0.02910791736628328, 0.01526963840504842, 0.049556051913116655, 0.02108847482928208, 0.029447452896939855, 0.02969877208982195, 0.08654364038790975, 0.008505081924210702, 0.07674241917473928, 0.05263918950887663, 0.049089206249586174, 0.013041569435569857, 0.015303831480975662, 0.014090574396375035, 0.04394020093604922, 0.04152568496231522, 0.013705587197494293, 0.027923030678981116, 0.018670330389535854, 0.06969672867230006, 0.016831505578011274, 0.06654785799660853, 0.009746353175225002, 0.037947922479361296, 0.05497921590826341, 0.02129432708690209, 0.023916990462956682, 0.037275328034801145, 0.011120497698097356, 0.043728002679667304, 0.015533646202779241, 0.05237842850121004, 0.03817905864811369, 0.015915961670024053, 0.0796736700992499, 0.05643001538036125, 0.04275746690109372, 0.00949342839885503, 0.03204925132117101, 0.06061391319547381, 0.04619928828573652, 0.033956623436617, 0.0017186799024264993, 0.03648615109601191, 0.035098133076514514, 0.02020555827766657, 0.07082897291651793, 0.07467794923910073, 0.07722846737929753, 0.020693092473915646, 0.01734608787644122, 0.04534835448222501, 0.056662949666913064, 0.0047652170012172845, 0.02445353185092764, 0.030800427975399152, 0.024657701341701404, 0.06111521486725126, 0.03057225700467825, 0.028716870849686008, 0.048109717201441526, 0.017796728427388837, 0.0340400086050587, 0.07165445826415505, 0.04239143457795892, 0.026674210725884353, 0.017701458718095506, 0.042873944222394905, 0.041102357142205746, 0.04351247960169401, 0.05265239380033953, 0.03479890252596565, 0.024810409040323327, 0.024415038559319716, 0.021714489541149566, 0.04749461502901145, 0.04504993478102343, 0.04232928077025073, 0.04527376312762499, 0.03509598890585559, 0.041672452086848874, 0.017491716758481095, 0.02774697628670505, 0.028628400061279535, 0.029918885457196405, 0.016551503013553362, 0.07625101732888392, 0.04429928166791797, 0.03057535451703838, 0.0460699798672327, 0.020319776077355658, 0.020280421046274047, 0.034819078764745166, 0.058190912141331604, 0.031577391283852715, 0.0037381571351683563, 0.006731745071842202, 0.022945545447458113, 0.015754192136228085, 0.02898856984185321, 0.08833087448562894, 0.04261964626078095, 0.03981590224429965, 0.03151957331491368, 0.04014280345290899, 0.013505248885069574, 0.04597516816907695, 0.045090870798698494, 0.04479801169197474, 0.052983488355364115, 0.009713086299598217, 0.024476140637749007, 0.01931914727070502, 0.057326757082981725, 0.023724440884377276, 0.08007789376590933, 0.042731523114655695, 0.02744102823947157, 0.08520190524203436, 0.0490759883874229, 0.025045872566157153, 0.047983082210911174, 0.09150675085506269, 0.032976564419056685, 0.026609151091958796, 0.03420066873409918, 0.022704294017915214, 0.03265918644943407, 0.04580702719145587, 0.024327466829812953, 0.01270203136040696, 0.023634733465899314, 0.006720053913470889, 0.016387272093977247, 0.05117795756086707, 0.02843562826248152, 0.01825498553392078, 0.05489687229107533, 0.029344040767422745, 0.023931880913940922, 0.006843134652756686, 0.045337111156966, 0.037624244312090535, 0.06935885894511427, 0.037952068328325234, 0.015462534036487341, 0.03390166888545666, 0.07204021220760685, 0.039129699779940505, 0.037601520174316, 0.07411728932389192, 0.0036324859081235316, 0.017564163942422186, 0.013522878073022833, 0.08732759939240557, 0.011593490040728023, 0.03447253057467086, 0.04212679913533585, 0.07155971441950117, 0.052385376699801, 0.04981438037274139, 0.022586320526897907, 0.03127918532118201, 0.019055573735386133, 0.045416438685996194, 0.006973097433469125, 0.03769896798101919, 0.02490976861944156, 0.008401888622237104, 0.041736729709165435, 0.034442420583218336, 0.08183322993240186, 0.06640934864325182, 0.031182371944721256, 0.015267109165766408, 0.01757361593523196, 0.03393732250801154, 0.011679141516132014, 0.04660900130069681, 0.03426367071058069, 0.014073954529262014, 0.043477959132620266, 0.043892218332205496, 0.023495910290096487, 0.06711895378040415, 0.03783762661208, 0.037925395116742165, 0.013717915330614363, 0.028351540810295513, 0.04992144302065883, 0.019502497610769103, 0.03684607660397887, 0.017941761894949844, 0.08150909375399351, 0.11665474463786397, 0.1264791174658707, 0.09577833235796009, 0.1927454580685922, 0.19938233122229576, 0.10313492082059383, 0.1736933346837759, 0.13347272362027848, 0.0904902850410768, 0.1781042329967022, 0.12808506057730742, 0.18636649607547692, 0.12042847142687865, 0.19898009566324099, 0.0942290604912809, 0.0763971194890993, 0.10948988981544971, 0.14497150374310358, 0.12994571216404438, 0.12581959499844483, 0.10453399217554502, 0.1657454775912421, 0.15639225233878407, 0.07214313239923545, 0.16329066003007547, 0.23222253045865468, 0.1540570469307048, 0.06975941173732281, 0.185101733942117, 0.13928163477352687, 0.15904944975461277, 0.1555138480450426, 0.10539434065244027, 0.1936091110110283, 0.14777582112167562, 0.14434092757957323, 0.132648534274527, 0.1624831219336816, 0.10209254175424576, 0.10576672745602471, 0.14400267787277699, 0.12506638041564397, 0.13475894103092806, 0.06583400523023945, 0.0906775878476245, 0.13531470192330225, 0.1646440252661705, 0.0976514011355383, 0.09557024602379117, 0.10846581083855458, 0.14839194448930876, 0.22707714512944221, 0.10721628860171352, 0.10945449742887702, 0.08216788340359926, 0.25208669741238865, 0.1274235025048256, 0.13384540219392094, 0.10776579340121575, 0.06787464501602308, 0.1798759964959962, 0.1547313207494361, 0.0869366003732596, 0.09315147902816534, 0.11759843757109982, 0.10140777778412614, 0.1828809023967811, 0.055076494081211944, 0.16524005042655127, 0.15572928291346344, 0.08595396631530353, 0.13302075144435677, 0.12140090710350446, 0.12049666419625282, 0.10832415986806154, 0.08615243102290801, 0.09717821116958346, 0.10034772966589246, 0.0910251402695264, 0.08631367129938942, 0.0853063657081553, 0.06830893456935883, 0.1650899720511266, 0.15312164569539682, 0.12774978285389288, 0.10282027056174618, 0.11871439697487013, 0.09445715003779956, 0.06840966309287719, 0.13285444251128606, 0.09815150180033275, 0.11497444765908377, 0.10906047892889806, 0.13535757176578045, 0.10787960407989365, 0.1377747713455132, 0.1728690910552229, 0.1840975156852177, 0.10185737508748259, 0.1301491233919348, 0.13582787795790605, 0.18333739361592702, 0.15692984206335886, 0.13372222094663552, 0.18203124084642955, 0.11928789477263178, 0.13984628447464534, 0.16711162642708846, 0.0835050723648497, 0.14679882568972452, 0.13590588234364986, 0.11135421227663755, 0.13557230095778192, 0.14479786663183145, 0.12491657345422677, 0.11458685488573142, 0.1319225967994758, 0.11708587221801281, 0.1556980295905045, 0.09228851140609809, 0.10866789213780846, 0.11603011244109698, 0.1917693175907646, 0.14384767333311693, 0.18937624671629497, 0.12679333346230642, 0.10511529312602111, 0.1567106345402343, 0.09831760717289788, 0.1329696848988533, 0.08523889897125107, 0.1819320118853024, 0.12036665688667979, 0.09214924887887069, 0.18437673284539155, 0.0972034391015768, 0.21361135984105722, 0.09966698940843344, 0.23645791890365736, 0.07763857394456863, 0.11898830799119813, 0.1569431684911251, 0.11954710872045585, 0.14640245267323085, 0.12884492480329104, 0.10930368623563222, 0.2004924552249057, 0.12270241869347435, 0.09066962863185576, 0.0859548891229289, 0.083472991229168, 0.11169497256300279, 0.1424990849835532, 0.14619465810911997, 0.1441799790731498, 0.08536940161138773, 0.06641938417617764, 0.20195093910608972, 0.08578135379190956, 0.0728479538645063, 0.17784408267055238, 0.12402706832758018, 0.12053346793566432, 0.12087124266794749, 0.11629540606268815, 0.09386267872261149, 0.13498827229653085, 0.15641597392303602, 0.13764161563345365, 0.14495099841484002, 0.10984424115823847, 0.11290774534323386, 0.12921484852475779, 0.13307683914899826, 0.092754244272198], [0.07751296354191643, 0.017316717488159026, 0.08460417695875679, 0.03475317944373403, 0.036217732820659876, 0.025451568653807044, 0.008240398135967553, 0.016302699489252906, 0.02314846813013511, 0.055194331865225515, 0.051899382778044255, 0.024365344350891452, 0.023083257522167902, 0.029795863665640354, 0.02648238548343735, 0.017025220540485213, 0.0298985056579113, 0.009991760631757123, 0.035425950307399035, 0.03798862100977983, 0.01140785388581987, 0.04085858665140612, 0.009053045601051832, 0.08387009027813162, 0.0715854512527585, 0.042956671211868525, 0.10192661958613566, 0.01543492783925363, 0.02735361935836928, 0.006433464894403836, 0.030724092785801207, 0.03572698915377259, 0.03480709922899093, 0.07522807829082012, 0.030495243280061653, 0.05634716286190918, 0.0318774632178247, 0.027000679368419305, 0.02105789664866669, 0.017764623542981486, 0.026452869210126143, 0.05302618856408766, 0.005059476434585771, 0.01711654626498265, 0.08139730510967118, 0.0474653226722564, 0.02701779711060226, 0.09856664309544222, 0.03935534320771694, 0.06127183432025569, 0.024255650683439205, 0.026561707923454896, 0.060913784961615286, 0.09186418953218631, 0.031306462428931675, 0.03847859453942094, 0.0829593130786504, 0.062300276277320724, 0.034371405108166594, 0.018890523484774997, 0.03984160515080605, 0.015911161034767116, 0.015784198651090264, 0.0494253524978246, 0.018113360008490936, 0.034790546367211, 0.042879915330559015, 0.04264112189412117, 0.031744093767234256, 0.04833015287294984, 0.027947250986471772, 0.05831094498613051, 0.031163929362914393, 0.03654650678592069, 0.034923186392656395, 0.002942818886367604, 0.04730858447562371, 0.03667869558557868, 0.017162769766790525, 0.08509084263018199, 0.08200483143861804, 0.02025699632109276, 0.02910908783919045, 0.024063396267592907, 0.03682908269443682, 0.04938131896778941, 0.08201762860906975, 0.013653882829073285, 0.09325647553695099, 0.07241213760737862, 0.05002777963610632, 0.005404685366167021, 0.03927467217934983, 0.030204144971711294, 0.019104380759277513, 0.06260919970061098, 0.006241076467891357, 0.03905729330810053, 0.031046702260417596, 0.05159588084955301, 0.0337086697774274, 0.021866435584213053, 0.006581783319623875, 0.04553505678528121, 0.05930463916489056, 0.025989093917555044, 0.05014166156096118, 0.017435252466904264, 0.027675027826002667, 0.01928252843208611, 0.03297501735921417, 0.05419281078502536, 0.021491495792620947, 0.025677279935085347, 0.0617541777236121, 0.09845424376960311, 0.050475890947771926, 0.040234327648899386, 0.02615096523160381, 0.08233939670026302, 0.0018172934110875108, 0.048931650418256006, 0.04571812553331256, 0.0341819852723607, 0.036131996528378556, 0.019289015226864388, 0.024911473438675915, 0.10782548412680626, 0.023454463674819896, 0.04784285955663238, 0.041699318680912256, 0.023272048016744, 0.07008806017360517, 0.06219743072454419, 0.007760062348097563, 0.01699973306884723, 0.04826029430010489, 0.025606615601905754, 0.07728308266294853, 0.057466440301920683, 0.008723951876163483, 0.04944172894049968, 0.06405351577060563, 0.045837361099464555, 0.027075930598324964, 0.05746568712804999, 0.030184535309672356, 0.022997409271608506, 0.03283613481159721, 0.01514882015596543, 0.022245999591957246, 0.011744691391608544, 0.01668448230650808, 0.027490252562399422, 0.01716129225678742, 0.02216157626493701, 0.04624104193810906, 0.03432949200006468, 0.04023125049258981, 0.046088361380887885, 0.042363383940288, 0.020205529439928274, 0.03051001838009272, 0.05781462376138993, 0.06327656603285245, 0.05205848566921694, 0.013836207733090435, 0.03354431502521038, 0.07447889420603003, 0.059405991940626075, 0.03726839340691056, 0.046921459891434224, 0.011375879619403608, 0.01251762589838888, 0.04030491564688938, 0.07405027042010001, 0.03391232527792454, 0.019786238903179765, 0.09773254713841847, 0.017065757918836813, 0.12088460980781487, 0.021059689677453468, 0.08171154146215745, 0.02765747412507023, 0.01161032703904701, 0.01089180595174964, 0.004350214805786631, 0.06748650941465582, 0.034089555232120414, 0.07035334700984613, 0.021748702973127365, 0.016692514464791332, 0.009624095583733703, 0.03033237112686038, 0.029862723113702874, 0.030039091328425065, 0.011075741528267307, 0.038162363293979845, 0.07382401291813169, 0.03964785626158118, 0.04604581384254353, 0.05547063132481916, 0.03943187856514539, 0.05916273035109043, 0.03050798616771187, 0.055540164200855155, 0.002640629287010857, 0.0169927458544927, 0.02883263910189271, 0.0349195664083319, 0.006504147887296442, 0.029765132814645767, 0.019920005296756114, 0.06183396665645497, 0.04644586791151336, 0.06259208704744067, 0.031887108593114784, 0.04325309941279037, 0.04822684930903571, 0.05341166091550674, 0.034936522998447926, 0.018273584178781936, 0.03458778314026339, 0.018823345125253712, 0.020029924577102065, 0.053264537560088296, 0.03409561454983694, 0.014998022533421005, 0.061704237546239576, 0.014206037307823343, 0.033568213028567176, 0.031222809239157608, 0.033101153626505814, 0.008836662479942399, 0.03197386268792408, 0.04886028889034476, 0.03782724502629467, 0.055299996731004546, 0.02175855530159814, 0.015936568778540407, 0.008543150283263197, 0.024200129555538297, 0.07475085104150431, 0.0021054943749082406, 0.02358179586008191, 0.052271549057747634, 0.05826012271323374, 0.02141044817731849, 0.04845099995977112, 0.04137190178568874, 0.09229667418237243, 0.04792048057009067, 0.021311913018247912, 0.013453651385914003, 0.021921686994444047, 0.06080425583890506, 0.05778459858681474, 0.004526242056661951, 0.019440901898113743, 0.027499241455058967, 0.0629651320299932, 0.03951799144436206, 0.06950998904981784, 0.04784901386925152, 0.03242824366316199, 0.02517307243709053, 0.04039831938488143, 0.027779420438621725, 0.07574935603354659, 0.05745496627475534, 0.07162242462592465, 0.05559838589813028, 0.01682004003253366, 0.025442030147782395, 0.030225043850285665, 0.07860281970351934, 0.04753402095021946, 0.1092230627047164, 0.09327428029584033, 0.048421887414796014, 0.07650970880474363, 0.04509445346359696, 0.05809831925268684, 0.033024591127676625, 0.03185991630224245, 0.03528990064348493, 0.026343730245051638, 0.0506401676684618, 0.005514233996759036, 0.028813904750027826, 0.007231900019438139, 0.044187068939208984, 0.07266153315348284, 0.027632524392434528, 0.07600262601460729, 0.031974510688866885, 0.029892632937324897, 0.052551828125225644, 0.05441425068836127, 0.017218128046286956, 0.034477833325841596, 0.07916197327098676, 0.026925234756033336, 0.0288657787522035, 0.043354730387883525, 0.013412823933841926, 0.021614515887839452, 0.0228350307526333, 0.016469162789040377, 0.07615524211100169, 0.030721670415784632, 0.04843558703682252, 0.012629261024163237, 0.03222967717530472, 0.05371765985286661, 0.07049573079815932, 0.027172051869066696, 0.03554327579747353, 0.05257464725790279, 0.018252268001171093, 0.04540808931259172, 0.03116740006953478, 0.012437761478525187, 0.037423584543700726, 0.027747044140206914, 0.05135930961530123, 0.03194788497473512, 0.05303382208304746, 0.01283675364019083, 0.03664516577763217, 0.03332013723307422, 0.03905979370964425, 0.07043517154774495, 0.05744126665272883, 0.0416030549178166, 0.022401750520137802, 0.011120585059481007, 0.04081064475966351, 0.02936635778418609, 0.02087134192697704, 0.025604410363095145, 0.03961090324446559, 0.03819569632677095, 0.06769665849528142, 0.05372149357572198, 0.10006103504981313, 0.0453320933905031, 0.05415844637900591, 0.04712781256863049, 0.00445301625378696, 0.05481220129877329, 0.03857672427381788, 0.1508337613195181, 0.10165760080729212, 0.17535729253930704, 0.1334366798400879, 0.24705793868218148, 0.1440691471632038, 0.11063250207475253, 0.09866448784513132, 0.21912649247263158, 0.10202928193445716, 0.0998404568859509, 0.2048742172441312, 0.133922687332545, 0.1484611007784094, 0.08037492925567286, 0.10282052161970309, 0.07774775701441936, 0.07962831003325326, 0.0998227878340653, 0.07969381580395357, 0.05643820869071143, 0.08748910429754428, 0.13047811788107666, 0.17339905404618808, 0.09196087398699351, 0.16757748142949172, 0.11917409087930407, 0.14317307381757668, 0.07851691038480826, 0.1543781025601285, 0.10439923512084143, 0.09443986775087458, 0.15954396607620375, 0.10545658945505108, 0.11788985479090895, 0.1213693552251373, 0.1165275736046689, 0.13383761261190685, 0.14167367427476815, 0.1620130735848631, 0.11392140202224255, 0.11650305134909493, 0.18460461204605444, 0.12746132404676505, 0.21449872079704488, 0.13793088868260384, 0.09668716216193778, 0.1446470282971859, 0.18568866673324788, 0.12224234480942998, 0.10641727969050407, 0.14347590399639948, 0.11899182280259472, 0.22825065787349427, 0.18228540649371489, 0.13463372417858668, 0.20431916202817643, 0.13902567779379232, 0.1405343325542552, 0.057253346379314146, 0.10233309598905699, 0.1118464283645153, 0.09724973554589919, 0.10364581697753497, 0.10124610324523278, 0.10920898310307946, 0.17726827785372734, 0.12172215272273336, 0.1346010323613882, 0.11729287968150207, 0.1282400515462671, 0.10643492838633911, 0.16774308468614305, 0.1269911942737443, 0.15708761502589497, 0.09396600603525128, 0.18507501323308262, 0.1055948341797505, 0.05391620598467333, 0.16220798955432006, 0.19129967636295728, 0.08572272158094815, 0.11230959636824471, 0.07288530721728291, 0.14509836265019008, 0.1238803690565484, 0.24523623500551495, 0.13997570824410233, 0.17319047238145555, 0.22464735193976335, 0.17468179735754216, 0.06658783727990729, 0.14946249632963113, 0.11953504436782428, 0.11902264186314174, 0.16375050321221352, 0.08345696423202753, 0.15466888195702008, 0.14656143342810019, 0.13136347037340912, 0.15907101359750542, 0.12725986699972833, 0.1790248014565025, 0.09392864589712449, 0.17159282096794673, 0.14209872218114988, 0.1189113621200834, 0.13112453105194227, 0.2289141836975302, 0.15355700733406202, 0.14164255665881292, 0.17440126383943216, 0.0877998461946845, 0.09389394561627082, 0.0946612058739577, 0.17583206349185534, 0.19059079725827488, 0.09783418489886181, 0.13511523976922035, 0.11356695568455116, 0.09615823732955114, 0.1394325409616743, 0.11541744960205895, 0.12651940887527807, 0.20040155867380754, 0.17526106270296232, 0.07980508876166173, 0.15611327945121697, 0.12488024468932833, 0.12428582087159157, 0.1493860932865313, 0.09090134155537401, 0.15992953681520053, 0.12883723021617957, 0.12528307735919952, 0.10154030924396855, 0.10282686592212745, 0.13660591335168906, 0.13706743930067333, 0.16903449967503548, 0.11964039371481963, 0.12314129514353615, 0.2263239034052406, 0.12634013992335114, 0.09582499521119253, 0.12425528679575239, 0.13450803235173225, 0.18123222514986992, 0.08643493229257208, 0.18286118416913918, 0.12582087064427988, 0.06154137557106359, 0.07665171939879656, 0.1261238365301064, 0.1969604633216347, 0.14079862194401876, 0.2045095996665103, 0.17218459849911077, 0.10920500010251999, 0.14074325348649705, 0.13378531113266945, 0.14556811244360038, 0.12110712858183043, 0.13381497668368475, 0.1080071415219988, 0.1555059498974255, 0.15922282902257784, 0.13158168723540647, 0.11824398221714155, 0.20557594458971704, 0.14394268180642808, 0.09997653708394084, 0.05898434349468776, 0.07363485771098308, 0.17075857573321887, 0.11294057286743607], [0.042188688314386776, 0.02080342566062297, 0.028534446709922383, 0.03853047193427171, 0.035793909669986794, 0.022788776716749583, 0.060326926809336455, 0.04336138342374137, 0.0200047797656485, 0.022195028041356375, 0.047783810046634505, 0.027585751277261546, 0.025528539969984974, 0.03727457146825535, 0.019430535579366342, 0.007755259168334305, 0.015239886340818234, 0.01332033536995628, 0.05588477856612631, 0.021568926816274012, 0.022630883314247643, 0.040382655403975926, 0.031447540037333965, 0.022521269374660084, 0.01727146768410291, 0.018027277663350105, 0.04216817280809794, 0.02691058348864317, 0.030807203147560358, 0.034591738999422104, 0.06237167173198291, 0.01546934652807457, 0.01393229846975633, 0.045734878562922986, 0.022599920065009167, 0.0019385270508272307, 0.0348397944388645, 0.04705128060387714, 0.012353528141310173, 0.01342511729204229, 0.02555923180521599, 0.05001206137239933, 0.026802859269082546, 0.01755049146179642, 0.0283992893195578, 0.03088425419160298, 0.0315927601020251, 0.07245511601545981, 0.02674078179656395, 0.03368034094039883, 0.06444276416940348, 0.04288463793428881, 0.015253165271133184, 0.047036685315626006, 0.028798518968479972, 0.04179930420858519, 0.04079393922750439, 0.011410889481859548, 0.022054717177525163, 0.011785086277606232, 0.037896418278770785, 0.01700325127291892, 0.01879384072630533, 0.058717231399246624, 0.040506633929908276, 0.0880326379888824, 0.05433622594656689, 0.018588699234117354, 0.011691647764694477, 0.02874426670106394, 0.023522347710760574, 0.029149236756243875, 0.00996025709901005, 0.030238550089831864, 0.018551691934200268, 0.02183958256085004, 0.036819664628377984, 0.014465623601738895, 0.011680602910928428, 0.06381790805608034, 0.05926590160067592, 0.02673130775136607, 0.044429706276527474, 0.027744179026090672, 0.04337151734424489, 0.03725922300613352, 0.029454577514635663, 0.0673791855307562, 0.022977763986481086, 0.06250011841101305, 0.03702008690951126, 0.04301051635827337, 0.019406476423942616, 0.03390529565513134, 0.06434163531022412, 0.015393744156296765, 0.026861823962203095, 0.05312625212328775, 0.051355964437659295, 0.015651003923267126, 0.029987811044390713, 0.007796311385131308, 0.01962863896707339, 0.030216684298855916, 0.025587486003392508, 0.04786521389282175, 0.03922598050641162, 0.01873669450703476, 0.07044312397816352, 0.03281688816579325, 0.03601578722840973, 0.03272920108533331, 0.06530894804745913, 0.07103797527296202, 0.0395735973891403, 0.04333711561879941, 0.017124931261475598, 0.04628928238525987, 0.04316557178805981, 0.05235433711537293, 0.017636227754077742, 0.031016392101134573, 0.010554530790873935, 0.03720779005171997, 0.05353243675615106, 0.020451293127345185, 0.009538360139621156, 0.03217440710536071, 0.019431102156106914, 0.04694584644000445, 0.0018399426979678018, 0.01643626401866121, 0.03311635959627373, 0.017801915827606405, 0.01162959319273276, 0.01117106806486845, 0.02031842918534364, 0.055803096520581415, 0.02254979159416897, 0.12264658883213997, 0.017627732495644262, 0.05740231874265841, 0.01926207060127386, 0.07627815194427967, 0.009287722874432802, 0.021488978427701762, 0.039718108384736946, 0.029989914502948523, 0.053538821770676544, 0.006395590341916042, 0.017163813014381697, 0.00854554381554148, 0.08291330840438604, 0.03815305718619909, 0.02306825002389295, 0.004693279990793339, 0.019959538443280116, 0.039505662463073216, 0.031975599737571817, 0.05922512164605515, 0.015321858460083604, 0.032152704162789245, 0.04640919648643051, 0.03388672075899584, 0.028905466265444244, 0.09102347107338053, 0.051216691732406616, 0.044275519371564896, 0.02869043851803456, 0.04744210320391825, 0.03180178959986993, 0.021218609364171113, 0.04904777829402259, 0.05761121253349951, 0.023597968742251396, 0.03341773431748152, 0.04644942004233599, 0.018937323741348724, 0.035127377935818264, 0.022608540852421095, 0.10438322169440133, 0.04156455484085849, 0.07190052898866789, 0.061935672270400186, 0.04764086307425584, 0.03004890973014491, 0.020887200986700397, 0.028098903563139693, 0.06399815409843411, 0.08465563026922089, 0.04578242690435477, 0.026844165088342767, 0.03166576029200639, 0.0217253664574985, 0.047374225953327756, 0.03901618426399572, 0.03802086838654109, 0.036255968268960714, 0.04139962333387562, 0.029296512782041515, 0.007810727709771267, 0.009260456792877188, 0.020647371088021567, 0.02151971436770899, 0.025966361298092773, 0.004465773560306323, 0.05916431133768388, 0.04785523942804762, 0.014290480142725366, 0.02540317383993949, 0.01976127051083105, 0.0586160346865654, 0.043069324988339625, 0.02754984998942486, 0.032182502028133185, 0.01609855205086725, 0.0252126734371164, 0.0778882476900305, 0.1226996909826994, 0.02902781291465674, 0.043132035194763114, 0.03179599491081067, 0.016672170288594704, 0.08091603379164423, 0.054033979307860136, 0.024219874924580966, 0.03606134746223688, 0.06365018098482064, 0.01797492359764874, 0.011912610997179789, 0.014749208831095269, 0.05082926520013383, 0.04517349600791931, 0.026442058450941528, 0.06245674645262105, 0.030495457018592527, 0.034394767068858655, 0.004625332766279046, 0.01965217395419521, 0.0332841511283602, 0.024528236860143285, 0.012604743857601923, 0.046600611215191226, 0.0838188948109746, 0.0477352133685989, 0.029183937037097554, 0.02589278604968318, 0.018252183184293762, 0.01441676908039621, 0.021073872755680765, 0.02964316614504371, 0.013733163708820939, 0.019170877191105058, 0.04502323442803962, 0.013370416343345173, 0.03037218077640448, 0.017414550363485302, 0.0779879584110209, 0.058905280594314845, 0.06315855522240911, 0.04714357493711369, 0.044936290343425105, 0.04311162486140217, 0.04357083022062268, 0.034179858065077236, 0.01211224787402898, 0.02433078995506678, 0.04391824693552085, 0.0470096287317574, 0.04801846441945859, 0.010177014262548514, 0.00466930353182501, 0.046200455365968604, 0.05347157555765339, 0.02200192884941186, 0.03949944368962731, 0.06479735978479896, 0.015368587470480373, 0.03886866057291627, 0.009676886456353324, 0.01998058151054595, 0.03799125711832728, 0.03614019323140383, 0.044519690198025534, 0.06473239684211356, 0.05791169498115778, 0.022260684786098342, 0.052250992839357684, 0.037162145001015494, 0.04478606269029634, 0.0193601460528693, 0.026879019735913192, 0.03628467708559973, 0.026128897576459816, 0.07080498670360871, 0.022588939672069888, 0.019469205290079117, 0.00852417420329792, 0.012196625399935459, 0.010283988700913531, 0.039727495916719945, 0.01279026550972568, 0.0490407961686807, 0.06981526874005795, 0.028927705250680447, 0.043486976863018105, 0.006461291615518608, 0.032739185728132725, 0.03810077267033713, 0.08452763142330305, 0.02222551461974425, 0.025976502003946474, 0.02289035849805389, 0.033785778496946604, 0.020975332507597547, 0.03691699029877782, 0.02622212828802211, 0.03719127450936607, 0.0371198213792273, 0.015035067152764117, 0.01756416054974709, 0.033829767922205586, 0.009603838768920727, 0.018702698206262927, 0.015235165433425988, 0.01573656210010605, 0.014284632867202163, 0.036319947335869074, 0.01840538451714175, 0.07493994518050126, 0.0419978028429406, 0.04695152238543544, 0.06759857625833579, 0.030918292900813476, 0.01597177965699562, 0.0635236342038427, 0.04044814760397587, 0.06551436773900475, 0.01805741649254092, 0.03568900137075356, 0.03577276312613061, 0.017409968555771878, 0.061029956942158084, 0.0251905837295843, 0.03174829729167478, 0.0498157306574285, 0.037536743828760724, 0.003927845840475389, 0.03673458990773984, 0.05195204388084156, 0.04568028363532253, 0.07020968079034771, 0.145697522642357, 0.11899170066629138, 0.06630243866571359, 0.06403798410402876, 0.25689867777483805, 0.14302086484219345, 0.15217845487807477, 0.28739168867468834, 0.16581305967909948, 0.08170799950936011, 0.07120284571179322, 0.07053711464894669, 0.18207385284560068, 0.20698344334959984, 0.12193874110068594, 0.0932254936279995, 0.12117979968232767, 0.11385559769613401, 0.10099187652979578, 0.18568897885935648, 0.1350988056510687, 0.13157730389918598, 0.13786961697041988, 0.10902750212699175, 0.10815970333559172, 0.0705681372699993, 0.18846364425761358, 0.1495582511914628, 0.20141054024653776, 0.11461676470935345, 0.24626022577285767, 0.16228811096932205, 0.12396585089819771, 0.10905197009976421, 0.06892538363380091, 0.09563567037028925, 0.14937853440642357, 0.09931489080190659, 0.10939943431211369, 0.12258543925625937, 0.11077787141714777, 0.14445821914289678, 0.35858032586319105, 0.152168711115207, 0.10174403938331775, 0.12379735708236694, 0.1522541522447552, 0.19927107862063817, 0.1686002236924001, 0.18590064107307366, 0.18562221101352147, 0.17114516427474363, 0.0808969669576202, 0.10241948028228112, 0.13095219672790595, 0.10292879545262881, 0.1437202308859144, 0.2349755098777158, 0.14534293381231173, 0.07111940626055002, 0.1441737094095775, 0.11563420082841601, 0.0824822351070387, 0.12313303058700902, 0.1058897797816566, 0.2108578918767827, 0.18277083044605597, 0.22469110387776578, 0.13854621137891496, 0.07912578021309205, 0.0997971324250102, 0.08031659560011965, 0.06891979929059744, 0.1401365753263235, 0.15308775965656551, 0.11150910146534443, 0.11987242554979664, 0.09080591917570148, 0.10780816112778016, 0.14763638217534336, 0.10894274631781237, 0.1061122374875205, 0.11316792959613459, 0.09095262523208346, 0.15294492803514004, 0.11693818228585379, 0.1566589301718133, 0.30146322931562153, 0.09162947748388563, 0.1250358327691044, 0.10816405274506126, 0.12320334038564137, 0.14164432084986142, 0.10410207749477454, 0.09987978477563177, 0.14117123266415937, 0.11924803762563638, 0.10756851612989392, 0.16048286855220795, 0.12829991190561227, 0.12829204089939594, 0.12019772880843707, 0.1633601827280862, 0.10130445725683655, 0.0934918254081692, 0.13999995908566884, 0.15018357549394878, 0.10385129095188209, 0.11364053602197341, 0.12025619138564382, 0.073116796224245, 0.13119256097291196, 0.1954919235514743, 0.14097939724368708, 0.11552131974271365, 0.15382291163716996, 0.08824512122997216, 0.14025006709354265, 0.16517292974250658, 0.13016821736735956, 0.11947183204548699, 0.08453731411801917, 0.08443291472004992, 0.09139039567006485, 0.14931328647903033, 0.09651059377938509, 0.11746167205274105, 0.10274101767156806, 0.11266389342823199, 0.07254564615764789, 0.13394772527473314, 0.14577552702810082, 0.20117112595055783, 0.15634731974984917, 0.13930154299097403, 0.07555604140673365, 0.1489107252231666, 0.13169792028410093, 0.08608908299356699, 0.2731561596904482, 0.13756912095206125, 0.1131454836577177, 0.12995390886706965, 0.12963484813060078, 0.0876497406778591, 0.17047089045601233, 0.14327360556593963, 0.12705933276031697, 0.1180858157042946, 0.09844098519533873, 0.13185835310391017, 0.09653992006289107, 0.12535224721900054, 0.1034566346289856, 0.10317967699042388, 0.09027603082358837, 0.1710219287446567, 0.1359050545309271, 0.09848449964608465, 0.19416955379503115, 0.10614984868360416, 0.1388544019843851, 0.12756530275302275, 0.14658112451434135, 0.2047804029924529, 0.1896029588367258, 0.11745528025286538, 0.11034973617643118, 0.13417632372251578, 0.12524482155484812, 0.09799990350646631, 0.11775364567126546, 0.19246991856821946, 0.11391074902244977, 0.09652980310576302, 0.10677382948675326], [0.021042158028909137, 0.03016042017510959, 0.09023347989256893, 0.06720287499151059, 0.01790618121490947, 0.022682014320577894, 0.04513798827039344, 0.03674869325810245, 0.018813392712867687, 0.015713435930332968, 0.0663348115714533, 0.007177227908479316, 0.019081522610836794, 0.021008080303935067, 0.025941716906215464, 0.034672274320785484, 0.036171653507543464, 0.017597649645592486, 0.021852361071588736, 0.011111010082199104, 0.007774704285631222, 0.035561301080243926, 0.03582574314038668, 0.033817808742501905, 0.0447498390983258, 0.07119474400367055, 0.019240596664271185, 0.039042799800102196, 0.05107227573171258, 0.014307489319305335, 0.015791039980415787, 0.007701392817710127, 0.022272304698292698, 0.019269147721518363, 0.04320977834452476, 0.02028329124940293, 0.017443484793018018, 0.012213985718387579, 0.0536039068496653, 0.027259121482659663, 0.025775282444166284, 0.032449722689177306, 0.021033920613782744, 0.023108855255746415, 0.0196604368143848, 0.034023554130856476, 0.036219435943556685, 0.06545130469437156, 0.028072651043268185, 0.04593530084405627, 0.04240482207387686, 0.04032826403688107, 0.02088003565690347, 0.03853121832279222, 0.04019220419494169, 0.025977014297885553, 0.03408204724213906, 0.021564036275127103, 0.06086465224091496, 0.03307484682383282, 0.015798853311155523, 0.00311923523466768, 0.00880140410403588, 0.03273261072380202, 0.013008641827452396, 0.027157721209472845, 0.08898847669895206, 0.024494094674342444, 0.03841203025409153, 0.026419086647885184, 0.046816571948251555, 0.03735278619985495, 0.024171142539541637, 0.026446311169170907, 0.020048850615109717, 0.014334654468776924, 0.02989275846630335, 0.004319719321626637, 0.03200987932671394, 0.015151863385524069, 0.016805388765143495, 0.02446935698390007, 0.0367295416072011, 0.031750509315835576, 0.05017728804211531, 0.032198291538017135, 0.012677062968058246, 0.059835497822080336, 0.01689828360187156, 0.049149853709552965, 0.03432071175692337, 0.05119483611945595, 0.02773209771008364, 0.06515015049704484, 0.037727038974740675, 0.023379439754145484, 0.04552048524575574, 0.026733394246548414, 0.04501292748110635, 0.02272495032022042, 0.019559808374781693, 0.008554365618952682, 0.060398749741060395, 0.009558521111362746, 0.05222680985129305, 0.017178291255342107, 0.019194067821704915, 0.07395866140723228, 0.022207776018019234, 0.007557608702752207, 0.031202063030962433, 0.05118020351177879, 0.07696315340165581, 0.013501360879412718, 0.04265408869832754, 0.02756572431618614, 0.04385198120559965, 0.020410830387845635, 0.0756841352475541, 0.055141877715608904, 0.014246405900589057, 0.018368012504652143, 0.04128401114472321, 0.06756956210093838, 0.03318336832204035, 0.020971810910850763, 0.012325850697899503, 0.04160715326932924, 0.06843643808471304, 0.0056300039453032824, 0.04076267572652016, 0.018939498446083496, 0.04236230846228344, 0.0394759019171553, 0.02227408585271665, 0.02960306472544159, 0.0729587586330516, 0.05051597201132348, 0.021938365385202423, 0.04090756330905216, 0.03929509947608624, 0.020100022333541086, 0.011359554915023702, 0.013684762109603201, 0.04736889945343137, 0.047528470533766916, 0.03950456323634301, 0.04375901173001953, 0.11578109008925301, 0.036956009455025196, 0.04554700239428452, 0.034293936765087504, 0.02951980847865343, 0.024590641725808382, 0.05154080076941422, 0.013151631208269723, 0.03158027505768197, 0.04648085317707487, 0.04466246414397444, 0.0023376790923066437, 0.04764491392831717, 0.06720709547932659, 0.057801833376288414, 0.010798013752459415, 0.05969783663749695, 0.038864592755479474, 0.014596390870532818, 0.09467593008386237, 0.05807788856327534, 0.01006661746318319, 0.06519934428589684, 0.026317431924066374, 0.061849165840872695, 0.06799751413719994, 0.03319607389026454, 0.05373120680451393, 0.04353131912648678, 0.023708693782931993, 0.013230652548372746, 0.08484401873179845, 0.05245012590395553, 0.022864285789962326, 0.04889353710625853, 0.0385915231225746, 0.046666849803711684, 0.03553909602175866, 0.013265294305581068, 0.039873659145087004, 0.06276606342622212, 0.013237124076113105, 0.03053032693320087, 0.02930735916431461, 0.010624204462926303, 0.050952873924481015, 0.019593151585598077, 0.09267744089343719, 0.009848583805640894, 0.038484341731028895, 0.053823630059404035, 0.04353872872889042, 0.0643193522202117, 0.04316403490624257, 0.056819087360054255, 0.032185721676796675, 0.029530583614749566, 0.026143542058499794, 0.014568672715021031, 0.009252760509428169, 0.006458508773773376, 0.012242581728579742, 0.020647250648055757, 0.01640368246340326, 0.009739896066353788, 0.04261347837746143, 0.005733063236610698, 0.009400250273756683, 0.030549536259578805, 0.024793069077921764, 0.05885068566671439, 0.01343016219990594, 0.06599462803985391, 0.057815492286213806, 0.047547642540718825, 0.05980671436658927, 0.010501926515384443, 0.016732883905725818, 0.06270694945539747, 0.03174377824845059, 0.033503647028867684, 0.006746784800530544, 0.018043223236288344, 0.048351190851203034, 0.015523301936419947, 0.07053758962345974, 0.035472060154591284, 0.03859966893547347, 0.02825875623550798, 0.07339395742331233, 0.03573616633989981, 0.022212493532736386, 0.015428719243832996, 0.06081238468842847, 0.06294906432075159, 0.06047347001731396, 0.02950334721910102, 0.042402776290795634, 0.06462044534938675, 0.011814129272741931, 0.009132122920293893, 0.026633483357727528, 0.053539388347417116, 0.008724219049327075, 0.013861801225825079, 0.012108940863981843, 0.028201235125639608, 0.04693660479305046, 0.009392371634021401, 0.01454515299493713, 0.012899070296303501, 0.018031314946711063, 0.023145740419360142, 0.027758837078831027, 0.03810580061482532, 0.03221495296540005, 0.07264509224998099, 0.020709960854479244, 0.05490216486422079, 0.023752756150705472, 0.03911397812355842, 0.025342365227905766, 0.04238305467047861, 0.034408066355224164, 0.05386036933798875, 0.0444939024746418, 0.05880356140966926, 0.05077006980510695, 0.057907379498439174, 0.02264734118112496, 0.028898216118769984, 0.030265301332942078, 0.07412815266954047, 0.04706568929499813, 0.028643314260989428, 0.030780736889157976, 0.011276609946175345, 0.04718883661553264, 0.05744724454624312, 0.015109163176800524, 0.012258713050479335, 0.055732345674186945, 0.016135630596961294, 0.05686936001958592, 0.03822849331689732, 0.07300810169960771, 0.09864690021744796, 0.0191950533938195, 0.03976067967180695, 0.07640486835901227, 0.0325544002865042, 0.04031859491286533, 0.04557414040235536, 0.007017446058203599, 0.06142191948103053, 0.04177852068096399, 0.10223770075078521, 0.02601516492930906, 0.07015241922012397, 0.04268128777455006, 0.02264519192145339, 0.022890255021463548, 0.017293289370302643, 0.01564661889070911, 0.02465362673891442, 0.040029389717217, 0.02797929141005235, 0.04420717053913644, 0.034496204661471505, 0.014960377410586392, 0.016883177716018896, 0.026225911120751073, 0.015772571953545724, 0.0902288726397923, 0.011729926469602754, 0.06560798521552767, 0.06544814272118465, 0.02048592216202191, 0.03593880743054407, 0.04372662525357945, 0.023002574619437968, 0.06891464920980589, 0.030267862802637473, 0.03459878219291568, 0.025343250716105103, 0.07225322470601116, 0.030364374231014932, 0.01165316125843674, 0.06388993454830987, 0.03128161447654877, 0.08046064858457871, 0.07854111372892346, 0.033257742545434406, 0.04929451737552881, 0.007462516260732497, 0.01640084618702531, 0.04113610747403332, 0.03219588613137603, 0.010321174116273011, 0.030751397034951618, 0.01919029516700123, 0.04206017717452986, 0.07409016149384634, 0.02795985647078071, 0.15909715076642378, 0.10755987159375634, 0.1829486744744437, 0.1254684395555939, 0.0921709348580667, 0.15316721610724926, 0.11930014911506857, 0.14296654132860048, 0.16532383593065397, 0.09065386626337256, 0.13132027483412198, 0.06773258013916866, 0.13465493518326963, 0.08533284892993313, 0.13908062555960246, 0.1662915354328496, 0.11243017882640872, 0.14842201716133527, 0.10200198447065693, 0.11256200460983173, 0.09270118961908988, 0.1171959713101387, 0.23232325219682284, 0.16082955923463615, 0.11459134678755488, 0.12767964947436536, 0.13021637978298323, 0.110179736012859, 0.1863789539784193, 0.12821266587291444, 0.09458973578044347, 0.10174597320812089, 0.06797033880970307, 0.09310814099652426, 0.17956591956317425, 0.1441871036908456, 0.05292642356029578, 0.12483409073735986, 0.12619345422301972, 0.15317872406116553, 0.07748979157102959, 0.12325148923056466, 0.1734734486256327, 0.08889027232570307, 0.14849546179175377, 0.14670959833477223, 0.3123233994202954, 0.17591367768389837, 0.11851513838129384, 0.13823893001036985, 0.15153411802436623, 0.10282296434577022, 0.10699583257415465, 0.14194883379553044, 0.15080345794558525, 0.06772058364003897, 0.06627178923892123, 0.15617677675826208, 0.12740001162248, 0.08964157343975135, 0.07996098896754639, 0.14534651647721017, 0.13769052443759783, 0.06393858550914697, 0.14945885938193115, 0.18121451538588318, 0.1629767833011491, 0.13474143482744694, 0.1291476192751101, 0.12385353978191103, 0.12918981058256968, 0.1836018729954958, 0.08892298449895211, 0.11028197088411876, 0.13946645414190634, 0.14587837936622755, 0.0994955168238708, 0.12219939354274954, 0.07869969414813177, 0.1786038519016334, 0.08324081690183707, 0.11571866486753736, 0.08541064296982118, 0.15429366566240788, 0.22448221008692468, 0.10968542325177363, 0.13521091320684978, 0.12788966963333742, 0.16531863835241112, 0.1807460683797087, 0.08702289645693131, 0.14237651441778454, 0.10672288507755313, 0.12177563485290323, 0.15474966833634035, 0.10512423621756689, 0.1333071475050279, 0.11761966214648314, 0.16620884915547712, 0.1101257653374757, 0.13494655596358435, 0.11267702986619302, 0.14693065147314752, 0.13759638448911055, 0.2289466176714216, 0.1030065623511161, 0.14569081871637277, 0.16822218469211034, 0.07079824206552335, 0.13934073517365114, 0.14416104794612952, 0.1277048909770591, 0.2756922250347478, 0.12071063342903342, 0.14982103423348495, 0.11399829361055579, 0.12759776386831487, 0.2083181624433824, 0.1739896916385208, 0.10601213321621929, 0.09016122948378325, 0.13055758790246078, 0.2147559534226145, 0.16650983371904918, 0.15737588384321757, 0.08577094506472349, 0.15123238707227366, 0.16426675979580196, 0.18724222694124493, 0.08705197846783058, 0.09726213916604008, 0.11961961697254862, 0.1304162083459752, 0.12916978022881917, 0.09719733228640896, 0.16213310642966203, 0.09875521476247481, 0.1708750801959208, 0.14955986610480718, 0.10747618786990643, 0.1419513308043991, 0.12283010541328362, 0.10987011369849954, 0.1234965082257986, 0.12689109678779328, 0.16922356667263166, 0.13620409848434584, 0.1581434290856123, 0.1545512918382883, 0.14622945338487625, 0.16656912410897867, 0.14647848930742058, 0.11855965027851717, 0.13997705174343927, 0.10619102218853575, 0.08400507124939136, 0.14377159598682607, 0.20946948709232466, 0.12539464208696569, 0.11074743912156139, 0.21770557229007992, 0.14817213985536778, 0.14756747015884944, 0.12760205220963272, 0.1690419228481395, 0.14928613150758402, 0.12013519502111844, 0.15355708875826427, 0.14470630511641502, 0.09144843755556004, 0.1535608478422676, 0.07713262430791344, 0.08310171043766396, 0.18876819791538374, 0.16652025601693562, 0.12741388087826117], [0.047742049608911784, 0.0273891033471695, 0.08377801986145121, 0.05639699108100363, 0.0213541891425848, 0.0188425527552941, 0.013358420692384243, 0.10866909993014165, 0.017943193603839194, 0.06956697242068392, 0.05959820055535861, 0.04436494010899748, 0.04830104372064982, 0.05077994927497847, 0.029825247624622922, 0.027592192270926068, 0.017380823780383383, 0.055881704802491834, 0.035228958020785024, 0.02163996095103877, 0.04917575339121478, 0.024122615411345447, 0.08668475531573806, 0.037186219423477135, 0.029862702757652317, 0.024164285943178192, 0.07356779130973987, 0.015217228360208017, 0.03514933532902172, 0.04787129017391375, 0.009904688473657837, 0.028371845970728567, 0.03410169422360403, 0.030721215797322135, 0.019758843051801835, 0.019835483582158173, 0.019513449165970087, 0.042836119287780354, 0.01910299145882683, 0.019304504485002587, 0.0042150362112027195, 0.05008782319990652, 0.00996300092499171, 0.05804552922823599, 0.02292158467961209, 0.02304415694171829, 0.03032995554219399, 0.0529977545541312, 0.05111201413507972, 0.021295806293242743, 0.043019194821161885, 0.030766586041344062, 0.03951788627143417, 0.048181828510548384, 0.017939923065049306, 0.04536728900192039, 0.0042794211268691075, 0.08260068017989397, 0.00999618976909135, 0.03527276084891387, 0.04397054502208318, 0.01478216697328857, 0.04317965817504695, 0.08881737730864968, 0.01977842896511512, 0.03754671150818467, 0.04797143854999116, 0.07621310079204184, 0.021286052352349673, 0.06255293557686464, 0.06474490902785744, 0.03733059810474515, 0.03987159300595522, 0.0824015097958701, 0.022755016206896732, 0.0009579743990408522, 0.03396713733673096, 0.011028186401485332, 0.044599591089146476, 0.023665552526446323, 0.05845237882541759, 0.005914790605727051, 0.025740938394197395, 0.10166650318673678, 0.043109609612396786, 0.011927624432636159, 0.034481996138181, 0.04263266734778881, 0.05336851965902107, 0.03591450909152627, 0.0324739226406174, 0.04249339124986103, 0.012381604224044298, 0.0334178903805358, 0.035202691930213144, 0.03240366033943636, 0.06680673267692327, 0.022373453913522617, 0.045225675350853374, 0.016026864826147045, 0.006294573865099145, 0.09444209334573575, 0.04636985841872437, 0.05534461719383087, 0.013046633851315294, 0.0767025552423937, 0.06958915373044354, 0.017836651731548563, 0.04897992818483284, 0.05540883374799575, 0.02883491219420518, 0.05567298064540539, 0.039798586030623744, 0.030374297805662667, 0.07203299259500844, 0.031611664087644646, 0.032704424379127364, 0.02350198317851339, 0.039645298184560876, 0.033745843318424056, 0.013394985248201659, 0.08175864536315203, 0.04255834401452115, 0.03895505504416568, 0.010225816197427256, 0.06918986979871988, 0.0630375249311328, 0.007214270831484879, 0.017338871656517898, 0.05282024640057768, 0.041116871006254635, 0.015535571545894657, 0.05094842952010887, 0.1383223491055625, 0.04906925053468772, 0.01897054142318666, 0.02846150758809277, 0.020993678398164253, 0.04273478008274521, 0.03459929787952985, 0.03145312438053744, 0.041393482591956854, 0.04327665814863784, 0.04093486416552748, 0.03910675851096, 0.022589594458362887, 0.056707400495984724, 0.039671435353479216, 0.039536685084125826, 0.05646413890644908, 0.024679716410381452, 0.051101951460753164, 0.014016688718194408, 0.03591268043965101, 0.007464842787677688, 0.04526197358167597, 0.024988022366804735, 0.04304212251944201, 0.09059842995234899, 0.030861197571669306, 0.030990329571068287, 0.06049221793987921, 0.0667388452483075, 0.02445982356688806, 0.05904129972415311, 0.001837387165453817, 0.0496331436692604, 0.08387864660471678, 0.05952689331024885, 0.026263773374791657, 0.025558897626719305, 0.024553101775901656, 0.012944813734585685, 0.01821898076949375, 0.019705325298543488, 0.030623259089354957, 0.04187940526753664, 0.019123873374025737, 0.09308954235166311, 0.07614728289523295, 0.07973676707063403, 0.02078175325212734, 0.051308090399418554, 0.0729176394109215, 0.04990134820608156, 0.12290141944374357, 0.06810979811208588, 0.025665527708562355, 0.0544464675310467, 0.04650897845359785, 0.03480942999677999, 0.021385678256462728, 0.03568923546533499, 0.049777966790965626, 0.0308615029124277, 0.02053708879144064, 0.03281804506800004, 0.01260166585312358, 0.027995454114196554, 0.06414992881140538, 0.07619355219815459, 0.01883282425946423, 0.03865320195576974, 0.018061000853776932, 0.009892742864654532, 0.022183079039677978, 0.043638921209744046, 0.05428152923871364, 0.01501927594654262, 0.06654327788523265, 0.0786724713231836, 0.03314511591036405, 0.011776299249114735, 0.031303100287914276, 0.02693000655355198, 0.05153313332370349, 0.02775919670239091, 0.04089693745066013, 0.03625230757253511, 0.04184488819113799, 0.06541181395628623, 0.027580887877515385, 0.007916966785809823, 0.05084928198318396, 0.03376536137823548, 0.013666410281855081, 0.04059771029278636, 0.011383147577622106, 0.03430311395121472, 0.017940487945452332, 0.010904654012327748, 0.035435870489371676, 0.03743806787367378, 0.028278594903115715, 0.071132976960923, 0.018527386809832284, 0.057872061750718524, 0.014365800922470433, 0.03557468518348677, 0.016606423637962768, 0.05084744654595852, 0.018217677982257943, 0.026180384813674858, 0.0777152009042246, 0.03343216336465307, 0.028761236861880337, 0.018272681727207134, 0.02681506272139294, 0.041619451716542244, 0.07189917870398078, 0.017669560786868845, 0.0538001018576324, 0.009899109219467002, 0.04721216464947377, 0.008421997855683523, 0.0534524442628026, 0.06681526186210768, 0.04143831679331405, 0.07626461517065763, 0.024821062040116106, 0.019840267254039645, 0.0417572791422052, 0.020176391449889967, 0.06370107111121927, 0.0074328600395736945, 0.0034187159950046665, 0.032809091798428974, 0.022880367069904293, 0.01063345289523048, 0.059274200083953996, 0.012975777831992932, 0.05519746669701167, 0.014431087865627237, 0.002387331528422822, 0.0021979004543806824, 0.0319626566820911, 0.03476923358227525, 0.04849173241694059, 0.016430448973551393, 0.051177231528397114, 0.018370380591867224, 0.029285629080342393, 0.019963972669626986, 0.006552996471457715, 0.05581285046147449, 0.05675552559218236, 0.020413520779194574, 0.030500227119773626, 0.04981743378032531, 0.026018560997077396, 0.05860737657972744, 0.005802907814670886, 0.015380785833778126, 0.03258367907255888, 0.011855295144154556, 0.01808541963276054, 0.010695235205015965, 0.0036620713071897626, 0.04339578175651176, 0.0721126322501472, 0.0391366785126073, 0.07292637894196169, 0.03377672005444765, 0.02436227397993207, 0.03180266830271908, 0.048658051528036594, 0.015115917992911168, 0.03888888091647199, 0.011304275515223188, 0.06388823821076325, 0.02248056066621627, 0.0218735652909215, 0.03909982727574451, 0.06900844989078385, 0.025725839293694923, 0.031588950127895386, 0.011816195411873716, 0.07864718910838876, 0.06144149521631854, 0.03879842880581107, 0.008351549805541123, 0.011496097364995097, 0.029757984448224306, 0.010591829012680267, 0.007174289851848568, 0.08795971583042826, 0.025458476140296886, 0.05285932323230164, 0.03202854582507696, 0.028120221437088082, 0.04673449635239584, 0.013770184579438396, 0.04492109115900738, 0.04468134777354343, 0.03559447465730565, 0.0345294393066849, 0.006946416588367096, 0.019607480548854386, 0.02875354906011905, 0.011994689137541821, 0.02619860856793821, 0.056089434905775955, 0.03639909844579441, 0.014580182365274854, 0.05195114142926676, 0.023667488047587018, 0.044656085914799144, 0.08349546430898563, 0.04812081803434661, 0.035725235140749385, 0.05975085736385413, 0.01807968601185296, 0.1136046958022884, 0.14136510368968758, 0.26039611867495943, 0.15538518423480646, 0.17755054842148507, 0.1401401987033231, 0.1691378948411771, 0.18004298396408558, 0.12425064561622483, 0.17635205201804638, 0.1572025181459529, 0.10736190900206566, 0.19436087352888926, 0.08240681593971592, 0.11706500048083918, 0.11380065671567406, 0.1251532600394317, 0.12035556962447506, 0.12619169003197125, 0.0937495669350028, 0.1654078657073634, 0.14200260091040814, 0.12248302118054458, 0.11952118868274347, 0.21243030178759778, 0.15196824472929749, 0.12930784853441374, 0.10060277740870203, 0.12851479037531785, 0.12936407194605895, 0.16602503401892527, 0.15498495713940688, 0.08868353627622128, 0.21844460549099104, 0.17438404262065887, 0.10700040590018034, 0.07900634447910956, 0.1721010029848133, 0.1358566614133971, 0.18869023424174103, 0.08582108880260161, 0.1635303185986621, 0.09448549244552851, 0.08166497360382761, 0.15932427000786575, 0.12612949551216193, 0.07246075464146477, 0.12279771215149335, 0.09382533894053527, 0.11694044859281608, 0.1892085535717862, 0.08841208834201097, 0.12916591257921287, 0.1657130436173507, 0.09441649221948215, 0.1471124445753438, 0.11258932921503272, 0.18861005854393753, 0.1939667939607586, 0.101810780087752, 0.11516819654830865, 0.07112189648406846, 0.10154177487960883, 0.11097092820065362, 0.10452525264450482, 0.1887244459773813, 0.1315877397677728, 0.13971238237406525, 0.08683475226696048, 0.15285625707890305, 0.14198563753494195, 0.10572988300451211, 0.0907977292580264, 0.16622046567499638, 0.14606142097285815, 0.09075601971043007, 0.08090025106711046, 0.13623391331306525, 0.1907499408615487, 0.11294125140245471, 0.15778607183269092, 0.09807426415916, 0.1438501432005848, 0.16591789333948068, 0.10638545639812946, 0.13240206321435316, 0.11103479191660881, 0.10211371204682759, 0.10393059133951153, 0.1240253991314343, 0.11030295118689537, 0.12418371492198535, 0.06251995198960815, 0.15901468162025723, 0.0629107067361474, 0.1568204215062516, 0.11188072830970798, 0.11093525082937308, 0.08290064015558787, 0.10106191491442067, 0.16309563549501555, 0.16424886004201003, 0.1567089789147888, 0.15756732571337903, 0.11406674422323704, 0.09874196297356061, 0.11045252744640623, 0.08026541370366301, 0.11133534221776895, 0.1347046989415373, 0.09039978882563965, 0.11696787497826985, 0.17784602328070573, 0.07180571729051215, 0.13045890176934855, 0.06700081404830728, 0.05306399653532675, 0.13084470321025166, 0.11286290774920157, 0.13450887373515538, 0.0779782078628029, 0.12430365277188164, 0.11028780628527914, 0.18544856033154897, 0.0635495406708547, 0.17097269424370357, 0.13824460256312573, 0.11829515732824802, 0.11815870393599782, 0.18526968492993287, 0.1269359750939267, 0.09020361078104802, 0.16061936265655927, 0.1799964364618063, 0.12612326656069073, 0.0741880333849362, 0.2275038758026702, 0.12971909503851617, 0.10290801192500762, 0.15872379365776265, 0.10666253617299454, 0.18904774077236652, 0.18166393627013477, 0.11957325946007456, 0.11094685377819197, 0.070706246287695, 0.1839883258300168, 0.13367093726992607, 0.07137724956763641, 0.22574448878211634, 0.1252768076956272, 0.19463220611214638, 0.20610404839473112, 0.11199153986360345, 0.09096303395926952, 0.12731413623051985, 0.15006411261856556, 0.12394168148083345, 0.18512248354298727, 0.1238539604736226, 0.11551099243972983, 0.13762778708977358, 0.1659165769815445, 0.08311909450484173, 0.25439119232552393, 0.15417011800621236, 0.14976244951997483, 0.1274238417723349, 0.1984840729939086, 0.09052442892321519, 0.12099249687577997, 0.17609264808041708, 0.11831073649227619, 0.057097588665783405, 0.1384525599756411, 0.08807052059897355], [0.023347485843779783, 0.029267685221774236, 0.04964500446138637, 0.08217370523405926, 0.08158191413219486, 0.01791071213249649, 0.03483560787779944, 0.02631051934856389, 0.03304612782916852, 0.05127434006759098, 0.016201402692656432, 0.010412645725799459, 0.013921445302133049, 0.056947740992265086, 0.03450225719383784, 0.0491642963274249, 0.057660494531903944, 0.0387890209177775, 0.06324454596532242, 0.03415017215801137, 0.0135100054155503, 0.03932372686852302, 0.028758804313838482, 0.04937693902424403, 0.04014187046725835, 0.07271045552832739, 0.0949727687984705, 0.04627926042303443, 0.03316394525713154, 0.06367656921169587, 0.07624740073723452, 0.050198095318462164, 0.06328151933848858, 0.05041118245571852, 0.03662743905026998, 0.06530485648129668, 0.0262988434572305, 0.04817291256040335, 0.030978146474808455, 0.0006060889479288432, 0.021620232545371567, 0.03897200824160661, 0.007622983007292662, 0.047330412947173627, 0.02368679745788021, 0.021434680359171968, 0.016099573246070316, 0.04775843283693705, 0.06243134888687304, 0.028186548235160962, 0.01802388159558177, 0.038581399380096366, 0.037741105005677254, 0.024679528116913776, 0.025164879126740352, 0.01841076529983963, 0.00814118783455342, 0.09934558094080005, 0.02209268799716873, 0.05180714272760919, 0.025829013935955505, 0.007922906511729317, 0.05463497134457741, 0.04309175396338105, 0.023466918185087185, 0.07054314003991229, 0.017465323442593217, 0.0340614978090993, 0.03726054954209498, 0.02776484550642116, 0.02272979336391602, 0.03242500026577285, 0.017769006879201958, 0.04461914986105902, 0.07532421313226223, 0.05619276900376592, 0.02309040249591427, 0.023932891931118708, 0.05087494417758925, 0.02483060902782849, 0.037409389591110606, 0.036251069246126075, 0.044385333478982957, 0.05110372243715184, 0.020043006732261608, 0.009370542314302708, 0.06951819253819329, 0.03669220521779997, 0.05273823865822383, 0.0351891076591398, 0.06784012115427426, 0.014671190874651074, 0.04077788508896317, 0.04523085257304566, 0.05387753966663565, 0.048151752445846796, 0.0264911962606545, 0.04339923210708158, 0.03150100181145327, 0.011920695741926985, 0.03999575134366751, 0.008883939407366728, 0.027908810281327794, 0.04872368282771536, 0.10633396237556424, 0.0331277182724859, 0.07987837732902595, 0.04454314036827002, 0.004046624243658568, 0.053486255662781854, 0.030199079707797085, 0.027750231558457017, 0.004883322806563228, 0.008646883868745394, 0.00921128929725715, 0.0993621236245547, 0.04820138049711074, 0.018651139722870927, 0.03488567697682551, 0.07034088232155357, 0.013352603950936879, 0.03659782438938107, 0.06738841360700981, 0.07509184881512608, 0.02903286460787058, 0.0382899041287601, 0.08920767065137625, 0.029433905945292542, 0.05232500404651676, 0.032234979926475456, 0.016695031829710518, 0.03813925239124468, 0.01545181148685515, 0.026573673888508762, 0.041889854706823826, 0.07863455478634153, 0.04453150688537529, 0.08415887478206839, 0.04443667483116899, 0.048537855834833214, 0.034840442439807315, 0.042405992546784024, 0.03070665443582194, 0.06499235039310795, 0.05589751127575125, 0.1043798765167594, 0.03790978541863816, 0.03244675070579563, 0.04078677389770746, 0.028333004929923584, 0.0548717868514359, 0.026887542135747414, 0.0769450840141092, 0.024845557154289315, 0.009908989537507296, 0.020382574493331567, 0.066505449557943, 0.04361651598342827, 0.057861198405069966, 0.029793125776840106, 0.0035512854103996816, 0.01144186545362962, 0.029519492959869758, 0.017693764130984033, 0.01658898189530841, 0.06785875372588634, 0.05488918788198914, 0.0604400114555444, 0.03438805975019932, 0.019391239920098866, 0.06796660008175032, 0.08618344685861043, 0.022117374797484705, 0.04926607658022216, 0.04253480902739933, 0.02405653627855437, 0.046668627565460544, 0.017817593379212276, 0.030620853682713847, 0.033743522728660276, 0.027340937538870742, 0.06283595931849309, 0.05208958971447178, 0.02525478501671127, 0.048362044018826315, 0.010260393493808806, 0.0039687801618129015, 0.038132545072585344, 0.03203021162854774, 0.10836455305772168, 0.03744293296975749, 0.021045532044289366, 0.09585959371179342, 0.053451236470469406, 0.030944009378020252, 0.0878014068252274, 0.016641039101939117, 0.024247260597933615, 0.0974568651456918, 0.020488113830132142, 0.006292191783099302, 0.02797811245545745, 0.020065778367487446, 0.026222757629251907, 0.007093705760780722, 0.05213693788807307, 0.027888320220102156, 0.032888398971408606, 0.03885828237980604, 0.034683334441589456, 0.031654089489685636, 0.05536355171352625, 0.01542792875053627, 0.07324267804090466, 0.017744226780320917, 0.034029878077230284, 0.09183987083711795, 0.04757272458768316, 0.021692454116418958, 0.019547581173745648, 0.033404075407556126, 0.06715343693005187, 0.06695384585431643, 0.05826234830809491, 0.026971051136830022, 0.03382371199716415, 0.07387093361467123, 0.015696547193718807, 0.05035070462950638, 0.019299897232225964, 0.025003338598513176, 0.0457709189504385, 0.07279805439923491, 0.06932179736239569, 0.04441339090200407, 0.0137837255939043, 0.012446225354714053, 0.0015406680426427297, 0.03312037991625922, 0.0020778192639616983, 0.02722561711977635, 0.1056680345375623, 0.027055518568626473, 0.018807352054864168, 0.03387470729649067, 0.026145396155438254, 0.011306931979821196, 0.04197171995682376, 0.012676819543620306, 0.02437926110412393, 0.03230016339304192, 0.04703982014741216, 0.06143344100564718, 0.03388670040294528, 0.04263448242896369, 0.04782353487930127, 0.051095671619155576, 0.0020147922665013796, 0.026088816512908255, 0.0719605182696666, 0.011905669583939016, 0.045516936507608206, 0.07353803076382194, 0.015822232235223055, 0.0418894679418632, 0.0036211717607719557, 0.023538649514583603, 0.04165521051202502, 0.03946075701553907, 0.08252522030047008, 0.044502774320010624, 0.03251105546951294, 0.03207046911120415, 0.051546636170574596, 0.09648507407733373, 0.03804307683770146, 0.033976484156612835, 0.024509665356682878, 0.028384665193568383, 0.019237711194104383, 0.06385032845927135, 0.011779146551686739, 0.05740786237376077, 0.04537116004420178, 0.025163964800802723, 0.024869283827553903, 0.028291046020707915, 0.030883348347353082, 0.07261614594608545, 0.025545908770124828, 0.03685367280351264, 0.04203364645530071, 0.03800671753872718, 0.05035191581451467, 0.005275059308457587, 0.017869891465774605, 0.03802276149924312, 0.024988594032557945, 0.023706849864018813, 0.05885902486209359, 0.05524251124422465, 0.015143581865621465, 0.10114427549498421, 0.055560177591230185, 0.03990489550467048, 0.023021648238812174, 0.04541893569486482, 0.050455382226833274, 0.029845922586641142, 0.04032682554264154, 0.05305976586948548, 0.09992303459772042, 0.03005040929253612, 0.06840638576873712, 0.02004658430814743, 0.048165910079010894, 0.03730633708515337, 0.037345386775476594, 0.022137946282912577, 0.031383560970425606, 0.028362831633005823, 0.025046810640820434, 0.04539783325578485, 0.04344088397920132, 0.013823203609458037, 0.03454964268686516, 0.01376164351989116, 0.020639399997889996, 0.03818461584991642, 0.05064922271828566, 0.04112032814217465, 0.039620697897459776, 0.043601242160158496, 0.06441847940108605, 0.01746431242541543, 0.052775045790310414, 0.01986973942257464, 0.02936091593333653, 0.016889325243287852, 0.012029341920944197, 0.04715853663427489, 0.03427653234185917, 0.03759891799251948, 0.03509919837649379, 0.04317559035761016, 0.059321772174111435, 0.01572139005708907, 0.04583989203508411, 0.0198247508545007, 0.015442871787984456, 0.0354966027662158, 0.025979725045285056, 0.1397957878985575, 0.09655566207532372, 0.16167861010347093, 0.1000245570072106, 0.168599273743374, 0.09819292636322123, 0.19100374009992394, 0.14439617390079157, 0.14563353679009847, 0.13532498851418495, 0.1327579276902335, 0.12768164436732019, 0.0924666268484933, 0.282960013619491, 0.07418111911309616, 0.18069166344191345, 0.20491973337318214, 0.16364892651992186, 0.13731206474559648, 0.16759429552725383, 0.0731467671160187, 0.11947688034602574, 0.2041630989738873, 0.17441250037934097, 0.06871506491942064, 0.15139978166137422, 0.17238460348120757, 0.1552150755056313, 0.13116978933768614, 0.17208319822592394, 0.0977335310141955, 0.24056498280593328, 0.26647717665348736, 0.09547448437660933, 0.10735595824995212, 0.18676242125885828, 0.07708611751773528, 0.1267756779811212, 0.09452433178999595, 0.06671778352132865, 0.16559556206422194, 0.12136026285588741, 0.11701276685510363, 0.10937162794704948, 0.1479007394186088, 0.11119865133826222, 0.1428599570478712, 0.14189505310995237, 0.14075499214231968, 0.13320445801530564, 0.08979840323861156, 0.12940075354916708, 0.16407993196376733, 0.07531078492424317, 0.09892805120242493, 0.1027812547981739, 0.15853791577475412, 0.12836074935538427, 0.0981740630897028, 0.14960821851023606, 0.08050868207854883, 0.09728091423000608, 0.1396670833762203, 0.09352634248456784, 0.10060793427484375, 0.10502358233290059, 0.125153816438147, 0.16616785206965037, 0.11834887016032423, 0.06987334455230407, 0.1452158306326185, 0.1265159212052822, 0.12318628201527254, 0.1118117348690118, 0.10845310866300549, 0.12568132313234465, 0.17478709242173604, 0.14695768430829048, 0.18626662929143223, 0.10412548016756773, 0.16293780824967793, 0.11162948036300284, 0.09002900336469923, 0.11311504457678113, 0.08132725993969611, 0.14507648668118886, 0.292363884725741, 0.1152554697224072, 0.1524874461548669, 0.11038700810500554, 0.14754210651985236, 0.08580363688192197, 0.16348956578544208, 0.1848778309566634, 0.14754712767899036, 0.09874603418367249, 0.11842653527855873, 0.11580854361610753, 0.2003886800791536, 0.11119371160332646, 0.10214997295822416, 0.07346948515623808, 0.11991305622671332, 0.1533114726522139, 0.18283469416201115, 0.05500393833166786, 0.18618942557701043, 0.17754452303051949, 0.0998565245951925, 0.22153804664100918, 0.055798475697104416, 0.14039992833776133, 0.14812864576067242, 0.1663629308875118, 0.073940530951534, 0.1768342868557998, 0.15288639760443143, 0.1252720443797963, 0.12304077696587358, 0.18248277875993932, 0.10870891636503593, 0.12336736944104944, 0.10421215623084988, 0.22022377859268868, 0.08521428172077451, 0.16183890721627645, 0.40259648540190285, 0.27782844326325823, 0.17754161890063966, 0.07288948699299778, 0.08419823659850018, 0.12410904892853328, 0.15567822993866035, 0.09296285986368145, 0.1602533608675003, 0.18120839500001498, 0.10990482076470341, 0.19693211412855557, 0.14198447045470985, 0.20204435980745725, 0.12544089103383677, 0.10338970393474613, 0.13353254326752254, 0.14265765861741134, 0.11039477054561887, 0.15818233628358158, 0.1579278992222888, 0.1564394919467824, 0.10279424195843083, 0.09965264517813921, 0.2048088200390339, 0.16852861110653194, 0.1617350506463221, 0.15362035536340304, 0.15274471949253762, 0.10767963302454778, 0.23177543016416685, 0.1384579882557903, 0.11189556108521563, 0.1398799940943718, 0.12312419606106621, 0.07733858682747398, 0.0926198943385056, 0.17639754100569657, 0.16360459104180336, 0.10062366271657602, 0.10264775303325482, 0.11685280900980745, 0.11163652355649642, 0.14389719281877789, 0.10796267712222678, 0.14333966773535523, 0.08957147398697478, 0.09162966747369085, 0.12231591157615185, 0.1107655017237578], [0.03327443450689316, 0.023348887018593292, 0.054062579558896165, 0.02037272386119834, 0.041261222546121905, 0.06644416427505867, 0.028077560244128108, 0.07987071666866541, 0.03448866613741432, 0.06727808381297759, 0.009518811545733894, 0.013654328117679273, 0.05956166822995458, 0.03266022460801261, 0.0705027672063027, 0.06323516182601452, 0.007982243550941348, 0.04767584155446716, 0.02830252344054835, 0.043040012275534015, 0.05112995120829769, 0.026944890219186033, 0.007838916598952242, 0.01813083398155868, 0.01001317604511444, 0.04997782588803342, 0.06361398792692594, 0.06755959442151444, 0.04083176076944385, 0.01664558019755142, 0.028205910231918097, 0.018516615066411238, 0.0413810586157654, 0.033736896834203174, 0.019915289478376508, 0.012300928106664546, 0.02076215885712632, 0.018306862928771546, 0.045888692273625305, 0.07866753837359802, 0.03296551786895309, 0.04323573909433825, 0.03505242017230817, 0.038374056041772873, 0.032955506084752936, 0.019152980829988207, 0.03757192586947765, 0.018221698302243437, 0.022655532795137594, 0.012924504333308764, 0.03128710721752473, 0.033971361217222044, 0.0404123379183667, 0.09128143651677029, 0.015309025666543415, 0.020481788187420795, 0.036570927261241844, 0.06431165084775005, 0.08096615717347179, 0.016407202363812497, 0.021602385378043567, 0.03295820665412715, 0.015607511524909308, 0.03439843455063445, 0.034427991536046774, 0.0134743492484891, 0.026318746585665003, 0.055818268563598394, 0.014302140767020839, 0.02320692901100431, 0.032313547496284754, 0.04080650908872485, 0.017856914483542954, 0.02739353078816618, 0.08697172134582486, 0.011801894438186926, 0.03813200902992061, 0.05440959254545825, 0.01187796245462128, 0.022377893228882124, 0.04630754854796188, 0.022150582301297357, 0.009244325470977595, 0.027258853461327295, 0.040893727980021916, 0.030458378472498486, 0.02464903984218836, 0.07386446717594351, 0.03346252780673759, 0.04692155827901193, 0.04075380048847624, 0.0508026225226266, 0.027722625361223305, 0.04963447359789695, 0.029368681766624962, 0.0336648432005729, 0.04907264320978096, 0.06326355851654496, 0.06339505860315901, 0.003352801618997806, 0.05266384407877922, 0.02224302082322538, 0.035524819644966295, 0.03431285432140742, 0.022866177206326808, 0.04584242636337876, 0.01336472258636994, 0.04110792112935867, 0.08772684261202812, 0.04315887125475066, 0.017994741909205914, 0.03101148290027465, 0.04907119453751615, 0.013358954190542656, 0.05007958917745522, 0.021675412709425603, 0.03296381135338119, 0.01946115956109549, 0.018495241213323813, 0.07747824290501219, 0.08312693836965732, 0.033025432511099746, 0.050824054051190615, 0.03632783530546086, 0.03445176061775003, 0.008323438947887292, 0.04492005639310394, 0.011824858607724309, 0.05413486050175769, 0.030762650538235903, 0.04997008380347064, 0.10139428172260523, 0.022007406323349903, 0.03472547825159771, 0.010413087621730353, 0.04196302792323487, 0.04001797675820334, 0.05777632724493742, 0.023881343625751988, 0.07663428783416748, 0.012730503537958222, 0.041150906322790046, 0.03569833461993507, 0.03343300135540111, 0.0815339959891779, 0.0710566146299243, 0.05445286611627255, 0.022195745592138598, 0.03782762161323002, 0.05238035214798791, 0.012814665628996278, 0.07398264083479132, 0.05095867539889046, 0.017961656541696618, 0.06360022723674774, 0.013184494355560412, 0.023104532987677624, 0.02348346426151693, 0.016135825675779154, 0.02975816765267934, 0.008714476134628057, 0.02625671321792262, 0.018991248615618263, 0.05937642138451338, 0.04100558447784611, 0.027032813090564947, 0.029341302878622497, 0.08248910866677761, 0.006922315872673477, 0.010384841057072793, 0.023851661111361215, 0.0480634953959712, 0.061873986651854854, 0.03471635874094708, 0.0384532139370484, 0.060752490402332375, 0.033857635355421474, 0.05669337856982436, 0.043018048096980364, 0.06275689641812018, 0.04690892734963979, 0.04169285224218454, 0.030198482596980672, 0.0234301873881902, 0.04800597598244037, 0.0564699030614325, 0.045761215899671824, 0.03551609029195138, 0.0394655101533447, 0.008076869500135737, 0.029264156839677265, 0.034296369313129356, 0.008026890306999641, 0.05689116474241018, 0.04169946117326617, 0.038536538037338426, 0.05770105056996856, 0.007357717375271022, 0.005676612939818629, 0.014878440914409501, 0.0635942764846342, 0.024212224442245703, 0.03283119846933654, 0.02557141999048846, 0.02162370834100459, 0.033406524918973446, 0.010427648135061775, 0.012067809767488922, 0.10371400974690914, 0.04242741050464766, 0.017752596509775946, 0.02303931729069778, 0.02119807350183172, 0.03940037079155445, 0.06321695673146419, 0.039186605119279454, 0.020026114602972354, 0.04421046143397689, 0.029329058714210987, 0.00625320104050583, 0.07295814795153481, 0.01983542929935668, 0.04808604989999107, 0.1051040972982134, 0.06337176449596882, 0.03370626437078629, 0.03297743972923074, 0.02893753383042557, 0.03212156958345856, 0.022153455897101333, 0.04156648866566164, 0.03546541390408363, 0.015920780964994004, 0.009528480669749635, 0.08239906028445278, 0.024436510799984847, 0.03612364376229899, 0.025487775282402123, 0.019645860185846686, 0.041810645921421905, 0.021244441192331057, 0.03591021057218313, 0.01964238439021366, 0.07315326069614717, 0.029620041671608175, 0.007730479917622038, 0.030364387801715305, 0.04526996333152056, 0.02490238276576357, 0.016074319869013767, 0.028987290803343058, 0.016085332492366433, 0.017518210158284222, 0.006909056450240314, 0.05608611008418458, 0.02256478212906846, 0.00818165990390948, 0.016599314287304878, 0.05157268512994051, 0.010998885563042547, 0.030587717425078154, 0.0545636369580669, 0.0612985346732395, 0.028301020485482047, 0.02528592468505459, 0.044295495442513905, 0.06793599815240928, 0.040501171723008156, 0.07638777606189251, 0.06022627292467015, 0.02303885927956019, 0.03801782176430736, 0.019439612681578313, 0.02594873126197074, 0.01195246135882501, 0.07253054875348296, 0.08033760304429702, 0.0026053458901255256, 0.04320331869114723, 0.08460037037730217, 0.02041039103642106, 0.03272231734756913, 0.029900425912014077, 0.055894261093011925, 0.01343030808493495, 0.04575778251247747, 0.030115572403052022, 0.03322844001065407, 0.05274944466405681, 0.019892392314172218, 0.02185892080888152, 0.028817891143262386, 0.04635072712387357, 0.023352936176317077, 0.01642095117962786, 0.07673339465899126, 0.02501299075915345, 0.025261936775807823, 0.009617985375890774, 0.0630260237625667, 0.05412474015195455, 0.04023227508046797, 0.056030429500554285, 0.061222857662609646, 0.026313800065379058, 0.005384480713733605, 0.023084914843950952, 0.06265259201505355, 0.029436983101602112, 0.021075981303251216, 0.058519180598003526, 0.017523889496390308, 0.020251632501770343, 0.023287350677752068, 0.06787983580891575, 0.03822580971089857, 0.017680505556719642, 0.028544695981379067, 0.0264226930615093, 0.019498881019119705, 0.0043147850997879034, 0.03257273769538317, 0.07476905613605465, 0.044517047304127894, 0.046281906709607155, 0.03441291109525731, 0.029482285492122173, 0.047310056896614175, 0.029427368260387863, 0.04670822347647377, 0.06637656183115073, 0.041334517898836305, 0.05885386121060167, 0.023377136127757173, 0.04239748032497508, 0.05630783836490341, 0.07158036224011864, 0.02233262815778809, 0.04916417079844645, 0.03345684168328132, 0.03368419501930475, 0.01952656015886792, 0.031992339196481874, 0.04771658418966191, 0.030835423418985944, 0.07109186452414308, 0.010067368940716344, 0.10173540841788054, 0.056916012694793086, 0.06924939089055572, 0.06619103678635188, 0.02959889852042709, 0.10599940389926944, 0.10580352441008602, 0.14113915152847767, 0.15256709259535584, 0.14410581519561155, 0.11844690489981856, 0.08337370798523937, 0.10782485308923892, 0.10847262333014182, 0.16397836884217604, 0.11001924891024828, 0.15053820503609522, 0.10634289189640965, 0.1320799219288996, 0.1557875962129661, 0.154665896402938, 0.1433843153395823, 0.161693239318473, 0.12768973250474247, 0.10515882114746741, 0.1645511473928179, 0.12245543194668633, 0.1223681994846889, 0.0774835083367569, 0.27880775928497314, 0.18259541557303496, 0.10183598766369478, 0.12156148920101778, 0.11578651836940221, 0.0862837682611176, 0.13155492581427097, 0.05801834711538894, 0.19004977414650576, 0.22440850761319908, 0.08267447086317198, 0.12956024999065058, 0.0721032413254891, 0.07334474327840976, 0.11450140018548284, 0.15784787280218943, 0.13983101743672574, 0.19810718750315054, 0.1062283483999116, 0.10556686496628181, 0.09302941736366067, 0.10792443488857575, 0.10564962588250637, 0.20041567220219544, 0.15211254198636326, 0.1274036214287792, 0.07036142157656805, 0.08219461089798383, 0.11186262499541044, 0.25525249753679546, 0.13182221432881697, 0.06931039118873221, 0.09663807693868876, 0.1390748851533447, 0.2369541179920946, 0.25804637904678074, 0.15855059080890246, 0.14054575908396924, 0.18407577542322023, 0.17454395975385392, 0.09832220085497413, 0.14827386582536356, 0.14670042454132012, 0.20137403506253446, 0.17730500016893658, 0.13100304614220346, 0.12288913795990603, 0.12122824708265917, 0.17669137381017208, 0.07636005112103053, 0.1944423655846289, 0.10907231936497347, 0.07992782217583486, 0.10337065067142248, 0.08209031328026738, 0.11305982539696352, 0.14863909408450127, 0.08406554907560349, 0.14312886047576154, 0.1110971492848226, 0.18824462672429426, 0.17793211580387183, 0.07322095813495771, 0.10065796266176871, 0.09876727232975618, 0.19959338275449617, 0.11003032260175262, 0.09406691776322466, 0.15935692111296312, 0.12721422873437405, 0.12628361795629772, 0.11591933481395245, 0.24418412574699946, 0.1100799370823162, 0.11937861490462508, 0.16176223275916918, 0.14813239127397537, 0.06737302443278687, 0.100942472395088, 0.12649073398538999, 0.07860142192138092, 0.1031287597226245, 0.1620976733309882, 0.1863989300493683, 0.15287156482892378, 0.241471994136061, 0.13389355103884423, 0.09923012820737702, 0.17546558672828333, 0.11650050005742482, 0.17840586895389215, 0.1253430734255484, 0.13130114014659608, 0.12311595864593983, 0.04970987919451935, 0.21606061341507093, 0.1311357133090496, 0.09380068097795759, 0.20019508046763285, 0.1708008348941803, 0.1500462671475751, 0.13173169775732926, 0.11795019012476717, 0.17356528155505657, 0.11067909028913293, 0.11476342326828412, 0.08529394851731402, 0.1902993664677654, 0.14450036973825522, 0.19142162267650875, 0.09911155421286821, 0.08368988494787898, 0.11513184064200946, 0.13664022008223192, 0.19401681556233338, 0.22486346534320287, 0.13478078985852854, 0.0892645251005888, 0.07876299468002149, 0.09909567649343184, 0.15756367519497871, 0.14573239934231552, 0.17683580677424157, 0.1412466179047312, 0.13969132064708642, 0.25308835080691744, 0.1577743331768683, 0.2824996140386377, 0.13397052405135973, 0.13434939086437225, 0.1932403136576925, 0.1919031518378428, 0.14536964095064572, 0.10699311164872986, 0.11214289388486318, 0.18857420475355216, 0.1333224552550486, 0.08044079464993306, 0.12740656627076014, 0.16181310931486742, 0.16559375716107233, 0.1157382745295763, 0.11062068878007786, 0.16720047380243028, 0.07869650503354413, 0.1349679162459714, 0.11798014066049031, 0.16450086794793606, 0.09741617340062346, 0.18209685518273286, 0.1624136942305735, 0.10415062667535883], [0.05629136353465063, 0.05068521900102496, 0.004576868402572083, 0.08177486235009772, 0.041051918241594515, 0.060522025983248434, 0.009360514414895858, 0.03134965457554374, 0.021377717344356433, 0.042769181808190684, 0.009932021560546542, 0.023717804811894894, 0.05346164859033056, 0.015136591258591839, 0.03858079209125467, 0.049626283680221865, 0.07508148758539132, 0.018131139322317073, 0.039545791024076085, 0.09064636166606631, 0.04162230834897075, 0.07495900522917509, 0.02577428499768887, 0.0362948313621538, 0.044923757801630666, 0.02482304166603301, 0.040348419919610023, 0.06680351642093488, 0.05019951006397605, 0.022006047556975057, 0.011395725072361529, 0.037327330958630354, 0.049347782374492714, 0.0060792051538425896, 0.030021303532911197, 0.01417703417661999, 0.01783762712563787, 0.06168699597141572, 0.04573073610663414, 0.0518198890079345, 0.09360629426581518, 0.02066770678253046, 0.033529899548739195, 0.04889131151139736, 0.05889088208121913, 0.061221134183662276, 0.02328905719332397, 0.015925710521904484, 0.10003255014973027, 0.00662064302014187, 0.018853614572435617, 0.06649772782943078, 0.00859257222951523, 0.05565549140529973, 0.08065774943679571, 0.037916658978377066, 0.015618191666102834, 0.03314299548843077, 0.012072388182527252, 0.06795941439590283, 0.06579570192843676, 0.02247656918396907, 0.05001155586381044, 0.021430812709565674, 0.01726493508821087, 0.022604423841195445, 0.019181029771321585, 0.02587626202564154, 0.022038356001888002, 0.09201875302408423, 0.010828178026713431, 0.028528506135834113, 0.03681901323476008, 0.024627898387344818, 0.029468087146856954, 0.004697682410811207, 0.06847931471254144, 0.009691297691980643, 0.045316056215337346, 0.062207133775310855, 0.030931609150554453, 0.04214039358443447, 0.058993747990046225, 0.05204721859523228, 0.036189834853368144, 0.05431068588846496, 0.06131100614688226, 0.022235697734036615, 0.055220038164407015, 0.049689475646508593, 0.027314018358343413, 0.025077646664742912, 0.011484431651686984, 0.03532319635685001, 0.009755565136271929, 0.03516837162896991, 0.021737807397065417, 0.043687480568353615, 0.03507031314074993, 0.01093452566835497, 0.06203396485320159, 0.0415318698090102, 0.014549037607918893, 0.0639276746660471, 0.05044746711584074, 0.010734480822325816, 0.009071808790655007, 0.06410264849130597, 0.012180116642931742, 0.04026529259447541, 0.053074632571744065, 0.009584004342156862, 0.03571977971919945, 0.04241448101986732, 0.009944620259505297, 0.05069381603971124, 0.015683336116905724, 0.012673338658974638, 0.01761553922135915, 0.018025842561785663, 0.019110750506765077, 0.04934926836618355, 0.04593900903793318, 0.014569103584757872, 0.027972563735342452, 0.020408078928345015, 0.06681570290986981, 0.06871617093150105, 0.04205331040014114, 0.008358271543069609, 0.019487982050382664, 0.043227369364883216, 0.0010334230402284966, 0.05297313391097954, 0.01698658475652337, 0.016527046915143728, 0.029230050276964903, 0.059087419749370644, 0.033926893424774916, 0.024613257297979932, 0.04954700025596789, 0.007318822899833322, 0.05468708622668471, 0.05747053186808314, 0.020703270499195372, 0.028137508813025694, 0.05242565114583288, 0.05990304598318679, 0.00732768711168319, 0.07092691944645983, 0.04653813171067408, 0.04578205371009452, 0.08234728127717972, 0.026585828147030303, 0.06666346000773565, 0.016354982308777313, 0.014502881959612881, 0.017203846580481956, 0.028573523541646342, 0.034287331226680956, 0.008153544805411781, 0.07615305722824164, 0.0568424594987716, 0.049580468995762725, 0.028845996063734804, 0.024737649730273654, 0.05203803123107978, 0.043140886684081385, 0.03530001420793789, 0.01578128264684762, 0.0059959450902949485, 0.03587740340403148, 0.029582752779658352, 0.019765063521585295, 0.02921609959698149, 0.044349001321409426, 0.023397973938179866, 0.024993771254750233, 0.03787270347986903, 0.03236622556245752, 0.04137012402393988, 0.05511439026200345, 0.03525095273341451, 0.020871981446232115, 0.012484423483588865, 0.10762252751737833, 0.05184572762144463, 0.0431328460441104, 0.046633370885891576, 0.010693857778928109, 0.03340799733996391, 0.005361874047334173, 0.029348824439304214, 0.011541109681794686, 0.04564551550096699, 0.032002856489270926, 0.022724261607176492, 0.03224318341485091, 0.07886522276593105, 0.0448524505565209, 0.03919758042320609, 0.029809145988630395, 0.05285953018548233, 0.09123434618647609, 0.028614924355809177, 0.05313542252406478, 0.06016410554626158, 0.03667123170037355, 0.01633333195266979, 0.011671491881965526, 0.024368480879015157, 0.025181852680231844, 0.07496569558445897, 0.032664000655391386, 0.014798305928707123, 0.007917426493284958, 0.013290367870857673, 0.0674403826040881, 0.004958926450594195, 0.011832571854548795, 0.056216816284826825, 0.03322275049452271, 0.00935376129512276, 0.023407320758061748, 0.05211210689906563, 0.01681963460786002, 0.07227662059345416, 0.07144637192998614, 0.03226737318826573, 0.027237971546128392, 0.02731423718588693, 0.06612281009022679, 0.013697685657202132, 0.008532606697242175, 0.008070988297861601, 0.021182256850547025, 0.0517052267678082, 0.01967139515493597, 0.05474333677973066, 0.021856257558933327, 0.030754084033625465, 0.02370777606431927, 0.023799856659024954, 0.07487163706017391, 0.043369861718799384, 0.05807286061878715, 0.042195069936237166, 0.01747590858888413, 0.03194232777293239, 0.049665496218949556, 0.034688722009637525, 0.019624810333230665, 0.047104070628327985, 0.01771040859499148, 0.0410796906799078, 0.016799594076084237, 0.04076841274010284, 0.030315004023058072, 0.04038719141057559, 0.03923194143655045, 0.02774072189017066, 0.05240714071052415, 0.07859620398708753, 0.025258472854537622, 0.04140024080074259, 0.005049029963889292, 0.05665074282192758, 0.06397263439638273, 0.044210899089063914, 0.06756618299654552, 0.03728489877123918, 0.06538004494671311, 0.01753471721895039, 0.023661079284335886, 0.0019880732538045515, 0.05808894189872912, 0.06255273880170924, 0.03014976717531681, 0.04020313200141702, 0.035239264967718294, 0.03845173133803265, 0.039764255551355224, 0.020219819387421012, 0.04908167790355427, 0.015680170751043727, 0.08415609957384211, 0.029795612607683455, 0.018581971559407454, 0.008023668113829834, 0.03764391164960606, 0.031077816483697722, 0.06657242774963379, 0.050721096540136, 0.06665640324354172, 0.06832089035638741, 0.026519384301666702, 0.06407062163842575, 0.045309694949537516, 0.048275015117334466, 0.027560916895579015, 0.03431396033348782, 0.04798032396606036, 0.03199818138299244, 0.06345734811787095, 0.06819180585443974, 0.010659512032621672, 0.029265306956533874, 0.0372085296548903, 0.0398161770509822, 0.024814476857760122, 0.04549270602209227, 0.016106808125706654, 0.03035083067204271, 0.04803092232240098, 0.02312215623844947, 0.0728892223643405, 0.09500165403421436, 0.02119852981663176, 0.022386946582368443, 0.00957485769010548, 0.029845562963081256, 0.038434387982956, 0.06181877425738743, 0.01449508050323597, 0.1209460443684033, 0.014408441759379846, 0.045609146023967435, 0.0677410482562014, 0.044330572310302935, 0.04152618368555393, 0.03251479419746569, 0.05598015684102263, 0.04675993802292006, 0.04047189972230366, 0.03498499754018017, 0.028847641511155025, 0.01204978024387466, 0.061934600185070715, 0.029031856983367885, 0.042710892257413695, 0.06321032744433198, 0.051800740749708245, 0.02774327657451587, 0.012916258436494639, 0.020781164622998664, 0.00545172141365973, 0.04332105130223291, 0.01755773482312049, 0.035635909398219416, 0.009240061726554163, 0.06575595334704433, 0.03612982860899397, 0.15399059121097836, 0.11787270142563752, 0.15410948411694594, 0.22828488317983492, 0.1648184359073639, 0.18341417663863727, 0.1480868344328233, 0.16672938050968306, 0.16676241159439087, 0.14434820147497313, 0.160456636388387, 0.1277412333126579, 0.15452355332672596, 0.12251441021050725, 0.1311107160789626, 0.11716606148651668, 0.2176420207002333, 0.09663126444710152, 0.10960118312920843, 0.156168987176248, 0.07401290349662304, 0.17295005385364803, 0.14884417450853757, 0.12728821619280747, 0.09527505614927836, 0.09591332689992019, 0.18484959032918724, 0.16102604940533638, 0.12363092601299286, 0.12403436936438084, 0.13625534144895418, 0.07149219339979546, 0.17193002573081426, 0.08762491308152676, 0.1030073698077883, 0.07215010773922716, 0.22817143212471688, 0.12254856766334601, 0.08514864702842065, 0.09660429946546044, 0.1244398754622255, 0.11083286668040923, 0.12020174573574748, 0.10842963813671044, 0.20261544202055248, 0.17790418730250426, 0.09487267809786967, 0.18560588546097279, 0.1622075688626085, 0.10237423556723765, 0.1118581263082368, 0.22515896734382423, 0.27727630574788364, 0.08453436249068805, 0.15424648033721106, 0.152298026319061, 0.07872304932347365, 0.06389019917696714, 0.07428596634417772, 0.16254800345216477, 0.15739172085055284, 0.14197754939751966, 0.11678460266973291, 0.08818732361708369, 0.06514802668243647, 0.10806998065007584, 0.06279682141861745, 0.12627923462007726, 0.08837098947593144, 0.13994775260133402, 0.09116542738463197, 0.11000392758952719, 0.12496442374374185, 0.10773380726043667, 0.08412561299545424, 0.08282456959464721, 0.17680407847676957, 0.08452546689659357, 0.09465208636330706, 0.12939852795430593, 0.17515371846301214, 0.07709856863532748, 0.14742305076548032, 0.10569521665040936, 0.08723446367574589, 0.12607225429798874, 0.2124691004199641, 0.06236798728683165, 0.1369215135595628, 0.1410653404891491, 0.18746573637638772, 0.09702370874583721, 0.13823735580912658, 0.1614013606948512, 0.13486955580966814, 0.0823482922943575, 0.14712905511260033, 0.06138500039066587, 0.13098563493362494, 0.18836715657796177, 0.10316351428627968, 0.12494589973773275, 0.09819119609892368, 0.12047710881701537, 0.12046853213437966, 0.14942295130874428, 0.10939157009124756, 0.14099444715040071, 0.12045075451689106, 0.18328404719276087, 0.14297899923154286, 0.11122799797781877, 0.1889164306755577, 0.10412218248737709, 0.10365633427032403, 0.13943530938455037, 0.10874529262738568, 0.16150149889290333, 0.21041341072746686, 0.12667897317026341, 0.1375423866723265, 0.19548086343067034, 0.18204338662326336, 0.09380718812878643, 0.09936593699135951, 0.17647113491381916, 0.09969585428812675, 0.14183562701301916, 0.1375143224639552, 0.06562521321965115, 0.10962206165173224, 0.1986087877303362, 0.10260449642581598, 0.1430104018322059, 0.09809611977211066, 0.0938528331794909, 0.16124711611441203, 0.2096979362624032, 0.15487385381545338, 0.11963048710354737, 0.2095445602067879, 0.06459901042814765, 0.13606658657746656, 0.1607346050441265, 0.1141521582113845, 0.12575738690793514, 0.11762856452592782, 0.09657861012965441, 0.16576781496405602, 0.15937293453940324, 0.167913912662438, 0.19881568662822247, 0.21853292360901833, 0.09492098979119744, 0.16753131390682288, 0.17509285387183937, 0.12069499998220376, 0.11192422918975353, 0.06709771563432046, 0.16149056090840272, 0.08520692640117236, 0.2653716259769031, 0.19725589746875422, 0.12976691818663053, 0.12430665189666407, 0.31760530599525993, 0.12014706938394479, 0.15207990445196629, 0.10525957002703633, 0.11417849894080843, 0.13651298119553498, 0.10415032811995063, 0.09306249594581978, 0.05879553434039865, 0.10981911500649792, 0.12339223096413271], [0.029745536723307202, 0.043954721585448296, 0.06147045509091445, 0.05591660185850092, 0.07150359957345895, 0.027199113541947942, 0.01516817367103483, 0.02513966815812247, 0.03704790345260075, 0.07215090841054916, 0.017617976858413646, 0.044934156350791454, 0.08858073822089604, 0.010025703497896237, 0.029905772767961025, 0.022548865393868515, 0.019669459633795277, 0.03785379610157438, 0.02629908942617476, 0.058542149008384774, 0.09645131696015596, 0.06613942062748329, 0.009498606469216091, 0.02733302242787821, 0.04653724961514984, 0.06838573794811964, 0.005342084997599679, 0.005388591787777841, 0.0055418245028704405, 0.06851410320294754, 0.0633104724277343, 0.007432681075962526, 0.027904252222340022, 0.02493828235726271, 0.15136683200086865, 0.018999742177714194, 0.04609448855210628, 0.0404675638835345, 0.013986550737172365, 0.022394439305311868, 0.04138165233390672, 0.018421917022871118, 0.08272335252591542, 0.056724655641508956, 0.05900113723639931, 0.07966209429183177, 0.019560882156448703, 0.04689432866871357, 0.03197652254519718, 0.04523855733818241, 0.035399049786584716, 0.05721359779792173, 0.07403352417583976, 0.013923828656386052, 0.05026895812313471, 0.023320653176467334, 0.032615604145186286, 0.027320966556934372, 0.005385795799416623, 0.021233789888875823, 0.06897553415702921, 0.048983266577124596, 0.034260451061917205, 0.08808875962027482, 0.05243091997025268, 0.013298340657326792, 0.04446070854152952, 0.032021522987633944, 0.0117838097836024, 0.03435710498264857, 0.024835927046037147, 0.05387696969721999, 0.013699415921499687, 0.004081402556039393, 0.031870572694710324, 0.06024131604603358, 0.0570600385378514, 0.03660944090890033, 0.027828972154696072, 0.046887509391776154, 0.008432549075223505, 0.07959261909127235, 0.05761658653084721, 0.02796939667314291, 0.03850099976573672, 0.013274913387639182, 0.026778542270351733, 0.02361168193497828, 0.029511543922126293, 0.036769585351326635, 0.06057545383061681, 0.03714876089777265, 0.03390931597511683, 0.04510109292875443, 0.023135124738993387, 0.056186492554843426, 0.06081778582717691, 0.01934335909650794, 0.032987003680318594, 0.012965163847963725, 0.019382666630138243, 0.0247319279837289, 0.0565996253862977, 0.038814211530344825, 0.03392998075910977, 0.051493018333400996, 0.05016072500231011, 0.029806876288993017, 0.06795538389789206, 0.05996425662721906, 0.008119426368336593, 0.005332475669482457, 0.05301578662225178, 0.03577766893431544, 0.031064958245094334, 0.013676798652990587, 0.00772139263738479, 0.01876043644733727, 0.024422616099140475, 0.02652982865194125, 0.06109587661921978, 0.008292272986311997, 0.06056327412703207, 0.0472863488830626, 0.01281692345427083, 0.04784162123022335, 0.014237674851236599, 0.033695984565253766, 0.05185986489855817, 0.00867608207876661, 0.0883168423814433, 0.022254549133192216, 0.013523247874607998, 0.012578133410508079, 0.029972014749156575, 0.006043814039523048, 0.048084082148436985, 0.016473771738154546, 0.029536273130880933, 0.020276899449527264, 0.027903069875070026, 0.06688091691051211, 0.0720721712069852, 0.07028397358953953, 0.00723397803293275, 0.031916557012924125, 0.01071106457883226, 0.05334609068397965, 0.03927734221464821, 0.0393076727299818, 0.03704471094533801, 0.0502180103212595, 0.01067081218518849, 0.07194539372410093, 0.07566613371350936, 0.010222426915009106, 0.0336099191834884, 0.016785684108201946, 0.04681832256859966, 0.017983013431408575, 0.028147881917123283, 0.03131101539890681, 0.03580602830541985, 0.046776738549981794, 0.03608574418883238, 0.05432483334360378, 0.02067706886945026, 0.05451536936951535, 0.03501213215557592, 0.05138753327940192, 0.06307475614760603, 0.0076939747336187535, 0.04280340711453131, 0.006002582859114877, 0.034526996580617766, 0.01850871691879417, 0.03234011214226484, 0.01628077941547547, 0.028314097551628947, 0.04290001014513629, 0.09863360093108245, 0.06649963451283318, 0.0543354184898947, 0.014720995345019867, 0.040120656069900305, 0.09366089597876583, 0.057143959748957834, 0.03316529893449374, 0.010914855786333126, 0.015111826426748718, 0.052939939977867265, 0.018685468505801897, 0.062160945896591456, 0.012175529746205678, 0.05474593896152718, 0.050321079790592194, 0.049958999933941026, 0.03126977404047336, 0.01607241997096155, 0.03430541757760303, 0.036491609910236936, 0.012826051446609199, 0.006094942925431366, 0.025691115264115588, 0.04803770427991237, 0.03021514063168849, 0.015204320927815778, 0.06651353769536529, 0.058120161294937134, 0.05782345150198255, 0.05976117788148778, 0.06970639101096562, 0.06643623220069067, 0.0459336248625602, 0.018463930214888284, 0.03647384586344872, 0.04518409811758569, 0.05558201963348048, 0.04262108814769557, 0.02626605155611677, 0.03849508972572429, 0.0674153310911996, 0.05374515409182225, 0.006688812888959157, 0.031163484922477176, 0.05368264405322926, 0.025099051051906178, 0.0426352322101593, 0.015902959242729203, 0.03361843140529735, 0.016815510811284184, 0.05331701206575547, 0.014088922163604625, 0.01863026968203485, 0.011435482983610459, 0.05732909124344587, 0.03270057708557163, 0.03667167274813567, 0.066723836053695, 0.045711173942046504, 0.09030560137970106, 0.01325504164144929, 0.026290590775066187, 0.044035426540566344, 0.04633139566119228, 0.02348871951523636, 0.0675188551789948, 0.04071113420650363, 0.04734946281782218, 0.06870908702590636, 0.022296363853716424, 0.03345215639897755, 0.029294870727296387, 0.02492864885633545, 0.015443731831120593, 0.014514783463839973, 0.029950036999902556, 0.01615855490256633, 0.04411108319514564, 0.004531406556322638, 0.021395506836207848, 0.01476879813708365, 0.017375521029212644, 0.0548745959864131, 0.03036405871223126, 0.034908740382109366, 0.051559843854712586, 0.029610738956502507, 0.04455900112433093, 0.03468942429338183, 0.03340342401393822, 0.036851247040820975, 0.00836076176658805, 0.028687273152172565, 0.014286590440730964, 0.06299798669559614, 0.037784154659935405, 0.044274114804076295, 0.0362252984861178, 0.03195565759337374, 0.04319793451577425, 0.05899222807160445, 0.030022579178746258, 0.04669820490692343, 0.06479720372174468, 0.06914925269250359, 0.02107697196437844, 0.01287420283603881, 0.018838700372725725, 0.021639838814735413, 0.031135010200419595, 0.016127176050628935, 0.0201659827227039, 0.004920889049701924, 0.017762545529486876, 0.04470915074593254, 0.03734505090064236, 0.016934795571225028, 0.028795621623950343, 0.06999158606465374, 0.041049957275390625, 0.022341505092169558, 0.027896101320428506, 0.07557623460888863, 0.04328527554337468, 0.05925108239586864, 0.011357715236954391, 0.06936582749975578, 0.007151906677920903, 0.037016544956713915, 0.0403236296427037, 0.04599293900121536, 0.016147197922691703, 0.04422200670731919, 0.021631959326831356, 0.018420291931501458, 0.012005440524912305, 0.07056466317070381, 0.05319192074239254, 0.05537894767309938, 0.014576930486197983, 0.00491996921066727, 0.027391496879447783, 0.04935554481510605, 0.040943790293697796, 0.03680584626272321, 0.03514289263901966, 0.026455556208799993, 0.041520080263061185, 0.003532247626156147, 0.0518717494394098, 0.03545236228299992, 0.0018877310711624368, 0.035006059267159016, 0.024647038163883344, 0.027326734104592885, 0.039157624888632975, 0.03374977542885712, 0.04327023581468633, 0.06877183794443097, 0.05403057984741671, 0.02539571843642209, 0.027496897116569535, 0.0693304758252842, 0.03961428234885846, 0.04598644542108689, 0.03908131005508559, 0.013884741646636809, 0.05385484606293695, 0.04527125933340617, 0.03776278080684798, 0.021747422238279666, 0.1379878856241703, 0.07880507742187806, 0.11100338253059558, 0.1200434435158968, 0.18577102731381143, 0.2341023167329175, 0.14198628892855986, 0.10407242551445961, 0.10210839233228139, 0.20702875591814518, 0.08825317544064351, 0.11869940135095801, 0.09673858154565096, 0.10043696380619492, 0.15701479464769363, 0.054651347787252495, 0.09408981832010405, 0.11731267933334623, 0.1296359066452299, 0.23556160128542356, 0.20561403754566396, 0.15040639282337256, 0.16086501947471074, 0.059853010810911655, 0.0847339467810733, 0.13166057371667453, 0.06640441569366626, 0.14763624646833964, 0.16123896012348787, 0.13645303941198758, 0.11770109991942133, 0.167894520131605, 0.13142204151621886, 0.14593933895230293, 0.18797850528998034, 0.11890270401324544, 0.181611404088991, 0.17046122811734676, 0.10261536655681473, 0.1219759112490075, 0.1598383281379938, 0.11044461572808878, 0.1634701189718076, 0.15235790024910653, 0.11925661430827209, 0.24472231258239063, 0.09763746402625527, 0.1103817019611597, 0.06845871438937527, 0.13099900207349233, 0.09828498320920126, 0.15882575032966478, 0.14403458258935384, 0.10059618204832077, 0.1027342594627823, 0.09688019180404288, 0.1545589185718979, 0.1106602338009647, 0.10953263073627438, 0.14613204289759907, 0.1957247153456722, 0.1560798819575991, 0.13898208870419435, 0.1869760783655303, 0.17425835079380445, 0.06910879164934158, 0.08623038112585034, 0.08846147212066821, 0.11170698263283287, 0.14561246149241924, 0.12557061335870198, 0.09993304977459566, 0.12488617508539132, 0.13219631782599858, 0.06974588174905096, 0.16976435908249446, 0.09145896841904946, 0.1442375731255327, 0.0955508059955069, 0.1512342733996255, 0.06925063260963985, 0.15921484945075853, 0.18176992344004766, 0.07523118598120553, 0.10961694549769163, 0.12919811585119792, 0.09530345962515899, 0.09364080455686365, 0.18022698909044266, 0.1461928803473711, 0.17448295945567743, 0.12595596696649278, 0.21599244778709753, 0.15292032435536385, 0.14445152878761292, 0.19569264778069087, 0.09226200782826968, 0.09501895667718989, 0.15008822775312833, 0.14160995983651706, 0.1011147660070232, 0.09627836516925267, 0.13462981581687927, 0.1488190008593457, 0.15235844307712146, 0.1635483404887574, 0.18054979534021445, 0.10252946402345385, 0.22529490504946026, 0.1290748260383095, 0.10292597274695124, 0.11144132938768182, 0.1309622661875827, 0.07932579198053905, 0.06428653148135968, 0.1084946689328977, 0.07241456676274538, 0.038746022153645754, 0.1339349823870829, 0.108900561795703, 0.1616061289927789, 0.08109329427991595, 0.12546781530337675, 0.21571029935564312, 0.12923972361854144, 0.1703944874129125, 0.0650502158594983, 0.13687844015657902, 0.10802091578287737, 0.10653486302388565, 0.12818426239703382, 0.133885245770216, 0.06762138182031256, 0.10957208076225859, 0.16861375368067197, 0.15786315341080936, 0.0960141843450921, 0.17228335248572485, 0.10390217429293053, 0.10919381784541266, 0.17981548474303313, 0.20580349809357099, 0.10783080384135246, 0.13707927295139857, 0.15055340422051294, 0.09322038425930909, 0.09358656246747289, 0.21878618001937866, 0.11864876906786646, 0.09058230796030589, 0.148397847743971, 0.13978578629238264, 0.07549453220729317, 0.18015727640262671, 0.1638599916228226, 0.10699075034686498, 0.1292959741715874, 0.10226279297577483, 0.08853811943637473, 0.11338953234787498, 0.08151359244116715, 0.13295715914240905, 0.09583306299256426, 0.16085482787873062, 0.13708077929913998, 0.1473079440849168, 0.08247781105871711, 0.14269624011857168, 0.1456181611865759, 0.12345509044826031, 0.11815767256276948, 0.06154271228505032, 0.1769723958734955, 0.09980992959546191, 0.13581029033022268, 0.08991543017327785], [0.05019389857937183, 0.023831496746944528, 0.02136881496491177, 0.015814194987927164, 0.04999775785420622, 0.013403561930837376, 0.031776008661836386, 0.032723637098180394, 0.011012896463008863, 0.015346804800044214, 0.03535825626126357, 0.034292790040905984, 0.02790483915513115, 0.02637612520317946, 0.0173231313404228, 0.016539472587672726, 0.06480928164507661, 0.07100616555128779, 0.06829456319766385, 0.04809076911104577, 0.02673722118405359, 0.018400697536500435, 0.06651054535593305, 0.043356026389769146, 0.03588528458827308, 0.01008523307141981, 0.01238940398408366, 0.020769244459058558, 0.049518210015126636, 0.015317605741854225, 0.019661464794938053, 0.017327100770281892, 0.020538221944921782, 0.0353805325659258, 0.03012149262108973, 0.03127358401460307, 0.010987309755624404, 0.03707254445180297, 0.03932778450793453, 0.027702072535508444, 0.07113875807928187, 0.03497058206370898, 0.03735317635749068, 0.043853080432329855, 0.03303030439253364, 0.039830931794962714, 0.06565037329814263, 0.02065345415446375, 0.06656465852367026, 0.022939635407445685, 0.02623782619567854, 0.06753834270473037, 0.05313136488465326, 0.011795035297317165, 0.03246637393853494, 0.00937434719941978, 0.06488814777029411, 0.09151736992810454, 0.0577620780095458, 0.04897805542818137, 0.005077368554858757, 0.010867106428902065, 0.022487749744738852, 0.015862917194941213, 0.027016820020175407, 0.06676334714783089, 0.07853859636400427, 0.0796427967559014, 0.018353330703186135, 0.06655326592070715, 0.057468781247735023, 0.03511883517993348, 0.015725256010357822, 0.010876974872579532, 0.05136622049446617, 0.08262324825461421, 0.033858575126422305, 0.04007806781945484, 0.058531862417502065, 0.0038180503927703413, 0.032360858350460014, 0.0304413031387542, 0.05834145192056894, 0.01618006276631994, 0.03471625017534409, 0.053914526610502174, 0.05268789814519031, 0.03728065114202244, 0.11159055959433317, 0.04834850385252919, 0.06298742190535579, 0.012739377079664596, 0.09027040576828377, 0.032774805423936675, 0.0726190365052649, 0.023513024639604346, 0.04847540007904172, 0.023843121748151522, 0.06002118571528366, 0.017117672633113604, 0.025247772357293537, 0.021017418642129217, 0.06126857056681599, 0.059496725643319745, 0.021553076238238385, 0.04096827183717063, 0.03406450371923191, 0.0319572351872921, 0.14788320607372693, 0.03346431913918682, 0.023183086986786554, 0.027925436085622226, 0.027073297882452607, 0.0376090994104743, 0.005037922769718404, 0.025534217611753514, 0.016995444727529372, 0.057720192042844634, 0.031185676410262073, 0.03848614324150341, 0.029888236030404056, 0.015746787622837082, 0.029902865245406116, 0.01089189331313329, 0.03674763135079827, 0.05399896011554769, 0.029661595156150203, 0.02800273479494665, 0.01632875353763146, 0.06429476211113588, 0.0713083850485938, 0.02054051878595991, 0.02692831021600536, 0.0354118571350617, 0.06121949891426733, 0.09073696644710642, 0.024904893345332572, 0.04702460399961897, 0.027914879777069603, 0.07793375024838106, 0.010296604363247752, 0.08041133944477354, 0.008349883153901567, 0.049368599828864844, 0.009965930499934723, 0.059791420187268934, 0.01748293821167733, 0.05870832223445177, 0.023455501833398427, 0.049210636876523495, 0.06210322292255504, 0.03274478703471167, 0.003930382289191974, 0.014865175554794925, 0.02609025500714779, 0.015009561021413122, 0.03942903211074216, 0.01956163363398186, 0.04999401912625347, 0.10032581977014031, 0.05886135223720755, 0.02918964351660439, 0.012135317216494253, 0.013868869016213077, 0.015883897497717823, 0.026177063384758573, 0.021550584318382398, 0.08253832281168018, 0.0824775667861104, 0.05131711491516658, 0.017802653734439185, 0.010929738603798407, 0.021914384261305844, 0.0901893140482051, 0.03951764539150255, 0.036005286898996146, 0.0619208055681416, 0.03262999587293182, 0.11969787920159952, 0.0787469744682312, 0.05266999499872327, 0.07722476257809571, 0.02402189028050218, 0.024956660478242805, 0.01781590043434075, 0.006442120032651084, 0.007676423577192638, 0.019662146722631793, 0.04756336419710091, 0.028783523344567845, 0.05810022593608924, 0.00766332954767027, 0.02733393675381584, 0.07194123430443661, 0.011969819132770811, 0.02797569178177842, 0.02151366862069283, 0.045212773007473776, 0.033263055474630425, 0.017361653469769017, 0.03557756895731602, 0.0334748737514019, 0.024599796859547496, 0.028371135205296532, 0.03586008379768048, 0.0025458994371417376, 0.055465386249125004, 0.05365951279444354, 0.02746244110832257, 0.0375762142107955, 0.032741971114384275, 0.03669661569542118, 0.06853356358728238, 0.024685117549129894, 0.02404294182945575, 0.0492048116533884, 0.040354689583182335, 0.027402641817129085, 0.04643272468820214, 0.02960006220798407, 0.02190147343623851, 0.04212570669395583, 0.031621499452739954, 0.04086003532367093, 0.026699538741792952, 0.009424733513567065, 0.02585389751142689, 0.07280551828444004, 0.04762746879298772, 0.03337281529924699, 0.05138941282140357, 0.028437473877732242, 0.04764302420829024, 0.06764871999621391, 0.027492300041818192, 0.06232314969279936, 0.024640110321342945, 0.03474816167727113, 0.04200612846761942, 0.04376824659162334, 0.030082392040640116, 0.06437571812421083, 0.05104613856279424, 0.028502921972955977, 0.020739507661866288, 0.03371340595185757, 0.04057586485786097, 0.019776274616430913, 0.04174025469858732, 0.027978865629328147, 0.04405315326792853, 0.019760181462126117, 0.020921388973615, 0.0307188239613814, 0.04104687672640596, 0.023866911185905337, 0.020043267968243787, 0.07427976453410727, 0.05941404615129743, 0.020353551854246428, 0.02709685661830008, 0.06748452130705118, 0.0354802873916924, 0.025821193819865584, 0.06167767968560968, 0.01636939948158605, 0.0928595664777926, 0.009182347234205475, 0.04404837638139725, 0.018468617195529596, 0.0334610655637724, 0.018214078353984014, 0.06283842918596097, 0.019260135080133165, 0.016597984358668327, 0.030928420035966804, 0.01204796092185591, 0.025624808822093264, 0.05213276489770838, 0.012197206395545175, 0.0337825690263084, 0.0372427685319313, 0.04017798210095082, 0.030552721981491362, 0.0959842134533184, 0.03999037056096962, 0.044452006329915354, 0.03581337344699672, 0.00964798595357154, 0.0422009731908994, 0.03292967425659299, 0.0466219104294266, 0.02732388086483947, 0.031487668598336835, 0.05090514916394438, 0.08429500926285982, 0.06303168274462223, 0.030389198434672186, 0.021240336055468236, 0.03240214042099459, 0.02830910692656679, 0.044660221585737805, 0.06407545959310872, 0.03493602427520922, 0.03853083495050669, 0.04307245642745069, 0.04330861036266599, 0.03445065460566964, 0.021822586954970444, 0.032853596910302124, 0.04894249001517892, 0.0178531757555902, 0.019689596856811216, 0.015010246341781957, 0.05107976336564336, 0.04605733536716018, 0.0401479196069496, 0.09273433605475084, 0.031242717456604754, 0.04203998736504998, 0.07598345061498028, 0.039295557487223826, 0.0464626684385751, 0.029728128907403777, 0.023489474385444607, 0.07867335341870785, 0.02683932882999735, 0.0507748093722122, 0.025896421301045587, 0.012729961558112075, 0.03610373215217676, 0.042219313992453475, 0.051169991559748135, 0.010442519078164228, 0.03775655185537679, 0.010746068504106785, 0.05596365826204419, 0.032571526510374885, 0.02247666078619659, 0.009820686686517937, 0.025279894205076352, 0.05321309442764946, 0.045267544354179075, 0.03138215301026191, 0.0692174726032785, 0.025233263582257286, 0.03802008807126965, 0.0004386655475952596, 0.06588055273251874, 0.06396735539393765, 0.03954632706674082, 0.016941550387335674, 0.18894837610423565, 0.10296758729964495, 0.17530467893396104, 0.16561325825750828, 0.1284733997391803, 0.09386445648436036, 0.11531120458883898, 0.14702129018093857, 0.15679342938320978, 0.07275266719183751, 0.12332899150039468, 0.07143432793340512, 0.12253027435924325, 0.1289722586848906, 0.1436302164303405, 0.12459893764129706, 0.1690057162195444, 0.12859088129230908, 0.13823521163846764, 0.15896162018179893, 0.09899177921137639, 0.17805318002189907, 0.16022733226418495, 0.17211412585207395, 0.13596156292728015, 0.05157706507348588, 0.049034278839826584, 0.11091570902083601, 0.1121570820521031, 0.08261131960898638, 0.07815588904278618, 0.14164054819515773, 0.07816088984587363, 0.09134038085384028, 0.10357593465596437, 0.15806898022336618, 0.17941639758646488, 0.10662191228142806, 0.08364685904234648, 0.18091036884912423, 0.14766007661819458, 0.0943282555256571, 0.24398718774318695, 0.1271463752325092, 0.1322041345494134, 0.10780441561447722, 0.15097524944160665, 0.10671353486499616, 0.11960497418684618, 0.16613235111747468, 0.19451244468135492, 0.183742438309959, 0.190121753141284, 0.10406194893377167, 0.1266271738069398, 0.10579042189887591, 0.10456677220229592, 0.1834011623369796, 0.1594514138996601, 0.14255613620792115, 0.09085433943463223, 0.08930565789341927, 0.07465949987194367, 0.15394290376986774, 0.12413331334080015, 0.18165879297469342, 0.16771587543189526, 0.10895936364041907, 0.11502623345170702, 0.1466603095510176, 0.12826171038406237, 0.08741170380796705, 0.10846954278115715, 0.08212666240121637, 0.21203026468200342, 0.22449723285223755, 0.09921117672430617, 0.1421610659786633, 0.15516736092311995, 0.08466509583273105, 0.13151375230933937, 0.15513709826128824, 0.1610227652958461, 0.10069271722542388, 0.11229021740811211, 0.10232519105608974, 0.11965815776160785, 0.11553695318954331, 0.2510134721440928, 0.12166552219007697, 0.23880573149238313, 0.15034383189465317, 0.14056713293705667, 0.13815617587949547, 0.10711807065776416, 0.09581702242472342, 0.16454988531768322, 0.23178362686719212, 0.20905841700732708, 0.1357258398618017, 0.08434741252235003, 0.12246387292231832, 0.25228846658553394, 0.1405376573758466, 0.11982936571751322, 0.21047400390463217, 0.08799472145204033, 0.09428478857236249, 0.20343547873198986, 0.14137887795056614, 0.10207114075975758, 0.16581498671855244, 0.12963517382740974, 0.13071365095674992, 0.13492021523416042, 0.10635871533304453, 0.1333692470299346, 0.26042127875345095, 0.12010782291846615, 0.16692049668303557, 0.16769698501697608, 0.1191332566418818, 0.0848987086543015, 0.13847168109246663, 0.07113683103982892, 0.20895481828067983, 0.23064591363072395, 0.11167139347110476, 0.06122239625879696, 0.1320266162178346, 0.1992524867611272, 0.18373253169868672, 0.09871800390205213, 0.1331036277115345, 0.16199988286410058, 0.15349725554031984, 0.15838456686053956, 0.2187358055795942, 0.14027993620506354, 0.15578923826771124, 0.14863865982208932, 0.32003307715058327, 0.12193893109049116, 0.13230888678559236, 0.1370901023702962, 0.12607777757304056, 0.09198074149233954, 0.13804860093763896, 0.05205707770905324, 0.22874984251601355, 0.15353675984910556, 0.13771791011095047, 0.13805337782417024, 0.0858667270679559, 0.10393846234572784, 0.08361475755061422, 0.0972093694976398, 0.12514548402811798, 0.19895864038595132, 0.1733600925654173, 0.15529666255627358, 0.20952596834727696, 0.16557973862758704, 0.06936817523092031, 0.14293059254331247, 0.06983724648931197, 0.08004511373915843, 0.1257412377744913, 0.22439473335232052, 0.12844153573470457, 0.15496595815888473, 0.0475426349522812, 0.12464323240731444, 0.1469261867127248, 0.12866151678775037, 0.1151705307087728], [0.028776992445013354, 0.03456463831077729, 0.04902791078867657, 0.07447724536593471, 0.0485535232084138, 0.03497627836519054, 0.01653971686027944, 0.01557782561784344, 0.044555031694471836, 0.025337522184210162, 0.09595722133027655, 0.059133777261844704, 0.03291272105915206, 0.01867818273603916, 0.123057238225426, 0.030320120177098682, 0.03981531870418361, 0.023513823614588807, 0.01726524212530681, 0.05305297373394881, 0.01937383719320808, 0.008968347467349043, 0.0755003404670528, 0.01989462469438357, 0.04455657196896417, 0.03995725465938449, 0.005813640118243971, 0.029608055350503752, 0.052743208927235434, 0.015433952445164323, 0.004363017913419753, 0.06389859944049801, 0.06659201705562216, 0.03091227090252297, 0.08082151386354651, 0.040641740430146456, 0.03958754806912371, 0.02904571606112378, 0.07206772001726286, 0.04667188114087496, 0.026432893139177134, 0.04434098782283919, 0.020695351995527744, 0.020610090677759478, 0.07649317290633917, 0.028668962884694338, 0.044453617850584645, 0.009297854250429996, 0.024860201636329293, 0.0394127472702946, 0.07376412541738578, 0.011809782407778715, 0.020495443704671094, 0.07054610523794379, 0.1074842827926789, 0.06527474988251925, 0.008465597123306776, 0.018963123339095285, 0.06240025841231857, 0.07482302681143795, 0.04326192715338298, 0.024955093062349727, 0.07975436148366757, 0.07348536966102463, 0.013774321098545832, 0.024430721199938228, 0.019952943082898855, 0.03477502487865942, 0.02858209004625678, 0.025096280932692543, 0.07427255849220923, 0.08276380678372723, 0.05779806750693491, 0.0017095231783709355, 0.014229123613664081, 0.033992687572858164, 0.04358044845451202, 0.03215480762134705, 0.04545292351394892, 0.03682970355397888, 0.06515355674283844, 0.05506358834515725, 0.02735599423093455, 0.043387659692338536, 0.03059636874656592, 0.036166133625166755, 0.04829768497230751, 0.011920098631110574, 0.04824649289782558, 0.02344015846028924, 0.07483651608760868, 0.02847940394920962, 0.02232227032072842, 0.011514144700153597, 0.03907625496919666, 0.00918271703579064, 0.033877692850572724, 0.011320251622237265, 0.03065703995525837, 0.020342203356059532, 0.05528478736856154, 0.03618165850639343, 0.010199070043329681, 0.020344893747408475, 0.018277869127424698, 0.04891304838071976, 0.04277215039889727, 0.04249156938333597, 0.028392933142770613, 0.055301380942442586, 0.038048844385359964, 0.05710167344659567, 0.021184173711974705, 0.0362086845561862, 0.014919353183358908, 0.1341067331710032, 0.016618549058746015, 0.026314627878101807, 0.07411491445132665, 0.05694144418729203, 0.012855449824460914, 0.06171137573463576, 0.05422723965187158, 0.030889713005828004, 0.01763660943002573, 0.0440692820453218, 0.021421277596216117, 0.04588113339351756, 0.01881388295441866, 0.013254095085098274, 0.008641508175060153, 0.029993934822934012, 0.03546387702226639, 0.009863921241568667, 0.026864979150039808, 0.012476133481998528, 0.030165302234568765, 0.03242672035204513, 0.0270727228240243, 0.05589829837637288, 0.028726139638040746, 0.09802618995308876, 0.01586713089740702, 0.008974014082923532, 0.06676073478800909, 0.008564178931659885, 0.03934796413938914, 0.03918124129995704, 0.014121401938609779, 0.021316459202872853, 0.016728928046567098, 0.08720788545906544, 0.018386655254289508, 0.01631656874503408, 0.0043900320888496935, 0.03586702181824616, 0.05596904583009226, 0.04511204787663051, 0.018728463877258555, 0.06382351275533438, 0.059569322104964934, 0.04089070849918893, 0.05185013470639076, 0.028960030658968856, 0.03516992208148752, 0.05874769762158394, 0.04627443264637675, 0.05100115169105785, 0.080452472237604, 0.027892516959192495, 0.04468836721831134, 0.03071447115923677, 0.07993949297815561, 0.074118856739785, 0.08459579026592629, 0.03292334691754409, 0.06135249177792242, 0.035137311688491275, 0.03127686473141823, 0.010147241842267769, 0.029446706508419344, 0.013258954244000571, 0.012566690765587347, 0.013413291274836021, 0.03685981354543141, 0.020838765460731726, 0.10679496585258416, 0.04095444329349058, 0.060436720560703955, 0.015311894173334752, 0.01187170296907425, 0.05213825085333415, 0.016981582257098386, 0.04999937955290079, 0.01005668964769159, 0.04395027718107615, 0.016657133952581456, 0.03942691168880888, 0.08917368961764233, 0.0234502686320671, 0.09744045816894088, 0.0423576096072793, 0.043625279263194115, 0.03705593052187136, 0.040362373992268524, 0.04290606267750263, 0.010324926414926137, 0.02987240580841899, 0.03226516116410494, 0.005573781805911234, 0.04278043191879988, 0.02862232717286263, 0.048461415472307375, 0.013811310586918677, 0.029766595057610954, 0.014360148725765092, 0.016279658136357154, 0.03313993868817176, 0.043122569631252966, 0.050699821074626276, 0.06648986360856465, 0.05144678295723029, 0.04301589035562106, 0.02940939726041896, 0.0342706426578973, 0.024830999185464213, 0.025697868383888687, 0.02094492396073682, 0.0035230946128389663, 0.031666957906314304, 0.01925190445035696, 0.06429834477603436, 0.041017801500856876, 0.015256649548453944, 0.034266846254467964, 0.03570724039205483, 0.039551144665373225, 0.060258197997297556, 0.06407591421157122, 0.024981135236365453, 0.01819200730616493, 0.03779086876394493, 0.035022391605057886, 0.020315189180629592, 0.012817571455213641, 0.03207779050405536, 0.05322854467002409, 0.04428332930962954, 0.07549407758883067, 0.04989728717399495, 0.038265578648341556, 0.02727407300179558, 0.036196196119167974, 0.02219449878404183, 0.01656802025224481, 0.037697258072772195, 0.02759619732387364, 0.06477317001138415, 0.015188724800412143, 0.01242477516643703, 0.006544509270627583, 0.08170187233814172, 0.014859413096149052, 0.024845889636448452, 0.03560624384720411, 0.055225144140422344, 0.06260024303836481, 0.03624108121065157, 0.028931708607290472, 0.081322489838515, 0.009196510804550988, 0.006960844787369881, 0.04032680857926607, 0.02913048883367862, 0.03212474173467074, 0.07474055766527142, 0.022971826805067912, 0.05118360636489732, 0.016435102027441775, 0.05205320327409676, 0.05613155835973365, 0.018728526641747782, 0.013561731836359416, 0.02068943517016513, 0.028916190511413982, 0.09459475015423127, 0.018544624991981045, 0.11567103170922824, 0.019359832230423177, 0.03840359267113464, 0.027695226117170284, 0.08265874242143971, 0.02664355281740427, 0.020197417553780333, 0.07875554436551672, 0.02465154363640717, 0.01430059879619096, 0.041857166282300434, 0.02915934014267155, 0.06600874835359198, 0.03420962878902044, 0.0441196904118572, 0.018246324034407735, 0.056661083695611784, 0.03043643804267049, 0.05866889256451811, 0.022058225203571574, 0.03594914151887808, 0.024561756490064517, 0.04000673343294433, 0.048506388773343394, 0.057545408207390986, 0.03891460757170405, 0.05644408480397292, 0.028346811421215534, 0.04473972214119775, 0.021312971532877003, 0.0670001015865377, 0.05265035819528358, 0.026933316108105437, 0.07356359117797442, 0.021898333515439714, 0.008881170136321868, 0.06204848550260067, 0.04479162667744926, 0.06112289588366236, 0.019441819616726468, 0.053621681074478796, 0.0327992903600846, 0.060517744427280765, 0.014483757450112274, 0.020954224979504943, 0.027906732267833183, 0.031081168446689844, 0.07156753792826619, 0.030884949689997093, 0.04015787032299808, 0.04900124096976859, 0.04663801885076931, 0.029956313448825052, 0.04827857403350728, 0.0599307505679982, 0.02745480589302523, 0.046490851390574656, 0.048779858741909266, 0.07072892971336842, 0.03876276161255581, 0.04069426582594003, 0.11379606981894799, 0.07732433759208236, 0.04732614496190633, 0.034493487128721814, 0.14269200606005533, 0.10081908080194678, 0.18751407521111624, 0.19583486872059958, 0.14941204046564444, 0.11756741495004722, 0.10527185151087386, 0.13430211054427282, 0.12329008430242538, 0.13433529090668472, 0.18993932221617016, 0.2640972286462784, 0.1840240710547992, 0.1182625333645514, 0.27840834643159595, 0.12487989185111863, 0.117847758478352, 0.16941248439252377, 0.10660475213080645, 0.15085641081844056, 0.1156891757356269, 0.10724222221012626, 0.1250225334827389, 0.1294393486210278, 0.18259781758700097, 0.11230998991855554, 0.1135249679375972, 0.1610274471874748, 0.13290671684912272, 0.14705257064529828, 0.10264989720391375, 0.15469819466982568, 0.12650757522455283, 0.069519237482122, 0.15190804510244302, 0.09014833731842892, 0.15132777552519525, 0.13950563275388309, 0.13127355091273785, 0.13932511529752187, 0.11998200895530836, 0.18881208556038992, 0.06616424822381564, 0.14174949377775192, 0.1375383154622146, 0.10889676878494875, 0.13996065833738872, 0.12260833302778856, 0.17948541816856178, 0.08481663305844579, 0.12513730089579309, 0.09443264813827616, 0.09252453981233494, 0.22688540470387253, 0.11432276905647346, 0.16294164875788347, 0.11645764378564698, 0.08872603970978941, 0.21781991901142256, 0.1551466113222497, 0.11319509135293108, 0.08734870861683573, 0.21774335311991827, 0.1885715720376798, 0.14111384217228207, 0.21038861705788545, 0.13294901672218526, 0.12242400220462255, 0.0840009254004274, 0.15917269885540009, 0.14218626676925591, 0.09479298415992941, 0.16408650018274784, 0.24880375500236238, 0.09465214064610855, 0.08437924260007483, 0.12413237696247441, 0.11224181071988173, 0.10831818197454725, 0.14537635844733032, 0.11660366452166013, 0.17212517240217753, 0.15850344619580678, 0.16618709532277925, 0.10638164303132466, 0.13932633666055544, 0.08294882971261229, 0.17396229239446775, 0.09602124789463622, 0.10553918752287116, 0.1369050115879093, 0.09894610701927117, 0.16856766758220537, 0.11420572176575661, 0.09672845101782254, 0.12511798978916236, 0.15304322061794146, 0.1281589258994375, 0.07811696827411652, 0.1969931008560317, 0.11910160976861205, 0.1337360902024167, 0.11657026702804224, 0.1500613306249891, 0.20891429616936616, 0.11437075505299227, 0.06312464204217706, 0.08831452179167952, 0.22259103799504892, 0.19922747596033982, 0.1538350845554045, 0.2166870640856879, 0.06590369756200484, 0.10661184282175132, 0.10352266965700047, 0.22856891793864115, 0.26393093328390804, 0.06807909440249205, 0.15035353494541986, 0.1434444606836353, 0.10493555598493133, 0.11370365334940807, 0.15376222346510204, 0.15634528414479323, 0.09221709559538535, 0.09320279663162571, 0.0839125733556492, 0.16186330733554705, 0.09248295240104198, 0.20596566796302795, 0.09324637893587351, 0.1144547305469002, 0.0983999338267105, 0.10570978479725973, 0.0922182219635163, 0.1404132004827261, 0.07242274310972009, 0.15541826960231575, 0.1778013078229768, 0.11560008408767836, 0.11162997569356646, 0.13070837195430482, 0.1615711844393185, 0.10612450540065765, 0.16114724933036736, 0.09484206259782825, 0.06840563259486641, 0.09686470763491732, 0.1328475893075977, 0.3179996434066977, 0.1075588334351778, 0.12864064505057676, 0.09328988660126925, 0.09512353927961417, 0.03958776859300477, 0.08479407855442592, 0.0849942938823785, 0.08476604827280555, 0.2124397877071585, 0.17508709989488125, 0.1420799946146352, 0.10598619960780654, 0.12172854452260903, 0.09606901675994907, 0.10984655496265207, 0.17830182239413261, 0.10871153551020793, 0.10583050974777766, 0.13350016357643263, 0.11020763058747564, 0.2026133249912943, 0.11276019111807857, 0.17651395047349588, 0.19458046103162424, 0.23792645867381776, 0.10490345449319907], [0.07232312059828214, 0.054073449689894915, 0.02327061121884201, 0.020055995588856082, 0.05479674427104848, 0.036507192466940196, 0.006536014436278492, 0.036322264532957754, 0.0060183706726612786, 0.02013078541494906, 0.02675076643936336, 0.04203146496521575, 0.04681144900886076, 0.01452814381835716, 0.03567218388031636, 0.020255400067461387, 0.018988883921078274, 0.027315709606877396, 0.04114073169018541, 0.010890745740783001, 0.006857412301802209, 0.032563706394284964, 0.016560522440288748, 0.026640322990715504, 0.008752635247739298, 0.015270376311881202, 0.07499470974185637, 0.028706414625048637, 0.010840022703632712, 0.04962112342140504, 0.04281004657968879, 0.06411570350506476, 0.002013577476775806, 0.020680561628458754, 0.0333448494784534, 0.052495855771537335, 0.05414212421913232, 0.07434624739523445, 0.045574720549796305, 0.053809129766055515, 0.017234655463003686, 0.024091055051290562, 0.017445233717028583, 0.020296151184343865, 0.03060135937162808, 0.04213949113285967, 0.019834297842213085, 0.015121643132131015, 0.013483805482142737, 0.018738701274352412, 0.0348376400901803, 0.005222799389490059, 0.023552886875612394, 0.016943041468039155, 0.005521694489289075, 0.02935762843117118, 0.007620329087200973, 0.014545936702883669, 0.03133248085422175, 0.023523348549913083, 0.05750248408211129, 0.024272999127528498, 0.022572335920163562, 0.011844385997392237, 0.05559764629495995, 0.03701620229652949, 0.055051948076912334, 0.03406190832278558, 0.04372384326000299, 0.017225605502192463, 0.039786993259830136, 0.035588744429073164, 0.021196840264435326, 0.03817792210195746, 0.01199488082368459, 0.01848676970361599, 0.05191121642876949, 0.022298579270552312, 0.0755893506907991, 0.01787513993414385, 0.058768454007804394, 0.03047608145113502, 0.039102646588746987, 0.018739352667970315, 0.018544798018410802, 0.06879085728100368, 0.011618946978290166, 0.022469393676146865, 0.03698792774230242, 0.10143745690584183, 0.01294611906632781, 0.05782626063695975, 0.029583940215940987, 0.033731454983353615, 0.010114751041068562, 0.08270268434924738, 0.06719073600002698, 0.06459126834358488, 0.08194304403981992, 0.03763736039400101, 0.016833186648519974, 0.04504437079387052, 0.04606749303638935, 0.030997840953724723, 0.016434572770127227, 0.03412324110312121, 0.03545739022748811, 0.06683481045599494, 0.03570601563634617, 0.011890844441950321, 0.03394940382401858, 0.020943485466497283, 0.07789671580706324, 0.0032710037984153523, 0.023535139792199646, 0.014128067696999227, 0.011588043949034597, 0.022770714114553163, 0.03743391523935965, 0.00863964983727783, 0.0241809507632362, 0.027546759262414913, 0.029415490504886423, 0.017012024730710045, 0.03386148264897721, 0.005810230903859649, 0.04697443312034011, 0.10555551307541983, 0.049558243581226895, 0.10025828517973423, 0.05176964009712849, 0.036252955573477914, 0.05813384734626327, 0.05260527293596949, 0.02013536891900003, 0.05889964196830988, 0.024271236632817557, 0.044150143063494136, 0.05911104633871998, 0.050992948202682395, 0.02214098781613367, 0.021836167833368694, 0.02203944674693048, 0.029997147686247314, 0.04440229006909898, 0.03211208027122276, 0.06980413398040192, 0.12648730059819563, 0.01744815311394632, 0.03433285414108208, 0.022754239284300377, 0.02012037668776299, 0.049091866106859276, 0.03854923003486224, 0.043021267745643854, 0.05411878600716591, 0.033192284272185395, 0.023670110585434095, 0.03490415009270821, 0.04449762084654399, 0.02999578383085983, 0.0795652334179197, 0.01896510466134974, 0.03427608111607177, 0.035213490815034935, 0.01666678611322173, 0.07878081979496138, 0.012485138489864767, 0.01998966370177056, 0.012087687450860227, 0.017504391792629446, 0.024863818227978687, 0.018336016185847775, 0.048513364113335095, 0.027862717397511005, 0.002355857045456235, 0.05805016362241336, 0.041298762496028624, 0.025271846779755185, 0.06981627297188554, 0.021132515144667456, 0.015491524445159095, 0.019317028545109288, 0.029526020466749157, 0.014636209001764655, 0.0059765279625675505, 0.04481101920828223, 0.06060279879186835, 0.026181901339441538, 0.021563593531027436, 0.03068576573527285, 0.028794356156140566, 0.05070650803723505, 0.008746995773565556, 0.041186319065413306, 0.020093932481748716, 0.005236365849019161, 0.010418249576884722, 0.032002334017306566, 0.018035630429429666, 0.041115507150867155, 0.02699290674978069, 0.032028484756925275, 0.026849779965622083, 0.02223978590752397, 0.026216937495129447, 0.04404110587867243, 0.024342075688764453, 0.019215930220005766, 0.012405628604548318, 0.029956737533211708, 0.016856692797903503, 0.028385377655337964, 0.04301650103713785, 0.0744727331080607, 0.02966218887429152, 0.02759311338221388, 0.04872509078787906, 0.028203772846609354, 0.07085430262876408, 0.008208717335946858, 0.05167187337896653, 0.02103557963190334, 0.03823998091476304, 0.05770566460809537, 0.026114811189472675, 0.019634128315374255, 0.06278833294553415, 0.037438868544995785, 0.014932934061757155, 0.0510579077526927, 0.01226029742974788, 0.0030964918010535514, 0.028391959445018853, 0.03467223700135946, 0.01372704332295273, 0.02769402171751218, 0.035926919497017346, 0.0488919968317662, 0.0494355440938047, 0.007892720185087194, 0.04739466003541436, 0.07077631859907083, 0.009180258194516813, 0.028370695853871957, 0.017238092242873142, 0.06625758071563073, 0.04375403467565775, 0.01307974466388779, 0.07813613688839333, 0.058535451867750714, 0.024553320603445172, 0.0399914867510753, 0.05060593218409589, 0.03789509513548442, 0.009960744796054704, 0.01567881877001907, 0.036888586822897196, 0.08051383894469057, 0.07779683545231819, 0.04941714222409895, 0.029999050976974622, 0.06403959223202296, 0.030678841285407543, 0.06488648535949842, 0.04660754245040672, 0.015656321941475784, 0.04863800760358572, 0.028360349891175116, 0.026017488911747932, 0.04848836688324809, 0.04168909315818122, 0.07055883455489363, 0.05498456276421036, 0.057790515412177355, 0.06799665918307644, 0.054294536755021126, 0.0554641309593405, 0.015609888093812125, 0.017672922927886248, 0.05292475097147482, 0.025930565183183978, 0.06217448945556368, 0.00990085644714002, 0.01710600861614304, 0.011960356113766986, 0.029428467487118075, 0.019512651887323176, 0.1224908921867609, 0.06792989812259163, 0.009724453457498124, 0.03461869380303791, 0.05888076512409108, 0.02710250372599278, 0.03796863476080554, 0.03647808331464018, 0.08298521276031222, 0.026576728992430226, 0.05219459979395781, 0.074754623696208, 0.04703796774681125, 0.05242823975692902, 0.029511533744101013, 0.07955015636980534, 0.06612393645835773, 0.04190818193767752, 0.03298612158479435, 0.041283013698245795, 0.02140115903291319, 0.06362466806811945, 0.02481552180168884, 0.03556697702567492, 0.010061058565042913, 0.08904775351818119, 0.02947784448042512, 0.04955423343926668, 0.03431657608598471, 0.049816968983837535, 0.008841222235267716, 0.017323529979746257, 0.03616427104654057, 0.024610039345653992, 0.02200866670214704, 0.12941213936678, 0.045242662475045235, 0.008261634585713702, 0.05626141299892749, 0.008047001236783606, 0.0348918041480439, 0.026530140778049827, 0.043524072372487614, 0.03267983427005155, 0.01129501944940005, 0.013652580041837479, 0.034204102121293545, 0.010959778197242745, 0.05653091014495917, 0.030219754669815302, 0.0159705091001732, 0.042903820119265995, 0.04410072196541088, 0.0917266301278557, 0.06137822861117976, 0.11225650100303547, 0.04277076958013432, 0.07130867003330163, 0.04396125927035298, 0.030037004833242724, 0.030196769296058586, 0.06055137262280498, 0.013528913642013711, 0.03369757912254759, 0.20095630176365376, 0.1424340677580663, 0.13227861055306026, 0.13436860697610037, 0.11994899144130093, 0.08099845544035945, 0.06562710633235318, 0.11211043276957103, 0.08575425310326473, 0.07783124396311385, 0.09903432335704565, 0.18523391256374971, 0.10962493185486112, 0.07772765202181679, 0.10880479336317096, 0.07019968596952302, 0.10230925905385188, 0.18271354851978167, 0.1688914102103029, 0.08746177290699311, 0.052894759723650556, 0.20034420889403137, 0.15883334992187365, 0.17266528627702168, 0.13788468044783386, 0.17199956199952535, 0.1750824587153537, 0.12654957654220717, 0.12586730958095618, 0.0758321305204715, 0.12207523520503726, 0.17672151433570044, 0.11082842906138726, 0.10271175245621375, 0.09934372175484896, 0.15061151395950997, 0.14091987615185125, 0.12554282056433813, 0.1834156151328768, 0.1325401993734496, 0.1023891701229981, 0.09069654611604554, 0.09671876832310643, 0.13666736148297787, 0.06820567511022091, 0.1662609606449093, 0.07289401282157217, 0.14516261991645607, 0.1061695601258959, 0.07644681539386511, 0.1379814124000924, 0.10625923531396048, 0.13646077471120016, 0.11031567371849503, 0.06811579636165074, 0.08298343499856335, 0.07277433281498295, 0.09436162587787424, 0.16364151691751821, 0.06310076439487082, 0.1446171456149646, 0.15729018487036228, 0.13381914288869926, 0.07407028041779995, 0.22135378367134503, 0.22304299660027027, 0.1841297053865024, 0.1004734689901982, 0.09684015823794262, 0.14834143434252056, 0.13035471950258526, 0.08882683608680964, 0.07458378893456288, 0.1628404384745019, 0.11461362987756729, 0.08967942890844174, 0.21160919299083097, 0.12281838032816138, 0.10713419943515744, 0.14645867608487606, 0.12742901220917702, 0.08809023882661547, 0.07912897611302988, 0.20434139083538735, 0.10454081145248242, 0.1564078993563141, 0.11460759091590132, 0.14763955771923065, 0.11949775208319936, 0.13971038748111042, 0.10943172579365117, 0.19125521874853543, 0.14390122331678867, 0.09742002747952938, 0.13690250100834028, 0.1688895917364529, 0.17886599712073803, 0.14606383655752453, 0.18200135816420826, 0.17294250854424068, 0.16435509148452962, 0.20488630873816355, 0.16145385216389382, 0.10640564281493425, 0.12969109868364675, 0.15385207507227147, 0.2349521139902728, 0.11197366046586207, 0.0922688813880086, 0.08736691371138607, 0.2104605689112629, 0.11609137058258057, 0.17120834945568017, 0.11122092085757426, 0.0977408659777471, 0.13289324114365236, 0.11226504375892025, 0.11751974107963697, 0.14589978036071571, 0.11603049242070743, 0.2358702261533056, 0.12028899176844529, 0.14172377730054514, 0.13995864987373352, 0.09151293230908257, 0.15748214242713793, 0.12975473169769558, 0.23827677273324557, 0.23272733337112836, 0.1814666861402137, 0.10185655406011002, 0.1053597896492907, 0.17585113032587937, 0.18368838621037348, 0.07156837252633912, 0.08803252942327942, 0.13891304098069668, 0.17797746908451828, 0.12215695796268326, 0.10790733580610581, 0.06016275526157447, 0.09385844466409513, 0.13454563676246575, 0.06739043564136539, 0.15496529319456645, 0.09812544605561666, 0.1351119013769286, 0.2811170039432389, 0.14376814902893134, 0.09249040950089693, 0.16092587049518312, 0.05943474146936621, 0.1337884459644556, 0.05404464587835329, 0.08951788329120193, 0.14966866240969726, 0.09558149613440037, 0.13058824411460332, 0.15385687910020351, 0.13962810832474912, 0.21745741846305983, 0.0996445706114173, 0.10740023265991892, 0.13804884521024569, 0.08209123608789273, 0.1476845717323678, 0.22539863948311123, 0.1605409647205046, 0.1007650965558631, 0.11487680646990027, 0.0774589114423309, 0.13197584822773933, 0.09420052130839654, 0.18257875075297697, 0.07907955162227154, 0.07696953841618129], [0.022249709482171705, 0.08679499011486769, 0.04584837033014212, 0.02418453512447221, 0.04238627092646701, 0.014079716987907887, 0.009031134857130902, 0.030590614769607782, 0.04076861630060843, 0.06526596285402775, 0.04183196549170783, 0.03133801091462374, 0.05955856732491936, 0.0576055467660938, 0.03300310192363603, 0.04893123311921954, 0.016720325918868184, 0.091387416901333, 0.031274343973823955, 0.06447753908910922, 0.006988459890375712, 0.03416379374851074, 0.05441001323716981, 0.014558716909959912, 0.049444310766245635, 0.035742649742002995, 0.0587489189846175, 0.03537456824311188, 0.008965995495340653, 0.07208712611879621, 0.02903426917535918, 0.07281096692063979, 0.019830498046108654, 0.09038695094308682, 0.03871765938986625, 0.024568786112857715, 0.025500121227066432, 0.028159417012440305, 0.016434499827612723, 0.02168106660246849, 0.03341400237487895, 0.03964510480208056, 0.03642878435286028, 0.020808005771998848, 0.01310387930633234, 0.017190632110993777, 0.041525973339698145, 0.08114415726491384, 0.018611591309309006, 0.04058003106287547, 0.046599878397371085, 0.055460205634257624, 0.03708959264414651, 0.07750131988099643, 0.05365294457546302, 0.03947706560471228, 0.03501250874251127, 0.03424491260999015, 0.030264371739966527, 0.020271868112363985, 0.05269280056070004, 0.016883028438314795, 0.038273826241493225, 0.021302026763026203, 0.047591251986367364, 0.04660348141832011, 0.033957909260477336, 0.043430868802326064, 0.07502759154886007, 0.04992429965308734, 0.007850092918878155, 0.03925540178482022, 0.03166904440149665, 0.041109916022313495, 0.027877431429390396, 0.008258323334822697, 0.044912677324776135, 0.051912363152951, 0.015382309144894992, 0.002613159220865262, 0.06119902751275471, 0.043151770385780504, 0.03468941750803164, 0.045482100519750795, 0.022723998674856763, 0.032219974124538045, 0.024996889123160924, 0.06171014080090182, 0.03329879391406264, 0.03733245389802115, 0.13007388742906706, 0.020201007004028985, 0.02584397224044161, 0.027234083540471535, 0.026973083349210874, 0.025061253258692365, 0.01720428593190653, 0.03272615785577467, 0.024305996285485368, 0.05652147850819996, 0.008533190237358212, 0.004912968001527978, 0.0503222841902503, 0.02463342166239662, 0.009797859072153057, 0.043664193246513605, 0.028551844347800528, 0.03671454259061387, 0.09718104066061121, 0.021170720058892454, 0.08779548999986478, 0.050025160490934334, 0.03340894728899002, 0.02786720760299691, 0.08168540429323912, 0.0559847369523985, 0.0631210525919284, 0.02173092365930123, 0.052200255383338244, 0.009540900405097221, 0.02868806364546929, 0.03477992390149406, 0.05430437551279153, 0.059104016715926785, 0.006834385367775602, 0.054559731989034584, 0.02721267406429563, 0.02707213249855808, 0.06230383858616863, 0.046387812455317805, 0.025837191979267767, 0.03790248098916241, 0.03944583942315408, 0.08110181667975017, 0.023903253521504145, 0.017003103691552366, 0.046597856363015513, 0.03496378992817231, 0.017786379072016904, 0.041767877859196494, 0.07317810864853007, 0.007334694682088281, 0.012527391713644778, 0.037747652868607214, 0.025813078541042547, 0.05792903155088425, 0.05675064353272319, 0.04938125450696264, 0.03991729233946119, 0.027746837187026228, 0.07268395195049898, 0.03480922643627439, 0.023021851799317768, 0.03646544559991785, 0.03980887262150645, 0.11621497252157756, 0.0913501110460077, 0.07638048181044203, 0.03441649715283087, 0.10540628286876849, 0.022956393526068757, 0.004022094354565654, 0.02596588123456708, 0.04080157953181437, 0.04582580904077206, 0.02134666758190308, 0.059111270255276134, 0.04024884829829846, 0.04314346172447715, 0.013792043585064155, 0.015474074220817004, 0.02643216710670718, 0.07379230497671024, 0.034168221189507415, 0.01011037449019828, 0.03952287689649633, 0.011049533113172012, 0.013536606532787638, 0.050143042379724126, 0.01250407809857279, 0.030860854911484888, 0.06612226047686168, 0.056050300398575406, 0.049066217483154366, 0.046346018090844154, 0.016880928372432078, 0.04466150062424796, 0.03500042403382914, 0.013026488146611621, 0.03484413367030876, 0.03024547453969717, 0.044595044904521534, 0.003764815503797893, 0.04089197735967381, 0.03326677723920771, 0.02874123364953058, 0.017234385745333772, 0.035940205212682486, 0.016954356039475118, 0.016759613096447926, 0.02060736296698451, 0.030956786192421402, 0.06259182920413357, 0.029276031202503612, 0.07781476234751088, 0.010120065666602125, 0.021816436035026397, 0.0566121273940163, 0.06624030521405594, 0.02366179853145565, 0.005978529640872563, 0.05444354643779142, 0.016214929288253188, 0.014021033886820078, 0.0341371544636786, 0.022274530293153863, 0.04422041215002537, 0.055640960577875376, 0.04572141303547791, 0.08558902982622385, 0.028395504790491292, 0.01952881459146738, 0.03830916773793953, 0.023057352751493454, 0.014610546807359372, 0.050655180255749395, 0.04660929985610502, 0.017660870449617505, 0.019752396969124675, 0.05086308338546327, 0.06515828613191843, 0.08978601997452122, 0.018521593817110573, 0.03472351050004363, 0.06799813160406691, 0.08106949127146176, 0.12608370796910354, 0.028963053532476937, 0.03696286265871354, 0.005504888025045927, 0.027558908431923816, 0.053695254626550844, 0.0307369476317295, 0.08701908309012651, 0.021749973529949784, 0.06877797868634973, 0.038812420197895596, 0.054040527170790095, 0.05307595232235534, 0.055830913063670905, 0.026808180679966296, 0.053001544172210355, 0.03566074717257704, 0.030927731322922876, 0.02282374332259808, 0.015071762326572622, 0.02141599859377103, 0.015816999033891728, 0.04637648770585656, 0.06237804317580802, 0.03166152284081493, 0.028029954227219735, 0.03028236309598599, 0.06863145583442279, 0.055097145294504504, 0.06057142333260604, 0.04028905149815338, 0.030748109532786266, 0.016092056774401238, 0.034029806831053326, 0.02664852817542851, 0.005539089582660901, 0.016852930321225097, 0.009271093677463276, 0.07498740870505571, 0.020358389808929393, 0.008564498691287423, 0.004926568811892399, 0.0049028633428471425, 0.01943127009352403, 0.05853993019887379, 0.03405238508379885, 0.08698233363351651, 0.03409783335934792, 0.0225664682885898, 0.03884847754878657, 0.05876275431364775, 0.03835427674597927, 0.04777513836909618, 0.03933727042749524, 0.04204775319833841, 0.02228252513201109, 0.10495108086615801, 0.05827394447156361, 0.05301685531490615, 0.031163651163556745, 0.058030214692865095, 0.02743099270654576, 0.02720199222676456, 0.07207043415733747, 0.036690712440758944, 0.025178512591602545, 0.030221430651311363, 0.03719018206798604, 0.020031636181686605, 0.08573878250483956, 0.057950649676578384, 0.004551364815727408, 0.05750026527260031, 0.028552933396505456, 0.015971991699188948, 0.012441827599624438, 0.030966404426310743, 0.05662658018991351, 0.10155683157167264, 0.00475137319049931, 0.04477897539202656, 0.060889167711138725, 0.011264422609071647, 0.09290331163044487, 0.013051552382031721, 0.0939801467050399, 0.016747029664527093, 0.021572665544226766, 0.029136551544070244, 0.03443812884922538, 0.049540282759283266, 0.028970659910035983, 0.01146658109168389, 0.051308996243668456, 0.03154833980702928, 0.035105152521282434, 0.08113235754093953, 0.08185188964541469, 0.014691129626174058, 0.028943379409611225, 0.011485430794501943, 0.010233947591456984, 0.028645492358399288, 0.02685264507973833, 0.02181497379206121, 0.02649837007213916, 0.03146552121532815, 0.016594924165734222, 0.06578793270247323, 0.01112059354116874, 0.05752655850457294, 0.035259152829114876, 0.03872215807703989, 0.035229877435735295, 0.028623816557228565, 0.04837725677394441, 0.1346521396189928, 0.14874498625951155, 0.25640918261238504, 0.11257438787392207, 0.12369217058377606, 0.14356610844177858, 0.08020490873605013, 0.09844995542828526, 0.10246645526162215, 0.11778172345033713, 0.10145957714744977, 0.08885146012263638, 0.1938835241432701, 0.09432960581034422, 0.07075319412563529, 0.12076383057449545, 0.10864267777651548, 0.20421183135892662, 0.06681870882000242, 0.08702289645693131, 0.11386387582336154, 0.08444258384406567, 0.10673378234995262, 0.12980692461133003, 0.17997988020735128, 0.17945706897548266, 0.2689972828541483, 0.08810861355492047, 0.13417688012123108, 0.10321091674268246, 0.08290617021598987, 0.13561883488936083, 0.13281444965728692, 0.23200415074825287, 0.08029682987502643, 0.17840073922915117, 0.13276111680482114, 0.13138560418571743, 0.12345754674502782, 0.08701172777052436, 0.1210095009633473, 0.13264157250523567, 0.07860157119908504, 0.19314059615135193, 0.1076087329004492, 0.06809880584478378, 0.10560710887823786, 0.1596287829535348, 0.07346550215567861, 0.13322664611041546, 0.14252200589648314, 0.17556059520159448, 0.12111172904925686, 0.09005203962858234, 0.22474674374929496, 0.23585231282881328, 0.11921797852431025, 0.19034839740821294, 0.1062232797433223, 0.17430568539670535, 0.22969876016889298, 0.09913717569517237, 0.09871660611991372, 0.06737219662006412, 0.11485529690980911, 0.14532911883933203, 0.12204402259417943, 0.1951268445700407, 0.15605549540902885, 0.1893126137022461, 0.13663233550531523, 0.13613562073026383, 0.12911048983888967, 0.09920502919703722, 0.14922617615333625, 0.1319590477006776, 0.1473329006029027, 0.15504257833319052, 0.11101199313998222, 0.17991030322653906, 0.19258303035582813, 0.07045809924602509, 0.07418603849198137, 0.15994492598942348, 0.051337671133556535, 0.08854028396308422, 0.08706159330904484, 0.16222415225846426, 0.1598477190626519, 0.15388707390853337, 0.21928183627980097, 0.0925214999754514, 0.13116007271621907, 0.09500704838761262, 0.0997348293395979, 0.11323616307760988, 0.08065482495086533, 0.199353086362992, 0.19500187199030602, 0.1349896565079689, 0.10947409352021557, 0.08343742920884065, 0.183885324214186, 0.09939446260354348, 0.09126733655908278, 0.13577104386474403, 0.17627654464117118, 0.14828778936394624, 0.33619632412280354, 0.14755121245980263, 0.2887141534260341, 0.1589425533477749, 0.19311608746647835, 0.11015501019677945, 0.18449692853859492, 0.37485851666757036, 0.24722778956804956, 0.12128745604838644, 0.13931492370154175, 0.19380310417285987, 0.27866988096918377, 0.10822129395923444, 0.11535028820591313, 0.1644130383751222, 0.08855054341256618, 0.07748812237488371, 0.13120089338294097, 0.09491795673966408, 0.10960562074823038, 0.19342055970004626, 0.10918336162077528, 0.07864638165171657, 0.1299882155976125, 0.14432475130472863, 0.11964944537196841, 0.10201484270926033, 0.11392009923500673, 0.10160811524838209, 0.19338728434273175, 0.11630939745477267, 0.2694346936685698, 0.12338499778083392, 0.13397749939135142, 0.15642233858151094, 0.10389914124139718, 0.2454216650554112, 0.12065770769757883, 0.1486218457243272, 0.13077826106122561, 0.09653831872024707, 0.1489719155111483, 0.13585075815873487, 0.13018147594162396, 0.16577013555381978, 0.15640983996646746, 0.19954148839626992, 0.2224092177514519, 0.1537093791578497, 0.1152244471013546, 0.19399153334753855, 0.16295722792191164, 0.07718363657061543, 0.22813245707324573, 0.1084420553275517, 0.09697697803910289, 0.13349427389247076, 0.1013859153858253, 0.08381911872753076, 0.16284923228834355, 0.11460934153624944, 0.14947637915611267, 0.13247501929955824, 0.15946586669555732, 0.1244710066488811, 0.19641399835901602, 0.08523800330502646], [0.01038706156292132, 0.027703482192009687, 0.03186670504510403, 0.030220456953559603, 0.07162070793232747, 0.0334000211608197, 0.048937431536614895, 0.06393070093223027, 0.043951915843146186, 0.04369801143184304, 0.04622989021507757, 0.03316482735265579, 0.06868851384414093, 0.013548831189317363, 0.047887914281870635, 0.021359312081975595, 0.024331119044550827, 0.0016855554131325334, 0.07039327201034341, 0.017783123800264936, 0.06348405525620494, 0.0917735236829945, 0.039766545607043166, 0.035978966525622776, 0.03460097046835082, 0.009353300739478852, 0.038199051682438166, 0.010879785703894283, 0.007515083216795964, 0.0315765431150794, 0.009582162967750003, 0.04352972117651786, 0.04540391292955194, 0.015436517307534814, 0.005957101504983646, 0.010952336364425719, 0.013978840883022972, 0.016164838136839013, 0.05092308623716235, 0.006746339511924556, 0.02192440622353128, 0.030013629301850284, 0.01008887171545731, 0.04884064530155488, 0.02071094642659383, 0.03353599618588175, 0.02826631341927818, 0.024634120553465824, 0.057822148714746745, 0.07617363719535725, 0.04282347478770784, 0.07642096999500479, 0.03803909722981708, 0.03753987866054688, 0.04279054209057774, 0.029469617243324007, 0.07447429373860359, 0.025851351308769414, 0.0324907944138561, 0.05266144885016339, 0.06966013527874436, 0.025180236070549915, 0.016742028861439655, 0.02220841384093676, 0.07216215173580817, 0.0814914789849094, 0.017881297639438083, 0.02807623710084174, 0.0770628098398447, 0.010152760028306927, 0.02183451220792319, 0.03952992348266499, 0.0736835425985711, 0.02575241751037538, 0.03267178005938019, 0.056340567501527924, 0.018971567707402364, 0.005854180889270667, 0.038741326691316705, 0.008961648630377437, 0.061697187567395825, 0.0841808525313224, 0.04231661591412766, 0.0198121504592044, 0.016196515544184616, 0.07170846965163946, 0.04901552073923605, 0.04958854356248464, 0.06943373528442212, 0.06169424272541489, 0.049650073117975674, 0.004825392455261732, 0.03595281917867916, 0.014311083858566625, 0.026149367281634892, 0.041221093985119035, 0.009751498167003905, 0.020405598882851855, 0.041771921927907636, 0.0394015480498118, 0.05336996493861079, 0.04516692778893879, 0.05618277079026614, 0.029551706409880092, 0.02618466128062989, 0.023126064600156884, 0.021016280399635434, 0.032487863142575533, 0.03737674527136343, 0.016281076274546127, 0.007883460726588964, 0.05438164368804012, 0.05211108909653766, 0.011815811191419405, 0.03352647294689502, 0.07185791020414659, 0.057734970535550795, 0.05953112058341503, 0.06644698019538607, 0.0483688259763377, 0.031397331838629076, 0.02266974131842809, 0.011903000396809407, 0.02644312035824571, 0.03071844737444605, 0.049600051516400914, 0.05669464743030923, 0.03124431540657367, 0.016657997388392687, 0.023991941441116587, 0.029588293018085614, 0.06700297857501678, 0.044086608437022994, 0.04409498155915311, 0.04624249739572406, 0.042878721108926196, 0.02867578894698194, 0.020632523045475994, 0.040131560127649984, 0.046091462285923104, 0.03820147065977965, 0.07084712372826678, 0.014070788315231246, 0.02723664670650448, 0.030072482036692754, 0.009154352575673588, 0.0644234734188233, 0.04268040228635073, 0.02443463125798319, 0.045913160246397765, 0.030809537308024507, 0.0745457299053669, 0.027143326089052216, 0.056357459630817175, 0.03624733051817332, 0.12295353093317576, 0.03277251536824873, 0.05135625960039241, 0.053182163408824375, 0.03279340406879783, 0.01276524453091302, 0.03855820366048387, 0.008839572547003627, 0.03367017987849457, 0.0372500458200063, 0.05248750639813287, 0.02092591310585184, 0.04380570851000292, 0.027604029314326387, 0.03703595105824726, 0.06275579040603978, 0.04706487166030066, 0.03279577215601291, 0.03290369315072894, 0.03836289414071611, 0.06363730239016668, 0.047159608719604354, 0.038201368879526854, 0.037526793112712245, 0.08252956970993962, 0.06029042162533317, 0.053355603744941096, 0.03428997751325369, 0.03830114406134401, 0.038474000857344696, 0.005210704078698265, 0.025867398661960448, 0.05632562616041728, 0.044031850661018064, 0.05668275271143232, 0.026611968708623732, 0.08949317104582276, 0.010262547842493015, 0.020703107650790895, 0.020864371675997972, 0.05064480884798935, 0.015093192158799087, 0.037772724737546275, 0.038098536897450686, 0.02160983399621078, 0.02003844188792365, 0.012399559108806508, 0.01947954616376332, 0.025935917128143565, 0.024671779247000813, 0.05854657305670636, 0.05435242936281221, 0.07222963882876293, 0.05542608889351998, 0.0074835593279983315, 0.05465827902246799, 0.01594687233279858, 0.026994764239394238, 0.07322203022028718, 0.03994598758539983, 0.052111940657986064, 0.03878694120794535, 0.06096868522997413, 0.03271433777574982, 0.030566190901611532, 0.05382315169221588, 0.038998576280261786, 0.04035296271155987, 0.017393508992557014, 0.06722450668790511, 0.059743400263999186, 0.035271949999566586, 0.008381611451373568, 0.06074932164379528, 0.04859664071617382, 0.10503445246389934, 0.010482784194339598, 0.02133675248894308, 0.02568652667105198, 0.018212631378056746, 0.038700207469186614, 0.02377878305768328, 0.006590441426461828, 0.04461265967360564, 0.06397110090724059, 0.11812479075576578, 0.054206011683813164, 0.06397226798747267, 0.049086288549005985, 0.04526820931849735, 0.039353178681007454, 0.043195040563919714, 0.006989929342775473, 0.02024253334717027, 0.055213154426642826, 0.02502612889345203, 0.044098153710365295, 0.009916458511725068, 0.013238076569645532, 0.014288492035120726, 0.030463413202336857, 0.04054856060871056, 0.041934729620282135, 0.06298886718494551, 0.031579406532858095, 0.021410750125401785, 0.062366257022534094, 0.01838630241607981, 0.009087530447037091, 0.03777447196521929, 0.07994714006781578, 0.008349115561161722, 0.01642423528911812, 0.014561224096853818, 0.03457959661526339, 0.007405153758424733, 0.0296808757287051, 0.03791000254984413, 0.04401974220361028, 0.033587055946035047, 0.058366191307348866, 0.07969562070710318, 0.03449304947363479, 0.012419869358252202, 0.06331089311944586, 0.007838841111931418, 0.011674744609211172, 0.0030916417599655688, 0.04895398439839482, 0.0351607448953603, 0.03464505149583731, 0.043741943181625435, 0.06220480640019689, 0.009057976006131088, 0.020937575426484858, 0.01549601973965764, 0.02697586195011224, 0.07566172323588814, 0.0326297041028738, 0.030372306305382932, 0.07317466847598553, 0.03663327105875526, 0.03518576926684805, 0.059236202122909684, 0.015071275477696742, 0.054132142969008, 0.019022142315017324, 0.013304123472023224, 0.02969259742115225, 0.02399941041533436, 0.027415179447936158, 0.038134081954402585, 0.07657231044556413, 0.018484596695218767, 0.057259202136525085, 0.10353571788540908, 0.047673938263739855, 0.015454462862440517, 0.015263400971889496, 0.043630364883158884, 0.03659702371805906, 0.025521878452439393, 0.058761906144874435, 0.03132379560598305, 0.023329282445566993, 0.02269581741919475, 0.009706653787621429, 0.04491503523396594, 0.0203933275770396, 0.03742810697960002, 0.024418142857030034, 0.02002386186671044, 0.03152228066963809, 0.01705935933361096, 0.05018014467454382, 0.07574084720441274, 0.0452136618883482, 0.029490271849291663, 0.006644978678585696, 0.028489022183098962, 0.03746203033785735, 0.08370956924876996, 0.018190394089158093, 0.034901069543723545, 0.03726348759872573, 0.012788267224095762, 0.02439637714996934, 0.035471619106829166, 0.022613628168723414, 0.021279073619682874, 0.05480993159913591, 0.011167644007530595, 0.002722598225643326, 0.0801048723182508, 0.020113352153982435, 0.025377823771642785, 0.01391782786231488, 0.08026935599212136, 0.23836454802325793, 0.13431764899619988, 0.1191005241125822, 0.15766336555991853, 0.16840734332799911, 0.08579845965972968, 0.11419630369969777, 0.11786687959517751, 0.07714151311665773, 0.11416120986853327, 0.1307668752436127, 0.18007442727684975, 0.19332939173494065, 0.1036807954577463, 0.15003064727144583, 0.1480472215584346, 0.08164939443979945, 0.11689983148659978, 0.08177927282771894, 0.12339710284556661, 0.16119725736124174, 0.10461289222751345, 0.11688816068427903, 0.09785544340099607, 0.05681296358151095, 0.12917005164282663, 0.1298746695475919, 0.11562269287449972, 0.1612492874264717, 0.11306030715682677, 0.16464905999600887, 0.14594012605292456, 0.07950261142104864, 0.15890804305672646, 0.15675798271383556, 0.0861383310652205, 0.1328383476606437, 0.17934908691261495, 0.11756537934499127, 0.13314775962914738, 0.1383335313626698, 0.10926457547715732, 0.10690455604344606, 0.08932078243898493, 0.1390581660504852, 0.10594961299960103, 0.07001397093491894, 0.1450608532343592, 0.1356367753552539, 0.1531542425176927, 0.1219352941427912, 0.1294597725250891, 0.09958501559283052, 0.24388513607638224, 0.1592645046434232, 0.08571472843842846, 0.10216644100312676, 0.09538767939167363, 0.10686501102255923, 0.16820680908858776, 0.0915214547089168, 0.14990107422428472, 0.09946756118110248, 0.14908981775598867, 0.22132273390889168, 0.23040937632322311, 0.1442055327019521, 0.379187922924757, 0.12161932752600738, 0.093849270870643, 0.14850646762975625, 0.17026652927909577, 0.10216103986437831, 0.08624479320964643, 0.1339905544051102, 0.12540612289948122, 0.1187674312719277, 0.15660386026969977, 0.08630399539002351, 0.16864297139857495, 0.24551717564463615, 0.13825799684439385, 0.1383538195597274, 0.09640678470688206, 0.22182361488895758, 0.09687103158129112, 0.09823984705976077, 0.10983369672404868, 0.22873268915074213, 0.09071524654115949, 0.06278642626213175, 0.14730376430920192, 0.12018987137292113, 0.13255858767245496, 0.09026834302182708, 0.12147406674921513, 0.0810492370011551, 0.11284837352910213, 0.21821859904697963, 0.17006599503968442, 0.14899972187621252, 0.1330348514020443, 0.13570582307875156, 0.0458007405645081, 0.18427439619387898, 0.05782771270189967, 0.06134192020233188, 0.11588941141963005, 0.13136889865355833, 0.1281458708856787, 0.12791994586586952, 0.16004226862319879, 0.12759887666574546, 0.11315262184611388, 0.16955786730561936, 0.21576289939028875, 0.10680492674665791, 0.15588199400476047, 0.17933072575501033, 0.08217786465372358, 0.09385490271129779, 0.22586769717080252, 0.08558080598179783, 0.12573906646243163, 0.09886772943926708, 0.13657643779047898, 0.11376765955771719, 0.07862422069800751, 0.10171898787042924, 0.1368767981018339, 0.12889622205070086, 0.21109817469758646, 0.14421143595661434, 0.1835651235388858, 0.14388119296303817, 0.08169301067079816, 0.1279365699738264, 0.1453371119818517, 0.16056362779012748, 0.0858495058491826, 0.12241903532828603, 0.22761177644133568, 0.05657899792173079, 0.10101447853126697, 0.19753833088491643, 0.1165201368608645, 0.12129394284316472, 0.1276891761060272, 0.1416994043226753, 0.0548659107381744, 0.13882196801049368, 0.15961627076779092, 0.20315985780741486, 0.15181294163422926, 0.23802606761455536, 0.1155009094093527, 0.11027885640838317, 0.11010973155498505, 0.13404239448053495, 0.1807159007127796, 0.09341589733958244, 0.1808700774397169, 0.11293193511664867, 0.09936620840536696, 0.082193817012012, 0.11382998978453022, 0.17506070488265582, 0.18927164375782013, 0.15653323834495886, 0.15306490659713745, 0.11287114516432796, 0.17343429715505668, 0.30336540724549976, 0.11919151565858296, 0.21426048715199741], [0.03292362850957683, 0.02715697482095233, 0.02844352980277368, 0.03533467038401535, 0.07675879901008946, 0.03028591183413352, 0.03937440325639077, 0.06556111880178962, 0.04443572488214288, 0.05150623958823936, 0.02017561622363116, 0.04511034136105861, 0.01888759560616953, 0.053114594891667366, 0.05734488075332982, 0.022351963013144474, 0.005484434010993157, 0.008386444317043891, 0.03488080509539161, 0.053876606680985005, 0.04007922811433673, 0.03199551134769406, 0.03339029775400247, 0.05663813903395619, 0.034773376038564105, 0.03242759226954409, 0.06520705922905888, 0.02620505465061537, 0.032347019628754685, 0.04303977818095258, 0.02390635273020182, 0.06264129440699305, 0.027943303609000783, 0.016649006799395596, 0.0499728657970471, 0.03983669594994613, 0.06494775707168238, 0.045423936497952254, 0.006482640023542834, 0.0392226251507444, 0.031201730548803295, 0.020243568113073707, 0.030124196583139043, 0.026056270580738783, 0.026117857811706405, 0.06717201521886246, 0.025334422975512486, 0.030706878352378095, 0.02506122102827898, 0.11828648565070969, 0.03549392594556723, 0.020080947017829334, 0.058847360845123015, 0.03509796344275985, 0.02746725531427988, 0.11971834381776196, 0.017612022713625004, 0.030059915568147386, 0.014958216276551996, 0.028516031269516264, 0.019409022626600096, 0.018620888935402036, 0.011981551003243242, 0.04622149673689689, 0.0427577790272023, 0.009514105905379568, 0.027438665241269127, 0.02823264790432794, 0.014526381323646222, 0.024776507734454105, 0.029770486455942904, 0.03997836388381464, 0.005832661151154233, 0.04619752409468804, 0.028115308843553066, 0.04096349834331444, 0.009438350863222564, 0.04367390647530556, 0.04855635609211666, 0.08129570806132895, 0.02946805322010602, 0.039397269886519225, 0.0576627744095666, 0.02788828290067613, 0.05195650864126427, 0.082809207561825, 0.06742222500698906, 0.07891979055213076, 0.017626370336594324, 0.03205496797870312, 0.09935362158077103, 0.1006189536835466, 0.053932914909507544, 0.08212797875915255, 0.037089243198611906, 0.027297401035736715, 0.033006552274205854, 0.03679622124348368, 0.0196981905028224, 0.026788816986871616, 0.041429197282663414, 0.030471776146441698, 0.08225331096244709, 0.017161551796432053, 0.03235420870727726, 0.06093509774655104, 0.03354494267010263, 0.05728302550102983, 0.04781886995104807, 0.032278884534857104, 0.009439030246409987, 0.04726810646908624, 0.07242863279368196, 0.05179561102496726, 0.04578816731061254, 0.025289497171927775, 0.04740748434726681, 0.04876632536096232, 0.005124940645016197, 0.059301097212093215, 0.01413335433296327, 0.04121867161510246, 0.037325753364712, 0.07981099880167417, 0.03870472651241081, 0.012016524394441928, 0.050432223826646805, 0.0211077672761998, 0.028640254068055322, 0.06410279098365988, 0.09669154549815825, 0.007823716566365744, 0.02589519145632429, 0.034052232413419654, 0.03039512543806008, 0.02404615978178169, 0.0323110674507916, 0.03710541947345648, 0.05394967133179307, 0.06534837771739278, 0.011915476111296033, 0.01869947855759944, 0.023036837245204618, 0.023578952798353772, 0.04464031336829066, 0.05153834107997162, 0.021527658316439817, 0.031508655686463626, 0.046324766374060085, 0.049925568513572216, 0.06958554392414433, 0.03062801222716059, 0.004216520506556013, 0.06687026391071932, 0.0032916647656488097, 0.023364949638822248, 0.11737733014992305, 0.0819067084895713, 0.025113707408308983, 0.03553654473008854, 0.03062282143426793, 0.06843955256044865, 0.06059346893536193, 0.014328966648983104, 0.028359941073826382, 0.04991715128666588, 0.026328617573848793, 0.028619117702224424, 0.0536559674489711, 0.036918703599699905, 0.0938854164310864, 0.04060881451836654, 0.1409987083503178, 0.014199430921248027, 0.0575279291453106, 0.027682286454364657, 0.018628817617094943, 0.01986013984839831, 0.03577680040949157, 0.04553090754364218, 0.026765455026179552, 0.022039735124313405, 0.02100380214064249, 0.034591311522360356, 0.02133043872059456, 0.11808532715908118, 0.032221175131521056, 0.03401539135458214, 0.016637734636398296, 0.012771807660880898, 0.07422356826386281, 0.050947113162172694, 0.028534090479037592, 0.05879949698490756, 0.036674695621643744, 0.021669080281364064, 0.06603060396654264, 0.023053676788029925, 0.019063731422647834, 0.06525691798222916, 0.012008912079701466, 0.022735869645008018, 0.05318810737558773, 0.11700428516737052, 0.016553703163351332, 0.015792480170992867, 0.07104727798806769, 0.10212135235113756, 0.028779730333813598, 0.020475374335157018, 0.024324871433366622, 0.03194792229416115, 0.009967508942021855, 0.025781945658049414, 0.05516413027154548, 0.038140626424657445, 0.07756701564150197, 0.04156504338607192, 0.047540497566972456, 0.07260069570371083, 0.07256399374455214, 0.08309212952320065, 0.02859458526862519, 0.02704483164208276, 0.06357571855187416, 0.08146251911031348, 0.02713097505537527, 0.03912851573633296, 0.023368454272193567, 0.08291853990937982, 0.02218517062387296, 0.05703048833778926, 0.0311003167049161, 0.008576424792408943, 0.03967789500685675, 0.04153905888753278, 0.01843230878668172, 0.022458725409316163, 0.015145924507773348, 0.020637094675164138, 0.044179961284888644, 0.035898706010941944, 0.0403610338856067, 0.059768580698541234, 0.01849567886841084, 0.03784712949501617, 0.01160723461569952, 0.028805372172168324, 0.01929314580879041, 0.011030830991720515, 0.012022536214707153, 0.0067076519896675435, 0.02610578328104956, 0.1300915021981512, 0.039774006099573204, 0.033600711463285346, 0.008854091500065156, 0.06198834015854767, 0.024847441785303608, 0.015331768464030964, 0.02325937637527074, 0.06473842901842934, 0.022646364090698104, 0.03496055670880845, 0.020268036085846167, 0.02438069959836347, 0.04444017946454031, 0.06968356509293828, 0.036528780058558495, 0.03980909314538751, 0.04042644126872931, 0.010748419627946402, 0.031619406172207425, 0.015889527642035058, 0.034845846971230846, 0.009766064617516739, 0.07115684782287904, 0.009351691763315882, 0.02236813589531396, 0.009399604817320193, 0.023824143123679926, 0.038345832377672195, 0.04002139996737242, 0.052540265888507874, 0.03748196908938033, 0.07196240459701844, 0.03811695912320699, 0.04347246639164431, 0.022692579110818248, 0.055433064233511686, 0.10773774954889502, 0.05841435372297253, 0.10523201471992902, 0.0391240272271846, 0.023313835595867465, 0.04805545136332512, 0.03996309684589505, 0.015727698736424957, 0.0418199859559536, 0.027157946822366545, 0.021544547053053975, 0.009573095195394541, 0.01783837012148329, 0.021231496440512792, 0.00467884458235598, 0.009776408883876033, 0.05212665468986545, 0.02500953701590853, 0.04755921495546188, 0.07237488603485481, 0.012193801846089107, 0.007161574105599097, 0.05254476457568152, 0.06480844026165349, 0.0613352841298495, 0.030171059604201998, 0.028997784347406456, 0.0429502590559423, 0.02505820833279618, 0.06147117433803422, 0.018366087161536728, 0.024957003138427223, 0.024813786448378648, 0.052760647277214696, 0.07032236510089465, 0.037142372490572076, 0.046708549173282723, 0.015450150772397007, 0.0455611193153475, 0.05593037611937948, 0.034209153814507384, 0.047013391208435805, 0.10063096375337668, 0.05889674462378025, 0.019080738902890255, 0.015009384602308273, 0.01191225222178868, 0.03327997474532042, 0.010181713117552655, 0.022972052417961613, 0.050056013478232284, 0.08859540136264903, 0.007508847479974585, 0.012640971690416336, 0.008399135466398937, 0.024538136686065366, 0.028295100267444338, 0.02570556297100016, 0.05305827987779464, 0.025017989865903343, 0.022266375998567258, 0.004899185683046068, 0.06751648709177971, 0.1206771545112133, 0.13005712761410645, 0.12569528738302843, 0.16471201447503908, 0.11799367064876215, 0.12510091784809316, 0.15280964172312192, 0.1299444908010108, 0.17036294910524571, 0.0948173367817487, 0.11627856482352529, 0.18406679161957332, 0.18075159165476049, 0.18273463738816126, 0.19444395335657255, 0.0603740985638329, 0.12566169989960535, 0.09058489996407713, 0.13784095565123217, 0.1324763492281948, 0.08476133923977613, 0.1445630799446787, 0.11028550605156592, 0.09748665961836066, 0.15038805880716868, 0.13090193085372448, 0.17010036962372915, 0.06810669042170048, 0.12316064696226801, 0.11927968449890614, 0.22567803306238993, 0.10928829027605907, 0.07684271343584571, 0.0949636764292206, 0.1740720115069832, 0.1299440429678985, 0.1736975008887904, 0.1476728737886463, 0.13008487969636917, 0.16800228506326675, 0.09554496380899634, 0.17154606990516186, 0.229052333427327, 0.1199943447219474, 0.17029641196131706, 0.1705327999911138, 0.09920957538166217, 0.10449117661586829, 0.17217284627258778, 0.17081131147486822, 0.06697797455957957, 0.08848187566867896, 0.16977598917271408, 0.1196935772895813, 0.24084817618131638, 0.12005648495895521, 0.06273261164980275, 0.08041397216064589, 0.10484758391976357, 0.07655079410012279, 0.17347287865621702, 0.07226129248738289, 0.11119674465485982, 0.14250128343701363, 0.06294136973364012, 0.14758489493812832, 0.1401610840111971, 0.12977951179657662, 0.23637589759060315, 0.1458652564989669, 0.09210604655423335, 0.0613211298893605, 0.08243390984301056, 0.10758444134678159, 0.13446391400481972, 0.13655441254377365, 0.26245202549866264, 0.15451181467090333, 0.17615503259003162, 0.05862959860158818, 0.18444310714091572, 0.14119742411587918, 0.08696144154029233, 0.15116920189133712, 0.1372922243816512, 0.1356025364782129, 0.1651231117014374, 0.19357789840017045, 0.11037277922566448, 0.09743800865752356, 0.2146476592336382, 0.12143365320350442, 0.2112195510417223, 0.15558288219783986, 0.08074243060712304, 0.17274578767163412, 0.12239683366247586, 0.12226637851979051, 0.16871185627366814, 0.11109777353703976, 0.12206695707780973, 0.1622979361563921, 0.07151035778224468, 0.1514344276594264, 0.20296913518437318, 0.17069260855870588, 0.16760591204677308, 0.13579814455338887, 0.11793830219124045, 0.16657521735344613, 0.15506273082324437, 0.16563189082912036, 0.1596184963626521, 0.17185305271829876, 0.15364654681512288, 0.14872719507132257, 0.15846048135842594, 0.06990196515939065, 0.14795207737811975, 0.12785469793847629, 0.15221619499581202, 0.11656635866633483, 0.07899032426731926, 0.15638944320380688, 0.12467004811125142, 0.15680157180343354, 0.11070187549505915, 0.08650520137910332, 0.12534027786127158, 0.11760250878121171, 0.15978555168424333, 0.15048648709697382, 0.15254590873207363, 0.10994427757603781, 0.0764984722648348, 0.13906335005802767, 0.14789296340729507, 0.22279117868414947, 0.11644871426480156, 0.13080913440457412, 0.09718952913369451, 0.08246828442705528, 0.1150712746062449, 0.10710836760699749, 0.13462890657995427, 0.13525841065815516, 0.09093169242675815, 0.16444258178983415, 0.14910717468176568, 0.13004124989467009, 0.08741474364485059, 0.1004252183650221, 0.1342481127274888, 0.15666475200227328, 0.096799201864217, 0.2145121693611145, 0.23972981476358005, 0.14070494339934417, 0.18498603015073709, 0.10696660807090146, 0.12623058365924017, 0.15891064863119805, 0.06128201234553542, 0.1371251962014607, 0.13381790795496531, 0.09673919901251793, 0.18474326389176504, 0.15967124567500182, 0.09021127144140856, 0.1709068220640932, 0.10699785460851022, 0.21929202787578106, 0.06379297189414501, 0.17813438709293092, 0.057949475810996125], [0.09838598314672709, 0.04960543569177389, 0.031568580506635566, 0.02909084203253899, 0.025331973464095166, 0.06207940634340048, 0.025206968653947115, 0.05003016468669687, 0.015316140106213945, 0.02494349011353084, 0.04257528024858662, 0.023157173734424368, 0.03728970279917121, 0.06640955898910761, 0.04073603304901293, 0.03018791780674032, 0.04900650300883821, 0.044700760660426955, 0.04633224382996559, 0.017689138218494396, 0.01544176068689142, 0.0446061559154519, 0.059394524698810916, 0.020693771008934294, 0.061178461116339476, 0.02834728978840368, 0.018698630388826132, 0.019404579918565493, 0.0005725514004422751, 0.0062325252303188396, 0.021174272189715078, 0.05969470859106098, 0.006511688955859947, 0.02938671044207045, 0.01834105939737388, 0.04003934721861567, 0.03971901422898684, 0.02283448283560574, 0.06471201365015336, 0.02076468470373324, 0.06061016768217087, 0.022273380176297257, 0.03781423411731209, 0.03395003146891083, 0.054026433998452764, 0.01824351489943053, 0.007168134691060654, 0.0936072917122926, 0.05792063128735338, 0.04337640279637916, 0.017956525120618086, 0.016784981824457645, 0.021143585443496704, 0.03228020089279328, 0.025582357974989072, 0.0351641579265041, 0.032826866023242474, 0.021782365095402514, 0.0680937236174941, 0.037430264720959325, 0.03539417790515082, 0.03665240913895624, 0.022038293237398778, 0.014325555314176848, 0.01955218842652227, 0.07504855149558612, 0.01720727657500122, 0.05386500712484121, 0.028282333631068468, 0.024938034691980908, 0.03608750837988087, 0.08416510373353958, 0.07160333065049988, 0.03492409223690629, 0.04844104585104755, 0.03778289597747581, 0.000678548589348793, 0.020796323095315268, 0.0464742137119174, 0.02003663359209895, 0.023377407541764633, 0.054959233051964214, 0.062384496043835364, 0.030878924299031496, 0.02252805811752166, 0.09019970241934061, 0.046213174504893165, 0.07804532176149742, 0.032959672289767435, 0.02652338596193918, 0.017736355774104595, 0.048749009147286415, 0.02289275711934481, 0.013631240115500987, 0.022344514394977262, 0.038492755565260134, 0.04195960810674088, 0.05194445785933307, 0.04984202728207622, 0.02507675948020603, 0.02761182907436575, 0.010837217809499373, 0.03795810389731612, 0.02606624674185046, 0.037601679630045376, 0.016838562342205217, 0.011091943248175085, 0.06912714602159602, 0.04613730411178299, 0.04824366340679782, 0.01594501145050994, 0.059908576043588777, 0.03710866626352072, 0.0313738748830344, 0.09336787063096251, 0.016836504684761167, 0.04728258640638419, 0.035047812919531546, 0.019749847373792102, 0.04568734718486667, 0.028660525301737443, 0.01918194579359676, 0.04385012201964855, 0.016496660420671105, 0.017950275813096335, 0.005890884968851293, 0.028983653855643103, 0.015047759150287934, 0.041950970355953486, 0.08203067683747836, 0.08445149979421071, 0.027284632703023295, 0.037047245273632665, 0.047848124988377094, 0.012107719500948275, 0.0534010859472411, 0.02287936453441424, 0.10259235743433237, 0.043090783658304384, 0.05914979747363499, 0.018034259788691998, 0.04753247728305204, 0.05967546533793211, 0.029288288937615495, 0.0333743182543133, 0.0030377915245480835, 0.031044554697083573, 0.0249918306445969, 0.07996995241514274, 0.017395125602238944, 0.08013345221323626, 0.020507241732307842, 0.044591804899807484, 0.04693770401978067, 0.05053471654121365, 0.05166461644694209, 0.04857271557141628, 0.021517578678737794, 0.06339600176683494, 0.01833666588312813, 0.04965027667848127, 0.06926665282143013, 0.025126177185614194, 0.021506813720666935, 0.04835522813456399, 0.040349885555250306, 0.02889195324054786, 0.03149579405518515, 0.024508869774373512, 0.03709316513101969, 0.012523842127328473, 0.03267485721568976, 0.046902884995298724, 0.02537194256936865, 0.05050780923504915, 0.027461433483819877, 0.03805471710594637, 0.028055275457778146, 0.042043084877410104, 0.06378227139690093, 0.006917495729534754, 0.04456372033538563, 0.05618620757013559, 0.009142683469690382, 0.040791750952069245, 0.01440597528458706, 0.012862748316755252, 0.06370924745819398, 0.012314170565722244, 0.04118221053587539, 0.05626876831852964, 0.028776629428778375, 0.0856923232121127, 0.035269201932741065, 0.02589630425375487, 0.046752606452043564, 0.025181335297280123, 0.01363397206711982, 0.08585127682558127, 0.09221984366221087, 0.03743196105850594, 0.04092625694881592, 0.035768936188625436, 0.018623343535831997, 0.04939044865646532, 0.024144391296431422, 0.03359083877876401, 0.07257860938885383, 0.00556675303128681, 0.021213342236088853, 0.06046751247985022, 0.007881073131492096, 0.034302801825106144, 0.014501609706452914, 0.03436001589787858, 0.042854527942836285, 0.05674890309040036, 0.016193950681814125, 0.044702599490327496, 0.02419596165418625, 0.08318978428308453, 0.042970720279429636, 0.09091391480926957, 0.02739246209551181, 0.038233850350869555, 0.030463633726217916, 0.012619546947202511, 0.014281693114233869, 0.03934442897194198, 0.0344831530403878, 0.02807105309329927, 0.06078386586159468, 0.0251972605141678, 0.06302198647920575, 0.041153966515724144, 0.03187435892011438, 0.02162374566043062, 0.06060049177280494, 0.05468476224424584, 0.021668271128354327, 0.04578951759529965, 0.041585813342992745, 0.019069951892431294, 0.01574408196445022, 0.04327172180637717, 0.010447312079902207, 0.08680234543446984, 0.0271911034360528, 0.01657107874884137, 0.006129935400427452, 0.04673308160688196, 0.02774505433626473, 0.021949539160622016, 0.04382329274501119, 0.05275684408843517, 0.02878144702741078, 0.022219455302027718, 0.03489809077499168, 0.029425108738775765, 0.020919489075562785, 0.03452244700331773, 0.11915024715874876, 0.054427149639065774, 0.020025205366047363, 0.024061976433066384, 0.024676712196586386, 0.048713616760713715, 0.06309864736561265, 0.005931991044365401, 0.024395924227844392, 0.04380415466481021, 0.031568088568747044, 0.08015653597457068, 0.00589823562352519, 0.0766421588403838, 0.017541872370722036, 0.017018862667360475, 0.009673687163740396, 0.049442631392074485, 0.028486440357353007, 0.046641995065978596, 0.034411642234772444, 0.026297523706619228, 0.03669482097029686, 0.10084091605884687, 0.0196693476755172, 0.01874264356281076, 0.030241081025451422, 0.037449552078864405, 0.026795563321294527, 0.056565898803195784, 0.045045371633023024, 0.041998976708522866, 0.05147841286712459, 0.10571034119597503, 0.05296776669898203, 0.054040428783212385, 0.003594635528445776, 0.00371076340421236, 0.051860397548547814, 0.011664581002800592, 0.016074492895443524, 0.015073387417942286, 0.030349398963153362, 0.039017117249646356, 0.05570503803236144, 0.058957079957638464, 0.022812019933813384, 0.04630264613245215, 0.10055402466761214, 0.03024565435147711, 0.027653099270537496, 0.03653505990015609, 0.014623596732105528, 0.005144962517078966, 0.06499822650636945, 0.051734200213104486, 0.04919530877045222, 0.06532726849296264, 0.03391728536891086, 0.014519679093999522, 0.020800053341580287, 0.015655673940532973, 0.10692194011062384, 0.05568071933729308, 0.038602569672678194, 0.0774277870410255, 0.0568605322789933, 0.020516127148377042, 0.01828764342436833, 0.032948768232017756, 0.020380001149273345, 0.07995502464473248, 0.09285217044608933, 0.013094444276898034, 0.04199585884011217, 0.05772679418857608, 0.016503247299364636, 0.04195607972464391, 0.03466276465249913, 0.03126303618773818, 0.06694007159343787, 0.07324941589363984, 0.03517005778849125, 0.012315698117682976, 0.006147579007249857, 0.04167983115517667, 0.04638833153460707, 0.038441648307655535, 0.02069074474275112, 0.07632976810314826, 0.055281245415764194, 0.16013795563152858, 0.12358991535646574, 0.1190719577882971, 0.14086990883307798, 0.17959106607096537, 0.26404267443077906, 0.15410309231707028, 0.11955088137515954, 0.14518478087016515, 0.059577803792698045, 0.14125224974538597, 0.1851307073874133, 0.15756363448287758, 0.1429719967501504, 0.15515246029411042, 0.08013668882527522, 0.2176033170627696, 0.1307528702808278, 0.10382016655057669, 0.08638750948011875, 0.12868375916566166, 0.18138005078903266, 0.3102543561586312, 0.11328032213662352, 0.11499169601925782, 0.11075125927371637, 0.15705024131706782, 0.09300407408071415, 0.1310081080134426, 0.133909442328981, 0.1585067438759974, 0.2149328203605754, 0.18266877877925122, 0.09659301542810031, 0.10828505589493684, 0.12041319081825869, 0.10967633766787392, 0.09253695021782603, 0.12799951088215622, 0.10764990640538079, 0.14933753732059682, 0.09624690828578812, 0.14335554545479162, 0.1538088388208832, 0.1568430167223726, 0.09990392026624509, 0.20907669674072946, 0.16005347802170686, 0.10776996639158044, 0.14617990675781453, 0.1310286404831069, 0.10593148254390274, 0.08016347060246126, 0.12772275001874991, 0.18334466751132691, 0.13041285638298306, 0.10842459662152187, 0.13659830018877983, 0.11903197850499835, 0.08731083957744495, 0.12740653912935937, 0.13498440464692457, 0.1185083801725081, 0.11539501723434244, 0.15838472970894404, 0.14422945784670965, 0.06559073007000343, 0.15877576944019112, 0.15166108549705573, 0.08026717110936131, 0.16323780215212277, 0.1566699631512165, 0.1811424685376031, 0.050466981782977066, 0.15603942769978726, 0.16575317217835359, 0.08281003537454776, 0.1437474944229637, 0.13469899924738066, 0.11234432379049913, 0.09781435810561691, 0.18707635227058614, 0.08815579888011728, 0.097071803307959, 0.20350897764520987, 0.27935028874448364, 0.15481864820633615, 0.15404435832585606, 0.12067233691258089, 0.10677373449185065, 0.17469456738659314, 0.17467372279082025, 0.1005268357694149, 0.1343369601028306, 0.1352636218070984, 0.12265988811850548, 0.21353830876094954, 0.15167612183306897, 0.17155358807316848, 0.13166668053184236, 0.17295537356819424, 0.0745748458430171, 0.16346569492348603, 0.12055108270474843, 0.10358198718833071, 0.10372800113899366, 0.08181128610989877, 0.11986451383147921, 0.18312292226723262, 0.1565661065812622, 0.10446876460420233, 0.11050735307591301, 0.17653832345136575, 0.07553444363709007, 0.12681982346943446, 0.13427407347730227, 0.20446021588785307, 0.19281169665711267, 0.237368784312691, 0.11232083290815353, 0.14248748203473433, 0.2059560599071639, 0.1287437823734113, 0.11896857619285583, 0.08914625644683838, 0.1510766904268946, 0.05616175995341369, 0.18175852405173437, 0.2712958880833217, 0.25198535142200335, 0.1495623088308743, 0.11651838624051639, 0.16662039421498775, 0.18892743651356014, 0.11652848284159388, 0.1643620803952217, 0.10297583150012152, 0.28565244057348793, 0.12398105008261544, 0.18652183988264628, 0.10021297261118889, 0.10458718253565685, 0.17504583139504704, 0.12851601173835142, 0.07760040634976965, 0.09018714952149562, 0.08266652521810361, 0.1990997213870287, 0.16736861478005136, 0.06526857521384954, 0.13460270155753407, 0.1486231620822634, 0.09835853640522275, 0.16368997788855008, 0.08415286974715334, 0.1812246119869607, 0.13538167332964285, 0.20291357673704624, 0.17528349507067884, 0.12358941324055195, 0.13292925778244222, 0.12986664926367147, 0.12090415161635194, 0.13922710769942828, 0.15878459039543355, 0.27846208640507286, 0.1892219614237547, 0.15356272059891904, 0.36950161840234486, 0.11210588658494608, 0.12406442846570696, 0.15354862064123154, 0.09502858508910451, 0.11570505345506327, 0.28882589457290514, 0.08978469004588467], [0.018474386439525654, 0.02130919378916068, 0.014144584087521901, 0.0541016699613205, 0.027232176857069135, 0.02630621743654566, 0.07799762074968644, 0.01691514010807233, 0.012404970425580229, 0.03557767073756882, 0.02891627193561622, 0.013645234052091837, 0.017869379171835523, 0.0471500481611916, 0.04273389459454587, 0.03525092898468886, 0.03265052494992103, 0.08126617143196718, 0.01549813337624073, 0.032790181027459245, 0.03629587969875761, 0.04159518391160028, 0.042936688355569325, 0.017787544455911432, 0.024863860636417354, 0.04537900051634226, 0.02819420550284641, 0.010024655161292424, 0.04295926321563976, 0.010719772727627839, 0.033527826624257226, 0.032857322067554505, 0.02551657230859356, 0.0044633545829648414, 0.11684739430035863, 0.041565742277141125, 0.031936723073678355, 0.019690433151221702, 0.01369671365578792, 0.020799259455608468, 0.049284790576036484, 0.016461106882031475, 0.03275040191199098, 0.02864414207371218, 0.007813112760361816, 0.02134344114788941, 0.015952181869319508, 0.016864604516220943, 0.014192921225912869, 0.05457805243453809, 0.03579197245250855, 0.05027862724715045, 0.03921065579301544, 0.03152622974344662, 0.03173158158149038, 0.07990259424384151, 0.03570232101316963, 0.06619928777217865, 0.016490263531782796, 0.034467014084969244, 0.01353255398238876, 0.06421148550829717, 0.04473817508135523, 0.04333268478512764, 0.021107982711068222, 0.05239613487252167, 0.03950977099261113, 0.015519393574712532, 0.01251070823387376, 0.04399703163653612, 0.019064489685531174, 0.039662784031991444, 0.04036659448008452, 0.03433860811804022, 0.041195896587201526, 0.03953031364030071, 0.049561324130211554, 0.02361138677224517, 0.05961750487663916, 0.0250399252067187, 0.01418995687605015, 0.04940785647236875, 0.04097983068121331, 0.028725430568946258, 0.04809028056583234, 0.01764216154281582, 0.036575775393950086, 0.04146734791408692, 0.027591418741004806, 0.09330343694559165, 0.022811592456751635, 0.01681831824992384, 0.0628180867061019, 0.04867762387064951, 0.02178591552988759, 0.01724427200055548, 0.02518306386524013, 0.03612720946382199, 0.010281402634323707, 0.06677922486726727, 0.021084035513922572, 0.05570035274805767, 0.04526018564190183, 0.026390550857675926, 0.01924158393272332, 0.011025250041192132, 0.07160757827971663, 0.03703797648527792, 0.08102512865194253, 0.0430782239751092, 0.057696266898087094, 0.02515095898083278, 0.05240457245547857, 0.05109279463067651, 0.04912869020232132, 0.02731222363321909, 0.05881158847893987, 0.027436571960736598, 0.04213650897145271, 0.048969702662101815, 0.015956415927835872, 0.00870237615890801, 0.0175291142160339, 0.022440745927659527, 0.034600685483642986, 0.010799836467153259, 0.013592628080264797, 0.024861646915919015, 0.025123079673254063, 0.0487568496194269, 0.03737321349659136, 0.027029501839673946, 0.028376812847065072, 0.011150028390277709, 0.04702408152765461, 0.001777458846585692, 0.024430210602336695, 0.02422199534651424, 0.01348003706828292, 0.06110165095222848, 0.019333849428221583, 0.03058323570127998, 0.021600935009441206, 0.04621284880808421, 0.011856815910765102, 0.028533306771091053, 0.03644772905058094, 0.04527680974985872, 0.0182481492936079, 0.04472056370494621, 0.05366656955863748, 0.05061880399339965, 0.01978422704684947, 0.12801181950739451, 0.06252934291426625, 0.024516740780589834, 0.018973323416763117, 0.063057507787432, 0.06719613035342523, 0.04903102865708726, 0.06717974373272487, 0.02618199972701924, 0.06098154346857752, 0.05472585093230009, 0.03627754228987864, 0.055951953532972505, 0.07590208069554397, 0.022586463019251823, 0.028462549139346396, 0.0175953070034406, 0.020477610108043467, 0.045246333349496126, 0.03381049752767597, 0.025836269171642404, 0.053166187301810296, 0.02313071595770972, 0.06745351904204913, 0.11097501298146588, 0.09465585223266057, 0.02958833033751164, 0.023701202756326114, 0.028426839537652474, 0.06478533614426851, 0.05423065268301538, 0.06465507099138838, 0.048096302564122846, 0.010484366877270597, 0.053572592458554676, 0.015164099068247845, 0.012843675545549818, 0.08424799357141767, 0.04997812105076654, 0.050527839588799646, 0.025265351503289173, 0.02857970499566623, 0.006130760244559497, 0.08978069347462483, 0.018069368886894414, 0.10072743107697793, 0.027255033309172307, 0.031547155763421736, 0.05485522381163069, 0.033071226839508326, 0.06258593273482152, 0.03296132791521294, 0.03063238538535578, 0.02269123730781887, 0.01669108445223953, 0.03531576639839581, 0.06294397530811173, 0.004335401962245149, 0.04661447029294712, 0.03255325695499778, 0.020966559049806426, 0.016600350749545863, 0.014476453020636524, 0.0023584494733118583, 0.03791982095156397, 0.05124733437384878, 0.031659717937665324, 0.020708478255463496, 0.1062485348167164, 0.06288096654628005, 0.026697007806173394, 0.03680436366370746, 0.03851693855332477, 0.01168176914299173, 0.03511437720486096, 0.014608280500397086, 0.03989892439650638, 0.022696806383984428, 0.020760169053184133, 0.021370954046558057, 0.039647432177194526, 0.031417738779314926, 0.05531104328110814, 0.014338461050231541, 0.05368046934849449, 0.039753181859850883, 0.012435291611057307, 0.04947044454248888, 0.05984855962118932, 0.021078217076137662, 0.08963370921888522, 0.0568730851768383, 0.03408011681001101, 0.014372433602277721, 0.049788884419415674, 0.06353707598256213, 0.015651992888056805, 0.022192217210041623, 0.07600624939160687, 0.07542302140167781, 0.04169155963297401, 0.016891861267920052, 0.025019418182117597, 0.03640541899949312, 0.0072790598995717505, 0.01940050531577851, 0.020051306911877224, 0.03080118793462004, 0.03037460653909615, 0.03929373562069876, 0.022605417894997766, 0.09430577566048928, 0.04248463814812047, 0.04256331767620785, 0.059768227860331535, 0.027653160338689173, 0.033356045306261094, 0.013575681668174053, 0.014021974505989679, 0.061823815772575993, 0.007752410169424755, 0.06930579072130577, 0.017565519316121936, 0.05178415056850229, 0.03509359706991485, 0.051489126935069046, 0.07050736767372914, 0.011533650885602193, 0.01825776752749724, 0.016667118595380868, 0.03302053348826511, 0.03439853633088725, 0.0451385616324842, 0.005638595046808145, 0.017901248265323893, 0.04858859329085265, 0.04430754283177001, 0.03698053849594934, 0.02364748313889972, 0.01737877121195197, 0.013102337335502463, 0.055064816493541, 0.047473166537071974, 0.07604918030223676, 0.035417943594178984, 0.020080171791570525, 0.022165204730949233, 0.026919831920947348, 0.030101614937718426, 0.03681443990873439, 0.02785862922402365, 0.022589765788455094, 0.0272770500741899, 0.009865097651657249, 0.008487466306957816, 0.04664630376334701, 0.050149454535650353, 0.016398457743759667, 0.035347586298095326, 0.04252840704949839, 0.049477179002548964, 0.044018571730703115, 0.056793367490172386, 0.02147084966834102, 0.020335470592336993, 0.018810369839359607, 0.03392478996621711, 0.08886995020189456, 0.0598516333848238, 0.013278768314713878, 0.0495624063935663, 0.07809499052486249, 0.056579893587955406, 0.02922594514010208, 0.042257478194577355, 0.01662684414934899, 0.030311533316437687, 0.05395580868103674, 0.026250228119481887, 0.02065365092961916, 0.04393658434439983, 0.029271054148141826, 0.01211904255407197, 0.018449290821860944, 0.028130435085456287, 0.01693103479088417, 0.03098697421540107, 0.02385645665760551, 0.013953319484634059, 0.029632496181875467, 0.029954498367650167, 0.025461453212691203, 0.03161847997190697, 0.031420958427978415, 0.047744203957595995, 0.04612842548106398, 0.021785299759358168, 0.03220444245796118, 0.09374274765806538, 0.13012540180768284, 0.19249889201351575, 0.16053857627723897, 0.16260001994669437, 0.15552690305880137, 0.12596406867461546, 0.20311472165797437, 0.11168721690773964, 0.07114633731544018, 0.14007786847651005, 0.0988575310579368, 0.157627688188638, 0.09785049009535994, 0.10865113232284784, 0.16911971010267735, 0.13846279228372232, 0.1734906155616045, 0.13582550308534078, 0.24764443721090043, 0.08103485884410994, 0.2098443912608283, 0.1743381465119975, 0.1586449071764946, 0.14264346366482122, 0.10304166975298099, 0.14398680015334062, 0.2602933613317353, 0.27071517067296164, 0.081984672163214, 0.08387897908687592, 0.11799151290740285, 0.10799443934644971, 0.1610731397356306, 0.1158423482307366, 0.1826706515359027, 0.12827372045389243, 0.10430556336151701, 0.11614481200064931, 0.15717944795531885, 0.17110734273280415, 0.10258856442357812, 0.17565379877175602, 0.15187718532979488, 0.11677038057574204, 0.09196143038570881, 0.14272316438811167, 0.24696793779730797, 0.10819382686167955, 0.0905613683696304, 0.11060124875179358, 0.11460080556571484, 0.11820024384983949, 0.08525704978299992, 0.07974277889089924, 0.16870743222534657, 0.12621011904307775, 0.10484899527260236, 0.16593130119144917, 0.13762073032557964, 0.22044430247374944, 0.07480856044484036, 0.15771532777164662, 0.09918918540435177, 0.10079974933926548, 0.11572110759360449, 0.18590195743100985, 0.08910364444766726, 0.10989200323820114, 0.10589365421661309, 0.12642258192811692, 0.11662000364490918, 0.1210044798042093, 0.16900509196732724, 0.1370791101029941, 0.14092048683336802, 0.20686748171491282, 0.11064751805471522, 0.09150983818939754, 0.1837371050247124, 0.13808168630514825, 0.11245233978011779, 0.07887027785181999, 0.09469496299113546, 0.14745564758777618, 0.09341132401355676, 0.08198952368859734, 0.10456781036087445, 0.17050582143877233, 0.14053563534149102, 0.19096656995160238, 0.10560660676232406, 0.18831645644136838, 0.1430817972868681, 0.17426039996956075, 0.16005407513252326, 0.0872273322726999, 0.12176382834357874, 0.1112056402489543, 0.344646690679448, 0.1261289119720459, 0.10186528002044984, 0.1822293730718749, 0.1113331030522074, 0.22635635094983236, 0.12468014471232891, 0.13273115269839764, 0.09807866106608085, 0.09848669131419488, 0.2055109137935298, 0.09701569524726697, 0.07385933066585235, 0.16331720432000502, 0.11359788331070117, 0.08115348712142025, 0.14579278895897524, 0.1610706698681627, 0.13859334242131027, 0.12158188596367836, 0.1388237050601414, 0.14385817705520562, 0.16423424439770834, 0.12213173003068992, 0.0774308947314109, 0.07807914673217706, 0.09488337859511375, 0.11915087141096592, 0.08639386735324349, 0.11304893490991422, 0.13824947444455965, 0.15109628651823315, 0.06341930944472551, 0.09029073467744247, 0.16300939369414533, 0.1367826038705451, 0.165685182969485, 0.13909499693129743, 0.10864384485674755, 0.19629164492445333, 0.12894815712102822, 0.198141589228596, 0.05779875961265393, 0.13266325848443167, 0.21099828077214106, 0.1334506305200713, 0.1325462790472167, 0.14526107534766197, 0.15546100373779023, 0.09180691439126219, 0.12983310249234947, 0.10518303127693278, 0.1547766061765807, 0.16044903679617814, 0.11492693663707801, 0.22256865991013391, 0.11778261911656175, 0.06851391321314232, 0.11035086254456214, 0.17333118697362287, 0.1571730018726417, 0.14241694153419562, 0.13201717101037502, 0.11138367426714726, 0.12643167429736682, 0.12189836826707635, 0.1729082696671997, 0.12582348978945188, 0.11301248400871243, 0.15606309500123772, 0.07789235961224351, 0.16550603615386145, 0.07687305073652949, 0.13325050340167113, 0.1258437101330076, 0.09293588131134, 0.11523861491254397, 0.20157231656568392], [0.02848959554518972, 0.004970118461642414, 0.10748501561049904, 0.08534120848136288, 0.04891227485079851, 0.05960185107375894, 0.025423724969316806, 0.009440628196378904, 0.04532791022211313, 0.03583839103313429, 0.041250447410025766, 0.09980322566947766, 0.022066259058192372, 0.04171762555571539, 0.012916039608951126, 0.0337976291110473, 0.04061903325574739, 0.023712681872504096, 0.041852793124105246, 0.027125624806753228, 0.004468591176971261, 0.022168254745858054, 0.013344594693210508, 0.06209652578192098, 0.05958002260220902, 0.04189025164980974, 0.0807807474796261, 0.04267922842076846, 0.05120981477999261, 0.019468923698046377, 0.011750227389191943, 0.014338857993217451, 0.03058838578207152, 0.01448885494443987, 0.07908396888524294, 0.059458205210311074, 0.057126283911722045, 0.004502407665963152, 0.010038007882290652, 0.01876103864716632, 0.03694024030119181, 0.05091020424983331, 0.052329227927007844, 0.05195076484233141, 0.05668670178524085, 0.022402549495122263, 0.03774712021861758, 0.029744902293064764, 0.10757566110364028, 0.006149923769823674, 0.052132086362689734, 0.05020304523142321, 0.05136669546897922, 0.016063268229897534, 0.03678984979965857, 0.054400442500731776, 0.05633168547813382, 0.030275557389748946, 0.031586107066167254, 0.013380839489400387, 0.013693265849724412, 0.04274928716144391, 0.015780556614377668, 0.04215618309431842, 0.10961852648428508, 0.009592944889196327, 0.029365597824965204, 0.015652761328965425, 0.03673475954149451, 0.10093186010739633, 0.03890269249677658, 0.012584723681876702, 0.02731271048209497, 0.008044227724894881, 0.03521018634949412, 0.05781613689448152, 0.029111343968127455, 0.05589521782738822, 0.019918699116845216, 0.010766667979104179, 0.013884259886773569, 0.02803904659646962, 0.006699748753037835, 0.024476381517680626, 0.0868316310058747, 0.040440761750297885, 0.0727328471839428, 0.017717333044856787, 0.04058954751651202, 0.011167382771548415, 0.02956911761845861, 0.013710713529560183, 0.059324757728193483, 0.061936249025166035, 0.026029690667720776, 0.0415356322856886, 0.0242117732164583, 0.06869850187961545, 0.024589725703533207, 0.0038348750926421155, 0.012783480159539198, 0.04381099769047328, 0.026182288104402165, 0.010868588179749037, 0.054071037497903617, 0.0809766948223114, 0.029081820909466063, 0.060009182430803776, 0.060678876138159206, 0.03007300790133221, 0.06304087689412491, 0.04622532367440207, 0.05084894271567464, 0.01075956117295261, 0.03575055467497025, 0.07169744345758643, 0.04107478826439806, 0.044010317352201254, 0.03501385563452329, 0.037694995158485005, 0.07583246300263063, 0.02796164949956749, 0.039452061589275084, 0.006353957553593708, 0.008856613953996981, 0.015307139339191573, 0.03749783323811633, 0.03997721715963312, 0.008430068181561572, 0.023443184726472412, 0.015567510189222438, 0.016062937444075942, 0.04656519168721778, 0.027772180469972745, 0.012357629037329128, 0.009437479793892374, 0.030851477557527165, 0.03013030339830688, 0.022248038589688282, 0.035154275063957484, 0.06002042575606278, 0.024720811883785894, 0.06671528651246003, 0.022502350122002617, 0.06902657356113195, 0.011022143198975494, 0.022380995830254893, 0.01106197150823261, 0.08286746657852616, 0.011874653748236597, 0.03892471435080681, 0.06707980909517833, 0.026225186784618666, 0.01481849404184946, 0.020780616705971103, 0.020731663797050714, 0.020378464267456105, 0.009421630064025521, 0.012354008204835867, 0.041649107089532275, 0.05126711027696729, 0.032548724341073206, 0.021665977679991295, 0.0065824822106930825, 0.023047649700726782, 0.024598414344446998, 0.012179640820249915, 0.03956715130646314, 0.03493194627974715, 0.03853480777304087, 0.053589633865548034, 0.02950833105881299, 0.013724066250558411, 0.017941151213433062, 0.03722331832562174, 0.02164674290855016, 0.03454442475257175, 0.026141272358862416, 0.05539535125717521, 0.01995301093640072, 0.038546003600848575, 0.0342012624522405, 0.020483374263026884, 0.04359049077278801, 0.050602702357407124, 0.039408180729619095, 0.00979267167193549, 0.0616521667689085, 0.04906545752393348, 0.0349482345128698, 0.027783764759078622, 0.04086667139615331, 0.038556666778666634, 0.04163601475634745, 0.011370874575472303, 0.007160481664219073, 0.014217474863731434, 0.03749267297929951, 0.049291474145970175, 0.04488737814660583, 0.012381555030255445, 0.054984491518033404, 0.04774893334667597, 0.037625815120658705, 0.03375075251928397, 0.0556334661585944, 0.07444840762764215, 0.008415505971892603, 0.050233246825103245, 0.03447674088446157, 0.06061657305274691, 0.03725071417699967, 0.05851075319307191, 0.0477679492905736, 0.026052543727148856, 0.03543492054034557, 0.06212906153606517, 0.0351474388236446, 0.01086814543564937, 0.027801689957933765, 0.04708893929741212, 0.06080302769052131, 0.0313298956358007, 0.015328548815367478, 0.029452324778373753, 0.011392926115409603, 0.02622657099605671, 0.014604475615280015, 0.028250340704939196, 0.029449865088931153, 0.021009678253903985, 0.051299730847988806, 0.02856644642140184, 0.060231558712465424, 0.05827863993389266, 0.010129571094044616, 0.008201860739583415, 0.04928222571366599, 0.039542181217776876, 0.0434211114687579, 0.027113163511135747, 0.0036484446276777555, 0.0382801162611161, 0.04865699979875769, 0.046553320717066526, 0.01667741366795131, 0.02181774051859975, 0.015710955884839808, 0.03509911695229156, 0.016538744858865227, 0.01715295136507068, 0.01850156855237271, 0.008182555570134094, 0.004865725849023355, 0.06457557382860354, 0.03174990202699389, 0.004417642951011658, 0.08185757576887097, 0.042309633788785765, 0.05154343687796167, 0.015143936400168707, 0.03933349098744137, 0.06916529326034443, 0.03591707734657185, 0.027110902293186103, 0.04685388798160212, 0.017415027034335902, 0.02447243414020964, 0.014936513333980526, 0.021978604208145822, 0.020889346853696873, 0.019342517713084817, 0.038497942965477705, 0.02043089466834707, 0.039044336681919437, 0.010831504544642354, 0.018874962980459844, 0.01273104382146682, 0.0796618771606258, 0.02984155621379614, 0.14060756005346775, 0.05844602095229285, 0.024612553317898085, 0.02188354654104582, 0.03668263787403703, 0.06090275876756225, 0.03409564169123769, 0.06097125687769481, 0.022653811012527773, 0.018990624363401105, 0.006221347638139767, 0.04409088320764048, 0.04177587778706636, 0.030788251664489508, 0.05331503413617611, 0.008698654394330723, 0.03045968125973429, 0.0579340255686215, 0.019113639369606972, 0.05544186822537865, 0.021038651699200273, 0.03629109602687614, 0.025692457067114965, 0.03010129602625966, 0.016265434346028736, 0.015205674605177981, 0.012236430808635694, 0.005746471512663577, 0.03139015633080687, 0.0329935786846493, 0.1265282162598201, 0.03573812052075352, 0.00651043705875054, 0.032648886287850995, 0.02068732662259468, 0.039203497248568704, 0.04783990792930126, 0.06384061183780432, 0.08153844717890024, 0.037475892808288336, 0.04192866012454033, 0.03636873400370989, 0.07070459066224949, 0.03261472883501223, 0.021391230369252816, 0.029282813160015003, 0.032700794216777594, 0.025084920560142825, 0.05661939450406602, 0.044059745235634704, 0.058131106064787934, 0.006593515190096306, 0.040173954995615144, 0.03137260262987443, 0.021193305096988167, 0.05622101980926735, 0.024217444072876657, 0.017206085746043494, 0.02764809168209987, 0.05870330107531377, 0.04197803033249719, 0.010178229688400669, 0.01622758566268853, 0.007768532161467842, 0.04954710542889578, 0.04573451215401292, 0.028576566771204983, 0.009623099833593836, 0.03032951449443187, 0.02383400732651353, 0.032634833827614784, 0.012501352932304144, 0.18198318699640886, 0.06501844684992518, 0.21526473255029746, 0.1579225387956415, 0.10230015311390162, 0.10602553428283759, 0.07169090238000665, 0.09482866153120995, 0.1606279664805957, 0.10285219563437359, 0.10511221936238663, 0.1491932129221303, 0.08739813989294426, 0.08309077923851353, 0.12768221433673585, 0.14356825261243752, 0.141648744898183, 0.1370952728071383, 0.15794256914939198, 0.21362946315535478, 0.11631101236811706, 0.11856183516127722, 0.10240264582846846, 0.1500773983342307, 0.11494531136538301, 0.22244414873421192, 0.17865539342164993, 0.17484978905745915, 0.13244943852935517, 0.19862442117716583, 0.12056611904076167, 0.09265409250344549, 0.13636450416275434, 0.18322443110602243, 0.15616259537637234, 0.15010953375271388, 0.11802435400230543, 0.11511965415307454, 0.15509808249771595, 0.1098769601168377, 0.19514387579900877, 0.11540143617561885, 0.09102132011737142, 0.14834109507501125, 0.15818532183766365, 0.14103950187563896, 0.10133713550333466, 0.10145873576402664, 0.13204219538186276, 0.07439584830509764, 0.1090936389352594, 0.12799105633582386, 0.13128816655703954, 0.1390218644269875, 0.14541305362113885, 0.12921088588024887, 0.1133575937045472, 0.17698853143623897, 0.09750093599515301, 0.1544193574892623, 0.08936450723558664, 0.10674711556306907, 0.08948982586818081, 0.15373741622482026, 0.18573522780622753, 0.15555302665701934, 0.12508852779865265, 0.12788341354046548, 0.16061706920819624, 0.1521093121596745, 0.11312002502381802, 0.09910088085702487, 0.11127769388258457, 0.16583897971681186, 0.0910083261717643, 0.10705739605639662, 0.10889604953782898, 0.1440706399402448, 0.14503372540431364, 0.09566029440611601, 0.10448144642370087, 0.1308474037796259, 0.13873526480581078, 0.21893568842538766, 0.20621413391615662, 0.10040567655648504, 0.14660371973046235, 0.06646911400769438, 0.0945091936737299, 0.12949714623391628, 0.09468970434474093, 0.12303165745522295, 0.17850561360163347, 0.09836399861212287, 0.10444490731294666, 0.1279007297541414, 0.11073116106646401, 0.08950402082077094, 0.10716111691934721, 0.03138261780674968, 0.09164345530526978, 0.13012142559247358, 0.10767497148896966, 0.054746271443686316, 0.20026354465101445, 0.1750922839024237, 0.10701984592846461, 0.1550782692751714, 0.1422246175685099, 0.2203889882990292, 0.1531917383628232, 0.10989030690065452, 0.1611210307372468, 0.08240254795444862, 0.15310667721288546, 0.11742420334901128, 0.16289909104151384, 0.07711384924394743, 0.10751670998122011, 0.07425005827099085, 0.12233948388269969, 0.09395753791821854, 0.14808265465710843, 0.144104485266975, 0.08240131980606488, 0.06767750345170498, 0.13774263592703, 0.07887352124920913, 0.174070111608931, 0.14866820323680127, 0.13341344680104936, 0.10150768528027193, 0.18372096946196897, 0.10242344971214022, 0.2868168609482901, 0.10935870864029441, 0.12703029146151884, 0.08423702166016613, 0.1077057837641665, 0.1626933320824589, 0.16136770535792622, 0.14524092285760812, 0.14805243270737783, 0.17573717715484755, 0.11840037096823965, 0.09578979281442505, 0.14060846929039272, 0.05016540689393878, 0.20522382562713964, 0.08097303751856089, 0.10316523097987686, 0.14509465784898826, 0.08867099694907665, 0.09545218771589653, 0.1361322823379721, 0.1420072963727372, 0.12030742077955178, 0.09608102682977915, 0.09736879808562142, 0.21511944463210447, 0.11482537351548672, 0.10210204124450684, 0.11386029315846306, 0.14865664100008352, 0.10367987943547112, 0.1832777639584882, 0.12327603862753936, 0.08884075284004211, 0.0825428825670055, 0.1267094529633011, 0.12408050974564892, 0.12176219985953399, 0.11104121085788522, 0.10261025718812432, 0.11456113840852465, 0.12000609694847039]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.032235838273274045, 0.12398389992969376, 0.029016881715506315, 0.03384705020913056, 0.03711126844531723, 0.048594615289143155, 0.07773527197007622, 0.05079485668933817, 0.03877214914453881, 0.02998474406610642, 0.02103142869392676, 0.08153453203184263, 0.03469303749235613, 0.027896784944459796, 0.033564474300614426, 0.010047067172958382, 0.11443071040724005, 0.01212508830108813, 0.04845721873321703, 0.08471791978393282, 0.014873823483607598, 0.013812861039436288, 0.024369023707030073, 0.043450851658625264, 0.025453716217141067, 0.05431929310517652, 0.05906287035239594, 0.05391451982515199, 0.0807557977469904, 0.010246920332844769, 0.0363530666301293, 0.05210613579090152, 0.022698331391438842, 0.06004078859197242, 0.032080270549548526, 0.06687829097998993, 0.03983504032450063, 0.027486198315662996, 0.048392462743712325, 0.028036624226453047, 0.0546793068226959, 0.002968740408375327, 0.04394922884447234, 0.03384399001619645, 0.07640421696539436, 0.043010102451911995, 0.0323684477646436, 0.06511853076517582, 0.0769759573574577, 0.01547591305071754, 0.04193678218871355, 0.008825113813925003, 0.013688534764306886, 0.0172355256841651, 0.005238367103239787, 0.022125666495412588, 0.047318270563014915, 0.0013672297209268436, 0.025137281411194375, 0.010275166049333555, 0.021250281682504073, 0.018131397165624157, 0.052372365790818415, 0.03347045309575541, 0.05148398703230279, 0.03018673715580787, 0.043433735612779856, 0.01583842377710555, 0.04243116958865097, 0.020415846457970992, 0.027968967499743615, 0.05776874122342893, 0.00687857241635876, 0.050840739227299175, 0.048597326036542654, 0.0822571786120534, 0.07538759508835417, 0.026414338599092195, 0.07524306034403187, 0.03564009935195957, 0.04075575466932995, 0.04578389593267015, 0.05427532742864319, 0.02386131157566394, 0.03314931943480458, 0.039504037371703556, 0.07317897038800375, 0.02831769548356533, 0.05844315753451415, 0.044398442775543244, 0.04156221389504416, 0.010664825809986463, 0.06740718188562564, 0.05657575113166656, 0.012204385296042477, 0.097029232020889, 0.024871690930532556, 0.03892538610047527, 0.017522746164883887, 0.044421272086245675, 0.06345123451735292, 0.038202888797968626, 0.05724467470177582, 0.06204798338668687, 0.015479923192677754, 0.025313554631013955, 0.03085244446992874, 0.0034109268370749696, 0.021958628137196814, 0.01440027219775532, 0.05890480561980179, 0.020332624137933766, 0.04348040525136249, 0.03504621836223772, 0.008474504591764083, 0.050068271213344166, 0.0234119653302644, 0.052431527259094377, 0.07184364061270442, 0.038727053707199435, 0.02070720600230353, 0.03039913558002029, 0.017596725141629577, 0.0295088806721781, 0.06142077275684901, 0.05028756016067096, 0.051797558420470784, 0.02920090380523886, 0.06268622021057776, 0.05235302075743675, 0.026173292426392436, 0.024707748388339366, 0.011492779328753906, 0.000833717302677022, 0.04312759757574115, 0.03861621501190322, 0.016175565775483847, 0.04475814097427896, 0.04189203280423369, 0.021474593485306417, 0.06491989642381668, 0.012109295398529087, 0.028812364475535493, 0.07105925413114683, 0.026271549386105368, 0.033513268655432124, 0.01888739543833903, 0.011890017477396344, 0.042942343944949765, 0.01953216825079705, 0.015708826981218796, 0.05173688381910324, 0.06952946300485305, 0.04759597119742206, 0.012736880918964744, 0.027754068673987473, 0.012759979947337081, 0.09439575618931226, 0.01287191447668842, 0.013749060936139097, 0.020564527051257234, 0.018200962272073542, 0.002373998739390767, 0.02093422515983028, 0.015787737211212516, 0.0427503490687481, 0.021213481335767677, 0.020614494370030503, 0.03458544219444905, 0.017941677078072513, 0.0325581152657313, 0.022860268862651925, 0.06888902772750173, 0.01371877028473786, 0.0248153419899089, 0.0417983474742089, 0.054578578299177546, 0.10263068787753582, 0.014490551281986492, 0.05717669227825744, 0.02557974391882973, 0.03403884152482663, 0.038814082608691285, 0.049537884137992344, 0.029185755510947535, 0.05110385814415557, 0.044963716728878875, 0.06737267159457717, 0.0065664111087763944, 0.0020303226608250824, 0.012985970276141805, 0.019346168231485144, 0.04792414465919137, 0.03432136993589146, 0.010286138808753873, 0.08506580468799387, 0.052544031757861376, 0.04794713681829827, 0.05118985906509416, 0.025984183020357574, 0.04120930443917002, 0.03126052560816918, 0.06712850755346672, 0.02857069405061858, 0.04348680044391325, 0.05286118241825274, 0.04664804759834494, 0.018378779159060547, 0.03586009397570576, 0.06330208573490381, 0.003898465698252299, 0.05055891309997865, 0.027112764871812293, 0.019999953685328364, 0.03358612974573459, 0.021976651723629663, 0.033340221869626215, 0.09523084959281342, 0.04927200697628515, 0.03391856440742101, 0.06992886907288007, 0.014332193082996776, 0.044607916713825295, 0.03886232984119228, 0.007722084743103811, 0.014082851819694042, 0.03393382465999041, 0.019211684287126576, 0.01813168723934463, 0.05127242999151349, 0.014715051378256508, 0.05576825035469873, 0.013691866371248449, 0.04608705520097699, 0.05464332411065698, 0.01518622609520597, 0.025969587732106447, 0.013865545042790473, 0.048554656361894946, 0.03922762256115675, 0.03344341686793736, 0.04920865894694414, 0.04120493128097483, 0.025326543487608433, 0.032767063339373896, 0.033156705288482566, 0.04191528280664768, 0.023163562141624943, 0.004271122219506651, 0.0505825837941042, 0.08398109182183232, 0.007793553140280502, 0.016890163234035884, 0.017434731691277454, 0.11728473726127829, 0.022943092543365698, 0.04841261862644127, 0.03618460674104946, 0.014604328033913459, 0.0552193392733378, 0.017387753319261328, 0.08575620049876825, 0.013412836656373526, 0.02713493091453399, 0.015803380836067454, 0.03130147858921971, 0.10746200648801667, 0.04541587210925562, 0.05022998646433864, 0.018603060427787046, 0.050978054359023056, 0.03853545916665878, 0.046880774931716065, 0.029328814441604272, 0.04709382474954639, 0.04309079383632966, 0.013279087226172643, 0.013276112698284643, 0.06366652689341988, 0.025204008544928262, 0.06282333856714623, 0.014951948309317231, 0.01363484822546265, 0.023946277730699097, 0.023897367230217372, 0.05428115604445338, 0.03090470184438995, 0.044243098968373876, 0.032848005781748464, 0.030853095863546644, 0.016069196929622973, 0.04644628181787474, 0.028459455019661357, 0.02185138058848679, 0.04705037475962724, 0.0018267212310872439, 0.030221359405134405, 0.011912815405854156, 0.05890981320823942, 0.030009296855756214, 0.05725525984806674, 0.03483223555875676, 0.08011790019060884, 0.016061526091237153, 0.05840185510792902, 0.00811604641577495, 0.0898695679913674, 0.028248817393822328, 0.059617633798292706, 0.05630572133564523, 0.041533603465982845, 0.017859126507703747, 0.05036029911467007, 0.007954416829826576, 0.010551207665620106, 0.07144871287580047, 0.02130833883503718, 0.03920203839827861, 0.0031356969183044775, 0.0628350025841168, 0.04381841407822711, 0.030288690435034887, 0.015373603540605732, 0.037571634099419625, 0.012359689239279499, 0.028929869777389934, 0.004043767611230058, 0.032453407134328566, 0.04214356234297156, 0.018400064802595546, 0.017160645952182155, 0.013836559723131359, 0.02900720919881548, 0.05710502540958779, 0.04627883294597268, 0.0335380283982626, 0.0305416584680123, 0.019884444972766296, 0.03030839848465153, 0.026199594140052795, 0.03639223845675588, 0.04250839365912335, 0.03628099603312356, 0.0896596699686987, 0.07483077568135091, 0.0038597641812105265, 0.030259750916489532, 0.043417830751942735, 0.042518724354782274, 0.027574406171749746, 0.058240770894501886, 0.0020539617606638266, 0.15052846127322742, 0.2033385703606265, 0.12116236133234841, 0.17316457948514394, 0.16822111260678085, 0.14786245647285665, 0.14679936851773942, 0.12668400790010179, 0.10463799123785325, 0.09728870381202016, 0.09858493639954499, 0.1385310800479991, 0.07968725437032324, 0.12678148624088081, 0.10224612815571682, 0.12656416504510812, 0.1901340481958219, 0.1308821854846818, 0.11385643907955714, 0.20255422459117003, 0.10190430256937232, 0.10154584608972073, 0.13293638240013803, 0.1015466128342918, 0.10603315423109702, 0.14846914820373058, 0.15972719767263957, 0.11622140503355435, 0.22507454401680402, 0.10372831326510225, 0.14919972685830935, 0.1086250969341823, 0.13451556409043924, 0.1230581881744521, 0.09453907635595117, 0.14210607750075205, 0.11671722414238112, 0.09703856866274561, 0.10018254710095269, 0.14325495942362718, 0.13785451278090477, 0.20943310404462473, 0.08057617595685379, 0.08353306871971913, 0.22064751014113426, 0.257376529276371, 0.0908307603427342, 0.1269852231655802, 0.12137329072824546, 0.12204909803611891, 0.16781624433185371, 0.1657364937875952, 0.08036458838198866, 0.18178660183080605, 0.0837745661182063, 0.16076868107276304, 0.08806787431240082, 0.14675553515553474, 0.16305204640541757, 0.06001621883894716, 0.12246411719492503, 0.07554058437900883, 0.15957713286791528, 0.08594011741557292, 0.09780273480074746, 0.11875631686832223, 0.08483717231346027, 0.092015251783388, 0.15145304666033813, 0.13516655058733054, 0.09237117054206984, 0.12325451549674783, 0.10653653900538172, 0.13785443135670253, 0.11321447709841387, 0.13101105285542353, 0.12288214904921395, 0.132761985329645, 0.25369805523327416, 0.15173732569175108, 0.1629996770726783, 0.12430289281266076, 0.11980008014610835, 0.1692567877471447, 0.08423078592334475, 0.19858878451798642, 0.08525139758629457, 0.10661600224141564, 0.11467229601527963, 0.175868582246559, 0.18941310473850795, 0.10923654519553695, 0.14646010100841522, 0.1052359841497881, 0.07763098792306014, 0.2021873135651861, 0.10911121977759258, 0.19087736973805086, 0.10487115622631141, 0.09479542688599654, 0.16590329126587935, 0.1486633856381689, 0.2890742112483297, 0.13357037838016236, 0.09807347027318818, 0.11138786761356251, 0.08311516578708376, 0.09209402291370289, 0.07222744037530252, 0.13704381271132401, 0.11425420987818923, 0.12215808433081422, 0.09555186451013599, 0.15998960073505128, 0.1162878471825804, 0.08855632453092507, 0.11645256834370749, 0.12079196263636861, 0.13352114387920924, 0.12741246952542237, 0.12059259547718934, 0.09179630210357052, 0.25681695501719204, 0.1280990791107927, 0.15956652058022364, 0.15174675732851028, 0.155329897201487, 0.10676105267235211, 0.1516646138791527, 0.09083742355661732, 0.12055926583707333, 0.09195805806666613, 0.18403851027999604, 0.10001235694757529, 0.16979638593537466, 0.09694754318999392, 0.12896946312061378, 0.12344989287001745, 0.0948037796520761, 0.263659057872636, 0.10683615292821612, 0.09788076632789203, 0.13985510542988777, 0.2110031255121742, 0.12517582811415195, 0.12938421086541244, 0.0757415189540812, 0.14518912349428448, 0.1145758219063282, 0.09221619314381055, 0.10976935803358044, 0.2101884763687849, 0.16224376192050322, 0.11674714753670351, 0.19694160004811628, 0.08472026072974716, 0.10981580375560693, 0.11765900360686438, 0.10549836007079907, 0.15365463495254517, 0.12310945828046117, 0.059497695948396406, 0.06868172170860426, 0.1054689320070403, 0.08145913322057043, 0.09508844544844967, 0.08592121342995337, 0.12816858823810304, 0.1830891447940043, 0.13396889556731495, 0.12738441888775143, 0.13382553468857492, 0.16920185355203493, 0.09044369004134621, 0.18260419581617626, 0.0860870745299118], [0.06818754465452262, 0.04183600956041898, 0.0036129559739492834, 0.10772221788231816, 0.037198307524834356, 0.055247966665774584, 0.015466785058379173, 0.06293472687580756, 0.02850082190707326, 0.005265433865133673, 0.059817408078483174, 0.04197706342009561, 0.01609694222653551, 0.0314087651536933, 0.017129943938925862, 0.06958197482994624, 0.015300494785021459, 0.04398465176512088, 0.05002908242334213, 0.07475581791784082, 0.03876118062596236, 0.013320549956655927, 0.015198292144175087, 0.01921074790880084, 0.08302937860467605, 0.0437149001684572, 0.01378911909913378, 0.026491323485970497, 0.05882973250533853, 0.008498698606022766, 0.024884527116747837, 0.04503326317561524, 0.019564417323895862, 0.04846559864069734, 0.02433906977863184, 0.017971692074622427, 0.0274612451903522, 0.029710263080362762, 0.026770291284524968, 0.027715653413906693, 0.05112819380259939, 0.03106376063078642, 0.025602432433515787, 0.009710154180148882, 0.04828710321869169, 0.039397778787783215, 0.008917595592460461, 0.03538743665974055, 0.039158316994352, 0.06335826164909772, 0.06389572245201894, 0.03066705513213362, 0.04426822851278952, 0.018127403987039412, 0.01653660916989403, 0.036305989870535474, 0.01898553195808615, 0.04189056038324322, 0.03659593127667904, 0.06964858661272696, 0.03352679864370397, 0.01204555042620216, 0.01915909443050623, 0.04122174198606184, 0.037702927232853005, 0.04628737909453256, 0.025977587659976313, 0.008245742447408182, 0.03550357471353241, 0.04498976229556969, 0.019446323392912745, 0.06631995843989508, 0.051899796684405634, 0.038282128117446385, 0.010147271528174835, 0.016422569485647336, 0.011877205888075488, 0.024127246412847723, 0.04815652593970299, 0.015202285322759832, 0.029491326971245662, 0.00485536886013246, 0.02134983125142753, 0.04674063030896442, 0.026105245542047278, 0.017833742512656108, 0.024720727066908563, 0.042980409759495936, 0.03166644221970013, 0.027721884061715434, 0.025789278925263455, 0.027290527475997806, 0.06875492885176625, 0.06567412880914551, 0.026613485234390413, 0.026164054172113538, 0.009200770308130553, 0.023086908040568233, 0.010471304229992841, 0.014831423526629806, 0.007377164188905486, 0.051209658716938326, 0.031564332877418826, 0.04943285709513085, 0.019317328796855042, 0.08433299365320376, 0.01736704951950482, 0.0245329238407846, 0.04671445242794497, 0.051618957825537236, 0.006690448582438486, 0.01513544114173523, 0.02960007238600935, 0.04200062894129327, 0.04191032950101154, 0.0278955771521266, 0.04182268313265272, 0.07656275667250156, 0.01973019360697695, 0.00730968897031354, 0.015212100331804581, 0.025589586069275225, 0.042485896830580065, 0.03829699142702988, 0.0030853082716930658, 0.019110691134950945, 0.06719205235796315, 0.009496512340514787, 0.015346558831099952, 0.04258337517135909, 0.024265764247892157, 0.04377792589366436, 0.04040889096047197, 0.05889718567154237, 0.0609206585213542, 0.041256917241428576, 0.02964821444558246, 0.018984502281195352, 0.07056893115597111, 0.024365888875243918, 0.047395776225520034, 0.06313213306878294, 0.02059287454799882, 0.027543605770915747, 0.07089301305157797, 0.010446366371719964, 0.052330856411052604, 0.10267885029315948, 0.05919950016375099, 0.01972402911633253, 0.011820389606457735, 0.006668135382434619, 0.01431100073802684, 0.029166573325970342, 0.04319187180538263, 0.05484118152941976, 0.026320773709033216, 0.06734232750854321, 0.014057785887936396, 0.060779299320919175, 0.034297733168516836, 0.053424668431814225, 0.03876502113416791, 0.040471702947148254, 0.03337513928168586, 0.012922291460979198, 0.08004676936460392, 0.04581137999360051, 0.010253160310510014, 0.010633128894759076, 0.028941275951053416, 0.021395131945610046, 0.04229218526078122, 0.01644375334892954, 0.012553387238377971, 0.02452075431522514, 0.05545400043151208, 0.056525359728506634, 0.016737243493220637, 0.08246117338005986, 0.05761374346911907, 0.042075919186962504, 0.024130323569157293, 0.007949863011682672, 0.02372111945546099, 0.02211556480532246, 0.03250344569927879, 0.08149586232112986, 0.03300575838823404, 0.00549286904944373, 0.014447725544284497, 0.07097645928817135, 0.015017130079546144, 0.02472787712966757, 0.04824312397145799, 0.07427077394511018, 0.013794283598794468, 0.01290930769339736, 0.05777556050036635, 0.03639357517074261, 0.02148285464915846, 0.05205678254632013, 0.024317107296415737, 0.05046911916828581, 0.06939429882913828, 0.005393110406917653, 0.018559529013665657, 0.010924781057318407, 0.02781275686408792, 0.04167328329224672, 0.04587396127837045, 0.022963567337553416, 0.026631999062374234, 0.0562794314963477, 0.054148074971245866, 0.05621299613267183, 0.06478596039648567, 0.00640863984257781, 0.020049437547900846, 0.01662073563784361, 0.0244697691939239, 0.03520094470254012, 0.03905536287597247, 0.05785659793764353, 0.043643036524632146, 0.04031932094533529, 0.07333044654556684, 0.03554445305573089, 0.03667856666392513, 0.059968660319490094, 0.019231097174010107, 0.0484168221508818, 0.029896592189158713, 0.04537190643272229, 0.012222441112888711, 0.012738036973002766, 0.07083775994500943, 0.021331765256556015, 0.0076535306538322145, 0.009398818564867335, 0.021500930822055255, 0.017232592716546993, 0.023423537745007446, 0.03815070266968437, 0.04190574260428548, 0.03056994659293975, 0.06251795031130314, 0.06013009737112692, 0.007008553008615438, 0.024616112234070897, 0.0151893999427557, 0.0782090522614973, 0.03154997168374913, 0.029983841614531617, 0.014521889421822769, 0.07955493325633661, 0.03036671856950436, 0.05105566858713116, 0.01952828703049038, 0.07199010239647967, 0.025854387752977864, 0.0454819003519203, 0.015015277678945234, 0.028411382509927665, 0.020578886548589383, 0.04792479944548436, 0.037731510520513566, 0.057212810697300095, 0.03567167158637728, 0.026700605738109777, 0.05632149727482881, 0.03242632340905922, 0.01221937667911074, 0.05581496409805758, 0.039405263029038906, 0.030526710341551473, 0.01854928313488407, 0.009084888401308229, 0.016770211813439215, 0.01223446729792548, 0.04060637857764959, 0.019544816143544655, 0.03275681406791721, 0.08584867125110966, 0.043409416917711496, 0.020768811892984167, 0.04503681869911296, 0.024597581442711607, 0.017050485791904584, 0.05874323286116123, 0.03770514604236398, 0.03974883923573153, 0.0161475253158382, 0.035708458362413306, 0.025830118251698356, 0.014324585009100181, 0.04145036078989506, 0.055140999012759755, 0.06757974012621812, 0.025266238687826053, 0.013440928854314345, 0.022028132175494517, 0.048914775252342224, 0.031202996016613076, 0.028079812980390022, 0.03541666794834392, 0.03691014388043966, 0.02378078643232584, 0.02583051349834672, 0.02303646574728191, 0.05835243061717067, 0.021521256338538866, 0.014047675716158534, 0.015442914196423121, 0.07385665723787886, 0.06053020233022315, 0.021630388518263186, 0.015453752097008484, 0.06610586028546095, 0.055897602877978764, 0.12716643272766046, 0.0542534344962665, 0.04495814595637577, 0.04001266722168241, 0.06397557245301348, 0.02647523711701589, 0.07315663301518985, 0.026446872656898837, 0.04537705312083874, 0.03864372960690941, 0.08114588752921138, 0.0583539233942117, 0.029164011856274943, 0.0029473896678869744, 0.03137578835178699, 0.025166052992322614, 0.056711051014385054, 0.047291515927229605, 0.03207290844459619, 0.05265832758907761, 0.04789478784160955, 0.015234088259083884, 0.030818968944783722, 0.028921581472137144, 0.017776964398633157, 0.11571373870330197, 0.03718918462150863, 0.03973970954705562, 0.03928381883140121, 0.032416494829314094, 0.00876528738133077, 0.032002198310302835, 0.13808900091264928, 0.11786986514925957, 0.09279634737010513, 0.20796532423368522, 0.0973494326961892, 0.10241424877728734, 0.16505618100719793, 0.12150418013334274, 0.11413610407284328, 0.14254589032913956, 0.1287584930126156, 0.1476085079567773, 0.10917707160115242, 0.10923989715852908, 0.07161001422043357, 0.10767761099019221, 0.07041050679981709, 0.16303524587835583, 0.1475557450737272, 0.15319268831184932, 0.103575011848339, 0.11892383359372616, 0.125541178509593, 0.130165286096079, 0.2302695166851793, 0.11899917812219687, 0.1100772704396929, 0.0823875523305365, 0.16383951343595982, 0.10406832037759678, 0.1280945600675685, 0.09193534071424178, 0.1719689057873828, 0.11652841498809201, 0.07818999221282345, 0.12291163818112441, 0.2402507939508983, 0.12896916456520557, 0.12326216937175818, 0.14085268761430467, 0.18700795594070638, 0.10742849364344563, 0.06898907093065125, 0.09914475493133068, 0.13723080339176313, 0.13281704166105815, 0.16616509721747466, 0.17494785093835422, 0.09641179908066988, 0.1477687507867813, 0.14350271970033646, 0.13143228739500046, 0.14530864065246923, 0.10340032979313817, 0.0727466960836734, 0.13770305019404205, 0.11624379668916975, 0.15795783618731157, 0.10973933964435544, 0.12047305117760386, 0.17399171367287636, 0.08068776104067053, 0.10260887297668628, 0.10618475252496344, 0.16744889904345783, 0.1663592667984111, 0.10412742756307125, 0.1273392963090113, 0.14353585935064725, 0.08112181989209992, 0.17508673348597117, 0.1641675036932741, 0.08813950725431953, 0.20757859998515674, 0.0957100988764848, 0.1999382006802729, 0.051021229542259655, 0.11499375876571451, 0.0851141774494733, 0.2116216780351741, 0.1364407307867493, 0.12548476510814258, 0.08435026236942836, 0.15301396218793734, 0.10942977839814765, 0.13924802014870302, 0.13372310304215976, 0.12046591298920767, 0.09357542092246668, 0.07993092308087008, 0.09697737837476389, 0.17773170370076383, 0.11436137769903455, 0.1475131195038557, 0.157236105629376, 0.06965091398784093, 0.06171340455434152, 0.12079308900449957, 0.11027362490338938, 0.15412384191794054, 0.0882253690755793, 0.17566903866827488, 0.08695684785821609, 0.14255388347165926, 0.15847312925117357, 0.15200545558972017, 0.09460621061069624, 0.2997743827956063, 0.1895774866321257, 0.11299500494663205, 0.1747770229620593, 0.16322759698544229, 0.12245853963707175, 0.156425324135593, 0.14055892266333103, 0.09864175692200661, 0.13248198106884956, 0.1372843398047345, 0.1440984055932079, 0.06842319986649922, 0.13065524266234466, 0.09396036062389612, 0.14980496652424335, 0.1163309205855642, 0.11924159154295921, 0.22432807407208852, 0.13686503230461053, 0.07104370210851942, 0.1311670887683119, 0.14482887568218367, 0.12148264343185083, 0.08296516205051116, 0.09426002204418182, 0.11056810910148279, 0.17203795351088047, 0.06791305688342877, 0.05827608185687235, 0.11984809328402792, 0.16767451193715843, 0.14670227015657084, 0.14857380544500692, 0.11985927554113524, 0.11425358562597207, 0.13660722970962524, 0.2959079545523439, 0.11267189335610185, 0.13941442407667637, 0.17576749409948075, 0.1944986975618771, 0.06674413782145296, 0.20423365304512636, 0.0953502921121461, 0.1215720743473087, 0.13438041348542484, 0.2752585325922285, 0.16269760685307638, 0.1339783679161753, 0.17011643733297074, 0.10205712901162249, 0.11432964940156255, 0.16462900250085763, 0.11348361801356077, 0.060991762205958366, 0.11900386001382555, 0.16408065121088708, 0.23263334270034516, 0.13830795059246676, 0.15982840795602116, 0.11905085534921714, 0.19228678196668625, 0.1990358576710735, 0.15276841393538884, 0.11864855193666049, 0.12655561550387315, 0.1228360900921481, 0.1235772810344185], [0.008473725124661411, 0.019375733698585203, 0.01352274660686297, 0.061991807472492964, 0.053795810123639445, 0.024330101242022853, 0.015081711346283555, 0.08328281143414122, 0.02187653897064073, 0.05597764626145363, 0.019282185771901692, 0.024383697026808347, 0.031586666857557635, 0.03252492133261902, 0.01325999918792929, 0.06383833196014166, 0.05196386056819132, 0.017911117557170134, 0.05969006062618323, 0.03938817412459424, 0.03315460182992475, 0.04131935264116951, 0.01609946128779224, 0.046020416276795525, 0.08591297601482697, 0.06024198101035186, 0.0589646931205477, 0.043305472138204744, 0.010976781436641301, 0.004984063204444412, 0.058927746888782294, 0.027371408850220696, 0.04106678155117801, 0.016540291918707744, 0.008385491823511464, 0.04167762591636606, 0.11796359797673565, 0.01678010485401111, 0.04097400206540312, 0.020475859487695352, 0.011532741648677205, 0.024542350388531173, 0.025013998383656144, 0.04315116648961391, 0.031874372490814755, 0.007270647761678057, 0.06492358765431813, 0.009199651573518557, 0.023901319696701, 0.012545308430812188, 0.04486070154234767, 0.03410888330212661, 0.03365163551643491, 0.04396797676703759, 0.06368990242481232, 0.017524590083797063, 0.09902256434517247, 0.07681482564657927, 0.032240231787519794, 0.051136302296072245, 0.021881561826116273, 0.001485529014774199, 0.07670813280024699, 0.0355373182600098, 0.016530688951856325, 0.009814475546590984, 0.034894094203731844, 0.059744356998375485, 0.05381056826029505, 0.04158973188272544, 0.01899962004141084, 0.04254099387409432, 0.0211789557776813, 0.026674471961866533, 0.03737224319151469, 0.008609946966836495, 0.05259550203170095, 0.008078342769294977, 0.008222226119999374, 0.062093207745679786, 0.04129855215017285, 0.029012467845210006, 0.027625291209135736, 0.022049283808363334, 0.05274213005655578, 0.03164860014138477, 0.02975888689979911, 0.07002907512443406, 0.027025162608229687, 0.04153692150222404, 0.03185308345460466, 0.03999377002141305, 0.02955927207533802, 0.02309610558274601, 0.022503201683451022, 0.045384014890130074, 0.05128192948177457, 0.020706597017124295, 0.047252927640719075, 0.046955417176442485, 0.04895336693152785, 0.02205882570706308, 0.030253579640494924, 0.02646656204680247, 0.04011978075972625, 0.05068840133026242, 0.017499586068359867, 0.024883950361981988, 0.027044689149728844, 0.06049667591495173, 0.049790516296135526, 0.048728860049907646, 0.037138759291597774, 0.03031139082408377, 0.048772354144603014, 0.04225553758442402, 0.034153632686606476, 0.04655542417562433, 0.009450281205187951, 0.04444815903635962, 0.017168118319075023, 0.08749447829489197, 0.03330232908150979, 0.0041587114433891004, 0.009357628944729055, 0.03594603043581758, 0.0669479900971055, 0.038168968832386393, 0.03827749711594411, 0.01254824479110539, 0.028049418004229665, 0.012655652643713568, 0.05387994507327676, 0.030414931875254427, 0.054442718625068665, 0.0271694140641817, 0.014630723046138883, 0.03951554871829493, 0.03165103608210172, 0.01890973959650312, 0.0792352482676506, 0.0008150716904700467, 0.029442509769329002, 0.05685590806284121, 0.017486298656357185, 0.06095766582127128, 0.039976779504546096, 0.023204896798623458, 0.015534872654825449, 0.010454556289395052, 0.013676757092720695, 0.05135381008897509, 0.020078582323289344, 0.03629815618374518, 0.007539972729448761, 0.0047345688466780955, 0.04690565002549972, 0.018019140332138965, 0.051390912383794785, 0.035093675101442, 0.011487093205297632, 0.023326917751027004, 0.019787609543917433, 0.04790150873096926, 0.018078249213950973, 0.016307508606197577, 0.03647018177434802, 0.025564675352403095, 0.03548799554950424, 0.031091122555413415, 0.015099512712497796, 0.04733881660337959, 0.027193098329007626, 0.02190897294453212, 0.08289584291300603, 0.028046383256358758, 0.06676984751330954, 0.011965119429597897, 0.045674787501671484, 0.008443477729867612, 0.0639914773138506, 0.04923877233107175, 0.02476716261090977, 0.03911222071786012, 0.016783349947737794, 0.039574418416512866, 0.04101459542289376, 0.08559286354907922, 0.020551404183996574, 0.09451285097748041, 0.037657933575766425, 0.040368026188973866, 0.06512137382690396, 0.022142260069293634, 0.04381002060004643, 0.04689524808366384, 0.016118383933124796, 0.04240937843652708, 0.02489485272339412, 0.01971820728587253, 0.05974081504557814, 0.0063026407983021015, 0.018981431910235966, 0.015667795968641127, 0.02884744473599962, 0.034942602672215016, 0.007674135217842246, 0.08436004005904708, 0.013836960906961134, 0.02084406990824001, 0.027555534416543584, 0.02421697079470115, 0.013090963392252368, 0.024494579826880778, 0.027928348697189773, 0.02452811981285257, 0.0291261801363102, 0.0427128973283938, 0.06909114295350653, 0.06605134678206273, 0.021561220354799713, 0.011256507498079112, 0.05753324207450662, 0.005908107883962137, 0.03099840074511511, 0.02509809940654252, 0.005168087414598891, 0.04049234737509063, 0.026564625624035085, 0.02700225017698748, 0.02445088217167982, 0.007936853799037635, 0.03560452036825674, 0.0324444029746311, 0.04345694490309272, 0.019582400198227594, 0.01893270800688437, 0.07011853318129267, 0.026457562976117645, 0.03425679375816669, 0.03812141031292932, 0.012355457725269454, 0.04133395810744592, 0.015006197184058172, 0.046015659746314795, 0.061717367198850424, 0.024489723212484802, 0.04289129436282175, 0.02766557752953044, 0.02433020811128829, 0.02352922466317458, 0.07503276198570218, 0.0863075102014201, 0.025749689799600413, 0.055852202099881, 0.09113316304449524, 0.06994783412665129, 0.043978568698678694, 0.04950799127774579, 0.04632464763043182, 0.05481101046981556, 0.04498557234182954, 0.02882753312587738, 0.04043416978259172, 0.02706636325456202, 0.02756404663835253, 0.047832807060331106, 0.020162410235830715, 0.015855270105281045, 0.023676794155367782, 0.03617898168574486, 0.024849139819187776, 0.03444452404177614, 0.019642111279868653, 0.0581617962036814, 0.04646615610857095, 0.04908455828470843, 0.033011980554355044, 0.015817945590242743, 0.032495374525231976, 0.022779567300208976, 0.020845907041803002, 0.006490486008780343, 0.030617461007620608, 0.046352206330214224, 0.0331071891954967, 0.023357177020183632, 0.01620052907881992, 0.06065119869474854, 0.04530181037262082, 0.059289928525686264, 0.045258899818041494, 0.025615697793130363, 0.03455153240689209, 0.06642865296453238, 0.04823309522388237, 0.05570291421775307, 0.04427105461114219, 0.03278837951698473, 0.03846441315753119, 0.04153164249977895, 0.06433748946126018, 0.06839225866964885, 0.03293631711442556, 0.04477670908506427, 0.042325436869370084, 0.01215851039160043, 0.04685630017359342, 0.025607222890747443, 0.05404885279546891, 0.05586424609646201, 0.017105743987485766, 0.044525094729449065, 0.030140980146825314, 0.03465170792437025, 0.014720727323687502, 0.03431355321247663, 0.0285077293935631, 0.05888724513351917, 0.046691419556736946, 0.11871728753404957, 0.030724869708397558, 0.03136801573314837, 0.0212924899533391, 0.02945183284048523, 0.02636300742493144, 0.04037428906719599, 0.05898975820413657, 0.017094831448048353, 0.03773915082482355, 0.004095841781236231, 0.04636648949235678, 0.011590198297718806, 0.04386267831016864, 0.02702679787762463, 0.006620235899130681, 0.0053860421924452695, 0.013084250984580388, 0.021055348749671663, 0.061497969685920646, 0.03664036514237523, 0.016895408309730034, 0.016717287778322185, 0.029617846610822847, 0.022858321467148404, 0.05199593152584774, 0.018493663619405458, 0.032527540477791, 0.004485769139137119, 0.04269756582964744, 0.06333839414375168, 0.07775645583335843, 0.09764042922428676, 0.12320450746587344, 0.11753124903355326, 0.1610624324530363, 0.1918710164193596, 0.14136020466685295, 0.07446661950754267, 0.15501710612859043, 0.10601258783468179, 0.10567282499479395, 0.0755859376596553, 0.18362916367394583, 0.13573012820311955, 0.13265409826167993, 0.09145496506243944, 0.1410846108836787, 0.13826338441244193, 0.13536570061530384, 0.08794706793768065, 0.2022631059267691, 0.08272634486534766, 0.08910434333873646, 0.12870878353714943, 0.10019588031406913, 0.16665753722190857, 0.09479608506496463, 0.14019904126014027, 0.08738029442195382, 0.15701186337641307, 0.1370565148868731, 0.13543394766747952, 0.18007748068443366, 0.0983893418950694, 0.11259989400527307, 0.1464704961649009, 0.11775080939488751, 0.18197805727166788, 0.22762247015322956, 0.07244164709533964, 0.1424034522580249, 0.12324151476579052, 0.10574039351195097, 0.11781406242932592, 0.1068679422938398, 0.07052898579942328, 0.09192828395004783, 0.1676372875060354, 0.09988804254680872, 0.07586153822817973, 0.09283843689731189, 0.22055096817868097, 0.08385325582431895, 0.1465030387043953, 0.16661446381892475, 0.11154318427933113, 0.12103862368634768, 0.14784224970000132, 0.16619892897350447, 0.17843298321323736, 0.14959570632449218, 0.09273890938077654, 0.10763192522738661, 0.16259509378245898, 0.07430550815271479, 0.15400139348847525, 0.09590105220143284, 0.16456623801163264, 0.12112440408340522, 0.13976031408778258, 0.22087399155965873, 0.14866823037820204, 0.14553535277290003, 0.15804288376654896, 0.11249370327485458, 0.15459047045026506, 0.15519397306655133, 0.10343995623822723, 0.10466536334050552, 0.10006880427577666, 0.1606281836118017, 0.16314482928386756, 0.1364354653550046, 0.1757346394338778, 0.19636538811028004, 0.2792651190289429, 0.2396406281207289, 0.08419010096362659, 0.15901848141636166, 0.062176701479724476, 0.11047802000705685, 0.15375995715813978, 0.09249513210462672, 0.10674330898161445, 0.07979347224214248, 0.10338004838143076, 0.2148293573409319, 0.14990106065358433, 0.08002551764781986, 0.15635977765279158, 0.1341540813446045, 0.16563772623028072, 0.16080870106816292, 0.10649584726031337, 0.11443414379443441, 0.14454933282520088, 0.08973861073276826, 0.11792444650615964, 0.07727117437337126, 0.10585172075246062, 0.0783105136028358, 0.10756276215293578, 0.10011368936726026, 0.11182803328015975, 0.15804137741880758, 0.1697596229080643, 0.12570632036243165, 0.11347507525767599, 0.08136017567345075, 0.1801317906273263, 0.17849542200565338, 0.20837943415556634, 0.14393105171620846, 0.08183611370623112, 0.14005641319922038, 0.18952533443059238, 0.168069134333304, 0.17245910662625516, 0.07721940893679857, 0.11679282651415893, 0.14406473668558256, 0.13677001026059898, 0.08877853796418224, 0.1463085434266499, 0.1603690782295806, 0.1391946194427354, 0.04842614182936294, 0.13598212253834518, 0.12307292595505714, 0.0926865196919867, 0.13842089953167097, 0.14321797926511082, 0.18463194343660558, 0.15045801576759132, 0.14762860616402967, 0.1900063343346119, 0.16631441563367844, 0.08796252496540546, 0.11154356425894157, 0.06990800412105662, 0.10252379825604813, 0.2077483015933207, 0.18851889057883195, 0.08308940181242568, 0.17636476776429585, 0.07627556672585861, 0.1653523344014372, 0.1324295981654099, 0.07998240353273493, 0.18214182848376886, 0.11264012434652873, 0.07103296089917421, 0.0358190052876515, 0.07087251450866461, 0.12530218490532466, 0.13769433780440263, 0.1050041965874178, 0.07200133215103831, 0.1429743037692138, 0.12203784792550973, 0.23460421551551136, 0.10535288216280085, 0.11079057359269687, 0.08724805473216943, 0.08359686458217246, 0.16255753008382662, 0.128951278382114], [0.03534269406061087, 0.05383329239806958, 0.014226194038721067, 0.020004795032686422, 0.01763097250035831, 0.05781735825751509, 0.014800614644108074, 0.044784569913255315, 0.038349367545119355, 0.045267228835395405, 0.02734357364741819, 0.013543594595310944, 0.049680498628211875, 0.0354384692784931, 0.018908070400357246, 0.02433094771445862, 0.044104603185717545, 0.029345346947333643, 0.011013837082178464, 0.015230493719822593, 0.03306452291352408, 0.09179282121892486, 0.07078695802816323, 0.05944264640233346, 0.04254258843138814, 0.07355475665203162, 0.05545458057895303, 0.03604174119287303, 0.0744242382102779, 0.031237726831542592, 0.03915140611518707, 0.11437445985419409, 0.026260930313063518, 0.08351022244564124, 0.08481709446225848, 0.01418865324064557, 0.027059988418061818, 0.03631915684257235, 0.07115359085478953, 0.04572248512080737, 0.02849595681098955, 0.025761606570865427, 0.05645798798650503, 0.02720659099785345, 0.050923109985888004, 0.023613139088930826, 0.03673108188169343, 0.056515911128371954, 0.021910477595935975, 0.10305168492985622, 0.037941540857510905, 0.03223311056249908, 0.028717311897448132, 0.05613092053681612, 0.01464779837988317, 0.023776470949607234, 0.0552680886217526, 0.025521615520119667, 0.03066089403416429, 0.08700903398650033, 0.05499253894335457, 0.04475116902696235, 0.020481467579624484, 0.005182028340641409, 0.04215348931029439, 0.006669647667357432, 0.06447675198848758, 0.06191085145941802, 0.04164608421602419, 0.07175020634063653, 0.04340905050880142, 0.04278268465506179, 0.12549535025443348, 0.05565395452348249, 0.03126926853188446, 0.028941174170800617, 0.036379739841712375, 0.04379451268219522, 0.017520975188485215, 0.019464849095259393, 0.03919511055573821, 0.049316182998674254, 0.04421157423140747, 0.0445417968689331, 0.051144027417259555, 0.0125047260995156, 0.04169065718139921, 0.05708710529974528, 0.013191015077089625, 0.023520400315257053, 0.03159292973577976, 0.05622462961556656, 0.03359377344271966, 0.021201630721666982, 0.04683248698711395, 0.032676909784121175, 0.04160945689571755, 0.049707833411438127, 0.06441779408071723, 0.018748841980206113, 0.06551328208297491, 0.02950648544356227, 0.04145216569304466, 0.01980127184651792, 0.028808669852358953, 0.021984563441947103, 0.01452066466611411, 0.011160226771607995, 0.041729113153581104, 0.04125450844211238, 0.075763707049191, 0.045488407502749136, 0.01644229789131454, 0.050774517602154186, 0.013659102459704238, 0.009416518998997552, 0.059965254073696475, 0.020054343356085674, 0.012739817279257944, 0.02026278422480183, 0.0311694967427424, 0.005183893887858305, 0.01720313581504992, 0.0617388699735914, 0.05179921743859138, 0.07722698817295687, 0.01629326954883124, 0.01701941736973822, 0.010729847276317222, 0.011941779521293938, 0.08353035457964454, 0.0382862366469843, 0.02945757663941809, 0.06777098522122417, 0.030256711079605987, 0.036485679514173947, 0.05870984215289354, 0.01863459703911628, 0.08231311025364058, 0.050076892000756094, 0.032886149627821784, 0.036453048765127144, 0.05926404241472483, 0.028186215753001825, 0.025620852962934544, 0.021088384923392108, 0.032820732066673894, 0.0194660501022424, 0.06243801210075617, 0.10071375181100198, 0.016579726677654043, 0.04647632734850049, 0.054586805536278656, 0.04250645644164511, 0.003931565484630742, 0.05719672941735812, 0.05484099493228963, 0.0518498598997082, 0.0235769816541246, 0.010228851793466933, 0.02679537163515176, 0.06785743736795016, 0.021397350755121027, 0.05471976108050772, 0.07724418903567962, 0.04096101829782128, 0.025636776483484676, 0.08749520432736192, 0.046183207005794556, 0.09034526853689126, 0.03015399444848299, 0.04829154423038874, 0.034393908722060065, 0.03525558373491679, 0.01476531894877553, 0.04606388323009014, 0.030958848938878094, 0.09244686790875026, 0.03364469410319414, 0.047200710978358984, 0.01669918107134955, 0.020289467614410178, 0.010008721462717014, 0.007532390948784138, 0.029982993445758308, 0.06259547293718372, 0.013651762407140007, 0.05706100205757788, 0.045507847531033416, 0.007853522913397422, 0.027323943629328693, 0.027902544010430574, 0.043873887708676715, 0.012611893072192158, 0.02640932083262929, 0.031068724114447832, 0.05141672385590417, 0.03441998143015163, 0.04915467470086046, 0.03667377959936857, 0.1376358209443944, 0.11281759518065623, 0.04098834968837244, 0.022585579227390032, 0.07250977879656212, 0.00254183734484416, 0.03038046568898218, 0.024007507034444382, 0.03705572356869068, 0.029445308726280928, 0.014260653439643127, 0.026804279103609066, 0.007693435298278928, 0.06972807020481143, 0.023898871881621223, 0.06433850047843796, 0.009771732929428774, 0.033214920200407505, 0.06065808582518782, 0.08723461973880019, 0.0038672887104829507, 0.004960391238065702, 0.1130193236417004, 0.04145240318030119, 0.016844818435077156, 0.04514023422130516, 0.013843448549908186, 0.10347998980432749, 0.01222544871935887, 0.024081823582361852, 0.04346919924552951, 0.0299341999925673, 0.0462572385690042, 0.043241082557610104, 0.007189026784284839, 0.03467019800362842, 0.057150154773678095, 0.04513248195871711, 0.027865341631695628, 0.0033409474001798245, 0.01573750696011952, 0.021667343231716325, 0.045090290651257546, 0.025620059076962725, 0.0440292213378208, 0.05915191450289317, 0.06630883725093943, 0.019244639036644782, 0.016437878932005594, 0.034131271565066915, 0.037023072463593314, 0.028599236626178026, 0.01958674960769713, 0.0451709413235741, 0.04865078102531178, 0.07474454066583089, 0.030987282948834554, 0.04095080295311553, 0.07105432118156127, 0.014035844609939625, 0.04701035137155226, 0.012940870597958565, 0.04886266715558512, 0.03444567076595766, 0.020142172928899527, 0.012867113841431481, 0.0663042910663145, 0.0407689827095185, 0.01657205244659313, 0.02204888516903988, 0.031992172955402305, 0.02233896737119981, 0.0284036336400147, 0.04536212535042848, 0.02864326337086303, 0.04879097314551473, 0.02719565640602793, 0.04217016091570258, 0.0322260707616806, 0.05397465159850461, 0.040891916291522126, 0.03381929812686784, 0.02153977016652269, 0.026297584774770906, 0.019372193442125405, 0.03190037395272936, 0.014858008528660451, 0.026616506411560943, 0.033907979261130095, 0.030285107770136425, 0.049784287344664335, 0.011930483609570988, 0.08045166478093181, 0.066703351081482, 0.011022966770854379, 0.04481665104893701, 0.054136885928788354, 0.03558987079720412, 0.04231447174346872, 0.009199666840556477, 0.048738118660237105, 0.06337413936853409, 0.06520144774445466, 0.019210573186033537, 0.046231752793703756, 0.03527612638260637, 0.03656037604170186, 0.011758642071591956, 0.09099493867584638, 0.041265466782663546, 0.022750441184533492, 0.030417452632848705, 0.024779976744736944, 0.02392301755025983, 0.03818901614951236, 0.05977316080991711, 0.03203783496948225, 0.04928199161908456, 0.06709141882934741, 0.021751293280561055, 0.04074755796630468, 0.022332399152219296, 0.03773288116125124, 0.007576284530971731, 0.07025533941175256, 0.05248896185574787, 0.015995156884725605, 0.018987321594197835, 0.02327999535814992, 0.08751630676644188, 0.023738854664510915, 0.0641439984153424, 0.07354379152613026, 0.0840847719726818, 0.010791004485716777, 0.020723149878904223, 0.036511680976088555, 0.044312821834215095, 0.039260110817849636, 0.012009516824036837, 0.04978791411433901, 0.06528102633144174, 0.017962581045659523, 0.10611989814788103, 0.08105648375515427, 0.027794999602649893, 0.03004522528499365, 0.046465073845216205, 0.03316845412233046, 0.01861759804056159, 0.05018572223239711, 0.01859612071088382, 0.13604118222636835, 0.13408793775098665, 0.08055593525724751, 0.10584446721311126, 0.1306232429508652, 0.11580235537673746, 0.10259165175791297, 0.10914722963103227, 0.1099779193422624, 0.16895325189190252, 0.11975847237876483, 0.12910221171166214, 0.16075824520417623, 0.0739874652187739, 0.23448484763503075, 0.11343110618846756, 0.11290319915860891, 0.15851446560450963, 0.05377321830019355, 0.10548856881047998, 0.1521411354520491, 0.19841064193419047, 0.10304269434085914, 0.15728202887943812, 0.22047882633549826, 0.13838432649416582, 0.1313431414642504, 0.09245013166218996, 0.2103784933154072, 0.14549316146544047, 0.12162755137043339, 0.17882999405264854, 0.1255180947482586, 0.15795539346124443, 0.24056267578686985, 0.11072814158563103, 0.09314616609896932, 0.12914236741406576, 0.20030159689486027, 0.07812963652291469, 0.11434638207512242, 0.10689377412199974, 0.1399331505277327, 0.16620730209563458, 0.15021307819655963, 0.09707482957414218, 0.16605765798262187, 0.09772411973348685, 0.07399691042623349, 0.21589605510234833, 0.12540169885115965, 0.1648098999368293, 0.08320541772991419, 0.1127485745985593, 0.1476058480995042, 0.088151822664908, 0.09759814292192459, 0.1517048238643578, 0.09893681787486587, 0.15003877612096922, 0.13144159689545631, 0.09913114351885659, 0.11239541069205318, 0.14810477489871637, 0.10681937275720493, 0.0792174774355122, 0.12369245556848389, 0.16314845266086714, 0.13007384671696595, 0.15059457772544452, 0.2119238432496786, 0.09995873911040169, 0.15043726616672107, 0.10936796385794878, 0.19267189130187035, 0.06725706958345004, 0.16248386832220213, 0.126826283122812, 0.19391690806618758, 0.1500692016312054, 0.14341555509184087, 0.12611614194299492, 0.20958862427089894, 0.15712212531694345, 0.20364365327571118, 0.07538576304380383, 0.09271556099078485, 0.1307007045085941, 0.11312197241932154, 0.0882684967613646, 0.1322851244892393, 0.16495665349066257, 0.14784550666809082, 0.07436443891908441, 0.15965869277715683, 0.060135939557637484, 0.10357554110565356, 0.12596866914204188, 0.10215360990592412, 0.1750775868339198, 0.1353442453380142, 0.1377778383237975, 0.15945647577089922, 0.12031645886600018, 0.0911602908745408, 0.13361824224037783, 0.09971918910741806, 0.06149233105991568, 0.11784680852932589, 0.107458925939032, 0.14739552938512393, 0.17771483532020024, 0.08765538608921425, 0.106751261412033, 0.16675703759704316, 0.1298660792942558, 0.18968439660966396, 0.20668213308921882, 0.053644785191863775, 0.12959755584597588, 0.14434046617576055, 0.10270041413605213, 0.09422804947410311, 0.15045257391674177, 0.18613355500357492, 0.18152641079255513, 0.11233953333326749, 0.12909112444945745, 0.13303029164671898, 0.14932398019092424, 0.16246112382837705, 0.09560629658933197, 0.23499491597924912, 0.20219280969883713, 0.13718303452645028, 0.15012030888881, 0.14942603185772896, 0.23299660320792878, 0.17680847538369043, 0.16158402232187136, 0.23289143028003828, 0.1420464614140136, 0.12028946674295835, 0.1510967750634466, 0.1233651302754879, 0.11882475391030312, 0.11504969719265189, 0.049835092654185634, 0.11362730458910976, 0.11083408804344279, 0.18066159076988697, 0.1285785726670708, 0.10187916284693138, 0.15010999515652657, 0.09812850624855075, 0.15659240659858498, 0.1624489373394421, 0.1492786540516785, 0.14285930565425328, 0.11387497665626661, 0.0973600178424801, 0.15851077437400818, 0.10532395621495587, 0.157686232190047, 0.17959489300847054, 0.14648900660020964, 0.08842802034424883, 0.1553265723798956, 0.14290882513991424, 0.08855428214051894, 0.08650353218295745, 0.09818259906023741, 0.12405792810022831, 0.07092940966997828, 0.1262331892337118, 0.12071106769144535], [0.024230811212744032, 0.000704580638349788, 0.03881061868742108, 0.04249623431158917, 0.007007919850626162, 0.025408040632360747, 0.02253162381904466, 0.0234444213565439, 0.0165429755247065, 0.025128606340980957, 0.015198332856276205, 0.008548371610231698, 0.03457602073571511, 0.0314421015791595, 0.020640429674780796, 0.0014002535962000756, 0.03282422652201993, 0.008728598144703677, 0.019055305714053766, 0.03978905261361173, 0.030986590843115534, 0.06000578975571053, 0.02481382037512958, 0.00944634061306715, 0.014828080045325416, 0.004528468923776278, 0.052964855783752034, 0.021840615630415932, 0.06050090318811791, 0.05467210078079786, 0.06361216266772576, 0.040529999283275435, 0.027155592305851833, 0.07102637910949332, 0.041790663065122705, 0.03528135110224996, 0.0295062174222299, 0.014022887983758534, 0.05293981105621372, 0.007246949926151761, 0.013478469652389842, 0.03194344735571316, 0.013109388162514992, 0.021496829077867523, 0.03431588737294078, 0.07098633875804287, 0.02999798906967044, 0.02670745724546058, 0.02772223181091249, 0.041998019974146567, 0.03370394038834742, 0.0288956987538508, 0.05903375441474574, 0.003648882282764784, 0.027714866313285062, 0.00911040895152837, 0.0661594509812338, 0.04309265302228076, 0.007239972041653735, 0.04812622256577015, 0.007091996700702501, 0.03541636260758553, 0.053455613021339686, 0.027682042181757942, 0.036646845151803324, 0.026678627988855754, 0.041072742481316836, 0.06444127139236246, 0.049018153455108404, 0.023362406828839864, 0.02403253479860723, 0.059261755751711984, 0.03795969506193485, 0.06773805591676917, 0.026687957845362167, 0.0647518572264484, 0.028519444300660064, 0.012039871936264848, 0.044724818119513135, 0.01476926462990897, 0.036362019899700365, 0.049078807700425386, 0.028297062929985777, 0.03127233551016875, 0.019932330885369862, 0.028867983991014104, 0.023621905761371766, 0.012273413511658353, 0.01833047085840787, 0.024145746670131172, 0.0435003813223115, 0.03997324772977403, 0.034504591354302, 0.037425101069467406, 0.03202662896364927, 0.032220499989177497, 0.04850421067593353, 0.01319609475987298, 0.048918011864381175, 0.0138627825570958, 0.017248889431357384, 0.005444966597549085, 0.05064879184854882, 0.016201233058901768, 0.032803483706499846, 0.009750576207547315, 0.029617164683129107, 0.03150931725810681, 0.025194607442244887, 0.03703071955325348, 0.013662385721025723, 0.06719724315085582, 0.052117070382727046, 0.011916929024404712, 0.04334461682343057, 0.06117719225585461, 0.014386540345315422, 0.020831284612151127, 0.021108713832550814, 0.012982572512035924, 0.01829544996975788, 0.005586723165054406, 0.015343172941356897, 0.12870988276387962, 0.06830248170133148, 0.07378511929086276, 0.019167842443234155, 0.039394786448350975, 0.03202310397422739, 0.08180486716862236, 0.005895964651634651, 0.10170585143246821, 0.021719239286280105, 0.023053807406021014, 0.008761611417867243, 0.033601715695112944, 0.02171155996620655, 0.025929477830816592, 0.04418210545554757, 0.030763468172933375, 0.0035659805705238667, 0.06641888884561402, 0.037952539910163195, 0.005192467177818928, 0.020656164901863252, 0.06053653984729733, 0.04256391139434917, 0.014232780917414596, 0.03656451849799071, 0.0233000867800521, 0.02362737136094698, 0.048533160372504165, 0.042239364702254534, 0.02236068218813411, 0.028317418980545232, 0.07226776571146079, 0.09642582439950534, 0.04952086308704955, 0.016520322633108923, 0.05372345793460097, 0.05179998079048736, 0.017927025810682347, 0.019026298342006545, 0.022730473595272218, 0.014399826060980558, 0.04764841856168849, 0.12766599734979017, 0.035499656173799715, 0.0643329161352345, 0.03860209130549005, 0.04863066924735904, 0.022092708353219286, 0.030213970158781325, 0.04243899309741599, 0.03855738263311131, 0.04173295705446175, 0.04294828112636294, 0.003865449456498027, 0.02180454131614949, 0.036543032686625204, 0.03892416134476662, 0.03562972455152443, 0.038606013237897835, 0.0306986443299268, 0.03509723062493971, 0.013953114227790917, 0.06587932458413498, 0.06526339799165726, 0.01125600453399654, 0.06849411356129817, 0.03382944222539663, 0.04447206721774169, 0.013258591227765595, 0.014540157280862331, 0.028619036278022186, 0.009737652659948384, 0.018495867161878517, 0.026050048414617777, 0.043945761530527046, 0.01803491627132254, 0.03237888702590551, 0.007304604198517544, 0.08313533863318817, 0.015187423709513885, 0.027805466005312543, 0.039838527994496484, 0.0503385961720986, 0.01985212804616562, 0.0332936913307224, 0.0685375737292426, 0.04065285822642701, 0.03528644011488982, 0.03920397900843194, 0.02492308826185763, 0.08664391429296561, 0.026340746387307132, 0.012354271985324366, 0.013195053208619356, 0.05509938785274114, 0.05852639342525175, 0.045399638158934455, 0.006153557748932923, 0.03367175068706274, 0.0074621948047674126, 0.03289334209901946, 0.039624199138156006, 0.0487393773426967, 0.08329606322305542, 0.024000401076461588, 0.034583006253732104, 0.011859791286821877, 0.012256126135720738, 0.07426181049751383, 0.03426589969811695, 0.011032009098146642, 0.005863967060577124, 0.045060245120631795, 0.03662199380674532, 0.009777837200090289, 0.05607457498886755, 0.09383554410721574, 0.025315644518871392, 0.032192642733986886, 0.04527455022824662, 0.03224363803331341, 0.014564414907779013, 0.02634547238371202, 0.01810288512414055, 0.04866721514346344, 0.06282804760017566, 0.05649103264191321, 0.03540005062573722, 0.07147757775549378, 0.08684415676231895, 0.014093129080720246, 0.01606849634221622, 0.02840417986070471, 0.02643883540960295, 0.05588506015815905, 0.046337678895464966, 0.012163841132340687, 0.004153644483137343, 0.008730921278973775, 0.027816234356058494, 0.012985796401543277, 0.025341905520430634, 0.04239589933838163, 0.05390527139284781, 0.02650874317623675, 0.010167380761621254, 0.03470358192654593, 0.046166898416621346, 0.062388146562235694, 0.02987875689619354, 0.019313164288178086, 0.04420564044266939, 0.031593720229076486, 0.041124284001333375, 0.02803456487267145, 0.05832473960305963, 0.06686204685164349, 0.035239736549556255, 0.04605976452252694, 0.03385158621573022, 0.049682680118296824, 0.004039025075534093, 0.013147098594345152, 0.01785216134573732, 0.015400134259834886, 0.014250938514513629, 0.01525766565464437, 0.0602302627105798, 0.00469932276921879, 0.10117346607148647, 0.017071958032569716, 0.014219225484079548, 0.013567368766026837, 0.0455570514979107, 0.026786396313192587, 0.09455043503216334, 0.028586266429296563, 0.013191995560191572, 0.050400648199554, 0.07243777944573335, 0.037628305344177146, 0.02529572442706142, 0.04943580872246197, 0.054334607640547414, 0.03518747238974486, 0.03175901135961924, 0.01647130526336176, 0.05073660445798721, 0.015389488045392292, 0.04331208106928638, 0.023460346573431577, 0.06080084280776126, 0.025670526815312247, 0.021481059924034134, 0.02547218763668622, 0.045419878858540735, 0.013640838841508542, 0.03763710255069392, 0.04813447355159691, 0.07726284196334225, 0.04444865436692323, 0.009616404389297324, 0.014607281357582127, 0.04881510524345296, 0.056728580966591835, 0.02570287088331367, 0.029072582655187165, 0.07765090292585747, 0.015923997220982398, 0.06204456357019288, 0.04496296016233308, 0.10910517403057643, 0.022937557393951074, 0.009935281073142375, 0.034964878976877244, 0.04050941253080964, 0.030916864584599222, 0.018900922033935785, 0.06043035590222903, 0.016015635071588413, 0.02966914725090776, 0.06147169002464839, 0.05520052688994578, 0.062092868478170464, 0.009910048052136387, 0.008362850806276714, 0.022213799712647284, 0.037720569143337865, 0.12076940813234874, 0.0779173636276807, 0.09264972952327558, 0.12017882482281753, 0.0739386242681316, 0.13886755199304648, 0.12083035414772374, 0.06769036169030837, 0.17057086580565997, 0.06886295841208526, 0.13376382871397904, 0.161961219938738, 0.15183968948466436, 0.18061230198613235, 0.08026023648147072, 0.07223816801394735, 0.06846755570066826, 0.1255761230630534, 0.10793729991252933, 0.12148132707391467, 0.11999024637043476, 0.17233211201216492, 0.1037457041176302, 0.13225148272301468, 0.0923708380599107, 0.09944336462233748, 0.16144773177802563, 0.13477678650191852, 0.19765406181769712, 0.0979386114382318, 0.10673568903335504, 0.09589725240532841, 0.10319867597094604, 0.18587534528757843, 0.11891125355448041, 0.058651494926639965, 0.15095779752092703, 0.11004173556076628, 0.23408711754849978, 0.11385668335216385, 0.10455290973186493, 0.11249436145382267, 0.20887162988739355, 0.10902018751949072, 0.10391336333538805, 0.08159269605364118, 0.07418561101491962, 0.0722818656691483, 0.14292143232056073, 0.17188699303993157, 0.13704814176474298, 0.21006285239543232, 0.09590522519179753, 0.12420055616114821, 0.1277146347399269, 0.16866906785539218, 0.16035082563757896, 0.13263670062380178, 0.13096480390855245, 0.19873475097119808, 0.1296849511563778, 0.056382358473326476, 0.14016782864928246, 0.12914297809558256, 0.15757560384060654, 0.11666189639696053, 0.11230940637843949, 0.16428982998643601, 0.06902860238083772, 0.1314245249543871, 0.09026177480284657, 0.12256866587059838, 0.1293698259230171, 0.13615031779876777, 0.1315226275473833, 0.14648817878748688, 0.19956180373472826, 0.17717435503644602, 0.15135916455515794, 0.1361195258796215, 0.1629125260348831, 0.12635449772434576, 0.14883614065391676, 0.08854564438973155, 0.1069595105946064, 0.14895985115851673, 0.08746013085224799, 0.15368241417620862, 0.14192760922014713, 0.08820645830460958, 0.09836936582412038, 0.16565471674714768, 0.10188451648822852, 0.10609719436615705, 0.1603827846369573, 0.09731186899755682, 0.17823577379541738, 0.1318338987018381, 0.14694871407534393, 0.10916953307709523, 0.12144106280590806, 0.07052921650132962, 0.10291890919740711, 0.22467176562973432, 0.1031542658539755, 0.196919140538999, 0.08467888366430998, 0.08618420003248112, 0.11824481002986431, 0.07873258952583585, 0.08730002372924771, 0.1254397646657058, 0.1607327051460743, 0.09338281875742332, 0.10462068180952754, 0.19498562786195958, 0.10115859936922789, 0.15629497755851063, 0.05382227638204183, 0.11224862321146897, 0.10734152581010546, 0.15291926584073476, 0.1296682320535183, 0.2508828677237034, 0.12283158461962428, 0.21258424781262875, 0.0948459031060338, 0.2047223068241562, 0.11511953201677118, 0.20908858467425617, 0.08118342408644301, 0.21412628649600915, 0.1172018474234002, 0.12624268872397287, 0.09960845897772483, 0.15961500869265624, 0.10901327324765069, 0.16109713273388998, 0.08633611045245614, 0.1039635952828186, 0.12928623040871962, 0.15418283375246183, 0.09858692450714962, 0.14299465981977327, 0.1547618955373764, 0.11116805619427136, 0.1112573989001768, 0.11935710534453392, 0.17366881242820195, 0.06432003754058055, 0.06820836210889475, 0.13200212110366139, 0.17583803460001945, 0.0722506462729403, 0.10234019346535206, 0.16053864413074084, 0.17057497772787297, 0.13306835746126516, 0.0635471318715385, 0.24516406602093152, 0.10702822583594493, 0.1055792753717729, 0.10809461147125278, 0.06657178992671625, 0.10646954045764037, 0.09980794827320746, 0.2574803722756249, 0.0778659103172166, 0.10809364116617612, 0.12829755060374737, 0.23862700536847115, 0.1362875990037407, 0.11753646018249647, 0.13436085810618742, 0.12971065406288418, 0.10965937429240771], [0.019659325713291764, 0.056320136812116416, 0.044633806217461824, 0.03236080746033362, 0.0324933558835515, 0.04244706087878772, 0.04420459210606558, 0.020397536190492765, 0.011478964355774224, 0.013491338917187281, 0.022401205995785337, 0.02775250973978213, 0.09992216607289654, 0.034345814159938266, 0.08994978440127202, 0.04285549485523786, 0.05451153903933508, 0.03434001607820392, 0.015433955837839415, 0.03110159235075116, 0.09841063432395458, 0.036478571859853606, 0.047573382766651254, 0.014796115956934435, 0.023851486388593912, 0.03566619920145188, 0.03111961084817137, 0.004322927520011685, 0.03343875872503434, 0.0434756826476327, 0.044757465831935406, 0.02352765215826886, 0.0783222590440086, 0.02819061265992267, 0.02210516286348658, 0.023694449636553015, 0.03428431853119816, 0.08579948424760785, 0.04100669727527669, 0.03848178365400859, 0.03357108323169606, 0.005703650863974222, 0.017928019864484668, 0.025419974367001226, 0.03439215810171195, 0.026851771465901817, 0.04131119325757027, 0.04385343327053955, 0.026078248329992806, 0.03563028095023973, 0.02001384668983519, 0.01366767574966486, 0.00671284193439143, 0.028847553301602602, 0.04122706509328314, 0.042557190504989455, 0.026078389126009176, 0.06008299347013235, 0.03024070443851607, 0.08776177359478814, 0.026747882665534104, 0.028782936411776712, 0.04263514739328197, 0.012808682646469345, 0.022061000411797847, 0.015232816005923917, 0.024474362876000147, 0.019875366174216782, 0.016205874238429323, 0.029440687902803932, 0.032466221268155744, 0.05448613468823688, 0.010402667868350233, 0.03550305224156805, 0.020226957575817193, 0.021251747318144356, 0.026399051205122044, 0.03957889335496085, 0.003344813989575154, 0.02946371738133686, 0.016784873258854662, 0.026476327862058367, 0.03476024638595326, 0.013051856026452566, 0.07347671833953687, 0.0522032918275467, 0.047713262760745626, 0.03733512732599463, 0.07293573593986885, 0.0031469018639264895, 0.07411923671939544, 0.07907496472554547, 0.01681919695277299, 0.039401256279753785, 0.011706896142901053, 0.07842013772044863, 0.12013583284403596, 0.021647043160295913, 0.01311421678734145, 0.03712399097691689, 0.03586080643747534, 0.04105084615626505, 0.03057828578831894, 0.028907342414770807, 0.033616629894822836, 0.0890062271750399, 0.039542741009167263, 0.001387398220166298, 0.014790909897003855, 0.0334881289329912, 0.006370147823223046, 0.02187131594733468, 0.02019234380817839, 0.04922633817685502, 0.04905857717884438, 0.07715375388839416, 0.03508658441049712, 0.07367493198918444, 0.010768253206541496, 0.012235861687388803, 0.04561992455273867, 0.041947082350296636, 0.043527288628476005, 0.010810861813037522, 0.062022117631775994, 0.028641332938734974, 0.016365063642816882, 0.015700806697298373, 0.021367220407617942, 0.05593542781259332, 0.015575362535725747, 0.016262815200856755, 0.011974611286340016, 0.059728377498686314, 0.029486044576125484, 0.026238723558240702, 0.025150097241359096, 0.04497566233788218, 0.027500462818092535, 0.04361570513408099, 0.047717361112258265, 0.020185914688876698, 0.05454201543969767, 0.08571297103273016, 0.03535234622125115, 0.00941431291201817, 0.011957850623210626, 0.03402457532605954, 0.017819315161822096, 0.022556938264252882, 0.05062760119991643, 0.031642639211245945, 0.03471817721479705, 0.07987544605774538, 0.015648364422044585, 0.054372452931212525, 0.049211630930325816, 0.018848701978900602, 0.035678596036242585, 0.02845887147954532, 0.007715022041728454, 0.023725233074011545, 0.054595823266676495, 0.04112344601058534, 0.01196657573538167, 0.035934274816619496, 0.026760498327868323, 0.04007466496633632, 0.0860070481098124, 0.021387510301013078, 0.05115655317370381, 0.021753778415066854, 0.016258609980078678, 0.05736775416880846, 0.021371230549578155, 0.07978235105318682, 0.0342231011018157, 0.059164440259337425, 0.04155794590977686, 0.0096059244159343, 0.03447102761960455, 0.048740700485983064, 0.01319325084997607, 0.0020432625356729007, 0.051418467690902095, 0.036866212130657265, 0.01806343679449388, 0.035391083785465786, 0.04790433482932193, 0.026537998213565776, 0.04706401331350207, 0.059048845033560476, 0.03444600664079189, 0.0417929768695363, 0.03600007235737784, 0.05723573161023004, 0.05118821361767394, 0.027181045850738883, 0.03932245461536305, 0.08279754354485444, 0.010991651531574982, 0.014766385945092355, 0.029912123855735575, 0.04220651003665157, 0.03849514061585069, 0.028751153831503222, 0.032736006791570356, 0.0731044943843569, 0.06630721555224486, 0.04248677892610431, 0.032566736053143225, 0.03279975515657237, 0.04517356386142118, 0.009706017661041446, 0.008522693300619721, 0.02770188424204077, 0.03522543303136315, 0.03856694658419915, 0.019273149381790842, 0.04146317492372223, 0.022164244603897845, 0.017995271166520457, 0.05779553657131536, 0.07842920294829778, 0.01850033870765141, 0.0783773764435734, 0.07081141921558551, 0.013534996708455895, 0.029861403363091604, 0.044079572028879604, 0.03108881214367492, 0.02395822842871504, 0.0344673872792295, 0.04792849067598581, 0.023808787876207913, 0.011581932044854122, 0.034946741735828776, 0.033014799867357524, 0.027034271940855042, 0.08698882721364498, 0.024264205313686813, 0.040778488985129764, 0.020526493467124443, 0.03535781182082636, 0.022892972554213235, 0.011938810082418578, 0.09193363759134497, 0.030852909266416515, 0.01673025797520365, 0.08657209136124168, 0.024190083844587207, 0.03129418433776923, 0.01443185461019831, 0.01703439942294998, 0.058150885360581536, 0.06889048657779183, 0.038025424749191315, 0.027105563918926885, 0.05891118384897709, 0.041355769615620375, 0.011196106007056577, 0.04562552585931761, 0.013272216210940053, 0.03637131582945585, 0.022048320288636854, 0.03678257929693375, 0.025943011211763536, 0.04660283002470221, 0.026023877318948507, 0.022002787196210453, 0.022688214434310794, 0.03740881622901984, 0.041295512313289304, 0.0025857765161033186, 0.06392538800303425, 0.010763650194608738, 0.07883336554680552, 0.010347504667671663, 0.006227972260343709, 0.014257657707535794, 0.01511934629109289, 0.05579011614567467, 0.017311737041122148, 0.019334762057821666, 0.037102376243897846, 0.008310322017808045, 0.052585035629038296, 0.0409414798819593, 0.015511717647314072, 0.03310444452134626, 0.007072165242529341, 0.055119221431336234, 0.02189867108661149, 0.04574694630822965, 0.026292229437136223, 0.037926443453345976, 0.06473863257893495, 0.04004373394751123, 0.050024135903056176, 0.029327308093862872, 0.07428697057600532, 0.04133091827056237, 0.14087419717439584, 0.019638771191239357, 0.016168663378006647, 0.0317143026872405, 0.02378373805965696, 0.032191519758531024, 0.03196895009438906, 0.038168073166161776, 0.022526239643671682, 0.013146267388947308, 0.05150969333148428, 0.04127647262066603, 0.00810675133418824, 0.03086061403155327, 0.048837625820721896, 0.028828720562160015, 0.03499266837856599, 0.008382247577953552, 0.042402664332517555, 0.007178598549216986, 0.01391816628165543, 0.04933510394766927, 0.08203993884048291, 0.04406658486862268, 0.04833784067471113, 0.028226115308435898, 0.01563312791820083, 0.034901988958673816, 0.025090035017845885, 0.01106827933939972, 0.01300232466642878, 0.01088579582782196, 0.01042806713043579, 0.03933148252378617, 0.01910568693918841, 0.01897652610205114, 0.09126205755663769, 0.031207562557288578, 0.030054514429398944, 0.045959524544222016, 0.13093421554991178, 0.04018749176923718, 0.05809270776808262, 0.03819916703339134, 0.022404444304161837, 0.019862877737198557, 0.009053171978199055, 0.06964904801653964, 0.04729064400973065, 0.07072705017136675, 0.18325879211936677, 0.17879343458584376, 0.19262577806200298, 0.1822079720773867, 0.13998298213950225, 0.16800413067851747, 0.1932243409433535, 0.08984797022172383, 0.1535400575292962, 0.1039006340184382, 0.0836289253618036, 0.06067259290388652, 0.2405707910656929, 0.0879684282200677, 0.09597303119621106, 0.11277230975351163, 0.1942349781415292, 0.07011988346597978, 0.07142896072140761, 0.14222716886018003, 0.18025142992181437, 0.10197325529796736, 0.10968876842941556, 0.24224289134144783, 0.14633620051401003, 0.1364486017929656, 0.12014892856989588, 0.126402972266078, 0.09599824555750404, 0.14496940028454575, 0.08742154935108763, 0.1917358658143452, 0.1463239597422736, 0.1748712986175503, 0.13124089980764048, 0.13044526321547373, 0.12825639066951616, 0.09939121920615435, 0.06021645452295031, 0.10139840043016843, 0.13200269107307705, 0.11735651269555092, 0.06591319705226592, 0.11229591710226876, 0.17764950596860477, 0.09383001404681376, 0.22982814322624887, 0.17210317429687294, 0.158414965229375, 0.1359497292765549, 0.10822161965604339, 0.10729634216321365, 0.11723550276032516, 0.12052362917789392, 0.10854374058544636, 0.14699812499540194, 0.13417434240026133, 0.14567981287837029, 0.08371229017419474, 0.16396612807043962, 0.11373346817812749, 0.15193548505859716, 0.13177948019334249, 0.25577849788325174, 0.06255860812962055, 0.12091534744415965, 0.12205531341688973, 0.1115059530628579, 0.09078358858823776, 0.16526386700570583, 0.11828772058444363, 0.13549436442553997, 0.11421272424714905, 0.15240279212594032, 0.07554865894573075, 0.13553040820573056, 0.17626567451017244, 0.11258768716028758, 0.1583692455398185, 0.10825701204261609, 0.13758335661675247, 0.11880827908005033, 0.08917343177433525, 0.11015378883374588, 0.17375333075012478, 0.11624516732990742, 0.1340918325419937, 0.29550398194364136, 0.20042390961732182, 0.13473003543913364, 0.12266242583947522, 0.10857746377587318, 0.083261335800801, 0.19201950702284062, 0.1846230546278613, 0.23052415730697767, 0.24539050672735485, 0.16171887437147753, 0.11624591371842793, 0.08686601237526961, 0.27311658752816065, 0.11673212477139064, 0.12364940930690084, 0.08676499208169323, 0.15179129636713437, 0.14820884859987668, 0.09801675831632954, 0.13387201433735235, 0.11728802137076855, 0.15246474237314292, 0.10924066390310015, 0.14407961017319135, 0.08106786957276718, 0.15848063384847982, 0.12003592534789018, 0.23448430480701582, 0.059222712846738954, 0.16478782040732248, 0.11326080746948719, 0.12013359367847443, 0.26919783066426006, 0.1282152443059853, 0.15646489629788057, 0.14839415651346954, 0.0934627026851688, 0.1040704713336059, 0.18123446431543144, 0.11733674018510751, 0.08345691673457623, 0.13074179658932344, 0.1928578641797815, 0.109149767352002, 0.11152932180890016, 0.1505166683346033, 0.11716064677706786, 0.10407235087560755, 0.13403091366801942, 0.13464489286499365, 0.09741156614784684, 0.11061184068343469, 0.10774135256984405, 0.11071870994887181, 0.12347750924527645, 0.2172638459929398, 0.10871072805353574, 0.08159205144537346, 0.04950880891244326, 0.09847769393984761, 0.1267934963107109, 0.11442483429397855, 0.12415574570851666, 0.10631744683321033, 0.09875321986951999, 0.15330110463712895, 0.08650121837854385, 0.17931072254266056, 0.1266949051725013, 0.14226899375872953, 0.14834265570555413, 0.13874662348202296, 0.07507053603019033, 0.1311201070036207, 0.12775483115443162, 0.1372204760887793, 0.13429581373929977, 0.15722264349460602, 0.15007188862987927, 0.17616801975028856, 0.20968124430094445, 0.24301009731633322, 0.10345510792519365, 0.12773006462625094, 0.06371833982744388, 0.1764091303838151, 0.10235774716628449, 0.18986310916287558], [0.035453753279788155, 0.02086803746143622, 0.004518984700553119, 0.04290213056706956, 0.0970981711787837, 0.03022661805152893, 0.010847822463672076, 0.05475178114803774, 0.039678709248879125, 0.06274314251329217, 0.025202378364545957, 0.03698467755956309, 0.04699822934344411, 0.03157474499727998, 0.020767030738560215, 0.035281042368816476, 0.028335551132581065, 0.04535848501005343, 0.07289891862975699, 0.04211318772286177, 0.021396650167714273, 0.03374740394896694, 0.02831714247752513, 0.0675612229055592, 0.024173125558133637, 0.03523925478969302, 0.015777128316195946, 0.03600037769813623, 0.0454545893174197, 0.033228911592492034, 0.046224346583975215, 0.024961344066209028, 0.04106966532500727, 0.026595424328531538, 0.016764744517526457, 0.03940519178286195, 0.010897635415728604, 0.016158317415309802, 0.05829195957630873, 0.020036029695932354, 0.06270143975104604, 0.014198612438381782, 0.06223660933652094, 0.05449241113715938, 0.009647650926906084, 0.010657721548341215, 0.049671949086976905, 0.04926138451056821, 0.01203924768404769, 0.03902438775237117, 0.0070424530422315, 0.05807388520666531, 0.00874996097159705, 0.01367136019481612, 0.020444285556940094, 0.08597879391163588, 0.006847322061990521, 0.07207750449223177, 0.002439653151668608, 0.03678089313741241, 0.01563677504392607, 0.07493216238383736, 0.033858663335974724, 0.006676932588951396, 0.03225675750789898, 0.02102777817552643, 0.02804936372142817, 0.03977774822020105, 0.03388095999668751, 0.027736972984192625, 0.0508706999410476, 0.04121879714408091, 0.020252811456365243, 0.033433011533426385, 0.04865546630961554, 0.0318991491970207, 0.010260885431697326, 0.06385695774640356, 0.04260735459891813, 0.024561132237847363, 0.05894927680492401, 0.044603516414229355, 0.03247339338330286, 0.03409926506823727, 0.040590758701520305, 0.06535744973059211, 0.00469386183457183, 0.040382767362254005, 0.03957342097003545, 0.06544981191733054, 0.07610338846487658, 0.039988877783928595, 0.030808760385428156, 0.08173545982156481, 0.021594471963388578, 0.014911380396889789, 0.030794389013733183, 0.07648340878742081, 0.05496109223791531, 0.008733952634169586, 0.02821458869480661, 0.01787390330407236, 0.020883888039471846, 0.06140554643103054, 0.07091969983386141, 0.030862211981522183, 0.047139256061719995, 0.030357008733387505, 0.02517652278766036, 0.03950139447780592, 0.03286513200561915, 0.024408307491934726, 0.029796338640153408, 0.08914534042456321, 0.05861631967127323, 0.015416339372417756, 0.06452043607298817, 0.04013183493433254, 0.045847495019968064, 0.0025189719869688687, 0.003344110433577693, 0.027099178904401403, 0.011646607458325369, 0.04671770600335939, 0.022362858589206423, 0.02363352058455348, 0.022782951493614485, 0.031764873902180364, 0.06710195647818701, 0.010685289577980126, 0.03820873437715428, 0.030363176616707017, 0.03667243270735655, 0.024344781347151314, 0.010253156069666147, 0.007320931447403771, 0.023048716697043607, 0.0635046623647213, 0.02718786852035139, 0.031743791819150956, 0.027290722554815666, 0.035142644973737855, 0.022164444771728346, 0.025996171037799547, 0.008943770928973598, 0.06528806273958512, 0.047000862059316466, 0.0734104390389153, 0.026626840499894958, 0.028352326214579598, 0.025671520869114568, 0.0485692380794457, 0.016024715566475476, 0.033909757022878954, 0.023473991912656596, 0.027672783571428487, 0.033356387966445515, 0.03372205388067024, 0.014693071932664939, 0.022819929955793277, 0.05639723874628544, 0.04020746784018619, 0.03029242916298764, 0.035199869224535565, 0.05455658697922315, 0.03206132585182786, 0.01139554356424404, 0.0474085937520223, 0.06567675473966769, 0.04916654567101172, 0.01545696156764669, 0.026047617562913468, 0.0324830116171922, 0.046794736691351445, 0.06225713502083506, 0.010956012327889246, 0.02303474396467209, 0.05761324135320527, 0.02832842312221016, 0.06088515756917851, 0.08971793577075005, 0.020689587840544324, 0.03547055380684989, 0.020901991353769387, 0.056257793014603, 0.07069838206682887, 0.015944256580301693, 0.07649790229541914, 0.0238561869399356, 0.011942756611720791, 0.08541647158563137, 0.0541503684196089, 0.022733365850789205, 0.02707296879296856, 0.06190569459327629, 0.03077386672209416, 0.006427415330628199, 0.01549873557606978, 0.03963608707168272, 0.022880105833922113, 0.05220845887171371, 0.012699003397886242, 0.012619318789802492, 0.02966293865548713, 0.030358325091323683, 0.032270338386297226, 0.01069433699428503, 0.017822789261117578, 0.016460986442065666, 0.013111832584919674, 0.01986909142163183, 0.03361158837963428, 0.06676287895866803, 0.014440115774050355, 0.045650261853422434, 0.07116568913417202, 0.05202284901003752, 0.036085920607937236, 0.0310347023686128, 0.05525381903031042, 0.036922259123197625, 0.04122482932039669, 0.0205972765439323, 0.0103932845772111, 0.007400977375384952, 0.029579149758709327, 0.02255495694199843, 0.006715828760726643, 0.0189058091824076, 0.05089411957721625, 0.02278123140734221, 0.0331826931796968, 0.03691119900239365, 0.04255207435094884, 0.03237526364890592, 0.028964420780539513, 0.018458311944933872, 0.04321123380213976, 0.023066141476322497, 0.00631135021935084, 0.021480237200324024, 0.03067471579249416, 0.05687374335580638, 0.07654708929892097, 0.006610321230255067, 0.024427169069115604, 0.03200209653005004, 0.018524633653994118, 0.024589486519939134, 0.05427196868030088, 0.045258672508810244, 0.008526826427052063, 0.01394322797256921, 0.07508704478719405, 0.004967927217616567, 0.035658463902239285, 0.006347104349905359, 0.03431564310033407, 0.06154958584478923, 0.0025369130889885128, 0.026096573864508952, 0.022950295192588652, 0.0296860970556736, 0.015875046008399556, 0.04535839340782591, 0.019114221213385463, 0.0557304593468351, 0.03739734898720469, 0.07071567792445421, 0.020155468822589943, 0.05893727352044412, 0.03174647203247462, 0.011465036576347691, 0.022348314191081693, 0.007450311112084559, 0.03457608858921698, 0.04602117284334131, 0.018883090133645704, 0.050660136954060624, 0.02058414519498391, 0.04176426466022219, 0.03966294348772083, 0.013091976105767702, 0.07509194381002869, 0.027387152558990886, 0.04290968944717731, 0.044872647151350975, 0.02436806697265378, 0.045073283171015124, 0.08255525904574565, 0.08338522272450583, 0.03450752941093274, 0.01816353597678244, 0.051497842717383585, 0.03506047438297953, 0.04914180967690689, 0.026326797403661267, 0.0199851751926222, 0.028055010829120874, 0.019381331612489054, 0.04175455482410533, 0.0386916273938758, 0.03982156801170536, 0.05449738819152117, 0.05546052793839148, 0.016832017871950353, 0.018411253845053058, 0.04319845698773861, 0.019833634574232355, 0.029280136339366436, 0.07838564778545073, 0.03152840784085648, 0.03984366111191256, 0.03868722030892968, 0.043602137826383114, 0.040173971958990605, 0.057970198270465643, 0.035567957508776865, 0.009161563706584275, 0.03163743484765291, 0.048831939697265625, 0.028983558860740492, 0.05385476803140981, 0.08455686949725662, 0.04672521399334073, 0.027076285132872205, 0.01123192417435348, 0.027048317615741065, 0.06513194540249449, 0.06232221331447363, 0.0944545716047287, 0.02636446966789663, 0.003928311909216323, 0.009111365685904664, 0.022724054653995802, 0.02813141217588314, 0.04064589984981077, 0.023404878031994616, 0.013131399838519948, 0.04524507466703653, 0.037459146564028094, 0.018318708453859602, 0.02912284852936864, 0.052122773469558785, 0.03267842630988785, 0.03520192179296698, 0.061868246245597086, 0.026530086495248333, 0.04744412184559873, 0.021454608932669674, 0.018004967431936945, 0.025217295956930945, 0.09373695975435631, 0.17515462769993714, 0.09466164692171983, 0.15927686755146298, 0.20840221936149256, 0.09152992282594953, 0.14090144714074476, 0.13098894618451595, 0.13838442148906843, 0.17246026013578686, 0.12995741010776587, 0.1443993223032781, 0.086609688986625, 0.07745270963226046, 0.16217551486832754, 0.09284389910421201, 0.1843078208288976, 0.08960425401372568, 0.19304845109581947, 0.07739702226327998, 0.06399809303028242, 0.14855627210012504, 0.11452068415071283, 0.08374831359833479, 0.13557023821132524, 0.14772083264376434, 0.1487545400325741, 0.11466190085879394, 0.11844265727060181, 0.15670462271996907, 0.1360450770173754, 0.13450989153768333, 0.16472406525697025, 0.07182571371751172, 0.07726224485252585, 0.12555240147880145, 0.11546239576169423, 0.05127158182274018, 0.0989394166639873, 0.14273437378661974, 0.12350508490843431, 0.1060663413788591, 0.2080150337091514, 0.12021899409592152, 0.08306618234408752, 0.18826320501310484, 0.07129028173429625, 0.150931198948196, 0.0693809791867222, 0.13497183817837918, 0.05309529057038682, 0.18934401630290917, 0.06698546558618546, 0.10858949420175382, 0.07329407706856728, 0.09965590214622871, 0.07501087923135076, 0.17335698487503187, 0.14346180403871195, 0.09074436926415988, 0.08372985066047736, 0.17516623064875603, 0.14204405940004758, 0.11227261620972838, 0.1443944911339453, 0.17934410646557808, 0.21203284311507428, 0.1450898673917566, 0.17312487161585263, 0.1173199667994465, 0.09964755616549935, 0.2211036349513701, 0.17261523753404617, 0.10174735063420874, 0.197234713605472, 0.14585948895130837, 0.0768174651478018, 0.13435279711016587, 0.10574251054120914, 0.0835324851796031, 0.11174809506961278, 0.10650663596710988, 0.12614078633487225, 0.22500745047416004, 0.09084701125643083, 0.2722442629081862, 0.12704695628157683, 0.12901354075542518, 0.15218636659639223, 0.1513478465910469, 0.24707840329834393, 0.20298004602747305, 0.16882134468427726, 0.19221823635910237, 0.0911925687853779, 0.15361297290240014, 0.07620199317378656, 0.15596047336501734, 0.15050711456154073, 0.09796143735625915, 0.13583638678703988, 0.09591992226030145, 0.11791551698531423, 0.12665261887013912, 0.14912717789411545, 0.13298107071646623, 0.14702483213373593, 0.13254028079765184, 0.14482831928346837, 0.1062456239014864, 0.11594198431287493, 0.13615981728902884, 0.18950972812516348, 0.15101988347513334, 0.19094900946531976, 0.13753737908388886, 0.07032176120472805, 0.12854521588555404, 0.14894096074359758, 0.11681261259530272, 0.07682800279664141, 0.17136395110615663, 0.11032359900751285, 0.10776601053242173, 0.1347542048564979, 0.1654871321682419, 0.11954404174217156, 0.13402819952794484, 0.11741359106131963, 0.07026679986821753, 0.14191127009689808, 0.129022958821484, 0.1169391322348799, 0.08046180887946061, 0.14072664294924053, 0.07481592933514289, 0.08052791854632751, 0.12242538641606059, 0.1174714836691107, 0.1946315411478281, 0.15637227626783506, 0.13621490076184273, 0.14317650720477104, 0.08124029210635594, 0.08479607344738074, 0.1381119353962796, 0.1325219196400472, 0.18967050021248205, 0.11858527176082134, 0.14236930837588652, 0.08275265845337085, 0.11845720506140164, 0.15927124928150857, 0.1515859038169895, 0.17070510717374937, 0.07896793261170387, 0.09918216935225896, 0.17281042491751059, 0.11034869801785264, 0.09166155861956732, 0.1185395520712648, 0.11257800446557147, 0.07121764456054994, 0.17001061301146234, 0.21713942981192044, 0.09684927774859325, 0.14840198680758476, 0.16852177147354397, 0.11876459499554974, 0.14281611011496612, 0.159563222900033, 0.10274905152618885, 0.18074173932628973, 0.1115340715540307, 0.18588001360850676, 0.10988301264920405], [0.07730542682111263, 0.025851822890607373, 0.056799857677625756, 0.022628321844552244, 0.04062886183549251, 0.052709743580115695, 0.03149059986961739, 0.046092134035591564, 0.013547592862908329, 0.028147026962999786, 0.09357337853206055, 0.06231100391596556, 0.02041254029609263, 0.034424758316682916, 0.05586012738889881, 0.030936979755227054, 0.08375264265175376, 0.03776615312589066, 0.038625378627330065, 0.04248410889080592, 0.014619476328204786, 0.007527205244904118, 0.04277867790577667, 0.026132066334996904, 0.03043299787012594, 0.028953231738082, 0.00790973614701735, 0.04361701470666698, 0.029632879554161003, 0.009370971487702003, 0.03983147462297763, 0.05503145292667406, 0.07219491819185869, 0.04825018412832703, 0.11122889364404337, 0.029802153685263226, 0.04190836514213255, 0.08442291989922523, 0.008723281822832567, 0.06731600034981966, 0.006742698747465121, 0.04918952425941825, 0.049537158105522394, 0.01767270410034273, 0.022381704899349382, 0.01466858699651701, 0.10627385095826217, 0.0666616347485355, 0.03010577435738274, 0.05096799847004669, 0.033251883395548375, 0.015566276951826044, 0.04557515820488334, 0.01874810576971088, 0.05746021813579968, 0.011332214194616037, 0.01750577430772994, 0.10133575129189662, 0.026220121520704458, 0.0821935727394053, 0.014873714918004615, 0.015282055595889688, 0.05507583250956876, 0.07608603153909956, 0.05546367634087801, 0.031585001054086854, 0.017529051451544677, 0.044624059061918936, 0.06333449935274464, 0.025112391050372804, 0.013194227092234152, 0.07274008036724158, 0.030913655113961016, 0.06775878516158887, 0.03608693162511502, 0.0358675035781094, 0.025607100754444088, 0.028192051154162203, 0.030624185289655412, 0.026960391351687055, 0.024529990873166492, 0.015310128285948719, 0.035021638431187184, 0.044007643924227784, 0.046661187428981066, 0.057228749484888146, 0.05331064401460545, 0.03787558386102319, 0.017933261547503725, 0.032697075844875405, 0.0382327714801899, 0.02599700733221003, 0.06474210667823042, 0.015182198989870293, 0.04054926967780505, 0.033360428642481565, 0.06374159322253295, 0.05569666151755622, 0.0364058295131794, 0.014977795404515095, 0.10092801959919077, 0.00973846435746444, 0.08327918127179146, 0.02308215999177524, 0.025238355987572243, 0.05366893086050238, 0.08887613165591444, 0.012872790635031248, 0.04603621257202966, 0.03481190325692296, 0.040648973613445244, 0.04287062279347863, 0.027486812389854873, 0.03220259005736027, 0.009003638921837722, 0.026575556823185513, 0.0570402592420578, 0.07287413174552576, 0.030650376741375242, 0.026033782233883227, 0.04130559195099132, 0.046331853672329865, 0.07164853465344224, 0.03355749896062272, 0.013037466843213354, 0.024560112738981843, 0.006726956310948091, 0.019464182434603572, 0.0874016343482903, 0.08202469894396407, 0.03225038267139878, 0.09078287612646818, 0.052103394509426186, 0.05337237373792699, 0.008999809439826225, 0.04332555338208165, 0.03062020568177104, 0.012165162579289504, 0.017436787652383958, 0.02873315569013357, 0.03260955839817013, 0.032070835520114215, 0.06255465905581202, 0.038327457649367194, 0.059731261272515566, 0.011621207348071039, 0.009862553993506091, 0.03405170315610511, 0.033489920265440426, 0.05988955670701606, 0.049425803723612, 0.04367039166390896, 0.04398317595145532, 0.004576442197763494, 0.022135486593469977, 0.05848592559673956, 0.013325970603286155, 0.009233274680030133, 0.03676512737625411, 0.01950850264568414, 0.017260660317593386, 0.07919509935059718, 0.0021090293303132057, 0.02810240480383592, 0.027129321126267314, 0.030556450531418835, 0.051597071678510735, 0.03998746303841472, 0.030537648326052085, 0.028860452252307107, 0.0419913296188627, 0.026226986598755633, 0.032584774906613996, 0.02976083429530263, 0.018299032634656345, 0.032582586631178856, 0.051738373203469176, 0.056203778234443495, 0.03393758713666882, 0.029107103124260902, 0.08729894485856805, 0.00981568927610559, 0.022974369615050297, 0.038725876448942084, 0.031360266863235405, 0.05881616859031575, 0.02874176629952022, 0.010276938722069775, 0.007658173529697316, 0.013476579932362905, 0.06287799456289836, 0.05035831779241562, 0.04455642947661025, 0.02672713645733893, 0.04066322624151196, 0.04432172082098467, 0.030743546384785856, 0.01914015312546066, 0.05899099313787051, 0.02282868984288403, 0.032333584635385444, 0.02236898406408727, 0.07274786994925567, 0.04819524993321725, 0.03069200486476932, 0.043852503677564006, 0.027062607563233802, 0.03336433021883879, 0.05937288621706622, 0.03328745898657611, 0.010581306630878575, 0.04174957776974354, 0.0824001052283815, 0.024472591899601475, 0.04025118585143771, 0.02821119093070073, 0.05918052153927939, 0.04813935561105609, 0.08122862130403519, 0.024695298967084715, 0.01790442380921117, 0.04181149069752012, 0.003831189799322081, 0.03623394641493048, 0.04374264546536973, 0.05921087919601372, 0.0204894403660936, 0.017788357001596262, 0.0498634248838893, 0.056919588574341366, 0.00862330901769123, 0.029422397991376262, 0.04028381320780941, 0.04667291251410331, 0.01105183589139155, 0.005381746217608452, 0.028503444444920336, 0.057860390948397775, 0.028330786120412604, 0.01721522900541978, 0.04315698832007391, 0.05202626882653151, 0.02744947769679129, 0.03109893249347806, 0.11093443658735071, 0.08177312530044999, 0.06779403505580765, 0.04144115985504218, 0.03488067617373807, 0.03317851001130683, 0.04211272292637399, 0.041082564275711775, 0.027001888857090046, 0.038892914807157855, 0.026889699877106717, 0.02970501800466861, 0.016026374584596072, 0.006651229682444994, 0.03513286389144404, 0.027604597587404505, 0.02524723801096635, 0.07265110407024622, 0.028987860772758722, 0.02935639689011233, 0.03879149417792048, 0.020284877325009023, 0.04637979217139738, 0.02692041376472584, 0.032740963489881585, 0.015009450759472591, 0.031006916359599148, 0.0250117846631578, 0.05915855057537556, 0.09400042133139712, 0.01786411882910345, 0.05448288789817265, 0.10015440146837916, 0.02514405658335558, 0.041612476376550536, 0.018652115116960237, 0.030872630886733532, 0.027546040015295148, 0.08892877918801137, 0.011201170422802014, 0.009787197590672543, 0.03753570906285729, 0.03424276504665613, 0.012825941184668668, 0.027433823893911073, 0.011938991590536066, 0.044917562776910405, 0.0377864650716739, 0.04302804291780506, 0.026947173489523784, 0.07177700168852295, 0.04146246924730284, 0.031723981989281516, 0.021264322268377458, 0.055700203470353565, 0.015278001349153263, 0.09586384812636034, 0.021753371294055666, 0.0707666901871562, 0.018158567404108386, 0.059493210831923146, 0.043193866698337455, 0.05708031316420861, 0.060057670543236394, 0.020953178339238678, 0.047509128893060346, 0.01983387375782643, 0.0968327418501888, 0.03136500643034067, 0.007811326516925224, 0.01876198689985488, 0.030894934332796505, 0.07281759620777198, 0.022571155269231116, 0.04742183875558632, 0.0160989286378026, 0.05597448768094182, 0.01847582493376519, 0.00810771485391472, 0.025780011833246266, 0.037721369814659865, 0.022498711477965117, 0.02485895822090762, 0.02283966345047312, 0.030866551212966442, 0.01538072815830154, 0.011501215215373253, 0.07205885156456913, 0.01882808978137161, 0.027296591882726977, 0.02454252171862338, 0.05199279669406159, 0.01014267445342349, 0.03457584431661027, 0.024979649244674614, 0.0557819669401007, 0.053679264948836396, 0.06561651440071208, 0.010000606183893979, 0.007950946123206189, 0.02382115926593542, 0.005524352226140243, 0.007777884918531137, 0.024456159477787356, 0.035574637686035464, 0.017799311949472343, 0.037605666023279936, 0.04606309612946851, 0.13889336346515588, 0.2522355408540794, 0.20596968489033834, 0.053573332061725, 0.13738336520535605, 0.08543923643550702, 0.17525121037449154, 0.08273730999124901, 0.1381517518311739, 0.14379972804869923, 0.20547911764255591, 0.13216230965086392, 0.11466836051217147, 0.07825993560254574, 0.08086821064352989, 0.10515262612274714, 0.09839675828282322, 0.10163497844977037, 0.08403555104242903, 0.1543073177869831, 0.09664376984749522, 0.07388885372451373, 0.20056060728217873, 0.06653961379613195, 0.1195732866014753, 0.1074752447062305, 0.12144262343645096, 0.11280185995357377, 0.10558563324489764, 0.10631087861422982, 0.13282122143677302, 0.17878687993756362, 0.1531938011092799, 0.18511582032910415, 0.2174357867666653, 0.13113966238285812, 0.1617642140814236, 0.14199737619076455, 0.12306126872343676, 0.20312050277633326, 0.11288787783788783, 0.11219655243413788, 0.15533331701798098, 0.09397431808922972, 0.14339540260178701, 0.08274021412112884, 0.14950250275433064, 0.18057305552065372, 0.10693457443267107, 0.14145784585603646, 0.10141953679599933, 0.11377778330019542, 0.23174028205020086, 0.11625317404312746, 0.16710725666156837, 0.14320907688566617, 0.15931706396596773, 0.21772397415978567, 0.07163148306842361, 0.11830047704279423, 0.07913466902183634, 0.1340809759816953, 0.1363594422915152, 0.12468450090714864, 0.14401570574513503, 0.10396094221089568, 0.08579229856176035, 0.10883582276957375, 0.18165814158107552, 0.17849185291145528, 0.17655087634921074, 0.14313309453427792, 0.1208748524742467, 0.1551346012524196, 0.1715740119772298, 0.12675131857395172, 0.2074433815266405, 0.12140812671610288, 0.08656381323401417, 0.09180059044488839, 0.08648468926548958, 0.12371135955410344, 0.10487718161727701, 0.1263745009366955, 0.13524839548127993, 0.16933157587690012, 0.0933591378852725, 0.12956943735480309, 0.08846204209008388, 0.11946180329791137, 0.1485913930726903, 0.09158768651208707, 0.11291126015463046, 0.13691052129226072, 0.15188373997807503, 0.2022618574223348, 0.14361546507903508, 0.2545543392854077, 0.12295790069869586, 0.08783873303660325, 0.15805334677653654, 0.07110912645501749, 0.19360434769519738, 0.07300796599260398, 0.10052233029689107, 0.1538032748337303, 0.29202554002404213, 0.07358542643487453, 0.09163470220352922, 0.14762415497430734, 0.10372684084411178, 0.1430419808519738, 0.12439562140830926, 0.1463620119861194, 0.1286432777664491, 0.09173047063606125, 0.11024391185492277, 0.13269128198070185, 0.20177859121135303, 0.1310583603169237, 0.13044322761041777, 0.07881857348339898, 0.13619515539280005, 0.13988411958728517, 0.24060154227273806, 0.10152990730213267, 0.1466056060578142, 0.1423758358827659, 0.22669461422732898, 0.1755537555686065, 0.1142491480069501, 0.1944886688143015, 0.1699965266244752, 0.14632169343531132, 0.0746493422027145, 0.23463795227663858, 0.09742408511894089, 0.25781149736472536, 0.060647711024752686, 0.11397569839443479, 0.12378845470292227, 0.17561337165534496, 0.1272185170756919, 0.14321435588811124, 0.17221562112016336, 0.14099261510585034, 0.03483511593991092, 0.10359055030026607, 0.10461800838155405, 0.10503572132438421, 0.1840681486896106, 0.13376522649611744, 0.14108956418931484, 0.121976766203131, 0.09497152707938637, 0.16093394506190503, 0.1841043010354042, 0.1528454955135073, 0.08937455633921282, 0.15034791667546543, 0.14275399701935904, 0.12440688508961882, 0.1021747530571052, 0.18036169186234474, 0.09869950025209359, 0.20592734430517468, 0.11050604350332703, 0.11001523876828806, 0.19681379119200365, 0.17743834587080137, 0.13120185690266745, 0.10820456128567457, 0.11188200395554304, 0.11722968092986516, 0.10582025708364588, 0.1040667597470539], [0.006417547311035118, 0.00716826191637665, 0.07082009089312383, 0.00739397998300514, 0.0452251087741128, 0.027943909201504927, 0.020531558731038655, 0.05228452603997929, 0.014250214178381222, 0.03953863587230444, 0.05496207611369235, 0.014603389959250177, 0.008842942321539989, 0.07388388006282703, 0.07927374155925852, 0.04740115700821791, 0.015294070754732405, 0.003016996122564056, 0.05490196808906538, 0.013914041636910821, 0.02841824758797884, 0.02757863005224083, 0.0886189600984965, 0.03623781745721187, 0.030475854141903774, 0.02021010615862906, 0.03694628265553287, 0.07052420212754182, 0.05898049620113202, 0.040021583171827455, 0.016962629077689986, 0.024295858972306763, 0.046654341010642905, 0.03860490722581744, 0.01518835499882698, 0.012257754619765495, 0.015322832157835364, 0.030285121340836798, 0.025700132994513427, 0.05411431785406811, 0.037733233999460936, 0.015263277139248592, 0.043667708057910204, 0.019395733518259864, 0.025637887584577714, 0.02908911176824144, 0.07069270951407296, 0.04019929488588657, 0.026766934232520204, 0.04745741434661405, 0.027315707910539846, 0.030956202652305365, 0.04074384637975267, 0.017309282440692186, 0.022934137577457086, 0.02624451824729996, 0.019403791121606315, 0.02523167581031365, 0.013858700320789856, 0.03923622638519321, 0.03044453975079315, 0.019900721331526126, 0.03190062161801117, 0.004475491878110915, 0.029753020964562893, 0.032371453674776215, 0.06041866474385772, 0.030913509228932004, 0.03331356901409371, 0.06929872717176165, 0.06137212858136211, 0.02030462778306433, 0.06015577992158277, 0.018982330969135677, 0.06180939690342971, 0.04776125214993954, 0.05492944875732064, 0.01168283274663346, 0.03988746054736631, 0.006768319381600512, 0.030339536456657306, 0.033567371645144055, 0.05889708389128957, 0.09850268438458443, 0.0732948641691889, 0.04190535923199994, 0.022783640206658413, 0.06977645653699126, 0.06672114226967096, 0.05425715286816869, 0.03599836244913084, 0.010944729138697897, 0.03733890337337341, 0.03385448356025985, 0.0977524621412158, 0.037391069145607095, 0.024009866639971733, 0.023232401215604374, 0.05685900218252625, 0.028641678991594484, 0.028950778833989586, 0.02205183170735836, 0.02654660543027733, 0.03838407800399831, 0.016764603721510087, 0.01717220649256238, 0.09366203591759716, 0.02027589691403721, 0.011200621657605683, 0.03334637957492045, 0.04338985814579895, 0.07894968001970223, 0.00960974965710193, 0.05066922932331051, 0.09249026022319283, 0.021103221091574857, 0.018971316649445465, 0.003760399513079652, 0.03006269077637366, 0.0680267047137022, 0.09960268464471612, 0.02891019904719932, 0.030575276485511234, 0.02856751172138112, 0.13403411635330745, 0.04782506497576833, 0.03272224949406726, 0.029943838582507203, 0.007624033040234021, 0.03974525657083307, 0.07434007272656475, 0.021640664931120615, 0.04827812620039497, 0.008610735763795674, 0.01723452314867505, 0.016579365357756615, 0.009834428716983114, 0.054450759265039644, 0.03652194042557052, 0.02204002350169633, 0.058257476426661015, 0.02020461850666574, 0.03885906269507749, 0.002092719044802444, 0.02710838832094201, 0.041087955236434937, 0.0466171403282455, 0.054160553230238814, 0.0599078092990177, 0.0267745168613536, 0.015596721121775252, 0.028442954744345376, 0.0715736990262355, 0.07384417219353573, 0.0521589597421033, 0.0408965981831508, 0.012592826238168138, 0.06937554412122283, 0.12485663167067937, 0.08552891840892178, 0.01939147910369294, 0.023451240633481314, 0.08553163933434657, 0.10776613266872508, 0.021946192286642532, 0.07183509785681963, 0.009432158383008624, 0.03677644194769008, 0.029580662891800915, 0.06856841993119035, 0.030437730651881014, 0.03192085553226726, 0.039371343063456674, 0.03054238450048225, 0.0789946736767888, 0.05364260030910373, 0.01796791941991874, 0.03741236835984247, 0.03346107913447278, 0.012183302364844297, 0.10293414909392595, 0.03779806802049279, 0.023706710764339993, 0.02665992926007935, 0.020797313756442497, 0.028712134675255845, 0.07254056393035821, 0.011412299986529564, 0.019215541758707592, 0.06006184353360108, 0.02281988924369216, 0.029402618695582663, 0.03598874082256641, 0.008196201757527888, 0.01952071118700717, 0.05592035076447895, 0.06424709502607584, 0.07260486190872532, 0.021861813064398508, 0.04238721409014293, 0.04078201736722674, 0.025980827664690356, 0.04742864446182336, 0.03475627017074397, 0.045393222610333135, 0.00976825034844556, 0.005042115692049265, 0.024081774388573, 0.027627584657498767, 0.022730453239221658, 0.04296195021431361, 0.041962478309869766, 0.0299590513376253, 0.02807567222043872, 0.0358551033506436, 0.04606498245682035, 0.07524906537894692, 0.029259614047727416, 0.04508456720837525, 0.07599814089813403, 0.023072378909481422, 0.012278695906778532, 0.052677431742527654, 0.012059408655789281, 0.011227802922283965, 0.0072945118382839215, 0.028202809326882874, 0.0800064168870449, 0.01749000176122146, 0.05541178537532687, 0.026892471692657897, 0.005330924792880458, 0.041375077329576015, 0.07715584377625159, 0.04802916830937777, 0.04396675540400403, 0.0039618900627829134, 0.07999499035733086, 0.03954198444262147, 0.011565116250754466, 0.011027808118212436, 0.02693205403297075, 0.08704633984182562, 0.05160485447517463, 0.028243687669081346, 0.023650071749995862, 0.024441852566919157, 0.010420025642296033, 0.007061521572593067, 0.034744059933083396, 0.04809040609481079, 0.032639736243124516, 0.035725045150944164, 0.04881693050265312, 0.035017580791775665, 0.03102860233879515, 0.03258238985602345, 0.00683718644514946, 0.02870001264714769, 0.04149868944659829, 0.027570930376116718, 0.010277205047064593, 0.013475267815270593, 0.0015147786450272957, 0.03644273503284369, 0.04563390576679792, 0.05610650345417006, 0.024287643609568477, 0.013539342725250338, 0.011497036287827151, 0.036882897306765826, 0.010377029422670603, 0.01790595899469086, 0.014799686747470071, 0.01269116547025208, 0.08081616022224937, 0.061965188543711386, 0.04854868186105575, 0.027986969033788358, 0.02816953736224345, 0.027132573005344187, 0.03634514473378658, 0.03219180813591395, 0.015799275699204633, 0.033943619312984605, 0.034917832751359255, 0.030529132711568048, 0.036046870917614014, 0.06768686723496233, 0.0773738706484437, 0.011911296335581158, 0.014650073168533189, 0.025870343503941382, 0.03096683868872268, 0.062269409719322405, 0.03708099899813533, 0.007042953037723366, 0.022371923817055564, 0.04003519797697663, 0.0033836603314349695, 0.05586476517575128, 0.09078184475323983, 0.03568619902112654, 0.05529467701645834, 0.04302162736920374, 0.04217148745166404, 0.04775597993284464, 0.03625793941318989, 0.0614664653050048, 0.0194387899578682, 0.029906308810625757, 0.045219446399382184, 0.025141673229102577, 0.02854652124057923, 0.05477337891768132, 0.005508892653909112, 0.02779311327529805, 0.021930160200489417, 0.010314366713698422, 0.039173058167632134, 0.016146122444687144, 0.02698633004911244, 0.15919184711362633, 0.08908613145883594, 0.005854475203835006, 0.0649167208799294, 0.046878603619656393, 0.02125220193660685, 0.06874415371567011, 0.04381960829985993, 0.024270880401932766, 0.030394355300813913, 0.03612691769376397, 0.0491266444192401, 0.024220606046063558, 0.049474359689546485, 0.014241416971864445, 0.04954129038378596, 0.0929524986339467, 0.05496344675443002, 0.044386565020041804, 0.06150203411068235, 0.02797468754995082, 0.01930240781179496, 0.05414793247889195, 0.04291060546945248, 0.029063385113009384, 0.03849804813840559, 0.009667124881941293, 0.02695915981062821, 0.02554236681732748, 0.010235964536799915, 0.11752457224896976, 0.08715870524091379, 0.09554855325924498, 0.07584068006170647, 0.1862319697226797, 0.08459336111055953, 0.13548707695943968, 0.0838144232652017, 0.09516982893858637, 0.12433747095721108, 0.2257427517324686, 0.12380963856620447, 0.12011536822787353, 0.1843631485743182, 0.15371419675648212, 0.1360554178910596, 0.10660089805190053, 0.09593212910528694, 0.10844324276383434, 0.2134681482400213, 0.17169210421187536, 0.1753808105630534, 0.1140857432037592, 0.14772280039531843, 0.1527203872267689, 0.17026156240275928, 0.11261676917118685, 0.10499086337430136, 0.13940359465777874, 0.06068013821329389, 0.08453505459640707, 0.06962649351251976, 0.07090318429150752, 0.14318767589117798, 0.1788550184241363, 0.13127280452421733, 0.09106687695852347, 0.11850316902356488, 0.11671664060226508, 0.10443397611379623, 0.2086887104170663, 0.08982945300106492, 0.13488878549209662, 0.12462504766881466, 0.09863976881440197, 0.09600218784596239, 0.17467370922011988, 0.126621650531888, 0.10355953446456365, 0.10719619039446115, 0.06503245181271008, 0.11389306639986378, 0.11923495547047683, 0.17787805013358593, 0.13022254088095256, 0.06028798568461623, 0.09144076332449913, 0.19880976980285986, 0.10070423875004053, 0.12917545278157505, 0.09420212265104055, 0.11634029793952193, 0.11956895754805633, 0.12784057083938802, 0.0784073541206973, 0.1080555957076805, 0.14195732905396394, 0.12681305168994836, 0.10465201655668871, 0.12999869217830046, 0.11079191709203379, 0.1031511038807886, 0.12254433360482965, 0.11757094333214418, 0.20746242121926375, 0.16188356839120388, 0.11099772354854004, 0.14516829246921198, 0.11408487467893533, 0.19869862576680525, 0.12120179778763226, 0.11979904877288, 0.11486163442688328, 0.1667514600391899, 0.1237221754023007, 0.1375246090548379, 0.07457207063479082, 0.07144031939761979, 0.16974778925733908, 0.09870775123792035, 0.13880033631409916, 0.0753585130774549, 0.07659076659807137, 0.13881184426801546, 0.12097665986844472, 0.09787347207644156, 0.10747863059597355, 0.2050886885928256, 0.14855259444032395, 0.1356509838785444, 0.10493324218051774, 0.14400970749557018, 0.10872466516281877, 0.04932794879589762, 0.10555359960666724, 0.14725797676614352, 0.1568442109440054, 0.05040996787803514, 0.10935077656592641, 0.1565856755312, 0.1344170815178326, 0.1380646957882813, 0.08972696707184825, 0.1738269789410489, 0.1649346011025565, 0.03638728854379483, 0.08954996442688362, 0.10434233995952777, 0.1916207591337817, 0.15158120835466043, 0.18721507196979864, 0.11060570672686611, 0.10365539789199829, 0.0891329368044223, 0.198630867259843, 0.1629868256194251, 0.14570236738239015, 0.1876355872622558, 0.1054998596331903, 0.1990235083337341, 0.14123561206672872, 0.18656514398753643, 0.22032483959836618, 0.15756366162427834, 0.08495299824114357, 0.14812338032892772, 0.08368449059448071, 0.15761440247297287, 0.19074444472789764, 0.0824730002454349, 0.10796573731516089, 0.11798303121966974, 0.12316283184502806, 0.1375901283962386, 0.10513291468045541, 0.15609475544520787, 0.2427253025983061, 0.17100964726081916, 0.09321020623402936, 0.15777429246476718, 0.11121508545641388, 0.1130758048966527, 0.2535438377942358, 0.19433335214853287, 0.115222642198205, 0.12609892072422163, 0.06464198205087866, 0.19235634537679808, 0.15726161854607718, 0.2151210866868496, 0.08326124759124857, 0.17983506726367132, 0.1650271261376994, 0.20744890480169229, 0.07840453141501971, 0.2679118168141161, 0.07911199238151312, 0.06170735880732536, 0.12546268557863577, 0.10042787822229521, 0.14978936021881445, 0.1391761497195278, 0.09385934711566993, 0.11727185866662435, 0.16024048227284635, 0.17655424188290322], [0.031445385688649755, 0.04443769941904715, 0.03942122217267752, 0.05578045719968421, 0.02718822644757373, 0.008035282088842775, 0.040824456339968104, 0.033037890414042134, 0.02791021315247885, 0.040257787997169156, 0.04662823098312531, 0.03385570153061833, 0.036594933830201626, 0.008481037187656122, 0.051857422172491036, 0.028081874030509164, 0.015577036820884262, 0.023890698927321603, 0.04082790669053793, 0.027601074294320176, 0.07643213868141174, 0.046875367007617436, 0.008564966880450291, 0.01970121676900557, 0.01605557364278606, 0.03475855004840663, 0.02222114146154906, 0.038735976442694664, 0.04825599578076175, 0.037832028698176146, 0.07236332379813705, 0.019514385544295822, 0.041362320871225426, 0.025323892112023065, 0.03202196064272097, 0.031148747141872133, 0.0798393887068544, 0.02917855964707477, 0.025814725684800317, 0.03557108894788793, 0.04162260690437896, 0.04793475016153284, 0.02586787024379841, 0.03496599177430783, 0.028331959985994866, 0.01965335290879011, 0.1519282790166991, 0.0582359940079706, 0.04377639240452221, 0.0365163289409663, 0.06446362233587674, 0.015053441881069114, 0.04262546130589076, 0.03049656981602311, 0.08793182125581162, 0.04828598363591092, 0.025371854359816228, 0.008799916416007494, 0.051076509790228944, 0.02466609312354454, 0.04781756377113717, 0.022200771840289235, 0.047229843879384656, 0.02573220055949475, 0.015640953123303394, 0.011633199606356876, 0.07196126465818711, 0.02188718518508332, 0.03958873550540634, 0.06197747002754893, 0.05644221204732146, 0.08823207300156355, 0.013492521264457276, 0.02818511313359652, 0.05854951111333711, 0.010406593193433114, 0.05211391519489033, 0.0012201048812130466, 0.03112209428633962, 0.03846517650942717, 0.06722406564014298, 0.039552359243056605, 0.027782567144770707, 0.01470914133824408, 0.024475896365142295, 0.08503010696066277, 0.024076544579916766, 0.026899757462420633, 0.03431294931631003, 0.015460103184783032, 0.0432449502072164, 0.04358711845374533, 0.007529044922973428, 0.07151348582868065, 0.023678219078906944, 0.06980029347219638, 0.031767438764550855, 0.02518053462595812, 0.03285212448931166, 0.025248642578454952, 0.058677014628691335, 0.046164401407752714, 0.019309488324714557, 0.040851207583078315, 0.02179538787874792, 0.0998940272256732, 0.057769528324050565, 0.0897983353851097, 0.05404230832521405, 0.014252458432955402, 0.035212530687983544, 0.041312183918697495, 0.04207228223926254, 0.06347682207290616, 0.0307625521506582, 0.002133423088318003, 0.04711275248389159, 0.019888456811064055, 0.052539332902857235, 0.04639402783608862, 0.016661646210455468, 0.03816825297794171, 0.02929630582886083, 0.016568388357492428, 0.047330280632844994, 0.07837348165256636, 0.04629602702334523, 0.029311206457870345, 0.01626246914799724, 0.047050038884793005, 0.03269314034176724, 0.030051342278186764, 0.017683119612878988, 0.013646157707885971, 0.053244575059839656, 0.009327628367048289, 0.05496911930718592, 0.028575647356254712, 0.0403017401030021, 0.05533113470301032, 0.043256685470363924, 0.02180137425394995, 0.051628423389047384, 0.04536767576688102, 0.049819550809583495, 0.015369785084788288, 0.05523349351382681, 0.033361531261886866, 0.0450613477400371, 0.02887722903064319, 0.06859330859567438, 0.012195284445104855, 0.01818676901582096, 0.011385688691266944, 0.00418042965299849, 0.016395080335704342, 0.04958688115168895, 0.04273603537252971, 0.04051056943301644, 0.05760577068264995, 0.016722112162304775, 0.022727035119065216, 0.05431791228641357, 0.021864209989351884, 0.03203919543219464, 0.02490115461737982, 0.018861366835023676, 0.0072086763102561235, 0.0823489979707769, 0.03276933982436146, 0.05037423622395311, 0.004025174479465932, 0.023753517806263905, 0.03796281632302063, 0.07743694047842707, 0.06865085515060596, 0.09591390365468604, 0.029650714847126176, 0.024059357287894403, 0.02426592370362154, 0.022807962294401865, 0.023267191402348023, 0.04315733098025833, 0.033736859514777146, 0.046734967934233804, 0.023326617499281253, 0.026255966829402105, 0.021714917018211315, 0.024963880090841224, 0.009498297735782606, 0.044749252165534666, 0.031431957480630705, 0.021635816798412373, 0.018576003843918443, 0.0783368611176099, 0.039127528467880826, 0.09827198247824397, 0.054656487690018754, 0.017156079411506653, 0.03533338116747992, 0.02869939518028072, 0.027193605533934066, 0.0507770180036979, 0.030282071325927973, 0.03145386737638286, 0.005790281550226999, 0.09056271865431752, 0.008973497548140585, 0.010519164697533208, 0.02969956936846886, 0.05997385111238275, 0.012225910971340324, 0.013366355311258562, 0.059846985419946055, 0.05742929729499987, 0.03382374592391508, 0.00884615772935961, 0.034137948349650414, 0.05607360807646598, 0.024028405913018754, 0.0600880892681224, 0.10431931726634502, 0.08024444697158677, 0.02401209732384554, 0.07423718646168709, 0.030277270690671036, 0.0435018401726016, 0.041774276444422345, 0.03869671979919076, 0.04154453805780836, 0.03693808934518269, 0.03502015583217144, 0.039290770422667265, 0.00663375825388357, 0.038039514528853555, 0.0318187258339354, 0.03155740503487842, 0.021825960970350673, 0.04821601649746299, 0.023851898598617742, 0.06711564931486334, 0.02149454750386732, 0.025401850696653128, 0.03205288487619587, 0.040210154838860035, 0.026773032566000308, 0.03211992074336324, 0.06982812019331114, 0.006641396861856005, 0.050693564981754334, 0.03760768127228532, 0.012453043783482696, 0.07908956679914679, 0.009655800980648823, 0.022185338561290076, 0.03413435550672667, 0.08038918527641467, 0.012789448723196983, 0.013748629218233483, 0.024568587641364763, 0.014564593023221408, 0.05343466664531401, 0.04273602858717952, 0.022599550263424004, 0.019336731505713294, 0.00959892278271062, 0.031820171113525114, 0.010307778138667345, 0.02052272929410849, 0.06657739462597029, 0.01036837131583265, 0.10587482486984559, 0.012247428164950438, 0.03389307184677039, 0.049683674172099145, 0.015161188153017844, 0.05707580769168479, 0.06489002731229578, 0.038558834698051214, 0.032673724062208614, 0.040478118495749574, 0.0695060874734606, 0.017264309139656167, 0.02337773154223604, 0.11535805064652647, 0.04095642800842013, 0.0242481477824705, 0.06569658831826278, 0.028072445786425045, 0.02476906929431217, 0.03184848977252841, 0.01639074958594782, 0.036844828099544556, 0.032145498120891194, 0.05662203739796366, 0.024352570929165398, 0.01844285661354661, 0.025375603265794258, 0.11561189059700284, 0.019797047966026833, 0.057814874819346836, 0.015932813087212186, 0.004134388931561261, 0.04028949933126569, 0.04586728788646204, 0.02848673891276121, 0.020747924888772622, 0.04596561100333929, 0.021169790465916907, 0.05620621756783553, 0.010019331205902355, 0.021774592476763895, 0.031861276764954836, 0.032620669409100495, 0.03847106958606413, 0.03151001954185111, 0.041943265590816736, 0.007804105207989258, 0.0456985260492989, 0.01739558530971408, 0.03060635338936533, 0.03921731222154839, 0.06930272374302149, 0.006318025307596794, 0.017851752528388585, 0.06056549972189324, 0.07298617823315517, 0.041010799019464424, 0.022588649598349417, 0.019316290638276508, 0.059446921172950945, 0.02892686047458223, 0.042878568438546996, 0.06917237038058893, 0.04406649326639516, 0.006210028825859938, 0.030368469189852476, 0.039976287566657574, 0.05460506830630558, 0.06978797127625772, 0.027762684372386763, 0.040053063804017644, 0.0068782547771531555, 0.024839165354413644, 0.05780745164624282, 0.028000488844034926, 0.0653251243223037, 0.010876789123618176, 0.029089179621743302, 0.0045687001132007155, 0.007451268694629627, 0.06434759284768786, 0.14570227238748754, 0.12910979773317063, 0.08612505213490554, 0.1378471574613026, 0.09515515901148319, 0.08447438678038971, 0.09954851719417743, 0.07862087552036558, 0.1357940054897751, 0.0923175730609468, 0.19148734557841504, 0.1279478200844356, 0.20743563265672751, 0.064888507393854, 0.16264711027698858, 0.07146577803151948, 0.1041840852371284, 0.05058769316279462, 0.13418276980519295, 0.1164862508220332, 0.14983860829046794, 0.1553805973380804, 0.18483162272189343, 0.09860585563416992, 0.08395001491797821, 0.13086710843656743, 0.15166563168168068, 0.13125508118953022, 0.08231297454663686, 0.06764453343514885, 0.23849930507796152, 0.08755748027137347, 0.1576416931514229, 0.08975432560380016, 0.12446253853184835, 0.1821146463709218, 0.1495262650506837, 0.12137642556003161, 0.16383914702704974, 0.1354319527745247, 0.1361881121993065, 0.11752325589103357, 0.11038564424961805, 0.0784032354131341, 0.15025457739830017, 0.15882466467363493, 0.1668884019766535, 0.09749956535441534, 0.14245918712445668, 0.12126743926533631, 0.12318823619612626, 0.09723268396088056, 0.10657507300909076, 0.10598143629197564, 0.18249192541199072, 0.14062635547348432, 0.12213559768029622, 0.1356324055897338, 0.15191654036087648, 0.0864088154797043, 0.1072125363030604, 0.07473194705588476, 0.09667677379080228, 0.11327262754951205, 0.18604180349835328, 0.12489118267382894, 0.11586321996791021, 0.12498902742351804, 0.15191043354570866, 0.1846715970230954, 0.08476589220975127, 0.1822874556694712, 0.3391611964574882, 0.12205737616334643, 0.09432877799762146, 0.03793114570102521, 0.1577026934495994, 0.07141233661345073, 0.11289903973894459, 0.1876383421144315, 0.1535617842205933, 0.10156536754220724, 0.09557984729430505, 0.09012659705643143, 0.07674581184983253, 0.21455210793231214, 0.15990367106028966, 0.05686319552894149, 0.0918962231704167, 0.08485793548503093, 0.12420325673052243, 0.06345392151602677, 0.14450963852660997, 0.1239737897579159, 0.20090448882962975, 0.30103157247815815, 0.08667159173637629, 0.1268214112413781, 0.15236111650509493, 0.08833344613334962, 0.08186815412981169, 0.16577496672315256, 0.13095710932144097, 0.057344602553972175, 0.24730210272329195, 0.13676344204161847, 0.11258369058902774, 0.13038686849176884, 0.19098410329648427, 0.06759036598461014, 0.1274322827479669, 0.11184722225048713, 0.11263551030840192, 0.14945686448897633, 0.08627481838422162, 0.1905245315283537, 0.13945475619818481, 0.1382107436656952, 0.12433023777391229, 0.08652033949536936, 0.12109154941780226, 0.1435905628438507, 0.19017310467149529, 0.11747870328170912, 0.18967063591948577, 0.08652680593409709, 0.0833450738074524, 0.10491530849997487, 0.10498528581644807, 0.059130988482918055, 0.0805623677692243, 0.10864503229303019, 0.086083152597504, 0.17070254231137888, 0.14265780789511545, 0.14369508437812328, 0.18300253658422402, 0.1940756038363491, 0.25567647335784777, 0.10367048172546284, 0.09970793899680887, 0.09969843950654779, 0.10704343859106302, 0.09156140685081482, 0.12008682904498917, 0.14146391195910318, 0.1358190027198621, 0.09828112234494515, 0.12930814708982194, 0.11557356693914958, 0.1621994807251862, 0.11505944095551968, 0.0928520415244358, 0.08554566465318203, 0.13265086843499116, 0.11047901745353426, 0.07692868382270847, 0.18863527290523052, 0.09213627528931413, 0.13094120446060384, 0.10350828471460513, 0.15301630991910184, 0.14634191377886704, 0.1605667354805129, 0.22607337470565522, 0.0779368511534163, 0.09706851919846875, 0.1128290081396699, 0.19885675156755106, 0.148013905489019, 0.23401755413838796, 0.08804912638983556, 0.10862207745334931, 0.13620997459760734, 0.10816736399595227, 0.16353680539344037], [0.06040516868233681, 0.009421765771029251, 0.04578304097854665, 0.023510712531528304, 0.026519499652619873, 0.04890004764976246, 0.026079607096367648, 0.03232194436714053, 0.02127118904276618, 0.014838261463280236, 0.012170255832773234, 0.01682958871658359, 0.029767416084983518, 0.060334241416837485, 0.09347716226641621, 0.016339158872142434, 0.034660209968153916, 0.016125552655596818, 0.04266802241493549, 0.060433599299618175, 0.018671032673280154, 0.06089511167790208, 0.059671285562217236, 0.052040199150464365, 0.018137302116623948, 0.05070932395756245, 0.032456324834908755, 0.08691879561437027, 0.039369232819548676, 0.023846619596172656, 0.04306592892057129, 0.027785450918599963, 0.0309456921448665, 0.024883634843198315, 0.09811869463218109, 0.06438124818461281, 0.03415569882573826, 0.036381592242313285, 0.08947664193276848, 0.03481974033638835, 0.051010403516037126, 0.07117814025176422, 0.019319518768627728, 0.013368163607083261, 0.023175550159066916, 0.016528414163206304, 0.03974000470978873, 0.024588078559775437, 0.027175527664699724, 0.05020163727125951, 0.0425449666966285, 0.023863669484853745, 0.044615692725139, 0.0769346888576235, 0.043758628357733996, 0.07652983415339674, 0.030566089121358733, 0.019272252019228678, 0.050921186339110136, 0.04577492230704852, 0.055447615416986604, 0.01242275143574391, 0.03608001056792481, 0.0052654847552600715, 0.04399362199806741, 0.01967639765436096, 0.054348005314490626, 0.06264489064259188, 0.01435647954765175, 0.04743346884580595, 0.02170556510931679, 0.009642363442773265, 0.013755489207272018, 0.060681027094168324, 0.04354627403829779, 0.00974830226706607, 0.0409071901147919, 0.029462207640920366, 0.019655649749828235, 0.029888884031346867, 0.008748393555703973, 0.010725385060400834, 0.006644007525340254, 0.01109892622168575, 0.012715933694770294, 0.026433164553184594, 0.01497555963162865, 0.032213653570839336, 0.03377864370122552, 0.05673403638814177, 0.0918146904025759, 0.05382738235805716, 0.012635344938774194, 0.038608540780842304, 0.011238697650177138, 0.058900157654924054, 0.03487143452678408, 0.07177636386560542, 0.035579818300902843, 0.039988731898899586, 0.041967166986848624, 0.016905659277524267, 0.02080457577747958, 0.024996229247855287, 0.05821888814015048, 0.03649389996592488, 0.014187331793696752, 0.026396354028422917, 0.025657275026398044, 0.030407220324767486, 0.03395219938829541, 0.0313210611098579, 0.021598185246278132, 0.02216108263071094, 0.04214790157441582, 0.07865199313632079, 0.03960759199357458, 0.03063139133155346, 0.04116533197728651, 0.017583434336951802, 0.020395671915529028, 0.010370136355049908, 0.04540103254839778, 0.0267326478580279, 0.016689450879182135, 0.023687148599752357, 0.05500219449666994, 0.006687246745319239, 0.0034705361384632333, 0.0142790417386485, 0.004907477805058339, 0.050233535202486176, 0.031441996406231604, 0.031552092105682404, 0.025671444533924972, 0.04633216919111354, 0.006725519513046103, 0.03176744554990104, 0.05544745596125722, 0.11250917387327977, 0.034484635639403544, 0.0036557159785713467, 0.02766489051282406, 0.046413912304810116, 0.038340309102620394, 0.05490609697465386, 0.02319289860315621, 0.03769414698971169, 0.01270626881159842, 0.008796620432154408, 0.06939320638775826, 0.021577790179955106, 0.08188352294798408, 0.029313245455601385, 0.11095335414367062, 0.04376050789973565, 0.042162476506616385, 0.054450053588620255, 0.03434720854940159, 0.054116044725690565, 0.02777736447751522, 0.010508571917723333, 0.021355763343828063, 0.006555240301947508, 0.04725131272737469, 0.012118632040385689, 0.02941647098798837, 0.023077437388045446, 0.06769277727497475, 0.12674527961228574, 0.013895641463542623, 0.040569934461797984, 0.0595236566982099, 0.055351253266313245, 0.06417160121990101, 0.017003079942826713, 0.06314222288451024, 0.010786615212314894, 0.041763257035719495, 0.02390019841758268, 0.029609073153031722, 0.014998955519071646, 0.07697380640144859, 0.042409941620592556, 0.027847168767558675, 0.062375709015343866, 0.021995732128354054, 0.022465442906000783, 0.006195733365270176, 0.07799559871533088, 0.02223589281285448, 0.026029751735872457, 0.04399663130087512, 0.03975139052740165, 0.03762844105118087, 0.08619150785463196, 0.039729148149490356, 0.021759322046169212, 0.030308880244514773, 0.05610426768128361, 0.01806567087104278, 0.0362017058235194, 0.03812469102974449, 0.09995111237679209, 0.04531215803165521, 0.03823346358590892, 0.06508583894797734, 0.03464231360703707, 0.007539261115847954, 0.019091763400605748, 0.03196377626487187, 0.03114008224968399, 0.0742929077574185, 0.02609121174152408, 0.028626076078840663, 0.03416953754744359, 0.026910420640238693, 0.026823885372972915, 0.026558931018891077, 0.04069565003737807, 0.04050874417381627, 0.02146761814531471, 0.058338086386876445, 0.022849108657932708, 0.03805487995435085, 0.038591370452195406, 0.045860577175127606, 0.021111165040305684, 0.018288829164313417, 0.054807404056191444, 0.04816949613658445, 0.023256175386320268, 0.0013201285764807835, 0.03509950032457709, 0.04289296355896762, 0.06645448479269232, 0.04018227044226868, 0.0266358073401664, 0.04462597253067153, 0.004815239026876432, 0.013802504050545394, 0.04498039511963725, 0.011161024050254906, 0.044894794534359656, 0.0448796123133174, 0.0399377196361976, 0.08612161874771118, 0.0050310415764605355, 0.035738232479031594, 0.05542425684896963, 0.01699976869193571, 0.04584112357614296, 0.025519189757428, 0.04491993086412549, 0.04837734159082174, 0.031261400918343236, 0.022404875173898678, 0.03200728053759251, 0.023788766004145145, 0.025007830500336628, 0.0152094557415694, 0.03174087411857077, 0.07277630735188723, 0.01783785443486912, 0.06948619961206402, 0.015528782803033079, 0.06576385828001158, 0.04848362731614283, 0.024958443329004303, 0.005555819287630064, 0.03228678268247417, 0.07087879774293729, 0.07468244792627436, 0.05162928852119616, 0.012582241091877222, 0.035811124103409905, 0.047985548685703955, 0.014624260000086256, 0.0162923111181174, 0.02920595889112779, 0.01662520209460386, 0.01025339016424758, 0.014228076973397816, 0.019795641702200686, 0.042375594177948575, 0.021740267086508017, 0.03472543753949659, 0.06267047141279493, 0.030541312415152788, 0.026345901557111313, 0.03792396680052791, 0.03414938845006483, 0.011667187425440975, 0.025957306248268912, 0.005714745759697897, 0.020207878867430345, 0.008536174095102718, 0.03839483617671898, 0.04395483693640147, 0.08015585743955203, 0.02978313434869051, 0.06364408095500299, 0.011272784705007715, 0.018163644542385424, 0.08230122910546404, 0.015944763785228133, 0.017127426574006677, 0.019288063581500734, 0.05562737969947713, 0.05101746028023107, 0.03917952799903495, 0.022018654737621546, 0.016369185743055174, 0.039452794407095225, 0.06865531312567846, 0.09947134062115635, 0.0644332171816911, 0.006960690844737525, 0.003013928296110992, 0.01771568081208638, 0.009091539740828531, 0.05411380895280412, 0.033412733514394076, 0.04064959447298731, 0.03609844297170639, 0.02451794178757284, 0.08548850486321108, 0.02947836695238948, 0.06357596282448087, 0.03278388422248619, 0.05050945468246937, 0.06858008394816092, 0.010472219404099243, 0.043727178259619644, 0.01081262091507337, 0.03607316414958664, 0.03730067810309785, 0.06059661055249827, 0.023500622715801, 0.03368785571573036, 0.015976622700691223, 0.019990484729143124, 0.020215771926034774, 0.03619821476084845, 0.0034685546041665865, 0.07684094245944705, 0.02187555339852614, 0.05136722133361867, 0.03590511816686817, 0.029598803525524478, 0.03947371364172016, 0.024206556978502443, 0.1365624192569937, 0.09062916758869376, 0.14227986388972827, 0.06140357189412628, 0.16753774641879968, 0.15407254467053072, 0.12650268977241858, 0.19546600351376192, 0.06372196320444345, 0.1083600272291473, 0.12506769677358015, 0.07742220948317222, 0.06586328401629414, 0.18360057020825998, 0.1400868794215577, 0.17469656227954797, 0.08942379084016595, 0.1928214675613812, 0.15708738432398864, 0.18506482163710253, 0.15091815750513757, 0.10629700935844864, 0.10318431816995144, 0.14821422259722436, 0.10999230428465775, 0.12415611211742673, 0.10780248178967408, 0.19801539528582776, 0.18390249115015778, 0.11137089066739593, 0.10287377304796662, 0.10259027433182512, 0.13274019078484603, 0.11117811886859791, 0.14428610195006641, 0.1439563746431044, 0.1453211528382131, 0.09567706100642681, 0.18949364684522152, 0.10026768288974251, 0.11208117433956691, 0.19995019717940263, 0.08585876785218716, 0.11761989284838949, 0.08250808050589901, 0.10979814827442169, 0.14319828817886965, 0.12709635363093444, 0.10094780568033457, 0.10076994129589625, 0.17993911382343086, 0.09071314986795187, 0.10508166493049689, 0.23911546915769577, 0.16089894622564316, 0.12325705321771757, 0.09780381367142711, 0.1061575161293149, 0.1784482773925577, 0.11772015318274498, 0.16114069468208722, 0.09372688350932938, 0.13907369093171187, 0.13570050336420536, 0.12189705190914017, 0.1148212615932737, 0.10875925687806946, 0.18109906943781034, 0.10697634504841906, 0.13531162137431757, 0.23738379350730351, 0.07905742459531341, 0.11517424908067499, 0.1296814363449812, 0.10541367211512156, 0.09258724323340825, 0.05541580569531236, 0.16493827876235756, 0.1340433715709618, 0.1622777429542371, 0.1870857160538435, 0.12990075243370874, 0.09909346446927104, 0.06321367262197392, 0.12298766124461379, 0.15753407749746526, 0.1401459662509816, 0.10723876168153115, 0.22984407522848674, 0.13625786559922354, 0.22240421016301426, 0.12234791128763131, 0.08928842988929578, 0.11952064585472856, 0.0698129345795938, 0.11063772000904594, 0.13921209850481578, 0.1300677534724985, 0.12251265959015914, 0.10713711713573762, 0.18983490924750054, 0.09273417320634637, 0.16289139645440237, 0.09486092587134667, 0.12801335299653666, 0.09511507116258144, 0.10911882615515164, 0.1024551847949624, 0.1351505100194897, 0.12738926362778458, 0.1216721311211586, 0.1267256156674453, 0.09919386729598045, 0.07664233525948864, 0.179495759042246, 0.09851497943912234, 0.08759531538401331, 0.09933307554040637, 0.13912287114986352, 0.12815592677465507, 0.1460310226040227, 0.08244756196758576, 0.10171301676226513, 0.1858692384724106, 0.22918090224266052, 0.11577669318233218, 0.15120620919125421, 0.10393072026116507, 0.16505460680595466, 0.11524321537997041, 0.13507393055728503, 0.12610364332795143, 0.11449925601482391, 0.10841386898287705, 0.19262995783771786, 0.12736749622438634, 0.09048435464501381, 0.106031953224114, 0.1935465500823089, 0.19836276450327464, 0.12623930961958, 0.11915796888726098, 0.11371390601353985, 0.12641152180731297, 0.09439824641283069, 0.1771466029541833, 0.147426714854581, 0.10803027278078453, 0.09109534150255577, 0.12038047185965947, 0.13555360053266796, 0.09942549879529647, 0.10215048185948815, 0.08907436566161257, 0.22223100731415407, 0.1902632684047733, 0.09652794391981193, 0.1764535472861358, 0.12576238092567238, 0.1286788737135274, 0.13895141892135143, 0.1069728166663221, 0.10549601233963456, 0.09772386189017977, 0.1450685342507703, 0.06074462618146624, 0.13219316942351206, 0.11215991832848106, 0.1121555824897119, 0.1894237305969, 0.11071687790432147, 0.12287737216268267, 0.14541986611272606, 0.11160001837249313, 0.17727389612368175, 0.14182040068720067], [0.03261959732377103, 0.015498659240880182, 0.042307387837874036, 0.009738624661362596, 0.02900545857846737, 0.033043705459151945, 0.03574011541370835, 0.031046281568706036, 0.027109560490186726, 0.026896697269486528, 0.037909924518316984, 0.020123418220984082, 0.03276822024158069, 0.015691264798598628, 0.04885377495416573, 0.10749274412436144, 0.03018166171386838, 0.012476033398083277, 0.007043891960555422, 0.052750913692372184, 0.011737560836731322, 0.05158231693453022, 0.03569977989952479, 0.009878414749566997, 0.035358921225581846, 0.051588878368160555, 0.0351901627810938, 0.043373023691986284, 0.04162756699536528, 0.03196806799886482, 0.04944826662540436, 0.001540939138586899, 0.04976577351668051, 0.018305904498057704, 0.04913304300446596, 0.06749442791832344, 0.021778953760596256, 0.011556253735242146, 0.04738891962915659, 0.02927591585155044, 0.03270106902346015, 0.07077216596475669, 0.06415014594261136, 0.03306875018669026, 0.04188458248972893, 0.09555314015597105, 0.034299229338232956, 0.013303212538760687, 0.033639974892139435, 0.04518787416496447, 0.03254924002768738, 0.06621391698718071, 0.007029554939695767, 0.020809306862897108, 0.09894443782312529, 0.05687519542074629, 0.004334071185439825, 0.04445137529234801, 0.02054538727471871, 0.02925021294504404, 0.06146559678018093, 0.05640380017991577, 0.018956110679677556, 0.03694065081487809, 0.04608075500332883, 0.034088323691061566, 0.013522677905192333, 0.035197002414081774, 0.03363231423177889, 0.042911172046193054, 0.008136751911869007, 0.05164206533559731, 0.07785343884357385, 0.028031757434031794, 0.1059147295142923, 0.031632593500294855, 0.0363066785835794, 0.011507954764445978, 0.03720317940626826, 0.07244402875325509, 0.04185151747827019, 0.013233811977053327, 0.02016289029935641, 0.01784218518462564, 0.012236361258796282, 0.02197946255494441, 0.05084860684084041, 0.05441601827208485, 0.03348233763660703, 0.041722867238734446, 0.015185805403494408, 0.028720633326364414, 0.0185740920715034, 0.024912470885153328, 0.03700781221102391, 0.015266233855592353, 0.047354287201804776, 0.03526062525010534, 0.02109870035201311, 0.038552945014089346, 0.07155568392149039, 0.0505523109542472, 0.07942742295563221, 0.04693773116118141, 0.019541409897751043, 0.0349583786113986, 0.05894373995917184, 0.021245940754722272, 0.022304285750059143, 0.025632776519549743, 0.044058584940752814, 0.07432519245360579, 0.049778299273124764, 0.03114437059100185, 0.02667930313119931, 0.03677574644929596, 0.05849321306283985, 0.02471863039370094, 0.04668314142950943, 0.009647037700882979, 0.025184495574129478, 0.025424832677734748, 0.05440548062324524, 0.01438591948577336, 0.055506020318716764, 0.014717789267056754, 0.012355675704644194, 0.011446698319299944, 0.03580557029428227, 0.04450239094772509, 0.014523943686591727, 0.013359829500716711, 0.04422576239864741, 0.016359396179073622, 0.024984337921653475, 0.02633207301343126, 0.02526256611703762, 0.023495118100462214, 0.036787597063396654, 0.02832871998128082, 0.030804950411298444, 0.054052795083927255, 0.06911202147603035, 0.024343972194141576, 0.01984928159176239, 0.028926707804203033, 0.023434370556580167, 0.038039382214524915, 0.05393290812415736, 0.06077079049178532, 0.020135336688586643, 0.032438068850232024, 0.03181871226323502, 0.023559283764500703, 0.04087086474256856, 0.03975022344716957, 0.10173641264970813, 0.020484198683074543, 0.04627047339454293, 0.02279861717085753, 0.025462686450087597, 0.04496247500979474, 0.08251593794141497, 0.0027900058027756003, 0.03703917070691075, 0.01698547026275524, 0.008438132570258208, 0.02958899869450501, 0.06937456024544579, 0.013156112932067896, 0.01789506002595382, 0.03629353196759309, 0.03879669175616332, 0.02133210452406534, 0.02339975000359118, 0.016758544403793554, 0.021982639795169234, 0.04401992880074041, 0.015907361238662685, 0.03818254292543445, 0.023862113943323493, 0.022944419079327157, 0.04442159099770444, 0.048824384209832976, 0.03543619279350553, 0.0338922134999718, 0.019325769772487025, 0.018553479873974408, 0.022874021071142385, 0.05722303622003112, 0.11157033925077744, 0.06749277907822814, 0.04008342485342707, 0.01896689090478633, 0.03155223459803632, 0.012425339198671281, 0.04745079863018223, 0.0492495406818177, 0.07424000916736466, 0.028683337649064403, 0.0797601290313261, 0.011156296357512474, 0.05881707782724074, 0.019561857550538013, 0.07544428668916225, 0.017308234104088376, 0.020191890886053443, 0.030401825971369232, 0.022518300783953497, 0.0313895354712648, 0.01453997238006975, 0.034089358456965, 0.06022922455200127, 0.024004353542945216, 0.0501762397055115, 0.03722786790292178, 0.07666087283619813, 0.019828952682603682, 0.05658927094191313, 0.11257203335740737, 0.03951261405433927, 0.023520162828000526, 0.03524266103548663, 0.03997685753607324, 0.02467439160682261, 0.036625084533755264, 0.022929087580580796, 0.031489554925688674, 0.04122821181746466, 0.09080856546227421, 0.07950756472668477, 0.009162890242545732, 0.03561047790572047, 0.06298328962709222, 0.04841542776141848, 0.015776663519708172, 0.07198514909084354, 0.029410374350845814, 0.01295764313545078, 0.03449331410229206, 0.040551902393677404, 0.023361758827897053, 0.019572849817840115, 0.0571332863931145, 0.04664412566593715, 0.07029514906129666, 0.03134074880342398, 0.1162157053393977, 0.05993930010923317, 0.023290780672271336, 0.11970150257859911, 0.020603208636332835, 0.041468555706420114, 0.03192163584753871, 0.007271546820577766, 0.04909460399565952, 0.10009523321475301, 0.011458883960066097, 0.01733242387750319, 0.0003604744852054864, 0.019384610632966672, 0.053130659208233864, 0.0044023729445013616, 0.020891109348407814, 0.024276401980647018, 0.021534184126981666, 0.03528046561405063, 0.05339736757533891, 0.03002538831372346, 0.030005866861236945, 0.04113678261637688, 0.024327224253543785, 0.0716814436018467, 0.012826069258153439, 0.02810140566102096, 0.01906415550703449, 0.018467880985034362, 0.019986954650708606, 0.1104880894667336, 0.054700117491717846, 0.06426928312118564, 0.028329892150525535, 0.012506768489921731, 0.03447641179497753, 0.03692761276449476, 0.04716488093669925, 0.04304342530667782, 0.04863450636288949, 0.03868845184998853, 0.03462560807487794, 0.03479329782671162, 0.03671700906540666, 0.04284333550770368, 0.035724709276109934, 0.022735459131321738, 0.058336084708571434, 0.010067618302335697, 0.05122363314564739, 0.018955778197518418, 0.03648933003257428, 0.029535245150327682, 0.017037493542635014, 0.01569278132436531, 0.010888617685330766, 0.07025678469134228, 0.06009779231888907, 0.028933879919350147, 0.04657652322202921, 0.08070326556584664, 0.03893424437514373, 0.10200038991336312, 0.033791342484099526, 0.11291125336928026, 0.035298402687268596, 0.04453149331467492, 0.03287542198917695, 0.023162644423012222, 0.0700295636696475, 0.027792670531198382, 0.015099265047215989, 0.016035083581560423, 0.06400091573596, 0.04231177117409451, 0.015167647806395377, 0.09095009429646389, 0.012116394571161695, 0.0679063190306936, 0.02651438519491681, 0.023919243199218596, 0.039224694682551284, 0.07180178178740398, 0.01454277812237186, 0.10599091542618615, 0.026154150953516364, 0.033026511381779394, 0.04231203580275178, 0.019065422671181814, 0.044961168829883845, 0.04965697042644024, 0.059635967814496586, 0.006968230641047869, 0.02212444513237902, 0.003905514404842896, 0.06712374423763581, 0.02275341486425272, 0.03743264977154987, 0.02793583463478301, 0.02631416986696422, 0.0550076363475195, 0.04003763391769358, 0.019018357785950814, 0.022047356768910373, 0.2153664720909936, 0.08339521754533052, 0.17858530075422355, 0.11172220217330114, 0.09303024517638342, 0.11220451843525682, 0.16929896548390388, 0.2029971315392426, 0.11979828881365912, 0.11116991538022246, 0.13944449674870285, 0.10798998137137719, 0.15780964413923876, 0.099890709189432, 0.23261985342417443, 0.19442241665508064, 0.11528833795871053, 0.10446066968142986, 0.1044412160824452, 0.11889437160321645, 0.12990352085658483, 0.11923361197113991, 0.19102569749312742, 0.08848824711250407, 0.11437672616115638, 0.1485556342772075, 0.12646850517817906, 0.07698588432478053, 0.19047692551144532, 0.22328427008220128, 0.10079676378518343, 0.10675700860364096, 0.08571597015751259, 0.07476482207753829, 0.09354817774146795, 0.17527058933462414, 0.21352817144777092, 0.19622626129005635, 0.1367411318102053, 0.15942552100334847, 0.171216166179095, 0.12052136287093163, 0.14765512331255845, 0.2400734248970236, 0.11113390552678279, 0.23130151416574204, 0.13336669573826448, 0.15008813275822572, 0.13414300765310014, 0.17794930988124438, 0.17258677977536405, 0.18966883101633616, 0.11534293288631098, 0.16248260624706745, 0.17378176136740617, 0.1498823602284704, 0.0901322899652379, 0.17032116491879734, 0.12810718081891537, 0.092407635013972, 0.16429595037230424, 0.17803758728717053, 0.15227054565080575, 0.11663323507777282, 0.1540512658123459, 0.14841656173978532, 0.1361706738493272, 0.11142615055931465, 0.1377721657710416, 0.1367489349629198, 0.1800754586500781, 0.23507848435214587, 0.21277061424085073, 0.12082979774900846, 0.14738335646688938, 0.0877842806013567, 0.09922366855399949, 0.09295842224465949, 0.16419612430036068, 0.1667207631149462, 0.21204300756965364, 0.06233233027160168, 0.09710549257163491, 0.11908555563007082, 0.09655830836189644, 0.10274745696889502, 0.13360019320888178, 0.07113420510930674, 0.11900177012596812, 0.2642929452870573, 0.08618751806872231, 0.13076919583337648, 0.10049261046307427, 0.17112402112356254, 0.15702566477869237, 0.1230525156216962, 0.17697753916893685, 0.13470978795417718, 0.13990264359329427, 0.1768113523721695, 0.16643835684018476, 0.15634039869265898, 0.1967657780540841, 0.1077358496508428, 0.07216221958931003, 0.15813511024628366, 0.09863974845835141, 0.13830866983958653, 0.11934554310781614, 0.10874867851712874, 0.1491831706038543, 0.2646901054041726, 0.24025277527315275, 0.10763048673314707, 0.1666025487439973, 0.09471835209322826, 0.14514535798558167, 0.13467459912811006, 0.14148232739950928, 0.14133617095649242, 0.11298309665705476, 0.10520017107150384, 0.13133905668343815, 0.12044831179082394, 0.1408079992979765, 0.14350091479718685, 0.07137948194784777, 0.06628578741635595, 0.1939331657652344, 0.1521833674716098, 0.08975700581712381, 0.09545786705400262, 0.13643497680979116, 0.09873557117368494, 0.24583999546510832, 0.044466282706707716, 0.20800910331308842, 0.13773484634501593, 0.14297659721757683, 0.15905206889978477, 0.07707647553512029, 0.20772945189050265, 0.1534207303609167, 0.13632482343486377, 0.16257190145552158, 0.12026949067200933, 0.1628966076033456, 0.08066983414547783, 0.20395321452191897, 0.1346988228282758, 0.09675487317144871, 0.1813410757375615, 0.0885209117883018, 0.18556022005421774, 0.1314766907266208, 0.08889018411615066, 0.23331966730100767, 0.17157699753131184, 0.1805577613413334, 0.07161895731197936, 0.08662031484501702, 0.12386192647474152, 0.19550450359072002, 0.1517345436981746, 0.0716001618919628, 0.12172652248825346, 0.13959059890891823, 0.19358258029179914, 0.10947818508637802, 0.09884081195507731, 0.2041757061545338, 0.07352336083671876, 0.1629012759242739, 0.13940563026283467, 0.13026209947253975, 0.06108567823788949], [0.004158079557652984, 0.04876645428261586, 0.029483008131917034, 0.06267085817775556, 0.02355241699011198, 0.008879741820107614, 0.028385822095775178, 0.03738331688301904, 0.04851871436195714, 0.028735187902514423, 0.1454000257487808, 0.05491356425253408, 0.02433212666905352, 0.043359816007848294, 0.012346380623057485, 0.027674549458814517, 0.010000154109937804, 0.013400955508196992, 0.05827960345361914, 0.021518837361197387, 0.015898606440584575, 0.04472490293639047, 0.04412046054910336, 0.031388195364602973, 0.0457042460995061, 0.04259198238807065, 0.019301284836339097, 0.02086781015220497, 0.06706505774387292, 0.04177310597151518, 0.01707151868114514, 0.014835002798853176, 0.036191151211304326, 0.03528764112187283, 0.020555283707965697, 0.031724148230361085, 0.03714691188984683, 0.01155169737259192, 0.023906593610133444, 0.04361145750486425, 0.061727714857884815, 0.06118648818561009, 0.030274071398058107, 0.03437455351065312, 0.022893659570919614, 0.03723601371582065, 0.039900878577360084, 0.03185178406004395, 0.009744995257018932, 0.004423810834331172, 0.020589100196957588, 0.05977783591619559, 0.009483777934552302, 0.07992209534027747, 0.030411152435200553, 0.010832898934105677, 0.015223425081265824, 0.05365186570478337, 0.03129990438797644, 0.01773160433263651, 0.014824650050806147, 0.01960631855763495, 0.04718416150925415, 0.05542388026203428, 0.048926038933651786, 0.023008579654353004, 0.0640803382598928, 0.012719767417625656, 0.012766189390926488, 0.005387703755072185, 0.011652584503670889, 0.03463225093271051, 0.03210895561746188, 0.01234109144258712, 0.008588847072262849, 0.07894294216696705, 0.023333458828606775, 0.036020699821944745, 0.05648831510916352, 0.008930525077240807, 0.03033544828316995, 0.024245185977114097, 0.035545233371002335, 0.01603512598999909, 0.014080144464969635, 0.07827619330159255, 0.08713974697249276, 0.011563358845056167, 0.05197001148813537, 0.03831559685724122, 0.03351304813155106, 0.08633087894746236, 0.014731634774112275, 0.02650957607797214, 0.02848250824691994, 0.010496971513410764, 0.027279170496123176, 0.01904540928080678, 0.03666718423898731, 0.0535465774259397, 0.02745724522641727, 0.011609904650997902, 0.02929538980658565, 0.032042778097093105, 0.006268145774291562, 0.002678771860831018, 0.01997434238104948, 0.014679548729743277, 0.0599673507469041, 0.009167611149937978, 0.053470038675836155, 0.037037925595151525, 0.02971907046490482, 0.05775219853967428, 0.0926840091124177, 0.03616607594969017, 0.0115448305982032, 0.035616710249866755, 0.07495954805719, 0.01154319108796439, 0.05769073683768511, 0.012100083437482161, 0.02261276134023709, 0.02634391514584422, 0.044960049247103076, 0.06069886577980859, 0.04249971519623484, 0.048635907537703, 0.042768286141966066, 0.02899233571120671, 0.0452516700274178, 0.036229495225208144, 0.00776946684345603, 0.06517745474619524, 0.012897682692190366, 0.07888819117631231, 0.05762169589953763, 0.025559343763494065, 0.00922530613440488, 0.011923314038930195, 0.030157074997467653, 0.0310939927585423, 0.02537187810854188, 0.03314315155148506, 0.01069211564026773, 0.03615593524383647, 0.013372505383033837, 0.09793939853885344, 0.02058636230815734, 0.033597678411751986, 0.034325237585497756, 0.06999447662383318, 0.04149069291140352, 0.02809155672522528, 0.018513349616633992, 0.017481182502316575, 0.04246339660936168, 0.025340624785582935, 0.042527073728186746, 0.07327530200460128, 0.027054904494434595, 0.0688762916252017, 0.021932178842169896, 0.0273434430294271, 0.056360224661018164, 0.022254423604213765, 0.027429985082043067, 0.016206970072484443, 0.011960701318457723, 0.052624149780188284, 0.01971583241330726, 0.05043112799259169, 0.03586643488545503, 0.019964128732681274, 0.02873606321268848, 0.012886842247098684, 0.01564982666500977, 0.012275927483902445, 0.012204092677815684, 0.04197476997173258, 0.034844574718070884, 0.05213241884484887, 0.03122785414702126, 0.04545129502990416, 0.02505718544125557, 0.03908524555819375, 0.21671930806977407, 0.03157335739316685, 0.015620235752846514, 0.013924915160584663, 0.02949924547491329, 0.020588754144098078, 0.056361595301755836, 0.025210902460717728, 0.033122602118445296, 0.006635304889641702, 0.03841122279741934, 0.06728899465607745, 0.03347062612218516, 0.011090630282914, 0.0182609244116715, 0.04682400529938085, 0.035340173303016593, 0.024631192674860358, 0.04340943727376206, 0.08032431732863188, 0.03862518863752484, 0.018825557149414505, 0.06915113223450524, 0.017720922495105436, 0.03332526017246502, 0.029581008944660425, 0.07395296849842582, 0.05388804338872433, 0.008877548455659832, 0.004196056314477963, 0.018424213863909245, 0.047545494977384806, 0.035357944135154994, 0.08555495379758732, 0.022432121747572507, 0.016083814270262207, 0.07045558866645608, 0.010838209318795373, 0.062151073212070126, 0.009117229924803334, 0.04712374475119369, 0.03300952086491244, 0.05214644755635943, 0.062387495168617794, 0.03486031333782843, 0.022434747678094676, 0.06001601527844157, 0.02596399321087769, 0.04634771442839077, 0.017168744267629724, 0.012107181761945997, 0.037973286118358374, 0.05559879980449166, 0.022734158040423478, 0.03374923938619239, 0.0453156287382756, 0.041795850465340276, 0.02296426792496017, 0.016163062071427703, 0.029793753421732357, 0.020552306635571376, 0.035552415664174726, 0.018651874237028614, 0.017609965056180954, 0.021664971751826148, 0.07134288855429206, 0.012300848378799856, 0.003455927067469539, 0.07342142452086721, 0.006387543340679258, 0.020659827294626405, 0.038255923095026186, 0.04637285075815661, 0.04239061355058636, 0.005398361843877605, 0.038286039871828895, 0.032050353940576315, 0.06502642642174448, 0.06422283061380897, 0.03569800213777593, 0.004124571378010192, 0.06558328654084887, 0.06675182562321424, 0.04938666243106127, 0.03277804542865072, 0.04306631229285683, 0.03500059027490871, 0.01543626794591546, 0.0842370352308665, 0.008163487887941301, 0.033886761471096954, 0.004944076287626688, 0.03768566530197859, 0.045873740754489384, 0.04551611887291074, 0.03724314851154174, 0.03154783769111548, 0.00837138677681131, 0.030554964539727995, 0.028175296428214227, 0.04411302041262388, 0.01660724636167288, 0.04759425789649997, 0.0814546752454979, 0.039454629844320674, 0.036350274458527565, 0.016717179212719202, 0.022821694146841764, 0.046503628204975805, 0.04060495026143534, 0.05877194167780025, 0.03428541775792837, 0.051910012029111385, 0.013686272698188466, 0.053361459502152035, 0.009491197714981223, 0.04957548515605075, 0.0414999379510326, 0.036483396243836196, 0.03832005822498884, 0.0878122498148254, 0.07066141547901289, 0.013183757296896406, 0.09179759810545615, 0.02055985533765384, 0.01956220529973507, 0.012581642284723265, 0.05225287916670952, 0.008460107775005912, 0.02603726481486644, 0.05020253633015922, 0.03761117572763136, 0.031845463506345234, 0.02070127730257809, 0.04238693928346038, 0.06294945787106242, 0.030794484008635794, 0.03070999961346388, 0.03920457611924835, 0.015376180277339049, 0.020269369407157813, 0.05391706433147192, 0.042852916422166994, 0.020521753900019184, 0.006100304200247462, 0.04113314566867692, 0.056502893434039185, 0.018523183285391757, 0.06434514333627053, 0.0056588611914776266, 0.023605788858341317, 0.060399645407285006, 0.05548105701538069, 0.03528264710413558, 0.02044692336182509, 0.023586528641836982, 0.05320208519697189, 0.03619950058470879, 0.003949392295908183, 0.012135233247785695, 0.03332007955759764, 0.02511158868271325, 0.04171279438638261, 0.04964948957785964, 0.03620000948597278, 0.05042869883722492, 0.14139217723693165, 0.06371432968548366, 0.09590044151991606, 0.16503193016563142, 0.18152413091489247, 0.09082985110580921, 0.09104188651378665, 0.0580017501488328, 0.10445134661027364, 0.10153938643634319, 0.4064387306571007, 0.11403988780719893, 0.07124339496450764, 0.11493391197706972, 0.07441289310476609, 0.09874110801943711, 0.1280277515096324, 0.08282161118196589, 0.1592347983803068, 0.1090100502063121, 0.16769762283989362, 0.20831958736692155, 0.10064167103597096, 0.09972682262637786, 0.1365970109722444, 0.08323338694338288, 0.13096229332898343, 0.12441099701183182, 0.1440553864730256, 0.14446561517460005, 0.1593749972858599, 0.09873599865074668, 0.13770372872906073, 0.12783635035157204, 0.14898855318980558, 0.08827775197901896, 0.0920904063220535, 0.18441296661538736, 0.09031193889677525, 0.14290305759225572, 0.16984184778162412, 0.1560103049767869, 0.16317969241312572, 0.1690563349319356, 0.0957401172657098, 0.07499745780868189, 0.10890219027974776, 0.14220356941223145, 0.1964196709117719, 0.1648988558777741, 0.08333089242556266, 0.13250121075127805, 0.12734988145530224, 0.18006268862102712, 0.05724790452846459, 0.06319918589932577, 0.14353325377617562, 0.1209298273814576, 0.2104979833321912, 0.1196068198020969, 0.10475999183420624, 0.13429833788956913, 0.1586618705519608, 0.09408103807696275, 0.10844024363905191, 0.09564873895474843, 0.30435897250260624, 0.11162639981401817, 0.06899254502994673, 0.13352704713387148, 0.08850082036639963, 0.11985428152339798, 0.08151498343795538, 0.09688486691032137, 0.06822639756969043, 0.23960759703602108, 0.1865549659622567, 0.0776531013793179, 0.17987507368837083, 0.06188406289688178, 0.11241668276488781, 0.14165520455156053, 0.14134796389511653, 0.13548208294170244, 0.10703577114535229, 0.1313474705176694, 0.18157249689102173, 0.13583720102906227, 0.160713665453451, 0.08852070822779622, 0.09866287971713714, 0.22308045173329966, 0.15526604705623218, 0.17978195154241153, 0.08632363219346319, 0.09734654213700976, 0.12854987063578197, 0.1272602876914399, 0.23143665120005608, 0.0903642743027636, 0.10417478930737291, 0.0916853209159204, 0.13759436245475495, 0.12377421903823103, 0.12181186862289906, 0.1206805200449058, 0.0905769339629582, 0.09435102716088295, 0.1362046684537615, 0.10721769316920213, 0.12664233227925642, 0.12171573378145695, 0.1524010415055922, 0.1479852305991309, 0.1365727601306779, 0.09411652545843806, 0.07891007393066372, 0.07592637903456177, 0.14829613534467562, 0.10010195749678782, 0.142904523227896, 0.1112937955185771, 0.14973035481359276, 0.12087250474308218, 0.10638913405793053, 0.2026682998985052, 0.12820925962712082, 0.15996596057500156, 0.17347210512629577, 0.1477196519928319, 0.15476006349282606, 0.20724736633045332, 0.08867274078407458, 0.23347670744572366, 0.15126898725117954, 0.15949846351785318, 0.1413088259952409, 0.14503395610621997, 0.15434157023472445, 0.08469375715191875, 0.14168852062097617, 0.13582532666623592, 0.12122925131448678, 0.13390098778264864, 0.08581502948488508, 0.12250233228717532, 0.12368032336235046, 0.24488627378429684, 0.17245640605688095, 0.10494101819183145, 0.15320844389498234, 0.17923989705741405, 0.09165769775531121, 0.1101370154480849, 0.14406233467161655, 0.09336983838251658, 0.163687100900071, 0.12803912375654491, 0.12062576226890087, 0.08297719247639179, 0.18432984607560293, 0.14847357225205216, 0.13382332266441413, 0.05260467243247798, 0.1325089324797903, 0.08653977952365365, 0.10922828063900981, 0.06423475925943681, 0.13393141329288483, 0.14131885474281652, 0.20659296001706803, 0.12142198240118367, 0.09426536890012877, 0.10440177284181118, 0.10592220018484763, 0.09008566782410656], [0.03723004939300673, 0.019256197880687456, 0.027984546663771783, 0.02272423785845084, 0.035789590794593096, 0.016505978402814696, 0.04969049684171166, 0.009374568571469613, 0.08352684655359813, 0.012985655605526907, 0.0114719101360866, 0.03517009171524218, 0.05275656249640243, 0.03917722097997155, 0.02347706228361598, 0.027448510784389715, 0.054092903288879564, 0.07094529417476483, 0.025534399119871, 0.01798498966465039, 0.046566843919988186, 0.04743114486336708, 0.008618169114924967, 0.02343055888611291, 0.05190100786941392, 0.03563782965232219, 0.021008390733706098, 0.020780672685110142, 0.04946875838296754, 0.011545770369204027, 0.04639600915834308, 0.03818629522408758, 0.050166835210153034, 0.03455325249316437, 0.013995802562151636, 0.02992206100108368, 0.01942289018604372, 0.04480434242369873, 0.06295435010854687, 0.02865961945748755, 0.07963485789618321, 0.04967722808942199, 0.06394366095108645, 0.015250705581690584, 0.04745549748518637, 0.014936474318216954, 0.04812236170151404, 0.05794427823275328, 0.047151042214993916, 0.020989099983125925, 0.018030254735744426, 0.02302157529629767, 0.04103544680401683, 0.015767717035487294, 0.007856003807059355, 0.037225940863468816, 0.04695582090477858, 0.038975998027516265, 0.06908133133713688, 0.04733603460980313, 0.07322574859218937, 0.0469872879662684, 0.01523078209720552, 0.009881206921168735, 0.027482966792636683, 0.06799821981361934, 0.03783704646463905, 0.09245564815189157, 0.0674920394750578, 0.07584072077380759, 0.03440912486985326, 0.04806185673390116, 0.018295539875647852, 0.05918585482452597, 0.007820531692621964, 0.05650896632245608, 0.05395051610789128, 0.022827225903581296, 0.08708814438432455, 0.07863844279199839, 0.05558253871276975, 0.03314694116956421, 0.03949081611686519, 0.02642251324972936, 0.035978067466723065, 0.0118271724121379, 0.011246707756072283, 0.02901825574891908, 0.0483027095241206, 0.052615003128136904, 0.02121165268389242, 0.052053535756255896, 0.03915672243705817, 0.06238622630813292, 0.008836521683926029, 0.0767567769757339, 0.02305371919646859, 0.00753160469633128, 0.014536036876961589, 0.02182308228553406, 0.021155956833224212, 0.028117049285875897, 0.01815696606146438, 0.013187997292594185, 0.043478386609682014, 0.014307513068030988, 0.04541480341660125, 0.008028744403938097, 0.06956832949072123, 0.027977683282058154, 0.03481415260050978, 0.0357800505922309, 0.023150127148255706, 0.022901466116309166, 0.02945969027600118, 0.04126747524631875, 0.04040396140356149, 0.021611952721806507, 0.08333465829491615, 0.04290971319590296, 0.008747218841952937, 0.03538481072921838, 0.0678840766527823, 0.06736661906221084, 0.008941186558721321, 0.03015992823722107, 0.012098109748746668, 0.033300171340150495, 0.0741414926680071, 0.034808731105710776, 0.03985069752005594, 0.030033439131719724, 0.031982836313545704, 0.02300861188476639, 0.02641383987585349, 0.06977266352623701, 0.038252272576625855, 0.027520830743014812, 0.033593261148780584, 0.047937043609895875, 0.032268767577729056, 0.04106908857024141, 0.024897546507418156, 0.02941422164440155, 0.01023082887487752, 0.008025020094854491, 0.029090546869805882, 0.054772819126290936, 0.013514244563079305, 0.025829743361100554, 0.03655348891126258, 0.05106458114460111, 0.10050508193671703, 0.02801245989810143, 0.04834105693069952, 0.012964973009989729, 0.017752007880647267, 0.045287822373211384, 0.03109669332791652, 0.0219544941625957, 0.038796352488654, 0.023564343939402273, 0.09504432031618697, 0.03137998848355242, 0.02343120688705572, 0.0596586037427187, 0.05519379582256079, 0.030908454143043076, 0.022677110208730613, 0.09408423397690058, 0.03988251402708037, 0.01326265141168343, 0.03635902416759303, 0.027694934347112263, 0.03180175906579409, 0.058861827211720605, 0.020372861264539615, 0.025096664304978082, 0.0342992055895073, 0.0372333301098219, 0.023731404350006154, 0.03147432520719511, 0.0647955345255988, 0.010589376108587852, 0.03434582433796354, 0.016530463338962624, 0.08936180666621242, 0.033768513173397095, 0.023966896713578274, 0.02870887770716633, 0.0902248624978321, 0.02996633541105049, 0.03765945688688329, 0.05371674722326653, 0.04483804865075009, 0.047049122862517834, 0.07249502744525671, 0.011152571200260093, 0.01282256462478212, 0.04054059460759163, 0.02108623905639563, 0.026855301544336335, 0.01717125315086118, 0.04648031713441014, 0.029637300209807496, 0.04495672103283661, 0.03277614213792341, 0.019961316205028976, 0.03339345633451428, 0.08144836486982447, 0.02767498032855136, 0.02230495580339006, 0.019688580750620792, 0.02118430602630334, 0.0411630283508982, 0.04520485111113105, 0.06391377826886517, 0.021545125504157374, 0.015013247162901928, 0.035883371119520495, 0.02698821128745164, 0.03771214173840625, 0.065941471606493, 0.06811173193688903, 0.06144017207303217, 0.033602987948272905, 0.05446822475641966, 0.0252548952786518, 0.07193288832370724, 0.025786267926118205, 0.06262422246592385, 0.02486675967728453, 0.04094621266371437, 0.019301773381552527, 0.06307795204754386, 0.03094938337536795, 0.012395107919084174, 0.05149892498073833, 0.03610771515273622, 0.056283791083842516, 0.009543000470979937, 0.015134747339678662, 0.020269997052050064, 0.036737989368183274, 0.07378683598445994, 0.039779261353292635, 0.03822309557082398, 0.03915699045839054, 0.022274757602385113, 0.0434466650975602, 0.023893082281574607, 0.034713081416807005, 0.01616326902460839, 0.004089242604095489, 0.07336714171937533, 0.069852493171181, 0.05312286962621978, 0.0282209448715938, 0.019904928248641745, 0.05075325570734484, 0.049126841194395504, 0.04309449524485639, 0.03925090649032167, 0.047731844442231317, 0.045764438941010406, 0.03324119646900466, 0.0012160347313121228, 0.035077953445059915, 0.014037291585866894, 0.03315734989675028, 0.020625522260421088, 0.017126417253166437, 0.043215040383594375, 0.03988617133083088, 0.021936172020754645, 0.02263289177790284, 0.019432718765788844, 0.009127278180260743, 0.058747276929872375, 0.05158583513860192, 0.02836522177260901, 0.04433260452268379, 0.025657615990244916, 0.023483923968992064, 0.03187187548194613, 0.013559122021043939, 0.058444195693092685, 0.012353853838119124, 0.020089640747755766, 0.05604836318109717, 0.025089110513882976, 0.07827801177544252, 0.031203769546534334, 0.028100323397666216, 0.041986586659082344, 0.025786312030894414, 0.013508443088669862, 0.04483039477573974, 0.021786933332415562, 0.042668931651860476, 0.022468927183321545, 0.013091060083492525, 0.007355130460512425, 0.0705369110884411, 0.019504461969648088, 0.0870564364429031, 0.03735742059403232, 0.022702575627980486, 0.007249640317500702, 0.03018669305103166, 0.010610136735652174, 0.07599896871085678, 0.028760965447872877, 0.022728415937828164, 0.011622926586174538, 0.047275597495692115, 0.03293073955657227, 0.006304314659376229, 0.05137375223317316, 0.01104341187913503, 0.015217391208612492, 0.037142857643110413, 0.06376000187758889, 0.03858068352565169, 0.037105388939380646, 0.03336341758923871, 0.02745810187687831, 0.036955446270959716, 0.05077293661556073, 0.018314228426398974, 0.05207747447171381, 0.017116278243650283, 0.03183998433606965, 0.052182691504380534, 0.06576090665268046, 0.004911315344673182, 0.0536003411481423, 0.028531813994050026, 0.05491373388628874, 0.02824151805335922, 0.02488299532394324, 0.010405599987799568, 0.007995638680378241, 0.0444628255707877, 0.02870363263147218, 0.022308641944878867, 0.04606095874415977, 0.050117526070347855, 0.05081174881862743, 0.03462079047624554, 0.027231036918237805, 0.019987120891788175, 0.07954221751008715, 0.09489800781011581, 0.0949534916185907, 0.10646966937929392, 0.15406480937131814, 0.10795085025685174, 0.251995963709695, 0.053764041114066324, 0.12372564950159617, 0.08689548115112952, 0.14902143499680928, 0.1671246542994465, 0.09934531631214277, 0.11471067395593439, 0.2507438766104834, 0.1367994858218091, 0.09741556271910667, 0.16501621529459953, 0.14102192781865597, 0.12573025907788957, 0.18106382632894175, 0.12847952012504849, 0.13058204230453285, 0.12923021055758, 0.17652389779686928, 0.10202431505812065, 0.05963131306426866, 0.08175719329821211, 0.14230908160763128, 0.08994073274412326, 0.13443807539130959, 0.06761893909424543, 0.0928067018144897, 0.15780874847301415, 0.200216590027724, 0.1033266137487122, 0.15304818749427795, 0.10747593681194953, 0.17594642378389835, 0.057694007376474996, 0.1267200923923935, 0.17142769268580846, 0.1523910127580166, 0.06976891801293407, 0.11308176921946661, 0.07479565470878567, 0.17714824500892842, 0.15959472049559864, 0.16763559116848878, 0.14008063689938613, 0.1773185030158077, 0.10373429794396673, 0.19142967010182993, 0.09189304762652942, 0.1644604815436261, 0.06739523288394723, 0.1412578680153404, 0.15677026419767312, 0.2480744927057198, 0.11139585397073201, 0.1351687354700906, 0.19887895323336124, 0.08386303351393767, 0.18541057594120502, 0.15707371862871305, 0.10014161786862782, 0.14003840487982544, 0.16781487369111606, 0.22720716600971563, 0.11919714749923774, 0.0984802588022181, 0.08063369537038462, 0.0638374566499676, 0.1141998999352966, 0.11027973171855722, 0.11532624092485223, 0.12735714178000176, 0.14033079919006142, 0.18828575951712473, 0.22473614503230366, 0.1931836288422346, 0.10243824177554675, 0.18289015761443547, 0.09498831403574773, 0.0761960492070232, 0.17163930061672414, 0.09000572961355958, 0.15756153102431977, 0.12773180167589868, 0.14303088001906872, 0.2427401760859149, 0.06499822650636945, 0.1034986563026905, 0.1276983498994793, 0.08947350031563214, 0.12242860267204897, 0.1304406084652458, 0.06737572500216109, 0.14629547484219074, 0.08704106762473073, 0.1238417604139873, 0.1368991761867489, 0.10563262179493904, 0.08548904090587582, 0.09658819104411773, 0.09497013608259813, 0.22926941035049303, 0.10240690702838556, 0.14431732813162462, 0.08953194253678833, 0.18254445759313448, 0.1356200019695929, 0.09780027171862976, 0.1069657870435289, 0.10510873847774097, 0.14349189028143883, 0.06279345588492495, 0.17309861231063092, 0.14974601540182317, 0.1139505925987448, 0.11308406945317984, 0.14755491726100445, 0.07106646017304488, 0.1775375884026289, 0.0952358775373016, 0.05836975361619677, 0.10937463385718209, 0.168782111789499, 0.11728445227657046, 0.18268160309110368, 0.08118003819669996, 0.10853499426905598, 0.11150544416159391, 0.14363481689776691, 0.10843147696661097, 0.19855800616954053, 0.1575296941612448, 0.12682245618530683, 0.12388791436595575, 0.24559493575777325, 0.1377471685409546, 0.11210046509014708, 0.19875611125358514, 0.13149138779512473, 0.0994398837376918, 0.07786770164966583, 0.13271326651530607, 0.1497888852443014, 0.10974445579839603, 0.11832163376467568, 0.18264353727655752, 0.17533027327486447, 0.16624897771647998, 0.060396632711802206, 0.19017751514911652, 0.048758043841059716, 0.06755834591708013, 0.1570456815617425, 0.20826405606099538, 0.16415337659418583, 0.10193865679736648, 0.10324261111340352, 0.16567485566650117, 0.20924418632473263, 0.11105565686843225, 0.2497522383928299, 0.1106271959309067, 0.09389216785452195, 0.10252544031079326, 0.16626390548689024, 0.10796988316412483, 0.13172948573316845, 0.1250463772032942, 0.10902735284928765, 0.0925386669114232, 0.13102497639400618], [0.0169191231086318, 0.010708965361118317, 0.018103690884475197, 0.0512194601552827, 0.02500611380673945, 0.05126865055145962, 0.009750704281032085, 0.043037165821130784, 0.07792990295482533, 0.020530561284561242, 0.02620801136695913, 0.027197276408384954, 0.00690859038149938, 0.026127496401646307, 0.06871141440102033, 0.07211354827242238, 0.02218143019958266, 0.039509438510451994, 0.015005644178017974, 0.028606059295790534, 0.07657457675252642, 0.013030252319627574, 0.0455365699183728, 0.038145525447492085, 0.09074974326150757, 0.018007367749565413, 0.01339050182806594, 0.04219497154865946, 0.05064636269318206, 0.039383526159716506, 0.0518721022776195, 0.030889394094369242, 0.012542733390416418, 0.05426246579736471, 0.01648667747420924, 0.04449107976896422, 0.08985451808465378, 0.046081043380711756, 0.06694794938500438, 0.08262147727821555, 0.020062341587617993, 0.020692649729815975, 0.009377503235425268, 0.032176422354366095, 0.06690921182078974, 0.01740860639672194, 0.044135568131293566, 0.015054181484239442, 0.04747326831732478, 0.08690643949168068, 0.013250458985567093, 0.016439997657601322, 0.03558266814798117, 0.024409104770581638, 0.03353360774261611, 0.03865958018494504, 0.04380684844883425, 0.03040205667327557, 0.04800715324069772, 0.05857347697019577, 0.07061007751950196, 0.02240293626008289, 0.06662521777408463, 0.024982309101947715, 0.03214453120848962, 0.05772379506379366, 0.026680439677355543, 0.050549277902713845, 0.0763554981510554, 0.02760538299168859, 0.02363568002225033, 0.033800543418952396, 0.018481460167095065, 0.027771184719832878, 0.029478601046970913, 0.04038077925464936, 0.05321397313049861, 0.09486755515847888, 0.010948550987190433, 0.037720477541110346, 0.06289735995233059, 0.014291952563715833, 0.022683103369282823, 0.07047745785010712, 0.03779473641355123, 0.08261790818401746, 0.011998032618846213, 0.03842937360916819, 0.028326307789289525, 0.03797209868207574, 0.030303150016282285, 0.07262740284204483, 0.05506316426077059, 0.022836021413760524, 0.008057308183716876, 0.03247474366798997, 0.022401735253099884, 0.024257547188816325, 0.029927183940474476, 0.023943767151130096, 0.028104945917480757, 0.015981477618749653, 0.033342915653650246, 0.031102684792131186, 0.028168765528659736, 0.02293083650459136, 0.006036175855635, 0.018089221125202518, 0.03675965838400381, 0.021781476214528084, 0.0132791839174128, 0.014693828499210733, 0.04451572076816644, 0.01970816157492144, 0.03139844463605966, 0.005735818936955184, 0.03798685681873134, 0.04786813159340194, 0.02129995553488178, 0.07748171700430767, 0.03410123621246644, 0.02263588411733508, 0.033601586773459396, 0.03456311160698533, 0.05248683125578931, 0.047847354851130924, 0.0406633551631655, 0.04008826280811003, 0.011803252356392997, 0.021490552628945028, 0.02811717481485435, 0.03892018852223243, 0.02101288772454219, 0.01110515178048185, 0.020964506481375014, 0.027079791462581073, 0.02435757851760302, 0.03495957622570651, 0.01829278332713459, 0.015852438917915736, 0.00794226087496749, 0.024253598115007793, 0.03016324627346226, 0.06603282956140381, 0.04888038370492203, 0.05371082700522883, 0.03542233710842473, 0.0532692533784679, 0.03757670275600893, 0.03451996695782457, 0.06478234380483627, 0.027631562569045594, 0.011757834614919764, 0.044564700818487575, 0.036837825618152104, 0.02848151419311762, 0.028141564756099666, 0.016437933214807084, 0.03433796011709741, 0.015666131861507893, 0.021145091791238104, 0.02912515215575695, 0.08459595311433077, 0.00498851397008236, 0.07107005640864372, 0.0062843360439209, 0.016749284097126553, 0.06962696170168263, 0.038011860834168534, 0.02262995541760964, 0.022524424562496797, 0.06078189132469041, 0.015624110187802995, 0.045094870762633424, 0.03542443717430745, 0.04076907091907092, 0.018280744419566224, 0.04912613212530102, 0.027165071440062354, 0.05028665431642106, 0.0075795533734240705, 0.012629747024870344, 0.05448337983606117, 0.015348323022148438, 0.004598668884552483, 0.022173521873940314, 0.021274720817538242, 0.01845357577050371, 0.020075537397393158, 0.02868623160091894, 0.031969818619212935, 0.004742080229334533, 0.037447170420948944, 0.05260320340416261, 0.03485083081094282, 0.025205421594104598, 0.03562220638351781, 0.0230300434133304, 0.05922323531870331, 0.03545871337077447, 0.12925172011767114, 0.03287531681624906, 0.07683253541056599, 0.021101565466129353, 0.044570047674434524, 0.03464542129742248, 0.05919208377599716, 0.029712403858346597, 0.04091368708759546, 0.04490680799686483, 0.06851443568510668, 0.022425979309316193, 0.04785072717017361, 0.042059044021048715, 0.062135263346135616, 0.017638867255300283, 0.05406003844525133, 0.038297768349626234, 0.01869804854504764, 0.018049956000010883, 0.030551721142338853, 0.06247686501592398, 0.09687824440853936, 0.029940130388630287, 0.027328301520485963, 0.030840563321752206, 0.018080032064712474, 0.038879893720149994, 0.024329393869265914, 0.05851426800446851, 0.04084662747170244, 0.008017881906458309, 0.022466993358518397, 0.07187443931720086, 0.07098384174917426, 0.046871777557368786, 0.03250026676271643, 0.021372982866263816, 0.04632101407540696, 0.06445197867495672, 0.0571066267522318, 0.09471764641680888, 0.03340481501072645, 0.044841387043041844, 0.09318131421293531, 0.08924300875514746, 0.02748962491750717, 0.020014579507655332, 0.04164219960304243, 0.02644794134955321, 0.04659730335697532, 0.05404311917456133, 0.09340207558125257, 0.06288111582398415, 0.02646343739304159, 0.0205054317401456, 0.028665750021381036, 0.0218307429458946, 0.029480809678456614, 0.015536867547780275, 0.04357846713225756, 0.10517414246818849, 0.026563190522470644, 0.04516157754031675, 0.01706617691421083, 0.010486016565534686, 0.035452474241278, 0.05256095102855137, 0.01709620887413621, 0.055502780314002714, 0.01775765498833997, 0.0165597421250173, 0.025099704141861627, 0.08013399504125118, 0.06407829586948667, 0.024471994788785065, 0.020315304531582763, 0.05887967946806124, 0.040003601993833265, 0.04242929343932441, 0.003290893992276064, 0.014361225900107195, 0.013273733584875507, 0.018472739295767884, 0.05140527357746448, 0.02358001470565796, 0.047150350109274895, 0.027965388227520243, 0.03490246393318687, 0.02618178938116346, 0.029421939980238676, 0.09255042592329638, 0.028992769973618642, 0.014487854105287364, 0.06930268303092037, 0.06057417818478175, 0.013970497446799917, 0.04442986573225685, 0.010651278010170375, 0.01858317426272801, 0.034294160681643655, 0.04285044316202402, 0.03903895250654646, 0.06648730553154435, 0.06272478135568754, 0.04029657645151019, 0.050474910464669974, 0.047609955804156404, 0.014576306233980825, 0.04584537799070988, 0.00584392059161993, 0.06788869069090911, 0.018113298940339258, 0.01238816141683076, 0.024973764649725387, 0.06383119377174548, 0.01679932266207678, 0.02913811895996332, 0.05513275820495827, 0.0465382708103529, 0.01783762882197542, 0.05065283252458487, 0.030251316726207733, 0.05022310951192464, 0.022450277648333992, 0.015416902556483234, 0.02886068295421345, 0.02885705279186368, 0.050732889478760104, 0.0425634907026376, 0.03080334228330425, 0.042086470406502485, 0.025279336110023514, 0.025842871317373853, 0.027086863493812934, 0.05798589278544698, 0.03149893567232149, 0.03942561907959836, 0.014889691025018692, 0.01719786529429257, 0.016341211440573846, 0.017228487579684173, 0.028771160436528068, 0.08145968283393554, 0.013894272519142499, 0.02473507129720279, 0.061718988897545, 0.04284424474462867, 0.026133150294689194, 0.042493998538702726, 0.01363147675458874, 0.03554464304553611, 0.11106120728488479, 0.13418734313121863, 0.12167241610586643, 0.162180115335754, 0.10829759522208146, 0.11579095598842416, 0.10505014019353048, 0.12561118975281715, 0.2238894554653338, 0.08665705751627684, 0.1477962721671377, 0.15234434311943396, 0.07910368032753468, 0.09294144529849291, 0.18846109296594346, 0.15582648984023503, 0.17430956661701202, 0.126065713220409, 0.0621872323432139, 0.10735645358051572, 0.1126247283869556, 0.0778114850233708, 0.17151062323578767, 0.1470816255147968, 0.31961097408618244, 0.11652180605701037, 0.27089148121220724, 0.1337257900408336, 0.1589241921901703, 0.11469129499580179, 0.15361557847687177, 0.15568713231810502, 0.0736814323546631, 0.1941034509135144, 0.13955530151724815, 0.06350575480610132, 0.20096327710364545, 0.16689651725547655, 0.13926583847829274, 0.2848057374358177, 0.1445213636117322, 0.10922553935753447, 0.13568860185997828, 0.07912298464881522, 0.12682400324514934, 0.17576342288936886, 0.1623626005436693, 0.13635656530303614, 0.13731985432761057, 0.13289286116404192, 0.12350679481668131, 0.11508542884673391, 0.10251324025115796, 0.16423560146774563, 0.09353848147605147, 0.11906107408659798, 0.08214113555316414, 0.13369851293308394, 0.1107263977506331, 0.16759444480495794, 0.1365921390908105, 0.09995618781873158, 0.1273294168391398, 0.22708781169993536, 0.21476697283131735, 0.29639237427285736, 0.15353042233203137, 0.1427972332707473, 0.15156254864164762, 0.1432482147855418, 0.08106261771172285, 0.13080400467983314, 0.12779368406959943, 0.08848060680819408, 0.1212641280144453, 0.23520879021712712, 0.1873518917709589, 0.19448275198893888, 0.11844136805406638, 0.13760872025574955, 0.15690111289066927, 0.1479821636208466, 0.1314399955528123, 0.1450479474983045, 0.09454677772841283, 0.25317943734782083, 0.14966179563530854, 0.10036730540118047, 0.06364198428179536, 0.09468215903533356, 0.08879671591733183, 0.12276649954063551, 0.1836393145578248, 0.1369958674269063, 0.054488156722592454, 0.1331797864820276, 0.0985382871170129, 0.0935535788802164, 0.06488345909331526, 0.09950754724975143, 0.17305638029107026, 0.07964981959334441, 0.09074231330305338, 0.22967281298977987, 0.13031521519379957, 0.0718318476740803, 0.10647734361035482, 0.11763798259198666, 0.17889433274311678, 0.1263695747724601, 0.1094136903328555, 0.13555733247527055, 0.10145969928375312, 0.12304860725998878, 0.07019919063895941, 0.2272358544703041, 0.10607655333088976, 0.12851283619446413, 0.12997734546661377, 0.1957492647426469, 0.1168756756399359, 0.14532924097563538, 0.1006239273452333, 0.11268648185900279, 0.16396319679915905, 0.14322209118732385, 0.1035956528836063, 0.1684163407023464, 0.128144717376147, 0.14375472760626248, 0.1495403242962701, 0.09196181036531925, 0.05520865234679409, 0.06901628018489905, 0.09467241527246577, 0.14798466062971524, 0.06596771055566412, 0.10390543804637023, 0.0784516828134656, 0.10285386483051948, 0.06226541314806257, 0.1310827468654939, 0.15752149745821953, 0.17523362274680818, 0.17587664324258054, 0.14652232266962528, 0.10858329917703356, 0.21461700302149567, 0.08947229930864913, 0.11970136687159538, 0.13407687763018267, 0.09540262751813446, 0.143362072961671, 0.24504089834434645, 0.11600267248494284, 0.12433999510748045, 0.14302010488297257, 0.11058436001517943, 0.14885813875922135, 0.06329550394522292, 0.10665759643805878, 0.13094414930258477, 0.18574455087738379, 0.13548647984862328, 0.13279498927295208, 0.11802339048257895, 0.08199364918151072, 0.19151250565690653, 0.12477361969649792, 0.09908674697258643, 0.13060209979968412, 0.09506331251135894, 0.13615689958844865, 0.11919330699103219, 0.07503176453922476, 0.13249998938824448], [0.03102347600672926, 0.02786668173835746, 0.015607031461383616, 0.0753544554380434, 0.06664984859526157, 0.04582997863846166, 0.04265584271135075, 0.03270307409444025, 0.018877612659707665, 0.037085409475756545, 0.012305507369871651, 0.0624600848449128, 0.020628606202080846, 0.011086619292785014, 0.024037131873358573, 0.05947007278778723, 0.029110014039490904, 0.013440483565708356, 0.006143903467870716, 0.028240851392703395, 0.026940081102241362, 0.028370531309129934, 0.021914864324831536, 0.031844513557319126, 0.04868374425651772, 0.0053167981178765845, 0.061390381173363755, 0.019260226682360684, 0.01001306323866759, 0.037393684898103983, 0.08940188772976398, 0.05063500740964498, 0.034102484716900756, 0.027062875584566166, 0.021972534712404013, 0.06424705431397472, 0.014631896911721145, 0.05137994047254324, 0.0539630113302597, 0.007997066148423722, 0.03553659562021494, 0.026451328935633813, 0.013424015520805759, 0.009449172648601234, 0.025900168510686074, 0.01968366646074823, 0.004450188035012356, 0.017734900316489593, 0.021952777468998517, 0.028927515260875225, 0.01405915483233652, 0.08907983465386288, 0.05197670862876943, 0.05311374333021896, 0.09334372835499899, 0.05035993949111019, 0.02431685454212129, 0.031087431324911968, 0.07355250391576972, 0.03863638446533254, 0.05944545553731067, 0.021722655710098997, 0.006802882683197302, 0.07812046272946255, 0.06793671739952904, 0.05895715459649052, 0.0371112345185663, 0.02015425424490656, 0.060704877600073814, 0.09065969487918274, 0.04074571913640414, 0.007574314234911331, 0.03311979298346809, 0.014807657837601644, 0.025228481606713364, 0.015254978655970522, 0.026976065510617833, 0.08012940814452511, 0.0473206895403564, 0.010785549064166844, 0.038960021920502186, 0.04594202173341598, 0.03194934043235012, 0.027125521330162883, 0.046020205930939743, 0.0481987918860146, 0.013898365781642497, 0.03606018038200481, 0.025391930514680486, 0.02041125956124493, 0.019777679183919514, 0.058611909193652015, 0.02704744060922946, 0.07697211006390196, 0.08991743863693305, 0.03552133536764553, 0.02139369514770806, 0.0531917884280639, 0.026257963418694477, 0.04598064733935254, 0.023257747891225984, 0.08001668990722724, 0.01101264964589583, 0.03841408621519804, 0.03243188400353704, 0.024172558981393064, 0.0347966735384294, 0.04664768118943487, 0.09478162548371724, 0.04796610865741968, 0.028585048458938087, 0.021688740833529403, 0.012226258720537382, 0.08970589855951921, 0.016396401782653162, 0.05909687174218042, 0.05758576068495001, 0.005392274536591555, 0.028862029846225466, 0.05574834213725158, 0.029129739052483013, 0.033005575183779, 0.02241140098444053, 0.03339476929977536, 0.03849230433947273, 0.05145475235102432, 0.014326013325314437, 0.013407692512763398, 0.03987638346318688, 0.06511815078556538, 0.008181677715453719, 0.026549646963498423, 0.056714141741395, 0.038728811112897735, 0.03722943192613976, 0.03238457314936178, 0.04214136388951114, 0.06812176068446466, 0.01603511072296117, 0.013115016610494681, 0.045012242160737514, 0.025453605955200534, 0.05584429716691375, 0.01613966279130961, 0.0965201204110469, 0.0272002908002053, 0.009279462558749531, 0.03226875739970377, 0.02533098789198058, 0.01723969358551715, 0.04010814388415643, 0.025093789012836556, 0.02080738321611924, 0.03144106002790587, 0.025854940759018064, 0.026449868389006172, 0.015987867722287774, 0.023311560807217444, 0.02498149825260043, 0.06546744704246521, 0.018402397266722152, 0.02882672906188028, 0.03137051613469209, 0.03228445191468511, 0.05446744104847312, 0.04921595998374479, 0.037076727620192935, 0.04937386865328465, 0.022282849132482494, 0.03011405248461025, 0.00351094501924568, 0.0035692884287397775, 0.07975529786199331, 0.02642522399712886, 0.03165743127465248, 0.06681807778243508, 0.015494029935715454, 0.020547782503334538, 0.03225723587508712, 0.07824526567544256, 0.03348187284011926, 0.04479329587359514, 0.017536315168919306, 0.03200655450512256, 0.022826527012512088, 0.038570417290819545, 0.03293702279084495, 0.056434592099062035, 0.021051435298951607, 0.07405166820223842, 0.023973955174109766, 0.017848914555673088, 0.04688254251543965, 0.07364822485085044, 0.026261966775304506, 0.006265308225660452, 0.020010755962825248, 0.08011188158499342, 0.04934169591537543, 0.04030915988343103, 0.025129805651626418, 0.02387583561773811, 0.04997464355879596, 0.038262284360826015, 0.023826799588277936, 0.009052764857187867, 0.04706081062821405, 0.012309915302986545, 0.06348180251994304, 0.03588081982785037, 0.03324714043576803, 0.0450726419554225, 0.037206860458744426, 0.06785505571003471, 0.05465625698811241, 0.06350337314818587, 0.042233325740588565, 0.017730944457330873, 0.09863932098128966, 0.042363787668624094, 0.03753795162109392, 0.057732222468725274, 0.051600328646600246, 0.020794255259845938, 0.0434685037471354, 0.09653204227132456, 0.04877428796940616, 0.051646625090922625, 0.04082665140075343, 0.04382848014522876, 0.04960503874878798, 0.05842732731252909, 0.03577779785596898, 0.013170375738159885, 0.02713131601922214, 0.05244604790849345, 0.02450833033903369, 0.027832454735679284, 0.014162137788454337, 0.03214075516111084, 0.04101915517821908, 0.061219729616173675, 0.04454760512869273, 0.06280289430703435, 0.0731942102845226, 0.03387632220983505, 0.04620553080790809, 0.019314935264576758, 0.0226016096172056, 0.0244277984103454, 0.07559093846274273, 0.05365423718467355, 0.02698065580001899, 0.03229903702491096, 0.08272515064371483, 0.009044648730196059, 0.028005691511290412, 0.038215584188167534, 0.08766090936426606, 0.03491539341796722, 0.050097071632210693, 0.02201335707546345, 0.039189801019217284, 0.031035825344068662, 0.009335557048741196, 0.046814573662621636, 0.04398406822500484, 0.002519007822099541, 0.02553677568877382, 0.06215954811445304, 0.044474886530744176, 0.052637103013694286, 0.04819324825491224, 0.025279210581045066, 0.05656317448509591, 0.04084572162745254, 0.096964574418962, 0.07201330829411745, 0.03160652079220329, 0.04200032360053488, 0.017300274888319627, 0.049276302102953196, 0.025953462347388268, 0.036547080148011446, 0.09205557711954628, 0.027658639508964758, 0.033553003666124175, 0.02894086204469204, 0.03922779219491141, 0.044760122296533415, 0.04171741520985961, 0.053325911052525043, 0.028219396115413735, 0.03775419055351189, 0.08251990737127406, 0.026392579677381685, 0.07694194239697286, 0.024660086392291954, 0.06099987069943121, 0.02499524876475334, 0.03757801911394511, 0.020595904206857085, 0.03210373429049339, 0.0234069696161896, 0.09121491972889219, 0.014115977899304457, 0.06812380986022097, 0.06614593456366233, 0.07664601291928973, 0.028846857803208486, 0.03396476585684078, 0.007603665115311742, 0.04101378457354648, 0.04238555507202234, 0.01038566293261413, 0.06868540615375553, 0.05191565404779144, 0.03496760668765221, 0.011858815044563795, 0.03313895141971963, 0.03280731403668012, 0.023418526763894727, 0.060652705042489936, 0.00855933758430183, 0.021783247190926756, 0.021027345609452044, 0.019225053123331497, 0.06126620926495109, 0.04364054290843861, 0.06177263387611934, 0.010631104315897184, 0.1148565047021423, 0.06744423668299403, 0.030700232101870433, 0.0715718941230859, 0.004399358128596629, 0.010214415112776416, 0.03666109099451985, 0.06812096679849283, 0.028398320710818683, 0.037271752155252864, 0.05531535537115165, 0.03254029015079141, 0.03842534650383251, 0.09755969712776796, 0.017112254530989697, 0.04737992225480931, 0.03119500626676849, 0.01701121388136276, 0.0070104800480683994, 0.036272134365780015, 0.04981760002140488, 0.10307586113257067, 0.04607467532956174, 0.18922139145433903, 0.18011136672326497, 0.13241016492247581, 0.1064492929726839, 0.12086509514067854, 0.07759286782571248, 0.09057624864258937, 0.1276513681347881, 0.0846523122329797, 0.16549675379480633, 0.09550943571541991, 0.1156830010669572, 0.1383834443986416, 0.08926721209926264, 0.13405167683959007, 0.14780343749693461, 0.11666931957006454, 0.09698170742818288, 0.11756744209144797, 0.10289347770490817, 0.14226626604795456, 0.11816323654992239, 0.17537882924079895, 0.11323777120560408, 0.2846235914954117, 0.10713212990335055, 0.09093776531517506, 0.08560051063873939, 0.1757412619356598, 0.09229043166020087, 0.1439937347812312, 0.1349722860114915, 0.10311402194201946, 0.09735397888081414, 0.12432152538427285, 0.17969751464469091, 0.13542568311095238, 0.11765429457383496, 0.0797173473984003, 0.08894438549344029, 0.20292657746800355, 0.1003268782847694, 0.10769586358219385, 0.12072139499442917, 0.1468634900770017, 0.11663308580006872, 0.14276087736444815, 0.2658933108406407, 0.09365181718021631, 0.15434774490339415, 0.16894433594175748, 0.07637655987803425, 0.18176947560693535, 0.11787329853645392, 0.0937555923259684, 0.10537006945482322, 0.16822122117238386, 0.16407092101871967, 0.10679753071495465, 0.08845447642462594, 0.11889232242746012, 0.18698399008384772, 0.09610159322619438, 0.1891576498746872, 0.1632361329559769, 0.1347978753702981, 0.21937807968684606, 0.16984484690640653, 0.10527660804135458, 0.20978193889771188, 0.08810882390077625, 0.10376966318913869, 0.15912791554416927, 0.15212972249303544, 0.15214737797422068, 0.1874799991824797, 0.2541274864758764, 0.08587645047477313, 0.09650515192853552, 0.19164047736142362, 0.1473194384681327, 0.11900056233363492, 0.12566359979765757, 0.10770563448646239, 0.1569570784590074, 0.18375421767788275, 0.10916842027966465, 0.09971954194562775, 0.14445171877741814, 0.18860410100647382, 0.15820143025900635, 0.1897044541048152, 0.19044853560626507, 0.1189820518983262, 0.13961520258869442, 0.1358856348586934, 0.12258751557341643, 0.1155288786228214, 0.14709697397691862, 0.20231487814869198, 0.09422648205821003, 0.10823975689709187, 0.09225258976221085, 0.14252400078943797, 0.10637160749839884, 0.13274443841406278, 0.18626536721629755, 0.14288893049316748, 0.0575243668364627, 0.16634527540632657, 0.06985775181757552, 0.15896529784160002, 0.1140809663172279, 0.14723945276013442, 0.20481120848229953, 0.09210118145814963, 0.12912400625646114, 0.11803941747971944, 0.11436721310019493, 0.08946381762091603, 0.1813850040946688, 0.1980166845023632, 0.2041387531374182, 0.09066177798168999, 0.14809148918305123, 0.1061061578137534, 0.12875093413250788, 0.1369878471429859, 0.19274463025586946, 0.15615386941603251, 0.21667619395468915, 0.09069152495690755, 0.07655373894210372, 0.09727588628551789, 0.14394640017833027, 0.19313073025218078, 0.09516028873622417, 0.1717796895120825, 0.14016960641103132, 0.11324464476534299, 0.14186644607356616, 0.06219471658446959, 0.12329743962202754, 0.21560385078191757, 0.12747481332293578, 0.0975225337647966, 0.11457411199808121, 0.04801146872341633, 0.0542291836547, 0.10114703713251011, 0.0927728700584599, 0.13356974055724485, 0.07999342972678797, 0.16835510970226356, 0.2332271694072655, 0.07528222538530827, 0.13344900203602655, 0.14626172451036318, 0.0886685067255582, 0.09887983450399977, 0.17080934372331413, 0.19007778407207557, 0.1287983637303114, 0.16081962548196316, 0.1142977446849857, 0.21177673685763562, 0.27139913397175924, 0.11186420598200389, 0.08366684189864568, 0.15188682052705968, 0.176013870164752, 0.07056023912238223, 0.12353344767221383, 0.1620754852358784], [0.038144840127123256, 0.003857845623445298, 0.03268353907125337, 0.04309687690277185, 0.023470919845359664, 0.04122435434588364, 0.031057779344597032, 0.02979070340682353, 0.05119862913021019, 0.03915325512311288, 0.028365255699359944, 0.06614933402410575, 0.028604644550276653, 0.0829484700890524, 0.013498546655422874, 0.024398295707734566, 0.02743888576515019, 0.010858003033458121, 0.020169163355603814, 0.045323034948004146, 0.006149401297859315, 0.00821654508555574, 0.03412898490205407, 0.00803099714020001, 0.06458195884312902, 0.05770708953163453, 0.01580091775394976, 0.018431306251191666, 0.04713377689144441, 0.045367835222610405, 0.020968374130981307, 0.062316276133060455, 0.007705704907753638, 0.02381101856008172, 0.016050123310248767, 0.04773613278354917, 0.024593194713816047, 0.07115538897258894, 0.0062172959359096626, 0.024409057273130332, 0.010719832947610744, 0.01551001622075481, 0.0804630641692451, 0.05318507093137928, 0.026494383678904602, 0.05116950301453471, 0.049717763771436045, 0.035364926260496886, 0.03617166368556874, 0.02061766991391778, 0.01732171998758401, 0.03600254222484572, 0.05712573429835694, 0.03281182629455413, 0.038768848071673086, 0.02365890288326357, 0.029339877955083336, 0.029209229429917674, 0.0516886569426528, 0.04845933236980012, 0.01575851270795933, 0.03770680506048458, 0.05996928457170725, 0.04875457313443933, 0.04190232278779149, 0.07248396732445274, 0.041535812097468545, 0.040270971932581494, 0.015259263604613287, 0.030426962301135063, 0.03344080450811556, 0.005445731645782611, 0.03410161279940179, 0.04805483389645815, 0.03950242924370936, 0.052836202151541195, 0.02196968825800078, 0.06529718225023576, 0.026361204218119383, 0.019113588479480574, 0.016971996253622428, 0.03346898406744003, 0.01817916433459946, 0.011546641438534217, 0.043618789075740745, 0.03483968926593661, 0.05094416492751666, 0.017323351864303862, 0.08635304668652159, 0.0620667448799525, 0.02469138042735202, 0.008762295890067304, 0.05774449038186243, 0.014849635406530328, 0.03443089905860169, 0.039681871222066026, 0.06261924201888697, 0.035121949655669074, 0.04101756401360035, 0.02013157930092088, 0.043990097008645535, 0.02157946616145117, 0.030365442923669304, 0.026296892669051886, 0.049198684482170005, 0.040610253012606075, 0.0360301619927798, 0.012707701368656541, 0.03247261306803141, 0.054545927194080183, 0.0254618314959641, 0.03774561047820108, 0.023284741710605364, 0.009598068676755896, 0.06992247048765421, 0.018573145515152385, 0.012108716947425689, 0.004916430650545018, 0.014353395605991994, 0.06545009690203837, 0.06997601368597575, 0.061009329477591176, 0.031020863646907464, 0.023837793551917588, 0.022108297695272734, 0.017680030582206588, 0.02579983353747853, 0.04767076611252768, 0.017393851652741432, 0.02983097785285541, 0.026976674495797073, 0.058184269283499034, 0.04221705447084137, 0.01312140077685139, 0.012141333277603346, 0.038084820312048705, 0.03803053411788174, 0.04932625585102609, 0.008248172450943716, 0.029332302111600126, 0.06167143716343811, 0.00483814297643091, 0.04589700432760375, 0.05851161493254559, 0.03314838644915393, 0.04728843877092004, 0.015061019420889872, 0.012499648961238563, 0.016364137442516427, 0.053807782874043496, 0.03897690726444125, 0.06326807755976915, 0.029875245477472032, 0.05608455963166697, 0.009832870630946542, 0.009736654365302196, 0.02428717372406806, 0.08946517469095332, 0.02335203711741737, 0.042054124642163515, 0.05047440156340599, 0.0535353307080056, 0.0037278595180915935, 0.007293561041089041, 0.02127782172257347, 0.047029764258435795, 0.026515757531992028, 0.05306395243055054, 0.02840480411292187, 0.016630676175866808, 0.03962853836960026, 0.003947835906209158, 0.032666952282722504, 0.01912749675102532, 0.032548072947455306, 0.0029226218674531473, 0.044478126535458226, 0.07837027896727834, 0.030259136842297654, 0.043678842817566225, 0.04892612035785403, 0.03935468163607376, 0.08999940566718578, 0.021670640911906958, 0.026238101002361094, 0.061672454965966086, 0.027093368948304226, 0.0356593595684639, 0.013055582880042493, 0.02006620754088674, 0.02680051153791802, 0.026778973140088574, 0.05113538966647216, 0.021234307271827544, 0.02147938054986298, 0.008336724663552428, 0.02815830591134727, 0.049562151942934306, 0.03406027305339064, 0.0412211618386209, 0.0632290957229478, 0.05211539440123098, 0.07018823908375842, 0.07231577884938035, 0.06979182535516364, 0.035763283991920095, 0.06320677870618445, 0.08417132589966059, 0.03025540489969509, 0.04351102075140391, 0.043260766858501096, 0.03513760345854929, 0.02032033756508359, 0.04987184889614582, 0.014289906780634607, 0.029173935430922678, 0.013214840986100691, 0.017622348320271288, 0.07141895232988255, 0.0470756976865232, 0.012664811170127774, 0.06415340291070086, 0.029459015133657625, 0.02212291333957442, 0.02738334088852363, 0.04346829340127962, 0.04185350558587483, 0.02894904856969203, 0.046862196642905474, 0.03825954647202577, 0.03320462343149951, 0.036228189045297246, 0.040495801118335555, 0.0168736375136567, 0.01812450833884733, 0.04652269503899983, 0.012122804182581604, 0.03780139623475926, 0.03653681730585439, 0.06835897652698414, 0.05132314709148236, 0.01863932642819626, 0.025022776930459907, 0.007830537539640707, 0.0351217868072646, 0.020391617668792605, 0.01887503931564944, 0.0388108595673527, 0.044132874347269535, 0.03505508002958127, 0.030397130509040186, 0.018656990391069224, 0.04110809076311333, 0.017279421810859015, 0.006616347045305052, 0.025635422806122472, 0.02696741758180516, 0.06951914927256958, 0.06205160676368645, 0.0029790136405998574, 0.025176285300403833, 0.02107479386696858, 0.03255245628367577, 0.03735027222761086, 0.06824626507503645, 0.028194409063352004, 0.0038845731178298593, 0.079205826989242, 0.01228542612599475, 0.009840709406749477, 0.005857008259876498, 0.036591283311801295, 0.03725036812414016, 0.012749855356690074, 0.016372101747297814, 0.020875840614150678, 0.026385017404598848, 0.008244407429758991, 0.008499080281970757, 0.03341730684041977, 0.041496864187398126, 0.023774051972265755, 0.03835296717339328, 0.02406443951518408, 0.026346108510292003, 0.016317042023209587, 0.003987751576849925, 0.09888471995613404, 0.03683906394456114, 0.06559419059859854, 0.02959143802789705, 0.06444258775029864, 0.05566059059596487, 0.0161837726565344, 0.043640512374362776, 0.03535133181139827, 0.04923936265653797, 0.036991496836500506, 0.059754066834492345, 0.014526474622211285, 0.027384107633094703, 0.014819801918097904, 0.013143990903959742, 0.03117353402610336, 0.0414870864977794, 0.08526701746242386, 0.01806439013619508, 0.02074729894021792, 0.012515344324388673, 0.03636728193876999, 0.027347583789378405, 0.025422483250232678, 0.027403430614088262, 0.04090226395055652, 0.012298175798995154, 0.018593306486893977, 0.06382928030299288, 0.014276588834556085, 0.030914343827004944, 0.04003173405570643, 0.01814097468741238, 0.03815294522792101, 0.013350174795570118, 0.018714821930708628, 0.013898398012055882, 0.0615158626543624, 0.06205495194132839, 0.04996125606287803, 0.01338755274524114, 0.011328293958545795, 0.055714330569441826, 0.02549171417818538, 0.02518045320175588, 0.05732478933142764, 0.04104992334863969, 0.03636698338336178, 0.013228156387672892, 0.05256315966003707, 0.05810008344373532, 0.07529306158955608, 0.03661235521680542, 0.058426126305546076, 0.024337013817525337, 0.10420655831694603, 0.03942080826631614, 0.010437675186299851, 0.037168523230190785, 0.004490367486141622, 0.03879190469160676, 0.025196778754304563, 0.052362662740051746, 0.024901498973901783, 0.1044758620804974, 0.13844790522541317, 0.1668533624282905, 0.16909022097076687, 0.1050000778798546, 0.10453728985573564, 0.18508044151323183, 0.1044392144041402, 0.11295061518571206, 0.14367179705628327, 0.11089490513716425, 0.1325399008180414, 0.12102422517325197, 0.1600785023931946, 0.09950136579573154, 0.0679877975157329, 0.14229761436581612, 0.12735730462840625, 0.09833824820816517, 0.1833070223884923, 0.08554274695260183, 0.11315993645361491, 0.1006056543971811, 0.07398117519915104, 0.13461260816880635, 0.10243617224373988, 0.15377124798085007, 0.13118257293743746, 0.1188233018453632, 0.1464105136692524, 0.1039977730917079, 0.12445449110652719, 0.125702330576522, 0.09856318935219731, 0.10079588847500937, 0.16419402084180287, 0.14085100484745844, 0.10365949624351092, 0.07469975735460009, 0.07927404690001692, 0.06883728264697961, 0.07559955585747957, 0.1751538541700159, 0.14088217674621514, 0.10956247270639453, 0.17376170387225492, 0.0988566828891635, 0.1226033932928528, 0.09666542189994029, 0.07701856935662882, 0.10035514605364629, 0.09605472681245633, 0.16418716763811453, 0.10291554366371461, 0.13610026905579226, 0.11387763651353972, 0.07703606877475977, 0.09809151930468422, 0.06712965427764825, 0.11939973091440541, 0.07677618307726723, 0.07925424724817276, 0.06771546070064817, 0.11498309219522135, 0.15174288967890398, 0.12486178853682109, 0.12920297416193144, 0.10978500505111047, 0.1459023045109851, 0.0717781823394554, 0.1143476984330586, 0.1419522807534252, 0.20101097811545643, 0.1210092974028417, 0.1352474998150553, 0.1600693150290421, 0.11415659583040647, 0.17334786536438124, 0.0734362912231258, 0.09307935075568301, 0.11322719963001353, 0.12133073301187583, 0.09886614166732345, 0.12967910218451703, 0.13064475251095636, 0.11167150203670774, 0.06349454540759325, 0.10118627681263856, 0.10466291382908821, 0.11729836224445275, 0.10043438537312405, 0.10742651910654136, 0.12428677082061768, 0.08251299309943404, 0.05731499807110854, 0.10618638779435839, 0.15571624147040503, 0.13370717103992188, 0.12685962633362838, 0.08208299188741616, 0.10991679690778255, 0.05999647346990449, 0.15927195495792798, 0.08102804635252271, 0.09903226061058895, 0.07616275349365813, 0.08975539768912963, 0.09646427697901215, 0.17821330071559974, 0.1458097794758422, 0.14184873630957945, 0.2303153042282377, 0.1488028381552015, 0.10884871493492808, 0.18109305761754513, 0.17448941910905497, 0.1285136640071869, 0.20199910152171338, 0.10102202384067432, 0.17555480051253522, 0.16487085952290467, 0.15258999993758543, 0.14075306510286673, 0.18001296557486057, 0.09904771763831377, 0.08733278339994804, 0.09823473769107036, 0.11123117352170603, 0.09860187263361045, 0.11879655399492808, 0.09061811425323997, 0.1999320802944047, 0.13288269670946257, 0.13583460902529104, 0.08641768393239804, 0.1959541823182787, 0.14889433181711606, 0.12442675259496484, 0.10946042782494, 0.1032295221728938, 0.14151188438492163, 0.07267851688499961, 0.1090112579986453, 0.15896170160600118, 0.20978010685316154, 0.14985576165573938, 0.11939058426235404, 0.09068543171244008, 0.10593133326619864, 0.2006397516067539, 0.07127744385174342, 0.09989912302366324, 0.08456326129713229, 0.07411256672016212, 0.13190595912081854, 0.14100515443299497, 0.11573473257677895, 0.15625278625105107, 0.14305114107472555, 0.1443811511354787, 0.06055761514497655, 0.16723738610744476, 0.09909157135656901, 0.11159203201532364, 0.14481945761612483, 0.16231648730380194, 0.12182789562003953, 0.17886629567614623, 0.20745579871748174, 0.09186375526977436, 0.0813624012683119, 0.08540997122015272, 0.14059168233403138, 0.15131975524127483, 0.12111064339322702, 0.0757816271590335], [0.06732646335980721, 0.03127475788018533, 0.022516302498323575, 0.04078148810991219, 0.03610815620049834, 0.08008747468037264, 0.014753858492310559, 0.04407653219199606, 0.06200441465313945, 0.041367572732269764, 0.042493978182652166, 0.025743467633479407, 0.04570356077913727, 0.011545861971431544, 0.0765605310776404, 0.02999136656788843, 0.06758287495800427, 0.045481785000967126, 0.027510306664875576, 0.01672958622553519, 0.03183408786675759, 0.05040925880894065, 0.09129092922168118, 0.11375094045485769, 0.065422466956079, 0.027665964294491068, 0.019303435792348216, 0.04095240768843463, 0.010828533409429448, 0.002880233360753794, 0.06649803317018918, 0.031001389691872255, 0.022637485459979092, 0.01667922705278865, 0.00878318543878517, 0.02351130455333207, 0.0354785299859941, 0.025211767592866505, 0.022104197647422552, 0.0378051926381886, 0.03189358181719269, 0.03374240993122969, 0.03790013665067298, 0.028138185651706796, 0.008951149149132627, 0.07334708422422409, 0.047189820491309674, 0.05903303516762597, 0.03326242104438799, 0.006956648048279541, 0.04863073370818581, 0.046451289406312365, 0.051382759785545726, 0.013642938059222485, 0.02956315329564469, 0.010648792027495801, 0.03290454810485244, 0.062086904155356545, 0.045876030810177326, 0.019895187878449048, 0.051085038975413354, 0.007541631747569356, 0.04956899157592228, 0.03475955767290933, 0.027560433439378227, 0.05747596014823232, 0.00654552792132433, 0.039840940186487775, 0.023673645752881254, 0.043209130343581946, 0.054397596046328545, 0.031587338607226095, 0.018326789805931703, 0.02886812648336802, 0.022756580230114714, 0.07988215676907982, 0.03143205586820841, 0.045206242107919285, 0.01995638495178095, 0.048347092499690394, 0.027403318655810187, 0.03214627504348755, 0.016032783347847204, 0.10588092489966325, 0.014822563555623804, 0.029654083773493767, 0.015078021812119653, 0.013067057755376612, 0.03435083531907626, 0.04076774438310947, 0.02570868592842349, 0.0301180931606463, 0.010801361474607672, 0.03460672783798405, 0.07616335060447454, 0.0347189066399421, 0.030878924299031496, 0.020450363534369638, 0.0366503192510988, 0.01440980561476733, 0.006371992590304996, 0.04062537416549666, 0.019221994626734937, 0.10746208791221891, 0.06521938821034771, 0.021919610677286983, 0.02331604592369071, 0.08840657185230937, 0.02117971912957728, 0.030001408886164427, 0.024832178140059114, 0.01853012809130762, 0.08206236442284924, 0.036313480897141356, 0.034220858543579064, 0.03166771786553519, 0.04676148847543767, 0.04533721972256899, 0.008839577636016267, 0.03174589867038386, 0.004236986819055996, 0.025455755214872103, 0.058626334848148484, 0.011344631385457302, 0.048817551362195184, 0.08621599618345499, 0.040756755508482456, 0.029846441665930406, 0.02266333594785205, 0.018115578818001916, 0.03950075665488839, 0.028102694877556393, 0.03609361519504871, 0.04134873320747699, 0.031695266387292316, 0.06064246594905853, 0.07741832826286554, 0.06272598914802074, 0.04327961316864405, 0.012647193856537342, 0.0625603858913694, 0.02833325259520539, 0.03203758391152535, 0.014806589144947273, 0.08166122130517449, 0.044038944744638035, 0.018392780729170357, 0.062148990109562874, 0.02892974764108658, 0.007115720405376383, 0.04112586498792682, 0.050734273690198145, 0.04480097010465605, 0.01772807934321463, 0.03115886070632509, 0.025598150877548114, 0.03623417711683682, 0.022451244560735564, 0.07894722372293472, 0.04817028323720608, 0.0349367367369788, 0.012386363299031342, 0.04017293719308717, 0.018390217563137412, 0.031318794802895615, 0.06410845675106559, 0.04812052965696369, 0.008956404402852058, 0.04724474111571908, 0.03710891053612743, 0.08161018868642193, 0.06580488250723907, 0.025824627207059945, 0.014474926316844565, 0.042342522381139655, 0.02813068953608828, 0.03681488095649651, 0.02292797139047512, 0.02062810747884214, 0.011521159055908876, 0.06077134010515042, 0.029461593566728488, 0.006718151894996741, 0.02688003414576607, 0.028884190799934522, 0.050730104092508554, 0.03524909354746342, 0.01804948950718556, 0.047611061816236804, 0.016094311207000698, 0.016507413504379134, 0.029181969285543476, 0.055580655778093, 0.050868640587266, 0.007668729838249939, 0.05020708251478417, 0.04029266130445259, 0.056288038713059256, 0.026577879109286835, 0.07784611066537243, 0.029723056858139377, 0.06563642261815922, 0.03034779762050935, 0.09157883163009371, 0.07387796323746443, 0.014462948477427875, 0.05342860732759748, 0.06298050763351576, 0.07479718141257763, 0.07154159074915306, 0.07073890417814255, 0.03338835375117404, 0.029381115920841694, 0.012924991182184644, 0.037143715989909, 0.027645068808591793, 0.04667279037779995, 0.031360752015773735, 0.08930799205388341, 0.05359386113871421, 0.02492400089145771, 0.03879467650715794, 0.006785045693894582, 0.026834524802065322, 0.01573422285062926, 0.04759439021082861, 0.03461238003468939, 0.017682944890111685, 0.03384574742189475, 0.003022092980765072, 0.014179179195447691, 0.06951254712683813, 0.06084804848900863, 0.07562783719705683, 0.06944794380771262, 0.03073806721451027, 0.04053546827552574, 0.040378088863300424, 0.030462938227823803, 0.024712194489049058, 0.034747985258166275, 0.05223066732287407, 0.025919014820829034, 0.04946367954835296, 0.09393448808363505, 0.024340528628921936, 0.019748531015855924, 0.035725730471313, 0.021203120106032917, 0.03903020619015608, 0.028894677558647733, 0.08564996227089848, 0.012687034040157284, 0.02637920744850167, 0.02849794491859419, 0.09441481623798609, 0.04761923477053642, 0.07473099032150847, 0.07709435493286167, 0.05694731351520334, 0.03740385613803353, 0.03198665985837579, 0.06737148415829454, 0.03209430604640927, 0.05406053377581494, 0.036645203097058196, 0.08501329286290066, 0.016983265023944632, 0.013718052733955639, 0.01353592290875635, 0.030234366921441894, 0.012715595275429743, 0.03991012700966426, 0.012747384641053421, 0.07273953753922667, 0.032112385611981153, 0.031209883147052357, 0.027271781249770095, 0.04408104105719498, 0.022589219567765082, 0.05067999767405646, 0.012621614782671844, 0.005092139838130346, 0.030010952481201718, 0.03393464568736298, 0.049665547109075954, 0.01655697200580367, 0.0567241297768695, 0.05416583901803408, 0.08531000944120543, 0.03192834655887314, 0.034963331917034726, 0.04836506010698421, 0.03292400170383709, 0.03965970687568188, 0.01429403227354799, 0.031206395477056503, 0.005366959667298943, 0.06490880916161196, 0.04019432122419987, 0.05612102071089404, 0.024460495316556523, 0.01200554654600897, 0.03875833756423422, 0.022757218053032244, 0.05493520612695387, 0.012155831874614316, 0.0662449463935835, 0.005531849614011922, 0.05483410440917526, 0.019845298591202924, 0.034599749105317254, 0.054061456583440304, 0.018931401826973473, 0.03798479407227465, 0.05741583516022988, 0.023029108731342212, 0.04410760909585016, 0.011857629304618707, 0.058300651609897614, 0.013481675730352955, 0.042704439389386346, 0.056569827520953755, 0.021622397072081054, 0.021285212665264095, 0.0636579841375351, 0.03967648704669305, 0.017657934089324305, 0.058870315684803894, 0.006941434869077057, 0.024846637721306512, 0.05703012192887919, 0.0234687926380762, 0.017503075434693267, 0.03353531086551292, 0.0559681705199182, 0.0690958316304854, 0.018788763588028293, 0.05205724734280791, 0.012106046063958533, 0.030944151870374168, 0.03277655604428478, 0.05017288774251938, 0.02019606896543077, 0.03691193860556398, 0.015912065182679465, 0.029595977427171807, 0.020119932247325778, 0.03948481786730034, 0.02175362065567502, 0.07110012229532003, 0.017409237434289286, 0.13925027288496494, 0.08966619069022791, 0.1364019185836826, 0.10847334257726159, 0.1247530465147325, 0.14315650399242127, 0.06586439002837453, 0.13241602746503695, 0.12392649586711611, 0.15730063430964947, 0.10915407604937043, 0.16301706113985606, 0.18860152257340296, 0.053323142629648955, 0.16595328572605336, 0.1122189915872046, 0.14092016113655909, 0.14502106394086564, 0.10492208027946097, 0.2072145930890526, 0.12456720934382506, 0.1039970742006387, 0.11638254352978297, 0.318993018673999, 0.19802914240530559, 0.1346580157322543, 0.09774464541780097, 0.16473811093185628, 0.11896040663123131, 0.18570295668074063, 0.13914131373167038, 0.20227831868188723, 0.14939187440489018, 0.17541582297001565, 0.14094533478575094, 0.13634034831609043, 0.1113353150763682, 0.11941692499177796, 0.08498904880668436, 0.09397853857704572, 0.11139434083764042, 0.10650871228426695, 0.15421187505126, 0.14442199894360133, 0.1158207572464432, 0.10805982976619687, 0.13610071688890457, 0.14603270537086896, 0.11577377548175198, 0.13258376132164681, 0.09999833162873983, 0.15860870054789952, 0.10959822471652712, 0.09680982772260904, 0.1383981550378459, 0.14109856156366213, 0.14082322562379496, 0.14768383891454764, 0.1943395132465022, 0.1083217171419944, 0.08085041945534092, 0.16484781647367136, 0.12489217333495617, 0.11709003842302732, 0.15587477439216205, 0.14637455131326402, 0.06671561899461917, 0.18869900091418199, 0.24097310804894992, 0.08002295278544937, 0.1395515560039452, 0.07318956231964485, 0.07264622540346213, 0.1371703730630023, 0.11423754505813122, 0.26917997162256924, 0.07646096284900393, 0.06030703216258969, 0.13753233078335012, 0.2031672674098185, 0.1717097596930606, 0.14992170168885163, 0.20774121768772602, 0.1550238507666758, 0.0992997187588896, 0.14576465689710208, 0.0689658989597644, 0.10030314991516726, 0.1887658501842192, 0.10296117514371872, 0.1980860579226698, 0.08730163185724191, 0.12746819082115377, 0.08299309733722891, 0.13999457151762076, 0.10894712965403285, 0.09888145620269434, 0.11337902184043612, 0.17146193156284945, 0.051351910190922875, 0.11059162033987896, 0.0809645965429289, 0.13013439918203012, 0.14544080570340157, 0.2042344944285495, 0.07115051030580487, 0.14671607155885014, 0.1348276630576168, 0.14522355236113071, 0.12417444613363061, 0.11374937303896461, 0.08157698796795947, 0.16964940167963505, 0.1311976228441511, 0.1185184767735856, 0.13326544474278176, 0.18659147114625999, 0.08697400122348752, 0.12107117979654244, 0.13019257677452906, 0.09745854112718787, 0.19217494582491262, 0.17017730192414351, 0.11164309177547693, 0.108324030946408, 0.14316172871206487, 0.08239947419081416, 0.07924315998596804, 0.09430651526365962, 0.11572532808142048, 0.11905233455555779, 0.14852125969316277, 0.1634460309786456, 0.17124226263591222, 0.15531578367309912, 0.18751849925943784, 0.14454214035400323, 0.11787755973637104, 0.12110818709645953, 0.09623991258974586, 0.10387296336037771, 0.09697071516088077, 0.10637064397867237, 0.11452768663210527, 0.1487002165189811, 0.1277764628508261, 0.19788628364247934, 0.08826171141117811, 0.09111622681042977, 0.08637755537139517, 0.09191438076751572, 0.10533512490136282, 0.18321042614323751, 0.06928930232035262, 0.19994680450430938, 0.09519625109221254, 0.0687920990000878, 0.11396398688001291, 0.15099560549216612, 0.16704913335187094, 0.09981594820107732, 0.11932771120752607, 0.162494087059583, 0.09850541888070957, 0.10041153909904615, 0.17064125702849456, 0.11581380904785224, 0.10613591835967132, 0.21303683067006723, 0.08867438962416989, 0.10085202367710215, 0.18862987176648208, 0.12715899598385605, 0.09724580682814121, 0.1930966270821435, 0.1529105941631964], [0.04602477925696543, 0.037759496697357724, 0.08201357096965824, 0.07820790553731577, 0.04996136462848101, 0.012846636502737445, 0.04432996841413634, 0.047178434673696756, 0.012471251422539353, 0.015079862338357737, 0.08717094601265021, 0.06646660342812538, 0.016212456028110216, 0.05883884523063898, 0.024432498961687088, 0.04517643067187496, 0.033558856030660014, 0.02600487833842635, 0.022419436535398875, 0.06341412543718304, 0.07578597656850304, 0.05345189804211259, 0.035223645091589005, 0.03467572467135532, 0.012859282699147505, 0.07267684090350356, 0.007957784059856619, 0.008619366729232882, 0.0330741547181138, 0.04000836530966418, 0.013491968258417078, 0.04686813382431865, 0.03283426544762083, 0.056150251999497414, 0.01747498069224613, 0.047439063367034705, 0.06817690522543021, 0.01976049698090979, 0.03992803694148149, 0.052884527415569337, 0.030252127575555017, 0.029441363045147488, 0.02778398528295968, 0.051816418301314116, 0.04078912162887199, 0.029367741995624135, 0.02817932522988745, 0.016752763285434673, 0.030395681836775372, 0.010635156018127288, 0.030265447217971087, 0.043532038373606544, 0.045921543546553166, 0.07727114044662033, 0.028467105501996617, 0.015190785850531288, 0.05871731960879905, 0.00507899491848158, 0.010644820053130388, 0.026959697549630488, 0.015944863869143382, 0.005933128014606024, 0.007722280670090446, 0.024815360649621913, 0.03040404138820512, 0.03924595318468554, 0.00953384448907205, 0.07064903900027275, 0.05623577116057277, 0.08076034393161535, 0.06755185912230185, 0.021057089191994498, 0.0367152313036578, 0.01875421088854117, 0.08882703964731523, 0.015691252924235802, 0.03602447586932352, 0.01928226210709129, 0.03400126764816897, 0.04374901351651975, 0.016849227216360823, 0.025079276845125214, 0.04356759021590863, 0.04468277608975768, 0.0527459875281368, 0.016480624941842895, 0.02946312366319554, 0.08174799914870944, 0.016983122531590716, 0.0156486816371658, 0.029724234116396735, 0.04475953536374228, 0.010982024815997906, 0.09362021101904766, 0.02170590098415102, 0.016355806728824973, 0.004569681020387049, 0.07298648357391357, 0.024033315113878677, 0.038461217257593355, 0.012592231671858047, 0.14821697744940007, 0.06944747561854975, 0.0131347000632169, 0.023483264093686427, 0.022548821289092302, 0.06616124231368303, 0.03321670135483146, 0.039114093474511585, 0.03629820368119648, 0.0121035906153598, 0.022684141527861357, 0.04703684816403048, 0.029707447160035372, 0.08430779964796134, 0.023646506048472862, 0.023033958560388004, 0.0391295505022364, 0.04547878248350961, 0.0493173670422818, 0.026850241369434764, 0.07540110472057547, 0.03345141679580722, 0.049008820205926895, 0.016987280254917483, 0.011316794486317252, 0.020710844646341035, 0.01399916724767536, 0.005972550051020724, 0.026014912175014615, 0.009188895097135432, 0.011188332540249186, 0.048945740197918246, 0.024586629887510623, 0.03869037888944149, 0.05054852133616805, 0.02432617761327752, 0.052240875882229636, 0.019985619633059417, 0.02542825079789119, 0.06856475584208965, 0.048059054384274144, 0.030770928665463413, 0.016968126907678585, 0.1016272838626589, 0.011319891150508608, 0.049429233718131266, 0.019262063815923672, 0.0263174437984292, 0.030441011368696178, 0.020577139320916364, 0.02889363600739411, 0.03503614550988589, 0.017930657669369663, 0.05989964652274336, 0.036693144988800795, 0.07792124484798738, 0.007959766230279846, 0.05292173827599202, 0.04013507493904658, 0.013025438961839038, 0.04364212728770716, 0.027685550207804357, 0.07337281427213124, 0.06542215482997042, 0.024673711375466416, 0.023420165425964763, 0.03347441913293941, 0.022739976478208388, 0.04085841701765146, 0.08070570150656359, 0.03012243239209056, 0.052729271817952394, 0.07023139391094446, 0.014075448154471815, 0.047277897729405334, 0.02053073261465345, 0.09120385960808822, 0.08597303314932755, 0.004414303710551134, 0.0039765913721307045, 0.014835973103929843, 0.05594004524339523, 0.02548024015102003, 0.04278135133375015, 0.06454456477825131, 0.05692096600042922, 0.07295010052621365, 0.04061333356159074, 0.01747189844692392, 0.013836000779909747, 0.056770558535520516, 0.11272321774491242, 0.012733865678975624, 0.026060153497383, 0.08577747935695307, 0.06499201791094882, 0.0250617384112307, 0.01644493908887463, 0.05561846035665699, 0.06310833684567894, 0.053374572191387415, 0.025779916838343655, 0.024716715228610804, 0.06184824981859752, 0.10525644876595054, 0.05578423324706299, 0.02856956428981253, 0.031199443885790448, 0.036416703036853244, 0.026813457986073833, 0.023218364022406082, 0.0806699019989797, 0.02776231287446405, 0.05107676763353603, 0.014142840252523976, 0.049057325281734974, 0.0582542194585715, 0.01843000346395586, 0.008707837517639356, 0.10123629162886313, 0.051044469366648366, 0.050009900238364935, 0.041083578685564656, 0.05336074025503226, 0.010123732300209147, 0.011975962419195898, 0.0607376169147236, 0.01824427825132651, 0.00435359009342002, 0.032187251773263724, 0.05591203531782542, 0.07888654233621699, 0.017185933255989636, 0.004987805749156645, 0.03287613445094653, 0.03793971220563565, 0.02512709829690201, 0.015605255395972302, 0.050076233821788003, 0.03264982266617673, 0.018227538792416453, 0.02384249071058418, 0.04560806715328779, 0.03200391161122492, 0.04800702092636909, 0.07141724242163555, 0.004020664342013853, 0.06388549014393773, 0.05108136470828738, 0.04940590229151504, 0.04492965766361781, 0.07331633301717894, 0.036942968011966774, 0.028481436161590473, 0.07082505776946034, 0.009196162207185157, 0.05092872486316732, 0.021297202379043614, 0.052256217559001276, 0.043067028147301505, 0.019268855951460342, 0.030419148970395327, 0.06326801649161748, 0.019083410634526184, 0.03582351415285042, 0.026582920624475394, 0.05861088460577386, 0.018546915047668984, 0.05724802666476794, 0.04423850189362254, 0.022801044629886746, 0.027312405141336576, 0.05195751626576696, 0.017045200004109314, 0.06135022547096014, 0.021602994363222803, 0.046361675286399465, 0.049841867826346836, 0.07180776646626846, 0.0260328679079456, 0.04697034494685275, 0.018492801879931773, 0.06782596691378526, 0.04658721014857292, 0.037013009789266756, 0.0056227092697684255, 0.030683027846472602, 0.03538834250399044, 0.02094535483047366, 0.023740364404927407, 0.02312821725250355, 0.09541743315224137, 0.037275999784469604, 0.04060320642643741, 0.0578833186466779, 0.04842239631606, 0.06601402057068688, 0.02029499428213707, 0.06181794644466468, 0.024373055901378393, 0.020970114573304142, 0.0287280191800424, 0.01697455093796764, 0.014246699366984623, 0.05362279726458447, 0.05876830473010029, 0.030125692752855163, 0.04390149390591042, 0.033643961285373995, 0.05597822301621948, 0.06436073607099907, 0.03512870447177972, 0.004355525190476328, 0.06029681342520884, 0.0321811415654208, 0.008797029249503143, 0.005537697737703898, 0.05539241320054446, 0.030350216597850834, 0.05227120979023831, 0.023398060451394746, 0.08983530875827585, 0.01861669558898679, 0.04334005367543016, 0.03917476807587913, 0.006440195537704442, 0.04933985369279981, 0.047002748386668305, 0.011209773398669702, 0.045851315172123056, 0.030100936402699778, 0.038458672751273425, 0.061093902082315514, 0.016836245145116533, 0.05727111042610236, 0.017988331449617232, 0.006488578477209168, 0.02633733844517597, 0.015246690350717731, 0.06419268330293042, 0.03836801029475672, 0.03199531117986355, 0.06093746583376612, 0.019355576119518707, 0.06391512855355229, 0.08011000882834196, 0.044413954086069546, 0.061004796863666604, 0.08204037988824503, 0.022495286572458487, 0.082695647941104, 0.10200963834566729, 0.15128988612975391, 0.1767171581408807, 0.18826545774936676, 0.11727758550218173, 0.04473320820501872, 0.09522536702986274, 0.10935216756271464, 0.10212668563638415, 0.16075957513281278, 0.17555714824369975, 0.207255359472973, 0.21266556344926357, 0.15606646053493023, 0.07911619929862873, 0.14898252779883997, 0.20651529489883355, 0.07558266033551522, 0.1381370411919696, 0.1812246119869607, 0.14904161462826387, 0.16110819285469397, 0.08200584924114601, 0.12075591885617801, 0.11802470684051514, 0.12445169554225036, 0.07931262161582708, 0.14454874928508485, 0.14772780798375607, 0.1903892180749348, 0.3425427164350237, 0.11685964864279542, 0.08805403219802038, 0.09387652762234211, 0.08741061815193721, 0.11091711358832461, 0.12412096400346075, 0.06845682806202344, 0.18223576487175056, 0.1517589981002467, 0.18420226792139666, 0.1630225708442075, 0.09349707048386335, 0.09513886060033526, 0.21108779311180115, 0.13632603122719697, 0.13775041193834373, 0.06137276640427964, 0.14035491432462419, 0.08000928709017378, 0.1391480176576546, 0.08664346645985331, 0.11194255642060723, 0.16491499144051755, 0.17103042400309018, 0.0919672522161688, 0.1627512654023511, 0.05420136032626033, 0.0749514667051179, 0.13513582652168615, 0.09000453539192677, 0.08713864774576255, 0.054504953856979094, 0.15022512897849083, 0.10007045311587197, 0.10080479085445404, 0.12658110127917357, 0.20486912823149137, 0.15531435874955996, 0.15716409949319704, 0.11329634913376399, 0.10354415886104107, 0.21760208212903567, 0.06303244270384312, 0.14333844637232168, 0.25370028082813534, 0.09600581800831215, 0.1484087043042694, 0.1009971351761903, 0.1809251880539315, 0.07690853133265461, 0.12944052927196026, 0.08689315377601556, 0.14657087863555976, 0.08946522218840462, 0.12549150974622794, 0.22818375432065555, 0.15254771363522324, 0.13316293167216436, 0.09739061298647098, 0.06861842796206474, 0.20164318276303156, 0.06071154081395694, 0.13627212840531552, 0.19070538825222424, 0.11116209187145744, 0.09282595185296875, 0.18065993514444145, 0.11909578793815204, 0.143739609846047, 0.08446031396410295, 0.2618607229420117, 0.22429602007780755, 0.152732180165393, 0.10534647000687462, 0.18115272798708507, 0.13023596230362142, 0.1574034866477762, 0.12316769015576158, 0.07962072401174478, 0.08526350265102726, 0.20597945579460689, 0.1222583989479712, 0.06461965824876513, 0.2205800094774791, 0.1084783026682479, 0.19573235564998218, 0.15271870445992264, 0.11294609614248786, 0.16613609663077764, 0.12977274001709052, 0.16936945170164108, 0.06367175839841366, 0.2205807694367, 0.08215619903057814, 0.11181654568229403, 0.07409700791218451, 0.05914638444249119, 0.10251175425946712, 0.1374666350228446, 0.07690636680594512, 0.11553251557052135, 0.14060224033892155, 0.11055782251060009, 0.13703807230506623, 0.14072790502437524, 0.09588165967059986, 0.13618799006300314, 0.1438643652945757, 0.056276323805962286, 0.14975000518773282, 0.10094795495803867, 0.22570938138025148, 0.10855429859033652, 0.15326647220977715, 0.0963940146778311, 0.16949260580752576, 0.0692021648532578, 0.13648940888898714, 0.048982238596571345, 0.060590876931590695, 0.0753426014312676, 0.1953247460935797, 0.10337434868727412, 0.17307828340147222, 0.1407630124262401, 0.07684376516512462, 0.11004698742181063, 0.07510085297482354, 0.20538132717566832, 0.09103895524250609, 0.15003360568412713, 0.11539184169045516, 0.10983812077237026, 0.1510260717145034, 0.12512284809989588, 0.19442438440663473, 0.16105665133467742, 0.09183990476386887, 0.1664068999567202, 0.1030289607920817, 0.13185656177146093, 0.10243868282330887, 0.28151948377490044, 0.06637074000069074, 0.14765390194952488], [0.031570595755640946, 0.04578034719452262, 0.01916760834865272, 0.05665080049740417, 0.04474944215533989, 0.027348738995247653, 0.038763945656163354, 0.04973061861736434, 0.02779192753535296, 0.021771528891154697, 0.015101321008322495, 0.04541855910792947, 0.012828552696321691, 0.03057066584005952, 0.0698369275778532, 0.0532483680705939, 0.022946760025141493, 0.024462030502036214, 0.02826710051989981, 0.04864980732756002, 0.04868454492783972, 0.061162183061242104, 0.09033095823334795, 0.06526049386177744, 0.011768747154357178, 0.08618816946234022, 0.07996062255863633, 0.02204591148932065, 0.07003366880651031, 0.10313247809452669, 0.022605212638154626, 0.013201854674012532, 0.08336137221860034, 0.06584463108863149, 0.03462151650871549, 0.040615209710917304, 0.038295885414949486, 0.04600264883733221, 0.016147930740511844, 0.02962746823738728, 0.0029558728399154332, 0.025708736818549887, 0.03278614713677338, 0.032258606515824795, 0.030936888152999536, 0.023653966541002904, 0.07206046647791352, 0.02160602232574352, 0.037529938122523684, 0.020971690470884954, 0.02675378761653389, 0.028737946147365228, 0.0265011876888041, 0.005623214778357318, 0.038762988921787055, 0.03753569549215691, 0.04070840310305357, 0.03615321431841169, 0.020448684160198485, 0.04791913367807865, 0.021875638215403472, 0.030006860915039266, 0.0439362450768905, 0.013496168390182512, 0.07925369763480765, 0.04078425653278828, 0.05479765011529837, 0.03231853812134691, 0.004654732840468309, 0.06046318342643125, 0.04870278734181609, 0.051028004714420865, 0.02043275215796062, 0.05101625248789787, 0.036835773049720695, 0.09624115430882998, 0.05982531301145043, 0.03701323370582291, 0.07350162736007146, 0.04299628069358213, 0.037915295122989585, 0.03500674119485276, 0.04454612931502717, 0.08236948294298989, 0.04838529062856521, 0.06737338405634676, 0.0051298892857240775, 0.03263899663995419, 0.03109282228563513, 0.04281687603465148, 0.029039541392454078, 0.03951327223330736, 0.012115400517359376, 0.008953813247249594, 0.07037628827882664, 0.0018162071189310933, 0.04191949311643839, 0.04443919558876327, 0.056462374715400596, 0.044869841409048865, 0.028894837014377117, 0.06892965161906821, 0.004789789298748863, 0.04189206673098462, 0.022470698159720217, 0.005544201071773256, 0.04469795831079994, 0.06087411101907492, 0.031063204232071127, 0.020225020358338952, 0.04787887280274715, 0.009427931958011218, 0.1007970826966422, 0.034072269552520344, 0.003413171091649149, 0.06012031289615801, 0.018909334171829478, 0.029921826906502247, 0.04882699317697968, 0.053240907578063865, 0.015637178772262166, 0.017837394727393985, 0.021928350208327174, 0.06253687465297324, 0.039211280045232604, 0.040595868070210726, 0.008003878640010953, 0.01747606465193842, 0.0849359602268253, 0.02965223476556795, 0.06127381564251014, 0.029536117067826644, 0.032174213722880395, 0.046374044979789426, 0.045146785476910214, 0.09606873177524124, 0.034257323015481234, 0.014277711810011948, 0.018962670416970338, 0.018176906509324908, 0.030577169598213265, 0.02155196513714535, 0.027293038055566803, 0.10636060844574656, 0.003833869588561356, 0.015467485645785928, 0.022454386177871908, 0.028347474689196264, 0.01030162297787943, 0.009928868069047374, 0.05982821714133024, 0.06525598838925362, 0.01057780793468867, 0.04621005663648248, 0.028978480026125908, 0.005490243967090334, 0.012278017371759882, 0.008933735396047788, 0.02400626870803535, 0.04464513435959816, 0.06365140913320438, 0.017794278915971518, 0.039833927527070045, 0.050715488448206864, 0.03619431996984141, 0.01497839081899396, 0.08153770757572991, 0.015809852363807813, 0.03287489273186241, 0.05349281370373709, 0.07860062803540911, 0.08783459397298948, 0.038165101182780097, 0.02769899707553642, 0.03934293958757605, 0.04526338832718985, 0.03279418438406927, 0.026575534770797406, 0.026378805416503122, 0.012944576247329158, 0.026457707164809108, 0.02308030759117433, 0.017642446527523652, 0.024169461469032934, 0.032932771768953116, 0.06101031335336821, 0.011375709137480174, 0.0618711028780256, 0.026414216462788836, 0.07490941789001226, 0.03899729384907654, 0.03413019608706236, 0.03468795187239136, 0.018859899503045847, 0.10236042737960815, 0.017672084937138215, 0.023252708072374974, 0.020525630031313215, 0.04055882005819252, 0.046518891850220304, 0.050435962554599555, 0.04683380673772522, 0.02657438295760325, 0.03106767577784402, 0.047644625550934246, 0.03498193734724607, 0.014017471577972174, 0.0703818794073803, 0.05028060856940491, 0.09089138744665043, 0.003683025316734399, 0.041532589056129963, 0.018619153582091843, 0.012129391061275132, 0.043312712106853724, 0.00940689567609557, 0.0042008497403003275, 0.08868431659149272, 0.029697513407362357, 0.020706452828432833, 0.030751027233366455, 0.04255282413214445, 0.025436540799481527, 0.01511382810505373, 0.024969087847109352, 0.05620147121538009, 0.03130665920408709, 0.005394397927115538, 0.0381444160427366, 0.04019915239353265, 0.02269085223919579, 0.05769556800701788, 0.012361156571257328, 0.039387695757406097, 0.0583334927048002, 0.07138277284268822, 0.029188802133181264, 0.09978514271123068, 0.07873580578182425, 0.015298615243019802, 0.04023814440837928, 0.04561046577457871, 0.020046251825988293, 0.04388803177114044, 0.033667699833001406, 0.07356986762689692, 0.07288296627146856, 0.005943791616508471, 0.024482768228543655, 0.006901500962807664, 0.021130106345351254, 0.03289920464158058, 0.029423157950597148, 0.02380993290405188, 0.03454454688887511, 0.035784837656787465, 0.04430306789332202, 0.013799734779500535, 0.03500511949615819, 0.028517144066946845, 0.013428453139827719, 0.031568801030516624, 0.047397448814341, 0.03617367893457413, 0.052151502642248354, 0.04132094380578824, 0.026563982712104917, 0.04219439479389361, 0.016697496608165757, 0.061485226798270426, 0.045701901761016676, 0.054573577496090105, 0.0342879622642483, 0.01828235594023551, 0.05709047083343778, 0.02534868578160448, 0.06999145035765, 0.048049622747514925, 0.04289692620347653, 0.04034539365342685, 0.02166946874266224, 0.019447773761515106, 0.05634332235370364, 0.08862962666898966, 0.0256206985962178, 0.012018835654349198, 0.05324115863602076, 0.02681645202184362, 0.059575408564082215, 0.046912482873137505, 0.0576765825971961, 0.060413372170712264, 0.01829942618496716, 0.0300918881382261, 0.023328648015324558, 0.038142010636095486, 0.05223696073517203, 0.028077823176447834, 0.04706369100936821, 0.023409235923151885, 0.008800745076899017, 0.026041198621637056, 0.028201070580897585, 0.06566714668380362, 0.029437302013060877, 0.030988908040204217, 0.005615922223244394, 0.035821746569126844, 0.015083224479375141, 0.012741005563709353, 0.05822850298136473, 0.02800941836488034, 0.03456683337156262, 0.03475601911278708, 0.027411277871578932, 0.032923421556396146, 0.008057796728930302, 0.03878728047545467, 0.030131043001477207, 0.037471434833215814, 0.009160412741558892, 0.06135148076074464, 0.025185009564406106, 0.023958879822332944, 0.025813522981479764, 0.05227937935186284, 0.05261929825480495, 0.07368204303617988, 0.032349940722009966, 0.055794323062790294, 0.03563245565497449, 0.024868057375507693, 0.0760857058422906, 0.01738663712915565, 0.06488192560417311, 0.03560258654345359, 0.024943683496011154, 0.029740193260035346, 0.07609882192420107, 0.06366365669029099, 0.019153087699253644, 0.034481293854436705, 0.022901366032393913, 0.03777279259104814, 0.037306211556174924, 0.05277584985430751, 0.01676738741142409, 0.007537792935701353, 0.033371556616787396, 0.03807501887370433, 0.03767195889460189, 0.009003821278123983, 0.12262587994337082, 0.173291859083942, 0.17244993283280305, 0.11513346912605421, 0.09451890350984675, 0.055848670325108936, 0.08221240208617278, 0.11129527472491775, 0.17545539513230324, 0.12505133050893033, 0.0721124354749918, 0.15864699706435204, 0.14123249080564293, 0.13911371092711175, 0.11775303498974868, 0.10811977833509445, 0.17731335972036633, 0.13157758888389381, 0.10656990935759884, 0.17848269268870354, 0.12643022223242692, 0.11627220016505037, 0.21125813254288264, 0.12371868773230485, 0.10055804838027273, 0.1611973794975451, 0.14706785125391825, 0.16521338400031838, 0.15798903522746904, 0.13604202360979148, 0.05965823054845844, 0.17065364707793507, 0.12126123745526586, 0.2185420702610697, 0.10577356708901269, 0.1398790848574468, 0.10834041078175817, 0.18018918111920357, 0.1178125153694834, 0.07182035329086439, 0.09487911739519664, 0.20637639878051622, 0.08949235680380038, 0.11440314831478254, 0.10956277804715292, 0.07028374967298337, 0.16029632570488112, 0.13152627806578363, 0.11620516090520791, 0.06333323727760996, 0.10259070180888687, 0.08805441896298102, 0.13151289735521587, 0.137716037354299, 0.12294316291809082, 0.16696403148983205, 0.1299231712307249, 0.10974514111876488, 0.16115122554557665, 0.1106723795777985, 0.13794878843639577, 0.18522103396909578, 0.14244465290435723, 0.07625493247594152, 0.19735203231019632, 0.14957573025354318, 0.11049362631248576, 0.11717010555522782, 0.11247433788542237, 0.18177581312400953, 0.1548632958105632, 0.14667545445263386, 0.09750331765306847, 0.15153201456580842, 0.10377102025917598, 0.15275158626692636, 0.11084419821522065, 0.08691123673426253, 0.1337372844240495, 0.10972577572933265, 0.15868377366236278, 0.12338795619351522, 0.15952261936451706, 0.20669889290417942, 0.15909534586327417, 0.14727768142308506, 0.134483971499971, 0.09904927826885666, 0.14125059411994048, 0.1723923116390194, 0.08385449075805289, 0.11262339167296886, 0.10387869019593511, 0.09109525329300336, 0.16487201303243637, 0.11313380607004676, 0.1453705501875707, 0.15385017517421926, 0.1024491119065455, 0.09825261030346155, 0.10225429771734135, 0.11682141997984477, 0.07968356992517199, 0.14161202258297376, 0.07558940497360059, 0.07868729731334106, 0.2117982871298279, 0.08922020319317069, 0.12933812476694584, 0.1114758803908314, 0.10409639137131826, 0.09480140477951084, 0.22243046946823597, 0.12310670342828546, 0.10014141430812222, 0.13660944173378603, 0.09510257933288813, 0.1333959541682686, 0.11241775485021727, 0.1582294266138758, 0.0999643641657063, 0.10210506072533981, 0.12116685323417187, 0.18410985145185674, 0.1440595391073397, 0.12911533457892282, 0.11151997838169336, 0.16405861239348138, 0.15662675404122897, 0.09554511308670044, 0.11309580810900245, 0.11286697217396327, 0.14514682362122194, 0.11648671222584588, 0.16978466085025243, 0.15867833181151322, 0.13495948884103978, 0.08773723098316363, 0.13160660304129124, 0.09078576668564763, 0.09637511069221155, 0.17846657069666044, 0.09033917529242379, 0.16034705298287527, 0.091308896828975, 0.17588317074945994, 0.09233801053570849, 0.07699336856603622, 0.15822623749928816, 0.146429892629385, 0.16425491257437638, 0.10207855036216122, 0.09256225957402162, 0.13380804205579416, 0.12631879321166448, 0.12131630735737936, 0.21198727270322187, 0.0506727984175086, 0.2018397950700351, 0.10372343459831816, 0.24655916116067342, 0.11976216360926628, 0.13624037296644279, 0.11537527186529976, 0.12008301567818437, 0.12653733577047074, 0.11128689481743745, 0.09928735585084983, 0.11242665722966194, 0.13452661064054283, 0.14665978029370308, 0.13274580905480043, 0.12043928727507591, 0.128177354910544, 0.09162170147257191, 0.1441802911992584], [0.09980825361396585, 0.0517623560237033, 0.016154755106461898, 0.02526882560258465, 0.03616979092891727, 0.025820138697911586, 0.03334514464118651, 0.056933389976620674, 0.035643855043287785, 0.022284304590097496, 0.06132058027599539, 0.015374621343133705, 0.045616141720009704, 0.035149060522339175, 0.05823959702891963, 0.0367652359418571, 0.05307363512526665, 0.018549222066732388, 0.04779199996430959, 0.029937843725617443, 0.028852811947997128, 0.027760720013507774, 0.02386123184779925, 0.039473126708929024, 0.012801231483795812, 0.022961781094116823, 0.05471271788701415, 0.043093932060790915, 0.04191108946023243, 0.027679813194221685, 0.054731526877731085, 0.02630990357803447, 0.05401034254048552, 0.057775981192077906, 0.04055080655962229, 0.0665008355198162, 0.04596686968579888, 0.007117588921183986, 0.021792672042335783, 0.04845501010173133, 0.02839032417562391, 0.08045401251209633, 0.03695248785827841, 0.021877699265522615, 0.016933708218857646, 0.07613789197057486, 0.024375362920441797, 0.028046797162720134, 0.029311708573784147, 0.0076082002737426335, 0.02115232327819935, 0.07941860878573996, 0.062377636054796834, 0.04351554997265339, 0.04259403834917715, 0.04741977940180472, 0.04383607295208743, 0.01950322194690151, 0.016024469597531215, 0.033903504322682104, 0.022949916909315755, 0.02154693888899471, 0.05827743892690965, 0.027081104427842156, 0.025240610420171703, 0.022459734730156403, 0.015650337262611305, 0.018759591671239053, 0.020085021620616317, 0.04536438826471567, 0.06756469700485468, 0.04952391649463347, 0.02881456632167101, 0.08072101604193449, 0.015122608348195041, 0.014632000388311488, 0.030443929069276367, 0.009753811123248721, 0.07113806597356286, 0.030552016305071966, 0.05126255052164197, 0.13340442228530133, 0.039009239458079846, 0.052377906029245684, 0.02354204558235194, 0.03137640921132905, 0.06014541190649782, 0.012195715314841695, 0.04276328194620354, 0.02252467392411615, 0.05882941359387977, 0.04061704175546765, 0.04494350656334843, 0.013591537335222321, 0.040903943324727673, 0.038940191734582186, 0.03259374853223562, 0.06482308983270611, 0.06787180195429496, 0.0194064102667783, 0.030607724030103003, 0.013160855043679476, 0.012604959292470344, 0.01565273249122713, 0.058426893050117154, 0.014764126423480255, 0.03876375227368303, 0.04812440409192017, 0.028765643946826458, 0.02671799319796264, 0.039729124400764704, 0.04692766170150467, 0.031007058851953064, 0.05955968012234994, 0.025881673342415264, 0.033471569285861084, 0.030817235287811075, 0.06921574912433114, 0.04223735284592424, 0.019064175863085047, 0.019337859570181797, 0.05078650392325861, 0.039335591053324084, 0.048180183063128164, 0.005976533899748964, 0.04109153450865831, 0.013976901969207185, 0.01331315138044634, 0.021664160902478864, 0.02786212707204478, 0.03578991309872695, 0.03427369945815631, 0.02731568755448929, 0.051406820637307, 0.027052449894004633, 0.005086517327332071, 0.026253430804769908, 0.030984110797622373, 0.06658109264182192, 0.02859678032941052, 0.007973990868777037, 0.08991300780326128, 0.05251034588686057, 0.023901402817240784, 0.043513840064406395, 0.023553606122732162, 0.06433694663324527, 0.02152666256629995, 0.00746426179206797, 0.016169874563014934, 0.08301852882972785, 0.015635789471811483, 0.08114100207707711, 0.04548495715217931, 0.026944859685110192, 0.060167016461491585, 0.03175578492560557, 0.06140833520995719, 0.050394938327372074, 0.07920812043760504, 0.04352249477856925, 0.07069814457957234, 0.019141515284510593, 0.06386544621948685, 0.03450718675074833, 0.017509121181709424, 0.036009867010372024, 0.02455691005369382, 0.02360181094679449, 0.0023954094878198312, 0.050116399702216895, 0.03482972837186285, 0.029332447996629134, 0.018215733979429518, 0.024671813173751746, 0.04132015331249152, 0.02596597622946969, 0.030623242125979493, 0.02451468481948333, 0.03954259851681335, 0.034269163451556645, 0.04599193137671266, 0.011383335022921008, 0.02808790620682495, 0.06313671318015882, 0.026428521677319492, 0.01863227814569005, 0.005820919102656522, 0.009376040144291307, 0.02843140098931534, 0.0172170780133456, 0.030654064579201595, 0.014842135898236717, 0.04056152402024184, 0.04632299200498632, 0.04650801832654646, 0.028958252897219997, 0.020683231663757136, 0.07613779697567225, 0.0368272879693125, 0.023570613602974584, 0.07950075902044773, 0.05038860759564808, 0.07929033174046449, 0.05819515298519816, 0.028559009677597454, 0.04009760284264173, 0.01591501341733549, 0.03514603086348091, 0.04743461896266256, 0.032244445489985604, 0.044865783769637346, 0.032724129036068916, 0.016672334833336726, 0.016157133371702263, 0.011773917591199279, 0.014217680120574576, 0.061475795161511214, 0.010138828008036529, 0.07833273562469653, 0.03742680758503931, 0.03833083336108497, 0.01034269470255822, 0.048741545262081284, 0.04723431881783264, 0.007918581699154206, 0.022976233890014033, 0.03540240174957684, 0.009765253768169453, 0.025520261842757463, 0.02601959745931838, 0.018327868676611354, 0.021581913976530944, 0.05732042635125773, 0.04305308085999318, 0.04133919979046498, 0.02680557849816978, 0.008554883850073176, 0.017431837739422917, 0.03860977910725134, 0.041718531399965286, 0.0369681043417326, 0.05479544487648776, 0.00929201376025698, 0.03642014999474798, 0.06520962409142937, 0.02910356456413865, 0.029377048103404895, 0.021393907189901386, 0.032560659772051234, 0.05751469771244696, 0.027555936448542134, 0.022049375410590853, 0.021854973431410532, 0.04886255519730704, 0.065400780976883, 0.07593007026506321, 0.015287560211228473, 0.06247572507709265, 0.10323536435940436, 0.013425007030101759, 0.042183371992515664, 0.024193412058853676, 0.03898294283343213, 0.028093943472153375, 0.032363348573978455, 0.010618264737006809, 0.05564686043986252, 0.019757704809308052, 0.04550409183970519, 0.03419138298236898, 0.003103086313266041, 0.031396632947559865, 0.07802592244531427, 0.031451278765286715, 0.029163618305964128, 0.04165094591943281, 0.006766711253606315, 0.008153056260198355, 0.022958271371732866, 0.012495586232814406, 0.02057770250498184, 0.02783302470509495, 0.06678485670792204, 0.025626384719674076, 0.05019627684461219, 0.02857432760564344, 0.1193552054464817, 0.014082734772403325, 0.07033076536442552, 0.01051978555707527, 0.026270300881671052, 0.011387563144255961, 0.023766394704580307, 0.019726420952273265, 0.01270567933430097, 0.05298209735857589, 0.04152424307540059, 0.04834385249497635, 0.008652076357975602, 0.016522739914112856, 0.016583441656881144, 0.03529240783037884, 0.051728754969579835, 0.014799886915300573, 0.04740262942920838, 0.023894018659900342, 0.033857635355421474, 0.04187185995812927, 0.061769003713769574, 0.030071603333843604, 0.017923953743385415, 0.02820958280270653, 0.030985691784215823, 0.07091710104474, 0.03534877373437796, 0.07457209099084139, 0.03300600266084075, 0.01581414749047586, 0.020969162927940488, 0.03667272108473948, 0.023068131280264685, 0.0030231909352421227, 0.01691474825409906, 0.04899191789861236, 0.050259852183184454, 0.03377506442900215, 0.017614000643204366, 0.07712895343346254, 0.046457552284534485, 0.008981746837629803, 0.0643185515488897, 0.009465568599158099, 0.007657982691723321, 0.0024893859517760575, 0.025110187507899742, 0.04478945875806468, 0.029868687436516796, 0.02373591491154262, 0.039754264123205624, 0.04091629605474217, 0.0648620038160256, 0.04597084590100816, 0.024803455752719725, 0.01753246278635093, 0.028263178587492024, 0.00997288548387587, 0.030953230668923686, 0.01291981989717377, 0.03328843268432787, 0.021412633060078536, 0.06532335334590503, 0.22737715260258742, 0.10040298955781118, 0.07844638345496995, 0.1439985523798636, 0.10014123110366718, 0.2119435207652194, 0.13308346165078028, 0.09718940021204096, 0.1969470554696662, 0.1162414625287056, 0.15997406228312425, 0.07889736496976443, 0.10062069073319435, 0.17418288412903035, 0.19853283252034867, 0.11825669796339103, 0.09836825981203999, 0.1381002917353596, 0.16116156641926083, 0.19307249837688037, 0.08680519528154816, 0.10723448691091367, 0.2367645895906857, 0.1530305455837931, 0.11140955359275852, 0.15302503587944166, 0.17579886955874308, 0.11668925492891244, 0.11262764608753578, 0.06064258808536189, 0.10575375386646815, 0.14504900601293358, 0.14839434650327477, 0.13145774602890015, 0.14728756089295658, 0.10441229013460022, 0.12654788020466054, 0.11136498062738351, 0.0944553247785994, 0.08700775834066526, 0.10034170427492686, 0.15593763387628964, 0.08229010113115821, 0.10618744630898748, 0.15174700160111698, 0.150867850918855, 0.12968824883656843, 0.12505944578775338, 0.10446723790041038, 0.08696938040001051, 0.09658068644681148, 0.11543823991503034, 0.12119654592658792, 0.10986828843929938, 0.09494929148682527, 0.09494503028690815, 0.09431417592402015, 0.1517685925854104, 0.12012812468622412, 0.12522960879973002, 0.12077597635132925, 0.13907480372914247, 0.13884089913751396, 0.09328631072172097, 0.0915492678593312, 0.12109335432095186, 0.15542249009013176, 0.09298566542565823, 0.14880868712706224, 0.16385410193886074, 0.2290311631347452, 0.08230521210602351, 0.15533118641802243, 0.13005011156201363, 0.1648511548659631, 0.13743600595210279, 0.06504788169903414, 0.06573069148830005, 0.15296569120671066, 0.16173452138900757, 0.13843005975442274, 0.19775494640426977, 0.16244291194847651, 0.17829392424651555, 0.2123833064522062, 0.1224990753190858, 0.11697138978966645, 0.07539754919707775, 0.12026604371411459, 0.08962638104068381, 0.10966617321329457, 0.1106148940910186, 0.09445835104478256, 0.10765975194850139, 0.11899089999496937, 0.16999420603471144, 0.11065017112663814, 0.11729726301772253, 0.12739435264042445, 0.08837065020842211, 0.19772860567484582, 0.1187574432364532, 0.11588478381080286, 0.09674354842198746, 0.14284899192196981, 0.1493138971605471, 0.07841757285807814, 0.12864159499960287, 0.14898879746241228, 0.14635566089834484, 0.10238303616642952, 0.20758415040160927, 0.12514495477080345, 0.10136313017989908, 0.11299548670649529, 0.16626915734793457, 0.15587993125830377, 0.10991292925817625, 0.09589984440909964, 0.055075706980590305, 0.06349419935473374, 0.11540248111954757, 0.10967707727104425, 0.14039068669080734, 0.07784784771502018, 0.0948593041726521, 0.12330790263201509, 0.13131566079599516, 0.12740364857017994, 0.15237806630986078, 0.11589098562087331, 0.12633786004568848, 0.08878973379198994, 0.183435197653515, 0.11146680837763207, 0.0743174571543932, 0.16789219954184123, 0.1419936985309635, 0.16414067441863672, 0.09631155910236494, 0.17648395922567162, 0.19133350811898708, 0.16655212002141134, 0.0967501030702676, 0.13738541438111238, 0.17203665072364466, 0.10950660891830921, 0.04243151903418558, 0.1108424679509231, 0.13676607475749084, 0.16421079422746385, 0.10342122188636235, 0.17998188867100648, 0.11007446809006588, 0.08108840204243149, 0.1816880649753979, 0.0638832984758275, 0.06779721059969493, 0.16313455626368523, 0.1702947291944708, 0.19563406306718076, 0.15855497414512293, 0.07842630560376815, 0.16288968654615538, 0.11836691919182028, 0.11942548810371331, 0.12815272408936704, 0.0979246064754469, 0.09910257040922131, 0.11332197061606816, 0.22433135818157876, 0.11781902930566243, 0.11468205334884779, 0.11290207279047795, 0.15553640254906245, 0.15187095637832368], [0.029475418717733452, 0.017677436882097806, 0.009816582397823887, 0.040510538898940594, 0.022647068070779954, 0.04198624399889793, 0.05371023328708751, 0.03971482766792178, 0.031332056769835095, 0.048593756942344565, 0.05521401616611651, 0.05902506916650704, 0.05989594850689173, 0.05268907201077257, 0.07690726247216974, 0.0577610262802669, 0.012005335351984416, 0.10019294904278857, 0.04137871427727597, 0.029755840277565376, 0.0828772306974445, 0.02304126807887639, 0.038023874296673706, 0.013509379466995597, 0.09018792983676706, 0.05075325910001993, 0.031203498132526875, 0.006803815244763557, 0.06168356936957155, 0.09487672216658082, 0.02887371421924659, 0.022450681376670088, 0.09336377906480006, 0.08036887672330652, 0.034425898255514245, 0.022788339061662555, 0.06132367439568043, 0.00788250653671899, 0.02742017007299832, 0.048327845853886435, 0.031801426583634954, 0.1056070885221873, 0.042051844764500856, 0.034362068466309986, 0.06835762624229703, 0.052051666392279525, 0.04202216564278517, 0.05699109259460654, 0.02786903964754726, 0.018186261810894524, 0.011128233845478721, 0.048690807806061845, 0.06565925532153674, 0.04314933444506355, 0.04193799676639693, 0.009211021275924785, 0.03624997341207095, 0.04172586636351688, 0.049908133556268046, 0.04846556471394641, 0.013422431141537215, 0.027647452162844793, 0.03337887800963862, 0.03713102399238518, 0.058173324513648234, 0.04284935411331909, 0.036695333264235935, 0.026672784106007645, 0.020005164834271585, 0.05498410475307277, 0.03226903899173651, 0.03340697614476085, 0.03189897956326604, 0.04814378305205277, 0.03277879520984633, 0.05788110662251711, 0.022700287268630097, 0.02435586352034339, 0.027171963659514273, 0.03713014528953603, 0.044006578624248505, 0.025737187791881815, 0.016278075453426157, 0.05521613998072488, 0.03630751657432743, 0.007051826155345354, 0.04634636753637876, 0.04143897497228213, 0.05075123367298927, 0.057980512002749104, 0.01501679590104946, 0.02665225163634334, 0.017185809423348734, 0.04293521932725396, 0.01890847582503089, 0.017074034349726777, 0.020674861934302107, 0.06105289821113859, 0.01804659894800612, 0.014937168120273521, 0.022393949063760892, 0.033758969578359804, 0.021913452971992747, 0.031635741902781386, 0.020565892602982264, 0.016538073109196763, 0.027932294378323213, 0.010261597893466907, 0.05967767057674272, 0.04624284005590847, 0.06286651375038282, 0.05021187975736601, 0.0056030851888603395, 0.025549294659867883, 0.020850309037736485, 0.032427012122103145, 0.0953377459996513, 0.04658614484859364, 0.011964954884855874, 0.03182701413918819, 0.049142525531351566, 0.015574334555172493, 0.033677128077085526, 0.050858985033950636, 0.012742257460818758, 0.03688233073002525, 0.05262115065540586, 0.011744553140098495, 0.01674619167377906, 0.021966304064595273, 0.043595237125243456, 0.05015351217506187, 0.025600559676864316, 0.0472762590673353, 0.041994030188236914, 0.09050214583320276, 0.01652773902086275, 0.041788267836506875, 0.039557835020657094, 0.017200403015262315, 0.08318126866860048, 0.02196186644557331, 0.03668297374887126, 0.007401901031179088, 0.04930214410913842, 0.028009586302297454, 0.022110457132969583, 0.03164053914536323, 0.030324388162365983, 0.05263608521116631, 0.02992642737392868, 0.04891642409243754, 0.026627535998289074, 0.030884084557848315, 0.03439402407301324, 0.011720628843509724, 0.02092284952024264, 0.05945796772305455, 0.05169923869626863, 0.02578978443385235, 0.02119454851240984, 0.05206989523555551, 0.056493651787085195, 0.008279961816567396, 0.005020579838726137, 0.015210497292823024, 0.013992093520105948, 0.06314073010746922, 0.026381276980308548, 0.03152035363018513, 0.017499124664547186, 0.03130076952012522, 0.03508321209145444, 0.0602728882804513, 0.017497462253751497, 0.015756254882684777, 0.022850599738636186, 0.02438819401764444, 0.03563808749562927, 0.009287719481757708, 0.05249012554330485, 0.010562774991350514, 0.06794565370572464, 0.026142649784950272, 0.06410150855247464, 0.006169597044520612, 0.022161711971940737, 0.014460953584473048, 0.006904061160249901, 0.030093638758574213, 0.045580559343631775, 0.025967214555878724, 0.0591384998655745, 0.019584225457427756, 0.010182138050108083, 0.03388254776863115, 0.014548547366367919, 0.05510290605681283, 0.0732612766857658, 0.02032383032409208, 0.07108983570443732, 0.04740736221096345, 0.11407807575804846, 0.04191449909870114, 0.04195780659626637, 0.04391805694571563, 0.061802808328398635, 0.03578695468604565, 0.05475163526300873, 0.041230895423463414, 0.008843184049640383, 0.04868488758802414, 0.009721023462978857, 0.061200296373239586, 0.013063393666275909, 0.1001727015578321, 0.012790832086466253, 0.06906724495014974, 0.039992775967610736, 0.030458860232361724, 0.07103415512080703, 0.01938394906132349, 0.00560157120759998, 0.026229234246004905, 0.023800265476373688, 0.07483080282275166, 0.03279535485697644, 0.02153219941205212, 0.05081760457583836, 0.061519329968307696, 0.03475340675296528, 0.03526122236092176, 0.03618346340954304, 0.0157949483421232, 0.06154053418764046, 0.027947826044900075, 0.08476927131414413, 0.022274474314014827, 0.02554893333997045, 0.020837852831131647, 0.040763788523950746, 0.018471304194203446, 0.05352295083659036, 0.023974387740184153, 0.05538263890360083, 0.012512065303911055, 0.042196674671556265, 0.0167356302762138, 0.039772920443543365, 0.004021510814449617, 0.049840856809169054, 0.04985215441722955, 0.07276634645781346, 0.09437683184764215, 0.04300605159785066, 0.013626635407230683, 0.0255810382243778, 0.02446767421705382, 0.023711740405165722, 0.07170840179813759, 0.027057450697092072, 0.03260306481804166, 0.032545674326164384, 0.01822444806540651, 0.004658817197196186, 0.004653769744826215, 0.03258435082222734, 0.050355318667633195, 0.012741893596415008, 0.02106701785565487, 0.01739900851888316, 0.04011346359870263, 0.023573490591453652, 0.044810554411794455, 0.0251702005376241, 0.02735490518222962, 0.011836807609402707, 0.06904424261301756, 0.032530539602573426, 0.028547277807125022, 0.053879768654171906, 0.006104517054544496, 0.038979943708649704, 0.033387010251837115, 0.13325445247547968, 0.058126451314560006, 0.03453527131517019, 0.02968487229996494, 0.032468657208872695, 0.01956406787836126, 0.01969938472445522, 0.03550220068011965, 0.05661963877667274, 0.03386301274544426, 0.039140624193740745, 0.024588477199098895, 0.013667917477765253, 0.03679405671677419, 0.05170483321749738, 0.06465399212070874, 0.025952108670026064, 0.10233578977308103, 0.029921250151736394, 0.011734082496591976, 0.02874497916283352, 0.07022245081939868, 0.06680923647114209, 0.009647375272054757, 0.017905088773529445, 0.017257276124187877, 0.02100675376797361, 0.029082445161683217, 0.03361341363883444, 0.02240749092639557, 0.04332325314836843, 0.03433569720281022, 0.01849505291985614, 0.0043253358952435, 0.019500668958893845, 0.04904639068990946, 0.02837343204633466, 0.022316406081829752, 0.034019533810870986, 0.006296276987995952, 0.029540378267743757, 0.04695812453116689, 0.03658757511792438, 0.01356952905189246, 0.046737922954240015, 0.035136399058891196, 0.056118432099797895, 0.030145502582724606, 0.061342843009957244, 0.05002167960628867, 0.026013229408168366, 0.017824716300570538, 0.013670479795629424, 0.03849841454731567, 0.031172411050647497, 0.024369064419131194, 0.01569007057696581, 0.040846736037305424, 0.020462480473465154, 0.03423052088224462, 0.02224739737409566, 0.03470653694655214, 0.021248254559135864, 0.023426747215645652, 0.06261622932340417, 0.028294021396764686, 0.040957371172096045, 0.02970426483079791, 0.16276795736380986, 0.08760889965508666, 0.12226396293512412, 0.10190966978136982, 0.1472326945513487, 0.1060568011764969, 0.15374264094446385, 0.1305400545575789, 0.11243608208107096, 0.11741250540528979, 0.09137231271181788, 0.16835205629467964, 0.1735706284110035, 0.0990952965138214, 0.10226999223232269, 0.12608155022774423, 0.167113064921328, 0.23414756144796098, 0.09000555997980492, 0.07367061650646584, 0.12043908371457032, 0.11985441723040172, 0.15668407667960438, 0.13659018490995678, 0.18739871068724565, 0.10632345186812536, 0.1855246512485402, 0.1158792469650507, 0.10258607420005969, 0.19043101583208355, 0.13506030557411058, 0.13202501487519058, 0.1471632532775402, 0.18264915554651193, 0.0740755254934941, 0.09071230169917856, 0.17979012110403605, 0.23409786554319517, 0.08628178015351295, 0.17660445347428322, 0.0689816681135978, 0.21251788708780492, 0.20640187098511628, 0.23105857148766518, 0.20570888317057065, 0.12471770841096129, 0.08266296969460589, 0.09787272568792105, 0.14286936154322966, 0.12041814412389483, 0.14326239616743155, 0.0936168794121061, 0.28913894348910874, 0.1376641294253724, 0.23114854523113795, 0.12705663219094276, 0.13539105068360055, 0.09891114210976021, 0.11940654340599265, 0.15529400269900048, 0.14876338812921727, 0.06311072528894458, 0.07446121158344404, 0.09822334508810725, 0.1516642203288419, 0.07070430567754166, 0.18385610649628298, 0.20279909430869988, 0.11228134895541839, 0.09005486911961011, 0.11165335801030908, 0.10851376290832247, 0.09490912899907146, 0.09003280994615384, 0.1879931345049824, 0.116834054301892, 0.18169096910527774, 0.16596488867487225, 0.11186432133295707, 0.07115070029561009, 0.10450862853654794, 0.10622709311012711, 0.13714248527373585, 0.181930396971958, 0.09812366829386779, 0.13225114345550537, 0.08846211672893592, 0.12707952596247196, 0.08614422753453255, 0.08948888948985509, 0.13740195706486702, 0.10075521708599158, 0.08691252595079796, 0.2020497066634042, 0.09491014001624924, 0.1734908734049116, 0.09256498728479658, 0.18376210225479944, 0.0896913982661707, 0.14568488832030976, 0.12066974490880966, 0.12849314510822296, 0.11705217616898672, 0.16068604907819203, 0.15747349789100035, 0.12717049036707195, 0.10726688017270394, 0.09379496771310057, 0.22236391875360692, 0.1387689472841365, 0.15766506189746515, 0.18386255257896014, 0.08366529483880315, 0.11112228900726352, 0.13912034699959414, 0.13107856708977902, 0.24201642349362373, 0.1389698615031583, 0.10717134244207825, 0.08831741235085896, 0.21971007330077036, 0.11134336928703956, 0.09822725344981466, 0.14471467823854514, 0.10515358964247362, 0.2176899252725499, 0.11610654262559754, 0.0699637932702899, 0.10587373242846557, 0.11064812195088182, 0.14838731688048157, 0.14729720966092177, 0.09420206836823906, 0.11158061905630998, 0.06776491233280726, 0.20816101373306342, 0.058753322676888535, 0.109841167394604, 0.09685670092169728, 0.09485770283000809, 0.21032852599663393, 0.09176747793597834, 0.12135929933616094, 0.09289107085870844, 0.12747899309865066, 0.06416471408946173, 0.0940229215526155, 0.14600294482495102, 0.12798439312194074, 0.13640490413776465, 0.10719589862440314, 0.10026348275797707, 0.12468774430453777, 0.1208962398980345, 0.17190776978220257, 0.1292903966137341, 0.14003129383283003, 0.15068160662693636, 0.10215407809508698, 0.11341267717736107, 0.1196161157318524, 0.14052366598376206, 0.09570405312946864, 0.13704654042209896, 0.0742049492629511, 0.197444367355534, 0.07628047253404345, 0.16946218029728957, 0.07940337567457131, 0.12090803283665862, 0.13807863289756434, 0.11828682491821901, 0.12788403779268265, 0.12836833537689277, 0.06557800753840379, 0.08511377032846212], [0.03991555528981345, 0.03597359931362527, 0.006933491344430617, 0.027967673194195544, 0.04298740206286311, 0.01201978390703776, 0.02245591288166387, 0.010538730254795934, 0.015029966265761426, 0.018058600536148463, 0.004541202905654375, 0.018949164177424142, 0.030149855384869233, 0.04001773248559662, 0.0787748826135482, 0.015866939211264253, 0.048825256127331934, 0.028291400555255156, 0.04136202231581722, 0.03165726503357291, 0.032648082223853896, 0.010412798396178653, 0.03163731610402465, 0.021431560794423734, 0.043352674426777024, 0.029419524395572286, 0.06539978353040558, 0.045800129882991314, 0.024414131018732275, 0.022495138991091932, 0.022097013657912612, 0.031595457278724225, 0.05858703409986837, 0.01848148221948317, 0.032107876746782234, 0.04845749693257468, 0.04373986007911818, 0.027254331025428007, 0.01470749419448631, 0.03187593990670783, 0.05414905206167272, 0.03319895087874361, 0.016012415422924926, 0.01950286401967917, 0.058375127613544464, 0.046252275085342784, 0.07364607389484133, 0.07606596047324793, 0.06917226860033614, 0.019773769125874554, 0.0310650735960475, 0.036162147231932194, 0.011995416866349322, 0.0470088246677603, 0.02434143956218447, 0.03575831711558359, 0.024691950396767685, 0.05334462844101446, 0.053026215705488405, 0.053102656068014245, 0.06659910096121685, 0.04555908710296665, 0.05158574014369931, 0.01790413543182824, 0.03369109232776931, 0.05578468447285039, 0.023589807662314603, 0.04908572197226541, 0.028996152470686605, 0.030145299022219012, 0.020995659720418707, 0.025541722209059765, 0.036732846072741916, 0.023321752403197542, 0.05150722007134131, 0.02115454717672297, 0.07178458771003143, 0.022775594477674792, 0.07962685796831336, 0.028473633008876016, 0.034528027953846116, 0.04609707037785223, 0.05073711335925119, 0.0602410107052752, 0.030777205114385912, 0.026448014292067716, 0.026370927624936615, 0.01087655418086797, 0.010169775990237082, 0.043939532579055855, 0.025697664823383093, 0.01984349708072841, 0.021477690997666547, 0.053409238545490165, 0.04042932504255857, 0.08241134176829032, 0.011150103877298534, 0.04663409013301134, 0.04404184887451785, 0.01881864627024957, 0.0539546280301043, 0.063128896456744, 0.07692704176796333, 0.04984065664133855, 0.030440054634319882, 0.04288664300526891, 0.019101798933531557, 0.02238950805206384, 0.03248649589451296, 0.009913840214721859, 0.021268230630084872, 0.03610513671966536, 0.04852450565834131, 0.013129064829887023, 0.026099469512701035, 0.058719158438699584, 0.016437653319111893, 0.010474853816309145, 0.010122123324046177, 0.028390610856669288, 0.03910672797688416, 0.04357158339449337, 0.03174704200189028, 0.10979592946491071, 0.03145729737090213, 0.0329772124199995, 0.0633207183065159, 0.04239502402820757, 0.06512398618672575, 0.03246766994042056, 0.036925159860402346, 0.05357982224917837, 0.02445842748108719, 0.0862131802631276, 0.02990632238132613, 0.026675238706437603, 0.061254674169634066, 0.02283352779756699, 0.02628538471513561, 0.07375813395317111, 0.014243053937596934, 0.057847593777946064, 0.03517612049888287, 0.04902126453816891, 0.014357107192544, 0.014337940274604728, 0.03872668729828937, 0.06810669720705066, 0.008790337197881724, 0.0343485113366374, 0.06478391122072935, 0.009458166630273419, 0.01146084492626999, 0.06970266585371324, 0.023534727582175816, 0.04332970262372068, 0.02857697049954108, 0.038862641967300854, 0.03638265754229256, 0.023241992308092967, 0.0410708052638386, 0.055713434903217215, 0.04117661262197154, 0.01572971059275525, 0.03565710683220199, 0.007094099735175925, 0.05240755122421043, 0.02833205837357257, 0.029308210725763013, 0.012656175115677928, 0.024683886008071046, 0.04105402848550251, 0.04929304156186325, 0.04871455992438963, 0.03608622594869562, 0.013715641390133117, 0.039760082560990534, 0.02967721503227949, 0.05424377894295113, 0.035653585235455205, 0.028550148010253906, 0.0598283867750849, 0.018691694064598, 0.04994958865323237, 0.04777515533247164, 0.03581311221101454, 0.03414354965622936, 0.03565155980842454, 0.027676167764833996, 0.026445388361545544, 0.058877820282110145, 0.04787287794585739, 0.06567284637796027, 0.028819231249924217, 0.032277632637747695, 0.018329142626108866, 0.0231617267043995, 0.04904056546677436, 0.019596681664032594, 0.039039264632655044, 0.02837666017668588, 0.026307109710095183, 0.11412714741059712, 0.05443687304588301, 0.034203002894563336, 0.03783499728888273, 0.034493677118527036, 0.035287885394479544, 0.02340498999027269, 0.04244512705398457, 0.02427241389107491, 0.09278602685247149, 0.05165530355381114, 0.020296347959499274, 0.045911382484648905, 0.015867359902975813, 0.036502985549824576, 0.020637768121170144, 0.03269055512334619, 0.06118168415767806, 0.025688769229288613, 0.018877171611945544, 0.05095340996714575, 0.05796566565654107, 0.07242743178669896, 0.017255847807973623, 0.011565187496931424, 0.033562825460519106, 0.07593788698847805, 0.07338482434196131, 0.020777334292818393, 0.08412444591522217, 0.059923110263688226, 0.05135669047012925, 0.04636682536719101, 0.017758479408387626, 0.0022696294514129734, 0.02952347935310432, 0.016883966512978077, 0.039722919198019166, 0.05464921718729394, 0.018157003380890404, 0.013704627070442905, 0.025921293002154146, 0.018123802662427937, 0.047717374682958634, 0.06399753663156714, 0.020489735528826714, 0.040635060252887864, 0.02566442169648196, 0.01334478213850941, 0.017636887629383376, 0.06553025902914149, 0.02682981237636081, 0.020282146221558963, 0.02822618994728795, 0.022145338921940753, 0.011059147106217486, 0.06182851802025523, 0.02975832371573363, 0.04136853285932115, 0.028560356569609473, 0.029924876921411072, 0.03816091122903994, 0.010923055882033492, 0.04082608821668795, 0.0324473681726626, 0.07022196227418524, 0.048605519346892834, 0.013768177812120743, 0.04241118333967669, 0.008869998057239821, 0.017432998034304807, 0.04517042563695993, 0.044300791408334456, 0.028637638315558434, 0.03445892934022205, 0.047325639453317435, 0.04588606295042804, 0.03586942043953708, 0.023862388750006045, 0.03524279334981527, 0.011650107002684047, 0.03184863905023251, 0.03619719356564539, 0.027587035404784337, 0.047217192593961954, 0.0403428593251322, 0.04577011827911649, 0.04868425655045679, 0.020978955884597132, 0.0573479545169643, 0.007976533678759421, 0.012149057550621884, 0.046215013334793706, 0.03680401421817286, 0.0333304882847837, 0.040360789612999985, 0.01217715144490025, 0.007581169983106, 0.03211260274318712, 0.03781244278486286, 0.03907805308699608, 0.024861221135194813, 0.05038736587656396, 0.037084530772907395, 0.010876579625931169, 0.07084609914038863, 0.03972157569868224, 0.0621194059827498, 0.0326533476555986, 0.04753749844219003, 0.02708902462784733, 0.040152367403996844, 0.026243317240316952, 0.026972476060369184, 0.01571976496571941, 0.06383671026144709, 0.02884099186797227, 0.014370194436716182, 0.01562599990782993, 0.03196303326902645, 0.03799982023026262, 0.045533248489456515, 0.008739413992900933, 0.025924885845077888, 0.03633819653519562, 0.04060734888272626, 0.05062317375891975, 0.06024981808981725, 0.08254208189568349, 0.046936265525541136, 0.0657207238088761, 0.028656145358192067, 0.018086074419053536, 0.028116592971075858, 0.027101621630468538, 0.024912197774808322, 0.023198637313076427, 0.023410007756735598, 0.07685036052550588, 0.05844213294663599, 0.023019904403814247, 0.01661517165069069, 0.03177081786894372, 0.06233247954930578, 0.05573744825752718, 0.027610597533306906, 0.030863314600927488, 0.030206380744597743, 0.05681655642443469, 0.038670820117528946, 0.10055450642747538, 0.09193491323718003, 0.18845041282474995, 0.11609149271888392, 0.08778337136443172, 0.07625723949500493, 0.1472664177417755, 0.1427815319704158, 0.11080365574785642, 0.1220299769192934, 0.1142326867473977, 0.10289807138698441, 0.064359969326428, 0.11778864450752735, 0.1302614209375211, 0.17692791111767292, 0.196758789143392, 0.16665673655058655, 0.16462235285767488, 0.18211731979889528, 0.07863438515258686, 0.09919609289084162, 0.0965243883963142, 0.11147363443991967, 0.10850274349961962, 0.10160668353949275, 0.15671503144715512, 0.10810706258884498, 0.07456336503050157, 0.10259230993688107, 0.12111525743135385, 0.1948620802057641, 0.14491857801164898, 0.15735540565635475, 0.11968240860317435, 0.15776019250707968, 0.1165477939482246, 0.09969997299568993, 0.20829093961843423, 0.12321319271411214, 0.14183488062449864, 0.10377398545720748, 0.07680514973721334, 0.08196514392537729, 0.136423509567976, 0.11379733189408268, 0.13447627691285952, 0.2217119415955884, 0.12226734203951699, 0.15648654156497546, 0.12225496556077685, 0.08780087078256266, 0.1994392874517611, 0.14400677622428962, 0.14470262745661394, 0.09265821121100869, 0.10124231023447854, 0.16727093287876674, 0.14734465282942566, 0.16808299001838478, 0.1624585318246058, 0.07763801754585334, 0.14725271133439882, 0.09586059115827084, 0.13446533892835888, 0.11263756626950842, 0.16874644798891886, 0.0661609098315239, 0.10686926543712616, 0.16190923058560916, 0.16370249007429394, 0.09353586233087949, 0.10546087779636894, 0.13469111467046396, 0.07924117187836341, 0.1013979593824063, 0.20514260498540743, 0.09173676065568413, 0.20019654610327312, 0.08617219674800124, 0.11813377455941268, 0.12153879898999419, 0.14575533382594585, 0.09609116414295775, 0.16292433254420757, 0.0781639636095081, 0.14631608873605728, 0.1650805811264685, 0.11862141053591456, 0.11089087463915348, 0.08703130350581237, 0.16759413267884934, 0.09863418447119848, 0.12543395640594618, 0.11808987334370613, 0.16441379833434308, 0.05702235270291567, 0.11581371405294963, 0.14472706828798565, 0.10159910430333444, 0.10143903789243527, 0.08121195648397718, 0.13268925994634628, 0.13185437688870089, 0.08018160105815955, 0.1834789088794163, 0.08021280688366719, 0.05861897274319615, 0.08858320808836392, 0.10741013927119118, 0.08623085610036339, 0.10360080974974803, 0.13936692662537098, 0.08237280776458127, 0.1243501595620598, 0.2143416806523289, 0.07275586987712554, 0.1176751120282071, 0.10361524218959467, 0.11237400291221482, 0.14292471643005097, 0.1312090629445655, 0.13594849434282097, 0.2991311587393284, 0.09142548271587916, 0.11345860721277339, 0.2355930038860866, 0.12863817518310888, 0.1340866078223501, 0.06634697770433766, 0.08779882839215652, 0.22071115672588348, 0.17966700771025249, 0.2032962433461632, 0.0905412837330784, 0.20247144331889494, 0.1801481433212757, 0.17383307218551636, 0.09415544622710773, 0.23353907838463783, 0.0912355946909104, 0.138955042298351, 0.14379922593278543, 0.10372333281806537, 0.12224845162459783, 0.16512083182377474, 0.12898760714701243, 0.1640814925943102, 0.06742288997130734, 0.15942324112568582, 0.10342394959713731, 0.1913347973355225, 0.12287988274225167, 0.18719536731285707, 0.16990784209753784, 0.10853548959961959, 0.13639115701828683, 0.15129626435892923, 0.10771997871675662, 0.07598896031933171, 0.13701337363038743, 0.13071542871849878, 0.08950277910168682, 0.1431834146912609, 0.19650387710758618, 0.10332398781819002, 0.15927647400115216, 0.0735652603741203, 0.07725408886160169, 0.16347420375261987, 0.12901386645223412, 0.1325110766504492, 0.17625803420586245, 0.14138444193771907, 0.16355337521859578, 0.1480652027364288], [0.04748062363692692, 0.020168439019471407, 0.02543612689312015, 0.024796453271327273, 0.06739421508141927, 0.026329922057422142, 0.03935438986601574, 0.01717338035814464, 0.03529072845620768, 0.039559863840362856, 0.041611594281026294, 0.12240253335663251, 0.02314156573265791, 0.08226905976022993, 0.058386092739445825, 0.07761175824063164, 0.06636707591159002, 0.02535921834143145, 0.026709036535716484, 0.027177203646195785, 0.0022194999203618082, 0.026206445647403598, 0.020753453252837062, 0.04189760357673679, 0.027004791290632317, 0.07620412377374512, 0.02731777574600918, 0.006184894192431654, 0.10009707883000374, 0.03196455658014331, 0.06825538458568708, 0.021560962511492626, 0.05803575153861727, 0.04491809881957514, 0.02943684739459838, 0.03614343662879296, 0.013752616459636815, 0.005056977729379598, 0.07645427927907024, 0.03255822043865919, 0.012532088872311371, 0.05129143575738583, 0.023406318222571696, 0.062296652900321145, 0.05736573213445289, 0.022018961774717485, 0.07565172162971326, 0.053481112367340496, 0.041631580530000586, 0.013746979529969394, 0.02179766775641058, 0.0291932533229036, 0.0399801416455635, 0.09914301788168293, 0.05460679857060313, 0.03208405677495258, 0.040902745710419755, 0.01742720334524555, 0.0238739323270108, 0.020932438916393688, 0.07276297413877078, 0.044099144371492524, 0.05191227833607367, 0.029620126488485506, 0.01060677713914109, 0.03965961866612945, 0.018288589980719343, 0.030063389667442868, 0.05190171015315822, 0.018630276467385035, 0.011993055564484425, 0.0446110277968858, 0.055641893563526015, 0.04751907282375863, 0.020163521336923753, 0.031485985831490586, 0.012741090380586684, 0.05081846631531205, 0.02120043141102152, 0.05011370591819286, 0.043002170377543995, 0.038155255639659505, 0.03489532235211559, 0.017893440023596798, 0.0354182862543634, 0.01561044788520251, 0.01010019052773714, 0.017055746134636656, 0.04037807868527515, 0.0232673288056893, 0.019168319114084755, 0.0896570576088769, 0.015476834162005355, 0.010127415049022861, 0.012783284232552563, 0.02827126842125186, 0.05023588632632579, 0.019607090391218662, 0.024468491851751293, 0.009159472122389292, 0.0639149182076965, 0.05639997324241059, 0.03205907990091613, 0.03762100770005158, 0.005846406150210116, 0.04228092497214675, 0.007702352096592742, 0.03576379967853427, 0.03792845870235136, 0.03971886155860765, 0.03437747799658349, 0.016400720658046857, 0.05806683522782155, 0.017239766528031657, 0.02827100209625704, 0.012274448277561792, 0.0874833163938352, 0.05392572243830987, 0.03504906142396586, 0.01790070204463388, 0.05195082251780799, 0.05303024620349918, 0.04088273910539491, 0.04294834219451461, 0.004084927121376885, 0.03026266861706972, 0.04370816231572202, 0.0459834768303803, 0.022886378890169517, 0.03225438942068389, 0.01877674164383539, 0.052022947397615225, 0.017827257414215376, 0.058242752216756344, 0.04140167250963194, 0.049046641747866354, 0.039305959429059706, 0.03582620115152427, 0.03547334258577653, 0.04224130531240787, 0.017737047879823616, 0.02968300293598856, 0.01703129173256457, 0.015205406583845615, 0.03800626631293978, 0.024539999264691557, 0.027940764191693494, 0.0119799030113167, 0.08269541723919765, 0.03547305081571851, 0.0683782808482647, 0.03530650778806635, 0.03529173947338547, 0.021910564109150852, 0.025983282265120318, 0.030258458307279006, 0.027217508626303503, 0.004946143274927246, 0.0435522926439132, 0.04496541985177568, 0.018852048852880086, 0.031247155075626712, 0.03832094371318817, 0.04425554330061589, 0.08606850981180157, 0.01139366062956729, 0.03270737600645848, 0.03848879970610142, 0.003816259908489883, 0.032198162616363595, 0.06702439314020531, 0.012613654718734324, 0.020011763587327938, 0.02603838439764721, 0.027352308089445745, 0.03112136825386967, 0.05146811270554151, 0.05250123994691031, 0.0063322948990389705, 0.0349333745959614, 0.028365325249199356, 0.028283763643620268, 0.022154821448826363, 0.026324273253391896, 0.016815751691215804, 0.03362745592104537, 0.038904867201511345, 0.03863194684631058, 0.02811455397334482, 0.03555537746953113, 0.0323171403392085, 0.045121754320072274, 0.07194749039730855, 0.041873820924333165, 0.07945721064295087, 0.017274894285947084, 0.05894294607320002, 0.015353459532239606, 0.032005957394306145, 0.023426226440018842, 0.037479421190385304, 0.05589157070166298, 0.05494150971727712, 0.04061679409018584, 0.04181332952742066, 0.028361172614885227, 0.026351127973092452, 0.03332891069086535, 0.07947564643940755, 0.008428818828958486, 0.0737352469669921, 0.016000960055472593, 0.014208055101335049, 0.08478081319481134, 0.04634647949465683, 0.018523330866758312, 0.03200726696689214, 0.05885270770106997, 0.019107792094083767, 0.014530033538384097, 0.031368589095239124, 0.05735782041613545, 0.04027907024802906, 0.07954284854765449, 0.01834388210305146, 0.013205311809932547, 0.033217610591756444, 0.04071403155103326, 0.03969239530020526, 0.05102555859567864, 0.028156042997060076, 0.008887514438746231, 0.04136278906038829, 0.04906740831211209, 0.07874384642179523, 0.02880390314385295, 0.046538128317998986, 0.012335966806858778, 0.035416240471282175, 0.02566522067146642, 0.0016637401942196967, 0.08488566042589289, 0.021751513804442117, 0.02810185688680836, 0.023139606462791562, 0.019722098684204475, 0.06031996504004512, 0.035620065605533976, 0.031205075726445233, 0.04890161845833063, 0.03290800863344755, 0.013734590328697647, 0.05355507268437317, 0.014760630271796669, 0.062126747731651576, 0.04536327885996018, 0.005314875743351877, 0.004787013242353818, 0.023850046198016832, 0.0545225211286119, 0.02977105642535857, 0.06430669754211392, 0.04853307894830193, 0.036726881749928, 0.047496274047132046, 0.02847570593335799, 0.026315990037151744, 0.040793698347572765, 0.07689285038837365, 0.030045439023524523, 0.03023082496864455, 0.033984100712197166, 0.04191545922575252, 0.04373084234872034, 0.04163633366780622, 0.011887685861438513, 0.08924388406532151, 0.03700606498335089, 0.03960051826600518, 0.03753047077251332, 0.024040755250358155, 0.04550469573587179, 0.03587861119636467, 0.02758448920212686, 0.06594725951020207, 0.10839974866913897, 0.02827223194097834, 0.07322943982269083, 0.005873137461354158, 0.027439732237585952, 0.018811921988214766, 0.0509676931292883, 0.046587987071169276, 0.0333061424483146, 0.009226909173386437, 0.03719956620729395, 0.06698548594223601, 0.02242791822313198, 0.029713099356740713, 0.04459352159340467, 0.024772339833102057, 0.026424053524221693, 0.00391947611102036, 0.029707891600472585, 0.042015773842909505, 0.019617368500413637, 0.013433309754223695, 0.04358052309336407, 0.0943324217306716, 0.05367255423750196, 0.023010817123577, 0.01441336961995278, 0.0491726287374539, 0.06066799922181027, 0.007078708016446659, 0.010855076003021427, 0.012890625927996422, 0.03235980662118111, 0.03146879853946822, 0.015554238044257675, 0.02321023347654513, 0.01347946370619216, 0.018090981923575913, 0.015173393301665783, 0.01357050274964422, 0.03199498209037951, 0.04383167604516659, 0.015689319099432657, 0.031415811739861965, 0.016564917650872042, 0.04775046683581812, 0.016935796410377537, 0.04493940821183579, 0.019259190220119696, 0.050063158451978645, 0.03954908191891653, 0.020277973231194273, 0.034320742290999205, 0.03250045675252165, 0.03358526122091072, 0.09673727875841515, 0.035107771666454415, 0.009946230932005813, 0.038451694018606625, 0.039498351248247285, 0.03773949009233287, 0.04418175261733787, 0.08461553563496896, 0.006280035404155829, 0.037959664527859004, 0.011085074777448816, 0.011581647908315063, 0.13376989481704576, 0.19518903908985002, 0.08200468894626413, 0.13702414876648358, 0.14018310925790242, 0.12309782819024154, 0.13031026188816341, 0.07244214242590324, 0.07837315595575742, 0.13365182972380094, 0.1332085427961179, 0.17088900373450347, 0.18453157453664712, 0.1530509287757533, 0.1393471405442272, 0.1396887693554163, 0.25191288388201166, 0.11129020606832844, 0.2657339365354606, 0.08034886672560658, 0.09776779024728707, 0.18701769970357418, 0.09601234551519156, 0.11148317464228187, 0.1497660864676748, 0.09418778520609651, 0.16584309163902486, 0.10436378845146724, 0.21588479142103875, 0.10624856874346733, 0.236176354012319, 0.14561231221471513, 0.12878518658024923, 0.09112056264919893, 0.11810062133840152, 0.10121240041085652, 0.1492634412965604, 0.1107774575107864, 0.11835846464548792, 0.06719464436173439, 0.06722677299486739, 0.22336477147681372, 0.12028266782207148, 0.1762082161647933, 0.12951153117631162, 0.1566076193537031, 0.14994178632540361, 0.20839333055274828, 0.14937227831355163, 0.14610894556556428, 0.11272378771432809, 0.1255356009517397, 0.1996240932494402, 0.1987423234220062, 0.15316808463207313, 0.07621903118810483, 0.06732820040945496, 0.10581751580217055, 0.11247074843517371, 0.11643757271979537, 0.10169369887028422, 0.10143242896135364, 0.13500463856118067, 0.08801586460322142, 0.10160803382417985, 0.12318405642041139, 0.07627414858766965, 0.1522468647786549, 0.15265660493501595, 0.07169639172830752, 0.0980812937819532, 0.0858825912166919, 0.1777540682149785, 0.14305783143000944, 0.1385936409767185, 0.09452862691666399, 0.15003574985478604, 0.0671594487503171, 0.10641266565237727, 0.09796183090656996, 0.15077675080725125, 0.17571865314883844, 0.176751152745315, 0.12100171138133321, 0.1476900950074196, 0.10879793337413243, 0.10279159567185811, 0.15414320730737277, 0.149721303156444, 0.14864186250737735, 0.14722634346357413, 0.16094028257897922, 0.2303225781236376, 0.10592532823128359, 0.1076576824166945, 0.09808290869529758, 0.16371650860777923, 0.13501915921057972, 0.1181548498570919, 0.11007140789713178, 0.21871732228568622, 0.11030019633471966, 0.10398726258426905, 0.21310741188270704, 0.10220473073422909, 0.19990530530256884, 0.08956464113933699, 0.14814258286995546, 0.16760166441755636, 0.18408132583967277, 0.13434390830142157, 0.14389115385711193, 0.2331317402422428, 0.1295877035175051, 0.12367173310901437, 0.1015242211786764, 0.1329615424786295, 0.09787664762032883, 0.12993649765849113, 0.0800155567537461, 0.1322419018085514, 0.137466322896736, 0.16336612669484957, 0.17597249309931481, 0.09795784790601049, 0.10983911821884768, 0.11011613692556109, 0.19190092624298163, 0.11755756262157645, 0.14153085622404302, 0.11652959563902446, 0.19951324776879378, 0.11586347781121731, 0.1702249622238534, 0.15929304382630757, 0.09911388158798218, 0.1326781048306397, 0.0861532384795802, 0.0758019085707409, 0.0836005083152226, 0.09718144099627223, 0.13407448918691703, 0.1295011495905263, 0.08091159617262227, 0.11424510393823896, 0.07568471878767014, 0.09850953758827277, 0.09648412412830762, 0.1311836043106658, 0.12354047729500703, 0.11259735628430333, 0.12535013018974236, 0.09452268973525081, 0.0681889085099101, 0.1278088561126164, 0.2036035925682102, 0.18743915137435707, 0.0741365665037717, 0.12006214394101075, 0.15230730867811612, 0.1451358042125191, 0.20693091116845608, 0.10856885316648654, 0.19041007624140807, 0.1862326075455972, 0.11875637115112372, 0.19429008875574383, 0.11876992828079633, 0.10209906926112515, 0.1854433084705046, 0.17601980056081498, 0.11380597643022027, 0.14505227655172348, 0.18517330581588404, 0.09264790426407542, 0.11094692841704402], [0.06593621296009847, 0.011249627152990018, 0.061502081608133655, 0.04508123899410878, 0.05384952974106584, 0.037210765427776744, 0.039188118252371035, 0.044292051877294264, 0.01385385388441916, 0.010413141056363071, 0.04202268132939935, 0.017000805154176693, 0.045840858947485685, 0.048183311109564135, 0.0462525668554008, 0.045780432011399946, 0.01790469861589372, 0.009790639459554638, 0.04395667576630201, 0.0035660293402283317, 0.054627154621162584, 0.006081226764113775, 0.020683223182069402, 0.022147374526996697, 0.012644364365509577, 0.043100883652056964, 0.01930457742751709, 0.04118510109505483, 0.00942214999148356, 0.011448301358281501, 0.05657123548111745, 0.054159074023898156, 0.01339594113440918, 0.04214035287233336, 0.021203829175127403, 0.01704444513390107, 0.02169619793338435, 0.05452751853902425, 0.08484326555792775, 0.022562785539776087, 0.019614549187411155, 0.004777115960938058, 0.02228411629662982, 0.02722504545402314, 0.022095897467806935, 0.0198132055811584, 0.014598099082442266, 0.01866746018640697, 0.02121995116717049, 0.05950891213225467, 0.09572507414434638, 0.035908772077943595, 0.04870015801861882, 0.03697131381237081, 0.04025835118123463, 0.016082915211362497, 0.05519822665623256, 0.04820115318787949, 0.0529718989772456, 0.04204275239525097, 0.05500462704471179, 0.039789195105965645, 0.04220796888694167, 0.01065537381717669, 0.05698189165975366, 0.012878520863263734, 0.024212253279983997, 0.058542915752955844, 0.017967707377725413, 0.041928276752254794, 0.06999281421303749, 0.02947745771546449, 0.03747647974107947, 0.0055977519036137634, 0.012077586608938873, 0.04611999807613237, 0.03173514389033828, 0.07447196636348963, 0.03594627470842429, 0.05425034037658146, 0.034065141542149444, 0.03752830624580383, 0.03299973299726844, 0.059484098106622696, 0.0187203587764608, 0.012620804781493331, 0.021769856302333728, 0.025126562254237275, 0.043740111137075086, 0.03629389837650316, 0.034620291753006835, 0.009116138331592083, 0.01698818101015474, 0.05327444417136056, 0.03227183794868844, 0.023097443993070295, 0.02250363933853805, 0.013158199427250241, 0.020474429475143552, 0.07998233567923307, 0.0238485059235245, 0.047144277220858, 0.06258377499346222, 0.02132458465972117, 0.024529081636241505, 0.024599596691716994, 0.016499216801353862, 0.039111535397491286, 0.02954315347597003, 0.039082738371299844, 0.04216976736539176, 0.06290420637066875, 0.033669681155255864, 0.014441798540896602, 0.048274713169251166, 0.023737994621374776, 0.00899157117653106, 0.006041745355884943, 0.02785533493650811, 0.019361033237406185, 0.006926298449148557, 0.04827844850452883, 0.013846547758605863, 0.03629730462229677, 0.017936240316235592, 0.04330249336947288, 0.018989475942882042, 0.005741851961439741, 0.04809671986315932, 0.06496904271521739, 0.013677063281647861, 0.027879821568993584, 0.01599227311089635, 0.07539312514875617, 0.021234135941735337, 0.01452321426144668, 0.03723523000787411, 0.040327751742941995, 0.014679687829422099, 0.03907732705452612, 0.051479620659457784, 0.028926181939563582, 0.04450569202059081, 0.04021461620660765, 0.05200087804613369, 0.08061281006251063, 0.08224704808422498, 0.03716878107349787, 0.04375595832243562, 0.05791605796132769, 0.02371901090789054, 0.05259348339002047, 0.013684060674027672, 0.01925803840692554, 0.049965792069477696, 0.02578476836372699, 0.023009587278855697, 0.008106496883556247, 0.02782540475683553, 0.016410410138113157, 0.008991441406708742, 0.03685032423319561, 0.02158243135948266, 0.0472691785544157, 0.02305267934155251, 0.0015856386931513303, 0.07270167528518609, 0.04681821400299668, 0.024303076888567636, 0.014402189059183002, 0.03230083514271038, 0.03420786799064704, 0.05050249630585313, 0.031599589556987794, 0.015452931069635918, 0.07060650842530386, 0.029374598591987575, 0.020616913347371986, 0.055293574397053034, 0.05179966187902859, 0.026731682641963874, 0.03520458165024008, 0.03459627500602177, 0.03455567147050585, 0.03376562600689275, 0.015421961035047258, 0.03510772416900311, 0.07697187936199562, 0.015396263217553496, 0.07263578274952513, 0.04548610048368573, 0.04797955722148929, 0.054074121439563375, 0.01885162985750607, 0.013670366141013801, 0.03780193567009909, 0.03611372358032635, 0.05439345359003969, 0.054164291958191564, 0.021965435539771403, 0.030969525687396526, 0.05066502919154508, 0.022039102390408516, 0.045236582801278145, 0.018111373597223843, 0.04562267940491438, 0.05517861699419362, 0.05669683909841946, 0.023232711645375406, 0.02241312276705035, 0.05002858709277851, 0.05254419460626585, 0.06029740375067506, 0.046565049194863865, 0.03981036200587239, 0.030614584019141536, 0.02356842702387699, 0.011937581934034824, 0.01666460801581187, 0.03370841532679541, 0.036489587875881364, 0.04829232793833528, 0.031179783333625113, 0.032498305796512535, 0.026638099092191884, 0.05593256439481463, 0.04900485756141799, 0.08606007562151977, 0.06392396986484528, 0.0213254480955324, 0.01165286439936608, 0.016986812065754617, 0.04643007500895432, 0.06401636597833463, 0.0182510602088379, 0.034505083292190514, 0.02901162646178688, 0.037267993071249554, 0.02493060303718916, 0.025675980540524636, 0.027850809107933725, 0.04257665428199938, 0.034113178428794654, 0.04005223599129489, 0.03271363549200552, 0.05558834357985428, 0.10751031818134443, 0.04794429375657013, 0.01121590650706951, 0.018806892347389033, 0.049193907595638714, 0.011724087675767285, 0.018184660468250513, 0.09417532051780395, 0.02153809248868908, 0.03094769043049642, 0.0766235873369234, 0.03238152652712805, 0.013725161236444754, 0.06196010631642171, 0.06904164382389613, 0.016409673927617923, 0.027033216818901043, 0.01959599634366376, 0.02259688701347581, 0.0856048668335591, 0.01282108626661024, 0.02695297835660832, 0.04637632825012718, 0.10595980459558112, 0.026390793433945094, 0.04877670355407255, 0.01666487773348178, 0.0701125959998795, 0.018565400037914515, 0.05937232981835093, 0.03622124084670629, 0.05757752326982362, 0.05383949760081513, 0.010337001793751759, 0.05109822291082569, 0.020214324950107505, 0.02188538876362145, 0.04542941227555275, 0.046891288831830025, 0.025059416125129377, 0.03362896226878677, 0.01978960443687226, 0.05450959503650665, 0.00792998363197382, 0.011809142888523638, 0.02623626895781074, 0.046538674538689, 0.06119123114539044, 0.072297281984772, 0.03670998622796365, 0.10877659344779593, 0.01968881823787732, 0.0067388777471413565, 0.0395499504437404, 0.027521290450489948, 0.04815743178395288, 0.03558637634185808, 0.0627732016146183, 0.07403528158153806, 0.04327350635347622, 0.054066637198307683, 0.003982929313289267, 0.06427389037396226, 0.010481399134732783, 0.020370377826371362, 0.0324475208430418, 0.009921753629376846, 0.04872166079335979, 0.0405422638037375, 0.008012658883152264, 0.019982712110504508, 0.0209072313404509, 0.025734853631417667, 0.03394330718687602, 0.04585464677906462, 0.03232746424951723, 0.020838938487161483, 0.031003795098513365, 0.04553659027442336, 0.06246327395950045, 0.007229813524255795, 0.024480566382408142, 0.013935048232919403, 0.061492873887930594, 0.024902270807485496, 0.03059522880773459, 0.0336514387412795, 0.029467513784766197, 0.02043856550673289, 0.02902455933924232, 0.03167948027008346, 0.019062160614079664, 0.02053195906669966, 0.03876757581851312, 0.06312779044466359, 0.01686335601178663, 0.02156458419215466, 0.012966185043166791, 0.03783085143991879, 0.03084846825471946, 0.012776107876561582, 0.02844745003884392, 0.030810382084122727, 0.04390549386984535, 0.07114019657352141, 0.11515799138162817, 0.08510177382933241, 0.13433557589139256, 0.12401816594813551, 0.18437131813594274, 0.16090571800512926, 0.09840884299150535, 0.16220367407160147, 0.1309335912976946, 0.08176184126308986, 0.12891038986189024, 0.07926423528364726, 0.16203463742775576, 0.13088446536234447, 0.15598648839763232, 0.1190856641956738, 0.12936427550656454, 0.13817425205239228, 0.09936284965702466, 0.11086422178362097, 0.06836277632308857, 0.10136267556143658, 0.12202534931046621, 0.13173289197896207, 0.08720710514379398, 0.152834096125194, 0.09752603500549283, 0.0678620853328279, 0.07971682492643595, 0.10783608962914773, 0.08459865368370499, 0.15219688388918126, 0.12587070225604943, 0.10469014343938657, 0.08899364713579416, 0.13732022073652062, 0.11969397083989211, 0.12419109738298825, 0.1381171058331217, 0.18977405822702817, 0.07045068964362144, 0.0716372641867825, 0.11868446000984736, 0.04896572305421744, 0.15082403112735066, 0.1669167104576315, 0.17984394250171526, 0.08487059016312871, 0.1712352872959205, 0.09366415294685534, 0.12430568837693759, 0.19114446826279163, 0.08627953420260123, 0.11582811256604535, 0.08651552189673696, 0.09050916867064578, 0.1665745388184275, 0.13460542926830904, 0.14529782480427197, 0.09099670286689486, 0.1640669990863119, 0.09699313395789691, 0.08097697302166905, 0.146034998819232, 0.0761215053498745, 0.11933242024055549, 0.16845626570284367, 0.07561953871377877, 0.17177956737577915, 0.1126887413806149, 0.17855150971029485, 0.1629872191697359, 0.09826698846050672, 0.07212331239134073, 0.09907028571303401, 0.09759584268821136, 0.13221409544348717, 0.09067359806171485, 0.19666834042540618, 0.10789889483047382, 0.09299419461084263, 0.11413785469319139, 0.1886597815901041, 0.12723265774548054, 0.11750303554747786, 0.16099141697798455, 0.03498708064268742, 0.14246085632060254, 0.09127814562192985, 0.06018900778144598, 0.13171335017042501, 0.1108791631247316, 0.06436139424996716, 0.1420029266072171, 0.21746154395597322, 0.10327855989869152, 0.1945930817829711, 0.11341377640409128, 0.14360834046133927, 0.13800908305815288, 0.21542557249111788, 0.10604578176779406, 0.10860841854342393, 0.12024709901639394, 0.06239274702966213, 0.12893652703080857, 0.08641161782933132, 0.05275174489777003, 0.2052305159824235, 0.0681107412757618, 0.09609396649258477, 0.09892098086753062, 0.10943959001451731, 0.10914314485022, 0.06761767023376056, 0.12551631698650972, 0.17392745640661034, 0.1165452833686556, 0.15037602159593785, 0.20975143196327345, 0.10160299909434148, 0.14533517137169838, 0.10027245977627379, 0.08488724819783654, 0.13502503532384122, 0.16069316012518747, 0.1754952794206994, 0.0839401897309082, 0.19838458618947438, 0.1388538862977709, 0.11897586365895611, 0.10963542200624943, 0.12518245061593397, 0.16269326422895702, 0.164876912055271, 0.12393478756504399, 0.11815185073230948, 0.1351854952850512, 0.1376117600926331, 0.12418746043528829, 0.09579887161297457, 0.18465862343353884, 0.14547836940203393, 0.168611025969897, 0.18823889988873685, 0.17843196541070938, 0.2183325250766107, 0.15882879016654833, 0.11982184754950659, 0.10452558512666396, 0.14744439747716698, 0.09511574969760009, 0.060835346313459535, 0.10447168909013271, 0.20389490122241632, 0.12274906119065625, 0.0787759411281773, 0.06250255435173001, 0.08935505524277687, 0.06622595419841153, 0.1521290439580168, 0.11287126051528112, 0.11444968224636146, 0.09490816547934498, 0.10233538265206985, 0.16316496820322104, 0.0782587006688118, 0.16531144588121346, 0.15840269731623785, 0.17282434845609324, 0.10720978145088468, 0.06898092851042747, 0.24121713638305664, 0.08990726739700351, 0.11160394030490092, 0.09676158388278314, 0.27817911016089575], [0.019981553511960164, 0.013749706392575587, 0.009770604016791497, 0.06391328972365175, 0.03376109339296818, 0.04757631064525672, 0.04028716856347663, 0.04084031031067882, 0.014091447162042772, 0.03365910957966532, 0.04665282109220113, 0.04091132917840566, 0.08796941209584475, 0.06360762326845101, 0.03706006619281002, 0.026585044439083765, 0.03526780415060265, 0.034617614932358265, 0.022048079408705235, 0.042493228401456556, 0.024348289373197725, 0.027724969699712734, 0.0496516201778182, 0.008187181482623731, 0.044180500720228465, 0.03555061076102512, 0.03951701096126011, 0.0701055663770863, 0.046317713002541235, 0.011478756554424763, 0.02137063004608665, 0.02961014523836119, 0.1014620673709682, 0.041902275290340185, 0.021843789477965662, 0.03017040142523391, 0.020980389289824024, 0.0338399493401604, 0.028425412917775766, 0.01512229791842401, 0.032254565839788744, 0.04566574602254799, 0.04792375450155564, 0.0149256330249565, 0.043753393460065126, 0.035483496862330606, 0.026379480558846678, 0.017436417850798795, 0.027501826673480015, 0.012870280055462249, 0.028143337428835884, 0.022278881398960948, 0.041379138361662626, 0.03825783995645387, 0.025109600575108613, 0.00911288645251521, 0.06277346624327557, 0.01687763917392918, 0.011113342546325709, 0.0072248746374888075, 0.012326493609829672, 0.01750546387795891, 0.026004588264705877, 0.017094266567645327, 0.059515127513025484, 0.018477538234687278, 0.056946838540690284, 0.015525522442268474, 0.053206743339874914, 0.06877044016229254, 0.024945300105693083, 0.015406402227069651, 0.013211483085927154, 0.049213632608630827, 0.027041194694382802, 0.03452162258327007, 0.0200221248170627, 0.0485556843424482, 0.0464862102110471, 0.031452198180236986, 0.04284206325454371, 0.02285728500490742, 0.060786125383206775, 0.0474235520565084, 0.0076192044154075635, 0.04395419911348394, 0.03169295258287873, 0.03356187890416809, 0.02578777597019715, 0.04885757135759507, 0.06761684242103781, 0.0655820651778153, 0.007027385748058025, 0.05661066175837602, 0.03950605940605913, 0.07139802630990744, 0.02581347548402846, 0.03162216102438314, 0.018176577419840863, 0.054678696141179116, 0.029121664485761097, 0.05020499262692673, 0.041462197833295376, 0.009624813982684697, 0.05494304659909435, 0.03918244909229023, 0.03539383185229131, 0.01642319543420204, 0.015208480347480093, 0.0628919859549829, 0.02474393296454634, 0.051725932263902256, 0.030809238752616302, 0.07607011310756207, 0.021556055006970252, 0.003093242890567386, 0.036319014350218434, 0.009147759759798646, 0.05275365836652262, 0.014469816948154142, 0.03380492675517287, 0.06528806952493531, 0.035135574638843536, 0.036489285927798064, 0.04968416950266276, 0.031027414902512516, 0.007374084488089595, 0.04877423029392958, 0.01661889341526798, 0.01615314867480525, 0.0612450186163187, 0.030931018825088228, 0.0036800808988378514, 0.014354924006121499, 0.01866688173530357, 0.041192225712750635, 0.03279544645920396, 0.021659653733617494, 0.02455032996035048, 0.06854275773678507, 0.019030386515493904, 0.03862142955352153, 0.038978556104536564, 0.023760598319183503, 0.016211156633549502, 0.038321642604257376, 0.027978906341429268, 0.006852551870646754, 0.06814584189227649, 0.03235789654510362, 0.06914702031229224, 0.05653803815533008, 0.030577369766043763, 0.014271940869678344, 0.010498039357896363, 0.038346504127340655, 0.04518603872773903, 0.01817857740180833, 0.03349275654181838, 0.06460825207510165, 0.023300987535289357, 0.04745540588295885, 0.06913490846220936, 0.04759045131504536, 0.04754880622827581, 0.09589378509138312, 0.025469515905050293, 0.043603712027626376, 0.038014873529651334, 0.006459749220604343, 0.019523459253832698, 0.059067457249122005, 0.03230843134224415, 0.015892752379711186, 0.07563730276056699, 0.06259261630475521, 0.03626699107033866, 0.02134317991190723, 0.009417998205338205, 0.10422154037015778, 0.021528857627085278, 0.02798629049876971, 0.0469242825971118, 0.03554198318826301, 0.06330807041376829, 0.034447580842035155, 0.0130461537877896, 0.014653182555256146, 0.022635037644899318, 0.029647803931896175, 0.02138645517905908, 0.03633915666224701, 0.008175578533804842, 0.02287604140916041, 0.013437524304858275, 0.029612381011247635, 0.05748030277235167, 0.006540714987620179, 0.03012612022991691, 0.019155910404931222, 0.029806309712252448, 0.034083143076194186, 0.05779680543180023, 0.028886569065174887, 0.020892183130074824, 0.0398237596798156, 0.023253313664879118, 0.03498256499213832, 0.03238373515861375, 0.04808777677161353, 0.011197737035607653, 0.08447579134787832, 0.08080086604292903, 0.036219079712671895, 0.015270990386073078, 0.026456970954313874, 0.004819584195502102, 0.06591475089745862, 0.010519103629381528, 0.036111657441194565, 0.02931763218449695, 0.027150467670123492, 0.0073232995346188545, 0.056192874176693816, 0.021708148631400297, 0.004259500186890364, 0.03060239753020661, 0.02394197242600577, 0.039919528112347634, 0.016409629822841713, 0.06213605044675725, 0.0331963486969471, 0.046725593972951174, 0.04470879790772285, 0.020148535891036903, 0.024451852476756488, 0.05932964996567794, 0.011513769809555794, 0.02738156312677477, 0.007184419531508216, 0.04837391498897757, 0.0025050876761919683, 0.03006901472274746, 0.0038477948234815684, 0.0490712182862418, 0.04812435320179377, 0.05302959820255637, 0.004694814328104258, 0.03936160947861416, 0.019098562321492603, 0.10015212837606668, 0.017701821734330485, 0.019053156454382197, 0.041454883225794346, 0.010262110187405986, 0.06736771828894104, 0.04648618306964636, 0.01878988147447152, 0.07139260481510844, 0.0179879446846566, 0.038843195153666396, 0.016852765776483074, 0.039385972278458733, 0.07622191496193409, 0.06774047828678574, 0.07495468974645648, 0.018723457985158478, 0.06421886796930007, 0.032531906850636005, 0.04293365869671106, 0.03542344651318022, 0.035116226212786775, 0.004105804371647537, 0.03169186692684889, 0.05942242605877774, 0.08851504246039049, 0.024257564152191793, 0.021498018210487704, 0.021111039511327232, 0.03413954290694424, 0.06260400890771832, 0.05652347340115479, 0.023025017165179764, 0.0473165708327932, 0.024455689592286944, 0.014812553467761193, 0.031209340319037437, 0.014924920563186918, 0.030349802691489458, 0.016618888326255337, 0.035902000298457484, 0.038776535873434374, 0.0395813801858042, 0.013259779512217003, 0.02790411651533629, 0.02537702818933342, 0.038728868788374324, 0.11204318994922297, 0.09688859885292393, 0.03951650545267122, 0.02837993750082595, 0.029953707874353443, 0.0338242378618036, 0.08175783790647984, 0.01816739684103855, 0.023592421718473946, 0.02974239849884595, 0.003434660507731938, 0.02242575539276004, 0.012584109607684826, 0.013052392069117298, 0.0345588096949671, 0.0480592749081552, 0.03006447193079761, 0.045218323423926315, 0.03534136073929923, 0.03751721219824893, 0.034290231963885684, 0.02208501546244536, 0.06624899724764483, 0.08377873910857098, 0.07023565511086158, 0.011285297738920366, 0.0640090513708336, 0.06785263334001813, 0.06191109573202474, 0.06296148151159286, 0.05071187524923256, 0.06521366137479033, 0.015002402476966381, 0.023843937686511447, 0.06284768440361534, 0.08498327447367565, 0.014772394372682487, 0.033675163718206544, 0.05800022344504084, 0.05517773150599428, 0.136335055742945, 0.041341907145189385, 0.06945788434573583, 0.019551932279552733, 0.04214560812605279, 0.07342934980988503, 0.06335834985865013, 0.014577013606737767, 0.04606584080361894, 0.024413966473990252, 0.04486693049381886, 0.007889386881808085, 0.015489943458565643, 0.041187513287046125, 0.030243031813630035, 0.13813552127352782, 0.09961692709475756, 0.13422777024762972, 0.23712130902068956, 0.07439735465283905, 0.16448370101196425, 0.1707342570381505, 0.07863205099212271, 0.10975325639758791, 0.16958669147321156, 0.11748923414519855, 0.11824432148465089, 0.18021579326263495, 0.1479517381106104, 0.12137961467461926, 0.08504673106861965, 0.15689932155822003, 0.09932801366916724, 0.1203164452952998, 0.16212541184255055, 0.13047921710780688, 0.10606543214193412, 0.15208761260977813, 0.17436319802488598, 0.1407067754438945, 0.20772779626505716, 0.13825982888894423, 0.19811294148010866, 0.2095284517854452, 0.12602751169885906, 0.15035979103829178, 0.1788259499839374, 0.2406292807843004, 0.18184574294303144, 0.08318002694951636, 0.13630636728235654, 0.20240732175963266, 0.1646221900092704, 0.09723685695124523, 0.07219698772366558, 0.08166164199688605, 0.1281203715396779, 0.15761657378503255, 0.14976884131985052, 0.11938321537205152, 0.1011671217690621, 0.1459540631622076, 0.14940659861479486, 0.1041435699111649, 0.09274874135319676, 0.09164506343326398, 0.1731594226190022, 0.09449304454028606, 0.1302485287721668, 0.1506493083600487, 0.15987456190798963, 0.153548674924033, 0.10170671995729208, 0.09441463981888124, 0.17561007397515432, 0.10587088936673743, 0.07028627382325274, 0.10013170447200537, 0.07870794513395854, 0.14229359743850573, 0.09651423072708504, 0.10738544738186256, 0.1076149143544691, 0.11845675722828933, 0.128892042274986, 0.1287113619702203, 0.1476737287427698, 0.08562251552939415, 0.09917313805116074, 0.11115943879953452, 0.12636067239301546, 0.06519509665668011, 0.1045009610908372, 0.14235903535570416, 0.13282054290175438, 0.15777518813099178, 0.09942560057554926, 0.18136325026197092, 0.15250047402722494, 0.09483955880360943, 0.14313289097377233, 0.09444003059927907, 0.21873951038079603, 0.20703304425946303, 0.18087169235306128, 0.1350465448839324, 0.1413597296923399, 0.10508830778832946, 0.1262259017676115, 0.11921925417014531, 0.16414025372692517, 0.13198922893830708, 0.25100646966270035, 0.20949381935809339, 0.21130108380956308, 0.1172819145556007, 0.18173402893756116, 0.13763983787170478, 0.20783889958901064, 0.16304536962083407, 0.10602552071213722, 0.08459836191364697, 0.13254007723714623, 0.10391299014112779, 0.1643873354686158, 0.13240077399781772, 0.1586028380053384, 0.09542285464704037, 0.12238403649202415, 0.11536673589476518, 0.08444349986634084, 0.14128758784915718, 0.11608491092920303, 0.07485912487443004, 0.0933617977425456, 0.13080871371286257, 0.2135677028979574, 0.19170466677418777, 0.14085928297468595, 0.18960684005703243, 0.16875517394925865, 0.13197236055774347, 0.19946979438619955, 0.07806497892098767, 0.12380497024527617, 0.1464690983827625, 0.10157049048159804, 0.12306709055389677, 0.09323250968009233, 0.10072807568524565, 0.16335909707205637, 0.14253021617020878, 0.1298755787845169, 0.1303030965583665, 0.1533554552921227, 0.09771128185093403, 0.13042927693043435, 0.08501611556857824, 0.16654708529157297, 0.09948748975460019, 0.1928441170603037, 0.0896307033087526, 0.09765953677041189, 0.1793108039668628, 0.09472312219440937, 0.21100554109684058, 0.19899662477629526, 0.11339892327253308, 0.10208675385053669, 0.09499655823622431, 0.11527915059455804, 0.18755180175815309, 0.11430519499949046, 0.1161794579987015, 0.16591041588357516, 0.15686101147106715, 0.2540685896362577, 0.19949002830045565, 0.14019914982574327, 0.1074166599927204, 0.1647647095045873, 0.13134970968323095, 0.06962970976850816, 0.054952705545084815, 0.0809438062299575, 0.10709464084357023, 0.11696023467395987, 0.07702492722975356, 0.10888597329280206, 0.17832745744713716, 0.1290364616683551], [0.060448655991681984, 0.010772792605816253, 0.020417284952210527, 0.0725690284743905, 0.04435877901102815, 0.03885495077286448, 0.09286207027201142, 0.045823403634130955, 0.039212698183421574, 0.020817376340606382, 0.02333300081746919, 0.02291371367339577, 0.026729110994243195, 0.04147580924576946, 0.07476020803941147, 0.0869183817080089, 0.013786848551327629, 0.03648838008354817, 0.06202356291136571, 0.02296514662780932, 0.06838721036911011, 0.026529553845258694, 0.018786125783143297, 0.02792074910498091, 0.04197433231664555, 0.05050124101606863, 0.06089576307151999, 0.031018770366374935, 0.029558773352099315, 0.025426907298554267, 0.022811266759942685, 0.016951672433476363, 0.043824551427470784, 0.028121671805690442, 0.03586246884827103, 0.024350207930962955, 0.01670523190737835, 0.02001003162669284, 0.026944376228909408, 0.035605575490210734, 0.0827426907739469, 0.02788580964053316, 0.022469313948282173, 0.03933623226891671, 0.10149569556649242, 0.05385538889095187, 0.020361904620325992, 0.049077939175601513, 0.07183737773448229, 0.05665845776508961, 0.021196940348350575, 0.05394506747169154, 0.06755334511399269, 0.023807266261428595, 0.05757897533476353, 0.020618675842082927, 0.031782777048647404, 0.011586895528515535, 0.031930941955319474, 0.024358788006273762, 0.02964078787980335, 0.02141995106025466, 0.00368236204875367, 0.0191035834806306, 0.015936796087771654, 0.019276723565001572, 0.026648911547714045, 0.022588893870956132, 0.031086233710604053, 0.030646763542400937, 0.02522207623613732, 0.014316566421517303, 0.030130456068686078, 0.06610731913575105, 0.061888168033744605, 0.030784933628248315, 0.04597524959327919, 0.057459281757473946, 0.047112810159368176, 0.021360704775101373, 0.014027729331116592, 0.03321462843034949, 0.012315796505260681, 0.04620449943467975, 0.030464648136070797, 0.043287161870726516, 0.06120142274137054, 0.08391901265297617, 0.012603959301486611, 0.02604431818638529, 0.02929055524457778, 0.024284222096736943, 0.03085552162623831, 0.02449585377637829, 0.04680621071851679, 0.01738350569004459, 0.01142268835766507, 0.027715003716626337, 0.017492536089516113, 0.05829512833484581, 0.013084327319769986, 0.012986854068003595, 0.01106969578125115, 0.041821960492857864, 0.02362540191305535, 0.01768690923095814, 0.027856781912435378, 0.023797922834221805, 0.05742458826197045, 0.04824475924085293, 0.02228094244908009, 0.01700814181406583, 0.043419516911464076, 0.013394356755140637, 0.09506154153496027, 0.09702186991593667, 0.05579050969598549, 0.022325199895671437, 0.04702693476740803, 0.01949547816600118, 0.05227269917460425, 0.020188167425138608, 0.009415564809127577, 0.04683291785685079, 0.08474784317825522, 0.03314395222280707, 0.04367370970015015, 0.02772890859549599, 0.07278123351612262, 0.0117191106214055, 0.07172187071825777, 0.045476770627179315, 0.0320039726793766, 0.018637314571865966, 0.0698841739712017, 0.019357976437147175, 0.022351343849939958, 0.04533499752038291, 0.04295012674161366, 0.07740312907844782, 0.029723148460366895, 0.050595469174108336, 0.050980782069798024, 0.02187644736841321, 0.03222617593460849, 0.06667782459408045, 0.07603292260318995, 0.050127405540219376, 0.028103612596169114, 0.017547159854854857, 0.05564834303887827, 0.06308578234165907, 0.012633769041193383, 0.05098355049267411, 0.025999465325315083, 0.04949000670707651, 0.04611096677503415, 0.0336356763727963, 0.053648598558668575, 0.027969554432534745, 0.01692821717421923, 0.0423182511835226, 0.024303543381392956, 0.05230170315397637, 0.01740692532621324, 0.04133761541119643, 0.017694005010915653, 0.02471354986274881, 0.04313547536730766, 0.017933748396379606, 0.033989003127706904, 0.019436228488172804, 0.028817887750587294, 0.040833399431513887, 0.0715091432045613, 0.03620183813784804, 0.01611170036319111, 0.024450010254180858, 0.00855741139301764, 0.0341017586844308, 0.041881128746484, 0.05441662556092654, 0.025893596899030463, 0.06624097017837421, 0.042337396049073765, 0.011880738511016327, 0.029251712507435253, 0.0631641327802624, 0.026112346411017433, 0.02692907696057643, 0.03832793940923043, 0.06886593718081713, 0.05902543557541711, 0.014935042609327605, 0.015080908978624004, 0.019176470015996268, 0.013812533646289791, 0.02606699482670852, 0.005954483632064823, 0.021497321015756046, 0.027582930267921517, 0.030371522597436394, 0.04253899898113949, 0.040045528672635555, 0.05785587869052376, 0.08319692247148071, 0.10053157872919526, 0.05692017889980759, 0.05235271880935345, 0.05054335768467613, 0.045066928690565486, 0.008374498708040586, 0.038338066544383764, 0.05331133272764938, 0.04115856698315058, 0.03245413316679852, 0.02294122996473951, 0.06415425107947417, 0.0410435451194644, 0.01724352900471006, 0.07894113726381745, 0.005462714953214994, 0.031495824589260986, 0.008035225261534964, 0.040086274700505395, 0.06957043973462922, 0.03407050196879676, 0.05726548537079777, 0.018866287910246422, 0.011381212056481411, 0.028800371369080882, 0.0919858847877809, 0.02327256031068308, 0.014210706476920416, 0.012360262601370258, 0.03437973073284541, 0.025316126278734634, 0.01733855783407177, 0.02382765114972634, 0.016930634455223168, 0.020874537826914872, 0.07397327705153398, 0.03470204843740378, 0.024370273907801936, 0.0335221642495266, 0.038649473405842266, 0.05087768206638949, 0.03669043763407639, 0.02109593871448721, 0.01278705773542502, 0.03311549785680004, 0.013470131305179425, 0.007108361269014755, 0.033080804361296554, 0.03553934029436537, 0.014159890141205063, 0.04797335201874375, 0.02501375920006207, 0.028991382369505506, 0.025164339691400528, 0.06496495114905493, 0.020578126589368497, 0.0071567446326038665, 0.026420345330344777, 0.04444754835484283, 0.036903175325798135, 0.02466622374153563, 0.04460106011746185, 0.048368289933672974, 0.033239011586244614, 0.02822725015825459, 0.030213230555610995, 0.031395811920187304, 0.06164308797035899, 0.018549200014344285, 0.048697823858154674, 0.018028046104258726, 0.07270295093102114, 0.013970002116236304, 0.03118352884692805, 0.038034832637224875, 0.03586682165041566, 0.009078041982970067, 0.05421321094036102, 0.08091561309993267, 0.049207756495369334, 0.04325512144714594, 0.04618718661367893, 0.033775939739176204, 0.016300753790086935, 0.021417898491823247, 0.07233450641589505, 0.024149838236293623, 0.05043175903015903, 0.08714894112199545, 0.0424503348102527, 0.05467655875587037, 0.03505718009546399, 0.011511544214694627, 0.06049469459269728, 0.07765088256980691, 0.03353896816926343, 0.10818795074841805, 0.05420581490865775, 0.07573161912815911, 0.020351494196802378, 0.013385636731982231, 0.045163884559380155, 0.02223327536402004, 0.08392435950892312, 0.06874738354235888, 0.042691679538360665, 0.04948663099535874, 0.03935438986601574, 0.029969049551125084, 0.07057162493999515, 0.006534156946664942, 0.03425624414480158, 0.01574698948700513, 0.04767855230186667, 0.029246637065495764, 0.044300214653568606, 0.06861985967095409, 0.019328500875937085, 0.01156849111430347, 0.024627167265862226, 0.011297843003246402, 0.04754142715994801, 0.01707216159307531, 0.05413780873641372, 0.05311735313651817, 0.0650615541796599, 0.005466680142230221, 0.03805082570761442, 0.04844494742740478, 0.011589806443745536, 0.02855810383334756, 0.049538918903895786, 0.06470553364072527, 0.0646791114870991, 0.015602147705586893, 0.038214451034686396, 0.028022961923852563, 0.010815476699333106, 0.05537872714921832, 0.03837589826434851, 0.0013454783267141984, 0.02607328654266894, 0.045392028388700316, 0.032472267015171905, 0.04383021040952631, 0.02559057842674, 0.17510031775704452, 0.12268926868481295, 0.09529744780489377, 0.15603184167827877, 0.11056135767804724, 0.16915692096310003, 0.1599242849541562, 0.17428726995629923, 0.11855661044163363, 0.10584544430353812, 0.15103262636278356, 0.11505960380392415, 0.10945745584155832, 0.10844969563186169, 0.13752896524965763, 0.12824187002011708, 0.09891971879239593, 0.06798012328467198, 0.16818729442145142, 0.08718587378306047, 0.10078544582107238, 0.09514485206454992, 0.06603618830974613, 0.16654912089662893, 0.14554352233452456, 0.08840220887213945, 0.12096158282033034, 0.09725534024515323, 0.12362290572907243, 0.11577441330466952, 0.1615028152508395, 0.20055380836129189, 0.17295940406620502, 0.12478121928870678, 0.08170170948973723, 0.136244783444064, 0.11313049481915576, 0.1159898888851915, 0.08353962336799928, 0.08651243456240211, 0.0997306631345834, 0.13967758709830896, 0.11466636561921664, 0.15672495162912778, 0.25261022789137705, 0.160303016060165, 0.11693829085145678, 0.15011644123920373, 0.11462166373218809, 0.22727561662239687, 0.1243843984391008, 0.14751672931015491, 0.1823021663086755, 0.06343890553606407, 0.11394278944603034, 0.11526853830686637, 0.1146751187209572, 0.10862635900931698, 0.10146355336265904, 0.0952112263600741, 0.11102987932307379, 0.10477025806903839, 0.08567091543227434, 0.09621140733361244, 0.10200056633246796, 0.1081759813906891, 0.12261055862264973, 0.14513834193348885, 0.12262548639306001, 0.11476039700210094, 0.13080446608364582, 0.09472419427973883, 0.12308264257652418, 0.2555367765682084, 0.14565188437700272, 0.09137316088059119, 0.056088013374911885, 0.19979094501052583, 0.08741254519139018, 0.11428878802273955, 0.07489292948905911, 0.14430758436875685, 0.14102633829627717, 0.08665570723158972, 0.1173930721623557, 0.12905878547046865, 0.1158737236899989, 0.1353265762861286, 0.09158532521022217, 0.11036145447620324, 0.09494386320667607, 0.15031979818429264, 0.13785467562930925, 0.10955046942191464, 0.15565596041934832, 0.1103857731712716, 0.11243969867272036, 0.1158344636538199, 0.1505520200090749, 0.09607605316809245, 0.17457137256860733, 0.1127491309972746, 0.1147788395839078, 0.16548021111105168, 0.07433433910565716, 0.07169064453669957, 0.11179886305970804, 0.1630544484193836, 0.13213543966412544, 0.1523487400263548, 0.15600233897566795, 0.1118864890720163, 0.13367397710680962, 0.1459507926234177, 0.17177289059119566, 0.17861552270395414, 0.1669749559036323, 0.13869011508566992, 0.17246771045029163, 0.08723450438784701, 0.14826439347650322, 0.13662332456026757, 0.10033662204763719, 0.18900374456175736, 0.17572021377938135, 0.1835708368037428, 0.10355549039585249, 0.1293069664388895, 0.17482363831784042, 0.07959030528685876, 0.13555043855948107, 0.13216486094253405, 0.15194984285959176, 0.2161238800202097, 0.1773733286453145, 0.1549907246870654, 0.10336282037730728, 0.08572190733892576, 0.1051004874919142, 0.17296439808394226, 0.10548242806856122, 0.16778792228017533, 0.1825178861618042, 0.12337106067155089, 0.0732374804626618, 0.1856868075472968, 0.16878561303019524, 0.09220504481345415, 0.0790850952533739, 0.09315298537590674, 0.11502402142754622, 0.16156624470438274, 0.14376894970025333, 0.13009969890117645, 0.13770370158765996, 0.15403005480766296, 0.11632405381117548, 0.1578910547707762, 0.13987147169453756, 0.08410378452390432, 0.13367551059595176, 0.16857666495655263, 0.13040698026972158, 0.12192533324871745, 0.09342277768467154, 0.11370939375566584, 0.10216675991458551, 0.09368212733949934, 0.13490308901028975, 0.13775581307709217, 0.20664319874984877, 0.07175127842596599, 0.14112294811223233, 0.06833723626498665, 0.138823216514928, 0.06083032515432153], [0.05737595087183373, 0.04363261083407061, 0.03950479393824935, 0.04060611394899232, 0.0460399546926575, 0.058642348274588585, 0.03141290421730705, 0.06303615429039512, 0.03361025505832263, 0.0625468830444983, 0.028831081864024912, 0.10742470063269138, 0.009451812149823775, 0.023973829645131315, 0.040517069798495085, 0.02959518354119999, 0.056197623921824355, 0.04635208758658596, 0.04599098821303674, 0.04378510479416166, 0.034705804128732, 0.053698922108326635, 0.014682103414088488, 0.05167873676068016, 0.02467365369998983, 0.05326721438073686, 0.0419864068473024, 0.06422965667609658, 0.03348696185275912, 0.011507761381965662, 0.04872859202857528, 0.0195124635938555, 0.017542903743950383, 0.014005609937677426, 0.03693976532667875, 0.06780175678431988, 0.03855481777074082, 0.007811896486340889, 0.04162666454379048, 0.0279843617629792, 0.012037787985588824, 0.03445073602987187, 0.0479661018720695, 0.02328916236625186, 0.020141708132411753, 0.023195716219821146, 0.03093780078259962, 0.03583365825137921, 0.007261607978892113, 0.041023243351706436, 0.02729222720621952, 0.04578575851129634, 0.027405657905286977, 0.05312440650803702, 0.05462989929531302, 0.01110911272865321, 0.014075133483856916, 0.03263987534280334, 0.025106167187914252, 0.03922941389360598, 0.08592128128345523, 0.031341128783034425, 0.05043760460934468, 0.04879711728010859, 0.03550936261724148, 0.03236909576558641, 0.027856025345889584, 0.02926843161029475, 0.05363291082903743, 0.004185198481926429, 0.023092884237744978, 0.019729391239317398, 0.027607389759006243, 0.00410194053880072, 0.0036643333733081818, 0.07033691967704467, 0.06845540992383446, 0.03739690454676747, 0.03261154650577477, 0.03158190014905163, 0.09574802898402725, 0.03913844948900597, 0.09122338106057473, 0.0104007018131337, 0.05334498127922416, 0.006009215538922165, 0.021979393005105, 0.010474351700395346, 0.052176163997501135, 0.10036766502474036, 0.02981105606470789, 0.009546264224419636, 0.0050426805724522895, 0.054826840691800625, 0.07713219004550151, 0.0276257373459105, 0.011023550310970416, 0.03922330368576305, 0.028299107016729455, 0.0631789384143693, 0.02209887793287635, 0.039760367545698366, 0.0077049780271149105, 0.054371106039200506, 0.04439589487654822, 0.027096985539953624, 0.0032502819750724094, 0.01782050259810473, 0.024697332875803113, 0.026752966589161327, 0.06302438170782157, 0.01364671325843249, 0.06096864451787301, 0.024201690186081187, 0.05118569625275476, 0.053032386981483014, 0.027123577327334454, 0.043239901906677654, 0.05810825300535985, 0.05273936841902988, 0.047035603052271266, 0.037015774819467745, 0.0688494827066149, 0.04968618814434324, 0.04137606120535305, 0.017535979294085076, 0.0409480073888387, 0.02754409940514181, 0.03194200886147363, 0.0686997775254505, 0.037896041691835435, 0.0315983817646546, 0.026651227048465183, 0.05271691230258771, 0.04559255923543658, 0.07997652063412325, 0.04944418862994228, 0.022901683247515132, 0.02644013480416366, 0.023653608613780568, 0.032435677014291286, 0.03213734891531723, 0.026263462945020626, 0.04862607217260769, 0.03518412381942783, 0.054627303898866685, 0.06132463113005672, 0.007116172479332558, 0.008528404869139194, 0.043538796582392285, 0.04109461845031806, 0.052416782693139145, 0.04449489992111921, 0.010138140991330147, 0.020416453746812682, 0.10349999980202743, 0.045282567119491954, 0.0614165115569319, 0.03972171140568597, 0.022311235644987652, 0.028685665024178367, 0.03621364125449743, 0.04222044036058443, 0.05533933819138578, 0.07771085149475507, 0.037074091511645486, 0.026513292753536786, 0.014489565709871905, 0.04317071847617626, 0.014962832011016352, 0.039001419341989925, 0.038900887593626976, 0.01902345019126577, 0.0418428763348077, 0.025585740472057035, 0.016179428336077502, 0.046273730362632444, 0.012422362974445735, 0.049035870004445314, 0.04206965970141547, 0.07732680067420006, 0.13125654682517052, 0.04163876960852316, 0.02835761709138751, 0.016866775828280618, 0.01654787115486605, 0.018825436709448695, 0.056909729460520406, 0.03578387752973607, 0.04021287237160972, 0.02431787404098681, 0.036465136866484366, 0.031136713323316405, 0.021641122942258204, 0.01589924087082701, 0.007124560868500599, 0.006608628709467926, 0.06092476365821702, 0.02319537186329918, 0.012878849104579006, 0.04551875837413328, 0.020360274439943687, 0.05460217096177595, 0.045197373655225546, 0.018608010340748087, 0.07812794018536806, 0.050309127396238704, 0.01718048970880253, 0.013390774090242172, 0.028765684658927575, 0.03515230052705322, 0.06823230760970286, 0.03595790479864393, 0.040830875281244516, 0.023215225797944834, 0.031425463900502236, 0.016798089424680387, 0.07244976237416267, 0.051274699691150866, 0.01170159932891173, 0.03926773076610906, 0.033126751360084326, 0.028100101177447608, 0.06781534105539322, 0.01581430864254279, 0.05496196076273918, 0.033397507188575606, 0.04180902761540242, 0.0473648180652942, 0.019901243803490485, 0.012243437530872012, 0.008283774335203426, 0.028452452538268905, 0.044327484975968084, 0.010158116214110382, 0.028864384362740175, 0.020831075962632895, 0.0522646381785827, 0.019208563026040792, 0.0442422847263515, 0.03554812393018177, 0.013985312410763331, 0.04782088180737836, 0.03154402771698577, 0.06636597668485981, 0.04218241186546428, 0.07551794845078673, 0.03314987922619496, 0.028731157404503653, 0.08607242495885917, 0.03735302707978657, 0.018626736210925237, 0.03601529189784612, 0.0947152783295938, 0.026240299455821514, 0.04366437645096864, 0.030823318354253258, 0.037412361574492285, 0.017964915206123675, 0.023330086509564092, 0.05136177269741893, 0.0538448817761881, 0.03396295756101608, 0.03659537487796374, 0.08791567890771798, 0.03400500637612172, 0.04485696620707001, 0.04669820490692343, 0.018739939600761448, 0.05728400259145668, 0.06363602674433164, 0.04148233335997377, 0.03777770857725825, 0.05686717852950096, 0.005866716823740197, 0.0463563861059291, 0.03351533140188881, 0.04882162257230707, 0.05139890552631446, 0.047004054566579204, 0.0036235699579784913, 0.005964164630443389, 0.02867252180086715, 0.03985089768788644, 0.006984177486239267, 0.026694402231701782, 0.062232151361448426, 0.04637823493352958, 0.02445705684034952, 0.011191156942264309, 0.014729517744854093, 0.07816595850246293, 0.016662665709320987, 0.03229412103870085, 0.01685228062394474, 0.04844077782971518, 0.028914110801581825, 0.04593208119539278, 0.018855066637375524, 0.02276841557717749, 0.07731599839670317, 0.08220568458948817, 0.03241996214325939, 0.054769765718707016, 0.0729442990518042, 0.01314562447701714, 0.042619541087853055, 0.009634806259003068, 0.04731369045163904, 0.02626745612360537, 0.04862465742709381, 0.04204335629141756, 0.01312015312058585, 0.015000163311404842, 0.015164506189259035, 0.007085850869771093, 0.004230137856211513, 0.039791346061974764, 0.02920429308765701, 0.034938619671655555, 0.028082834157560552, 0.02178179512598685, 0.032858730027718205, 0.07327767009181635, 0.055549687439841886, 0.043367754867566485, 0.05005063948088458, 0.08394523803144693, 0.03872425135757242, 0.009136204308431064, 0.002388005398513217, 0.04160420164199812, 0.05167007865384221, 0.06909798258649451, 0.04387879351686154, 0.050239774331982644, 0.03059874361913119, 0.01678650513557451, 0.03591083821707538, 0.03848046051072223, 0.04117339297330805, 0.03226835706404277, 0.03296569089538284, 0.05147522375253694, 0.02322105611009257, 0.03952894978491323, 0.08374892427985157, 0.025415652098932436, 0.01458333755311157, 0.04853939950200064, 0.028348059925649847, 0.030154689946877103, 0.2275579414729561, 0.10068187423582588, 0.09982474880026919, 0.09941023854272706, 0.1290948971041611, 0.17157238349318504, 0.13730394946677343, 0.14577818688537392, 0.08642665416534458, 0.12786506595356123, 0.17402831385178225, 0.2590073203401906, 0.18545468071741716, 0.26670603294457707, 0.14371136921857083, 0.10359985980072192, 0.13683189265429974, 0.16471996690545762, 0.19545218854078225, 0.13769844972661563, 0.10116374266466924, 0.17609928415289947, 0.08885651520852532, 0.09584753614451204, 0.15353205081607613, 0.09737813472747803, 0.0928147356691105, 0.11660200889621462, 0.10087115157927785, 0.1895675528794527, 0.1339646615087986, 0.15253034313874586, 0.1398305967450142, 0.15398941056004592, 0.08907237755400793, 0.13306834389056477, 0.1100332403023328, 0.12387533432671002, 0.11578273214399815, 0.08478903025388718, 0.10899553634226322, 0.12812157933201107, 0.1436020029442651, 0.12044812180101871, 0.15608718299439975, 0.10423968439655644, 0.12053810911519186, 0.10889115730034453, 0.06694024801254272, 0.14134488334613188, 0.16857963693993433, 0.17775891295501164, 0.13273602457983152, 0.250247270401035, 0.11776798990155969, 0.06176354829221964, 0.09389714830155883, 0.11557811312377453, 0.15649408687438282, 0.112955670271601, 0.13414188128496918, 0.15564439818263054, 0.08989300459091153, 0.13887686149350234, 0.08666572919381516, 0.10249430233878748, 0.1415398128862892, 0.1217599878353732, 0.1995239821927888, 0.11128443173531975, 0.14752689376473427, 0.10113903720464025, 0.11009622870811395, 0.19979459552892617, 0.05293673050722905, 0.18402023054659367, 0.16134228743612766, 0.11676378521536078, 0.13460792627717766, 0.12746147332446917, 0.20500396671039717, 0.25659333701644627, 0.11733212614698069, 0.12570822026048387, 0.12498837602990014, 0.12483837907867772, 0.12093940829592091, 0.09892482137573616, 0.1786361908806222, 0.27797622819031986, 0.07628049967544419, 0.15061107969709805, 0.10798851573573691, 0.15729470391358646, 0.18934903746204718, 0.10387461898582322, 0.10816963708826474, 0.15881527374897683, 0.12294409929641656, 0.10779898054897785, 0.12349893738116537, 0.1624710304396493, 0.06292788724281959, 0.18466333246656827, 0.10133341034608227, 0.07986143430961029, 0.0659777664446405, 0.14749110782785074, 0.16497311475021498, 0.11245083343237638, 0.1629883726792676, 0.12637226177113398, 0.14759900846651622, 0.13661440861012253, 0.14748584239610604, 0.15854333048420294, 0.09235629026911088, 0.14058066292532853, 0.07664731570652553, 0.12914286952997955, 0.1357145897511925, 0.1312225250793355, 0.1086883024711694, 0.18397575936147145, 0.181999892528568, 0.20841963057007107, 0.15301696131271975, 0.19274125115147658, 0.14177432815943444, 0.18000965432396956, 0.1256356577255896, 0.11776013246604375, 0.15535862637417658, 0.11835858678179127, 0.10916529901857887, 0.2995980993977615, 0.1718587117003543, 0.0893309401082141, 0.1059004734935505, 0.08239093822027956, 0.11402021029165813, 0.1823381965181657, 0.08305687962898187, 0.14342882723680564, 0.1337976876114096, 0.1565723626741341, 0.16924595832824707, 0.16529864871076175, 0.1392065073762621, 0.09810040132807833, 0.14328875046755585, 0.11746278485017163, 0.08602433039673738, 0.10832786466926336, 0.09148836255605731, 0.1193475244300706, 0.13084812302674564, 0.1650681503649269, 0.19918669600571903, 0.12117830690528665, 0.1376171748020819, 0.09243046771734953, 0.13076695666781493, 0.10899614702378001, 0.16487007242228302, 0.10157320462167263, 0.07547488183315311, 0.1093090670183301, 0.13977472617157868, 0.1336007360368967, 0.12962734353329453, 0.10344384424388409, 0.09441950491496495, 0.1382315204079662, 0.19251084780054434, 0.12287905492952891], [0.03256265127233096, 0.005531196524056473, 0.016608637358461107, 0.08022164819496018, 0.022053124316568886, 0.039503287590507946, 0.061600523468639166, 0.0361412110339318, 0.023117689781689217, 0.01929072174243629, 0.06577312706836633, 0.0023011020259998205, 0.02730128395238093, 0.08072022215596267, 0.021281222879354442, 0.03209273863051619, 0.04171332025102206, 0.03628400872860636, 0.020360576388026987, 0.023272131137283783, 0.05331726651638746, 0.03366702129798276, 0.08507473420883928, 0.029829264551933323, 0.03405248347137656, 0.004206803036920194, 0.023859613541779772, 0.04534928407520056, 0.030971442548824207, 0.013660516357049346, 0.026067931205034256, 0.045760863061462126, 0.0816639286598989, 0.009012566746345587, 0.016989477012040358, 0.05417105695232749, 0.06502369871096951, 0.03935006759794695, 0.026233064576185176, 0.027056612706344043, 0.03217183545764003, 0.004072759292154972, 0.011294215385402952, 0.005103370864942137, 0.02970435982570052, 0.03908896393009594, 0.029109511923577105, 0.023554936051368713, 0.058461539048169336, 0.032368101711784086, 0.014927648273961884, 0.12224564248962061, 0.05845146280314241, 0.04171412092234407, 0.013730395285944854, 0.06176762628768172, 0.14712963865271636, 0.0461156113472368, 0.011429622137386884, 0.048816034836428504, 0.03541114806596722, 0.02402925068911697, 0.0711347750787224, 0.09310296377433197, 0.05142596211018307, 0.017179643236366764, 0.0423309499663966, 0.02445712299751384, 0.05354851803609303, 0.05806025343814066, 0.02972585242241621, 0.04524169216996857, 0.01245317270513624, 0.02124119270592928, 0.0163102091755718, 0.019316648565498844, 0.0673680372003998, 0.03953676990100315, 0.008495422978220242, 0.027333992732954875, 0.04018470299031053, 0.02471355495176145, 0.06625595901693616, 0.0303809576268707, 0.07829080216054406, 0.01761550359827067, 0.04230400873348117, 0.022337771453229443, 0.025262467729459916, 0.026291883384276713, 0.004845618311914482, 0.022149062382855585, 0.008677019305261118, 0.023224267277068326, 0.070754239069564, 0.0667478833347559, 0.059084332415035794, 0.010439670079254677, 0.009497888070265097, 0.08358522770660264, 0.030892515355455022, 0.015461187144475324, 0.006039139357328947, 0.016387438335056816, 0.032229890913835595, 0.01914450083859265, 0.05788779019245079, 0.029703956097364426, 0.013500114919484725, 0.02152637588525457, 0.023184786717008268, 0.0178010897112212, 0.07048402606908764, 0.011766462187681879, 0.02903824539056846, 0.05067858971389277, 0.0483560254132109, 0.04365684810493674, 0.041871313737439256, 0.03496305371767708, 0.02596547411355589, 0.04134537785180977, 0.01684649780924831, 0.016908636349918585, 0.02881635765412024, 0.00823141772499574, 0.04606152192822524, 0.02520958610278155, 0.03423579988468971, 0.05275401459740741, 0.03339929852102484, 0.04027719749137759, 0.0703044653471027, 0.027132140439269797, 0.05247549632830279, 0.03577808962602701, 0.02006574104806142, 0.01777412642591766, 0.03381798176893166, 0.006556991346380008, 0.03340789555971112, 0.005989202996715903, 0.016255615944308893, 0.03888483684776085, 0.03887111008433359, 0.02586891858040222, 0.02646422788633832, 0.05638388178444334, 0.027551632840186357, 0.044495279900729656, 0.10157124365546874, 0.018478718885619725, 0.010217619494401982, 0.060894236367728026, 0.051540950047118325, 0.01730484651800777, 0.01666440106263118, 0.028852330188133886, 0.03611936899168151, 0.024106630822643638, 0.026902839707742845, 0.061144955057118616, 0.052094583732209036, 0.04767869818689568, 0.05757655296474695, 0.03342789537938578, 0.015513615849028741, 0.03805951774120331, 0.012571432029030152, 0.025317881988095384, 0.007461014153834964, 0.0477268334611186, 0.027434529570330466, 0.11976019585771219, 0.02607848072823669, 0.040591959708503315, 0.022270058747380972, 0.053796071359621625, 0.10961326783789055, 0.0026318891198440853, 0.02382477925025991, 0.03741371864452958, 0.11202651155846459, 0.0509094578613128, 0.00849624230925526, 0.04038655019498297, 0.046899879085166116, 0.01651376119947859, 0.04876032032604728, 0.13018018672508852, 0.08319428297025816, 0.05564500803926161, 0.03244900683473263, 0.056158031403486214, 0.013065551407635212, 0.06068591933165278, 0.017611284806792225, 0.029445892266396965, 0.029505749233067036, 0.05284141330048442, 0.05105104437097907, 0.023662363411858678, 0.021836644504219294, 0.04785868299326726, 0.04708313782300268, 0.04273773849542652, 0.0773119136158909, 0.036297949230564494, 0.02486812522900956, 0.019770203424351554, 0.02178802916647068, 0.15208717834736618, 0.04046369284125311, 0.02540038845368794, 0.02610351867042482, 0.02672604231962136, 0.04131269621263657, 0.0157782801293901, 0.05217149228389774, 0.0370077647135726, 0.05869323840098722, 0.03137576460306134, 0.05851844099483319, 0.04833923167149935, 0.04861617234668561, 0.011801443212399525, 0.021870354123945748, 0.05155615940956133, 0.03127287833818367, 0.023200983347903405, 0.059692964756063054, 0.06884172705135175, 0.06143665726163557, 0.037163006740489175, 0.03677369048818946, 0.010977868789008685, 0.023520330765417645, 0.02854099457285234, 0.017658666907144443, 0.07010488105671746, 0.03181716181071741, 0.018832807296088765, 0.02374572483157473, 0.020149592709328448, 0.018053966141971092, 0.051807977325682125, 0.010717290985797132, 0.04959441289039595, 0.021925308675106083, 0.02444175078666636, 0.054102127972458086, 0.03237651554601533, 0.025536280358210206, 0.010481046296523085, 0.03368368272536567, 0.04668913967907429, 0.03274818988783019, 0.033435369442616186, 0.02463256161926048, 0.008526601662327136, 0.09065100963094405, 0.033679184038192034, 0.06402021327189036, 0.024071523420778767, 0.015042086597532034, 0.07757935819349118, 0.02628222104561116, 0.03882971266284585, 0.035836620056735616, 0.049388114496001174, 0.03756730843867574, 0.048133282722639184, 0.017024243450058357, 0.017891792879839028, 0.016486205892371278, 0.019953129680028985, 0.023107404887144054, 0.0314094674374376, 0.01474782292331968, 0.046564747246780565, 0.007731909082005066, 0.02400752399781985, 0.05838357537452664, 0.011361436153362905, 0.028063785983249545, 0.03117058239877224, 0.008854856548298682, 0.03723281103053263, 0.07406103877084595, 0.04183704432632242, 0.024682094675621817, 0.01788080230887447, 0.056660652825874944, 0.08433772304228374, 0.031067451861287867, 0.04745043222127216, 0.030627825630030463, 0.05516972140009914, 0.07374425791203976, 0.009716237246591066, 0.03479578805023006, 0.01849852701915162, 0.034839299108300886, 0.040002010829214535, 0.013313537297238196, 0.01177918047843767, 0.04582795660410609, 0.03109321922862104, 0.0026460403917423847, 0.06232369252081428, 0.01931694712090705, 0.05463689159868019, 0.09022935439965554, 0.028195323389289633, 0.03269008014883314, 0.023786184178399186, 0.023783447985936488, 0.10756790544837713, 0.07233687450311013, 0.023483080889231393, 0.00744035785152976, 0.00892136400632028, 0.01680177726250674, 0.07769311458936759, 0.03623402783913272, 0.01624085950399084, 0.09290132352284022, 0.022623877440180098, 0.03514274675399065, 0.027343763637223413, 0.04123721597716212, 0.009772638773678668, 0.02134039961466832, 0.019229395747450844, 0.06074145742292915, 0.028116881348458782, 0.024586005635293465, 0.05781025399586984, 0.030223880162728683, 0.023789739701896906, 0.015875955245324543, 0.04355597708906446, 0.021235869598707983, 0.01182787724038852, 0.029714201976146017, 0.02889972585918648, 0.04621172243995326, 0.003688738157507032, 0.01784587980780218, 0.042522544506937265, 0.024443289364821146, 0.01305382717068174, 0.1308373614613499, 0.209965726892863, 0.1296632108943803, 0.131407018750906, 0.10035129876009055, 0.1543109275932823, 0.25900542044213837, 0.1199012632880892, 0.11153424797313553, 0.12931808084249496, 0.18128950707614422, 0.11692328165684428, 0.16558440694851534, 0.18131343222090177, 0.18228818848729134, 0.13045103076313222, 0.0963736789833222, 0.15883177572063037, 0.11154830043337174, 0.1670787310493844, 0.09976722938673836, 0.07066658591585499, 0.15901960778449262, 0.1742232841040407, 0.1680286665047918, 0.10985931820635285, 0.1256051372204508, 0.16281268639223917, 0.11565489614648478, 0.12408943926649434, 0.09403564408421516, 0.07243887867246356, 0.1287039795092174, 0.10222877801528998, 0.10284707948033299, 0.2611131401998656, 0.09276138246059418, 0.047851432846593, 0.12827719455318792, 0.11649414896965027, 0.1316739408565419, 0.05231753337596144, 0.11894461033599717, 0.13006735992218765, 0.12519224866160325, 0.234680102871997, 0.13211770275873796, 0.10968885663896799, 0.11702525189944676, 0.108444213068911, 0.04331238980271986, 0.28918682092002457, 0.18347975026283944, 0.05674780047099505, 0.10881096124649048, 0.19168979328657898, 0.13457811144845827, 0.1693205428974969, 0.1205240362989051, 0.14431385403232916, 0.07204838855458157, 0.1740729207439082, 0.14928462515984262, 0.18202657252550125, 0.1031769085675478, 0.11207031777926854, 0.10988299229315349, 0.13151322305202484, 0.19194640165993146, 0.16451666424317019, 0.09679519850760698, 0.0964813692761319, 0.12980916377689156, 0.16355600793446812, 0.0924474989463176, 0.055685818527958224, 0.13339067516582354, 0.144390840615545, 0.0965606357370104, 0.17969452909060887, 0.12914713072989667, 0.11713172761457306, 0.15585595183074474, 0.07873123245579855, 0.18844118474849633, 0.24983178983841622, 0.13933567330241203, 0.11878153122961521, 0.1427958354886089, 0.10345570503601006, 0.11871979811361857, 0.14067694704447473, 0.12441566533276013, 0.11976487774934087, 0.1934928372502327, 0.19617857384894574, 0.15974310253347668, 0.08838547619857959, 0.10218460538557597, 0.1835620565606015, 0.09629000204482249, 0.08546850165086133, 0.14254270121455193, 0.14534403303904192, 0.07978111611945288, 0.07578937602894646, 0.22125284480197088, 0.09733890183269978, 0.10493340502892222, 0.08666123050664153, 0.15478678420186043, 0.10647101966398102, 0.21899012050458364, 0.08149113971740007, 0.14474764146975108, 0.09374901732163769, 0.19667394512466022, 0.1286528722516128, 0.09231922190104212, 0.09827639295586518, 0.09158375779432909, 0.1865622398576566, 0.1281106820596116, 0.06298846006393433, 0.14393500079001698, 0.07364253194204398, 0.11603212090475218, 0.14182924878384384, 0.10093570061560188, 0.159219924892698, 0.1341127992740699, 0.08839824622763054, 0.1466430476201432, 0.1704150198825768, 0.10319923236966133, 0.13374242771949085, 0.13663298689893313, 0.13693194942814962, 0.08295359981379338, 0.10603645191128765, 0.1361633456711258, 0.17274124148700917, 0.12907109409570694, 0.07263000841651644, 0.08787919407976524, 0.09898570632295949, 0.11144920039389815, 0.2135817621435438, 0.09789055758821112, 0.16057457934532846, 0.38119977925504955, 0.1608470111553158, 0.16116383272622312, 0.12440223033939089, 0.132974950330598, 0.11255866621753999, 0.04313342279887625, 0.13542294182947703, 0.14689224639109202, 0.11817269532808236, 0.06613969204149076, 0.25733755422489984, 0.15146752659763607, 0.16580445585506304, 0.11115850242120878, 0.17802308020847185, 0.08242430178714649, 0.05845140852034092, 0.09234646508204085, 0.11174271428691489, 0.11514280576791082, 0.08655497870807137, 0.08958490219499383, 0.18192973200763973, 0.12508962702538284, 0.15153464728168078], [0.03962958331352898, 0.041678514797240496, 0.020798372271071588, 0.03308838020477976, 0.03456314214106117, 0.05956243497452565, 0.027402149879240563, 0.014850911052365388, 0.06708531201417957, 0.03765105662335243, 0.05850984395614692, 0.017492349492385983, 0.022967015991785696, 0.03165894440774407, 0.03300220286473632, 0.013041582158101457, 0.02476760365867189, 0.02672585063347859, 0.07205644955060311, 0.031040422418820005, 0.0948153758155448, 0.03811725089326501, 0.05179240155432906, 0.1009382044098207, 0.008563296836135643, 0.028201211376913955, 0.11209726240485907, 0.036917862216276784, 0.02437316785965647, 0.03468149221901383, 0.03891215806028672, 0.051287998977516375, 0.021025606863466755, 0.039084461850247214, 0.0071640634809487635, 0.07345527663294758, 0.03712588069694383, 0.026423685418974076, 0.017243695245789628, 0.021992685506120324, 0.0435176500385361, 0.028721678270293132, 0.02514647047168442, 0.025810182892850468, 0.01026742735744587, 0.048370702125664265, 0.01159249768326325, 0.025581199376444732, 0.01215541542374662, 0.021726206144584075, 0.01909082193326737, 0.0556068608005132, 0.052482200254287036, 0.027623347206307308, 0.025586970316778337, 0.04103545019669192, 0.08879506029188633, 0.02417182785991047, 0.019539264030754566, 0.035377010969179015, 0.07360726169177464, 0.05578953939090882, 0.031123213869120394, 0.01962192147038877, 0.03415647574833461, 0.02064558314824743, 0.06094644285206284, 0.09603076095559768, 0.02288738651467221, 0.029380060798887695, 0.03548112877511552, 0.02860543504357338, 0.04762685811147094, 0.03305551875382662, 0.024473993074414984, 0.08416080860687153, 0.05125074401231749, 0.07054730624492679, 0.035336899371551614, 0.030848593783697913, 0.017261535627767444, 0.03847845204706703, 0.07255217366452728, 0.01959685129778726, 0.0618208505745445, 0.05180555156299046, 0.02219953860289284, 0.06495778581925801, 0.030955218776528324, 0.03729067649692297, 0.08018607938928263, 0.01900396605820528, 0.008113498516779925, 0.08155652335179703, 0.04344155912154487, 0.023257963326094405, 0.004301497263700834, 0.03213719963761313, 0.06803740521094628, 0.004682379749803138, 0.023443586758470962, 0.05959041775869472, 0.010670847808276969, 0.034240505525044033, 0.061362900505108495, 0.028151250843490874, 0.0640833509553756, 0.02160098759590515, 0.03680245698030506, 0.030109441839158535, 0.026624156893896203, 0.09588761042271342, 0.005919071737610335, 0.07856984290161304, 0.006378602369555405, 0.01366737125707524, 0.0684168827054756, 0.02016355187099959, 0.03389203029551676, 0.04777764555599008, 0.04225274541282228, 0.016101025311010222, 0.06584449538162776, 0.08458785819155829, 0.03529505750962666, 0.05220511030139668, 0.08448531119418995, 0.05508420563169888, 0.012451585781361376, 0.04064734512940049, 0.02611761862811233, 0.022816276044717858, 0.05408854030870965, 0.005876594597274172, 0.06547708223973002, 0.014274476894310542, 0.09305536454277379, 0.03754652151837945, 0.03366376432989325, 0.01912770200786846, 0.023116595643971647, 0.038117339102817435, 0.01688590203411877, 0.048263473236667256, 0.04160075129142829, 0.05441884437043752, 0.024499892756076794, 0.02624528668820858, 0.02369282115250826, 0.04200010646932891, 0.017028869362547994, 0.03613028662013156, 0.024592928388821225, 0.012270690041727253, 0.05527600373274513, 0.02381489978038839, 0.027141516096889973, 0.01872580062731036, 0.02784113659124289, 0.06419320577489478, 0.026200569534142102, 0.04248828188117061, 0.028456191266221658, 0.0200246608416949, 0.027613106416538358, 0.03292292283315744, 0.036194289435765574, 0.010280516297955598, 0.03198434944663729, 0.0303685573994049, 0.07396942297262804, 0.04089059993358595, 0.00908191132891391, 0.05984921780015741, 0.05058915201308472, 0.01810949744789728, 0.020490958588197827, 0.03694728010201028, 0.012535755505918391, 0.04546033990170274, 0.008800921496003866, 0.0762099116774542, 0.005302743113134056, 0.05662869721917169, 0.050004081800580025, 0.024362380849197507, 0.01455958204210869, 0.033670074705566676, 0.04012759069779089, 0.04206607364384191, 0.03908697582249131, 0.011715645003797752, 0.09903023857623339, 0.011507982754015496, 0.02387495861122651, 0.020004757713260393, 0.06768913354192461, 0.01704180732901607, 0.012950532936624118, 0.045294804498553276, 0.021691743350986923, 0.012092326934050237, 0.06283297376441103, 0.02974063091512237, 0.02519637163329337, 0.03605354430952242, 0.032910980616829226, 0.02938980795443058, 0.032420637285602946, 0.020408677735498974, 0.014245123469403811, 0.07069259416311979, 0.01524207291991583, 0.07327411456831864, 0.02913323011515396, 0.037985221549336395, 0.02570841790709112, 0.027689446695148945, 0.013520642300136387, 0.0413889906901334, 0.025751822095896517, 0.03799301791670067, 0.05642542848363519, 0.02258829167112708, 0.028102789872459004, 0.05550541642255016, 0.045295340541218004, 0.04279297463861959, 0.007878398007181073, 0.021094557895724262, 0.008239720449117678, 0.040465830226561854, 0.02973914153075644, 0.05544171555499945, 0.02537058380299381, 0.06211976560630968, 0.017255681566894054, 0.015397666088704551, 0.020121575998408452, 0.02532287091682, 0.07788439361112458, 0.025551130097093325, 0.03511616853731019, 0.025167895214898244, 0.0069171577342785895, 0.027823594764673283, 0.05420571991375514, 0.030290960134672265, 0.03996981434257967, 0.009034801490737923, 0.01612265022205455, 0.06677181526486363, 0.0498514249920845, 0.02601082739420235, 0.020124364777335098, 0.024469906597265174, 0.048939619812050035, 0.025252430500196557, 0.043572655479822836, 0.022632301452436616, 0.05392394128388592, 0.008237327765008169, 0.019465951714664698, 0.0326284997032157, 0.04365421199638929, 0.02533717273867556, 0.07172455093158142, 0.029357699677348137, 0.04910667174096618, 0.018819638627714345, 0.05119851717193212, 0.03967908922848957, 0.04373029273535524, 0.02001952093892864, 0.017015846579202583, 0.06762997885899884, 0.02067161344790033, 0.05489786634487765, 0.028069448357980167, 0.007193685775356633, 0.1169796950582947, 0.015187399960788233, 0.040024670506162305, 0.03325436344104154, 0.03637755156627723, 0.03791863012260624, 0.014953983914373177, 0.03678669461182185, 0.014405123723138655, 0.04817364877089858, 0.02197733874033604, 0.035123595103089295, 0.05158726006214108, 0.03784582670778036, 0.025693395141778246, 0.0054250443853171805, 0.01903332457212465, 0.01174960398514356, 0.07082637412739651, 0.02332712640054524, 0.029263301885553768, 0.08735953803573336, 0.027995554198111807, 0.030508942902088165, 0.06145797683192151, 0.07461210420089108, 0.03575452071215425, 0.033902550980980904, 0.04769607207604817, 0.04497923821743045, 0.12121171796960489, 0.0432394269321646, 0.06948374331529651, 0.0327365903316864, 0.03615169779264501, 0.01322664155824376, 0.023597373327772533, 0.020565733147252883, 0.01933749146493418, 0.043082349468022585, 0.030306539298700433, 0.0424376360273787, 0.014484685346750277, 0.03331456985324621, 0.03920883731916547, 0.01747387976917837, 0.034744935243257453, 0.07118846755474806, 0.01908665572825287, 0.024045840870322924, 0.01735566709456699, 0.024696379534101913, 0.04041368820305381, 0.06339344368981463, 0.027572282357141376, 0.008523424422102315, 0.04242795333266258, 0.04359358149979796, 0.05097332496994308, 0.016939323096136962, 0.032388698642275164, 0.07478591773126807, 0.03228760710252183, 0.07558218536100217, 0.10520775030766215, 0.011397896384421204, 0.02452581618646426, 0.051655137312731574, 0.03639690338500908, 0.012407456408254802, 0.03233123690422092, 0.003490331337421334, 0.10248506747718368, 0.18977447891873972, 0.1302302490387644, 0.2533325419894287, 0.08357585035264492, 0.22258812029446873, 0.06994217514459576, 0.19460639464003698, 0.12571230504129613, 0.10982613105859075, 0.16437114562307084, 0.10933073942682572, 0.10411815877471652, 0.2075421626546553, 0.10435034667274781, 0.13245070060448988, 0.18305840715765953, 0.10784681726779256, 0.13011138327419758, 0.10035679489374161, 0.16641615517437458, 0.12026115826198033, 0.19257534933941706, 0.16535872620131287, 0.12145779547946793, 0.14074693114629813, 0.18008772656321526, 0.10341941698321275, 0.09088650877986636, 0.12188909947872162, 0.12446666402476174, 0.10655380772160632, 0.08508278841951064, 0.10226486250758171, 0.11849147107984338, 0.12833352653043612, 0.13833169931811945, 0.11583941695945603, 0.08208355507148163, 0.08206563496163913, 0.09644088109156915, 0.10353477472173316, 0.12108456050711018, 0.13285373683486665, 0.12099305327449526, 0.13950675912201405, 0.15330147104603903, 0.16889815484838827, 0.11388257624847548, 0.16329574904271535, 0.20917433792991297, 0.2295187855405467, 0.1429151762276888, 0.12133138440549374, 0.14632359333336353, 0.12292576528021268, 0.17274951961423668, 0.13448356437895978, 0.08790818109576191, 0.1853763506348644, 0.1378508894039052, 0.12299722858837672, 0.052946338563093116, 0.13193383333938463, 0.2044663227030209, 0.13446856875504765, 0.1331391150930098, 0.11353765654244594, 0.08243249849017177, 0.1076028160750866, 0.16407227808875696, 0.15736802640770162, 0.11541784315236978, 0.12480578225638185, 0.10337723924645356, 0.18420171152268136, 0.11305268720856734, 0.17321787162550858, 0.12111233973077365, 0.11808724062783377, 0.12843590389404977, 0.15676623369966233, 0.1958451960235834, 0.12842561730316707, 0.16243175683276995, 0.1538399157247373, 0.06894322231944118, 0.12167237539376531, 0.1360769545925515, 0.08469898187156234, 0.19804252311587334, 0.07264246631945882, 0.09172222643558468, 0.14551547169685364, 0.22413298168352672, 0.15706860247467244, 0.07990118289100272, 0.059644476643630435, 0.13942206438098634, 0.15541620685585908, 0.09129546862095594, 0.13675312830933503, 0.11011938710830041, 0.12568615430167743, 0.24814134197575705, 0.107094159083707, 0.19874906806009157, 0.17097946602318967, 0.100285311229527, 0.19477617767240318, 0.12331257095294339, 0.17897606907146318, 0.15245868984077657, 0.1768228874674865, 0.08411406432943684, 0.10954005390937839, 0.1767973338386842, 0.09307264682969876, 0.12497859155493123, 0.22671696517084325, 0.1522433635379587, 0.10269423946738243, 0.1568690181842872, 0.1759688832930156, 0.13784645178488322, 0.11422218302530901, 0.16980880312621593, 0.19936831268881047, 0.12708488638911927, 0.14174838098032133, 0.14132946703050817, 0.1610031963459083, 0.2057254665664264, 0.0836480532639793, 0.17468561072434696, 0.11978693013744694, 0.15823010514889443, 0.14232911196138176, 0.14579574737165654, 0.08118324766733817, 0.17754374950059823, 0.1144274670098509, 0.10213686366166387, 0.14588952091123375, 0.11609835949327264, 0.11244372917073113, 0.21352488733828068, 0.07389798680586473, 0.11508707090147904, 0.22970912818397793, 0.11614521912166051, 0.11229758629841463, 0.1819217252944197, 0.10083020199090242, 0.1156466044485569, 0.1145359104765313, 0.2031909075698682, 0.16751496121287346, 0.10375622819576945, 0.15066529464508804, 0.12099766731262207, 0.07479807707880225, 0.14558949986738817, 0.11750816527221884, 0.15501038863190583, 0.15096846409142017, 0.14221183396875858, 0.14050196643386567, 0.24007429342184747, 0.1338163608951228, 0.25782007404736107, 0.13304952132914746, 0.08798011259308883, 0.0850981165255819, 0.16775266560060637, 0.11434210730450493], [0.09240780464772667, 0.01268470666504332, 0.04201111909268158, 0.023231612418645194, 0.013155800805959319, 0.018724869337997267, 0.0414545032461839, 0.048137666058859656, 0.005550905845926276, 0.036731723097286055, 0.06206158801381077, 0.006792758092550295, 0.03203040161835296, 0.053841081980083666, 0.015191761244620596, 0.03165048986141171, 0.03616531938314438, 0.05398154890696917, 0.05717110114970377, 0.0057888807994978765, 0.10068640006440026, 0.03346658544614911, 0.011399849717106138, 0.02611828189609306, 0.05575908334659679, 0.026417576907468692, 0.03281586357791509, 0.009724136242376906, 0.016385967610403895, 0.034716524982026646, 0.01861710610267307, 0.04256894612418754, 0.016161079052835703, 0.032627722780619345, 0.04264233986447964, 0.05739536375871726, 0.02402433131023177, 0.00404629303375259, 0.040595250603343756, 0.05516284105501004, 0.04926590355379241, 0.056532542021679025, 0.044807467077459605, 0.04169569191123758, 0.03212018197934542, 0.026448948974055902, 0.014792289019429257, 0.045871983348791084, 0.0414054078449096, 0.011819080033871745, 0.045569631537156444, 0.04038153582119516, 0.02084811058427606, 0.042359825024115186, 0.058664889207908084, 0.03234446833708456, 0.05635423658947859, 0.0036789774312637746, 0.0033684583904687315, 0.05416845816320606, 0.036155531515500376, 0.03537210516099419, 0.029396260822457925, 0.06442042001123939, 0.024657163602699126, 0.03165249153971672, 0.046879556961357594, 0.052024087336446555, 0.06572919192590884, 0.05933899339288473, 0.045054029739860973, 0.02254099947666483, 0.06095965392887592, 0.04211544045912368, 0.044336146475481134, 0.059815331761326106, 0.0340654129561569, 0.03548631617533309, 0.035460616661501784, 0.035837892309895585, 0.10382421061928783, 0.04546675205762897, 0.043930569131459506, 0.03418371892933335, 0.016799477028793523, 0.08074772318026849, 0.08521160829280104, 0.04246354927974088, 0.05794459714421204, 0.0301458554209343, 0.05761974850403411, 0.024830152713028446, 0.023966068900855522, 0.008945847246130663, 0.04329590818711689, 0.05558929692155548, 0.085669483723385, 0.027385086419859102, 0.017720484840018407, 0.016625605822939957, 0.028827757042433535, 0.03267121008996453, 0.024059045161785822, 0.09061012789607048, 0.03546452841588429, 0.04450275735663516, 0.04703197967527168, 0.029026024974882603, 0.005765216890722513, 0.036136580032429526, 0.032092575782111714, 0.11734626681676932, 0.08131020156932728, 0.04137839536581721, 0.01794982119463384, 0.04951577068173459, 0.014698832694973265, 0.029745071926819425, 0.029101545922458172, 0.03469411636303578, 0.051393456890114715, 0.0683579451537558, 0.08423018881252833, 0.04264777832265411, 0.06198697630316019, 0.017108676955103874, 0.01608089487334447, 0.018933652866897837, 0.04924208697463785, 0.019726470146062117, 0.02063166639501495, 0.054452296146856885, 0.005744704353024385, 0.04080501291900873, 0.02588939167825239, 0.05240479637203472, 0.01958963168518884, 0.13133007287979126, 0.011412476405634411, 0.018297117469566207, 0.04293612177882876, 0.010536302795766719, 0.013993647365298654, 0.036043037194758654, 0.016579550258549194, 0.024877409284402217, 0.0697486705279776, 0.03494680280398045, 0.03439074335619807, 0.07904035943959441, 0.03535371346931372, 0.04189951026013919, 0.014437713760084339, 0.014195828748467778, 0.04781010667128222, 0.009101872980993773, 0.037546959173466475, 0.025341444116617953, 0.01731205086356827, 0.02836978152793433, 0.054784544211413176, 0.0349281532689929, 0.037868184436644824, 0.045490035986793895, 0.037281858934355636, 0.01794257104795958, 0.01572412794588932, 0.0318047683686018, 0.01193626896877374, 0.018152984757242457, 0.037314893411738534, 0.05714277909802539, 0.01651699441884245, 0.02531378872559539, 0.06501260466341462, 0.04065799812919327, 0.03887428223554577, 0.03809495083987713, 0.07781825001750674, 0.06592162445719753, 0.007083118069983486, 0.0307483436273677, 0.09398235194385052, 0.046037433935063224, 0.016642068778829913, 0.04001604632607528, 0.022180383559316397, 0.0265929086599499, 0.036541187071374485, 0.04239259148016572, 0.046885042916983366, 0.07231873047671147, 0.08062966487237386, 0.053776037613196034, 0.06046019108699901, 0.045078881084918976, 0.047791796403803995, 0.05097809846379927, 0.03603691680889044, 0.07868969932730709, 0.05508586125714438, 0.04710172628983855, 0.04028573685458728, 0.020089605124667287, 0.019128794449248483, 0.009717558693539883, 0.027065028236912828, 0.02933146751352719, 0.10237732968692269, 0.04176022059151104, 0.062443053615944724, 0.022252552543899844, 0.022978722417194928, 0.02007912175862917, 0.03719608532264829, 0.04240434370668871, 0.06239809388560908, 0.023162985386859094, 0.014229528190168952, 0.024480238989261643, 0.05435027840680309, 0.034727113520992656, 0.06485448564801898, 0.06864288914948702, 0.02786605409346521, 0.02544147883807974, 0.060976685157844, 0.006999501775551055, 0.02790829968372626, 0.02666451615680541, 0.04752600745164922, 0.032892605888524225, 0.025707045570015907, 0.02093185537627765, 0.012550869873458785, 0.023537473952663795, 0.017699083845530237, 0.047321303614548275, 0.028691391859735762, 0.013819661656660693, 0.05332848270024572, 0.007007318074881498, 0.021877655160746405, 0.06306227788861309, 0.015002580592408776, 0.03061421761023147, 0.039568956209612746, 0.02399556651445372, 0.0315593252889812, 0.06383785020027842, 0.042547755475555143, 0.018284167628735304, 0.05180316311972482, 0.02490787041772689, 0.05302981533376234, 0.03796115051954985, 0.043769888646368466, 0.09882545670760529, 0.03812174618776355, 0.032534912760768614, 0.016532293687175428, 0.03365667363894837, 0.053813713270106485, 0.029175862470375638, 0.03798864475850548, 0.011178441196014839, 0.011189088258626205, 0.06106429759945188, 0.04875031532719731, 0.056087155028113296, 0.048432553985289166, 0.03582514263689518, 0.06387734772371394, 0.05826931007738624, 0.032516772127045054, 0.06673512009105512, 0.017695709830150008, 0.02983046555891633, 0.025011262191193442, 0.09465620507087026, 0.023815729289448688, 0.06126714564327683, 0.041338429653218815, 0.011026948923245072, 0.014336756230997188, 0.07353003762130227, 0.07238000897424561, 0.06515095795371703, 0.03745459698672805, 0.046023836093289514, 0.019610186207241247, 0.031369844385023625, 0.009623072692193091, 0.04189964935981801, 0.1374215938683067, 0.04394840781709977, 0.0663027304357716, 0.04081192719084876, 0.11791398349617209, 0.022837780515796373, 0.04043203239728298, 0.016457310478602136, 0.02091464094285454, 0.025532706174999475, 0.09972763686840024, 0.0055775154448513475, 0.042232776127223454, 0.04058741691655346, 0.012989711548600878, 0.03085306193679571, 0.04787190764078072, 0.026259793766907284, 0.0379587620762842, 0.044787005853972266, 0.03819795245570796, 0.03938484251765268, 0.10817283977355276, 0.03361182247421571, 0.03184008950899754, 0.02740588691085577, 0.07991981546261481, 0.02224505982095642, 0.007012726423064513, 0.025172663619741797, 0.03004066552966833, 0.0375234547204205, 0.03454731870442629, 0.035762968473136425, 0.089693155671869, 0.05159939566094961, 0.09461197815835476, 0.019495703778894882, 0.06018604936876467, 0.0317665634543768, 0.017104101932740638, 0.03332251549831458, 0.008847688673995435, 0.039520936286343, 0.06440589257649013, 0.056708730424621275, 0.012343017633871307, 0.042688687198928425, 0.02223322617023119, 0.0058354948830258635, 0.028451814715351378, 0.07760869804769754, 0.04372114269062877, 0.016178939790864075, 0.0034881733840198387, 0.009173520341781633, 0.006804280465335718, 0.026409865356981754, 0.17361640238336154, 0.10363534718219723, 0.13686135464480945, 0.21016684467239038, 0.05812421893434865, 0.15936464284147533, 0.16800864972174168, 0.15412629821470805, 0.08535151542829615, 0.1231436835868018, 0.1962225293474538, 0.09354289195367269, 0.1438457327229636, 0.14738338360829012, 0.13154420496097632, 0.1900771191077573, 0.2535361839192254, 0.12177891896239348, 0.14901383540460042, 0.1315205240888255, 0.15072173518793924, 0.14921764018280165, 0.09483761140810591, 0.11015362598534141, 0.1289484692471368, 0.08731921948492527, 0.19981382521135466, 0.10217043078903641, 0.10721767959850174, 0.10154938804251806, 0.08774505449192864, 0.12718358609293187, 0.16193076728710107, 0.09559870378247329, 0.12762577379388468, 0.1439269126525947, 0.16237851897520678, 0.12530765389757498, 0.1225963229579585, 0.1327161977865866, 0.1306193210184574, 0.1815651280007192, 0.07815865068031208, 0.09791560910109963, 0.19163937813469342, 0.11703180654772691, 0.0970451979498778, 0.10062106392745461, 0.06915876575346504, 0.14767044463327952, 0.14722860977053642, 0.10373546502419881, 0.09004093879567725, 0.1251636959080185, 0.09266644862613507, 0.1245329026132822, 0.13770887202450208, 0.10565432134483542, 0.11486101017466613, 0.1366951678480421, 0.0937320946582726, 0.10956453545285122, 0.07499706425837108, 0.13859015330672264, 0.07019218137221676, 0.11098342003034693, 0.12000946248216288, 0.19185322523117065, 0.15972425283065864, 0.12460455591125147, 0.1666818694876773, 0.10283407874937568, 0.16776984610727855, 0.11354644357093743, 0.11673107982746192, 0.2040639921490635, 0.18616959878376552, 0.11158624411161457, 0.11402124166488647, 0.09980158361473254, 0.19004235097340175, 0.2217679207346269, 0.08533924751515899, 0.09258391162646668, 0.08620977401733398, 0.16914431378245354, 0.16006266538585934, 0.10803006922027894, 0.13572054728865623, 0.16094633511134557, 0.10936054747019495, 0.14346204831131867, 0.10242190943764788, 0.10119773726910353, 0.07801615154104573, 0.11607473290392331, 0.14073319759752068, 0.1459958337779556, 0.16022905574313231, 0.11992680334619113, 0.09020361078104802, 0.082720753736794, 0.055604292545467615, 0.28292516406093327, 0.16425884807748453, 0.125121070338147, 0.13809650550995553, 0.06466132708426033, 0.04258004356441753, 0.12918328307569027, 0.16122066681938513, 0.19455986070845807, 0.15979122423699924, 0.09928107261657715, 0.11053695755877666, 0.09356980265251227, 0.1085984915761011, 0.13348746140088352, 0.13413927571049758, 0.16457747455154145, 0.09022829588502645, 0.15042292193642684, 0.1809841798884528, 0.11535670714718954, 0.14109648524650506, 0.06891086976975203, 0.1279085057654551, 0.10315304449094193, 0.17058873841805117, 0.10959721369934933, 0.1032478426183973, 0.11270217637398414, 0.07932045190994229, 0.1598099653742143, 0.1877118410276515, 0.14371109780456337, 0.11514237150549889, 0.18797048500605992, 0.12306562491825648, 0.14711277027215275, 0.17600085586309433, 0.1388766850743975, 0.08532708138227463, 0.14706848907683576, 0.17801510063665255, 0.1710385392819132, 0.11980606482497283, 0.10114610075418438, 0.13557946628757886, 0.1575595632727657, 0.09082276041486434, 0.11640004973326411, 0.14973001554608345, 0.11150044335850648, 0.3560617124395711, 0.08704199043235608, 0.13728613113718374, 0.09548858433429684, 0.08969124220311642, 0.11101894133857318, 0.11793344388050692, 0.15732177746083054, 0.13103458444987023, 0.09903407908443894, 0.08056350092270545, 0.12572769421551908, 0.08341273731951203, 0.09468314969646079, 0.10941433494112321, 0.11543467082083225, 0.07972369170082466, 0.20107870948101791, 0.11300692002155951, 0.10504152279879365, 0.23073678304042133, 0.09480845475835459], [0.020454075120921646, 0.014788601181602903, 0.018565113356869136, 0.02598204563504883, 0.008820073146905218, 0.012160253378429582, 0.007515337667427957, 0.027439694918159927, 0.032180554632629664, 0.023804277314671447, 0.020497955980577638, 0.03318140057048627, 0.02091212697061045, 0.016998778030808483, 0.03811094051759158, 0.009774626033114535, 0.020956628689808503, 0.07618844282946416, 0.03273274303813066, 0.013853389087931385, 0.02412492243040885, 0.03921595175883599, 0.04705289890989661, 0.03095549697588597, 0.036016458978078196, 0.057021375612488816, 0.04334676777943969, 0.023972062061407735, 0.03678796686498182, 0.029177789509828602, 0.013068549684248865, 0.016373526670836976, 0.026474738393777182, 0.03024328626426203, 0.039496271538415124, 0.05237733945250511, 0.0377849621166076, 0.011050473732341613, 0.03759478232158082, 0.010364004094818873, 0.024863989558070898, 0.016672224571396197, 0.049499445129185915, 0.031160523117120777, 0.04121260211936065, 0.021054458172459687, 0.016117215156555176, 0.010513180866837502, 0.07095182846699442, 0.03406700412077563, 0.06852538045495749, 0.05416005111432501, 0.0661940901939358, 0.08156605676880904, 0.03832309466919728, 0.024144391296431422, 0.014847603194149477, 0.046331463514694145, 0.022530777346608893, 0.009051855620262879, 0.024094303537692343, 0.016091412166133523, 0.04348146376599159, 0.04354501874851329, 0.010235367425983506, 0.04896125490111964, 0.05301627516746521, 0.027468955044501593, 0.025907888542860746, 0.007599794073030353, 0.04639547990102853, 0.04099492808537824, 0.020163955599335686, 0.037209700127797465, 0.06656159154538598, 0.03610689412536366, 0.022282062031860863, 0.02441437359500144, 0.03277320408129266, 0.04220177386222141, 0.046008345138813765, 0.03854331660217472, 0.060443980885403495, 0.009770447105568434, 0.011021924371431981, 0.050315451342612505, 0.028236038883083632, 0.06345662887075118, 0.04049069174964513, 0.04133776129622545, 0.030415963248482773, 0.014057450861270939, 0.008397787726218147, 0.06144808379134961, 0.044822513591498137, 0.02859195594542793, 0.04835997109434434, 0.02394455934076437, 0.03623500832223466, 0.09189424184816224, 0.02011972020513245, 0.008601513624723469, 0.042859152158988376, 0.038958600389638116, 0.02290355261149151, 0.05052512205604996, 0.05756507215223142, 0.036110816057771444, 0.035323807038366795, 0.05990286956408194, 0.020881272286974957, 0.04319628567567893, 0.022214378163750683, 0.0182879843882152, 0.032160147691943815, 0.028500248544982502, 0.02490405535458454, 0.005998570596732731, 0.009578057830887181, 0.018618595487039005, 0.044175567770642896, 0.04380578654153006, 0.02683604641684464, 0.05371871158214552, 0.02518542516710503, 0.04932361974247864, 0.09075179243726389, 0.04653673392853566, 0.07981621673596756, 0.015707205282524228, 0.01504200347699225, 0.044661850069782565, 0.0048099439092246545, 0.028028408863714764, 0.023735029423343282, 0.08465668878384999, 0.05238810780325106, 0.026247022041518773, 0.006249566637312195, 0.036866303732884784, 0.07612538657018117, 0.038179425057023764, 0.05373873854322093, 0.04303949658891984, 0.019764298473351767, 0.02785761481417077, 0.02508695955787386, 0.04312871376584683, 0.019427667072575008, 0.026603037491440773, 0.03615954505013568, 0.05916714082871165, 0.03739648046238082, 0.0446187054206218, 0.05892149079591036, 0.058500765157597404, 0.00870766703571592, 0.03862891040210213, 0.008274751515792949, 0.026938347445268716, 0.06479627412876912, 0.02122325393637376, 0.05233782835836921, 0.036370063932346444, 0.035220523830503225, 0.023746021690645387, 0.04601168353110552, 0.05323901107268674, 0.06455618808312075, 0.044475293651755364, 0.014340432194460715, 0.038605436483131986, 0.05420867832643645, 0.03117752041933792, 0.02327887068635651, 0.04069239306928856, 0.03275474453611033, 0.08826267493090459, 0.024958399224228094, 0.015976827957534363, 0.036026684500809224, 0.009947392075056476, 0.008361974647933883, 0.058590040010000975, 0.09603332581796817, 0.056131565145083835, 0.006717332139877337, 0.02444254806531327, 0.024452000058123043, 0.04726640334618943, 0.04558442360056298, 0.06543247534760407, 0.02804306522011757, 0.005716681704922978, 0.012323403730988503, 0.022718003817967007, 0.014707370361845409, 0.05371217728991594, 0.051957132893481424, 0.0834370017317789, 0.04667069370459233, 0.043584478952522786, 0.027360077315409268, 0.037550219534231086, 0.04129507126552718, 0.0316574210966272, 0.014320505317300558, 0.031486525266830406, 0.02326489795398499, 0.0354038809559175, 0.04518851538055709, 0.04968965206561344, 0.030484963474529128, 0.014066772236089622, 0.03931634101484503, 0.0032639209530316293, 0.014876045685793673, 0.021643692893641334, 0.007021993090997317, 0.016172743069806268, 0.04916979246107595, 0.020459929181795036, 0.013946163484693637, 0.017912863088505607, 0.04432279969166432, 0.03184942275817905, 0.03669858344697526, 0.006084624952304044, 0.04410387036789741, 0.014067154760206384, 0.015546562116859215, 0.048871956299990416, 0.031893432539488585, 0.024212882621213794, 0.03192586312070489, 0.09810635886554207, 0.02668239046553416, 0.027076872065663338, 0.042137652302959135, 0.06084025212164436, 0.022657424211502075, 0.031402617626424344, 0.015936499228700995, 0.012789139141594725, 0.041474038269370794, 0.0033076262417515473, 0.010827290842176547, 0.007449079571025712, 0.016705586441925595, 0.03670613893440791, 0.08895213436335325, 0.027410120969372134, 0.029347447013216357, 0.012083939393050969, 0.03261052191789661, 0.014434473755370294, 0.023980967833527496, 0.0066976168808261195, 0.021388556941279342, 0.023399607511237264, 0.04524813825264573, 0.02888280658849648, 0.03145487160821046, 0.03794501156413129, 0.04133422952145338, 0.057243860459753444, 0.04968880389684013, 0.049352962989360094, 0.028364553415615643, 0.006720381730701774, 0.026416793199522153, 0.04870185096349035, 0.02718293896344091, 0.06455973682126828, 0.013717321612473046, 0.0264469914005271, 0.06980895836438451, 0.025412315402978232, 0.03569906743775521, 0.021054519240611365, 0.041003280851457796, 0.10338943930608885, 0.020317190858934606, 0.03557064790012581, 0.041307708980249505, 0.026350116955914667, 0.02473089491416301, 0.020954951011974896, 0.029658982796328406, 0.02251184282691351, 0.0211377127229103, 0.02966439411310213, 0.01604538374314351, 0.03187961417383381, 0.008831963624938257, 0.03319416381418705, 0.0378565984512014, 0.019757667489882027, 0.009639967365988662, 0.01447646998401199, 0.06795432538326297, 0.047402809240988324, 0.06871466458375965, 0.02503492440363126, 0.025920870614105036, 0.04884556807311518, 0.019840784636991363, 0.02460237529261836, 0.029651858178632598, 0.03433251826624785, 0.11309092944221837, 0.11257080520902361, 0.00955074594821781, 0.024611710238137414, 0.033185682126453946, 0.006563162622374615, 0.06471381176795278, 0.018036688944058757, 0.023768801807558963, 0.05453671268852694, 0.07337545377335378, 0.036596911759780984, 0.03622481672625456, 0.01937861747241446, 0.037526830432138274, 0.06620577456695692, 0.025632513587230017, 0.016947061788024645, 0.04812528279476932, 0.01968472497537732, 0.0525567712528365, 0.004506601436462785, 0.015066831073324596, 0.02821711284507598, 0.0635189658829144, 0.028280145355633328, 0.03489914589694568, 0.05394504372296589, 0.024505456743229712, 0.007778948522172868, 0.06952330190688372, 0.057612101414373944, 0.023201677149959972, 0.012580426010702337, 0.03209377678909472, 0.015575343876012733, 0.05960087398333209, 0.038899106439203024, 0.042535826829927306, 0.01570198225921818, 0.011716931675826865, 0.030293555531118597, 0.08833770054791655, 0.12768758833408356, 0.09661046734877995, 0.11835423058697156, 0.18291159932102474, 0.13177508328642162, 0.157821477789964, 0.07782536784985236, 0.15582935325801373, 0.10506602469831705, 0.16860652049737318, 0.13909338201795304, 0.14411538253937448, 0.08982937157686267, 0.25030388736299103, 0.13516699842044286, 0.10019056738487311, 0.11983005782323224, 0.11377290463341133, 0.08070302129323993, 0.08451648987829685, 0.1349859924188682, 0.17310748754867486, 0.19250982999801636, 0.12213394205485072, 0.11213888374290296, 0.08817690810454742, 0.11083367413708142, 0.10953336355409451, 0.09820040381912674, 0.08419086092284747, 0.10400518269411155, 0.07887027785181999, 0.10696836547659976, 0.1458529071616275, 0.14374339607145104, 0.1440077397440161, 0.1158472201121705, 0.11202114434646708, 0.05816518887877464, 0.15070270906601632, 0.09158461953380279, 0.10014194356543676, 0.14240592212549277, 0.0664170975131648, 0.0884305512798684, 0.07186116038688592, 0.14809765028102057, 0.11917170243603842, 0.09282119532248803, 0.07984293065965176, 0.09727928574596133, 0.15940880190048898, 0.14950208206261906, 0.13012739670063767, 0.09131231664546899, 0.11667640347565923, 0.1473388717110668, 0.1530671321919986, 0.13667388898985727, 0.1474246113960232, 0.07254994128431592, 0.20194253884255886, 0.2857384516724518, 0.10235678364655801, 0.09419136787099497, 0.09969702136835881, 0.11161612000848566, 0.09838854122374739, 0.07679306502853121, 0.1046373669856361, 0.10821440682879516, 0.0677760403071131, 0.1712950798017638, 0.15041301532515458, 0.08965757329549108, 0.12619008868932724, 0.06795625242271594, 0.12482715610946928, 0.1717676387301513, 0.15777107620877878, 0.1476407926529646, 0.15603416226804256, 0.12179029120930604, 0.09893512832266943, 0.06133860216609069, 0.1230469923466444, 0.12609096829380306, 0.16568010752754553, 0.1300794921283211, 0.13636842609516212, 0.14452544839254447, 0.0621222694005285, 0.1441842538437673, 0.1325621431959527, 0.11364818311163358, 0.12528712142791065, 0.16827722745282309, 0.11971358050193105, 0.14730368288499968, 0.12773693140063966, 0.07444164941885642, 0.1555632861065013, 0.10118997482849018, 0.06861222615199429, 0.1930058526673487, 0.13101451338401862, 0.09688037500849792, 0.13046091023300374, 0.14875448574977262, 0.1775847872985261, 0.17694695081029618, 0.14079043881169387, 0.08694507527564253, 0.10061714199504682, 0.09862076304852962, 0.07344570250383445, 0.1535795618380819, 0.11501606899712767, 0.09804375043937139, 0.16295929066836834, 0.11673835372286183, 0.05825377841080938, 0.1771721023001841, 0.15330407662051065, 0.10588349654738392, 0.27638560639960424, 0.11533713819725172, 0.20807640041623796, 0.12458846106060914, 0.06022837638322796, 0.08822653615581137, 0.12522774961377892, 0.0918309073895216, 0.1726697510374444, 0.20449043783758367, 0.14061634029660905, 0.09119017355676208, 0.060405575803347995, 0.09446005416767937, 0.16571798335228646, 0.111273561604321, 0.11270331631281547, 0.13959661072918347, 0.21673431726438658, 0.22860602023346083, 0.0851834151627762, 0.14072846142309053, 0.1734856351145676, 0.12774957929338726, 0.06846748106181622, 0.14012928786022322, 0.10787101382655756, 0.15273064667625086, 0.23117310819881304, 0.17668294640524046, 0.10391336333538805, 0.1023062870704702, 0.11718050071171351, 0.15268048936767237, 0.20741609084819043, 0.19269604714853422, 0.08405832946300507, 0.07549349404871464, 0.12586173202310288, 0.08730785402336291, 0.10827660134860448, 0.1576612756720611, 0.10650394218308584, 0.13369073692177022, 0.14790082084281103, 0.10666435464684453, 0.11427930210317884, 0.14548277987965516, 0.146747976275427, 0.1884012326065983], [0.01267950060511274, 0.0494133559986949, 0.010850207514262624, 0.08278528241706745, 0.03035518347418734, 0.03194231420223202, 0.05652870490614857, 0.049679111024098735, 0.019847585254215767, 0.015422890628022807, 0.062101757286914756, 0.018754599349839345, 0.014701066771522164, 0.04971154499799013, 0.08613713005823748, 0.04544539177524192, 0.011775526567362249, 0.013970970724975424, 0.030203999086682285, 0.06875107477286033, 0.021920156897976995, 0.037877975696963925, 0.05003480925889952, 0.011455729620398154, 0.03417307610756584, 0.014886347543714302, 0.07953315906758819, 0.04520747364897813, 0.01318976657265531, 0.03620593988203576, 0.06515169077153717, 0.028789060190320015, 0.0049868939677253366, 0.046144421944128614, 0.04216589293043528, 0.025299042463302612, 0.08627278956451587, 0.03815625308613692, 0.035973185407263894, 0.0033464303872148904, 0.0134440764086321, 0.04103284462222031, 0.023975000118038485, 0.047827450026358874, 0.0405804687179625, 0.07606520051402704, 0.023321219753207903, 0.028202704153954983, 0.07139659460101809, 0.025337040424346924, 0.0018885932347205067, 0.02492070660394217, 0.05508963730452316, 0.03710078847195421, 0.07256153744778462, 0.04249516901160989, 0.03306015993335417, 0.08980176198695387, 0.04693546485421913, 0.02686677048248904, 0.03219351804416094, 0.05105758544855884, 0.010019474546425045, 0.005109414915620748, 0.023790212980072414, 0.0554051425174943, 0.04221183653654797, 0.048180128780326674, 0.045731529992605956, 0.023363938621644462, 0.03876252073262419, 0.007348339173144528, 0.021752456968118037, 0.03360814481441464, 0.07587426075977938, 0.05517501736591969, 0.03242523096767919, 0.02005191589705646, 0.05357545926900847, 0.02939327187570078, 0.06554283228303705, 0.048471702063190084, 0.06735285837203264, 0.01708434638567269, 0.06300328605409179, 0.027406597676287805, 0.10318479992981468, 0.024881256577957953, 0.021329407347366214, 0.0471195242633777, 0.01319714479281434, 0.05529635978330459, 0.019873281375371983, 0.03736094897612929, 0.04379814284454499, 0.025768123899719546, 0.01016059541143477, 0.019632504920342138, 0.0405520041739302, 0.013969560220305408, 0.04836624075791665, 0.024757003245343055, 0.011681924357877245, 0.0230451289431325, 0.024277038107227002, 0.030608847005558864, 0.007714273956870394, 0.012065105805439609, 0.03840875292995146, 0.03468060673081449, 0.03465329908898898, 0.08591858071408101, 0.027998858663652624, 0.03883262697075095, 0.04829299629532865, 0.0311576495213168, 0.07980466806995017, 0.037241017911583185, 0.059144294554633756, 0.06643072249633925, 0.03251786456842508, 0.037442888864981275, 0.036354389773415666, 0.024713427726445452, 0.02712600987537631, 0.015221521790538515, 0.03742845303245953, 0.03565725950258119, 0.013917984773537942, 0.09431128536484071, 0.06980145376707826, 0.07939110097608396, 0.05595128517597914, 0.03795848048425146, 0.04704538413456508, 0.03827364982238837, 0.013777511909471025, 0.028056627438802804, 0.05726098668362413, 0.0200125371172492, 0.04414785640048129, 0.007900044970613505, 0.039821598545781205, 0.016008098243868778, 0.044981056691280434, 0.10314330072807414, 0.008594567970638829, 0.025593049990545427, 0.02861293964087963, 0.02852317624326263, 0.011440929075303887, 0.03991458498473678, 0.07107496900217873, 0.028152009106374214, 0.06528470399124281, 0.06382890710873262, 0.01329136107649122, 0.09422803590340273, 0.03105241891794971, 0.00624567099813638, 0.029116704394774776, 0.06178836231785161, 0.004233454196115157, 0.05901710995073829, 0.017546036879398992, 0.024076800726886307, 0.02103093675603824, 0.01139820002884205, 0.018930626600714665, 0.024298534096617783, 0.044521953112312725, 0.03641678446105548, 0.10590341833553144, 0.0438138475375516, 0.08211601618677378, 0.029751925130507777, 0.04899619606190494, 0.037593072413333824, 0.0023517767175300314, 0.041229100698339086, 0.02535461787400501, 0.05979832088840859, 0.015820805615346347, 0.021211664558255246, 0.027558119634964635, 0.014129550296014972, 0.025938950179676925, 0.052976774251354594, 0.017511781038982526, 0.050848823972046375, 0.01664485755775656, 0.06969864214105265, 0.07074674125760794, 0.03739167643444879, 0.03090626247493284, 0.04470303375273943, 0.012573457456060817, 0.03637987215604101, 0.024825560727289746, 0.045924332325479815, 0.050037961054061136, 0.032609582146895785, 0.040574090488787205, 0.00936864665709436, 0.04668032211650695, 0.04494041583633848, 0.04793485872713583, 0.05391642650855439, 0.050877017102071216, 0.016229524576504315, 0.03885803471452423, 0.02979227082271661, 0.0397245544674141, 0.08555237536451646, 0.03016605880111456, 0.030416132882237434, 0.024760767418359007, 0.030431233679077456, 0.021788263261052113, 0.03403797639267785, 0.02891672994675381, 0.07158250641077757, 0.0720248773161854, 0.034974256330834966, 0.06961389311722346, 0.007108359148592821, 0.009915399997095977, 0.018480803684464524, 0.0790406104975513, 0.07231062876858882, 0.030603235520954643, 0.006819551744099174, 0.014117376529611647, 0.03391522940780435, 0.04939491002421294, 0.050669507522668154, 0.05220210439126406, 0.03421843617356249, 0.04211042269266077, 0.09773999745292322, 0.033861916911389144, 0.03317312244325876, 0.015477716257529599, 0.06495876290968486, 0.02745365577616862, 0.041539235306637626, 0.06433724518865347, 0.07350634317845106, 0.036339010777218, 0.008577403579173344, 0.027009429077484777, 0.05085460848308035, 0.05076934716531208, 0.019826728784080063, 0.058285615273884366, 0.028224636102095246, 0.012814245785453489, 0.06259434656905276, 0.06733261088707618, 0.023785958565505486, 0.034733186409409554, 0.09314027641500745, 0.0903165325788515, 0.11223721703780548, 0.02745707389632506, 0.023858504137024283, 0.07257178332656622, 0.015454471344128251, 0.005981301880508129, 0.050634437440229316, 0.06729181057640485, 0.018715909283076013, 0.044955258789871416, 0.035561413038522005, 0.03396491852721997, 0.036087973176368644, 0.03016692732593843, 0.037499739921518734, 0.03128856946048992, 0.002960679412353784, 0.03615670198840754, 0.020450997964612076, 0.019722461700439453, 0.027584957391289727, 0.01111531284238611, 0.04395545440326844, 0.05032471673829215, 0.07436458819678851, 0.02216394604848964, 0.061317479370960166, 0.022920941767681922, 0.018588134353714328, 0.03284167844269957, 0.015272193089393633, 0.031121123981262957, 0.0741577096549528, 0.007538087250265692, 0.05356977993090238, 0.018446442671120167, 0.02488817084979798, 0.019049592449196746, 0.04376432805189064, 0.045383960607328584, 0.009582360591074186, 0.023206360737926195, 0.037128716973321776, 0.03826657270214387, 0.037318333584283075, 0.04529362724029592, 0.026166849736390368, 0.01816828572191298, 0.022517980176157186, 0.007594270797978554, 0.02146949090196618, 0.10121316037007741, 0.0465809947678021, 0.03145847123648439, 0.026129986625164747, 0.025825295564053313, 0.03761272957282407, 0.0390566045950566, 0.03443745370688183, 0.005520648273107196, 0.01956457338695015, 0.018283061616654907, 0.06272879149764776, 0.021075862559622953, 0.013544463120134813, 0.046990945270018916, 0.019208992199440087, 0.03250963393864887, 0.016211959001209055, 0.03552101645618677, 0.041086828868303976, 0.04606949471469436, 0.015809614876551286, 0.02388681940335248, 0.03413702214934996, 0.009770581964403391, 0.03869812097400427, 0.011476101786164301, 0.04672923092065113, 0.006700275889930448, 0.009462700940535536, 0.02396953451846327, 0.03377031468387161, 0.03210944416267531, 0.05574000972722258, 0.03804594025548015, 0.06588260190827505, 0.0482247933479292, 0.03321975815509047, 0.15379479314599717, 0.12914588222546236, 0.06798192818782159, 0.1456905880144664, 0.14597592556050845, 0.10583953426352569, 0.1285878550261259, 0.08366868751389639, 0.12723431337092603, 0.054552312208605666, 0.14105304543461117, 0.18741190140800817, 0.0879680278844067, 0.11789668085319654, 0.1633511446416378, 0.1678418115313564, 0.17411032159413609, 0.0652633708502565, 0.17643942018704756, 0.14455036419842923, 0.10494955416236605, 0.17382611041622503, 0.14621448490236486, 0.0816541306142296, 0.18925204766648157, 0.11575793847441673, 0.1271990431206567, 0.08044822460838727, 0.21796246564814023, 0.12088049788560186, 0.2105757434453283, 0.12427503216479506, 0.11431370382862431, 0.10954738208757979, 0.1347787542534726, 0.07644585865948882, 0.1800807783646243, 0.1728380820048707, 0.15658156360898698, 0.06852201492126499, 0.07784682312714201, 0.0983308996739132, 0.1750507847006832, 0.09615842731935637, 0.18829426834625856, 0.10843425217483725, 0.09343897431556668, 0.22085861595613615, 0.15980232506990433, 0.0612192139295595, 0.11272008969847645, 0.1573197961385761, 0.14111384217228207, 0.1391146473054375, 0.14230323263577052, 0.12937372071402414, 0.09756760206073523, 0.10582258445875985, 0.12711909812475952, 0.12159728870860168, 0.16229558842522757, 0.1962762557502304, 0.10914695143167462, 0.15840656496584415, 0.13143079461795942, 0.1100017698481679, 0.10185107828250953, 0.10317190097911016, 0.16990016108112677, 0.140397078490683, 0.1635013044412647, 0.1283885557204485, 0.06549291924706527, 0.16506424200321945, 0.12355222952153001, 0.10078131354280881, 0.1784574511860098, 0.12534732105476515, 0.20683130222771848, 0.08016906851636511, 0.1608992719224521, 0.13900794088840485, 0.19646985536175116, 0.07827877852001361, 0.10599979066423007, 0.1475292822079999, 0.16560241526791028, 0.17113452484565123, 0.13750798494688102, 0.16729905136993953, 0.09302821635667767, 0.11086728197655507, 0.07283165545335837, 0.1503255928733519, 0.14305665077907698, 0.18124401808849402, 0.12579535772757872, 0.14793159919125692, 0.17161867315215723, 0.09962428919970989, 0.10739437011735779, 0.1296025498637131, 0.06878941200141396, 0.15223879021193298, 0.10514622753752129, 0.1275915349168437, 0.12359230379973139, 0.11353523417242936, 0.08239245813872133, 0.14350900293460914, 0.075414695776999, 0.21423409213977201, 0.08893245684781245, 0.15675327368080616, 0.13293882512620517, 0.08021774661860295, 0.16552536083119257, 0.12319312164826052, 0.15357634558209352, 0.13149155064352921, 0.1023358508412327, 0.08424713183194399, 0.11675250796335084, 0.05776161660573312, 0.09861295989581517, 0.12436192535928317, 0.1764201090804168, 0.1672780303550618, 0.12316815155957427, 0.17413219756313733, 0.18033559540552752, 0.15556811727583408, 0.12635707615741662, 0.058659576278712065, 0.1910307322229658, 0.1431178410670587, 0.18781086642827305, 0.08572158842746701, 0.15530306792684964, 0.18396703340113163, 0.1160632385207074, 0.08075186902923243, 0.1100509093542184, 0.14764128119817801, 0.15268624334463052, 0.16013027461511747, 0.07982703258416482, 0.12524715571531228, 0.12553371462438787, 0.12358758119600159, 0.08789534999855927, 0.0922154603259904, 0.13409631087311677, 0.08874393267823116, 0.18413927273026534, 0.10563331390065805, 0.08371481432446412, 0.13160994143358298, 0.1006641441157886, 0.1184903039996113, 0.08603368060929434, 0.12883264331945352, 0.09844042201127325, 0.12290449999272823, 0.10315045927252088, 0.06879940003688846, 0.16196651251188346, 0.0660642118060163, 0.07796002312430314, 0.12489308257188116, 0.11597972443061215, 0.11119919416627713, 0.17326135214950356, 0.14305445232561656, 0.12284147766019617, 0.12067351756351334], [0.04553666491327541, 0.014693053272951926, 0.06340140290558338, 0.0687346677961094, 0.017650794204590575, 0.032223885878920555, 0.018843463688556637, 0.05240715767389961, 0.10238463072372334, 0.04020678930516754, 0.018023778118991425, 0.018394468585029244, 0.1183124871126243, 0.04348594888246485, 0.028963233344256878, 0.03846925789756434, 0.10358978355569498, 0.054464234970510006, 0.04960274190774985, 0.025629614546362842, 0.054079247771629264, 0.028587922054742063, 0.02315728908537754, 0.038635593972035816, 0.014200367299573762, 0.04461263592487999, 0.023238390983481492, 0.027390879412580813, 0.034761175978928804, 0.0598933497177703, 0.09796464004154716, 0.0494723444405411, 0.0641363106135811, 0.018974227564675466, 0.027833974654121057, 0.06951895928276436, 0.03415659109928778, 0.060377681228731356, 0.008374731106284474, 0.016086580996800746, 0.029646911658346653, 0.024945815792307258, 0.08897571345525128, 0.03633615753746458, 0.019519886766959513, 0.027566513113145317, 0.06746063008904457, 0.03761087717222316, 0.05425264061029468, 0.014651711830603225, 0.02115044543253524, 0.043070671880351644, 0.011269854281895926, 0.03811026876792312, 0.007551286452715951, 0.057102901594979424, 0.046630975657275746, 0.06573780253529549, 0.020626148208975792, 0.010889663477428257, 0.04449083210368242, 0.033223055835281096, 0.0674961106851697, 0.0291654910626156, 0.06003751126783235, 0.07638799319309847, 0.019062679693368927, 0.03706208144181541, 0.02336467313580215, 0.02465675987436303, 0.02735357016458043, 0.018218093584956865, 0.032391151546367576, 0.06722919536488396, 0.027941583522728512, 0.03254223754629493, 0.0332234052808157, 0.03483090563012021, 0.037835116032510996, 0.03580720556367721, 0.04784951259249023, 0.0046814437955617905, 0.04493605285616858, 0.043639721881066046, 0.05666635591270668, 0.010743647830427756, 0.03926911158487201, 0.03187143104150891, 0.033619730799858055, 0.05587275153292077, 0.017390918685123324, 0.0065347417590341395, 0.04532620709921632, 0.03818469727411866, 0.05998728610575199, 0.023981843143701553, 0.18658528290688992, 0.013200160880972232, 0.0030826719511034234, 0.027428032597526908, 0.06490192203117268, 0.02251923716227923, 0.036935276817530394, 0.03971929242834449, 0.015859007136896253, 0.03489800935078945, 0.055428646970540285, 0.028617095667868853, 0.046749671788087914, 0.10380085544394595, 0.0309672797364848, 0.04611886492265122, 0.006641372689045966, 0.007835717306339314, 0.025155228662437627, 0.02958473070923771, 0.04094203967334969, 0.07085766137710639, 0.005335280139531408, 0.05301099955769522, 0.028771218112004653, 0.03865993980850492, 0.030298464731978517, 0.04555935512429901, 0.04515003565964954, 0.051572020165622234, 0.013708421777534698, 0.011742322456224688, 0.022827532940677235, 0.02335075129355703, 0.032303562853485346, 0.025319181382656097, 0.013063229121533888, 0.033263432061565776, 0.0741030875859516, 0.062412655247109275, 0.025576001798201884, 0.08207988419703074, 0.016658860824203918, 0.021696501577805196, 0.015694153661440526, 0.02527555327729455, 0.04252351141933884, 0.04044155224359461, 0.020114955192963992, 0.11927063284175736, 0.053941861393728426, 0.07055961487016507, 0.0484830912734781, 0.045729487602199824, 0.024506681498938372, 0.031015465900834118, 0.04239085103784289, 0.046508571332586665, 0.030959771746503453, 0.03706087704215731, 0.01750837140051382, 0.05289540772459336, 0.02162639533967844, 0.007657372858375311, 0.023853462621835724, 0.04416971879878214, 0.05692050459661654, 0.017439198148037707, 0.004387088519121919, 0.027171500559364046, 0.03600625381139772, 0.03860196238383651, 0.05921007852469172, 0.058266792712467055, 0.04609162852700267, 0.026293530528034483, 0.06905317213386297, 0.08720842828708035, 0.01775705278851092, 0.022032454443563308, 0.00823838119062462, 0.06734363029577903, 0.020574387861415744, 0.05483947501384786, 0.03351716005376407, 0.04249490099027753, 0.08202837660376515, 0.050199954504413266, 0.07963036599435977, 0.030761181509920528, 0.033095341974071095, 0.026254289151568497, 0.026251834551138536, 0.01221883385109582, 0.03324251961229103, 0.07781459271375622, 0.041169983334839344, 0.03372881548213107, 0.042372900393924544, 0.04274702085448163, 0.023642996326088905, 0.05995028559118509, 0.005642090350322957, 0.06345396901347808, 0.0218742421296026, 0.03596298363325851, 0.02209328850066023, 0.07716812526008912, 0.06147443809147392, 0.09790150235806193, 0.07624827604740858, 0.028627908123391013, 0.02574732680139797, 0.018707498841519867, 0.028514158512864794, 0.03200681234842964, 0.05816768588764327, 0.054094552128974877, 0.015357133799365588, 0.027632906068382517, 0.01769138077673103, 0.04200549743005207, 0.052674062816160064, 0.021525780470775704, 0.042930707069379945, 0.0134241953325857, 0.02643083208905799, 0.04058506918538894, 0.012100412526966205, 0.0060158049621220145, 0.018450505399544324, 0.012263660418934055, 0.1176438315638474, 0.013590306642332246, 0.011559644713997841, 0.033635598341269154, 0.05974722041615418, 0.05256945985768523, 0.012053182248824408, 0.06097718048840761, 0.020387130855981792, 0.05300173755469067, 0.0216970766362335, 0.029984208023441688, 0.06346642691642046, 0.07631140694554363, 0.023083732496680956, 0.06662586238235235, 0.04481306838403855, 0.056836468034556935, 0.03326744898887617, 0.012161510364551629, 0.07521434474204268, 0.010556307704454022, 0.03167014702090195, 0.05416657183585422, 0.01601786575546222, 0.007088001401695822, 0.03446888005627053, 0.05013702716678381, 0.03519765380769968, 0.04086700387831245, 0.023374759558854357, 0.021012333022164445, 0.11018595817898001, 0.0201046329789928, 0.045497252206717215, 0.022604920868096606, 0.04642035499481218, 0.013447021250613034, 0.040224651739533455, 0.0318956343856241, 0.052823523724717755, 0.04980713701141732, 0.03766207942473037, 0.015991959288450222, 0.0443333509112043, 0.027736701570185165, 0.02845262556469866, 0.052890403528830836, 0.03835144725495151, 0.010652743645810654, 0.0218291857080268, 0.024691740050911903, 0.04337133753246494, 0.03093267445053373, 0.04321150860882231, 0.12411352725965635, 0.048932695362184725, 0.036094463363822014, 0.04853984394243785, 0.06654018376554761, 0.03681873842807753, 0.029676265083253384, 0.024149987513997724, 0.015670559302504574, 0.025749584626672522, 0.04601905581408313, 0.030535375233739614, 0.02672781838503267, 0.06367454717734031, 0.005007546453271061, 0.02637658321431705, 0.01838129822031728, 0.05432314379140735, 0.05490727423291121, 0.017916785020913397, 0.056039783105786355, 0.014789016784301825, 0.028969238379171917, 0.0781381114252976, 0.014122418044800205, 0.0252999771452908, 0.025719550970409597, 0.0694305325991341, 0.050037235021591187, 0.024052468461117575, 0.04383163872574057, 0.0429653666381325, 0.051640246861747334, 0.03987335380432861, 0.03737608709239534, 0.014773157724578465, 0.09908423639301743, 0.031453226160790236, 0.042744360997208526, 0.05953270835535867, 0.04572781840605395, 0.06616203619965486, 0.026965799275785685, 0.024603586477626647, 0.03082571697554418, 0.03951421878965838, 0.03500030529020088, 0.034825209328638654, 0.04369945331875767, 0.05655345107827868, 0.03236005089378782, 0.03586477926000953, 0.04687562145824943, 0.040778970744993, 0.05492012568616441, 0.03299489504258547, 0.013770366935724658, 0.022456148672582846, 0.008769764864285077, 0.009505546186119318, 0.02781972541872944, 0.06585223068084035, 0.039426022807934454, 0.04981283670557397, 0.032924656490130086, 0.035753835391785414, 0.07497607717024428, 0.026508392034364597, 0.07371717079409532, 0.14743317450795854, 0.13210736188505376, 0.09034538388784442, 0.1330572430576597, 0.061644953941660266, 0.13426780381372996, 0.14851895267409937, 0.1267700054283653, 0.17502031847834587, 0.21510181629231998, 0.10723820528281586, 0.15670015795954637, 0.23478033606495174, 0.10172389367861406, 0.14089573387588772, 0.20864067013774598, 0.25701503295983585, 0.15839450061321259, 0.22064550167747907, 0.12618073847677025, 0.0946076355342354, 0.13993851095438004, 0.12210735705282007, 0.12129596487752028, 0.09868107802633728, 0.08706614627901997, 0.1299035751393863, 0.10336336999067239, 0.1687291996287448, 0.21196840942970344, 0.16629773724292005, 0.08201557943331343, 0.12889331792082104, 0.10306583917034523, 0.0735615962850196, 0.13087393449885504, 0.14563800155052117, 0.1518080018992935, 0.1107945701639567, 0.12928465620747634, 0.13300549797713757, 0.10129864899707691, 0.2054543646850756, 0.08136594322110925, 0.11825467592903546, 0.06482458939509732, 0.08545280713588, 0.1164899149111339, 0.10889834977154221, 0.05558415362611413, 0.08487080729433469, 0.11291155192468848, 0.20946559230131762, 0.14464580693415233, 0.12054078254316535, 0.13423831468181951, 0.17498366401663848, 0.13313897938600608, 0.1365238106144326, 0.1642080529459885, 0.1093352177579488, 0.11633599602750369, 0.23180756558265003, 0.10074081857289587, 0.1887824742921761, 0.221074267955763, 0.10089042197380747, 0.16359178030065127, 0.0838014225342444, 0.2018380851617881, 0.13574147330863134, 0.0806590590093817, 0.19382118034575666, 0.10410481877624989, 0.11356207701776709, 0.09929100636925016, 0.07331928464451007, 0.11618209071457386, 0.09959012496152095, 0.22867968199508532, 0.2245856188237667, 0.1253236537533147, 0.11026491929910012, 0.14917656167277268, 0.28632657868521555, 0.10414158180356026, 0.19644683945391858, 0.12330020804490362, 0.0837166802957654, 0.11769626875008855, 0.23826013505458832, 0.1110176317659872, 0.12260366470686027, 0.12987046263047627, 0.09825581298874957, 0.13436872911240372, 0.2448648592191083, 0.10502370446920395, 0.12191257679036685, 0.08863911937390055, 0.1723234403346266, 0.12043489036815506, 0.09355334139295987, 0.1124527808278799, 0.14382463028388365, 0.14909482534442628, 0.12989341068480695, 0.19901399527277264, 0.23452129853623255, 0.1489540428987571, 0.11633738023894173, 0.1680649681282895, 0.10907613273177828, 0.11086409286196743, 0.08654549957386085, 0.0878391130162137, 0.08909029087850026, 0.1302890780248812, 0.2102556513356311, 0.10240759913410459, 0.10049650525408131, 0.14818944249834332, 0.16015312767454556, 0.0801898588293365, 0.18144584154444082, 0.14090809678392752, 0.10952943483633654, 0.08732437635106699, 0.11288234099213566, 0.11241160053759813, 0.1378282941877842, 0.09046469070017338, 0.0813753070043666, 0.18555884941348008, 0.1405942743378026, 0.1192382802920682, 0.09212929994932242, 0.14625507486718042, 0.12710292184991495, 0.10194684671504156, 0.0933448818645307, 0.09690825601241418, 0.09080472495406866, 0.13772796599992684, 0.20103714242577553, 0.1577689591795206, 0.1508165808128459, 0.161998878632273, 0.21510292908975057, 0.19819716124662332, 0.08960890876395361, 0.17142890047814163, 0.12532958414937767, 0.09253578313759395, 0.08004970063588449, 0.10926480617906366, 0.15612820722162724, 0.11757371175502028, 0.17133204638957977, 0.12756082442189964, 0.14754503779113293, 0.23968150307025227, 0.1493662122104849, 0.12343738068427358, 0.15953890420496464, 0.08147066153053727, 0.17870351512517246, 0.07449852422411953, 0.11805343601320471, 0.10547458420374564, 0.11376818881503173, 0.12174170810197081, 0.13251332938671112, 0.17723082272069796, 0.12168498257441179, 0.15178434816854341], [0.007516076422429511, 0.05256217239158494, 0.028605177200266292, 0.033397843063409836, 0.01822091798697199, 0.028052846302411387, 0.0009345247589018461, 0.01701502555183002, 0.05967475287616253, 0.04432611772790551, 0.005408821885274457, 0.0127689569656338, 0.023711411315681677, 0.01809864767294909, 0.03698906768113375, 0.02679483389614948, 0.03689286498618977, 0.05993166659027338, 0.07572707294353417, 0.07974353206476995, 0.06895067263394594, 0.004849083505437842, 0.034171233884990215, 0.03775045182555914, 0.08789989618318421, 0.031085290546928133, 0.0365704488940537, 0.06415144872984715, 0.03133107967940824, 0.02037218612219606, 0.026919660590855137, 0.04266927431204489, 0.018763757876253555, 0.01796218579901116, 0.046566226453121216, 0.02654630348219403, 0.030891911459288428, 0.05269217291580779, 0.03483252054346459, 0.01554661470332316, 0.025983816611447504, 0.014499233137550098, 0.066080028457301, 0.03055359050631523, 0.015379778209275432, 0.020939153020403216, 0.14831578571881565, 0.02428083959966898, 0.044500494442347965, 0.02895284497312137, 0.010685832405995046, 0.016761879403410212, 0.016362878760056834, 0.02905948014397706, 0.027999342119853412, 0.05600101500749588, 0.05624110783849444, 0.06928025744855404, 0.032757126194025786, 0.026077247490840297, 0.016993454923587184, 0.07275567310197012, 0.02444831730930933, 0.010039353077965123, 0.06294065727187054, 0.05113073152356914, 0.06556462682783604, 0.03714182287720697, 0.042440251779875586, 0.016988233596618687, 0.021868145492460047, 0.037936492556972165, 0.04354379738547972, 0.026588203019595573, 0.025665405572259, 0.024973152271871055, 0.052358713666243215, 0.03227001947483846, 0.07985079488051788, 0.021897559985518456, 0.08502383729709045, 0.0399681960365602, 0.05947878517742668, 0.006279118109627494, 0.0420745621169252, 0.09075809602758714, 0.014736277649977376, 0.09322822812412467, 0.05107916286215186, 0.04900695084195052, 0.03088663245684334, 0.061195485559957366, 0.05347870696069939, 0.052630385517009666, 0.028134857437440326, 0.009875236661173403, 0.06499726977199316, 0.03504627603771431, 0.017032760760879943, 0.049718113216970644, 0.005429356051276305, 0.05449010751077107, 0.06100390798279217, 0.02534186141565442, 0.024255403018157397, 0.06061322108975478, 0.029083374754658768, 0.022000751591154506, 0.04735650261864066, 0.024552504665085247, 0.01690417667850852, 0.028193596517667174, 0.04015291023201176, 0.05632242686780436, 0.014496887102723122, 0.019821705928604518, 0.07632389198988676, 0.12507246008941106, 0.04618800085570131, 0.00849658072859581, 0.045135040035737414, 0.049072741597358666, 0.07742024173161813, 0.020708949837301458, 0.05957045525844608, 0.08871276077947446, 0.03007103336442794, 0.052149952189730744, 0.031497185051973374, 0.031242697100554193, 0.07929067100797381, 0.037075679283589125, 0.08271774104131119, 0.02078204502218536, 0.011407825048081577, 0.05773297564259597, 0.007827517210638948, 0.042936841025948524, 0.01661266616013433, 0.032997069747320244, 0.04743090398343546, 0.02664286919337298, 0.03798016646344747, 0.045952108156468184, 0.022144168449033583, 0.048061975477529426, 0.01769094990699419, 0.03283037744196398, 0.012921187993405121, 0.0778989481872746, 0.044611991316612275, 0.015095180266403725, 0.01870194503239223, 0.01743201755120286, 0.03982535084443433, 0.013232931577866631, 0.023130649800545404, 0.03086447828848447, 0.04645456673045244, 0.021195544262549708, 0.05700824595987797, 0.04369290545582771, 0.038664587773382664, 0.046791259199380875, 0.05282364246834602, 0.03189629256459219, 0.02393114470344569, 0.02133711041616542, 0.014559875508504254, 0.0549029621428677, 0.053720119542309215, 0.01944174837054951, 0.030094154445188384, 0.028950307252151624, 0.040323782313082895, 0.05918862324740205, 0.03640763441632901, 0.020899458721812283, 0.024243666058672324, 0.043059842461454015, 0.03100341172622783, 0.036788370593317916, 0.04767653366018619, 0.027645901710327183, 0.03961329847308142, 0.05939133558422327, 0.02504019153171352, 0.01761190396999674, 0.04308295336418918, 0.00514974322036973, 0.07459712893302951, 0.03495052117588265, 0.04678114902760301, 0.027804005458684902, 0.029242050168769698, 0.05387752948861037, 0.05697777295219047, 0.025505481653713753, 0.09538030371602092, 0.07502140330949, 0.006443973281420767, 0.002421770361252129, 0.04520537019042032, 0.020856224166761552, 0.04859176544206483, 0.025071960541286638, 0.011345740790212793, 0.02058851665684155, 0.020074129437229464, 0.03127154162419694, 0.012591071376976157, 0.007133793185598084, 0.03553818678483367, 0.07363185858620064, 0.060858226514288356, 0.03047030372545123, 0.023663464334926436, 0.041433010649468215, 0.027450414075117027, 0.06843682484967367, 0.04299390921369195, 0.017184795013495853, 0.042742379674954076, 0.021655948932415674, 0.029442072114241973, 0.019305047313017503, 0.07685158867388964, 0.00896251545886376, 0.017912106521959816, 0.03342445181416614, 0.004905864588051502, 0.017281857751575962, 0.03555643937683531, 0.043165581966085095, 0.04356587352231145, 0.012612332423616732, 0.024095843812184672, 0.06947866787335702, 0.031245380706552948, 0.01730817642861179, 0.05353478787999068, 0.034368914884648154, 0.021516649085762243, 0.0044016893204700735, 0.051574269509209056, 0.04938410435404096, 0.026819546141528657, 0.06489509596888508, 0.0487280288445098, 0.006237852154299617, 0.025967967729749422, 0.04944381882835712, 0.04907421741102423, 0.04732610085713012, 0.061687884852290154, 0.03174045342685921, 0.05540171930832522, 0.04867101493956787, 0.07321740939681019, 0.05443108853484903, 0.033903941977769136, 0.04094011263389673, 0.011078253804173852, 0.09377272533518927, 0.04399283150477069, 0.01678361796907016, 0.028975128063133786, 0.017126128875783513, 0.052858763440911255, 0.06875959717269454, 0.009865686280785926, 0.020223922827946286, 0.017826093726658394, 0.05829029716551304, 0.034402417551193915, 0.05772842945797103, 0.10179072259260075, 0.03738436861229794, 0.05779103109879153, 0.053009025020790954, 0.06526130131844964, 0.04243339179083705, 0.05139005742967129, 0.07376475645495312, 0.08546327693121773, 0.06074628859226193, 0.0446192075365356, 0.03490312550483005, 0.01640030675168548, 0.020943677152640054, 0.038021027842270474, 0.02363637212796935, 0.0466344633272716, 0.08039058305855308, 0.05606640881991812, 0.02231341543873506, 0.05502779223024845, 0.07320947732244219, 0.025190578640571663, 0.018770193780905435, 0.04377578850835562, 0.1019012423764382, 0.04742111272311636, 0.03332903961251889, 0.009253845317289233, 0.05925112310796976, 0.03548961724819882, 0.03871139311896903, 0.08588139020970889, 0.04875369443159018, 0.03566254868305155, 0.04288687709985035, 0.02915813574301345, 0.030234584052647864, 0.020651591575837562, 0.02783990165750895, 0.032439639658800194, 0.0674350153920906, 0.012762173311784863, 0.058479669503867626, 0.0322934933938086, 0.019610542438126037, 0.006965681893884071, 0.02312614263168403, 0.07859477227819817, 0.04741628494645868, 0.01891418400087527, 0.024554424919188023, 0.028058478143066168, 0.07354559642927987, 0.05488224646874836, 0.044634030134017975, 0.01229635308430131, 0.034960563494158645, 0.010578316835952657, 0.02929099289966481, 0.09706260237310614, 0.09720804635435343, 0.02783284319697746, 0.02087652593451951, 0.031944353199963055, 0.005366912169847637, 0.037229414962764294, 0.03111771434279425, 0.03578079019540122, 0.017183880687558224, 0.03279061868254628, 0.03190330522400992, 0.03242000285536051, 0.025529226986691356, 0.05105854218293514, 0.014974501116999557, 0.1341444325766393, 0.10143873255167689, 0.08725079601364476, 0.10787257445710045, 0.1354951108140605, 0.09360947659505264, 0.2032660621085337, 0.08882743998297624, 0.15023004157202585, 0.209520730056933, 0.1326118798128196, 0.1909652128815651, 0.0685110701514142, 0.08707008178212813, 0.14374498384339468, 0.15763802906232222, 0.08240889904222318, 0.24043049716523715, 0.11194440203585795, 0.12515016591974668, 0.2321674876979419, 0.09781281783112458, 0.23000838926860265, 0.16540821854557308, 0.12422085792890616, 0.07749775757214852, 0.10724934004247189, 0.1938912865838834, 0.15491407737135887, 0.09691524492310626, 0.08283873740583658, 0.12577679300946848, 0.14174245058425836, 0.1754463163337537, 0.09407677009169545, 0.11030702918235745, 0.08146448686186757, 0.16632619500160217, 0.0791720427306635, 0.15405913681856223, 0.11032963118382863, 0.09464065983359303, 0.10503260006329843, 0.09012458859277622, 0.10545972428683724, 0.15031730117542402, 0.25768062153032845, 0.07011959169592176, 0.0885462211444974, 0.10120764388037579, 0.14514651149511337, 0.07912637053855828, 0.10489984468689986, 0.08076402159141642, 0.12446781753429345, 0.13894253011260713, 0.13474090557013238, 0.15406927413174085, 0.08481094693498951, 0.08082943915256433, 0.10099811905196734, 0.21681901200541429, 0.11005654798022338, 0.08038069001798119, 0.19407009413199766, 0.09910947111036096, 0.16833934054843017, 0.15714275278151035, 0.1982821138309581, 0.06468354910612106, 0.09355158398726157, 0.20012539492121764, 0.14306730377886975, 0.12176496828241007, 0.09636944492480584, 0.1091062936133572, 0.13131161672728403, 0.1230879080082689, 0.2379600325865405, 0.0986174585829888, 0.20718662387558393, 0.14378345677895205, 0.17160753160715103, 0.11841441664312567, 0.11093088784920317, 0.17046852915414742, 0.10970132132726056, 0.1748814359307289, 0.1733602825552225, 0.12249195070138999, 0.11897537511374269, 0.12029383650847844, 0.22421429732016154, 0.17407746692853315, 0.15578248005892548, 0.06560048061822142, 0.08323663034077201, 0.1295856543417488, 0.0731149370382939, 0.16175668234271662, 0.14757952094078064, 0.11432206338005406, 0.18427861668169498, 0.15017681728516305, 0.12605248178754533, 0.29131660663655823, 0.11044351650135857, 0.17641386655824526, 0.19043754333896296, 0.1396561318210193, 0.08897531990494047, 0.1358274436954941, 0.12806764936872891, 0.16431674068527563, 0.1007873389337744, 0.12132776102849416, 0.19938792235084943, 0.2787705212831497, 0.1960948019155434, 0.09855608509055205, 0.16092167714876787, 0.18595641665160656, 0.19396247847804002, 0.1056718004069158, 0.18737611547112465, 0.21752322278916836, 0.05279461813292333, 0.09370455970721585, 0.08067875009562288, 0.1473431329109839, 0.11413637548685074, 0.15432386047073773, 0.1452329432857888, 0.17683686528887066, 0.12659915031066962, 0.11238374667508261, 0.11706246275986944, 0.08824627473950386, 0.09182947568063225, 0.09335491061210632, 0.1745093816093036, 0.18347603189093725, 0.14144636504352093, 0.15995825241718972, 0.08982752596161195, 0.15553505904972553, 0.09800320118665695, 0.08358616408492837, 0.13660253424729618, 0.17344128606574877, 0.14723934419453144, 0.11378896555730275, 0.049313061737588475, 0.13867628654198988, 0.18091551214456558, 0.1950531420963151, 0.15726034290024213, 0.12244479251759392, 0.09029927064797708, 0.07525912805327348, 0.22014415929360048, 0.2327940740755626, 0.14672121485429152, 0.22872272825666837, 0.10096457906599555, 0.08933115723942008, 0.11801511235535145, 0.18875321586217197, 0.09240844925599438, 0.27522596291133333, 0.1041763499379158, 0.08802568300494126, 0.11999548466077872, 0.11859699684594359, 0.16168250489447797, 0.22918961463229998], [0.028236593585461378, 0.04182838621948447, 0.10176186449825764, 0.03207215866340058, 0.028172697639092803, 0.0572674259809511, 0.050963292829692364, 0.025026873585634997, 0.051743472394134314, 0.04868198006546923, 0.01685033831745386, 0.01214719666833324, 0.04154526409027832, 0.0066648177702778155, 0.04490252644089716, 0.03801641380414367, 0.012144133082724043, 0.045632022832121165, 0.02336141616771264, 0.03891122168196099, 0.020824504350977283, 0.03034141260598387, 0.07428869405495268, 0.02242316847800144, 0.017173176797639047, 0.02510756327371512, 0.03224084586171167, 0.04146987206435629, 0.08220058879149811, 0.0439928247194205, 0.010828885399470372, 0.035601911401110034, 0.03717411435874445, 0.01565360780140119, 0.04514777613803744, 0.04519763828388282, 0.017875647139070288, 0.060172777223799906, 0.054117523932031224, 0.03442388300650886, 0.029168975339936357, 0.04790464017008032, 0.05325340958578246, 0.024029830836557915, 0.021721342744837915, 0.006174123297179384, 0.028358171793765256, 0.039276361731546264, 0.06764807538794619, 0.04399686539545655, 0.031663198822310994, 0.06624571992350475, 0.03732003331450479, 0.009973927883298268, 0.03457132527338607, 0.0266825193871877, 0.029514919633844068, 0.03933122468047908, 0.029568724068147794, 0.0446223220122712, 0.03398355109883206, 0.005685421172529459, 0.05493568788681712, 0.014124552037433853, 0.027642766878541027, 0.017109930548550825, 0.10540769422160727, 0.020524079578795602, 0.03529755112582019, 0.006808982288930565, 0.031150222955537692, 0.020615848047392707, 0.040299972519278526, 0.05220317308391843, 0.09651925867157322, 0.06673327447580439, 0.005412647550526474, 0.036337572282978466, 0.054956858179398944, 0.05624729607786451, 0.22290791384875774, 0.16405691605593475, 0.030547789031905786, 0.022846937345873033, 0.035577745376420875, 0.007583759442370917, 0.04109746490472129, 0.025950073064970117, 0.025282185957101837, 0.030600436564002718, 0.010140292795508035, 0.02695975692144462, 0.06233420981360333, 0.04747795020895345, 0.009136499471164175, 0.05878685587751014, 0.06317095884255, 0.004834995422113154, 0.040534151917589564, 0.02429133144739483, 0.01421752745019538, 0.024180696312604204, 0.024962580696280514, 0.02768937884164708, 0.061418771078544, 0.03865921716871006, 0.03393484585519348, 0.03596791997551918, 0.021155293565243483, 0.04047853240211095, 0.04599624007408108, 0.04763959760644606, 0.05025071231648326, 0.02594080936562802, 0.08333897377763476, 0.03636981287438955, 0.07807280921510287, 0.053524233267775605, 0.03008525206574372, 0.014331255008333495, 0.037837786067809374, 0.0423699114471674, 0.05652439960145524, 0.010829557997307606, 0.02468120240207229, 0.04466710871617709, 0.03241052372114999, 0.02013577434367367, 0.015353730946247066, 0.04319955960714391, 0.024475407819928865, 0.07231386538062777, 0.034808079712092876, 0.03620926809630223, 0.01994508734372045, 0.039330820952142985, 0.043923312199435065, 0.02475804988560932, 0.006766361808071711, 0.03590769659993904, 0.053227045107632875, 0.02195997502920883, 0.05037874848182712, 0.019959735218435526, 0.039406589565000365, 0.015191681516755904, 0.02619624726607331, 0.0033578859667094158, 0.039731333032250404, 0.00425850401266611, 0.06425073197377579, 0.0783438975257533, 0.03279250500989812, 0.03908936765843204, 0.020726875036156604, 0.01780141201535506, 0.07492299537573542, 0.04658184293657541, 0.011618811271286436, 0.059241867890315394, 0.0369290478660592, 0.04419784407530512, 0.0513285516229059, 0.03881028959793704, 0.02262560770447765, 0.005305373284500092, 0.02764261420816183, 0.020033137440415363, 0.01731217130353408, 0.12920720822044782, 0.07670713535376958, 0.029041454861206666, 0.05711386672088078, 0.0340602900167661, 0.007149956737911063, 0.03509814664721489, 0.04226928809657693, 0.02432258816302887, 0.04911787774679916, 0.01794812485708722, 0.00632102061561974, 0.04982273992417114, 0.023275618807279637, 0.0295621965612684, 0.00930734271449702, 0.0061022969727803555, 0.05376529301117573, 0.007863035974358874, 0.03007838868403009, 0.04456584754266909, 0.03241139903132405, 0.026141699835924164, 0.017676695582589934, 0.031321580189147165, 0.036979429091193845, 0.010515116387978196, 0.032607614395341704, 0.022816391395671026, 0.02211544775803174, 0.08424259243266922, 0.05263495884303536, 0.030212212753083025, 0.019372659934950725, 0.013476373827350991, 0.044925606809556484, 0.04385778946535928, 0.042562425402658324, 0.006516074836586735, 0.016169547169868435, 0.027147972357592413, 0.037847831778760464, 0.022302207736564533, 0.06617613615734236, 0.04876574182084628, 0.04927436149279986, 0.027151963839839612, 0.04135296726599336, 0.006701018037607095, 0.03294576232188514, 0.04303276891420994, 0.030136752873659134, 0.023191736611936773, 0.04150701167860201, 0.019442742424351827, 0.07023852531399045, 0.04155502142384648, 0.05371264887175389, 0.03815120478559818, 0.018648902253646935, 0.013124213304503687, 0.04871751833707094, 0.07068638556769916, 0.07540887394653899, 0.08190235908010177, 0.054077826240765195, 0.015441426508394735, 0.0077713328147573126, 0.015988965252680436, 0.03418162904147591, 0.022130171967936412, 0.01203823581870113, 0.0316010959047292, 0.052201045876634974, 0.024797594906496148, 0.051810654146330695, 0.03760039719886013, 0.015288094557555658, 0.026799295263897096, 0.06159054221851485, 0.042900508868374994, 0.050207771227828095, 0.020113884803972075, 0.02179899429237204, 0.03563468464251075, 0.059907375036605766, 0.049053338888500414, 0.1813461376088006, 0.07231799087354115, 0.012412062812862652, 0.047406836346324, 0.08869591954031161, 0.03133251478097268, 0.03555234781067286, 0.02153607045433351, 0.04468838418168681, 0.041106808331928084, 0.03964601743168064, 0.046789427154830525, 0.0590244381289397, 0.04252303983750088, 0.03132787699412022, 0.018144903405170356, 0.03549454001975911, 0.04509092168882489, 0.03690205913569246, 0.02320587558538786, 0.006346357537300459, 0.03335530909576586, 0.030042192233460288, 0.026107299806816236, 0.0682423295719283, 0.019199182279407978, 0.034826518901224644, 0.013102410278016967, 0.028421200911647508, 0.05140799450288926, 0.020021865277418067, 0.030466028954833746, 0.025343174380915504, 0.03459517917196665, 0.0721086628202881, 0.01980899696770523, 0.025067600953791822, 0.05201341398060322, 0.04095952891345535, 0.07746944909117051, 0.015697922923469117, 0.01309464274839099, 0.06113515022609915, 0.03323050954246095, 0.03441743013848152, 0.027503879241911427, 0.04322186305320688, 0.0521637298432844, 0.048558137246540616, 0.020769383558737378, 0.04183326488626855, 0.023230966114039932, 0.07347460809562888, 0.010056166327558458, 0.04821896812479411, 0.06523863824882678, 0.05810974578240088, 0.028982788723494326, 0.007184091290192944, 0.031013406547052518, 0.024717191899461404, 0.05721792006599052, 0.024796578800305724, 0.03485909876014505, 0.035088538591350825, 0.025843604135193994, 0.02238205773755908, 0.010725060211760657, 0.04249439208901354, 0.052499896447573385, 0.056226434518716166, 0.054545051883906126, 0.044739949450428994, 0.022879235612760698, 0.021151035758001462, 0.012934567855804094, 0.03934880213013717, 0.037638517296207805, 0.01119613993380751, 0.026540043996647, 0.014573737978935242, 0.043731690517493656, 0.03527001956743853, 0.05725933784352882, 0.04920903214120439, 0.009569470970226186, 0.05658192919301135, 0.07099888487053768, 0.03399373251678688, 0.05908039691192763, 0.09654401841440372, 0.03562701041144984, 0.02296364028006792, 0.05612189941374319, 0.038807141195450506, 0.04294889859322991, 0.10363904519804887, 0.1225841228983232, 0.22309680442724908, 0.16267984280628817, 0.10278219117649964, 0.1371922761734043, 0.19236688981098787, 0.11135916558227368, 0.12057076022028923, 0.16953833906778268, 0.06839129514992237, 0.0977507047355175, 0.1274872169430767, 0.10982862806745938, 0.10756361032170908, 0.08436981774866581, 0.12040133002613272, 0.13070426003209182, 0.09240369272551366, 0.1681014597415924, 0.11440413897590977, 0.07443866386477437, 0.19197925632553442, 0.13601594072367462, 0.17125875103686536, 0.10357683710753918, 0.0689454682703529, 0.14130559616855212, 0.2835915668734482, 0.1111912349505084, 0.16992221346923284, 0.12059026131672518, 0.1494183779827186, 0.07045376340725593, 0.08930534576731068, 0.12708973112915242, 0.15904299010123524, 0.11013534625193902, 0.13337458031518118, 0.08613318776977913, 0.12206657709819929, 0.13043057971767016, 0.16330482784126485, 0.18490200037402765, 0.11997028387018613, 0.16635086653488024, 0.11804659638021674, 0.14453284442424774, 0.20572759716638497, 0.1921111499624593, 0.0852682048987065, 0.10879732269261565, 0.0889166673379285, 0.13168360319520744, 0.12824248070163385, 0.1657618981386934, 0.1802620150681053, 0.2003471537360123, 0.09565483219921589, 0.16646315050976618, 0.07939282445503132, 0.10672348218836955, 0.13665608423096792, 0.1041008425610406, 0.11198453738221101, 0.08708410031561341, 0.16359993629157543, 0.10938837419130973, 0.15971917738871916, 0.13901027504886898, 0.11067474087966339, 0.08032399163182292, 0.13844650744327477, 0.2372564731964043, 0.12285191352878298, 0.14797676248209818, 0.10196294835103409, 0.1306861024349928, 0.1735593918710947, 0.27671705718551365, 0.46956441764320644, 0.3498877223048891, 0.20231034553476743, 0.1891000151102032, 0.1203880850225687, 0.1368633359670639, 0.15795414495681012, 0.1220916286110878, 0.125897029414773, 0.14134774676391057, 0.16206080173807486, 0.16661919999335492, 0.26601414435676163, 0.15537529119423457, 0.1120319262679134, 0.09361518307455949, 0.11301860439458064, 0.1407797315290996, 0.09507219453475305, 0.15291499107011727, 0.06999414414167404, 0.07288946663694722, 0.09129398262926511, 0.11122191151870148, 0.164624687018139, 0.1301928481885365, 0.18546903851841176, 0.15340029288615498, 0.11423279531300068, 0.17223456581788404, 0.0974840269024883, 0.08201252602572952, 0.11365519916372639, 0.1098904222516077, 0.14135785693568842, 0.10873361503971474, 0.22534000048679964, 0.1569817771336862, 0.14169806082333836, 0.1351873001882008, 0.1313204648239272, 0.07185731309333018, 0.13219783774444036, 0.1503243443689176, 0.1310910249927214, 0.1720526912914855, 0.07797719006027494, 0.08690170331725053, 0.09324829240462609, 0.16138302667864732, 0.1104447039376412, 0.10229783252413784, 0.1949799553092037, 0.10055878798344306, 0.08239094500562974, 0.13442480324634484, 0.08589167680059161, 0.060853714256414344, 0.046277509802686315, 0.1146055960229465, 0.14301699719258718, 0.06816855924470083, 0.1204165020691497, 0.16957575348871096, 0.05200809765873211, 0.08309791742690972, 0.1607444980846984, 0.08241856816623892, 0.1261427133743252, 0.15951666182705335, 0.13278996811381408, 0.2573656184332711, 0.14492571620004518, 0.10454482837979283, 0.1192976792476007, 0.0757196769118309, 0.1325443655784641, 0.15845035761594772, 0.08337588608264923, 0.1750801516962903, 0.1334080049501998, 0.11974467097648553, 0.15048586284475668, 0.1183335759810039, 0.12319069249289376, 0.06283379479178361, 0.12937517277896404, 0.08806594048759767, 0.10470809069062982, 0.32900089451244896, 0.16471704920487745, 0.14253428738032067, 0.18120219318994454, 0.10316874579127346, 0.1284475475549698, 0.11914665092314992], [0.006859287178875613, 0.026917379016854932, 0.04121567588299513, 0.03155444322952202, 0.026809408828350048, 0.03259190970233508, 0.025269205582195094, 0.010211399024618524, 0.0536827763675579, 0.023635664755212407, 0.043983172558780224, 0.03187460658539619, 0.07910138009382145, 0.03823346358590892, 0.022872765781357884, 0.01231259381997266, 0.05130791058763862, 0.010209779870430273, 0.043554603055651696, 0.007325589590306793, 0.04104252392426133, 0.03722280263900757, 0.044450472840773206, 0.037150718471301455, 0.02394613523834518, 0.05528737258698259, 0.04597636239070978, 0.03169677612770881, 0.01821249397471547, 0.06071193436426776, 0.06394711469433137, 0.045871325169823, 0.02608780379939292, 0.013751819180989904, 0.021509505808353424, 0.027927018768553222, 0.049807330393897634, 0.04437762871384621, 0.01665146479250065, 0.0185771047669862, 0.04539273067244461, 0.03219027464677181, 0.06509570484714848, 0.037005525548011065, 0.02364865700448198, 0.022264097817242146, 0.02119774610868522, 0.02864702245486634, 0.05318416169445429, 0.10590843270931925, 0.009321772609837353, 0.07267827939774309, 0.02404021581501833, 0.012855869668003703, 0.040480120174054585, 0.05751798182193722, 0.06033779015498502, 0.07456552955721106, 0.06978525035083294, 0.003107132714441312, 0.04771502695179411, 0.01794684412223952, 0.10467421143714871, 0.06182494214070695, 0.0633886871593339, 0.0409406758179622, 0.01030141772103629, 0.019462039960282188, 0.07361226928021226, 0.020492997585928867, 0.047351006484989605, 0.05169885532398309, 0.061639267818203995, 0.09865439802940403, 0.6087795017021043, 1.544519407408578, 4.071478920323508, 3.564332510743822, 5.278938174247742, 4.086021934236799, 7.942449331283569, 7.721626026289804, 9.376931854656764, 9.307475055967059, 5.095772368567331, 3.253669649362564, 2.0581009345395223, 2.6160590861524855, 3.14783490555627, 5.1837352599416455, 3.5717651290552954, 3.7199899639402116, 4.58837582383837, 2.6772325464657376, 1.99327033332416, 2.12318970475878, 0.6723055786320141, 0.5448507549507278, 0.2047280336597136, 0.15857661941221782, 0.09620530730379478, 0.04091532914234059, 0.05117861573983516, 0.0014113650312148301, 0.024640887243939296, 0.03316223195620945, 0.00397054774553648, 0.09841771144419909, 0.00948191705226366, 0.03282038940648947, 0.08101235862289156, 0.04006030037999153, 0.12295423660959516, 0.06939457702849593, 0.010394813825509377, 0.02832502026909164, 0.008888514429729964, 0.03936154841046248, 0.022297237467552935, 0.02603989583440125, 0.02900175377726555, 0.006281419191509485, 0.014635264141751187, 0.030333911401352713, 0.04655530882467117, 0.01664965649667595, 0.02306943237116294, 0.024236346362158656, 0.06157364669655051, 0.017196535365656018, 0.04734349510233317, 0.028266964812896082, 0.013171045791490801, 0.05822954113994326, 0.04022168314882687, 0.06974522357008286, 0.03016960753926209, 0.02220990152896515, 0.025318480795249343, 0.07809131286506142, 0.03136501660836594, 0.022747945872002413, 0.025947589626801864, 0.04808478782485638, 0.01658482926099428, 0.022575835464522243, 0.005028269336824971, 0.02378782962581941, 0.03388128908617156, 0.03609675681218505, 0.06741789595357009, 0.050747036933898926, 0.09558512629675013, 0.05456668358030064, 0.04161614725100143, 0.01594005135952362, 0.020860314036586454, 0.011364869540557265, 0.05750228052160569, 0.06827781016805343, 0.027774943803836192, 0.01686301504793976, 0.0608738192490169, 0.04192575938733561, 0.03871512845424669, 0.042024621939552684, 0.0368702087019171, 0.020727400900796056, 0.01865905144118837, 0.06600915547460318, 0.013189636802832996, 0.03747368078412754, 0.05261619734976973, 0.023514673479699662, 0.03522721757846219, 0.03045771350818021, 0.07345360065145151, 0.056649012557630024, 0.06596338150224515, 0.009523585887758859, 0.015444598659606916, 0.004126314364839345, 0.054035885991262536, 0.045568311786545176, 0.0374908680761499, 0.06225619185715914, 0.023275223560631275, 0.034777640631156306, 0.06735564715095929, 0.06467957289091178, 0.02942848445049354, 0.016458631925550953, 0.007297644125563758, 0.02263186210101204, 0.07723437063395977, 0.01944376701222999, 0.033992463656302006, 0.0475389708631805, 0.02168833540885576, 0.03119842947593757, 0.02180795943630593, 0.07354362867772579, 0.06716643087565899, 0.033608976019812484, 0.03990702271195395, 0.02368623427381473, 0.0372645562913801, 0.005470779765996018, 0.02819590862574322, 0.009365763731433876, 0.02159443125128746, 0.02437874032849712, 0.05242964093174253, 0.016566215349095206, 0.024633017934060523, 0.039815199960555346, 0.03345834803102272, 0.028999792811061655, 0.035884287141795666, 0.015570117460031594, 0.02052579796873033, 0.049777247543845854, 0.005345888610463589, 0.010823086469567247, 0.01914145252002137, 0.02878942320655499, 0.05915939874414887, 0.06395915869091238, 0.006535167963842728, 0.04379647025572402, 0.04946765237088714, 0.05550737399607897, 0.0906211133780224, 0.04599877100970064, 0.03350978437811136, 0.0347331626606839, 0.08077034553779022, 0.023495966269235526, 0.027976141311228275, 0.0254885640793613, 0.0356137280884598, 0.01631796991984759, 0.02379941052225019, 0.0346700589039496, 0.04051674749436123, 0.056472515421254296, 0.07231906295887061, 0.06229078357240983, 0.06966276120926652, 0.10291614077453103, 0.6874052626746041, 1.597176113298961, 3.493321052619389, 3.1095366520541052, 4.478074473994119, 3.5336449231420244, 8.635899526732308, 8.608374238014221, 9.353019629205976, 9.197002172470093, 5.0552231158529, 2.9896728438990454, 2.2281153202056885, 2.8472462807382857, 3.5794561335018704, 5.649030498095921, 3.9614789485931396, 4.463290444442204, 4.600113502570561, 3.2556155792304446, 2.323618744100843, 2.5450769407408576, 1.1955409220286777, 0.6806602446096284, 0.3608694044607026, 0.19892449650381291, 0.0186435486123498, 0.05144371258627091, 0.054952088078217845, 0.04507752401488168, 0.0878567277852978, 0.04324982887400048, 0.014647550714601363, 0.09145852058593716, 0.03903462006045239, 0.05061279217313443, 0.031639253321502886, 0.049476822771664174, 0.04729369741731456, 0.02721320671428527, 0.0473554780307625, 0.03226574470422097, 0.08758483880332538, 0.014481742201106889, 0.07066463852035147, 0.008530887459138674, 0.04887039566944752, 0.03463993194912161, 0.06038109425987516, 0.08282382320612669, 0.06117278177823339, 0.04319445363112858, 0.0645861386188439, 0.03701565268316439, 0.04078658730057733, 0.006927689870021173, 0.025009252031200697, 0.029923689485128437, 0.008556153558726822, 0.02348577806593052, 0.012709699654286461, 0.048801727925560305, 0.012695304533865834, 0.040816486946174076, 0.031678615137934685, 0.04172215138428977, 0.040019632383648834, 0.01492852867314858, 0.04260577361232468, 0.039053093176335096, 0.036672870362443585, 0.015830822488559142, 0.011328321948115314, 0.09649700950831175, 0.03271201040063586, 0.062190611447606764, 0.05616811104118824, 0.030495212745985815, 0.03277806578470128, 0.03033043730205723, 0.04391200441334929, 0.039307828793036084, 0.03574434607954962, 0.031108638936919824, 0.05381302455706256, 0.048058419954031706, 0.031252098203237565, 0.015283412665926983, 0.050389364162193875, 0.02453119696916214, 0.02914934532184686, 0.013937034644186497, 0.011418551838557636, 0.04091757170057722, 0.021709548109876256, 0.04442187937508736, 0.02579011521967394, 0.020402246919859732, 0.02921707329473325, 0.02436028078331479, 0.019772961669202362, 0.08287383802235126, 0.1502416038087436, 0.07433857994952373, 0.17788221633860044, 0.11727806047669478, 0.15694059005805425, 0.08311320482087986, 0.14075847981231554, 0.15908235870301723, 0.1899331339768001, 0.1323055483933006, 0.0915133733568447, 0.08115704943026815, 0.29093179585678236, 0.16554794247661317, 0.09370307371552501, 0.08675874955952168, 0.10795278408165489, 0.08861572348645755, 0.17167097463139466, 0.09506914791251932, 0.10326226827289377, 0.09051120427570172, 0.1501744288418974, 0.16758525744080544, 0.09676363305853945, 0.1948080009647778, 0.12874391808041505, 0.10725674285952534, 0.10534099422927413, 0.10175967961549759, 0.10516483296773263, 0.11193311121314764, 0.08079923755888428, 0.07742332906595298, 0.0811381454446486, 0.1665917057543993, 0.09395531232335738, 0.0743453652997102, 0.12171259894967079, 0.10962944411273513, 0.12090453159596239, 0.13571414191808018, 0.17972305470279284, 0.1041676171922258, 0.11783429634358202, 0.09986542018928699, 0.0839767831244639, 0.07660055107304028, 0.10534789493041379, 0.17608899756201676, 0.14460263853626593, 0.12722486816346645, 0.11462600635630743, 0.16321378201246262, 0.14455025563282625, 0.2167660319911582, 0.1421042318855013, 0.22013364200081142, 0.13471759110689163, 0.14699398593178817, 0.2033975621951478, 0.09569933052573885, 0.26203423791698044, 0.14692747592926025, 0.14912881994886057, 0.08902860525995493, 0.10819654778710433, 0.1055881098977157, 0.18626676499843597, 0.25682129764131134, 0.3772389532199928, 0.23532253982765333, 0.19287094633494103, 0.2628311094428812, 1.6308680368321282, 3.3662361119474684, 6.489338687488011, 7.091460023607526, 8.076981220926557, 7.444817611149379, 12.848173703466143, 13.915911197662354, 15.099470819745745, 14.86300277709961, 9.177711367607117, 5.481584991727557, 3.4888763768332343, 4.570129420076098, 5.9906547495297024, 9.283025213650294, 7.6450768538883755, 7.722717761993408, 6.968541179384504, 5.202003376824515, 4.632738769054413, 4.144942658288138, 2.3735815031187872, 1.500312905226435, 0.8098466353757041, 0.5931115310106958, 0.3831368067434856, 0.27155090868473053, 0.30071939208677834, 0.17629113314407213, 0.14337055464940412, 0.09621366006987435, 0.10900673895542111, 0.22167869337967464, 0.20720753632485867, 0.2098817785403558, 0.2327849002821105, 0.22653903971825326, 0.25546235484736307, 0.14711633936635085, 0.18926878034004144, 0.11894043056028229, 0.13274350203573704, 0.11739033088088036, 0.15961431658693723, 0.11717710803662028, 0.06758319386946303, 0.14491811660783632, 0.13337661592023714, 0.1683188352201666, 0.2065558848636491, 0.14811377227306366, 0.14353797637990542, 0.11584499451730933, 0.10173131685171809, 0.12506738464747155, 0.13240810217601912, 0.18194285487490042, 0.1109129541686603, 0.12981617982898438, 0.13233209268323012, 0.2337757513991424, 0.09571214805224112, 0.1293301587658269, 0.08128485828638077, 0.1729709527322224, 0.13473460876515933, 0.0693387064550604, 0.10796860751828977, 0.12176548396902424, 0.14524678540016922, 0.10886219742574862, 0.1026192477771214, 0.1441363628421511, 0.1260531467518636, 0.1781092948679413, 0.175580516989742, 0.10355272197297641, 0.1484043345387493, 0.11806491682572023, 0.10003189197076218, 0.23287310983453477, 0.0833021564675229, 0.0756847323583705, 0.11977991408535413, 0.12319597149533884, 0.13501514228326933, 0.06255180242338351, 0.12027200125157833, 0.11605135058718068, 0.10028223746589252, 0.1011057279205748, 0.15085988491773605, 0.16160074142473085, 0.11976780902062144, 0.14029689958052977, 0.12932964307921274, 0.13198732904025487, 0.1714878651712622, 0.10768383315631322, 0.11406991976712431, 0.20266440510749817], [0.019931671010064225, 0.0455570548905858, 0.012105467612855136, 0.045495908707380295, 0.0033902497546348187, 0.03669543843716383, 0.0009969599466005871, 0.0436195117155356, 0.041425529800887616, 0.033767766784876585, 0.012122277469773377, 0.023167762273390378, 0.02679812309465238, 0.05151929120932307, 0.01612038561142981, 0.05440080890964184, 0.02231821946666709, 0.0508889728890998, 0.03237508722980108, 0.03033486135037882, 0.020962974688570415, 0.010309907890457128, 0.03850887755730322, 0.013335878062727196, 0.050978488621434996, 0.07753428311220237, 0.039150462951511145, 0.04896220824282084, 0.02954955884654607, 0.03248480973499162, 0.0628922845103911, 0.020392314863524268, 0.032037424455795965, 0.048107864800840616, 0.017965654809294, 0.027553451314036335, 0.007432034771357263, 0.04887942697054573, 0.027721812815538475, 0.012952540552110543, 0.010183328030897039, 0.02826402845260288, 0.04442155367827841, 0.055740298104605505, 0.05298684031835624, 0.014361061355365174, 0.047139388376048634, 0.04162033720474158, 0.012810574062833828, 0.043787360923098664, 0.006397184475125479, 0.03200384036504796, 0.028384448062362413, 0.0449546141816037, 0.06971204999302115, 0.046749091640646966, 0.015936224422018443, 0.0762099116774542, 0.008513740879217429, 0.010431825366270329, 0.04210602917841502, 0.046177687123417854, 0.003161594903628741, 0.022910232788750103, 0.036266536451876163, 0.03964286902919412, 0.03787331076871071, 0.03921049294461097, 0.06550168591950621, 0.734599055988448, 2.044262077127184, 3.428516072886331, 8.898645656449453, 19.108953135354177, 23.68654796055385, 30.08797890799386, 41.069815226963584, 43.30399806158883, 47.651128087724956, 46.74772678102766, 53.803747517721995, 59.050217628479004, 65.48603521074567, 60.973013469151084, 48.083455426352366, 35.99059520448957, 41.16343525477818, 37.796042919158936, 48.4043162890843, 48.11221054622105, 42.82970012937273, 41.501388686043875, 53.474149295261924, 49.57806852885655, 38.52820587158203, 34.90454312733242, 32.70952728816441, 27.89844867161342, 14.095170378684998, 15.008946214403425, 8.92919601712908, 1.651449578148978, 0.2561154583735125, 0.09447003541780369, 0.06966225909335272, 0.027264875459617803, 0.05887134027268205, 0.01629661811914827, 0.03433296949203525, 0.0606918293716652, 0.01923054247163236, 0.030152555954243456, 0.07998686829315764, 0.03672317016337599, 0.03896873431014163, 0.06428588687309197, 0.04698963909010802, 0.042120458225586584, 0.015463852090761065, 0.041677205224654505, 0.009215294350204723, 0.0750069437282426, 0.0033884503645822406, 0.05144305779997792, 0.0285931739157864, 0.012332133932172187, 0.014802180363663604, 0.0283562413616372, 0.046769953199795315, 0.01894952549732157, 0.04078089099909578, 0.032482085416891744, 0.013346364821440406, 0.01423133394148733, 0.05266304340745721, 0.009078874884705459, 0.07205115697745766, 0.018534850695037415, 0.01739986686568175, 0.044407148379832506, 0.06366357526608876, 0.059388350030141215, 0.013258269771800509, 0.0265814363291221, 0.015754132764413953, 0.017892764881253242, 0.00711051604178335, 0.10940583289733954, 0.05890030014727797, 0.034301305655390024, 0.05040535723258342, 0.061981670159314356, 0.03940720024651714, 0.015639628283679485, 0.024868398339354565, 0.010745461215265095, 0.07164176965930633, 0.07544846646487713, 0.028179900288315754, 0.048442558984139135, 0.09191989047186715, 0.046497358541403494, 0.12119540598775659, 0.039634163424904854, 0.026780477791492428, 0.03375893225893378, 0.012855401478840836, 0.07572061329015664, 0.040378689366791926, 0.056357123755982945, 0.012818000628612936, 0.1361701853041138, 0.019896690833515356, 0.033518116788140366, 0.018064166219638925, 0.0033763645956891453, 0.03221280540206602, 0.05063272074663213, 0.0958529712100114, 0.030981053997363363, 0.03955161624721118, 0.058680454801235876, 0.03065994747781328, 0.0018214182678743132, 0.09526940395257302, 0.008100699649990668, 0.034412670215325694, 0.037140425095068555, 0.04290199825274093, 0.04685779634330954, 0.0010134722023004933, 0.04435939647789512, 0.009454175148026218, 0.036118622603160996, 0.021461273842890347, 0.03888581733086279, 0.03340666062597718, 0.028599389296557223, 0.029021488968282938, 0.01825972679736359, 0.04049602164221661, 0.024279351911640594, 0.05657179866518293, 0.09337420814803668, 0.02418791931787772, 0.004700831237382123, 0.022612389842314378, 0.005120430507564119, 0.0285416154323944, 0.03614629665389657, 0.07226960454136133, 0.04096239233123405, 0.01585299531663103, 0.057495719087975364, 0.009909479779058268, 0.03889524218227182, 0.029209690833730356, 0.04409220974360194, 0.02937877836770245, 0.014641330244817903, 0.02663229761778244, 0.021134903587933098, 0.022552936603980403, 0.023084716372457997, 0.04699933196284941, 0.03232711819665773, 0.049064894339868, 0.0268392796362085, 0.030976629949041774, 0.027632777146728973, 0.05418301273935607, 0.08262860868126154, 0.03091315639072231, 0.03059982248981084, 0.018606195259573202, 0.0382902569669698, 0.08103461457150322, 0.02374560778428401, 0.04229983235044139, 0.038462041677641015, 0.06666386034339666, 0.05735422418053661, 0.028527542616107633, 0.10626506392977067, 0.1441987066396645, 1.0793695385966982, 2.611000580447061, 3.929320514202118, 10.042610100337438, 20.230208260672434, 26.99426395552499, 33.69523000717163, 44.2060409954616, 47.27158273969378, 50.17023222787039, 50.074604170663015, 59.45969581604004, 64.17685563223702, 71.45339134761265, 66.7356687273298, 54.31487437656948, 42.524743693215505, 47.45497349330357, 43.78005388804844, 58.34349550519671, 57.54882655824934, 51.880520888737266, 50.10663884026663, 61.31139074053083, 56.29114007949829, 44.55038676943098, 44.64393731525966, 39.612232548849924, 34.79415014811924, 20.104605674743652, 19.54015486580985, 12.402068087032863, 3.4645998052188327, 0.4307889368917261, 0.0776751401967236, 0.03378133748524955, 0.06445545277425221, 0.1033549290150404, 0.014982635055535605, 0.059689972416630814, 0.08588512893766165, 0.011899301532789, 0.07248203349964959, 0.019649429280044775, 0.0101076662873051, 0.037359120324254036, 0.027820076560601592, 0.07919615786522627, 0.03742659045383334, 0.011554945010824927, 0.010500380303710699, 0.032260984781065156, 0.01577363894986255, 0.03358952920617802, 0.01628629251250199, 0.05335179377081139, 0.031460686653320274, 0.018065287498757243, 0.011507456889376044, 0.014950292683871729, 0.02884292569277542, 0.0365142186970583, 0.023535093991085887, 0.04239210293495229, 0.1050865368119308, 0.032989965485674996, 0.06064872204193047, 0.049505073577165604, 0.019435098727366755, 0.04924324048416955, 0.020466329463358437, 0.011840026409897422, 0.05833371662135635, 0.09611737595072814, 0.040967623836227825, 0.02171158880394484, 0.029959122583802258, 0.0557383914212031, 0.03823243899803076, 0.04443137547267335, 0.005823796091135591, 0.01642940572596022, 0.031879573461732695, 0.02011920282218073, 0.09400099808616297, 0.03400861278974584, 0.02255198495861675, 0.019275100169969455, 0.011231077701917716, 0.019602210028097034, 0.04027386249176093, 0.03357247083580919, 0.04717029564614807, 0.05570377595722675, 0.021140035009011626, 0.02501278041329767, 0.06386424521250383, 0.0780512657282608, 0.034143074681716304, 0.0808587654360703, 0.054287408744650226, 0.08372523662235055, 0.008929927118255623, 0.036509848931538205, 0.0676989790850452, 0.05515027119378958, 0.06300633267632552, 0.09383829217404127, 0.17737208014088018, 0.14679289529366152, 0.10478534868785314, 0.15400249271520547, 0.21806276669459684, 0.10665965239916529, 0.14268509857356548, 0.13037150645894663, 0.12183267250657082, 0.1458175012043544, 0.17706711936209882, 0.14402965642511845, 0.12020786612161569, 0.12141977037702288, 0.17220477813056537, 0.05718348441379411, 0.13336592220834323, 0.17173614113458566, 0.09410030168614217, 0.1361618393233844, 0.1135912879503199, 0.09282567365361111, 0.06561673153191805, 0.17476551500814302, 0.17656378208526544, 0.17220663731651648, 0.12646743309284958, 0.13575112207659654, 0.08308001767311778, 0.3072065125618662, 0.11366640856223446, 0.07517175309892211, 0.09686936238514525, 0.1577453733022724, 0.10693337342568807, 0.08822659043861286, 0.14065541034298285, 0.06297512685081788, 0.11894131265580654, 0.10132023998137031, 0.13631731883755752, 0.12075023273272173, 0.0892442911863327, 0.1552809476852417, 0.0880309348659856, 0.11223789557282414, 0.13257229407983168, 0.1819112351430314, 0.12523578346839973, 0.10186377367270844, 0.11268743859337908, 0.11983161845377513, 0.1652426017182214, 0.089494053141347, 0.15376926665859564, 0.10268545243889093, 0.21008457908672945, 0.11097718429352556, 0.18543467750506742, 0.11747973465493747, 0.17391927327428544, 0.17694767005741596, 0.0745119456467884, 0.14288237584488733, 0.11700759641826153, 0.1776383372821978, 0.24636903564844811, 0.39507829025387764, 2.071075175489698, 4.967544232095991, 7.077627463000161, 15.642078229359218, 30.73136125292097, 40.54818616594587, 49.327909060886924, 57.66771718433925, 63.511614254542756, 64.58826541900635, 67.95681462969098, 78.24527631487165, 82.09416144234794, 87.1134011404855, 81.56450721195766, 69.46640110015869, 55.4889531816755, 59.04969651358468, 60.070803778512136, 77.18379306793213, 71.05733013153076, 68.71560655321393, 63.595555441720144, 71.50692026955741, 69.73368440355573, 60.560353006635395, 55.60972676958357, 54.900034291403635, 44.80212000438145, 29.078391756330216, 26.62251796041216, 18.309983253479004, 5.223841999258314, 0.7165614781635148, 0.20546463770525797, 0.16772055732352392, 0.15520572529307433, 0.1591536184506757, 0.1074166599927204, 0.09656958561390638, 0.20266933127173356, 0.12104163638183049, 0.14077618957630225, 0.18194603041878768, 0.19859695407961095, 0.11658302348639284, 0.2102989690112216, 0.1279801590634244, 0.12261924387088843, 0.0803948442584702, 0.13011696083205088, 0.08460424481225864, 0.21721642996583665, 0.11283134908548423, 0.0944002005936844, 0.09712250344455242, 0.1914980664317097, 0.18925184410597595, 0.11823414345937115, 0.09584977531007358, 0.10309628503663198, 0.11226477913026299, 0.13668657759470598, 0.08176699812923159, 0.16613258181938104, 0.13905340273465427, 0.1067905757310135, 0.132978261581489, 0.1308989452996424, 0.18180713430047035, 0.16938649650130952, 0.16173718124628067, 0.14931689628532954, 0.1438472933535065, 0.07646657433360815, 0.08786548088703837, 0.10725842562637158, 0.12042674794793129, 0.14906900030161652, 0.14984538006995404, 0.10637457269643034, 0.10880301560142211, 0.1580088348793132, 0.09492248935358864, 0.11580346817416803, 0.10018322563597135, 0.12444003831062998, 0.0890532700078828, 0.12168659748775618, 0.20664762279817037, 0.15298990133617604, 0.13552633699561867, 0.18349435233644076, 0.2525492954467024, 0.1905212067067623, 0.08862451730029923, 0.10482596579406943, 0.16741902993193694, 0.17628451064229012, 0.15837619373840944, 0.15293975759829792, 0.10725650537226881, 0.23007268724696978, 0.13420825558049337, 0.11876182657267366, 0.0996288014575839, 0.11517572828701564], [0.02503829841901149, 0.1095015402617199, 0.0247486979767148, 0.04411939524912408, 0.042066847173763175, 0.08556644818080322, 0.11770928305174623, 0.04835666323612843, 0.024953934463805387, 0.03992817604116031, 0.017692327333082045, 0.02224505982095642, 0.04373551066964865, 0.035638470867914815, 0.01842457857648177, 0.010031849328827645, 0.057755475863814354, 0.03526828591046589, 0.014495397718357188, 0.08535271643527917, 0.03665961857352938, 0.026619909264679466, 0.07006318507982151, 0.032060080740068636, 0.055811612135065455, 0.02032641214983804, 0.03602062857576779, 0.09198920960937228, 0.04098127596080303, 0.04876012694356697, 0.04627145387764488, 0.06676257361790963, 0.002437266192698319, 0.09156348316797189, 0.04570924011724336, 0.0387593010839607, 0.012383720405133707, 0.05455132494015353, 0.012278942723891564, 0.02599668163540108, 0.048395034391433, 0.06529071581150804, 0.021139056222247224, 0.025125211969550167, 0.05219266257647957, 0.04753035007576857, 0.028067456857700433, 0.06757288013717958, 0.03232023785156863, 0.02519420371390879, 0.027796066598966718, 0.022017704788595438, 0.04873815258698804, 0.029002951391573464, 0.04070374835282564, 0.03259215058226671, 0.052449369337409735, 0.019049248092674782, 0.04488960713414209, 0.012131570006853767, 0.032237147845860036, 0.010069349414802023, 0.06509987105216299, 0.02536223951860198, 0.04317400597834161, 0.6417409958583968, 2.187005868979863, 5.867311196667807, 11.574495077133179, 15.299212421689715, 37.52551480701992, 50.601541655404226, 59.05261475699288, 73.1600148337228, 70.50227328709194, 71.00691400255475, 79.32820865086147, 78.2400790623256, 77.64884294782365, 78.9611005783081, 84.16419655936105, 82.89927005767822, 84.2478528703962, 88.04106208256313, 82.64135987418038, 95.96006992885044, 86.10439068930489, 83.22630786895752, 79.24192592075893, 77.97019018445695, 77.09516184670585, 80.747531073434, 76.77134799957275, 78.09786333356584, 83.31687068939209, 88.29180172511509, 83.85267407553536, 74.47287000928605, 73.22281265258789, 74.88440486363002, 68.09835638318742, 47.85658632005964, 19.06880818094526, 5.03943680865424, 1.3692466467618942, 0.13544507564178535, 0.03294991156352418, 0.0569109338601785, 0.033061011494802575, 0.03561812160270555, 0.08360246249607631, 0.0430675302632153, 0.07749922999313899, 0.036761256333972724, 0.026966124972594634, 0.021730073794190372, 0.07616027005548988, 0.02224499705646719, 0.013953422961224402, 0.03830565631921802, 0.0053213998575561815, 0.03383375431544014, 0.039126575126179626, 0.005415739973873964, 0.02250562235713005, 0.06291323088641677, 0.036403631059718985, 0.04082171845116785, 0.07112016621977091, 0.027015802217647433, 0.047897213604301214, 0.027905912936798165, 0.07689268753996917, 0.017158598472763385, 0.045487077574112585, 0.09481391696525471, 0.05042455638093608, 0.046807292981871536, 0.016373321413993835, 0.06443268113902637, 0.02863106670390282, 0.016868640103244355, 0.06627524298216615, 0.04676156311428972, 0.02861930090667946, 0.0162549102678895, 0.020707921856748204, 0.027725865365937352, 0.03193042966138039, 0.06312428920396737, 0.006039189823370959, 0.013924068688148898, 0.022179637170795883, 0.0690436183608004, 0.013418428633095962, 0.012072892842947372, 0.00888589019554534, 0.04193343022572143, 0.019912164824615632, 0.05190012577388968, 0.06116148417017289, 0.0610332614076989, 0.014835996852655495, 0.09478983575744288, 0.03172642471534865, 0.05002465158967035, 0.034508903444345505, 0.023178701954228536, 0.09243893583438226, 0.04688602000741022, 0.00411597137073321, 0.040631097608378956, 0.057627985919160504, 0.05662922986916133, 0.020649104744994214, 0.057585312851837704, 0.023238453747970716, 0.073993945228202, 0.015117253010560359, 0.03367605599175606, 0.043962372067783556, 0.04282027888777001, 0.06245620362460613, 0.022404434126136557, 0.012838213338649698, 0.05602641596591898, 0.05358074166412864, 0.034251412975468805, 0.007997961814648338, 0.03255910931953362, 0.02106695848384074, 0.03354541764461568, 0.06738341958927256, 0.029764803725161722, 0.06974347294973475, 0.010472183781010764, 0.0531047866679728, 0.009909143056055265, 0.009658929027084793, 0.01781620747143669, 0.020169636633779322, 0.018233791492613297, 0.1794941984117031, 0.006017299435500587, 0.009776025511590498, 0.017792192420789173, 0.05521498307851808, 0.023323713369401436, 0.036402284167706966, 0.09804211516997643, 0.0038111641104998334, 0.05290792330301233, 0.01928699658518391, 0.03898470023913043, 0.02467376396193036, 0.03272984230092593, 0.03469952428713441, 0.021420521029670323, 0.013964720569284899, 0.050838927538799386, 0.036281148703502755, 0.03671960785452809, 0.017138462946084992, 0.07454277827803578, 0.030405317034040178, 0.06514728029391595, 0.045496729734752855, 0.030260728006916385, 0.029977602485035146, 0.0183226999361068, 0.04199277829112751, 0.036358952921416075, 0.0419136136105018, 0.04315389759306397, 0.08839650917798281, 0.059788977461201806, 0.05452773906290531, 0.03441299930480974, 0.016459417329835038, 0.013758649484121373, 0.051266452097999196, 1.010093393070357, 3.318436631134578, 8.477930494717189, 13.951018708092825, 18.766142913273402, 42.280253955296104, 55.97388185773577, 66.37714862823486, 82.42313085283551, 80.65357753208706, 81.17861815861293, 89.15920788901192, 88.9715439932687, 87.5052239554269, 88.81946182250977, 94.91592938559396, 93.03977680206299, 99.50502695356096, 102.21452563149589, 91.9281553540911, 110.10467066083635, 96.79741818564278, 95.85916124071393, 91.24843393053327, 89.43824754442487, 89.52065317971366, 93.43656757899693, 88.31475162506104, 90.44797366006034, 95.78923457009452, 97.87702233450753, 96.5821282523019, 85.75796740395683, 86.17622116633824, 87.39634568350655, 80.31117725372314, 58.671332359313965, 25.378997121538433, 7.501511437552316, 1.6306520998477936, 0.1164977994880506, 0.009501305342252766, 0.01702078292146325, 0.05046423710882664, 0.026514458137431314, 0.11550134367176465, 0.04295341424377901, 0.02700642486368971, 0.033747332702789984, 0.02865531754546932, 0.019302501110360026, 0.015806619144443954, 0.017884225518043553, 0.045585349800863435, 0.009983261980648552, 0.044663458197776756, 0.038487636018544436, 0.02213835170758622, 0.02847383656938161, 0.0401460129235472, 0.046949296790574274, 0.035311942853565724, 0.039940281105893, 0.017823591628777127, 0.018169812425704937, 0.0516086848053549, 0.0478202609478363, 0.0466650347225368, 0.012365752797839897, 0.03493950855252998, 0.02743925217406026, 0.041927065567246506, 0.04306241410917469, 0.021373318741098046, 0.020134001670937453, 0.040752894644226344, 0.056805547193757126, 0.06149151003254311, 0.07016865656312023, 0.04439862937267337, 0.05379469732620886, 0.06309669997010912, 0.014734827281375016, 0.012922619702294469, 0.037266262806952, 0.06404423341155052, 0.07993392220565251, 0.021508192843092338, 0.01912284200079739, 0.08183966244437865, 0.02340067790022918, 0.03845906290890915, 0.05154277869899358, 0.08268625701644591, 0.06583733005183083, 0.040831343470407386, 0.019553389433505278, 0.024628407288608805, 0.026155806578961865, 0.039244714858276505, 0.07531349906431777, 0.03868779706369553, 0.06549629156610795, 0.027764056709461978, 0.02594905865511724, 0.054315751152379174, 0.04554797948471137, 0.03401849565229245, 0.06177880175943885, 0.05489062637622867, 0.053745937799768786, 0.07575634494423866, 0.25576443863766535, 0.07864401356450149, 0.12081278009074074, 0.12543832617146627, 0.16622665391436645, 0.14880922995507717, 0.0850058968311974, 0.09324882166194064, 0.11580150042261396, 0.1293355327631746, 0.09177729633769818, 0.10553334533636059, 0.07760526466050319, 0.11453198854412351, 0.14111366575317724, 0.18416019875024045, 0.13120558884527, 0.07983676956168242, 0.15425425634852477, 0.17175400017627648, 0.15566457781408513, 0.14322770945727825, 0.11522648270641055, 0.11806927302053996, 0.06026333450738873, 0.24036136801753724, 0.1707800038691078, 0.15420010925403663, 0.09718256736440317, 0.12483641132712364, 0.17109428771904536, 0.10528377337115151, 0.19962224763418945, 0.14603536522814206, 0.14558237524969236, 0.08052116033754178, 0.19715653280062334, 0.12883560173213482, 0.12174695996301514, 0.14148049535495894, 0.1759782335055726, 0.08780095899211508, 0.12739385052451066, 0.12151796796492167, 0.18545259082955973, 0.10587912678186383, 0.11631280370056629, 0.12989478132554463, 0.13960114334310803, 0.11691504424171788, 0.09186481378440346, 0.07162192251001086, 0.1041786637423294, 0.2740178448813302, 0.21432633219020708, 0.15132994683725493, 0.09296024750385966, 0.205119629789676, 0.15640481880732945, 0.13508486854178564, 0.09377995173313788, 0.1208376551845244, 0.09427920422915902, 0.18554625580353395, 1.4712039700576236, 5.561245220048087, 12.905859385217939, 22.305171387536184, 29.805023942674907, 58.06164182935442, 73.04897567204067, 83.66555908748082, 99.13627215794155, 94.29615701947893, 93.60709026881626, 101.32942935398647, 101.70718901497978, 101.05867195129395, 103.87090669359479, 108.28519453321184, 103.64497212001255, 108.31227166312081, 111.40891701834542, 107.75231633867536, 121.3217590876988, 111.41955471038818, 111.9027602331979, 106.56986495426723, 103.91066428593227, 102.63609368460519, 105.3698902130127, 100.51978356497628, 102.60602188110352, 107.38358238765171, 112.3616053717477, 108.92718723842076, 99.54716777801514, 101.9013842173985, 102.42420836857387, 90.85308837890625, 72.30893693651471, 33.46020718983242, 10.447028262274605, 2.733230684484754, 0.37780742985861643, 0.139480377680489, 0.1371117476373911, 0.14018430347953523, 0.1069792356075985, 0.260779898081507, 0.1945659810943263, 0.13050346794937337, 0.18423444405198097, 0.11582800400044237, 0.09101944736071996, 0.10769296623766422, 0.06168547605297395, 0.1138207684936268, 0.13037054293922015, 0.15170456602105073, 0.10855286688144718, 0.07381834715072598, 0.11931510402687959, 0.08012201889817204, 0.1873394474387169, 0.17791006341576576, 0.14002634052719387, 0.15040951408445835, 0.10022788681089878, 0.16248758669410432, 0.12489804944821767, 0.16862594016960689, 0.12210502289235592, 0.14235286068703445, 0.15545455765511307, 0.12106013324643884, 0.12862232460507325, 0.06357679742255382, 0.09016176552644797, 0.11269379646650382, 0.1224131320736238, 0.10859984864613839, 0.18069000781646796, 0.09711909041340862, 0.09531146633837904, 0.16786256113222667, 0.11488169192203454, 0.08388881105929613, 0.13336905704012939, 0.0965361406228372, 0.1867311815065997, 0.08040380092071635, 0.11346378443496567, 0.14366681660924638, 0.06583928423268454, 0.1187421761985336, 0.1047400768314089, 0.2223059990044151, 0.12631286281560147, 0.1341682355850935, 0.18189469245927675, 0.08879767265170813, 0.12417794737432684, 0.13549171813896724, 0.09620593155601195, 0.09752214699983597, 0.14869150412934168, 0.23637277632951736, 0.1187282662306513, 0.10526184990469899, 0.09925548506102391, 0.16428977570363454, 0.1226341173584972, 0.14211184504841054, 0.2000016572752169], [0.018988916151491658, 0.020445601914876273, 0.09507710034293787, 0.03452898468822241, 0.028853565121867826, 0.027839028043672442, 0.03767208442358034, 0.04673232164766107, 0.030471677758863995, 0.04418677377647587, 0.016783575560631495, 0.045335289290440936, 0.02628142885597689, 0.01780554768629372, 0.029228767845779657, 0.06011941044458321, 0.02109471395877855, 0.043388629997415204, 0.051949560442673307, 0.017211793921887875, 0.057362977282277176, 0.021697850166154758, 0.019500287282945852, 0.01673444114359362, 0.0493132008372673, 0.0895603188712682, 0.13489023755703652, 0.0630180916881987, 0.007056413052071418, 0.018283327941649725, 0.028662523587367365, 0.04016980575397611, 0.04621790050129805, 0.046992217523178885, 0.0347326130473188, 0.008308623135755104, 0.03723278049645679, 0.01791844403903399, 0.04632655092115913, 0.0025759778343074557, 0.024501835062567676, 0.06822309310414962, 0.04720640727984054, 0.043215545892183266, 0.0336874316313437, 0.04463171632960439, 0.06517194504184382, 0.026097194724051014, 0.062084095020379336, 0.03992709377780557, 0.01403928647882172, 0.06321505004806177, 0.10773375976298537, 0.020042658983064548, 0.055822404234537056, 0.023583395506388376, 0.07372884838176624, 0.06846980165158, 0.07525180666042225, 0.042452536656388214, 0.10659238922276668, 0.0264542720812772, 0.6387625528233392, 4.992882575307574, 12.006392495972769, 30.065355573381694, 44.399391991751536, 65.91638578687395, 67.07825660705566, 62.427556310381206, 64.40751498086112, 75.93226269313267, 73.67723873683384, 74.43136841910226, 61.30390753064837, 57.62359612328665, 57.85393932887486, 59.142309052603586, 62.30285699026925, 65.65008912767682, 50.158878871372764, 45.874984400612966, 51.039208684648784, 42.89541271754673, 58.807412828717915, 50.75550331388201, 56.511988571711946, 58.88605948856899, 65.94383811950684, 71.99203654697963, 62.43779795510428, 52.5068210874285, 56.150939328329905, 56.77240358080183, 58.52868584224156, 55.16181462151663, 53.631859506879536, 63.88640703473772, 66.80681828090123, 67.66138417380196, 76.21219866616386, 82.04355076381138, 74.5191867010934, 51.04303714207241, 25.18343833514622, 5.723679772445133, 1.7921570049864906, 0.8856899685093335, 0.20363773645034858, 0.11116165082369532, 0.035787958917873244, 0.07084894898746695, 0.005113994178827852, 0.021916260410632406, 0.024311058156724488, 0.025178409115012203, 0.03506690350228122, 0.03740518606667008, 0.04775532175387655, 0.06446824315935373, 0.03990592009254864, 0.0034477625948576523, 0.08704222113426242, 0.03356214353282537, 0.04673898146886911, 0.033523372041859796, 0.05307043922532882, 0.007603679534180888, 0.018457022728398442, 0.049164730589836836, 0.006892730473607246, 0.05134194929684911, 0.04069274590749826, 0.05936294567904302, 0.029415819594370465, 0.014476412308535405, 0.042211324242608886, 0.014938535368336099, 0.05225006663905723, 0.018056846523125256, 0.03582964471674391, 0.006161818488700581, 0.013014327950908669, 0.030095240101218224, 0.027481226350313852, 0.03731802824352469, 0.011616928336609687, 0.015202897700614162, 0.059956745244562626, 0.04681212075852922, 0.03663190720336778, 0.05400927724050624, 0.010960807025964771, 0.08149791149688618, 0.02217487046228988, 0.06277959341449396, 0.016025492489071827, 0.03978831979579159, 0.03423014429530927, 0.061740362750632424, 0.015005192952230573, 0.03967137089265244, 0.017232784402689764, 0.02885273391646998, 0.011088967872118312, 0.045058901621294875, 0.022827437945774624, 0.03303133576576199, 0.0433414378868682, 0.051676500987793715, 0.03876408814851727, 0.04131743577974183, 0.04273908878011363, 0.020170783357960836, 0.032605405763856, 0.010595087677107325, 0.037803689683122296, 0.0452626114045935, 0.04467005016548293, 0.033002681231924465, 0.10199019153203283, 0.028481259742485623, 0.00751149800739118, 0.0390822091139853, 0.023158922658434937, 0.037032985860215764, 0.05928235607487815, 0.002684993390825444, 0.02570985470499311, 0.013187666506772595, 0.008868750400974281, 0.05633262864180973, 0.02669859048910439, 0.033393052606178183, 0.00921962594813002, 0.01987161726823875, 0.05161197230752025, 0.046400775866849084, 0.053265060032052655, 0.020571821302707707, 0.03800501102315528, 0.039970340207219124, 0.008343673710312163, 0.04038059605019433, 0.028832801950297186, 0.0412790951585131, 0.041815863855715306, 0.04163904441520572, 0.02943175838195852, 0.039923361835203, 0.01080427663068154, 0.03457414119371346, 0.027339366730302572, 0.04615814870755587, 0.03208586846345237, 0.006132606707978994, 0.06853587739169598, 0.06911326319511447, 0.052792426464813094, 0.018053684549938356, 0.06779186374374799, 0.01490808610937425, 0.018047172310096875, 0.01638494641520083, 0.0197531620173582, 0.02083217179668801, 0.00740154310395675, 0.011425455084203609, 0.008667841270965124, 0.015470517000981739, 0.016099926084280014, 0.014439674726288234, 0.07374315868530955, 0.08041143443967615, 0.04738538106903434, 0.02399928488635591, 0.10948770493268967, 0.07289631305528538, 1.500987097620964, 7.823978202683585, 17.39643931388855, 34.917918409620015, 52.26162263325283, 72.68164525713239, 77.41029739379883, 71.24215916224888, 78.04937880379813, 87.97197614397321, 83.88973576681954, 83.47853442600795, 72.9275211606707, 71.15265941619873, 69.67608383723667, 71.71234376089913, 75.65733637128557, 77.63077068328857, 69.07121535709926, 61.73218754359654, 64.7501723425729, 62.56908416748047, 71.72578157697404, 65.08710438864571, 69.8665270124163, 70.96586404527936, 75.14392702920097, 82.4631038393293, 72.73169313158307, 64.02596160343715, 69.25532872336251, 67.13446058545793, 67.37104674748012, 66.32713549477714, 61.360570090157644, 73.79216194152832, 75.28437096732003, 77.21504606519426, 84.78182888031006, 91.30520766122001, 86.84094142913818, 60.946200370788574, 33.41769463675362, 8.29587379523686, 2.792276910373143, 1.1435352840593882, 0.2032449868108545, 0.07734054100832768, 0.0865459745483739, 0.042803023742245774, 0.04828818887472153, 0.04810635506042412, 0.010496885000195886, 0.01832798572390207, 0.04615316826051899, 0.04271096011091556, 0.06143473022218261, 0.025055024307221174, 0.044289436124797375, 0.01912651287524828, 0.09365012762801987, 0.017902432308931435, 0.03434842312708497, 0.08540992372270141, 0.05395429215527006, 0.013998541299120655, 0.02455655043013394, 0.020070005640653626, 0.0055983337473922545, 0.04068797919899225, 0.04474459741530674, 0.0365893257382725, 0.019046713764380132, 0.034528804876442463, 0.05607931116329772, 0.010235303813325507, 0.04843662180272596, 0.019908804379935776, 0.04577256439785872, 0.04518044759918537, 0.0597864193841815, 0.07823161355086736, 0.03928032437605517, 0.034165208494024615, 0.08173891356480972, 0.10396050116313355, 0.0458875421567687, 0.04081142507493496, 0.005873706158516663, 0.032419921431158266, 0.012454551827561642, 0.04197261223037328, 0.11174962855875492, 0.0627600991034082, 0.03434597700834274, 0.0437076194877071, 0.06709212450576679, 0.014115265437534876, 0.09939643714044775, 0.06190800839768989, 0.024863828406003968, 0.027457940724811385, 0.030613715494317666, 0.04272753672142114, 0.08854672326041119, 0.08062541045780693, 0.041854268937770805, 0.04574858497029968, 0.05924435132848365, 0.07036815264395305, 0.02592372046118336, 0.020383203834561364, 0.0219459073019347, 0.043162341961371045, 0.1550482101738453, 0.12166759850723402, 0.16412627590554102, 0.12351748852857522, 0.17545454017817974, 0.04373940546065569, 0.08845870369779212, 0.10809340367891959, 0.11111877419586692, 0.12143624520727567, 0.15968411069895538, 0.09402947620089565, 0.0907787506335548, 0.14020961283573083, 0.08700329358024256, 0.19447257396365913, 0.14422768008496079, 0.13896705236818108, 0.16216282626347883, 0.06836043537727424, 0.16658173128962517, 0.14424286569867814, 0.15856397151947021, 0.0749041795996683, 0.159539026341268, 0.18096337600478105, 0.24782628459589823, 0.07089824455657176, 0.10933246290577309, 0.11081379306103502, 0.1583307861749615, 0.17119316384196281, 0.20291475738797868, 0.1244868707976171, 0.14696582672851427, 0.10741602895515305, 0.09822999473129, 0.15135512048644678, 0.09977100204144206, 0.06739589784826551, 0.1824461921517338, 0.22131844556757382, 0.10054230636784009, 0.11316151744020836, 0.19850448332726955, 0.07899235987237521, 0.14831699351114885, 0.0833518048748374, 0.12481247261166573, 0.2224864350365741, 0.08491776870297534, 0.10310894650007997, 0.15049374742167337, 0.18776784730809076, 0.10205366848302738, 0.097744428286595, 0.16131730377674103, 0.21941307852310793, 0.13696001363652094, 0.19510760131691182, 0.20113592355379037, 0.19267042566623005, 2.321336260863713, 11.09663098199027, 24.620536974498204, 47.62586096354893, 66.36012554168701, 90.74877507346017, 91.8021011352539, 89.34021541050502, 90.88450118473598, 98.81817667824882, 95.39529255458287, 95.36108657291958, 81.55650288718087, 79.92834540775844, 77.42301954541887, 80.17497866494315, 85.41855485098702, 86.05259881700788, 71.0455390385219, 68.7288567679269, 71.17795780726841, 64.65505150386265, 79.56186962127686, 70.21364511762346, 76.51707172393799, 77.72243131910051, 85.5828172138759, 88.80286952427456, 86.04533794948033, 73.8386037009103, 78.12355082375663, 77.80349595206124, 80.95931911468506, 76.37657220023019, 73.98302895682198, 86.08573477608817, 88.54639761788505, 87.40771293640137, 97.75964641571045, 101.57252597808838, 99.19923673357282, 74.53445884159633, 39.590991905757356, 13.333552275385175, 5.917671740055084, 1.8517496415546961, 0.4176912839923586, 0.24865295737981796, 0.2063421191913741, 0.13757186223353657, 0.14458791432636126, 0.15114048628934793, 0.12668708844908647, 0.12085137516260147, 0.11813772363322121, 0.14764323537903173, 0.11922917435211794, 0.19767775626054832, 0.08509241004607507, 0.153738352603146, 0.33158562438828604, 0.11811496556869575, 0.13235694063561304, 0.15995902594711098, 0.16007922164031438, 0.11144566522645098, 0.09190271675054516, 0.13305684950734886, 0.07743277427341257, 0.2601078769990376, 0.25413994437881876, 0.1264400202780962, 0.13715817300336702, 0.1557950193860701, 0.12829434791845934, 0.08629665364112173, 0.14503980507808073, 0.09213375792439495, 0.14270708310816968, 0.07737500380192484, 0.15124450570770673, 0.14070525552545274, 0.10977618409586803, 0.10445364005863667, 0.14257846001003469, 0.1745106843965394, 0.20124294209693158, 0.14289867425603525, 0.11504531385643141, 0.09001118503510952, 0.09754255733319692, 0.19053123545433792, 0.2498177577342306, 0.16786588595381804, 0.08640920903001513, 0.1150224336556026, 0.1062456239014864, 0.24196219497493335, 0.20213991110878332, 0.12244009705526487, 0.09449546012495245, 0.0981123164030058, 0.09718941378274135, 0.13875821286014148, 0.1598001266164439, 0.25600374436804224, 0.18198329556201184, 0.19397581847650663, 0.14025940373539925, 0.10340029586638723, 0.12214832699724607, 0.0914680879297001, 0.18318130342023714, 0.07243406785918133], [0.023966543875368576, 0.04735308280214667, 0.0458078142920775, 0.03729987403910075, 0.03770954294928482, 0.020313565785597478, 0.019734268209763935, 0.04386971132563693, 0.03741394256108573, 0.03309381187760404, 0.04916726831080658, 0.04486845041226063, 0.022597048165542737, 0.06336833110877446, 0.03754169713439686, 0.015938628132322004, 0.020156876782753637, 0.021345951727458408, 0.04915802327117749, 0.02094546509241419, 0.075457267064069, 0.04982234637386032, 0.033188131637871265, 0.017548294704673544, 0.02489322593568691, 0.035421312520546575, 0.05537496806521501, 0.06219153425523213, 0.027597569660948854, 0.039303306357136795, 0.023640361913879002, 0.039834395716232915, 0.010102950468925493, 0.05104508004816515, 0.050875015423766205, 0.028119649771334868, 0.04395608204816069, 0.030536990147083998, 0.027348688105121255, 0.06594706273504666, 0.060113792174628804, 0.021671383907752376, 0.04104248321216021, 0.04553420522383281, 0.017907316064728156, 0.0544775410422257, 0.03777629383174436, 0.04053859292928662, 0.04630371143243142, 0.043749278145177026, 0.04281659104994365, 0.03842518365542803, 0.06817422501210656, 0.034319565032741854, 0.02279840682500175, 0.01779507110560579, 0.004776142687270684, 0.05028853385842272, 0.08070108746843678, 0.41305960395506447, 4.327231253896441, 17.216972555433, 34.560958181108745, 58.287361008780344, 72.37897477831159, 76.80035672869, 80.91378062111991, 66.9735472542899, 61.01736382075718, 53.16379063470023, 55.933356489454, 58.49067224775042, 51.3656176839556, 53.39616618837629, 40.53781597954886, 30.27531623840332, 35.50732019969395, 24.285559109279088, 31.939114502498082, 30.900275434766495, 16.991876976830618, 23.774854353496007, 22.74461715562003, 20.51302252496992, 30.184065546308243, 30.100318908691406, 19.45465554509844, 33.148403303963796, 41.233063152858186, 30.118676049368723, 30.697297709328787, 32.53576326370239, 27.36279467173985, 37.04411581584385, 36.10473673684256, 35.82484245300293, 36.01784256526402, 38.11282171521868, 45.66070543016706, 51.733646392822266, 65.68455914088658, 63.53839956011091, 70.24453680855888, 68.99619565691266, 67.55318682534354, 49.49686145782471, 34.47880615506853, 23.424609558922903, 15.089918783732823, 7.640621321541922, 1.5761573782988956, 0.13274051648165497, 0.12348582808460508, 0.013834837092352765, 0.041357903608254025, 0.02631145911956472, 0.04297447257808276, 0.0316438673596297, 0.032455673441290855, 0.08090202204350914, 0.020171828301889554, 0.041469885635056665, 0.011751188364412104, 0.07064526634556906, 0.0052466312356825385, 0.048312768805772066, 0.02581901232978063, 0.0105042827282367, 0.040087207686156034, 0.02615894141074802, 0.01687492333751704, 0.021476210094988346, 0.03598032020298498, 0.0678000400907227, 0.05696333372699363, 0.022877429013273547, 0.03660011105239391, 0.020254260128630058, 0.047211764313812764, 0.01717131252267531, 0.03652323303478105, 0.09492526456181492, 0.06703994516283274, 0.013944430675889765, 0.01937965054198035, 0.049486386722752025, 0.008931748984780694, 0.03762967259223972, 0.038976964939917834, 0.026310364981847148, 0.06650981253811292, 0.04992105286302311, 0.019382205226325562, 0.044879775161721876, 0.030187873701964105, 0.03531720149996025, 0.06205347952033792, 0.02400164449188326, 0.032497613690793514, 0.06786566799772636, 0.035313897034419436, 0.07659996753292424, 0.03515067543568356, 0.04661354748532176, 0.09705315716564655, 0.054836625166769536, 0.07856368858899389, 0.053132403043231795, 0.06114173201578004, 0.053914326442671676, 0.04627607809379697, 0.00906515575479716, 0.04191804105149848, 0.053489526201571734, 0.029145884793251753, 0.0809940178213375, 0.06176400291068213, 0.05401775553556425, 0.0541397764879678, 0.023424577599923526, 0.021521381867517318, 0.019996695020901303, 0.04632322609956775, 0.045254733613026996, 0.022684591057311212, 0.04116176288308842, 0.07317911288035767, 0.049821046979299614, 0.006727878694489066, 0.020873482704960873, 0.024868910633293644, 0.06348036402570349, 0.017267167468422225, 0.05791848711669445, 0.08696302931223597, 0.04017837904393673, 0.04431835189461708, 0.043002523215753694, 0.05930860859474965, 0.03254530452457922, 0.06445254864437239, 0.05346575372719339, 0.0556055037304759, 0.0654740831149476, 0.051778399984219244, 0.03094178039048399, 0.013898566797641771, 0.031731778356645785, 0.022568203641899993, 0.05237458799300449, 0.05601287240694676, 0.028996437455394437, 0.021365157661161253, 0.03201641022626843, 0.033835392977510176, 0.020312352904251645, 0.018038604109148895, 0.05985225085169077, 0.017054889484175613, 0.027591121881934147, 0.04937781772709318, 0.05618925079969423, 0.017062845307269266, 0.022628978327182785, 0.023110105456518273, 0.05525150183322174, 0.0628046788541334, 0.008197267905675938, 0.07196623831987381, 0.0265891173455332, 0.05493894824758172, 0.03627809190324374, 0.009070711260262345, 0.09168850324515786, 0.046528923990471024, 0.7208108987127031, 6.824855038097926, 23.868894747325353, 43.64739193235125, 69.54161534990583, 80.45037746429443, 87.82308319636753, 90.28535802023751, 78.14358248029436, 72.72250066484723, 65.08552714756557, 63.9260812486921, 69.30320875985282, 63.155803952898296, 66.8351252419608, 52.26622928891863, 39.78099387032645, 44.190463134220664, 39.64348554611206, 47.13549879619053, 46.01539012363979, 26.469405719212123, 32.98911237716675, 35.2622572353908, 29.647549969809397, 44.2623735155378, 44.357372760772705, 35.91953250340053, 49.309756892068044, 54.76355430058071, 46.98644604001726, 46.445824078151155, 41.97639880861555, 36.025652340480256, 46.874232632773264, 50.08011061804635, 49.76303652354649, 56.98785332271031, 49.873592785426546, 57.71359266553606, 63.19514465332031, 79.92973504747663, 70.94260842459542, 79.71268027169364, 78.8249853679112, 78.82645143781389, 59.43493243626186, 41.32218769618443, 28.851958649499075, 18.44667169025966, 8.355428542409625, 2.1444824593407765, 0.17164067125746182, 0.1433740287486996, 0.0376492110081017, 0.04132084881088563, 0.07143223804554769, 0.07607214192726783, 0.0349093273149005, 0.02999743606363024, 0.05943959978009973, 0.006575741813451583, 0.06702400637524468, 0.03856657678261399, 0.008984624674277646, 0.02286458434537053, 0.017343874155942882, 0.028103822942024896, 0.08902015071362257, 0.0920090771147183, 0.033333674006696255, 0.021349106915295124, 0.02851755458063313, 0.03774968847366316, 0.06561610049435071, 0.08398117324603455, 0.059790707725499354, 0.03692878663007702, 0.04312886982890112, 0.029625011940619776, 0.018322262281019772, 0.0448638974422855, 0.03805969076763306, 0.030463589621441703, 0.021495388887290443, 0.05450102513922112, 0.032750781891601424, 0.026061347719015818, 0.01628168356338782, 0.05448201937334878, 0.044219730222331624, 0.034218337785984786, 0.025473068035872917, 0.031656539001102955, 0.018213527044281363, 0.05582525747429047, 0.010703152012346047, 0.05593269331646817, 0.05447589559480548, 0.03229462654728975, 0.09086168796888419, 0.03444634251562612, 0.04689729047406997, 0.05355370204363551, 0.022806489873411398, 0.06739940587431192, 0.06751058383711747, 0.07391761003860406, 0.004276814280144338, 0.04245544417894312, 0.03325735917314887, 0.002927443494887224, 0.06676836830696889, 0.03523504787257739, 0.06778720220816986, 0.03796796640381217, 0.03025056355233703, 0.15415114616709097, 0.15671378294272081, 0.1430035214871168, 0.12982577431414807, 0.13737934827804565, 0.10424754861742258, 0.1415419570569481, 0.1239134001412562, 0.09404347437833037, 0.1450189333409071, 0.1352305364395891, 0.1889285628816911, 0.14097514961447033, 0.1223108089928116, 0.0961518387443253, 0.1226009912788868, 0.09040141052433423, 0.16814052978796618, 0.11033121895577226, 0.10291055643132754, 0.19685858807393483, 0.09993718883820943, 0.11609914659389428, 0.08422931350235428, 0.23827218583651952, 0.14410941143121037, 0.20261138438114099, 0.11103231526379075, 0.11923613612140928, 0.15920358576944896, 0.11570396779903344, 0.08473147012825523, 0.12166546790727548, 0.13450873802815164, 0.20383860995726927, 0.21706812935216085, 0.17711985510374817, 0.09209877265883343, 0.07656564723168101, 0.16746865798320087, 0.12714499102107116, 0.10537110082805157, 0.2001874130219221, 0.14099127160651342, 0.1398146240306752, 0.12776107367660317, 0.10725204061184611, 0.10731059818395547, 0.12891418965799467, 0.10847320687025785, 0.1438251459704978, 0.08648565278521606, 0.2163693332778556, 0.13598193254853996, 0.17764992666031632, 0.08938184380531311, 0.08879285505307571, 0.2780094492648329, 0.12316462317747728, 1.143991585288729, 9.856634616851807, 29.094819034848893, 54.40752860477993, 84.73277459825788, 94.21990053994315, 98.78966127123151, 99.52116761888776, 87.58773381369454, 82.0654375893729, 75.01058415004185, 77.1925755909511, 80.6831282206944, 73.51605442592076, 74.92528111594063, 59.12384074074881, 47.868405205862864, 52.799910000392366, 40.06042609895979, 51.4151166507176, 48.97326953070504, 30.598073959350586, 39.56704146521432, 39.57989910670689, 32.02592529569353, 48.25714649472918, 48.471831934792654, 35.456028597695486, 49.00926467350551, 59.11975519997733, 49.03083883013044, 47.976588657924104, 48.94859300340925, 45.2551668712071, 54.74602746963501, 55.24676329748971, 53.18804332188198, 53.86121259416853, 57.596800395420615, 67.79620007106236, 73.97463553292411, 89.70308508191789, 85.51622567858014, 88.70402445111955, 89.40807151794434, 91.63051537105015, 73.79526778629848, 53.13492086955479, 38.09968614578247, 24.23263815471104, 13.784059575625829, 4.34164833171027, 0.7025650377784456, 0.3296595891671521, 0.11814935372344085, 0.13292788714170456, 0.12669934279152326, 0.21824172352041515, 0.09292204598230974, 0.1466926485300064, 0.12796175719371863, 0.051996138479028425, 0.12198880341436182, 0.09011512302926608, 0.12368662016732351, 0.18607529598687375, 0.15567497297057084, 0.16646111490471022, 0.17979081320975507, 0.19949530730290072, 0.09468051019523825, 0.10068701753126723, 0.16433499327727727, 0.10140155561800514, 0.1798960675618478, 0.1923375092446804, 0.12387169737901006, 0.1979355995676347, 0.10097462138427155, 0.1119241409802011, 0.058142742940357754, 0.08103963573064123, 0.18052900502724306, 0.08222320436366967, 0.09474174119532108, 0.14992133527994156, 0.11592360958456993, 0.12141207578991141, 0.16487524285912514, 0.180040853364127, 0.09666958810495478, 0.13309013843536377, 0.09870954257036958, 0.12556168383785657, 0.1197388084339244, 0.15776784638209002, 0.1149752347597054, 0.171808852947184, 0.1395026607705014, 0.06426484550216369, 0.19411186474774564, 0.1662738120981625, 0.16661282176417963, 0.1449115348181554, 0.12407303228974342, 0.23161024759922708, 0.16949970328382083, 0.2120652228061642, 0.09813069791666099, 0.11411173109497343, 0.15284269994923047, 0.09307283681950398, 0.0951335137443883, 0.19250024908355304, 0.124152665159532, 0.11641082486936025, 0.20912139862775803], [0.0755133954808116, 0.044158743494855504, 0.05455802547346268, 0.04889097224388804, 0.03219616093805858, 0.0270911484424557, 0.01882016788502889, 0.025292799941131046, 0.027721346322713152, 0.07070382391767842, 0.01712591513725264, 0.022476367319801023, 0.04299641979326095, 0.06180334437106337, 0.03252652267526303, 0.04221990771059479, 0.03273050047989402, 0.04681533022916742, 0.04362388826640589, 0.04263906254033957, 0.03912710438349417, 0.039064573988850625, 0.0178010897112212, 0.008507556032522448, 0.034501344564237764, 0.04387840335922582, 0.02813151225979839, 0.06433664807783705, 0.034354112643216334, 0.026844672293269208, 0.05187014809676579, 0.045234862715005875, 0.03230535079325948, 0.022470492902877073, 0.013312931704734052, 0.0230437243756439, 0.028923403338662217, 0.017833223433366845, 0.05191099251221333, 0.05908802364553724, 0.052503336620117934, 0.044321954915566106, 0.06410437197025333, 0.02672833067897175, 0.062430914624461105, 0.025411121181345413, 0.049098186660557985, 0.026784135095242943, 0.009853627017166997, 0.04784077984680023, 0.03568886566374983, 0.02802152682228812, 0.049058641639671156, 0.04593833728826471, 0.021810424214761173, 0.06935313210955688, 0.09963009745946952, 0.03464719566649624, 9.248636841773987, 23.404009887150355, 55.6742616380964, 68.69243431091309, 76.163971219744, 69.55564376286098, 63.432119914463584, 56.23673915863037, 54.46308292661394, 47.31426899773734, 51.865849767412456, 32.169006075177876, 32.25913463320051, 31.083499431610107, 28.4068865776062, 29.613854680742534, 18.04403747831072, 17.03667722429548, 21.91933270863124, 15.13706578527178, 15.348511627742223, 33.15130417687552, 92.85749776022774, 44.39285026277815, 18.415708780288696, 41.691036292484824, 23.13406194959368, 21.770076717649186, 23.430555479867117, 25.07071770940508, 19.696011645453318, 12.109892862183706, 15.814166000911168, 15.37775833266122, 24.860027483531407, 20.303459644317627, 13.966547063418798, 9.2853650195258, 13.232427324567523, 29.54282672064645, 27.47956609725952, 22.31971917833601, 25.845940385546, 42.3657237461635, 43.9059066091265, 59.36381762368338, 67.86957999638149, 69.57094369615827, 69.23806244986397, 62.491820199149, 54.475426401410786, 44.75532736097063, 22.936083453042166, 9.62829944065639, 3.1630019545555115, 1.4851258801562446, 0.8517183799828801, 0.10420871605830533, 0.009556463453918695, 0.02734655580882515, 0.012654718809894152, 0.0515175168402493, 0.02795523395096617, 0.06999373702066285, 0.029572333874447004, 0.08560492111636059, 0.05545808521232434, 0.04412725607731512, 0.054739587873752625, 0.07236597687005997, 0.06215490693492549, 0.006748819981502103, 0.05424281881589975, 0.08456630113401584, 0.029315094463527203, 0.024139775561967065, 0.047594675195536444, 0.027907748374023607, 0.05435288058859961, 0.031343201707516394, 0.04670095297374895, 0.027369285035612326, 0.031775221561214755, 0.04348264441692403, 0.02202323654533497, 0.04318915766530803, 0.046271409772868664, 0.0842096224161131, 0.04212140138926251, 0.047791494455720694, 0.01210866351279297, 0.03845702391117811, 0.010694325968090976, 0.05466840276494622, 0.01271989888378552, 0.02485110248172922, 0.038129121863416264, 0.007078507000447384, 0.041588100006005595, 0.029995967035314867, 0.0874153475410172, 0.008456224858361696, 0.09894163547349827, 0.016926247726327608, 0.08398348026509796, 0.014706260957089918, 0.08558662102690764, 0.04655310019318547, 0.05859360231884888, 0.05076312499919108, 0.04064505168103746, 0.003021231241291389, 0.052863251950059614, 0.027265906832846146, 0.04097482309277568, 0.039838117480810196, 0.022209063538217118, 0.07479139350886856, 0.05474864292357649, 0.04742812877520919, 0.034135071361171346, 0.034825304323541265, 0.036824546687837155, 0.04332832519763282, 0.008358803344890475, 0.0407812302666051, 0.019322221034339497, 0.02464317051427705, 0.0633653998374939, 0.059186404437891076, 0.023902922735682557, 0.02506406239366957, 0.011622119977671121, 0.03574227654774274, 0.062204833541597636, 0.02951092306258423, 0.028464432074023143, 0.02766065645430769, 0.07878429389425687, 0.017884987173601985, 0.043533578648098877, 0.03617398766800761, 0.029427293621535813, 0.02472198914204325, 0.01432488695718348, 0.0561476973151522, 0.015181781690833824, 0.01802982047333249, 0.10243990418634244, 0.030467874570084468, 0.02568086259998381, 0.014272521017119288, 0.015481985939134444, 0.031312114625637016, 0.05208107749266284, 0.009854121499561837, 0.05842940362968615, 0.020106191913198148, 0.06522422616503068, 0.03581089000882847, 0.005639623027361397, 0.02921153644898108, 0.016019148186647465, 0.016730461535709243, 0.009644197183661163, 0.013888881558419337, 0.03512893856636115, 0.038102614892912764, 0.031273556873202324, 0.01880686859866338, 0.05295833845489791, 0.012453136233878987, 0.049183889026088376, 0.11045218139354672, 0.099934990384749, 0.3722529964787619, 14.451946479933602, 32.81113427025931, 67.09435558319092, 79.01180853162492, 86.41095215933663, 81.2033190046038, 74.62987150464738, 68.62203516278947, 66.60259682791573, 57.41936772210257, 60.24206297738211, 44.51047631672451, 45.68214757101876, 41.52535302298409, 42.73907824925014, 40.995778696877615, 28.870065655027116, 28.16734916823251, 37.22127056121826, 23.404504946299962, 27.60225738797869, 36.72513444083077, 66.34590952736991, 49.225857394082205, 27.917900153568812, 32.18819005148751, 36.14902802876064, 31.58298110961914, 26.241747992379324, 34.020867756434846, 31.58892181941441, 23.831433534622192, 24.516876799719675, 24.247823442731583, 38.07303285598755, 33.058010714394705, 23.271328823907034, 19.96577545574733, 15.47195679800851, 36.222581659044536, 39.16297939845494, 34.74954271316528, 38.55394894736153, 57.65222964968, 55.37033353533064, 70.76632567814418, 75.86026545933315, 80.71709101540702, 80.10279382978166, 74.43644060407365, 62.425659452165874, 52.010778767721995, 27.081550700323923, 11.75036701134273, 4.037956467696598, 1.773369510258947, 0.9720213902848107, 0.04906824291018503, 0.035275373208735666, 0.03548687257404838, 0.007508986579653407, 0.02849008409040315, 0.034218412424836836, 0.010498829003024315, 0.04001310148409434, 0.04194731305220297, 0.06545238356505122, 0.04125777558822717, 0.051720897534063885, 0.031134314702025483, 0.02401109648469303, 0.04351413183446441, 0.024227345595136285, 0.029819245982382978, 0.04661257378757, 0.009302416550261634, 0.033891965834689994, 0.08652638524238553, 0.026334500472460474, 0.031005220022052526, 0.039383499018315754, 0.05188109625929168, 0.05984311777033976, 0.0388235142454505, 0.06982986402830907, 0.0542756259840514, 0.02574034297971853, 0.03683223109692335, 0.008455909339578023, 0.026235329186809913, 0.011428617057390511, 0.030771912541240454, 0.011852756575016039, 0.057330556879086156, 0.07119556503104311, 0.06553054401384932, 0.030729154657040323, 0.04184654720925859, 0.02769608107129378, 0.031514647150678296, 0.030768774316779206, 0.02497217687778175, 0.07341099543763058, 0.026086188886048536, 0.023814623277368288, 0.024117926734366586, 0.1025340509201799, 0.018200979235449007, 0.04020924560193505, 0.0251849111768284, 0.048904749897441695, 0.0006471442393376492, 0.07525207807442971, 0.03736322885379195, 0.05950331421835082, 0.037138647333319695, 0.008298828482760914, 0.06125544769955533, 0.15125092464898313, 0.0915736136958003, 0.10032903602612869, 0.061276862264743874, 0.1150642449834517, 0.09597690563116755, 0.058471547439694405, 0.11086063233337232, 0.09147037459271294, 0.23294707015156746, 0.1105814151731985, 0.08076490368694067, 0.19179427410875047, 0.1487569963293416, 0.06742318174136536, 0.19106882517891272, 0.18375572402562412, 0.1327272036245891, 0.08612942868577582, 0.11485121212899685, 0.1279709581285715, 0.10067901760339737, 0.13348322734236717, 0.22041234347437108, 0.1165947892836162, 0.09762197307177953, 0.08546705637127161, 0.10950011533818074, 0.10659346809344632, 0.08946979551443032, 0.17273125345153467, 0.07191138554896627, 0.11504751230989184, 0.08158001423414264, 0.0680807228865368, 0.10357724422855036, 0.15416240984840052, 0.13890734128654003, 0.18022897041269711, 0.16401104708867414, 0.19387715948479517, 0.12453602387436799, 0.13085269635277136, 0.12046752790255205, 0.12616066741091864, 0.10787935302193676, 0.14415134489536285, 0.11978466383048467, 0.13288561441004276, 0.19910562464169093, 0.1185433247259685, 0.10040336275207144, 0.11279957329056092, 0.11530260076480252, 0.10892749285059315, 0.20432245970836707, 0.3610217762844903, 1.263005216206823, 18.780598640441895, 40.92070688520159, 79.02266161782401, 92.47866807665143, 98.81682177952358, 89.8650267464774, 82.83508259909493, 74.9020185470581, 73.58675234658378, 66.4553575515747, 69.17846080235073, 51.90451996667044, 52.42554106031145, 49.457086494990754, 45.74714796883719, 47.47842366354806, 29.755125454493932, 29.06701234408787, 40.12719481331961, 26.2962201322828, 25.977879728589738, 47.7352568762643, 106.64372430528913, 59.771183558872764, 33.201352051326204, 59.33221026829311, 35.88251597540719, 33.54317215510777, 37.71008675439017, 37.44149718965803, 34.68998622894287, 24.22462340763637, 26.48132709094456, 28.181030171258108, 39.44632693699428, 33.92822395052229, 26.63666796684265, 20.363856860569545, 23.053197077342443, 43.63555220195225, 43.72534029824393, 38.06191921234131, 42.70605346134731, 63.651071548461914, 69.14989675794328, 80.21435410635812, 88.17165347508022, 92.79711096627372, 89.34239714486259, 86.3730914252145, 74.46710995265416, 64.21966348375592, 36.2236864226205, 19.79239879335676, 7.179833727223532, 3.677189494882311, 1.7203951414142336, 0.4901962791170393, 0.13988549022802285, 0.18074047725115502, 0.13031510662819656, 0.09862612347517695, 0.13285037130117416, 0.1518785288291318, 0.14582493794815882, 0.12825126094477518, 0.0855176615129624, 0.09922206042600529, 0.17355207726359367, 0.27553852328232353, 0.1892344464680978, 0.16026258894375392, 0.1436329169997147, 0.19906006780053886, 0.08341714101178305, 0.10022401237594229, 0.07686672679015569, 0.18351755823407853, 0.0723853829715933, 0.08078472369483539, 0.11461293777184826, 0.12695923527436598, 0.11279566492885351, 0.10488378376300846, 0.13858859267617973, 0.16804530418344907, 0.16429721244743892, 0.15596261753567628, 0.07250739035329648, 0.14665186857538565, 0.15103026506091866, 0.16582230132605347, 0.08642735305641379, 0.16570651611047132, 0.1469210841293846, 0.14641128719917365, 0.10023286047258548, 0.08164512645453215, 0.1391181078340326, 0.12617210751133306, 0.14664451325578348, 0.16793642645435675, 0.16245288641325065, 0.10962895556752171, 0.14792998427791254, 0.10942975125674691, 0.21258006803691387, 0.12649279673184666, 0.1731425949505397, 0.10006377633128848, 0.1458376401237079, 0.1698088166969163, 0.13283833408994333, 0.2769074541117464, 0.22271557631237165, 0.12414874322712421, 0.14430580660700798, 0.26600741328937666], [0.018475129435371076, 0.03550897924495595, 0.07064876758626529, 0.051085476630500386, 0.024204892871369208, 0.06366099683301789, 0.035528093576431274, 0.02141693836477186, 0.020637717231043747, 0.037760063274098296, 0.06209605759275811, 0.02141698246954807, 0.00971383523262505, 0.04146584835169571, 0.08164629353476421, 0.09759384779525654, 0.02623436227440834, 0.03744345544172185, 0.016823044246328727, 0.028354658678706204, 0.05490740993991494, 0.03502712777948805, 0.010991422526006187, 0.010621063693958734, 0.01926913923983063, 0.02911816324506487, 0.03305405990353652, 0.035941063559481075, 0.012396671942302158, 0.01982640308727111, 0.02330378649224128, 0.03711820985855801, 0.05275130045733281, 0.009902563810880696, 0.0423426479101181, 0.04079657194337674, 0.042441330650555234, 0.03259151954469936, 0.06096816954335996, 0.014546815405732818, 0.03421821904235652, 0.028994045619453703, 0.028451304117749845, 0.058377203930701525, 0.04224506778908627, 0.053399878154907904, 0.019872334819020968, 0.09700389552329268, 0.006315712351351976, 0.010150488632332002, 0.047475826394345076, 0.05454256505306278, 0.1046774819759386, 0.31858768899525913, 0.9352514147758484, 1.7853196518761771, 10.377445527485438, 33.20137637002127, 62.42027459825788, 79.69917297363281, 74.1832412992205, 65.27090508597237, 49.71816505704607, 44.26469768796648, 38.92427750996181, 27.00139454432896, 26.33693310192653, 35.97064345223563, 36.21547017778669, 26.349905388695852, 30.15394163131714, 26.554496833256312, 16.191065822328838, 24.67746009145464, 31.298261301858084, 26.123682464872086, 20.311198200498307, 41.91927071980068, 26.126128230776104, 45.27409029006958, 77.80025809151786, 60.629723821367534, 50.45410088130406, 51.51964882441929, 55.99651561464582, 63.178357805524556, 56.258410590035574, 55.542527266911094, 42.00675548825945, 49.44734859466553, 33.356991699763704, 28.636493274143763, 18.18158401761736, 21.629943711417063, 25.053168296813965, 37.84194619315011, 63.541283062526155, 32.669064453669954, 26.301629304885864, 21.991786786488124, 13.146882840565272, 19.507976021085465, 22.650090387889318, 28.98061149460929, 55.60049956185477, 50.18989910398211, 50.18349633898054, 55.802966594696045, 63.52675437927246, 67.61426149095807, 63.60978535243443, 48.87616498129708, 41.042394161224365, 28.91080641746521, 18.29938551357814, 7.45902407169342, 3.5037572469030107, 0.2634841044034277, 0.05279143241101077, 0.048336785552757125, 0.02657362978373255, 0.042028343704129965, 0.0393168058113328, 0.02905516805393355, 0.04934108184118356, 0.07632736608918224, 0.03228706427450691, 0.06632867761488472, 0.078241425167237, 0.024170620067577277, 0.03312866822151201, 0.04172757966443896, 0.00443864573026076, 0.029516761856419698, 0.04208404803648591, 0.03942095415134515, 0.012750114896334708, 0.07224927563220263, 0.01983034028671682, 0.0460726906146322, 0.016793690821421996, 0.014004341925361326, 0.039646645076572895, 0.011129261826031973, 0.04952461538570268, 0.029949294004057134, 0.07685525954834052, 0.027138372783416083, 0.03689173861805882, 0.02284357350851808, 0.011011520733258553, 0.03369354523186173, 0.05435106890009982, 0.039686756674200296, 0.08615190855094365, 0.056771064044109414, 0.028205684619024396, 0.060224149110061784, 0.11690254562667438, 0.040649221278727055, 0.043270490265318325, 0.10323548649570771, 0.013799971418588288, 0.017636741744354367, 0.017169185315391848, 0.1043463365307876, 0.040147800863321335, 0.014962033036031892, 0.00527619755095137, 0.07002412181879793, 0.025096974734749113, 0.04716983424233539, 0.03856965054624847, 0.06645424052008561, 0.003009421551334006, 0.03241414370547448, 0.0230717122488256, 0.030388268841696636, 0.06772238175783839, 0.030202082225254605, 0.013371260271274617, 0.07110457348504237, 0.02161518933384546, 0.04470691836572119, 0.015535171210233654, 0.05154752505144902, 0.04855647483574493, 0.0374150112537401, 0.04389142444623368, 0.006670260469296149, 0.05017331861225622, 0.043379819220198054, 0.06205813427056585, 0.05214881564357451, 0.027331415996221558, 0.057722254789301326, 0.048253369850239584, 0.015348933703665222, 0.01073225522746465, 0.017751917974757295, 0.02362757661779012, 0.03174107428640127, 0.04397439570831401, 0.052664247807115316, 0.012127278272860816, 0.05749651975929737, 0.015843019155519347, 0.03328378811212523, 0.03863262538132923, 0.005357212935840445, 0.021498287928157618, 0.033513363650334735, 0.019635733050693358, 0.023328836308792233, 0.025405416398176124, 0.05253376213035413, 0.040195820786591084, 0.04314778399254594, 0.052835845920656405, 0.013762927647413952, 0.030760713320757662, 0.03698224501152124, 0.10412434701408659, 0.037160106003284454, 0.014662420809535044, 0.03328831394069961, 0.06642835440912417, 0.07117929376129593, 0.08699226060083934, 0.3715333693793842, 1.1316614640610558, 2.7614032413278307, 14.970044987542288, 41.879513127463206, 73.83572019849504, 88.54797485896519, 82.91569559914726, 73.36959334782192, 63.05874456678118, 56.11300563812256, 49.963606698172434, 43.715553760528564, 41.92622586659023, 48.43548938206264, 52.85195895603725, 32.99478905541556, 36.41363974979946, 27.706775665283203, 20.85845569201878, 30.83298213141305, 25.719903537205287, 31.9180406161717, 29.917570863451274, 37.51645088195801, 21.344508239201136, 45.77401317868914, 87.68691934858049, 52.15206691196987, 35.0385217666626, 43.528400557381765, 44.03185313088553, 45.2339505468096, 48.364204338618684, 47.00239910398211, 43.6066928591047, 43.355737822396414, 34.951078687395366, 29.355868067060197, 25.36479500361851, 29.30128649302891, 27.438981669289724, 27.960945980889456, 53.822997501918245, 46.244934286390034, 35.48593711853027, 33.73540449142456, 27.55771769796099, 36.35609824316842, 35.49447298049927, 39.72417150224958, 65.11911473955426, 61.79090676988874, 60.89238657270159, 68.87647124699184, 74.36872346060616, 77.57753358568463, 73.96238585880825, 58.325958251953125, 47.241969517299104, 33.690498283931184, 20.52977463177272, 8.446918078831263, 3.6751163261277333, 0.4197848087974957, 0.05007550778931805, 0.07031372056475707, 0.048288728310061355, 0.03383340147723045, 0.035317408453140936, 0.004248921825949634, 0.06462972770844187, 0.03816601041970508, 0.06016279597367559, 0.09296623896807432, 0.031150881134505783, 0.013941553687410695, 0.05310981800513608, 0.031075533213359968, 0.00768380773453308, 0.020713421383074353, 0.060519671466733725, 0.01745288589570139, 0.04163875603782279, 0.0827069455491645, 0.05501409260822194, 0.01840122340113989, 0.031798715836235454, 0.026979695672967603, 0.02387364734230297, 0.022802951313289146, 0.049601551078792126, 0.09344517612563712, 0.014693521462114794, 0.05880663517330374, 0.04933890035109861, 0.03886399564466306, 0.03642818384936877, 0.04300678102299571, 0.03732352776985083, 0.010995466594717332, 0.04424717357116086, 0.09517544720854078, 0.01011499107283141, 0.08600828982889652, 0.06335707421281508, 0.030444512609392405, 0.07243190333247185, 0.04685863094138248, 0.043425952816115956, 0.04163603171972292, 0.03371960097657783, 0.09425312134304217, 0.03982676558994821, 0.07533729528742177, 0.03597867475556476, 0.040244461569402895, 0.04086054422493492, 0.021583284617268612, 0.04906756437516638, 0.040599515195935965, 0.06673811243048736, 0.02361182782000729, 0.10845563959862504, 0.1342228983661958, 0.2312318964728287, 0.15201450724686894, 0.15044782417161123, 0.17033063726765768, 0.10290974897465535, 0.1677024540092264, 0.1247875839471817, 0.12034136110118457, 0.1916302993361439, 0.1404892642583166, 0.10202614031732082, 0.10891460068523884, 0.1539126546787364, 0.1652718194361244, 0.11518682911992073, 0.23289921986205236, 0.09000974654086999, 0.13464901835790702, 0.10178037493356637, 0.06418313631521803, 0.2753495377089296, 0.09636306669563055, 0.11592100401009832, 0.15556692305420125, 0.1388018833739417, 0.1766512452491692, 0.17854776419699192, 0.16298451860036167, 0.09644714396979127, 0.07850838119962386, 0.13269631671054022, 0.11476856656372547, 0.08222920261323452, 0.0833670651274068, 0.1306708896798747, 0.09251776803284883, 0.15110527032188006, 0.18903229731534207, 0.14113955864948885, 0.19709454184131964, 0.1280111681137766, 0.22380693203636579, 0.17955357022583485, 0.1080900381452271, 0.20441113066460403, 0.1387143659272364, 0.0963357285197292, 0.12771452617432388, 0.12983333319425583, 0.2756217930998121, 0.19669621464397224, 0.5344460989747728, 1.6400521440165383, 3.997921815940312, 20.3326472895486, 52.81795447213309, 87.51566014971051, 103.04646818978446, 93.48399598257882, 85.2969891684396, 69.61667673928397, 61.690887451171875, 56.18280724116734, 43.203315189906526, 42.19621549333845, 53.828434467315674, 53.79379422324044, 41.6174236025129, 48.320541858673096, 45.01996340070452, 29.954361574990408, 42.49283409118652, 48.127239499773296, 37.49614477157593, 33.70435299192156, 58.35952499934605, 42.85466153281075, 60.098172732761924, 90.61584213801792, 78.45974636077881, 69.35651533944267, 69.85743182046073, 71.65648719242641, 81.90537193843296, 76.89651979718889, 74.25828879220145, 60.0359377179827, 66.94106442587716, 49.338862895965576, 43.85770000730242, 30.403628621782573, 32.6918580191476, 44.1250319480896, 52.79562643596104, 76.43977301461356, 45.7574382509504, 40.063868931361604, 35.32355424336025, 26.841047491346085, 32.872726576668875, 37.828532695770264, 45.903082915714805, 75.9407047544207, 70.04810428619385, 71.79012189592633, 78.46768120356968, 87.45866407666887, 88.10215064457485, 84.91664477757045, 69.06141144888741, 61.52703503199986, 44.41645676749093, 29.452618258340017, 13.428212795938764, 6.78981179850442, 1.045677615063531, 0.19595829424049171, 0.19695070598806652, 0.2184946813753673, 0.13182260787912778, 0.1274503046380622, 0.0864460738375783, 0.2174929329859359, 0.179840658392225, 0.21581676150006907, 0.10348385745393378, 0.17423663767320768, 0.0970674946105906, 0.12724739552608558, 0.16716223156877927, 0.11930202187172004, 0.10634558568043367, 0.12986244234655583, 0.14888685436121055, 0.11327138583042792, 0.17129867603736265, 0.07799147322241749, 0.09033697683896337, 0.09944216361535446, 0.12660706202898706, 0.12368710871253695, 0.1633457706442901, 0.17514405612434658, 0.18005078711680003, 0.12917951042098658, 0.11527731855000768, 0.10978467256895133, 0.14236667566001415, 0.08289737640214817, 0.1610194540449551, 0.11353790081505265, 0.09009298243160759, 0.17933969598795685, 0.13665802484112127, 0.1012677349416273, 0.1956206416445119, 0.20263520096029553, 0.1911944355815649, 0.1587741816682475, 0.19648071192204952, 0.1617921832948923, 0.15044911338814668, 0.09631270582654647, 0.22726816630789212, 0.1852453662348645, 0.16951378967080796, 0.08331019032214369, 0.14736644737422466, 0.09514503526900496, 0.10381646174937487, 0.12921315218721116, 0.164966275117227, 0.17053849968527043, 0.13067097110407694], [0.05096963034676654, 0.013879708613135984, 0.052206670931939564, 0.018264267892975892, 0.06550678171749626, 0.06752931818898235, 0.039418321435472796, 0.043204960745892355, 0.02267307122903211, 0.0389956076895552, 0.025601750505822043, 0.03441523847037128, 0.03217090247198939, 0.06493989963616643, 0.02014657492483301, 0.04376810409926942, 0.05517042368384344, 0.07946814862745148, 0.025499071194125072, 0.05243831600195595, 0.06330056581646204, 0.03161888709291816, 0.06145590051476445, 0.01757245564035007, 0.04912862913416965, 0.03404290934226342, 0.023303874701793705, 0.039105133419590335, 0.06453714160514729, 0.05640154065830367, 0.027230404184332917, 0.02836979170595961, 0.05782843194901943, 0.12180657604975359, 0.05694614643497126, 0.025347354156630378, 0.016148390447986976, 0.021651701303198934, 0.026086406017254506, 0.04116084007546306, 0.011900995325829302, 0.023386784895722355, 0.05416505531008754, 0.010459305186356817, 0.023167763969727924, 0.011939184973016381, 0.04789176836077656, 0.018708284245803952, 0.09706617146730423, 0.026121915451117923, 0.1987427712551185, 0.49884798058441704, 6.071158315454211, 8.261373383658272, 16.831658465521677, 37.97741174697876, 59.50271906171526, 67.31135477338518, 71.26637363433838, 52.31911897659302, 45.796692098890034, 41.281735283987864, 22.24725467818124, 21.215334279196604, 20.197781017848424, 16.657967397144862, 17.990093401500157, 23.832385437829153, 20.57161668368748, 54.668297971997944, 42.6974515914917, 36.748212882450645, 49.788981097085134, 40.46483557564871, 49.893530641283306, 64.72577721732003, 63.813958168029785, 75.94003772735596, 65.31333773476737, 43.233036109379356, 29.896330220358713, 50.80756616592407, 49.03287117821829, 24.231274570737565, 38.63933188574654, 33.14129877090454, 31.626261438642228, 51.906666960035054, 56.94047008241926, 60.40676307678223, 51.460540499006, 62.0019166128976, 65.61094992501395, 53.193775585719514, 41.874847412109375, 46.51824515206473, 29.858167239597865, 31.51672308785575, 34.29540845326015, 21.32791941506522, 19.364730221884592, 21.21140159879412, 16.197202818734304, 22.30417432103838, 25.567055327551707, 23.80897695677621, 23.62857219151088, 29.49098273686, 42.58750329698835, 43.61791072572981, 59.74496105739048, 64.21748174939836, 69.67634092058454, 63.209562165396555, 54.30894408907209, 48.14023263113839, 31.78287730898176, 19.063133239746094, 3.4903765363352637, 2.9645963609218597, 0.3438773676753044, 0.10740209184587002, 0.06749717598514897, 0.07508909396295037, 0.03226072354508298, 0.02057306980714202, 0.042090545009289465, 0.009140249225310981, 0.01677490727576826, 0.01658475971115487, 0.02477813621849886, 0.019813624576532414, 0.03938871016725898, 0.02818112165134932, 0.06390398700854608, 0.06691451796463557, 0.06287725495972804, 0.04554050542148096, 0.03559160784685186, 0.01941270537541381, 0.03481296516422715, 0.0727925379095333, 0.026211266638711095, 0.031503325793892145, 0.024000886228999922, 0.05883190381739821, 0.013610010451105024, 0.02217355919336634, 0.03864630464730518, 0.026311019768140147, 0.02290163066105119, 0.02930556783186538, 0.03326160001701542, 0.07942229323089123, 0.035125579818018844, 0.003204069711500779, 0.008302269503474236, 0.02388852252624929, 0.029632808307984045, 0.035554400379104276, 0.008430231878134822, 0.07180000402565513, 0.02436405174168093, 0.04298386689541595, 0.055457454174757004, 0.041677279863506556, 0.06285966054669448, 0.03762826802475112, 0.02365378164021032, 0.01455707146253969, 0.05062621359580329, 0.07382982117789132, 0.023983841429331472, 0.025601063489115665, 0.05724483076483011, 0.04973396040233118, 0.026496695786980645, 0.007511828793212771, 0.02472352941653558, 0.02677479845338634, 0.05120230000466108, 0.031293349739696295, 0.03170760893928153, 0.042486361627067835, 0.017175841743924787, 0.032987454906105995, 0.05096435473699655, 0.017418244986661842, 0.011263930671183127, 0.014628690833758031, 0.019605948756049787, 0.056584266746150594, 0.010348509747668036, 0.03812047732727868, 0.06427604132997138, 0.04393522048901234, 0.009778827861217516, 0.022058834188750813, 0.06877198722213507, 0.03723213588818908, 0.035716105452073474, 0.012470410887285002, 0.023819140624254942, 0.04425165868763413, 0.034289631460394175, 0.01998046785593033, 0.07279362356556313, 0.07558878750673362, 0.08108460903167725, 0.06244819691138608, 0.054148095327296426, 0.011828462476842105, 0.0558598322261657, 0.04026713142437594, 0.02299174520054034, 0.036157719790935516, 0.030231099775327102, 0.04080657694222672, 0.0425887423833566, 0.050721910782158375, 0.05114201556092926, 0.07143081312200852, 0.1213285888412169, 0.021819655683689883, 0.07923162489065103, 0.026847059040197303, 0.20896188861557416, 0.9089673565966743, 7.433000462395804, 12.303441882133484, 22.493610007422312, 46.775043623788015, 70.26546478271484, 77.42345033373151, 81.62251772199357, 62.99903869628906, 59.6464911869594, 53.65993022918701, 34.21034860610962, 35.07684455599104, 32.16959319795881, 25.54047151974269, 21.329576560429164, 35.558611801692415, 32.89692367826189, 49.5722667830331, 41.452483790261404, 43.247665541512625, 41.85890824454171, 36.029689243861604, 46.305286339351106, 43.654927253723145, 41.45297016416277, 60.51940727233887, 48.95038563864571, 40.95430142538888, 34.417571680886404, 45.00786658695766, 40.77910607201712, 26.712047236306326, 30.814294951302664, 29.101850611822947, 27.522896800722393, 40.091508865356445, 40.972926071711946, 46.76914807728359, 39.06240769795009, 45.0966089793614, 38.23535667146955, 38.691745621817454, 43.67557382583618, 51.41613803591047, 45.05416938236782, 35.74879094532558, 37.96061447688511, 26.803165912628174, 22.2492071219853, 29.95188454219273, 26.349382536751882, 34.60540580749512, 43.895189012799946, 34.39291599818638, 37.54260390145438, 42.5756322996957, 52.057359491075786, 53.97571195874895, 71.300795010158, 73.01195566994804, 79.86478328704834, 73.31805855887276, 63.47014740535191, 54.788633823394775, 37.36056457247053, 21.446231603622437, 5.053189464977809, 3.108544145311628, 0.7156766684991973, 0.023057948165972317, 0.1165044219898326, 0.03089713617893202, 0.020662624555240785, 0.02839963706875486, 0.044493386788027625, 0.03454735263117722, 0.062457119646881304, 0.014398039817543966, 0.0480657040274569, 0.044341947949890576, 0.07350770024848835, 0.026233627760250653, 0.015237014441351806, 0.03904622300927128, 0.05882686908755984, 0.023066300932051878, 0.05114164915201919, 0.045300880779645274, 0.038921314890363386, 0.01873191083515329, 0.011434115735547883, 0.021953074328069175, 0.06107659265398979, 0.01185850122211767, 0.028697213690195764, 0.013940985414332576, 0.08375285299760954, 0.023404260565127646, 0.020930079310866337, 0.03067509237942951, 0.017536384718758718, 0.05447389730917556, 0.047049292496272495, 0.02331781859642693, 0.01789176743477583, 0.014487104324091758, 0.06312563948865448, 0.08521484490483999, 0.0189117327931204, 0.07651333218174321, 0.05384052558136838, 0.053250525811953206, 0.03543514445690172, 0.030692174498523985, 0.034585740749857256, 0.024815932315375124, 0.02331475161814264, 0.017963559832423925, 0.03955565353057214, 0.02961284580773541, 0.022811020790998424, 0.048956847816173515, 0.04322168663410204, 0.0613919621599572, 0.1689696724393538, 0.11630759255162307, 0.07800437217312199, 0.0753871336845415, 0.10700341181031295, 0.166065922539149, 0.15920528210699558, 0.18518706650606223, 0.07503980517919574, 0.1359856916325433, 0.20195553957351617, 0.13932314754596778, 0.09358336656753506, 0.23427881726196834, 0.10722339286335877, 0.1394410226494074, 0.12313317986471312, 0.18238973803818226, 0.13798574145351136, 0.1363296274627958, 0.1918973842901843, 0.14137330039271287, 0.23128699351634296, 0.13192915144775594, 0.12205156790358679, 0.11730825528502464, 0.14325495942362718, 0.14233866573444434, 0.14214288124016353, 0.26930997893214226, 0.18588019002761158, 0.2442875344838415, 0.1453532339738948, 0.18762732270572866, 0.1341236558343683, 0.12417610175907612, 0.10059047556881394, 0.12430410060499396, 0.09196753041552645, 0.12432554231158324, 0.08581104648432561, 0.11504957505634852, 0.106211988920612, 0.11937801779380866, 0.20340512107525552, 0.1448562613555363, 0.1904291430754321, 0.09249441964285714, 0.2219737068350826, 0.12427203304001264, 0.422478267124721, 1.9645473488739558, 10.783454826899938, 17.051421301705496, 30.2010087285723, 57.01134518214634, 84.61142430986676, 87.12923608507428, 90.35608373369489, 69.69979803902763, 64.53798130580357, 57.74755893434797, 37.56937531062535, 34.46650436946324, 33.89919785090855, 25.04096031188965, 29.496391909463064, 38.55605772563389, 34.19394390923636, 69.81868866511753, 61.3174843106951, 56.939334051949636, 70.91457939147949, 57.15030220576695, 70.90129443577358, 81.9748261315482, 82.00929614475795, 92.96767534528459, 88.31149986812046, 58.76385457175118, 43.916033608572825, 65.56993470873151, 62.210800307137625, 33.11071974890572, 51.123830795288086, 43.84783009120396, 40.18562568937029, 63.600502559116904, 68.31339618137905, 79.45181015559605, 65.44915417262486, 79.33478164672852, 87.35900606427873, 73.0606278010777, 57.99418524333409, 58.83442047664097, 40.80488388878958, 46.90761177880423, 48.8644711630685, 36.041789531707764, 29.2006105695452, 32.59698731558663, 27.452077286584036, 36.65250492095947, 41.63303967884609, 39.75900629588536, 38.09001425334385, 45.329446588243755, 61.082246099199565, 66.6445917401995, 78.41157449994768, 83.83632496425084, 89.77206679752895, 84.41949422018868, 76.04251670837402, 66.94493457249233, 49.633171217782156, 29.756921563829692, 9.48251928601946, 5.595685269151415, 1.3695974222251346, 0.15730655113501207, 0.25310713265623364, 0.1578350213489362, 0.13588103439126695, 0.11524686589837074, 0.08430312454168286, 0.10714476422539779, 0.1279076100992305, 0.19453122653067112, 0.1603799212191786, 0.09153323407684054, 0.13691570529980318, 0.10346253109829766, 0.09990312638027327, 0.15436753098453793, 0.10861679166555405, 0.103720299766532, 0.24707840329834393, 0.13575051139507974, 0.1316742936947516, 0.20071662962436676, 0.09917311769511018, 0.1402130462229252, 0.11397753043898515, 0.16970141817416462, 0.08094191990260567, 0.0905650799561824, 0.1400267340775047, 0.1967798372996705, 0.13531946523913316, 0.08641728359673705, 0.10032978241464921, 0.1703742534986564, 0.18655776152653353, 0.10160013567656279, 0.07871680001595191, 0.23437853476830892, 0.12484939848738057, 0.14735173673502036, 0.2121807366077389, 0.1261537599244288, 0.23978206196001597, 0.12932346841054304, 0.09756587858178786, 0.09126106689551047, 0.14620267839304038, 0.09829805179366044, 0.1631315028561013, 0.12639968815658773, 0.1635465355856078, 0.11777359460081373, 0.1491371387881892, 0.1737625181142773, 0.13862839554037365, 0.14559764228761196], [0.0163266738277993, 0.0064176927719797406, 0.023549692672012106, 0.11219465932143585, 0.018756109090255838, 0.02641741745173931, 0.02496553401994918, 0.04964994080364704, 0.06634080982101814, 0.025587518233805895, 0.031869731311287196, 0.011542547327865447, 0.01865137042477727, 0.0524463736053024, 0.02540183542961521, 0.06962930264749698, 0.01562547404319048, 0.037208953739276955, 0.04587046682302441, 0.10360480632100787, 0.09754128847271204, 0.1034729533961841, 0.04438700946047902, 0.03218869026750326, 0.027969571395910213, 0.047006504077996523, 0.0675512280847345, 0.033820841794035265, 0.049443262429641824, 0.02747769287920424, 0.05255868472158909, 0.05530239874497056, 0.036111287639609406, 0.04494059904079352, 0.03443844776068415, 0.021523561661264727, 0.034021457457648854, 0.045128736445414167, 0.04884135437064937, 0.009763971336984208, 0.028851108825100318, 0.016767345002985427, 0.041754578572830985, 0.035565755662641356, 0.07811939742948328, 0.0265726018031793, 0.060917340485113006, 0.09303027231778417, 0.24272047142897332, 1.4439761510917117, 10.869959899357386, 29.76162896837507, 44.427320275987896, 49.71113000597273, 66.48389380318778, 66.98287173679897, 63.06054415021624, 59.82998616354806, 43.77050706318447, 39.50276368004935, 22.80167923654829, 20.36406009537833, 26.953399862561906, 24.28836270741054, 29.778398445674352, 42.033325399671284, 55.19904654366629, 37.35413401467459, 49.01760598591396, 47.093139103480745, 44.95112759726388, 35.71722180502755, 49.685581479753765, 54.10999979291643, 45.54591424124581, 59.639404024396626, 56.30731201171875, 45.6198604447501, 34.71766785212925, 23.14746676172529, 16.403369767325266, 9.830083812986102, 5.562937540667398, 4.0885376163891385, 1.722844815679959, 1.3369619505746024, 2.2368316182068417, 4.559048346110752, 11.095642600740705, 13.220716135842459, 22.389393976756505, 24.06622358730861, 35.42257649557931, 46.11262321472168, 45.07319702420916, 41.062210423605784, 46.841253008161274, 60.7066125869751, 62.75189127240862, 59.990788323538645, 63.413616861615864, 44.86525133677891, 28.934796810150146, 17.4732985496521, 16.319001265934535, 31.884675366537913, 15.812911851065499, 18.61912076813834, 28.741893972669327, 34.784290654318674, 40.87293454578945, 51.2912962777274, 45.79583747046334, 59.303514208112446, 72.61866678510393, 65.03114359719413, 67.66549750736782, 55.957654339926584, 50.73234844207764, 31.67422137941633, 15.630262817655291, 4.107797154358455, 0.5296469564948763, 0.16358320361801557, 0.04729456254946334, 0.01916716051554041, 0.03799903312964099, 0.04706576732652528, 0.08203289564698935, 0.03702304871486766, 0.010589268391153641, 0.0344468582022403, 0.09668837673962116, 0.034223430191299746, 0.033151107374578714, 0.04960624314844608, 0.012912713091022201, 0.02243075110683484, 0.12767092351402554, 0.0242176238846566, 0.028614082972386053, 0.04534120950847864, 0.02627118636987039, 0.01892794299471591, 0.06381618457713298, 0.012266485669117953, 0.04386607098526188, 0.038169942530138154, 0.051357016166938205, 0.04132089291566184, 0.043595423722373586, 0.014257471110405666, 0.09083844814449549, 0.016505335490884523, 0.053336241748183966, 0.08305899665824004, 0.056478306717638455, 0.033900705365730185, 0.04593215583424483, 0.03383108428014176, 0.027172525147242204, 0.032466194126755, 0.021608963775049363, 0.009409517365773874, 0.04073196862425123, 0.05037756443821958, 0.013386836890796465, 0.0596343529011522, 0.05427108997745173, 0.06936670959528003, 0.017445182826902186, 0.009980912553146482, 0.0772445961566908, 0.05984663258173636, 0.04606382894728865, 0.03320995671674609, 0.06425316112914256, 0.05601445339354021, 0.026877598205049123, 0.03623163939586707, 0.02096852340868541, 0.051250102796724865, 0.019835865258106163, 0.028477734753063748, 0.056395491518612416, 0.02199187465677304, 0.011311633379331656, 0.04789658595940896, 0.0092947016070996, 0.01683157852052578, 0.02675927696483476, 0.015481232765263744, 0.07721852005592414, 0.011436325215202357, 0.037332067133060524, 0.07033667540443794, 0.05829143710434437, 0.08042816711323601, 0.011492548626847565, 0.015941805372546827, 0.03489146827320967, 0.019147593261940137, 0.06152403221598693, 0.059343057817646434, 0.029605215681450706, 0.02268614829517901, 0.02955374201493604, 0.02211238586876009, 0.02403975780388074, 0.12074523871498448, 0.018886279248233353, 0.01695271228839244, 0.03173245010631425, 0.04104549590764301, 0.029568191418158155, 0.011516921604717416, 0.050647658695067675, 0.03342882836503642, 0.060213468968868256, 0.005855257639528385, 0.03625360357442072, 0.05196157729785357, 0.05097291784893189, 0.09560394885816745, 0.32232942964349476, 2.5013245684759955, 14.049173304012843, 35.94017212731497, 53.06200647354126, 61.423041343688965, 78.27016476222447, 77.96758460998535, 74.64987536839077, 69.07892090933663, 54.651386056627544, 50.73096227645874, 40.29870414733887, 32.67311872754778, 32.431818212781636, 30.31592845916748, 30.020477158682688, 34.09531423023769, 45.13255548477173, 36.43469279153006, 38.496275424957275, 55.651888438633506, 45.28651019505092, 41.87383644921439, 51.38225514548165, 50.4357784816197, 42.36848565510341, 48.472339153289795, 48.82862540653774, 38.965636662074495, 31.823131697518484, 22.459065301077707, 16.078609228134155, 10.413826295307704, 5.796507750238691, 3.2009608319827487, 1.7810057976416178, 1.1471903622150421, 1.9451021637235368, 4.189050257205963, 9.859284486089434, 10.80035024029868, 16.45630635534014, 19.292241403034755, 29.805711814335414, 35.7260981287275, 35.23107719421387, 29.362795421055385, 29.839288984026226, 42.77202660696847, 47.54481717518398, 45.51451185771397, 45.042246273585725, 32.40247597013201, 29.938707283564977, 22.87618998118809, 21.51738289424351, 40.44547094617571, 24.22659148488726, 25.773830243519374, 39.259354387010845, 44.11231674466814, 54.15608719417027, 60.551021575927734, 56.459456716264995, 68.47235012054443, 82.09305667877197, 74.15972164699009, 77.29397760118756, 65.72905540466309, 57.13957418714251, 37.87432827268328, 18.08252007620675, 5.324903982026236, 0.4009655586310795, 0.20465462974139623, 0.056470211794865985, 0.047819372066961865, 0.012034492001735737, 0.014255773076521499, 0.06585358096552746, 0.05002036324835249, 0.014560487886358584, 0.035054245431508334, 0.06518223841807672, 0.03694249303745372, 0.02988854137116245, 0.049813057229455025, 0.0786472230351397, 0.026549314481339285, 0.015795467421412468, 0.024882030107879212, 0.03323064864213977, 0.03917853733790772, 0.08290743229112454, 0.0169767544804407, 0.09894632415047713, 0.033032631767647605, 0.03819340966375811, 0.06872848634208951, 0.034769759446914704, 0.012715800532272883, 0.0501786485048277, 0.004956067697743752, 0.08134179415979556, 0.044943828867482286, 0.03892987121694854, 0.06991012115031481, 0.013573298313921052, 0.042697457264044454, 0.02030690766072699, 0.014782105905136891, 0.025900550186634064, 0.07892194150813989, 0.06201219066445317, 0.023473555953907113, 0.032144290328558, 0.07908738870173693, 0.0410311448919986, 0.009195532017786587, 0.035004057588854005, 0.06785602601511137, 0.022811477105798464, 0.04876051710120269, 0.0653217655739614, 0.0626522663182446, 0.014903870710570897, 0.006893717317974993, 0.09964980211641107, 0.18118159286677837, 0.06579978670924902, 0.22198041076106684, 0.10616320903812136, 0.22527237768684114, 0.12383369941796575, 0.17082167948995317, 0.13230481557548046, 0.1457537460540022, 0.15257606282830238, 0.08875435497611761, 0.060001094293381484, 0.10324672303561654, 0.12267716362008027, 0.16235151328146458, 0.10751316124307257, 0.06577234675309487, 0.27672750662480083, 0.27211151431713787, 0.17070433364382812, 0.1316136055226837, 0.12223815146301474, 0.1017286434237446, 0.18002421568546975, 0.19828173385134765, 0.15427936214421475, 0.0956227917756353, 0.07995345044348921, 0.1101309357743178, 0.20564428663679532, 0.11834611530814852, 0.09001571764903409, 0.2478417009115219, 0.09989129272954804, 0.09313926539782967, 0.15742581044988974, 0.16198042247976574, 0.15061071328818798, 0.10674761767898287, 0.10385209162320409, 0.11891399483595576, 0.14300143159925938, 0.09776856377720833, 0.13736750105662004, 0.131246667355299, 0.14349620576415742, 0.3171659952827862, 0.6137907270874295, 4.560266886438642, 19.90380447251456, 46.081787109375, 62.672445569719585, 73.12392589024135, 89.46863201686314, 88.7843108858381, 83.03974178859166, 79.38223784310478, 63.28779193333217, 56.37825311933245, 34.765356813158306, 32.218209743499756, 38.24073805127825, 35.635542256491526, 41.9244054385594, 56.786960056849885, 73.77390902382987, 52.310781138283865, 65.0116400037493, 67.1776088987078, 63.35477951594761, 53.198569842747276, 67.06687545776367, 69.88288307189941, 59.268106188092915, 75.34997585841587, 72.8936903817313, 58.931396484375, 44.444162709372385, 30.956621851239884, 21.837432554789952, 13.114225438662938, 7.466880747250148, 5.533372521400452, 2.1966642992837087, 1.7624567129782267, 2.9991645174367085, 6.15356525353023, 14.747211047581263, 16.988151005336217, 29.13171570641654, 31.484973294394358, 45.599196502140586, 59.20960235595703, 59.543206214904785, 53.61432225363595, 61.97542313167027, 77.36892781938825, 81.15791947501046, 77.19376373291016, 84.7332123347691, 61.78239522661482, 43.52046571459089, 30.20249216897147, 29.164966310773575, 46.94367640359061, 25.199639797210693, 29.618197304861887, 43.374383313315256, 52.49419968468802, 58.99062292916434, 70.6867618560791, 64.78662259238106, 77.7897732598441, 89.09899480002267, 83.41787665230888, 86.58693613324846, 74.42781094142369, 70.69416863577706, 48.395033495766775, 26.716808489390782, 9.340627517019, 0.9913542100361415, 0.36363454322729793, 0.10636818089655467, 0.17272775221083844, 0.17546541030917848, 0.14392513489084585, 0.1542865274740117, 0.16327214959476674, 0.10444494802504778, 0.16304360542978558, 0.16759316915912287, 0.09139532861965043, 0.14581729764384882, 0.20506964890020235, 0.21734132112136909, 0.1809999897543873, 0.26771034619637896, 0.12572149240544864, 0.09363826005054371, 0.18477914482355118, 0.14162837527692318, 0.10237609475318875, 0.23520651033946446, 0.08849530387669802, 0.11698432266712189, 0.15906045559261525, 0.11355206862624202, 0.09611660242080688, 0.15622637766812528, 0.14177303894289903, 0.18660186630274567, 0.2040209730288812, 0.1431744580290147, 0.13039343671074935, 0.10608909265803439, 0.13877457912479127, 0.12326581989015852, 0.06222898938826152, 0.07631055877677032, 0.215330428310803, 0.14234264194965363, 0.14689759324703897, 0.1599183138459921, 0.16273181858871663, 0.09609030240348407, 0.1261563654989004, 0.1446199276085411, 0.18189614452421665, 0.1900744999625853, 0.1082604725712112, 0.13463638403585979, 0.1957845485636166, 0.11353997034685952, 0.16729416591780527], [0.014707134570926428, 0.014354654288451587, 0.06257974449545145, 0.04727716491158519, 0.07089700962283782, 0.03523998760751315, 0.017820265110848204, 0.06490163704646484, 0.007928952258745474, 0.0470602847635746, 0.04158711273755346, 0.020143204302127873, 0.0628834974818996, 0.025694557132997682, 0.015030568465590477, 0.06939490951065506, 0.06099919894976275, 0.0023170431460519986, 0.010451228923297353, 0.038665710748838525, 0.03329181857407093, 0.014368018035643866, 0.02594752686231264, 0.03435723051162703, 0.028455695935658047, 0.009601194178685546, 0.04258010463256921, 0.07186951315296547, 0.05298286071047187, 0.015294922316180808, 0.039417832890259366, 0.03706926034231271, 0.01673103659413755, 0.04328403721696564, 0.05690827739558049, 0.026237853337079287, 0.02324726622152541, 0.056146363993840556, 0.03715151235727327, 0.0445941560236471, 0.05537470004388264, 0.010429911049348968, 0.021280936198309064, 0.03140543693942683, 0.05148896747933967, 0.13675217836030892, 0.8677704014948436, 3.768864027091435, 16.326936108725413, 35.727216788700645, 59.2899443762643, 69.22795282091413, 64.91196114676339, 63.91167068481445, 53.83799866267613, 42.73379414422171, 52.137948172433035, 34.44098711013794, 18.86643147468567, 23.538521800722393, 16.378295455660137, 26.251732553754533, 33.95170538766043, 46.0897775377546, 53.277515275137766, 61.618160656520296, 50.664457593645366, 62.87459645952497, 65.82389831542969, 41.2279041154044, 38.99089336395264, 40.88440602166312, 30.089823654719762, 18.000046695981705, 21.085019077573502, 12.79875898361206, 7.217720082827976, 6.373482687132699, 4.819224945136479, 2.2332055270671844, 0.4086798775408949, 0.3903152458369732, 0.312082438064473, 0.03591138443776539, 0.06590541425560202, 0.09045429554368768, 0.1006628345432026, 0.03786470355199916, 0.01806376418764038, 0.18531893300158636, 0.08964116631874017, 0.41265614703297615, 1.325454322355134, 3.513713146959032, 10.574128184999738, 21.641574995858328, 25.96233139719282, 26.96647810935974, 33.15304470062256, 45.3704548563276, 54.17123774119786, 72.81354985918317, 71.28974737439836, 63.37530449458531, 86.5529455457415, 47.01397132873535, 30.278606210436138, 23.139830691473826, 24.88233641215733, 23.91325899532863, 21.61056865964617, 28.394867931093486, 35.28658635275704, 38.76946817125593, 41.18959869657244, 58.35446671077183, 55.794958795819966, 72.39013358524868, 74.22873115539551, 69.13291536058698, 61.24417386736189, 44.00914294379098, 17.639546360288346, 3.3185996966702596, 0.21903700727437223, 0.059080926169242175, 0.0019016075363781834, 0.052886451062347205, 0.07830949580030781, 0.02807413024960884, 0.03715955638991935, 0.05788217870784657, 0.0952310599386692, 0.023056502886382595, 0.029895102804792777, 0.04842492046632937, 0.009409848999764239, 0.08502431227160351, 0.018324399666328515, 0.07122852826224906, 0.0539588926226965, 0.03283172433397599, 0.0377685449618314, 0.057508760531033785, 0.009385532849202198, 0.035033200667904954, 0.0683689374210579, 0.034547722432762384, 0.012882994105374175, 0.04281633999198675, 0.017491962727425352, 0.05838126835546323, 0.021915366440745335, 0.04473381210118532, 0.0655754901734846, 0.05490857023479683, 0.03930403578228184, 0.04034903060112681, 0.04686626106766718, 0.05786372934068952, 0.03429843205958605, 0.032777329574206045, 0.05999629705079964, 0.017140164372644255, 0.0017983993914510521, 0.040129378637565036, 0.019069744939250604, 0.03499490075877734, 0.004045710341805326, 0.021239825457866703, 0.013149129110388458, 0.02293417489688311, 0.038356180036706586, 0.019419314306495444, 0.04068570949935487, 0.033664191806955, 0.03657735638054354, 0.025922107244176523, 0.048240874627871175, 0.048338169764195166, 0.05186709129650678, 0.034505853429436684, 0.029910919456077472, 0.03340608047853623, 0.0644269407327686, 0.04029868669541819, 0.01765528441007648, 0.026825308600174527, 0.031938592437654734, 0.010286037028501076, 0.017735210746260624, 0.013843153387175074, 0.026625089879546846, 0.008700596700821604, 0.02789046778343618, 0.015055124647915363, 0.013726417374398028, 0.036488597214754136, 0.03620759890015636, 0.027129751996004155, 0.021986224156405245, 0.01775563465032194, 0.03583445892270122, 0.028664253851664916, 0.06802656900669847, 0.05121180967294744, 0.04594332112797669, 0.007519841443614236, 0.01194876164663583, 0.04229035660890596, 0.04568976616220815, 0.0518450897985271, 0.06580556104225771, 0.02468820657980229, 0.03715410436104451, 0.021510437097666518, 0.013973572058603168, 0.059717025607824326, 0.03285679281023996, 0.09451149390744311, 0.008275698072143962, 0.1675520363662924, 0.896490671804973, 4.393550506659916, 20.328931740352086, 42.38010999134609, 68.1579441343035, 79.69610186985561, 75.11333411080497, 73.09420844486782, 61.73396628243582, 53.97819593974522, 62.620730127607075, 49.273185048784526, 33.327691146305625, 34.17849806376866, 28.16283631324768, 32.260913372039795, 40.043503761291504, 43.873336928231375, 49.16755158560616, 49.95649174281529, 53.8741431917463, 52.89363077708653, 51.9289150919233, 42.11006825310843, 44.939680440085276, 40.303991726466585, 29.496044499533518, 22.476798840931483, 20.90145288194929, 14.628214461462838, 8.73780267579215, 7.4461924859455655, 4.555694537503379, 1.637923932501248, 0.31324607133865356, 0.39523932018450325, 0.1992786917835474, 0.08723003284207412, 0.09351281249629599, 0.10767678317746945, 0.04290770133957267, 0.020880308767248477, 0.046623114829084704, 0.06375234800257853, 0.23079204293234007, 0.4402747207454273, 1.2143420960221971, 2.9217281469276974, 7.274321845599583, 13.441112126622881, 17.51970556804112, 17.100694452013286, 25.8710390159062, 39.281435762132915, 48.6887651171003, 56.95414761134556, 49.78980793271746, 43.17607825142996, 67.79292052132743, 44.33160536629813, 23.427607706614904, 26.31964077268328, 33.05632925033569, 34.55881118774414, 26.62535629953657, 40.852565901620046, 46.15783166885376, 54.61064529418945, 52.79991694859096, 66.85667160579136, 65.03789724622453, 81.39928599766323, 84.23098264421735, 76.59750407082694, 68.5016645703997, 52.62151500156948, 22.21159652301243, 4.677564638001578, 0.4502463899552822, 0.02349500953485923, 0.04112669958599976, 0.02339446421579591, 0.101092272571155, 0.01692208830666329, 0.09095480332949332, 0.04132217534684709, 0.09551943053624459, 0.05278422976178782, 0.031178999625678574, 0.03615205063085471, 0.04814265329124672, 0.08787042740732431, 0.028493615865175213, 0.01631409039587847, 0.05450880115053483, 0.0162609831563064, 0.05389406877968993, 0.060862826981714795, 0.018430532721270407, 0.0421293368563056, 0.04199400983218636, 0.05260807528559651, 0.05444650824314781, 0.061565409281424115, 0.05561625172517129, 0.03210957647700395, 0.008472565677948296, 0.053770127573183606, 0.01630656374618411, 0.029805607428508143, 0.05423613524596606, 0.0238846514839679, 0.023510039085522294, 0.025139047298580408, 0.004617323932637061, 0.020241700445434878, 0.016565338342583606, 0.06182304224265473, 0.0867956890059369, 0.020867905147107582, 0.03048870898783207, 0.002676230323101793, 0.009708742827310093, 0.08251593115606479, 0.042813707276114395, 0.05653771924387131, 0.02680317309152867, 0.015301086806825228, 0.10267893850271191, 0.01943995364542518, 0.11471310311130115, 0.09806967726243393, 0.23095844686031342, 0.0999831867271236, 0.1431094000914267, 0.25995838216372896, 0.14381262021405355, 0.12061282939144544, 0.12482094072869845, 0.1289053008492504, 0.145300918923957, 0.11800843557076794, 0.19986109196075372, 0.0788912106571453, 0.08963163968707834, 0.06705684068479709, 0.17487509841365473, 0.08274423104843923, 0.12774066334324224, 0.08641214708664588, 0.12854642367788724, 0.1150016433426312, 0.056032997755599875, 0.1525728872844151, 0.1596193513167756, 0.17885846538203104, 0.06508927912052188, 0.13924318897937024, 0.17522085271775723, 0.15893541515937873, 0.14556480119270937, 0.09125694818794727, 0.133628691679665, 0.1544973754457065, 0.1484214879040207, 0.07322931768638746, 0.15401439421943255, 0.17125884603176797, 0.1333568026976926, 0.13477264743830475, 0.16001168026455811, 0.1243684392954622, 0.13829585909843445, 0.11560541737292494, 0.11982765580926623, 0.38166292011737823, 1.51050580399377, 6.9157183681215555, 29.079816137041362, 54.16710008893694, 78.43831811632428, 89.64230918884277, 87.19944068363735, 81.78509167262486, 72.34641551971436, 60.32728263310024, 69.16890702928815, 52.28133119855608, 30.733275481632777, 34.85849741527012, 26.217521360942296, 38.76520892551967, 49.087428433554514, 62.47171211242676, 70.64511435372489, 80.3799227305821, 68.7579836164202, 81.00328731536865, 81.48668043954032, 56.29308557510376, 55.15611015047346, 54.111465862819124, 40.94465037754604, 26.003591537475586, 27.59541688646589, 18.12062052318028, 10.800389323915754, 9.52932322025299, 7.356254134859357, 3.391813733748027, 0.875449246593884, 0.9465907663106918, 1.0257763458149773, 0.23366357598985943, 0.19904455649001257, 0.2067909836769104, 0.23379692169172422, 0.1256451979279518, 0.13383493918393338, 0.5002834349870682, 0.49187595184360233, 0.6185827042375291, 1.8554080852440424, 5.461850370679583, 14.643059287752424, 27.12259370940072, 33.79205315453665, 34.94515882219587, 41.99636445726667, 55.63639048167637, 68.51221193586076, 88.46283163343156, 86.93927233559745, 79.96790150233677, 102.71854100908551, 61.17004353659493, 45.38013022286551, 34.27566167286464, 37.23103972843715, 36.89974267142159, 31.662395545414515, 44.555851527622764, 52.38122197559902, 56.48603357587542, 57.35312359673636, 75.30036572047642, 74.23633248465401, 91.08958421434674, 90.95621354239327, 90.38341099875313, 81.219605582101, 64.73469175611223, 30.577215467180523, 7.864578264100211, 0.9605516514607838, 0.2024748224232878, 0.1800645070948771, 0.141385785437056, 0.18163839621203287, 0.14840632943170412, 0.17730448448232242, 0.17817949610097067, 0.23649075999855995, 0.16551442284669193, 0.08811005883451019, 0.15376233203070505, 0.17022196309907095, 0.2060787526092359, 0.10396920676742281, 0.12580628214137896, 0.14816604661090033, 0.12072694541088172, 0.13125637040606566, 0.11612642370164394, 0.08556983407054629, 0.21050950485680783, 0.12724245579114982, 0.12318177654274873, 0.1704936892326389, 0.07937037173126425, 0.11869917064905167, 0.12626674957573414, 0.11256718183202402, 0.11274940919663225, 0.19018571185214178, 0.2039361832929509, 0.12551958752529963, 0.10027597458767039, 0.08678919542580843, 0.13752082282943384, 0.12517428105430944, 0.17489819574568952, 0.16896698544067995, 0.10689245776406356, 0.10043284509863172, 0.23269666358828545, 0.09254526227180447, 0.1705096619469779, 0.11716346948274545, 0.1588264831474849, 0.11415103184325354, 0.15610831257488045, 0.11159419654203312, 0.09595937907163586, 0.1310564332774707, 0.09953668354345219], [0.02941162624795522, 0.0336053017526865, 0.014595060941896268, 0.03047774386193071, 0.017197151136185442, 0.05017460443611656, 0.12615564625178063, 0.02825379105550902, 0.039747407526842186, 0.03325593085693462, 0.018927133841706172, 0.09416147840342351, 0.039417422376573086, 0.002955168011664812, 0.07737342281533138, 0.0436362308183951, 0.025643427823004977, 0.12317553402057715, 0.03441395603918603, 0.03350777252178107, 0.0646266471594572, 0.06676386961979525, 0.04134572051199419, 0.008287234863798534, 0.01613586808421782, 0.023002912190609744, 0.022197050075711947, 0.06029441819659301, 0.0085743001296318, 0.07817760894873313, 0.06112917233258486, 0.022614405091319765, 0.03575764197324004, 0.04208276221262557, 0.05302763384367738, 0.0293635418638587, 0.01447392038867942, 0.022888065049690858, 0.025406537677294443, 0.06653227883258037, 0.05994360880660159, 0.03498436989528792, 0.06674162724188396, 0.04270626464858651, 0.379909341356584, 2.701620940651212, 11.768744996615819, 35.63842575890677, 55.94561658586775, 62.62548964364188, 61.76071684701102, 54.515135356358115, 48.56687634331839, 51.64132915224348, 36.014719349997385, 27.26981908934457, 24.389672654015676, 16.537120853151592, 19.522235461643763, 26.861454350607737, 49.092083726610454, 53.83368730545044, 51.02423184258597, 63.75482899802071, 54.86458805629185, 56.16299792698452, 43.9477173941476, 42.601972920554026, 32.0787524495806, 26.779891184398107, 13.675092714173452, 8.077087180955068, 4.947254623685565, 1.9774631815297263, 0.7240907198616436, 0.2785003829215254, 0.43651780805417467, 0.09042102018637316, 0.03442734692777906, 0.04508311175076025, 0.06234728518341269, 0.05954167180295501, 0.032627838131572516, 0.02146864103685532, 0.016821054442386543, 0.03446747209610684, 0.04410082035298858, 0.06237703215863023, 0.11173710280231067, 0.023887094210035036, 0.04058623965829611, 0.03552553889208606, 0.07419456767716578, 0.03846987197175622, 0.056117237878165076, 0.21755997224577836, 0.22371488197573594, 1.146610513329506, 1.586115015404565, 5.463951766490936, 15.743106773921422, 17.651690074375697, 37.468383244105745, 46.29393993105207, 43.80235760552542, 51.98090846197945, 68.55210849217006, 59.657434599740164, 42.66065393175398, 34.1884583064488, 37.230275426592144, 20.20232687677656, 16.049138443810598, 16.374588591711863, 28.954366411481583, 36.737186091286794, 47.24186182022095, 55.75988776343209, 58.69214221409389, 57.72251067842756, 72.22062533242362, 69.59417847224644, 62.690309388296946, 38.34097971235003, 22.03337870325361, 8.031437516212463, 0.7299650960734912, 0.02360148185731045, 0.02326391407820795, 0.04071811293917043, 0.037439499582563124, 0.04554473269464714, 0.07484266361487762, 0.03557126875966787, 0.02479258901439607, 0.06319208842303072, 0.021319059688331823, 0.1139554101973772, 0.03769376701010125, 0.017495214606502225, 0.03216632575328861, 0.005595439795537719, 0.023038898295323764, 0.05727539876742022, 0.035777465373809846, 0.014987109993983592, 0.028929282844598805, 0.013294798704529447, 0.02680843343426074, 0.07536189896719796, 0.08850671683571168, 0.02302033357721354, 0.03863563807681203, 0.028478050271847417, 0.022441183582746556, 0.020749103843367527, 0.0699414491121258, 0.02881789792861257, 0.071906099761171, 0.05447054534618344, 0.034309051132627895, 0.010802264774351247, 0.03257359264950667, 0.06123034190386534, 0.027279723502163376, 0.02209751577382641, 0.045094409358820746, 0.02656169096007943, 0.0049171049447198, 0.02384411749829139, 0.04441318055614829, 0.04619423998519778, 0.03415599738114646, 0.028170146347422684, 0.025697283147435104, 0.036486093420535326, 0.029982270805963447, 0.01978086320949452, 0.018120184374440993, 0.02225353302700179, 0.02321827581285366, 0.07037018146365881, 0.02328398005504693, 0.030831196145819764, 0.052381627793822966, 0.03021693874948791, 0.001214446747326292, 0.01130516524426639, 0.09146483774696078, 0.05706147703209093, 0.04964916727372578, 0.02763363379719002, 0.026743814848097305, 0.06323780132723705, 0.0029360797613792655, 0.030266692329730307, 0.0253074579938714, 0.009200506527642054, 0.02558706870435604, 0.025197655760816166, 0.015332039878038424, 0.026262494336281503, 0.029009882626788955, 0.02392803701306028, 0.0586106131917664, 0.03697614498170359, 0.02791608078405261, 0.020560194605163166, 0.0570650596969894, 0.028304623506431068, 0.10036330882992063, 0.026927879346268516, 0.02769437794839697, 0.010797028180344828, 0.029625483522457734, 0.05574503427903567, 0.10988254446004118, 0.04086826934612223, 0.011178543824436409, 0.0501792524009943, 0.3344264605215618, 3.586076681103025, 15.887717894145421, 43.109820229666575, 65.99152360643659, 73.29922199249268, 71.08899307250977, 68.9881704875401, 61.50915036882673, 62.83498477935791, 50.70327370507376, 37.70489992414202, 42.43765844617571, 30.64139597756522, 29.198335034506663, 27.812285797936575, 30.66283811841692, 45.26080880846296, 42.62954337256295, 48.83907202311924, 51.08445187977382, 51.39230571474348, 43.38201590946743, 43.64223984309605, 34.575354848589214, 27.49271556309291, 17.288109949656896, 9.894272140094213, 5.755268020289285, 2.8449288393769945, 0.9261449319975716, 0.38747487110751017, 0.47131585223334177, 0.024589004760075892, 0.07793294279170887, 0.0651647729266967, 0.046616621248956235, 0.05259880988991686, 0.013824958470650017, 0.06285219666148935, 0.05283467884042433, 0.1265145777059453, 0.031304165587893555, 0.11961817847830908, 0.13107501156628132, 0.01955687371082604, 0.07005938528371708, 0.11398825129227978, 0.11520258470305375, 0.04618281006280865, 0.09187972798411335, 0.0682705430580037, 0.11777409671672753, 0.729221584541457, 1.4231903978756495, 3.396538074527468, 9.450248377663748, 16.46649067742484, 32.903545311519075, 42.2278402192252, 43.04201275961739, 43.083066190992085, 57.64429480688912, 43.139996256147114, 40.03896311351231, 31.03638369696481, 39.3163400377546, 30.696873869214738, 26.95229857308524, 21.555080345698766, 38.00463826315743, 49.904755456107004, 52.9865733555385, 65.07778685433524, 66.01808656964982, 69.27142769949776, 80.84542424338204, 79.23089218139648, 71.06211049216134, 47.40486308506557, 27.153527089527675, 9.961154631205968, 0.80670094702925, 0.010932049863705677, 0.011554047648262764, 0.07557117952299969, 0.04821658307420356, 0.031256759738815684, 0.048710617635931285, 0.06822848067219768, 0.08087521991027252, 0.03182323469913431, 0.01781502682050424, 0.03029288038877504, 0.030942883009889295, 0.022392651365537728, 0.025599857393120016, 0.01435467803717724, 0.037683225968586545, 0.021623732089730244, 0.04751462841938649, 0.03487266606784292, 0.007760073374291616, 0.026182851288467646, 0.03341065380456192, 0.050114007866276164, 0.029082061789397682, 0.012298727108697807, 0.04271835953529392, 0.04768539532752974, 0.012503258767537773, 0.000721316333510913, 0.0518899239998843, 0.013200445017511291, 0.03881937518183674, 0.05722760954605682, 0.018182529868291955, 0.030242655226694684, 0.033186157100967, 0.059787946087973456, 0.0695643804169127, 0.04141448325078402, 0.046893514426691194, 0.037132849251585345, 0.01874668593518436, 0.031041847342359166, 0.017853820363857915, 0.013766433977122818, 0.01863780990242958, 0.04827596167368548, 0.025469078249963265, 0.02231693364280675, 0.11536569095083646, 0.14420878967004164, 0.11922774942857878, 0.10570284338401896, 0.10950524506292172, 0.17445865433130944, 0.24287582880684308, 0.1165513630424227, 0.16670432899679455, 0.11352930377636637, 0.0840354221207755, 0.15170996715979918, 0.14066560193896294, 0.1961254309862852, 0.22214860602148942, 0.25166182592511177, 0.11898439962949071, 0.19144030953092234, 0.1271385992211955, 0.11933795708630766, 0.1529736572078296, 0.10070309202585902, 0.15359234543783323, 0.04979834319757564, 0.15690309421292373, 0.10430914602641549, 0.09023640437849931, 0.1469642118151699, 0.17520759414349282, 0.14534810424915381, 0.1508523260376283, 0.07310387691748993, 0.1636902628732579, 0.17012223202203, 0.2018839812704495, 0.07076124155095645, 0.09156855182456118, 0.08531967177987099, 0.08052933668451649, 0.16395840634192738, 0.20194609436605657, 0.14877360686659813, 0.1412417460232973, 0.17874590999313764, 0.6328703718526023, 5.523826565061297, 22.449021680014475, 53.523012501852854, 77.91353457314628, 81.60614776611328, 79.96084908076695, 75.93325628553117, 68.42968123299735, 69.8681389944894, 53.79191473552159, 41.753875800541465, 36.64743273598807, 29.036252668925695, 28.270326682499476, 38.370134353637695, 64.4285888671875, 69.4461054120745, 64.32226058415004, 79.17256205422538, 67.9544244493757, 71.22837393624442, 57.32440321786063, 56.36553791591099, 43.29152257101876, 36.089905806950156, 21.355792113712855, 12.043555804661342, 7.83127989087786, 3.8507967506136214, 1.4112942133631026, 0.8052497506141663, 0.7473005801439285, 0.24471520153539522, 0.17263571572090897, 0.11269321971173797, 0.23102991016847746, 0.1818497870117426, 0.07593377506626503, 0.19538715774459497, 0.13183794277054922, 0.20572755645428384, 0.17905514554253646, 0.22698247592364038, 0.26885264632957323, 0.20850527526012488, 0.21977392344602517, 0.19020329947982514, 0.2175358028284141, 0.17393500171601772, 0.23101783224514552, 0.22781243281705038, 0.2336149385997227, 2.080233118363789, 2.4268140409673964, 7.540254592895508, 20.55779150554112, 24.201551914215088, 46.05469260896955, 56.98795754568917, 54.817333357674734, 67.97961861746651, 90.51841449737549, 76.37467534201485, 59.987821442740305, 49.024460383823936, 53.97472184044974, 33.29263053621565, 25.076748745782034, 26.215607132230485, 42.45629698889596, 52.29913943154471, 64.19494874136788, 74.34051377432687, 75.84167902810233, 76.62374741690499, 89.5265452521188, 86.30638177054269, 86.58892331804547, 62.947691508701865, 37.67938266481672, 14.009137783731733, 1.8995393514633179, 0.06752310280821153, 0.132370402770383, 0.1636274712426322, 0.21484524863106863, 0.197769290634564, 0.28135777530925615, 0.1275945883244276, 0.16855025637362683, 0.14934631756373815, 0.10158802382647991, 0.2527600484234946, 0.14605289857302392, 0.09073516154395682, 0.11905188672244549, 0.0887884513608047, 0.08319476473012141, 0.10051955508866481, 0.12232101415949208, 0.11843957672161715, 0.11949988268315792, 0.08883678341018302, 0.07720393833837338, 0.1624082252383232, 0.16685809860272066, 0.0810037480135049, 0.13170366069035871, 0.08965916106743471, 0.05351608406220164, 0.1066210912540555, 0.16570423623280867, 0.18218222845877918, 0.12604740634560585, 0.11589053778776101, 0.13777004874178342, 0.16174982913902827, 0.1274997562702213, 0.19384005718997546, 0.13468183231140884, 0.1503451211111886, 0.08873855189553329, 0.14461498787360533, 0.13658734863357885, 0.07147427328995296, 0.1123495688661933, 0.16117068592991146, 0.07837935098047767, 0.14239535054990224, 0.11087745321648461, 0.08524529077112675], [0.03349685489333101, 0.06426192780158349, 0.029101291471826177, 0.016167129888864498, 0.06607591653508799, 0.0181345387827605, 0.029651539267173836, 0.0532169892186565, 0.02883252375093954, 0.04369652883282729, 0.007638885323623461, 0.018852259198735868, 0.04244629413421665, 0.012228478378217136, 0.020585113803723028, 0.02770871200066592, 0.017848163078139936, 0.0282725033549858, 0.020580506550946405, 0.05478022872869458, 0.02227460323566837, 0.011564990721776016, 0.02668858040124178, 0.035310260086719475, 0.028552665375173092, 0.04191095714590379, 0.02044863666274718, 0.03353443555533886, 0.013952059105836918, 0.043545941556138654, 0.040025321899780204, 0.012479029130190611, 0.02514262148179114, 0.03997218242979475, 0.05695642624050379, 0.07091748102435044, 0.031611066976828237, 0.10290417141680207, 0.08317351301333734, 0.07645140229059116, 0.04989250689478857, 0.07891759888402053, 0.3107202925852367, 1.816328485097204, 13.025989396231514, 30.668163912636892, 58.79770619528634, 59.546395438058035, 69.85247775486538, 57.41362156186785, 57.441702706473215, 61.77030536106655, 40.6147255897522, 25.330983332225255, 21.919299704687937, 20.62778765814645, 10.67335193497794, 27.996411323547363, 55.19376591273716, 69.48677321842739, 98.4047519138881, 74.21946920667375, 64.57174955095563, 54.4386739049639, 39.14932271412441, 26.461293697357178, 17.855545009885514, 10.3601827280862, 6.319435255868094, 3.2213055917194913, 1.081081509590149, 0.3587629874902112, 0.1378355816538845, 0.08609512195523296, 0.1079513727288161, 0.16193012946418353, 0.06018195101725204, 0.014845755882561207, 0.1035106528018202, 0.05401969275304249, 0.05708360405904906, 0.03263609929542456, 0.05619894027976053, 0.021568704596055404, 0.12773841060698032, 0.061306792444416454, 0.06003401002713612, 0.03184409625828266, 0.07235239938433681, 0.025325276323461106, 0.014184520114213228, 0.039272717998496125, 0.09233447536826134, 0.07357639513377633, 0.11433990885104452, 0.17813967966607638, 0.02978187905890601, 0.050220375015799484, 0.041994647655103884, 0.12002373885895525, 0.5318714657000133, 1.4313200073582786, 1.9407304440225874, 3.6006553045340945, 9.646607943943568, 19.291364192962646, 29.651809215545654, 44.64633444377354, 46.13368667875017, 51.31063311440604, 35.53406034197126, 31.122305120740617, 26.869215488433838, 33.510206426892964, 14.902145453861781, 15.922295604433332, 33.495372022901265, 40.19093063899449, 38.9088316644941, 51.51906170163836, 57.92959131513323, 51.835923876081196, 72.0075796672276, 69.67147023337228, 64.85267216818673, 38.20595536913191, 22.41650411060878, 4.086299862180438, 0.5821311516421181, 0.09821102289216858, 0.06068488795842443, 0.04177351648520146, 0.022418622293376496, 0.013454999974263566, 0.02414750407582947, 0.10760950643037047, 0.05635392107069492, 0.043800683958189826, 0.04085024067067674, 0.035820420033165386, 0.08327662998012134, 0.019070443830319812, 0.020782029755147438, 0.013000827648543885, 0.03867071494460106, 0.04672088833259685, 0.04153071629947849, 0.0584488572286708, 0.04343016991125686, 0.049699901337070126, 0.09009609690734319, 0.012915858100833637, 0.07960879536611692, 0.0301137267878013, 0.03863236414534705, 0.04023306896643979, 0.04814201546832919, 0.0100705037725025, 0.008771883589880807, 0.009555157274007797, 0.037420938257128, 0.020135145002443875, 0.023286952038428614, 0.03785411501303315, 0.024227876548788378, 0.03962749003299645, 0.04070834882025208, 0.06566367258450814, 0.03892870752939156, 0.018060756581170217, 0.003927151190250048, 0.03902982621054564, 0.04289586768884744, 0.04701645140136991, 0.046343422694397826, 0.006606648659466633, 0.030678820929356983, 0.020787831229556884, 0.04861876435045685, 0.0375422297843865, 0.03593180834182671, 0.029143096014325107, 0.011786589232672538, 0.009106733836233616, 0.04968460376507469, 0.02671155390063567, 0.06307544825332505, 0.11625599674880505, 0.03500935694734965, 0.05821812139557941, 0.09614813394312348, 0.06193547549524477, 0.061429519073239396, 0.03947255334683827, 0.02281931079258876, 0.05845974093036992, 0.03695372279201235, 0.02138726263573127, 0.032036973230008564, 0.018466785150979246, 0.04227255524269172, 0.05388576351106167, 0.012942463458914841, 0.01500873320869037, 0.01806585068282272, 0.026318224113700644, 0.057687154172786644, 0.011584443472591894, 0.037874233576336076, 0.02250593787591372, 0.06034104033772435, 0.009196935737106417, 0.033856383458312066, 0.04443158581852913, 0.08662344967680317, 0.0278859385621867, 0.11867578833230905, 0.09601094094770295, 0.2500319576689175, 2.7551652789115906, 14.987292153494698, 38.29893963677542, 67.37115791865757, 69.28255871364048, 78.27796064104352, 65.22909082685197, 63.934405190604075, 65.72946534837995, 45.40053013392857, 42.39955799920218, 35.69859715870449, 29.42948075703212, 16.867214134761266, 32.812450953892295, 45.07259947913033, 62.805114473615376, 75.20975426265171, 63.889992305210654, 53.3772531918117, 49.20284148624965, 38.174198627471924, 28.097570146833146, 20.1454975605011, 11.9500504221235, 8.000220996992928, 3.919593036174774, 1.7434093121971403, 0.5792473778128624, 0.14511329042060034, 0.005984521105087229, 0.04579328346465315, 0.3728451132774353, 0.07778685420219388, 0.1139245368540287, 0.04700431240988629, 0.05062559273626123, 0.07000907869743449, 0.022112862539610693, 0.08432787071381297, 0.09536667873284646, 0.5175123076353754, 0.22139480789857252, 0.03780460570539747, 0.06889253575354815, 0.04561384827164667, 0.04097876538123403, 0.03637253719248942, 0.052306520752608776, 0.05869465653917619, 0.07125620570565973, 0.057883569704634805, 0.0904867227322289, 0.04435547793816243, 0.09682717786303588, 0.012431887061601239, 0.27003587569509235, 0.4987065738865307, 1.0297549494675227, 1.4417762862784522, 3.090374605996268, 8.334186162267413, 17.789269617625646, 26.61701672417777, 37.75682381221226, 42.021054880959646, 46.873631613595144, 36.60685525621687, 28.757339818137034, 25.830105440957205, 44.323663575308665, 28.385300261633738, 23.4295688356672, 45.13284730911255, 48.842907428741455, 52.88290275846209, 58.77066380637032, 68.77352673666817, 60.862189701625276, 79.88555145263672, 78.08543995448521, 75.59639372144426, 47.560631275177, 27.007227557046072, 5.175869899136679, 0.5906444319656917, 0.061660892729248316, 0.050662084349564145, 0.06375051595802818, 0.03633317876873272, 0.006724595433167581, 0.07281950289117438, 0.07752572678561721, 0.039059915845947604, 0.0776669027815972, 0.053684204683772156, 0.048976152137454064, 0.03907123381005866, 0.021276859899184535, 0.050386989289628606, 0.023508412297815084, 0.005789196318281549, 0.046628349726753573, 0.053556409398359914, 0.021818127283560376, 0.029525263900203363, 0.06918539825294699, 0.06665515473910741, 0.010179201689814883, 0.04680287232622504, 0.03066925358559404, 0.04926574409806302, 0.011462144320830703, 0.03735798038542271, 0.06075773547802653, 0.04137579657669578, 0.03443992357434971, 0.028456254030710885, 0.08220003239278283, 0.03810881670298321, 0.12178938197238104, 0.043666079573865445, 0.030072495607393127, 0.03878333818699632, 0.015229810095791305, 0.030985169312251464, 0.03355439805558749, 0.03640550720904555, 0.01856396663268762, 0.0379668977111578, 0.008732565878225225, 0.04323324887081981, 0.01960893431013184, 0.13802888270999703, 0.15099267422088555, 0.13318883813917637, 0.10033163481525012, 0.10830679615693432, 0.11299752231155123, 0.15295521462602274, 0.18077656174344675, 0.2429796446646963, 0.11439812715564456, 0.15792537507201942, 0.18276614855442727, 0.1430661774107388, 0.24142832362226077, 0.21973021222012384, 0.14022234215268067, 0.13650151395371982, 0.11507858921374593, 0.08015254618866102, 0.1289651340671948, 0.10987770650535822, 0.14629772757845266, 0.12495246795671326, 0.21404540512178624, 0.12659920459347113, 0.19451598663415226, 0.12075149480785642, 0.11961969839675085, 0.13496472713138374, 0.19130730309656688, 0.11225882837814943, 0.08924558040286813, 0.08023709843733481, 0.10023312510124274, 0.14337454443531378, 0.156502134299704, 0.18103908694216184, 0.18670364655554295, 0.185828282098685, 0.23144992334502085, 0.2268984325762306, 0.1474330523716552, 0.48179639556578224, 4.8268901109695435, 21.594593014035905, 50.023771149771555, 81.92762007032121, 78.25172424316406, 86.17016928536552, 76.30448463984898, 74.31893961770194, 73.90302739824567, 55.409347670418875, 40.8057176726205, 33.022071157182964, 30.789993626730784, 17.206578050340923, 39.12095321927752, 67.65296295710972, 81.47299943651471, 115.89357621329171, 88.5520326069423, 81.62025260925293, 68.23447854178292, 50.87480388368879, 37.09433044706072, 24.378168174198695, 14.609952858516149, 9.750268118722097, 5.129849808556693, 2.3762565595763068, 1.174772865005902, 0.31358308611171587, 0.17201364838651248, 0.2903421217841761, 0.7835756593516895, 0.13889708183705807, 0.24140226787754468, 0.3908794884170805, 0.3302323270056929, 0.1779213406677757, 0.12114683645112173, 0.4090007431805134, 0.1376958577228444, 0.6079350241592952, 0.47759686091116493, 0.26590680011681145, 0.19711229231740746, 0.1689679761018072, 0.2165053795490946, 0.09498534883771624, 0.15755375501300606, 0.2404651024511882, 0.19274096616676875, 0.3363823784249169, 0.5485470880355153, 0.31828606660876957, 0.2028579232948167, 0.16330832908196108, 0.4785705315215247, 1.1949574904782432, 2.14054673910141, 2.9608562758990695, 4.657841742038727, 13.971856355667114, 24.094811950411113, 38.22410406385149, 58.65586566925049, 62.69962692260742, 68.18377753666469, 51.482521125248496, 45.44257715770176, 39.16420228140694, 50.13941696711949, 27.02432359967913, 29.476471424102783, 48.354421275002615, 54.50652306420462, 56.193497044699534, 67.83564499446324, 75.21664687565395, 68.84227221352714, 89.10116958618164, 88.8792371749878, 89.81138665335519, 59.10361453465053, 35.51960808890206, 8.332160762378148, 1.1280828160899026, 0.21460507437586784, 0.11559154811714377, 0.1479558500328234, 0.1347013876906463, 0.09710683607097183, 0.19622510778052465, 0.20418832690588065, 0.10027955046721868, 0.17947690933942795, 0.1569786694433008, 0.1646092842732157, 0.11206832288631371, 0.19027173652180604, 0.11264644150755235, 0.10792664691273655, 0.12279822783810751, 0.16087302618793078, 0.2073746866413525, 0.2659594001514571, 0.18823447584041528, 0.16357677110603877, 0.1813857911952904, 0.10338732227683067, 0.14372769477111952, 0.10301310342869588, 0.10101455317011901, 0.13613179379275867, 0.15570870973169804, 0.13308400447879518, 0.1815305362854685, 0.18460751617593424, 0.12768202434693063, 0.14138050643461092, 0.1304643979029996, 0.12617445524249757, 0.20465377478727273, 0.11300132210765566, 0.12061288367424693, 0.2158168429242713, 0.12651227068688187, 0.0926071514508554, 0.10727936521704708, 0.15419488453439303, 0.11455208675137588, 0.1113622732726591, 0.14809971302747726, 0.14517452142068318], [0.011476054288712996, 0.014378755852313978, 0.037691270001232624, 0.03428500724424209, 0.015615158614569476, 0.030819226788090806, 0.030803233717701266, 0.035738724416920116, 0.016110090538859367, 0.019829929773030535, 0.04735523036548069, 0.021068882130618607, 0.0550596460566989, 0.029491608563278402, 0.03535323849480067, 0.06463511527648994, 0.06303474293755633, 0.015470725650499974, 0.004874351301363536, 0.014217490130769355, 0.013871250674128532, 0.036425853081579716, 0.04367913458762424, 0.05139715151329126, 0.010011376230977476, 0.035303529019334486, 0.02180352690629661, 0.00464896486872541, 0.020377200495983874, 0.03714091024760689, 0.027296517243874923, 0.034259796275624206, 0.09438153409532138, 0.0628587988072208, 0.028692660720220635, 0.06534597570342676, 0.0065916954439931685, 0.012558414334697383, 0.06774984207004309, 0.14564146207911627, 0.09254723002335855, 2.1630810499191284, 10.777892793927874, 33.16677434103829, 48.52773714065552, 62.442029408046174, 52.22226456233433, 65.76883384159633, 52.068584305899485, 49.52967432567051, 51.58814416612898, 91.62707601274762, 81.96581431797573, 11.146848218781606, 21.016014780317033, 24.777689593178884, 53.284459999629426, 58.06306273596627, 66.49273191179547, 49.054636410304475, 39.02177810668945, 26.756413221359253, 17.056924274989537, 9.913148658616201, 5.366299612181527, 2.803437888622284, 1.6703411872897829, 0.6459607779979706, 0.21565065612750395, 0.21852362767926284, 0.10121383890509605, 0.072526511470122, 0.03967651758076889, 0.06462467940790312, 0.7501532499279294, 0.0781856020912528, 0.07600198140633957, 0.07130143006465264, 0.06025031342038086, 0.05817067144172532, 0.22818405287606375, 0.030250176787376404, 0.07360835413315467, 0.07313601912132331, 0.3872345340039049, 0.27905053911464556, 0.02602909186056682, 0.09491712214159113, 0.07989667741847889, 0.09758753741958312, 0.051552909226822, 0.05851338590894427, 0.03645629555519138, 0.13493997417390347, 0.09857496193477086, 0.09035579940038067, 0.0867183224431106, 0.06512513969625745, 0.08666266900088106, 0.016084538606394614, 0.09788687314305987, 0.058829033614269326, 0.0172524703999183, 0.4149288593658379, 0.4391840978392533, 0.521780292902674, 3.589351236820221, 7.760265827178955, 21.43466980116708, 25.93373261179243, 42.66429826191494, 56.14376531328474, 54.67500993183681, 17.338150875908987, 24.54801688875471, 28.962775468826294, 18.149891546794347, 21.51579523086548, 18.379901238850184, 35.8810499055045, 37.64005586079189, 42.02392448697771, 62.999802998134065, 57.76704863139561, 61.64069366455078, 64.8942779813494, 59.153412273951936, 33.56936338969639, 12.72343703678676, 0.947911792567798, 0.1253318911684411, 0.35913292478237835, 0.0979558869398066, 0.04306482969384108, 0.05784793304545539, 0.018170465515660386, 0.003536692454612681, 0.012568818821039583, 0.047946604168308635, 0.027821394614875317, 0.008907327661290765, 0.016338244546204805, 0.07346147165766784, 0.012895804846526256, 0.03322812109919531, 0.06320099758782557, 0.02897073794156313, 0.032717486178236346, 0.04605060429977519, 0.03207410266622901, 0.030207568180880377, 0.04189348826184869, 0.0473518648317882, 0.024566316245389835, 0.03093071687700493, 0.038140969084841866, 0.05737450559224401, 0.014566776209643908, 0.008295590174384415, 0.022475980554840395, 0.021565347544050643, 0.04677469276690057, 0.02383970532433263, 0.019263714352356534, 0.03562590439936944, 0.02454017398745886, 0.022358227587704147, 0.04785524282072272, 0.04075507274163621, 0.048751136354569874, 0.045555789422776015, 0.018670640819306885, 0.04548095040289419, 0.04300826022933636, 0.04012388250391398, 0.050649436456816535, 0.01275067892856896, 0.09986567803259407, 0.04670858310003366, 0.034088113345205784, 0.017579597221421342, 0.04613175708800554, 0.025346541610945548, 0.03309115880568113, 0.02941836749336549, 0.007306309017751898, 0.03897692083514162, 0.04459040711766907, 0.05905206807489906, 0.03519691081185426, 0.03800904830651624, 0.042246882870261154, 0.034198694197194915, 0.020181321006800448, 0.01741706603206694, 0.025839249636711817, 0.04214022395067981, 0.04176573708121266, 0.05382323311641812, 0.012310053554496594, 0.020282378619802848, 0.00564794525936512, 0.03973121089594705, 0.04389044057045664, 0.025155106526134268, 0.019120541767084172, 0.009221031363787395, 0.06966441004936184, 0.03432849455358727, 0.04161856622834291, 0.03122337581589818, 0.08095920897488083, 0.03663784099210586, 0.027986565305452262, 0.040198728309146, 0.08753875270485878, 0.09194688938025918, 3.0760291814804077, 14.640523195266724, 40.45929091317313, 56.60311419623238, 72.07697827475411, 60.547471046447754, 73.46304661887032, 61.453801018851145, 58.702536719185964, 64.85496507372174, 91.90619209834507, 81.14810167040143, 17.94794910294669, 26.044436522892543, 30.077122347695486, 32.81769684382847, 39.314613410404746, 48.60628652572632, 45.39568376541138, 42.11986173902239, 30.319638797215053, 20.332834890910558, 12.037083557673864, 6.662008370671954, 3.5586894878319333, 1.8792417091982705, 0.7331257121903556, 0.16824179435414927, 0.22338651173881122, 0.05824387179953711, 0.07306317160172121, 0.07008054879094873, 0.1564580159527915, 1.2277149898665292, 0.060664111216153414, 0.2194180725408452, 0.017045160988345742, 0.07909785171172448, 0.08439753590417759, 0.24523352086544037, 0.1383733342268637, 0.047981043213180134, 0.28058761092168943, 1.0744011423417499, 0.5369643867015839, 0.36030204061950954, 0.16944075216140064, 0.24030749233705656, 0.04683209004412804, 0.2867782658764294, 0.41003580763936043, 0.07493613181369645, 0.1302834190428257, 0.07794925477355719, 0.04849431424268654, 0.16072233713098935, 0.15674834751657077, 0.05684598788086857, 0.12534058998738015, 0.021088929447744573, 0.08373650030366012, 0.10103857330977917, 0.29293947241136004, 0.41097408586314743, 0.5824661308101245, 3.3452464725290025, 6.786728969642094, 18.837024961199077, 27.443770715168544, 38.09595496313912, 44.80705322538103, 45.731365135737825, 21.417281934193202, 21.170700788497925, 31.935713359287806, 26.929472003664287, 36.667068345206125, 28.522648777280533, 47.085739271981375, 47.82241160529, 49.181541783469065, 71.6832447052002, 65.84588241577148, 71.53048161097935, 73.07874870300293, 69.15030670166016, 40.60180541447231, 16.601560183933803, 1.557211486356599, 0.04692151417423572, 0.4300243364913123, 0.174632997119001, 0.014084718639164098, 0.017541176872327924, 0.06348361420844283, 0.006770660751499236, 0.040168024599552155, 0.024022209191960946, 0.056207832481179915, 0.05621399697182434, 0.048657790292054415, 0.01677121265259172, 0.030360323376953602, 0.06362030508794955, 0.0394645568116435, 0.06362025080514805, 0.06273512222937175, 0.03319868625008634, 0.034548916654395204, 0.03325077738346798, 0.05381806607225111, 0.03844188579491206, 0.05511063117800014, 0.07991777307220868, 0.04268315713852644, 0.07139825701181378, 0.04379875352606177, 0.03602934096540723, 0.00650225010966616, 0.05993074378264802, 0.012609977907102023, 0.011430330358312597, 0.052447086067071984, 0.008671931988958801, 0.02587881331731166, 0.023020336969888637, 0.020767805964819024, 0.020105428561302166, 0.020635785102578144, 0.00744481582660228, 0.03870733208688242, 0.0284398046455213, 0.07016157265752554, 0.005924169231937932, 0.024821961099015813, 0.06714028013604027, 0.2579016610980034, 0.10696256400219031, 0.15546791122428008, 0.04524958353223545, 0.13490846300763742, 0.1452628666801112, 0.08664095588028431, 0.13220037546541008, 0.1115423496812582, 0.1295443722712142, 0.10649944349591221, 0.1469832786491939, 0.09871759678104094, 0.11640079612178461, 0.09395298494824342, 0.13690692505666188, 0.11020322010985442, 0.05242073855229786, 0.0848615113645792, 0.18042589484580926, 0.12171919431005206, 0.150457785065685, 0.1874110193124839, 0.11956252503607954, 0.14118568546005658, 0.10313802851097924, 0.0947002691349813, 0.1200229110462325, 0.16736862835075172, 0.10294324824852602, 0.21339873410761356, 0.19395216474575655, 0.06897864184741463, 0.07394308224320412, 0.16233064154429094, 0.16247641800769738, 0.14577901469809668, 0.17405442387929984, 0.25232510747654097, 0.3045082502067089, 4.489307539803641, 20.230489662715367, 50.51435218538557, 67.56154550824846, 82.85187639508928, 68.61826229095459, 81.80469948904855, 70.08489499773297, 66.29219995226178, 66.04208564758301, 97.47401986803327, 88.81942013331822, 21.108943462371826, 32.05797733579363, 38.34744848523821, 70.62464496067592, 75.41845730372837, 82.9530838557652, 63.60040528433663, 52.184132848467144, 37.31128099986485, 24.155382871627808, 14.384189384324209, 7.672605616705758, 4.237010197980063, 2.407699763774872, 1.0854074146066393, 0.537547981100423, 0.3786589913070202, 0.18017031784568513, 0.2722245582512447, 0.26657078734466005, 0.38966469360249384, 1.5510007739067078, 0.2898391916283539, 0.3050276551927839, 0.18672408403030463, 0.21469758584031037, 0.12013419078929083, 0.44306341824787004, 0.4419606088527611, 0.2388471221285207, 0.37706817952649935, 2.060595120702471, 1.5582905198846544, 0.36435107620699064, 0.4141945759100573, 0.5974529609084129, 0.22956261890275137, 0.29178072458931376, 0.326743164232799, 0.374567343720368, 0.2680825633662087, 0.25678566098213196, 0.09868635702878237, 0.3215425190116678, 0.28512285756213324, 0.23843592990721973, 0.21198181728167192, 0.1842251888343266, 0.2929230790053095, 0.461134027157511, 0.8645231500267982, 0.903147643165929, 1.3353024167673928, 5.437662822859628, 10.69899252482823, 27.412811279296875, 35.235121045793804, 58.988656588963096, 74.49996798379081, 75.09380272456578, 27.58150485583714, 36.8584634235927, 43.247717653002056, 27.329921007156372, 33.43056617464338, 30.43141794204712, 51.5820505959647, 52.144979749407085, 58.120941230228965, 79.91503960745675, 73.84896346500942, 77.98002883366176, 83.8499503816877, 78.54381261553083, 50.52259969711304, 23.120778730937413, 3.0342926553317477, 0.27738033873694284, 0.4953964629343578, 0.2116044975285019, 0.20321716687508992, 0.11687125159161431, 0.19762044719287328, 0.14010743903262274, 0.09212748826082263, 0.14212806203535625, 0.2132407711552722, 0.17982396643076623, 0.1474657849009548, 0.12218792630093438, 0.20317762185420307, 0.19345243727522238, 0.26612452843359535, 0.1088664246989148, 0.16355370091540472, 0.1538099516183138, 0.1889581470085042, 0.1215687088136162, 0.11077479086816311, 0.13288205888654503, 0.16190130529659136, 0.10750307142734528, 0.13414497540465423, 0.17529528800930294, 0.14093715165342602, 0.1117762949849878, 0.10303935594856739, 0.1635864470154047, 0.09540848327534539, 0.08741538825311831, 0.1822717815105404, 0.07701468135097198, 0.11825378026281085, 0.15661200268992356, 0.07652745249548129, 0.15845951783869947, 0.09942868790988411, 0.08987762220203876, 0.08922354837081262, 0.21452499367296696, 0.16513189194457872, 0.11292400982763086, 0.11829964923007147], [0.019423643359914422, 0.008454722751464163, 0.010782436284768795, 0.047803864149110656, 0.07444077410868236, 0.06180395505258015, 0.03985850406544549, 0.03507839110014694, 0.025996320315503647, 0.013912939865674292, 0.035761601225073845, 0.08390906532960278, 0.03542416576029999, 0.028701420607311384, 0.034601414908788035, 0.023593982349016836, 0.049258341281009574, 0.05946499056049755, 0.03321957155796034, 0.054931453828300746, 0.040771679886217625, 0.02229005517438054, 0.012695949142133551, 0.05359735220138516, 0.10952983517199755, 0.022609746948416744, 0.030554777942597866, 0.019712485539327775, 0.026331402960100343, 0.044903357646295, 0.0051620039240723205, 0.11496733661208834, 0.021060760066445385, 0.03888864003654037, 0.04074028067822967, 0.044083073269575834, 0.027688094714124287, 0.08809219979281936, 0.12196381975497518, 1.7725662333624703, 13.46135744026729, 28.383816821234568, 53.97527769633702, 66.66154534476144, 64.97156279427665, 58.02772419793265, 63.07210595267159, 58.15072815758841, 43.24646002905709, 31.45849370956421, 12.079629114695958, 18.067063808441162, 30.90033449445452, 35.75414105824062, 48.709845951625276, 53.13014398302351, 58.48648943219866, 47.18946892874581, 30.65282576424735, 19.864757333483013, 11.35727788720812, 5.404406573091235, 2.1798893937042783, 1.0036372137921197, 0.2636075977768217, 0.08729922984327589, 0.023929098920364465, 0.009263478818216493, 0.06730361030037914, 0.08789847804499523, 0.0702860974041479, 0.07015227672777005, 0.020788056842450584, 0.6250633107764381, 0.07999499035733086, 0.040462481656244824, 0.08976282086223364, 0.1769313309341669, 0.07099011819809675, 0.2561520178403173, 0.20001103462917463, 0.334394705082689, 0.022170273387538533, 0.35522374883294106, 0.9900579367365155, 0.2403208730476243, 0.3129950405231544, 0.14276869408786297, 0.11791717261075974, 0.21658494456538133, 0.39518547164542334, 0.24447084750447953, 0.029244523428912674, 0.168558412364551, 0.044247217675937076, 0.0343013701162168, 0.18314767522471292, 0.07011780714882271, 0.08099329178886754, 0.057013029631759436, 0.0700284033747656, 0.03564107304971133, 0.058288906168724806, 0.03671966553000467, 0.031734027700232606, 0.14952262810298375, 0.018094764756304876, 0.3033961041697434, 1.0236437916755676, 6.204030888421195, 12.327949047088623, 29.811253002711705, 50.53594718660627, 74.88850430079869, 60.74193722861153, 42.44646528788975, 43.58253397260393, 17.05982862200056, 32.46933501107352, 43.458004883357454, 69.69747039249965, 33.62501846040998, 46.1450435093471, 43.89616870880127, 53.98670053482056, 57.536722796303884, 60.940634863717214, 64.32016917637416, 50.850068296704976, 31.47454752240862, 11.29344391822815, 1.8242536655494144, 0.02283047778265817, 0.07578337777938161, 0.005058034123586757, 0.08958142131034817, 0.01670407839784665, 0.02000538875082774, 0.04372389754280448, 0.01631961197459272, 0.03338662687955158, 0.03331944173468011, 0.04393376163872225, 0.061087333863334994, 0.0435004322124379, 0.06944460541542087, 0.059897027377571375, 0.03643909129979355, 0.046930162103048394, 0.03152780394468989, 0.04446554310353739, 0.07008232655269758, 0.013944335680987154, 0.03203594185678022, 0.025613541748108606, 0.03405829851648637, 0.00762568018399179, 0.04886908609686153, 0.08417110198310443, 0.016422762868127654, 0.12131652448858533, 0.05170101306534239, 0.04194282454305461, 0.010310443084953087, 0.013809695673574294, 0.04299271499205913, 0.0678407046943903, 0.0316017947957984, 0.006780736148357391, 0.040894905238279274, 0.06264786262597356, 0.09137944411486387, 0.06477460850562368, 0.012284521129913628, 0.03934498197798218, 0.036574689737920246, 0.025905094674921463, 0.04886983587805714, 0.05650202151654022, 0.01639884620505784, 0.047853441310248206, 0.04870046675205231, 0.07676102460495063, 0.030075369203197103, 0.02370497032201716, 0.05080658516713551, 0.04562440288386174, 0.048757148174835105, 0.02919579782922353, 0.05538308673671313, 0.06637239562613623, 0.008630782232752867, 0.022528261678027253, 0.024191973564614142, 0.027863395932529653, 0.06642796764416353, 0.05266490598608341, 0.034098274407110045, 0.03129057113879493, 0.022998533943401914, 0.03733419094766889, 0.039778067131659815, 0.05574071201096688, 0.007914953233141984, 0.02085854814920042, 0.06466883168156658, 0.031044683618737117, 0.01886400972892131, 0.046220475541693826, 0.057698139654738564, 0.05564390541985631, 0.09516420388328177, 0.056603197873170884, 0.0281086914307837, 0.13999406940170697, 2.2663310638495853, 15.534728561128889, 34.710483414786204, 63.97310665675572, 77.91809259142194, 75.73134858267647, 66.4343045098441, 68.79595552171979, 65.79102638789585, 56.43941811152867, 41.57909386498587, 20.488431113106863, 35.359754358019146, 45.53537729808262, 23.71510853086199, 36.861861092703684, 42.85305649893624, 53.36690732410976, 44.29982778004238, 29.9439913885934, 19.800872121538433, 12.347584656306676, 5.6485276222229, 2.362468727997371, 0.9488063731363842, 0.2737274318933487, 0.041690538437770944, 0.046255365812352726, 0.052635786655758104, 0.08027238904365472, 0.09303722730172531, 0.10551739297807217, 0.016333503282762, 0.037978622796280045, 0.5506942985313279, 0.08811766521206923, 0.3709001876413822, 0.6861141462411199, 0.402660674814667, 0.07629449106752872, 0.9741780459880829, 1.314559438398906, 0.2671961523592472, 0.05414483496653182, 0.2868198465023722, 1.0633758710963386, 1.5444548108748026, 1.0929053894111087, 0.07766195626131125, 0.0796711663050311, 0.4806402804596083, 0.9955491849354335, 0.8254616260528564, 0.3376908924962793, 0.4497131428548268, 0.21728782542049885, 0.2390707672706672, 0.03842779601524983, 0.1026862734662635, 0.5433869106428963, 0.4538444983107703, 0.15595081102635178, 0.038490797991731336, 0.08724098439727511, 0.04827322717756033, 0.07654132853661265, 0.09527519864163228, 0.024162321584299207, 0.3193589390388557, 0.7624287083745003, 4.827199740069253, 11.508045979908534, 28.192006587982178, 39.62647635596139, 43.158071994781494, 38.99604892730713, 41.415696552821565, 38.86337307521275, 18.493997607912334, 27.65459816796439, 39.94298069817679, 65.03437450953892, 40.674698965890066, 55.60713161740984, 51.88166386740548, 63.52594838823591, 65.99899986812046, 68.83490017482212, 72.48704705919538, 61.7532753263201, 39.83971309661865, 16.740595374788555, 3.15324581520898, 0.10534270413752113, 0.10320742228733641, 0.03201630166066544, 0.02237981857199754, 0.030503158391054188, 0.025908675643482378, 0.0061393144507227194, 0.04914222697594336, 0.015937708717371737, 0.038804915600589344, 0.09243086805301053, 0.0179859616660646, 0.04158699738660029, 0.09979492718619959, 0.09224900709731237, 0.02389350806229881, 0.01685638745714511, 0.02898868519280638, 0.04089525807648897, 0.042568338835345845, 0.041630002936082225, 0.07660957558878831, 0.029354340929005827, 0.05180315633437463, 0.0377293867059052, 0.05061292788013816, 0.1058008713381631, 0.03719399204211576, 0.027087565777557235, 0.024227396485262682, 0.05295625195971557, 0.06086209416389465, 0.006644618630941425, 0.05913843201207263, 0.022625746804156473, 0.04994653524564845, 0.05371107467051063, 0.01036374709968056, 0.029645683509962897, 0.04566756110372288, 0.07603963331452437, 0.014419337335441793, 0.09856340648340327, 0.04595219636602061, 0.0821255971012371, 0.10502230668706553, 0.11086766195616551, 0.10983975604176521, 0.14782586986465113, 0.15142416820994445, 0.17018271663359233, 0.11517286486923695, 0.15665175127131598, 0.12506419553288392, 0.09745657337563378, 0.16315298527479172, 0.09701873508415051, 0.09518970322928258, 0.22529470148895467, 0.11544889291482312, 0.09314987768552133, 0.20277637695627554, 0.08254132872181279, 0.21664521204573767, 0.08624228263007742, 0.10560185023184333, 0.12566681605364594, 0.09879284631460905, 0.193464759471161, 0.10845048273248331, 0.18135831052703516, 0.07888550417763845, 0.11540602307234492, 0.1586523303495986, 0.08469958576772894, 0.17470022636864865, 0.1700487466795104, 0.1263204895492111, 0.1718562554035868, 0.14229860502694333, 0.1131693816610745, 0.245362822498594, 0.23022372914212091, 3.9202639716012135, 22.399800641196116, 44.68952097211565, 76.24484130314418, 87.19495214734758, 84.08780806405204, 74.57987921578544, 80.0569565636771, 72.70895167759487, 62.08705289023263, 46.02096257890974, 20.874087401798793, 30.140173775809153, 42.82799782071795, 52.31564140319824, 65.86101559230259, 69.65681648254395, 74.93738487788609, 63.145291328430176, 39.40485313960484, 26.79532834461757, 16.686818054744176, 8.287227630615234, 3.7394518681934903, 1.8414619650159563, 0.5955539313810212, 0.2213632288788046, 0.23880613861339434, 0.12489646167627402, 0.16912868033562387, 0.22446650878659316, 0.16512468590268067, 0.17263753419475897, 0.18625433423689433, 1.0632280047450746, 0.4938980947647776, 0.34053238002317293, 0.46814839648348944, 0.4207796225590365, 0.5321154668927193, 0.7060192695685795, 1.1292847458805357, 0.8927376674754279, 0.2372329416019576, 1.5801481412989753, 4.344752873693194, 2.874642159257616, 2.098564854690007, 0.3653551723275866, 0.4087182011987482, 0.5997156309229987, 1.072396912745067, 0.7808446373258318, 0.30075508302875925, 0.671638985829694, 0.20799950882792473, 0.9371306853634971, 0.6378845285092081, 0.6353985933320863, 0.3255796123828207, 0.33910232675927027, 0.382390771061182, 0.15328217351010867, 0.15005131544811384, 0.09775735437870026, 0.18797523475119046, 0.33558013290166855, 0.20535504072904587, 0.9516822759594236, 1.5537174109901701, 9.6863386120115, 17.073995998927526, 39.57929113933018, 64.0984035219465, 96.41791452680314, 82.21045344216483, 56.12587717601231, 59.534382002694265, 27.164981194904872, 44.962293352399556, 55.472562381199424, 80.98407554626465, 48.50797993796212, 60.22207995823452, 58.32069846561977, 71.42286096300397, 74.61600984845842, 77.38678468976701, 83.64339433397565, 73.5560552052089, 51.390586035592214, 23.827471324375697, 4.187434366771153, 0.20650380051561765, 0.41147128918341225, 0.1681469487292426, 0.10527575987258128, 0.09242510050535202, 0.1733825792159353, 0.08139419741928577, 0.14488456983651432, 0.13052402756043843, 0.22410704807511397, 0.21519493843827928, 0.15342691860028676, 0.11594840325415134, 0.1306247085865055, 0.20752122306397983, 0.08072180992790631, 0.1328034573899848, 0.10397530679724046, 0.09272419874157224, 0.17260299676230975, 0.09694527688303164, 0.11834747237818581, 0.05712456043277468, 0.15355255614433969, 0.1438656680818115, 0.19536195695400238, 0.13781617555235112, 0.116291361993977, 0.19000243954360485, 0.15074848303837435, 0.14843481433178696, 0.1666938252747059, 0.07022485961871487, 0.21486428832369192, 0.1352833943175418, 0.1830003381307636, 0.12026911069239889, 0.13712630899889128, 0.11062375575836216, 0.17682246677577496, 0.17911249532231263, 0.09947547289941992, 0.3245311129306044, 0.1328428124210664], [0.02915281942114234, 0.0794378181121179, 0.02473774642151381, 0.044161403352128606, 0.02972422054569636, 0.05496302606271846, 0.021657976055783883, 0.04423935006239584, 0.008780088774593813, 0.011666301089072866, 0.04105858824082783, 0.032773499244025776, 0.021446132333949208, 0.04289176255198462, 0.058975420759192536, 0.030945318950606242, 0.05112205984603081, 0.042595371670488796, 0.0034798244346997565, 0.030042372045240233, 0.05205857727144446, 0.014048942880305861, 0.05655919487721153, 0.01156701275613159, 0.01450572841401611, 0.02726393229594188, 0.019869466312229633, 0.012212701590864785, 0.011730365821027329, 0.011365622714427965, 0.033343346523387093, 0.009386403070363616, 0.017176048697105477, 0.03908085882929819, 0.012498427598204995, 0.031552020859505446, 0.10147759903754507, 0.7474628857203892, 8.227916938917977, 28.099010160991124, 56.84053414208548, 60.59279414585659, 63.92599092211042, 58.021581990378245, 52.200197083609446, 62.934649739946636, 54.23521327972412, 37.428740297045024, 19.077121700559342, 23.758814437048777, 28.054659809385026, 15.398250307355609, 12.45256585734231, 41.81672920499529, 53.99631684167044, 39.697632857731406, 19.968233380998882, 7.187214885439191, 2.360979207924434, 0.37632985200200764, 0.24821389093995094, 0.06381036274667297, 0.04840563650109938, 0.02634608985057899, 0.05352471163496375, 0.13473049684294633, 0.04690864575760705, 0.03222435746075852, 0.07922990819705383, 0.03583317309884088, 0.13020237482019834, 0.1255949999072722, 0.2617688493004867, 0.08543947392276355, 0.09956436098686286, 0.13200721011630126, 0.34100016206502914, 0.10920691357127257, 0.05327716509678534, 0.0751447949026312, 0.5230152809194156, 0.28054030346018927, 0.10598649137786456, 0.33160980737635065, 0.651057553078447, 0.8282887286373547, 0.7816949231284005, 0.1608399408204215, 0.077018175806318, 0.1119570770700063, 0.6859259477683476, 0.7793959379196167, 0.11808794630425316, 0.21001823193260602, 0.057775078740503104, 0.050195727231247086, 0.01127185596020094, 0.038916388726128, 0.8514684619648116, 0.06735259374337536, 0.08774349386138575, 0.11294048465788364, 0.04187619240422334, 0.08016261564833776, 0.10466152283229999, 0.061998565681278706, 0.08000200640942369, 0.019824554079345295, 0.03709073597565293, 0.1353116485157183, 0.4094901569187641, 1.8478582160813468, 9.416120563234601, 23.407221691949026, 41.679769788469585, 58.293621335710796, 78.77012934003557, 59.86179501669747, 49.82045643670218, 89.1618412562779, 76.9069629396711, 49.68861436843872, 32.369843755449565, 28.65165424346924, 38.70259175981794, 43.895915099552695, 51.83510398864746, 53.26985836029053, 61.77071530478341, 62.08270331791469, 50.17114591598511, 38.62528610229492, 18.929805994033813, 1.4371838527066367, 0.009415289154276252, 0.029286901333502362, 0.030706942813204866, 0.04695399903825351, 0.038066754317177195, 0.01738370585787509, 0.02599715152090149, 0.07002635419900928, 0.03147413861006498, 0.061482139463935576, 0.03557129929374371, 0.08209874747054917, 0.036326644476503134, 0.021222709412021295, 0.0785089104569384, 0.012830064133075731, 0.05311269499361515, 0.0730340624494212, 0.04660053996901427, 0.028210809254752736, 0.03455210916165795, 0.058798458826329024, 0.029460304350193058, 0.0386692900210619, 0.04860007071069308, 0.010158595429467303, 0.04474082136792796, 0.01823716381165598, 0.03604258596897125, 0.03134244174829551, 0.050110581264431985, 0.016726839855047207, 0.04755846517426627, 0.03826332591207964, 0.06491250039211341, 0.020143187338752404, 0.029079456214926074, 0.029864439807300056, 0.06691531863595758, 0.03219599808965411, 0.05617995486993875, 0.07566451201481478, 0.04752095236576029, 0.04162109377128737, 0.042222153661506515, 0.015477360026644809, 0.02062781061977148, 0.025032737824533666, 0.028117276595107148, 0.03714741400576063, 0.04950550105422735, 0.04028419658009495, 0.0370205177792481, 0.05223148495757154, 0.029086835283253874, 0.05336490985272186, 0.0904785328145538, 0.035380454534398656, 0.05716789846441575, 0.009653186076320708, 0.01893054348017488, 0.019560710826356496, 0.022721851111522744, 0.05392327292689255, 0.06395184408341135, 0.022319903929850886, 0.03271562020693507, 0.04475382888423545, 0.03807587722050292, 0.03705708063872797, 0.02551177336967417, 0.02339534631132015, 0.02313455137690263, 0.07822927260505301, 0.024582653672301343, 0.03601388054500733, 0.02821583889557847, 0.05291400636945452, 0.022590649580316882, 0.839639316712107, 9.564726029123578, 31.39483778817313, 64.07781600952148, 69.62101936340332, 71.96336827959333, 66.07551343100411, 60.3746554510934, 68.487900188991, 66.26394162859235, 46.908688749585835, 30.125645092555455, 36.66341706684658, 33.78714772633144, 17.11066859109061, 18.304285730634415, 38.85346841812134, 46.496014390672954, 36.288669449942454, 20.38159040042332, 8.577023097446986, 2.7405312870229994, 0.607118122279644, 0.4556036410587174, 0.03722727757745555, 0.014517492514901927, 0.06289716996252537, 0.027907156352219836, 0.08705049247613975, 0.04791150015911885, 0.1044544814420598, 0.14043118166072027, 0.3169199042022228, 0.4374160798532622, 0.386692683079413, 0.9507274414811815, 0.24170682153531484, 0.37900360567229135, 1.0622955347810472, 3.0733560792037418, 0.994369945355824, 0.16166852707309382, 0.9297304196017129, 0.9151351856333869, 0.029885922225990465, 0.07317706370460135, 0.2229858503809997, 1.1021772176027298, 1.2429746453251158, 2.0042812739099776, 0.3848629726895264, 0.25953527486750055, 0.2903138133031981, 2.402048707008362, 2.498986065387726, 0.5389755644968578, 1.5922241104500634, 0.4654412046074867, 1.3056906057255608, 0.6773527392319271, 0.19929043043937, 1.622078565614564, 0.7636325380631855, 0.20387567153998784, 0.04147372953593731, 0.16798631234892777, 0.2102066475365843, 0.10244223834680659, 0.0545273421199194, 0.03354624545733843, 0.0484600448315697, 0.04379355934049402, 0.10750970071447746, 0.09195595460810832, 1.5325952129704612, 8.00226376737867, 25.576291220528738, 34.13410602297102, 50.65211064474923, 70.51111139569963, 46.98862082617623, 45.645474978855674, 96.65399347032819, 87.65329701559884, 47.26246670314244, 33.134989806583945, 35.11281190599714, 48.826544421059744, 50.428330012730186, 60.83463314601353, 61.00539207458496, 69.51883220672607, 72.0101296561105, 63.297463825770784, 50.71017674037388, 25.247316598892212, 2.6943259835243225, 0.0595692406807627, 0.1036264787295035, 0.02016741443159325, 0.06431049733821835, 0.018130152053864937, 0.014229183833646988, 0.04893963338275041, 0.028153539202841263, 0.026742605359426568, 0.032436399654086144, 0.044378765260002444, 0.07205469214490481, 0.08603216747620276, 0.027967663016170263, 0.05557216391233461, 0.0027181627270432985, 0.005302764317353389, 0.07307519524225167, 0.034234894040439806, 0.0053316342860593325, 0.026738875113161545, 0.04781309901071446, 0.016056920534798076, 0.06462740033332791, 0.039762834020491154, 0.028867719362356832, 0.027324725640937686, 0.0519691938534379, 0.006104677782527038, 0.004048073764092156, 0.04058605984651616, 0.021228298844237412, 0.012586818658746779, 0.03293301943423493, 0.026099605219704763, 0.014726449070232255, 0.0499975644717259, 0.012428027893682676, 0.01785055491408067, 0.014960872741150004, 0.03960897620501263, 0.04819650861567684, 0.10699162565703903, 0.13283084306333745, 0.14036358600216253, 0.1323720719665289, 0.1143144637878452, 0.1303283516317606, 0.18852255466793263, 0.15993415085332735, 0.1855460793844291, 0.20781615509518556, 0.09834883335445609, 0.09829692542552948, 0.1321791780314275, 0.18448391423693725, 0.20401597901114396, 0.09556282285068717, 0.15072959262345517, 0.052783615687595944, 0.06374432771865811, 0.10856370987104517, 0.11016715597361326, 0.09982539340853691, 0.1629986592701503, 0.07389707756893975, 0.08406563728515591, 0.20255643661533082, 0.10622024669178895, 0.13030559356723512, 0.08570885232516698, 0.06612038093486003, 0.23924007532852037, 0.13762317305164679, 0.08609379202659641, 0.12178080528974533, 0.1201470558132444, 0.15201807634106704, 0.14433475291090353, 1.615726066487176, 13.116126639502388, 42.180783544267925, 76.40692887987409, 80.30773789542062, 81.99995081765312, 74.55518531799316, 69.70998409816197, 78.44779545920235, 70.40932028634208, 52.26993267876761, 31.48228086744036, 37.90478917530605, 43.43027809688023, 25.888732603618077, 23.83371775490897, 57.607615266527446, 68.37152481079102, 51.91173219680786, 26.448606286730083, 10.299557958330427, 4.010254434176853, 0.8432586767843792, 0.5826259393777166, 0.202637982953872, 0.14328834334654467, 0.1452187347624983, 0.11832327581942081, 0.22772072202392987, 0.21930904553404876, 0.2018962220421859, 0.2803145412887846, 0.2224954595523221, 0.6817866670233863, 0.5013780476791518, 0.6238631723182542, 0.23716970213821956, 0.29998643855963436, 0.7512360832520893, 3.2734044875417436, 0.9395006724766323, 0.2726798823901585, 0.9986358135938644, 1.0573725189481462, 0.5773610504610198, 0.3024229221045971, 1.109390641961779, 2.2076220427240645, 3.543952141489301, 3.284625828266144, 0.6866346640246255, 0.5124669383679117, 0.9097907181297029, 3.1351140567234586, 2.666763348238809, 0.5394568900976862, 0.8923808666212218, 0.29381079279950684, 0.5814054448689733, 0.3031015656888485, 0.5575527676514217, 2.8204340509005954, 1.0162281095981598, 0.22914420706885202, 0.3210960972521986, 0.3149973159389836, 0.41397440486720627, 0.38415203083838734, 0.22423284846757138, 0.2788650819233486, 0.1631611276950155, 0.28501988308770315, 0.41073909561548916, 0.8186260642749923, 2.5965066381863187, 13.216720921652657, 32.39211968013218, 54.68519599097115, 72.16228825705392, 92.49885954175676, 78.0769214630127, 60.366595540727886, 96.08713163648332, 84.3985037122454, 64.6131955555507, 47.2998480115618, 42.87559298106602, 53.974478653499055, 60.28417600904192, 70.16914190564836, 70.2957033429827, 78.9933749607631, 82.23303508758545, 76.86047254289899, 64.20767784118652, 31.308923312595912, 4.009982151644571, 0.10241325133080993, 0.12901048734784126, 0.1978579480201006, 0.149547706757273, 0.1130037105509213, 0.11012071025158678, 0.13607787740017685, 0.14473008098346846, 0.13612101865666254, 0.18071461149624415, 0.12455427646636963, 0.18138336203992367, 0.12454804751489844, 0.13500368861215456, 0.15399888290890626, 0.08920391835272312, 0.16204280698938028, 0.15559850207396916, 0.12333695750151362, 0.06582829875073262, 0.20071703674537794, 0.09771944462720837, 0.09144994390330144, 0.13009237072297505, 0.1577970776706934, 0.0926120640443904, 0.10723960306495428, 0.0946889715269208, 0.16004430422825472, 0.10012842036251511, 0.0838884242943355, 0.0989181242351021, 0.09940629625426871, 0.10640564281493425, 0.12085539208991186, 0.12204722527946744, 0.07820253832531826, 0.12825459933706693, 0.10468219100896801, 0.10003773415727274, 0.1234559454023838, 0.15938075126281806], [0.0237586661907179, 0.03275999978982976, 0.020493794864575778, 0.06748580373823643, 0.01202984234052045, 0.04191283668790545, 0.0377260211722127, 0.03222542954608798, 0.05062015088541167, 0.03879049673144307, 0.06970417220145464, 0.03771973115258983, 0.005844079199180539, 0.013458139895062362, 0.007999177240500492, 0.044922634826174805, 0.007791070550281022, 0.08033684308507613, 0.004574174618548048, 0.05849361339850085, 0.027962645249707357, 0.024364053438018476, 0.015993742139211724, 0.043212797825357745, 0.00776973316845085, 0.012506394447492701, 0.005530097721410649, 0.029309913848659823, 0.0212584512441286, 0.042285650968551636, 0.05851028500390904, 0.024178452058030025, 0.04621694376692176, 0.025963246822357178, 0.025303698909868087, 0.10190000744270426, 2.0069721809455325, 18.355476583753312, 51.98009204864502, 63.07327325003487, 58.35245868137905, 66.71340669904436, 60.55361325400216, 57.432430335453574, 59.90369265420096, 49.01681736537388, 19.845641102109635, 14.74325578553336, 25.750086511884415, 24.382467372076853, 23.09007290431431, 55.69602687018258, 51.656132289341514, 31.192864077431814, 19.47835758754185, 6.498360923358372, 1.4875153005123138, 0.4678853963102613, 0.16529539174267224, 0.0380959686424051, 0.07043719358210053, 0.01744758992988084, 0.0483025602464165, 0.021505470221330012, 0.08629097430301563, 0.048062552232295275, 0.01713535695203713, 0.15121612937322684, 0.030293331614562442, 0.1487438598913806, 0.0523066598522876, 0.2893376728253705, 0.18006594558911665, 0.3196460407759462, 0.16830705585224287, 1.1247250991208213, 1.814430975488254, 2.046171311821256, 0.26126920325415476, 0.8252158878105027, 0.5945656044142587, 0.3225946825529848, 0.09253454141850982, 0.3238673699753625, 0.36649315697806223, 0.7840277265225137, 0.6341062283941677, 0.09616735684020178, 0.016759363734828572, 0.09563915804028511, 1.7426609694957733, 1.4287410314593996, 0.5489888957568577, 0.5106467817510877, 0.25288916006684303, 0.3519070696617876, 0.13980511096971376, 0.18594271024422987, 2.379429280757904, 1.2431556241852897, 0.09092746515359197, 0.06121383314686162, 0.07902543845453433, 0.05078473294685994, 0.0320224491879344, 0.09680902705128704, 0.03921419774581279, 0.023186930887667195, 0.05783007400376456, 0.05813319595264537, 0.04022203598703657, 0.01554447562167687, 0.03366252939615931, 0.6512816324830055, 5.343148214476449, 15.914018562861852, 41.64965629577637, 53.06979887826102, 40.490939957754954, 19.388362782342092, 24.2131119796208, 42.32931171144758, 44.13224070412772, 30.5727755682809, 25.00613420350211, 30.592438970293315, 34.65221234730312, 42.05862379074097, 46.90064968381609, 65.45706817081997, 61.5657434463501, 69.61966446467808, 63.00080353873116, 26.710530791963848, 3.2488256692886353, 0.029369377265019075, 0.0502836246575628, 0.0497196942035641, 0.01135162029614938, 0.04228470780487571, 0.02084485361618655, 0.022452281022976552, 0.016257598962900893, 0.040225812034415345, 0.019772552851853625, 0.030879249995840446, 0.035634016285517385, 0.030014949052461555, 0.019777307685996805, 0.03594385912375791, 0.023319983123136417, 0.07834746661995139, 0.021316460899210403, 0.07539369511817183, 0.024430736466976147, 0.05628186065171446, 0.05088514255891953, 0.056830819230526686, 0.016922619260315384, 0.01984689654117184, 0.031199291215411255, 0.028630086220800877, 0.09729308036289044, 0.06824222779167549, 0.011061549968352275, 0.0520386724466724, 0.06601428519934416, 0.02292747436357396, 0.04363799840211868, 0.03898917857025351, 0.015237475845164486, 0.04480671051091381, 0.01320176646446011, 0.11924197152256966, 0.023208535442660962, 0.03722134039604238, 0.03105180145108274, 0.0691246490127274, 0.04417989682406187, 0.02603982967723693, 0.008913217345252633, 0.021639489369200807, 0.08192373971853938, 0.01611191070904689, 0.00774764091641243, 0.03576937384371247, 0.024782002171767608, 0.0158456043739404, 0.03924566480730261, 0.03867558343335986, 0.02855460937800152, 0.06579718113477741, 0.026040145196020603, 0.016671693617744104, 0.08218129804091794, 0.04291909394253578, 0.026824721667383398, 0.013378665632834392, 0.028470718700970923, 0.08685347304812499, 0.03497794416866132, 0.052553870515631776, 0.03975267635126199, 0.007941699387239558, 0.02573382225818932, 0.005009727095187242, 0.045102205726185014, 0.02731747379792588, 0.07237840763160161, 0.054475885416780195, 0.01945250654327018, 0.016766768248219575, 2.3707025604588643, 22.239021062850952, 57.870076520102366, 73.37108721051897, 67.51914065224784, 73.143568447658, 68.4707589830671, 64.91872174399239, 66.62434468950543, 61.43734073638916, 30.897440569741384, 29.17897735323225, 37.14784894670759, 27.124476671218872, 27.654587745666504, 42.89831706455776, 43.14997386932373, 32.75159515653338, 18.922086545399257, 6.293921036379678, 1.7968000301292963, 0.3154887652822903, 0.12017024814018182, 0.023462723142334392, 0.10493072481559855, 0.04122639673628977, 0.0461378537251481, 0.06260915898850986, 0.17890106381050178, 0.2621482860829149, 0.0805471617994564, 0.5034285805055073, 0.3163016230932304, 0.9616661859410149, 1.4169855479683195, 1.5788051847900664, 1.4585523860795158, 2.4547405881541113, 1.5447046203272683, 2.266796810286386, 3.967675004686628, 4.760010659694672, 0.7824286637561662, 0.7559185719915799, 1.354680399809565, 0.4382284219775881, 0.1103353648047362, 0.3113742103534085, 0.9782831285681043, 1.6631645666701453, 1.4348196195704597, 0.824799864419869, 0.2830431748713766, 0.12265678042812006, 0.6682850143739155, 1.3331068945782525, 1.8553594478539057, 2.936683927263532, 1.8831344374588557, 2.692624109131949, 1.4240612025771822, 2.1221168594700948, 6.924235991069248, 2.0745709879057745, 0.5180881395936012, 0.29492388878549847, 0.31746718340686386, 0.30166491706456455, 0.26916091835924555, 0.161208982446364, 0.08248816550310169, 0.06061448995023966, 0.02549328498675355, 0.055109379280890734, 0.03594861226156354, 0.03530168679675885, 0.05530986602285078, 0.15453439631632396, 5.201455771923065, 14.691484757832118, 41.01112379346575, 50.9462765284947, 42.66782099860055, 34.46693863187517, 38.81213011060442, 56.31388848168509, 49.65597173145839, 30.13233620779855, 27.279456240790232, 38.077368531908306, 46.43042687007359, 51.11825486591884, 56.829535143715994, 73.2815249306815, 69.82243374415806, 81.47116511208671, 75.31881318773542, 37.891535486493794, 5.676317811012268, 0.04449836044971432, 0.05333505431190133, 0.04314645406390939, 0.13482522033154964, 0.03354322597650545, 0.03352741950324603, 0.09185401829225676, 0.009140295874593514, 0.025913927504526715, 0.008518581378406711, 0.029863269334392886, 0.033310515606509786, 0.01474262704141438, 0.034381881688854525, 0.03066662765507187, 0.03235979983583093, 0.030586842114904096, 0.04377255189631667, 0.01392099492451442, 0.03504644227879388, 0.04664678891588535, 0.05125138183523502, 0.03449115975360785, 0.07018550458763327, 0.011333270164738809, 0.01265121587286038, 0.0401400893128344, 0.00557245484586539, 0.03926777487088527, 0.01615081960335374, 0.05204224493354559, 0.06046733606074538, 0.040955651085823774, 0.011823431987847601, 0.04019443657515304, 0.031041195948741267, 0.016291205106037, 0.038550753345979114, 0.0701056138745376, 0.014199759162563299, 0.02372453418294234, 0.11035065898405653, 0.20333067221300943, 0.08917516882398299, 0.1464764265609639, 0.12843612102525576, 0.12969261860208853, 0.14416863396763802, 0.1366283728608063, 0.14095305651426315, 0.08189502411655017, 0.14093012203063282, 0.08345838915556669, 0.06253450656575815, 0.13494222691016539, 0.2555189718093191, 0.15310210388685974, 0.10578964836895466, 0.10898056107440166, 0.1884959153831005, 0.16313026792236737, 0.1581711268850735, 0.10292924328574113, 0.16095233336091042, 0.1741933607097183, 0.13064999080130033, 0.16189671839986527, 0.09483896169279303, 0.10249041433313064, 0.09530544773276363, 0.19784953418586934, 0.1504781546869448, 0.06582338615719761, 0.18130313205931867, 0.11923194277499403, 0.1328395011701754, 0.24151862306254251, 4.609792343207768, 30.47568838936942, 69.86458846500942, 81.84619413103376, 74.81868880135673, 84.24980531420026, 77.84451811654228, 74.58718872070312, 75.72853456224713, 64.34968512398856, 34.667557443891255, 28.12580762590681, 38.175418036324636, 36.437732628413606, 35.33408076422555, 72.99876798902238, 68.57189001355852, 42.80291134970528, 26.11500937598092, 8.459357959883553, 2.462098947593144, 0.7631588663373674, 0.36354519373604227, 0.2157938134457384, 0.18855437796030725, 0.28047975099512507, 0.23572968798024313, 0.20335680938192777, 0.39065733605197495, 0.3000397171292986, 0.158157026927386, 0.7491021177598408, 0.3431500867009163, 0.8007147482463292, 0.735337356371539, 0.7362495245678085, 0.9609833082982472, 1.3474911855799812, 0.5653019632611955, 1.6004856271403176, 6.290747880935669, 6.580921156065805, 0.7083005043012756, 0.7380644700356892, 2.0910914157118117, 1.3728615556444441, 0.6960604925240789, 1.2562061867543628, 1.911294617823192, 4.581316888332367, 3.132443125758852, 1.3866128006151743, 0.6359387072069305, 0.377359433897904, 4.773113659449986, 5.505929742540632, 1.0629957829202925, 2.1620920172759464, 1.4016138528074538, 1.485523121697562, 0.687193016920771, 1.086471248950277, 10.459389976092748, 4.270724160330636, 0.2602800891867706, 0.3054828979074955, 0.2643175353961331, 0.25560302872742924, 0.17906408863408224, 0.30170489634786335, 0.1691852430147784, 0.20694191700645856, 0.17523785680532455, 0.1522054062890155, 0.14267847607178347, 0.15930459249232495, 0.19487599017364637, 1.0470040696007865, 7.569741879190717, 22.240646941321238, 49.811295236860005, 65.02053369794572, 54.626594884055, 29.517948695591517, 32.538910797664094, 50.42047160012381, 55.076476846422466, 44.24549634116036, 40.21535355704171, 44.96165411812918, 50.26713180541992, 60.25680010659354, 64.78239808763776, 81.82524531228202, 77.4831770488194, 90.6813497543335, 88.21698352268764, 52.22045455660139, 7.9339525529316495, 0.10890520976058074, 0.11422800485576902, 0.11882216190653187, 0.21637891419231892, 0.11298345628061465, 0.1309466598821538, 0.16621639446488448, 0.26792840020997183, 0.0853920103982091, 0.08718687801488809, 0.13944961290274346, 0.1234138762312276, 0.10328053443559579, 0.08227094608758177, 0.1040544104097145, 0.08634974900633097, 0.1992756383759635, 0.08730352496994392, 0.22926873181547436, 0.14877785449581488, 0.18578676932624408, 0.11562432135854449, 0.19723137521318027, 0.10680050948368651, 0.06492582003452949, 0.08578913658857346, 0.11513015787516322, 0.11467081680893898, 0.1575494259595871, 0.07061390445700713, 0.17666404241962091, 0.19689350548599446, 0.15952609346381255, 0.08238392216818673, 0.22738942051572458, 0.10826216890875782, 0.11881039610930852, 0.08728908574474709, 0.25773514860442703, 0.13930154299097403, 0.15559259881930693], [0.039101113099604845, 0.019429385462509732, 0.03773488283955625, 0.01926349552481302, 0.009101941682664412, 0.013746307780300933, 0.03208085069698947, 0.060709505208901, 0.009169505958977555, 0.04562322562560439, 0.00606655005166041, 0.05470718443393707, 0.0515539134586496, 0.00998679205908307, 0.033674037350075584, 0.060829022367085726, 0.03839595575949975, 0.036697504576295614, 0.01780587338310267, 0.049529527979237695, 0.041829767038247416, 0.0824002545060856, 0.007167495171805578, 0.05716765419180904, 0.015237014441351806, 0.007647400089938725, 0.027247730576034104, 0.023923838577632393, 0.031161849653082233, 0.04314849306164043, 0.03522803182048457, 0.020149940458525504, 0.08085110477570977, 0.023421756590583494, 0.43420014956167763, 5.352128761155265, 26.026074171066284, 58.752925055367605, 62.46340206691197, 61.61813981192452, 56.803208419254844, 53.814492906842915, 45.22798899241856, 62.158459527151926, 37.39795977728707, 15.085675171443395, 17.125742707933696, 9.983236874852862, 11.49233957699367, 34.31414079666138, 45.19293533052717, 41.97121197836739, 31.595512185777935, 11.611192856516157, 2.0174394249916077, 0.11805582445647035, 0.05120782667238798, 0.018036198702507784, 0.05929167914603438, 0.03961159195750952, 0.012001915535490428, 0.06228674628904887, 0.06182640777634723, 0.03978009934404066, 0.055548357511205335, 0.09299986037824835, 0.09821915852704219, 0.22341294746313775, 0.7030453862888473, 0.9678405289139066, 1.1492722162178584, 1.2204422886882509, 2.7237752718584876, 2.2645762094429562, 1.495042045201574, 2.6357987012181963, 3.596743468727384, 2.1000100799969266, 0.4828468220574515, 1.5447121113538742, 0.41968587839177673, 0.17418221916471208, 0.14321772142180375, 0.09361367672681808, 0.877152749470302, 1.0178111046552658, 1.1593247396605355, 1.0589358636311121, 0.3859732731112412, 0.15795915254524776, 1.98820618220738, 1.9753563574382236, 0.7011388114520481, 3.9896195871489386, 1.5133062537227358, 6.128083603722708, 2.654210124697004, 0.8639703882592065, 1.7775210589170456, 0.44382147757070406, 0.41044151729771067, 0.16210307446973665, 0.3055365021739687, 0.07944245929164545, 0.16483178947653088, 0.10033162802989994, 0.05691147329551833, 0.05952693402234997, 0.1836831479200295, 0.11377846862056426, 0.07824490605188267, 0.0440376555281026, 0.036512451113334725, 0.16630866165672029, 0.007787498063407838, 0.555489858346326, 1.271716085927827, 11.770066891397748, 30.31417751312256, 53.045914445604595, 44.3466169493539, 14.160731843539647, 15.002975974764142, 25.608525650841848, 38.888716629573274, 31.907600947788783, 20.57316960607256, 25.79524632862636, 50.25038317271641, 51.71301719120571, 54.95096806117466, 54.55610193525042, 58.631387165614534, 67.76728861672538, 46.98335756574358, 6.461285769939423, 0.3239827480699335, 0.07159868947097234, 0.11096914365355458, 0.028287034182410156, 0.0461522115261427, 0.03376609080338052, 0.04101568786427379, 0.03826055748920355, 0.07372865839196102, 0.07885093281843833, 0.03873918930600796, 0.019189893135002682, 0.03756171731012208, 0.030023227179689065, 0.06047577703637736, 0.020491180808416436, 0.06602239369281701, 0.0907794020271727, 0.03360904387331434, 0.02773162952092077, 0.036105031546737464, 0.016874950478917787, 0.07119091706616537, 0.03597200136365635, 0.0282761419990233, 0.04923495217891676, 0.0026156339653035893, 0.05784609421555485, 0.05440526349203927, 0.031077266870332614, 0.039598248566367795, 0.07579298583524567, 0.014204441902360745, 0.01235337631909975, 0.056256103462406566, 0.015082038739430053, 0.025086917149435197, 0.00623128011855962, 0.032500999580536566, 0.05004571670932429, 0.039927687495946884, 0.015377756174919861, 0.020366060647315214, 0.012378862094400185, 0.02323870310959007, 0.03606921507577811, 0.027199171217424527, 0.044676085734473805, 0.010605270791399692, 0.04032092568065439, 0.02525488510062652, 0.027454797411337495, 0.03214549133554101, 0.05652755818196705, 0.049204597914857526, 0.050574926526418755, 0.06521214824169874, 0.07021266634442977, 0.030217216948845556, 0.00803518115675875, 0.024361171360526766, 0.029678609421742812, 0.027155080011912754, 0.032146190226610215, 0.056781581336898465, 0.03309731311830027, 0.04693230966638241, 0.037028141120182614, 0.051012625718223195, 0.019391706412924186, 0.05237805869962488, 0.043064928081418784, 0.06935981567949057, 0.08191505447030067, 0.4330253611717905, 6.222943884985788, 32.55063588278634, 68.03798348563058, 71.44230897086007, 71.62767996106828, 63.75528063092913, 63.69310120173863, 52.9723608153207, 69.85855742863247, 48.838755880083355, 23.883010012762888, 23.350953442709788, 12.443773780550275, 19.425144808632986, 34.65882355826241, 33.483785901750835, 41.570540632520405, 32.72388226645333, 10.664142966270447, 2.0118815175124576, 0.05786683024572475, 0.04851743871612208, 0.01216662991126733, 0.04356693882229073, 0.04180285973208291, 0.09705519955605268, 0.1470037568360567, 0.18411969020962715, 0.07186281601233141, 0.23688444601637976, 0.38393131696752136, 0.5678116743053708, 1.1205339240176337, 2.779437073639461, 3.7381725311279297, 5.5284779497555325, 4.670898709978376, 4.8221392801829746, 4.075172322137015, 5.724287739821842, 5.8828078508377075, 8.035356300217764, 3.0570197786603654, 0.9925376836742673, 1.3399476132222583, 0.7086543196013996, 0.20055102636771543, 0.36861450171896387, 0.41623995187027113, 0.9484874073948178, 0.35532791752900394, 0.7860808106405395, 0.31852656656077927, 0.48976082248347147, 0.44935818761587143, 0.48547763803175514, 0.6033688091806003, 1.6506243710006987, 6.216065602643149, 3.448191199983869, 7.860847081456866, 4.0058353798730035, 3.7628807595797946, 4.355238139629364, 2.081477714436395, 1.0387749054602213, 1.304955508027758, 1.4840869073356902, 0.9343038541930062, 0.835086563868182, 0.7951377875038556, 0.782841158764703, 0.3712412193417549, 0.5097839023385728, 0.39856634022934095, 0.2498486717896802, 0.06518991943448782, 0.043555407119648795, 0.20595698271478924, 0.09819481947592326, 0.29240731096693445, 1.717339888215065, 10.941027811595372, 31.363869667053223, 38.683247974940706, 27.54998435292925, 19.70394127709525, 28.170218774250575, 31.674554892948695, 38.31813750948225, 29.467664582388743, 21.388921124594553, 32.61847461972918, 58.45560468946184, 59.0958742414202, 62.82313115256173, 62.511198725019185, 67.73803670065743, 79.15259987967355, 61.81616347176688, 11.488503302846636, 0.4226805791258812, 0.06945139755095754, 0.006107485221166695, 0.18970468480672154, 0.003464990386938942, 0.02606393802644951, 0.031097110626952987, 0.03166131249495915, 0.03937454914141979, 0.06703512756420033, 0.05103580786713532, 0.03735041132728968, 0.02509307994374207, 0.08293150671358619, 0.03305544411497457, 0.04919494575421725, 0.06882677892489092, 0.03400492834459458, 0.055747365046824725, 0.03307709956009473, 0.0519937432504126, 0.043734441976994276, 0.02661671506107918, 0.07098618948033877, 0.005933220040917928, 0.10722669732889958, 0.06442145816981792, 0.05418065822284136, 0.03550021257251501, 0.025969482559178556, 0.02639472215170307, 0.028773121402731965, 0.02562936857741858, 0.06556077274893012, 0.035011338269604106, 0.04550883140681045, 0.05746740382164717, 0.059341151134244034, 0.016172624326178005, 0.021495056405131305, 0.1400273311883211, 0.1548221765884331, 0.10642702345337186, 0.07563184733901705, 0.07092820187764508, 0.1089036287739873, 0.1400275754609278, 0.13875969206648214, 0.09150223859718867, 0.15141038037836552, 0.09466776730758802, 0.13954979181289673, 0.08523776581776993, 0.2530296710985047, 0.15566643700003624, 0.12842609227768012, 0.13866429004286016, 0.13042471717510903, 0.10827595674033676, 0.11812982548560415, 0.09211777842470578, 0.25680655986070633, 0.09860179120940821, 0.14932448230683804, 0.2126598230430058, 0.09709966395582471, 0.15030769311955997, 0.18692102203411715, 0.11412929158125605, 0.1425590810499021, 0.1093641844178949, 0.13220645513917717, 0.1359047016927174, 0.13139890347208294, 0.8481369093060493, 10.897413969039917, 46.296865122658865, 78.87382425580705, 81.67148167746407, 78.74869414738247, 74.51068210601807, 70.56397329057965, 62.47030857631138, 74.3563973563058, 52.75594874790737, 28.054295028959, 29.853247914995464, 18.318289824894496, 17.620549985340663, 48.170095988682334, 59.320884704589844, 56.84183692932129, 42.062935147966655, 15.98682873589652, 2.866303018161229, 0.1800098850258759, 0.13876725094658987, 0.1348022994186197, 0.20506400348884718, 0.17425027622708253, 0.15530758697007382, 0.31586947771055357, 0.312576737254858, 0.16964161209762096, 0.21091269036488874, 0.27766133365886553, 0.421644890414817, 1.046932959130832, 1.8821545243263245, 3.103251789297376, 5.128714646611895, 4.046497106552124, 7.081199271338327, 6.196052185126713, 7.443560855729239, 7.95612599168505, 15.128884281430926, 4.147158699376242, 1.705162410225187, 3.00952102456774, 1.8357155876500266, 0.44185663014650345, 0.6091603498373712, 1.3135733370270049, 2.7292341675077165, 3.6951870662825446, 4.73495762688773, 4.70227677481515, 1.0634035553250993, 0.6594545053584235, 7.182094497340066, 8.65660776410784, 7.224142389638083, 11.676320927483694, 5.397694178989955, 10.699804595538549, 8.145229033061437, 2.5928171447345187, 3.32777544430324, 1.6957216539553233, 0.6152521829519952, 0.7242964516792978, 1.1604853059564317, 0.6650303261620658, 0.5606403734002794, 0.43198109577809063, 0.7378347452197755, 0.2596684305795601, 0.7126786293728011, 0.7984408416918346, 0.2942078714924199, 0.31039679422974586, 0.1498805553253208, 0.3746451852577073, 0.17802892918033258, 0.9080841211335999, 2.591895639896393, 17.565963200160436, 42.30043499810355, 72.24829305921281, 64.02321011679513, 24.630450316837855, 23.736170257840836, 34.32939556666783, 51.89018930707659, 44.02741323198591, 33.06142922810146, 41.437788350241526, 66.29320744105748, 68.22018609728131, 72.77010972159249, 72.97727026258195, 75.5304205758231, 87.83520780290876, 74.89189502171108, 14.09386932849884, 0.4845626471298081, 0.16374876616256578, 0.20350131019949913, 0.24236934312752315, 0.1183681134134531, 0.12489910796284676, 0.12267260386475495, 0.13085896601634367, 0.13199385654713425, 0.2680879645049572, 0.11672645221863474, 0.10207287102405514, 0.12192601178373609, 0.10890340485743114, 0.08122479436653, 0.1415392564875739, 0.11875330417283944, 0.17966748268476554, 0.11316403480512754, 0.12170361514602389, 0.1340532781822341, 0.10522391301180635, 0.13876335615558283, 0.1110284204727837, 0.09878763516566583, 0.17274856966521057, 0.1327463790242161, 0.0961455555100526, 0.15493862676833356, 0.15712859854102135, 0.17760546904589447, 0.13964059336909226, 0.08628581743687391, 0.12285819676305566, 0.17374597543052264, 0.07138064224272966, 0.14454527518578938, 0.10700278077274561, 0.08577968459576368, 0.10265195995037045], [0.03520466307444232, 0.031219620124569962, 0.07024983649275132, 0.013840191581818675, 0.040112761314958334, 0.03370660703097071, 0.009360581420228949, 0.01661330059037677, 0.03306554750140224, 0.017139385753710355, 0.02767390654688435, 0.03031409139345799, 0.061245954994644435, 0.006538250633249325, 0.018046892414401685, 0.0392809147015214, 0.0716212914724435, 0.023996910013790642, 0.02849499329126307, 0.02392281568609178, 0.06002391342605863, 0.061140972056559155, 0.04238505295610853, 0.013822511503739017, 0.060338509402104785, 0.030744855957371846, 0.005548245140484401, 0.06338410704795804, 0.07715369960559265, 0.02589045697823167, 0.05687209112303598, 0.02022103396510439, 0.035795890992241244, 0.1746394703430789, 7.231418022087642, 33.3747512953622, 55.62712158475603, 58.85168675013951, 59.047987256731304, 44.91840853009905, 46.31650768007551, 39.25310100827898, 34.48991632461548, 26.388219492776052, 21.91578565325056, 21.41261795588902, 24.933607169560023, 46.04939113344465, 37.37495081765311, 34.81174646105085, 41.90276179994856, 26.84002784320286, 3.0659458254064833, 0.09450544816042696, 0.055154505252305946, 0.1602690757385322, 0.05291590287483164, 0.059005819128027985, 0.08882741284157548, 0.15852776489087514, 0.05996289277183158, 0.1282946736152683, 0.10247787500598601, 0.23892501794866153, 0.03689587428899748, 0.4915443924920899, 0.5586052026067461, 0.6625453137925693, 2.1361383242266516, 3.1064970323017667, 6.006602168083191, 6.206165288175855, 3.898933436189379, 6.0031267660004755, 6.551916769572666, 4.0903884427888055, 4.253729735101972, 5.072204947471619, 0.9033469696130071, 1.1143573011670793, 0.2581269075827939, 0.29531377500721384, 0.4766584741217749, 0.389448023800339, 0.44129219757659094, 0.1850149764546326, 0.3778808202062334, 1.4462300815752573, 1.9481459089687891, 1.8471184500626154, 0.3882937543094158, 0.05144815359796796, 3.876408244882311, 5.4318185193198065, 3.877657183579036, 6.130493325846536, 3.4716491869517734, 4.441220794405256, 7.551379527364459, 1.9301872040544237, 2.9832461944648196, 0.9290656724146434, 0.6398903865899358, 1.3350228603397096, 1.2118593092475618, 0.7587670077170644, 0.19781819943870815, 0.2594690498496805, 0.16878850358937467, 0.09482612381024019, 0.12360960644270692, 0.0024493502652538674, 0.037847909810287614, 0.014212535128795674, 0.046606226092470546, 0.09173787345311471, 0.09045109285839967, 0.08627331203648023, 1.6249824783631732, 20.36072322300502, 54.43235451834542, 56.817212513514924, 38.35349689211164, 19.2741448198046, 16.696243286132812, 40.507876191820415, 43.91168056215559, 25.102686371122086, 19.082808801106044, 35.274482590811594, 43.49288831438337, 44.47742026192801, 64.95722171238491, 64.60833181653703, 77.35137666974748, 58.10431071690151, 9.915038568632943, 0.6939167018447603, 0.009784234088978596, 0.050451752064483504, 0.0159697813713657, 0.006478384336722749, 0.05037749658471771, 0.03929734203432288, 0.009219352837785013, 0.013584189649139131, 0.027101411284612756, 0.027324449137917588, 0.00953714725827532, 0.03092730723853622, 0.010741243271955421, 0.06890307340238776, 0.029550410407994474, 0.06845690948622567, 0.04055145116789, 0.019358054468674318, 0.07403810428721563, 0.022799478910331215, 0.042771916304315837, 0.0196723094808736, 0.007323463231192103, 0.022759296066526855, 0.0010864253189148648, 0.010397282844808484, 0.02106011036916503, 0.053267431511942825, 0.03925675206950732, 0.024889261594840457, 0.03001414838113955, 0.05845174100250006, 0.05595337845651167, 0.024774200715390698, 0.015046936426577824, 0.05463520883183394, 0.07256537117063999, 0.054870351749871454, 0.060554731371147294, 0.002767955747133653, 0.044075029236929755, 0.05029422337455409, 0.0514801159900214, 0.03710468326296125, 0.0456807043270341, 0.025966848146968653, 0.03746095825252788, 0.06327632176024572, 0.03616315824910998, 0.017837052067209567, 0.016774590060647045, 0.13125977665185928, 0.023242094088345766, 0.06867394569729056, 0.041718565326716216, 0.048344924580305815, 0.019410449246476804, 0.03993042538474713, 0.07175486109086446, 0.0602162577477949, 0.005448078952862748, 0.0201604848927153, 0.010583902027324905, 0.03241416745420013, 0.04406414553523064, 0.052810404250132184, 0.07402719344411578, 0.0047814509515384475, 0.041368583749447546, 0.04746681544929743, 0.0687173990798848, 0.19377163371869496, 8.153781397002083, 39.04869542803083, 66.44394860948834, 67.89146682194301, 68.87126704624721, 52.79847867148263, 55.285798277173726, 48.80389676775251, 42.63357332774571, 39.700186320713584, 42.22858020237514, 27.491838353020803, 27.82593379701887, 28.260324750627788, 20.207472017833165, 36.25236858640398, 40.438564436776296, 24.52370340483529, 3.871626147202083, 0.12394580697374684, 0.07304906485868351, 0.17409428102629526, 0.0242859744134226, 0.11276808248034545, 0.2472949916762965, 0.7339963540434837, 0.45626106006758554, 0.7524145628724779, 0.9330621893916811, 1.1093248512063707, 1.1458699873515537, 2.0570159299033026, 1.747518737401281, 3.14569724883352, 4.546102983610971, 4.416895151138306, 8.275950704302106, 9.427410517420087, 7.826265028544834, 7.069680895124163, 7.3940375702721735, 7.812054225376674, 7.805883356503077, 3.698913472039359, 1.0349799948079246, 2.3983446657657623, 0.4301379775362355, 0.39421674076999935, 0.003794232117278235, 0.14121370895632676, 0.2562746698302882, 0.37659198365041185, 0.1571135079222066, 1.2575165735823768, 0.9761968233755657, 1.3431977416787828, 0.09113404514001948, 0.5086272986871856, 2.400623674903597, 7.316064017159598, 3.903174008641924, 8.483761770384652, 5.668221422604152, 4.5203238640512735, 5.045481741428375, 2.8241854267460957, 3.8990884678704396, 4.016833943980081, 4.473257635320936, 3.071437507867813, 3.413342292819704, 1.860815303666251, 1.3068063344274248, 1.496292069554329, 0.8492012321949005, 0.9489932145391191, 0.4773206157343728, 0.1324726715683937, 0.02070906518825463, 0.05726008423204933, 0.01663980247186763, 0.04823865581836019, 0.07554755971900054, 0.07108113688549825, 2.103949708598001, 20.43570123400007, 46.8287809916905, 46.09315088817051, 30.7899797303336, 25.925035204206193, 26.516398123332433, 45.43563938140869, 41.088947091783794, 25.897681883403234, 31.845522267477854, 52.14042173113142, 56.15054675510952, 53.572007724217, 70.82566329411098, 72.05599471500942, 83.821441922869, 71.1671255656651, 18.362951108387538, 0.3862984542335783, 0.026344892236271074, 0.009197500617509442, 0.03045359140794192, 0.020567276814420308, 0.031171586630599837, 0.007945595026415373, 0.015276155733902539, 0.08246792480349541, 0.09142794579799686, 0.03654217773250171, 0.0377984174660274, 0.082577467496906, 0.0627092429037605, 0.020311759186110327, 0.045649515464901924, 0.05708823845322643, 0.029593022407165596, 0.03947495875347938, 0.027169298713228533, 0.04215454103957329, 0.026126809384939925, 0.08098440298012324, 0.0030680815398227423, 0.025769574268321906, 0.031919026880392005, 0.011846035685656326, 0.033245413564145565, 0.008544924652336963, 0.00457485654624179, 0.022699155811486498, 0.06739715313805, 0.04837643574657185, 0.010513019714770573, 0.023438443463029604, 0.03557876996429903, 0.03313044598326087, 0.060020276478358676, 0.03573088055210454, 0.16545088482754572, 0.15973063105983393, 0.1460521521845034, 0.08270079123654536, 0.13151072604315622, 0.20864657339240822, 0.20617595953600748, 0.1067919802985021, 0.07464052124747209, 0.14723532726722105, 0.11399158968457154, 0.12235396381999765, 0.18091989548078605, 0.18374925080154622, 0.10657808570457356, 0.1409130093774625, 0.1618733632245234, 0.09403364919126034, 0.10746894790125744, 0.13496828265488148, 0.12404523949537959, 0.11428721382149629, 0.14875839411148004, 0.0649750070380313, 0.0979374104312488, 0.11590120435825416, 0.21588865907064506, 0.14505374218736375, 0.1821332382304328, 0.11318498796650342, 0.13759096977966173, 0.13336109103901045, 0.17442347907594272, 0.6342694567782539, 14.167970129421779, 52.561930724552695, 78.0449389048985, 75.05606705801827, 78.52874197278703, 64.11815725054059, 65.13986900874546, 55.38685287748064, 47.86956902912685, 38.035943371909006, 37.577410902295796, 34.68294422967093, 37.12834187916347, 60.0738262448992, 52.254733494349885, 47.73382554735456, 56.19525146484375, 34.30371502467564, 4.452220227037158, 0.2313461617699691, 0.17160413893205778, 0.2456848280770438, 0.18618549007390225, 0.39797715470194817, 0.3769288355750697, 0.9963886141777039, 0.305292582405465, 0.8597071798784393, 0.7598772538559777, 0.934846790773528, 0.9894891615424837, 2.727265873125621, 2.349852753537042, 4.4971325142042975, 6.993513873645237, 7.946332505771092, 13.099571687834603, 15.889618226460048, 9.189108150345938, 13.541107126644679, 16.268628563199723, 12.08027182306562, 11.416016221046448, 13.357849257332937, 3.562713146209717, 3.721135982445308, 2.2434436976909637, 0.7010587443198476, 0.9503321541207177, 0.7297607213258743, 2.0287035405635834, 2.5640572479793002, 3.64290360893522, 2.273587154490607, 1.598090561372893, 1.957839731659208, 2.1439461452620368, 2.7774412035942078, 11.02795238154275, 11.717700055667333, 11.568463172231402, 14.318031242915563, 10.886613862855093, 10.190402626991272, 17.0751667703901, 9.133988959448677, 9.75639295578003, 6.234115719795227, 4.795893328530448, 3.1290411140237535, 3.582678577729634, 2.3665805416447774, 1.0928388386964798, 1.4858314480100359, 0.38233583686607225, 1.1392783182007926, 0.4461815852139677, 0.17515852249094419, 0.1335820627531835, 0.1008690684767706, 0.12659674829670362, 0.1557920609733888, 0.2570636974913733, 0.2767887647662844, 3.1055010514599934, 30.30482176371983, 73.70559433528355, 79.76509748186383, 56.504811082567485, 30.265373366219656, 26.34284601892744, 48.28969880512783, 56.045455251421245, 40.693427835192, 33.59923716953823, 50.29917342322213, 59.78830392020089, 62.6591397694179, 82.24149104527065, 81.58105782100132, 91.63189111437116, 80.85124683380127, 19.761538369315012, 0.8142807260155678, 0.10137402066694838, 0.14780516097588198, 0.0888087327725121, 0.14976339946900094, 0.07819592939423663, 0.10647766930716378, 0.11438010526554925, 0.13338251917489938, 0.14046900320265973, 0.16386897542646953, 0.15854043992502348, 0.14982017927936145, 0.10499056481889316, 0.0908901457275663, 0.1063960347590702, 0.1937788940433945, 0.13613171236855642, 0.09995054919272661, 0.1015062467860324, 0.11750489473342896, 0.23880372302872793, 0.181092908339841, 0.08140815488461937, 0.11517848313919135, 0.25539021300418036, 0.1933503177549158, 0.10805726490382637, 0.12660008668899536, 0.10693788568356208, 0.11339930325214352, 0.13571156348500932, 0.1109323806262442, 0.10072593829993691, 0.0771538760246975, 0.12961185936416897, 0.13535635040274688, 0.1333163891519819, 0.16867292193429811], [0.09628540836274624, 0.06333196841712509, 0.043115424657506604, 0.015149032198158758, 0.04188281151333025, 0.09488756515617881, 0.0281161688866892, 0.045068570745310614, 0.04697657050564885, 0.13392377298857483, 0.02590820745431951, 0.08979809789785317, 0.06336153218788759, 0.029932615613298755, 0.015081137984192796, 0.0028155081173671143, 0.12530544187341416, 0.026041006935494285, 0.05079986767045089, 0.04006993896993143, 0.09311305359005928, 0.11976289642708642, 0.08924639464489051, 0.1531889835106475, 0.1313207633793354, 0.07024714270872728, 0.0983408402119364, 0.040983040151851516, 0.028095977380871773, 0.013896345443624471, 0.025231704648051943, 0.016856536734849215, 0.7111175102846963, 8.30082699230739, 34.57543822697231, 55.37780632291521, 59.343911034720286, 69.66386195591518, 52.718831471034456, 49.820230620247976, 27.95650087084089, 23.753050906317576, 24.800017629350933, 12.701324394771031, 7.817986249923706, 29.43655402319772, 46.44910362788609, 64.52426556178501, 67.59399359566825, 39.518018450055806, 21.219160999570573, 2.0422475337982178, 0.11688396733786378, 0.06953533233276435, 0.03431302395516208, 0.03894554198320423, 0.13125296416027205, 0.07265850688729968, 0.07696805242449045, 0.08634090769503798, 0.3368203863501549, 0.1909013491656099, 0.12867005275828497, 0.6565367504954338, 1.0366638473102023, 0.7168932003634316, 0.9240210631064006, 2.04393008351326, 7.274466889245169, 5.869502919060843, 8.451503021376473, 8.31047717162541, 7.240807209696088, 2.796930032117026, 5.1436198353767395, 5.84094625711441, 7.000865936279297, 0.6377573439053127, 1.0072706873927797, 0.6924974237169538, 0.21097312069364957, 0.2713225952216557, 0.49325174944741385, 1.2863953496728624, 2.2694288747651234, 11.155236431530543, 38.16870955058506, 37.9334956577846, 42.4023129599435, 33.72978687286377, 23.02761902127947, 6.588214593274253, 1.7697705605200358, 4.414673464638846, 1.8733648359775543, 7.63048129422324, 3.606397339275905, 8.479965448379517, 5.856935799121857, 4.21206225667681, 1.8192600820745741, 2.5004933902195523, 2.65213891012328, 3.2306328969342366, 3.0882682161671773, 3.1820187398365567, 1.7053142935037613, 0.7099445132272584, 1.2348488356385912, 0.41717706301382607, 0.8245248677475112, 0.23615290384207452, 0.1086999054199883, 0.1309023651161364, 0.08142627855496747, 0.11785562948456832, 0.1218125471579177, 0.034920322974877696, 0.03283748170360923, 0.22538042760321073, 3.830465453011649, 25.99904567854745, 53.70637198856899, 48.54832812717983, 27.69768394742693, 17.23924674306597, 31.533603736332484, 35.91598197392055, 20.418488809040614, 13.858223778860909, 16.363289083753312, 26.89654275349208, 35.9052609034947, 48.856602328164236, 65.81535897936139, 70.84689698900495, 62.287223543439595, 21.65366312435695, 0.6893597692251205, 0.19428210918392452, 0.04523126308673194, 0.10016027079629046, 0.05397505532684071, 0.06912986016167061, 0.04949666313560946, 0.013892549888363906, 0.028740117459424903, 0.026726496938083853, 0.02162933848532183, 0.030655418256563798, 0.04625950148329139, 0.13413646657552036, 0.07399836927652359, 0.030969512116696154, 0.050541328864970377, 0.042425958439707756, 0.035181857512465546, 0.01818164946910526, 0.05213864101096988, 0.023428555511470352, 0.07477418586079564, 0.034571091178804636, 0.038991336311612806, 0.039623822551220655, 0.07426996648843799, 0.0416583317731108, 0.05740497859993151, 0.04271660552227071, 0.015199764565165554, 0.051583826674946716, 0.03507516127345817, 0.048011570503669124, 0.08083880972117186, 0.16474670118519238, 0.21294977462717465, 0.04012303433514067, 0.07759146325822387, 0.08020806392388684, 0.07347186002880335, 0.015484153858519025, 0.026153893110209277, 0.06309467793575355, 0.07038863083081585, 0.0006935560346132011, 0.06888349766709975, 0.08639086144311087, 0.07442936793501888, 0.09953204914927483, 0.05690971928249512, 0.04872290251244392, 0.03132234354104314, 0.030336893562759672, 0.03892291623300739, 0.04738995100238493, 0.013770414433175964, 0.040203009865113666, 0.04797411197796464, 0.07013998167323214, 0.07575880802635636, 0.10046638508460351, 0.09702490975282022, 0.09544607411537852, 0.06245329949472632, 0.07568978065890924, 0.018716112843581607, 0.1038930004994784, 0.026362367905676365, 0.016316131089947054, 0.640787409884589, 9.451318400246755, 41.01159627096993, 65.5464984348842, 67.88058594294957, 77.97028745923723, 61.446665218898225, 56.819418566567556, 38.146235602242605, 35.57517283303397, 33.66318838936942, 20.10436248779297, 15.233327865600586, 34.24726438522339, 49.724428858075825, 64.56936631883893, 52.404251779828755, 33.19966016496931, 20.35978521619524, 2.9258959804262434, 0.048529737163335085, 0.14731500084911073, 0.0226666488950806, 0.025923774743984853, 0.16452074902398245, 0.20268400119883673, 1.0667904764413834, 1.2119533270597458, 1.5157211869955063, 1.0179337837866373, 1.853201380797795, 2.4515693868909563, 3.768550055367606, 2.795308930533273, 3.0545612020151953, 3.8869660326412747, 6.87821763753891, 7.433588453701564, 7.571373837334769, 8.942745004381452, 5.912759797913687, 6.0374908191817145, 4.866809683186667, 8.182066644941058, 6.384204626083374, 5.108576595783234, 1.797664646591459, 1.7637754593576704, 1.044915484530585, 0.7231884311352457, 0.2402170571897711, 0.9601272685187203, 3.2921620181628635, 11.617994274411883, 33.523574760981965, 36.70467547007969, 41.34592621667044, 32.87125703266689, 20.692742892674037, 7.040621791567121, 1.805840396455356, 5.464755586215428, 6.669796432767596, 7.41390073299408, 4.494414900030408, 8.484533020428248, 3.6461549316133772, 6.228951471192496, 6.3904375944818765, 6.295087030955723, 6.206436702183314, 2.9728156455925534, 4.8626629114151, 3.942091303212302, 2.243455422776086, 2.388227002961295, 3.3040102166788916, 1.5561259388923645, 1.2963194400072098, 0.7690516444189208, 0.5931327013032777, 0.5108492566006524, 0.17680919463081018, 0.24369224214128085, 0.13589814704443726, 0.020771317383540527, 0.07254948666585342, 0.14572566827493055, 4.824283667973109, 25.32553768157959, 48.157106331416536, 38.847823006766184, 27.422893115452357, 28.70423821040562, 44.42319304602486, 40.28588472093855, 16.841799361365183, 21.826631580080303, 25.55062631198338, 35.79816484451294, 46.02134472983224, 55.921242305210654, 70.28024360111782, 78.30555888584682, 75.63774939945766, 37.0257864679609, 2.0814675092697144, 0.32901229390076225, 0.018478920749787773, 0.07547141451920782, 0.04868931502902082, 0.022565721900069287, 0.0050678928133233315, 0.04564084718003869, 0.055848636398358006, 0.050517994045679054, 0.0073475376536537495, 0.043238534658615074, 0.04972765002665775, 0.07702783135963337, 0.056639611454946656, 0.07002641526716095, 0.03941863356158137, 0.013124008047660547, 0.05671257771817701, 0.01953109786180513, 0.04128103916134153, 0.07592979206570558, 0.11634108504014355, 0.07059502082743815, 0.04505645550255265, 0.03194553045822041, 0.08866676289056029, 0.04099200699212296, 0.048059777024069, 0.0287803817274315, 0.016481870053602115, 0.045929757212953906, 0.06688646732696465, 0.05735491628625563, 0.054221441570137224, 0.16506223353956426, 0.11009698866733483, 0.06335588677653245, 0.12865881621837616, 0.1460068260452577, 0.2623005764825003, 0.10337648607258286, 0.08179238890962941, 0.12426473200321198, 0.14373499580792018, 0.12144368195108005, 0.17138285509177617, 0.1809812079050711, 0.09638722254229443, 0.18228491794850143, 0.1492792647331953, 0.09895131816821438, 0.12266545210565839, 0.11889046324150902, 0.3465001497949873, 0.2101724086595433, 0.1130399103941662, 0.11963113849716527, 0.24585804449660437, 0.21823164049003804, 0.13196244037577085, 0.15074365186904157, 0.17513594084552356, 0.14820893002407892, 0.2183795611241034, 0.11768975481390953, 0.07050314718591315, 0.18320932691650732, 0.16006939645324433, 0.12765626715762274, 1.3625586799212863, 12.850117462021963, 50.14525692803519, 74.04377705710274, 75.29967090061733, 88.10055255889893, 68.84578105381557, 65.23170334952218, 42.33365780966622, 35.763722624097554, 34.88102694920131, 19.731575999941143, 13.518402150699071, 41.90663194656372, 58.125308173043386, 76.07992580958775, 83.5212241581508, 51.43836532320295, 29.7871219090053, 3.8612368532589505, 0.3891869778079646, 0.32878273193325314, 0.21038031178925717, 0.09809697472623416, 0.4041241391428879, 0.2449701949954033, 1.126469965491976, 1.2289883558239256, 2.2572076448372433, 1.3183061459234782, 1.6043424201863152, 3.0243104823998044, 4.1446868777275085, 3.272913988147463, 4.323439274515424, 6.453574138028281, 16.78866822378976, 17.421084574290685, 16.643436976841517, 18.236919471195765, 15.756753035954066, 15.06591796875, 12.742148535592214, 16.243880816868373, 18.444576808384486, 7.429507255554199, 2.279071888753346, 1.4310046242816108, 1.5579266079834528, 1.1170067361422946, 0.8098237280334745, 2.2117486212934767, 4.671559223106929, 12.330044797488622, 34.48069953918457, 34.32354865755354, 35.92067200796944, 28.533046756471904, 20.312566995620728, 7.227817118167877, 4.034569220883506, 15.789194175175258, 9.468592490468707, 17.69658933367048, 11.128000361578804, 21.025099549974712, 14.53926362310137, 12.391649263245718, 11.940066729273115, 10.836649366787501, 10.952141455241613, 8.93526005744934, 9.148376941680908, 7.2363525458744595, 4.081671493394034, 3.260710562978472, 3.4770386006150926, 1.3471329190901347, 2.0527972877025604, 0.5463507516043526, 0.3532490219388689, 0.5447623282670975, 0.17516419504370007, 0.28206613872732433, 0.20242610360894883, 0.12035330331751279, 0.11964195434536253, 0.4318513327411243, 6.079820982047489, 37.56135014125279, 74.23752757481166, 69.75935799734933, 45.093423230307444, 30.97087608064924, 42.15141698292324, 46.44231871196202, 34.132952622004915, 22.46584153175354, 27.373649494988577, 42.73646572657994, 52.973875522613525, 66.10172203608921, 82.5336002622332, 85.88362557547433, 89.20462826320103, 38.015849181583945, 1.8333568913596017, 0.5254248401948384, 0.09530012801821743, 0.19880767991500242, 0.13666595013013907, 0.08470708357968501, 0.15769128049058573, 0.10023530998400279, 0.14617479060377392, 0.11661495534437043, 0.10677891171404294, 0.1366074468408312, 0.1384334388588156, 0.2323051488825253, 0.10048569619123425, 0.21940568249140466, 0.16265099149729523, 0.08508101065776177, 0.13910516138587678, 0.08321598930550472, 0.1571711426866906, 0.10438254994473287, 0.17271857841738633, 0.18508543553096907, 0.0912310756476862, 0.14438324102333613, 0.19892261017646107, 0.1413665964667286, 0.17191235667892865, 0.1167326947408063, 0.09127971982317311, 0.2222077471337148, 0.19517712401492254, 0.11883647899542536, 0.1714194416999817, 0.23532213270664215, 0.32423215040138786, 0.13550127191202982], [0.19992690985756262, 0.0356903380847403, 0.12741607933172158, 0.12140092067420483, 0.23152008386594908, 0.13677040381090982, 0.12032058435891356, 0.031554416088121276, 0.07491420834724392, 0.14788480741637094, 0.20930401954267705, 0.05475488205307296, 0.08757547502006803, 0.04001113712521536, 0.07838419572051082, 0.07454459675188575, 0.07830999791622162, 0.040354896536363025, 0.011854742986283131, 0.03427201669131007, 0.0816663306738649, 0.01401845206107412, 0.20978373023016111, 0.20376508390264852, 0.6287009098700115, 0.09929674677550793, 0.10255079716444016, 0.12742538883217744, 0.17728283921522753, 0.06683098351848976, 0.026947850328204886, 0.40218784447227207, 11.965397255761282, 35.821416991097585, 59.79434190477644, 64.76488862718854, 56.767324447631836, 38.70380769457136, 48.931618554251536, 30.724048273903982, 24.705857379095896, 14.63184142112732, 16.26846354348319, 30.806005750383648, 43.08864559446062, 29.107621090752737, 31.44461120877947, 40.66790362766811, 37.61018555504935, 17.996386732373917, 2.9552634102957587, 0.05359516053327492, 0.10429890693298408, 0.10285013967326709, 0.027165556592600684, 0.12077927403151989, 0.021421146978225027, 0.6032625777380807, 0.6618849092296192, 0.42172775311129435, 1.3437823674508502, 1.1610812225512095, 2.0658438333443234, 1.152649149298668, 1.4913201992000853, 2.3643245484147752, 1.4062031379767825, 2.7551941573619843, 2.775587554488863, 1.92843582374709, 7.10372359412057, 5.5429388880729675, 5.0142634851591925, 3.909493395260402, 3.9861711093357632, 6.582706408841269, 4.654266893863678, 0.8588746988347599, 0.6966065232242856, 2.1244169303349087, 0.6900753793971879, 1.1909477284976413, 1.628451149378504, 4.14485320023128, 17.48002961703709, 59.794168199811665, 72.5721138545445, 63.05427687508719, 66.61660439627511, 64.87327357700893, 63.98745468684605, 41.710605893816265, 15.340305805206299, 4.154538554804666, 3.1709463511194502, 5.6932848777089795, 2.517019897699356, 2.7790909664971486, 2.7070437925202504, 2.415319983448301, 3.859748635973249, 4.738535514899662, 9.23364610331399, 5.71988388470241, 5.677911988326481, 1.9821970760822296, 3.124728019748415, 2.788733546222959, 4.082296831267221, 2.4402025682585577, 0.7173776743667466, 1.3652937731572559, 0.5193731220705169, 0.07860433962196112, 0.2548855186573097, 0.20506457345826284, 0.15724234815154756, 0.17613680713943072, 0.029545412997582128, 0.026582272623532584, 0.1358558607420751, 0.8790153552378926, 9.68484388078962, 36.13607311248779, 43.861229692186626, 35.65840877805437, 21.952713591711863, 29.639305932181223, 46.089124407087056, 45.12588174002511, 38.245990889413015, 49.521333013262065, 29.162902695792063, 28.061946732657297, 57.877062933785574, 67.27607876913888, 73.28558267865861, 73.54572323390416, 42.5836227280753, 2.800772168806621, 0.061093902082315514, 0.07822006488484995, 0.04869315892990146, 0.06404056253709964, 0.019092285872570107, 0.02805440523661673, 0.057419634956334314, 0.058599064525749, 0.04969794376354132, 0.0551976532941418, 0.17289260907896928, 0.19007980610643113, 0.24526112366999897, 0.14671908425433294, 0.09589743560978345, 0.0938474659674934, 0.010186381438480956, 0.03343266887324197, 0.04223022483555334, 0.03685664139421923, 0.012311073053362114, 0.010585569527133234, 0.08375199125813586, 0.02582377564561154, 0.05480137527255075, 0.07384075237704174, 0.1546009334602526, 0.06900604787681784, 0.05574679847008415, 0.08280217115368162, 0.020209137549889938, 0.10256782839340822, 0.07535545966987099, 0.04698382743767329, 0.055219926206128936, 0.24878120049834251, 0.18368936330080032, 0.13848967584116118, 0.12886650221688406, 0.13300353022558348, 0.1438581363431045, 0.13179560218538555, 0.09164004227412598, 0.045765955466777086, 0.0046949135638507345, 0.14380369069320814, 0.19204645843378135, 0.006808035308495164, 0.047823076868163686, 0.04459989642990487, 0.11603674851357937, 0.009542408449176167, 0.02846447957147445, 0.044498869350978305, 0.035232924057969024, 0.04840352625719138, 0.0337220233465944, 0.017190951022452543, 0.1547725349664688, 0.1926378831267357, 0.37779380487544195, 0.10853942510272775, 0.04714108471359525, 0.08623814356646367, 0.08682387535061155, 0.16879679528730257, 0.03053218951182706, 0.5420314148068428, 13.079250812530518, 44.57855824061802, 69.29774052756173, 75.20982374463762, 62.5554587500436, 47.38865988595145, 55.595232827322825, 41.03220810209002, 34.77984380722046, 20.110028743743896, 26.219682250704082, 26.09347517149789, 27.467064550944738, 34.196771826062886, 32.881550788879395, 46.76410368510655, 37.324611118861604, 16.88792324066162, 3.5189410150051117, 0.01900968441207494, 0.05577945296785661, 0.14800512524587767, 0.07688937628907816, 0.23756623800311769, 0.9105568113071578, 1.1960346783910478, 1.7841695078781672, 2.596945894615991, 4.595499898706164, 2.541133620909282, 3.938812622002193, 2.7305706100804463, 3.814278755869184, 3.7706432001931325, 4.856694408825465, 3.6148426575320105, 7.193579001086099, 7.2513293879372736, 7.557297655514308, 7.843579070908683, 6.903779625892639, 4.822583964892796, 6.0587140917778015, 4.978010824748448, 4.476155034133366, 1.8995141642434257, 0.7302716853363174, 2.7973141372203827, 1.435331506388528, 1.577952510544232, 2.8900113574096133, 4.713191960539136, 18.494258165359497, 65.78512041909354, 86.80966758728027, 75.73057038443429, 79.70008318764823, 77.76263359614781, 71.96042224339077, 45.86837666375296, 19.024654115949357, 4.896129778453282, 1.3896843386547906, 3.0408013803618292, 3.485653498343059, 5.049146916185107, 3.366973055260522, 3.8947271704673767, 1.1985570916107722, 2.3197794301169257, 3.865315011569432, 2.409001031092235, 3.7744429962975636, 4.039482465812138, 3.2099541894027164, 3.0389976714338576, 5.815331723008837, 2.663289248943329, 1.7683175184897013, 2.7047921419143677, 2.2306116776806966, 1.1895802361624581, 0.58454977614539, 0.2909603757517678, 0.44900795498064583, 0.08703131707651274, 0.011210874321737459, 0.04455178151173251, 0.13554161760423863, 0.5260131571974073, 7.6154175996780396, 34.08442292894636, 43.10081883839199, 32.775733198438374, 28.31451027733939, 36.3797151701791, 43.05440139770508, 26.692371674946376, 26.54258414677211, 48.9241874558585, 38.694903578077046, 36.36198336737496, 64.9901144845145, 72.62346799033028, 80.89914771488735, 84.54320689610073, 59.13852228437151, 6.620692644800458, 0.12581936429653848, 0.017971510566504936, 0.016358234187854186, 0.04054065228306821, 0.05410241634984102, 0.0362916184988405, 0.003063675727129781, 0.07288018427789211, 0.012492999318055809, 0.08141662978700229, 0.08356107864528894, 0.10505343108837094, 0.1398721095174551, 0.12662057844655855, 0.06299065173204456, 0.053258637698101144, 0.024119911449296132, 0.0330431762018374, 0.10606676885592085, 0.046225581517709155, 0.05297821613826922, 0.04061151848041585, 0.03041538310104183, 0.030018572429461137, 0.06565736220883471, 0.055174433825803657, 0.12047807233674185, 0.05013347503596118, 0.028389196111155406, 0.04930631709950311, 0.08404228889516421, 0.059891354824815474, 0.13249067988778862, 0.06885541310267788, 0.0554229676324342, 0.13509288882570608, 0.23538873770407268, 0.3806852868625096, 0.18233286323291914, 0.33701637440494125, 0.41266694931047304, 0.2237486323075635, 0.1462126121457134, 0.1229855442153556, 0.10875632560678891, 0.2753532017980303, 0.2579095592456204, 0.1671361079705613, 0.28203090918915613, 0.17832069923835142, 0.27379707672766274, 0.13130922828401836, 0.1326790140675647, 0.11764307160462652, 0.11627253943255969, 0.11730977520346642, 0.16320310187126907, 0.08388788825167076, 0.39760675600596834, 0.2451827393046447, 0.878959769649165, 0.2513773569038936, 0.20381635400865758, 0.23890406478728565, 0.17810435513300554, 0.21569030971399375, 0.13793133651571615, 1.085349006312234, 17.001755578177317, 56.69347551890782, 80.11202798570905, 81.52884210859025, 72.47385937826974, 55.305725710732595, 65.2534373147147, 44.01900243759155, 38.79648971557617, 23.201086010251725, 25.627650567463466, 43.00141443525042, 60.6940016065325, 42.180672373090474, 46.404878343854634, 54.72531488963536, 49.465921129499165, 25.861330645424978, 4.4833255750792365, 0.24662294345242636, 0.2638397110360009, 0.2452058366366795, 0.13740977378828184, 0.4369116026375975, 0.8030828897442136, 1.9565087173666273, 2.9214057070868353, 2.3896733139242445, 3.8787515248571123, 3.769933181149619, 6.431326874664851, 6.8736578822135925, 9.30120951788766, 8.922721164567129, 7.452211362974984, 12.202263951301575, 13.231213995388575, 9.87276485988072, 19.413183484758648, 18.718664135251725, 16.95639773777553, 11.743271163531713, 12.93079560143607, 15.21853688785008, 15.248125791549683, 7.015065448624747, 2.6424077408654347, 4.93543096099581, 1.5315402810062682, 2.5914099173886433, 4.4603617787361145, 7.611836671829224, 19.805374554225377, 65.74700260162354, 76.27704620361328, 68.50012901851109, 71.13137708391461, 69.16053444998605, 63.8370817729405, 45.12612840107509, 20.124357666288102, 13.288676466260638, 7.237568046365466, 10.451453396252223, 9.256356290408544, 10.181808573859078, 7.981504287038531, 10.230432067598615, 10.371418833732605, 14.183335202080862, 17.941290991646902, 15.246397427150182, 13.768721427236285, 9.488577246665955, 9.819737945284162, 7.847383209637233, 10.840341465813772, 9.033108932631356, 2.9561060965061188, 3.1238666602543423, 2.4775519583906447, 0.7597297674843243, 0.46729268240077154, 0.4614447419132505, 0.37339928639786585, 0.3168216251901218, 0.22428166227681295, 0.10495009020503078, 0.1894631806228842, 1.617415455835206, 11.968833139964513, 48.38493776321411, 58.252185753413606, 50.61026859283447, 34.07658536093575, 37.93866859163557, 57.24818842751639, 56.498387472970144, 46.922279426029746, 62.308137621198384, 42.09719671521868, 41.83960267475673, 72.9768533706665, 84.20505891527448, 90.50880513872418, 97.82489000047956, 66.27000740596226, 6.543068672929492, 0.16858794220856257, 0.17187355804656232, 0.21218035662812845, 0.13420491718820163, 0.13437972137970583, 0.15935591688113554, 0.10275912098586559, 0.14609111366527422, 0.2678941477622305, 0.2417144211275237, 0.30143673930849346, 0.26700917524950846, 0.37522500700184275, 0.22716326479400906, 0.28227333618061884, 0.1967438885143825, 0.06501457920031888, 0.16415803134441376, 0.23639641648956708, 0.16372200474143028, 0.14544798460389885, 0.15902264762137616, 0.14818708119647844, 0.09791168038334165, 0.15527660506112234, 0.166823398321867, 0.3010908221559865, 0.14538060607654707, 0.24497307198388235, 0.15010143204459123, 0.15303670668176242, 0.11780490220657416, 0.30628017655440737, 0.1802558268287352, 0.20200557474579128, 0.3096036139343466], [0.19774665470634187, 0.07172111754438706, 0.013309753616340458, 0.062191323909376345, 0.2289736233651638, 0.0698692529861416, 0.03156577476433345, 0.042633593548089266, 0.11606808326074056, 0.03316653386822768, 0.10104956557708127, 0.15890896586435183, 0.01586023358894246, 0.037003713859511275, 0.008731654944962688, 0.046361529401370456, 0.06295521184802055, 0.03641151902931077, 0.013829018654567855, 0.07766382901796273, 0.08150585714195456, 0.0635534558179123, 0.08145122150225298, 0.1810215807386807, 0.19236577701355728, 0.12174759778593268, 0.10864202638289758, 0.133283100223967, 0.014942609971123082, 0.2857994655413287, 0.26525836491159027, 8.631147827420916, 38.57163558687483, 55.17377594539097, 65.77442019326347, 60.14603887285505, 58.42118331364223, 44.809644903455464, 26.97825356892177, 20.439093691962107, 17.121879509517125, 28.354465893336705, 23.49685171672276, 40.98712818963187, 45.74016155515398, 39.16067954472133, 44.87475299835205, 24.44532946177891, 9.243992839540754, 1.4369665043694633, 0.16080437201474393, 0.03716971745182361, 0.061079048950757296, 0.19902086204716138, 0.13074778126818792, 0.28329944397721973, 0.29764068871736526, 0.7519090814249856, 1.248617342540196, 2.067937195301056, 1.3178912081888743, 0.9734052760260445, 1.3828033421720778, 1.7380762440817696, 4.276267520018986, 3.431132938180651, 3.708049918924059, 3.3335368037223816, 2.919392466545105, 7.962904827935355, 3.9807641080447604, 4.904706461088998, 2.9450797396046773, 3.5889328249863217, 3.9637292964117865, 7.941634654998779, 3.376784563064575, 3.7156017422676086, 2.3625594888414656, 8.243529541151863, 6.73129710980824, 5.787139407226017, 7.977106077330453, 18.067744731903076, 40.50414153507778, 55.103050231933594, 45.46134771619524, 52.69309881755284, 48.67796761648995, 56.81925180980137, 55.97011246000017, 65.42302199772426, 46.277854851314, 17.18342317853655, 5.450149169989994, 5.310573756694794, 1.8926940730639865, 6.168941182749612, 2.0008356188024794, 5.010434593473162, 4.65951669216156, 5.828871590750558, 4.752352442060198, 0.9833737696920122, 3.803278454712459, 2.997211639370237, 1.1161510220595767, 3.8352119411740984, 5.042934792382376, 1.4876558929681778, 1.2110558152198792, 3.3073260273252214, 1.7165328115224838, 1.4991207463400704, 0.5944040045142174, 0.08426218173865761, 0.161510401272348, 0.0501337159158928, 0.04210266703739762, 0.060618411882647445, 0.11826059275439807, 0.10444806928613357, 0.04321398865431547, 3.4910470374992917, 22.424555335726055, 47.739033222198486, 39.847766058785574, 42.96596820013863, 52.60639919553484, 81.70509706224713, 86.51632159096854, 69.76274177006313, 47.28690004348755, 38.97770915712629, 50.37045499256679, 46.35308299745832, 52.5383311680385, 66.9009177344186, 73.68636866978237, 49.36239644459316, 3.2462363796574727, 0.12123940219836575, 0.052186375949531794, 0.03843843883701733, 0.0780754555016756, 0.05695901145892484, 0.03392555671078818, 0.01535438742887761, 0.07593830768018961, 0.15028713350849493, 0.08744795114866324, 0.09397939353116921, 0.12415034456976823, 0.1738960945180484, 0.05232164869084954, 0.1344308014959097, 0.02068795426748693, 0.07928553449788264, 0.05837790960712092, 0.01225816343711423, 0.06410545762628317, 0.025884027858929973, 0.032825142544295104, 0.020764079111229097, 0.08890956986163344, 0.18022187293640204, 0.17729357363922255, 0.02829109351815922, 0.0770034651671137, 0.014502203424594231, 0.07025455909648112, 0.08640123624354601, 0.06940620711871556, 0.024398489090214883, 0.007829387422784098, 0.25648344148482594, 0.19021891935595445, 0.06297954411378928, 0.03470719851819532, 0.05962143359439714, 0.17287432934556687, 0.1108171178826264, 0.07972682653261082, 0.024908062103869658, 0.055730679870716164, 0.09132399423313992, 0.08591917782489743, 0.024925198505765626, 0.05331247266648071, 0.023405651561915874, 0.024262753248746907, 0.07819042647523539, 0.03162975383124181, 0.022742629550131302, 0.00628038527377482, 0.05807497086269515, 0.0965747492653983, 0.07738864914114986, 0.0664267869932311, 0.1615434323570558, 0.1438656545111111, 0.16658193485013076, 0.06292123081428663, 0.1164595436836992, 0.11842055059969425, 0.17549655506653444, 0.2531634239213807, 9.372284378324236, 47.834661279405864, 68.38831165858677, 75.32631724221366, 67.180680002485, 66.90794236319405, 50.87417507171631, 37.39334964752197, 27.934084245136805, 21.975698232650757, 30.369189875466482, 18.986675262451172, 39.543434960501536, 49.11755929674421, 37.216309547424316, 40.53925078255789, 27.805592945643834, 11.12608700139182, 1.5613037581954683, 0.10295034572482109, 0.1328185751502003, 0.10943456207002912, 0.6007514010582651, 0.6762530782393047, 0.7046053111553192, 0.8661995657852718, 1.796861695391791, 2.708324215241841, 3.421098002365657, 3.588854657752173, 3.4582897552422116, 3.0725442256246294, 4.174927609307425, 3.6294590617929186, 3.8796048504965643, 2.7097101637295316, 3.0324848209108626, 5.171489059925079, 6.08048323222569, 2.2385135165282657, 5.461482984679086, 4.053402313164302, 2.40263517839568, 2.148080106292452, 4.56538553748812, 2.6850729371820177, 3.080581988607134, 3.242895164660045, 4.7603181174823215, 5.437289791447776, 7.493547933442252, 10.204811453819275, 19.0319618838174, 45.148484230041504, 67.25674193246024, 56.98819031034197, 59.399003301348, 55.3723589352199, 65.2169384275164, 68.87616552625383, 74.59350463322231, 54.14373677117484, 20.239331245422363, 3.4869397836072102, 2.293686555964606, 1.412525890128953, 2.070260282073702, 1.9086336748940604, 2.6368906540530066, 2.568822192294257, 2.96707751921245, 3.4892782866954803, 0.8218031280807087, 1.037695546235357, 0.8764577667628015, 1.1173960523945945, 1.217810875603131, 3.4626918733119965, 1.431924500635692, 2.4596362454550604, 4.577884043966021, 2.7894283660820554, 3.8047631978988647, 2.849445168461118, 0.9307128297431129, 0.6411460020712444, 0.8899823810373033, 0.20343072898685932, 0.07146446167358331, 0.02306155627593398, 0.02919494966045022, 0.10816236997821502, 3.5941776292664662, 18.08782502583095, 41.98797450746809, 36.84350047792707, 43.081548009599956, 54.923237800598145, 74.81532587323869, 82.01823847634452, 73.14808477674211, 52.2365847996303, 45.856425762176514, 57.36033582687378, 53.61084468024117, 60.285815783909385, 70.25418785640171, 80.88100596836635, 66.12954262324742, 8.076222130230494, 0.09053145854600839, 0.07326315622776747, 0.12030643011842455, 0.03999831959871309, 0.02766900582771216, 0.02003652841917106, 0.04704086848401597, 0.031229123007506132, 0.09780973728213992, 0.04045594736401524, 0.046604241377540996, 0.10687683788793427, 0.1187830918601581, 0.11975275911390781, 0.1628937441855669, 0.032044440507888794, 0.025765723582091074, 0.046930983130420954, 0.011880205012857914, 0.0390612220258585, 0.04172955420134323, 0.03864974821252482, 0.09278306843979017, 0.0534299542196095, 0.11109402123838663, 0.10038314240851573, 0.04973299348992961, 0.020837522045310055, 0.05295166167031441, 0.037988308883671246, 0.03425149100699595, 0.06659125709640128, 0.0315055072839771, 0.02967131177761725, 0.16757129319012165, 0.2852167939501149, 0.1525147504040173, 0.13050909979002817, 0.1622303133564336, 0.40974330476352144, 0.3180038503238133, 0.20694296195038728, 0.13115909562579223, 0.2188015149108001, 0.2705392401133265, 0.325617176081453, 0.3905992534543787, 0.1280115209519863, 0.14728177977459772, 0.26178182289004326, 0.15897688721971853, 0.2003623257790293, 0.17638656230909483, 0.15456300335271017, 0.19022645109466144, 0.2100036298590047, 0.151926419830748, 0.1858163805944579, 0.43330391336764607, 0.3232410007289478, 0.2638271717088563, 0.252156206539699, 0.3350411589656557, 0.18571422036205018, 0.30659488109605654, 0.6668653562664986, 14.012746504374913, 60.47757911682129, 78.00286756243024, 82.77252101898193, 76.23050716945103, 74.00103173937116, 59.15323856898716, 39.91753986903599, 31.550237723759242, 27.95923672403608, 43.38963113512312, 33.523661613464355, 55.96262577601841, 62.291510581970215, 51.60302373341152, 59.01292664664132, 37.29998322895595, 15.654352222170148, 2.6922350100108554, 0.21521790006331035, 0.20731441916099616, 0.1422555451946599, 0.5012802843536649, 0.4898766076990536, 0.703063788158553, 1.0309572049549647, 2.5732725134917667, 4.9102376614298135, 5.354377806186676, 6.078136043889182, 6.433842556817191, 7.727799500737872, 10.82146668434143, 13.893401639802114, 12.993237325123378, 13.626120941979543, 11.536942669323512, 8.455659781183515, 16.240067992891582, 12.214955704552786, 13.585810099329267, 12.02624523639679, 11.588057960782733, 10.41321051120758, 18.607241085597447, 7.289652177265712, 9.63550819669451, 7.762830580983843, 17.328968831471034, 12.514777421951294, 10.6304372549057, 16.80446147918701, 22.906025545937673, 50.83558477674212, 65.93957192557198, 58.94828755514962, 64.00761835915702, 60.03531238010952, 71.04592813764299, 70.7261859348842, 76.97146306719098, 62.353731700352256, 24.54895142146519, 9.217627031462532, 9.294029423168727, 6.641082567828042, 11.910179053034101, 7.094351777008601, 11.115887914385114, 12.005821875163488, 16.632594312940324, 14.597289766584124, 7.592324393136161, 10.165815557752337, 8.566234282084874, 5.337529293128422, 10.295881492750985, 13.904061044965472, 6.135410479136875, 6.823437171322959, 11.346441302980695, 6.262138673237391, 4.989414989948273, 2.914542406797409, 1.3532650300434657, 0.5937897946153368, 0.7480164074472019, 0.21723416687122413, 0.15023228073758738, 0.40293111173169954, 0.18098776255335125, 0.14598888557936462, 5.211616209575108, 29.998235974993023, 63.33589431217739, 53.96260418210711, 59.43685013907296, 59.31081676483154, 86.55215345110211, 92.23050621577671, 77.86327825273786, 55.63034554890224, 52.597672258104595, 66.79121957506452, 63.786610058375764, 72.02358831678117, 79.96555301121303, 91.91995647975376, 76.22760282244, 9.272021004131862, 0.25392658582755495, 0.18296889481799944, 0.3693768765245165, 0.1461490605558668, 0.14343775675765105, 0.139199844162379, 0.19564266689121723, 0.21132848305361612, 0.37207302185041563, 0.26148340318884167, 0.2579570295555251, 0.38858566007443834, 0.35446012552295414, 0.2954684267086642, 0.2741077372006008, 0.15596371676240647, 0.10305338126740285, 0.1625800710171461, 0.06667334626295737, 0.18019581719168595, 0.05435806798881718, 0.09814679276730333, 0.14689439056175096, 0.16606684534677438, 0.3975511704172407, 0.3318216731505734, 0.180884272392307, 0.2153823769518307, 0.09089917702866451, 0.20345841321562017, 0.0969552377771054, 0.17712334277374403, 0.2001308367720672, 0.13915286239768776, 0.4164936696844441], [0.08533860969224147, 0.0685077046177217, 0.03750657616183162, 0.09114625198500496, 0.09498426996703659, 0.0824221440457872, 0.0281036957167089, 0.11004832413579736, 0.04666662588715553, 0.08134260161646775, 0.07178939852331366, 0.04589154551337872, 0.014839001066450561, 0.04222809423559478, 0.04803415893443993, 0.00889821832866541, 0.039289983322045634, 0.023101883308429803, 0.05254708516544529, 0.028642659474696432, 0.0632948118395039, 0.0413591215786125, 0.08102008035140378, 0.043170219752937555, 0.07423470302351884, 0.08486583363264799, 0.05092710316447275, 0.19631734783095972, 0.3397353727902685, 0.09844192835901465, 3.4900102359907965, 34.5179557800293, 59.52032579694475, 62.795275824410574, 59.747003827776226, 58.07567719050816, 36.42976999282837, 26.19420668057033, 24.248539107186453, 19.50443070275443, 23.181573731558665, 21.565513065883092, 46.10504273005894, 39.37669556481497, 36.65192822047642, 40.01423100062779, 13.380232879093715, 2.1315158179828098, 0.17435084868754658, 0.033213980429406674, 0.0409385689667293, 0.0787644942424127, 0.13173240343374865, 0.20815658968474182, 0.8390658731971468, 0.3054868605520044, 1.626541263290814, 1.814905515738896, 0.7457417409334863, 2.9007050693035126, 6.457729160785675, 2.514189375298364, 2.120077346052442, 1.4733345700161797, 1.4638309542621886, 0.9880835626806531, 4.135811422552381, 3.004493785755975, 13.865440351622444, 12.978588785443987, 9.699697392327444, 16.07319484438215, 13.043414609772817, 10.326136554990496, 13.057626281465803, 12.657086082867213, 12.062895246914454, 13.333145805767604, 15.022736651556832, 19.834112303597585, 23.632506608963013, 21.132815735680715, 26.137254033769878, 35.021582058497835, 28.35174219948905, 41.16376876831055, 38.01285798209054, 49.52286856515067, 44.743376459394185, 48.067693437848774, 43.638265473502024, 45.67449413027082, 47.20233004433768, 29.671774864196777, 17.543588263647898, 12.643478904451642, 10.96891701221466, 10.668399606432233, 9.19960514136723, 9.30044434751783, 5.874160383428846, 10.160500185830251, 8.151929702077593, 3.506126365491322, 3.2073497005871365, 0.9163972607680729, 1.4159857673304421, 1.7415331900119781, 2.4836852635656084, 0.7349207358700889, 1.6254148951598575, 3.345182418823242, 2.004685572215489, 3.068411350250244, 1.7222064499344145, 0.796110426740987, 0.8068728063787732, 0.15420804811375483, 0.1653098173971687, 0.03025774923818452, 0.019514852037121142, 0.05115001888147422, 0.09786085811044488, 0.0579472773575357, 1.9750751725264957, 13.614652940205165, 40.05307143075125, 52.93105724879673, 58.303807394845144, 48.017423221043174, 46.64618928091866, 93.28174781799316, 102.18273067474365, 36.72589179447719, 33.03240660258702, 44.15153932571411, 51.83641372408186, 48.656706128801616, 62.086948667253765, 69.16359860556466, 56.30180556433541, 4.927223835672651, 0.1211100055703095, 0.07944189610757998, 0.07208049004631382, 0.025707834366975085, 0.02039899504078286, 0.04544703382998705, 0.10034346846597535, 0.010391604354871171, 0.0013261826991635773, 0.1566654033958912, 0.061363551898726394, 0.19673200058085577, 0.0917309998933758, 0.05046506492154939, 0.10802945175341197, 0.049263990085039816, 0.027881533173578124, 0.036976898155574284, 0.018496762828103135, 0.013488331310717123, 0.023413904244080186, 0.0485223004195307, 0.03302536805027297, 0.1352632146860872, 0.31850604766181534, 0.09100291146231548, 0.12181736475655011, 0.035500931819634776, 0.01800257389965866, 0.03890175951112594, 0.057555810149226866, 0.05877741067005055, 0.04120558945994292, 0.08771680707910232, 0.12748862829591545, 0.07807481767875807, 0.01200726069509983, 0.012613839619526905, 0.08694237470626831, 0.05222911347768136, 0.08785320618855101, 0.01770220510661602, 0.036044723354279995, 0.08242381324193307, 0.0726710937118956, 0.1077830892588411, 0.05186083520363484, 0.021548277299318994, 0.06842574437281915, 0.05814305506646633, 0.018542799732780883, 0.0070863428076596135, 0.03932406274335725, 0.02021730880785201, 0.047503829534564695, 0.11041056684085301, 0.1571849440889699, 0.1384843018438135, 0.04711065241800887, 0.10447055593665157, 0.018636288287650262, 0.25202744773456026, 0.28490282222628593, 0.08316407459122793, 4.616028785705566, 42.49808692932129, 69.2674116407122, 69.45745182037354, 69.24802616664341, 67.56179564339774, 46.57031495230538, 40.818109784807476, 32.95286362511771, 25.399987629481725, 22.895771741867065, 19.548805373055593, 44.447556904384065, 35.60625212533133, 28.35659204210554, 33.49143239430019, 13.907053112983704, 2.2996329111712317, 0.0734813188069633, 0.04043038694986275, 0.02521504322066903, 0.18803803995251656, 0.366214143378394, 0.4368119936968599, 1.1562514645712716, 1.6730504419122423, 2.7365028517586842, 3.8165130359785895, 5.160003687654223, 3.1997290466512953, 4.675214844090598, 4.488949707576206, 2.440723248890468, 2.7481929787567685, 2.284032468284879, 1.2184897363185883, 2.887219701494489, 2.864996973957334, 8.101510099002294, 9.762972899845668, 9.107346091951642, 11.475286960601807, 10.528158903121948, 11.770171982901436, 12.819452456065587, 13.215174078941345, 13.791083335876465, 13.633909004075186, 16.07193374633789, 22.314294372286113, 24.577878509249004, 24.56831431388855, 29.919238431113108, 37.52753325871059, 37.82784135001046, 46.988804953438894, 45.16767862864903, 56.0774621282305, 52.312684944697786, 55.73291138240269, 52.30888080596924, 55.272968428475515, 53.023704528808594, 34.68897526604788, 21.22792441504342, 14.946304730006627, 12.574575356074742, 12.686385767800466, 9.364674363817487, 8.291690979685102, 7.939658761024475, 11.284089037350245, 10.468624132020132, 4.470278595175062, 3.06945292864527, 1.5022956388337272, 0.8090075318302427, 0.375201692538602, 0.9964782893657684, 0.1866419677223478, 1.5467993936368396, 2.859341791697911, 2.8796309658459256, 3.5670303659779683, 3.262533596583775, 2.6971645397799353, 2.6426765492984226, 1.493425829069955, 0.8510060267789024, 0.32411750512463705, 0.12975336105695792, 0.04016993467562965, 0.08093554845878057, 0.027673579153737853, 1.8013501231159483, 12.727266362735204, 35.08503648212978, 51.396596227373394, 66.11204705919538, 59.38882419041225, 61.526131766183035, 95.7259920665196, 96.43674414498466, 46.69600439071655, 45.328272342681885, 56.120214394160676, 60.901704107012065, 57.14443792615618, 67.47519329616001, 77.26660864693778, 72.28276307242257, 9.289659006255013, 0.22885110708219664, 0.04018821440903204, 0.057418929279914925, 0.01391480753331312, 0.02571176308473306, 0.030365727908377136, 0.050615781119891574, 0.08193524088710546, 0.06660094657646758, 0.06980241050145455, 0.04198371984862855, 0.08545757723706109, 0.041174057937626324, 0.07779682188161782, 0.02073102767047073, 0.04381074323984129, 0.06649710357721363, 0.03888813452795148, 0.01200526240946991, 0.0703625004472477, 0.04970977741426655, 0.07022298007671322, 0.028091051216636385, 0.07209199121487991, 0.19516428613236972, 0.13761892542243004, 0.08870144960071359, 0.05732304549642971, 0.031115010380744934, 0.01795836734319372, 0.058615654706954956, 0.048360205188925774, 0.0842930618673563, 0.061603719368577003, 0.22943204162376268, 0.2376393297953265, 0.09911503509751388, 0.23157243962798799, 0.22761147788592748, 0.16375038107591017, 0.14340853903974804, 0.24700018178139413, 0.13064739879752907, 0.23575273102947644, 0.2096358367374965, 0.32350970059633255, 0.2004203540938241, 0.14837916088955744, 0.20263551308640412, 0.062180888040789535, 0.1673652763877596, 0.10625546944460698, 0.18390536813863687, 0.09219777091805424, 0.1387927910046918, 0.15676578586655004, 0.19174490390079363, 0.15404095208006247, 0.15379999072424003, 0.21884909378630774, 0.10232353543064424, 0.3557338986013617, 0.48074971458741594, 0.2587118319102696, 7.111272377627237, 56.63269962583269, 82.31119537353516, 78.73607621874127, 77.51855727604458, 73.80488409314836, 51.878453799656455, 39.23643227985927, 34.84125893456595, 30.964018208639963, 37.196326528276714, 33.45298106329781, 63.50640310559954, 50.969459193093435, 47.24880307061331, 52.46646595001221, 20.365317719323293, 3.7891345279557362, 0.34326307635222164, 0.19520924586270536, 0.20686142918254646, 0.19335920656366007, 0.38591073932392256, 0.29512693360447884, 2.3944089455263953, 2.3499624047960554, 4.952155275004251, 7.627678564616612, 7.793033531733921, 8.901038442339216, 15.425678321293422, 9.852063570703779, 7.860222612108503, 5.89004613671984, 8.029688307217189, 6.5877490639686584, 11.128954001835414, 7.12764971596854, 20.902870314461843, 20.607648304530553, 17.386819532939366, 23.59939844267709, 19.63452356202262, 18.236917734146118, 20.9239250932421, 18.418573175157817, 17.73278944832938, 16.952911479132517, 19.217067105429514, 26.453680208751134, 28.01900339126587, 28.128569534846715, 37.68089737210955, 43.89517511640276, 42.13000610896519, 50.94233342579433, 51.70061813082014, 61.398138999938965, 56.71822500228882, 62.23789133344378, 56.99449232646397, 60.41883904593331, 57.87775427954537, 38.57880960191999, 24.959200859069824, 18.612853493009293, 14.393805691174098, 16.395026717867168, 13.267751966203962, 15.577590261186872, 12.391723956380572, 16.188712120056152, 11.897589785712105, 5.373734184673854, 7.3623789719172885, 4.2935264110565186, 6.338822901248932, 7.493797200066703, 10.027580278260366, 5.7917973058564325, 6.400822980063302, 10.644754018102374, 7.038193830421992, 9.480124763080052, 7.666994946343558, 3.466013546500887, 3.256970477955682, 1.360644776906286, 0.5788104555436543, 0.2879105508327484, 0.2185777612030506, 0.25401886659009115, 0.1526643130928278, 0.14307626044111593, 2.7451520562171936, 18.86903010095869, 54.60727194377354, 64.56372438158307, 68.3661608014788, 56.64203453063965, 52.72415379115513, 95.07904529571533, 105.81899397713798, 48.10130534853254, 46.52339029312134, 61.20600046430315, 68.67868382590157, 67.58439118521554, 78.60268470219204, 86.44900744301933, 83.43319048200334, 9.914522664887564, 0.4150840538953032, 0.14309607366366045, 0.1425902529486588, 0.14236595641289437, 0.0934954419998186, 0.11542386854333536, 0.23645542189478874, 0.21337292263550417, 0.1946545299142599, 0.3334566982729094, 0.20833481369274004, 0.28595305872814997, 0.2137494824294533, 0.17435033300093242, 0.19685014709830284, 0.17921365132289274, 0.11535522794084889, 0.15313121303915977, 0.1624626980296203, 0.18844844507319586, 0.14566325662391527, 0.17128316472683633, 0.10376327138926301, 0.40507061406970024, 0.511983930000237, 0.1792538748787982, 0.18719044114862168, 0.12502953596413136, 0.11177558252321822, 0.15605282198105538, 0.14953915721603803, 0.15578330787164824, 0.19261398512337888, 0.20794648810156754], [0.09497125566537891, 0.04001184619430985, 0.04383724003231951, 0.12323610005634171, 0.07837128319910594, 0.024863960720332604, 0.028516224651996578, 0.059085139871707985, 0.047623075278741975, 0.07493610467229571, 0.09839970312480416, 0.025863006844052246, 0.04615187904398356, 0.030281046738049815, 0.04367351631766983, 0.002879060131298112, 0.06344451023531811, 0.04057823633775115, 0.02830051158421806, 0.07891538007450954, 0.0663720563586269, 0.025277968861960938, 0.06995432770677976, 0.05759205748992307, 0.05294454723064389, 0.00613767239597759, 0.13782790063747338, 0.03158669399895838, 0.025666521762364676, 2.503326735326222, 30.3877763066973, 61.34060096740723, 62.62350940704346, 63.1911563873291, 54.76123360225132, 39.92961236408779, 48.57868480682373, 19.5539505141122, 17.849597351891653, 19.190425974982126, 22.950285570962087, 33.14249733516148, 29.381433963775635, 43.24395867756435, 46.399288518088206, 8.329092264175415, 0.32654568340097156, 0.02593520636271153, 0.0640216992635812, 0.07552988388176475, 0.04822996039209621, 0.03955968402858291, 0.5119546715702329, 1.4784338963883263, 0.5744735854012626, 1.3381390188421523, 0.8714528381824493, 1.8700227524553026, 2.078698217868805, 2.372127592563629, 1.8583156892231532, 1.6170516524996077, 0.5733562824981553, 2.4376406371593475, 2.98321818453925, 4.464644040380206, 8.319987518446785, 13.757270795958382, 25.382641451699392, 26.012083973203385, 23.630250181470597, 26.918368782315934, 21.284328154155187, 22.76899664742606, 29.569344520568848, 32.908975328717915, 41.51798793247768, 50.53666285106114, 50.04020711353847, 48.32413060324532, 56.22181095395769, 42.28938736234392, 38.9776223046439, 45.82148674556187, 30.347049440656388, 32.33597476141793, 37.93904032026018, 42.970790249960764, 41.87403794697353, 43.44079419544765, 40.904375144413535, 39.43737070901053, 36.22836256027222, 43.05142062050955, 30.65945781980242, 36.69288785117013, 38.45050416673933, 34.350427763802664, 35.1515793800354, 29.75255114691598, 32.54043940135411, 38.65492016928536, 49.625931194850374, 48.01100655964443, 37.47128759111677, 29.9370744568961, 22.564980166299, 11.865446550505501, 5.189252998147692, 0.6745430071439061, 0.9466396208320345, 2.2408187985420227, 1.3894256268228804, 3.622361694063459, 3.334898433515004, 1.8128906467131205, 1.672164112329483, 2.3142629946981157, 0.5691242867282459, 0.08457223831542901, 0.10333335160144738, 0.042337229807994196, 0.045898364790316136, 0.037663992893482955, 0.07431811533336129, 0.07511741601462875, 4.84896844625473, 19.452129874910625, 30.927474158150808, 30.84383521761213, 32.361707414899556, 40.779675824301584, 31.565700939723424, 15.982064008712769, 10.810695239475795, 19.29892209597996, 37.08596134185791, 42.084877559116904, 55.94121142796108, 62.78071240016392, 71.35483115059989, 50.900077956063406, 0.6595387522663388, 0.022479887220210264, 0.06528342156005756, 0.03097738651558757, 0.06273784315479652, 0.04445884257022824, 0.023675879829430153, 0.06655537616461515, 0.022962427398722087, 0.03854009695351124, 0.010832701310781496, 0.14474916138819285, 0.05680880416184664, 0.03065429188843284, 0.047766076533922126, 0.07189001848122903, 0.04091438937133976, 0.11012841840939862, 0.05392526103449719, 0.02055564842053822, 0.03100633281948311, 0.08823823409953288, 0.014859301137870975, 0.11073385485048805, 0.04008121622194137, 0.11551678712878909, 0.05455628163846476, 0.048148454765656164, 0.035074920393526554, 0.008307486589598869, 0.07694783886628491, 0.026197270157613924, 0.06663363839366607, 0.02282825897314719, 0.05543604639491864, 0.026613931371165172, 0.04903373261913657, 0.12041567425642695, 0.11117396623428379, 0.01819532025339348, 0.049993679858744144, 0.044926058035343885, 0.04425867813240204, 0.08390751148441009, 0.063707428984344, 0.04450344946235418, 0.04358003794082573, 0.06399631526853357, 0.02644638411168541, 0.049432602644498856, 0.02508382642242525, 0.030763427460832254, 0.030189254520727054, 0.04354784145419087, 0.12787304552538054, 0.02486783515528909, 0.016377669127125825, 0.08632011738206659, 0.09501762674855334, 0.03282337496057153, 0.10754855362964527, 0.020255184632592967, 0.09751933107950858, 2.975688725709915, 37.157242911202566, 73.3613805770874, 72.56317847115653, 71.10017272404262, 61.194931983947754, 48.44360140391758, 52.894117150987896, 25.05114984512329, 27.648174558367046, 25.11807315690177, 27.803822892052786, 28.619068929127284, 34.26586471285139, 41.75450808661324, 37.37547888074602, 6.8985311303819925, 0.11424693598278932, 0.05389060825109482, 0.029939350073358843, 0.041361286105321984, 0.0744700189679861, 0.4544364794024399, 1.7612631427390235, 2.5177464187145233, 2.5134098742689406, 2.776561822210039, 3.0471192470618655, 3.9051216755594527, 3.5978764593601227, 3.0341526057038988, 2.980159891503198, 2.2304138711520602, 1.115883082151413, 0.6155803224870137, 2.6474336768899644, 4.557900156293597, 9.77179103238242, 15.379213980266027, 24.144401243754796, 28.580608912876674, 26.6546915939876, 27.425655024392263, 25.480020454951696, 26.428536415100098, 31.085569994790212, 33.67682770320347, 45.12298434121268, 53.39633641924177, 52.54552950177874, 51.80474383490426, 57.469356536865234, 47.83587374005999, 43.088544845581055, 48.41297721862793, 35.802215644291465, 38.59866407939366, 43.34446784428188, 49.40812948771885, 48.95752143859863, 51.03198255811419, 47.49317121505737, 45.46609680993216, 42.28776843207223, 47.269890853336875, 35.343005725315635, 41.083975655691965, 40.59363085883004, 37.15665578842163, 37.304968561444966, 32.62318549837385, 35.6905129296439, 42.28028522218977, 51.50311211177281, 51.703880310058594, 40.60668304988316, 31.913201195853098, 24.475535018103464, 13.713137575558253, 5.860118508338928, 1.6249880152089256, 0.5237947276660374, 0.8557222251381192, 0.5966189056634903, 2.4547983450548987, 2.718316159078053, 3.064611988408225, 3.9342007551874434, 3.0225265324115753, 1.2439234001295907, 1.23849099448749, 0.3435548464102404, 0.1068779778267656, 0.16295355026211056, 0.015574726409145763, 0.14163315216345446, 0.12365954662007944, 3.4831315193857466, 21.755690472466604, 37.26978983197893, 36.01837410245623, 29.433541979108536, 53.25843552180699, 41.54352256229946, 17.794060400554113, 24.056450945990427, 32.535731996808735, 49.371741771698, 48.7653933252607, 65.31541524614606, 69.41820839473179, 78.67031846727643, 66.50290407453264, 2.703387303011758, 0.08174741560859339, 0.06885501955236707, 0.027409410203940103, 0.031453076883086135, 0.09069045965692826, 0.03286527110529797, 0.015482542337849736, 0.01747099599534912, 0.04187947990638869, 0.026275596847491603, 0.08339513612112828, 0.031413375799145014, 0.0766817717147725, 0.03615352983719536, 0.047409676015377045, 0.11235336866229773, 0.046053728953536065, 0.07708427190248456, 0.05633472192234226, 0.06500773278198071, 0.05064089370093175, 0.07217201084962913, 0.08147308390055384, 0.11203998726393495, 0.09071496834180184, 0.0451615537915911, 0.04533339278506381, 0.03793749339612467, 0.015092578084607209, 0.02540127563822482, 0.011167419242805668, 0.005179581797814795, 0.010833256861328014, 0.15461750328540802, 0.14664402471057006, 0.2268793928836073, 0.3188103027641773, 0.19070860450821264, 0.11549640393682889, 0.1535174623131752, 0.1374553306294339, 0.12378888896533422, 0.256412819560085, 0.2149584689842803, 0.18091875554195472, 0.2366049438714981, 0.1424677095242909, 0.14634312157120022, 0.1224170404353312, 0.15949159674346447, 0.0906154883227178, 0.10042493338031427, 0.2233783421771867, 0.1933595865432705, 0.14629113221807138, 0.10630173874752862, 0.24871375411748886, 0.20920246999178613, 0.13763819581695966, 0.248051395373685, 0.19487795792520046, 0.17221993660288198, 6.42272196497236, 48.870922565460205, 82.06284591129848, 80.3371913092477, 79.70566259111676, 70.22447735922677, 53.71588407244001, 58.80030482155936, 28.547665766307286, 25.691796336855205, 31.04501335961478, 35.579449449266704, 49.56564514977591, 42.28368289130074, 57.57315567561558, 57.67785808018276, 11.618943572044373, 0.7823039761611393, 0.14654113166034222, 0.2002161286239113, 0.2913218177855015, 0.11219435398067747, 0.2607716199542795, 1.6458772314446313, 3.8532277515956332, 4.102646367890494, 4.232549454484667, 5.010229187352317, 6.629436952727182, 9.703226208686829, 8.38365386213575, 7.15496221610478, 6.796857271875654, 6.761031491415841, 8.401911990983145, 7.834408317293439, 8.416290419442312, 13.010392427444458, 18.011898585728236, 30.768211024148123, 33.18233830588204, 30.4209782736642, 33.381449358803884, 29.85177837099348, 30.706590924944194, 34.560023648398264, 40.119600432259695, 48.546215874808176, 55.83668620245797, 57.36965683528355, 53.89968824386597, 61.30729825156075, 55.794159752982004, 48.28589814049857, 51.843459197453086, 41.31962728500366, 43.421373980385916, 49.598131452287944, 53.72631679262434, 54.756765910557334, 55.7133799961635, 53.900285788944785, 52.29443550109863, 48.31943014689854, 52.324125153677805, 41.519026688167024, 45.53707613263811, 43.50733361925398, 38.3233972958156, 39.14742585590908, 34.32837070737566, 37.09060968671526, 45.558170863560264, 56.046028477805, 55.27115842274257, 42.810074942452566, 34.44019848959786, 28.488154445375713, 15.064722878592354, 8.706414188657488, 3.565617493220738, 3.4759364426136017, 4.613666832447052, 5.730069509574345, 11.491182701928274, 10.862744195120674, 7.506767749786377, 7.247260783399854, 7.3042642389025, 2.4457902227129256, 1.355079704097339, 0.4808663140450205, 0.3279643915593624, 0.4487011485866138, 0.2089557410883052, 0.29824086651206017, 0.2386319451034069, 6.673179336956569, 28.178247417722428, 43.360076972416465, 43.47475699016026, 44.21228395189558, 48.880108083997456, 38.742133957999094, 27.632994481495448, 22.599024602345057, 31.756095477512904, 53.86859505517142, 57.88823216302054, 73.35959489004952, 80.78453717912946, 85.55343328203473, 77.55987126486642, 4.228519065039499, 0.4237175163413797, 0.15615108742245606, 0.13393465669027396, 0.138609450842653, 0.160752341949514, 0.1318693318005119, 0.1517351950917925, 0.11602505056985787, 0.1499641915517194, 0.11599807201751641, 0.29944358340331484, 0.14975145725267275, 0.15439459096108163, 0.09829041148935046, 0.1651215646415949, 0.10749013176453964, 0.2601712521697794, 0.18744048130299362, 0.23785627101148876, 0.12242941691407136, 0.17442859522998333, 0.17862741063748086, 0.22853026858397893, 0.227769956524883, 0.27974419189350946, 0.14569585344621114, 0.1145190420959677, 0.11329807939806155, 0.10068227457148687, 0.11932952968137604, 0.0853845736544047, 0.20919267194611685, 0.21730689225452288], [0.047066147306135724, 0.04088433027001364, 0.0443598069915814, 0.08534526612077441, 0.08353577607444354, 0.03194934043235012, 0.03188715948324118, 0.05371677436466728, 0.07213814516684838, 0.04065758761550699, 0.04200997236850006, 0.05693311856261321, 0.07181876551892076, 0.07549403009137937, 0.03978642329041447, 0.027817618567496538, 0.03885008567678077, 0.058641126911555014, 0.06232217260237251, 0.005836115742567927, 0.05309749920187252, 0.02772992300534887, 0.036717243159988096, 0.0462563293320792, 0.031881575140037706, 0.02510569560607629, 0.04813522672546761, 0.09027756431273051, 2.9443870910576413, 27.02657307897295, 66.86653804779053, 65.78743416922433, 64.33955465044293, 53.30133022580828, 33.83609083720616, 37.37594093595232, 69.79382801055908, 44.7521242414202, 26.363678455352783, 31.426056044442312, 21.967561892100743, 36.585413115365164, 41.652063846588135, 25.108458587101527, 2.9819275566509793, 0.037686330266296864, 0.064530254474708, 0.028661424360637153, 0.022872889613998786, 0.01467652924891029, 0.17118168302944728, 0.6216299778648785, 1.2222216789211546, 0.410409653293235, 0.21018532796629838, 1.12054543197155, 1.7584845146962573, 1.8479279151984622, 3.459835512297494, 1.104827629668372, 1.9814779375280653, 3.872298385415758, 5.0627540946006775, 11.552690761429922, 15.740829501833234, 22.268446683883667, 31.299150671277726, 40.31117268971035, 44.89144951956612, 45.55100727081299, 43.355706555502756, 37.92124250956944, 38.720789091927664, 44.73851272038051, 50.224292687007356, 57.01551757540022, 61.8045460837228, 58.78589425768171, 58.763798986162456, 59.70993518829346, 61.85120323726109, 52.4146671295166, 48.73129504067557, 60.83529322487967, 41.81038202558245, 24.10530025618417, 45.47136354446411, 43.1606810433524, 38.5218517439706, 42.364445277622764, 39.99698209762573, 30.805095536368235, 35.58118649891445, 53.70069183622088, 42.9725272996085, 52.29740238189697, 55.934159006391255, 57.71855020523071, 59.12229129246303, 60.82237652369908, 60.71843147277832, 59.4113780430385, 59.16869831085205, 63.31395190102713, 63.67658533368792, 64.13763999938965, 62.689732687813894, 67.73668180193219, 56.78845044544765, 35.33664117540632, 18.35434750148228, 4.858198693820408, 0.555877111852169, 1.6145216396876743, 1.7915914867605482, 2.4620348938873837, 3.3286530886377608, 2.3463799570287978, 2.3283092124121527, 1.2626031977789742, 0.13741152440862997, 0.04975316972870912, 0.05351955137614693, 0.03790390591270157, 0.10205121897161007, 0.01928001954885466, 0.03304621943139604, 0.3798758488680635, 17.025935309273855, 43.541966915130615, 58.74182183401925, 28.820033414023264, 24.903222697121755, 33.170508997780935, 14.68926307133266, 16.55612243924822, 16.690128871372767, 38.8858574458531, 45.647535119737896, 56.16267136165074, 61.30367129189627, 71.51177706037248, 31.88501582826887, 0.3318905308842659, 0.05794494319707155, 0.05721264106354543, 0.05179080021168504, 0.02737278288363346, 0.1471412144601345, 0.025459349754133394, 0.03845343106825437, 0.06124583285834108, 0.05608069537473576, 0.03862253895827702, 0.08783447183668613, 0.025655300489493778, 0.022908343068723167, 0.12685813355658734, 0.09091006751571383, 0.028626897106213228, 0.007513633696362376, 0.03581180263842855, 0.05202838585578969, 0.007194983473579798, 0.05472672963514924, 0.08540143524961812, 0.061515536957553456, 0.03949182713404298, 0.03496710117906332, 0.03582436910697392, 0.011267305534732128, 0.014011195977218449, 0.032991495582142046, 0.06307582823293549, 0.04803921741300395, 0.06379788448768002, 0.023518742993474007, 0.03880315480221595, 0.036632870723094256, 0.1462078352591821, 0.019763435037540536, 0.014225445953863007, 0.048694682241018326, 0.013448237524633961, 0.021199939473133003, 0.03427822867940579, 0.03172872494906187, 0.06434413231909275, 0.018320523535034487, 0.037695103724087985, 0.03735091683587857, 0.0308934313777302, 0.054029470442661216, 0.01902078354864248, 0.04551999670054231, 0.061708729448063035, 0.043554640375077724, 0.05892689872000899, 0.02456434510116066, 0.028684080644909824, 0.15045750008097716, 0.026424357168642536, 0.07042938364403588, 0.117003647344453, 3.170948305300304, 33.941519328526084, 76.4271342413766, 73.29563672201974, 69.91530336652482, 59.69831085205078, 43.00440216064453, 50.960944175720215, 70.25879451206752, 38.80218723842076, 24.874262605394634, 25.08483644894191, 25.386410849434988, 38.64535597392491, 35.60454634257725, 23.26979500906808, 2.559765866824559, 0.029978688141064982, 0.0188281949542995, 0.09684215991624764, 0.22649873473814555, 0.24260037073067256, 1.0078448908669608, 1.032377677304404, 2.9168505115168433, 3.0608751603535245, 2.310232388121741, 2.8269219313349043, 3.827571962560926, 2.839903554746083, 1.7552287408283778, 3.2869443552834645, 1.5884601409946169, 2.6393533561910902, 4.533747783729008, 10.939639908926827, 16.23108744621277, 23.645254816327775, 33.57520335061209, 42.20738819667271, 47.634834562029155, 47.20747171129499, 46.9253887448992, 40.87063816615513, 39.72598845618111, 45.87888928822109, 52.154300757816856, 59.80865519387381, 62.022386005946565, 60.9517102922712, 60.56860746656145, 62.87836933135986, 65.35278265816825, 57.094303199223106, 53.58691855839321, 62.50187424251011, 43.92553527014596, 30.515650953565324, 48.23748309271676, 49.154023442949565, 43.58447599411011, 48.38297142301287, 44.17884227207729, 36.087400981358115, 39.27315003531319, 56.53936447416033, 47.36769022260393, 56.449687549046104, 57.11192730494908, 58.63407611846924, 61.73770441327776, 62.21168967655727, 63.147681508745464, 63.61762292044503, 62.5725930077689, 65.77060563223702, 66.39569337027413, 66.38467352730888, 67.06675733838762, 69.9859595979963, 59.09381757463728, 38.70739296504429, 21.598475319998606, 6.034644229071481, 0.6197039155023438, 0.22817726752587728, 0.9557649940252304, 1.90404069849423, 2.8587168880871365, 2.6649815695626393, 4.093444781644004, 2.5539678122316087, 1.4639295318296977, 0.6105412500245231, 0.5216056108474731, 0.03327314529035773, 0.05594913761264511, 0.04425500725795116, 0.03741821733170322, 0.6612037143536976, 17.383086613246373, 42.00927768434797, 48.410451548440115, 26.42583703994751, 18.17275980540684, 26.37455586024693, 14.81310428891863, 20.747958489826747, 27.40213189806257, 50.700782775878906, 55.08970969063895, 62.4666051864624, 68.83590071541923, 76.97697298867362, 43.6010092326573, 0.7401970784579004, 0.055571549838142734, 0.06028190601084914, 0.037539529215012274, 0.03024327608623675, 0.13655809020357473, 0.002901215783952336, 0.012232921086251736, 0.02143317231509302, 0.10525361248957259, 0.09796137628810746, 0.020114668511918614, 0.009254467873168843, 0.013618012923481209, 0.05579410593158432, 0.12892770607556614, 0.011445529542730322, 0.016622596520132253, 0.005772957278947745, 0.07263853760170084, 0.04289122650931988, 0.015433996549940534, 0.015902287493060743, 0.059828746398644786, 0.02057943955462958, 0.018893488682806492, 0.03769324793081198, 0.05741742971752371, 0.008910290314815938, 0.049079625335122855, 0.02788291229600353, 0.09182251391134091, 0.09369894822261163, 0.11926223257822649, 0.19556025202785218, 0.1456651429512671, 0.1956098936498165, 0.15069300601524965, 0.1797914510326726, 0.16411573147135122, 0.1447930218917983, 0.1393894539879901, 0.16130624365593704, 0.2211833085332598, 0.14442047902515956, 0.10419927085084574, 0.19266233752880776, 0.135922370744603, 0.09608634654432535, 0.13801139007721627, 0.12375242449343204, 0.14463072988603795, 0.12083582313997404, 0.19807825476995536, 0.19834794529846736, 0.1371881506804909, 0.09491303736077887, 0.18656280982707227, 0.09662079465176378, 0.27357723138162066, 0.2511138410440513, 5.054164818355015, 45.92894063677107, 88.49971267155239, 79.81481879098075, 82.08876964024135, 69.58932862962995, 49.9384229523795, 49.68843024117606, 77.34025260380336, 53.54869304384504, 36.507628032139365, 41.86708280018398, 33.54890094484602, 49.22999504634312, 55.66610445295061, 34.55881813594273, 4.53034142936979, 0.2723409948604447, 0.21556094022733824, 0.15094582816319807, 0.2849278194563729, 0.2839240218911852, 0.7185121306351253, 1.422805967075484, 3.52067545907838, 3.896728251661573, 3.378940675939832, 6.581863505499704, 6.438444869858878, 6.843282963548388, 11.952561327389308, 9.010450857026235, 9.18782273360661, 9.184336474963597, 8.899392587797982, 15.252280814307076, 19.324698175702775, 26.787669692720684, 36.50041580200195, 46.19112048830305, 51.12098550796509, 49.95708581379482, 49.645639760153635, 45.620284284864155, 47.047836848667686, 51.01179804120745, 55.405418464115684, 60.49804156167166, 62.54508508954729, 59.76581954956055, 62.5112612588065, 60.208100182669504, 67.14215918949672, 63.52647645132882, 54.53564991269793, 62.79976436070034, 48.82972322191511, 35.530607087271555, 53.5203617640904, 54.90524196624756, 48.217183930533274, 55.260364396231516, 49.59925011226109, 40.71212543760027, 43.9648551259722, 59.56371034894671, 51.207497528621126, 61.06436838422503, 58.65870748247419, 58.528797013419016, 62.371414865766255, 61.762710980006624, 65.7673260825021, 66.793470791408, 64.38028499058315, 67.3284890311105, 68.89405018942696, 70.1285366330828, 69.8595996584211, 75.9692132132394, 64.72269221714565, 42.42863621030535, 24.60289376122611, 7.3009021793093, 2.9221005269459317, 4.8434255208287915, 7.285516696316855, 9.047533392906189, 12.169187920434133, 9.633321251188006, 7.215671667030879, 4.643587512629373, 3.0743752930845534, 0.667860848563058, 0.3717686581824507, 0.28814279979893137, 0.22220249527267047, 0.1391647503312145, 0.15123458552573407, 1.033234259911946, 24.886553968702042, 57.87743813650948, 78.52665751320976, 44.092483111790244, 38.25173704964774, 47.58867767878941, 23.12872747012547, 26.217154843466624, 28.279512201036724, 55.350117751530235, 60.50822067260742, 72.69836262294224, 77.28017153058732, 85.94281727927071, 50.58025932312012, 1.438144332596234, 0.17391495779156685, 0.12781815204237187, 0.13887280385409081, 0.12576379227851117, 0.21739660815468856, 0.0778042111279709, 0.1776493295494999, 0.17558091054005281, 0.1985783622201, 0.22939871198364667, 0.18351830462259905, 0.11650113788034235, 0.15087851748934814, 0.21944486110338143, 0.2813714002924306, 0.07122928143611976, 0.1257112600973674, 0.10484497155994177, 0.2570760468287127, 0.16184593683906964, 0.14220355584153108, 0.12674035344805035, 0.13792535183685167, 0.19566515354173525, 0.15882359258830547, 0.08563687333038875, 0.14455226409648145, 0.14173106476664543, 0.1782018741858857, 0.19436786243958132, 0.25727694747703417, 0.2609527888042586], [0.026101225222061788, 0.053284964856824706, 0.035980428768587966, 0.047604066120194535, 0.03364314704335161, 0.029349652252026966, 0.02068848691747657, 0.013882963884887951, 0.037127814521746974, 0.04406016253467117, 0.03730270353012851, 0.09679527993180922, 0.0180584054573306, 0.07068612093904189, 0.05124125470008169, 0.06568183018160717, 0.07885708034570728, 0.030540199617722204, 0.06252622843853065, 0.04347598120304091, 0.008449192691062177, 0.04290302962596927, 0.02705852617509663, 0.01902067837571459, 0.028584505630923168, 0.032220347318798304, 0.02000167716427573, 0.15434036244239124, 15.244448457445417, 61.863994870867046, 63.248895917619976, 63.945654324122835, 57.76516566957746, 49.730876786368235, 30.38006728036063, 17.89942809513637, 62.66158553532192, 54.5204542023795, 43.11094583783831, 49.36672517231533, 43.51396220070975, 40.370020457676475, 29.299761363438197, 3.584806897810527, 0.16848830612642424, 0.05509850914989199, 0.025285495511655296, 0.03833527098010693, 0.09739132544824056, 0.2662412364568029, 1.376995625240462, 0.760790073445865, 3.2927213481494357, 3.336499124765396, 1.5234804792063577, 1.46843598144395, 3.999436523233141, 2.551421297448022, 1.528494581580162, 4.6771416664123535, 8.21227046421596, 14.897406782422747, 20.0099173613957, 30.42902081353324, 40.60207292011806, 50.621649742126465, 57.141005516052246, 58.57756641932896, 58.9237117767334, 62.83255985804966, 58.0595052582877, 51.0149108341762, 50.97341619219099, 56.389252117701936, 60.85178130013602, 61.64104107448033, 67.28818947928292, 61.544259616306846, 60.05364172799246, 63.02870055607387, 63.874574252537315, 63.879479680742534, 64.0399135862078, 57.52919789722988, 53.12307071685791, 22.2512811592647, 39.85747964041573, 42.37329033442906, 38.61147655759539, 41.36841753550938, 31.297000203813823, 41.581199169158936, 52.5297258240836, 65.94894504547119, 59.21425070081438, 61.34251172201974, 60.71568693433489, 62.224384035382954, 64.01485838208879, 65.04590157100132, 52.26191445759365, 56.680180140904014, 56.71595294134957, 60.114646911621094, 53.5949124608721, 57.67118780953543, 56.11517695018223, 59.112362316676546, 57.64051846095494, 63.109112058367046, 63.87089170728411, 56.7387604032244, 32.572783265795024, 13.491371052605764, 2.0114494264125824, 1.2362650739295142, 2.9933784050600867, 2.5462160110473633, 3.6272964349814822, 1.905490483556475, 1.023093146937234, 0.3346601208405835, 0.5362264662981033, 0.18938630260527134, 0.023961955282304968, 0.023874587113303796, 0.11900415856923376, 0.06610882548349244, 0.4384596667119435, 11.889956321035113, 33.70314053126744, 55.61421530587332, 57.37750482559204, 43.36409650530134, 53.05173703602382, 25.756833212716238, 19.367646728243145, 18.557882819856914, 27.599215814045497, 41.69315896715437, 60.11107553754534, 64.53413200378418, 59.158171789986746, 8.146387645176478, 0.25212770806891577, 0.022169978224805424, 0.04318217553996614, 0.048131691558020454, 0.03203996217676571, 0.06565206963568926, 0.013516412482463887, 0.010393525457142718, 0.08993996599955217, 0.05349253550437944, 0.04645833938515612, 0.03623277594202331, 0.05980229710361787, 0.01564786400246833, 0.030139640040163482, 0.07374954369983502, 0.040341251197138, 0.08221642579883337, 0.04924244320552264, 0.06091286215398993, 0.019437281913789253, 0.056565094739198685, 0.0037110611114517917, 0.021790426091424057, 0.05560261995664664, 0.017081750989226357, 0.06613100000790187, 0.06061195222926991, 0.02988236670249275, 0.03405170315610511, 0.011718381196260452, 0.014474939887544938, 0.0017603972955839708, 0.060672830391143046, 0.018245014461821744, 0.07891138350324971, 0.056570431417120356, 0.03022746622030224, 0.07680989948234387, 0.04074722548414554, 0.0382536092906126, 0.06850410838212286, 0.03002801424424563, 0.04245376819744706, 0.039501177346599955, 0.024574209303994263, 0.025229082110204866, 0.04227850938748036, 0.023668549954891205, 0.04803014539980462, 0.0177403947538031, 0.04861893059153642, 0.01802020223944315, 0.01698841680107372, 0.024735795633335198, 0.04476024782551186, 0.035708583891391754, 0.045260416343808174, 0.03404630880270686, 0.14625958033970424, 20.9080137184688, 72.15694509233747, 72.14939934866769, 71.86021532331193, 66.50487041473389, 58.01535293034145, 37.96072564806257, 24.83733640398298, 61.895567485264365, 49.1790578024728, 39.08183486121041, 38.393921511513845, 39.71324545996529, 40.953981808253694, 26.13019118990217, 3.2540580970900397, 0.10191619050289903, 0.036231629217841795, 0.09674218456659998, 0.23264067087854656, 0.5039995270115989, 1.2942763439246585, 2.8084638246468137, 3.515738981110709, 3.2114356756210327, 2.877062737941742, 3.480287100587572, 3.0676880862031664, 3.3948086244719367, 3.1624150489057814, 3.4281154658113207, 7.579483253615243, 9.753224577222552, 15.395071506500244, 21.971124580928258, 34.07703699384417, 42.677854197365896, 53.73092344829014, 59.897592135838096, 61.29456220354353, 63.676376887730186, 64.68119757516044, 59.511925424848286, 55.69258403778076, 56.20183488300869, 59.076884814671104, 60.814983640398296, 62.653622899736675, 66.19058949606759, 61.286453655787874, 59.88292448861258, 62.745505877903526, 66.37916360582624, 67.25862489427838, 64.49305425371442, 61.3991881779262, 56.698266301836284, 26.454574789319718, 45.98466518947056, 46.03796829496111, 43.830727100372314, 46.401209694998606, 37.08474888120379, 43.77307442256382, 55.9128349849156, 65.89866093226841, 62.68397263118199, 62.46229730333601, 59.29942866734096, 62.21499007088797, 66.04736627851213, 66.78834996904645, 55.38625880650112, 59.90975843157087, 59.47551686423165, 61.74729987553188, 56.81243215288435, 60.025174958365305, 58.65875611986433, 62.81213215419224, 61.28997639247349, 65.78281361716134, 67.94541263580322, 59.60299546377999, 35.12068421500069, 14.997700554983956, 2.8757160902023315, 1.2224711626768112, 1.2196353205612727, 1.7235162939344133, 3.728866287640163, 1.100966602563858, 2.0326160277639116, 1.8049411475658417, 1.902330355984824, 0.9766874313354492, 0.281814592225211, 0.07327359888170447, 0.15184606771383966, 0.027326815528795123, 0.3020459551896368, 10.876690966742379, 36.24340541022164, 49.31545441491263, 49.892356395721436, 35.110525948660715, 32.129943302699495, 22.115489040102275, 19.23342490196228, 31.24251937866211, 40.51156221117292, 50.26830952508109, 65.21432590484619, 71.57627023969377, 70.19461400168282, 16.189177649361746, 0.14570111887795584, 0.03046800009906292, 0.04198322791074004, 0.04004128443609391, 0.06768531338976962, 0.06512178773326532, 0.021681655231597166, 0.036840336197721105, 0.07891082710453443, 0.055209279991686344, 0.03899088169315031, 0.03501824575609394, 0.01176371836170022, 0.009770657451424216, 0.055042163601943424, 0.05978512338229588, 0.01870357521277453, 0.02585067955910095, 0.04150859605787056, 0.023058083872976046, 0.050052457954734564, 0.07437836924301726, 0.06095888718430485, 0.06215876101383141, 0.057920963769512515, 0.015723227190652063, 0.023382525392142788, 0.01896159493896578, 0.09018432681581803, 0.06200974115303584, 0.10978995157139641, 0.11225598531642131, 0.10492470620998315, 0.16080541695867265, 0.19290390956614697, 0.23479892792446272, 0.13732636826378958, 0.13351169867174967, 0.15682312207562582, 0.1918030950639929, 0.26097556043948444, 0.14717492407986096, 0.11803153290280274, 0.14863271585532598, 0.09361635694014174, 0.16716088806944235, 0.10535243432968855, 0.13450050061302526, 0.0960732168917145, 0.12310906473015036, 0.0984639875324709, 0.09672281239181757, 0.042453829265598736, 0.25058784069759504, 0.10466840996273927, 0.12266356577830655, 0.20442991251392023, 0.11080809336687837, 0.26224254816770554, 0.474693979535784, 29.000028235571726, 81.81521906171525, 80.32055732182094, 79.03156226021903, 75.74781581333706, 65.75582681383405, 42.840688705444336, 26.9180109500885, 67.38348402295793, 61.07918194362095, 59.51935999734061, 63.36010878426688, 56.50591237204415, 53.84631218229021, 38.241307803562705, 4.732422402926853, 0.4736714544040816, 0.1184514510844435, 0.2329577367220606, 0.29013581999710625, 0.6569031051227024, 1.1816147778715407, 3.3202770352363586, 4.4070599760328015, 6.987630920750754, 7.924993719373431, 7.906589678355625, 8.09934834071568, 8.953508632523672, 9.299890228680201, 5.840119855744498, 10.611580712454659, 12.101538521902901, 20.244003908974783, 27.583714382989065, 38.73371621540615, 46.93455341884068, 56.54326936176845, 62.579284123011995, 63.09522955758231, 65.1522923878261, 67.33977290562221, 60.60919189453125, 58.764313152858186, 58.65323230198452, 62.442828450884136, 62.1617807660784, 64.30418831961495, 66.80959061213902, 61.15755762372698, 60.80551324571882, 64.10458741869245, 65.18959031786237, 65.76998724256242, 62.857198170253206, 64.46898569379533, 59.365638051714214, 31.228317260742188, 50.19601699284145, 51.893427167619976, 47.874012402125764, 51.550967829568044, 40.77637890407017, 48.56904765537807, 58.50611114501953, 69.85650076184953, 63.174376487731934, 63.56239863804409, 59.29739284515381, 62.568041937691824, 66.80321911403111, 68.40045710972377, 58.01115274429321, 62.42665999276297, 59.85622256142752, 65.66204002925328, 58.19188928604126, 63.32263714926583, 60.552814211164204, 64.2887077331543, 63.970223154340474, 68.89277866908482, 69.01769338335309, 63.24466446467808, 37.679323605128694, 17.393399477005005, 3.3692944049835205, 5.29993302481515, 8.09015587397984, 6.7704992805208475, 10.083686113357544, 6.121872782707214, 4.531206480094364, 3.108597125325884, 3.558884688786098, 0.6746441902858871, 0.2731502971478871, 0.13371694194419043, 0.3067312937762056, 0.14478349526013645, 0.7684944857444082, 16.897322416305542, 48.781388078417095, 72.69841820853097, 77.37660557883126, 57.83659315109253, 72.93877029418945, 38.18587507520403, 29.348478657858713, 30.03090293066842, 41.35712671279907, 57.09900712966919, 76.62862505231584, 79.08910029275077, 79.3749908719744, 19.3784807068961, 0.39060674448098454, 0.12903768303138868, 0.14772821510476725, 0.13737094801451477, 0.1319902738822358, 0.15264265425503254, 0.07893351053020783, 0.16072477985705647, 0.1861339078417846, 0.1502533153231655, 0.19554301723837852, 0.11141132456915719, 0.1887979313199009, 0.15437887609004974, 0.17861913251025335, 0.20497214341802256, 0.19212225079536438, 0.10784326852964503, 0.09824024061007158, 0.17342733538576535, 0.12547986608530792, 0.17815255826073034, 0.14168685142483028, 0.13047682866454124, 0.22648714536002704, 0.0642848147877625, 0.10649060896996941, 0.1464925892651081, 0.18574449659458228, 0.11721418319003922, 0.19640007482043334, 0.11906234973243304], [0.055711188952305486, 0.029455961726073707, 0.049339046236127615, 0.03387160639145544, 0.033197393640875816, 0.017628763868872608, 0.02150306651102645, 0.024211936064862778, 0.09027861604200942, 0.03512137968625341, 0.04264259770778673, 0.019626506670777286, 0.009366969827429523, 0.02074027101376227, 0.045052574282245975, 0.0761956013739109, 0.05088845380981054, 0.06979718578181096, 0.091832814072924, 0.022244201474157826, 0.08034779464027711, 0.0647197760907667, 0.015893500464569246, 0.01335706701502204, 0.027528922273112193, 0.028061891174209968, 0.12453238692666803, 4.354873359203339, 42.20711374282837, 61.56155368259975, 70.6444959640503, 62.04723276410784, 45.222711835588726, 28.87462888445173, 20.46171702657427, 35.0013211114066, 28.894837720053538, 46.68963984080723, 39.083571910858154, 33.326669761112754, 43.79933861323765, 24.936021668570383, 3.0016228769506728, 0.060462837373571734, 0.030889794430030242, 0.05133723347846951, 0.026702408944921832, 0.2784471314932619, 0.7216694897839001, 1.0390023503984724, 2.824265113898686, 1.4513384188924516, 2.3493685509477342, 3.507989351238523, 1.9495383713926588, 1.7233570281948363, 2.2181279361248016, 6.717472800186702, 14.168873395238604, 23.308411359786987, 33.45315824236189, 36.95177425657, 42.49727399008614, 52.411926065172466, 58.334045955113, 58.79762281690325, 60.77387114933559, 60.716798646109446, 63.672749928065706, 64.1372161592756, 62.182785170418875, 58.671846526009695, 59.96806076594761, 59.647686277117046, 60.555461474827354, 61.06996863228934, 58.93561404091971, 58.340500831604004, 60.31623499734061, 63.5688465663365, 63.085786955697195, 64.84627982548305, 64.00477654593331, 59.25574534279959, 59.162896565028596, 44.573329721178325, 24.536698273250035, 42.798447132110596, 41.48119722093855, 30.894671712602886, 39.07028695515224, 57.87478045054844, 62.16873591286795, 59.00243486676897, 60.976411138262065, 62.76133387429373, 62.60434627532959, 61.26365661621094, 59.89604268755232, 56.000392709459575, 53.02870028359549, 54.35306862422398, 52.0455128124782, 54.46200248173305, 59.46042537689209, 63.22286101749965, 59.849003383091514, 63.91088553837368, 59.64835330418178, 56.54675735746111, 57.790109702519004, 59.8170416695731, 64.72338008880615, 63.430139677865164, 46.55317374638149, 19.549950088773453, 7.457398193223136, 2.2811394120965685, 2.0066775338990346, 0.7973850412028176, 0.898347903575216, 0.35207998752593994, 1.4176652772086007, 0.722171062869685, 0.11583188522074904, 0.1087964405970914, 0.08791630994528532, 0.09441107072468315, 0.08263791139636721, 0.8473333609955651, 8.415525249072484, 24.287369115012034, 34.394729478018625, 44.85303292955671, 46.932517596653526, 43.905305589948384, 33.05808367047991, 21.447193929127284, 16.584559679031372, 33.56377356392996, 50.6023302759443, 59.021542412894114, 63.047002111162456, 44.187249592372346, 4.339574294430869, 0.13108979005898747, 0.05649556525583778, 0.0564931937759476, 0.03445426780464394, 0.07490879363779511, 0.07151305156626872, 0.030460315689976727, 0.043450234191758294, 0.02322263709668602, 0.04621932203216212, 0.057362766936421394, 0.034789932293019125, 0.05599390396050044, 0.027207822538912296, 0.04443637288308569, 0.0313019332076822, 0.02314863437121468, 0.044375532040638585, 0.041926051157393625, 0.017891107559470192, 0.009317865096298712, 0.05142459825479558, 0.01962663559243083, 0.014364448941445776, 0.0287948413086789, 0.06251147708722524, 0.03936312939705593, 0.021722555626183748, 0.035371436804000816, 0.018858535647658364, 0.016940887119354944, 0.025291130744985173, 0.031852462595062594, 0.04981811231534396, 0.04625937595431294, 0.01091445969151599, 0.010082104176815068, 0.004209899277027164, 0.017039597001192824, 0.06157627941242286, 0.01548312757430332, 0.06447508279234171, 0.029218186092163836, 0.03359134768002799, 0.03371758912024753, 0.044320787835334025, 0.10450249457997934, 0.039276551721351485, 0.02771691040002874, 0.010560051521419414, 0.06384856426822287, 0.028609248410378183, 0.04164069664797612, 0.04873059709955539, 0.03663097082504204, 0.021277160150930285, 0.05825512869549649, 0.038248683126377206, 6.814623815672738, 55.06955296652657, 70.20921216692243, 78.89266777038574, 68.87815965924943, 55.23275225503104, 38.107468128204346, 28.215972661972046, 32.2058037349156, 37.25750889096941, 49.99625628335135, 32.72032478877476, 38.41645104544503, 40.4239627974374, 24.938795736857823, 2.459061933415277, 0.0054824285159286645, 0.1303675573851381, 0.0391062055049198, 0.25726755655237604, 0.440964763717992, 1.6985125499112266, 2.8737864451748982, 5.097618852342878, 4.701660556452615, 5.707911270005362, 2.784053065947124, 1.4729934568916048, 2.5115145359720503, 3.054579006774085, 7.702464631625584, 15.741449628557477, 25.891982623508998, 35.166889735630576, 42.09738084248134, 49.19916936329433, 56.98909705025809, 61.31634480612618, 63.19857011522566, 62.891473633902415, 62.34989629473005, 65.75938429151262, 67.26141807011196, 62.20016261509487, 59.612868853977744, 59.89054666246687, 61.79046903337751, 61.187129156930105, 61.6146240234375, 59.521381923130576, 59.25165980202811, 60.76219817570278, 64.72300488608224, 63.83478191920689, 66.59421035221645, 63.25846358707973, 59.36322702680315, 61.02466637747628, 45.64973769869123, 29.430922508239746, 47.37303338732038, 45.706841468811035, 36.56074701036726, 42.16664048603603, 59.17621626172747, 62.29909801483154, 62.202858516148154, 62.02427591596331, 64.16220882960728, 64.17324951716832, 63.174487658909385, 61.62324673788888, 58.42460877554757, 56.60126597540719, 57.80860580716814, 54.8529428754534, 56.15310716629028, 61.96292332240513, 64.28327424185616, 62.96224103655134, 65.31995241982597, 61.59172970908028, 59.75844056265694, 60.03208146776472, 61.3610634122576, 68.04905891418457, 66.23775386810303, 48.57405383246285, 24.059087787355693, 8.433673075267247, 3.4437078748430525, 0.38689860488687244, 0.6051339230367115, 0.9126238461051668, 1.59987516275474, 1.1181488462856837, 2.230730665581567, 1.023741175021444, 0.39867439014571054, 0.14018101937004498, 0.09577477004911218, 0.005953665573282966, 0.3887960602130209, 7.410467454365321, 21.62623163631984, 35.65739434106009, 44.80428784234183, 46.160263538360596, 38.25147301810128, 39.341926779065815, 29.69506175177438, 24.983787059783936, 41.68194110052926, 55.07604258401053, 64.93687043871198, 70.59933962140764, 59.388997895377024, 7.577124340193612, 0.1763605744178806, 0.027134822348931005, 0.03298799094877072, 0.03774554601737431, 0.05826945935509034, 0.05359630725745644, 0.03985862959442394, 0.006094771595339158, 0.017688374866598418, 0.06695159990340471, 0.03568303704793964, 0.018534901585163813, 0.061493722056703906, 0.012808772552359318, 0.05617689128432955, 0.00814327348156699, 0.04658909647592476, 0.004597355071122625, 0.028218512323551943, 0.0394873963003712, 0.026323906844481826, 0.08771399115877491, 0.025404571622077907, 0.05582512855263693, 0.05505930678918958, 0.05175509909167886, 0.020070896217865602, 0.015278915675090892, 0.04575211335239666, 0.01150621092944805, 0.014793186381991421, 0.09609649742820434, 0.10266316934887852, 0.09681660628744534, 0.13561506223465714, 0.12123446246342999, 0.0997305613543306, 0.06915075904024498, 0.09951693138905934, 0.2514853525374617, 0.1481073669024876, 0.2197208891489676, 0.09158500629876341, 0.10746254253068141, 0.1841837710567883, 0.22567998724324362, 0.2017702180892229, 0.11938869793500219, 0.1353865044989756, 0.1325193547776767, 0.08343672353242125, 0.10574423402015652, 0.19032698284302438, 0.1621705208505903, 0.10397620246346508, 0.10265209565737418, 0.23237682932189532, 0.21939112112990447, 10.919375487736293, 67.45101356506348, 77.69112273624965, 87.04854665483747, 78.10099002293178, 62.16793687002999, 42.547957624707905, 30.660621643066406, 49.910887241363525, 38.527643067496165, 55.594649178641184, 52.524809973580496, 43.78722095489502, 58.89540481567383, 34.5094998223441, 4.994133685316358, 0.22520183718630246, 0.13696734181472234, 0.1056963498038905, 0.12137481064668723, 0.6920130582792419, 2.449511851583208, 3.2697024004799977, 8.658397793769836, 7.894591876438685, 11.849851318768092, 9.151206595557076, 8.12935413633074, 6.002281257084437, 7.596952761922564, 11.873857344899859, 17.896103382110596, 28.98993076596941, 37.4518152645656, 43.053842067718506, 50.10970646994454, 58.608715193612234, 64.90456826346261, 66.81087602887834, 66.0313298361642, 65.13001646314348, 69.07887922014508, 69.26661259787423, 64.3183765411377, 61.29128960200718, 61.34275490897042, 62.07438632420131, 63.37886892046247, 62.808741433279856, 60.4306092943464, 58.983924865722656, 62.529938016619, 67.0360324042184, 63.77526365007673, 66.51180471692766, 65.09000873565674, 59.60310663495745, 60.20903124128069, 48.86206013815743, 34.24796267918178, 51.569352763039724, 49.980765274592805, 41.71211017881121, 46.37855509349278, 61.81542001451765, 66.36246708461216, 63.35344546181815, 62.8007926940918, 67.16701289585659, 66.37708609444755, 66.12418556213379, 65.54753371647426, 61.91302136012486, 58.53335503169468, 59.592503683907644, 56.65574680055891, 58.29705374581473, 65.29934406280518, 66.64272267477853, 64.0601258959089, 68.38680389949253, 65.05685888017926, 60.5385981968471, 62.94248035975865, 64.21582112993512, 71.62164197649274, 68.88785239628383, 53.103504589625764, 27.308657782418386, 12.223194531032018, 4.69840098278863, 4.486500033310481, 3.502233854361943, 3.0632538327148984, 4.946879855224064, 4.612111304487501, 3.0806527733802795, 0.9039886466094426, 0.5077536169971738, 0.31978755603943554, 0.2949577883950302, 0.1703442893922329, 1.0788424525942122, 12.310027037348066, 34.2164352280753, 46.9555960382734, 62.22090993608747, 63.395412581307546, 60.48332527705601, 45.3187255178179, 31.467748710087367, 27.115716729845317, 48.22879089627947, 66.47289480481828, 74.48574502127511, 79.56680284227643, 66.41540540967668, 8.309850096702576, 0.32367621308990885, 0.09090051374265126, 0.09974588267505169, 0.11356408548142229, 0.1339864424828972, 0.11004938943577663, 0.1107141501935465, 0.1684214025735855, 0.15819269072796616, 0.12244222765522343, 0.1060732217239482, 0.09963566823197262, 0.1481691135891846, 0.13215492718986102, 0.19909613872213022, 0.12538868454950197, 0.1380264942667314, 0.10705461406282016, 0.10499663770731006, 0.1313209126570395, 0.12125286433313574, 0.170842157676816, 0.11436753879700388, 0.13461420951145037, 0.11259477785123245, 0.14660754666796752, 0.09430294616946153, 0.10592174556638513, 0.13596355782023498, 0.1865572729813201, 0.07503675855696201], [0.09196638369134494, 0.010995423338109893, 0.03347225460622992, 0.026398784880127226, 0.02547032505806003, 0.047387409888740094, 0.020654273485498767, 0.043434091843664646, 0.04661214291783316, 0.05127637227997184, 0.04725971638358065, 0.006120494009727346, 0.04652893756117139, 0.07569567712822131, 0.0064495491429365105, 0.025024284974538853, 0.049530647562018464, 0.009048720788476723, 0.05008540761524013, 0.012921784256052758, 0.051687164165611775, 0.01721595673422728, 0.05982843427253621, 0.01589449112569647, 0.03508075240201183, 0.01952574252417045, 1.3438254679952348, 32.63958672114781, 57.11734342575073, 65.91329383850098, 52.730202198028564, 52.650495937892366, 36.5600209236145, 19.87043227468218, 22.562873125076294, 20.996424334389822, 14.078949809074402, 28.0528758593968, 49.09554740360805, 44.00122894559588, 24.57581663131714, 2.2232782883303503, 0.017959050967225006, 0.07485764566808939, 0.0973389900422522, 0.17966327576764993, 0.11591101597462382, 0.6899879298039845, 0.9261219160897392, 2.3280527804579054, 3.2745609283447266, 4.153553647654397, 2.032485966171537, 1.730699211359024, 1.7905646732875278, 5.481734377997262, 12.057915994099208, 24.628556932721818, 35.97993319375174, 47.17532239641462, 48.1071765763419, 56.6363856451852, 59.6934540612357, 63.44848987034389, 60.40585286276681, 58.77809837886265, 54.77418157032558, 57.20763874053955, 60.288039207458496, 63.0475857598441, 59.93055438995361, 61.082468441554475, 59.130163601466585, 58.69731862204415, 59.190661566598074, 60.57296398707798, 59.90226827348982, 61.37791974203927, 59.70992129189627, 59.91699150630406, 60.66386726924351, 60.0566155569894, 60.5173019681658, 65.83407742636544, 59.7348027910505, 61.5047938483102, 34.40975843157087, 29.83720452444894, 35.355286666325156, 35.185514381953645, 57.258930342538015, 57.52022777284895, 60.32044560568673, 54.13175112860543, 54.49464511871338, 53.45814759390694, 54.5215276990618, 52.24676391056606, 54.193291323525564, 50.04870476041521, 49.97956671033587, 49.52164568219866, 53.51495606558663, 56.30762815475464, 59.82044628688267, 59.91592843191964, 60.5240695135934, 57.29731913975307, 62.43880544389997, 55.28696557453701, 54.88173968451363, 55.94285120282854, 59.819730622427805, 57.90042625154768, 61.31858907427107, 53.155515330178396, 50.72904109954834, 37.8734701701573, 16.65122938156128, 3.670356810092926, 0.793818823993206, 2.039580076932907, 0.6921219495790345, 1.7890061054910933, 0.7790860374058995, 0.1773225606552192, 0.021063514918621098, 0.029365166955228363, 0.01616578469319003, 0.020770269046936716, 0.2670579212052481, 4.608711464064462, 16.983327218464442, 34.66983297892979, 39.59570278440203, 56.5800461769104, 29.402862208230154, 28.937159197671072, 17.88252660206386, 32.20529651641846, 45.223886081150596, 50.948475633348735, 57.57341275896345, 66.20413848331997, 25.040081364767893, 0.6552108930689948, 0.11677765447114195, 0.07861252275428601, 0.12702037127954618, 0.052053817348288636, 0.05882047050233398, 0.051672541735959907, 0.07952735759317875, 0.064164978718119, 0.049775568169674704, 0.051480037958494256, 0.03352776216343045, 0.08279618647481714, 0.017606691124715974, 0.04079369156222258, 0.035859520613615, 0.06227472943386861, 0.05819943454116583, 0.024211530640189136, 0.030310525691934993, 0.06519360387963907, 0.04691224877855607, 0.04832239382501159, 0.07849862386605569, 0.04400645309527006, 0.05671715782955289, 0.04925766274599092, 0.012494245277983802, 0.009959636239467986, 0.01809415577112564, 0.04465175007602998, 0.007550177896129233, 0.036289738956838846, 0.03808794157313449, 0.0028050654634301153, 0.03984222261767302, 0.044923177654189725, 0.042985688761941025, 0.060801670620484013, 0.09929472474115235, 0.04023300450561302, 0.012536524794995785, 0.02992019842245749, 0.019100048313183442, 0.005844294209964573, 0.022827756857233386, 0.05198529888210552, 0.041665045877120326, 0.0764632291559662, 0.006546662347058633, 0.014816806185990572, 0.04286060422392828, 0.031119590492120812, 0.057802003010043075, 0.032697632243590694, 0.046064839964466434, 0.08334707548575741, 2.164318263530731, 43.040876729147776, 67.10500022343227, 72.25947271074567, 61.55907317570278, 60.519052914210725, 46.48664474487305, 29.971554892403738, 25.673736231667654, 25.306671585355485, 17.556918382644653, 37.34012644631522, 46.80769320896694, 42.47522388185774, 24.97528941290719, 2.195752565349851, 0.05812010022678545, 0.02459001916992877, 0.19243040068873338, 0.48962918668985367, 0.8696372956037521, 2.2062187237398962, 4.335343275751386, 5.3903955306325635, 3.209950932434627, 3.7560606684003557, 1.2112475420747484, 1.450240494949477, 2.2073747302804674, 6.830472222396305, 14.27899626323155, 27.985146556581768, 37.65531063079834, 47.23662287848336, 49.065305369240896, 55.81731115068708, 59.18980693817139, 63.34910978589739, 64.2208377293178, 61.115458488464355, 57.71439518247332, 59.549508231026785, 61.83664676121303, 64.7246446609497, 60.80691678183419, 60.27901349748884, 60.54718617030552, 59.29903956821987, 59.42314829145159, 60.548457690647666, 62.21016107286726, 63.62592601776123, 61.766622815813335, 61.21095452989851, 61.93545709337507, 62.92621462685721, 61.44986833844866, 66.10187489645821, 60.601409912109375, 60.33753817422049, 36.12716204779488, 34.590293475559776, 40.79115424837385, 40.11356244768415, 58.55460957118443, 59.450920241219656, 62.941320010593955, 56.408109528677805, 55.92070729391915, 55.65261799948556, 56.32232012067522, 54.97563416617257, 56.70718084062849, 53.14074345997402, 51.890488079616, 52.105541774204795, 54.17292267935616, 59.7328850882394, 63.150419098990305, 62.639448574611116, 61.4479158946446, 59.57460512433733, 64.26409026554653, 57.94223703656878, 58.273502826690674, 59.684004511152, 64.12454959324428, 62.19466659000942, 62.792121342250276, 58.31165885925293, 55.852264063698904, 41.48960106713431, 19.209203481674194, 4.953808077744075, 0.5830719268747738, 0.8359793531043189, 1.8099874939237321, 2.461128371102469, 1.805826065795762, 1.8343200853892734, 0.4819933335695948, 0.20216713393373148, 0.06890403692211423, 0.08171462201114212, 0.27016243604677065, 4.628860371453421, 17.224441868918284, 35.12986625943865, 43.048061166490825, 57.74011393955776, 24.882016795022146, 26.776172161102295, 20.168207747595652, 38.927598748888286, 53.398132528577534, 57.4634609903608, 65.30164391653878, 74.59292793273926, 39.93850605828421, 0.771231261747224, 0.046215233858674765, 0.05195124660219465, 0.05162509856745601, 0.0817517785887633, 0.07855842994259936, 0.03098594623484782, 0.0519117592567844, 0.03949716041928955, 0.014175283556271876, 0.05723369600517409, 0.02426315188807036, 0.03386045127574887, 0.020388118124433925, 0.03568259260750242, 0.05189312329249723, 0.0754188144845622, 0.037798929759966474, 0.006592283649037459, 0.05613271186926535, 0.054475732746401, 0.018986237634505545, 0.03569638043908136, 0.017237576556258967, 0.016995680518448353, 0.06388590405029909, 0.07436371288661446, 0.03668263108868684, 0.020052446850708554, 0.04447652519281421, 0.05692547147295304, 0.20069758993174347, 0.17419049729193958, 0.07917667712484087, 0.08617442912821259, 0.08725269591169697, 0.13736841029354505, 0.1449090378092868, 0.13147909274058683, 0.25871617453438894, 0.22949625817792757, 0.1157078490193401, 0.05076857363539083, 0.07975291620407786, 0.13878863837037766, 0.10180931445211172, 0.0943446217903069, 0.06931075759764228, 0.1283110805920192, 0.11404765024781227, 0.1167784822838647, 0.19621757604181767, 0.09546592805002417, 0.26734366587230135, 0.16205823687570436, 0.16699314064213208, 0.1830548516341618, 3.415167063474655, 52.81946570532662, 78.39735848563058, 83.89095864977155, 69.7441622870309, 67.56399822235107, 50.51585299628121, 31.1014883177621, 33.66316754477364, 32.390681403023855, 24.519927058901104, 42.24215350832258, 65.86656720297677, 58.680045400347026, 33.93879910877773, 3.3727606875555853, 0.16861692922455923, 0.21825077517756394, 0.25233881388391766, 0.6591466133083616, 1.9673483414309365, 3.533809074333736, 5.577136184488024, 7.465968796185084, 9.911917958940778, 12.027052964482989, 9.49767678124564, 8.838037388665335, 6.069404763834817, 9.832368033272878, 18.57757748876299, 30.21172979899815, 40.9102463722229, 51.33041116169521, 50.10332454953875, 58.30871977124895, 59.77947275979178, 65.54568549564907, 64.98126942770821, 63.635062898908345, 60.97898891993931, 62.05730070386614, 64.39457048688615, 66.38054629734584, 63.242371559143066, 62.414597920009065, 60.44545759473528, 59.886127608163015, 59.84191622052874, 62.22946316855294, 64.18765313284737, 66.3410735811506, 64.5547959463937, 64.68190629141671, 63.844280106680735, 64.96018859318325, 63.937080247061594, 68.52152947017125, 61.66948699951172, 61.67099475860596, 39.24684068134853, 37.26053830555507, 43.930617877415244, 43.67798832484654, 59.71857874734061, 61.32744107927595, 64.71588298252651, 60.16334683554513, 60.13349737439837, 58.47778333936419, 59.33576079777309, 58.50297750745501, 57.91903352737427, 55.53594732284546, 54.816596848624094, 53.1213128226144, 56.40175540106637, 61.25702108655657, 63.68804291316441, 63.32543727329799, 62.71299525669643, 60.28371047973633, 66.2231695992606, 59.41643633161272, 59.0435334614345, 61.32045119149344, 67.99071489061627, 63.59769548688616, 63.69184357779366, 60.112562452043804, 59.385405676705496, 42.26309190477644, 20.50333673613412, 5.684600063732692, 2.757013716867992, 5.659767201968601, 5.609599905354636, 5.322052615029471, 3.332919933966228, 1.5204194720302309, 0.42553840577602386, 0.3498946162206786, 0.22015523298510484, 0.15242070545043263, 0.6336560068385941, 7.257842455591474, 24.65285130909511, 46.660975047520225, 54.558012689862935, 71.15560545240129, 37.61392715999058, 39.98548630305699, 26.92882582119533, 46.20171996525356, 58.80830914633614, 69.22525691986084, 73.38194724491665, 85.69182055337089, 43.87732172012329, 0.843796890761171, 0.2151529099792242, 0.1736762220306056, 0.1644376420548984, 0.16387881418423994, 0.10431745129504374, 0.13167983054050378, 0.15864595212042332, 0.08536433295479842, 0.2063050711793559, 0.13625483933304036, 0.18724012348268712, 0.15590144081839494, 0.16852102508502348, 0.07543860735105616, 0.15270514733025006, 0.13063669151493482, 0.1993295954806464, 0.14010597339698247, 0.15163387624280794, 0.19270788079925946, 0.08865513280034065, 0.12906730787030288, 0.17547371557780675, 0.1142443304083177, 0.1580682745469468, 0.32543961703777313, 0.102830706430333, 0.10880961096180336, 0.17371279506811074, 0.16019052852477345], [0.018520075595006347, 0.01413272668807102, 0.05028571115274515, 0.03696166165173054, 0.04933783844379442, 0.07634914706328086, 0.023726452740707567, 0.0178645971962916, 0.028558242933026383, 0.048381551900612454, 0.07487409335694142, 0.045374718960374594, 0.07048883688236986, 0.03816129799400057, 0.04892376584133931, 0.0074482788997037065, 0.029957928362169435, 0.101550622976252, 0.01052156840783677, 0.04863417048805526, 0.04052724443109972, 0.03508967513750706, 0.043858864943363836, 0.01843256493365126, 0.05472491116129926, 0.04640424657346947, 16.995161737714493, 67.54839951651437, 59.950245584760395, 58.8407016481672, 57.00366742270333, 36.20044469833374, 20.188001428331646, 18.794048615864344, 23.605314833777292, 41.87594175338745, 36.82334722791399, 28.0923034123012, 31.980202674865723, 23.930917842047556, 2.614751304898943, 0.0403122336470655, 0.10719361874674048, 0.05053392944059201, 0.15396017927144254, 0.5693946150796754, 1.6603527175528663, 0.8419953531452588, 3.167813799210957, 3.7748108165604726, 1.625371903181076, 3.3078408454145705, 3.030643114021846, 3.174128843205316, 18.411803892680577, 30.231396675109863, 47.87719120298113, 52.4196628843035, 53.90366956165859, 54.96076154708862, 59.280786650521414, 56.88022225243704, 58.79674734388079, 57.94038534164429, 55.998342990875244, 54.20754555293492, 51.18111521857125, 52.31345272064209, 56.9463552066258, 59.821412086486816, 57.981390135628835, 55.82258830751692, 57.460445472172324, 54.990809031895225, 59.47500269753592, 59.12065151759556, 59.82369804382324, 54.544668674468994, 55.66612529754639, 55.17819152559553, 54.26044566290719, 56.655399390629356, 58.09786973680769, 56.774164949144634, 60.82591315678188, 57.25009223393032, 52.761535099574495, 21.620647021702357, 25.372080189841135, 47.74014493397304, 55.43743576322283, 58.89237540108817, 56.12207303728376, 51.97811876024519, 51.00668069294521, 49.58596863065447, 50.387460708618164, 47.39251266207014, 48.81468732016427, 47.00009230204991, 49.93063054765974, 49.32474763052804, 51.6672146660941, 56.81304012026106, 61.13082095554897, 52.45238889966692, 57.230348927634104, 62.74039200374058, 61.45774759565081, 54.09608255113874, 48.798074177333284, 53.894525732312886, 58.368251936776296, 59.99663870675223, 54.51701831817627, 54.11282423564366, 52.76871953691755, 54.18456438609532, 57.69647577830723, 40.26363658905029, 14.510406017303467, 1.7448886271033968, 0.4583760808621134, 2.1000771735395705, 1.5923591660601752, 0.9146045169660023, 0.08739921876362391, 0.016507225210911462, 0.11418141664138862, 0.03313568427360483, 0.094545983842441, 0.03275168434317623, 1.274315472160067, 10.208339401653834, 37.53133044924055, 32.14422532490322, 54.36621461595808, 46.5581556047712, 22.281927926199778, 20.707278524126323, 43.02915164402553, 49.44251612254551, 56.93445989063808, 62.72134699140276, 56.253043106624055, 5.28365078994206, 0.21879061763840063, 0.0459351346029767, 0.006956706571924899, 0.034372897885207615, 0.05291475275797503, 0.09100774263164826, 0.07119559895779405, 0.07372789843274014, 0.045141214704407115, 0.03513260265546186, 0.025561820416312133, 0.07624159247747489, 0.12677303169454845, 0.008695584871540112, 0.03760147946221488, 0.10270907902824027, 0.019357106215985756, 0.018438877005662237, 0.024539576876642447, 0.043915003538131714, 0.06608992149787289, 0.05160873230280621, 0.028905435731368403, 0.039586852570729594, 0.021008914902008007, 0.01905304449610412, 0.05458087853289076, 0.10564292195652213, 0.015291509285037006, 0.0035676192325939026, 0.005288275474283312, 0.027389529127893702, 0.05047322091247354, 0.04235356553856816, 0.031237570768488303, 0.0070686512793015155, 0.03392764659864562, 0.09672903455793858, 0.032194138903703005, 0.009199938254563935, 0.04045758602608528, 0.01836870121769607, 0.04459704997550164, 0.005806474364362657, 0.027754170454240272, 0.03083958283865026, 0.05095088242420128, 0.019907528734100715, 0.048628212950591526, 0.037919973621943166, 0.0749536787292787, 0.08631285027201686, 0.041178817860782146, 0.03377250635198184, 0.04860406728195293, 0.07542363886854478, 23.519674812044414, 79.02785192217145, 66.5096994127546, 68.4467807497297, 64.16195174625942, 47.63925361633301, 26.18227141244071, 25.01095277922494, 26.384583847863333, 33.37295518602644, 40.77108437674386, 33.67201607567923, 36.51625769478934, 25.213466712406703, 2.3922791055270602, 0.03390724305063486, 0.03526015366826739, 0.09411999277238335, 0.5892636946269444, 1.651615900652749, 3.730468715940203, 3.3598732990877966, 3.541651202099664, 7.0073473027774265, 5.9944988404001505, 2.4714460117476325, 1.156127916915076, 4.450866631099156, 19.55219088281904, 32.397455896650044, 48.97200148446219, 53.70046601976667, 55.14227628707886, 55.6821791103908, 60.752366474696565, 58.722783769880024, 59.87501743861607, 61.449520928519114, 58.231167452675955, 56.80089814322335, 54.82014390400478, 54.36002377101353, 58.28665229252407, 60.33427252088274, 59.85271372113909, 55.756642954690115, 56.65102549961635, 57.38021114894322, 61.12298338753836, 61.57324055262974, 58.793169021606445, 57.16374002184187, 56.27086523600987, 57.50315604891096, 58.121757643563406, 59.38395350319998, 59.26267269679478, 60.383507456098286, 62.776077951703755, 59.62603569030762, 52.23107140404837, 24.695113727024623, 29.762997763497488, 49.76988049915859, 57.63795110157558, 61.1506233215332, 57.35274491991316, 55.05956493105207, 52.912192889622276, 53.1717289515904, 52.343545368739534, 50.23551402773176, 49.98835270745413, 48.80215971810477, 51.61864675794329, 52.22951848166329, 55.15634291512625, 59.9064302444458, 62.05176298958914, 56.42443779536656, 58.564983231680735, 64.09813254220145, 63.16062600272042, 56.051423754010884, 50.75271013804844, 55.62649972098214, 63.6707557950701, 64.00146225520542, 61.23251479012625, 59.56310585566929, 58.42569269452776, 58.625446455819265, 61.31744262150356, 44.97880574635097, 17.824740171432495, 2.4704330946717943, 0.5236804080860955, 0.3243947002504553, 3.3510957700865607, 2.7982247854982103, 1.379970214196614, 1.357224091887474, 0.17316310027880327, 0.043257825409195254, 0.1103731659906251, 0.08133921572672469, 0.8846391620380538, 8.965095622198922, 34.56021472385952, 32.848209857940674, 40.19224732262747, 36.30386168616158, 18.944640398025513, 28.342402083533152, 50.403702122824534, 55.37145914350237, 63.64130932944161, 67.36625943865094, 66.05990777696881, 13.600851212229047, 0.2225916079644646, 0.017931083450093865, 0.029981198720633984, 0.01698113272764853, 0.01769865636846849, 0.052305095829069614, 0.09597604389169387, 0.03101405794067042, 0.0193755589758179, 0.01987120505821492, 0.028338994697800705, 0.009280744989934777, 0.08299000321754388, 0.04495177111987557, 0.03631792190883841, 0.057009826946471415, 0.03762819338589907, 0.027703639951401522, 0.015656420329053487, 0.030360360696379627, 0.059225983385528834, 0.062199764885008335, 0.03565821962963257, 0.032745675915586095, 0.037231535384697576, 0.006957313436682203, 0.06587165035307407, 0.034040466616196294, 0.1016957616167409, 0.04087560770234891, 0.13039786075907095, 0.08924940055502312, 0.12441669670598847, 0.20012926257082395, 0.2886046107326235, 0.14513762268636907, 0.1306765486619302, 0.1480976367103202, 0.07857536617666483, 0.13680747896432877, 0.18115846839334282, 0.09763149291809116, 0.11296406374978167, 0.1308427761707987, 0.14348971896937915, 0.10068952132548604, 0.14210386547659123, 0.2344681013907705, 0.09630842427057879, 0.08966935266341482, 0.13649862339454039, 0.19352327633116925, 0.12266172016305582, 0.11006500252655574, 0.14361408086759703, 0.2791884717132364, 30.099943705967494, 88.2333882195609, 75.85319914136613, 76.64256313868931, 73.67525850023542, 52.03501755850655, 30.070393017360143, 28.502151591437205, 34.893742152622764, 56.74188361849104, 50.06840637751988, 40.01637799399239, 43.01037413733346, 33.681674071720664, 3.989829335893903, 0.2637247129210404, 0.2705751753279141, 0.209109062861119, 0.33378019662840025, 1.6255816519260406, 4.035493331296103, 4.173313890184675, 9.51950454711914, 9.818535906927925, 7.659120031765529, 7.600175857543945, 6.69288182258606, 6.231602208954947, 23.307443823133195, 33.77932058061872, 52.16741895675659, 56.62248577390398, 56.63418654033116, 56.973137038094656, 59.96334293910435, 57.51948084150042, 59.799191747392925, 63.18545191628592, 60.89663192204067, 58.65067536490304, 56.316636494227815, 56.32098259244646, 61.96208953857422, 64.24922806876046, 61.81044510432652, 56.11861630848476, 57.76596818651472, 57.76570068086897, 64.21386868613106, 64.15471867152623, 63.32695198059082, 58.90528515407017, 59.06223801204136, 60.6730249949864, 59.056213923863, 63.962128502982004, 62.32785660879952, 62.55267947060721, 64.84820447649274, 60.537284987313406, 53.59973798479353, 29.46422869818551, 35.03764976773943, 51.12938240596226, 58.08998353140694, 64.6754514149257, 60.8228976385934, 56.85548319135393, 55.8740188734872, 54.82825592585972, 56.45401975086757, 52.273934841156006, 52.87120199203491, 52.10870667866298, 54.811753954206196, 54.954622813633506, 56.79990802492414, 61.50476605551583, 62.73659133911133, 57.76082304545811, 58.89140265328543, 65.92542539324079, 66.07385281154087, 57.54973329816546, 51.756575448172434, 58.65713718959263, 65.73441246577671, 67.06072630201066, 63.125704356602256, 59.84491089412144, 58.11736290795462, 59.205086026872905, 62.79763126373291, 47.28730998720442, 18.897331850869314, 2.8556616348879675, 3.350795043366296, 6.997343633856092, 6.826913441930499, 2.811862362282617, 2.0129461118153165, 0.8712880898799215, 0.2653898378568036, 0.2082232761063746, 0.42308015482766287, 0.27019600995949333, 1.718422287276813, 14.420176710401263, 49.34956659589495, 47.21390226909092, 69.11857427869523, 63.64952904837472, 35.07662916183472, 31.27437686920166, 57.81416436604091, 61.21909087044852, 73.97660882132394, 75.41841561453683, 77.09861510140556, 12.898960692541939, 0.6175036164266723, 0.12910297167088303, 0.2519619012517588, 0.16073392650910787, 0.13107950346810476, 0.1529758149491889, 0.15439830933298382, 0.22651396106396401, 0.1596344555062907, 0.20617233615900787, 0.09649375254022223, 0.10205790932689394, 0.1660076906638486, 0.09481690930468695, 0.14393603216324533, 0.1643548064998218, 0.1380111729460103, 0.144528596795031, 0.06875513919762202, 0.16750755161046982, 0.16175991216940538, 0.10289093319858823, 0.14548098854720592, 0.11742226273885795, 0.08116815704852343, 0.08608625350253922, 0.127986075888787, 0.1569892545895917, 0.2639294947896685, 0.09184943818088089], [0.08573577659470694, 0.03897121774830988, 0.018757210013323596, 0.08623156856213297, 0.025096335215494037, 0.034301078346158774, 0.014852434363482254, 0.0658081801874297, 0.1137938102973359, 0.03976162283548287, 0.012440132958415364, 0.036813432284231694, 0.0861017783837659, 0.05613751928987248, 0.04940716775932482, 0.028546690874333893, 0.024983603407495787, 0.06313086420829807, 0.027341919718310237, 0.040528313123754094, 0.019147825660184026, 0.02751365184251751, 0.035692774025457244, 0.066534266940185, 0.15765736731035368, 2.4286611761365617, 42.670332772391184, 66.2500730242048, 67.08561474936349, 58.15784311294556, 46.741101673671174, 23.452402353286743, 20.579216275896343, 23.924289260591777, 25.015361411230906, 27.1590404851096, 24.577710015433176, 40.249893052237375, 25.152303457260132, 3.5708295106887817, 0.1008369398436376, 0.04788623830037458, 0.10571606803153243, 0.01858144230209291, 0.8489237385136741, 0.2729837032301085, 0.8329008668661118, 2.227130195924214, 2.220187859875815, 4.7391990678650995, 4.694393174988883, 6.106885952608926, 17.567109652927943, 37.74531759534563, 55.201520102364675, 60.72667898450579, 59.786219460623606, 58.24060658046177, 60.312573296683176, 56.215939726148335, 52.28848089490618, 54.69834198270525, 60.71682643890381, 56.92926263809204, 52.60311269760132, 49.319387095315115, 48.08692257744925, 51.24206829071045, 54.470691204071045, 57.05548013959612, 58.91418579646519, 54.594226700919016, 56.85696315765381, 58.18126549039568, 56.909731251852854, 52.922226088387625, 56.50860479899815, 52.20470299039568, 53.16638231277466, 51.839335441589355, 53.71653720310756, 52.84072719301496, 56.20457942145211, 54.799893379211426, 59.92189693450928, 54.17077916009085, 64.92711516789028, 33.10601234436035, 22.685510567256383, 56.887941701071604, 52.95354161943708, 56.87948226928711, 54.506655079977854, 57.36990349633353, 53.24233654567173, 53.804098401750835, 49.41612686429705, 49.38391848972866, 49.05563347680228, 50.353709833962576, 48.34815052577427, 50.24203838620867, 55.39715705599104, 58.90957219260079, 56.819373403276714, 53.14875473294939, 50.89764608655657, 57.38577665601458, 53.81525026048933, 47.081441811152864, 43.97513151168823, 50.21655239377703, 52.7369384765625, 59.3063907623291, 63.35702378409249, 60.838343484061106, 55.063897132873535, 49.29897328785488, 53.62173250743321, 62.24158082689558, 53.33462599345616, 31.640807492392405, 6.550470241478511, 0.7664340191653797, 1.9333636164665222, 3.652940716062273, 1.2438298165798187, 0.45130715732063564, 0.07733354531228542, 0.0794315484485456, 0.037578015721270015, 0.1748617041323866, 0.10358922037162951, 0.33044902394924847, 3.9799481289727345, 36.688771043504985, 46.829100608825684, 42.08117069516863, 36.29373468671526, 24.77173846108573, 27.84324697085789, 40.55370650972639, 52.07452154159546, 57.67206675665719, 56.38293620518276, 60.546039717538015, 3.087595109428678, 0.495558497096811, 0.028136324769418155, 0.10358303213225943, 0.02043646035183753, 0.061379734958921156, 0.08418310526758432, 0.05362871748262218, 0.0370022448311959, 0.03572234118889485, 0.04007239865937403, 0.024804044381848404, 0.03126364347657987, 0.043371045762406926, 0.040042200458369086, 0.027332040248438716, 0.03398141371352332, 0.03240621841645666, 0.03528475734804358, 0.033595805655100515, 0.04227002430707216, 0.07712925877422094, 0.029567207542381117, 0.020730876696429083, 0.020848029160073826, 0.05432649914707456, 0.027570845559239388, 0.03010480065963098, 0.039989502036145756, 0.025833086842404943, 0.03493277409246989, 0.04497849182890994, 0.04270425618493131, 0.03175622936604278, 0.03619561597172703, 0.035675678335662396, 0.03789961417870862, 0.061075154159750254, 0.08081070480069943, 0.0075551133902211276, 0.04289454793823617, 0.05541020438873342, 0.03808435212288584, 0.05365542122828109, 0.032783724766756804, 0.009466074107746993, 0.024412685739142553, 0.08542272767850331, 0.03332164358081562, 0.021525137558845536, 0.04609719590683069, 0.08581715329949345, 0.040145368315279484, 0.03975961437182767, 0.12098556224788938, 4.4259790522711615, 54.766903332301546, 74.04843235015869, 73.51009287152971, 66.4472906930106, 56.25688198634556, 32.942983286721365, 26.70240487371172, 21.57977945463998, 25.384567839758738, 37.02936826433454, 31.18331377846854, 33.87837062563215, 21.953493527003697, 3.1995206006935666, 0.23207650972264154, 0.021049138457913483, 0.07508438492992095, 0.83844015534435, 1.8907042826925005, 2.780779378754752, 3.803458239351, 3.022300281694957, 2.653696175132479, 2.208340964147023, 2.5228094841752733, 6.377066654818399, 19.219714369092667, 40.492732592991416, 58.48812920706612, 64.14209379468645, 64.01247514997209, 61.303574017116, 62.372304235185894, 58.832940510341096, 53.45245007106236, 56.74389164788382, 62.475311279296875, 59.57241644178118, 56.28622422899519, 52.27134663718087, 50.63577890396118, 54.23257991245815, 56.477765219552175, 59.008764675685335, 57.7591415813991, 56.27232435771397, 58.25871358598982, 60.42765630994524, 57.69837958472115, 55.983199392046245, 58.59370708465576, 54.58642734800066, 55.67640168326241, 53.51518535614014, 55.57063620431082, 54.92295292445591, 59.37360068729946, 57.44545473371233, 62.55725833347866, 57.92221927642822, 65.88325677599225, 33.970642702920095, 24.34622209412711, 55.63796772275652, 52.2913852419172, 57.08280045645577, 58.741828782217844, 58.14139672688076, 55.16666099003383, 54.750609806605745, 52.53745569501604, 51.55240610667637, 51.13120283399309, 52.60674313136509, 51.57034982953753, 52.34607103892735, 55.86353404181344, 61.046831130981445, 59.275214195251465, 53.41304336275373, 54.378551142556326, 59.075342314583914, 57.35252605165754, 49.68277440752302, 46.5952798298427, 52.582330635615754, 56.01271186556135, 61.21538748059954, 64.50248295920235, 61.0256530216762, 57.10101515906197, 53.055099964141846, 57.50984369005476, 64.2865537915911, 59.7889084134783, 36.585406167166575, 9.423090474946157, 0.921587239418711, 1.4585418552160263, 2.330719803060804, 2.6869044389043535, 1.8662507491452354, 0.5278282112308911, 0.13834695278533868, 0.1361876100833927, 0.15434538360152925, 0.07916853470461709, 0.33726816517966135, 3.5952467833246504, 34.174113750457764, 47.00282294409615, 43.715519019535606, 36.0002566746303, 24.191676786967687, 37.45959029878889, 49.04661471503121, 57.88548762457711, 63.37606184823172, 63.33797182355608, 74.24754687717983, 8.799408878598895, 0.6766297465988568, 0.11608177609741688, 0.034444554575851986, 0.003212099113235516, 0.027772969266931926, 0.02984934240313513, 0.09107090745653425, 0.014781395139704858, 0.015114835729556424, 0.009227384147899491, 0.04285589519089886, 0.02571516763418913, 0.030442843413246528, 0.04909707725580249, 0.04787431304742183, 0.01979550938787205, 0.0716773723917348, 0.051207575614431074, 0.02461544218073998, 0.06009666595075812, 0.04643905541992613, 0.054252928987677605, 0.021489514470366494, 0.006977341245926384, 0.027939159456374388, 0.03146990455154862, 0.04128069310848202, 0.003613367335804339, 0.015123149479872413, 0.12667062718953404, 0.1035944993740746, 0.1303151473402977, 0.18094453987266335, 0.11343540131513562, 0.17787081695028714, 0.1330724558127778, 0.13171895486967905, 0.2367485218814441, 0.12195946356015545, 0.08455834191824708, 0.1336779533220189, 0.16978082034204686, 0.22362538320677622, 0.17911238675670965, 0.07116044405847788, 0.06144965799259288, 0.2770475580223969, 0.12732563061373575, 0.08626638419393982, 0.088585175839918, 0.1598603669553995, 0.17157930455037526, 0.15772370089377674, 0.3067533054522106, 7.178223916462489, 69.5737646647862, 81.64309828622001, 84.78237083980015, 73.82815361022949, 62.42150442940848, 33.9622597013201, 31.128197193145752, 36.08863776070731, 37.81548397881644, 38.7715665272304, 31.86853470121111, 52.30084521429879, 34.526734828948975, 5.648746924740927, 0.37002571885074886, 0.13863104182694638, 0.26843317598104477, 0.7620166476283754, 2.692677306277411, 3.5902573253427232, 4.0230894940240045, 6.891195135457175, 7.932648028646197, 11.328639149665833, 8.2480936391013, 10.625504033906118, 21.61295015471322, 43.68027775628226, 61.032733236040386, 67.62817178453717, 65.19004195077079, 62.00464030674526, 62.30043206896101, 59.30734961373465, 54.699134077344624, 56.73220477785383, 65.00520597185407, 61.53485175541469, 58.90953050340925, 55.34393038068499, 52.54649877548218, 56.49240159988403, 58.28677041190011, 61.385173661368235, 58.867952483040945, 56.71487944466727, 60.36394132886614, 63.60091945103237, 60.15985189165388, 58.85302080426897, 62.058926582336426, 57.347724846431184, 58.65059198651995, 57.237415245601106, 57.8694338117327, 57.61915969848633, 61.028084891183035, 60.29981640407017, 64.69712284633091, 59.94247055053711, 66.00592722211564, 38.04602868216378, 29.00510389464242, 55.40337569372994, 54.0292513029916, 58.271762302943635, 60.886251313345774, 60.59262044089181, 58.82318523951939, 58.8769017628261, 55.11618232727051, 55.05511808395386, 53.723012924194336, 56.404156003679546, 54.664618900844026, 55.205310344696045, 59.5797051021031, 63.79234232221331, 58.63358279636928, 54.88527979169573, 55.771640641348704, 60.86975628989083, 60.0140300478254, 52.2066867010934, 48.402513231549946, 55.6026291847229, 57.81366409574236, 64.67262349809918, 65.51596110207694, 61.30676324026925, 59.183699471609934, 55.24069404602051, 60.00018228803362, 70.46051461356026, 61.87723118918282, 36.98030008588518, 9.954064863068716, 3.45332960997309, 6.428771240370614, 9.919012938226972, 5.313743438039507, 1.4338374265602656, 0.3269335611590317, 0.24988259854061262, 0.1580621405903782, 0.23162734668169702, 0.2345111205109528, 0.5870522675769669, 6.506847279412406, 49.87958213261196, 62.13662133898054, 55.91166421345302, 52.24767065048218, 35.70661537987845, 38.98268059321812, 56.603392124176025, 63.91522816249302, 73.71903215135846, 71.00316892351422, 84.55383763994489, 8.260692460196358, 0.8251567195568765, 0.17644008515136583, 0.22516634980482714, 0.13794760778546333, 0.21302568912506104, 0.20320549607276917, 0.20000817121139594, 0.15789333464843885, 0.09591408007379089, 0.06709871986614806, 0.11080172192305326, 0.09371464273759297, 0.1143384567861046, 0.1319317298808268, 0.14678004384040833, 0.1574308451797281, 0.12852389631526812, 0.1467256931854146, 0.11668952634291989, 0.22306116776806967, 0.13019248177962645, 0.1193032975175551, 0.07052027340978384, 0.08372150467974798, 0.15476181411317416, 0.12110683002642222, 0.15902787234101975, 0.11795674477304731, 0.0990707471168467], [0.018498147039541175, 0.006075316724101347, 0.04039809207565018, 0.037014953792095184, 0.0919151950095381, 0.02886076777109078, 0.11899569045220103, 0.03264710513342704, 0.022734166522111212, 0.03497995602499161, 0.040899848365890126, 0.018003315199166536, 0.03269598679617047, 0.04647323662149055, 0.027940628484689763, 0.04705970800880875, 0.07832633703947067, 0.08392820680247885, 0.05509211056466613, 0.008329353228743588, 0.04863174472536359, 0.05338442791253328, 0.02103669921468411, 0.04628049874944346, 0.10849502855645758, 22.5255126612527, 61.86191735948835, 62.777835845947266, 56.96783556256975, 47.22368533270699, 29.563122408730642, 25.52991894313267, 22.55089095660618, 39.31422431128365, 34.898116043635774, 29.85932411466326, 47.36328159059797, 24.03577310698373, 2.957247772387096, 0.03679227216967514, 0.03253982874697872, 0.03182601330003568, 0.11234232211219412, 0.41771351279956953, 1.800262947167669, 2.0785538256168365, 5.635446769850595, 2.7103949955531528, 2.1030366718769073, 3.291332794087274, 16.58666672025408, 36.072830608912874, 54.25172914777483, 61.27566310337612, 60.7044586454119, 58.50379044669015, 58.43393325805664, 62.82325622013637, 56.778445039476665, 61.59983825683594, 56.97513117109026, 54.13683026177542, 61.01792662484305, 52.47431741441999, 50.87722533089774, 43.81485046659197, 48.50135830470494, 48.16130304336548, 55.356558731624055, 55.98327929633004, 54.788546970912385, 55.15692656380789, 58.09419066565377, 54.46645280293056, 55.163798332214355, 49.70541163853237, 50.839236055101665, 46.226969718933105, 49.44566365650722, 46.79517602920532, 51.1604061126709, 49.58158084324428, 48.68616649082729, 49.78684105191912, 53.73622144971575, 54.68030445916312, 61.27089663914272, 41.482343673706055, 27.223929711750575, 60.50730351039341, 48.996608529772075, 56.38241509028843, 53.91092348098755, 57.86723470687866, 55.34257548195975, 61.642395973205566, 56.80213492257254, 55.12436383111136, 51.57270874295916, 52.99496330533709, 51.71499742780413, 54.24761928830828, 52.5593911579677, 59.17220715114048, 54.24269648960659, 56.75422361918858, 58.51641532352993, 59.559430258614675, 49.8936105455671, 41.80832535879952, 43.56111962454659, 50.426356724330354, 53.4340512411935, 59.765895979745046, 59.855659757341655, 56.671307291303364, 59.82315608433315, 61.1164242880685, 60.31506769997733, 57.212523324149, 61.09787259783064, 63.987683977399556, 46.30830880573818, 11.231747388839722, 0.836342559329101, 3.779986790248326, 2.334507439817701, 3.3072765214102606, 0.35139811411499977, 0.19084714778832026, 0.08364044010107007, 0.09913883132061788, 0.04652479849755764, 0.009276929926792426, 0.27590371082936016, 2.4429646943296706, 29.597338812691824, 36.68998350415911, 31.410290581839426, 22.842821257455007, 12.213805777685982, 33.03673185620989, 42.90725244794573, 53.65078639984131, 55.60835450036185, 52.22839982169015, 50.12897382463728, 3.2267466826098303, 0.23789578889097485, 0.014754623540544083, 0.02218298743745046, 0.10440396450992141, 0.01864664612470993, 0.04502204359908189, 0.04993790088753615, 0.013621589651198258, 0.03224714266668473, 0.013880770520440169, 0.0704128070335303, 0.032395660411566496, 0.026178729188229357, 0.025496112781443765, 0.0675893888941833, 0.043340342052813084, 0.08393765879528862, 0.04641659930348396, 0.09967600035348109, 0.029026201393987452, 0.018486515252983997, 0.008068319110731994, 0.06514239484178168, 0.04197719573442425, 0.07891895595405783, 0.06630805015031781, 0.06137662726853575, 0.032869708724319935, 0.03984804105545793, 0.06174712774476834, 0.06123764972601618, 0.02374658148203577, 0.029310972363288914, 0.028256376273930073, 0.017607959985200847, 0.02299258149495082, 0.05874638804899795, 0.026180686761758158, 0.03467410975801093, 0.03878670032801373, 0.07580162358603307, 0.023405749949493578, 0.05793785250612667, 0.013360386747600777, 0.0598754296079278, 0.03810240115438189, 0.026135842382375683, 0.05423974844494036, 0.08641528870378222, 0.061135523420359404, 0.026254738681018353, 0.026792754186317325, 0.2138529047369957, 32.26701736450195, 73.75721250261579, 68.87345572880336, 67.11145509992326, 56.95776414871216, 39.34963927950178, 30.29340934753418, 24.51324462890625, 32.402420384543284, 31.643805640084402, 28.63491255896432, 35.38125555855887, 20.23416178567069, 2.7084290896143233, 0.010858762144510235, 0.07871719356626272, 0.07672018358217818, 0.37754806663308826, 1.345147688473974, 3.626461999756949, 3.9853651182992116, 3.129076723541532, 1.5454856412751334, 1.1862378269433975, 2.614446452685765, 13.285651394299098, 36.02448851721627, 57.67379338400704, 63.23917538779122, 63.49445220402309, 62.16234357016427, 60.478107179914204, 62.94085448128836, 58.16710506166731, 61.218778201511924, 57.661578450884136, 55.50550379071917, 62.68521635872977, 54.61287566593715, 53.65325995853969, 46.77426542554583, 50.76437963758196, 51.364113398960654, 55.58127042225429, 58.189148221697124, 56.467860562460764, 56.65920352935791, 60.16553551810128, 57.001555170331685, 57.156440939222065, 53.06315640040806, 52.987261227199006, 48.95220259257725, 51.079685415540425, 49.27971288136074, 51.95718036379133, 51.03551571709769, 51.31889452253069, 51.112640721457346, 56.79944249561855, 56.427807671683176, 64.04388795580182, 42.986277784620015, 28.814476592200144, 59.93391036987305, 50.486597606113975, 57.44867869785854, 56.40304429190499, 58.135779108319966, 57.079048429216655, 62.66929803575788, 58.01265008108956, 58.94600159781319, 55.608642850603374, 54.29791382380894, 55.253555161612375, 55.86258908680507, 55.562756947108674, 58.5774621963501, 55.06303555624825, 57.43904849461147, 60.330742835998535, 60.44301182883126, 51.94595207486834, 44.164577620370046, 44.90447391782488, 52.53940119062151, 57.27903495516096, 63.12470381600516, 61.9904659816197, 55.825183459690635, 58.91877160753523, 61.50785105569022, 64.0569019317627, 60.5097770690918, 64.7867546081543, 64.40577098301479, 50.8438218661717, 13.682205063956124, 2.660701262099402, 1.3202364423445292, 2.69199030314173, 5.201533939157214, 1.638524408851351, 0.8073716110416821, 0.2804992656622614, 0.09357234037348203, 0.04849118280357548, 0.04334048115249191, 0.3256731687911919, 3.6396136369024004, 31.465636457715714, 40.848053046635215, 28.774397645677837, 27.497304848262242, 21.6832172870636, 42.28128923688616, 49.747416973114014, 58.99966253553118, 60.857909611293245, 57.12268311636788, 66.4379940032959, 8.277127555438451, 0.42347622928874834, 0.03431429620832205, 0.12158848132405962, 0.05878536310046911, 0.06869411854339497, 0.02411785039917699, 0.07471517367022378, 0.040752131292330365, 0.026919185616342083, 0.009859322470479777, 0.04813731322064996, 0.020161643491259644, 0.02863647123532636, 0.006010540378546076, 0.0588009829765984, 0.027148851060441563, 0.05319448560476303, 0.036625481476741176, 0.017638661998457143, 0.032026442366519144, 0.03449241843606744, 0.06851456460676023, 0.0246286362941776, 0.009053266973101666, 0.02878488041460514, 0.03858043925304498, 0.042724038873400004, 0.03685146417202694, 0.16219843578125748, 0.12339007322277341, 0.13041291066578456, 0.13890955331070082, 0.16470455058983394, 0.07731295855981962, 0.1352789838399206, 0.1879233403929642, 0.11552744012858186, 0.12266172016305582, 0.12523593274610384, 0.14531470675553593, 0.13493572654468672, 0.14208722779793398, 0.10699719642954213, 0.08991327243191855, 0.21625538010682377, 0.13699122624737875, 0.13374362194112369, 0.16673620657197066, 0.11174424099070684, 0.15881900569157942, 0.15046873662088597, 0.15072960619415554, 0.6800848469138145, 42.665778228214805, 83.47756167820522, 76.660642351423, 74.21684973580497, 62.44749069213867, 43.00528458186558, 35.05200822012765, 32.40273305347988, 54.0622934613909, 46.059684889657156, 39.21990251541138, 61.3768983568464, 31.63629116330828, 4.279263930661338, 0.14328073018363544, 0.24184469985110418, 0.14764411747455597, 0.6426262397851262, 0.9459834503276008, 6.323398334639413, 6.195009521075657, 11.444981523922511, 8.524290612765721, 7.5317942925861905, 7.606462240219116, 20.52528088433402, 39.984207834516255, 59.024106298174175, 64.13941179003034, 65.77641432625907, 63.07419041224888, 62.94331414358956, 66.45103577205113, 59.07402215685163, 60.50888769967215, 59.626702717372346, 55.38386515208653, 63.937629154750276, 57.84461484636579, 56.87927729742867, 47.418870653424946, 54.2406120300293, 53.61690003531319, 59.19874232155936, 60.00268363952637, 56.94062989098685, 57.89130326679775, 61.735821451459614, 59.5070686340332, 59.879241943359375, 54.65032993044172, 55.74141250337873, 51.09905699321202, 53.84566947392055, 51.89942693710327, 55.54654679979597, 54.40781000682286, 54.19454894747053, 54.69293975830078, 58.232418128422324, 60.85346276419503, 64.45837579454694, 46.70021152496338, 32.37713936397007, 59.56823362622942, 51.21777391433716, 59.269426345825195, 56.88432516370501, 59.307259287152974, 59.43819114140102, 63.64850071498326, 59.02653121948242, 60.71857043675014, 57.09096111570086, 57.00608886991228, 57.58901146480015, 59.782814843314036, 57.755354813167024, 60.33666270119803, 55.95964847292219, 58.9765111378261, 61.76998574393136, 64.21632834843227, 54.77925028119768, 45.749305384499685, 48.00178630011422, 56.36732360294887, 59.22304017203194, 65.79158224378313, 61.54512814113072, 56.143160820007324, 60.38211781638009, 62.72822570800781, 65.50985363551548, 62.28431224822998, 68.57823371887207, 70.77202320098877, 53.453700746808735, 14.377130883080618, 5.09760365315846, 11.771737064634051, 9.24234698499952, 8.265973091125488, 2.226723292044231, 0.405786929918187, 0.27293194457888603, 0.2117571679076978, 0.1368865690061024, 0.17599967521216187, 0.678248405456543, 4.63238571371351, 41.134294509887695, 50.376750060490195, 43.343998840876985, 35.966894899095806, 21.964124270847865, 45.28487042018345, 55.97427443095616, 67.35587882995605, 69.44167246137346, 66.14329310825893, 73.73171956198556, 7.911124246461051, 0.512294807604381, 0.23921819935951913, 0.26451010363442556, 0.17596420140138694, 0.18333963278148854, 0.05972670151719025, 0.13122187368571758, 0.16459149308502674, 0.11538905969687871, 0.10279698323990617, 0.15581579612834112, 0.1622024527085679, 0.10425092093646526, 0.10135103190051657, 0.13798460151468003, 0.1977037712931633, 0.17361644309546265, 0.1755850360329662, 0.14300656132400036, 0.0911654138139316, 0.09277009485023362, 0.10079340503684112, 0.12546404264867306, 0.18402861723942415, 0.11571395583450794, 0.0944103446922132, 0.0948028772005013, 0.1576414895909173], [0.005191428171071623, 0.011241261664378856, 0.05011417410735573, 0.02531473188927131, 0.029862115824861184, 0.04542535463614123, 0.07050000556877681, 0.06949762614177805, 0.030605617178870097, 0.018088571427922164, 0.1038110198985253, 0.025108618395669118, 0.023276472065065588, 0.033204480939145596, 0.009178010547267539, 0.039872763478862386, 0.025805999724460498, 0.015735004862238253, 0.020774874603375793, 0.043467611473585875, 0.015143597132659383, 0.043110125299010954, 0.07849725322531802, 0.03823715481641037, 3.9110641224043707, 55.07689373833792, 62.425652503967285, 61.4988739831107, 49.58176497050694, 30.649671282087052, 31.504320553370885, 25.056211607796804, 25.93389936855861, 32.38933345249721, 33.011079107012065, 54.227900300707134, 25.10340550967625, 1.5888922320944923, 0.0628545308219535, 0.059140026569366455, 0.09542589448392391, 0.004477525362744927, 0.22682390228978225, 1.8741895002978188, 2.313051619700023, 2.1663979462214877, 2.9042846943650926, 1.3747821897268295, 2.708182862826756, 18.983145577566965, 40.22644635609218, 57.09290313720703, 60.56128406524658, 59.091045243399485, 57.46686560767037, 55.229774951934814, 57.24646527426583, 58.0253826550075, 60.28514180864607, 56.49102585656302, 53.88233511788504, 57.18555041721889, 57.02185780661446, 53.07178258895874, 46.34090280532837, 41.33663647515433, 48.26443862915039, 50.66597924913679, 55.18311432429722, 57.150385584150044, 55.06579051698957, 55.11744342531477, 57.20036397661482, 56.01770067214966, 51.089982645852224, 47.08131674357823, 44.974741050175254, 42.932099206107004, 46.20834159851074, 48.08213526862008, 49.60119908196585, 48.98650584902082, 50.168040071214946, 45.62161486489432, 52.36369514465332, 52.168596676417756, 61.259098597935264, 36.7697696685791, 29.06592321395874, 55.482348918914795, 47.15415818350655, 51.997855118342805, 50.65846477236067, 53.80288246699742, 55.054506642477854, 55.49435888017927, 51.09174748829433, 55.93128940037319, 53.776527949741904, 58.374081475394114, 52.16970143999372, 55.285780906677246, 56.85637256077358, 55.54396901811872, 52.2970723424639, 56.83008057730538, 56.75045769555228, 51.102555411202566, 42.62655912126814, 43.22517422267369, 47.1931688444955, 54.627539839063374, 57.94501979010445, 59.66138812473842, 60.0559207371303, 58.49778720310756, 59.811503955296104, 60.917782238551546, 63.0434307370867, 61.10852418627058, 57.20433487210955, 59.95532471793038, 61.8971586227417, 54.47738231931414, 18.860245840890066, 1.8707989965166365, 1.5791178537266595, 4.927142628601619, 1.9365126703466689, 0.7055264360138348, 0.059786935070795674, 0.1548391128224986, 0.08710316036428724, 0.07528519058333975, 0.02869679978383439, 0.4114005315516676, 6.9627967561994275, 42.90920489174979, 43.974370683942524, 33.41296638761248, 26.084077732903616, 20.147618498120988, 34.00562340872628, 47.05810628618513, 56.323678493499756, 60.47446632385254, 55.99651214054653, 47.63504648208618, 0.6226382266197885, 0.1169620802892106, 0.05762721917458943, 0.05385403521358967, 0.05860399068998439, 0.0527388595177659, 0.03312921444220202, 0.05775624939373561, 0.036978489320193014, 0.06685711390205792, 0.009123508070063378, 0.03768212674185634, 0.026067178031163554, 0.10840390808880329, 0.012483958687101091, 0.013553681018363153, 0.1071451645610588, 0.011869032933775867, 0.0268008999992162, 0.008416794340259262, 0.03011361482952322, 0.06882231416446821, 0.0503075701583709, 0.030859324815017835, 0.061634457004921775, 0.06260908434965781, 0.03782369628814714, 0.024291048159024546, 0.005393418716266751, 0.03293323656544089, 0.0332470013360892, 0.01208975019731692, 0.04655807724754725, 0.04171660775318742, 0.026564534021807567, 0.02184612363842981, 0.02983153085889561, 0.012175539924230958, 0.09189698991498776, 0.06554814521223307, 0.05713036869253431, 0.03169876762798854, 0.0143990525310593, 0.005465262428125632, 0.01220685092266649, 0.02175830933265388, 0.01643665417629693, 0.03617161958079253, 0.015966790728271008, 0.04479827632063201, 0.040301750281027386, 0.08652259901698146, 7.558751566069467, 68.37077440534318, 67.51081671033586, 70.93183871677944, 56.781721115112305, 44.56351886476789, 39.25176000595093, 28.432978800364904, 30.556468146187918, 36.02033002035958, 29.282682691301616, 43.60271501541138, 20.589299849101476, 1.6847438258784158, 0.06440263560840062, 0.06796328883085932, 0.2041729377316577, 0.1859531325421163, 1.6556031895535332, 2.405212091548102, 3.2358208128384183, 2.1936739683151245, 2.6227528069700514, 1.7794993413346154, 3.610672218458993, 18.66110004697527, 43.226004532405305, 59.643920353480745, 65.04226766313825, 61.213754653930664, 59.53630665370396, 57.89653526033674, 59.19232218606131, 59.494026865277974, 61.907608713422505, 56.72593402862549, 56.75070088250296, 58.07438482557024, 59.08138724735805, 55.817331995282856, 49.01505947113037, 44.24558319364275, 49.74321331296648, 53.37513051714216, 56.88020488194057, 58.44516849517822, 56.03416790281023, 57.00133282797677, 59.22654206412179, 56.03870160239083, 53.488274982997346, 49.13212619509016, 47.32802990504673, 46.114315101078574, 50.18646321977888, 50.396858147212434, 52.16274629320417, 50.97151238577706, 53.42994138172695, 47.32722391401018, 54.915014607565745, 53.66195910317557, 62.69346387045724, 39.596738065992085, 31.15034110205514, 58.24421616962978, 48.89458812986101, 52.596404211861746, 51.659255504608154, 52.93173122406006, 54.778854233878, 55.08502313068935, 52.889076232910156, 56.68294204984392, 56.16422775813511, 58.90898854391915, 54.436502592904226, 57.17773021970476, 56.80310419627598, 55.81427131380354, 53.48699304035732, 58.66248035430908, 59.56792095729283, 52.881238664899556, 44.58125066757202, 44.60642746516636, 48.687128816332134, 59.222227232796804, 59.97996997833252, 61.18253639766148, 58.964956283569336, 58.34201553889683, 59.74787930079869, 61.1843637738909, 64.477552822658, 61.40922137669155, 61.26720019749233, 63.06057889120919, 64.91853414263043, 56.51109225409371, 22.424173184803553, 2.7259606974465505, 0.5262542271188327, 5.854799228055136, 4.149217537471226, 2.458371021917888, 0.5994493737816811, 0.2135350653635604, 0.06127184789095606, 0.05034275219908782, 0.021314830718828098, 0.0900176650445376, 7.660294277327401, 40.02632434027535, 43.18766784667969, 32.963675022125244, 25.887587887900217, 30.00712619509016, 42.10831730706351, 54.85392951965332, 62.333658354622976, 68.8707389831543, 59.41493552071707, 62.69208812713623, 3.0062653592654636, 0.2882837179516043, 0.025826856194596206, 0.03524829287614141, 0.04002611578575202, 0.039155959085162194, 0.01497219070526106, 0.040885531276996644, 0.03644466885764684, 0.08592736774257251, 0.02804280398413539, 0.048194330518266985, 0.0784235643222928, 0.0329658639218126, 0.01477186511536794, 0.04465884076697486, 0.09343759010412864, 0.01703828912494438, 0.04647316537531359, 0.03411758890641587, 0.08886530223701682, 0.031121510746223584, 0.035694721420960765, 0.05934205358581884, 0.013540358831440764, 0.06628809443541936, 0.01472972469803478, 0.03145265619137457, 0.04604105731206281, 0.11141190810927323, 0.1550198338393654, 0.10386087865169559, 0.17390997734452995, 0.1154937847916569, 0.12056371702679566, 0.19490161165595055, 0.09048733341374568, 0.13170618484062807, 0.19979546405375004, 0.16038123757711478, 0.11714634325887475, 0.11649239834930215, 0.08188129056777273, 0.11164051334240607, 0.18538058469338076, 0.14436517842113972, 0.10467026914869036, 0.10150475400899138, 0.1791929288634232, 0.1038200037021722, 0.14460037222930364, 0.1710672548839024, 10.989086764199392, 79.79731627873012, 78.48953328813825, 80.47848987579346, 65.61259664808, 43.85464627402169, 41.91158601215908, 33.94282558986119, 36.780542850494385, 44.67854629244123, 43.36441612243652, 71.21940381186349, 33.60664394923619, 3.18288921884128, 0.26522310823202133, 0.20472681229668005, 0.37520049831696917, 0.204551723120468, 1.9547996776444572, 6.536829624857221, 7.201358812195914, 9.123029044696263, 8.90248453617096, 6.47097590139934, 6.221590289047786, 24.0139297076634, 45.45193290710449, 62.66799872262137, 67.43213530949184, 64.64395523071289, 62.81696810041155, 60.841831479753765, 62.16547720772879, 64.09215709141323, 63.50142124720982, 59.84664099557059, 58.14711162022182, 59.91801983969552, 62.265836988176616, 58.615663392203196, 49.71831096921648, 46.18065650122506, 53.4982248033796, 54.84857593263899, 59.932666642325266, 61.430809429713655, 55.80170897075108, 58.85575839451381, 61.62425422668457, 58.62200709751674, 56.04981524603707, 52.05032096590315, 50.007776396615164, 48.7906847681318, 51.94023370742798, 54.48026582172939, 54.533690520695274, 53.62705135345459, 55.07059519631522, 49.504910945892334, 57.50156143733433, 56.87461158207485, 65.42577348436627, 42.74682201657976, 34.869649274008616, 59.451434407915386, 48.60829108101981, 53.53026989528111, 51.09089980806623, 53.55453995295933, 55.931817463466096, 56.95100007738386, 55.16346134458269, 59.23462976728167, 57.678504262651714, 62.06260912758963, 55.95595897947039, 58.563885416303364, 58.47244017464774, 57.114925452641074, 55.488428592681885, 60.689818790980745, 61.27353000640869, 54.953611850738525, 47.29276779719761, 47.79992028645107, 52.996266092572895, 61.46097155979702, 61.41764954158238, 64.10118280138288, 59.78166839054653, 59.13896002088274, 60.15928213936942, 64.6626945223127, 67.14010947091239, 66.02591024126325, 63.349019459315706, 66.27588558197021, 67.09256294795445, 58.75165353502546, 23.498222248894827, 3.933052565370287, 9.341687985828944, 14.86802111353193, 6.185091836111886, 2.7843572667666843, 0.39204309454986025, 0.6505062569464956, 0.2648349862013544, 0.2543959692120552, 0.11886041771088328, 0.7266843521169254, 10.86944660118648, 58.653531074523926, 58.544076102120535, 45.9405962399074, 36.64073467254639, 31.426493780953543, 46.72577742167881, 62.76824038369315, 69.1517310823713, 76.5953779220581, 68.20250293186733, 70.42169502803257, 2.890723764896393, 0.58860459285123, 0.11086553814155714, 0.08502736567918744, 0.12056982384196349, 0.12559547488178524, 0.19968556852212974, 0.14571611450186797, 0.09159729456795113, 0.20040351285466126, 0.14080725290945598, 0.09539737565709011, 0.11695798193769795, 0.23170697955148561, 0.1103222080107246, 0.1876791220690523, 0.15602171793580055, 0.07733146899512836, 0.14199700978185448, 0.08111495990306139, 0.24761460881148065, 0.1473193841853312, 0.12967763654887676, 0.1841644463794572, 0.1432641332170793, 0.18353137320705823, 0.12898287097258226, 0.08259215778005974], [0.00498070360793333, 0.03431781441239374, 0.018072971907843436, 0.025839269992762377, 0.06921097223779984, 0.037157951654600244, 0.04449245719505208, 0.008588782611436077, 0.024328284464510422, 0.03729144663416913, 0.01683611622346299, 0.03833700463707958, 0.06235098319926432, 0.046985781618527005, 0.04549546765961817, 0.011125652019732764, 0.04589807641293321, 0.04655398228870971, 0.005216846941038966, 0.06998610350170306, 0.016103897210476652, 0.037550982886127064, 0.054068550667060275, 0.06846575079751865, 27.344579969133648, 64.72688892909459, 62.87176159449986, 58.20897838047573, 44.364619731903076, 20.044606242861065, 33.79907430921282, 40.522404875074116, 23.00722258431571, 23.92257305553981, 39.83158370426723, 23.292341913495743, 1.0261948662144798, 0.10582264552691154, 0.06709894378270422, 0.1256994264466422, 0.10284940685544695, 0.17859594018331595, 0.9093832171389035, 1.0942505172320773, 1.825152805873326, 1.2006037703582217, 0.47915114036628176, 6.035118877887726, 22.877478872026714, 42.39773409707205, 60.35712514604841, 58.82918153490339, 57.23373964854649, 52.58484240940639, 49.86071082523891, 51.96391316822597, 54.7207464490618, 58.28020783833095, 57.520714146750315, 54.425500120435444, 54.79141657693045, 57.551789964948384, 55.05718169893537, 51.464563505990164, 42.37551028387887, 41.45600305284773, 48.79107734135219, 52.5821395601545, 56.256044728415354, 55.72731808253697, 55.90047761372158, 56.286787033081055, 54.420448780059814, 50.63518830708095, 45.0496426309858, 43.765796184539795, 43.65206112180437, 41.34358467374529, 47.793142318725586, 47.502210821424214, 51.49937398093087, 49.2711318561009, 50.375645296914236, 43.513847555433, 49.91823148727417, 53.14346020562308, 58.42488670349121, 29.149631636483328, 24.57905796595982, 54.16611691883632, 47.14948551995413, 54.79031876155308, 50.591240950993125, 54.81600972584316, 52.77588312966483, 51.63282803126744, 50.010632106236045, 54.02116012573242, 52.537716252463206, 54.16222940172468, 53.76521975653512, 56.12195839200701, 51.588092054639546, 50.09195382254464, 54.45818444660732, 57.069220202309744, 50.904021058763774, 47.12503480911255, 40.56741877964565, 44.37971816744123, 51.77468245370047, 57.311573369162424, 56.35210009983608, 59.40967573438372, 55.39958892549787, 55.95345415387835, 57.54586315155029, 59.16983781542097, 59.42990888868059, 61.453724588666645, 58.68226187569754, 57.56788199288504, 60.270647866385325, 62.2901417868478, 57.52453565597534, 26.116227047783987, 2.2321083630834306, 3.554201602935791, 2.05350969518934, 2.5030985304287503, 0.5274725503155163, 0.14210704102047853, 0.030294753145426512, 0.04256828115986926, 0.03204069499458585, 0.062485075289649625, 0.19749460608831473, 19.84722876548767, 33.388060569763184, 41.28802687781197, 26.74539337839399, 10.133837342262268, 21.68999351773943, 33.12263938358852, 45.53735753468105, 49.424252782549175, 53.88964809690203, 49.290121282849995, 34.95272888456072, 0.20637897721358708, 0.10549067226903779, 0.017593386749337827, 0.04056029926453318, 0.016917615064552853, 0.04838975538898792, 0.04491649069158094, 0.03992260526865721, 0.037726031350237985, 0.03976911386208875, 0.018410181759723594, 0.0486245624321912, 0.02242770618093865, 0.03222428960725665, 0.05669401300006679, 0.0433709609455296, 0.014099710870401135, 0.10321511687444788, 0.04420017145041909, 0.015307558334565588, 0.014781541024733866, 0.03328740131109953, 0.06240369179951293, 0.014507904815088426, 0.04013703590525048, 0.02929259424230882, 0.0035298477326120648, 0.033514483233115504, 0.03007537598854729, 0.022358102058725696, 0.027780263518382396, 0.024908379318990877, 0.010834320464969745, 0.027127714694610665, 0.08558352012187243, 0.024279189063236117, 0.048807715997099876, 0.03871503345934408, 0.07931335443364722, 0.030075986670064073, 0.07470882936779942, 0.12898344094199793, 0.0494192762167326, 0.01638702951770808, 0.022631368466785977, 0.033592009251671176, 0.025113848204325353, 0.017930426967463324, 0.007188623904117516, 0.049112924441163025, 0.1162063686975411, 36.72013521194458, 74.31100477491105, 70.43854440961564, 65.34076922280448, 52.45668636049543, 25.961275271006993, 34.39280135290963, 41.36450569970267, 21.04115857396807, 26.788062265941075, 41.00662136077881, 18.80578064918518, 0.7275514655879566, 0.03328295012137719, 0.06191773180450712, 0.07674902132047073, 0.04501645586320332, 1.440680859344346, 2.5381663058485304, 2.768684519188745, 2.037630238703319, 2.1997384428977966, 2.036877227681024, 7.56181137902396, 24.08820595060076, 47.132337365831646, 62.07392079489571, 61.541549818856375, 59.80931527273995, 55.44757318496704, 52.95752988542829, 53.98879541669573, 56.916662079947336, 60.611047063555034, 57.03406926563808, 56.02899496895926, 57.1557982308524, 58.82293510437012, 57.03872455869402, 53.5145218031747, 44.4458441734314, 44.131323541913716, 50.92041533333914, 54.06745249884469, 59.173666272844585, 56.95461661475045, 56.47079617636544, 58.34076486315046, 56.15251309531075, 52.73741442816598, 47.28951951435634, 46.72251524244036, 46.26660919189453, 44.51280048915318, 49.777328968048096, 50.542106764657156, 51.89926365443638, 52.73585455758231, 51.360830375126426, 45.456643785749165, 51.36198377609253, 54.85899128232683, 62.02356025150844, 34.1026827948434, 27.144954749516078, 57.0291290964399, 47.278819288526265, 54.529823848179404, 52.815070969717844, 54.95068318503243, 52.91246039526803, 54.69897774287632, 51.5969683783395, 54.458733354296, 52.63566848209926, 55.16208907536098, 55.17073610850743, 57.14466026851109, 52.521488734654014, 50.41874149867466, 55.52818965911865, 59.533131326947895, 55.023191111428396, 49.35594156810215, 41.672224044799805, 45.13878801890782, 53.98547417776925, 60.46831716809954, 59.47239017486572, 58.757754053388325, 54.724404675619944, 55.686525208609446, 58.8729829788208, 61.37950393131801, 61.15044961656843, 64.9664419719151, 60.44863292149135, 61.84838226863316, 62.84323923928397, 65.14272471836635, 57.85681240899222, 29.444544451577322, 3.2363927364349365, 1.4284926333597727, 3.687944872038705, 4.843978771141597, 2.71561005285808, 1.0549657280955995, 0.39098919395889553, 0.32457380635397776, 0.030872125378144637, 0.06177939208490508, 0.16353882742779596, 19.249801806041173, 35.83480964388166, 41.00563471657889, 22.521590403148107, 13.951139433043343, 33.29336704526629, 47.18353864124843, 52.72650923047747, 57.140077931540354, 63.78412955147879, 55.7097704069955, 51.91171135221209, 1.160957349198205, 0.25773544715983526, 0.03809308147590075, 0.026040917029604316, 0.027553239271843007, 0.05071862327999302, 0.03189486764105303, 0.026219665205904415, 0.015197627179856812, 0.08117473205285412, 0.05158037971705198, 0.05209337593987584, 0.025894836921777045, 0.0070704778107548395, 0.030371637948389565, 0.06530209484377078, 0.025593954138457775, 0.04595042199694684, 0.041536239574530294, 0.022272421745583415, 0.04399289257292237, 0.02308429398440889, 0.02651462607484843, 0.03485758223437837, 0.025781111059976474, 0.012134279906084495, 0.026129199524543116, 0.09479341163699116, 0.20556430092879704, 0.10094165136771542, 0.10317728176180806, 0.1114105646099363, 0.08574305727545704, 0.10345185774245433, 0.12355997839144298, 0.09861436446330377, 0.17922720845256532, 0.10556953160890512, 0.11655892192253045, 0.11343823080616337, 0.14645239285060338, 0.16764085660023348, 0.08431527710386685, 0.13645584854696477, 0.11520132262791906, 0.11507453157433442, 0.2045239167554038, 0.07774403185716697, 0.11330594361892768, 0.20286430152399199, 0.30175847347293583, 45.53555795124599, 87.66202395302909, 80.70194394247872, 74.95823642185756, 58.81927340371268, 31.488839966910227, 41.521489824567524, 52.6037415095738, 32.63927752631051, 35.921710763658794, 53.792015484401155, 30.341577734266007, 1.762835064104625, 0.23551198680485996, 0.10482959595641919, 0.23743652924895287, 0.1928792516035693, 1.2741251566580363, 3.477311534540994, 6.045370510646275, 6.677979239395686, 7.79423383304051, 7.175967923232487, 10.394615394728524, 26.4038234097617, 48.09762627737862, 64.39651598249162, 63.21350179399763, 63.59607655661446, 58.14722626549857, 53.50900840759277, 55.399272782461985, 59.585027422223774, 63.76454952784947, 57.850291524614605, 57.0343610899789, 58.89622470310756, 59.78100831168038, 60.27239881243025, 56.762047290802, 46.058552333286826, 46.041094984327046, 53.44725281851632, 56.46856233051845, 61.196689878191265, 57.54674904687064, 57.818882192884175, 60.45248222351074, 59.060285568237305, 55.65617200306484, 49.99380356924874, 49.31180313655308, 48.91588435854231, 45.832972117832725, 52.797988823481965, 53.60753386361258, 55.13758972712925, 55.00460468019758, 54.72552333559309, 47.619941098349436, 54.23968097141811, 57.52745042528425, 64.75212478637695, 36.487554686410085, 32.29631791796003, 58.351895877293174, 48.308038575308665, 56.88174738202776, 54.79878861563546, 56.94130039215088, 55.94381352833339, 56.60062674113682, 52.68915571485247, 55.89667347499302, 54.65017359597342, 56.59538779939924, 57.47088166645595, 58.51936830793108, 52.79776300702776, 51.24786308833531, 56.363012245723176, 61.21900054386684, 57.67592300687517, 52.10686540603638, 44.668033667973106, 48.08946214403425, 55.96967819758824, 61.89288548060826, 61.97954341343471, 59.54279627118792, 54.68440042223249, 55.358479908534456, 59.52298695700509, 63.134604998997276, 63.9796518598284, 65.64166791098458, 62.937505449567524, 64.01107161385673, 66.61034406934465, 67.69890444619315, 61.77765655517578, 32.637568269457134, 5.371993226664407, 10.320615342685155, 9.638746925762721, 8.968803354672023, 2.5595207256930212, 0.45363963501793997, 0.4002466643495219, 0.4429719517273562, 0.23009307043892996, 0.1532622245805604, 0.49609486545835224, 28.00519732066563, 48.19538395745413, 55.95529890060425, 38.00917543683733, 16.684879507337296, 32.48934582301548, 46.45649651118687, 57.43787424904959, 65.44311618804932, 70.91102886199951, 65.4057696206229, 59.30451474870954, 1.1732050691332137, 0.42331517221672194, 0.14874101004430226, 0.07909012319786207, 0.08855313541633741, 0.12695360343371118, 0.1363876150654895, 0.13673214800655842, 0.13517742071832928, 0.11057159677147865, 0.18024620520217077, 0.10083115193992853, 0.14301885637853826, 0.15972433425486088, 0.14328784123063087, 0.1614913615797247, 0.0721943685784936, 0.19579009898006916, 0.07631959686321871, 0.11554149937416826, 0.06383970938622952, 0.07309949358126946, 0.1570512998316969, 0.2045891239706959, 0.15133024539266313, 0.05834069196134806, 0.1041828774447952], [0.018072283194799508, 0.056431952597839494, 0.022496779349499514, 0.025993645191192627, 0.0027041810888996614, 0.01790024233715875, 0.015881052739652138, 0.04438487546784537, 0.028218656512243406, 0.09159342013299465, 0.008735532772594264, 0.008199261102293218, 0.06289621322814908, 0.04347956047526427, 0.0139192731419046, 0.022494803116257702, 0.017313178928036774, 0.05286100599914789, 0.04727969923987985, 0.04435197330479111, 0.008537234306069357, 0.030001656551446234, 0.291291636547872, 3.9845430595534186, 51.896942956107004, 60.179758480616975, 57.04392181124006, 61.476771763392854, 34.85618366513933, 41.657990659986226, 37.17634350912911, 27.521844148635864, 54.017800671713694, 39.66524035590035, 27.68150680405753, 1.2095561985458647, 0.09678084749196257, 0.0424517902678677, 0.09268573937671525, 0.09386544714548758, 0.4349246078303882, 1.4221095187323434, 1.370169562952859, 0.23364750828061784, 1.3770951798983981, 1.6334691601140159, 6.96600421837398, 25.435425179345266, 44.90629087175642, 57.831736360277446, 60.96345969608852, 56.693069049290244, 55.42375128609793, 47.85409886496407, 49.402626514434814, 53.993721689496724, 56.17593199866158, 55.39231068747384, 57.25859682900565, 51.00152860369001, 52.84887048176357, 57.918689591544016, 53.7464839390346, 49.43467508043562, 41.94004235948835, 43.51027618135725, 51.89999668938773, 54.88895538875035, 54.4066982950483, 53.159639086042134, 55.09564692633492, 54.282575675419395, 52.88111012322562, 45.572039467947825, 43.294510296412874, 40.49065160751343, 44.099900313786094, 44.08324548176357, 48.40379864828927, 48.14927223750523, 53.56443418775286, 50.66793516704014, 50.58538709368025, 43.23003101348877, 49.656357356480186, 50.74256576810564, 58.66658673967634, 32.80380392074585, 24.981311764035905, 51.15381227220808, 49.3026419367109, 55.74898951394217, 51.169876507350374, 55.1081988470895, 53.89002677372524, 50.23234217507498, 51.998685428074424, 54.54035036904471, 52.53467641557966, 53.16715703691755, 48.93500580106463, 51.67522593906948, 50.02787406103951, 52.0684175491333, 56.1140513420105, 55.03088624136788, 48.46916035243443, 42.102748325892854, 41.10834298815046, 46.250326088496614, 55.8063816343035, 57.80792488370623, 56.73308025087629, 51.86439411980765, 52.270373889378135, 58.930639130728586, 57.50044625146048, 57.55119589396885, 59.418145588466096, 58.31777327401297, 63.795649664742605, 60.01408563341413, 57.472066334315706, 58.912080492292134, 57.69816766466413, 57.069932392665315, 32.298492704119, 5.156442735876356, 3.577769024031503, 3.489648929664067, 2.771133759192058, 0.4894118383526802, 0.04585860603089843, 0.17427128367125988, 0.051226584772978506, 0.10372308854545866, 0.015243935498542019, 1.3490873170750481, 32.05005291530064, 35.48873724256243, 47.57859584263393, 33.92131049292428, 20.926165887287684, 18.009584835597447, 38.464049679892405, 42.864107608795166, 49.89290182931082, 52.96021883828299, 54.49149063655308, 28.529598712921143, 0.4988906468663897, 0.03506924444809556, 0.04282770884622421, 0.0406751039970134, 0.021988987490268688, 0.061030669403927665, 0.10677116284412996, 0.07450746053031512, 0.040067788013922315, 0.02477636863477528, 0.03279397403821349, 0.08036761464817183, 0.06409678594874484, 0.01631299965083599, 0.058996781041579585, 0.010056377521583011, 0.056605538818985224, 0.02128535176494292, 0.05493526040975537, 0.017353244724550417, 0.017046674121437327, 0.04957042667748673, 0.03032678339098181, 0.015722085555483187, 0.05246633949822613, 0.04359959332006318, 0.005549578461796045, 0.044327023572155407, 0.03539988099198256, 0.06511026620864868, 0.03335125824170453, 0.0292688081972301, 0.037849589184458764, 0.032051965461245606, 0.06385531569165842, 0.11079425125249795, 0.04201319880251374, 0.05276173632591963, 0.045145832135209014, 0.06786009722522326, 0.031065216088401418, 0.07522802400801863, 0.014938073964523417, 0.06102298838751657, 0.04557844231437359, 0.08614601208163158, 0.050057794632656236, 0.05376408861151763, 0.23848280310630798, 6.93697030203683, 63.494667598179404, 66.30684675489152, 65.7540202822004, 68.86201899392265, 44.89119243621826, 37.895377840314595, 43.77096217019217, 33.75495324816023, 34.669631481170654, 41.91283668790545, 27.087710278374807, 1.9069183383669173, 0.10702583739267928, 0.0374084362494094, 0.11441761468138013, 0.21997432197843278, 2.1117058524063657, 3.8297020196914673, 3.773111982004983, 2.738326753888811, 2.5808147830622534, 1.2590612449816294, 9.732260993548802, 27.31197554724557, 47.376087120601106, 60.79561901092529, 62.78745910099575, 58.496355874197825, 57.78576707839966, 51.01866980961391, 52.143649169376914, 56.950756890433176, 58.49089459010533, 58.37161486489432, 57.86711311340332, 51.72805656705584, 54.92008679253714, 58.98418194907052, 56.595012596675325, 51.525690283094136, 45.01484257834298, 44.87398522240775, 54.28336082186018, 56.90527398245675, 56.7661988394601, 53.85626547677176, 57.046301569257466, 56.77048587799072, 56.15096364702497, 48.47956875392369, 46.24525737762451, 42.31333780288696, 45.561836038317, 45.838402135031565, 50.37716000420706, 50.312958649226594, 54.59946911675589, 52.623707158224924, 54.23551900046212, 45.16249179840088, 52.63155862263271, 53.17438316345215, 60.85859053475516, 34.43312522343227, 27.312223945345195, 52.29749618257795, 50.776841231754844, 57.94458205359322, 53.66907058443342, 57.05569205965315, 55.34177643912179, 51.53905861718314, 52.30114051273891, 54.59256608145577, 53.91614505222866, 53.14280012675694, 49.511428356170654, 51.793004853384836, 49.22041695458548, 53.14162935529436, 57.079170022692, 58.12521437236241, 49.56147970472063, 43.200570651463096, 41.92354733603341, 47.508769920894075, 58.44985852922712, 59.60267584664481, 58.33553286961147, 50.97689723968506, 53.01318495614188, 61.80974333626883, 61.396575655256, 59.0909549168178, 60.76337242126465, 61.65231800079346, 65.7231980732509, 62.36407061985561, 61.35037708282471, 62.38362979888916, 60.88775907244001, 59.06759507315499, 33.53231906890869, 6.56181230715343, 0.9472134986094066, 2.476387049470629, 3.7216953124318803, 2.403323484318597, 1.1207743968282426, 0.7630869959081922, 0.2806951994342463, 0.08565586552556072, 0.0464411317370832, 1.4213767009122031, 32.770535945892334, 39.87752866744995, 43.086522919791086, 24.392801080431255, 26.869542053767614, 33.6956399508885, 50.4378525188991, 53.589246204921174, 57.94266087668282, 59.62121364048549, 63.72062301635742, 40.978807721819194, 0.41358465435249464, 0.008011747949889727, 0.09154236037284136, 0.03762967259223972, 0.026999544518600618, 0.038549708402050395, 0.032603085174092224, 0.1384906800729888, 0.0949918424178447, 0.04175164390887533, 0.021666905576629297, 0.03101575088554195, 0.038027881045958827, 0.06254579738846847, 0.024153997655957937, 0.0762885267447148, 0.030955741248492683, 0.03733262353177581, 0.016013299214786718, 0.036821517028978894, 0.03299198752003057, 0.00626200927321666, 0.05272709372054253, 0.0365783300782953, 0.08608995151839086, 0.01159698364790529, 0.13936669592346462, 0.11781094116824013, 0.169670504118715, 0.1653387772717646, 0.08763103346739497, 0.10813353902527265, 0.14192816561886243, 0.10605574266186782, 0.1723368481865951, 0.22956419310399465, 0.09622072361941848, 0.13593272518898758, 0.1305602341890335, 0.2924373022147587, 0.08800289101366486, 0.19612933934799262, 0.10874430875160865, 0.24237135159117834, 0.16777660431606428, 0.16019852166729315, 0.1077071340488536, 0.15483574728880609, 0.5229251171861375, 10.151009815079824, 76.81221035548619, 74.04524312700543, 74.7584479195731, 77.49059772491455, 48.81842197690691, 53.911305631910054, 47.13053430829729, 38.34876864297049, 68.27796036856515, 53.64108671460833, 38.08509840284075, 2.15493363567761, 0.2691436564283711, 0.19276091509631701, 0.28178223967552185, 0.2332906260022095, 1.8980713273797716, 5.173393300601414, 5.4031055229050775, 5.668363860675266, 8.610106945037842, 6.146411214556013, 11.302414042609078, 30.727741241455078, 47.8630759375436, 61.499395098005024, 65.70291628156389, 61.82314641135079, 59.87855407169887, 53.74621295928955, 54.89181457247053, 60.288921628679546, 61.89886787959507, 59.994568143572124, 57.08476332255772, 55.17219870431082, 56.12484189442226, 60.056525230407715, 59.031575611659456, 53.88388456617083, 47.444224630083355, 45.71108334405081, 58.48526654924665, 59.97651672363281, 57.32936770575387, 54.57284361975533, 56.592080456869944, 58.2658737046378, 59.3002416065761, 49.04145915167672, 47.71456861495972, 45.03497845785958, 48.338805198669434, 48.68693426677159, 53.32483945574079, 54.18813576017107, 58.57059737614223, 55.00244379043579, 55.76635306222098, 47.75004611696516, 53.96029738017491, 56.72833463123867, 62.45420265197754, 38.243847370147705, 31.035754884992325, 54.35998903002058, 52.10129989896502, 59.6467274257115, 54.98935685838972, 58.47117560250418, 58.766182218279155, 53.86489166532244, 54.60206079483032, 55.13433449608939, 55.030702114105225, 54.48201676777431, 51.23481437138149, 52.52994121823992, 50.21870286124093, 54.36023221697126, 59.854860714503694, 60.163395472935264, 53.05315446853638, 45.61838047845023, 44.91380187443325, 50.28046539851597, 61.268214634486604, 60.4862504686628, 58.85814162663051, 49.88326815196446, 53.30170195443289, 63.239050320216585, 63.81939165932791, 61.79473522731236, 64.11579486301967, 63.63600785391671, 66.69591808319092, 63.22844736916678, 62.2217298235212, 63.87299006325858, 64.15167536054338, 60.15395287105015, 37.01150444575718, 8.416812402861458, 10.567304185458593, 10.887921861239843, 11.527833580970764, 2.423642839704241, 0.8451648173587663, 0.5142962144953864, 0.2749995764877115, 0.39647238116179195, 0.14180323375122889, 2.329104564019612, 44.25516128540039, 49.52831595284598, 62.508933612278526, 45.731667382376536, 32.51421342577253, 27.473932845251902, 49.780611991882324, 57.01227624075753, 65.139299256461, 67.39991651262555, 74.25671849931989, 46.531808035714285, 0.7268012229885373, 0.1310499193412917, 0.18431793100067548, 0.15437183289655618, 0.13431615621915885, 0.11075067573360034, 0.16260559750454767, 0.1603579773966755, 0.16725551656314305, 0.10564527647303683, 0.09855126749191966, 0.15327043485428604, 0.28466169802205904, 0.1518747561744281, 0.16892091291291372, 0.22434814513794013, 0.189951250861798, 0.08111757226288319, 0.06984660348721913, 0.10596394365919487, 0.09231671132147312, 0.11325436138681003, 0.1676875805216176, 0.16736556137246744, 0.19433256504791124, 0.273867454379797], [0.07135165522673301, 0.02534062648192048, 0.00764502352103591, 0.08301603182085923, 0.04657755459525755, 0.07598879068557705, 0.028272416841770922, 0.01985025528951415, 0.006757159176881292, 0.03744835446455649, 0.030448112237666334, 0.017872325710154006, 0.027298976933317523, 0.04597170764048185, 0.031404738048357625, 0.051579368699874194, 0.08018614045743432, 0.034822627502892695, 0.056833550333976746, 0.028782739636621306, 0.07301370639886175, 0.1716848574578762, 0.14093246976179735, 24.04536509513855, 62.57379504612514, 56.03344529015677, 50.31821148736136, 39.273441859654014, 27.55584168434143, 26.0660297870636, 19.517578431538173, 38.528150285993306, 42.86449670791626, 30.782281126294816, 7.7329142434256415, 0.07108235146318163, 0.04997806676796504, 0.1393999577100788, 0.04109797380598528, 0.18512898390846594, 0.998377644589969, 2.932272038289479, 2.0486950278282166, 2.103113102061408, 1.562621961746897, 7.407758525439671, 29.412829399108887, 46.94497224262783, 61.89206559317452, 58.715342249189106, 59.76273454938616, 53.13450745173863, 49.84159285681588, 43.71211787632534, 51.10181195395333, 53.30854593004499, 58.17717300142561, 56.90686164583479, 54.09439066478184, 49.30990627833775, 50.49885770252773, 52.32104362760271, 54.100199358803884, 48.537158897944856, 42.88053315026419, 41.46517467498779, 53.34048332486834, 52.50128337315151, 55.71228218078613, 51.59794807434082, 54.307874066489084, 56.497633593423025, 53.39175755637032, 42.613298484257285, 40.24483476366316, 41.67371095929827, 44.620997837611604, 44.18940353393555, 48.005548749651226, 47.531580856868196, 50.38797834941319, 46.93777043478829, 48.3365991456168, 39.537132944379536, 48.96273258754185, 50.36219358444214, 58.95716735294887, 34.81796162469046, 30.13148852757045, 58.745386259896414, 51.665627002716064, 55.4563696043832, 49.17418016706194, 53.05908823013306, 49.837069579533164, 52.834571089063374, 53.14407164709908, 57.85499198096139, 53.619835649217876, 54.27314002173287, 52.10635123934065, 51.944003105163574, 47.756747654506135, 52.97710296085903, 53.583972522190635, 54.20670829500471, 44.3997289793832, 41.7695300919669, 39.60050746372768, 47.29705483572823, 55.74309049333845, 57.283471379961284, 55.77223818642752, 52.640650340488975, 56.18111882890974, 53.952039446149556, 57.127206393650596, 56.115559101104736, 55.86895363671439, 58.711326190403526, 57.94853210449219, 61.9352764402117, 62.27607863289969, 56.426716804504395, 54.72499874659947, 51.71136351994106, 54.808787073407856, 35.336721079690115, 3.8503868068967546, 2.5385141500404904, 4.1067445022719244, 4.625790570463453, 0.594703482730048, 0.49151372270924704, 0.13538582596395696, 0.11528099620980875, 0.031265065007443936, 0.11438706703484058, 3.8866859333855763, 36.581932067871094, 28.973581654684885, 38.77757671901158, 28.42135099002293, 16.907345192773, 17.03427141053336, 33.22644894463675, 39.33099378858294, 50.44443246296474, 48.59148686272757, 57.859932150159565, 16.059918573924474, 0.6719301044940948, 0.07549909874796867, 0.025905746068539362, 0.08233666220413786, 0.021877716228898083, 0.06379740272781678, 0.006338652772163706, 0.060605614712195735, 0.08769081240253788, 0.05947346546288047, 0.0183038485369512, 0.043021376311246834, 0.06970943084784917, 0.02910443308896252, 0.08200885515127863, 0.030272989134703363, 0.031113524389054095, 0.022153135289305022, 0.020713986263477376, 0.026932518829458525, 0.02824120592725064, 0.02646598868471171, 0.030292798964572803, 0.07095554683889661, 0.031937588205827136, 0.05664448333638055, 0.019939701472009932, 0.024460142478346825, 0.025101079871611934, 0.057262832298874855, 0.06826740822621755, 0.01516879622691444, 0.030034182127565145, 0.02500250908945288, 0.10057340362774474, 0.03501602355390787, 0.05220336646639875, 0.08006728826356785, 0.012941743363626301, 0.04384596259998424, 0.06589170106287513, 0.07370058061288935, 0.04503272034760032, 0.027910532063937614, 0.042190951228673966, 0.057565126435032914, 0.052652200417859216, 0.2580102267009871, 33.19243056433541, 73.15976469857353, 65.22433131081718, 58.489692551749094, 51.50846222468785, 35.14317553383963, 33.10260077885219, 28.754246132714407, 29.82809543609619, 49.303830078669954, 33.328549248831614, 7.859578166689191, 0.06221279954271657, 0.07937755063176155, 0.09672666647072349, 0.20095313979046686, 1.0032115280628204, 2.6420449146202634, 4.483285188674927, 2.1353577375411987, 1.7572594604321887, 2.303052293402808, 8.635666762079511, 32.071196283612935, 48.82958425794329, 61.69286073957171, 59.369952883039204, 64.11070878165108, 56.31525380270821, 52.4598616872515, 45.5491555758885, 53.720647062574116, 55.383760929107666, 60.223407064165386, 57.197275502341135, 52.85699987411499, 50.40782240458897, 51.71681438173567, 53.91117014203753, 56.10440376826695, 51.995711599077495, 44.22526666096279, 43.16551004137312, 55.24548830304827, 54.74526316779, 55.7249869619097, 51.19916663851057, 56.39479330607823, 56.7722680909293, 56.33502490179879, 45.43362440381731, 42.99726288659232, 42.66721303122384, 47.84075484957014, 46.71268354143415, 49.52423736027309, 50.265669209616526, 51.4675338608878, 49.76845611844744, 49.871320724487305, 42.497044699532644, 51.33119283403669, 51.816284792763845, 61.669869150434224, 37.66338096346174, 31.88282367161342, 60.23696994781494, 53.577458586011616, 57.71077169690813, 51.60808549608503, 55.06385891778128, 51.23997688293457, 54.724884101322715, 54.91371182032994, 58.562523569379536, 55.25873156956264, 58.167883259909495, 52.88883999415806, 51.61234821592058, 48.65974249158587, 54.51077536174229, 55.123415402003694, 56.54322419847761, 47.44937671933855, 42.732588631766184, 41.114801338740754, 48.55294173104422, 58.627496174403596, 58.79132774897984, 54.362427847726, 51.79372746603829, 58.621888978140696, 57.557845320020405, 58.438088280814036, 58.51080812726702, 57.83275427137102, 59.497841426304404, 60.55808789389474, 62.84622696467808, 60.35677078792027, 59.762241227286204, 58.61883177076067, 56.903926031930105, 57.79873936516898, 38.8631785256522, 6.6118554047175815, 1.0892965602023261, 3.6569294163158963, 5.005763666970389, 2.2901227814810614, 1.5003795645066669, 0.583231192614351, 0.11643831910831587, 0.07541274159614529, 0.10249317597065653, 5.236200673239572, 38.67763730457851, 33.77221952165876, 41.74582283837454, 23.726956946509226, 19.39636537006923, 25.791120835712977, 41.222960472106934, 44.77332666942051, 58.833412987845286, 54.757283551352366, 66.06796073913574, 23.7262464932033, 0.5111624683652605, 0.029104215957756554, 0.043319897792701206, 0.009582896633738918, 0.007645749553505863, 0.019452082458883524, 0.01724121350395892, 0.07860984932631254, 0.05622184083663991, 0.028711228831005946, 0.043548058585396836, 0.03572863120851772, 0.06138494610786438, 0.043962463670011075, 0.048190530722162554, 0.010417072318627365, 0.055451618773596625, 0.02519169991968998, 0.049940740556589196, 0.010099489092161613, 0.031403442046472003, 0.02557828846121473, 0.005141992654119219, 0.025191772862204483, 0.012445989563795072, 0.16261477129799978, 0.06672105406011854, 0.12023765380893435, 0.1429649671273572, 0.13653006670730455, 0.22859201527067594, 0.13108489103615284, 0.12338459065982274, 0.09897824922310454, 0.16325650257723673, 0.12305275989430291, 0.11784113597656999, 0.14370370177286013, 0.09684785961040429, 0.21414246277085372, 0.19175483765346663, 0.12374137794332844, 0.1492741892912558, 0.18459165202719824, 0.18653676765305655, 0.17367357574403286, 0.31409500007118496, 0.42577822719301495, 43.85638679776873, 82.97300434112549, 74.61184787750244, 66.82435553414481, 55.9826991217477, 40.556068897247314, 36.10233613422939, 27.05222930227007, 52.6258749961853, 55.916131905147004, 44.54227474757603, 10.625888790403094, 0.21497262322476932, 0.12383460865489074, 0.28086909438882557, 0.20734565891325474, 0.7924278272049767, 2.783971858876092, 8.584192769868032, 8.698112828390938, 6.532336745943342, 6.217720142432621, 11.200645514896937, 35.13135664803641, 50.266791343688965, 63.45699446541922, 61.5552864074707, 64.13208144051688, 58.56981222970145, 53.61269637516567, 48.00293622698103, 56.95206315176827, 57.120424951825825, 62.38374791826521, 59.4269072668893, 53.814482484545024, 51.64780487333025, 51.94387108939034, 56.0487938608442, 58.44139562334333, 53.769541536058696, 47.36220114571707, 45.895537172045024, 57.358376434871126, 56.58702564239502, 56.93042298725673, 53.15127345493862, 57.13591596058437, 60.240701130458284, 60.00643566676548, 48.5122252873012, 45.90371520178658, 45.57291841506958, 50.199202741895405, 49.9779234613691, 52.720717906951904, 53.21805953979492, 54.95305599485125, 52.95603602273123, 51.910790715898784, 43.714223180498394, 53.02572645459856, 56.11336694444929, 64.3852460043771, 41.930328777858186, 34.44613572529384, 61.45138304574149, 57.022125312260215, 59.802443504333496, 53.69548068727766, 57.00484166826521, 54.165474210466655, 56.84711061205183, 58.07513175691877, 61.395463943481445, 57.854349272591726, 59.8116637638637, 55.8315167427063, 52.32098804201399, 49.37053278514317, 55.531177384512766, 58.15952805110386, 58.55144119262695, 50.1323367527553, 45.25461796351841, 43.91930273600987, 51.64526530674526, 61.088874680655344, 59.92749718257359, 55.903597354888916, 53.293541295187815, 59.535736901419504, 58.82501261574881, 61.7011707850865, 60.67513724735805, 59.46868678501674, 62.62700435093471, 63.85748168400356, 63.03430775233677, 62.534093039376394, 64.69220352172852, 60.63516426086426, 60.371723311288015, 61.86651011875698, 41.1129982812064, 7.1400400911058695, 7.966625588280814, 10.358203360012599, 12.278558645929609, 2.436794911112104, 1.4115155786275864, 0.7287681603005954, 0.30742641219070976, 0.18713158502110414, 0.23128802488957131, 6.43615630694798, 51.52284846987043, 42.00047084263393, 54.7783192225865, 39.63795478003365, 24.914814029421123, 25.813193525586808, 45.694921834128245, 51.605969769614084, 68.09342316218785, 63.33158642905099, 76.65846061706543, 26.080636637551443, 0.9817195555993489, 0.16389015928975173, 0.07735457311251334, 0.1534445605107716, 0.14209987569068158, 0.17450468614697456, 0.13691285545272486, 0.2009464765765837, 0.1388479694724083, 0.13279701130730764, 0.13104081340134144, 0.08123170185301985, 0.16907933726906776, 0.1340084405882018, 0.14941729232668877, 0.13688639258699759, 0.1669598381434168, 0.11713069624134473, 0.15316265635192394, 0.09332321624138526, 0.10845648776739836, 0.11557082565767424, 0.09360115097037383, 0.21741061311747345, 0.13451306708157063], [0.06646116157727582, 0.0662713549765093, 0.023432373967287794, 0.021278038853779435, 0.008864698698744178, 0.012407314764069659, 0.03342424825366054, 0.08194569711174284, 0.05650271701493433, 0.0737001056383763, 0.020667698300842727, 0.04497281927615404, 0.012769803438069565, 0.0562287245744041, 0.041203526713486226, 0.01812858463797186, 0.02268767330263342, 0.041297985573432276, 0.01655187620781362, 0.03836229024454951, 0.12963136046060494, 0.11196491414947168, 3.4244218468666077, 54.2481438773019, 63.26250049046108, 59.536396980285645, 48.846610818590435, 31.12514693396432, 20.835825409208024, 19.32863780430385, 25.196947370256694, 50.55129228319441, 39.31400544302804, 15.09686871937343, 0.0927338067974363, 0.05001093161159328, 0.04532708240939038, 0.12084156354623181, 0.04560423343043242, 1.0130383436168944, 3.497742929628917, 3.4677000045776367, 2.9829120295388356, 1.7789519535643714, 12.260325704302106, 35.197194303785054, 57.5659191267831, 58.280801909310476, 59.53277696881975, 58.063660281045095, 58.104734557015554, 52.77466719491141, 47.10831049510411, 44.92578751700265, 49.63991444451468, 53.66208764484951, 54.630465030670166, 53.32462753568377, 56.7606645992824, 52.16572707039969, 52.1467411177499, 51.62326383590698, 54.80855778285435, 51.5772876058306, 45.620933941432405, 38.81033747536795, 48.941238335200715, 55.6532746042524, 55.52755389894758, 52.26705265045166, 53.59497846875872, 51.96815504346575, 49.78923123223441, 41.756554331098286, 40.86165761947632, 40.592143944331575, 45.27071346555437, 45.35633264269148, 48.87518528529576, 47.8791366985866, 47.583452633449006, 46.744436808994834, 45.59793192999703, 40.150506019592285, 53.04651199068342, 50.8880158833095, 57.95329509462629, 31.126196111951554, 31.857733726501465, 60.05005645751953, 49.06327996935163, 54.00794465201241, 47.549229281289236, 52.54775987352644, 47.173060757773264, 50.276859283447266, 47.878542627607075, 49.243985244206016, 50.96769435065133, 54.31973116738455, 53.82029117856707, 49.556602069309776, 44.750911780766074, 56.26889542170933, 52.77740478515625, 50.275709356580464, 40.13679722377232, 39.16339629037039, 39.387572969709126, 46.88134411403111, 54.892787320273264, 55.307268210819785, 51.42508036749703, 51.185572487967356, 54.55723449162075, 57.90367106028965, 51.69458014624459, 51.8759628704616, 54.590203693934846, 57.173033237457275, 56.5406950541905, 53.81838389805385, 56.612633228302, 53.94237797600882, 58.772706576756065, 56.787029538835796, 47.36013058253697, 52.887651852199006, 33.088468142918174, 6.112140093530927, 0.9424553939274379, 2.5619248024054935, 2.2185380969728743, 2.272981358425958, 0.516833664051124, 0.07329543413860456, 0.02357116321633969, 0.055157568837915144, 0.10732995000268732, 16.094739471163066, 41.8290170942034, 24.91640169279916, 48.35848249707903, 50.12305743353707, 31.180256571088517, 35.62097883224487, 40.665360586983816, 40.150196824754985, 51.35186719894409, 47.74869121823992, 54.33904715946743, 3.4407733465944017, 0.21981364488601685, 0.07135327692542758, 0.053487901110202074, 0.023636134640712823, 0.0057165638094634885, 0.03573633258097938, 0.010756488257486905, 0.03416188367243324, 0.009951212227211466, 0.05410477086635573, 0.06360211356409959, 0.05389657935925892, 0.0004893776380673184, 0.05566117413608091, 0.009126966054152166, 0.020980918547138572, 0.05024197957079325, 0.048038043547421694, 0.06338090436267, 0.020219249418005347, 0.04585687576660088, 0.04609407125306981, 0.029727321450731585, 0.046004606410861015, 0.025753355585038662, 0.025404773486245955, 0.03866417725969638, 0.03911949461326003, 0.052457769600940604, 0.006405019010084548, 0.032824776135385036, 0.06586014918450799, 0.03890994603612593, 0.1260689701884985, 0.03691013709508947, 0.04904162398140345, 0.0353569874007787, 0.0246484155899712, 0.021611608365284543, 0.07717130758932658, 0.11738456333322184, 0.04423539759591222, 0.04719266355303781, 0.04714544090841498, 0.09550078439393214, 0.30041421417679104, 5.73492716891425, 65.75542381831578, 71.22783892495292, 66.98795781816754, 54.858383314950125, 40.76481710161482, 29.76804562977382, 20.657458203179495, 23.43653266770499, 59.560868535723, 45.084849153246196, 14.441175903592791, 0.10813693848571607, 0.052104754972138574, 0.05057340321530189, 0.3934532260256154, 0.4407002164849213, 3.7956380418368747, 4.74645732981818, 2.2309058904647827, 1.2532413687024797, 2.2611242575304846, 13.004557677677699, 36.767285687582834, 57.51828575134277, 60.011000633239746, 61.708765166146414, 60.66392285483224, 58.638119970049175, 55.71756281171526, 48.693486418042866, 47.188746316092356, 51.10677644184658, 56.539944648742676, 56.46979563576834, 55.32182468686785, 58.6419414792742, 53.86919607434954, 52.12730353219168, 52.45676973887852, 55.96257366452898, 53.22700187138149, 47.53932115009853, 41.080056871686665, 50.75317914145333, 57.348266805921284, 56.892805440085276, 53.83640405109951, 55.2430807522365, 53.339906624385286, 52.64492348262242, 44.25963939939226, 40.47899947847639, 43.22414588928223, 47.81781884602138, 48.40029328210013, 50.10392556871687, 50.32725804192679, 50.633809089660645, 49.3951815196446, 47.54944814954485, 41.49242550986153, 54.43692295891898, 51.7473795073373, 60.740200178963796, 34.113059929439, 33.30823619025094, 60.907672609601704, 49.91212749481201, 55.98494686399187, 50.151155948638916, 52.81826366697039, 48.120475428445, 52.35029901776995, 49.84239884785244, 51.45836918694632, 54.06532635007586, 55.27396202087402, 55.10917854309082, 49.480446338653564, 45.26116664069039, 58.623396737234934, 54.91082484381539, 53.43470784596035, 41.62316976274763, 41.76071630205427, 40.471405097416465, 48.298384053366526, 57.246100493839805, 55.95105355126517, 51.84751347133091, 50.809890338352744, 57.45871189662388, 58.77611814226423, 54.65622200284685, 53.26059988566807, 54.921076910836355, 58.451421873910085, 60.286573137555806, 55.69110059738159, 58.61783817836216, 58.67542484828404, 59.1602840423584, 58.7969696862357, 53.05619083132063, 55.706685406821116, 37.19792808805193, 7.979780265263148, 0.08797804984663214, 6.134462918554034, 6.287990314619882, 2.8690232379095892, 2.3217518499919345, 0.4703027723090989, 0.08684477422918592, 0.02190342083174203, 0.10863911546766758, 17.828398397990636, 42.56914268221174, 25.68749019077846, 40.00036934443882, 31.443541186196462, 31.219232491084508, 46.49916539873396, 47.57428101130894, 45.96109342575073, 57.303676741463796, 53.36056014469692, 64.05266353062221, 6.0703423363821845, 0.2515051657600062, 0.06339716206171683, 0.08886559400707483, 0.06843550170638732, 0.03927464164527399, 0.05847574078610965, 0.0805672871481095, 0.04248538453664098, 0.02923318510875106, 0.0625987977587751, 0.0223828516235309, 0.07516523916274309, 0.019099692082298652, 0.014665277441963553, 0.020907002334882106, 0.015696849141802107, 0.013537045884212213, 0.1259076688438654, 0.02406731141465051, 0.008230098822553242, 0.03416495065071753, 0.05994876567274332, 0.05768180053148951, 0.029037078310336386, 0.10107050516775676, 0.132181742893798, 0.10343154240399599, 0.05563927102567894, 0.07332012602793318, 0.07112856648330178, 0.1331341075045722, 0.18885815808815615, 0.12356681802443095, 0.19546978973916598, 0.1665162390896252, 0.13281766591327532, 0.1046091534995607, 0.21220045483538083, 0.10382845146315438, 0.1896703237933772, 0.17481252391423496, 0.1318252541657005, 0.16011548255171093, 0.17832310125231743, 0.2746973841318062, 0.3244450204074383, 8.489117962973458, 80.72713116237095, 79.08589022500175, 75.7525405883789, 63.89766311645508, 45.218956334250315, 31.542452267238072, 29.57266228539603, 35.20316628047398, 62.55362442561558, 51.516271999904085, 20.687785352979386, 0.23679553078753607, 0.13073517408754143, 0.27535496598907877, 0.5301426670381001, 0.22654106175260885, 5.259636512824467, 11.587225045476641, 12.255881462778364, 8.79535894734519, 5.977765841143472, 15.585340976715088, 40.83589022500174, 61.720882824489046, 62.296596663338796, 62.69867501940046, 62.405662536621094, 62.40414088112967, 57.304944787706646, 51.36578444072178, 50.82655559267317, 54.0472297668457, 59.2752628326416, 59.51663630349295, 57.861415590558735, 60.68883214678083, 53.949079513549805, 52.83596420288086, 51.492331981658936, 58.16729266302926, 55.44986956460135, 51.382870061056956, 42.757612568991526, 53.734536511557444, 60.034881591796875, 59.02997752598354, 56.30168744495937, 57.18240635735648, 56.39099958964756, 53.930979456220356, 46.474276951381135, 43.56838744027274, 46.21815940311977, 50.904615129743306, 50.907734870910645, 52.642891134534565, 52.68842615400042, 52.86287457602364, 51.53225980486189, 49.13448510851179, 44.24376276561192, 56.637622424534385, 55.09419475282942, 62.56402587890625, 37.85765954426357, 36.43479354040963, 61.70505482809884, 53.82097905022757, 58.21325499670846, 52.38188900266375, 56.21617249080113, 51.495615005493164, 55.48301247188023, 52.267347948891775, 52.5955183165414, 57.61486223765782, 57.63848958696638, 58.391556194850374, 49.120665141514365, 44.57055044174194, 60.74948992047991, 57.809071336473735, 55.93700776781355, 44.032655647822786, 43.86035074506487, 43.330296993255615, 51.3967456136431, 61.18389824458531, 58.49450765337263, 53.13987840924944, 50.963525431496755, 57.9408335004534, 61.69372231619698, 57.09075614384243, 55.81104040145874, 57.57307924543108, 62.16317735399519, 61.397228785923545, 58.34975583212716, 61.53455993107387, 59.78089714050293, 63.19372722080776, 60.94968836648123, 55.72633491243635, 60.041176659720286, 39.22779219491141, 8.730890086718968, 5.834549571786608, 9.73388079234532, 10.0841611964362, 5.463221337114062, 1.328614884189197, 0.48193660804203575, 0.22423765249550343, 0.16451006888278893, 0.2916407292442662, 23.060004574911936, 56.48022140775408, 34.17412417275565, 62.53626087733677, 64.49700777871269, 41.153940541403635, 46.95760754176548, 53.86451646259853, 53.74428483418056, 67.29349095480782, 60.75665351322719, 73.48227923257011, 7.232219670500074, 0.4646671861410141, 0.2297814871583666, 0.10901403999222176, 0.2553762351827962, 0.10287498762564999, 0.20251352606075151, 0.15588226541876793, 0.10485772801829235, 0.130443417600223, 0.13920524530112743, 0.14221350316490444, 0.13557892345956393, 0.08992530964314938, 0.1576448551246098, 0.08135571091302804, 0.09408690061952386, 0.10575879538165671, 0.2633628366248948, 0.11634797895593302, 0.11908539278166634, 0.06097613554447889, 0.15855904535523482, 0.13994307070970535, 0.16261888322021278], [0.044316879473626614, 0.013933560544891017, 0.010384016637025135, 0.05778087342956236, 0.055902641000492234, 0.04713219929752605, 0.04948953173256346, 0.021676542470231652, 0.061150844741080485, 0.010177339959357466, 0.04099206806027463, 0.03883394332868712, 0.03364147445453065, 0.006612965396405863, 0.0770540228113532, 0.02674149765100862, 0.027738659143713967, 0.012207648201313401, 0.016639658283176165, 0.06816586546067681, 0.04494707905022161, 0.06062251701951027, 20.557367665427073, 69.07507855551583, 58.32184491838728, 55.22514050347464, 35.61810575212751, 28.127002716064453, 14.452073284557887, 21.26226588657924, 38.464400563921245, 24.510444504874094, 33.57576962879726, 1.1921950387103217, 0.04042511473276785, 0.052492415598992787, 0.11084299042288746, 0.11611582498465266, 0.5890415151204381, 2.336152208702905, 3.363992929458618, 2.3063967653683255, 1.7585972057921546, 18.998178005218506, 47.82770613261631, 57.78755276543753, 58.809754371643066, 58.37995965140206, 58.69816630227225, 56.65145281382969, 57.64405509403774, 46.94868605477469, 43.054672377450125, 40.67417090279715, 43.44665847505842, 47.463245323726106, 50.586637769426616, 51.35929134913853, 52.57641771861485, 57.02165283475603, 52.04542943409511, 50.40640149797712, 53.33011313847133, 52.58897658756801, 46.310542651585166, 38.545117786952424, 40.51690884998867, 46.624747140066965, 53.187449250902446, 51.062252385275706, 53.07380451474871, 49.935077394757954, 47.853098324366975, 40.657606397356304, 40.03073992047991, 41.63142769677298, 47.45805154527937, 45.69653034210205, 51.007420676095144, 48.39543996538435, 48.934363092694966, 45.67552941186087, 43.47623348236084, 40.631522859845845, 51.66901772362845, 49.609543868473594, 57.00158643722534, 32.63427134922573, 36.10711996895926, 61.38493742261614, 47.74484191622053, 53.22377790723528, 46.43630852018084, 49.78773389543806, 46.72392920085362, 47.770612784794395, 45.36578566687447, 46.37433753694807, 45.40543903623308, 49.21965612683977, 53.11265536717006, 54.674044132232666, 46.45157718658447, 55.655619621276855, 53.18491663251604, 49.438034534454346, 39.68678671973092, 39.823593275887625, 39.10650096620832, 44.67825446810041, 51.03938238961356, 56.420129912240164, 52.8885030065264, 49.589223861694336, 56.17901699883597, 55.199008328574045, 52.06423125948225, 47.13081571034023, 46.964256967817036, 53.27014323643276, 56.307068824768066, 58.472558294023784, 48.54692806516375, 58.597354888916016, 57.65302521841866, 58.65530981336321, 58.21940762656075, 48.504040309361045, 44.24726813180106, 33.53866624832153, 6.832532797540937, 3.0869256939206804, 2.618566517318998, 2.903812651123319, 1.0319415692772185, 0.06779161268579108, 0.03974799106695822, 0.051543287600257566, 0.02687071616362248, 1.6975177632910865, 31.057214396340505, 48.297988006046836, 49.102512972695486, 45.688473905835835, 30.100221633911133, 6.423940939562661, 25.071744305746897, 37.18687002999442, 42.84600755146572, 52.22172955104283, 54.86250707081386, 23.138910055160522, 0.15533710324338504, 0.02146611349391086, 0.042420058577720604, 0.06547192537358829, 0.02035593011948679, 0.03724117736731257, 0.008790403355046042, 0.07760502038789646, 0.0596420339175633, 0.02250682675678815, 0.057899393141269684, 0.020174523782251135, 0.033786436675914695, 0.02834220416843891, 0.05562409558998687, 0.03737117789153542, 0.011537724640220404, 0.00930837748040046, 0.031862247070031505, 0.009535356773994863, 0.004690790615443672, 0.05631267631958638, 0.04557168749826295, 0.005176221353134939, 0.015619779438046473, 0.043334248808345625, 0.04442324323047485, 0.062025802076927254, 0.03766824391537479, 0.053072946412222724, 0.014250502555764146, 0.005955828403654907, 0.01610854856802949, 0.06950630460466657, 0.05930575874767133, 0.034951691648789814, 0.046575705587331734, 0.004924864840826818, 0.081001895612904, 0.04522010797102537, 0.04402155049943498, 0.0004273260081910329, 0.04407905634226544, 0.02353080904244312, 0.06258886400610209, 0.05563087076214807, 28.077335255486624, 78.59350613185337, 64.85704953329903, 64.6119031906128, 44.695638860974995, 36.28212077277047, 23.55626576287406, 25.879321268626622, 28.611365113939556, 29.457085950034006, 34.38366099766323, 1.4252203575202396, 0.028156918307234133, 0.050496111291327646, 0.12597516950752052, 0.4125560224056244, 2.1345778022493636, 3.028814435005188, 2.2016363867691586, 0.45292806891458376, 2.2485469324248175, 20.247092383248464, 49.57790872028896, 61.25068432944161, 61.674816267830984, 60.68405873434884, 59.73530306134905, 59.61741992405483, 59.60079288482666, 50.17612082617623, 44.646563734327046, 43.26058571679251, 45.15674563816616, 49.751544203077046, 53.39578403745379, 53.18899175098964, 56.18795238222395, 58.47824192047119, 51.63619443348476, 50.73235886437552, 55.79641791752407, 53.416121414729524, 47.461480481284006, 40.58356639317104, 42.35226855959211, 50.006268637520925, 53.857290336063926, 53.22592837469918, 54.691115856170654, 51.277854987553184, 49.626824038369314, 42.8059720311846, 42.39226586478097, 43.50292498724801, 49.099236897059846, 49.994314261845176, 53.83283615112305, 49.98116479601179, 52.28048004422869, 48.73260130201067, 44.774118764059885, 42.09936802727835, 53.8868271282741, 52.74787841524397, 59.37007795061384, 33.51771395547049, 38.38444069453648, 63.31684929983956, 49.59360122680664, 55.44851119177682, 47.8984283719744, 51.76155383246285, 47.95801264899117, 48.99842548370361, 48.90663283211844, 49.1882016318185, 47.14846760886056, 52.69779232570103, 54.971986361912315, 55.30346754619053, 47.373804637363975, 55.92223589760916, 54.918092659541536, 51.75109331948416, 41.87303393227713, 41.47332838603428, 41.1333703994751, 46.94696984972273, 52.545261996132986, 58.234717982155935, 52.32788412911551, 48.838394573756624, 56.29659788949149, 57.85600989205496, 53.985439436776296, 48.807627950395855, 48.108434200286865, 55.10298769814627, 57.79193707874843, 60.274636132376536, 53.81167541231428, 60.01355062212263, 59.133415358407156, 59.023668561662944, 57.98106009619576, 53.73845182146345, 49.240538937704905, 35.3836144719805, 8.202562962259565, 1.3853903519255775, 4.619741295065198, 6.533481461661203, 3.4724171800272803, 1.257535029734884, 0.22491542755493096, 0.0689608845859766, 0.09639250154473952, 1.5506900591509682, 33.38285289491926, 49.53197765350342, 57.333713803972515, 43.54425982066563, 21.57731979233878, 10.971673710005623, 35.85449736458914, 43.41695492608206, 50.1956661088126, 57.483867849622456, 62.456495557512554, 30.902860164642334, 0.22948681297046797, 0.010955308347807398, 0.04770676239526697, 0.037011625577828715, 0.024711283555786525, 0.025724024212520038, 0.07323935321931328, 0.018259139864572456, 0.033005768566259315, 0.048123128446085114, 0.10286081981446062, 0.012651917308435907, 0.04422707875658359, 0.023374501715547273, 0.03974554494821599, 0.009016345338230687, 0.049608472135982344, 0.03266745100596121, 0.023680994287133217, 0.04325648869520851, 0.03162474963547928, 0.02246768037522478, 0.02384824468754232, 0.04150924066613827, 0.1421585553990943, 0.13853988743254117, 0.11209712669785533, 0.1477201541087457, 0.1305930617132357, 0.09015714470297098, 0.12093099446168967, 0.093966942413577, 0.1371974873223475, 0.16696689490761074, 0.1336412988603115, 0.1955742027078356, 0.11953196381883961, 0.16074506805411407, 0.16783455120665686, 0.13048399399433816, 0.1177000142633915, 0.08924401977232524, 0.14146176778844424, 0.1792892265532698, 0.19764925778976508, 0.07514113081353051, 36.42438861301967, 88.91349179404122, 72.19029644557408, 73.93063953944615, 50.62575960159302, 41.442169189453125, 23.022360971995763, 30.085140568869456, 51.2158214705331, 33.90334245136806, 47.25041157858712, 2.0655965209007263, 0.15727493140314305, 0.21872432476707868, 0.2381527636732374, 0.3988253506166594, 1.918848829610007, 9.405783380780901, 11.802657416888646, 7.272771963051387, 4.983954574380602, 22.85943440028599, 52.99077354158674, 64.68950762067522, 64.12245123726981, 64.64083548954555, 62.6746620450701, 62.68370165143694, 63.92150238582066, 51.58491325378418, 47.184910910470144, 45.55456474849156, 47.09223236356463, 51.551620960235596, 55.571574211120605, 55.59023707253592, 58.286082540239605, 60.99610233306885, 52.50507361548287, 50.427034173692974, 55.2624488558088, 57.35367945262364, 49.121874128069194, 43.55162491117205, 44.64235312598092, 52.72057894298008, 56.70530482700893, 56.05782651901245, 56.459929193769185, 54.27974428449358, 52.25914560045515, 45.13327809742519, 45.0250494820731, 46.23900399889265, 51.59505762372698, 52.541186877659385, 55.767079148973735, 53.384979588644846, 54.839168071746826, 52.41849211284092, 47.108341761997764, 45.46586057118007, 56.43552712031773, 55.9198248726981, 60.21473571232387, 36.46581029891968, 40.881737913404194, 65.35824394226074, 52.24967867987496, 58.25873443058559, 50.76047127587454, 53.38531657627651, 50.94177062170846, 52.3165967805045, 51.046893392290386, 49.81190667833601, 49.470347132001606, 54.14168010439192, 58.60549817766462, 57.30462169647217, 46.80532387324742, 58.463511739458355, 58.415826252528596, 54.083589690072195, 44.251906054360525, 42.80821629932949, 43.50908803939819, 50.413606779915945, 54.372728552137104, 60.571595191955566, 53.460774012974326, 50.12901551382882, 57.937512261526926, 60.64837973458426, 57.30417701176235, 50.89706243787493, 50.692729813711985, 58.61070237840925, 59.971145766122, 63.09961387089321, 57.777047089168, 61.689317158290315, 59.89727251870291, 63.10685389382498, 59.524668421064106, 56.27540935788836, 51.909943035670686, 40.56459433691842, 10.814429896218435, 6.375552381787982, 10.276383110455104, 8.735554933547974, 4.055760358061109, 0.8758580503719193, 0.18482323602906295, 0.3356118069163391, 0.11640976635473115, 2.550012550183705, 44.86345522744315, 59.85028185163225, 53.72225904464722, 55.755253314971924, 45.14668812070574, 14.74333221571786, 38.59184789657593, 52.441612243652344, 57.88953842435564, 67.07515771048409, 69.06025109972272, 37.263206413814, 0.3349165256534304, 0.06645305308380298, 0.1311491211610181, 0.13437183680278914, 0.11754651607147285, 0.11221710525985275, 0.15169778067086423, 0.22224210814705916, 0.1412634862852948, 0.09898200152175766, 0.17868305050901004, 0.06014728466314929, 0.10967401029275996, 0.11275541423154728, 0.20828910757388386, 0.07286896130868367, 0.09860426786222629, 0.06610235904476472, 0.17465633872364247, 0.11164358710604054, 0.07252547331154346, 0.1364181898534298, 0.18272098526358604, 0.15920433215796947], [0.0509632249761905, 0.045768119993486574, 0.008141511835024824, 0.07893680821039847, 0.06189842748322657, 0.03968785250825541, 0.05719417134033782, 0.01738380763812789, 0.022237755391480665, 0.03582819943715419, 0.03675170934626034, 0.03843384176226599, 0.011323143877754254, 0.07752324334744896, 0.08266708840216909, 0.02154220610723964, 0.032941399341715236, 0.00857109235533114, 0.004967345373838076, 0.03944223979488015, 0.01398461267152535, 1.2450071019785744, 46.26160996300833, 66.36118166787284, 65.3421380179269, 52.39177976335798, 37.32439225060599, 29.873321260724747, 20.1951858656747, 19.59760778290885, 28.40524332863944, 59.53299931117466, 10.855055144854955, 0.04181595885061792, 0.047499286742614846, 0.08102374444050447, 0.11081366413938147, 0.16674866447491304, 2.775052760328565, 2.8158499768802097, 2.0578597017696927, 2.183984488248825, 24.326664652143204, 55.04152045931135, 58.21920265470232, 56.65715728487287, 55.41742842538016, 54.129173346928184, 52.262098584856304, 52.92146526064192, 43.77424866812569, 44.117548738207134, 46.042137214115684, 43.792609282902305, 44.301557881491526, 43.92241552897862, 44.72844130652291, 48.352576528276714, 54.027052198137554, 53.85794694083077, 55.02161387034825, 49.98148788724627, 52.98301935195923, 50.62765645980835, 45.90898888451712, 40.054231779915945, 38.18352658408028, 37.910108021327424, 42.17081635338919, 45.14221348081316, 46.17596994127546, 42.95245047977993, 42.61320120947701, 38.85773113795689, 41.66255562646048, 43.17454269954136, 47.82914093562535, 48.55174664088658, 48.364926951272146, 44.66684552601406, 46.540983131953645, 42.926731722695486, 40.70119939531599, 41.49182449068342, 54.42593090874808, 52.23357622964041, 57.32717554909842, 33.440790448869976, 40.91553047725132, 58.436379023960654, 49.72963653291975, 51.22231108801705, 47.17145919799805, 48.205952167510986, 46.039781774793354, 47.75012602124895, 43.685395104544504, 43.56651490075247, 40.99561888831002, 48.59779930114746, 51.911384786878315, 55.019133363451274, 48.36424602781023, 53.33968080793108, 52.8114891733442, 48.50336633409773, 40.68779979433332, 40.60033934456961, 37.920478207724436, 41.566020829336985, 49.419003418513704, 54.95990344456264, 55.68781757354736, 45.50932502746582, 52.643078735896516, 57.14777306147984, 53.77716370991298, 51.935779912131174, 42.58445303780692, 46.08953087670462, 54.39861754008702, 55.73721579142979, 54.40064293997628, 52.02120106560843, 57.96018075942993, 57.28646952765328, 59.10546275547573, 58.08829511914934, 49.80693524224417, 40.43482283183506, 19.87239166668483, 6.638122200965881, 4.520078071526118, 2.2613411716052463, 4.547492623329163, 0.9542638574327741, 0.09148618445864745, 0.06856826386813607, 0.11729414175663676, 0.03168861674410956, 6.833270609378815, 30.29958282198225, 25.27751346996852, 50.11372600282942, 72.3309349332537, 55.87303570338658, 9.572198816708156, 21.777080501828873, 36.91514335359846, 48.83892958504813, 50.94401836395264, 46.43522112710135, 2.2814255910260335, 0.3270765149167606, 0.017047071064423238, 0.07985791949821369, 0.020169974204951098, 0.028486701593335186, 0.050136270600238016, 0.05448746122419834, 0.04699703851448638, 0.03192989361871566, 0.05595115964700069, 0.025876633523564254, 0.002067447220075077, 0.05715521664491721, 0.0690874517230051, 0.02388784399123064, 0.036045825973685296, 0.01600668689102999, 0.02645338828941541, 0.05100580304861069, 0.034224400496376414, 0.022832847566210797, 0.01455135819768267, 0.012996484176255763, 0.07673786620476417, 0.048610761029911895, 0.011905904526689222, 0.058801987208426, 0.0505114970728755, 0.056782795914581845, 0.014771768424127783, 0.038160422683826516, 0.04321743221953511, 0.03849675213651998, 0.042050643757517846, 0.03904262338099735, 0.011980398341880312, 0.1035363624936768, 0.05818713948662792, 0.02154836381253387, 0.011770190737609352, 0.01418245312691267, 0.04191315220668912, 0.03235918576163905, 0.05900136115295546, 1.8307269981929233, 55.25250250952584, 75.46827588762555, 71.14416871752057, 58.57459259033203, 46.69180073056902, 36.64672401973179, 21.950410263878958, 19.068062986646378, 27.138802119663783, 48.957403319222585, 11.65164874281202, 0.07249862368085555, 0.021741208553846394, 0.2273745063160147, 0.31865801236459185, 1.9883227816649844, 3.6070215914930617, 1.6905112649713243, 0.5055191197565624, 3.0312806112425665, 25.535527876445226, 57.38165637425014, 61.25340107509068, 60.05455889020647, 56.57180561338152, 57.170194898332866, 55.298332827431814, 55.08137880052839, 46.511203152792795, 46.86887557165963, 47.90914249420166, 44.928281920296804, 45.82125745500837, 45.736941065107075, 46.464570317949565, 50.59586845125471, 56.09069149834769, 54.62196738379342, 55.58312211717878, 49.67646891730172, 55.01672581263951, 52.475529875074116, 49.74007967540196, 41.123764514923096, 41.16356379645211, 40.206998348236084, 45.021519797188894, 47.34613343647548, 48.14765330723354, 45.41850512368338, 43.80489717211042, 42.051675592150005, 43.09487812859671, 44.66478191103254, 50.023590496608186, 49.67712204796927, 51.91259029933384, 48.14189325060163, 49.835801533290315, 45.250452518463135, 43.22811678477696, 43.979661737169536, 56.886277607509065, 52.90363965715681, 58.66010407039097, 35.64573873792376, 42.628365652901785, 59.564377376011436, 52.268668106624055, 51.73104081835066, 50.43498291288103, 50.74650192260742, 49.74936246871948, 49.08995062964303, 47.216674600328716, 45.919119358062744, 42.65297964641026, 51.884338923863, 53.96351787022182, 56.17227029800415, 48.96647419248308, 55.446572644369944, 54.48226342882429, 52.213308334350586, 43.36595514842442, 42.64696250643049, 40.784803594861714, 42.738258361816406, 51.34589522225516, 56.343571186065674, 58.205726623535156, 46.857820987701416, 51.81432887486049, 58.6573942729405, 56.350672245025635, 52.512049606868196, 45.7042567389352, 47.41309322629656, 55.52447237287249, 56.96404879433768, 57.576588085719514, 56.08801991598946, 58.78055804116385, 58.93857397351946, 61.68297345297677, 58.98474475315639, 54.977399008614675, 46.25182689939226, 24.027205978121074, 4.609645128250122, 2.5183910812650407, 4.96148236308779, 10.330306342669896, 3.661467892783029, 0.9209936027015958, 0.14934790533568176, 0.027665097466004745, 0.07537050279123442, 7.471525618008204, 35.58674158368792, 26.759140389306204, 50.41481229237148, 66.71642221723283, 46.47654206412179, 14.692410605294363, 32.13842010498047, 42.54780823843819, 55.41760560444423, 56.938097272600444, 55.71257747922625, 3.7083078707967485, 0.2678587825170585, 0.050852993569735966, 0.01775520038791001, 0.02639876282773912, 0.038225165102630854, 0.051360252778977156, 0.029499102982559373, 0.047710657186274014, 0.023144062741526535, 0.030903042826269354, 0.009488933952525258, 0.020591687111716186, 0.05343742149748972, 0.07786409184336662, 0.06048496440052986, 0.049265506610806496, 0.05041026643344334, 0.051104051526635885, 0.06179130715983255, 0.03549765110281961, 0.038887995428272655, 0.012310840655118227, 0.008040237090816455, 0.2049302506659712, 0.12092557975224086, 0.10614781307854823, 0.21468302447881016, 0.11957602788295064, 0.1062208234465548, 0.10817288727100406, 0.1269143433975322, 0.11491228028067521, 0.16295232889907701, 0.12657200890992368, 0.15695162303745747, 0.13324599792914732, 0.24545732885599136, 0.15873766291354383, 0.14870476270360605, 0.09739496918129069, 0.1303630926247154, 0.13146884686180524, 0.1402330765766757, 0.19279363405491623, 3.3805335504668097, 67.54241711752755, 81.83486856733049, 80.34586266108921, 65.96273721967424, 50.835077558244976, 40.7412349155971, 30.734797137124197, 27.706028733934673, 39.07334416253226, 77.36339010511125, 15.5353730065482, 0.2616059737546103, 0.21463444137147494, 0.25871454605034416, 0.4420403502881527, 1.2791728058031626, 8.695015668869019, 9.956072892461505, 8.780917116573878, 5.0717958722795755, 28.07013692174639, 61.020247323172434, 63.82360921587263, 61.164540563310894, 59.292397090366904, 59.21247891017369, 57.946437222617014, 57.27303865977696, 49.04656260354178, 48.312523637499126, 51.62603269304548, 48.09884221213204, 48.72467688151768, 48.393018518175396, 49.298559870038716, 51.39056519099644, 59.41547053200858, 57.7170980317252, 55.15470661435808, 49.28194325310843, 56.28224638530186, 55.17605495452881, 50.962101050785606, 44.04716348648071, 43.209641524723594, 42.791498933519634, 47.381576197487966, 49.63093737193516, 50.38257612500872, 47.326452663966585, 46.79609319141933, 43.145440169743125, 46.7816617829459, 48.321552821568076, 53.09827954428536, 51.91585942677089, 55.26820196424212, 51.992605754307334, 51.00759438105992, 47.68846770695278, 45.54388189315796, 45.566467012677876, 59.85010119846889, 56.484300000326975, 60.73792116982596, 37.421538489205496, 46.72930710656302, 61.45255034310477, 54.75391714913504, 54.03722436087472, 52.8685964175633, 53.61004911150251, 51.79107672827584, 52.99471664428711, 49.85825463703701, 48.284980978284565, 44.90021814618792, 52.861224378858296, 55.55604498726981, 58.68412399291992, 49.43202086857387, 57.16202729088919, 57.89723702839443, 53.61248792920794, 45.56393786839077, 44.41767965044294, 42.25741522652762, 45.44883748463222, 54.25228500366211, 60.03489548819405, 62.41235365186419, 48.45939118521554, 53.479624475751606, 60.984867095947266, 58.58218002319336, 55.77206795556204, 46.29484667096819, 50.10183416094099, 60.05655302320208, 59.62437507084438, 58.954457555498394, 58.700514793395996, 59.49779278891427, 61.49113368988037, 64.92975548335484, 61.99396092551095, 56.10822180339268, 47.86146395547049, 26.649277210235596, 11.457344974790301, 10.823347040585109, 8.878277012280055, 15.047103984015328, 2.8974092347281317, 0.5485879629850388, 0.287682617349284, 0.3220754404153143, 0.16158362877156052, 10.441034572465078, 44.862392153058735, 33.78391333988735, 56.51461499077933, 77.37440299987793, 70.0578942980085, 20.269719191959926, 36.02031264986311, 49.4751170703343, 64.68401159558977, 63.420613697596956, 64.129225730896, 5.170913227966853, 0.41443309453981264, 0.09751325819109168, 0.20131380829427922, 0.11618438416293689, 0.0802752049639821, 0.13447112004671777, 0.12421704456210136, 0.12487485712128026, 0.07317480418298926, 0.13171875130917343, 0.13858943405960286, 0.1351178182022912, 0.17481116684419767, 0.1402897478214332, 0.1333142314106226, 0.15415656087653978, 0.21967008044677122, 0.11098570669335978, 0.09614416451326438, 0.19021045123892172, 0.16373239989791596, 0.15168777906468936, 0.07434485639844622], [0.010315631333339428, 0.019915258944300667, 0.034765773053680143, 0.025420990473191653, 0.041651906046484194, 0.0588183534730758, 0.08508013534758772, 0.006766302860341966, 0.059990977336253436, 0.03211680966030274, 0.09180962853133678, 0.037090963284884176, 0.032620224968663285, 0.0692383579111525, 0.0257260496395507, 0.0712763514103634, 0.0132291317817622, 0.03672191487359149, 0.0046439437095874125, 0.04703184396826795, 0.1533729207835027, 9.907612681388855, 72.08003548213414, 59.477844510759624, 59.372808592660085, 42.6119053704398, 44.34858676365444, 29.54938234601702, 32.630950110299246, 36.49788318361555, 41.97299419130598, 32.94845846721104, 0.6415114881736892, 0.03778057538771203, 0.024568183913028667, 0.05815910241965737, 0.30076553246804644, 1.6675978430679865, 2.7858133486339023, 0.9130267330578395, 1.7644111109631402, 24.171301194599696, 54.040816579546245, 60.1134865624564, 54.09732280458723, 53.60695021493094, 48.636862073625835, 47.08353321892874, 44.92202506746565, 43.383898871285574, 42.08429043633597, 47.57864448002407, 48.213883536202566, 52.54975748062134, 49.479237352098735, 46.64655058724539, 42.76053081239973, 44.535917145865305, 50.949246883392334, 53.58606045586722, 54.50458451679775, 49.65029157911028, 51.43597861698696, 51.892405782427105, 47.19207450321743, 43.574713775089805, 42.57861655099051, 44.11376544407436, 43.81296055657523, 40.5197298186166, 39.501030104500906, 40.495793274470735, 40.12782709939139, 38.53549105780465, 39.44455862045288, 44.85953296933855, 47.67787170410156, 49.30324642998831, 46.84512662887573, 45.22878108705793, 44.515096868787495, 40.39423145566668, 38.82717990875244, 45.90233598436628, 53.85117244720459, 50.439975193568635, 52.39171722957066, 37.26669440950666, 42.42978613717215, 56.641638483319966, 45.770949023110525, 48.14285905020577, 45.397431237357004, 46.60040760040283, 44.021302291325156, 47.70221471786499, 43.57036420277187, 44.403095381600515, 38.94294384547642, 45.40536608014788, 50.68263408115932, 54.828148228781565, 47.15062502452305, 50.94991738455636, 53.82175724846976, 49.92476279394967, 40.9555903162275, 39.38291072845459, 38.34482206617083, 42.81878450938633, 48.276653562273296, 53.49225977488926, 52.80175474711827, 50.128928661346436, 46.56096962520054, 52.301675524030415, 55.82227911267962, 53.085282938820974, 47.83557496752058, 41.652209758758545, 47.30555248260498, 54.71602167401995, 55.83132219314575, 55.89687844685146, 53.20640046255929, 56.64694690704346, 56.09834146499634, 57.62873431614467, 60.822425161089214, 55.68083463396345, 38.146913051605225, 11.354054791586739, 3.3685722265924727, 5.7203263981001715, 4.0289641959326605, 3.526894531079701, 0.38394901316080776, 0.06369762415332453, 0.07788362008120332, 0.09790137343640838, 0.3670735758330141, 19.744970389774867, 53.60039111546108, 69.47090353284563, 65.3448964527675, 85.98023332868303, 39.27584246226719, 23.024933542524064, 33.777451515197754, 45.820204802921836, 44.55822433744158, 51.580674852643696, 14.778325080871582, 0.20204174066228525, 0.009458026682425822, 0.039521845523267984, 0.050013825563447814, 0.09823075469051089, 0.03509054705500603, 0.034315358115626235, 0.03193791050996099, 0.033044852183333466, 0.026003007278112427, 0.02701494047817375, 0.08991792039679629, 0.03871248895302415, 0.05897618750376361, 0.05276525792266641, 0.04436469244371567, 0.02153681345017893, 0.05420809478632041, 0.06654318289033004, 0.03185269329696894, 0.16512749503765786, 0.022848701536921517, 0.022127164361466254, 0.0036408475799752133, 0.09763496701738664, 0.10053700700934444, 0.0358112767737891, 0.028170773992314935, 0.06198796017893723, 0.06741331584219422, 0.03620288308177676, 0.021368786127173474, 0.02789144148118794, 0.07314640070710864, 0.04401798479791198, 0.03151871496811509, 0.04535169287451676, 0.006494194626741643, 0.034641431511512825, 0.026192666297512393, 0.06699258341853108, 0.0345126727063741, 0.05220164977280157, 0.11989065100039754, 12.744370222091675, 81.32823371887207, 66.55898993355888, 66.58146040780204, 49.384748799460276, 51.40491669518607, 36.14449085508074, 26.896893637520925, 30.163273062024796, 37.613718714032856, 33.44366352898734, 1.0023196616343089, 0.02619612343343241, 0.028505809139460325, 0.15612353890069894, 1.0305541008710861, 4.052843851702554, 3.351742821080344, 1.6577319438968385, 2.234356322458812, 25.70159329686846, 57.60091372898647, 60.14823450360979, 55.767020089285715, 55.23128618512835, 52.349986348833355, 50.29550130026681, 48.27846704210554, 45.07667807170323, 43.86951889310564, 48.15450075694493, 50.054384912763325, 52.69289384569441, 52.74036741256714, 48.77178219386509, 45.97304432732718, 46.49583721160889, 53.81835610525948, 55.50600058691842, 55.457762718200684, 50.79815135683332, 52.567256518772666, 54.54865346636091, 51.32804877417428, 44.9217506136213, 44.83746549061367, 45.02355561937605, 45.438109466007774, 42.2857916695731, 41.30434819630214, 42.962806769779746, 41.87493426459176, 40.248941149030415, 42.49158688953945, 47.35175800323486, 49.35218606676374, 51.29925891331264, 50.15040554319109, 47.897500787462505, 45.98092358452933, 41.81870249339512, 41.47968946184431, 48.93008647646223, 55.22896201269967, 52.12882171358381, 53.776093687329976, 39.10616397857666, 44.79942062922886, 57.405898639133994, 47.98462077549526, 50.47975015640259, 46.76534741265433, 49.177202633449006, 46.69528872626168, 48.9825245312282, 47.041517462049214, 45.75821297509329, 41.02167115892683, 47.884903703417095, 52.978840010506765, 55.3157172203064, 47.76442193984985, 50.657426016671316, 57.0085381099156, 52.143051624298096, 43.66950804846627, 41.48003339767456, 40.62256663186209, 44.07853807721819, 51.09380415507725, 55.434559209006174, 54.094831875392366, 52.14910697937012, 46.46203769956316, 53.97136238643101, 57.71219955171858, 54.13438449587141, 50.666344029562815, 44.172911984579905, 48.22696352005005, 57.49107313156128, 57.88789170128958, 58.3842327935355, 55.01624986103603, 58.624862807137625, 58.53477941240583, 59.35677215031215, 61.26594952174595, 59.02504430498396, 42.54199954441616, 14.79224579674857, 1.973043475832258, 1.017408651965005, 4.6440751893179755, 7.040920564106532, 3.390393478529794, 1.0384463859455926, 0.22991914834295, 0.027480988863057325, 0.16258250017251286, 18.444510800497874, 46.85054969787598, 65.9330197743007, 63.932612555367605, 81.95267527444022, 38.171926566532676, 31.67629541669573, 40.73582921709333, 51.83594472067696, 50.95037596566336, 61.23776762826102, 19.306099585124425, 0.1670786767665829, 0.04213729267939925, 0.04364680578666074, 0.02505437291360327, 0.024481920059770346, 0.026000316886763488, 0.051399441568979194, 0.05635442318660872, 0.018772281972425323, 0.031090406700968742, 0.02350426814518869, 0.038465166331401894, 0.0904738644936255, 0.005957167662147964, 0.05741738222007241, 0.03523603514102953, 0.04724451380648783, 0.05581905905689512, 0.07235623989254236, 0.006918792155504758, 0.021490698513974036, 0.025191531982272863, 0.03881391976028681, 0.1520916431077889, 0.20202092320791312, 0.1784021777233907, 0.13984267466834613, 0.19046596038554395, 0.17757015808352403, 0.22318406403064728, 0.11812185948448521, 0.08272505564881222, 0.12337046356073447, 0.18658601572471006, 0.11434062809816428, 0.11948142653065068, 0.14422432812196867, 0.09983686065035206, 0.2414897988949503, 0.09972485487482377, 0.14360342786780425, 0.18772431250129426, 0.1358770988881588, 0.2788218456719603, 16.53015180996486, 92.00733007703508, 72.85478046962193, 76.4200748716082, 57.0745529447283, 57.93505607332502, 37.340974126543315, 43.73524495533535, 47.669162137167795, 55.25458696910313, 46.36657987322126, 1.4076583513191767, 0.09866213332861662, 0.19730207856212342, 0.38274181793843, 0.7469426393508911, 5.4772506185940335, 8.511860285486494, 7.626016208103724, 4.037835308483668, 28.338457243783132, 60.12385327475411, 63.348282950265066, 58.10240691048758, 57.82792179925101, 53.88777208328247, 51.47825493131365, 50.01107331684658, 48.3067809513637, 45.75665657860892, 51.811525276729036, 54.10608448301043, 57.15127842766898, 54.30115168435233, 51.007490158081055, 46.996576513562886, 48.22808912822178, 55.02031455721174, 59.10088389260428, 56.87188788822719, 51.528493881225586, 53.754165172576904, 57.32033504758562, 51.945298944200786, 47.403820855276926, 46.28022418703352, 48.29646635055542, 47.755048819950645, 45.06942762647356, 42.58746855599539, 44.80683435712542, 44.09640189579555, 41.79874379294259, 45.26829201834542, 49.59961141858782, 51.037186758858816, 54.71072367259434, 51.95678779057094, 50.2799824987139, 46.963148730141775, 44.87990508760725, 43.22733163833618, 51.72206374577114, 57.496145316532676, 54.91153008597237, 55.034964833940776, 41.22750806808472, 47.58226449148995, 61.98192664555141, 50.30375228609358, 53.58642871039254, 49.180339745112825, 51.13122367858887, 49.28800555637905, 51.65990168707711, 49.13688918522426, 49.26741109575544, 44.18866702488491, 50.74967377526419, 55.01116030556815, 58.97202260153634, 47.507501874651226, 52.3577162197658, 58.42224638802664, 54.65237270082746, 45.34840474809919, 44.873623916081016, 43.17072466441563, 47.13446698869978, 52.96783406393868, 58.668004172188894, 56.50425522668021, 53.54381193433489, 46.04365539550781, 55.20875317709786, 59.591225215366904, 57.559036936078755, 53.78072813579014, 46.028247765132356, 51.361438342503135, 60.07818971361433, 59.7110538482666, 61.52356093270438, 58.35311181204659, 60.28867149353027, 60.353046553475515, 62.814466748918804, 66.0145012991769, 60.9226598739624, 45.2583908353533, 16.341869524547032, 7.355589713369097, 14.233815601893834, 11.058198758534022, 10.009704300335475, 2.530926500047956, 0.43614692081298145, 0.1971558949777058, 0.10294052732310124, 0.4934511301772935, 28.525660821369716, 68.45784228188651, 70.22146878923688, 68.6532951082502, 89.1537674495152, 51.55251727785383, 34.14506680624825, 47.50418063572475, 60.20045716421944, 58.69588729313442, 69.69486481802804, 23.763650383268082, 0.3078472396092755, 0.10775369512183325, 0.0986279012369258, 0.15240811184048653, 0.1814840566366911, 0.1368883331971509, 0.1994915617895978, 0.09305562917143106, 0.08853206690400839, 0.10007660742849112, 0.14209784008562565, 0.14291824320597307, 0.12688437929110868, 0.1282563228160143, 0.16263516806066036, 0.12719725178820745, 0.1171667535922357, 0.16150938346982002, 0.13759225899619715, 0.24153919624430792, 0.19304725687418664, 0.11018389543252331, 0.13113218492695264], [0.01161997580701219, 0.04599999915808439, 0.040688728980187855, 0.01318438578995743, 0.0347407961796437, 0.0784402834251523, 0.05249022053820746, 0.022987636671002423, 0.04943493680496301, 0.03370975882613233, 0.0387907783234758, 0.05815432553312608, 0.043335161437945705, 0.08186660706996918, 0.015465845287378346, 0.026347974481593286, 0.015870437059285383, 0.037266707247389216, 0.0635364381596446, 0.04032678483054042, 0.21271757994379314, 31.049957002912247, 73.25453117915562, 56.45964779172625, 63.5266501562936, 47.80787597383772, 30.903680052076066, 21.4149386542184, 47.10656302315848, 37.97928428649902, 47.24347032819475, 11.754887683050972, 0.09791052008845977, 0.08703554434967892, 0.03102278390101024, 0.34719716810754364, 0.6365142134683472, 4.742843398026057, 1.821477425949914, 0.9223047494888306, 16.11223677226475, 54.127040249960764, 58.94052641732352, 57.10038982118879, 55.962608405521934, 54.49902595792498, 54.15380818503243, 52.92081560407366, 49.147669315338135, 50.22031831741333, 45.81568847383772, 46.81481163842337, 52.17873757226126, 54.98557703835623, 53.70623649869646, 53.17453949792044, 47.30701507840838, 43.52766057423183, 49.99063866479056, 51.79066678455898, 53.7507119178772, 50.39925874982561, 50.302206311907085, 52.99429627827236, 49.60058069229126, 47.99477556773594, 48.69195434025356, 48.68775762830462, 49.1858183997018, 46.496393067496165, 43.72355808530535, 36.56512090138027, 39.96962703977312, 37.7680208342416, 42.06432131358555, 43.31371511731829, 51.531029973711284, 47.36355951854161, 46.55103717531477, 46.49441283089774, 41.770221437726704, 37.56046772003174, 41.841780935014995, 48.531791414533345, 53.625658239637104, 47.47358076913016, 51.26468815122332, 37.79659877504621, 41.39116593769619, 55.16242606299264, 46.16662808826992, 47.20536988122122, 42.48707750865391, 46.931350299290244, 44.446837765829905, 48.18612895693098, 41.798674310956685, 42.54762411117554, 37.85018328257969, 43.65881477083479, 47.85555451256888, 53.61858149937221, 49.38498503821236, 51.05927855627877, 53.757149423871724, 48.26415375300816, 40.381314754486084, 38.41997725622994, 37.51098264966692, 44.257839815957205, 48.13255834579468, 51.00472477504185, 50.99571990966797, 51.10428203855242, 47.1956285067967, 49.171105589185444, 54.4161547933306, 54.35702562332153, 52.64504507609776, 46.46258313315255, 42.49448776245117, 47.6213515826634, 50.343478611537385, 54.51351295198713, 54.33369009835379, 55.20485176358904, 54.47161184038435, 56.52702794756208, 56.00735827854702, 56.129740374428884, 53.93706955228533, 37.37950883592878, 9.989528468676976, 2.8774572653429846, 8.530871425356183, 6.65716243641717, 3.261368904794965, 0.7502781003713608, 0.1532683042543275, 0.21408652434391634, 0.07190404380006449, 2.528223433664867, 26.852692672184535, 54.529681410108296, 77.63450881413051, 68.799638066973, 39.09457785742623, 14.81909189905439, 33.89251020976475, 48.462493555886404, 50.99329151426043, 49.37095315115792, 26.251593589782715, 0.1551393238561494, 0.06262303502964121, 0.08954400010406971, 0.011745503089124603, 0.03475432277524045, 0.034327028917946985, 0.04407271882519126, 0.030208141542971134, 0.04899896448478103, 0.01882333494722843, 0.05819208600691386, 0.06775562318840198, 0.009212959341571798, 0.014999393174158675, 0.030820570287427733, 0.05435702643756356, 0.01643348202508475, 0.0779147580532091, 0.03505762114322611, 0.048740289972296784, 0.018272827612236142, 0.08417374148432698, 0.02072786908995892, 0.020693206128531268, 0.054478877756212435, 0.04227265023759433, 0.04145361775798457, 0.004955877283854144, 0.03869896235742739, 0.0626624036314232, 0.013866321965386825, 0.05688395870051213, 0.053803385967122655, 0.04252200846427253, 0.07562004761504275, 0.045232884785426516, 0.05415804943602, 0.0010895811428781599, 0.028462257369288375, 0.026219124074227045, 0.03197280756597008, 0.043814264836588075, 0.025619426343057836, 0.3163623926895005, 38.540069920676096, 81.95881748199463, 63.11048085348946, 70.33312634059361, 53.09861305781773, 38.01085690089634, 25.740729025432042, 38.82775313513619, 35.71200370788574, 47.32434041159493, 13.599553636142186, 0.07764459255018405, 0.046202853987259526, 0.31365758925676346, 0.5121681658285004, 3.1889725838388716, 4.747432683195386, 2.1105387721742903, 1.3077914587088992, 19.169515371322632, 54.33685152871268, 60.73936639513288, 59.56503050667899, 58.90884263174874, 57.19259589059012, 55.73865406853812, 56.10273620060512, 50.49501187460763, 51.360059125082834, 49.31553084509713, 48.45667791366577, 54.663083348955425, 55.24840654645647, 56.03435550417219, 55.1759854725429, 49.39563315255301, 45.523554938180105, 52.05641801016671, 53.191322871616904, 54.94227933883667, 50.515189443315776, 51.1098301751273, 54.94988414219448, 51.538137980869834, 49.85815388815743, 51.21176719665527, 50.66561099461147, 51.91524451119559, 48.3720314843314, 45.40952805110386, 38.813762937273296, 41.729557105473106, 40.09874194008963, 43.75728464126587, 46.40283557346889, 52.80766766411917, 49.53211661747524, 50.18481649671282, 49.850979873112266, 44.61464371000017, 38.45622253417969, 44.289054598127095, 50.78897278649466, 56.33343723842076, 50.7548953465053, 53.796458857400076, 38.61150435038975, 42.73659426825387, 57.68103340693882, 48.77340112413679, 48.335470063345774, 43.920671531132285, 49.480290004185264, 48.04153347015381, 49.4803386415754, 44.54493938173567, 43.31379154750279, 39.862225260053364, 46.29275526319231, 51.54187611171177, 54.82837751933506, 49.01384701047625, 51.16657611301967, 55.66640669958932, 49.69906793321882, 42.27029371261597, 39.554030963352744, 40.31787770135062, 46.45117766516549, 48.878853934151785, 53.00232144764492, 53.83869695663452, 51.13775151116507, 48.0001916885376, 49.666835239955354, 57.860015528542654, 56.885249274117605, 54.66141925539289, 48.8157434463501, 44.54103796822684, 49.140467507498606, 52.93777963093349, 58.06931611469814, 55.99405942644392, 57.15918547766549, 56.825067452022004, 57.7276280266898, 57.41357292447771, 58.94732870374407, 58.02073778424944, 42.147307123456685, 12.960896934781756, 1.8937365199838365, 1.4791531435080936, 8.21117525441306, 5.478039673396519, 3.866114054407392, 0.826042289180415, 0.19944656134716102, 0.017869474166738133, 2.4362116966928755, 32.347015448978965, 58.14098678316389, 85.76093428475517, 70.79445198604039, 45.63242278780256, 22.056688172476633, 38.53689806801932, 54.790947573525564, 55.62985570090157, 56.45590966088431, 33.75954253332955, 0.23584699311426707, 0.2032649628818035, 0.017558582991893803, 0.046286530925759246, 0.01832335302606225, 0.018533330776595643, 0.06181942565100534, 0.040692114869930913, 0.008433943464686828, 0.029103330469557216, 0.011010527527625007, 0.027031294868460724, 0.038713360870523114, 0.03098303871229291, 0.021094101580924222, 0.027270927991984144, 0.022092423368511454, 0.03635645591254745, 0.045705993327179124, 0.009181803558021784, 0.006586502106594188, 0.023511319820369993, 0.02537302822539849, 0.13010134095592157, 0.16825981624424458, 0.1383811780916793, 0.21926306800118514, 0.12418017296918801, 0.1588461742337261, 0.2147004356873887, 0.08109956394348826, 0.12974475723292145, 0.1575156349156584, 0.08525759939636503, 0.21382470482162066, 0.2457851426942008, 0.11847019222165857, 0.11029436771890946, 0.10007689919854913, 0.11871540120669774, 0.12097105516919068, 0.1620327103883028, 0.20348507964185306, 0.6120792989219938, 45.40470947538103, 89.69403157915387, 70.39536135537284, 78.51592254638672, 59.93078368050711, 42.76619706835066, 29.268150533948624, 60.240986006600515, 47.810686520167756, 61.17123862675258, 17.60471851485116, 0.3486974633165768, 0.22082719978477272, 0.2860838531383446, 0.4973174769963537, 4.402994845594678, 14.071537818227496, 9.714609095028468, 3.6407883167266846, 19.139271599905832, 60.122324671064106, 61.78785651070731, 61.38567393166678, 60.58342102595738, 59.448140961783274, 56.85141849517822, 57.98170975276402, 54.17309985842024, 54.24460029602051, 52.58977563040597, 50.27680022375924, 58.52915137154715, 58.662661007472444, 58.09064361027309, 59.23217010498047, 52.23314544132778, 48.75589861188616, 53.297828333718435, 55.63504253114973, 58.34947790418352, 50.88356556211199, 52.153307165418354, 58.68802888052804, 54.25666584287371, 52.844645977020264, 53.223260266440256, 52.541186877659385, 54.9257356779916, 52.00908688136509, 47.86661604472569, 40.83774539402553, 44.73709181376866, 42.33848680768694, 45.33307007380894, 48.44433443886893, 56.251045499529155, 53.261666434151785, 52.790429183415, 52.50413908277239, 45.57845960344587, 42.14167560849871, 46.0555750301906, 53.59753540584019, 56.823198386601035, 54.358828680855886, 55.04809692927769, 40.590577125549316, 47.90783970696585, 58.94194384983608, 52.710778508867534, 52.43556036267962, 47.59700856889997, 53.3397398676191, 50.27845389502389, 52.740645340510774, 46.19010257720947, 46.966004439762656, 41.51699781417847, 47.836144719805034, 52.72681842531477, 57.10644170216152, 50.64730249132429, 51.02948815482003, 59.24348872048514, 52.62362725394112, 44.93103340693882, 42.28505516052246, 42.346817697797505, 48.338294506073, 51.98184299468994, 55.196837016514365, 55.19589900970459, 52.437634399959016, 48.47271088191441, 51.28831550053188, 59.269426345825195, 59.241334778921946, 58.06356995446341, 52.00049890790667, 46.76866865158081, 51.6381642477853, 54.50713797977993, 61.59154210771833, 57.9748067174639, 59.4518860408238, 59.53439589909145, 61.77221611567906, 60.3409914289202, 62.377098492213655, 60.01275157928467, 44.02650996616909, 13.314823406083242, 5.974926633494241, 15.140043088368007, 18.813503571919032, 8.18387404509953, 2.7596355761800493, 0.35927845697317806, 0.42058040467756136, 0.14647147325532778, 4.115799742085593, 38.194907733372276, 60.581815992082866, 79.47731004442487, 72.79089873177665, 49.16406011581421, 23.467231546129497, 45.748902388981406, 61.38502080099923, 64.85871710096086, 64.44279098510742, 40.14937693732125, 0.5505779704877308, 0.18391991592943668, 0.14170709890978678, 0.0937113654134529, 0.11503779568842479, 0.11738697891788823, 0.13521674860801014, 0.09855915885418653, 0.12259712362928049, 0.06953248248568603, 0.10680289114160196, 0.1570953774665083, 0.08006918137626988, 0.11098012913550649, 0.09121669749064104, 0.07642034574278764, 0.0942768972100956, 0.14950600399502686, 0.10376304747270686, 0.2322533359485013, 0.09480835297810179, 0.13768597825297288, 0.08106234629771539], [0.06260774085032088, 0.04617830798295992, 0.01644742931239307, 0.013907104464513915, 0.0034545367068078902, 0.02458563244103321, 0.019288945677024976, 0.059784750188035626, 0.014264190303427833, 0.041067843458482196, 0.05167096074936645, 0.07270882025893245, 0.029095038771629333, 0.018004560310925757, 0.053672286216169596, 0.042590336940650425, 0.09394106308796576, 0.03138699435761996, 0.04148167857368078, 0.12537785513060434, 3.0842606254986356, 54.57628992625645, 63.72773797171456, 55.29582800183977, 41.264132022857666, 33.21140609468733, 20.213579484394618, 26.275335584368023, 52.46894645690918, 50.51084334509713, 26.67392941883632, 1.2942105531692505, 0.03905828736190285, 0.025869978791368858, 0.03478954892073359, 0.21662976858871325, 3.034029709441321, 1.3305210790463855, 1.1394541944776262, 10.708494186401367, 49.04512432643345, 62.178789956229075, 63.195651871817454, 60.05222429547991, 58.61931814466204, 57.451871395111084, 56.07370662689209, 56.87966292245047, 55.695922647203716, 52.7799790927342, 51.0831629889352, 49.17512859616961, 53.60835722514561, 53.22503900527954, 54.626382963997976, 52.097249099186485, 50.29780462809971, 46.291601862226216, 47.72258683613369, 51.31176567077637, 52.582907336098806, 50.64914723805019, 50.38627256665911, 50.72690800258091, 51.81845957892281, 50.79283251081194, 51.27009384972708, 49.94397456305367, 51.360281467437744, 51.38656997680664, 48.90947117124285, 41.48187814440046, 39.168329511369976, 38.57612759726388, 43.27532632010323, 45.49973998750959, 49.22297041756766, 44.694874559129985, 46.77553694588797, 42.51385586602347, 39.089609895433696, 37.73452704293387, 44.2407819884164, 49.67439488002232, 52.55326632090977, 46.78909635543823, 53.89930261884417, 36.5757030078343, 40.199341433388845, 55.50265850339617, 45.65319095339094, 41.85371446609497, 41.54769148145403, 45.958077907562256, 43.43004880632673, 46.60531302860805, 42.75839424133301, 39.48388195037842, 36.99230309895107, 39.2929801940918, 48.36568430491856, 53.6587872505188, 50.342749050685335, 48.59717743737357, 53.824105739593506, 50.05606985092163, 40.7856582232884, 36.91238144465855, 40.74196100234985, 44.49615607942854, 51.14723232814244, 52.598582472120015, 51.72568723133632, 47.3339775630406, 46.57859025682722, 47.00749908174787, 52.12633425848824, 53.67532743726458, 52.90110009057181, 49.96325928824288, 41.99208436693464, 41.3637170791626, 47.11579717908587, 48.90157454354422, 50.983609199523926, 52.036212648664204, 52.05660908562796, 51.12172201701573, 55.72404200690133, 55.71759407860892, 58.72232518877302, 52.06515884399414, 31.129093510763987, 6.693873677934919, 2.4799827422414507, 6.477121148790632, 7.161136993340083, 4.472193692411695, 0.6899702336106981, 0.15154726803302765, 0.062171721032687595, 0.04357653330745442, 6.500381112098694, 36.453769070761545, 27.05498252596174, 33.39201756886074, 15.653342996324811, 23.264802728380474, 35.17014149257115, 35.182412011282786, 47.44414472579956, 47.180127075740266, 43.84686081750052, 2.826563447713852, 0.283955560198852, 0.061883492927466116, 0.04078281464587365, 0.019957511319911907, 0.0033240646007470787, 0.03943203462819968, 0.04154919620071139, 0.06958387472799846, 0.050031073923621855, 0.029840158431657722, 0.027036339776324372, 0.023608402914500663, 0.011336219247563608, 0.04619112890213728, 0.038155221712908576, 0.07880809011736087, 0.06932733420814786, 0.04093678781230535, 0.034967562582876, 0.017653710208833218, 0.044059687560158114, 0.02072701752851052, 0.06856481691024133, 0.012444150733894535, 0.05043326537790043, 0.04272235271387866, 0.0059876885913711575, 0.07431603901620422, 0.023404230031051805, 0.043094471496130736, 0.06094279233366251, 0.04661566451457994, 0.03919669154233166, 0.03286143738244261, 0.08071416283824615, 0.028906965827835456, 0.05909263089831386, 0.03082287052114095, 0.02210718489784215, 0.028368061441662054, 0.03542953636497259, 0.25409722381404465, 4.243803799152374, 62.45120103018624, 71.68791389465332, 63.35933058602469, 48.51557779312134, 43.112074920109336, 32.085113525390625, 30.20768247331892, 49.39986113139561, 56.40623351505825, 31.56053842817034, 1.8426915790353502, 0.028772106992879083, 0.06318658550402947, 0.2607877419463226, 1.288196127329554, 4.392562559672764, 1.9876633541924613, 1.3443978258541651, 13.861851607050214, 48.99640703201294, 63.70612212589809, 63.39354351588658, 62.203435216631206, 61.705680165972026, 59.93484837668282, 58.083681515284944, 59.8785332271031, 58.71464742933001, 54.93969808306013, 53.030069078717915, 51.63194213594709, 55.6634259223938, 55.75732735225132, 56.75676318577358, 54.61057581220354, 52.50741515840803, 48.57238973890032, 49.29568331582205, 53.60772841317313, 54.15774433953421, 51.44025523321969, 49.86336503710066, 52.01323843002319, 53.61009774889265, 52.92691264833723, 53.057535307747976, 53.170502594539094, 51.76430531910488, 53.09887361526489, 50.99443449292864, 43.72524997166225, 40.24748202732631, 39.89436762673514, 45.490721225738525, 47.60872670582363, 50.34128645488194, 48.04951695033482, 49.0554632459368, 44.94010428019932, 40.040964194706504, 39.36000599179949, 46.41513735907418, 52.23785284587315, 54.60923828397478, 48.326458249773296, 54.91274949482509, 38.75113534927368, 41.42202983583723, 57.198508807591026, 48.09408617019653, 44.80793217250279, 42.20399400166103, 48.30628762926374, 44.981286253247944, 48.886253765651155, 44.627998147692, 43.05076054164341, 39.19976316179548, 41.692214012145996, 50.6831065586635, 54.94337020601545, 51.63267864499773, 48.65759202412197, 55.634660380227224, 52.50556346348354, 42.743427821568076, 38.49088362285069, 42.273361342293875, 46.26035928726196, 52.323003019605366, 55.25142553874424, 52.2733998298645, 47.20432070323399, 47.16766895566668, 48.24197162900652, 52.97239555631365, 55.67916011810303, 53.94099528448922, 51.877588748931885, 43.60850633893694, 43.94529594693865, 48.71103409358433, 50.51557159423828, 51.9424467086792, 53.42249638693673, 52.021267073495046, 54.63324431010655, 56.91917732783726, 55.24545703615461, 59.72523512159075, 55.04050949641636, 33.34457526888166, 10.360909683363777, 1.9367743134498596, 3.9106472304889133, 3.367181718349457, 4.708271333149501, 1.8421745896339417, 0.3420439660549164, 0.0931740403175354, 0.03438980019252215, 7.286102516310556, 43.524756227220806, 34.03536517279488, 41.099091461726594, 24.06106628690447, 22.611946514674596, 42.76384857722691, 39.772211347307476, 54.512915406908306, 52.86317682266235, 56.574432032448904, 4.49927863904408, 0.14760858938097954, 0.048758471318121464, 0.09850206691771746, 0.03813461121171713, 0.05608125855880124, 0.03151983794357095, 0.05392538656347564, 0.028497595473059585, 0.12329372125012533, 0.010061046690680087, 0.0414841755825494, 0.06425288292978491, 0.02664890306602631, 0.04620203635256205, 0.021925644549940313, 0.0917139347376568, 0.034440025354602506, 0.058448891155421734, 0.15030503326228686, 0.01621046961684312, 0.03419782906504614, 0.04758935548099024, 0.13905617115753038, 0.11875137713338647, 0.0954886521877987, 0.1182909504111324, 0.09219234263790504, 0.1200142257979938, 0.13807114187095845, 0.1675507878618581, 0.1222542327429567, 0.14325616721596035, 0.09725859721324273, 0.11936081014573574, 0.14379961948309625, 0.11369339389992611, 0.16203181472207817, 0.1948165912181139, 0.16321758180856705, 0.17859420313366822, 0.15319642025445188, 0.3165939359792641, 5.633228557450431, 75.19938060215541, 79.48816313062395, 73.07556642804826, 55.41658769335066, 47.93458332334246, 27.606466259275162, 36.07302515847342, 63.78121130807059, 63.90575081961495, 39.81082248687744, 2.6719823139054433, 0.11991211984838758, 0.19931188571665967, 0.35074935321296963, 1.7815927032913481, 8.650872894695826, 9.784216148512703, 3.866377217429025, 14.804785558155604, 54.42075102669852, 63.97411414555141, 66.5594207218715, 62.5639841897147, 63.5434786932809, 61.536602701459614, 62.021510532924104, 61.64938586098807, 60.906428882053916, 57.62530190604073, 55.90016841888428, 54.281693254198345, 58.22963537488665, 56.149935313633506, 59.07824666159493, 57.37909596306937, 54.57420546667916, 51.36564547674996, 50.965950352805, 55.99679354258946, 54.7906870160784, 51.943249225616455, 49.98618834359305, 53.244619028908865, 55.34360728945051, 55.70360388074602, 54.83850104468209, 53.658672605242046, 54.05361863545009, 55.52832167489188, 53.51677649361746, 46.507986136845176, 42.844503266470774, 42.83022471836635, 46.73191615513393, 49.90285512379238, 53.334761483328684, 49.992917673928396, 51.809750011989046, 47.13959475925991, 42.692917891911094, 42.36921174185616, 48.43997097015381, 53.588339465005056, 57.693880626133506, 51.23385899407523, 55.1901285307748, 41.23500517436436, 44.117764132363455, 60.43623038700649, 48.41465868268694, 45.933790479387554, 45.301261220659526, 50.70066465650286, 47.41964537756783, 51.31571224757603, 47.07112373624529, 44.9684077671596, 41.85831069946289, 44.07052680424282, 52.64016049248831, 58.289118903023855, 53.5332749911717, 49.37884630475725, 57.732304164341514, 54.96760899680001, 43.97859866278512, 40.006872858319966, 45.07029962539673, 48.41071905408587, 55.17124680110386, 56.77608265195574, 53.92810637610299, 48.59816755567278, 47.49513060706002, 49.25609942844936, 54.22189705712454, 57.45929207120623, 56.84625598362514, 55.86336728504726, 47.12927668435233, 45.75314426422119, 51.86318513325283, 52.66356897354126, 56.19268410546439, 56.17891277585711, 55.828007902417866, 57.43262488501412, 61.71141242980957, 57.5204952784947, 63.79185594831194, 55.13158648354666, 36.618583815438406, 11.271034240722656, 7.681491494178772, 16.924660103661672, 17.97377382005964, 12.069553358214241, 1.170604597244944, 0.37165436574390953, 0.14264190303427832, 0.1743116836462702, 10.711698174476624, 50.60854891368321, 33.036290645599365, 43.0194866997855, 24.65980645588466, 31.513735362461635, 48.48096186774117, 47.451864174434114, 63.314264569963726, 58.998182569231304, 65.87232031141008, 6.411709938730512, 0.41244398270334515, 0.1410795897245407, 0.23150944443685667, 0.08730627303676945, 0.11126332929623978, 0.08837453821407897, 0.12749314733913966, 0.1888060194573232, 0.25341868879539625, 0.11092218224491392, 0.19840958341956139, 0.13725620774286135, 0.10450687113084964, 0.15731197941516126, 0.06226704841745751, 0.18374447391501494, 0.2109284730894225, 0.1275225007640464, 0.21199856352593216, 0.11967232557279722, 0.24553603891815456, 0.16195492313376494], [0.023011707700788975, 0.03955650509202054, 0.03049838828987309, 0.04493634801890169, 0.017965152693380202, 0.05594930724639978, 0.02596077016953911, 0.06897171400487423, 0.06498176524681704, 0.04359421593004039, 0.026085869974589775, 0.05242431443184614, 0.013508653434525644, 0.03511695224525673, 0.06691202095576695, 0.03232796297275594, 0.03621039446443319, 0.014958107710949011, 0.051375027879008224, 0.040070298593491316, 12.510580710002355, 73.44291073935372, 55.949035099574495, 54.33210938317435, 47.67447403499058, 26.939427035195486, 13.809647185461861, 27.212268897465297, 26.001920495714458, 32.33343866893223, 15.871827363967896, 0.06963504305375473, 0.04357323901993888, 0.05919852985867432, 0.2069590160889285, 0.6468136693750108, 3.1665950417518616, 2.947810164519719, 4.41561016866139, 37.91175127029419, 59.09121200016567, 59.7214344569615, 61.85669926234654, 60.3648932320731, 60.9819974899292, 59.68745081765311, 59.24699756077358, 52.46172380447388, 51.5981183052063, 55.07587930134365, 53.81283228737967, 49.27731922694615, 52.939857142312185, 54.32648829051426, 52.02686037336077, 53.66983488627842, 53.187466621398926, 48.101350511823384, 47.42040967941284, 50.03834499631609, 52.20917068208967, 52.85767732347761, 47.75666080202375, 47.76760074070522, 52.189819949013845, 50.84778233936855, 51.430239404950825, 48.87087392807007, 49.417495659419465, 52.71812622887747, 49.3424585887364, 41.93486247743879, 38.245320388248985, 38.51632097789219, 43.54385682514736, 46.61652742113386, 47.24689926419939, 46.69023738588606, 47.92187854221889, 40.01220907483782, 39.14623771395002, 38.321820054735454, 48.70205007280622, 51.419441904340474, 51.373469148363384, 47.33168813160488, 54.42000062125069, 35.118610177721294, 39.377435547964915, 54.95107923235212, 46.77304254259382, 42.51418937955584, 35.27566378457205, 41.744718074798584, 41.49139370237078, 45.80914674486433, 42.62054892948696, 41.05834722518921, 36.046601159232004, 38.8879314831325, 45.87820141656058, 52.90215621675764, 51.8887232371739, 48.76635217666626, 52.829186235155376, 50.0464848109654, 40.01476601191929, 37.13291726793562, 38.77961254119873, 47.60753508976528, 51.61340086800711, 51.975252628326416, 48.21887929098946, 49.4053258895874, 51.157348905290874, 50.3593031338283, 52.128832135881694, 53.21416507448469, 52.74237544195992, 54.38383524758475, 42.803745133536204, 40.575676713671, 41.91766568592617, 44.487279755728586, 47.901961530957905, 46.75374739510672, 47.66377033506121, 48.760439259665354, 49.182861941201345, 52.91142858777727, 55.09998607635498, 57.10921403339931, 49.90055874415806, 29.45116261073521, 5.118750061307635, 4.3062607220241, 3.909033945628575, 6.0005216257912775, 3.283224029200418, 0.3791136369109154, 0.139365908822843, 0.03439475689083338, 1.0668745062180927, 19.668944937842234, 40.05165747233799, 19.37045727457319, 25.575856958116802, 21.905182702200754, 17.907064165387833, 33.35517127173287, 43.70240082059588, 48.183134283338276, 47.52214172908238, 10.835016540118627, 0.20208725679133618, 0.06279503008616821, 0.05176166731065937, 0.027513724785032015, 0.04572324847270336, 0.06107733225716012, 0.10155626838760716, 0.04172310811866607, 0.0308901167341641, 0.057314048122082434, 0.009219408816924053, 0.050076233821788003, 0.01730548942993794, 0.034320481055017026, 0.03442955555926476, 0.02321888310169535, 0.05729331887726273, 0.016957177048815147, 0.014047749506841813, 0.08278167939611844, 0.0212217781227082, 0.05448001430236867, 0.021764729970267842, 0.038357184268534184, 0.024316130205988884, 0.031648257481200356, 0.05427620952416744, 0.03669499060405152, 0.04515445292262094, 0.03284096937360508, 0.06676281110516616, 0.022527026744293313, 0.027043846069968173, 0.09638813856456961, 0.04046327554221664, 0.03419183760083147, 0.08333318587392569, 0.06112596286194665, 0.04013681538136942, 0.017312183177896907, 0.0881820988974401, 0.04290948588667171, 16.568035125732422, 82.20411668504987, 63.0066956111363, 61.370644978114534, 54.51948840277535, 32.42274039132254, 15.641904524394445, 22.33371979849679, 26.904156242098125, 38.71113804408482, 17.633214814322336, 0.10930800850370101, 0.05746164984468903, 0.25967608445457047, 0.9196081970419202, 3.4754157619816914, 2.865044959953853, 1.462777976478849, 5.333831982953208, 40.4304906300136, 59.98102610451834, 61.56294332231794, 63.422121456691194, 63.3193575995309, 60.84546538761684, 60.439843450273784, 60.977877208164756, 55.17880644117083, 54.65615252086094, 57.121446337018696, 55.41797385896955, 53.70931107657296, 54.401233536856516, 57.09516824994768, 52.67716312408447, 55.552167892456055, 54.45211866923741, 51.65647969927107, 49.99164615358625, 52.137013639722554, 54.12371206283569, 53.430632727486746, 47.6181241444179, 50.390194824763704, 52.114828041621614, 52.63686009815761, 53.482004233769004, 49.91212402071272, 50.206963879721506, 54.01077256883894, 53.11453138078962, 43.32028463908604, 40.86304725919451, 41.21400771822248, 44.658483369009836, 48.52771977015904, 49.16190617425101, 49.19830778666905, 49.96569810594831, 42.25064768110003, 40.3198892048427, 39.35128600256783, 50.60960503986904, 54.00558226449149, 52.43854113987514, 48.28398391178676, 54.674349852970664, 35.8069543157305, 41.95277493340628, 56.520993437085835, 48.99634797232491, 45.21928637368338, 37.32189089911324, 43.709317752293174, 45.13431337901524, 47.718803542000906, 45.125245979854036, 43.14195564814976, 37.85449116570609, 41.6266508102417, 48.08394874845232, 54.686794076647075, 53.198885985783164, 48.98248979023525, 53.82999086380005, 51.601484707423616, 41.54619067055838, 39.16410500662667, 39.87482929229736, 50.39654547827584, 53.70060150963919, 53.0430656841823, 50.4479968888419, 48.62326792308262, 51.327055181775776, 52.79438965661185, 52.55368321282523, 54.056456974574495, 53.583020618983674, 56.36038582665579, 44.754924365452354, 41.98303433826992, 43.11130019596645, 46.35144322259085, 48.92901297977993, 47.56617246355329, 50.29690483638218, 50.924817017146516, 51.31331511906215, 56.04759529658726, 58.47058500562395, 57.57880456107003, 51.82757561547415, 32.43933268955776, 6.3975720916475565, 1.7187842449971606, 1.548179371016366, 4.6701600296156744, 4.850202185767038, 1.2221202786479677, 0.2474743149110249, 0.04546891997701355, 0.9844873270818165, 23.802537713732036, 33.694479601723806, 21.784080811909266, 25.915474482945033, 24.7741824899401, 24.384053298405238, 37.39038971492222, 49.7312902041844, 51.830014433179585, 57.48757471357073, 16.555889674595424, 0.2117203777389867, 0.04791039075436337, 0.03890360512637666, 0.06260844652674027, 0.03635803350646581, 0.006057932656923575, 0.06058206954704864, 0.053015925721930604, 0.03478372369759849, 0.06351506430655718, 0.018932460341602564, 0.05707227252423763, 0.021003585009436523, 0.01758567859152598, 0.03339168196544051, 0.026373707922175527, 0.03816741159451859, 0.014594918449542351, 0.06521259607481104, 0.04881313070654869, 0.12082818283566407, 0.006882650835905224, 0.10838028828480414, 0.10582583464149918, 0.10464569261031491, 0.2114787921309471, 0.11858776876968996, 0.12355505222720758, 0.19326825572976045, 0.1245285871305636, 0.18317862999226364, 0.14603626089436667, 0.08556362547512565, 0.1792675812861749, 0.10023059416562319, 0.16060454345175199, 0.16555669557835373, 0.20900570840707847, 0.11713260971009731, 0.14811046102217265, 0.291166433266231, 0.15035867824086122, 18.911287307739258, 89.27142129625592, 70.1087064743042, 69.80415303366524, 60.92757225036621, 37.661907945360454, 20.325933592660085, 37.490078994206016, 36.70972333635603, 46.05559934888567, 23.17283637183053, 0.306052025939737, 0.1822247861751488, 0.3575709643108504, 0.9824892857245037, 4.175543393407549, 9.948400344167437, 4.827303094523294, 6.965592971869877, 40.39784451893398, 59.84883662632534, 62.51234517778669, 64.95736067635673, 63.29647718157087, 60.23782457624163, 60.84078924996512, 63.1584164755685, 58.398504393441335, 57.17782402038574, 60.27162061418806, 58.480284690856934, 56.02908876964024, 56.682556424822124, 57.953024114881245, 54.60151883534023, 56.353475843157085, 57.099938188280376, 54.64600120271955, 52.20573827198574, 55.035729135785786, 55.77800171715872, 56.22485079084124, 48.24222871235439, 48.373011180332725, 54.261310713631765, 52.657989570072715, 54.056561197553364, 50.366775921412874, 51.90847001756941, 56.2200356892177, 53.9019707271031, 45.361689703805105, 43.09664297103882, 42.552467005593435, 47.49092347281319, 51.64867339815412, 51.08172818592617, 52.59084217888968, 53.09712961741856, 44.91503865378243, 42.891160420009065, 41.28205490112305, 52.47537006650652, 55.658791473933626, 56.674454825265066, 50.81221103668213, 55.582180636269705, 38.63795614242554, 44.88885089329311, 58.48304312569754, 51.375452859061106, 47.83387613296509, 38.187490531376426, 46.326794488089426, 46.438483306339805, 50.9902377809797, 47.84083475385393, 46.47301932743618, 39.927816254752024, 43.093193190438406, 51.13246740613665, 59.06542028699602, 57.13520377022879, 49.629895142146516, 56.46046073096139, 52.951450211661204, 44.36574534007481, 41.42049428394863, 42.47692271641323, 52.4822279385158, 55.86693865912301, 54.429856640951975, 51.837407316480366, 50.43145670209612, 53.50515215737479, 54.17661912100655, 55.56417785372053, 55.73177882603237, 57.18634598595755, 60.44595091683524, 47.438659123011995, 44.24319301332746, 45.61498280933925, 49.54629789079939, 53.419724055698936, 49.99163225718907, 53.145961557115825, 52.54795094898769, 54.69065727506365, 59.10303783416748, 62.17894976479666, 59.56154945918492, 51.822889055524556, 35.1231369291033, 8.761070455823626, 9.147922703198024, 9.96430390221732, 15.407112734658376, 9.122558304241725, 0.7560600872550691, 0.36840442727719036, 0.14727084179009708, 1.5839225330523081, 30.787325518471853, 57.044654846191406, 29.924265452793666, 34.26804992130825, 30.918260846819194, 27.962132385798864, 44.55383307593209, 57.91452762058803, 59.944464683532715, 63.88699068341936, 21.6556624685015, 0.3209384057138647, 0.12398624766085829, 0.1666072713477271, 0.14256692491471767, 0.1641184048993247, 0.11723995395004749, 0.18717359990945884, 0.16345593758991786, 0.14335823245346546, 0.14166238345205784, 0.10170707279550177, 0.13988664373755455, 0.0630891750167523, 0.10783819987305573, 0.15733743804906095, 0.09004466395292963, 0.13475362131638186, 0.16667125719998563, 0.16642766312829085, 0.23169636726379395, 0.23219427626047814, 0.12124799245170184], [0.03717943068061556, 0.04579093912616372, 0.022994503445391144, 0.04906265178163137, 0.04994061842028584, 0.012997377297974058, 0.04435763228684664, 0.0392725280086909, 0.026333759172952602, 0.07524835291717734, 0.029762496706098318, 0.01931236361685608, 0.05200631311163306, 0.014876715739124587, 0.03974112768524459, 0.08785113665674414, 0.05821417910712106, 0.0261602577686842, 0.05093520487259541, 0.1810783198369401, 28.16471927506583, 68.09481280190604, 55.88518115452358, 46.07977213178362, 31.55684198651995, 19.11495464188712, 28.211048126220703, 40.65126964024135, 38.459126881190706, 40.59636150087629, 3.4908481453146254, 0.15194563594247612, 0.04059217683970928, 0.16416788367288454, 0.12015831949455397, 1.743403666785785, 2.5454393327236176, 1.572789021900722, 22.48929865019662, 56.089479037693565, 59.71363857814244, 60.616091455732075, 59.15858173370361, 56.655281271253315, 55.27493476867676, 58.9203280040196, 60.02377142224993, 59.81731959751674, 54.139175278799875, 51.55273267201015, 55.0204952103751, 54.243130752018516, 54.19004304068429, 50.67837483542306, 51.621954100472585, 53.30156646456037, 55.890117849622456, 51.99152183532715, 49.49334566933768, 50.869248798915315, 54.21273238318307, 49.623523644038606, 48.44142314365932, 47.79101616995675, 50.10840368270874, 48.97812284742083, 47.675533635275706, 48.093933309827534, 49.20689228602818, 50.763184547424316, 51.64080456324986, 46.217356886182515, 40.01400865827288, 39.39500406810215, 42.93352011271885, 47.672205448150635, 47.37654570170811, 46.775505678994314, 43.74804701123919, 38.93438366481236, 37.15484578268868, 41.00764274597168, 52.6060448374067, 49.28100177219936, 49.9967600277492, 48.42343773160662, 52.73884923117501, 35.147493839263916, 38.90576750891549, 55.13925382069179, 45.79434360776629, 45.77192177091326, 35.56499024799892, 37.57679598672049, 37.59551790782383, 41.77358089174543, 40.65436853681292, 39.44898809705462, 37.91283171517508, 36.59084660666329, 42.72824600764683, 52.544987542288645, 52.16620997020176, 47.33757325581142, 50.603494099208284, 50.614677224840435, 39.30688006537301, 36.69320052010672, 40.50356830869402, 48.492575781685964, 51.51115117754255, 52.33385957990374, 45.05773033414568, 50.00092199870518, 52.37815087182181, 49.95475121906826, 50.64278963633946, 54.74004507064819, 52.62106684276036, 52.07204450879778, 42.02696432386126, 40.460121222904746, 39.68099887030465, 42.97280870165144, 42.7001370702471, 46.40618460518973, 46.267133780888145, 49.68503952026367, 51.911304882594514, 54.10950647081648, 54.42792156764439, 55.58105502809797, 52.91078935350691, 55.73473181043352, 32.731990814208984, 10.051651443753924, 0.7453968822956085, 1.301514629806791, 3.4913768598011563, 0.16489251836069993, 0.08640335327280418, 0.023705932145406092, 0.062180155222969394, 8.339308721678597, 32.74327816282, 37.613065583365305, 37.58990723746163, 17.312802110399517, 26.15393144743783, 33.9743287222726, 42.143148626599995, 44.091069153376985, 55.10599626813616, 28.356493030275615, 0.9852714964321682, 0.07374131307005882, 0.1028558054406728, 0.042278126015194824, 0.08603803680411407, 0.02489456773868629, 0.07981952798685857, 0.030412020960024426, 0.01049634047584342, 0.05442955165303179, 0.007677066489122808, 0.06666206222559724, 0.009271783238675977, 0.032982213223086934, 0.0025730633143601672, 0.01938329597136804, 0.047309042486761294, 0.05766195338219404, 0.04548818697886808, 0.004031366535595485, 0.11535069532692432, 0.04146995009588344, 0.03462254788194384, 0.005359284588069255, 0.046556333412549326, 0.038941352029464076, 0.027200039742248397, 0.047024447936564684, 0.050941091163882186, 0.08484754711389542, 0.009798613942361303, 0.08994531285549913, 0.043877941955413134, 0.015994198454011763, 0.05673205506588731, 0.0533346675469407, 0.03288213948586157, 0.05945217303399529, 0.008111767404313599, 0.03935032883392913, 0.03542393505839365, 0.07035636649067913, 35.12677083696638, 76.8876816885812, 61.21542222159249, 53.52865791320801, 38.27160194941929, 27.303715876170568, 27.173539638519287, 29.56925766808646, 34.89817162922451, 42.552397523607524, 4.6629690783364435, 0.14062262353088173, 0.09510196186602116, 0.35339403844305445, 1.6194073089531489, 2.845807352236339, 2.0817621563162123, 1.4638660209519523, 24.574433939797537, 58.4418819972447, 62.137114661080496, 62.5662909916469, 60.77179363795689, 59.62085928235735, 57.3389492716108, 59.23588044302804, 59.379951340811594, 59.81022548675537, 55.0317964553833, 53.23347064426967, 57.73266894476754, 54.88454328264509, 55.98473146983555, 51.298230579921174, 52.539422035217285, 53.774770055498394, 56.90090356554304, 53.14887980052403, 51.63095896584647, 53.08661004475185, 55.85785388946533, 51.507329668317524, 49.75727299281529, 49.34072848728725, 49.02607236589704, 49.6057779448373, 48.05941465922764, 47.57923855100359, 49.015455518450054, 53.30958121163504, 52.80431515829903, 48.64279236112322, 41.21717609677996, 40.63863781520298, 45.00090796606881, 47.85974775041853, 49.34512669699532, 48.38409008298601, 46.08084910256522, 41.21902084350586, 39.58322034563337, 44.138601779937744, 54.66037007740566, 51.47545828138079, 53.822122028895784, 49.497639656066895, 53.693093981061665, 35.772605895996094, 41.60693529673985, 56.91573796953474, 48.59419666017805, 47.915441036224365, 38.883616651807515, 38.7624192237854, 39.4895065171378, 44.33240788323538, 42.72461557388306, 41.24851942062378, 38.51958315713065, 39.682489258902415, 45.725424425942556, 53.82603733880179, 52.60018055779593, 48.175432205200195, 53.571702003479004, 52.57694925580706, 41.826449734824045, 38.99858501979283, 42.9137316431318, 50.879420961652485, 53.76235015051705, 54.02804231643677, 45.8067114012582, 50.77996097292219, 53.79398529870169, 52.141439642224995, 52.77408702032906, 56.03887530735561, 54.891741616385325, 54.82874229976109, 44.55679995673043, 41.43493264062064, 42.98166765485491, 43.968881607055664, 45.47943040302822, 48.10266719545637, 48.4302921295166, 50.60395615441458, 53.864655426570344, 55.11909709657942, 55.94295195170811, 54.43077032906668, 52.702829769679475, 56.4982693535941, 35.49783590861729, 9.891557131494794, 0.2622965324137892, 2.3399554789066315, 7.120192561830793, 2.7104718600000655, 0.6649509647062847, 0.3123031790767397, 0.06330815862332072, 9.769071681158882, 38.25644792829241, 36.10663359505789, 35.55743408203125, 16.660140446254186, 29.416744709014893, 40.02224574770246, 45.623539515904014, 49.98449298313686, 61.49908242906843, 36.15771675109863, 1.3353370491947447, 0.07171290727066142, 0.04679037371118154, 0.03668452759406396, 0.024233309917950203, 0.08292172902396747, 0.06235824352396386, 0.022471149385507618, 0.05796622884060655, 0.04797832228775535, 0.029782859542007958, 0.0622164975585682, 0.058233700559607575, 0.0586903342711074, 0.049864205199160745, 0.01674424427827554, 0.03649296698027423, 0.056503996053444486, 0.013123184475781662, 0.024539563305942074, 0.04557744486789618, 0.02304639101826719, 0.181143119931221, 0.09705220721662045, 0.06823099125176668, 0.1535510362258979, 0.10253810177424125, 0.17655905948153564, 0.14439806022814342, 0.1623895112425089, 0.11038409040442534, 0.16982842635895523, 0.1302150905664478, 0.14411106705665588, 0.16840382851660252, 0.20660497008689813, 0.1541275874312435, 0.12368177542729036, 0.15145192029220717, 0.17106986045837402, 0.10977659800222941, 0.301618396703686, 42.45620666231428, 87.1071616581508, 70.02650928497314, 61.31051526750837, 43.67662647792271, 28.192979335784912, 37.4108521597726, 57.40361615589687, 49.300050258636475, 56.35556377683367, 5.929327777453831, 0.27444876890097347, 0.3298409751483372, 0.3738874244902815, 1.211456530860492, 5.895662452493395, 7.029710948467255, 4.656607134001596, 25.201091970716202, 61.446185793195454, 64.01131480080741, 64.06217561449323, 62.05829429626465, 60.87007590702602, 59.203995159694124, 61.03652000427246, 59.64174556732178, 58.93230669839041, 58.4148257119315, 56.81992925916399, 60.007665497916086, 58.5468692779541, 56.07920612607683, 52.12587220328194, 53.962406158447266, 55.42561340332031, 59.67331123352051, 55.804519517081125, 53.99454852512905, 54.0184885433742, 57.51636110033308, 53.053418500082834, 49.60037224633353, 50.75179992403303, 51.15366983413696, 51.57059301648821, 49.406854493277415, 47.91481222425188, 49.98400313513619, 56.3683762550354, 55.939328466142925, 50.59977681296212, 42.83643988200596, 42.46990850993565, 46.637111459459575, 51.755126748766216, 51.18212965556553, 50.720237731933594, 47.92666237694876, 44.63512005124773, 39.60010099411011, 47.27971560614449, 57.017317158835276, 55.323526995522634, 55.12022965294974, 51.92269992828369, 53.757399559020996, 38.942148276737754, 45.051157338278635, 58.775228772844585, 51.188685280936106, 50.610442297799246, 41.48074211393084, 41.759225913456504, 42.344219071524485, 48.07331453050886, 46.183988162449424, 43.45887688228062, 41.041949476514546, 41.16774313790457, 46.91810703277588, 57.818854400089805, 54.54795864650181, 47.84718540736607, 54.94189371381487, 55.691093649183, 42.871250356946675, 40.4663850239345, 45.373755250658306, 54.651875904628206, 56.62305552618844, 55.64930023465838, 45.3793728692191, 51.67699078151158, 56.81740706307547, 53.653930459703716, 55.445210797446116, 59.65621171678816, 57.28784874507359, 56.226591314588276, 45.92997939246041, 43.31275626591274, 45.18059532982962, 46.64517484392439, 47.53077833993094, 50.92630393164498, 51.48989316395351, 53.3022369657244, 55.96768406459263, 57.392085620335166, 56.967133794512065, 56.89032145908901, 53.508476870400564, 58.62520326886858, 37.43887077059065, 13.618391939571925, 2.118624521153314, 7.590595160211835, 11.908514959471566, 2.977881533758981, 0.34901230356522966, 0.33324347542864935, 0.19782297632523946, 13.510003515652247, 48.73507833480835, 51.06867599487305, 49.92559657778059, 25.01286005973816, 36.87707069941929, 45.07934965406145, 53.974325793130056, 55.97167233058384, 67.80890137808663, 41.33123425074986, 1.64664783009461, 0.11480181477963924, 0.18515932799449988, 0.09550636195178543, 0.1451871014599289, 0.17811495384999684, 0.14919937402009964, 0.10672975863729205, 0.11692896778030054, 0.15589920165283339, 0.15371212043932506, 0.10501115157135896, 0.22897166918431008, 0.270423916301557, 0.2764127478003502, 0.10128375515341759, 0.12950800279421465, 0.09462016129067966, 0.1150999359254326, 0.07040495638336454, 0.19053814294082777, 0.1480351300644023], [0.028116513243211166, 0.03298764489591122, 0.06295052995639187, 0.012356886889652481, 0.03477497738120811, 0.045258245031748495, 0.023371215909719467, 0.06131262106022664, 0.002125103612862793, 0.031076927602823292, 0.03313418810388871, 0.02546576191005962, 0.032775962326143465, 0.02473077786687229, 0.041856307935501845, 0.018378918258739368, 0.05254365177825093, 0.04412865046677845, 0.02443381362328572, 1.992481278521674, 45.008589199611116, 61.29987062726702, 56.95947340556553, 46.58262021200997, 32.44189657483782, 17.441725935254777, 19.08106654030936, 36.766000270843506, 39.3903557232448, 19.791747399738856, 0.1347329667104142, 0.0948532787816865, 0.09858262938048158, 0.09162132149296147, 2.6476814235959734, 2.6267332562378476, 0.5849842014057296, 6.5572729621614725, 45.80086101804461, 61.72693470546177, 61.273008891514365, 58.845391682216096, 58.04827002116612, 57.16247892379761, 58.73993192400251, 54.692206723349436, 55.049500465393066, 53.406706605638774, 59.06414181845528, 54.462005955832346, 52.66441317967006, 53.20254421234131, 53.22627578462873, 50.55513116291591, 53.08597081048148, 51.36539534160069, 52.73145982197353, 52.25539009911673, 53.135455880846294, 51.7861921446664, 52.09915637969971, 50.057720048086985, 53.271501609257285, 50.2506993157523, 53.840277671813965, 50.1068959236145, 51.65745939527239, 47.036518233163015, 48.48117726189749, 52.056414536067415, 52.23801960263933, 46.701107842581614, 41.892179693494526, 39.68238156182425, 42.825149059295654, 44.8146892956325, 45.19866064616612, 43.909182684762136, 42.91230378832136, 37.249108518872944, 38.73295191356114, 45.10038185119629, 53.05838646207537, 46.01225996017456, 53.40642172949654, 45.550170012882774, 53.152409485408235, 31.395810535975865, 36.33443375996181, 56.10095746176583, 44.44667100906372, 45.645151887621196, 37.948997088841026, 39.76988022668021, 35.17645740509033, 38.3316239629473, 35.38526119504656, 37.241003445216585, 35.287062304360525, 37.3180832862854, 41.245701926095144, 51.07213619777134, 49.081838607788086, 47.34414277757917, 51.47897754396711, 47.98323113577706, 38.110803263528005, 37.608247007642476, 39.467706544058665, 49.16267742429461, 51.043558256966726, 51.17618547167097, 46.03366041183472, 51.802287646702354, 50.58647101266043, 49.372193404606406, 46.67254032407488, 50.87786109106881, 49.868781157902305, 51.48449093954903, 41.05863904953003, 38.81220654078892, 38.74690389633179, 42.39406197411673, 44.20424141202654, 47.46491983958653, 48.93661083493914, 51.278911113739014, 51.15668535232544, 56.0952182497297, 53.25255734579903, 53.72666072845459, 56.96199212755476, 56.92804322923933, 56.908685547964915, 39.890730244772776, 2.9465412497520447, 1.9923377547945296, 3.420646369457245, 3.984139629772731, 0.23482194383229527, 0.15238396956452302, 0.11771966463753156, 0.35860418315444675, 13.382254804883685, 30.149293286459788, 33.115413257053916, 26.06509178025382, 15.07191252708435, 20.63876233782087, 44.40067046029227, 44.05850642068045, 53.27624722889492, 41.33380161012922, 5.142125538417271, 0.0292606250649052, 0.029765645108584846, 0.0662051842414907, 0.04070534969546965, 0.029696607563112463, 0.007282461056352726, 0.093265208282641, 0.01368344490349825, 0.00999871052668563, 0.006508904841861555, 0.052058360140238485, 0.020627055749563233, 0.014021058483714504, 0.07155918516218662, 0.019551838980987668, 0.014597267877044422, 0.10644961866949286, 0.03908823789762599, 0.0003245397212075269, 0.015962348020236408, 0.030366467511547462, 0.03923426541898932, 0.01640748734852033, 0.04448823331456099, 0.04995214333757758, 0.010933040524832904, 0.049423679909003634, 0.049041522201150656, 0.05828032270073891, 0.013864599334608232, 0.032445532735437155, 0.032590013196957965, 0.04203454212152532, 0.048632867700819454, 0.15685574603932245, 0.027894235349127224, 0.036322753078171184, 0.061260624921747615, 0.04162546692948256, 0.07835083215364388, 2.517380769763674, 55.94193056651524, 68.65419837406704, 62.44457244873047, 52.18788834980556, 37.2343053817749, 21.111104352133616, 18.686865704400198, 36.32828113010952, 41.04688617161342, 22.707074301583425, 0.21092255626405987, 0.31744842869894846, 0.29259561800530975, 0.9047787870679582, 2.946592492716653, 2.864422010523932, 1.6737905336277825, 8.078200629779271, 48.95558983939034, 62.471795490809846, 63.02416338239397, 62.41421576908657, 59.292390142168315, 60.06382083892822, 61.489723205566406, 57.42689609527588, 58.80347320011684, 54.181913648332866, 58.278974533081055, 56.66857664925711, 54.31719854899815, 54.63272666931152, 54.80875928061349, 52.60246304103306, 54.17173106329781, 52.60763944898333, 54.3538225037711, 53.38694245474679, 56.0442601612636, 54.95119387762887, 52.1990019934518, 52.09074558530535, 53.036645548684255, 52.05109221594674, 54.770770004817415, 51.84938253675188, 53.61079256875174, 49.264478955950054, 47.43141562598092, 53.513073103768484, 53.72016416277204, 48.411858558654785, 43.726497173309326, 41.9290120942252, 44.522316047123496, 47.368524006434846, 48.21079158782959, 45.14791447775704, 44.607295989990234, 40.117449964795796, 39.87904337474278, 47.258342947278706, 54.99266767501831, 49.77608871459961, 54.99820538929531, 48.27638953072684, 53.54296772820609, 33.02146666390555, 37.70460115160261, 58.72796017783028, 46.70825753893171, 48.11991957255772, 39.98229360580444, 39.78313044139317, 36.77057218551636, 41.30527230671474, 37.72035966600691, 40.001665183476035, 37.935528005872456, 38.63522550037929, 42.88980552128383, 53.57669428416661, 51.86088875361851, 49.04644101006644, 53.744371686662944, 49.92248725891113, 39.61067615236555, 38.9388096673148, 41.00583621433803, 50.97580984660557, 52.95525087629046, 53.06428895677839, 47.641591685158865, 53.953960623059956, 51.51908949443272, 51.2055971963065, 49.42749064309256, 53.19736433029175, 54.05919109072004, 53.181703090667725, 43.51103700910296, 40.867021628788535, 40.819610595703125, 43.788596698216026, 45.74071046284267, 49.31084428514753, 51.8761157308306, 54.04060465948922, 53.56110600062779, 58.548905100141255, 56.01486580712454, 55.15539796011788, 58.223586968013215, 59.10357979365757, 58.23868887765067, 43.98853458677019, 4.302297208990369, 1.4223368551049913, 3.5577302021639685, 5.90218767949513, 1.799474978021213, 0.3161576379622732, 0.04611155031515019, 0.4804206522447722, 17.066410303115845, 34.49046523230416, 31.49572910581316, 29.802946431296213, 21.310594081878662, 26.733730827059063, 48.045448780059814, 49.34356335231236, 57.578363350459504, 49.51063626153128, 6.728328926222665, 0.12633439951709338, 0.06406602117099933, 0.03274428491879787, 0.02402116255169468, 0.022682419745251536, 0.051726939888404946, 0.014443737454712391, 0.02638033720930772, 0.03572698236842241, 0.030704744359744445, 0.00833954821739878, 0.056175581711743555, 0.015585856079789144, 0.044307118747383356, 0.013087521523370274, 0.03015769585700972, 0.07187874801456928, 0.02942462358623743, 0.04775578315768923, 0.03508668279807482, 0.06017253973654338, 0.11192638014576264, 0.1110065852158836, 0.10518555542720215, 0.15086540819278785, 0.08521758618631534, 0.22142150146620615, 0.0931633466056415, 0.07824149302073888, 0.09017585191343512, 0.10421895515173674, 0.05952472199818917, 0.09659875583435808, 0.1889463404991797, 0.18939859765980924, 0.11591089383832046, 0.12916209921240807, 0.10498852921383721, 0.11518961111349718, 0.17608150653541088, 3.003730135304587, 67.67324474879673, 76.73801054273332, 72.61513710021973, 60.14155033656529, 44.468669005802695, 26.24603155681065, 29.33449193409511, 49.7413546698434, 55.99666847501482, 29.632270881107875, 0.2862957189125674, 0.6115721889904567, 0.4645123173083578, 1.0406183493988854, 6.010825370039258, 10.14415454864502, 5.668407286916461, 7.857335635593959, 53.24557440621512, 63.65881878989083, 66.01974718911308, 64.3290489741734, 62.270158767700195, 61.417190960475374, 64.43156269618443, 60.92482771192278, 60.83810029711042, 54.912923199789866, 57.483565602983745, 60.94680486406599, 55.42625611168997, 55.465301513671875, 57.67762531552996, 53.78416401999337, 56.77944905417306, 53.31164482661656, 56.17532055718558, 55.26227862494332, 59.098743847438264, 55.690666334969656, 55.107990401131765, 53.39140319824219, 55.965498856135774, 54.583359718322754, 58.443507875714985, 54.34980297088623, 56.66058969497681, 50.4850446837289, 49.02946308680943, 55.37195593970162, 57.16640813010079, 51.76347500937325, 45.61551782063076, 43.63322455542428, 46.448867389133994, 49.010199206215994, 50.118190220424104, 47.359536511557444, 47.12516335078648, 41.40395062310355, 42.62226513453892, 48.61627803530012, 57.77956928525652, 51.59713166100638, 57.35686867577689, 48.8054392678397, 54.13153920854841, 34.80576058796474, 42.07275990077427, 60.675790378025596, 49.89096328190395, 49.731460435049875, 41.888198375701904, 43.60554640633719, 39.88898972102574, 43.03136117117745, 40.354828221457346, 42.086138657161165, 38.88057681492397, 41.90754910877773, 45.60504341125488, 57.20185089111328, 54.641755853380474, 50.82730599812099, 56.82303857803345, 52.18880551201956, 43.41411658695766, 40.57181004115513, 44.56775726590838, 53.832877840314595, 55.07616070338658, 53.423882552555625, 48.06208971568516, 54.74846976143973, 55.4713533946446, 53.801079409463064, 51.507569381168906, 55.786509786333355, 56.12847580228533, 55.12697287968227, 45.30859157017299, 42.470968110220774, 43.7978447505406, 47.421896593911306, 47.785089356558665, 51.961033139910015, 54.04603467668806, 56.875379358019146, 55.70601837975638, 61.9578789302281, 58.0939370564052, 56.55920852933611, 59.89372893742153, 62.21978432791573, 61.5017922265189, 46.59746503829956, 4.6410249301365445, 4.476396918296814, 9.94546125616346, 12.03884926864079, 1.2967817123447145, 0.42292080766388346, 0.3003898954817227, 0.5197056585124561, 22.708780084337505, 42.92531081608364, 45.89716305051531, 36.890845503125874, 21.76198032924107, 30.22431993484497, 54.696816853114534, 56.75045769555228, 62.96093477521624, 56.865294047764365, 7.583510603223528, 0.20479291517819675, 0.1413260879261153, 0.17719069415969507, 0.12125955468841962, 0.1525925783706563, 0.18264882984970296, 0.20339195749589375, 0.10492047893681697, 0.08067170011677913, 0.09062761374350105, 0.15393491062734807, 0.1273481308349541, 0.09321446064859629, 0.1788016584302698, 0.07032010557928256, 0.11993460649890558, 0.15012505863394054, 0.10213507232921464, 0.0903266698920301, 0.16220127205763543, 0.14571144618093967], [0.01624723264415349, 0.021050178312829564, 0.007870149565860629, 0.0632927490930472, 0.02075511057462011, 0.030472295225730965, 0.06962313476417746, 0.03754478107605662, 0.042898117032434256, 0.049892456004662175, 0.031160305985914807, 0.037834573204496076, 0.021080369728484323, 0.020724118487643342, 0.06244785764387675, 0.029246905086828128, 0.05922091472893953, 0.10242317829813276, 0.24651272222399712, 9.966128672872271, 57.13197980608259, 52.73835243497576, 53.35823597226824, 37.8191283089774, 33.44565766198294, 22.981630631855555, 36.83825806209019, 38.37039491108486, 31.742744513920375, 5.926682685102735, 0.06021948078913348, 0.05626097195116537, 0.24878342609320367, 0.8002893339310373, 2.227069399186543, 2.063082141535623, 2.7179657093116214, 30.19568293435233, 63.911712374006, 60.143829345703125, 56.15253046580723, 56.72542333602905, 55.33136108943394, 52.141054017203196, 53.67521974018642, 52.83708981105259, 54.317716189793174, 55.831263133457725, 52.77116182872227, 54.87335320881435, 50.75933871950422, 49.979584080832346, 52.40038858141218, 51.49467005048479, 54.029035908835276, 50.20537274224417, 50.88174513408116, 50.650231157030376, 52.73897082465035, 53.0724252973284, 49.09914309637887, 52.40806981495449, 51.42085238865444, 48.1287750516619, 50.12708044052124, 49.05372967038836, 51.40699768066406, 48.574745178222656, 47.67947326387678, 49.02422761917114, 51.649368218013215, 46.51729672295706, 41.75739853722708, 41.72770888464791, 46.09739623750959, 44.85148695537022, 45.642407349177766, 42.24752099173409, 41.41420269012451, 35.23211942400251, 39.00801372528076, 46.13453435897827, 52.12651491165161, 45.9324494770595, 51.993189402988975, 46.73933335712978, 52.440747192927766, 30.232195717947825, 35.95577083315168, 54.64215537479946, 45.13333020891462, 46.90152515683855, 40.32683045523507, 41.836781706128804, 35.404466015951975, 37.110995701381135, 36.78247792380196, 36.53869342803955, 35.834615094321116, 35.425362723214285, 41.367093903677805, 51.36813293184553, 49.64693907329014, 50.98389754976545, 51.78401041030884, 44.63792364937918, 38.24752296720232, 38.27433259146554, 39.073017597198486, 47.04064198902675, 51.61999470846993, 48.15537970406668, 47.41614348547799, 51.25845561708723, 49.12089443206787, 48.59681265694754, 45.199008056095664, 47.83600228173392, 47.339744567871094, 46.62108196531023, 40.22829457691738, 39.178876876831055, 40.60441446304321, 43.995962211063926, 45.5199488231114, 49.35689694540841, 50.18197815758841, 53.84679855619158, 55.473215511866975, 56.66226421083723, 54.50734642573765, 52.67785446984427, 53.616910457611084, 55.03138998576573, 53.971657684871126, 55.88230460030692, 27.517482416970388, 0.26741073227354456, 4.821663762841906, 3.4177289945738654, 2.248866766691208, 1.0824937309537614, 0.08252813800105027, 0.048400557666484795, 6.778127534048898, 31.5054600579398, 41.11095551082066, 18.806631803512573, 27.516726800373622, 37.66720942088536, 27.232277972357615, 40.77244274956839, 43.50405059541975, 48.29807138442993, 12.196124349321638, 0.06449951005301305, 0.15882254764437675, 0.017994748694556098, 0.07484272468302931, 0.022675342625007033, 0.04909609677270055, 0.06627399447773184, 0.0713572802820376, 0.025137447652273943, 0.04755906228508268, 0.07973895873874426, 0.023283377855217884, 0.022585231478192976, 0.021957442397251725, 0.045143586184297285, 0.042830148179616244, 0.04964919102245143, 0.06721498684159347, 0.03270205629191228, 0.016415127652830312, 0.041638874781451056, 0.06276534417910234, 0.005972230715477573, 0.008968847886925297, 0.0418935832567513, 0.028415779416848506, 0.039226024611187835, 0.08087622414210013, 0.04304503004199692, 0.030873326385127645, 0.051249760136540444, 0.05122382313545261, 0.06446010752448014, 0.05932258641613381, 0.007734579117303448, 0.05635769033272352, 0.062342990056744645, 0.03214126066969974, 0.11800616926380567, 0.21194972257528985, 13.175723944391523, 68.58582809993199, 59.31992585318429, 61.738378388541086, 44.530521869659424, 40.91228566850935, 28.675875663757324, 29.384571075439453, 34.13959857395717, 37.94201067515782, 7.295737930706569, 0.034269726635622125, 0.0892370647883841, 0.1739385300981147, 1.9378341308661868, 5.914036963667188, 2.0687816185610632, 2.604747853108815, 32.580982140132356, 65.5977761404855, 62.16339274815151, 59.62669576917376, 58.58042907714844, 57.50898558752877, 54.179735388074604, 55.792308058057515, 54.51276254653931, 57.203858920506065, 58.10605818884713, 54.108439922332764, 57.831461906433105, 52.732345717293875, 51.996482849121094, 53.651578494480674, 52.45512648991176, 54.51392984390259, 50.205966813223704, 52.6111934525626, 52.631166049412315, 54.068977628435405, 53.4534193447658, 50.72790159497942, 52.997627939496724, 54.622471128191265, 49.909633091517854, 51.68809052876064, 51.7538343838283, 53.76499741418021, 50.62281009129116, 47.7640015738351, 50.827257360730854, 52.90757233755929, 47.88293041501726, 43.635065828050884, 43.22861705507551, 46.932336943490164, 47.68239498138428, 47.034503255571636, 44.93903425761631, 43.98121813365391, 37.24028083256313, 40.32995367050171, 48.7982930455889, 52.991600377219065, 48.354428223201204, 54.06092814036778, 47.44697959082467, 52.305542196546284, 31.94085850034441, 38.12451205934797, 55.859861918858115, 46.27443981170654, 47.41742890221732, 43.51109954289028, 42.76859072276524, 37.55206387383597, 40.47656413487026, 38.78836032322475, 38.645689487457275, 38.176248346056255, 38.73625578199114, 43.04106433050973, 53.51694672448294, 51.859419209616526, 52.39913443156651, 53.38508381162371, 46.642760344914024, 39.72514425005232, 39.4366272517613, 40.060585907527376, 50.20826666695731, 53.377055168151855, 48.37137140546526, 46.453474044799805, 53.4645607812064, 50.75554847717285, 50.56533459254673, 46.70647185189383, 49.46891232899257, 50.35687126432146, 48.932448863983154, 42.15934835161482, 41.226424149104524, 42.246245997292654, 46.523136683872764, 47.29812485831124, 52.30309295654297, 51.28984063012259, 55.22260788508824, 56.58659832818167, 57.90072154998779, 56.19930573872158, 55.47067247118269, 55.09916271482195, 57.103360176086426, 56.21354259763445, 58.19637087413243, 29.88413613183158, 1.7106988217149461, 2.809007521186556, 4.290478323187147, 5.7006573506764004, 2.55848804967744, 0.07273798369403396, 0.11716925060110432, 7.718021648270743, 35.46068736485073, 37.27561937059675, 20.540217774254934, 25.840435675212316, 38.96130098615374, 33.31656013216291, 45.95462812696184, 49.14060647147042, 57.832354749952046, 17.190091712134226, 0.10766615731907742, 0.07786198159945862, 0.004883579801701541, 0.058082489030701775, 0.022786847980959073, 0.047183035141123195, 0.01927845043662403, 0.015574902828250612, 0.0281994811126164, 0.0797101210004517, 0.06291398406028748, 0.01979090892044561, 0.04783956526911684, 0.013375071941741874, 0.021004212654328773, 0.050078310138945065, 0.046461501358343024, 0.07254643325826951, 0.04463990285460438, 0.02820052096753248, 0.011167954437301626, 0.1345150348331247, 0.12994290302906716, 0.0773229601659945, 0.12861283868551254, 0.09498660412750073, 0.11854648669915539, 0.15667284013969557, 0.1239657559032951, 0.1810388426695551, 0.1606600069041763, 0.13825206644833088, 0.1486405868615423, 0.11586894680346761, 0.14608743600547314, 0.2219991111861808, 0.13280275171356543, 0.22080581236098493, 0.21893665194511414, 0.2646801716514996, 17.247843401772634, 78.81798158373151, 66.70677811758858, 70.11092294965471, 51.09036479677473, 43.100266456604004, 32.667497634887695, 51.85133498055594, 51.262756552015034, 45.50155694144112, 9.995444859777178, 0.21188615741474287, 0.36171901172825266, 0.48588584469897406, 2.0833437400204793, 9.27295206274305, 7.773306727409363, 3.9878108842032294, 34.105899810791016, 67.6353840146746, 64.92100770132882, 62.15820244380406, 61.735425404139924, 59.9507736478533, 56.64885071345738, 59.0575201851981, 57.66388872691563, 58.70494079589844, 60.41099452972412, 56.90360641479492, 55.91497155598232, 55.21370724269322, 51.922171865190776, 55.976226874760215, 53.95873056139265, 58.04233625956944, 52.20792695454189, 53.998505524226594, 54.55905491965157, 55.267496722085134, 55.47029032026018, 52.390727111271445, 54.98575421742031, 57.17405114855085, 52.60543687002999, 52.916969776153564, 53.58670316423689, 56.19412585667202, 51.521847929273335, 48.003026553562705, 51.85249532972063, 55.56484488078526, 50.93962015424456, 45.928311824798584, 46.30795097351074, 50.68251248768398, 50.11830486570086, 50.83123867852347, 47.1510523387364, 46.25498138155256, 38.49244001933506, 42.95883240018572, 51.87539659227644, 56.2882843698774, 51.49339158194405, 55.61225938796997, 50.2479374068124, 53.966880798339844, 34.58096204485212, 41.24162333352225, 58.14670862470354, 49.09819119317191, 49.15668460300991, 45.96967445101057, 45.88407959256853, 40.397163595472065, 42.85761104311262, 42.74829503468105, 40.58243383680071, 39.60506548200335, 41.11870275224958, 46.11096606935774, 55.84093849999564, 53.19356019156319, 55.60028764179775, 56.177255630493164, 48.8973639351981, 41.90723991394043, 42.20449079786028, 43.36979750224522, 51.91597407204764, 56.202776363917756, 49.264315673283164, 47.265742778778076, 55.006459849221365, 53.22426428113665, 52.49795866012573, 48.66848332541329, 52.45031486238752, 52.043817452022004, 52.307439054761616, 44.18708978380476, 43.41368579864502, 46.001663957323345, 50.0434901373727, 50.02079037257603, 53.21534974234444, 54.73199210848127, 57.219148431505474, 59.17512539454869, 59.9985077721732, 58.399935722351074, 56.49429498400007, 58.76386151994978, 60.64791420527867, 59.38366167885916, 63.591087750026155, 32.29684598105294, 2.3703974911144803, 9.428790603365217, 11.101236769131251, 9.676856057984487, 2.053914862019675, 0.171342278697661, 0.19026302413216659, 9.87894528252738, 45.12137583323887, 52.03159557070051, 28.182230472564697, 34.884758131844656, 47.66167197908674, 37.87282746178763, 54.66729743140084, 54.863101141793386, 64.58989824567522, 20.326119456972393, 0.1658686316971268, 0.19116881409926073, 0.0661841021584613, 0.1863039487174579, 0.10629228675471884, 0.0972451554345233, 0.22168519374515328, 0.1323151293077639, 0.08052764713232007, 0.10980143238391195, 0.17186684054987772, 0.13213211484253407, 0.0999843402366553, 0.18366842371012482, 0.07561260408588819, 0.14274784949209007, 0.11095333378762007, 0.15517483837902546, 0.0975683688053063, 0.1375644254897322, 0.10624983081860201], [0.07165707062397685, 0.05083769939041563, 0.04563047916495374, 0.025495459691488316, 0.014636980835348368, 0.09602334456784384, 0.07620302454701491, 0.02828051515721849, 0.036163775715976954, 0.038138753668005974, 0.038862903203283033, 0.052781145820128064, 0.013485421243655895, 0.08845859513218914, 0.030640571910355772, 0.06736372171768121, 0.024862211796322038, 0.13777554487543447, 0.1079559867669429, 26.08859406198774, 57.05228396824428, 53.86348812920706, 47.08455807822091, 36.920239857264924, 23.57498942102705, 17.25590852328709, 34.66969748905727, 39.50720705304827, 21.26954586165292, 0.33355193744812695, 0.04507649264165333, 0.1081930940438594, 0.3502581752836704, 1.4684052573783057, 2.517966155494962, 0.34952679595776964, 6.430078370230539, 49.56339045933315, 60.83348669324602, 56.585486616407124, 56.46504306793213, 50.262341022491455, 47.64927291870117, 46.563981669289724, 45.18355873652867, 46.2073757989066, 51.30509540012905, 54.41906261444092, 53.7855258669172, 54.852366174970356, 54.77701990944998, 50.598154408591135, 54.74148334775652, 52.38550206593105, 53.314146178109304, 51.18024321964809, 50.987072876521516, 47.3298225402832, 50.736520835331504, 48.71515090124947, 49.749251297542024, 51.14635338102068, 49.54354987825666, 47.32002558026995, 45.847962856292725, 48.32509640284947, 48.63006673540388, 51.75465079716274, 49.3589049748012, 48.053001471928184, 50.85038096564156, 44.94183438164847, 44.06168174743652, 41.02203246525356, 44.47147260393415, 45.03424889700753, 45.4955050604684, 43.49459409713745, 40.35484906605312, 37.365661076136995, 42.97859655107771, 46.85104301997593, 52.6912054334368, 45.96613434382847, 52.685275145939414, 46.01263516289847, 53.02040760857718, 30.958942549569265, 35.712382384708945, 54.584808417728965, 44.57263837541853, 44.77514362335205, 42.96290404456002, 43.45209196635655, 38.490181854793, 36.134572301592144, 36.303615025111604, 35.971894127982004, 35.201147828783306, 36.410429682050435, 37.73225498199463, 47.18175990240914, 49.98508358001709, 50.24883025033133, 46.58350263323103, 39.53236648014614, 36.68827077320644, 38.37440054757254, 37.26742049625942, 45.070184980119976, 51.64168698447091, 50.03423861094883, 45.74120378494263, 50.230302878788535, 49.775320938655305, 45.9223051071167, 42.760225091661724, 42.44185168402535, 43.935655321393696, 41.514955043792725, 39.44004576546805, 38.616104057856965, 39.55170679092407, 42.39740058353969, 48.62480694907052, 48.67237431662423, 52.2129088129316, 54.53054993493216, 54.62379823412214, 51.8545172555106, 54.47782700402396, 53.62998349325997, 53.01096153259277, 50.19360944202968, 53.476664543151855, 54.59672457831246, 48.26121466500418, 12.079701202256338, 1.6611038829599107, 3.215260224682944, 4.974335661956242, 0.3285672020699297, 0.06613418233713933, 0.05188737270821418, 0.6167291636977876, 21.081602300916398, 37.66026817049299, 42.810484886169434, 43.24774544579642, 37.86122397014073, 24.784319911684307, 37.55159487043108, 44.361006668635774, 53.43613222667149, 30.07472174508231, 1.0196234988314765, 0.03980363093848739, 0.0271206172183156, 0.011729172447563281, 0.03353359077924064, 0.04435249238408037, 0.0898609370259302, 0.03623671144513147, 0.05918532556721142, 0.022486564004793763, 0.01484929783535855, 0.07618342167032616, 0.023491839079984596, 0.06372357811778784, 0.06277705569352422, 0.06926575036985533, 0.016033528040030172, 0.02048139294077243, 0.02095044723578862, 0.03376537834161094, 0.014877899782732129, 0.07966131397656032, 0.04215356394914644, 0.05387031666136213, 0.029097030271909068, 0.02061230779093291, 0.05660077550315431, 0.016039478792143718, 0.03363840069089617, 0.07847829495689698, 0.019574196709852134, 0.05346873928127544, 0.027057583011420708, 0.016812231790806566, 0.02689737580450518, 0.07771642905260835, 0.09559831023216248, 0.06604152838034288, 0.04708149576825755, 0.03184340754523873, 31.713176454816544, 66.19670391082764, 59.56350885118757, 54.417996065957205, 41.846102714538574, 31.780466284070695, 23.31012061664036, 40.41498572485787, 40.51871885572161, 26.674985545022146, 0.2896686079246657, 0.0811342845803925, 0.4128270564334733, 0.40076596076999393, 4.103079761777606, 3.652039621557508, 1.2771890951054437, 7.709763714245387, 53.426404748644146, 62.45179162706648, 58.84658677237374, 58.816431590488975, 54.546058314187185, 49.48353828702654, 48.765018122536794, 47.68776593889509, 50.04034260341099, 53.31115845271519, 55.16979462759835, 55.944987773895264, 53.18808501107352, 55.900352546146934, 53.366917746407644, 55.93374211447579, 53.50179270335606, 53.754380566733225, 54.00624929155622, 51.29491976329258, 49.936602524348665, 52.49301501682827, 50.11541788918631, 51.12149967466082, 52.577640601566856, 52.01657009124756, 49.51581961768014, 47.832184246608186, 49.27588789803641, 50.598446232931956, 52.759186608450754, 49.31517996106829, 50.15430695669991, 51.972157205854145, 48.37804862431118, 46.283590589250835, 42.16672733851841, 46.09046540941511, 46.40571212768555, 47.67236178261893, 45.72570582798549, 43.32018736430577, 39.08665691103254, 43.56092160088675, 49.8452684538705, 53.52954728262765, 49.47079529081072, 53.82995959690639, 46.206097330365864, 53.21155602591378, 31.58288730893816, 38.1801358631679, 56.45417955943516, 46.786473410470144, 47.051627090999055, 45.2756918498448, 43.99624013900757, 40.65649468558175, 37.70820379257202, 37.3024776322501, 38.335963112967356, 36.94879347937447, 37.941819599696565, 39.28414555958339, 49.400302342006135, 52.111906324114116, 52.564984457833425, 48.21592630658831, 41.096878460475374, 38.478644371032715, 38.711356912340435, 39.417797633579795, 46.02431508472988, 53.18643133980887, 50.32605252947126, 46.36863306590489, 51.56440911974226, 50.61338833400181, 46.92369685854231, 44.023959977286204, 44.76056282860892, 45.61504186902727, 43.80979912621634, 41.35035916737148, 40.98977197919573, 41.89407655170986, 44.70839922768729, 49.99071856907436, 52.410439150674, 55.102553435734336, 56.9111521584647, 57.42692041397095, 53.81615700040545, 56.118550300598145, 55.27684204918997, 54.91044616699219, 53.87935086659023, 55.70499004636492, 58.27459716796875, 51.90637860979353, 15.583544867379324, 1.3097998137984956, 3.8114091498511176, 6.728771873882838, 3.826788987432207, 0.272142048392977, 0.10020017544073717, 0.32799313430275234, 24.006686210632324, 39.39830098833357, 28.815296479633876, 43.50441884994507, 42.27802358354841, 29.15262978417533, 43.01456390108381, 49.532762799944194, 58.555429458618164, 40.12961973462786, 1.7098040240151542, 0.10595833895994083, 0.0288803367210286, 0.047160789370536804, 0.02280176048433142, 0.029951638342546563, 0.067609717803342, 0.046379089887653074, 0.058827384774174006, 0.03854668213586722, 0.02863436099141836, 0.023203012167609165, 0.017810494206579666, 0.04614067643082567, 0.06108560359903744, 0.04206184297800064, 0.030891762181584324, 0.01671372546947428, 0.039393361524811814, 0.02482454801377441, 0.08308604306408338, 0.20676006962146076, 0.11030006741306611, 0.1897604332438537, 0.08081435531909976, 0.09046325220593385, 0.22088530952376978, 0.11672871852559702, 0.08701233845204115, 0.10011588103537049, 0.1215440101389374, 0.18455716887755053, 0.10891439712473325, 0.13629686779209546, 0.13415034940200193, 0.24103564183626855, 0.20289434705461773, 0.23255894812090055, 0.17032640320914133, 0.3385104813746044, 36.6128237588065, 75.71807057516915, 66.51736327580043, 64.01107856205532, 48.11429500579834, 32.936208793095176, 25.53031846455165, 46.424986430576865, 53.767398016793386, 32.76942423411778, 0.7115394505006927, 0.11622719972261361, 0.5265514797398022, 0.9705976609672818, 4.603222821440015, 9.042878099850245, 5.247160153729575, 8.578742776598249, 55.23870686122349, 66.22820009504045, 62.3533148084368, 61.430330004010884, 55.24128811700003, 51.376300539289204, 49.53872088023594, 50.306364808763774, 50.99995483670916, 56.98734263011387, 57.325233527592246, 58.79052175794329, 53.29588631221226, 57.92244161878313, 55.48477384022304, 58.49197850908552, 57.198904854910715, 56.560858726501465, 57.1359680720738, 53.227623735155376, 51.246053082602366, 53.645286900656565, 51.900417055402485, 52.37990876606533, 54.812789235796245, 55.113555908203125, 50.79898861476353, 49.71830749511719, 52.12493072237287, 54.64822115216936, 54.90652390888759, 50.95327683857509, 49.92211553028652, 53.20528875078474, 50.394381114414756, 48.235912799835205, 44.97252457482474, 48.274756704057964, 49.334839888981406, 49.974550110953196, 47.95764439446585, 45.761231967381065, 40.68896014349801, 46.0605013029916, 50.97551454816546, 56.61464473179409, 51.354073251996724, 55.18077278137207, 48.41047239303589, 54.8664744922093, 33.85892609187535, 41.93110350200108, 58.558611733572825, 50.37509291512625, 48.28884417670113, 48.621888705662315, 45.433832849775044, 42.745915276663645, 41.27628442219326, 39.81361566271101, 40.68652479989188, 39.04688194819859, 40.828664098467144, 41.916203090122764, 50.70083488736834, 54.831886359623496, 55.0208078793117, 50.611401149204795, 43.614158698490684, 40.8637490272522, 42.71478387287685, 42.23984670639038, 48.60436187471662, 56.59120150974819, 52.89253990990775, 47.288157667432515, 53.029381207057405, 53.20567784990583, 49.47057294845581, 47.50169665472848, 46.90551689692906, 48.96814523424421, 46.24778304781233, 43.2728180204119, 42.08863306045532, 44.08488525663103, 46.48481042044503, 53.057080200740266, 53.39545052392142, 57.713450227464946, 59.735025133405415, 57.85871621540615, 56.84201758248465, 58.84309182848249, 56.49357237134661, 57.429345335279194, 55.84453419276646, 58.95819568634033, 58.48373794555664, 53.86041007723127, 15.312083959579468, 5.084118068218231, 9.407907792500087, 13.880283440862383, 2.9412912343229567, 0.21254288431789192, 0.2115725249584232, 0.9226885288953781, 30.337363651820592, 52.34148522785732, 59.304334095546174, 49.850107874189106, 46.12873956135341, 35.26368856430054, 50.61764063153948, 56.3816681589399, 68.06244809286935, 45.56971182141985, 2.70253158892904, 0.27742105083806173, 0.11639414647860186, 0.12530656824154512, 0.09079650789499283, 0.2163848988711834, 0.16311624938888208, 0.15724020398088864, 0.1416282124285187, 0.17529950849711895, 0.07278577970074755, 0.2190683013094323, 0.1339312233030796, 0.15951774748308317, 0.16524481374238217, 0.146642749064735, 0.31589645626289503, 0.11357192256088768, 0.10568607678370816, 0.07137725635298661, 0.14935302148972238], [0.05158304635967527, 0.04923637031710573, 0.02563944991145815, 0.0444005258780505, 0.020748309957395707, 0.029758761370820657, 0.07067881311689105, 0.015963118157482574, 0.0666947608281459, 0.07947254553437233, 0.024427420127072504, 0.032742385020745654, 0.05177066129233156, 0.06093844970954316, 0.022381114573883157, 0.019787731680220792, 0.08718838436262948, 0.1125863775877016, 1.021590381860733, 35.57976906640189, 59.08996827261788, 56.42714064461844, 47.512337820870535, 32.400540896824424, 17.840210335595266, 31.87761947086879, 35.286617619650706, 35.560790061950684, 10.413355554853167, 0.01845907190415476, 0.07276680786162615, 0.201490743085742, 0.40205634438565796, 2.9890631394726888, 5.170648327895573, 1.002458842737334, 20.05641644341605, 60.70964200156075, 59.047869137355256, 56.33647012710571, 53.662556648254395, 44.72124992098127, 43.68128524507795, 42.40091984612601, 41.21280567986624, 41.55588688169207, 49.01614339011056, 51.205499921526226, 54.52415411812918, 52.262803827013286, 57.724973814828054, 53.0638164792742, 49.98722015108381, 47.848144258771626, 49.84223556518555, 50.989998068128315, 51.86269875935146, 48.089472566332134, 48.57053109577724, 50.93549639838082, 51.17519187927246, 51.409092562539236, 47.331948689052034, 43.631508350372314, 40.12749358585903, 44.552304472242085, 47.075080735342844, 49.22143486567906, 49.30904470171247, 50.99862425667899, 50.9514980997358, 45.42835072108677, 43.720125675201416, 42.27732528959002, 44.972753865378245, 44.4744325365339, 45.520820822034565, 40.02883611406599, 39.660828249795095, 36.49152558190482, 42.773277282714844, 48.75685746329171, 48.75898361206055, 47.631798199244905, 54.04280376434326, 47.91609416689192, 52.57913793836321, 31.039329733167374, 33.00407184873308, 54.75524078096662, 44.037922382354736, 46.55542843682425, 41.99161188943045, 44.758082321711946, 41.25477627345494, 40.00692844390869, 33.67000109808785, 37.821542807987754, 33.88116380146572, 35.65345818655831, 34.58292143685477, 42.720272949763704, 44.398669379098074, 44.18625947407314, 38.19629042489188, 38.01846865245274, 36.82404899597168, 36.804458550044465, 37.20316355569022, 43.87858976636614, 49.97171177182879, 51.58992290496826, 45.54909651620047, 50.020939758845735, 50.28576339994158, 46.02334928512573, 41.93276759556362, 41.19706801005772, 40.5084285736084, 40.802511078970774, 37.90816947392055, 39.25152376719883, 40.40375048773629, 43.934856278555735, 47.52260031018938, 52.1699481010437, 50.93222379684448, 53.2638829095023, 53.51322943823678, 54.822798115866526, 53.5897673198155, 52.63394185474941, 47.381016867501394, 47.653622491019114, 49.27796540941511, 56.276934487479075, 52.282842431749614, 38.575432777404785, 5.421222950731005, 2.553766097341265, 5.35264162506376, 5.275736357484545, 0.3490041611450059, 0.1298017134623868, 0.05336967656122787, 7.76794011252267, 42.870228971753804, 40.61396476200649, 22.873329060418264, 10.285114390509468, 22.97443403516497, 31.648016248430523, 45.82975162778582, 43.40643882751465, 46.76428781236921, 8.15517451081957, 0.11768822132476739, 0.020987600420734713, 0.016091625904664397, 0.07635276365493025, 0.048604077459978204, 0.045747390748666864, 0.05231672252661415, 0.05078145223004477, 0.025905976770445704, 0.03992891564433064, 0.01680138031952083, 0.05085452366620302, 0.004181280790362507, 0.07551769060747963, 0.01217869935291154, 0.037848751193710735, 0.056180914996990135, 0.028331478226131628, 0.04178350791335106, 0.04412886081263423, 0.03532229390527521, 0.04665621715996947, 0.021937065990641713, 0.06751272122242621, 0.01479819736310414, 0.03011907703642334, 0.03125048328989318, 0.014264124146263515, 0.03180414750905974, 0.04710682887317879, 0.013651554605790546, 0.03954496321135333, 0.05462309358907597, 0.011653834704442747, 0.006189693131351045, 0.04903399385511875, 0.033586187421211174, 0.09223238298935549, 1.7118446230888367, 46.43804209572928, 67.03024455479213, 61.590770857674734, 54.85364464351109, 40.671954427446636, 20.469526801790508, 21.81254758153643, 31.633112362452916, 41.41967439651489, 12.235313057899475, 0.015437831969133444, 0.09357865074915545, 0.3577955322606223, 1.1528929876429694, 5.035871948514666, 3.7420361638069153, 0.11640398523637227, 21.023829766682216, 62.80797018323626, 61.0694614137922, 59.8620034626552, 55.1200316292899, 47.310673304966514, 45.85578652790615, 44.477357728140696, 42.98229646682739, 44.647237709590364, 51.272497926439556, 54.38355384554182, 55.78188228607178, 53.73701354435512, 56.99130310331072, 55.80164296286446, 51.00223731994629, 50.17600965499878, 51.69143608638218, 53.567633833204, 53.84749685014997, 49.89549698148455, 51.09460667201451, 51.11229331152779, 53.85063396181379, 53.53546019962856, 50.2350241797311, 44.82203701564244, 42.17162234442574, 46.42942632947649, 50.61369405473982, 51.90904671805245, 50.06299025671822, 51.83003527777535, 52.44209166935512, 47.238908835819785, 46.147159235818044, 45.38463265555245, 46.23615871156965, 47.226176261901855, 47.10059104646955, 41.842166560036794, 40.82515525817871, 38.53818695885794, 44.81027718952724, 49.70038461685181, 51.933688504355295, 50.46009022848946, 55.51418209075928, 49.85835191181728, 52.052950859069824, 33.09574638094221, 35.65319415501186, 56.46377502168928, 45.866629191807334, 47.999847752707346, 44.843121324266704, 46.170699732644216, 43.22606359209333, 42.52161005565098, 36.74876179013933, 40.216527802603586, 36.6511743409293, 37.85151733670916, 36.834061350141255, 45.008478028433665, 46.04449265343802, 47.43061310904366, 40.599647998809814, 40.20381954738072, 37.898702553340364, 38.06806141989571, 39.406770842415945, 45.82597180775234, 53.23146608897618, 53.112391335623606, 45.51085710525513, 51.30225011280605, 50.57666015625, 47.95421893256051, 43.58259998049055, 43.40298209871565, 42.57576778956822, 42.87249755859375, 39.648300647735596, 41.18576676504952, 42.97572694505964, 45.64490870067051, 50.561367171151296, 53.398500783102854, 52.401482922690256, 55.610574449811665, 55.39128582818167, 56.16779913221087, 55.234242643628804, 54.132209709712434, 49.311817032950266, 50.27050862993513, 52.25721400124686, 59.13397816249302, 55.57938746043614, 42.191803387233186, 7.422641566821507, 2.8585711930479323, 5.189324217183249, 9.242957557950701, 1.2787187844514847, 0.2582359074481896, 0.03236380658511605, 7.865490215165274, 46.54130274908883, 37.76487330027989, 24.046511547906057, 18.023974554879324, 30.415145260947092, 37.739213602883474, 51.5108767236982, 48.65032420839582, 56.0147511618478, 13.460462859698705, 0.08427665489060537, 0.017895343314324106, 0.05141353474131652, 0.02351047165159668, 0.037434264684894254, 0.004492037954540657, 0.032639230734535625, 0.00984957446676812, 0.025517520561282123, 0.026321667678920285, 0.06533030154449598, 0.011834294485327388, 0.04765606904402375, 0.021754249996904815, 0.005300584947690368, 0.02171767526306212, 0.07735759259334632, 0.023994175517665486, 0.11059146427682467, 0.04833990342116781, 0.1061000374278852, 0.12911492745791162, 0.11727928183972836, 0.19628039481384413, 0.0980579928894128, 0.1361360414219754, 0.13206384064895765, 0.06583395094743796, 0.19051291500883444, 0.1490373941404479, 0.15396601467260293, 0.10600802129400627, 0.1930572720510619, 0.1594504096678325, 0.050692686278905184, 0.10789851485086338, 0.15613739458577974, 0.18366866798273154, 2.464276339326586, 57.97543552943638, 73.22650214603969, 72.01685551234654, 62.88895838601248, 46.5560051373073, 25.325516836983816, 43.89503615243094, 46.02487094061715, 50.14327669143677, 15.281610897609166, 0.16838248180491583, 0.2456027524811881, 0.4602764131767409, 1.2500422660793578, 8.706886666161672, 15.085176638194493, 4.302077037947519, 22.929418393543788, 63.139135224478586, 63.1175263268607, 61.268423080444336, 57.64479160308838, 49.750675678253174, 48.18639298847744, 46.26275641577584, 44.03460809162685, 46.19207239151001, 52.80781010219029, 56.665707043239046, 58.64308793204171, 53.622236251831055, 57.3802250453404, 58.08822911126273, 52.65222256524222, 51.280043670109336, 54.509125164576936, 54.46902363640921, 56.76057079860142, 52.71367590767996, 51.918847152165, 53.28682933534895, 56.33899232319423, 55.759481293814524, 52.01095942088536, 47.39428097861153, 43.93065956660679, 49.47192437308175, 53.41985954557146, 52.97556046077183, 51.25541230610439, 53.480256761823384, 55.16331195831299, 48.81229019165039, 48.585514886038645, 48.17475822993687, 48.03048236029488, 50.52120658329555, 49.42835916791643, 44.35286685398647, 43.661684376852854, 39.97420937674386, 46.90694127764021, 52.67398432322911, 56.13588605608259, 51.238875593457905, 57.79112761361258, 52.137055328914094, 52.66994047164917, 35.168185574667795, 36.689809799194336, 58.355696541922434, 48.519468784332275, 50.51182998929705, 48.59301546641758, 47.46387413569859, 45.512510776519775, 45.30595472880772, 38.74624381746565, 42.93447896412441, 38.297039304460796, 39.49915756498064, 38.33933993748256, 46.053080626896445, 48.00691407067435, 49.344348498753135, 42.3781019619533, 43.32560348510742, 40.58119705745152, 39.625798906598774, 41.949245248522075, 49.5258458682469, 57.55417667116438, 55.37731647491455, 47.25462218693325, 54.3774151120867, 54.327186584472656, 50.988083839416504, 46.10219744273594, 45.02956928525652, 44.57736662455967, 45.241562298366, 41.61784744262695, 43.3604348046439, 45.79987437384469, 49.19751569202968, 52.837273938315256, 56.93755531311035, 54.664215905325754, 57.14037670407976, 58.746629987444194, 57.74631520680019, 57.09594644818987, 56.96867976869856, 53.2769524710519, 52.7650647844587, 53.32650702340262, 62.45763506208147, 55.52726902280535, 44.6741168158395, 9.080958570752825, 8.126005973134722, 14.171098555837359, 11.604552984237671, 0.9003099011523383, 0.2965397520789078, 0.11911246632891041, 9.684088264192853, 57.68208953312465, 53.839694023132324, 32.57361010142735, 17.028509616851807, 32.743094035557334, 41.978306089128765, 59.27736813681466, 54.317556381225586, 64.71101924351284, 15.80351093837193, 0.40952850771801813, 0.16106483446700232, 0.15873759506004198, 0.1591528042086533, 0.18983621203473636, 0.14758082372801645, 0.11677774946604456, 0.11141951448683228, 0.09127004391380719, 0.09775579374815736, 0.1340266660388027, 0.14938920097691671, 0.09539606608450413, 0.11691398572708879, 0.04100238857790828, 0.1404734001095806, 0.137512422565903, 0.17268619872629642, 0.20152053077306065, 0.16408644589994634], [0.06293645714010511, 0.020813213528266976, 0.07817180068897349, 0.028925713750400713, 0.01820579344140632, 0.018067962623068264, 0.05756127914147718, 0.03652108207877193, 0.040476751247687, 0.04489581912223782, 0.10597794183662959, 0.0450640109899853, 0.03980521531775594, 0.07267248470868383, 0.06028692716998713, 0.03177229368260928, 0.04009076999500394, 0.10286582740289824, 9.20980509689876, 46.077048437935964, 54.06657007762364, 49.40304340635027, 37.193078245435444, 25.327868802206858, 19.541718210492814, 47.08170236860003, 40.40475450243269, 28.062669345310756, 2.182309538125992, 0.05187287241486566, 0.05135065829381347, 0.26640693470835686, 0.26035065682871, 4.913629685129438, 0.3794269843825272, 2.9028618335723877, 33.982246194567, 61.677776200430735, 57.308863571711946, 53.037913594927105, 53.64084700175694, 49.56464808327811, 45.73590578351702, 41.5968291418893, 41.54993574959891, 40.98867416381836, 44.53307185854231, 52.24292850494385, 53.12724311011178, 53.50356101989746, 53.22071722575596, 54.362994125911165, 48.42269427435738, 46.10723488671439, 46.285657678331646, 48.43235227039882, 51.33538954598563, 51.122552326747346, 50.83571679251534, 49.01111636843, 49.376018387930735, 49.129798548562185, 47.08588171005249, 39.675534112112864, 36.032572746276855, 42.71810858590262, 46.92507607596261, 50.334595339638845, 47.33330706187657, 51.61485651561192, 49.32227407182966, 45.39720542090279, 43.80703026907784, 44.61805527550833, 44.33894266401018, 44.09148257119315, 43.75809758050101, 38.34896319253104, 37.73030948638916, 35.69528634207589, 44.86360461371285, 45.96087455749512, 49.15813330241612, 49.591520241328645, 53.37982055119106, 48.30411631720406, 54.93936456952776, 33.23823308944702, 33.07891436985561, 55.79129709516253, 43.93468257359096, 46.79800394603184, 40.27699102674212, 44.89392307826451, 40.845242500305176, 42.202343804495676, 35.81122745786394, 35.23665312358311, 34.748396260397776, 36.857386452811106, 34.25054393495832, 37.828800201416016, 38.6568135534014, 40.129505089351106, 36.49481207983834, 37.73448187964303, 35.0053962298802, 37.986729281289236, 35.568936824798584, 41.29612152917044, 48.06764480045864, 50.20236069815499, 46.78899908065796, 50.175259249550955, 50.41199827194214, 48.92366981506348, 42.01141078131539, 39.44113315854754, 39.5652106148856, 39.071575845990864, 38.545343603406636, 38.89514718736921, 39.42657320840018, 41.77540479387556, 46.390377453395296, 52.177976744515554, 52.13908767700195, 53.09847756794521, 51.749397959027974, 52.12223482131958, 50.976706164223806, 48.73145137514387, 45.18456622532436, 46.165432998112266, 51.17344440732683, 55.05768544333321, 54.71108497892107, 46.38380445752825, 20.335534266063146, 6.558707330908094, 2.9772965822901045, 8.251741443361555, 2.6760680718081336, 0.22645198367536068, 0.08620544496391501, 0.3142828457057476, 22.616888420922415, 30.650105544498988, 36.67942919049944, 17.799071788787842, 14.941666807447161, 28.781639405659266, 39.12517772402082, 39.90899705886841, 50.1839861869812, 26.835301331111364, 0.344843574400459, 0.06270544310765606, 0.01564151461103133, 0.03780904671709452, 0.04624246346897312, 0.05211880403969969, 0.05114760668948293, 0.021130401508084366, 0.09136336962027208, 0.014737424374158894, 0.028136906613196646, 0.07506052763866526, 0.008329877397045493, 0.04029490386268922, 0.021245728712528944, 0.06268508705709662, 0.047260255818920474, 0.015184246469289064, 0.03630750300362706, 0.0841131347364613, 0.08318270037748984, 0.04827539170426982, 0.0737793246018035, 0.04987371147477201, 0.0266981324779668, 0.016272964388398186, 0.08277723499174629, 0.04065141633951238, 0.008955470569032644, 0.012051533408729094, 0.059645731933414936, 0.013577752896318478, 0.08573727615709816, 0.08919597949300494, 0.06319862950061049, 0.029160700605383942, 0.12836302923304693, 0.060890884404735904, 12.12694547857557, 58.77927262442452, 61.39936188289097, 55.55092763900757, 42.095949513571604, 32.83701283591134, 22.143564973558696, 39.57478870664324, 37.0024995803833, 37.044709886823384, 2.0241285860538483, 0.03061314213222691, 0.37822092909898075, 0.3873913570174149, 2.7613841337817053, 6.732703685760498, 1.2812535741499491, 3.272451932941164, 37.320136478969026, 62.764516149248394, 61.04402405875069, 56.66836125510079, 57.2684702192034, 51.961418764931814, 47.962414332798545, 43.06155456815447, 42.947413035801475, 43.41733012880598, 46.453199590955464, 53.43453414099557, 54.43124975476946, 54.248942920139854, 53.23442254747663, 56.45824425561087, 50.4455372265407, 47.874304226466585, 48.37054804393223, 50.07389545440674, 52.858177593776155, 53.918250356401714, 51.94954081944057, 48.43926920209612, 50.92740869522095, 53.4969984463283, 48.85776615142822, 41.80169677734375, 38.08811739512852, 44.810596806662424, 48.002891063690186, 51.67308241980416, 48.57981736319405, 50.66948808942522, 50.71262945447649, 47.45530700683594, 47.24115310396467, 46.01046732493809, 46.2621762411935, 46.114711148398264, 47.03692470278059, 40.525198050907676, 39.953705242701936, 39.168148858206614, 46.48658568518502, 47.82728924070086, 51.68869849613735, 51.15345791407994, 55.35830272947039, 50.60196896961757, 55.82379034587315, 34.51256397792271, 35.80382762636457, 57.17924492699759, 46.93505368913923, 48.82683277130127, 42.418384143284385, 47.7009779385158, 42.40935148511614, 44.52889946528843, 37.56690175192696, 36.66190235955374, 36.21181889942714, 39.289068358285085, 36.047646863119944, 39.710084029606406, 40.042826311928884, 40.753623553684776, 38.47779669080462, 39.90312583105904, 38.04933949879238, 39.21276324135916, 37.26485661097935, 42.76340389251709, 49.42086900983538, 52.933176449366975, 47.735857895442415, 52.382066181727815, 51.970826625823975, 50.914346081869944, 43.01164218357631, 40.70382581438337, 41.19982297079903, 41.40359626497541, 41.507013252803254, 41.11774737494332, 41.73205845696585, 43.87699515478951, 49.25443533488682, 53.500476019723074, 54.40893908909389, 55.01312664576939, 53.74335030147007, 55.71371003559658, 53.294194425855366, 50.35267455237252, 48.635121549878804, 48.11105019705636, 53.614971910204204, 56.722869873046875, 57.661529813494, 47.63578299113682, 22.3431293964386, 5.844358691147395, 0.9675665093319756, 8.385263238634382, 6.558688657624381, 0.44698646345308846, 0.086878870613873, 0.2793125621974468, 26.91288317952837, 33.87403842381069, 34.220121247427805, 21.747076443263463, 22.136114767619542, 36.64244392939976, 42.94516181945801, 45.455768312726704, 56.66153812408447, 37.34353453772408, 0.5466839394399098, 0.12013949693313666, 0.02436463867447206, 0.04434802083830748, 0.02914956584572792, 0.05862112369920526, 0.0011510245032176109, 0.007158161074455295, 0.047983757353254726, 0.05804554279893637, 0.012386325131436544, 0.02296893115687583, 0.04434603273070284, 0.03192786819168499, 0.05033240454005344, 0.01893593104822295, 0.024808325937816074, 0.04817245115659066, 0.04450565470116479, 0.02628133386107428, 0.1383435329688447, 0.12704698342297757, 0.14975451066025666, 0.1230155626045806, 0.1376354002526828, 0.06482057925313711, 0.21041392641408102, 0.16430498845875263, 0.13462566318256514, 0.17624150509280817, 0.16307689435780048, 0.1226956197725875, 0.1465161887130567, 0.13781863184911863, 0.10289385768451861, 0.10231865676386015, 0.17419796117714473, 0.20349757825689657, 15.113495758601598, 69.17097759246826, 69.1837066922869, 66.3711245400565, 51.13012933731079, 36.056950501033235, 29.837048189980642, 61.746632848467144, 55.57440907614571, 41.63652767453875, 3.3141472041606903, 0.180289875715971, 0.4892380791051047, 0.45457297350679127, 4.277688426630838, 15.171311719076973, 5.212142535618373, 5.311114413397653, 38.32472440174648, 63.23215075901577, 60.31015532357352, 58.37306703839983, 56.834044524601524, 55.7731796673366, 49.42614964076451, 46.2735469681876, 46.34077773775373, 46.108912876674104, 48.90075813020979, 58.452227864946636, 56.09976584570748, 54.925902434757774, 54.14113119670323, 58.523273195539204, 52.049966607775005, 50.27131462097168, 50.791877133505686, 53.65989201409476, 55.59923151561192, 55.13382380349295, 53.76620292663574, 52.30096680777413, 52.535784653254915, 55.088764735630576, 51.54586090360369, 43.01645728519985, 38.83253696986607, 47.57887029647827, 50.54458727155413, 53.19364704404558, 48.71389675140381, 52.02318477630615, 53.35753420421055, 49.411065101623535, 48.99524320874895, 48.61726120540074, 48.591636248997276, 48.223409516470774, 49.54966081891741, 43.21649244853428, 42.035305636269705, 40.938504695892334, 49.49810518537249, 50.49767303466797, 53.879851136888774, 53.021310874394004, 57.62603146689278, 52.79552221298218, 56.44284009933472, 36.87699774333409, 38.00570828574044, 58.86502034323556, 48.07851178305489, 52.14646666390555, 44.815846170697895, 49.15593419756208, 45.58023486818586, 46.369119439806255, 39.44747338976179, 39.28633771623884, 38.99939448492867, 41.85265139171055, 38.88609021050589, 42.0741981778826, 42.37678875241961, 43.78745371954781, 41.2611859866551, 41.62348590578352, 38.510870116097585, 42.35931750706264, 39.871897152491975, 44.927597522735596, 53.12608276094709, 54.49345350265503, 49.82912084034511, 53.77869231360299, 53.86232778004238, 54.519304275512695, 46.6397830418178, 43.73878158841814, 43.90916531426566, 43.075398853846956, 43.62138829912458, 42.894360065460205, 43.466797828674316, 47.468074321746826, 50.977612904139924, 56.14201436723982, 56.83011531829834, 58.37014879499163, 55.43421527317592, 58.01498467581612, 56.03184025628226, 52.185136863163535, 51.18318230765206, 51.451288972582134, 55.81383010319301, 60.04209382193429, 58.091084820883616, 49.27751725060599, 24.180627414158412, 10.073200413158961, 9.308623245784215, 14.267622062138148, 7.591454131262643, 0.34814527151840075, 0.24783942103385925, 0.5540355678115572, 31.33533341544015, 44.02354655947004, 50.02484117235456, 25.419353996004375, 23.25284140450614, 40.1730911391122, 51.0155257497515, 52.557668004717144, 63.55088547297886, 47.24224397114345, 0.8490076597247804, 0.2020329332777432, 0.07054837154490606, 0.08718144973473889, 0.11237555675740753, 0.09173403973025934, 0.11456094841871943, 0.08276359643787146, 0.16918265101100716, 0.24443268669503077, 0.10627452949328081, 0.1281569038650819, 0.10524459475917475, 0.10666573207293238, 0.09353681906525578, 0.17681918266628469, 0.13289393324937138, 0.10518696678004094, 0.1230092386582068, 0.16749313952667372], [0.06365369579621724, 0.009151705440932086, 0.06240842118859291, 0.048001599431570084, 0.0284164342031415, 0.07497242665184395, 0.07078503777406045, 0.019089183271197335, 0.037560614690716775, 0.005082152650824615, 0.021750253425644975, 0.004880245650253657, 0.09084182046353817, 0.016242618606026684, 0.044099032413214445, 0.0607148249234472, 0.014862653100863099, 0.053231475941304646, 23.94462490081787, 59.93185370309012, 54.933726106371196, 46.76668494088309, 34.13736472811018, 17.92144172532218, 13.134557604789734, 26.422058956963674, 35.656317370278494, 16.616630826677593, 0.35741785966924255, 0.027051499944978526, 0.04745434397565467, 0.23427208619458334, 2.2283632840429033, 2.7033380142280032, 2.3641907955918993, 10.37315501485552, 56.291056701115195, 51.07548870359148, 62.649335861206055, 55.70352745056152, 55.68715054648263, 51.604013851710725, 49.2765097618103, 45.98688513892037, 41.9723619052342, 38.449402877262656, 42.59682777949742, 48.49585880552019, 52.63012381962368, 52.031084878104075, 51.191151891435894, 49.62497581754412, 47.58412660871233, 41.34930998938424, 43.13341978618077, 43.80622427804129, 47.629053660801475, 48.59219557898385, 49.925259590148926, 48.90158496584211, 52.21416643687657, 51.592379093170166, 45.09949942997524, 38.1782876423427, 38.533260686056956, 40.15293094090053, 48.94127655029297, 50.347637108394075, 48.68602752685547, 47.99521330424717, 52.52543878555298, 45.661907468523296, 47.597779818943565, 44.22405767440796, 44.91003247669765, 43.02651480266026, 41.81944247654506, 36.47454765864781, 36.99388728822981, 36.815134457179475, 45.299204553876606, 42.869732175554546, 48.80253144672939, 46.94049412863595, 50.84453753062657, 46.47859525680542, 55.99765164511544, 31.747656890324183, 32.98227882385254, 56.84257691247122, 43.491731439317974, 45.46506152834211, 40.841844831194194, 43.23091343470982, 42.31391797746931, 44.16330262592861, 39.09011363983154, 36.614098753247944, 34.52037027903965, 35.8996502331325, 34.546123777117046, 37.21482610702515, 35.2385847227914, 36.45359883989607, 36.279254640851704, 38.00986678259713, 37.36904832295009, 38.32277543204171, 36.34888253893171, 38.8814731325422, 44.74646840776716, 51.562244755881174, 49.20005873271397, 48.97687217167446, 50.60928889683315, 47.844010080610005, 42.08655207497733, 38.99823066166469, 38.56887715203421, 37.48965515409197, 37.91281434467861, 39.83883762359619, 39.055984088352744, 39.69661842073713, 40.72002901349749, 47.485198157174246, 51.62249605996268, 53.14480120795113, 51.32765620095389, 51.11269283294678, 48.44978182656424, 43.59162221636091, 42.93404122761318, 50.38047776903425, 50.671145234789165, 55.20712382452828, 56.70253596987043, 51.86213248116629, 36.319470814296174, 12.045066169330052, 2.6112943589687347, 6.978449744837625, 3.839216274874551, 0.5052083507180214, 0.035001815030617375, 0.0839772309575762, 6.53614262172154, 38.660155636923655, 34.247604846954346, 29.34268386023385, 12.371497750282288, 20.5997725214277, 37.76016936983381, 43.5781774520874, 44.316913400377544, 42.7947541645595, 3.780568701880319, 0.32289391649620874, 0.08122040424495935, 0.10416100147579398, 0.01335455643545304, 0.024556377403704182, 0.012269798616346504, 0.01983506458678416, 0.022463066337097968, 0.023497040050902536, 0.054555094202182124, 0.08273398516965763, 0.06136241874524525, 0.02183459702480052, 0.035560513979622295, 0.014639119916994656, 0.01784856171746339, 0.03815462120941707, 0.01563785900361836, 0.029184205058429922, 0.01910012634471059, 0.0073069731339014, 0.05188238208315202, 0.05286732994552169, 0.0369464183625366, 0.037281309320990524, 0.033961705663906674, 0.03542137019602316, 0.05568769806995988, 0.014871845554028238, 0.015522596260000552, 0.01612840928802533, 0.06167938959385667, 0.03327271442062088, 0.008414699363389185, 0.01281833480710962, 0.0317812740935811, 0.19354101323655673, 32.15595041002546, 67.29240008762905, 61.439411299569265, 52.47644703728812, 39.179314613342285, 22.235022374561854, 13.95158498627799, 28.59546763556344, 39.380461488451274, 22.09097753252302, 0.26526411888854845, 0.05860043516648667, 0.24988436273166112, 0.9108452158314841, 3.10989448428154, 1.4841622518641608, 0.8198004184024674, 12.032427396093096, 58.30220236097063, 53.86124038696289, 63.53735038212368, 58.15270144598824, 58.02362128666469, 53.91028772081648, 52.22795861107962, 47.21892581667219, 44.09917075293404, 41.203773021698, 45.10802139554705, 50.62591593606131, 55.92495959145682, 53.92315925870623, 51.979265213012695, 52.506056785583496, 49.738971437726704, 43.93624939237322, 45.182794434683665, 46.376230921064106, 48.33166592461722, 49.742667879377095, 51.45695522853306, 49.99059002740042, 52.85155943461827, 52.66744259425572, 48.0074143409729, 41.180222102573936, 39.399405751909526, 43.60710975102016, 50.22457756314959, 52.61690487180437, 49.239270891462056, 49.35810245786394, 54.35705689021519, 48.48414761679513, 49.06901223318917, 46.88883427211216, 46.85564272744315, 46.40288421085903, 44.11121545519148, 38.66861506870815, 38.60091182163784, 38.500340121132986, 47.12339850834438, 45.24561309814453, 51.14948354448591, 49.55486501966204, 53.09896394184658, 48.583360944475444, 58.01914317267281, 33.6774982043675, 34.03548329217093, 57.93873514447893, 45.60405676705496, 49.01296806335449, 43.99379784720284, 45.81307595116751, 44.64163746152605, 45.48412043707711, 40.997401101248606, 38.98814882550921, 36.54773998260498, 36.9597612108503, 36.30358723231724, 38.41432837077549, 37.29590811048235, 37.38125283377511, 37.634452138628276, 39.90099273409162, 39.17506231580462, 39.79574489593506, 38.41061108452933, 41.39518894468035, 46.17222833633423, 53.59257786614554, 49.23870113917759, 49.10831124441964, 52.561708382197786, 50.119444370269775, 44.50513315200806, 41.77511991773333, 40.36685555321829, 39.82587228502546, 40.237664222717285, 40.40119007655552, 41.348896571568076, 41.78685542515346, 43.03422730309622, 48.47615024021694, 52.01147358758109, 54.58653851917812, 53.70549304144723, 53.16987378256661, 48.62992777143206, 46.09548895699637, 45.98033993584769, 50.20265599659511, 54.136086804526194, 56.299384117126465, 56.47115053449358, 51.70825072697231, 40.26204545157296, 12.832444718905858, 2.362823303256716, 4.4044192263058255, 9.045963968549456, 1.4141646879059928, 0.2988609660949026, 0.054408445821276734, 6.608077755996159, 42.61095346723284, 29.803682940346853, 25.75819332259042, 19.213620798928396, 27.626402378082275, 43.097890172685894, 49.16710342679705, 48.10416105815342, 54.41891322817121, 7.763025999069214, 0.5189142152667046, 0.07084166152136666, 0.07001532800495625, 0.012766204657964408, 0.037310662745897255, 0.010644976116184677, 0.010424768602076386, 0.023702310464744056, 0.00755427115862923, 0.06944161986133882, 0.06828187459281512, 0.041941277483212094, 0.032883493163223775, 0.014320008290399398, 0.010982202083271528, 0.03611928756747927, 0.036408804889236174, 0.04365798465109297, 0.01496897275293512, 0.19155528050448212, 0.16494651617748396, 0.14681924959378584, 0.10400999350739376, 0.1052392004057765, 0.18920767147626194, 0.13272822142711707, 0.12386405707470008, 0.18563244332160267, 0.0789572796119111, 0.12987234895782812, 0.07616209531469004, 0.14509339577385358, 0.13120045912052902, 0.08483884829495635, 0.17709933620478424, 0.10452437054898057, 0.47556554419653757, 38.82032551084246, 74.48896898542131, 69.45319952283586, 60.78658635275704, 47.62541280473982, 28.35967356818063, 20.92687460354396, 37.802362305777415, 48.58353117534092, 26.26368519238063, 0.8358702446733202, 0.1944027527102402, 0.4885447791644505, 1.4585723621504647, 6.505312596048627, 11.44835661138807, 6.09144184419087, 13.519892539296832, 59.646845545087544, 56.80899626868111, 64.26729338509696, 59.519985335213796, 59.023084912981304, 55.817491803850444, 53.600359848567415, 49.10299934659685, 46.55509492329189, 42.480528831481934, 46.33922134126936, 53.064216000693186, 58.33765207018171, 53.39370305197579, 54.97897277559553, 54.37000485828945, 51.437330041612896, 45.32711199351719, 45.939682551792686, 49.872032914842876, 49.306439127240864, 52.54976442881993, 54.0929628099714, 52.47316401345389, 56.23004109518868, 56.28187813077654, 48.933230536324636, 45.06363977704729, 42.60787194115775, 46.51913799558367, 53.01085730961391, 54.63192415237427, 50.93184164592198, 51.24266236168997, 56.493954522269114, 50.53696162360055, 51.67326307296753, 49.29172631672451, 49.604065213884624, 48.05280692236764, 47.05842590332031, 40.75239372253418, 40.4179630279541, 40.660128593444824, 49.319095270974294, 47.35155650547573, 53.14746584211077, 51.61918871743338, 55.56534515108381, 50.84751830782209, 58.652037211826865, 35.68189716339111, 36.146346024104524, 59.81873008183071, 47.54497350965227, 50.40474782671247, 45.479836872645784, 47.410894121442524, 47.627201965876985, 49.30636269705636, 43.87327439444405, 41.02100760596139, 39.260983739580425, 40.07629925864083, 38.969322681427, 40.96438673564366, 39.66991996765137, 40.12058012826102, 40.19371339253017, 42.90775966644287, 41.60673379898071, 42.74608203342983, 40.719049317496165, 43.107152121407644, 48.65944719314575, 56.73257303237915, 50.6818767275129, 51.853217942374094, 55.90458747318813, 52.06200436183384, 45.43028579439436, 43.57938643864223, 41.99452665873936, 42.767343521118164, 42.1499787058149, 43.35775974818638, 42.07944754191807, 45.18201276234218, 44.357723644801546, 51.55596358435494, 54.03555679321289, 57.9994033404759, 56.66479335512434, 55.706470012664795, 51.4925855909075, 47.72530358178275, 46.57762098312378, 54.15334612982613, 55.95592771257673, 59.99526991162981, 59.50524820600237, 55.12155328478132, 41.09775045939854, 16.954335859843663, 6.567430359976632, 15.851722751344953, 9.777161989893232, 0.845918099795069, 0.4158925147993224, 0.1752878919775997, 8.66385647228786, 51.72379037312099, 45.62751388549805, 40.1102933202471, 18.97182869911194, 30.172444684164866, 48.45993661880493, 58.29053633553641, 54.63057967594692, 62.65605476924351, 9.157039608274188, 0.6432033745305878, 0.16734132410160132, 0.2274130199636732, 0.10903996681528431, 0.20045943771089825, 0.06940515538943665, 0.06410449410655669, 0.13798447937837668, 0.09204223712107965, 0.1828994806855917, 0.13481520515467438, 0.08419660132910524, 0.110492506729705, 0.15597377265138285, 0.10297560758356537, 0.1610069011471101, 0.1792068795434066, 0.10683348628559283, 0.09381264355033636], [0.014276141001443778, 0.0411480157636106, 0.04293159934292946, 0.04698021423869899, 0.06602328257369143, 0.09731395888541426, 0.01595135236025921, 0.057062250562012196, 0.01895316074868398, 0.08969262641455446, 0.03089412348344922, 0.020400553974988203, 0.0680362449160644, 0.04184356165517654, 0.016535342005746703, 0.04704397617440138, 0.08156729848789317, 2.948998740741185, 41.64938531603132, 51.617708751133506, 55.889971937452046, 46.16553374699184, 29.03085044452122, 14.29895235810961, 24.818703072411672, 38.94364561353411, 30.258282729557582, 8.544343982424055, 0.03720796647082482, 0.06471828331372567, 0.18420969109450067, 0.4961009994149208, 2.633917259318488, 4.328288682869502, 4.267909271376474, 44.06619460242135, 57.12502465929304, 51.0860082762582, 49.23543201174055, 53.90041085651943, 54.87570864813668, 54.73202337537493, 50.87032576969692, 47.262525762830464, 43.382106236049104, 38.84656538282122, 40.00335012163435, 48.64905963625227, 51.67383629935128, 52.998795236860005, 51.27078866958618, 51.73266669682094, 45.92885725838797, 40.12512425013951, 41.960959911346436, 41.340457984379356, 43.13144302368164, 44.925968170166016, 46.71792248317173, 48.79040336608887, 49.19800901412964, 48.48643357413155, 43.01450831549508, 36.8291837147304, 36.21204124178205, 40.297460419791086, 48.70540605272566, 50.70788036073957, 47.38814571925572, 47.102925641196116, 51.0558739389692, 47.4211357661656, 48.322341442108154, 44.31445721217564, 47.16898563929966, 42.561822754996165, 38.640381063733784, 36.831702436719624, 37.242924622126985, 38.26791245596749, 44.43325751168387, 42.39574343817574, 46.786706175122944, 44.363049439021516, 49.961421489715576, 45.71673570360456, 56.484341689518516, 33.40054995673043, 32.33327886036464, 54.5773286819458, 42.911928585597444, 47.29821865899222, 41.05324029922485, 45.43467705590384, 41.318300179072786, 45.54753317151751, 40.5163425718035, 37.689325537000386, 35.277466842106406, 36.644187927246094, 34.23058523450579, 37.28625706263951, 35.04664421081543, 36.87180743898664, 35.762513637542725, 36.82758215495518, 35.88622631345476, 37.467931611197336, 35.62667982918875, 38.37675251279558, 44.05848905018398, 49.35017803737095, 48.77850457600185, 49.17641053880964, 48.45449617930821, 48.813929966517854, 43.68671873637608, 39.54173960004534, 38.81340857914516, 36.950572218213765, 38.139075483594624, 37.26757335662842, 37.771929195949006, 38.771031515938894, 40.2940662247794, 40.006115504673545, 40.20200606754848, 45.437949657440186, 45.21883821487427, 45.15614809308733, 43.41582236971174, 43.76396186011178, 48.93847642626081, 50.872250420706614, 53.82658972058977, 53.531440666743684, 52.164462498256135, 50.20966672897339, 48.95151472091675, 26.399032626833232, 3.1610241064003537, 2.9992333480290005, 6.1789808954511365, 0.8664579519203731, 0.08202214086694376, 0.045035682152956724, 0.281403942831925, 22.967513629368373, 44.89770637239729, 33.87628616605486, 20.19640006337847, 18.300460747310094, 24.633639539991105, 36.16401529312134, 41.47234869003296, 42.0220102582659, 14.787390742983137, 0.040199607011995146, 0.007417871201011751, 0.02238627483269998, 0.042034328382994444, 0.00811452989000827, 0.027980315997930508, 0.0699075630732945, 0.009883018609668528, 0.004052150911385459, 0.05788707773068121, 0.03529680134462459, 0.025711471314675043, 0.0201000155481909, 0.011013193322079522, 0.0669425211048552, 0.057596515464995585, 0.011661606474912592, 0.04608700431085058, 0.12902074679732323, 0.01968020253947803, 0.06733624104942594, 0.051665539254567454, 0.012033603969030082, 0.05299861290092979, 0.03231544739433697, 0.0022488815468802515, 0.03516093149249043, 0.05303580340530191, 0.05615255223321063, 0.03930906711944512, 0.055424979488764486, 0.02364397680919085, 0.019475817613835846, 0.012750453315675259, 0.05436406284570694, 0.0801876468051757, 3.9833110570907593, 52.87484284809658, 59.12003312792097, 61.422089440482004, 52.70476484298706, 37.28017738887242, 21.22053153174264, 22.989330972943986, 32.2599058832441, 37.70692532403128, 10.839300104549952, 0.01523042077730809, 0.037801399627434354, 0.6045222644295011, 4.3973194701331, 2.649927645921707, 1.4439115545579364, 4.983605861663818, 46.613108907427105, 56.61209126881191, 53.89146505083357, 52.22046150479998, 55.289637156895225, 56.0813044820513, 56.282764026096885, 52.3321190561567, 49.60985653741019, 45.028544425964355, 40.66438089098249, 42.208447796957834, 50.30615636280605, 54.57450423921858, 54.338755335126606, 52.802696228027344, 53.98319864273071, 47.63405636378697, 43.08431339263916, 44.47367518288748, 43.71778760637556, 45.87969527925764, 47.39467355183193, 49.44207143783569, 50.91021190370832, 50.97919361931937, 51.44687339237758, 45.18364211491176, 39.254459381103516, 37.98317527770996, 42.632482460566926, 51.22772026062012, 52.72368826184954, 49.183160713740754, 48.30840335573469, 51.99646895272391, 48.769993032727925, 50.60010685239519, 46.595967701503206, 49.574920994894846, 44.755355153764995, 41.22168895176479, 38.619063990456716, 39.57913133076259, 40.57848031180245, 44.93860346930367, 46.48801701409476, 48.636254106249126, 46.066716466631206, 52.523479393550325, 46.311108929770334, 57.809147766658235, 34.37917940957205, 33.68392876216343, 55.64634725025722, 44.90027025767735, 50.34096336364746, 43.30733667101179, 47.7134291103908, 42.41902685165405, 46.33661229269845, 40.16835246767317, 38.340204988207134, 37.43685579299927, 37.79943364007132, 36.11989770616804, 38.37972981589181, 37.437564509255544, 38.595068386622835, 37.53471074785505, 39.23470565250942, 37.66949885232108, 38.389641421181814, 37.637888022831504, 40.597136225019185, 46.42596960067749, 51.78870044435774, 49.90565872192383, 48.98782253265381, 49.76644114085606, 51.51217603683472, 46.341757433755056, 41.36943892070225, 41.75079427446638, 39.65514462334769, 40.40020343235561, 38.96114812578474, 40.04791586739676, 39.91187013898577, 41.665390491485596, 41.8629903112139, 41.85129649298531, 45.82030207770211, 46.74315486635481, 46.07078811100551, 46.02051094600132, 45.62645428521292, 50.23539243425642, 53.85697071892874, 55.57355792181832, 55.674143518720356, 53.13259669712612, 50.76490422657558, 50.857252734048025, 28.699768781661987, 3.9240051422800337, 1.8139093177659171, 11.70040946347373, 3.9124780808176314, 0.780953257211617, 0.019052825668560605, 0.15873152895697526, 25.21645096370152, 44.9011526788984, 31.838355200631277, 18.303901842662267, 26.780976840427943, 31.59259394236973, 40.99485458646502, 47.21262380055019, 52.46905762808663, 21.575893674577983, 0.08110333659819194, 0.03388081071898341, 0.04147977189027837, 0.05906164220401219, 0.019842628555904542, 0.021197608705343943, 0.054572213640702624, 0.03533590531774929, 0.008383427380717226, 0.0368961151689291, 0.027805376099422574, 0.06220243152763162, 0.026767285374392356, 0.025676226509468894, 0.04674612644261547, 0.06183654508952584, 0.01871825022889035, 0.0340131012988942, 0.0682193883029478, 0.0894292394763657, 0.11567887557404381, 0.1166897706155266, 0.039299560843833854, 0.15798747459692614, 0.11358691139944962, 0.12019509609256472, 0.1306770100657429, 0.09605698633406844, 0.14669036865234375, 0.14222811880920613, 0.17795716731676034, 0.14912583439477853, 0.07394403219223022, 0.062085309598062716, 0.15031157433986664, 0.1727213468402624, 5.363708368369511, 64.3432719366891, 68.8180091040475, 71.14122268131801, 58.61879702976772, 39.514756270817344, 22.80601838656834, 34.44192164284842, 52.604412010737825, 45.60831601279122, 13.797901255743843, 0.09359460989279406, 0.16025470436683723, 0.36282282535518917, 4.69820773601532, 13.448662212916783, 9.351819327899388, 6.651549594742911, 50.559119428907124, 57.254264627184185, 54.20272350311279, 55.063244002205984, 57.62778588703701, 59.11116027832031, 58.836011614118306, 53.65073776245117, 51.2329557282584, 47.24748986107962, 43.059285981314524, 44.62927661623274, 54.51197392599923, 54.9705411366054, 55.54943725040981, 53.6562511580331, 56.82543223244803, 49.75418451854161, 45.30384942463466, 47.46411732264927, 45.71135432379586, 47.168669496263774, 48.79341541017805, 51.8124737058367, 54.33123738425118, 53.49150936944144, 54.569855894361226, 46.81492280960083, 40.99946124213082, 39.85976559775216, 43.94289187022618, 54.07092659814017, 53.52086203438895, 48.82582875660488, 50.044598375047954, 54.42187663487026, 50.8082331929888, 52.212717737470356, 50.673538889203755, 52.02471685409546, 47.2471216065543, 42.552116121564595, 40.13784987585885, 41.298240729740684, 42.61705051149641, 48.53296913419451, 47.95036963054112, 50.83835015978132, 48.96872888292585, 54.47850445338658, 48.61546509606497, 59.903553690229145, 36.25945922306606, 37.340161187308176, 56.70435987200056, 47.79653303963797, 52.66486133847918, 45.27166189466204, 49.99743052891323, 45.164562361580984, 50.26065261023385, 43.753164359501426, 41.26807859965733, 39.93178020204817, 40.66111523764474, 36.99130603245327, 40.88017804282052, 40.0605650629316, 40.022964886256624, 39.21891587121146, 41.995697430201936, 40.321709632873535, 40.73268515723092, 39.65561015265328, 42.52286073139736, 48.55644709723336, 53.47360038757324, 52.98637185777937, 51.84003373554775, 51.86406755447388, 55.09352077756609, 48.09293276923043, 43.89573792048863, 44.36704812731062, 41.251541887010845, 42.90578637804304, 41.53285012926374, 41.618121896471294, 41.90482888902937, 42.994268212999614, 44.53665018081665, 44.104062284742085, 49.34451525551932, 48.64562375204903, 50.36807870864868, 48.32413060324532, 48.96904502596174, 52.593023913247244, 55.1541542325701, 57.01862342017037, 58.31878771100725, 54.21569231578282, 50.62066657202584, 52.18638753890991, 30.421645300728933, 5.101700484752655, 8.989165919167654, 12.09669736453465, 2.097467907837459, 0.31831768634063856, 0.14941660022096975, 0.5646895989775658, 30.7676134790693, 59.64375359671456, 45.00899566922869, 28.524774926049368, 26.318329300199235, 36.429130758558, 48.18382215499878, 54.8662417275565, 59.33774103437151, 28.49537362371172, 0.19630949039544376, 0.08649267562265907, 0.11671601635004793, 0.12278587850076811, 0.08989259068455015, 0.14578983054629394, 0.22170875248100075, 0.16564052179455757, 0.08780874857412917, 0.12324257328041963, 0.13653689276959213, 0.10324426673884902, 0.0829905392602086, 0.10955057798751763, 0.1905540342309645, 0.17816109423126492, 0.12519680841692857, 0.10685541653739554, 0.19699398295155593], [0.025783898142565573, 0.11902752731527601, 0.01795324101112783, 0.04424703447148204, 0.04363043952201094, 0.029283830962542976, 0.01569579401984811, 0.026178493397310376, 0.024325994408822486, 0.02365086054695504, 0.05069948859246714, 0.03744382524330701, 0.02501756408517914, 0.02561885637364217, 0.08524404905204262, 0.0774537410054888, 0.188398274193917, 12.857025708471026, 55.00805098669869, 53.22670309884207, 53.86963728496006, 32.91448872429984, 21.678911140986852, 11.258358120918274, 23.92390537261963, 38.34982476915632, 27.89397403172084, 4.1754096405846735, 0.116262944947396, 0.12950349732169084, 0.4690911801798003, 2.452479818037578, 1.6596366188355853, 0.7516587834273065, 28.20585608482361, 59.7494843346732, 59.28218323843819, 59.202452659606934, 54.014284883226665, 53.422795159476145, 51.845790318080354, 52.81713111060006, 53.14478383745466, 46.58090053285871, 42.19168874195644, 38.8604930468968, 38.8264399256025, 41.68710013798305, 51.416381222861155, 52.422157287597656, 52.34844732284546, 49.41279520307268, 45.25788014275687, 37.09800604411534, 38.45621906008039, 38.54204320907593, 39.83627373831612, 40.04990305219378, 43.08279173714774, 44.685244355882915, 46.53970466341291, 45.17967469351632, 39.676468644823345, 36.10048443930489, 37.33889661516462, 38.73681511197771, 50.5356171471732, 49.63539464133126, 44.87700074059622, 46.799567290714805, 49.47739955357143, 45.991658551352366, 44.8175311088562, 47.37608364650181, 45.983209541865754, 40.889669282095774, 39.022122042519705, 35.58231210708618, 37.88657447269985, 37.86933251789638, 42.49987609045846, 40.64182703835623, 43.21856301171439, 41.58604206357683, 47.82592739377703, 46.61086116518293, 55.26136841092791, 35.570489747183665, 31.430329186575754, 54.39395877293178, 44.376066889081685, 46.56358214787075, 40.82419293267386, 45.23758445467268, 42.63948277064732, 42.806986468178884, 40.3262676511492, 37.4761825970241, 34.293251037597656, 35.189596448625835, 33.836705752781455, 36.87410034452166, 35.373483998434885, 36.458365304129465, 35.94039446966988, 36.79394245147705, 35.704107080187114, 36.88156965800694, 37.854508536202566, 40.20976373127529, 44.647435733250205, 50.03345346450806, 49.079531805855886, 48.43634401048933, 47.02029766355242, 49.196195534297395, 43.93933091844831, 42.2065544128418, 39.95554304122925, 38.401863302503315, 37.55160181862967, 38.844762325286865, 36.912617683410645, 38.677560874394004, 39.42360632760184, 39.109648500170024, 37.315376962934224, 39.38561357770647, 38.19856595993042, 40.21670150756836, 37.787090165274485, 42.16603251865932, 48.256896359579905, 52.779603890010286, 53.8129643031529, 53.17186444146292, 52.85784060614449, 55.24378946849278, 50.815723351069856, 44.176358291081016, 15.374173062188284, 2.109744940485273, 4.380982518196106, 5.127150867666517, 0.6087398752570152, 0.1342630676392998, 0.04825710179284215, 6.705510607787541, 33.015657969883506, 30.48196608679635, 34.20589828491211, 11.066679903439113, 26.046534878867014, 34.61391387666975, 42.828543254307334, 43.20248488017491, 21.584769998277935, 2.9694381696837286, 0.09804526357246296, 0.013567823384489332, 0.03158807821039643, 0.0300477596132883, 0.08716430994016783, 0.06485114047037703, 0.021462322179494158, 0.04088970087468624, 0.03420514367254717, 0.05870930611022881, 0.05578609582568918, 0.04088779758395893, 0.02312822064517864, 0.07572116968887192, 0.04652803510959659, 0.025713919129754816, 0.05892993855689253, 0.03571778143356953, 0.049974260186510425, 0.010013969082917486, 0.021405243813725452, 0.022247577185875604, 0.0136659488780424, 0.032265941479376385, 0.009133712388575077, 0.009815541694739034, 0.07307230468307223, 0.025699403569368378, 0.029367609681295495, 0.0214248246380261, 0.0498720117445503, 0.06266194222761051, 0.06428037038339035, 0.05949901230633259, 0.17396843992173672, 16.87501175062997, 65.5069214957101, 59.32014124734061, 62.68675191061837, 39.90536315100533, 29.703427382877894, 14.841763871056692, 27.569284711565288, 41.69443048749651, 32.80605513708932, 3.7399647321019853, 0.13979747066540377, 0.05145624852074044, 1.12135902260031, 3.154460664306368, 2.536292029278619, 0.9555666446685791, 31.59500844138009, 61.65839072636196, 58.90279075077602, 60.19197341373989, 55.76058953148978, 55.39255734852382, 53.8503942489624, 54.500627517700195, 54.34156935555594, 49.7289034979684, 44.75333670207432, 40.79194981711251, 40.83189153671265, 44.58512428828648, 52.55028901781355, 53.438494614192415, 53.64132295336042, 51.39876753943307, 47.67196226119995, 38.1088855607169, 41.310823917388916, 40.39754922049386, 41.20297397886004, 42.01077849524361, 43.239407607487266, 47.00720725740705, 47.81974349703108, 47.896899768284385, 41.491664682115825, 38.025677408490864, 39.15710122244698, 41.92974860327584, 53.22843320029122, 51.537908690316335, 44.54010690961565, 48.77069827488491, 50.40322617122105, 47.912953581128804, 47.48607015609741, 46.77549178259713, 48.09668479646955, 42.52953100204468, 39.571147850581575, 37.286642687661306, 39.8820276260376, 40.21665287017822, 45.16114384787423, 43.24221120561872, 45.36865527289254, 43.009481293814524, 49.62763697760445, 48.02180058615548, 57.82514599391392, 37.55277606419155, 33.584725856781006, 55.40246895381382, 47.42062854766846, 47.543173926217214, 42.98672594342913, 47.0702691078186, 43.72462463378906, 44.48916966574532, 42.347898142678396, 40.05737236567906, 35.734411648341585, 37.34428494317191, 36.474280153002056, 39.19312415804182, 38.08816950661795, 36.92516960416521, 38.51326724461147, 38.18424572263445, 38.55964299610683, 38.27427353177752, 39.32788099561419, 42.14357941491263, 46.52533578872681, 53.179097516196116, 50.778411524636404, 49.92694452830723, 49.96015344347273, 51.98546300615583, 45.7367708342416, 44.16888550349644, 42.13547781535557, 40.334143434252056, 38.893535205296104, 41.613973821912495, 39.31520748138428, 40.33558865955898, 40.162349224090576, 40.63543469565255, 39.754615034375874, 40.77608013153076, 40.44987957818167, 42.12770972933088, 39.68102318899972, 42.220864227839876, 50.34525040217808, 55.38502550125122, 55.25571257727486, 53.794013091496055, 53.38076203210013, 55.59700461796352, 51.75676999773298, 46.43121549061367, 16.628397600991384, 2.1704346324716295, 6.94188745532717, 6.559892867292676, 2.7078124369893755, 0.14495003489511354, 0.11857441520052296, 6.5040775537490845, 38.583749771118164, 24.879967076437815, 31.045096737997874, 16.483442544937134, 32.53175067901611, 40.48958158493042, 47.82553482055664, 49.590036800929475, 31.74213307244437, 4.292992268289838, 0.11130295574132885, 0.003063595575180703, 0.059033957975251336, 0.048331269063055515, 0.016209372086450458, 0.020244889560022523, 0.010955544986895152, 0.05859992626522269, 0.03735177518267717, 0.03348906870399203, 0.04430139530450106, 0.024269843939691782, 0.04191418018724237, 0.09969394760472433, 0.018014329518856745, 0.02110519732481667, 0.03344529301726392, 0.03665568646309631, 0.13514618096607073, 0.18333075754344463, 0.13971593789756298, 0.12537873722612858, 0.17407731765082904, 0.11412887088954449, 0.09289797834519829, 0.10471241295869861, 0.12471100448497704, 0.07271654877279486, 0.12286346219480038, 0.15565849814031804, 0.11605559821639742, 0.1815708412655762, 0.1833821362150567, 0.1472160161605903, 0.3060787059366703, 19.446864877428325, 73.65710285731724, 67.82160963330949, 69.41001646859306, 46.28666169302804, 31.266990934099468, 16.093975169318064, 34.93971838269915, 54.27132306780134, 40.29839495250157, 5.801827464784894, 0.28220635120357784, 0.32577978021332193, 1.3612565440790994, 6.043157509395054, 8.42133481161935, 1.7512611023017337, 35.32862990243094, 63.874205998011995, 60.67283044542585, 61.137025696890696, 56.449020521981375, 58.26845496041434, 55.52449321746826, 57.424988814762656, 57.26292903082711, 51.68314688546317, 47.31565863745553, 42.286524704524446, 43.041578497205464, 45.780415943690706, 56.31900930404663, 54.83486366271973, 56.00319283349173, 53.34746626445225, 51.29120247704642, 40.242621762411936, 42.13367475782122, 42.38583878108433, 45.121473108019146, 44.7382938521249, 46.310566970280235, 49.76749031884329, 50.68379095622471, 50.375652245112825, 43.34098332268851, 39.83608266285488, 41.58650064468384, 43.109417234148296, 55.46088245936802, 54.69475323813302, 46.94627850396292, 51.73466430391584, 54.13974503108433, 51.02786922454834, 50.60828488213675, 51.11104610988072, 50.767933641161235, 45.19367183957781, 43.38589300428118, 39.530615534101216, 42.09017556054251, 41.633164746420725, 46.59647492000035, 44.4280880519322, 47.30717141287667, 45.02593537739345, 51.31361736570086, 50.748760087149485, 59.1844151360648, 41.16222626822335, 37.13858004978725, 58.48769841875349, 50.24856621878487, 50.515505586351665, 44.721562589917866, 49.274102210998535, 46.73331274305071, 45.71560314723423, 44.974278994968955, 41.18110799789429, 37.88384730475289, 39.28690052032471, 39.522656372615266, 41.53986086164202, 40.73647887366158, 39.48522990090506, 41.313891547066824, 39.89731018883841, 39.50434439522879, 39.9608862059457, 41.96067156110491, 45.05467660086495, 48.757805892399375, 54.803673199244905, 52.11174304144723, 51.455364091055735, 52.58184426171439, 54.92649303163801, 47.824551650456016, 47.07931218828474, 44.954789297921316, 42.47771481105259, 41.45961264201573, 44.85418633052281, 43.26567874635969, 42.88734585898263, 42.50341967173985, 42.56454644884382, 43.44247565950666, 42.85067326681954, 43.73634277071272, 44.28642470496041, 41.697272300720215, 44.7248386655535, 53.84036105019705, 56.28904867172241, 57.1131397656032, 57.14598042624337, 55.737615312848774, 58.046473911830354, 54.197109358651296, 47.402851581573486, 18.61151943887983, 5.607491995607104, 9.976472803524562, 12.64738552910941, 1.5517363058669227, 0.26814648136496544, 0.30477811715432573, 8.819648112569537, 45.390535150255474, 42.538473333631245, 47.77279451915196, 15.892612900052752, 38.62328502110073, 45.96944168635777, 56.977656841278076, 54.25903517859322, 43.82123933519636, 4.7534554685865125, 0.24965518074376242, 0.06879382926438536, 0.17518343829682895, 0.11010190804622003, 0.21270814830703394, 0.14977874793112278, 0.07821781214858804, 0.1697919618870531, 0.15504578101847852, 0.18845065709735664, 0.1218525128705161, 0.12553387747279235, 0.15622427420956747, 0.1462082423801933, 0.1011960409315569, 0.19854112421827658, 0.18646963339831146, 0.12680816623781407], [0.04112555964716843, 0.04640561382153204, 0.053110533859580755, 0.014315246670906032, 0.01343403069768101, 0.036413127157304964, 0.025791925211836184, 0.03232124547607132, 0.029626501324985708, 0.026630502892658114, 0.032679186269108734, 0.07737790114645447, 0.053051022945770195, 0.08262985040034566, 0.027272902528888414, 0.01897645994488682, 0.027251693220543008, 20.679018463407242, 60.82085486820766, 49.638427530016216, 41.091580459049766, 23.62819872583662, 16.36919331550598, 20.91423409325736, 35.535828658512656, 33.53747115816389, 27.965651648385183, 0.7219587085502488, 0.02615580488262432, 0.026920447691476772, 1.7650216839143207, 3.9129661917686462, 1.217229506799153, 12.624048267092023, 56.83994007110596, 60.01816422598702, 58.83651188441685, 57.439687728881836, 55.75263384410313, 53.86557953698294, 56.73448378699166, 52.43590777260916, 51.17088747024536, 50.729926994868684, 44.67732688358852, 39.60136209215437, 38.17358718599592, 37.987062794821604, 47.293841293879915, 52.965659277779714, 52.1040027482169, 50.129005091530935, 41.29980754852295, 36.84846496582031, 36.84222200938633, 35.949427127838135, 36.93761382784162, 36.90587445667812, 39.683587074279785, 38.15717206682478, 40.36065428597586, 40.25195666721889, 37.848074504307334, 36.38094500132969, 36.22572571890694, 39.05538306917463, 47.06229257583618, 47.13417169025966, 45.60493571417672, 46.49345745359148, 47.839834213256836, 44.257144996098106, 47.319344656808035, 45.17712817873274, 42.802758489336284, 36.309628690992085, 36.66725942066738, 34.967764786311555, 36.88362285069057, 37.634452138628276, 39.97393144880022, 39.00001287460327, 44.0408684185573, 42.36735309873308, 47.77463926587786, 44.98435388292585, 56.47576413835798, 36.65043435777937, 29.709111009325298, 54.16240658078875, 43.87905529567173, 45.4720653125218, 39.16818012510027, 41.32913589477539, 39.74062136241368, 42.82204321452549, 39.52615131650652, 38.426550252096995, 34.67060770307268, 36.06509378978184, 35.65667520250593, 35.656299999782014, 36.79949058805193, 36.734108039310996, 35.59285947254726, 35.38929115022932, 35.92784949711391, 38.50265734536307, 40.554748739515034, 44.5303863797869, 47.20637042181832, 50.19099344526018, 50.74256229400635, 51.76258563995361, 48.0499129976545, 48.33317020961216, 43.99407924924578, 41.37171792984009, 40.149981430598665, 39.3384804725647, 38.03573145185198, 38.13897473471505, 36.9684499331883, 36.04241139548165, 39.52336161477225, 38.23378637858799, 40.87013789585659, 40.252199854169575, 40.31049524034773, 38.758667196546284, 39.165380001068115, 41.99886233466012, 48.93483904429844, 52.324423926217214, 53.25687912532261, 52.70263869421822, 55.06860801151821, 52.33172648293631, 57.34743649618966, 52.350872244153706, 37.321508748190745, 5.3068912114415845, 9.067607607160296, 7.562450613294329, 5.613594685282026, 0.062121231241949966, 0.0407611999128546, 0.3430797904729843, 22.32233691215515, 43.58254439490182, 31.97562381199428, 28.317421572549, 16.75028463772365, 26.68359957422529, 37.64436026981899, 42.84170314243862, 35.974464961460654, 10.665083578654698, 0.09310157956289393, 0.032979838350521665, 0.017974648790966188, 0.029391721423183168, 0.0535479819934283, 0.044996150702770264, 0.03644454332866839, 0.0735305193811655, 0.04092507290520838, 0.06208696522350822, 0.03714511037937232, 0.025029540228258287, 0.015834237216040492, 0.06805174944124051, 0.04405702431020992, 0.051462752278894186, 0.005361148863032992, 0.006139393330418638, 0.048899453931621144, 0.05297218056927834, 0.05908397279147591, 0.06778577049928051, 0.0982623201395784, 0.0792750104197434, 0.04044496527473841, 0.05447691000465836, 0.028024968691170216, 0.022749370795541575, 0.050219499705625434, 0.015643699493791376, 0.0012839708236112657, 0.03416253845872624, 0.061271081146384986, 0.050481217447668314, 0.04041014285758138, 26.58534162385123, 68.25884587424142, 56.919337136404856, 46.02426644733974, 31.10482692718506, 20.58927205630711, 19.296606608799525, 31.141391822269984, 35.698249748774934, 31.61678409576416, 0.7368799107415336, 0.03619542598192181, 0.08476650967661824, 3.399891014610018, 4.284182386738913, 0.4582303858229092, 14.352746180125646, 60.68004962376186, 60.98328985486712, 62.8701148714338, 57.8084842136928, 58.07694523675101, 54.379708017621724, 59.227493967328755, 54.77073873792376, 53.50508614948818, 53.020873137882774, 46.05090931483677, 41.233841351100374, 40.555186476026265, 40.70596585954939, 49.024040017809185, 54.31045879636492, 54.62764058794294, 51.529306820460725, 43.604069914136616, 38.26267351422991, 38.057517528533936, 37.00825268881661, 39.192554405757356, 39.52272585460118, 42.501995291028706, 41.702528612954275, 41.95401518685477, 40.94630057471139, 39.890935216631206, 37.588163239615305, 37.981928076062886, 39.64638989312308, 50.36009522846767, 48.76587275096348, 48.082579953329905, 49.24128586905343, 49.94762931551252, 46.47950894492013, 50.01779569898333, 46.01616832188198, 43.76806477137974, 38.399924755096436, 39.14320135116577, 37.67929233823504, 38.53864206586565, 39.44759498323713, 42.54326064246041, 41.083940914699006, 46.553013937813894, 44.67302942276001, 51.74273811067854, 48.27390554973057, 56.97652428490775, 37.995612553187776, 31.106345108577184, 54.542858668736045, 46.66302476610456, 47.80136898585728, 41.39609568459647, 43.723606722695486, 42.30558361325945, 44.48101248059954, 40.932056767599924, 40.06405305862427, 37.253430298396516, 38.95465503420149, 37.50688321249825, 38.22044931139265, 37.70027242388044, 38.0832154410226, 37.389604568481445, 37.13219118118286, 37.28603819438389, 39.19271421432495, 42.66980818339756, 46.9583614213126, 47.692942346845356, 50.483564717429026, 51.69410072054182, 52.47083636692592, 49.821919032505576, 50.57478066853115, 46.22267573220389, 43.06630366189139, 42.26595803669521, 40.18492044721331, 40.152135372161865, 40.830140590667725, 37.65906613213675, 38.33502510615757, 40.93282454354422, 40.14594800131661, 42.99285078048706, 41.822666440691265, 41.28322914668492, 40.25160925728934, 41.209376743861604, 43.23000322069441, 50.609719685145784, 54.082842758723665, 55.27478190830776, 54.819459506443565, 56.51820720945086, 53.915696893419536, 59.35661928994315, 55.06637763977051, 40.327480111803325, 5.8493131910051614, 1.9798453279903956, 8.47297121797289, 6.008339651993342, 0.7545468455978802, 0.12589546878423008, 0.28596890930618557, 26.52931135041373, 45.167762007032124, 25.457885231290543, 23.463231120790752, 25.009497131620133, 29.93864127567836, 43.724798338753835, 48.47183888299124, 47.039339201790945, 17.47115503038679, 0.04242007214842098, 0.01073746383190155, 0.03658738173544407, 0.0482563214775707, 0.09428574530673878, 0.06989372774426426, 0.03434536971950105, 0.020814226241782308, 0.02215378837926047, 0.08133042869823319, 0.0692382018480982, 0.04983108929757561, 0.037411666076098166, 0.04797758946993521, 0.027953164419159293, 0.03403251079310264, 0.04042648537350552, 0.02092768408225051, 0.11692906277520315, 0.1553032850580556, 0.19810344198984758, 0.17700746256325925, 0.1640232607190098, 0.13605156381215366, 0.10880610972110714, 0.12567550130188465, 0.11513174564710685, 0.13254967172230991, 0.1518303392721074, 0.1740894362862621, 0.14525599990572247, 0.10582202806004457, 0.14914685540965625, 0.21268585164632114, 0.1310242707175868, 34.954448563711985, 78.36780084882463, 64.19959708622524, 56.456524576459614, 36.85470444815499, 23.87871950013297, 31.080157348087855, 49.502826486315044, 44.917272499629426, 36.923620155879426, 1.0473151100533349, 0.13728790889893258, 0.09740491650466408, 5.154231471674783, 11.200708048684255, 4.571531219141824, 16.721421820776804, 61.939917836870464, 62.84100191933768, 63.286402293613975, 61.1277220589774, 59.44309656960623, 55.43888793672834, 60.47906603131975, 56.74633046558925, 55.084005219595774, 56.09368964603969, 48.03815317153931, 44.89820664269583, 42.35359566552298, 42.54887478692191, 51.52399492263794, 56.87485824312483, 55.96360199792044, 55.6429044178554, 44.55912412915911, 41.72758729117257, 41.09565905162266, 38.719871929713655, 40.67972946166992, 42.59148808888027, 44.34368133544922, 42.28405809402466, 44.75939553124564, 43.54050431932722, 41.69018861225673, 39.718359334128245, 40.64926855904715, 43.123970236097065, 52.618888582502095, 50.81066506249564, 49.453904220036094, 51.832877090999055, 52.56434869766235, 49.90031208310808, 53.86167117527553, 48.62819766998291, 47.24526991162981, 39.69046231678554, 41.402276107243125, 39.89118535178048, 39.74976519175938, 41.06946781703404, 44.87583344323294, 43.77596834727696, 48.67943716049194, 47.37400960922241, 52.8544533593314, 51.03783988952637, 60.628396715436665, 40.28260864530291, 34.392043999263215, 56.302496910095215, 48.47929777417864, 49.90916756221226, 44.15528787885393, 46.140085969652446, 43.73647826058524, 47.352598735264365, 44.906474999019075, 42.06357090813773, 39.80563218252999, 41.47087914603097, 41.251628739493235, 41.073237214769634, 40.88320050920759, 40.34078938620431, 39.60130303246634, 39.95221485410418, 39.52249656404768, 42.3948575428554, 45.11627932957241, 49.021622044699534, 50.976952825273784, 53.23030226571219, 54.719853605542866, 53.73828159059797, 51.94239459718977, 51.96671676635742, 47.62540585654122, 43.84205266407558, 44.12870059694563, 43.05988352639334, 43.00200503213065, 42.9636162349156, 39.90977873120989, 40.095229625701904, 44.302686963762554, 42.8916780608041, 46.172346455710276, 43.88120228903634, 43.80087069102696, 41.262954303196494, 42.93284613745553, 45.61970411028181, 53.61850854328701, 56.938604491097585, 58.67966324942452, 57.24720525741577, 61.30531106676374, 56.27894251687186, 63.604664530072895, 55.723354135240825, 42.0340792792184, 7.1474229863711765, 16.30145706449236, 17.613353388650076, 11.854374596050807, 0.5618044137954712, 0.13541104032524995, 0.6034886656062943, 31.117135660988943, 60.38621030535017, 44.57974985667637, 36.970715045928955, 26.20565036364964, 37.01397453035627, 51.93702711377825, 55.08800390788487, 54.89527824946812, 24.468560763767787, 0.20309057938201086, 0.14659276817526135, 0.1955715021384614, 0.10047766912196364, 0.2913188865142209, 0.17996181760515484, 0.18449055030941963, 0.11460676310317856, 0.08518012426793575, 0.20615601060645922, 0.12407263873943261, 0.2199688529861825, 0.10411950905940362, 0.13495862031621592, 0.1338089241513184, 0.14011767134070396, 0.12880259778882774, 0.06626533637089388], [0.08867937685655695, 0.022114531735756567, 0.06348998565226793, 0.03630600344123585, 0.01886926158996565, 0.062000954124544344, 0.018856079350890856, 0.08423729307417359, 0.025276976504496167, 0.010599546500348618, 0.03211127620722566, 0.05533723473282797, 0.02303985333336251, 0.05092974266569529, 0.026521788011970263, 0.11428910014884812, 0.673298791050911, 36.14114877155849, 55.12023312704903, 43.29520859037127, 39.340613569532124, 26.334273678915842, 19.72203438622611, 27.291318552834646, 43.30131605693272, 43.28066948481968, 16.846287897654943, 0.07125917090369122, 0.10893898723380906, 0.1264504018638815, 1.0225965678691864, 2.0327167766434804, 1.0896551523889815, 38.857873576028005, 60.970407894679475, 55.843630926949636, 55.78165646961757, 56.45228964941842, 56.56652498245239, 54.11281033924648, 52.627205576215474, 55.23679263251168, 51.65090724400112, 50.103501728602815, 50.74371222087315, 42.28731679916382, 37.68907192775181, 36.77983413423811, 38.31457308360508, 44.95277432032994, 48.89482436861311, 44.286567143031526, 37.739772932870046, 37.16210665021624, 37.055969442640034, 37.82461738586426, 37.431373664310996, 35.73691299983433, 37.16285705566406, 37.736882482256206, 37.96712146486555, 37.63087034225464, 38.496119090488975, 35.84782361984253, 35.98471008028303, 36.70317465918404, 44.306504998888286, 47.918185574667795, 50.42290346963065, 47.93821028300694, 49.14741918018886, 45.74254478727068, 44.939774240766255, 39.79345546449934, 37.283467360905235, 35.22431659698486, 37.62901169913155, 35.917114530290874, 39.58091006960188, 38.27715356009347, 38.412434986659456, 39.32640102931431, 46.23151731491089, 45.343141487666536, 51.6277072089059, 46.4011367389134, 56.27217149734497, 37.210570335388184, 28.73977129799979, 55.029003279549734, 45.23166806357247, 46.5222681590489, 37.721933432987754, 39.10412120819092, 36.7633877481733, 39.61625208173479, 39.02321638379778, 37.201961517333984, 35.642014503479004, 36.00023235593523, 35.498148577553884, 36.5469583102635, 35.711218561444966, 36.06276614325387, 35.85333701542446, 36.59334795815604, 36.49719531195504, 38.84568643569946, 43.19884055001395, 46.89647381646292, 47.43328469140189, 49.13352278300694, 49.954706055777415, 51.09728520257132, 47.6594728742327, 48.182078157152446, 45.01748636790684, 42.86111988340105, 39.436217308044434, 37.76214960643223, 38.702088015420095, 36.088019371032715, 36.90746906825474, 36.77954925809588, 42.269296646118164, 43.641103812626426, 44.87096275602068, 40.79099096570696, 39.172126701899934, 37.88816908427647, 40.005240031651084, 37.677548340388704, 40.64473485946655, 46.69540684563773, 49.77219772338867, 49.55489976065499, 51.57618979045323, 50.634083543504985, 51.762526580265586, 52.974869115012034, 57.9454471043178, 25.96715518406459, 5.21809366771153, 5.232586307185037, 4.9097447735922675, 0.2731729330761092, 0.19555525801011495, 0.06537031475454569, 7.371599231447492, 26.816640206745692, 39.232395376477925, 26.586915390832083, 14.349032367978777, 32.324138505118235, 36.10971859523228, 47.45044674192156, 44.3208669253758, 22.662868125098093, 0.2889384228203978, 0.022403799695894122, 0.05497586733794638, 0.048790929040738514, 0.05529663798266223, 0.056378358509391546, 0.05139158752613834, 0.14502084680965968, 0.022819397305803638, 0.07080432173929044, 0.006593225964544607, 0.0430307808066053, 0.038011545315384865, 0.010447522425757987, 0.04012751605893884, 0.06518264553908791, 0.039283550810068846, 0.033371298773480315, 0.01360516740740942, 0.05683440189542515, 0.022514797846919725, 0.02704232445518885, 0.05480755672657064, 0.026243702308940034, 0.06524315050670079, 0.05020605114155582, 0.02743805625608989, 0.012563028372824192, 0.026367809756525924, 0.05209968631554927, 0.024209367809817195, 0.08580063775713954, 0.04555196927062102, 0.09803564873124872, 1.2823812450681413, 46.52275800704956, 61.362286295209614, 50.965901715414866, 44.35624715260097, 32.87445667811802, 22.3988904271807, 28.512947354997905, 35.533410685403005, 49.1048857825143, 17.45499873161316, 0.16234049387276173, 0.06497208933745112, 0.4014185486095292, 2.5459558878626143, 2.3309239063944136, 2.1758983050073897, 41.985657283238, 61.88912650517055, 58.0017066683088, 57.96061849594116, 58.38542093549456, 57.87194211142403, 55.14260285241263, 53.67234666006905, 56.51626171384539, 54.309930733272004, 51.8104031426566, 51.44724859510149, 43.273221015930176, 40.09052569525582, 39.80611855643136, 40.177902766636436, 47.44248410633632, 52.24587106704712, 45.57110493523734, 39.666445868355886, 37.69063179833548, 38.24119315828596, 38.95351552963257, 38.55494948795864, 37.65722485951015, 39.87657676424299, 38.578330176217214, 40.12631934029715, 39.33659403664725, 38.53244079862322, 37.43501452037266, 38.7533518246242, 38.81794922692435, 47.624596391405376, 49.344383239746094, 52.568079880305696, 50.073627948760986, 50.703808716365266, 48.627506324223106, 47.38644688470023, 42.1705071585519, 39.53420775277274, 37.68320764814104, 38.372885840279714, 37.512434823172434, 40.498374530247276, 39.56525230407715, 41.26911735534668, 41.93656131199428, 48.50250128337315, 46.676386151994976, 51.93546029499599, 47.860223702022004, 57.13321311133248, 38.593817710876465, 30.025903701782227, 55.87511321476528, 45.65190553665161, 49.00101716177804, 40.22759280885969, 40.46040957314627, 38.41480432237898, 41.50320911407471, 41.56269611631121, 39.2632349559239, 35.96715893064226, 35.999488898685996, 37.32880783081055, 37.50750855037144, 36.634234632764546, 37.90309728894915, 37.319771698543, 38.8856976372855, 38.9274354662214, 40.50918245315552, 45.458933217184885, 49.11113568714687, 49.847971303122385, 52.31558929170881, 50.76887859616961, 52.26657322474888, 50.61602170126778, 49.62751538412911, 47.17892503738403, 43.6643385887146, 40.731028011866975, 39.63482461656843, 40.21986641202654, 38.41279976708548, 38.17841618401663, 38.907615729740684, 44.085597446986604, 46.28380945750645, 47.0326828275408, 43.685138021196636, 40.350086075919016, 40.404143060956685, 41.231312206813264, 39.51608337674822, 43.6780925478254, 47.92468214035034, 53.21921641486031, 51.476997307368684, 52.74410554340908, 52.96325172696795, 53.86362361907959, 54.85911634990147, 60.91150106702532, 27.907913855143956, 2.373537642615182, 4.8284695233617505, 7.920551214899335, 2.2431627299104417, 0.18170257205409662, 0.2169136812112161, 7.494017805371966, 33.23488405772618, 37.22799989155361, 28.015880175999232, 20.42154254232134, 38.734775815691265, 42.397556918007986, 53.49878413336617, 50.69014508383614, 35.498037406376426, 0.4704979732632637, 0.08260688198996441, 0.01741884888282844, 0.026959005443911468, 0.00928702567970114, 0.028569225022303205, 0.0223448214320732, 0.08381664886006288, 0.02641071522209261, 0.06341861733900649, 0.038891082762607505, 0.06210120088819947, 0.07399521408868687, 0.04129845715527024, 0.07054876509521689, 0.016208987017827373, 0.04203484067693353, 0.04364081092977098, 0.11948741120951516, 0.17254967748054437, 0.11066330077924899, 0.06262812404228107, 0.28473516979387825, 0.10295510225530181, 0.13708497264555522, 0.18656808882951736, 0.1318683682807854, 0.08272599202713796, 0.2254026156983205, 0.10944670106151275, 0.098227484151721, 0.1540992110967636, 0.14761394980762685, 0.17767326826495783, 2.072863902364458, 56.777527877262656, 69.22594479152134, 59.01731095995222, 50.29903098515102, 39.26287712369646, 29.06470901625497, 38.82574510574341, 55.38148191996983, 59.67950207846505, 20.85257751601083, 0.42308786298547474, 0.2962264860314982, 0.4976786747574806, 5.31868360723768, 6.992421703679221, 2.192902935402734, 44.485136236463276, 63.06797872270857, 59.74805300576346, 59.447334970746724, 61.36541993277413, 60.74263204847063, 57.65486649104527, 55.35978616986956, 59.75728021349226, 56.475322927747456, 55.37319271905081, 55.160522256578716, 46.27237619672503, 41.586952277592246, 41.255967889513286, 42.920891761779785, 49.266316754477366, 54.735560008457725, 47.910629408700125, 40.65660238265991, 40.31294795445034, 40.829153946467805, 41.625083991459434, 39.74522106988089, 39.70559549331665, 42.0536766733442, 41.69967290333339, 42.885622705732075, 42.450620310647146, 42.64245659964425, 38.94808898653303, 40.585998262677876, 41.49651452473232, 49.610950878688264, 50.41704266411917, 55.71700348172869, 53.21382808685303, 52.530399799346924, 50.51737812587193, 48.38478837694441, 45.261263915470664, 41.274352822984966, 39.2334862436567, 41.004130431583945, 39.522552149636404, 43.66176775523594, 42.06563452311924, 43.6525787625994, 43.38213402884347, 50.46945292609078, 49.283037594386506, 53.703262669699534, 52.28405836650303, 58.270150320870535, 41.606726850782124, 33.90804638181414, 57.285625321524485, 48.68236582619803, 51.11050762448992, 42.36722108295986, 42.4007739339556, 41.16745131356375, 44.38917119162423, 44.07673501968384, 41.13760532651629, 39.68754407337734, 39.13532904216221, 39.24159826551165, 39.06365489959717, 38.9990679195949, 39.95636640276228, 39.90737118039812, 41.31392281396048, 40.13013737542288, 42.15392875671387, 47.551209517887656, 51.806595529828755, 51.40671975272042, 54.38165351322719, 52.32736301422119, 53.42300360543387, 52.42402287891933, 52.83272634233747, 50.090862955365864, 47.15624611718314, 42.77079330171858, 44.02217776434762, 42.70634528568813, 40.26837873458862, 41.364992073604036, 40.68567017146519, 47.012036255427766, 47.85935517719814, 50.263233866010395, 46.004641260419575, 42.21624714987618, 42.596466473170686, 43.83875921794346, 40.653972489493235, 45.720466886247905, 49.93834999629429, 54.25747530800955, 54.9465594291687, 56.18801144191197, 55.00503199441092, 56.505787304469514, 57.36620705468314, 62.24436010633196, 30.743312154497417, 8.084454877035958, 12.161833252225604, 13.5183413539614, 1.4640376631702696, 0.612919705254691, 0.5518475909318242, 10.806356957980565, 40.41018104553223, 56.40407609939575, 38.559653418404714, 20.48978427478245, 42.92130517959595, 46.38464171545846, 61.341267994471956, 57.15435995374407, 44.1002060345241, 0.8910142428108624, 0.1834672245063952, 0.1344624212277787, 0.0991718488346253, 0.09320121564503227, 0.16290511643247946, 0.07964713938002076, 0.28107412053006037, 0.10197261068969965, 0.24231530459863798, 0.07330667746386357, 0.14287554978259973, 0.22253691804196152, 0.10715175313608986, 0.15520567101027283, 0.11435901639716965, 0.12582851094858988, 0.11294150246041161], [0.021968292172199914, 0.026265359450397745, 0.028092106338590384, 0.07356211875698396, 0.03381647542119026, 0.004281015684162932, 0.08052992700998272, 0.02145031380600163, 0.015128682932949491, 0.05044762996424522, 0.015866009618288705, 0.09027695363121373, 0.041572066223514934, 0.07067877240478992, 0.04507415848118918, 0.009382939997262188, 5.781758461679731, 51.12188877378191, 53.44454649516514, 46.56587157930647, 29.570678574698313, 19.652448177337646, 23.440369810376847, 33.24443435668945, 37.80501651763916, 39.54416104725429, 7.622760108539036, 0.18725874248359883, 0.11177842558494636, 0.10067435606781926, 1.8373471115316664, 3.2624374074595313, 12.443946616990225, 51.2411823953901, 60.69357081821987, 56.497796876089915, 54.44665043694632, 53.09789044516427, 54.18723249435425, 56.494350569588796, 53.62406710215977, 51.37175294331142, 55.14368329729353, 50.92534160614014, 52.87149034227644, 48.31792933600289, 40.240099566323416, 38.615443978990825, 36.97904941013881, 39.29264668055943, 40.036222049168174, 37.447580337524414, 37.49866349356515, 37.41379819597517, 37.596831117357524, 36.26904426302229, 36.234028816223145, 34.74156270708357, 37.62517976760864, 37.31671449116298, 37.18393094199044, 36.24362775257656, 38.75238602502005, 35.01198312214443, 36.97510978153774, 35.014911787850515, 39.45681176866804, 43.76204415730068, 46.6888998576573, 42.508606501988, 41.93136058534895, 37.518875803266255, 38.65057407106672, 35.62328563417707, 37.150141852242605, 35.84436341694423, 37.601806027548655, 37.042993681771414, 39.20102425983974, 36.834394863673616, 40.00750167029244, 43.11782455444336, 46.254699979509624, 47.91400623321533, 49.824604511260986, 47.3631773676191, 52.9268535886492, 32.546998500823975, 27.56393459865025, 55.2624488558088, 43.587474141802105, 48.14177860532488, 39.08398185457502, 41.25277519226074, 35.46175043923514, 38.21786458151681, 34.69055945532662, 38.1784474509103, 35.20881864002773, 37.7473395211356, 33.674114431653706, 34.80031667436872, 36.17930827822004, 34.71205023356846, 35.056708676474436, 36.863111768450054, 35.63224881035941, 40.81684521266392, 45.50149440765381, 48.72795990535191, 49.34994179861886, 49.81470332826887, 47.97583130427769, 47.300438608442036, 49.585680280412944, 49.65062509264265, 43.53073167800903, 41.84186431339809, 37.309356348855154, 39.280862535749165, 38.19614798682076, 38.3326210294451, 37.36850636345999, 39.92591939653669, 44.906853675842285, 49.61539772578648, 47.86290223257882, 46.51840148653303, 42.004563331604004, 38.20571565628052, 37.867644105638774, 38.82333755493164, 39.41882249287197, 40.50008031300136, 39.75384725843157, 46.052806173052105, 46.571794918605256, 51.398295061928884, 50.96320581436157, 54.46776601246425, 52.49300112043108, 48.90643828255789, 7.80355657849993, 3.3321002636637007, 5.048983633518219, 2.185193474803652, 0.25618347472378183, 0.03059427546603339, 1.9465825642858232, 25.77887463569641, 28.237362691334315, 26.85815221922738, 15.349086591175624, 21.46513591493879, 32.9647867338998, 46.282871450696675, 45.95816476004464, 39.46120997837612, 9.184244411332266, 0.15669945228312696, 0.04643732176295348, 0.05888136902025767, 0.0349045572137194, 0.034638788617615185, 0.02409353170410863, 0.021610122373593704, 0.02329708426259458, 0.029077590243624787, 0.017296066274866462, 0.019345343811437488, 0.0035801276015782996, 0.07779603478099618, 0.048324046057782004, 0.04308262088203004, 0.06271085781710488, 0.023106214058186327, 0.05341646494343877, 0.04006271257198282, 0.04626232758164406, 0.07687828902687345, 0.0738972064905933, 0.02989031234756112, 0.029603173291044574, 0.03822407266125083, 0.0331765660084784, 0.019246774725615978, 0.04749692544074995, 0.054255697410553694, 0.0284468817657658, 0.02890631104154246, 0.04568420217505523, 0.02425000866475914, 8.296297635350909, 61.172739437648225, 59.240612166268484, 54.10750886372158, 35.45009136199951, 26.356467962265015, 27.822053228105815, 31.634196281433105, 35.981444426945274, 45.07223122460501, 7.906961406980242, 0.11003709438123874, 0.2093131933361292, 0.3587323177073683, 4.082426241465977, 2.130414528506143, 14.068530116762433, 56.25533601215908, 62.356879234313965, 59.12035274505615, 55.805196966443745, 55.200019291469026, 56.299477917807444, 58.81135245731899, 54.08214099066598, 50.95043502535139, 56.85102244785854, 52.725880418504985, 56.5430018561227, 50.27277026857649, 41.71982267924717, 39.18362944466727, 39.362146036965505, 40.20834977286202, 41.244135107312886, 39.07741233280727, 40.451769488198416, 39.3873610496521, 38.65042815889631, 38.5558180127825, 37.78614868436541, 37.69966445650373, 39.20547458103725, 39.06365142549787, 39.235695770808626, 38.27877943856375, 39.6645906993321, 37.66723721367972, 39.14905520847866, 36.94443001065935, 41.53796747752598, 46.925006593976704, 48.94175945009504, 46.91596698760986, 43.8595586504255, 40.61117853437151, 39.71764366967337, 37.97729710170201, 39.035782200949534, 37.37365845271519, 39.328957966395784, 39.7337634904044, 40.90806463786534, 39.09680822917393, 42.31080865859985, 44.40083026885986, 48.80775301797049, 49.19572653089251, 51.67050116402762, 48.632797377450125, 54.15870319093977, 34.485375676836284, 29.607465812138148, 57.51892498561314, 46.60162353515625, 48.92225933074951, 41.865568092891145, 41.80482346670968, 37.00231892721993, 39.33607986995152, 36.60642794200352, 39.43007857458932, 37.08755942753383, 39.11852829796927, 35.99958964756557, 36.69657039642334, 37.96125371115548, 37.205657958984375, 36.839557375226704, 38.74375983646938, 37.140605449676514, 42.10193191255842, 46.890595640454976, 52.55353730065482, 50.740047046116416, 50.70438889094761, 49.12423651559012, 49.96505192347935, 51.03662395477295, 52.20085368837629, 46.29723685128348, 43.93734720775059, 39.773350851876394, 41.66657863344465, 39.70546695164272, 40.31099203654698, 37.654063429151265, 42.17090320587158, 48.25619459152222, 51.74283191135952, 51.75130523954119, 48.7925260407584, 43.65185962404524, 40.2904566356114, 38.55365364892142, 40.61620208195278, 40.43038640703474, 42.21528482437134, 41.14150674002511, 48.36919314520699, 49.595584937504356, 54.311494077954976, 52.29303543908255, 57.48871421813965, 55.59191158839634, 53.732538904462544, 8.346305557659694, 1.173429039972169, 5.41436334167208, 3.3966533711978366, 0.9842592307499477, 0.007131198637320527, 1.461951032280922, 28.920245545251028, 31.581556728907994, 26.61043851716178, 18.751001051494054, 27.78183705466134, 37.79986442838396, 52.40340062550136, 50.11832571029663, 50.26971306119646, 16.045257874897548, 0.21832630969583988, 0.0564692482751395, 0.031396378496927876, 0.07798084057867527, 0.0338234337978065, 0.03474764599065695, 0.06204072306198733, 0.010256670881062746, 0.014498814142176082, 0.039542072652173896, 0.0449443750881723, 0.017047393368557096, 0.04508073687819498, 0.07237924901502472, 0.04075283018339958, 0.05553049168416432, 0.028367554236735617, 0.1651012221617358, 0.17078353225120477, 0.13852920729134763, 0.14302288687654904, 0.11289553849824838, 0.08458580223045178, 0.14941901580563613, 0.14369113530431474, 0.13320217813764298, 0.08703831277255501, 0.15463771005826338, 0.17650926858186722, 0.10156020389071532, 0.12434809681560312, 0.2103435080498457, 0.1196227925164359, 11.389367273875646, 71.56670257023403, 66.3597503389631, 62.79105131966727, 40.38889523914882, 29.242977210453578, 31.708211966923304, 44.950964314596995, 50.94178451810564, 49.88144424983433, 9.969843353543963, 0.2906916487429823, 0.42581948212214876, 0.27821564248629976, 9.197496363094874, 5.943669727870396, 15.771149703434535, 56.460700443812776, 63.46259471348354, 61.2031169618879, 58.35744053976876, 58.680670738220215, 58.100919995989116, 60.79266602652413, 55.54577554975237, 52.958516529628206, 56.920587812151226, 55.18923568725586, 57.29622827257429, 52.36405297688076, 44.31499569756644, 42.21962397439139, 41.609506130218506, 44.095449992588584, 43.05217102595738, 39.77091203417097, 42.19897740227835, 40.499659946986604, 41.307870932987754, 40.841271604810444, 40.478454044886995, 39.56448800223214, 42.27722454071045, 41.27826465879168, 41.838376317705425, 40.25206436429705, 42.213856969560894, 38.76016453334263, 40.56988886424473, 38.340614931924, 43.09151867457798, 48.518575940813335, 50.21378353663853, 48.75642320087978, 44.9744005884443, 41.51772390093122, 42.93366602488926, 40.04952090127127, 41.18776089804513, 38.172854151044575, 40.427096435001914, 41.98786333629063, 43.427085399627686, 41.72974818093436, 44.30502503258841, 47.21306153706142, 50.92688758032662, 51.68375137874058, 52.14891937800816, 50.408882004874094, 55.00542456763131, 34.928062779562815, 32.638134547642295, 59.581442151750835, 48.45460387638637, 50.953655515398296, 44.77561957495553, 44.74130242211478, 39.40007972717285, 43.30938638959612, 37.93409320286342, 42.10906423841204, 39.16329901559012, 41.647450242723735, 37.91800464902605, 38.086731229509624, 39.8359124319894, 38.33593879427229, 39.19053942816598, 42.26855666296822, 38.25164324896676, 45.30178928375244, 49.9244327545166, 55.820587226322715, 52.33127137592861, 52.16399002075195, 50.88893304552351, 51.00437389101301, 54.558433055877686, 54.74389437266758, 48.896724700927734, 46.86814948490688, 40.722797870635986, 43.12274040494646, 41.70806632723127, 42.288108893803184, 40.352615220206125, 43.98538705280849, 49.8086062840053, 55.763382707323345, 51.78490325382778, 50.81518486567906, 45.35163218634469, 43.16956084115164, 41.0033209664481, 43.16348116738455, 42.04504006249564, 45.39277941840035, 43.17129441670009, 51.417169843401226, 51.63603115081787, 57.44897052219936, 55.61015408379691, 60.98250470842634, 57.99726676940918, 55.140824113573345, 9.878574422427587, 8.78507387638092, 12.269726616995674, 4.625817494732993, 0.6108135868396077, 0.16371470370462962, 2.747087129524776, 35.499399253300254, 40.37631899969918, 36.500818797520225, 20.57274924005781, 30.913414478302002, 45.6396176474435, 57.662922927311485, 57.16745730808803, 56.97161190850394, 20.004855598722184, 0.3829251581004688, 0.16085514000483922, 0.1423135327973536, 0.1377483627625874, 0.10251429876578705, 0.11396934730666024, 0.18299573766333715, 0.1299822037773473, 0.187615909746715, 0.13278908601828984, 0.1707051478858505, 0.06374546765748944, 0.14307775321815694, 0.15069747077567236, 0.1704141784991537, 0.1300994681992701, 0.09869625685470444], [0.0369955680466124, 0.064427137507924, 0.10353011997150523, 0.06215726823679038, 0.043389210144856145, 0.0552955523266324, 0.07912143080362252, 0.01698176546155342, 0.01900880062021315, 0.021782950331856097, 0.05041642753141267, 0.07595168160540716, 0.04986757073285324, 0.0709744847512671, 0.04512704689321773, 0.03809380750837071, 13.69249882016863, 49.08942951474871, 47.20957701546805, 38.30317108971732, 25.5486512865339, 15.716326679502215, 22.655985934393748, 39.61261122567313, 36.4793175969805, 40.17974403926304, 1.5235004552773066, 0.013228715330894505, 0.056742833594658544, 1.0075063833168574, 1.6154978615897042, 1.863461047410965, 22.604836770466395, 57.534270082201274, 58.18046644755772, 54.79815632956368, 51.29880380630493, 49.96139022282192, 54.080393518720356, 53.2548884664263, 54.03972571236746, 55.16203696387154, 54.127693380628315, 55.46208797182356, 53.506246498652864, 50.78055851800101, 44.57984365735735, 36.817066056387766, 38.16640969685146, 38.452515670231406, 38.33698797225952, 37.89718784604754, 36.681232248033794, 37.43797792707171, 37.27782194955008, 37.26456478663853, 37.57943630218506, 37.40091623578753, 37.68491343089512, 37.52705730710711, 37.961972849709646, 34.6778234073094, 37.815688950674875, 36.007180554526194, 36.969651971544536, 35.628482886723106, 35.17172915594918, 35.4638557434082, 39.442092009953086, 35.010590008326936, 36.12704740251814, 35.841208934783936, 36.55384397506714, 35.48961271558489, 35.84351226261684, 34.22027063369751, 37.03005266189575, 37.45269421168736, 36.16917085647583, 35.89714888163975, 37.691562856946675, 41.708146231515066, 45.24406712395804, 44.3485381262643, 51.89065136228289, 44.70321587153843, 55.630508831569124, 33.47026470729283, 25.395490407943726, 54.936915329524446, 43.07165724890572, 48.91401876722063, 41.21704060690743, 44.322308676583425, 38.121993337358745, 38.941925934382844, 35.80283750806536, 35.82661771774292, 35.41256414140974, 35.93471431732178, 34.4659172466823, 37.43591431209019, 34.40552697862898, 35.89692306518555, 34.666629859379356, 38.1639917237418, 35.67079046794346, 39.828252043042866, 44.45039871760777, 49.16056169782366, 48.744857924325125, 48.967426095690044, 45.964584895542686, 49.18553352355957, 49.4448298726763, 47.72420924050467, 40.80706214904785, 39.25032867704119, 36.65321363721575, 37.98523194449288, 37.07541397639683, 40.02366665431431, 36.560479504721506, 39.81183344977242, 46.44468457358224, 51.135396071842735, 49.35447202410017, 50.773422718048096, 46.56640311649868, 44.55216203417097, 39.17987394332886, 39.162482602255686, 39.67682300295149, 41.752402782440186, 37.98416192190987, 38.292853014809744, 40.07183851514544, 47.0959461757115, 46.327777658190044, 53.504686628069194, 51.28449746540615, 60.16787706102644, 28.22588947841099, 1.3588550729410989, 5.519903872694288, 5.789863535336085, 0.27679593009608133, 0.05004515013258372, 0.0435864331333765, 11.697927219527108, 34.850896086011616, 30.719657012394496, 22.03712030819484, 36.74796969549996, 44.777075222560335, 40.06122861589704, 47.306104864392964, 46.03577961240496, 33.29989835194179, 0.22365422094506876, 0.055404474160500934, 0.0540277198223131, 0.0584815422605191, 0.019120102415659597, 0.06493331784648554, 0.017306286708584855, 0.014910720521584153, 0.03358968187655721, 0.04126387222536972, 0.01053119936425771, 0.04143002848806126, 0.03217802369701011, 0.032785746801112375, 0.0275988012020077, 0.05543581569301231, 0.08012087895934071, 0.0383411097739424, 0.08595856678272996, 0.014266473573765584, 0.04670601823766317, 0.04925660423136183, 0.023297640661309873, 0.0685308426618576, 0.03840468171983957, 0.010988956051213401, 0.019918007011126195, 0.03482706851458975, 0.026021458341607025, 0.08397210123283522, 0.07047154102474451, 0.04462043568491936, 0.07446372894836323, 19.55786234991891, 58.90846742902483, 52.52766568320138, 44.90666954857962, 30.424021584647043, 18.23188897541591, 21.673404693603516, 31.789297444479807, 39.8001708984375, 43.988305296216694, 1.5253853712763106, 0.052471092636031766, 0.3528376397277628, 5.079620846680232, 8.849552290780203, 2.6317756942340305, 27.191700492586406, 58.90615367889404, 60.846292223249165, 56.004836082458496, 54.83383880342756, 51.92917217527117, 54.17330483027867, 55.43031733376639, 55.97621297836304, 56.2371004649571, 55.04599509920393, 55.671697752816335, 54.8514837537493, 51.960435594831196, 47.0871011189052, 38.57185445513044, 40.54358993257795, 39.10642106192452, 40.06599160603115, 39.454449381147114, 38.624646868024556, 38.00102867398943, 38.74534402574812, 38.18569442204067, 39.77929156167166, 38.86820902143206, 39.23115164893014, 39.74960538319179, 38.919823714665, 37.23937061854771, 38.45339461735317, 38.36401299067906, 39.37848472595215, 36.888264247349326, 36.931871141706196, 37.296536922454834, 41.7023549079895, 37.44045843396868, 39.42931079864502, 37.38964973177229, 38.651442595890586, 37.72373996462141, 38.711923190525596, 36.136545589991975, 37.75811617715018, 37.82798726218087, 39.06371743338448, 38.270455496651785, 40.411886828286306, 43.34819207872663, 47.05510466439383, 46.53453172956194, 53.86966855185372, 45.54872478757586, 57.4993553842817, 34.86664417811802, 26.814461946487427, 56.66577999932425, 44.39809615271432, 50.37949807303292, 44.87339462552752, 46.51197440283639, 40.440509932381765, 41.907681124550955, 39.24137592315674, 37.98198366165161, 36.52413347789219, 38.073251724243164, 36.5355042048863, 37.77741827283587, 36.2632668358939, 37.1592161996024, 37.452544825417654, 39.591308048793245, 37.68521567753383, 41.552402360098704, 45.47895792552403, 49.9897631917681, 50.53235149383545, 50.08636399677822, 48.17456020627703, 51.427991662706646, 52.5049728666033, 50.49633550643921, 43.02585819789341, 39.600646427699495, 38.03429317474365, 39.041837556021555, 38.4127858706883, 40.78949710300991, 37.65251745496477, 42.43584496634347, 48.857641083853586, 52.76831654139927, 49.82918684823172, 52.92234073366438, 48.997893946511404, 46.900833811078755, 41.6792243548802, 40.4933614049639, 41.587424755096436, 42.406106676374165, 39.917321000780376, 41.26773118972778, 41.13240807397025, 49.104083265577046, 48.62934064865112, 55.640330110277446, 51.78546258381435, 61.706270762852256, 31.994175502232142, 1.2477240647588457, 2.920126804283687, 5.471534422465733, 1.8072718339306968, 0.06837811799986021, 0.11757065834743635, 13.689811604363577, 37.66942589623587, 27.467550924846105, 18.219410010746547, 36.41050263813564, 50.083428382873535, 43.77011448996407, 54.30681446620396, 52.05846772875105, 42.56490775517055, 1.3185057980673653, 0.06414160318672657, 0.040350947462554486, 0.01119792363273778, 0.059233230139528, 0.025573686297450746, 0.054730122310242484, 0.027196372260472605, 0.046240655173148425, 0.023079730836408477, 0.058247820873345645, 0.12572388084871428, 0.04942473503095763, 0.052768558995532136, 0.0520757747414921, 0.06276959859366928, 0.05276914932099836, 0.20321177930704185, 0.15883704115237507, 0.19466691996370042, 0.17010250022368772, 0.15566588060132094, 0.1276359518191644, 0.20317523341093743, 0.2369873390666076, 0.08337684960237571, 0.155304791405797, 0.16337118856608868, 0.26710349161710056, 0.17911307886242867, 0.1686838734894991, 0.13683118697788033, 0.2452863651726927, 27.407860687800817, 67.17139026096889, 60.93128258841378, 53.56705365862165, 37.19922045298985, 23.756087269101823, 30.73677042552403, 51.5428592818124, 48.787769998822895, 50.279610770089285, 2.183348510946546, 0.186341648123094, 0.5355355005179132, 4.065143031733377, 7.474139009203229, 5.117603174277714, 27.858100482395717, 61.255867685590474, 62.5562230518886, 59.87727560315813, 57.12514277866909, 54.257673331669395, 56.399354798453196, 58.34120954786028, 59.1850335257394, 59.611534799848286, 56.040146827697754, 60.166056632995605, 57.43965993608747, 54.514714990343364, 48.60178061894008, 40.2099061693464, 41.859804562159944, 41.633317606789724, 41.22545140130179, 41.98338522229876, 40.394863741738455, 40.48765345982143, 40.18122053146362, 41.187347480228965, 41.61798293249947, 40.66993250165667, 41.88720825740269, 41.155851296016145, 41.83925526482718, 37.50145666939871, 41.0671193259103, 39.98753949574062, 40.673291955675396, 38.39957039696829, 39.73281506129673, 39.1995130266462, 43.804640088762554, 38.73031159809658, 41.93047816412789, 40.57432528904506, 40.270550046648296, 39.03034176145281, 39.49469682148525, 38.03665903636387, 40.83222852434431, 40.73744119916643, 40.79273496355329, 41.182084219796316, 42.047756808144705, 46.821829319000244, 49.82796049118042, 49.515030997140066, 56.41792385918753, 47.76749651772635, 59.17206818716866, 37.602681500571116, 29.146921839032853, 58.339764322553364, 46.51605994360787, 52.94018023354666, 46.46668257032122, 47.879202706473215, 41.81723294939314, 42.18524776186262, 41.843417235783164, 39.6874919618879, 40.44777079990932, 40.600752762385774, 38.43295301709856, 40.74060262952532, 40.39520420346941, 40.1253604888916, 38.945323603493826, 42.60210146222796, 39.27589804785592, 44.22826828275408, 47.23421880177089, 52.33659717014858, 53.46096508843558, 53.15560565676008, 50.4815844808306, 53.02541725976126, 53.34240450177874, 51.79530470711844, 45.04432031086513, 42.316461018153596, 41.0863310950143, 42.1979421206883, 41.56982844216483, 44.18189947945731, 39.79761743545532, 44.88130514962332, 51.412083762032644, 55.476929324013845, 52.402021408081055, 56.84680489131382, 51.80882937567574, 49.09828151975359, 43.54183142525809, 42.178646973201204, 44.76793139321463, 44.57241603306362, 42.57449279512678, 42.59059871946062, 44.35488183157784, 51.85802262169974, 52.93384000233242, 58.95175470624651, 54.87003196988787, 64.1403636932373, 34.96883828299386, 3.5956675836018155, 15.338950906481061, 19.695606912885392, 1.1434465859617506, 0.17315033024975232, 0.5276539634381021, 16.02082106045314, 50.60367822647095, 42.41501426696777, 32.13806922095162, 44.468960830143516, 55.08476604734148, 50.499580315181184, 61.24390983581543, 57.37363120487758, 49.492004667009624, 2.174745338303702, 0.15294876854334558, 0.13418730241911753, 0.19103130219238146, 0.19913419096597604, 0.1799974271229335, 0.12288478176508631, 0.14648402615317277, 0.1004694520628878, 0.1016737227993352, 0.18026915325650147, 0.23299361765384674, 0.13500063520457062, 0.1339537642363991, 0.18400448853416101, 0.14760123406137737, 0.13637221232056618], [0.0033963319729082286, 0.015832900502053753, 0.036525397561490536, 0.0076304545260167545, 0.04517821521897401, 0.0229433690463858, 0.06465770370726075, 0.023394440467070256, 0.03546524766300406, 0.04878281715459057, 0.04407885278175984, 0.06730741009648357, 0.06987683222229991, 0.07414675131440163, 0.06466990376689605, 0.5061154706137521, 29.89906781060355, 58.89061055864607, 50.05278335298811, 41.64059931891305, 24.221045085362025, 17.611545119966777, 39.81951468331473, 40.68999195098877, 37.312000138419016, 26.357240949358257, 0.10258072055876255, 0.03258709888905287, 0.5340860411524773, 2.35778477362224, 4.908653472151075, 2.229289782898767, 27.3536855833871, 57.83288628714425, 57.95304495947701, 55.22241333552769, 50.281584058489116, 46.0860150882176, 51.93194103240967, 53.14632633754185, 53.22613682065691, 52.72945179258074, 48.52475636345999, 46.93145104816982, 50.08651685714722, 52.80854661124093, 46.09144510541643, 38.91481753758022, 38.08027287891933, 38.52011122022356, 36.761883463178364, 36.84818703787667, 36.12318073000227, 37.48922783987862, 38.80989279065813, 39.359675952366416, 39.44343648638044, 39.69421434402466, 41.29514530726841, 37.6889260155814, 37.54815203802926, 36.7671571459089, 37.88811002458845, 35.30936254773821, 36.958340304238455, 36.90167079653059, 36.36192083358765, 36.22041034698486, 35.623098032815115, 34.61112764903477, 35.8802022252764, 34.20852817807879, 36.727601051330566, 35.69360140391758, 36.16070447649275, 34.378863266536165, 38.33325678961617, 36.46528570992606, 37.93948153087071, 35.570677348545615, 37.227249486105784, 35.068267004830496, 40.99514641080584, 42.33799695968628, 49.02468620027815, 46.39630774089268, 54.718366691044395, 33.73108966009957, 22.061895847320557, 50.79058129446847, 47.469985076359336, 51.00621863773891, 45.921176024845664, 47.602521964481895, 43.35969134739467, 41.742300101688926, 39.70447335924421, 35.43351296016148, 35.694855553763254, 36.9243288721357, 34.73522594996861, 36.30227402278355, 35.259794098990305, 34.69737563814436, 35.046724115099224, 37.01951571873256, 37.25332260131836, 38.87737022127424, 38.8864688873291, 42.73279012952532, 46.66554348809378, 47.68630681719099, 48.07399197987148, 48.65511499132429, 46.884085178375244, 43.84014538356236, 37.27246141433716, 36.08051879065377, 36.03928123201643, 37.10244594301496, 36.0263888495309, 36.67376640864781, 35.350134577069966, 41.27647202355521, 47.763727119990754, 49.75921154022217, 50.34496900013515, 51.42137002944946, 49.424304894038606, 48.95737900052752, 45.54272154399327, 42.40379640034267, 41.542643615177695, 40.95208147593907, 38.970097405569895, 41.47657666887556, 41.00204597200666, 41.40378039223807, 47.03006683077131, 49.480300426483154, 48.74797766549246, 52.643471309116904, 45.738320282527376, 7.348544239997864, 2.72643295781953, 4.015503798212324, 4.504311740398407, 0.04720283479296735, 0.02349219361453184, 5.092171898909977, 32.92738110678536, 33.66569321496146, 28.424276181629725, 26.373616116387502, 43.495188168116975, 26.926823002951487, 46.53776264190674, 45.56547342027937, 46.649725914001465, 8.929954239300319, 0.20139064559979097, 0.0552238108191107, 0.04977751217250313, 0.012698375752993991, 0.05095925215365631, 0.012981492793187499, 0.050095697598797936, 0.028683921189180443, 0.007221963722258806, 0.013246723650289434, 0.03891359655452626, 0.03467802829774363, 0.054357131610491445, 0.02630382899328002, 0.02426852418908051, 0.04425753480089562, 0.03550995294270771, 0.04725409472095115, 0.046415181165294986, 0.04770088628200548, 0.06261940486729145, 0.005811758455820382, 0.0987901593159352, 0.023723209343318428, 0.014124557974615266, 0.04841333108821085, 0.03846023677449141, 0.05191212227301938, 0.028434976868863617, 0.029889257225607122, 0.08996511250734329, 0.9219267240592411, 39.226280961717876, 66.73883710588727, 56.229249000549316, 49.311900411333355, 30.54196378162929, 22.079434837613785, 35.09717151096889, 38.72496148518154, 43.42565059661865, 29.72289276123047, 0.17666431383362838, 0.045439766719937325, 0.6708211068596158, 4.818234392574855, 9.028794969831194, 2.740920820406505, 27.527169942855835, 59.04304013933454, 60.16663333347866, 58.1569641658238, 52.29756566456386, 47.001454148973735, 52.89998490469796, 55.1221091406686, 56.363835607256206, 55.30813326154436, 52.18978520802089, 49.98934629985264, 51.392156328473774, 54.38435983657837, 47.484520707811626, 42.5774735723223, 39.22127478463309, 39.49487747464861, 38.58475725991385, 38.24578939165388, 38.14508220127651, 39.39376034055437, 40.473378385816304, 41.28919070107596, 41.98469148363386, 42.5482633454459, 43.06419835771833, 40.24450125013079, 39.26686538968767, 37.94880253928048, 38.29505559376308, 37.081281730106895, 38.58167920793806, 38.79136194501604, 38.62770060130528, 37.35721901484898, 38.18960625784737, 36.39015136446272, 36.75755820955549, 36.93852751595633, 37.40403945105416, 38.387025424412315, 38.70675025667463, 35.823730741228374, 39.87524618421282, 38.8037679536002, 39.232103552137104, 37.303783893585205, 39.170181206294465, 37.90427153451102, 43.51197154181344, 45.46408878053938, 50.085888045174734, 48.124564443315776, 55.332316466740195, 35.90411445072719, 23.40285301208496, 52.363997391292024, 49.01222808020455, 52.31162881851196, 47.80860553468977, 49.41340317044939, 45.77111577987671, 43.49353797095162, 40.06960119519915, 37.461129324776785, 37.97656406675066, 38.12632206508091, 36.759267466408865, 38.24574422836304, 36.36317845753261, 37.77333968026297, 37.86223840713501, 38.30413688932146, 39.87894262586321, 39.32178742544991, 41.895247323172434, 45.586738382067, 47.461932114192415, 49.757741996220176, 49.89209236417498, 51.77341440745762, 49.59576211656843, 44.499300139290945, 39.10483339854649, 38.197530678340364, 39.38397380283901, 38.49122755868094, 37.35950149808611, 38.16539178575788, 36.91412544250488, 42.80381808962141, 49.2605219568525, 51.410075732639854, 51.34689923695156, 52.19703565325056, 51.537272930145264, 51.38240105765206, 47.65795121874128, 44.500408376966206, 44.81121867043631, 42.65997648239136, 41.59330987930298, 43.27995382036482, 42.79087012154715, 44.09511995315552, 49.862934248788015, 52.47141306740897, 53.010662760053364, 55.93898453031267, 49.094675404684885, 7.815510085650852, 0.22708679389740738, 5.850151317460196, 2.8393305454935347, 0.09659897296556405, 0.0018241268948518804, 4.608765312603541, 37.9751501083374, 28.652041605540685, 24.033740758895874, 37.0380083492824, 48.915978159223286, 34.00388635907854, 50.46146944590977, 49.307828766959055, 55.69118397576468, 15.256845780781337, 0.08873395821345703, 0.053903456311672926, 0.0619073977161731, 0.02486725670418569, 0.03631154367966311, 0.04948870052716561, 0.029093203334403888, 0.02121556274193738, 0.06283814420125314, 0.019573277294901863, 0.045223972227956565, 0.004572660213203302, 0.023569197161123157, 0.05661385087296367, 0.023436993094427244, 0.0682862036462341, 0.10186552429305655, 0.1417041676385062, 0.11181396724922316, 0.13950823832835468, 0.15260749257036618, 0.10158433938132864, 0.13830119238368102, 0.13562644805227006, 0.10462584546101944, 0.1309776282204049, 0.18330711738339492, 0.11464914440044335, 0.10980247054249048, 0.14393532648682594, 0.146233701014093, 1.4573860658066613, 49.835579190935405, 73.96096147809709, 65.33981037139893, 55.67560264042446, 37.43938493728638, 27.197821855545044, 50.59591361454555, 55.04480348314558, 49.5971691267831, 32.66469056265694, 0.3617836625448295, 0.10817864803331238, 1.0897759859051024, 6.2431336130414685, 11.023336172103882, 4.410167992115021, 32.16150549479893, 62.33170591081892, 64.08931527818952, 60.71959182194301, 54.531307288578574, 49.54745129176548, 55.91164684295654, 56.35932970046997, 57.83414043698992, 58.54143578665597, 53.449702058519634, 52.57350294930594, 53.8261068207877, 58.26826735905239, 50.376340116773335, 44.279400076184956, 40.88470132010323, 42.69538450241089, 39.83162539345877, 40.62844133377075, 40.841639859335764, 42.43865898677281, 42.89351238523211, 43.61910581588745, 43.8546393258231, 44.27219132014683, 46.85004595347813, 43.627725056239534, 39.877351488385884, 40.21155636651175, 41.16912930352347, 38.57554394858224, 39.46395104272025, 40.71156958171299, 40.02964905330113, 39.81709671020508, 39.45381709507534, 38.609294823237825, 38.77011782782418, 38.14104529789516, 39.95153045654297, 39.979677609034944, 40.33670384543282, 38.16600322723389, 42.957077980041504, 40.33560603005545, 41.602721214294434, 41.189939158303396, 41.176459653036936, 40.01477643421718, 45.19654144559588, 48.096993991306846, 52.65217740195138, 51.63327619007656, 56.824150289808, 38.26797151565552, 25.480859449931554, 51.58717489242554, 51.78097404752459, 53.157228061131065, 50.663206917899, 50.76998335974557, 48.441065311431885, 46.368098054613384, 44.97266353879656, 39.643850326538086, 40.23902606964111, 40.730659757341655, 39.301088741847444, 39.942393575395855, 38.71833290372576, 39.57665777206421, 39.52265289851597, 40.881119523729595, 42.33555119378226, 41.55951384135655, 43.536255495888845, 46.82751989364624, 51.417788233075825, 52.714346408843994, 53.07357175009591, 53.38463217871529, 50.9437369619097, 47.074601309640066, 41.69575064522879, 40.35972670146397, 40.9469050679888, 41.178464208330425, 40.07458652768816, 40.15974712371826, 38.181275367736816, 45.819648947034565, 52.062452520642964, 53.75096900122506, 52.266361304691856, 54.40639952250889, 53.716571944100515, 54.60534381866455, 51.0194445337568, 46.69959660938808, 46.28956256593977, 45.50809867041451, 44.332932472229004, 45.91112545558384, 45.452422755105154, 45.043371881757466, 51.86076716014317, 54.17531285967146, 54.75385114124843, 58.580331802368164, 51.74704251970564, 10.648107392447335, 6.366486285414014, 13.123460463115148, 10.128479412623815, 0.20099562965333462, 0.13751680590212345, 6.163526364735194, 43.96348980494908, 47.23615040097918, 40.93175452096121, 35.991738183157786, 51.496705872671946, 38.20022657939366, 57.00357709612165, 57.0016941343035, 61.84851428440639, 19.34814487184797, 0.2637253371732575, 0.12146196168448244, 0.1647962342415537, 0.05224998860753008, 0.1251697348696845, 0.12051797019583838, 0.18981297899569782, 0.14639255963265896, 0.13051644153892994, 0.10672965685703925, 0.12130033464304038, 0.11697586812078953, 0.08859880760844265, 0.11272177925067288, 0.13902179657348565, 0.13367294573358127], [0.0245450475652303, 0.05948255783213036, 0.0316236843355, 0.07231787552258798, 0.0895355659137879, 0.021608439606747458, 0.0467545979523233, 0.05829119283173766, 0.03340868266033275, 0.01667685218022338, 0.05810359825513192, 0.02393601997755468, 0.08974067347922496, 0.060731801869613786, 0.047080196373696835, 2.407552548817226, 47.180658612932476, 50.421753542763845, 49.54080881391253, 36.34300088882446, 25.36397511618478, 17.898288590567454, 46.44034889766148, 35.751830782209126, 43.21344913755144, 18.05930440766471, 0.07949332227664334, 0.24225898619209016, 0.496210053563118, 10.82521002633231, 13.136379769870214, 2.1779119798115323, 34.44635806764875, 58.53413322993687, 56.0664700780596, 55.21960278919765, 50.39347090039934, 42.983866759708945, 45.01200771331787, 48.91648885181972, 52.23279455729893, 52.39091123853411, 54.740250042506624, 50.68330110822405, 54.6029988016401, 51.22456577845982, 44.39745691844395, 39.726658957345144, 37.77840839113508, 37.763448919568745, 37.6683280808585, 36.098403453826904, 36.80782495226179, 35.99699796949114, 40.94777011871338, 41.57180173056466, 44.03494855335781, 42.694755690438406, 42.736180850437705, 38.98466430391584, 38.53055436270577, 35.479763644082205, 36.44827651977539, 35.4780787059239, 37.850725242069785, 35.84412717819214, 36.79484224319458, 37.22822570800781, 35.93849066325596, 35.285578863961355, 34.83886180605207, 36.46593189239502, 35.91736466544015, 35.38640417371477, 35.764219420296804, 34.57744625636509, 37.36141920089722, 35.3278933933803, 37.76540831157139, 37.87715966360909, 38.86306735447475, 35.20602893829346, 38.44215938023159, 36.133217402866904, 45.57466588701521, 43.20159551075527, 54.269978591373985, 32.15703432900565, 20.80630772454398, 50.08249732426235, 41.0276882989066, 48.81436422892979, 45.867025239127024, 50.82348448889596, 46.11299841744559, 47.06221614565168, 41.18193483352661, 36.498737812042236, 34.91835962023054, 37.296536922454834, 35.25798061915806, 37.30327320098877, 35.68149069377354, 36.76516648701259, 35.61547238486153, 37.59001840863909, 36.53749138968331, 36.04523583820888, 36.91225985118321, 36.314207553863525, 36.398708071027485, 39.17431885855538, 38.52685097285679, 41.07073238917759, 39.134033203125, 37.19631610597883, 35.81220020566668, 36.38130283355713, 36.72481829779488, 36.78092500141689, 36.70544672012329, 37.11735330309187, 39.130837031773154, 46.44443096433367, 47.22787857055664, 50.12222364970616, 47.66119602748326, 48.968885217394146, 49.87372480119978, 50.7741105897086, 49.17389529091971, 44.874756472451345, 42.406249114445274, 44.91200229099819, 40.09272480010986, 37.89711141586304, 40.35350111552647, 42.52169343403408, 44.81741646357945, 49.53476388113839, 53.210944584437776, 54.63607570103237, 54.17086948667254, 18.777967010225566, 0.06669541222176381, 2.128600831542696, 5.819420303617205, 0.17903914568679674, 0.043226361740380526, 0.6150816806725093, 23.149551221302577, 41.92752865382603, 30.371548788888113, 12.354848997933523, 22.072740248271398, 34.199283599853516, 37.77622665677752, 44.660102299281526, 46.62977416174752, 26.55148478916713, 0.5162511010255132, 0.03800201529104795, 0.07712714174496275, 0.04574910404958895, 0.08283980949116604, 0.030807715441499437, 0.02134843516562666, 0.0192702333775482, 0.026261193245383244, 0.0814338442204254, 0.008053100418432482, 0.04222929524257779, 0.054184929600783756, 0.029651043936610222, 0.03462692443281412, 0.02044565959035286, 0.02503294817038945, 0.05662905005738139, 0.03396508137562445, 0.01650979516229459, 0.053001934329846075, 0.032910563317792754, 0.030312330595084598, 0.03458890950839434, 0.036861811831061325, 0.041472280863672495, 0.05427564634010196, 0.055181521124073436, 0.01893570034631661, 0.07343625051102468, 0.032866865662591796, 3.8614709206989835, 56.35308674403599, 56.29421813147408, 56.89367743900844, 40.531739779881065, 28.79328284944807, 21.714385168892996, 45.64571469170706, 36.364293643406455, 49.67449910300118, 18.99751271520342, 0.042441225477627346, 0.0776113782610212, 1.3672855177095957, 12.26014939376286, 8.386405348777771, 3.385868464197431, 35.452425956726074, 61.70724351065499, 58.41942541939871, 58.35421657562256, 51.492707184382844, 45.92698124476841, 45.000098500932964, 50.78233725684029, 53.75452300480434, 54.65998445238386, 55.163343225206646, 52.807636397225515, 54.64455597741263, 53.428068842206685, 46.007469177246094, 41.6293362889971, 39.201986585344585, 39.40859127044678, 39.41725219999041, 39.19127941131592, 37.69931009837559, 38.26656103134155, 42.91020890644619, 43.33887801851545, 46.616308552878245, 44.93831164496285, 44.738978249686106, 40.39809465408325, 40.11927386692592, 37.931459835597444, 38.14254263469151, 37.53256722858974, 39.05926711218697, 36.56458241598946, 37.17500945499965, 38.7084629876273, 37.441931452069966, 36.72432497569493, 36.74375908715384, 38.04738705498831, 37.78794479370117, 37.34999636241368, 37.64140381131853, 37.34511872700283, 37.78883416312081, 37.56720052446638, 40.11666134425572, 39.867551054273335, 41.625813552311485, 36.709841455732075, 38.89110333578927, 37.28596523829869, 47.67648901258196, 45.91275480815342, 55.926456928253174, 34.10388135910034, 21.386081048420497, 49.92106635229928, 41.34760420663016, 50.906970569065635, 47.160679067884175, 52.316631521497456, 48.82401180267334, 49.459994316101074, 43.28561660221645, 38.29197406768799, 36.7614665712629, 38.71013750348772, 37.91148376464844, 37.97575460161482, 37.00550815037319, 38.67501435961042, 37.34304468972342, 38.19263219833374, 38.53349345070975, 38.693708487919395, 37.80373804909842, 38.835705348423545, 39.389448983328684, 41.52699627195086, 40.268284933907644, 43.83151919501168, 40.91107668195452, 38.84054476874215, 36.656983034951345, 38.27771636417934, 39.09330633708409, 37.92331307274954, 38.88409955160958, 38.58420835222517, 39.887075492313926, 49.092375550951274, 49.31954690388271, 52.70831189836775, 49.38679851804461, 49.64899921417236, 52.299660546439036, 53.1675774029323, 51.06369413648333, 46.22203649793352, 44.629102911267964, 46.5250370161874, 42.74058253424508, 39.61148909160069, 42.353710310799734, 43.46116631371634, 47.24757671356201, 50.53421013695853, 55.53143794195992, 55.94713476725987, 57.00724227087838, 21.615540095738, 1.109423211642674, 2.803422906569072, 7.239226494516645, 0.3685754452432905, 0.07001634580748421, 0.437460863164493, 25.232796600886754, 44.070318358285085, 30.952518939971924, 14.861501966203962, 29.4381069455828, 41.370804241725374, 41.82573754446847, 51.57899338858468, 51.50190659931728, 35.66437380654471, 0.5513872184923717, 0.06477420138461248, 0.09298432871167149, 0.011881027736568024, 0.029173660624240125, 0.03268363067348089, 0.07221857870795897, 0.03800057001145823, 0.0372905102558434, 0.04030110906543476, 0.02221432388094919, 0.02372729921314333, 0.03097597516274878, 0.03579863566639168, 0.08394777575241667, 0.025456910420741354, 0.09278620327157633, 0.13677851908973285, 0.12204214983752795, 0.13494480534323625, 0.13007106472338947, 0.16297465270119055, 0.11348874773830175, 0.18292508859719547, 0.13385133258998394, 0.08849863548363958, 0.11430330867213861, 0.1216487352337156, 0.15091221353837422, 0.12872683256864548, 0.10614271728055817, 6.562892752034323, 63.72304793766567, 62.424262864249094, 63.94973986489432, 48.97974872589111, 35.26581123897007, 25.81663809503828, 57.34797845567976, 46.860273701804026, 55.064772605895996, 22.385829550879343, 0.1890034188649484, 0.41023122572473114, 0.46451741989169804, 23.356739555086406, 24.189969267163956, 3.94388393844877, 38.26471628461565, 60.98218509129116, 60.1361654826573, 60.39228997911726, 54.687026841299875, 48.46173620223999, 46.687044688633506, 53.404847962515696, 56.56365885053362, 57.04639189583914, 58.139027391161235, 53.92515686580113, 57.90673174176897, 56.38375261851719, 49.21561574935913, 43.0484676361084, 41.710459981645855, 42.13847943714687, 41.939771379743306, 40.21479770115444, 39.12996155875069, 40.31746080943516, 46.419799600328716, 44.66615070615496, 49.032489027295796, 45.7675895690918, 47.53451647077288, 43.07033361707415, 41.99686472756522, 38.798963274274556, 39.31666660308838, 39.443019594464985, 41.33441999980381, 37.968274865831646, 40.0727904183524, 40.42327145167759, 39.31008665902274, 38.5037899017334, 38.088860852377756, 40.20566776820591, 39.3669889313834, 39.53686891283308, 39.47867774963379, 39.05680397578648, 40.2823098727635, 39.503642627171104, 42.048347405024934, 42.625457831791465, 44.454400879996165, 39.03203017371041, 41.504039423806326, 39.253882680620464, 49.7824706350054, 48.01057924543108, 58.63230432782854, 36.7226539339338, 23.728179829461233, 48.0061845098223, 42.51040261132376, 51.233660970415386, 48.45454829079764, 53.89226756777082, 49.619323457990376, 51.80351052965437, 46.54931402206421, 40.82103497641427, 38.85621295656477, 41.6892123903547, 39.94441897528512, 40.45218290601458, 39.79706852776663, 41.003942830221995, 38.80778748648507, 41.206781591687886, 40.53965377807617, 39.69646903446743, 39.60075759887695, 41.02068451472691, 40.10433176585606, 42.830756255558555, 41.742428643362864, 45.29238142286028, 43.13282571520124, 42.02075263432094, 38.402092593056814, 40.61862005506243, 40.372987338474815, 39.85899087360927, 39.99726349966866, 40.074485778808594, 42.61261756079537, 51.28449051720755, 51.69490671157837, 55.880494594573975, 51.866895471300396, 51.2413387298584, 55.07788038253784, 54.78792858123779, 55.06600243704659, 47.9771340915135, 46.813064166477744, 50.119270665305, 44.58582953044346, 42.12484359741211, 44.38856322424752, 47.21333251680647, 48.2610513823373, 54.01136663981846, 57.44001082011631, 59.8704594203404, 58.46353258405413, 24.139480182102748, 2.2573463916778564, 5.39326947927475, 9.97555216721126, 0.715220530118261, 0.15259485824831895, 0.8529210154499326, 31.344960144587926, 57.08435685294015, 43.08302102770124, 18.675069400242396, 31.240987300872803, 44.802415302821565, 48.83143595286778, 59.3039311000279, 57.765061446598594, 42.7654709815979, 1.513611540198326, 0.15180497563311032, 0.19272461347281933, 0.10546533577144146, 0.15029554734272615, 0.15007768331893853, 0.13548124155827931, 0.17125986383429595, 0.16292046489460127, 0.16726405253367765, 0.08529413172176906, 0.1595219001173973, 0.12629918354962552, 0.11127228595848594, 0.21325278122510227, 0.09977391974202224], [0.03412315628624388, 0.0386462469718286, 0.036529679117458205, 0.03405680573944535, 0.027762429921754768, 0.07100834364869765, 0.020559719630650113, 0.03618400963023305, 0.03394685931769865, 0.08423394111118146, 0.09030475321092776, 0.04850149653585894, 0.05603891458096249, 0.03966933868027159, 0.024971595034003258, 12.119232978139605, 57.554037707192556, 50.093135016305105, 49.03796420778547, 32.45074510574341, 25.18258023262024, 18.658761978149414, 36.05085693086897, 35.61673695700509, 47.49187190192086, 6.372206389904022, 0.2838604567306382, 0.07859268917569093, 1.329730178628649, 4.607343103204455, 5.670769240174975, 3.197386200938906, 35.12501641682216, 59.52864279065813, 54.86715541567121, 55.19409247807094, 49.28871079853603, 43.24888147626604, 41.76958220345633, 41.707732813698904, 44.69897747039795, 49.60626431873867, 50.54858248574393, 51.72026416233608, 50.44906691142491, 44.15812969207764, 38.953786509377615, 37.2207807132176, 35.99119969776699, 35.40828405107771, 38.77340085165841, 34.98088298525129, 38.43297038759504, 38.221602712358745, 41.718169007982524, 45.34172405515398, 47.78304311207363, 46.30470963886806, 45.892219407217844, 39.4333233833313, 37.774913447243826, 35.27668169566563, 37.15485620498657, 35.874060017721995, 37.041392121996196, 36.99175419126238, 36.48994834082467, 37.59775870186942, 37.096633774893625, 35.59379053115845, 36.4520320211138, 35.78277805873326, 35.70731367383684, 35.289282253810335, 36.85071965626308, 35.16657011849539, 41.480644839150564, 42.42453677313668, 46.26804746900286, 43.07775081907, 44.46939161845616, 42.32653938020979, 43.12425511223929, 39.556400299072266, 47.26236942836216, 44.54825019836426, 54.219444343021934, 32.02651241847447, 24.69650510379246, 48.52292551313128, 40.881685801914756, 49.92275129045759, 46.62396546772548, 49.756661551339285, 46.403370584760395, 49.470347132001606, 44.60602446964809, 38.785181522369385, 34.855937004089355, 36.22028875350952, 34.164973395211355, 35.615243094308035, 35.744549070085796, 36.071871757507324, 34.80588912963867, 36.26827301297869, 35.322703089032856, 36.68062775475638, 35.86256422315325, 36.41758285249983, 36.78581305912563, 36.16702733721052, 35.48218509129116, 34.39876985549927, 34.49625655582973, 36.46939556939261, 35.91032266616821, 35.85501153128487, 36.1781131880624, 37.511892863682334, 37.84309959411621, 37.73034075328282, 44.602161271231516, 48.58058861323765, 51.17739793232509, 50.1196528162275, 49.844910621643066, 47.363945143563406, 47.57782111849104, 49.604787826538086, 49.75724172592163, 49.15177917480469, 44.627946036202566, 41.97256687709263, 40.621197836739675, 40.96859386989048, 41.10053668703352, 45.04940986633301, 50.42513384137835, 51.00973095212664, 52.57681376593453, 52.22355692727225, 56.014438492911204, 42.70229796000889, 7.623958672795977, 0.2701691399727549, 5.7882541588374545, 0.14124831424227782, 0.06883408674704176, 0.020934293013332144, 10.167748894010272, 37.82211256027222, 28.2574360370636, 34.85184451511928, 14.423310347965785, 21.556664534977504, 29.65389714922224, 46.746503898075645, 43.40127979006086, 46.396158354622976, 5.234948694705963, 0.3238711969128677, 0.03471724083647132, 0.08608890657446214, 0.025554025745285407, 0.029622460648949658, 0.062458286727113385, 0.07497678284666368, 0.04891476846699204, 0.04644373731155481, 0.04705914143206818, 0.03306848895070808, 0.01598716034953083, 0.057070291201983175, 0.029301160746919255, 0.013626234223400908, 0.06248841368194137, 0.0288196926537369, 0.05208738786833627, 0.013588137026610119, 0.0450651611068419, 0.061329394445887635, 0.022912648373416493, 0.039205821231007576, 0.04352348204702139, 0.06870819135968174, 0.03189547832256981, 0.08897558453359775, 0.04893120937049389, 0.05935143093977656, 0.07022793338234935, 15.956247976848058, 68.66976233891079, 54.17599378313337, 56.47197389602661, 39.04029853003365, 31.837194851466588, 16.532302277428762, 32.58115931919643, 40.78056519372122, 50.889916215624126, 6.751895913055964, 0.32058882447225706, 0.051518066453614404, 2.1740034009729112, 11.435839431626455, 8.113151805741445, 3.4068683087825775, 36.65687533787319, 62.26835223606655, 55.668918473379954, 57.45068672725132, 50.0877571105957, 44.891272340502056, 43.72617060797555, 42.74081877299717, 47.479927948543, 52.44506549835205, 52.667630195617676, 53.723551409585134, 51.513975620269775, 47.04586008616856, 41.073942456926616, 39.68081821714129, 38.02609430040632, 36.93177386692592, 39.19331523350307, 37.22520324162075, 39.83112859725952, 40.34546899795532, 43.588280132838655, 47.72785357066563, 49.646171297345845, 47.5172884123666, 47.2099278994969, 41.0501309803554, 38.027119159698486, 37.646208490644185, 38.17222881317139, 36.56996032169887, 39.212096214294434, 39.1803742136274, 39.53986358642578, 39.87600353785923, 37.65296213967459, 36.33536829267229, 38.284355367933, 38.11961357934134, 38.403329372406006, 36.28553581237793, 39.1659289087568, 37.75577116012573, 41.88584641047886, 45.296473911830354, 48.21351180757795, 45.87621075766427, 46.39999723434448, 44.395935262952534, 45.01715285437447, 41.80518477303641, 49.52529001235962, 47.05241223743984, 56.377349853515625, 34.5860481262207, 26.294604676110403, 47.371661118098665, 42.006338596343994, 50.43755374635969, 46.25027397700718, 49.6018556867327, 48.42455986567906, 50.29122468403408, 45.53220544542585, 41.46068613869803, 37.66727195467268, 38.52464839390346, 35.45706387928554, 38.7088486126491, 37.634486879621235, 37.5075398172651, 36.5392701285226, 38.19497374125889, 37.88474014827183, 39.002024378095356, 37.74651615960257, 37.681786741529194, 38.37053040095738, 38.98326424189976, 37.06915364946638, 36.62039729527065, 35.234752791268484, 38.167212213788716, 37.536256722041536, 38.45668806348528, 38.11198445728847, 38.74269676208496, 39.612969057900564, 40.037114892687114, 47.61886412756783, 51.76589298248291, 52.2300500188555, 51.06493091583252, 50.08475201470511, 50.265109879629954, 49.20823676245553, 51.15070295333862, 53.516710485730854, 50.913481031145366, 47.056007930210654, 43.31450721195766, 42.833973271506174, 43.28374753679548, 44.39637647356306, 47.65179858888899, 53.56612607410976, 52.17658363069807, 54.31665658950806, 55.63118280683245, 56.12553671428135, 43.08457395008632, 9.443304521696907, 1.1976724990776606, 6.892142696040017, 1.0115101741892951, 0.06260943040251732, 0.05842247578714575, 10.817023311342512, 43.97272743497576, 29.053729125431605, 35.41328675406319, 21.570456709180558, 27.710475581032888, 33.940939153943745, 51.30877447128296, 49.25997999736241, 57.604234967912944, 9.275194593838282, 0.38953452344451633, 0.02744195613610957, 0.029520337735967975, 0.04328749096021056, 0.03283696601699505, 0.02087120113096067, 0.02588097784402115, 0.025383275800517628, 0.047866177412548234, 0.04376982079286661, 0.006018221819041563, 0.04414129835952606, 0.024359072990981594, 0.05681539273687771, 0.06256980395742825, 0.12761840490358217, 0.06575518660247326, 0.08182343188673258, 0.11613810807466507, 0.11945931985974312, 0.2226320079394749, 0.10105178438659225, 0.11962550665651049, 0.14857764595321246, 0.12217294424772263, 0.15305380576423236, 0.113129266670772, 0.14417738706937858, 0.13187492292906555, 0.21780869604221412, 23.018754856927053, 75.9911973135812, 61.06889860970633, 63.167268480573384, 44.78773375919887, 35.81670611245291, 29.245433398655482, 47.494262082236155, 47.36309398923601, 59.936154638017925, 7.633706995419093, 0.4667484973158155, 0.15093269172523702, 5.350573233195713, 13.868840626307897, 14.674232380730764, 6.06247958115169, 40.21372767857143, 63.717016901288716, 59.17304788316999, 59.29657295772007, 53.056771005902974, 47.938714027404785, 46.240063599177766, 45.577639716012136, 50.24911860057286, 54.106178283691406, 55.23987068448748, 57.352029255458284, 54.52280616760254, 48.06526156834194, 43.10525178909302, 40.90339544841221, 40.06407042912075, 38.45072998319353, 41.05536297389439, 38.78238487243652, 41.96561867850167, 41.44014378956386, 45.37290757043021, 50.72210679735456, 50.697833265577046, 50.5185523714338, 49.226937838963096, 42.70430598940168, 39.851229735783164, 38.31479890005929, 41.483441489083425, 39.18327508653913, 42.25877707345145, 40.488164152417866, 40.25455181939261, 42.4124573298863, 39.70353535243443, 38.444292477199006, 40.41376979010445, 40.22955914906093, 39.44971070970808, 37.49710709708077, 40.9273111479623, 39.49458565030779, 46.34109040669033, 47.15991824013846, 50.71329995564052, 47.320185388837544, 48.857654980250764, 46.64477184840611, 47.01165063040597, 44.20477294921875, 51.63489859444754, 48.32940081187657, 56.821141719818115, 37.14463887895857, 28.18214362008231, 47.99413980756487, 42.96778515407017, 51.96380199704851, 48.75142397199358, 51.340798718588694, 50.73104565484183, 51.783468450818745, 48.69894422803606, 43.410430567605154, 39.11073241915022, 40.24124949319022, 38.48220879690987, 41.52759381702968, 39.82727582114083, 39.10248143332345, 38.05214657102312, 40.667889731270925, 40.029895714351106, 40.73528725760323, 39.69799068995884, 38.26827028819493, 41.43582548413958, 41.070784500667024, 39.90453631537301, 38.049429825374055, 38.61340468270438, 40.193338189806255, 38.21890333720616, 40.283411162240164, 41.045308930533274, 40.92129053388323, 41.695076669965474, 41.63898386274065, 50.34033455167498, 53.002043519701274, 56.74177244731358, 52.287198952266145, 51.15917975561959, 50.52889476503645, 50.21591315950666, 53.06063073022025, 54.157174587249756, 53.04504592078072, 48.24911437715803, 45.61088684626988, 46.096618039267405, 45.902294295174734, 46.396245207105366, 49.07628699711391, 54.90073258536202, 55.549294812338694, 57.145883151463096, 56.87734917231968, 58.61214760371617, 46.48980964933123, 13.60365046773638, 5.550560627664838, 11.929376925740923, 0.7997850467051778, 0.14237308103059018, 0.2565639428794384, 13.173677699906484, 49.89462150846209, 39.96117803028652, 48.59988028662545, 21.472732033048356, 31.02360248565674, 40.38987146105085, 60.36378846849714, 56.13049077987671, 63.757775034223286, 11.941948822566442, 0.3969604106886046, 0.151659131316202, 0.1687518898397684, 0.13598417171410151, 0.09867471336786236, 0.1068604580525841, 0.07600736218903746, 0.06251689179667405, 0.1268269345164299, 0.11880977185709135, 0.08753611320363623, 0.13646856429321425, 0.11788794132215635, 0.11410749703645706, 0.1774828170559236], [0.008519223442168107, 0.035716404007481675, 0.021412919741123915, 0.041074516850390604, 0.03466082404234579, 0.046484775109482665, 0.02734691882506013, 0.020668241128857647, 0.05100436455437115, 0.06255571757044111, 0.059127229398914745, 0.07950395492038556, 0.039841503370553255, 0.051121839322149754, 0.16040619409510068, 24.429178374154226, 55.755708421979634, 48.83621631349836, 47.82429109300886, 29.550101484571183, 9.348360862050738, 25.061735425676616, 38.51640783037458, 33.679582663944785, 46.06582709721157, 1.0687821124281203, 0.07689328465078558, 0.08222351648977824, 7.142785498074122, 14.439316391944885, 5.990577016557966, 6.079536974430084, 40.7226311138698, 60.32068879263741, 53.338096618652344, 52.34947913033621, 45.42449794496809, 42.36678334644863, 38.65706716264997, 39.85395690373012, 38.95124694279262, 39.82034151894705, 39.15673644202096, 39.70492499215262, 39.56532526016235, 38.867726121629985, 37.45560203279768, 36.57577248982021, 38.46303176879883, 36.782825333731516, 37.82198749269758, 36.663799217769075, 37.972339562007356, 38.97666692733765, 42.96361970901489, 48.20387813023159, 49.51978703907558, 47.29556097303118, 49.51832444327218, 43.795739446367534, 38.718457971300396, 37.51254946844918, 37.02099568503243, 36.142764227730886, 36.028719970158164, 35.40035615648542, 35.54047352927071, 36.69531624657767, 36.48621368408203, 36.55376754488264, 37.50333268301827, 34.76733010155814, 36.58889763695853, 34.77475772585188, 36.244009903499055, 40.723645550864084, 46.080838680267334, 45.42632532119751, 50.16426372528076, 47.005529267447336, 48.32523536682129, 46.10243368148804, 47.6142018863133, 42.61334364754813, 48.63585805892944, 47.153946263449534, 55.39842510223389, 33.25644431795393, 27.212586777550833, 51.0773925100054, 43.73500524248396, 51.394376277923584, 45.334077562604634, 47.36882277897426, 46.41406038829258, 49.719961166381836, 42.71183436257498, 37.06866380146572, 35.739525522504536, 35.73477642876761, 36.07850728716169, 36.260449341365266, 35.114538533346995, 36.868361132485525, 36.51589291436331, 36.389369692121235, 36.405909878867014, 36.96132108143398, 35.417886461530415, 35.87829147066389, 35.99072027206421, 35.866608074733186, 34.94230311257498, 36.22736201967512, 35.9988739831107, 36.02301549911499, 35.317967891693115, 38.205823353358674, 36.34307037081037, 36.924770082746235, 35.62943826402937, 43.10272264480591, 48.68872690200806, 49.66389615195138, 48.00826896939959, 47.61510862622942, 51.365600313459126, 49.071676867348806, 50.50623321533203, 50.00925636291504, 49.39034904752459, 48.6960711479187, 45.02061653137207, 40.59117814472744, 39.74759040560041, 39.78599657331194, 46.55462939398629, 48.21090623310634, 50.67406347819737, 53.307809420994346, 55.24826758248465, 53.628024101257324, 57.926638330732075, 51.55559185573033, 29.79070370537894, 3.2296201969896043, 3.091403373650142, 3.0405073847089494, 0.16143635953111307, 0.03869821936158197, 2.5467903230871474, 38.27111210141863, 37.80453014373779, 28.040348257337296, 15.523366519383021, 24.280750955854142, 32.07603570393154, 44.511667932782856, 44.5587454523359, 48.39126409803118, 24.428740637642996, 0.365943435047354, 0.036974530068359206, 0.02385378153329449, 0.054482002409973314, 0.02675877315258341, 0.021731739597661153, 0.07300597109964915, 0.010132723737375011, 0.010095820762217045, 0.007211917163138943, 0.0591182659513184, 0.07957503146358899, 0.040524201201541085, 0.03229870454275182, 0.03228014660999179, 0.03771093733874815, 0.03248894879860537, 0.035065956945930205, 0.041890244864459546, 0.014128430713234203, 0.043862325471958945, 0.04942371044307947, 0.038022242419953854, 0.03092672030574509, 0.0037720054304892464, 0.027059045254385898, 0.04922825164560761, 0.013265626787740206, 0.059738161973655224, 0.6478582876069205, 32.49538728169033, 62.10986382620675, 54.50556768689837, 54.62980842590332, 36.20041690553938, 18.30020366396223, 24.889050109045847, 34.03614684513637, 39.2749148777553, 49.18067673274449, 1.071107261947223, 0.05485117635024445, 0.11212991350995642, 5.160650304385594, 8.981203283582415, 4.018937945365906, 4.934024819305964, 42.4631861277989, 61.072872979300364, 54.862500122615266, 55.65818350655692, 47.34830127443586, 43.20367997033255, 40.05444369997297, 42.43238128934588, 41.34965739931379, 42.122773034232004, 41.90893874849592, 41.10605008261544, 42.506091254098074, 40.88254737854004, 39.15203251157488, 37.75695930208479, 40.39927932194301, 38.33471243722098, 38.567122731889995, 37.72000183377947, 40.329529830387656, 40.62551266806466, 45.35381044660296, 49.97481066840035, 50.20015117100307, 50.40050595147269, 50.49575533185686, 46.08820029667446, 38.977497237069265, 38.29970046452114, 38.39804526737758, 37.843120438711985, 38.00412062236241, 38.04851961135864, 35.47055728094918, 37.566519601004465, 39.120960167476106, 38.16784449986049, 37.12193216596331, 36.99017347608294, 38.06073107038225, 36.6034506389073, 39.11693716049194, 41.978761196136475, 48.524638244083945, 47.6931368964059, 51.263235977717805, 48.0352349281311, 50.34204728262765, 49.687210832323345, 49.90857696533203, 45.021460737500874, 49.88855573109218, 48.89601598467146, 57.10795988355364, 34.98188699994768, 27.573623861585343, 51.94850901194981, 45.98510640008109, 53.239063944135395, 46.88423803874424, 49.56735093252999, 47.77300296510969, 50.85126338686262, 44.51778929574149, 39.82931859152657, 38.29386050360543, 38.381522451128276, 38.175296442849294, 38.73822212219238, 36.62854405811855, 39.207336698259624, 37.64845623288836, 38.28929206303188, 37.955392905644004, 37.93692111968994, 37.235653332301546, 37.50632735661098, 37.39741434369768, 38.664682388305664, 37.46120922906058, 38.61845602308001, 37.831002780369346, 38.68287624631609, 36.59149973733084, 39.09463691711426, 38.00234535762242, 37.51896612984793, 38.28359106608799, 44.52021074295044, 51.51031391961234, 51.197224617004395, 50.08077417101179, 49.481759548187256, 52.631631578717915, 51.45751803261893, 52.66411788122994, 50.38079391207014, 51.526642186301096, 51.22268976484026, 46.24137333461216, 41.80766180583409, 41.62552867616926, 40.26277501242501, 48.963542052677695, 50.154258319309776, 51.52834449495588, 55.029357637677876, 57.29032230377197, 56.04286009924752, 57.41168301446097, 54.54172958646502, 32.09046711240496, 3.152238109282085, 4.902624607086182, 6.792267118181501, 0.1818154395690986, 0.07327129864799124, 2.598474932568414, 43.95989063807896, 36.66868380137852, 29.77495561327253, 16.56261726788112, 26.05669140815735, 37.70314202989851, 50.363649232046946, 50.15996626445225, 54.29781307492937, 32.32540307726179, 0.467122668666499, 0.05056745585586343, 0.05956621441457953, 0.022957284103280733, 0.025738619500771165, 0.010246635348136936, 0.07829156211976494, 0.07089844811707735, 0.013013430588346506, 0.031113056199891225, 0.038389323079692464, 0.01212156331166625, 0.03957447948466454, 0.035104568981166394, 0.01972792560367712, 0.10467337005372558, 0.14481514213340624, 0.19439094620091574, 0.1032799780368805, 0.08722771225231034, 0.10478215957326548, 0.13525716215372086, 0.09131697139569692, 0.20127467039440358, 0.1316477765462228, 0.15253947622009686, 0.22940905285733088, 0.0999126530119351, 0.1563545936452491, 1.3440495473997933, 40.7134108543396, 68.06093338557652, 62.27159704480852, 61.013097626822336, 40.012222971235005, 15.814562048230853, 35.87540796824864, 51.250270639147075, 45.138082776750835, 56.152808393750874, 1.606400715453284, 0.20810464104371412, 0.19317132021699632, 15.600347348621913, 28.36189525468009, 11.83877067906516, 9.212170958518982, 44.52021769114903, 62.79351793016706, 57.60650702885219, 58.134816782815115, 49.380656310490195, 45.387404986790244, 42.35561759131295, 44.28525045939854, 42.761691161564414, 43.93744795663016, 45.31431341171265, 42.839924403599326, 44.43428584507534, 43.38563939503261, 41.436978885105674, 40.58606079646519, 42.32060561861311, 40.932768957955496, 40.996577739715576, 39.76803895405361, 41.269044399261475, 42.33385583332607, 47.7396377154759, 50.976970195770264, 52.55191142218453, 50.77520840508597, 53.36457967758179, 48.468343939099995, 42.11269467217581, 40.800864355904714, 40.02085610798427, 39.557102067129954, 39.65018013545445, 38.76331901550293, 36.8686112676348, 39.17702865600586, 40.62932028089251, 40.367807456425254, 40.128039019448416, 38.235321930476594, 39.919558320726665, 39.31615243639265, 40.87951448985508, 44.70596388408116, 50.56526858466012, 49.33790404456002, 53.87092270169939, 51.055286816188264, 52.617002146584646, 52.61755452837263, 53.452491760253906, 47.7683025087629, 50.50505896977016, 50.4500744002206, 58.39455781664167, 37.59639685494559, 30.199872698102677, 52.70316328321184, 47.85629449571882, 56.07849393572126, 49.63071502958025, 50.54323237282889, 48.98873969486782, 53.14531537464687, 47.53222009113857, 42.26251867839268, 40.31552921022688, 39.2877516746521, 41.1720301764352, 39.68047775541033, 39.1706988470895, 41.02663912091936, 40.891128403799875, 40.26166330065046, 40.54873854773385, 41.169212681906565, 38.71023825236729, 39.48232555389404, 39.691535813467844, 40.123144013541086, 38.47244310379028, 40.115834508623394, 39.345449515751426, 40.402590138571604, 38.430767808641704, 41.62275287083217, 39.70873955317906, 40.337634904044016, 40.388870920453755, 48.010023389543804, 54.10843644823347, 53.67217295510428, 51.36822325842721, 50.24288259233747, 55.77484376089913, 53.56977040427071, 55.46748324802944, 53.33439670290266, 53.80478627341134, 51.688007150377544, 48.47838756016323, 44.939746447971885, 44.63712808064052, 42.861741747174946, 51.71177693775722, 52.71185200554984, 55.63718605041504, 57.6822840826852, 59.292327608381, 57.90103769302368, 61.88441562652588, 56.286821774074006, 35.23277950286865, 7.503885115895953, 7.048961366925921, 5.899789682456425, 0.2785780073276588, 0.23075931040304049, 3.6652177487100874, 50.66375582558768, 49.104079791477744, 37.1805089541844, 22.351838963372366, 33.62537629263741, 41.938055174691335, 57.38903188705444, 56.57868432998657, 62.142978940691265, 36.467033181871685, 0.7642135268875531, 0.13515924955052988, 0.11264500301331282, 0.09709760120936803, 0.12519998396081583, 0.05278873523431165, 0.15937836281955242, 0.1855068193482501, 0.06486084352114371, 0.12131079765302794, 0.12738786584564618, 0.24476986431649753, 0.14272852481475898, 0.13126121514609881, 0.13632903035197938], [0.05200264902253236, 0.04259986696498735, 0.03309365242187466, 0.03181660541200212, 0.03389468336743968, 0.06523679263357605, 0.02627093022290085, 0.02718359205339636, 0.031264841090887785, 0.02875302658815469, 0.042313097710055966, 0.028909551046256508, 0.09510069300553628, 0.08944272875253644, 3.2457048424652646, 41.73117256164551, 54.54394606181553, 53.621920108795166, 38.449899673461914, 23.50308425085885, 19.406077214649745, 29.098359142030986, 32.69625275475638, 46.275436878204346, 25.761665684836252, 0.049284926283040216, 0.03294163343629666, 0.14029791738305772, 0.8520365314824241, 5.0106304458209445, 3.692277942384992, 2.44172574366842, 41.11208111899239, 54.85218552180699, 52.91574689320156, 49.07743344988142, 42.773551736559185, 41.976145199366975, 42.23401716777256, 40.267444201878135, 39.59074177060808, 37.92222220557076, 36.86021784373692, 37.26898036684309, 37.97493124008179, 37.263206413814, 38.2426210130964, 37.13187503814697, 37.12552091053554, 37.41506624221802, 36.04179300580706, 36.203870160239084, 36.83639594486782, 38.010481698172434, 43.49411119733538, 46.834999629429404, 48.20510796138218, 48.22408349173409, 48.5211363519941, 47.518563406808035, 41.7732960156032, 36.38759790148054, 37.99568550927298, 36.52969898496355, 37.528780460357666, 34.72650943483625, 37.03567722865513, 37.95100859233311, 37.54677629470825, 34.695107051304404, 37.42349440710885, 35.846138681684224, 35.892479692186626, 34.35496841158186, 42.69189650671822, 45.854841572897776, 48.38054650170462, 49.221038818359375, 48.52927616664341, 48.17528976712908, 49.27854905809675, 46.68893807274954, 51.28878450393677, 45.61560467311314, 48.338624545506065, 44.12444829940796, 53.600283418382915, 31.371408462524414, 29.64790780203683, 55.38693972996303, 42.46078552518572, 48.52799769810268, 44.91105038779122, 48.716147967747276, 45.35053437096732, 44.95142636980329, 35.74119309016636, 37.412870611463276, 36.310271399361746, 36.95740229742867, 35.95324168886457, 34.969487939562114, 35.14865071432931, 37.1982616015843, 35.61415570122855, 35.57581206730434, 35.62053067343575, 36.1820250238691, 35.93779236929757, 36.88100685392107, 37.17707306998116, 35.70933559962681, 36.454738344464985, 35.24338592801775, 37.194374084472656, 36.853491987500874, 35.63329104014805, 37.074191093444824, 36.008062975747244, 36.87171016420637, 36.7796048436846, 43.313669954027446, 48.48221601758684, 49.445434365953716, 45.8523610660008, 49.78801877158028, 48.561692987169536, 48.579563753945486, 48.61826869419643, 50.304162229810444, 49.599177156175884, 50.10754905428205, 46.7473133632115, 40.49636650085449, 36.88223321097237, 43.61833803994315, 52.09714487620762, 55.49870497839791, 55.11959041867937, 49.30037334987095, 52.24318906239101, 50.75821311133248, 55.111579145704, 52.2195999281747, 51.61738913399832, 9.66700872353145, 0.7490132568137986, 4.994318246841431, 0.10581982282123395, 0.11064413895032235, 0.27232449288879124, 28.866577659334453, 38.06194700513567, 37.462081227983745, 42.86712660108294, 20.403687408992223, 25.22117747579302, 37.99611977168492, 45.171732902526855, 49.09949745450701, 40.268576758248464, 1.8170127740928104, 0.035514458415231535, 0.062276446127465794, 0.05615967006555625, 0.05365179445860641, 0.032775999645569494, 0.04023764907781567, 0.09090393355914525, 0.01556853816977569, 0.058517979591020515, 0.0480686624401382, 0.018514494644477963, 0.024705611003030623, 0.037541849804776053, 0.0463661264761218, 0.03476958981316004, 0.038992628920823336, 0.016358661664915935, 0.019704712920689156, 0.048166734499058554, 0.011782266964603747, 0.05068292555266193, 0.11844250799289771, 0.010529166303708084, 0.03916977745081697, 0.0309169256527509, 0.021906038280576468, 0.05622155924460717, 0.025504146636064564, 4.458046725818089, 50.299246379307334, 62.17666380746024, 58.28351170676095, 49.203261852264404, 27.254672016416276, 16.27244312422616, 29.822123459407262, 36.402025835854666, 50.78369562966483, 28.812640530722483, 0.05667983161817704, 0.02756661658973566, 0.5648543472800935, 3.179024500506265, 9.700545072555542, 4.318257221153804, 5.362525871821812, 41.49964468819754, 58.9882744380406, 53.50143487112862, 52.19647979736328, 44.44920710154942, 45.409719126565115, 44.05014773777553, 43.06140865598406, 39.843729155404226, 39.306553500039236, 38.509480476379395, 37.95935685294015, 38.50751066207886, 39.31015961510794, 40.11581366402762, 38.073519229888916, 39.00658934456961, 39.04772615432739, 38.2490029335022, 36.886436871119905, 38.47239794049944, 40.09694235665457, 44.31891448157174, 49.51878997257778, 50.16314506530762, 49.42568063735962, 51.40769944872175, 49.44401693344116, 43.172409602573936, 37.890093735286165, 39.82818603515625, 38.57287584032331, 38.523449829646516, 36.07114219665527, 39.060170378003804, 37.97550099236624, 37.931949683598106, 36.40458277293614, 39.004112311771934, 37.40419231142317, 37.62804937362671, 35.90049096516201, 44.37611552647182, 47.62387030465262, 50.637856415339876, 50.54081787381853, 50.0205089705331, 48.51317024230957, 51.130966595241, 49.14979893820626, 51.9659628868103, 46.66826718194144, 50.72888476508004, 45.25500358854021, 55.55248750959124, 32.811509472983225, 31.365981919424875, 56.35725218909127, 44.41699525288173, 50.25499677658081, 46.11508287702288, 51.79499898638044, 47.77533755983625, 47.65207999093192, 38.23695475714547, 38.43513127735683, 37.49182646615164, 38.39662088666643, 37.46336317062378, 37.34224912098476, 36.205079146793906, 39.26747335706438, 37.43515001024519, 38.34504440852574, 36.623624733516145, 37.011695521218435, 36.90228223800659, 38.09718826838902, 38.16526671818325, 37.68879747390747, 37.87172964641026, 36.853088991982595, 37.75854696546282, 40.098849637167795, 36.57675565992083, 37.75670221873692, 38.45785883494786, 38.860319341932026, 40.3587817464556, 45.72544527053833, 50.46035426003592, 50.59107766832624, 46.04831763676235, 51.821033886500764, 49.87653534752982, 50.89098971230643, 52.35267530168806, 52.64781393323626, 52.2259783744812, 51.456520966121126, 48.61709097453526, 42.17246307645525, 39.25397300720215, 45.85553986685616, 54.604471819741384, 56.27035454341343, 57.13008989606585, 50.532191685267854, 53.9194141796657, 52.49948031561715, 57.55221380506243, 55.08043384552002, 56.00640637534005, 12.198184490203857, 0.16915189980396203, 8.216183168547493, 0.8914160441075052, 0.1687874857868467, 0.1645905974188021, 30.096855231693812, 43.73087453842163, 32.35778168269566, 42.432756492069785, 29.313400677272252, 31.05157940728324, 42.67699262074062, 52.842373916081016, 55.806652614048545, 48.117032596043174, 2.902966490813664, 0.10458839711334024, 0.05624850047752261, 0.03997701020645244, 0.009322318830527365, 0.03868576485131468, 0.04334101380248155, 0.03274626624105232, 0.05628124997019768, 0.07520868575998715, 0.04733177001721092, 0.012267427136456328, 0.02380119506934924, 0.04556586227512785, 0.07757677297507014, 0.16136858745345048, 0.15226095116564206, 0.0848913329786488, 0.1361766585281917, 0.12251527873533112, 0.11139944342098065, 0.12148588682923998, 0.20654601896447794, 0.09665679093450308, 0.1362455298325845, 0.16847107133695058, 0.12417492110814367, 0.16650432401469775, 0.14023424365690776, 5.573640372071948, 59.44347177233015, 68.77403395516532, 67.36500876290458, 52.64774097715105, 32.29552582332066, 27.372664587838308, 40.93189695903233, 45.010836941855295, 58.02203014918736, 31.322309017181396, 0.1800515606467213, 0.16213450421180042, 0.7339554248111588, 4.343210373606, 14.52998777798244, 13.576108677046639, 4.671369016170502, 43.861521516527446, 59.741070066179546, 56.728178296770366, 54.38676391329084, 47.53825112751552, 46.87746354511806, 46.159971714019775, 44.09270198004586, 42.713415077754426, 41.267613070351736, 40.722144739968435, 39.73378086090088, 41.87571593693325, 40.37042692729405, 42.81161396844046, 38.978181634630474, 40.985762868608745, 40.83908987045288, 40.138148648398264, 39.064638069697786, 41.59472036361694, 41.568532603127615, 46.9317741394043, 51.54433229991368, 51.679106507982524, 51.4346410887582, 52.292653288160054, 53.345402649470735, 45.13823216302054, 41.25269528797695, 42.82548257282802, 39.97969497953142, 40.61381537573678, 37.41817208698818, 40.93687186922346, 40.66263689313616, 40.70394740785871, 39.033812386649, 41.654919556209016, 40.28816025597708, 39.841172218322754, 38.56997496741158, 48.22585875647408, 49.63649940490723, 51.50739567620413, 52.893106188092915, 51.65631294250488, 51.7454548563276, 52.1142270224435, 50.89804560797555, 54.69632353101458, 48.92258937018258, 52.69747270856585, 48.27627835954939, 56.99461044584002, 34.43515757152012, 34.56098249980381, 59.31060137067522, 46.61633634567261, 52.03030320576259, 48.707719802856445, 53.75586748123169, 50.822299821036204, 48.71568938664028, 40.44536672319685, 40.18779352733067, 39.40897342136928, 39.97862148284912, 39.78857782908848, 38.83590337208339, 39.62374223981585, 42.30363811765398, 39.439667088644846, 39.830659593854634, 39.31477321897234, 39.083040373665945, 39.2782986504691, 40.42993130002703, 40.77740376336234, 39.06544058663504, 40.144742488861084, 38.09111901691982, 40.94320862633841, 42.17969267708914, 39.15748684746878, 40.65680388041905, 40.98582540239607, 40.38839496885027, 42.29141623633248, 49.924161774771555, 52.41170024871826, 52.66998563494001, 47.31985534940447, 54.39149563653128, 52.95190184456961, 53.390972409929546, 53.24136727196829, 54.917439528873985, 54.816801820482524, 53.751361574445454, 51.696025371551514, 44.268644264766145, 42.59239482879639, 46.900232791900635, 58.21854952403477, 59.54384544917515, 58.806829180036274, 51.60291951043265, 56.80718278884888, 54.132286139896934, 60.35812568664551, 54.89635174615042, 59.96628202710833, 12.557911838803973, 1.687240943312645, 10.95487470286233, 0.4572308765990393, 0.32774617469736506, 0.6410390649523053, 35.0618051801409, 50.68876934051514, 49.994366373334614, 54.5808618409293, 29.207211358206614, 35.319725785936626, 49.76181016649519, 58.539719581604004, 63.180567332676475, 55.16863775253296, 3.747374551636832, 0.22463314341647284, 0.13468620207692894, 0.22705934037055286, 0.14561822904007776, 0.0716362056721534, 0.1119024550010051, 0.20941778272390366, 0.12421769595571927, 0.16764823906123638, 0.13198089652827807, 0.09804790307368551, 0.17888074847204344, 0.12122714785592896, 0.2187242026307753], [0.047596249396779707, 0.015969777978690605, 0.04099290605102267, 0.03183779606063451, 0.007437943115032145, 0.026848299062943885, 0.02231554264601852, 0.03480071760714054, 0.007693863623509449, 0.042103155582611046, 0.02944704916860376, 0.009512147483681994, 0.020850760263523886, 0.06132178806832858, 7.722285236631121, 55.94330283573696, 42.26252910069057, 45.47049501964024, 22.248715536934988, 33.56260974066598, 44.89733811787197, 30.710172721317836, 32.503117152622764, 46.071354389190674, 12.569374629429408, 0.41643930545875, 0.36766889531697544, 0.7308795441474233, 4.729111152035849, 6.239153598036085, 1.103063547185489, 6.140325461115156, 39.25443853650774, 56.93629421506609, 51.61895595278059, 49.45637777873448, 49.34255586351667, 52.917518683842246, 50.52176938738142, 48.71165248325893, 45.26246247972761, 38.44725240979876, 38.841639110020225, 37.25644929068429, 39.62625401360648, 38.26109627314976, 38.87019273212978, 37.51659332002912, 38.103684834071565, 38.06763410568237, 37.306948798043386, 35.376520361219136, 37.27475084577288, 36.00361960274832, 40.35071836199079, 46.35657794134957, 48.68894577026367, 45.986683641161235, 48.3369083404541, 48.47480923788888, 46.40199831553868, 39.6127849306379, 36.79778480529785, 35.23775788715908, 36.458827359335764, 34.901590142931255, 35.85510185786656, 35.50539207458496, 37.40884760447911, 34.95608833857945, 36.458862100328716, 36.421894209725515, 35.19390433175223, 36.773108278002056, 49.03698798588344, 48.0077235358102, 50.590942178453716, 43.598278590611045, 46.650035108838765, 45.751671246119905, 48.09263399669102, 47.31319202695574, 51.59152446474348, 46.08144317354475, 52.27784667696272, 44.75963871819632, 53.63500009264265, 30.784455912453787, 29.468696389879497, 52.097172669001985, 42.48098393848964, 45.84090001242501, 39.635196345193044, 42.20756884983608, 36.10660580226353, 36.85550001689366, 35.42766605104719, 35.95856748308454, 34.092152799878804, 36.696959495544434, 34.845688411167686, 36.82230499812535, 34.37696988242013, 35.83123826980591, 37.51845891135079, 36.58013595853533, 35.09905447278704, 35.417191641671316, 36.05200685773577, 36.4044577053615, 35.83309343882969, 35.996615818568635, 36.06568786076137, 35.29227692740304, 38.31369761058262, 37.305705070495605, 37.17073283876692, 37.69646481105259, 38.385277952466694, 36.65741729736328, 38.05304636274065, 43.76642499651228, 49.200208118983674, 46.615321908678325, 44.97514057159424, 48.19629764556885, 46.665015425000874, 45.25910302570888, 44.46149499075753, 46.71684551239014, 48.04937103816441, 47.01396438053676, 43.059911319187705, 38.66806616101946, 40.668994494846885, 47.114477021353586, 53.382756165095735, 46.49060869216919, 37.67936182022095, 56.03353909083775, 51.62398297446114, 54.634998730250764, 51.08755772454398, 53.314292090279714, 55.712678228105815, 20.4608485017504, 1.3902822094304221, 3.1393741709845404, 0.9387711116245815, 0.054323846075151644, 0.17965608329645225, 16.935843229293823, 44.33168527058193, 34.75227335521153, 33.02387421471732, 12.171813470976693, 17.908089024680002, 36.3189879144941, 47.11469241550991, 44.23290967941284, 50.02691520963396, 9.75845309666225, 0.22379213997295924, 0.016792557667940855, 0.02838888737772192, 0.03982634150556155, 0.04889467704508986, 0.0918468733185104, 0.027686218564797725, 0.004133924135073487, 0.03608760337478348, 0.01052140471126352, 0.048437191772141626, 0.04955436236092022, 0.0692417166594948, 0.029496517764138322, 0.06363003528011696, 0.03525767023009913, 0.051457530951925685, 0.05096193915233016, 0.07342500718576567, 0.0373632559951927, 0.06788230567638363, 0.023862459996183003, 0.033364954471055946, 0.03252880933827587, 0.016205626573147516, 0.029210661138807024, 0.05410853334303413, 0.05272312768335853, 9.362090502466474, 65.45003659384591, 46.80417047228132, 51.909084933144705, 26.340157066072734, 36.29248401096889, 43.41837930679321, 26.2249333517892, 36.53170354025704, 51.89071042197091, 14.911902461733137, 0.3136945829859802, 0.29983626518930706, 0.8631668399487222, 4.214549711772373, 6.440587086336953, 4.018378181116922, 6.597719294684274, 42.74021427971976, 58.04791913713728, 56.04818936756679, 51.29088633401053, 51.443684169224326, 53.30017682484218, 52.65773248672485, 50.92866631916591, 48.027070794786724, 40.00429160254342, 40.70728601728167, 39.09681517737252, 41.45218849182129, 39.92182343346732, 40.98693364007132, 37.43065799985613, 39.31421388898577, 39.324295725141255, 39.11110414777483, 36.11673280170986, 39.12929800578526, 38.108083043779644, 43.33567837306431, 47.78354685647147, 52.536170278276714, 48.02982575552804, 48.735950333731516, 51.47946739196777, 48.88918243135725, 41.65163653237479, 38.198176860809326, 36.79401193346296, 38.53281600134713, 37.25037656511579, 37.46648638589041, 37.30322108949934, 38.46120091847011, 36.78918988364083, 38.26387207848685, 37.04665538242885, 36.81604814529419, 38.81250878742763, 50.494487285614014, 49.478264604296, 52.002982888902935, 47.48382936205183, 47.34526491165161, 46.290340764181956, 48.01105867113386, 47.49755552836827, 51.64458090918404, 48.107920033591135, 53.34064313343593, 46.6264112336295, 54.37468099594116, 31.649652549198695, 30.911482879093715, 55.70912422452654, 45.316026142665315, 49.48232582637242, 42.425724915095735, 44.39946494783674, 39.50975356783186, 38.40346833637783, 36.860155309949604, 38.09836251395089, 36.56390149252755, 37.278805119650706, 36.30745390483311, 38.95122957229614, 37.25977400371006, 37.38864919117519, 39.051895073481965, 38.943204402923584, 37.24295241492135, 36.344168186187744, 36.70354986190796, 38.652582100459504, 37.27212790080479, 37.11943081447056, 37.980270930698936, 36.8237224306379, 39.762883390699116, 39.14938872201102, 39.386089529309956, 38.20679610116141, 39.714266845158164, 39.12338856288365, 39.795279366629465, 45.673121861049104, 51.38335990905762, 48.48772941316877, 46.88255310058594, 50.14069196156093, 48.94542809895107, 47.574353967394146, 46.072580746241975, 48.42731135232108, 50.05542366845267, 48.84274067197527, 46.22869982038225, 39.74785443714687, 42.87120866775513, 49.10988848549979, 55.19801821027483, 48.03493268149239, 38.61148697989327, 55.47777700424194, 53.46067326409476, 55.63887446267264, 52.37273475102016, 55.90016494478498, 58.196909359523225, 23.913602931158884, 0.14827884627240046, 3.2860308842999593, 1.8292409522192818, 0.05695770188633885, 0.04509395474035825, 16.933519056865148, 47.317166396549766, 35.5534736088344, 35.37519325528826, 13.144369329724993, 23.558711528778076, 41.02558994293213, 53.42609902790615, 48.355175154549734, 57.94158738000052, 13.14456387928554, 0.17053497130317347, 0.04374077610139336, 0.08391371329448052, 0.06822389377547161, 0.024535712619711245, 0.07073786601956401, 0.02113813002194677, 0.02382788185163268, 0.0680378530440586, 0.014693550299853086, 0.032668675761669874, 0.04158597958407231, 0.008206539238536996, 0.0321310351469687, 0.14214738671268734, 0.11318901846451418, 0.12400432383375508, 0.08943204182599272, 0.17740159641419137, 0.18571308042321885, 0.1522406493978841, 0.12157314643263817, 0.15295972009854658, 0.1429796777665615, 0.10867857227900199, 0.12605979639504636, 0.19987743108400277, 0.10529682159956012, 11.788597737039838, 73.24605437687465, 53.168633529118125, 58.734032903398784, 31.84828417641776, 41.09867109571184, 51.22572265352522, 42.81270483561924, 45.1817626271929, 56.67004271915981, 16.517090933663503, 0.5089351907372475, 0.6635915605085236, 2.51559008870806, 13.095536521502904, 14.707964147840228, 5.905461583818708, 7.685084581375122, 44.43228128978184, 60.95769269125802, 58.31824575151716, 54.91279465811593, 52.948010853358674, 56.05279949733189, 54.339123589651926, 55.05368675504412, 51.66275044849941, 42.61189842224121, 43.46169785090855, 40.73402615955898, 44.32273251669747, 42.28812279020037, 41.972646781376426, 41.163553374154226, 41.00996344430106, 42.671875272478374, 41.965917451041086, 37.72962508882795, 41.36431115014212, 39.82149839401245, 44.92870923451015, 50.848994800022666, 53.2074739592416, 49.422692911965505, 50.24995238440377, 52.58180257252285, 50.5669708933149, 43.538089820316856, 39.5328563281468, 39.56891747883388, 40.79217563356672, 38.6681912285941, 39.02018002101353, 38.533792223249165, 40.44919170652117, 38.36469391414097, 39.59259346553257, 39.51212985174996, 38.89232274464199, 40.794423375810894, 56.223638330187114, 52.827574253082275, 54.01292651040213, 50.15007897785732, 47.825375011989046, 49.136976037706646, 50.2915894644601, 48.92017487117222, 54.43091624123709, 49.39335414341518, 56.865783895765034, 47.90762083871024, 54.60708434241158, 34.09100982121059, 33.69100202832903, 57.67656224114554, 47.43723821640015, 50.50097690309797, 44.27046816689627, 46.73825986044747, 41.393170492989675, 41.01540388379778, 38.987582547324045, 39.75788763591221, 39.250488485608784, 39.364973953792024, 39.26372480392456, 41.57183299745832, 37.56384801864624, 39.87522186551775, 41.28569228308541, 40.69015175955636, 38.40962791442871, 38.998206342969624, 38.888195514678955, 40.77542005266462, 38.901914732796804, 39.25775282723563, 39.399002756391255, 39.29213598796299, 41.18345301491873, 40.51270171574184, 41.52283777509417, 40.97193247931344, 42.17064264842442, 39.71260969979422, 43.16655921936035, 47.96235874720982, 54.548295634133474, 49.45663138798305, 46.682121889931814, 51.48269830431257, 50.63764796938215, 50.47029365812029, 49.04089287349156, 50.84822702407837, 51.6293226650783, 51.46252768380301, 48.919327190944124, 42.35391180855887, 44.96225166320801, 52.79367051805769, 55.72601876940046, 53.02914844240461, 45.82287638528006, 57.52268396105085, 57.2639399937221, 58.15254511151995, 55.291593074798584, 57.909118447984966, 61.76307923453194, 26.539823974881852, 2.7639551843915666, 10.982003075735909, 4.507771074771881, 0.22273386961647443, 0.3347643981022494, 20.19707577569144, 57.72277818407331, 46.97824716567993, 42.284245695386616, 17.57123688289097, 28.07373435156686, 46.431667123522075, 59.829944474356516, 55.451478072575156, 66.71447672162736, 15.07984389577593, 0.31269729935697144, 0.1585059839167765, 0.2603058735174792, 0.15474440290459565, 0.12007981299289636, 0.20502202931259358, 0.0916651344991156, 0.10202338546514511, 0.12533733301929065, 0.06773465645632573, 0.1465701458177396, 0.13767409031944616, 0.09869323737387146, 0.11805210608456816], [0.029527855903974602, 0.02344820079659777, 0.03332156554928847, 0.014969965110399892, 0.11944584415427276, 0.04076575966817992, 0.04606539636318173, 0.0563889232996319, 0.07478425532047238, 0.056693443030651124, 0.12184571394962923, 0.0071893923450261354, 0.2058587579854897, 0.10635368738855634, 13.352750148091998, 52.87179953711373, 52.885980810437886, 39.99530758176531, 38.82706873757498, 28.208147253308976, 10.133531621524266, 30.203065395355225, 32.53517614092146, 46.85717133113316, 4.49122393982751, 0.17692673046674046, 0.9465587394578117, 10.644919906343732, 1.5677614573921477, 5.120700768062046, 1.8518091355051314, 8.15978637763432, 34.41370153427124, 56.67476749420166, 49.06172704696655, 56.43062169211251, 51.288086209978374, 54.199054854256765, 51.31438514164516, 53.026261465890066, 51.334684303828645, 49.07542194638933, 42.947294916425435, 42.85451214654105, 43.13339894158499, 43.989910330091206, 43.16718108313424, 37.996950081416536, 37.724438258579795, 37.79674816131592, 35.337151868002756, 38.483667918613975, 36.27157688140869, 36.95897953850882, 34.78213323865618, 42.663318565913606, 47.675335611615864, 48.462830543518066, 45.68651103973389, 47.813823631831575, 47.64724751881191, 45.19509274618966, 41.65767451695034, 38.32881341661726, 35.747755663735525, 35.32044839859009, 35.73163931710379, 35.43622623171125, 37.591421944754465, 35.68232447760445, 36.30107198442732, 35.31895800999233, 35.77492659432547, 42.48407588686262, 48.5038492338998, 46.67036553791591, 45.39728879928589, 43.890290532793315, 49.54143067768642, 44.03803355353219, 43.776618003845215, 45.46557569503784, 50.517503193446565, 46.65625722067696, 51.029185908181326, 44.52136066981724, 55.55430098942348, 27.993204729897634, 30.980047702789307, 54.713179860796245, 43.22670630046299, 45.811408383505686, 34.077968052455354, 39.276995863233296, 35.15864222390311, 38.41696868624006, 37.72477177211216, 39.47602701187134, 38.03946958269392, 37.75911324364798, 35.42707198006766, 35.06157241548811, 34.952714988163535, 36.54434926169259, 36.41051306043352, 35.92634521211897, 35.15990332194737, 35.28496394838606, 34.866619859422954, 35.762642179216655, 36.5225180217198, 35.49308681488037, 35.60432052612305, 37.038004875183105, 37.8647814478193, 39.05480636869158, 40.06624868937901, 40.79435389382498, 37.66743523733956, 37.42332765034267, 43.2290860584804, 45.85822881971087, 46.48469230106899, 47.04054471424648, 47.04427242279053, 48.817018440791536, 46.64467109952654, 42.28124407359532, 37.234777859279085, 39.244151728493826, 43.04711273738316, 41.19471604483468, 40.287819794246126, 37.95081751687186, 43.477713448660715, 50.6828737940107, 54.163108348846436, 36.30472673688616, 34.60846301487514, 56.01629018783569, 47.62048653193882, 51.485675607408794, 47.150902952466694, 55.180623395102366, 53.60892697743007, 43.03327539988926, 1.1298199743032455, 5.3215484363692145, 4.236251975808825, 0.07723895753068583, 0.011880384824637855, 4.937493707452502, 47.61902393613543, 30.062475545065745, 47.02416781016758, 52.326251302446636, 20.554367780685425, 26.617296389171056, 40.3842191014971, 47.59153686250959, 50.28481149673462, 22.597815615790232, 0.21576611564627715, 0.04110696100230728, 0.06606121946658407, 0.0658816791006497, 0.05582892834874136, 0.02723009545089943, 0.008708157277266895, 0.026135423387001668, 0.03497100275542055, 0.022680080495774746, 0.016216159132974486, 0.03373514621385506, 0.09425339275704962, 0.06505911823894296, 0.02612007831755493, 0.04693276767752, 0.023889526758076887, 0.017950847478849546, 0.03489929178197469, 0.025053136283531785, 0.03714829949395997, 0.01692525706520038, 0.049373933114111423, 0.026042218120502572, 0.08918233415377991, 0.04505435882934502, 0.07640049180814198, 0.0082212719301294, 17.760568346296036, 61.55230563027518, 57.60297734396798, 48.062933921813965, 40.328734261649, 37.994549478803364, 15.173785277775355, 29.343910217285156, 39.77828407287598, 52.24400200162615, 5.496772016797747, 0.5633939227887562, 1.752889803477696, 23.25921290261405, 5.955836457865579, 7.5156727348055155, 4.442342494215284, 9.519759893417358, 40.12486021859305, 57.663499627794536, 53.11141858782087, 57.55704975128174, 54.34622117451259, 56.326593262808665, 53.97948830468314, 53.547623021262034, 53.076031412397114, 50.793933800288606, 45.56505652836391, 44.27131584712437, 45.42574167251587, 46.27638530731201, 44.56637804848807, 40.374943256378174, 40.64275114876883, 39.19589301518032, 37.15329286030361, 38.84061425072806, 37.94811814171927, 38.52829967226301, 38.07016324996948, 44.859741415296284, 49.45089912414551, 50.72495903287615, 46.61523853029524, 50.26073598861694, 49.97688470567976, 48.17740896769932, 43.57150023324149, 39.43060663768223, 38.35965994426182, 37.531288760049, 38.18862656184605, 37.15331717899868, 37.38906260899135, 37.129922594342915, 37.196448121752056, 37.24894871030535, 38.277428013937815, 42.696864468710764, 50.02749538421631, 48.00071975163051, 46.61136838368007, 44.91882542201451, 49.58822332109724, 46.25311926433018, 45.04785694394793, 47.82006311416626, 52.160637514931814, 49.020110811506, 54.6348945072719, 45.77582318442208, 56.423638752528596, 28.487014940806798, 33.12418188367571, 56.12659631456648, 45.540390423366, 46.43028790610177, 36.740823473249165, 40.342734881809776, 36.8284124646868, 40.24355282102312, 40.93415512357439, 41.66129800251552, 38.91950409752982, 40.087881905691965, 37.84473589488438, 37.760902404785156, 37.60206658499581, 38.015942982264924, 37.465468474796836, 37.107754366738455, 36.86605085645403, 37.63103709902082, 37.03891856329781, 37.90762404033116, 36.99413742337908, 37.82145595550537, 38.090813296181814, 37.01084436689104, 39.47253554207938, 40.79204361779349, 42.382430689675466, 41.979730469839915, 39.876795632498606, 38.81065361840384, 45.03665297372, 48.215554577963694, 49.33567019871303, 48.06579310553414, 47.997693811144146, 50.95408977781023, 48.36594486236572, 44.594518252781455, 39.728364740099224, 41.79072209766933, 44.1549265725272, 42.72630051204136, 42.450627258845735, 39.56132309777396, 44.71136263438633, 53.55393893378121, 53.94836384909493, 40.85241651535034, 39.156562737056184, 59.30978148324149, 50.939797333308626, 52.84228358949934, 48.81678915023804, 56.228304045540945, 54.37815509523664, 46.243631499154226, 0.9743034392595291, 4.210236183234623, 7.194704174995422, 0.14461623637803964, 0.05036887240463069, 5.114587656089237, 49.18683283669608, 34.00388288497925, 41.49165078571865, 39.33585752759661, 21.955739532198223, 30.4694766998291, 45.9088568687439, 52.80598272596087, 56.73227078574044, 28.85363142830985, 0.0959114134311676, 0.0742747773017202, 0.021461602932374393, 0.042466772321079455, 0.027897609364507452, 0.04764646438083478, 0.03261817579290696, 0.06287108707640852, 0.07866322289087943, 0.010120214096137455, 0.03673293428229434, 0.01530006221894707, 0.06433949792491538, 0.043540123118353743, 0.12043345187391553, 0.137632496122803, 0.11308123996215207, 0.07491177919187716, 0.20345649974686758, 0.11493062786757946, 0.14409285517675535, 0.17701856339616434, 0.1520354061254433, 0.13434523823005812, 0.29960241488048006, 0.10440727576081242, 0.25341201201081276, 0.11416340832199369, 24.102404594421387, 69.36932781764439, 66.59189660208565, 53.57023245947701, 51.31784534454346, 37.96980346952166, 15.131182398114886, 42.76752764838082, 44.48061295918056, 58.82066304343087, 6.2707935231072565, 0.9110654954399381, 1.117672134722982, 20.00854335512434, 6.792347022465297, 14.022278564316885, 9.56461659499577, 10.83716092790876, 40.25186634063721, 61.638407707214355, 54.56588152476719, 61.90865094321114, 55.738619327545166, 59.47103527614048, 55.435639653887065, 57.37973172324044, 55.11183622905186, 53.98619679042271, 46.91865941456386, 47.04508883612496, 48.67359025137765, 48.434669494628906, 47.537181104932515, 41.01167617525373, 40.86073350906372, 41.78925255366734, 38.563134465898784, 40.91852167674473, 39.56261893681118, 39.782029151916504, 38.65057059696743, 46.445754596165244, 52.644381523132324, 53.01006868907383, 47.45304536819458, 51.88730233056204, 52.22754519326346, 50.21175813674927, 45.93796982084002, 41.07312256949288, 39.971437045506065, 40.40721069063459, 40.10885851723807, 38.266234466007774, 39.61882291521345, 38.74936008453369, 39.78880017144339, 38.833700793130056, 40.422653062003, 44.99940020697457, 52.54409122467041, 49.479838371276855, 48.20118917737688, 46.550853048052105, 51.61244201660156, 48.11226265771048, 44.84717559814453, 47.79211745943342, 52.65781586510794, 52.713147844587056, 55.21854318891253, 47.90690170015608, 57.68949283872332, 29.92014169692993, 35.81508718218122, 58.60598455156599, 50.05931118556431, 49.65866763251168, 37.532285826546804, 42.40496369770595, 39.32181174414498, 43.98963935034615, 42.76649931498936, 43.74715764181954, 41.00708341598511, 41.27110801424299, 39.698310307094026, 40.66741030556815, 39.41237803867885, 39.87027474812099, 38.72043125970023, 39.08101149967739, 38.082874979291645, 39.29089226041521, 37.84984629494803, 39.95731135777065, 39.33111885615757, 39.80918966020857, 40.20646333694458, 39.69316169193813, 42.10346746444702, 42.38147183826992, 43.36355454581124, 45.309279441833496, 41.16185106549944, 41.27292496817452, 47.67640563419887, 50.83355590275356, 50.733265604291645, 48.986165387289866, 48.87313209261213, 53.071254525865825, 51.60913119997297, 46.47605916431972, 40.84949827194214, 44.79119048799787, 47.123600006103516, 44.35910981042044, 43.446498666490825, 41.381097997937886, 47.32797431945801, 56.39039857046944, 56.40741123471941, 44.08735534123012, 40.705764361790244, 61.06101240430559, 53.32436350413731, 55.68443727493286, 51.974370207105366, 58.115823881966726, 58.99584797450474, 49.133074624197825, 2.6536903125899176, 11.745698690414429, 8.832723753792898, 0.1742461778755699, 0.11889150818543774, 6.4950210111481805, 58.49707153865269, 41.00554091589791, 59.39714813232422, 62.82297134399414, 28.835350717817033, 36.429662295750205, 53.98770454951695, 59.68468543461391, 63.44783673967634, 34.24953644616263, 0.5811218715139798, 0.15681519678660802, 0.14364724765930856, 0.16597524311925682, 0.08711675142071076, 0.1607089564204216, 0.10383191199174949, 0.14507263260228292, 0.23253082962972776, 0.12319838708000523, 0.13620730116963387, 0.09020482535873141, 0.20146650581487588, 0.15098090842366219], [0.04562604833128197, 0.03998290667576449, 0.057347465971750874, 0.032942427322268486, 0.056429913600108454, 0.052431506903043816, 0.08893523205603872, 0.09256572010261671, 0.0764707676800234, 0.02841843418510897, 0.04347070220059582, 0.017947307222389748, 0.01596140655289803, 0.3889109497623784, 25.851564952305385, 50.6999385697501, 45.13433074951172, 39.39264862877982, 29.9775025503976, 12.3157844884055, 31.113623346601212, 29.169757093702042, 41.04803262438093, 37.72339950289045, 0.9595496995108468, 0.03573263456512775, 0.7808396433080945, 3.369938633271626, 2.960813501051494, 4.360337683132716, 2.735404819250107, 12.625826137406484, 39.58282082421439, 56.69814123426165, 53.127267428806846, 50.79147413798741, 51.57884400231497, 50.426144804273335, 46.78729329790388, 50.64522845404488, 48.881195477076936, 49.342284883771626, 50.93273101534162, 51.11343976429531, 48.48852498190743, 48.44799961362566, 44.15080976486206, 38.30616576331002, 35.1117662021092, 36.451316356658936, 37.0836614881243, 40.68514558247158, 42.25214154379708, 41.83264752796718, 39.69306789125715, 39.420180865696494, 44.543310029166086, 47.55425977706909, 47.77179397855486, 43.248044218335835, 48.69273253849575, 47.524882793426514, 48.74263102667672, 42.33448811939785, 43.325683389391216, 35.34766796657017, 35.48764637538365, 36.904172148023335, 35.7789044380188, 36.15763684681484, 37.174682889665874, 34.43113456453596, 37.14014686856951, 40.98425163541521, 50.01839671816145, 44.6702675138201, 45.10637467248099, 44.73678261893136, 45.62044061933245, 45.72994075502668, 49.30893700463431, 45.372202328273225, 46.000051975250244, 44.36639152254377, 48.32585028239659, 43.18373169217791, 51.44114460263933, 28.599435056958878, 29.760687487465994, 53.66080917630877, 44.17390905107771, 46.040063176836284, 38.48392152786255, 41.29207420349121, 40.61479159763881, 43.87862450735909, 39.239492961338584, 42.5007654598781, 38.90505531855992, 40.774169376918245, 39.055230208805625, 38.0545471736363, 33.518342767442974, 35.650984627859934, 34.60436357770647, 36.02798693520682, 35.02779027393886, 37.31574174336025, 35.26423052379063, 36.36730221339634, 35.78486599240984, 36.58490937096732, 34.97476509639195, 39.746520383017405, 43.09867531912667, 45.41760533196585, 44.34076656614031, 43.45724752971104, 42.19232102802822, 44.77279165812901, 45.880042689187185, 45.91153539930071, 47.88492454801287, 45.962038380759104, 47.7092011315482, 49.042261668613975, 45.89818443570818, 43.469882828848704, 37.664430141448975, 37.939168861934114, 35.6632308278765, 36.52182667595999, 36.81102459771292, 39.25223248345511, 40.660660130637034, 51.712009702410015, 49.769276005881174, 51.63119867869786, 54.74300847734724, 52.88602944782802, 49.762803758893696, 46.90960938589913, 45.0414993422372, 54.71654278891427, 53.63297816685268, 58.559528895786826, 10.365486809185573, 0.7986781118171555, 3.0933167338371277, 0.4636714224304472, 0.024352455578212227, 1.2380692171198981, 38.88011475971767, 33.806633949279785, 45.53192056928362, 70.02894810267857, 26.161668266568864, 24.74192374093192, 41.327784470149446, 45.7041004044669, 45.957938943590435, 27.37522326196943, 0.7745639543448175, 0.032343128230422735, 0.06087109153824193, 0.026269194869590656, 0.1330230584634202, 0.04903644336653607, 0.013980716184180762, 0.014982294091688735, 0.08003919012844563, 0.013015052287041076, 0.02522734845323222, 0.04720029028664742, 0.02240651722864381, 0.07228947204670735, 0.00856620944770319, 0.028966056049934456, 0.031467573783759556, 0.009381832288844245, 0.036947833108050485, 0.010550473999631192, 0.058756932483187745, 0.04903515075732555, 0.01345406359593783, 0.0204708909150213, 0.07883223917867456, 0.007712300268134901, 0.04066028479220612, 0.6581614347440856, 34.028663635253906, 58.15743316922869, 50.40220478602818, 46.15936027254377, 34.11112485613142, 15.100325448172432, 26.000115701130458, 33.24414600644793, 44.506793771471294, 43.39964696339199, 1.0001276135444641, 0.08588493216250624, 0.6685039911951337, 3.708137205668858, 4.752551334244864, 8.710249594279698, 5.931242440428052, 12.732383710997444, 41.58091081891741, 58.17839935847691, 55.059960978371755, 52.19555916104998, 53.50931065423148, 51.39416088376726, 47.328742095402305, 52.11415754045759, 51.53702974319458, 51.323049545288086, 53.74834953035627, 52.26538855688912, 51.371822425297324, 50.413144724709646, 45.301653793879915, 40.25733804702759, 37.57134859902518, 39.07233319963728, 38.20791823523385, 41.83069855826241, 43.84208740506853, 42.16293362208775, 41.181722913469585, 42.88931219918387, 47.22893122264317, 48.70787961142403, 49.87694876534598, 44.80611869267055, 51.56026104518345, 49.50056484767369, 50.831930024283274, 44.435876982552664, 42.34172466823033, 38.01766613551548, 36.18353625706264, 38.48966073989868, 36.12881224496024, 38.25437389101301, 39.63441119875227, 36.28685597011021, 39.12792226246425, 42.44238322121756, 50.59686551775251, 46.337032658713206, 48.01096487045288, 45.113618169512065, 46.35306215286255, 46.53015783854893, 50.494702679770334, 47.85092006410871, 47.684434277670725, 44.73484059742519, 49.42022630146572, 46.54349143164498, 50.72681072780064, 29.2191344669887, 30.80195495060512, 54.237822328295024, 47.97084944588797, 48.14158405576433, 39.60276910236904, 44.30248546600342, 42.913808073316304, 46.123441559927805, 42.73306458336966, 44.16528981072562, 41.4253580229623, 42.712907859257285, 40.003002711704795, 39.0092122895377, 35.006414140973774, 36.761702810014995, 35.60165589196341, 37.810783522469656, 36.21755116326468, 37.72386155809675, 36.87486464636666, 38.20285994665963, 37.511809485299246, 38.29755694525582, 37.45083556856428, 42.288838454655235, 45.32829318727766, 46.9956419808524, 46.601369925907676, 46.46417774472918, 42.08554458618164, 46.232003688812256, 47.70039081573486, 48.87160348892212, 49.18999426705496, 46.726628576006206, 48.33720711299351, 50.7495174407959, 48.41512073789324, 45.315522398267476, 40.19433525630406, 38.60190193993704, 37.07380199432373, 38.359628677368164, 39.879255294799805, 41.46268721989223, 42.19791432789394, 52.55414874213082, 51.95203522273472, 53.40216595785958, 59.341937746320454, 53.49130092348371, 52.49969570977347, 48.30080550057547, 48.03434555871146, 56.949659075055806, 56.0172073500497, 60.13972296033587, 12.549569657870702, 0.21092076493161066, 11.33280633177076, 1.9767655389649528, 0.07814435394746916, 1.2532777381794793, 41.277284962790354, 37.99141584123884, 43.278296675000874, 67.73957225254604, 30.75606209891183, 31.670316491808208, 45.846177169254844, 50.99981239863804, 51.192517212459016, 33.58024774278913, 1.2449293690068381, 0.030831925570964813, 0.07302400656044483, 0.04057952555428658, 0.010837806438628052, 0.032058845806334696, 0.058322113672537465, 0.022569464020697132, 0.034976590491299114, 0.04218589275010994, 0.10838500410318375, 0.043390234732734304, 0.03981685558600085, 0.052650775494320054, 0.1472378107053893, 0.22572987313781465, 0.0843517483611192, 0.08593297922717673, 0.18460956535169057, 0.14411703816482, 0.23835521138140134, 0.21182043451283658, 0.12423725133495671, 0.129271872607725, 0.2627716969166483, 0.16003020427056722, 0.20451794564723969, 0.9757916565452303, 41.829235962459016, 65.0160937990461, 59.04316520690918, 49.67828587123326, 41.334433896201, 18.398789916719707, 42.228066035679404, 42.85378605978829, 50.53037125723702, 46.45691687720162, 1.3437969152416502, 0.18295991101435252, 1.6626875294106347, 5.316561366830554, 5.97143429517746, 11.763418333871023, 7.607772844178336, 16.87849279812404, 42.86226633616856, 57.710368701389854, 57.205849579402376, 54.740302153996055, 53.801517145974294, 52.70578622817993, 48.94245774405343, 54.01558767046247, 52.61567504065377, 53.78993797302246, 55.23219639914376, 55.034124101911274, 53.27407244273594, 52.83722530092512, 48.67660229546683, 42.89712197440011, 38.1851281438555, 41.35039043426514, 40.48852893284389, 45.13221154894148, 46.24553183146885, 45.701216902051655, 43.49832875388009, 44.257523672921316, 49.26731729507446, 51.062235014779226, 51.92948831830706, 44.58401952471052, 52.94605840955462, 51.79749338967459, 53.07461397988455, 46.972275188991, 46.688194615500315, 38.5845627103533, 38.88982834134783, 39.47727421351841, 38.683195863451274, 39.87240089688982, 40.52104302815029, 37.92239591053554, 40.63029302869524, 44.68887478964669, 53.68277243205479, 47.20432070323399, 50.76164552143642, 47.86108180454799, 47.562375273023335, 48.029582568577354, 51.424844128744944, 49.28644915989467, 49.86690861838204, 47.411922454833984, 50.7147729737418, 46.31900208336966, 51.79273039954049, 32.14488540376936, 33.65550715582711, 56.99970694950649, 50.049333572387695, 51.36777857371739, 42.079023701804026, 45.65132188796997, 45.01624958855765, 48.372128759111675, 44.96800824574062, 47.22178152629307, 43.89773552758353, 44.21310383932931, 42.21209560121809, 41.24916212899344, 37.188575812748496, 39.65947682516915, 37.24779878343855, 38.8637934412275, 38.904489040374756, 41.41722168241228, 38.56694555282593, 40.35052728652954, 40.3936755997794, 40.06535584586007, 40.10419627598354, 43.12228877203805, 46.25251129695347, 49.68110683986119, 47.65266711371285, 48.51539713995797, 45.7665890284947, 48.21910858154297, 50.23976979936872, 50.31098883492606, 51.35640089852469, 48.292544092450825, 50.18001181738717, 53.539451939719065, 50.548519951956614, 48.17168017796108, 41.428251947675435, 41.80947528566633, 38.34862967899868, 40.40055431638445, 42.35231719698225, 44.75536905016218, 43.727706159864155, 55.995918069567, 53.767662048339844, 55.33616576875959, 59.382153919764924, 57.33306762150356, 54.30297211238316, 51.89913511276245, 50.12437411717006, 60.528314862932476, 58.1951584134783, 65.04612391335624, 13.977268133844648, 5.590641745499202, 8.532797813415527, 1.1900701927287238, 0.16981873687888893, 1.6196107608931405, 46.6778244291033, 44.1576189994812, 56.18032326017107, 79.38589259556362, 36.36796229226248, 35.27240855353219, 53.20604263033186, 58.345295088631765, 58.606262479509624, 40.6804381779262, 1.8376582605498177, 0.16052301068391117, 0.2088067890810115, 0.09646238386631012, 0.21351507572191103, 0.1045743650091546, 0.14403090492955276, 0.17065788113645144, 0.13577477580734662, 0.19232145510613918, 0.24515939770000322, 0.18973832657294615, 0.10036972098584686, 0.12575441492455347], [0.004585364085089947, 0.05241972753512008, 0.07063167528914553, 0.05961282977036067, 0.07353119113083396, 0.035472161934844086, 0.007576564426666924, 0.039296887415860376, 0.05730491504073143, 0.02974037985716547, 0.011803310880038356, 0.012026052722441298, 0.052128853143325875, 3.005341248852866, 42.30484710420881, 50.63806138719831, 48.67315946306501, 40.08146177019392, 32.02053696768624, 25.21966450554984, 43.25184835706438, 34.98449952261788, 48.77044466563633, 29.6354045186724, 0.04304184092740927, 0.03110596550894635, 0.9282920339277813, 3.1028837519032613, 4.334541193076542, 7.59049962248121, 4.838694666113172, 21.608195849827357, 49.856691292354036, 51.23309121813093, 49.08819620949881, 53.23520769391741, 53.185389110020225, 49.84482029506138, 49.46094969340733, 50.10599265779768, 51.73798554284232, 50.10927568163191, 48.71581098011562, 47.111895765577046, 49.72977202279227, 48.651088510240825, 44.103093011038645, 36.17186328342983, 36.19646338054112, 35.49743986129761, 39.55432973589216, 45.88188396181379, 46.159978662218364, 49.16661357879639, 43.63390547888619, 44.249168464115684, 44.99634299959455, 46.695191451481406, 48.00361715044294, 45.57726798738752, 45.316533361162456, 47.95664732796805, 47.80522871017456, 48.91313287190029, 46.161152907780235, 39.16239922387259, 36.140481744493755, 37.6700998714992, 35.86992583956037, 36.20358875819615, 36.04219947542463, 34.81040893282209, 36.691282817295615, 42.25079359327044, 46.24738005229405, 47.392276423318044, 44.65199722562517, 42.89900146211897, 45.982052666800364, 44.41698135648455, 44.12667172295706, 43.775297846112935, 46.04100465774536, 45.17629092080252, 47.01916510718209, 44.069501944950645, 49.58533634458269, 33.07316820962088, 36.11049331937517, 51.94669205801827, 44.99804878234863, 44.140130383627756, 39.17125817707607, 44.6760310445513, 44.10722371510097, 44.98678922653198, 40.187387057713096, 42.90432725633894, 42.00906923839024, 43.56910310472761, 41.386524541037424, 41.43487358093262, 36.90922001429966, 34.56490823200771, 35.03539507729666, 34.943557262420654, 36.48113802501133, 35.67531374522618, 34.40566941670009, 35.357457978384836, 35.79798766544887, 36.65166418892996, 38.676122597285676, 45.745678424835205, 47.09836762292044, 49.48900999341692, 48.4551180430821, 46.5886720929827, 46.328052112034385, 46.719697747911724, 47.07235704149519, 48.35408081327166, 45.18198496954781, 45.38058532987322, 45.66262660707746, 48.68412719454084, 47.40062468392508, 42.92105851854597, 36.220111574445454, 36.4951525415693, 35.430549553462434, 38.4379939351763, 38.42984369822911, 39.13808052880423, 37.07819325583321, 45.03725399289812, 49.13797310420445, 49.097315720149446, 48.135059697287424, 46.72255693163191, 39.68158599308559, 41.28471606118338, 41.5195825440543, 50.0334986277989, 50.31531408854893, 57.994362422398154, 27.38762927055359, 0.8146472977740424, 10.628496970449175, 3.126967293875558, 0.11438592709600925, 0.03434389729851058, 24.960481064660208, 47.24320977074759, 52.84595571245466, 65.95535823277065, 20.218837533678325, 18.15498457636152, 33.28303854806082, 42.69121558325631, 47.15897328513009, 35.387488092694966, 1.4707445204257965, 0.0384674733504653, 0.018180955667048693, 0.05857208597340754, 0.01333262279097523, 0.030117207672446966, 0.07214216887950897, 0.03790290168087397, 0.06864432764372655, 0.05168662812294705, 0.03963410574942827, 0.021727973728307655, 0.060534287111035416, 0.028638259175100496, 0.057046739251485894, 0.019993044502500976, 0.025490445317700505, 0.018431129832086817, 0.0583369532333953, 0.015005830775148101, 0.010923465547551001, 0.030884607029812675, 0.07255970540323428, 0.014198794794668044, 0.03662556629361851, 0.02044406672939658, 0.06582973045962197, 3.5838843073163713, 48.873614992414204, 55.96002714974539, 54.5207599231175, 44.41390677860805, 37.42001335961478, 20.539731400353567, 34.7862674168178, 36.843691553388325, 53.23787580217634, 32.80508933748518, 0.048093812340604405, 0.03133479805131044, 1.6261383763381412, 6.089868077210017, 6.83793762751988, 9.7415429183415, 9.113467454910278, 21.67638894489833, 49.4823431968689, 50.53594371250698, 52.85243143354143, 53.79879345212664, 54.45994928904942, 49.850476128714426, 49.921101093292236, 50.73373113359724, 51.681500162397114, 52.29301112038748, 52.02911853790283, 49.81476933615548, 52.2179844720023, 50.725872720990864, 46.28414644513811, 37.20025226048061, 38.373240198407856, 37.18964236123221, 40.667083740234375, 47.243307045527864, 47.45668969835554, 49.21985762459891, 46.71591097967965, 45.34173100335257, 47.59180089405605, 50.44298376355852, 48.0692081451416, 45.521849155426025, 45.28208071844918, 49.01102951594761, 49.49693788800921, 51.17707136699131, 48.164686816079275, 41.80261393955776, 37.902416365487234, 39.209320408957346, 37.38520288467407, 36.15779318128313, 37.656248637608115, 35.54584796088082, 38.620787143707275, 44.97504677091326, 47.38598830359322, 48.098501750401084, 45.53398418426514, 44.37142896652222, 47.552512305123464, 47.55751500810896, 46.77381379263741, 46.30008561270577, 47.08554124832153, 46.78715433393206, 48.3963189125061, 44.355941431862966, 50.33849327904837, 33.69215542929513, 37.044008118765696, 55.205456256866455, 47.24134070532662, 46.68631860188076, 42.62442602430071, 46.690251282283235, 45.56768989562988, 46.30065883908953, 41.673947198050364, 44.13276876722063, 43.23750032697405, 45.39311293193272, 43.53468172890799, 41.901490279606406, 38.421224457877024, 36.08228363309588, 36.760691847120015, 37.417696135384695, 37.330899238586426, 37.41432973316738, 35.31907960346767, 37.687480790274485, 37.06612770898001, 37.32611887795584, 42.17385271617344, 47.46535757609776, 49.70704793930054, 49.9650936126709, 49.25757939474923, 49.75147124699184, 48.984629835401265, 48.08032178878784, 49.66730076926095, 51.5089624949864, 47.516412939344136, 45.62518971306937, 45.92218698774065, 50.01638868876866, 48.84821932656424, 44.02927882330758, 38.8187586920602, 37.94067314692906, 37.514946596963064, 39.429067611694336, 40.54974256243025, 39.34553984233311, 38.614936760493684, 47.46419722693307, 51.495615005493164, 50.55350528444563, 49.55568143299648, 47.017567021506174, 43.191009930201936, 41.51201595578875, 44.03261048453194, 51.58738333838326, 54.5433589390346, 59.076370647975374, 32.32296773365566, 0.08388674831283943, 10.833265594073705, 6.575151111398425, 0.07196239102631807, 0.1001663776114583, 26.4153139931815, 49.98364877700806, 49.52267401559012, 66.7998492377145, 26.66605189868382, 26.079577037266322, 37.0081102507455, 49.469659260341096, 53.768759863717214, 44.22045850753784, 2.4227630240576605, 0.10279405875397579, 0.04537100398114749, 0.05908709405256169, 0.03999448926853282, 0.010577624730233635, 0.05720094990517412, 0.007435685289757592, 0.04426052374765277, 0.01810441182793251, 0.04533489913280521, 0.008228339720517397, 0.05092611250334552, 0.057803292226578505, 0.11247584423316376, 0.07212323775248868, 0.15339329040476254, 0.18312567711940833, 0.14227130077779293, 0.09412015562078782, 0.06395652597504002, 0.14080893567630223, 0.15784832063530171, 0.19262813936386788, 0.11094471639288322, 0.09387852930064712, 0.14730159299714224, 4.8206393378121515, 57.169798851013184, 63.67962864467076, 61.64127036503383, 52.253173623766216, 43.93955673490252, 35.398907457079204, 55.06082950319563, 45.020852770124165, 59.77855559757778, 35.64027050563267, 0.34079999423452784, 0.16308358471308435, 3.1432892637593404, 9.975964716502599, 11.634811520576477, 15.229230165481567, 11.8914840562003, 26.05464342662266, 50.454493454524446, 51.521410192762104, 54.49208818163191, 55.72914545876639, 55.26807689666748, 50.51944521495274, 51.39171511786324, 52.739849771772114, 54.68119035448347, 52.85910170418875, 53.1960163797651, 51.40197760718209, 52.837520599365234, 52.87652431215559, 48.20782470703125, 40.42554003851754, 40.940495354788645, 39.70060321262905, 41.816743101392476, 49.98188393456595, 50.823064122881206, 53.6554799079895, 49.23306615012032, 47.079138483319966, 49.80444083895002, 52.79952090127127, 49.394764627729145, 47.58893476213728, 46.34959500176566, 50.32052523749215, 50.25849519457136, 51.77139595576695, 50.92246157782418, 44.028146266937256, 40.40428549902779, 42.2628938811166, 39.80549669265747, 39.31185844966343, 39.37165812083653, 37.55151844024658, 40.81907211031233, 46.97234467097691, 49.69756017412458, 51.45822327477591, 47.10675409861973, 45.169099535260884, 47.612513474055696, 47.2760191644941, 47.15356411252703, 48.279544012887136, 48.463865825108115, 49.31815379006522, 49.21223545074463, 46.90491240365164, 52.39983967372349, 36.93888534818377, 39.438774245125906, 56.99797337395804, 49.693453788757324, 48.96887826919556, 42.73063618796212, 48.076104232243125, 46.2519519669669, 49.53058106558663, 42.938168457576204, 46.627901622227256, 46.473832266671316, 47.49287591661726, 45.07727214268276, 44.75579636437552, 41.13846690314156, 38.26494557516915, 38.630601474217, 38.252859183720176, 39.927962166922434, 39.22912972314017, 37.83363267353603, 39.32401084899902, 39.35326623916626, 41.23543248857771, 43.30237218311855, 50.11400045667376, 51.51491710117885, 53.74314532961164, 52.61461196626936, 52.31734023775373, 51.517310755593435, 48.87447656903948, 50.85470969336373, 53.80741616657802, 48.654295103890554, 44.42597232546125, 46.61366823741368, 52.60565226418631, 50.989852155957905, 45.83623777117048, 40.227349621909006, 40.53133678436279, 38.605831146240234, 41.866811820438926, 42.07411132540022, 42.075910908835276, 40.65413229806082, 50.23570510319301, 53.0096309525626, 53.54496880940029, 52.83908741814749, 50.83908666883196, 44.80248825890677, 45.28702436174665, 46.20687552860805, 54.8205885887146, 55.07308612551008, 63.73827838897705, 32.18332978657314, 3.513636499643326, 18.132647854941233, 6.480573969227927, 0.29493178693311556, 0.19908298871346883, 29.223581314086914, 58.371448108128135, 59.45388017381941, 70.45873587472099, 27.299121379852295, 26.858310290745326, 45.09054320199149, 56.45536075319563, 59.89350659506661, 51.39906283787319, 3.7373270222118924, 0.2551760673522949, 0.13696480409375258, 0.23412427412612097, 0.07076965538518769, 0.09125498722174338, 0.1357631321464266, 0.09014833053307873, 0.11410398222506046, 0.1159366781690291, 0.14937039198619978, 0.12447791413537093, 0.11586752187992845, 0.23024905206901686], [0.10257690719195775, 0.07164115897778954, 0.05207473658291357, 0.021313485523153628, 0.030226845360760177, 0.03236082781638418, 0.013152386926646744, 0.019043597592306987, 0.05307683102520449, 0.018122197927108834, 0.04770580566089068, 0.05640412926939981, 0.20777051682983125, 4.149251409939357, 43.09074395043509, 46.35803358895438, 43.88696929386684, 34.46246746608189, 19.38478446006775, 15.303753069468907, 33.227883747645784, 32.569937978472026, 52.65603365216936, 18.303686448505946, 0.046891142946801016, 0.08402860284383808, 0.6074115208217076, 5.494420051574707, 4.506995916366577, 11.813801458903722, 18.85700798034668, 32.29413618360247, 49.87664304460798, 49.49587133952549, 57.078096526009695, 53.178718839372905, 51.615745885031565, 51.73302452904837, 52.644124439784456, 52.08923087801252, 49.8334321975708, 51.54440178189959, 47.49874367032732, 47.13943842479161, 53.270052909851074, 48.341963154929026, 38.945347922188894, 34.54867376599993, 36.87887028285435, 39.32302073069981, 47.15824372427804, 45.97234950746809, 49.60018464497158, 46.81558288846697, 46.8916517666408, 45.53482491629464, 47.795223304203574, 47.21390226909092, 48.24500799179077, 43.90573985236031, 47.15262957981655, 42.92244121006557, 47.54061351503645, 50.74392066683088, 47.05313485009329, 39.83286912100655, 35.675202574048726, 34.59479243414742, 35.200571128300254, 34.81636701311384, 35.41070202418736, 34.19429131916591, 37.92597075871059, 41.941706453050884, 44.82300281524658, 45.03867837360927, 47.61322913851057, 42.451596532549175, 43.540261132376536, 44.51615299497332, 43.31803689684187, 43.473485469818115, 46.64144713538033, 43.36010823931013, 46.7975731577192, 44.42859179633004, 48.29892948695591, 32.924657412937705, 32.57377685819353, 51.616569246564595, 43.73181949343, 45.57527038029262, 43.31170013972691, 45.25811290740967, 42.0436087335859, 44.85079908370972, 43.469618797302246, 44.56886550358364, 43.43980060304914, 42.73231765202114, 41.11481523513794, 44.91353089468819, 37.846017837524414, 38.175296442849294, 34.152060168130056, 37.689544405256, 36.10688025610787, 37.28615978785923, 35.252290044512065, 36.043839250292095, 35.08181946618216, 40.53268126079014, 46.072236810411724, 47.54090533937727, 49.57650865827288, 46.074922289167134, 48.705506801605225, 49.492650849478586, 48.74047361101423, 48.63849490029471, 47.09369843346732, 44.67589555467878, 44.5305392401559, 47.47922618048531, 48.52264411108834, 47.75119604383196, 47.090703759874614, 38.507260526929585, 36.04403032575335, 37.02209350040981, 38.732562814440044, 38.18192849840437, 37.54717581612723, 36.871112619127544, 37.4099315234593, 37.06489092963082, 38.32924420492989, 38.5539003099714, 39.36717305864607, 37.87712492261614, 43.670602389744346, 44.58950860159737, 47.303506238119944, 46.76626804896763, 55.891952174050466, 52.27329560688564, 52.676221643175396, 1.390775857227189, 14.123903785433088, 4.96030420916421, 0.11113714213882174, 0.02928871302200215, 9.216131431715828, 52.62762941632952, 39.881697586604524, 46.84601599829537, 21.879764454705374, 21.02861533846174, 33.526857784816194, 47.88086332593645, 45.23616354806082, 44.12639032091413, 6.62537225655147, 0.19979862602693693, 0.02186185377649963, 0.03569453821650573, 0.054942961782217026, 0.06137706831629787, 0.017827038586671864, 0.03733389578493578, 0.03211670109469976, 0.034154094090419154, 0.003965139821437853, 0.005006705493932324, 0.008666991405854267, 0.02625401604122349, 0.037634195028139014, 0.11232265138200351, 0.05011888314038515, 0.01602913622212197, 0.03875773027539253, 0.014314108428412249, 0.04659896237509591, 0.02230715086417539, 0.10204403328576259, 0.03814536599176271, 0.011628638154694011, 0.053868491402161975, 0.12711909812475952, 6.09987565449306, 51.88616630009243, 53.20835638046265, 50.298572404044016, 38.28088821683611, 27.925907952444895, 20.580220290592738, 36.201407023838584, 34.679869651794434, 57.493289606911794, 20.00807956286839, 0.12017962549413953, 0.01344457598003958, 2.1486898107188086, 6.617979373250689, 5.642756274768284, 4.949564465454646, 9.71476890359606, 33.561331272125244, 51.74621220997402, 51.74238722664969, 57.66111292157854, 54.9254994392395, 53.78443499973842, 53.68039962223598, 54.791729245867046, 53.82384170804705, 51.144598960876465, 52.385616711207796, 50.183663095746724, 49.85504109518868, 52.4968295778547, 50.37643044335501, 41.07735749653408, 35.8922712462289, 38.37594999585833, 41.12446975708008, 48.18561479023525, 47.216452257973806, 52.00843027659825, 49.970245701926096, 47.70309713908604, 48.53526898792812, 50.76436921528408, 48.09748731340681, 50.26028782980782, 44.78566319601876, 45.35669394901821, 43.888084479740684, 49.120161397116526, 52.43670334134783, 50.363708291734966, 42.0307754107884, 38.45664290019444, 37.82066733496529, 36.799501010349815, 36.02542652402605, 37.509231703622, 35.67128726414272, 39.68214184897286, 44.12261397497994, 46.24108845846993, 45.35000283377511, 49.49091727393014, 44.881805419921875, 45.13820089612688, 45.524833406720845, 44.85104921885899, 45.724847725459504, 47.611287117004395, 45.27458708626883, 47.557761669158936, 46.01187086105347, 50.516544342041016, 33.624539034707205, 34.15716361999512, 53.268190792628694, 46.41127763475691, 48.7791542325701, 46.317393575395855, 46.468273707798545, 44.2165709904262, 46.57183313369751, 45.189155510493684, 45.942677225385395, 45.440180029187886, 44.01338134493147, 43.99865811211722, 46.46170766013009, 39.99240323475429, 38.7668764931815, 36.28226668494088, 38.511530194963726, 38.61032315662929, 39.01639672688076, 35.461173738752095, 37.636672088078086, 36.81187922613961, 42.55959585734776, 48.16977637154715, 49.97099263327462, 50.83935764857701, 48.38117183957781, 49.74861553737095, 51.252268246241975, 50.5233188356672, 50.828716482434956, 48.17197895050049, 45.55390814372471, 45.04070724759783, 49.32327113832746, 50.32708781106131, 48.87733227866036, 48.69507755552019, 42.177535261426655, 38.579351561410085, 38.84748254503523, 40.24830886295864, 39.402817317417686, 38.85282918385097, 38.25654867717198, 38.96780102593558, 38.99702514920916, 40.25427736554827, 41.30221857343401, 41.844688756125315, 39.98813009262085, 44.64663669041225, 46.332050800323486, 49.20006568091256, 50.17192758832659, 56.661583287375315, 54.644569873809814, 53.876936367579866, 1.857402435370854, 2.9118736471448625, 2.814137463058744, 0.1443633735179901, 0.09070227973695312, 10.106059312820435, 56.35551861354283, 43.79437065124512, 54.11097601481846, 20.852072034563335, 23.27948600905282, 37.995414529527935, 51.88377264567784, 50.3661401612418, 53.3369779586792, 8.783893551145281, 0.1839265384312187, 0.04249437512563808, 0.06694044478769813, 0.03845217917114496, 0.05294367192046983, 0.035512266747121296, 0.03351228817233017, 0.049618891041193686, 0.02726863115094602, 0.015509656597194927, 0.031528021075895855, 0.03645648893767169, 0.0092996591535796, 0.18691549875906535, 0.2730494668441159, 0.21816166995891503, 0.12798482738435268, 0.10098922345787287, 0.12068015363599573, 0.12031896944556918, 0.12624194233545236, 0.17261909161295208, 0.14838984103075095, 0.1625203735062054, 0.20177912046866758, 0.26831068683947834, 8.38491061755589, 61.02894646780831, 59.119359152657644, 56.07801103591919, 44.47533580235073, 28.329395055770874, 23.325767959867203, 47.828407900674, 43.835014138902935, 64.16307040623256, 21.872394153050013, 0.22795869782567024, 0.15284723256315502, 2.3588676069464003, 14.505577887807574, 13.91378504889352, 22.151183673313685, 26.386643988745554, 36.48035287857056, 53.89401156561715, 54.22057689939226, 61.42757851736886, 56.071035044533865, 55.96229573658535, 56.511627265385215, 57.00903490611485, 56.08635234832764, 52.50214147567749, 53.92669241768973, 51.58579567500523, 51.03868409565517, 56.203780378614155, 52.65299728938511, 42.31178835460118, 38.208498409816194, 40.58027989523751, 43.65294354302542, 51.209967613220215, 48.49256188528878, 52.482797690800254, 51.60087674004691, 50.46525274004255, 49.510073457445415, 51.44866255351475, 49.750658307756694, 50.70281512396676, 45.75237996237618, 48.383475167410715, 45.758129596710205, 49.39948245457241, 54.60521180289132, 53.06904847281319, 43.76821068355015, 40.72522279194423, 39.02504028592791, 38.83349929537092, 37.96219171796526, 39.90153121948242, 38.72058759416853, 42.0535238129752, 46.30222913197109, 47.46614619663784, 46.83267893110003, 52.210417883736746, 46.41192381722586, 47.74481759752546, 48.58130775179182, 45.338409764426096, 47.49009663718087, 51.21993480409895, 48.53049904959542, 49.97412627083914, 47.83911507470267, 50.10222673416138, 36.221174648829866, 35.62490803854806, 54.99450894764492, 47.67336579731533, 50.355304445539204, 47.76501601082938, 48.197023732321604, 46.88413381576538, 49.16404969351632, 48.03483540671212, 49.4901807648795, 48.65447228295462, 48.0056460244315, 44.819275106702534, 47.79977090018136, 41.63561051232474, 41.663615226745605, 37.003993443080354, 40.005764620644705, 39.96579858234951, 40.755871295928955, 36.076443672180176, 40.09602519444057, 38.516296659197124, 45.554245131356375, 50.25213759286063, 50.92984751292637, 53.859906332833425, 48.358479022979736, 51.74703209740775, 52.639924253736226, 51.34376212528774, 52.53307832990374, 48.532281262534006, 46.235543795994346, 45.4660690171378, 50.501372950417654, 53.35708257130214, 51.136879512241904, 51.91820444379534, 43.929652077811106, 40.537117685590474, 42.16782862799508, 43.52027811322893, 41.728108406066895, 40.79009812218802, 40.221669469560894, 41.743373598371235, 40.9162391935076, 42.121949672698975, 42.78539146695818, 42.799339975629536, 42.447799342019216, 46.92266157695225, 49.41386522565569, 51.7864214352199, 51.13221032278878, 59.810468673706055, 57.30429860523769, 57.396244117191856, 2.514771504061563, 26.800291095461162, 11.223834259169442, 0.1841238835560424, 0.26332741709692137, 11.098861353737966, 66.76009164537702, 47.14055013656616, 58.335518973214285, 30.264838354928152, 30.817279202597483, 42.93687956673758, 60.662533215114046, 57.478538581303184, 61.893503870282856, 11.3297004870006, 0.28037976207477705, 0.18170421410884174, 0.14744954077260836, 0.1286385687334197, 0.1302691019539322, 0.1962799469807318, 0.15511078467326506, 0.130441707691976, 0.10880752785929612, 0.11680651935083525, 0.08331074672085897, 0.13026482718331472, 0.10191323209021773], [0.05407990934327245, 0.0655782043135592, 0.03708680047254477, 0.049388341805232425, 0.012404501388248588, 0.1309314335563353, 0.05751374097807067, 0.042829893728984256, 0.055963556481791396, 0.0427588816466076, 0.05478888005018234, 0.04493140149861574, 0.1281297488936356, 6.795286544731685, 46.60195357458932, 50.41470112119402, 42.1215432030814, 25.49753860064915, 16.014644111905778, 24.213058131081716, 34.197209562574116, 34.16997609819685, 54.47070162636893, 11.490473117147173, 0.1505847389676741, 0.05117557251027652, 1.2741575092077255, 3.607277806316103, 5.606192682470594, 7.738749861717224, 20.54956136431013, 41.70241396767752, 49.81903553009033, 53.587575163160054, 51.90899460656302, 50.719793047223774, 49.35123068945748, 45.27472257614136, 48.700226170676096, 49.05702659061977, 52.11174998964582, 51.10661663327898, 50.61602864946638, 50.0164338520595, 50.430244241442, 41.151793548039024, 37.47781194959368, 37.01326928819929, 37.44581549508231, 45.27631718771798, 47.454952648707796, 47.50822796140398, 47.35384593691145, 48.31484086172921, 48.83563266481672, 47.73204680851528, 47.73131724766323, 45.523829392024446, 44.88844094957624, 47.386137689862935, 45.71150023596627, 48.559695380074636, 45.53805930273873, 44.65170540128435, 48.49981233051845, 41.3367337499346, 36.123882498059956, 35.38783550262451, 37.61181838171822, 34.85569034303938, 34.987035615103586, 34.072284426007954, 35.84176131657192, 39.45074946539742, 46.98201656341553, 45.65646702902657, 48.46165977205549, 46.14316749572754, 45.7017171723502, 42.757695947374614, 43.84145164489746, 41.77724954060146, 45.34180743353707, 43.17472335270473, 50.08792734146118, 45.31476157052176, 50.475734097617014, 32.72772114617484, 30.851248945508683, 51.99953658240182, 42.75682047435215, 45.7942567552839, 43.47488553183419, 46.858060700552805, 44.37115798677717, 48.10300418308803, 46.37086343765259, 47.17434270041329, 44.04998445510864, 44.80839422770909, 42.469741753169465, 42.59710570744106, 41.73689440318516, 39.361287934439524, 35.63261706488473, 36.00096539088658, 35.88541684831892, 37.214541230882915, 35.89259433746338, 35.71049247469221, 35.29646669115339, 44.77190923690796, 48.18222754342215, 48.479294300079346, 45.95084483282906, 47.133108615875244, 47.7717661857605, 48.536533560071675, 49.25406013216291, 44.57467072350638, 46.69776923315865, 47.70011288779122, 48.784302847726, 47.45820787974766, 47.899894441877095, 45.33757945469448, 40.02846438544137, 37.97351033346993, 39.79974705832345, 43.65818248476301, 46.28410128184727, 43.42313882282802, 42.12847055707659, 37.23904057911464, 39.447751317705425, 37.652468817574636, 39.8589630808149, 39.00382743562971, 44.182396275656565, 47.24328620093209, 50.427336420331685, 49.37471212659563, 54.15891858509609, 50.19679866518293, 57.65362276349749, 50.437317507607595, 55.24811124801636, 3.1039133880819594, 3.1351800646100725, 7.6651137215750555, 0.34959120250173975, 0.041674022895417044, 2.0228097311088016, 46.6458557673863, 32.80641644341605, 34.00408785683768, 23.581831659589493, 30.255861282348633, 33.22027894428798, 44.151643548692974, 46.51264142990112, 45.541957242148264, 8.994263291358948, 0.24423398450016975, 0.13818063028156757, 0.11715878759111677, 0.010004020063206553, 0.048454830289951394, 0.05327976727858186, 0.09677888652575867, 0.017835291268836175, 0.012847568640219314, 0.00536296097561717, 0.015002399084291287, 0.029789882379450967, 0.05983078878905092, 0.057788574802024026, 0.03035539382004312, 0.06376735041184084, 0.08197948137032134, 0.04338719489585076, 0.03271049726754427, 0.03224671179694789, 0.06373434646853379, 0.1098966376323785, 0.057969492594046254, 0.0098349757858419, 0.01908162948010223, 0.04549242103738444, 10.915844065802437, 56.41368893214634, 54.11901160648891, 50.25888776779175, 29.912106105259486, 19.93908221381051, 23.857279096330913, 34.76252889633179, 37.61205809456961, 61.28869097573416, 11.995282326425825, 0.18724655599466392, 0.04626790174682226, 3.3800430510725294, 6.7614679251398355, 7.355784262929644, 3.8055683204105923, 17.80200740269252, 42.82385669435774, 52.74621432168143, 54.17245020185198, 53.99832487106323, 52.51255335126604, 50.031170981270925, 48.02563599177769, 51.04418012074062, 51.30229875019619, 53.169672284807476, 53.2353709765843, 52.67083331516811, 50.70979458945138, 50.630394050053184, 45.001884187970845, 38.205663544791086, 38.99740730013166, 39.67175081798008, 46.68967110770089, 48.94929129736764, 50.63222142628261, 47.23217255728585, 50.702856813158306, 50.31403909410749, 49.110281058720176, 47.6005208832877, 47.05686255863735, 46.44286414555141, 48.56797068459647, 48.073807852608816, 47.89272390093122, 46.727743761880056, 45.88346120289394, 50.03092432022095, 44.05448688779558, 38.336175033024375, 37.50943667548043, 39.26316894803728, 36.24011891228812, 37.004535402570454, 35.44924020767212, 38.26792982646397, 43.23874058042254, 48.29159566334316, 46.71738052368164, 49.44963455200195, 47.172973905290874, 45.35825729370117, 45.215662888118196, 45.70050471169608, 43.940720558166504, 46.05922630855015, 42.795935358319966, 51.45627430507115, 46.314589977264404, 53.051222869328086, 33.85269703183855, 31.940254007066997, 54.63520022800991, 46.39931631088257, 49.2194059916905, 46.791361468178884, 47.99699204308646, 46.381879806518555, 49.95960453578404, 48.05946329661778, 48.973557880946565, 45.181154659816194, 46.29148374285017, 45.0657867704119, 44.4933420589992, 43.28893436704363, 42.871524810791016, 37.75540637969971, 37.53518669945853, 37.104763167245046, 37.669839314052034, 35.88311004638672, 36.486439500536235, 36.49851199558803, 45.74609184265137, 49.451298645564485, 49.09485605784825, 45.17135769980294, 47.99598108019148, 48.24819026674543, 49.905672618321006, 51.54550654547555, 45.59075444085257, 45.663040024893625, 49.04975182669503, 50.1238807950701, 50.36256531306675, 48.9880622455052, 46.777659620557515, 42.851090158735005, 38.93923698152815, 41.56925868988037, 45.815841334206716, 48.736624308994834, 45.68694877624512, 42.78604459762573, 38.937691007341655, 40.32603488649641, 40.24201726913452, 41.440883772713796, 41.426844937460764, 45.7913350377764, 50.235920497349326, 52.05164459773472, 52.41777992248535, 56.340124879564556, 52.5797632762364, 58.553268568856375, 53.44623490742275, 57.55568095615932, 4.514828273228236, 1.0516272272382463, 9.17609417438507, 0.5881020426750183, 0.0236161144649876, 2.1599007291453223, 50.66014276232038, 38.41556862422398, 38.207820960453574, 25.153224093573435, 29.125384160450526, 36.665077686309814, 51.83063629695347, 51.01093299048287, 53.94313185555594, 12.411848545074463, 0.25030633008905817, 0.12382580127034869, 0.06966847447412354, 0.026451798821134225, 0.04628509243151971, 0.020214726982106055, 0.01483983057551086, 0.017352637435708727, 0.019339949458039234, 0.03469563628147755, 0.029056806716003587, 0.01749479052211557, 0.029910444481564418, 0.17475972031908377, 0.12870335525700025, 0.11182227251785141, 0.15304501195039066, 0.1128136393214975, 0.1945860114480768, 0.16815494187176228, 0.1714012705321823, 0.16309513337910175, 0.13543321484965937, 0.14527771302631923, 0.09337517845311336, 0.14774859829672746, 15.488813127790179, 64.17067173549107, 61.61415849413191, 58.49246488298689, 35.354883670806885, 24.36034778186253, 34.405464444841655, 45.38965620313372, 44.147933210645405, 67.09635666438511, 13.631356409617833, 0.3427370217229639, 0.11847904031830174, 4.2396418281963895, 10.824348449707031, 14.944404397691999, 13.579172832625252, 23.66850869996207, 45.564955779484336, 54.96319689069475, 56.21015535082136, 56.05606515066964, 54.809478419167654, 52.61020333426339, 49.9775447845459, 54.056106090545654, 53.42442798614502, 55.473080021994456, 56.15936401912144, 54.26815121514456, 53.82831982203892, 54.02889347076416, 46.81193855830601, 41.163595063345774, 40.35973364966256, 41.911255972726, 49.86937870298113, 50.8768744468689, 52.76339374269758, 48.97100441796439, 52.076755387442454, 52.38817712238857, 50.24669715336391, 49.69664996010916, 47.549580165318076, 46.4150470324925, 52.0146141733442, 49.26896749223982, 50.494744368961875, 47.40487698146275, 49.49020160947527, 51.64882625852312, 45.15253850391933, 39.35662916728428, 39.07840245110648, 40.457470485142295, 37.08509281703404, 39.042205810546875, 36.29535361698696, 39.310145718710764, 45.65963193348476, 51.18843861988613, 49.02857371738979, 51.77256325313023, 49.54546063286917, 46.4133551461356, 45.604272161211284, 47.850673403058735, 43.95903253555298, 48.738409996032715, 44.75585194996425, 54.19851289476667, 48.879531383514404, 53.29235315322876, 35.32459994724819, 36.59924350466047, 55.150687081473215, 47.93700477055141, 49.257662773132324, 49.19215168271746, 50.75752871377127, 48.33876003537859, 51.486182825905935, 49.673276220049175, 50.65568896702358, 46.82423686981201, 48.82561683654785, 46.917339256831575, 46.96436466489519, 46.33477796827044, 44.42062568664551, 40.31952442441668, 40.5148834500994, 39.593152795519146, 39.52767992019653, 38.61679540361677, 38.43588515690395, 37.905650751931326, 48.09074061257498, 51.17079019546509, 51.33589676448277, 47.40617282049996, 49.00682585580008, 49.85594783510481, 50.53104175840105, 52.3111389705113, 47.126275062561035, 46.53612286703927, 49.14650549207415, 52.991367612566265, 51.991372449057444, 51.26573732921055, 49.16325412477766, 44.80239445822579, 40.526045731135774, 44.65233768735613, 49.21246474129813, 51.034115655081614, 47.380391529628206, 46.27625676563808, 40.79442684991019, 42.44687523160662, 42.28697633743286, 44.2600736618042, 44.027072770254954, 49.95442812783377, 52.8206399508885, 54.4996200289045, 53.66084391730172, 59.60753958565848, 54.583342347826274, 64.34349427904401, 53.49790866034371, 64.13767474038261, 4.36536123071398, 11.156579170908246, 16.214172056743077, 0.2961716061191899, 0.13901240564882755, 2.5251258398805345, 56.173003332955496, 42.82279014587402, 46.80768626076834, 34.05432333265032, 40.75311633518764, 42.86274923597063, 59.17036587851388, 55.31329924719674, 62.6246280670166, 15.848688125610352, 0.3603017692055021, 0.29781919771007126, 0.19698498557720864, 0.15588447744292871, 0.12768670623855932, 0.12792812899819442, 0.1783090148653303, 0.06789476357932601, 0.09091438299843244, 0.07442133408039808, 0.11145979232553925, 0.07944530913872377, 0.1436676172805684], [0.05652495939284563, 0.041195143413330824, 0.048638536860900264, 0.029680210764386823, 0.04984666167625359, 0.033259927428194454, 0.026639619010633657, 0.0260629626323602, 0.07107629893081528, 0.15603462367185525, 0.03543887979217938, 0.03413361590355635, 0.0486571456837867, 17.442973136901855, 54.51134511402675, 49.84327779497419, 38.81259216581072, 29.53205006463187, 19.09778390611921, 36.47488464627947, 41.42147397994995, 35.93358523505074, 52.96931055613926, 5.225453112806592, 0.03675399600927319, 0.1571699348943574, 2.9539782106876373, 4.209153567041669, 5.0920663731438776, 4.79169705084392, 26.104257038661412, 46.450336933135986, 49.798920495169504, 53.54690040860857, 52.1110760143825, 50.42903872898647, 47.905974115644185, 44.033326148986816, 41.00343908582415, 43.15126276016235, 45.705219064440044, 48.10151726858956, 46.6524635042463, 46.46973977770124, 41.39373677117484, 35.600641454969136, 35.90580633708409, 38.290615694863455, 44.86032853807722, 47.56654419217791, 47.82692098617554, 46.738040992191856, 48.212955951690674, 44.47776072365897, 43.87775598253523, 44.08274173736572, 47.07024826322283, 45.62926830564226, 46.86146879196167, 45.851589815957205, 46.4182779448373, 46.59734691892351, 47.34732852663313, 45.617317404065815, 49.04545783996582, 38.191239084516255, 34.49054513658796, 35.01702404022217, 35.249288422720774, 35.072887556893484, 34.74931689671108, 35.25828286579677, 35.361769335610525, 38.0487836429051, 43.131807804107666, 42.7471034186227, 46.586330550057546, 49.91455936431885, 48.38355507169451, 46.6227946962629, 47.628539494105745, 45.77795280729021, 48.083292143685476, 44.377550329480854, 48.38761976787022, 44.9617201260158, 49.817777906145366, 35.2376571382795, 29.89092799595424, 52.414816515786306, 42.54095731462751, 49.84316314969744, 46.307412488119944, 50.99421909877232, 46.53339569909232, 49.59348310743059, 46.64678682599749, 48.06149217060634, 46.80104725701468, 47.03020926884243, 42.81937510626656, 43.79508631569998, 42.42809077671596, 42.016337054116384, 35.841962814331055, 35.48654161180769, 36.38775771004813, 36.963648727961946, 35.3689398765564, 35.674730096544536, 35.397118295942036, 46.14190639768328, 48.469219412122456, 43.93570048468453, 48.062617778778076, 46.77407087598528, 47.42157350267683, 47.70484113693237, 43.992609705243794, 42.545272145952495, 47.687015533447266, 49.27215324129377, 46.315816334315706, 46.253807135990684, 43.11610834939139, 38.38172047478812, 35.001328059605186, 40.23881067548479, 46.71238476889474, 47.89013569695609, 48.01641225814819, 47.13536330631801, 41.27714252471924, 38.95937633514404, 39.24472148077828, 43.772886821201865, 46.38841111319405, 50.84314789090838, 51.14217403956822, 52.05348934446062, 53.234908921378, 55.03429433277675, 52.40250083378383, 55.498117855616975, 56.80577230453491, 58.60369164603097, 60.85987595149449, 9.957688348633901, 0.8020232894590923, 1.928580867392676, 1.2972320424658912, 0.08345468435436487, 0.32981888204813004, 28.729837111064366, 49.60978705542428, 36.16521038327898, 26.912363801683696, 25.06980923243931, 35.38652229309082, 38.840002809252056, 43.151314871651785, 41.62534802300589, 13.999491078513008, 0.19376308417746, 0.021948831787865077, 0.08083399212253944, 0.01797423997361745, 0.06290749726550919, 0.045906992363078256, 0.03569370361843279, 0.05249214418498533, 0.07037808639662606, 0.05889083458376782, 0.0063614931090601855, 0.03869028728721397, 0.020844365070973123, 0.06312791936631713, 0.014964463887736201, 0.028312949131109884, 0.054820818693510125, 0.007074895073726241, 0.04053383979148098, 0.04128984993855868, 0.03621152761791434, 0.01628675900532731, 0.12130452798945562, 0.04619037912094167, 0.04599208743976695, 0.04123310744762421, 21.80369905063084, 63.269942011152, 56.06071696962629, 44.72624567576817, 33.11783817836216, 23.767730712890625, 41.452407360076904, 39.33293233598982, 41.10089104516165, 56.01818009785244, 5.350257524422236, 0.17325192051274435, 0.16967750660010747, 1.90780770778656, 3.760729423591069, 3.6676209568977356, 6.6915468999317715, 26.503547430038452, 47.575983319963726, 50.823387214115684, 55.55725049972534, 52.60578427995954, 53.007206031254356, 49.9222788129534, 46.31684814180647, 43.31379154750279, 45.46275472640991, 47.61609179633004, 49.37939521244594, 49.71307897567749, 48.95755965369088, 43.74253708975655, 36.97666270392281, 38.22330502101353, 39.98221022742135, 47.61901698793684, 50.791112831660676, 50.15648521695818, 48.545263971601216, 47.575031416756765, 44.39294753755842, 44.68471629279, 44.89435734067644, 46.8924195425851, 47.28397485188076, 47.770314012254985, 48.3954747063773, 49.4218487058367, 48.21905647005354, 49.77067606789725, 48.26513344900948, 49.90549891335623, 40.947252477918354, 35.414839676448274, 35.790143149239675, 36.26554931913103, 36.59432765415737, 36.133158343178884, 35.82079860142299, 37.862318311418804, 39.34809677941458, 45.22944116592407, 44.561298915318076, 48.829615524836946, 50.34390592575073, 50.38894067491804, 47.34391001292637, 48.086721079690115, 47.17978661400931, 49.876267841884065, 46.325272832598, 50.122418199266704, 45.980628286089214, 50.96690573011126, 35.98916040148054, 32.701231139046804, 54.730647632053916, 44.565467834472656, 50.968361377716064, 47.874967779432026, 51.88624620437622, 49.227976594652446, 50.75920670373099, 48.3718786239624, 48.955131258283345, 49.83323417391096, 49.001350675310405, 45.43034832818167, 45.00143950326102, 44.5559800692967, 43.29309286390032, 38.710200037275044, 36.78362437656948, 38.1870562689645, 38.822517667497905, 37.19244595936367, 37.911431653159006, 37.8705449785505, 48.542766094207764, 50.99094302313668, 46.32801389694214, 49.260612283434185, 48.25496823447091, 48.32028130122593, 48.05118451799665, 44.08714689527239, 42.580628054482595, 48.16653503690447, 51.212555817195344, 47.65081194468907, 49.02965416227068, 44.726318631853374, 40.23783097948347, 35.721206596919465, 42.43289545604161, 48.31836359841483, 50.84047630855015, 50.422198227473665, 48.134819984436035, 43.640238761901855, 40.47592142650059, 39.966284956250874, 45.49211433955601, 47.407180309295654, 52.9453774860927, 54.157834666115896, 53.711367743355886, 55.6294527053833, 56.42740815026419, 54.53854731151036, 56.63712215423584, 58.599522726876394, 55.663603101457866, 62.92627716064453, 10.847788197653633, 1.3009177361215865, 5.410584390163422, 2.00068536400795, 0.16709895139294012, 0.185256372072867, 32.46165725163051, 52.92000266483852, 41.06131410598755, 26.514575958251953, 28.882754802703857, 39.83792393548148, 44.99532856260027, 49.09309121540615, 52.12509053094046, 19.694345814841135, 0.18116613583905355, 0.053004926669278314, 0.060728015644209724, 0.04772741360855954, 0.028761328464107852, 0.050359447553221665, 0.02037258815419461, 0.05490637178133641, 0.03688944856237088, 0.043762519756065946, 0.044356750191322396, 0.018258422313790237, 0.08571312709578446, 0.1340799174670662, 0.16697961065386022, 0.08703029248863459, 0.19544575602880546, 0.21182150659816606, 0.24250347593000957, 0.11144472884812526, 0.056783711936857016, 0.13841172573821886, 0.23518411868384906, 0.14938606614513056, 0.10904652146356446, 0.18998749820249422, 26.761320386614116, 69.59469958714077, 63.32292897360665, 48.742749146052766, 39.4132604598999, 27.004036596843175, 46.269287722451345, 54.86185394014631, 47.29778439658028, 60.84527778625488, 6.3052244526999335, 0.3084324082093579, 0.465061930673463, 6.362475872039795, 10.43551596573421, 10.745343957628522, 8.987978645733424, 28.90022257396153, 48.12332418986729, 52.497899600437705, 57.1866169657026, 56.11145966393607, 54.279473304748535, 52.1171417917524, 48.36416959762573, 44.8319798878261, 46.74639967509678, 50.26311922073364, 51.52105236053467, 52.61229474203927, 49.56029503686087, 46.023797443934846, 38.866715158735005, 39.273084027426584, 42.62676409312657, 49.60754973547799, 50.910385608673096, 50.693765095302034, 48.92723771503994, 47.37880039215088, 46.71082837241036, 45.36220734460013, 44.8262927872794, 48.50832387379238, 49.42552777699062, 49.77088451385498, 49.1433162689209, 49.57237100601196, 50.69875737598964, 50.890319211142405, 48.65550756454468, 52.96568359647478, 42.45644290106637, 37.41994040352957, 38.89069339207241, 39.32550818579537, 38.061769826071604, 38.731861046382356, 37.29861095973423, 40.3238844190325, 41.64339944294521, 46.94904736110142, 45.49992758887154, 50.21398156029837, 52.639778341565815, 50.975917543683735, 49.063116686684744, 50.21066379547119, 47.92292424610683, 51.99128907067435, 49.332918712071006, 52.233159337724956, 48.83544158935547, 53.245331219264436, 39.56783703395298, 34.01389523914882, 54.937669209071565, 47.57752234595162, 53.22665793555123, 51.450774805886404, 55.146733556474956, 50.35413367407662, 52.29757956096104, 50.79702227456229, 51.6745901788984, 52.45519249779837, 51.32575934273856, 48.13847473689488, 46.5656144959586, 47.36640133176531, 45.72358315331595, 40.03316484178816, 38.98687383106777, 40.99765471049717, 40.82937976292202, 39.557289668491904, 38.552826813289094, 38.86657966886248, 49.63627011435372, 53.71353905541556, 49.30691507884434, 51.09431484767369, 50.62632587977818, 49.90958098002842, 49.72274044581822, 45.69645043781826, 43.78930194037301, 50.0655471937997, 53.80608211244856, 51.07954297746931, 51.52654491152082, 47.48646967751639, 42.67829193387713, 38.99585090364729, 44.58713231767927, 49.697442054748535, 53.28924036026001, 52.00940302440098, 51.245566708701, 45.7506776537214, 43.00482600075858, 42.779641832624165, 47.12870345796858, 50.24774980545044, 54.896886757441926, 55.07116494859968, 55.82035446166992, 58.01827117374965, 58.94955907549177, 56.88673618861607, 60.24317468915667, 60.26325498308454, 59.911655289786204, 61.70134449005127, 13.113332595144, 3.242062032222748, 5.762386884008135, 3.197738604886191, 0.15137798711657524, 0.46505878227097647, 34.60408912386213, 60.56312533787319, 49.781925201416016, 36.37285382407052, 33.14624241420201, 45.065769399915425, 52.187374183109824, 54.87724072592599, 61.432595116751536, 26.26130543436323, 0.26103912560003145, 0.10743927556489195, 0.241435244679451, 0.1267733709620578, 0.10670177585312299, 0.14923355861433915, 0.10490632469632796, 0.1866001428237983, 0.21882421869252408, 0.13874703060303414, 0.10879063912268196, 0.12297698110342026, 0.1818759377513613], [0.03934184375352093, 0.02542947555359985, 0.043985011388680766, 0.05732407686965806, 0.059261009363191466, 0.038793299081070085, 0.00462394643441907, 0.0072199552586036065, 0.05529617318617446, 0.051142229299460135, 0.019694904696994593, 0.047252961567470005, 0.20141989045909472, 26.452010904039653, 51.801096030644004, 48.8855311529977, 41.01102304458618, 29.72309078489031, 18.195214646203176, 21.367228848593577, 30.38907561983381, 41.1482048034668, 47.83305971963065, 1.908054803098951, 0.08746121650827782, 0.14028630086353847, 3.2290908311094557, 4.130361429282597, 4.111794105597904, 7.013619354793003, 37.47639104298183, 43.147618430001394, 50.11798872266497, 49.690400055476594, 51.843751021793906, 51.957173415592735, 50.73568705150059, 46.34466872896467, 43.90266874858311, 36.32557480675833, 37.83408778054373, 36.7014410836356, 38.16524587358747, 37.7346590587071, 35.261871610369, 35.72132471629551, 36.97910846982683, 43.02382237570626, 49.293730872017996, 47.67462689535958, 49.869243213108604, 46.932715620313374, 46.4263448034014, 46.23639842442104, 42.6511036327907, 46.80524744306292, 47.30539962223598, 45.74161720275879, 46.860735757010325, 44.01312773568289, 44.21039056777954, 45.757160323006765, 45.372306551252095, 48.4239901133946, 42.92715208871024, 34.673703125544954, 35.12843493052891, 35.71665205274309, 36.71619210924421, 33.73548786980765, 35.025493894304546, 33.248981952667236, 35.55300807952881, 34.542420387268066, 39.809134074619834, 40.61914464405605, 45.108309745788574, 43.370617389678955, 47.584077971322195, 46.19363921029227, 48.56304093769619, 45.962038380759104, 47.17067405155727, 45.91367891856602, 48.96611983435494, 44.168367862701416, 51.52768094199044, 36.17617116655622, 27.524706806455338, 51.83495807647705, 44.50689104625157, 49.52419567108154, 47.350489956992014, 48.54155363355364, 45.3993558883667, 47.84772736685616, 43.20745979036604, 48.67158917018345, 47.19087246486119, 47.75791495186942, 41.74010099683489, 41.359134742191856, 40.69229875292097, 41.8291734286717, 37.965318407331196, 35.2593355178833, 36.24637229101998, 37.45885031563895, 36.6235031400408, 34.14076934541975, 34.41871813365391, 44.555792467934744, 46.64123868942261, 46.93150315965925, 48.66551297051566, 47.99799953188215, 46.29162270682198, 50.14073365075247, 44.62288427352905, 44.6712715285165, 48.19881984165737, 45.55718074526106, 44.58043425423758, 40.6438524382455, 36.55750914982387, 35.66544382912772, 40.14968613215855, 46.29495089394705, 47.15026371819632, 47.63782228742327, 49.13651745659964, 47.71018430164882, 44.239368030003135, 40.54054662159511, 41.00441878182547, 47.32491363797869, 49.1583000591823, 50.4730520929609, 51.87509781973702, 49.797774042402, 51.27471440179007, 50.75004550388881, 52.60082674026489, 49.167829513549805, 52.23306206294468, 45.74798175266811, 51.03002316611153, 13.309717348643712, 0.4214402442531926, 6.04780889408929, 2.7454942549977983, 0.26869082929832594, 0.17149209922977857, 16.260056223188126, 54.34043679918562, 32.282702922821045, 31.387340681893484, 19.215027809143066, 27.784409625189646, 41.72547156470162, 46.68220179421561, 47.54552241734096, 17.588426726205007, 0.1241573334804603, 0.007998499553650618, 0.010935584182984062, 0.04748006045286145, 0.03410880187792437, 0.049700908961572816, 0.04788021290940898, 0.04305351172973003, 0.044110520011080165, 0.0899100833173309, 0.03816933524129646, 0.07759201965693917, 0.05895209951060159, 0.01439230450029884, 0.04707610820020948, 0.09947728458791971, 0.056174553731190305, 0.007795409781725279, 0.005943039714890931, 0.025201199409951056, 0.026324012017409717, 0.008921669347078671, 0.005007730081810483, 0.03283099830150604, 0.03291141148656607, 0.41303723944084986, 32.37331090654646, 57.85527685710362, 53.94966663633074, 45.69892399651663, 31.90168455668858, 22.76300208909171, 26.794216632843018, 35.7739816393171, 45.79724448067801, 52.81123208999634, 1.8004428403718131, 0.08210235727684838, 0.3073794032846178, 3.3389292572225844, 2.9552966313702718, 4.727758424622672, 8.740376114845276, 36.5324296270098, 45.964928831372944, 49.28820358003889, 51.872957774571006, 52.41668210710798, 54.2264654976981, 50.29022066933768, 48.58175243650164, 44.98428092684065, 38.18301936558315, 39.42637518474034, 38.743061542510986, 38.752295698438374, 40.53287581035069, 37.25159249986921, 37.579870564596995, 38.61903619766235, 44.446031774793354, 50.84161581311907, 48.96873583112444, 51.75584588732038, 49.06904697418213, 49.418207849775044, 45.61898149762835, 43.46608216421944, 47.60878923961094, 49.68213864735195, 45.77868584224156, 49.936449663979666, 47.28568410873413, 46.958045278276714, 48.00248806817191, 47.50767905371529, 50.16595213753836, 45.630640574863975, 37.28417955126081, 36.1743403162275, 37.12783466066633, 38.14612095696585, 35.76882955006191, 35.675345012119834, 34.366884572165354, 37.37483269827706, 37.73259891782488, 41.1581963130406, 43.12399802889143, 46.62893690381731, 45.71135432379586, 48.38286025183541, 47.50392702647618, 49.765468393053325, 47.97278799329485, 48.96002279009138, 48.43216814313616, 49.381497042519705, 47.3730959211077, 53.17402185712542, 38.21062455858503, 28.32817564691816, 52.90180533272879, 46.48066929408482, 50.68557316916329, 48.28202451978411, 50.03197349820818, 47.787663664136616, 49.30169350760323, 45.73765672956194, 49.255845819200786, 48.15695694514683, 48.89944839477539, 43.64965009689331, 42.06922674179077, 43.712225573403494, 44.057891505105154, 42.16186012540545, 36.043109689440044, 38.27530881336757, 38.96483414513724, 38.069006374904085, 36.43206637246268, 37.309710706983296, 46.8960291317531, 49.00192390169416, 48.951761381966726, 52.30882522038051, 48.77409246989659, 48.89369876044137, 51.598021030426025, 47.61230155399868, 45.56709582465035, 50.953141348702566, 47.060468673706055, 47.109251976013184, 42.82212659290859, 39.20767021179199, 37.46656281607491, 41.091340746198384, 47.86723443440029, 50.71189989362444, 49.715670653751914, 51.79595783778599, 49.41770757947649, 47.52395520891462, 40.95560073852539, 42.62200805119106, 47.951912130628315, 51.01203427995954, 51.508785315922324, 52.72076654434204, 50.81238126754761, 52.62586109978812, 49.86780841009957, 52.38913944789341, 48.84814289637974, 53.59803915023804, 44.03303779874529, 51.98743282045637, 15.267535584313528, 0.6023342332669667, 8.082218425614492, 4.754565877573831, 0.31980766781738823, 0.15250941711877072, 17.425856249673025, 57.616627080099924, 38.43245274680001, 33.19177048546927, 20.05369622366769, 32.16544164930071, 47.09188495363508, 52.31523493358067, 55.27686636788504, 25.246567930494034, 0.14259416131036623, 0.04758156929165125, 0.03025251773319074, 0.019745272351428866, 0.014962419800992523, 0.04655738853450332, 0.012555224371940961, 0.027468970311539512, 0.03752212139910885, 0.0456563042077635, 0.03714840127421277, 0.05471852614677378, 0.03617684430043612, 0.09475938989115612, 0.10685821888702256, 0.08955869717257363, 0.13275709987751075, 0.17053754973624433, 0.06888362658875329, 0.11884074019534246, 0.10109430817621094, 0.1142533684947661, 0.08007009061319487, 0.10092884741191353, 0.12588770634361676, 0.6468014014618737, 36.785635880061555, 64.84269455501011, 61.43444333757673, 55.2940388407026, 39.86069318226406, 25.209167514528545, 29.765773568834575, 43.53069346291678, 52.49448108673096, 57.86783920015608, 2.587887180703027, 0.17514792377395288, 0.4271067444767271, 9.980014647756304, 10.828334978648595, 9.416384594781057, 9.447307552610125, 37.54323966162545, 48.453943797520225, 53.00843933650425, 53.24169036320278, 53.3765583719526, 55.07915537697928, 54.67043454306466, 49.816499437604634, 48.23154933112008, 38.15012659345354, 41.22540623801095, 39.788616044180735, 40.994809423174175, 41.34785086768014, 38.85753311429705, 37.82453400748116, 41.7543864931379, 46.79509612492153, 53.35725280216762, 52.014621121542795, 53.639127322605674, 48.914056982312886, 48.776698044368196, 47.073048387254985, 43.1254050391061, 49.711050101688926, 51.6029577255249, 48.429437501089915, 52.996161869594026, 48.08483811787197, 47.17934192929949, 50.2350241797311, 48.92617464065552, 54.10020283290318, 48.186931473868235, 39.89709479468209, 37.969261510031565, 37.978652000427246, 39.616057532174246, 37.18152339117867, 39.08162988935198, 35.7500034059797, 39.769185406821116, 38.35056127820696, 43.06220075062343, 44.530052866254536, 49.57490362439837, 46.75416776112148, 50.36713375364031, 50.06394910812378, 51.43857724325997, 49.62200893674578, 51.01277773720877, 50.36459766115461, 51.915286200387136, 50.37415838241577, 54.544050284794395, 40.245279448372976, 31.397967951638357, 53.418730463300435, 47.199727943965364, 51.65094893319266, 49.725422450474326, 51.75417137145996, 49.35634456362043, 52.19581624439785, 46.69858564649309, 51.390749318259104, 49.994314261845176, 51.741303307669504, 45.83236067635672, 44.66391338620867, 46.66192347662789, 45.76471301487514, 42.95465653283255, 38.162786211286274, 40.51521348953247, 41.23318127223423, 40.7396159853254, 38.1267945425851, 38.67660549708775, 48.81008413859776, 51.468020234789165, 50.472096715654644, 55.10625682558332, 52.08464159284319, 49.71868617194039, 53.39312635149275, 49.804690974099294, 47.397831508091514, 51.430381843021934, 48.809187820979524, 47.69340787615095, 44.864414078848704, 39.82852302278791, 40.52934265136719, 44.89856794902256, 49.69651447023664, 53.00983592442104, 52.28068849018642, 52.12285321099417, 52.93217243467058, 50.36789458138602, 44.25963939939226, 45.132517269679475, 51.36566284724644, 52.85672542027065, 53.76855141775948, 55.30078206743513, 51.640776770455496, 52.97916310174124, 52.5791448865618, 54.15028544834682, 49.787146772657124, 55.543249879564556, 48.08029399599348, 57.0086909702846, 16.92539140156337, 2.115036645105907, 14.168898582458496, 8.394690207072667, 0.7948860781533378, 0.3045641343508448, 20.306601967130387, 63.37986946105957, 45.55681596483503, 42.8065904208592, 27.258807931627544, 38.88015297480992, 53.57357106889997, 60.90404564993722, 63.11087690080915, 33.14867080960955, 0.40378142467566897, 0.11446425717856203, 0.09348546074969427, 0.1760685329458543, 0.16589494528514998, 0.07231277293924775, 0.12106144960437502, 0.0940883391137634, 0.13258956958140644, 0.14286512748471328, 0.05356990545988083, 0.128062777487295, 0.1928031878279788], [0.05244696732344372, 0.022167844232171774, 0.014790056639217904, 0.057822766181613715, 0.04183196549170783, 0.05889314838818141, 0.004767664392212672, 0.015151824369760496, 0.0260357788231756, 0.029157789690153937, 0.05628438140930874, 0.01722572254948318, 1.6023620750222887, 31.387809685298375, 46.581174986703054, 46.46109274455479, 30.06206907544817, 28.844256571360997, 16.367129700524465, 26.48311972618103, 33.83359643391201, 48.35666901724679, 34.80670206887381, 0.19785712020737783, 0.06032043322920799, 0.33663856610655785, 0.46118603008134024, 1.0041787390198027, 2.978687959057944, 14.918927090508596, 31.38300848007202, 46.78738709858486, 50.48341185706002, 51.16855982371739, 51.3097367967878, 50.350621359688894, 50.904972961970735, 49.2954957144601, 47.54661675861904, 42.164038385663716, 37.050831249782014, 38.53004714420864, 40.46456459590367, 36.55884320395333, 36.75377491542271, 36.48558834620884, 39.828394481113975, 43.92463547842843, 47.897886412484304, 47.14218296323504, 48.723968165261404, 46.78755732945034, 46.59774644034249, 42.87202855518886, 45.149495192936485, 47.01486069815499, 44.353238582611084, 42.9671493938991, 41.579500334603445, 41.54422780445644, 41.6350998197283, 40.60085698536464, 43.90384994234358, 40.71834407533918, 36.01726239068167, 35.710541112082346, 33.52515547616141, 36.36412688664028, 36.74389457702637, 35.37264674050467, 35.27540670122419, 36.28474719183785, 33.921345233917236, 34.01107427052089, 34.91281843185425, 37.25147785459246, 38.87064783913748, 41.39642572402954, 41.82902751650129, 41.75675582885742, 44.93505641392299, 43.33942345210484, 46.68264995302473, 43.588134220668245, 48.116056374141145, 47.52797474179949, 52.51706273215157, 37.31757606778826, 24.564767258507864, 45.75676080158779, 43.888129643031526, 47.64301953996931, 45.36462531770979, 46.52911908285958, 45.08889995302473, 46.727761132376536, 49.02461324419294, 47.03274188722883, 46.53623056411743, 43.447672912052695, 39.22483573641096, 42.9779121535165, 41.78668519428798, 42.498416968754356, 41.28484460285732, 36.00610358374459, 34.812281472342356, 36.170400687626426, 35.51019327981131, 34.396400519779746, 34.10366249084473, 40.04831886291504, 50.40317405973162, 48.97789703096662, 47.22451564243862, 44.90642983572823, 47.01632329395839, 48.12493964603969, 47.83966398239136, 45.610497747148784, 44.04192107064383, 48.61948810304914, 43.49789449146816, 36.81797627040318, 35.484523160117014, 39.87286295209612, 47.23384707314627, 49.10607392447335, 49.10241917201451, 45.039244651794434, 48.34108420780727, 47.12856101989746, 45.33714519228254, 40.95247057506016, 44.67976917539324, 46.48132937295096, 52.14652572359358, 48.2090163230896, 48.13596643720354, 47.412780557359966, 53.85054363523211, 50.34656361171177, 52.94137532370431, 47.8737553187779, 49.45665223257882, 50.96572801045009, 55.70072732652937, 14.230837430272784, 0.7648401132651738, 2.035680183342525, 10.137277569089617, 5.849679274218423, 0.9730583003589085, 10.144282221794128, 51.7281607900347, 39.530365398951936, 32.067756925310405, 27.78914655957903, 27.266426631382533, 42.293326990945, 44.525060585566926, 49.413587297712056, 28.534653527396067, 0.9797736257314682, 0.061150362981217246, 0.055816545084651024, 0.031640640925616026, 0.049963712359645536, 0.09334872237273625, 0.01595727427463446, 0.038639760177050314, 0.02814672501491649, 0.030224422990743603, 0.022353308208818947, 0.003251753547894103, 0.03147642527307783, 0.014955659895869238, 0.01746551343239844, 0.051517954495336325, 0.037737820896187, 0.011570019514432974, 0.09943648427724838, 0.04152361543050834, 0.03088738563071404, 0.033617657875376086, 0.043967182881065776, 0.02557747930820499, 0.05956730007060936, 2.099752345255443, 38.39148964200701, 53.586435658591135, 53.69259023666382, 35.09218617847988, 36.71509081976754, 21.730980941227504, 26.57826488358634, 41.10643918173653, 53.3422030040196, 37.715881552015034, 0.29108842888048714, 0.055504646285304, 0.7876331359148026, 3.0826586314610074, 3.0828038922377994, 2.6866173914500644, 12.897410375731331, 34.96300179617745, 49.00874355861119, 52.553519930158345, 51.23674249649048, 53.81752232142857, 50.591935770852224, 54.274147510528564, 51.075808320726665, 49.452122007097515, 43.92509405953543, 38.900997570582796, 38.30551610674177, 41.95844118935721, 38.58371155602591, 37.40180907930647, 38.120200702122276, 41.16205256325858, 45.74538312639509, 49.48138781956264, 49.913982663835796, 50.17527314594814, 47.76509591511318, 46.21146828787667, 42.775122029440745, 46.78737667628697, 49.188667161124094, 47.057064056396484, 46.13406882967268, 43.441662720271516, 45.60860783713204, 42.75753961290632, 43.08345529011318, 44.6190801348005, 42.95348228727068, 38.36389487130301, 37.79636948449271, 35.059227398463655, 36.73520932878767, 38.23178877149309, 36.691084793635774, 36.516744068690706, 36.97907372883388, 36.24770981924874, 35.7045830317906, 37.58250740596226, 39.19698388235909, 41.93205540520804, 43.46260806492397, 44.24349873406546, 44.40459966659546, 46.766142981392996, 46.44516747338431, 47.76502643312727, 45.210931164877756, 48.66612441199166, 49.267893995557515, 54.41825314930507, 38.86391850880214, 26.20076925413949, 47.265433583940776, 44.40647915431431, 49.27040924344744, 46.08575453077044, 47.75839785167149, 46.51411097390311, 49.10324600764683, 49.61666924612862, 48.57714925493513, 48.558535030909944, 45.76010635920933, 40.578577586582725, 45.0889173235212, 43.300284249441965, 43.55480023792812, 42.70614031382969, 37.92456374849592, 35.38870750154768, 36.53229761123657, 37.883552006312776, 36.378759792872835, 35.363158975328716, 42.98630557741438, 52.83286183220999, 52.68170724596296, 48.51253795623779, 45.86487824576241, 48.27427380425589, 49.709549290793284, 48.544426713671, 47.16234316144671, 48.70576735905239, 50.490474700927734, 45.95990180969238, 38.069162709372385, 36.20917163576399, 42.01487793241228, 50.289223602839876, 51.79539155960083, 49.94848394393921, 46.28006090436663, 50.654028347560335, 49.4897187096732, 46.972487109048025, 42.72269092287336, 45.485600403376985, 47.82294314248221, 53.613634381975444, 49.21746049608503, 48.820902483803884, 48.78636646270752, 53.319197518484934, 50.64849410738264, 54.87289115360805, 48.64690916878836, 52.0350592476981, 51.65964460372925, 55.51681545802525, 17.861298118318828, 1.02462956735066, 6.1281274642263135, 16.915066378457205, 9.90713586126055, 1.4579805710486002, 11.117492948259626, 56.054571287972585, 44.18235111236572, 33.03632191249302, 34.19873816626412, 33.68332774298531, 46.31178290503365, 50.65768657411848, 56.15908261707851, 37.03434317452567, 1.22337421136243, 0.11133925736482654, 0.0701649042644671, 0.010409170778335204, 0.04786606884694525, 0.0345870740711689, 0.0319395627427314, 0.038720712797450166, 0.011415172734164765, 0.01965387198807938, 0.05041742158521499, 0.06649382625307355, 0.049350214922534566, 0.09272571187466383, 0.13185025139578752, 0.0872753250545689, 0.14881661241608007, 0.16074804003749574, 0.17681573570838996, 0.13493998774460383, 0.0664175453462771, 0.09298358232315097, 0.12945106013544969, 0.1072862319914358, 0.21604088161672863, 2.878731608390808, 46.03400434766497, 59.601001330784385, 61.73709992000035, 42.2582003729684, 37.03087602342878, 20.670670202800206, 36.01297882625035, 48.73394577843802, 56.97482197625296, 42.97479936054775, 0.4210529364645481, 0.23490849775927408, 1.0275801633085524, 6.2826723371233255, 5.822930446692875, 5.782086764063154, 16.30761664254325, 38.82197570800781, 51.71434429713658, 53.05618735722133, 55.048023973192485, 54.89433676855904, 54.86954212188721, 55.663953985486714, 53.24362196241106, 51.58692128317696, 46.17319761003767, 40.70581299918038, 41.530963693346294, 43.92798798424857, 40.00460774557931, 39.37461110523769, 40.79004948479788, 42.94012437547956, 48.37351492473057, 50.83937849317278, 50.69893455505371, 52.48730707168579, 49.40815380641392, 49.47655187334333, 43.9784631729126, 47.78019435065133, 50.26048585346767, 48.69824940817696, 47.736809798649375, 45.3491655758449, 46.27305364608765, 44.74227864401681, 44.42449235916138, 46.573990549360005, 44.619618620191304, 39.913075651441304, 40.5915116582598, 36.30720724378313, 39.13125044958932, 39.46041440963745, 38.92131062916347, 37.556295326777864, 38.97651754106794, 38.05756269182478, 37.50710555485317, 39.09943812234061, 41.34193100248064, 42.96434579576765, 45.245488030569895, 45.235256808144705, 45.75665657860892, 48.51466063090733, 46.77923338753836, 49.077926771981375, 48.04859283992222, 50.812343052455354, 51.857709952763145, 55.838697705950054, 40.98502288545881, 30.676161289215088, 46.67565311704363, 46.28755801064627, 50.31396613802229, 48.392282009124756, 48.7862274987357, 48.36172383172171, 49.311070101601736, 53.25807074138096, 49.9135935647147, 51.03700263159615, 46.80107157570975, 42.379401275089805, 47.428063120160786, 45.62704488209316, 46.25546775545393, 44.14949655532837, 40.204545634133474, 37.414934226444785, 39.01671634401594, 39.32704026358468, 38.09170961380005, 37.74984434672764, 44.33469384057181, 54.69725111552647, 54.21688045774187, 51.67119598388672, 49.36948708125523, 50.90105765206473, 51.66273307800293, 50.8447390283857, 47.68125547681536, 49.610419341496055, 54.28977748325893, 48.82673897062029, 39.97507095336914, 38.31701190131051, 44.71656683513096, 52.51569741112845, 55.40916701725551, 52.97557088306972, 46.1509599004473, 53.56361082621983, 50.148762294224326, 51.23231301988874, 44.67622559411185, 49.60873440333775, 49.61225366592407, 56.7273827280317, 51.71087714603969, 50.194776739392964, 48.572469643184114, 55.842154434749055, 50.51948690414429, 58.01456430980137, 50.14149100439889, 52.44232095990862, 51.48841667175293, 58.60707541874477, 18.896270513534546, 2.9077190586498807, 9.392341222081866, 18.49305612700326, 8.71753478050232, 1.4249015003442764, 13.264954447746277, 60.083442551749094, 52.17422124317714, 41.80671337672642, 40.949840681893484, 37.98249088014875, 53.11420828955514, 57.644162791115896, 64.24391964503697, 43.13960368292672, 1.8097839334181376, 0.2705662729484694, 0.17995556151228292, 0.20666755815701826, 0.16386666840740613, 0.15460953728428908, 0.0951153968593904, 0.25513071407164845, 0.13468533355210507, 0.12970936484634876, 0.18453636499387877, 0.14847180806100368, 0.12778415743793758], [0.048255856681082926, 0.057599548516528945, 0.031147427391260862, 0.07320299731301409, 0.07191253905849797, 0.011149178525166852, 0.04216790817944067, 0.03719014474856002, 0.041448264116687436, 0.02164199825243226, 0.0414973289838859, 0.033628548362425396, 3.205187508038112, 40.11288499832153, 50.39592361450195, 44.2234080178397, 33.045910426548545, 15.130722079958234, 22.410525185721262, 35.968242849622456, 32.34135614122663, 56.45687893458775, 21.08232491356986, 0.057962870092264245, 0.009225492731535008, 0.49242475096668514, 1.9406828922884805, 1.2662493735551834, 5.04992641721453, 17.249608244214738, 47.277301107134136, 53.80557836805071, 51.59393201555525, 53.227512563977925, 50.68527092252459, 49.44788013185774, 48.075694288526265, 45.926442759377615, 44.87228986195156, 39.37679283959525, 37.40843766076224, 37.353863034929546, 37.24319560187203, 36.55510854721069, 35.900737626211985, 35.802319867270334, 38.088860852377756, 41.58498593739101, 44.21176631110055, 44.9634085382734, 46.030099460056846, 48.52698673520769, 49.16774960926601, 47.28679929460798, 43.2293952533177, 47.04022509711129, 47.0415278843471, 43.18356840951102, 41.40350941249302, 36.409846033368794, 36.74524252755301, 36.022206033979145, 37.401180267333984, 34.26336336135864, 34.0322002683367, 35.49987173080444, 35.10470683234078, 34.52445929391043, 36.04648651395525, 35.63423599515642, 34.838545663016184, 33.051562786102295, 33.32907731192452, 33.897926330566406, 34.280379499707905, 35.39612817764282, 39.76816054752895, 39.2886757850647, 41.72939034870693, 41.74390860966274, 44.00790269034249, 43.19550541469029, 45.638353075299946, 45.115032127925325, 46.93619319370815, 47.417067595890586, 48.927630288260325, 38.08842658996582, 22.977496453693934, 47.899001598358154, 44.68965298788888, 48.16338402884347, 48.21952199935913, 48.16174077987671, 45.784386839185444, 48.490876947130474, 43.416725635528564, 42.00486210414341, 40.54384354182652, 37.25051552908761, 37.4881717136928, 40.69551229476929, 44.52971935272217, 42.97603266579764, 41.337362561907085, 37.29096099308559, 34.25868374960763, 36.805737018585205, 35.685482433864046, 35.585720198495046, 36.94879347937447, 35.464637415749685, 40.488077299935476, 41.984146050044465, 40.297887734004426, 40.59895665305001, 45.24016918454851, 47.32435430799212, 47.7366395677839, 41.94825513022286, 44.615963867732454, 46.94694553102766, 46.292275837489534, 37.11415018354143, 38.1324781690325, 45.20150940758841, 49.771541118621826, 47.33902195521763, 43.20857845033918, 44.25577620097569, 47.98487091064453, 49.89394058500017, 46.3408020564488, 45.508143833705354, 47.710090500967844, 46.92036519731794, 51.066768714359824, 45.964234011513845, 49.13272374016898, 51.16652052743094, 53.724590165274485, 47.24125732694353, 54.460168157305034, 49.580844334193635, 55.96771533148629, 36.7298071043832, 42.537031582423616, 23.849610022136144, 0.14352294004389218, 3.6926692128181458, 12.515938639640808, 3.765404692717961, 0.27263642900756424, 4.969668209552765, 46.75004053115845, 43.56970412390572, 41.18554442269461, 19.15070138658796, 19.392781836645945, 45.77444396700178, 49.178762504032676, 49.251933983394075, 34.3363333429609, 1.175533584186009, 0.17488625352936132, 0.058135652249412875, 0.021721329174137542, 0.09836253976183278, 0.0298682328180543, 0.038125023511903625, 0.08137302034135376, 0.043116306753030846, 0.023353249998763204, 0.05517030494021518, 0.06251940916159324, 0.034843241396759234, 0.022919766205762113, 0.031311473410044394, 0.0571128014209015, 0.06783458430852209, 0.032951665576547384, 0.03255912967558418, 0.039314658247998784, 0.05147042990263019, 0.027754628465377858, 0.022057282039895654, 0.045918904045330625, 0.05880798545799085, 4.59365211214338, 49.97119760513306, 55.04953868048531, 50.99126958847046, 38.1991183417184, 21.791015114103043, 15.011867931910924, 32.20265620095389, 38.69321516581944, 59.91699845450265, 24.724263157163346, 0.03526946995407343, 0.05133455665782094, 1.7279251430715834, 2.9558216546263014, 1.8808306753635406, 6.840045537267413, 19.312908819743566, 49.01624413899013, 55.02556392124721, 52.95910365240914, 53.26723888942173, 53.22995138168335, 50.89536707741873, 49.256488527570454, 47.183549063546316, 47.74479675292969, 40.98146193368094, 38.57991436549595, 38.3008017539978, 38.095760413578574, 37.94769777570452, 38.33411489214216, 37.844826221466064, 39.43498052869524, 43.15690817151751, 46.44607073920113, 46.27705928257534, 47.57426016671317, 48.093974999019075, 51.04994365147182, 48.713636193956646, 44.512710162571494, 50.134132862091064, 47.606802054813926, 45.88755716596331, 42.28493356704712, 37.745063986097065, 39.13431460516793, 37.87473126820156, 38.39182315553938, 36.35890531539917, 36.71954114096505, 36.37583460126604, 36.220670904432026, 36.41815955298287, 36.63922691345215, 36.60882159641811, 36.86202437537057, 36.86683252879551, 35.51306288582938, 36.053306170872276, 36.5208226612636, 38.47559411185128, 41.35775205067226, 39.79041562761579, 44.42220292772566, 44.425854206085205, 45.531795501708984, 43.75292812074934, 47.84826932634626, 45.69058963230678, 48.56481620243618, 49.681440353393555, 50.86923837661743, 39.49999829701015, 23.60105037689209, 48.52476678575788, 46.117136069706504, 49.80990212304251, 50.170447622026714, 49.6206818308149, 48.55217742919922, 48.64998027256557, 46.26622009277344, 43.94217620577131, 42.03151886803763, 38.670265265873496, 40.56995139803205, 41.758538041796, 44.87607315608433, 45.68679244177682, 42.72408751079014, 38.79210192816598, 36.93141256059919, 36.99128866195679, 38.4007168497358, 36.85248449870518, 38.248005867004395, 37.78073951176235, 42.70621674401419, 44.67833089828491, 43.43305042811802, 41.96179716927664, 48.066578251974924, 49.27191700254168, 49.549417631966726, 44.42198405947004, 46.43141351427351, 49.050349371773855, 46.99314062935965, 38.116966315678184, 38.47576434271676, 47.779951163700645, 51.25987652369908, 49.90076719011579, 44.90172937938145, 45.7532901763916, 49.7438143321446, 51.715337889535085, 50.55342885426113, 47.39464923313686, 50.135161195482524, 49.454727581569124, 51.69266244343349, 46.04231439317976, 49.451548780713765, 51.377363613673616, 54.35278374808175, 49.186471530369346, 56.544249057769775, 53.05919245311192, 57.85539845057896, 41.44060584477016, 44.6555894442967, 26.609820127487183, 0.3562786265143326, 8.781133379255023, 12.957943950380598, 3.7124546425683156, 0.3553485449935709, 5.1371184928076605, 51.302125045231406, 49.53105354309082, 40.4613163130624, 25.500010422297887, 28.061383928571427, 50.941350255693706, 55.33590521131243, 56.068155016217915, 43.99492692947388, 2.057616731950215, 0.1436090868498598, 0.13012069277465343, 0.028174071672505567, 0.031050067794110094, 0.022219679218583872, 0.09940984499241624, 0.02792489156126976, 0.02704355090723506, 0.025651286954858472, 0.02885385349925075, 0.06255674894366946, 0.01805342670663127, 0.175461936209883, 0.11028216087392398, 0.18962758965790272, 0.19708067258553846, 0.14229804862822804, 0.10144121598984514, 0.10833888407796621, 0.11950695301805224, 0.09071184029536587, 0.1040891989001206, 0.13658418666039193, 0.17707406756068977, 6.07382425240108, 56.89476135798863, 63.954179763793945, 56.36617020198277, 45.02092572620937, 23.658075979777745, 29.028620072773524, 48.53604023797171, 42.8803003856114, 64.9951171875, 26.520653894969396, 0.21072903807674134, 0.10715473869017192, 1.8986265318734306, 5.543390955243792, 7.025834722178323, 7.777014459882464, 21.18534585407802, 50.06934438432966, 57.03632048198155, 56.52746568407331, 56.699440547398154, 54.32979563304356, 53.898750237056184, 51.2779974256243, 49.32500123977661, 49.687391485486714, 44.252694674900596, 41.5126690864563, 40.93878262383597, 40.23214735303606, 40.34460047313145, 40.01616954803467, 39.59231901168823, 41.68939651761736, 46.42810269764492, 47.89354378836495, 48.62179143088204, 49.33313410622733, 52.36500488008772, 53.26020383834839, 50.258644580841064, 44.66159963607788, 51.191454138074604, 50.22149951117379, 47.43230152130127, 44.89468043191092, 41.014542307172505, 41.17238106046404, 41.71057115282331, 41.39696420942034, 38.574032715388704, 37.128720555986675, 37.03499630519322, 38.18319654464722, 37.617147650037495, 39.39775902884347, 39.67299107142857, 38.47485065460205, 36.801783493586946, 36.10177680424282, 39.14524064745222, 38.48541191646031, 40.67579330716814, 44.48339571271624, 42.45385122299194, 46.3865316254752, 45.5104923248291, 48.005291666303364, 46.88714933395386, 49.07516833714077, 49.299734115600586, 49.59061002731323, 52.4168975012643, 51.0262051309858, 41.245111329214915, 26.12327078410557, 49.04880339758736, 47.57160595485142, 51.256419794900076, 52.06770188467843, 52.086531502859934, 51.217916352408274, 51.42855446679251, 47.559988566807334, 45.409343923841206, 43.69650527409145, 40.57140704563686, 41.73590081078665, 45.260801860264365, 46.80138077054705, 46.90167106900896, 44.68594264984131, 40.06047126225063, 38.368564060756135, 40.14638921192714, 39.28660522188459, 38.87693248476301, 40.899580887385774, 40.01294558388846, 44.888020583561485, 46.332460744040354, 44.791395459856304, 45.11559840611049, 49.04257433755057, 52.37734835488455, 49.68515069144112, 44.22112553460257, 48.454614298684255, 50.435319900512695, 49.957457542419434, 40.36020612716675, 42.6593268258231, 50.3640661239624, 54.04335267203194, 50.87788193566458, 45.40746096202305, 46.20871332713536, 51.376258850097656, 53.56262765611921, 51.77085747037615, 51.2254238809858, 52.50468104226248, 51.96559463228498, 53.62845836366926, 49.555316652570454, 50.11941657747541, 52.94389057159424, 57.38894503457205, 49.792684486934114, 59.4943881716047, 55.253829615456716, 58.348255021231516, 44.613865511757986, 48.19926452636719, 28.453142472675868, 1.7209694534540176, 14.336536901337759, 23.20468865122114, 4.445701513971601, 0.31541043519973755, 6.724614245550973, 57.03286027908325, 56.19678354263306, 54.66352455956595, 25.590005227497645, 28.819001606532506, 58.03907755443028, 62.02800709860665, 61.82628699711391, 52.59724841799055, 3.4221052740301405, 0.35627585809145657, 0.19168580350066933, 0.09973909053951502, 0.13565646644149507, 0.14211511558720044, 0.2676417055938925, 0.1131189800798893, 0.18260773776897363, 0.1286479053752763, 0.17859207253370965, 0.19285726706896508, 0.11396870948374271], [0.07345829611378056, 0.02715647270503853, 0.050912575729723485, 0.013476218612465476, 0.0591474836692214, 0.10620060988834926, 0.0389126228567745, 0.02716317493468523, 0.01973702645461474, 0.03487471185092415, 0.07515635713934898, 0.047263814735093286, 7.63070103100368, 47.32598713466099, 45.11604656491961, 45.883902413504465, 33.70684044701712, 26.456723519733973, 37.92254877090454, 36.170279094151084, 39.19276979991368, 55.67066594532558, 14.643427542277745, 0.11101151138011899, 0.07842063305101224, 1.1545353680849075, 2.4892149439879825, 1.9193382433482578, 6.907013143811907, 34.51557602201189, 54.617906161717, 49.11305686405727, 51.72611454554966, 49.65667002541678, 49.11331047330584, 41.439372539520264, 40.22507756096976, 38.67968007496425, 37.8008371761867, 38.19006831305367, 36.124275071280344, 36.425066062382285, 34.36798933574131, 34.52708918707711, 35.64775024141584, 35.273711340767996, 35.97425651550293, 34.98816122327532, 36.650809560503276, 36.766865321568076, 40.98556137084961, 43.539753913879395, 45.312673636845176, 46.21896539415632, 46.87756429399763, 44.64797074454171, 46.94708449499947, 44.27626991271973, 44.17151192256382, 43.65543099812099, 36.40025404521397, 35.24655430657523, 35.084369455065044, 33.80690492902483, 35.48759078979492, 33.84713847296578, 33.92959969384329, 35.36002533776419, 34.286834376198904, 35.509039878845215, 35.60623822893415, 33.86721876689366, 32.49803454535348, 33.78778696060181, 35.02569191796439, 36.5593261037554, 37.49253518240792, 38.45186948776245, 42.474647181374685, 41.61163227898734, 42.25177328927176, 44.38829571860177, 46.42090088980538, 45.294038568224224, 46.009425095149446, 45.485412802015034, 47.32292297908238, 38.10828801563808, 21.24045375415257, 51.64592885971069, 46.66334090914045, 47.44378341947283, 47.14476769311087, 47.39209924425398, 46.48623480115618, 43.705690792628694, 41.614418506622314, 35.94219405310494, 36.92901195798601, 38.40725857870919, 42.11020026888166, 45.542891774858745, 43.19483143942696, 46.944249629974365, 42.32385390145438, 37.28609030587332, 35.47171763011387, 36.142448084695, 36.1653528213501, 35.94731140136719, 36.4699444770813, 36.02149731772286, 35.63580628803798, 37.03703907557896, 34.74635001591274, 41.32451186861311, 44.63768393652779, 48.50726079940796, 44.28895384924752, 40.166591099330354, 49.56607593808855, 45.74392747879028, 43.16135849271502, 34.96729230880737, 42.47475835255214, 47.80258839470999, 48.36748388835362, 50.08808020183018, 46.62428508486067, 48.170759541647776, 48.2740340914045, 48.66656562260219, 48.64962591443743, 47.49459906986782, 49.52902814320156, 49.39958667755127, 47.400662899017334, 46.5926707812718, 51.44196449007307, 49.47727101189749, 50.223632608141216, 46.56578125272478, 48.977278641292024, 48.32651036126273, 52.6045092855181, 43.034651143210276, 33.47930431365967, 23.940153735024587, 0.6854980907269886, 8.15610556943076, 1.0462937248604638, 1.0839424303599765, 0.053613789712211916, 1.089223495551518, 37.540929385593955, 46.225941385541645, 38.24357986450195, 36.336768354688374, 18.456293208258494, 30.952018669673375, 42.1459869657244, 52.5705360685076, 33.746538979666575, 1.5950817742518015, 0.13318212064249174, 0.06221750857574599, 0.04268050067392843, 0.007755926677158901, 0.04818052911598768, 0.029516561688589196, 0.022772985510528088, 0.010672624721857054, 0.011665276501194706, 0.03036637930199504, 0.036693572465862544, 0.0441172782198659, 0.051621950164969475, 0.025333110010251403, 0.03214483654924801, 0.06891125653471265, 0.06751805450767279, 0.047503754895712645, 0.04447876435837575, 0.044383460722331486, 0.08112476473408085, 0.036305392759719064, 0.051830575934478214, 0.04656380408310464, 9.512836013521467, 55.5067058290754, 50.78819458825247, 52.12323883601597, 38.39316415786743, 31.50049557004656, 37.70597342082432, 40.69313601085118, 42.24472434180123, 61.84989697592599, 15.74760399545942, 0.07527967409363814, 0.022113709012046456, 3.3769873636109486, 1.6133643303598677, 3.4013559988566806, 8.069442425455366, 36.7507837159293, 55.9289721761431, 51.86521053314209, 53.86613539287022, 51.377731868198936, 51.2710040637425, 44.07439347675869, 42.349892275674, 40.48546130316598, 40.388603414808, 39.89015007019043, 37.319768224443706, 37.12535762786865, 37.910771574292866, 37.271780490875244, 36.23141976765224, 36.931725229535786, 38.40383659090315, 36.69977004187447, 39.79172188895089, 38.076715401240754, 42.414517470768516, 46.11031641278948, 48.29356895174299, 47.75902666364397, 47.838555744716096, 45.86799103873116, 49.29238986968994, 47.975622858319966, 46.86704472133091, 44.56923028400966, 36.50769056592669, 36.70880617414202, 37.27418804168701, 36.49988079071045, 37.4931639943804, 36.456409386226106, 35.59286642074585, 37.06115974698748, 36.57905551365444, 38.13183198656355, 38.44716903141567, 36.00349453517369, 34.51599638802664, 34.56014176777431, 36.30165910720825, 36.987022468021934, 39.61088807242257, 41.03755126680647, 42.62218523025513, 43.49360397883824, 43.47914130347115, 44.97334793635777, 47.76134041377476, 46.486985206604004, 48.64642974308559, 47.78953620365688, 49.161159242902485, 39.32421929495675, 22.300889560154506, 53.04615068435669, 47.79932621547154, 49.865456444876536, 49.35802602767944, 49.41341706684658, 48.00859553473336, 45.55301877430507, 42.4179116657802, 38.975926944187705, 38.17921870095389, 39.725314480917795, 43.11547258922032, 46.826647894723074, 45.0342732157026, 49.144563470567974, 43.52095208849226, 39.051175934927805, 37.736375263759065, 38.21460935047695, 37.173053537096294, 38.94927365439278, 37.99988569532122, 38.20591715403965, 36.51020233971732, 39.123565741947715, 37.029993602207725, 42.19431516102382, 47.08168847220284, 50.63455949510847, 46.91815219606672, 41.103767599378315, 51.18909175055367, 48.00809873853411, 45.902141434805735, 36.45759057998657, 44.010591643197195, 49.48121411459786, 51.22164406095232, 49.183702673230854, 46.990795612335205, 50.48113284792219, 48.23817791257586, 50.90718943732125, 49.68462610244751, 49.089023045131135, 51.09270633969988, 51.97365454265049, 47.249671595437185, 48.05782699584961, 53.853149209703716, 51.01256581715175, 52.60485322134835, 48.579066957746235, 51.403242179325645, 52.16715839930943, 55.39456537791661, 49.08535439627511, 36.12977804456438, 26.47204950877598, 0.4682322091289929, 8.935375571250916, 5.794741605009351, 3.2864299714565277, 0.08151150255330972, 1.0339181146451404, 41.07320594787598, 51.21149621691023, 39.72350100108555, 30.393352236066544, 23.364203657422745, 35.49862452915737, 47.02601603099278, 56.594352517809185, 44.80260637828282, 3.2944117145878926, 0.07644610293209553, 0.07946949212678842, 0.09217649884521961, 0.036008001039070744, 0.031969777907111814, 0.018991055233137946, 0.059508979985756535, 0.09902381963495697, 0.032597494045538564, 0.03608154405706695, 0.045155131457639594, 0.032029960570590835, 0.21196621097624302, 0.18793226991380962, 0.25983179467064993, 0.1367877743073872, 0.19104622996279172, 0.14847393866096223, 0.11118784906076533, 0.09316515150879111, 0.11585803596036774, 0.11221405863761902, 0.13442031134452137, 0.1002233134848731, 12.308343836239406, 63.92820044926235, 55.57446118763515, 59.98083850315639, 43.02934619358608, 34.423265729631694, 49.422630378178184, 46.45238665172032, 48.12120498929705, 66.68268871307373, 18.06966938291277, 0.2563975118100643, 0.2390038908592292, 2.808039550270353, 5.639243091855731, 4.69422424691064, 8.934291652270726, 38.062277044568745, 58.41449914659773, 54.059416907174246, 57.13557897295271, 53.09884582247053, 52.88096073695591, 45.81605672836304, 44.55097041811262, 42.467459269932334, 41.39145776203701, 43.391600949423655, 38.21457460948399, 39.86436183112008, 39.217929227011545, 38.45637192044939, 39.797662598746165, 39.45285824366978, 39.85859482628958, 38.42869029726301, 42.27647066116333, 39.527499267033164, 44.28627184459141, 48.04477480479649, 50.49096802302769, 49.54114580154419, 50.476237842014854, 46.24014697756086, 50.74328143256051, 49.32340662819998, 49.05394159044538, 47.18812445231846, 38.581502028873985, 37.322689941951204, 39.2510130746024, 37.95596265792847, 39.13807705470494, 38.353531633104595, 36.77895171301705, 38.896797384534565, 37.823217323848176, 39.963505676814485, 40.08509220395769, 37.14970064163208, 36.34892075402396, 37.20221165248326, 40.03267151968819, 40.22171115875244, 41.7248010635376, 42.93603883470808, 46.472286292484824, 45.44412660598755, 44.44269663946969, 47.441865716661724, 49.986862318856375, 48.84892109462193, 49.338876792362754, 49.20620788846697, 50.208367415836875, 39.56824002947126, 26.3425281388419, 55.33355324608939, 49.262147835322786, 51.83037573950631, 52.171372481754844, 50.54149532318115, 51.074616704668315, 47.229504449026926, 45.6031847681318, 39.70205538613455, 40.5709866796221, 42.300056321280344, 46.5754531451634, 48.18785558428083, 46.696289266858784, 50.77907855170113, 47.14699459075928, 41.22309248788016, 39.73486130578177, 39.64111621039254, 39.865963390895296, 40.21985598972866, 39.402518544878276, 39.78732367924282, 38.36919982092721, 41.12162446975708, 38.966237681252615, 44.37613984516689, 49.20398793901716, 52.41418770381382, 47.62183100836617, 42.93185601915632, 53.37459897994995, 50.23798758643014, 48.71918085643223, 38.431799616132466, 46.61337988717215, 50.49993814740862, 51.42238794054304, 52.39141150883266, 49.497021266392295, 52.92737470354353, 52.07862445286342, 52.61805132457188, 54.46147789273943, 50.32218585695539, 54.43441118512835, 54.08374949863979, 50.23518746239798, 49.41568217958723, 54.82802316120693, 54.85329375948225, 54.75040830884661, 51.61837577819824, 54.08877304622105, 52.06513452529907, 56.440283162253245, 51.26924269539969, 39.73586532047817, 30.564517634255544, 1.4557429254055023, 13.130648374557495, 7.7857605048588345, 4.122491291591099, 0.15526832693389483, 1.811505458184651, 46.29097305025373, 55.52427087511335, 52.7862811088562, 47.13205943788801, 25.944281714303152, 40.930917263031006, 55.23857137135097, 63.30981077466692, 53.43946041379656, 6.164146491459437, 0.3545854916529996, 0.20590157354516642, 0.1825076809951237, 0.08898978627153806, 0.17241549039525644, 0.0884588665461966, 0.14176911701049122, 0.11888906545937061, 0.1345825083553791, 0.14773407764732838, 0.07868014555424452, 0.14965993644935743], [0.04797942490716066, 0.05871206774775471, 0.08837227190711669, 0.024380409524642994, 0.027680313613797938, 0.05041357768433435, 0.022504017621810948, 0.016406539095831767, 0.03118858054014189, 0.0128548052161932, 0.027854469804359332, 0.16530592260616167, 11.504697816712515, 50.111742292131694, 39.50294433321272, 40.122866085597444, 20.251766783850535, 19.545022078922816, 25.020648990358623, 25.100198916026525, 44.982700211661204, 51.60834605353219, 11.828195520809718, 0.14477048095847878, 0.17665644282741205, 3.203037257705416, 1.3704119899443217, 2.9448908354554857, 21.518843752997263, 46.317094802856445, 54.273417949676514, 50.70698056902204, 50.557455335344585, 46.27305712018694, 42.759162017277305, 34.72865642820086, 37.58794437135969, 33.79733725956508, 36.31078904015677, 35.698756967272075, 36.43700654166085, 33.780633790152415, 35.76824590138027, 37.68312079565865, 38.71882969992501, 38.43492977959769, 37.05362095151629, 36.402376719883506, 38.37737785066877, 33.2812945502145, 36.51676491328648, 39.24935245513916, 46.349928515298025, 47.45763117926461, 48.513121604919434, 47.857343673706055, 44.284739766802105, 44.70575196402413, 47.3793180329459, 44.27992466517857, 41.68241705213274, 34.13782678331648, 36.31482246943882, 34.94165693010603, 36.82540736879621, 33.200667653764995, 35.190332957676475, 34.586162771497456, 35.980555057525635, 35.499402727399556, 34.34803410938808, 34.84161329269409, 34.61227757590157, 33.4002685546875, 34.53745589937483, 35.67324318204607, 39.50922897883824, 37.87006902694702, 41.65162263597761, 41.94520487104143, 44.05985089710781, 43.57385914666312, 48.38759544917515, 47.23560149329049, 50.27031060627529, 46.82303135735648, 45.367349011557444, 37.283613273075645, 26.92648254122053, 49.45616238457816, 43.75701018742153, 44.99573850631714, 43.43120568139212, 44.155607495989116, 41.59845502035958, 40.529530252729145, 37.57313428606306, 37.47181218011038, 41.040181159973145, 42.63377135140555, 45.399119649614605, 43.75744444983346, 50.011507579258506, 46.94849845341274, 43.196686608450754, 37.842408248356406, 33.90051800864083, 35.90876279558454, 34.751884256090435, 36.62071691240583, 33.855709075927734, 36.56805998938424, 35.3547933442252, 36.11735119138445, 36.5449572290693, 43.63576412200928, 48.64979267120361, 46.776388100215364, 41.61051361901419, 47.25477157320295, 46.08863803318569, 45.39139672688076, 39.15838663918631, 36.35550764628819, 43.783135414123535, 47.81394175120762, 48.82682234900338, 47.9320889200483, 46.8971860068185, 48.39484589440482, 49.410533564431326, 49.347454343523296, 49.06165409088135, 50.45632430485317, 48.078258173806326, 48.65403454644339, 46.18741709845406, 50.820875440325054, 49.708976064409526, 49.21255506787981, 43.77790689468384, 44.81796189716884, 46.31610121045794, 51.48194442476545, 50.721867084503174, 49.65456819534302, 40.95058066504342, 34.26144218444824, 0.32557339700204985, 9.833511011941091, 3.097771397658757, 2.141903809138707, 0.11779840184109551, 0.184139842699681, 28.08423481668745, 53.82816348757063, 36.23610980170113, 34.821411405290874, 19.657515151160105, 25.647993155888148, 41.367601122174946, 48.03065606525966, 46.63495404379708, 5.009011081286839, 0.3398161455988884, 0.0153083301681493, 0.0014676978566317952, 0.0385906681684511, 0.06849206438554184, 0.050412956824792285, 0.0017725723342404567, 0.06200102197804621, 0.03903608230341758, 0.016593224435512508, 0.058879896599267206, 0.0310590007076306, 0.020963600637125115, 0.024439813569188118, 0.034108187803732495, 0.08233383949846029, 0.02279748741005148, 0.07437773142009974, 0.04732999225546207, 0.040659416267382245, 0.07146252784878016, 0.02719862330039697, 0.038322595945958576, 0.1094651979261211, 15.509881802967616, 58.79617759159633, 47.671972683497835, 46.023668902260916, 27.335608107703074, 23.96997366632734, 21.444339956556046, 25.591526882989065, 47.90704066412789, 56.5399238041469, 13.762920549937657, 0.2309232716049467, 0.18928359954484872, 2.3439871711390357, 4.72739885534559, 5.0284968699727735, 22.569684096745082, 49.392815658024375, 55.83131524494716, 52.507540225982666, 52.09364298411778, 48.78608158656529, 44.455265930720735, 36.242672375270296, 38.51593882696969, 35.993145193372456, 37.20299679892403, 36.08871766499111, 39.223828247615266, 35.97271054131644, 37.94218438012259, 37.86021300724575, 40.0311324937003, 39.57518822806222, 38.38346447263445, 37.88078662327358, 38.460189955575125, 35.28671836853027, 38.26632479258946, 41.018648692539756, 47.53612845284598, 49.62628902707781, 50.64995322908674, 48.7006812776838, 44.764231477464946, 47.38847575868879, 48.503098828451975, 46.45675359453474, 43.45608370644705, 34.57122761862618, 37.41674075807844, 36.20981434413365, 38.558169978005544, 34.65118401391165, 37.47268417903355, 36.74804612568447, 37.16891935893467, 37.0536869594029, 36.11489152908325, 35.79717820031302, 35.94264568601336, 34.90789910725185, 36.81335571834019, 38.255475180489675, 40.825818811144146, 40.06457417351859, 43.386473178863525, 43.84992844717843, 46.771555628095356, 47.23822791235787, 49.750203200748985, 48.84058673041207, 51.68386949811663, 48.09540285382952, 47.78073631014143, 38.026910713740754, 27.58969851902553, 52.51894221987043, 46.14120462962559, 46.434290068490164, 45.31229496002197, 47.50957243783133, 43.46941382544381, 42.225099154881065, 40.771956375667024, 39.11430379322597, 42.787427289145334, 44.488617283957346, 48.171298027038574, 46.63221992765154, 50.16700826372419, 49.319592067173545, 45.82889005116054, 39.40338706970215, 35.299506528036936, 37.79825244631086, 36.83798360824585, 38.18030609403338, 36.165109634399414, 37.978891713278635, 37.34696347372872, 37.26135471888951, 38.26746082305908, 45.98441852842058, 49.782421997615266, 49.86623464311872, 41.38634041377476, 48.28443554469517, 47.95439263752529, 48.058157035282676, 41.63613510131836, 37.460545676095144, 45.309279441833496, 50.59573990958077, 51.17183589935303, 49.29130595070975, 49.116371154785156, 49.13927241734096, 51.78533056804112, 50.728297642299104, 50.37311267852783, 51.874844210488455, 51.78533751623971, 49.02267469678606, 46.77954953057425, 51.62393781117031, 50.73487411226545, 51.075603348868235, 46.61742721285139, 47.29706525802612, 47.18517146791731, 52.08492299488613, 51.20991202763149, 53.15037713732038, 44.356104714529856, 36.36114610944475, 0.610160401889256, 5.145712545939854, 9.428574340684072, 4.240049600601196, 0.26903666502663065, 0.0897065567384873, 30.524683611733572, 56.8901755469186, 39.08439179829189, 35.19312265941075, 24.634254455566406, 31.84533814021519, 46.574546405247276, 52.08799409866333, 55.47866637366158, 10.300217168671743, 0.4911889487079212, 0.03896868681269033, 0.011653372452461293, 0.06644875795713492, 0.008834410591849258, 0.014133356029300817, 0.01848113107761102, 0.10101563204079866, 0.06110437187765326, 0.04293522271992905, 0.026276092178055217, 0.034563118392335515, 0.13602425956300326, 0.1352622647370611, 0.17534437323255198, 0.15782541329307215, 0.137632496122803, 0.11211924693946328, 0.0808258361316153, 0.1465656810573169, 0.10915701410600118, 0.14566968913589204, 0.13332033822579042, 0.21382857247122697, 19.42569371632167, 67.56966795240129, 51.94753973824637, 54.22160870688302, 30.389416081564768, 26.99281178201948, 30.09946428026472, 33.62670687266758, 56.61680562155587, 61.53831195831299, 15.631681987217494, 0.29452458449772423, 0.4242094542298998, 9.101078816822596, 6.073335272925241, 5.558839840548379, 27.559852531978063, 52.061028139931814, 56.41209432056972, 54.58572210584368, 54.90169491086687, 50.49991382871355, 47.002190658024375, 38.22259283065796, 41.51851599557059, 37.99504280090332, 40.73519345692226, 37.66244990485055, 39.95937497275216, 38.461982590811594, 39.417481490543906, 40.96055480412075, 43.00890111923218, 42.4407434463501, 40.61763341086251, 41.31385333197457, 41.62610190255301, 35.9950316292899, 40.9296144757952, 41.92162268502371, 50.69365392412458, 52.68522303444998, 51.22528839111328, 52.114167962755474, 45.82189321517944, 49.02349805831909, 52.33175080163138, 48.960755825042725, 47.684632301330566, 36.113203116825645, 38.73310129983084, 37.070161138262065, 40.43894311359951, 37.023708956582205, 38.36369684764317, 38.948974881853374, 40.328543186187744, 39.017664773123606, 36.856285163334434, 39.69667748042515, 38.55862855911255, 36.62501784733364, 38.55603688103812, 40.56052269254412, 43.56051860536848, 43.22630330494472, 45.941773959568565, 46.87559795379639, 49.46897486277989, 48.24954169137137, 51.51378107070923, 50.77966914858137, 53.50656958988735, 50.71574224744524, 49.04876170839582, 39.41475779669625, 30.555710792541504, 53.281256880079, 47.8797481400626, 48.668368680136545, 46.68234075818743, 49.35403776168823, 46.71634871619088, 44.36540140424456, 41.878054005759104, 41.16192054748535, 44.658351353236604, 46.5629255431039, 50.341651235307964, 49.53442341940743, 50.141831466129844, 51.3932854107448, 48.87847178322928, 41.22807782036917, 36.522128922598704, 39.01126548222133, 37.462115968976704, 39.07344143731253, 36.67226907185146, 40.63956887381417, 39.21841212681362, 38.784288678850444, 41.175368785858154, 48.269708837781636, 53.16329383850098, 50.11585215159825, 42.63032157080514, 49.275550910404746, 49.93042210170201, 50.148703234536306, 44.69668109076363, 40.512559277670725, 47.77119295937674, 52.6613837650844, 51.864401068006245, 51.67937053952898, 51.21358415058681, 52.28386729104178, 52.551282610212056, 53.006615434374126, 53.034269264766145, 53.56593499864851, 52.849242210388184, 50.686855111803325, 48.941787242889404, 54.19193989889962, 53.3694121497018, 51.85200548171997, 49.151605469839915, 50.52718898228237, 49.753764152526855, 55.24077047620501, 54.6663316317967, 56.71312155042376, 46.77887208121163, 41.12980597359793, 1.1322160171610969, 17.13245814187186, 14.886022159031459, 5.239790720599038, 0.3386673858123166, 0.37299083545804024, 34.395674433027, 64.08677918570382, 51.65456199645996, 47.29626621518816, 29.834077835083008, 36.24745273590088, 54.18069771357945, 60.138041496276855, 65.66559055873326, 12.568305475371224, 0.6153356156178883, 0.12722329396222318, 0.14035138594252722, 0.14731163531541824, 0.15137019753456116, 0.14140566651310238, 0.10430614011628286, 0.15457385991300854, 0.17238791473209858, 0.1472313781934125, 0.1603700281786067, 0.11886558814772538], [0.0303401912429503, 0.05181218085012265, 0.021069750655442476, 0.051645502115466764, 0.0530971056515617, 0.021380156677748476, 0.024968088704294393, 0.07596056362880127, 0.024454117087381225, 0.09822527891291039, 0.046986734960228205, 0.06911509523966483, 16.50982138088771, 50.02030399867466, 42.07217625209263, 39.74219512939453, 20.386582681110927, 28.354248762130737, 69.15439919063023, 36.5655551637922, 40.67310435431344, 52.708502973829, 6.6176714812006265, 0.16539730770247324, 0.062181878701916764, 3.481037723166602, 1.1979017896311623, 3.9349615829331532, 30.793610164097377, 54.33561127526419, 50.60646445410592, 48.957882744925364, 45.91885880061558, 38.95635386875698, 37.162978649139404, 35.51800305502755, 37.68526431492397, 37.59824854987008, 36.53377757753645, 36.66027300698416, 35.67747810908726, 36.54178885051182, 39.34112426212856, 42.43750211170742, 44.06944983346121, 45.78009980065482, 44.793438230242046, 43.45980794089181, 42.868043763296946, 39.67513459069388, 38.43939052309309, 35.296341623578755, 37.117332458496094, 43.8046088218689, 46.31331845692226, 45.960752964019775, 46.83718831198556, 42.24089241027832, 46.159388065338135, 45.74924285071236, 45.61696999413626, 37.93251248768398, 33.73565462657383, 35.09970760345459, 34.377956526620046, 34.49701043537685, 35.64726734161377, 33.863623074122835, 36.34059681211199, 35.18997165134975, 36.212239265441895, 32.812975542885916, 33.98773527145386, 33.21660334723336, 35.47660568782261, 36.6061361176627, 37.83355276925223, 37.97065462384905, 38.99990865162441, 44.037102494921, 46.06113011496407, 47.01802212851388, 48.042044162750244, 46.31222758974348, 45.66360282897949, 43.49731779098511, 41.337105478559224, 38.164415563855854, 27.689563240323746, 50.07628216062273, 45.256678104400635, 42.94610677446638, 40.553077697753906, 41.60752936771938, 40.00275952475411, 40.14913722446987, 41.70019054412842, 40.630560534340994, 42.00791583742414, 46.82081140790667, 48.09155355181013, 51.839936460767476, 49.54602343695504, 43.39001676014492, 45.85896185466221, 38.031962054116384, 35.87029409408569, 36.02948774610247, 35.46205963407244, 35.760592460632324, 35.64734377179827, 34.896205289023264, 36.38783414023263, 36.449384757450645, 37.38030093056815, 45.614333152770996, 47.44012866701399, 46.0951589175633, 43.03548492704119, 50.50415917805263, 46.435019629342214, 45.912706170763286, 38.05050332205636, 38.445268699101035, 43.70519399642944, 48.42615795135498, 45.98334155763899, 45.06380305971418, 42.74984795706612, 47.33281373977661, 47.15300478254046, 49.63018349238804, 44.74227169581822, 45.37208768299648, 40.36384003502982, 44.99936894008091, 49.269735268184114, 52.62635442188808, 46.187833990369526, 47.11201041085379, 39.91908584322248, 47.54309402193342, 43.121653011866975, 52.15767410823277, 47.479493686131065, 56.12214599336897, 42.62513126645769, 49.46199887139456, 2.823062858411244, 8.85561111995152, 7.874344825744629, 6.022369367735727, 0.835153657410826, 0.11174741653459412, 20.10426868711199, 50.76129811150687, 35.97256115504673, 31.77929551260812, 16.48940757342747, 19.092475482395717, 30.66617325374058, 47.20332016263689, 46.52928236552647, 14.93796341759818, 0.43567647891385214, 0.12758542810167584, 0.06978775414505176, 0.04523428935291512, 0.024857268668711185, 0.013403602642938495, 0.035601802835507054, 0.055120588679398806, 0.012445304243426238, 0.053756655260388336, 0.015885683741154413, 0.02020515115665538, 0.02842499052972666, 0.06680455457951341, 0.013882111475270773, 0.027743001767833318, 0.050232744709189446, 0.018238600609557967, 0.03469945643363254, 0.06002817462597575, 0.039775163001779995, 0.06901640232120242, 0.021699363299246346, 0.1249799621956689, 22.456185272761754, 58.29946477072579, 47.683009896959575, 47.83129140308925, 25.823772157941544, 24.159720284598215, 54.19373600823538, 36.17783178601946, 45.49195453098842, 57.882218497140066, 7.501287358147757, 0.31899733415671755, 0.13124266399868897, 5.806146638734, 3.4474164758409773, 6.273717411926814, 35.18375996180943, 55.448372227805, 53.034217153276714, 51.05285494668143, 48.018823283059255, 40.784331117357524, 38.4770428112575, 37.1903406551906, 39.0927609034947, 39.2191937991551, 38.550460951668875, 38.87406982694353, 38.40292637688773, 38.100040503910606, 40.28473826817104, 43.34365490504673, 47.21574354171753, 46.07584639957973, 46.160492828914094, 43.752076966421946, 44.779031140463694, 40.67170081819807, 39.54073905944824, 36.60543782370431, 37.766982078552246, 44.77976417541504, 47.220336300986155, 48.26751320702689, 48.0772055217198, 44.399166175297324, 48.27871022905622, 48.45917926515852, 46.546163014003206, 39.27003376824515, 35.57209825515747, 35.79428080150059, 36.364696638924734, 34.97440031596592, 36.90078142711094, 36.78877993992397, 37.37744869504656, 35.7692950793675, 37.301932198660715, 34.59716871806553, 36.85294655391148, 35.58828755787441, 37.228924001966206, 36.90797281265259, 38.843886852264404, 40.002412114824565, 42.19378014973232, 45.07542739595686, 46.62055390221732, 49.63957050868443, 50.38994121551514, 46.88810818535941, 47.84565332957676, 43.68638174874442, 41.14277826036726, 38.54934923989432, 29.92461633682251, 51.58783149719238, 47.153845514569966, 44.89004945755005, 42.69860846655709, 42.76627697263445, 41.44368389674595, 41.99521105630057, 42.76179885864258, 43.642173835209434, 43.96325356619698, 47.00107547215053, 48.88836254392351, 51.3912113734654, 52.734325953892295, 46.599921226501465, 46.44496944972447, 39.407423973083496, 35.948388372148784, 37.997901984623496, 38.29843589237758, 36.47720187050955, 37.25540706089565, 36.78196723120553, 37.77594872883388, 36.87169279370989, 40.164499691554475, 46.194563320704866, 49.25525869641985, 46.162698881966726, 43.29993683951241, 51.496549538203645, 47.66900927679879, 48.471147537231445, 39.0771552494594, 40.21230329786028, 45.99827323641096, 50.385171277182444, 47.99646397999355, 47.19587516784668, 45.14834526606968, 49.081751755305696, 49.29468624932425, 51.31949206760952, 46.0077714238848, 46.908876350947786, 42.656988756997244, 45.429518018450054, 51.054772649492534, 54.82454211371285, 48.22335045678275, 47.922455242701936, 42.55510037285941, 49.01559100832258, 46.1402006149292, 54.3276104245867, 49.53719227654593, 58.82950810023716, 46.58924879346575, 52.87769160951887, 4.2545956543513705, 6.607084163597651, 11.801941752433777, 2.952322150979723, 0.7613323586327689, 0.01535728307706969, 21.507122141974314, 57.05800233568464, 41.040695326668875, 35.21393946238926, 20.70864037105015, 22.873435020446777, 35.10583244051252, 51.95740965434483, 54.286084515707834, 21.0171160697937, 0.3687207060200827, 0.11482469498046807, 0.03075938339212111, 0.040278059230851274, 0.02955521104325141, 0.039124868610607724, 0.016771590935864618, 0.026974949320512157, 0.029976713604160717, 0.014855560713580676, 0.01291648659389466, 0.022296871058642864, 0.09118628555110522, 0.13600678050092288, 0.17714629082807473, 0.15004077101392405, 0.1732912076903241, 0.09478172047861985, 0.12380661230002131, 0.15173343090074404, 0.1272560264915228, 0.12053554425282137, 0.11822882374482495, 0.21074621858341352, 28.36522170475551, 66.4349090031215, 54.27023220062256, 54.603273255484446, 27.98905144418989, 37.20375762666975, 75.10694871629987, 48.18945366995675, 49.47116354533604, 63.35167367117745, 8.73149197442191, 0.2950275417949472, 0.292879652764116, 8.975259099687849, 3.836685827800206, 8.419458797999791, 36.8719915662493, 58.008442946842735, 54.719440187726704, 53.250768184661865, 48.46586690630232, 42.14036239896502, 40.27002198355538, 39.835787364414756, 42.08402293069022, 41.91592516217913, 40.741026469639365, 40.541158063071116, 40.90179736273629, 41.60022333690098, 41.80030713762556, 45.62401894160679, 49.26107433864048, 48.48382452556065, 48.083695139203755, 46.345624106270925, 46.790736130305696, 44.164198943546836, 42.90545286451067, 38.5939427784511, 41.13929026467459, 47.46731696810041, 49.34857300349644, 48.83751562663487, 50.44022880281721, 44.01164429528372, 47.70473343985421, 49.16833325794765, 48.5641769681658, 40.64965418406895, 38.08801664624895, 37.11565446853638, 36.642763546534944, 37.68633781160627, 38.35735314232962, 38.14529412133353, 38.930197375161306, 37.25091505050659, 39.00220850535801, 35.6342568397522, 37.40441117967878, 36.685821533203125, 40.90346840449742, 39.631569385528564, 42.03342267445156, 42.3010116985866, 43.197638511657715, 46.76088319505964, 49.59277786527361, 50.428517614092144, 53.014942850385395, 49.92972033364432, 49.296492780957905, 45.30922385624477, 41.80609498705183, 38.84972333908081, 32.80975157873971, 52.88393109185355, 48.38142892292568, 48.33162423542568, 45.48532942363194, 45.35062122344971, 43.96387542997088, 43.453700474330354, 45.18273190089634, 44.22253254481724, 46.86695786884853, 49.11122601372855, 51.23951482772827, 50.88364894049508, 54.00731584003994, 49.88611691338675, 49.166481563023154, 41.710897718157085, 37.82188674381801, 40.46782330104283, 40.25153630120413, 38.93508890696934, 39.41816241400582, 37.91641698564802, 39.27472032819475, 38.41884469985962, 41.86886848722185, 48.04757840292794, 50.91990464074271, 48.73433140345982, 44.666206291743684, 53.29583420072283, 50.31734643663679, 50.57647950308663, 41.10858270100185, 42.923017910548616, 48.58718245370047, 52.3411934035165, 49.1894279888698, 48.455712114061626, 48.397854464394705, 51.539888926914756, 51.608679567064556, 51.899489470890586, 47.56222588675362, 47.448977197919575, 42.84827961240496, 46.696674891880576, 51.82645000730242, 57.09503970827375, 49.802693367004395, 51.89498356410435, 44.11917461667742, 50.92644984381539, 47.37176881517683, 57.612843785967144, 51.73330593109131, 62.61896528516497, 49.853046962193076, 56.55496317999703, 5.128646467413221, 14.852630853652954, 16.04418785231454, 7.594742366245814, 1.576829833643777, 0.21799437036471708, 25.005852801459177, 61.239025252205984, 49.99012449809483, 42.052130699157715, 24.89632487297058, 27.276894092559814, 43.688799721854075, 56.476573603493826, 64.46052973611015, 26.70727903502328, 0.49575261239494595, 0.2084976892386164, 0.18616597540676594, 0.08152568393519946, 0.11578816042414733, 0.0899366411779608, 0.19271329550870828, 0.25016533051218304, 0.1060305011591741, 0.10520648823252746, 0.09387537411281041, 0.11882203977022852], [0.019463096778573732, 0.05488200219614165, 0.0012946240354462393, 0.04779373022860714, 0.012891503782676799, 0.0614264045975038, 0.02359108330814966, 0.018054154435438768, 0.06392423449350254, 0.055694256110915115, 0.0020288712320117547, 0.19413097229387077, 22.2719555241721, 51.37390341077532, 41.92111546652657, 33.47821692058018, 20.247017690113612, 37.74402870450701, 38.1468574660165, 28.502917630331858, 44.37978070122855, 47.902020590645925, 4.401326409408024, 0.24880516635520117, 0.5285933816007206, 1.5413206304822649, 5.59605656351362, 8.850089039121356, 47.2781765801566, 50.55291468756539, 50.58729437419346, 47.37693132672991, 40.281465666634695, 37.233304841177805, 37.43492071969168, 41.424555506025044, 44.22085108075823, 44.75516060420445, 43.79743480682373, 38.89882278442383, 35.68455137525286, 36.81280681065151, 42.21166481290545, 46.653182642800466, 49.18549530846732, 47.56193058831351, 48.04588999067034, 48.255204473223, 46.00147983006069, 44.448988233293804, 44.39765494210379, 41.95317792892456, 39.48517778941563, 39.17549657821655, 41.79876463753836, 44.0169666154044, 47.387833050319124, 45.312562465667725, 43.23127474103655, 48.07052830287388, 44.86814873559134, 38.689654214041575, 33.86975833347866, 33.490525654384065, 33.66054112570626, 36.33242573056902, 33.25042717797415, 34.85412352425711, 35.63821383884975, 36.788449900490896, 36.12990658623831, 34.51909875869751, 33.33787720543997, 34.22909484590803, 34.81000593730381, 33.80320501327515, 37.17714950016567, 39.32334034783499, 41.142833845955984, 47.180436270577566, 46.938607692718506, 48.471772875104634, 45.37873363494873, 43.13503176825387, 49.45482833044869, 48.84508916309902, 49.98437486376081, 42.65952484948294, 31.251767430986675, 48.71349375588553, 46.17721714292254, 40.734526429857524, 38.209519795009065, 38.30310855593, 39.06595822743007, 41.14078065327236, 41.59886496407645, 44.135249274117605, 48.664661816188264, 51.437576702662874, 48.58489997046334, 45.284324986594065, 40.819464683532715, 46.78906856264387, 45.80005155290876, 36.67703901018415, 34.47607551302229, 34.68465001242501, 35.133496693202424, 35.844193186078755, 36.11680575779506, 35.420683111463276, 36.461314814431326, 36.66589409964425, 37.1692841393607, 45.56553942816598, 47.04647500174386, 43.955805097307476, 44.62489925112043, 49.37885672705514, 45.79447562353951, 44.6411406653268, 35.907897744859966, 38.56101526532854, 41.51341949190412, 44.97535596575056, 44.029344831194194, 41.283475807734895, 37.5817847933088, 43.5712639944894, 47.58582544326782, 47.1983174596514, 42.464322158268516, 45.52608060836792, 46.03623471941267, 50.43849870136806, 48.93651703425816, 49.11816726412092, 42.92403582164219, 42.969588211604524, 43.30592271259853, 50.687025342668804, 48.47753293173653, 53.31643908364432, 47.170451709202354, 55.24635682787214, 46.89997918265206, 56.686106954302105, 13.097507204328265, 5.41939514023917, 39.06420380728585, 5.766985288688114, 0.41830668811287197, 0.10744441207498312, 11.741801619529724, 53.35372311728341, 40.22544928959438, 36.4596402985709, 25.40281902040754, 25.295658690588816, 35.84537785393851, 45.062802519117085, 48.38883917672293, 18.94592407771519, 0.6655643060803413, 0.06660299575222389, 0.04265131688277636, 0.13024409115314484, 0.0321259664903794, 0.024359531002119184, 0.01613112342809992, 0.06705152775560107, 0.06759178412279912, 0.025422771627615606, 0.03742127413196223, 0.0893902304981436, 0.02285751740315131, 0.06754206786198275, 0.044604225483323844, 0.009447647641146821, 0.029509701699550663, 0.02344633821797158, 0.026808282460219095, 0.04361734379615102, 0.04051026748493314, 0.08547972462006978, 0.013868055622359472, 0.48301694435732706, 30.6669271332877, 58.422461782182964, 47.49285854612078, 38.769593238830566, 23.77392155783517, 38.94237061909267, 51.13876942225865, 35.982792377471924, 46.24897813796997, 53.68623610905239, 4.981867943491254, 0.2003791398767914, 0.7514764474970954, 2.3310691671712056, 1.7257573051112038, 13.997189487729754, 50.565748010362896, 53.58845411028181, 53.107072489602224, 48.46004778998238, 42.07287802015032, 39.20299407414028, 40.00498989650181, 41.02910573141915, 46.01278107506888, 45.06031158992222, 45.64774356569563, 40.996532576424734, 37.38989291872297, 37.780930587223594, 42.8832221031189, 46.8007241657802, 50.985606806618826, 48.910402229854036, 50.445697035108296, 49.55601494652884, 48.228408745356965, 46.056134360177175, 46.26585183824812, 43.35881587437221, 41.46129410607474, 40.012299401419504, 43.9288113457816, 44.68988922664097, 49.075029373168945, 45.44057955060686, 42.809654576437815, 49.57624462672642, 46.73663050787789, 41.512495381491526, 36.7077430997576, 35.880129269191194, 35.1794798714774, 37.950258186885286, 34.9060126713344, 35.34839405332293, 35.61164045333862, 37.821990966796875, 38.30244847706386, 37.13909421648298, 35.762666497911724, 36.22774417059762, 36.472299916403635, 35.71987254279, 38.74490976333618, 39.81482812336513, 43.66783005850655, 49.087480545043945, 48.71295179639544, 49.097194126674104, 47.79234674998692, 45.828379358564106, 49.96207462038313, 50.33307021004813, 50.492243017469136, 41.55056456157139, 31.596773283822195, 49.95949683870588, 48.50756304604666, 42.13585649217878, 40.48719835281372, 40.38781132016863, 41.50299024581909, 42.317756857190815, 42.67658615112305, 45.03703512464251, 48.138103008270264, 53.572303022657124, 49.44402040754046, 48.44375426428658, 45.18759911400931, 48.05402980531965, 46.29489878245762, 38.293926511492046, 35.87424414498465, 35.88739708491734, 36.18870224271502, 37.14397880009243, 37.845187527792795, 37.087215491703574, 38.21630818503243, 37.36799567086356, 38.63722310747419, 47.82607678004673, 50.00371517453875, 44.115234988076345, 44.85431834629604, 51.22365209034511, 46.93979236057827, 45.228669915880474, 38.9335047176906, 39.86874961853027, 44.61476877757481, 47.848210266658235, 46.14254910605294, 42.907985482897075, 39.914319378989084, 44.9345109803336, 49.982342515672954, 49.15636845997402, 44.09158679417202, 46.0012401172093, 46.24229744502476, 52.39238773073469, 51.07175404684884, 51.31546906062535, 45.35214982713972, 45.71483537128994, 45.5610682623727, 51.19212116513933, 50.029378346034456, 54.038812024252756, 50.4838878086635, 55.96473455429077, 50.42251089641026, 61.121975898742676, 15.163864987237112, 4.3702558023588995, 35.90890175955636, 4.3039200476237705, 0.4641753296766962, 0.1343470567039081, 12.389330301965986, 57.88952105385916, 45.91883795601981, 42.495186056409565, 26.95843904359, 31.12552908488682, 41.762950147901265, 49.63842405591692, 57.698202405657085, 25.12981387547084, 0.5650621418442044, 0.07418977721993412, 0.03524963637547834, 0.035810581275394986, 0.027002623371247734, 0.03595554010410394, 0.02556717405760927, 0.030699489106025015, 0.05586976597883871, 0.012275409252781953, 0.02496928462226476, 0.03341167499976499, 0.09791043187890734, 0.20455530578536646, 0.11314273559089218, 0.14019639497356756, 0.1286443362810782, 0.1016372311860323, 0.12917785479554109, 0.10894547402858734, 0.11678738466330937, 0.13786570860871247, 0.0973343760041254, 0.6422573338661874, 35.38714763096401, 67.96105303083147, 53.73968512671334, 45.02660935265677, 27.3853155204228, 46.749033042362754, 43.309938771384104, 37.92568588256836, 52.41648060934884, 56.77178519112723, 6.7994124719074795, 0.41245426929422785, 1.6391543064798628, 4.890668060098376, 9.853438445499965, 15.486263138907296, 50.01594052995954, 54.29924440383911, 54.63800730024065, 50.85774605614798, 43.78465012141636, 40.12243182318551, 43.16431842531477, 45.67070041384016, 49.05272218159267, 48.87718636648995, 47.855929715292795, 44.473008155822754, 38.98263890402657, 40.61915506635393, 45.731511047908235, 50.81373964037214, 53.39340080533709, 50.121459347861155, 51.62497309276036, 52.85405731201172, 51.34348767144339, 48.86511387143816, 48.49559824807303, 46.50779506138393, 43.86919927597046, 43.01206949778965, 46.790864671979634, 48.3299948828561, 51.89135660443987, 47.585929666246685, 43.364530767713276, 52.97586965560913, 48.22491380146572, 42.8307979447501, 37.99465370178223, 36.65166418892996, 35.911601134708945, 40.80260140555245, 36.731380871364046, 37.84819262368338, 37.03180708203997, 39.764974798474995, 39.545911993299214, 39.09873982838222, 37.75841842378889, 38.96893358230591, 38.145575523376465, 38.52002089364188, 41.53328091757638, 41.847054617745535, 44.683615003313335, 50.44144473757063, 51.32399797439575, 51.10366364887783, 47.96430424281529, 48.30057273592268, 52.46286678314209, 52.894718170166016, 52.02086407797677, 44.688117436000276, 34.24373122623989, 54.01009859357561, 50.16639334814889, 44.400865009852815, 43.0367807660784, 42.854793548583984, 43.94270426886422, 45.4849021094186, 46.05608572278704, 48.07876886640276, 49.06308889389038, 54.44191871370588, 49.5426744052342, 50.395023822784424, 46.91412918908255, 48.59310231889997, 49.97627673830305, 39.447004386356895, 37.15969215120588, 39.34830869947161, 39.00931303841727, 39.99376508167812, 38.899670464651926, 40.4898282459804, 41.027719565800254, 40.09793594905308, 41.143785749162944, 50.95859221049717, 52.560516766139436, 44.565467834472656, 46.228005000523154, 53.782531193324495, 49.004633699144634, 48.24670682634626, 40.23794909885952, 41.481141635349815, 46.156386443546836, 49.798079763139995, 46.30888203212193, 45.95771312713623, 41.29448870250157, 47.491816316332134, 52.49885845184326, 50.82679877962385, 45.36535487856184, 46.77274029595511, 47.66592427662441, 53.78129093987601, 53.179139205387656, 53.94228417532784, 46.40683773585728, 47.59131799425398, 48.00129992621285, 55.49119050162179, 53.4610276222229, 58.45696653638567, 52.53798375810896, 60.06493949890137, 53.46485260554722, 65.85357407161167, 18.086812325886317, 8.177169033459254, 51.6920405796596, 12.16551058632987, 1.1262416520289011, 0.28561123992715565, 14.927820784705025, 62.77839865003313, 54.977405956813264, 49.470798764910015, 35.67474399294172, 37.257168429238455, 49.55230113438198, 58.74385070800781, 65.85613100869315, 32.693025316510884, 1.1739390811749866, 0.17205353267490864, 0.10108695964195899, 0.19959551335445472, 0.12541064194270543, 0.1164356456803424, 0.14669479270066532, 0.17857611339007104, 0.14919348433613777, 0.12280223119471755, 0.10943796831582274, 0.2167640913810049], [0.05848558632923024, 0.058618680973138125, 0.04131385990019355, 0.07969775130706173, 0.040919118760419745, 0.12538267272923673, 0.041510896291583776, 0.07042985183319875, 0.03594894474372268, 0.09350993550781693, 0.0393532567125346, 0.638296154992921, 35.87371955599104, 47.55905055999756, 39.790999276297434, 39.42235565185547, 20.092673880713328, 35.74642855780465, 36.13161931719099, 30.042919840131486, 51.66527959278652, 42.03111239842006, 2.785189313547952, 0.2762333702828203, 0.6436465936047691, 5.547907284327915, 2.732003458908626, 18.833500487463816, 55.33998032978603, 50.828216212136404, 50.02687004634312, 40.79694209780012, 38.859006132398335, 39.08326966421944, 43.76065451758248, 47.34754044669015, 49.58475269590105, 49.05614069529942, 47.973399434770855, 41.05227797372, 37.5143004144941, 36.681360789707725, 41.27535683768136, 45.0231283051627, 48.761682987213135, 49.72676345280239, 45.97484391076224, 45.01887600762503, 47.11279903139387, 46.73857947758266, 47.707988670894075, 46.02897037778582, 45.59241853441511, 43.187191895076204, 40.2428788457598, 43.50907414300101, 45.47541434424264, 44.67523200171334, 44.560301848820274, 43.60658516202654, 47.425454071589876, 40.50946732929775, 33.65287031446184, 34.44083077566964, 34.12722383226667, 35.122546332223074, 35.59230709075928, 34.2802266393389, 35.29577187129429, 37.72306598935808, 37.844878332955496, 33.73884732382638, 34.54974726268223, 33.42414951324463, 34.10054969787598, 33.09245988300869, 35.70430857794625, 38.81874132156372, 44.705550466264995, 47.32131099700928, 48.13557733808245, 45.33047144753592, 45.73765325546265, 47.874151366097585, 47.91828284944807, 47.283759457724436, 46.37819378716605, 46.60245731898716, 34.557546615600586, 46.37066541399275, 47.23316962378365, 40.86181395394461, 37.963831492832725, 37.20266675949097, 41.957725524902344, 42.55836950029646, 45.03417246682303, 49.97083977290562, 46.273877007620676, 44.03568853650774, 44.368924140930176, 43.65111269269671, 48.17365346636091, 48.92199182510376, 43.56752586364746, 34.515947750636506, 35.43858514513288, 35.569221700940815, 35.98860454559326, 37.99256576810564, 37.01276206970215, 37.07446902138846, 34.761076722826274, 35.26977866036551, 36.15878677368164, 43.0718344279698, 49.607598372868125, 45.016006401606965, 44.98520851135254, 47.141015665871755, 44.73011929648263, 42.98091377530779, 41.06309979302542, 36.509986945560996, 39.70227425439017, 39.73843962805611, 39.41198199135916, 35.5781501361302, 35.38431624003819, 42.59904772894723, 47.81701980318342, 46.64377130780901, 47.32264157703945, 48.1467604637146, 48.424816949026926, 47.80465200969151, 47.463262694222585, 45.265759399959016, 39.82263789858137, 40.72950635637556, 47.26934194564819, 48.84278930936541, 47.81275708334786, 46.68994556154524, 50.19423825400216, 53.66333832059588, 53.613394669124055, 54.959142616816926, 31.635096073150635, 1.4621452561446597, 9.688664521489825, 5.0397360154560635, 0.4739669699754034, 0.04153810215315648, 4.931463973862784, 51.03582143783569, 41.05315344674246, 36.86410188674927, 24.71534514427185, 14.970062358038765, 29.811464922768728, 42.64493710654122, 47.93526772090367, 24.854317801339285, 0.3301742172666958, 0.024608368453170573, 0.018201053874301057, 0.06057329608925751, 0.04292188272146242, 0.04994164640083909, 0.034848785027861595, 0.01842053959678326, 0.04138322314247489, 0.009510837062927229, 0.04680136937115874, 0.03703382385096379, 0.0587400844586747, 0.044999997996326, 0.019749969510095458, 0.06595624331384897, 0.024805655902517692, 0.021785281099645153, 0.02014318903508995, 0.09995876625180244, 0.03608150673764093, 0.05552371311932802, 0.0562503121660224, 1.3877803151096617, 41.48525844301496, 54.10939529963902, 44.85281753540039, 42.5591025352478, 26.246222632271902, 37.47326782771519, 35.059467111315044, 31.596359866006033, 54.82372917447771, 47.65422003609793, 3.3458205674375807, 0.2967603845255715, 1.6023525212492262, 3.349974287407739, 3.255148312875203, 21.951365641185216, 57.24078859601702, 52.93199872970581, 52.13109377452305, 42.701460702078684, 41.51756409236363, 40.65857914515904, 45.477686405181885, 49.650979450770784, 53.360316957746235, 50.652562277657644, 49.189678124019075, 42.54791246141706, 38.54003865378243, 37.69550248554775, 42.16995825086321, 46.13913754054478, 49.61446666717529, 51.007799352918354, 48.60980231421334, 48.2875657081604, 49.138389996119905, 47.964731557028635, 50.22138139179775, 47.8007401738848, 47.13645764759609, 44.981654507773264, 42.75174134118216, 44.807081018175396, 48.13497979300362, 46.30155863080706, 45.37313686098371, 44.028959206172395, 48.519597326006206, 42.685955796922954, 34.18817343030657, 36.224905831473215, 35.53143392290388, 36.717317717415945, 37.22156238555908, 37.65125635692051, 36.56548220770699, 39.189160210745676, 36.829593658447266, 35.84235191345215, 37.18208966936384, 35.43866504941668, 36.75771106992449, 36.34977190835135, 37.022663252694265, 39.641852719443186, 46.38497870309012, 49.15847723824637, 49.14227751323155, 47.41223512377058, 48.30495357513428, 48.79013933454241, 50.06034299305507, 49.54627357210432, 49.20407131740025, 48.04241936547415, 35.274850845336914, 47.61539002827236, 49.535635880061555, 42.589434896196636, 40.07997138159615, 40.22641508919852, 44.48977415902274, 43.59154231207711, 47.34191240583147, 52.49425179617745, 49.195903709956575, 47.2256030355181, 46.79525940758841, 46.338540417807444, 50.07340213230678, 50.709176199776785, 46.02300534929548, 36.45711462838309, 37.77225228718349, 36.44422919409615, 37.800312587193076, 37.667285851069856, 39.01249878747122, 37.32532678331648, 36.24480547223772, 36.136333669934956, 38.224732875823975, 43.33850976399013, 50.80809422901699, 47.380322047642295, 45.54312106541225, 49.531956808907644, 47.03573308672224, 46.85673359462193, 42.77196059908186, 39.189629214150564, 41.57988248552595, 43.05627046312605, 41.12247562408447, 39.186895098005024, 37.80055577414376, 43.99993658065796, 49.35263075147356, 48.926258019038606, 48.33235032217843, 50.793600286756245, 50.48157058443342, 49.58780295508248, 49.60399573189871, 47.07000160217285, 41.91193689618792, 42.417536463056294, 49.241515159606934, 50.787124565669465, 50.103227274758474, 50.112332889011924, 51.91436208997454, 55.97321135657174, 55.913929326193674, 58.0960944720677, 35.11020285742623, 1.2542647080762046, 10.82183493886675, 9.63633850642613, 0.7241432656134877, 0.08639613366020577, 5.1687896847724915, 54.72000994001116, 49.0650691304888, 37.55320337840489, 25.405751160212926, 18.48665509905134, 35.50701795305525, 50.3539217540196, 57.68229103088379, 32.1194098336356, 0.15435230465871946, 0.027140832472858683, 0.010609510787097471, 0.026248087341498052, 0.00235468169557862, 0.020440724944429736, 0.04862028766157372, 0.09925557327057634, 0.08225884780819927, 0.02247011461960418, 0.019047526310064962, 0.021699504095262716, 0.21153688829924377, 0.18986442552081176, 0.12195672227868012, 0.19958566102598393, 0.09147072743092265, 0.2780536897480488, 0.1445371327655656, 0.1754607284175498, 0.10104718391916581, 0.1453654883163316, 0.15886389756841318, 1.541246045913015, 48.17338943481445, 62.22774696350098, 50.589201654706685, 50.37196275166103, 27.09888471875872, 42.74966730390276, 41.78881481715611, 40.6563036101205, 62.03075163705008, 52.92336906705584, 4.022894075938633, 0.3716604182762759, 1.7317299331937517, 16.286252668925695, 7.982977305139814, 21.30745870726449, 58.90839099884033, 54.45012106214251, 54.54629455293928, 43.928474358149934, 43.18174450738089, 42.72672087805611, 47.463933195386616, 51.899583271571565, 55.06727743148804, 53.490960461752756, 51.113213947841096, 45.17341089248657, 40.32608004978725, 39.918728010995046, 45.33467163358416, 48.29959651402065, 52.11986895969936, 53.75941801071167, 51.045083386557444, 51.11149774278913, 52.451680183410645, 49.09520346777779, 51.53873552594866, 49.34559570040022, 50.97113023485456, 46.900385652269634, 43.63096291678292, 46.92710147585188, 49.31812947137015, 47.786322661808555, 45.92687007359096, 44.65677063805716, 50.35429000854492, 46.113554273332866, 36.23078053338187, 38.09592717034476, 37.127091203417095, 38.59570762089321, 40.083626134055, 39.04020472935268, 38.37768357140677, 41.43800374439785, 39.05404206684658, 37.68743910108294, 40.21868174416678, 37.737431389944895, 37.9225036076137, 37.3130910055978, 39.957742146083284, 42.18281936645508, 49.27413695199149, 51.30261836733137, 52.03395101002285, 48.31316981996809, 49.4168564251491, 51.77388688496181, 50.76593950816563, 53.20758165631975, 50.11372947692871, 48.375807830265586, 37.45862797328404, 49.58323451450893, 50.17249386651175, 44.25959423610142, 40.75825105394636, 41.1681079183306, 46.163452761513845, 45.98345272881644, 49.3124805859157, 51.64907986777169, 49.135655879974365, 48.45073025567191, 49.34375442777361, 48.05853918620518, 51.47627122061593, 53.367588247571675, 47.38710001536778, 38.170245102473665, 39.569914545331685, 40.41941172736031, 39.79005084718977, 41.13546180725098, 41.60563250950405, 39.91253021785191, 37.18715143203735, 37.788931437901084, 40.8442245892116, 46.204457555498394, 53.35032197407314, 49.63138553074428, 46.35167946134295, 51.936193329947336, 49.47397756576538, 47.827306611197336, 45.099443844386506, 41.409033230372835, 44.99084002631051, 45.243000575474326, 44.09173618044172, 40.63833556856428, 38.63307155881609, 46.95591565540859, 51.51075513022286, 50.197740146092, 50.7474364553179, 53.67957278660366, 52.17553792681013, 52.286531925201416, 51.348327091761995, 49.39109945297241, 44.216619627816335, 45.11012669972011, 52.5270333971296, 53.45797388894217, 53.184979166303364, 52.483443873269216, 54.48722791671753, 57.98460367747715, 59.33942249843052, 60.12983567374093, 39.536101136888774, 2.662652403116226, 13.135648471968514, 13.635837997709002, 0.9052039842520441, 0.2140508605433362, 6.039043741566794, 60.44424860818045, 51.93155888148716, 48.882199491773335, 34.33084774017334, 24.833902256829397, 42.81055089405605, 56.29301609311785, 64.45977238246373, 40.570225851876394, 0.7675790605800492, 0.18359683826565742, 0.20585696665304049, 0.17317851659442696, 0.12852578264261993, 0.09628097074372427, 0.21330145932734013, 0.2467623416866575, 0.1479222354079996, 0.10956251341849566, 0.08768811183316366, 0.13066829767610344], [0.02299206580833665, 0.038779304296310456, 0.012298901831465108, 0.010407141110460674, 0.08961923606693745, 0.06174079022769417, 0.07104725084666695, 0.04466553790760892, 0.06316396993185792, 0.05064150098977344, 0.03231555935261505, 2.7708899208477566, 45.622469493321006, 48.79914419991629, 45.53582893099104, 27.99683690071106, 14.910879339490618, 46.802697454180034, 56.56042793818882, 32.579481329236714, 45.041422912052695, 39.848367077963694, 1.4817499241658618, 0.13714696360485895, 0.8502345596040998, 1.5758563258818217, 1.4710977928979057, 35.50647946766445, 55.18880837304251, 50.10746220179966, 47.85561357225691, 42.48239094870431, 42.19766419274466, 47.25682476588658, 49.404554639543804, 47.472583702632356, 50.05357544762747, 49.50984069279262, 48.61007676805769, 43.3726601600647, 35.35090930121285, 35.75680916649954, 40.89806965419224, 43.27396099908011, 47.171997683388845, 46.290691648210796, 43.68397767203194, 42.63129431860787, 43.79257801600865, 43.81246376037598, 44.43051644733974, 47.3960006577628, 46.81785842350551, 46.83214391980852, 45.75522524969918, 43.98114170346941, 45.82033681869507, 46.05463702338082, 43.56801571164812, 45.16466311046055, 45.975517886025564, 39.65657247815813, 32.56661326544625, 34.883952140808105, 33.96460471834455, 34.421559946877615, 33.89982666288103, 35.4494833946228, 34.21791866847447, 36.02401951381138, 34.46443380628313, 35.314306191035676, 35.803990909031455, 34.832215854099815, 34.75919028690883, 33.43275138310024, 34.670816149030415, 39.64734527042934, 43.208967549460276, 47.455793380737305, 47.41093233653477, 46.73949663979666, 47.60496425628662, 45.58528273446219, 45.249431133270264, 46.54156330653599, 45.598255021231516, 51.10054390771048, 36.0539801461356, 46.75090558188302, 47.700505461011616, 44.37496907370431, 37.73448882784162, 40.69662748064314, 44.879953724997385, 45.03331436429705, 44.83227171216692, 40.359636374882285, 43.53983729226248, 45.773471219199045, 46.84505367279053, 46.9795812198094, 43.68048620223999, 42.35463442121233, 36.52962255477905, 33.70732682091849, 35.71492542539324, 35.8354697227478, 34.79557452883039, 34.99658243996756, 35.49619265965053, 36.394375869206016, 36.25145489828927, 36.30415003640311, 35.48121581758772, 38.03153126580374, 47.789067200251985, 47.197997842516216, 46.26083871296474, 45.88733829770769, 47.494870049612864, 45.77514920915876, 43.70749385016305, 36.57714128494263, 36.1799509865897, 36.963391644614084, 35.673218863351, 35.664085456303184, 36.366635186331614, 39.34436559677124, 46.30509178979056, 47.877656732286724, 47.99476861953735, 47.6916777747018, 51.19575159890311, 48.192496980939595, 43.56970064980643, 38.07712187085833, 38.57069410596575, 41.79983466012137, 46.51078973497663, 47.7277250289917, 48.059348651341026, 47.83367116110665, 49.191394329071045, 50.38776295525687, 55.529350008283345, 53.40200614929199, 48.44104446683611, 2.734216025897435, 1.5794186890125275, 4.076384348528726, 2.6088281827313557, 0.021613516745024493, 1.6437663904258182, 42.30822392872402, 46.522487027304514, 45.456035818372456, 30.48919916152954, 23.184148039136613, 36.16023894718715, 46.12453590120588, 52.008471965789795, 32.896805558885845, 0.08087203079568488, 0.11802584677934647, 0.015126538762290562, 0.011493621560345803, 0.03177423429276262, 0.06265810171940497, 0.01885710054609392, 0.09405177286160843, 0.06123344959425075, 0.01729138777591288, 0.026790319941937923, 0.05317967997065612, 0.0628909274403538, 0.028505734500608275, 0.03159168801669564, 0.024878282898238728, 0.014861406292766333, 0.024923710817737237, 0.030221410295260803, 0.03910065848114235, 0.03591269740302648, 0.07590745469289166, 0.07143465363021408, 4.305681415966578, 52.408900124686106, 53.83683136531285, 49.94889388765608, 35.9513726234436, 19.443814618246897, 46.75725276129586, 52.75988490240914, 35.32102162497384, 52.05571624210903, 42.8117425101144, 1.907568212066378, 0.15610327784504208, 3.7023289459092275, 6.0308162059102735, 3.1564430722168515, 38.2888890675136, 57.2200516973223, 53.0656612260001, 49.29191044398716, 43.58147437231881, 42.72526523045131, 49.35790096010481, 50.59259932381766, 49.55039037976946, 51.17027255467006, 51.4983560698373, 49.53635154451643, 45.552984033312114, 37.57144587380545, 37.23835618155343, 42.24015590122768, 45.80334847314017, 46.81742416109358, 47.190399987357004, 45.163113662174766, 44.83602026530674, 45.46193831307547, 44.46673740659441, 46.35619579042707, 49.04213660103934, 48.87187099456787, 49.537216595241, 48.63167176927839, 45.268375396728516, 47.95232554844448, 46.18241786956787, 44.49356440135411, 46.289506980351035, 48.455076353890554, 41.2103008542742, 33.531617300851, 35.98510612760271, 34.908646038600374, 36.36001007897513, 34.803394726344514, 36.07773951121739, 35.7194938659668, 38.037002972194124, 36.03482048852103, 35.82856321334839, 36.382508346012656, 36.82889189038958, 35.65441356386457, 35.47705384663173, 36.57949672426496, 41.20405094964163, 45.98810107367379, 48.95169537408011, 48.129640102386475, 47.849214281354634, 51.06506640570504, 46.897026198250906, 46.99620131083897, 48.55143397194998, 47.73478439876011, 51.097649982997346, 37.641508034297395, 47.33841051374163, 48.17684268951416, 45.17548492976597, 39.754417010716026, 40.99532011577061, 46.707378591809956, 46.50334474018642, 47.76279258728027, 44.54248319353376, 44.22313356399536, 47.67271614074707, 48.71101324898856, 48.42665474755423, 45.73815352576119, 45.058060373578755, 38.42582416534424, 34.88029738834926, 36.69666419710432, 38.03702729088919, 37.212303910936626, 37.83269466672625, 37.69740629196167, 37.53598574229649, 37.21362059456961, 38.396589619772776, 37.06310871669224, 39.35714680807931, 50.13097143173218, 48.75582912990025, 46.20828948702131, 46.10072095053536, 49.22889723096575, 47.17581224441528, 46.301548208509175, 38.38564273289272, 38.59751762662615, 38.975715024130686, 38.78494528361729, 36.11428008760725, 37.93298149108887, 39.4659104347229, 46.51201261792864, 48.842236927577424, 50.445961066654746, 49.67905364717756, 52.065214429582866, 48.726841245378765, 46.63383190972464, 39.170747484479634, 40.34552805764334, 43.39128133228847, 47.45538343702044, 49.471090589250835, 50.32021951675415, 48.87510885511126, 50.87701688494001, 51.968227999550955, 57.81502594266619, 55.333963189806255, 54.70954247883388, 3.117114096879959, 0.25305336554135593, 11.161145874432155, 4.96852262531008, 0.09391982494188206, 1.5512620913130897, 44.99757630484444, 51.085765089307515, 43.09753928865705, 26.756163086209977, 27.212715319224767, 43.37325423104422, 52.20282350267683, 58.62919153485979, 42.798610414777485, 0.6981418036988803, 0.04507702529164297, 0.011952821830553668, 0.02245038451759943, 0.027917478566191027, 0.04457290091418794, 0.02688525038372193, 0.06634907437754528, 0.04703512129240802, 0.030143015751881257, 0.06875444030655281, 0.039169193910700936, 0.15745204261371068, 0.08983652333595923, 0.14821362548640796, 0.25754217324512346, 0.13606441526540689, 0.11598885751196317, 0.1772411907357829, 0.14895728629614624, 0.07335833433483328, 0.1889076911445175, 0.2325613365641662, 5.503814884594508, 62.866974285670686, 60.20229843684605, 57.87417595727103, 37.73609038761684, 22.556961945125035, 52.5533253805978, 62.71771308353969, 41.57700940540859, 53.772841930389404, 48.63126877376011, 2.746939046042306, 0.3452481169785772, 1.1240540551287788, 3.3372766716139655, 3.391321280172893, 40.296070780072895, 58.853708675929475, 55.86975962775094, 51.08456652505057, 46.201768602643696, 45.46591963086809, 52.58175393513271, 52.286590984889436, 51.83716412952968, 52.59289189747402, 53.07847370420183, 52.678611823490684, 47.79656778063093, 38.591649872916086, 38.878332546779085, 44.512480872017996, 48.00553485325405, 50.518180642809185, 48.78875664302281, 44.60877595629011, 44.6698853628976, 47.47988278525216, 45.47963537488665, 47.34791217531477, 50.75216123035976, 51.33629281180245, 51.57899686268398, 50.525007247924805, 48.102962493896484, 49.54748603275844, 48.3873279435294, 45.294392926352366, 47.19634417125157, 50.33806249073574, 43.84745141438076, 35.18165118353707, 39.29509939466204, 37.547196660723, 36.961376667022705, 36.14438663210188, 38.79522514343262, 38.020101479121614, 40.03748662131173, 36.53982251031058, 39.51582281930106, 39.132938861846924, 39.50140183312552, 37.75626448222569, 36.519307953970774, 38.40812362943377, 42.713543619428364, 47.354863848005024, 50.01448835645403, 49.58690316336495, 49.58895288194929, 52.52891288484846, 48.016457421439036, 49.40366874422346, 51.40860966273716, 49.57533441271101, 54.74540213176182, 40.75448513031006, 49.03682470321655, 49.24740375791277, 47.2232198034014, 42.62655217306954, 44.636718136923655, 50.55891098294939, 47.71927601950509, 46.167774541037424, 44.977985858917236, 47.749511105673655, 48.726525102342876, 49.03372928074428, 51.20009422302246, 47.231637545994346, 47.57965196881975, 41.13779640197754, 37.559085028512136, 39.24359587260655, 39.55771350860596, 38.52463797160557, 39.32900660378592, 40.01846592766898, 38.806661878313335, 39.35582317624773, 41.20025028501238, 39.25839900970459, 44.178887435368125, 51.83322102682931, 52.00097138541085, 48.00886998857771, 47.54984767096383, 51.2080533845084, 49.20862586157662, 48.02336393083845, 40.735554763248985, 40.90269715445382, 41.284893240247456, 40.35175016948155, 39.44559390204293, 41.124945708683555, 41.672877175467356, 48.29941586085728, 50.5894969531468, 52.453712531498496, 52.00167662756783, 55.45100212097168, 51.79366840635027, 47.84768220356533, 41.68899352209908, 43.444886684417725, 46.63706977026803, 50.30580200467791, 51.557030132838655, 51.25246279580252, 51.90586791719709, 53.47098786490304, 54.92552375793457, 60.137054852076936, 57.66371849605015, 57.664844104221885, 4.027103815759931, 4.974491127899714, 12.489603229931422, 5.295614719390869, 0.3486940435000828, 2.2412165829113553, 51.10724197115217, 55.469803946358816, 57.95550809587751, 43.467680249895366, 36.09581872395107, 48.4023186819894, 60.544066429138184, 66.1009646824428, 51.92696612221854, 1.8321885083402907, 0.285852418414184, 0.08778336457908154, 0.15575440227985382, 0.14547608952437127, 0.17668557912111282, 0.11357344247932945, 0.14888825214334897, 0.15404541684048517, 0.12012839610023157, 0.15051193216017314, 0.21397130909774983], [0.024334618588909507, 0.05139900052121707, 0.03204822673329285, 0.02842549603831555, 0.059506672966693125, 0.04609251740787711, 0.07545759276087795, 0.009364131006545253, 0.06885088048875332, 0.031628722458013465, 0.021631299451525723, 3.120306577001299, 44.84465340205601, 47.881808280944824, 41.61082281385149, 28.400013072150095, 20.124500104359218, 38.44121095112392, 42.77473293031965, 28.658253295081003, 48.91254922321865, 38.72363090515137, 0.8117963650396892, 0.06272324108119522, 4.217863133975437, 4.437431854861123, 4.002892817769732, 32.6356714112418, 52.06128869737898, 49.26451022284371, 47.52285391943795, 46.61464098521641, 47.85678434371948, 47.46753583635603, 48.2382995060512, 48.855633054460796, 47.9780547278268, 44.05344465800694, 48.08089501517159, 47.295901434762136, 37.71717391695295, 34.88290296282087, 40.12281744820731, 41.686912536621094, 46.014125551496235, 47.72715527670724, 46.235887731824604, 43.93907036100115, 43.37141990661621, 42.849116870335166, 44.40166752679007, 43.27114003045218, 44.2575340952192, 46.80398634501866, 46.9067119870867, 45.86961691720145, 45.40366377149309, 43.179336956569124, 43.18653181621006, 47.05124494007656, 45.23250184740339, 35.85049172810146, 33.33607414790562, 36.40102529525757, 35.214867046901155, 35.076292174203054, 35.3686272076198, 35.091932569231304, 33.91501195090157, 35.144328934805735, 35.16546188082014, 35.81360026768276, 34.84813070297241, 35.34825161525181, 35.60003348759243, 35.97436421258109, 36.053056035723, 39.125657149723594, 42.64870997837612, 46.82272563661848, 46.51937770843506, 48.616135597229004, 46.63739633560181, 46.28050906317574, 41.5854549407959, 44.898175375802175, 46.66380296434675, 50.51815979821341, 34.844906738826204, 44.08172035217285, 49.54408488954817, 46.118174825395855, 41.15324224744524, 39.87528439930507, 44.38138573510306, 45.576034682137625, 41.953997816358296, 42.904761518750874, 45.54230465207781, 46.2819264956883, 46.90868180138724, 44.66386822291783, 43.03709690911429, 35.322855949401855, 35.80934797014509, 34.52223587036133, 34.85191747120449, 34.488429410117014, 36.642749650137766, 33.31840835298811, 36.07905966894967, 34.35667072023664, 36.29430443899972, 35.41882446834019, 35.80566542489188, 34.92956011635916, 40.894178662981304, 47.14771025521414, 47.34082153865269, 47.640160356249126, 48.527049268995015, 46.78301668167114, 45.5815862928118, 41.51553521837507, 35.77325207846505, 36.30726282937186, 36.33194283076695, 36.13719524656023, 35.321869305201936, 37.583042417253765, 40.936361176627024, 41.74452699933733, 42.84648697716849, 43.411691665649414, 44.49038907459804, 38.63336338315691, 37.8249682698931, 37.896096978868755, 38.84937245505196, 41.08815152304513, 44.47621822357178, 45.61208193642752, 46.704641001565115, 45.89123623711722, 49.78303691319057, 48.76377786908831, 53.164270060403005, 52.13680519376482, 62.844712257385254, 16.111875465938024, 0.17681199019508703, 7.937008023262024, 2.0216878141675676, 0.17798880061932973, 0.5320109182170459, 38.41846602303641, 48.97377674920218, 42.20930242538452, 38.06890215192522, 19.790635687964304, 32.43905823571341, 43.80447333199637, 51.52295616694859, 43.880667277744834, 1.5445168018341064, 0.16273683974785463, 0.061217198680554114, 0.03986043789024864, 0.09862792837832655, 0.03685364905478699, 0.029349465654896836, 0.04211200028657913, 0.04545017544712339, 0.04880893736013344, 0.017442014068365097, 0.08915134545947824, 0.015483948601675885, 0.05292289178552372, 0.028951660929513828, 0.06368548516184092, 0.01682139540623341, 0.08397800448749747, 0.04229963557528598, 0.03162143499191318, 0.006154597603849002, 0.07884007625813995, 0.056636985524424484, 4.341679164341517, 53.46274035317557, 52.466215814862935, 48.17010988507952, 33.081568581717356, 27.151913370404923, 44.57595614024571, 42.173401083265034, 31.90510654449463, 53.98944854736328, 42.055844511304585, 0.9227662618671144, 0.10257158069206135, 5.8962157028062006, 6.491511736597333, 8.093029822622027, 36.70206989560808, 55.31919131960188, 51.818626335689, 49.13853243419102, 48.70967919485909, 49.720398902893066, 50.45925644465855, 50.714057309286936, 50.45810999189104, 48.56204039709908, 45.4458532333374, 50.166125842503135, 48.241280283246724, 39.00486619131905, 38.047029222760884, 41.572837012154714, 44.527683530535015, 48.0438472202846, 48.415784290858674, 45.8193154335022, 43.771875858306885, 42.82829311915806, 44.45553691046578, 44.15194926943098, 42.69489118031093, 45.62283079964774, 47.366995402744834, 48.63207476479666, 45.798818247658865, 47.233173097882954, 43.43571506227766, 43.32540546144758, 48.18905067443848, 47.711469718388145, 38.32663515635899, 34.34966346195766, 37.67008597510201, 36.26345443725586, 35.656525816236226, 37.319792543138774, 37.71779925482613, 37.33970955439976, 37.006300245012554, 35.250959464481895, 36.10075889314924, 36.44781446456909, 37.28692756380354, 36.887645857674734, 37.05010516302926, 38.06319768088204, 39.33487435749599, 44.08213029588972, 48.69803053992135, 48.13596643720354, 49.358422074999126, 48.8137423651559, 47.2691057068961, 43.03987966264997, 45.99907922744751, 48.7573299407959, 51.47952992575509, 35.956698417663574, 45.15004062652588, 51.02754265921456, 48.29458686283657, 42.71421759469168, 41.870841775621685, 45.35987274987357, 47.28943961007254, 43.665954044886995, 43.19206953048706, 45.99131808962141, 48.862039293561665, 49.23293760844639, 45.83050203323364, 44.4127915927342, 37.5712582724435, 36.39876018251692, 36.70704133169991, 37.13033601215908, 35.8416987827846, 38.242878096444265, 35.01983806065151, 37.61270080293928, 37.85814939226423, 39.339310782296316, 36.4221373966762, 38.33649812425886, 36.350025517599924, 44.060771533421104, 48.65577507019043, 50.102893761226106, 48.09208161490304, 49.895767961229595, 50.015777247292654, 48.2665057182312, 45.15757247379848, 38.40170349393572, 38.77431453977312, 38.194615909031455, 38.237399441855295, 38.297285965510774, 39.83309146336147, 44.3252477645874, 43.45210586275373, 43.94685581752232, 47.171952520098, 47.03438861029488, 41.860294410160606, 40.1810815674918, 39.02414049421038, 41.447494983673096, 43.282257148197715, 47.25453186035156, 46.65721607208252, 49.19646651404244, 47.68593856266567, 52.05481992449079, 49.38930334363665, 56.1687718800136, 54.10346501214163, 64.75847543988908, 18.902433565684728, 0.5891678311995098, 11.116328256470815, 6.73671236208507, 0.17087064257689885, 0.513186728315694, 41.6487842968532, 53.29445150920323, 42.011612279074534, 38.11229712622506, 27.276690857751028, 37.479694911411826, 50.30185195377895, 54.996673311506, 53.8274165562221, 3.070395712341581, 0.18343146571091243, 0.008853924410816814, 0.02664886405026274, 0.058281367644667625, 0.054983680668686113, 0.012116183377137142, 0.052790133016450067, 0.05660898916955505, 0.06689108815044165, 0.0149825621130211, 0.03868557146883436, 0.07916847363646541, 0.21128363188888344, 0.09350300766527653, 0.09148947535348789, 0.08619090395846538, 0.1551465027566467, 0.14775481367749826, 0.17627681605517864, 0.10998763596372944, 0.2033944816461631, 0.16014380460338934, 5.924868771008082, 61.189067704336985, 59.396536690848215, 55.38811050142561, 40.429472718920024, 29.407972608293804, 46.985153675079346, 50.505882331303184, 38.08015128544399, 59.20350183759417, 47.04136112758091, 1.2329548001289368, 0.2197802881045001, 7.501266513551984, 8.17927346910749, 7.100270773683276, 40.25109509059361, 56.77561712265015, 54.096923283168245, 51.14446347100394, 50.89490849631173, 52.58317484174456, 50.818648542676655, 52.28102200371878, 51.829851150512695, 47.813448429107666, 44.953090463365825, 51.74611840929304, 52.398283277239116, 40.43328033174787, 40.60381691796439, 43.34642028808594, 46.260001455034526, 49.836635317121235, 51.227657726832796, 49.067167486463276, 45.228958266122, 44.54527289526803, 43.94015775408064, 45.07770640509469, 43.237538542066304, 46.54783405576433, 49.27829197474888, 49.796485151563374, 47.77773468835013, 48.74001850400652, 44.05982310431344, 46.176442418779644, 51.23627349308559, 48.96297924859183, 39.49950497491019, 35.87354237692696, 39.916000843048096, 37.66523265838623, 37.543607916150776, 41.0432140486581, 39.1884445462908, 37.739540168217246, 39.17615665708269, 37.56446293422154, 37.71832731791905, 38.66337612697056, 39.8411340032305, 40.587669304439, 39.181628363473074, 40.47996875217983, 41.36917488915579, 47.58170863560268, 49.96194955280849, 49.61347654887608, 51.72160169056484, 50.89471047265189, 49.737046786717, 45.764740807669504, 48.16901554380144, 50.530180181775776, 52.96032306126186, 39.746579442705425, 46.68418550491333, 53.59387023108346, 49.90869508470808, 44.23111704417637, 43.96329525538853, 48.986773354666575, 48.685457774571006, 44.85648618425642, 45.51112461090088, 47.34172827856881, 49.49975190843855, 51.800953592572895, 49.666150842394146, 46.13510063716343, 40.0358190536499, 39.906909125191824, 38.115545409066335, 38.07472126824515, 36.41682897295271, 40.49863856179373, 35.77350916181292, 39.20403977802822, 39.1371077810015, 41.62830448150635, 38.01889944076538, 38.49006373541695, 38.03858021327427, 46.30542530332293, 49.53123072215489, 51.66458477292742, 47.89323806762695, 51.579042025974815, 52.648522649492534, 49.92495386941092, 48.136994770595, 39.846018586839946, 40.303185735430034, 39.30763741901943, 40.43388482502529, 39.55382946559361, 41.747830867767334, 46.79833745956421, 45.02232231412615, 46.50449466705322, 48.464251450129915, 49.17297118050711, 43.16616317204067, 42.09582444599697, 41.61630841663906, 43.30757985796247, 45.047554697309224, 48.92123794555664, 49.01099477495466, 50.65293748038155, 50.30005931854248, 54.90125022615705, 52.91989844185965, 59.51649733952114, 55.948823179517476, 69.87146023341587, 22.425894601004465, 1.4749527403286524, 18.791981526783534, 4.487007686070033, 0.31259543767997194, 0.7621390010629381, 48.679874897003174, 60.5740270614624, 57.408274923052105, 47.81229155404227, 29.803210462842667, 45.138555254255024, 57.133018561771934, 62.38693019321987, 61.852384431021555, 4.840060421398707, 0.3958484817828451, 0.1625982014728444, 0.19283320621720382, 0.23605744753565105, 0.07561662779854876, 0.1403002379728215, 0.24519308017832891, 0.12375042960047722, 0.13207822559135302, 0.14192192309669086, 0.14059652707406453], [0.007500194462149271, 0.02554205129854381, 0.06183798358376537, 0.024333685603258864, 0.051254940751407824, 0.06211838139487164, 0.03157757109563265, 0.1553412830190999, 0.04358952046771135, 0.09164762151028429, 0.15603325303111756, 4.619880259037018, 49.51479475838797, 50.26267801012312, 39.18518236705235, 29.005955048969813, 15.752969741821289, 37.97054692677089, 41.43552671160017, 31.56765685762678, 50.65478917530605, 35.24355615888323, 0.4607179494840758, 0.12081442214548588, 15.952014786856514, 6.972730943134852, 2.0340454024927954, 21.389680215290614, 56.47447524751936, 48.64833354949951, 49.77598449162075, 46.14147908346993, 49.48809283120291, 49.243717738560264, 48.90107079914638, 44.27213226045881, 40.97482292992728, 47.7907451902117, 48.189974784851074, 43.83395801271711, 35.87230559757778, 34.361086300441194, 37.27662685939244, 41.851668221609934, 45.65145737784249, 46.18507555552891, 49.100831508636475, 44.73801939828055, 44.81125341142927, 42.82215438570295, 42.48751524516514, 44.62898479189192, 46.0224529675075, 43.88022606713431, 43.54696961811611, 43.813241958618164, 42.79688031332833, 45.34488895961216, 44.60290125438145, 45.70615012305123, 40.939835275922505, 34.94303962162563, 33.15307944161551, 33.83460392270769, 33.658873558044434, 32.395256791796, 35.854507786887034, 32.93674380438668, 34.30923536845616, 34.406228746686665, 33.760661193302695, 34.16258668899536, 34.91687617983137, 35.27377734865461, 35.61884226117815, 36.387868881225586, 35.342574937003, 37.47128759111677, 42.121279171534944, 45.75684765407017, 45.30345337731497, 45.62268141337803, 40.56049837384905, 39.17472185407366, 40.30647570746285, 45.416090624673025, 45.39784812927246, 50.7822573525565, 39.66462196622576, 40.82701390130179, 48.31375694274902, 46.45056969778878, 44.650722231183735, 40.68098013741629, 43.419393743787495, 44.527746064322336, 46.15272126879011, 45.696627616882324, 45.852996826171875, 44.566357203892295, 47.521683147975374, 47.51506846291678, 46.17350680487496, 40.7095685005188, 34.9181581224714, 35.265581948416575, 34.29046828406197, 34.27898638589041, 35.968437399183, 34.91552822930472, 34.85143109730312, 34.26229681287493, 35.44282702037266, 34.953177043369834, 33.639571462358745, 35.627986090523855, 36.45310204369681, 45.40167658669608, 45.34500013078962, 45.94322265897478, 46.597392082214355, 47.4771590914045, 48.03218466894967, 46.58914804458618, 41.61769805635725, 39.44014998844692, 38.298463685171946, 38.166687624795095, 36.1200783593314, 34.79501519884382, 36.910877159663606, 36.93471295492989, 37.35106985909598, 34.98623309816633, 36.45181662695748, 37.095945903233115, 37.028089795793804, 36.37876326697213, 38.64041233062744, 42.98024674824306, 43.38716105052403, 45.77231781823294, 46.00271660940987, 43.738878863198416, 45.47096749714443, 46.59084687914167, 53.743781089782715, 52.77692188535418, 59.99378994532994, 33.44406999860491, 0.29953665126647266, 13.915740966796875, 7.033824282033103, 0.35096265748143196, 0.12085912403251443, 30.42411538532802, 53.271650995527, 38.78329856055123, 36.46042544501168, 22.030116524015153, 34.8914145060948, 47.12127583367484, 48.7756210735866, 44.480682441166465, 5.96254928622927, 0.193493176517742, 0.06391666882804461, 0.03132933923708541, 0.04934994011585202, 0.044306178976382525, 0.0468542001077107, 0.0787642906819071, 0.018995750695466995, 0.011903294711373746, 0.0160753834726555, 0.031332915116633685, 0.06127655692398548, 0.053155059327504466, 0.0278557929476457, 0.014306780250210847, 0.07218111678957939, 0.07377463592482464, 0.03314990297492061, 0.09068397964750018, 0.030363251255559068, 0.0607519747157182, 0.2580085167927401, 7.0331728884152005, 57.52460166386196, 55.249619007110596, 46.703619616372244, 32.51572118486677, 15.620273045131139, 35.13088417053223, 41.816725730895996, 30.703269686017716, 57.19121667316982, 37.75792162758963, 0.45269505998917986, 0.12038184250039713, 7.958195686340332, 6.335514690194811, 2.9629229307174683, 22.23162817955017, 58.89445291246687, 47.59151949201311, 52.065315178462434, 46.84162473678589, 52.07455628258841, 50.94185747419085, 50.98520381110055, 44.27901445116316, 42.223181452069966, 47.875805037362234, 50.57728202002389, 46.04549319403512, 39.05350705555507, 36.66550152642386, 38.972932270595, 43.11922114236014, 48.21691642488752, 47.60022211074829, 51.01006099155971, 46.10543877737862, 45.21848733084542, 43.39585324696132, 43.99622624261038, 45.04779093606131, 46.71673781531197, 45.2433306149074, 43.698541096278596, 43.55944858278547, 44.515670095171245, 45.50836270196097, 46.633706842150005, 47.66229036876133, 43.477345194135395, 37.0468499319894, 34.26171663829258, 35.61504854474749, 33.86084726878575, 34.142384801592144, 36.68658583504813, 34.48586899893624, 36.60324566704886, 36.05027328218733, 35.04177699770246, 35.03814656393868, 37.47095060348511, 37.14583049501692, 38.011252948216026, 37.18649135317121, 36.706700869968955, 39.21989556721279, 44.14371912819998, 47.142516476767405, 47.961368628910606, 47.494251659938264, 43.53061008453369, 40.3421060698373, 41.39234018325806, 47.55394015993391, 47.86048078536987, 51.3749178477696, 39.72845506668091, 42.76860809326172, 50.15678398949759, 48.29400321415493, 46.124487263815745, 41.68848630360195, 45.466357367379324, 46.64278813770839, 47.472986698150635, 47.24841397149222, 46.166197299957275, 46.56371416364397, 50.57297761099679, 50.66726813997541, 48.457588127681184, 41.385093212127686, 36.71059186117989, 37.565901211329866, 35.46627024241856, 36.86356340135847, 36.79418216432844, 36.14818034853254, 36.84575169427054, 34.46021624973842, 37.419009344918386, 36.902549743652344, 35.33964627129691, 36.85552780968802, 38.88322755268642, 49.98621613638741, 47.42984880719866, 48.036110401153564, 46.26447262082781, 49.51365177971976, 49.14346218109131, 47.048385756356375, 42.91745935167585, 41.09412349973406, 40.47064079557146, 41.122572898864746, 36.901795864105225, 35.9200119291033, 39.22184106281826, 39.34171485900879, 38.89076287405831, 37.16401393072945, 38.65670933042254, 38.840551716940745, 39.07797513689314, 39.602817739759175, 40.8974860055106, 45.088872160230366, 46.17358670915876, 47.85405370167324, 48.14773668561663, 46.5806052344186, 47.22487347466605, 48.70218903677804, 55.190347399030415, 54.895660400390625, 62.573746408735005, 37.8746200970241, 0.22800019702741078, 2.1909795871802737, 5.473937630653381, 0.5987479314208031, 0.23654813691973686, 33.97090673446655, 56.717443329947336, 42.14715773718697, 37.91169221060616, 28.434007133756364, 42.04525893075125, 50.752018792288645, 55.33506795338222, 54.363365854535786, 9.381602781159536, 0.17235769278236798, 0.06855267791875772, 0.042550435688878806, 0.006368803899801735, 0.007836900501778083, 0.03544516981180225, 0.04889813418100987, 0.023265685054606626, 0.10097774943070752, 0.05228906204657895, 0.03239855436342103, 0.11234150787017175, 0.23981455021670886, 0.20637342679713452, 0.16773102033351148, 0.11639384792319366, 0.18932224889951094, 0.12950095960072108, 0.32047339209488457, 0.1078836481486048, 0.4689328372478485, 0.31612398262534824, 9.688754848071508, 66.43664605276925, 60.91262667519705, 54.579510416303364, 37.858458587101524, 23.956857204437256, 44.08168561117989, 50.020373480660574, 40.394109862191335, 60.67757606506348, 42.38377169200352, 0.5768486208149365, 0.35284803488424843, 26.54431598527091, 12.51108705997467, 3.8702612604413713, 27.25620583125523, 60.99459457397461, 51.77600261143276, 53.03356402260916, 48.35308027267456, 53.13209295272827, 54.16308055605207, 51.57951102937971, 44.55869334084647, 43.445494651794434, 48.07693106787545, 53.232167857033865, 47.9106502532959, 40.12846285956246, 38.299724783216206, 42.255500997815815, 45.267114298684255, 50.14068848746163, 48.268892424447195, 51.5332464490618, 47.155242102486746, 46.56341886520386, 44.354096685137065, 44.35875545229231, 47.31504372188023, 46.739670344761436, 46.55406311580113, 45.080277238573345, 45.34289830071585, 45.22641175133841, 47.31168079376221, 48.12591239384243, 49.36859771183559, 45.24639824458531, 38.70472138268607, 35.95330074855259, 37.11601577486311, 36.651719774518696, 34.84680707114083, 39.509347098214285, 35.620944091251914, 38.199094023023335, 36.89224903924124, 37.3485163961138, 37.02693292072841, 38.61863667624337, 38.46798930849348, 39.8754893711635, 39.945131165640696, 37.90677636010306, 41.790030751909526, 47.49839278629848, 50.29355927876064, 48.96855517796108, 49.160429682050435, 46.15674427577427, 42.3468211718968, 43.765375818525044, 50.26891054425921, 49.821481295994346, 54.172745500292095, 44.549858706338064, 44.51577431815011, 52.9824218068804, 51.75155190059117, 47.110794476100374, 44.075755323682515, 48.12878199986049, 48.60953480856759, 49.83183411189488, 47.093938146318706, 48.971713134220664, 45.999117442539756, 52.01837314878191, 51.98401083265032, 49.7455027444022, 44.127241475241526, 38.994614124298096, 37.747044222695486, 37.78924410683768, 38.33345133917672, 39.12577526909964, 38.24894387381417, 37.941538197653635, 36.644007274082725, 39.78419004167829, 37.795080593654085, 36.79948016575405, 38.49751567840576, 40.43230758394514, 51.139419078826904, 49.59236444745745, 48.7992136819022, 45.911695207868306, 51.866318770817344, 51.11778933661324, 49.91557380131313, 45.28119134902954, 43.66665928704398, 42.21897431782314, 43.67406606674194, 39.097051416124614, 38.34454066412789, 41.52085059029715, 41.139661993299214, 42.05559090205601, 39.178515570504324, 39.52634934016636, 42.22414377757481, 40.952637331826345, 42.15613828386579, 43.29792186192104, 48.19034651347569, 48.0568334034511, 50.771279198782786, 50.49177401406424, 47.67605822426932, 48.94556358882359, 50.89210489818028, 57.056383405412944, 57.857170241219656, 63.936156136649, 41.42321450369698, 0.852390889610563, 22.226856504167827, 11.800909944943019, 0.9172335416078568, 0.42193910319890293, 37.879879883357454, 62.87981455666678, 50.672329902648926, 48.12309489931379, 34.15833439145769, 44.98148775100708, 61.542494773864746, 61.34274101257324, 66.83531284332275, 12.384721909250532, 0.27218550177557127, 0.12374041442360197, 0.182251208328775, 0.12728198724133627, 0.13377088547817298, 0.16337291204503604, 0.20080264072333062, 0.11310247132288558, 0.15933552011847496, 0.09084030733044658, 0.09842838480004243], [0.012133010197430849, 0.014169504134250539, 0.08398485769118581, 0.036252056514578204, 0.011935358883679976, 0.06644547384764467, 0.06931871681341104, 0.018167003290727735, 0.027193534287757108, 0.051727930549532175, 0.03418345090800098, 8.958599925041199, 50.549523966653005, 44.37237739562988, 43.484008516584126, 27.692401579448156, 35.90454176494053, 49.734264033181326, 39.216744559151785, 35.612036500658306, 50.22176354272025, 31.699828965323313, 0.12696638703346252, 0.05559898979429688, 1.0025865158864429, 8.00349794115339, 1.1445392987557819, 19.263392482485088, 59.33147375924246, 51.892690658569336, 54.4943185533796, 48.263379028865266, 50.309984820229666, 45.48963383265904, 50.2610764503479, 48.78617191314697, 48.63260977608817, 48.574022565569194, 48.20997517449515, 43.26850666318621, 36.285230091639924, 36.42369726725987, 39.032464436122346, 42.28345707484654, 44.608195781707764, 45.91036115373884, 45.69286169324602, 41.515090533665244, 42.041684082576204, 43.45015341894967, 43.11301987511771, 45.69625241415841, 45.226731368473594, 45.898299080984934, 45.84430810383388, 45.66392592021397, 45.781409536089214, 46.2618670463562, 45.557667119162424, 42.99835722787039, 36.3932398387364, 33.7601956639971, 33.777719020843506, 32.77193600790841, 34.66869000026158, 32.18730068206787, 35.99223845345633, 34.43669659750802, 33.71807221003941, 33.90924842017037, 34.12075505937849, 33.80624485015869, 35.09691790172032, 37.24793427331107, 36.12460511071341, 37.73425606318882, 36.15257855824062, 33.928779806409565, 36.4744781766619, 38.91259411403111, 37.30235603877476, 37.052745478493826, 36.1467490196228, 38.32696866989136, 37.38754095349993, 46.16874728884016, 46.6225654057094, 49.28985030310494, 37.86988837378365, 40.74059220722744, 49.22700384684971, 46.080220290592735, 45.461306027003694, 41.87064027786255, 41.76813350405012, 44.55458000728062, 48.59427309036255, 48.393782820020405, 48.67266614096505, 48.38195698601859, 46.895525387355256, 47.57965891701834, 46.93721457890102, 43.595054626464844, 38.636479650224956, 35.71159723826817, 33.107513155256, 34.31317152295794, 34.890844753810335, 36.1661935533796, 34.998524461473735, 37.89473513194493, 38.9018417767116, 35.480270862579346, 35.087468351636616, 33.980582101004465, 33.847906248910085, 39.392193521772114, 48.09135552815029, 44.988429001399446, 46.028119223458425, 48.18385689599173, 46.95204550879342, 45.9278358731951, 44.82679305757795, 45.5323166166033, 43.52087218420846, 43.844988277980256, 40.36626148223877, 37.53176818575178, 36.25628042221069, 35.95932483673096, 35.78592906679426, 36.76752887453352, 36.53518806185041, 36.12367752620152, 34.846313749040874, 38.31145681653704, 39.416025842939106, 42.95873512540545, 41.5062906401498, 43.673638752528596, 41.695497035980225, 42.26344973700387, 43.903057847704204, 46.35960040773664, 47.82461071014404, 57.14199216025216, 53.21285533905029, 59.11917849949428, 2.657398045063019, 3.763161293097905, 9.558230331965856, 0.060764181560703685, 0.1693152231829507, 25.394314425332205, 57.23598044259207, 39.78313738959176, 42.18280894415719, 17.21442256655012, 19.536404575620377, 38.99300561632429, 47.292934553963796, 46.379368032727925, 9.266551903315953, 0.3915728154991354, 0.09417690150439739, 0.029388508559869866, 0.041379243534590514, 0.06838925275951624, 0.035168534477374384, 0.03750750914748226, 0.012729598541877099, 0.01074390482556607, 0.03425010001020772, 0.06553644726851157, 0.04162140250472086, 0.013304843567311764, 0.004007966831393007, 0.05491791705467871, 0.02068183897063136, 0.07403076932366405, 0.0368760814225035, 0.054369199355798106, 0.02953353863475578, 0.03380468248256615, 0.02979669826371329, 11.852475132261004, 57.0773982320513, 51.369532993861604, 47.15619053159441, 33.45542682920183, 29.37551757267543, 44.911759104047505, 42.42493282045637, 38.554977280753, 55.145566259111675, 34.327422278267996, 0.15939476979630335, 0.09175184448914868, 6.724435329437256, 7.396225384303501, 1.9084054699965884, 21.27542403766087, 58.460475376674104, 52.64556271689278, 55.74133259909493, 49.907465253557476, 51.874027797154014, 46.568852356501985, 49.65060772214617, 48.91837876183646, 49.654015813555034, 49.66113076891218, 50.42045075552804, 45.01388372693743, 36.8082765851702, 38.25047247750418, 40.52404464994158, 44.37380872453962, 46.262537547520225, 48.69383035387312, 48.11591393607003, 42.75510426930019, 42.1796509878976, 42.71876171657017, 45.218192032405305, 46.95438010351998, 47.77282231194632, 47.83869818278721, 50.05884565625872, 46.383578641074045, 46.63604143687657, 46.46676247460501, 47.70129755565098, 44.87003864560808, 36.82245438439505, 35.11798831394741, 36.45770869936262, 34.173273018428254, 36.57403891427176, 34.951189858572825, 36.92354025159563, 35.52784865243094, 35.972477776663645, 35.769830090659006, 35.93908126013619, 35.87616184779576, 36.94088295527867, 37.461191858564106, 38.66323716299874, 39.607448714120046, 37.586919512067524, 36.03320850644793, 37.40814583642142, 39.92430394036429, 40.05182422910418, 38.88143144335066, 38.52629164287022, 39.22063902446202, 40.5313263620649, 48.84257044110979, 47.55290835244315, 51.499450411115376, 40.09009838104248, 41.5600141116551, 50.91255692073277, 48.27249506541661, 45.92339250019619, 43.47488553183419, 45.151426792144775, 46.92266852515084, 49.903272015707834, 49.492803709847585, 48.80730138506208, 49.318938936506, 48.528668199266704, 48.67928082602364, 48.954221044267925, 43.76583787373134, 39.45363991601126, 36.88958093098232, 36.06511810847691, 35.42479991912842, 35.81362458637783, 36.40259211403983, 37.17980023792812, 38.55515098571777, 38.45571878978184, 36.148413113185335, 37.22348703656878, 36.39317383084978, 35.788367884499685, 42.167543751852854, 48.37039518356323, 46.195754936763215, 47.70044987542288, 46.79933452606201, 48.72572258540562, 48.88692079271589, 46.633064133780344, 47.49869850703648, 44.79257665361677, 46.419302804129465, 41.7185720035008, 40.62331356321062, 37.10163647787911, 37.91386352266584, 37.12342950275966, 39.0950642313276, 37.7730895451137, 39.203522137233186, 37.385605880192344, 39.44948141915457, 41.55584519250052, 45.29021011080061, 44.07295867374965, 46.020771503448486, 43.496164390019004, 45.90583092825753, 46.3652458190918, 49.28285346712385, 48.78305564607893, 58.483946391514365, 55.392668519701274, 62.37092154366629, 4.062092338289533, 1.3806198707648685, 3.6127744827951704, 0.08240759625498738, 0.16346611561519758, 28.180804354803904, 61.21497753688267, 47.726092202322825, 44.45559597015381, 22.711043460028513, 25.69523048400879, 45.08432109015328, 52.415844849177766, 57.461209774017334, 13.183110748018537, 0.6549549496599606, 0.05551632387297494, 0.08227206567036253, 0.04977292866845216, 0.058963051065802574, 0.1004387279972434, 0.040070576792848964, 0.07883973020528044, 0.008607460135993148, 0.0316339268216065, 0.044638369365462234, 0.16226578716720852, 0.17805157867925508, 0.1535966337791511, 0.135303886075105, 0.09993988262223345, 0.17029281572571822, 0.1995855931724821, 0.10904498118907213, 0.08065510315022298, 0.1846436278096267, 0.11992531056915011, 14.336883442742483, 67.74547127314976, 56.14396333694458, 56.376988547188894, 37.24140991483416, 48.360990796770366, 57.981542995997835, 48.17926066262381, 46.835319246564595, 58.19917099816458, 39.15741389138358, 0.36736225177134785, 0.17679976299405098, 5.200025311538151, 14.409266301563807, 4.42306558574949, 21.747088602610997, 61.50691304888044, 54.16014494214739, 57.53269978931972, 52.511827264513286, 52.73282166889736, 47.19083077566964, 52.159359046391074, 51.631240367889404, 51.41113880702427, 50.14059468678066, 53.42717252458845, 47.59992333820888, 39.695944445473806, 39.43832608631679, 42.317291327885215, 46.22686549595424, 48.537801606314524, 50.44418232781546, 46.76506948471069, 43.05352245058332, 43.72637905393328, 45.70393712180001, 47.22535637446812, 50.049326624189106, 49.272643089294434, 49.00088514600481, 50.94568593161446, 47.54317045211792, 49.29245587757656, 48.39750705446516, 50.07201944078718, 47.33936241694859, 39.737088203430176, 38.33779396329607, 37.4221499306815, 36.15943990434919, 38.83700813565935, 35.28998749596732, 38.79413080215454, 38.05173315320696, 36.16899715151106, 36.91154418672834, 36.19796419143677, 37.58376155580793, 38.38619858877999, 40.204899992261616, 40.96286508015224, 40.9914847101484, 40.168220451899934, 38.183290345328196, 40.58475453513009, 43.09845297677176, 41.85778611046927, 40.9480619430542, 39.395820481436594, 41.74697623934065, 42.463662079402376, 48.41114289419991, 50.46811539786202, 51.67877646854946, 43.239793232509065, 42.941573074885774, 51.47255393436977, 50.67971236365182, 47.70420190266201, 45.09410415376936, 45.93039975847517, 48.963559423174175, 52.186047077178955, 52.02220855440412, 51.703720501491, 50.77717127118792, 51.12420947211129, 50.437317507607595, 51.33292293548584, 47.8157274382455, 42.29156909670149, 37.561742714473176, 36.63023247037615, 37.91066040311541, 38.30142709187099, 39.29195186070034, 38.05138921737671, 41.488412925175254, 41.033364977155415, 38.14257042748587, 38.80467816761562, 38.56278010777065, 37.02483456475394, 43.57736103875296, 51.40778977530343, 49.75101613998413, 47.57010514395577, 47.63184336253575, 50.92572375706264, 51.59733663286482, 49.89597640718733, 50.53044073922293, 47.7270302091326, 48.54959964752197, 46.02297060830252, 43.77901513235909, 39.737095151628765, 40.550923756190706, 39.12356921604702, 41.48050934927804, 39.13838972364153, 41.42777599607195, 38.204350335257395, 42.76344558170864, 42.99892350605556, 48.20551095690046, 45.98599924360003, 49.64772769383022, 45.212327752794536, 47.42478357042585, 47.31534596851894, 50.859010628291536, 53.48172630582537, 62.87051091875349, 55.78634302956717, 68.24360152653286, 5.197685505662646, 7.253170660563877, 17.03457018307277, 0.2915549895593098, 0.2858769813818591, 31.462162358420237, 67.87882804870605, 53.7651606968471, 54.92606571742466, 26.668405600956508, 30.515935829707555, 52.154248646327424, 60.89902210235596, 65.28562137058803, 19.553696904863628, 0.7867738391671861, 0.19870800312076295, 0.1742367869509118, 0.1320168860256672, 0.1890424346285207, 0.2324297550533499, 0.1476595745022808, 0.12031279477689948, 0.2659160281930651, 0.1769792762185846, 0.20665510025407585], [0.035818082480026145, 0.04319993619407926, 0.004475275170989335, 0.07362480860735689, 0.01627970054479582, 0.09390648494341544, 0.03386238510055201, 0.06959293317049742, 0.04570528765075973, 0.036405853261905055, 0.04184238100424409, 9.573109030723572, 53.084727082933696, 45.65397957393101, 44.70664133344378, 26.8240122454507, 46.696324007851736, 51.73962184361049, 55.409406730106895, 35.98736776624407, 48.492773805345806, 28.776803459439957, 0.09652382521224873, 0.05004524173481124, 4.168109689440046, 6.685814636094229, 2.7943316229752133, 27.622044120516094, 34.174381256103516, 41.29474925994873, 50.61738702229091, 46.28591128758022, 45.84414829526629, 51.80043247767857, 48.69344472885132, 50.832857608795166, 47.94476938247681, 46.95673554284232, 44.39374658039638, 39.192933082580566, 37.264269488198416, 36.65670163290841, 37.39392982210432, 41.13550002234322, 43.478981494903564, 45.22577599116734, 46.90401956013271, 45.72720316478184, 39.099778584071565, 43.60490369796753, 44.722580501011436, 42.71817806788853, 41.732034138270784, 44.48657103947231, 44.838671003069194, 46.06586183820452, 44.2801331111363, 45.488001005990164, 42.013165201459614, 34.99256985528128, 32.68989862714495, 33.28476864950997, 34.56151751109532, 33.91991737910679, 32.29921184267317, 32.69206993920462, 34.75681400299072, 34.15728521347046, 33.55070400238037, 34.93011597224644, 35.05059773581368, 34.2512526512146, 33.98171465737479, 39.537087781088694, 37.47343805858067, 36.14063113076346, 34.88329553604126, 36.483232906886506, 34.135988984789165, 36.86658239364624, 34.95273583275931, 36.76095935276577, 35.66235188075474, 37.99279505865914, 38.266699995313374, 45.14636850357056, 45.98410585948399, 49.850705419267925, 37.14724097933088, 44.04277917316982, 50.676616941179546, 44.96848767144339, 43.43041011265346, 39.52458102362496, 40.495185307094026, 41.44941963468279, 42.738136768341064, 44.12923213413784, 45.93441581726074, 47.87983499254499, 48.68221296582903, 48.37845509392874, 43.946758542742046, 41.322621958596365, 41.05675261361258, 38.58981554848807, 33.648857729775564, 35.55335201535906, 34.463047640664236, 34.25106504985264, 35.1431234223502, 36.77114888599941, 37.059071813310894, 36.17793253489903, 34.97337893077305, 35.590889658246724, 34.754687854221885, 36.945246423993794, 42.063619545527864, 47.207593304770334, 44.2844375201634, 47.281845229012625, 47.03586162839617, 46.57667602811541, 46.398611068725586, 47.042604855128694, 46.66873618534633, 48.46301119668143, 44.57974638257708, 42.20682191848755, 39.25959757396153, 37.375016825539724, 37.925998551504954, 35.813707964760916, 35.06915637425014, 35.83994436264038, 37.258728299822124, 38.961144651685444, 40.90536526271275, 41.22666386195591, 41.159950733184814, 40.70421143940517, 41.98100546428135, 41.46921157836914, 42.30147722789219, 45.51368849618094, 51.39130517414638, 54.49875497817993, 58.101743357522146, 47.67384869711739, 9.341405715261187, 0.25775542323078426, 2.160304810319628, 0.18089420614498003, 0.047488063773406405, 19.615693943841116, 58.54600770132882, 40.96083620616368, 40.27581330708095, 30.271400928497314, 23.437382084982737, 43.100335938589915, 47.08034746987479, 48.18694884436471, 18.670897006988525, 0.7359400583165032, 0.008755911723710597, 0.006276683865248093, 0.0455908900392907, 0.03143804054707289, 0.031897021989737234, 0.08887920541954891, 0.024622439573119794, 0.06103056762367487, 0.05106158880516887, 0.05615600597645555, 0.012404380100114005, 0.07018110768071242, 0.022825811158067415, 0.04322499788499304, 0.01809308198945863, 0.06531753151544503, 0.05046411497252328, 0.012268807955219277, 0.09336548897304706, 0.09939295625580208, 0.037124974852693934, 13.372916425977435, 61.605042457580566, 49.60458285467965, 53.89248991012573, 33.413504873003276, 49.845535959516255, 52.92033617837088, 58.05630908693586, 39.881381443568635, 52.87216779163906, 29.088268620627268, 0.12345477832215172, 0.09186435238059078, 6.104928297655923, 13.378663454736982, 1.273679603423391, 29.17925180707659, 36.624336923871724, 45.30399881090437, 51.120905603681294, 48.32971000671387, 47.3006192616054, 53.09604917253767, 50.681650911058696, 51.36183786392212, 49.875764097486226, 50.20637328284127, 46.175233432224815, 41.259560108184814, 39.09742314474923, 37.76683269228254, 38.312790870666504, 43.332516942705425, 45.78055143356323, 47.436060496738975, 48.94804409572056, 46.49676827022007, 40.4994341305324, 44.47555467060634, 45.91624975204468, 45.31764159883772, 43.354299545288086, 46.390043939862935, 46.406111649104524, 46.93217713492257, 46.35308647155762, 47.31456429617745, 44.11559976850237, 37.293691635131836, 34.61582463128226, 35.23041364124843, 36.31818192345755, 34.98826544625418, 34.10655641555786, 33.990973131997244, 36.17847796848842, 36.296944754464285, 34.27378565924508, 36.17547982079642, 35.554248332977295, 36.14230217252459, 36.02051067352295, 41.43937601361956, 38.190853459494456, 40.086388042994905, 37.17293889181954, 38.19259050914219, 35.2142972946167, 36.70058298110962, 36.82280874252319, 39.36666931424822, 37.164823395865305, 39.1391818182809, 41.16245208467756, 46.24919353212629, 47.017309938158306, 51.76354101725987, 37.908249378204346, 45.35831982748849, 51.25852509907314, 45.936767782483784, 45.41389151981899, 40.415694441114155, 41.56698315484183, 43.72923476355416, 45.4457038470677, 46.92537832260132, 47.40282031467983, 48.368904794965474, 48.57646138327462, 49.52031510216849, 45.38109949656895, 43.82911859239851, 42.86215516499111, 40.45530264718192, 36.42953027997698, 37.2114770753043, 36.36572844641549, 37.3460567338126, 37.231675488608225, 37.95877667835781, 38.19814906801496, 36.909428460257395, 37.56404256820679, 36.20942871911185, 36.746507099696565, 38.05857712881905, 44.39130081449236, 47.62843179702759, 46.86957039151873, 49.1405474117824, 47.15156650543213, 49.39220421654837, 48.24736343111311, 48.73523814337594, 47.78031594412667, 50.63381951195853, 46.56134830202375, 43.133437156677246, 40.641451835632324, 39.56711789539882, 39.65040247780936, 38.085404123578755, 36.21288892201015, 38.52906050000872, 39.31556878771101, 41.31173413140433, 42.57261678150722, 43.39691284724644, 44.66770710263933, 44.10349600655692, 42.92491129466465, 44.419680731637136, 43.88027123042515, 47.04476227079119, 51.90595129558018, 56.28830868857247, 59.59451866149902, 50.70556313650948, 10.959985971450806, 0.21301276981830597, 0.11545451118477754, 0.1858051847666502, 0.024500435584091713, 22.18492238862174, 60.55968597957066, 46.950843470437185, 44.62539952141898, 31.46147448675973, 30.43360662460327, 47.91835233143398, 51.80902392523629, 56.429530824933735, 24.756129332951136, 0.586547491805894, 0.021944701205939054, 0.05226379679515958, 0.03556364541873336, 0.03417871134089572, 0.0204007320904306, 0.06575448092605386, 0.021148479377318705, 0.08837645846818175, 0.019043365194063102, 0.03114925604313612, 0.13916787159230026, 0.14458586515060493, 0.11134542524814606, 0.2031562208597149, 0.07638673790331398, 0.17724257494722093, 0.09883680859846727, 0.11516422033309937, 0.1602013036608696, 0.21722231964979852, 0.09078390071434633, 16.55060383251735, 71.67935371398926, 56.62368433816092, 59.17276300702776, 36.61658273424421, 56.95685740879604, 56.26481335503714, 63.006827626909526, 44.0464061328343, 57.64624030249459, 32.6273717880249, 0.22367469913193158, 0.21646465387727531, 8.359510609081813, 11.304064239774432, 4.856178070817675, 32.87088530404227, 39.22005190168108, 48.27805709838867, 54.383206435612266, 47.42096553530012, 46.57847908564976, 53.775054931640625, 52.33885186059134, 54.414643560137065, 51.46649163109915, 52.16378852299282, 48.44616181509835, 43.4142347063337, 41.785750661577495, 39.071634905678884, 40.982358251299175, 45.66661139896938, 48.73162160600935, 49.114321436200825, 50.16149139404297, 47.927232129233225, 41.93690177372524, 46.76466996329171, 47.908194065093994, 46.256141730717246, 45.79339517865862, 49.07538720539638, 48.14390475409371, 48.972154344831196, 48.912410259246826, 51.1434976713998, 47.95941271100725, 38.627030100141255, 36.24540996551514, 37.16318709509713, 37.48821687698364, 36.48981632505144, 35.062496525900706, 35.13963195255825, 38.82477930613926, 37.08962999071394, 36.60603189468384, 37.55819913319179, 37.770153931209016, 38.231535162244526, 36.86866685322353, 43.473614011492046, 40.39031267166138, 41.91465711593628, 39.02983801705496, 40.490262508392334, 37.21515267235892, 40.39831352233887, 38.22199528557913, 40.787384850638254, 39.98026473181588, 41.870390142713276, 41.81661803381783, 47.83128445489066, 49.11146572657994, 54.28247492653983, 41.995989254542756, 46.4273488180978, 53.23353317805699, 47.287667819431846, 47.21914121082851, 41.91792971747262, 43.849900654384065, 44.732228074754985, 47.31642641339983, 49.1269463130406, 50.12889739445278, 51.134075914110454, 51.97678818021502, 52.84603909083775, 48.00086566380092, 44.37503508159092, 43.44270147596087, 42.26376240594046, 37.666636194501606, 39.933055196489605, 38.58154719216483, 37.92102364131382, 38.33778701509748, 39.49491221564156, 39.73182841709682, 39.002159867967876, 39.036779267447336, 37.73522881099156, 39.0772316796439, 40.22960083825247, 44.703132493155344, 49.81665577207293, 49.966705594744, 48.61248084477016, 45.802368777138845, 51.031968661717, 49.156646387917654, 51.127475125449045, 51.622329303196494, 52.692591599055696, 48.83925267628261, 45.621441159929546, 42.75518069948469, 42.3532760483878, 41.34430381229946, 39.25363949366978, 38.25458581107003, 40.90834256580898, 41.13387761797224, 44.016945770808626, 45.414992809295654, 45.98851796558925, 47.09843363080706, 47.1518930707659, 47.16586937223162, 47.29445273535592, 47.1513580594744, 50.71939352580479, 55.52272490092686, 60.10444695608956, 61.43101787567139, 52.41583095278059, 13.264053787503924, 0.46602707888398853, 5.951485582760402, 0.4499135006751333, 0.12141165509819984, 25.16624849183219, 68.313583782741, 51.527934551239014, 53.09346096856253, 41.842743260519846, 34.49716329574585, 57.78916474751064, 58.04287474496024, 65.59304441724504, 30.607214314596995, 0.8521360861403602, 0.1797840278595686, 0.11680924706161022, 0.11470269438411508, 0.11282178852707148, 0.08821413253567048, 0.2275255617818662, 0.1822646161807435, 0.17343493497797421, 0.1466642857662269, 0.19098437471049173], [0.02852953750906246, 0.03505387902259827, 0.02563175362800913, 0.04561307474172541, 0.035481736063957214, 0.0557571189877178, 0.03872706727789981, 0.028701797194246734, 0.0384993509256414, 0.07058568418558155, 0.06259180884808302, 12.434525728225708, 51.04249518258231, 44.187815870557515, 42.655564376286094, 20.19139388629368, 33.36847012383597, 52.36091933931623, 45.23365872246878, 30.536141191210064, 55.58791637420654, 24.17829803058079, 0.12887859371091637, 0.04387124142210398, 9.538224731172834, 6.7697992495128085, 3.44924168075834, 26.405994721821376, 12.41410323551723, 29.33525971003941, 45.9565041405814, 49.97779144559588, 50.64782360621861, 50.779578821999685, 44.753065722329275, 45.5228705406189, 42.95900957924979, 42.83475146974836, 37.76413679122925, 35.74222142355782, 34.39653948375157, 34.5971930367606, 36.05502585002354, 40.618967464991975, 41.632938929966514, 45.426287106105256, 45.53979982648577, 45.35560655593872, 42.933770247868125, 40.916760308401926, 45.19896636690412, 43.76963159016201, 41.54999133518764, 39.95950698852539, 38.69998618534633, 41.004078320094514, 40.54429170063564, 37.53453704289028, 32.62057644980294, 33.262169633592876, 34.24868529183524, 34.49014214106968, 34.42652096067156, 35.30602741241455, 32.10309198924473, 32.78509242194039, 32.951216902051655, 35.589447907039094, 34.95398303440639, 35.30009365081787, 34.499834878104075, 35.81066812787737, 37.991846629551475, 42.6976774079459, 42.4493522644043, 41.556974274771555, 37.87044422967093, 35.332965578351704, 33.92048018319266, 37.31065913609096, 35.542894976479666, 35.86235230309622, 35.279516560690745, 38.61424194063459, 39.006592818668906, 44.58728865214756, 43.193410532815115, 49.160836151668, 39.34113468442644, 43.027324267796104, 47.580416270664756, 44.13954326084682, 39.81293821334839, 36.838709694998606, 40.79389531271798, 40.03878940854754, 42.34372574942452, 42.20133284160069, 44.41892685209002, 42.489252294812886, 43.59507547106062, 43.75373758588518, 44.140248503003804, 46.02200828279768, 45.99553564616612, 44.22866433007376, 35.752713203430176, 33.101186820438926, 33.68835129056658, 33.482149600982666, 37.8921469279698, 34.980893407549175, 33.90924147197178, 35.44964320319039, 34.14469855172293, 36.31743151800973, 34.990301268441335, 35.13886765071324, 37.13837507792881, 42.27392067228045, 46.47743838174002, 44.84033509663173, 46.78922489711216, 46.888955865587505, 47.42967510223389, 46.583172593797954, 46.997337341308594, 45.992273466927664, 46.3152882712228, 44.249686104910715, 41.014292172023225, 35.99781438282558, 36.363789899008616, 36.17019918986729, 35.97717128481184, 37.209809507642476, 38.37749249594552, 37.720967633383616, 38.43603106907436, 39.690642969948904, 39.7221599987575, 38.500253268650596, 41.947108677455354, 41.58641726630074, 45.51585980824062, 45.14554514203753, 52.24022912979126, 51.90666001183646, 59.6776191166469, 44.832660811288015, 27.256954499653407, 0.1737245065825326, 1.2144079953432083, 0.0626444292387792, 0.08851548350815262, 14.453829441751752, 56.166270528520855, 43.81757763453892, 40.979940278189524, 37.91679566247122, 10.669364537511553, 34.076682635716026, 46.5851389339992, 54.022518498556956, 27.81319601195199, 1.0395938158035278, 0.03665853970284973, 0.05315132059955171, 0.046055771343942196, 0.020077249001977698, 0.01684335958478706, 0.007686420094354877, 0.030689453573099205, 0.039415329096040556, 0.012429924399059798, 0.058493172350738726, 0.04892630695498415, 0.027024711382442286, 0.061148435941764286, 0.06654534741703953, 0.022706712995256697, 0.06940592891935791, 0.03453957322718842, 0.04218006074162466, 0.04343601888311761, 0.04438981520278113, 0.034149083109306436, 14.733014140810285, 59.808238301958355, 47.10256780896868, 48.69840921674456, 24.991306747709, 43.16765703473772, 60.45439297812325, 51.958375453948975, 36.28082840783255, 57.9422995703561, 27.61823650768825, 0.03740847356883543, 0.10134725246046271, 3.6731721333095004, 2.3667014837265015, 3.0179765479905263, 27.09444308280945, 13.438536081995283, 31.168274402618408, 48.40151269095284, 51.284073625292095, 52.58526277542114, 52.21453469140189, 45.796518393925254, 48.267770290374756, 46.222536768232075, 42.984870774405344, 39.1490204674857, 37.15244518007551, 35.74571984154837, 35.89343506949288, 38.67329815455845, 43.10220152991158, 44.61442831584385, 46.75387246268136, 46.4268798146929, 47.968733719417024, 43.25393629074097, 42.703743185315815, 46.961647919246126, 45.779533522469656, 43.40733861923218, 41.88765294211251, 41.113661834171836, 42.19344316210066, 41.43945939200265, 38.58014365604946, 36.69289827346802, 35.26292426245553, 36.33469779150826, 37.051519121442524, 35.328643798828125, 36.6774628502982, 33.72871685028076, 34.04768432889666, 35.170054640088765, 37.20043291364397, 35.39035422461373, 37.498569692884175, 37.168432985033306, 37.554436683654785, 40.932828017643516, 44.026850427900044, 43.52216107504708, 43.10104465484619, 40.087187085832866, 38.16416195460728, 35.475090980529785, 37.745456559317454, 36.80102613994053, 39.04555136816842, 37.1736649785723, 38.98774930409023, 41.28131839207241, 46.77160426548549, 44.87473562785557, 50.950997829437256, 40.390618392399375, 44.402272020067485, 49.46392004830496, 45.61728266307286, 42.08562796456473, 39.21789448601859, 41.844105107443674, 41.162618841443745, 43.339506830487935, 44.9869247164045, 47.31027725764683, 44.80867910385132, 45.491982323782786, 46.760028566632954, 44.54033620016915, 48.416156019483296, 47.56903164727347, 46.10160684585571, 37.78085763113839, 35.797560351235525, 34.385672501155305, 35.907116072518484, 38.00303322928292, 37.5395119530814, 36.53187724522182, 36.62028612409319, 36.73671361378261, 37.4145381791251, 36.49802214758736, 35.637393951416016, 37.67454671859741, 45.74218348094395, 47.539623396737234, 46.628881318228586, 48.52653510229928, 46.51338488715035, 48.14359555925642, 47.72093316486904, 47.45745052610125, 48.6539546421596, 48.874935150146484, 46.17265565054757, 41.844549792153494, 38.87477159500122, 38.581512451171875, 37.403487069266184, 37.57729973111834, 38.70787933894566, 40.21922022955758, 39.8136955669948, 40.54417358125959, 41.76805707386562, 42.4635648046221, 39.65791695458548, 42.89447471073696, 43.55482803072248, 47.418287004743306, 48.022742067064556, 52.92899363381522, 53.173000471932546, 60.474292618887766, 48.63276611055647, 31.067813873291016, 0.20246967912784644, 0.9851713989462171, 0.22266180919749395, 0.04629795406279819, 16.593971014022827, 60.50018160683768, 47.73606981549944, 49.15715708051409, 41.02886254446847, 19.291303396224976, 44.070471218654085, 52.978308473314556, 62.60608332497733, 34.16533817563738, 1.0619399824312754, 0.04442036963467087, 0.039823559511985095, 0.05915769562125206, 0.023949088562013846, 0.03173264688146966, 0.006734893898413117, 0.02974947901176555, 0.046694076021334956, 0.04739601371277656, 0.07010621098535401, 0.08128014246800117, 0.09484721267861979, 0.17323536425828934, 0.15370625789676393, 0.15930022272680486, 0.14089737593063287, 0.10891054304582731, 0.19404998235404491, 0.12050547158079487, 0.2881511322089604, 0.16850205324590206, 19.48058101109096, 70.65973336356026, 53.193261419023784, 55.55287313461304, 29.101866245269775, 42.38226740700858, 58.16470445905413, 52.43336125782558, 39.46172414507185, 65.45879132407052, 27.477813414164952, 0.26604798968349186, 0.19614726624318532, 17.491045985903057, 13.77870946271079, 4.902176448277064, 31.035108702523367, 13.977701527731758, 33.81066737856184, 49.72493955067226, 54.29037850243704, 55.834188325064524, 55.18553924560547, 46.97932413646153, 50.49858324868338, 46.99668768474034, 45.56278099332537, 41.05832290649414, 39.31601694652012, 37.54196466718401, 37.82802547727312, 40.8112519127982, 44.65200069972447, 45.89959144592285, 49.30949286052159, 50.19903251102993, 48.44044344765799, 45.263862541743684, 44.701357228415354, 48.22036273138863, 47.52131141935076, 44.715764318193706, 44.02292122159685, 43.439251695360454, 44.86649506432669, 44.25995206832886, 39.474213532039094, 37.257897990090505, 37.463102613176616, 37.506226607731406, 38.00623287473406, 36.69046640396118, 37.185806955610005, 34.4742933000837, 35.45370789936611, 35.741165297372, 38.78497655051095, 38.003398009708945, 39.54634278161185, 39.068643706185476, 40.980232102530344, 42.955775192805696, 45.68942928314209, 45.872444834027974, 43.9332651410784, 42.79568869726998, 40.44669730322701, 36.76088639668056, 41.59656163624355, 39.731547015053884, 40.63818965639387, 37.83846167155674, 41.131807054792134, 42.90495259421212, 48.07632310049874, 46.9148656981332, 53.20298542295183, 43.92206117085048, 46.08110271181379, 50.53614173616682, 48.234359877450125, 43.68184110096523, 39.95432710647583, 44.250697067805696, 42.794243471963064, 46.27020835876465, 46.53967687061855, 49.80543095724923, 45.847344466618125, 47.450724669865195, 48.648010458265034, 49.418902669634136, 50.0051395552499, 48.73322663988386, 50.21676083973476, 39.9074649810791, 37.396045548575266, 35.8464617729187, 37.296384062085835, 40.50594111851284, 38.58016102654593, 36.85532283782959, 38.9485684122358, 37.49104131971087, 39.696826866694856, 38.271414348057334, 38.14136144093105, 39.50706114087786, 46.66247933251517, 49.50775623321533, 50.80837910515921, 51.70620100838797, 47.86113044193813, 48.594029903411865, 50.56283324105399, 50.95969697407314, 50.33802080154419, 51.4188791002546, 50.034144810267854, 44.91284997122628, 40.033008507319856, 39.664757456098286, 39.485695430210654, 39.37069232123238, 40.16314479282924, 42.90063428878784, 40.95811251231602, 44.32045350755964, 43.741922174181255, 45.27178348813738, 42.10434641156878, 47.05077941077096, 45.58511945179531, 50.84816101619175, 49.09225743157523, 55.697784764426096, 53.882467133658274, 63.80438355037144, 45.87577649525234, 31.40342923573085, 0.2271073670791728, 4.438248268195561, 0.7771738714405468, 0.14427719957062177, 19.582300901412964, 66.81966550009591, 55.56416048322405, 54.10300643103463, 45.939998694828574, 19.037782737186976, 47.33071538380214, 60.63868004935128, 70.69849736349923, 41.48924323490688, 1.5602178850344248, 0.13469876854547433, 0.09920816402882338, 0.12880464696458407, 0.09863730573228427, 0.08433589099773339, 0.10047363862395287, 0.12944571327950272, 0.1566442602447101, 0.11773318105510303, 0.2264013242508684], [0.05428232651736055, 0.020391724538058043, 0.05725101900420018, 0.029867849445768764, 0.028107040894350836, 0.013435830511817974, 0.04168741039133497, 0.05467752566827195, 0.018096905534288714, 0.1030817711725831, 0.04370258815054383, 10.850319947515215, 48.88312012808663, 43.20811986923218, 40.74915933609009, 26.439700433186122, 39.39902360098702, 46.98252725601196, 29.077260937009537, 32.79163415091378, 58.55764593396868, 19.164762803486415, 0.0838196479848453, 0.04663037515378424, 1.4355413636990955, 2.3316610668386732, 3.5288621740681783, 28.83344864845276, 27.192918164389475, 43.078212874276296, 51.48348345075335, 49.46377761023385, 48.238973481314524, 49.001222133636475, 44.64568131310599, 40.63590022495815, 34.9908675466265, 34.63843754359654, 35.991953577314106, 39.852331025259836, 38.511828967503135, 40.111120155879426, 35.27745641980852, 36.101182733263286, 39.468495164598735, 42.936420985630576, 44.21082483019148, 47.23827307564871, 45.46348428726196, 41.05686725888933, 44.19947147369385, 45.84026772635323, 43.35321910040719, 39.12787709917341, 35.17092316491263, 32.87026344026838, 32.11934035164969, 33.61108732223511, 33.13029282433646, 34.12910679408482, 33.61896310533796, 35.27481957844326, 34.22441176005772, 34.42660781315395, 31.86161082131522, 32.84860243116106, 33.51933635984148, 34.384866510118755, 34.07779087339129, 34.76491560254778, 36.2993140901838, 34.17924846921648, 39.3998122215271, 44.56537750789097, 45.47071736199515, 44.122488907405305, 45.16133144923619, 44.60026093891689, 41.05827079500471, 38.97722625732422, 38.49004636492048, 39.61118337086269, 36.05842351913452, 36.97998046875, 40.58144719260079, 48.01145471845354, 44.432653018406455, 50.997307573046, 37.60857704707554, 41.944513525281636, 50.05320371900286, 43.799592222486226, 37.24492917742048, 36.16247626713344, 42.15268850326538, 42.74262530463082, 44.510139329092844, 44.32152353014265, 44.529097488948274, 45.058067321777344, 44.46604258673531, 45.38043246950422, 45.44689893722534, 45.75978326797485, 46.83710493360247, 46.55970852715628, 36.13911642347063, 32.011341026851106, 33.80941322871617, 34.15792097364153, 35.49161032267979, 34.953555720193044, 36.008931500571116, 32.318444456372944, 34.925773348127095, 35.506792136601035, 36.66065515790667, 32.81354876926967, 33.56256457737514, 36.68279211861746, 44.028163637433735, 47.38883359091622, 45.97101545333862, 46.545443875449045, 44.65245580673218, 44.86500467572893, 45.86064679282052, 47.47517190660749, 45.695873737335205, 44.69297422681536, 42.20357363564627, 39.92408159800938, 38.971511363983154, 35.76805830001831, 37.552480765751426, 38.04705701555525, 37.27554988861084, 36.628828934260774, 42.66396822248186, 37.93812663214547, 40.78361545290266, 39.720356941223145, 43.54065717969622, 46.15790809903826, 49.79058960505894, 49.70096131733486, 54.39758573259626, 53.73470674242292, 58.85969802311489, 47.533005237579346, 46.89410448074341, 5.035164969308036, 0.8096210360527039, 0.7593061987842832, 0.25480846422059195, 12.762371267591204, 52.756786005837576, 49.008802618299214, 37.111888544900076, 46.583697182791575, 34.23949977329799, 26.792099169322423, 42.44466570445469, 53.78405632291521, 30.529293741498673, 0.950717670576913, 0.07429416304720299, 0.03633271057956985, 0.04012509708159736, 0.007800307108222374, 0.05351461503388626, 0.03736977671672191, 0.05036399034517152, 0.02996864921546408, 0.04090364137664437, 0.031785491188721995, 0.04143877819712673, 0.07664510368236474, 0.018972685593845587, 0.06102138704487255, 0.05012550564216716, 0.04176464803250773, 0.022430861368775368, 0.002227554131033165, 0.07053052607391562, 0.10296278327171292, 0.0694676823914051, 16.184888873781475, 56.8593533379691, 48.523679392678396, 45.735217911856516, 26.109355279377528, 38.368640490940635, 56.05143765040806, 37.904278482709614, 35.561210427965435, 63.26725305829729, 20.957406725202286, 0.02378044886115406, 0.048978157208434174, 1.3278472168104989, 3.6328044022832597, 5.3103297012192865, 33.31522260393415, 31.176202297210693, 45.58766596657889, 54.416512625558035, 50.9455817086356, 49.4432178906032, 50.36267301014492, 47.16655724389212, 43.71273626599993, 37.87705544063023, 36.176216329847065, 37.79098810468401, 41.357838903154644, 40.56279822758266, 41.934351784842356, 37.525139604296, 38.23784065246582, 41.54036808013916, 44.9868517603193, 45.45332602092198, 48.59571136747088, 44.921799251011436, 42.048347405024934, 48.12997361591884, 46.54534312656948, 44.361513887132915, 42.24539484296526, 37.059596402304514, 35.403858048575266, 35.07271385192871, 34.72724941798619, 35.322195870535715, 36.04651083265032, 34.32094308308193, 37.09224598748343, 36.89398261478969, 35.20152997970581, 33.706260272434776, 35.44176394598824, 34.85411657605852, 34.757064138139995, 35.328404085976736, 37.03584051132202, 36.94679239818028, 34.76518658229283, 41.90318216596331, 46.698338985443115, 45.92301034927368, 47.01450981412615, 46.19649839401245, 44.86964954648699, 41.04626430783953, 41.576088769095286, 38.59441178185599, 40.030375140053884, 38.560365608760286, 38.85223511287144, 43.2630558013916, 49.15712581362043, 47.73097331183297, 51.2619366645813, 39.00501905168806, 44.38647876467024, 51.42195020403181, 44.51907123838152, 40.52639661516462, 38.64353901999337, 43.68166739600045, 45.22313567570278, 46.41749627249581, 47.630828925541465, 47.30375289916992, 46.524105957576204, 46.246021679469514, 46.58647646222796, 48.48222296578543, 47.510475703648154, 47.36570651190621, 47.53376953942435, 37.14271422794887, 34.945547921316965, 34.6571420942034, 36.75660283224923, 37.71986286980765, 37.17488438742501, 37.70682110105242, 34.865403924669536, 37.138152735573904, 37.60920933314732, 37.31570700236729, 36.3993090902056, 36.76589604786464, 38.420074531010215, 46.900291851588655, 48.69014433452061, 46.68374082020351, 47.47471332550049, 46.398197650909424, 46.247421741485596, 47.528409004211426, 49.365547452654155, 47.99206229618618, 46.951076235089985, 43.022345883505686, 41.80743598937988, 40.34784180777413, 36.95333760125296, 39.39180442265102, 39.53659445898873, 37.86375658852713, 37.87619038990566, 45.10243156978062, 41.759667124067036, 43.360455649239675, 41.47686849321638, 45.59858506066458, 48.28804165976388, 50.718281814030235, 51.39745780399868, 55.85613768441336, 54.59336165019444, 60.60029125213623, 52.1717928477696, 57.20553343636649, 5.5355247259140015, 0.8523825843419347, 0.6337142522845949, 0.1535736314420189, 12.83035331112998, 57.65469626017979, 51.450861658368794, 43.50507892881121, 43.28590842655727, 30.18142523084368, 34.98611497879028, 48.57401214327131, 61.11463860103062, 37.22607176644461, 1.77634996175766, 0.020324868482670615, 0.028055538390097872, 0.02955158766625183, 0.05074562897373523, 0.07043786533176899, 0.04609654112053769, 0.060158297286501954, 0.011952459662487465, 0.015915390004270842, 0.028919304987149577, 0.11675079805510384, 0.16567301005125046, 0.11623907408543996, 0.17896667814680509, 0.13485731503793172, 0.07415433733591012, 0.14280443931264536, 0.22933889233640262, 0.14284933118947915, 0.30181351623364855, 0.15727638346808298, 22.362037181854248, 67.18361214229039, 53.957243646894185, 53.03341811043875, 33.67739050728934, 49.138202394757954, 51.21745082310268, 40.74135650907244, 42.56785031727382, 66.98688779558454, 22.88957394872393, 0.2749901855630534, 0.12821320870092937, 3.6834550329617093, 9.314171382359095, 5.29079874924251, 35.440103326525005, 33.814068521772114, 49.59133958816528, 55.64511741910662, 53.62486267089844, 52.62081323351179, 54.221685137067524, 48.8062869480678, 45.08744083132063, 39.54240662711007, 38.33267314093453, 41.179030486515586, 45.15032550266811, 42.555263655526296, 45.36100878034319, 38.49260677610125, 39.831646238054546, 42.60121556690761, 48.015328339168, 46.11144896915981, 50.97898169926235, 46.168101106371196, 44.535298756190706, 49.44096320016043, 50.051605633326936, 47.37164374760219, 43.67706421443394, 38.15539680208479, 36.96363830566406, 35.04053327015468, 36.27516562598092, 37.14620917184012, 37.373182501111714, 36.86343138558524, 39.36812843595232, 37.672962529318674, 36.85927636282784, 35.89086423601423, 35.880653858184814, 35.73096186774117, 37.046089104243684, 38.06452131271362, 38.75691277640206, 39.44604206085205, 37.265985693250386, 41.52105903625488, 48.078772340502056, 48.814444133213584, 49.085364818573, 49.669426918029785, 47.910757950374055, 44.19562911987305, 42.80540227890015, 41.09727103369576, 43.46553325653076, 38.61052465438843, 40.45534781047276, 45.368557998112266, 51.45957122530256, 49.33664294651577, 54.42134509767805, 40.56642171314785, 46.17833232879639, 52.889649459293906, 46.57436227798462, 41.517174993242534, 39.83620078223092, 46.51804365430559, 46.56918934413365, 48.38634477342878, 50.377358027866904, 48.74084881373814, 49.402678625924246, 46.535007681165425, 46.997319970812114, 50.83868714741298, 49.783783844539094, 49.60624347414289, 50.22763477052961, 39.90359830856323, 36.31019844327654, 37.50325625283377, 38.54001433508736, 39.82242597852434, 37.769295828683035, 40.78467157908848, 36.12294796534947, 38.245320388248985, 38.53842319761004, 40.31307649612427, 37.67352185930525, 37.947565759931294, 39.88113825661795, 48.43523577281407, 50.65647063936506, 49.96909924915859, 50.185288974217, 46.89186716079712, 48.88349880490984, 49.615627016339985, 51.3090489251273, 49.96161951337542, 50.51629073279244, 45.970518657139365, 44.15880366734096, 43.085508482796804, 40.46464797428676, 41.67370401109968, 42.15962975365775, 40.931671142578125, 40.20907933371407, 48.7810754094805, 43.41532209941319, 46.13660144805908, 43.99754640034267, 48.34392602103097, 51.44757168633597, 54.84519215992519, 53.24117967060634, 58.9116427557809, 57.39146375656128, 63.150863783700125, 50.58121470042637, 54.142131737300325, 6.935495546885899, 2.2858072987624576, 1.780564695596695, 0.3442345756505217, 14.870670114244733, 63.07193224770682, 58.38173839024135, 50.34442704064505, 55.79864828927176, 44.202598163059776, 39.97506400517055, 57.17384965079171, 66.89121804918561, 45.819346700395855, 3.0618311890533993, 0.24653201975992747, 0.0932945209954466, 0.11773202754557133, 0.11889277026057243, 0.21718058974615165, 0.17580264221344674, 0.1420374233275652, 0.18114797824195453, 0.11221604674522366, 0.0986367357628686], [0.04193291114643216, 0.04180774518421718, 0.040471892936953476, 0.05496010496946318, 0.03891430562362075, 0.026600621906774383, 0.025564342870243957, 0.020141870980816226, 0.07402966331158366, 0.09542009300951447, 0.08803907050085918, 17.29656069619315, 48.500705174037385, 44.8754825592041, 42.292475836617605, 31.55769314084734, 31.867256232670375, 28.81110324178423, 28.219363382884435, 37.62738929476057, 55.543190819876536, 16.975923912865774, 0.3294764661363193, 0.36531280460102217, 0.7309846356511116, 0.8415028995701245, 5.006550550460815, 41.3694806098938, 50.626030581338064, 52.481564385550364, 48.80383423396519, 47.548121043613975, 45.7980192048209, 41.507812295641216, 36.98010901042393, 36.66916670118059, 37.24978596823556, 40.46314368929182, 43.49519164221627, 45.68427719388689, 44.69408941268921, 44.21418081011091, 41.12202399117606, 39.01679972239903, 39.67275135857718, 42.355648858206614, 44.02652038846697, 45.620180061885286, 43.07252924782889, 41.23296935217721, 41.97647523880005, 44.279226371220176, 44.171359062194824, 41.10544906343733, 34.46621254512242, 34.13120862415859, 34.241215978349956, 34.05177681786673, 32.13026291983468, 34.42740338189261, 34.398217473711284, 34.69525991167341, 33.940286023276194, 32.77899885177612, 32.55801139559065, 33.656233242579866, 34.7809624671936, 34.59836728232247, 35.22453546524048, 34.30904081889561, 34.80458286830357, 34.468759059906006, 42.18753024509975, 44.74027408872332, 50.59293631144932, 51.288068839481895, 43.03504024233137, 46.8771265574864, 45.3664596421378, 47.140046392168315, 42.07798147201538, 42.02688441957746, 40.604834829057964, 37.58419581821987, 40.473583357674734, 49.189963000161306, 46.08595602852957, 49.268543652125764, 37.5165307862418, 40.689147744859966, 49.06377329145159, 42.59276308332171, 39.2004371370588, 39.58067383084978, 45.03102493286133, 46.767883505140034, 52.996676036289756, 47.09413269587925, 48.60286801201956, 47.090634277888704, 46.45105259759085, 48.69826677867344, 46.58032035827637, 43.74095637457711, 44.35917581830706, 45.751810210091726, 36.294380869184224, 35.41584369114467, 34.447636536189485, 34.58689233234951, 35.59946720940726, 36.00514473233904, 34.86234671728951, 34.89134849820818, 35.529648235866, 36.155006953648154, 33.08413246699742, 34.655981745038716, 36.408689158303396, 35.01447057723999, 35.298759596688406, 40.88414546421596, 47.149548053741455, 45.46917833600725, 46.73895468030657, 46.74402339117867, 45.65051589693342, 46.4005183492388, 47.085353646959575, 43.392862047467915, 40.95169585091727, 41.841704504830496, 38.87600142615182, 39.230550629752024, 38.25167451586042, 35.8287091255188, 37.866091183253694, 35.94582448686872, 41.10121413639614, 42.02651963915144, 41.44671678543091, 42.65910448346819, 45.546539579119, 45.76706845419747, 49.466588156563894, 50.422594274793354, 52.493553502219065, 52.40618685313633, 58.627454485212056, 53.65414932795933, 59.51033428737095, 17.50148912838527, 0.6408688883696283, 0.12336089621697154, 0.11697062983044557, 6.7956396000725885, 52.901826177324565, 48.12028782708304, 45.08301830291748, 43.88604518345424, 56.37827396392822, 40.607725279671804, 39.9757970401219, 55.05333934511457, 36.71943344388689, 5.357174456119537, 0.04460010677576065, 0.058292624540627, 0.009274393902160227, 0.024896959574627023, 0.05121913106579866, 0.06415782017367226, 0.04581320186012557, 0.0247280891718609, 0.04048566719783204, 0.0862709643053157, 0.024124766367354562, 0.03019202294360314, 0.03054428779120956, 0.029719796497374773, 0.050833200703241994, 0.03244740888476372, 0.037685902789235115, 0.022388727736792395, 0.03313435095229319, 0.13111448873366627, 0.05225489102303982, 21.268515791211808, 57.18471315928868, 49.466820921216694, 49.269926343645366, 33.67039714540754, 37.21613236836025, 40.76535906110491, 34.08978693825858, 41.94950928006853, 60.8075282233102, 18.691481045314244, 0.11779927036591939, 0.1537808288953134, 0.8082985441599573, 1.6085043911423003, 5.483997319425855, 43.0150329044887, 51.92798055921282, 55.06202111925398, 50.042454855782644, 51.073682171957834, 48.03960534504482, 45.82795899254935, 38.77966465268816, 38.98894092014858, 39.79681144441877, 42.57458659580776, 44.69410330908639, 47.24854598726545, 47.152824129377095, 46.580275194985525, 43.60952772412981, 41.1890914780753, 41.195640155247276, 45.97615017209734, 45.484134333474294, 47.275070735386436, 45.93626056398664, 42.685716084071565, 44.071089608328684, 46.17622355052403, 45.33269487108503, 43.3329963684082, 36.05965335028512, 35.396822997501914, 36.4908481325422, 34.40908793040684, 33.737277030944824, 35.715606348855154, 35.56109230858939, 35.75889362607683, 34.46769251142229, 33.93056549344744, 34.061966351100374, 35.49988215310233, 36.92647933959961, 35.32542330878121, 36.04110860824585, 35.870776993887766, 35.705823285239084, 34.365752015795024, 41.98586572919573, 46.68940707615444, 52.09197194235665, 50.40714495522635, 45.736117703574045, 48.59642008372715, 47.35604851586478, 48.39715269633702, 44.50624486378261, 44.07094022205898, 43.114604064396445, 38.646082060677664, 42.504986490522114, 50.93986334119524, 47.809425422123496, 50.340727124895366, 38.93091303961617, 41.55027273723057, 49.98410388401577, 43.83038663864136, 40.638623918805806, 41.003925459725515, 45.85044683728899, 48.858092716761995, 53.462403365543906, 49.049671922411235, 49.563866410936626, 48.12525231497628, 48.18623317990984, 48.653641973223, 49.27375480106899, 45.337086132594514, 45.09032085963658, 47.52933658872332, 37.26891088485718, 36.84277786527361, 35.39464473724365, 36.19599437713623, 38.20295374734061, 37.18821450642177, 38.16618735449654, 36.820897987910676, 35.86570480891636, 37.48098380225045, 35.18166855403355, 36.27040263584682, 36.63729531424386, 37.02388613564627, 38.341365337371826, 42.375277519226074, 48.61132049560547, 48.9128097806658, 49.735823903764995, 48.123921734946116, 46.879471574510845, 48.04450729915074, 47.57930455889021, 44.67260210854666, 42.841578074863975, 42.8157377243042, 42.02681493759155, 41.23424782071795, 39.234691756112234, 39.274129731314524, 38.618101664951865, 38.517550809042795, 44.12425374984741, 43.64354610443115, 43.60178048270089, 43.93769114358084, 47.3125319480896, 47.99319832665579, 50.63838447843279, 54.11856344767979, 55.24418551581246, 53.918062755039756, 58.90177631378174, 58.58231898716518, 66.56083815438407, 22.478238855089458, 0.7512166500091553, 0.2774487893496241, 0.020240080443077853, 7.671360152108329, 57.00419895989554, 52.24650682721819, 48.240578515189036, 51.405472551073345, 62.064492089407786, 47.041646003723145, 47.76805932181222, 61.01165240151541, 44.48375007084438, 7.211335556847708, 0.07921083457767963, 0.027300076160047735, 0.05272218451968261, 0.028622927676354135, 0.03098532198263066, 0.046085535282535214, 0.03392602150727596, 0.04000724233420832, 0.037930596087660105, 0.04545180393116815, 0.1639427321829966, 0.10407788772135973, 0.06563155752207551, 0.20142127467053278, 0.18934769396271023, 0.07187402541083948, 0.12162683212331363, 0.23965759149619512, 0.18365527370146342, 0.2740020214446953, 0.22957401829106466, 27.405201264790126, 65.58504704066685, 57.22205972671509, 55.0317964553833, 40.52711575371878, 42.712643827710835, 34.89151872907366, 37.5877810886928, 48.720914431980674, 64.80916254861015, 20.961327246257238, 0.5690795034170151, 0.5637962126306125, 5.566962284701211, 3.190304900918688, 7.70375873361315, 44.20990071977888, 52.328283650534495, 55.65956967217581, 50.679111344473704, 51.36219917024885, 49.85250500270298, 46.226462500435964, 40.03056968961443, 40.48811204092843, 42.761590412684846, 43.872548307691304, 47.80635779244559, 48.57201453617641, 49.527336256844656, 49.408629758017405, 45.69176040376936, 43.48846231188093, 43.42036301749093, 46.97361271721976, 49.06329039164952, 50.500122274671284, 45.984977858407156, 43.02313450404576, 45.51789215632847, 48.15240240097046, 46.84277466365269, 45.82230315889631, 37.526567459106445, 37.731789452689036, 38.395113127572195, 37.88077967507498, 34.5508450780596, 37.62065996442522, 36.34099633353097, 39.12767212731497, 35.78240633010864, 34.06128542763846, 36.46995142527989, 37.7739372253418, 39.31314386640276, 37.854088170187815, 39.86555692127773, 37.229156766619, 37.231449672154014, 36.44299936294556, 45.56814500263759, 49.36821208681379, 52.778078760419575, 48.956982953207834, 47.20803451538086, 50.39851529257638, 48.89030109133039, 52.17910235268729, 46.557731764657156, 45.729454381125315, 45.914516176496235, 40.761798109327046, 44.50400059563773, 53.34667764391218, 48.61357518604824, 52.796383789607454, 40.01610006604876, 45.39338738577706, 51.42039728164673, 45.58021749768938, 43.36076831817627, 44.16964633124215, 48.832804747990195, 50.87547785895211, 54.97595030920846, 49.950022969927105, 51.8927184513637, 49.81462689808437, 50.58225345611572, 51.61521782193865, 50.594697679792134, 46.76265498570034, 48.126812185559956, 48.34155668531145, 38.97678852081299, 39.38841717583792, 37.65385498319353, 36.89004298618862, 39.21230466025216, 39.830711705344065, 39.41578960418701, 38.73159006663731, 38.03909437997, 40.37682621819632, 35.99338490622384, 38.520062582833425, 39.90268809454781, 39.66148138046265, 39.905394417899, 45.40366724559239, 51.76371124812535, 50.77510070800781, 51.25414425986153, 49.07822207042149, 47.35901192256382, 50.30358552932739, 51.09027099609375, 46.92768859863281, 45.190684114183696, 45.696103027888704, 44.022226401737754, 43.73300763538906, 41.29840053830828, 41.1576543535505, 42.426419734954834, 40.84275851930891, 46.30290310723441, 45.72510480880737, 46.1042297908238, 48.02526773725237, 49.85645505360195, 49.88740927832467, 52.87164667674473, 57.12476757594517, 58.04101610183716, 55.79261725289481, 62.45429992675781, 58.97685159955706, 62.20565169198172, 27.65115533556257, 1.5680796631744929, 0.8993512668779918, 0.14619726368359157, 8.53593579360417, 63.47355202266148, 58.76807907649449, 57.047413281032014, 58.53647477286202, 61.771493503025596, 48.06676932743618, 55.59075471333095, 70.15544700622559, 54.37850250516619, 10.349439944539752, 0.21078695782593318, 0.1320827039224761, 0.13472019668136323, 0.16956539904432638, 0.11625936228249754, 0.08655120605336768, 0.21478403120168618, 0.08096666607473578, 0.1800383563552584, 0.09764558609042849], [0.032097495160996914, 0.021589542406478097, 0.035061451473406384, 0.05569640706692423, 0.02027198176697961, 0.07421099500996725, 0.02484808978624642, 0.04095365958554404, 0.040252712555229664, 0.1978565773793629, 0.11553579968001161, 17.314804928643362, 46.53512927464077, 38.23120164871216, 32.640872137887136, 27.439004250935145, 23.323699133736746, 29.199832371303014, 34.658132212502615, 39.5373865536281, 55.272593225751606, 12.783724818910871, 0.06669880489685706, 0.054808767911578925, 0.3353938071855477, 2.3814876845904758, 7.40456235408783, 42.18005050931658, 52.88141236986433, 49.36707953044346, 48.31948225838797, 45.54443080084664, 39.4001908983503, 39.1474814414978, 40.66961635862078, 43.576714856284006, 45.49759299414498, 45.39895289284842, 47.55453423091343, 47.701710973467144, 46.32861144202096, 48.08015155792236, 45.901370184762136, 44.967591353825156, 42.13578353609358, 44.26412098748343, 44.15833813803536, 47.847824641636436, 43.07576363427298, 42.08536393301827, 40.86753232138497, 43.77644082478115, 45.00181818008423, 39.51109804425921, 33.556648186274934, 34.845646721976145, 33.50400168555123, 33.71538325718471, 34.72761419841221, 35.20377424785069, 32.96241044998169, 33.54255029133388, 32.98546804700579, 32.81289216450283, 33.302882603236604, 34.84188774653843, 34.997256415230886, 33.271601813180105, 34.953625202178955, 34.86328125, 34.29740606035505, 35.51091241836548, 39.68355580738613, 46.48091942923409, 42.702867712293354, 47.47871896198818, 50.725546155657085, 46.90853588921683, 48.90439551217215, 47.2793265070234, 45.45584126881191, 44.402570792606895, 42.67227826799665, 38.29915850503104, 40.99044248035976, 47.18945850644793, 45.682547092437744, 49.2815055165972, 39.077245576041086, 40.451126779828755, 49.6067784854344, 41.670004095349995, 40.627079486846924, 43.0217205456325, 47.37891156332833, 44.895583697727744, 51.21676989964077, 47.13550921848842, 45.66934551511492, 47.69145890644619, 45.042993204934255, 46.312008721487864, 47.08321360179356, 44.720669746398926, 45.92190211159842, 41.22902972357613, 33.97037867137364, 33.96521615982056, 34.39138739449637, 33.91031149455479, 35.38808216367449, 34.04095499856131, 34.425343241010395, 34.103454044886995, 35.06210742677961, 33.22287062236241, 34.78615277154105, 33.56266532625471, 35.59685468673706, 36.5307377406529, 36.7112797328404, 34.28579562050955, 38.1564598764692, 43.21819823128836, 47.3042323248727, 47.0412951196943, 47.50875949859619, 44.40882764543806, 44.41021033695766, 44.056237833840505, 45.16112300327846, 44.40587813513619, 43.91727386202131, 40.683314732142854, 38.426439080919536, 37.157413142068044, 35.289865902491975, 35.135848658425466, 40.872003487178254, 45.408364227839876, 42.592728342328755, 42.25632435934884, 44.76149041312081, 45.99909659794399, 51.22122369493757, 50.41144936425345, 52.48680680138724, 50.77979074205671, 54.9740742955889, 56.09207418986729, 65.32102939060756, 27.29097809110369, 0.4344277030655316, 0.1496929268219641, 0.09664853316332613, 2.990224574293409, 49.60891505650112, 50.35143429892403, 42.59346832547869, 33.67651850836617, 23.64940983908517, 34.43242345537458, 44.825490270342144, 52.02220855440412, 46.201758180345806, 8.563729456492833, 0.02918877499178052, 0.02272481800589178, 0.010178185583624457, 0.0339981938845345, 0.050927601887711456, 0.06137786220226969, 0.06404453875230891, 0.04556210658379963, 0.04627513832279614, 0.03954726005239146, 0.029919882903673818, 0.007935266875262772, 0.031198154669255018, 0.06670268611716372, 0.019471707387960384, 0.052539203981203694, 0.0204968194344214, 0.020261751155235937, 0.052755873783358505, 0.1466622773025717, 0.2093011968369995, 23.678977898189, 54.27257374354771, 43.55703060967581, 39.4475393976484, 30.563249588012695, 27.601199524743215, 27.588784830910818, 36.46747439248221, 43.47463887078421, 59.161506925310405, 14.50814003603799, 0.06333536109221832, 0.0182718691815223, 1.1709900051355362, 2.5315368558679308, 7.999708567346845, 43.25393629074097, 52.85338681084769, 52.48602512904576, 49.144685064043315, 47.896010398864746, 40.653260299137656, 40.25887359891619, 40.49600172042847, 43.686270577566965, 47.59903744288853, 46.84543929781233, 49.45341089793614, 48.89734309060233, 48.55823973246983, 49.703674588884624, 46.132950169699534, 46.55157218660627, 44.21863807950701, 45.18918330328805, 47.13802099227905, 48.685690539223806, 43.63514573233468, 42.6770030430385, 43.622701508658274, 46.818383012499126, 46.25695814405169, 41.48141261509487, 34.40635034016201, 35.819666045052664, 36.49358919688633, 34.292802878788535, 36.06017793927874, 37.62691681725638, 33.18715688160488, 34.616415228162495, 33.28819758551461, 33.76605646950858, 34.805385385240825, 35.550381660461426, 35.13815893445696, 36.503650188446045, 35.828337396894185, 35.91603408540998, 35.825436523982454, 36.56297390801566, 42.187078612191335, 48.722811290196006, 45.690367289951865, 49.35023362295968, 49.48789480754307, 50.020578452519004, 51.23719760349819, 48.70603139059884, 46.118543079921174, 45.95256798607962, 42.50951324190412, 40.75120905467442, 42.6004547391619, 48.966998781476704, 47.28517689023699, 49.984326226370676, 42.01999875477382, 43.48567261014666, 50.515446526663645, 45.3465530531747, 40.24426848547799, 45.26599563871111, 48.96932642800467, 47.52656773158482, 51.451848302568706, 47.08545786993844, 45.260829653058735, 48.57277536392212, 46.90581914356777, 46.904158524104524, 48.21061788286482, 47.07846450805664, 46.397040775844026, 43.425334453582764, 35.253568513052805, 34.913912773132324, 35.866847787584575, 35.680535316467285, 36.64096048900059, 36.10279471533639, 36.76919991629464, 35.69674893787929, 35.38969414574759, 35.007571016039165, 36.715980189187185, 35.52708087648664, 36.77309438160488, 37.97329493931362, 36.95735018593924, 34.685306617191856, 40.76291329520089, 46.722768851688926, 48.486565589904785, 48.39816018513271, 47.838041578020366, 46.37937845502581, 46.30469574247088, 47.955726691654746, 45.96843072346279, 46.27822310583932, 45.668681962149485, 42.896128382001606, 40.95626776559012, 39.61019672666277, 37.16824885777065, 37.687849044799805, 43.19468552725655, 47.28641019548689, 44.56084033421108, 45.02667188644409, 45.50813341140747, 48.59031956536429, 52.985451221466064, 53.73471021652222, 52.61858980996268, 55.64568369729178, 57.27812474114554, 58.752049582345144, 65.4220631463187, 34.71143184389387, 0.6412139641387122, 0.17563709323959692, 0.08739117812365294, 3.289815264088767, 51.74019506999424, 55.424963746752056, 47.13727406093052, 40.14998490469796, 28.863039289202007, 35.63895034790039, 52.19881091799055, 55.94456393378121, 54.930835655757356, 11.0205351795469, 0.04640243149229458, 0.05388483052541103, 0.05547815967085106, 0.06144806343529906, 0.0733108368835279, 0.09377606372748103, 0.022112791293433735, 0.05384658829176, 0.05943854805082083, 0.040815116305436404, 0.1615389133138316, 0.11798544680433613, 0.16022037049489363, 0.0966703344934753, 0.11851634617362704, 0.12014108470508031, 0.08454134461602994, 0.19601215635027203, 0.14763909631541797, 0.2539327197841236, 0.22900353318878583, 31.473001548222133, 63.34591361454555, 51.67234591075352, 46.21047816957746, 37.51819140570504, 31.519908836909703, 33.60241597039359, 45.10315070833479, 48.23491225923811, 65.29345893859863, 15.977891615458898, 0.2767606462751116, 0.3749872211899076, 3.1034895479679108, 7.678184151649475, 9.752459406852722, 46.51762676239014, 55.81701585224697, 54.62284633091518, 51.01956960133144, 49.52783652714321, 42.22295216151646, 42.9012839453561, 43.48192058290754, 47.127525738307405, 50.075427532196045, 50.227947439466206, 51.342573983328684, 51.368727002825054, 50.51955986022949, 52.367558343069895, 48.24179097584316, 49.326720918927876, 45.07973180498396, 47.57002523967198, 48.82931327819824, 50.63078662327358, 44.08265488488333, 43.74915177481515, 44.643002782549175, 47.53637163979666, 48.7168983731951, 43.24356957844326, 37.2575922693525, 38.683025632585796, 38.04971122741699, 36.089707783290315, 37.628997802734375, 38.22996834346226, 35.54081399100167, 36.21210030147007, 34.55857842309134, 34.88658898217337, 37.24516541617257, 37.698354721069336, 39.10763699667794, 36.94399227414812, 37.43388543810163, 38.07319613865444, 37.14283234732491, 38.91105161394392, 43.129723344530376, 49.65026031221662, 47.89337008340018, 50.447034563337056, 49.69627128328596, 49.94754941122872, 53.86229651314871, 50.82178912843977, 48.880851541246685, 49.31779943193708, 46.76499652862549, 41.97587769372122, 44.40046548843384, 52.14049468721662, 47.51291104725429, 52.78895616531372, 43.86100040163313, 45.7171664919172, 52.42667709078108, 46.84129122325352, 42.733703817640034, 47.06369611195156, 50.64701761518206, 48.04050861086164, 54.72086456843785, 48.88316876547677, 46.97949436732701, 50.87338645117623, 48.190231868198936, 49.94905022212437, 50.920391014644075, 47.23580299104963, 49.289572375161306, 45.10059724535261, 36.71978085381644, 37.24011754989624, 37.261326926095144, 37.175183159964426, 39.35342257363455, 36.87024062020438, 37.39259229387556, 36.81402621950422, 36.66911806379046, 35.85566813605172, 38.38215126310076, 37.64748695918492, 39.002392632620676, 38.96542821611677, 40.09527478899275, 36.68933037349156, 42.70034899030413, 47.197560106004985, 49.96522910254342, 50.68654939106533, 51.356835160936626, 49.527892112731934, 48.38642120361328, 49.795081615448, 48.48199020113264, 47.95099496841431, 47.716795512608115, 46.17838791438511, 43.35484497887747, 41.982019901275635, 39.30979483468192, 39.239614554813926, 45.35509933744158, 51.02627461297171, 46.623906408037456, 48.85985061100551, 48.341087681906565, 50.404963220868794, 56.23866033554077, 55.68985339573452, 55.56421259471348, 58.034891264779226, 59.7125894001552, 61.48927157265799, 66.57389381953648, 40.4228823525565, 0.776949194925172, 0.3165439958018916, 0.17691309191286564, 3.349853128194809, 59.102982248578755, 59.12337521144322, 54.320307867867605, 42.943803446633474, 35.70418698447091, 46.0374367577689, 59.816180092947825, 63.487080165318076, 65.15496744428361, 14.619847093309675, 0.1755424647458962, 0.0773277370525258, 0.167014460212418, 0.10975573305040598, 0.13691789018256323, 0.21495705763144152, 0.11930207615452153, 0.17044813239148685, 0.11991137345986706, 0.09684580364929778], [0.019396410356940966, 0.007513220638169774, 0.050455372048808, 0.04620007538635816, 0.03404569472851498, 0.011275447106787136, 0.07699214720300265, 0.043591885162251334, 0.030453333564634835, 0.07503911985882691, 0.12096165067383222, 14.05602857044765, 51.90846654347011, 38.801558426448274, 38.88323450088501, 20.50537429537092, 17.561974934169225, 29.89171314239502, 32.48954732077462, 41.10971525737217, 58.563996587480815, 13.098411338669912, 0.11704936703400952, 0.05531033081933856, 0.28252499124833513, 0.9849700097526822, 13.616620148931231, 46.00535345077515, 48.4624970299857, 49.7725625038147, 45.59484345572335, 45.34908219746181, 44.278152874537874, 45.33480364935738, 45.40067604609898, 47.92792694909232, 48.45207473209926, 48.544669900621685, 47.09363589968, 46.082210949489046, 44.21655361992972, 44.39518485750471, 47.206676142556326, 45.11437552315848, 45.36898878642491, 47.19119208199637, 45.93154273714338, 44.23798186438424, 41.32606131689889, 40.20618193490164, 42.14516707829067, 45.827323232378276, 42.69757318496704, 35.08973693847656, 33.18364109311785, 32.024778842926025, 31.54416847229004, 33.66555425098964, 34.30852665219988, 34.726408685956685, 34.26565626689366, 33.494764055524556, 33.98880876813616, 32.462772437504356, 32.69513756888253, 32.935333320072715, 34.91904401779175, 33.10705804824829, 34.783613204956055, 34.708176612854004, 34.767569814409526, 33.16717038835798, 36.51512861251831, 46.46122128622872, 45.85749231066023, 39.571679387773784, 39.80166128703526, 46.11937338965279, 41.606101512908936, 45.980680397578645, 45.235472202301025, 44.77865593773978, 40.15051644189017, 40.99110950742449, 41.46192986624581, 46.43050330025809, 46.041084562029155, 50.01956401552473, 42.44903612136841, 43.12235477992466, 48.074408871786936, 42.14804015840803, 38.23545742034912, 45.388787678309846, 46.066938808986116, 47.784196513039724, 42.92208685193743, 37.82875503812517, 38.97553784506661, 42.780145577022004, 44.50220101220267, 44.80782100132534, 45.503231457301546, 43.512124402182444, 40.178135531289236, 34.18306303024292, 33.29905761991228, 33.49931165150234, 33.84846210479736, 33.627412114824565, 34.22540535245623, 34.44542700903756, 34.979941504342214, 35.407328673771445, 34.45004756110055, 32.9222811290196, 35.077306611197336, 36.56252922330584, 32.919435841696604, 34.16035284314837, 34.32804066794259, 34.67298398699079, 35.154702595302034, 37.038088253566194, 41.28511905670166, 45.48549270629883, 47.48696647371565, 47.438652174813406, 45.983365876334055, 44.4391565322876, 45.30851861408779, 44.76162242889404, 43.93724993297032, 41.87291233880179, 41.25487354823521, 36.12422295979091, 37.20411198479788, 35.68087230409895, 40.80912228993007, 43.888456208365305, 45.474882807050435, 42.91999544416155, 43.53545297895159, 42.58933414731707, 46.78974601200649, 46.119651317596436, 48.643987451280864, 46.997243540627615, 55.22441094262259, 54.379364081791465, 63.0651091166905, 33.085640226091655, 2.274168848991394, 0.023373965672882538, 0.1417926757463387, 1.95447267804827, 43.78022064481463, 54.365961006709504, 44.30637298311506, 33.016953808920725, 25.85746223585946, 36.47552040645054, 44.62255423409598, 56.16475234712873, 42.587958403996055, 7.7486788375037055, 0.041520175257963796, 0.048036812006362846, 0.047651546608124457, 0.052204394446952004, 0.043160021371607266, 0.039432424785835404, 0.01878427847155503, 0.09662883529173476, 0.07816072699746915, 0.03073478310502001, 0.04196054787774171, 0.07895529828965664, 0.06307882735771791, 0.0405121945243861, 0.023480268361579095, 0.017830305732786655, 0.06895529345742293, 0.04044206453753369, 0.02125393898625459, 0.13520852476358414, 0.12966995553246566, 20.722427334104264, 57.55359302248274, 44.571811539786204, 43.04367685317993, 26.536539213997976, 21.12142937523978, 32.928207942417686, 38.53796809060233, 44.77006449018206, 61.11336013248989, 13.718400835990906, 0.2091246691665479, 0.06446927453258208, 1.2028312108346393, 1.3111848937613624, 13.492138828550067, 46.04738310405186, 51.7521424974714, 51.55554321834019, 49.494217668260845, 47.2256759916033, 46.19769695826939, 47.88696037020002, 47.95919384275164, 48.92714044025966, 51.28658192498343, 50.9403531891959, 47.89726454871041, 47.473570346832275, 45.99422591073172, 46.26761668069022, 48.30783012935093, 46.19083561216082, 45.88554218837193, 47.52153723580496, 46.70375163214547, 46.40846014022827, 41.62221438544137, 41.78821727207729, 45.12349850790841, 47.30218260628836, 45.35864291872297, 36.75535563060215, 34.854745388031006, 35.25115401404244, 33.87181847436087, 35.33192682266235, 34.96760845184326, 36.25383465630667, 34.93851981844221, 34.34024517876761, 34.94230658667428, 33.9315173966544, 34.72855567932129, 33.74530914851597, 34.33931064605713, 34.779513767787385, 35.87214926310948, 35.844259193965364, 35.603761196136475, 35.21379007611956, 38.952355180467876, 48.76209293093, 47.09828771863665, 41.57445594242641, 41.99220248631069, 46.15555265971592, 43.1818904195513, 46.82051263536726, 47.31757286616734, 45.2563967023577, 42.962712969098774, 41.422738552093506, 42.73189728600638, 47.675971371786936, 48.1733512197222, 48.924062388283865, 42.235014234270366, 46.287818568093435, 49.62538228716169, 44.000815527779714, 40.55825410570417, 45.84269264766148, 47.38971601213728, 49.906864234379356, 45.618575028010774, 41.6978941644941, 38.694611753736226, 44.228580951690674, 46.134107044764924, 46.451674461364746, 46.85669885362898, 45.06788165228707, 42.80353668757847, 35.44963278089251, 35.90621280670166, 35.915999344417024, 34.87170941489083, 35.51375423158918, 37.31420619147164, 36.61765275682722, 36.010807514190674, 36.01711647851126, 36.18312978744507, 35.91907739639282, 35.604806900024414, 37.02406331471035, 36.44594887324742, 36.76179313659668, 37.50194999149868, 37.55529478618077, 36.69064705712454, 38.85425009046282, 44.181590284620015, 49.37564318520682, 48.47734880447388, 48.328917912074495, 47.07979161398751, 46.486814975738525, 47.341794286455425, 47.917059966496055, 46.70249400820051, 42.82401302882603, 41.769543988364084, 38.34183781487601, 39.29501254217965, 37.867946352277485, 41.897804260253906, 45.41094200951712, 45.97858551570347, 45.86068500791277, 44.622557708195274, 45.42851400375366, 48.013806683676584, 48.78558826446533, 50.665485927036826, 49.9026049886431, 56.9041622706822, 55.84712587084089, 64.00793102809361, 37.53407498768398, 2.496428042650223, 0.12067159052406039, 0.140736956681524, 1.9172346762248447, 47.560950892312185, 56.15015765598842, 47.84675809315273, 38.416527475629536, 33.29595177514212, 43.01855911527361, 52.69348096847534, 60.52404172079903, 51.75726679393223, 10.082372903823853, 0.0556276443281344, 0.027636556586782848, 0.026887131622061133, 0.060829490556248596, 0.052216085605323315, 0.05156824751091855, 0.04757869230317218, 0.020629530706043755, 0.05607426964810916, 0.022375257120334675, 0.12048071862331458, 0.15893720649182796, 0.16226995337222302, 0.1973185126802751, 0.17569886706769466, 0.05784728843718767, 0.15749233402311802, 0.12116810173860618, 0.0936490148305893, 0.32532684451767374, 0.34864744171500206, 26.181779827390397, 66.358749798366, 52.13357775551932, 50.69593988146101, 32.33403621401106, 25.70848069872175, 40.237587792532786, 43.209412234170095, 49.87729270117623, 68.04469544546944, 15.913297687258039, 0.3062664701470307, 0.26418288690703257, 2.9308800101280212, 3.987068295478821, 15.288411446980067, 50.33686392647879, 52.4139792578561, 54.46483734675816, 51.01097815377371, 49.49823720114571, 47.863096782139365, 50.64807721546718, 48.72792516435896, 51.12373699460711, 53.917183807918, 52.65641580309187, 49.315999848502024, 48.378184114183696, 47.180460589272634, 47.179185594831196, 49.22968585150582, 49.44299554824829, 47.672299248831614, 51.17011622020176, 49.15661859512329, 46.70754534857613, 42.06921284539359, 41.834825788225444, 46.399861744471956, 49.41794034412929, 46.044951234545024, 37.72296871457781, 36.481412478855674, 35.287062304360525, 35.299728870391846, 37.24814966746739, 36.84302800042288, 39.04194525309971, 36.3117652620588, 36.45893158231463, 36.72261571884155, 36.04170962742397, 34.77430261884417, 35.842383180345806, 37.11822182791573, 37.991401944841655, 38.00883844920567, 37.857715129852295, 37.67331688744681, 37.58250045776367, 41.590176241738455, 50.89932060241699, 48.34065341949463, 44.08711562837873, 42.84864091873169, 45.1460280418396, 43.96122816630772, 47.775434834616526, 49.32650205067226, 47.455921922411235, 44.27365044185093, 44.30233260563442, 45.958703245435444, 50.16167204720633, 50.610219955444336, 50.986867904663086, 45.91737536021641, 47.005383355276926, 50.93305063247681, 45.27380888802664, 41.29228612354824, 48.60351766858782, 49.908983434949604, 51.5616888999939, 47.810325213841026, 44.064822333199636, 40.59401995795113, 46.819453035082134, 47.210459436689106, 47.84997510910034, 49.4486722264971, 46.46157217025757, 43.1597569329398, 36.785635880061555, 38.00791086469378, 37.119990144457134, 38.5040956224714, 37.49620035716465, 38.143619605473106, 38.209624017987935, 37.25435788290841, 38.42101948601859, 38.7021609715053, 36.78253698348999, 37.73923444747925, 39.82593829291207, 36.443308557782856, 39.69828598839896, 39.29588801520211, 39.14810330527169, 38.84487697056362, 40.210479395730154, 45.1604768208095, 51.23561341421944, 51.565479142325266, 51.65855026245117, 49.01638657706124, 48.203652313777376, 50.92004707881382, 50.77481583186558, 49.71008430208479, 46.2544845853533, 44.83294568743025, 40.26211493355887, 40.495664732796804, 39.72433825901577, 44.6426796913147, 47.69472803388323, 49.368583815438406, 48.17295517240252, 47.395896434783936, 48.7938357761928, 50.6828737940107, 52.27227769579206, 51.59571075439453, 52.32044955662319, 59.68904195513044, 59.278028215680806, 65.91382190159389, 41.710845606667654, 2.9967408989156996, 0.1932614975209747, 0.2420648437525545, 2.139448706592832, 53.60695021493094, 61.38060174669538, 56.71304164613996, 45.52424280984061, 39.09877109527588, 48.6022287777492, 60.23616395677839, 68.40725244794572, 62.24666690826416, 14.601797410420009, 0.19513102434575558, 0.11719640557255064, 0.10597308352589607, 0.14783239737153053, 0.17581714929214545, 0.12733173742890358, 0.15339449819709572, 0.17687256980155194, 0.14918877530310834, 0.09072939399629831], [0.03763504998226251, 0.05366322438099554, 0.012845629726403525, 0.01727313518391124, 0.02358340229173856, 0.05717454132224832, 0.10130987875163555, 0.0678164538528238, 0.07990012437637363, 0.06522729314331498, 0.04889861594087311, 19.671864918300084, 49.888625213078086, 46.06846046447754, 35.85152006149292, 18.707177025931223, 13.372201630047389, 20.013754504067556, 33.63485363551548, 41.42345074244908, 54.6066118649074, 11.283270018441335, 0.07431026468319551, 0.1109776660533888, 0.8365429171494075, 2.986960223742894, 16.84516055243356, 43.685516698019846, 52.94114603315081, 49.13783414023263, 49.51755666732788, 50.68119927815029, 47.15479394367763, 48.60644980839321, 49.98820332118443, 49.47039576939174, 47.333769117082866, 46.794036524636404, 44.30376740864345, 43.105866704668315, 43.90372487476894, 42.07839141573225, 41.550859860011506, 43.99571902411324, 44.47354316711426, 45.69446325302124, 43.66600963047573, 43.121739864349365, 43.90015002659389, 41.514628478458945, 43.294246264866416, 45.978998933519634, 38.11960663114275, 34.70226716995239, 34.18977846418108, 32.99830484390259, 33.87083877835955, 32.21470437731062, 32.843717847551616, 35.354883670806885, 33.55118342808315, 34.192029680524556, 33.03487321308681, 33.055019514901296, 33.22262396131243, 34.027736050742014, 33.590975761413574, 34.183872495378765, 33.33887774603707, 33.67070286614554, 34.46127585002354, 33.51089777265276, 32.790817737579346, 43.45153611046927, 45.68958561761038, 48.81300238200596, 39.623995849064414, 42.288900988442556, 47.343038014003206, 45.957733971732004, 46.68106576374599, 43.102976254054475, 43.20599372046334, 40.26212535585676, 39.2948214667184, 41.97983121871948, 45.747915744781494, 49.02208757400513, 45.29266282490322, 44.08471155166626, 47.93402051925659, 42.173536573137554, 38.94239146368844, 42.030323777879985, 45.94094712393624, 44.7092399597168, 48.396885190691265, 47.53742776598249, 45.27718571254185, 43.441621031079976, 45.01338345663888, 43.314260550907676, 44.64542075565883, 40.916989598955425, 39.42364454269409, 36.50976460320609, 33.83230059487479, 32.91035107203892, 33.781498840876985, 34.146897656576975, 33.29528474807739, 35.321209226335796, 33.51413563319615, 33.731197357177734, 34.54405321393694, 33.830928325653076, 35.60000222069876, 34.947382245744976, 34.70473378045218, 35.97018487112862, 35.142383439200266, 34.691292490277974, 35.06667586735317, 35.73237582615444, 34.79415709631783, 37.2791942187718, 42.10863692419869, 42.87333481652396, 45.120368344443186, 46.323775495801655, 46.36715657370431, 45.42884751728603, 44.00261163711548, 41.045524324689595, 41.3924617767334, 39.132852009364534, 37.21603856767927, 36.07140275410244, 38.886573110307964, 45.25128282819475, 45.051105226789204, 43.54068497249058, 42.44543695449829, 43.21963998249599, 43.718374729156494, 41.02870968409947, 46.19444867542812, 48.540914399283274, 53.025316510881694, 53.05961629322597, 61.38545853751046, 29.627410616193497, 0.9533921842064176, 0.08495717123150826, 0.08622257797313587, 1.2728509221758162, 42.66285303660801, 54.936571393694194, 41.662044933864046, 28.355494226728165, 17.769024303981237, 25.520500659942627, 36.694260120391846, 49.244919776916504, 44.361934253147666, 8.18636063167027, 0.04806024860590696, 0.04702598821105702, 0.01465674995311669, 0.048553736946944676, 0.04964842767055545, 0.042358098152492724, 0.04525843502155372, 0.08306743763387203, 0.013603102964615183, 0.07250576186925173, 0.009412670857273042, 0.04157927565808807, 0.01278334784521056, 0.010491580552687603, 0.026826073648408055, 0.05708438437432051, 0.07559170520731381, 0.02650539799859481, 0.057594758059297285, 0.05320301478994744, 0.1296693312802485, 22.613984073911393, 55.7865514755249, 51.97776787621634, 42.375868116106304, 25.353578874043055, 17.76682346207755, 20.073651450020925, 38.623677594321116, 45.141633306230815, 57.90481056485857, 13.106849925858633, 0.16514445841312408, 0.1951866913586855, 1.0159310741083962, 3.1572977006435394, 19.959626299994333, 46.30763830457415, 54.82878398895264, 51.20851196561541, 51.61146926879883, 51.647686753954204, 49.28318003245762, 49.58980056217739, 51.43900108337402, 51.26223891122, 48.84580830165318, 47.64335652760097, 44.34007174628121, 43.70973464420864, 43.64762469700405, 40.984974248068674, 42.25176286697388, 45.412960461207796, 46.09494699750628, 46.850049427577424, 44.6690411567688, 42.0984856060573, 43.78942700794765, 42.16621317182268, 45.47700548171997, 46.80839845112392, 39.50323268345424, 35.65602554593767, 34.583477292742046, 35.22002261025565, 35.15235757827759, 33.69076231547764, 34.485153334481375, 35.596274512154714, 35.32524960381644, 35.30266448429653, 34.24367216655186, 33.71653665815081, 34.5500043460301, 35.5160436630249, 35.02709545407976, 34.26697642462594, 35.01885836465018, 33.58373573848179, 34.375392641339985, 35.63500377110073, 34.98448215212141, 45.50498240334647, 47.123829296657014, 48.61853619984218, 40.188794067927766, 43.14180278778076, 45.831516470227925, 46.28908314023699, 47.30649743761335, 45.31874983651297, 42.89571843828474, 41.14703055790493, 40.653149127960205, 44.35148416246687, 46.511665207999094, 52.263411794389995, 46.54791743414742, 45.95930426461356, 50.281024728502544, 44.68927083696638, 41.3002279145377, 45.14600372314453, 47.92827435902187, 48.606710365840364, 49.68682173320225, 49.33548607145037, 46.935477529253276, 43.88181720461164, 46.11826862607683, 44.93451445443289, 46.375789710453574, 41.546871594020296, 40.313469069344656, 37.692222935812815, 35.901543617248535, 35.86157063075474, 35.20183917454311, 35.64663505554199, 35.98655482700893, 36.80699464253017, 35.004878589085166, 35.75980731419155, 35.954968316214426, 35.919928550720215, 37.761100428445, 37.312528201511924, 37.36882945469448, 37.02107211521694, 37.14534412111555, 36.86141988209316, 36.31906434467861, 35.60600199018206, 37.216761180332725, 39.105027948107036, 43.9017515863691, 45.93194920676095, 47.14583076749529, 46.84671776635306, 48.72154671805245, 47.695839745657786, 45.9061644417899, 43.7695586340768, 41.70378623689924, 40.887491021837505, 39.82738699231829, 38.429190567561555, 40.96385172435215, 47.97079733439854, 47.057939529418945, 46.51432984215872, 45.08848306110927, 45.40821484157017, 45.571876185280935, 43.436191013881135, 46.41330303464617, 51.235974720546174, 55.51145492281233, 56.66568272454398, 63.084904534476145, 34.089595862797324, 1.0126645522458213, 0.06873645234320845, 0.07225265473659549, 1.20945306122303, 45.792370319366455, 59.8557014465332, 47.69610725130354, 37.12526035308838, 22.155689580099924, 29.99219799041748, 42.912196091243196, 54.112275327954976, 53.57626696995327, 11.159004092216492, 0.17620974965393543, 0.02483481594494411, 0.05218572455591389, 0.022569725256679312, 0.07616961348269667, 0.014379685445289527, 0.032933273884866915, 0.04770350881985255, 0.02643498302703457, 0.04795724020472594, 0.15932720127914632, 0.12213643906371933, 0.10063903153474842, 0.1424903590232134, 0.13509706860142096, 0.11154388995575053, 0.2070047493491854, 0.1787507954452719, 0.16596212025199616, 0.1490808203816414, 0.2301355738724981, 26.642758062907628, 64.45604119982038, 58.340174266270225, 49.02201114382063, 28.64898787225996, 21.25205029760088, 28.409116949353898, 43.75605133601597, 50.05759845461164, 63.174265316554475, 14.573975086212158, 0.3103367031684944, 0.37039332198245184, 2.9750827125140598, 5.282452659947531, 19.8176554952349, 47.816842624119346, 56.64620344979422, 54.24673686708723, 54.861239024571006, 55.21008375712803, 51.50331013543265, 52.74215657370431, 53.075902870723176, 53.66218491962978, 49.55761303220476, 49.124670778002056, 45.48768833705357, 44.854217597416465, 44.20382104601179, 43.01701314108712, 42.80583306721279, 46.65603835242135, 46.57955258233206, 48.610983507973806, 44.149604252406526, 42.15103135790144, 44.226850850241526, 45.34280450003487, 47.741551944187705, 49.18602337156023, 42.813555989946636, 37.493612153189524, 37.303123814719065, 35.65550095694405, 37.68229396002633, 35.34837320872715, 36.24665369306292, 38.40714045933315, 36.50293452399117, 36.82536915370396, 36.14428588322231, 36.06371457236153, 35.167070388793945, 37.62973083768572, 37.10273429325649, 36.60356528418404, 37.349513462611604, 35.87187828336443, 37.34616443089077, 37.3017133304051, 37.270665305001394, 46.10148525238037, 49.045016629355295, 50.28092745372227, 42.99912847791399, 43.343707016536165, 46.42242949349539, 49.048129422324045, 50.938553605760845, 47.947434016636436, 45.612179211207796, 44.055939061301096, 42.84203665597098, 46.00588151386806, 48.430844511304585, 54.17419419969831, 47.48340204783848, 48.20523302895682, 52.30538933617728, 48.90735197067261, 42.743882928575786, 46.13145630700247, 49.95331989015852, 50.89074305125645, 50.408631869724815, 51.61823334012713, 48.2383759362357, 45.70249884469168, 47.908923625946045, 45.840785367148264, 47.463175841740195, 43.33529622214181, 42.230741092136924, 40.5328688621521, 38.303497655051096, 37.73339796066284, 37.69550943374634, 37.88493122373308, 36.81435278483799, 38.85774156025478, 36.60405165808541, 37.47793006896973, 37.13741970062256, 37.888474805014475, 39.36986895969936, 40.29405232838222, 38.69115849903652, 38.12297650745937, 38.501615115574424, 39.018845966884065, 39.3288711139134, 38.95936243874686, 38.8463499886649, 41.1349823815482, 45.84894950049264, 46.7999598639352, 48.84523507526943, 49.51152910505022, 50.78619698115757, 50.3952704838344, 48.01218775340489, 46.03081859861101, 45.20977776391165, 43.60169015611921, 42.80429056712559, 41.282242502485005, 43.02653564725603, 51.02086544036865, 50.07065759386335, 48.3375996862139, 46.9642083304269, 48.395231519426616, 48.812790461948936, 45.0096001625061, 49.72303227015904, 53.350377559661865, 58.58038738795689, 60.114716393607004, 65.51557895115444, 38.0640801021031, 1.1050637598548616, 0.17730516301734106, 0.2248084225824901, 1.6063710770436694, 51.780355657849995, 64.05975764138358, 55.07517058508736, 39.50888156890869, 26.491176162447246, 37.04171173913138, 51.52631562096732, 60.93502766745431, 62.96672262464251, 16.20152633530753, 0.35664508970720427, 0.1499069639082466, 0.11205487432224409, 0.17076484539679118, 0.21683594823947974, 0.08942037780902215, 0.09779971531991448, 0.14992170168885163, 0.10165926321808781, 0.18155492283403873], [0.01994624424592725, 0.02966372236343367, 0.025696699607319066, 0.029343925416469574, 0.05937846377491951, 0.054221984398152144, 0.14211972962532723, 0.03434879292867013, 0.02812018072498696, 0.02013772682818983, 0.12138698356492178, 19.066791466304235, 49.80603197642735, 44.89793913705008, 38.00096961430141, 20.847654717309133, 17.954390083040508, 31.053174018859863, 31.893853936876567, 43.06288167408535, 51.15471206392561, 9.725457838603429, 0.17211375944316387, 0.2428435848227569, 0.2087820496942316, 2.143250891140529, 20.823999575206212, 45.756197997501914, 52.59219012941633, 53.466982228415354, 50.499847820826936, 48.857269355228965, 49.60676111493792, 49.87261308942522, 48.02200208391462, 48.03633621760777, 47.88337162562779, 48.84804214750017, 46.52754878997803, 48.28945214407784, 47.53631605420794, 47.81676966803414, 45.96606486184256, 44.04455443790981, 42.36812087467739, 43.61660099029541, 41.3953070640564, 44.13868863242013, 43.14498158863613, 44.0448636327471, 46.33993353162493, 40.24525165557861, 33.26690830503191, 33.72160884312221, 32.94814232417515, 34.900947434561594, 34.019863741738455, 33.78635563169207, 33.67162350245884, 33.81912681034633, 33.193378993443076, 33.25149720055716, 31.97704471860613, 33.30596760341099, 33.705318791525706, 36.2133857182094, 34.22845213753836, 33.764392375946045, 33.51400361742292, 32.33626658575875, 33.702119146074565, 33.91340691702706, 33.071483271462576, 38.999338899339946, 45.78632886069161, 45.47367034639631, 47.268518584115164, 42.00686318533761, 44.51304367610386, 46.26965250287737, 47.09392772402082, 45.56877728870937, 40.92635229655674, 38.91334104537964, 37.79366316114153, 40.40239211491176, 44.17916883741106, 47.564716815948486, 46.235192911965505, 44.866918904440745, 47.98585408074515, 44.48421212605068, 43.44929879052298, 40.431984492710654, 41.709730420793804, 43.44293424061367, 46.283625330243794, 46.81802865437099, 47.387277194431846, 47.17657307216099, 46.152415548052105, 44.32545621054513, 44.890080724443706, 48.25786215918404, 45.02057484218052, 37.16826622826712, 34.22182355608259, 33.63225500924246, 32.76721818106515, 35.60439000810896, 35.31231900623867, 35.870422635759624, 34.71499279567173, 34.65013831002371, 34.21258592605591, 33.47023344039917, 34.43455307824271, 34.667178767068044, 35.357259954724995, 35.57910898753575, 35.90529217038836, 36.42460053307669, 35.124794074467246, 36.36958122253418, 35.35303544998169, 33.736446721213206, 34.351063523973735, 36.28649466378348, 40.40892342158726, 40.34677178519112, 42.89288704735892, 41.437520844595774, 39.931564807891846, 39.25073514665876, 39.202389580862864, 37.54814856392996, 37.73810189110892, 37.654852049691335, 38.54948125566755, 40.574050835200715, 44.70574154172625, 44.69885240282331, 42.4155319077628, 42.053725310734336, 41.61192410332816, 43.968572412218364, 52.54715538024902, 53.743489265441895, 56.74566343852452, 54.652271951947895, 62.10256821768624, 29.561475685664586, 0.15285020454653672, 0.4425593481532165, 0.0851135328412056, 0.9050860277244023, 40.72854750497, 54.994891098567415, 44.17315517153059, 33.23783704212734, 21.952263695853098, 24.565915448325022, 41.43993534360613, 44.007617814200266, 47.98111540930611, 12.357391170092992, 0.08484853098967246, 0.022261169938636676, 0.05630431676815663, 0.022152911372748867, 0.021695081743278673, 0.051765945473951955, 0.04156714005927954, 0.022345472825691104, 0.055723124383283515, 0.06686972786805459, 0.031817613036504815, 0.06264910434505769, 0.027708198010389293, 0.022800539121297852, 0.026914722552256923, 0.06881493848881551, 0.029063130662377392, 0.026150661587182964, 0.08361462862896067, 0.026513835581551706, 0.24472665520651, 23.46486394745963, 57.08507251739502, 50.62258080073765, 43.76307943889073, 23.28541282245091, 20.001713275909424, 29.07201157297407, 36.455492224012104, 48.8466386113848, 55.83841282980782, 10.963686755725316, 0.20083065064890043, 0.10386773185538394, 0.7106016065393175, 3.1956940974508012, 21.220050368990215, 47.59428487505232, 52.491760866982595, 55.801104477473665, 52.52894762584141, 51.23371308190482, 50.50805711746216, 50.270418303353445, 48.97025053841727, 50.001550810677664, 47.502916063581196, 49.40818507330758, 47.53702129636492, 49.91286052976336, 47.09535557883126, 48.86754921504429, 45.37648589270455, 44.13349485397339, 43.2459944997515, 42.25361456189837, 40.91533245359148, 44.35646949495588, 43.884134428841726, 47.023938519614084, 46.817868845803396, 42.10843195234026, 35.12034027917044, 34.7728157043457, 34.89507620675223, 35.113107204437256, 36.084006786346436, 36.06160579408918, 34.712154456547324, 35.307875633239746, 34.395250592912944, 34.49022204535348, 34.12995794841221, 34.39780405589512, 35.023392064230784, 36.75730460030692, 34.85307087217058, 35.925699029650005, 35.62589815684727, 34.69102498463222, 35.41938379832676, 35.63516705376761, 34.60293919699532, 40.810862813677105, 47.30413852419172, 47.78488091060093, 47.99568230765206, 45.41648319789341, 46.610597133636475, 48.41217817578997, 47.757459844861714, 46.2820063999721, 42.521887983594624, 42.09663738523211, 39.86428540093558, 42.42924765178135, 46.569828578404014, 49.4556690624782, 47.58591576984951, 46.17392717088972, 49.28434385572161, 44.71343667166573, 42.760218143463135, 43.22375679016113, 43.58496931621006, 46.228762354169575, 48.59301199231829, 48.8280348096575, 48.510522978646414, 47.06814643314907, 48.69823203768049, 45.76178434916905, 47.29510586602347, 48.7226619039263, 44.313491412571494, 38.18199450629098, 35.361220427921836, 35.84710100718907, 34.70023829596383, 35.848393372126985, 35.76004007884434, 37.65524809701102, 36.40472521100725, 37.047840050288606, 35.56297527040754, 35.02205106190273, 36.21328844342913, 35.426967757088796, 37.03330441883632, 36.5577175957816, 36.94622611999512, 36.63299437931606, 36.967515400477815, 37.621382577078684, 37.62118802751814, 35.87281281607491, 36.949439661843435, 39.187767096928184, 41.61223677226475, 43.46417488370623, 44.7570400919233, 43.674479484558105, 41.2500376020159, 42.93553161621094, 41.897967542920796, 39.129680156707764, 40.45817920139858, 38.95462376730782, 40.36702925818307, 43.44936827250889, 47.602660928453716, 46.019896030426025, 44.80377714974539, 43.787165369306294, 43.64938606534685, 46.391492639269146, 55.484072072165354, 57.459861823490684, 59.924836022513254, 57.82810245241438, 62.95213140760149, 30.94126980645316, 0.3871798440814018, 0.473488412797451, 0.05992705255214657, 0.7048868760466576, 44.389289311000276, 58.92956910814558, 50.16475009918213, 37.130718163081575, 29.299004009791783, 31.13917187282017, 46.86862196241106, 52.6779135295323, 57.0138395854405, 17.085342407226562, 0.09123402727501732, 0.08276794584734098, 0.07784397328006369, 0.02978767714064036, 0.06129919285220759, 0.04215535528159567, 0.024296126993639127, 0.04277856594749859, 0.04347270048622574, 0.014542784907722046, 0.1588044443300792, 0.18312958548111574, 0.10323119136903967, 0.11367256287485361, 0.21685428225568362, 0.11422854768378393, 0.2167891836059945, 0.14539824798703194, 0.09691797941923141, 0.1699590850621462, 0.28008476219006945, 28.31196549960545, 65.243834904262, 54.153116839272634, 50.6012533051627, 30.31448323386056, 25.438086339405604, 41.283406325748985, 42.62913690294538, 53.264633314950125, 60.28820596422468, 12.0670485326222, 0.2750047333538532, 0.3431322548006262, 1.771967494062015, 3.5266587265900204, 23.253951379231044, 47.46973494121006, 54.13948794773647, 57.29889638083321, 55.301824297223774, 51.276649475097656, 51.857049873897004, 52.243105684007915, 50.86025435583932, 51.56967238017491, 49.55769641058785, 50.90790510177612, 49.7667190687997, 53.170426164354595, 49.54274388722011, 50.363888944898335, 47.58512714930943, 44.452170508248464, 44.140050479343955, 43.65106405530657, 42.546300479343955, 45.9156938961574, 46.47312355041504, 48.904398986271445, 49.74632610593523, 43.79753902980259, 36.96498973029, 36.89918681553432, 37.48527431488037, 37.41873836517334, 38.64498771939959, 37.93585457120623, 36.516024930136545, 36.794453144073486, 36.45553043910435, 35.85254144668579, 35.11681406838553, 35.93714966092791, 37.442073890141074, 39.001541478293284, 37.353682381766184, 37.74627644675118, 37.32081045423235, 36.143601485661094, 37.38173573357718, 37.88931553704398, 37.01589570726667, 43.46468210220337, 49.715663705553325, 50.108091013772146, 50.12633350917271, 46.27055924279349, 48.872767312186106, 49.713881492614746, 50.20749889101301, 48.519632066999165, 44.086653573172434, 43.78737381526402, 42.36836406162807, 44.494710854121614, 47.793448039463584, 51.450097356523784, 49.85438796452114, 49.2968749318804, 50.03101464680263, 47.61185686928885, 47.302391052246094, 44.90859419958932, 46.78177990232195, 46.49363463265555, 52.20014844621931, 51.930481910705566, 50.75249474389212, 48.707136154174805, 50.63851996830532, 47.322766644614084, 49.557880537850515, 49.95604705810547, 46.80313866479056, 40.96105854851859, 36.82906559535435, 37.87985903876168, 35.77866472516741, 38.56171008518764, 37.75874151502337, 40.24326794488089, 37.72044651848929, 39.731547015053884, 38.14220217296055, 36.57179812022618, 37.04436942509243, 37.69902522223336, 37.566578660692485, 39.2317978313991, 39.845299448285786, 39.75329140254429, 39.77108573913574, 40.288299219948904, 39.31323766708374, 37.7585643359593, 38.31187718255179, 40.821959086826865, 43.65691443852016, 44.56713192803519, 47.21927670070103, 46.246497631073, 42.9980480330331, 43.94732829502651, 43.613199847085134, 42.039095878601074, 41.646807534354075, 42.27674164090838, 42.04947648729597, 45.157489095415386, 48.949927057538716, 48.255548409053254, 47.290137904030935, 47.434493677956716, 46.360493251255576, 50.16265174320766, 57.24811894553048, 60.29029042380196, 61.6666590826852, 59.940031732831685, 64.81652763911656, 34.74308783667428, 0.8661249269332204, 0.9681010863610676, 0.14658914479826177, 1.182040355035237, 49.21413230895996, 64.11803218296596, 56.63315125874111, 43.7416581426348, 33.05308096749442, 35.36453819274902, 53.255235876355854, 59.3100038255964, 65.90736702510289, 23.128779581614904, 0.2683977835944721, 0.20118888999734605, 0.22506025406931127, 0.10122364373611552, 0.16921830124088696, 0.17320492517735275, 0.10341233986296824, 0.16517128768776143, 0.12089075733508382, 0.1530408457453762], [0.016007680944832306, 0.021422653325966427, 0.025590861715110283, 0.09360800417406218, 0.02636765199713409, 0.053927008262170215, 0.009307728631288877, 0.024581664707511663, 0.044798822541322024, 0.07758064741002661, 0.15075967886618205, 15.669711215155465, 45.819853918892996, 44.333867004939485, 35.73037127086094, 25.350943769727433, 24.302722896848405, 18.441106183188303, 33.09762239456177, 41.136986936841694, 52.115557602473665, 12.085898995399475, 0.1552257285054241, 0.08804528588163, 0.7248507333653313, 4.26746415240424, 24.771516118730815, 44.01730012893677, 48.6463428906032, 48.143564292362754, 50.14975936072213, 48.84684705734253, 48.15662343161446, 50.65488992418562, 48.12915372848511, 47.830805029187886, 47.922566413879395, 45.43333952767508, 46.38265800476074, 47.10140398570469, 46.11598266874041, 46.033135822841096, 47.60868501663208, 46.132686138153076, 45.69653729030064, 44.62365204947335, 45.914658614567344, 44.90382078715733, 44.21508060182844, 44.44557319368635, 39.825361592429026, 32.83145775113787, 32.74091230119978, 33.82081522260393, 36.237801688058035, 34.642707211630686, 33.15121732439314, 32.917094298771445, 34.05578245435442, 33.18666703360421, 32.225498403821675, 32.428403173174175, 33.46433441979544, 33.331123556409565, 32.56969826562064, 33.362987995147705, 33.85455567496163, 33.00986664635794, 34.46973875590733, 32.45179775782994, 33.195213317871094, 32.801809787750244, 32.18361118861607, 33.284129415239605, 39.42676428386143, 44.96580566678728, 42.625836508614675, 44.82442372185843, 44.897678579602925, 48.12780925205776, 47.72143690926688, 43.8077563558306, 40.78142329624721, 39.43812806265694, 36.61528689520699, 40.115844930921284, 44.08386387143816, 46.94515289579119, 46.82860728672573, 44.56490503038679, 46.9896491595677, 45.78354263305664, 45.252029759543284, 46.67948852266584, 41.52941771915981, 39.03974962234497, 43.85196426936558, 46.927195276532856, 47.39975963320051, 48.701518535614014, 47.688849857875276, 45.09739759990147, 44.64797421864101, 45.518305574144634, 48.655986990247456, 40.55186523709978, 35.52135556084769, 34.35548257827759, 33.51184967585972, 32.78620760781424, 34.90334456307547, 34.114560740334646, 34.98071622848511, 33.671651295253206, 34.762758186885286, 33.04247106824602, 33.511801038469585, 34.7328531401498, 35.45777606964111, 34.755118642534526, 35.920004980904714, 37.24379662105015, 34.85232394082205, 36.04623637880598, 34.98178277696882, 34.76468978609358, 35.169745445251465, 34.036886828286306, 35.56289536612374, 35.86482238769531, 36.52458163670131, 35.566185338156565, 38.410402638571604, 37.737327166966026, 36.421824727739605, 38.806522914341514, 38.78041158403669, 37.89691686630249, 38.41595424924578, 39.18746485028948, 44.584537165505544, 42.16732488359724, 43.10046795436314, 41.14885793413435, 42.421285016196116, 49.103412764413015, 54.19051204408918, 55.78345605305263, 59.125035830906455, 53.96980946404593, 57.1285890851702, 29.67752797263009, 0.23710515988724573, 0.29785307017820223, 0.0693341399143849, 0.3344826160797051, 36.96693522589547, 57.743883337293354, 46.36020490101406, 42.46959931509835, 20.984978914260864, 20.07062724658421, 35.767898491450715, 45.7264666557312, 49.224888120378765, 14.490095564297267, 0.09387867179300104, 0.07420283223369292, 0.018260956642084887, 0.059031990223697255, 0.03998727644128459, 0.03979821622903858, 0.08868554473987647, 0.018554684273632507, 0.0036722251596594496, 0.023823481552036743, 0.026102495778884207, 0.02853157989946859, 0.02112393676569419, 0.03704826986151082, 0.027549257967621088, 0.006856712562564228, 0.03398771730384656, 0.04275599787277835, 0.042421595459537845, 0.08611518623573439, 0.18142312419201645, 19.755132130214147, 55.27753339494978, 50.08781964438302, 41.769689900534495, 28.927223273686, 27.836620126451763, 25.535995142800466, 34.842162200382774, 46.31758465085711, 56.96655361992972, 12.913423367909022, 0.15814646892249584, 0.1082401911595038, 0.5054448608841214, 5.024004425321307, 24.52992377962385, 44.91204398018973, 49.07750293186733, 48.85644251959664, 52.371984345572336, 50.59277650288173, 50.9517308643886, 51.35183940614973, 48.83235658918108, 49.96945708138602, 49.04515559332711, 48.39564841134207, 48.98255579812186, 49.05229139328003, 47.616460050855366, 49.007079465048655, 48.193355083465576, 48.742054326193674, 47.096981457301546, 46.02370016915457, 46.69847794941494, 47.18563004902431, 45.43366609300886, 45.25367995670864, 41.37423317773001, 35.99465990066528, 33.29303353173392, 35.7696077483041, 37.275998047419954, 36.71314879826137, 35.71214962005615, 33.579750946589876, 35.217698437826975, 35.325753348214285, 33.10071781703404, 34.36556788853237, 34.30573695046561, 34.104433740888325, 34.407017367226736, 36.617305346897666, 34.539314542497905, 35.51554339272635, 34.49726751872471, 34.95103005000523, 35.01479366847447, 34.24340466090611, 35.16519437517439, 36.54216752733503, 41.768866539001465, 47.5130534853254, 44.456742422921316, 46.525721413748606, 46.96064043045044, 48.43132741110665, 49.39291293280465, 44.793660572596956, 43.3147052356175, 41.57019669669015, 39.25525842394148, 40.67322594778878, 45.624477522713796, 48.22535848617554, 47.900047302246094, 47.48019892828805, 49.062515667506624, 47.430734702519004, 47.857909951891216, 47.68608794893537, 42.54770401545933, 41.63192449297224, 45.906591756003245, 48.28193766730172, 49.49691356931414, 49.57779407501221, 49.98078611918858, 46.56126839773995, 45.32017074312483, 48.853677136557444, 49.32890612738473, 43.06237098148891, 36.83611454282488, 35.47690098626273, 35.79505899974278, 35.092352935246055, 35.96469579424177, 35.66648258481707, 37.35287291663033, 36.53279440743582, 35.3826139313834, 33.82656485693795, 36.15777233668736, 35.15021753311157, 36.79217413493565, 35.81181458064488, 36.38559682028634, 39.72697162628174, 37.040961333683555, 37.82236269542149, 37.13180903026036, 36.81882742473057, 36.00372729982649, 35.14258146286011, 38.86683675221035, 37.49629763194493, 38.20621592657906, 36.87517384120396, 40.167046206338064, 39.38924401147025, 38.766136510031565, 39.688020024980815, 40.85871158327375, 40.34934261866978, 41.3919997215271, 41.34134040560041, 45.54666117259434, 44.80674055644444, 45.040762833186555, 43.89355271203177, 43.94199555260794, 50.681546688079834, 56.52877541950771, 56.17546994345528, 59.926163128444124, 54.680801255362375, 57.74236168180193, 30.52033403941563, 0.5029311871954373, 0.5305989139846393, 0.09770173486322165, 0.33022627447332653, 39.08789021628243, 62.394225801740376, 51.50640555790493, 42.70426082611084, 23.407459667750768, 25.263130698885234, 42.288254805973594, 52.46560089928763, 57.31094455718994, 18.191188165119716, 0.06948052027395793, 0.03618802655754345, 0.004549432687261807, 0.03450640982815197, 0.05344217124262026, 0.035007796316806755, 0.045032537143145285, 0.0773847136380417, 0.0368397356942296, 0.03618248971179128, 0.07722850130604846, 0.12499099517507212, 0.1909771008150918, 0.17928592887307915, 0.11126853365983282, 0.09602514947099344, 0.1661707426288298, 0.10595264605113439, 0.13793369781758102, 0.13458089344203472, 0.40099009445735384, 24.280271530151367, 61.37719018118722, 56.02010127476284, 49.0697591645377, 34.710903780800955, 32.57156733104161, 26.52269319125584, 43.84025308064052, 50.050893442971365, 61.73954568590437, 15.067472628184728, 0.23848312880311692, 0.29360044694372583, 2.213943600654602, 7.872073633330209, 28.17780099596296, 45.36525412968227, 49.58244936806815, 48.815851143428254, 53.692843845912385, 51.92206416811262, 51.803024155753, 53.818376949855256, 51.47125114713396, 51.317570890699116, 52.30395105906895, 49.411426407950266, 52.70158951623099, 51.83246367318289, 49.3459917477199, 50.130137647901265, 49.180186884743826, 52.03142186573574, 48.73036398206438, 48.55974401746477, 49.038506167275564, 48.30444288253784, 48.96389641080584, 47.58658627101353, 43.22892277581351, 37.08265747342791, 35.21121229444231, 37.29362562724522, 39.36337239401681, 38.73355293273926, 37.71218511036464, 36.29606580734253, 37.33485623768398, 36.59419216428484, 35.87701300212315, 35.49210017068045, 36.6982935496739, 36.33177954810006, 35.385327202933176, 36.947098118918284, 36.965149538857595, 36.49797351019723, 36.58117471422468, 36.081630502428325, 35.63229397365025, 35.43278339930943, 35.915478229522705, 37.38507086890084, 43.287308488573345, 48.375147751399446, 46.16157674789429, 47.60056604657854, 48.60916655404227, 50.65837444577898, 52.28399930681501, 45.36234630857195, 45.22358383451189, 43.29106051581246, 40.32216126578194, 44.28285333088466, 48.194459847041536, 50.06168746948242, 51.00648266928536, 48.12120498929705, 49.676003387996126, 50.083212988717214, 48.831957067762104, 49.71457631247384, 44.82146378925869, 42.80211925506592, 46.76494789123535, 50.89358139038086, 51.94292960848127, 50.70504896981375, 51.28744350160871, 46.83055625643049, 47.909139020102366, 49.85552746909005, 48.95129237856184, 45.46035759789603, 39.13682290485927, 38.10395928791591, 37.34078305108206, 36.64660937445504, 38.28213194438389, 37.71958841596331, 38.973793847220286, 37.14298520769392, 35.937865325382774, 36.037023067474365, 37.43726226261684, 37.34232555116926, 38.45910603659493, 38.2645252091544, 38.2758229800633, 41.744693756103516, 37.66765063149588, 40.709617137908936, 38.58079331261771, 37.99453558240618, 39.362840856824604, 37.08845574515206, 40.82138933454241, 38.49752262660435, 40.3974415234157, 38.84574202128819, 42.29852424349104, 42.093969276973176, 40.59822014399937, 41.65891477039882, 42.60376555579049, 42.18176324026925, 42.31353235244751, 44.55513933726719, 48.82007564817156, 46.8137902532305, 47.61814498901367, 46.8842693056379, 47.50415979112898, 53.380845410483225, 58.75703144073486, 60.55806704929897, 62.33115005493164, 56.77764252253941, 58.429778235299246, 34.64745283126831, 0.7205340021422931, 1.5229286402463913, 0.3769378193787166, 0.4687548982245581, 43.930312156677246, 66.10728059496198, 58.434357098170686, 54.747576917920796, 29.980928012302943, 31.395108767918178, 50.31478949955532, 61.379754066467285, 65.706209727696, 25.039324011121476, 0.15933026825743063, 0.12753453797527722, 0.1414817167179925, 0.1131375040858984, 0.1100314421845334, 0.21583785036844866, 0.19381598276751383, 0.20414335360484465, 0.11492867368672575, 0.18171021235840662], [0.022703489953918115, 0.022304894735238383, 0.02341693051026336, 0.06484350695141725, 0.08909459279051848, 0.04726915141301496, 0.0497525251204414, 0.02805789460295013, 0.04877545504963823, 0.024899224185251763, 0.13502040771501406, 16.15998305593218, 49.894961970193044, 44.91505602427891, 38.59631906236921, 19.19399561200823, 19.180396250316075, 32.45400728498186, 38.015147413526265, 37.67445986611502, 47.61124542781285, 13.651529635701861, 0.16517261761639798, 0.034443319642118046, 0.5903149896434375, 2.991708666086197, 20.686885561261857, 45.03399181365967, 46.7794383593968, 50.262347970690044, 49.77572740827288, 49.28400339399065, 48.34446798052107, 49.10374627794538, 46.20601742608206, 44.89087281908308, 44.91465302876064, 45.09417363575527, 44.15660803658621, 43.97103207451956, 42.99610253742763, 42.77009500776018, 43.688087531498496, 45.24751343045916, 44.73631361552647, 45.79069580350603, 41.15641757420131, 41.89679677145821, 39.137663636888774, 36.0653578213283, 30.582416193825857, 33.2697605405535, 32.34074122565133, 33.22140455245972, 33.33050169263567, 34.12722383226667, 32.367992060525076, 32.51867764336722, 33.025493144989014, 34.53058760506766, 31.332821641649517, 32.81594589778355, 32.335259096963064, 33.41342844281878, 33.32127101080758, 35.5500168800354, 33.081346239362446, 34.99941035679409, 32.133452142987935, 33.04263782501221, 33.34964745385306, 32.546407903943745, 34.07543543406895, 31.546756676265172, 35.9632887840271, 40.99623032978603, 45.14903661182949, 45.102674756731304, 42.113031659807476, 46.14639493397304, 45.95254019328526, 44.27617958613804, 42.04519292286464, 39.81375462668282, 37.88282939365932, 40.373682158333914, 45.56077296393258, 47.864830357687815, 46.81786189760481, 43.426057066236226, 48.633603368486675, 46.664740971156526, 46.36694812774658, 47.61286435808454, 46.925718784332275, 41.95800345284598, 41.12396601268223, 42.95842593056815, 45.19406788689749, 45.888335364205496, 48.126673221588135, 44.502173219408306, 39.97813163484846, 44.18585647855486, 47.590835094451904, 44.18388319015503, 36.69399956294468, 34.13832010541643, 33.817361967904226, 34.219898905072895, 32.71450219835554, 34.07759632383074, 34.16135685784476, 33.76476410457066, 34.57403816495623, 32.517055238996235, 34.920565673283164, 32.677211216517854, 33.77717358725411, 34.84694603511265, 37.16188430786133, 38.07399518149239, 37.50987788609096, 38.38841853822981, 38.37217364992414, 36.06145640781948, 36.145731108529226, 36.017755712781636, 36.16994905471802, 34.375521183013916, 36.08369064331055, 35.23738963263375, 36.36590215138027, 36.094012192317415, 36.92447131020682, 36.55726943697248, 39.75373261315482, 37.98776108877999, 38.26174940381731, 37.43950653076172, 40.43335328783308, 38.150178704942974, 39.28347158432007, 38.691961015973774, 43.32902199881417, 50.05268955230713, 53.65262419836861, 56.25557919910976, 57.06997060775757, 53.473120961870464, 56.00701781681606, 29.710827214377268, 0.5712291023560933, 0.6749813407659531, 0.10247326096785919, 0.10995269141026906, 27.369067158017838, 59.274852888924734, 48.54062952314104, 40.67380264827183, 32.8382739339556, 19.59110426902771, 33.12815625326974, 43.792334829057964, 45.75815391540527, 14.54492553642818, 0.12157964679811682, 0.07173719203897885, 0.021648564775075232, 0.029948445835283825, 0.019518037759033696, 0.06150483646030937, 0.02904845055724893, 0.010026176776071745, 0.019529603388426558, 0.006079639416254524, 0.005777583615521767, 0.019096428328858953, 0.019549102788524966, 0.028612681797572544, 0.012366646767726966, 0.13012108632496425, 0.037407720394964726, 0.034019197936036756, 0.005788710741658828, 0.07016672952366726, 0.142026064651353, 19.519252947398595, 56.037593364715576, 51.744707924979075, 42.211918422154014, 26.459827627454484, 21.929688998631068, 24.221376861844742, 35.75727469580514, 41.124681677137104, 55.44787890570504, 14.348828264645167, 0.16514638545257704, 0.1621100226683276, 0.8150212519935199, 4.126168191432953, 23.71052098274231, 43.55069037846157, 47.78053133828299, 50.70750515801566, 50.04160370145525, 50.76961857931954, 50.16528163637434, 49.483989919934956, 49.18477616991316, 47.51055908203125, 48.269562925611226, 47.565470695495605, 46.57897240774972, 45.02632795061384, 45.24504334586007, 45.731889724731445, 46.08787373134068, 46.43911559241158, 46.753570216042654, 46.610426902770996, 43.23202167238508, 43.70417608533587, 40.64949437550136, 36.41517530168806, 32.95586177280971, 34.68442072187151, 33.085633277893066, 34.66241577693394, 35.54146017347063, 35.9471481187003, 34.401406696864534, 35.31554644448416, 35.527563776288716, 34.75289521898542, 33.013469287327354, 35.07644850867135, 34.45516838346209, 34.58286585126604, 34.05376400266375, 35.97046627317156, 33.72900520052229, 34.97852407182966, 32.48054245540074, 34.69561079570225, 33.581904888153076, 34.280052934374126, 34.99576950073242, 33.97737898145403, 37.534405027117046, 42.8683842250279, 46.329785687582834, 46.77884776251656, 44.517427989414756, 46.35753679275513, 46.827884674072266, 45.33566175188337, 44.418572493961875, 41.332999093191965, 40.05956104823521, 41.824622358594624, 47.45895481109619, 48.91586003984724, 48.481403078351704, 45.79574019568307, 50.3803631237575, 48.430080209459575, 48.72679955618722, 49.29798664365496, 47.50823490960257, 43.87794705799648, 41.5273471559797, 45.52001483099801, 47.96827861240932, 47.88210357938494, 48.30137872695923, 46.49405499867031, 42.03970732007708, 43.462733132498606, 50.09005696432931, 46.96051188877651, 37.35364416667393, 37.206026213509695, 35.40206888743809, 35.44908387320382, 34.16644293921334, 36.33101177215576, 35.60415724345616, 36.04368986402239, 35.44422360828945, 34.25128391810826, 35.68494394847325, 35.029721873147146, 35.61546196256365, 36.50999736785889, 38.37070063182286, 39.24436364855085, 37.833379064287456, 37.8509441103254, 39.08499281747, 37.1464523587908, 38.35964604786464, 37.48950229372297, 37.12334612437657, 35.62614481789725, 37.21951961517334, 37.24044758932931, 38.005121162959504, 38.40366636003767, 39.89729976654053, 38.97352286747524, 40.69791637148176, 38.79849427086966, 40.5454728943961, 38.77372741699219, 42.826889583042686, 41.82298953192574, 42.36313206808907, 41.07391466413225, 44.90539802823748, 52.1451221874782, 55.7890111378261, 58.12001017161778, 59.518123217991416, 55.059839384896414, 57.231575284685405, 32.01533624104091, 0.9813371875456401, 0.6425023664321218, 0.133293943213565, 0.0632650445082358, 30.333535194396973, 61.98673479897635, 55.43486145564488, 38.45962020329067, 32.480591092790874, 27.722028698240006, 39.78720555986677, 50.338625294821604, 54.153332233428955, 18.849903447287424, 0.14567145332694054, 0.08755504433065653, 0.011705106506789369, 0.04791608705584492, 0.024648359610832164, 0.04029154511434691, 0.043713655056697984, 0.05295862004693065, 0.02813217043876648, 0.048134202137589455, 0.10741872273917709, 0.11748213666890349, 0.09447949419596366, 0.16443385582949432, 0.1522505288677556, 0.26525725211415974, 0.13859612441488675, 0.11663290938096386, 0.0899215777005468, 0.1408130611692156, 0.29167742441807476, 24.33722243990217, 65.18013381958008, 56.182925360543386, 50.449792998177664, 28.912513937268937, 27.01201660292489, 42.50072029658726, 49.508968693869456, 47.688043866838726, 57.79473025458199, 16.810930252075195, 0.3142997276570116, 0.17241535468825273, 1.7992302711520876, 4.900630908352988, 23.249084166118077, 46.18669101170131, 47.806628772190635, 52.39761277607509, 51.942210469927105, 53.278439385550364, 51.48688459396362, 53.108111245291575, 50.97459043775286, 48.801770618983674, 49.209101813180105, 48.84567281178066, 48.17703029087612, 47.713529859270366, 47.85559272766113, 46.98046364103045, 47.852198532649446, 49.378436361040386, 48.52011844090053, 49.480713844299316, 44.284517424447195, 44.2761344228472, 41.980751855032786, 39.0853054864066, 34.54098558425903, 37.96076733725411, 34.498848233904155, 37.14158861977713, 37.69076034000942, 37.90669992991856, 35.75258118765694, 38.241985252925325, 37.42631190163748, 37.68657405035836, 33.85048055648804, 37.26215723582676, 35.46423789433071, 36.82980557850429, 35.87263216291155, 38.42604303359985, 35.75493662697928, 38.13539988654, 33.943614210401265, 36.96509395326887, 36.0468339238848, 35.37090621675764, 37.17023604256766, 35.68811927522932, 40.49413612910679, 44.57052959714617, 49.58749723434448, 50.12100076675415, 45.173970222473145, 47.46729612350464, 47.936243942805696, 47.179612909044536, 46.24753986086164, 44.24349178586687, 40.91042007718767, 43.68239000865391, 50.108844893319265, 50.905858857291086, 51.21249328340803, 46.22055653163365, 52.99643979753767, 51.04429129191807, 50.031469753810335, 50.82953289576939, 49.699498721531455, 47.03841856547764, 45.15337923594883, 46.326012815747944, 48.54923139299665, 49.77250344412667, 51.48834718976702, 46.75978190558297, 42.24493626185826, 44.75369453430176, 50.195127623421804, 48.84383501325335, 39.312428201947895, 39.54903868266514, 37.30672992978777, 38.816180910382954, 35.46779537200928, 39.2401773588998, 38.28308384759085, 37.04315349033901, 37.26219892501831, 36.19077280589512, 37.67968838555472, 35.81892606190273, 37.84773404257638, 37.50860289164952, 41.60590696334839, 42.585853099823, 39.42072629928589, 41.27629484449114, 41.08859273365566, 39.19651140485491, 40.41586119788033, 39.624725409916465, 40.4430182320731, 37.72096068518502, 39.37434359959194, 39.341541154044016, 41.89283629826137, 40.77860580171858, 40.871617862156455, 40.111634322575156, 43.34679201671055, 41.26866224833897, 42.18422637666975, 41.721007347106934, 44.49266113553728, 43.66634661810738, 44.565089157649446, 43.09379073551723, 46.61365781511579, 54.07276439666748, 58.33745057242257, 60.91223062787737, 60.7771645954677, 56.35647051674979, 57.52282639912197, 34.101748262132915, 1.9040493837424686, 1.1801520735025406, 0.31229069403239657, 0.26354316409145084, 33.90528794697353, 68.73674297332764, 61.61349841526577, 54.693690163748606, 45.84016350337437, 31.44572639465332, 46.8105593408857, 58.18475348608834, 64.00652749197823, 26.390185832977295, 0.3208669695471014, 0.13438409114522593, 0.17877476130213055, 0.0912494503759912, 0.07296219880559615, 0.16909886550690445, 0.1896310094743967, 0.1208400164863893, 0.09808873052575759, 0.10986403402473245], [0.04276283411309123, 0.019193445265825306, 0.0465315465283181, 0.06250414890902382, 0.015514669274645192, 0.08830623687910182, 0.012643609495301331, 0.06097205076366663, 0.012215497155141617, 0.09161708064909492, 0.08534350192972592, 15.271577698843819, 50.19224064690726, 43.554880142211914, 35.888790198734824, 16.542783635003225, 39.99358442851475, 64.0086258479527, 44.71583380017962, 32.624894755227224, 45.295754773276194, 17.76172522136143, 0.08780399204364844, 0.10144828632473946, 0.3576292911810534, 3.5754924033369337, 27.407810313361033, 43.81604903084891, 49.070054462977815, 49.81624582835606, 47.98067767279488, 47.3959971836635, 46.83453410012381, 45.44082621165684, 44.314978327069966, 43.0603004183088, 40.906348432813374, 39.24799408231463, 37.76484203338623, 36.42228330884661, 34.623154980795725, 36.9993485723223, 35.47998946053641, 37.089661257607595, 37.93547936848232, 37.43059894016811, 35.007932322365896, 33.297970226832796, 30.880580765860422, 32.17337301799229, 32.29299667903355, 32.68840823854719, 32.26028456006731, 32.26545054571969, 31.759107521602086, 33.09945324489048, 32.42364018304007, 33.029502255576, 32.616087913513184, 32.5147762298584, 32.56970173971993, 32.459541525159565, 33.093734877450125, 33.50634322847639, 31.938322407858713, 34.42552389417376, 32.13174288613455, 33.82741253716605, 32.29051269803728, 32.655998366219656, 34.089811256953645, 31.42966215951102, 32.93077530179705, 33.646825381687705, 34.1338906288147, 41.08569186074393, 43.81187316349575, 47.89384950910296, 44.5552122933524, 46.70784412111555, 46.425424167088096, 43.133169651031494, 43.19855219977242, 38.10138498033796, 37.99332659585135, 42.489412103380474, 47.2702625819615, 48.08800302233015, 48.036179883139475, 38.13855784279959, 42.38207285744803, 41.474096161978586, 46.52925109863281, 47.25082152230399, 46.09710441316877, 41.84607144764492, 40.68994678769793, 43.89767299379621, 45.0038366317749, 46.71638693128313, 43.56484385899135, 46.488228934151785, 39.76398468017578, 44.37645251410348, 43.795242650168284, 44.03524732589722, 38.54827574321202, 33.024301528930664, 34.456016063690186, 32.30377680914742, 33.536171845027376, 33.26039784295218, 36.27942487171718, 35.19334152766636, 32.95985003880092, 32.850457600184846, 32.80020475387573, 32.69897992270333, 34.36703395843506, 34.9454471724374, 34.36254889624459, 34.748187814440044, 36.28268705095564, 34.959670134953086, 37.261035101754324, 36.205468245915, 34.40033320018223, 35.747960635593955, 35.30122620718819, 35.70135906764439, 36.073518480573384, 35.83080748149327, 35.352635928562705, 37.44125747680664, 37.23784548895699, 37.91104255403791, 37.56745760781424, 38.55191659927368, 39.80225535801479, 39.73671647480556, 38.29856790815081, 38.480951172964915, 39.79871872493199, 39.670382022857666, 40.0426595551627, 45.50739690235683, 53.32915081296648, 54.10247489384243, 54.108707427978516, 57.00320189339774, 56.72252593721662, 39.43398693629673, 2.2791617810726166, 0.17611356052969182, 0.06819873369698014, 0.09556658193469048, 28.998181751796178, 59.951607431684224, 44.140283243996755, 48.961947441101074, 35.6008950642177, 18.563585553850444, 40.42056860242571, 46.07677745819092, 45.05053547450474, 13.119968993323189, 0.04190140676551631, 0.033942574369055886, 0.026561713012467538, 0.09197628351726703, 0.09065238027168171, 0.0499402384406754, 0.0761806939595512, 0.046134362662477155, 0.040678574703633785, 0.022185564174183776, 0.032616167329251766, 0.05889375228434801, 0.01781373590763126, 0.03561677471069353, 0.025915449119306037, 0.021333429363689253, 0.00811776310937213, 0.02693892759270966, 0.03731544981045382, 0.053506309765258005, 0.124935029606734, 17.662942681993755, 57.32952751432146, 49.5606598172869, 45.0549510547093, 23.110530138015747, 32.82450955254691, 53.385347843170166, 46.01852028710501, 38.69672053200858, 48.196269852774485, 18.1396255833762, 0.2114454082080296, 0.054028791907642565, 0.4853451337133135, 2.2104230352810452, 26.893315315246582, 44.12343386241368, 50.47003657477242, 51.31242574964251, 50.18881171090262, 49.55200236184256, 49.222143581935335, 48.44430317197527, 45.93585409436907, 44.42230715070452, 43.274996280670166, 41.21012714930943, 40.45327377319336, 38.50904621396746, 37.56714493887765, 39.3220271383013, 37.45114476340157, 38.69814491271973, 38.339795044490266, 39.18778794152396, 37.66103247233799, 35.815114974975586, 32.603157315935405, 33.148041997637065, 33.372496604919434, 33.885808672223774, 34.10415233884539, 34.16751643589565, 34.31209455217634, 34.7781970841544, 33.37164545059204, 33.76466335569109, 34.0102196420942, 34.694509506225586, 33.77804211207798, 34.55201237542288, 35.36027199881417, 34.62913737978254, 34.83293499265398, 34.358428614480154, 34.711108752659385, 35.62056541442871, 34.479803221566335, 35.35029091153826, 33.46376119341169, 33.431486810956685, 35.25634779248919, 34.68210697174072, 35.90788732256208, 43.81711557933262, 46.89431292670113, 50.42113862718855, 44.15345702852522, 47.20983062471662, 48.47735227857317, 46.27219206946236, 44.13734763009207, 40.84002092906407, 38.9076817376273, 45.23663255146572, 48.16585758754185, 49.225482191358296, 49.15077863420759, 40.14801509039742, 43.2194037437439, 44.3196370942252, 47.864288398197715, 49.120529651641846, 48.28674234662737, 43.6434314591544, 42.7191994530814, 47.03793913977486, 46.69027212687901, 48.200685432979036, 48.16035461425781, 47.10964107513428, 39.965906279427664, 44.1967408316476, 47.58218458720616, 45.290456771850586, 38.64545324870518, 33.91320889336722, 36.106835092817036, 33.64532457079206, 33.462819712502615, 35.48047236033848, 37.05441999435425, 35.84901871000017, 35.43221017292568, 34.79046065466744, 36.17867946624756, 35.335032667432515, 35.8500713620867, 36.61825030190604, 36.26879412787301, 36.34309121540615, 37.34516041619437, 38.43667030334473, 38.182998520987375, 37.529405798230854, 36.85254355839321, 37.1492212159293, 37.548134667532786, 38.24449355261666, 38.414766107286724, 36.85558686937605, 38.46891689300537, 38.94575786590576, 38.18116072246006, 40.15988261359078, 39.34679399217878, 40.54645953859602, 40.56180810928345, 40.728832381112234, 39.82071672167097, 39.886731556483674, 40.170433453151155, 42.36986139842442, 41.65840407780239, 47.775587694985525, 55.49143716267177, 55.92822871889387, 55.53351892743792, 58.42301763807024, 57.590439319610596, 42.73669501713344, 2.7547592435564314, 0.4144626786666257, 0.03397246722930244, 0.03609314700588584, 30.634934152875626, 64.81174033028739, 48.86862965992519, 50.83199603216988, 37.35047231401716, 20.9807231426239, 44.59991700308663, 50.88504900251116, 54.95106186185564, 16.58656770842416, 0.060757966179932864, 0.05344844090619257, 0.05253405390041215, 0.0339365930828665, 0.025292728694954088, 0.006408592345126505, 0.021108858021242276, 0.04794503335974046, 0.012872246110678782, 0.05692153596984489, 0.25349047780036926, 0.20172078002776417, 0.1720691525510379, 0.1756275123251336, 0.09048360825649329, 0.2839458164359842, 0.08523974714002439, 0.2505241126886436, 0.08881448674947023, 0.14477103735719407, 0.21389063128403255, 20.984770468303136, 64.90318557194301, 55.49444573266165, 48.75168105534145, 25.03043031692505, 48.9736864226205, 70.20726667131696, 54.032909529549734, 45.00213779721941, 55.093857765197754, 21.343677929469518, 0.4047776497900486, 0.2154922317713499, 1.4832625687122345, 6.289301787103925, 28.379458563668386, 47.14748443875994, 53.635271072387695, 53.588304724012104, 53.41890416826521, 52.55323505401611, 52.66081748689924, 50.40988949366978, 48.2064802306039, 47.662488392421174, 44.80927664893014, 42.922281401497976, 42.048597540174214, 39.94885540008545, 38.94945430755615, 41.04424933024815, 38.56325953347342, 41.50261156899588, 41.301263196127756, 41.26323570523943, 39.11222628184727, 37.00961453574044, 33.265014920915874, 35.077792985098704, 35.48142773764474, 36.176258019038606, 36.33823789869036, 36.24177605765206, 35.63276297705514, 37.837561879839214, 35.543127741132466, 36.410721506391255, 36.33976650238037, 35.954957893916536, 36.26029995509556, 36.816857610430034, 36.54644414356777, 35.90860993521554, 36.2432838167463, 36.74503755569458, 36.67993293489729, 37.28922741753714, 36.580184595925466, 36.404683521815706, 36.72039924349104, 34.664736475263325, 36.927726541246685, 36.130716051374165, 36.74218879427229, 44.86913537979126, 47.92444242749895, 52.18910428455898, 44.36836133684431, 47.45152718680245, 51.18932798930577, 47.50996501105172, 46.88794142859322, 42.15303938729422, 40.76665490014212, 47.783348832811626, 49.316051959991455, 52.06862252099173, 52.801393440791536, 41.16361590794155, 45.008752482278005, 47.15360580171858, 50.09262432370867, 49.94160522733416, 50.9648733820234, 44.810819149017334, 44.20577696391514, 47.86606713703701, 49.05536944525582, 49.675892216818674, 47.77307939529419, 49.73349625723702, 41.323052746909006, 44.45962592533657, 47.88636629922049, 49.41052314213344, 41.42041090556553, 36.542494092668804, 38.0213417325701, 35.364711897713796, 35.692524433135986, 37.144843850817, 39.29279259272984, 38.24242993763515, 36.841374329158235, 36.87469094140189, 37.63183961595808, 36.85291181291853, 38.58821746281215, 39.27062783922468, 37.3592027255467, 37.420148849487305, 39.33414479664394, 38.60425043106079, 40.56241260256086, 39.81364345550537, 38.49714742388044, 39.63432782036917, 39.348141942705425, 41.91506705965315, 40.28536013194493, 39.24357155391148, 39.97429275512695, 41.31277983529227, 40.82288319723946, 42.23605298995972, 42.059395040784565, 42.17551333563668, 43.28344529015677, 43.591042041778564, 43.28356688363211, 42.47178452355521, 44.08494084221976, 43.15902042388916, 44.59886087690081, 50.274375302451, 56.52553061076573, 59.119866371154785, 58.90012264251709, 60.344257082257954, 60.58634621756417, 46.85984986168997, 3.7911321350506375, 1.4419291466474533, 0.2868746449904782, 0.18359089429889405, 34.311677660260884, 70.32463564191545, 57.19008411679949, 61.43752833775112, 44.51070213317871, 28.542310442243302, 54.11722591945103, 58.35216685703823, 64.50743702479771, 23.50779860360282, 0.3681780679949692, 0.09668015289519515, 0.13094957758273396, 0.19732803931193693, 0.15821295178362302, 0.09600819966622762, 0.14404507274074213, 0.218289600951331, 0.13733011377709253, 0.21500760849033082], [0.02675928035750985, 0.03827756157677088, 0.030076750021960055, 0.017791688608537828, 0.1381660689200674, 0.03756435002599444, 0.02041368023492396, 0.037293546700051854, 0.02570512192323804, 0.05770599030490432, 0.007064105518760958, 14.487749678747994, 50.834810052599224, 46.20751476287842, 27.933938332966395, 26.831870658057078, 54.07916716166905, 63.23961312430245, 45.71649946485247, 29.648512295314244, 48.6543402671814, 21.709422418049403, 0.02421902336313256, 0.03169921546110085, 0.2685289851256779, 1.8605827561446597, 28.36427501269749, 48.97871691840035, 50.44225072860718, 48.54456915174212, 48.4796347618103, 45.375395025525776, 43.089222294943674, 43.15962144306728, 41.04377685274397, 37.4757205418178, 35.71807295935494, 35.09017814908709, 34.042862279074534, 34.36997652053833, 32.06948355266026, 33.48655823298863, 32.4641238621303, 31.483722618647985, 31.559405871800013, 33.5016427721296, 30.625811168125697, 33.28245489937918, 31.920072964259557, 33.44306598390852, 30.813989230564662, 31.984357697623118, 32.04487998144967, 30.615729331970215, 32.084349223545615, 31.932548454829625, 33.62533112934658, 31.484858649117605, 32.672667094639365, 32.63614041464669, 32.52057102748326, 33.316518442971365, 33.52923059463501, 33.155028411320274, 34.09066241128104, 33.382418632507324, 33.16272006716047, 32.93041399547032, 33.17055416107178, 32.98681947163173, 31.197369984218053, 33.71348292487008, 34.37571920667376, 32.783869538988384, 34.834439277648926, 42.21437808445522, 42.70257936205183, 47.71590614318848, 42.08026742935181, 46.39886120387486, 46.45828219822475, 43.70521484102522, 39.266556194850374, 39.537424768720356, 38.14473131724766, 44.746753283909385, 45.897458348955425, 48.48107998711722, 44.96861273901803, 41.58527428763253, 48.761648246220176, 44.1343286378043, 48.89519957133702, 46.598139013562886, 46.10152694157192, 38.381008284432546, 42.315397943769185, 42.76342126301357, 44.7535069329398, 43.78310414722988, 47.234361239842, 46.134923458099365, 41.69162341526577, 42.04498447690691, 36.11820929391043, 46.65363080160958, 37.30530902317592, 33.37700945990426, 33.8159966468811, 34.085899421146934, 34.55188383374895, 34.354912825993125, 35.46056924547468, 33.68875776018415, 33.95153863089425, 34.760708468300955, 34.15258475712368, 32.73245634351458, 32.97612271990095, 33.62320498057774, 35.15459837232317, 34.76200778143746, 34.81165613446917, 33.78441708428519, 34.40661437170846, 33.91206244059971, 33.55696085521153, 34.42519038064139, 34.68707493373326, 35.26907341820853, 35.81526436124529, 35.819033758980886, 35.042419706072124, 36.08391298566546, 35.152837003980366, 35.97668143681118, 38.581196308135986, 35.856189250946045, 39.094883578164236, 39.423724446977886, 38.45872735977173, 37.840358529772075, 37.76295212336949, 38.390072209494456, 42.262702805655344, 41.756561279296875, 45.29068953650338, 48.7129031590053, 52.67941781452724, 56.34594399588448, 60.40821525028774, 43.09566674913679, 0.8289605868714196, 0.27700901723333765, 0.06062782994870629, 0.08487418639872756, 25.54694550377982, 59.098306110927034, 47.201874937329976, 39.73083135059902, 36.99567297526768, 30.91140992300851, 41.8723669052124, 46.192298207964214, 42.31682232448033, 15.006672416414533, 0.029363999874996285, 0.006718415251400853, 0.10892364555703742, 0.036230228043028286, 0.027741468278691173, 0.07164248890642609, 0.04847031445907695, 0.031670869660696814, 0.023799765056797435, 0.02999641147575208, 0.01846361130342952, 0.023299778046618615, 0.008164939952881207, 0.03547214836414371, 0.06883789332849638, 0.02538879059388169, 0.08329463151416608, 0.028756283556244204, 0.053839212616107295, 0.06501416529395751, 0.01548873057721981, 17.218490736825125, 57.72908367429461, 49.88063825879778, 34.66271454947335, 23.36809117453439, 52.480945995875764, 69.15490640912736, 52.53254679271153, 34.995713915143696, 52.41627563749041, 22.745468309947423, 0.030377602271203483, 0.0264158415541585, 0.4740816695349557, 2.0348822261605943, 28.020457301821025, 51.33253036226545, 52.43225302015032, 51.090507234845845, 50.14558349336897, 46.961682660239084, 44.4091785294669, 44.94929674693516, 43.61435324805123, 40.48199415206909, 36.93469558443342, 37.51583596638271, 36.75499085017613, 36.139005252293174, 33.88305718558175, 36.20983518872942, 35.349113191877095, 33.397367681775776, 33.73261478969029, 34.33836569104876, 31.3610417502267, 34.073990208762034, 34.142652307237896, 33.76205083302089, 32.73500285829817, 34.30471209117344, 34.31600291388375, 32.17626346860613, 33.29461424691336, 33.920615673065186, 34.07765538351876, 33.443250111171174, 34.07415696552822, 35.89977877480643, 33.517383916037424, 35.980297974177766, 33.708369050707134, 34.36672476359776, 34.688238756997244, 35.89222608293806, 33.56729282651629, 33.9807071685791, 34.90448406764439, 34.18768358230591, 34.27429287774222, 36.17743921279907, 35.71412985665457, 35.10182680402483, 35.85748856408255, 44.02020100184849, 44.31846284866333, 48.25832768848964, 42.9750633920942, 46.78647688456944, 47.449088369097026, 46.15813391549246, 41.388143471309114, 41.51840135029384, 39.69337708609444, 46.46013389314924, 48.4837098802839, 50.289310455322266, 45.64958483832223, 43.25518001828875, 50.77340882165091, 47.68530627659389, 48.508407252175466, 47.57626472200666, 47.468751771109446, 42.55169228145054, 44.34275722503662, 43.99484702519008, 47.03796345846993, 48.41133744376046, 47.21032394681658, 48.578893252781455, 40.913578033447266, 43.84925447191511, 39.94709055764334, 48.033160890851704, 39.71540982382638, 35.05569076538086, 36.216519355773926, 35.46925796781267, 35.18113006864275, 35.508577823638916, 37.6326699256897, 35.79521880831037, 34.880676065172466, 37.15068728583199, 36.35189110892159, 35.03465856824602, 35.25271388462612, 35.17813886914934, 36.78826577322823, 37.636526175907676, 35.81644902910505, 35.20032099315098, 35.6968948500497, 35.22715841020857, 35.44770465578352, 36.588063853127615, 36.75459827695574, 37.02580383845738, 35.893997873578755, 38.086012090955464, 37.53429733003889, 38.03465795516968, 37.07967322213309, 38.4472211429051, 39.73819644110543, 39.18072509765625, 41.24097715105329, 40.314917768750874, 40.06976100376674, 38.458039488111226, 39.78102513722011, 41.043457235608784, 43.61885220663888, 42.6441102709089, 47.902896063668386, 51.00474214553833, 54.844295842306956, 57.822988578251426, 62.41767597198486, 46.03141614368984, 1.3122654472078596, 0.5581478157213756, 0.10866645364356892, 0.04436870597835098, 28.61181674684797, 62.1140535899571, 51.76660517283848, 49.68897220066616, 44.50942019053868, 36.20204973220825, 50.34530251366751, 52.7052720614842, 50.74740171432495, 19.274711097989762, 0.0523885929557894, 0.038319118453988006, 0.033467263981167755, 0.060978836113853116, 0.038225188851356506, 0.02684169352453734, 0.06761497644973652, 0.01598994403944484, 0.015443516396252173, 0.03371055610477924, 0.16602519686732972, 0.14647614157625607, 0.06226778123527765, 0.13159852847456932, 0.3091155844075339, 0.15962077624031476, 0.10713695428733315, 0.13481069968215056, 0.07601645455828734, 0.18788441962429456, 0.2061159498989582, 20.84768772125244, 65.58137144361223, 58.15002291543143, 40.461622033800396, 35.46276487622942, 59.87148775373186, 64.68584592001778, 53.879184109824045, 41.015560218266074, 60.999444416591096, 26.52896567753383, 0.10635764324771506, 0.1077456884086132, 1.0413875366960252, 3.0891580198492323, 31.6856198992048, 51.957972458430696, 55.479979583195274, 53.288284982953755, 53.670960494450156, 48.72384309768677, 46.79678453717913, 48.052101680210654, 46.3924514906747, 41.72077805655343, 38.53372968946184, 39.994060380118235, 38.04460430145264, 37.871788706098286, 35.917336872645784, 37.75446489879063, 37.32263435636248, 34.64180741991316, 35.61086572919573, 36.481499331338064, 33.961655208042686, 36.49225861685616, 35.29111310413906, 37.415250369480674, 34.19528143746512, 35.40099539075579, 36.43175022942679, 33.42746727807181, 35.56760971886771, 37.153605529240195, 37.73738275255476, 34.34914582116263, 36.460731165749685, 37.562204769679475, 34.80720928737095, 37.66019868850708, 35.587957518441335, 35.38872487204415, 37.43381943021502, 36.452730315072195, 36.34940365382603, 35.86112594604492, 37.84083448137556, 36.331921986171174, 35.26624550138201, 37.59920392717634, 39.379801409585134, 36.016800335475374, 38.09033039637974, 47.01691389083862, 46.14028746741158, 50.164583342415945, 44.45258740016392, 50.82351228169033, 49.38151788711548, 48.842025007520405, 41.81728506088257, 43.47956166948591, 41.987224102020264, 49.36358111245291, 50.357628617967876, 52.79274640764509, 49.46668890544346, 46.32726696559361, 53.022648402622764, 49.050255571092876, 52.31572478158133, 48.26878472736904, 49.772294998168945, 43.588443415505544, 46.24961389814104, 46.266980920519146, 48.403343541281565, 48.27309955869402, 49.110659735543386, 49.85300874710083, 40.80960518973214, 42.59105035236904, 42.875280312129426, 50.14898463657924, 41.506474767412456, 38.303598403930664, 38.86649281638009, 36.81045137132917, 38.03590863091605, 37.378852231161936, 40.03522845676967, 36.925659452165874, 37.91310616901943, 38.73195137296404, 39.48145702907017, 36.61321633202689, 36.224374294281006, 37.24439764022827, 39.077315058027, 40.080909388405935, 38.5065587588719, 37.0941914830889, 38.4974809374128, 38.01820462090628, 37.255900382995605, 39.269363267081125, 38.55322980880737, 38.77024289539882, 38.64898293358939, 40.38013356072562, 38.600196157182964, 40.567053999219624, 40.162390913282124, 38.519016878945486, 42.24133709498814, 40.07634094783238, 42.334046908787315, 42.26130969183785, 42.05501767567226, 41.15155383518764, 42.012633664267405, 43.14402968542916, 45.882484980991904, 45.327045985630576, 50.457477705819265, 53.60239219665527, 58.05154609680176, 60.29605048043387, 65.06581510816301, 48.48964711597988, 2.0367180705070496, 1.8441296390124728, 0.40307259985378807, 0.1508113018104008, 31.796165738786968, 68.96451187133789, 57.60631595339094, 52.72770779473441, 48.804299763270784, 43.35826349258423, 55.58615500586373, 60.53868852342878, 60.294111933027, 27.5389176096235, 0.33650959017021315, 0.11427124110715729, 0.17031372817499296, 0.17021855685327733, 0.16673349243189606, 0.11083793533699852, 0.23344685190490314, 0.11128195508250169, 0.12535409283425125, 0.15222773009112903], [0.0246100105079157, 0.03943735773542097, 0.016178006805213432, 0.04256519382553441, 0.011886295712819057, 0.05837096140852996, 0.0374023124708661, 0.06700102439416306, 0.01306326813729746, 0.01468506352310734, 0.03515372545059238, 11.672535027776446, 52.95554617473057, 46.29243564605713, 40.301924637385774, 31.657413687024796, 35.49403524398804, 41.37558112825666, 35.50952277864729, 40.93037877764021, 50.053422587258474, 27.200248513902935, 0.06131768971681595, 0.03637863043695688, 0.40482099460703985, 0.8386292223419461, 26.36878364426749, 48.394578388759065, 49.7417437689645, 49.40902580533709, 47.3225998878479, 42.07058164051601, 39.08440222058977, 37.673553126198904, 34.70616858346121, 36.340360573359895, 34.26072651999337, 34.17966536113194, 34.249678884233745, 33.098921707698274, 33.56402022497994, 34.19670581817627, 35.34822382245745, 33.90486410685948, 33.70402295248849, 33.58853694370815, 32.63438599450247, 33.772959504808696, 32.02547366278512, 33.639366490500315, 29.299532072884695, 31.574153423309326, 31.357619762420654, 32.80835151672363, 32.983904702322825, 33.70944602148873, 32.14637579236712, 33.791233267102925, 31.902219567980083, 33.65516669409615, 33.24106795447213, 33.28247921807425, 33.36206388473511, 32.3623605455671, 33.536779812404085, 33.51572677067348, 31.085052353995188, 32.50626816068377, 33.84768738065447, 32.10516950062343, 32.058057240077424, 31.713885171072825, 33.57133320399693, 32.505760942186626, 33.550544193812776, 42.0313138961792, 43.842361858912874, 47.57447208677019, 41.79773283004761, 45.11929832186018, 45.83630725315639, 42.79204436710903, 40.565105029514854, 39.86492810930525, 36.72521434511457, 42.82571881158011, 48.71093681880406, 45.92531715120588, 46.459091663360596, 43.20784541538784, 48.89689145769392, 45.98257725579398, 44.387385504586355, 44.04951892580305, 40.917660100119456, 38.57974066053118, 43.850817816598074, 43.900990758623394, 46.07995278494698, 46.766306264059885, 47.08963373729161, 41.09826462609427, 50.71958112716675, 39.01830053329468, 40.38864510399954, 45.525441374097554, 32.579960754939485, 34.50858266013009, 33.013469287327354, 35.04648787634713, 34.52161053248814, 34.949626513889854, 32.79340246745518, 33.22309296471732, 33.12486628123692, 31.871713502066477, 34.190535817827495, 32.33385903494698, 33.333180223192485, 33.30113165719168, 34.1013765335083, 33.25147635596139, 33.10262162344796, 33.90598971503121, 33.742449964795796, 33.23422050476074, 33.20522567204067, 33.35914216722761, 34.65685721806118, 34.787472929273335, 36.24097006661551, 35.68800115585327, 36.22609397343227, 34.93140486308506, 36.712113516671316, 38.01664127622332, 35.641465595790315, 38.26085656029837, 36.78685181481497, 37.793649264744346, 40.286523955208914, 38.173743520464214, 37.564949308122905, 38.79878609521048, 40.96985149383545, 41.44471223013741, 41.75814894267491, 46.58406891141619, 51.653245312826975, 53.993388175964355, 60.363927432468955, 42.39485059465681, 1.155473266329084, 0.3067632663462843, 0.10303642467728683, 0.0351005995513073, 21.324358463287354, 59.0755855015346, 46.0212196622576, 38.2976507459368, 24.662544046129497, 24.061863592692784, 32.11766236168997, 47.50767905371529, 48.176582132067, 14.361245564052037, 0.027895360020920634, 0.042577950283885, 0.026963551628536413, 0.0074859876351963195, 0.06263240559824876, 0.045441656439964256, 0.04664776939898729, 0.029775619573358978, 0.02247020452549415, 0.013073075512823249, 0.056554285676351616, 0.01892556472947555, 0.02993662914793406, 0.054645749873348644, 0.0532770361751318, 0.04337902194155114, 0.01881965559108981, 0.017433062495131577, 0.01495277781837753, 0.04032104781695774, 0.020382113089518886, 13.744952508381434, 58.52187660762242, 52.09813846860613, 44.443054471697124, 36.84025566918509, 42.43302052361624, 51.23087821687971, 43.14817428588867, 41.978142806461875, 54.61739546912057, 28.545114040374756, 0.1341137085109949, 0.06389908120036125, 0.33539757984025137, 1.4346755530153001, 28.322592769350322, 52.489273411887034, 52.249553612300325, 51.05247974395752, 49.29636771338326, 43.28361552102225, 40.274573053632466, 39.135975224631174, 36.35748093468802, 37.432061535971506, 35.84977953774588, 37.497127941676546, 36.12348297664097, 33.32774673189436, 36.23407397951399, 37.81211757659912, 37.220613956451416, 35.39639220918928, 34.26640319824219, 33.7404454095023, 35.473385197775706, 33.9399733543396, 33.0627771786281, 33.96931559698922, 30.571702071598597, 33.1630813734872, 34.28948163986206, 34.039183207920615, 35.62589815684727, 34.53160204206194, 34.643818923405235, 35.29951695033482, 33.837820938655305, 34.733148438589915, 34.66648047310965, 34.61296544756208, 33.767598969595774, 33.85999264035906, 35.30232054846627, 34.03999267305647, 33.58868285587856, 34.95921502794538, 34.77586596352713, 33.86235155378069, 33.77976526532854, 34.02562032427107, 34.773065839494976, 34.6473833492824, 36.09799698420933, 43.39158705302647, 46.62459427969796, 49.94478750228882, 44.02637447629656, 47.50567102432251, 48.06268031256539, 44.9770131111145, 42.87009000778198, 41.00440488542829, 38.6156906400408, 44.10675123759678, 49.017995085035054, 48.44633552006313, 48.831227506910054, 44.12987831660679, 51.10689456122262, 47.14529923030308, 47.14876985549927, 46.02516623905727, 43.08589063371931, 40.07812316077096, 44.12566423416138, 45.35529388700213, 47.91805703299386, 47.642613070351736, 51.74671248027256, 40.66015986033848, 50.021464347839355, 44.48510496956961, 41.235960551670615, 47.582097734723774, 33.817233426230295, 35.55813932418823, 34.48818622316633, 36.02476297106062, 36.34341083254133, 35.53292778560093, 34.345275674547466, 34.46124110903059, 33.86574922289167, 34.141134125845774, 34.39404508045742, 33.295955249241416, 35.45664003917149, 34.56212200437273, 35.94754764011928, 36.15400641305106, 34.543243748801096, 35.25485045569283, 36.55613688060215, 35.39343575068882, 34.4830584526062, 34.85050698689052, 35.63020256587437, 36.779118469783235, 37.999864850725444, 37.16446903773716, 38.044680731637136, 37.7308167048863, 38.38049064363752, 39.320279666355674, 38.25342893600464, 39.40500599997384, 39.14429221834455, 40.909648827144075, 41.36750732149397, 40.2285794530596, 39.67064952850342, 40.77688959666661, 42.99951410293579, 41.01329857962472, 43.08465732846941, 48.932612146650044, 53.91627359390259, 56.10132571629116, 60.08287279946463, 44.666046483176096, 1.3651210452829088, 0.750209161213466, 0.1195863416152341, 0.025897240632080605, 23.94997501373291, 63.652905872889924, 51.22013977595738, 40.9326091493879, 30.21690968104771, 29.58451591219221, 39.11621107373919, 54.84930201939174, 55.5024048941476, 19.746483360018047, 0.05444188741967082, 0.055629048895623, 0.04321592587179371, 0.026952717120626142, 0.04341703686597092, 0.05708198236035449, 0.019052113206791024, 0.029018021654337645, 0.018497188608827334, 0.025164110685831735, 0.15260485985449382, 0.12192348763346672, 0.12283903493412904, 0.19565793392913683, 0.08934381870286805, 0.1937137275402035, 0.1618849118905408, 0.09825314634612628, 0.10898748891694204, 0.09896440710872412, 0.08670287898608617, 15.020007746560232, 67.61151695251465, 57.59213468006679, 50.91068090711321, 41.136344228472026, 43.146767275674, 48.86577047620501, 44.87975917543684, 50.059957368033274, 58.52461419786726, 32.93820640019008, 0.23685201204248837, 0.2622763120702335, 0.7592884483081954, 1.6971169390848704, 30.428169659205846, 54.08080346243722, 54.74193845476423, 54.72847979409354, 52.02333416257586, 44.95092262540545, 43.46471684319632, 41.6379451070513, 38.52991165433611, 39.26094899858747, 38.05597850254604, 39.768129280635286, 38.574369703020366, 36.23048523494175, 37.82009063448225, 39.41391706466675, 39.20422043119158, 37.31052017211914, 36.790308543613975, 35.444185393197195, 35.613151686532156, 36.43223312922886, 34.848151547568186, 36.63517958777291, 33.018256596156526, 35.31237459182739, 34.47150707244873, 36.816249643053325, 36.71343714850289, 36.71153334208897, 36.02349839891706, 38.248391492026194, 36.34657573699951, 37.32918998173305, 37.26205996104649, 36.44843980244228, 36.24271406446184, 35.547473839351106, 36.99403320040022, 36.625142914908274, 34.85996001107352, 36.794838769095286, 36.466004848480225, 35.17885453360421, 34.39064393724714, 34.08979041235787, 37.9074364389692, 35.97171694891793, 38.51830121449062, 45.625821999141145, 48.90048367636544, 49.21265581675938, 42.87452643258231, 49.67829976763044, 50.32626097542899, 47.70572355815342, 44.92276505061558, 44.110843726566856, 39.98821347100394, 46.9701247215271, 51.42650127410889, 50.050104822431294, 51.0481927054269, 47.67102425439017, 52.61663736615862, 49.81031206675938, 47.57611880983625, 46.81722961153303, 44.63672161102295, 42.59275613512312, 46.3792325428554, 47.43660593032837, 48.22312116622925, 49.30379186357771, 51.77393204825265, 44.18053068433489, 49.47821249280657, 44.99580104010445, 46.444486549922395, 49.77879156385149, 35.930434226989746, 36.712874344417024, 36.347041266305105, 37.85555076599121, 38.28658921377999, 38.57643679210118, 35.375575406210764, 36.47079563140869, 36.0771176474435, 35.526969705309185, 37.76111779894148, 34.77323954445975, 37.60745143890381, 35.90599741254534, 38.59574931008475, 38.19209371294294, 36.82519197463989, 37.44118104662214, 38.04483011790684, 38.13719946997506, 38.15027945382254, 38.83739028658186, 38.192215306418284, 37.52133199146816, 39.768230029514854, 39.2108142716544, 40.35938276563372, 40.062385490962434, 40.118519987378804, 42.58456768308367, 40.153618812561035, 42.485760825020925, 41.10904475620815, 42.09321887152535, 43.57037115097046, 42.31703771863665, 42.497791630881174, 44.07580048697335, 45.83101967402867, 45.163516657693044, 44.4619778905596, 52.12134197780064, 55.43921797616141, 58.98809378487723, 63.15462275913784, 47.81147861480713, 1.7165638612849372, 1.421998347554888, 0.3432283082178661, 0.08824667507516486, 25.700313091278076, 68.46582576206752, 56.62361485617501, 51.29276234763009, 34.22970628738403, 34.439260482788086, 45.6957243510655, 62.885213306971956, 65.61466026306152, 26.124714272362844, 0.26233379755701336, 0.22497295375381196, 0.13962809475404875, 0.059396750293672085, 0.1311503696654524, 0.12605142327291624, 0.1368030956281083, 0.10879400465637445, 0.11696119819368635, 0.08711247665009328], [0.0619156826287508, 0.00044390834383583363, 0.03567014488258532, 0.08145838683204991, 0.05878579057753086, 0.02125475662095206, 0.01938813562238855, 0.026446155106116618, 0.03930931817740202, 0.11710770747491292, 0.021551612298935652, 5.2498286962509155, 45.716634954724995, 43.41870934622628, 40.17628036226545, 20.752215998513357, 22.134521893092565, 27.1241101537432, 32.855977943965364, 43.519149030957905, 50.171451636723106, 28.936874321528844, 0.07600297885281698, 0.06746867072901555, 0.4729389622807503, 1.652578660420009, 32.206057344164165, 52.88798883983067, 51.6490729195731, 50.55235535757882, 45.026786531720845, 38.795847007206504, 38.53027990886143, 37.02441419873919, 34.20970937183925, 33.498828751700266, 31.72847638811384, 32.504072529929026, 33.16949456078665, 33.61194542476109, 32.90532752445766, 31.918905666896276, 33.26743636812483, 32.47319820949009, 33.313621044158936, 31.127971376691544, 31.229224000658306, 32.00130435398647, 32.4342292376927, 33.10637365068708, 32.540901456560405, 32.91040318352835, 32.392824922289165, 32.81027269363403, 33.480742590767996, 34.65049614225115, 31.8641608101981, 32.12955072947911, 32.13383429391043, 32.83606093270438, 33.96440322058541, 32.38031816482544, 32.906143937792095, 31.98300279889788, 33.12983076913016, 33.692495891026084, 33.14723948069981, 32.69398416791643, 33.86976875577654, 33.51925992965698, 32.344187532152446, 31.547965662819998, 32.85517542702811, 31.813668251037598, 35.630713258470806, 42.848929268973215, 47.934631960732595, 37.59850215911865, 36.48788472584316, 47.28715712683541, 43.739170687539236, 44.56839302607945, 37.57435022081648, 39.8241526058742, 36.139376980917795, 41.01887103489467, 45.856477873665945, 48.34922054835728, 48.32669448852539, 46.0893953868321, 46.489180837358745, 48.1911802973066, 41.63392557416643, 39.75825589043753, 37.13453272410801, 41.9350848197937, 43.80669328144619, 43.90059123720442, 45.12718800136021, 46.4197370665414, 44.95958702904837, 52.76832348959786, 44.34416423525129, 35.009433133261545, 45.70185613632202, 39.348176683698384, 33.36002458844866, 33.31151573998587, 34.60909182684762, 34.34339271272932, 33.71344470977783, 33.25410277502877, 33.42607763835362, 32.55933155332293, 34.222480160849436, 32.226252283368794, 33.83588933944702, 32.64384249278477, 32.34498657499041, 33.41119112287249, 33.98254149300711, 32.428788798195974, 33.97116034371512, 33.245292459215435, 35.09337084633963, 33.991032191685264, 34.771822111947195, 34.64360352924892, 34.84886026382446, 32.91731316702706, 35.15977130617414, 35.33233676637922, 36.48699535642351, 37.08108370644705, 37.60667324066162, 36.48355252402169, 36.43242073059082, 37.66773748397827, 40.70640359606062, 42.221552099500386, 46.78787694658552, 46.22954402651106, 45.849651268550325, 41.65690674100603, 43.354195322309224, 39.78813314437866, 42.41604954855782, 46.87665407998221, 52.85845899581909, 54.05671753202166, 61.2958128792899, 42.41426386151995, 1.3412640797240394, 0.23246797014560017, 0.1609268340149096, 0.08179246354848146, 19.479814972196305, 59.7020628792899, 49.14420563834054, 47.08112914221627, 31.146745409284318, 35.50052833557129, 38.55864592960903, 43.90110887799944, 46.09504427228655, 11.447977934564863, 0.1508063349340643, 0.04458601360342332, 0.018227545577766638, 0.07826698558138949, 0.04110434864248548, 0.019479798918057765, 0.016333298025918857, 0.018057871111003414, 0.005797776817676744, 0.032206444136266194, 0.024260439444333315, 0.011414942880427199, 0.030292612367442677, 0.03167445232559528, 0.0606448408216238, 0.05146080149071557, 0.05981128090726478, 0.01497855706007353, 0.03646554059482046, 0.08153118006885052, 0.06476329732686281, 6.9727344172341486, 51.82685647691999, 50.37250818525042, 45.430546351841514, 26.645552975790842, 28.48499127796718, 36.902369090488975, 41.406538827078684, 46.42303051267351, 54.28926331656319, 31.45418930053711, 0.07528983176286731, 0.036482293624430895, 0.3377200966434819, 1.626013200197901, 35.42510216576712, 54.10667855398995, 54.668992791857036, 51.41058989933559, 47.597189222063335, 41.22472184044974, 41.56336314337594, 39.33458253315517, 36.68675259181431, 35.74221100125994, 34.50854097093855, 35.6052029473441, 34.727881704057964, 35.717812401907786, 34.797693729400635, 34.373745918273926, 35.98623868397304, 33.54472507749285, 34.43352474485125, 33.242693832942415, 32.9267383984157, 33.6122476713998, 33.86548866544451, 35.175807748522075, 34.06888675689697, 34.40920604978289, 34.53636850629534, 32.59619174684797, 34.77355916159493, 35.515119552612305, 35.560334954942974, 33.45158100128174, 32.884337016514365, 33.73388283593314, 34.63313954217093, 34.075473649161204, 33.73402179990496, 33.3497690473284, 34.211286612919395, 34.4409384727478, 35.048329148973735, 34.30685561043875, 34.98304387501308, 33.72565269470215, 34.49663175855364, 32.50968320029122, 34.2496337209429, 34.08922413417271, 36.62936741965157, 44.357800074986045, 48.91734348024641, 41.133419036865234, 39.42212288720267, 47.23906169618879, 45.88094595500401, 45.424758502415244, 38.873017174857004, 40.372723306928364, 37.7096003804888, 42.764967237200054, 47.78895950317383, 48.89770787102835, 49.21583114351545, 47.647601876940044, 47.24415125165667, 48.564291613442556, 42.28849104472569, 41.484994411468506, 40.62326839991978, 43.386275155203684, 45.07823099408831, 46.47339800425938, 47.187672819410054, 47.7997396332877, 44.36464057649885, 50.29133585521153, 49.41785001754761, 38.78049496241978, 47.46293960298811, 40.57366173607962, 34.8904104913984, 35.35669020244053, 36.33155025754656, 35.621965476444785, 35.90125526700701, 34.997992924281526, 35.43570164271763, 35.167671407972065, 35.985870429447715, 34.195448194231304, 35.152503490448, 34.98388460704258, 35.57685429709298, 34.8521328653608, 35.06251042229788, 34.848210607256206, 35.409857818058555, 35.804584980010986, 38.20519801548549, 36.52277510506766, 36.035616057259695, 36.64549766268049, 36.487700598580496, 35.89645058768136, 36.59121486118862, 37.52798836571829, 37.82716390064785, 38.15235001700265, 39.42776829855782, 39.2991224016462, 38.025503703526084, 39.800740650721956, 40.50378022875105, 44.893870966775076, 49.41226019178118, 47.56975078582764, 47.27297237941197, 42.36431673594883, 45.951998233795166, 42.43834631783621, 45.71584633418492, 49.050554343632285, 54.79555422919137, 57.774201801845, 62.079076358250205, 43.21918487548828, 1.50132788504873, 0.3966435619762966, 0.15225588929440292, 0.10532806813716888, 21.41822862625122, 64.79878888811383, 53.64486653464181, 49.73203018733433, 30.32596513203212, 34.89542709078108, 42.85655491692679, 51.11638580049787, 55.845506940569194, 15.344681433268956, 0.1438828350177833, 0.027379588589870503, 0.05295560395877276, 0.06142540715102639, 0.031047455434288298, 0.0029817156942694312, 0.1047947463978614, 0.049011812545359135, 0.058722917522702894, 0.03640995839876788, 0.15082108628536972, 0.07638947239943913, 0.08559453274522509, 0.13475371631128447, 0.17008138421390737, 0.16903696954250336, 0.09776755954538073, 0.1310229000768491, 0.18639449243034634, 0.1503018441476992, 0.1588886505258935, 7.759567533220563, 58.24011673246111, 56.660304818834575, 51.09203931263515, 31.61204195022583, 31.90189300264631, 35.97573300770351, 46.45496443339756, 52.927044664110454, 59.98415279388428, 34.88391045161656, 0.12737874633499555, 0.16015539398150785, 0.8008651116064617, 2.3157931183065688, 37.600683893476216, 57.062077454158235, 56.960324559892925, 54.618072918483186, 49.52952493940081, 43.10863903590611, 44.03886386326381, 40.632394858769004, 38.67416320528303, 37.84397159303938, 35.236733027866904, 37.744890281132285, 36.86185761860439, 37.906387260981965, 36.822259834834504, 36.69991595404488, 37.83032185690743, 34.65957048961094, 35.802799292973106, 34.78266824994768, 34.67062159946987, 36.00170884813581, 36.06052187510899, 37.53731632232666, 35.89617960793631, 36.19258281162807, 35.669953210013254, 35.48696545192173, 37.126663889203755, 38.33117233003889, 36.680992535182405, 35.75182383401053, 34.405311584472656, 35.333524908338276, 37.24065950938633, 34.47453996113369, 35.90256152834211, 33.84115259987967, 35.660072871616904, 37.15025302342006, 37.291238921029226, 35.28648212977818, 37.60578734534127, 35.50083058220999, 36.08453137534005, 34.38809047426496, 35.33810377120972, 36.097649574279785, 38.444163935525076, 46.33356550761631, 51.93312570026943, 41.33072355815342, 38.46673515864781, 50.3356306212289, 47.8630724634443, 48.60000535420009, 40.573793751852854, 43.09190429959978, 40.17565502439226, 45.19970635005406, 50.56691183362688, 52.51969262531826, 51.37132215499878, 51.11900874546596, 50.44279963629586, 51.48875365938459, 45.284255504608154, 44.253090722220286, 41.58865806034633, 44.788268770490376, 47.49230963843209, 47.40770489828927, 48.83514976501465, 49.6066951070513, 47.09282990864345, 50.458651951381135, 47.71907104764666, 42.45261444364275, 48.41064609800066, 42.42563458851406, 37.00660596575056, 37.853025095803396, 38.14583608082363, 38.55945886884417, 37.855109555380686, 36.68619326182774, 37.30756718771798, 36.73050192424229, 36.883925097329275, 35.53846549987793, 36.68246555328369, 36.77932344164167, 36.741851806640625, 37.33021484102522, 37.54292351858956, 36.54191739218575, 37.88030024937221, 38.066383429935996, 41.19113424846104, 37.46951927457537, 38.97383206231253, 38.59408521652222, 39.40292501449585, 37.02378191266741, 38.49043198994228, 39.279000418526785, 40.847101143428254, 39.78257458550589, 41.793466636112754, 40.81322520119803, 39.53350945881435, 41.33610841206142, 43.743412562779014, 47.43010241644723, 52.220885344914024, 51.03207983289446, 50.68374579293387, 45.96302849905831, 50.267510482243125, 43.16456856046404, 47.448435238429475, 51.59689542225429, 57.144264221191406, 59.759170123508994, 65.62488801138741, 46.15399626323155, 1.982641760792051, 1.2215988380568368, 0.5469388514757156, 0.30815024620720316, 23.482161487851823, 70.5451853615897, 60.02769715445382, 60.21589606148856, 45.31420224053519, 45.27940566199166, 51.75274699074881, 58.44233363015311, 64.86196885790143, 21.448762484959193, 0.3934313771980149, 0.08134595357945987, 0.16442059725522995, 0.13451898390693323, 0.1982012188860348, 0.11066969936447484, 0.2266704990927662, 0.07227681058325938, 0.0968641715922526, 0.12131116406193801], [0.010077882840830301, 0.04697368673181959, 0.05253612682489412, 0.03464839667347925, 0.0400097122016762, 0.06734567268618516, 0.03352610653798495, 0.043674350915742774, 0.035085488576442, 0.02707609175039189, 0.09142615446554762, 1.43557100210871, 35.96254880087716, 44.883716174534385, 41.951301915305, 31.584054606301443, 27.975182839802333, 29.779603958129883, 29.820730345589773, 42.49524859019688, 49.88414709908621, 33.589853627341135, 0.22109484113752842, 0.06537514592387847, 0.21359108521470002, 1.7619031369686127, 30.028394630977086, 52.192039898463655, 51.91643612725394, 50.01792424065726, 45.958237716129844, 39.744821548461914, 36.01304483413696, 35.45379475184849, 33.75484902518136, 35.0070082119533, 32.76309095110212, 36.07914999553135, 34.26949862071446, 32.2443071774074, 33.453901699611116, 36.90137202399117, 35.215613978249685, 32.85558884484427, 32.19342204502651, 36.226021017347065, 39.237335545676096, 41.54350866590227, 42.26246656690325, 42.6128260067531, 40.04367399215698, 41.93656478609358, 38.81220654078892, 35.807301725660054, 34.36372314180647, 31.65271670477731, 35.597980294908794, 34.80942923682076, 33.01102352142334, 33.0858347756522, 30.8314048903329, 32.59941571099417, 33.86505787713187, 32.843227999550955, 33.38109500067574, 32.31265313284737, 32.2921142578125, 32.43134226117815, 33.56735188620431, 33.56944676807949, 33.978643553597585, 33.55109657560076, 33.11585099356515, 32.190340518951416, 33.916234833853586, 41.65472500664847, 45.54850244522095, 39.340589250837056, 38.84921612058367, 46.777298314230784, 45.01495722361973, 43.68229968207223, 39.71652500970023, 37.766568660736084, 35.65675163269043, 38.49219683238438, 44.58219909667969, 47.19126851218087, 45.20956931795393, 47.634542737688335, 47.35051427568708, 44.47677755355835, 40.749697821480886, 39.72356700897217, 43.8147531918117, 44.01718895775931, 46.53359372275216, 45.779241698128835, 47.46603502546038, 50.385369300842285, 53.362338883536204, 42.98197684969221, 34.33955730710711, 46.05220167977469, 41.71687316894531, 35.07738651548113, 33.780925614493235, 35.168477399008616, 35.14444358008248, 33.49807834625244, 33.03372328622, 33.29640688214983, 33.81006635938372, 32.85645389556885, 33.85903031485421, 32.704086848667686, 32.82011134283883, 32.49804149355207, 33.790639196123394, 33.28013072695051, 33.70813281195504, 32.96830947058541, 34.97019665581839, 36.45315762928554, 37.63217312949044, 38.00869253703526, 35.748509543282644, 34.21412147794451, 34.185418469565256, 34.67868150983538, 33.858495303562705, 34.56435585021973, 34.91694566181728, 35.6633871623448, 37.68220363344465, 36.64465345655169, 37.96393918991089, 36.03126301084246, 40.76872198922293, 46.95471361705235, 47.586419514247346, 50.68897083827427, 49.8355062348502, 48.92134911673409, 47.5648627281189, 45.68679591587612, 46.98871462685721, 48.90231800079346, 54.729403904506135, 53.59000355856759, 58.70359284537179, 37.44159099033901, 0.818991441811834, 0.18313356169632503, 0.2842441275715828, 0.12185005657374859, 18.2714398588453, 59.950363704136436, 47.02296577181135, 41.61711440767561, 26.392523901803152, 23.58894487789699, 38.643031801496235, 43.60870783669608, 49.24036175864083, 13.217526912689209, 0.11262875209961619, 0.014313404448330402, 0.018136971330802356, 0.05038504867947527, 0.031075872480869293, 0.06621293311140367, 0.038693568004029136, 0.036545936816505024, 0.047176558524370193, 0.0775472702724593, 0.036855250397431, 0.02115912050274866, 0.050387196242809296, 0.07169365044683218, 0.06620962864586286, 0.06161462342632668, 0.020838102192751, 0.03532832947426608, 0.06362959423235484, 0.04407015396282077, 0.03923316279958401, 1.8517222830227442, 42.18020336968558, 51.55942031315395, 45.32361357552664, 36.5517977305821, 28.747508117130824, 31.786723136901855, 37.36060626166207, 48.14305707386562, 54.674926553453716, 36.53553547177996, 0.10180709564260074, 0.10123468350086894, 0.31867201732737677, 2.183503108365195, 32.91678510393415, 55.37870611463274, 54.71929080145699, 51.442037446158274, 47.88903440747942, 40.62751374925886, 38.25008685248238, 36.955828530447825, 35.121003832135884, 35.992412158421104, 35.54866198131016, 37.74619306836809, 35.227749007088796, 34.9502831186567, 35.641079970768516, 36.592729568481445, 37.59138372966221, 34.52326420375279, 32.88075869424002, 37.56742286682129, 40.580019337790354, 43.30588449750628, 44.740701402936665, 42.208576338631765, 41.91631426130022, 43.271609033857075, 39.28615358897618, 36.7859902381897, 35.55479724066598, 35.46637099129813, 36.85860933576311, 36.06964833395821, 34.714548110961914, 34.92308439527239, 32.25742885044643, 34.56019040516445, 34.64439909798758, 33.64404610225132, 34.460827691214426, 35.03085790361677, 33.236940724509104, 34.052843366350444, 34.823256152016775, 34.25229140690395, 35.28407457896641, 35.26222596849714, 34.51379033497402, 33.09271349225725, 35.36695269175938, 43.85945095334734, 46.451865536826, 40.54640047890799, 40.15795448848179, 49.59366723469326, 45.09355524608067, 45.74794701167515, 40.87411226545061, 38.493906089237754, 36.606379304613384, 39.35211631229946, 47.55971758706229, 48.31837402071272, 47.60554443086897, 48.64483513150896, 48.716971329280305, 46.65646914073399, 43.51366342817034, 41.3856212752206, 45.164475509098594, 46.08769307817732, 46.9963368007115, 46.52223341805594, 49.57550116947719, 50.52503851481846, 52.87778541019985, 49.28073426655361, 38.02365548270089, 47.06337649481637, 43.646165575299946, 36.778903075626914, 34.27040883472988, 35.79811273302351, 35.444751671382356, 35.069569792066304, 35.53946604047503, 35.297359534672324, 34.53899492536272, 34.95848546709333, 35.525639125279014, 35.63618843896048, 33.6308445249285, 35.31309025628226, 35.4122097832816, 35.51691913604736, 35.39896304266793, 35.22093282427107, 36.64397948128836, 38.03408472878592, 39.020579542432515, 38.904968466077534, 36.775105885096956, 36.89777980531965, 37.04893786566598, 37.162877900259836, 36.50948667526245, 35.735217639378135, 36.57718644823347, 37.445412499564036, 40.312277453286306, 38.06402799061367, 40.77712236131941, 38.02833162035261, 41.830806255340576, 48.53731523241316, 51.212840693337576, 51.34508228302002, 52.94623211451939, 50.74309035709926, 49.86203793116978, 47.41135617664882, 48.340212208884104, 50.543235846928184, 56.91843387058803, 54.418135029929026, 61.96911416734968, 38.85461139678955, 1.1135140721287047, 0.6979024165443012, 0.20228021857993944, 0.11758475830512387, 20.727699279785156, 64.05731187547956, 52.34245450156075, 46.545082569122314, 37.14824499402727, 33.19701984950474, 45.040259088788716, 49.584266321999685, 58.1371340070452, 17.538870436804636, 0.07451553509703704, 0.04600231635517307, 0.034524838839258463, 0.03314331439988954, 0.04751427897385188, 0.04669990124447005, 0.06665873061865568, 0.023511825328958885, 0.031635721546730826, 0.06645339913666248, 0.2019109869641917, 0.11117676179856062, 0.1966420811201845, 0.17333239476595605, 0.13770412227937154, 0.1793736091681889, 0.09057353450251476, 0.12501251830586366, 0.18798003877912248, 0.1604339868894645, 0.23010794392653874, 2.151828008038657, 50.791199684143066, 58.28125354221889, 52.750560419900076, 42.544619015284944, 37.58574526650565, 39.65188939230782, 40.83649819237845, 53.55669389452253, 58.26678391865322, 41.33200897489275, 0.2489079236984253, 0.20912465559584753, 0.5184012427926064, 2.3470715199198042, 34.70767634255545, 57.56106928416661, 58.38981219700405, 53.53614459718977, 50.900119645254954, 41.78884955814907, 39.861547810690745, 39.19624042510986, 37.676579066685264, 38.41810819080898, 36.55366679600307, 40.55521079472133, 38.85383319854736, 35.393574714660645, 37.03646584919521, 39.236321108681814, 40.71741649082729, 36.857077257973806, 35.256219250815256, 40.13490383965628, 42.986395903996055, 44.975404603140696, 47.880255358559744, 44.94208104269845, 43.96344116755894, 46.2920743397304, 42.44568708964756, 38.977514607565745, 37.67846202850342, 36.634672369275776, 39.53419733047485, 38.41033315658569, 37.20931271144322, 37.72994123186384, 33.21199321746826, 37.17145197732108, 37.16098799024309, 36.69072348730904, 36.00557204655239, 36.45283453805106, 33.63118151256016, 34.46302679606846, 37.00688736779349, 36.001083510262625, 37.732748304094585, 37.36834308079311, 35.66531876155308, 34.49110794067383, 36.62944037573678, 46.35952397755214, 50.22089154379708, 43.59261580875942, 42.87529420852661, 49.294432640075684, 48.12152113233294, 47.28837653568813, 43.180719648088726, 41.205801895686555, 40.584368910108296, 40.72794301169259, 49.94035455158779, 50.413530349731445, 49.665216309683665, 51.11787966319493, 50.481521947043284, 48.50759431294033, 45.713195596422466, 42.69721187864031, 47.36023827961513, 47.17391191210066, 49.597971643720356, 48.20130729675293, 51.46471636635916, 51.93089880262102, 53.00570522035871, 47.23414237158639, 41.81355735233852, 50.02396222523281, 44.31066696984427, 37.08110455104283, 37.340074334825786, 39.0934487751552, 38.21615532466343, 36.70895208631243, 36.56100409371512, 36.372030462537495, 35.98739208493914, 35.95138999394008, 38.80879497528076, 36.63517958777291, 35.08421312059675, 36.55587979725429, 37.574089663369314, 37.32110227857317, 38.29364858354841, 36.80908257620675, 39.134561266217915, 40.56044626235962, 41.51741123199463, 42.77751915795462, 39.50919076374599, 39.005435943603516, 39.36559581756592, 38.739757674080984, 36.79798282895769, 37.41198124204363, 36.76505878993443, 38.78259331839425, 42.29976797103882, 40.125155517033164, 42.73192160470145, 40.70552812303816, 44.61160387311663, 51.735942772456575, 52.1469669342041, 54.27655506134033, 53.84233781269619, 53.422538076128276, 52.22550937107631, 50.69481079918997, 51.609339645930696, 52.82035854884556, 60.48237337384905, 57.537897041865754, 62.353113310677664, 41.64834656034197, 1.510800016777856, 1.2605715010847365, 0.7405283663954053, 0.18991710697965963, 23.149283715656825, 71.37144429343087, 59.143309593200684, 55.95760917663574, 38.46599864959717, 33.546170302799766, 52.90547398158482, 56.98290273121425, 67.20026002611432, 23.914874451501028, 0.16230495220848493, 0.16965786979666778, 0.099678253089743, 0.1637486033141613, 0.11532552167773247, 0.20009225527090685, 0.13013403277312005, 0.08926228593502726, 0.07895632287753479, 0.25937921181321144], [0.03794744071949806, 0.01418419017656041, 0.021415543975308537, 0.008952593580553574, 0.02788916669253792, 0.06528052421552794, 0.027428320974909833, 0.032150658379708014, 0.017006313162190572, 0.07439792462225471, 0.02690579472774906, 0.5592197382024356, 27.90998441832406, 48.37570013318743, 46.04821341378348, 23.47847546849932, 22.059208631515503, 29.11145649637495, 27.974786792482647, 42.293497221810476, 48.612630231039866, 40.17918470927647, 0.8143683927399772, 0.07976376597902604, 0.32836977552090374, 1.0553188920021057, 21.250596387045725, 52.7673785345895, 50.350982666015625, 49.69481563568115, 45.328220231192454, 40.82084042685372, 37.34851292201451, 39.38106598172869, 40.759258542742046, 42.82512821469988, 42.159886837005615, 43.2613639150347, 40.0221380506243, 37.077963965279714, 38.05467571531023, 36.26455225263323, 31.924624034336635, 35.52374574116298, 40.509738309042795, 48.649931635175435, 44.88598823547363, 43.15312140328543, 42.807434626988, 41.746906757354736, 42.6999842098781, 42.264665671757285, 43.17596708025251, 41.10438251495361, 39.00947284698486, 38.4896433694022, 37.03354065758841, 36.71024097715105, 32.823925903865266, 32.521727902548655, 32.755677223205566, 33.074380670275005, 31.58667755126953, 32.05766119275774, 32.144454615456716, 34.18775653839111, 32.983526025499614, 32.427135126931326, 33.520701680864605, 33.60412522724697, 33.85380874361311, 34.090669359479634, 33.491897923605784, 33.44274289267403, 31.167253017425537, 39.79174620764596, 45.131933620997835, 47.530938148498535, 48.9520914213998, 46.68361575262887, 48.680451597486226, 44.74844864436558, 40.7038014956883, 37.765745299203054, 36.7781526701791, 37.55113976342337, 43.644268717084614, 47.673105239868164, 47.839243616376606, 44.63372346333095, 47.04685020446777, 44.015573501586914, 40.35563768659319, 43.54252971921648, 47.3837822505406, 48.69318069730486, 46.65685823985508, 46.78125531332833, 44.50929512296404, 42.999232700892854, 36.98913472039359, 38.151672567640034, 46.91243382862636, 44.259229455675396, 36.46394123349871, 33.48869480405535, 34.58903585161482, 35.0225374358041, 33.44179098946707, 34.23167610168457, 32.81007466997419, 33.611924580165315, 33.28249658857073, 33.80243376323155, 32.12531580243792, 31.096259798322404, 32.22188881465367, 33.646675995418, 32.45638356889997, 32.492802551814485, 32.713588510240825, 32.783709730420796, 37.30707039151873, 39.383404050554546, 42.83078752245222, 42.97866950716291, 40.46188606534685, 39.770446504865376, 36.41319159099034, 34.633101327078684, 34.608695779527935, 36.280480997903005, 34.170316559927805, 35.88762290137154, 37.28360285077776, 37.242479937417166, 35.233116490500315, 36.87396138054984, 37.31530053274972, 44.39916270119803, 48.817087922777446, 51.383227893284385, 51.50695446559361, 52.69578429630825, 52.4496408871242, 51.471657616751536, 50.814170428684776, 50.480149677821565, 55.78676339558193, 55.55432530811855, 59.78863048553467, 29.645941461835587, 0.6619409833635602, 0.37669343820640017, 0.04298551234283617, 0.042089035268872976, 17.171369791030884, 59.820314271109446, 48.42204461778913, 43.36123037338257, 21.597558157784597, 18.823632308415004, 33.976402759552, 43.06899956294468, 48.231771673474995, 14.17671877997262, 0.0295367922101702, 0.0020334683067630976, 0.03751154982351831, 0.004210396728012711, 0.02784937570270683, 0.06144039598958833, 0.05507815309933253, 0.06674862293792622, 0.02568561234511435, 0.01862785579370601, 0.03995961596124938, 0.013684387219005396, 0.04321982066280075, 0.06548532644020659, 0.05736696706818683, 0.024409657776621834, 0.13170604913362435, 0.015282394863399012, 0.03649563701557262, 0.038445895936872275, 0.03522818788353886, 0.5789804692779268, 33.47040367126465, 54.93589741843087, 51.89608137948172, 30.00459357670375, 24.568124975476945, 30.640655994415283, 33.26452854701451, 48.43492657797677, 53.35945190702166, 42.50649077551705, 0.7341951919453484, 0.08275549472974879, 0.12723235919007234, 1.3183124427284514, 23.253704718181066, 54.02102810995919, 51.317629950387136, 50.83592176437378, 47.237932613917756, 42.6005276952471, 38.23426580429077, 40.02072409221104, 42.009065764290945, 43.2998708316258, 44.044557912009104, 44.925377573285786, 40.78014482770647, 37.09101268223354, 37.76919160570417, 37.42264672688076, 33.212528228759766, 35.95691728591919, 41.52690941946847, 49.46849891117641, 46.538909094674246, 46.68699605124337, 44.48998607907976, 43.64502607073103, 44.659775733947754, 44.381965909685405, 46.154989855630056, 43.677738189697266, 41.65735489981515, 39.23738070896694, 39.05475773130144, 37.150398935590474, 34.54815265110561, 33.56535427910941, 33.7142402785165, 33.81789003099714, 32.97175577708653, 33.440797397068565, 33.88765689304897, 35.64189985820225, 34.840612752096995, 34.773006779806956, 33.97969967978341, 34.12337105614798, 36.31350231170654, 35.076927934374126, 34.62551042011806, 36.62180083138602, 33.17951733725411, 41.96412134170532, 47.641497884477886, 49.358901500701904, 50.3531539780753, 46.52678796223232, 48.24367046356201, 46.2973758152553, 42.52548715046474, 38.53068290437971, 38.48683977127075, 40.11451087679182, 44.19295058931623, 48.4402072089059, 48.43383918489729, 48.57521070752825, 47.725706577301025, 46.546559061322895, 41.08631025041853, 45.97414561680385, 47.49650982448033, 50.49670723506382, 49.098507336207796, 48.66502659661429, 46.91405275889805, 47.48356533050537, 41.737978322165354, 38.59602723802839, 47.52135310854231, 47.55503797531128, 39.003883021218435, 34.282429218292236, 35.275785378047395, 35.94665479660034, 36.187062467847554, 36.318828105926514, 34.56338310241699, 35.892111437661306, 34.200044427599224, 34.00227090290615, 34.64533710479736, 33.16513804027012, 33.339767115456716, 35.01640912464687, 34.69416904449463, 34.75236368179321, 34.26128237588065, 34.9659652028765, 38.57003402709961, 40.82273728506905, 44.92788587297712, 44.042612416403635, 42.733325140816824, 40.91495030266898, 38.29502432686942, 36.601706641060964, 36.1385258265904, 37.41856813430786, 35.995966162000386, 39.13778175626482, 39.21741853441511, 39.18313612256731, 37.34561204910278, 38.529400961739675, 39.58939034598214, 46.93134682519095, 51.1388840675354, 52.77594566345215, 53.11006021499634, 54.544078077588765, 55.2180290222168, 53.668757915496826, 53.650070735386436, 52.646969727107454, 57.40991817201887, 59.09849371228899, 63.46690954480852, 31.649996485028947, 0.6586552453892571, 0.6533913335629872, 0.2702826181692736, 0.054436767872955115, 19.831805501665386, 65.87322357722691, 52.3615585735866, 50.016722202301025, 27.27404706818717, 23.717248576028005, 40.98521743501936, 50.78649575369698, 56.99074029922485, 19.091172695159912, 0.04474554397165775, 0.024656476585992744, 0.13058384720768246, 0.05005250545218587, 0.046680396755359004, 0.026693927257188728, 0.04899149042155061, 0.042460451767380746, 0.01753230841963419, 0.02737076933096562, 0.15119353415710585, 0.13140074908733368, 0.14443814807704516, 0.058739310928753445, 0.1330805303794997, 0.18422543310693332, 0.1616412771067449, 0.11763408780097961, 0.17192173403288635, 0.16475636352385792, 0.2036511307316167, 0.8742565448795045, 38.212771551949636, 62.317003522600444, 57.96164335523333, 35.03791727338518, 31.353409154074534, 37.75168909345354, 38.2452335357666, 54.250429834638325, 59.27352578299386, 48.2160895892552, 0.9915734039885657, 0.3874499553016254, 0.46257941531283514, 1.686486303806305, 24.948563167027064, 54.99054847444807, 53.77715328761509, 53.568839345659526, 49.43790251868111, 44.57413223811558, 40.33763142994472, 43.16909531184605, 44.94733388083321, 45.46142414637974, 46.34340068272182, 48.36529173169817, 42.116905280521934, 40.58204473767962, 41.291692052568706, 39.347252573285786, 34.07462249483381, 38.157554217747276, 43.40036957604544, 51.304456165858674, 48.214654786246165, 46.08166898999895, 44.52549832207816, 44.018505641392295, 45.51209388460432, 45.44645425251552, 48.176331996917725, 45.74596677507673, 43.583006450108115, 41.75353881290981, 41.606247425079346, 39.361065592084614, 36.73858962740217, 36.61940370287214, 36.28567477634975, 35.195512839726035, 35.168546880994526, 34.442321164267405, 35.397177355630056, 37.40955284663609, 36.15491662706648, 35.14284896850586, 36.80877685546875, 35.78240980420794, 38.50310550417219, 36.825459480285645, 36.71661594935826, 38.495177609579905, 33.88204969678606, 44.885133607046946, 49.83085788999285, 51.406931672777446, 51.529914787837434, 49.47323063441685, 51.06243651253836, 49.86755132675171, 43.973151275089805, 41.144299915858674, 40.546139921460835, 41.75771468026297, 47.150440897260395, 50.594815799168174, 49.64270414624895, 49.791100297655376, 49.808918952941895, 46.95011738368443, 41.96264137540545, 46.033177512032644, 50.30572557449341, 52.93187018803188, 49.712054116385325, 48.10004425048828, 46.00587109157017, 46.11405454363142, 43.71247223445347, 43.016693523951936, 48.98703391211373, 49.54278557641165, 41.20505496433803, 36.27791016442435, 36.656170095716206, 37.55216809681484, 37.48875188827515, 37.55064991542271, 36.127078669411794, 37.76260471343994, 34.863517488752095, 37.32506275177002, 35.404945441654746, 34.10963099343436, 34.76042011805943, 37.09384754725865, 36.13034432274954, 35.41426992416382, 37.56672804696219, 34.93241235188076, 40.8409207207816, 43.29874174935477, 46.99186910901751, 47.03758825574602, 45.384757723127095, 43.78820412499564, 40.75985261372158, 37.66888741084507, 38.051086970738, 39.953045163835796, 37.25741509028843, 40.247627939496724, 39.71684462683541, 41.2137645312718, 38.16787576675415, 40.327806677137104, 40.56135300227574, 48.73074613298689, 52.52021026611328, 54.842381613595144, 55.2071863583156, 56.26055063520159, 56.654447487422395, 56.68285519736153, 55.48947082247053, 55.1480085509164, 60.80507550920759, 61.321493421282085, 65.36746420179094, 33.959143434252056, 1.5143667225326811, 1.3145777859858103, 0.41330998337694574, 0.12761795707046986, 21.870858601161412, 72.07258701324463, 57.422803606305806, 56.601787090301514, 29.99932336807251, 27.566284826823644, 47.87655544281006, 58.76038047245571, 64.70357077462333, 25.657097033091954, 0.13200098116483006, 0.11160833721182176, 0.29199354031256264, 0.07095119064407689, 0.11761890218726226, 0.13553038106432982, 0.20832124299236707, 0.12688006380839006, 0.1592159622481891, 0.10733528328793389], [0.04276797740853258, 0.048724239226430655, 0.06545548447008644, 0.06822323559650353, 0.017941619402595928, 0.0547682186588645, 0.019968445911737423, 0.03523841340626989, 0.03595225938728877, 0.027684793641258563, 0.02922065256695662, 0.02184325173896338, 14.866610629217965, 50.942729473114014, 42.816745213099885, 41.82945135661534, 32.395260265895296, 27.357435873576573, 25.218320029122488, 41.427258355276926, 47.94868816648211, 42.26029178074428, 2.145921604973929, 0.07617324364504643, 0.1669600417039224, 0.16909674847764627, 15.366827079227992, 47.39010163715908, 48.72337062018258, 50.5179374558585, 47.06900800977434, 42.17816754749843, 42.59993362426758, 45.38165882655552, 47.969841957092285, 46.93428591319493, 45.860122203826904, 46.75925036839077, 45.705118315560476, 39.00399766649519, 31.997361251286097, 31.988936560494558, 37.32343339920044, 43.88627447400774, 46.8858118057251, 40.477665424346924, 39.39412859507969, 40.037114892687114, 41.840373924800325, 42.28334590366909, 40.98040580749512, 42.80988734109061, 43.605775696890696, 43.05654491697039, 45.37931033543178, 42.88135303769793, 40.04763446535383, 38.43934188570295, 34.57488237108503, 29.91910294124058, 32.115195751190186, 32.750059604644775, 31.837750707353862, 32.07359341212681, 30.617212772369385, 32.910500458308626, 33.515368938446045, 32.333629744393484, 34.25493172236851, 34.50786004747663, 33.75119079862322, 32.29146807534354, 33.295166628701345, 32.815365723201204, 33.674576486860005, 33.98886782782418, 41.84069006783621, 45.261350767953054, 45.0887679372515, 47.616988113948274, 46.9448367527553, 44.40237276894705, 39.68251705169678, 38.09095573425293, 36.81094469342913, 36.525960854121614, 42.14146716254098, 48.60164165496826, 46.15934290204729, 45.00380883898054, 47.33764968599592, 43.99126870291573, 41.868055547986714, 48.16161571230207, 48.76089784077236, 43.07908139910017, 40.32334245954241, 37.77037974766323, 35.977699347904746, 38.043367522103445, 43.1420807157244, 48.594339098249165, 44.5180845941816, 39.07420226505825, 34.94687155314854, 33.296007360730854, 32.85519627162388, 33.46694694246565, 33.045774936676025, 33.8781031199864, 32.74259376525879, 33.18300880704607, 32.81028659003121, 34.39234972000122, 32.61537919725691, 32.226894991738455, 32.32972138268607, 33.866075788225444, 32.82911968231201, 31.910769326346262, 33.375654561179026, 38.06124176297869, 41.45148324966431, 43.589756625039236, 45.49393129348755, 48.42987176350185, 47.54257985523769, 45.59083781923567, 45.96876423699515, 42.134769099099294, 40.254572663988384, 36.07193429129464, 35.0631913457598, 33.858057567051475, 35.064132826668875, 38.520875522068565, 37.445256165095735, 35.16818904876709, 35.6748377936227, 37.17952578408377, 46.35603598185948, 47.523392404828755, 51.72840745108468, 50.95185593196324, 53.52910259791783, 51.89534139633179, 53.60187802995954, 52.346126624516074, 56.74950579234532, 54.455658776419504, 53.15040145601545, 19.604767901556833, 0.06461281183042697, 0.5320946222969464, 0.1155303306877613, 0.030472240942929472, 14.805897269930158, 57.05321502685547, 48.19160066332136, 42.999746867588584, 35.42951774597168, 31.87928703853062, 34.22103840964181, 37.07818978173392, 41.51189088821411, 10.522659403937203, 0.02302842341097338, 0.03580579421083842, 0.19669853523373604, 0.058052742055484226, 0.057585591051195345, 0.03783766732418111, 0.029077597028974975, 0.032302904674517255, 0.0892906758402075, 0.02987186637307916, 0.03474682157060929, 0.016772922560838715, 0.030694172784153904, 0.04863926628604531, 0.043219159091157575, 0.016781443264335394, 0.04880631482228637, 0.02333802536928228, 0.04933866625651717, 0.03763353345649583, 0.030548135084765296, 0.03914253426981824, 20.604347910199845, 57.25824247087751, 48.41725036076137, 42.92494256155831, 30.875036103384836, 29.369156496865408, 30.317738464900426, 46.04118531090872, 52.14574752535139, 45.94276407786778, 2.2755971380642483, 0.1261681720082249, 0.20123299477355822, 0.5809892586299351, 16.356068168367656, 49.98193952015468, 50.465683528355186, 52.99452556882586, 47.88284008843558, 44.438385282244, 43.700538703373496, 47.18925700868879, 49.29911572592599, 49.339675835200715, 47.81716571535383, 49.0377105985369, 46.35396194458008, 41.3215206691197, 34.11061068943569, 33.19069698878697, 38.12566198621477, 45.40539387294224, 48.19644703183855, 41.957975660051616, 39.93288843972342, 40.48706981113979, 41.873002665383474, 41.703317233494346, 41.98218665804182, 43.35043287277222, 45.321164335523335, 44.59588009970528, 45.48792110170637, 44.5641303062439, 42.178101539611816, 39.297274180821006, 35.96683931350708, 32.98001371111189, 34.567750045231406, 34.80616705758231, 33.613606044224326, 33.19204841341291, 34.075584820338655, 35.35891710008894, 33.94450010572161, 33.835951873234336, 35.6772210257394, 35.6131204196385, 34.80766786847796, 34.548156125204905, 35.17184727532523, 34.69186919076102, 35.01035724367414, 37.13415057318551, 43.009884289332796, 45.912216322762625, 47.939134393419536, 49.01624413899013, 48.99200187410627, 46.04039669036865, 41.97928925922939, 40.126777921404155, 38.78606741768973, 38.392094135284424, 44.28810269492013, 48.82633944920131, 47.52375371115548, 46.386476039886475, 48.98903499330793, 45.75423165730068, 42.86516373498099, 49.793184757232666, 49.81433159964425, 45.82966130120413, 42.830749307359966, 40.13972936357771, 39.00407062258039, 40.58863510404314, 43.06695679255894, 49.00488730839321, 47.69065638950893, 40.02648414884295, 35.15150989804949, 35.07571199962071, 34.91685880933489, 35.249906812395366, 34.85087176731655, 35.77424219676426, 34.23068250928606, 34.783310958317344, 35.59411709649222, 36.31107044219971, 33.75011382784162, 34.42129244123186, 33.82082911900112, 34.42010082517351, 34.86078337260655, 33.66294867651803, 35.214189597538535, 38.66130208969116, 43.76204415730068, 45.696936811719624, 46.84452908379691, 48.567487784794395, 50.184750488826204, 47.530955518995015, 46.96599401746477, 43.91885110310146, 41.51315893445696, 37.60621118545532, 36.65481867109026, 35.75569398062569, 37.02854837690081, 39.61956984656197, 39.47107294627598, 37.93807799475533, 37.03927986962454, 40.09110586983817, 48.7832293510437, 50.11000176838466, 52.99376821517944, 54.49560397011893, 54.98663663864136, 52.83560289655413, 55.604682377406526, 55.843064648764475, 57.162579672677175, 56.46211092812674, 55.5188512802124, 20.86478897503444, 0.07467231739844594, 0.8635775436248098, 0.1387016230395862, 0.06356109612222229, 16.38652559689113, 64.08577864510673, 51.35009888240269, 50.57092441831316, 32.42520352772304, 28.629951545170375, 40.891444546835764, 41.58504499707903, 52.497420174734934, 15.214413131986346, 0.06461666590933289, 0.04654947342351079, 0.054972705364759476, 0.044508426516715965, 0.01556783588603139, 0.027068929813270057, 0.023863657610490918, 0.013966734121952738, 0.014407011746828045, 0.025190431059205105, 0.1887217725494078, 0.13354618182139738, 0.16220680890338762, 0.19176536851695605, 0.16925570209111485, 0.16334631347230502, 0.14144503511488438, 0.1154581888445786, 0.12763667106628418, 0.11913970272455897, 0.13173620322985308, 0.09373599623462983, 23.29200666291373, 67.76388399941581, 54.542723178863525, 53.78344488143921, 41.09288672038487, 36.25648191996983, 33.07478713989258, 50.999478885105674, 55.71677071707589, 50.404028688158306, 2.503933399915695, 0.17336447590163775, 0.2822956735534327, 1.086845148886953, 17.509701899119786, 50.66997446332659, 51.89121069226946, 55.49020733152117, 51.78680011204311, 46.55370875767299, 46.59634985242571, 49.65314728873116, 52.92390407834734, 50.9026175226484, 48.873083455221995, 50.306896345955984, 48.83263799122402, 43.671665464128765, 35.59795250211443, 35.068197522844585, 40.49946192332676, 48.72219984872, 49.67495421000889, 41.586834158216206, 41.55160679136004, 40.36464950016567, 42.26430436543056, 42.42353275844029, 42.81493520736694, 44.87937355041504, 47.84623350415911, 46.90587820325579, 48.66810464859009, 46.67851577486311, 43.605758326394216, 42.50165135519845, 38.07909515925816, 32.98688895361764, 36.2150011743818, 37.04280955450875, 34.113487243652344, 34.542667048318044, 33.82170806612287, 35.91226816177368, 36.1621219090053, 34.98491988863264, 36.949509143829346, 37.34876305716378, 36.425614970070974, 36.003980909075054, 36.81849043709891, 36.603714670453755, 37.75600045067923, 38.77100372314453, 45.3068197795323, 49.5256860596793, 51.01392418997628, 52.353005341121126, 50.89655521937779, 48.640214579445974, 43.131307533809114, 43.85067537852696, 40.51835754939488, 40.405445848192485, 46.08491379874093, 51.10964952196394, 49.70931652614048, 48.5815509387425, 51.33968005861555, 47.34570264816284, 44.422140393938335, 52.76503004346575, 51.5012013571603, 46.76871034077236, 44.4883463042123, 39.16083240509033, 40.00257887159075, 43.349359376089915, 46.09750740868704, 51.8350761958531, 48.330873829977854, 42.94959477015904, 37.872104849134175, 35.51943090983799, 37.65451506205967, 36.962415422712056, 35.82834781919207, 36.84312874930245, 36.21721417563302, 36.35598707199097, 36.73439986365182, 38.423069204602925, 35.70177943365914, 35.88010842459542, 35.08351482663836, 36.77853829520089, 36.48485878535679, 35.730141980307444, 38.36430134092058, 40.43314831597464, 46.7847398349217, 47.41197804042271, 48.60255534308297, 52.69282783780779, 53.05099010467529, 50.08025305611746, 49.734194551195415, 47.33384207316807, 44.614782673971995, 40.19637107849121, 38.46300050190517, 37.833625725337434, 40.278877462659565, 41.80137716020857, 42.158326966421946, 39.676169872283936, 39.90580783571516, 41.34097909927368, 52.492719718388145, 51.912583351135254, 56.116834095546174, 54.97847597939627, 56.714629309517996, 53.551823207310264, 56.48802770887102, 57.229424817221506, 61.04913098471505, 58.80948339189802, 57.61275345938546, 23.15738184111459, 0.18905846162566117, 2.0234120530741553, 0.5183869664158139, 0.08441040092813117, 18.150598526000977, 69.27026040213448, 57.87708030428205, 55.52894353866577, 51.456607818603516, 42.04260124479021, 45.609778608594624, 50.15649216515677, 61.08642891475132, 21.61785384586879, 0.3601126479251044, 0.13145552043403896, 0.29234757274389267, 0.09760370012372732, 0.15425481274724007, 0.10769846915666546, 0.1094671046095235, 0.13104165478476457, 0.15267542749643326, 0.10641112537788493], [0.017199855098234754, 0.06180687275316034, 0.11694518476724625, 0.028348182061953203, 0.055782889747726064, 0.029706582027886595, 0.030151131030704294, 0.014154375347841, 0.02533789198579533, 0.08131813364369528, 0.035303301710103235, 0.02321193490310439, 6.320832712309701, 47.059148515973774, 46.04840448924473, 39.864497320992605, 23.958194732666016, 25.12054671560015, 27.87714375768389, 40.020119598933626, 45.52551780428205, 46.0593444279262, 5.975977982793536, 0.1539906726351806, 0.2840464838913509, 0.1561916366751705, 6.66293682370867, 43.876133578164236, 51.43024287905012, 48.036746161324636, 46.87386785234724, 46.047713143484934, 46.5307171685355, 48.897068636757986, 43.35610607692173, 44.86949668611799, 46.818160670144216, 45.38893011638096, 45.78606482914516, 35.49462236676897, 31.21929155077253, 35.484290395464214, 44.521364143916536, 44.68617194039481, 39.937661852155415, 37.99669647216797, 44.92924771990095, 44.4556029183524, 45.43377031598772, 44.686633995601106, 45.0631742477417, 41.91259002685547, 42.59637614658901, 42.755347456250874, 43.23191744940621, 42.35584340776716, 43.282858167375835, 38.90716062273298, 36.53365250996181, 31.502305575779506, 32.18983677455357, 31.72967495237078, 33.43886579786028, 32.60887915747506, 33.66684661592756, 32.24431412560599, 31.271743501935685, 32.884125096457346, 34.037751879010884, 32.375496115003315, 34.455210072653635, 33.00153923034668, 33.05528702054705, 33.498380592891145, 32.56233317511422, 32.604675497327534, 34.03709527424404, 37.48776524407523, 42.01442282540457, 42.2725692476545, 43.14034366607666, 43.11057758331299, 39.12024450302124, 36.68045057569231, 34.844958850315635, 37.01365143912179, 44.180106844220845, 47.21134533200945, 47.735937799726216, 44.91284997122628, 47.23988158362252, 44.6343731198992, 43.926890168871196, 47.334067889622276, 42.51219524656023, 42.99822868619646, 44.20636408669608, 44.88480356761387, 47.571369716099326, 47.69984885624477, 46.511581829616, 43.226688929966514, 39.9817898614066, 33.70143474851336, 32.95272813524519, 32.35951178414481, 33.66960852486746, 34.39668887002127, 32.66687229701451, 32.714908667973106, 33.77768775394985, 33.8544271332877, 34.42605890546526, 33.670536109379356, 33.38545846939087, 32.95508704866682, 33.63397816249302, 33.453995500292095, 33.58262402670724, 34.78794193267822, 34.185786724090576, 38.86607592446463, 46.29730633326939, 45.696241991860525, 45.23688963481358, 40.664478165762766, 45.09113727297102, 42.944147382463726, 46.56696244648525, 47.24785811560494, 46.85526752471924, 43.0496939931597, 39.834654808044434, 38.48824678148542, 36.52714899608067, 33.9182254927499, 35.92551837648664, 36.01132862908499, 36.40927628108433, 34.66195024762835, 38.462024280003135, 43.58130761555263, 49.54379653930664, 51.123083863939556, 52.607173919677734, 49.35722698484148, 54.63748618534633, 52.22168091365269, 56.417652879442485, 54.773962702069966, 54.80923523221697, 14.137555258614675, 0.14988022962851183, 0.44375017711094444, 0.011088404688052833, 0.00848731872559126, 14.552550315856934, 59.31897394997733, 46.38371065684727, 42.7713109425136, 29.26491962160383, 29.84362118584769, 40.30169882093157, 39.01260301045009, 43.749492236546104, 8.758087941578456, 0.028126233257353306, 0.03700027707964182, 0.06337626318314246, 0.025443241332790682, 0.0030766586465428448, 0.028304409767900194, 0.07855301523315054, 0.03283079813367554, 0.0211187883812402, 0.06556672350104366, 0.07351215822356087, 0.0102893381013668, 0.06827988648521048, 0.024474267881097536, 0.04042738443240523, 0.027838196838274598, 0.030513509442763667, 0.06997055826442582, 0.06351110844739846, 0.04252201524962272, 0.07883015607616731, 0.07878269933696304, 9.63751014641353, 54.573934486934114, 53.06076274599348, 47.086124897003174, 31.868326255253383, 29.086634056908743, 31.800626482282365, 46.879909311022075, 49.727288041796, 50.0104410307748, 5.899794893605368, 0.07617770162011896, 0.1717559407864298, 0.8531068797622408, 8.102511508124215, 45.23404087339129, 52.94266768864223, 50.726275716509136, 49.64920418603079, 48.134271076747346, 47.59087678364345, 49.831934860774446, 47.31092344011579, 46.09146247591291, 48.0982620375497, 48.146395683288574, 47.43886409487043, 37.534182684762136, 32.567363670894075, 36.60969706944057, 45.64760112762451, 46.57243415287563, 41.61391823632376, 38.12484557288033, 44.18746846062796, 45.55749341419765, 46.6963518006461, 46.237319060734336, 46.13880402701241, 43.38032054901123, 42.41352735246931, 44.833432061331614, 44.57840885434832, 43.639801025390625, 44.79077359608242, 40.61971092224121, 37.352490765707834, 33.79425573348999, 33.89378867830549, 33.39087806429182, 35.376912934439524, 34.05489655903408, 34.95045334952218, 34.368135247911724, 33.31842919758388, 35.07218926293509, 35.66120890208653, 33.753886699676514, 35.37356390271868, 35.69035312107631, 34.60033014842442, 33.925604479653494, 35.31748846599034, 35.71373380933489, 36.55642523084368, 40.541679177965435, 44.07880905696324, 44.346689905439106, 45.17487348828997, 43.76866231645857, 41.11925513403756, 38.9069104875837, 36.7551645551409, 38.337231159210205, 45.01004137311663, 49.67055947440011, 48.982913630349294, 45.968177114214214, 49.17303024019514, 45.69174998147147, 46.002633231026785, 48.913685253688264, 43.30379656382969, 44.31413412094116, 44.86429943357195, 45.718024594443186, 46.77164942877633, 47.08114998681204, 48.00653191975185, 46.53260013035366, 39.94249085017613, 35.95066390718733, 34.14014400754656, 34.004025323050364, 34.43813834871565, 34.980327129364014, 33.86173663820539, 34.059489318302695, 34.99279914583479, 35.716540881565635, 36.484931741442, 34.98019858769008, 35.09423589706421, 35.06525496074131, 34.78994648797171, 34.934500285557334, 34.427914074489046, 36.240435055324006, 36.708691528865266, 40.258870124816895, 47.85299062728882, 47.346588543483186, 46.74057361057827, 44.373252868652344, 45.573856421879356, 44.29827833175659, 47.70710277557373, 49.67569419315883, 47.91880049024309, 44.712401390075684, 41.09623227800642, 40.126795291900635, 37.35439804622105, 36.43540150778634, 37.88268348148891, 37.559950079236714, 38.08853081294468, 37.037660939352854, 40.596382345472065, 46.70696169989449, 52.21150180271694, 52.45808294841221, 53.95699003764561, 51.95636395045689, 57.3285756111145, 53.86572544915335, 57.86129747118269, 54.538846084049766, 56.61519711358206, 15.387072392872401, 0.05660159992320197, 0.21308039261826447, 0.10983897572649376, 0.03162218477310879, 15.795739378247942, 64.10054356711251, 52.58786834989275, 48.69811044420515, 33.94695629392351, 33.632470403398784, 46.49034118652344, 44.980678285871235, 52.46553141730172, 11.537601011140005, 0.061006757829870494, 0.041320075280964375, 0.0053873572781282875, 0.11704307022903647, 0.024313097154455524, 0.05663271753915718, 0.04921365635735648, 0.03072154488680618, 0.014749548098604594, 0.047503042433943064, 0.07843636827809469, 0.14103761554828712, 0.22087680069463594, 0.07267473744494574, 0.10209193107272897, 0.11747275931494576, 0.09647340327501297, 0.1397194934210607, 0.09701242470847708, 0.11794940302414553, 0.36363389183368, 0.14398294607443468, 11.483887961932592, 63.95199108123779, 60.115529332842144, 52.59927034378052, 36.47702121734619, 33.16615942546299, 36.62938479014805, 51.032614844185964, 53.87192324229649, 54.598916734967915, 7.185767488820212, 0.28202070402247564, 1.5919308747564043, 0.7555163907153266, 8.115165046283177, 47.79247876576015, 53.723714692252024, 52.94967494692121, 51.14457811628069, 50.273624897003174, 50.3115690095084, 53.75336265563965, 47.091158866882324, 48.248902457101, 50.335932867867605, 49.96789026260376, 50.26393910816738, 38.64609248297555, 35.925191811152864, 39.1989780153547, 48.1044841493879, 47.209580489567344, 40.940460613795686, 40.185097626277376, 45.143495423453196, 46.94579907826015, 49.17842204230172, 48.050395897456575, 48.63774796894619, 43.93230281557356, 43.6298268863133, 45.457748549325125, 46.51132474626814, 45.50908184051514, 46.677956444876536, 41.836694853646414, 40.02884653636387, 34.55697686331612, 35.14675038201468, 34.47328928538731, 37.358167443956646, 36.11925499779837, 37.34189476285662, 36.79526260920933, 34.63080842154366, 36.71956893375942, 37.78882721492222, 35.120447976248606, 38.44485180718558, 38.02760900769915, 36.985771792275564, 36.643691131046836, 35.73765298298427, 37.60836165291922, 37.611210414341514, 39.81126717158726, 47.43859658922468, 46.53095688138689, 46.16676010404314, 46.69261366980416, 43.19921227863857, 39.611846923828125, 38.67867953436715, 39.76433209010533, 46.584940910339355, 50.79283251081194, 51.42022705078125, 46.764392035348074, 50.92842313221523, 48.416916847229004, 48.36484704698835, 50.75168527875628, 44.618684087480815, 46.593772070748464, 48.4458943094526, 46.72986643654959, 48.55900056021554, 50.309804167066304, 48.721435546875, 49.2982610974993, 42.6963711466108, 36.48637696674892, 35.36915874481201, 35.131585938589915, 37.00369119644165, 36.847745827266145, 35.26084327697754, 36.299397468566895, 36.051770618983674, 37.118791580200195, 37.87444986615862, 36.65551349094936, 36.59083271026611, 36.602213859558105, 36.67405823298863, 36.65611103602818, 35.0698755128043, 39.19573320661272, 38.04887396948678, 43.943044730595176, 50.60891022000994, 48.44339990615845, 47.198442527226035, 44.38986601148333, 47.58197614124843, 45.077602182115825, 49.8093011038644, 50.07867234093802, 51.935446398598806, 47.54078027180263, 44.51062222889492, 41.66881595339094, 38.63700076511928, 38.76033476420811, 40.33329922812325, 39.62144238608224, 39.58776446751186, 38.977736949920654, 43.8042197227478, 48.52814361027309, 54.38332802908761, 55.3441527230399, 56.00200121743338, 53.839832987104145, 59.97143064226423, 56.83457606179373, 60.18057141985212, 56.213615553719656, 57.110304900578086, 16.40479588508606, 0.18168324737676553, 1.5920149045331138, 0.5599595585039684, 0.1259703654795885, 17.6130268233163, 70.9878203528268, 55.44102798189436, 56.214154039110454, 42.75420100348336, 41.684400762830464, 54.90518290655953, 51.94897106715611, 62.78507586887905, 17.093202556882584, 0.19142388898347104, 0.10774698441049882, 0.13854203160320008, 0.2333634735218116, 0.06695753708481789, 0.11455630723919187, 0.13596773759594985, 0.11084737375910793, 0.14383896094347748, 0.1414197121879884], [0.031938107285116396, 0.01289508814391281, 0.04072284911360059, 0.032901345419564416, 0.020748386292585304, 0.06702000301863466, 0.062257698204900534, 0.03290198663515704, 0.04387717181816697, 0.05597186514309474, 0.010366930277086794, 0.056822639490876875, 2.6638937422207425, 39.30920423780169, 44.09962238584246, 41.74834850856236, 24.05407813617161, 23.128122976848058, 27.804309265954153, 38.85128320966448, 45.079634530203684, 50.16281849997384, 9.234109027045113, 0.15216504702610628, 0.2249260398426226, 0.4927163581762995, 0.8445311742169517, 28.922769478389196, 54.50327478136335, 50.9246745790754, 50.29231902531215, 47.440288475581575, 48.22706774302891, 49.305813789367676, 39.44129296711513, 41.0372177532741, 49.04173360552107, 46.91592182431902, 40.985780239105225, 31.61549867902483, 32.896350451878135, 41.692005566188264, 46.176126275743755, 41.39658900669643, 45.179320335388184, 45.28830977848598, 46.45514161246163, 43.153468813214985, 41.93542528152466, 41.84884377888271, 45.11492095674787, 45.760401657649446, 43.46011018753052, 43.65841177531651, 43.80886459350586, 46.24246767589024, 43.128830501011436, 38.48869841439383, 33.800109590802876, 31.939472334725515, 32.32704285212925, 32.81050893238613, 31.424530914851598, 32.5202305657523, 33.967453479766846, 32.94261850629534, 32.79234286717006, 32.0001995904105, 34.8213141305106, 33.183130400521414, 35.303734506879536, 32.67716952732631, 33.53250319617135, 32.842696462358745, 35.06356307438442, 35.42954206466675, 33.308972699301584, 32.56798900876726, 33.83165788650513, 34.62158121381487, 36.40733773367745, 35.483682428087505, 34.52819742475237, 35.73441512244088, 35.864721638815745, 39.52550513403756, 44.76323093686785, 45.4663017817906, 47.98816435677664, 44.62060179029192, 48.63053226470947, 45.52612924575806, 44.80071299416678, 46.20381484712873, 47.08796616962978, 47.39822060721261, 48.70719868796212, 47.50845725195748, 44.97027335848127, 44.237293992723735, 45.78522409711565, 39.567385401044575, 33.43925142288208, 35.03636087690081, 34.26589945384434, 32.90653998511178, 33.609114033835276, 33.727028438023154, 33.964073181152344, 32.9408779825483, 34.050863129752024, 34.75232546670096, 33.86452633993966, 34.40080567768642, 34.30187027794974, 33.25340100697109, 33.889348779405864, 33.01191636494228, 33.20040014811924, 33.40580974306379, 34.41928093773978, 40.462556566510884, 44.25916344778878, 44.96890803745815, 46.118449279240195, 43.228825501033235, 42.366224016462056, 44.931155000414165, 43.399094581604004, 43.99984277997698, 46.263378279549734, 50.22532102039882, 47.64831754139492, 44.74639197758266, 42.688092367989675, 37.939891474587576, 33.34463085447039, 33.45054224559239, 35.229541642325266, 36.4372809955052, 36.939201491219656, 36.3538088117327, 39.720871107918875, 46.39239590508597, 50.95842892783028, 51.05338995797293, 51.44473334721157, 53.606637545994346, 54.17575407028198, 53.98657546724592, 45.89931699207851, 6.178534473691668, 0.17109618761709758, 0.3746922755880015, 0.08826178605003016, 0.05641894168885691, 15.088315486907959, 57.99109329496111, 48.50959539413452, 43.74782814298357, 30.666708265032085, 26.701565878731863, 42.53090327126639, 45.82135125568935, 42.64918940407889, 7.327880297388349, 0.08877487387508154, 0.10906684358737298, 0.02945835356201444, 0.02562695129641465, 0.05735378313277449, 0.03894903983122536, 0.028815825004130602, 0.03496314871257969, 0.012643592531925865, 0.048554205136107545, 0.042319679499736855, 0.030589125385241847, 0.027864961652085185, 0.029629741329699755, 0.007023203003752444, 0.09119908272155694, 0.03198766748287848, 0.020152293278702667, 0.03740916906722954, 0.024884859598906975, 0.04793686379811593, 0.0904205519972103, 3.762171174798693, 47.15073619570051, 51.60644572121756, 46.81085811342512, 27.47887475149972, 24.38030127116612, 32.02369839804513, 44.70642941338675, 49.712088857378276, 53.31328460148403, 10.180897491318838, 0.18792111479810306, 0.11245461287243025, 1.0531276038714816, 1.5665117587362016, 32.65096092224121, 54.707607405526296, 52.087476457868306, 52.55596917016165, 49.11235509599958, 50.29516083853585, 49.19729682377407, 41.05597441537039, 41.09538459777832, 51.568084716796875, 48.541386876787456, 43.74117176873343, 33.64479998179844, 34.2007600920541, 43.640117168426514, 47.9207946232387, 43.8781589780535, 45.80311918258667, 47.84865495136806, 47.86188432148525, 46.41713844026838, 43.85906532832554, 44.177490847451345, 46.800838811056956, 47.4838502066476, 44.46426384789603, 43.895915099552695, 45.14931801387242, 46.81818846293858, 44.919356959206716, 39.700926303863525, 36.59721115657261, 33.17913866043091, 34.769824504852295, 34.81370932715279, 32.595458711896626, 34.3164302280971, 33.56613942555019, 32.731973443712505, 34.33907788140433, 34.73852981839861, 35.278529916490825, 34.8996376991272, 37.441174098423545, 34.96555873325893, 34.99054792949131, 34.54667615890503, 35.21144853319441, 35.829768725803916, 34.01896047592163, 33.804643290383474, 36.21587317330496, 37.965617179870605, 38.34141050066267, 37.96713536126273, 37.33397034236363, 36.99229267665318, 36.26749134063721, 39.82982928412301, 47.181422914777485, 47.38911151885986, 49.04651744025094, 46.67727552141462, 50.33577653339931, 47.08393621444702, 46.64530338559832, 47.06726401192801, 47.226158891405376, 47.50181824820382, 49.09068366459438, 47.768531799316406, 47.574499879564556, 46.01087726865496, 46.37443133762905, 42.12379789352417, 35.22517817361014, 37.14344378880092, 35.15260771342686, 34.76787553514753, 34.54484878267561, 35.80588776724679, 35.80810424259731, 36.104774951934814, 37.41376345498221, 35.43066767283848, 35.35690559659685, 35.92123828615461, 35.625703607286724, 34.94476277487618, 35.673785141536165, 33.700705187661306, 34.90641566685268, 33.96127305712019, 35.55057968412127, 41.96489953994751, 47.03758478164673, 48.29923868179321, 46.57016209193638, 45.23767130715506, 45.814927646092, 45.77467673165457, 43.45203290666853, 44.74248708997454, 47.619159426007954, 50.73818145479475, 49.0493140901838, 45.92500795636858, 44.219517026628765, 38.77960559300014, 36.170383317129954, 35.906052998134065, 36.71088021142142, 37.90126643862043, 38.86145189830235, 38.746782302856445, 43.355928897857666, 50.04031481061663, 53.953797340393066, 53.17339651925223, 55.567269802093506, 55.01727819442749, 55.26124334335327, 54.807696206229075, 48.30570050648281, 6.701303473540714, 0.442743149719068, 1.2783993844475066, 0.2568211890757084, 0.015377301556457366, 16.66951530320304, 63.55510997772217, 52.94323396682739, 48.03219509124756, 34.06013202667236, 28.489775112697057, 50.78297996520996, 51.66670397349766, 51.28888177871704, 11.09891780785152, 0.08248659130185843, 0.05361996438088162, 0.035492378885724714, 0.021536173930923854, 0.05589372505034719, 0.04571600850405438, 0.06752004261527743, 0.021368338294061165, 0.04764256958982774, 0.0899426665689264, 0.10178204412971224, 0.10810983101172106, 0.10354839291955743, 0.11057169855173145, 0.11252317883606468, 0.2164370510727167, 0.13413016977054731, 0.10786107328853436, 0.1401827021368912, 0.10302903543093375, 0.1629154844475644, 0.22560632548161916, 4.157162802559989, 53.906872681209016, 57.03804363523211, 52.37973853519985, 33.77175746645246, 31.760121958596365, 36.716942514692036, 50.0951360974993, 52.95969424928938, 59.15888050624302, 11.747341070856367, 0.26360043244702475, 1.4589418108974184, 1.8231200235230582, 1.2299393905060632, 33.724714687892366, 56.9657997403826, 55.61970090866089, 55.9822370665414, 51.92364140919277, 52.13796901702881, 50.14368316105434, 42.06004817145211, 43.64736066545759, 52.92096151624407, 51.5838988167899, 44.676326342991416, 34.80298130852835, 35.725253922598704, 46.37705775669643, 48.71685320990426, 43.32188272476196, 46.79357099533081, 49.4742693901062, 50.11300686427525, 49.719078745160786, 45.34520162854876, 46.53687674658639, 49.085844244275776, 48.99069561277117, 45.70090075901577, 44.87429789134434, 47.88763434546334, 47.761420318058555, 46.435610226222444, 42.488967418670654, 38.1157260622297, 35.94342041015625, 36.031627791268484, 36.855534757886616, 33.38285289491926, 36.43929597309658, 35.477081639426096, 36.0936404636928, 35.91047205243792, 35.52367278507778, 37.376295294080464, 35.826141766139436, 40.662616048540386, 36.150514943259104, 37.316731861659456, 36.07226085662842, 37.40266023363386, 38.870675631931846, 36.32409831455776, 36.41346951893398, 37.387700762067524, 39.01987082617623, 38.910874434879844, 38.94717877251761, 38.34613527570452, 38.84756939751761, 38.20957885469709, 42.13932364327567, 48.11136286599295, 48.02683803013393, 51.368581090654644, 47.541742597307476, 50.25987441199166, 48.82116651535034, 47.76155233383179, 49.49845606940133, 48.873177255902974, 50.56252752031599, 51.577054841177805, 49.79563052313668, 49.13497148241316, 48.46702378136771, 48.69303478513445, 42.703131743839805, 37.467997619083945, 37.6402782031468, 37.352706159864155, 36.87951646532331, 37.268556526729036, 37.44884838376726, 38.01672118050711, 37.87712492261614, 39.49509286880493, 37.148092133658274, 37.04004764556885, 38.05906697681972, 37.53044802801949, 35.71246228899275, 37.63149568012783, 36.87071309770857, 37.05100148064749, 36.48413617270333, 36.7809910093035, 45.062569754464285, 51.09064967291695, 48.846395424434114, 48.3532053402492, 48.05938686643328, 46.87751913070679, 48.36993660245623, 45.86124781199864, 45.11293724605015, 48.462323325020925, 51.59936898095267, 50.59639651434762, 50.41908890860421, 47.64560079574585, 40.60686022894723, 38.742724554879324, 37.978919506073, 38.911305223192485, 40.93026065826416, 41.067425046648296, 40.78122527258736, 44.31519719532558, 51.396728243146626, 57.020325728825156, 56.78374651500157, 58.05927249363491, 56.34926870891026, 58.33567878178188, 57.32293019975935, 49.44526066098894, 8.088935596602303, 0.37479020176189287, 2.3826306632586887, 0.5106211059859821, 0.07484853972813912, 18.375753164291382, 68.70303726196289, 57.4880576133728, 55.34250599997384, 45.035944257463726, 36.58690697806222, 56.95370640073504, 59.205092975071494, 60.583761487688335, 15.79421251160758, 0.13572931396109716, 0.2166403808764049, 0.17351296650511877, 0.22374067987714494, 0.14422580732830934, 0.14977922290563583, 0.12082569939749581, 0.18919191589312895, 0.14331082999706268, 0.29744119942188263], [0.012555454225678529, 0.025676150174279298, 0.06857608737690107, 0.04616212831544025, 0.1061525424676282, 0.018626232398673892, 0.015081670634182436, 0.022014508888657604, 0.027257074003240893, 0.04337481841711061, 0.025083485458578383, 0.06372165107833487, 1.0155504431043352, 28.395131962639944, 42.07946491241455, 48.6476491519383, 35.262476103646414, 27.369456257138932, 29.897994313921245, 40.027675764901296, 43.33228417805263, 49.6454313141959, 15.055485248565674, 0.062191948161593506, 0.1067453445866704, 0.3568982646933624, 0.28495395662529127, 8.858914988381521, 45.403347628457205, 49.32075241633824, 49.375924587249756, 48.94148499625069, 48.813485281808035, 45.32083082199097, 51.26844712666103, 48.45701142719814, 46.99926894051688, 39.83413369315011, 32.232057503291536, 31.693579060690745, 39.73581668308803, 45.17537375858852, 43.22223513466971, 46.3451828956604, 45.1205872126988, 41.79000990731375, 41.51375995363508, 40.34145988736834, 40.88267592021397, 40.17499841962542, 41.5670804296221, 43.44823571613857, 43.23254973547799, 44.53387784957886, 46.07629108428955, 43.94642850330898, 39.684889861515586, 37.49046809332711, 32.06425155912127, 31.73622362954276, 33.22806787490845, 32.637432779584614, 32.26707642418997, 31.72838258743286, 33.42040096010481, 32.75844955444336, 32.17066669464111, 33.52309880937849, 33.642718996320454, 33.12916374206543, 33.086626870291575, 33.52161536897932, 34.21740102767944, 34.310030937194824, 31.78249168395996, 33.03962230682373, 33.86961589540754, 34.438291209084646, 33.5232377733503, 34.59591456821987, 33.14353609085083, 34.08043813705444, 33.23030172075544, 34.81662062236241, 36.087279387882774, 47.74770457404, 49.26304415294102, 47.81725604193551, 46.48870488575527, 44.04834120614188, 48.48253910882132, 45.67299679347447, 45.96537699018206, 45.68075793130057, 47.37713629858834, 45.87537349973406, 44.99549879346575, 45.24320902143206, 44.99878181729998, 46.293905190059114, 43.10725287028721, 34.76891081673758, 33.654854025159565, 33.63662542615618, 33.50505781173706, 31.968595709119523, 33.272810799734934, 33.974439893450054, 33.52780621392386, 33.11222403390067, 34.933694294520784, 35.40840564455305, 34.19181081226894, 33.85776226861136, 34.21019574574062, 33.12432084764753, 33.10602624075753, 33.05581855773926, 31.638764722006663, 33.03699241365705, 33.687962191445486, 38.745580264500205, 42.100983483450754, 43.7391984803336, 44.44492701121739, 44.190251214163645, 45.19003793171474, 46.169247559138704, 46.81644099099295, 44.73722382954189, 44.173957688467844, 43.93656553540911, 48.75297689437866, 49.37265198571341, 46.57686015537807, 43.8192069871085, 41.75720746176583, 32.27879456111363, 35.04433046068464, 36.05833666665213, 39.04845571517944, 40.585480621882844, 40.28616612298148, 37.44686814716884, 42.17052452904837, 47.07655722754342, 51.76749801635742, 50.8041615486145, 53.73404318945748, 53.2822504724775, 38.180629185267854, 2.2764828162533894, 0.13167718425393105, 0.14152207598090172, 0.08830949384719133, 0.024358660780957768, 13.703274607658386, 59.955380303519114, 49.19956888471331, 44.307251930236816, 26.42828801700047, 33.90087931496756, 43.27661173684256, 50.04269456863403, 41.527837003980366, 3.7585789561271667, 0.0668031025145735, 0.09258838995758976, 0.04555523980941091, 0.01677342806942761, 0.03382020736379283, 0.009093248800906752, 0.08861433927501951, 0.019345264083572795, 0.05076623947492667, 0.08086377302450792, 0.011416251604844416, 0.01020468067976513, 0.0504808713948088, 0.035652686176555495, 0.06899756618908473, 0.03596327879599162, 0.04503059314031686, 0.07105424654270921, 0.025720582343637943, 0.01991351510930274, 0.02607996841626508, 0.022398245886766484, 1.3435315809079578, 34.83828163146973, 50.11953122275216, 51.59331709997994, 37.515325273786274, 25.248084374836512, 30.914901392800466, 44.69364472797939, 47.830794606889995, 55.00306218011038, 17.374373572213308, 0.06042300058262689, 0.06271672035966601, 2.394233069249562, 0.9153601335627692, 11.008562564849854, 48.07713603973389, 50.88695975712368, 50.646791798727854, 50.70023039409092, 49.84670673097883, 45.091974530901226, 51.67424971716744, 49.788602420261924, 47.793277808598106, 43.71300029754639, 35.52335316794259, 32.33932031903948, 40.72422572544643, 47.88611616407122, 45.11505992071969, 45.50352675574166, 47.94209780011858, 43.4951673235212, 43.20522247041975, 41.546882016318186, 43.30245903560093, 42.062695435115266, 44.16325398853847, 45.10641288757324, 45.43226950509207, 46.527006830487935, 47.87457173211234, 45.72588300704956, 42.41643169948033, 38.74596241542271, 33.88864006314959, 33.829924310956685, 35.46360560825893, 33.75863231931414, 34.400868211473735, 33.510178634098594, 32.977158001491, 33.56515972954886, 34.142197200230186, 35.186921392168315, 35.96392107009888, 36.02983168193272, 33.76238782065255, 33.97180652618408, 35.088340350559776, 35.98187868935721, 33.82385505948748, 35.10517236164638, 35.260693890707834, 36.311240673065186, 35.41315821238926, 35.54470845631191, 35.06615475245884, 34.80052859442574, 34.58861895969936, 36.19241258076259, 38.053306920187815, 48.33594601494925, 48.878186907087056, 49.43780871800014, 47.502474852970664, 46.684025696345735, 49.26393352236067, 46.46376085281372, 45.95836625780378, 46.08608457020351, 49.292188371930806, 47.78037847791399, 46.9831143787929, 47.45132221494402, 46.945062569209504, 47.21117510114397, 46.420775822230745, 36.11265073503767, 36.02843509401594, 36.22435344968523, 35.65511185782296, 34.793962546757285, 35.438467025756836, 35.5403276171003, 35.370722089494976, 35.072081565856934, 36.69030312129429, 35.642837865012034, 35.53131232942854, 35.13994114739554, 35.40262474332537, 34.3818370955331, 34.583810806274414, 35.43935292107718, 34.60500628607613, 35.20942313330514, 35.63493428911482, 41.78513922010149, 43.517665590558735, 46.909852572849815, 46.69019569669451, 44.99520002092634, 46.88197292600359, 48.96360458646502, 47.506473541259766, 45.002287183489116, 44.41543190819876, 45.883284023829866, 50.242764472961426, 50.64050367900303, 47.69530126026699, 46.31601783207485, 41.331463541303364, 33.37953165599278, 36.552186829703196, 37.893018926892964, 41.68958411897932, 43.260151454380576, 41.52512373243059, 39.90278189522879, 45.68707036972046, 49.32153408867972, 54.72392872401646, 53.20767893110003, 57.09756885256086, 55.33667646135603, 39.94122280393328, 3.2021042449133734, 0.8798830115369388, 1.4291692141975676, 0.06908030674925872, 0.03535728595618691, 15.2988007409232, 65.10066032409668, 54.9095915385655, 46.99854285376412, 35.36912400381905, 37.02736718314034, 47.076553753444124, 55.09611940383911, 50.69703769683838, 7.357728021485465, 0.07659419998526573, 0.04289234269942556, 0.05723172825362001, 0.027920793209757124, 0.10157228859939746, 0.016576006609414305, 0.08219047183437006, 0.011668692925013602, 0.06072534900158644, 0.05033851135522127, 0.10150425867842776, 0.1424042529293469, 0.10795034135558776, 0.14846304138856276, 0.20364663882979325, 0.09360600249575717, 0.13829493629080908, 0.2134442095245634, 0.07357444095292262, 0.10605864679174763, 0.1165719497948885, 0.10451257761035647, 1.5182218870946338, 40.232647623334614, 58.25343642915998, 59.119727407182964, 46.29824781417847, 37.87424142020089, 37.97738742828369, 50.60364695957729, 52.20334461757115, 58.95875154222761, 19.333466802324565, 0.17172649236662046, 0.34544665632503374, 3.970902008669717, 0.6884285477655274, 11.092634030750819, 48.22823504039219, 50.95370762688773, 51.483740534101216, 50.28855310167585, 50.23459339141846, 46.151508808135986, 54.5116925239563, 51.23550224304199, 51.05005134854998, 43.506868089948384, 36.80867263248989, 34.084975310734336, 43.72254364831107, 47.55165420259748, 45.1483348437718, 49.21619939804077, 48.4783285004752, 46.13350602558681, 45.50210932322911, 43.2770459992545, 45.43398571014404, 44.807379790714805, 46.41616569246565, 47.50880813598633, 47.659368651253835, 47.243960176195415, 49.939777851104736, 48.17131192343575, 44.59895120348249, 41.50304583140782, 35.23027467727661, 35.979148047310964, 37.70188788005284, 35.063969544001985, 36.46458394186837, 34.14369453702654, 35.80996983391898, 35.166556222098215, 35.58619267599923, 37.16837045124599, 36.97046143668038, 36.739183698381694, 35.302789551871165, 36.359263147626606, 37.21330792563302, 37.83499104636056, 35.269740445273264, 36.22475644520351, 37.82375233513968, 38.03079128265381, 37.978599888937815, 38.77199036734444, 37.19751814433506, 37.21401316779, 36.92128208705357, 38.31683472224644, 39.692480768476216, 50.308056695120676, 51.607414994921, 50.17887578691755, 49.11300475256783, 49.39115156446184, 51.8910230909075, 48.497995376586914, 48.41695506232125, 46.82576199940273, 51.31023359298706, 49.849076066698345, 48.125050817217144, 50.415732928684776, 49.465973240988596, 49.34770447867257, 47.409400258745464, 38.763881819588796, 36.95990364892142, 37.53999832698277, 38.14968885694231, 36.334239210401265, 37.080038002559114, 38.00257812227522, 38.08284023829869, 36.7746889931815, 38.27993631362915, 38.13766499928066, 37.894453729902, 36.755734307425364, 37.1174054145813, 36.70177807126726, 35.47035230909075, 36.41862160818917, 36.22191463197981, 36.28000852039882, 38.65974916730608, 43.920046193259104, 45.80589151382446, 48.67527518953596, 49.00790630068098, 47.00794376645769, 51.50169815335955, 51.11092799050467, 50.78883382252285, 47.25782878058297, 45.722037179129465, 45.61481605257307, 51.807297297886436, 49.981588636125835, 48.68780973979405, 48.664738246372764, 45.66276904514858, 35.66567659378052, 39.02371665409633, 40.52146686826433, 44.59569597244263, 44.33658027648926, 44.147759505680625, 42.275581291743684, 47.320452894483296, 50.86593450818743, 56.87381601333618, 56.12977858952114, 58.876262528555735, 57.81179503032139, 42.0067207472665, 3.2767626387732367, 1.2994358156408583, 2.343944613422666, 0.19208038518471376, 0.09519733674824238, 16.441551855632238, 69.11774049486432, 59.903303555079866, 58.88261318206787, 41.80288144520351, 46.3882235118321, 56.61187587465559, 63.98282718658447, 61.797083718436106, 12.734826871326991, 0.11158528737723827, 0.2033599984965154, 0.20710536252175057, 0.10022082326135465, 0.19090695386486395, 0.06749483503933464, 0.30081362703016823, 0.06518673031990017, 0.1380667042519365, 0.11466973115290914], [0.03230241612930383, 0.04110916963379298, 0.015743539136435305, 0.015076825894149286, 0.03926743560337594, 0.011436616137091602, 0.05236811816160168, 0.024545268089111363, 0.038403022701718977, 0.038058876525610685, 0.03196720965206623, 0.027951586825240935, 0.1071421993630273, 18.494398866380962, 47.607771328517366, 45.56505305426461, 33.94067859649658, 18.50811287334987, 28.011266572134836, 34.98123386928013, 44.13506167275565, 48.615388665880474, 21.291661977767944, 0.07842573563435248, 0.2286804419543062, 1.5046199198280061, 1.7387532591819763, 0.5291338211723736, 24.332289218902588, 51.46088443483625, 45.768968786512104, 48.79119546072823, 48.680673939841135, 47.714523451668875, 46.987998962402344, 43.559097698756624, 38.774932929447715, 32.06305646896362, 32.88734211240496, 38.34501314163208, 45.88290882110596, 44.65413727079119, 46.48551913670131, 45.04547718593052, 40.71551963261196, 42.05546930858067, 40.743736267089844, 40.120107650756836, 38.70132371357509, 40.321556772504536, 39.87271703992571, 41.44398614338466, 41.401254722050254, 41.07218108858381, 40.66058717455183, 40.86748020989554, 38.09713963099888, 32.55280024664742, 33.68481118338448, 32.48923117773873, 33.13314158575875, 32.44284847804478, 32.044115679604666, 32.373272691454204, 32.20729412351336, 31.9927476474217, 33.52756997517177, 32.48269292286464, 33.806248324257986, 34.47969205038888, 33.85853351865496, 34.5405478477478, 33.15453856331961, 36.67773035594395, 33.770270551954, 33.23524188995361, 34.0318146433149, 34.505160672324045, 33.86395311355591, 36.139442988804404, 34.92024258204869, 35.29923207419259, 33.54213687351772, 32.810411657605854, 38.66489083426339, 47.113962854657856, 48.706920760018484, 47.72789178575788, 41.63771234239851, 42.80095543180193, 47.58567605699812, 44.62664672306606, 42.96946314402989, 43.911069120679585, 44.7163097517831, 45.78521367481777, 46.952396392822266, 43.602294649396626, 43.59185150691441, 43.31237064089094, 39.35027156557356, 36.7642354284014, 34.531536034175325, 33.50006553104946, 33.8611147744315, 33.01976782935006, 34.93187734058925, 32.22518573488508, 34.82755013874599, 33.01470259257725, 34.09540108272007, 34.51523903438023, 35.07521520342146, 34.87622226987566, 33.765128884996685, 32.95644194739205, 34.40275812149048, 32.90432698386056, 33.88789313180106, 33.29769229888916, 35.049221992492676, 34.46913078853062, 38.5091678074428, 39.150681086948936, 41.028331007276265, 41.490438325064524, 41.81801462173462, 42.100048950740266, 41.18948752539498, 44.66266965866089, 45.866698673793245, 42.75091103145054, 42.22727741513933, 44.27883379799979, 48.36835936137608, 49.81479712894985, 46.04265832901001, 38.057694707598, 34.07847874505179, 35.60121815545218, 39.83769811902727, 42.445826053619385, 44.501144886016846, 45.13170780454363, 44.532304082598, 43.68926525115967, 48.37335164206368, 52.583206108638215, 53.77521474020821, 53.84060076304844, 29.19885614940098, 0.9683746716805867, 0.47979678000722614, 1.2422387876680918, 0.12827807664871216, 0.04607282971431102, 12.886063967432294, 58.670276233128135, 47.714394909994944, 50.13052327292306, 31.17370441981724, 32.2915028163365, 51.49107435771397, 41.3667881829398, 42.01205348968506, 2.333639132125037, 0.1034482547215053, 0.029535350323255573, 0.04480602179786988, 0.02359598402732185, 0.08786248854760613, 0.032809186793331585, 0.05399195084880505, 0.06525267035301242, 0.06999107716338974, 0.03217554704419204, 0.04410701198503375, 0.06488670927605458, 0.02575441918868039, 0.04133484698832035, 0.011807523734335388, 0.031037996656128337, 0.011278448776075882, 0.05648344322772963, 0.05584014453259962, 0.029036545660346746, 0.045022362510540655, 0.0468938095894243, 0.11080078554472753, 22.956205436161586, 52.48289149148123, 50.34885651724679, 40.179042271205354, 22.581454345158168, 33.77079514094761, 44.96252959115164, 47.218981402260916, 54.62168945584978, 22.529705899102346, 0.10006689759237425, 0.08036379449601684, 1.787090031164033, 4.089267611503601, 1.5930429122277667, 27.825167758124216, 52.887016092027935, 46.46172503062657, 49.49038921083723, 49.7732503754752, 49.08268976211548, 49.94807052612305, 45.48638207571847, 42.051022461482454, 33.53341341018677, 33.87749515260969, 39.16890968595232, 48.415433406829834, 45.48914398465838, 46.409603118896484, 48.11847087315151, 44.230613299778526, 43.859009742736816, 41.74569429670061, 42.36879137584141, 41.73252746037075, 42.51585694721767, 43.434648513793945, 44.88110712596348, 42.82174096788679, 41.79322344916207, 42.8510137285505, 42.963039534432546, 40.318065302712576, 34.66864831107003, 34.869861194065635, 33.6625074659075, 34.96846655436924, 33.36288377216884, 33.71525124141148, 33.78784949438912, 33.456969329289024, 34.05117579868862, 33.55356318610055, 34.47316769191197, 35.64057275227138, 35.035019874572754, 36.87251615524292, 35.42511258806501, 34.97352136884417, 37.094823769160676, 35.5179683140346, 33.68500573294503, 35.69472701208932, 36.11636454718453, 35.0202236856733, 37.952109881809776, 36.561302866254536, 36.34483521325247, 35.49065147127424, 34.11843088694981, 40.474014145987375, 49.6945481300354, 49.31450598580496, 49.64032438823155, 42.43120009558541, 45.4614588873727, 49.31662171227591, 46.22456911631993, 45.38369812284197, 45.20410108566284, 46.493922982897075, 46.50518601281302, 47.225814955575125, 46.35670648302351, 45.61028582709176, 45.08779518944876, 40.88538571766445, 37.39876924242292, 35.56460114887783, 34.93932580947876, 35.90525048119681, 35.26997320992606, 35.393182141440256, 34.47453301293509, 34.22844866343907, 35.76189177376883, 36.38944959640503, 36.10986450740269, 36.32515444074358, 35.865371295383994, 33.88390139171055, 34.67468976974487, 35.11843647275652, 35.5442533493042, 34.704824107033865, 34.378797258649556, 35.92506326947893, 36.49452372959682, 39.98830379758562, 41.99048975535801, 43.51533794403076, 43.53968095779419, 44.863437856946675, 44.14062717982701, 43.68442235674177, 46.13676125662667, 48.45600741250174, 44.14605024882725, 44.23175975254604, 47.57650096075875, 49.97505732945034, 50.450446128845215, 47.48544829232352, 39.83830261230469, 36.43817731312343, 38.18797690527779, 41.394275256565635, 45.71326507840838, 47.77649443490164, 48.029113565172466, 43.94769654955183, 44.75866944449288, 50.82911947795323, 54.85082367488316, 55.74451487404959, 56.32184416907174, 30.67405251094273, 1.5790649822780063, 1.9775819522993905, 2.574080241577966, 0.07997096343232052, 0.019153172516130974, 14.666717903954641, 65.45910399300712, 51.66411229542324, 55.30493014199393, 33.49553183146885, 37.67497403281075, 57.57817922319685, 48.7141295160566, 51.1838493347168, 4.6016994288989475, 0.06086159883333104, 0.07973338118089096, 0.039589268155395985, 0.021704650783379163, 0.015623346835907017, 0.019184985630480305, 0.027974594251385758, 0.0493000949333821, 0.06656476030392305, 0.029248201088713746, 0.13535404338368348, 0.09962271499846663, 0.0920381930523685, 0.10361513362399169, 0.11293287149497441, 0.09090005233883858, 0.04819104980145182, 0.1479173499558653, 0.1499987154134682, 0.14806983034525598, 0.13621742491211208, 0.12866072968712874, 0.2245450560003519, 25.560829741614207, 61.969315665108816, 55.96682596206665, 46.49641738619123, 29.0942371232169, 37.41904061181204, 46.35816560472761, 52.36398002079555, 57.99082926341465, 26.52363814626421, 0.1761513685009309, 0.5698723037328038, 7.976741296904428, 4.072526361261096, 0.9668745121785572, 29.14636250904628, 53.540855475834434, 46.51751559121268, 51.23608241762434, 52.303370884486604, 51.21030807495117, 52.81891679763794, 47.88795396259853, 41.97799342019217, 35.927842548915315, 36.07901103155953, 42.190524918692454, 52.2451171875, 46.55807570048741, 48.99616731916155, 49.93269763674055, 45.721582072121755, 47.174235003335134, 44.65998765400478, 45.36475385938372, 43.76797444479806, 44.64938817705427, 45.336280141557964, 47.9225629397801, 45.32369695390974, 44.63695090157645, 45.33914279937744, 45.397174154009136, 43.04008116040911, 35.87903145381382, 37.14610147476196, 35.720470087868826, 38.1264888218471, 36.07968153272356, 36.48232964106968, 35.596635818481445, 35.589534759521484, 35.43672997610909, 35.88760553087507, 36.32926777430943, 36.247953006199424, 37.69610350472586, 38.44946888514927, 38.797743865421836, 37.38286134174892, 39.30075522831508, 36.65588174547468, 35.91061101640974, 38.05370991570609, 39.47876460211617, 37.178851808820454, 40.80328927721296, 37.75181416102818, 38.60189151763916, 38.27965491158621, 35.869891098567415, 42.48785918099539, 49.881086417606895, 52.43016856057303, 49.60707030977522, 42.91864054543631, 46.97150393894741, 51.66171169281006, 46.83119201660156, 46.89145026888166, 46.03787102018084, 47.026502404894146, 48.52178600856236, 49.99119104657854, 48.222193581717356, 48.043809005192344, 47.51447786603655, 41.98907232284546, 39.07373673575265, 37.82077155794416, 38.019649846213206, 36.381410530635286, 36.654891627175466, 37.92919472285679, 36.216957092285156, 37.391053267887656, 36.96288442611694, 36.7577805519104, 37.519792965480256, 38.80443498066494, 38.06618888037545, 36.486807755061555, 36.10057476588658, 38.01420245851789, 37.663057872227256, 36.65581921168736, 36.53559453146798, 38.20458657400948, 38.235606806618826, 42.160838740212576, 44.50358370372227, 46.598573275974815, 45.914891379220144, 46.69917624337332, 47.02850348608834, 44.99716636112758, 49.1412387575422, 51.02307844161987, 45.30054555620466, 45.00772067478725, 48.390378202710835, 50.07401704788208, 52.073642594473704, 50.821288858141216, 42.31771864209856, 38.469236510140554, 39.34277793339321, 45.24003716877529, 48.50158412115914, 49.32440716879708, 49.97013453074864, 49.39882237570626, 47.69505112511771, 53.04793637139456, 57.31233072280884, 59.09877858843122, 58.03012132644653, 33.942036969321116, 1.8346557702336992, 2.606785846608026, 4.226368163313184, 0.22097856737673283, 0.13110292649694852, 16.843086515154155, 69.78616414751325, 58.392494201660156, 61.33322892870222, 42.01405804497855, 44.23787416730608, 63.04179096221924, 54.03935398374285, 60.750830922807964, 10.47732240813119, 0.19491135541881832, 0.17617038105215344, 0.12420920069728579, 0.21914091812712805, 0.2080709585653884, 0.0980231094041041, 0.13121670324887547, 0.17981392411249025, 0.1698945699525731, 0.14899544710559504], [0.0521761334634253, 0.03764951974153519, 0.03685214609972068, 0.024560558875756602, 0.03043374086597136, 0.0811412124229329, 0.029485559423587153, 0.023663157297830497, 0.023811157659760544, 0.09347883824791227, 0.056939659640192986, 0.09087826457938977, 0.04441612879080432, 10.418536305427551, 49.74201822280884, 42.31954254422869, 39.208358083452495, 19.858920846666607, 19.651812417166575, 32.771710191454204, 46.555004596710205, 46.61039216177804, 27.443577902657644, 0.049170694912650754, 0.02799054321699909, 1.6904484054871967, 1.7205031641892023, 0.8623069460902895, 9.683660081454686, 44.075463499341694, 49.2885753086635, 48.81629582813808, 47.06886209760393, 45.661785875047954, 41.926597595214844, 38.49055358341762, 32.08475916726248, 35.653350489480154, 39.38485969815935, 44.39138419287545, 45.18878378186907, 44.588216236659456, 44.81005137307303, 42.68894352231707, 40.14328684125628, 38.897902148110525, 35.483039719717844, 33.9840874671936, 35.45597301210676, 36.94369002750942, 36.581299781799316, 36.92614235196795, 38.17012003489903, 39.56219857079642, 37.767829758780344, 34.618892260960166, 32.34357956477574, 33.393514905657085, 30.995882647378103, 32.903451510838096, 32.7883163860866, 33.00464507511684, 32.442886693137034, 31.801220553261892, 32.2014923776899, 33.171426159994944, 32.67168739863804, 32.82143497467041, 32.048875195639475, 34.070380619594026, 31.046594074794225, 34.86205836704799, 33.920160566057476, 36.68527957371303, 33.892600536346436, 33.66830226353237, 34.839556625911165, 36.47528069359915, 38.971650327954976, 38.348327432359966, 38.13545547212873, 37.01382514408657, 33.74470465523856, 33.195025716509136, 34.35653175626482, 46.46529293060303, 48.92445148740496, 47.09460864748274, 43.645185879298616, 40.68567711966378, 47.78812224524361, 45.309793608529226, 44.213857718876426, 43.22477470125471, 45.87477248055594, 45.94892365591866, 46.20927265712193, 43.660110609872, 47.58327892848423, 45.177795205797466, 35.82119117464338, 32.727283409663606, 35.933133602142334, 34.984982422419954, 34.174690450940815, 32.34640053340367, 34.653452600751606, 33.865474769047324, 33.022526264190674, 34.78867149353027, 34.04423802239554, 34.70369849886213, 33.26592860903059, 32.52548687798636, 33.247745173318044, 33.41975825173514, 33.64235768999372, 32.47133609226772, 33.97885547365461, 32.94738844462803, 33.81356825147356, 33.250600882938926, 33.21773590360369, 36.65190737588065, 35.57886232648577, 36.60928017752511, 39.23307282584054, 41.07473455156599, 41.723647662571494, 41.757127557482036, 43.06880848748343, 46.77516521726336, 43.80816282544817, 40.65737015860421, 42.82925891876221, 45.6369252204895, 51.2917548588344, 41.8502334186009, 37.75407232557024, 36.38050726481846, 39.01097713197981, 42.21005630493164, 46.11479105268206, 46.63752835137503, 50.86552456447056, 47.6447878565107, 49.56116703578404, 49.85921696254185, 52.586489132472444, 53.27968658719744, 25.267744302749634, 0.43499305844306946, 0.8929024157779557, 1.1414087010281426, 0.18104207249624388, 0.07961545179464988, 14.12562346458435, 57.88690505708967, 48.75372382572719, 41.66847201756069, 40.11862073625837, 33.23187896183559, 41.30835035869053, 47.749990531376426, 43.08016184398106, 5.457809558936527, 0.1038847698697022, 0.07250837422907352, 0.025148709637245963, 0.06023846619895526, 0.015231652318366935, 0.037489494042737145, 0.029746242399726595, 0.026143138330163698, 0.10708316681640488, 0.017132787000653998, 0.014895061629691293, 0.052507231411124976, 0.019010515617472783, 0.05544060954291906, 0.003898307938860463, 0.027620471914165785, 0.05593379932854857, 0.024372648780367205, 0.07028997862445456, 0.09987224625157458, 0.03186839120462537, 0.14624144988400595, 0.03668913823951568, 13.301107662064688, 56.79258809770857, 47.64672292981829, 43.78018242972237, 22.533933877944946, 24.18739148548671, 39.88663080760411, 50.22539397648403, 52.75556659698486, 28.691408361707413, 0.028930337966552803, 0.10312603879719973, 4.319618199552808, 6.025218563420432, 1.5915474210466658, 11.68201584475381, 45.53540161677769, 51.17826645714896, 50.98430401938302, 49.753635610852925, 48.379236766270225, 45.53664187022618, 39.742111751011436, 34.194746426173616, 35.528137002672466, 39.39731434413365, 47.3694863319397, 46.99556902476719, 45.32314109802246, 47.03773764201573, 43.00746979032244, 42.9776029586792, 41.75796134131295, 38.648131779261995, 36.45867797306606, 36.19557053702218, 38.418830803462434, 38.19146490097046, 40.02269738061087, 40.09459039143154, 41.84889241627285, 39.76168482644217, 37.114546230861116, 35.009182998112266, 33.724183150700156, 33.18472153799874, 34.21061611175537, 35.13237803322928, 34.222796303885325, 34.149110657828196, 33.086265563964844, 33.66663122177124, 33.884676115853445, 34.353738580431255, 34.09927122933524, 34.44988080433437, 35.847417150224956, 33.555908203125, 35.585657664707725, 36.4980707849775, 37.197639737810405, 36.016373021262034, 34.0929970060076, 35.456508023398264, 37.90251016616821, 39.69150802067348, 41.09003448486328, 39.91827637808663, 38.8265962600708, 36.15916197640555, 35.289508070264546, 36.24511466707502, 49.29064587184361, 48.82531458990914, 48.0254032271249, 45.10527685710362, 43.68059042521885, 49.135225091661724, 46.85660852704729, 45.273107119968955, 44.612785066877095, 47.49850743157523, 47.12213741030012, 46.213111536843435, 46.31112282616751, 47.677444389888215, 45.724472522735596, 38.90288053240095, 35.85139151981899, 37.101521832602366, 35.187967096056255, 35.17446327209473, 34.508058071136475, 36.30889565604073, 34.81226757594517, 34.11109011513846, 36.769189493996755, 35.810748032161165, 35.342880657741, 36.58401305334908, 34.248779092516216, 35.27550745010376, 34.59363208498274, 35.29629646028791, 34.65360198702131, 35.6297960962568, 33.65639999934605, 35.69852767671858, 34.955897263118196, 36.311591557094026, 37.832305567605154, 38.665241718292236, 39.437384605407715, 41.78988136563982, 44.56302554266793, 44.56396007537842, 44.451708453042166, 47.06485993521554, 50.677131107875276, 45.157787867954795, 41.614873613630024, 46.0092305455889, 49.1604540007455, 52.138910497937886, 43.687660217285156, 38.976983070373535, 37.77719593048096, 41.972233363560264, 44.99206985746111, 47.449335030147004, 50.17563097817557, 52.10130337306431, 49.9733168057033, 52.500432218824116, 51.484390190669465, 54.115763323647634, 56.16333144051688, 25.709022658211843, 1.3869631418160029, 2.583271839788982, 2.6168318561145236, 0.10965011907475335, 0.11293606060956206, 15.343319586345128, 63.14754949297224, 54.11260536738804, 50.22098534447806, 48.27226230076381, 37.39320026125227, 48.38614327566964, 52.90025935854231, 50.102157252175466, 7.215985204492297, 0.18503492538418087, 0.06358770148030349, 0.020022231686328138, 0.0466706597778414, 0.044361795099186044, 0.018364918384967104, 0.11228326242417097, 0.040731985587626696, 0.04589026647486857, 0.05318993942013808, 0.20991939652178968, 0.21837696912033217, 0.1002858065600906, 0.1119645070284605, 0.06682868328477655, 0.1554886336837496, 0.11841665580868721, 0.2589164509304932, 0.14437119024140493, 0.21362258281026567, 0.13758727854916028, 0.2378052451780864, 0.143470719988857, 15.947854552950178, 65.46414143698556, 53.31223542349679, 51.535334382738384, 31.849983010973247, 27.962705612182617, 44.38579784120832, 55.57738637924194, 55.415858132498606, 33.93256657464163, 0.1996977957231658, 0.15688846499792167, 5.210689493588038, 6.665404302733285, 2.558600740773337, 12.25967344215938, 48.24117953436715, 53.23974139349801, 52.234215463910786, 50.73878942217146, 50.07089383261544, 47.64033753531319, 41.97613477706909, 35.71561677115304, 39.14095708302089, 42.44068438666207, 50.047033718654085, 47.62592697143555, 46.58389173235212, 48.87154442923409, 45.244098390851704, 45.61273506709507, 43.29402044841221, 39.5260887827192, 37.87795523234776, 38.134305545261924, 41.82999331610543, 40.43017101287842, 42.05991962977818, 42.42368909290859, 43.22252001081194, 41.18059730529785, 38.23914691380092, 36.381865637642996, 37.939332144601, 35.19412667410714, 36.95044020244053, 36.11681270599365, 35.107583386557444, 35.75243527548653, 35.98471702848162, 35.05714293888637, 35.96668297903878, 36.154871463775635, 36.18874045780727, 35.46361950465611, 37.686049461364746, 33.828138623918804, 37.718504496983115, 38.997598375592915, 40.332402910505024, 37.15915713991438, 36.53331899642944, 37.330041136060444, 39.111399446214946, 43.10687419346401, 41.947709696633474, 40.571375778743196, 41.22915826525007, 37.83261128834316, 38.16402299063546, 37.70887776783535, 51.31118202209473, 52.20340715135847, 50.231074128832134, 48.53980963570731, 45.75077840260097, 50.39952972957066, 48.12824698856899, 47.823769978114534, 46.22248118264334, 50.018351554870605, 49.80200549534389, 46.66039834703718, 47.43321520941598, 49.12829078946795, 46.72802863802229, 39.46950960159302, 37.27376420157296, 39.208573477608816, 38.670143672398154, 36.81157003130232, 36.073320456913535, 38.56532662255423, 36.973237242017476, 36.38557597569057, 37.597133363996235, 37.01377303259713, 36.89708151136126, 37.87111125673567, 35.75927577699934, 37.25926331111363, 36.365485259464805, 37.18906913484846, 36.45356062480381, 38.29604918616158, 35.88131046295166, 38.209700448172434, 35.81136294773647, 37.47457408905029, 40.78036022186279, 39.90083292552403, 40.07807452338082, 45.000022070748464, 46.64849608285086, 46.48120083127703, 45.251929010663716, 47.44146272114345, 51.094519819532124, 46.90083728517805, 40.857023171016145, 48.439255305698936, 48.44075959069388, 52.25000524520874, 46.89938163757324, 41.343303271702354, 39.95978839056832, 43.34318937574114, 45.34979786191668, 49.071829727717805, 51.88755941390991, 53.65082114083426, 52.832632541656494, 56.188268525259836, 54.47932086672102, 57.63296924318586, 58.72465978349958, 30.04373972756522, 1.4540047901017326, 3.6238004054341997, 4.346374843801771, 0.6134165014539446, 0.12090860280607428, 17.03655389377049, 67.93807533809117, 59.50693661825997, 54.69397503989083, 50.98978962217058, 43.581616810389924, 54.12156159537179, 61.55057552882603, 60.19325188228062, 11.046699489865984, 0.2747729457914829, 0.12088973953255586, 0.1035239045907344, 0.24834283973489488, 0.18403418122657708, 0.14494901709258556, 0.20182672648557595, 0.12669913923101767, 0.1263096872717142, 0.15908915762390408], [0.07397492589162928, 0.08041062019765377, 0.020033344393596053, 0.05275818758777209, 0.0161991346893566, 0.07948542412902627, 0.019537767861038446, 0.005039649217256478, 0.03420632093080452, 0.017721365239205103, 0.14273480804903166, 0.07009661650019032, 0.043860717343964746, 4.940968241010394, 40.54806457247053, 45.53744438716343, 41.217440128326416, 30.51706143787929, 25.74865518297468, 32.39922768729073, 42.52204084396362, 49.116385051182334, 34.08169228690011, 0.7027424882565225, 0.017271459202415178, 1.219146123954228, 17.402531147003174, 7.636689509664263, 5.017952110086169, 44.65292828423636, 49.47174024581909, 46.665255137852256, 44.635491779872346, 40.735770157405305, 34.55304070881435, 34.64295734677996, 38.16741023744856, 43.543964522225515, 45.14839390345982, 46.80297885622297, 46.25860834121704, 45.14770950589861, 42.17414454051426, 40.74524402618408, 37.49448415211269, 34.599579742976594, 31.244777543204172, 33.79827526637486, 32.761506761823384, 33.399594579424175, 33.48784712382725, 36.473397731781006, 34.047131947108674, 33.31476749692644, 33.271799836839946, 32.04084307806832, 30.103730474199565, 32.6858617237636, 32.79030704498291, 31.737939834594727, 32.930077007838655, 32.721804755074636, 33.07982805797032, 32.479597500392366, 32.22057213102068, 34.52072811126709, 31.80463559286935, 33.572187832423616, 32.89956051962716, 33.41784749712263, 33.885610648563926, 34.6376246043614, 32.964474064963206, 34.78558996745518, 35.1111547606332, 33.19440385273525, 33.984063148498535, 37.20420578547886, 38.842163699013845, 41.54615592956543, 42.65000581741333, 39.71447876521519, 36.542066778455464, 36.02244922092983, 34.91135583605085, 40.58556400026594, 47.98536423274449, 48.54851572854178, 44.50882264545986, 41.304435048784526, 49.8950001852853, 47.549024309430806, 43.56815814971924, 45.16055672509329, 45.30936976841518, 45.80143077032906, 45.55813264846802, 46.39970888410296, 46.75525515420096, 42.78827496937343, 33.955686705453054, 34.69218533379691, 33.59177133015224, 33.51951353890555, 32.85238919939314, 34.7668263571603, 34.34058564049857, 33.24168981824602, 34.89914090292794, 33.427026067461284, 33.547851766858784, 34.474244662693565, 33.25850445883614, 32.155943461826865, 32.848209857940674, 33.08777679715838, 33.69523695537022, 33.506398814065115, 33.625105312892366, 31.641808032989502, 33.14439071927752, 32.31530039651053, 33.467356886182515, 32.44947705950056, 34.35003171648298, 34.16034936904907, 34.342093399592805, 37.859215940747944, 41.31443350655692, 42.714752605983186, 42.88750914164952, 43.12008619308472, 49.251249585832866, 45.11672054018293, 43.82302502223423, 42.05209248406546, 45.99609497615269, 48.73389714104788, 41.93060670580183, 39.872901167188374, 36.45251144681658, 39.57926682063511, 41.61038160324097, 49.71387454441616, 49.23868029458182, 50.954270430973594, 49.30980552945818, 52.92681189945766, 52.90862151554653, 51.85120643888201, 17.821127108165197, 0.7284319326281548, 2.561292950596128, 2.682523165430341, 0.24906376962150845, 0.09773672012878315, 15.658738272530691, 57.9489802633013, 45.54228728158133, 44.09325783593314, 23.171165330069407, 25.028048821857997, 40.37099320547921, 44.75222846439907, 44.86050919124058, 4.73274028301239, 0.15042459113257273, 0.057884200742202144, 0.024834033933335116, 0.023223030646996837, 0.050754422787576914, 0.04932626602905137, 0.02984877921906965, 0.02370288552317236, 0.045828455327344794, 0.020277389691078236, 0.03304454344989998, 0.05422317183443478, 0.0446854257690055, 0.036712605373135636, 0.02146712111841355, 0.028267198907477514, 0.04095433472788759, 0.026913580917088047, 0.03129371954128146, 0.02562885289080441, 0.034135705791413784, 0.019997573723750453, 0.0761851587199739, 6.560246356895991, 48.3220774105617, 49.61220155443464, 47.38503640038626, 31.209425108773367, 24.880439553941997, 38.58029304231916, 48.641468729291645, 53.32614571707589, 36.80985730034964, 0.6640811370951789, 0.12845554069748946, 3.723475354058402, 12.380816153117589, 7.7957276957375665, 5.82767128944397, 45.63943352018084, 53.124908515385215, 47.56506075177874, 45.793492453438894, 41.59001643317086, 35.83214848382132, 35.18397535596575, 38.859297956739155, 44.59583841051374, 47.79445205415998, 47.60442924499512, 46.304727009364534, 47.501748766217915, 43.184954575129915, 43.23285893031529, 40.71991089412144, 35.38543142591204, 33.44939579282488, 35.547404357365195, 34.327790532793315, 35.831345966884065, 35.79356166294643, 38.188828059605186, 35.57465171813965, 35.652433327266145, 34.95337854112898, 33.657167775290354, 32.011441775730674, 33.567838260105674, 34.87305041721889, 33.92295026779175, 33.930579389844624, 35.05609376089913, 34.63253852299282, 33.844209807259695, 33.871616976601736, 35.71244491849627, 33.82996947424752, 34.33046906335013, 35.022749355861116, 34.925679547446116, 34.88101652690342, 36.59558875220162, 35.40508440562657, 35.377840518951416, 37.001836027417866, 34.98277984346662, 35.62281315667288, 38.26762063162667, 40.49484831946236, 41.814512729644775, 43.53926059177944, 41.40127209254673, 38.85199192592076, 37.56773206165859, 35.41675737925938, 44.40533964974539, 49.63433851514544, 49.269273212977815, 44.909004143306184, 44.4808109828404, 50.948604175022666, 49.00334480830601, 44.467647620609824, 45.39255012784685, 47.607719217027935, 48.53449426378523, 46.77845866339547, 48.18499640056065, 47.77961070196969, 44.62460742677961, 35.82248701368059, 36.078819956098286, 35.03050354548863, 35.0302916254316, 35.95750093460083, 35.48282779966082, 36.54170199802944, 34.72361551012312, 36.89430570602417, 35.03574596132551, 35.738469396318706, 36.66903468540737, 35.29590736116682, 34.23536212103707, 34.05830117634365, 35.0288359778268, 34.54136773518154, 34.56644030979702, 34.50683866228376, 34.87069845199585, 34.613500458853586, 35.223329952784944, 33.93796532494681, 34.2080522264753, 35.393119607652935, 36.15691076006208, 37.576809883117676, 40.81033475058419, 42.795271805354524, 43.65522255216326, 45.05277974264962, 45.55854606628418, 50.27045999254499, 44.98849500928606, 43.97812271118164, 44.50798886162894, 49.53572620664324, 49.53208187648228, 43.966095379420686, 40.796646799360005, 38.526618208204, 40.62626307351248, 45.153681482587544, 51.1799270766122, 51.07829230172293, 55.082789284842356, 52.74943133762905, 55.01532922472273, 55.24697174344744, 52.8274005481175, 20.381656408309937, 1.1367832635130202, 3.416382998228073, 2.5170767860753194, 0.11599964621875967, 0.15628842291023048, 16.574849571500504, 64.31738989693778, 50.17438725062779, 46.791893005371094, 25.966663599014282, 30.032021590641566, 46.825928756168906, 50.554616996220176, 52.88047783715384, 7.248095870018005, 0.07025605865887233, 0.04916397063061595, 0.04882432992703148, 0.010100578989035316, 0.06976198338504348, 0.012287065636233559, 0.06234315290514912, 0.06631972095263855, 0.019986143801361322, 0.041894176974892616, 0.12864253137792858, 0.17241886949964932, 0.12191971497876303, 0.17234239860304765, 0.1435757436390434, 0.15881234247769627, 0.1375874685389655, 0.06230492424219847, 0.1394823725734438, 0.16034045762249402, 0.2399408934371812, 0.13405303390962736, 0.18260009746466363, 7.212463770593915, 55.03001424244472, 57.71171317781721, 52.44215767724173, 40.95401654924665, 36.28881188801357, 42.56897939954485, 52.516791752406526, 57.88648469107491, 43.52209159306118, 1.1449515223503113, 0.20223861081259592, 6.278014438492911, 25.441306829452515, 13.72765931061336, 6.427684281553541, 49.66220773969378, 53.01426192692348, 49.32134648731777, 48.81865126746041, 44.13095876148769, 37.38209356580462, 37.7172850881304, 41.91172497613089, 48.378243173871724, 50.017031397138325, 49.92624970844814, 47.4846179825919, 50.02316665649414, 45.05630247933524, 45.41342946461269, 42.918567589351106, 36.965886047908235, 36.34632212775094, 37.07881164550781, 35.464630467551096, 37.96381064823696, 38.05895927974156, 40.5236416544233, 37.628834520067485, 37.52392714364188, 37.7441086087908, 35.65480266298567, 33.4911162512643, 36.16147920063564, 35.933401107788086, 34.83586713245937, 35.685875007084434, 37.30642073495047, 36.946771553584504, 36.04661158152989, 35.00683103288923, 37.46629878452846, 36.39113106046404, 36.95043325424194, 36.774386746542795, 36.86380658830915, 36.65538494927542, 38.40010888235909, 37.27770383017403, 37.41078962598528, 37.8576352255685, 37.54833616529192, 38.173145975385395, 42.03711216790335, 43.91531099591936, 44.023247786930625, 47.18368107931954, 43.26120063236782, 40.719487054007395, 39.97332000732422, 38.312561580113, 46.664251123155864, 51.85345765522548, 51.91461222512381, 45.70612580435616, 45.089917864118306, 52.15992532457624, 52.0629632132394, 47.019102573394775, 49.589824880872456, 49.434980801173616, 50.941881792885916, 47.7112786429269, 49.84567492348807, 49.8082206589835, 47.814271790640696, 37.992225306374685, 36.89810289655413, 36.615554400852744, 36.42326647894723, 36.844702516283306, 38.153489521571565, 37.937608991350444, 36.31787272862026, 38.956788131168906, 36.9851325580052, 36.01898554393223, 38.39550222669329, 35.893243994031636, 35.162894521440776, 35.02125896726336, 36.84476852416992, 36.11338029588972, 36.08440283366612, 36.175271374838694, 36.67945350919451, 37.81034231185913, 36.74174410956246, 36.548764841897146, 36.41059643881661, 38.10644326891218, 38.12586348397391, 39.00542204720633, 41.96878010886056, 45.58759648459298, 46.66449083600725, 48.051014287131174, 48.01150335584368, 53.53385863985334, 46.037235260009766, 44.61511271340506, 46.517960275922505, 50.274715764181956, 51.23607199532645, 47.66947133200509, 43.435822759355815, 42.00569241387503, 42.68864822387695, 47.36675568989345, 54.158512115478516, 54.109384877341135, 55.54999310629708, 55.59160239355904, 58.84989411490304, 58.16909224646432, 56.274645056043354, 22.161538226263865, 1.76288218157632, 7.254909447261265, 7.315742662974766, 0.5384078206760543, 0.14198037210319722, 19.55099752971104, 68.37854943956647, 55.7110002381461, 54.566218512398855, 32.45875290461949, 35.20201982770647, 54.306665079934255, 59.027295521327424, 61.87001895904541, 9.560264417103358, 0.2006500381976366, 0.13066236728004046, 0.11520795870040144, 0.0950994309304016, 0.13462951726147107, 0.13841673332665647, 0.2062839280281748, 0.12324967075671468, 0.09485676645168237, 0.14712343684264592], [0.027416054758110216, 0.0792732055165938, 0.12113321146794728, 0.03904096097020166, 0.044820939390254874, 0.019489951498274292, 0.02656460866065962, 0.058164293212550025, 0.013909886458090373, 0.02851714745962194, 0.07263361143746547, 0.0644474189196314, 0.05339923354664019, 1.5418685610805238, 35.87854855401175, 47.79009553364345, 38.55466113771711, 37.25999982016427, 20.08334592410496, 29.48851612636021, 41.028529030936106, 46.533489499773296, 43.825074740818565, 3.42947079879897, 0.19991921527045114, 4.555150406701224, 32.29266316550118, 9.344695687294006, 5.439462406294687, 49.02060065950666, 47.52714095796858, 47.13361930847168, 39.36691944939749, 35.55686432974679, 38.961735248565674, 44.5530548776899, 44.05631078992571, 45.215312004089355, 44.38922677721296, 44.19181455884661, 45.92643928527832, 44.230460439409526, 40.91973066329956, 40.054909229278564, 33.40592091424124, 32.13213198525565, 31.41618960244315, 30.380480698176793, 30.71609606061663, 30.963177476610454, 31.14922939028059, 33.38652154377529, 32.97605323791504, 32.526991162981304, 30.442618438175746, 32.746516023363384, 31.22746958051409, 33.33195734024048, 31.71607732772827, 32.17910875592913, 32.183006695338655, 31.63263988494873, 32.7964631489345, 32.08857025418963, 32.30405126299177, 32.064970697675435, 33.31480918611799, 34.22626345498221, 33.5777324948992, 33.359222071511404, 32.98875454493931, 35.13911083766392, 34.62830359595162, 34.739631107875276, 36.24703236988613, 32.7497295652117, 31.50934410095215, 35.96079785483224, 41.30096442358834, 43.92065416063581, 44.97203125272478, 40.54349960599627, 37.73790386744908, 34.67099332809448, 32.86100149154663, 37.4706483568464, 46.407067026410786, 49.87422854559762, 43.66233055932181, 43.097351687295095, 47.00904158183506, 47.815248012542725, 43.76953431538173, 44.16542182649885, 45.96940347126552, 44.755045958927695, 46.47909900120327, 46.682775020599365, 46.86847257614136, 39.127863202776226, 34.34913887296404, 34.10028914042881, 34.79593236105782, 34.681002208164756, 32.389034679957796, 34.12054313932146, 34.30717175347464, 33.81541647229876, 34.38114922387259, 35.05464506149292, 34.68632105418614, 33.09687546321324, 33.391378334590364, 32.67696108136858, 32.333528995513916, 33.26832921164376, 34.04386281967163, 34.072934082576204, 34.43994835444859, 32.564775466918945, 32.79666812079293, 33.463695185525076, 32.75455508913313, 33.98189878463745, 32.00615072250366, 34.931974615369526, 34.69744512013027, 37.18243360519409, 37.98711838041033, 40.140198366982595, 40.92204441343035, 45.27577870232718, 44.65634332384382, 45.33391080583845, 46.26093251364571, 45.847594601767405, 39.93011958258492, 44.99649933406285, 45.25543090275356, 41.34768411091396, 40.175338881356375, 41.71551827022007, 38.89972257614136, 41.52781963348389, 46.722143513815745, 50.234256403786794, 50.879796164376394, 51.31182125636509, 51.25210496357509, 44.125379358019146, 13.756159084183828, 2.012916147708893, 3.000493577548436, 1.2470861332757133, 0.07600650723491396, 0.027638218997578536, 17.268262420381816, 58.67825276511056, 46.3534825188773, 40.812356676374165, 42.98952259336199, 27.757004192897252, 33.812706674848286, 46.91641862051827, 33.47634785515921, 1.3576092826468604, 0.06574170411165271, 0.045852346545351405, 0.04041050248114126, 0.034661390619086366, 0.03175960507776056, 0.02410887338088027, 0.029583309178373644, 0.024347381832610284, 0.019916174966575842, 0.02551616179490728, 0.00672749404995037, 0.06932769383170775, 0.07407703862658568, 0.05480176203751138, 0.09378825021641594, 0.031524278955268006, 0.032776338913078816, 0.05854749586433172, 0.06862509117594787, 0.07647929686520781, 0.05498142793242421, 0.00787139467761985, 0.03309780844886388, 2.5678652950695584, 42.75019189289638, 52.4503287587847, 44.0321102142334, 39.860133852277485, 22.194064480917795, 30.58447286060878, 46.63742412839617, 51.88685417175293, 47.03592068808419, 2.9580976239272525, 0.09548156828220401, 2.7563809965338026, 22.229005234582083, 9.732679622513906, 5.678608979497637, 51.82433080673218, 48.08180175508772, 50.14692102159773, 40.88324219839913, 37.81056465421404, 39.629537037440706, 45.95122350965227, 45.63237067631313, 47.233190468379426, 46.419163840157644, 46.256697586604524, 48.35551561628069, 46.00962311880929, 42.29479653494698, 41.76727192742484, 35.66653817040579, 34.37529189246041, 33.18730974197388, 33.00275863919939, 33.85528870991298, 34.2575546673366, 32.839899812425884, 34.44123724528721, 33.816778319222585, 33.73753064019339, 32.60210466384888, 34.52166959217617, 33.91968808855329, 35.00012949534825, 33.57310152053833, 34.31860154015677, 33.73284755434309, 33.459321294512065, 35.318395205906455, 34.822905267987935, 33.46758965083531, 35.203857626233784, 34.79283346448626, 35.661643164498464, 34.07734618868147, 34.75372552871704, 34.01313093730381, 35.852621350969585, 35.610997744968955, 36.200517654418945, 36.49366910117013, 34.94733708245413, 34.677239758627756, 37.90104409626552, 42.858799185071675, 43.85496241705758, 45.15984106063843, 42.377782344818115, 38.10345901761736, 36.29349497386387, 35.264980929238455, 39.29864992414202, 47.55689314433506, 50.454476084027974, 45.65550470352173, 44.50184317997524, 49.1738258089338, 49.38580839974539, 45.65749536241804, 45.580999170030864, 47.442209652491975, 47.80083050046648, 47.501866885593955, 47.79406990323748, 47.895416327885215, 40.73015948704311, 34.95770379475185, 35.12727458136422, 35.94166946411133, 35.99845361709595, 34.66993372780936, 35.365986892155235, 35.47065455572945, 35.04853064673287, 36.364946774074006, 35.59819221496582, 36.19173860549927, 35.54538590567452, 35.34824814115252, 34.2816093308585, 34.11318499701363, 34.64533710479736, 35.53810766765049, 34.88328858784267, 34.93915557861328, 34.09236819403512, 35.48971693856375, 34.89435706819807, 34.53479126521519, 34.078913007463726, 34.49123995644705, 36.2044711794172, 37.0526099886213, 39.237693377903526, 40.042593547276084, 41.04556253978184, 43.56962421962193, 46.61896276473999, 47.37198073523385, 47.663294383457725, 47.389198371342246, 47.79106828144619, 42.65303175789969, 48.7969902583531, 46.79747240883963, 43.201171670641216, 42.65337569372994, 41.2470429284232, 39.795640672956196, 45.00670971189226, 49.21961096354893, 51.85923855645316, 53.028873988560264, 54.73279115131923, 53.780106272016255, 47.51215021950858, 16.026075635637554, 1.33355798465865, 2.3592666941029683, 1.761940700667245, 0.21671197989157268, 0.07481661465551172, 18.620103938238962, 64.19148853846959, 50.949754101889475, 45.37789290291922, 40.83955192565918, 31.0088723046439, 40.8971768106733, 51.67162329810006, 40.92510856900896, 2.6486958605902533, 0.05233406588169081, 0.05497133133134671, 0.043166270679129023, 0.06643008467342172, 0.03300544286945036, 0.018403058838365332, 0.01032396374336843, 0.07075628824532032, 0.011242424503767064, 0.01976521110295185, 0.0714241499081254, 0.1683961475001914, 0.20016882116241114, 0.13997695674853666, 0.174785599644695, 0.12960643108401979, 0.100168840693576, 0.1674154336963381, 0.29093858120696886, 0.11336384979741913, 0.19730818537729128, 0.1207845394632646, 0.08571202108370406, 3.034073135682515, 48.93194164548601, 59.217606680733816, 49.738422530038015, 48.13649797439575, 30.649341242653982, 39.45697505133492, 52.06028468268258, 55.12250518798828, 53.21644755772182, 4.1493769117764066, 0.24327383030738148, 7.386906981468201, 37.3571321623666, 11.658211316381182, 7.515395675386701, 53.96470601218087, 50.72366666793823, 53.40633487701416, 43.15058183670044, 39.2856776373727, 42.32362461090088, 49.04072264262608, 47.48511477879116, 49.69802222933088, 45.887821197509766, 48.338985851832796, 49.35907867976597, 48.3772600037711, 44.59007487978254, 44.72309466770717, 36.81586749213082, 36.80122068950108, 36.30441059385027, 35.1375926562718, 36.23435190745762, 35.080794606889995, 34.66986424582345, 36.53393043790545, 35.592783042362754, 35.211326939719065, 34.047878878457205, 35.540820939200266, 34.94082314627511, 37.63319798878261, 35.137818472726, 35.50613553183419, 36.35945074898856, 34.567406109401155, 38.06843662261963, 36.366669927324565, 34.81737797600882, 36.424920150211875, 37.018737520490376, 38.344332218170166, 36.87286703927176, 36.24355479649135, 36.4350471496582, 38.232219559805735, 39.34627635138375, 38.21453986849104, 38.39792367390224, 36.81806659698486, 35.9560626574925, 38.928825105939595, 45.08796542031424, 47.04143408366612, 46.26452473231724, 44.43393496104649, 41.05820478711809, 38.74858883449009, 36.34522778647286, 41.282516956329346, 49.99726377214704, 53.024135317121235, 47.03323520932879, 46.79595422744751, 50.251074518476216, 50.97565351213728, 48.54231446129935, 48.297432150159565, 48.40849215643746, 50.02605363300869, 49.249720982142854, 50.58937188557216, 50.493861947740825, 41.158321380615234, 37.47546345846993, 36.7640825680324, 38.6330680847168, 38.13523660387312, 35.937483174460276, 36.82765858513968, 37.071946825299946, 36.89568839754377, 37.62786177226475, 37.34330872126988, 37.956876346043174, 36.801449980054585, 36.76310634613037, 37.112420082092285, 34.07675559180123, 36.27555472510201, 38.700542041233604, 37.381596769605366, 38.08885737827846, 35.747925894601, 37.284224714551655, 36.82319784164429, 35.689588819231304, 36.63767051696777, 35.972408294677734, 39.5345447404044, 39.614435127803254, 42.448337827410015, 42.03575379507882, 43.25708382470267, 45.513556480407715, 48.205882685525076, 49.65330709729876, 48.09161955969674, 47.40274041039603, 47.70099878311157, 45.56133229391915, 49.48208263942173, 49.542736939021516, 45.901224272591726, 45.62017658778599, 44.372241905757356, 43.3705027444022, 46.050801617758616, 51.37528262819563, 54.66788455418178, 55.71941103254046, 57.02286182131086, 54.83290079661778, 46.16896268299648, 17.319345576422556, 3.583158220563616, 7.521634289196559, 4.202397312436785, 0.30551079926746233, 0.14935310291392462, 20.92895906312125, 69.94374234335763, 55.63282952989851, 54.202796459198, 58.59304700578962, 40.260370935712544, 47.94688858304705, 58.98853152138846, 47.829259055001394, 3.707550517150334, 0.27846395916172434, 0.16805932271693433, 0.1543461164193494, 0.12027635744639806, 0.1528567863362176, 0.17208850436976977, 0.12119463245783534, 0.24098100619656698, 0.13875872854675564, 0.09500613915068762], [0.05802139373762267, 0.007217378521870289, 0.04245336786178606, 0.03543534462473222, 0.025564042618498206, 0.004946988475109849, 0.03038992446714214, 0.06976177303918771, 0.0392556630208024, 0.04146819608286023, 0.046814889181405306, 0.03747588263026305, 0.01432633732578584, 0.7723791258675712, 28.537081922803605, 47.26114307131086, 37.72405958175659, 34.89865452902657, 22.52170852252415, 27.902014834540232, 42.13959462302071, 45.51024218967983, 47.31175722394671, 7.666594556399754, 0.15269211945789202, 3.036286788327353, 22.280173506055558, 11.184862681797572, 6.325448487486158, 49.668183190482004, 46.201396874019075, 45.796650409698486, 39.02603735242571, 44.25697129113333, 45.070365633283345, 46.65971047537667, 45.40354912621634, 47.86751583644322, 47.435831206185476, 46.59508180618286, 44.05879824502127, 40.953238351004465, 39.56568309238979, 35.45591395241873, 32.545900685446604, 32.47718300138201, 31.565106868743896, 30.50073664528983, 31.064767088208878, 32.57260608673096, 31.96856791632516, 32.11138813836234, 32.49685682569231, 33.51744644982474, 33.54247038705008, 33.51619577407837, 32.670634746551514, 32.809775897434776, 31.04772663116455, 33.169400760105674, 32.34750182288033, 32.758953298841206, 31.999362332480295, 32.810446398598806, 33.66802086148943, 33.46466098512922, 32.91097640991211, 34.01426349367414, 33.81846325738089, 34.04760789871216, 34.455946581704275, 33.73708248138428, 30.894105434417725, 34.41922535215105, 36.181257247924805, 33.09553446088518, 33.40235301426479, 37.93266534805298, 42.54961824417114, 48.212441784994944, 46.62199912752424, 39.7014856338501, 39.10034833635603, 35.0570421900068, 33.24197122028896, 37.17221280506679, 45.43243278775896, 47.97926024028233, 44.90623876026699, 43.23366492135184, 47.20463684626988, 46.77749286379133, 43.930843693869456, 45.142963886260986, 46.58507292611258, 46.30305249350411, 46.271361759730745, 46.559138774871826, 44.92858416693551, 35.76270471300398, 33.156522274017334, 34.801192147391184, 35.377420152936665, 36.37277739388602, 35.09546225411551, 34.054997307913645, 33.99083069392613, 34.04573883329119, 34.41890573501587, 34.95463963917324, 33.0003719329834, 36.17178337914603, 34.04399136134556, 33.895352022988455, 34.265371390751426, 33.4200188091823, 34.057071345193044, 33.71417079653059, 32.56036683491298, 32.84610455376761, 32.89994961874825, 32.85852445874895, 33.53993082046509, 34.310562474387034, 32.283887590680806, 33.29693494524275, 35.50935254778181, 36.77202435902187, 38.089124883924214, 41.156212602342876, 41.38987704685756, 43.41728149141584, 47.55581617355347, 46.935571329934255, 40.388638155800955, 43.850303649902344, 45.11260025841849, 42.92527607509068, 42.30833509990147, 40.88798086983817, 42.69687489100865, 46.35803358895438, 46.51546239852905, 44.53603179114205, 40.1687832559858, 47.533467292785645, 49.11005176816668, 50.864791529519216, 48.34697280611311, 41.189647333962576, 13.590586985860552, 1.5297382005623408, 1.37505327803748, 1.225170863526208, 0.20004220652793134, 0.036007342860102654, 17.971795320510864, 59.35766151973179, 44.078868116651265, 39.92358480181013, 19.471275636128016, 32.15378604616438, 39.74802119391305, 44.58243533543178, 30.986665861947195, 1.3688856661319733, 0.04090732582179563, 0.029552232274519544, 0.060535963092531474, 0.029094088822603226, 0.017251744367448345, 0.022579519909673502, 0.028378987551799843, 0.01917485679898943, 0.010963873156080288, 0.020639852920014943, 0.003866953683817493, 0.02744857524521649, 0.01832689667519714, 0.05703318890716348, 0.06558946799486876, 0.04618734946208341, 0.053286382995013676, 0.03678781080192753, 0.006190832222013601, 0.03486689512750932, 0.03370162319125874, 0.02725781699908631, 0.03442715693797384, 0.9773399106093815, 33.877411774226594, 51.23837532315935, 43.25256402151925, 40.017222200121196, 26.039270537240164, 34.55441297803606, 47.766593251909526, 47.9143397467477, 52.541044439588276, 7.905405879020691, 0.025274918847052113, 1.328141212463379, 23.674623114722117, 10.907785023961749, 5.724100572722299, 54.50927455084664, 47.89145932878767, 47.08332824707031, 39.43282311303275, 46.13968644823347, 46.59006173270089, 49.71104662758963, 44.41239207131522, 48.393782820020405, 48.0923421723502, 49.44044208526611, 45.8108560017177, 44.10974243709019, 41.13144227436611, 36.80094970975603, 32.70217956815447, 33.758423873356406, 33.84685359682356, 32.35351896286011, 32.18722077778408, 33.43655552182879, 32.46311984743391, 33.67968341282436, 32.7801696232387, 35.5043637411935, 34.53687572479248, 35.53639841079712, 33.54458263942173, 35.4430285181318, 32.51634304864066, 33.894837856292725, 34.11587047576904, 35.497109821864534, 33.03783661978585, 33.893114703042166, 34.42201852798462, 35.04669632230486, 33.9229850087847, 35.983223165784565, 34.522583280290874, 37.70446218763079, 34.797846589769634, 36.40593767166138, 33.32054839815412, 37.06255286080496, 36.399083273751394, 34.93526111330305, 34.25389296667916, 39.374812602996826, 43.50265053340367, 51.257628781454905, 49.53703246797834, 42.37175130844116, 38.941540309361045, 36.823083196367534, 35.092578751700266, 37.335227966308594, 45.637046813964844, 49.1994229725429, 46.59636722292219, 45.97467367989676, 48.692729064396445, 47.76519666399275, 45.49712746483939, 45.72580310276577, 47.647904123578755, 47.7368723324367, 48.53940316608974, 48.09280770165579, 45.486354282924104, 35.66089970724923, 36.100599084581646, 36.67140402112688, 37.694501944950645, 37.7141375541687, 36.07477263041905, 35.38686275482178, 35.15606096812657, 35.93457882744925, 35.48352261951992, 37.70055382592337, 36.68740919658116, 36.91444853373936, 35.40767955780029, 34.94549233572823, 36.07751022066389, 36.412257058279856, 34.99892050879342, 35.39896651676723, 34.08606965201241, 35.450035776410786, 34.94410269601004, 34.15560027531215, 34.90861129760742, 36.8538567679269, 35.222353730882915, 34.39409024374825, 36.67033747264317, 38.25396394729614, 40.54667493275234, 43.862577642713276, 43.67841216496059, 44.85738945007324, 48.080641405923025, 48.173879282815115, 43.1550738470895, 45.63490676879883, 46.09809800556728, 44.83865015847342, 44.87300205230713, 43.212386063167024, 45.13167306355068, 48.185722487313406, 48.2977865082877, 45.48565946306501, 43.38498626436506, 50.84395735604422, 51.998963356018066, 52.828602586473735, 51.938791956220356, 42.6111341203962, 15.271247659410749, 1.2536528323377882, 3.0296857825347354, 1.8813446249280656, 0.12374515059803214, 0.004866806416040552, 19.069044419697352, 66.11736243111747, 49.14695712498256, 48.52168525968279, 29.10763325010027, 37.11617905752999, 43.81274863651821, 52.52240937096732, 37.04035684040615, 1.8306462253843034, 0.02807346698162811, 0.03843034391424485, 0.07278088067791291, 0.036058287269302776, 0.08553655871323176, 0.02426982019096613, 0.03583722056022712, 0.06777296654347863, 0.011312817422939199, 0.027371310462642993, 0.10055521888924496, 0.10642461465405566, 0.0787885890209249, 0.1951588714229209, 0.10883750553642, 0.11110265220382384, 0.27193137684038704, 0.09785008297434875, 0.08326170220971107, 0.10046281599040542, 0.1645841784775257, 0.15755306290728704, 0.16090883926621505, 1.3356940128973551, 37.771130153111045, 58.4115183694022, 48.70937694822039, 44.31528752190726, 34.23218332018171, 38.63200848443167, 52.58254255567278, 52.11215645926339, 58.12616974966866, 9.679216708455767, 0.24608486518263817, 5.909042511667524, 26.89453646114894, 15.654345273971558, 7.142847163336618, 56.73013768877302, 49.21596663338797, 49.43979590279715, 43.03647157124111, 48.42765876225063, 48.56676517214094, 50.441614968436106, 45.7118684904916, 49.678782667432515, 50.613958086286274, 51.37318427222115, 47.894860471997944, 45.15100295203072, 43.96544919695173, 38.608756337847026, 34.711890425000874, 36.594289439065115, 36.61876099450247, 34.49096202850342, 35.18013300214495, 35.776945046016145, 34.793382372174946, 35.93273755482265, 35.52144936152867, 38.09061874662127, 36.56319625037057, 38.08629696709769, 36.27265385219029, 38.241453715733115, 34.403466837746755, 36.173701081957134, 35.610261235918315, 37.239297662462505, 35.18288796288626, 35.153726373400005, 36.85436398642403, 37.49272625786917, 36.10579286302839, 37.89222683225359, 36.22019147872925, 38.21613795416695, 36.53900957107544, 38.74993678501674, 33.698492186410085, 38.13419089998518, 38.44434111458914, 36.08539642606463, 36.33708797182356, 42.00454248700823, 47.169930594308035, 51.40053238187517, 50.49952820369175, 43.471699782780235, 41.354726110185894, 39.59960767201015, 37.04053054537092, 39.771429674965994, 47.54046065466744, 51.58750145775931, 47.28611489704677, 47.76081582478115, 48.43834161758423, 48.914046560014995, 47.612239020211355, 47.513710090092246, 49.19208220073155, 48.87406662532261, 49.41783264705113, 50.33621079581124, 48.82266385214669, 37.11685650689261, 36.70810093198504, 38.770270688193186, 38.6286802973066, 40.22235039302281, 38.359767641339985, 37.10812609536307, 37.47117641993931, 37.40595367976597, 37.12402357373919, 39.90069396155221, 37.97040796279907, 40.46156644821167, 37.60059009279524, 37.26342528206961, 38.78095006942749, 37.722878387996126, 38.27619123458862, 39.012304237910676, 37.07438216890608, 37.758672033037456, 36.18390103748867, 35.877985749925884, 36.84667927878243, 38.44110672814505, 37.14950956617083, 37.01527384349278, 38.70735822405134, 40.8425292287554, 42.2578946522304, 46.34271281106131, 45.306121485573904, 47.776404108319966, 50.87086425508772, 48.31263828277588, 42.669999258858816, 47.55861629758562, 48.124085017613, 47.487230505262104, 46.824334144592285, 45.201377391815186, 46.95591565540859, 52.208729471479145, 51.36870615822928, 50.12031636919294, 44.41093642371041, 53.06136723927089, 53.824849196842735, 56.55685656411307, 53.08473055703299, 44.60470083781651, 17.181389093399048, 3.8608751126698087, 5.951743100370679, 5.619610088212149, 0.6383219393236297, 0.054743669261889796, 22.384549345288956, 70.22811821528843, 55.20343780517578, 53.03751407350813, 33.10711015973772, 44.058826037815635, 51.57402195249285, 61.6568968636649, 46.71035589490618, 2.5473509558609555, 0.2367592698761395, 0.10709978413901158, 0.17756588331290654, 0.09604928496160678, 0.15695231514317648, 0.08857702663434402, 0.07066261648599591, 0.11790782239820276, 0.09122476527201277, 0.10434865712055139], [0.04670167900621891, 0.018595048625554358, 0.017660824648503746, 0.0323745240457356, 0.08686005483780589, 0.047869397061211724, 0.043331799296928306, 0.08716050335871321, 0.06455039339406149, 0.058993734419345856, 0.012904341665229626, 0.026326676963695457, 0.059904749106083593, 0.07111452080841575, 17.267414740153722, 49.80473613739014, 36.158293451581685, 39.1593976020813, 28.346986157553538, 26.46613311767578, 40.109344891139436, 44.94740683691842, 48.868469851357595, 15.671976327896118, 0.09606520339314427, 0.9844201249735696, 22.881844077791484, 5.026778493608747, 3.6912817444120134, 47.32834257398333, 47.252252851213726, 46.307839802333284, 44.49560717173985, 47.29046446936471, 47.583424840654644, 47.203341007232666, 46.28248929977417, 47.76569693429129, 44.08005278451102, 45.074805532182964, 41.13770954949515, 42.03426340648106, 33.365680422101704, 33.35818331582205, 32.694098813193186, 31.646056856427872, 32.046867166246685, 31.30052294049944, 32.2597564969744, 31.092855181012833, 30.92243324007307, 32.312072958265034, 32.73703520638602, 30.845683438437327, 30.1435158593314, 31.077513558523997, 33.863786356789724, 33.588439668927876, 31.378116948263987, 33.26524073737008, 33.89521653311593, 34.08957501820156, 31.881951672690256, 33.04552132742745, 33.677807399204795, 32.36662673950195, 33.37012726919991, 33.959021840776714, 33.360441480364116, 33.671078068869456, 33.18737574986049, 34.769087995801655, 33.364933490753174, 33.777159690856934, 33.52712181636265, 32.76927137374878, 35.244237082345144, 39.64337090083531, 44.073740346091135, 42.91410337175642, 40.81703628812517, 41.91815900802612, 38.52408211571829, 36.520610741206575, 34.08626767567226, 35.91392183303833, 42.15438733782087, 49.12363549641201, 44.91155065808977, 44.45752756936209, 47.029563086373464, 46.380893162318635, 43.43310948780605, 44.63918474742344, 46.297525201525005, 46.69224541527884, 46.87471553257534, 48.07977288109915, 42.18211759839739, 35.03661101205008, 33.58487524305071, 35.60987908499581, 34.18575545719692, 34.766121115003315, 32.739084924970356, 34.99475506373814, 35.171750000544954, 33.68356398173741, 34.71641717638288, 35.735971518925254, 34.262275968279155, 32.930917739868164, 34.01158148901803, 32.2702830178397, 34.0952273777553, 33.01399735042027, 32.6491231237139, 32.9982909475054, 34.185630389622276, 33.54537125996181, 32.25677571977888, 33.58064031600952, 33.384485721588135, 33.30129493985857, 32.82857772282192, 32.89561741692679, 35.02384717123849, 37.309109687805176, 39.81177091598511, 41.872693470546174, 43.5289112499782, 47.98664270128523, 43.7710976600647, 40.33245849609375, 44.295485155923025, 48.4185323034014, 43.03016608101981, 42.43978459494454, 40.69505023956299, 41.46406643731253, 46.0634195463998, 50.39132738113403, 50.09707464490618, 47.503520556858604, 44.44508334568569, 46.619105202811106, 49.73169667380196, 49.963512897491455, 46.74219601494925, 38.008619580950054, 13.432591898100716, 1.0114389551537377, 0.7992324477859906, 0.9702409143958772, 0.2720012388059071, 0.06329921553177492, 18.44950829233442, 60.07591765267508, 45.52726527622768, 39.76003115517752, 28.463451862335205, 29.817346572875977, 38.24376399176461, 46.4420998437064, 27.641702311379568, 0.6218539487038339, 0.06311850808560848, 0.05208645827536072, 0.03815617844728487, 0.056022965615349155, 0.07904566558344023, 0.06646361108869314, 0.03461500257253647, 0.04970831177862627, 0.017227381567603776, 0.021324214858136008, 0.042060017718800476, 0.08125247859529086, 0.0369135840529842, 0.032673951371439865, 0.023273763014003634, 0.13241999010954583, 0.03446378765095558, 0.031675487091498714, 0.06918868914778743, 0.02651555397148643, 0.03214659395494631, 0.014877969332571541, 0.04118383562724505, 0.20223382035536425, 22.207877499716624, 55.395989758627756, 41.557641301836284, 42.401628562382285, 28.825041328157695, 31.111531938825333, 45.83873912266323, 49.47670125961304, 53.210326194763184, 16.14304334776742, 0.05329063401690551, 0.3243859607194151, 27.715280260358536, 7.360185078212193, 4.503715063844409, 50.59075110299246, 48.35314628056118, 48.4057754107884, 45.200946603502544, 49.08419057301113, 47.9501542363848, 49.37567445210048, 47.29077366420201, 51.23706211362566, 46.91234002794538, 46.97687142235892, 44.0317245892116, 44.673533167157856, 35.541349002293174, 33.83815445218767, 34.184525626046316, 34.4394029208592, 33.93164593832833, 34.68039771488735, 33.59763560976301, 33.67276995522635, 32.44312293188912, 34.211682660239084, 34.33504097802298, 32.814306122916086, 33.580730642591206, 33.346833433423726, 33.96276344571795, 35.442479610443115, 32.08532544544765, 34.154082093920024, 36.03119352885655, 35.10557188306536, 33.04343686785017, 33.68229940959385, 33.76805060250418, 33.25086144038609, 33.92370067323957, 33.92957190104893, 35.18654618944441, 35.91944217681885, 33.924989564078196, 36.49797698429653, 34.457423073904856, 35.05853952680315, 34.76231697627476, 34.46079642432076, 35.7959657396589, 39.95730440957205, 45.07284614018032, 47.80714988708496, 43.78679364068167, 43.03272649220058, 40.522050516945974, 38.15959351403372, 35.92018910816738, 38.05622516359602, 45.099176338740754, 51.89406292779105, 46.42474671772548, 45.50121995380947, 49.57304845537458, 50.08882713317871, 45.62609297888619, 46.92399215698242, 47.784196513039724, 48.22312116622925, 47.04762145451137, 48.92639698301043, 44.07102360044207, 35.830258573804585, 34.85789292199271, 36.39977809361049, 35.86563532693045, 36.73762035369873, 34.564824853624614, 36.541920866285054, 36.12091909136091, 35.058431829724995, 35.92366668156215, 36.98171404429844, 36.54699999945504, 35.76404224123274, 35.705309118543354, 35.036478996276855, 35.68292897088187, 34.487022399902344, 34.51769174848284, 35.59180334636143, 35.07234559740339, 35.01729849406651, 35.02317667007446, 35.40953820092337, 34.99000597000122, 34.57028613771711, 35.30869204657418, 36.17987108230591, 36.808196680886404, 39.96184158325195, 40.00643859590803, 41.910123416355674, 45.319225788116455, 50.231720311301096, 44.995933055877686, 44.10107108524868, 45.39028154100691, 48.40283284868513, 45.736614499773296, 43.986133984157014, 42.96418946129935, 44.02594716208321, 47.760735920497346, 50.926762512751985, 52.41197122846331, 48.939480440957205, 47.36970520019531, 48.08807945251465, 51.81766401018415, 52.32620961325509, 51.11822707312447, 39.64180408205305, 14.952290603092738, 1.8520820694310325, 1.7409761399030685, 1.6483350481305803, 0.38266555060233387, 0.03737624994079981, 19.212635891778127, 63.379084314618794, 50.549944332667756, 45.7413010597229, 28.676744188581193, 35.348074436187744, 42.05754334586007, 53.49558796201433, 34.882475648607524, 1.0175739973783493, 0.12703438981303147, 0.08276717910276991, 0.01787960808724165, 0.028434659653742398, 0.024774631585127542, 0.03090029475944383, 0.028101719483467083, 0.014918929098972251, 0.012134261246371483, 0.01646026549860835, 0.1871057871196951, 0.19127908961049148, 0.1458750002618347, 0.17951078180755886, 0.12346252719206469, 0.24900924254740986, 0.10239180962422065, 0.1761762300240142, 0.15570123227579252, 0.13695197978190013, 0.2579828681690352, 0.08510199096053839, 0.12761087316487515, 0.19089199895305292, 25.07227063179016, 63.96926430293492, 48.37540136064802, 48.621992928641184, 37.30173764910017, 37.56446293422154, 50.257727418627056, 53.742648533412385, 57.90416785648891, 19.11348683493478, 0.18650688497083528, 3.066801756620407, 28.771807704653057, 7.402811408042908, 4.861116937228611, 51.64989628110613, 51.68231657573155, 50.36071709224156, 47.680275780814036, 52.02160406112671, 50.83049522127424, 49.42828968593052, 50.09546266283308, 53.04880142211914, 49.024040017809185, 49.609391008104595, 45.54868309838431, 46.20207779748099, 37.35686118262154, 36.50514752524239, 35.29701559884207, 35.688834939684185, 35.70764371326992, 35.62549863542829, 35.56993736539568, 35.09083127975464, 34.515433583940776, 36.23976802825928, 36.289148875645225, 34.014437198638916, 33.41377932684762, 34.42340121950422, 36.59440755844116, 37.92681496483939, 34.22518648420061, 37.381593295506065, 38.565364837646484, 36.451187814985005, 35.296685559409006, 36.68372317722866, 36.57068988255092, 34.45650938579014, 36.25529030391148, 37.033571924482075, 36.98762001310076, 37.85498448780605, 35.82821927751814, 37.7388071332659, 36.408789907182964, 37.39897074018206, 36.61824682780674, 36.70895903451102, 37.87543303625924, 41.96081747327532, 47.567183426448274, 46.77390759331839, 46.179986000061035, 45.23419025966099, 41.55760656084333, 39.85022224698748, 37.66167518070766, 39.61539050510952, 46.71968732561384, 52.63945525033133, 47.9861285345895, 47.56229884283883, 48.76149538585118, 50.64072602135794, 47.60107673917498, 48.875963483537944, 50.6789584841047, 49.41538340704781, 50.68603869846889, 50.90351384026663, 44.4705102784293, 37.209892886025564, 35.50225496292114, 38.66220188140869, 37.78567968096052, 38.28836795261928, 37.29606097085135, 37.66512496130807, 38.3149413381304, 37.21728924342564, 37.847261565072195, 38.94861010142735, 38.38897786821638, 36.88592617852347, 37.16382285526821, 35.24928147452218, 38.1371682030814, 35.813416140420095, 37.01758064542498, 36.98447942733765, 38.53261797768729, 37.76523808070591, 36.31344672611782, 36.94102539334978, 37.54101276397705, 37.16285705566406, 37.418682779584614, 36.07397706168038, 39.6158629826137, 41.14743702752249, 43.711266721997944, 45.77008049828665, 46.680551597050254, 52.29930966241019, 46.51861688068935, 47.43730422428676, 47.073176928928916, 50.463025842394146, 47.29588059016636, 46.195171288081575, 45.46680552618844, 46.26798146111624, 50.91523197719029, 55.3169401032584, 53.04989923749651, 53.045838015420095, 49.74913665226528, 50.76805523463658, 55.06122555051531, 53.771111828940256, 52.00257989338466, 40.334390095302034, 16.709024497440883, 3.374589366572244, 5.039256589753287, 3.2166887308870042, 0.9191884824207851, 0.10862376022019557, 22.63882040977478, 69.1685596193586, 55.273534706660676, 52.50965942655291, 42.79760987418038, 44.138490608760286, 49.91373947688511, 60.528245380946565, 43.8879976272583, 1.2780715163264955, 0.3014857566782406, 0.17140437822256768, 0.13259530998766422, 0.2370111420750618, 0.16622696604047502, 0.11826896587652819, 0.09977106989494391, 0.09399322886019945, 0.09624954100166049, 0.10165787900664977], [0.07943539574210133, 0.027898934204131365, 0.0465425896857466, 0.05457873436223183, 0.06217693218163081, 0.057910453262073655, 0.03970195925129311, 0.0357798504244004, 0.03690603195822664, 0.026075754713799273, 0.07674707392496721, 0.0718987173001681, 0.06276786832937173, 0.05184542228068624, 11.03178083896637, 47.93557691574097, 39.187975542885916, 41.31059462683541, 32.29214552470616, 31.818417344774517, 34.520655155181885, 45.74628291811262, 48.38965559005737, 22.047638143811906, 0.023429055931046605, 0.19888868342552865, 19.823849814278738, 6.249865983213697, 2.0606433238301958, 41.68696117401123, 49.68029390062605, 48.09713642937796, 46.5138886315482, 50.166820662362234, 47.76547111783709, 46.10694653647286, 45.06729800360543, 46.75604030064174, 42.83827073233468, 43.287034034729004, 36.79212897164481, 33.341559750693186, 32.06932026999337, 34.292247022901265, 30.673691204616002, 32.071779932294575, 30.994545119149343, 30.808229173932755, 31.303788593837194, 31.687961442129954, 31.60665362221854, 31.58996057510376, 31.805594444274902, 33.12450844900948, 33.08403171811785, 32.88705723626273, 32.9113655090332, 33.68051372255598, 31.459504672459193, 33.21493577957153, 33.17069659914289, 33.2397130557469, 33.59436648232596, 33.343050139290945, 32.98888308661324, 33.87247855322701, 31.98378794533866, 34.33078520638602, 34.59774194444929, 34.03278044291905, 35.43027509961809, 34.252826418195454, 33.17159291676113, 33.89501503535679, 32.86580269677298, 32.581729071480886, 34.882169927869526, 40.98832675388881, 42.13538748877389, 36.42725474493844, 41.10409416471209, 42.830405371529714, 37.14863756724766, 35.234360218048096, 33.34608997617449, 35.874709674290244, 43.8926112311227, 49.14430986131941, 45.72880472455706, 42.999910150255474, 46.328746931893484, 46.07901477813721, 43.27309594835554, 45.185222830091206, 46.61508914402553, 47.79239886147635, 47.8450140953064, 46.044961656842915, 41.08365256445748, 31.737585476466588, 32.940975257328574, 35.15824270248413, 34.789727619716096, 34.84084204265049, 34.27847916739327, 34.902476038251606, 34.46806424004691, 33.43595450265067, 33.45128222874233, 34.10381882531302, 34.86820752280099, 34.20620400565011, 34.17937353679112, 33.90299504143851, 32.79534796306065, 33.79727125167847, 32.34331553322928, 33.29251936503819, 32.274684701647075, 32.26615578787667, 32.261948653629844, 32.708443369184224, 32.85419225692749, 32.00462906701224, 30.942979063306534, 33.070309025900706, 34.83998046602522, 39.17235599245344, 41.145724296569824, 43.242520400456016, 43.835830552237375, 39.100136416299, 42.62113952636719, 46.88167415346418, 46.200427600315635, 47.43938173566546, 46.01925679615566, 38.24421215057373, 40.23581600189209, 42.858788762773784, 47.50343370437622, 43.92303391865322, 50.01417916161673, 51.15575776781355, 48.612526008060996, 47.5590957232884, 49.06416933877127, 49.82857540675572, 48.49724497113909, 36.46719299043928, 12.00419773374285, 1.1707483381032944, 2.234749981335231, 0.7626023590564728, 0.1878862516688449, 0.14265845928873333, 20.494522946221487, 58.53195149557931, 42.229928152901785, 45.245025975363596, 22.79379997934614, 30.674271379198345, 39.88181223188128, 46.525797843933105, 14.070348807743617, 0.14928645720439299, 0.04792170532579933, 0.013191358585442816, 0.05023747070559433, 0.05524276230218155, 0.02303629950620234, 0.020967184998361126, 0.030509088787117174, 0.026833644402878623, 0.024177724329222525, 0.028711445962211916, 0.031063475646078587, 0.021700828934886625, 0.045908016950956414, 0.07016109768301249, 0.07375969458371401, 0.03821844760594623, 0.018161820979522805, 0.016544648113527467, 0.027242663615782346, 0.0074600387597456574, 0.06405447250498192, 0.01922879694029689, 0.0910332826897502, 0.0372229349533362, 13.739611949239459, 53.3584166254316, 42.74076318740845, 46.692106451307026, 33.21647827965872, 32.640802655901226, 42.00366006578718, 48.013198716299875, 52.58332770211356, 22.92861761365618, 0.03263044709871922, 0.06378551479429007, 22.489686012268066, 7.962317705154419, 2.757099700825555, 46.21910088402884, 50.86654247556414, 50.52532339096069, 48.50452668326241, 52.282859802246094, 50.12921701158796, 48.91208369391305, 45.81889854158674, 48.02864803586687, 44.43220138549805, 45.371841021946494, 39.363928249904085, 36.448005540030344, 33.37435872214181, 35.581433159964426, 32.82939413615635, 34.62949521200997, 32.67823607581002, 32.99242319379534, 32.60456780024937, 33.804566860198975, 34.05960396357945, 34.16717944826399, 33.12775673185076, 34.597505705697195, 34.15590252195086, 33.914080892290386, 35.6038167817252, 35.72450351715088, 33.53620311192104, 34.850830078125, 33.718079158238, 35.52874149594988, 34.82516343252999, 34.401451860155376, 34.39347880227225, 35.42707198006766, 33.59489107131958, 34.512807164873394, 34.914034366607666, 35.50635092599051, 35.72436802727835, 34.875916549137656, 34.456453800201416, 35.542978354862754, 34.30672012056623, 35.10701363427298, 36.55864518029349, 42.28482239586966, 46.354062693459646, 41.84441082818167, 43.73295552389962, 43.39448792593819, 40.493778296879356, 38.467384815216064, 35.24624163763863, 37.743722983769004, 46.078094141823904, 50.49058934620449, 46.11176858629499, 44.220468929835725, 50.26342494147164, 47.943233830588206, 45.25383629117693, 46.933188097817556, 48.32488795689174, 48.281215054648264, 49.27917092187064, 48.496796812329976, 42.18006787981306, 35.134295736040386, 34.785749776022776, 36.59741265433175, 36.40687567847115, 36.64471251623971, 35.017208167484824, 34.71768869672503, 36.02358177730015, 35.51721790858677, 35.00422198431832, 35.94827720097133, 34.99001291819981, 35.57948419025966, 37.00123848233904, 35.42399740219116, 35.23922743116106, 34.75895752225603, 33.97950165612357, 35.374126706804546, 32.94563055038452, 35.07023681913103, 33.256190708705354, 34.30019576208932, 34.14612640653338, 34.27480009623936, 33.19873258045742, 35.847973006112234, 36.50893081937517, 41.45576333999634, 43.93176085608346, 45.84663575036185, 44.679463454655235, 42.44645833969116, 43.93946988242013, 48.50486019679478, 48.2145540373666, 48.57153163637434, 47.75953388214111, 41.64063058580671, 42.58540494101388, 44.3948061806815, 49.86113813945225, 46.39563029153006, 52.31494658333914, 52.828672068459646, 50.32174464634487, 50.16758843830654, 52.114418097904746, 52.43469531195504, 49.79845496586391, 38.398628916059224, 11.848466890198843, 1.8542783515793937, 2.85719610112054, 1.469278450523104, 0.07032594098044292, 0.11092121193983726, 22.076763255255564, 62.49679510934012, 47.61701590674264, 49.92342526572091, 30.037024293627056, 34.32843671526228, 44.646709646497456, 53.967599936894004, 21.56671510423933, 0.12559847400656768, 0.027770243252494504, 0.03658037246870143, 0.05203733912536076, 0.032786907095994265, 0.013107822442959462, 0.014934124890714884, 0.048357701394706964, 0.042821507036153755, 0.05374803786565151, 0.035657232361180444, 0.1647824735513755, 0.12230144520955426, 0.128963831279959, 0.17408816064042704, 0.19215674751571246, 0.09696411301514932, 0.08535507773714406, 0.1042621439056737, 0.15321083233824798, 0.08278985574309315, 0.2085118027670043, 0.17335678131452628, 0.13293854014149734, 0.09793582265930516, 15.569386175700597, 61.45095920562744, 50.60944523130144, 50.72167600904192, 41.76569121224539, 42.183896337236675, 44.62598317010062, 52.665073258536204, 58.49812766483852, 27.18481135368347, 0.0975367897855384, 1.7050187779324395, 29.19109501157488, 10.367551292691912, 3.2015787873949324, 47.59807859148298, 52.23285709108625, 54.03879117965698, 51.431559562683105, 54.51000411169869, 50.95727552686419, 50.9798641204834, 48.855014664786204, 51.71866260256086, 46.48472009386335, 47.30432265145438, 40.568228244781494, 38.450559752328054, 35.245953287397114, 38.49459743499756, 34.52361856188093, 36.43679462160383, 33.09325197764805, 33.76106766292027, 34.83568300519671, 36.00542960848127, 35.140066214970176, 35.24323654174805, 34.21030691691807, 36.7630820274353, 36.56917517525809, 35.50544418607439, 36.36163248334612, 37.71326902934483, 35.86730636869158, 36.94580922807966, 37.175860609327046, 36.56030579975673, 36.13399560110909, 36.68707915714809, 36.555838108062744, 37.2425320489066, 36.50494255338396, 37.340984548841206, 38.122969559260774, 37.7977625983102, 38.09034776687622, 38.35179458345686, 35.86500651495797, 36.38030229296003, 35.817661489759175, 36.281870637621196, 39.71436064583914, 45.280764034816194, 46.916095529283794, 41.05348348617554, 45.90434748785836, 46.70682273592268, 43.304081439971924, 39.88714497429984, 36.406552587236675, 39.865723678043906, 47.936261313302175, 51.513409342084614, 47.947083132607595, 46.13391596930367, 50.58009256635393, 49.307245118277415, 46.488579818180625, 46.40391601834978, 49.73914514269148, 51.1785443850926, 51.87332950319563, 49.81327894755772, 44.80297810690743, 36.76265818732125, 36.44494138445173, 39.75627565383911, 38.827551637377056, 38.45852933611189, 37.02687038694109, 38.57098593030657, 37.611856596810476, 36.87793575014387, 35.94635949816023, 37.71645825249808, 37.56922592435564, 37.09927756445748, 38.405952317374094, 39.28572974886213, 37.422455651419504, 36.21160697937012, 35.085793835776194, 37.44239003317696, 35.38519171306065, 37.07991640908377, 36.146123681749614, 36.229561124529155, 35.95677832194737, 36.33822052819388, 34.869597162519185, 37.377632822309224, 38.45779630116054, 44.34804827826363, 46.56512812205723, 46.75882305417742, 46.71091175079346, 42.84701156616211, 47.832271099090576, 51.085660866328645, 49.164442266736714, 50.432662214551655, 49.901316097804475, 42.53776114327567, 43.855389731270925, 46.17845392227173, 52.23059892654419, 47.29703746523176, 54.206763880593435, 54.97870179585048, 52.846994468144004, 51.74357884270804, 54.124493735177175, 55.4129433631897, 51.66187844957624, 40.331614289964946, 13.844340409551348, 2.981714550937925, 7.072641261986323, 4.1659687757492065, 0.23850926597203526, 0.25155461739216534, 24.240220376423427, 68.21487072535923, 53.0264699118478, 58.326771191188264, 35.56945446559361, 42.75138003485543, 52.293827533721924, 62.81663458687918, 29.244978291647776, 0.5049297170979636, 0.16800825617143086, 0.09490878973156214, 0.1870901808142662, 0.1412767991423607, 0.12040162858154092, 0.11396499111184052, 0.15157833136618137, 0.12038721649774484, 0.11950160616210528, 0.142883746485625], [0.08829152623989753, 0.05153622744338853, 0.06275089816855532, 0.025994042134178535, 0.03525056257577879, 0.019564269742529308, 0.04240119530420218, 0.004188145868413682, 0.07640421018004417, 0.04181864584929176, 0.02951019024476409, 0.022468699874090295, 0.10442312633884804, 0.06137016761515822, 5.242560011999948, 47.27749913079398, 40.069865226745605, 40.53434188025338, 24.57697524343218, 23.221430335726055, 31.12597724369594, 39.96590975352696, 48.2926378931318, 26.130213771547588, 0.2681046021836144, 0.2590444226350103, 11.515849675451006, 5.5761999147278924, 0.7299893062029565, 24.625633478164673, 46.619410923549104, 49.95173570087978, 48.69025550569807, 47.94867427008492, 46.38816792624337, 43.52140372140067, 40.773071561540874, 38.92944696971348, 34.834154401506694, 33.400470052446636, 31.33416611807687, 33.21970919200352, 30.523043836866105, 33.226796354566304, 31.268832206726074, 32.12154293060303, 30.792310850960867, 32.462362493787495, 33.174306188310894, 32.55272381646292, 32.598859855106895, 33.135900020599365, 32.15862199238369, 32.70810638155256, 32.9573278427124, 32.2745874268668, 33.71932635988508, 32.36018923350743, 32.59355837958199, 33.02818557194301, 32.373984881809776, 32.95362097876412, 32.465551716940745, 31.606243678501674, 32.31135729381016, 33.16255678449358, 31.647971085139684, 34.21807847704206, 35.006705965314595, 33.29576069968087, 34.48585162843977, 34.02334826333182, 31.500669275011333, 32.72097097124372, 33.509751319885254, 33.908550126211985, 35.22581393378121, 41.8635287966047, 40.52083110809326, 35.649501187460764, 44.60581602369036, 43.039803232465474, 38.39293834141323, 35.175060817173545, 33.94615725108555, 35.43777220589774, 43.2600541796003, 50.28156321389334, 46.10763440813337, 42.72153752190726, 44.58253608431135, 46.82872193200247, 45.64187928608486, 43.063350677490234, 45.8439085824149, 45.77967596054077, 46.70538445881435, 45.59633731842041, 39.3749863079616, 33.200264658246724, 32.226603167397634, 33.05243478502546, 33.82639810017177, 35.130832059042795, 33.305345739637104, 35.086565085819785, 35.059741565159385, 33.54474244798933, 34.404752254486084, 33.770840304238455, 33.984132630484446, 34.441299779074534, 33.43200445175171, 33.29987055914742, 34.61362900052752, 34.93143960407802, 33.670494420187815, 32.86981528145926, 32.29661669049944, 32.68035875047956, 30.666020393371582, 32.15142713274275, 33.097688402448384, 32.76866340637207, 32.33149664742606, 32.11943762642996, 36.57291330610003, 40.7851232119969, 41.06235980987549, 39.59908308301653, 38.52949823651995, 44.38177830832345, 45.990334919520784, 46.34563452856881, 45.7726582799639, 45.79125165939331, 46.92422839573452, 41.20576368059431, 38.411722796303884, 45.65272889818464, 47.95611579077584, 48.6322797366551, 36.56383548464094, 44.29712493079049, 51.05173976080758, 48.638216972351074, 52.422935485839844, 48.215332235608784, 47.66985695702689, 36.868729387010845, 9.162528685161046, 0.873011188847678, 1.1590000199420112, 1.243888333439827, 0.15089598298072815, 0.07258797317211117, 20.97284041132246, 56.87178366524832, 42.1815756389073, 35.25424248831612, 24.99459845679147, 38.049669538225444, 49.38134070805141, 47.427667072841096, 16.710483619144984, 0.0724249483485307, 0.039506968642984114, 0.020522003261638538, 0.011741238496532398, 0.023634431517816017, 0.05461491724210126, 0.09647552030427115, 0.04022081123132791, 0.027087060268968344, 0.01595575944520533, 0.027962122777742997, 0.034391289576888084, 0.038629816246352026, 0.059079073768641265, 0.032174461388162205, 0.06216285257999386, 0.0302206096239388, 0.025205977992819886, 0.028441375454089472, 0.063682832089918, 0.03902378046352949, 0.09064995790166513, 0.04516269712309752, 0.06643977415348802, 0.037311005406081676, 7.210599482059479, 53.97310291017805, 46.1242162840707, 45.395947796957834, 29.58503702708653, 27.030465807233536, 35.497703892844065, 46.093050139290945, 52.52338906696865, 27.979956252234324, 0.20983691380492278, 0.20877241449696676, 15.075996330806188, 6.9075950554439, 1.0917426518031528, 27.14041931288583, 47.1857898575919, 51.80569921221052, 49.01132481438773, 49.626514843532014, 48.01967443738665, 46.19805826459612, 42.912512234279085, 41.64642538343157, 37.36964586802891, 36.294790812901084, 34.81279911313738, 34.528972148895264, 33.96199219567435, 34.045898641858784, 33.8529680115836, 34.09374393735613, 31.790089539119176, 35.24878815242222, 34.157316480364116, 34.244137695857454, 32.86980833326067, 34.0746294430324, 33.05865689686367, 33.78830460139683, 34.17607661655971, 34.13429709843227, 34.41557059969221, 33.79569401059832, 33.47364500590733, 33.70757000786917, 34.5082665170942, 34.74727760042463, 33.908008166721885, 34.22348764964512, 33.74529177801949, 34.58044787815639, 35.00210278374808, 35.261593682425364, 35.577726296016145, 34.88452189309256, 36.47882080078125, 35.285585812159944, 34.940145696912495, 35.4334261076791, 35.01574557168143, 35.755558490753174, 36.8381017276219, 42.10028518949236, 44.5060190473284, 41.359315395355225, 44.7780305998666, 42.93418019158499, 40.927957330431255, 37.44278955459595, 36.659494808741975, 37.25569541113717, 46.430260113307405, 51.7918757711138, 48.18375267301287, 42.451005935668945, 46.77124990735735, 49.8029191834586, 46.42808880124773, 47.200165680476594, 46.669132232666016, 46.57347638266427, 46.902661187308176, 46.21596377236502, 41.251628739493235, 34.9619699886867, 34.47252498354231, 35.463317258017405, 34.75295775277274, 38.31475026266915, 34.69846303122384, 36.3711793082101, 36.50340352739607, 34.92227145603725, 36.11687871388027, 34.532265595027376, 35.195460728236604, 36.08021306991577, 35.88121666227068, 35.177301611219136, 36.47319623402187, 35.42317404065813, 35.60338946751186, 33.85959311894008, 34.29093381336757, 34.35376289912632, 33.467777252197266, 34.79659243992397, 34.75551468985421, 35.08116980961391, 33.77231332233974, 33.89018256323678, 38.932142870766775, 42.390740735190256, 42.835567883082796, 40.74889530454363, 40.02858597891671, 45.82343918936593, 47.79073824201311, 47.7710713659014, 48.00861985342843, 48.29468413761684, 48.29382256099156, 44.35864428111485, 40.37919207981655, 47.63361862727574, 49.8557185445513, 49.235393796648296, 38.53648465020316, 46.530084882463726, 54.3579740524292, 50.96230254854475, 53.77421072551182, 49.8442679132734, 48.88657685688564, 38.39897632598877, 10.391876935958862, 1.594049858195441, 2.074728625161307, 1.5222811549901962, 0.22360738845808165, 0.14637957247240202, 22.555792910712107, 62.702614648001536, 46.76393345424107, 43.40717533656529, 28.672372034617833, 41.399851185934885, 55.45143985748291, 55.87466505595616, 21.357954740524292, 0.0360952776058444, 0.0276717216641243, 0.04626147602019565, 0.008342862012796104, 0.020144142376791154, 0.037731493557138104, 0.05874815224004643, 0.017464999442121813, 0.040360681047397, 0.05427067946376545, 0.025347486470959017, 0.1336508390626737, 0.07609711201595408, 0.16567733910466942, 0.08859802050782101, 0.14215151220560074, 0.09325475884335381, 0.08775343439940896, 0.09416735451668501, 0.18875533289143018, 0.10789668280631304, 0.12107226545257227, 0.13835976352649076, 0.20992318274719374, 0.13285680381315096, 7.773187739508493, 60.71418612343924, 52.78097268513271, 50.34121002469744, 33.53942360196795, 32.94859395708357, 42.01298107419695, 49.993216446467805, 57.57493094035557, 32.17824717930385, 0.4296175683183329, 0.7772316826241357, 19.967071294784546, 10.93134810243334, 1.2269388543707984, 28.758866684777395, 49.37670278549194, 53.30089943749564, 49.68406677246094, 50.6509051322937, 50.58404609135219, 47.66844299861363, 45.76037386485508, 44.82886014665876, 37.51080199650356, 37.216854981013704, 36.589185987200054, 37.066249302455354, 34.084853717258994, 35.991814613342285, 34.10422529493059, 36.28201654979161, 34.671253885541645, 37.57573291233608, 36.45793104171753, 36.26336758477347, 35.43852261134556, 36.803850582667756, 35.602534839085166, 35.596343994140625, 36.29206364495413, 34.78259529386248, 36.90244552067348, 36.77328545706612, 35.73792743682861, 36.155764307294575, 37.07337468011038, 35.60690525599888, 35.66172306878226, 34.95611265727452, 36.28625842503139, 36.15317610331944, 35.95531572614397, 37.330134936741416, 38.58496223177229, 36.166586126599995, 38.860034465789795, 38.029742104666575, 34.7504494530814, 36.85993296759469, 36.197755745479036, 37.54719318662371, 39.45827089037214, 44.02735069819859, 46.79705899102347, 40.436281953539165, 48.46598849977766, 46.04680987766811, 40.83378144672939, 40.78939635413033, 38.39825371333531, 38.74764040538243, 48.86551686695644, 54.07970217296055, 49.52516147068569, 43.30833373750959, 47.58247641154698, 51.18395355769566, 50.35364382607596, 46.90787581035069, 48.12565531049456, 48.36340182168143, 50.1210389818464, 48.272595814296174, 44.08324548176357, 35.769031047821045, 35.54593481336321, 36.985233306884766, 37.05985695975167, 40.62472404752459, 36.74728182383946, 37.884462220328196, 38.10369178227016, 36.13664633887154, 39.09984459195818, 37.00370509283883, 37.162395000457764, 38.53786039352417, 36.80634846006121, 37.75458649226597, 38.48767702920096, 38.11278697422573, 38.20569133758545, 36.238805702754426, 36.05419554029192, 36.70862552097866, 35.137450218200684, 36.20354012080601, 37.579408509390696, 36.978149618421284, 35.72543804986136, 35.861890247889924, 40.56194012505667, 44.13995667866298, 45.15529693875994, 41.82505662100655, 41.86781930923462, 48.054787158966064, 48.76110976082938, 49.806664262499126, 49.4074763570513, 49.4640451158796, 50.75707013266427, 46.128173283168245, 41.3142945425851, 51.26357991354806, 51.30099596296038, 51.62511205673218, 38.687295300619944, 47.58510977881295, 55.65613031387329, 51.424913610730854, 56.72204998561314, 50.93461397715977, 50.195110252925325, 40.42388984135219, 12.023104650633675, 1.8875869299684251, 3.960832331861768, 3.149651208094188, 0.49059824326208656, 0.23685475332396372, 26.429231234959193, 66.7747106552124, 52.65427923202515, 47.029743739536826, 38.22072376523699, 50.19074331011091, 61.17747810908726, 63.22983700888497, 29.019257375172206, 0.19175386056303978, 0.14154260845056602, 0.13407683691808156, 0.06942951479660613, 0.11332112244729485, 0.09629171195306949, 0.22490214183926582, 0.13074594922363758, 0.2748041855437415, 0.09721185293580804, 0.10159853433391877], [0.028993882771049227, 0.102024145424366, 0.10697779032800879, 0.04023507743009499, 0.06359948084822722, 0.05545045508603964, 0.05342726043558546, 0.014305675934467996, 0.03350721612306578, 0.05947771309209721, 0.01740314588615937, 0.026752773206681013, 0.044186587179345746, 0.04354514767016683, 2.154662004538945, 32.90774897166661, 43.04582037244524, 43.929051058632986, 35.104470593588694, 30.020584855760845, 31.634178910936626, 38.14510999407087, 49.114036560058594, 32.18816920689174, 1.298949550305094, 0.12683282420039177, 3.4129123730318884, 3.4559599374021803, 0.1236181559839419, 10.22647419997624, 35.097894123622346, 45.429726464407786, 48.26928847176688, 48.47959654671805, 44.078301838466096, 43.16297047478812, 39.146668502262656, 36.727187633514404, 35.93735115868704, 34.688811983381, 34.49757323946272, 32.902576037815635, 32.38508462905884, 32.91514532906668, 33.02401317868914, 37.295275824410574, 37.78176089695522, 39.70634242466518, 39.40659713745117, 39.88827058247158, 39.16436903817313, 39.33618061883109, 37.17675345284598, 38.23523507799421, 34.104423318590435, 34.388733182634624, 33.19595330102103, 32.89217458452497, 32.12029572895595, 33.54947417122977, 33.523995126996724, 34.11477613449097, 32.84100110190255, 32.790661403111045, 31.804746764046804, 33.247352600097656, 33.68790660585676, 35.47600466864449, 34.17808812005179, 34.33656958171299, 33.96844359806606, 35.52198437282017, 34.41591453552246, 32.62600646700178, 33.24957602364676, 33.72468342099871, 35.35350792748587, 42.45628309249878, 40.23832777568272, 34.80556256430489, 43.639147894723074, 41.54009015219552, 39.27288947786604, 35.33216306141445, 34.75481292179653, 36.58867876870291, 45.28470713751656, 50.14918960843767, 45.3855984551566, 42.78476960318429, 43.322157178606304, 47.00438281467983, 44.46635525567191, 43.92146709987095, 46.86511312212263, 46.42544501168387, 46.24227312632969, 45.415482657296316, 35.190933976854595, 33.02491297040667, 32.425821917397634, 33.90199450084141, 33.02249499729702, 34.17687218529837, 35.71036393301827, 35.243483202798025, 34.00672122410366, 34.08935267584664, 32.86369391850063, 33.97107001713344, 34.2422582081386, 32.62446744101388, 34.76199388504028, 33.20908539635794, 32.951696327754426, 34.37079988207136, 34.98338433674404, 33.908557074410574, 33.82341384887695, 33.932997362954275, 32.90477166857038, 31.77181577682495, 31.782943316868373, 32.20284380231585, 32.4170046533857, 33.46466793332781, 35.63068199157715, 40.971460001809255, 38.903894969395225, 41.828436919621055, 46.48277112415859, 44.1712965284075, 45.37408529009138, 44.16542182649885, 44.47887243543352, 45.516360078539165, 45.78535958698818, 42.800667081560405, 37.92868403026036, 41.644191537584575, 47.915517466408865, 50.84529141017369, 50.359918049403596, 36.86631488800049, 46.667117255074636, 50.1556271144322, 47.43875639779227, 48.81808498927525, 47.90118333271572, 36.79488393238613, 7.213965450014387, 0.4847086678658213, 2.2425693103245328, 1.250046283006668, 0.22442585096827575, 0.170685809637819, 22.639855691364833, 58.24997622626168, 38.4751945904323, 39.25141954421997, 25.96733410017831, 40.89864635467529, 47.369757311684744, 44.67454760415213, 15.31949942452567, 0.08951921321983848, 0.06275590575699296, 0.04326693134914551, 0.026873772963881493, 0.0920649476881538, 0.03449690015986562, 0.10482830673988376, 0.02891680458560586, 0.037563518820596595, 0.07656103997890439, 0.03392291381689055, 0.027933558149795448, 0.02499319110730929, 0.020645910541393926, 0.03198155727503555, 0.02034694970851498, 0.03401186636516026, 0.06920708423214299, 0.030026887876114676, 0.09984817182911293, 0.03440585093838828, 0.006726845200838787, 0.0982271855963128, 0.02147033398172685, 0.03288681459214006, 2.625572907073157, 40.99787357875279, 51.31879724775042, 49.9493350982666, 35.50914062772478, 32.54642874853951, 37.039179120744976, 41.994669096810476, 53.35177762167794, 35.15991374424526, 1.1547574933086122, 0.12749818206897803, 4.732544430664607, 6.629273235797882, 0.3650606609880924, 13.393484830856323, 37.256643840244834, 46.64552225385393, 49.181402819497244, 50.16773087637765, 46.60877670560564, 45.39590610776629, 40.69397326878139, 37.836123602730886, 36.71336766651699, 36.8012033190046, 34.84916251046317, 33.735178674970356, 33.256697927202495, 33.849535601479666, 34.90509898321969, 38.22646297727312, 38.10302822930472, 39.344643524714876, 40.60220840999058, 40.931980337415425, 40.18975291933332, 41.47067417417254, 38.67847456250872, 38.78699152810233, 35.35445983069283, 34.47105891363961, 34.402282169886995, 35.09360013689314, 34.63591534750802, 34.86225986480713, 36.097924028124126, 35.99446882520403, 35.43063988004412, 34.514259338378906, 33.233063629695344, 35.35171529224941, 35.63134901864188, 37.36156163896833, 34.812125137874055, 35.14555876595633, 36.05888557434082, 35.92447962079729, 35.79513542992728, 33.35050903047834, 33.42760624204363, 34.8889513696943, 36.75565440314156, 44.556153774261475, 42.864399433135986, 37.76766300201416, 45.77241161891392, 43.78252049854824, 41.54345308031355, 37.23149136134556, 36.89226640973772, 38.55424771990095, 46.614960602351594, 50.32864768164498, 47.23445504052298, 44.713843141283306, 46.70821237564087, 48.85873889923096, 45.36633457456316, 46.40687247685024, 47.46321753093174, 48.42731830051967, 45.84574638094221, 46.431677545819966, 37.737431389944895, 35.122744355882915, 34.44467312949044, 35.76092944826399, 34.802435874938965, 36.20650700160435, 36.19191231046404, 36.40972096579415, 35.67202377319336, 35.18074096952166, 35.55813237598964, 35.26266370500837, 35.46573175702776, 34.3537038394383, 35.90997525623867, 35.24017933436802, 35.3123641695295, 36.059358051845, 36.29586778368269, 35.895523003169465, 33.78761672973633, 36.49178613935198, 33.42245415278843, 33.23375844955444, 34.00888558796474, 33.79867478779384, 33.912468910217285, 34.746464661189485, 38.05142395836966, 40.88760566711426, 41.22431537083217, 43.222325461251394, 48.746761730739046, 45.53016267504011, 47.23408331189837, 45.58287518365042, 47.31306348528181, 48.075847148895264, 48.254742418016704, 44.559780733925955, 40.485555103846956, 44.1193448475429, 51.45241458075387, 52.41711636951992, 49.72534254619053, 37.23281499317714, 46.96340928758894, 50.78138535363333, 50.758081095559255, 47.77323920386178, 50.74850647790091, 38.04673045022147, 8.585414784295217, 0.9008253706353051, 2.8327734002045224, 3.0174751920359473, 0.2905291531767164, 0.10267865351800408, 25.16570132119315, 63.35032572065081, 43.853527614048545, 42.375242778233115, 34.42846645627703, 47.02550881249564, 50.873365606580464, 52.52560554231916, 18.906472206115723, 0.05555957708773868, 0.09391667653939553, 0.06155003367790154, 0.04988730592387063, 0.0079669179893764, 0.025835968919896653, 0.04833865152405841, 0.05328039153079901, 0.055344145611992905, 0.039424886261778216, 0.041361923928239515, 0.1031678161982979, 0.18149199549640926, 0.1758403687604836, 0.14654601711247647, 0.23121707726802143, 0.09911412586058889, 0.1726940968739135, 0.07552049974245684, 0.19772476516664028, 0.15085495875350066, 0.09271434641310147, 0.17531093502683298, 0.23013228976300784, 0.08545550770525422, 3.388421275785991, 46.5009754044669, 56.82378898348127, 55.14175864628383, 44.00463356290545, 39.813525336129324, 42.7849884714399, 48.92743573869978, 57.72295536313738, 40.26710721424648, 1.6381614740405763, 0.3533899943743433, 6.976198962756565, 10.600180455616542, 0.7458484609212194, 13.015181473323278, 38.247825213841026, 47.64790064947945, 51.54857070105416, 54.25217383248465, 49.14336838041033, 48.73267425809588, 43.227317741939, 40.05538865498134, 39.23842641285488, 38.1829047203064, 37.78767033985683, 36.79115274974278, 36.25061069216047, 36.05127034868513, 37.47830179759434, 42.289578437805176, 40.7942670413426, 43.42243358067104, 42.576837812151226, 44.17613247462681, 41.26895407267979, 44.512195995875764, 40.6327804837908, 42.07559476579939, 38.23557901382446, 36.4314340863909, 36.341031074523926, 37.7649427822658, 35.70383957454136, 37.24996314729963, 37.7961471421378, 38.92008079801287, 37.34832532065255, 35.863022804260254, 34.5653737613133, 36.41785035814558, 37.43673072542463, 39.38376535688128, 36.588810784476145, 37.71893875939505, 39.1680064201355, 39.025012493133545, 38.46065548488072, 34.29670429229736, 35.398163999829976, 36.52130208696638, 38.94512210573469, 47.72090537207467, 44.43766614368984, 38.054925850459504, 46.95256314958845, 46.178349699292866, 43.247186115809846, 39.355121408190044, 39.00999048777989, 40.049541745867046, 49.88871553965977, 52.18142652511597, 48.041050570351736, 46.59270552226475, 47.801681654793875, 49.44272109440395, 48.18916531971523, 47.06710072926113, 49.74422080176217, 49.49661479677473, 47.65809713091169, 48.81673009055001, 37.57559742246355, 36.1456755229405, 35.591653960091726, 37.810415267944336, 36.67727524893624, 37.507470335279194, 39.78972775595528, 38.830098152160645, 38.04763719013759, 36.360322747911724, 37.26119491032192, 37.06160790579659, 37.628782408578054, 36.360614572252544, 37.964776447841096, 37.51328250340053, 37.276130063193186, 37.53675699234009, 38.34683356966291, 38.42974294934954, 35.35562365395682, 38.90035833631243, 36.012996196746826, 36.0414525440761, 35.65159259523664, 36.21693277359009, 35.909527097429546, 37.30991220474243, 39.56276484898159, 44.082033021109446, 42.071929591042654, 45.74555683135986, 50.03981106621878, 47.81163494927542, 49.52697147641863, 47.87988362993513, 48.72670228140694, 50.185420989990234, 48.602037702287944, 47.76782308306013, 42.362242698669434, 46.34358133588518, 53.24228096008301, 54.41444901057652, 50.84370027269636, 37.69085761478969, 49.22336993898664, 51.7748943737575, 51.743207114083425, 49.984128202710835, 51.98430265699114, 41.62785979679653, 8.440773265702383, 1.9599354820592063, 6.590313817773547, 4.533636612551553, 0.540116263287408, 0.22540526198489325, 27.98375517981393, 68.70842211587089, 49.21070337295532, 50.90931906018938, 35.77953324999128, 52.07204450879778, 58.48043755122593, 59.525995526994976, 22.923578432628087, 0.23190831446221896, 0.15627690138561384, 0.1434786452778748, 0.12999415956437588, 0.17287133022078446, 0.1318323923540967, 0.18504970387688705, 0.11675214155444077, 0.13553878132786068, 0.14592563254492624, 0.13711629382201604], [0.023601412307471037, 0.10639985491122518, 0.03290290605010731, 0.02688468380698136, 0.004391385766211897, 0.025803065060504844, 0.019446796671088253, 0.007929557003080845, 0.02596643254426973, 0.11796336727482931, 0.06446844671985932, 0.02507484601145344, 0.020731163377474462, 0.060530670519386015, 0.32441497487681253, 21.99020607130868, 45.63932582310268, 36.66760335649763, 34.53379419871739, 23.504440886633738, 28.8127794946943, 41.272063391549246, 45.172031675066265, 41.397620814187185, 3.9782193303108215, 0.1925156789698771, 1.2765032861913954, 3.1621052026748657, 0.412052685128791, 2.2210687611784254, 17.990711791174753, 41.313634463718955, 48.85480621882847, 47.313772201538086, 46.58358948571341, 44.709993839263916, 43.4280685697283, 45.71690593447004, 43.65823112215315, 43.40923547744751, 40.94500820977347, 39.811527729034424, 39.974053042275564, 41.05322987692696, 44.19195352281843, 45.60304580415998, 44.44410017558506, 45.072655064719065, 46.465376308986116, 44.21310383932931, 44.03575107029506, 45.76230198996407, 44.77059950147356, 44.66403497968401, 40.92112030301775, 39.81508868081229, 37.02323995317732, 35.49575144904, 33.004561696733745, 34.185571329934255, 33.72751828602382, 33.03816665921892, 32.178782190595356, 33.10506738935198, 31.84437928880964, 33.939438343048096, 32.69658279418945, 34.821189062935964, 34.93314191273281, 34.15270635059902, 34.2402606010437, 34.379078660692485, 33.33607414790562, 34.19286346435547, 34.854752336229595, 32.17381770270211, 35.808020864214214, 43.77427993501936, 42.92606469563076, 37.03980793271746, 41.63422434670584, 43.35147162846157, 39.90345239639282, 36.64014754976545, 33.19636671883719, 35.54473624910627, 43.348390102386475, 49.554330008370535, 43.14802142551967, 43.72375610896519, 43.90678555624825, 46.98739446912493, 48.70428391865322, 45.27759565625872, 46.849597794669016, 44.866526331220356, 47.70061315808977, 44.82542773655483, 36.82368074144636, 33.62167985098702, 33.13728271211897, 33.38718857084002, 34.33881384985787, 34.72566522870745, 34.277093001774375, 34.420667103358674, 34.63887528010777, 34.938113348824636, 32.53407137734549, 33.005367687770296, 32.894036701747346, 32.542916434151785, 33.74017095565796, 32.47508117130825, 31.97904579980033, 32.186703136989046, 32.02222537994385, 33.50714227131435, 33.201105390276226, 33.007948943546836, 32.879303046635215, 31.789912360055105, 31.95814561843872, 32.01334210804531, 32.25408329282488, 31.85879680088588, 33.024377959115164, 36.84070035389492, 42.54212808609009, 42.55798734937395, 43.177408831460134, 41.96908930369786, 45.85042251859392, 45.60980640138899, 42.99654722213745, 47.264634541102815, 43.615909644535606, 44.39220755440848, 37.245901925223215, 37.14862714494978, 47.931835310799734, 47.95756449018206, 48.9889029775347, 53.45416975021362, 47.895350319998606, 49.6861686025347, 51.19991704395839, 49.9715450150626, 47.733047349112375, 31.67049367087228, 6.36369354384286, 1.023521438241005, 1.3833911163466317, 0.6149841344782284, 0.1281343222196613, 0.3427334119166647, 25.76956752368382, 57.97408757890974, 45.27629634312221, 37.477509702954976, 16.994354009628296, 29.4529378754752, 46.99478040422712, 41.205298151288716, 5.3222962362425665, 0.030287204443344047, 0.05233660699533565, 0.00909258977376989, 0.038919313212058375, 0.05632046250892537, 0.014883840356820395, 0.033002192686711035, 0.08610964260463204, 0.07726595643907785, 0.07533302730215446, 0.0763045944539564, 0.023798991526876177, 0.08860076857464654, 0.04319266229867935, 0.0180059190773006, 0.05831100605428219, 0.028311894009155885, 0.030445106327533722, 0.04062362015247345, 0.06077459707323994, 0.04351072219599571, 0.07045109676463263, 0.05199030986321824, 0.022404289937445095, 0.06825986291681017, 0.446330265807254, 27.369259970528738, 50.90140853609358, 42.977488313402446, 41.01959364754813, 33.55011340550014, 32.90281922476632, 45.093457971300396, 49.90254940305437, 45.14939096995762, 3.709788271359035, 0.27333868561046465, 1.5695835139070238, 6.212724821908133, 0.9192848886762346, 2.770152977534703, 21.63577672413417, 41.558819021497456, 51.268516608646934, 48.254058020455496, 48.60912486485073, 47.1772574697222, 45.92690828868321, 46.80020652498518, 45.64096212387085, 46.3201276915414, 41.76213026046753, 40.239859853472026, 41.0964789390564, 41.99939734595162, 45.487556321280344, 47.5188969203404, 45.81838090079171, 46.569401264190674, 48.82332740511213, 47.06964724404471, 46.01293740953718, 46.59368174416678, 46.33814089638846, 44.401636259896414, 42.306931563786094, 40.48985603877476, 38.25069481985909, 36.56757361548287, 34.27612720217024, 35.040766034807476, 34.54336534227644, 34.995335238320486, 34.13508571897234, 34.049087865012034, 34.572294167109895, 34.468449865068706, 34.53379767281668, 37.80059746333531, 36.45491552352905, 35.96872574942452, 35.67354890278408, 35.18799836294991, 35.513361658368794, 34.62354755401611, 35.181835310799734, 34.319532598767964, 37.46376616614205, 44.29940046582903, 45.09254428318569, 39.64300612040928, 41.79068388257708, 45.20697069168091, 41.82021720068795, 38.438237122126985, 36.31260599408831, 36.340207712990896, 45.01089947564261, 50.874651023319785, 45.30341168812343, 42.504375049046104, 46.93192005157471, 49.18014519555228, 49.388674531664165, 48.107944352286204, 48.684068134852815, 47.79708889552525, 48.38374614715576, 46.913045270102366, 38.608756337847026, 34.76221970149449, 34.18647459575108, 35.33882985796247, 35.12716688428606, 36.57990666798183, 35.56983661651611, 35.06543561390468, 34.83441148485456, 36.73955542700631, 35.24501528058733, 33.78850262505667, 35.141876220703125, 34.66122416087559, 35.38537236622402, 33.29352337973458, 33.836184637887136, 34.264652252197266, 34.46001475197928, 35.9718211718968, 35.1853997366769, 34.37655993870327, 34.32239178248814, 33.72414493560791, 33.800853048052105, 34.604992389678955, 32.94715220587594, 34.082995074135916, 35.35152421678816, 39.59066881452288, 44.63492202758789, 45.057674748556956, 44.95281948362078, 42.932596002306255, 45.8897944859096, 47.168301241738455, 46.01501144681658, 48.58787727355957, 45.25299208504813, 45.72741508483887, 39.37390933718, 39.6075564111982, 49.65351554325649, 49.32650205067226, 49.74545063291277, 53.23272371292114, 50.257376534598215, 50.51550906045096, 51.96291957582746, 50.69762829371861, 50.34297834123884, 35.781471797398154, 6.658559024333954, 1.2777507049696786, 1.138559722474643, 2.3438039124011993, 0.08712971822491714, 0.21549110540321895, 27.944914749690465, 63.19774327959333, 49.73969752447945, 43.4218429837908, 17.466438940593175, 35.97159188134329, 52.199391092572895, 49.61128439222063, 8.517722828047615, 0.0887166080730302, 0.057392717472144535, 0.09312159634594407, 0.014550447264420134, 0.07587035918342215, 0.03135807180245008, 0.03238788779292788, 0.06398347060063056, 0.036031213722058704, 0.048567114264837334, 0.025329573146466697, 0.08170698170683213, 0.2245858766670738, 0.12097372859716415, 0.15616973356476851, 0.16221914467002663, 0.06489975071911301, 0.0864378839199032, 0.08397628779390029, 0.1861335685742753, 0.23766660690307617, 0.17833003588020802, 0.12973305928919995, 0.11471815141183989, 0.1972055501703705, 0.5755626069647926, 33.239820752825054, 59.80099827902657, 48.08964279719761, 44.37865856715611, 34.22570759909493, 40.3776148387364, 50.891493456704275, 54.52001646586827, 50.80341114316668, 5.596768753869193, 0.759160503745079, 4.468792114939008, 7.418839165142604, 1.4933839227472032, 2.986196790422712, 22.118787697383336, 44.202042307172505, 51.53819009235927, 50.45713724408831, 51.24713352748326, 49.628953661237446, 48.13385418483189, 49.92124353136335, 46.43221255711147, 47.65076330729893, 45.11948939732143, 44.23202378409249, 43.233567646571565, 44.81068365914481, 48.43056658336094, 49.461185932159424, 48.16704225540161, 48.15366349901472, 50.59921053477696, 48.35156209128243, 48.28421320234026, 49.53796700068882, 49.04053156716483, 47.82639639718192, 44.33896698270525, 42.99933344977242, 40.8698912348066, 39.882805824279785, 37.22174651282174, 37.365876470293315, 36.7205034664699, 36.304028442927766, 35.975142410823274, 36.18004478727068, 36.355709144047324, 37.1096373285566, 35.31775944573538, 39.036185196467805, 36.905457564762656, 37.502933161599294, 37.029204981667654, 37.64490917750767, 37.60313660757882, 37.37661838531494, 38.74591377803257, 35.92825596673148, 38.12841694695609, 45.975055830819265, 47.727429730551584, 42.14197785513741, 43.22552858080183, 47.52578953334263, 44.447358880724224, 39.82792895180838, 37.37989446095058, 38.52709763390677, 45.979190008980886, 53.16948120934622, 46.00781658717564, 44.649238790784565, 46.32328217370169, 48.9445595741272, 52.43573406764439, 47.99445595060076, 50.19937644686018, 49.382834570748464, 51.887885979243684, 49.30500085013253, 40.76778745651245, 36.817451681409565, 35.84268890108381, 38.07332468032837, 37.55148022515433, 39.230842454092844, 37.47289957318987, 37.277919224330354, 37.27215916769845, 37.35056611469814, 37.034513405391145, 35.50111198425293, 35.428218432835166, 36.614682401929585, 37.794705390930176, 36.14123909814017, 35.94896854673113, 35.0656475339617, 36.633279255458284, 38.089680739811485, 38.548894132886616, 35.9992561340332, 36.9941200528826, 36.25198990958077, 35.01456437792097, 36.33714703151158, 35.14618410382952, 36.93181903021676, 36.97310175214495, 41.572107451302664, 47.04642636435372, 45.95905760356358, 48.09809528078352, 45.37324455806187, 48.09508671079363, 49.413747106279644, 47.75359664644514, 50.277168478284565, 46.154267242976594, 48.187334469386506, 40.99457318442208, 40.287288257053916, 51.708535603114534, 51.96270418167114, 52.8274040222168, 53.77118478502546, 51.548952851976665, 52.23009865624564, 53.00869294575283, 51.16572495869228, 50.88414226259504, 36.31267895017351, 8.736957601138524, 3.265766680240631, 4.162441262177058, 2.003443798848561, 0.24259127836142266, 0.4224585624677794, 29.98743847438267, 68.58770411355155, 55.191229820251465, 49.951961517333984, 25.784999472754343, 42.64806727000645, 56.01725946153913, 60.04344177246094, 11.897634949002947, 0.17337894226823533, 0.2052510484520878, 0.1210438891180924, 0.1261596360376903, 0.1465990785509348, 0.17690087828252996, 0.06692838722041675, 0.21242077515593596, 0.19111066364816257, 0.12884222423391684, 0.1918190542076315], [0.024834103483174528, 0.04217178261439715, 0.04789763090333768, 0.0236411659778761, 0.00929595435237778, 0.026355709780805876, 0.03832359339243599, 0.012553067478750433, 0.047199384442397525, 0.010788461675734391, 0.005597415604695145, 0.04374056914821267, 0.04350092415032642, 0.039471301449728866, 0.03422459727153182, 16.460153920309885, 48.048537254333496, 37.067138671875, 37.76011378424508, 26.542580672672816, 26.69545841217041, 40.29994440078735, 43.32271303449358, 46.681093556540354, 9.886249576296125, 0.18606918917170592, 0.4465004966727325, 2.8168757046972, 0.2202448131782668, 0.414943162884031, 7.437352640288217, 29.192227567945206, 49.76928642817906, 48.12737498964582, 47.72687387466431, 45.89743750435965, 45.65413243430001, 44.89901263373238, 45.95310994556972, 44.97624880926949, 44.574556078229634, 44.619868755340576, 44.35610124043056, 45.5983418737139, 45.04490743364607, 44.508645466395784, 45.057365553719656, 43.244792461395264, 43.48622499193464, 45.00173132760184, 42.9637656211853, 43.769113949366975, 44.24768154961722, 44.90205594471523, 44.613726547786165, 42.23609120505196, 42.53753185272217, 39.89565651757376, 35.06415367126465, 31.75235387257167, 33.42022378104073, 32.091186250959126, 33.52153199059622, 33.05582203183855, 33.17245101928711, 33.751572949545725, 33.6514424596514, 34.0377379826137, 34.69436706815447, 33.28909042903355, 34.66159936359951, 34.103308132716585, 33.838901383536204, 33.26394837243216, 33.93771171569824, 31.784770693097794, 37.53497477940151, 40.55667339052473, 43.108190877096995, 40.60993480682373, 40.30474213191441, 41.74559702192034, 39.47692332948957, 36.37989582334246, 34.91326311656407, 35.108594349452424, 44.71658420562744, 49.091277735573904, 46.62377439226423, 45.318513597760884, 42.789115701402935, 44.77395895549229, 44.8231383051191, 46.07750701904297, 47.15860503060477, 47.92936175210135, 46.58699062892369, 42.74941716875349, 33.98993785040719, 32.31261839185442, 32.903785024370464, 34.176833970206125, 37.32801921027047, 33.9968513080052, 33.50817060470581, 34.47779171807425, 32.727283409663606, 33.933956214359824, 34.67475577763149, 32.89034720829555, 33.482601233891074, 33.480683531079976, 34.31088209152222, 34.38816343035017, 34.52095740182059, 34.51354019982474, 34.07494558606829, 34.05931561333792, 32.627552441188264, 33.32778147288731, 32.874991689409526, 32.165893282209126, 32.514661584581646, 32.706136567252024, 32.1205597605024, 32.20525482722691, 31.35028941290719, 33.94199528012957, 37.631544317517964, 40.18657064437866, 43.999366828373496, 45.12827886853899, 43.77746568407331, 45.500288895198274, 44.58219909667969, 45.51436594554356, 47.372133595602854, 42.48498610087803, 39.51412398474557, 35.925115380968364, 38.63690349033901, 41.42877306256975, 43.506885460444856, 43.583367756434846, 46.56814364024571, 46.707239627838135, 51.05377558299473, 49.72400501796177, 50.095580782209126, 29.96001740864345, 4.504519317831312, 0.5279045328497887, 1.11909618973732, 4.389921809945788, 0.09171008744410106, 0.45410728135279244, 31.56681612559727, 53.428426674434114, 40.14475291115897, 34.324146202632356, 26.162349190030778, 35.581447056361604, 48.20064026968819, 36.251830101013184, 2.692198531968253, 0.06241491476872137, 0.03672785884035485, 0.007137748196588031, 0.01787958264217845, 0.0723571219880666, 0.011448571924120188, 0.042107403211827786, 0.03484910393932036, 0.05102089027475033, 0.06863703339227609, 0.03424741640420897, 0.033795057463326623, 0.0598258761955159, 0.018672466078507047, 0.04461228987202048, 0.07454803013908011, 0.012816439998070044, 0.07880678054477487, 0.006811664198591773, 0.0077918720697718, 0.07891546149871179, 0.010278054064006677, 0.03957651848239558, 0.04638044695769038, 0.0067542652250267565, 0.06933699654681341, 20.18588396481105, 53.932021686008994, 42.63432373319353, 39.54972308022635, 27.16848134994507, 34.68433734348842, 46.047834736960276, 46.28870793751308, 51.4574624470302, 9.700778705733162, 0.23529520843710217, 0.5718186678630965, 4.00087045771735, 1.59277377809797, 1.4291268736124039, 9.48127555847168, 31.347565719059535, 50.37465170451573, 48.94936425345284, 50.70668874468122, 47.74360166277204, 48.273120403289795, 46.605253968920024, 48.179806096213206, 46.67136607851301, 47.48005301611764, 48.2461370740618, 46.85189764840262, 47.2342848096575, 46.710112707955496, 46.77624913624355, 47.436369691576274, 45.65987164633614, 45.21255356924874, 47.01590987614223, 44.060337271009175, 45.262594495500835, 46.37571675436837, 45.63219002314976, 46.02654545647757, 43.28771495819092, 43.65926987784249, 40.442438057490754, 37.365292821611675, 34.32446929386684, 35.55702761241368, 33.58787339074271, 34.19496529442923, 33.30316400527954, 34.13105228969029, 34.86014413833618, 34.86332293919155, 35.86286646979195, 37.7225136075701, 34.737675189971924, 35.68724032810756, 35.77419008527483, 35.549968242645264, 34.30869688306536, 35.689196246010916, 33.57309109824044, 39.437231745038716, 43.53237840107509, 46.80544546672276, 43.73288951601301, 43.127656255449565, 43.127836908612935, 41.12720734732491, 39.10402740750994, 35.84883805683681, 36.997107778276714, 46.162268093654085, 51.3181197983878, 48.70800815309797, 47.22446700504848, 44.56277888161795, 47.48509393419538, 47.206776891435894, 48.145572321755544, 48.23902906690325, 47.50188773018973, 46.91897555759975, 44.83841044562203, 35.450410979134695, 34.31482866832188, 34.4562349319458, 37.01761886051723, 36.97427947180611, 35.348546913691926, 35.24543564660208, 36.28325680324009, 34.88046761921474, 36.067087922777446, 36.17363854816982, 35.07121998923165, 35.221624170030864, 34.45629399163382, 34.91408995219639, 35.145940916878835, 35.341591766902376, 35.92461163657052, 35.41144895553589, 35.14054216657366, 34.88354219709124, 35.265074729919434, 34.64690044948033, 34.04184784208025, 34.646393230983186, 33.60180800301688, 33.58513232639858, 34.48956196648734, 33.46429967880249, 36.6646260534014, 39.58062171936035, 42.61538641793387, 45.354692867824006, 47.989616530282156, 45.746175221034456, 45.70255790437971, 47.14489623478481, 47.7409474509103, 47.88099881580898, 44.70579712731497, 41.65882444381714, 37.74873958315168, 42.3658800806318, 44.6637362071446, 45.563267367226736, 46.760268279484336, 48.3131593976702, 48.9506288255964, 53.0471373285566, 51.09521116529192, 51.91828782217843, 31.956009047372, 5.4080274530819485, 0.6396213067429406, 2.759983854634421, 3.8310538785798207, 0.0994089086140905, 0.405173832816737, 34.6236378805978, 59.30380603245327, 45.28808396203177, 38.68965768814087, 29.426850863865443, 39.650013378688264, 55.002238818577354, 43.34158434186663, 4.428194659096854, 0.021587555995211005, 0.05377606475459678, 0.017182932434869663, 0.05298652819224766, 0.011007019501578594, 0.03204214366685067, 0.07013382057526282, 0.034116106307400126, 0.03095274551638535, 0.08301904451634202, 0.01626790251715907, 0.06796223710158042, 0.18992301023432187, 0.15025870289121354, 0.18947510926851205, 0.14898283992494854, 0.08454160924468722, 0.18214626610279083, 0.10595607943832874, 0.09033903958542006, 0.1633584728198392, 0.11385080723890237, 0.14671817501740797, 0.07714920770376921, 0.15445522485034807, 0.12175187255655016, 23.125579936163767, 63.276918002537315, 48.359917300088064, 46.33279078347342, 36.74361317498343, 38.64071805136544, 52.635935987745015, 52.81240633555821, 57.317111083439414, 12.29596301487514, 0.4229198848562581, 2.498555277075086, 6.8044412306376865, 1.8738585923399245, 1.0520871111324854, 9.95916223526001, 32.81754745755877, 53.41152170726231, 52.22533219201224, 53.34637539727347, 50.573766231536865, 49.51464189801897, 48.38839796611241, 50.93185901641846, 50.14527429853167, 49.30500085013253, 49.988192898886545, 48.211722646440776, 49.13672590255737, 50.64542300360543, 49.36655494144985, 49.54703787394932, 46.1634875025068, 45.827726227896555, 46.869619028908865, 45.41317932946341, 46.217106751033235, 49.12751953942435, 47.87100035803658, 47.92395952769688, 46.23413331168038, 45.7167843409947, 43.67669595990862, 40.23057358605521, 35.16192872183663, 37.54829795019967, 34.492167540958945, 36.465789454323904, 35.573609488351, 37.364785603114534, 36.83451993124825, 36.96357577187674, 37.0754382950919, 39.64478833334786, 37.14936365400042, 38.65914467402867, 37.108028820582796, 38.281353746141704, 37.321866580418174, 36.71431609562465, 34.83301837103707, 41.80763053894043, 44.77129084723336, 47.30631331035069, 44.892300673893516, 44.57589360645839, 44.98103264399937, 43.246817861284526, 40.274503571646555, 38.28170463017055, 39.15389115469796, 47.36598096575056, 52.70086342947823, 49.636673109872, 49.8916893686567, 45.03250142506191, 45.714310782296316, 48.04115826742989, 49.465104716164724, 50.837221077510286, 50.169787543160574, 50.41493041174752, 45.743218762534006, 37.184698717934744, 37.21081699643816, 37.33774321419852, 38.528268405369346, 40.68941525050572, 34.55628204345703, 37.36310066495623, 38.33464642933437, 36.932013579777305, 37.04674570901053, 37.77045617784773, 35.99012620108468, 37.77235651016235, 36.79578719820295, 37.36823885781424, 38.66876098087856, 36.878196307591026, 37.706800256456646, 36.53971481323242, 36.68217372894287, 35.94348989214216, 37.030587673187256, 37.0687506539481, 35.87031841278076, 36.28412185396467, 35.6260301726205, 35.78008215767996, 36.11759090423584, 34.92099298749651, 38.618271895817344, 42.015444210597444, 44.830131667000906, 48.920282568250386, 48.794270038604736, 48.530290603637695, 48.397159644535606, 48.27281468255179, 49.84259687151228, 50.94303519385201, 47.20583541052682, 44.600229672023225, 39.95140191486904, 43.86185155596052, 46.15284981046404, 47.51476274217878, 49.66414628710066, 50.61753988265991, 51.74859544209072, 53.91145849227905, 53.02135256358555, 53.34840774536133, 34.35233504431588, 5.90534085886819, 1.0141773053577967, 5.889987511294229, 12.590971367699758, 0.29223884429250446, 0.7865382518087114, 38.23778854097639, 64.66634232657296, 52.88853427342006, 45.71878889628819, 38.85014023099627, 47.02560608727591, 60.46163994925362, 53.32631594794137, 6.139157729489463, 0.21667926093297346, 0.22147667993392262, 0.1195078215428761, 0.15178136261446135, 0.10747296482856784, 0.12024629834507193, 0.13796363478260382, 0.18531708738633565, 0.1823847983032465, 0.15490590780973434, 0.15237345227173396], [0.012830198991910687, 0.04408581455105117, 0.08241251563387257, 0.05232192349753209, 0.04416882313255753, 0.10882987880281039, 0.024267828690686395, 0.04366568602355463, 0.01635814767463931, 0.07238198351114988, 0.05120955015133534, 0.03676413671512689, 0.015261494288487094, 0.03746853409601109, 0.08922711067966052, 9.617290888513837, 42.7168995993478, 39.536941868918284, 42.3814822605678, 31.640550409044536, 20.900884866714478, 37.25941617148263, 44.731679167066304, 47.9503835269383, 20.296287366322108, 0.01758356495494289, 0.44231588978852543, 2.0419559265886034, 1.3193808368274142, 0.9525739252567291, 2.225066146680287, 17.348979643413, 49.42483295713152, 48.124769415174214, 46.675229276929585, 44.12682110922677, 46.28762749263218, 45.04133605957031, 45.386362757001606, 45.153407028743196, 46.07048239026751, 43.507048743111746, 44.86897904532296, 43.88390513828823, 45.38196802139282, 44.97690541403634, 44.91662284306118, 43.011788095746724, 47.20312213897705, 42.41970777511597, 42.53743805204119, 40.11055735179356, 44.54431404386248, 43.750343390873496, 45.29545600073678, 43.78827708108084, 43.32072932379586, 41.34046145847866, 40.33895853587559, 35.797285897391184, 31.55125216075352, 32.79122768129621, 32.65814535958426, 31.614935874938965, 33.06499365397862, 33.65012925011771, 32.68472569329398, 33.70449890409197, 33.89525127410889, 33.945431164332796, 35.10174342564174, 34.77858618327549, 33.867798941476, 33.44360099520002, 33.08255522591727, 33.54537125996181, 38.67724125725882, 41.863289083753315, 43.20907524653843, 44.40883459363665, 42.00413949148995, 40.73038182939802, 40.29915230614798, 36.50664486203875, 38.72285965510777, 33.94814443588257, 40.81191546576363, 48.30167749949864, 48.305113383701865, 44.881273882729666, 39.99760743549892, 41.529702595302034, 46.394459520067485, 47.253350666591096, 47.27657502038138, 45.74450765337263, 45.66823032924107, 41.21274662017822, 34.33281755447388, 34.2022921698434, 31.85025746481759, 33.22623702457973, 35.283143520355225, 33.87289891924177, 35.7844352040972, 35.18337433678763, 34.50195060457502, 34.439500195639475, 32.31515448434012, 32.66717454365322, 34.01972825186593, 34.418061528887065, 31.701632022857666, 33.510908194950645, 33.52369288035801, 33.20340176991054, 33.80657836369106, 33.52357128688267, 34.097099917275564, 33.402578830718994, 33.01755482809884, 33.76197440283639, 33.188782760075156, 33.87566777638027, 32.571876525878906, 31.62086616243635, 30.780283519199916, 30.99545533316476, 35.56224570955549, 40.29742220469883, 40.935614245278494, 43.68069812229702, 46.855545452662874, 43.413029193878174, 42.976828234536306, 43.3845728465489, 46.6318690436227, 47.936202253614155, 44.858164174216135, 37.88805791309902, 33.84011731828962, 35.09645584651402, 36.840696879795615, 41.24743202754429, 38.988086291721885, 43.21041972296578, 46.94685867854527, 50.51720094680786, 48.62647451673235, 24.13140116419111, 2.20571237376758, 0.3569665253162384, 1.1872585607426507, 1.890120199748448, 0.13715203904679843, 0.4498730057052204, 29.807938711983816, 50.760985442570274, 41.89787026814052, 29.99978542327881, 11.472297498158046, 31.26617799486433, 45.91313348497663, 32.065842696598594, 1.2403020858764648, 0.11769400244312626, 0.014113719225861132, 0.01705874695575663, 0.0036445629832867, 0.027082697288798432, 0.04942129485841308, 0.04551657009869814, 0.05872692766466311, 0.02559030701273254, 0.033952131534793546, 0.036033999108310254, 0.07912049442529678, 0.045607347906168015, 0.006348519095419241, 0.029826146683522632, 0.03243427583947778, 0.09293656663170882, 0.020060336516637887, 0.07898013267133917, 0.05476539595318692, 0.027136618770392876, 0.020598794766036526, 0.06272491027734109, 0.02664135436394385, 0.03967581529702459, 0.0932130967932088, 12.329644407544817, 48.90392998286656, 45.62487357003348, 45.8439815385001, 32.02835021700178, 27.233031851904734, 42.12856435775757, 49.56572505405971, 52.23137712478638, 20.698654072625295, 0.0046741978897313985, 0.21142073667475156, 1.8760674680982317, 3.2459247963769093, 1.7741838608469283, 3.9583392313548496, 19.83643821307591, 49.32564742224557, 49.53919335774013, 46.75686713627407, 46.99024323054722, 47.98932123184204, 45.83277756827218, 47.922583784375874, 46.412406717027935, 48.19969184058053, 46.21484163829258, 47.959909507206504, 45.55512407847813, 45.86095946175711, 45.106287819998606, 46.88788931710379, 45.06705134255545, 47.087094170706614, 44.34062760216849, 43.275242941720144, 42.256279196058, 46.00674656459263, 45.48503065109253, 45.360567569732666, 44.53974212918963, 44.497893129076274, 42.15161500658308, 42.04962934766497, 36.97972338540213, 33.30613783427647, 33.329209327697754, 34.722771303994314, 32.61422232219151, 34.62076827457973, 35.33484854016985, 35.321389879499165, 35.64862224033901, 35.39388738359724, 35.25605596814837, 35.05463811329433, 35.27890511921474, 35.53717660903931, 34.76126779828753, 35.64813239233834, 33.8468952860151, 40.05327640260969, 42.79345832552229, 45.450477259499685, 44.680717604500906, 44.5566714150565, 43.5565060206822, 41.326342718941824, 38.54292215619768, 39.51635088239397, 36.368976729256765, 43.99327673230852, 49.21231188092913, 49.033764021737234, 46.15205076762608, 41.687093189784456, 46.135944843292236, 47.49333102362496, 48.26327133178711, 48.553101539611816, 48.08052676064627, 47.06369958605085, 42.4267567225865, 34.87950529370989, 34.51068449020386, 34.70763117926461, 35.753022398267476, 36.4227523122515, 34.400850840977256, 37.082921504974365, 36.75302103587559, 36.25889989307949, 36.33990199225289, 34.811412947518484, 34.21846410206386, 35.28837203979492, 35.99763025556292, 33.09256758008684, 34.67895596367972, 35.190121037619456, 34.657677105494905, 34.94939374923706, 36.23871885027204, 35.23810182298933, 33.99619817733765, 34.369524887629915, 35.465769972120015, 34.59866605486189, 35.435969148363384, 34.65511669431414, 33.39509909493582, 33.21315009253365, 33.3179497718811, 38.29318652834211, 43.60990640095302, 43.93408850261143, 45.07484027317592, 47.33508232661656, 46.49638959339687, 46.4701566696167, 45.49100610188076, 48.917961869921, 49.45542934962681, 44.7223790032523, 39.161468165261404, 36.03483091081892, 38.06529951095581, 39.36901780537197, 44.53312744413103, 42.808591502053396, 45.133205141339985, 49.17580604553223, 52.11783313751221, 49.65975849969046, 26.12285041809082, 3.3752917860235487, 0.8926206337554115, 2.8675858293260847, 3.8198459999901906, 0.13577473509524549, 0.5292863558445657, 33.188963413238525, 54.83739628110613, 49.02378988265991, 38.55586665017264, 17.98574730328151, 37.56012725830078, 50.967520645686555, 37.76472738810948, 1.87838990347726, 0.08037655773971762, 0.06750805968684809, 0.004534361152244466, 0.09261200297623873, 0.03157821570390037, 0.0626906171174986, 0.003431958454062364, 0.07904258503445558, 0.008154275926894375, 0.014898115037275212, 0.06795771805835621, 0.1572951381759984, 0.13013334066740104, 0.15831907466053963, 0.12150584932948862, 0.15114778732614859, 0.21080993302166462, 0.05596408573910594, 0.14448128933353083, 0.1610050962439605, 0.1056958476879767, 0.11134788833026375, 0.3116771083857332, 0.10561774830733027, 0.1160313066627298, 0.1324570516922644, 13.818222999572754, 54.861794880458284, 51.49723046166556, 50.320935181209016, 41.708684716905864, 32.56080804552351, 47.0945600100926, 53.30424846921648, 58.28898688725063, 24.27780318260193, 0.15580637806228229, 1.4651731508118766, 7.659926022802081, 6.363037373338427, 1.5009002451385771, 3.6233424757208144, 20.91536143847874, 53.143001624516074, 51.86503682817732, 50.560714040483745, 47.588469232831685, 50.56977449144636, 48.221675940922324, 49.19090795516968, 48.240731375558035, 49.694996288844514, 46.782547678266255, 48.196551254817415, 47.82564599173409, 47.55472878047398, 46.21697473526001, 47.35338735580444, 46.5102026121957, 49.56777824674334, 44.501426288059776, 44.94989429201399, 44.25068664550781, 47.656617164611816, 46.55565425327846, 47.67838587079729, 46.44713381358555, 47.33129555838448, 44.72212539400373, 44.63711071014404, 39.37387112208775, 34.7894983291626, 36.01815176010132, 37.17892476490566, 35.39098651068551, 37.386919089726035, 36.96033443723406, 36.669416836329866, 37.27144350324358, 36.057353496551514, 36.549963406154085, 37.43068579265049, 36.70946625300816, 38.36691386359078, 36.25388329369681, 36.318049907684326, 37.001481669289724, 43.66509246826172, 44.96481902258736, 46.785490240369526, 48.01123237609863, 46.539610862731934, 45.8341463633946, 44.145668097904746, 40.519059317452566, 42.59188066210066, 37.810123443603516, 45.94330951145717, 51.5589165687561, 50.12164347512381, 49.07319504874093, 42.50625453676496, 46.330810546875, 50.22830179759434, 49.104517527988975, 50.95521191188267, 49.35377025604248, 49.405867849077495, 44.433406897953574, 37.875644956316265, 37.431870460510254, 36.789863858904155, 36.93216644014631, 37.38270500728062, 36.19790860584804, 39.155492714473176, 38.23437350136893, 38.31704664230347, 37.781740052359446, 36.457489831107004, 35.06920501164028, 38.3977986063276, 37.51511335372925, 34.43937512806484, 37.53739275251116, 37.276487895420615, 35.80158335821969, 37.45199244362967, 37.441782065800254, 37.976522377559114, 36.14289276940482, 36.40523937770298, 37.049545833042686, 36.675590310777935, 37.87202147075108, 35.50884185518537, 34.83334493637085, 34.67476619992937, 35.7292491367885, 39.456499099731445, 44.414945534297395, 45.15329933166504, 48.27367973327637, 48.77487414223807, 47.86628253119332, 46.42554228646414, 46.029171875544954, 50.94969504220145, 51.64600876399449, 48.15372255870274, 40.99820361818586, 38.06466722488403, 40.23941516876221, 40.09721681049892, 46.07991804395403, 44.4410012790135, 46.39772169930594, 51.91069344111851, 53.392619132995605, 51.60675491605486, 27.889996188027517, 4.047571471759251, 1.6499444246292114, 5.096587913376944, 7.000705693449293, 0.5317316332033702, 0.6896119671208518, 37.092850480760845, 59.88918481554304, 53.181977544512065, 42.86525058746338, 20.687116588865006, 43.5154630116054, 57.54000582013811, 46.60604953765869, 3.223483634846551, 0.2624594351010663, 0.13144262826868466, 0.07372614102704184, 0.1099144627473184, 0.1186680258916957, 0.14248970762959548, 0.10313618968107871, 0.11129142064601183, 0.11504216545394488, 0.11376531861190285, 0.15686683330152715], [0.026658360147848725, 0.05148989028696503, 0.03526193482269134, 0.04809879618031638, 0.08274050589118685, 0.03752304081405912, 0.03552185105425971, 0.06193035255585398, 0.06729281480823245, 0.02850215183570981, 0.04303495379696999, 0.0324944585029568, 0.11184302890407187, 0.050341547799429724, 0.045404784847050905, 5.711335863385882, 39.398676191057476, 38.41235160827637, 43.74244328907558, 26.681621074676514, 27.716190474373953, 39.657784938812256, 45.02834987640381, 47.04272992270333, 33.387442180088584, 1.1625508751188005, 0.1540236087249858, 1.1666466210569655, 1.9283863178321292, 1.9286214709281921, 0.7254267281719616, 9.934413620403834, 44.026232038225444, 48.67820732934134, 46.91428899765015, 44.86937509264265, 47.95978791373116, 45.7694343158177, 46.32679101399013, 44.287578105926514, 43.04414585658482, 42.90095738002232, 42.624335697719026, 46.3836863381522, 46.50598505565098, 46.60729326520647, 45.77720587594168, 44.16426147733416, 44.28581326348441, 40.81543125425066, 45.20163794926235, 42.967858110155376, 42.18115527289254, 44.67470046452114, 43.439116205487935, 44.2232551574707, 42.803230966840474, 43.632255281720845, 41.49387420926775, 41.07040582384382, 35.23433937345232, 30.706076758248464, 33.52943556649344, 31.982175963265554, 32.57294307436262, 32.61626509257725, 34.98413821629116, 34.51860196249825, 34.281699657440186, 34.17219604764666, 34.557237420763286, 32.84287016732352, 31.88873311451503, 33.051937988826204, 34.49102108819144, 34.26759481430054, 37.1631315095084, 41.527295044490266, 43.417660168239046, 41.83620500564575, 43.67150912966047, 40.58857951845442, 41.17929451806204, 37.887376989637104, 36.329795837402344, 34.22785459245954, 38.99135194505964, 45.98999793188912, 47.012258597782676, 46.530248165130615, 41.662044933864046, 43.32286589486258, 44.90927512305123, 47.05509424209595, 46.74379410062517, 46.2201361656189, 46.02886962890625, 39.17906100409371, 32.497030530657085, 33.434137548719136, 33.37405300140381, 35.27196734292166, 35.07851907185146, 34.88394866670881, 33.91727706364223, 34.16293409892491, 34.553190095084055, 32.441007205418174, 34.69538150514875, 35.27299567631313, 34.00441094807216, 33.84433487483433, 33.128996985299246, 32.41006340299334, 32.72610221590315, 33.189338615962434, 34.56233739852905, 34.93684877668108, 32.93959951400757, 33.68905305862427, 33.618143217904226, 33.43668753760201, 33.3304773739406, 32.676533767155235, 32.84172371455601, 32.17756278174264, 32.90854454040527, 32.096192428043906, 33.2564616884504, 37.85892064230782, 43.02773421151297, 45.210097381046836, 44.80660854067121, 44.978764057159424, 44.88534900120327, 43.49372557231358, 44.41303130558559, 48.064948899405344, 47.92707232066563, 46.04863377979824, 43.657369545527864, 42.48520844323294, 41.03153760092599, 42.82281446456909, 41.732593468257356, 43.85782854897635, 45.99271467753819, 48.39357784816197, 46.97257743562971, 15.916073492595128, 1.527947519506727, 0.48020943786416737, 0.9780562264578683, 2.686622602599008, 0.06857844867876597, 0.387409188917705, 35.855143547058105, 55.09165866034371, 38.77951526641846, 27.973937375204905, 22.702792474201747, 34.4692245892116, 44.56540182658604, 29.473994391305105, 0.47165137422936304, 0.032655824308416674, 0.025342857165794288, 0.06856042678867068, 0.027958516364118884, 0.03387066662045462, 0.059178336656519344, 0.058399059543652196, 0.028178460097738674, 0.023158491788698093, 0.026411809359810183, 0.03385070751288107, 0.020702084759250283, 0.030144352465867996, 0.07637482282838651, 0.03517764041732464, 0.024295416228207092, 0.02692473603279463, 0.031279127645705423, 0.05702523647674492, 0.037251867686531374, 0.02509339206985065, 0.04861060157418251, 0.03677414510665195, 0.033801381409700425, 0.030979018392307416, 0.08970465684043509, 6.950428528445108, 47.055188042776926, 43.1148715700422, 46.09343923841204, 30.85995156424386, 32.929399558476035, 44.16029405593872, 48.345444202423096, 52.526404585157124, 34.81404284068516, 1.127096714718001, 0.48640560252325876, 1.0851230812924249, 3.393124989100865, 4.089049177510398, 2.5521929817540303, 9.928717834608895, 44.927621841430664, 50.50003889628819, 50.009742736816406, 45.94922937665667, 49.318716594151084, 46.55056817190987, 47.268330982753206, 46.83134140287127, 45.5102665083749, 44.99303218296596, 45.44858040128435, 45.5865021433149, 45.77133812223162, 45.879254068647114, 47.84996816090175, 44.88379260471889, 46.10693958827427, 41.88335200718471, 45.229194504874094, 44.7576584815979, 45.224855354854036, 46.61687135696411, 45.945060457502095, 45.28465155192784, 45.56679357801165, 45.13509157725743, 44.02492925098964, 43.211917059762136, 36.830132143838064, 32.152222701481406, 34.48371505737305, 32.48659781047276, 34.901812485286165, 32.9447272845677, 36.97182675770351, 35.1854692186628, 35.05724368776594, 35.6178834097726, 35.71978916440691, 34.46658427374703, 34.64926631110055, 33.593650817871094, 36.28341313770839, 35.367772579193115, 40.520782470703125, 43.331318378448486, 45.21499586105347, 43.92164427893502, 43.88602433885847, 41.519440105983186, 42.79361118589129, 39.668742247990195, 38.03797571999686, 37.0483090536935, 40.081499985286165, 46.749498571668354, 48.525607517787385, 47.07240915298462, 44.17448575156075, 47.076762199401855, 46.25254256384713, 49.377199581691194, 48.63034118924822, 47.86220046452114, 47.218192781720845, 40.14688948222569, 32.976331165858674, 34.402831077575684, 35.992380891527446, 37.166477067129954, 37.97886392048427, 36.27689225333077, 36.18727091380528, 35.68084798540388, 36.47914041791643, 33.55873959405081, 35.07512140274048, 35.74404879978725, 35.30334888185774, 36.128416197640554, 35.263695512499126, 34.7673578943525, 35.39582245690482, 34.857034819466726, 36.04424224581037, 36.071579933166504, 34.84639365332467, 35.64699288776943, 34.947083473205566, 34.750102043151855, 35.03900466646467, 33.56227275303432, 34.08295685904366, 34.411630971091135, 35.07071277073452, 34.51143836975098, 35.68452705655779, 40.39237976074219, 45.56080770492554, 49.7757864679609, 46.872380937848774, 47.86974273409162, 47.130193846566335, 44.4991021156311, 46.933334009987966, 49.36614152363369, 49.373197419302805, 47.7687645639692, 45.088594232286724, 43.79626750946045, 42.153240885053364, 43.03452260153634, 44.06214032854353, 45.429441588265554, 48.5331324168614, 50.65207590375628, 48.94396897724697, 18.59039691516331, 1.8634030733789717, 1.3801465247358595, 3.1872817831380025, 3.3172389354024614, 0.037091974302061965, 0.4572880363890103, 39.08550351006644, 58.321601731436594, 43.459019320351736, 33.889769145420615, 21.75461002758571, 39.19461107254028, 50.6196208681379, 34.872692584991455, 1.0028580384595054, 0.06836347521415778, 0.08033633418381214, 0.03519522125965782, 0.08753553644887038, 0.1197273140507085, 0.03616140762876187, 0.08768065473330872, 0.04392742072897298, 0.012655862989569349, 0.032891876463379176, 0.027329860454691306, 0.0993041428072112, 0.16306537283318384, 0.1984264382294246, 0.14914856531790324, 0.08233578689396381, 0.1301407366991043, 0.14529688842594624, 0.1945114540202277, 0.22159207159919397, 0.18194294986980303, 0.08855013629155499, 0.13973256200551987, 0.13754446298948356, 0.15318675791578634, 0.2253560817667416, 7.866268413407462, 55.00885697773525, 50.98953601292202, 52.70572369439261, 36.8980507850647, 40.96321596418108, 50.40658562523978, 52.690694740840364, 55.75194249834333, 40.000140053885325, 1.7314929344824381, 1.2935979174716132, 4.661001869610377, 7.400583641869681, 4.444098651409149, 1.919657860483442, 12.18040839263371, 48.076816422598704, 52.94523504802159, 52.455605915614534, 47.23798125130789, 50.60527283804757, 47.53470754623413, 47.76280648367745, 47.565307412828716, 44.95128740583147, 45.83893714632307, 45.41879347392491, 47.44428368977138, 47.80503068651472, 47.69527694157192, 48.59289039884295, 47.26328659057617, 47.906092235020225, 43.17081151689802, 45.739067213875906, 47.61937829426357, 46.40525354657854, 49.755230222429546, 47.87756640570504, 47.14492750167847, 47.583820887974326, 46.516594954899375, 46.26504584721157, 46.67533002580915, 38.91653721673148, 33.15622697557722, 37.379220485687256, 34.84253740310669, 36.5138327734811, 34.83595051084246, 39.736640044621055, 37.92609930038452, 37.18368080684117, 37.09386839185442, 37.219790594918386, 35.33420583180019, 35.30472115107945, 35.970084122249055, 38.503529344286235, 37.96006209509713, 42.90062386648995, 45.711708681924, 46.97704512732369, 44.95950017656599, 47.84650100980486, 43.90733446393694, 43.96668250220162, 41.37982995169503, 40.41785185677664, 37.2292331968035, 42.75636536734444, 47.82209546225411, 49.78380468913487, 49.947799546378, 42.95556674684797, 45.49164881025042, 48.259828499385286, 50.10093436922346, 49.34043318884713, 48.76622363499233, 50.23626790727888, 42.77553544725691, 35.66034732546125, 36.74492291041783, 37.74848249980381, 40.19692693437849, 39.140297004154746, 36.97568300792149, 37.03123385565621, 36.944482122148784, 39.19156081335885, 34.86246483666556, 37.133625984191895, 38.555366379874094, 37.192553656441824, 37.360053879874094, 36.56998464039394, 36.55760989870344, 35.75544037137713, 37.30283893857683, 38.200497559138704, 37.4381377356393, 35.99248858860561, 37.578352383204866, 36.714409896305625, 36.5578669820513, 37.40157978875296, 35.611751624516074, 35.52385343824114, 35.57697589056832, 37.13211475099836, 36.68600566046578, 38.614842959812705, 41.37498705727713, 47.56875024523054, 50.7021689414978, 48.31168985366821, 50.20205845151629, 49.24562849317278, 46.01288182394845, 46.494513579777305, 50.252040318080354, 52.03851250239781, 50.061586720602854, 47.19868571417672, 48.91543967383248, 46.656191212790354, 46.17502498626709, 47.00143330437796, 47.970561095646445, 51.17059217180525, 52.51228584562029, 52.16785669326782, 19.29495814868382, 2.9445099873202185, 2.2570447964327673, 5.8886095966611585, 9.3280417237963, 0.21296234109572001, 0.6180922591260501, 43.20762307303292, 64.5992922101702, 48.59671538216727, 39.07345880780901, 31.861669881003245, 46.421102387564524, 58.80418886457171, 42.27911445072719, 1.44720749769892, 0.27130343339272905, 0.1681647670588323, 0.16403577290475368, 0.12921065517834254, 0.15431415741997107, 0.21389403752982616, 0.18865492327937058, 0.0926187951117754, 0.08579338421779019, 0.08995855107371296, 0.09598080042217459], [0.024092644519571747, 0.0419865086275552, 0.006821759527416101, 0.04592575724901898, 0.002411866930612762, 0.1134424852207303, 0.04059739477400269, 0.03428880704034652, 0.02490700189290302, 0.026880760178236023, 0.031214280053973198, 0.013962115842982062, 0.053515978889273744, 0.05049789583842669, 0.06982098879026515, 1.5891824279512679, 21.681438548224314, 37.76363999502999, 44.52380296162197, 28.283872195652553, 23.893242972237722, 33.80602250780378, 45.459266730717246, 45.10057292665754, 41.92036853517805, 3.540367305278778, 0.2841306765164648, 0.26871316667113987, 2.0143592017037526, 2.350650493587766, 1.7835860763277327, 2.51326504775456, 38.036488805498394, 50.49688788822719, 44.19427074704851, 45.612571784428184, 44.829864161355154, 48.724464961460654, 47.54973302568708, 45.94380630765642, 44.99020079204014, 46.16257381439209, 46.12900359289986, 45.83192293984549, 44.83848687580654, 44.51438815253121, 42.740770135607036, 43.594703742435996, 42.68281173706055, 45.32147005626133, 43.540198598589214, 42.26536743981497, 45.49186767850603, 41.087310791015625, 41.86684308733259, 42.77720996311733, 44.625611441476, 45.4764461517334, 43.79596873692104, 41.72956057957241, 40.920925753457205, 34.669475146702354, 30.661927904401505, 32.65407024111067, 33.12763166427612, 32.69471720286778, 34.78064285005842, 35.10736451830183, 34.35554163796561, 35.37374455588204, 34.42737906319754, 35.19536345345633, 32.130520003182546, 33.08390665054321, 34.09399059840611, 33.29068851470947, 38.21786805561611, 41.766420773097444, 43.00614963259016, 42.82721962247576, 44.662579332079204, 42.06240708487374, 42.567610604422434, 38.649771554129465, 37.498277868543354, 35.01363679340908, 40.20316294261387, 44.813640117645264, 47.318375383104595, 45.51204524721418, 43.06486191068377, 43.28993838174002, 45.13207605906895, 45.375975200108115, 47.46351282937186, 45.20764814104353, 45.022325788225444, 38.405410357883994, 33.906750542776926, 33.583909443446565, 34.53355795996529, 35.61266878673008, 37.40131228310721, 36.29514864512852, 34.15982478005545, 34.09557131358555, 34.71987043108259, 34.061726638248985, 34.900697299412315, 33.04721668788365, 34.14598396846226, 34.06950167247227, 31.902796268463135, 33.51393413543701, 34.776418345315115, 34.028027875082834, 32.82863678250994, 35.609076568058555, 34.24275500433785, 35.54823119299752, 35.95520108086722, 34.383692264556885, 34.21742187227522, 34.46273497172764, 33.478161334991455, 33.786491121564595, 32.70889152799334, 33.60041836329869, 33.6705812726702, 33.68050677435738, 40.989938735961914, 44.201271057128906, 43.89185735157558, 44.783585684640066, 44.1404013633728, 45.30392585481916, 45.411939076014924, 43.307795252118794, 45.180477210453574, 44.712238107408794, 44.44325944355556, 48.11052213396345, 47.39748062406267, 49.097753456660676, 46.15131425857544, 45.414923327309744, 46.91629007884434, 48.86542306627546, 44.59673472813198, 13.20603893484388, 0.19720109898064817, 1.2653112581798007, 0.9349725097417831, 0.8211250816072736, 0.0785811065829226, 0.9780235482113702, 41.74195963995797, 48.08378546578543, 35.40387889317104, 30.52619137082781, 28.561671597617014, 37.00415325164795, 47.8013550894601, 23.15238434927804, 0.07983981618391615, 0.01747060414137585, 0.07636056002229452, 0.0883641294868929, 0.04202996540282454, 0.061698978899845054, 0.04525052669591137, 0.040294805475111516, 0.022205019469505975, 0.03991147729435137, 0.03934751630627683, 0.012811595258036894, 0.032389858937157054, 0.02341674730580832, 0.03952200497899737, 0.025362346387867416, 0.03584261830630047, 0.02036343132411795, 0.015197764583198088, 0.06891981286129781, 0.023781978957621113, 0.04584187675001366, 0.06215120891907385, 0.017861718511474983, 0.04271838328401957, 0.044603859074413776, 0.1362828899707113, 2.5893929856164113, 31.359940460750035, 44.70115920475551, 49.87779644557408, 30.924663611820765, 33.17984390258789, 42.18898589270455, 49.516299043382915, 49.90854222433907, 45.66023990086147, 3.7237511106899808, 0.20751533338001796, 0.39678792708686417, 3.7647446138518195, 6.963663978236062, 2.1142567098140717, 2.9888331975255693, 40.49537638255528, 51.20226900918143, 46.67663976124355, 48.341608796800884, 47.392338957105366, 48.9174233845302, 47.949810300554546, 46.7147228377206, 45.374415329524446, 47.12734855924334, 45.87439727783203, 46.25876120158604, 45.26834412983486, 44.69185209274292, 45.42013100215367, 45.186876501355854, 43.16535023280552, 46.330282483782085, 45.628497055598665, 44.74307073865618, 46.54073647090367, 42.42252179554531, 43.159152439662385, 44.63317455564226, 44.67833437238421, 45.56556027276175, 45.42656850814819, 43.500548703329905, 41.19013023376465, 34.962011677878245, 32.44887604032244, 33.584972517830984, 34.855773721422466, 33.22346816744123, 36.025634969983784, 34.948288985661094, 35.19289336885725, 35.85894421168736, 34.6293180329459, 35.99869680404663, 34.7107960837228, 35.16711207798549, 35.21630184991019, 35.02544525691441, 39.321380955832346, 44.27538054330008, 45.117123535701204, 43.615127972194124, 46.494600432259695, 43.428739070892334, 43.21952881131853, 40.322136947086875, 39.26487125669207, 38.37755502973284, 41.4428049496242, 46.78106076376778, 48.732173987797324, 44.95865249633789, 44.997117723737446, 45.81529937471662, 46.42481967381069, 48.06519208635603, 48.63401678630284, 48.37519986288888, 46.47621897288731, 39.71942588261196, 33.44597380501883, 34.69216448920113, 35.85372611454555, 35.29492766516549, 37.381527287619456, 36.765878677368164, 35.59542335782732, 34.857128620147705, 35.87289272035871, 35.389339787619456, 35.88760553087507, 35.97501039505005, 36.26240178516933, 35.060540607997346, 34.72961875370571, 35.75763947623116, 35.73028441837856, 35.1614944594247, 34.51214708600725, 35.9784323828561, 35.860382488795686, 36.56949131829398, 37.41437489645821, 35.95624678475516, 35.87201377323696, 36.349632944379536, 35.61361721583775, 35.08669362749372, 35.44312579291207, 35.06905909946987, 34.42239720480782, 36.01409748622349, 43.969079630715505, 46.471028668539866, 47.58746174403599, 47.698806626456125, 46.25576305389404, 46.38426651273455, 45.95534379141671, 44.68131167548043, 47.09621715545654, 47.104624475751606, 46.8670516695295, 49.77787440163748, 47.73366921288626, 49.879286834171836, 48.62570326668875, 48.02018860408238, 49.5639636857169, 51.82495961870466, 46.66984094892229, 14.768630606787545, 0.39604243423257557, 1.8212244680949619, 4.485514257635389, 2.8991284796169827, 0.13908886297472886, 0.9833186183656965, 45.18155765533447, 52.801813806806294, 40.62390416009085, 31.302940913609095, 30.246286664690288, 42.22465099607195, 51.87599066325596, 29.999754156385148, 0.1747482937893697, 0.043469972775450776, 0.06518989907843725, 0.07823514193296432, 0.04826895579961794, 0.061732769943773746, 0.013540128977703196, 0.038064264093658755, 0.043180021191281934, 0.015284070844895073, 0.016418264180954014, 0.03606753570160695, 0.09479660075157881, 0.12974535434373788, 0.08555874680834157, 0.1070809547922441, 0.10415959012295518, 0.1892731636762619, 0.12607621694249765, 0.20538622619850294, 0.10407838305192334, 0.1532476767897606, 0.19833076479179518, 0.1841168539332492, 0.21904476971498557, 0.13606296320046696, 0.16055830807558127, 3.044877584491457, 36.65272031511579, 53.47631713322231, 52.866633551461355, 38.19881609507969, 33.674110957554404, 43.43161562510899, 54.09810447692871, 53.18843936920166, 52.11197928019932, 4.7881743141583035, 0.597856770668711, 2.3913463098662238, 8.320757031440735, 8.865001610347203, 4.104669162205287, 3.8148263607706343, 42.11721447535923, 53.460360595158164, 49.150851590292795, 51.07617310115269, 49.46336766651699, 52.37209899084908, 49.618513992854524, 47.963522570473806, 47.44881738935198, 49.36283418110439, 47.74574170793806, 48.0880377633231, 46.91894429070609, 48.49299962180001, 47.42356068747384, 46.28890943527222, 45.267079557691304, 47.549152851104736, 47.49067333766392, 45.34666422435215, 48.54517364501953, 43.72966207776751, 44.101977825164795, 45.94572401046753, 46.06467022214617, 48.37593289784023, 46.797913619450156, 43.36866841997419, 45.14967932019915, 36.63335568564278, 33.52148682730538, 36.16666603088379, 36.52166339329311, 34.848234925951274, 38.27741411754063, 38.21282713753836, 36.98471219199044, 38.761960642678396, 36.35759210586548, 39.45946250643049, 35.11782850537981, 36.32899679456438, 36.62360388892037, 38.17104761941092, 41.37869044712612, 47.31595393589565, 47.071453775678364, 45.79476397378104, 49.88476201466152, 45.31858307974679, 46.121468271527974, 42.32108504431588, 41.25482838494437, 39.07494919640677, 44.07882295336042, 46.79855285372053, 50.26368202481951, 45.565119062151226, 45.77717808314732, 45.02144684110369, 48.54428080150059, 49.674846512930735, 50.895856925419395, 49.03625842503139, 47.62479441506522, 42.09870794841221, 37.40004423686436, 36.199454580034526, 38.551423277173726, 38.10224308286394, 40.490675926208496, 39.329249790736604, 36.69212007522583, 36.404992716653005, 37.19968250819615, 36.52140283584595, 37.49095794132778, 37.87035042898995, 38.757465158190044, 35.99653244018555, 35.29325662340437, 38.59862239020211, 38.29702540806362, 37.28231743403843, 34.665087359292166, 38.60680389404297, 38.486652169908794, 39.12362827573504, 39.31653806141445, 37.80281046458653, 37.61765834263393, 38.34500271933419, 37.536694458552766, 37.10969986234392, 36.97593661717006, 35.99463905606951, 36.574876172201975, 37.89734765461513, 45.2145859173366, 49.1018876348223, 48.93926852090018, 50.10350867680141, 48.22412518092564, 49.30858959470476, 47.02757242747715, 44.691487312316895, 46.41917773655483, 47.29649550574166, 46.991070066179546, 50.898379121507915, 50.690627983638215, 54.188302516937256, 50.03335618972778, 51.329059737069265, 52.00175653185163, 52.97123173304966, 48.84144483293806, 16.13477325439453, 0.8504726439714432, 3.3614993946892873, 7.566652536392212, 6.114870301314762, 0.4755832403898239, 1.4037779995373316, 51.522577490125386, 56.76128298895699, 45.78929921558925, 43.80747842788696, 41.06560114451817, 48.90118891852242, 60.193995339529856, 36.35939168930054, 0.3844808489084244, 0.12854541944605963, 0.20836210437119007, 0.155979309497135, 0.06295430261109557, 0.141618726508958, 0.12452655152550765, 0.14520230064434664, 0.1707296972828252, 0.15168638128255094, 0.06735114846378565, 0.16179021554333822], [0.013847828493453562, 0.010087232205218502, 0.04236590130520718, 0.03269008354150823, 0.029627458059362004, 0.014879628350692136, 0.05748469289392233, 0.04818859011200922, 0.030254041044307605, 0.01362043698983533, 0.057524251485509534, 0.019722892570176294, 0.05488334908815367, 0.028313958451950123, 0.06610796374401876, 0.3463568703404495, 15.68511884553092, 38.34191077096121, 47.31433847972325, 24.040357181004115, 24.855215856007167, 35.570232663835796, 46.095339570726665, 44.4864216532026, 44.710619177137104, 7.515437364578247, 0.2625832270298685, 0.43628884319748196, 1.653908046228545, 7.091951174395425, 3.728590096746172, 0.19185266883245536, 25.047797339303152, 48.006594453539165, 45.71059349605015, 44.093393325805664, 43.59046881539481, 45.739150592258994, 47.28844601767403, 47.25389610018049, 47.772158758980886, 47.098843574523926, 45.695564542497905, 46.07276487350464, 43.4041667665754, 41.64260040010725, 42.28647606713431, 42.566022941044395, 43.844001633780344, 44.138730321611675, 43.97425256456648, 43.878082547869, 41.98608807155064, 40.15778773171561, 43.27614968163626, 41.61246606281826, 42.913901873997276, 41.02314417702811, 41.93935448782784, 42.82149083273751, 45.141032287052695, 38.712319237845286, 33.77524546214512, 31.167270387922013, 33.74583721160889, 35.117050307137625, 33.58270393099104, 33.61513464791434, 32.19609015328543, 34.083269527980256, 33.82252447945731, 33.37473045076643, 32.950563771384104, 33.37001609802246, 33.8344406400408, 34.15444687434605, 36.566045011792866, 41.14806931359427, 41.629364081791465, 43.03839274815151, 42.40573147365025, 45.01903581619263, 42.309068134852815, 41.99699674333845, 38.35890259061541, 38.41146223885672, 38.60576861245291, 45.96386228288923, 47.70610570907593, 47.12761606488909, 43.157078402382986, 43.6130747795105, 43.82976130076817, 43.9082099369594, 48.02991608210972, 46.52794483729771, 43.58756446838379, 36.96669551304409, 35.41453742980957, 32.03298813956124, 33.915804045540945, 35.3932273047311, 37.54459803444998, 35.40864188330514, 34.730935437338694, 33.5027232170105, 34.638176986149375, 32.69822951725551, 33.36788994925362, 34.537403787885395, 34.88415363856724, 33.80572720936367, 32.38191625050136, 33.6840364592416, 33.582717827388215, 33.363279819488525, 33.72133091517857, 33.65983240944998, 36.88939332962036, 34.86472647530692, 35.00663300922939, 35.26334115437099, 34.06459624426705, 34.211741719927105, 31.84869064603533, 33.16430425643921, 32.229045459202354, 33.539295060294016, 33.62079395566668, 34.54953186852591, 36.96827275412423, 44.473154067993164, 46.14333772659302, 46.57202420915876, 44.88930600030081, 46.89206518445696, 46.25127451760428, 47.50922155380249, 48.696675641196116, 49.07381691251482, 45.986940724509104, 49.272549288613455, 47.423310552324565, 48.147639410836355, 47.73440224783761, 49.47386986868722, 49.76051432745797, 48.412542956215994, 34.189893109457834, 8.962245992251805, 0.17496866839272635, 1.4245137040104185, 2.8356045739991322, 0.8424341753125191, 0.042874938276197226, 2.048763858420508, 42.35279662268502, 49.48109252112252, 36.25837877818516, 26.681112119129725, 25.08030448641096, 40.03391177313668, 44.658577169690815, 14.800144161496844, 0.02058730716817081, 0.005322410026565194, 0.014086790715477296, 0.07466611558837549, 0.09774301693375621, 0.0423367242994053, 0.09244692219155175, 0.02348081288593156, 0.02739026873106403, 0.04733940014349563, 0.00893489908360477, 0.06099576556256839, 0.04206774623266288, 0.03361816677664008, 0.051420411693730524, 0.055941100365349224, 0.03189998718776873, 0.04085517022758722, 0.04127730382606387, 0.017456336246271218, 0.03421640735385673, 0.02852813633424895, 0.07711334712803364, 0.016527917136305144, 0.05207744733031307, 0.08157354101006474, 0.030062365079564706, 0.434027258838926, 22.607437133789062, 44.90686757223946, 51.195227009909495, 29.28557661601475, 30.09913076673235, 40.28248010362898, 49.99326508385794, 47.91684457233974, 48.3065516608102, 6.916528701782227, 0.08760374278894492, 0.19049843507153646, 4.204151298318591, 5.413776653153556, 2.164488060133798, 0.6920190293874059, 26.525524582181657, 51.59644031524658, 45.814535072871614, 47.18100254876273, 45.53505768094744, 48.96276038033621, 48.08002301624843, 49.69873441968645, 47.966489451272146, 48.99856097357613, 46.527135372161865, 46.66129119055611, 45.802719661167686, 43.941467489515034, 43.40283966064453, 45.09387138911656, 45.843255451747346, 45.90564680099487, 44.68759284700666, 44.63954952784947, 43.40879079273769, 42.57132094247, 43.94936759131295, 41.84769037791661, 43.48188584191458, 43.05804225376674, 43.927887235369, 45.078950132642476, 45.47719655718122, 38.70458936691284, 34.45919139044625, 33.42544535228184, 33.956923484802246, 35.32048313958304, 35.39736148289272, 34.237074851989746, 34.489673137664795, 35.998408453805105, 35.61947454724993, 34.417839186532156, 35.029232025146484, 34.79734979357038, 34.34511934007917, 34.24371385574341, 38.158266408102854, 42.442122663770405, 43.18528808866228, 44.3711371421814, 44.62819617135184, 46.06437144960676, 43.39545372554234, 43.480610847473145, 40.94761378424508, 40.50718484606062, 40.45283603668213, 47.91898461750576, 49.076505865369526, 48.10384144101824, 44.61283370426723, 46.41005475180489, 46.15151923043387, 48.31219359806606, 47.31791680199759, 48.894546440669465, 45.877642086574006, 39.12650830405099, 35.325951371874126, 34.3577025277274, 35.362009048461914, 37.37622233799526, 38.77264697211129, 36.57059260777065, 36.92136199133736, 35.70798070090157, 34.761521407536094, 34.34425776345389, 34.466698919023784, 35.708001545497346, 35.38033144814627, 35.160424436841694, 33.72728204727173, 35.34075450897217, 36.85659088407244, 34.16367060797555, 35.88142163412911, 36.66422653198242, 38.057083266122, 36.83318240301949, 35.856019020080566, 36.35855443137032, 36.443822724478586, 35.768044403621126, 33.29203299113682, 35.177885259900776, 33.557704312460764, 34.91564634868077, 35.15847199303763, 36.305973938533235, 38.05269200461251, 47.09444189071655, 48.295003754752024, 48.79642398016793, 46.94035863876343, 49.860696928841726, 48.29279770169939, 48.7987551007952, 49.406684262411936, 49.39632102421352, 48.39172615323748, 50.60197939191546, 49.14704050336565, 49.61598137446812, 49.81145851952689, 50.13229506356375, 51.56061887741089, 51.07527330943516, 35.09000791822161, 9.627152119364057, 0.2437520617885249, 2.2846074317182814, 3.8726905243737355, 2.030356994697026, 0.010947444975110037, 1.9915625963892256, 46.76347139903477, 51.945083550044465, 43.130102021353586, 30.40662329537528, 27.29069321496146, 44.56743764877319, 50.67873614174979, 19.858469213758195, 0.0726868085829275, 0.03751801286957093, 0.045871983348791084, 0.0260930353043867, 0.009592505537771752, 0.023700936431331292, 0.05271663410323007, 0.027284936347444142, 0.0654326653374093, 0.009287333564965852, 0.004951548654519553, 0.034516489465854, 0.1320586023586137, 0.08726343712104218, 0.08535257394292525, 0.14320316006030354, 0.124541737139225, 0.23681501831327165, 0.1097040151112846, 0.12481141409703664, 0.16166153816240175, 0.09095584148807184, 0.17978097445198468, 0.10113144439778157, 0.16318319365382195, 0.18264608856822762, 0.14476433343120984, 0.5610043395842824, 28.684861421585083, 54.56788955415998, 56.91780505861555, 36.324720178331646, 34.002757276807515, 45.960450717381065, 55.148835386548726, 51.44442415237427, 52.49297332763672, 9.226840342794146, 0.4301803452627999, 2.462171035153525, 6.5565520865576605, 12.681925892829895, 7.3078773021698, 1.2678741663694382, 31.148107256208146, 54.126817907605854, 47.924560546875, 49.247045925685335, 47.41950641359602, 50.25510447365897, 51.18323789324079, 50.944866044180735, 49.43571036202567, 50.00841563088553, 48.3757209777832, 49.469537666865754, 47.26234858376639, 46.87099824632917, 45.63461494445801, 47.03924192701067, 47.89221668243408, 48.04250969205584, 46.840405327933176, 45.52746329988752, 44.57060950142996, 43.02700465066092, 46.557877676827566, 43.73683261871338, 43.41311604636056, 42.734113761356895, 45.37924085344587, 46.56309577396938, 47.7657664162772, 41.71233599526541, 37.040523597172324, 35.61318990162441, 36.856372015816824, 38.72916514532906, 38.005784715924946, 37.02246175493513, 35.43937029157366, 37.443519115448, 38.01114525113787, 36.45865018027169, 36.486508982522146, 37.18337161200387, 36.53116505486624, 37.13000249862671, 39.082088470458984, 44.56104530606951, 45.65778718675886, 46.46112053734915, 45.60850361415318, 50.308303356170654, 45.032119274139404, 45.88342646190098, 41.9160224369594, 42.96267127990723, 42.02350412096296, 49.64404167447771, 52.11265325546265, 50.5817323412214, 44.83150741032192, 47.42183058602469, 48.17597763878958, 48.98806571960449, 49.11686447688511, 50.25503499167306, 48.41703149250576, 40.64644411631993, 38.47289821079799, 36.6663179397583, 36.23482091086251, 38.94819668361119, 40.25728593553816, 37.774972506931846, 38.089673791612896, 37.82484320231846, 37.16571623938424, 36.647335461207796, 35.67469882965088, 37.63142619814192, 38.0498606136867, 36.54138585499355, 35.39722946711949, 37.64656979697091, 39.128155027117046, 35.98471702848162, 37.648831435612266, 38.29516329084124, 39.677882603236604, 38.5538204056876, 38.49297155652727, 39.12666811261858, 39.147592612675254, 38.07587466921125, 34.45474106924874, 37.88962820598057, 34.8206227847508, 37.08801106044224, 37.48734835215977, 37.384664399283274, 39.50009209769112, 49.335826533181326, 50.86728940691267, 50.7211583682469, 48.97402688435146, 51.07760443006243, 50.81392724173409, 50.33740241186959, 51.78408684049334, 52.34121077401297, 49.436172417231965, 50.66740015574864, 51.22431564331055, 50.61767189843314, 51.40632370540074, 51.87933622087751, 53.08392456599644, 52.015006746564595, 37.78963668005807, 10.64067803110395, 0.6809367069176265, 4.799107304641178, 6.968044817447662, 3.846289106777736, 0.22290975946400846, 2.8424426870686665, 51.45502015522548, 58.091244629451204, 48.11723061970302, 38.94279098510742, 34.73194292613438, 51.94340556008475, 58.83930506025042, 26.1291298525674, 0.1518961978810174, 0.07244173530489206, 0.13399336354008742, 0.16325518621930055, 0.07695490241582904, 0.10184851342013904, 0.17908762022852898, 0.0840305977367929, 0.17518537890698227, 0.12830534018576145, 0.09288742034030811, 0.1076854480696576], [0.026204292995056937, 0.03775193103189979, 0.0508372142378773, 0.045247846482587714, 0.013401206566153892, 0.03423015108065946, 0.061773590610495636, 0.029015572142920325, 0.03941003991557019, 0.10389304121157952, 0.04581227565982512, 0.03751366685277649, 0.02332828499908958, 0.028428099916449616, 0.06096094314541135, 0.08726092654147319, 13.304721593856812, 44.08669178826468, 52.57700831549508, 30.769107341766357, 22.226840870721, 34.51060806001936, 43.428798130580354, 46.41154861450195, 48.074099676949636, 12.69058769089835, 0.11206020760749068, 0.3644672142607825, 3.6618435297693526, 3.718760132789612, 1.1351982057094574, 0.08559057688606636, 19.70307101522173, 57.894447326660156, 45.39249454225813, 46.15851954051426, 40.38129390989031, 44.50111014502389, 43.16179970332554, 46.579563004629954, 43.7590286391122, 44.91043894631522, 42.287202153887065, 43.067467485155376, 41.169073717934744, 42.70701231275286, 41.77205228805542, 45.51136779785156, 44.48874582563128, 46.0290641784668, 46.00220591681344, 44.36954600470406, 41.402724266052246, 45.89079850060599, 45.01763228007725, 44.464562620435444, 43.467499596732004, 46.38892527988979, 43.054064410073416, 39.55743210656302, 43.47633423124041, 41.47565950666155, 32.46697609765189, 33.47953707831246, 32.21025405611311, 34.402362074170796, 32.310846601213726, 33.07748304094587, 34.522524220602854, 35.85261787687029, 33.004030159541536, 34.695638588496614, 32.336443764822825, 33.57331691469465, 33.164300782339915, 34.24872350692749, 32.73260572978428, 37.01413433892386, 40.21381800515311, 43.417222431727815, 43.81033066340855, 45.62273352486746, 44.866526331220356, 41.70353610174996, 40.659544944763184, 40.0737874848502, 39.29369238444737, 44.772555419376914, 46.887764249529155, 45.234426498413086, 44.32854468481881, 40.51579366411482, 45.10401228496006, 46.56781360081264, 47.67895562308175, 44.8189937046596, 42.32786301204136, 35.03558962685721, 33.32542255946568, 33.25101430075509, 32.855234486716135, 33.84777423313686, 35.37641961233956, 32.78051355906895, 33.27080624444144, 34.6672100339617, 34.32273571831839, 33.358753068106516, 34.97429609298706, 35.136515685490195, 33.713548932756694, 34.98174803597586, 32.55415167127337, 32.52780410221645, 32.721599783216206, 33.651963574545725, 33.468951497759136, 33.71380601610456, 33.53265953063965, 36.933559553963796, 38.686068943568635, 42.78172281810215, 42.05854736055647, 41.132175309317454, 36.66171128409249, 34.40060417992728, 32.3704378264291, 34.112149715423584, 32.4413719858442, 33.45835896900722, 32.76396642412458, 38.5206948689052, 43.89123201370239, 44.49022579193115, 44.34554345267159, 44.25313588551113, 44.87731340953282, 43.63229349681309, 45.67715876443045, 46.38947071347918, 48.604764870234895, 49.304535320826936, 48.04204068865095, 50.32573291233608, 48.89529684611729, 47.5633202280317, 46.88707985196795, 47.33610371180943, 21.548991986683436, 3.35223679457392, 0.36919967031904627, 1.0587546676397324, 3.068952658346721, 1.9763807824679782, 0.07056588453373738, 2.7538616231509616, 45.84220627376011, 47.730740547180176, 37.38429961885725, 21.559622730527604, 22.627296822411672, 40.07891525541033, 37.534120150974815, 11.956386310713631, 0.07035313666399036, 0.09344748993005071, 0.03647489420005253, 0.024951391653823, 0.08345084384615932, 0.03923068614676595, 0.038945803219186406, 0.005176232803413379, 0.014630103882934366, 0.02046618188199188, 0.04725061044363039, 0.016916317366329685, 0.010778289587636079, 0.04065782849543861, 0.021191749555457915, 0.07789636296885354, 0.017889901463474547, 0.020499467417331677, 0.02000800789599972, 0.007987931370735168, 0.009100392078315573, 0.02842804224097303, 0.04963620046951941, 0.0277459228610886, 0.058980937248894146, 0.02604212991095015, 0.033669623479779275, 0.1519239228218794, 17.509858233588083, 50.90410443714687, 57.927381787981304, 32.736131940569194, 27.21475808961051, 36.856785433632986, 50.70516014099121, 46.89159618105207, 52.10906451089041, 13.431342959403992, 0.11431100325925009, 0.4632375399981226, 4.628821722098759, 6.256651767662593, 2.166595752750124, 0.2907613478600979, 22.15563746861049, 59.7398749760219, 46.17740821838379, 47.46124076843262, 41.67665352140154, 47.06835487910679, 44.85550301415579, 48.97909906932286, 44.84349652699062, 47.60156658717564, 44.49251174926758, 44.76491240092686, 42.28192499705723, 43.25925861086164, 42.45033890860421, 46.69155059541975, 45.291742188589915, 46.04835932595389, 48.22327402659825, 44.48778697422573, 41.86000605991909, 46.10060977935791, 46.04224838529314, 46.31881100790841, 45.69351829801287, 46.00244910376412, 43.81757068634033, 41.35491023744856, 45.477516174316406, 43.302445139203755, 33.61555848802839, 35.348119599478586, 34.49911573954991, 35.98356015341622, 33.52720519474575, 35.57143817629133, 34.78254665647234, 36.796982288360596, 35.62375463758196, 35.237118652888704, 34.176781858716694, 34.83634655816214, 35.09179360525948, 35.137596130371094, 35.14315468924386, 39.80481924329485, 41.14949369430542, 45.94924674715315, 45.027926036289756, 44.76869222096035, 46.36564186641148, 43.48792382649013, 43.034633772713796, 42.03383609226772, 40.1926920073373, 46.49402720587594, 48.78397280829293, 46.97245931625366, 45.470498493739534, 42.64184863226754, 47.46641717638288, 47.67328936713082, 49.858122621263774, 48.19681876046317, 43.52182756151472, 37.11349357877459, 35.016839912959504, 35.60585260391235, 35.54479878289359, 37.39596911839077, 37.023184367588584, 34.683548722948345, 35.3051449911935, 36.03455993107387, 35.69699559892927, 35.513934884752544, 35.954151902879985, 37.26952232633318, 34.02017641067505, 36.08628579548427, 33.87227010726929, 35.87378556387765, 34.463002477373394, 35.203979219709126, 35.033202920641216, 34.84442731312343, 35.61174815041678, 38.13331890106201, 40.52607352393014, 43.38690744127546, 44.390515668051584, 42.16059902736119, 37.21738304410662, 35.33921548298427, 34.14142942428589, 35.15201016834804, 33.54665320260184, 34.5579947744097, 34.737598759787424, 40.574575424194336, 45.68649019513811, 47.66031013216291, 46.09579815183367, 46.23027358736311, 47.30352013451712, 46.957447733197895, 47.853782721928184, 47.76064559391567, 48.68180649621146, 50.806197370801655, 49.560350622449604, 50.23242555345808, 51.260057176862446, 48.98954568590437, 49.541750294821604, 48.23743792942592, 25.581622225897654, 4.570948438985007, 0.5193357212202889, 2.3281776309013367, 3.7879112107413153, 2.6883081921509335, 0.053613263847572465, 3.4952365841184343, 50.79850918906075, 51.47162982395717, 42.89794533593314, 26.660291842051915, 27.2491968359266, 46.67911679404122, 45.336846419743125, 15.507554156439644, 0.05103811149352363, 0.03067738582779254, 0.037902196004454575, 0.059609023188906055, 0.024614017257200818, 0.021748526554022516, 0.019062940929351107, 0.07248296309262514, 0.02229694739383246, 0.03927916068849819, 0.02057903752263103, 0.0646747960043805, 0.15345633987869534, 0.09026367470089879, 0.18581655701356276, 0.14018327210630688, 0.08009565102734736, 0.0766973305227501, 0.16314625420740672, 0.12114383732633931, 0.09546059476477758, 0.19713218696415424, 0.15841884644968168, 0.16541116338755402, 0.1610053133751665, 0.13533884419926576, 0.130436686532838, 0.2613951393536159, 21.487311090741837, 57.272521018981934, 61.590110778808594, 40.27227667399815, 34.385828835623606, 43.107641969408306, 54.29460300718035, 53.86250148500715, 58.16481563023159, 16.326685973576136, 0.2355934110070978, 1.900741389819554, 10.116998382977076, 11.519170045852661, 4.677631514413016, 0.7188706142561776, 23.922795397894724, 62.1850711277553, 48.24980224881853, 50.32877622331892, 43.83802965709141, 49.172998973301475, 46.02863686425345, 51.199531418936594, 47.060315813337056, 48.57014547075544, 46.24048743929182, 46.346207754952566, 43.71000214985439, 46.932336943490164, 45.89206307274954, 49.99344226292202, 46.48226390566145, 49.289940629686626, 50.617585045950754, 45.33185066495623, 44.54741988863264, 48.38039364133562, 48.24593210220337, 48.11897809164864, 46.83065700531006, 49.61104120526995, 44.546190057482036, 43.15908990587507, 46.56035818372454, 45.43266555241176, 35.66287299564907, 38.52059759412493, 35.85830497741699, 38.638442516326904, 35.09411430358887, 37.28121614456177, 37.28943586349487, 37.980521065848215, 37.021746090480256, 36.59884398324149, 35.182495389665874, 36.8938193321228, 38.19810390472412, 37.45101274762835, 36.29457194464547, 40.02567120960781, 43.125742026737754, 49.83607598713466, 47.5746214730399, 48.35582481111799, 49.134172439575195, 45.33029079437256, 45.252321583884104, 42.97450406210763, 42.4813244002206, 47.91728925704956, 50.544496944972444, 48.157498904636924, 45.239040102277485, 42.70600829805647, 48.364635126931326, 50.55804245812552, 50.90606382914952, 48.22125904900687, 45.87792348861694, 38.68745510918753, 36.14105844497681, 38.722359384809224, 36.492175238473074, 37.84363807950701, 37.967527934483115, 35.1890857560294, 36.57178769792829, 38.27624682017735, 36.78016069957188, 36.791048526763916, 38.29721648352486, 38.857196126665386, 36.237714835575645, 38.05540527616228, 34.617127418518066, 36.205857345036094, 35.96481391361782, 36.90487044198172, 36.31150123051235, 36.95786435263497, 37.87428658349173, 41.38107367924282, 43.18914086478097, 46.89143637248448, 46.66559559958321, 45.37016303198678, 39.69339793069022, 38.22111286435808, 35.26984119415283, 37.64577770233154, 36.155951908656526, 37.61079004832676, 36.69320052010672, 43.78773512159075, 47.61528580529349, 49.650218623025076, 46.89255503245762, 46.89738055637905, 48.3072395324707, 47.9794374193464, 48.75460277284895, 49.93697772707258, 52.7450852394104, 53.658165386744905, 51.83083779471261, 54.46908269609724, 52.619392326899934, 51.277264390672954, 50.01346002306257, 49.972854750497, 26.756515707288468, 5.494734457560948, 0.7806210464664868, 4.347034054143088, 10.15042269229889, 4.852941078799112, 0.27211140575153486, 3.8107234495026723, 56.54317208698818, 55.986381667000906, 46.71817609242031, 33.081714493887766, 36.01832546506609, 51.67244665963309, 52.324955463409424, 20.383079051971436, 0.11597359047404357, 0.1859936953655311, 0.07943603356501885, 0.13284320597137722, 0.17941966812525476, 0.13528317718633584, 0.14677952815379414, 0.1276738547853061, 0.15079298136489733, 0.150726674922875, 0.11745770940823214, 0.1874905571873699], [0.04245059604623488, 0.03602535457217267, 0.021689202237342085, 0.021872703551447818, 0.03684584929474762, 0.010857876656310899, 0.020290795846709182, 0.01723670294242246, 0.015543703788093157, 0.06551212178809301, 0.031139006771679436, 0.04148316117269652, 0.0870187913200685, 0.05650443710120661, 0.06992863158562354, 0.05329322941335184, 7.412138496126447, 40.23820965630667, 49.70278869356428, 35.08960492270333, 27.99908290590559, 42.404887267521445, 41.01521280833653, 44.58860533578055, 47.44181707927159, 19.836542436054774, 0.27332476207188194, 0.37881562433072496, 4.198927990027836, 2.6240879467555454, 1.4775042491299766, 0.04804198244320495, 15.13150896344866, 60.57447869437081, 43.10089179447719, 48.253036635262625, 42.02233682359968, 44.22890056882586, 41.649079595293315, 44.34163161686489, 41.180093560900005, 43.04241228103638, 39.68175622395107, 40.39239018304007, 38.83272109712873, 43.03913273130144, 42.770088059561594, 44.38744109017508, 46.9864946774074, 46.3178208896092, 44.88864592143467, 42.11530024664742, 44.359078543526785, 45.853125367845806, 42.236890247889924, 43.27613231113979, 44.71278701509748, 45.77945361818586, 43.368387017931255, 43.28440414156233, 44.27025277273995, 44.29606185640608, 33.194184984479634, 32.725000926426475, 32.56270490373884, 33.06006390707833, 32.32783147266933, 34.84655346189226, 33.35559163774763, 36.913878781454905, 34.114491258348735, 33.975162506103516, 32.658458028520855, 33.508552755628315, 34.083054133823936, 35.85771785463606, 32.95753976276943, 34.25513669422695, 35.86655248914446, 40.70913771220616, 42.142512866428916, 46.446974005017964, 44.108964238848, 42.60067708151681, 41.55423321042742, 41.011797768729075, 40.10142394474575, 44.2837427003043, 47.01981128965105, 48.928634302956716, 42.960704939705984, 38.080516065870015, 47.127758502960205, 45.81968368802752, 45.909774030957905, 45.38032129832676, 41.208101749420166, 34.99227455684117, 33.3311721937997, 31.71961396081107, 33.250788484300884, 33.516636984688894, 35.991529737200054, 35.09403439930507, 34.61438635417393, 33.92350264957973, 33.19862140927996, 33.4494583266122, 34.485823835645405, 34.22444997514997, 34.8207756451198, 33.36953319822039, 33.43988023485456, 33.19530711855207, 34.0540315083095, 35.92744650159563, 35.264630045209614, 33.06665774754116, 36.99354682649885, 44.80150508880615, 46.43258081163679, 45.910725934164866, 45.89187547138759, 45.409993580409456, 43.83275597436087, 41.666641167231965, 33.244177273341585, 32.71242816107613, 32.39188691547939, 32.872469493321006, 32.91084439413888, 35.31070007596697, 37.37640299115862, 41.36890043531145, 40.425553934914724, 42.80696562358311, 42.20484863008772, 42.03778961726597, 42.357441493443076, 43.45256791796003, 46.0181485584804, 46.08122430528913, 44.80351659229824, 46.6474677494594, 46.528309617723735, 47.010903699057444, 48.63136257444109, 42.01192842211042, 13.32826817035675, 0.19537901532437119, 0.486687818808215, 0.9832003904240472, 1.5551803324903761, 1.099991140621049, 0.04997272669736828, 4.825988582202366, 48.919327190944124, 43.28744397844587, 35.15871517998831, 27.777494430541992, 34.101696150643484, 38.68561731066023, 39.15790721348354, 6.3238886169024875, 0.09488833868610007, 0.009438204130024781, 0.018468493362888694, 0.054079098493925164, 0.02674045949243009, 0.05552027973213366, 0.021549975333203162, 0.029820270570261136, 0.03982755269056984, 0.05304446829749005, 0.03697150380217603, 0.1257652307727507, 0.04773465696988361, 0.038150376972875426, 0.03590534208342433, 0.03430016910923379, 0.01945628259064896, 0.01772949069605342, 0.035000444389879704, 0.015706374077126384, 0.028176229413864867, 0.007970800057851841, 0.06003183192972626, 0.025442998756521513, 0.03404767944344452, 0.03669654105656913, 0.05617962238777961, 0.0327564171249313, 10.278037650244576, 47.49063859667097, 55.92011322293963, 40.86657346997942, 27.20564900125776, 41.62734563010079, 44.99302176066807, 50.49185044424874, 51.60790136882237, 22.01726930482047, 0.07558661619467394, 0.1787946152367762, 4.219300542558942, 6.320056685379573, 3.3703186128820692, 0.24635503068566322, 18.476166793278285, 61.089381899152485, 46.19981268474034, 48.77272367477417, 42.64197369984218, 44.587427616119385, 43.69404213769095, 47.872890268053325, 43.76908268247332, 45.356398650578086, 40.85491091864449, 41.99398469924927, 40.370381764003206, 43.70857776914324, 45.6531423160008, 45.49942037037441, 47.906477860042024, 45.91727113723755, 45.97133159637451, 42.70371886662075, 45.56548384257725, 46.45420707975115, 45.02838461739676, 45.07965537479946, 45.20871121542794, 47.98383910315377, 46.024193491254536, 45.622351373944966, 45.306791986737935, 45.653725964682444, 34.748410156794954, 34.1711642401559, 33.6283084324428, 34.92136124202183, 34.60978317260742, 34.677469049181255, 35.13359744208199, 38.134305545261924, 35.3600183895656, 35.00807128633772, 35.746709959847585, 34.10334634780884, 35.23675387246268, 35.28279958452497, 34.93502140045166, 35.68248776027134, 39.815463883536204, 41.396265915461946, 44.353085722242085, 47.140730789729524, 45.73449877330235, 45.288167340414866, 44.19539982931954, 42.18399361201695, 42.13401869365147, 45.9726448059082, 49.251350334712434, 48.50242485318865, 44.30077273505074, 41.372520446777344, 46.7508430480957, 47.24066325596401, 46.71139465059553, 47.133803435734336, 41.20896332604544, 36.25256313596453, 34.67654146466936, 33.21755525044033, 34.14181157520839, 36.09464795248849, 36.45429713385445, 38.180399894714355, 35.13737726211548, 35.65401751654488, 36.00467572893415, 35.19395644324166, 35.83067546572004, 36.17523315974644, 36.216578415461946, 36.38027102606637, 35.121097632816856, 34.5029650415693, 35.23771619796753, 36.85844257899693, 36.07094417299543, 34.10988460268293, 38.322198731558665, 47.37474264417376, 48.16216114589146, 48.53634595870972, 46.806310517447336, 47.76457480021885, 44.76750407900129, 41.22136238643101, 34.97385140827724, 34.98736218043736, 33.29709822790963, 33.90751484462193, 35.76286104747227, 37.02881588254656, 41.06395789555141, 43.17495264325823, 42.086003167288645, 44.58315447398594, 45.31035988671439, 44.91028956004551, 45.17386599949428, 46.36709751401629, 48.01359476361956, 47.875933579036165, 45.95649719238281, 48.09567035947527, 48.71807261875698, 49.779204981667654, 50.06851407459804, 44.44498954500471, 15.409515074321202, 0.5604813790747097, 1.4128015381949288, 3.995136022567749, 5.227945779051099, 2.6669581149305617, 0.03333527534934027, 5.373394157205309, 52.618819100516184, 47.604377133505686, 38.63341549464634, 28.471336330686295, 37.02068649019514, 44.66279820033482, 46.206451688494, 8.62024176120758, 0.04105881555005908, 0.06599343381822109, 0.02979986702225038, 0.014352259059835757, 0.027825550641864538, 0.02782385260798037, 0.026511080729375993, 0.06643691073570933, 0.024003179677362953, 0.03718768845179251, 0.005285182626851435, 0.06795458322657005, 0.12758465457175458, 0.07782126271298953, 0.11637108985866819, 0.12092475193951811, 0.11406810129327433, 0.16370299219020776, 0.16641445883682796, 0.17236382673893655, 0.11193796952388116, 0.17321450609181607, 0.09800301798220191, 0.12686501390167645, 0.16652991835560116, 0.11974194326571055, 0.16104890246476444, 0.09724392728613955, 10.974626694406782, 54.74167442321777, 61.89236436571394, 44.823475292750764, 37.57692105429513, 51.12834712437221, 49.662103516714915, 52.53145245143345, 55.81743969236101, 25.74867081642151, 0.30675420111843515, 0.8357986999409539, 11.797731144087654, 11.926000101225716, 4.920853640351977, 0.7112016486270087, 19.39249174935477, 65.79787731170654, 46.77320235116141, 51.55838850566319, 45.2242682320731, 47.549580165318076, 45.644404956272666, 49.72192750658308, 45.77686888831002, 46.91790900911604, 42.83049917221069, 45.223972933632986, 42.14926304136004, 46.15504544121878, 46.43067700522286, 47.11333056858608, 49.97764900752476, 49.43682554789952, 46.01117256709507, 43.985929012298584, 48.57697902406965, 48.882859570639475, 45.324919836861746, 47.538664545331685, 47.19723354067121, 49.60941532679966, 47.02836799621582, 46.472442626953125, 48.176536968776155, 48.48772593906948, 36.665567534310476, 35.139656271253315, 34.93411466053554, 37.63065494809832, 35.42198937279837, 37.38192680903843, 36.98321485519409, 40.31154441833496, 36.38590948922293, 36.442207268306184, 36.418729305267334, 36.38374512536185, 37.46509674617222, 39.57008825029646, 36.53685910361153, 37.73783091136387, 40.404341084616526, 43.886173725128174, 46.284208978925435, 50.399251801627024, 49.00465454374041, 46.21515430722918, 46.926472663879395, 43.90835932322911, 45.077963488442556, 48.585872718266074, 50.56000532422747, 51.10695709500994, 44.4431482723781, 41.023279666900635, 49.72705527714321, 49.51641021456037, 47.8368638583592, 47.99597065789359, 43.97120230538504, 38.54307849066598, 37.82437767301287, 36.54109055655343, 37.672868728637695, 37.85104833330427, 39.71076495306832, 37.55817134039742, 36.49797003609793, 37.844054971422466, 37.1366970879691, 36.463972500392366, 37.61043916429792, 37.33638136727469, 38.27348838533674, 37.96395308630807, 36.93868385042463, 36.225326197487966, 36.8145820753915, 39.904602323259624, 37.936865534101216, 36.1137763432094, 41.372093132564, 50.20261778150286, 50.0095169203622, 49.612993649074006, 48.77849415370396, 49.281046935490195, 47.35531548091343, 44.416230951036724, 37.055437905447825, 36.294474669865195, 34.80853986740112, 36.1336864062718, 37.835908208574565, 39.803870814187185, 41.81215034212385, 46.868135588509695, 43.22659165518624, 45.51222242627825, 46.109600748334614, 46.833543981824604, 47.18178422110421, 48.06380244663784, 51.10105112620762, 51.043617316654746, 48.80230563027518, 51.5346291405814, 49.73291608265468, 51.42093924113682, 50.51313625063215, 46.28995166506086, 16.83940049580165, 0.9877210621322904, 1.2492943576404025, 6.249100378581455, 9.207294191632952, 6.505547097751072, 0.13916777659739765, 6.143401776041303, 59.165793963841026, 52.74269853319441, 47.14498656136649, 37.31544991901943, 44.15113980429513, 50.288289070129395, 53.626867226191926, 10.156642198562622, 0.21512902554656776, 0.1579494902065822, 0.15984276575701578, 0.15320874245039054, 0.09285694054727044, 0.1532996797135898, 0.11933292235646929, 0.09409355026270662, 0.09110914290483509, 0.14463191053697041, 0.09961342585406133, 0.21312552876770496], [0.061964347160288265, 0.007438890519551933, 0.045511060394346714, 0.015386739978566766, 0.07150258855628115, 0.03840345696413091, 0.033882873465440104, 0.05564425147271582, 0.04077594108613474, 0.012567149624893708, 0.027763647892113243, 0.07746678923389741, 0.05125790594943932, 0.03281580250976341, 0.060878073663583825, 0.026426872837224176, 3.52083374772753, 37.42930310113089, 50.382263456072124, 37.789695739746094, 29.848488398960658, 37.39711209705898, 33.6855650629316, 41.277774810791016, 47.63654729298183, 28.21907503264291, 0.8858005425759724, 0.2697351218334266, 1.7485718237502235, 4.904537533010755, 2.408220878669194, 0.157765444368124, 15.093380723680768, 51.16138580867222, 48.06757184437343, 46.481016704014365, 41.48995542526245, 40.920533180236816, 39.77128028869629, 41.30458443505423, 39.125281946999685, 39.99290003095354, 38.57424463544573, 39.28414208548409, 42.078137806483674, 44.55449315479824, 42.941941329411094, 46.24093212400164, 44.76261602129255, 44.52101673398699, 42.76729140962873, 44.624044622693745, 43.78141573497227, 41.53447253363473, 42.896288190569194, 41.86819798605782, 42.91614614214216, 43.27180010931832, 45.95069544655936, 44.55758162907192, 45.490710803440635, 41.15977702822004, 32.19831010273525, 32.19589212962559, 32.60580457959856, 32.46169546672276, 32.47684601375035, 34.58632605416434, 34.75266592843192, 35.357096672058105, 34.10792521068028, 33.38080317633492, 34.4792160987854, 33.964358057294575, 34.77974305834089, 33.43709053312029, 33.51352766581944, 34.36968469619751, 34.38979973111834, 36.08829729897635, 41.08891929898943, 44.74784762518746, 44.77186407361712, 44.792187554495676, 42.55539567129952, 43.788999693734304, 41.00408179419381, 43.97782393864223, 46.33201258523123, 48.34732716424124, 46.18697241374424, 38.689146995544434, 43.660895756312776, 43.804306575230186, 46.43189293997628, 44.35821696690151, 39.381138937813894, 32.82901545933315, 33.31585489000593, 33.052730083465576, 33.483494077410015, 33.672089031764436, 34.96506193705967, 34.31109401157924, 33.22737305504935, 33.27899122238159, 33.594449860709055, 33.23036772864205, 34.37646961212158, 34.018595695495605, 34.33980744225638, 34.643520150865825, 32.83993107931954, 33.52576344353812, 33.60434062140328, 32.662008558000835, 32.38732542310442, 34.28180388041905, 40.79938786370413, 46.79953254972185, 42.82353012902396, 41.06839779445103, 43.56315892083304, 44.887086050851, 45.62828860964094, 46.349466460091726, 41.38979714257376, 36.600018228803364, 32.97450378962925, 34.40640592575073, 32.33303219931466, 32.03646223885672, 34.75278752190726, 37.114511489868164, 36.74959557397025, 37.36121770313808, 38.26916313171387, 36.22406162534441, 36.741629464285715, 38.438966682979036, 38.92198460442679, 39.110593455178396, 40.713459491729736, 45.193890707833425, 45.8587395123073, 47.89769186292376, 49.688986097063335, 40.165475913456504, 8.4124002967562, 0.160705441609025, 0.6217571081859725, 1.9254348533494132, 2.7943824316774095, 1.6230225435325076, 0.04710159397550991, 6.894531139305659, 53.462427684238975, 40.7952641078404, 33.06841564178467, 22.414702790124075, 32.012556961604524, 39.96016706739153, 31.213062490735734, 2.0374875835009982, 0.07326472364366055, 0.029698748341096298, 0.05321176789168801, 0.08640065948878016, 0.18221673874982766, 0.05162860659350242, 0.060398410473551066, 0.025877495263037936, 0.0199545020171042, 0.028343279646443467, 0.03624441621026822, 0.023864234365256767, 0.04747711561088051, 0.07172247461442437, 0.025782115291804075, 0.10422403059367623, 0.009494812610293073, 0.012344946369661816, 0.02625533239915967, 0.015591023123956152, 0.023054791281798055, 0.03126191660495741, 0.03444778440254075, 0.03630167778049197, 0.02151533272782607, 0.043982500809111764, 0.018100167591390864, 0.060809188788490634, 4.820865588528769, 42.83374398095267, 56.6521372113909, 41.04837308611189, 33.21994195665632, 48.667983055114746, 41.38919612339565, 46.579090527125764, 50.56532417024885, 29.731873307909282, 0.812064847775868, 0.1296556791556733, 2.060415118932724, 5.495500496455601, 3.4568514781338826, 0.26584166075502125, 18.502384083611624, 55.21508993421282, 48.49268347876412, 48.844519410814556, 44.18884072984968, 43.34119176864624, 42.55605575016567, 43.61066028050014, 41.100877148764475, 42.61652939660208, 40.34673357009888, 41.704578331538606, 43.24281569889614, 44.07933712005615, 43.92402056285313, 48.74690069471087, 46.72557244982038, 45.62011752809797, 44.64581332887922, 46.462496280670166, 44.3806596483503, 43.27959598813738, 43.974353313446045, 43.55956322806222, 44.58714621407645, 45.74371903283255, 46.17861025674002, 44.85462754113333, 47.44692053113665, 43.23343563079834, 34.86245788846697, 34.291336808885845, 33.99522195543562, 34.42681973321097, 34.36021430151803, 35.772932461329866, 35.785057067871094, 35.924670696258545, 35.58466754640852, 35.01083319527762, 35.06963579995291, 35.22639063426426, 35.581655502319336, 36.01335402897426, 35.598202637263704, 36.44661242621285, 35.615920543670654, 38.142292499542236, 43.380035672869, 44.96125112261091, 48.28750664847237, 44.501728534698486, 45.60821873801095, 43.131231103624614, 43.099974632263184, 46.2830034664699, 48.42497328349522, 47.888162408556255, 45.65311452320644, 41.79306364059448, 45.69504690170288, 47.54849624633789, 48.805338518960134, 46.72210529872349, 40.77888372966221, 34.46574354171753, 34.19162321090698, 35.19315045220511, 35.59873417445591, 34.507887840270996, 35.18781076158796, 35.311971596309114, 34.81335844312395, 34.770554065704346, 35.99629967553275, 34.833014896937776, 36.986209528786794, 35.75224072592599, 34.511890002659385, 35.75411673954555, 34.093000480106895, 35.55804552350725, 34.84154033660889, 34.71849816186087, 32.96880626678467, 35.69124943869454, 43.83216537748064, 48.16483620234898, 46.0594938141959, 42.142109870910645, 44.95184326171875, 47.81510557447161, 47.90964623859951, 47.63136393683297, 43.87273938315255, 36.763092449733186, 35.559709617069785, 36.50974028451102, 35.21027428763253, 33.78047398158482, 36.41862508228847, 39.46001141411917, 39.44217191423689, 39.805507114955354, 40.11017172677176, 39.731967381068635, 39.31677082606724, 41.48921891621181, 41.52871595110212, 42.25026553017752, 42.69208410808018, 47.276786940438406, 47.882169587271555, 49.93888848168509, 50.829289708818706, 41.756929533822195, 9.423879095486232, 0.3258897571691445, 2.718977974993842, 7.262162063802991, 4.372824464525495, 2.3241053351334164, 0.07381314278713294, 7.362873162542071, 58.31427138192313, 45.2100487436567, 40.685083048684255, 26.77801169667925, 37.74977139064244, 44.573854310171946, 37.802654130118235, 2.7573422363826205, 0.06374944387269871, 0.010023487232891577, 0.09193097094872169, 0.015559666324406862, 0.02011553873308003, 0.016795768834916607, 0.001372621423797682, 0.01828031354982938, 0.05798072913395507, 0.047561172528990676, 0.014171975698055965, 0.026205845143912092, 0.17610809153744153, 0.12991250466023171, 0.20637075336916105, 0.3012003648493971, 0.20577295044703142, 0.17483199786927017, 0.15851491343762192, 0.17706087683992727, 0.13441822145666393, 0.14839271801923, 0.10110926308802196, 0.11368690031979765, 0.11934128190789904, 0.1229428236505815, 0.16117258582796368, 0.1558456788105624, 5.845622394766126, 51.144341877528596, 60.88773822784424, 48.72687251227242, 39.4906564440046, 46.87691463742937, 43.927300112588064, 50.73511382511684, 56.830549580710276, 34.89799097606114, 1.4233238250017166, 1.026581034064293, 6.635272136756352, 12.349965282848903, 7.661069869995117, 0.5397381292922157, 20.896552664893015, 55.42644371305193, 51.794144357953755, 51.67878341674805, 46.93805531093052, 43.93740626743862, 43.97201524462019, 45.425258772713796, 42.56479658399309, 43.393470014844624, 42.70503207615444, 42.80612141745431, 45.94024535587856, 47.693772656576975, 46.179805346897666, 49.19398948124477, 48.56698751449585, 45.28043746948242, 46.05739893232073, 48.153204917907715, 48.03930309840611, 44.76698643820626, 47.549767766680034, 45.44826078414917, 47.17048992429461, 46.77069405147007, 48.63632706233433, 46.61876821517944, 48.869800431387766, 45.50875527518136, 37.22628716060093, 36.42683437892369, 36.35170003346035, 36.42214434487479, 35.94521999359131, 37.42812190737043, 38.01087427139282, 38.14553730828421, 36.20930365153721, 36.15187679018293, 37.0906583241054, 38.311644417899, 38.30510268892561, 36.63122606277466, 37.039543901171, 37.59176935468401, 37.392151083265034, 39.54264286586216, 43.846822602408274, 48.11311728613717, 49.97583205359322, 46.73254149300711, 46.834631374904085, 46.04887349264962, 45.237580980573384, 48.98110362461635, 50.117248739515034, 49.94260924203055, 46.74774415152413, 43.7040753364563, 47.11559220722744, 49.00007915496826, 50.8607303074428, 47.631523745400564, 43.26175996235439, 37.69299071175711, 36.75653682436262, 36.94650752203805, 36.213774817330496, 36.52363320759365, 39.00969866343907, 36.32442487989153, 36.417760031563894, 37.56862837927682, 37.66734491075788, 36.59502942221505, 37.90345859527588, 36.94919647489275, 38.09281437737601, 38.01461240223476, 34.91695955821446, 36.392711775643484, 37.557170799800325, 35.81188406263079, 34.14228752681187, 38.2220265524728, 46.3819249698094, 48.87948274612427, 48.917843750544954, 44.895878996167866, 46.03452546255929, 49.48968744277954, 48.20229394095284, 50.84284911836897, 44.72976841245379, 39.891963550022666, 37.37035458428519, 39.71284941264561, 36.41355984551566, 35.55828523635864, 37.37025383540562, 40.998658725193565, 39.884727001190186, 41.38156700134277, 42.01967913763863, 41.08091150011335, 39.71975939614432, 43.728963783809114, 43.09060846056257, 43.217326232365195, 44.70263222285679, 49.93720701762608, 49.06865440096174, 51.2828437941415, 51.50969205583845, 45.08393546513149, 11.596212540354047, 0.5525218918919563, 2.6723510026931763, 5.988465198448726, 9.048129200935364, 6.677024296351841, 0.24084421353680746, 8.863770910671779, 63.539559909275596, 51.34773996898106, 45.026640619550435, 32.18216248920986, 44.493442807878765, 49.82231855392456, 45.23602110998971, 4.0142253296715875, 0.14423165630017007, 0.07410888906036105, 0.12558406192277158, 0.17566508959446633, 0.20590542762407235, 0.083270577447755, 0.08787109237164259, 0.1093773887093578, 0.10605748649686575, 0.09266366663255862, 0.10230749486280338, 0.17615360766649246], [0.04355502035468817, 0.054873537471784015, 0.03435123904741236, 0.006548002029636076, 0.027265492926484773, 0.02940275440258639, 0.011528343045418816, 0.053321364867900095, 0.032733160337167125, 0.0009735512306048934, 0.07301019158746515, 0.013543799852154084, 0.06587842891791038, 0.030245759524405003, 0.019275668443047574, 0.025047633364530544, 2.177052140235901, 30.865798473358154, 49.38044091633388, 42.77451753616333, 26.008512599127634, 26.2850752217429, 30.345277650015696, 46.76809542519705, 45.677016326359336, 42.67343861716134, 4.450226962566376, 0.1250163181019681, 1.3851639926433563, 3.7416349053382874, 1.8172482528856821, 0.42517411389521187, 16.048412357057842, 47.321856430598665, 49.90002720696585, 45.39150789805821, 43.40628596714565, 38.77416515350342, 39.024050167628694, 39.4260208266122, 40.21197673252651, 39.49110460281372, 39.324875899723594, 41.491536140441895, 44.27353579657418, 46.2713235446385, 44.455370153699604, 43.41797283717564, 35.62354966572353, 39.01278018951416, 42.88483755929129, 42.40236854553223, 42.24314015252249, 40.163780553000315, 38.04273523603167, 39.927715505872456, 40.10367168698992, 42.24796567644392, 43.7614083971296, 43.824261801583425, 42.98191431590489, 36.13008723940168, 29.705900941576274, 32.53380387169974, 34.38956349236624, 33.04424980708531, 33.96882227488926, 33.50322348730904, 34.61482409068516, 35.73055192402431, 33.58393028804234, 34.47002363204956, 34.69654185431344, 32.38226366043091, 34.0232892036438, 33.34642348970686, 32.08241762433733, 34.007197175707134, 33.58135250636509, 34.33986302784511, 37.485903126852854, 42.6628669330052, 44.548865113939556, 45.61378424508231, 43.427839279174805, 44.74949434825352, 41.85737269265311, 46.024499211992534, 46.01027972357613, 48.96116924285889, 42.672545773642405, 40.112603596278596, 46.00207737513951, 45.65062011991228, 47.442421572549, 43.03922305788313, 38.86057642527989, 34.88405636378697, 33.35316671643938, 33.32921627589634, 32.036646366119385, 33.667346886226106, 33.73032188415527, 34.01922798156738, 33.37279885155814, 34.275018964494976, 32.57420417240688, 34.911803994859966, 33.43459265572684, 34.64795657566616, 34.061368806021555, 34.432989733559744, 33.278247765132356, 33.334389209747314, 33.08485507965088, 33.962134633745464, 32.79997546332223, 34.25758940832955, 43.36024372918265, 47.195631980895996, 41.86305979319981, 40.582051685878206, 44.92918171201433, 45.51289292744228, 46.77838223321097, 44.58262641089303, 43.20332561220442, 39.98861994062151, 37.56243058613369, 33.083951813834055, 33.61144168036324, 32.714960779462544, 32.23419407435826, 32.88157858167376, 35.33322613579886, 34.62586825234549, 35.173459257398335, 33.775797843933105, 32.52512904575893, 34.13036789212908, 34.514669282095774, 34.094918182918, 37.19199432645525, 40.84503058024815, 44.75436850956508, 47.672427790505544, 48.46067312785557, 40.63977384567261, 7.701592632702418, 0.1270498875528574, 3.3706288933753967, 6.365218239171164, 3.5640704333782196, 1.1864312908479144, 0.04174499426569257, 7.951748626572745, 52.69568007332938, 38.630802971976145, 28.587069000516617, 23.49758301462446, 32.86904403141567, 40.16478456769671, 20.935188123158046, 0.24596245746527398, 0.050888579338788986, 0.04358413629233837, 0.04444205222119178, 0.0684872128601585, 0.03808238776400685, 0.008777791085386915, 0.036053215220038376, 0.023064591023804884, 0.016260889857741337, 0.051683612034789154, 0.021301302426893796, 0.032515815392668755, 0.02947891317307949, 0.04336445379470076, 0.011043789314239152, 0.029068050041262592, 0.06954798022551195, 0.04442225256934762, 0.0228166305792651, 0.09887513225632054, 0.022240277845412493, 0.07286235916295222, 0.029255301957683902, 0.03822101925366691, 0.04392081179789134, 0.025335920841566155, 0.02942799251260502, 0.09335024229117803, 2.5782439495835985, 38.26574461800711, 54.269982065473286, 47.43946163994925, 27.637333631515503, 32.482779775347026, 36.408921922956196, 48.136070660182405, 50.26716307231358, 42.907050950186594, 4.400607705116272, 0.3274399111313479, 1.8954338346208846, 5.195008277893066, 3.797065462384905, 1.1116222079311098, 17.55420684814453, 48.61569786071777, 51.5216394833156, 47.99655430657523, 44.96670198440552, 40.40772833142962, 40.70164408002581, 40.67027991158621, 42.635115827832905, 41.33824150902884, 40.991533347538535, 42.96968896048409, 44.268345492226736, 47.10753229686192, 45.47215216500418, 45.080576011112754, 37.31902824129377, 41.39663069588797, 46.14793395996094, 44.63365398134504, 45.23471137455532, 42.12611511775425, 39.61992073059082, 42.4785555430821, 42.62879296711513, 45.34003216879708, 45.55344261441912, 44.32298265184675, 44.87467656816755, 38.74078253337315, 31.87453099659511, 33.25842802865164, 35.79425648280552, 34.51333522796631, 35.7619959967477, 35.51121466500418, 36.55587979725429, 37.21341214861189, 36.25887210028512, 36.84792995452881, 36.50428942271641, 34.9572764805385, 35.62268114089966, 34.32005371366228, 34.76576328277588, 35.29675851549421, 36.375622681209016, 35.64661421094622, 39.97069011415754, 44.960670948028564, 46.2923765863691, 46.99090330941336, 46.320120743342805, 45.51098217282976, 43.14519698279244, 45.64736141477312, 47.33479050227574, 49.04551689965384, 44.14664084570748, 41.271858419690815, 48.40863112040928, 47.80044140134539, 48.4796347618103, 45.87267065048218, 40.512656552451, 36.52391113553728, 35.588805198669434, 35.38885341371809, 34.601511342184885, 34.56062814167568, 33.80206898280552, 35.88528135844639, 34.3019814491272, 36.03651237487793, 34.32640784127371, 36.444951806749614, 35.37877852576119, 35.47537585667202, 34.456822054726736, 35.58125945499965, 35.586456707545686, 36.09550952911377, 34.78579146521432, 35.56172112056187, 34.72445624215262, 35.12696191242763, 46.321920326777864, 48.47375658580235, 45.81228385652815, 40.9323034286499, 44.651913847242085, 45.81516735894339, 47.97222171510969, 46.352662631443565, 43.83045612062727, 41.44860322134835, 37.52815164838518, 35.803417682647705, 35.891510418483186, 33.73261478969029, 33.63510029656546, 35.07189743859427, 35.99639000211443, 37.48145975385393, 36.86028732572283, 36.594452721732004, 34.17666373934065, 35.06853451047625, 36.62675142288208, 36.11452327455793, 36.40577091489519, 43.54060159410749, 45.806766986846924, 50.49879516874041, 49.51581961768014, 43.25327968597412, 8.429064682551793, 0.29183726012706757, 4.913715234824589, 9.345182929720197, 5.289493356432233, 1.2320770472288132, 0.12541820082281316, 9.148364782333374, 57.24646527426583, 46.001733439309255, 34.756911277770996, 25.22509799684797, 37.068754128047395, 45.428472314562114, 27.226318155016216, 0.5229212088244302, 0.03305288603795426, 0.037085860701543946, 0.09604797538902078, 0.06700696836092643, 0.05511882109567523, 0.10242297473762717, 0.005973414759085114, 0.024562765810904757, 0.04936318511941603, 0.05909034423530102, 0.05211943507726703, 0.03420408855059317, 0.13314913026988506, 0.11709557526877948, 0.17714907282165118, 0.2332699985376426, 0.14701157355947153, 0.12898804140942438, 0.10282445033746106, 0.12096749964569296, 0.07188728398510388, 0.13655963726341724, 0.1307167179350342, 0.0834660701719778, 0.17556838478360856, 0.13288319882537636, 0.07276320484067712, 0.20318793558648654, 2.8767835072108676, 42.81701966694423, 59.96704632895333, 52.23061282294137, 33.390471594674246, 36.12286458696638, 41.06404822213309, 55.43330158506121, 53.89153453281948, 51.702810287475586, 5.793564319610596, 0.7002000446830476, 5.056495938982282, 10.703375101089478, 6.442085291658129, 1.0274464104856764, 21.880740676607402, 49.98735564095633, 53.411657197134836, 50.04515075683594, 47.407343591962544, 41.269996302468435, 42.9285695212228, 42.92908716201782, 45.46875449589321, 43.31047378267561, 41.9387013571603, 45.610216345105854, 48.63259935379028, 50.451696804591585, 46.647915908268516, 45.938087940216064, 37.94120121002197, 43.535293170383994, 48.54300233295986, 47.036011014665874, 45.86111927032471, 44.7850969178336, 41.42370087759835, 43.810848304203574, 43.579612255096436, 46.122847488948274, 48.23564182009016, 46.74645526068551, 46.19340297154018, 40.15322623934065, 33.21137135369437, 35.05469022478376, 37.88288845334734, 36.0818841116769, 37.90830496379307, 36.87595551354544, 38.249548367091585, 38.31001853942871, 36.29737901687622, 39.6301589012146, 38.39550222669329, 36.5536459514073, 37.554530484335764, 35.97975601468767, 34.40136500767299, 37.561843463352744, 37.74523769106184, 36.832261766706196, 40.3458685193743, 47.195270674569265, 48.27078233446394, 48.33828060967581, 47.007106508527485, 48.25288724899292, 45.80612775257656, 48.10361215046474, 49.334798199789866, 49.54236173629761, 44.988651343754356, 43.6330577986581, 50.51485940388271, 48.349825041634695, 50.238168239593506, 47.485653264181956, 41.870549951280864, 38.77483912876674, 37.186619894845144, 36.861534527369905, 34.90928874697004, 37.334241322108674, 35.601523876190186, 36.84777362006051, 36.5794654573713, 38.51513283593314, 36.04541996547154, 38.87088060379028, 36.733406271253315, 37.423400606427876, 37.4082361630031, 38.14252526419503, 37.813545431409565, 36.888264247349326, 34.88786397661482, 37.889263425554546, 35.749298163822715, 37.30116442271641, 48.79962362561907, 50.266482148851665, 49.09860461098807, 43.45963076182774, 45.58631454195295, 48.08747843333653, 49.08634104047503, 48.35993814468384, 46.16003772190639, 43.733844893319265, 41.430593490600586, 38.8667950630188, 38.18768160683768, 35.01718732288906, 35.66247694832938, 35.54534074238369, 38.82295887810843, 39.44348859786987, 38.628871372767854, 37.22014495304653, 34.80587870734078, 37.42277526855469, 38.346621649605886, 36.9503116607666, 39.240976401737754, 45.94184691565377, 49.2342403956822, 53.86656618118286, 51.538207462855745, 45.45245054789952, 10.801488876342773, 0.2908939336027418, 7.764008300645011, 14.300807527133397, 11.367644599505834, 6.3470230783735, 0.24520602662648472, 10.983146054404122, 63.85397284371512, 48.22117567062378, 40.41852583203997, 34.8833406993321, 44.416651317051475, 52.675252369471956, 32.444602898189, 0.9047980574624879, 0.29709555368338314, 0.12680336220988206, 0.15293849552316324, 0.1253168276910271, 0.113027459276574, 0.1295575222798756, 0.14290890656411648, 0.06482733746192285, 0.1290055883250066, 0.16070707009306975, 0.11169615321393524, 0.08626835873084408], [0.0411890332054879, 0.02550913386845163, 0.06725681852549314, 0.054541214768375666, 0.04084347228386572, 0.06784526444971561, 0.016379928648737923, 0.041939917020499706, 0.0406431246415845, 0.0644011360460094, 0.057720775582960675, 0.040280101621257405, 0.03301129523398621, 0.010481387260369956, 0.06688217898564679, 0.027172730404085348, 0.7359663311924253, 18.467007330485753, 42.80848033087594, 37.600527559007915, 22.7253862789699, 27.702184643064225, 32.5337621825082, 43.83295399802071, 43.56713676452637, 44.65253223691668, 10.422698276383535, 0.03834292485511728, 0.44474078395536965, 4.142274550029209, 1.9218037681920188, 0.8129315269844872, 12.960731915065221, 45.42538384028843, 49.52908025469099, 46.507110663822715, 44.20016629355294, 40.41917896270752, 40.094336782182964, 39.64948878969465, 38.225094182150706, 42.08716351645333, 43.21656193052019, 43.379802908216206, 43.96290963036673, 45.422323158809114, 40.942791734422954, 39.768660817827495, 41.32526227406093, 41.85154662813459, 44.280282497406006, 43.00629901885986, 40.038966587611604, 35.84589202063424, 36.07738515308925, 37.22687080928257, 38.44851003374372, 39.24353333881923, 41.058531352451865, 41.488558837345664, 39.31736837114607, 33.495583942958284, 33.55994858060564, 33.51269040788923, 32.47058916091919, 33.271362100328716, 33.80802706309727, 34.79207263674055, 34.90584938866751, 35.159899847848074, 32.86066450391497, 34.255261761801584, 32.367099217006135, 32.9295836857387, 34.30461481639317, 32.301987648010254, 32.644377504076274, 33.485046999795095, 34.8270776612418, 33.97943564823696, 33.76674434116909, 41.05519274302891, 43.356390953063965, 45.63931540080479, 45.59468017305647, 44.78877598898751, 44.168760435921804, 45.34068529946463, 44.884324141911094, 48.56634828022548, 39.44489560808454, 39.79819761003767, 46.30765567507063, 44.89575045449393, 47.485215527670725, 43.911221981048584, 38.32221610205514, 34.053889070238384, 35.80522768838065, 33.809298583439414, 35.535349232809885, 32.493017945970806, 35.146215370723176, 32.862471035548616, 34.17374202183315, 32.55431842803955, 34.568608147757395, 34.20785072871617, 35.18060547964913, 33.70519024985177, 33.18348823274885, 33.43566962650844, 34.906881196158274, 31.57481697627476, 34.375100816999165, 32.89919226510184, 34.21975646700178, 34.15742417744228, 41.29782383782523, 46.18762901851109, 45.792130606515066, 47.60368578774588, 46.5500088419233, 44.05549437659127, 45.48040315083095, 43.90726498195103, 46.33852999550955, 43.74617447171892, 41.229290281023296, 36.35591411590576, 34.25542157036917, 35.15869780949184, 34.50337151118687, 33.99510383605957, 33.7568917955671, 32.85824653080532, 32.91149057660784, 32.88363177435738, 33.82974018369402, 33.407432147434776, 34.48027917316982, 35.261208057403564, 36.469784668513704, 40.66538143157959, 44.982373646327424, 48.95876864024571, 49.59459481920515, 40.50354051589966, 6.997347107955387, 1.3014753290585108, 4.2524126172065735, 11.434489744050161, 1.4822594225406647, 0.2843279944998877, 0.06256409069257123, 11.88420842375074, 53.259811265128, 35.59849098750523, 37.183406352996826, 23.482069424220494, 37.797224112919395, 42.62939051219395, 14.185579470225743, 0.07576102683586733, 0.08610204979777336, 0.06296722870320082, 0.0069415489477770665, 0.017119075504264662, 0.028754529543220997, 0.028508343467754976, 0.010052922930169319, 0.06913720191057239, 0.03445789457431861, 0.029517436998763254, 0.049919763646487675, 0.011562615001041974, 0.03878618124872446, 0.056953705315079005, 0.03584426375372069, 0.025083573668130806, 0.00963339236165796, 0.07480435352772474, 0.07515143776046378, 0.007331046708194273, 0.009220592860531594, 0.06717369798570871, 0.054765046507652314, 0.023960747489971772, 0.054081568361393044, 0.0365372651389667, 0.03340709488838911, 0.009963839763908513, 0.8735051623412541, 24.539996930531093, 51.38447509493147, 45.309734548841206, 28.021699292319163, 33.27232789993286, 40.76119014195034, 50.71158375058855, 47.21591377258301, 48.04999985013689, 10.558710132326398, 0.0925289299339056, 0.611386161829744, 5.668286996228354, 2.7352324170725684, 0.9869562174592699, 14.057751723698207, 46.497456141880576, 51.670358725956504, 47.52948944909232, 47.34569222586495, 41.778514112745015, 42.50944028581892, 40.5945862361363, 40.35524163927351, 44.27170842034476, 43.904235567365376, 46.47157410212925, 44.977530751909526, 47.83689859935215, 43.58982610702515, 40.21618039267403, 41.98516048703875, 43.05814300264631, 46.62238475254604, 44.62498957770211, 41.74252244404384, 38.91998699733189, 37.28609725407192, 39.26844610486712, 40.01459925515311, 42.02403218405587, 42.26285914012364, 44.24541296277727, 42.12088312421526, 36.06690032141549, 34.617672852107454, 36.30276039668492, 33.52322040285383, 34.50877373559134, 36.24863045556204, 35.101865019117085, 36.52478313446045, 36.12327800478254, 35.0206093106951, 34.923827852521626, 34.685872895377024, 34.27841315950666, 35.519267627171104, 34.34749214989798, 34.150986671447754, 34.41475766045706, 37.06251464571272, 36.13286304473877, 35.30230665206909, 41.27894558225359, 46.642590114048545, 46.90653828212193, 46.97401918683733, 45.448649883270264, 45.425790309906006, 45.72940574373518, 45.22819743837629, 48.59489842823574, 42.851097106933594, 41.61052404131208, 46.98279823575701, 47.6605498450143, 47.87211206981114, 44.3369311605181, 39.32181869234358, 35.68066038404192, 37.066749572753906, 35.58527898788452, 36.066942010607036, 34.93939529146467, 36.14156218937465, 34.995060784476145, 36.09600632531302, 35.277070794786724, 36.41601603371756, 35.498047828674316, 36.576033047267366, 34.92765283584595, 35.53709323065621, 35.560182094573975, 35.62179524557931, 32.25012629372733, 36.00078126362392, 34.74019043786185, 35.15701634543282, 36.39334406171526, 43.965890407562256, 47.98106677191598, 47.69112539291382, 48.58345474515642, 48.96420907974243, 45.382965087890625, 46.88694783619472, 45.657835824149, 48.06153733389718, 44.6964761189052, 43.02889803477696, 38.65601798466274, 37.17210510798863, 36.435443196977886, 36.76729958398001, 35.09852988379342, 35.95576041085379, 34.042236941201345, 34.98918955666678, 34.38448435919625, 35.13872173854283, 35.27572979245867, 35.46134396961757, 37.530503613608225, 38.253262179238455, 44.172078200748985, 47.268803460257395, 50.53599582399641, 51.07894890648978, 41.522723129817415, 8.688378402165004, 1.432225770183972, 7.164777415139334, 11.962710908481053, 5.761021562985011, 0.9732568668467658, 0.02525401148679001, 11.891151411192757, 56.807207107543945, 39.90744066238403, 38.402985436575754, 28.026123557771953, 42.17848369053432, 46.83952638081142, 18.30928495952061, 0.0967386154724019, 0.01251350634265691, 0.03036020463332534, 0.03451222487326179, 0.06169130466878414, 0.0251187183894217, 0.014325321219595415, 0.027615538964580213, 0.025952161256490008, 0.0535864379656102, 0.10203846251325947, 0.033358518566404066, 0.04366403039810913, 0.13931482870663914, 0.09458868405116455, 0.13363876113934176, 0.21484272448079927, 0.11445462198129722, 0.17366132140159607, 0.18904683153544152, 0.12456687007631574, 0.08404223461236272, 0.18086162289338453, 0.1087772584121142, 0.09293040553373949, 0.1410184401486601, 0.09342089814266988, 0.12030166680259363, 0.17289958441896097, 1.1619293370417185, 28.77475200380598, 56.70297370638166, 50.951373032161165, 33.39429657799857, 38.46283374513899, 41.2704062461853, 53.56237057277134, 52.734169619424, 51.99625008446829, 13.316092320850917, 0.2812742612191609, 2.836521953344345, 11.16080367565155, 4.9440271854400635, 2.32660625236375, 16.17383255277361, 50.31505700520107, 52.50742210660662, 49.61950063705444, 48.28263596126011, 44.656207833971294, 44.305636474064414, 43.84647866657802, 43.13524716241019, 47.467789445604595, 46.78675133841378, 48.86630201339722, 46.10538666588919, 49.99580465044294, 42.872407232012065, 40.5815236227853, 44.664653369358604, 46.97841044834682, 48.495810168130056, 46.9108635357448, 44.65326179776873, 40.69080489022391, 38.21832316262381, 41.61470685686384, 41.904398100716726, 43.09771646772112, 43.93446370533535, 44.93808582850865, 43.7383577483041, 37.65816634041922, 36.8450151852199, 37.606086117880686, 36.1516683442252, 36.49926587513515, 37.67714534487043, 38.40042502539498, 38.89339624132429, 37.48597608293806, 37.28194917951311, 36.697834968566895, 36.09273024967739, 35.92855821337019, 38.680649348667686, 35.958841936928884, 35.911524704524446, 36.81424856185913, 38.38526405606951, 38.61652094977242, 35.258960315159385, 43.17691898345947, 46.86578709738595, 49.08384663718087, 50.240002564021516, 47.06146226610456, 47.093378816332134, 46.33824511936733, 47.96535342080252, 49.41210733141218, 44.01779692513602, 44.96980088097708, 48.69786030905587, 48.942516803741455, 49.16957351139614, 46.070590087345664, 41.602540561131065, 37.28519398825509, 39.583317620413645, 37.96819148744856, 38.93773964473179, 36.92246675491333, 38.110570498875205, 37.14700126647949, 38.797976630074636, 35.92174897875105, 37.544882910592214, 37.919970989227295, 38.72093152999878, 36.0564398084368, 36.54114614214216, 39.05985076086861, 37.33532176698957, 33.4015782901219, 38.47121327263968, 36.56700038909912, 37.11286129270281, 38.39701345988682, 45.9022456577846, 50.00794315338135, 49.431610924857004, 51.05721146719796, 52.3057541166033, 47.74614470345633, 47.618457657950266, 46.385513714381624, 50.39197703770229, 47.25963531221662, 45.7686630657741, 41.73968757901873, 37.512539046151296, 38.43041345051357, 37.72607455934797, 37.09878771645682, 37.13978903634207, 36.2853238923209, 36.154030731746126, 35.892858369009836, 37.91391910825457, 37.49614129747663, 37.49815974916731, 40.44137150900704, 39.850646087101524, 46.00174733570644, 49.00441830498831, 53.59505837304251, 52.89355434690203, 46.46527903420584, 9.755457554544721, 3.2513478653771535, 9.600317307880946, 21.788463388170513, 10.85670186792101, 2.0320412814617157, 0.23847949185541698, 14.182541370391846, 62.5856625693185, 44.18526240757534, 48.99505908148629, 32.71961259841919, 50.373665060315815, 53.85966314588274, 22.56219741276332, 0.2002789338252374, 0.1571276214505945, 0.15744619364184992, 0.09813788360250847, 0.1803492611008031, 0.0848146245947906, 0.13029831967183522, 0.10251319953905684, 0.1890499527965273, 0.12917123229375907, 0.30211047029920984, 0.09555415117314883, 0.12159259324627263], [0.07995211372950248, 0.021401883369045596, 0.05895817239901849, 0.05781948207212346, 0.024327817971685102, 0.05271087673359683, 0.03504037278305207, 0.03216340805270842, 0.03741070594904678, 0.03132173625220146, 0.03018977360001632, 0.020920194751982178, 0.00771887951330947, 0.026550900556945374, 0.012842472842229264, 0.05550654957603131, 0.3254057445696422, 13.385232976504735, 34.916417598724365, 36.95980984824044, 17.89915190424238, 13.743370924677167, 29.276481424059185, 39.0341910634722, 45.2413330078125, 49.07113490785871, 15.012503692081996, 0.03755932208150625, 0.7189091007624353, 3.2967324129172733, 3.5459156589848653, 0.3379954461540495, 12.367639763014656, 43.09494413648333, 50.54518134253365, 47.184956073760986, 45.25144263676235, 38.70443998064314, 39.83845894677298, 39.689948150089805, 45.13314608165196, 43.334962708609446, 46.55165556498936, 44.70983403069632, 45.08805922099522, 43.46968827928816, 40.30163976124355, 42.10812275750296, 40.35476221357073, 43.271136556352886, 43.90642772402082, 41.3935352734157, 41.953327315194265, 36.682844230106895, 34.74252503258841, 36.13564232417515, 36.34027372087751, 38.164141110011506, 39.03163760049002, 38.81558336530413, 34.54776355198452, 34.096867152622764, 34.575021335056846, 34.0959187235151, 33.14964703151158, 32.473618575504844, 33.20400626318795, 33.28145088468279, 33.71965639931815, 33.06238807950701, 31.35021298272269, 33.967891216278076, 33.44245106833321, 33.44949654170445, 34.13830620901925, 32.9556359563555, 32.71482876368931, 35.0364442552839, 35.01866034099034, 34.482391425541465, 34.88569613865444, 37.12353025163923, 42.06076383590698, 45.50267560141427, 46.34294210161482, 45.80415793827602, 46.828124386923655, 43.88180678231375, 48.66550949641636, 50.70653241021292, 34.67216409955706, 42.3292943409511, 45.98193802152361, 45.82329675129482, 45.83798176901681, 41.17237411226545, 36.659202984401155, 35.21835504259382, 34.697201933179585, 36.32141978400094, 34.82459715434483, 35.22024495261056, 36.06000076021467, 33.294582980019705, 33.325335706983296, 32.52170705795288, 34.5364796774728, 33.43068081992013, 34.91027886526925, 32.05214779717581, 34.21804026194981, 33.12008244650704, 34.35238020760672, 34.01236316135952, 34.30945076261248, 34.71611492974417, 33.1532427242824, 34.003340925489155, 35.900112288338796, 41.391892024448936, 43.2495241846357, 41.649559020996094, 43.755068165915354, 43.816115038735525, 46.36613171441214, 44.522118023463655, 45.65441383634295, 43.350002084459575, 42.65924344744001, 42.178580965314595, 40.26421676363264, 38.50128507614136, 38.037802015032085, 38.13066121510097, 37.53447450910296, 38.43170581545149, 37.257974420275005, 35.574835845402305, 33.489257608141216, 34.72505031313215, 34.697254044669016, 34.73876258305141, 39.25887496130807, 44.90268128258841, 44.52981662750244, 49.0865911756243, 47.89472150802612, 39.55197777066912, 5.548675060272217, 0.5852968703423227, 7.081151068210602, 7.29090632711138, 4.501283194337573, 0.12264671096844332, 0.04350404201873711, 17.402930668422155, 50.86698716027396, 36.44974953787667, 28.981955971036637, 18.898983785084315, 39.718717166355674, 36.7287266595023, 6.005822232791355, 0.055449298183832846, 0.01101939004313733, 0.10252994578331709, 0.0408869087030845, 0.027033206640875766, 0.0648396121604102, 0.0354477041400969, 0.031176658679864237, 0.040454040680612834, 0.024567425650145327, 0.111661432577031, 0.028608997352421284, 0.05474183043198926, 0.060197733741785796, 0.042467732448130846, 0.038150916408215246, 0.04692553449422121, 0.04928562517410942, 0.07143886733267989, 0.03371647971549204, 0.006483277422375977, 0.061851520357387405, 0.06031612453183957, 0.05782379076949187, 0.03727959602006844, 0.023743592535278628, 0.05378328775987029, 0.06159173644014767, 0.008879522144395326, 0.5431481205991336, 16.866993529456003, 41.14858348029, 43.46379620688302, 22.45273549216134, 20.57731420653207, 34.45443882261004, 44.36067662920271, 49.656614439828054, 50.035791533333914, 16.43390188898359, 0.08539942000061274, 0.43724359625152176, 5.849777851785932, 5.182785962309156, 0.6834020689129829, 13.152372785976954, 44.4957218170166, 51.56013250350952, 48.32118804114205, 46.26734222684588, 41.76066419056484, 40.86664295196533, 41.23953192574637, 45.49898610796247, 46.654339517865864, 47.405068056924, 46.308416502816335, 46.7598374911717, 44.344320569719585, 41.450545242854524, 42.88025522232056, 44.568459033966064, 45.76602622440883, 45.58739151273455, 42.25494166782924, 43.293019907815115, 37.39635821751186, 36.6938328061785, 36.788303988320486, 39.03147431782314, 40.13741213934762, 41.74475976399013, 39.60312693459647, 36.20649310520717, 37.10747296469552, 35.5819091115679, 35.42553990227835, 35.235833236149375, 35.87534196036202, 34.52156884329659, 35.27771350315639, 35.99468074526106, 34.90905250821795, 33.29498597553798, 35.470004899161204, 34.21828344890049, 35.24029745374407, 36.3677191053118, 34.037185600825715, 34.303284236363, 37.425620555877686, 37.33873333249773, 36.05210413251604, 36.193270683288574, 39.49155970982143, 44.86303833552769, 48.24857589176723, 47.60530819211687, 48.21929965700422, 48.391774790627615, 47.20822559084211, 48.535168239048545, 49.48671708788191, 38.15887437547956, 43.4761118888855, 48.33857938221523, 46.63336638041905, 46.58876936776297, 43.009901659829275, 38.31651163101196, 35.5641634123666, 36.61899028505598, 37.71959883826119, 36.94276244299752, 36.99018389838082, 36.88910150527954, 33.6527487209865, 35.87645714623587, 34.97467129571097, 36.30066898890904, 35.65598038264683, 35.73534270695278, 33.630250453948975, 35.32727500370571, 34.052930218832834, 35.17469603674752, 34.986896651131765, 35.48336975915091, 36.47333867209298, 35.87008217402867, 35.66850103650774, 37.326466287885395, 44.47287961414882, 44.78370727811541, 44.07760007040841, 44.2816686630249, 44.87236976623535, 47.73414169039045, 46.58999572481428, 48.36545154026577, 45.08158349990845, 44.07525505338396, 42.19032342093331, 41.59708622523716, 39.488742215292795, 39.47349786758423, 39.52741241455078, 38.44204126085554, 39.61650916508266, 38.922213894980295, 37.66237347466605, 35.17609262466431, 36.32815258843558, 34.987720012664795, 36.4065386908395, 39.124003478458945, 45.50619486400059, 46.82955224173409, 51.66380657468523, 48.89002316338675, 41.518658433641704, 6.760097392967769, 0.8726901603596551, 8.36417371886117, 7.191964847700937, 6.83837319271905, 0.714666411280632, 0.08186088023441178, 18.13273991857256, 56.77841377258301, 39.983186449323384, 35.015700408390586, 22.684654201780045, 42.82145609174456, 44.75437545776367, 9.202281934874398, 0.0682154188730887, 0.0456129288566964, 0.09581215732863971, 0.10228612100971596, 0.05420861386560968, 0.060307432498250685, 0.00650607789534011, 0.023080326250887344, 0.05854229150073869, 0.014872116968035698, 0.03403121139854193, 0.029102964060647146, 0.1036476625927857, 0.152796545997262, 0.1400316466710397, 0.15107815606253489, 0.146579292469791, 0.134624129693423, 0.14456812824521745, 0.09254188995276179, 0.09992561303079128, 0.147253919126732, 0.14325597722615513, 0.11235013883560896, 0.1425766415361847, 0.1013163316196629, 0.21277948947889463, 0.12102594865219933, 0.1264092419296503, 0.5894379424197334, 20.287235600607737, 47.82399926866804, 50.29445212227957, 27.383934565952845, 23.408616542816162, 38.03290353502546, 49.31267860957554, 53.35951444080898, 57.64407246453421, 20.02983784675598, 0.18456736047353062, 1.346556110041482, 9.927739875657217, 11.000670279775347, 1.8946467339992523, 14.951427289417811, 45.12503753389631, 54.509229387555806, 50.24683959143502, 48.76606730052403, 41.90711832046509, 43.18832097734724, 43.121583529881065, 47.73892205102103, 47.82966205051967, 51.73366723741804, 49.22539186477661, 49.34916360037667, 44.08695581981114, 42.288265228271484, 45.33354255131313, 46.09152500970023, 48.43166787283761, 47.59693908691406, 44.48697403499058, 46.37528249195644, 40.3948290007455, 39.339036328451975, 38.885982513427734, 40.75523206165859, 41.5376478603908, 43.228019509996685, 42.59617117473057, 38.39485951832363, 39.62158135005406, 38.44625881740025, 36.745683738163535, 37.04842717306954, 36.33057056154524, 35.785856110709055, 37.68825551441738, 37.88642856052944, 35.320754119328086, 34.70978512082781, 37.00353833607265, 36.6609400340489, 36.33501740864345, 37.65939964566912, 36.854829515729634, 36.562345096043174, 40.549568857465474, 38.59209108352661, 38.5996333530971, 36.99722242355347, 40.67756162370954, 44.79072495869228, 49.90557186944144, 48.58184276308332, 49.43531778880528, 51.52353981563023, 47.98461035319737, 49.873679637908936, 50.691538197653635, 39.06602770941598, 44.66077280044556, 48.93529762540545, 47.966864653996055, 48.8297301701137, 44.841759477342876, 40.633777550288606, 37.90386159079415, 38.52132715497698, 40.59508998053414, 38.39657572337559, 38.27708060400826, 39.43195111410958, 36.351422105516704, 38.18864393234253, 35.15124586650303, 38.80523402350289, 37.38143348693848, 38.668208599090576, 34.82491329738072, 37.05508007322039, 35.422097069876536, 37.70617144448416, 38.18167836325509, 38.26479966299874, 38.93218108585903, 36.75604697636196, 37.60762166976929, 38.23907395771572, 46.22772707257952, 47.61831521987915, 45.99729701450893, 48.20486824853079, 45.87578691755022, 49.21902731486729, 49.14364978245327, 49.44439213616507, 48.02266216278076, 45.65016153880528, 45.510898794446675, 44.49473169871739, 41.68554374149868, 41.72732673372541, 41.8573761667524, 41.591444287981304, 42.281723499298096, 39.82681029183524, 38.71788821901594, 36.142437662397114, 38.344057764325825, 37.508060932159424, 37.822289739336284, 41.476392541612896, 47.72990676334926, 49.03984022140503, 54.22709083557129, 49.03764111655099, 43.51682138442993, 8.423016275678362, 1.7197223603725433, 13.869567581585475, 16.348673548017228, 11.95081993511745, 1.343449396746499, 0.24647363860692295, 20.769543068749563, 62.89948490687779, 47.38586323601859, 41.02173021861485, 29.336656297956193, 49.534392152513774, 51.63664606639317, 11.559297629765101, 0.25983944854566027, 0.15566115799759114, 0.20893473364412785, 0.28206760436296463, 0.14927146158048085, 0.23646877546395573, 0.13103136819388184, 0.08915169829768793, 0.14326284400054387, 0.18538750575057097, 0.10611884641860213, 0.10556262412241527, 0.2024344088775771], [0.025519534113949964, 0.0614070256373712, 0.060268878138491085, 0.02235320133955351, 0.048991741479507515, 0.0547121411322483, 0.016354559920728207, 0.03471153774963958, 0.019627180116783296, 0.06579267566225358, 0.061813793810350556, 0.04767195354881031, 0.04340725917635219, 0.013486990355886519, 0.05189616312938077, 0.01804602049690272, 0.1781844086945057, 8.117750644683838, 33.46452896935599, 39.88987214224679, 29.704678058624268, 28.603859322411672, 32.445210865565706, 40.79214436667306, 44.3040314401899, 46.22825860977173, 30.7322575705392, 0.6594211757183075, 0.07440407214952366, 4.319974294730595, 2.317815261227744, 0.03815264327983771, 9.842257056917463, 41.019628388541086, 50.73276880809239, 48.91978924615042, 44.87184170314244, 41.9478417124067, 38.594116483415874, 44.11450890132359, 44.53507988793509, 45.423869132995605, 44.63157646996634, 44.35525008610317, 43.27116434914725, 41.407403877803254, 40.629497459956575, 42.416386536189485, 44.80313444137573, 43.48538425990513, 42.26671886444092, 42.289158071790425, 39.77041523797171, 36.77005454472133, 34.646188259124756, 33.85549715587071, 34.31661088126046, 35.32699012756348, 34.89411040714809, 34.83191360746111, 33.77516555786133, 34.546766485486714, 32.25855098451887, 33.40831109455654, 32.52873863492693, 33.67083488191877, 34.217470509665354, 34.3931313923427, 34.85698618207659, 35.25281810760498, 34.384189060756135, 32.75937713895525, 32.14668846130371, 32.96844843455723, 33.63766418184553, 32.320184980119976, 35.89999764306204, 33.56422867093767, 34.274126120976035, 33.71200295857021, 35.13849939618792, 35.65871449879238, 38.83905438014439, 44.15509680339268, 47.1615059035165, 46.53692190987723, 48.64432443891253, 45.17673907961164, 48.29415260042463, 47.58379309517996, 34.283902236393516, 45.2775296483721, 47.539154393332346, 47.66637590953282, 43.725177015577046, 42.78382464817592, 35.274190766470774, 37.87401212964739, 37.4930875641959, 36.509695121220176, 35.39571475982666, 35.77822004045759, 34.842603410993306, 34.398123673030305, 33.38893256868635, 33.18906763621739, 35.72680337088448, 35.076181003025596, 35.208804743630544, 34.517472880227224, 33.56273480824062, 35.48595101492745, 33.266053676605225, 32.7038506099156, 32.82890428815569, 32.87763895307268, 33.9637188230242, 33.986807686941965, 33.23274401256016, 34.71788672038487, 37.208770751953125, 39.51618759972708, 40.21634020124163, 43.60574442999703, 42.87141711371285, 45.891757352011545, 42.64706325531006, 45.585880279541016, 44.87326260975429, 43.640752928597585, 42.653396538325715, 41.63377618789673, 42.339838232312886, 42.78244195665632, 41.908785888126914, 43.61540242603847, 41.858185631888254, 41.522330556597026, 39.87581941059658, 38.2201053755624, 37.28829288482666, 38.6106219291687, 40.95929718017578, 43.38057763235909, 45.09550074168614, 50.74331964765276, 46.99006257738386, 36.069349561418804, 5.042551338672638, 0.20944459842784063, 5.717951851231711, 7.854291456086295, 4.813628605433872, 0.7435638063720295, 0.11783292570284434, 22.434241124561854, 49.029536042894634, 33.11756719861712, 34.617579051426475, 27.851056746074132, 42.20096458707537, 33.664268834250315, 3.0781481649194444, 0.07492411495851618, 0.0366980134775596, 0.051665824239275286, 0.059965912252664566, 0.05878588557243347, 0.04003201564773917, 0.036740890105387995, 0.008519259913425361, 0.04103386242474828, 0.03927811574456947, 0.06262380177421228, 0.023840709556160227, 0.07688221774463143, 0.040265621683959446, 0.0373653153489743, 0.03084564215636679, 0.007671326931033815, 0.046374265503670485, 0.03451218076848558, 0.06298923359385558, 0.02789891554441835, 0.030265708453953266, 0.08141077402979136, 0.034400775496448786, 0.04298089491203427, 0.02437242486381105, 0.07277292146214417, 0.014422696083784103, 0.013045293744653463, 0.15080813983721392, 11.188730222838265, 40.202683516911094, 43.67973232269287, 31.25850370952061, 23.993003470557078, 38.22355168206351, 46.312884194510325, 47.08898755482265, 51.923474652426584, 30.48820209503174, 0.4931006261280605, 0.2985913705612932, 5.1633870261056085, 4.806318666253771, 0.9371343765939985, 11.446716836520604, 42.88536214828491, 50.5104056085859, 48.97685480117798, 46.7239465713501, 42.59230102811541, 41.231367792402, 44.943460260118755, 47.09131520135062, 47.596032346997944, 47.850645610264365, 45.9786376271929, 44.249686104910715, 40.21860531398228, 42.46059792382376, 44.695791721343994, 45.85637017658779, 46.54680919647217, 44.33414840698242, 44.34415033885411, 41.10972567967006, 39.04453345707485, 35.287440981183735, 34.74408837727138, 37.67951815468924, 37.628688607897075, 37.00300332478115, 36.22720915930611, 35.677988801683696, 36.14329923902239, 34.42335953031267, 34.52141945702689, 35.09934977122715, 33.91931288582938, 35.29681757518223, 35.72401019505092, 35.53716271264212, 35.84198365892683, 35.603153228759766, 34.68173524311611, 33.82300737925938, 33.98323283876692, 35.62025274549212, 34.76174027579171, 36.82635579790388, 35.12435981205532, 35.587888036455425, 34.936053207942415, 36.514833314078196, 36.945510455540244, 40.12233107430594, 45.450536319187705, 48.3372175352914, 48.555724484579905, 47.81965317044939, 46.48679413114275, 49.242741516658235, 47.3109894480024, 36.38561071668352, 46.5131208556039, 48.4674128804888, 48.82531806400844, 45.244442326681956, 43.816768169403076, 37.28348820550101, 38.42251682281494, 38.609451157706125, 39.02517230170113, 37.774837017059326, 37.29257992335728, 36.914976596832275, 35.40057502474104, 35.37024961199079, 34.78720889772688, 36.961974212101524, 36.234320640563965, 35.95124755586897, 34.72222934450422, 35.347157273973735, 36.11153554916382, 35.71409164156233, 34.998757226126536, 34.8678149495806, 35.402141843523296, 34.73013292040144, 34.49062156677246, 35.214137486049104, 37.28115708487374, 40.50347103391375, 41.63682644707816, 42.499233382088796, 44.51534700393677, 45.4702205657959, 46.965240137917654, 43.60839169366019, 46.15297835213797, 45.6150210244315, 46.77638462611607, 44.4921851839338, 44.024442877088276, 44.41967378343855, 42.816085134233745, 42.76440790721348, 44.257933616638184, 43.72005271911621, 42.58297307150704, 39.82774135044643, 39.71719203676496, 38.80429949079241, 40.70089020047869, 41.37453542436872, 45.47288172585623, 45.890590054648264, 51.73285777228219, 47.656102997916086, 37.47199283327375, 5.324428030422755, 0.9417035771267754, 9.982444780213491, 6.999798085008349, 5.911507819380079, 1.2110018581151962, 0.13282118072467192, 24.127984387534006, 54.15574325834002, 38.783013684409006, 38.02419049399239, 29.564442566462926, 46.84646415710449, 38.253932680402485, 4.66137490102223, 0.14973771013319492, 0.04085661889985204, 0.0235825049291764, 0.06362379954329558, 0.04547955940610596, 0.022574473305472305, 0.05336313548364809, 0.030079752539417574, 0.03191641112789512, 0.017916079344494, 0.03196518083236047, 0.06995447019913367, 0.06676771691335098, 0.14646305942109653, 0.1524539536663464, 0.1403592298073428, 0.08240329434296914, 0.2031568179705313, 0.07962565696133034, 0.16612460224756173, 0.08313436154276133, 0.10976893734186888, 0.15845812005656107, 0.15261070882635458, 0.079149101461683, 0.10792962568146841, 0.13774297519453935, 0.18837333124663147, 0.1357696053705045, 0.4937873035669327, 12.523379291806902, 45.77001101630074, 51.08603606905256, 41.849566391536165, 39.79831920351301, 43.587098939078196, 48.90475681849888, 53.95922040939331, 54.661464418683735, 37.487567220415386, 1.0626962504216602, 1.1778674189533507, 12.531706707818167, 6.871875669275012, 1.7313647185053145, 12.46538267816816, 44.73314871106829, 52.5515570640564, 52.20004422324044, 49.38586745943342, 46.429395062582834, 42.58213581357683, 48.044000080653596, 48.395453861781526, 49.59253467832293, 47.79009900774275, 47.18962526321411, 43.904072284698486, 41.67720937728882, 45.113774503980366, 47.275174958365305, 48.54085881369454, 46.91137770244053, 46.83671930858067, 47.58397374834333, 43.27870314461844, 39.640247685568674, 37.82201528549194, 36.71446200779506, 40.4503937448774, 39.49516582489014, 37.43996858596802, 38.88661132540022, 37.337416648864746, 38.04817567552839, 36.528622014181956, 37.6318222454616, 36.05846520832607, 37.05678585597447, 37.22269146783011, 38.37757934842791, 37.75981848580496, 38.52269942419869, 37.670527185712544, 35.75654166085379, 35.48046888623919, 36.37100560324532, 37.22481761659895, 37.25668552943638, 39.34791612625122, 36.90056255885533, 37.44211905343192, 38.02540642874581, 39.95329877308437, 38.56804684230259, 42.349610873631065, 48.408669335501536, 50.825867721012656, 50.59182807377407, 50.325951780591694, 48.288642678942, 48.99092490332467, 48.056861196245464, 38.26054389136178, 46.921747888837544, 50.60861839566912, 49.43020738874163, 46.76086582456316, 47.01671239307949, 38.46636343002319, 41.493738719395225, 41.136139256613596, 40.621798855917795, 39.41758918762207, 38.55525868279593, 37.831336293901714, 37.18914903913225, 37.28489521571568, 36.07686056409563, 39.180499281202046, 38.767147472926546, 37.35769496645246, 36.71510124206543, 36.30928822926113, 39.191755362919395, 37.18426098142351, 36.50357723236084, 37.21577453613281, 35.76780816486904, 37.36266640254429, 36.624955313546316, 36.4556450843811, 38.2635281426566, 41.909987926483154, 42.725668225969585, 44.36888939993722, 47.34265933718, 45.79191868645804, 49.2348553112575, 44.44449969700405, 47.244258948734824, 48.07749387196132, 48.459293910435264, 46.48440742492676, 46.737773486546104, 47.05358648300171, 45.0584077835083, 45.28760801042829, 47.422511509486604, 46.58397511073521, 46.137445654187886, 42.252780778067454, 43.638616357530864, 40.83137389591762, 42.93950251170567, 44.68558134351458, 47.431492056165425, 48.766571044921875, 53.30893155506679, 49.200284549168174, 40.068767411368235, 6.931809527533395, 1.2164201502289091, 12.829299790518624, 17.118502685001918, 13.331549457141332, 2.8604951926640103, 0.15974964361105645, 27.81943028313773, 60.450606209891184, 43.085449423108784, 46.56541994639805, 39.39310720988682, 53.01842042378017, 46.049085412706646, 6.6226207699094495, 0.15546018949576787, 0.16556094320757048, 0.1580251468611615, 0.17417759155588491, 0.14373536221683025, 0.11653000276003565, 0.0770098501816392, 0.20157269654529436, 0.16243060332323822, 0.1121086889345731, 0.13373850578708307, 0.14965183474123478, 0.13806236162781715], [0.045130103693476746, 0.012134164555131324, 0.020354140483375107, 0.029297496657818556, 0.03774948491315756, 0.07760478968599013, 0.04547233300815735, 0.08170779594885451, 0.06230645773134061, 0.06280030230326311, 0.06293031639818635, 0.05861228917326246, 0.005323586860738162, 0.033399936343942366, 0.042264942079782486, 0.012834057311660476, 0.10535689230476107, 4.174911107335772, 24.603579895836965, 45.774294580732075, 38.09410326821463, 27.71535669054304, 21.502822944096156, 27.660187993730815, 42.91176530293056, 45.54781109946114, 37.39933204650879, 2.8016146378857747, 0.11346717032470874, 4.133808604308537, 4.972878277301788, 0.5874880499073437, 8.950095329965864, 41.904217447553364, 50.59296063014439, 47.86940574645996, 43.84624242782593, 40.964789731161936, 44.844590868268696, 44.807629925864084, 46.54771941048758, 47.42604814256941, 44.090461186000276, 40.74434076036726, 41.27366147722517, 39.872491223471506, 41.986025537763325, 46.3348057610648, 44.01318679537092, 43.15236404963902, 41.321600573403494, 40.86545828410557, 41.45688199996948, 37.454208918980186, 34.35323831013271, 32.98096214021955, 34.39070994513375, 31.865432330540248, 35.59269271578108, 33.85606343405587, 33.68974787848336, 31.748094626835414, 32.98349823270525, 31.63332428250994, 34.6317047391619, 32.395593779427664, 33.286085333142964, 33.448669706072124, 36.79663140433175, 35.57920626231602, 32.358816964285715, 33.83967958177839, 33.027775628226145, 33.655760765075684, 33.659210545676096, 33.18820258549282, 32.166174684252056, 32.055462087903706, 35.213453088487896, 33.9195282799857, 34.47169814790998, 32.99110998426165, 35.18390934807913, 41.87940195628575, 49.03899254117693, 44.02300112588065, 48.55777072906494, 41.26474346433367, 53.274871485573904, 47.94859089170183, 35.24737071990967, 48.0914180619376, 44.28268657411848, 48.349592276981895, 41.13765396390642, 39.20560312271118, 37.565421785627095, 36.10879448481968, 36.97723593030657, 38.588481494358604, 35.715651512145996, 36.41786078044346, 35.1512701851981, 34.00372655051095, 33.15552173342024, 33.590958390917095, 33.6890287399292, 34.443950516836985, 34.51845952442714, 34.78322063173567, 34.328492300851, 33.56753601346697, 32.254541873931885, 33.736898354121614, 32.341251918247764, 32.408979484013145, 33.19681140354702, 33.40993697302682, 33.03959798812866, 31.69502428599766, 33.97750752312796, 35.134003911699565, 38.357776982443674, 41.94774096352713, 42.386898381369456, 44.85382849829537, 45.256514821733745, 42.5979950768607, 44.252472332545686, 44.14293398175921, 45.35349777766636, 45.56309366226196, 44.349045344761436, 43.904002802712576, 45.50963422230312, 45.53810099193028, 45.20400381088257, 45.400217464991975, 44.685115814208984, 43.58269030707223, 43.114183698381694, 43.239202635628835, 43.40093238013131, 44.86918749128069, 45.77912357875279, 49.23107896532331, 47.17112915856497, 29.519508566175187, 4.054090184824807, 0.6873914748430252, 9.482549684388296, 3.711016365459987, 5.791261426040104, 0.5341803846614701, 0.2010817357472011, 21.66965092931475, 44.273146697453086, 27.81135126522609, 22.26779702731541, 23.547118459429058, 42.23234960011074, 24.41199200493949, 1.2107990575688226, 0.03302221964778645, 0.05636443157813378, 0.009911387310629445, 0.047144663985818624, 0.025821836731795753, 0.04027322466884341, 0.03699256552915488, 0.05667850847489067, 0.042948403262666295, 0.023888359677844813, 0.06554864054279667, 0.04632468834253294, 0.0051250369121719685, 0.06117332460624831, 0.032460572464125495, 0.01307215609787298, 0.01679402499991868, 0.01535870460793376, 0.04797758946993521, 0.05324649192126734, 0.036253518757543395, 0.04999435839376279, 0.058973039101277075, 0.005347148565176342, 0.01236700130227421, 0.05780272904251303, 0.02090620675257274, 0.0811970354989171, 0.04375669792560594, 0.17794375946479185, 5.659819747720446, 32.00386129106794, 52.224831921713694, 42.53486027036394, 29.320039681025914, 27.313641377857753, 36.937228202819824, 46.33917270387922, 49.52704095840454, 39.983221190316335, 2.4667579318795885, 0.1013913368806243, 4.46479776927403, 7.968855091503688, 0.9309771869863782, 10.418057748249598, 42.121557099478586, 50.64763600485665, 49.77260766710554, 46.212135314941406, 42.68121712548392, 46.16287606103079, 46.92712232044765, 47.45280565534319, 47.39098753247942, 44.39883960996355, 41.480919292994905, 41.595870290483745, 42.067910058157786, 43.90893602371216, 46.05695424761091, 46.589356490543906, 46.17276682172503, 44.48538637161255, 43.128684588841026, 43.244775090898784, 39.765308312007356, 36.341802324567524, 35.597156933375764, 35.971935817173545, 34.586385113852366, 36.404204096112935, 35.75904301234654, 35.872920513153076, 33.93066624232701, 34.73130021776472, 33.39898313794817, 35.5696907043457, 35.37144817624773, 33.61861916950771, 34.230564389910015, 38.23195900235857, 37.879084314618794, 34.49194172450474, 35.68318952832903, 34.75343370437622, 34.32583808898926, 34.87100417273385, 34.669520309993196, 34.597043650490896, 33.70903607777187, 35.060780320848735, 35.44219820840018, 36.109937463487896, 34.91911349977766, 36.88014875139509, 44.380489417484824, 49.02189997264317, 46.83875860486712, 47.45619290215628, 44.95558834075928, 49.4535185950143, 47.710955551692415, 38.84859078271048, 48.19737114225115, 47.63480676923479, 49.012405259268625, 42.09480653490339, 41.07227141516549, 37.2143223626273, 39.59069313321795, 40.195783955710276, 38.81184523446219, 37.897674219948904, 38.22774491991316, 36.41350078582764, 34.77421229226248, 34.79973649978638, 35.965335028512136, 34.953736373356406, 35.78189563751221, 35.21810143334525, 35.94448348454067, 36.00782673699515, 34.94503722872053, 34.766103744506836, 35.42090197971889, 33.34050709860665, 34.65885829925537, 35.39959185464041, 35.23729583195278, 33.98042229243687, 34.29705170222691, 35.27226958956037, 36.41962562288557, 40.57747629710606, 43.158141476767405, 44.98526062284197, 46.423169476645334, 45.932831627982004, 44.18728085926601, 46.5081980569022, 45.70410735266549, 46.09961271286011, 47.271162373679026, 45.365334033966064, 45.694379874638145, 46.4843726839338, 47.00910064152309, 46.467922823769705, 45.50195646286011, 46.44692536762783, 46.54819883619036, 43.472894872937886, 45.12339081083025, 44.07834005355835, 46.05083983285086, 47.56438330241612, 50.77476372037615, 47.69218846729824, 32.199102197374614, 4.799497706549508, 1.174697954739843, 8.74269333907536, 6.516762793064117, 6.149986496993473, 0.41666772748742786, 0.06433293649128505, 25.902182579040527, 51.07215704236712, 37.15295239857265, 31.9648471559797, 29.199356419699534, 47.33103152683803, 31.610555035727366, 1.9921377769538333, 0.04743713293490665, 0.028997679174478565, 0.05902506238115685, 0.033002233398812156, 0.0217776272246348, 0.029214304871857166, 0.026049453000138913, 0.0913995558928166, 0.027429825626313686, 0.02254963044210204, 0.07255372750971999, 0.03843406567882214, 0.030295730235853364, 0.13257842803640024, 0.08814240459884916, 0.13127473156367028, 0.12154201524598257, 0.08998349402099848, 0.1376283706298896, 0.19178204690771444, 0.16812775975891522, 0.1866444375898157, 0.16047563536890916, 0.14123941186283315, 0.13266722112894058, 0.10360832791775465, 0.08564852377665894, 0.13750410372657434, 0.07961100060492754, 0.26370897090860773, 6.438661132540021, 36.42067132677351, 59.674318722316194, 50.2702202796936, 38.52135147367205, 32.08416509628296, 37.039255550929475, 49.78100109100342, 53.51396247318813, 45.33217028209141, 3.6638954196657454, 0.4098627269268036, 10.630407725061689, 11.62147011075701, 2.1046860005174364, 12.701441645622253, 44.88768012183053, 52.839209011622835, 52.264877864292686, 47.77035222734724, 44.82757125582014, 48.02907535008022, 49.18444613048008, 50.56537280763899, 48.522529465811594, 44.19109542029244, 40.923892634255544, 43.87840563910348, 43.11973878315517, 44.85333865029471, 48.93880646569388, 48.51931939806257, 47.35505839756557, 45.28519351141793, 44.885963916778564, 46.343643869672505, 40.686695030757356, 38.5500544820513, 36.69209575653076, 37.50599036897932, 35.73889323643276, 39.71941198621477, 38.37511968612671, 36.82217298235212, 35.39798334666661, 36.525422368730815, 34.85147973469326, 37.60241746902466, 37.63172844478062, 36.842618056706016, 35.839819295065745, 40.00487872532436, 39.68423325674874, 35.592056955610005, 37.09259339741298, 37.45359052930559, 35.99925265993391, 36.8925895009722, 36.21139505931309, 35.28199359348842, 34.30175215857369, 36.60682051522391, 38.116083894457134, 39.1415615762983, 36.57934038979666, 37.57786948340279, 45.22092267445156, 51.62296853746687, 48.207477297101704, 50.037309714726035, 43.84281696592058, 50.22458103724888, 48.90954760142735, 39.88151693344116, 49.542024748665945, 48.648343971797395, 50.10230316434588, 44.016320432935444, 43.46677698407854, 40.217132295881, 40.48547519956316, 41.927087443215505, 41.626251288822715, 39.11477279663086, 40.113221985953196, 39.59475782939366, 36.73683868135725, 37.026880809238975, 36.80678967067173, 37.02169745309012, 38.25604145867484, 37.752446447099956, 37.572950158800396, 38.03109005519322, 36.668989522116526, 36.56288358143398, 37.30797365733555, 35.23088959285191, 35.57026045663016, 37.21020902906145, 36.925430161612375, 36.60708107267107, 34.95734248842512, 37.621201923915315, 38.54055976867676, 42.92841666085379, 45.5313195501055, 45.46154226575579, 48.59503739220755, 47.95863798686436, 44.46697017124721, 45.70485428401402, 47.5627886908395, 48.91892072132656, 49.36303915296282, 47.22267089571272, 47.4710933140346, 48.952574321201865, 48.92586544581822, 48.5890063558306, 48.291112763541086, 49.344820976257324, 48.99915157045637, 46.741428239004954, 48.014980929238455, 47.21449286597115, 49.22239024298531, 49.69633729117257, 53.42141594205584, 49.02184091295515, 33.84637764522007, 5.97857574054173, 1.8526976363999503, 17.361738273075648, 9.28875139781407, 12.126525112560817, 1.6392318223203932, 0.23446582151310785, 27.453715324401855, 54.85826866967337, 39.02732624326433, 34.427201884133474, 33.16786868231637, 54.2218588420323, 37.94414029802595, 2.9794264222894395, 0.11586377636662551, 0.1386482494750193, 0.1274430714547634, 0.18616151064634323, 0.10861076627458845, 0.19574547851724283, 0.2132753221584218, 0.24433324060269765, 0.136683849883931, 0.09266472514718771, 0.14686450787952968, 0.1969799915594714, 0.11391461667205606], [0.015185009821185043, 0.04442993358575872, 0.03265755457271423, 0.03266824149925794, 0.07157137843647174, 0.01782932355334716, 0.029764939432165453, 0.014831851003691554, 0.03496375260874629, 0.014786982875583428, 0.036153061648032496, 0.1031849899196199, 0.10034855069326502, 0.019278053493638123, 0.01779731366384242, 0.019038654464696134, 0.01861128766488816, 1.5882337817123957, 20.689847230911255, 41.04318625586373, 36.11675712040493, 38.187910897391184, 55.10563843590872, 40.944705963134766, 35.35844462258475, 45.69838898522513, 46.13908542905535, 11.410770331110273, 0.23797010204621724, 2.4332183258874074, 6.271348076207297, 0.021985509998298118, 6.937633855002267, 36.53098440170288, 50.16289145605904, 46.851456437792095, 45.48475619724819, 46.23951816558838, 45.00419793810163, 44.95455305916922, 48.781405448913574, 45.428826672690256, 41.4365758895874, 44.42989458356585, 42.73753227506365, 42.07377086366926, 44.96065010343279, 44.63523817062378, 43.38043519428798, 44.18527977807181, 43.11474650246756, 43.13850934164864, 40.18999263218471, 38.4945626940046, 35.73128495897566, 32.07661587851388, 33.01928492954799, 32.84542710440499, 32.87423780986241, 34.21285343170166, 33.52526664733887, 34.209469658987864, 32.920526708875386, 33.70869561604091, 33.09643425260271, 33.80518177577427, 34.434226512908936, 34.18370573861258, 33.84907354627337, 35.39965091432844, 34.03077588762556, 31.96680654798235, 33.94928046635219, 33.150289739881245, 34.90276786259243, 33.81553111757551, 32.673851762499126, 34.50771413530622, 36.23125648498535, 35.50214726584298, 38.079293182918, 34.1361210005624, 33.866676807403564, 38.70462410790579, 47.12889453342983, 44.0637766293117, 47.68817935671125, 40.520695618220735, 56.97829607554844, 41.99263327462332, 38.41846602303641, 49.04369994572231, 44.61022465569632, 46.482441084725515, 39.934323242732454, 38.51975686209542, 36.97464772633144, 38.789117676871165, 37.380849838256836, 39.257863998413086, 37.20981298174177, 36.89343023300171, 34.64657735824585, 34.050612994602744, 32.8889228275844, 32.03560413633074, 34.86520937510899, 34.63329240253994, 33.2224954196385, 35.55373069218227, 32.1796680859157, 33.32952199663435, 33.633345876421245, 34.85226488113403, 32.43314184461321, 33.647374289376394, 31.161743095942906, 33.27600349698748, 31.652042729513987, 31.62473283495222, 33.21969182150704, 37.19297749655587, 37.49942432131086, 39.64931855882917, 42.862561634608674, 43.49788754326956, 44.32190915516445, 43.869967051914756, 43.5052422114781, 44.06511763163975, 43.540174279894146, 45.33300059182303, 43.152027062007356, 45.786641529628206, 43.332770551954, 37.79330880301339, 40.39171273367745, 46.26651886531285, 45.27626507622855, 45.2159686088562, 44.35295370646885, 45.24651288986206, 43.69827011653355, 44.063199928828645, 45.24345220838274, 50.92065157209124, 43.65258223669869, 25.370709657669067, 2.355200695140021, 0.8294113512550081, 8.956069043704442, 4.765537083148956, 2.6336786321231296, 0.6122499640498842, 0.11014397043202605, 25.134064435958862, 35.36060551234654, 31.048470088413783, 27.828218017305645, 28.97668923650469, 44.05159296308245, 14.250334944043841, 0.23322179540991783, 0.0131996248383075, 0.02577388466202787, 0.0494686769587653, 0.011576032182866973, 0.03699412615969777, 0.09474282006600074, 0.02466348754907293, 0.015335164531799299, 0.08809939226401703, 0.02952339792890208, 0.04545662152980055, 0.029305594973266125, 0.12206777131983212, 0.060651802590915134, 0.030362494689013277, 0.01912679446728102, 0.020658767083659768, 0.06024428802941527, 0.031167115084826946, 0.022055046267009208, 0.0751643299258181, 0.06736957747489214, 0.03800591008205499, 0.019084192646135176, 0.06949830467679671, 0.10656652346785579, 0.020603715841259276, 0.035024505241640976, 0.05981276011360543, 0.04790504729109151, 2.52060039128576, 25.642867122377666, 48.735950333731516, 43.6416666167123, 37.710889271327424, 41.945069381168906, 36.74381119864327, 42.703433990478516, 50.36603593826294, 48.486780984061106, 11.367562089647565, 0.1882591609443937, 2.424191095999309, 7.740570289748056, 0.8799656842436109, 8.054363097463336, 38.56828655515398, 50.21457215717861, 48.32672228131975, 47.19983911514282, 46.76371806008475, 47.85547808238438, 45.578556878226145, 47.61194372177124, 45.79701171602522, 42.695252486637656, 44.076404980250764, 43.74718543461391, 44.61552265712193, 45.74296167918614, 45.459016595567974, 46.35396889277867, 46.42007405417306, 44.07679407937186, 44.742236954825266, 40.06426150458199, 39.77985783985683, 38.37239946637835, 34.463294301714214, 34.80108445031302, 35.54834931237357, 34.348388467516216, 36.14107928957258, 34.92000981739589, 34.158532415117534, 35.80183001926967, 35.466197286333355, 35.43990877696446, 34.367006165640696, 36.18616962432861, 34.3167324747358, 35.88975599833897, 35.91423102787563, 35.60868399483817, 33.57614483152117, 34.713613578251426, 34.338261468069895, 35.692274297986714, 36.10738052640642, 34.10481936591012, 35.94863155909947, 37.181853430611746, 37.64911978585379, 39.55866193771362, 37.78273017065865, 36.800126348223, 41.176233836582725, 49.4353038924081, 47.17865058353969, 47.72687387466431, 41.450104032244, 51.496928215026855, 44.24123362132481, 39.90582520621163, 49.14756161825997, 46.88901145117623, 46.66062068939209, 40.74772105898176, 38.168737343379426, 37.369426999773296, 39.85221637998308, 39.10663298198155, 39.97198942729405, 38.27583687646048, 39.04012482506888, 35.80494628633772, 36.24018839427403, 34.397369793483186, 33.39616911751883, 34.84679664884295, 36.63702086039952, 35.51714495250157, 36.373830045972554, 34.10202619007656, 34.21888794217791, 34.97989634105137, 35.24197196960449, 33.59229244504656, 34.87992218562535, 33.000934737069265, 35.44487673895699, 31.96309620993478, 33.483646937779014, 34.673988001687185, 38.51196098327637, 39.56838246754238, 41.59798949105399, 43.49611922672817, 46.317615917750764, 45.191514423915315, 42.76238945552281, 43.296949114118306, 43.868723324366975, 45.85895490646362, 47.159452710832866, 45.20246131079537, 47.67555100577218, 46.549154213496614, 39.414764744894846, 41.40036882672991, 48.25624322891235, 48.08734294346401, 47.75270727702549, 45.60274008342198, 47.067705222538535, 45.942222118377686, 46.15607030051095, 47.557108538491384, 52.474070753370015, 45.95364843096052, 27.877451215471538, 3.678746325629098, 1.6618052167551858, 9.802295361246381, 7.498634883335658, 4.971361398696899, 0.3141651063093117, 0.15939196066132613, 26.033972535814556, 42.53841079984392, 32.83857618059431, 27.489746945244924, 31.04017046519688, 50.15181255340576, 18.970348732812063, 0.51070508147989, 0.051571684290788004, 0.07900540810078382, 0.019078543842104927, 0.026093252435592667, 0.03438358820442643, 0.04346900925572429, 0.014209915135454918, 0.05093454669362732, 0.005060544703155756, 0.03164083770077143, 0.0519958501016455, 0.06375088915228844, 0.0463339469528624, 0.09784741633172546, 0.09240675291844777, 0.09853881637432746, 0.08582121772425515, 0.15870649101478712, 0.08353594570819821, 0.09466171477522169, 0.19793296685176237, 0.16692740416952542, 0.15264365848686012, 0.10705716535449028, 0.23414965133581842, 0.2479440239923341, 0.1320339036839349, 0.12852979956993035, 0.17728488839098386, 0.15224177576601505, 2.5123070648738315, 30.684370585850306, 55.242945262363975, 48.9925924709865, 46.98852007729666, 60.63075910295759, 49.970339502607075, 46.197745595659526, 52.48467023032052, 55.29330233165196, 14.600359133311681, 0.35119219230754034, 7.752608043806894, 10.263792974608284, 0.8487778806260654, 9.882999556405203, 41.037353243146626, 51.86494997569493, 50.19418961661202, 50.406283378601074, 50.74530335835048, 49.758204051426475, 48.22817598070417, 50.95353044782366, 47.13386596952166, 44.845059871673584, 45.61139753886631, 45.095604964665, 44.58931057793753, 49.10455921718052, 47.96399852207729, 47.71639946528843, 47.49978242601667, 46.43685047967093, 48.14826822280884, 43.095284598214285, 41.45991141455514, 40.50100094931466, 35.34591702052525, 36.33835254396711, 35.91928584235055, 36.57258326666695, 37.56119728088379, 37.322846276419504, 36.41613415309361, 37.627677645002095, 37.579432828085764, 36.1383694921221, 36.53929097311837, 38.87799208504813, 36.411732469286235, 37.598787035260884, 38.21809387207031, 37.31787831442696, 35.91098621913365, 36.96789060320173, 37.65102011816842, 36.959823744637625, 37.27359397070748, 36.185777051108225, 36.38325875146048, 39.49076761518206, 40.80785424368722, 42.13796527045113, 39.13855995450701, 36.86767326082502, 41.440755231039866, 50.801205090114046, 48.31024462836129, 50.03130299704415, 42.83167689187186, 53.09508337293352, 47.310221672058105, 40.73586743218558, 51.16869878768921, 48.14154584067208, 49.55326345988682, 43.70166431154524, 41.18889692851475, 39.48295783996582, 42.453604561941965, 41.00481482914516, 42.91513517924717, 39.54516158785139, 40.592574732644216, 38.66755894252232, 37.342492307935444, 35.938553197043284, 33.07828555788313, 39.15852212905884, 38.98572390420096, 36.707173347473145, 39.31605168751308, 35.03837932859148, 35.377677236284526, 35.80096844264439, 37.901499203273225, 35.847441468920024, 36.02250133241926, 33.26570974077497, 36.430992875780376, 34.833247661590576, 34.21817227772304, 36.37604999542236, 40.92093964985439, 42.02992425646101, 43.57259110042027, 45.53089223589216, 47.62802185331072, 47.41275971276419, 44.07696431023734, 44.15774754115513, 45.14411728722708, 47.77185303824288, 48.82186828340803, 46.22728933606829, 48.034831932612825, 48.8902177129473, 41.04460368837629, 41.606949193137034, 50.09642846243722, 49.333912304469514, 49.446480069841655, 47.6992860521589, 49.34662055969238, 49.82504224777222, 48.766192368098665, 49.905380793980186, 53.94356959206717, 46.93256275994437, 30.116146905081614, 4.42230258669172, 2.3016276955604553, 18.2961893422263, 13.645991052900042, 11.322185141699654, 1.4676464923790522, 0.21006425017757074, 31.271514211382183, 45.639235496520996, 40.81754003252302, 38.62047447477068, 39.99483510426113, 57.31084728240967, 23.96510819026402, 0.8007203936576843, 0.1881811022758484, 0.17961632114435944, 0.08430561476520129, 0.30415595482502666, 0.16497880087367126, 0.19625454262963363, 0.07671252970716783, 0.12022774719766208, 0.12372817365186554, 0.10123979965490953, 0.13191700567092213, 0.11035217890249831, 0.2911958002618381], [0.0351743495224842, 0.024856067661728178, 0.08442201744765043, 0.040332759331379614, 0.06694486883601972, 0.033354287900562794, 0.035061766992190053, 0.041204758254545074, 0.03436805993052466, 0.03053340069683535, 0.016314770627234663, 0.015371028500209962, 0.017785400285252502, 0.05321716903043645, 0.01163190190813371, 0.024770692689344287, 0.046485389183674536, 0.2713313347526959, 14.737832716533116, 41.65113278797695, 38.44477537700108, 49.363386562892366, 69.70801080976213, 55.62833057131086, 35.54941586085728, 36.01213462012154, 44.226034436907085, 14.99888174874442, 0.012186427018605173, 1.4154179692268372, 9.849852306502205, 1.5239781439304352, 6.38421939100538, 34.49863978794643, 49.41955927440098, 48.19051327024187, 46.94695595332554, 47.4300468308585, 47.22318506240845, 47.82617405482701, 42.57214082990374, 41.897383894239155, 43.04450021471296, 43.71142305646624, 43.60743979045323, 45.04412923540388, 42.00938885552542, 46.346902574811665, 45.18293339865548, 42.83650588989258, 44.1214918409075, 42.16763755253383, 40.46598897661482, 40.2646301814488, 39.26538889748709, 35.56364229747227, 32.896062101636616, 33.80894422531128, 34.24949128287179, 32.7814758845738, 32.78039196559361, 34.9685777255467, 33.053251198359895, 34.30403464181082, 34.12187371935163, 36.58016722542899, 33.86304637363979, 34.155273709978374, 34.08867175238473, 34.66266243798392, 33.2541583606175, 33.45017051696777, 32.6123080934797, 34.73993682861328, 32.937966687338694, 33.97621168409075, 33.15352760042463, 37.26463079452515, 38.17854472569057, 39.66626868929182, 40.737656593322754, 36.28741530009678, 34.90294851575579, 38.35294451032366, 43.18632337025234, 46.564540999276296, 46.93562344142369, 47.50806467873709, 48.26425102778843, 36.24108123779297, 43.777587277548655, 47.19860928399222, 45.94247920172555, 44.28304440634591, 38.6872501373291, 38.827878202710835, 39.05598061425345, 42.286319732666016, 40.85273265838623, 40.991773060389924, 40.249462263924734, 38.44699880055019, 35.57927227020264, 32.79920073917934, 33.46542876107352, 33.2888194492885, 33.1899014200483, 34.30311747959682, 32.51048919132778, 35.53580781391689, 33.35577229091099, 33.738666670663015, 34.257540770939414, 34.1479503086635, 33.19755138669695, 32.454549244471956, 32.585088525499614, 34.814216545649934, 32.07560838971819, 32.249928270067485, 34.686671938214985, 36.42073386056082, 38.69685254778181, 42.2995491027832, 42.79979855673653, 43.34492295128958, 44.368767806461875, 43.22734900883266, 43.49576834269932, 42.86843286241804, 42.842547348567415, 44.92622525351388, 43.94325317655291, 43.64961188180106, 37.500918184007915, 42.06207357134138, 43.75413015910557, 43.90739352362496, 46.70315408706665, 46.455026967184885, 47.41526106425694, 45.522432804107666, 45.55456474849156, 47.35834836959839, 46.45215736116682, 47.93668515341622, 38.98526184899466, 19.93361919266837, 2.1001466555254797, 1.1274737630571638, 4.784717585359301, 5.173009412629264, 3.2968177454812184, 0.07266537366168839, 0.5802438471998487, 31.112424782344274, 37.98122978210449, 30.330342497144425, 25.48330695288522, 33.23696156910488, 44.626254149845664, 9.504592844418116, 0.08343518325792891, 0.041773899857486994, 0.009847705950960517, 0.03413117317748921, 0.053704570912356885, 0.057463040841477256, 0.03728826091225658, 0.06423728340970618, 0.051542273190404685, 0.016668416293604032, 0.014813900359773209, 0.03570807159745267, 0.03142997955105134, 0.06812634758119072, 0.05522187699430755, 0.05518426240554877, 0.032127164104687314, 0.021402736626831547, 0.01222299411892891, 0.011547537104758834, 0.05749883356371096, 0.02224119217135012, 0.039930679835379124, 0.03598316326471312, 0.023740495022918497, 0.04568970848673156, 0.10146348550915718, 0.03566631794508014, 0.01823895175143012, 0.030066717881709337, 0.05167791234063251, 0.3919605032673904, 20.897026879446848, 47.78071893964495, 42.69500582558768, 52.23172800881522, 65.64960275377545, 52.90447344098772, 38.378958565848215, 42.112156186785015, 50.78475522994995, 16.67461701801845, 0.02581988594361714, 1.4437227589743478, 7.842861669404166, 0.5540949531963894, 7.834369233676365, 36.1446715082441, 50.42648526600429, 49.01466689790998, 48.44889940534319, 47.99936485290527, 48.580119609832764, 48.75245230538504, 45.184062480926514, 43.73190287181309, 43.796375206538606, 45.14390536717006, 46.026705265045166, 46.55005747931344, 44.07755143301827, 47.42976542881557, 46.57035664149693, 45.10147966657366, 46.25240012577602, 43.74151917866298, 41.733580112457275, 40.99914509909493, 39.34318092891148, 37.56466095788138, 34.31048257010323, 34.99219465255737, 35.22322225570679, 34.774111543382915, 35.478776999882285, 35.33528627668108, 34.731869970049175, 36.67755665097918, 35.807489327022004, 36.098695278167725, 36.2169188771929, 34.54392467226301, 35.083393233163015, 36.15846715654646, 34.8599739074707, 34.796227659497944, 34.071169240134104, 34.48384707314627, 33.97207750592913, 34.845712729862754, 34.41765505926949, 38.61136538641793, 41.156167439052034, 40.43424960545131, 41.4607868875776, 38.85405206680298, 36.95667273657662, 40.54884277071272, 45.16567407335554, 47.3897750718253, 48.793891361781526, 46.454512800489155, 48.137178897857666, 38.08931943348476, 45.11650167192732, 49.25258363996233, 47.207558563777376, 46.652098723820274, 39.93677943093436, 41.24851942062378, 39.89848443440029, 41.56974853788103, 42.18614060538155, 42.16641814368111, 42.4813244002206, 40.57984563282558, 38.08646024976458, 35.00035531180245, 34.833108697618755, 34.858139583042686, 33.82516132082258, 35.43507630484444, 34.85418953214373, 35.10880626950945, 34.696461950029644, 34.33687877655029, 35.46372372763497, 35.2370456968035, 34.18483829498291, 34.36489738736834, 34.48089408874512, 35.41006973811558, 33.493440423692974, 34.71744898387364, 35.68322079522269, 39.03576135635376, 39.515788078308105, 44.68214545931135, 44.28424644470215, 45.35892084666661, 45.11948939732143, 44.18591901234218, 43.9658591406686, 43.334841115134104, 43.03925085067749, 46.72346019744873, 45.6533716065543, 43.97610425949097, 38.91678735188076, 44.03908967971802, 43.995903151375906, 44.89019884381975, 48.17761046545846, 47.34853751318795, 48.979199818202424, 48.75554425375802, 47.78106982367379, 50.538101128169465, 46.868434361049104, 49.28972176143101, 41.18430069514683, 23.448426246643066, 2.134279898234776, 3.009711882897786, 6.152807899883815, 7.868674227169581, 5.492101090294974, 0.06300826650112867, 0.34696293781910625, 32.07274920599801, 41.90682302202497, 33.169626576559885, 31.490455423082622, 35.620353494371685, 49.1321678842817, 13.772674083709717, 0.026399483771196434, 0.05744402150490454, 0.045475047148231945, 0.020901998139119575, 0.027613313369719044, 0.07097364336784397, 0.02690275149819042, 0.06153320600943906, 0.07240394090435334, 0.02371345370608781, 0.08012248030198471, 0.09081894026270934, 0.03626881632953882, 0.004250509173808885, 0.13474052559052194, 0.14023174664803914, 0.16569339324321064, 0.1127934664753931, 0.15770285629800387, 0.08121288607695273, 0.1245114609066929, 0.0703960879306708, 0.09934917039104871, 0.1080055401793548, 0.10078970702098948, 0.11988728546670505, 0.19799908330397947, 0.09605908300727606, 0.1193101235798427, 0.15546434213008198, 0.2186567833913224, 0.51579507121018, 24.13920225415911, 56.287224769592285, 49.25321592603411, 57.59560530526297, 71.61186586107526, 57.45991393498012, 44.99526602881295, 43.824973991939, 52.64123746326992, 19.17082510675703, 0.16179360821843147, 5.133329553263528, 18.964305537087576, 2.643995838505881, 8.696662391935076, 38.992786748068674, 51.42884976523263, 50.047408921378, 50.95449277332851, 50.388179847172324, 51.84317432131086, 50.0837584223066, 44.758210863385884, 44.04382487705776, 44.24110507965088, 46.64995173045567, 45.3663067817688, 49.01144640786307, 45.013727392469136, 49.986570494515554, 50.10524920054844, 47.232794421059744, 48.977956090654644, 47.51842096873692, 43.66306012017386, 43.75870554787772, 41.643298694065635, 38.85106781550816, 35.81287418093, 36.604881967817036, 37.291006156376426, 35.518583229609895, 36.25999076025826, 38.39210455758231, 36.65745203835623, 38.388296944754465, 38.290177958352224, 38.33722768511091, 37.18191596439907, 36.979101521628245, 36.61544322967529, 37.83937188557216, 35.888216972351074, 36.294783864702495, 36.42807115827288, 38.1848224231175, 36.53940561839512, 36.67979049682617, 36.15661893572126, 39.040361063820974, 42.86940908432007, 43.21714210510254, 43.23917831693377, 40.736166204724995, 38.46643986020769, 41.04162291118077, 48.536662101745605, 48.7198235648019, 51.17583111354283, 46.12055458341326, 53.63206100463867, 42.69623218263899, 43.929283823285786, 50.958911827632356, 48.612637179238455, 49.558867182050435, 40.13899980272566, 44.39315250941685, 43.4270784514291, 44.290176732199534, 43.145242146083284, 44.91518804005214, 44.79291016714913, 43.50746216092791, 39.31687157494681, 35.409652846200125, 36.48501164572579, 37.369590282440186, 36.01924957547869, 36.51709147862026, 34.6219425201416, 37.83147178377424, 36.98645966393607, 37.0503066607884, 37.3399145262582, 37.00811719894409, 36.52198648452759, 35.329449789864675, 35.58249970844814, 37.518410273960654, 35.21167434964861, 36.33295031956264, 38.441943986075266, 41.09534290858677, 41.42002528054373, 47.840021814618794, 46.21797180175781, 48.01938608714512, 46.14613785062517, 44.86815915788923, 45.57800449643816, 43.670619760240825, 43.94465323856899, 48.22001532145909, 46.19609887259347, 44.97435542515346, 39.01288093839373, 44.19665050506592, 45.618943282536094, 45.90693916593279, 49.251284326825825, 48.22642503465925, 52.88860375540597, 50.38519906997681, 49.957794530051096, 50.74268388748169, 48.455111094883506, 48.767821720668245, 43.227060658591135, 25.875878436224802, 4.0726518630981445, 3.889136476176126, 12.283332926886422, 16.371632133211406, 12.520185726029531, 0.4959633382303374, 0.8307409541947501, 36.96745981488909, 48.75293173108782, 41.705408641270225, 38.40089750289917, 42.58334132603237, 54.9301095690046, 18.31202254976545, 0.1729618739336729, 0.2022487481257745, 0.11632997063653809, 0.1802882065198251, 0.19896507289792809, 0.16655859324548924, 0.14389385442648614, 0.16255940284047807, 0.17864619248679706, 0.137751877573984, 0.1703405167375292, 0.2660875347043787, 0.21643957522298607, 0.08842420019209385], [0.015192840115300246, 0.004233560217211821, 0.027658692095428705, 0.006655148222177688, 0.043082905866737874, 0.042268080304243734, 0.03606676895703588, 0.038390171248465776, 0.05171803750896028, 0.01831732763509665, 0.03311552499820079, 0.03950357596789088, 0.018428532739302943, 0.021030812923397337, 0.03907927445002964, 0.05210596276447177, 0.0679038559485759, 0.16908876890582697, 6.046251194817679, 32.986579758780344, 42.2445193699428, 38.525843484061106, 49.746506759098594, 56.66761779785156, 45.55278600965227, 36.26892614364624, 40.69709995814732, 23.320958069392614, 0.0348694124924285, 0.9942443349531719, 3.113266531910215, 0.32912954475198475, 3.9159660765102933, 27.109042985098704, 47.48447207042149, 51.00137921742031, 47.31673213413784, 47.6037483215332, 45.66885914121355, 44.12598385129656, 38.757072584969656, 44.33273792266846, 43.75879240036011, 45.34371818814959, 44.880818775721956, 44.291163376399446, 44.136645862034385, 44.162809303828645, 44.24817834581648, 45.15030118397304, 43.665766443525044, 44.440594809395925, 41.86780888693673, 43.12434196472168, 39.81828485216413, 37.78960541316441, 35.49284015383039, 33.827016489846365, 34.08713272639683, 33.352680342538015, 33.7627387046814, 32.692483357020784, 32.44920260565621, 34.16516099657331, 33.905822958265034, 35.57507903235299, 33.75659997122628, 33.4221727507455, 35.663453170231406, 33.543443134852815, 34.02752760478428, 32.909162930079866, 34.12408324650356, 33.73484863553728, 31.605569703238352, 32.404254708971294, 34.400885581970215, 39.02210814612252, 43.66525227682931, 43.48426212583269, 42.47254187720162, 40.569214888981406, 37.03518043245588, 36.636847155434744, 41.22876569202968, 44.04065302440098, 45.67874642780849, 47.431679657527376, 27.539159059524536, 35.84625332696097, 44.823725427900044, 47.84576450075422, 46.331449781145366, 42.82493366513933, 40.968284675053184, 42.5850818497794, 42.639566149030415, 40.76177379063198, 41.09308474404471, 42.23681034360613, 41.69556999206543, 39.337629318237305, 37.480184759412495, 31.816982541765483, 32.98578766414097, 32.253777572086875, 34.74489089420864, 35.3687036378043, 34.332018511635916, 35.039598737444194, 33.82832275118147, 32.91864374705723, 33.58640037264143, 33.49614674704415, 33.50334160668509, 33.142792633601594, 32.51788902282715, 33.72853619711739, 32.718629428318565, 33.19067961829049, 35.523919446127756, 39.96917540686471, 41.83327633993966, 42.98303297587803, 43.77440847669329, 44.89023011071341, 43.0991165297372, 44.146421977451865, 44.59973982402256, 45.68231780188424, 44.00135401317051, 44.97875363486153, 45.09254080908639, 41.337654386247905, 44.11352573122297, 44.471886021750315, 41.14154495511736, 42.24180957249233, 44.96326262610299, 43.60697078704834, 45.983143533979145, 44.58881378173828, 44.06844234466553, 45.66185188293457, 44.26912021636963, 45.2206586429051, 32.80917140415737, 23.118508407047816, 5.688521887574877, 2.124019363096782, 7.007599174976349, 5.430090589182718, 3.374916583299637, 0.11762663748647485, 0.9958589226007462, 35.293819427490234, 38.14151430130005, 25.58831855228969, 17.65386312348502, 31.52396658488682, 40.146920749119346, 4.927110927445548, 0.05815227635736976, 0.026941500936767886, 0.015020010460700308, 0.05773163892860923, 0.040584899551634274, 0.04822765337303281, 0.06063639984599181, 0.02739377336443535, 0.0387796333857945, 0.06539550197443791, 0.01858854486740061, 0.048047960336719236, 0.04090840808515038, 0.055496103529419215, 0.0071960258730021966, 0.016907262316505824, 0.02639224210620991, 0.005427237325680575, 0.04688123294285365, 0.012357441592030227, 0.049947227351367474, 0.07729343032198292, 0.02141513685429735, 0.10477288399956056, 0.024466673377901316, 0.09151008924735443, 0.022988081111439636, 0.050125210479434044, 0.06559630762785673, 0.0398382158683879, 0.04624083498492837, 0.025788244159360017, 9.191885692732674, 42.17291818346296, 46.723960467747276, 43.78351756504604, 59.277736391339985, 59.17028944832938, 46.95977537972586, 38.16073301860264, 43.86373104367937, 23.2587890625, 0.060004690528980324, 0.7955476769379207, 6.030424935477121, 0.6828261826719556, 6.125032041754041, 30.90560817718506, 48.33275331769671, 52.18340676171439, 48.4117682320731, 49.72132648740496, 47.929393018995015, 44.2656044278826, 41.879513127463206, 43.98373338154384, 45.45462185995919, 45.8582045010158, 46.31371450424194, 44.793893337249756, 44.44849143709455, 46.03498404366629, 45.74401780537197, 47.05271795817784, 46.15916919708252, 45.60215990883963, 43.223061970302034, 44.72333090645926, 40.54766852515084, 39.670705114092144, 36.40260253633772, 35.07082046781267, 36.50559220995222, 33.96521268572126, 35.41271700177874, 34.91995423180716, 34.096620491572786, 34.36476884569441, 37.22468212672642, 36.76450293404715, 35.549419334956575, 35.1981566292899, 37.02118328639439, 34.90933738436018, 35.309143679482595, 34.50194713047573, 34.38199690410069, 35.628302233559744, 33.82817683901106, 34.807469844818115, 35.92026206425258, 39.93922867093767, 43.81883525848389, 45.01092726843697, 43.35434470857893, 42.37284564971924, 38.925479548318044, 38.92950602940151, 42.62291826520647, 46.35293013708932, 45.85260425295149, 47.37166806629726, 31.21765525000436, 37.57255063738142, 45.97398580823626, 48.20290538242885, 45.95770270483834, 43.54009090151106, 41.890908173152376, 43.06846802575247, 44.11633627755301, 43.734779426029746, 42.85719762529646, 44.043255124773296, 44.15549285071236, 41.18899072919573, 39.39042173113142, 34.073931149074006, 34.787848131997244, 33.95685052871704, 35.63657406398228, 37.21374566214425, 35.71102748598371, 34.381600856781006, 34.072336537497385, 34.71452726636614, 35.559119020189556, 35.23010444641113, 33.89775262560163, 35.168314116341726, 33.53149570737566, 34.69012519291469, 33.96992703846523, 34.74225057874407, 36.970638615744456, 41.25084359305245, 42.86770330156599, 45.074558871132986, 44.166978222983225, 45.51039852414812, 44.09274366923741, 45.32591690335955, 45.05058063779558, 45.41035836083548, 46.460060937064036, 46.02837978090559, 45.908203738076345, 41.81818832669939, 43.97243561063494, 44.31768117632185, 41.653693199157715, 41.8899701663426, 43.842441763196675, 45.5533766065325, 46.62045315333775, 45.27341284070696, 46.61776072638375, 48.11451734815325, 47.35970674242292, 48.45437805993216, 37.23218618120466, 26.71465802192688, 5.517254437719073, 3.4658791422843933, 5.515919949327197, 9.823410068239484, 4.87190922669002, 0.10074167352701936, 1.1290773855788367, 37.48976285117013, 42.765696798052105, 33.2975811277117, 23.140167679105485, 36.868163108825684, 46.55846132550921, 8.163429839270455, 0.04461085477045604, 0.010332894960551389, 0.03115004314375775, 0.08481966610997915, 0.015567371089543616, 0.010670086152718535, 0.04425557044201663, 0.0031992926129273003, 0.041238230387015004, 0.046285669186285565, 0.0348209718774472, 0.014747599006763526, 0.021255341857405644, 0.07431214422519718, 0.07712352515331336, 0.1552651242486068, 0.12770954572728702, 0.1328976516212736, 0.09220347739756107, 0.09383880107530526, 0.12340192044419901, 0.13101483908082756, 0.11069338702197586, 0.27254460964884075, 0.1536893488040992, 0.12737076676317624, 0.06678936896579606, 0.09113843526159014, 0.14512272205735954, 0.15988976109240735, 0.1927483757691724, 0.19289333799055644, 10.668805207524981, 48.89383772441319, 54.66602938515799, 47.672917638506206, 57.44867522375924, 61.77428667885916, 53.86832754952567, 47.08754580361502, 48.73486294065203, 28.740744045802526, 0.18031027247863157, 2.825668215751648, 10.487416403634207, 1.005365469626018, 7.961873888969421, 35.11121729442051, 49.3481456892831, 52.87752137865339, 50.05873795918056, 50.421975885118755, 48.100124154772075, 45.51382398605347, 43.09810209274292, 44.57329150608608, 44.58075039727347, 46.060893876211985, 48.106506075177876, 45.94801344190325, 47.42603424617222, 47.59657778058733, 48.18253673825945, 49.098149503980366, 48.602468490600586, 48.30869518007551, 45.66084092003958, 46.46518523352486, 43.599720341818674, 40.323408467429026, 39.11940029689244, 35.888432366507395, 37.46938031060355, 35.784150327954976, 37.6117627961295, 35.19595405033657, 36.253150258745464, 35.762214865003315, 37.93872765132359, 37.98769508089338, 38.17305564880371, 35.02367346627371, 39.078788076128276, 35.355776514325825, 37.37727846418108, 36.00369255883353, 37.03182445253645, 37.571327754429404, 34.993473121098106, 36.6712372643607, 38.34764303479876, 42.21878324236189, 48.18281119210379, 46.26077617917742, 46.945826871054514, 45.091015679495676, 41.326488631112234, 41.28753702981131, 45.916444301605225, 47.52402816499983, 48.47574724469866, 49.997145652770996, 37.25660562515259, 37.99701261520386, 47.180839266095845, 52.86801624298096, 49.3445326260158, 45.22845452172415, 44.27850028446743, 45.47968748637608, 46.09424522944859, 43.91604750497, 43.208460330963135, 46.38093485151018, 47.34187766483852, 43.287318910871235, 40.40369142804827, 34.85087871551514, 36.82155111857823, 34.45478275844029, 38.29501737867083, 39.11429337092808, 38.55254193714687, 37.13823611395699, 35.5996687071664, 37.21436752591814, 37.31795474461147, 36.83804266793387, 36.06776884623936, 36.28170040675572, 34.967111655644004, 36.02346018382481, 35.97584070478167, 36.93762077604021, 38.30865321840559, 43.442117827279226, 45.34089374542236, 47.67924744742257, 47.474477086748394, 47.167915616716655, 46.0492730140686, 48.2435245513916, 46.66419901166643, 47.79639754976545, 47.36763116291591, 47.54862131391253, 47.17309897286551, 42.42160810743059, 44.565919467381065, 45.30454771859305, 42.70780440739223, 41.581438882010325, 45.22130135127476, 44.73848492758614, 47.229125772203716, 45.68774781908308, 46.773997919900076, 49.49189696993147, 48.31867626735142, 49.50469207763672, 39.68528243473598, 30.29924236025129, 7.32669562952859, 5.969380233969007, 15.199432815824236, 14.323431730270386, 8.308814815112523, 0.40310022979974747, 1.3595026667628969, 42.249574184417725, 47.62792805262974, 37.306014265332905, 26.834924391337804, 42.7357292175293, 51.58612224033901, 12.089446919304983, 0.1463261174836329, 0.13921880243080004, 0.12708510352032526, 0.14403587180588925, 0.11039810893791062, 0.17437352532786982, 0.17923978849181108, 0.09954126365482807, 0.1177135171102626, 0.2291035492505346, 0.1721113845705986, 0.10968836809375457, 0.14189848649714673, 0.16395886774574006], [0.02616806940308639, 0.050366521280791075, 0.06127359172595399, 0.027607031831783906, 0.013000670737320823, 0.03626519973788943, 0.010447887986499284, 0.014034661414500858, 0.025848905190027187, 0.10258570100579943, 0.028281912939356904, 0.031366047981594286, 0.06496531077261482, 0.026505849224382212, 0.0439833862973111, 0.03481175058654376, 0.06369873695075512, 0.07287679160279886, 0.3313744371490819, 23.234190702438354, 48.79692425046648, 33.20572941643851, 27.447380304336548, 36.17822435923985, 40.549596650259836, 45.862849371773855, 49.71161985397339, 32.21013593673706, 1.377637465085302, 1.1455888024398257, 3.0803852677345276, 7.653617927006312, 24.79096760068621, 27.257023981639318, 38.53595311301095, 48.715960366385325, 47.6146674156189, 45.26866374697004, 44.84669964654105, 42.704427582877024, 43.2642891066415, 42.795125893184114, 44.747955322265625, 46.17056424277169, 45.086040769304546, 44.13363034384591, 44.38142395019531, 43.55445630209786, 43.86498171942574, 44.63667644773211, 47.258864062173025, 44.442995412009104, 43.716512611934114, 43.12072542735508, 42.17081635338919, 41.610551834106445, 39.194680554526194, 34.77558108738491, 32.97249576023647, 34.43453918184553, 34.16096428462437, 34.327860014779226, 33.202717372349326, 33.13421508244106, 33.78399671827044, 32.31014483315604, 32.414409501211985, 35.16584403174264, 33.95744112559727, 33.46666554042271, 35.9478359903608, 33.71153048106602, 32.9511022567749, 32.74062395095825, 33.7804079736982, 32.29688419614519, 34.79343448366438, 41.29586444582258, 44.64238786697388, 45.2603953906468, 45.09386791501726, 41.260588441576274, 40.29019260406494, 36.99299791881016, 38.51855829783848, 41.566750390189036, 45.66991179330008, 41.81679173878261, 34.86693252835955, 40.9675099509103, 42.08432865142822, 48.56931168692452, 46.49123403004238, 45.35210466384888, 44.56029142652239, 43.86095871244158, 42.70435462679182, 44.67381109510149, 44.80050107410976, 44.80381189073835, 43.5478172983442, 43.02320051193237, 39.74800729751587, 32.451092515672954, 30.020112378256663, 32.874963896615164, 33.312488487788606, 33.30686739512852, 33.35552910396031, 32.671183654240195, 32.25361428941999, 33.112856319972444, 32.661880016326904, 31.86749941962106, 33.43729550497872, 33.50770160130092, 32.87819480895996, 33.17535884039742, 31.820578234536306, 34.5320189339774, 41.384071826934814, 40.91855294363839, 43.48792382649013, 41.09554440634591, 43.603159700121196, 43.131533350263325, 43.485137598855154, 44.27260473796299, 42.97132526125227, 41.863681656973704, 41.62766524723598, 43.76616096496582, 44.9788613319397, 46.797434193747385, 46.34018019267491, 43.98318099975586, 44.39558090482439, 42.932759284973145, 44.50076968329293, 44.335075991494314, 42.84088672910418, 43.186372007642476, 43.427092347826274, 45.05126850945609, 42.85563080651419, 38.52941138403756, 21.29706941332136, 10.500933255468096, 2.093201062508992, 2.077028261763709, 9.026395235742841, 6.512613415718079, 3.6875153865133012, 0.04377286062975015, 1.5590466793094362, 33.939299379076274, 34.86498703275408, 28.741021973746165, 20.509320872170584, 33.72665670939854, 29.248143196105957, 1.8677724046366555, 0.057104767566280704, 0.022217268722930124, 0.011681294168478676, 0.05708388225840671, 0.09079939166882209, 0.056586797681770155, 0.046795411833695004, 0.03517415274732879, 0.034821826831570694, 0.018311982475487248, 0.06094138776617391, 0.040344531913953166, 0.00888172144602452, 0.03441452940127679, 0.06399662060929195, 0.04968681578923549, 0.0265626612651561, 0.010334152794842209, 0.041221409503902705, 0.03666945393862469, 0.018993358859526258, 0.03784165371741567, 0.04504786864189165, 0.04129960387945175, 0.021710306372759596, 0.03362617688253522, 0.026685620292222927, 0.04404932972309845, 0.023507930537951843, 0.01955265661568514, 0.013800188549794257, 0.023124427634424398, 1.4407915962593896, 29.88960783822196, 54.86425454275948, 38.656448772975374, 35.31632464272635, 49.628102506910054, 48.85120357785906, 49.120401109967915, 50.6211633682251, 32.606718267713276, 1.1011381362165724, 0.5003934662256921, 2.0609379708766937, 7.3270143781389505, 23.1298565523965, 32.53699656895229, 41.62006391797747, 50.22644315447126, 49.411836351667134, 46.299668720790315, 44.936171599796836, 43.062457833971294, 43.899740082877024, 43.61494384493147, 44.318233558109824, 46.252101353236604, 46.09867123195103, 45.255347524370464, 45.11457354681832, 45.19857726778303, 45.536235400608604, 47.12365211759295, 48.29538937977382, 46.410238879067556, 45.41511787687029, 44.47093759264265, 42.565877028873985, 42.446409702301025, 40.04106841768537, 36.19813789640154, 33.74043498720442, 35.10540860039847, 36.943443366459434, 37.17530475343977, 33.85907547814505, 34.900329044886995, 34.594531876700266, 34.518845149448936, 34.86571659360613, 35.781996386391775, 34.964676312037874, 36.29741375786917, 36.51204013824463, 35.30903250830514, 33.83040026256016, 34.15042039326259, 35.94893727983747, 34.74967472893851, 35.6749906539917, 42.87067713056292, 47.071137632642476, 47.615556785038535, 46.09691333770752, 43.68634353365217, 42.12277998243059, 39.248233795166016, 40.052963733673096, 43.01639475141253, 46.55312163489205, 44.575507981436594, 33.52804592677525, 41.67811264310564, 43.26332330703735, 49.08304064614432, 46.68030146190098, 45.43690047945295, 46.45650345938546, 45.536520276750835, 45.41871009554182, 47.57814768382481, 46.14683267048427, 46.49597617558071, 44.36042649405343, 44.95663057054792, 40.744337286267964, 33.88913685934884, 32.29747826712472, 35.04064791543143, 34.608824321201865, 35.90382957458496, 35.476067202431814, 34.68618556431362, 34.27149275371006, 33.726653235299246, 34.37416628428868, 33.91167681557791, 34.494415283203125, 34.21701192855835, 33.99128232683454, 33.5109429359436, 33.3343961579459, 36.30766582489014, 43.27308900015694, 42.88960402352469, 43.91709668295724, 43.80532448632376, 46.34438732692173, 44.31319611413138, 44.80312054497855, 45.131933620997835, 44.50470583779471, 44.04043068204607, 44.57677255358015, 46.175921303885325, 46.46243027278355, 47.54188503537859, 46.4601616859436, 44.91586201531546, 44.959392479487825, 43.64236838476998, 44.64995098114014, 44.22431823185512, 42.11608191898891, 42.70933648518154, 44.23511225836617, 46.39831229618618, 44.326415061950684, 40.422201429094585, 26.195752654756816, 14.587395531790596, 4.170312702655792, 4.667023352214268, 10.957616635731288, 7.052461521966117, 5.227055106844221, 0.027935144225401536, 1.7295609010117394, 38.64380652563912, 42.22272287096296, 33.93478304999215, 22.17493609019688, 38.008157525743755, 36.8698410987854, 3.1132378705910275, 0.06821383110114507, 0.03521796914615801, 0.03757369006052613, 0.04808482175160732, 0.03732948191463947, 0.03871200040781072, 0.0035259631196303026, 0.006944565460019345, 0.0431576973891684, 0.026573329531986798, 0.03011331966679011, 0.05524374957063368, 0.004378066547880215, 0.04777272617710488, 0.16336160765162536, 0.08639177068003587, 0.1491975826876504, 0.10524674571518387, 0.16319881352995122, 0.12725472370428698, 0.1425304197307144, 0.18300776130386762, 0.15487056970596313, 0.14569308502333506, 0.21252647734114102, 0.15149740927985736, 0.11001865179943186, 0.13188216968306474, 0.13654195464083127, 0.05254785191001637, 0.21977108716964722, 0.14067793770560197, 1.4924678461892265, 36.83473185130528, 61.62865243639265, 45.17357070105416, 39.602817739759175, 46.841492721012656, 48.924774578639436, 54.77072136742728, 57.18843044553484, 39.077422755105154, 2.150759071111679, 2.409847842795508, 10.860594596181597, 11.6397899048669, 32.53538458687918, 39.837802342006135, 41.56284897668021, 51.578958647591726, 49.76842137745449, 47.16719995226179, 44.74177142551967, 45.781454699380056, 44.79365709849766, 44.03753328323364, 45.88037620271955, 48.00380475180489, 47.92936175210135, 47.489801338740754, 46.56979383741106, 46.442026887621196, 47.212780135018484, 47.82005616596767, 50.162901878356934, 48.77827181134905, 45.957733971732004, 46.84886128561837, 45.31993103027344, 44.53067820412772, 41.90842110770089, 38.398139068058555, 35.48013884680611, 37.744838169642854, 38.160778181893484, 38.53661666597639, 35.309452874319895, 36.48675911767142, 37.3944022996085, 35.49088771002633, 36.681353841509136, 37.664669854300364, 36.62061963762556, 38.46783297402518, 39.23213481903076, 36.33977345057896, 36.171182359967915, 36.673891476222444, 36.86815268652779, 36.84679739815848, 38.29048020499093, 45.15464033399309, 46.83722652707781, 48.26071439470564, 48.29031024660383, 45.74235371180943, 44.1156518799918, 41.56019476481846, 42.09963205882481, 43.91790614809309, 48.368046692439485, 45.0281275340489, 37.354915687016074, 43.397757053375244, 44.65171234948294, 51.178978647504536, 48.76869024549212, 46.9594418661935, 48.59075035367693, 47.59746715000698, 46.62100900922503, 47.83439029966082, 48.42455986567906, 48.59268542698452, 46.293384075164795, 47.84926986694336, 43.119019644601, 36.301044191632954, 32.31949363436018, 36.6698510987418, 37.00255864007132, 36.885151454380576, 37.30056687763759, 36.1103196144104, 36.58570841380528, 36.391579219273154, 35.88520492826189, 36.15595538275582, 36.70650979450771, 36.46074506214687, 34.96898766926357, 34.97310447692871, 35.660072871616904, 39.80891520636422, 45.81538275309971, 45.44722897665841, 45.99433013371059, 44.70118352345058, 47.863954884665354, 44.81232343401228, 45.902791091373985, 47.428146498543875, 44.53482280458723, 45.708547251565115, 45.609299182891846, 48.178836822509766, 47.90687043326241, 47.801587854112896, 47.38829163142613, 44.696503911699565, 45.07756049292428, 44.53974560328892, 45.730343750544954, 45.57354375294277, 41.69576454162598, 44.27711064474923, 44.79707908630371, 46.62330886295864, 43.890443393162315, 41.954741273607524, 28.13180218424116, 14.359148076602391, 3.7267783539635793, 6.860586149351938, 19.28050763266427, 12.704254797526769, 11.13560255936214, 0.16410456278494426, 2.1009504752499715, 42.06096880776541, 47.45552934919085, 39.77043955666678, 29.436279569353374, 43.81940501076834, 42.53841427394322, 5.105212799140385, 0.11740230023860931, 0.11905089606131826, 0.10605949496052094, 0.10362837184220552, 0.206319266131946, 0.13113001361489296, 0.16264240124395915, 0.08696510562939302, 0.23235764035156795, 0.11271905153989792, 0.12844036865447248, 0.10703613755426236, 0.08638038486242294, 0.13078462571970054], [0.019263950143275515, 0.044724332966974804, 0.0246742202767304, 0.028521798817174773, 0.052889463757830005, 0.03393380430393985, 0.01640986731009824, 0.06092883486832891, 0.014480829571506806, 0.039183052988456826, 0.01787358778528869, 0.014193902557183589, 0.055385658384433815, 0.027408679082457508, 0.048913448716380765, 0.03346770163625479, 0.05185178693916116, 0.02834581397473812, 0.03775877405756286, 8.00073950631278, 44.131768226623535, 42.60735430036272, 28.1340777192797, 22.45377424785069, 31.528163296835764, 38.90143878119332, 44.49606227874756, 41.05984803608486, 3.9923050659043446, 0.5687493554183415, 0.9886288877044405, 2.010815837553569, 7.803268228258405, 17.461005449295044, 31.379145281655447, 45.71891048976353, 44.76684400013515, 45.84171642575945, 44.321784087589805, 47.370316641671316, 43.63633040019444, 45.85395915167672, 47.69020128250122, 44.452222619737896, 45.56982299259731, 44.59368794304984, 44.255310671670095, 44.05106142589024, 45.50773388998849, 44.62258202689034, 46.24621275493077, 45.52068533216204, 44.86553621292114, 45.83019978659493, 44.471816539764404, 42.108167920793804, 40.40785687310355, 38.7117668560573, 33.90207093102591, 32.30148042951311, 34.52667576926095, 33.130779198237825, 33.84968498774937, 34.58562776020595, 33.17570277622768, 33.59604794638497, 33.15319061279297, 33.892068999154226, 35.01870550428118, 33.5459931237357, 34.83679124287197, 33.519318989345, 33.33772781917027, 33.55445602961949, 33.60182537351336, 32.57784850256783, 37.38070045198713, 44.038891656058176, 45.747154917035786, 43.67622348240444, 44.78467307771955, 43.99167169843401, 41.62864146913801, 37.24772235325405, 38.08714117322649, 38.20898478371756, 44.37190491812569, 45.80403981889997, 48.53128072193691, 42.08421400615147, 38.91338620867048, 48.38706043788365, 47.76422739028931, 45.987868309020996, 45.13239220210484, 47.23787702832903, 49.93853759765625, 47.74813188825335, 45.075166838509695, 45.115640095302034, 46.18574605669294, 45.341668469565256, 39.49443278993879, 32.610042980739046, 31.989270074026926, 34.73344373703003, 32.86368349620274, 33.158787386757986, 34.874082224709646, 34.56440448760986, 34.02591214861189, 33.18730279377529, 32.40649202891758, 33.279071126665386, 32.19914736066546, 31.996141842433385, 33.13666432244437, 32.249209131513325, 32.451745646340505, 38.787908690316335, 43.38494804927281, 43.40166541508266, 44.8544989994594, 44.581938539232524, 43.67062323434012, 42.298916816711426, 44.78491973876953, 44.2087334224156, 42.83092301232474, 43.686458178928916, 41.87532683781215, 41.18606553758894, 41.46212788990566, 43.30113192967006, 43.75846930912563, 44.87627117974417, 43.38597290856497, 45.949416978018625, 43.75888967514038, 43.880660329546245, 44.73176949364798, 43.73460919516427, 42.343558992658345, 41.565016814640586, 42.880932671683176, 32.16244350160871, 9.923225283622742, 1.8844287565776279, 0.6240400256855148, 5.276164974485125, 6.000919410160609, 7.356481688363211, 3.229463428258896, 0.06752935211573328, 2.6396095710141316, 37.879709652491975, 32.81133576801845, 26.32620508330209, 21.554204872676305, 35.70059823989868, 23.273963928222656, 0.5503914547818047, 0.05668113101273775, 0.037557157554796765, 0.03227199061906763, 0.041579197626560926, 0.020015761854925325, 0.015701137483119965, 0.024726686300709844, 0.008869487459638288, 0.010772748501040041, 0.06607577404273407, 0.10302472673356533, 0.03956786376823272, 0.04738097059141312, 0.06001592706888914, 0.0357332113198936, 0.11804694921842643, 0.015932964061253836, 0.0016597902722423896, 0.01974110445007682, 0.07278835134846823, 0.03779530977564199, 0.020535224516476904, 0.029720983933657408, 0.03409506832914693, 0.045249210337975194, 0.02452192987714495, 0.019702187074082236, 0.01273799202005778, 0.033648181773189983, 0.03088166218783174, 0.038583960849791765, 0.022609675702239786, 0.02342665222074304, 12.246885282652718, 52.14846427100045, 43.29947131020682, 30.7097384589059, 29.631777559007915, 40.28417198998587, 45.427874769483296, 49.14967734473092, 42.64285959516253, 4.069171684128897, 0.5219672971538135, 4.224571619715009, 3.2944883619035994, 12.611364330564227, 23.90760142462594, 33.86711801801409, 47.65106555393764, 44.04829951695034, 45.92586953299386, 45.48471450805664, 46.374163831983296, 44.092260769435335, 46.28680065699986, 48.73194122314453, 46.14379630770002, 46.686325550079346, 44.86335447856358, 44.729184763772146, 44.99079833711897, 45.931706019810264, 46.04728235517229, 46.91134296144758, 46.691769463675364, 46.839828627450125, 47.56250728879656, 44.36937229973929, 43.69916990825108, 42.62376594543457, 40.19962978363037, 35.292259556906565, 34.42815031324114, 35.728821822575156, 34.16230876105172, 36.07431057521275, 35.96393149239676, 35.24116250446865, 35.89123249053955, 35.28492225919451, 35.05131687436785, 35.50938034057617, 35.059373310634065, 35.85632126671927, 34.46221385683332, 35.594808442252024, 34.08376979827881, 34.77153723580496, 33.64793709346226, 38.41754886082241, 45.79468059539795, 47.5178199495588, 45.53137166159493, 47.5751564843314, 45.88538237980434, 43.5653406551906, 38.99131025586809, 39.541437353406636, 40.0337415422712, 45.87584597723824, 46.12248618262154, 49.67421075275966, 43.77950498035976, 41.067525795527864, 49.36568294252668, 48.58763408660889, 47.09229489735195, 47.708006041390554, 46.21530021939959, 48.272821630750386, 49.14659581865583, 47.231370040348594, 47.03220340183803, 47.66528156825474, 46.264194692884175, 40.90365947995867, 34.15864706039429, 33.89312859943935, 35.88237353733608, 35.45748424530029, 35.299829619271414, 36.40914079121181, 35.35518939154488, 35.09076527186802, 34.17621210643223, 35.14137942450387, 34.76563474110195, 33.5754326411656, 34.21927009310041, 35.09598684310913, 34.43969474520002, 33.829229491097585, 41.379440852573936, 44.91071687425886, 44.2527745791844, 46.228161334991455, 46.377950600215364, 45.828924792153494, 44.123322691236226, 45.11257593972342, 45.54787710734776, 44.835266385759624, 44.56529065540859, 43.85127639770508, 43.7815477507455, 43.40799174989973, 45.450984477996826, 45.75754247392927, 46.51205083302089, 44.67741026197161, 46.21758270263672, 46.400469711848665, 45.77899851117815, 45.2066684450422, 43.645519392830984, 41.4800820350647, 44.0533960206168, 44.47838258743286, 36.44285345077515, 13.133216602461678, 3.9547235625130788, 0.9456498282296317, 3.9783400552613393, 7.5616854429244995, 8.389032636369977, 1.81566102377006, 0.060826925693878105, 2.823576156582151, 39.16152375085013, 37.37563521521432, 30.91224718093872, 23.158422333853586, 39.02659320831299, 29.58193118231637, 1.0986055178301675, 0.05787170212715864, 0.01794311048329941, 0.029396562770541226, 0.053316163896982155, 0.06693630572408438, 0.03924834841330137, 0.018135195265391042, 0.03936422183843596, 0.040928601287305355, 0.004332248046661594, 0.05348164162465504, 0.03297471541113087, 0.030726050359330008, 0.07902180150683437, 0.09300072211772203, 0.2567727416753769, 0.1258480663278273, 0.10824961601091282, 0.1284573727420398, 0.11808136451457228, 0.08690781691776854, 0.0770529710820743, 0.1434555072337389, 0.1203623821160623, 0.10857004738811936, 0.14719928348703043, 0.13131070749035903, 0.12613204680383205, 0.08403570032013313, 0.11771202433322157, 0.0871699010687215, 0.18947173016411917, 0.06687341231320586, 13.33117859704154, 57.77553238187517, 53.38049800055367, 39.8503542627607, 33.90374892098563, 41.89016124180385, 49.180537768772666, 54.24552093233381, 49.014538356236045, 5.37779540675027, 1.4469170847109385, 8.163024238177709, 3.157694399356842, 9.017409477915082, 24.284238951546804, 37.37556573322841, 46.739010265895296, 45.248753683907644, 47.47999048233032, 45.54950993401663, 48.23631232125418, 45.0430383682251, 48.241863931928364, 50.46371718815395, 47.653667654309956, 48.87657492501395, 46.58287729535784, 46.97348070144653, 47.34231540134975, 47.06362315586635, 47.59843642371041, 49.60718495505196, 49.639928340911865, 48.941540581839426, 49.80109180722918, 47.463905402592246, 46.566201618739534, 44.42119891302926, 43.22420494897025, 36.64590760639736, 36.19771058218819, 36.825435161590576, 35.93455103465489, 37.24101734161377, 37.17624970844814, 36.56948784419468, 35.88459348678589, 36.737179143088206, 36.90614196232387, 37.69734723227364, 36.51535790307181, 38.662684781210764, 36.56120211737496, 36.69273151670183, 35.975736481802805, 36.15098394666399, 35.39679173060826, 42.032561097826274, 47.74582161222185, 48.27250896181379, 47.22647156034197, 48.754863330296104, 47.803147724696565, 44.54352542332241, 40.4906724521092, 41.1203008379255, 41.536160945892334, 47.062087603977744, 48.68465525763375, 52.232395035879954, 46.488673618861604, 42.60670116969517, 51.255603381565635, 51.97577721732003, 49.957492283412385, 50.04042945589338, 47.39129325321743, 50.5389974457877, 50.515797410692485, 49.09395974023001, 47.54516805921282, 49.63449832371303, 47.5830010005406, 44.19634825842721, 36.75369848523821, 35.28146553039551, 38.31334672655378, 36.5120609828404, 37.38716575077602, 39.078659534454346, 37.090227535792756, 36.8231908934457, 35.78848252977644, 36.00038174220494, 36.28185674122402, 35.35200364249093, 34.72126701899937, 36.580698762621196, 35.42513690676008, 36.333322048187256, 44.046847343444824, 47.85678781781878, 46.80355208260672, 48.020685400281636, 48.47950274603707, 46.48815597806658, 45.607155663626536, 46.70942831039429, 47.21167189734322, 47.14540345328194, 48.09224489756993, 44.58833088193621, 44.59151315689087, 43.37092311041695, 46.72046204975673, 47.69953271320888, 48.51572370529175, 45.78433820179531, 49.16154834202358, 46.612389768872944, 47.27026605606079, 45.630230631147114, 44.421129431043354, 41.60281848907471, 44.87718486785889, 44.78167493002755, 39.198981489454, 15.2992228439876, 5.282341488770076, 1.7314160700355257, 12.38677510193416, 12.990059392792837, 13.041963304792132, 9.603280714579991, 0.13823477737605572, 3.380079311983926, 45.37525953565325, 42.54879488263811, 39.258034229278564, 30.910920075007848, 45.8193154335022, 36.48599828992571, 1.8486405398164476, 0.14555357822350093, 0.09493964271886007, 0.11969952125634466, 0.1264654789119959, 0.140487242223961, 0.21794107822435244, 0.11071135462926966, 0.115709409649883, 0.14396595555756772, 0.12064204710934844, 0.19151551835238934, 0.17512421576040132, 0.07910875576947417, 0.12906337236719473], [0.05457183026841708, 0.011661382558356439, 0.018852818990126252, 0.0058943802723661065, 0.030393490168665136, 0.07153696992567607, 0.047476199588605335, 0.03573248189474855, 0.009269228554330766, 0.054659072908439806, 0.009470711894599455, 0.03014579774545772, 0.036224182296012125, 0.013966343964317014, 0.06549247141395297, 0.04619002967540707, 0.07529498862900905, 0.10282229938145195, 0.022040457764108266, 1.2212503424712589, 29.68453175680978, 48.76709910801479, 26.35047514098031, 27.746529783521378, 29.01231959887913, 39.82100159781319, 42.726116384778706, 44.48492431640625, 5.569580887045179, 0.4132706012044634, 2.071369171142578, 0.18637697265616485, 0.600114066685949, 1.8657693692616053, 25.17622263090951, 43.219334261757986, 50.08708313533238, 44.852668149130686, 47.56968477794102, 41.716609137398855, 43.45314114434378, 47.66642107282366, 46.79041998726981, 46.35008484976632, 44.952513762882774, 44.47065619059971, 43.6522730418614, 43.494826861790244, 42.923497336251394, 44.52396624428885, 44.18473434448242, 44.65609666279384, 45.80344922201974, 45.12705945968628, 43.023784160614014, 43.74262741633824, 41.704303877694265, 39.35756369999477, 35.44375807898385, 33.29109845842634, 33.80394499642508, 34.39960363933018, 33.01706845419747, 33.06570584433419, 33.20586838041033, 32.57659782682146, 33.74735539300101, 34.328186580113, 33.77733339582171, 34.01605960300991, 33.67387471880232, 33.00453042984009, 32.123787198747905, 35.13629681723458, 33.663410731724326, 33.78423295702253, 40.85202046803066, 45.26825727735247, 43.80768339974539, 45.450494629996165, 46.33269350869315, 45.54448986053467, 43.190968241010395, 40.78422342027937, 38.76261029924665, 39.410637514931814, 42.61906201498849, 45.11801985331944, 46.82411527633667, 44.070464270455496, 34.44722311837332, 44.03078658240182, 43.36507967540196, 44.375775064740864, 50.06292077473232, 50.40399742126465, 46.78744615827288, 46.49940511158535, 44.17975943429129, 45.81413207735334, 44.673446314675466, 44.45632553100586, 37.751209667750764, 32.783845220293315, 32.27694634028843, 33.20093168531145, 32.34215865816389, 33.525537627083914, 33.95639542170933, 34.18994174684797, 34.65818084989275, 34.170222759246826, 32.973426818847656, 32.0297155380249, 32.42819125311715, 34.006683009011404, 33.551204272678916, 33.3393189566476, 33.937301771981375, 42.083387170519146, 43.26554325648716, 44.107612814222065, 41.159582478659495, 41.5121306010655, 41.24200201034546, 43.229700974055696, 43.35108600343977, 43.79266486849104, 40.45134564808437, 39.35448912211827, 39.847800799778526, 41.30939258847918, 38.79034055982317, 43.21092346736363, 43.71933010646275, 42.37588548660278, 42.874165126255576, 42.29848950249808, 42.60664905820574, 43.30606515066964, 44.61894464492798, 45.62171561377389, 43.594154834747314, 40.58860731124878, 36.6597831589835, 17.32104093687875, 1.4432520185198103, 1.7334889130932944, 0.5330078761492456, 2.0954199263027737, 5.302559443882533, 6.548785303320203, 2.336457060916083, 0.02489205207010465, 3.1545142957142422, 34.59188461303711, 28.758456741060527, 25.57397747039795, 22.20036997113909, 39.156357765197754, 14.249953661646162, 0.1926277322428567, 0.06951289317969765, 0.0094367766619793, 0.05834622202175004, 0.05897439617131438, 0.05197565011414034, 0.10275367913501603, 0.019639556595523442, 0.06603099751685347, 0.042309426835605075, 0.06515121579702411, 0.02393772479678903, 0.02484106525246586, 0.02565274071613593, 0.09822408469127757, 0.029862845250006233, 0.021505437990916625, 0.05668567719736269, 0.03000730535547648, 0.022747783023597937, 0.06554275764418499, 0.059997559125934324, 0.029965755263609544, 0.05976121180823871, 0.04206859779411128, 0.017688340939847485, 0.007241930463351309, 0.04519115827445473, 0.02670820533031864, 0.014397848131401198, 0.08232022130063602, 0.02336318205509867, 0.01763372735253402, 0.04294274088793567, 2.010975646121161, 37.92635638373238, 54.0998797416687, 31.334631647382462, 29.817339624677384, 35.59894609451294, 45.10947009495327, 46.89041498729161, 49.33379765919277, 6.137460197721209, 0.300065528601408, 1.8972779299531664, 2.683521317584174, 0.8266765837158475, 3.8359857967921664, 28.61492259161813, 45.63042518070766, 48.752018042973106, 46.332478114536826, 46.268849985940115, 45.15337923594883, 44.48846442358834, 47.11164910452706, 49.00529030391148, 47.27563353947231, 48.840617997305735, 45.46766710281372, 45.99997901916504, 45.68406874792916, 45.217952319553916, 44.51801858629499, 45.82627058029175, 46.72457538332258, 47.468612807137625, 46.404336384364534, 45.81624780382429, 45.15418175288609, 42.13846206665039, 41.384568623134065, 37.23661913190569, 35.673906735011506, 35.397837434496196, 34.62918601717268, 36.30074889319283, 34.284065519060405, 35.05795240402222, 35.463223457336426, 35.73942824772426, 35.31272894995553, 36.23879528045654, 34.63052354540144, 34.86614738191877, 34.134866850716726, 33.73255920410156, 34.791930198669434, 34.790662152426584, 34.38714551925659, 42.43096038273403, 47.58258410862514, 45.81143965039934, 47.53631952830723, 46.33995090212141, 47.03358956745693, 44.61549139022827, 41.734771728515625, 41.563575063432964, 40.721314430236816, 44.79653712681362, 46.58201224463326, 49.49153913770403, 45.13327809742519, 36.63538803373064, 46.20684773581368, 45.32639285496303, 44.18702377591814, 48.299044132232666, 49.491542611803325, 49.06418670926775, 47.16290596553257, 45.39816427230835, 46.56049714769636, 46.39824628829956, 45.86713988440377, 39.44958911623274, 35.05990832192557, 33.47818217958723, 34.54668310710362, 34.12823826926095, 35.75887972967965, 35.0072375025068, 35.14333186830793, 36.28508765356881, 34.92350476128714, 34.61024522781372, 33.7913235936846, 34.15650701522827, 34.94986970084054, 34.78430455071585, 35.45242248262678, 35.537972177777974, 43.1350873538426, 45.36780759266445, 46.214379583086284, 44.58128540856497, 41.68592936652047, 41.727337156023296, 43.97398853302002, 44.82711614881243, 44.523327010018484, 42.997579029628206, 41.68158674240112, 40.86150128500802, 42.390080656324116, 42.176548617226736, 43.4214643069676, 44.38054152897426, 43.99204690115792, 45.064619473048616, 44.81397363117763, 44.53698369434902, 44.99743734087263, 46.916533265795024, 45.78020402363369, 44.62252991540091, 42.48682737350464, 40.89582886014666, 21.026758432388306, 3.667719534465245, 3.6555488961083547, 2.505217948130199, 1.1353587742362703, 7.099345360483442, 2.8463308555739264, 0.17329645955136844, 0.009819759638048708, 3.4863315990992954, 39.68719318934849, 35.10349089758736, 31.947066715785436, 25.51791419301714, 46.04349211284092, 19.677314043045044, 0.4185239007430417, 0.06432963202574424, 0.02259054610372654, 0.032749960864228864, 0.027894622114087855, 0.04883236378165228, 0.0041560125703524265, 0.03433646394738129, 0.06461869472903864, 0.0428849398823721, 0.03143370470830372, 0.01729317401934947, 0.0660505596814411, 0.02010246505960822, 0.07394991509084191, 0.10030867997556925, 0.13779672873871668, 0.07626900529222828, 0.10528909308569771, 0.11789301676409585, 0.13532013020345143, 0.19261462294629642, 0.10244221799075603, 0.28388067707419395, 0.12910667647208485, 0.11102175047355038, 0.12353092352194445, 0.2451518252491951, 0.11669994864080634, 0.10085849011582987, 0.12967573665082455, 0.15088889907513345, 0.18389338521020754, 0.10732701873140675, 2.5387723190443854, 42.96111140932356, 60.805068561008994, 37.73001766204834, 38.56070607049124, 40.19427619661604, 50.53649262019566, 50.202312060764854, 53.48043394088745, 8.082815102168492, 0.5602122992277145, 5.940188680376325, 6.027208353791918, 1.536003195813724, 4.081868214266641, 32.206873757498606, 45.467910289764404, 50.521526200430735, 45.440100124904085, 48.264244079589844, 46.60076890672956, 46.82100248336792, 47.862085819244385, 50.311537742614746, 48.35474784033639, 50.28663192476545, 47.86284664699009, 46.19167981828962, 47.01028183528355, 47.128050327301025, 46.935956954956055, 46.93413305282593, 47.716969217572895, 49.725825445992605, 46.95710032326834, 48.36677517209734, 46.84309080668858, 45.2768417767116, 43.13411113194057, 39.16673837389265, 38.18209178107125, 37.20183644975935, 37.444425855364116, 37.669748987470356, 36.103444371904644, 37.213401726314, 36.60041427612305, 37.57946062088013, 36.75572735922677, 37.320838247026714, 36.846564633505686, 36.32486956460135, 36.01897512163435, 34.97136742728097, 38.240449701036724, 37.09407683781215, 35.88332544054304, 45.246137687138145, 49.233437878744944, 46.08727618626186, 48.42377471923828, 48.89735003880092, 51.05459199632917, 45.84063250677926, 43.12938635689871, 42.97659199578421, 42.42569017410278, 46.63269240515572, 48.62850686482021, 50.460864952632356, 47.79492800576346, 37.3159293447222, 47.48739726202828, 45.49699197496687, 45.59061547688076, 50.272398539951865, 50.20042562484741, 50.024052551814485, 49.24395745141165, 45.51943813051496, 48.00022642953055, 47.90109648023333, 48.08175311769758, 40.93465191977364, 36.431489671979634, 34.60286971500942, 36.35528530393328, 35.27035536084856, 37.68383993421282, 37.40524843760899, 37.85332039424351, 38.13562222889492, 37.48183495657784, 36.69668851579939, 34.79221854891096, 36.38404737200056, 37.50398233958653, 37.77109541211809, 37.561346667153494, 38.462204933166504, 44.87659427097866, 48.13810995646885, 47.59081424985613, 44.515016964503694, 43.592636653355186, 42.92804493222918, 45.01346683502197, 46.0203719820295, 47.49040930611746, 44.497670786721365, 43.04833909443447, 42.39153282982962, 45.22244085584368, 43.37115934916905, 45.46642337526594, 47.655533245631624, 46.411138670785085, 45.048186983381, 46.782950673784526, 45.88936022349766, 48.334031786237446, 48.813106604984824, 48.13395493371146, 45.008384227752686, 44.5615907396589, 41.22774083273751, 24.141543797084264, 5.452211047921862, 6.447854467800685, 6.810952126979828, 8.348428232329232, 17.613264799118042, 15.36286313193185, 6.8286791528974256, 0.14595548808574677, 4.1005480119160245, 41.86989334651402, 39.258395535605295, 37.35026386805943, 30.634468623570033, 51.73767287390572, 23.62054875918797, 0.854468292423657, 0.16991998787437165, 0.08640664416764464, 0.1711028508309807, 0.13516231652881416, 0.11125938022243125, 0.18898300853158745, 0.1918979271181992, 0.14262530606772217, 0.17508273012936115, 0.22180726219500813, 0.11536547381963048, 0.15922216405825956, 0.17127300027225698, 0.14956530795565673], [0.029298941937408278, 0.023531202592753937, 0.01450004568323493, 0.057556129060685635, 0.029733574150928428, 0.055517263643975766, 0.02656103278111134, 0.01978952301267002, 0.06635598186403513, 0.0821611387655139, 0.02897690243220755, 0.059908942452498844, 0.0484105965920857, 0.019471827827926193, 0.04963813090164747, 0.032658684333520274, 0.04769764966996653, 0.05526971371312227, 0.017896372991214906, 0.19015466208968843, 7.594387139592852, 44.55077586855207, 38.267710958208355, 24.398543766566686, 27.259474958692277, 35.1393574987139, 39.20595748083932, 48.30311230250767, 8.005395667893545, 0.1288776844739914, 1.4295745981591088, 1.5829197125775474, 1.8159577335630144, 0.7670650567327226, 9.722788861819676, 38.473516600472585, 44.42053883416312, 46.30386890683855, 41.452622754233225, 39.01877301079886, 42.68158885410854, 46.74342237200056, 44.547562326703755, 46.184853213174, 44.25088119506836, 45.39316156932286, 45.12983873912266, 46.05515119007656, 43.19015530177525, 43.46292073386056, 41.39862830298287, 44.92118780953543, 46.173906326293945, 44.484472683497835, 42.4506515775408, 42.391494614737375, 40.69921221051897, 39.10755361829485, 35.97908551352364, 34.734888962336946, 32.84215450286865, 33.872534138815745, 33.982941014426096, 34.97574826649257, 36.53557368687221, 34.36522395270211, 33.98129429136004, 34.41191584723336, 33.356609548841206, 35.274704933166504, 33.4518415587289, 33.568887438092915, 32.978794302259175, 31.6665575163705, 32.47455658231463, 33.31521565573556, 40.73127119881766, 45.321421418871196, 42.71644796643938, 43.083896500723704, 46.277166979653494, 45.61028235299246, 45.65536573954991, 42.39449276242937, 41.681082998003276, 41.20064980643136, 42.36581407274519, 45.50107404163906, 46.930766650608604, 44.22055230821882, 36.176636695861816, 43.330880641937256, 39.86920125143868, 39.37884603227888, 38.43718447004046, 39.78283861705235, 43.485318252018516, 44.2065760067531, 45.48937674931118, 45.84866809844971, 42.973218645368306, 43.028053828648154, 35.24758958816528, 34.01100131443569, 33.017982142312185, 32.202340057918, 33.8296776499067, 33.64125640051705, 32.073527404240195, 33.73197555541992, 32.26800748280117, 33.93788889476231, 32.32678576878139, 33.24180793762207, 33.622968741825645, 31.633987835475377, 33.433689389910015, 31.999160834721156, 33.127454485212056, 40.50646570750645, 45.011882645743235, 43.4673502104623, 42.13740941456386, 41.192708015441895, 42.007179328373496, 44.54469619478498, 43.2496075630188, 44.294356073652, 40.74410104751587, 42.264835902622764, 38.94709192003523, 38.27439512525286, 37.72184658050537, 36.869750772203716, 39.67861911228725, 39.53075449807303, 38.80226019450596, 39.584842750004356, 37.97511189324515, 40.19626338141305, 39.97773558752877, 43.20499317986624, 44.74676023210798, 42.592565059661865, 29.888888699667795, 7.802588173321315, 2.793470914874758, 5.016905537673405, 3.2544736862182617, 1.0744396831308092, 3.0868798792362213, 5.602643021515437, 0.5591103583574295, 0.11276274240974869, 3.8948092460632324, 27.710942847388132, 24.941324881144933, 19.228573322296143, 25.289386204310826, 38.374695846012656, 8.727098107337952, 0.09938965857561145, 0.0353700933046639, 0.01916665500695152, 0.006957306651332016, 0.06146272657705205, 0.022951060240822177, 0.021928222983011177, 0.013929191627539694, 0.051560722557561736, 0.05331711384600826, 0.016160339449665377, 0.02008204285188445, 0.012680142668874135, 0.05308144845600639, 0.006678868110092091, 0.009404503840154834, 0.026439829463405267, 0.021203225278960805, 0.020012387839545096, 0.11587003245949745, 0.02199584578296968, 0.03917475450517876, 0.060948281681963375, 0.02141899093320327, 0.048365256882139614, 0.018872571144519106, 0.09234594939542667, 0.010850015828119857, 0.03172661131247878, 0.0644158466852137, 0.021545481735042164, 0.020006778051278422, 0.039044743802930625, 0.012780023023619183, 0.17872807809284755, 12.146941525595528, 52.730348110198975, 38.60741880961827, 28.32765105792454, 28.229547704969132, 44.180252756391255, 44.542330333164756, 51.245743887765066, 7.953345843723842, 0.11699730982737881, 1.6403265978608812, 3.060950504881995, 3.397354704993112, 0.5774062680346626, 14.1280631508146, 40.550718784332275, 45.152420384543284, 45.334223474775044, 43.10448053904942, 41.33029971803938, 45.02598054068429, 46.766066551208496, 47.76897995812552, 47.969386850084575, 46.258379050663535, 46.01091200964791, 48.41002076012747, 45.263779163360596, 44.09488024030413, 45.540849004473, 44.20467220033918, 46.423958097185405, 46.71021693093436, 46.209595748356406, 44.7292994090489, 44.34144401550293, 41.895358494349885, 41.09211547034127, 37.08383519308907, 36.51617431640625, 34.28633757999965, 34.623436382838655, 36.490580626896445, 35.36871058600289, 36.28704704557146, 35.48844541822161, 34.928670746939524, 35.706552846091135, 35.06545645850045, 35.73619038718087, 34.928729806627544, 35.091185637882774, 34.3358712877546, 33.62436532974243, 34.835568359919954, 35.070375783102854, 41.91853073665074, 47.94310528891427, 44.10094254357474, 45.929409640175955, 48.305353096553254, 44.934629099709646, 46.46856205804007, 42.31614140101841, 44.09786796569824, 41.4344288962228, 43.07479436056954, 46.68408128193447, 49.17940173830305, 46.57686710357666, 37.4040915625436, 42.46059444972447, 40.875116280147004, 39.69068465914045, 43.20922463280814, 42.95419447762625, 44.32050214494978, 44.370862688337056, 46.83554853711809, 47.44556563241141, 45.89458179473877, 43.91315705435616, 37.40728773389544, 35.37748963492257, 34.20005832399641, 33.231719153267996, 34.89053208487374, 34.948650291987825, 33.68476949419294, 34.88383749553135, 34.111267294202534, 35.94360801151821, 35.19549546922956, 34.819625718253, 34.875075817108154, 33.49722719192505, 34.74862902505057, 33.083211830684114, 34.746850286211284, 42.97491747992379, 46.834315231868196, 43.068068504333496, 42.43614721298218, 42.612433433532715, 43.33365644727434, 45.84792116710118, 44.906450680324006, 44.612767696380615, 42.6502594266619, 42.69978271211897, 40.71228872026716, 40.55965069362095, 38.701275076184956, 39.39138753073556, 42.01437766211373, 42.010601316179546, 40.66224431991577, 42.89032663617815, 38.55250024795532, 42.21373190198626, 41.67490257535662, 44.83699996130807, 44.74542270387922, 44.4624399457659, 32.648476941244944, 11.713399120739528, 3.2108357420989444, 8.322620017187935, 1.9582364303725106, 0.33729826499308857, 1.281963158931051, 2.082491717168263, 0.47834319514887674, 0.08153193324272122, 4.649378836154938, 33.226400307246614, 29.88887827736991, 25.608313730784825, 27.120271274021693, 43.38205065046038, 11.96064989907401, 0.051726902568978925, 0.07515979052654334, 0.02710496850444802, 0.09277339931577444, 0.06481995500091996, 0.05669785350827234, 0.01415303863385426, 0.04146330723805087, 0.03350987937301397, 0.060312412945287566, 0.030829737295529673, 0.09199193053479705, 0.021633815120107362, 0.08351151166217667, 0.03786364503737007, 0.09170799077089344, 0.07897726925356047, 0.14282864944211074, 0.1808163510369403, 0.17900268121489457, 0.18433551862835884, 0.12069791768278394, 0.19119951102350438, 0.1380498901541744, 0.28930404462984627, 0.10679168852844409, 0.21359758558017866, 0.11630946530827455, 0.14000924144472393, 0.1844394159104143, 0.11360141169279814, 0.10882584151944943, 0.0965345867776445, 0.14343102569026606, 0.24344495683908463, 13.995732971600123, 60.76041943686349, 48.39734377179827, 37.83143704278128, 36.267216886792866, 46.05078077316284, 47.849196910858154, 58.72107451302664, 10.34480723312923, 0.31017380048121723, 3.527259962899344, 4.497477752821786, 2.759893528052739, 1.1778068393468857, 14.964760882513863, 41.53071355819702, 46.040639877319336, 45.992652143750874, 43.336143902369905, 42.22706202098301, 48.23854269300188, 48.686291558401926, 48.7684713772365, 48.4441294670105, 46.85847064426967, 47.995491232190815, 49.74359198978969, 47.815470354897634, 46.171300751822336, 46.98953104019165, 47.44204289572579, 48.6581826210022, 48.600015776497976, 47.2511237689427, 46.61797612054007, 46.592966079711914, 44.53817183630807, 44.50260400772095, 40.221155302865164, 38.21300779070173, 36.65215751102993, 35.815886225019185, 38.31576122556414, 37.05142879486084, 39.862319060734336, 37.48324196679251, 37.11729424340384, 38.62551539284842, 37.57009097508022, 37.75317253385271, 36.75934042249407, 37.13754824229649, 35.53374072483608, 34.225652013506206, 35.307590757097515, 35.76720367159162, 43.40167236328125, 49.026544843401226, 45.46792071206229, 46.790624959128245, 49.730223655700684, 48.78965990883963, 48.254870959690635, 43.89925023487636, 46.874010290418354, 43.78821107319423, 45.806304931640625, 48.58533075877598, 51.515820366995676, 48.240311009543284, 39.89972121374947, 43.45707035064697, 41.97133009774344, 41.581497941698345, 42.939492089407786, 46.20267186846052, 47.02828114373343, 45.6403819492885, 48.806325163160054, 50.25401708057949, 46.557585852486746, 45.69965703146798, 39.04655885696411, 37.22274357931954, 36.609287125723704, 35.41749388831002, 36.88040236064366, 36.63278940745762, 34.83645078114101, 36.25437314169747, 35.16606289999825, 38.294621331351145, 36.24058791569301, 36.80036606107439, 36.23999037061419, 34.715131759643555, 36.0658164024353, 33.60490689958845, 36.6565591948373, 45.02058179037911, 49.05470241819109, 45.091029575892854, 44.59649848937988, 44.32959038870675, 44.14757537841797, 47.455046449388774, 46.98574079786028, 48.569356850215364, 45.24993487766811, 46.06209938866751, 41.959413937159944, 43.724138259887695, 41.122725759233745, 39.87027127402169, 42.66418014253889, 43.31033134460449, 42.70675522940499, 44.69738980701992, 40.62772914341518, 43.23445701599121, 43.45027501242501, 47.15404353822981, 48.06809295926775, 46.284191608428955, 34.517636162894114, 15.326555320194789, 5.006996972220285, 12.752246005194527, 7.752569828714643, 2.66153113756861, 8.246099506105695, 12.489940217563085, 2.208933515208108, 0.17698949495596544, 5.104256119046893, 38.598243713378906, 34.137920583997456, 30.49911424091884, 34.110805238996235, 50.118405614580425, 16.459770032337733, 0.1958923949194806, 0.18934858962893486, 0.13544511635388645, 0.24249967613390513, 0.2132698938782726, 0.16253372707537242, 0.10649594225521598, 0.23098941519856453, 0.11000616675508873, 0.14791090387318814, 0.09160737759832825, 0.11326884810945817, 0.10869329648890666, 0.2668195111410958, 0.11906457532729421], [0.032837196718901396, 0.01664289489521512, 0.07035536904420171, 0.020391018861638646, 0.03996098320931196, 0.016712110556129898, 0.07940560805478267, 0.022123296711859957, 0.053220554920179505, 0.006856313075071999, 0.01741405333658414, 0.03167321060651115, 0.03036785850833569, 0.03523944138682314, 0.03470621803509338, 0.02811688304479633, 0.018465970908956866, 0.014220596124817218, 0.04227788174258811, 0.034423092513212135, 2.116584356342043, 28.82960455758231, 41.613483973911826, 28.93604748589652, 27.494456086839946, 36.161208220890586, 33.6798050062997, 48.87289237976074, 11.239753450666155, 0.10777806131435291, 0.3245357269687312, 4.386760379586901, 0.9753477317946297, 0.22622752429119178, 1.8868347874709537, 24.967913900102886, 44.3686774798802, 45.52868618283953, 47.75933585848127, 44.86255890982491, 43.49015767233712, 48.056802136557444, 45.9884033203125, 45.92796094076974, 45.80277872085571, 45.99632774080549, 45.964602266039165, 44.391988686152864, 42.44839688709804, 44.16302817208426, 45.01787199292864, 44.44951977048601, 45.32363442012242, 44.147828987666536, 43.300617762974326, 41.58116790226528, 41.12303147997175, 40.68417978286743, 38.86723974772862, 37.42181989124843, 35.41404758180891, 34.09679419653756, 33.37903485979353, 35.583944933755056, 33.82951089314052, 34.26858493259975, 32.99641840798514, 36.39282989501953, 34.47726365498134, 34.793250356401714, 34.69645152773176, 32.66594123840332, 34.141495432172505, 32.8358142716544, 30.929888657161168, 34.58923734937395, 40.68959590366909, 44.69200495311192, 44.441779477255686, 42.85909448351179, 46.661551748003276, 46.45799037388393, 45.646822929382324, 45.35434545789446, 43.18332174846104, 42.21803283691406, 42.602049350738525, 44.692147391183035, 47.35592344829014, 42.40564809526716, 36.9441625050136, 43.93914679118565, 45.66272040775844, 45.54840169634138, 43.748130389622276, 44.621512004307334, 45.93107373373849, 45.29272883278983, 43.15270798546927, 43.02021278653826, 42.43639734813145, 36.29860884802682, 32.4997090612139, 32.18807888031006, 31.935008117130824, 33.302952085222515, 32.82198388235909, 32.564209188733784, 32.92420230593, 31.67680958339146, 32.345413889203755, 32.801861899239675, 33.35026931762695, 34.195639269692556, 36.48233658926827, 33.557746001652305, 32.33432109015328, 32.86582006726946, 32.771856103624614, 41.4370379447937, 43.64337239946638, 44.66880144391741, 42.77180773871285, 41.761268683842246, 41.89520215988159, 42.52419825962612, 43.9806136403765, 42.5160619190761, 40.85336147035871, 39.917122977120535, 38.25456844057356, 37.826896395002095, 35.99805409567696, 34.76437016895839, 35.4445675441197, 34.729931422642295, 36.31604882649013, 36.829576287950786, 37.05569846289498, 38.912753922598704, 41.36661100387573, 43.065528937748496, 45.33860778808594, 38.38615689958845, 19.512073721204484, 2.630243616444724, 1.7315553597041538, 7.7237096173422675, 0.9027646237186023, 0.43008133343287874, 0.06650656914072377, 0.9715662832771028, 0.05469640251249075, 0.05448042820873005, 7.07095284972872, 32.61913122449602, 27.469077791486466, 19.52595795903887, 27.551294088363647, 39.19609103884016, 4.219084714140211, 0.1397096953753914, 0.10428208604987178, 0.008252462488599122, 0.0210334422465946, 0.05214020164151277, 0.028680297812180858, 0.04690052708610892, 0.055335484112479856, 0.02077042341365346, 0.06827457355601446, 0.027000192519543425, 0.054790606921804805, 0.025478021341509054, 0.03006623951452119, 0.1018144441768527, 0.018104600121400187, 0.04343554051592946, 0.013269181463069149, 0.09319290359105382, 0.06608895797814641, 0.008416814696309822, 0.0640849590833698, 0.01783951006031462, 0.027263367415538857, 0.02170633355022541, 0.05134800861456564, 0.030591602038059915, 0.069598666791405, 0.054030986968427896, 0.04395756125450134, 0.010764921599599932, 0.06510043423622847, 0.04756988152595503, 0.03219112281554511, 0.02885504432820848, 3.2053861830915724, 37.467243739536826, 47.186206749507356, 32.16569525854928, 29.612923622131348, 38.97541625159127, 38.585577147347585, 52.39457988739014, 11.831137214388166, 0.06998932654304163, 0.8944345478500638, 3.6332790510995046, 3.0814492106437683, 1.0953381274427687, 2.1257818170956204, 30.111227580479213, 45.9797180720738, 46.374983719417024, 46.74544777188982, 46.27431127003261, 44.99341433388846, 49.33521161760603, 45.783692019326345, 48.301205021994456, 46.22465596880232, 47.412634645189556, 47.4067599432809, 46.630319595336914, 42.417512144361226, 45.84772661754063, 46.12753752299717, 45.43657738821847, 46.124330929347444, 46.772747244153706, 45.179862294878276, 44.142503193446565, 42.48621245792934, 41.56458602632795, 39.913794789995464, 38.51929133278983, 36.3849332673209, 35.581457478659495, 34.63999394008091, 37.26684032167707, 34.558866773332866, 35.692479269845144, 35.53954594475882, 38.05978264127459, 35.64541564668928, 36.383588790893555, 35.86228976930891, 33.89646373476301, 35.966714245932444, 35.2976861000061, 33.01344844273159, 36.13080985205514, 42.41642822538103, 47.32479551860264, 45.43756750651768, 46.306120123182026, 47.41546951021467, 47.6797650882176, 46.757857254573274, 47.640323638916016, 44.65445341382708, 43.2722031048366, 43.759587969098774, 47.86050162996565, 48.75704506465367, 45.22467122759138, 38.09202575683594, 45.614812578473774, 46.553211961473735, 47.12441989353725, 44.566819259098594, 46.69672005517142, 47.56843410219465, 46.4070531300136, 44.94343594142369, 44.98406205858503, 45.368756021772114, 38.44031115940639, 34.81330285753523, 33.57210097994123, 32.950143405369346, 34.52837460381644, 33.59415108816964, 34.046395438058035, 35.37870904377529, 33.056801727839876, 32.64738259996687, 34.28271756853376, 34.04732302256993, 36.63564164297921, 38.147719042641775, 35.980683599199565, 34.32141556058611, 35.14100769587925, 35.49360792977469, 42.45153052466256, 44.4519168989999, 45.38373286383492, 44.49523196901594, 43.09593078068325, 43.483268533434185, 44.13993583406721, 43.92024769101824, 43.777868679591585, 41.962287017277305, 41.56778219767979, 42.298986298697336, 39.78626755305699, 37.670207568577354, 36.21360458646502, 37.685757637023926, 36.12298270634243, 38.16579825537545, 38.65448243277413, 39.14318050657, 40.34489924567086, 42.22464057377407, 44.37303400039673, 47.21916205542428, 40.628767899104524, 22.890223605292185, 4.391897703920092, 2.267235198191234, 10.986831205231802, 1.2648055596011025, 0.42226667276450564, 0.4283555746078491, 0.7232151382735797, 0.02480883144640497, 0.02303673037593918, 7.671818733215332, 36.391898836408345, 29.857663495200022, 21.07151872771127, 31.751589570726665, 44.352046966552734, 6.181879162788391, 0.07975785593901362, 0.03285422794786947, 0.04006759802411709, 0.01712593718964074, 0.043188418062137704, 0.01686589712543147, 0.06496363479111876, 0.037422346217291694, 0.01655837657329227, 0.0277374377806804, 0.013793642383201845, 0.04800650863243001, 0.034907692045505555, 0.012832002198722745, 0.02480795274355582, 0.12178353300052029, 0.14280025953693049, 0.1565220696585519, 0.17271998977022512, 0.10560418439230748, 0.1184638004217829, 0.17909872106143407, 0.1018331717433674, 0.13266661044742378, 0.18622958127941402, 0.1620476245880127, 0.09502828653369631, 0.109612738580576, 0.08947521700922932, 0.12047465252024786, 0.14667656725006445, 0.16509074558104786, 0.13244615441986493, 0.13317551171141012, 0.08908737996327025, 3.6015913571630205, 42.64082724707467, 52.650145053863525, 40.06639807564871, 36.87201935904366, 45.68109491893223, 43.005322796957834, 57.683823108673096, 13.993136082376752, 0.2104321654353823, 3.1484274566173553, 9.72085986818586, 3.4871797135898044, 0.8754567376204899, 3.47792341027941, 30.72527810505458, 45.98016970498221, 46.49363463265555, 49.29881347928728, 47.31951836177281, 47.754920278276714, 49.52454308101109, 49.139119556971956, 50.569812706538606, 48.5420434815543, 48.9067440032959, 48.80699219022478, 45.76806204659598, 44.171334743499756, 45.90658828190395, 47.83343492235456, 45.86392634255545, 48.932202202933176, 47.358720098223, 45.87501219340733, 45.93820605959211, 44.66891608919416, 43.945445333208355, 43.39144808905465, 40.69029767172677, 39.65967832292829, 36.72558259963989, 36.49255044119698, 38.789041246686665, 36.77005801882063, 36.521871839250835, 36.61393894468035, 39.84676899228777, 37.027627740587505, 39.38467557089669, 37.11505692345755, 35.22164848872593, 36.92170940126692, 37.53032643454415, 34.23083536965506, 37.49491841452462, 44.527975354875835, 48.297560691833496, 48.07559353964669, 47.43113422393799, 50.0487117086138, 49.3522937638419, 50.049333572387695, 49.72748259135655, 46.62835325513567, 46.61656216212681, 46.048519134521484, 48.94865206309727, 50.336387974875315, 44.956571510859895, 41.49801186152867, 47.0677364894322, 47.905810832977295, 48.84411294119698, 46.13521875653948, 47.57988125937325, 48.21211174556187, 47.4627936908177, 46.32816328321184, 46.11206041063581, 45.866844585963655, 39.095946652548655, 36.12090172086443, 35.18767179761614, 35.01506117412022, 36.014125279017854, 35.24781540461949, 35.63247462681362, 37.09967361177717, 34.47862202780587, 35.03524916512625, 35.58119344711304, 35.28563444955008, 38.869233880724224, 39.61381326402937, 36.87784889766148, 36.34848996571132, 36.24609088897705, 37.73965828759329, 44.90063851220267, 47.77780417033604, 46.06944710867745, 45.71952887943813, 43.28767326899937, 44.61532463346209, 44.70082221712385, 45.01933111463274, 44.90856293269566, 43.90509366989136, 43.18928330285208, 42.631933552878245, 41.174253599984304, 39.23205838884626, 37.057049887520925, 40.25184897014073, 36.80267286300659, 40.306361062186106, 40.70537873676845, 42.091773646218435, 43.189543860299246, 45.04812444959368, 45.65812417439052, 48.19755179541451, 40.25223459516253, 26.782983132771083, 5.965052809034075, 4.603760872568403, 19.31998556000846, 3.3573302584035054, 1.5137135918651308, 3.650449352605002, 2.8425330136503493, 0.397263552993536, 0.2211132701486349, 9.902622137750898, 42.64671931947981, 36.80479206357683, 30.61215100969587, 38.775533948625835, 51.2396468435015, 7.578187414578029, 0.21721130024109567, 0.20586329059941427, 0.17052203842571803, 0.05997464499835457, 0.10222019454730408, 0.2060896498816354, 0.14062837750783988, 0.1264984964260033, 0.05415737768635154, 0.12687288490789278, 0.09451357022460018, 0.09843010827898979, 0.11007121790732656, 0.13762447583888257, 0.17700022937996046], [0.04147822143776076, 0.017601459619722197, 0.01982600275161011, 0.031735483157847605, 0.04912862913416965, 0.03913980655904327, 0.06725084063197885, 0.03778054824631129, 0.039512040692248514, 0.020894023656312908, 0.07959265980337348, 0.05885532684624195, 0.003880150765845818, 0.04481015407613345, 0.025782943104526827, 0.03257705996345196, 0.03894534181537373, 0.013633356296590396, 0.046434862073510885, 0.02207426237873733, 0.11361199683908906, 17.096153804234095, 41.7219557762146, 31.671376092093332, 20.493722166333878, 31.753885950360978, 32.69532864434378, 41.949783733912874, 18.58620888846261, 0.006094284322378891, 0.5255676582455635, 3.9210469467299323, 3.6773610285350253, 1.562814774257796, 0.4804918169975281, 9.163271273885455, 38.25569404874529, 44.809234959738596, 47.722301959991455, 49.86174610682896, 45.32415553501674, 45.82800415584019, 46.63677794592721, 43.757256848471506, 46.993967464991975, 47.32372202192034, 46.0534210886274, 46.31519447054182, 42.97381271634783, 43.39229229518345, 43.86653116771153, 44.72071838378906, 44.29113558360508, 46.00703838893345, 44.33272402627127, 44.670229298727854, 44.14074877330235, 43.74920736040388, 42.30311352866036, 42.68733154024397, 40.45720297949654, 37.14559425626482, 35.256465911865234, 33.63174431664603, 34.03647688456944, 33.2004348891122, 33.073703220912385, 34.84856843948364, 36.257791655404226, 36.55707836151123, 35.016704423086985, 32.17311940874372, 34.93871784210205, 33.41324084145682, 32.84348855699812, 32.93352678843907, 40.0960008757455, 44.08126177106585, 44.46721683229719, 40.70477076939174, 44.81679459980556, 45.04302794592721, 47.451568875994, 44.71836641856602, 43.50896297182356, 44.49905347824097, 44.70034973961966, 46.90891456604004, 46.54518331800188, 41.45620107650757, 38.9001464162554, 48.37792355673653, 44.16641889299665, 44.1826742036002, 44.337563446589876, 43.77927221570696, 43.896165234701975, 44.886255741119385, 41.338057381766184, 41.387542452131, 36.20282793045044, 32.80281727654593, 31.90856327329363, 32.59097712380545, 33.31633084160941, 32.82910578591483, 33.52237272262573, 32.99913167953491, 33.60069281714303, 32.33041967664446, 32.4989447593689, 33.44056115831648, 32.671510219573975, 33.69632434844971, 33.04979794366019, 36.8579284123012, 34.07784993307931, 33.253637245723176, 32.13385166440691, 39.76203571047102, 41.333506311689106, 43.424719538007466, 44.773371832711355, 42.888141427721294, 40.30071217673165, 41.91598769596645, 43.73691599709647, 43.845766476222444, 43.77990797587803, 41.44493804659162, 41.10084935597011, 40.13111359732491, 37.86699097497122, 36.3726349558149, 35.923298427036826, 35.42813852855137, 34.03070640563965, 35.362644808632986, 39.28076526096889, 39.593375137874055, 40.985755920410156, 43.255725451878135, 44.750887462071006, 32.065168721335276, 5.2941747052328925, 0.20955344901553222, 1.2551405067954744, 1.3110500552824564, 0.13681065450821603, 0.07805175427347422, 0.16718900656061514, 0.056410344650170634, 0.05642797638263021, 0.011678973578714898, 8.037777747426714, 27.963285786764963, 28.722789900643484, 29.399777208055767, 28.507484333855764, 28.058854784284318, 0.40692431745784624, 0.018696057044767907, 0.03167737002617546, 0.04539471538737416, 0.01743615322214152, 0.026440116144450646, 0.043957398406096866, 0.020213822834193707, 0.018440016944493567, 0.017301385989412665, 0.03024855169600674, 0.024824100180662105, 0.048699754290282726, 0.05161777717460479, 0.09035022862787757, 0.033180481155536005, 0.037224403981651576, 0.037276725816939554, 0.06892741245350667, 0.02623780075061534, 0.023722688567691615, 0.041232259278850894, 0.027213578212207983, 0.018880021459023868, 0.032922899084431786, 0.0181846163634743, 0.008532521880364843, 0.05997446857924972, 0.014238005637058189, 0.05442167046879019, 0.06847534528268234, 0.046433515181498866, 0.016430167381518652, 0.023827311882217015, 0.1263656664107527, 0.04824249632656574, 0.3639652340539864, 22.584832906723022, 48.07824775150844, 35.012990610940115, 26.30977954183306, 38.37972981589181, 37.063883440835134, 49.04365478243147, 18.899454525538854, 0.009630104011323835, 0.5026753523520061, 3.3734292345387593, 1.6005582575287138, 2.1667562127113342, 0.8750720354063171, 12.610864928790502, 41.18243162972586, 45.05825144904, 47.062191826956614, 48.124161447797505, 47.100841181618826, 47.85582201821463, 48.061971596309114, 45.845423289707725, 47.59532363074166, 47.97892325265067, 46.113648074013845, 46.888212408338276, 43.087054456983296, 43.30409186226981, 45.465877941676546, 45.854987485068186, 45.48039272853306, 47.473876067570274, 45.716753074101035, 45.78128446851458, 45.17864983422415, 44.5203913961138, 44.391227858407156, 43.19421999795096, 41.984291962214876, 39.046117646353586, 35.66604832240513, 34.60888685498919, 35.46649258477347, 35.7549991607666, 35.279902185712544, 36.61668348312378, 35.55714920588902, 36.99508932658604, 36.052097184317454, 34.81245865140642, 35.57544033867972, 34.63543939590454, 33.746966293879915, 34.645552498953684, 42.817294120788574, 45.63334689821516, 45.96083286830357, 44.62356867109026, 46.30372299466814, 48.43842847006661, 47.341221060071675, 46.21232639040266, 45.570253780909944, 46.2763922555106, 45.688112599509104, 47.74659286226545, 48.3577355657305, 43.19900035858154, 39.70223951339722, 49.05974333626883, 45.753522941044395, 46.117205551692415, 45.89911202022007, 46.905787876674104, 46.570704051426475, 46.53217281614031, 44.148516859327046, 42.93245356423514, 37.82333891732352, 34.672779015132356, 33.04706730161394, 32.92011676515852, 34.21284300940377, 33.349473748888286, 34.12908247538975, 34.85893862588065, 34.91663646697998, 34.05622019086565, 35.73970964976719, 35.278238092150005, 35.00929069519043, 35.259262561798096, 34.501394748687744, 38.23581525257656, 34.81609255926949, 33.709852491106304, 33.881938525608604, 41.063676493508474, 43.34991523197719, 45.524051734379356, 44.87546518870762, 43.46233013698033, 41.10498006003243, 42.9921281678336, 42.830919538225444, 44.629985332489014, 45.6716696875436, 42.45885740007673, 43.91359479086739, 41.96554224831717, 40.323200021471294, 37.36076259613037, 36.91420534678868, 36.57341357639858, 35.35730859211513, 37.4169978414263, 41.899235589163645, 43.324081829616, 44.0892139843532, 45.23378379004342, 45.446565423692974, 33.22851603371756, 9.564224890300206, 0.3321764383997236, 2.158248794930322, 3.539992753948484, 0.20361805893480778, 0.10186622996947595, 0.0652624209012304, 0.09332854952663183, 0.09685088587658745, 0.015048456345019596, 8.70624395779201, 34.08045898165022, 33.27912671225411, 29.45971236910139, 32.74342060089111, 34.003347873687744, 1.2163881233760288, 0.03862934805718916, 0.019145723897963762, 0.012999211038861955, 0.019858916789027195, 0.044421957406614504, 0.03603134603638734, 0.02533601244379367, 0.016303142233352576, 0.06639047179903303, 0.026534040658069507, 0.023946905375591347, 0.020448964055893675, 0.025950329211939658, 0.03403868206909724, 0.04581508818747742, 0.21695904806256294, 0.1442662344447204, 0.11461733467876911, 0.08850878636751856, 0.17611776744680746, 0.22789719541157993, 0.16675804182887077, 0.09289096907845565, 0.18109053346727574, 0.1583499615745885, 0.11093124747276306, 0.10666138266346284, 0.09901970771274396, 0.14284983330539294, 0.14394154186759675, 0.07655882795474359, 0.09856288401143891, 0.16769594007304736, 0.14885801662291798, 0.16772906615265779, 0.4918857770306723, 25.73006875174386, 55.51156956808907, 41.41093356268746, 30.79876572745187, 40.49145759854998, 42.134908063071116, 51.95258413042341, 23.128923756735666, 0.09087693465075322, 1.358492789523942, 8.504735776356288, 10.212093165942601, 3.6305095425673892, 0.9916801239762987, 13.349107554980687, 42.436564104897634, 46.301760128566194, 47.88509477887835, 50.10838631221226, 48.50117417744228, 49.59438637324742, 49.68688426698957, 47.79101616995675, 50.72096381868635, 49.129892349243164, 47.858802795410156, 48.51743991034371, 44.807251249040874, 45.961284501211985, 44.721295084272114, 46.20242173331124, 46.11013923372541, 49.29130942480904, 48.35641540799822, 47.82551050186157, 47.48640019553048, 46.99377638953072, 46.817955698285786, 47.21969706671578, 43.54873446055821, 41.99133048738752, 38.3006454195295, 36.27754885809762, 37.442831243787495, 36.49929714202881, 36.54940755026681, 39.7507448877607, 38.501351084027974, 39.34373331069946, 38.38612215859549, 35.74341303961617, 39.02096169335501, 35.824588843754356, 35.09513568878174, 35.36834233147757, 44.56373773302351, 46.75580406188965, 47.84675461905343, 46.35134942190987, 47.72660289491926, 50.28478022984096, 50.42458840778896, 47.78647552217756, 47.36519234521048, 48.35971927642822, 46.800897870744976, 49.940153053828645, 48.233401026044575, 44.24949502944946, 42.17541258675711, 49.88771152496338, 48.216617652348106, 47.1850255557469, 48.325780800410676, 47.72625548498971, 47.075945786067415, 48.80297613143921, 45.91741010120937, 44.7623415674482, 40.13244765145438, 37.206825256347656, 34.18835060937064, 34.3949761390686, 35.89556469236101, 35.022791045052664, 35.812457289014546, 36.55896479742867, 37.71727466583252, 36.44889838354928, 36.38741724831717, 36.91365991319929, 35.04353141784668, 36.72607939583914, 36.73067910330636, 39.382605007716585, 36.35211345127651, 36.256221362522666, 35.208763054439, 43.15864174706595, 43.97498212541853, 46.22550712312971, 49.16365017209734, 44.78965493610927, 42.48314135415213, 43.97825820105416, 45.013862882341655, 46.43239321027483, 47.84123774937221, 43.9384936605181, 46.288659300122944, 43.93382794516427, 43.02558026994978, 39.5895779473441, 39.175291606358115, 38.31713696888515, 37.57439191000802, 38.58261374064854, 44.323740005493164, 44.64476415089199, 45.00253731863839, 46.69179378237043, 45.33875717435564, 36.45644065311977, 11.689857755388532, 0.4750165822250502, 2.844684132507869, 3.7307787793023244, 0.3335561172238418, 0.24773468236838067, 0.9347830627645765, 0.6236856132745743, 0.35137099985565456, 0.1643005779811314, 11.301537701061793, 38.82662057876587, 38.31993361881801, 38.396047660282676, 39.141078676496235, 39.680766105651855, 1.814457574060985, 0.17909450057361806, 0.11049315812332289, 0.15948688771043504, 0.08888938344482865, 0.1365724072924682, 0.1536174648042236, 0.13100164836006506, 0.16627991891333035, 0.19596913723008974, 0.13170329428144864, 0.08991867357066699, 0.12460359239152499, 0.15043917963547365, 0.14894071647099086, 0.1339231487363577], [0.008064496414070683, 0.06034699108983789, 0.03328834108210035, 0.02628342035625662, 0.04989645257592201, 0.0874438052996993, 0.0644432594999671, 0.027455168909260204, 0.0767040615901351, 0.03889907929780228, 0.015069263621366449, 0.04176264635420271, 0.06392548299793686, 0.03178410358460886, 0.037478698550590446, 0.00867908459622413, 0.06095657337989126, 0.005279471906500736, 0.0074106770334765315, 0.03232747442754252, 0.043046488892287016, 4.990960095609937, 34.36147192546299, 37.01545449665615, 24.04025990622384, 32.940110206604004, 31.083224977765763, 33.563433102199006, 23.913932970591954, 0.03323613799044064, 0.7886121262397084, 1.2860355632645744, 0.9150252086775643, 1.8260363127504076, 0.21214937471917697, 1.1219498366117477, 19.781543970108032, 41.31586830956595, 48.75810466493879, 48.290383202689036, 49.01179381779262, 43.6969256401062, 44.450016566685264, 44.14307641983032, 43.499794823782786, 46.39571714401245, 45.92498016357422, 44.26786606652396, 45.685795375279014, 42.054882185799734, 41.01123496464321, 43.20214441844395, 43.979102407182964, 46.46143320628575, 46.2989877973284, 45.726171357291086, 45.785946709769114, 46.11323118209839, 44.43857635770525, 45.57272386550903, 43.76816552025931, 41.38579150608608, 37.13158668790545, 32.96131958280291, 32.43872124808175, 34.95872517994472, 35.07366228103638, 34.09514052527291, 32.04327842167446, 40.41823748179844, 36.18736471448626, 32.162169047764365, 33.60408353805542, 32.70963498524257, 33.24694265638079, 32.16887058530535, 38.35835368292672, 42.572644574301584, 47.227479049137656, 42.66131748471941, 40.83319432394845, 43.921342032296316, 45.89505427224295, 48.319204330444336, 46.94611522129604, 44.473730768476216, 46.04151882444109, 45.69331680025373, 46.9874952180045, 42.30444063459124, 41.35250963483538, 48.26861449650356, 44.233691351754324, 42.204966749463765, 41.78456251961844, 43.11926283155169, 41.02539191927229, 40.3099741254534, 37.549892561776296, 34.49102456229073, 31.62947150639125, 32.87887225832258, 32.40049225943429, 30.9728285244533, 32.02720029013497, 33.203026567186626, 33.23516893386841, 33.10801689965384, 35.1754012789045, 32.01715666907174, 32.58770799636841, 33.62033190046038, 33.79726777757917, 32.23071302686419, 32.16495874949864, 32.2122551373073, 32.87535299573626, 32.64249801635742, 32.365487234933035, 32.88922854832241, 37.47352838516235, 41.03816965648106, 41.83099733080183, 44.67545434406826, 45.667730058942524, 45.10224049431937, 42.31227125440325, 43.08908333097185, 43.96206195013863, 43.42846461704799, 43.75931698935372, 43.16100760868618, 42.2076279095241, 38.994784355163574, 37.1469908441816, 33.59546429770333, 33.93367828641619, 36.68208340236119, 39.807970251355854, 40.01234456471035, 43.36341905593872, 42.832840715135845, 39.113647188459126, 14.494933247566223, 0.9763249307870865, 0.2043992563017777, 0.48915307223796844, 0.8948516568967274, 0.1421823991196496, 0.049215780171964846, 0.0948899332433939, 0.05713883002421685, 0.09261002165398427, 0.49067396777016775, 14.985864298684255, 23.86432978085109, 28.74803270612444, 49.29207025255476, 31.694016797201975, 13.20888682774135, 0.15191435547811644, 0.10397098452917167, 0.0163189453139369, 0.07706795992063624, 0.04208775623036282, 0.029606810238744532, 0.006691598699295095, 0.07810585387051105, 0.016757134747292315, 0.03711214714816638, 0.036543595870690684, 0.0465864162626011, 0.060770994052290916, 0.08878853278500692, 0.04177335363679698, 0.02810127504302987, 0.06165220069565943, 0.06064526829868555, 0.03260700371382492, 0.029775147991521016, 0.030368618467556577, 0.026615573425910304, 0.04547368668551956, 0.03475237198706184, 0.05961880087852478, 0.04519912088289857, 0.01443011247153793, 0.039811325525598865, 0.044162299018353224, 0.03384086196976049, 0.022417166835761497, 0.07318922983748571, 0.03812185475336654, 0.0046676496027170545, 0.03717442309217794, 0.02539149116325591, 0.01199548302351364, 8.568760820797511, 41.724325111934114, 43.0406300680978, 27.556566034044536, 39.43456016268049, 38.26063074384417, 39.356872354234966, 25.412685462406703, 0.05198999434443457, 0.14903742128184863, 1.7376451300723212, 0.10829675383865833, 1.2587447762489319, 0.9499140679836273, 2.1621141646589552, 25.113124302455358, 44.51323127746582, 48.92577511923653, 49.10746356419155, 51.24536868504116, 45.66189357212612, 47.34657464708601, 44.160057817186626, 45.53666966302054, 48.398368631090435, 47.610762528010774, 45.27283614022391, 46.67839070728847, 42.53743805204119, 43.93547814232962, 43.481288296835764, 45.340028694697786, 48.43301582336426, 47.643203667231965, 47.36788477216448, 45.9246049608503, 47.73422506877354, 45.474993978227886, 46.75441442217146, 45.38497659138271, 42.58044392721993, 39.51374530792236, 35.186699049813406, 34.69596862792969, 36.65492984226772, 36.83307818004063, 35.47618184770857, 33.147305488586426, 40.73007958275931, 37.1787371635437, 33.49747385297503, 36.428050313677105, 34.721718651907786, 34.52214206968035, 33.74960660934448, 39.32276712145124, 44.08403410230364, 48.598240511757986, 43.07655572891235, 41.86350795200893, 45.77008397238595, 47.189250060490195, 49.41582809175764, 47.77241236822945, 46.3573248726981, 46.078302587781636, 47.34732505253383, 47.00380264009748, 42.775799478803364, 42.19643088749477, 49.13681970323835, 44.960577147347585, 45.6964886529105, 43.517665590558735, 44.33123363767351, 43.34325190952846, 43.13341978618077, 39.153467314583914, 36.13475642885481, 34.31133719852993, 34.227246625082834, 34.87486042295183, 32.59351321629116, 33.56437805720738, 35.12612812859671, 34.52854483468192, 34.69775431496756, 35.18540668487549, 33.6932567187718, 33.62321540287563, 34.541468484061106, 33.99209179197039, 34.455303873334614, 34.731192520686555, 35.74300309589931, 34.30407633100237, 33.900479793548584, 32.77620915004185, 35.22768299920218, 39.9278370993478, 42.50051532472883, 44.54077046258109, 44.56663513183594, 45.93661492211478, 45.4320193699428, 43.737635135650635, 43.91372333254133, 45.45927020481655, 45.635330608912874, 44.789665358407156, 43.80107913698469, 42.86024441037859, 39.08859198434012, 38.59787893295288, 35.241638456072124, 36.05447346823556, 37.822522503989084, 42.53124720709664, 41.85850872312273, 45.20050539289202, 43.74532331739153, 40.674063205718994, 18.810248340879166, 1.0901132992335727, 0.6911284657461303, 1.2260487249919345, 0.810725311083453, 0.12836016581526824, 0.06122785846569708, 0.03275704816249864, 0.024119141312049966, 0.10691953131130763, 0.3789574110082218, 15.624834537506104, 35.78381681442261, 33.599654061453684, 48.2452963420323, 35.95480850764683, 18.19042386327471, 0.38210147087063107, 0.033415705497775755, 0.023273562846173133, 0.06996825124536242, 0.02108207454771868, 0.054507450865847726, 0.024492993751274686, 0.03796533368793981, 0.019303535876263465, 0.03908484182985766, 0.017768386019659892, 0.05487246877912964, 0.049026404440935166, 0.058299104550055096, 0.072918894700706, 0.014414200825350625, 0.16049791845892156, 0.21258214435407094, 0.12479982471891812, 0.1307653146130698, 0.19418807780104025, 0.17233612893947534, 0.13383369067949907, 0.12061601850603308, 0.22764415613242558, 0.24725058834467614, 0.08767538930156402, 0.19849970644073828, 0.27390824790511814, 0.18277767007904394, 0.13298020219164236, 0.2005885493542467, 0.10873925366571971, 0.0699951144467507, 0.1304553598165512, 0.10562034709645168, 0.05937395830239568, 9.034120764051165, 44.7382104737418, 47.18677650179182, 33.77100011280605, 44.128474780491416, 40.91345296587263, 42.419593129839214, 28.86124665396554, 0.12225404275315148, 2.183924125773566, 5.807335649217878, 2.944881715944835, 5.520220449992588, 0.6114514640399388, 2.4773524148123602, 25.325235434940883, 45.06929561070034, 49.34607512610299, 49.53139400482178, 50.909645625523154, 46.08944402422224, 49.24790055411202, 48.66352578571865, 47.911282539367676, 50.78206975119454, 48.32200445447649, 45.02883972440447, 46.92403384617397, 43.20403780255999, 44.55572993414742, 45.09994758878435, 46.17467410223824, 49.63800368990217, 49.086493900844026, 46.57715892791748, 48.56396157400948, 50.01906374522618, 46.949912411826, 49.8535680770874, 46.4120488848005, 44.90605115890503, 40.87952838625227, 36.76876565388271, 36.58458627973284, 39.16183294568743, 38.25537443161011, 36.83296006066458, 34.80585438864571, 42.38795450755528, 38.43036133902413, 36.53209611347744, 38.14430400303432, 35.67177363804409, 35.19156973702567, 34.84270415987287, 41.295687266758506, 46.35815518242972, 51.465473720005576, 45.94850328990391, 44.16840260369437, 46.50732953207833, 49.96837663650513, 51.43751764297485, 49.61467163903372, 47.09779439653669, 49.23923962456839, 48.95648268290928, 48.491985184805735, 43.95661803654262, 44.765603746686665, 51.39401497159685, 46.73757546288626, 46.613091536930625, 46.46195779527937, 45.918289048331125, 45.380891050611226, 43.60844727924892, 40.576805795942036, 37.7548748425075, 36.358370304107666, 35.87938928604126, 35.76655748912266, 35.291453565870015, 35.19841718673706, 36.05116612570626, 36.10157183238438, 35.248465061187744, 37.5710255077907, 34.39030000141689, 37.16285358156477, 37.1605224609375, 36.96624388013567, 36.24282176154, 36.26984330586025, 36.972163745335166, 36.78062970297677, 36.23012392861502, 36.16028411047799, 36.943856784275596, 41.60998903002058, 43.50284855706351, 44.574573448726106, 46.557523318699424, 48.0177880014692, 46.44662659508841, 45.122320788247244, 45.2142002923148, 46.82422644751412, 47.1571980203901, 45.9504348891122, 46.486453669411794, 46.14186470849173, 41.58965860094343, 40.88819278989519, 38.136535917009624, 37.30720935549055, 40.354842117854524, 45.0400367464338, 43.0626871245248, 47.93733133588518, 45.04216289520264, 41.16132647650582, 20.70054050854274, 1.4388074512992586, 1.0926657851253236, 0.8206067894186292, 1.75347138941288, 0.4749180589403425, 0.5668180276240621, 0.20891230127641133, 0.09472413321158715, 0.2935795752065522, 1.6647677549294062, 21.937698534556798, 37.45479951586042, 37.1220155443464, 54.655530657087056, 43.576575892312185, 21.173914330346243, 0.4248012996145657, 0.14032090614948953, 0.21478655535195554, 0.1816360077687672, 0.11413138146911349, 0.14842350993837627, 0.16411218951855386, 0.16042342888457434, 0.1145464549107211, 0.12715928096856388, 0.16345236849571976, 0.24537981301546097, 0.1848183370062283, 0.16685363384229795, 0.23155523197991507, 0.21514246053993702], [0.01512057613581419, 0.014877786128116506, 0.013841697929560073, 0.018578663701191545, 0.005007109646352806, 0.04311785042019827, 0.05720729420759848, 0.07690217345952988, 0.04170525246965034, 0.03444274967270238, 0.01824387621932796, 0.027228848642802665, 0.06058987269976309, 0.012016275880991347, 0.05886243789323738, 0.012504878769894796, 0.03553466858076198, 0.033926275957907946, 0.08129384209002767, 0.015664433827623725, 0.008916950136023973, 0.3589017071894237, 19.227918454578944, 45.05706678118025, 30.324968065534318, 32.62354333060128, 27.816875083105906, 30.24899298804147, 23.164656605039323, 0.210642864129373, 0.10977275070867368, 1.2180196472576685, 0.2897310331463814, 0.6236056004251752, 4.851070710590907, 0.7916996777057648, 4.887128821441105, 29.295359679630824, 45.480354513440815, 48.25669486182076, 49.8274359021868, 49.40310941423689, 44.818819999694824, 45.983063629695344, 46.28826672690255, 44.196226664951865, 45.303043433598106, 44.05937841960362, 43.2446847643171, 44.33209521429879, 43.678551128932405, 44.58929320744106, 43.94476440974644, 42.000703607286724, 42.64206402642386, 43.275593825748985, 44.89807115282331, 44.12668909345354, 45.1687764440264, 45.01500586100987, 46.18909508841378, 43.49611575262887, 42.365699427468435, 33.9060765675136, 33.578232765197754, 33.8540415082659, 32.51027379717146, 32.416896956307546, 33.802388599940706, 33.745458534785676, 34.23411839348929, 34.39101913997105, 33.70959888185774, 34.87386335645403, 33.054821491241455, 33.01200669152396, 34.544424942561555, 41.67913402829851, 44.85766737801688, 46.260592051914756, 43.45602117265974, 41.931555134909495, 44.38239669799805, 43.14867803028652, 47.545848982674734, 45.800652572086875, 47.34303106580462, 45.09848151888166, 44.679619789123535, 39.73380517959595, 39.958541188921245, 44.42216123853411, 41.43636049543108, 40.296293122427805, 38.03747544969831, 37.71049322400774, 35.29318019321987, 34.4694538797651, 33.64923988069807, 33.88647222518921, 32.04418863568987, 33.94522271837507, 32.69181285585676, 33.280571937561035, 33.41811152866909, 33.50300809315273, 32.966985838753835, 33.221949986049104, 33.41704845428467, 33.78659881864275, 34.47258056913103, 34.04079866409302, 31.566096987043107, 31.613122395106725, 31.434310504368373, 32.16288818631853, 31.36525583267212, 32.811294078826904, 31.96832820347377, 31.90080213546753, 34.12415967668806, 36.03088780811855, 38.56076513017927, 40.73292487008231, 42.90363243647984, 43.663143498556956, 42.267434528895784, 41.52655853543963, 43.2788872718811, 42.982209614345, 43.936725343976704, 43.23264701025826, 43.01608555657523, 40.41810894012451, 38.13675478526524, 36.688934326171875, 34.326699665614534, 35.832468100956504, 39.97081865583147, 41.42194645745413, 44.78972094399588, 41.626741136823384, 33.02938066210066, 5.8255073598452976, 0.3871907006417002, 0.36649350981627193, 1.9755435245377677, 2.430722836937223, 0.09321201792252914, 0.07267667126974889, 0.09404232086879866, 0.14154657109507493, 0.4438293757183211, 2.391510461057935, 20.531694071633474, 23.723130226135254, 24.547379391533987, 48.09042794363839, 31.1592104775565, 4.1293109485081265, 0.06146153914076941, 0.02172585839538702, 0.07823898244116988, 0.021108201538611735, 0.07338426115789584, 0.038254820475620885, 0.07153768917279583, 0.052722798593874486, 0.031427502898233275, 0.01875867904163897, 0.01581864957032459, 0.0546740854957274, 0.05355544927130852, 0.04946678723873837, 0.033794596059513946, 0.0714863987107362, 0.033095939084887505, 0.0594136593863368, 0.014414343317704541, 0.09904116977538381, 0.029095418751239777, 0.06515306819762502, 0.03521966887637973, 0.04818366394777383, 0.023525168720100607, 0.013755375552656395, 0.03769857782338347, 0.06502433653388705, 0.04632786727909531, 0.052796378931296725, 0.02310498251712748, 0.03690663246171815, 0.03599620131509645, 0.035347192747784514, 0.03474687585341079, 0.015428191682855998, 0.03790395680282797, 0.9681704597813743, 25.236006668635778, 49.040778228214805, 32.93507276262556, 37.5099195752825, 33.975496019635884, 35.12305007662092, 25.844231128692627, 0.13378745530332836, 0.005905056596800152, 0.2915351763367653, 0.0769619998921241, 0.27445278582828386, 4.732787183352879, 0.6738600209355354, 6.898898082120078, 32.52715444564819, 48.58054344994681, 48.13968024935041, 50.423838002341135, 49.3682016645159, 46.52471739905221, 47.44107709612165, 47.444860390254426, 46.57935455867222, 46.718592984335764, 45.656592096601216, 44.44712611607143, 44.48645292009626, 43.87064797537667, 44.33940124511719, 44.237182821546284, 44.13739626748221, 44.20868131092617, 43.508910860334126, 45.810574599674766, 45.41634770802089, 46.463705267224995, 47.19110175541469, 48.002442904881065, 45.50710507801601, 42.163374832698274, 36.940393107278005, 35.03042016710554, 35.58103363854544, 34.241969857897075, 34.110040937151226, 34.59371893746512, 36.02465874808175, 35.69697822843279, 36.627098832811626, 34.9549731527056, 35.04416370391846, 34.70951066698347, 34.603060790470664, 36.26741143635341, 44.232416357312886, 46.58073377609253, 47.97424364089966, 43.63631650379726, 43.630059650966096, 46.192874908447266, 44.730324268341064, 49.41098172324044, 47.177802903311594, 47.488310950142996, 46.806400844029014, 46.24434716360909, 41.10226331438337, 42.40021807806832, 48.813572134290425, 44.06387390409197, 41.903738021850586, 41.7445513180324, 39.33661488124302, 37.75844621658325, 37.69252865655081, 34.71680627550398, 35.5779138973781, 33.95985909870693, 35.374227455684114, 33.868229729788645, 33.86781978607178, 35.169005462101524, 34.477875096457346, 36.47303989955357, 35.34238386154175, 35.19099303654262, 33.27681296212332, 35.999693870544434, 35.60637024470738, 33.18481533867972, 33.63614252635411, 32.3098703793117, 33.36219590050833, 32.50767517089844, 33.45623629433768, 32.77037961142403, 33.38939809799194, 36.48090178625924, 38.84705523082188, 40.930555956704275, 43.012938022613525, 44.646390029362266, 44.67870610100882, 43.61194569723946, 42.75044550214495, 42.904820578438894, 44.865942682538716, 44.70953525815691, 45.31548765727452, 43.940772669655935, 41.94712604795183, 40.02676902498518, 38.46315336227417, 35.72571250370571, 37.972228390829905, 41.87488215310233, 43.991821084703716, 45.277359417506624, 43.49689047677176, 33.663831097739084, 8.68792416368212, 0.5522469495023999, 2.87669882604054, 3.8037370358194624, 1.3766053318977356, 0.0694776229294283, 0.10498669716928687, 0.12953872685985907, 0.12238095594303948, 0.6913985769663538, 4.179359691483634, 26.328477144241333, 28.430473974772863, 27.96078269822257, 53.49228409358433, 36.62837035315377, 6.9600765364510675, 0.03603064375264304, 0.04350152126114283, 0.1054589846836669, 0.03410525653245194, 0.05790337614182915, 0.03460423761446561, 0.061091547565800805, 0.02018268995120057, 0.05699612053909472, 0.04883776831307581, 0.013413681432471743, 0.044987414564405165, 0.07950036547013692, 0.029308254830539227, 0.062291373897876055, 0.04788194317370653, 0.10834713506379298, 0.15437375993600913, 0.13980355033917086, 0.11725507171026298, 0.1053069249859878, 0.16557230188378266, 0.12709745285766466, 0.11439735362572329, 0.11372996015208107, 0.13723240473440715, 0.06112107740981238, 0.1277243242199932, 0.20189968257078103, 0.11764562289629664, 0.09883201814123563, 0.158759172473635, 0.14956753355051788, 0.11487090321523802, 0.1792703361383506, 0.07318148096757275, 0.13559231774083205, 1.00289277945246, 29.743838105882915, 57.16076619284493, 40.330096108572825, 42.00230516706194, 36.29955727713448, 40.32331814084734, 28.38807085582188, 0.5190331488847733, 0.18447571753391198, 4.496200152805873, 0.5171525212270873, 2.323967673948833, 11.488828131130763, 1.6263088243348258, 7.259212987763541, 34.080695220402305, 47.060013566698345, 48.90653903143746, 51.232931409563335, 52.030980655125205, 48.10084329332624, 49.70474113736834, 48.80417469569615, 48.124675614493235, 49.260542801448274, 48.103143147059846, 47.350344044821604, 46.466870171683176, 45.43903010232108, 46.377196720668245, 45.22707530430385, 43.76518474306379, 43.736683232443674, 44.72594690322876, 46.600588253566194, 47.3563403402056, 46.92543043409075, 48.07853610174996, 48.756864411490305, 47.66406910760062, 43.89519248689924, 38.441933563777376, 36.924158641270225, 36.709375926426475, 35.41734102794102, 36.05378907067435, 36.25094420569283, 37.466823373522075, 37.033940179007395, 38.051024436950684, 36.266570704323904, 37.18869045802525, 35.72291932787214, 36.06538561412266, 37.76066269193377, 44.910112380981445, 47.56624889373779, 49.74808747427804, 45.76571702957153, 44.52817685263497, 46.73573419025966, 46.3813031060355, 51.03294488361904, 49.1319385937282, 49.891470500401084, 47.2904714175633, 45.81599766867501, 41.914851665496826, 44.521183490753174, 48.125856808253694, 45.326660360608784, 43.11868265696934, 44.49133055550711, 41.2797828401838, 39.474359444209504, 38.27676446097237, 35.5148138318743, 37.274490288325715, 34.95022405896868, 37.433003016880576, 34.71288054330008, 36.1193904876709, 36.587900570460725, 36.20856366838728, 38.1716764313834, 36.9853583744594, 36.824584007263184, 35.414464473724365, 37.00717919213431, 38.41765308380127, 34.72517538070679, 35.06638751711164, 33.52428000313895, 34.884105001177105, 33.70223726545061, 35.87975059236799, 35.404327051980154, 34.611718245915, 38.36132056372506, 40.19707632064819, 43.1277882712228, 43.94355194909232, 46.52474519184658, 46.2818535396031, 45.163447175707134, 44.62748745509556, 44.72120475769043, 44.50659922191075, 45.344857692718506, 45.97191177095686, 46.396679469517295, 43.73976823261806, 42.31548132215227, 39.90707588195801, 37.5860127721514, 38.51410450254168, 44.49603796005249, 44.32616492680141, 47.63931267602103, 43.45561817714146, 36.14289971760341, 11.072216749191284, 1.0526961641652244, 2.738402098417282, 5.9304481744766235, 4.289364440100534, 0.15330645149307592, 0.45170515882117407, 0.22306257912090846, 0.2989778369665146, 1.8038892554385322, 7.618258544376918, 30.111147676195415, 33.71411173684256, 32.03372812271118, 55.54232576915196, 42.33205277579171, 8.451846957206726, 0.15788258665374347, 0.13088107268725122, 0.1631324663758278, 0.17922339508576052, 0.15295266333435262, 0.153647388198546, 0.1505939263318266, 0.17322476554129804, 0.08060090855828353, 0.14610940696937696, 0.16553700449211256, 0.1068858081208808, 0.14341166030083383, 0.16513094199555262, 0.10588706564158201, 0.12338448209421975], [0.023189841802897196, 0.04110809076311333, 0.01713154697790742, 0.023945834986599426, 0.036481058690696955, 0.0015051316794207586, 0.04745660010459168, 0.02785366913303733, 0.05617659612159644, 0.029244587889739444, 0.048681868107191155, 0.037381454304392846, 0.0611316082733018, 0.026515830474506532, 0.007737537529984755, 0.07828207620020423, 0.08140404974775654, 0.04023067373782396, 0.058746252341994216, 0.08690109263573374, 0.05549126896741135, 0.06846426480582782, 7.9066478695188245, 41.01497309548514, 31.029008184160503, 26.294205154691422, 38.69922535760062, 28.293438128062657, 24.850569248199463, 1.5654714831284113, 0.037120594909148555, 0.12830452594373906, 0.06666441674211196, 0.12968029640614986, 2.9826184681483676, 3.73492294549942, 0.9626254716089794, 10.415010963167463, 36.727500302451, 48.51481696537563, 50.011542320251465, 47.18856218882969, 45.80405371529715, 46.411677156175884, 47.32253735406058, 46.31521531513759, 45.55377265385219, 46.29566308430263, 46.59572104045323, 45.18049805504935, 45.65412548610142, 45.22685991014753, 45.77306822368077, 45.56778369631086, 45.93529823848179, 44.606093951633994, 46.60269008363996, 44.4122531073434, 41.76592397689819, 46.090906620025635, 45.28796584265572, 45.39342907496861, 43.233105591365266, 36.31245313371931, 34.255921840667725, 33.09711170196533, 34.64310673304966, 33.545902797154014, 32.95675809042794, 34.707412311008994, 34.21127619062151, 32.7757887840271, 34.550084250313894, 33.974321774074006, 34.58044787815639, 34.3821428162711, 32.86262042181832, 37.262195450919016, 46.87455572400774, 44.95348998478481, 45.15926088605608, 30.10219839641026, 33.968346323285786, 44.11028439658028, 40.34766115461077, 44.48947538648333, 43.31707457133702, 41.73997245516096, 40.68456540788923, 38.648750168936594, 38.71775620324271, 46.84504325049264, 43.02636889048985, 42.16854429244995, 37.41699089322771, 35.677207129342214, 34.09589440482003, 34.98316894258772, 33.54631968906948, 32.97026538848877, 31.81613486153739, 32.705073492867605, 33.412278515951975, 34.345018591199604, 32.58576250076294, 33.41270235606602, 31.607199055807932, 33.176835332598, 32.741388252803254, 33.30637754712786, 33.51596648352486, 36.12817995888846, 32.298214776175364, 32.345174176352366, 32.1503084727696, 31.423679760524205, 31.725144726889475, 31.210602828434535, 31.331855842045375, 31.94035475594657, 31.93573420388358, 32.211966787065776, 33.123226506369456, 36.11375897271292, 38.78161709649222, 42.382899693080354, 43.611639976501465, 44.47562762669155, 41.98710250854492, 42.85121175221035, 40.75825800214495, 42.57813017708914, 43.65843261991228, 40.848991053445, 40.42391416004726, 37.09812068939209, 37.56469917297363, 36.198401927948, 39.64169985907418, 41.15717145374843, 43.12979630061558, 40.318895612444194, 20.010325568062918, 0.9258570160184587, 0.24035156997186796, 2.410598031112126, 2.8808047771453857, 0.45575177882398876, 0.07394587780748095, 0.09274443944117852, 0.12566495686769485, 0.08347834487046514, 0.12505796658141272, 2.569931081363133, 30.475785664149694, 33.86097928455898, 26.590549298695155, 37.334175314222065, 15.840784549713135, 0.5724003623638834, 0.040395639171557765, 0.020967888978442976, 0.030355546490422318, 0.04462758405134082, 0.024729904253035784, 0.01921025597091232, 0.021532413150582994, 0.03531182410993746, 0.011465788053880845, 0.07914695729102407, 0.031340324719037325, 0.03556469036266208, 0.020955554908141494, 0.016956657969525883, 0.021596733181338226, 0.02678486960940063, 0.008058222509654505, 0.08381968869694642, 0.02239227986761502, 0.028632603585720062, 0.014897921654794897, 0.03187157353386283, 0.036990950615810494, 0.011463542102969118, 0.027779756313455955, 0.016773726624835814, 0.01266906049568206, 0.032752895528184514, 0.04047620502699699, 0.01829021337575146, 0.01757102902047336, 0.04747224372944661, 0.035276323157761774, 0.03935613030833857, 0.02186069857063038, 0.058538634196988175, 0.02335000829771161, 0.05959849911076682, 12.511700238500323, 47.8403205871582, 33.852801254817415, 27.181373732430593, 38.95055559703282, 31.58956800188337, 26.96169080053057, 1.582453531878335, 0.024856758071109653, 0.2491780077772481, 0.19417154868798597, 0.08838992060295173, 3.339264073542186, 4.195827790669032, 2.8107156923839023, 14.799867970602852, 38.038059098379954, 49.245889050619944, 50.7556665965489, 50.39185544422695, 46.84090212413243, 47.90287869317191, 48.215099470955984, 46.54506867272513, 47.598578861781526, 46.60598005567278, 47.41326693126133, 46.02443320410592, 47.28567368643624, 46.18479415348598, 47.2233761378697, 46.2362768309457, 46.90167801720755, 44.632233074733186, 46.620817933763774, 44.83956037248884, 43.14776086807251, 45.50985656465803, 45.49929182870047, 46.380080223083496, 44.48771054404122, 38.151071548461914, 34.85852868216378, 34.04211187362671, 35.52164043698992, 35.43816130501883, 34.802196162087576, 35.193310260772705, 35.065755231039866, 35.26698548453194, 36.06916543415615, 36.29957464763096, 35.55715267998831, 34.993893487112864, 35.2070746421814, 38.73625578199114, 47.86749846594674, 46.12741592952183, 47.73463501249041, 32.6090007509504, 37.49576609475272, 45.80515500477382, 41.53394794464111, 46.59168413707188, 43.95570087432861, 43.27944312776838, 42.41311393465315, 40.562937191554475, 40.80630479540144, 47.77503183909825, 45.28058685575213, 44.25834008625576, 36.86844103676932, 37.25766869953701, 35.42695733479091, 37.12136936187744, 34.08127192088536, 34.99759687696184, 33.082836627960205, 34.568941661289756, 35.28598533357893, 36.33109515053885, 35.21389429909842, 34.164295945848735, 33.34774364743914, 35.18763705662319, 34.19880764825003, 34.734597137996126, 35.45275599615914, 37.88715464728219, 32.63122109004429, 32.83091231754848, 33.76156793321882, 31.637764181409562, 34.549827166966026, 32.55732699802944, 33.23250777380807, 34.35588557379586, 32.22431721006121, 32.77223825454712, 35.541651248931885, 38.29286343710763, 42.74699224744524, 44.66873543603079, 43.49995115825108, 44.89540999276297, 42.6812310218811, 42.907308033534456, 41.884630475725444, 43.856529235839844, 45.172545841761995, 42.244095529828755, 41.866262912750244, 38.22974252700806, 38.26331622259957, 37.666934967041016, 41.01043592180525, 42.09065498624529, 45.08228179386684, 41.867277349744526, 23.998853853770665, 2.2132856931005205, 1.4863045769078391, 6.864427634647914, 5.540586054325104, 1.6250231904642922, 0.12952887453138828, 0.0797307009675673, 0.07642271383000271, 0.08772269676306418, 0.7854269200137683, 3.512200176715851, 29.94301516669137, 31.564269610813685, 27.354614904948644, 43.002123151506694, 23.29303499630519, 1.2960153477532523, 0.029793675390205214, 0.04904972568952611, 0.0198298737938915, 0.036233556257294755, 0.03655009962884443, 0.07791478519460984, 0.012817127862945199, 0.00657067824587492, 0.05895273733351912, 0.02758567833474704, 0.053742344956845045, 0.06557600586009876, 0.030476946583283798, 0.01868055760860443, 0.006023009307682514, 0.03420507242637021, 0.101986887066492, 0.1278337040649993, 0.12190075671034199, 0.15273066024695123, 0.10150481507714305, 0.10561367031186819, 0.11451958492398262, 0.0679331754467317, 0.1435662577194827, 0.15251483182821954, 0.09876086017382996, 0.10311421871717487, 0.13602478882031782, 0.13312958846134798, 0.10469764803669282, 0.07538566126355103, 0.1811645616378103, 0.0974260935825961, 0.22512539343110152, 0.16884545981884003, 0.10523671696760825, 0.21386804963861192, 13.60328481878553, 53.33391727719988, 40.838124070848735, 36.24947118759155, 47.79968752179827, 35.806308133261545, 29.85120861870902, 2.9229477729116167, 0.2705997925783907, 0.9120381346770695, 0.3907440256859575, 0.7376824276787894, 6.162537114960807, 8.04599746635982, 3.8238759551729475, 14.155613626752581, 40.584573881966726, 48.73318495069231, 53.060140882219585, 50.28499909809658, 48.44956643240792, 49.425444398607524, 49.92025341306414, 47.96007626397269, 47.62614583969116, 48.08253131593977, 47.6720039503915, 47.42656230926514, 48.39337635040283, 47.831465108054026, 48.46629769461495, 47.35342904499599, 48.84326526096889, 46.15992655072893, 48.82894502367292, 44.91297503880092, 44.13963706152779, 47.52041162763323, 47.492393016815186, 48.26565456390381, 46.42904417855399, 40.34352002825056, 36.37073809759957, 35.6215694291251, 38.07333857672555, 37.551184926714214, 36.81583275113787, 37.703548499516074, 38.11018487385341, 37.24790300641741, 38.059900760650635, 38.80761725561959, 38.234370027269634, 36.43663133893694, 34.6958018711635, 40.54635878971645, 51.42339195523943, 49.39751958847046, 48.488802909851074, 33.06406259536743, 38.683188915252686, 45.36301680973598, 41.14210081100464, 46.974425656454905, 43.9482558795384, 42.17720174789429, 41.36084052494594, 40.86606625148228, 42.98823022842407, 49.438899585178916, 48.28369556154524, 46.34175395965576, 39.82404143469674, 39.56073597499302, 38.95304652622768, 38.82871198654175, 36.773546014513286, 37.45563677379063, 34.99502951758248, 35.11557034083775, 37.35873372214181, 37.315581934792654, 36.449839864458355, 35.62313972200666, 33.98633868353707, 36.909334659576416, 35.59778574534825, 35.6340970311846, 36.414914744240896, 39.21797786440168, 35.513771602085654, 34.44467660358974, 35.82862227303641, 32.880418232509065, 35.0174617767334, 33.02288062231881, 33.68484592437744, 36.15795646395002, 34.15682315826416, 34.17018454415457, 36.446066992623464, 39.69954361234392, 42.15612438746861, 46.68479347229004, 46.00894219534737, 47.09141942432949, 43.59264360155378, 44.005019187927246, 42.750417709350586, 43.93866041728428, 45.78597102846418, 44.359877586364746, 43.594540459769114, 40.718243326459614, 41.86590160642351, 39.43846157618931, 43.42599105834961, 43.95273399353027, 47.33348076684134, 41.61448451450893, 25.215212447302683, 2.807590522936412, 1.3264365153653281, 9.173386982509069, 5.204851703984397, 1.6635280443089349, 0.29834188680563656, 0.2620543496949332, 0.27038469697747913, 0.47920873441866463, 1.4162774831056595, 6.766563560281481, 41.610353810446604, 44.15313393729073, 35.77722644805908, 47.626472405024934, 26.97652346747262, 1.4407300395624978, 0.14731817639299802, 0.17400039892111505, 0.08224546031228133, 0.20058761297592095, 0.09594135718154055, 0.19923734185951097, 0.14751716357256683, 0.13572991107191357, 0.09779077222836868, 0.15260221356792109, 0.14754711410829, 0.1071685536631516, 0.09505157385553632, 0.0902769129191126, 0.07663322931953839, 0.12487576635820524], [0.06687926807041679, 0.04079777295035975, 0.030196759118033305, 0.03684620213295732, 0.03576084805120315, 0.02533044506396566, 0.06017386966517993, 0.024676778353750706, 0.07857343913721186, 0.06291422833289419, 0.02442331499020968, 0.02833069791086018, 0.025823548336380293, 0.07127304694482259, 0.055182827303984334, 0.010839498535330807, 0.018376787658780813, 0.04831996466964483, 0.020433021875630532, 0.06360814574041537, 0.051827322359063795, 0.06694858042257172, 1.796782442501613, 27.282226834978374, 39.404311180114746, 27.018945693969727, 29.781160354614258, 31.60858522142683, 25.663751670292445, 7.035788885184696, 0.2846931006227221, 0.08476648932056767, 0.08461729304066726, 0.09184696152806282, 0.09999432827212981, 2.8046099628720964, 3.962824293545314, 1.8737524151802063, 17.088583741869243, 43.45454468045916, 50.24858358928135, 50.200950213841026, 46.454082012176514, 44.217220646994456, 45.08890342712402, 47.44318240029471, 45.744333948407856, 45.70353760038103, 46.685123511723106, 46.895695618220735, 44.36009298052107, 44.72577319826399, 44.226805686950684, 44.74174015862601, 44.26804671968733, 45.87712444577898, 45.89191716057913, 46.96562923703875, 45.93384606497628, 43.5957042830331, 45.13907636914934, 45.273614338466096, 42.3751038142613, 40.50547906330654, 34.426541805267334, 33.5694328716823, 33.59386968612671, 33.29252978733608, 33.261242049080984, 34.43746437345232, 35.54850217274257, 35.28278916222708, 32.357194559914724, 32.14286000388009, 33.726590701511924, 36.119439125061035, 36.08747393744332, 34.69981792994908, 41.910536834171836, 43.54457943780081, 46.3295008114406, 40.2972172328404, 31.1771194594247, 40.04891640799386, 41.14991058622088, 40.735547815050396, 41.83952624457223, 41.27286243438721, 40.821087087903706, 38.08394152777535, 39.03128671646118, 48.67656408037458, 41.4293532371521, 43.475542136601035, 38.68323060444423, 37.757966790880474, 35.84393262863159, 37.10613891056606, 36.52088172095162, 36.497785908835276, 34.77725560324532, 33.71936110087803, 32.18789822714669, 32.04943452562605, 32.608215604509624, 32.580117089407786, 31.790381363459996, 32.22210768290928, 33.952094486781526, 34.232520307813374, 33.105133397238596, 32.43082462038313, 31.877946036202566, 32.138767514910015, 32.81265245165144, 33.265966824122835, 32.4228515625, 32.388117517743794, 31.95687757219587, 31.828888280051096, 31.19168288367135, 33.28092629568917, 31.82501813343593, 33.30669369016375, 35.44478988647461, 38.59629474367414, 41.891637734004426, 44.56792402267456, 43.50192444665091, 45.062854630606516, 41.79910857336861, 43.19094739641462, 41.10189505985805, 39.349566323416575, 40.945150647844585, 39.470124517168315, 37.415458815438406, 39.45316049030849, 39.556879724775044, 42.16052259717669, 42.70740141187395, 34.34703704289028, 10.29676912512098, 0.255190696567297, 1.4550749212503433, 5.252893286091941, 5.08812370470592, 0.6790230753166335, 0.02758470124432019, 0.03675575341497149, 0.12113188153931073, 0.2540873714855739, 0.21096474757151945, 11.624344059399196, 35.54061596734183, 26.782253571919032, 31.315624850136892, 31.778110844748362, 5.300372932638441, 0.1976092785064663, 0.0777956208746348, 0.039378063952816386, 0.06855083908885717, 0.029945463673876863, 0.03122864124764289, 0.054210316988506486, 0.050233399495482445, 0.05924646157239165, 0.016541550601167337, 0.023278829974255393, 0.015994088192071234, 0.015594753370221173, 0.030168138510946716, 0.010840364515648356, 0.04192157621894564, 0.01908093228537057, 0.052063242199697664, 0.0059305958067333055, 0.048643181433102915, 0.030087080717618977, 0.03675348371533411, 0.02209401792580528, 0.03591804425897343, 0.0106119060157133, 0.02463548949786595, 0.027954282305602516, 0.02376623864152602, 0.013359223060043795, 0.03800536725404007, 0.045890490391424725, 0.09834658740354435, 0.05333681511027472, 0.015646359351064478, 0.021268464724666307, 0.038616608562214036, 0.04983010881447366, 0.03348367435059377, 0.08094538721655097, 2.9816963119166235, 33.398875440870015, 41.55490371159145, 27.38021727970668, 36.82338891710554, 35.1478898865836, 28.841032607214792, 7.640914014407566, 0.4264002538153103, 0.20812003021793707, 0.03782566403970122, 0.14431613390999182, 0.04603078089920538, 3.823490764413561, 5.470036217144557, 3.0434264966419766, 21.939293146133423, 44.45574535642351, 50.48505858012608, 51.88795893532889, 49.39198187419346, 46.3805388041905, 46.56308535167149, 47.64867884772164, 47.29821171079363, 48.71882997240339, 48.309959752219065, 47.69670827048165, 46.09764289855957, 45.39791761125837, 45.19024985177176, 46.49601786477225, 45.44488395963396, 48.25942897796631, 47.88504614148821, 48.14136518750872, 44.964332648685996, 44.1132721219744, 45.54020629610334, 47.33296660014561, 44.239684173039024, 41.359718390873496, 35.44547775813511, 35.25114706584385, 34.71121992383684, 35.43116446903774, 33.87472629547119, 36.785430908203125, 36.03710991995675, 36.113015515463694, 35.00741120747158, 33.48806946618216, 35.458832195826936, 37.54063408715384, 36.93716219493321, 35.880945682525635, 44.588619232177734, 46.7592990057809, 47.27362551007952, 42.277419090270996, 32.9322726385934, 39.42132731846401, 42.194221360342844, 40.0664119720459, 41.05196877888271, 41.301329204014365, 40.68165758677891, 40.00291933332171, 42.36773872375488, 48.94426080158779, 43.90858861378261, 44.43433100836617, 40.12788268498012, 39.95992735454014, 37.73462431771414, 36.816576208387104, 38.75005143029349, 37.11918762751988, 35.86718130111694, 34.90557493482317, 32.911316871643066, 34.43884359087263, 34.491062777382986, 35.00281497410366, 33.329313550676616, 33.982572759900776, 35.047068050929475, 36.46136345182146, 35.15964623859951, 36.19631746837071, 33.389571802956716, 34.77325691495623, 34.576591627938406, 34.223696095602854, 33.626314299447195, 33.9096861566816, 33.22493076324463, 33.97667373929705, 32.50179352079119, 33.71805483954293, 33.04249538694109, 36.672022410801475, 37.876159123011995, 40.6147985458374, 43.770545278276714, 44.512574672698975, 43.453168937138145, 46.17032452992031, 42.310714857918875, 44.65528719765799, 43.521358558109824, 42.053853852408274, 43.09458630425589, 42.00916998726981, 38.52610404150826, 40.12746926716396, 40.975618498665945, 45.226123401096885, 44.822954177856445, 35.44627332687378, 12.476940137999398, 0.4782469517418316, 3.7030528613499234, 9.382457409586225, 7.046623298100062, 1.84397634438106, 0.059510845957057815, 0.044103483602936776, 0.0932837322886501, 0.6877687403133937, 0.573144796703543, 14.48391079902649, 43.87191949571882, 30.63068880353655, 33.75728784288679, 37.4351395879473, 9.463865109852382, 0.28612787649035454, 0.03277230162971786, 0.04368094627612403, 0.05264820045392428, 0.016559665789827704, 0.02089694814224328, 0.009634699389737631, 0.015905766681368862, 0.04390268812754324, 0.022598727539713894, 0.03402915204476033, 0.06228851048009736, 0.05604554047541959, 0.03328857856935688, 0.013117149754959558, 0.0679541625348585, 0.09379809575953654, 0.16352166049182415, 0.15017354674637318, 0.1480460273368018, 0.12825325583773, 0.13440831484539167, 0.10433092700051409, 0.11799475630479199, 0.12271547370723315, 0.18004716373980045, 0.15097163963530744, 0.10207557159342937, 0.1604102381638118, 0.0947330966591835, 0.1261095737240144, 0.21905004871743067, 0.13718239670353277, 0.15397369568901403, 0.12014849430748395, 0.10370828291135174, 0.1978236955723592, 0.09991859019334827, 0.20983060342924936, 3.2025704256125858, 37.49117333548409, 50.56940623692104, 37.224154063633506, 40.233891350882395, 39.62860945292881, 32.237803663526265, 11.10065746307373, 1.0927415639162064, 0.7835078601326261, 0.13593790919653007, 0.35796530172228813, 0.26790869555303026, 5.211919324738639, 9.572492378098623, 3.555158717291696, 22.490453788212367, 45.6348546573094, 51.89865221296038, 53.469844886234824, 51.20873430797032, 46.47951589311872, 48.296546254839214, 50.164162976401194, 48.43672268731253, 48.96232264382498, 49.615838936397004, 50.0045211655753, 47.79673801149641, 48.16642733982631, 47.547700677599224, 48.01335505076817, 47.239673137664795, 49.02269206728254, 49.139949866703574, 49.746656145368306, 46.65071603230068, 45.59793192999703, 46.31877279281616, 48.74801240648542, 45.538886138371055, 44.81982054029192, 37.288567338671, 36.64343057359968, 36.267241205487935, 37.67297295161656, 35.522811208452495, 38.59454032352993, 39.022653579711914, 38.95595434733799, 35.93951899664742, 34.7365391595023, 36.66545983723232, 40.147160461970735, 38.592942237854004, 37.22097178867885, 47.013106278010774, 48.673718793051584, 49.54110411235264, 42.362579686301096, 31.873256002153667, 42.206801073891775, 42.08054535729544, 42.56346947806222, 42.72647769110543, 41.643840653555735, 41.17033134187971, 40.69607162475586, 45.79649060113089, 50.92881570543562, 44.728910309927805, 47.084856850760325, 42.888356821877615, 42.030084065028596, 38.786724022456575, 39.328495911189485, 40.03996018001011, 40.16794599805559, 38.64510236467634, 36.969290665217805, 35.579605783735005, 35.91994244711739, 36.02141393933977, 35.688928740365164, 34.91967282976423, 35.81703962598528, 36.28080408913748, 37.86563607624599, 36.24591370991298, 37.062417370932444, 34.88451494489397, 35.94002621514456, 35.687070097242085, 36.03040490831648, 35.395051206861226, 35.46919543402535, 34.67858076095581, 35.05202211652483, 33.829031467437744, 35.53173964364188, 35.301090717315674, 37.593711376190186, 39.529430866241455, 42.553196566445486, 44.66255153928484, 47.18715865271432, 45.87318481717791, 47.23654644829886, 44.06125095912388, 45.563944816589355, 43.01688807351248, 43.396238871983115, 44.102422509874614, 43.709567887442454, 40.233290331704275, 42.82399913242885, 42.16809960774013, 48.538677079336985, 45.955479281289236, 37.09712362289429, 13.917870589665004, 0.8071492144039699, 3.767755789416177, 11.671092408043997, 12.670514345169067, 2.5686441447053636, 0.2927748326744352, 0.20383946491139276, 0.2783016264438629, 1.8126255295106342, 2.0522086450031827, 22.78742848123823, 46.41441127232143, 36.23334094456264, 40.97439214161464, 41.72122968946184, 9.748219268662588, 0.3809230183916432, 0.11445304778005395, 0.1846235024609736, 0.12817232018070562, 0.11812644638121128, 0.13763797868575367, 0.14203583555562155, 0.10947383567690849, 0.18904567802590982, 0.16170797709907803, 0.09388864625777517, 0.1314469844635044, 0.11397548126322882, 0.0740496190264821, 0.06252052195902381, 0.2038083201540368, 0.14157276254679474], [0.04299791257030197, 0.004853005861930017, 0.00768717411639435, 0.06107825506478548, 0.02862834238580295, 0.037974263208785226, 0.03518914497856583, 0.02306588872202805, 0.024945320461743643, 0.021543632727116346, 0.05948483092444284, 0.04422769622345056, 0.032603461761027575, 0.03027566595535193, 0.048559894652238915, 0.03606169690777149, 0.027952675873945867, 0.03970205085352063, 0.029219058009662797, 0.0014235708159893484, 0.05152053971375738, 0.033976582544190545, 0.11417893320322037, 12.5023592540196, 36.87757444381714, 27.289232356207712, 22.523296185902186, 31.462659154619487, 29.996335642678396, 9.872251561709813, 0.9218751553978238, 0.05249214757766042, 0.07497818741415228, 0.040835177193262746, 0.0732742842020733, 1.9127085762364524, 4.708019895212991, 0.5491732401507241, 5.4770104714802335, 30.882206644330704, 47.95112698418753, 50.242257254464285, 48.10998364857265, 46.30697127750942, 45.69671794346401, 44.05115522657122, 43.72668130057198, 42.63762412752424, 42.30768544333321, 41.9319338117327, 40.68809161867414, 41.152078424181255, 41.320443698338096, 40.21486370904105, 41.81008325304304, 43.4012450490679, 44.369806562151226, 46.60522617612566, 45.51613426208496, 44.02399819237845, 43.84714221954346, 46.10894761766706, 43.118137223379954, 39.52521678379604, 32.7723320552281, 34.19238403865269, 33.34180988584246, 33.039976664951865, 32.76562009538923, 33.952111857278005, 35.403812885284424, 34.999948842184885, 34.04138926097325, 32.49854523794991, 32.44508579799107, 33.38460731506348, 34.803558009011404, 34.61311483383179, 37.26059736524309, 43.715175083705354, 44.64986760275704, 47.63175998415266, 53.783048834119526, 46.594209807259695, 47.97149215425764, 46.82894427435738, 46.59387976782662, 42.842109612056184, 42.75981167384556, 37.31581817354475, 36.52815648487636, 46.378096512385774, 42.87795884268624, 43.88487441199166, 41.82150261742728, 39.54183340072632, 39.49935558864048, 43.078991072518484, 41.88347012656075, 41.93240281513759, 42.14048399244036, 35.17870167323521, 34.75432654789516, 33.306203842163086, 31.75233997617449, 33.65012925011771, 32.497503008161274, 32.574798243386404, 32.92335115160261, 33.75364351272583, 32.53031587600708, 32.862762859889436, 32.17348766326904, 32.81449025017874, 32.32239103317261, 33.67913450513567, 32.90650871821812, 32.19483600343977, 32.971804414476665, 32.365907600947786, 30.91394601549421, 31.816270351409912, 30.92129373550415, 30.764643124171666, 31.687850270952495, 32.645492689950125, 37.23496198654175, 41.612118652888704, 42.48679263251168, 40.909263202122276, 44.502617904118125, 45.85832609449114, 39.724421637398855, 39.29749304907662, 42.043768542153494, 39.68489333561489, 41.41731548309326, 40.43813712256295, 40.9409886768886, 43.310796873910085, 41.486828735896516, 25.87911455971854, 4.379251113959721, 0.09999822306313685, 4.163291547979627, 9.187678558485848, 8.576952746936254, 2.09866321512631, 0.14333233955715383, 0.03942178874941809, 0.1660757748676198, 0.3554633802601269, 2.060653094734464, 22.228199243545532, 24.042141130992345, 27.526426485606603, 37.61285366330828, 20.04269896234785, 0.9681909786803382, 0.04991096304729581, 0.036691204378647466, 0.03759977973199316, 0.033518150714891295, 0.028627446719578335, 0.037773196319384236, 0.055720240609454255, 0.026737494294398596, 0.01000326095215444, 0.0492079736265753, 0.06381231014217649, 0.054540858537490876, 0.02157844666258565, 0.02717975154519081, 0.014211587724275887, 0.013398337211193783, 0.007970621094240673, 0.05206810051043119, 0.059333483688533306, 0.029644075381968702, 0.05332771934834974, 0.032768651111317534, 0.0738155244450484, 0.016812869613724093, 0.02339640652228679, 0.05751321172075612, 0.015907217049971223, 0.07450110944254057, 0.02246364309186382, 0.029541694625679935, 0.10183114970901183, 0.0469550100554313, 0.027391026993947368, 0.031352263542690446, 0.0446587186306715, 0.013539855019189417, 0.04649861722386309, 0.02723084353575749, 0.030008971158947264, 0.3611961326428822, 18.182459490639822, 44.87396090371268, 29.32009526661464, 25.94450405665806, 38.358652455466135, 33.2872873714992, 12.392280680792672, 1.0514948857682092, 0.22197994935725415, 0.16427491578672612, 0.11240400094538927, 0.04297463881916233, 1.4092784758125032, 6.867002376488276, 0.7137602141925267, 6.748712335314069, 33.93827451978411, 49.41346917833601, 51.375828061785015, 49.878567695617676, 47.93341950007847, 47.776855741228374, 47.31686067581177, 45.58282307216099, 45.2093573978969, 44.12582056862967, 44.53817531040737, 42.61173513957432, 42.47616536276681, 44.023866176605225, 42.743323598589214, 44.84636613300869, 45.48336655752999, 45.55514144897461, 46.83227940968105, 47.95211015428816, 43.7866963659014, 45.370753628867014, 47.920398575919016, 45.51719386237008, 40.62364707674299, 34.36451176234654, 34.59866605486189, 34.16520963396345, 34.87161561420986, 35.13642883300781, 35.38218314307076, 37.01339088167463, 36.10311780657087, 35.5332612991333, 34.787094252450125, 33.90970005307879, 35.21866423743111, 36.16572107587542, 35.930441175188335, 37.76659645353045, 45.59012215478079, 46.336146763392854, 49.5966341154916, 54.263968399592805, 48.52719170706612, 49.19389568056379, 47.59872824805123, 48.12179211207798, 44.770936489105225, 41.77587727137974, 37.859858649117605, 40.133003507341655, 47.259232316698345, 45.08967467716762, 45.51577295575823, 42.099843978881836, 41.96172768729073, 40.32812282017299, 43.70042405809675, 43.73793738228934, 42.13368170601981, 43.15931224822998, 36.81600645610264, 34.4510064125061, 34.53495454788208, 33.712590081351145, 34.62442997523716, 33.20860597065517, 34.92002023969378, 35.26351138523647, 34.9635819707598, 34.01474986757551, 33.42964553833008, 33.261464391435894, 33.45470074244908, 34.1859256880624, 34.17594460078648, 34.99844108309065, 33.97573225838797, 33.60570246832711, 33.85658802304949, 32.74747140066964, 32.93822724478585, 32.201023374285015, 32.24391460418701, 33.60140153339931, 34.73252657481602, 40.763528210776194, 44.06110157285418, 43.86651379721505, 43.23631565911429, 46.40624713897705, 44.42834513528006, 41.795387813023154, 41.86353574480329, 43.94727618353707, 41.83439152581351, 42.5545723097665, 41.17591074534825, 42.618506159101216, 44.076748916081016, 41.5437205859593, 28.66935477937971, 6.330641831670489, 0.7253065460494587, 7.085763369287763, 8.746243000030518, 4.597918306078229, 1.757438050849097, 0.02279529913461634, 0.07093444439981665, 0.4263861674283232, 1.5779905085052763, 2.7306357494422366, 25.34556586401803, 33.71973282950265, 28.962499277932302, 41.71249232973371, 25.5673280443464, 1.6311802715063095, 0.03923632138009582, 0.032033760366695266, 0.0673416354028242, 0.05577163963711687, 0.05423305808965649, 0.04079913002039705, 0.06326929892280272, 0.08328737118946654, 0.011494105864715363, 0.030648514162749052, 0.02187913775976215, 0.03498902125284076, 0.05998267885297537, 0.026433515695056746, 0.060467064646737914, 0.023080383926363926, 0.0135689684123333, 0.18650626071861812, 0.10829477251640388, 0.16165757551789284, 0.12263110466301441, 0.09979672530399901, 0.10856506694108248, 0.13838542572089604, 0.08802621904760599, 0.19513554338897976, 0.1361765092504876, 0.24731475061603955, 0.1962798519858292, 0.11352357015545879, 0.2624307194990771, 0.17294113790350302, 0.10360817864005055, 0.095025728456676, 0.18745250494352408, 0.10827371757477522, 0.08321045245975256, 0.21022766855146202, 0.14956152173025267, 0.4024940537554877, 18.63696547916957, 50.26690598896572, 38.17392069952828, 31.328920228140696, 42.38119043622698, 38.89975731713431, 16.323627029146465, 2.549310347863606, 0.25102500723940985, 0.34680152790887014, 0.34408790352089064, 0.17320052827043192, 2.8650267209325517, 9.889254672186715, 1.5501780637672968, 8.633410334587097, 35.84021186828613, 50.16717849458967, 53.77928638458252, 51.151397773197715, 51.817750862666536, 50.23100117274693, 48.27632004874093, 47.34597362790789, 46.72899096352713, 46.14909083502633, 45.87161799839565, 43.672051089150564, 44.775386810302734, 46.72207750592913, 43.312047549656455, 46.976732458387104, 47.9174108505249, 47.179553849356516, 48.51549094063895, 48.121382168361116, 45.91436331612723, 45.49207265036446, 50.07489252090454, 47.92799643107823, 42.88772453580584, 36.55873898097447, 37.49943821770804, 36.23380994796753, 36.284330299922395, 35.37514461789812, 36.68638433728899, 38.465831892830984, 38.151672567640034, 37.12494421005249, 36.980550221034456, 35.41135515485491, 36.46589020320347, 37.6737129347665, 37.75125135694231, 39.09096132005964, 48.05223022188459, 47.15788589205061, 50.87478998729161, 51.449781213487896, 46.79924767357962, 50.18438570840018, 48.591424328940256, 48.58848524093628, 46.699752943856375, 43.0090366091047, 39.73441662107195, 44.45700298036848, 48.56974594933646, 46.313450472695486, 48.37137140546526, 44.77916315623692, 44.37740094321114, 42.359988008226665, 46.482989992414204, 46.85854707445417, 44.262950216020855, 45.25538921356201, 39.19617441722325, 37.3675787789481, 37.36517122813633, 35.72778654098511, 36.33655990873064, 34.872845445360454, 35.378000327519004, 37.454674448285786, 36.61788204738072, 36.44494138445173, 36.24906471797398, 35.765602111816406, 35.703137806483674, 35.18564639772688, 35.30682298115322, 37.749333654131206, 35.5811448097229, 36.4936968939645, 35.85605376107352, 33.683289527893066, 34.134060859680176, 34.640991006578716, 33.5064127104623, 34.033027103969026, 35.16145971843174, 41.57050241742815, 44.43485907145909, 46.70131628853934, 43.38325963701521, 48.53288228171212, 46.314273834228516, 43.360858644757954, 43.06602225984846, 46.23988989421299, 44.00373029708862, 44.23037358692714, 41.81613513401577, 44.48207902908325, 45.49787092208862, 44.859647614615305, 28.021982431411743, 6.621457380907876, 0.4058858874653067, 9.344133751732961, 17.06308732713972, 15.715051685060773, 5.297247546059745, 0.4801323562860489, 0.16348229189004215, 1.359101733991078, 3.37912979722023, 5.073578085218157, 30.82834073475429, 34.92415789195469, 35.910006523132324, 48.4583454813276, 27.941431965146744, 1.6552455744573047, 0.12468816499624934, 0.10780992531882864, 0.10972811667514698, 0.10374747509402887, 0.14221441240182944, 0.15422992408275604, 0.12392972569380488, 0.1647033156561, 0.07933054172566958, 0.12520026894552366, 0.16556938418320247, 0.10170958337507077, 0.1828627855117832, 0.15163877526564257, 0.11450422289116041, 0.10694561419742447, 0.10163405564214502], [0.0358030902487891, 0.05228396964126399, 0.035911316584263525, 0.013141759371917163, 0.0037434039072000553, 0.039161295763083866, 0.035938688686915805, 0.027264368254691362, 0.02638726674818567, 0.0058294423506595194, 0.02895302139222622, 0.01354706784643765, 0.03143250709399581, 0.03215751836874655, 0.012996643631985145, 0.029752101549612622, 0.04123031188334737, 0.02124868712521025, 0.02158279946473028, 0.06342222035995551, 0.038312010799667666, 0.1135048425889441, 0.03112258283155305, 1.504626868026597, 18.33062287739345, 35.327066557747976, 26.883490562438965, 29.6510066986084, 29.72206939969744, 9.289655532155718, 1.4555194973945618, 0.18906123004853725, 0.042663598366613896, 0.07261517564100878, 0.026422626904344985, 0.3273746632039547, 0.8699596268790108, 0.3064953535795212, 0.3774149923452309, 15.24497652053833, 42.01138646262032, 50.42367819377354, 49.56248719351632, 45.82525961739676, 46.086293016161235, 44.39266266141619, 43.12508889607021, 40.28743764332363, 41.25440107073103, 41.54150063650948, 40.43677874973842, 42.62021541595459, 40.94663756234305, 40.97134188243321, 38.6281418119158, 40.625373704092844, 43.21300445284162, 44.41971199853079, 46.51225233078003, 45.12909180777413, 45.72948564801897, 44.662992749895366, 43.02616391863142, 37.69112859453474, 34.29532160077776, 33.82015861783709, 34.61393124716622, 33.635652678353445, 34.362330027988975, 34.05449703761509, 34.14128351211548, 34.150222369602744, 34.295332023075645, 34.2580132484436, 33.62483433314732, 31.819143431527273, 33.92504167556763, 33.230013370513916, 33.71033191680908, 39.72572095053536, 46.361650126320974, 42.19001770019531, 45.45259646006993, 46.94578170776367, 45.34727913992745, 44.44862345286778, 46.9549811226981, 45.41662911006382, 48.0522962297712, 39.00592926570347, 37.16822106497628, 48.653138228825156, 43.56588956287929, 44.71166835512434, 42.58629431043352, 43.199799401419504, 43.67974621909005, 44.68161392211914, 46.041588306427, 46.745381764003206, 44.8739470073155, 41.64750235421317, 33.54465559550694, 33.453540393284385, 32.37520776476179, 33.38902984346662, 33.43571826389858, 32.21728910718645, 32.23766817365374, 33.267262663160054, 32.014950616019114, 32.70050505229405, 33.011996269226074, 31.32195118495396, 31.79344551903861, 32.55374520165579, 32.87212903159005, 33.06651530947004, 34.7874173436846, 34.10956151144845, 34.860832009996685, 35.882797377450125, 34.64197070258004, 33.80051258632115, 32.11590794154576, 31.356382983071462, 32.52344410760062, 36.289006437574116, 37.376121589115684, 41.76329060963222, 42.16901676995413, 42.814344610486714, 40.37015247344971, 40.61770289284842, 42.01667056764875, 42.8159670148577, 40.350933756147114, 42.611377307346885, 42.106583731515066, 43.16236250741141, 32.26102801731655, 12.533211861337934, 1.0640693881681986, 0.27277786284685135, 4.875025928020477, 6.928565587316241, 3.1299165870462144, 1.840374571936471, 0.09684581721999816, 0.0398532284556755, 0.23861986718007497, 0.1525700781494379, 4.024550352777753, 27.947987590517315, 35.27259962899344, 31.04635783604213, 37.83461584363665, 6.572027896131788, 0.22344638566885675, 0.07181375793048314, 0.08091536204197577, 0.06196288152464798, 0.02776987345090934, 0.006835399777628481, 0.016040367673018148, 0.024919661660013453, 0.06311406368123633, 0.02548619938482131, 0.030614458490163088, 0.007447634291435991, 0.025513412031744207, 0.04081000693674598, 0.04871871595137885, 0.03319830966315099, 0.03473699299086418, 0.05261556291952729, 0.032638368995061944, 0.016931760823354125, 0.07218136784753629, 0.07650647219270468, 0.028031694669542567, 0.03510950193075197, 0.02038866943413658, 0.04637675911986402, 0.006347120889196438, 0.02825659849414868, 0.024269377446866462, 0.04154624457338026, 0.018247991534216062, 0.0013820617542868213, 0.03268207682828818, 0.03309816467974867, 0.045382243913731406, 0.035941192481134615, 0.05247220204078725, 0.0386823382494705, 0.0374021123030356, 0.013511189459157842, 0.022320326317899992, 2.8044238814285825, 26.207034792218888, 38.56564276559012, 25.80472367150443, 36.08532346997942, 35.28327553612845, 11.904375570161001, 2.1269445547035764, 0.4946005142160824, 0.06437319397394146, 0.16727710754743644, 0.05189852782392076, 1.709757775068283, 1.0439180923359734, 0.8156409444553512, 0.6312468818255833, 16.56453844479152, 43.16887991768973, 51.33521236692156, 51.368275369916645, 47.376257351466585, 46.96676526750837, 47.67214986256191, 44.029035636356895, 43.32786512374878, 44.065729073115754, 42.71703161512102, 42.68255812781197, 43.79917533057076, 42.71178225108555, 42.03912019729614, 41.65280382973807, 42.616772583552766, 45.065828459603445, 46.79259477342878, 47.70546300070626, 46.59070444107056, 47.18132563999721, 46.81731993811471, 45.96631499699184, 39.41555336543492, 37.37074368340628, 34.93347890036446, 36.119748319898335, 34.442654677799766, 35.59750434330532, 35.55330337796892, 35.334396907261436, 36.119129930223735, 35.69632509776524, 34.34059953689575, 34.92516885484968, 34.26256431852068, 34.85587794440133, 34.730403900146484, 35.19335194996425, 42.21106726782662, 46.65842853273664, 44.01633780343192, 46.46911096572876, 50.50568083354405, 47.782257965632844, 47.89592007228306, 47.62183795656477, 46.673787525721956, 49.07180540902274, 40.12444680077689, 39.22554097856794, 49.94888693945748, 44.570877007075715, 45.378316743033274, 44.76752839769636, 44.94639239992414, 46.52306372778756, 45.565744400024414, 45.85556765965053, 47.151854855673655, 46.45431130273001, 42.658156054360525, 35.43101855686733, 34.69514874049595, 32.804536955697195, 34.54461601802281, 34.48639358792986, 33.671067646571565, 34.530292306627544, 35.05710819789341, 33.24935368129185, 35.0070082119533, 34.49999468667166, 32.621858392442974, 33.294419697352815, 33.69972201756069, 33.71682848249163, 34.59761340277535, 35.15190941946847, 36.119585037231445, 35.98164245060512, 36.96583046231951, 35.235027245112825, 34.25182935169765, 32.8308219909668, 32.528380802699495, 34.40616621289934, 38.16939742224557, 41.162386076790945, 43.388856410980225, 44.43135370526995, 43.868004185812815, 42.726835523332866, 42.260448115212576, 42.89254311152867, 45.65605361121041, 41.90429040363857, 44.61747162682669, 43.43559694290161, 46.218670095716206, 35.409423555646626, 15.315332242420741, 1.174919102873121, 1.9210422890526908, 13.006349444389343, 8.016753367015294, 5.760421412331717, 1.1031347662210464, 0.1408608571759292, 0.04885025675009404, 0.4825062517608915, 0.8527527930481094, 4.712458057062967, 31.982005732400076, 30.815507411956787, 33.992661544254844, 45.33178465706961, 10.799368807247706, 0.2844878302088806, 0.04759974724480084, 0.06653673680765287, 0.009449220994221312, 0.051311160770377943, 0.0561369052156806, 0.01728063978121749, 0.05897447759551661, 0.05543012617688094, 0.03545256923618061, 0.07351264676877431, 0.05987787911934512, 0.05719567768807922, 0.015704542032576034, 0.004129327484406531, 0.02276679896749556, 0.014748862778235759, 0.0678485349885055, 0.12890766215111527, 0.1287608950265816, 0.15137034681226524, 0.17970915830561093, 0.09168764829103436, 0.10964074172079563, 0.15631469578615256, 0.09275845118931361, 0.1316350879413741, 0.09376480683152165, 0.10352532951427357, 0.09654130427432911, 0.07415345524038587, 0.06515536843133823, 0.12502359199736798, 0.18851433082350663, 0.08967096079140902, 0.09359211966927562, 0.14572935950543198, 0.15953813067504338, 0.10288048375930105, 0.1694299363132034, 0.25212179124355316, 2.970974372965949, 30.37562390736171, 47.19220304489136, 35.92863116945539, 40.50819928305489, 39.73940890175955, 15.792647429874965, 3.4729241813932146, 1.243947718824659, 0.20540856357131684, 0.4724503627845219, 0.18785199922110352, 3.060435035399028, 2.766075687749045, 1.591003181678908, 0.908908731171063, 17.86843912942069, 45.08833714893886, 52.67565883908953, 54.231648853846956, 47.12842205592564, 48.68158067975725, 49.4794145311628, 46.131511892591206, 46.47327988488333, 46.30311502729143, 45.400297369275776, 44.37829726082938, 46.518832274845664, 45.067704473223, 45.1708539554051, 43.32366493770054, 45.19513096128191, 47.756987367357524, 48.421804904937744, 49.22012513024466, 46.30720056806292, 49.293206283024375, 48.74799503598894, 47.233308587755474, 40.56509460721697, 38.80351087025234, 37.559460231236045, 37.80608306612287, 37.37191792896816, 38.4324631690979, 36.93272924423218, 37.14148787089756, 37.662800788879395, 38.18549639838082, 37.52485472815377, 37.29835387638637, 35.335623264312744, 37.64407191957746, 37.21153960909162, 36.86668314252581, 43.6996145929609, 49.82929801940918, 44.596689564841135, 48.32696894236973, 51.283500398908345, 47.53679200581142, 49.17904390607561, 49.650885650089805, 49.26278359549386, 50.806318964277, 41.13159166063581, 42.46366555350167, 52.49319914409092, 47.00960438592093, 47.49258409227644, 47.466778482709614, 46.885526929582866, 48.017794949667795, 48.82262563705444, 47.68756096703665, 49.16909408569336, 48.527024950299946, 45.28119829722813, 37.23058462142944, 36.400928020477295, 35.521987846919465, 35.354428563799175, 36.77251420702253, 34.67438752310616, 34.891292912619456, 36.73567138399397, 35.35437992640904, 36.40602452414376, 36.31221342086792, 34.235983984810964, 36.99525260925293, 36.215171405247276, 35.861084256853374, 36.72890383856637, 37.777074337005615, 38.32022196905953, 37.79272862843105, 39.01326656341553, 37.585727896009175, 36.167065552302766, 34.31609671456473, 34.46880422319685, 36.648398535592214, 40.35850034441267, 41.80398620877947, 45.14851202283587, 44.36679451806204, 45.12092767442976, 43.24743972505842, 44.49068089893886, 44.171643938337056, 46.577367373875205, 43.71127367019653, 46.20849098478045, 44.58874429975237, 47.09813485826765, 33.7718061038426, 15.531808580671038, 1.351979830435344, 3.3845841331141333, 11.721978408949715, 14.802159139088221, 12.174313953944615, 3.2836839130946567, 0.14965672019336904, 0.11706145852804184, 1.0305093718426568, 1.235572099685669, 7.680421471595764, 35.95610087258475, 42.62604495457241, 40.20585536956787, 49.3366881098066, 11.616773997034345, 0.2785048612526485, 0.2247063030621835, 0.12299976630934648, 0.14462996992681706, 0.1522792987525463, 0.1482268162071705, 0.06862759497016668, 0.12678110626127037, 0.1265602024005992, 0.1140440675829138, 0.2611654959619045, 0.15483190678060055, 0.15236820041068963, 0.14308825694024563, 0.1842794037823166, 0.1201502720692328, 0.143620119829263, 0.18459181487560272], [0.054074403031596115, 0.05706253554672003, 0.027772287339238182, 0.04337647743523121, 0.07778644708118268, 0.02169856771693698, 0.01548277643243117, 0.04405741107517055, 0.03582839960498469, 0.03270050923206976, 0.05014554617394294, 0.04029736355213182, 0.032947628293186426, 0.04748753112341676, 0.043778516219130585, 0.014420019263135535, 0.013963696829575514, 0.04323188501543232, 0.032689143770507405, 0.019631176688043133, 0.025686574168503284, 0.07418506140155451, 0.005778803706302175, 0.2150484427277531, 9.279698763574872, 33.664550236293245, 33.73106186730521, 23.979614291872295, 35.4444876398359, 14.534177541732788, 0.47175847419670647, 0.23095964108194622, 0.020469406619668007, 0.09675774337457758, 0.04755070273365293, 0.16707813393856796, 0.4453736942793642, 0.9682301708630153, 0.07975302476968084, 3.528114591326032, 25.467977489743912, 44.75310741152082, 49.15311670303345, 48.873142514910015, 47.43361473083496, 44.01371833256313, 42.965808391571045, 43.63204336166382, 44.35423912320818, 45.067912919180735, 47.13231652123587, 46.43582909447806, 46.22292586735317, 42.125792026519775, 38.90835918698992, 40.63636228016445, 42.44091020311628, 44.782050132751465, 45.78386572429112, 45.28516224452427, 46.98945461000715, 45.77552441188267, 40.43828650883266, 35.7231034551348, 34.128290380750386, 34.395267963409424, 33.29334967476981, 34.3535509790693, 34.525532790592735, 35.244341305324006, 33.08420889718192, 34.22292137145996, 33.09458603177752, 32.28055592945644, 33.180431025368826, 32.11320856639317, 32.15948009490967, 32.68933234895979, 33.4901191847665, 33.4930374281747, 38.698099749428884, 44.59852041516985, 45.61298867634365, 42.827945709228516, 45.722773688180105, 44.13246999468122, 44.90147229603359, 43.73950072697231, 45.567578724452424, 42.564035756247385, 36.72533941268921, 47.346835204533164, 45.538663796016145, 45.01830278124128, 44.90334830965315, 46.228435788835796, 43.290560245513916, 50.93416234425136, 45.75685807636806, 45.57694837025234, 46.58348873683384, 45.36757482801165, 33.87626184735979, 31.49006632396153, 31.07295206614903, 32.52864136014666, 32.06418555123465, 32.87965740476336, 32.2890431540353, 32.07705708912441, 32.056445258004324, 32.50914471490042, 34.16567863736834, 32.650005544934956, 31.85118852342878, 31.210839067186626, 32.71926171439034, 35.448576654706685, 39.74312618800572, 41.140221323285786, 42.01391560690743, 41.75142308643886, 41.30820792061942, 41.0505895614624, 38.88653836931501, 36.30158267702375, 33.96630007880074, 34.074556486947195, 35.48482540675572, 38.44064814703805, 39.76107685906546, 43.69735990251814, 42.16820730481829, 39.33544410978045, 40.127239976610454, 40.58033548082624, 43.06017535073416, 42.554155417851035, 43.49196767807007, 35.28863607134138, 20.81529348237174, 3.5455997330801825, 0.21855212615004607, 2.961666826690946, 14.307618498802185, 4.479877531528473, 2.364034026861191, 0.46543485351971214, 0.09637501569730894, 0.03138724202290177, 0.045717759124402485, 0.0501610269503934, 11.781207459313528, 30.727084636688232, 29.725744996752056, 35.93635409218924, 24.8742504460471, 1.486686185002327, 0.14131899044982024, 0.07524991354772023, 0.03160811195682202, 0.08274149655231408, 0.028829046258968965, 0.06070656715227025, 0.041578149289957116, 0.02615487528964877, 0.03890952195173927, 0.08677917346358299, 0.007245904134054269, 0.018172445141577294, 0.017884189894955074, 0.029268814982580285, 0.01788531456674848, 0.07015533013535397, 0.0294006916561297, 0.06663093782429184, 0.0336337662967188, 0.03985833103901573, 0.020526639352153455, 0.07313496060669422, 0.015530681004747748, 0.01529992651194334, 0.025722706158246313, 0.010264276410453022, 0.055130953301808665, 0.02863053066123809, 0.04552736898351993, 0.03399851618866835, 0.015433893073350191, 0.019549063772761395, 0.0769346888576235, 0.03945836517959833, 0.02479065688593047, 0.044941599879946025, 0.03365504854757871, 0.0383624938050551, 0.02378940043438758, 0.050148731895855496, 0.030898259154387882, 0.5365043942417417, 13.207255738122122, 40.24949353081839, 35.13627597263881, 27.50424783570426, 38.328316620418, 17.043458666120255, 1.2086722574063709, 0.3859838311161314, 0.07831453053014618, 0.08903281896242074, 0.13312299310096673, 0.24207347471799168, 0.7178244761058262, 2.2214413583278656, 0.44172146597078865, 3.7160568492753163, 28.834801810128347, 46.79771906988961, 50.49681840624128, 48.29645592825753, 47.731810569763184, 47.12869650976998, 44.577616759708945, 45.09409373147147, 44.83565548488072, 47.251429489680696, 48.18348169326782, 48.350592817579, 47.67838587079729, 44.17885269437517, 40.703047616141184, 42.37171309334891, 43.53303153174264, 46.15630306516375, 47.55857808249337, 45.64517273221697, 47.83782270976475, 47.534641538347515, 42.940461363111226, 36.86562006814139, 35.2735515322004, 36.02751793180193, 36.379437242235454, 35.2916932787214, 35.57925142560686, 36.84134306226458, 36.53970439093453, 36.25478655951363, 36.00719445092337, 34.07461902073452, 34.0364282471793, 33.33583096095494, 34.486549922398154, 35.29948568344116, 34.51265777860369, 35.417438302721294, 41.00684717723301, 47.18567173821585, 47.60739265169416, 44.79646417072841, 46.69208213261196, 45.55572509765625, 47.127605642591206, 43.81816128322056, 48.32950850895473, 44.66325330734253, 40.17227472577776, 48.84061452320644, 47.131454944610596, 47.28582654680525, 45.97383989606585, 47.82373523712158, 44.377275875636506, 50.87913261141096, 48.17353534698486, 46.753483363560264, 46.803788321358816, 46.74747664587838, 36.703949383326936, 33.89636298588344, 33.043106828417095, 33.83942597252982, 34.108154501233784, 34.49919216973441, 33.0577848979405, 33.05053097861153, 34.172091824667795, 33.576064927237375, 35.064296109335764, 34.41566440037319, 33.51838098253523, 32.03845637185233, 33.75672156470162, 37.498844146728516, 40.65027257374355, 42.2284551348005, 44.10712991441999, 44.130868434906006, 42.263859680720735, 42.282202925000874, 39.001009941101074, 37.34720318658011, 34.95290953772408, 35.98812511989048, 36.951670033591135, 39.97296564919608, 42.64743150983538, 44.402435302734375, 43.14001710074288, 41.62268686294556, 41.09408875874111, 42.35148341315133, 45.68960646220616, 43.922703879220144, 44.8435104233878, 36.675315856933594, 21.84199752126421, 5.91885597365243, 0.9436821852411542, 4.224521245275225, 10.987197722707476, 5.69868015391486, 6.214621680123465, 2.583544339452471, 0.5052245269928659, 0.10849147303295986, 0.10950833239725657, 0.076622080989182, 13.538867201123919, 36.85096979141235, 34.23238481794085, 38.54472173963274, 32.32504524503435, 2.385876557656697, 0.2096688271101032, 0.04288023763469287, 0.04594544494258506, 0.03550957974844745, 0.02124413245889757, 0.020313582748972943, 0.006173702605467821, 0.02765923153076853, 0.022714614535548856, 0.009047971007281115, 0.07634960168174335, 0.018272681727207134, 0.004474004614166915, 0.01920606262449707, 0.05145257764628955, 0.03337959725675838, 0.029615488701633046, 0.11707812334809985, 0.17209329482700142, 0.14525058519627365, 0.10453104733356408, 0.13528485995318207, 0.11614669832800116, 0.09881919382938317, 0.09101019214306559, 0.12091393609132085, 0.16597233898937702, 0.12184647390885012, 0.16456854503069604, 0.1633358776037182, 0.09431556013545819, 0.17320155964366027, 0.10531031087573085, 0.13447388846959385, 0.15193795492606504, 0.09632420020976237, 0.11447919851967267, 0.12551023731274263, 0.1287460486803736, 0.12723284773528576, 0.06215276276426656, 0.47996733656951357, 15.632432392665319, 46.12569972446987, 43.81384992599487, 32.086656025477815, 46.14510604313442, 22.335243191037858, 1.78464589374406, 1.3938341502632414, 0.1922362989612988, 0.4820292145013809, 0.44004534876772333, 0.3869132341018745, 2.1020739121096472, 3.6386180903230394, 0.8780688803110803, 5.053515161786761, 28.250196014131816, 46.8516822542463, 51.21444225311279, 51.60489279883248, 49.82189818790981, 48.29419428961617, 46.40854351861136, 46.928452900477815, 47.559380599430625, 48.48298379353115, 50.963782514844624, 51.3936710357666, 49.67042745862688, 45.47771072387695, 43.4538185937064, 45.33996616091047, 46.3311892236982, 48.773835386548726, 49.179686614445274, 46.87369762148176, 50.829084736960276, 49.91696344103132, 44.192325251443044, 38.62724549429757, 37.29403209686279, 37.39176893234253, 37.969244139535085, 37.96544347490583, 37.25666468484061, 39.08872400011335, 38.08676249640328, 38.308305808476035, 37.26972729819161, 34.83723245348249, 36.045743056706016, 33.8870975630624, 36.52710383278983, 36.7229631287711, 36.48603303091866, 37.549934250967844, 42.295810971941265, 49.354416438511436, 50.03729234422956, 46.52235153743199, 49.021663733891074, 46.88238286972046, 48.4823271887643, 46.62997565950666, 48.53115218026297, 47.553102902003694, 42.46924843106951, 49.104388986315044, 49.37574045998709, 49.0766726221357, 48.88504825319563, 50.24349055971418, 46.45553765978132, 51.50069066456386, 48.67281552723476, 47.962362221309114, 49.0181896345956, 48.90636532647269, 38.49710920878819, 35.14809833254133, 34.00951787403652, 36.52842051642281, 35.698809078761506, 37.19506890433175, 34.04292828696114, 34.05944415501186, 35.10799333027431, 34.59123843056815, 36.645191941942485, 36.23048870904105, 34.78536762510027, 33.29494776044573, 35.893018177577424, 38.8747090612139, 43.386421067374094, 45.36193983895438, 45.890725544520784, 46.06152616228376, 44.96327999659947, 44.468679428100586, 42.486497334071565, 40.72306537628174, 36.668756757463726, 38.02895695822579, 39.47410236086164, 40.92985071454729, 43.77533606120518, 46.41947650909424, 44.868548257010325, 43.38734517778669, 42.757706369672505, 42.18429238455636, 46.13285984311785, 45.71784046718052, 44.509204796382356, 38.59041656766619, 21.873156717845372, 5.319521733692714, 0.7172917989747865, 6.373244711330958, 22.370890923908778, 12.959397860935756, 9.954399245125906, 3.4772731023175374, 0.4957584749375071, 0.160748705001814, 0.2781125594462667, 0.31460683260645184, 19.243030786514282, 40.70020580291748, 37.87939350945609, 46.2446494102478, 36.43675293241228, 3.2292988428047726, 0.3953404761850834, 0.12665398951087678, 0.12286103303943362, 0.15750578258718761, 0.0931514993842159, 0.23199307705674851, 0.15108940617314406, 0.06917532879327025, 0.20366979044462952, 0.28929492511919563, 0.11317202116229705, 0.10722782369703054, 0.10888517940683023, 0.11891113141817705, 0.11622481127934796, 0.2710843208645071, 0.09771754472915616, 0.1341620609164238], [0.007232793141156435, 0.052509779310120006, 0.028155849614579762, 0.05168443645483681, 0.03759235655888915, 0.025677486888266036, 0.057101829509649954, 0.04960255191794463, 0.03297404366146241, 0.05176372666444097, 0.010161157747331475, 0.11985094313110624, 0.0045651776682851565, 0.021040100371465087, 0.05786762413169656, 0.04662741334842784, 0.0667660002197538, 0.05209500781659569, 0.03266323730349541, 0.010559365352881806, 0.020877051799158965, 0.02930029561477048, 0.051454402905489714, 0.043300440801041465, 1.9008560350963046, 22.08173816544669, 34.25648464475359, 25.47797073636736, 30.991199561527797, 28.620599269866943, 2.307874777487346, 1.4549274891614914, 0.21323285943695477, 0.12573981285095215, 0.11067435411470276, 0.20431445299514703, 0.1021557744326336, 1.0304171996457236, 0.4279510591711317, 0.08931020407804421, 9.561455164636884, 29.255001068115234, 45.370736258370535, 49.059472356523784, 47.06959513255528, 45.297203472682405, 46.4025993347168, 46.005085945129395, 45.28243507657732, 47.76593664714268, 46.27935913630894, 48.08639798845564, 45.939606121608186, 41.85256453922817, 37.89556196757725, 41.61253901890346, 44.1175765310015, 47.086416721343994, 44.75148500714983, 46.05038472584316, 44.980504580906455, 43.20123073032924, 37.941812651497976, 34.78039618900844, 34.761959144047324, 33.77809074946812, 34.77750226429531, 34.71349893297468, 34.34490047182356, 33.89839880807059, 36.34751374380929, 36.37326724188668, 35.39600658416748, 34.46292952128819, 33.8316787311009, 33.20524304253714, 34.480935777936665, 33.334819998059956, 32.10728175299508, 32.327619552612305, 34.70053359440395, 35.00184917449951, 38.06988879612514, 38.00602442877633, 38.84900072642735, 38.46852779388428, 40.239960602351594, 44.174360683986116, 44.73146724700928, 42.884052412850515, 35.968743119921, 48.25788647787911, 46.785806383405415, 45.89400856835501, 45.69713136128017, 48.24055767059326, 49.25582844870431, 41.78195347104754, 42.49270902361189, 45.5491555758885, 44.35728938238961, 42.50095306124006, 34.104253087724956, 32.42429331370762, 34.03260326385498, 32.54094314575195, 32.22164910180228, 33.01779454095023, 33.41668714795794, 33.86532538277762, 34.753437178475515, 34.023250988551546, 32.2639810017177, 33.53549786976406, 31.7667818069458, 32.72253431592669, 34.188899517059326, 39.39051900591169, 40.76912151064192, 42.02436222348894, 43.02928365979876, 42.339688846043174, 43.564527715955464, 42.544698919568745, 41.61452620370047, 42.78848341533116, 39.01942266736712, 37.74130153656006, 38.15382303510393, 39.92179216657366, 40.43936347961426, 41.767657552446636, 41.11128555025373, 38.01172889981951, 40.83744314738682, 39.109735352652415, 40.99150208064488, 42.26716354915074, 36.34046132223946, 22.623636858803884, 8.192171062741961, 0.822759319628988, 0.24914242540087017, 2.7145137573991502, 11.886483958789281, 3.803323183740888, 3.440372956650598, 1.425625524350575, 0.5811006469385964, 0.04243357499529209, 0.026557977677189877, 0.4433504928435598, 19.385486228125437, 26.434195722852433, 23.636739798954554, 34.53619132723127, 13.586001174790518, 0.2683944452021803, 0.021840900615123764, 0.025522329678226794, 0.020151633403397033, 0.05050422317747559, 0.06017040913658483, 0.027030970867989317, 0.006709660877407129, 0.03112291531371219, 0.09056465926447085, 0.029146973841956685, 0.02255252100128148, 0.03312198804425342, 0.03773617544876678, 0.0460026081252311, 0.012251563835889101, 0.019139496642830114, 0.00829453590059919, 0.011231119262187608, 0.028722841957850114, 0.009778365609236062, 0.024380295870027373, 0.05451191223359533, 0.024927458027377725, 0.023107267483802776, 0.08779686742595263, 0.0949081519086446, 0.024524498132190535, 0.09326768493545906, 0.032509284493114264, 0.040157826218221865, 0.025742621161043644, 0.034805158618837595, 0.057717070781758854, 0.041420138840164454, 0.036151731719395945, 0.03203836761947189, 0.044948354696056673, 0.009517233951815536, 0.029151530204606906, 0.043043737432786396, 0.03753407718613744, 0.0870554322110755, 4.129059076309204, 28.380012682506017, 40.22148534229824, 27.43074631690979, 37.33081586020333, 30.6664685521807, 2.874169247491019, 1.7081994244030543, 0.6999694513423103, 0.3405973565365587, 0.04675759707710572, 0.1435593230915921, 0.18230901951236383, 2.305423366171973, 2.5514128293309892, 0.17936674239380018, 9.636568665504456, 31.90892457962036, 46.802363940647666, 52.37512493133545, 48.22312116622925, 48.153858048575266, 48.03778144291469, 48.420887742723735, 47.18803412573678, 47.20752034868513, 47.89595133917672, 50.15726688929966, 47.781024660382954, 44.48085962023054, 39.498216084071565, 43.101134981427876, 46.206097330365864, 48.19309800011771, 47.13742344720023, 47.536100660051616, 45.370882170540945, 44.12891946520124, 41.19623075212751, 36.91009201322283, 37.16814463479178, 34.70021745136806, 36.01932600566319, 36.31158460889544, 36.054490838732036, 36.263808795383994, 37.003857953207834, 37.741589886801584, 37.162318570273264, 36.542042459760395, 34.79721430369786, 34.70498391560146, 34.936070578438894, 36.78239801951817, 34.60117435455322, 34.47708995001656, 35.444470269339426, 37.1346230506897, 40.412355831691194, 41.2202194077628, 40.97583736692156, 41.84866312571934, 42.661046504974365, 46.68754495893206, 46.082871028355186, 45.775083201272146, 39.08590303148542, 47.13596779959542, 47.97794008255005, 46.907264368874685, 47.83785397665841, 48.55953904560634, 50.907331875392366, 45.59466975075858, 43.015835421425955, 48.18574333190918, 45.33777747835432, 43.8634044783456, 35.60697821208409, 33.02102892739432, 34.29436274937221, 33.97473866598946, 32.55951568058559, 34.014760289873394, 34.5964287349156, 33.629263809749055, 35.1759432383946, 36.21614762714931, 34.41905164718628, 35.022415842328755, 32.93784161976406, 34.34023128237043, 34.888128008161274, 39.93849911008562, 42.377782344818115, 44.25897584642683, 44.49984209878104, 43.1108763558524, 44.28146021706717, 45.12760489327567, 43.530106340135845, 43.15253775460379, 40.412477425166536, 39.03944042750767, 40.1932304927281, 40.66509655543736, 42.22389016832624, 43.702564103262766, 41.45515884671892, 40.0212208884103, 41.429999419621055, 39.62618453162057, 41.66255562646048, 42.465899399348665, 38.43405778067452, 25.892121587480815, 11.089952026094709, 1.934667055095945, 1.1171830466815402, 7.431860089302063, 10.056298920086451, 6.742765545845032, 7.337220413344247, 5.226952186652592, 1.3977475059883935, 0.08646718306200844, 0.009289425149160837, 0.5074049585631916, 23.323539325169154, 30.123706545148575, 27.829512119293213, 41.68358782359532, 18.19712540081569, 0.37901267090014046, 0.045756900416953225, 0.03161359112709761, 0.0208321022468486, 0.037352884587432654, 0.05533009993710688, 0.037187491676637104, 0.02071003888600639, 0.0348626882103937, 0.013598795115415539, 0.06724530378622667, 0.03729916497000626, 0.02283245910491262, 0.06299712495612246, 0.00769446836784482, 0.019319661260981644, 0.02513444174214133, 0.01749672265058117, 0.10789877269417048, 0.12559487777096884, 0.19906902446278504, 0.09385924533541713, 0.2977117449045181, 0.09260048823697226, 0.1355173396212714, 0.2056582915995802, 0.1687671025948865, 0.07882398819284779, 0.16248641961387225, 0.12440993849720274, 0.1413131279072591, 0.11916791621063437, 0.13434151985815593, 0.11542527989617415, 0.16469938015299185, 0.1346655881830624, 0.09402416327169963, 0.09584824860628162, 0.11186142398842744, 0.12878191604145936, 0.16197274146335466, 0.11999317764171533, 0.20366229941802366, 3.7608193159103394, 32.3138621194022, 46.016380241939, 35.566921847207205, 41.31925903047834, 39.830676964351106, 5.976403559957232, 3.377085506916046, 2.2856401077338626, 0.8510419077106884, 0.26291123085788315, 0.6665891110897064, 1.3344483311687196, 3.741503323827471, 1.1079372742346354, 0.23701266199350357, 11.774278368268694, 32.24855252674648, 48.39295251028878, 52.020391600472585, 50.12109456743513, 49.982874052865164, 50.670929840632844, 49.7498905318124, 48.285279750823975, 49.958916664123535, 50.262716225215364, 52.00952114377703, 49.01807498931885, 45.432675974709646, 40.757921014513286, 45.22214208330427, 48.74746697289603, 51.4627673966544, 47.95112351008824, 49.314575467790874, 46.73008183070591, 46.21841648646763, 41.41854184014456, 39.24511405399868, 37.795441899980815, 36.378606932503835, 38.51861735752651, 38.14423452104841, 36.1163124356951, 38.20444066183907, 39.712064266204834, 40.17129502977644, 38.88471794128418, 39.70667593819754, 37.621066434042795, 36.406278133392334, 36.68315689904349, 37.08822645459856, 36.60825531823294, 36.17831121172224, 37.86166865485055, 38.23252180644444, 41.177494934626985, 41.507982526506694, 41.816955021449495, 42.9952826499939, 44.621265343257356, 49.94017389842442, 47.09000546591622, 47.978117261614116, 42.416094711848665, 48.82993514197213, 50.051897457667756, 46.99038219451904, 48.964167390550884, 51.23796885354178, 50.553408009665354, 45.854719979422434, 46.06031370162964, 48.249253341129844, 47.103422437395366, 45.571963037763325, 37.10688931601388, 34.71596901757376, 36.49086897713797, 35.536137853349956, 34.62082733426775, 35.399501528058735, 36.08686944416591, 34.97854144232613, 38.15256541115897, 38.778886454445974, 36.43179191861834, 36.59104463032314, 35.52950579779488, 35.458960737500874, 36.932982853480745, 42.22968149185181, 44.89456231253487, 46.493770122528076, 46.324039527348106, 44.09334121431623, 46.34580128533499, 46.928265299115864, 44.88576936721802, 44.61518219539097, 42.249824319567, 41.65852567127773, 40.974947997501914, 42.19486059461321, 43.637476852961946, 44.96200500215803, 43.47212362289429, 41.30567530223301, 43.291022300720215, 41.008222920554026, 42.185886996132986, 42.5451158114842, 38.63491630554199, 25.65839808327811, 9.968089801924569, 1.6955211332866122, 1.8383168194975172, 6.534386898790087, 20.52062385422843, 11.469790066991534, 10.183473535946437, 4.994192310741969, 1.7834926013435637, 0.2001017683318683, 0.11286569652812821, 1.536109590104648, 27.994856664112636, 36.18745156696865, 32.762663636888774, 46.06184230531965, 21.610382795333862, 0.7612240101609911, 0.20984265421118053, 0.1718472715999399, 0.10757387655654124, 0.16271934711507388, 0.25294466423136847, 0.0997415604069829, 0.08729710602866751, 0.13520300148853234, 0.1420694501804454, 0.17639146133192948, 0.08773740740226847, 0.13065408915281296, 0.11982720797615391, 0.105189551998462, 0.07041478835578475, 0.08578531643641846, 0.13084725450192178, 0.2718779897051198], [0.024380066864458576, 0.016699053846033554, 0.061861901943172724, 0.050506604835391045, 0.018305804414142455, 0.06902799169932093, 0.016142276847468953, 0.00996617307620389, 0.06449540491615023, 0.03881645069590636, 0.011721961316652596, 0.026883248705416918, 0.037653597736997266, 0.02423533534498087, 0.04955664902393307, 0.053775925654917955, 0.03056027407624892, 0.02728655974247626, 0.04743563337251544, 0.1181418491261346, 0.02952997971858297, 0.011347113127288009, 0.025313698819705417, 0.026303735694714954, 0.11682129784354142, 7.99858295917511, 30.79262351989746, 24.53540243421282, 24.669917821884155, 37.27537270954677, 9.525298476219177, 0.42679725108402117, 1.033626833132335, 0.07735943142324686, 0.08861333504319191, 0.04825619255591716, 0.254402401724032, 1.7934457872595106, 2.1789049208164215, 0.6529873066714832, 0.45275656240327017, 9.318780643599373, 28.08964572634016, 45.34127589634487, 50.86624370302473, 47.95226648875645, 48.438810620989116, 45.61445822034563, 44.12815863745553, 47.09615462166922, 47.74719040734427, 47.150371415274485, 44.6542067527771, 41.64603281021118, 39.77821111679077, 43.90092127663748, 45.57906757082258, 45.3021297454834, 46.39577272960118, 44.40087195805141, 44.270266669137136, 41.318189007895334, 37.91516630990164, 35.11963503701346, 34.15605885641915, 33.80759627478463, 34.85383169991629, 35.20997551509312, 35.0148457799639, 34.587934562138145, 38.0098111970084, 40.2278151512146, 38.25631938661848, 36.23299700873238, 33.92815794263567, 32.34830086571829, 33.13503496987479, 32.34923192432949, 32.757921491350444, 31.544849395751953, 33.11136940547398, 34.04501622063773, 34.29310165132795, 33.07790688105992, 35.987353869846885, 36.637885911124094, 42.1103253364563, 43.971626145499094, 45.607739312308176, 43.15780448913574, 37.975674697331016, 44.405683585575645, 45.85043641499111, 46.27771241324288, 47.03374590192522, 49.6900908606393, 40.32405117579869, 42.02325051171439, 48.786533219473704, 43.97116756439209, 43.687291962759836, 38.648708479745046, 31.10969761439732, 32.32418714250837, 33.606685638427734, 31.50078739438738, 32.106750215802876, 33.37745761871338, 33.52783053261893, 36.163619245801655, 35.87540102005005, 34.001537867954795, 32.8015318598066, 33.11240816116333, 32.65245131083897, 31.792688165392192, 36.038676738739014, 40.02454907553536, 42.65742996760777, 43.80004732949393, 42.762233121054514, 41.774859360286165, 42.57546206883022, 42.763845103127615, 42.326647077287944, 43.01022822516305, 42.13281318119594, 41.19634192330496, 39.81356702532087, 40.693907260894775, 41.216835635049, 43.23886217389788, 41.33064365386963, 39.88920858928135, 40.45018182482038, 40.786992277417866, 41.26561198915754, 38.54938745498657, 24.683015176228114, 10.360483237675258, 1.9153197961194175, 0.796764643064567, 1.6858048375163759, 9.372935771942139, 5.356066218444279, 5.522215451513018, 6.083085766860417, 5.698604157992771, 0.7266181270991052, 0.06404782286179916, 0.05176321776317699, 1.512990979211671, 28.75459180559431, 25.890660728727067, 27.849243266241892, 26.912033762250626, 3.1650848942143575, 0.04684688210753458, 0.0499295922262328, 0.02874839897932751, 0.007403604154075895, 0.007411406458621579, 0.05440035429117935, 0.03701201234278934, 0.010603032474006926, 0.04386938902150307, 0.008618415932038, 0.028641648457518647, 0.05824642987655742, 0.013132585578465035, 0.03688077009948237, 0.010135040086294924, 0.03119408685181822, 0.04736712169168251, 0.012454595932337855, 0.0646452254482678, 0.04935139896614211, 0.0622649449588997, 0.027504506886803677, 0.01979953479687018, 0.031616898985313516, 0.046129585775945864, 0.006806272389699838, 0.0437918630029474, 0.02969030397278922, 0.06920433616531746, 0.04786073895437377, 0.015174501010083725, 0.11283248223896537, 0.03263346318687711, 0.052067493221589496, 0.033899182054613314, 0.05603983738858785, 0.019278694709230746, 0.013374456171212452, 0.03912656834082944, 0.07614106072911195, 0.04362519783899188, 0.031231094151735306, 0.03367144873897944, 0.285222873623882, 12.064905881881714, 37.76042645318167, 28.88603261538914, 30.423222541809082, 42.024921553475515, 9.314414569309779, 1.1523569992610385, 1.1829911725861686, 0.19105298817157745, 0.1360139051186187, 0.03883915447763034, 0.4555686286517552, 2.5253549133028304, 3.7285570928028653, 1.8125018732888358, 0.8881231408034052, 12.106335384505135, 30.899379117148264, 45.88224526814052, 50.497874532427105, 48.41788959503174, 48.80180188587734, 47.347061020987375, 45.73356771469116, 47.84926291874477, 48.924055440085276, 48.96247550419399, 46.857244287218364, 43.28509201322283, 40.78734316144671, 45.07794611794608, 46.61259126663208, 46.835121222904746, 48.10787834439959, 46.17676551001412, 46.34588466371809, 42.868773324149, 39.27532829557146, 37.19881050927298, 35.4602496283395, 35.5663104057312, 35.794961724962505, 35.69436917986189, 36.24485410962786, 36.45166029248919, 38.648037978581016, 40.13503238133022, 39.64884260722569, 36.76759488242013, 35.80902835300991, 34.115373679569785, 35.398170948028564, 33.946581091199604, 34.31917476654053, 33.594748633248464, 35.45755025318691, 35.24677317483084, 35.8582945551191, 35.914713927677695, 37.478093351636616, 38.77519001279558, 43.25169549669538, 45.352000440870015, 47.82906450544085, 45.68913745880127, 39.18816314424787, 44.97950056621006, 47.36957665852138, 46.411677156175884, 47.84865147726876, 49.07195479529244, 44.19501420429775, 41.7515481540135, 50.65106841496059, 46.10738774708339, 45.035367556980674, 40.258501870291575, 32.87558576038906, 33.73435183933803, 35.22895451954433, 33.60743604387556, 33.73456028529576, 33.535091400146484, 34.82980482918875, 37.8246625491551, 36.713683809552876, 35.47141885757446, 33.19376809256417, 34.4671505519322, 34.62454114641462, 33.43143817356655, 36.57951062066214, 42.10603134972708, 43.55563402175903, 45.40456008911133, 44.22962318147932, 43.181334563664024, 44.55804715837751, 43.14795194353376, 43.06297547476632, 44.45665904453823, 43.47829362324306, 42.71361657551357, 41.44022716794695, 42.38361188343593, 41.756397996629985, 43.988423415592735, 42.04221909386771, 40.54771716254098, 41.53135279246739, 42.112319469451904, 41.92462778091431, 39.40135472161429, 27.18011784553528, 12.713548013142177, 3.7537907787731717, 2.450643105166299, 3.3690462240151, 8.945037041391645, 8.217049956321716, 6.381500908306666, 7.5894791058131625, 4.825496128627232, 1.9304484128952026, 0.19679070743066923, 0.06072564755699464, 1.8643178471497126, 31.718033245631627, 29.215476240430558, 30.839628083365305, 33.55861105237688, 5.075507513114384, 0.012503318987520677, 0.020154093092839633, 0.01027015591638961, 0.05803790927997657, 0.04406316505212869, 0.05146816359566791, 0.007025647002072739, 0.02138799545355141, 0.042938130242483954, 0.004543883118978036, 0.02833159188074725, 0.05583741342914956, 0.017280278461320058, 0.07164776112352099, 0.06767005313720022, 0.029021804487066608, 0.01771735000823225, 0.02096829440311662, 0.03581075430182474, 0.09850938152521849, 0.1823402592646224, 0.17210079942430767, 0.0941299061690058, 0.08011874835938215, 0.12187886717064039, 0.07483124387051378, 0.07953819379742656, 0.15984116441437177, 0.16295198963156768, 0.08971416990139655, 0.12657119466790132, 0.1623884934399809, 0.10512455512902566, 0.11628714150616101, 0.11266513514731612, 0.15135575830936432, 0.10676488639520747, 0.18773834460547992, 0.19672934072358267, 0.17351820479546273, 0.10601728329701082, 0.12667636759579182, 0.13763160045657838, 0.2798633969255856, 12.266683306012835, 44.30627918243408, 36.08063691002982, 34.92608949116298, 48.3804110118321, 14.564496006284442, 1.2423890424626214, 2.9098690918513705, 0.5555421326841626, 0.5229321196675301, 0.14474133109407766, 0.6698416279894965, 8.709012814930507, 5.5158400450434, 1.2364313964332854, 0.8098689998899187, 11.078404988561358, 30.174240793500626, 47.780639035361155, 51.98390660967146, 50.83068629673549, 50.146198408944265, 49.001211711338584, 46.63036823272705, 49.61780180249895, 51.829910210200715, 52.168037346431184, 49.449311460767476, 45.48010090419224, 43.97724723815918, 47.603717054639546, 48.81254032679966, 48.537259646824424, 48.80733265195574, 46.72248050144741, 48.60150963919503, 45.60896566935948, 41.79216384887695, 39.55540670667376, 37.089894022260395, 37.05450684683663, 37.32388503210885, 38.4536760193961, 37.85060364859444, 37.452159200395855, 41.276753425598145, 44.2440858568464, 42.38845477785383, 38.954995495932444, 37.87241056987217, 36.42209223338536, 37.063445704323904, 35.26566880089896, 36.00178180422102, 34.57736982618059, 36.76842519215175, 37.720623697553364, 37.05004262924194, 36.879481724330354, 40.43798426219395, 40.69396979468209, 44.987640380859375, 46.98778704234532, 49.943276269095286, 47.124868052346365, 42.13320575441633, 45.5577574457441, 49.085524627140586, 47.15711464200701, 48.604087420872276, 50.09241587775094, 45.62903554098946, 44.83341121673584, 53.022273199898855, 46.99736513410296, 46.62146759033203, 41.1628029687064, 34.93467746462141, 35.99093566622053, 37.52126250948225, 34.53625386101859, 35.32778222220284, 34.97324691499983, 35.9300868170602, 39.91967644010271, 38.95183753967285, 36.861906255994526, 35.70118536267962, 35.32750082015991, 35.408134664808, 35.081857681274414, 38.60882929393223, 42.274691922324045, 45.4837452343532, 47.30157116481236, 45.87859746388027, 44.21704346793038, 46.864105633326936, 44.59822859082903, 44.451270716530935, 45.88184922082083, 44.8635698727199, 45.802146434783936, 42.33552687508719, 44.10914836611067, 44.415015016283306, 45.00100176674979, 43.97529479435512, 42.098933764866416, 43.84429693222046, 44.85893889835903, 42.527043546949116, 38.88495070593697, 27.125510215759277, 12.190633535385132, 3.1693738869258334, 2.9697074123791287, 6.287322853292737, 19.249428340366908, 11.182479449680873, 13.030698537826538, 12.169289537838527, 12.369429792676653, 3.760669929640634, 0.30256669010434833, 0.19880679781947816, 2.920338507209505, 39.17073358808245, 35.12803193501064, 37.683037417275564, 38.087221077510286, 5.746093792574746, 0.1458223323736872, 0.16522007435560226, 0.11242132394441537, 0.1327840784298522, 0.13074432073959283, 0.23363255336880684, 0.09684473156396832, 0.1900480506675584, 0.1738188908036266, 0.0698533006278532, 0.08655216957309417, 0.14129179476627282, 0.20165566780737468, 0.19883026156042302, 0.12466949171253613, 0.18479366547295026, 0.08086342697164842, 0.07241675843085561, 0.11457366416496889], [0.0561297263151833, 0.04660099458747676, 0.05387411306479147, 0.0031870117652163443, 0.03539009312433856, 0.008548127337624984, 0.10047396432076182, 0.026545251752915125, 0.029480887709983757, 0.02009182732685336, 0.03747231353606496, 0.017621912361521806, 0.018848013265856674, 0.061177674015717845, 0.057374851645103524, 0.09610903675534896, 0.03332808966349278, 0.039997715702546496, 0.031369583149041445, 0.027007279817813208, 0.01200068908344422, 0.044306908401527574, 0.07738901555005993, 0.04954128020576068, 0.05567846999370626, 1.3517280668020248, 20.978015082223074, 32.00201654434204, 22.662717001778738, 32.2886575290135, 18.85310309273856, 0.22881851025990077, 0.1298898144492081, 0.2709479353257588, 0.16435488792402403, 0.0841887371082391, 0.07433359271713666, 1.0714883272136961, 5.81138471194676, 1.3293174122061049, 0.2986166663467884, 1.4620361477136612, 11.32323692526136, 26.90164794240679, 44.77922569002424, 50.09822109767369, 45.0956848689488, 50.70902681350708, 46.36087540217808, 45.76508821759905, 44.72218445369175, 43.51840557370867, 40.11504588808332, 40.073328903743196, 41.803996631077354, 43.17693635395595, 46.599886485508506, 45.1102100781032, 45.626054763793945, 46.05692645481655, 45.62088530404227, 43.672996044158936, 46.287957532065256, 42.70085620880127, 36.13818189076015, 32.90703330721174, 36.43328578131539, 34.7250120980399, 35.23684072494507, 35.878117765699116, 40.49295493534633, 41.20436709267752, 41.55510868344988, 38.65011548995972, 34.69962338038853, 34.562448569706504, 33.66622475215367, 32.87445667811802, 33.12408460889544, 33.006628785814556, 33.76973901476179, 34.254549571446006, 34.1347348349435, 33.94793598992484, 35.53814935684204, 41.79544339861189, 43.96058545793806, 43.1214028767177, 46.86910833631243, 43.25118480409895, 36.84127705437796, 43.86476285117013, 42.53008338383266, 44.72949743270874, 45.61446169444493, 41.75487286703927, 44.203362464904785, 46.36423485619681, 43.201925550188335, 43.51273584365845, 40.0983042035784, 33.91352503640311, 31.22083405085972, 31.61402566092355, 32.10845252445766, 31.601251397814067, 32.665395804813926, 32.78380700520107, 36.57314954485212, 42.44675363813128, 41.265876020704, 41.11574281964983, 35.42895494188581, 32.48621218545096, 32.16311052867344, 32.69778135844639, 35.47393757956368, 42.90076283046177, 45.646746499197825, 42.50710916519165, 41.007920673915315, 42.29546703611101, 43.302195004054475, 43.89658212661743, 43.2325427872794, 44.176674434116904, 43.118481159210205, 43.167545863560264, 41.64257608141218, 42.995769023895264, 42.32758160999843, 41.387295791081016, 41.19289561680385, 43.66083322252546, 38.51423304421561, 42.10639265605381, 39.00711045946394, 28.06946815763201, 11.335314631462097, 3.126351509775434, 0.7484202172074998, 1.5325385417257036, 1.3772054825510298, 7.831518735204424, 8.025014775139944, 3.4335752299853732, 5.52043627841132, 4.624761368547167, 1.54245459820543, 0.2060376876699073, 0.06692233468805041, 6.30737144606454, 31.847405229296, 22.633261850902013, 35.84357132230486, 17.84407353401184, 0.192978100585086, 0.10113271325826645, 0.03645953555990543, 0.008225288009271026, 0.013522530323825777, 0.04223359376192093, 0.040908601467630694, 0.035941083915531635, 0.06316680620823588, 0.03111805361030357, 0.036797106731683016, 0.036309830378741026, 0.02235650071608169, 0.03250490454956889, 0.017456241251368607, 0.048747512977570295, 0.054997400646763187, 0.02647306919763131, 0.023624518121193563, 0.05627325004232781, 0.019411231258085797, 0.06631895420806748, 0.0563072921442134, 0.018435357105252997, 0.055332247500440905, 0.03452488972938486, 0.03316896302359445, 0.050303366633930376, 0.0175637788737991, 0.06795364684824433, 0.01004691280624164, 0.034353742841631174, 0.018161273062495247, 0.0076905905402132445, 0.04624793924657362, 0.03305234320993934, 0.023202435412843312, 0.037986005257282934, 0.006939039640461228, 0.13531710393726826, 0.016550064519313828, 0.050457967445254326, 0.03692602838522621, 0.07121543253638915, 0.06594495927648884, 2.5284972361155917, 26.807199341910227, 35.68027823311942, 26.1284749848502, 40.1098382132394, 21.92652062007359, 0.2621192719255175, 0.23520670032926969, 0.2373944872191974, 0.2734672815671989, 0.1393048678125654, 0.8569312116929463, 4.524480189595904, 7.3292873076030185, 3.7989479899406433, 0.7234160932047027, 1.6342465983969825, 14.462729215621948, 31.69234922954014, 46.49999918256487, 48.886931215013774, 46.45743451799665, 50.492969104221885, 47.36752693993704, 46.93029069900513, 48.39922325951712, 45.46464811052595, 42.89235898426601, 40.955364499773296, 44.24675049100603, 46.3605523109436, 47.70069306237357, 47.30276625497, 48.16440541403634, 47.53852558135986, 46.86233384268624, 46.64844397136143, 46.93423727580479, 43.48044409070696, 37.097137519291465, 36.1608920778547, 37.64236266272408, 35.93273408072335, 36.68830551419939, 37.67271934236799, 42.12653200966971, 42.78496067864554, 41.885985374450684, 41.3622544833592, 36.22817495891026, 35.46171222414289, 34.945537499019075, 34.05805451529366, 33.993752411433626, 34.42377642222813, 34.09024204526629, 34.5451614516122, 35.807284355163574, 36.642079148973735, 36.9235645702907, 43.09768867492676, 45.96397692816598, 44.68255540302822, 48.85064424787249, 44.35569477081299, 37.86074801853725, 44.797898973737446, 43.01259061268398, 45.1429499898638, 46.642531054360525, 44.249581881931846, 44.02109384536743, 48.62802743911743, 43.72048350742885, 46.41596072060721, 42.83918442044939, 36.0037967818124, 33.52038206372942, 33.853787899017334, 32.4744245665414, 33.22424636568342, 33.32900435583932, 33.90256772722517, 38.41443954195295, 42.0154789515904, 42.03421824319022, 42.00773171016148, 35.66896309171404, 33.724346433367046, 33.85692501068115, 33.762085574013845, 37.848015444619314, 44.371300424848286, 46.07493618556431, 43.79134818485805, 42.41716126033238, 44.439660276685444, 44.403043270111084, 45.57209505353655, 43.46347311564854, 45.971797125680105, 44.58612830298287, 44.33606263569423, 41.287867069244385, 43.39769104548863, 43.53783621106829, 43.56304080145699, 41.80600813456944, 43.61226878847395, 40.90703630447388, 42.33435957772391, 40.20724500928606, 31.111993994031632, 14.086241943495613, 5.3359841874667575, 2.359728966440473, 3.1998604110309055, 3.9690946085112433, 8.308688879013062, 6.110972796167646, 7.1419074194771905, 7.974988613809858, 7.355082494871957, 1.2193971276283264, 0.06787668740642921, 0.05899935268930026, 6.109814618315015, 38.56916550227574, 26.878241198403494, 37.22260114124843, 24.96213821002415, 0.6085162301148687, 0.10221662545310599, 0.03654893933396254, 0.02423926575907639, 0.04697716761646526, 0.018601163922409927, 0.058578219929976125, 0.04356667080095836, 0.0280017577045198, 0.03200503797935588, 0.053842154065413136, 0.03658148187345692, 0.023577405738511255, 0.053672957965838056, 0.0102165066969714, 0.03398673003539443, 0.049669869377144744, 0.03683176290776048, 0.02850961232823985, 0.02205675108624356, 0.13780751744551317, 0.09763752509440694, 0.13580117081957205, 0.09159544216735022, 0.1559448399181877, 0.1299955030637128, 0.24061942845582962, 0.20700979764972413, 0.0975855425266283, 0.14622498862445354, 0.12472776429993765, 0.13027200608381204, 0.10898187743233782, 0.09043741359242372, 0.1026782396116427, 0.16257617622613907, 0.18910662404128484, 0.2068858157311167, 0.11206929319139038, 0.23346718081406184, 0.069532591051289, 0.15863175716783318, 0.14622664424989903, 0.21547286638191768, 0.15068380508039678, 2.3895245790481567, 29.046202489307948, 44.96664292471749, 31.689434460231237, 41.56619800840105, 27.33506441116333, 0.8400685308235032, 0.33990305236407686, 1.5629975987332207, 0.7065911388822964, 0.3180589745087283, 0.4553779331701142, 5.737775061811719, 14.469389932496206, 3.4652831171240126, 0.7025565153786114, 2.037715571267264, 12.997556499072484, 29.67908784321376, 47.20801019668579, 49.80618483679635, 46.92013938086373, 52.10010828290667, 49.110468660082134, 48.91525207247053, 49.83289023808071, 47.65029082979475, 44.738540513174875, 44.38644749777657, 45.86082397188459, 47.21148082188198, 51.05072184971401, 49.371199812207905, 49.5688065801348, 49.380253314971924, 49.06432219914028, 48.455402919224326, 48.84927545275007, 45.82821954999651, 39.880954129355295, 36.542049407958984, 39.02659668241228, 38.750110489981516, 37.709277289254324, 39.33514881134033, 43.93181644167219, 45.32860585621425, 44.527099881853374, 41.47145584651402, 37.9656206539699, 38.520757402692524, 37.43499020167759, 36.67974533353533, 35.43198088237217, 36.28089788981846, 37.88263831819807, 38.43582609721592, 37.72448689596993, 37.170600822993684, 39.49917146137783, 45.797609261104036, 48.258345058986116, 46.55550486700875, 51.15377058301653, 45.26876449584961, 40.86892890930176, 44.4453786441258, 42.67107275554112, 45.242142472948345, 46.51669222967965, 46.733788694654194, 46.05779845373971, 49.33263036182949, 45.96642616816929, 49.31337342943464, 43.863758836473735, 36.74644456590925, 34.297117710113525, 34.71193558829171, 34.93000132696969, 33.12802076339722, 35.66078506197248, 35.13447986330305, 39.4938838822501, 44.974588189806255, 43.478905064719065, 44.685105391911094, 38.14019414356777, 36.227469716753276, 35.397434438977925, 35.36749465124947, 39.83575957162039, 45.97535807745797, 48.31873185294015, 43.90474625996181, 44.61568941388811, 47.66187347684588, 45.53412662233625, 47.21744932447161, 45.28511013303484, 47.199119976588655, 46.20798029218401, 47.43039424078805, 44.23963553564889, 45.218209402901785, 45.18164103371756, 43.120485714503694, 42.56979233877999, 45.739650862557546, 41.43130568095616, 43.59067031315395, 41.21678352355957, 31.233476298195974, 13.107126116752625, 4.535676343100412, 1.9293542887483324, 4.636128187179565, 4.717226692608424, 16.843774386814662, 17.453308582305908, 10.596790603228978, 13.438519580023629, 11.437949078423635, 4.600048797471183, 1.0732174515724182, 0.1739502823246377, 8.52511657987322, 42.346883705684114, 31.707979202270508, 45.26977545874459, 27.501492874962942, 0.6657012073057038, 0.21394219994544983, 0.1310260756207364, 0.06631533761641809, 0.1568304095417261, 0.12351298305605139, 0.154598436451384, 0.13552644556122168, 0.09465913634215083, 0.10413096951586859, 0.09582408597426754, 0.118746193125844, 0.09329214612288134, 0.11048513783940248, 0.10849821767104523, 0.18942690614078725, 0.07961845770478249, 0.10775167308747768, 0.15802026140902722, 0.19845248040344032], [0.04269969642960599, 0.03408836101048759, 0.02747813392696636, 0.03720021420823676, 0.02019358552726252, 0.05221146817452141, 0.017503248461123024, 0.01218006744914289, 0.009179211554250546, 0.06123874895274639, 0.03459715031619583, 0.006154719740152359, 0.04059673320235951, 0.023636657112677182, 0.09230733396751539, 0.14318291257534707, 0.02284602471627295, 0.05823847744613886, 0.017116507249219075, 0.029847347510180304, 0.019310735132811323, 0.024559362957786237, 0.01949251805698233, 0.00748187062397067, 0.014028048242575355, 0.020488415778215443, 5.650848320552281, 27.464683055877686, 24.488707065582275, 27.339511258261545, 33.48655823298863, 2.491463771888188, 0.09966481131102357, 0.11616016046277114, 0.10864808570061411, 0.07940442061850003, 0.18368348718753882, 1.4494096423898424, 3.1472052250589644, 4.354625829628535, 0.2005444717194353, 0.2041870919721467, 2.127886035612651, 12.196467416627065, 26.09126738139561, 43.860962186540874, 48.80565118789673, 46.550252028873985, 46.71897166115897, 43.93044417245047, 44.78275190080915, 42.49021462031773, 43.551756926945274, 44.80236666543143, 43.698937143598286, 48.619703497205464, 45.509071418217246, 44.67957809993199, 45.09473991394043, 47.34811019897461, 46.766518184116904, 47.76520708629063, 46.004794120788574, 46.973876748766216, 42.380790914808, 34.15598242623465, 35.313885825020925, 36.08427776609148, 34.83639172145298, 36.19467074530465, 42.25039407185146, 43.12236867632185, 44.53447886875698, 42.15799692698887, 38.24533428464617, 34.63962568555559, 34.07573420660836, 33.81921018872942, 33.063353879111155, 33.730408736637656, 34.000082220349995, 34.2882969720023, 33.70808070046561, 36.54232038770403, 42.43872846875872, 45.498593534742085, 44.83870226996285, 46.69547285352434, 46.858592237745015, 42.105836800166536, 36.07479000091553, 45.09247132710048, 44.408584458487375, 49.25509541375296, 41.80607066835676, 45.56863832473755, 45.364715644291465, 42.73052849088396, 43.64184726987566, 41.384422710963655, 35.617952891758506, 32.36088057926723, 31.296725749969482, 32.53310210364205, 32.32149471555437, 31.897091797419957, 33.03411585944039, 34.317277908325195, 38.63949864251273, 44.26916537966047, 45.44497081211635, 42.51413379396711, 40.664321831294465, 32.05749443599156, 32.594725676945274, 33.43371023450579, 35.574648244040354, 41.211746079581125, 44.314161913735525, 42.107045786721365, 41.903137002672466, 42.38901063374111, 43.64118719100952, 43.39563437870571, 44.41877399172102, 42.61065469469343, 41.945326464516775, 42.7954455103193, 40.66861234392439, 41.71332611356463, 43.41636780330113, 42.29250710351126, 44.157177788870676, 43.305384227207725, 41.58443702970232, 43.08716910226004, 33.80420902797154, 19.19576219149998, 4.903078845569065, 1.47057982640607, 1.2127076408692767, 3.14700785279274, 4.078373270375388, 4.837691954204014, 4.793669470718928, 5.605208209582737, 5.785706775529044, 4.713949748447963, 1.4161890021392276, 0.18384263079081262, 0.10768510880214827, 16.5976813520704, 28.48297803742545, 23.483111654009136, 31.322309017181396, 6.471120510782514, 0.020258173579350114, 0.0805568919916238, 0.03678921536941614, 0.07327509844409567, 0.07851672718035323, 0.04225771568183388, 0.02098254024583314, 0.045928050697382004, 0.007860010556344475, 0.06272539882255451, 0.024721563361319046, 0.026349204326314584, 0.04330100737778204, 0.01863224761161421, 0.019988004683649967, 0.09754297802490847, 0.017859518361677016, 0.08269103390297719, 0.02069353182534022, 0.04207894545314567, 0.03283475399283426, 0.040111919931535206, 0.021366511338523457, 0.06639894670141594, 0.006717115432755756, 0.059722691375230036, 0.018090893714023486, 0.03490398045895355, 0.03672234574332833, 0.01134186889976263, 0.04076190898194909, 0.007067727199422994, 0.022126158433301107, 0.023806413003642644, 0.08615245816430875, 0.044810836003827195, 0.09693667305899517, 0.05766326295478003, 0.037677261645772626, 0.021620027288528423, 0.039785398702536307, 0.02932780681710158, 0.05111647550282734, 0.03862324124202132, 0.057811244656997066, 0.052997652773878405, 8.947724257196699, 35.030562605176655, 25.48904095377241, 29.41554614475795, 36.029536383492605, 2.3719662640775954, 0.16040373779833317, 0.2149609795638493, 0.3419831964586462, 0.2052013932594231, 2.801447012594768, 4.446675564561572, 6.023248314857483, 4.849446134907859, 2.988756984472275, 1.3067161164113452, 2.8541332483291626, 13.213713220187596, 31.199371065412247, 45.30115352358137, 48.14049318858555, 46.91868025915963, 48.00140414919172, 46.76038987295968, 46.60157142366682, 44.1158047403608, 44.64808538981846, 46.94327688217163, 45.97889123644148, 47.89263704844883, 46.64311817714146, 44.68047441755022, 47.54675224849156, 48.70136914934431, 47.16960750307356, 47.57020936693464, 48.08713102340698, 47.74095787320818, 42.86205441611153, 35.3745470728193, 37.30308212552752, 36.75499085017613, 36.91256904602051, 38.10993473870413, 43.09540271759033, 45.22971909386771, 44.86269787379673, 42.421274593898225, 38.410360949380056, 35.348133495875764, 34.55032048906599, 34.94508934020996, 35.70517015457153, 34.1831568309239, 34.620709214891704, 36.90128864560808, 35.58548395974295, 38.61129937853132, 42.81416743142264, 46.16392523901803, 46.43684005737305, 47.326383181980674, 48.09529515675136, 42.888363770076204, 38.86467238834926, 45.700991085597444, 44.47216394969395, 48.93460280554635, 43.57813228879656, 45.484064851488384, 47.29506417683193, 44.968449456351145, 45.244508334568565, 42.07599081311907, 37.91372455869402, 34.559415681021555, 32.74333374840872, 33.63124057224819, 34.214708600725444, 33.526103905269075, 34.00279549189976, 35.50212642124721, 39.69900860105242, 46.29093483516148, 45.49326426642281, 45.139514105660574, 40.57055936540876, 33.93217052732195, 35.00529200690133, 34.23033162525722, 37.219172205243794, 44.48452132088797, 44.93359729221889, 42.69428668703352, 44.21530294418335, 42.5622535433088, 43.938500608716694, 45.615507398332866, 44.80284261703491, 44.370852266039165, 42.55905042375837, 44.600486755371094, 41.38634041377476, 42.24554770333426, 42.97333329064505, 41.66105828966413, 43.377440520695274, 44.98503828048706, 41.91681800569807, 44.49762909752982, 34.87460681370327, 20.87506536075047, 6.662735760211945, 2.343377466712679, 2.278248744351523, 4.241943853242057, 6.258255933012281, 6.819068925721305, 5.713851979800633, 6.607968756130763, 7.856601732117789, 3.7854294010571072, 0.3130261445684092, 0.041206033900380135, 0.06731015137795891, 18.75522381918771, 33.564725467136924, 23.637445041111537, 37.71207741328648, 9.809276563780648, 0.05834819655865431, 0.06258043660117046, 0.04545340866648725, 0.025467181744586145, 0.06986076451305832, 0.03380650434909122, 0.04279893556875842, 0.06944427293326173, 0.054888427922768254, 0.02153317989515407, 0.03354125143960118, 0.04290768098352211, 0.0331407732862447, 0.004661322687752545, 0.05308101080091936, 0.05419900580974562, 0.03388376234631453, 0.06003016951893057, 0.027401630799951296, 0.06403241333152566, 0.12839238265795366, 0.11593070706086499, 0.13393536236669334, 0.13398744671472482, 0.0727067846538765, 0.16771301201411656, 0.08063421784234898, 0.17209652465369019, 0.10191467736980744, 0.1491243823298386, 0.13669363435889992, 0.077416089097304, 0.12163213826715946, 0.05239759372281177, 0.12787646534187452, 0.199435826923166, 0.183400049539549, 0.11395961711449282, 0.07298041747084685, 0.12807702672268662, 0.1205323144261326, 0.07641120587608644, 0.15866434041942867, 0.1780314397599016, 0.1031320777588657, 0.1105334156059793, 9.206381372043065, 41.553826740809846, 33.60892295837402, 35.121861934661865, 44.82980162756783, 4.754482499190739, 0.23299033354435647, 0.41471110390765326, 0.6454322806426457, 0.17173679252820356, 2.929857756410326, 6.95785528421402, 8.220419832638331, 8.880515200751168, 1.6360309826476234, 0.48111796911273685, 2.752728198255811, 14.167871117591858, 30.63352366856166, 45.04014444351196, 48.00328016281128, 48.34072290148054, 48.98178454807827, 47.88626555034092, 49.52523095267159, 45.81991992677961, 46.984149660382954, 49.89758838926043, 47.82680981499808, 51.50020776476179, 48.59088931764875, 45.961565903254915, 48.034369877406526, 50.28081280844552, 49.956401416233604, 51.70102807453701, 50.27849905831473, 50.59991577693394, 44.656193937574116, 37.97502851486206, 37.82578468322754, 39.39482341493879, 39.00326810564314, 39.9552720614842, 45.84234176363264, 47.297033991132466, 47.138528210776194, 45.29701934541975, 41.04210581098284, 38.45791094643729, 37.059784003666465, 37.44296325956072, 37.397244112832205, 36.8273389680045, 34.920120988573345, 37.52402441842215, 37.02981294904436, 40.880553245544434, 44.875586782182964, 48.59731640134539, 47.423543316977366, 50.83407006944929, 49.92664575576782, 44.828603063310894, 40.358017444610596, 44.81552307946341, 45.780648708343506, 51.94008779525757, 46.454349517822266, 48.53279890332903, 48.59066002709525, 45.99265561785017, 47.304381711142405, 45.325958592551096, 40.04447650909424, 35.39532913480486, 35.19647863933018, 36.18031229291643, 35.71187169211251, 34.50651904514858, 35.44563756670271, 37.34170716149466, 40.52465261731829, 48.80764184679304, 47.4226713180542, 46.1072279385158, 42.91671242032732, 36.06217207227434, 35.91052416392735, 35.995278290339876, 38.27913727079119, 45.15041235515049, 47.39678233010428, 44.04747268131801, 46.02684770311628, 45.50587524686541, 46.688142504010884, 47.68498318535941, 45.88621268953596, 44.125532218388145, 44.227288586752756, 45.666340419224326, 41.380264214106965, 43.10442842755999, 44.152734415871755, 43.03703090122768, 45.62455742699759, 45.881328105926514, 44.97922611236572, 46.12555728639875, 35.24436214991978, 21.20651354108538, 6.7839405706950595, 3.274585029908589, 3.5075392382485524, 9.367612583296639, 8.44022696358817, 11.097871235438756, 13.583542381014142, 14.671960319791522, 14.064620018005371, 11.425930431910924, 2.967667247567858, 0.904232810650553, 0.43748393335512703, 23.403487035206386, 38.400199208940776, 31.4683393069676, 43.10606125422886, 10.937758684158325, 0.15067587979137897, 0.18715405810092176, 0.16180113995713846, 0.17061685690922396, 0.13577310661120073, 0.1126903970060604, 0.1863210206585271, 0.18057524040341377, 0.1623253354004451, 0.14655391526009354, 0.12093206654701914, 0.1654281946165221, 0.22151873553437845, 0.10517062765679189, 0.09983934408852033, 0.19086905089872225, 0.09529196524194308, 0.17955184674688748, 0.10296876116522721, 0.13403837755322456], [0.008107011722001647, 0.016501671401783824, 0.01660214377833264, 0.0674009257927537, 0.07888879507247891, 0.06438527868262359, 0.02783872270291405, 0.054599300758647065, 0.030736011253403764, 0.03493448400071689, 0.029110726501260484, 0.013634441952620233, 0.04770184980173196, 0.02804818476683327, 0.00393947126576677, 0.03569108108058572, 0.04282462490456445, 0.0356299925728568, 0.052818285434373786, 0.025139128722782646, 0.03423325198569468, 0.07012224476784468, 0.06204343720206192, 0.020117533626034856, 0.017843228432216814, 0.03396440962595599, 0.8531878697020667, 12.119031480380468, 29.725974287305558, 24.188065460750035, 34.94829593385969, 10.137137736592974, 0.036886042316577265, 0.10196650387453181, 0.05690914252772927, 0.1607181302138737, 2.861678123474121, 3.328582303864615, 7.746438911982945, 6.083322874137333, 5.3687731708799085, 2.2495429132665907, 0.5914162248373032, 1.4182262356792177, 10.531368970870972, 30.918844495500835, 47.87738922664097, 50.93286650521414, 48.29679291588919, 46.12719358716692, 46.90661471230643, 45.64521789550781, 47.6276535987854, 46.70816373825073, 47.813917432512554, 46.39019332613264, 46.16774674824306, 43.96162073952811, 43.45500673566546, 43.83463198798043, 46.709615911756245, 46.890894412994385, 47.70841251100813, 46.89505638395037, 43.04318700517927, 34.669322286333355, 36.42225204195295, 35.46997710636684, 34.6160226549421, 36.43440791538784, 43.27330786841256, 45.686194896698, 45.40141255514962, 44.272427558898926, 39.899689946855815, 36.45702430180141, 34.550865922655376, 33.842795848846436, 33.144894463675364, 33.1371819632394, 35.23306785311018, 34.99081890923636, 37.28046226501465, 43.041269302368164, 45.5403139931815, 46.74735505240304, 47.97695343835013, 44.464784962790354, 44.981275830950054, 41.20844915934971, 36.4313576562064, 46.37084606715611, 45.53579418999808, 43.31699814115252, 42.76237208502633, 43.29511478969029, 42.25163779939924, 44.25091593606131, 39.786625385284424, 37.3212342943464, 33.17262125015259, 33.20560087476458, 31.351178782326834, 31.46078314099993, 32.3622841153826, 31.663441249302455, 34.275824955531526, 35.52536119733538, 43.533236503601074, 46.160030773707796, 46.07885149547032, 43.591556208474294, 43.37597792489188, 36.87125505719866, 30.976368631635392, 32.383125237056184, 33.69800928660801, 41.58541325160435, 42.88730069569179, 41.53631033216204, 43.226400579724995, 41.62738731929234, 40.4129672731672, 43.30668354034424, 41.46241276604788, 43.962791510990684, 43.307263714926584, 41.48437949589321, 42.01395034790039, 40.8789655821664, 42.06281355449131, 42.600565910339355, 42.66810934884207, 40.854810169764924, 41.69396148409162, 41.129191058022634, 28.52451089450291, 11.676747373172216, 2.052766237940107, 1.345114141702652, 1.7760324073689324, 1.8970625357968467, 5.943887293338776, 6.219407251902989, 2.7828723064490726, 4.757689092840467, 6.247348129749298, 2.913466955934252, 0.27150332980922287, 0.044987153328422985, 2.090774621282305, 28.7461063180651, 25.828507355281285, 31.935220037187847, 22.160975422177994, 1.0417398320777076, 0.01054175482464156, 0.031960312343601666, 0.06865660912756409, 0.009282878134399652, 0.06683328375220299, 0.032265826128423214, 0.05207631756950702, 0.1152606944420508, 0.09435414163661854, 0.04275242877858026, 0.004329117031634918, 0.01127047768594431, 0.04558668990752526, 0.012359887710772455, 0.008102751370253307, 0.04372401289375765, 0.03643226184483085, 0.09603518500391926, 0.028182290427918946, 0.015325724413352353, 0.01163799175992608, 0.009142451919615269, 0.0386380129493773, 0.0430739559898419, 0.03449455921405128, 0.06559249426105193, 0.0471016516509865, 0.033465357297765355, 0.05475379300436803, 0.05469634483701416, 0.04178736199225698, 0.031174745211111646, 0.02877096026869757, 0.04220755837325539, 0.016931830373193537, 0.04926111309656075, 0.04337251139804721, 0.04570665489882231, 0.0359681608554508, 0.01843610349377351, 0.04141974189717855, 0.05017249758488365, 0.05529317066871694, 0.04479529755190015, 0.09111140242644719, 0.10857522461031165, 1.4511203105960573, 20.10140081814357, 33.90145601545061, 26.29118095125471, 40.220846108027864, 10.17725316115788, 0.05181492552427309, 0.028320986378405775, 0.03545613493770361, 0.376477446939264, 3.1430690927164893, 6.591392959867205, 6.6255998100553235, 6.424809464386531, 6.911187708377838, 7.098645763737815, 3.2558166427271704, 3.5816643578665595, 12.476568409374782, 33.0831492968968, 49.156604698726106, 51.948272773197715, 50.50086920601981, 46.67072337014334, 47.841032777513774, 46.23969187055315, 48.7573299407959, 47.52602229799543, 47.559373651232036, 48.59645482472011, 45.74464314324515, 43.86175775527954, 43.52244247709002, 47.0123940876552, 48.212271554129465, 47.362520762852256, 49.60927288872855, 48.39856318065098, 43.69115516117641, 36.098566736493794, 38.26547016416277, 37.49499831880842, 36.488437107631135, 38.308013984135215, 44.965190751211985, 46.99388061250959, 46.52793441499983, 45.65023796898978, 41.87355504717146, 37.86429507391793, 35.874549865722656, 35.22002955845424, 35.344200815473286, 34.46289130619594, 36.16688142504011, 36.04323475701468, 38.1767520904541, 44.88186795370919, 47.64223091942923, 48.233838762555806, 49.39793995448521, 45.63631725311279, 46.10996552876064, 42.056108542851035, 38.794228076934814, 47.319285597120015, 47.41696684701102, 44.03090817587716, 44.79738480704171, 45.22852747780936, 45.423817021506174, 45.936750411987305, 42.43346173422677, 38.24221454347883, 35.00736951828003, 33.91971935544695, 33.27311999457223, 33.26264558519636, 34.53285619190761, 33.45053877149309, 34.81905944006783, 36.74819203785488, 44.098625319344656, 46.77444607870919, 48.156446252550396, 46.694586958204, 45.03351933615548, 38.83833524159023, 32.90159286771502, 33.187181200299946, 35.94162777491978, 43.29048381532942, 44.76176834106445, 43.22346843991961, 42.97089099884033, 43.27623306001936, 42.32866900307791, 44.56130238941738, 43.69942699159895, 44.43676635197231, 43.37041589191982, 43.588829040527344, 43.322372572762625, 41.6252681187221, 42.130259718213765, 43.70058734076363, 43.9730817931039, 41.6985125541687, 43.86228929247175, 42.4082293510437, 30.184628350394114, 13.571138109479632, 3.831207173211234, 2.161173986537116, 4.505634937967573, 4.9549888372421265, 6.441790427480425, 6.427677767617362, 6.162569684641702, 7.2231075423104425, 5.463485368660518, 1.7709366636616843, 0.37949177090610775, 0.01780981567156102, 2.1889897968087877, 34.139178207942415, 28.206597805023193, 33.40355505262102, 28.537184408732823, 1.8121751993894577, 0.06524101990674223, 0.05199160247242876, 0.04576053736465318, 0.037596404020275385, 0.016209482348390987, 0.045201526289539676, 0.0490280973858067, 0.013701083421308016, 0.0585092536306807, 0.012360518748339797, 0.02941496464024697, 0.033429106564394066, 0.06847731303423643, 0.03572249385927405, 0.042362220252731016, 0.036259557719209363, 0.04133453486221177, 0.046018692797848156, 0.039060126191803386, 0.06657489761710167, 0.128723249903747, 0.0532557505315968, 0.14797852667314665, 0.20165882978056157, 0.15002782456576824, 0.20365892031363078, 0.175005078581827, 0.13583608823163168, 0.12977242789098195, 0.15401242646787847, 0.11690981952207428, 0.2057847569563559, 0.1632710096559354, 0.10185974996004786, 0.1339463817753962, 0.1310389677860907, 0.16160143353044987, 0.14968075390372956, 0.13803370030862944, 0.06643248668738774, 0.13923237313117298, 0.2089451559420143, 0.2110760137438774, 0.16371683430458817, 0.15632023263190473, 0.19890494112457546, 1.4639335487570082, 23.91971560886928, 44.0009058543614, 32.56383398600987, 44.96838692256382, 14.966621262686592, 0.12638048561555998, 0.2558781611067908, 0.11651869836662497, 1.0892888520445143, 6.940275038991656, 12.170801639556885, 18.732395512717112, 12.3138633114951, 11.425226058278765, 5.598026377814157, 1.4036464180265154, 1.9139451384544373, 12.48885108743395, 33.35822153091431, 49.303180422101704, 54.76535735811506, 52.46417304447719, 50.95919670377459, 50.57637875420706, 48.4109240259443, 50.77274874278477, 49.915104797908235, 48.41497482572283, 47.87593010493687, 47.90172529220581, 45.66938720430647, 44.208695207323345, 46.141225474221365, 48.47761978421892, 48.62009607042585, 51.51506648744856, 51.84812143870762, 46.464295864105225, 38.19592217036656, 39.29249382019043, 39.20313303811209, 37.442365714481895, 41.342928068978445, 47.870976039341514, 49.51651791163853, 48.09758458818708, 48.349362986428396, 44.190379755837576, 40.52665369851248, 38.64948320388794, 35.75821270261492, 36.032152380262104, 36.63761840547834, 38.130122729710166, 37.855425698416575, 40.61954763957432, 47.00406319754464, 49.31975882393973, 50.96449817929949, 50.02591119493757, 47.348259585244314, 45.812478406088694, 44.18433134896414, 39.86736345291138, 47.84630298614502, 48.17833307811192, 45.38461528505598, 45.27841901779175, 45.88019902365548, 46.256030559539795, 46.63750403267996, 44.335746492658345, 40.62003748757498, 37.12921040398734, 35.536599908556255, 34.62719188417707, 34.78835187639509, 36.37836374555315, 35.42888198580061, 36.38713584627424, 38.990771770477295, 46.51006017412458, 49.223352568490164, 46.72830309186663, 47.65246909005301, 45.738466194697786, 41.395091669900076, 35.31305551528931, 34.46977697099958, 37.00254821777344, 44.67396395547049, 45.43940877914429, 43.69763783046177, 43.392980166843955, 44.56357445035662, 44.17470809391567, 47.14057445526123, 44.632917472294395, 47.279548849378315, 44.95130477632795, 43.89166975021362, 45.629243986947195, 43.54727533885411, 43.05114964076451, 45.01087515694754, 44.50170769010271, 43.186653409685405, 44.75726590837751, 43.65519823346819, 30.705607754843577, 14.317945258957998, 3.900478107588632, 3.40161286507334, 6.5853341306958875, 6.665745632989066, 13.09186179297311, 14.086176804133824, 10.05014455318451, 12.856205821037292, 13.546808992113386, 7.351754307746887, 1.8681810455662864, 0.16974378590072903, 3.5650447010993958, 38.68326881953648, 33.28112779344831, 42.56345558166504, 33.03079809461321, 2.207376684461321, 0.25156419830662863, 0.21745355081345352, 0.17849103866943292, 0.09383768149252449, 0.1703233498015574, 0.147831759548613, 0.17451467418244906, 0.16847940374697956, 0.20666204845266684, 0.1867479413215603, 0.08272434997239284, 0.08914434976343598, 0.1527178223643984, 0.1420504647706236, 0.14397687997136796, 0.11559590431196348, 0.07751800505710499, 0.2606951897697789, 0.09528971929103136, 0.09846451000443526], [0.022197765930156623, 0.0090490201920537, 0.06197956670075655, 0.10531950502523355, 0.042332134010004144, 0.028332243274365152, 0.01296533687439348, 0.04797642578237823, 0.015354302612000277, 0.05839381446795804, 0.022939535323530436, 0.014454492234757968, 0.010601772095209785, 0.017691474075296094, 0.02719945111311972, 0.058095917238720825, 0.03494100132957101, 0.026256837050563524, 0.03167978221816676, 0.035329510125198534, 0.06270054408482142, 0.01616078897911523, 0.01926961082166859, 0.03740004277122872, 0.03394892206415534, 0.016667496878653765, 0.05135339278993862, 2.2748024378504073, 14.749085324151174, 21.136361054011754, 27.718756096703665, 23.39261657851083, 0.31574915988104685, 0.04151805822870561, 0.23968443434153283, 0.7613756763083595, 2.4346529117652347, 4.353460269314902, 2.0580121278762817, 18.459440742220195, 38.410909857068745, 8.716269339833941, 3.712065977709634, 0.7512988884534154, 2.428326576948166, 14.933271646499634, 41.279563971928184, 48.20946448189871, 50.6074788911002, 46.04512841360909, 46.71112019675118, 46.1074607031686, 48.31281198774065, 49.377963883536204, 48.53712068285261, 45.42582852499825, 46.00821263449532, 46.098778929029194, 48.579622813633506, 45.75540590286255, 48.08737073625837, 47.54407024383545, 47.79673801149641, 43.88112933295113, 38.949843406677246, 34.83210815702166, 36.19566433770316, 34.72354602813721, 33.796319348471506, 36.959035124097554, 47.3454247202192, 47.20529692513602, 46.22672305788313, 44.66480622972761, 42.870666708265034, 38.205607959202354, 34.86132533209664, 33.45937688010079, 34.09616538456508, 32.84093509401594, 34.376403604234966, 34.305743898664204, 42.89389453615461, 44.19900941848755, 46.29786218915667, 47.842783723558696, 45.65723133087158, 44.73640046800886, 43.85853379113333, 41.560163497924805, 39.54189246041434, 47.182826450892854, 45.30131680624825, 44.07789536884853, 42.35054193224226, 43.0047322000776, 41.99013887132917, 39.102325098855154, 39.02034330368042, 33.45884186880929, 34.57217952183315, 32.220704146793906, 31.75093296595982, 31.755188737596782, 32.415378774915425, 32.68443734305245, 32.65097829273769, 34.43883664267403, 43.35840940475464, 43.96519211360386, 44.10057428904942, 43.71550859723772, 41.75470263617379, 40.6872022492545, 32.08358492170061, 32.73024681636265, 32.16310010637556, 38.96390656062535, 42.84367643083845, 44.32292706625802, 44.94367218017578, 44.65244538443429, 43.13634497778756, 42.98416205814907, 42.24389055797032, 40.32810197557722, 40.31345517294747, 40.36938122340611, 43.305377279009136, 42.61896126610892, 41.157272202628, 42.61422259466988, 41.247907979147776, 40.16099085126604, 42.58188567842756, 37.0626779283796, 22.030113049915858, 5.80798921414784, 1.3847969323396683, 0.9807375797203609, 2.2170707242829457, 3.6761798347745622, 6.1844126496996195, 4.8166302272251675, 4.6551306418010165, 4.052554632936205, 4.725439897605351, 1.257141262292862, 0.03722727418478046, 0.0317290608238961, 12.632120336805071, 32.59767518724714, 23.66168209484645, 26.691042831965856, 7.898931894983564, 0.07137154987347977, 0.0535231306483703, 0.04385511264471071, 0.04832703500453915, 0.024845938830237304, 0.08798625333500759, 0.019599341521305696, 0.02249990400326039, 0.017019419066075767, 0.024037503371281282, 0.03143854944833687, 0.04938223838273968, 0.03928221409608211, 0.03001376840152911, 0.036026854134563885, 0.010333176552584129, 0.01869153291253107, 0.03708089043253234, 0.06347517323281084, 0.02395014538030539, 0.04439747925581677, 0.05094227520748973, 0.03506493914340224, 0.04299668442191822, 0.03336228782843266, 0.01418435387313366, 0.015459280461072922, 0.005568350981255727, 0.04361492821148463, 0.044855846624289236, 0.028333176260015795, 0.01668896063763116, 0.017188579542562366, 0.011704913124309053, 0.01250321720726788, 0.0576905400625297, 0.054373216283108504, 0.0617300286622984, 0.04352748879630651, 0.027887604365657483, 0.03188271847154413, 0.020839991912777935, 0.02051090242873345, 0.03738528802724821, 0.03207002806344202, 0.04130244354850479, 0.025328875951735035, 0.09340924769639969, 4.108386882713862, 25.948282139641897, 23.00291817528861, 35.440249238695415, 24.529256752559117, 0.22769458485501154, 0.09276263775037867, 0.2622183651796409, 0.42124881595373154, 1.1928566374949046, 7.028961845806666, 6.96429409299578, 18.57339641026088, 32.88611922945295, 11.156383752822876, 7.379502807344709, 3.1955846633229936, 3.2745587570326666, 19.13842739377703, 42.070206437792095, 50.61528171811785, 51.472797121320454, 48.87932988575527, 48.66151428222656, 48.53387934820992, 48.426529679979595, 50.971474170684814, 50.54874924251011, 46.30812120437622, 47.8037348474775, 46.75573805400303, 49.83478709629604, 47.3717931338719, 48.731506960732595, 49.153516224452424, 49.3139431817191, 47.82688971928188, 41.4829238482884, 36.56098672321865, 37.63364267349243, 35.6390198298863, 35.381835733141216, 39.165018694741384, 47.41805076599121, 48.34200831821987, 48.22485474177769, 46.31715038844517, 44.84179769243513, 38.14642320360456, 36.07162857055664, 35.81004279000418, 35.587280069078716, 35.05347081593105, 35.43825510569981, 36.22454105104719, 42.83665180206299, 46.075050830841064, 47.75221048082624, 48.39273016793387, 47.035027844565256, 45.78477941240583, 44.38322005953108, 42.35339069366455, 41.8784396307809, 48.921762534550254, 47.39848116465977, 44.90227133887154, 44.49161890574864, 46.2302770614624, 43.59852525166103, 41.3450368472508, 40.02116182872227, 36.32255234037127, 35.04786014556885, 32.977508885519846, 32.04490777424404, 33.50216041292463, 33.26567152568272, 33.95353971208845, 34.91610145568848, 36.34238944734846, 44.81741993767874, 45.885351112910676, 46.32712800162179, 45.494563579559326, 43.42535877227783, 41.068335260663716, 33.35605369295393, 34.97651604243687, 33.35838828768049, 40.9162391935076, 44.15565960747855, 46.02339097431728, 44.13335936410086, 45.35081924710955, 44.67810508183071, 44.20674276351929, 43.39242083685738, 41.88699286324637, 42.21697671072823, 42.33950124468122, 44.20224380493164, 42.7140543120248, 42.859441893441335, 42.80765002114432, 42.4914687701634, 42.14442362104143, 43.063163076128276, 38.68307079587664, 23.133288962500437, 7.141506161008563, 2.3259739662919725, 2.7966807654925754, 3.327794768980571, 4.112872813429151, 5.951249778270721, 7.138248758656638, 5.37215086391994, 6.839644278798785, 3.040471775191171, 0.4131841558430876, 0.05840112907545907, 0.053153020329773426, 11.741619229316711, 36.96740075520107, 23.30283543041774, 34.001478808266775, 12.009216938699995, 0.3251393517213208, 0.054710461758077145, 0.02736890844867698, 0.057863105088472366, 0.011826067248226275, 0.14165600522288255, 0.03792918812749641, 0.047117888993982754, 0.026021831535867283, 0.0228770235885999, 0.04509275373337524, 0.03058088118476527, 0.0245286049653909, 0.07466652949473687, 0.08240785409829446, 0.022651037500639046, 0.07196536300969975, 0.02733081888540515, 0.07765933711613927, 0.00823082315868565, 0.010564627391951424, 0.1593510721411024, 0.12908955024821417, 0.1419695019721985, 0.11028570961207151, 0.11433426343968936, 0.07934741689158337, 0.09946954928870712, 0.17187777853437833, 0.13164916075766087, 0.16042421598519596, 0.10343917592295579, 0.09121299268943922, 0.06756056472659111, 0.11087746678718499, 0.08844100071915559, 0.13957873811679228, 0.09957406403762953, 0.11317210937184946, 0.07812922940190349, 0.11702275489057813, 0.15200992035014288, 0.09113656929028885, 0.1822606399655342, 0.15432866449866975, 0.14960364518421038, 0.12410496414772101, 0.13133548758924007, 5.172356281961713, 32.66107749938965, 29.724602018083843, 37.632308619362966, 32.106604303632466, 0.8168496053133691, 0.23669415765575, 0.6439692505768367, 2.0848732122353146, 7.101458481379917, 10.372677326202393, 7.778100984437125, 27.098697117396764, 47.66882862363543, 14.385232482637678, 7.006743678024836, 2.6441602068287984, 3.8205026047570363, 17.957475083214895, 43.96683188847133, 51.884894779750276, 54.12872518811907, 50.8059298651559, 50.06544991901943, 50.038358892713276, 51.325484888894216, 51.809242793491904, 52.1011574608939, 47.88942698069981, 48.80712073189871, 47.25573737280709, 50.86494786398751, 47.594729559762136, 51.139856815338135, 50.73456491742815, 51.09390490395682, 46.79559639522007, 42.90113108498709, 38.020806721278596, 39.725595882960725, 38.04196398598807, 37.369597230638774, 40.59480510439192, 50.96591561181204, 50.5901848248073, 49.14591489519392, 49.06218910217285, 46.77265344347273, 40.73328617640904, 37.046252386910574, 35.802524839128765, 37.49359825679234, 35.72681031908308, 37.19946711403983, 37.96053457260132, 45.83363219669887, 47.76180246898106, 49.30898911612374, 50.30367585590908, 48.650119236537385, 47.00230530330113, 45.60339668818882, 43.09399570737566, 43.368397440229145, 48.76548017774309, 49.01748786653791, 47.13972677503313, 46.58822046007429, 47.542326245989116, 44.719269684382844, 42.86880806514195, 41.982541016169954, 37.43900973456246, 37.08495037896292, 34.842172622680664, 34.90150676454817, 35.124116625104634, 35.42941699709211, 36.59133298056466, 35.70776183264596, 37.95258583341326, 46.228758880070274, 47.99085678373064, 46.623107365199495, 45.9953167779105, 44.2271009853908, 42.8370270047869, 34.97786399296352, 35.54185274669102, 34.71552780696324, 41.96163388660976, 46.065410205296104, 47.900005613054546, 45.64567995071411, 46.396766321999685, 46.12072134017944, 45.68069192341396, 45.07112298692976, 41.92514194761004, 42.11523076466152, 42.69826800482613, 45.93494735445295, 44.27379635402134, 43.78672068459647, 45.670363426208496, 45.25081035069057, 44.154165744781494, 44.11638144084385, 40.08926459721157, 24.103250537599834, 7.547047325542994, 2.863749555179051, 3.3890466136591773, 5.246754552636828, 8.169545122555324, 13.588172486850194, 11.993767619132996, 10.58377662726811, 12.234177027429853, 11.247366939272199, 3.334750132901328, 0.1954398663448436, 0.1684649916631835, 16.3998088155474, 41.98908621924264, 31.609926223754883, 40.72600099018642, 14.012086425508771, 0.3417608269623348, 0.2878677488437721, 0.12034373597374984, 0.1507099422493151, 0.06871311752391712, 0.35208709857293535, 0.14978378266096115, 0.14401588216423988, 0.04348628814997418, 0.09608206498835768, 0.11536311251776558, 0.09970404420580183, 0.15978494100272655, 0.14483803590493544, 0.15660495949643, 0.10464110571358885, 0.12100984023085662, 0.11855616260852132, 0.1294578726270369, 0.07978417631238699, 0.184663468173572], [0.029357122922582284, 0.021964314260653088, 0.04270944019247379, 0.05666136868031962, 0.025801127843026603, 0.035377794677125554, 0.04765475268608757, 0.023886251130274365, 0.03082219877147249, 0.03322424666423883, 0.03038825187832117, 0.036638970752911906, 0.027155259823692695, 0.037829708108412366, 0.0560084822853761, 0.007135395376410867, 0.07286596896925143, 0.011215410328337123, 0.07584469698901687, 0.03754446216459785, 0.034135614189186265, 0.00504761649062857, 0.01945820963010192, 0.08387329296341964, 0.025191876338794827, 0.05223124407763992, 0.06212004380566733, 0.5981838245476995, 7.929705466542925, 25.0142879145486, 19.674661568232946, 37.04967784881592, 5.3402586323874335, 0.0836051291386996, 0.20200248062610626, 0.1296088873807873, 0.5310186828885759, 5.228572419711521, 5.5985492297581265, 12.066001960209437, 7.72875314099448, 12.406813706670489, 10.88393793787275, 4.159363210201263, 0.5029087683984211, 6.422011077404022, 30.587074960981095, 49.61458478655134, 50.12843186514718, 47.1838686806815, 45.97230781827654, 45.758275508880615, 47.87977245875767, 48.75821931021554, 47.55999551500593, 46.62102290562221, 47.87033680507115, 46.683289187295095, 48.16146285193307, 46.33172423498971, 44.93007108143398, 44.006853512355256, 42.84696987697056, 39.424471378326416, 34.63591534750802, 33.63612515585763, 33.781578745160786, 34.45962912695748, 34.68551158905029, 40.43803637368338, 46.91900682449341, 45.8605877331325, 47.511660371507915, 46.019836970738, 41.14270530428205, 38.271330969674246, 35.52124091557094, 33.93481779098511, 34.76706954411098, 33.750971930367605, 35.30580159596035, 37.865208762032644, 44.718154498508994, 44.53189066478184, 47.69953271320888, 46.00933824266706, 47.0595098223005, 45.15524135317121, 44.478247097560335, 43.25189699445452, 40.265960761478965, 46.733906814030235, 43.31863096782139, 42.631985664367676, 41.10840204783848, 40.65005717958723, 37.94083295549665, 38.531631333487375, 36.36347723007202, 33.14109032494681, 31.67708056313651, 30.93773317337036, 31.214507716042654, 32.623446055821006, 32.14176566260201, 33.20077187674386, 31.294453689030238, 35.58519213540213, 42.205633776528494, 44.87214742388044, 41.45911584581648, 44.844736780439106, 43.62540088381086, 43.19759334836687, 36.580285344805034, 31.835812159946986, 33.062461035592214, 33.86676365988595, 41.325734751565115, 41.507075786590576, 42.4209862436567, 42.5757816859654, 43.46324382509504, 44.18650266102382, 42.75850888660976, 40.719254289354595, 38.26181888580322, 40.47919055393764, 40.88092150006975, 40.51445613588606, 40.582885469709126, 39.493098735809326, 39.1607802936009, 38.75658621106829, 42.857117721012656, 34.479382855551584, 15.160797357559204, 3.3517109027930667, 0.7052126814212117, 2.391027344124658, 3.639877885580063, 3.37112786088671, 3.6149998605251312, 4.338140359946659, 4.323374135153634, 5.855751131262098, 3.1707756859915595, 0.40951262999858173, 0.0412162424597357, 1.299042482461248, 32.47114501680647, 28.73977303504944, 24.738121339253016, 23.15174511500767, 1.1025329870837075, 0.07533388225627796, 0.04572278367621558, 0.012621948112999755, 0.039400170623723946, 0.09116835865591254, 0.05562736273610166, 0.038381601351180246, 0.012269028479100337, 0.048094219461615594, 0.03861564504248755, 0.011429209079194282, 0.01732279546558857, 0.0443776321065213, 0.03825624200648495, 0.024120452580973506, 0.011795243098666626, 0.031181981787085533, 0.023700310482776592, 0.020695496184219207, 0.03431149385869503, 0.025370526127517223, 0.019058750975610952, 0.04192421572016818, 0.02794872680013733, 0.04683419689536095, 0.023393276779513274, 0.02779116587979453, 0.02897010351132069, 0.011905153897324843, 0.034543379808643034, 0.05346078685085688, 0.004732433157706899, 0.0952117352613381, 0.022012882100950395, 0.027699321076007824, 0.025779479183256626, 0.006762527661131961, 0.03115733739520822, 0.022135060812745775, 0.055243590114904303, 0.03972004220954009, 0.027907984164942588, 0.06448861956596375, 0.04236876472298588, 0.06932223841015782, 0.07519597001373768, 0.025582727776574235, 0.03664315052862678, 1.2939770285572325, 14.196082540920802, 27.961868354252406, 24.94536873272487, 39.12398610796247, 5.038198726517813, 0.04604884689407689, 0.19486536431525434, 0.05158414897908058, 0.5521321956600461, 5.175927221775055, 6.870711846011026, 19.203313146318706, 11.999517253467015, 8.48671736036028, 9.127314346177236, 4.206010809966496, 0.62305598706007, 7.728962455477033, 32.50875561577933, 51.79780258451189, 51.89744322640555, 48.9568578856332, 46.05471692766462, 47.679553168160574, 48.76006405694144, 51.30546712875366, 48.96862465994698, 48.06377465384347, 49.20407826559884, 47.92882326671055, 48.25244951248169, 48.72917236600603, 46.07049281256539, 47.464308398110525, 45.06377179282052, 42.25731100354876, 36.75988933018276, 35.82181303841727, 35.268239634377615, 36.24472556795393, 34.9665766443525, 43.53365339551653, 49.43170472553798, 49.24496841430664, 48.70118154798235, 47.72437252317156, 42.72103030341012, 40.12808765683855, 36.793782642909456, 35.696905272347585, 35.118825571877615, 35.77046585083008, 35.99858563286917, 39.54879549571446, 46.53418779373169, 46.39357015064785, 48.2724985395159, 47.76656893321446, 48.26308025632586, 47.2668788092477, 45.094882352011545, 43.38202633176531, 42.09355238505772, 47.39769949231829, 45.27129364013672, 44.145112242017476, 42.29068667548043, 41.01302759987967, 40.178444726126536, 41.92206736973354, 37.46395376750401, 34.9439811025347, 33.197339466639924, 32.366567679813926, 32.91746255329677, 33.16559314727783, 33.57344545636858, 34.191265378679546, 33.23260852268764, 36.30632134846279, 44.39020299911499, 46.90924807957241, 42.30661194665091, 46.89536557878767, 45.02266277585711, 45.17498465946743, 37.31356348310198, 32.861526080540244, 33.188834871564595, 35.94405269622803, 43.34374870572771, 43.99300227846418, 44.10990571975708, 43.051156588963096, 45.577639716012136, 44.55942637579781, 44.24851185934884, 40.87839930398123, 40.426290443965364, 42.6637875693185, 43.093415532793315, 42.41854395185198, 42.5732421193804, 41.11497504370553, 39.89472893306187, 39.65471036093575, 43.78566108431135, 35.686708790915354, 16.79709812573024, 3.7418945942606245, 1.8769859330994743, 2.894692054816655, 3.4725895822048187, 5.047677372183118, 6.468084582260676, 4.9773946063859125, 5.648084240300315, 5.046249517372676, 1.3325876252991813, 0.11124811654112168, 0.03912714509559529, 1.0974777383463723, 32.663207122257774, 34.21971477781023, 28.04240492412022, 30.66692018508911, 2.3559135368892123, 0.10322612271245037, 0.0384299707199846, 0.02051861397922039, 0.027633986635399715, 0.12388549878128938, 0.04304896554510508, 0.0795287350192666, 0.011631013875428056, 0.02357209280931524, 0.06901896039822272, 0.015193170901121838, 0.016502996241407733, 0.053735478182456324, 0.029106468694018464, 0.03136887407994696, 0.024258044215717485, 0.01920291591834809, 0.07947871341769185, 0.0386505115644208, 0.021342374151572585, 0.05119138237621103, 0.22852733731269836, 0.18595865581716808, 0.1562594494649342, 0.14638924838176795, 0.1144496143928596, 0.09713538882455655, 0.14217596660767282, 0.08523112295993737, 0.15561908882643494, 0.1579955898757492, 0.08791901730000973, 0.17121448341224874, 0.08661029288279158, 0.10832724041704621, 0.12044953315385751, 0.10931397282651492, 0.16542591473885945, 0.13542480101542814, 0.20133873767086438, 0.08340134471654892, 0.13807785936764308, 0.1392195759607213, 0.07759835038866315, 0.1512703714626176, 0.13026530215782778, 0.11043852248362132, 0.1682991577046258, 0.9748660262141908, 19.67528690610613, 39.474293436322895, 26.75393966266087, 45.13519580023629, 8.745613319533211, 0.18902898606445107, 2.0422579560961043, 1.304700378860746, 3.337628207036427, 12.42737168925149, 17.839053460529872, 18.53129553794861, 10.704193251473562, 20.933411121368408, 17.165198053632462, 6.475801425320761, 1.4194351136684418, 7.892318946974618, 32.427527700151714, 54.08170672825405, 54.54208047049386, 51.14288970402309, 49.858244214739116, 50.21783086231777, 50.544952051980154, 53.824772766658235, 51.59925780977522, 48.914519037519185, 51.596339566367014, 49.18782990319388, 51.559715611594065, 50.680063247680664, 47.95172105516706, 47.84780032294137, 46.586288860866, 44.600823743002756, 38.092494760240825, 37.21185227802822, 36.5487995828901, 37.614378792899, 37.808184896196636, 44.62344012941633, 51.38051462173462, 48.951469557625906, 50.274705341884065, 50.6455202783857, 44.8845534324646, 42.05156094687325, 39.68454939978463, 37.224685600825715, 37.04329245431082, 36.75108596256801, 38.16958849770682, 42.71778549466814, 48.103511401585166, 48.920574392591206, 50.605192933763774, 49.014677320207866, 49.2698255947658, 48.10897963387625, 45.86287021636963, 45.32921034949166, 43.017815658024375, 49.2240960257394, 47.213339465005056, 46.347715514046804, 44.78506565093994, 43.02456930705479, 40.672649247305735, 43.33033868244716, 39.36401857648577, 36.01099511555263, 34.81331327983311, 33.44936800003052, 33.7195382799421, 35.5737658228193, 34.41254465920584, 34.74160092217581, 35.22239194597517, 39.140786852155415, 45.9807186126709, 47.32147427967617, 43.660874911717, 47.27639089311872, 46.926903452192036, 48.375328404562815, 40.15378556932722, 34.875520501817974, 35.306392192840576, 37.74149261202131, 45.980614389692036, 44.87954725537981, 44.1609263420105, 43.43297052383423, 44.68712036950247, 46.43093408857073, 46.158102648598806, 43.18609407969883, 41.87242943899972, 44.402966839926584, 43.42727994918823, 43.76636593682425, 43.717259543282644, 43.7111451285226, 41.03057180132185, 40.55941792896816, 45.1966769354684, 37.628104959215435, 16.69095049585615, 4.563509958130973, 2.698055863380432, 5.327959018094199, 8.334135787827627, 10.39853765283312, 9.789962308747427, 11.897112965583801, 13.037043980189733, 13.053043944495064, 6.5391247017042975, 1.6632432767323084, 0.22282256771411213, 2.123170162950243, 38.442604064941406, 37.64521837234497, 35.408221517290386, 37.605064732687815, 2.77648908325604, 0.19825486386460917, 0.16541899368166924, 0.07836666237562895, 0.12740556203893252, 0.2110532828207527, 0.14699785358139447, 0.14460476913622447, 0.08998560426490647, 0.14678513285304817, 0.1312314003173794, 0.10212872802679028, 0.06817688486937966, 0.09979446578238692, 0.15141457372478076, 0.13402642176619597, 0.17307761843715394, 0.07390319116945777, 0.12411142380109855, 0.19220816689942563, 0.12570181488990784, 0.0879541247018746], [0.03753738504435335, 0.052991949687046666, 0.007402731388408158, 0.08475911364491497, 0.05889396941555398, 0.019346293760463595, 0.062388784385153224, 0.027886919045288647, 0.01853006363048085, 0.030162435424114977, 0.060391489416360855, 0.01755024379651461, 0.04212457014779959, 0.04905033976371799, 0.04323263479662793, 0.02730900907356824, 0.02804604738152453, 0.027994203913424696, 0.028335208472396647, 0.01871347164602152, 0.05579734593629837, 0.04863708818863545, 0.011939781235664018, 0.021149291923003535, 0.08310333213635854, 0.0553515280729958, 0.0434074559515076, 0.13861478412789957, 4.978713461330958, 27.73788969857352, 23.28259011677333, 40.3522504397801, 16.020940916878835, 0.05853626610977309, 0.2101807003574712, 0.11123970949224063, 0.15737022486116203, 3.5325896654810225, 6.306523331574031, 5.51998725107738, 5.027166724205017, 4.705114679677146, 7.132935992309025, 2.9302690029144287, 0.5845230690070561, 1.7676306239196231, 19.346287965774536, 47.729958874838694, 48.59693772452218, 48.88586466653006, 46.022185461861746, 46.69738013403756, 46.831605434417725, 48.87235736846924, 47.67500557218279, 47.85669749123709, 45.9500527381897, 45.50276592799595, 42.20796142305647, 40.17062452861241, 38.67636578423636, 37.71196971620832, 34.848981857299805, 34.56065593447004, 34.39542777197701, 34.671396323612754, 34.98137283325195, 33.442600454602925, 35.51657172611782, 44.94378335135323, 47.17181703022548, 48.1140170778547, 46.09030907494681, 48.09890127182007, 42.194075448172434, 38.88272033418928, 36.17748090199062, 34.07139505658831, 33.46250704356602, 33.75493587766375, 34.2211252621242, 38.97981446129935, 43.958737237112864, 44.10609810692923, 45.83609185900007, 43.63091427939278, 45.90049818583897, 45.63811336244856, 44.85099710736956, 42.62882423400879, 42.29042264393398, 48.340323380061555, 43.93477290017264, 42.46321044649397, 40.480041708265034, 37.79393414088658, 36.97574554170881, 36.29789318357195, 34.37429135186331, 34.117697851998464, 33.02113315037319, 31.47032301766532, 32.708589281354634, 31.920382159096853, 31.317028386252268, 33.52220596585955, 30.95664964403425, 34.349906648908345, 41.28707844870431, 45.79945748192923, 44.27714538574219, 43.7508818762643, 45.83093976974487, 42.090203353336875, 41.5049010004316, 33.45374883924212, 31.717095238821848, 32.8402715410505, 35.29977403368269, 41.04073701586042, 43.79459299360003, 44.81065934044974, 44.93313523701259, 42.361610412597656, 43.737256458827424, 41.57387229374477, 38.81996767861502, 38.13328068596976, 37.48444400514875, 38.01170458112444, 38.813179288591655, 36.30520268848964, 39.99656867980957, 41.30133267811367, 42.98479781832014, 27.823908397129603, 10.551792332104274, 1.6504047427858626, 1.5614898396389825, 2.3107022600514546, 1.4814522372824805, 2.3729466114725386, 5.628762602806091, 4.049745389393397, 2.2594968591417586, 2.452191467796053, 0.6425935072558266, 0.03918528197599309, 0.031307286848979335, 6.898634484836033, 47.7161979675293, 27.668775967189244, 24.69744484765189, 14.396479879106794, 0.4564683118036815, 0.04185550047882965, 0.01096445499985878, 0.0452312834427825, 0.036925533054662604, 0.06553476450166532, 0.059638790520174165, 0.09210155465240989, 0.014608288982084819, 0.012351622306076544, 0.010898717679083347, 0.03239469010648983, 0.04034233685316784, 0.026471455980624472, 0.02816987662975277, 0.0541262702484216, 0.03160105858530317, 0.038146801093327146, 0.011535331107942122, 0.004966150728120867, 0.023238538564848046, 0.024077570864132473, 0.04993811462606702, 0.004300919660766209, 0.017931524497855986, 0.05337797843718103, 0.01652660417104406, 0.012307462398894131, 0.05190830212086439, 0.022241258328514438, 0.05028715982500996, 0.014609530701168945, 0.020485296213467206, 0.05010554653459361, 0.04035687107326729, 0.018480545841157436, 0.039128142542072704, 0.020301898375951817, 0.025584904177646552, 0.010231912834569812, 0.041955927054264715, 0.02658890699967742, 0.03180007629894784, 0.017874997441789935, 0.06709390905286584, 0.027082717644848993, 0.04688658658415079, 0.026547212719119022, 0.04958829928987792, 0.12411891482770443, 8.260620372635977, 34.4064302444458, 22.25333261489868, 45.676689761025564, 16.580173628670828, 0.09545552610818829, 0.12710095409836086, 0.22687230897801264, 0.2241004662854331, 2.3855708369186948, 7.67150172165462, 7.670872041157313, 5.758103319576808, 7.274935892650059, 7.504811831883021, 5.807569716657911, 1.4771853919540132, 1.9615496354443687, 22.877286059515818, 47.90733943666731, 50.99138423374721, 51.234199455806184, 48.431574072156636, 47.45964963095528, 48.62179490498134, 50.990272521972656, 50.2975093296596, 49.81878192084176, 47.94147941044399, 47.20118359157017, 45.30098329271589, 42.387996196746826, 40.90187726702009, 40.796038831983296, 37.144294943128315, 36.414956433432444, 36.94638940266201, 36.392402580806184, 36.641068186078755, 35.48434945515224, 36.92674684524536, 44.8937007359096, 48.52729940414429, 49.18760756083897, 48.18004233496529, 47.913210664476665, 44.82201617104666, 40.066776752471924, 38.01129116330828, 36.48640823364258, 35.78602981567383, 36.03491428920201, 35.462191649845664, 40.938271931239534, 47.8422417640686, 46.122402804238455, 48.028700147356304, 45.33228145326887, 47.314164774758474, 46.629864488329204, 45.341143880571636, 43.449319635118755, 43.29698038101196, 48.25141075679234, 44.98929752622332, 44.223651204790386, 40.677099568503245, 38.62810359682356, 40.11579976763044, 38.32830272402082, 35.71585300990513, 34.722420419965474, 34.210473673684255, 33.45149414879935, 33.81896700177874, 33.589252608163015, 32.063143321446006, 34.78519739423479, 32.42625617980957, 35.98184742246355, 41.83124399185181, 47.48670244216919, 46.001132420131135, 44.62147031511579, 46.70913996015276, 43.51936442511422, 41.6551627431597, 34.7565986088344, 32.52995456968035, 33.61710793631417, 37.17907762527466, 42.7609407561166, 44.37829726082938, 45.447896003723145, 45.171406337193076, 42.48100478308541, 45.1937552179609, 43.43001406533377, 39.13302224023001, 38.278696060180664, 39.43540784290859, 39.563876560756135, 39.58403328486851, 38.67508384159633, 40.81952026912144, 42.60015944072178, 42.69961942945208, 28.891742297581263, 11.980670264789037, 2.3053250057356696, 1.7585713671786445, 2.8950670404093604, 4.961736840861184, 5.578640469482966, 7.285220529351916, 5.821766189166477, 5.886012273175376, 2.8890279701777866, 0.5849992377417428, 0.030506496783345938, 0.08950768490987164, 6.854304109300886, 50.31106526511056, 26.304483277457102, 30.467982837132045, 19.959899016789027, 0.47110366076231003, 0.05874613020569086, 0.026713737087058168, 0.05929670709052256, 0.032620150329811234, 0.053310800077659745, 0.029013774025120904, 0.012476690728882594, 0.07025508156844548, 0.048023488971271684, 0.05383587422381554, 0.009200397113870298, 0.04155161178537777, 0.06928407760070902, 0.0409914845201586, 0.018335861819131032, 0.05834733481918063, 0.038523123400019746, 0.028990605446909155, 0.027664897298174243, 0.033856179897806475, 0.05296233841883285, 0.1413362388099943, 0.09624577513230698, 0.04783711915037461, 0.13725694056068147, 0.09951319944645677, 0.09586762078106403, 0.15447469880538328, 0.13995588145085744, 0.0966904191300273, 0.10789914588843073, 0.2209050820342132, 0.08705462475440331, 0.14311024147484983, 0.18952238958861145, 0.08367854662771736, 0.08788965030440263, 0.13369634162102426, 0.10785740919943367, 0.09093642181583814, 0.09272651933133602, 0.20924151289675916, 0.12964441547436373, 0.11742446119231836, 0.047292360703327825, 0.1952780086014952, 0.13740123781774724, 0.1440829485654831, 0.23582717989172253, 10.405554464885167, 41.94409315926688, 30.8055054800851, 48.452168532780235, 21.29835135596139, 0.25383628638727324, 0.468832685479096, 0.3046228140592575, 1.1094846597739627, 11.848729184695653, 14.972348315375191, 13.599174090794154, 11.591669287000384, 14.019385508128575, 13.426903929029192, 8.134375078337532, 1.3419231814997536, 2.4699449837207794, 21.52764364651271, 51.85470833097185, 52.6154978615897, 53.72458669117519, 48.723120485033306, 50.907932894570486, 51.32391112191336, 53.44694014957973, 51.80104391915457, 52.26738268988473, 48.98619665418352, 48.76642860685076, 45.899542808532715, 45.02360078266689, 42.33563804626465, 41.5268885748727, 38.11144944599697, 39.00835766111101, 37.57011876787458, 38.77433885846819, 38.07111862727574, 35.81532342093331, 39.818534987313406, 48.43970346450806, 49.636662687574116, 51.433498110089985, 48.87547016143799, 51.500315461839946, 45.74920810971941, 42.18543883732387, 39.278493200029644, 38.3498386655535, 36.378238677978516, 38.03259434018816, 37.32936716079712, 42.454848289489746, 49.488540990012034, 47.44741037913731, 49.29511703763689, 47.8090363230024, 47.57380853380476, 48.11438185828072, 45.89926140648978, 43.359562805720735, 46.83136224746704, 50.767127650124685, 47.4875397000994, 46.24439580099923, 43.97467640468052, 40.87468549183437, 40.320003850119456, 40.118339334215435, 38.36464875085013, 36.784812518528526, 35.91353620801653, 35.35282700402396, 36.42450325829642, 35.534216676439556, 33.90699372972761, 36.16495329993111, 34.10645914077759, 38.95515183040074, 43.292710712977815, 48.678099632263184, 47.56088835852486, 45.07154335294451, 46.94800165721348, 45.53063515254429, 43.266918999808176, 37.66290848595755, 33.695671217782156, 36.86950411115374, 38.2570732661656, 44.97166299819946, 47.41311754499163, 48.868598393031526, 47.809467111315044, 42.80701078687395, 46.485845702035085, 45.838315282549175, 41.933542319706504, 41.22739689690726, 41.60488905225481, 40.65896824428013, 42.48422874723162, 40.99676881517683, 42.54777002334595, 43.95856005804879, 45.65072086879185, 29.576709611075266, 12.43791731766292, 2.8946725130081177, 4.1814450195857455, 5.898651480674744, 6.651887450899396, 7.671092646462577, 14.660822357450213, 11.585199645587377, 10.302781922476631, 7.503167714391436, 2.3226195062909807, 0.15833597018250398, 0.1830399510051523, 9.268392307417733, 56.143820898873464, 32.509370531354634, 36.603405475616455, 24.077630792345317, 0.7438420057296753, 0.1280010850833995, 0.06388785144580261, 0.16277398275477545, 0.10748897825500794, 0.19927270710468292, 0.11479329237980501, 0.1956109521644456, 0.08683036214538983, 0.1580865407096488, 0.14121095410415105, 0.12395164237490722, 0.1733273057533162, 0.14884577585118158, 0.13341964861111982, 0.18115899765065738, 0.0739751158814345, 0.14635866002312728, 0.1648327937083585, 0.11936777191502707, 0.10655067288982016, 0.09091500725064959], [0.08953929785639048, 0.06198921546872173, 0.02532328651951892, 0.025903791887685657, 0.033114286671791754, 0.03269350675067731, 0.017876200145110488, 0.01472101909374552, 0.030762809993965284, 0.0744775982041444, 0.044770860113203526, 0.12117823905178479, 0.05805256563637938, 0.029847683385014534, 0.043106488351311, 0.034779828906591446, 0.033298152698470015, 0.040956774061279635, 0.024700430388163244, 0.03853292823103922, 0.017685287532263567, 0.04355267262352364, 0.05632446925821049, 0.01806283289832728, 0.03583344790552344, 0.06892500365419046, 0.04310905999903168, 0.06864996626973152, 1.2731366668428694, 29.48654283796038, 28.308802332196915, 31.932155881609233, 32.03136226109096, 2.2504192548138753, 0.028628908962543522, 0.04750419594347477, 0.24609935869063648, 1.3944524313722337, 3.610345435994012, 5.003317032541547, 4.5862105914524625, 3.2764838423047746, 6.255664689200265, 3.590112064565931, 0.7574148774147034, 0.1383408731115716, 10.644008823803492, 39.18127053124564, 50.767325673784526, 48.90065390723092, 47.300820759364534, 44.987563950674875, 44.20120504924229, 43.514156750270296, 42.59552846636091, 41.43080888475691, 40.280642305101665, 39.322141783578054, 36.067626408168245, 33.87077971867153, 34.22334173747471, 35.448138918195454, 35.44519635609218, 37.161050524030415, 36.30996567862374, 34.29984835215977, 36.142805916922434, 35.61905765533447, 34.572224685123985, 42.5947641645159, 45.71999093464443, 49.07184362411499, 48.003412178584504, 46.93622098650251, 43.81649718965803, 39.18097870690482, 35.62674583707537, 34.38786118371146, 34.38008267538888, 33.312120233263286, 33.48052372251238, 36.161885670253206, 45.03831706728254, 45.3338691166469, 45.94337204524449, 45.094058990478516, 47.02486263002668, 46.091128962380544, 45.06036370141165, 41.91504621505737, 41.03632490975516, 47.08444690704346, 45.189224992479595, 41.916182245527, 39.42276212147304, 36.914632661002024, 36.816378184727256, 34.54495995385306, 35.44007553373064, 33.14874029159546, 31.818848133087158, 32.89448486055647, 31.965243203299387, 31.286164488111222, 33.388842242104666, 32.034186703818186, 32.93978016717093, 31.677059718540736, 40.4345657484872, 44.223015444619314, 44.55174861635481, 43.999992166246685, 45.63151952198574, 45.25285312107631, 41.758096831185476, 40.25051491601126, 32.08882386343819, 31.49025739942278, 31.31482580729893, 35.866180760519846, 42.50671311787197, 43.414391040802, 41.712853636060444, 41.224780900137766, 43.495556422642295, 41.71762704849243, 41.22253663199288, 40.06822197777884, 38.26463638033186, 35.73123632158552, 36.71706410816738, 36.74852555138724, 40.6203362601144, 42.33806644167219, 40.47452136448452, 21.691160815102712, 6.305201871054513, 0.6272135068263326, 0.9699982702732086, 2.5014724348272597, 4.023839899471827, 4.346453011035919, 5.74995481967926, 3.523313603230885, 4.418914471353803, 2.830695237432207, 0.5623076153653008, 0.054830623524529595, 0.5260474096451486, 21.895448275974818, 33.85974597930908, 31.738137858254568, 27.690839971814835, 4.662376744406564, 0.10039082342492682, 0.03988900421453374, 0.019122153287753463, 0.05724455935082265, 0.043059265706688166, 0.03179444445829306, 0.035931017848529985, 0.04254504133548055, 0.02770094447103994, 0.024604460091463158, 0.055809532425233295, 0.04763004383338349, 0.04705935517059905, 0.028806641032653194, 0.03130748023145965, 0.014042818253593785, 0.04398890617968781, 0.035560028827083964, 0.03785006755164691, 0.023041719304663793, 0.029763792707983936, 0.009178801888733037, 0.023764031706377864, 0.027710813762886182, 0.011177809310278721, 0.04659713711589575, 0.05811160496835198, 0.028053774199049388, 0.01819997330728386, 0.02624039614706167, 0.025383779612768973, 0.029834628371255736, 0.06321352334426981, 0.0769931310787797, 0.04921483700828893, 0.03661808205236282, 0.029858872427472045, 0.03897570286478315, 0.05544593604281545, 0.03908141862068858, 0.05454397301322647, 0.04622360698080488, 0.02643715773176934, 0.04038605486441936, 0.05062911094033292, 0.011030351776363594, 0.05278358515352011, 0.07314536933388029, 0.034367476390408616, 0.05041237667735134, 2.4237049392291476, 36.7590069089617, 28.12347824232919, 38.110681670052664, 34.091440609523225, 1.6958548639501845, 0.11475506371685437, 0.044787287446005006, 0.04881948179432324, 1.2693431675434113, 7.684370653969901, 7.619808861187526, 7.169243369783674, 5.4446770293372015, 6.5202160477638245, 5.574686510222299, 2.144505258117403, 0.21787865300263676, 11.650825381278992, 40.868994917188374, 51.547639642442974, 49.1428542137146, 49.19906514031546, 45.34937054770333, 45.7898759160723, 44.41557087217058, 45.30257095609392, 43.630024909973145, 42.95441681998116, 40.749576228005544, 38.633401598249165, 36.13413109098162, 36.17548329489571, 35.96864237104143, 37.78823661804199, 37.134636947086875, 37.07040779931204, 35.19420657839094, 37.32900932856968, 35.979380811963765, 35.613134316035676, 43.80408770697457, 47.75184222630092, 50.27802310671125, 49.67637511662075, 48.361668246132986, 46.06328058242798, 40.742766993386404, 37.20107562201363, 36.87912041800362, 34.68483413968767, 34.87405790601458, 36.535233225141255, 39.11348043169294, 48.7982166154044, 46.158717564174104, 48.28752054486956, 46.12173925127302, 46.64214195523943, 46.9455246244158, 45.465158803122385, 42.979374749319895, 43.76103319440569, 47.41137702124459, 46.93510232652937, 43.15804072788784, 40.68132407324654, 38.874903610774446, 38.36352661677769, 36.5181302343096, 37.77896424702236, 34.51524598257882, 34.2607091494969, 33.5950265611921, 33.47077192578997, 32.56355953216553, 34.29540845326015, 32.59011902127947, 33.636903354099815, 33.84127071925572, 42.58474833624703, 46.10657828194754, 46.46564728873116, 44.55618504115513, 48.20139414923531, 46.8167849268232, 43.49669940131051, 40.65562616075788, 33.588943413325715, 33.644674914223806, 32.88851983206612, 37.34073093959263, 43.347292287009104, 44.54620047977993, 42.67517566680908, 42.49139928817749, 44.65716668537685, 42.69197988510132, 42.835970878601074, 40.70949901853289, 39.14272539956229, 37.26624277659825, 37.97484786169869, 38.69618204661778, 41.25706570489066, 43.80439690181187, 39.903754643031526, 23.143862383706228, 6.664263495377131, 1.1251644641160965, 2.255650814090456, 3.4691827935831885, 6.531463444232941, 8.435586435454232, 7.478379147393363, 6.195862412452698, 3.6463794452803473, 1.2369710760457175, 0.17512314367507184, 0.03682227359552469, 0.3112850508519581, 22.935353892190115, 45.5808185168675, 30.346323353903635, 32.78233398709978, 7.585427437509809, 0.16060978174209595, 0.013214913928615195, 0.05790285366986479, 0.02276113998544003, 0.11400545894035272, 0.032992764442626915, 0.04456433101690241, 0.045447868428059986, 0.028544947039335966, 0.041493810779814205, 0.012474271751541113, 0.027946879488549063, 0.036995052359998226, 0.027158316623951708, 0.012032496260612138, 0.01938930100628308, 0.03956734129626836, 0.05013594490342906, 0.01790194376371801, 0.026857971579634717, 0.010308030044793018, 0.040319873951375484, 0.18290995726627962, 0.16043056707297051, 0.11746654393417494, 0.11010770952062947, 0.23895251218761715, 0.11109714249947242, 0.10885826870799065, 0.08934726566076279, 0.09360493041042771, 0.12577097117900848, 0.1795030329376459, 0.21431748409356388, 0.15858354046940804, 0.14977702445217542, 0.1473906167915889, 0.08690284325608186, 0.11424264764147145, 0.15347266543124402, 0.12934964629156248, 0.11413747471358095, 0.14140026537435396, 0.14414150613759244, 0.1958163718559912, 0.1645212239984955, 0.14857866375574044, 0.12631287638630184, 0.10715682179267917, 0.14374906862420694, 3.4866503477096558, 45.089031968797954, 37.44117062432425, 41.34775359289986, 39.349420411246165, 3.419949595417295, 0.27484060930354254, 0.30043573730758255, 0.4253547399171761, 6.4046748876571655, 12.959132092339651, 15.402297633034841, 13.29324838093349, 8.400848048073904, 12.27991875580379, 10.711183139256068, 2.943092771938869, 0.4336950480937958, 11.862464036260333, 42.23240865979876, 53.764771597726, 53.22174555914742, 51.993192877088276, 48.35763829095023, 46.931068897247314, 47.3609504699707, 47.59931884493147, 45.50966896329607, 43.92990916115897, 42.84511123384748, 39.32807207107544, 38.647996289389475, 37.077748571123394, 37.47252089636666, 39.781695638384136, 40.48309196744646, 40.10732296534947, 37.737209047589985, 39.37680673599243, 38.240331581660676, 38.30905621392386, 44.66636610031128, 49.295068400246755, 52.24672222137451, 49.817795276641846, 49.891998563494, 47.60447440828596, 42.85664871760777, 38.47586509159633, 38.04565347943987, 37.33765288761684, 36.69004603794643, 37.98934875215803, 39.65396690368652, 49.8923077583313, 48.891854013715474, 48.78257622037615, 48.89853818075997, 48.72293288367135, 46.689059666224885, 46.78700147356306, 43.4376779283796, 44.339064257485525, 49.362674372536794, 48.93002046857561, 45.31253467287336, 42.47626611164638, 41.11025374276297, 40.06815596989223, 39.153512477874756, 39.54263939176287, 37.28714990615845, 36.21951402936663, 34.70435857772827, 35.213779653821675, 33.90707015991211, 35.778522287096294, 34.97951071602957, 35.232814243861604, 35.30836548124041, 43.94440310341971, 47.61546645845686, 48.44961506979806, 46.47744880403791, 47.66535105024065, 48.184992926461355, 47.03976304190499, 43.262440885816304, 34.93465314592634, 35.02379853384835, 34.36140244347708, 38.39305993488857, 45.68662221091134, 47.88448681150164, 43.61625010626656, 42.05554573876517, 44.826810428074424, 45.475456033434185, 44.729500906808035, 42.786364214760916, 41.565850598471506, 38.94944041115897, 40.79387446812221, 39.38403286252703, 44.85470049721854, 44.63795491627285, 42.0403048651559, 23.389198064804077, 7.836353812898908, 1.9012781381607056, 3.1776580938271115, 6.728497854300907, 8.4768648147583, 12.47763843195779, 13.046621203422546, 8.223953860146658, 10.804275972502571, 6.511380544730595, 0.9469009382384164, 0.2131992176707302, 1.043154007622174, 27.94244119099208, 43.657515457698274, 37.64268922805786, 40.29900639397757, 9.321612903050013, 0.24381931817957334, 0.12554045926247323, 0.19780008255371026, 0.11605106560247284, 0.1949567494115659, 0.1410289438707488, 0.154256848352296, 0.19138799448098454, 0.1191477637205805, 0.17904791235923767, 0.10372069331684283, 0.1842238860470908, 0.08374061222587313, 0.08729780491973672, 0.12623987958899566, 0.10460654792508908, 0.08628838908459459, 0.1818650947617633, 0.08798159858477966, 0.12531106014336857, 0.10871317756495305, 0.14257780861641678], [0.03655905968376568, 0.033415522293320725, 0.04377379361540079, 0.07702767529657908, 0.013812985720245965, 0.019950401969254017, 0.0882426852892552, 0.029483143838920763, 0.046031154093465636, 0.05748388543725014, 0.10011515500290052, 0.022868100853104676, 0.048829374834895134, 0.08788511769047805, 0.0111310311060931, 0.04888131329789758, 0.05820174156022923, 0.028911345771380832, 0.03044745745137334, 0.026573962265891687, 0.04434841099594321, 0.03284349352387445, 0.05360185767390898, 0.039756269194185734, 0.09236348274030856, 0.022243304111595665, 0.015258218660684568, 0.0836245555962835, 0.16770731231995992, 17.138862643923076, 31.14296211515154, 26.537694352013723, 35.46061093466622, 15.279710565294538, 0.13768128279064382, 0.09436600242874452, 0.24533945375255176, 0.31747524440288544, 5.758727354662759, 4.931586870125361, 4.51476617370333, 8.205403906958443, 4.076071245329721, 4.126742286341531, 2.2850060846124376, 0.10367080742227179, 2.812180459499359, 24.47673010826111, 50.51418890271868, 51.856553077697754, 50.30105638504028, 45.70090423311506, 44.246357917785645, 40.76830857140677, 40.54045282091413, 37.33531829289028, 38.010679721832275, 36.29062189374651, 37.098322187151226, 37.726008551461355, 40.53838225773403, 40.918980257851736, 42.813392707279746, 43.63219274793352, 45.19913312367031, 40.856689657483784, 35.172291960035054, 36.01515361240932, 36.036217076437815, 43.59036806651524, 46.76914807728359, 47.81205184119088, 48.4909360068185, 47.838496685028076, 43.56709507533482, 38.87223202841622, 35.517641748700825, 33.45766762324742, 33.71699871335711, 34.4321003641401, 34.36737789426531, 36.03080790383475, 44.64110939843314, 44.69152900150844, 47.27767630985805, 44.52394887379238, 46.02046230861119, 45.33621760777065, 46.295756884983604, 43.00935622623989, 41.07754162379673, 48.02389546803066, 43.36480174745832, 43.77241434369768, 40.95112609863281, 39.37150526046753, 36.841683523995535, 36.162931374141145, 34.30395821162632, 35.27420118876866, 33.93525900159563, 32.616664613996235, 30.83438914162772, 32.07158885683332, 32.34533745901925, 33.796559061322895, 32.21473911830357, 32.693435260227744, 35.38417380196707, 42.19498218808855, 43.55461958476475, 45.45128672463553, 42.3565799168178, 46.0702565738133, 44.08084487915039, 40.71545362472534, 38.78231539045061, 33.6171635219029, 32.32744237354824, 32.144308703286306, 35.89977877480643, 41.494332790374756, 43.69009556089129, 42.431307792663574, 41.343476976667134, 41.67690713065011, 42.48057052067348, 42.670992851257324, 40.003919873918804, 39.95197514125279, 38.705329350062776, 41.34991795676095, 41.14762462888445, 43.02551078796387, 34.232485566820415, 13.846285036631993, 2.346204080751964, 0.4092575822557722, 0.820825603391443, 1.8910753599234988, 6.181227769170489, 8.46951448917389, 4.859694293567112, 6.333881863525935, 2.821739877973284, 0.9254969039133617, 0.04521212161385587, 0.053045333429638825, 4.189492336341313, 33.216162136622835, 19.579671008246287, 23.960055112838745, 22.118664366858347, 0.2619917887662138, 0.04361844641555633, 0.04250848526135087, 0.0077199185200567755, 0.021282155865005085, 0.006641098306447799, 0.026139350408422093, 0.04281638748943806, 0.01827783520067377, 0.01509254246151873, 0.060958106869033406, 0.08124762028455734, 0.07242629184786763, 0.03700748312153986, 0.048940685112029314, 0.05247862437473876, 0.008730930608830281, 0.045585556754044125, 0.060906395715262206, 0.03773567333285298, 0.07764862983354501, 0.015129531101722802, 0.017174988486138836, 0.017093450629285405, 0.056514289429677386, 0.05188149320227759, 0.10571165755391121, 0.061472782466028414, 0.013863333018629678, 0.04365745878645352, 0.04895410653469818, 0.06665622682443686, 0.010497408320329018, 0.015384965609493, 0.030771926111940826, 0.07085270807147026, 0.021174513069646697, 0.00756804457133902, 0.012149993928947618, 0.06849726874913488, 0.052199790586850474, 0.046307962454323254, 0.04106395206015025, 0.024393934423902204, 0.06277100316115788, 0.01149723306298256, 0.004910761066379824, 0.09009189677557775, 0.0045322933167751345, 0.005588106104239289, 0.11156370317829506, 0.3031650222837925, 24.188341651644024, 36.47405086244856, 30.240109716142925, 41.751690592084614, 14.246621131896973, 0.14238973227994783, 0.22411972310926231, 0.08580624924174376, 0.31511301973036354, 3.7488597290856496, 5.02857677425657, 4.975375720432826, 6.0554362790925165, 6.157189607620239, 6.175741732120514, 5.480310865810939, 0.7251669306840215, 3.7441840256963457, 27.705481563295635, 51.60843638011387, 52.39680331093924, 52.280323709760395, 47.73007352011544, 46.01725918906075, 41.236783913203645, 43.262691020965576, 39.11014182226998, 38.6648838860648, 38.531912735530305, 38.61033705302647, 37.76724263599941, 40.77592032296317, 40.89194481713431, 44.76940441131592, 45.40798555101667, 45.40933697564261, 41.38949837003435, 36.52523824146816, 37.16676194327218, 37.077151026044575, 44.982081821986604, 49.19409023012434, 48.813547815595356, 50.05405139923096, 49.504799774714876, 46.07181297029768, 41.11563164847237, 37.278151988983154, 34.95426096235003, 35.475810119083945, 35.52697317940848, 35.699493476322715, 36.89690433229719, 44.89133487428938, 46.12694345201765, 48.09927647454398, 47.4488000188555, 47.81551204408918, 46.02096257890974, 45.88523299353463, 42.960447856358115, 43.0824408531189, 49.21603264127459, 45.526660782950266, 45.42085708890642, 42.829144273485454, 39.804968629564556, 39.192425864083425, 37.121397154671804, 37.17493649891445, 35.80559246880667, 34.451548371996196, 35.52255065100533, 33.140444142477854, 33.66764218466622, 32.96023218972342, 34.79906252452305, 34.342472076416016, 33.179795265197754, 38.31004285812378, 45.31090184620449, 45.059328419821604, 46.23723220825195, 43.88670526232038, 47.52815539496285, 43.78587300436837, 43.447183064052034, 39.55741821016584, 35.03427641732352, 33.80417081287929, 33.73847906930106, 37.45049510683332, 43.395672593797954, 45.06301096507481, 43.43117788859776, 43.98137099402291, 42.195670059749055, 43.102205004010884, 43.357367174965994, 41.620779582432334, 41.732395444597515, 39.84372568130493, 41.153502804892405, 43.08796467099871, 43.181636810302734, 35.051990849631174, 14.954637357166835, 3.3362346589565277, 1.0050412927355086, 2.7565551357609883, 3.5990867487021854, 6.1505831735474725, 6.6322826743125916, 6.412627535206931, 6.779243588447571, 1.4229791292122431, 0.66023921753679, 0.04382466338574886, 0.029869362578860352, 3.972503568444933, 37.60791349411011, 25.287447656903947, 28.89265251159668, 27.48701630319868, 0.679977855512074, 0.04006948095879384, 0.056156687904149294, 0.03201470710337162, 0.04791731520422867, 0.06417274115873234, 0.055562705134174654, 0.029446445272437165, 0.04093474202922412, 0.008812223344908228, 0.04423899383151105, 0.04867708443530968, 0.042390091078622, 0.06327349905456815, 0.030210214467453103, 0.01953927760145494, 0.04142468163211431, 0.03961740360994424, 0.03721079596185258, 0.048646886234304736, 0.034062695423407216, 0.01972048377086009, 0.03109769755974412, 0.15775105942572865, 0.14470914139279298, 0.21403981399323257, 0.24509412263120922, 0.14217992925218173, 0.1319430207035371, 0.1424316657441003, 0.15448098203965596, 0.1401677472250802, 0.15337661201400415, 0.14717059502644197, 0.1507248700197254, 0.19696062617003918, 0.17311702775103704, 0.10939048443521772, 0.11708136674548898, 0.13586506167692797, 0.15747850547943795, 0.10960888450167008, 0.09653034593377795, 0.13816558037485394, 0.17051958212895052, 0.1020219808976565, 0.1523700188845396, 0.17013635912111827, 0.14047824484961374, 0.10479905509522983, 0.2854003241019589, 0.4980949152793203, 27.26156462941851, 44.7045499256679, 35.20758533477783, 44.04942512512207, 19.911994661603654, 0.2744604939860957, 0.49500160983630587, 0.46430061438253944, 1.8695155339581626, 14.247388907841273, 12.707622936793737, 12.500532746315002, 17.039407866341726, 10.940533620970589, 9.97333742891039, 7.222057061535971, 0.7532192511217934, 3.6528408357075284, 26.293281044278825, 52.57231828144619, 55.97125891276768, 54.86652660369873, 49.10916587284633, 49.179551124572754, 43.12154531478882, 45.242854663303916, 40.096747807094026, 40.70122718811035, 40.397392886025564, 40.75070183617728, 41.21452535901751, 44.42833818708147, 44.025332246507915, 46.84294836861746, 48.60127340044294, 48.64004782267979, 45.16372857775007, 38.1010479927063, 39.818482875823975, 38.546601227351594, 47.12779671805245, 50.05366924830845, 49.6335950578962, 51.60500397000994, 51.800807680402485, 47.32386793409075, 42.006185735974995, 38.154236452920095, 35.91096190043858, 36.64407328196934, 38.27503088542393, 37.72517476763044, 38.740334374564036, 47.629706791469026, 47.3066086087908, 49.61199310847691, 48.747369698115754, 48.42510529926845, 46.879318714141846, 47.77694606781006, 43.67608451843262, 44.987126214163645, 51.23269517081124, 46.15622663497925, 47.143923486982075, 46.31191144670759, 43.42502873284476, 41.18590572902134, 40.38508415222168, 38.24330888475691, 38.465279511043, 36.28653982707432, 36.252980027879985, 35.77610083988735, 35.10442543029785, 34.00443526676723, 37.022301946367534, 36.638236795152935, 35.26758650371006, 39.11324419294085, 45.73372057506016, 47.546630655016216, 46.941188948495046, 44.909973417009624, 47.25598750795637, 44.90130206516811, 45.195082323891775, 41.59516157422747, 37.40399776186262, 36.04983901977539, 35.59903989519392, 38.61936971119472, 45.63957943235125, 47.53846304757254, 45.461959157671245, 44.399760246276855, 43.33485501153128, 43.87214878627232, 46.5523225920541, 43.6439664704459, 43.06863130841936, 42.75662245069231, 43.78993075234549, 45.05173751286098, 44.8727901322501, 35.931855133601594, 15.24077980858939, 2.7915013177054266, 1.6534450139318193, 3.4638793638774326, 5.66662073135376, 13.467745440346853, 14.686105115073067, 14.43812564441136, 11.752950872693743, 5.131385360445295, 2.2098376495497565, 0.30988602020910805, 0.2712856557752405, 6.983235316617148, 41.936682905469624, 27.050014563969203, 33.9698679787772, 33.197415896824424, 1.0985556862183978, 0.18985194047646864, 0.13149581184344633, 0.0718037291829075, 0.14454418952975953, 0.1657558320356267, 0.12674888941858495, 0.1642603272838252, 0.07657971326261759, 0.08377262550805296, 0.10506538687539951, 0.11947781672435147, 0.15692435950040817, 0.1294243937092168, 0.0850457539781928, 0.1411984690598079, 0.09220418307398047, 0.16766046626227243, 0.1662553966577564, 0.1925924348511866, 0.1815149706921407, 0.10182920231350831, 0.06851944327354431], [0.024378596139805656, 0.02522069711371192, 0.03196767105587891, 0.04405194886827043, 0.022635746713993803, 0.0703123499240194, 0.031147987182651247, 0.060656986598457606, 0.010849636696678187, 0.022704690960901122, 0.03674737011481609, 0.03303536626377276, 0.01713387096034629, 0.03415378535698567, 0.06528703136635677, 0.023776019723819833, 0.09762124703930956, 0.045963409157203775, 0.02702345948533288, 0.024731559878481284, 0.0396330879469003, 0.012751248897984624, 0.05075415815891964, 0.006928244996483305, 0.03948642260261944, 0.02043174622979547, 0.03563168551772833, 0.06199730360614402, 0.10157335389937673, 4.044934630393982, 25.957518032618932, 26.642699003219604, 29.685796328953334, 31.76077856336321, 2.676135165350778, 0.13423942747925008, 0.1034360071644187, 0.09781271605087177, 2.918858758040837, 3.2198744799409593, 3.6083100480692725, 2.9149779719965796, 4.930264975343432, 4.645785748958588, 2.73371228149959, 0.7517448759504727, 0.2527815986956869, 11.69699616091592, 45.68743862424578, 51.53659200668335, 52.79715503965105, 48.388679368155344, 46.68652704783848, 43.169553892953054, 41.13862323760986, 41.91962507792881, 43.35104431424822, 42.54731144223894, 41.13371433530535, 43.11178656986782, 43.67316974912371, 45.11315611430577, 48.94776964187622, 47.003444807870046, 48.793700286320274, 47.383605071476524, 38.453193119594026, 35.203909737723215, 36.85699735369001, 41.404051371983115, 47.6121278490339, 47.79183953148978, 48.44956990650722, 47.61436169488089, 46.53208943775722, 42.43786341803414, 37.22212866374424, 36.088842732565745, 34.09692621231079, 33.720445019858225, 35.325246129717144, 36.4587196622576, 42.74807269232613, 44.72619009017944, 46.28665821892874, 44.36139924185616, 46.30018983568464, 46.824848311288015, 46.47809498650687, 43.28679779597691, 41.18746559960501, 46.30173233577183, 44.53488881247384, 43.09563895634243, 42.30357558386666, 37.862217562539236, 36.5760886328561, 36.72068759373256, 34.08454104832241, 35.43893950326102, 32.32099444525582, 30.88710512433733, 32.66773387363979, 31.688597202301025, 32.11152015413557, 32.94473423276629, 32.6386695589338, 34.502197265625, 33.57114560263497, 37.09917334147862, 42.91576051712036, 45.45565019335066, 45.110581806727815, 41.641978536333355, 45.62994228090559, 42.466208594185964, 41.14917755126953, 40.58211421966553, 39.1482492174421, 35.56951699938093, 32.146775313786094, 33.310737541743684, 37.75836978639875, 40.730051789964946, 40.97430528913225, 42.78838961465018, 42.95143256868635, 44.33395733152117, 44.03262438092913, 41.06585127966744, 40.09459733963013, 39.98819957460676, 42.84715747833252, 40.494636399405344, 26.78744908741542, 8.71840330532619, 0.9802803014005933, 0.7790876658899444, 2.4275199345179965, 3.604799904993602, 4.244059145450592, 6.037873404366629, 4.581980441297803, 6.1093043599809915, 1.1101343163422175, 0.4459852714623724, 0.08586294762790203, 0.13478780591062137, 15.925743647984095, 35.05167123249599, 20.634600366864884, 28.39930956704276, 11.695891397339956, 0.07013321667909622, 0.08733329908656222, 0.068884780098285, 0.03431016732273357, 0.07006023345249039, 0.04073744100917663, 0.028574571878250157, 0.010866179380432835, 0.0393936702582453, 0.037701933179050684, 0.03229912184178829, 0.005922067893802055, 0.019753681096647466, 0.05119413383571165, 0.05925970657595566, 0.033268460006053956, 0.04449011964191284, 0.03313008975237608, 0.046153497350003035, 0.07269659305789641, 0.03167905279302171, 0.04880778045792665, 0.038294233182179074, 0.07101847417652607, 0.022803794393049817, 0.01508733131257551, 0.018527315563655326, 0.04920801094600132, 0.028299775373722826, 0.05286447670576828, 0.006240987410170159, 0.03291472613013216, 0.0253415950906596, 0.058047612330743244, 0.0285491471711014, 0.06248004734516144, 0.0818471670416849, 0.08241048002881662, 0.029628133201705556, 0.04899983640227999, 0.03570045504186835, 0.041216079611331224, 0.050654355835701735, 0.0337771984216358, 0.007530669166174318, 0.02771098678931594, 0.054329857895416875, 0.005290815739759377, 0.05605489068797656, 0.06918066207851682, 0.08008900138416461, 0.09714797564915248, 6.471195638179779, 34.25662708282471, 27.34490306036813, 35.33386189596993, 34.33182743617466, 2.476317350353513, 0.11124021160815444, 0.030104498711547682, 0.021221762855670283, 0.1496934425085783, 2.4757706139768874, 5.24070006608963, 5.39870514188494, 5.278392740658351, 8.260223456791469, 6.325057651315417, 1.3949625811406543, 0.41047631257346695, 14.31884765625, 45.40051623753139, 51.67836652483259, 53.29501778738839, 50.271335465567454, 46.856764861515586, 44.4710487638201, 43.27363790784563, 43.47183179855347, 44.69077164786202, 42.54790898731777, 41.95236151559012, 44.7776380266462, 45.25318316050938, 45.917542116982595, 49.79341752188546, 48.35207973207746, 49.77136046545846, 48.75548866816929, 39.49455090931484, 37.24858740397862, 37.41330834797451, 44.06542682647705, 48.70730985913958, 49.07440403529576, 50.53658989497593, 49.53553860528128, 48.06901012148176, 43.59587103979928, 38.49956887108939, 37.03602463858468, 35.8439291545323, 36.31261989048549, 36.01852348872593, 36.256975242069785, 44.5164726121085, 47.21023709433419, 46.95949397768293, 47.19108438491821, 46.56433950151716, 48.37011725561959, 46.55294445582798, 42.277665751320974, 42.98599290847778, 49.705887590135845, 46.11781699316842, 44.24532263619559, 45.40603310721261, 39.767417090279714, 39.83219861984253, 38.19445262636457, 36.4828577041626, 37.28360979897635, 34.54655803952898, 33.720059394836426, 33.19880206244332, 32.15113183430263, 33.501569816044395, 33.95017678397042, 34.93556683404105, 35.44499485833304, 34.92568302154541, 41.162987095969065, 45.03924117769514, 47.31657927376883, 45.16892235619681, 43.706354345594136, 48.20185273034232, 43.2672837802342, 42.58596427100045, 41.63951192583357, 39.234976632254465, 35.37796211242676, 33.33772781917027, 36.001684529440745, 39.79675585883004, 42.87517956324986, 42.190688201359336, 43.156074387686594, 42.686772210257395, 45.241242681230815, 43.80139528002058, 43.31241580418178, 41.6314902305603, 40.92867646898542, 42.83391421181815, 42.60625648498535, 28.44358696256365, 11.41327863080161, 2.327985469784055, 1.3372689740998405, 3.718730168683188, 2.711381205490657, 5.197175681591034, 7.492484859057835, 5.91866055556706, 5.524741121700831, 0.1638601544712271, 0.40384170572672573, 0.0268965106723564, 0.12826137111655303, 15.564300094332014, 40.269615513937815, 20.05777481624058, 31.712040424346924, 16.015415361949376, 0.02488237276806363, 0.06445564954940762, 0.04139914157401238, 0.025804042150931697, 0.050466215038405995, 0.01398690018270697, 0.017474546429834197, 0.01874860279661204, 0.06232995539903641, 0.013383739378436335, 0.03632145368361047, 0.04078654658847621, 0.02127782002623592, 0.05396422590794308, 0.0525693716481328, 0.028013759292662144, 0.043081565760076046, 0.044419453612395694, 0.029926756463412727, 0.009367779828608036, 0.045695798338523934, 0.0339176653485213, 0.018069100865562047, 0.09851336452577795, 0.14925588241645268, 0.0939187528565526, 0.1927765485431467, 0.18138177426798002, 0.23920704424381256, 0.09569247053670031, 0.0825722970600639, 0.12915829941630363, 0.13179851988596575, 0.09264040645211935, 0.08955935535154172, 0.10249667721135275, 0.17912322974630765, 0.14677028650684015, 0.15360548187579426, 0.23935816756316594, 0.16349831888718264, 0.12343090746019568, 0.1065676701920373, 0.14935509780687944, 0.14343486619847162, 0.21259981340595654, 0.20269249645727022, 0.24609642741935595, 0.17985733678298338, 0.14686899978135312, 0.1521456137831722, 0.2455892360636166, 8.544999718666077, 41.59784010478428, 35.03611421585083, 38.76257903235299, 40.83863476344517, 4.431437730789185, 0.3157042408628123, 0.20747624976294382, 0.44558767708284513, 5.578089824744633, 10.452695386750356, 11.876775588308062, 9.131106325558253, 12.413967745644705, 12.62154517854963, 6.811533604349409, 1.7760468465941293, 0.6447907122118133, 13.847389800207955, 47.177726473127095, 54.734368392399375, 56.24871437890189, 52.3964524269104, 50.124520029340474, 47.68129716600691, 44.69301244190761, 47.09208992549351, 47.94071510859898, 46.14679445539202, 44.615606035505024, 47.06701735087803, 47.60456126076834, 47.429970400674, 53.479725224631174, 50.64716352735247, 53.20228712899344, 50.77351999282837, 42.92296232495989, 38.5261561529977, 39.680345739637104, 44.57295451845442, 51.661322593688965, 49.96604551587786, 51.09977265766689, 51.95123617989676, 49.49544749941145, 45.23854330607823, 41.10566445759365, 39.20627709797451, 36.981158188411165, 38.70360967091152, 39.46623352595738, 38.61944614137922, 45.44117709568569, 47.25192975997925, 48.25981460298811, 49.56534290313721, 48.22414255142212, 50.03685113361904, 47.426947934286936, 43.330151081085205, 45.34333951132638, 49.56606204169137, 48.901630129132954, 46.6136508669172, 47.172494479588096, 41.82915258407593, 41.485310554504395, 39.890813623155864, 38.20559753690447, 39.05989245006016, 35.78116260256086, 34.84951686859131, 34.69335610525948, 33.57654782703945, 35.40847512653896, 35.31770733424595, 37.297857080187114, 37.748089926583425, 36.54307426725115, 42.14607381820679, 45.74696036747524, 49.30207218442644, 46.80298580442156, 44.36148956843785, 47.264849935259136, 46.42474324362618, 44.51248434611729, 43.0802834374564, 43.1595276423863, 39.14005381720406, 34.436043466840474, 36.87301295144217, 40.95620175770351, 44.085805892944336, 43.340232917240684, 45.298207487378804, 44.65081255776541, 46.009209700993125, 46.78355169296265, 44.398009300231934, 43.01972641263689, 42.56432063238961, 45.43072700500488, 43.72781733104161, 28.235910517828806, 10.779215557234627, 1.8901577634470803, 2.3845844098499844, 6.640962711402348, 7.776531560080392, 10.835263201168605, 12.651947890009199, 11.870699388640267, 11.744865775108337, 3.645406263215201, 1.1218171694449015, 0.18110394131924423, 0.6098978902612413, 21.601289340427943, 43.273519788469585, 27.483365024839127, 39.3948928969247, 18.474636452538626, 0.14488211353974684, 0.08410445627357278, 0.13226510770618916, 0.11765961428838116, 0.24748101883700915, 0.08782644476741552, 0.14388492490564073, 0.08977275461490665, 0.11685928223388535, 0.15691044953252586, 0.12328245756881577, 0.10484252204852444, 0.13438589604837553, 0.1879470076944147, 0.13820458256772586, 0.10420595442077943, 0.10499045625329018, 0.09881347377917596, 0.1680843470884221, 0.14201819364513668, 0.11971339051212583, 0.23186152268733295, 0.18406923434564046], [0.05845966629151787, 0.03099141861977322, 0.03632168438551681, 0.05119512449683888, 0.025251768928553377, 0.045490521139332225, 0.050386673770844936, 0.07310617715120316, 0.06412973560925041, 0.06139089007462774, 0.010238803357684186, 0.0889440258698804, 0.05225131853616663, 0.018773466016032865, 0.025141549396461675, 0.034641842025199106, 0.031757620362831016, 0.03954729737181749, 0.017366866315049783, 0.032031154792223654, 0.04731914248051388, 0.030620378708200793, 0.06774745362677745, 0.06713854987174273, 0.08153697475790977, 0.024821504784215773, 0.05544454843870231, 0.030458575247653892, 0.04968626956854548, 0.2321054967386382, 19.506798301424297, 32.517506871904644, 25.557758637837, 36.659202984401155, 13.982972604887825, 1.0556457830326897, 0.029447171304907118, 0.17781795907233441, 0.49102794591869625, 2.325268507003784, 2.5285604212965285, 4.014124580792018, 3.012673769678388, 5.205025843211582, 7.277088097163609, 1.4873225965670176, 0.19672347818102154, 1.6114491245576312, 30.129480498177664, 52.8135666847229, 52.263404846191406, 50.96928201402937, 47.25408717564174, 47.923827511923655, 47.47130175999233, 47.772791045052664, 46.40802240371704, 47.99433435712542, 46.99753189086914, 46.4733042035784, 49.05120052610125, 49.94649675914219, 46.942759241376606, 47.11128779820034, 47.34346185411726, 46.43022189821516, 40.79278360094343, 35.283675057547434, 36.48909023829869, 41.89135980606079, 48.6431918825422, 48.14516237803868, 47.17686142240252, 46.2512640953064, 48.93423107692173, 44.854099478040425, 39.76563140324184, 36.42372506005423, 34.87285239355904, 34.04424844469343, 34.59821442195347, 35.069413457598, 42.251040254320415, 47.68787363597325, 47.304885455540244, 44.9255929674421, 45.76646743501936, 45.19623225075858, 45.10989740916661, 43.25852905000959, 40.581426348005024, 50.564101287296836, 44.51005595070975, 46.18359906332833, 41.47199085780552, 41.202167987823486, 39.16606787272862, 36.328604221343994, 34.125382559640066, 32.613628251211985, 31.762890815734863, 31.423558167048864, 31.65819535936628, 33.06819677352905, 32.84721279144287, 32.89003453935896, 33.2098844391959, 33.209217412131174, 34.202688217163086, 36.99928951263428, 40.83033166612898, 43.22426748275757, 46.6523870740618, 44.63731568200247, 41.20067759922573, 45.290977886744905, 42.927280630384175, 41.95766299111502, 43.03446354184832, 42.669648374829976, 40.356634753090994, 38.96145732062203, 36.72162560054234, 39.18959099905831, 40.092297485896516, 40.48476995740618, 42.41891915457589, 42.046349797930034, 42.0496050289699, 42.10388435636248, 42.387471607753206, 42.38144751957485, 41.815523692539756, 35.058397088732036, 17.141711405345372, 4.2876768963677545, 1.1598070966345924, 0.6206685208848545, 2.7010138417993272, 1.8435976675578525, 1.661222219467163, 4.71745468037469, 4.114190365586962, 4.581013338906424, 0.12596125953963824, 0.33318430717502323, 0.033000889899475236, 2.4906779740537917, 30.531232288905553, 27.72121923310416, 20.383822509220668, 24.685453993933542, 2.460916668176651, 0.05150443807776485, 0.04201841673680714, 0.010652657132595778, 0.06947489521865334, 0.045487494873149056, 0.030738562545073882, 0.01036101345172418, 0.08343181093888623, 0.04435230239427515, 0.060043828428855965, 0.013587917350897831, 0.01956056324498994, 0.047942675450550656, 0.04377782750608666, 0.06496636250189372, 0.006674841004756412, 0.05223112872668675, 0.029713866101311784, 0.05168558996436851, 0.03350096003019384, 0.032582881793911965, 0.03814479262967195, 0.022050009840833287, 0.015308160534394639, 0.056328652426600456, 0.00686185246533049, 0.06997881603560277, 0.0630459048386131, 0.018942258387271847, 0.013544446156759347, 0.04192338790744543, 0.03509865554847887, 0.047498536961419244, 0.0250069670645254, 0.048735333273985555, 0.012359882621759815, 0.02810998403999422, 0.03671815239691308, 0.05661481100001505, 0.035284557180213075, 0.057015139875667434, 0.05558660313753145, 0.011587315372058322, 0.08926732745021582, 0.009683401240701122, 0.03163898190749543, 0.019504579016938806, 0.07218275205897433, 0.026743048103526235, 0.018032037586505924, 0.025906217650377324, 0.08929495061082499, 0.5509169665830476, 25.711291245051793, 35.89491156169346, 27.863971710205078, 42.49432447978428, 15.369889497756958, 0.8444799855351448, 0.07855435194713728, 0.030813058904771293, 0.26614700151341303, 1.2651643689189638, 4.0865738817623685, 6.1962736589568, 5.879165257726397, 5.949984771864755, 7.134299142020089, 3.8632005878857205, 0.48726533353328705, 2.678076752594539, 32.51775005885533, 53.36980472292219, 52.332476888384136, 53.21535669054304, 48.02718544006348, 49.269582407815115, 48.93115997314453, 49.04044124058315, 48.917597089494976, 48.228478227342876, 46.91236087254116, 47.851976190294536, 51.437125069754465, 50.95227977207729, 49.31018073218209, 49.326693126133506, 49.047837597983225, 48.256142480032786, 41.27337312698364, 36.49352666309902, 38.18644135338919, 43.41762890134539, 49.77055447442191, 50.18939535958426, 46.2880791255406, 49.210578305380686, 50.800037792750764, 45.24957357134138, 41.468683515276226, 38.38798080171858, 36.63247326442173, 36.307770047869, 36.6147449357169, 36.64428172792707, 44.618975911821636, 48.887789317539756, 48.50072601863316, 47.719196115221294, 46.240296363830566, 45.77987051010132, 45.83302075522286, 43.92190831048148, 41.60688318525042, 50.15343843187605, 47.29552623203823, 47.277839592524934, 43.91931663240705, 42.69784416471209, 41.53650140762329, 39.976179191044395, 37.12735870906285, 35.8591422353472, 32.2888103893825, 33.50034345899309, 33.83750132152012, 34.48221772057669, 32.959276812417166, 34.26633371625628, 34.962637015751426, 34.34612682887486, 34.62046602794102, 38.912343978881836, 44.102860246385845, 45.10557215554373, 46.849879196711946, 44.97318465369088, 42.340658119746614, 46.77581139973232, 45.16352013179234, 44.03320802961077, 44.44252988270351, 42.521321705409456, 41.451566628047395, 38.58009154456002, 37.05964503969465, 41.100713866097585, 42.287716320582796, 43.704877853393555, 42.5154504776001, 43.338322162628174, 42.70932953698294, 43.72602469580514, 43.32472801208496, 43.38056026186262, 43.38561855043684, 37.37489175796509, 17.742739268711635, 5.515769694532667, 1.659258484840393, 2.166897347995213, 2.8631726375647952, 3.6551476376397267, 4.631521531513759, 4.533077282564981, 4.506960306848798, 2.2878791647297994, 0.12192126203860555, 0.2914123614983899, 0.09001071684594665, 2.051937882389341, 33.76221758978707, 31.222310543060303, 21.54388506071908, 31.07241358075823, 4.034741188798632, 0.058797305316797326, 0.013852203347986298, 0.028344792779535055, 0.08084265701472759, 0.012940727257435876, 0.06519126293382474, 0.09935947733798198, 0.04873165561418448, 0.04290094991613712, 0.017369018967396448, 0.09972759615629911, 0.004110584226769528, 0.03083822237593787, 0.022978237264656594, 0.030560111227844442, 0.021163856677178825, 0.04743499554959791, 0.024983063972155963, 0.02097102889924177, 0.058017811072724204, 0.025370419258251786, 0.029155964430953776, 0.031338173763028214, 0.10305819886603526, 0.13438172984336103, 0.0903819976374507, 0.12382907180913857, 0.24252578616142273, 0.11812918766268662, 0.1693829409778118, 0.11366735851126057, 0.1843766514211893, 0.16246401438755648, 0.12385067636413233, 0.15097109680729254, 0.17337533246193612, 0.1322451587766409, 0.10502168243484837, 0.21969370703612054, 0.11163315802280392, 0.11697882653347083, 0.1107223876086729, 0.15545401482709817, 0.19096578285098076, 0.12990900341953548, 0.13750254309603147, 0.1720283454550164, 0.13502981221037252, 0.19136343151330948, 0.13917502335139684, 0.09915002714842558, 0.21910654354308332, 0.7171836133514131, 33.27079234804426, 46.03558506284441, 34.516187463487896, 46.19794014522007, 21.359613622937882, 1.476953170129231, 0.18704914301633835, 0.2910920115453856, 1.0618006927626473, 6.041953299726758, 9.732709152357918, 11.797823207718984, 9.774308017321996, 13.272552302905492, 15.548560687473842, 4.576935614858355, 0.35678522075925556, 2.240696987935475, 32.08114610399519, 55.54270792007446, 55.02529294150216, 55.503117084503174, 51.621877670288086, 51.63607631410871, 51.66680472237723, 51.520295006888254, 51.17538642883301, 51.00350884028843, 50.06207309450422, 50.08853530883789, 53.64499160221645, 52.977193287440706, 50.44903564453125, 50.61827639171055, 49.50028344563076, 50.495439188820974, 43.67794663565499, 39.5952650478908, 39.79922941752842, 46.121999808720176, 52.87201493127005, 51.75783307211739, 48.935047490256174, 47.93610497883388, 54.784926959446494, 47.73427023206438, 44.7874801499503, 41.871724196842735, 37.80093445096697, 37.62600660324097, 38.36922761372158, 38.506711619240896, 46.37557084219796, 51.36679540361677, 50.44812543051583, 48.580668517521445, 47.92790610449654, 45.509182589394705, 47.11926780428205, 44.134134088243755, 43.94261046818325, 51.68046835490635, 49.151424816676546, 49.59088100705828, 45.701335021427695, 44.85768474851336, 44.72471359797886, 41.917749064309255, 37.57288415091378, 37.71220595496041, 34.23363896778652, 35.20478868484497, 35.233689716884065, 36.59981325694493, 35.067408902304514, 35.5627772467477, 36.91907950810024, 36.73519195829119, 35.83660575321743, 41.50936869212559, 44.85923419679914, 46.27629498073033, 50.09337820325579, 46.127957889011924, 41.530654498508994, 47.50319051742554, 47.464075633457725, 44.99969203131539, 46.067744800022666, 45.12728180204119, 44.918095861162456, 42.38629388809204, 39.05620295660836, 41.833196435655864, 44.258114269801546, 44.326852798461914, 45.10377952030727, 45.478721686771934, 41.274877411978586, 43.10327155249459, 45.06461252485003, 44.66602911267962, 44.71535437447684, 37.99197864532471, 18.785264355795725, 5.710731370108468, 2.664965501853398, 2.4859427767140523, 5.70589542388916, 7.269744285515376, 8.944562826837812, 10.71414828300476, 12.701790792601448, 9.762751426015582, 1.080980977841786, 0.8997585507375854, 0.2382512055337429, 4.035482040473393, 39.65792390278408, 37.281546183994834, 28.714717830930436, 36.82147468839373, 4.3960210255214145, 0.18148743574108395, 0.11844523570367269, 0.16128701397350856, 0.1356668887393815, 0.08063543242003236, 0.21814595508788312, 0.25876576187355177, 0.15232879109680653, 0.17020162061921187, 0.09239249011235577, 0.12338657198207718, 0.16816890612244606, 0.1488187023039375, 0.07160573944981609, 0.12091308113719736, 0.17070018100951398, 0.12403834557959012, 0.07608183140733413, 0.1316211779734918, 0.11652354310665812, 0.055708474812230895, 0.11288491942520652, 0.09478091302194766], [0.03838857329849686, 0.01996978941107435, 0.0423561032595379, 0.026866646649848138, 0.04020017698141081, 0.021563523981188024, 0.03251569664904049, 0.051241963769176176, 0.02513790057439889, 0.037813633613820584, 0.02170416902351592, 0.04527431952634028, 0.06545465665736369, 0.058447154105773995, 0.016830352068479573, 0.06841904723218509, 0.05730396509170532, 0.007407167311092573, 0.02875540146071996, 0.06404371093958616, 0.05361957761592098, 0.01821995955625815, 0.021982498999152864, 0.0091236726148054, 0.03591886867902108, 0.04235081747174263, 0.04362151339384062, 0.02357063565536269, 0.07463763068829264, 0.028769945858844688, 8.772872839655195, 38.3030321257455, 25.327940021242412, 29.500407968248638, 30.526636055537633, 5.19064176934106, 0.45246422237583567, 0.07422459285174098, 0.03807042858430317, 0.5374242163130215, 3.4143298055444444, 4.953321269580296, 4.648483821323939, 6.168605932167598, 4.4041182824543545, 2.452159549508776, 0.3614275130842413, 0.11554972321859427, 9.410306658063616, 43.19517190115792, 54.09951148714338, 53.45440598896572, 49.412565912519185, 50.066662379673545, 48.0708965573992, 51.1127518926348, 48.24564375196184, 47.27569259916033, 47.159563882010325, 48.1581381389073, 48.032886437007356, 49.351724011557444, 47.94997010912214, 48.04257222584316, 49.22476652690342, 46.04040363856724, 39.518463134765625, 35.26235103607178, 37.322992188589915, 45.08629090445382, 46.421574865068706, 50.69325787680489, 50.36931896209717, 47.17722967692784, 47.04204205104283, 45.561895098005024, 40.9249279158456, 37.30585445676531, 34.31154564448765, 33.40586532865252, 35.03534296580723, 36.58574662889753, 43.764774799346924, 46.973234040396555, 47.66364179338728, 46.12135362625122, 45.64097254616873, 46.377498967306956, 43.93244872774397, 43.345430169786724, 43.90362065179007, 54.425482749938965, 44.49370336532593, 46.079904147556846, 42.81829466138567, 39.191147395542686, 38.90208496366228, 37.47896882465908, 34.76761845179966, 35.134080341884065, 32.01201152801514, 32.50336728777204, 31.45591245378767, 34.451117583683555, 34.26296731403896, 34.39891576766968, 33.15794318062918, 38.9063720021929, 40.98156615665981, 42.78556864602225, 42.73206056867327, 45.165781770433696, 44.90961905888149, 44.80120979036604, 42.32487528664725, 43.712913445064, 44.78632327488491, 45.789497239249094, 44.62186288833618, 42.82763998849051, 43.85025153841291, 42.534672669001985, 41.550404753003804, 40.71434538705008, 38.897551264081685, 41.87165124075753, 43.369040148598806, 43.52817126682827, 43.143494674137656, 44.25506401062012, 43.509862763541086, 42.32141508374895, 34.50795384815761, 21.67848903792245, 6.198704659938812, 1.0289607920816966, 1.047661542892456, 2.7113707831927707, 2.576802198375974, 1.193028171147619, 4.284047331128802, 5.240248433181217, 3.6432332141058783, 0.9645552252020154, 0.07842804265341588, 0.0205053045148296, 0.32257245374577387, 12.83213118144444, 34.65564823150635, 23.730366774967738, 28.806849207196915, 13.446807043892996, 0.029367524864418165, 0.017450516112148762, 0.014448841734390174, 0.019233568737815534, 0.02834743567343269, 0.07680386730602809, 0.012513557232783308, 0.032490821555256844, 0.011217365357359605, 0.01179263582785747, 0.017149244867531315, 0.02361840960968818, 0.05595467445839729, 0.0207812714922641, 0.06451863795518875, 0.023757687403953502, 0.044434605299362114, 0.029367548613143817, 0.02626452485232481, 0.038502567181629796, 0.03890323193211641, 0.04420205099242074, 0.04368503784228649, 0.010690651700964995, 0.02962966329817261, 0.08620587922632694, 0.03284533913912518, 0.01660760598523276, 0.0314066549097853, 0.028542568774095604, 0.03856075834482908, 0.06299515720456839, 0.030182998427855115, 0.016349547243277942, 0.01859597991486745, 0.01806048007815012, 0.04227424479488816, 0.01669426169246435, 0.006869988948372858, 0.016098962564553534, 0.01432228647172451, 0.018889375064255934, 0.04053337160231812, 0.0176448570231774, 0.05250989126839808, 0.013854964137343424, 0.029115771409124136, 0.02989779319614172, 0.02289688939760838, 0.03801547742581793, 0.03435541543045214, 0.03165651185970221, 0.06427765624331576, 0.06278819723853044, 12.878628526415143, 42.50967999867031, 27.721552746636526, 35.01525224958147, 33.049384525844026, 5.638676813670567, 0.2660499167229448, 0.0806441990924733, 0.07150134683719703, 0.38946718562926563, 1.8354763090610504, 4.198823767048972, 5.767577622617994, 6.412047794886997, 5.1103692310197015, 5.451096730572837, 2.4668148202555518, 0.12483063020876475, 10.939005885805402, 44.06785869598389, 53.83528886522566, 52.91333586829049, 51.344863414764404, 50.86640351159232, 49.76765012741089, 50.151753493717735, 50.82713924135481, 48.59318222318377, 48.45464903967721, 49.708976064409526, 50.041496004377095, 50.2019681249346, 47.7807536806379, 49.18867063522339, 50.49643625531878, 47.76250771113804, 41.260710035051616, 36.899051325661794, 39.102839265550884, 46.897324970790315, 49.325167996542795, 50.91029180799212, 50.26920584269932, 47.17470053264073, 48.98869800567627, 47.66467012677874, 44.08884572982788, 37.395823206220356, 35.7623017174857, 36.94555561883109, 35.54704999923706, 37.58229201180594, 45.82233442578997, 48.21933092389788, 49.06715359006609, 47.70682137353079, 47.44198383603777, 46.842642647879465, 43.861469405038015, 44.06200136457171, 43.42305197034563, 52.664705004010884, 47.25202356066023, 47.61330556869507, 44.95453568867275, 40.715696811676025, 39.95415687561035, 37.95864813668387, 36.0284628868103, 36.995547907693044, 33.50457491193499, 33.40354115622384, 33.62712376458304, 34.87322759628296, 35.95581252234322, 35.17859745025635, 34.666956424713135, 38.6814101764134, 41.565874917166575, 44.06568043572562, 44.99445308957781, 46.87313134329659, 45.37500940050398, 44.97860772269112, 43.82057925633022, 45.213706970214844, 46.01111350740705, 45.28864676611764, 44.35949543544224, 43.95267840794155, 45.27040427071707, 43.541230406079976, 43.884297711508616, 41.995784282684326, 40.61100482940674, 42.2921735899789, 45.46759067262922, 43.79254674911499, 43.40917641775948, 44.30500071389334, 45.140674454825266, 44.52653360366821, 37.25787367139544, 24.26263005392892, 9.176046405519758, 1.784698765192713, 2.0597420121942247, 3.2869313274111067, 4.303430199623108, 4.269189042704446, 5.771262773445674, 3.856588508401598, 1.802053302526474, 0.5765855120761054, 0.11039589012839965, 0.07850012342844691, 0.33620080245392664, 11.69283332143511, 39.06736871174404, 25.797033752713883, 29.316534314836773, 18.848102126802715, 0.02398591605015099, 0.05254609789699316, 0.026526425798822726, 0.01482673654598849, 0.0346862250007689, 0.01506548248497503, 0.07905555862401213, 0.02698311548946159, 0.05956146466944899, 0.060520926756518226, 0.014961439317890575, 0.01499675536927368, 0.044416990530278, 0.03041185132626976, 0.028447689222437993, 0.06558820591973406, 0.04972675096775804, 0.04870935895347169, 0.06492588788803134, 0.04626047518104315, 0.0629429914323347, 0.019112587640328065, 0.031165245720850568, 0.007522492819199604, 0.09487033036670514, 0.1594333512974637, 0.14344284577029093, 0.050143096662525616, 0.1371075135788747, 0.10302584631634609, 0.14360858473394597, 0.21878905700785772, 0.11278461837874991, 0.15447043760546617, 0.17383558276508534, 0.14400790259242058, 0.13553667786930287, 0.17547073002372468, 0.05861956985401256, 0.12518426908978394, 0.16922358024333203, 0.06643242561923605, 0.08658140086169754, 0.1675831132701465, 0.21448350804192678, 0.13341016269155911, 0.13372832776180335, 0.1043143571753587, 0.0689568676586662, 0.09988260069595915, 0.0944129027692335, 0.1446866818836757, 0.09895041571663958, 0.21406882815063, 13.863772783960615, 52.00518546785627, 33.548237391880576, 39.00110721588135, 39.98488875797817, 7.6414524997983655, 0.8255305109279496, 0.2719803399273327, 0.20627366857869284, 2.6889337471553256, 8.07055847985404, 12.154320512499128, 13.474162970270429, 16.02967480250767, 10.675988776343209, 8.634950229099818, 2.6304950543812344, 0.21078922413289547, 11.240797417504446, 44.501203945704866, 56.724936962127686, 57.49431446620396, 53.236361094883506, 54.10098450524466, 51.308374949863975, 54.55678285871233, 51.96810988017491, 51.72422810963222, 50.546352113996235, 51.2698506627764, 50.053801264081685, 51.742682525089805, 49.568935121808735, 50.09944398062569, 51.859374046325684, 49.28531312942505, 43.24864176341465, 38.9954513822283, 40.85448707853045, 49.76348468235561, 50.05529165267944, 54.11188622883388, 49.06847027369908, 49.37428828648159, 50.18011604036604, 48.09721633366176, 46.049676009586875, 39.422765595572336, 37.49297639301845, 37.80438075746809, 38.20084844316755, 39.89514929907662, 48.82587391989571, 51.07013511657715, 49.82408339636666, 49.79687425068447, 49.22567326681954, 48.93597160066877, 44.35125139781407, 44.65394272123064, 44.88859380994524, 53.537169456481934, 47.9880427633013, 49.443231787000386, 47.02160392488752, 43.59241083690098, 42.298326219831196, 41.0295295715332, 37.85931321552822, 38.78026567186628, 35.65256186894008, 34.9555116380964, 34.59707839148385, 37.458607128688264, 37.52029323577881, 37.5923182623727, 36.187698228018625, 42.73115382875715, 42.97336803163801, 46.276301928928916, 45.655476910727366, 48.90900911603655, 47.982508523123606, 45.590209007263184, 44.45415769304548, 45.37911925997053, 46.22404105322701, 47.81297247750418, 46.08115829740252, 46.071938037872314, 47.813378947121755, 45.055836950029644, 45.71128831590925, 43.75817748478481, 42.69308117457798, 45.03324140821184, 45.26687111173357, 45.87798949650356, 44.58375896726336, 44.48818302154541, 44.51095226832798, 45.89789955956595, 37.562375000544954, 24.27369679723467, 7.173927324158805, 2.379943447453635, 3.15717437011855, 6.566650858947209, 6.907632836273738, 6.238131778580802, 11.629305941717965, 10.353687030928475, 7.4766594682421, 2.630149164370128, 0.4617165359003203, 0.18780208618513175, 0.808080001601151, 16.876458712986537, 42.97892311641148, 32.998843329293386, 38.505030155181885, 21.272908789770945, 0.1688775545252221, 0.1383388646479164, 0.06921469739505223, 0.12504807354084083, 0.1300739688532693, 0.21434195206633636, 0.1875509468040296, 0.1050635412601488, 0.10521619128329412, 0.2085141504981688, 0.08939818971391235, 0.09680034180304833, 0.14863795414566994, 0.09394892052348171, 0.17035940715244838, 0.13099362807614462, 0.17775093338319234, 0.10953793009477002, 0.10120233773652997, 0.12392266892961093, 0.20197641131068977, 0.13158214863921913, 0.13333010913005897, 0.1550850546253579], [0.10481087517525468, 0.021691370156726668, 0.03115245872842414, 0.06020827139062541, 0.019171937402071695, 0.03474479953625372, 0.044728838439498625, 0.04139575568426933, 0.032979631397340975, 0.004794570850208402, 0.02461112500168383, 0.054930144255714755, 0.015059173805639148, 0.034686998530690155, 0.012724811477320535, 0.03669779295367854, 0.06304545022015061, 0.02236332677836929, 0.03515006136149168, 0.01630440430848726, 0.038533599980707677, 0.0684796879068017, 0.023163602853726064, 0.09330365407679762, 0.026255413823361908, 0.02754812820681504, 0.011853424932009407, 0.04552085844001599, 0.045664629832442315, 0.026386089489928315, 0.4069200562579291, 23.26680554662432, 31.129663263048442, 23.04080843925476, 30.76211745398385, 20.549139261245728, 4.246915289333888, 0.4200768231281212, 0.07298735888408762, 0.2278846560844353, 1.4660541606800896, 3.2860239361013686, 2.4603506071226935, 2.4216085374355316, 4.159968572003501, 5.076906706605639, 2.08188396692276, 0.1938597211348159, 0.6001954908881868, 19.968320233481272, 45.370666776384624, 51.6841265814645, 49.9029141834804, 49.988613264901296, 51.57177421024868, 49.53447553089687, 50.06908730098179, 48.05570779527937, 50.72471237182617, 49.847207001277376, 49.627178396497456, 48.27200174331665, 48.51603984832764, 48.846294675554546, 45.243702343532014, 40.94622761862618, 36.72499200275966, 37.17102813720703, 41.66388273239136, 46.7579163142613, 48.33895805903843, 51.951257024492534, 43.529060636247905, 48.06184305463518, 50.08269534792219, 46.36966487339565, 41.68275056566511, 38.86728491101946, 35.62828138896397, 33.772608620779856, 35.289362158094136, 37.99136372974941, 44.56054850987026, 45.78500870295933, 46.402349199567524, 46.71444838387625, 44.584571906498496, 44.418145179748535, 45.091682706560405, 45.40187461035592, 43.689039434705464, 49.1596097946167, 48.1446065221514, 47.19966541017805, 40.60798583711897, 40.91727794919695, 36.67713975906372, 38.2178750038147, 33.70977258682251, 33.713566303253174, 33.43513114111764, 31.736164569854736, 33.31953396115984, 33.84862886156355, 33.36334235327584, 34.474109172821045, 39.09120103291103, 43.059935637882774, 44.14756843021938, 43.00359616960798, 43.92625788279942, 45.32889073235648, 44.40200104032244, 46.5297965322222, 42.854029246738975, 44.912676266261506, 46.27514852796282, 44.006071840013774, 45.487333978925435, 46.56737239020211, 45.87637056623186, 43.66678088051932, 43.151759556361604, 42.39672660827637, 43.63936676297869, 41.67766795839582, 40.293916838509695, 41.33482646942139, 44.305785860334126, 45.30477353504726, 46.02152190889631, 38.0496243749346, 26.62057420185634, 11.313054340226309, 1.7417394646576472, 0.7885546407529286, 0.962012835911342, 2.52761264358248, 2.2505243463175635, 4.006832446370806, 3.343634707587106, 1.7197490675108773, 1.2841843026024955, 0.3307525190923895, 0.008082817707742964, 0.2866411203784602, 3.902725849832807, 25.82170159476144, 28.09798182759966, 18.580850090299332, 27.070087909698486, 4.079059839248657, 0.2260435191648347, 0.07231131408895765, 0.00816237339417317, 0.023543953962091888, 0.07367721865219728, 0.009002038427362484, 0.029279820820582763, 0.04714334423520735, 0.020971349507038082, 0.02317550775062825, 0.038071280145751576, 0.06666395533829927, 0.06937363743782043, 0.016250213109222904, 0.03500818647444248, 0.006730787489297134, 0.04053886773596917, 0.04160303116909095, 0.10082516047571387, 0.05482264734538538, 0.02557400181623442, 0.062190000766089985, 0.05176367238163948, 0.0274456829896995, 0.024144732260278294, 0.05332958192697593, 0.04583001256521259, 0.07099102743502174, 0.015281821501308253, 0.03398924061496343, 0.0281149899320943, 0.040929741226136684, 0.06252257792013032, 0.043749352784029076, 0.040806044292237074, 0.0525313702944134, 0.06535587552934885, 0.0252794701206897, 0.014345865563622542, 0.02723605468470071, 0.0225176205525973, 0.012936850277973073, 0.050345289920057566, 0.039756493110741885, 0.026136934823755707, 0.05535086989402771, 0.007046812629726316, 0.017071274408538426, 0.058768101169594696, 0.04721957425187741, 0.04238159242751343, 0.012607195065356791, 0.055809759734464545, 0.0746913638764194, 1.2760787946837289, 32.24048566818237, 32.77812337875366, 26.750602790287562, 38.119988782065256, 22.171972683497838, 4.726497760840824, 0.2933634210910116, 0.14498154606137956, 0.12353166991046496, 0.2857909160000937, 1.6614178546837397, 5.682893846716199, 4.1640302283423285, 5.3618058647428235, 4.477491693837302, 4.1270462700298856, 0.3220159736062799, 1.005050303680556, 24.368291309901647, 47.96181678771973, 54.1021865436009, 51.800488063267295, 53.53148930413382, 51.28047098432268, 51.936363560812815, 51.85193599973406, 50.14825160162789, 51.34010737282889, 50.93132053102766, 49.97458832604544, 49.83952924183437, 48.61244262967791, 50.0353433745248, 47.82597255706787, 43.37168741226196, 38.637560095105854, 38.45439863204956, 43.163099016462056, 49.67147316251482, 49.142763887132915, 53.58010932377407, 45.0336583001273, 49.10871076583862, 50.02638714654105, 46.515146255493164, 42.352021898542134, 40.39592334202358, 36.87238066537039, 34.68401425225394, 36.867916447775706, 38.86505453927176, 45.90368046079363, 47.610008648463655, 47.9298654964992, 49.01239831107003, 46.96608781814575, 43.85803352083479, 44.75200612204415, 44.9981495312282, 45.146778447287424, 48.592407499040874, 48.51717240469796, 49.00284801210676, 42.60648577553885, 41.03393472943987, 37.10725062234061, 39.069192613874165, 36.211363792419434, 35.16137286594936, 33.85944373267037, 34.024004868098665, 34.728791918073384, 36.182362011500764, 35.14718811852591, 36.37237439836775, 40.20443793705532, 47.08102491923741, 46.63113253457205, 45.48341519492013, 45.253478458949495, 46.750603335244314, 44.97839232853481, 45.532608440944124, 44.0090526172093, 45.11845064163208, 47.47766630990164, 44.25648144313267, 46.57173933301653, 46.54221296310425, 46.06971114022391, 44.052093233381, 44.15791082382202, 43.3632036617824, 44.966048853737966, 43.022797516414094, 42.171900272369385, 42.04396309171404, 45.81018550055367, 44.26532997403826, 44.11483894075666, 39.268977642059326, 28.3696893964495, 13.79375057561057, 2.9453804663249423, 1.5153400131634303, 2.753157683781215, 4.463624826499394, 3.9485948170934404, 6.15209527526583, 6.727612393242972, 4.654054539544242, 0.8423496027077947, 0.08329153060913086, 0.020006956166720817, 0.11700094677507877, 3.291371443441936, 27.34106765474592, 33.726437841142925, 21.274666684014456, 32.20060648236956, 6.7292599848338535, 0.1361132562160492, 0.011637669455792223, 0.04079820382009659, 0.04517075811911907, 0.03856063620852573, 0.011104606407960611, 0.04839542454906872, 0.02330346418810742, 0.03864686443869557, 0.02220014249905944, 0.053058822705809555, 0.03974299704922097, 0.0898081266454288, 0.018228590521695356, 0.044155734192047796, 0.007802480116619596, 0.00964327946504844, 0.024502304948068092, 0.050098533875175884, 0.053328665904700756, 0.02626983099617064, 0.05123152450791427, 0.06400505479957376, 0.0018859085685107857, 0.16025783919862338, 0.08012591368917908, 0.160707151517272, 0.17658105758684023, 0.09855866352362291, 0.08061192796698638, 0.14793687819370202, 0.15272377990186214, 0.09455413304801498, 0.12160362622567586, 0.08537319462214198, 0.20126318958188805, 0.1041733847398843, 0.08935865147837571, 0.06648189082209553, 0.16206978554172174, 0.19632903220398085, 0.08820712326892785, 0.1080579502241952, 0.10767628784690585, 0.07093443082911627, 0.14140710500734194, 0.11018313547330243, 0.10282244865915605, 0.221994280016848, 0.17886085382529668, 0.11578419777963843, 0.13545765568103108, 0.14615363388189248, 0.1572413167783192, 1.3511883871895927, 36.35298545019967, 40.994062491825645, 32.20550148827689, 39.55992998395647, 28.087139163698467, 6.402335516044071, 0.960283385855811, 0.46707956812211443, 0.48377891204186846, 3.125611309494291, 8.532656243869237, 8.32293094907488, 9.104817816189357, 11.595743536949158, 9.819200328418187, 5.700880127293723, 0.3589668465512139, 1.3985024711915424, 22.224063328334264, 47.64507620675223, 56.28287519727434, 53.27425309589931, 55.294886520930696, 54.68586301803589, 52.81804132461548, 53.85698461532593, 52.03832490103585, 53.436969484601704, 52.98705278124128, 52.182736260550364, 52.17216110229492, 50.40955598013741, 51.370196546827046, 49.09596429552351, 44.200541496276855, 39.9615740776062, 41.51833186830793, 46.33707087380545, 50.73794174194336, 50.93952635356358, 53.17624528067452, 46.25531142098563, 50.00562940325056, 52.14857196807861, 49.81865685326712, 44.61313247680664, 43.97944981711251, 39.63073212759835, 36.311866010938374, 38.40181813921247, 41.88937609536307, 47.46191474369594, 49.85211590358189, 48.744326387132915, 51.154468876974924, 47.0703490121024, 46.18357474463326, 46.84408439908709, 45.86833150046212, 48.031152861458914, 49.545651708330425, 50.710350445338655, 51.593098231724326, 43.20037610190255, 45.110435894557405, 39.9982397215707, 43.54731355394636, 38.86290407180786, 37.14663301195417, 36.167673519679475, 35.29921817779541, 35.9214745249067, 37.96880292892456, 36.99228572845459, 38.33989231927054, 42.761864866529194, 47.98208468300955, 47.070911816188264, 45.749215057918, 46.254185812813894, 48.54416268212454, 47.4660975592477, 46.63714272635323, 45.40879501615252, 47.625239099775044, 48.789090156555176, 44.06548588616507, 47.05713701248169, 48.254648617335725, 48.33070707321167, 45.68308557782854, 46.17541755948748, 45.35332407270159, 45.93934556416103, 44.19302007130214, 42.37395388739449, 44.427577359335764, 47.37160900660923, 46.53206164496285, 45.08967467716762, 39.28830405644008, 29.26215771266392, 12.97661897114345, 2.763089265142168, 1.6106874282870973, 3.486654907464981, 6.0625603539603095, 6.4058447905949185, 10.402399114200048, 10.307728171348572, 8.663985013961792, 4.010350840432303, 1.4340044004576546, 0.2031492998025247, 0.5809582088674817, 5.7380964159965515, 32.78959485462734, 36.806567328316824, 26.7687897000994, 37.55744872774397, 7.401992389133998, 0.3760757813496249, 0.14579686016908713, 0.11799466130988938, 0.13412402224327835, 0.16720951188887867, 0.0996680072109614, 0.11770564610404627, 0.186234711004155, 0.11646237996007715, 0.09727594735366957, 0.12104515119322709, 0.18453689425119332, 0.17494922157909187, 0.06363948048757655, 0.09662154782563448, 0.12917214153068407, 0.09324228736971106, 0.17764122784137726, 0.14444771542080811, 0.1346794981509447, 0.0973619313112327, 0.1633285087134157, 0.10635912923940591, 0.24688108531492098], [0.018506521858008843, 0.07780587353876658, 0.022395178908482194, 0.03217969289315598, 0.0732495855273945, 0.02573143381492368, 0.052313234856618304, 0.053472352480249744, 0.02660213164719088, 0.0173150499883507, 0.10132367336856467, 0.032925698041383705, 0.033301480912736485, 0.01708420558965632, 0.04676537987376962, 0.051806708465197256, 0.018231151991390755, 0.009719627377177988, 0.0634323712438345, 0.04001218206914408, 0.025062851208661283, 0.050051097492022176, 0.03553167963400483, 0.08315748601619687, 0.015043603123298712, 0.023620887958843793, 0.03753969206341675, 0.07976988636489425, 0.013428554071911743, 0.02494744597268956, 0.019162746645244103, 6.683968586581094, 31.985465935298375, 23.057334729603358, 27.801234688077653, 29.473320416041783, 15.574850933892385, 4.105682730674744, 0.3931256836014134, 0.06272838437663657, 0.25070164459092276, 0.3298737348190376, 4.7098802753857205, 4.4126754232815335, 3.019341000488826, 3.285820484161377, 3.8366007123674666, 0.30464794699634823, 0.3415743926806109, 3.337478820766721, 28.77255289895194, 47.45116588047573, 55.100503717150005, 50.423469747815815, 49.16087089266096, 49.671261242457796, 49.61638784408569, 47.58700663702828, 50.14231089183262, 50.71512038367135, 49.769171782902305, 46.99924462182181, 46.23479686464582, 45.10819510051182, 43.49551125935146, 37.923177582877024, 36.04387746538435, 39.17219270978655, 45.226877280644004, 47.38663101196289, 51.88888999394008, 43.827457972935264, 45.46082312720162, 50.01111848013741, 48.30164623260498, 47.12116118839809, 40.22170768465315, 38.519187109810964, 35.300448008946006, 34.25720030920846, 34.386898858206614, 38.90159164156233, 45.98688166482108, 47.69708694730486, 47.5480307170323, 45.06718683242798, 43.70276212692261, 47.0085517338344, 43.43877921785627, 45.648358481270925, 36.98090805326189, 37.40357044764927, 49.11748286655971, 42.621076992579866, 43.279370171683176, 39.30746718815395, 36.68567909513201, 35.92825944083077, 35.65502153124128, 33.6177784374782, 33.3668338230678, 31.64732837677002, 32.688925879342214, 33.04560817990984, 32.98413746697562, 36.211037227085654, 40.74243695395333, 43.68887267793928, 46.097347600119456, 44.8132266998291, 43.3461458342416, 44.906200545174734, 44.243220806121826, 43.92770658220564, 44.203181811741416, 42.99146808896746, 42.63474062510899, 43.939459460122244, 44.01488562992641, 44.231068406786235, 43.71415022441319, 44.62734154292515, 44.35494089126587, 42.28503084182739, 44.213447775159565, 40.94563007354736, 41.56612505231585, 41.86525889805385, 42.370726449149, 39.13944237572806, 42.71777507237026, 28.8795325756073, 13.84817407812391, 3.4844544998237064, 1.6992112781320299, 1.4359218861375536, 2.112170513187136, 3.4600808705602373, 3.4394123681953976, 4.085965480123248, 5.7951754331588745, 2.4280818700790405, 0.2810939608940056, 0.04859442190666284, 0.07632891993437495, 1.8900033831596375, 12.872026000704084, 32.60307741165161, 22.74012861933027, 25.114784921918595, 16.116091285433086, 0.3061312788299152, 0.10925087585513081, 0.03209478102092232, 0.04181563654648406, 0.028809161790247475, 0.017346878369737948, 0.01790693778145526, 0.029203054761247974, 0.048573363572359085, 0.016221824900380204, 0.050880101043730974, 0.05916361923196486, 0.006236966666100281, 0.024704527043338333, 0.05572771806535976, 0.03899254071127091, 0.0801765052601695, 0.05514831022758569, 0.05105920714725341, 0.0781340402151857, 0.04023799513067518, 0.03551825821133597, 0.014396925323775836, 0.025477534492633173, 0.03466811490112117, 0.03888035173128758, 0.03589949989691377, 0.02333446136409683, 0.03446819812857679, 0.060404809058776925, 0.03468873897301299, 0.06605273777885096, 0.02354885298492653, 0.030781781833086694, 0.020327128004282713, 0.06763805342572075, 0.045253424040441, 0.028188802667760422, 0.017920272690909247, 0.06304549093225173, 0.09088699732507978, 0.019473268018503274, 0.02016398443707398, 0.04992342434291329, 0.00790031808095851, 0.04427125817164779, 0.04892198129424027, 0.048899304653917036, 0.023305998516402075, 0.02352918734374855, 0.03301259123587182, 0.0105454112802233, 0.044025377436940155, 0.02667256527846413, 0.05234540080917733, 0.04331401489408953, 9.991948178836278, 38.334246907915386, 23.786001001085552, 29.310993126460485, 34.40018381391253, 16.40476288114275, 3.860169436250414, 0.2722376946892057, 0.03920697134786418, 0.137469634147627, 0.07879269415778772, 3.5778704243046895, 4.056900296892438, 5.422689454896109, 4.819113773959024, 5.029409689562661, 1.1435799045222146, 0.3897709250450134, 5.04737034865788, 31.065423692975724, 48.40989569255284, 54.375445297786165, 50.19442932946341, 50.22376462391445, 49.73721701758248, 50.38740164893014, 48.06901706968035, 50.368141242435996, 51.91812801361084, 50.96229560034615, 48.434693813323975, 49.177244322640554, 46.37737389973232, 46.00457872663225, 40.11636257171631, 38.95595782143729, 39.40844535827637, 48.178906304495676, 47.9141069820949, 53.03423799787249, 46.8868088722229, 44.81978232519967, 51.19709260123116, 49.8506498336792, 49.3430735043117, 43.223002910614014, 40.875383785792756, 36.35314525876726, 36.48812443869454, 34.68446588516235, 40.26517561503819, 47.098183495657786, 48.83202654974801, 48.3492066519601, 47.77731779643467, 45.906859261649, 47.43266977582659, 44.4584447315761, 45.35457474844796, 39.92069435119629, 39.02338661466326, 51.202765805380686, 43.68605170931135, 43.60702984673636, 42.045734882354736, 38.49674442836216, 37.29652302605765, 36.28245428630284, 34.70543902260916, 34.660550185612266, 33.418410301208496, 35.56297527040754, 35.118516377040315, 35.115302835192, 37.006428786686485, 42.25992700031826, 44.34385504041399, 47.369038173130576, 46.267272744859966, 45.80605479649135, 45.463512080056326, 44.91525752203805, 45.88726881572178, 44.883587632860454, 43.84959493364607, 43.913132735661094, 45.50254705974034, 45.573651450020925, 45.27317312785557, 45.03154257365635, 45.67530706950596, 45.41529505593436, 43.45161254065377, 44.56999111175537, 42.344424043382915, 42.704708984919954, 42.19891486849104, 43.578934805733816, 42.578251770564485, 42.73222385134016, 32.007509095328196, 16.351753337042673, 5.395066022872925, 3.1331963539123535, 1.4963058573859078, 4.321793419974191, 4.4242576360702515, 6.010367223194667, 7.444618718964713, 3.888630126203809, 1.6028445405619485, 0.14639817790261336, 0.14175595343112946, 0.0992854627381478, 1.4639834889343806, 13.006331205368042, 36.45186873844692, 25.691567046301707, 25.70675928252084, 21.766152722494944, 0.5946790554693767, 0.06804995132344109, 0.021974395594692657, 0.030435443988868167, 0.04202548707170146, 0.01725877059756645, 0.02002000100245433, 0.023818073627938117, 0.01459856387893004, 0.06232779087232692, 0.04613259168607848, 0.05874771119228431, 0.01628741548795785, 0.02180316049738654, 0.017645467704694186, 0.04399797819288714, 0.06398658507636615, 0.013392504354539727, 0.017811581558947052, 0.02089401178195008, 0.016239504130291085, 0.027671670773997903, 0.04145910032093525, 0.06287967732974462, 0.05650327680632472, 0.14560024786208356, 0.13906001166573592, 0.10145355854183435, 0.1445724301572357, 0.21151868999004364, 0.11113531009427138, 0.22623391609106744, 0.13453203892069204, 0.13671641956482614, 0.12963194400072098, 0.15553528975163186, 0.13200354602720055, 0.11542586343629019, 0.08337443401770932, 0.16820986249617167, 0.2473638765513897, 0.0995100714000208, 0.11702871242804186, 0.15466136378901346, 0.1066328841926796, 0.09034787411136286, 0.1730288860521146, 0.16184476975883755, 0.29008919107062475, 0.11571903127644743, 0.14087288081645966, 0.12131112334983689, 0.17579994164407253, 0.17787400606487477, 0.15463560659970554, 0.0824618519150785, 10.742968542235237, 44.39176981789725, 32.187981605529785, 35.388902051108225, 38.32827493122646, 19.880441154752457, 6.285896301269531, 0.8956821837595531, 0.2930027390164988, 0.6567971993769918, 3.317122118813651, 10.411720991134644, 14.405930297715322, 10.759824872016907, 6.772776986871447, 9.012968710490636, 1.555207148194313, 0.937518481697355, 4.418046380792346, 30.966387544359478, 49.87677158628191, 56.6072553225926, 51.86577681132725, 50.95571565628052, 50.68428775242397, 51.41666609900338, 49.49972758974348, 51.84324380329677, 53.480454785483225, 52.980993952069966, 50.2304870060512, 50.36150918688093, 48.25814356122698, 47.29538379396711, 41.56549276624407, 40.237973417554585, 41.95574181420462, 49.24551732199532, 50.47698824746268, 53.836942536490305, 46.55786030633109, 46.76053925922939, 52.69258117675781, 53.686996936798096, 50.438199928828645, 46.308937617710654, 42.080350807734895, 38.56953028270176, 38.29144600459507, 37.82454790387835, 42.88720342091152, 49.55704327992031, 50.75032343183245, 51.463347571236746, 49.702055658612935, 47.529968874795095, 48.82822935921805, 45.025105067661826, 46.09552369798933, 42.70924615859985, 42.75604575020926, 52.9413857460022, 46.62071718488421, 45.400596141815186, 43.173771449497764, 40.65172822134835, 39.917553765433176, 39.63106216703142, 37.34305511202131, 36.03825637272426, 35.2418885912214, 37.25935711179461, 38.04043885639736, 37.04886490958077, 39.386763504573274, 43.22791528701782, 47.297033991132466, 48.87942368643624, 48.480802059173584, 45.78823266710554, 46.31393337249756, 46.009074211120605, 46.29099389484951, 47.984658990587505, 45.08295576913016, 45.43554558072771, 46.705884729112896, 46.15762322289603, 46.99471092224121, 45.85308715275356, 46.3945255279541, 46.252737113407676, 44.2382424218314, 46.568887097494944, 43.67026540211269, 44.85270983832223, 43.93257032121931, 44.45334822790963, 42.87193822860718, 44.1925163269043, 31.949495111192974, 15.723502431597028, 4.564910454409463, 3.150728613138199, 2.9550265201500485, 6.968021367277418, 7.2667913011142184, 7.92930941922324, 9.530977760042463, 11.857820902551923, 6.592753938266209, 1.752200954726764, 0.23695900344422885, 0.2493794241121837, 2.523204662970134, 16.57283111980983, 40.53342471803938, 29.97399718420846, 34.40111834662301, 24.08913353511265, 0.8952624691384179, 0.17755684522645815, 0.11933498510292598, 0.15457136290413992, 0.10188101524753229, 0.08991448700960193, 0.14295487052627973, 0.12059294831539903, 0.11498486995697021, 0.14548710893307412, 0.13471247495285102, 0.1418659710990531, 0.13550866794373306, 0.16200065639402184, 0.12415858198489461, 0.15663919837347098, 0.16653936356306076, 0.1192425007798842, 0.15173953771591187, 0.13254967172230991, 0.3135685111795153, 0.13806522504559585, 0.0953046538467918, 0.13877252994903497, 0.19782499835959502], [0.05441908185769405, 0.05917657246547086, 0.048125693308455605, 0.011213368786099766, 0.035750025417655706, 0.04236020500372563, 0.03142555889540485, 0.04526564784880195, 0.04279047762975097, 0.029095123588506664, 0.027493122765528302, 0.06478331410991293, 0.03821651717381818, 0.04198971131284322, 0.02835053318579282, 0.027856052487290332, 0.05561657742198024, 0.03247350534158094, 0.0646912572639329, 0.061690001881548336, 0.0874556050236736, 0.03798388144267457, 0.0371982396713325, 0.046320966577955654, 0.0663219601182001, 0.026690953577469503, 0.017382411552327018, 0.025058052269741893, 0.01344156837356942, 0.08077762621854033, 0.06932242161461286, 0.5152652710676193, 18.01464138712202, 33.66044037682669, 23.663092579160416, 29.285458496638707, 30.819662434714182, 18.092925003596715, 5.160066221441541, 0.07342360940362726, 0.059272571599909236, 0.12363919056952, 3.76338016135352, 2.3357209861278534, 3.6740736620766774, 4.289487770625523, 5.123300262859889, 1.03171748987266, 0.16115077771246433, 0.20153733130012239, 6.639114924839564, 25.30442210606166, 42.18150615692139, 50.24382059914725, 48.7803840637207, 50.52108151572091, 47.36116933822632, 48.235158920288086, 49.4375307900565, 49.702990191323416, 47.678028038569856, 47.56890310559954, 44.48622710364205, 41.96534422465733, 37.54115520204817, 37.76703419004168, 37.1484569140843, 47.711094515664236, 47.106559549059185, 50.42868089675903, 47.40636389596121, 46.41895539419991, 48.46021107264927, 47.81249305180141, 47.07584851128714, 45.44972685405186, 40.139965602329795, 37.238637583596365, 36.94484690257481, 34.1202061516898, 32.7640289579119, 39.10440608433315, 46.29169218880789, 47.965523651668, 45.402079582214355, 46.07019404002598, 44.19012267248971, 46.87788043703352, 42.70373623711722, 43.6534229687282, 38.56806421279907, 43.27489900588989, 47.74768720354353, 45.44156619480678, 42.362878458840505, 38.64268786566598, 35.819933550698416, 34.48186683654785, 32.90150254113333, 33.528976985386436, 33.10767643792288, 33.57000262396676, 34.153130190713064, 34.52877759933472, 36.474144663129536, 39.39301340920584, 40.25178991045271, 44.17006322315761, 47.928920541490825, 47.232777050563264, 42.914648805345806, 43.911711829049246, 44.95438977650234, 45.61174842289516, 43.24398647035871, 40.15774951662336, 38.28492512021746, 41.53267295019967, 40.47072417395455, 44.042285851069856, 42.201760155814036, 43.844199657440186, 42.64643096923828, 41.21311487470354, 41.845710141318186, 39.7035596711295, 38.16398130144392, 43.45238379069737, 41.960751465388704, 44.119077341897146, 29.903257574353898, 15.87984732219151, 4.149704345635005, 0.8167539047343391, 1.9428077382700784, 1.2293639928102493, 2.245225476367133, 5.139770099094935, 4.694152159350259, 7.015890112945011, 2.5276033069406236, 1.629673706633704, 0.22478008696011134, 0.1932238931102412, 0.8863985219172069, 9.919058970042638, 25.213094983782085, 31.500439984457834, 22.62732982635498, 26.910743134362356, 6.1217325159481595, 0.045055122181241, 0.06518093563084092, 0.011806684047249811, 0.012452946244073766, 0.04207467407520328, 0.054326526288475306, 0.08864716679922172, 0.06955200393817254, 0.036991045610713105, 0.019584452766659002, 0.03282325282426817, 0.038578254370284934, 0.037224631290882826, 0.048128030861594846, 0.04012644736628447, 0.03731020134208458, 0.0201773532732789, 0.018065107686977302, 0.028088696700121676, 0.010133629581624908, 0.04455544560083321, 0.04480244591832161, 0.026625602173485925, 0.048183083800332885, 0.07239229045808315, 0.08689273986965418, 0.04430361072133694, 0.0029764742232925656, 0.035179984755814075, 0.011993593303486705, 0.046197218753929646, 0.01781042804941535, 0.009960056931179549, 0.03239611842270408, 0.03811983611168606, 0.07192140072584152, 0.011776122830009885, 0.07375499233603477, 0.019770500283422213, 0.024719600698777607, 0.05738004922334637, 0.1245489160397223, 0.061787860201937814, 0.022374524302514534, 0.033574438587363274, 0.02602609952113458, 0.03986910956778696, 0.03872204611876181, 0.03479685674288443, 0.1082202558006559, 0.008620143651829233, 0.026565811363980174, 0.023493375961801836, 0.012211036635562778, 0.05470486384417329, 0.05249345036489623, 1.3026953893048423, 25.143138783318655, 35.433648450034006, 27.5692013331822, 32.50857843671526, 35.68581247329712, 19.74397679737636, 4.216048785618373, 0.10072145318346364, 0.009077997878193855, 0.2345308523092951, 1.0904622290815627, 3.3549255302974155, 4.849177326474871, 7.246740537030356, 7.306585805756705, 2.2538386370454515, 0.6741266580564635, 0.5628857272011893, 10.629358547074453, 30.76858970097133, 45.73191056932722, 50.58358403614589, 50.42274366106306, 49.625187737601145, 49.364963803972515, 48.63646950040545, 50.36539670399257, 50.010934352874756, 49.12464645930699, 50.07886341639927, 47.0329190662929, 43.8438835144043, 39.9681053842817, 39.85046543393816, 38.6684205191476, 47.11030115400042, 48.99811281476702, 51.8276937348502, 51.27821976797921, 47.05407633100237, 49.119233812604634, 49.1608430998666, 48.5017717225211, 47.25015102113996, 42.62277582713536, 38.88710117340088, 39.09978553227016, 35.70256110600063, 34.5222601890564, 41.77681180409023, 47.570230211530415, 48.54049055916922, 47.94118411200387, 46.540177140917095, 45.85160371235439, 47.835939747946604, 44.762633391789024, 44.040965693337576, 40.154115608760286, 42.5445008959089, 49.47648239135742, 46.4597795350211, 44.626994132995605, 40.290418420519146, 38.24766193117414, 36.009754862104145, 34.639608315059114, 33.737405572618755, 34.04851811272757, 35.58708551951817, 34.81874329703194, 35.81537205832345, 37.83690874917166, 40.83912808554513, 42.57976647785732, 44.97683245795113, 47.7743752343314, 47.512851987566265, 44.85994986125401, 44.64416313171387, 46.23760046277727, 46.41451549530029, 45.032008102961946, 42.01703882217407, 41.29397800990513, 42.03863729749407, 44.38083335331508, 45.36905132021223, 43.94851991108486, 44.931884561266216, 43.720657212393625, 42.88245780127389, 43.52756677355085, 42.00120040348598, 40.440885135105674, 44.39333316258022, 43.44984075001308, 43.910999638693674, 35.09951305389404, 18.581772463662283, 7.046579437596457, 1.496845428432737, 2.995782481772559, 2.5661076179572513, 5.691230382238116, 4.565532752445765, 7.065183239323752, 6.881103311266218, 3.3519547411373685, 0.569166355899402, 0.14517365289585932, 0.11479840853384563, 0.7742257182087217, 8.870650495801653, 27.580255917140416, 33.59874037333897, 24.43136010851179, 31.376616137368337, 9.16720221723829, 0.041549935803881714, 0.07026538851537875, 0.04252890916541219, 0.008369543706066906, 0.0678950214226331, 0.027810263247894387, 0.06282567951296057, 0.045777005409555774, 0.03915612193356667, 0.01744327275082469, 0.06347396544047765, 0.06508667354605027, 0.10287352199000971, 0.05997415645314114, 0.03367114339822105, 0.04341252460809691, 0.013219620417138296, 0.025996140503723706, 0.04071298321442945, 0.0456261331481593, 0.009016882229064192, 0.05593722593039274, 0.017508413808952485, 0.04360270779579878, 0.028874555602669716, 0.2005708803023611, 0.10044148284941912, 0.12019259908369609, 0.09462132158556155, 0.1246623263827392, 0.11900833834494863, 0.11685540101357869, 0.16563471353479794, 0.0851332103567464, 0.11496977933815547, 0.12506287917494774, 0.13438178412616253, 0.13553940558007785, 0.0973843229668481, 0.18848932002271923, 0.14065602102449962, 0.18952065253896372, 0.10625772896621909, 0.11996746116450854, 0.11683363361018044, 0.1749363158430372, 0.10822366883179971, 0.11022874659725598, 0.15352861742888177, 0.26511706677930696, 0.12589518379952225, 0.13428157807460853, 0.13018309085496835, 0.14284338722271578, 0.20081743278673717, 0.21725403437657015, 1.1512248771531242, 28.087120056152344, 44.13319608143398, 34.413173471178325, 37.746467522212434, 38.57885129111153, 23.057008164269583, 7.177645913192204, 0.24659946614078113, 0.2686826325953007, 0.655359573662281, 10.165207590375628, 5.998765034335, 11.346865143094744, 11.86151213305337, 13.397984657968793, 3.4509072942393164, 0.4639956536037581, 0.7015532063586372, 7.899147289139884, 28.279241221291677, 46.100064345768516, 52.83902835845947, 50.883937290736604, 51.63456160681588, 48.43095915658133, 48.807568890707834, 50.915152072906494, 52.02341059276036, 50.70914840698242, 53.215033599308555, 48.99437468392508, 44.23424025944301, 40.567714078085764, 41.57506390980312, 40.75277239935738, 51.642791748046875, 50.5595189503261, 52.78050715582711, 50.26080199650356, 50.796035630362375, 50.7590468951634, 51.021518571036204, 49.657806055886404, 49.39635576520647, 44.19490303312029, 41.1506609916687, 41.361681256975444, 37.36968060902187, 36.12880529676165, 43.276615210941856, 49.41407019751412, 50.157541343144004, 48.60866975784302, 49.38881696973528, 46.92858839035034, 50.50593444279262, 45.00851624352591, 44.44573300225394, 43.32005187443325, 47.26051425933838, 50.232925823756624, 50.01562091282436, 46.329775265284944, 43.09487812859671, 40.3028279032026, 38.56979431424822, 36.99431112834385, 37.160355704171316, 36.48436893735613, 37.92187132154192, 36.75575862612043, 38.47565317153931, 39.78602089200701, 43.6843181337629, 44.35117844172886, 47.321050439562114, 50.271738461085725, 50.479781423296245, 45.418800422123496, 45.761749608176096, 47.49705178397042, 47.981237002781455, 44.993859018598286, 44.58635759353638, 42.92758287702288, 44.134005546569824, 44.29301854542324, 48.58906194141933, 46.34101745060512, 47.03175524302891, 46.43901136943272, 44.268960407802034, 45.91802849088396, 41.40148401260376, 41.55221823283604, 45.88704299926758, 45.11483063016619, 44.137667247227256, 36.47692394256592, 18.71100722040449, 7.354011603764125, 1.6116667985916138, 4.3201358403478345, 3.452174471957343, 5.759770452976227, 11.54577817235674, 9.953624520983015, 13.078446558543614, 7.703972390719822, 4.141983159950801, 0.49238463597638266, 0.29857185589415686, 1.4687065269265855, 12.49794888496399, 31.796367236546107, 39.66433014188494, 29.955469812665665, 36.95594664982387, 9.655471239771162, 0.21363505428390844, 0.189781074279121, 0.10924539329218012, 0.17990248650312424, 0.15009641088545322, 0.1351485965507371, 0.2537352389522961, 0.25020142857517513, 0.15025750866958074, 0.0777326188981533, 0.11149760708212852, 0.15934705521379197, 0.16722199693322182, 0.08974287871803556, 0.11569803740297045, 0.15871281496116094, 0.0667062144992607, 0.11661092484635965, 0.11663788982800075, 0.13421996709491524, 0.12692491497312272, 0.2573977809931551, 0.09871718287467957, 0.10406918211707047, 0.13012099133006164], [0.02671722475705402, 0.04541558712454779, 0.10321599896997213, 0.02165344513819686, 0.023124734671520333, 0.012588633739921664, 0.058102037624589035, 0.03998997361798372, 0.04107591802520411, 0.007102891004511288, 0.039327024548713646, 0.07842866690563303, 0.016636372477348362, 0.06545310281217098, 0.04373057432738798, 0.03716443844937852, 0.0232153190965099, 0.07731768116354942, 0.030567436013370752, 0.015941006397562366, 0.021217028377577662, 0.04792547458782792, 0.08217186640415873, 0.02836393255607358, 0.038286623411944935, 0.048271792075995884, 0.05602757626080087, 0.04123812182141202, 0.03809596185705491, 0.07116336854440825, 0.05132448041279401, 0.04057120671495795, 3.508437944310052, 25.03318006651742, 30.354539598737443, 25.137390886034282, 25.596673761095317, 32.60625621250698, 20.29969893183027, 4.704086346285684, 0.06338345565434013, 0.035752566531300545, 0.47494780591556, 2.9151894577911923, 3.387674344437463, 6.267555228301457, 4.9538940617016385, 1.699617747749601, 0.5456601658037731, 0.21996761805244855, 0.5221567441310201, 6.878407410212925, 21.03243511063712, 38.01699563435146, 45.20780100141253, 46.342931679316926, 49.14101641518729, 49.926666600363596, 50.11282621111189, 51.32944883619036, 47.18714823041643, 44.794133050101145, 43.03744084494454, 39.88217006410871, 40.17302860532488, 36.80165842601231, 39.83846589497158, 48.9153493472508, 48.92373929704939, 49.89311374936785, 44.01454169409615, 46.55717590876988, 47.71924475261143, 47.69333839416504, 48.09665352957589, 41.711953844342915, 39.41382326398577, 37.927884987422395, 35.032344818115234, 37.083150795527864, 33.113526821136475, 39.70961502620152, 46.8009604045323, 48.108072893960134, 48.0310069492885, 47.15900802612305, 44.69971397944859, 44.258201122283936, 46.45520067214966, 44.62789739881243, 36.98689045224871, 50.075573444366455, 47.03148773738316, 44.683993680136545, 43.46249341964722, 39.12367691312517, 34.79559537342617, 34.36720766339983, 32.79878732136318, 32.16547639029366, 34.730105127607075, 33.06077609743391, 32.917618887765066, 38.59223699569702, 41.95129844120571, 40.20173856190273, 40.634857995169504, 41.35171059199742, 43.70684766769409, 45.06244816098894, 46.07144818987165, 45.09623725073678, 44.575619152614046, 42.033144746507915, 40.31298269544329, 36.640164920261924, 35.15698160443987, 35.43168905803135, 33.54882451466152, 36.428686073848176, 40.50147342681885, 40.21182039805821, 39.51857083184378, 38.848886081150596, 39.11007581438337, 38.4213946887425, 41.632925033569336, 41.70019401822771, 44.755723408290315, 37.99030065536499, 20.30995273590088, 4.041613391467503, 0.814255484512874, 0.7060906514525414, 3.7855718391282216, 2.2047022793974196, 5.319349331515176, 2.4327923144612993, 7.393038766724723, 4.5406238947595865, 2.0504040675503865, 0.23946453471268925, 0.08828950420554195, 0.363299726907696, 8.805730870791844, 21.047780207225255, 30.48095859800066, 21.708347184317454, 25.361610991614207, 14.922633954456874, 0.7183464052421706, 0.07104199220027242, 0.0537930722348392, 0.029943519671048437, 0.07336678888116564, 0.052533219302339215, 0.050943577994725535, 0.040632329149437804, 0.052426936969693215, 0.07404091342219285, 0.043519787423844845, 0.03919606389743941, 0.031078461091965437, 0.04266117599659732, 0.006253557695475007, 0.029002944606223276, 0.033537027559110096, 0.014649698277935386, 0.024954195699787567, 0.005304823247050601, 0.049157582223415375, 0.04991929545732481, 0.02349601376668683, 0.04686043584453208, 0.09683045518717595, 0.04433037892782262, 0.04153746433023896, 0.036252097226679325, 0.0540572394882994, 0.05040435978610601, 0.019625398962359344, 0.03972346881138427, 0.03332045953720808, 0.05318415490910411, 0.0077286368468776345, 0.04327329940029553, 0.058121063746511936, 0.06660100085926907, 0.01888724446429738, 0.014152379606717398, 0.03292912125055279, 0.035774154122918844, 0.027045125108478323, 0.01538506569340825, 0.022406669899023006, 0.0217222519817629, 0.05110506254381367, 0.006935931101907045, 0.06558662493314062, 0.04571326043722885, 0.06970751059374639, 0.04915252035217626, 0.04466006552268352, 0.04318202965493713, 0.008491631663803543, 0.0940839693482433, 0.028820924194795743, 0.011620104728665735, 6.746294362204416, 32.63916982923235, 31.50602981022426, 26.95243058885847, 32.17826802389962, 37.97348254067557, 20.759355272565568, 3.5197168248040334, 0.16139160336128303, 0.030925091821700335, 0.26713437853114946, 0.6697676948138646, 2.2707173313413347, 4.148699028151376, 4.4424393347331455, 5.306031806128366, 2.748575129679271, 0.6506523862481117, 1.1433356319155012, 9.935355969837733, 25.094885281154088, 43.2234719140189, 47.518709318978445, 47.000509193965364, 48.4654917035784, 49.98309986931937, 50.73230675288609, 52.91839763096401, 48.01452929633004, 47.3229855128697, 44.347158908843994, 41.13454117093767, 40.6540767124721, 39.29713521684919, 41.12939255578177, 51.170769350869314, 50.193696294512065, 52.72689832959856, 46.929870332990376, 48.398285252707346, 48.01396301814488, 49.19078288759504, 48.9136574608939, 45.25418022700718, 40.42209373201643, 39.664309297289165, 36.16855594090053, 38.80631446838379, 35.462483474186485, 41.20555523463658, 47.77878386633736, 50.48058046613421, 47.802487645830425, 47.14734200068882, 46.30942051751273, 45.37077794756208, 47.5370317186628, 44.6449864932469, 38.574341910226, 52.157295431409565, 49.32320165634155, 47.730146476200645, 44.925846576690674, 41.70998750414167, 36.06101867130825, 36.670420851026265, 34.11379991258894, 33.724363803863525, 34.520182677677695, 34.726502486637656, 35.11428492409842, 39.01150866917202, 42.55735158920288, 42.20609930583409, 42.04245185852051, 43.61434282575335, 45.855602400643484, 46.85788699558803, 46.61581523077828, 47.90071432931082, 45.26681900024414, 44.79653712681362, 40.8624392918178, 38.340350900377544, 37.26338011877877, 36.63669776916504, 35.928957734789165, 39.21098450251988, 42.64722306387765, 41.427324363163535, 42.043393339429585, 40.68625034604754, 41.31349549974714, 40.725900241306846, 42.331236362457275, 43.08763115746634, 45.07733120237078, 38.13969734736851, 23.521410124642507, 6.8004820602280756, 1.549930642758097, 2.52657128231866, 3.693080025059836, 3.7864781447819302, 7.636034641947065, 7.965497374534607, 7.00188558442252, 2.2955260915415625, 1.15565467945167, 0.0952037014067173, 0.11047203532819237, 0.430734355534826, 8.435171280588422, 24.79029883657183, 32.45434079851423, 26.56210858481271, 27.84656647273472, 20.720599957874843, 1.4432653720889772, 0.039512678515166044, 0.007395536372704166, 0.005967605227072324, 0.06860430086297648, 0.06597281313900437, 0.035515276049929004, 0.03837378462776542, 0.05933910195848771, 0.04573133321745055, 0.06335424472178731, 0.07624619294490133, 0.04477327909054501, 0.008093980456968504, 0.032555251847952604, 0.06522970872798137, 0.022728768776037862, 0.027412997957851206, 0.07651947970901217, 0.020540104879598533, 0.027124696910115223, 0.047869770255471976, 0.049971831031143665, 0.050770680486623726, 0.016028617142832706, 0.004877081556644822, 0.16592969984880515, 0.1505987982132605, 0.251474848815373, 0.13118828620229447, 0.08598926370697361, 0.08191763968872172, 0.12331778210188661, 0.22825649327465466, 0.09560707011925322, 0.1346480141260794, 0.19565200353307383, 0.16493747809103557, 0.11089324951171875, 0.11405622693044798, 0.13436806414808544, 0.13623852735119207, 0.1318512556276151, 0.1793477162718773, 0.042629006651363203, 0.11779604053923062, 0.13835102399545057, 0.09689555383686509, 0.1353553868830204, 0.10330358427017927, 0.12284721806645393, 0.10525823331304959, 0.16969710269144603, 0.13954998180270195, 0.11478073948196002, 0.1741451168698924, 0.24421984383038112, 0.12630750238895416, 6.134463352816446, 37.15994576045445, 40.504033837999614, 33.5516802242824, 34.691174370901926, 41.56982496806553, 26.436615433011735, 6.085858532360621, 0.41735931751983507, 0.16851571894117764, 1.603709808417729, 7.399415475981576, 11.398647461618696, 12.470630305153982, 9.660829169409615, 5.889518507889338, 2.2786886521748135, 0.41394601496202604, 1.358199879527092, 8.921612058367048, 24.052070106778825, 43.02957548413958, 47.71294273648943, 48.56271437236241, 49.71035875592913, 50.69085727419172, 52.06513799939837, 55.72067213058472, 49.54225056512015, 49.33965846470424, 46.564454146793906, 42.60393231255667, 44.00946256092617, 40.532187938690186, 43.17455312183925, 51.55255896704537, 52.608924865722656, 52.99763836179461, 46.12511954988752, 47.6663932800293, 48.6767760004316, 49.80357926232474, 52.01471839632307, 46.14603015354702, 42.94000278200422, 41.04388107572283, 37.57069199425833, 41.28988899503435, 37.73923792157854, 43.433908530644004, 50.56032146726336, 51.38635458265032, 50.82772636413574, 49.91106442042759, 47.0906412260873, 47.334797450474326, 48.18751859664917, 45.96741281236921, 40.06851380211966, 53.04430593763079, 50.965668950762065, 49.27524866376604, 47.68868310110909, 43.14280332837786, 38.11432252611433, 39.48929459708077, 36.356900760105674, 34.75829744338989, 37.51719781330654, 36.0373774256025, 35.80789579663958, 42.23956877844674, 45.44521747316633, 43.22010898590088, 43.975218364170615, 45.70091118131365, 47.42626353672573, 48.494719300951274, 49.00805221285139, 50.38161379950387, 47.02098206111363, 45.35748951775687, 43.598744119916645, 39.73098073686872, 38.399716309138704, 38.094742502485005, 36.473258767809185, 40.2386508669172, 44.68731491906302, 43.09399223327637, 43.412240573338096, 42.55570139203753, 42.7525577545166, 42.560829162597656, 44.35093525477818, 44.531525884355815, 46.934258120400564, 39.2012083871024, 22.793951102665492, 5.7743425624711175, 1.481129254613604, 3.2309820439134325, 7.7304511070251465, 7.273451583726065, 10.4864228112357, 7.884595155715942, 17.474827153342112, 12.07562608378274, 6.216092961175101, 0.8921987478222165, 0.315338809043169, 0.7256659524781364, 11.018835476466588, 26.813675062997, 38.14551993778774, 29.4969026020595, 35.227165358407156, 23.002784422465734, 1.492350161075592, 0.13716824246304377, 0.09602491198373692, 0.1036443445565445, 0.15473938174545765, 0.17989282416445868, 0.1694530743573393, 0.08261716179549694, 0.16045413937951836, 0.1740990172007254, 0.1764247774013451, 0.14136716643614428, 0.1564391933913742, 0.11067608437900033, 0.15379343607595988, 0.139362597571952, 0.08766463452151843, 0.10577043904257671, 0.18682112810867174, 0.08399401112858738, 0.12313267774879932, 0.11444479679422719, 0.1118596326559782, 0.14560682965176447, 0.17423992178269795, 0.13430263980158738], [0.08191580085882119, 0.036197621042707136, 0.01341506649207856, 0.03857381335858788, 0.07556524234158651, 0.04260914253869227, 0.04916065598704985, 0.017029454599001577, 0.008468534331768751, 0.04818936364193048, 0.04223663020612938, 0.015424176451883145, 0.029339708321328675, 0.03084239536630256, 0.019642988286380256, 0.04127355492008584, 0.02627895220315882, 0.06329128345740692, 0.03591353539377451, 0.04191580527861204, 0.009716030293410378, 0.023397804304425205, 0.006228571491582053, 0.03488035047692912, 0.025209487715203847, 0.0406952327383416, 0.023232525048245276, 0.0368183482704418, 0.03198484138452581, 0.022514093866837875, 0.03465940590415682, 0.1295483484864235, 0.14379212845649036, 8.199067149843488, 29.33862611225673, 29.587791987827845, 24.73260794367109, 31.680662359510148, 33.12554373059954, 18.89618018695286, 3.701041792120252, 0.24199422182781355, 0.0684680442458817, 0.23235639184713364, 0.8650568585310663, 4.699717666421618, 4.390115925243922, 3.248012512922287, 3.2356171437672208, 1.7241340322153909, 0.26456634061677115, 0.7856209267463002, 4.985855775220053, 16.040863139288767, 31.1190915788923, 42.35207748413086, 48.880698680877686, 50.15935829707554, 51.9851016998291, 50.35791002001081, 47.97326047079903, 48.25106682096209, 43.14766011919294, 43.18125465938023, 39.996711117880686, 36.9510794367109, 44.78351272855486, 51.20554508481707, 49.89523989813668, 48.529870237622944, 42.89850466591971, 47.1591921533857, 48.45092827933175, 47.63934046881539, 47.5259667124067, 44.20092017310006, 40.622740336826865, 37.253225326538086, 36.51560803822109, 34.752099650246755, 34.589067118508474, 37.09244401114327, 44.60587508337838, 47.65840285164969, 49.18875401360648, 50.74618925367083, 46.95049606050764, 46.24072020394461, 46.18190370287214, 45.49729074750628, 35.699219022478374, 43.923666204724995, 48.26462970461164, 47.32734898158482, 44.49399866376604, 44.50592524664742, 40.12141738619123, 35.763267517089844, 34.746165888650076, 33.02820641653878, 33.479516233716694, 33.663160596575054, 35.56963859285627, 42.615073748997276, 45.89904948643276, 44.488676343645366, 43.24918719700405, 39.62390899658203, 40.184222153254915, 40.85240956715175, 41.84194074358259, 43.2604432787214, 41.034754616873606, 39.46958603177752, 36.398749760219026, 39.234615325927734, 40.95649010794503, 41.705554553440635, 39.312306608472554, 35.05986663273403, 32.379029273986816, 34.60601030077253, 35.889658723558696, 37.3055556842259, 39.13937636784145, 41.64644970212664, 42.32643863133022, 43.18118517739432, 40.29348605019705, 23.669644730431692, 6.3091957824570795, 0.39281488742147175, 1.105696480189051, 1.9127394088676997, 1.9581087572234017, 2.61550800715174, 8.781841226986476, 7.676951714924403, 4.008471786975861, 4.266702456133706, 0.7865955201642854, 0.10780784900167159, 0.46118988416024614, 5.784716657229832, 17.567700249808176, 28.528830936976842, 23.501607758658274, 19.867260422025407, 24.795904295785085, 6.275817504950932, 0.09770014030592782, 0.1007096263180886, 0.06175677651273353, 0.026675357450065867, 0.015327330845009004, 0.051118962333670685, 0.02391206260238375, 0.009818953877714063, 0.008006635188524212, 0.027076023896890025, 0.0331861028181655, 0.06119760937456574, 0.03530705061608127, 0.02530697623400816, 0.04112821950444153, 0.025704104120710065, 0.04687792169196265, 0.017936906976891414, 0.06595439091324806, 0.05808748983378921, 0.0695682887786201, 0.02286614497591342, 0.02244518354668149, 0.01967213306176875, 0.06370795145630836, 0.02279327031491058, 0.056484223543001075, 0.060793555341660976, 0.12470157284821783, 0.019164246207635318, 0.05391663685441017, 0.005577545130758413, 0.017544277777363147, 0.06977818001593862, 0.02956391664754067, 0.039248775890363116, 0.019784054020419717, 0.032227549968021255, 0.02362315765848117, 0.06014600901731423, 0.022138573927804828, 0.015457687600116645, 0.013243457352343415, 0.030019278105880533, 0.018572879190157567, 0.06459212329770837, 0.012701349432713218, 0.015280930924096277, 0.01663817059514778, 0.07217756805143186, 0.031164540044431175, 0.03010488547650831, 0.07715902610548905, 0.031086328705506663, 0.0876610925687211, 0.020873754118968333, 0.023044433444738388, 0.04249847008447562, 0.32194426602550913, 13.124071904591151, 35.67354195458548, 31.44690064021519, 26.182997499193462, 38.48084347588675, 39.48544182096209, 20.151089123317174, 3.098806462117604, 0.15658701903053693, 0.047399928859834156, 0.08497380212481533, 0.8931554821985108, 3.9273993372917175, 5.188567732061658, 9.889309389250618, 4.880696092333112, 2.3409488541739325, 1.0273403418915612, 1.4964695743152072, 8.867373551641192, 20.356172152927943, 34.232958044324604, 45.055392265319824, 47.997530528477256, 49.70307009560721, 52.58242096219744, 51.23037099838257, 50.22769383021763, 48.94490698405674, 45.23143529891968, 44.27352884837559, 42.67548138754708, 38.417305673871724, 46.04759155000959, 51.289937904902864, 51.11324174063546, 49.38018730708531, 43.582346371241975, 46.85452406747, 49.59551545551845, 49.92292152132307, 48.93920251301357, 45.82608297892979, 42.559679235730854, 37.92043999263218, 38.22138384410313, 36.550050258636475, 34.588903835841585, 38.912910257067, 45.86463853291103, 49.858636787959504, 49.835356848580496, 49.49289403642927, 47.13893468039376, 47.148502349853516, 46.1621013368879, 46.05246571132115, 37.42063174928938, 45.280312401907786, 50.6648953301566, 49.18325104032244, 46.636673722948345, 44.908757482256206, 40.66264731543404, 37.02863870348249, 35.38035576684134, 35.162925788334434, 35.67435489382063, 35.575127669743125, 36.20075389317104, 43.2418429510934, 47.20460557937622, 44.9433525630406, 43.561373233795166, 42.30503123147147, 43.136112213134766, 44.2191800389971, 44.04506165640694, 44.79551921572004, 42.77819660731724, 40.92484106336321, 38.228436265672954, 40.35968501227242, 41.916866643088206, 43.002262115478516, 39.48549740655081, 35.662501267024446, 34.86708538872855, 36.51494795935494, 37.55658367701939, 39.3823687689645, 40.199570723942344, 44.0408684185573, 42.471218245370046, 43.57956709180559, 41.99268191201346, 27.893256630216325, 8.238573738506862, 1.2216955700090952, 1.3556638956069946, 3.243264070578984, 3.757172380174909, 3.397139745099204, 4.3445305313382825, 10.966340099062238, 9.518233026776995, 6.182203991072519, 0.3263839477939265, 0.028040848106944134, 0.46915941366127556, 5.048032598836081, 20.97236098561968, 33.39014155524117, 30.39805964061192, 23.04418526376997, 27.773686817714147, 9.69395991734096, 0.10430935637227126, 0.037599549030086825, 0.020814728357696106, 0.009694183162147445, 0.051664694478469234, 0.00733435626274773, 0.03353268154231565, 0.05941595283469983, 0.028746672107705047, 0.09485730927969728, 0.044868589511939456, 0.01482717929008816, 0.04108276105086718, 0.04859955163140382, 0.04751466234613742, 0.046531298863036294, 0.02172906108067504, 0.041592873499861786, 0.08148413723600761, 0.02944752075044172, 0.03402013770703759, 0.04848314555627959, 0.06014749500900507, 0.01972574580992971, 0.012433963378758302, 0.04939544606687767, 0.11501583829522133, 0.14042914605566434, 0.2125075462141207, 0.07760404329746962, 0.19771837336676462, 0.07694998982229403, 0.1414863850389208, 0.10955271537282638, 0.06831304649157183, 0.1306498008114951, 0.17521010472306184, 0.07943891055349793, 0.09912306895213467, 0.13729956613055297, 0.12215167896023818, 0.10324439566050257, 0.10701977128961257, 0.1290669007492917, 0.10944527613797359, 0.21694207111639635, 0.10716606343963317, 0.12558628751763276, 0.06496132098670516, 0.17791904721941265, 0.10929337928869895, 0.16146603865282877, 0.21836778175617966, 0.07705614662596158, 0.14694114162453584, 0.11931161635688373, 0.07791416094239269, 0.26114399997251375, 0.29660117306879585, 13.155794773783002, 41.4600191116333, 40.41469737461635, 34.66816888536726, 41.892047677721294, 43.66641610009329, 24.371622971126012, 4.947425723075867, 0.5823602250644139, 0.40490545864616123, 2.2400977058070044, 5.982844105788639, 13.108653851917811, 11.953296099390302, 9.552333916936602, 8.460183926991053, 4.005739842142377, 1.245765324149813, 1.1085379677159446, 7.352487342698233, 18.031330960137502, 33.61099352155413, 44.736848626817974, 49.42985997881208, 50.05693142754691, 54.457434041159495, 53.09363119942801, 50.94986179896763, 52.01989827837263, 47.33507885251726, 46.49114370346069, 43.78172492980957, 39.40948758806501, 48.206730365753174, 52.98876551219395, 54.34560278483799, 50.64997059958321, 46.27526664733887, 48.06694998059954, 50.57008368628365, 50.727227619716096, 51.45466579709734, 47.6308845111302, 45.35772575650896, 40.80801405225481, 42.153223514556885, 38.0490129334586, 37.181672777448384, 40.30048288617815, 46.9705033983503, 51.348559856414795, 52.21002531051636, 51.886781215667725, 48.47643859045846, 48.72570521490914, 47.310582978384836, 46.61824710028512, 38.760168007441926, 47.45984765461513, 51.413456031254356, 50.76816293171474, 48.767401354653494, 47.60332448141915, 44.50548751013619, 39.30158206394741, 37.49480724334717, 36.54136848449707, 37.39038971492222, 36.4953853062221, 38.91670049939837, 46.865151337214876, 49.888934407915386, 47.125211988176616, 46.116177218300955, 44.06574991771153, 44.7513564654759, 44.388320037296836, 46.1304349218096, 45.86886651175362, 44.11191374914986, 42.42339379446847, 40.20658145632063, 42.57751873561314, 43.90136248724801, 44.383011613573345, 42.211088112422395, 38.09409632001604, 35.98590169634138, 38.23351887294224, 39.54830912181309, 41.09517962591988, 41.81455789293562, 45.38524409702846, 44.966955593654085, 45.327518463134766, 40.63236706597464, 26.80676507949829, 8.760806424277169, 0.9770110653979438, 2.6872970121247426, 4.674514378820147, 6.82906173808234, 6.7906864030020575, 17.554953779493058, 16.54500358445304, 9.412346822874886, 8.162749784333364, 2.1025587660925726, 0.15109009827886308, 0.8408329412341118, 7.544108237539019, 23.183845792497905, 36.60171358925955, 32.71443619046892, 28.198218277522496, 34.63560267857143, 10.762180311339241, 0.20862157616232122, 0.22557649708219937, 0.16878269532961504, 0.12082692076052938, 0.12161478134138243, 0.08051212903644357, 0.11638612619468144, 0.13471326205347264, 0.13255291511969908, 0.18878095437373432, 0.22615317042384828, 0.20771769966397965, 0.08748727225299392, 0.14391142848346913, 0.12767166990254605, 0.14340089873543807, 0.12181986176541873, 0.09708622217710529, 0.13656601549259254, 0.1550571804067918, 0.10433495071317468, 0.20271548522370203, 0.19150536746851035, 0.08200787806085177, 0.10887322361980166, 0.13005844397204264], [0.06395790340112788, 0.048824659016515524, 0.04622511672122138, 0.03238989964925817, 0.0673544325732759, 0.006664796141974095, 0.02604048785620502, 0.014381123939529061, 0.042522486831460676, 0.04594661541549223, 0.058675325076494894, 0.03140426646651966, 0.030556888186505864, 0.029680404146867137, 0.01725952886044979, 0.06217385163264615, 0.021432252900142754, 0.031610710745943446, 0.05552613888201969, 0.05076183578265565, 0.033943581993558576, 0.07703825365751982, 0.02697499851430101, 0.006885476934257895, 0.04224463691934943, 0.015100759520594562, 0.03402872456769858, 0.07635300114218678, 0.03253821383363434, 0.03699487254821828, 0.017831075870032822, 0.033498581764953475, 0.05505409564024635, 0.5509683181132589, 13.315692799431936, 31.56608656474522, 26.64898017474583, 18.942031349454606, 33.39466135842459, 37.28618063245501, 20.01201571737017, 3.447536983660289, 0.3621136476950986, 0.10841807589999267, 0.3801868350378105, 1.460234175835337, 1.8094314209052493, 11.733212777546473, 3.9724875007356917, 2.7273974546364377, 0.4262163708252566, 0.8370566495827266, 1.0753020197153091, 2.811638500009264, 9.371115343911306, 23.33048231261117, 35.68541642597744, 48.016902106148855, 50.971755572727744, 50.85846519470215, 48.49798148018973, 49.14295496259417, 45.76087066105434, 43.93873337336949, 41.531686305999756, 40.3883741242545, 45.71188933508736, 49.114387444087434, 51.27558640071324, 49.40368611471993, 47.57513911383492, 47.28549998147147, 48.849098273685996, 49.43957008634295, 46.85782446180071, 47.028722354343955, 43.784910678863525, 39.64120306287493, 34.43720381600516, 37.10789680480957, 35.53234066282, 35.00424977711269, 39.4592992237636, 46.02952970777239, 47.02424424035208, 49.51454809733799, 47.673372745513916, 50.402552195957725, 46.779118742261616, 46.525891644614084, 36.681360789707725, 43.82021100180489, 46.76196711403983, 48.98441791534424, 48.20438882282802, 45.52218961715698, 45.0125983101981, 38.93475539343697, 34.623050757816856, 34.51256397792271, 34.00521346500942, 34.71088988440377, 37.97468457903181, 46.57007871355329, 46.70272329875401, 46.67885971069336, 45.25013290132795, 41.03649514062064, 39.83916766302926, 39.12126588821411, 40.13245112555367, 39.354641982487266, 37.21806396756853, 37.99790893282209, 38.86810827255249, 44.747336932591026, 43.94174541745867, 43.98727696282523, 43.33475078855242, 41.49251583644322, 36.83355760574341, 35.89141661780221, 39.803280217306956, 41.554889815194265, 43.29413161958967, 43.289889744349885, 42.509436811719624, 42.603042943137034, 26.65117233140128, 5.822845765522548, 0.08725578324603182, 0.3997627603156226, 1.3966467593397414, 2.3493309872491017, 2.466741212776729, 1.7738447019032069, 2.0966947036130086, 11.81874075957707, 7.241568471704211, 1.0328011917216438, 0.09329139973436083, 0.33763986666287693, 4.150494268962315, 16.30489468574524, 30.8579991204398, 26.101185934884207, 19.2029344694955, 24.53650198663984, 16.367680345262798, 1.2038393510239465, 0.08009008704019444, 0.01154192562015461, 0.022295420690040504, 0.06736244607184615, 0.03912882446976645, 0.012488744903488882, 0.02088563526714487, 0.03396102373621293, 0.019686516307826554, 0.032483825859214575, 0.0053882287715428644, 0.0443997218140534, 0.028346865704017024, 0.005559819251564997, 0.07785097576145615, 0.053029194474220276, 0.014231802130650197, 0.069591135052698, 0.07856605667620897, 0.035786615418536324, 0.015254113523821746, 0.07139246232275452, 0.01788178109563887, 0.029267139001084224, 0.02158214128576219, 0.07409255672246218, 0.07268452870526484, 0.01626686775125563, 0.042913536740733046, 0.037091428081371954, 0.009479626996575721, 0.03555242244952491, 0.005365392251405865, 0.03261181791978223, 0.015109183532851083, 0.05522526288405061, 0.033007400442979166, 0.05394738127610513, 0.006162004661746323, 0.050881827915353436, 0.03257958411372133, 0.045490293830100975, 0.0841039948697601, 0.033314613958022425, 0.04229532348524247, 0.038896880844341855, 0.03153440609042134, 0.11531493653144155, 0.05951731239578553, 0.03809569383572255, 0.03452317982113787, 0.059690121694334915, 0.04093536288876619, 0.013433109586393195, 0.045736415444740226, 0.04687133650960667, 0.02904024367619838, 0.0553189957115267, 0.052394106052815914, 1.3532400599547794, 19.401666845594132, 37.33353955405099, 28.559123345783778, 23.314140149525233, 38.062575817108154, 41.03667231968471, 20.445961986269268, 2.978301465511322, 0.36929537089807646, 0.0809083188484822, 0.22022816192890915, 0.663552531174251, 5.12245214836938, 9.694719876561846, 4.591984110219138, 3.95626562833786, 1.7407307816403252, 2.0715150833129883, 1.888510606118611, 5.408927244799478, 13.383047768047877, 27.292425053460256, 39.23372595650809, 49.37461485181536, 51.05638115746634, 52.35299144472395, 49.54316077913557, 49.89350979668753, 48.61773715700422, 45.189218044281006, 42.87600292478289, 41.77526930400303, 47.28597245897566, 51.507586751665386, 51.75892741339547, 50.31504658290318, 47.28520815713065, 46.90019110270909, 48.88389137813023, 48.61480154309954, 48.868171078818186, 49.02686446053641, 44.60392958777291, 39.592364174979075, 35.350895404815674, 38.43277931213379, 38.11712959834507, 35.97781746728079, 41.89317675999233, 47.50069611413138, 48.291481018066406, 50.480743748801096, 48.91940362112862, 50.919883796146934, 47.20293453761509, 46.22745609283447, 39.25519936425345, 45.81692177908761, 47.189038140433176, 50.54874924251011, 49.45204905101231, 47.5745450428554, 45.75816781180245, 40.65185676302229, 36.01675169808524, 36.67297778810774, 36.07937581198556, 35.34143195833479, 39.124903270176475, 47.64847387586321, 48.057163442884175, 46.593525409698486, 45.74072783333914, 43.04543822152274, 40.50243575232369, 41.0557416507176, 42.85220534460885, 41.822951316833496, 38.81277976717268, 39.54412283216204, 39.525793484279085, 45.532677922930034, 46.212732860020225, 45.555857113429475, 44.43454640252249, 42.044199330466135, 36.31778587613787, 37.083161217825754, 40.869415283203125, 42.61417048318045, 44.059152603149414, 42.860650879996165, 43.190117086683, 43.65380859375, 29.843027114868164, 9.300843868936811, 0.5082436821290425, 1.8214674379144395, 2.972070017031261, 4.19843510219029, 3.5614433629172186, 4.303814956120082, 5.212098675114768, 6.026081442832947, 4.022773350988116, 1.2734280569212777, 0.08205559264336314, 0.25941856684429304, 3.931873542921884, 17.940882784979685, 32.1955759865897, 29.558032853262766, 19.665291922433035, 26.98233389854431, 21.96187479155404, 2.166896479470389, 0.025767406348937323, 0.022803729932223047, 0.022299337533435652, 0.03176862959350858, 0.03644459082611969, 0.03310049544753773, 0.02281027100980282, 0.03998391430026718, 0.058287277684680054, 0.027220434808571423, 0.05736886018088885, 0.014081491356981652, 0.05627372840951596, 0.0327033014036715, 0.05021040394370045, 0.04391550226137042, 0.03324492162625704, 0.04091589232640607, 0.031056775112769434, 0.017310914317412034, 0.06433091445692948, 0.023579495626368692, 0.04430873026805265, 0.03277486988476344, 0.03770908833082233, 0.0661472509215985, 0.16037682709949358, 0.08876513689756393, 0.13771204756838934, 0.09520877684865679, 0.12023618817329407, 0.10336037086588995, 0.11780001675443989, 0.15217640570231847, 0.144379088389022, 0.19361120089888573, 0.12017292156815529, 0.17068382831556456, 0.08757730706461839, 0.0988058199041656, 0.18005609326064587, 0.09314874453204018, 0.20385482694421495, 0.09261528708572898, 0.11040408683142491, 0.14393938412623747, 0.19473885824637754, 0.18704220838844776, 0.11821887642145157, 0.1298929899930954, 0.08628595314387764, 0.12984942804489816, 0.18804365822247096, 0.1402513970221792, 0.09609718953392335, 0.1641658344971282, 0.10232504856373582, 0.10308017661528927, 0.2892665352140154, 1.1973951139620371, 22.066591092518397, 43.48882361820766, 37.44794511795044, 27.40204678262983, 42.41059521266392, 45.768795081547324, 24.522407565798076, 4.732694685459137, 0.7171859475118774, 0.3412163704633713, 2.05638234104429, 4.458825792585101, 6.2424900361469815, 21.363907609667095, 11.691013761929103, 5.86876163312367, 2.1092683374881744, 2.498723336628505, 2.300775238445827, 4.27501597574779, 12.75181087425777, 26.18279252733503, 37.27781500135149, 48.3099284853254, 52.70692573274885, 54.7228239604405, 51.69584124428885, 52.59300306865147, 50.864079339163645, 47.4710168838501, 44.78770249230521, 44.101241316114155, 49.18882002149309, 52.97181190763201, 53.385285309382844, 50.9616494178772, 48.93637807028634, 46.669792311532156, 47.95480258124215, 52.10168204988752, 50.24125671386719, 51.690254892621724, 45.41806738717215, 42.803727763039724, 37.72019985743931, 40.70239795957293, 39.85677439825875, 37.69325474330357, 42.23789426258632, 49.39042200360979, 49.42867531095232, 51.769429615565706, 50.60677017484392, 53.79827928543091, 48.013181345803396, 47.406478541237966, 40.94976077760969, 48.865124293736045, 49.8399669783456, 52.587451457977295, 51.57595355170113, 49.85569075175694, 49.36136811120169, 43.02904394694737, 37.44364070892334, 38.24793291091919, 37.470262731824604, 38.20120627539498, 42.06957762581961, 49.159373555864605, 50.129501887730186, 49.03239870071411, 48.609875270298545, 44.163170610155376, 42.08278962544033, 43.3259265763419, 44.4200941494533, 41.591204575129915, 40.46473830086844, 42.65102372850691, 42.93888064793178, 48.213831424713135, 46.95616231645857, 46.91536944253104, 46.11822346278599, 43.8413474219186, 38.820023264203755, 39.147912229810444, 44.02350834437779, 44.32099199295044, 46.01778725215367, 45.59468364715576, 45.0990686416626, 44.798916884831016, 28.62597370147705, 7.034542552062443, 0.3534897661634854, 1.769543549844197, 5.157115408352443, 5.803898027965, 6.238860470908029, 6.514428198337555, 9.268858705248151, 19.567075661250524, 12.723301546914236, 2.419300866978509, 0.464433878660202, 0.7755489157778876, 5.402378567627498, 22.54814989226205, 38.62595312935965, 32.9153641973223, 25.38012794085911, 34.758384295872276, 23.998230252947124, 2.0521009479250227, 0.24305194935628346, 0.09721131010779313, 0.08748422563076019, 0.12109408713877201, 0.12366463563271932, 0.12199550734034606, 0.1076249498873949, 0.07832432857581548, 0.15655676993940557, 0.1113635760598949, 0.11297005521399633, 0.140438957672034, 0.08551364458565201, 0.1463586464524269, 0.14046307280659676, 0.08898457512259483, 0.11935132422617503, 0.11449576834482805, 0.12430343564067568, 0.08983089828065463, 0.13652055364634308, 0.12392090473856245, 0.13444057240017823, 0.13142946468932287, 0.14109360825802597, 0.13784124063594], [0.012318874509739024, 0.04484010800453169, 0.06218168871211154, 0.04783488677016326, 0.0559521095960268, 0.04334574319156153, 0.010916631851744438, 0.02058396877587906, 0.06968560069799423, 0.059268038985984664, 0.013399812176690569, 0.03046466170677117, 0.029628353725586618, 0.01920339258919869, 0.005863574782519468, 0.040822359666760476, 0.026003110754702772, 0.02727715015810515, 0.02783057010466499, 0.043443516695073674, 0.07258769497275352, 0.03667465151686754, 0.035842201007264, 0.024714716942980886, 0.007895082335120865, 0.020116866965379034, 0.008012265332841446, 0.027130189651091183, 0.06678969466260501, 0.05424863386100956, 0.040271721713777096, 0.03443560130628092, 0.05683200327413423, 0.02542959599356566, 1.916885746376855, 18.371469599860056, 33.22279419217791, 20.89746461595808, 19.769895315170288, 26.77364127976554, 34.50469514301845, 20.910860742841447, 4.748498363154275, 0.11583378511880126, 0.18340561352670193, 0.570438907614776, 6.213463068008423, 9.126299909182958, 2.470463275909424, 2.09079481448446, 2.9017192891665866, 1.5699187644890376, 0.4991657521043505, 0.6322539363588605, 0.8323959282466343, 5.423399473939623, 13.24860794203622, 27.06045423235212, 46.63557243347168, 52.7612224306379, 51.5088860648019, 50.28594057900565, 46.593393393925254, 45.74431310381208, 41.98602901186262, 39.91118574142456, 43.176293645586284, 50.48961659840175, 49.55584124156407, 52.58147948128836, 49.17935657501221, 47.544528824942454, 48.05005543572562, 50.625662326812744, 50.61314862115042, 48.96650545937674, 47.8758328301566, 44.504281997680664, 36.636548382895334, 35.669498103005544, 36.35270404815674, 36.32974720001221, 35.77585417883736, 39.81430353437151, 45.90727962766375, 49.68904168265206, 47.42901502336775, 45.57471799850464, 49.06979043143136, 47.3008485521589, 38.25552034378052, 43.912021023886545, 47.152129309517996, 47.94680173056466, 48.68685436248779, 47.20645032610212, 45.620266914367676, 39.86955908366612, 37.20581429345267, 33.17684575489589, 33.04396145684378, 33.62426110676357, 39.96356821060181, 47.66551085880825, 48.07710129874093, 50.238473960331504, 46.02133430753435, 43.01919140134539, 38.84290715626308, 37.572675704956055, 37.206901686532156, 37.37317555291312, 38.6993921143668, 38.763339860098704, 41.43105207170759, 43.38073744092669, 45.71230622700283, 45.16390575681414, 42.890809535980225, 42.53569058009556, 41.87138026101248, 39.62432588849749, 41.552239077431814, 41.925395556858604, 43.99532992499215, 45.59684453691755, 41.52441849027361, 28.948323215757096, 8.270389539854866, 0.6885304908667291, 0.2616644634732178, 2.1570500135421753, 2.171132709298815, 3.0665047211306433, 2.4051595457962582, 3.036527152572359, 2.8562235704490115, 4.296625741890498, 4.051134594849177, 0.6575123752866472, 0.16128514121685708, 3.037277558020183, 14.228944046156746, 31.313179084232875, 32.972610405513215, 24.341912473951066, 29.043252979006084, 25.220468759536743, 5.823053342955453, 0.03409092926553317, 0.03342153411358595, 0.05580682507050889, 0.03182842888470207, 0.06813345862818615, 0.03516232927462884, 0.0410817500336894, 0.014280225782256042, 0.050660903698631694, 0.07491641358605453, 0.041831280171339, 0.009840347238683274, 0.012536322930827737, 0.01838061968529863, 0.03252631911475744, 0.027526131797848002, 0.06833353824913502, 0.016417214148012654, 0.015616534344319786, 0.04028722284627812, 0.04574368594746504, 0.08738408743270806, 0.030033388241593326, 0.02558215950349612, 0.01694318396039307, 0.02253237190390272, 0.04930438327469996, 0.07330916090203182, 0.04638337483629584, 0.047637161665729115, 0.02496762730048171, 0.05537626745977572, 0.055623298311339955, 0.04263259610161185, 0.009637271037458308, 0.0616719460647021, 0.04525588033720851, 0.038391962580915005, 0.024207240602533733, 0.0492486382302429, 0.03931377275979944, 0.025524953912411417, 0.042504078176404746, 0.07242495513388089, 0.012044385890476406, 0.04306293997381415, 0.06010970739381654, 0.04395433482048767, 0.01797277433797717, 0.041413071897945235, 0.019454806776983396, 0.03914234088733792, 0.03233515883662871, 0.014981635912720646, 0.07256695894258362, 0.0642103116427149, 0.050764505817954025, 0.054927935624229055, 0.020025010287229503, 0.010306784084865024, 0.11874715664557048, 3.713610214846475, 24.868224620819092, 36.898227964128765, 22.39221841948373, 26.09551273073469, 35.59223760877337, 43.26762771606445, 20.525334732873098, 4.418935750211988, 0.1378469131886959, 0.05234706661264811, 0.4150958332632269, 2.677247311387743, 9.483794280460902, 3.733803851263864, 3.9010830351284573, 3.4632657510893683, 4.116160179887499, 1.4628463728087289, 2.0197164799485887, 2.0306451278073445, 8.176933663231985, 16.055445671081543, 32.100899832589285, 49.926597118377686, 53.39652749470302, 52.22883408410208, 50.70899902071272, 47.757845469883506, 48.34171649387905, 44.83137192044939, 41.679394585745676, 46.868187699999126, 50.77274874278477, 51.61976541791643, 52.81666905539376, 49.194858006068635, 47.51120179040091, 48.99486105782645, 53.397538457598, 51.072167464665, 51.03661700657436, 49.201094014304026, 45.70777947562081, 37.823259013039724, 37.77505588531494, 37.970376695905415, 38.52358879361834, 37.336256299700054, 43.09026452473232, 48.10942431858608, 50.27328443527222, 48.75057976586478, 48.39564493724278, 49.99637787682669, 47.03732075010027, 39.952110631125315, 46.40037938526699, 49.59998662131173, 49.41652291161673, 50.7456716128758, 47.85545028959002, 47.93394756317139, 40.19834436689104, 37.25124856403896, 36.092959540230886, 35.17829172951834, 36.486679213387625, 40.44335521970476, 48.44338600976126, 49.401434898376465, 51.134899275643484, 47.210852009909495, 43.95845236097063, 41.16893822806222, 39.724876744406565, 37.72301387786865, 39.95966679709298, 39.686606066567556, 39.713241985866, 42.68581683295113, 44.51898438589913, 45.593064716884065, 45.99317673274449, 44.556650570460725, 43.87138101032802, 42.74851737703596, 40.60588748114449, 43.96926375797817, 43.30736098970686, 44.89313098362514, 47.26334565026419, 43.46166658401489, 32.48309939248221, 11.779182059424263, 1.2367364657776696, 0.9998903977019447, 2.8164336255618503, 2.881363672869546, 3.434767714568547, 4.149064677102225, 4.035800354821341, 4.086366304329463, 3.3238097599574496, 0.9182714287723813, 0.3896697690444333, 0.1174283559833254, 2.7355205501828874, 14.84826738493783, 34.72941378184727, 32.792429719652446, 24.586525542395457, 30.093641689845494, 28.57353217261178, 9.403749295643397, 0.07347842824778386, 0.019243463474724973, 0.08662599418312311, 0.02313394408806094, 0.056800064630806446, 0.04134369847763862, 0.02666328122307147, 0.021214692520775964, 0.03057215522442545, 0.03294020512008241, 0.04508118471130729, 0.028304805014548556, 0.023132263017552238, 0.01964859977098448, 0.0351752010839326, 0.007025074912235141, 0.030545220776860203, 0.11925905703433923, 0.02040682194222297, 0.04139309243432113, 0.02486568589561752, 0.037024663628212044, 0.008664695412984915, 0.009222932958177157, 0.02197295201144048, 0.05101702601781913, 0.02498662967367896, 0.2458531047616686, 0.1966359064515148, 0.11675978185875074, 0.16548861137458257, 0.14943626416581018, 0.11723968253604003, 0.10798362349825245, 0.15748900920152664, 0.16015000641345978, 0.12038561515510082, 0.1198884661176375, 0.09125593038541929, 0.14580714675996984, 0.1256193457437413, 0.09708430192300252, 0.1662360176976238, 0.22754698991775513, 0.17425695301166602, 0.10315243380942515, 0.15212850113000187, 0.16010321463857377, 0.19073935571525777, 0.13518576669905866, 0.1271215272801263, 0.13267016597092152, 0.13490065985492297, 0.10951185399400336, 0.14802704192698002, 0.10873172192701272, 0.14818310498126916, 0.14560339626457008, 0.13807206467858382, 0.12507738625364645, 0.15022648604852812, 3.4560020608561377, 27.209310701915197, 44.162527901785715, 30.28652020863124, 29.36778770174299, 35.895318031311035, 44.61398363113403, 25.198833806174143, 6.457363077572413, 0.30863621298755917, 0.3503911681473255, 1.809601977467537, 12.35666595186506, 17.81767037936619, 5.933322991643633, 6.842612896646772, 7.119255423545837, 5.25627966438021, 1.6165783064705985, 2.3973751749311174, 1.5690705414329256, 7.900642888886588, 15.888070515223912, 32.627614974975586, 50.265221050807405, 55.439360414232524, 54.52682222638811, 53.98180552891323, 50.65086344310215, 50.39178596224104, 46.37537281853812, 44.667099135262625, 49.59446280343192, 53.931705542973106, 53.23249442236764, 55.397257804870605, 49.9672440801348, 47.684132031032014, 48.759376185280935, 55.139743668692454, 54.89096689224243, 52.639476094927105, 51.06585850034441, 48.57607575825283, 40.416893005371094, 40.6955018724714, 39.49661105019705, 40.62746511186872, 40.13469191959926, 43.358301707676475, 49.73217609950474, 52.65351493018014, 52.462099007197786, 50.71157332829067, 50.22761740003313, 49.05872195107596, 42.438110079084126, 48.60691186359951, 49.55365603310721, 50.67847558430263, 52.701217787606375, 49.34947974341256, 48.859652587345664, 41.46565062659127, 39.7100944519043, 36.20386321204049, 36.05527598517281, 37.5428192956107, 43.03853518622262, 50.831818853105815, 51.52166032791138, 52.92087466376168, 48.88746622630528, 45.48015648978097, 42.091857024601524, 41.40225873674665, 39.966097354888916, 41.21009588241577, 42.09899282455444, 41.96077925818307, 44.73174170085362, 46.985007762908936, 47.650200503213064, 48.34789344242641, 44.933239459991455, 45.925157342638286, 44.809182848249165, 42.97285039084298, 45.16100140980312, 44.14653662272862, 47.066746371132986, 49.007079465048655, 43.79410661969866, 31.36259467261178, 9.920660529817853, 1.3804476857185364, 0.7462938513074602, 4.953513213566371, 6.660772459847586, 6.944057464599609, 7.318878906113761, 8.819719331605093, 8.206768359456744, 10.079458134514944, 10.024227772440229, 1.3182216818843568, 0.3943580389022827, 4.055215358734131, 17.984223910740443, 38.54451329367501, 40.93195949281965, 32.8810088293893, 37.37305048533848, 34.79190240587507, 9.193759100777761, 0.179455589769142, 0.11047917351658855, 0.22363324064229215, 0.0892629169725946, 0.17302481484200272, 0.1330458436693464, 0.14172271878591605, 0.2246178492371525, 0.14456496627203055, 0.1910938766918012, 0.08501148117440087, 0.1636871144707714, 0.06671743746846914, 0.10952520077782017, 0.09364800381341151, 0.13459421986980097, 0.16403487723852905, 0.16166742784636362, 0.12578751386276313, 0.09096878115087748, 0.09545906806098563, 0.1273235950086798, 0.11491021753421851, 0.15307538317782537, 0.09762670924620968, 0.11666233065937247, 0.19131592049130372], [0.02586726295495672, 0.02056707495025226, 0.051371292543730566, 0.035142024114195786, 0.007988981403676527, 0.04769937993426408, 0.01168597351560103, 0.028037418112424866, 0.09866539029670612, 0.04467783635482192, 0.028955542149820497, 0.050475945230573416, 0.017616478992359977, 0.0374510584266058, 0.0031621440929094596, 0.03193789354658552, 0.05902226681688002, 0.052801725787243674, 0.02967379182311041, 0.016692036097603183, 0.08462019038519689, 0.03716744775218623, 0.02757080993615091, 0.024800784021083797, 0.018592624559200237, 0.05344329761075122, 0.07489392693553652, 0.019195394357666373, 0.05755590514412948, 0.03606281988322735, 0.031348945506449254, 0.05075636339773025, 0.12000080437532493, 0.04325286192553384, 0.0841800586453506, 3.8598710979734148, 22.463378395353043, 27.91713237762451, 15.758457081658499, 20.270106554031372, 23.745447840009415, 31.692592416490825, 21.94767267363412, 4.08732385294778, 0.629362454371793, 0.05722439329006842, 2.513860204390117, 7.130344748497009, 2.856962902205331, 3.6957281572478156, 1.9647362530231476, 3.2761136335986, 0.8214328650917325, 1.4415040037461688, 0.4404796654624598, 0.4184486376387732, 1.0361134197030748, 6.012476001467023, 21.899540764944895, 48.15595293045044, 54.309263706207275, 49.14352124077933, 49.89147744859968, 48.06014769417899, 47.491611344473704, 43.28237526757376, 43.547369139535085, 47.86524377550398, 50.74506711959839, 52.801469870976035, 49.976419176374165, 47.662061078207834, 45.992832796914236, 48.48533575875418, 48.979783466884065, 50.115386622292654, 48.60264219556536, 47.30775506155831, 40.21012851170131, 36.4392786026001, 37.1059513092041, 37.2838008744376, 36.30708565030779, 37.38804817199707, 37.457502365112305, 45.263633251190186, 47.97391012736729, 49.42241498402187, 47.99898270198277, 51.91417448861258, 40.65057134628296, 43.86557231630598, 49.90032250540597, 46.250972270965576, 49.966924462999614, 48.77733033043997, 46.50160421643938, 43.65744250161307, 37.29442119598389, 33.8593499319894, 36.40201193945748, 33.54299150194441, 41.38564559391567, 46.75174283981323, 47.24271992274693, 46.75574152810233, 48.40398972375052, 44.24891485486712, 42.37938737869263, 37.449261801583425, 37.5664918082101, 39.984996455056326, 41.09234128679548, 41.4945308140346, 43.816062927246094, 43.46927833557129, 45.00339542116438, 42.362183638981406, 44.50604336602347, 44.06050750187465, 42.44545085089547, 42.981063161577495, 41.96178674697876, 45.31207956586565, 45.80389390672956, 40.61694553920201, 28.596909386771067, 9.483916742461068, 0.7063040371452058, 0.2873362387929644, 1.5333420357533862, 3.8397456407546997, 1.414711315717016, 2.7503239044121335, 3.523360937833786, 2.5825987330504825, 4.356786285127912, 1.314272933772632, 0.5214020503418786, 0.15120532709572995, 2.7444068619183133, 12.716954367501394, 30.575940472739084, 25.249474014554703, 41.83700057438442, 37.220766816820415, 21.635483162743704, 14.795375960213796, 0.3972072888697897, 0.056893654965928624, 0.07210362130509955, 0.01455310542535569, 0.05085093082327928, 0.042562014888972044, 0.11209443969918148, 0.10153715405613184, 0.024331599108076522, 0.00985688144075019, 0.01291126526692616, 0.054184685328177044, 0.04200313612818718, 0.04451432637870312, 0.015775774638833742, 0.025292550579511693, 0.024326160649902055, 0.06363984011113644, 0.024399691793535436, 0.045266177106116495, 0.02123135225182133, 0.05411805997469595, 0.014386324910447001, 0.03254698729142547, 0.024178044937018837, 0.022875471439744745, 0.032463473201330216, 0.012128541196164275, 0.017393078122820173, 0.08917497204882757, 0.029437790558274304, 0.024910694819742014, 0.04568962027717914, 0.005368825214515839, 0.03613965718873909, 0.009760492996844863, 0.024185500340536237, 0.0245354598654168, 0.0278479847059186, 0.0973779990204743, 0.03547854355669447, 0.026681694967140044, 0.017606199186827456, 0.05383319061781679, 0.046404182112642696, 0.027254685559975247, 0.021572059951722622, 0.009891151700035801, 0.06636715733579227, 0.04137766594067216, 0.037202120891639164, 0.02337591306838606, 0.025646881566249898, 0.04085688013583422, 0.04620444175920316, 0.034214524419179985, 0.04678235003458602, 0.041388078060533316, 0.056503955341343365, 0.013926215403314148, 0.027157967178417102, 0.019422605201335888, 0.1590795088559389, 7.131038265568869, 30.54818936756679, 30.93857737949916, 18.932778085981095, 23.27663724763053, 30.261715139661515, 39.06956434249878, 21.977143457957677, 3.507169029542378, 0.26176827933107105, 0.03194421070760914, 0.5768069316233907, 1.969102327312742, 4.067791163921356, 2.945837527513504, 4.655662613255637, 5.368593820503779, 3.89455737386431, 1.9347154753548759, 1.5913796871900558, 1.164451858827046, 2.6166737845965793, 8.131065130233765, 27.26757308415004, 51.41271257400513, 54.5183766910008, 51.26589366367885, 52.14641802651541, 48.525367804935996, 48.63273136956351, 44.69079596655709, 44.67269590922764, 50.152260712214876, 52.165793078286306, 54.13704218183245, 51.45265081950596, 48.91988999502999, 46.40272787639073, 48.67606381007603, 50.97519493103027, 51.58233199800764, 50.80518640790667, 49.754656996045796, 40.18001501900809, 37.98392915725708, 38.61163984026228, 38.94630677359444, 37.187408515385215, 38.68485648291451, 40.58228097643171, 48.32979685919625, 49.97496352876936, 50.19948066983904, 49.55724825177874, 52.98219946452549, 41.71161338261196, 45.46359198434012, 48.81202268600464, 47.36034945079258, 51.99051087243216, 50.847038882119314, 47.953239236559185, 44.87935617991856, 37.024935313633506, 35.88456916809082, 37.22745098386492, 35.346726485661094, 42.620493343898225, 49.776821749550955, 49.15800476074219, 49.70110375540597, 48.32206698826381, 45.40026262828282, 43.447245597839355, 37.83662039893014, 38.71704053878784, 40.899334226335796, 42.703871726989746, 42.61272873197283, 45.44498470851353, 44.83636767523629, 45.717979431152344, 43.1089517048427, 45.28546449116298, 44.72587047304426, 43.78266641071865, 44.87341547012329, 44.062692710331504, 45.653708594185964, 45.767606939588276, 42.756143024989534, 31.63893495287214, 12.623191901615687, 1.5128046806369508, 0.8309186760868345, 3.070985874959401, 4.233505266053336, 2.4454438984394073, 4.222261343683515, 4.943619413035257, 4.817040170942034, 3.5426953860691617, 1.0127516218594141, 0.3051031625696591, 0.1246497734848942, 1.9337021240166254, 13.000670160566058, 32.461236885615754, 33.19335120064871, 44.3787454196385, 35.83523348399571, 27.126173768724712, 19.77081595148359, 1.0199554924454008, 0.15323736305747712, 0.025137778438095535, 0.03502934319632394, 0.029839887017650262, 0.028829948710543767, 0.05715596981878791, 0.03568352898582816, 0.1418263039418629, 0.047384346303130896, 0.0352698838604348, 0.04876244753333075, 0.024653445230796933, 0.024828724396814193, 0.012324122129939497, 0.031275131074445586, 0.014619177772796579, 0.0683118047724877, 0.033255272677966526, 0.008153325977868267, 0.060746498938117705, 0.05020301130467227, 0.03253473973433886, 0.021554531695853387, 0.027799274373267378, 0.054261814403746805, 0.01499919979167836, 0.022476789707850133, 0.13535666252885545, 0.11282666040850536, 0.1286111016358648, 0.12704357717718395, 0.12499893403479032, 0.16442234787557805, 0.12185407350105898, 0.08785381008471761, 0.18090884893068246, 0.13724863529205322, 0.1301228098039116, 0.2167701032012701, 0.08146215270140342, 0.08976242052657263, 0.16385746747255325, 0.1380154477166278, 0.1655905951878854, 0.2497271325971399, 0.12783016211220197, 0.10934784529464585, 0.27112910417573793, 0.12210589141717978, 0.15990282967686653, 0.12630287478012697, 0.13700346701911517, 0.12536569578307016, 0.1291244812309742, 0.1164040666605745, 0.20060929895511695, 0.10266131016292743, 0.18077888233321054, 0.07892975823155471, 0.20739208427923067, 0.17242361924477986, 0.1607894306736333, 6.705190556389945, 33.310362339019775, 38.51558099474226, 24.7253383908953, 28.279020615986415, 30.426404816763743, 42.016545500074116, 27.43632745742798, 5.417681975024087, 0.8429050243326596, 0.2546651576246534, 4.7054429820605685, 12.017953429903303, 5.864095483507429, 10.335815395627703, 7.664191348212106, 6.781541705131531, 4.593493606363024, 3.8705222521509444, 1.0527276481900896, 1.1574163734912872, 1.9545771181583405, 7.814565130642482, 26.582379954201834, 51.30493559156145, 57.9654301234654, 53.32017721448626, 53.25924498694283, 50.27788066864014, 53.90431921822684, 48.32797990526472, 45.47008507592337, 51.77482489177159, 53.061401980263845, 56.99763291222708, 52.21588264192854, 49.39928790501186, 46.64012002944946, 49.772885595049175, 51.82798555919102, 53.69558491025652, 52.35899468830654, 51.24859959738595, 43.66890008108956, 40.08389016560146, 40.81390959875924, 40.10211876460484, 39.87668098722185, 39.923768929072786, 41.53291266305106, 48.370586259024485, 51.943763392312185, 53.368463720594136, 52.06085443496704, 53.66962991441999, 44.25936494554792, 45.186584677015034, 49.74676731654576, 48.89348684038435, 52.688374042510986, 53.63210269383022, 49.74388034003121, 47.6074343408857, 39.578248909541536, 38.59589522225516, 40.53788546153477, 37.48768881389073, 43.72753940309797, 51.26575122560774, 50.42980303083147, 51.32506104878017, 51.41637774876186, 47.68043906348092, 46.4311876978193, 39.161297934395925, 41.27328627450125, 43.477025577000205, 44.48065117427281, 45.33897951671055, 46.88662474496024, 46.32978221348354, 45.4614554132734, 45.42197922297886, 49.12383699417114, 46.868590695517405, 46.24508714675903, 45.46967165810721, 45.173747880118235, 48.914279324667795, 46.20578466142927, 43.02925934110369, 30.975830146244594, 11.130990692547389, 1.1256710312196185, 1.0496647953987122, 4.829764928136553, 8.140426090785436, 6.166879304817744, 7.919081670897348, 9.070308719362531, 8.059153011866979, 12.03331937108721, 4.160084085805075, 0.720494809959616, 0.3008439711162022, 3.68823105096817, 16.191621678216116, 37.248406750815256, 32.93302304404122, 46.88454375948225, 42.954326493399485, 32.170496463775635, 22.007915292467388, 0.9609209916421345, 0.22510921715625695, 0.11585496898208346, 0.1557720306196383, 0.12276162765920162, 0.1401902474462986, 0.14950339842055524, 0.17831656017473765, 0.14972681286079542, 0.16847483042095387, 0.08559717903179781, 0.14168222381600312, 0.14089546246188028, 0.1068170318113906, 0.08337068171905619, 0.1431400698742696, 0.09836149481790406, 0.23905402102640697, 0.12887719592877797, 0.13220376814050333, 0.1406062301248312, 0.09501670394092798, 0.04250192382772054, 0.08200105878391437, 0.06333031279167958, 0.16865622997283936, 0.09941409940698318, 0.05694864344383989], [0.03824412676372698, 0.02184561812984092, 0.027205457844372307, 0.06660610344260931, 0.019594703734453236, 0.017186033339904885, 0.02613802726513573, 0.0436984355162297, 0.04762090735935739, 0.021181152534804175, 0.024003111823861088, 0.020526252587192824, 0.06974395470959799, 0.005856356442174209, 0.020452414406463504, 0.027801315067335963, 0.06416132819971868, 0.028046364596645747, 0.06584524855549846, 0.019919377651863863, 0.03468759564150657, 0.01970391733837979, 0.0584688875824213, 0.031387004535645247, 0.033030840435198376, 0.0532504749218268, 0.03893411884616528, 0.02234690453458045, 0.050785794854164124, 0.033349351558302126, 0.030020536788340126, 0.043985683138349226, 0.03494015655347279, 0.042340106796473265, 0.0458188642348562, 0.07668662324015584, 4.48855105468205, 21.85159124646868, 30.566775798797607, 18.62848346573966, 19.59390091896057, 22.317494017737253, 32.027763094220845, 17.821889672960552, 5.47951442854745, 0.5068035051226616, 0.22342282693300927, 2.5588278600147794, 3.7866861564772467, 1.100325414112636, 2.5430938814367567, 4.557047264916556, 2.8408600177083696, 1.721005605799811, 2.532422968319484, 0.6374555858118194, 0.10161319747567177, 0.5781733925853456, 4.492096373013087, 22.816350357873098, 49.929727281842915, 53.55531120300293, 50.814632483891074, 51.803319454193115, 49.483962127140586, 47.24777126312256, 43.654110840388704, 46.51582023075649, 47.26405784061977, 51.65878997530256, 51.18420716694423, 52.39847435270037, 48.976003646850586, 47.623859882354736, 47.80782733644758, 52.04380702972412, 49.70673874446324, 50.17548854010445, 41.17201280593872, 36.3993889944894, 36.769463947841096, 38.81524290357317, 38.09326948438372, 37.44303274154663, 38.09893921443394, 40.08990730558123, 41.98492772238595, 46.9175511768886, 49.68892356327602, 50.49346242632185, 42.52603258405413, 41.55972228731428, 50.76415034702846, 47.92875031062535, 50.50831767490932, 49.12782873426165, 47.77109221049717, 44.73059524808611, 39.508662700653076, 34.84834957122803, 35.27445479801723, 36.02731990814209, 43.80593940189907, 48.07926913670131, 47.941441195351736, 48.80707209450858, 48.282833984919954, 47.55372129167829, 43.77828557150704, 38.244514397212434, 35.84156329291207, 40.081430503300254, 43.76321145466396, 44.27710369655064, 44.22742755072457, 44.526484966278076, 47.491448061806814, 43.43642725263323, 44.78972789219448, 45.84681292942592, 44.856896127973286, 42.81183978489467, 44.777512959071565, 45.199765409742085, 39.608664648873464, 26.730234146118164, 11.20168513911111, 0.9456508053200585, 0.3782729591642107, 0.7517351050462041, 2.27671862074307, 1.7922043395893914, 1.3398392647504807, 2.354024712528501, 3.723600421633039, 3.4983107277325223, 2.0418629944324493, 0.5971067452004978, 0.5268980211445263, 1.5246572217770984, 14.64225503376552, 27.503995963505336, 29.14085258756365, 17.356537546430314, 25.531100136893137, 41.11642721721104, 22.68783473968506, 4.367308897631509, 0.08381162091557469, 0.04623075873990144, 0.051958238905561824, 0.047514791267790964, 0.017292273264112215, 0.03976628776373608, 0.03447096994412797, 0.01633980348041015, 0.016645809203120213, 0.04797426464834383, 0.0392721785631563, 0.0391383341380528, 0.05645813387153404, 0.10583362422351326, 0.01399080769624561, 0.04829734909747328, 0.06930304265448026, 0.012804078786367816, 0.024549831237111772, 0.02397278809387769, 0.05013644701934286, 0.06264989144567933, 0.025250065805656568, 0.045258360382701666, 0.05000882476036038, 0.06293115778160946, 0.017050344995888214, 0.041418907299105606, 0.026988022993983965, 0.040036171674728394, 0.02453179407997855, 0.07477502724421875, 0.05186896066048315, 0.08907381604824748, 0.041130943822541406, 0.06489958787070853, 0.00837990578397044, 0.032954491674900055, 0.039721100724169185, 0.03949275333434343, 0.060819034331611226, 0.050770792444901805, 0.039610258636197875, 0.05898287107369729, 0.036319821806890626, 0.015774549883125082, 0.017038847219997218, 0.003340209917431431, 0.04615904437378049, 0.04554505839145609, 0.01990258730282741, 0.06900141348264047, 0.06265647323536021, 0.05744803843221494, 0.03007765925888504, 0.0398293304523187, 0.02187077990466995, 0.008447087536166822, 0.01725871461842741, 0.06013142051441329, 0.04866353069831218, 0.048092000652104616, 0.015498477732762694, 0.17789440282753535, 8.068297709737505, 28.793576410838536, 32.20445925848824, 20.00790412085397, 18.8838540826525, 31.00997359412057, 41.456815992082866, 20.177005904061453, 4.803409976618631, 0.39016816658633097, 0.03846235380374959, 0.23022125927465303, 0.6441222195114408, 1.8884860702923365, 4.0146956358637125, 5.250632515975407, 6.929142722061702, 3.8990906391824995, 2.4866373794419423, 2.4811741411685944, 1.2005059527499335, 1.5012785962649753, 6.6765366196632385, 28.25047046797616, 52.38128798348563, 54.75615446908133, 51.77455391202654, 54.21914904458182, 51.54551696777344, 47.75268643242972, 45.58823571886335, 47.36535562787737, 49.40174756731306, 52.831861291612896, 53.08898285457066, 50.9987666947501, 48.947936398642405, 48.63948154449463, 48.448180266789024, 52.8646046774728, 50.713661261967246, 50.05935982295445, 42.15210485458374, 39.713301045554026, 38.79702820096697, 39.15746600287301, 39.67863995688302, 38.66489083426339, 39.54072168895176, 40.733987944466726, 44.166874000004356, 51.03161777768816, 50.21164696557181, 53.24277080808367, 43.974645137786865, 42.344646385737825, 50.73277923039028, 49.42435005732945, 53.167296000889365, 50.39705964497158, 49.127352782658164, 47.74291031701224, 41.090354101998464, 36.01860686710903, 37.60216038567679, 37.09526150567191, 44.76230682645525, 50.49005086081368, 49.69437095097133, 49.53594854899815, 49.46148123059954, 49.08969007219587, 43.466728346688406, 39.53943974631173, 37.85771860395159, 41.860450744628906, 44.73250947679792, 46.00367546081543, 45.452113560267854, 45.05150127410889, 47.55705642700195, 44.01567425046648, 47.107296058109824, 46.388390268598286, 45.92098147528512, 44.86662013190133, 45.0638655935015, 46.756957462855745, 41.5954464503697, 31.71117537362235, 13.287697638784136, 2.222587811095374, 1.1057035369532449, 3.820085278579167, 3.577126749924251, 4.207146406173706, 3.9290816698755537, 3.6539590614182607, 4.9196368370737344, 3.769571006298065, 2.13936967083386, 0.40884473440902575, 0.18731196677046164, 1.1027193942240305, 14.259260773658752, 30.450688770839147, 33.393608706338064, 20.364299808229717, 34.15263686861311, 44.886540617261616, 25.78720552580697, 6.789436595780509, 0.10006910961653505, 0.012848950307151037, 0.04692929357822452, 0.031248013422425305, 0.057268816977739334, 0.009753597384717847, 0.025485332556334988, 0.0011334946570319257, 0.0554508791704263, 0.014461757648470146, 0.02326564603884305, 0.03360114911837237, 0.010207502537273934, 0.040455893081213744, 0.060627633173550875, 0.027793245589626685, 0.051361765912068744, 0.041004668455570936, 0.036780455482325385, 0.019677101634442806, 0.05886888397591455, 0.0474227988826377, 0.014080137679619449, 0.02156514737622014, 0.07058548741042614, 0.05798045093459742, 0.03630521973328931, 0.049235311802476645, 0.11554964179439203, 0.10250219370105437, 0.13332419230469636, 0.23252195439168385, 0.1374030698622976, 0.13381705300084182, 0.08788310922682285, 0.16874454809086664, 0.10279359056481294, 0.1315802623118673, 0.12940694178853715, 0.12179170256214482, 0.12190925196877547, 0.22433390947324888, 0.12995791222367967, 0.1477627796786172, 0.10151826364121266, 0.11012083917324032, 0.2234173986528601, 0.10158478042909078, 0.14521022593336447, 0.17325844801962376, 0.1286163670676095, 0.13868889372263635, 0.14862153359821864, 0.173999815380999, 0.0962531508079597, 0.10866861138492823, 0.14836495236626693, 0.14422404313726084, 0.24647510424256325, 0.1566674661423479, 0.09740807847785098, 0.1316177174448967, 0.1176557330680745, 0.29635679189647945, 8.196980953216553, 34.24069138935634, 42.219321727752686, 27.044918060302734, 28.68366285732814, 30.507733481270925, 41.11497504370553, 23.778767926352366, 7.4179098435810635, 0.8972527480551175, 0.8495657954897199, 4.529055578368051, 7.728373595646449, 6.5486723950931, 6.823927887848445, 11.18075716495514, 7.0333170635359625, 5.970598774296897, 7.39578069959368, 2.5039173322064534, 1.1257647233349937, 1.6158718700919832, 6.451963893004826, 26.61687776020595, 52.12268645422799, 57.928396224975586, 54.229512282780235, 56.6665929385594, 53.491464206150596, 50.47181878771101, 48.71399055208479, 50.37342187336513, 51.306016036442344, 55.80466195515224, 54.57420894077846, 53.265807560511995, 48.73277153287615, 49.13370343617031, 49.990920066833496, 54.23444550377982, 54.14583512714931, 52.5624657358442, 43.888112272535054, 40.8933379309518, 41.36952577318464, 41.34567608152117, 41.65852219717843, 39.50315972736904, 41.56735488346645, 42.48387786320278, 45.31679391860962, 50.638860430036274, 53.02988495145525, 53.62766974312918, 47.23987463542393, 44.146800654275076, 50.81823512486049, 50.53785446711949, 55.016698019845144, 51.37539379937308, 50.83442095347813, 49.896480151585166, 42.82909911019461, 38.76646307536534, 38.635510376521516, 39.46175193786621, 47.45849275588989, 51.75104120799473, 51.595352922167095, 50.23597955703735, 50.716061864580425, 51.34587785175869, 45.774902548108784, 40.98516879762922, 39.71000065122332, 43.59991489137922, 48.31843308040074, 46.73195784432547, 47.21827963420323, 46.03206580025809, 49.04689264297485, 43.56142881938389, 47.11320202691214, 48.81621592385428, 47.68333298819405, 46.62789119992937, 46.80261754989624, 46.70133713313511, 42.24901832853045, 29.544219834463938, 12.754391261509486, 1.6984602212905884, 0.8479401884334428, 3.468975216150284, 5.211466823305402, 6.309837188039507, 5.0095712797982355, 7.058312339442117, 9.771124005317688, 10.385880640574864, 4.2153161849294385, 1.9507957782064165, 0.7385258195655686, 2.315951624086925, 18.244691031319753, 33.98808962958199, 37.27556378500802, 23.033248799187795, 34.32525791440691, 47.87943547112601, 32.05038295473371, 7.017043948173523, 0.1963818629405328, 0.11727891543081828, 0.11571763349430901, 0.14170498188052857, 0.12651740041162285, 0.13763196686548845, 0.08943141757377557, 0.1524056012609175, 0.1238884979060718, 0.1563722084143332, 0.07960416775728975, 0.14428885680224213, 0.09567266409950596, 0.19136712274381093, 0.11944621056318283, 0.11908087373844214, 0.18982830031641892, 0.15964869117098196, 0.07662816744829927, 0.15835594625345298, 0.13182080297597817, 0.10579228108482701, 0.09970951319805213, 0.10413314082792827, 0.1699368426842349, 0.135687719764454, 0.11315536312758923, 0.10925371213150875], [0.03084112989849278, 0.05035751712109361, 0.05021314522517579, 0.032800321733312945, 0.04819660021790436, 0.03398481995931693, 0.03222352286268558, 0.049642141043607674, 0.018920119485950897, 0.028254729130172303, 0.01951922519531633, 0.03810157673433423, 0.04567066879410829, 0.015310409877981459, 0.01621242379769683, 0.06750185787677765, 0.037166616546788385, 0.03112283388950995, 0.007357867501143898, 0.01863851727518652, 0.011006182358999337, 0.024965060741773674, 0.06500585323997907, 0.09311753192118236, 0.03593856994328754, 0.09545978052275521, 0.08427772019058466, 0.05450087246884193, 0.07258892312113728, 0.03778198334787573, 0.03437418370906796, 0.06798722076096705, 0.028326356983078376, 0.039315486060721536, 0.00808787957898208, 0.053754256639097414, 0.26875979559762136, 5.943343162536621, 23.63056285040719, 31.360440731048584, 22.220841101237706, 19.832858153751918, 28.97469857760838, 34.670600754874094, 23.35736836705889, 8.549471752984182, 0.891855463385582, 0.044022571694638045, 0.7837535983749798, 0.8189052950058664, 2.7095418870449066, 4.496620084558215, 6.080772450992039, 2.8801101744174957, 1.6857211334364754, 1.784618752343314, 1.3840403386524744, 0.5626040537442479, 0.28039075434207916, 5.298086106777191, 26.86411029951913, 49.2745885848999, 53.45029265539986, 52.285802364349365, 51.45406130381993, 53.96545989172799, 50.16114745821272, 48.02943318230765, 50.28406456538609, 52.50444827760969, 51.47684792109898, 49.30935042245047, 48.30923366546631, 49.5252274785723, 50.64659377506801, 49.84784623554775, 49.083551338740754, 49.106612409864155, 41.36859471457345, 38.40921449661255, 39.358366216932026, 38.00341885430472, 37.946731976100374, 38.03916733605521, 36.414869580950054, 39.0119811466762, 41.75911474227905, 48.15136364528111, 47.06960555485317, 55.38771445410592, 43.911635398864746, 41.576328481946675, 49.367777824401855, 46.40803977421352, 48.53448384148734, 49.081032616751536, 49.616294043404714, 46.711905343191965, 42.281560216631206, 34.857410022190635, 35.5340290750776, 36.977454798562185, 45.95477056503296, 47.35956430435181, 47.48871741976057, 49.57451105117798, 48.73036050796509, 46.768988268715994, 44.84672049113682, 41.01640442439488, 39.81753444671631, 43.24311447143555, 45.50177928379604, 45.734582151685444, 46.10344117028372, 45.35980674198696, 46.83737938744681, 45.09508037567139, 44.7969331741333, 45.06890303747994, 43.783965723855154, 44.14758927481515, 43.171669619424, 37.70981230054583, 25.20748778751918, 12.162759099687849, 1.0059139430522919, 0.2322183506829398, 1.563784156526838, 3.4460802503994534, 2.2032937492643083, 2.9953060959066664, 2.482400281088693, 2.3136404795306067, 4.611378703798566, 2.540525653532573, 0.5822125215615545, 0.08708025980740786, 1.4104107064860207, 11.432482583182198, 23.49480026108878, 24.81104963166373, 23.14539967264448, 16.209087712424143, 24.5730390889304, 22.086707864488872, 5.123424896172114, 0.15608175471425056, 0.019840730354189873, 0.027273179031908512, 0.043836300261318684, 0.04062414262443781, 0.056516209683780155, 0.04633875098079443, 0.05274857274655785, 0.07344252017459699, 0.014773086478401507, 0.012129011929833462, 0.035919119736977985, 0.05654156653742705, 0.016452993299545984, 0.03269236681184598, 0.025773273980511085, 0.03893890930339694, 0.037141551463199515, 0.03483423384438668, 0.017305313010833094, 0.03136579692363739, 0.03708869019257171, 0.021221559295164685, 0.04630364018625446, 0.032366513939840455, 0.013902011211030185, 0.033604911595050774, 0.10420515374945742, 0.031338811585945744, 0.013481401771839176, 0.027375756563352685, 0.04522720544732042, 0.03168280848434993, 0.04320857733754175, 0.033934340346604586, 0.027664057611088668, 0.009672060376033187, 0.03897733813417809, 0.03068680389385138, 0.03628467369292464, 0.057987433059939315, 0.02887906107519354, 0.053382483909704855, 0.030651967905993973, 0.05792852264962026, 0.040050166459488015, 0.05406273901462555, 0.016692165019256727, 0.03933946888095566, 0.05243210740653532, 0.027292115247941444, 0.07201830909720489, 0.031663198822310994, 0.042080431444836516, 0.037135078239121606, 0.06983462734413998, 0.0073770734348467416, 0.024161500556926643, 0.03959109002192106, 0.03314887499436736, 0.03974469677944269, 0.014039082918316126, 0.051446565826024325, 0.02192054535927517, 0.06216792802193335, 0.6214010130081857, 10.054778133119855, 31.071440832955496, 31.48592519760132, 19.30122889791216, 19.99750440461295, 33.177523204258506, 39.57349634170532, 23.145503895623342, 7.996823327881949, 0.5688517327819551, 0.1576939132064581, 0.1379474177956581, 0.8910145685076714, 2.5289866498538425, 3.2356898827212195, 11.3599077803748, 4.193061973367419, 2.9807965201990942, 3.002168744802475, 2.360432254416602, 1.3401495452438081, 1.087786738361631, 6.820012577942439, 31.901128700801305, 50.96712459836687, 57.01330804824829, 53.72000782830374, 52.528659275599885, 54.21455628531319, 51.11722305842808, 49.27721847806658, 51.11033739362444, 54.055300099509104, 52.30884606497628, 50.99998262950352, 48.71500498907906, 50.341223921094624, 50.83455991744995, 52.64244992392403, 51.18747976848057, 49.725516251155305, 42.640062945229666, 39.50280884334019, 39.999136039188926, 39.58714607783726, 38.59438746316092, 40.4271867615836, 37.56223256247384, 40.60414348329817, 43.790903500148225, 50.015256132398335, 49.952451365334646, 54.99305330004011, 46.15314163480486, 43.01552970068795, 48.362328324999126, 46.996034554072786, 51.32385901042393, 50.39088617052351, 50.69084685189383, 49.36572463171822, 43.55200011389596, 36.44158887863159, 37.76775680269514, 38.35473714556013, 47.687512329646516, 48.832050868443076, 49.70479672295706, 47.96202175957816, 49.952260289873394, 48.34703533990042, 46.71628270830427, 42.76172590255737, 40.306420121874126, 44.54907008579799, 46.57191998617989, 47.697114740099224, 47.9173378944397, 45.80842760631016, 46.90457541601998, 45.55771228245327, 45.67715876443045, 46.225937911442344, 46.858008589063374, 47.33194521495274, 45.363867964063374, 39.67262976510184, 28.84034126145499, 14.489971365247454, 1.9693544166428703, 0.8730946757963726, 1.7602272097553526, 4.27340920482363, 3.8244578668049405, 4.428666702338627, 6.429780031953539, 5.27845310313361, 4.066269508429936, 1.8553585793290819, 0.13391553557344846, 0.0010212702660023101, 1.238917548741613, 11.123352885246277, 30.42096437726702, 31.615766184670584, 27.366841997419083, 16.242006540298462, 27.121890204293386, 30.509852681841167, 9.796593495777675, 0.3955779363002096, 0.01800277746016426, 0.06242613773792982, 0.05001339469371097, 0.05100872753454106, 0.00967343695395227, 0.0406456827186048, 0.05752231766070638, 0.06312428920396737, 0.07168409667376961, 0.026171706350786344, 0.013554323082124549, 0.032212082762271166, 0.018068395189142654, 0.03136763914621302, 0.018274255928450396, 0.02419444852109466, 0.038733079098165035, 0.044923978325511725, 0.008960708011207836, 0.07092389318027667, 0.048386532347649336, 0.019301503663882613, 0.032867707046014924, 0.048215354925819805, 0.009587438577519996, 0.08196859766862222, 0.032208639197051525, 0.031162185527916466, 0.11152229218610696, 0.13248451878981932, 0.19154298544994422, 0.09545591287314892, 0.15864975191652775, 0.0770315836582865, 0.10556639677711896, 0.10433041809925012, 0.17424966554556573, 0.10088409802743367, 0.10242406039365701, 0.1222605159772294, 0.11209290621003934, 0.11794694672737803, 0.12345737032592297, 0.11087984165975026, 0.16194273664483003, 0.10862445232591458, 0.06907263251819781, 0.14578438869544438, 0.14010924393577234, 0.07024531066417694, 0.11521612826202597, 0.1350233389862946, 0.09505843384457485, 0.15401056728192739, 0.14558489939996175, 0.062392394191452434, 0.12258021453661577, 0.10319484903344087, 0.11811554910881178, 0.14225530092205318, 0.14752146548458508, 0.13882711130593503, 0.10404314672840492, 0.1434914017362254, 0.5420785865613392, 10.433521832738604, 37.28956093106951, 41.74690328325544, 30.210336685180664, 27.13114173071725, 37.24545724051339, 44.03895418984549, 30.504999365125382, 11.811200227056231, 1.674716706786837, 0.27261981847030775, 2.0282195551054816, 4.045176948819842, 8.334584815161568, 10.550828269549779, 15.271452631269183, 8.35469811303275, 6.434913447925022, 4.7226888452257425, 3.558250448533467, 1.3590483197144099, 0.7191940854702676, 7.147058205945151, 29.324055739811488, 51.60657773699079, 58.555644852774485, 56.60706772123064, 55.13857984542847, 57.925874028887065, 53.37558562414986, 50.400186334337505, 55.371865613119944, 57.833984102521626, 54.98665400913784, 50.332535198756624, 49.62720966339111, 51.00473519733974, 53.19405351366316, 54.10986777714321, 53.15761021205357, 51.692269870213096, 45.52316583905901, 41.052159854343955, 43.33470215116228, 41.39548771721976, 40.10419280188424, 42.549944809504915, 39.12785278047834, 42.22422020775931, 45.3877523967198, 50.779269627162385, 51.46334409713745, 58.685395513262065, 48.655983516148154, 44.07831226076399, 49.66908645629883, 49.08749444144112, 51.07486336571829, 52.08621188572475, 53.294861452920095, 50.69028752190726, 46.798608439309255, 38.673920018332346, 39.38502992902483, 40.09644208635603, 49.38894551140921, 51.7413067817688, 50.15469952992031, 48.87962171009609, 50.464533601488384, 50.42659991128104, 49.01606001172747, 44.306102003370015, 42.62867832183838, 48.27028553826468, 48.043159348624094, 48.86851154054914, 48.725503717150005, 44.96582303728376, 47.85732977730887, 46.262384687151226, 46.99408558436802, 47.22763538360596, 46.85750137056623, 46.99888678959438, 45.767982142312185, 39.42948450360979, 26.151351928710938, 13.885180183819362, 1.6615421622991562, 0.9269728532859257, 3.660697077001844, 6.336357593536377, 5.601886970656259, 7.423334649630955, 8.462766919817243, 8.203836219651357, 10.551423209054128, 6.411059847899845, 2.1438458306448798, 0.19897938998682158, 2.006274104118347, 14.292001553944178, 29.593989780970983, 32.724549293518066, 31.168788569314138, 22.431566068104335, 34.258794920785085, 31.45960542133876, 9.519869327545166, 0.34062783632959637, 0.19813540098922594, 0.12683382843221935, 0.1782497109047004, 0.1191550511866808, 0.12690382610474313, 0.16458124720624515, 0.1364094503223896, 0.16762089409998485, 0.13053729970540318, 0.04916947694229228, 0.11533404407756669, 0.13872168053473743, 0.1136845186618822, 0.09677920543721744, 0.09624859105263438, 0.09607447896684919, 0.1807086539587804, 0.17112912370690278, 0.10715693714363234, 0.10656463714050395, 0.16404721300516809, 0.08864765534443514, 0.10267702503395931, 0.15574897399970464, 0.09381280639874083, 0.1566724737307855, 0.21544001171631472, 0.14867962976651533], [0.05919937802744763, 0.011940116262329476, 0.0870098482285227, 0.03250869077497295, 0.06607306668800966, 0.04417468567511865, 0.03257907521245735, 0.02325865543181343, 0.02153772777611656, 0.0335728202813438, 0.004149248000300888, 0.032354388519057205, 0.017267247196286917, 0.048423400547887595, 0.07491954841784068, 0.06458121923995869, 0.02093881375289389, 0.018352038093975613, 0.031350353466612954, 0.06296072155237198, 0.05242922702538116, 0.039966095970677476, 0.052766116269465, 0.0319619510056717, 0.03367081091606191, 0.025812618833567415, 0.028714838637305156, 0.007644106650591961, 0.037194884315665276, 0.022181075665035417, 0.02999041661886232, 0.04588746412524155, 0.07708629393684012, 0.03381804283708334, 0.05621355931673731, 0.012700672594032117, 0.04190103696393115, 0.40893622807094027, 8.301573055131094, 29.83088513783046, 29.58901834487915, 26.985088859285625, 22.87074259349278, 26.324532304491314, 38.683206285749165, 28.525066750390188, 12.354164600372314, 1.3624065795115061, 0.06452587113848754, 0.585585600563458, 2.288630221571241, 2.1021205953189304, 10.444608552115303, 3.929773449897766, 1.6614337052617754, 3.6225039150033678, 1.9497537655489785, 0.5467769801616669, 0.6701079394136156, 0.3896698233272348, 7.236231820923941, 28.725454534803117, 50.239436285836355, 54.80102940968105, 50.86906814575195, 51.727479866572786, 54.00564479827881, 52.00102697099958, 51.36850813456944, 51.2454868044172, 53.479356970105854, 49.71681015832083, 46.81355054037911, 48.984681946890696, 50.79052570887974, 51.829402991703574, 50.45603942871094, 48.053227288382395, 44.4795047215053, 44.07474088668823, 43.949589933667866, 42.63729061399187, 40.66930716378348, 40.03590938023159, 39.740037713732036, 39.9455098424639, 41.01910032544817, 46.901629379817415, 49.99207694189889, 49.87772001538958, 44.195233072553364, 39.976919174194336, 48.72121320452009, 48.557711669376914, 49.41072463989258, 52.42644780022757, 49.5239177431379, 48.38276645115444, 40.73685755048479, 36.957603795187815, 35.479096617017476, 39.61395222800118, 46.31407928466797, 48.50264719554356, 47.9991911479405, 48.99860266276768, 49.38427632195609, 47.47394207545689, 46.972733770098, 43.73067651476179, 41.960574286324636, 43.43607289450509, 45.59554522378104, 47.25015102113996, 46.01948956080845, 46.33160958971296, 44.97844444002424, 43.73988287789481, 45.28449521745954, 46.14654084614345, 44.45472049713135, 41.1659574508667, 32.663526739392964, 21.76617009299142, 8.121363707951136, 1.4452104334320341, 0.038018147461116314, 0.7790288233331272, 1.4240520830665315, 4.65463080576488, 3.481212079524994, 2.8865355210644856, 4.965580931731632, 3.3785661246095384, 1.7108494022062846, 0.2497428474681718, 0.5021867528557777, 0.9930596670934132, 11.713981900896345, 22.891491651535034, 25.206553254808696, 22.676399741853984, 17.704249722617014, 26.16874326978411, 12.367977619171143, 5.35820973770959, 0.5003402690802301, 0.09029802892889295, 0.011461192675467049, 0.053013401571661234, 0.022734782292640636, 0.02575796114147774, 0.08074223383196763, 0.03845995857513376, 0.015849863877519965, 0.0900942784334932, 0.0531839072438223, 0.07918946072459221, 0.04534120611580355, 0.015667638209249293, 0.03394007396751216, 0.02760938634829862, 0.023823015059211423, 0.03684768133929797, 0.02082665361064885, 0.032207251592938385, 0.020757259834291678, 0.015180811385757156, 0.014407328961949264, 0.05669637769460678, 0.0463523691786187, 0.047781730336802344, 0.058289320075086186, 0.03223187902144023, 0.03319334278681448, 0.03894579304116113, 0.04028611344152263, 0.06039193046412297, 0.08768566232174635, 0.020339954012472714, 0.03190193458327225, 0.057536634749599865, 0.041183737239667347, 0.01636913146025368, 0.06913938679333244, 0.12046508517648492, 0.04015813834433045, 0.03432316805369087, 0.009819883470689612, 0.051234683088426075, 0.12541491671332292, 0.019386345986276865, 0.02664448580305491, 0.016327550834310905, 0.07246145353253398, 0.029576391513858522, 0.019062820489385297, 0.055506939733667035, 0.060940403890396865, 0.013657307734579911, 0.06141670833208731, 0.051601132710597346, 0.04667115510840501, 0.01969574947309281, 0.049075543946985684, 0.01864486327394843, 0.02217663634967591, 0.08694663590618543, 0.015380553435534239, 0.016823393691863333, 0.05521413490974477, 0.02683582080395094, 0.05902798008173704, 0.7593042446034295, 12.080402101789202, 35.552490438733784, 31.43962935038975, 24.402957609721593, 24.37018643106733, 34.51378686087472, 39.56280653817313, 28.651876585824148, 10.296460798808507, 0.969481498003006, 0.04601272168968405, 0.14747098247919763, 0.8802582142608506, 2.469900906085968, 10.8644551890237, 6.251501849719456, 2.8534736037254333, 3.6661440304347446, 3.750104759420667, 2.114396108048303, 1.9297505531992232, 0.7566181687372071, 10.364443710872106, 33.66606494358608, 52.223862648010254, 55.202572754451204, 53.328640120370046, 53.676456519535606, 54.32947949000767, 53.69621024812971, 52.73310307094029, 52.34270463671003, 55.01939044679914, 50.32825858252389, 47.17508615766253, 50.6240816116333, 49.25059298106602, 52.35389123644148, 52.60816751207624, 50.628260953085764, 45.845715114048545, 44.846122946058, 44.29488066264561, 43.348536014556885, 40.9927909714835, 41.13372128350394, 41.015268393925254, 40.38215896061489, 42.68659850529262, 48.86251177106585, 52.0289899962289, 52.01312378474644, 45.37682635443551, 40.67423691068377, 49.435074601854595, 49.28229413713728, 48.93362658364432, 51.98855495452881, 51.40571573802403, 48.79840421676636, 43.275295053209575, 37.936278411320274, 36.64844717298235, 40.159997258867534, 47.708607060568674, 50.33937570026943, 49.76176847730364, 49.84057494572231, 49.90113891874041, 49.050272941589355, 48.61843545096261, 44.96324872970581, 43.355122906821116, 45.491655758449006, 46.89394814627511, 47.22323022569929, 47.03200190407889, 46.30048860822405, 45.23150825500488, 45.37780605043684, 45.70959990365164, 46.97015598842076, 46.14748927525112, 43.38491678237915, 35.421502998897004, 25.07585416521345, 11.672230175563268, 3.3360008086477007, 0.48303339204617907, 1.6922891352857863, 3.501335148300443, 3.614074013062886, 4.7474470138549805, 4.306234666279384, 3.931322463921138, 4.881876851831164, 2.504197431462152, 0.48771001824310845, 0.12472426305924143, 0.8586952398930277, 10.00167999948774, 28.186663423265728, 27.766926220485143, 23.519028629575455, 21.043868371418544, 28.112842287336075, 20.428473370415823, 7.941566910062518, 0.7659243579421724, 0.029385953875524656, 0.03437317608456526, 0.05001740822834628, 0.03052792152655976, 0.022964625852182508, 0.06012590402471168, 0.022179023096604005, 0.020205890759825706, 0.0351614946765559, 0.06874010964695897, 0.026976411563477347, 0.08458409232220479, 0.049062095382916074, 0.004515555130118238, 0.022713958052918315, 0.03526125968034778, 0.012131353723816574, 0.02688248365718339, 0.036869163757988384, 0.0681761588369097, 0.03692114971844213, 0.0200391933654568, 0.016313252405130436, 0.020636679072465216, 0.03999859101272055, 0.04407044234020369, 0.04545249264421208, 0.03954263244356428, 0.0031845501673940036, 0.1767899106655802, 0.13160857079284533, 0.25974608212709427, 0.11327272932976484, 0.11668303954814162, 0.11496463604271412, 0.1449592358299664, 0.07546764186450414, 0.11886767803558282, 0.16359781926231726, 0.1035936444199511, 0.16308312330927166, 0.05291295124750052, 0.1435008876557861, 0.19938500465026923, 0.14564699892486843, 0.18524448413934025, 0.07190779609871761, 0.17415950181228773, 0.15954373537429742, 0.1741694219942604, 0.09513819563601698, 0.10709679179957934, 0.10432169892426048, 0.10641683864274196, 0.09326155776424067, 0.12799381118799957, 0.06837836227246694, 0.10313669858234269, 0.08127875147121293, 0.11143552791327238, 0.16556114676807607, 0.20597723019974573, 0.1317445763519832, 0.12182150382016387, 0.21703478614134447, 0.11689590955419199, 0.6505345382860729, 12.94361502783639, 41.21270145688738, 40.97754314967564, 35.900814056396484, 33.825171743120464, 37.950345039367676, 48.07296364648001, 36.86115237644741, 16.199559995106288, 2.069919386080333, 0.1977129586573158, 1.3405999839305878, 6.470230272838047, 8.576048612594604, 19.07891433579581, 11.285284996032715, 6.636613139084407, 8.786439197404043, 4.976384512015751, 2.3641250048364912, 1.9588858698095595, 0.861438909811633, 9.683001739638192, 32.26213278089251, 54.22035455703735, 56.82808297021048, 53.638085092817036, 55.17935882295881, 57.44262334278652, 56.239118916647776, 55.20769010271345, 54.206016949244905, 56.15223169326782, 52.38085719517299, 49.57691165379116, 51.553583826337544, 50.74765532357352, 54.29154927389962, 56.09544406618391, 52.73971428189959, 49.52667270387922, 47.72752005713326, 47.503735951014924, 45.3252602985927, 43.688775403159006, 43.86543682643345, 45.056344168526785, 42.47854164668492, 45.1650834764753, 50.043990407671245, 54.672053473336355, 54.0430017880031, 48.72889791216169, 43.25853252410889, 48.104480675288606, 48.78414651325771, 50.23400279453823, 55.89903586251395, 52.24644776753017, 51.75522402354649, 44.51262331008911, 40.83534826551165, 38.55596739905221, 42.83993482589722, 49.52433810915266, 52.013495513371055, 50.38383027485439, 49.73592812674386, 51.23347684315273, 50.875432695661274, 50.14442661830357, 47.622459820338655, 45.24464382444109, 47.12623337336949, 49.218422821589876, 49.471038477761404, 47.1084703036717, 46.55067934308733, 45.17036758150373, 47.24815688814436, 46.49774101802281, 47.58159051622663, 46.76478113446917, 44.22885193143572, 35.17058617728097, 23.419695445469447, 9.830219302858625, 2.4383947338376726, 0.4064197316765785, 1.9840865518365587, 4.0653045773506165, 8.935327802385602, 7.774712869099208, 9.289569548198156, 11.505626269749232, 9.404922672680446, 6.431475826672145, 1.4004012835877282, 1.0176166636603219, 1.5931741680417741, 15.03175367627825, 28.94054991858346, 31.47795213971819, 30.79775129045759, 26.740540061678203, 37.04255247116089, 22.270713533673966, 8.74675108705248, 0.8094211124948093, 0.16428569092282228, 0.1063070720327752, 0.3648502608495099, 0.11440069201801505, 0.10442647830184017, 0.12608376225190504, 0.09597919907953058, 0.11543727639530386, 0.23064976770962986, 0.20110633942697728, 0.15331064483949117, 0.14589971250721387, 0.14993844793311187, 0.12010779577706542, 0.10887961541967732, 0.14941304469747202, 0.11773353389331273, 0.055779972047145875, 0.09462895510452134, 0.17644469918949263, 0.11455381023032324, 0.11808766131954533, 0.2178593554667064, 0.1307485412274088, 0.16055499682469027, 0.17435954750648566, 0.11491861779774938, 0.10899811477533408, 0.12401105490114007], [0.044172629714012146, 0.09858079733593123, 0.025052959864426936, 0.018895312245669107, 0.03383785266695278, 0.03523206231849534, 0.03076720011553594, 0.02718315609464688, 0.029926546117556945, 0.02843842891577099, 0.015573484690061637, 0.015338184012632285, 0.044841760237302096, 0.020533813163638115, 0.03756836695330484, 0.05091857397928834, 0.04076936608180404, 0.024835945705750158, 0.06907381316913025, 0.09047927241772413, 0.022750546357461383, 0.028827078507414887, 0.008570786166403974, 0.0519813905203981, 0.037795360665768385, 0.05881263342286859, 0.05325275479948946, 0.019615076748388152, 0.0467360230561878, 0.06867420354059764, 0.08803256335003035, 0.07335146756044456, 0.06845667199896914, 0.0452239077671298, 0.07396757057202713, 0.057475817655878406, 0.08052308737699475, 0.022845905972644687, 0.38054814136454035, 7.5994297947202405, 25.519428900309972, 29.237873758588517, 17.492638860430034, 17.486133609499248, 30.086224487849645, 30.232032435280935, 28.82165581839425, 13.021730150495257, 2.0648448126656667, 0.11072928830981255, 0.20903031208685466, 0.9621196644646781, 10.416281614984785, 3.0033323509352545, 1.310391822031566, 2.3688057022435323, 2.132750860282353, 2.0127433112689426, 1.148766734770366, 0.13567022713167326, 0.7102330263171877, 7.149943879672459, 29.385314532688685, 46.71550103596279, 55.41098744528634, 54.65369633265904, 53.47504561288016, 53.45435387747628, 52.606274127960205, 55.046325138636995, 52.82771669115339, 48.86984559467861, 49.71233899252755, 48.75575964791434, 50.38867664337158, 52.60622549057007, 50.87125335420881, 49.93812765393938, 50.21552753448486, 48.647322586604524, 47.61759260722569, 46.05083635875157, 42.88227367401123, 41.93276064736502, 42.405651569366455, 44.64279086249215, 45.51815618787493, 49.32953493935721, 47.91069541658674, 55.9100661277771, 48.0061080796378, 38.22542769568307, 44.22829607554844, 51.42676877975464, 50.69062450953892, 49.24388102122715, 47.54598447254726, 46.976121016911094, 39.85689599173409, 37.859250681740896, 38.479964528764995, 39.724414689200266, 46.188646929604666, 49.52124268668038, 49.935042653764995, 50.51090587888445, 48.91441134044102, 49.570571422576904, 47.12201929092407, 45.32820980889456, 45.66388423102242, 45.93595831734793, 45.30109098979405, 46.06061942236764, 47.403442178453716, 46.85255077907017, 46.53953095844814, 44.46550062724522, 45.6808135168893, 42.5028464453561, 36.55291986465454, 28.253664902278356, 14.67997854096549, 6.874648869037628, 0.9301811839853014, 0.4294508115521499, 0.7585345687610763, 2.049892940691539, 2.18866713983672, 2.1815658637455533, 2.6296669159616743, 3.3631802073546817, 3.7289618253707886, 4.256880308900561, 1.4650317983967918, 0.5492403879761696, 0.7703038400837353, 11.69839448588235, 21.88427209854126, 22.346042428697857, 19.394906248365128, 22.18582218033927, 25.288953678948538, 15.369161673954554, 3.493274369410106, 0.6195144142423357, 0.029021254873701503, 0.04064531291701964, 0.0737253064289689, 0.04434470280206629, 0.02475920000246593, 0.021571651134373884, 0.030858195054211786, 0.046286636098687134, 0.029770218434610536, 0.06956701991813523, 0.03770699165761471, 0.008219202398322523, 0.022583755664527416, 0.022514808024945, 0.06020567260150399, 0.03232955413737467, 0.0179132447644536, 0.02450205897912383, 0.008661830298868673, 0.055096246235604794, 0.01200331755847271, 0.04129336814263037, 0.03433763102761336, 0.021756112575531006, 0.04053305947620954, 0.040376127897096534, 0.008296127913386693, 0.03634949414325612, 0.05556564997615559, 0.02735785680956074, 0.04783079181132572, 0.005563193266945226, 0.05545077060482331, 0.015211808561746563, 0.05208433446075235, 0.04094006513644542, 0.05136207464550223, 0.027220891123371463, 0.025360624605257596, 0.008427936733434243, 0.00812817522923329, 0.02825433388352394, 0.01701640128158033, 0.01715799288025924, 0.020993781874754598, 0.013608853548898228, 0.018828600378973142, 0.00770436056024794, 0.04995182442611881, 0.047653039385165484, 0.03375620794083391, 0.04705228822837983, 0.03678205682496939, 0.022621220975582088, 0.02223200141452253, 0.01951499792215015, 0.03698961050914867, 0.061125046839671474, 0.0035605298139021863, 0.04500224055456264, 0.08559867859418903, 0.016892227676830122, 0.05860741729182856, 0.07468239364347287, 0.08679295450981174, 0.02251568672779415, 0.010397770541853138, 0.031284148804843426, 0.9105548028435025, 12.732209137507848, 33.2218770299639, 33.89651584625244, 21.527282340185984, 21.444494553974696, 40.9696604183742, 40.03980384554182, 32.13967425482613, 11.167480025972639, 1.3981339995350157, 0.16339434018092497, 0.028204495486404215, 0.6167900147182601, 7.347312671797616, 5.982794165611267, 4.672174572944641, 4.156549624034336, 4.674175654138837, 3.499975689819881, 2.401353887149266, 0.31250318405883654, 1.1740651258400507, 9.466693895203726, 33.44309377670288, 49.9530211176191, 57.28440591267177, 56.40236684254238, 55.05299540928432, 55.147119181496755, 54.21581390925816, 55.089914662497385, 54.92066349302019, 49.63937595912388, 50.31906264168875, 47.749288763318745, 51.09442949295044, 53.92812722069876, 53.459565026419504, 52.03739731652396, 51.49858883449009, 50.81822122846331, 48.91409519740513, 47.549100739615305, 45.69536999293736, 44.01646287100655, 43.49515690122332, 45.00713702610561, 45.60028389522007, 50.923170294080464, 49.60164029257638, 56.67986747196743, 48.601276874542236, 40.966426031930105, 44.88688107899257, 51.26199919836861, 50.55589199066162, 51.916203362601145, 49.57887799399239, 49.13074002947126, 42.69036790302822, 39.71395417622158, 40.66422803061349, 41.14672136306763, 46.819821289607454, 49.41520275388445, 51.29826184681484, 50.81573029926845, 49.79419919422695, 49.48529270717076, 49.67746598379952, 46.422339166913716, 46.22914797919137, 45.53354297365461, 45.827622004917686, 47.94147593634469, 48.35291699000767, 46.70013509477888, 47.77685921532767, 46.3665451322283, 45.5064971106393, 44.1211062158857, 38.489174365997314, 30.521122659955704, 17.713410922459193, 9.745262810162135, 1.8621398040226527, 1.2527763822249003, 1.9912549214703696, 3.0045569709369113, 3.6635124002184187, 2.48745704974447, 5.612760467188699, 4.0200353264808655, 2.2307801714965274, 1.8812262884208133, 0.2945605197123119, 0.14078752111111367, 0.6215721666812897, 9.073721153395516, 26.054165737969534, 24.922022785459244, 20.330686160496303, 24.761720895767212, 26.881367887769425, 21.905655179704937, 5.699226456029074, 1.5914257190057208, 0.04094016013134803, 0.030342881634299244, 0.03546781591804964, 0.08032712646360908, 0.03171539852129562, 0.011489381564648023, 0.026046399592554996, 0.012346983671055307, 0.03353018453344703, 0.0466512808177088, 0.04040651269523161, 0.01691956415639392, 0.044990037102252245, 0.017604329822851077, 0.019952703899304782, 0.02402561204507947, 0.041555224984352074, 0.029785539755331616, 0.024044017307460308, 0.03667791527030723, 0.017154347450871552, 0.00207341429943751, 0.07018376753798553, 0.07358647816415344, 0.04959963421736445, 0.04119783719735486, 0.006495766283478588, 0.05449417872088296, 0.03521443397871085, 0.01880528252305729, 0.14060371954526218, 0.16380997002124786, 0.11824312726301806, 0.10077876225113869, 0.14698403860841477, 0.17027083119111402, 0.1809195562132767, 0.11951339910072939, 0.09488208937857832, 0.12804814827229294, 0.12104150067482676, 0.060314034643982134, 0.15520364897591726, 0.0997992901663695, 0.1065623504774911, 0.10834283993712493, 0.08319791313260794, 0.08199912495911121, 0.14670541855905736, 0.17704950459301472, 0.10132789385638066, 0.10949216290776219, 0.12380969284900598, 0.09128246110464845, 0.13653170876204967, 0.22869819243039402, 0.11902744589107377, 0.13563668036035129, 0.0895186975332243, 0.1434573121368885, 0.2100347067628588, 0.1293375412268298, 0.15330995273377213, 0.16601674232099736, 0.1378186997026205, 0.11591417794781071, 0.10737056710890361, 0.12396009692123958, 0.7074388191103935, 12.329121555600848, 36.72958128792899, 42.26295641490391, 29.064712490354264, 28.31812855175563, 41.24843256814139, 40.816212926592144, 36.7005934034075, 16.447073936462402, 2.8015555781977515, 0.3052736648491451, 0.8709275435124124, 2.8616494621549333, 18.891307762690953, 8.339800306728907, 6.282211150441851, 6.124404966831207, 6.402685097285679, 5.203755625656672, 2.5704398197787146, 0.46320269043956486, 1.3109173881156104, 8.417884162494115, 30.45600414276123, 49.609992027282715, 60.9536349432809, 58.01201432091849, 55.72066865648542, 56.467106682913645, 56.94529908043997, 58.61305086953299, 54.85808106831142, 50.9714811188834, 48.80919129507882, 47.14998926435198, 51.144727502550396, 54.78383261816842, 55.74094697407314, 54.458813258579795, 54.38044105257307, 52.7733678817749, 51.57898644038609, 49.73823840277535, 47.3442713192531, 44.68428897857666, 45.8999353817531, 48.51104061944144, 48.74634483882359, 54.38119493212019, 51.3565468106951, 58.296365874154226, 51.75479670933315, 41.50967788696289, 45.09795345578875, 53.8266453061785, 50.676950454711914, 53.68008000510079, 51.196915422167095, 50.95484018325806, 44.65748977661133, 41.9098732812064, 41.677369185856406, 44.23034232003348, 49.03029339654105, 53.321358408246724, 53.15970509392874, 50.47911092213222, 50.08200747626168, 50.428819860730854, 51.37544938496181, 47.669221196855815, 47.91078574316842, 48.67879097802298, 47.329127720424104, 48.632925919124055, 48.132805006844656, 46.7128780909947, 47.99844421659197, 46.53538288388933, 47.06485646111624, 44.098409925188335, 38.71266317367554, 30.37084354673113, 17.01326526914324, 8.65637413093022, 1.3014565472091948, 1.5638384393283298, 2.4377324836594716, 4.971910306385585, 7.18725049495697, 6.155156825269971, 7.818867802619934, 8.480245981897626, 10.208584325654165, 10.499722531863622, 4.199995841298785, 1.226593290056501, 1.576282445873533, 14.501966561589922, 29.606559072222026, 28.103672402245657, 27.014665603637695, 30.78722129549299, 34.37593460083008, 23.332085609436035, 5.185126202447074, 1.0254942923784256, 0.12496669005070414, 0.15149606578052044, 0.19499940212283814, 0.3077314815350941, 0.12421745168311255, 0.09047404769808054, 0.09702125923441988, 0.2082581663770335, 0.07358786916094166, 0.10275711930756058, 0.155758921323078, 0.05290041870570608, 0.1697437044765268, 0.09680474549531937, 0.10789557000888245, 0.09173681493848562, 0.12597772079919065, 0.10215614762689386, 0.1125752767547965, 0.12939096907419817, 0.12743669322558812, 0.12640424791191304, 0.1518123716648136, 0.12243574086044516, 0.12701688360955032, 0.13436365367046424, 0.1185725424438715, 0.10752255895308085, 0.10438913173441376, 0.10036010614463262], [0.07004385361714022, 0.0782249164102333, 0.010849746958618718, 0.04761784377374819, 0.02008106915413269, 0.023049018645126904, 0.03789433517626353, 0.032103316991456916, 0.03380959168342607, 0.013582099761281694, 0.04168469285858529, 0.058547143026122024, 0.09960895430828844, 0.06158422505749123, 0.025207448717472807, 0.011161602501358305, 0.05342325368630035, 0.04159179123650704, 0.009130802321513849, 0.024427297990769148, 0.013751766594525958, 0.08170029813689844, 0.04413195832499436, 0.054012035485357046, 0.017597252702606574, 0.05850683804601431, 0.07841914027397122, 0.041961348549063714, 0.09511697106063366, 0.040231850996081314, 0.03813969004633171, 0.03463000498179879, 0.056376411113888025, 0.06713815632143191, 0.019069644855335355, 0.041498587666345496, 0.04561238942135658, 0.04520805718909417, 0.0312648309128625, 0.19541423129183905, 5.725177543503897, 22.706372533525737, 30.759716851370676, 20.004070452281407, 11.99400212083544, 22.10204427582877, 33.51428154536656, 28.471822704587662, 11.38733058316367, 3.4458379319735934, 0.1230391077697277, 0.580482257264001, 6.213366227490561, 8.435879128319876, 2.08395431297166, 2.8683688044548035, 5.657607614994049, 3.7380722165107727, 4.133832054478781, 0.7267991602420807, 0.10237238316663674, 1.7260475009679794, 10.49351692199707, 26.316628728594097, 39.68008518218994, 48.21382795061384, 53.02279084069388, 54.295096329280305, 52.16368082591465, 53.48083346230643, 52.456165245601106, 54.262596130371094, 49.49110834939139, 49.72443233217512, 50.21784128461565, 52.367172718048096, 52.142245633261545, 52.452427114759175, 50.56055423191616, 51.50848306928362, 50.004260608128135, 48.023436886923655, 45.92999676295689, 44.49014241354806, 43.624382972717285, 44.908260686056956, 50.11008167266846, 51.155677863529746, 51.925472259521484, 46.541816915784565, 41.14670399257115, 45.37314033508301, 51.62969091960362, 48.864849839891704, 53.42992401123047, 49.53593465260097, 50.54594911847796, 43.20019197463989, 39.635429109845845, 38.21421330315726, 39.99879557745797, 42.840834617614746, 46.91092259543282, 48.749659129551475, 51.49291910443987, 52.391619954790386, 51.47421107973371, 50.02209663391113, 48.72959620612008, 47.419252804347444, 46.43393223626273, 47.403244154793875, 46.301468304225374, 48.127607754298616, 46.776666028159006, 49.22732693808419, 46.16355003629412, 42.51241758891514, 35.860948766980854, 29.941611630576, 20.03666271482195, 12.016295416014534, 3.248385978596551, 0.6149988451174327, 0.3995204418897629, 1.1102543898991175, 1.4368730293852943, 1.2951426974364688, 4.626998254231044, 2.3315848537853787, 5.294422669070108, 2.532596890415464, 0.46223678226981846, 0.9854396645511899, 0.0969615685088294, 1.120799475482532, 11.717498557908193, 25.70208314486912, 25.521353551319667, 17.254029035568237, 25.573159320013865, 24.759381089891704, 11.022630061422076, 2.0831620012010847, 0.07841346093586513, 0.03525017581081816, 0.08284700196236372, 0.0962940121867827, 0.043602046224155595, 0.022336168414247886, 0.016687060739578943, 0.0398083976469934, 0.007422106955865664, 0.01905050507879683, 0.02578235786807324, 0.00514581662303369, 0.07559097238949367, 0.04042632591777614, 0.007604583682093237, 0.026328361426879252, 0.05384752467008574, 0.047754008788615465, 0.045536990610084364, 0.006673876636861158, 0.09138543557907854, 0.01705285727179476, 0.002615571200814364, 0.03892749295170818, 0.07806843944958278, 0.08212512212672404, 0.0632554500230721, 0.07208878174424171, 0.06976164411753416, 0.02334106181349073, 0.02942715452185699, 0.05396175943315029, 0.022370432736352086, 0.04661648214927741, 0.10489423320229564, 0.042220918727772574, 0.025685393517570834, 0.013552498671093156, 0.011020532526474978, 0.011629648323703026, 0.056149393652698824, 0.04779315686651638, 0.06203372058059488, 0.009315848999124552, 0.08655834424176387, 0.005407533940992185, 0.03389303792001946, 0.012542210070283284, 0.027584526521552886, 0.010925678419880569, 0.010344197657624525, 0.012416496191040745, 0.012751864668514048, 0.07697616770331349, 0.03443202881940773, 0.052929290370749574, 0.018738455305408155, 0.06651078284318958, 0.028355550952255726, 0.00967157183081976, 0.11383755544998816, 0.03642058425715991, 0.026862451607095342, 0.027382684405893087, 0.03558420163712331, 0.045527826994657516, 0.06102553967918668, 0.03835081282470908, 0.014838098614875759, 0.029085274652710984, 0.08691336733422109, 0.6787038381610597, 9.29538779599326, 29.59874929700579, 34.82667119162423, 24.37250018119812, 19.474041019167217, 28.377353259495326, 38.002849102020264, 34.94625316347395, 12.335460918290273, 1.880915573665074, 0.16544937847980432, 0.051377684343606234, 0.7060777864285878, 5.48222770009722, 5.807432055473328, 4.55034225327628, 3.290602798972811, 4.060637124947139, 5.806725076266697, 1.47890995655741, 0.5231913743274552, 2.2709470561572482, 11.446068048477173, 31.25998714991978, 43.7500376701355, 53.176412037440706, 55.49608203342983, 55.20214196613857, 54.99094452176775, 54.43411936078753, 51.002216475350515, 53.558205127716064, 50.71751751218523, 50.148866517203196, 50.867612498147146, 53.313795294080464, 55.23571913582938, 54.66301039287022, 51.69485460008894, 52.95389250346592, 51.46427862984793, 48.35114172526768, 47.395073073250906, 46.025590079171316, 44.80388832092285, 45.461920942579, 51.66809708731515, 54.23821837561471, 53.91028424671718, 49.53165108816964, 43.61292886734009, 45.830470766339985, 51.71065132958548, 50.19648947034563, 54.432274614061626, 51.141923904418945, 51.84883362906319, 46.04348863874163, 40.67120402199881, 39.91374962670462, 41.055272647312705, 42.726766041346956, 48.24401787349156, 50.95106036322457, 53.23898751395089, 53.13150930404663, 50.88492740903582, 51.66394901275635, 51.384937150137766, 48.21749659946987, 47.77865532466343, 47.4986116545541, 47.1532792363848, 48.4132273537772, 46.939875738961355, 48.769527503422324, 46.5680706841605, 44.04423829487392, 38.9810825075422, 33.45710481916155, 23.74795961380005, 14.646969386509486, 5.445909031799861, 1.397016968045916, 1.9425287246704102, 2.4279261870043616, 3.2115898387772694, 6.1446919696671625, 4.002677857875824, 2.657121419906616, 2.4978337500776564, 2.438399293592998, 1.0921143804277693, 0.29054291386689457, 0.05103493594963636, 0.7689290738531521, 9.57221792425428, 28.008820806230815, 30.66802842276437, 18.94782441002982, 25.544477156230382, 29.12432108606611, 17.705818278448923, 4.883507941450391, 0.4764818378857204, 0.02691276158605303, 0.023474292164402347, 0.03043257717841438, 0.016565569044489945, 0.04471296411273735, 0.019456163847020695, 0.0340652636784528, 0.004551824099118156, 0.019655490294098854, 0.014742194475339991, 0.027786378815237964, 0.040413864622158666, 0.05006448159526501, 0.027845915174111724, 0.02250896753477199, 0.027553044193025147, 0.002075506519759074, 0.048783393909356425, 0.020340725846056427, 0.07480301002838782, 0.035605616202311854, 0.06933169040296759, 0.008800972386130264, 0.018377810550321425, 0.08670694341084786, 0.08116456759827477, 0.07428760161357266, 0.018965974882511154, 0.04531458379434688, 0.03521527875480907, 0.03366602724418044, 0.09809972957840987, 0.11112836868103061, 0.2280912021441119, 0.12342655126537595, 0.061716939721788676, 0.2208985545273338, 0.1535669003746339, 0.11296330379056078, 0.1463668295847518, 0.153315950983337, 0.16667707903044565, 0.11843878962099552, 0.18705143646470138, 0.11432256549596786, 0.13715590669640473, 0.11636920353131634, 0.15333539779697145, 0.08362256748867886, 0.06766199214117867, 0.11224844679236412, 0.1350147080208574, 0.21681291876094683, 0.09943341729896409, 0.15013310605926172, 0.0897683577079858, 0.16091923442270073, 0.12515349074133805, 0.1139619377042566, 0.19397577776440553, 0.15108731628528663, 0.09653444428529058, 0.11763210647872516, 0.14186001356158937, 0.19712354242801666, 0.1524348325495209, 0.09380774452750172, 0.0768620991813285, 0.11342989161078419, 0.1564904770680836, 0.5907300359436444, 9.44015177658626, 33.92826563971383, 43.97634744644165, 30.414947237287247, 23.44114974566868, 31.59848948887416, 42.13039173398699, 36.475641999925884, 15.330595697675433, 4.655869322163718, 0.32302519945161684, 1.510706433228084, 9.68610063620976, 17.0018059526171, 10.113512124334063, 9.352863294737679, 10.113755311284747, 8.622552037239075, 7.536315832819257, 1.886186650821141, 0.5017608499952725, 1.9350845984050205, 11.986435532569885, 28.681682620729717, 40.689661911555696, 51.8040246963501, 55.066933495657786, 56.76210635049002, 55.891702038901194, 54.48977790560041, 53.08827066421509, 55.39846331732613, 50.41578851427351, 49.99351174490792, 50.280305589948384, 53.28330659866333, 56.14897646222796, 56.408192907060894, 52.94849027906145, 55.01323086874825, 52.99719367708479, 50.58859716142927, 50.005094391959055, 47.992531299591064, 47.83262893131801, 47.03366947174072, 54.31045879636492, 55.306924274989534, 55.727137429373606, 50.15003381456648, 45.529033592769075, 50.013265473502024, 49.661888122558594, 50.22448376246861, 55.079700810568674, 53.13783911296299, 53.4484235899789, 48.2408321244376, 43.17240265437535, 42.78960902350289, 42.95440639768328, 45.56785665239607, 49.97798946925572, 52.3901504107884, 54.55186700820923, 54.840588978358674, 51.45330395017351, 52.803133964538574, 52.154370239802766, 51.692311559404644, 51.0573365347726, 49.58396407536098, 48.385052408490864, 49.08948162623814, 45.25018848691668, 48.76838799885341, 46.608161790030344, 44.68830156326294, 37.59805400030953, 33.05160100119454, 21.74543145724705, 14.329962168421064, 4.257008850574493, 1.500365993806294, 1.709604914699282, 3.777562303202493, 3.523239995752062, 7.581842167036874, 10.951263376644679, 5.367788697992053, 11.260764803205218, 8.573816503797259, 4.4514641761779785, 2.8216964517320906, 0.24985656993729727, 1.8372372431414468, 14.990328516278948, 33.14161491394043, 34.20300088609968, 23.841428518295288, 34.316454546792166, 34.86976391928536, 18.27699668066842, 4.203703139509473, 0.40096216595598627, 0.1825109515339136, 0.17503884248435497, 0.1872105257851737, 0.10869476212454693, 0.19544951511280878, 0.10209780040064029, 0.11039528623223305, 0.15725110125328812, 0.15434307658246585, 0.049516021739691496, 0.0929205599906189, 0.14062621976648057, 0.1864728360835995, 0.0927464614755341, 0.12291404019509043, 0.1453430423779147, 0.14420631980257376, 0.15353521278926305, 0.07796786020376853, 0.21788645615535124, 0.12787295053047792, 0.13754174884940895, 0.11506503208407334, 0.19460184845541204, 0.27673095358269556, 0.1556467730551958, 0.18625448351459845, 0.12837369580354008, 0.13364580433283532, 0.142269156607134, 0.09035824212644782], [0.04913891911772745, 0.037335714258785756, 0.02189741749316454, 0.04402432231498616, 0.04046538578612464, 0.06073570344597101, 0.01317593633263771, 0.019194147549569607, 0.026277739321812987, 0.010083868367863553, 0.013295774946787527, 0.05798762304974454, 0.028998435741024356, 0.025985100738970295, 0.030224236393613473, 0.07015317239399467, 0.062313901260495186, 0.08280293789825269, 0.025217911727460365, 0.018712721864825914, 0.01909811788105539, 0.06922950302915913, 0.030381500454885618, 0.036779424109097035, 0.06338091793337039, 0.021610899296190058, 0.08264148727591548, 0.03449151259181755, 0.02324724416913731, 0.05239709160689797, 0.04625228187069297, 0.039452081945325644, 0.026669036896367158, 0.05221315772671785, 0.027839620065476214, 0.0382157029317958, 0.03948275512084365, 0.029588846024125814, 0.06921148113906384, 0.018145802464070063, 0.33755610830017496, 5.299642937523978, 18.88302377292088, 31.61440781184605, 25.73183012008667, 20.898814303534373, 22.757924692971365, 27.935621534075054, 22.16032750265939, 15.882939270564489, 3.5476238301822116, 0.30625615641474724, 0.7523711366312844, 3.818459834371294, 5.921478918620518, 2.8402138352394104, 1.5782711505889893, 3.2533726138728003, 3.6220077701977322, 0.6314149413790021, 0.43682171031832695, 0.15323145980281488, 1.502924776503018, 7.852983457701547, 21.304641212735856, 34.16856213978359, 41.76680292401995, 46.48017249788557, 51.96992336000715, 53.82093736103603, 49.95863873617989, 46.69548674992153, 50.22029052461897, 52.61136020932879, 53.304946763174875, 52.881759779793875, 50.507188592638286, 53.16717093331473, 54.38274438040597, 52.688328879220144, 51.44481325149536, 51.012531076158794, 48.96840579169137, 46.0669527053833, 44.59192310060774, 46.44653279440743, 51.849677835192, 53.000063283102854, 56.279901368277415, 47.335405417851035, 40.07707398278372, 39.838952268872944, 57.67629126140049, 50.7654253414699, 54.21269416809082, 48.97383233479091, 47.94378968647548, 45.436921324048726, 44.63194819859096, 42.5772442817688, 41.522698811122346, 43.39954274041312, 44.835926464625764, 48.77480813435146, 50.61892604827881, 50.1892147064209, 51.34359189442226, 50.74077660696847, 51.4525465965271, 49.84751967021397, 48.554230621882844, 48.56497253690447, 48.2722692489624, 51.81665652138846, 47.54896872384207, 43.95142078399658, 37.6780937739781, 30.471766131264822, 22.1163558278765, 11.467841097286769, 5.3212162256240845, 2.105571461575372, 0.13439553124564035, 0.5200399862868446, 2.585506554160799, 2.1777482628822327, 2.8470102591173987, 4.240752237183707, 0.8329654633998871, 1.3946453524487359, 1.9595396518707275, 2.0883407975946153, 0.3337311249758516, 0.1516701371542045, 1.7623938534940993, 11.833422303199768, 25.142108712877544, 28.78986780984061, 15.996521472930908, 20.930079460144043, 25.485301085880824, 13.327037470681326, 2.112764149904251, 0.1396936955196517, 0.11780871557337896, 0.09072786050715617, 0.028379627071054916, 0.03713795183492558, 0.03421201044693589, 0.10664476534085614, 0.027063320025003383, 0.02290941176137754, 0.025972349369632344, 0.055827364325523376, 0.02151367031703038, 0.05714134060378585, 0.09104046837559768, 0.04141091415658593, 0.027930844009720852, 0.07119754635329757, 0.017513267030673366, 0.03810307290405035, 0.0045135937398299575, 0.04285678746444838, 0.0447011406400374, 0.08406881282904319, 0.021578439877235463, 0.004809647050153996, 0.04602759178461773, 0.05341156252792903, 0.027256880620760576, 0.022100686228701046, 0.011649348739800709, 0.005678049313636231, 0.02820488903671503, 0.01605839465212609, 0.026562403421849012, 0.05906769473637853, 0.0389832583522158, 0.0369468186981976, 0.08521782367357186, 0.03842329732807619, 0.05544526090047189, 0.019493836111256053, 0.05126535626394408, 0.02155864192172885, 0.010589728098628777, 0.023538021869691353, 0.036461041907646825, 0.020800187352246473, 0.06685279163398913, 0.0204703887991075, 0.0629398769565991, 0.04123131272249988, 0.05089829935293112, 0.034084337297827005, 0.0358702143255089, 0.05779141107840197, 0.06071654161704438, 0.040834074573857446, 0.026924135529303124, 0.015197008016652294, 0.011214021876055216, 0.013783633143508008, 0.033243751153349876, 0.0582106439396739, 0.07932865539831774, 0.030939520868871893, 0.057426467803972106, 0.045605743170848916, 0.03152923904625433, 0.04437061605442848, 0.05296943250245281, 0.029501983363713537, 0.07704697283250944, 0.0017667749946537826, 0.6169702336192131, 9.12932584966932, 27.360955136162893, 33.827023438044954, 25.314458778926305, 22.507442133767263, 28.24221079690116, 34.12574734006609, 28.40393011910575, 16.89333588736398, 2.937616071530751, 0.27712876509342876, 0.1366455126553774, 0.23892148956656456, 3.321277141571045, 5.3192459770611356, 4.79482113463538, 6.720282477991922, 8.650230186326162, 4.442256944520133, 1.6827091979128974, 0.4769306480884552, 2.8972062170505524, 10.739730681691851, 21.68436895098005, 37.0353923525129, 43.46380662918091, 50.69059671674456, 52.46543761662075, 53.764823709215435, 50.282799993242534, 50.127573762621196, 51.857265268053325, 51.30150318145752, 54.312237535204204, 53.71425471987043, 51.84305967603411, 55.25269358498709, 55.103317737579346, 54.63517590931484, 52.109102725982666, 53.26843050548008, 50.1620055607387, 48.38550404139927, 45.629699093954905, 48.897461209978374, 55.1012784412929, 54.19005693708147, 56.555129936763215, 47.0157014301845, 42.07913487298148, 41.77108996255057, 57.41838107790266, 50.46080241884504, 55.59177262442452, 52.02038812637329, 49.84215913500105, 47.17343943459647, 44.90726361955915, 43.58781460353306, 42.72780132293701, 45.13550846917288, 46.54026746749878, 50.99003628322056, 50.756767886025564, 51.703015259334016, 51.2006049156189, 51.20627811976841, 51.73407718113491, 50.867449215480256, 49.548559529440745, 48.423486368996755, 49.1127268246242, 50.42046465192522, 48.86110476085118, 44.85533625738961, 40.32466261727469, 32.699928351810996, 24.55669171469552, 15.16319101197379, 8.15326462473188, 4.267324319907597, 1.1649730822869708, 1.3912746076072966, 2.5904462890965596, 3.517836468560355, 4.5344986234392435, 5.307375414030893, 3.6985213330813815, 2.1143587614808763, 2.876521212714059, 1.1372688774551665, 0.05403478676453233, 0.129449689494712, 0.8237325559769357, 10.405071565083094, 27.824078627995082, 33.64358752114432, 20.950027738298687, 22.25779335839408, 30.09667805262974, 18.499285187040055, 4.087757246834891, 0.07394752664757626, 0.09768509718456439, 0.06620457355997392, 0.005647085216228983, 0.008949775115719863, 0.07717979606240988, 0.09302010786320482, 0.024759205091478567, 0.002903721062466502, 0.04758102307096124, 0.01563732635362872, 0.030986183722104346, 0.11366743993546281, 0.05039500278819885, 0.015912658900820782, 0.08392558087195669, 0.02011832920834422, 0.08471670520624944, 0.09219694310533148, 0.0760011128815157, 0.02250994971421148, 0.035615997788097174, 0.035341913745339425, 0.027023432343932133, 0.043145348051829, 0.09711956538792167, 0.007346597882652921, 0.06289219630083867, 0.04180591313966683, 0.021099831809156706, 0.02453485766558775, 0.018710085756278465, 0.04492331336119345, 0.08966949515576873, 0.11090371930705649, 0.14948728999921254, 0.18362216119255337, 0.15763716053749832, 0.12832295495484555, 0.18285023261393818, 0.08838472302470889, 0.09971419508968081, 0.08350811220173325, 0.10476738108055932, 0.07383885247898953, 0.18621145082371576, 0.13530991146607058, 0.17499367919351372, 0.14311926599059785, 0.19365698844194412, 0.16548055037856102, 0.17144257974411758, 0.1554527934640646, 0.15619306159870966, 0.15797004981764726, 0.10576581143374954, 0.17113328991191729, 0.1540127114525863, 0.11558088154665061, 0.11849809358162539, 0.07485172205737659, 0.09294916024165494, 0.17952674095119747, 0.18865048566034862, 0.20581928081810474, 0.1366329054747309, 0.17920324259570666, 0.10374384493167911, 0.13934920329068387, 0.19748311170509883, 0.14984101030443395, 0.19262835649507387, 0.05790174087243421, 0.5552840179630688, 8.832781076431274, 29.851278100694927, 44.343893255506245, 36.13899482999529, 31.592986515590123, 33.20586143221174, 37.519449029650005, 29.49323742730277, 19.93278193473816, 5.088727329458509, 0.5440991009984697, 1.747126272746495, 7.8659496647971014, 12.01144470487322, 12.015384333474294, 7.2477549740246365, 9.274699534688677, 10.745573248182025, 2.3655139931610654, 1.169548145362309, 0.4740907890456063, 2.3775558727128163, 9.172065087727137, 23.255902085985454, 37.1601368359157, 43.47197423662458, 49.400156429835725, 52.215177399771555, 53.661149638039724, 51.0991473197937, 50.94911139351981, 53.01510265895298, 51.2000664302281, 56.38250889096941, 53.002199854169575, 51.93476894923619, 55.85404627663748, 59.217537198747905, 56.10967745099749, 54.55225958142962, 55.38885395867484, 52.875054768153596, 50.658040932246614, 48.816691875457764, 51.95518275669643, 56.77002034868513, 56.16499205998012, 58.35248647417341, 47.366036551339285, 42.97034903935024, 43.671290261404856, 55.461295877184185, 53.001598834991455, 55.418463706970215, 53.56522280829293, 52.379116671425955, 50.37203918184553, 48.3467435155596, 47.36240611757551, 44.723660945892334, 47.35581227711269, 47.65285471507481, 53.15654018947056, 53.57328619275774, 52.80004896436419, 52.390504768916536, 52.39863068716866, 52.78785834993635, 52.536000047411235, 52.03378772735596, 50.80298730305263, 49.03874935422625, 52.31194496154785, 48.527775355747764, 44.830961976732524, 39.56208739961897, 31.936005183628627, 23.820754153387888, 12.97400905404772, 6.668348167623792, 2.846901693514415, 0.8521575278469494, 1.7689162577901567, 7.006662905216217, 6.2041129640170505, 7.0863847987992425, 8.41368397644588, 5.4820075290543695, 5.276629635265895, 5.924208692141941, 5.419351713997977, 1.2532616704702377, 0.5888196070279393, 2.1640505407537733, 14.5797073500497, 31.382178170340403, 37.64920663833618, 25.06203940936497, 27.431335176740372, 34.787327017102925, 19.43555494717189, 3.8118933524404253, 0.21482358979327337, 0.25319908772196087, 0.16026248037815094, 0.12443836911448411, 0.08597920103264706, 0.12180433688419205, 0.26101391123873846, 0.09517665500087397, 0.18820858294410364, 0.18903171377522604, 0.1491358767130545, 0.06770020044807877, 0.22481205953019007, 0.2182185719055789, 0.09621856587805919, 0.18371993808874063, 0.1741053547177996, 0.23257401159831456, 0.11841414522911821, 0.10228877408163888, 0.12459683418273926, 0.21781423288796628, 0.18699221392827375, 0.11309236115110771, 0.11608472093939781, 0.16282570069389685, 0.15344043501785823, 0.20574496766286238, 0.10707317878093038, 0.08852861994611365, 0.11966600162642342, 0.2611316234937736, 0.12081896833011083], [0.0492114341551704, 0.028425402739750485, 0.019497856431241547, 0.03849202614011509, 0.07953187663640295, 0.09681525600275823, 0.02714854571968317, 0.011824973110508705, 0.0324387304218752, 0.02225733791211886, 0.011475146748125553, 0.0683499655819365, 0.06984824554196425, 0.034727442610476694, 0.04978362577302115, 0.007400486285665205, 0.015433765848034194, 0.0264230204546558, 0.02290745927686138, 0.02631374408624002, 0.03604293880718095, 0.025364385385598456, 0.08673823744590793, 0.06140657780425889, 0.038819035914327414, 0.017353556850658994, 0.03761148785373994, 0.019692148148481334, 0.01317164205413844, 0.03899433882907033, 0.06301193059022937, 0.04595125659501978, 0.01763677058209266, 0.004936727329290339, 0.05456831545702048, 0.03316385365490403, 0.03503225411155394, 0.007526831202475088, 0.02983345789834857, 0.03241292234244091, 0.01987729830268238, 0.12198041672153132, 4.28853543315615, 19.99411542075021, 33.96029336111886, 27.4126010962895, 23.88060941014971, 20.668881041663035, 17.76524100984846, 14.632944447653633, 17.41442993709019, 7.328419651303973, 0.6914788069469588, 0.19272500702313014, 3.1748093324048177, 4.637011042663029, 0.9376750332968575, 3.424039261681693, 9.28694486618042, 8.206963777542114, 3.3534542492457797, 1.4501826294830866, 0.19579007183866842, 0.9394378129925046, 4.174100339412689, 14.297548821994237, 20.790024621146067, 29.28028208868844, 37.59187010356358, 47.909531593322754, 50.40637023108346, 52.81131199428013, 47.58380699157715, 49.411572320120676, 50.39604868207659, 51.56421457018171, 52.370566913059776, 54.92566272190639, 53.98256288255964, 54.354899474552695, 52.898181847163606, 53.407523018973215, 49.48803377151489, 46.39157254355294, 45.29495920453753, 47.66403089250837, 50.54261745725359, 56.237135205950054, 51.66252810614449, 60.253798484802246, 50.43775871821812, 32.73360627038138, 55.487758091517854, 51.93638093130929, 52.927499771118164, 51.09721919468471, 51.43884474890572, 47.538362298692974, 49.20796230861119, 46.513423102242605, 45.582704952784944, 45.24196529388428, 48.59672580446516, 49.82748801367623, 49.98904405321394, 51.836806297302246, 52.22142035620553, 48.93451247896467, 49.687339373997276, 50.02298947743007, 51.121325969696045, 48.4013945715768, 49.462370600019185, 45.828170912606375, 37.709200859069824, 28.9015896320343, 22.060414143971034, 15.530205283846174, 9.050071222441536, 3.340207725763321, 1.0746245703526904, 0.7306714238865035, 0.8557561518890517, 1.1763866926942552, 1.172739865524428, 2.2037588443074907, 5.863561340740748, 4.6769410371780396, 2.9503964143139974, 1.8819921101842607, 1.0679180387939726, 0.4520049898752144, 0.3531914550278868, 1.4257960809128625, 9.758988107953753, 24.689221654619487, 28.53220428739275, 20.13480601991926, 20.566072021211895, 22.396566254752024, 12.022662571498326, 2.333914888756616, 0.12140533115182604, 0.045673186159027476, 0.022169964654105048, 0.07711864648652927, 0.033140108321926424, 0.024849552029211606, 0.059021696847464354, 0.017242153274959753, 0.065077676171703, 0.04086788597383669, 0.03951869712078145, 0.060735275968909264, 0.09058840799012355, 0.01232259372980999, 0.07864727731794119, 0.023395951903824295, 0.01982392304177795, 0.03432503741766725, 0.013324088516778179, 0.02034637295374913, 0.035932232426213365, 0.05576546836112227, 0.07715510417308126, 0.013900722842663527, 0.0396428249244179, 0.0622129827471716, 0.03704364225268364, 0.07157188733773572, 0.023490032480497445, 0.030760363875223056, 0.11814659887126513, 0.03188129694068006, 0.013909945829904504, 0.01748118589499167, 0.09070018984909568, 0.06019594919468675, 0.026317803421989083, 0.05475913307496479, 0.009729142982645758, 0.027606604354722158, 0.005995560021671865, 0.027554575985829746, 0.047642155683466365, 0.031296416717980585, 0.026041565030547123, 0.041982454380818775, 0.05804202798753977, 0.06312355638614722, 0.04350937530398369, 0.06745849270373583, 0.04056359015937362, 0.04950681062681334, 0.01175387027407331, 0.0332007659599185, 0.03305431096149342, 0.05195730591991118, 0.05069497972726822, 0.03179828157382352, 0.06254621129482985, 0.009089532973510879, 0.04207227884658745, 0.05138757399150303, 0.05096981694389667, 0.01924352115020156, 0.058751097082027366, 0.053889573485191376, 0.039845598329390795, 0.04405910741271717, 0.0790761046643768, 0.01927137840539217, 0.053882109599986246, 0.04841927505497422, 0.014719446588839804, 0.017566503191898977, 0.06964176055043936, 0.5537259387118476, 7.3404452460152765, 27.662029266357422, 38.01508140563965, 30.866229261670792, 25.998312643596105, 25.637357200895035, 23.683820792606898, 25.52034432547433, 20.10182465825762, 5.260473770754678, 0.6767876009855951, 0.066167281275349, 0.8667802289128304, 1.3685624663318907, 5.40483432156699, 7.330338222639901, 9.552644848823547, 11.154001389231, 5.376201663698469, 1.8744378983974457, 0.15880622209182807, 2.941623010805675, 6.808977970055171, 17.398909398487636, 23.51590715135847, 31.743738106318883, 41.50261156899588, 49.707464831215994, 52.3191293988909, 52.90683930260794, 49.695083141326904, 50.760224614824565, 51.676507881709504, 51.69308975764683, 52.384449413844514, 55.11099549702236, 55.002825941358296, 55.326931612832205, 54.82984011513846, 53.43156378609793, 49.64724479402815, 49.846821376255576, 48.799498558044434, 50.20059585571289, 53.01353931427002, 58.16355105808803, 53.5426515851702, 56.573077133723665, 50.14147710800171, 34.940993377140586, 55.29891300201416, 50.94324711390904, 53.740341731480186, 51.65254354476929, 52.175002915518625, 49.062157835279194, 50.718438148498535, 47.61286088398525, 46.02069159916469, 46.58150502613613, 50.71255649839129, 50.94213540213448, 52.26170948573521, 51.99043096814837, 52.359470639910015, 48.327194758823936, 48.80532809666225, 51.0215220451355, 51.3377936226981, 50.528849601745605, 51.77699620383126, 47.38812140056065, 39.48491375786917, 31.755459717341832, 25.895781551088604, 17.680361815861293, 11.610617893082754, 4.667229192597525, 1.7912257292440958, 1.059927067586354, 1.618826157280377, 2.3790796995162964, 2.589868937219892, 4.311672500201634, 5.547757029533386, 4.660650985581534, 4.116489785058158, 1.2900966767753874, 0.5797429797904832, 0.4916366732546261, 0.13235852840755666, 1.3980832993984222, 10.360514504568917, 28.60280840737479, 31.85451671055385, 24.921378340039933, 21.308214323861257, 26.77527584348406, 16.75820905821664, 4.136795026915414, 0.32413381710648537, 0.06014908956629889, 0.06333501503935882, 0.05127560214272567, 0.033036577448781045, 0.0059073021236274925, 0.04197398287111095, 0.004631456120737961, 0.02451115134837372, 0.03774830426222511, 0.04078027353222881, 0.08269088462527309, 0.04086212181885328, 0.05636859778314829, 0.11351937680904355, 0.043332114815711975, 0.03818055481782981, 0.026172695315576026, 0.009360593294591775, 0.06506061780133418, 0.03354113608864801, 0.04667915842894997, 0.12198969908058643, 0.00868959934450686, 0.03465283429250121, 0.016679917462170124, 0.015477874016921436, 0.024203573120757937, 0.03443705676389592, 0.017005553202969686, 0.03494992745774133, 0.07725296927882092, 0.0444399826893849, 0.05569876836878913, 0.10682289435395173, 0.140771304124168, 0.13743131048977375, 0.21347445861569472, 0.1642702203243971, 0.23562169234667504, 0.07548861538193055, 0.09944810079676764, 0.19695882126688957, 0.07550242356956005, 0.10006479413381644, 0.15584871864744596, 0.14043243016515458, 0.13216263534767286, 0.16927554245506013, 0.1834795738437346, 0.11785244036998067, 0.08283157886138984, 0.10735568005059447, 0.0740551423015339, 0.10673758214605705, 0.14940453586833818, 0.16429109206157072, 0.10355020460805722, 0.17551042432231562, 0.054444737266749144, 0.16891904015626225, 0.1141309743481023, 0.11967582681349345, 0.1779010524707181, 0.20045770066125052, 0.12395013602716581, 0.12392588518559933, 0.18488388348902973, 0.17630458170814173, 0.12259793787130288, 0.170270939756717, 0.1613814253360033, 0.08735112420150212, 0.13025832681783608, 0.1995466724038124, 0.8329073265194893, 7.589963742664882, 29.652090617588588, 46.28306252615792, 39.598579338618684, 34.43054396765572, 30.362957341330393, 25.804096596581594, 23.764273984091624, 23.505507435117448, 9.514970847538539, 0.8654475861362049, 0.4982484813247408, 6.1603540778160095, 13.040534581456866, 9.220868366105215, 7.038473495415278, 19.488602706364222, 17.02649290221078, 7.228920578956604, 3.8545431324413846, 0.8668670813952173, 1.5343549528292246, 4.890454837254115, 15.433105945587158, 22.273405960627965, 32.19641671861921, 40.604671546391074, 48.815757342747276, 51.891342708042686, 53.95502369744437, 53.89753082820347, 51.451556478227886, 51.68801062447684, 53.307184083121165, 53.85533094406128, 56.21969175338745, 55.28799738202776, 58.47038350786482, 55.570476395743235, 56.33875955854143, 52.67941781452724, 50.83728361129761, 49.63085746765137, 52.096727984292166, 54.58499949319022, 60.285593441554475, 54.84055771146502, 57.584137303488596, 52.08055257797241, 38.79520777293614, 55.249695437295095, 52.95926693507603, 54.88858018602644, 54.66206891196114, 54.368990421295166, 52.023264680589946, 53.405678272247314, 51.67477083206177, 48.820259775434224, 48.871349879673545, 53.10805218560355, 53.82854216439383, 54.149097306387766, 53.73809398923601, 52.78116028649466, 49.25247941698347, 50.00638675689697, 52.93858562197004, 52.28019516808646, 50.61039366040911, 51.33942992346627, 46.80312129429409, 39.307067666734966, 31.1916446685791, 25.176352909633092, 17.034311362675258, 10.582135983875819, 4.447842861924853, 1.7522068172693253, 1.5016242691448756, 1.5490522384643555, 2.6492035133498053, 4.930915066174098, 6.134678312710353, 11.366638847759791, 13.415308254105703, 8.57163998058864, 4.424045281750815, 4.010032526084355, 1.4019362926483154, 0.9158034069197518, 2.4206468633243015, 13.507272873606, 32.672462122780935, 35.996848583221436, 29.077625717435563, 29.656249114445277, 32.00886051995413, 18.469046626772197, 3.4790852793625424, 0.27239856177142685, 0.12165824829467706, 0.08365715920392956, 0.1491787601262331, 0.1707006288426263, 0.06646073410021407, 0.14324803836643696, 0.08816723898053169, 0.115891447024686, 0.10208866731928927, 0.13384871344481195, 0.16437772741275175, 0.11848947618688856, 0.14724228903651237, 0.14336911615516457, 0.12937385642102786, 0.1397383295531784, 0.08075638807245664, 0.07962581302438464, 0.1503115471984659, 0.11075600901884691, 0.2087955932532038, 0.3384961507150105, 0.13333997502923012, 0.13277216335492475, 0.10928195954433509, 0.16659041653786386, 0.19122739881277084, 0.11158099903592042, 0.11557748887155737, 0.16396234184503555, 0.14215190575591155, 0.11350912414491177, 0.25724929038967403], [0.06110678067696946, 0.026027838267119865, 0.016075095095272576, 0.04038595308416656, 0.025556661853832856, 0.02646885040615286, 0.020886001676054936, 0.023132179897012453, 0.027653255333591784, 0.004790120084570455, 0.08200042096099683, 0.021483485686725805, 0.0195042295714042, 0.03638658286737544, 0.006934376408545566, 0.026699285987498503, 0.05040364393166133, 0.004105940502735653, 0.03459932841360569, 0.02228214854507574, 0.013586305830228542, 0.03714080846735409, 0.061299966382128854, 0.04901560216343828, 0.07974469235965184, 0.037450671661645174, 0.04798717038439853, 0.04225477762520313, 0.013112860565472926, 0.07419523942683424, 0.009687266345801098, 0.019567077181168964, 0.0627653713205031, 0.04278100188821554, 0.05816514816667352, 0.0457098711548107, 0.03570450928860477, 0.05512632230030639, 0.05908313819340297, 0.07214323417948824, 0.02305051651118057, 0.017632455099374056, 0.2413687211062227, 3.6092541345528195, 15.242489065442767, 28.784740039280482, 28.26277572768075, 18.368785858154297, 19.718223299298966, 22.152807814734324, 11.187820877347674, 19.88938696043832, 9.065188765525818, 1.0356005557945795, 0.44766220290746006, 1.0155825785228183, 6.108498803206852, 10.613034623009817, 8.159788983208792, 11.3351582969938, 3.9197515419551303, 1.2721718443291528, 1.2614055020468575, 0.9398405913795743, 0.47138587704726626, 2.5271551481315067, 6.572059163025447, 9.960866280964442, 17.571452277047293, 27.784263713019236, 35.53299379348755, 47.39678233010428, 50.14636516571045, 49.60149090630667, 48.18667091642107, 53.32997070040022, 51.30382735388619, 52.57673386165074, 52.85888283593314, 54.46379164287022, 55.01239708491734, 54.228636809757774, 52.33524921962193, 51.098782539367676, 51.21145452771868, 50.27278763907296, 52.15522139413016, 54.473932538713726, 55.50772374016898, 50.873125893729075, 47.59928410393851, 28.820957524435862, 54.708128520420615, 52.56908042090279, 53.839676652635845, 56.60669251850673, 52.69765336172921, 50.309922286442344, 50.44440467017037, 50.11899273736136, 50.01826817648751, 48.30219166619437, 47.956258228846956, 48.63280432564871, 51.87945434025356, 52.67469303948538, 50.24564102717808, 50.90832894189017, 50.26850754874093, 50.4543788092477, 49.777120522090364, 46.6261020387922, 39.75203725269863, 28.152009282793315, 18.98962824685233, 12.330853394099645, 7.315803459712437, 3.2951260762555257, 1.400075043950762, 0.4678452270371573, 0.4321832177894456, 0.8300681188702583, 2.650410979986191, 2.514748271022524, 1.1314139344862528, 3.726689330169133, 4.008975097111293, 1.9832586305482047, 3.276406760726656, 0.8752485630767686, 1.1029659467084068, 0.3959919240857874, 1.7626876320157732, 11.830001183918544, 28.706001315798076, 25.561406442097255, 21.578058038439067, 22.34773431505476, 23.93906807899475, 15.727471590042114, 2.405113513980593, 0.06497865755643163, 0.03669436974450946, 0.022823315845536332, 0.02060701182511236, 0.046015025316072364, 0.04148609583665218, 0.03864739369601011, 0.011774459571045424, 0.061196700137640746, 0.022333218483254313, 0.04159934672393969, 0.053946383829627714, 0.03900079508977277, 0.06635180887367044, 0.03883953106456569, 0.02627871641223984, 0.049543614366224835, 0.02540252753533423, 0.032635861808168035, 0.018107863874839883, 0.02826706998582397, 0.058084185368248394, 0.053836125281772444, 0.053592005345438204, 0.019565645472279618, 0.1290417406708002, 0.03953813036371555, 0.021118025029344217, 0.009757964605731624, 0.00548804212095482, 0.05099549949435251, 0.018983808479138782, 0.01912575800504003, 0.051794491442186494, 0.019280859235940234, 0.025630321919119785, 0.027340488009420887, 0.055831082697425566, 0.0367367205076984, 0.045300731501941166, 0.0665707178413868, 0.06633431624088969, 0.04630371482510652, 0.012540413648821414, 0.025548546575009823, 0.02478656531976802, 0.03634829313627311, 0.010584235357652818, 0.03964339828650866, 0.03880604536139539, 0.09692234239940133, 0.050364821550569365, 0.029805458150804043, 0.07377524660634142, 0.016339745804933564, 0.04357908120644944, 0.10092424015913691, 0.019878707959183624, 0.04416947113350034, 0.04154184088110924, 0.02482593052887491, 0.045685321757836, 0.045352642823542864, 0.03985995273771031, 0.031738702806511095, 0.02409559445056532, 0.04092061832281096, 0.030925607508314506, 0.033958659041672945, 0.0371946705771344, 0.03918573320178049, 0.008198488420540733, 0.044700719948325834, 0.022472464047106247, 0.07416095983769212, 0.047895208533321104, 0.023640555296359316, 0.6738254427909851, 6.528731499399457, 23.571055003574916, 34.91453811100551, 31.833706855773926, 18.137758255004883, 18.988386256354197, 21.636697360447474, 24.311324766704015, 23.80737713405064, 6.76268299136843, 1.204023044024195, 0.0701857420748898, 0.30886371220861164, 0.7048588661210877, 3.5243048071861267, 7.2077924098287305, 16.313074452536448, 8.42848537649427, 3.461757557732718, 1.7934713001762117, 2.1430278973920003, 1.985975593328476, 5.204305401870182, 9.086737734930855, 13.240628804479327, 20.915887764522008, 31.051304953438894, 38.4580533845084, 50.92616149357387, 51.86998047147478, 51.56380810056414, 49.68560232434954, 54.27936908176967, 53.05086156300136, 53.6684695652553, 53.07661158697945, 56.59199013028826, 55.83085666384016, 54.35734871455601, 53.42422301428658, 51.534924439021516, 52.50935023171561, 51.070989745003835, 54.11276517595564, 55.2553825378418, 58.15900693620954, 52.88776649747576, 47.994838101523264, 34.015910216740195, 55.617383684430806, 51.346631731305806, 53.892903327941895, 57.30469465255737, 54.42324195589338, 51.52291795185634, 53.06194741385323, 50.70897470201765, 51.851262024470735, 47.81439338411604, 50.525306020464214, 51.3925975390843, 52.80705622264317, 53.17817687988281, 51.332610266549246, 50.36230475561959, 51.09570101329258, 50.12792812074934, 50.85253490720476, 47.72604356493269, 42.91794572557722, 32.13540458679199, 22.008425985063823, 15.793529851096016, 9.439227666173663, 4.714372720037188, 1.9329630093915122, 1.1102550412927354, 1.2379912670169557, 2.092103030000414, 3.8220646466527666, 3.401326686143875, 3.290549601827349, 5.394762473446982, 5.062484851905277, 3.1102835834026337, 1.2816574381930488, 0.6266349064452308, 0.18707188751016343, 0.12315410588468824, 1.7084042876958847, 11.767142568315778, 29.547224930354528, 30.974694115774973, 25.276342698505946, 24.576811960765294, 28.687178645815166, 20.459537029266357, 4.77408857856478, 0.22341882357639925, 0.051454443617590835, 0.032281798842762194, 0.08701972769839422, 0.04862289323604532, 0.03937479680670159, 0.020412508065679243, 0.012183789213720177, 0.026379567072061554, 0.06160664385450738, 0.06398411520889827, 0.06380089039781264, 0.08049234974064998, 0.052443588219050846, 0.024718423440520252, 0.09410895979298012, 0.03906400741211005, 0.03870656873498644, 0.018714638726253594, 0.008408146411446589, 0.042321996696825535, 0.023124777079959, 0.002615509708578299, 0.012989826899554049, 0.030145753640681505, 0.025870531797409058, 0.03644034658957805, 0.020292917964980006, 0.0422323011527104, 0.03937720899869289, 0.01945483052570905, 0.01718525472097099, 0.04464511739622269, 0.014017653086089661, 0.03862805884065373, 0.08186214909489666, 0.08096402657351323, 0.11748054889695984, 0.13098613704953874, 0.0978939299072538, 0.17216873435037477, 0.14147478209010192, 0.12142514437437057, 0.1477617754467896, 0.12267206103674003, 0.16974911918597563, 0.20517807879618236, 0.08100825348602873, 0.18442809794630322, 0.10572113668812172, 0.15785457672817366, 0.11418893480939524, 0.14935203082859516, 0.1382366501327072, 0.11608345886426312, 0.10506541401680027, 0.13325948720531805, 0.1379808967134782, 0.17531626831207955, 0.17784439479666098, 0.1591377543019397, 0.13182844328028814, 0.32608647804175106, 0.1615826788225344, 0.19263263126569136, 0.08794805181345769, 0.09929817169904709, 0.10180232554141964, 0.15713652383003915, 0.1814214549958706, 0.17897773826760904, 0.15778153921876634, 0.11590898036956787, 0.17461578947092804, 0.2698037081531116, 0.16683486556368216, 0.1720001862517425, 0.5259490492088454, 5.705274862902505, 23.912838629313878, 43.1818973677499, 40.31298269544329, 27.932906525475637, 26.510485206331524, 31.045454570225306, 20.060969250542776, 27.76603511401585, 11.11980756691524, 1.5993589333125522, 0.6385891192725727, 2.1600145058972493, 14.531188079289027, 19.266117913382395, 21.647449697766984, 22.17489092690604, 10.475611414228167, 3.911769364561353, 3.9440902130944386, 2.6245817031179155, 1.7641149439982005, 3.572757418666567, 7.875134314809527, 10.625576989991323, 19.13795839037214, 29.031658172607422, 36.680933475494385, 49.33418328421456, 51.15670619692121, 55.14962748118809, 54.05723169871739, 53.77172327041626, 52.147380352020264, 52.806135586329866, 53.95852558953421, 57.44302633830479, 57.80396441050938, 57.0287504196167, 54.90257733208792, 55.703701155526296, 55.77883550098964, 54.747121810913086, 56.54090002604893, 58.55943162100655, 60.120393071855815, 53.198305811200825, 50.569538252694265, 35.43741437367031, 56.260109424591064, 52.04380355562483, 55.06363310132708, 58.64146205357143, 57.14817953109741, 54.06147357395717, 55.83857611247471, 53.53538029534476, 54.21343067714146, 51.92765746797834, 52.23962116241455, 51.94512871333531, 56.34994615827288, 54.24904366901943, 50.877944469451904, 51.81135851996285, 51.089176654815674, 51.0338134084429, 51.59910494940621, 49.4590493610927, 41.91405609675816, 31.07664850779942, 20.808485984802246, 13.958081551960536, 8.431789244924273, 4.426910979407174, 2.1028809888022284, 0.9956906459161213, 0.9139485635927745, 3.0769717480455125, 6.902357416493552, 7.108518285410745, 4.130751831190927, 9.510642988341194, 11.459476334708077, 7.043698975018092, 8.396763375827245, 2.6786467220102037, 2.2053758203983307, 0.5380549281835556, 2.7023887165955136, 15.676490919930593, 35.85854121616909, 33.18425253459385, 31.486727714538574, 32.62470020566668, 34.800181184496196, 22.287608078547887, 4.291048075471606, 0.38399553352168625, 0.14301874781293528, 0.12257397201444421, 0.14703319168516568, 0.15728713146277837, 0.1701611392199993, 0.11634407059422561, 0.08587351920349257, 0.10997941211930343, 0.12393131346574851, 0.21641554151262554, 0.17140527388879231, 0.21773191301950387, 0.21426582043724401, 0.07778542249330453, 0.10782975889742374, 0.1391050528202738, 0.09310974912451846, 0.13629817057933125, 0.1032977488690189, 0.13630476593971252, 0.1472925277692931, 0.19034667392926558, 0.146133494962539, 0.10398068079458815, 0.1745805735034602, 0.10747677141002246, 0.07620909065008163, 0.14486913995019027, 0.12115082623703138, 0.15027947963348456, 0.1354096561138119, 0.10347984052662339, 0.08968645174588476, 0.11746723603989397], [0.0183529473309006, 0.021242079890466163, 0.03351035774020212, 0.009022474205786628, 0.01320704716324274, 0.06024238813136305, 0.05267435458621808, 0.031540326308459044, 0.03686372869248901, 0.018777131801471114, 0.04238726498026933, 0.06784751040062734, 0.027629437058099678, 0.05365349079615303, 0.1032589366659522, 0.013938206813431211, 0.025978529127314687, 0.02406360491711114, 0.00683036759229643, 0.034189079355980666, 0.041474900008844476, 0.009795109308989984, 0.044457129269306145, 0.06633380055427551, 0.035093308692531924, 0.05419899902439543, 0.013951977681634682, 0.026159407903573344, 0.013945433211379817, 0.015627056726121476, 0.05280175292864442, 0.06225577795079776, 0.02719892355214272, 0.061230694742075036, 0.01648450955482466, 0.01098059056260224, 0.015763710286202173, 0.07736150774040393, 0.06472073961049318, 0.0309389644701566, 0.09256359628800835, 0.06037164226706539, 0.032381065123315365, 0.03574556404990809, 1.9188807478972842, 15.949756622314453, 30.616323402949742, 31.250277042388916, 26.018740347453527, 19.400727101734706, 15.38393007005964, 15.365770953042166, 26.005245208740234, 8.112826977457319, 3.023962203945432, 0.3946689436478274, 1.1498925600733076, 4.727632054260798, 6.0451976742063245, 11.619778224400111, 8.557617647307259, 1.501286955816405, 0.8069967340145792, 2.999970942735672, 1.4096228459051676, 1.1948425195046832, 1.1072837093046732, 2.0959327902112688, 4.329015638147082, 8.69039077418191, 17.5586120060512, 27.15498968533107, 39.136763845171245, 47.140372957502095, 51.912190777914866, 46.44664396558489, 52.28412784848894, 49.63373749596732, 52.78760126658848, 54.8526406288147, 54.63875770568848, 54.57630729675293, 52.17612157549177, 54.903671673366, 53.07089669363839, 54.406111172267366, 53.838227953229634, 55.64015987941197, 54.51477405003139, 59.56289740971157, 45.26723936625889, 30.97575719015939, 53.15522003173828, 54.037936551230295, 54.59106527056013, 54.756091935294016, 55.75853286470686, 52.50780425752912, 52.356889384133474, 49.80751541682652, 52.31294897624424, 51.780338287353516, 51.10243034362793, 51.1013776915414, 53.214304038456504, 52.32424674715315, 51.4656891141619, 50.84429781777518, 51.052535329546245, 47.33695139203753, 39.83789961678641, 26.45084708077567, 15.734817573002406, 8.086505464145116, 4.9777728489467075, 2.2761542967387607, 0.9924751498869487, 0.2961420219923769, 0.18549539281853608, 0.5947579283799443, 1.5414593773228782, 1.0667161090033395, 2.4234204973493303, 1.80892604802336, 3.3725756917681013, 4.1985862255096436, 2.930006057024002, 1.9299807122775485, 0.7560344114899635, 0.3391684703528881, 0.2129748532814639, 4.401649500642504, 15.316004480634417, 23.424845797674998, 24.210146835872106, 11.920530131884984, 22.14124948637826, 26.271430696759904, 14.41164345400674, 3.378295361995697, 0.04159199479701264, 0.006499075838032046, 0.03626873829801168, 0.07906319892832211, 0.058199685599122725, 0.03337416897660919, 0.015126467516113604, 0.03303054866514035, 0.06021618989429303, 0.04438809511650886, 0.05215660522558859, 0.038259627896228006, 0.03370055449860437, 0.012888824417521911, 0.03769321400406105, 0.02169222680718771, 0.011055944420929466, 0.08505777761872325, 0.06439764159066336, 0.0868749011840139, 0.00404358101409993, 0.021076393513275043, 0.032708899317575355, 0.03472756813945515, 0.04640282843528049, 0.052728864696941206, 0.03949929101924811, 0.010624171384344143, 0.00428156614569681, 0.037362648706351004, 0.05751984100788832, 0.021157318992274146, 0.027484137265543853, 0.03497116560382502, 0.019433385426444665, 0.009750314971565135, 0.02846397745556065, 0.05016963755978005, 0.028917167601840835, 0.04269087208168847, 0.04988428983571274, 0.08543219324201345, 0.01554078608751297, 0.04197307363418596, 0.033175992646387646, 0.026555297463866215, 0.06805702165833541, 0.08480778496180262, 0.004925952617278588, 0.03466944143708263, 0.027755620822842633, 0.0194202913969223, 0.023828109160863926, 0.0024800637287886013, 0.03373918349721602, 0.038586841230945926, 0.04188273008912802, 0.015817631767796617, 0.004996094478493822, 0.060070053807326725, 0.06854502404374735, 0.052717071758317094, 0.046165225827800374, 0.02597154869831034, 0.021899834774168472, 0.04000136622094682, 0.02063753572292626, 0.04100826808384486, 0.02964205334761313, 0.0398524243916784, 0.05944062436797789, 0.007901027150053, 0.04550356597506574, 0.023837503478197113, 0.05437970986323697, 0.010730283235066702, 0.07151651888021401, 0.01684859617879348, 0.08748481595622641, 0.19096420864973748, 4.651821996484484, 21.769324575151714, 34.84033482415335, 31.97986568723406, 23.66746994427272, 21.719648429325648, 13.930880223001752, 26.890331063951763, 29.09552080290658, 10.219988925116402, 3.105963323797498, 0.06802386843732425, 0.31699714862874573, 1.1595893140350069, 2.6220892540046146, 6.7645116703850885, 6.757641639028277, 7.46164527961186, 2.7591385628495897, 3.3327410178525105, 3.5518917611667087, 1.3957822514431817, 2.24110215476581, 3.1487284004688263, 6.344590774604252, 11.069187334605626, 19.668628794806345, 29.63361188343593, 42.68848841530936, 49.743824754442485, 53.148553235190256, 49.42275544575283, 53.95493337086269, 51.44122450692313, 52.18202754429409, 55.019915035792756, 56.078820501055034, 56.08271149226597, 53.72115428107125, 56.921772480010986, 53.5561797278268, 56.0278902053833, 55.64656959261213, 56.28302805764334, 55.67854520252773, 59.03923947470528, 48.46885115759713, 30.178402764456614, 53.15648112978254, 53.87741231918335, 54.61309453419277, 53.87925706590925, 56.14247989654541, 55.58186101913452, 53.93531513214111, 52.77788073675973, 53.89334453855242, 52.96449545451573, 53.70131369999477, 52.34003305435181, 55.1385555267334, 52.47867393493652, 52.59811346871512, 51.834370953696116, 52.12694222586495, 47.29007537024361, 42.82671240397862, 31.268901688711985, 20.193448816026958, 11.4932576077325, 7.824832831110273, 3.5904777135167802, 2.358093968459538, 1.5231333949736185, 1.296530925801822, 1.870120461497988, 3.180559618132455, 3.528477200439998, 3.553206273487636, 5.083701176302774, 4.220591170447213, 6.358763362680163, 2.9336369250501906, 1.7993784632001604, 0.5506938099861145, 0.3180190223668303, 0.25060806104115074, 3.5571561072553908, 16.505977290017263, 28.263864857809885, 31.127203600747244, 17.227467809404644, 24.073081459317887, 30.220349039350236, 19.954112904412405, 6.425952877317156, 0.1718364150396415, 0.0746236935790096, 0.023364500109372393, 0.08395034740013735, 0.035886115793670924, 0.047153610470039506, 0.02665542548389307, 0.037723917713654895, 0.015345211939087935, 0.06495175364294223, 0.0333936972144459, 0.054530456595654996, 0.034652335569262505, 0.06471715694559471, 0.027012021081256013, 0.025079080069969808, 0.03536005437906299, 0.05520921213818448, 0.030083878032330955, 0.0385210911876389, 0.006638680601359478, 0.03296128041776163, 0.012876832159236073, 0.011423597594590058, 0.021818782069853375, 0.043504934292286634, 0.016619202148701464, 0.01584460523112544, 0.011686140604849373, 0.018567513674497604, 0.02214974261421178, 0.029931160155683756, 0.05674434333507504, 0.028236859910456196, 0.03542167214410646, 0.018552677506314855, 0.11325168117348637, 0.11164554807224444, 0.06592798233032227, 0.23847810764397892, 0.2232756662581648, 0.1515483944011586, 0.11188095222626414, 0.13841302852545465, 0.11997487076691218, 0.08170635745461498, 0.15518098590629442, 0.20335997135511466, 0.09593182376452855, 0.09748773170369011, 0.18620742032570498, 0.13488660060933658, 0.07933342549949884, 0.10342645339135613, 0.08291420407061066, 0.08991080256445066, 0.13006968051195145, 0.13936411749039376, 0.14253386668860912, 0.1809701206428664, 0.1474753793861185, 0.1405250501952001, 0.10102990163224083, 0.12219435881291117, 0.1421223080583981, 0.11590773186513356, 0.2922811305948666, 0.17784909025899, 0.18018049587096485, 0.17017853685787745, 0.17105981814009802, 0.06786009722522326, 0.09953960802938257, 0.16225916466542653, 0.17843054048717022, 0.11360152025840112, 0.13362597753959043, 0.19016535580158234, 0.2048117784517152, 0.31749074214271134, 3.9702306389808655, 22.086245809282573, 43.283090932028635, 44.382146562848774, 34.1381915637425, 28.527738332748413, 22.305449315479823, 23.561471700668335, 32.97076218468802, 11.137878094400678, 3.86270900283541, 0.888428264430591, 1.5618549457618167, 7.463906918253217, 12.531906468527657, 19.593973875045776, 17.93641335623605, 7.222413156713758, 1.3165051511355808, 5.312062408242907, 2.8596160284110477, 2.2405404363359724, 2.009522169828415, 2.6435405143669675, 5.525945331369128, 9.592832360948835, 18.717074734824045, 28.49714888845171, 41.15810251235962, 48.60807221276419, 57.446802684238975, 53.53932687214443, 56.81574991771153, 55.06317452022007, 52.73739358357021, 57.228865487234934, 56.68312617710659, 57.09749242237636, 55.48683745520455, 57.418144839150564, 56.03799288613455, 59.2270701272147, 58.05775778634207, 58.81402056557791, 57.078680174691335, 60.87682260785784, 49.16908366339547, 37.45890242712838, 53.966863427843364, 54.53682763235909, 54.53270040239607, 55.05808843885149, 56.48094054630825, 57.39599398204258, 55.90833255222866, 55.03607307161604, 56.44388232912336, 55.322627203805105, 55.77546909877232, 54.44477094922747, 56.19971568243844, 54.115540981292725, 52.77651194163731, 51.80611957822527, 52.48671647480556, 48.67421211515154, 43.170377254486084, 29.524476528167725, 17.312529393604823, 8.78640011378697, 6.246683708259037, 3.46543510896819, 1.7601134330034256, 0.8859862983226776, 0.8822102780852998, 2.043160570519311, 4.156371576445443, 4.345988350255149, 6.0471444725990295, 7.381964206695557, 7.573740567479815, 8.053597927093506, 8.087551168033055, 5.860917116914477, 2.8787709091390883, 0.7534629266176904, 0.636508893753801, 5.975436457565852, 19.455711671284266, 30.61354759761265, 30.964278766087123, 18.929436002458843, 30.88335657119751, 36.5382695879255, 21.230988570622035, 5.193106642791203, 0.23292888541306767, 0.14510722431753362, 0.1424384918063879, 0.14581074299556868, 0.13215433007904462, 0.24536651372909546, 0.13483885888542446, 0.11979100134755884, 0.19132410362362862, 0.14946580758052214, 0.20104090150977882, 0.18113736595426286, 0.17632180292691502, 0.24376381401504787, 0.1358563492872885, 0.12052544765174389, 0.08733014389872551, 0.1636810755091054, 0.22315469703504018, 0.16863043207143033, 0.14028374957186834, 0.1547040572123868, 0.12178419796483857, 0.0867422204464674, 0.12525740159409388, 0.10297992306628398, 0.1504231933504343, 0.18060434955571378, 0.18982432410120964, 0.0711972817246403, 0.08902960270643234, 0.13737953826785088, 0.13120125979185104, 0.09208416379988194, 0.15847892394023283, 0.1048202525292124], [0.0382993900483208, 0.028815031118158783, 0.014665263871263181, 0.026566695155841962, 0.05006669022675071, 0.0475270727516285, 0.016681593443666185, 0.08419149196041481, 0.03895937391955938, 0.04793800034427217, 0.11405545340052672, 0.030451107969773666, 0.06020019682390349, 0.010554635115633053, 0.026219995991726006, 0.03892811720392533, 0.042171965818852186, 0.05588685827595847, 0.025496730248310735, 0.01489302093562271, 0.05854141619056463, 0.02916132825027619, 0.003878809811015214, 0.015384393943739789, 0.02432204194233886, 0.0857883087758507, 0.06446287594735622, 0.027173585358208845, 0.044031911729169745, 0.035385370520608764, 0.02756695924992008, 0.013473201676138809, 0.07651850261858531, 0.014763391909322568, 0.029154498795313493, 0.014213478292471595, 0.05472292644636972, 0.011088525976187416, 0.05365191998758486, 0.020039071229153445, 0.047629137989133596, 0.035436908647950204, 0.008855098276399076, 0.008973886009438761, 0.137570749436106, 1.6846909544297626, 12.52851140499115, 22.999885286603654, 34.494328430720735, 23.233268329075404, 18.62756630352565, 12.486396636281695, 19.7457138470241, 32.851228850228445, 10.22924826826368, 4.607290123190198, 1.0396878336157118, 0.4278873854449817, 2.116250191416059, 11.549708247184753, 6.137196600437164, 9.748440742492676, 5.455085865088871, 2.8080425901072363, 3.597445236785071, 1.2100711252008165, 0.7071027000035558, 0.5011496799332755, 0.3541218622454575, 1.300339081457683, 3.613333595650537, 9.069928305489675, 14.478433881487165, 23.586492163794382, 34.00273643221174, 37.40963275091988, 35.09541709082467, 43.40986776351929, 49.45642989022391, 53.19930287769863, 54.95741598946707, 54.48651920046125, 55.0128938811166, 58.33748531341553, 57.73128277914864, 57.22383846555437, 56.990184443337576, 55.61660201208932, 55.25549370901925, 52.27123894010271, 37.09554638181414, 45.96921239580427, 50.425964151109966, 53.003975118909565, 55.209750243595664, 55.86826229095459, 53.024194376809255, 55.12779624121529, 55.51627002443586, 54.22978673662458, 52.76052066258022, 52.010386194501606, 50.20754752840315, 51.566076687404085, 52.90039832251412, 50.25388853890555, 49.99175385066441, 47.33842441013881, 39.54196194240025, 26.727440970284597, 15.537257705415998, 5.585446664265223, 2.8824703906263625, 0.9692450421197074, 0.7370354852506092, 0.44280752912163734, 0.802823472235884, 0.9369454724448067, 0.9153820638145719, 1.951768308877945, 3.1980378116880144, 3.920923616204943, 2.1237423036779677, 3.103293695620128, 3.4757564408438544, 6.313858892236437, 1.8679180996758598, 1.6598314940929413, 0.1188894182975803, 1.6238814060177122, 7.527185899870736, 20.118522916521343, 16.436457089015416, 29.784533705030167, 23.979895693915232, 24.579200404030935, 23.40170134816851, 18.144810676574707, 3.227191584450858, 0.16521324829331466, 0.048533811766122065, 0.04214915007885013, 0.035487072741878886, 0.002155474204170917, 0.05694255019937243, 0.04281747993081808, 0.06508178130856582, 0.03013521938451699, 0.026742172793352177, 0.05476036461602364, 0.04626928935093539, 0.01067644402584327, 0.06009105446615389, 0.06978071095155818, 0.043355106974818876, 0.0046139270166999525, 0.02091804549231061, 0.017844985837915113, 0.061470597583268366, 0.031195956215794598, 0.04236540936731866, 0.15896247513592243, 0.03339209247912679, 0.04470186327983226, 0.040284946361290555, 0.1378565483859607, 0.040569622335689406, 0.05948090899203505, 0.06513276642986707, 0.014225534163415432, 0.040069043303706815, 0.023029017129114697, 0.04439698392525315, 0.011407490021416118, 0.048142765249524794, 0.07061876955309085, 0.05489891128880637, 0.007521843121919248, 0.03610859724826046, 0.17400471440383367, 0.003274943966451766, 0.040878874848463705, 0.034172075268413336, 0.024177296852160777, 0.016361374108652984, 0.03479480417445302, 0.06230489710079772, 0.027665730199909637, 0.01644938179690923, 0.01759534771554172, 0.04123514983803034, 0.04989858656855566, 0.07415211174104895, 0.018082215251134973, 0.055966810057205815, 0.05552140949293971, 0.013278769162882651, 0.010020085227941828, 0.059434408987207074, 0.02072814728931657, 0.015653353350769197, 0.03872321659166898, 0.0437542585922139, 0.06085557344236544, 0.04909445811063051, 0.05011232849210501, 0.02304141566024295, 0.04919914249330759, 0.03319057097126331, 0.008645555636446391, 0.03395505941339901, 0.018335909316582338, 0.005109002705596919, 0.007472539071126708, 0.03189619417701449, 0.04221520207024046, 0.043412161591861925, 0.05546615638637117, 0.055790228103952746, 0.023791989045483724, 0.16296135341482504, 4.419713948454175, 20.079955203192576, 30.520215920039586, 36.78004952839443, 23.85142523901803, 14.64493009022304, 13.614997744560242, 30.833440712520055, 31.575053215026855, 13.760916863168989, 6.5860589146614075, 0.2827480935624668, 0.12576088814863137, 0.2731916606426239, 1.6187284482376916, 3.017965908561434, 11.045184782573156, 6.588203302451542, 4.3050083092280795, 1.2682920353753226, 3.548362727676119, 1.573383310011455, 1.2058490089007785, 0.9628557392529079, 1.9916700763361794, 5.920193936143603, 12.286743623869759, 17.79259433065142, 27.797981194087438, 40.883221353803364, 39.67894567762102, 40.02784252166748, 47.503694261823384, 52.63536623546055, 53.61440910611834, 56.20832102639334, 55.74510894502912, 56.16380391802107, 58.83658136640276, 59.3681116104126, 60.07727255140032, 57.36806917190552, 56.83977678843907, 58.5079802104405, 55.41997494016375, 38.25772292273385, 42.83214242117745, 52.46778610774449, 53.84400885445731, 54.89302703312465, 55.75147349493844, 53.213174956185476, 55.23542383738926, 56.51049470901489, 53.426661831992014, 54.3001754624503, 52.44011490685599, 52.26541634968349, 53.05272020612444, 54.008135727473665, 52.92789581843785, 50.796487263270784, 50.12207773753575, 42.76809740066528, 34.054483141217915, 20.98943965775626, 8.32619833946228, 4.509213694504329, 2.7380119136401584, 1.5281389206647873, 0.9276064421449388, 1.5896260270050593, 3.7069707768304005, 4.019138140337808, 4.916075885295868, 4.570685710225787, 5.3042713063103815, 5.355615454060691, 4.777535319328308, 3.5084251335689, 2.9060293436050415, 0.8107172229460308, 0.3376004030661923, 0.01610607361154897, 1.0880573924098695, 6.055484916482653, 23.303287063326152, 21.64145687648228, 26.85653155190604, 23.521236419677734, 19.57107434953962, 28.87897845676967, 23.285100153514318, 6.649667935711997, 0.3315116912126541, 0.04065183703122394, 0.036775946617126465, 0.021651360339352062, 0.03550855855324438, 0.01884595051939998, 0.038064131779330115, 0.06141985673457384, 0.02914746238717011, 0.0232936101632991, 0.03060459598366703, 0.018926462092037712, 0.01600172171103103, 0.06179081861461912, 0.05561758165380784, 0.049375754980636496, 0.009679540376445013, 0.017597040660413246, 0.04061819187232426, 0.01294662881576057, 0.06995286885648966, 0.10059502853878907, 0.09284082534057753, 0.04169053504509585, 0.028636084470365728, 0.04173755752188819, 0.05953237587319953, 0.05607758089900017, 0.02597099229959505, 0.07171414220439536, 0.05395532352849841, 0.0022402181389874643, 0.05254787226606693, 0.01746886200271547, 0.02125112645860229, 0.13078405575028487, 0.035388722483600886, 0.12408645371241228, 0.10595597087272576, 0.11506894044578075, 0.2618181380842413, 0.15552173262195929, 0.17751415180308477, 0.13963216596416064, 0.174026739650539, 0.07806338436369385, 0.15999730889286312, 0.15837221752320016, 0.13847070400203976, 0.09641082199024302, 0.14967490493186883, 0.1498705130070448, 0.05235054071194359, 0.1976530575858695, 0.12094575938369546, 0.24069545151931898, 0.18291048652359418, 0.12464743932443005, 0.12106906276728426, 0.07416188264531748, 0.08884848135390452, 0.1359893014388425, 0.18592718536300318, 0.15657971799373627, 0.17574797943234444, 0.13342228132699216, 0.11824905765908104, 0.18505507787423475, 0.10466425054307495, 0.1633643896452018, 0.18168670790536062, 0.08373097024325814, 0.14276821911334991, 0.09979725456131355, 0.10040541871317796, 0.10314467136881181, 0.15349616988429002, 0.2128014468720981, 0.25876616899456295, 0.09121093672833272, 0.12286971828767232, 0.20742865731673582, 3.828723192214966, 20.08026613507952, 35.47988871165684, 47.82543407167707, 33.79007986613682, 25.305332320077078, 18.159799677985056, 28.864519255501882, 39.36644697189331, 14.483676297324044, 6.331317109721048, 1.416106600846563, 1.014396716441427, 5.176689352308001, 16.56753659248352, 11.263400776045662, 13.457788671766009, 10.390349200793676, 8.578032323292323, 9.904380900519234, 3.1774094785962785, 1.6043800924505507, 1.0169505051204135, 0.8581440523266792, 1.8463491541998727, 4.752120545932224, 10.449791039739337, 15.893010684422084, 25.15809825488499, 38.86203554698399, 40.98688152858189, 41.81522839409964, 49.24426317214966, 52.976602690560476, 53.26539066859654, 57.10683080128261, 57.04969229016985, 58.90012264251709, 61.11306135995047, 62.66048771994454, 60.55793503352574, 59.1345340183803, 57.46791825975691, 59.028935296194895, 54.34463351113455, 42.966888836451936, 45.7377679007394, 53.33391032900129, 53.858131068093435, 55.1956592968532, 55.87414741516113, 53.0684300831386, 57.096224376133506, 57.62108782359532, 55.63883972167969, 56.410346848624094, 54.51644509179251, 53.43834522792271, 54.162385736192974, 54.98801238196236, 53.19602680206299, 51.64740882601057, 46.29098694665091, 41.03249992643084, 28.81601561818804, 18.730446543012345, 6.9039272751126965, 3.684190673487527, 1.9138654513018472, 1.4726762281996864, 0.7763492614030838, 2.0762678682804108, 1.789213357227189, 3.5232289220605577, 5.685267525059836, 7.671544279370989, 7.614657640457153, 7.489843675068446, 7.824203150612967, 9.440807512828282, 10.930500422205244, 4.512551435402461, 3.591153642960957, 0.5620135654296193, 2.4612380223614827, 9.056244696889605, 24.261747632707866, 21.58655742236546, 36.96520512444632, 31.260358878544398, 32.51899378640311, 35.46730204990932, 25.46337604522705, 6.208502488476889, 0.4006372833890574, 0.11822159056152616, 0.08693753675158535, 0.09328662284782954, 0.13359447994402476, 0.08340425563177892, 0.12907507031091622, 0.13166657196623938, 0.1677147490637643, 0.09722950841699328, 0.2325480915606022, 0.09861944669059344, 0.07175648278955903, 0.24140766901629312, 0.19113602728715964, 0.1543819159269333, 0.1171261907688209, 0.09528159722685814, 0.14068270102143288, 0.12036319635808468, 0.15247221982904843, 0.269011097827128, 0.2330103096153055, 0.15707613421337946, 0.14735172316432, 0.09927692676761321, 0.2216961860124554, 0.11392294908208506, 0.15517510979303292, 0.17190521849053247, 0.14215969533792563, 0.06352183608604328, 0.10271848352359873, 0.12414883822202682, 0.12440159251647336, 0.30199712780969484, 0.14270027061658247], [0.07779676081346613, 0.048872614478958507, 0.04218136013618537, 0.01760837049888713, 0.033505692811948914, 0.0682693827631218, 0.00955728702579758, 0.01743331864210112, 0.07714199487652097, 0.006686278136580118, 0.07166730971740824, 0.03865597377132092, 0.04422110425574439, 0.025522499311981455, 0.09101833456328937, 0.04177090412537966, 0.04025616629847458, 0.010880559233815541, 0.02837656857445836, 0.02970811551702874, 0.053035440389066935, 0.011310407775454223, 0.035997968898820024, 0.038105644551771026, 0.021542825270444155, 0.062342555794332705, 0.10152952732252223, 0.044833994404013665, 0.01757691191908504, 0.046680135519376824, 0.06329614176814045, 0.054574008365826945, 0.08746212574520282, 0.05182990079213466, 0.07632123891796384, 0.02809047615820808, 0.032164490316063166, 0.02094651003634291, 0.0495937343553773, 0.07607761091951813, 0.08080444870782749, 0.0790114470624498, 0.04941016688410725, 0.05305152506168399, 0.07426035164722375, 0.043636261352470944, 0.7720960953405925, 6.90156923021589, 23.004584005900792, 29.637537615639822, 22.8576626096453, 22.225274051938737, 13.082767469542366, 29.169604233333043, 32.9964462007795, 15.864569970539637, 8.279767870903015, 1.8731520473957062, 0.6177642281566347, 0.46199511523757664, 1.1000203447682517, 12.29667259965624, 7.613216757774353, 5.222734195845468, 4.438397654465266, 2.3262349580015456, 1.2057159074715205, 0.13282594404050282, 0.947224572300911, 0.08641393163374492, 0.7983537177954401, 1.3677969702652522, 2.8176033113683974, 4.497045661721911, 8.255763581820897, 12.89175193650382, 16.651184218270437, 19.087533576147898, 29.113700764519827, 39.5584465435573, 49.5655791418893, 54.41885069438389, 55.64238677706037, 55.50115769250052, 58.335734367370605, 57.452455043792725, 56.18477010726929, 53.475240162440706, 56.70635053089687, 43.0087308883667, 36.99031244005476, 41.12410497665405, 42.81631095068795, 52.01259919575283, 52.76894187927246, 58.151263168879915, 55.361165387289866, 52.94815329142979, 53.89595358712332, 57.25450086593628, 57.27778775351388, 55.96083314078194, 54.87264101845877, 53.37595387867519, 44.231832708631245, 38.03622129985264, 27.707684142248972, 18.138725791658672, 7.477653929165431, 3.5903808729989186, 0.5874191650322506, 0.29774466742362293, 0.16840149435613835, 0.8537445941141674, 0.7389857034598077, 0.5944489506738526, 1.0750516674348285, 7.720819166728428, 4.1485413908958435, 3.912788144179753, 2.703907766512462, 3.4553020298480988, 5.131800949573517, 4.494645493371146, 1.9432493831430162, 4.038025949682508, 0.5748209410480091, 0.6423285529017448, 2.394781542675836, 10.229150993483406, 18.303116696221487, 21.77248774256025, 30.25235939025879, 33.38895688738142, 27.38709078516279, 27.900213514055523, 18.044124330793107, 5.010517971856253, 0.354661514716489, 0.0287829431971269, 0.05058193579316139, 0.039732211735099554, 0.03890626159097467, 0.014348184457048774, 0.0274131251831672, 0.04954150412231684, 0.011655999231152236, 0.046546263952872584, 0.04168091341853142, 0.052291684584426026, 0.04053322571728911, 0.009447077671731157, 0.058143116134618006, 0.02146089555961745, 0.03382471622899175, 0.005176051719380277, 0.04358166981754558, 0.016985661948898008, 0.019204405302714025, 0.027364677782835703, 0.01838680962100625, 0.02782504174060055, 0.04700943874195218, 0.07524267357907125, 0.07044931900288377, 0.09080643486231565, 0.018051949196628163, 0.10336096797670637, 0.01405406666786543, 0.022886175329663923, 0.03665538451501301, 0.023741533181497028, 0.04387351790709155, 0.028662900174302713, 0.005686474598145911, 0.019214018447590724, 0.025120843900367618, 0.01089119611840163, 0.0320765691410218, 0.05694700138909476, 0.023285993607714772, 0.019452654124636735, 0.1052443708426186, 0.025164475398404256, 0.03589888921539698, 0.044079181871243885, 0.024401484822322215, 0.03493483344625149, 0.058889497869781086, 0.05970071362597602, 0.00987715776344495, 0.014281226621408547, 0.046432317567190955, 0.047197701675551276, 0.022315032048416988, 0.04108820629439183, 0.055189398915639946, 0.047700692899525166, 0.05719594910208668, 0.015373381320387125, 0.04651853561933551, 0.028657546533005576, 0.026828273798206022, 0.046683334811989746, 0.028665495570749044, 0.05390299490786024, 0.014306176354044249, 0.016599726497328708, 0.041552649943956306, 0.06070583433445011, 0.009879017797564822, 0.0338296084664762, 0.020351845338674526, 0.05754942513470139, 0.027589703743745173, 0.05435813244964395, 0.01343773040987019, 0.0501637919805944, 0.07582032401114702, 0.01645999408460089, 0.06357217659907681, 0.07587352115660906, 2.259473191840308, 13.750908851623535, 32.174818243299214, 34.4091991015843, 24.180542298725673, 15.960696560995919, 17.28733175141471, 37.44745874404907, 28.75337413379124, 19.05323553085327, 10.261836188180105, 2.1975213161536624, 0.3335906410855906, 0.17384505511394568, 0.5070146109376634, 4.62575626373291, 9.06594090802329, 3.984402358531952, 3.3372295541422705, 5.016961557524545, 4.35579833814076, 1.595339834690094, 1.5011700306619917, 0.8457220845988819, 1.4746210724115372, 2.3038899855954305, 2.7881824672222137, 6.310945859977177, 11.15475961140224, 16.256040164402553, 20.009389298302786, 23.835793529238018, 33.84404305049351, 43.07578795296805, 52.47028398513794, 55.975069999694824, 55.55929674421038, 57.38885818208967, 60.254243169512065, 59.08463205610003, 58.82139260428292, 55.286381925855366, 56.398625237601145, 47.21247441428048, 36.87026146480015, 41.199114254542756, 45.63050161089216, 55.546525955200195, 55.05092484610421, 56.6609787940979, 54.31052827835083, 52.91789388656616, 54.70916380201067, 56.80337170192173, 59.33015360151018, 58.75148677825928, 55.78036757877895, 56.3610007422311, 50.106169836861746, 42.98342554909842, 33.881306239536826, 24.46990524019514, 12.216096077646528, 6.405417042119162, 2.5679658268179213, 0.9701396226882935, 1.6776387499911445, 1.5356565458433968, 2.5717851647308896, 1.7808171106236321, 3.88913300207683, 14.239824056625366, 10.008764556476049, 8.502775515828814, 7.509412407875061, 8.265279139791216, 3.782089923109327, 2.537167936563492, 1.5054543550525392, 0.85637209883758, 0.15956987254321575, 0.5126186045152801, 2.001948199101857, 12.313237973621913, 24.35085654258728, 27.088373831340245, 25.214293548039027, 35.652217933109824, 31.853276457105363, 33.0122081892831, 24.127730778285436, 9.04634438242231, 0.5861617039356912, 0.03659297286399773, 0.051999283488839865, 0.057196268013545444, 0.03292224769081388, 0.04533462771879775, 0.05893850166882787, 0.06617358486567225, 0.04365264458049621, 0.01996556722692081, 0.07474045588501863, 0.030305189014013325, 0.04518242892143982, 0.037912448668586354, 0.027188599641833986, 0.00844738185073116, 0.052311117827360115, 0.025155958087582673, 0.027173288499138186, 0.06116815416940621, 0.058553351621542654, 0.008855178004263766, 0.034973021397101026, 0.024572384044794098, 0.04565306420304945, 0.023341038064765077, 0.0612393460635628, 0.013645215392378824, 0.01360321492289326, 0.07202322847609009, 0.032301279583147595, 0.04066121099250657, 0.06326748723430292, 0.052960272279701064, 0.02633116886551891, 0.009527156678294497, 0.04498461221477815, 0.02474643675876515, 0.09770275266574961, 0.10952056638364281, 0.12740571131663664, 0.13254446057336672, 0.0978966508326786, 0.15898114841963562, 0.1797511460525649, 0.05910113972744771, 0.17004814956869396, 0.09273171012422868, 0.07341788256806986, 0.18261566305799143, 0.12071997007089001, 0.21875966287084989, 0.15360659467322485, 0.15647177664296968, 0.12294274222637926, 0.1557297714586769, 0.09041084216109344, 0.1446293592453003, 0.12108901169683252, 0.11908257007598877, 0.17972127694104398, 0.154521626287273, 0.1309817401426179, 0.16866078972816467, 0.1853302102535963, 0.1731743232480117, 0.10346956072109086, 0.18900047402296746, 0.09982973603265625, 0.09472588383193527, 0.18576243706047535, 0.10622993617185525, 0.27885444249425617, 0.1618698619838272, 0.10085989468331848, 0.147247405190553, 0.12427436720047678, 0.15025632801864827, 0.12352892862898962, 0.21665802278688975, 0.12300690449774265, 0.2220534346997738, 0.1387695986777544, 0.12533889364983353, 1.8958231508731842, 13.434801425252642, 35.21342876979283, 42.1745023727417, 34.09096813201904, 30.0419887815203, 20.59482192993164, 38.06429897035871, 40.24289969035557, 22.355022975376674, 10.470833659172058, 2.8054978123732974, 1.1318462427173341, 1.5656917627368654, 4.072092967373984, 20.864200115203857, 14.007516247885567, 9.492607201848712, 14.67079302242824, 7.205881220953805, 4.7696608390126904, 2.2510993097509657, 3.468793260199683, 0.8725685668843133, 1.00857803438391, 1.9044430426188876, 3.4515011480876376, 5.864173650741577, 9.501946449279785, 14.440890158925738, 19.177599600383214, 22.776193244116648, 33.33881173815046, 43.07561772210257, 50.784595421382356, 55.824307986668174, 56.42082473209926, 57.437380926949636, 60.30468014308384, 59.52432101113455, 58.803834506443565, 57.122568471091135, 57.76372044427054, 51.10247550691877, 39.449474470955984, 40.89331708635603, 48.58219017301287, 57.283592973436626, 54.75347593852452, 57.27592216219221, 55.31786073957171, 53.830682209559846, 54.2424533026559, 57.86707837241036, 59.47096579415457, 60.31174646105085, 57.68713739940098, 56.31414903913225, 48.56692150660923, 41.30926404680525, 28.928623335702078, 21.621543339320592, 9.576673456600734, 4.9285426906176975, 1.5066505308662141, 0.6980352465595517, 1.1086170034749168, 2.3991639018058777, 1.8309988464627946, 1.834564140864781, 2.5187914712088446, 15.561737946101598, 11.006941897528511, 9.27144604069846, 8.05327136175973, 8.142274311610631, 13.163013952119009, 10.987877777644567, 7.6604905639375955, 6.885947942733765, 1.2738980374165942, 1.0388124691588538, 3.000545906169074, 13.140507868358068, 24.01593426295689, 28.625440427235194, 37.563396385737825, 39.19452769415719, 34.155641964503694, 38.01799617494856, 27.497318744659424, 8.727173668997628, 0.499416212950434, 0.15571814136845724, 0.12915538171572344, 0.19700591159718378, 0.14419508326266492, 0.1677156990127904, 0.10309152850615126, 0.11629544677478926, 0.15051699403141225, 0.1789151501974889, 0.12559410424104758, 0.10245238923068557, 0.17285881803504058, 0.13129514189703123, 0.1674270909279585, 0.2025602771235364, 0.17436754064900534, 0.14275124216718332, 0.11225221266171762, 0.1177008149347135, 0.17137765751353332, 0.05951882552887712, 0.110493707736688, 0.08358676119574479, 0.11989445079650198, 0.19539882854691573, 0.2181954202907426, 0.19503408883299145, 0.08052274810948543, 0.14293493516743183, 0.04831604952258723, 0.15399713228855813, 0.15386799350380898, 0.11188521342618124, 0.13646727507667883, 0.1594327406159469, 0.10883330540465457, 0.1000823817614998], [0.03381139658657568, 0.09433992632797786, 0.0355934941742037, 0.005221228156837502, 0.008370863456678177, 0.04294030155454363, 0.00874332829178976, 0.029670952154057365, 0.12154174383197512, 0.09449811998222556, 0.021826286667159626, 0.04418471781536937, 0.009778132362823402, 0.034668050440294404, 0.04781069699674845, 0.04824745641755206, 0.03960679471492767, 0.030065784896058694, 0.05365545515503202, 0.012435260228812695, 0.024034906278497407, 0.05369451841605561, 0.037977873015084436, 0.0020985044040051954, 0.09339928680232593, 0.03944567318207451, 0.026133460724460225, 0.05577471340075135, 0.024182809949187294, 0.021825759106182625, 0.01981017422596259, 0.016145091071458798, 0.05055435334465333, 0.02075144648551941, 0.06285075138189963, 0.017227507096582224, 0.02739782421849668, 0.007921966740728488, 0.05408840120903083, 0.0424580667167902, 0.046570752281695604, 0.011483984666743448, 0.054713949428073, 0.025413100807262317, 0.01891754274921758, 0.025455887529200742, 0.04715258588216134, 1.0155434949057442, 4.940975623471396, 22.633836814335414, 32.53443963187081, 25.877648489815847, 20.16238168307713, 9.482995237622942, 20.06180998257228, 25.99781584739685, 24.989166702542985, 17.99115821293422, 4.521971889904567, 1.5669481924601962, 0.379232679094587, 3.708171946661813, 2.5486120539052144, 1.758199312857219, 1.211598208972386, 6.591501525470188, 6.0598861660276135, 0.9216924394880022, 1.4000458398035593, 0.44687868495072636, 0.7805493931685175, 0.5333852501852172, 0.1269276426838977, 0.19720644583659513, 0.32573901382940157, 0.7175244007791791, 1.527779025690896, 2.7337971798011234, 7.159011713096073, 14.152576395443507, 28.121751614979335, 42.67748941693987, 54.10913126809256, 55.97289521353585, 58.49973964691162, 56.23107290267944, 55.56869765690395, 55.326862130846294, 53.4294376373291, 39.74178171157837, 29.85884816305978, 34.20501238959176, 33.494110924857004, 49.222008092062815, 56.090087005070274, 54.54208047049386, 56.9591190474374, 53.98739882877895, 48.37745802743094, 48.81876938683646, 42.7542461667742, 35.47059202194214, 35.55295944213867, 22.932395696640015, 12.935527324676514, 6.559970600264413, 2.6096778171403066, 0.40825147767152103, 0.05742684778358255, 0.22225285614175455, 0.29113782622984474, 0.12143767013081483, 2.6309729601655687, 1.6006136259862354, 3.123186605317252, 2.6996090028967177, 5.039395987987518, 15.630412203924996, 9.249200514384679, 9.320310115814209, 8.370996849877493, 9.559695533343724, 3.0193783470562527, 2.402442148753575, 1.4626000374555588, 0.04457860739369478, 1.2778666530336653, 4.728033312729426, 14.404388666152954, 18.491878407342092, 21.86311309678214, 31.22556230000087, 24.1764463356563, 15.01032543182373, 17.00962962423052, 20.02923682757786, 8.247562970433917, 0.4810849651694298, 0.01885516332861568, 0.017444427956693938, 0.020539903015430485, 0.04265251110440918, 0.06807086377271584, 0.02629426334585462, 0.007805220549926162, 0.058916225364165645, 0.05906539450266531, 0.035591699449079375, 0.054635069732155116, 0.015398001963538783, 0.06220254687858479, 0.03061076725966164, 0.028978547879627774, 0.043181123810687234, 0.05190261939008321, 0.060628718829580715, 0.060504370502063205, 0.04046956556183951, 0.05008328040795667, 0.010581448275063719, 0.01488355706845011, 0.05581356292324407, 0.05195253581873008, 0.07065982092171907, 0.026214403166834797, 0.015832432312890887, 0.05932366528681346, 0.057201750576496124, 0.024691487296617458, 0.037430783800248585, 0.021280554522361075, 0.026642097359789268, 0.02242977062373289, 0.059355461437787325, 0.017406019481963346, 0.062323346467954774, 0.01673149799795023, 0.06931620623384203, 0.026927779262353266, 0.06971820430564028, 0.013133267506158777, 0.06610837086502995, 0.06177288493407624, 0.030507151569638933, 0.057423923297652175, 0.07886871043592691, 0.02999827066170318, 0.06218794480498348, 0.035999488817261796, 0.016849300158875327, 0.031317183282226324, 0.028599111097199575, 0.08044825174978801, 0.03193566455904927, 0.058792358796511374, 0.07671647199562617, 0.05526544912053006, 0.02000375517777034, 0.05324350975986038, 0.026737857310633575, 0.061667481304279397, 0.05335312030677285, 0.02808536509318011, 0.029474014150244848, 0.05834372501288142, 0.013060295305747007, 0.0240616422545697, 0.07112005086881773, 0.034536387505275865, 0.0579669073756252, 0.01255202423115926, 0.1113777845831854, 0.03914336547521608, 0.044086069001683166, 0.04801387752273253, 0.02464760304428637, 0.025394205303330506, 0.029931085516831706, 0.040250212153685946, 0.07250986022076436, 0.06276442815682717, 0.018514443754351566, 0.1080599654732006, 1.7786743513175418, 9.921046154839651, 27.945748533521378, 38.17107193810599, 30.207314218793595, 16.28110579081944, 15.716877324240548, 32.25449671064104, 32.731289046151296, 30.242986270359584, 15.041524580546788, 3.988885683672769, 0.6370942794850895, 0.1761247699281999, 1.265637172119958, 1.9764752345425742, 1.3670589412961687, 1.7204049123185021, 4.480575391224452, 4.712255256516593, 3.1383176105363026, 2.516145727464131, 1.5355111765010017, 1.652458586863109, 1.8156209630625588, 0.6130730541689056, 0.5664744174906186, 0.4069190520261015, 1.5635027544839042, 2.8951124208314076, 4.851897980485644, 10.685521704810006, 18.451518058776855, 32.66309942517962, 47.758387429373606, 55.85752385003226, 55.909218447549, 58.679649353027344, 58.053731305258616, 58.13358000346592, 56.07774700437273, 54.37453508377075, 42.92870848519461, 32.51761456898281, 38.46696097510201, 37.513748032706125, 52.83414377485003, 56.417138712746755, 55.43030343736921, 55.52719954081944, 52.56213917051043, 50.01233788899013, 51.94485773359026, 49.64563281195504, 44.456183092934744, 40.947235107421875, 30.508254596165248, 17.927099296024867, 11.019673602921621, 4.803646649633135, 1.2837950949157988, 0.5607146865555218, 0.7819114572235516, 0.8905251004866191, 1.672351170863424, 4.4917676363672525, 4.018269615513938, 3.735304662159511, 2.9780085555144717, 6.822075324399131, 16.62777747426714, 12.766072920390538, 8.079779607909066, 7.895198975290571, 5.708012453147343, 2.8545868354184285, 1.8165248802730014, 1.4825360476970673, 0.4102430593754564, 0.6641989307744163, 4.862788413252149, 15.118118047714233, 25.68764999934605, 22.164352246693202, 28.24077946799142, 31.980268682752335, 22.849496739251272, 21.57192972728184, 25.08824454035078, 11.993155309132167, 1.2987918044839586, 0.030878693597125154, 0.07286443548010928, 0.038769146627081294, 0.09339962606983525, 0.044233144859650304, 0.035734588745981455, 0.036661267413624694, 0.0422456581145525, 0.020281225110271146, 0.02976055609594498, 0.07936249393969774, 0.011205492690870804, 0.033206743853432794, 0.050439986267260144, 0.020264813044507588, 0.02683349003616188, 0.0592502477977957, 0.02711398453850831, 0.0068978640151077086, 0.0538062765263021, 0.0085128774434062, 0.019231036105858426, 0.005457636542684797, 0.05682916360508118, 0.0506113502862198, 0.04222315450065902, 0.12078242243400641, 0.01120611185407532, 0.023276931772540723, 0.056749775007899315, 0.04127553624234029, 0.025385755846010785, 0.01795485083545957, 0.011320359339671475, 0.08209076111337968, 0.011375665032703961, 0.04271505846242819, 0.09018104949167796, 0.0637136579358152, 0.27175552770495415, 0.08539882288979632, 0.20632161386311054, 0.12336042124245848, 0.17030649499169417, 0.10370957212788717, 0.1821580319000142, 0.3036562544958932, 0.2376295860324587, 0.3475344814360142, 0.12388460311506476, 0.12137756549886294, 0.1413565541484526, 0.1668290573039225, 0.14605247788131237, 0.18163618418787206, 0.15348912669079645, 0.12820137505020412, 0.1504366012024028, 0.1879964457558734, 0.12672324079488004, 0.11013585515320301, 0.08629632115896259, 0.13235607211078915, 0.15335104481450149, 0.13191521433847292, 0.2212032846042088, 0.15743163228034973, 0.12798626587859221, 0.12248426968497889, 0.16056053367044243, 0.17603784959231103, 0.11212045473179647, 0.1718886893774782, 0.2064195400370019, 0.14197844506374427, 0.1340832422886576, 0.1694056854716369, 0.11078180692025594, 0.21026026537375792, 0.08507364176745925, 0.12544352374970913, 0.11540997214615345, 0.1165964991918632, 0.10695548688194581, 0.16943201263036045, 2.0125428991658345, 9.46766664300646, 34.090412276131765, 46.51605994360787, 39.15839358738491, 27.640590599605016, 17.910897833960398, 28.623493194580078, 32.1965000970023, 32.033259119306294, 22.818050929478236, 5.940127015113831, 2.1565495261124203, 0.9183832513434547, 5.419993119580405, 4.561586609908512, 3.8265718562262396, 2.7280679558004652, 12.97144603729248, 15.993985380445208, 5.263669942106519, 3.2679421177932193, 2.9387286518301283, 2.862578783716474, 1.788639913712229, 0.5771741547754833, 0.7653621509671211, 0.5731753579207829, 0.8533196140612874, 1.8303246540682656, 3.9280324918883185, 9.070506743022374, 17.14198759623936, 32.74830865859985, 48.436538560049875, 55.54291636603219, 56.68169832229614, 60.69015230451311, 57.3513309614999, 58.09507656097412, 56.25068071910313, 56.64692258834839, 47.77427101135254, 34.2947553225926, 41.23093005589077, 40.657529967171804, 56.39868777138846, 58.533744130815776, 56.546031270708355, 56.71549436024257, 55.1593063218253, 50.82267154966082, 53.23170232772827, 46.05409853799002, 40.04130813053676, 37.57415567125593, 26.519700254712784, 15.050001382827759, 8.268336347171239, 3.5290408730506897, 0.6352787369063922, 0.3196181665573801, 0.6792993747762271, 1.0885337782757623, 0.9782582670450211, 6.227479321616037, 6.319696247577667, 6.5635693328721185, 5.297755198819297, 8.689842735018049, 22.160865988050187, 15.822972842625209, 16.549478224345616, 14.649701765605382, 17.82664050374712, 7.721915245056152, 5.535157774175916, 4.0212655918938776, 0.8996927056993756, 1.564210710780961, 6.7808738095419745, 17.502672059195383, 23.808758088520594, 27.39355434690203, 37.24416140147618, 33.388790130615234, 23.318489721843175, 27.044640132359095, 29.74255963734218, 12.455710785729543, 1.2028110176324844, 0.13558688946068287, 0.11562478276235716, 0.1194435642766101, 0.19825461959200247, 0.08212575994964157, 0.1324983744749001, 0.12340126905058112, 0.12175997426467282, 0.14270890158201965, 0.09147317694233996, 0.1072174013991441, 0.09400684705802373, 0.1413634480642421, 0.11312277987599373, 0.11823760398796626, 0.17465560590582235, 0.14158030785620213, 0.14960596577397414, 0.11377089616975614, 0.11076349326010261, 0.09067842923104763, 0.1562810404492276, 0.08322317499135222, 0.14736981290791715, 0.14093111269176006, 0.13508246652781963, 0.20535776843982084, 0.10651794714587075, 0.12163627733077322, 0.18002227507531643, 0.1017815555844988, 0.0818085109016725, 0.08762948640755244, 0.16315260529518127, 0.2221452404877969, 0.118922408670187, 0.08168382330664567, 0.1960904321500233], [0.03214446335498776, 0.028647015669516156, 0.02571618713305465, 0.029700668595199074, 0.05389309508193817, 0.001813716471328267, 0.013339012046344578, 0.02991992361577494, 0.054284246771463325, 0.03607173244069729, 0.020986270492098162, 0.02608561891663287, 0.1625311757837023, 0.05369279493710824, 0.03443860721641353, 0.030454734739448344, 0.08082951379141637, 0.05804462677666119, 0.07096260360309056, 0.003705941988820476, 0.034800782067967315, 0.0160949626006186, 0.011171646515971847, 0.007244921954614776, 0.025651366682723165, 0.03911381188247885, 0.032411894361887655, 0.04734338992940528, 0.11596194681312356, 0.016328639883015836, 0.009539260046689637, 0.011398568982258439, 0.03875473115061011, 0.06779016740620136, 0.06520864021565233, 0.033767308773739, 0.039475603361747096, 0.03742054470681718, 0.042437700488205464, 0.038365771129195175, 0.01381758279499731, 0.03596668164911015, 0.10225338169506618, 0.051740480054702075, 0.0009190846945525014, 0.04180961115551846, 0.05394927778148225, 0.06780379238937582, 0.07500078941562346, 4.395749611513955, 15.204305240086146, 28.96943531717573, 33.84758315767561, 17.49536255427769, 15.22154893193926, 18.94002332006182, 20.389004128319876, 28.185383217675344, 22.11225986480713, 8.995988181659154, 2.685839410339083, 0.45475319240774426, 0.2869337046785014, 1.228777629988534, 2.244649644408907, 1.662471809557506, 2.0761892667838504, 2.3605149814060757, 1.4232970092977797, 0.287988365228687, 1.6383757825408662, 1.8936236117567335, 0.1957890676068408, 0.17480444934751305, 0.29272820374795366, 0.06553020474634, 0.41308774958763805, 0.09994868322142533, 0.3836502677627972, 1.5586780990873064, 6.198943070002964, 18.97294909613473, 28.841109037399292, 45.44999088559832, 53.97884907041277, 55.10462399891445, 52.07073824746268, 47.79997934613909, 44.55591058731079, 37.331875460488455, 27.559508596147808, 23.41983093534197, 28.111329317092896, 49.15949862343924, 62.54036726270403, 55.84981482369559, 47.87719815117972, 40.58787080219814, 31.578166007995605, 22.93696587426322, 13.223598769732885, 7.676044975008283, 4.852069514138358, 2.480942245040621, 0.45765726800475803, 0.06398621188210589, 0.01659032030563269, 0.14664080845458166, 0.3190924104835306, 1.2167565950325556, 1.2438191771507263, 2.423356660774776, 3.743933456284659, 2.8173989909035817, 3.956725077969687, 1.7528786212205887, 7.932338833808899, 21.293881927217754, 19.30352180344718, 8.443683692387172, 7.833986214229038, 5.925570539065769, 1.241951305951391, 0.19760771787592343, 0.39703456099544254, 3.476756981440953, 9.167553969791957, 19.938418660845073, 22.07800350870405, 21.721420219966344, 36.227323804582866, 21.681120668138774, 15.889421939849854, 23.60805242402213, 21.35448932647705, 8.87144867011479, 0.6048461699060032, 0.016268094203301837, 0.05056803600330438, 0.030437588159527098, 0.03423984056072576, 0.019358895852097442, 0.09131929198546068, 0.027719227597117424, 0.032121572976133654, 0.07342668316726174, 0.007256569856378649, 0.030264609227223054, 0.011823678804960634, 0.027856398540149842, 0.030705076841903583, 0.04985995078459382, 0.026069273008033633, 0.02878186771912234, 0.019878407707437873, 0.039753741651241264, 0.05701391851263387, 0.04336900676467589, 0.03462009158517633, 0.024376068596861193, 0.06611139713121311, 0.13953096925147943, 0.03548741200938821, 0.061968608360205374, 0.05869205096470458, 0.0695144266688398, 0.0972647854526128, 0.0417603461204895, 0.015559639183006116, 0.06497642517622028, 0.04839503778410809, 0.034035319928079844, 0.007709028881176242, 0.06794502945350749, 0.0274126485123166, 0.04983590689620801, 0.07833763464753117, 0.016411963983305862, 0.034401525277644396, 0.07027163103755031, 0.022336723116625632, 0.08221837319433689, 0.05620524387008377, 0.010528207872994244, 0.011044458519401295, 0.01340201317465731, 0.017926204783309783, 0.04223544616252184, 0.06949590944818088, 0.02397384660850678, 0.017980942203264152, 0.06657053463693176, 0.04506512378741588, 0.05954984136457954, 0.030293206085583994, 0.039819054039461274, 0.032367765836949856, 0.04236210150910275, 0.020664731406473687, 0.038020356092602015, 0.008628143579699099, 0.04600699824680175, 0.06589024899793522, 0.08316703300390925, 0.07171257478850228, 0.025895803834178617, 0.007042760927496212, 0.034824951485331566, 0.016179382534963743, 0.01124890027235129, 0.0321994654035994, 0.025605646993166635, 0.025300827010401657, 0.037125083418296914, 0.03752317991373794, 0.0436194133279579, 0.006374014624660569, 0.04289988122348275, 0.02729809144511819, 0.017273077508434653, 0.018811796459236314, 0.03462184899087463, 0.09929317768130984, 0.1256586600627218, 0.6434299509440149, 8.996365989957537, 23.750476598739624, 34.763032640729634, 34.22166722161429, 15.41556521824428, 17.598803860800608, 19.840829474585398, 28.196868589946202, 40.86798048019409, 22.716499532972062, 11.063103318214417, 2.818132242986134, 0.3471263290515968, 0.27524811029434204, 0.41077342948743273, 0.7330556330936295, 0.8731094407183784, 2.1564357493604933, 3.3811430377619605, 2.686493192400251, 2.60538187623024, 2.538408407143184, 1.8023363330534525, 1.1723370871373584, 1.4195193605763572, 1.035397538117, 0.6428775691560337, 1.224383111510958, 0.6142842120357922, 1.2263565084763934, 3.3400943832738057, 9.42616331577301, 23.39645893233163, 35.187855924878804, 49.91133540017264, 56.42320796421596, 57.21109894343785, 54.571697166987825, 53.24425424848284, 48.773713793073384, 42.988240650721956, 29.102557591029576, 26.77424577304295, 32.964397634778706, 52.539842401232036, 61.78850269317627, 58.75056266784668, 50.70825208936419, 45.58317395618984, 37.06200047901699, 27.88953239577157, 18.21170793260847, 11.87601910318647, 8.284014957291738, 4.228198145117078, 1.2810491451195307, 0.29392288678458756, 0.21731765381991863, 0.9001119317752975, 1.8347493537834711, 2.6954874183450426, 3.260930734021323, 3.8740145904677252, 5.964205128805978, 6.571118116378784, 6.040955798966544, 5.617054453917912, 8.00819752897535, 13.274115647588458, 7.35098305770329, 4.715607762336731, 1.6269910505839755, 0.909700771527631, 0.35731692079986843, 0.11241683204259191, 0.13664480697895798, 2.1751765608787537, 10.339518785476685, 25.07344835145133, 29.001087835856847, 20.54367276600429, 32.80933468682425, 27.775059086935862, 18.746625423431396, 24.096547263009207, 25.346724476133073, 13.230504410607473, 1.5644614973238535, 0.033500654689435444, 0.047568578738719225, 0.06975589014057602, 0.05975707952997514, 0.02111041865178517, 0.030969471404595033, 0.03697254874610475, 0.031201211469514028, 0.06899232111339058, 0.037854684982448816, 0.034720657260290215, 0.018355569868747677, 0.03369544852258904, 0.02861796080001763, 0.022818932509315864, 0.05478097511721509, 0.07230227600250926, 0.0035257667685592814, 0.05700528754719666, 0.08206566888839006, 0.03687087705891047, 0.006211143743712455, 0.04102149951670851, 0.06221796997955867, 0.02769675282096224, 0.02681212975377483, 0.03453240789739149, 0.07095290055232388, 0.05982989990817649, 0.03534259567303317, 0.03775520157068968, 0.027501129478748356, 0.0819355733692646, 0.10437723701553685, 0.06429017521440983, 0.011145214184320398, 0.020337479055992196, 0.010144100225131427, 0.02259686665742525, 0.19294126970427378, 0.14707288598375662, 0.10030122966106449, 0.13805231930954115, 0.17459691262670926, 0.17749770411423274, 0.17813954395907267, 0.08349867377962385, 0.0902349998110107, 0.13392692139106138, 0.18987859333200113, 0.08169069686638457, 0.2845668931092535, 0.10769918840378523, 0.18897563964128494, 0.13629078811832837, 0.14896732861442225, 0.1477741790669305, 0.15973491940115178, 0.09472622988479477, 0.19197127675371511, 0.1678196234362466, 0.08477495065225021, 0.10074576509318181, 0.14180300304932253, 0.09458533208817244, 0.12896943597921304, 0.1196239460259676, 0.19626425925110066, 0.11628089898398944, 0.0982983707051192, 0.10306205294494118, 0.12875265761145524, 0.12327419301228863, 0.09967947445277657, 0.1012011638709477, 0.10344376960503203, 0.09335841185280255, 0.15009949143443788, 0.11073888279497623, 0.12299988844564982, 0.06754536554217339, 0.16884103577051843, 0.1997756508312055, 0.09289816833500351, 0.09465322630213839, 0.16342671987201485, 0.16581190616956779, 0.470736383327416, 7.764741335596357, 26.62167375428336, 42.60180268968855, 45.47115509850638, 25.201653037752422, 23.167781557355607, 25.88895842007228, 27.647345985685075, 36.65974146979195, 26.838367223739624, 12.135304161480494, 3.9822536281176975, 0.8123145486627306, 1.4261685694966997, 3.4424246294157843, 6.332795773233686, 4.558286649840219, 10.182348796299525, 7.071191694055285, 4.656216297830854, 2.7569173106125424, 4.318074396678379, 4.8776306339672635, 1.6341164282390048, 1.110043989760535, 1.020321358527456, 0.5641056788819176, 1.062604403921536, 0.5465647344078336, 0.8559347965887615, 2.537575057574681, 7.950538771493094, 23.248686381748744, 35.37691988263811, 49.00371306283133, 56.47668824877058, 56.40883214133126, 53.85665110179356, 53.14600324630737, 52.343451568058555, 48.89772524152483, 32.740196636744905, 29.638541630336217, 39.16934394836426, 56.79373107637678, 63.706073488507954, 62.81152766091483, 51.679620674678254, 43.10917404719761, 33.598993982587544, 25.245346784591675, 15.460487059184484, 8.547411612101964, 6.086934634617396, 3.0626248036112105, 0.8862956017255783, 0.35045207345059937, 0.15226617588528565, 0.4691111562507493, 1.2258583009243011, 2.3110377277646745, 3.795763543673924, 5.789448380470276, 9.866480214255196, 6.676125373159136, 8.544602802821569, 7.578396729060581, 14.187657850129263, 29.005432197025844, 29.39366626739502, 17.452248982020787, 13.650560361998421, 11.301020060266767, 3.5344517827033997, 0.8408433635319982, 0.547287184212889, 4.102868710245405, 12.357943551880972, 26.719883067267283, 28.289218834468297, 27.611234460558208, 43.313412870679585, 30.266380855015345, 23.671235867909022, 34.359825202396934, 31.313769681113108, 12.701122897011892, 1.1834066531487872, 0.14380078656332834, 0.1732670111315591, 0.2309792371732848, 0.2072116889591728, 0.054803102144173214, 0.13269414539848054, 0.16363075535212243, 0.13249808949019226, 0.253107946898256, 0.11670661185468946, 0.13723631309611456, 0.09290160850754806, 0.10379382582115275, 0.10302210080304317, 0.15722368843853474, 0.18489007172839983, 0.09679934435657092, 0.08108857167618615, 0.14926413340227945, 0.17305355758539268, 0.17061889251427992, 0.19483055546879768, 0.14751892776361533, 0.16861998263214314, 0.3321427287799971, 0.08729682782930986, 0.1726061315940959, 0.17634749226272106, 0.120993188981499, 0.22589006168501718, 0.10322914219328336, 0.14324623346328735, 0.1218952334352902, 0.1588349241231169, 0.17673033529094287, 0.10477162192442588, 0.15565221490604536, 0.09399007367236273, 0.15016478007393225], [0.10061364075435059, 0.027612085221335292, 0.02898774542180555, 0.038534872233867645, 0.036002572758921554, 0.04280705763293164, 0.026254324774656976, 0.09863542619028262, 0.04393581759982875, 0.011085391992570033, 0.05655877757817507, 0.0372257474809885, 0.02396428774643157, 0.04827646718227437, 0.06002832390367985, 0.036002012967531166, 0.013921534359854246, 0.031196142812924724, 0.05935664887406996, 0.01733708710941885, 0.05781512587730374, 0.010059544583782554, 0.03122595085629395, 0.004748739202373794, 0.018840875077460493, 0.02939330580245171, 0.017618036230227778, 0.010959847747082157, 0.03114195161366037, 0.034351534210145473, 0.07005286456218787, 0.01642347702623478, 0.035402079445442984, 0.03578243903549654, 0.01961280365607568, 0.02378141407721809, 0.02844157222924488, 0.029756026874695505, 0.035924751577632766, 0.03386742661574057, 0.10858141284968172, 0.026403129200584123, 0.027237194623532038, 0.051612447282033305, 0.07173010134803397, 0.032978457531758716, 0.05983815089400325, 0.052889450187129636, 0.06160667778125831, 0.3722216753023011, 2.645227623837335, 12.835537535803658, 30.666715213230678, 37.951606137411936, 29.63668646131243, 23.722228697368077, 14.155679634639196, 10.464307563645498, 22.463077885763987, 25.223072596958705, 16.379136187689646, 6.981291992323739, 2.5419795640877316, 0.5458414160779544, 0.7119314808930669, 1.5405738076993396, 1.500352205974715, 3.109284996986389, 3.2637126190321784, 2.285972752741405, 1.3676755939211165, 0.6922552138566971, 1.6222443452903201, 1.2652321138552256, 0.16276805235871247, 1.3896596942629134, 1.0455403881413596, 0.23461051232048444, 0.5812713663492883, 0.18094002082943916, 0.33325121072786196, 3.2423223725387027, 12.727748394012451, 19.546599320002965, 24.13215504373823, 27.523332800183976, 24.387774058750697, 16.770719289779663, 17.55924776622227, 26.227389539991105, 25.437523535319738, 21.154148442404612, 27.31595860208784, 34.28504868916103, 33.24676547731672, 22.555277006966726, 11.304623569761004, 6.753004584993635, 4.550231950623648, 2.7220516843455176, 1.4631044332470213, 0.5222610756754875, 0.049203301912971904, 0.02244958554261497, 0.01900584390386939, 0.059764095582067966, 0.4406777434051037, 2.0014066738741736, 2.6905670080866133, 3.1137576826981137, 3.277617267199925, 4.466913930007389, 4.603590641702924, 6.798091445650373, 3.41299792272704, 3.995329703603472, 7.761740582329886, 10.82040968963078, 3.9576891405241827, 1.1440005962337767, 1.4204516134091785, 0.29303123748728205, 0.17567281132297857, 1.9463196183953966, 7.058350120271955, 15.925083569117955, 22.03097288949149, 16.36788010597229, 12.007242781775338, 21.068115847451345, 24.53324328150068, 18.792704139436992, 25.517780440194265, 18.003284556525095, 4.301552448953901, 0.22860650877867425, 0.0518259652890265, 0.05907179308789117, 0.05766851481582437, 0.06827952007630042, 0.03247947644974504, 0.038399446822170696, 0.022160940138357024, 0.02375416750354426, 0.05406931062628116, 0.02329115556286914, 0.02944752753579191, 0.024171514037464346, 0.04383391521072813, 0.025809823269290582, 0.05003104678222111, 0.0428982459540878, 0.05171484839437263, 0.008191869311433817, 0.035080589553607364, 0.08389850732471262, 0.05447844010112541, 0.028974544523017745, 0.08246064412274531, 0.0280451585006501, 0.015282988581540329, 0.030101774393447807, 0.03883833345025778, 0.01062430369867278, 0.03837498902742352, 0.05897369049489498, 0.03413960397509592, 0.03444935521110892, 0.0678061129791396, 0.09782451577484608, 0.07067517616919108, 0.04325348957042609, 0.025716594254065837, 0.032271946514291425, 0.022417619757886444, 0.01563006093991654, 0.013988333587933863, 0.07452570633696658, 0.04326114683811154, 0.016491710507710065, 0.02417599406492497, 0.04100669048992651, 0.012439062569423445, 0.07512721406029803, 0.043883594152118476, 0.01154900189223034, 0.07194200104900769, 0.045196942785488706, 0.027643435235534395, 0.014933884010783263, 0.013890405717704977, 0.048183029517531395, 0.020468916378117034, 0.014077545675848211, 0.09229195157864264, 0.045954673018838675, 0.029092249992702688, 0.06541216679449592, 0.028249139697956185, 0.03376528673938342, 0.046278744736420255, 0.04770938154043896, 0.050814815796911716, 0.02467475292672004, 0.09125947912356683, 0.0643258322296398, 0.06480786350688764, 0.039737694298050234, 0.045914904081395695, 0.02720918639429978, 0.02684808532441301, 0.0317316222935915, 0.022548914587657367, 0.02329650241881609, 0.03929390525445342, 0.032816877987767966, 0.0726509615778923, 0.05517477309331298, 0.04039770531068955, 0.07519035852913346, 0.011389892215707471, 0.021552256907203367, 0.04340988849954946, 0.02103071114314454, 0.06503068762166159, 0.6993408022182328, 4.896379913602557, 19.980038370404923, 37.94823626109532, 35.81138379233224, 27.101448604038783, 21.190032414027623, 13.074045743261065, 18.415818214416504, 34.246635573250906, 26.752112286431448, 17.471024751663208, 6.715661057404109, 1.6910300999879837, 0.06539381242224149, 0.4499165947948183, 0.5241958775690624, 0.7120310898338045, 2.290826286588396, 2.1359882865633284, 2.653408693415778, 3.2189182341098785, 2.6378501568521773, 2.5710225999355316, 2.5006529816559384, 1.3176410730395998, 2.6370977972235, 3.0864985968385423, 1.1895783905472075, 1.3083290755748749, 0.5433881048645292, 1.9894173400742667, 5.4916616167340955, 16.783778429031372, 24.45156373296465, 30.48533943721226, 34.96348122188023, 31.069227831704275, 23.562069245747157, 24.97054205621992, 33.39919853210449, 29.57177291597639, 24.74575046130589, 33.885120800563264, 41.774817671094624, 42.262609004974365, 30.5761593409947, 17.766297136034282, 10.964114938463483, 7.779997842652457, 4.310723202569144, 1.8015146000044686, 0.7770170484270368, 0.2236657967524869, 0.2577544461403574, 0.14397373156888144, 0.4405423620981829, 1.477380592908178, 4.196305913584573, 6.245377012661525, 5.36903372832707, 5.80114437001092, 5.2009181550570895, 2.524428414446967, 7.734307357243129, 7.718245727675302, 4.280036049229758, 5.109413853713444, 5.469481664044516, 2.5513385704585483, 0.7792510028396333, 0.5260743881974901, 0.1494771662567343, 0.1721385938248464, 1.1954441900764192, 6.696415850094386, 16.781506368092128, 27.126608031136648, 26.25790081705366, 17.67241828782218, 17.30139316831316, 31.401928424835205, 21.947676147733414, 27.955288410186768, 24.893701928002493, 8.753044417926244, 0.6368478355663163, 0.07714664284139872, 0.00842776709967958, 0.021793557530535117, 0.020288536325097084, 0.03120548963280661, 0.0314280932236995, 0.017795352697638527, 0.020413783711514304, 0.04913634407733168, 0.039254156673060994, 0.05944346742970603, 0.040693424442516904, 0.03876550289403115, 0.04966654455555337, 0.0225258036849222, 0.02118380899940218, 0.046732494674090824, 0.04959085736689823, 0.05204527459240385, 0.05900607697133507, 0.02079127649111407, 0.03873271947460515, 0.007209387923856931, 0.00958542078400829, 0.011465766001492739, 0.02283607060754938, 0.0639424870855042, 0.06138141094041722, 0.020105886572439755, 0.02352673783233123, 0.03648660232179931, 0.03724158448832376, 0.0201213011917259, 0.05495755707046815, 0.07419394342494862, 0.03315433720126748, 0.002075211569068155, 0.1037598651434694, 0.02247409931650119, 0.045411088437374146, 0.18996180886668818, 0.12458569263773304, 0.14993189328483172, 0.21338487842253276, 0.16842573162700447, 0.12301957953189101, 0.09971194235341889, 0.18904041259416512, 0.1725604526166405, 0.06577168857412678, 0.20937907908643993, 0.20574594475328922, 0.10388643228049789, 0.13634397169309004, 0.08524195916418519, 0.08006753932152476, 0.08623977883585862, 0.09198021223502499, 0.19889959426862852, 0.12490764393338136, 0.07181291654706001, 0.12100936525634357, 0.06898960697331599, 0.09137684532574245, 0.13298757108194487, 0.1697397418320179, 0.10298797727695533, 0.12843050275530132, 0.13920844798641546, 0.17545874709529535, 0.08801629886563335, 0.09658608758555991, 0.1737799293228558, 0.22270880453288555, 0.08984980226627418, 0.1285878550261259, 0.16199568951768534, 0.10175102829400982, 0.13080393682633126, 0.06236787872122867, 0.1722732830260481, 0.13337052267576965, 0.16613085834043367, 0.2285567314497062, 0.23488711033548626, 0.08728634446327176, 0.19706987030804157, 0.11723174367632185, 0.10865449785654034, 0.8645467087626457, 4.794503254549844, 20.592733996255056, 43.559399945395334, 49.29279286520821, 39.03068569728306, 33.075297832489014, 22.278886352266582, 18.1093453339168, 31.958892549787247, 31.877254690442765, 21.863960777010234, 8.940153326307025, 3.0647865618978227, 0.8812247195414135, 0.8678205588034221, 3.356091524873461, 4.754257985523768, 9.796079329081945, 8.857881443841116, 6.902766925948007, 4.837833958012717, 2.763045621769769, 4.990151933261326, 5.747070448739188, 1.6186617889574595, 4.1094182559422086, 2.395254888704845, 0.8275580278464726, 1.1943318269082477, 0.4805364374603544, 1.3762455454894473, 4.143596010548728, 16.612098864146642, 24.38000770977565, 27.536569118499756, 33.41750356129238, 27.77377019609724, 21.672159229006084, 23.691993611199514, 35.606505734579905, 33.063850675310405, 28.88916277885437, 38.256527832576204, 43.59483923230852, 39.79567541394915, 27.78750852176121, 14.17521275792803, 8.708071334021431, 5.770770754132952, 3.843491154057639, 1.8530118252549852, 0.9898048703159604, 0.19280848040112428, 0.19575660649154866, 0.09190237069768564, 0.22612872959247657, 0.8286537261945861, 6.022974295275552, 9.003183909824916, 8.185988903045654, 9.12441781588963, 10.713604586465017, 11.86419587475913, 13.601238574300494, 9.292677130017962, 10.798007828848702, 15.40407463482448, 19.096343891961233, 11.20594264779772, 4.5195821438516885, 3.482017853430339, 0.8835985064506531, 0.5050155924899238, 2.84316833955901, 9.181358303342547, 20.403998340879166, 26.689335312162125, 22.463977677481516, 18.728695596967423, 28.71058886391776, 35.62025274549212, 28.611340795244487, 36.53478854043143, 27.436728715896606, 7.39627662726811, 0.5668916893856866, 0.16895314332629952, 0.15790577898068087, 0.13642669868256363, 0.12877141231937067, 0.10974420474043914, 0.08117556665092707, 0.08224438144160168, 0.14301318382578238, 0.12339103674249989, 0.18667668157390185, 0.1177011134901217, 0.2110083502318178, 0.12126530866537776, 0.16509598387139185, 0.1284505602504526, 0.1306371936308486, 0.11959915235638618, 0.08917624769466263, 0.0765139903607113, 0.09146775544754096, 0.1323225660515683, 0.11489119141229562, 0.15085551515221596, 0.15450938551553658, 0.08324876254690544, 0.11391308318291392, 0.09725478384643793, 0.1827378265027489, 0.09767580804015909, 0.12277024505393845, 0.09599732953522887, 0.12171067191021782, 0.17244797865194933, 0.14425392581948213, 0.16703750326165132, 0.13149412907660007, 0.09536249895713159, 0.15663253515958786, 0.10693063892956291, 0.12296068269227232], [0.028540974216801778, 0.05156508553773165, 0.02287070982025138, 0.006658313163955296, 0.11622876035315649, 0.02355522951776428, 0.022101290124867643, 0.014545912954158016, 0.026373567126159157, 0.02388149799246873, 0.014790786064362951, 0.05342041740992239, 0.007157317994694624, 0.02956287170361195, 0.04762480554303952, 0.013106998022911804, 0.0177740042896143, 0.011680579162202775, 0.04610731964930892, 0.01785804594068655, 0.06118177915258067, 0.006156782910693437, 0.056389652724776945, 0.02813629593167986, 0.021736770934824432, 0.07817412806408745, 0.08165951818227768, 0.026189000512074147, 0.010614293610810168, 0.02995463746732899, 0.07407265529036522, 0.0018714810056345804, 0.052416667342185974, 0.02647396147118083, 0.03941431807886277, 0.05202877262075033, 0.048788272576140504, 0.038566841411271265, 0.03892907054562654, 0.02033171659734632, 0.01939539425075054, 0.03729294280388525, 0.010908910971400993, 0.03143289725163153, 0.10529051800923687, 0.01304613088723272, 0.11499149245875222, 0.019438316679692695, 0.010738192408877825, 0.022355260693335106, 0.1530208018209253, 2.337305392537798, 10.381257482937404, 25.742898600442068, 36.654169014522004, 33.97354704993111, 24.871059485844203, 20.010005950927734, 9.664667180606298, 25.05424874169486, 31.748716490609304, 27.536532640457153, 15.966724123273577, 6.017613760062626, 2.0417681080954413, 0.6855185553431511, 0.2642500618738787, 1.2434365919658115, 0.9937160547290529, 2.6077407896518707, 2.280354917049408, 1.235944696835109, 0.9285636650664466, 2.6453822212559834, 2.686050679002489, 1.5368906110525131, 3.65018184695925, 2.085155482803072, 1.171933223094259, 0.576969074351447, 0.41543208807706833, 0.2139848797981228, 0.9786166421004704, 1.7832015369619643, 1.9130859502724238, 1.691227363688605, 1.4011329071862357, 1.0963461590664727, 0.5791297469820295, 4.54658979177475, 8.370176093918936, 6.266982436180115, 8.310352972575597, 8.029282706124441, 2.433927910668509, 0.4473898932337761, 0.037371313598539145, 0.067878607660532, 0.05341410703424897, 0.16893254300313337, 0.021098271178613816, 0.0944398609655244, 0.30339925257222994, 0.8466136253305844, 1.1777769838060652, 0.7544812176908765, 2.8637788678918565, 2.7260883705956593, 5.46127540724618, 4.041642487049103, 4.059821580137525, 2.0184202066489627, 1.2213393662657057, 7.598372800009591, 8.920274530138288, 2.48969914657729, 2.9396401686327795, 3.2798176748411993, 1.414770701101848, 0.7652346406664167, 0.2779701485165528, 1.1304952523538043, 4.943503030708857, 13.782663856233869, 22.2899044581822, 20.406880106244767, 16.051290648324148, 13.954513651984078, 13.969132661819458, 17.515644345964702, 22.939187560762676, 22.763472829546245, 13.574330806732178, 2.605529091187886, 0.02606479128423546, 0.033235931037259955, 0.03784717359979238, 0.08471886294760875, 0.058259444178215096, 0.0772463535623891, 0.02453384325573487, 0.03367430876408305, 0.040850556189460416, 0.08398588227906398, 0.06667739033166852, 0.03457704871626837, 0.03326474841950195, 0.018238558201119304, 0.06723710708320141, 0.04542746488004923, 0.041353669549737654, 0.03952086843284113, 0.04821551438154919, 0.02718521375209093, 0.052139760593750646, 0.04968942475638219, 0.02745171686235283, 0.03798510280570813, 0.07139227911829948, 0.028787482596401657, 0.0851649386542184, 0.019327673063214337, 0.00883661413432232, 0.01841027505828866, 0.0315415544568428, 0.01772037797075297, 0.027376087349174277, 0.022682657232508063, 0.01858484006619879, 0.12833972834050655, 0.032485752898667536, 0.10877387930772134, 0.02868413832038641, 0.06612202298960515, 0.050492817003812106, 0.006419621083685862, 0.032420369264270575, 0.05458675803882735, 0.019582444303003804, 0.016502634921510304, 0.022801863960921764, 0.04679074690544179, 0.023778377633009638, 0.012271113277945136, 0.03775420751688736, 0.04294355512995805, 0.02984846370028598, 0.08609126109097685, 0.02677179593592882, 0.11111111353550639, 0.024603907085422958, 0.03074252518958279, 0.025755375923056687, 0.01919291600851076, 0.04328193036573274, 0.03429063229954668, 0.025060376252180765, 0.02222041373274156, 0.03847420441785029, 0.02976548226018037, 0.044853509071149995, 0.06686459135796342, 0.015070323832333088, 0.005910196499566415, 0.08018107858619519, 0.012655374444355922, 0.04351024043613246, 0.022178656687693935, 0.07046020948993308, 0.04569773555600217, 0.041108155223940096, 0.022636021520676355, 0.05201859798814569, 0.06014840424593006, 0.0803800793364644, 0.030940884724259377, 0.017035451152228882, 0.034101354956094704, 0.02657861023076943, 0.04452752388481583, 0.04838723802406873, 0.04026146226429513, 0.04470843828416296, 0.047130665808383904, 0.02866353460454515, 0.06861084194055625, 0.28794274053403307, 4.477165562765939, 17.700244086129324, 34.645236355917795, 40.369144984654014, 35.982681206294465, 24.049542699541362, 15.219018050602504, 16.147280011858257, 33.213650362832205, 34.300470215933665, 29.459083557128906, 15.144854715892247, 6.583957518850054, 1.3295952315841402, 0.18034155294299126, 0.24311214898313793, 0.5269588178821972, 0.50779204922063, 1.670561466898237, 1.3703207948378153, 2.1944803936140875, 3.7810064383915494, 4.2642640726906915, 4.070502698421478, 3.4866245090961456, 5.488241800240107, 3.733567612511771, 2.9437244066170285, 3.242654800415039, 0.8331285832183701, 0.9362310022115707, 2.5714080078261237, 3.955578625202179, 3.968776728425707, 3.7505911333220343, 3.312574088573456, 2.4023131728172302, 1.6580258309841156, 8.537836994443621, 13.576969385147095, 9.93991311958858, 14.29336426939283, 12.48134616443089, 5.405197364943368, 1.3225956814629691, 0.17350124141999654, 0.2622259647718498, 0.26285713804619654, 0.4291926696896553, 0.42850838069404873, 0.4686290164078985, 0.5805561904396329, 1.8120774903467722, 2.337507324559348, 1.8374502488545008, 4.557462419782366, 4.424597229276385, 4.857081770896912, 5.7416751725333075, 5.812942845480783, 6.596229340348925, 3.6473461134093146, 2.9124019273689816, 7.217651903629303, 3.735998179231371, 1.5379691017525536, 1.4810887596436908, 0.05426788389948862, 0.3022107577749661, 0.3789544254541397, 0.9268011025020054, 4.49652715240206, 14.258173380579267, 25.651444673538208, 30.436799321855815, 21.141007661819458, 12.872561880520411, 12.553956576756068, 23.188613993780955, 27.833123445510864, 28.313230071749004, 19.993712425231934, 5.340602568217686, 0.07098427601158619, 0.049841514988137145, 0.03570468570770962, 0.11427581443318299, 0.030169285235128233, 0.03769422162856374, 0.06658499421817915, 0.02356677479110658, 0.03244198060461453, 0.0697604702519519, 0.00805888747397278, 0.01514200257536556, 0.0851450100807207, 0.028879916029317037, 0.027719834885959114, 0.04509492165275982, 0.007517412288247475, 0.02837181374031518, 0.046321156567760875, 0.03494444828746574, 0.0476230108179152, 0.05844671305801187, 0.033385123924485276, 0.01409533347136208, 0.017376956130777086, 0.023536546056025794, 0.07974054651068789, 0.025364851878423775, 0.030596446778093065, 0.0351487483962306, 0.008845846451419805, 0.04072834524725165, 0.045669891871511936, 0.009986641085041421, 0.04856877328295793, 0.09872485710574047, 0.010632262066272753, 0.03551981544920376, 0.01629683355401669, 0.03519113647884556, 0.07368272835654871, 0.006782600847405514, 0.14828556376908505, 0.14899931475520134, 0.14542118247066224, 0.0858951916119882, 0.10904481834066765, 0.0913256634292858, 0.10118933700557266, 0.1500526996595519, 0.06866329269749777, 0.19568857657057898, 0.07001861889979669, 0.2012019314404045, 0.08339588929499898, 0.23920348872031483, 0.14354843938989298, 0.1819941114102091, 0.09627296403050423, 0.14413871057331562, 0.20787383057177067, 0.08966923052711145, 0.12905475497245789, 0.07975347260279314, 0.1856935386146818, 0.13659135199018888, 0.10730916647506611, 0.19219786673784256, 0.0928331103974155, 0.09619702917656728, 0.13883845641144685, 0.11753354248191629, 0.2302881899688925, 0.08796440450740711, 0.15562598274222442, 0.17791565454431943, 0.07913373264351062, 0.2003556489944458, 0.1667883994856051, 0.15708350310368197, 0.15997459154043878, 0.11985977765704904, 0.10571889073721, 0.20139707811176777, 0.17823012838406221, 0.10833232264433588, 0.20697580304528984, 0.09122106047081095, 0.21164662098245962, 0.1269834182624306, 0.07276109459676913, 0.11645218836409704, 0.22402421252003737, 4.1670865671975275, 16.28513922010149, 38.610472542899, 50.81257929120745, 48.718069144657676, 34.9986286844526, 28.019430705479213, 16.132386548178538, 36.28823866162981, 40.32318959917341, 35.23825815745762, 20.068777288709367, 8.793205874306814, 2.7321120245116095, 1.3968254583222526, 1.3325882766927992, 2.0588691447462355, 4.129281418664115, 7.75159273828779, 7.0700773767062595, 7.615549615451267, 5.494381836482456, 5.807406433991023, 6.513331251485007, 4.24301734992436, 9.517410533768789, 7.396879383495875, 4.588322843824114, 3.6517035024506703, 1.2875984736851283, 0.6946263951914651, 1.344900701727186, 3.069456619875772, 3.0657451961721693, 2.7818973873342787, 2.461927196809224, 2.2050082172666277, 1.5856714163507735, 6.757897853851318, 11.74891483783722, 9.206550734383718, 13.464197516441345, 11.378311821392604, 3.5275839226586476, 0.7523678253803934, 0.23352124648434774, 0.3879341850323336, 0.27201852787818226, 0.5131170291985784, 0.16593789655183042, 0.4333016877727849, 0.7399523173059736, 2.1434002774102345, 2.8508732404027666, 2.261029371193477, 6.823128845010485, 5.946450744356428, 11.654603464262825, 10.664763961519514, 11.44648928301675, 9.198594178472247, 10.043924178395953, 21.41037368774414, 15.822390930993215, 9.452650717326573, 8.394116112164088, 6.8201576215880255, 3.572157485144479, 1.6969226066555296, 0.7889105187995094, 1.7195784023829868, 6.383245340415409, 18.008723258972168, 29.031600849969045, 27.68426350184849, 22.36102100781032, 20.564949887139456, 21.51078384263175, 28.816620111465454, 34.79712050301688, 34.57388530458723, 21.20470527240208, 4.5733499101230075, 0.13930243865719863, 0.12829879910818168, 0.11102255793022257, 0.269644170999527, 0.15822040209812777, 0.20664579075362, 0.17815060407987662, 0.12721787925277436, 0.15775095086012567, 0.13731419534555503, 0.19515750078218325, 0.1091219134894865, 0.3050462199108941, 0.13091920635529927, 0.12896400769906385, 0.10573843254574708, 0.19079545699059963, 0.08671929274818727, 0.1636007098214967, 0.1028721717053226, 0.12803520182413713, 0.1047812435509903, 0.13095264456101827, 0.13236382098070212, 0.18276601284742355, 0.11951177061668464, 0.21262756548821926, 0.1159887896584613, 0.09140000372592892, 0.08364148504499878, 0.13184962714357035, 0.1365613607423646, 0.2278984167746135, 0.09445217637611286, 0.09969297051429749, 0.28399643514837536, 0.08413214728768383, 0.25508080103567665, 0.11740775566015925, 0.18585873475032194, 0.21678056621125766, 0.11146467099232332], [0.010231312331078308, 0.0673640270584396, 0.053705659961061816, 0.05703354174537318, 0.04028822368543063, 0.015624174648629767, 0.005535032791418156, 0.010567492506067668, 0.014079711898895246, 0.10051789267786912, 0.02597039858145373, 0.0176722443928676, 0.01172093757694321, 0.019942848178158914, 0.013412391367767538, 0.02193695742503873, 0.06909492239356041, 0.03564228762739471, 0.018780419303636466, 0.08593755255320243, 0.022859266327161874, 0.02869755295770509, 0.016506921566490616, 0.0970743681703295, 0.03054126152502639, 0.015585737336160881, 0.0785659956080573, 0.059223608512963564, 0.041982715616800954, 0.02639429976365396, 0.049233666355056424, 0.05572889193094202, 0.019580430750335966, 0.039431379841906686, 0.10523240827023983, 0.05116222233378461, 0.009444471249090773, 0.09445519585694585, 0.04979389540052839, 0.016383494350260923, 0.0341475428348141, 0.05759137895490442, 0.016381163582471863, 0.029448528374944414, 0.02549575824689652, 0.028609689458140304, 0.0413778457524521, 0.03782453767157026, 0.03007618005254439, 0.008765127077432615, 0.022419360200209276, 0.027790573857990757, 0.603577580835138, 5.416002682277134, 20.026162249701365, 29.646782193865093, 35.71185084751674, 27.656583615711757, 19.60586745398385, 8.639062694140843, 10.83755350112915, 19.852266209466116, 23.825029032570974, 23.727365153176443, 13.750802891595022, 6.701130637100764, 2.5970766076019833, 0.792592846921512, 0.7183927084718431, 0.933730736374855, 1.2771832325628825, 3.047104699271066, 3.538484560591834, 2.4475848121302466, 2.404410008873258, 3.5426723701613287, 4.633731058665684, 1.5956214538642337, 3.148122170141765, 3.1236354155199866, 1.3094047435692378, 0.4317868176315512, 0.05482664730932031, 0.21058381801205023, 0.045489581368331394, 0.08186371651078973, 0.15612155757844448, 0.07627243867942265, 0.0477668432784932, 0.1613842480416809, 0.28342578719769207, 0.1478235764162881, 0.33235785152230946, 0.11137500258960895, 0.08820218353399209, 0.08431140266891037, 0.043049420163567574, 0.3618073841290814, 0.26469566939132555, 0.2538717601980482, 2.0037503881113867, 0.11883782249476228, 0.34788973523037775, 1.2645291515759058, 1.2357016184500285, 3.4227607931409563, 3.5576118656567166, 4.0004183905465265, 3.1459743082523346, 4.309859888894217, 3.913981931550162, 4.80686149426869, 1.4429562858172824, 2.04114950128964, 6.589668069566999, 1.7349050428186144, 0.6970052304012435, 0.6236248708197049, 0.04742529589150633, 2.362042716571263, 5.537646097796304, 10.575166940689087, 14.851152624402728, 22.224640028817312, 28.1735817023686, 14.626187324523926, 16.576841967446462, 21.198293822152273, 23.252066680363246, 29.658649717058452, 24.252518687929424, 11.080137695584979, 1.415412432381085, 0.016956484943096126, 0.06522505397775344, 0.07066461137895073, 0.0051172240055166185, 0.04608060572562473, 0.039915005676448345, 0.08925149044288055, 0.04638566489198378, 0.01249264647984611, 0.03456836346802967, 0.01753293945720153, 0.05297893877806408, 0.06445653843028204, 0.022694999784497277, 0.019599266882453645, 0.029918899027896777, 0.010040759341791272, 0.009764601526382779, 0.012132003421096929, 0.05699650730405535, 0.039165187161415815, 0.044994043851537366, 0.025395827002025077, 0.042550791919763596, 0.09968569661889758, 0.013175480017837669, 0.1338433123060635, 0.01760816015303135, 0.041681809084756036, 0.023518006782978773, 0.062195890450051854, 0.05107734438830188, 0.026401397239949023, 0.04321649923388447, 0.08351278730801173, 0.0694913836196065, 0.040216309151479175, 0.01770405750721693, 0.04784143802576831, 0.03855496704844492, 0.05007156210818461, 0.014318050716870596, 0.03478784919051187, 0.05109852485890899, 0.05252355696367366, 0.05575531408456819, 0.028516628380332674, 0.05291469847517354, 0.022059327822976878, 0.017182126674535017, 0.031433185629014454, 0.013955693509030555, 0.048680103916142664, 0.029708739769245898, 0.0438645069620439, 0.03295969943116818, 0.05995797339294638, 0.04430224008059927, 0.06923812720924616, 0.04623335074367268, 0.045355353570942364, 0.0552995149711413, 0.06281955912709236, 0.010982796649581619, 0.04934732097068003, 0.04071932751685381, 0.07118000622306551, 0.030655587890318463, 0.1161437127739191, 0.0378775346492018, 0.0077331847278401256, 0.006387157423887402, 0.02970125213531511, 0.02880865628165858, 0.011725652547154044, 0.04578558209219149, 0.0647401117852756, 0.07984871856336083, 0.011239611127945994, 0.02304719338592674, 0.05497956196112292, 0.05460434566651072, 0.028469602510865246, 0.04863239951165659, 0.03158695523494056, 0.05663370141493423, 0.02404184260272554, 0.018246525898575783, 0.04828593613845961, 0.014720454213342496, 0.07266584185085126, 0.03322864357115967, 0.021030500797288756, 0.028244710560621958, 0.036504668316670826, 1.673366476382528, 9.47455404485975, 28.11583522387913, 37.40909773962838, 37.859712736947195, 27.205928666251047, 13.574237006051199, 13.617376634052821, 20.95067392076765, 31.690664291381836, 31.5349760055542, 23.89851665496826, 18.808891705104283, 7.687904681478228, 1.983910458428519, 0.15461605122046812, 0.29154432298881666, 0.41050348111561363, 0.2405046746134758, 1.0309999798025404, 1.847757032939366, 2.4052961213248114, 2.501515643937247, 2.129671939781734, 6.169181764125824, 4.224490412643977, 3.488123582942145, 4.412179929869516, 3.4579979309013913, 1.5980732994420188, 1.19571929531438, 0.9665311191763196, 0.3213737809232303, 0.4502346105873585, 0.28298028824584825, 0.13820828736892768, 0.3804469310811588, 0.17701412577714237, 0.9675743260553905, 0.5250248302306447, 0.7978830859065056, 0.30910586778606686, 0.14593467063137464, 0.4447220835302557, 0.2543621781681265, 0.9812607573611396, 1.0537222176790237, 1.3216859017099654, 2.966351866722107, 0.8241309374570847, 1.6700187474489212, 2.8545282099928175, 3.690995131220136, 6.655751083578382, 4.0610405547278265, 5.902928965432303, 6.714047772543771, 6.374664315155574, 2.986764588526317, 4.667368156569345, 1.854435988834926, 1.6699303750480925, 0.5856795640928405, 0.3775579461029598, 0.1705977629337992, 0.21656826617462294, 0.31287455984524315, 1.3448571669203895, 4.6530896084649225, 14.87733691079276, 19.54209688731602, 26.105875968933105, 33.188584736415315, 18.282244307654246, 14.370956540107727, 19.03841154915946, 23.67841683115278, 31.332324845450266, 29.729764529636928, 16.410569838115148, 2.9423868783882687, 0.04631775710731745, 0.07748897054365703, 0.04088939892660294, 0.04958532052114606, 0.059752322999494414, 0.027924576042486087, 0.05063595396599599, 0.004822102832674448, 0.016379645360367637, 0.02151744975708425, 0.030450334439852407, 0.0012468173206018815, 0.013455711587864374, 0.03862811312345522, 0.04499346370409642, 0.08726607662226472, 0.03290043278996434, 0.027553335963083164, 0.03922530536406806, 0.08316862077585288, 0.018926509589489018, 0.058252930242036066, 0.034780744928866625, 0.026259169514690126, 0.08131527701126677, 0.0012883305171271786, 0.07539243982838732, 0.029320872189210992, 0.02890902178894196, 0.09985758989517178, 0.04489113723060914, 0.02830039962593998, 0.019638004446668283, 0.017173000378534198, 0.06095377103026424, 0.030317338183522224, 0.03342801073033895, 0.038482530042529106, 0.02800003931458507, 0.04344723167430077, 0.01028625331153827, 0.023675140226259828, 0.023576482930885892, 0.10562074064676251, 0.1948059517890215, 0.1296598317899874, 0.1097920686006546, 0.16315633723778383, 0.12370131723582745, 0.12067190265016896, 0.09806979261338711, 0.14090933171766146, 0.21172242691474302, 0.09323035193873302, 0.10480900241860322, 0.12108195493263857, 0.17137498408555984, 0.16975511743554048, 0.10453541709908418, 0.1788465367364032, 0.14277271101517336, 0.10994857270270586, 0.17694331386259624, 0.14756548883659498, 0.1234263748462711, 0.0902469488126891, 0.11518205223338944, 0.07543556751417262, 0.21859642091606343, 0.1615649147757462, 0.193317978775927, 0.1556702639375414, 0.0745145580066102, 0.10771263696785484, 0.14440576838595526, 0.060630089470318387, 0.10581405527357544, 0.2148076713617359, 0.13684049647833618, 0.12032656903777804, 0.20872353283422335, 0.14698440501732485, 0.09444360647882734, 0.12170613929629326, 0.17653414367565087, 0.12632556499115058, 0.10903164797595569, 0.14185294322669506, 0.12940558471849986, 0.06727799560342516, 0.15135108998843602, 0.11128660304737942, 0.08416924958250352, 0.04432293879134314, 0.16560518369078636, 1.4452156445809772, 9.664186886378697, 29.044260467801774, 43.80688783100673, 48.733073779514854, 39.486727237701416, 27.059412002563477, 15.794615507125854, 18.695776769093104, 28.046097891671316, 31.413987023489817, 29.695172922951834, 18.671035970960343, 8.043828759874616, 3.3281004897185733, 1.281348351921354, 1.128546608345849, 1.7418267514024461, 4.735185180391584, 8.10685760634286, 10.760610886982509, 8.324106931686401, 8.675577214785985, 9.470412918499537, 14.90980063165937, 7.752703581537519, 7.519922426768711, 5.795845934322902, 5.425882152148655, 2.4639384831701006, 1.4785669978175844, 0.6894768572279385, 0.2726052978209087, 0.41976008298141615, 0.5328535501446042, 0.17364154889115266, 0.3767947841967855, 0.33102868284497944, 0.7443195858172008, 0.4743361473083496, 0.7507987810032708, 0.493938752583095, 0.22946507270847047, 0.3621687175972121, 0.20940938246037277, 0.7709930145314762, 0.9758968566145215, 0.8510937477861131, 5.177098861762455, 1.9578618790422166, 1.2302303463220596, 4.296342602797917, 4.951490419251578, 10.49667922088078, 9.483394759041921, 9.932041679109846, 8.7440847158432, 12.215716532298497, 10.130655067307607, 12.737406390053884, 4.014045545033046, 5.075730289731707, 13.241277592522756, 4.749089394296918, 2.0267120131424496, 1.1635145034108842, 0.45785398887736456, 3.250831527369363, 6.777008439813342, 15.013224567685809, 20.82988817351205, 30.585191999162944, 35.90488917487008, 21.681007759911672, 23.988330807004655, 31.76588896342686, 33.53120388303484, 40.57222693307059, 32.768451486315044, 16.49308317048209, 2.6275796336787085, 0.09380820593131439, 0.2107534517667123, 0.19592379752014363, 0.07753241714090109, 0.19471293820866517, 0.11415105898465429, 0.1652270904076951, 0.11317871151758091, 0.1762253695300647, 0.13933061143117292, 0.12645462235169752, 0.0923182787373662, 0.12821099667676858, 0.0757163113781384, 0.12679847675774777, 0.15932135230728559, 0.10035982794527497, 0.09250037718032088, 0.10830571728625468, 0.24516840864505085, 0.09354280374412026, 0.10296882223337889, 0.17687645102185862, 0.08953750652394124, 0.20919919945299625, 0.1029627900570631, 0.2500150485762528, 0.1123374638014606, 0.0976352384313941, 0.13411942177585193, 0.11219238622912339, 0.1370873882302216, 0.1296588954116617, 0.27787330799869125, 0.1204996361796345, 0.167869414335915, 0.14771114316369804, 0.08027662310217108, 0.11108359215515, 0.21022936488900865, 0.18336475214787892, 0.18521783128380775, 0.10028778109699488], [0.006380773257530693, 0.01568486282069768, 0.06014566296445472, 0.017546693362029533, 0.07136810970093523, 0.031168492510914803, 0.07894393961344447, 0.023488531221768687, 0.06429697413529668, 0.03287772222289017, 0.05336371902376413, 0.02475389216228255, 0.032218610269150565, 0.01944603331919227, 0.017610339946778755, 0.0565093123753156, 0.030161041034651653, 0.023625188174524477, 0.05169154071648206, 0.03314566891640425, 0.04160877496802381, 0.03484058153948613, 0.03632527383576546, 0.04004029716764178, 0.019200885402304784, 0.06605056646679129, 0.02950621402955481, 0.06844507583550044, 0.025132065173238516, 0.05464251326130969, 0.01608805850680385, 0.11415709794632026, 0.010433983107629632, 0.0920154010610921, 0.036109771113842726, 0.023126707512087057, 0.029461848017360483, 0.012259165972604283, 0.05963902800743069, 0.033825313339808157, 0.01654356245749763, 0.011818339582532644, 0.08744337782263756, 0.04652092745527625, 0.013896489632315934, 0.0324843652945544, 0.030955785353268896, 0.02983390912413597, 0.03437834991408246, 0.08423355434622083, 0.022392717522702048, 0.04044395765023572, 0.030667594567473446, 0.15130171978047915, 2.3495589750153676, 12.189913528306143, 27.86908905846732, 39.08909920283726, 34.992847783224924, 23.27004861831665, 14.132072261401586, 13.535055245671954, 17.012601716177805, 20.98576579775129, 21.80473780632019, 19.431938409805298, 18.535144839967998, 9.691709569522313, 4.191763963018145, 0.5875511265226773, 0.09843811499220984, 0.20738475610102924, 0.8827527261206082, 2.0075017639568875, 2.824618603502001, 1.3749596944877078, 3.652790895530156, 1.6589260569640567, 2.4141602856772284, 3.6207707737173354, 1.1061920821666718, 0.9127646556922367, 0.8979229235223362, 0.8501543839062963, 0.37642446692500797, 0.6277814134955406, 0.28679742770535605, 1.1193049613918578, 0.25810896711690084, 0.11902083695999213, 0.16061047384781496, 0.06995363560106073, 0.0707827511110476, 0.10933723979230438, 0.0831936112205897, 0.3077650283064161, 0.4418180622160435, 1.4880304442984718, 1.6201327443122864, 1.6561898780720574, 2.8803544470242093, 0.9463295574699129, 1.767578186733382, 2.1668424138001035, 2.7983837255409787, 3.31428399682045, 2.7783175451414923, 5.284092000552586, 5.384367099830082, 4.8142487321581156, 1.9432758731501443, 4.054319041115897, 1.8113414155585426, 1.70550927732672, 0.5672519100563866, 0.6541695318051747, 0.6611027483429227, 3.4434379807540347, 7.178758927753993, 18.623798642839702, 18.34166703905378, 18.239401715142385, 18.434574876512798, 15.24205480303083, 14.438878655433655, 16.65438907487052, 25.896412100110734, 28.581371477672032, 28.93635494368417, 18.500000851494924, 5.731083512306213, 0.6981093968663896, 0.2227475895945515, 0.05215252723012652, 0.06716594233044557, 0.11327920933919293, 0.0555622301596616, 0.0643215642443725, 0.07280948771429913, 0.0799584241051759, 0.07141475219811712, 0.050799056821103604, 0.018118340455527817, 0.06421371788850852, 0.07787393060113702, 0.035911146950508864, 0.029412372636475732, 0.05482154133330498, 0.01528232022454696, 0.02987233116956694, 0.12081724485116345, 0.03873808329392757, 0.02419295404771609, 0.02651175926439464, 0.08280287683010101, 0.013941206786382412, 0.05272626251514469, 0.04251249201063599, 0.03289515718019434, 0.0003284106309625453, 0.04842371606667127, 0.05212274293548294, 0.03473235520401171, 0.026317465850817304, 0.013187817480814244, 0.05227094855425613, 0.06337884161621332, 0.010514369999457682, 0.04481216932513884, 0.029157575951623063, 0.041611909799809964, 0.054379859140941074, 0.07537194807082415, 0.036842792494488616, 0.009356403340851622, 0.021110796935058067, 0.04026506528524416, 0.08226693594562155, 0.008849770928333913, 0.038676485884934664, 0.05455674982762762, 0.02354563503260059, 0.027771091421267817, 0.05177694113392915, 0.01350542191149933, 0.06097065298152821, 0.040783147128032785, 0.019671388369585787, 0.0101569906941482, 0.00919384925094034, 0.044924446514674594, 0.053056546220821996, 0.025960968641032065, 0.02479928106601749, 0.043535356409847736, 0.01429165231197008, 0.11876967043748923, 0.034280576410570314, 0.026069914223626256, 0.023763261569131697, 0.07247536350041628, 0.10340293536760978, 0.03887598875111767, 0.025534714638654674, 0.039368917300765, 0.03781020701197641, 0.021865426263372813, 0.04102703636246068, 0.04514288729322808, 0.04396338647763644, 0.03940544623349394, 0.012186710306975459, 0.02935130787747247, 0.03781175407181893, 0.021754977725712315, 0.01904105138964951, 0.03969756234437227, 0.037095061636396816, 0.025090391248730675, 0.029828569053539207, 0.09643479463245187, 0.03829940701169627, 0.038387626742145846, 0.012008580445711101, 0.02329377131536603, 0.03739277905385409, 0.030414752063474486, 0.07664606041674103, 0.0571868499474866, 0.6521952120321137, 5.063719025679997, 18.04891163962228, 35.458120005471365, 40.84528766359602, 31.36549207142421, 18.933394738606044, 10.843400410243444, 12.808641927582876, 23.583891800471715, 26.79068868500846, 29.083159957613262, 25.372809750693186, 23.148997102464946, 10.71941762311118, 4.036427429744175, 0.23778548623834336, 0.09443000185170344, 0.12873147374817304, 0.4865841386573655, 0.7042001443249839, 0.22488384853516305, 1.4341992757150104, 2.1794486173561642, 1.9931611163275582, 1.905249685049057, 2.267029792070389, 1.9798466307776315, 1.976697142635073, 1.86433521764619, 1.4994465517146247, 1.659892616527421, 0.6908999894346509, 1.3380480408668518, 1.652799591422081, 1.1212081164121628, 1.0945060806615012, 0.8123014122247696, 0.2234387725059475, 0.5331833181636674, 0.7374950434480394, 0.4146323395626885, 1.5960595160722733, 1.1599344440868922, 2.6604921647480557, 2.6369164926665167, 2.8315079595361436, 4.126536011695862, 3.947189109666007, 5.342169386999948, 3.311521436486925, 4.880535415240696, 3.5639290809631348, 3.287743180990219, 4.7210781659398755, 3.2411422644342696, 2.7932255566120148, 1.8108090098415102, 0.26016522677881376, 0.26182991745216505, 0.42847306973167826, 0.1550703439861536, 0.18134845819856438, 0.496774323284626, 3.292126625776291, 8.131020835467748, 14.403944849967957, 25.037276029586792, 25.75528723852975, 22.247919968196324, 20.387037788118633, 19.00231739452907, 14.997540746416364, 26.272149835314067, 30.644498348236084, 33.187754426683696, 26.662358931132726, 10.750591584614344, 1.5744015468018395, 0.1353403234056064, 0.03304336279896753, 0.03858804563060403, 0.023569046187081506, 0.016708470215754848, 0.04103000156049218, 0.11704091248767716, 0.03838699231190341, 0.009137563074805906, 0.005492179488231028, 0.03599152281614287, 0.033100522588938475, 0.14222611034555094, 0.041477461478539875, 0.017637021640049558, 0.0518112546498222, 0.07629286258348397, 0.08784921640264136, 0.042273732500949075, 0.0447909040376544, 0.01957765723844724, 0.0674043863213488, 0.036550333723425865, 0.007341849833859929, 0.08420053004686322, 0.03731658635661006, 0.043556530095104656, 0.034536221264196296, 0.0582771132301007, 0.023578269174322486, 0.018252173006268482, 0.029501355718821287, 0.03709298871191485, 0.022287812616143907, 0.06463537311979703, 0.026543440064415336, 0.05804831122181245, 0.0066772760973045865, 0.016191002447158098, 0.05605744197964668, 0.022131500200235417, 0.007066136034804263, 0.013640284139130796, 0.030909302311816385, 0.08029461785086564, 0.1424860842525959, 0.16737725931618894, 0.10591211036912032, 0.10242557352674858, 0.11723976396024227, 0.11832204088568687, 0.11646978956248079, 0.1282690249915634, 0.16797964913504465, 0.1252445908529418, 0.09594980494252273, 0.1164047180541924, 0.05297295070652451, 0.09259959935609784, 0.1295499905411686, 0.09254461087818656, 0.1222612623657499, 0.15406092815101147, 0.11415126254515988, 0.22196458732443197, 0.14225125685334206, 0.15229433508855955, 0.1380619273654052, 0.12526117424879754, 0.18183384143880435, 0.14818919822573662, 0.13831366385732377, 0.22629596133317265, 0.11459338239261083, 0.14791969768702984, 0.1666714200483901, 0.1646064615675381, 0.1464749202132225, 0.08911165794623749, 0.1585659799831254, 0.05076260252722672, 0.13598972213055405, 0.14921384038669722, 0.19771555066108704, 0.10160068528992788, 0.07730135561100074, 0.19893552948321613, 0.13560611914311135, 0.13662127538451127, 0.10852031077125243, 0.12410047224589757, 0.0630993733980826, 0.09695181117526122, 0.13637198161865982, 0.09373095471944128, 0.19152163873825753, 0.10359181237540074, 0.41870354967457907, 4.395926356315613, 19.4961519241333, 38.65572616032192, 51.49794612612043, 45.967277322496685, 32.42631523949759, 22.891866854258947, 20.431391613824026, 25.339585202080862, 30.60095398766654, 29.979923997606548, 26.25138166972569, 25.066496678761073, 12.78326450075422, 5.929645223276956, 0.9050167085868972, 0.46724442499024527, 0.3826323566692216, 3.6804425546101163, 5.113016928945269, 8.268194777624947, 5.844097699437823, 9.291872876031057, 8.816907048225403, 10.637311628886632, 11.444766129766192, 3.581090045826776, 5.495668121746608, 4.11984098809106, 2.8066108269350867, 2.0085298802171434, 1.2326650385345732, 1.6903907571520125, 2.967047772237233, 2.111114169870104, 0.9369609973260334, 0.9774950508560453, 0.3140435128339699, 0.4669878844703947, 0.5295980476907322, 0.5996696533901351, 2.121309348515102, 2.0111532594476427, 4.287854943956647, 4.56649420942579, 5.356279007026127, 6.919872088091714, 5.060188472270966, 5.601334588868277, 6.942505845001765, 9.425264392580305, 6.945756299155099, 10.788492270878383, 13.230348944664001, 12.832355260848999, 11.07716907773699, 8.013845545904976, 10.331499695777893, 5.865921122687204, 3.555717178753444, 1.7424046461071288, 0.9714744367769786, 0.8793210216930935, 4.266850105353764, 9.25989031791687, 23.272631611142838, 24.61408383505685, 23.23463191304888, 25.319338151386805, 22.544269323349, 22.405419996806554, 24.551645585468837, 37.101761545453755, 39.73601818084717, 39.973590987069265, 28.344290256500244, 9.675577589443751, 1.1912530149732317, 0.2739021953727518, 0.077044991510255, 0.13789546915463038, 0.24543548002839088, 0.10189466058675732, 0.11541297127093587, 0.20084195504231112, 0.1603390191282545, 0.14023439293461187, 0.10457709950527974, 0.09300990948187453, 0.12192829166139875, 0.31433924553649767, 0.08174386008509568, 0.11365462919431073, 0.12410941533744335, 0.1612883439021451, 0.12730940005608968, 0.14861233266336576, 0.10605848394334316, 0.12794788793793746, 0.12275781429239682, 0.22456537133881024, 0.12233533124838557, 0.19298378670854227, 0.15162767443273747, 0.10693682038358279, 0.1381754462740251, 0.2489145462002073, 0.12063275117959295, 0.07841329808746066, 0.15700308313327177, 0.14784926575209412, 0.1293930182499545, 0.11266136927796261, 0.09165239161146538, 0.11560210612203393, 0.17172593596790517, 0.12938951700925827, 0.2604500486382416, 0.19359879727874482, 0.07828958758286067, 0.11959168847118105, 0.07410079413758856], [0.045391482168010304, 0.07831523620656558, 0.036328089756092856, 0.01748821891045996, 0.037644746247678995, 0.009649343023608838, 0.02746807294897735, 0.043638826214841435, 0.057366302103868554, 0.10074411625308649, 0.01914971538021096, 0.07573877767260585, 0.06274988036602736, 0.02216111995013697, 0.03313788951241544, 0.04328664279143725, 0.040945232180612426, 0.0708875779860786, 0.104951990103083, 0.01895205134392849, 0.020654490616704737, 0.041433092073670456, 0.03861021336966327, 0.019116482431335107, 0.006629888059770954, 0.02554267385442342, 0.02986076214749898, 0.03265384977151241, 0.042774494737386703, 0.029430913605860302, 0.04476729101900544, 0.042815057560801506, 0.05550862250051328, 0.0005427269768136154, 0.04036263183557561, 0.032114407646336725, 0.026766484703070352, 0.033904369454830885, 0.05571267494399633, 0.030253851054502384, 0.058889925346842835, 0.01920421022389616, 0.046584502793848515, 0.0399541876811002, 0.029113549206938063, 0.04869966947340539, 0.030020377332610742, 0.10582353440778595, 0.015623825203095163, 0.012950130056456795, 0.013905343666140522, 0.030931364877947738, 0.05635168529780848, 0.012122035741672983, 0.012152788645055677, 1.0214860503162657, 7.2832806791578015, 24.82457603727068, 30.799029758998326, 37.91518715449742, 33.32067346572876, 22.99085783958435, 24.722058841160365, 19.027751275471278, 20.314244985580444, 21.926129783902848, 17.611704928534373, 23.237270491463796, 19.23284820147923, 15.244748967034475, 8.083205938339233, 2.753271894795554, 0.7541396703038896, 0.10624900300587926, 0.15400395835084574, 0.5867461668593543, 1.8770467298371452, 1.7469384542533328, 1.262297585606575, 1.9095768928527832, 2.5359396253313338, 1.2387118169239588, 1.4104646635907037, 1.1843859148877007, 0.6847365573048592, 0.3741678223013878, 0.8889617015208516, 0.24428156337567739, 1.5658853352069855, 1.1826452825750624, 0.3765619381197861, 0.29611241072416306, 0.18295608407684735, 0.6478832576956067, 0.3024382841374193, 1.6954465487173624, 1.5789564166750227, 2.279031502349036, 1.3641473203897476, 2.4338725422109877, 2.119297845023019, 2.420335280043738, 6.272196624960218, 2.896060198545456, 4.128287826265607, 4.1473067828587125, 1.7852550553424018, 4.1007004380226135, 3.88958854334695, 2.127819376332419, 1.3687387768711363, 0.2638848200440407, 0.5658737240093095, 0.7292296183960778, 3.4137431170259203, 6.639902242592402, 14.04649043083191, 13.310202854020254, 24.83710537637983, 52.57811655317034, 25.620205572673253, 20.357801505497523, 15.797809941428048, 11.866908277784075, 18.61972873551505, 23.471077374049596, 30.935072013310023, 32.044723646981375, 16.60368112155369, 3.9998195426804677, 0.25623925030231476, 0.04233807119141732, 0.028883081395179033, 0.042039529353912385, 0.04654084585074868, 0.0018194466995607528, 0.014264882409146853, 0.026285832548247914, 0.026943087012373974, 0.022632861243827, 0.06360881749008383, 0.03370492087144937, 0.027955712318154316, 0.030884118484599248, 0.04140326367425067, 0.047306223173758814, 0.09591960334884268, 0.04306574232344117, 0.03304126273308482, 0.010617022169753909, 0.008653365574511034, 0.044111754944814105, 0.03695208752261741, 0.021524550626054406, 0.03404109086841345, 0.029721910133957863, 0.025592228963172862, 0.06497926823794842, 0.010258826926084501, 0.008866495120206049, 0.05244315395663891, 0.009609147457272878, 0.044718701126320023, 0.061886939885360856, 0.062312605258609564, 0.02114976689751659, 0.04488804989627429, 0.02389909410183983, 0.021112574696806923, 0.03800055644075785, 0.006552744565332043, 0.03622698464563914, 0.09467736179275171, 0.04363315366208553, 0.01997775541219328, 0.03033764334395528, 0.03945640760606953, 0.058431812429002354, 0.018047694782061235, 0.030908121660883938, 0.06436150960092034, 0.08398567871855837, 0.02703157646049346, 0.05229216295161417, 0.020623942970165184, 0.055788860855890174, 0.01366298198367336, 0.06004207780850785, 0.014114409635242606, 0.06465130512203489, 0.021013591704624038, 0.055538179485925605, 0.04829051964251058, 0.01670850414250578, 0.03252205791484032, 0.051875196397304535, 0.052086329353707175, 0.07602702613387789, 0.035909918802125115, 0.04613820656335779, 0.015163089747407606, 0.004089552185697747, 0.06158740060137851, 0.07752804737538099, 0.0281963191394295, 0.020830755354836583, 0.07431851566902228, 0.019855344302154014, 0.0522384840462889, 0.011604353386376585, 0.04725024742739541, 0.007904853239389402, 0.024631462392530272, 0.03250447028715696, 0.02007795637473464, 0.06223722680338791, 0.046553429282669506, 0.011761882924474776, 0.03436243826789515, 0.027152961286317025, 0.016545918670349886, 0.013699588099760669, 0.0460581326458071, 0.07750458363443613, 0.04792436857574752, 0.01988321343170745, 0.021539651422894428, 0.03828036731907299, 0.024821299527372633, 0.03559674435694303, 0.13884302973747253, 2.6694014923913136, 13.849217176437378, 32.085627692086355, 38.091928482055664, 40.416952065059114, 29.392401695251465, 19.305345705577306, 18.320560148784093, 21.70334448133196, 19.85599044391087, 25.251417773110525, 28.820146322250366, 32.121876444135395, 25.1417213508061, 16.61145441872733, 7.819725036621094, 2.4317468277045657, 0.5694838017225266, 0.03737212444788643, 0.19071020585085663, 0.2319241650402546, 0.46025546001536505, 0.5565334994878087, 0.5972032600215503, 1.1023311636277606, 0.6424012375729424, 1.2530053470815932, 1.0220767557621002, 1.3383581042289734, 0.5726920238562992, 1.847876020840236, 1.7701881038291114, 2.014926782676152, 1.8045207815510886, 2.6027917180742537, 1.6031071607555663, 1.16998881314482, 1.2370934294802802, 1.360777335507529, 0.9867072765316282, 2.30911785364151, 2.029982877629144, 3.5984340522970473, 3.4020482131413052, 3.3321684428623746, 3.4345937924725667, 3.45528205377715, 4.403817338602884, 1.6765804524932588, 3.3145819008350372, 1.8134942714657103, 1.0828962922096252, 1.3888079971075058, 0.0757772098960621, 0.41599790485841887, 0.07834952936640807, 0.2706577123275825, 0.1863537531878267, 0.5811333251850945, 2.416753266538892, 6.080868857247489, 13.659780621528625, 21.219105413981847, 29.683736188071116, 53.69031817572457, 29.48665748323713, 18.69870022365025, 16.129289388656616, 13.358709965433393, 17.448561225618633, 23.815053156444005, 34.206905773707796, 36.33219991411482, 23.128595454352244, 7.575225744928632, 0.8431966315422739, 0.029846753792038987, 0.0058051893886710915, 0.005577385250944644, 0.038519028441182206, 0.011509916578818644, 0.06633148674986192, 0.07746249410722937, 0.02419519660595272, 0.01227228035817721, 0.06398203210639102, 0.025476688020197407, 0.08078902560685362, 0.036791977006942034, 0.08470240847340652, 0.07916026336273976, 0.05710176844149828, 0.07807878710861717, 0.0328274020659072, 0.029580371121742895, 0.00976038527941065, 0.042719346803746054, 0.022598676649587493, 0.02281314630194434, 0.02989012575043099, 0.00848593027330935, 0.08895147618438516, 0.021023703572739447, 0.02413889007376773, 0.010326742344269795, 0.02465110258864505, 0.06172590995473521, 0.0369523928633758, 0.026312605843746235, 0.030549838207662106, 0.016566442658326457, 0.00455189322487318, 0.015487882408446499, 0.0075190441649673236, 0.0918866829680545, 0.023086872417479753, 0.06030821959887232, 0.0540618603117764, 0.04465750066031303, 0.031547288077750375, 0.06945082758154188, 0.15111132285424642, 0.15521340630948544, 0.14467114343174867, 0.0863321138811963, 0.11824018242103712, 0.1778245001499142, 0.13390630749719484, 0.09912236327571528, 0.11322021071932145, 0.23145041189023427, 0.07329120686543839, 0.21166788626994404, 0.1531663475824254, 0.09767968247511558, 0.20143700311226503, 0.12077372361506734, 0.12103696806090218, 0.1163913644850254, 0.21129850537649222, 0.09903804851429802, 0.1814945467880794, 0.1294492416615997, 0.11469531192311219, 0.1590569814933198, 0.10086878349206277, 0.07747484344456877, 0.13954931683838367, 0.15636813720422132, 0.10674869654966251, 0.0897148959338665, 0.15273527428507805, 0.13443211785384587, 0.09262930561921426, 0.08255241598401751, 0.1320928276649543, 0.06784201426697628, 0.13943229668906756, 0.15564206402216638, 0.1492836344987154, 0.12910768070391246, 0.17654272035828658, 0.08202609672610249, 0.10147137008607388, 0.101422508779381, 0.10950363014957734, 0.21044432478291647, 0.10540202166885138, 0.20786861942282744, 0.08880274809364762, 0.111372966984553, 0.14816979212420328, 0.13010793631630285, 0.11945147599492754, 0.10989549090819699, 0.1468850674905947, 2.0037377945014407, 12.706523384366717, 33.65239783695766, 44.16773557662964, 50.52927344185965, 44.79129818507603, 32.783827849796836, 33.06309332166399, 27.51825887816293, 27.681821210043772, 30.502345153263636, 25.544595275606426, 30.658783844539098, 25.50081467628479, 20.371987989970616, 11.233493992260524, 3.595267193658011, 1.4298633826630456, 0.39535749384335106, 0.9141365992171424, 2.731689052922385, 5.1217469062123975, 4.690162590571812, 4.358264948640551, 8.740172011511666, 8.570235575948443, 5.1613607576915195, 5.780671502862658, 4.695566986288343, 3.413109745298113, 3.3851035109588077, 3.8232740674700056, 1.9236567659037453, 6.474754852907998, 4.328766371522631, 2.667548928941999, 1.5260706373623438, 1.6402448479618346, 1.9376847445964813, 2.17920868737357, 5.104221812316349, 5.653190732002258, 7.440242222377232, 4.950857264654977, 8.579874464443751, 6.328351965972355, 8.127979261534554, 11.496871539524623, 10.517668860299246, 11.957408564431326, 10.021522317613874, 5.446412341935294, 7.216403833457401, 8.046726158687047, 5.0260398132460455, 3.5277000878538405, 1.0408925861120224, 0.8759940287896565, 1.1384425801890237, 4.576519157205309, 9.195366740226746, 18.36308833530971, 17.324780804770334, 29.95257936205183, 60.79763398851667, 30.834048679896764, 26.102386236190796, 24.100830827440532, 19.56062773295811, 28.320947783333914, 34.04936579295567, 42.92078753880092, 40.43971783774239, 24.068672827311925, 6.486499045576368, 0.6506828388997487, 0.1360986405717475, 0.06820716788726193, 0.07048095230545316, 0.08667847208146538, 0.11511271952518395, 0.18391660467854568, 0.1962181052991322, 0.19473001014973434, 0.10987295676022768, 0.17722255816417082, 0.07771801682455198, 0.1818395004208599, 0.14231752258326325, 0.12299040252608912, 0.33431469223328997, 0.17203517151730402, 0.15562672913074493, 0.13249237622533525, 0.0934436290657946, 0.05230123157213841, 0.07293595985642501, 0.20437507331371307, 0.11582952391888414, 0.09179657351757799, 0.11439704149961472, 0.21382250636816025, 0.12001027672418527, 0.1875318799700056, 0.14021375189934457, 0.15293320295001778, 0.13819137827626296, 0.1078007108132754, 0.17078674850719316, 0.20609851154897893, 0.19959433270352228, 0.08286606879638773, 0.07836360896804503, 0.07935455507997956, 0.11675201941813741, 0.1041814253798553, 0.1269117378230606, 0.1867403553000518, 0.15885863213666848, 0.13877927458712033, 0.13814255089632102], [0.05985566388283457, 0.042197801039687226, 0.019808347270424877, 0.08589559873299939, 0.02737105092299836, 0.014621562823387129, 0.05159022526017257, 0.025344295660033822, 0.011127931897395422, 0.031253394205123186, 0.09762063635779278, 0.012133893141123866, 0.022128243232145905, 0.01426800706290773, 0.029337662538247447, 0.03379005326756409, 0.034464978479913304, 0.027025510357426744, 0.03720091309930597, 0.02645032131113112, 0.019045767208029116, 0.0654644343469824, 0.04933767220271485, 0.10464667648609195, 0.04402241902425885, 0.0150662017320948, 0.034306486270257404, 0.06024922097900084, 0.014288366506142276, 0.019658944037343775, 0.05010778909283025, 0.023188868105145435, 0.03179674469200628, 0.025658082483070235, 0.024027291419250623, 0.03962929493614605, 0.034837056550064256, 0.034553031969283304, 0.013746264523693492, 0.017076916427218487, 0.06670791083680731, 0.04127167198540909, 0.026553419618202106, 0.027548871202660457, 0.027145901129447987, 0.023337233179648007, 0.046843061955379586, 0.05518418776669672, 0.03377839603594371, 0.0660656706563064, 0.046170864453805346, 0.07501524221152067, 0.01132789786372866, 0.024007486678393822, 0.026998296014166305, 0.0070353216391855055, 0.1771880207317216, 3.1093414510999406, 10.739916546004158, 27.698533364704677, 37.22668668201992, 34.599590165274485, 30.18250220162528, 24.869642053331646, 22.11788443156651, 16.60554323877607, 23.636531352996826, 19.78515008517674, 25.00461254801069, 23.93342787878854, 23.619400569370814, 22.879987171718053, 17.790659257343837, 9.689237747873578, 2.9343562807355608, 0.9105947007025991, 0.36603085749915665, 0.30172913361872944, 0.13032565106238636, 0.22228572437805788, 0.18779018468090466, 0.6957810446619987, 1.0589929691382816, 0.9132732855422157, 0.7342826958213533, 1.1837910839489527, 1.5688585128102983, 1.5861056787627084, 0.593955682856696, 2.2875454340662276, 1.4649178045136588, 0.718376695045403, 1.2395735021148409, 2.094944408961705, 0.7181028925946781, 1.1384156559194838, 0.9918329843452999, 2.6107224353722165, 3.6682276214872087, 2.301159994942801, 3.836585513183049, 5.322962394782475, 5.0569106595856805, 1.0174108232770647, 2.3423067927360535, 1.4817789111818587, 0.5257400604231017, 0.882022133895329, 0.29231790719287737, 0.35540011365498814, 1.5016634613275528, 3.8244022812162126, 9.766563381467547, 18.468848603112356, 19.47953357015337, 29.34970154081072, 25.00148412159511, 18.67632876123701, 37.40557500294277, 60.43173490251814, 26.17237717764718, 19.34139817101615, 26.87656668254307, 28.889636993408203, 33.145700454711914, 30.450733934129985, 17.943693331309728, 9.424332465444293, 1.5490028411149979, 0.1628489608743361, 0.07461819744535855, 0.04369619295799306, 0.006537525024863758, 0.03688722296750971, 0.003859061897466225, 0.0439309728597956, 0.03460871933826378, 0.012703324817786259, 0.039549977585141144, 0.02297316351905465, 0.019072465864675384, 0.056583201446171315, 0.040177527482488325, 0.013340375901732062, 0.030674522410013845, 0.03700535252158131, 0.033898571373096535, 0.054888767190277576, 0.04449818063793438, 0.03276865789666772, 0.041264194529503584, 0.06533806398510933, 0.01594739480476294, 0.006187445060017386, 0.059503327789051194, 0.020139160233416727, 0.013664927682839334, 0.060961173847317696, 0.019209562168855752, 0.019887257500418594, 0.012793558949072446, 0.05320260427626116, 0.018033674552238414, 0.026908809119569402, 0.07979269192687102, 0.07796473215733256, 0.04746764326202018, 0.03452293215585606, 0.04330630673627768, 0.03005149494856596, 0.01994868357931929, 0.02882213198712894, 0.05246011054675494, 0.08618952653237752, 0.05134974566421338, 0.033077828985239775, 0.052435523830354214, 0.02721953235699662, 0.01415182151166456, 0.051000201742031744, 0.09978928177484445, 0.046554199419915676, 0.006478284252807498, 0.06918580537395817, 0.007472148065322212, 0.0342754127590784, 0.08331745743219342, 0.03832953057384916, 0.01571757499394672, 0.020513606390782764, 0.04125107166224292, 0.039147222946797094, 0.04876462223806551, 0.02518634288571775, 0.03441967608939324, 0.03380708110385707, 0.01793531750861023, 0.020805352700075934, 0.016333448999960507, 0.021943328868863837, 0.0468922523515565, 0.05741398275962897, 0.047741079303835116, 0.0583759622116174, 0.023807834534506713, 0.03133892693689891, 0.07767768470304352, 0.022315727546811104, 0.04899846915421741, 0.03245757673201816, 0.01605347527324089, 0.07393819000571966, 0.014551887454997216, 0.048969811227704794, 0.08456542582384177, 0.011593055778316088, 0.05317556465576802, 0.062143731463168345, 0.02592118613288871, 0.050582536296652894, 0.017889219535780803, 0.05418662933100547, 0.037724809987204413, 0.008326857068043734, 0.04570902977138758, 0.029131442175379822, 0.022765004242371236, 0.020113046813224043, 0.02792137166086052, 0.01770031369025154, 0.04824219098580735, 0.0220820333010384, 0.5299197275723729, 6.5529768041202, 18.39867353439331, 36.376522472926546, 42.309752532414024, 35.4730794770377, 31.279004369463237, 25.160488435200282, 19.374987500054495, 17.402677059173584, 18.184147902897426, 22.22630933352879, 29.24455792563302, 35.62098230634417, 31.62193271092006, 25.178706611905778, 15.838323150362287, 7.759559716497149, 2.455598690680095, 0.7812388390302658, 0.24293138725417002, 0.11335515776383025, 0.14988829062453338, 0.03153365970190082, 0.1745036004909447, 0.5690130069851875, 0.45669771092278616, 0.6562806442379951, 0.5204049838440759, 1.3769339599779673, 0.8995413652488163, 1.4569524547883441, 1.0120023020676203, 1.7255792575223106, 1.1152391795601164, 0.7120929179447038, 0.9161421316010612, 0.26290346841726986, 0.48205554166010445, 0.8900110966392926, 1.165594403232847, 1.5311365255287714, 1.253613205892699, 1.2903438806533813, 2.229607228721891, 1.1043915216411864, 0.8154316842556, 0.8145381350602422, 0.13552994680191788, 0.40843215797628674, 0.3265975777591978, 0.14952830065573963, 0.26033241780740873, 0.1717132202216557, 1.1949537992477417, 2.0749804973602295, 7.923782127244132, 15.805581501552037, 24.520839009966167, 32.64931419917515, 37.42670794895717, 22.616106748580933, 34.8866480418614, 67.12027931213379, 22.59012917109898, 14.344023585319519, 23.08919048309326, 26.388170855385916, 34.37557676860264, 33.886534758976524, 26.949482815606252, 16.563053267342703, 4.6278615679059705, 0.5335091235382217, 0.016319537335740666, 0.04813014789085303, 0.03401877724432519, 0.03092628265065806, 0.043236967242721996, 0.01188765702370022, 0.023400906905797974, 0.01959741617819028, 0.06151810860527413, 0.05667177401483059, 0.011178825416469147, 0.02959339220875076, 0.04533632066366928, 0.05620855851364987, 0.026629715792036483, 0.03163978936416762, 0.019206505368596742, 0.04207611256944282, 0.10537684123430933, 0.020043116994202137, 0.05545653475980673, 0.11014055740088224, 0.051698746758380106, 0.027793467809845294, 0.030342538974114826, 0.029376953108502284, 0.035750133983258686, 0.033756109553256204, 0.04313586213226829, 0.032506709452718496, 0.06232905973281179, 0.029411673745406524, 0.007120125793984958, 0.0354266695545188, 0.046213849647236724, 0.05415758124685713, 0.0366245145643396, 0.0486392221812691, 0.07416150945105723, 0.012969563299390887, 0.0435324115678668, 0.034042414011699815, 0.015694747379581844, 0.039888457993843725, 0.032124097126403024, 0.037917018601936955, 0.1807737254670688, 0.14566422014364175, 0.11492357110338551, 0.15735687129199505, 0.2178413878594126, 0.0732105290517211, 0.10822069684841804, 0.16572696715593338, 0.12347966698663575, 0.11484762946409838, 0.19054849738521235, 0.10973292070307902, 0.1189110092818737, 0.11990678656314101, 0.1996579657175711, 0.12932931738240377, 0.0922915173162307, 0.11101822209145341, 0.15202809151794228, 0.1509587610406535, 0.08271536616874592, 0.107851417735219, 0.07333808006452662, 0.1814347949943372, 0.2131667294140373, 0.17817718908190727, 0.15044167664434227, 0.13765236362814903, 0.09506831331444637, 0.08848024039928402, 0.13996325034115994, 0.19164602777787618, 0.1364589969494513, 0.08337552645908934, 0.08102902344294957, 0.16670375902737888, 0.11303376965224743, 0.1561828971441303, 0.1378885345267398, 0.07769292459956237, 0.08651569153049163, 0.25650081198130337, 0.10015183660600867, 0.17694567516446114, 0.17055140542132513, 0.09737796509372336, 0.06563052614884717, 0.11679488926061563, 0.08746236323245934, 0.17287142521568707, 0.1472117413899728, 0.21341588747288498, 0.1066525142107691, 0.13524294005972998, 0.1239988412708044, 0.08212028417204108, 0.3677621803113392, 5.473206767014094, 18.68334470476423, 40.26453638076782, 50.55023963110787, 47.27883665902274, 42.68129702976772, 34.74123961584908, 32.40054784502302, 25.543744121279033, 32.115039416721885, 27.868369919913157, 34.22767741339547, 33.463094166346956, 31.22371060507638, 29.94101755959647, 22.401181595666067, 13.326202818325587, 4.406654809202466, 1.5513834676572253, 0.7836774938872882, 0.9628758238894599, 1.082597628235817, 0.8909959495067596, 1.8183617017098834, 2.8632812031677792, 4.117231939520154, 3.468385922057288, 5.7281830736569, 4.427274022783552, 5.33697213445391, 5.409378009183066, 2.847710507256644, 6.449069968291691, 6.337728125708444, 3.32064094713756, 4.5725977676255365, 6.195513265473502, 4.287594386509486, 6.017684110573359, 7.229257566588266, 7.42390353339059, 10.859399506023951, 8.621564524514334, 12.603356531688146, 13.708519629069738, 11.269106115613665, 3.931289025715419, 6.0128746543611795, 4.324549683502742, 2.997145631483623, 1.8878244715077537, 0.7782275006175041, 0.6290978799973215, 2.241298658507211, 5.585042365959712, 12.112451536314827, 22.568343094417028, 26.072432552065166, 36.54673596790859, 33.0294258253915, 23.87855969156538, 41.357651301792686, 67.68247195652553, 32.200783661433626, 26.083516665867396, 35.75154938016619, 38.37883002417428, 44.01834235872541, 40.728808062417166, 28.98578269141061, 14.224907142775399, 3.409830629825592, 0.458695860845702, 0.09753710869699717, 0.09292479404913527, 0.08834143249051911, 0.14045013992914132, 0.14296435644584043, 0.1233656866742032, 0.09675403178802558, 0.08496617539120571, 0.11414113880268165, 0.16415242664515972, 0.08638148408915315, 0.11843222140201501, 0.1587298054780279, 0.15320613687591894, 0.07666206027248076, 0.20700294444603579, 0.10510059605751719, 0.1044310312718153, 0.22661686768489225, 0.1303719271506582, 0.13492970115372113, 0.2039010487496853, 0.17525678793234484, 0.11253662740013429, 0.1411766880857093, 0.13736845100564615, 0.14466005616954394, 0.1354590127510684, 0.11793013262961592, 0.11857212175215993, 0.1467565665287631, 0.07395150286278554, 0.11162033371095147, 0.060983748707388125, 0.1911985475037779, 0.0999324255223785, 0.16716942403997692, 0.15215112348752363, 0.18188405303018435, 0.11098321646984134, 0.11509101997528758, 0.10116113709019763, 0.12301770677523953, 0.24345700762101583, 0.12766401602753571, 0.07307651838553803], [0.05326424579003027, 0.06113695512924876, 0.08314513667885746, 0.02978125141401376, 0.016261481879545108, 0.015140117944351264, 0.06656199866639716, 0.04145434039777943, 0.033127239905297756, 0.020794280704909136, 0.022953321458771825, 0.06874196883291006, 0.06373771200222628, 0.05373797519132495, 0.01754531084692904, 0.023311684639858346, 0.060203888054404936, 0.02075997906337891, 0.008910645697531956, 0.009244552780208843, 0.03784256634701576, 0.038391029595264366, 0.08041748697204248, 0.017655211467561976, 0.03611906025824802, 0.05080581163721425, 0.013099209289066494, 0.04127381615606802, 0.0071478040855644, 0.015355347555928996, 0.02546543621325067, 0.07063514260309083, 0.027260827998231565, 0.026100305807111517, 0.019193404553724185, 0.07731582197759833, 0.009960235046621944, 0.07073270915342228, 0.05009059162278261, 0.03879270197025367, 0.04040270611377699, 0.03827647592074104, 0.019459833025134037, 0.035752600458051474, 0.014266083416129862, 0.019176337701667632, 0.025544668747378246, 0.04647655805040683, 0.0277223776959415, 0.03885351227862494, 0.013586458500607737, 0.06964945513755083, 0.05039178313953536, 0.023698249432657446, 0.059957132009523254, 0.030461570979761224, 0.0375590472748237, 0.03684375601421509, 0.8786351584962436, 5.507617720535823, 20.661661863327026, 32.13027681623186, 36.13392959322248, 34.16844054630825, 31.26575068065098, 25.489027057375225, 25.651126793452672, 19.316438504627772, 22.757066590445383, 23.994340998785837, 21.693382501602173, 26.806843246732438, 28.21314995629447, 23.7278984274183, 21.630846977233887, 18.973987851824077, 9.701981612614222, 4.378425581114633, 2.363484684910093, 1.0993260677371706, 0.4439445638230869, 0.4472664270017828, 0.2324701685990606, 0.3135873201702322, 0.2301577212555068, 1.055015885404178, 0.655025842998709, 1.9665388762950897, 0.7317412836211068, 1.1984496116638184, 0.5384840337293488, 0.49931003579071587, 0.06791649027062313, 0.17348241885857923, 0.3759337232581207, 1.071441752570016, 0.61838370348726, 1.4241686825241362, 0.4585572768534933, 0.9693548019443239, 0.8071461745670864, 0.10463016094373805, 0.3946272273148809, 0.7414399917636598, 0.3725117083106722, 0.36996703914233614, 1.2687880716153552, 3.382090381213597, 6.456303911549704, 11.75508223261152, 20.04368039539882, 27.262589488710674, 26.75207233428955, 23.313398429325648, 23.672887802124023, 18.802808557237896, 14.727302721568517, 17.365056037902832, 31.78898130144392, 39.47062826156616, 22.815867458071025, 27.332094056265696, 26.749946185520717, 29.02122371537345, 20.898211547306605, 12.435092874935695, 3.338434849466596, 0.29740803263017107, 0.01818465537923787, 0.03992438981575625, 0.03536143180515085, 0.02704097586683929, 0.002231408209939088, 0.015925607045314143, 0.04294556359361325, 0.017233612215412513, 0.05853491582508598, 0.047596191721303124, 0.01817895398874368, 0.010594084293448498, 0.041540130972862244, 0.05254791976351823, 0.031531121980931075, 0.044756956930671415, 0.013228331110440195, 0.07137925803129162, 0.022529269302529947, 0.016787529723452668, 0.08113222861928598, 0.12259644509426185, 0.04828847046675427, 0.05052612628787756, 0.01957524674279349, 0.10061229046966348, 0.016032679871256863, 0.05109917964520199, 0.013418208109214902, 0.0334099583061678, 0.04785409948921629, 0.035368349469665966, 0.026201597514695356, 0.018077326406325613, 0.014141099810201143, 0.04626789835414716, 0.03531601406367762, 0.02903992815741471, 0.022974059185279266, 0.03599343967757054, 0.01550113080468561, 0.01839852113542812, 0.017863470828160644, 0.021434285112523606, 0.042017415897654634, 0.028914741839149168, 0.07004163480762925, 0.0758418742833393, 0.01388447023262935, 0.08316613733768463, 0.01159994036424905, 0.03606014984792896, 0.029000973461994102, 0.025270465960992233, 0.06346089007066828, 0.06314855361623423, 0.02190786523611418, 0.009925041979710971, 0.04803223868033715, 0.03556516533717513, 0.03566866906891976, 0.0339630491632436, 0.013389451795124581, 0.04239494938935552, 0.0626770124903747, 0.0491309124045074, 0.044801295801464996, 0.031731612115566216, 0.020004252204671502, 0.06422834710351058, 0.05715531163981982, 0.055843486317566464, 0.006490770569403789, 0.004784436081536114, 0.030463046793426787, 0.006800584993990404, 0.07346096275640385, 0.03934766558398094, 0.02758581404175077, 0.03256763850471803, 0.0368008793863867, 0.02941836749336549, 0.058239970223179886, 0.06069782083587987, 0.005910550185944885, 0.014060768897512128, 0.06457326002418995, 0.04279272358066269, 0.07212565333715507, 0.04943680277626429, 0.05188313186434763, 0.026358537575496093, 0.031797816777335744, 0.056655903080744405, 0.0088807146696906, 0.06305123133850948, 0.0472043682821095, 0.02078596186558051, 0.06810835283249617, 0.08531574306211301, 0.018060498737863133, 0.02153891690873674, 0.05366655598793711, 0.09882094444973127, 0.0041301175536188695, 0.18417823421103613, 1.8394550212791987, 10.232082264763967, 28.751275777816772, 40.682449681418284, 38.45739677974156, 37.030278478349956, 31.972674301692418, 23.305406263896398, 23.513803584235056, 19.00181712423052, 22.43538757732936, 25.441704613821848, 25.74746182986668, 36.403328623090474, 37.09819711957659, 33.599285806928364, 28.599400315965923, 17.15692448616028, 10.876380034855433, 5.575938923018319, 1.8113017891134535, 1.2468311126743044, 0.26670814997383524, 0.24340408188956125, 0.15467572159000806, 0.08176224159875087, 0.31127340719103813, 0.25340180684413227, 0.3425002672842571, 0.17401356250047684, 0.09213217015245131, 0.28614312995757374, 0.39711430243083407, 0.6357333010860852, 0.20862688230616705, 0.24952107508267674, 0.30419655836054255, 0.4926851455654417, 0.12066738360694476, 0.6438592736210141, 0.14637132148657525, 0.12634657243532793, 0.2000814937055111, 0.14335507048027857, 0.29461078558649334, 0.2590590518500124, 0.1073831675041999, 0.12317668753010885, 1.0720011911221912, 2.810010233095714, 5.669419986861093, 11.211983237947736, 18.84481736591884, 31.029529299054825, 35.62016241891043, 37.63000529153006, 32.45224939073835, 29.552575043269567, 19.458070584705897, 14.762856653758458, 30.99252666745867, 47.28169584274292, 20.835523162569316, 25.309697525841848, 34.43492133276803, 35.74372223445347, 28.445683581488474, 18.89439102581569, 6.5779468928064615, 1.0516928008624484, 0.06645666967545237, 0.02130550764767187, 0.029744976931916814, 0.047566760264869244, 0.033517143090388606, 0.014697950599449021, 0.08592960012278386, 0.027161319141409228, 0.06889325500066791, 0.006237401352596602, 0.011325176938303878, 0.056548460453216515, 0.03557674453726836, 0.06071641269539084, 0.06180899656776871, 0.03484701065878783, 0.06507038192025252, 0.05197699022080217, 0.007179307618311473, 0.056551625819078515, 0.04197856976783701, 0.056156219714986425, 0.04400815621816686, 0.050027294483567984, 0.05842198045658214, 0.03963008542944278, 0.011833228337179338, 0.040270354465714524, 0.023283823991992643, 0.024664936221337745, 0.04228655681280153, 0.08546085456120116, 0.0058201786513174215, 0.06557381419198853, 0.017564581241458654, 0.009244464570656419, 0.04582706093788147, 0.013605151292202728, 0.025781918516648666, 0.035711148753762245, 0.015421567484736443, 0.02805365715175867, 0.0037234698206053247, 0.029859920764075856, 0.023759819700249603, 0.018321044310661297, 0.034545232209243944, 0.004176271081502948, 0.09061441623738833, 0.12433800021452562, 0.1530871625457491, 0.0937254721564906, 0.19681148417294025, 0.12250637635588646, 0.17293820663222245, 0.10675709681319338, 0.1528810371777841, 0.06687513579215322, 0.1521807618971382, 0.17790610077125685, 0.1847894178437335, 0.267249485211713, 0.1752591628049101, 0.11280354272042002, 0.1858544328383037, 0.14832768722304276, 0.11845765289451395, 0.1138026448232787, 0.2251057837690626, 0.11167013818132025, 0.11681163550487586, 0.22508123437208788, 0.1341026212487902, 0.24913360444562777, 0.08199093504143612, 0.12670967009450707, 0.15080368864749158, 0.13298269920051098, 0.09311698230781726, 0.13816604177866662, 0.24619758341993603, 0.08482117245772056, 0.2584626738514219, 0.15341361931392125, 0.08793185518256255, 0.1382456882191556, 0.16968251418854507, 0.11253476821418319, 0.14486897710178578, 0.12456882425716945, 0.08184559284044163, 0.07207906512277466, 0.10609665153814213, 0.10172542716775622, 0.11746065425021307, 0.17204399247254643, 0.1615560802498034, 0.14578871774886334, 0.13443523911493166, 0.21304171612220152, 0.1048529375610607, 0.06302113831043243, 0.18764911725052766, 0.15230867931885378, 0.10210477574063198, 0.17327789483325823, 1.5253173006432397, 9.477089268820626, 29.09624515260969, 45.484631129673545, 47.8010493687221, 47.56066949026925, 43.5388298034668, 35.93759434563773, 35.25154658726284, 27.27201819419861, 31.781157629830496, 31.96834557397025, 31.00128139768328, 37.50016777856009, 38.679791246141704, 32.84841135569981, 29.31830610547747, 25.943387133734568, 13.871120503970555, 6.156355823789324, 3.2337400444916318, 1.9902656716959817, 0.9674271110977445, 0.8572490374956812, 0.8656122258731297, 1.3294454110520226, 1.4625993860619408, 3.327401327235358, 2.871043860912323, 4.336415035384042, 3.2031868611063277, 3.0292851754597256, 1.8538497345788139, 3.0296931649957384, 1.947651935475213, 2.116699653012412, 3.4085586752210344, 3.4138801268168857, 2.672994145325252, 3.871714302471706, 3.0778335418019975, 3.670429766178131, 2.704180483307157, 0.3776960958327566, 1.5929567111389977, 1.8144525800432478, 0.9849304918731961, 0.7089489666478974, 2.16682374051639, 4.71834318126951, 8.48345865522112, 16.24857085091727, 26.74776097706386, 34.2235050201416, 34.76762192589896, 31.135951382773264, 31.56209829875401, 26.12283304759434, 20.77919932774135, 23.265772002083914, 40.03756652559553, 46.85855402265276, 29.668172223227366, 37.716062205178396, 41.46383367265974, 41.47948101588658, 30.484366689409526, 18.11150622367859, 5.251662152154105, 0.6301579145448548, 0.10167380422353745, 0.22045139995004448, 0.13950618915259838, 0.09158417170069047, 0.09493788531316177, 0.11728874061788831, 0.20473887664931162, 0.08903636770056826, 0.18793167280299322, 0.22939127523984226, 0.17926303510154995, 0.18760111768330845, 0.1137171019134777, 0.1949882334364312, 0.14874740184417792, 0.12653934423412594, 0.2084483868841614, 0.17828746459313802, 0.0847757581089224, 0.0890219963288733, 0.11256315133401326, 0.30330390483140945, 0.1309327906263726, 0.17488685064017773, 0.16244550395224774, 0.2438812277146748, 0.08501565416476556, 0.11348728210266147, 0.13521393947303295, 0.12591426420424665, 0.1993204081164939, 0.17380264667528017, 0.07499435011829649, 0.13825460416930063, 0.1277051352496658, 0.07047469621258122, 0.11707770265638828, 0.12100381483989102, 0.10300744444664035, 0.06946965014295918, 0.06489850900002889, 0.08934850737984691, 0.13885951813842567, 0.15439851289348944, 0.15477044507861137, 0.10323370194860867, 0.1278428371463503, 0.16123435965606145], [0.01709290610493294, 0.05629739910364151, 0.03860294286693845, 0.14683371596038342, 0.019295137309070145, 0.036998607883495946, 0.059888369270733426, 0.009538259207537132, 0.01991478566612516, 0.012320228187101228, 0.048201529774814844, 0.09854947615947042, 0.05248053105814116, 0.01739276938938669, 0.04412147156628115, 0.04476493989516582, 0.03558376398203628, 0.04634481369118605, 0.011147441475519111, 0.034952312508331876, 0.02384181896091572, 0.024006560478093367, 0.0228548354934901, 0.05423840155292835, 0.029445746381367956, 0.04535312119073101, 0.05744020135274955, 0.040728596305208545, 0.022222897170909812, 0.06500018747257334, 0.02599939577547567, 0.03010656824335456, 0.01364976751418518, 0.059521756800157685, 0.030679821768509488, 0.05136940282370363, 0.027893841798816408, 0.06563655153981277, 0.026670332898252776, 0.015769667823665907, 0.03269542361210499, 0.049412752102528296, 0.054612189531326294, 0.018960604277838553, 0.013742327324247785, 0.04252176758434091, 0.03763309240873371, 0.025399436808324287, 0.021834612291838442, 0.05841975486172097, 0.008330525397988302, 0.031438393385282586, 0.02997438283637166, 0.029213945248297284, 0.08744289606277432, 0.020247941271268895, 0.025228218674393635, 0.0920385933880295, 0.044511049054563046, 0.20587397074060781, 1.341366782784462, 5.292956599167415, 19.51835141863142, 31.092184679848806, 37.11459486825125, 42.32488570894514, 32.57238721847534, 29.180168969290598, 21.656619582857402, 21.821802582059586, 26.90151940073286, 29.598728452410015, 29.719668797084264, 18.173541477748326, 17.92747449874878, 22.444168363298687, 24.500258445739746, 21.62189769744873, 19.90801681791033, 18.670784098761423, 11.74256157875061, 8.488576872008187, 4.3823456679071695, 2.7792998467172896, 1.4209525351013457, 1.2088700639350074, 0.32042657317859785, 0.10143094975501299, 0.042096200598669906, 0.15469202000115598, 0.21752562480313437, 0.0034119893805057344, 0.22225601811494144, 0.040273553758327446, 0.014474856767005153, 0.05874570272862911, 0.2035626769065857, 0.1534231730869838, 0.10340358676122767, 0.12929739909512655, 0.7197423417653356, 1.822305564369474, 3.038566883121218, 3.759090951510838, 7.895839078085763, 13.823308212416512, 17.340973581586564, 20.153262172426494, 24.865301166261943, 25.827446017946514, 25.001711675098964, 18.807806049074443, 26.824627161026, 19.179842131478445, 16.63480384009225, 15.99509882926941, 18.653790542057582, 18.3191705090659, 26.330071755817958, 29.80145604269845, 33.93523815699986, 28.121334723063878, 22.096037558146886, 14.149276001112801, 4.6220954316002985, 0.5788037787590707, 0.061659284601254125, 0.05552351973684771, 0.035919347046209235, 0.040666690162782154, 0.04111837735399604, 0.10860939563385077, 0.05251738568767905, 0.024589014938101172, 0.05033052160537668, 0.054815190245530436, 0.06051496921905449, 0.0195728820482535, 0.06397939260516848, 0.056056061160883734, 0.04886326087372644, 0.042143901610480886, 0.08919272252491542, 0.06932938338390418, 0.08918774207787854, 0.023554291443101, 0.04714203805529645, 0.048218140312071354, 0.01011460430787078, 0.044170475365327935, 0.05156700239915933, 0.020327010956991996, 0.07474673233394112, 0.04929125701476421, 0.055594060237386396, 0.031587589665183, 0.026913543597662022, 0.0544083610043994, 0.03545949707872101, 0.057186598889529705, 0.030967242417058775, 0.06832947382437331, 0.06443825191152946, 0.037939552749906263, 0.03648536399539028, 0.05891482079667704, 0.024193820876202414, 0.05455566756427288, 0.036736737471073866, 0.023555176931300333, 0.006064371954250548, 0.07508703800184385, 0.0415519001627607, 0.032328458303319554, 0.07122882681765727, 0.049875540126647265, 0.016326855335916792, 0.03957772966740387, 0.006615844929391252, 0.049997293057718446, 0.01790427622784461, 0.02108734506847603, 0.06505204790404864, 0.03315037455675857, 0.042267747822084596, 0.026904088212177157, 0.010893817808079933, 0.009586212973642563, 0.046292644526277266, 0.07017814248268094, 0.0118370747825663, 0.05596644704097083, 0.043689780802066834, 0.030336737499705384, 0.026892620970361998, 0.014097676961682737, 0.10841955510633332, 0.04091194325259753, 0.010605482833593019, 0.0159654879410352, 0.038481535988726785, 0.026243887209732617, 0.012213579445545162, 0.03165689862466284, 0.027939456315445046, 0.0588886361303074, 0.027969644338424717, 0.04905563233686345, 0.03649863274767995, 0.005702560543016131, 0.04668098368815013, 0.07836002630314656, 0.013268631849704044, 0.022885937842407396, 0.02483784221112728, 0.03169359040579625, 0.01028298192457961, 0.028280491408492838, 0.0647756534495524, 0.013560904023636664, 0.02599738391914538, 0.03599313772948725, 0.04261762083375028, 0.03510269283183983, 0.05283950322440692, 0.012302040055926357, 0.02504538741361882, 0.03188877100391047, 0.05186282331123948, 0.017769939864852598, 0.038825230939047675, 0.04468228075919407, 0.0381732809224299, 0.06497100368142128, 0.03301945461758545, 0.30109904600041254, 3.191627881356648, 11.009827136993408, 28.825274092810496, 38.5605080468314, 42.04021801267351, 43.33387531552996, 33.48051677431379, 27.70601831163679, 23.678173644202097, 22.989494255610875, 26.240024839128765, 27.79276830809457, 30.408308233533585, 23.626871619905742, 24.155070202691213, 35.65752288273403, 31.684379645756312, 25.779244627271378, 24.47752915109907, 14.06507078238896, 10.979789205959865, 7.5615351881299695, 3.3959181649344305, 2.8039522724492207, 1.431397523198809, 1.1335295523915971, 0.6093662987862314, 0.2193429587142808, 0.09383052294807774, 0.13669252156146935, 0.052208078892103264, 0.03826758711199675, 0.09697510528245143, 0.10588665852057082, 0.038508701138198376, 0.10936598253569432, 0.10183235750134502, 0.2207350954413414, 0.05805861816874572, 0.23574879552636827, 0.5191122932093484, 1.1623152877603258, 2.7301895448139737, 5.647199647767203, 8.890517132622854, 15.781749180385045, 21.10687289919172, 26.76325719697135, 32.53812565122332, 34.803842885153635, 36.697140148707796, 30.025118555341447, 30.181067398616246, 18.63513810294015, 16.66948229925973, 12.444197620664324, 12.153537103107997, 12.287547877856664, 25.981826305389404, 34.07279511860439, 32.610755171094624, 33.567678451538086, 26.083318642207555, 20.60162247930254, 8.38555680002485, 1.692323224885123, 0.2126768542719739, 0.03606598185641425, 0.017548893511827503, 0.05217898670317871, 0.01776872867984431, 0.062306959847254414, 0.023186635724934082, 0.008027190558745392, 0.09562991639333111, 0.051769202442041466, 0.029289126928363527, 0.0760694413578936, 0.0881107577255794, 0.06185763395790543, 0.029810553948794092, 0.04768992454877921, 0.06289999945355312, 0.040267572472138066, 0.07345906285835163, 0.07001321776104824, 0.026155681049983417, 0.010046425957365759, 0.06245779139654977, 0.02938414897237505, 0.03127324474709375, 0.06292020622640848, 0.08030845996524606, 0.07917161525360175, 0.04687170631119183, 0.0381812129967979, 0.02901646780914494, 0.017118922833885466, 0.042863861192017794, 0.05041915184951254, 0.04456160669880254, 0.04060699604451656, 0.06401529389300517, 0.06241068071020501, 0.013957668894103594, 0.07722068458263363, 0.033807535722319565, 0.04631698697007128, 0.04824507136696151, 0.012970989071098822, 0.02559970472274082, 0.09494244506848709, 0.057938605679997375, 0.03853375604376197, 0.060018681921064854, 0.05923653460506882, 0.06174061380858932, 0.28242364525794983, 0.12156307697296143, 0.28523022894348415, 0.07330826523580722, 0.10389114809887749, 0.13709102517792157, 0.1810694174574954, 0.14942037287567342, 0.08569441988532032, 0.20611844690782682, 0.15331572028143065, 0.13304943990494522, 0.19261793419718742, 0.13278899102338723, 0.12410676905087062, 0.10823269334754773, 0.17796267702111176, 0.13040117200996193, 0.09466004557907581, 0.19583790855748312, 0.2209616582840681, 0.07223270580704723, 0.11175632569938898, 0.1401285957545042, 0.06846235812242542, 0.12481940723955631, 0.13465099968016148, 0.17521634724523338, 0.12260005490056106, 0.1524646066661392, 0.1270275908921446, 0.12953375998352254, 0.16936008791838372, 0.1975108366459608, 0.15823927894234657, 0.08629287420106785, 0.1344851657216038, 0.14616159988301142, 0.11043736218873944, 0.1144699433020183, 0.17868134060076304, 0.20825971343687602, 0.10939914254205567, 0.11082834085183484, 0.11120815761387348, 0.08820339132632528, 0.08762551697769336, 0.1485962513834238, 0.18958932028285094, 0.11283696735543863, 0.11933214882654802, 0.1662748163299901, 0.10885121872914688, 0.18241428743515695, 0.14946825030658925, 0.13005207931356771, 0.14412687692259038, 0.1542680441801037, 0.39959676350866047, 2.3819638533251624, 10.317537290709359, 29.74349069595337, 42.748632022312705, 51.627047130039756, 56.154017380305696, 44.8509658404759, 40.16899170194353, 34.218165329524446, 30.231896945408412, 36.13240098953247, 38.77695138113839, 41.178558009011404, 27.10879806109837, 25.4113027708871, 32.96900429044451, 32.91931772232056, 32.11221497399466, 29.576761722564697, 26.123546974999563, 16.724001339503697, 12.031406879425049, 6.272045935903277, 4.024277635983058, 2.3087124696799686, 1.7136809016977037, 0.9649164229631424, 0.3196174608809607, 0.2007333351565259, 0.4662509954401425, 0.8398536794951984, 0.2520846618073327, 0.5994156641619546, 0.2520846075245312, 0.3266977295279503, 0.39535168558359146, 0.46881401219538277, 0.4123339514647211, 0.47682675080639975, 0.46210813203028267, 1.0827333352395465, 2.682938971689769, 4.678201700959887, 5.909647439207349, 10.706878730228969, 19.456583670207433, 23.95723761831011, 26.71240680558341, 33.93560988562447, 34.35891498838152, 33.97112212862287, 27.080334765570505, 35.28241048540388, 27.193767581667217, 23.44180461338588, 23.13214945793152, 26.319095339093888, 26.317097731998988, 34.755014419555664, 39.91617454801287, 44.630912917000906, 41.72125053405762, 32.138416630881174, 20.856836761747086, 6.731343141623905, 0.9704380695308957, 0.17253438330122403, 0.1527662290526288, 0.19814867313419068, 0.11418236659041472, 0.10155358138893332, 0.23759875340121134, 0.11802755668759346, 0.15502828838569777, 0.18849535898438521, 0.18109550034361227, 0.20074605090277536, 0.13180510167564663, 0.1314388420432806, 0.1336794053869588, 0.1974380434091602, 0.11480146194142954, 0.29749754496983116, 0.1285716923219817, 0.26769935392907684, 0.1673346066049167, 0.13438136343445095, 0.12779152632824012, 0.20209343146000588, 0.14072106539138726, 0.13113143853843212, 0.24672119532312664, 0.2581189551523754, 0.20286403010998452, 0.21545762648539885, 0.1739289763250521, 0.20586120071155684, 0.11748538006629262, 0.1123357606785638, 0.277060151632343, 0.16152948167707237, 0.15711790482912744, 0.19535860499101027, 0.22031988629273005, 0.1293566216315542, 0.1824419852346182, 0.0839139779231378, 0.08796823823026248, 0.19409585132130555, 0.08654368788536106, 0.10709189956209489, 0.22507774670209202, 0.16865850985050201, 0.2156339641660452, 0.19849703301276478, 0.13776973661567482], [0.12912604186151708, 0.018982376770249436, 0.024592119235811487, 0.03849949681067041, 0.038910651712545326, 0.028018001832866242, 0.026706449620957886, 0.035781187138387134, 0.01586234722552555, 0.053279777456607134, 0.051148872157292705, 0.04378048057800957, 0.04389553636844669, 0.05476392013952136, 0.11388239982937064, 0.005220885072568697, 0.026952058941658055, 0.0319003535966788, 0.012596983113326132, 0.05846995288240058, 0.03305529144459537, 0.038436186100755415, 0.036407481745949814, 0.024610700917297175, 0.04326085846072861, 0.009011671080120971, 0.03541324473917484, 0.060383163791682036, 0.022661546311740364, 0.012065213522873819, 0.026771599160773412, 0.01894171386291938, 0.07477181098823037, 0.05417603061401418, 0.021884572825261524, 0.04522953960778458, 0.036299445400280614, 0.03383923348571573, 0.03682825827438917, 0.016032627284792916, 0.032529901779655895, 0.051648518203624656, 0.04929352332172649, 0.019773365397538458, 0.1007940157183579, 0.027818234338025962, 0.0022513467494198786, 0.04101850717727627, 0.01657786749170295, 0.015604551415890455, 0.01866179102632616, 0.06268898863345385, 0.05732478254607745, 0.0249631404876709, 0.02836453984491527, 0.027683892886021307, 0.024076776978160654, 0.05701047155473914, 0.021492069154711704, 0.0505342856714768, 0.03136170535747494, 0.38697720638343264, 0.356546512139695, 5.204384871891566, 14.290613651275635, 20.80670550891331, 31.200378554207937, 43.84625285012381, 44.24283518110003, 36.72683674948556, 29.054528168269567, 33.64564071382795, 36.51925236838204, 32.67446320397513, 27.946106365748815, 19.210200548171997, 25.469005823135376, 21.644126721790858, 14.776355266571045, 50.82601363318307, 40.74797814232962, 28.332447052001953, 26.75961286681039, 19.464273588997976, 18.65269272668021, 13.299398405211312, 13.886951974460057, 10.798251884324209, 9.371094499315534, 8.083654965673174, 6.919413506984711, 7.253296162400927, 6.074078295912061, 5.860847634928567, 5.9997173718043735, 7.021718783038003, 7.2004885503223965, 9.205194098608834, 11.93224913733346, 15.762665952954974, 15.084130934306554, 15.423176969800677, 20.218929597309657, 23.763848406927927, 22.934181383677892, 19.337409905024938, 25.312520231519425, 23.031982489994594, 19.26950168609619, 20.952768802642822, 19.435919727597916, 19.998876673834665, 25.78846836090088, 31.87820311955043, 27.144098384039744, 31.644844395773752, 33.926542486463276, 34.15557248251778, 31.6034574508667, 31.984837123325892, 30.302699089050293, 15.456662075860159, 4.763460874557495, 0.9264089635440281, 0.036164905476783, 0.01824830874933728, 0.022325425508565137, 0.03993296649839197, 0.00676567606361849, 0.009534672301794802, 0.09951668711645262, 0.0544421995457794, 0.029903411466096128, 0.0029442262104047196, 0.07617002060370785, 0.029465108378125087, 0.11492943364594664, 0.0339653595749821, 0.018858340568840504, 0.04750983796215483, 0.05456965556368232, 0.056032862048596144, 0.07185089415205376, 0.033704330545983145, 0.030297446929450546, 0.03477660247257777, 0.009236322150432637, 0.07933166130845036, 0.041871334093489816, 0.04439722141250968, 0.04122657994074481, 0.05038014965664063, 0.027312417015699402, 0.025411577496145452, 0.019840682856738567, 0.04030583506183965, 0.06391628206308399, 0.03432739871953215, 0.04215504994083728, 0.03380183942083802, 0.024009949760511518, 0.005888946479119892, 0.02741976295198713, 0.04121811182371207, 0.035136470305068154, 0.058260244849537096, 0.0671285211241671, 0.02251012104430369, 0.05201867601967283, 0.030176779654409205, 0.04274395726887243, 0.021575242280960083, 0.07222604937851429, 0.06926157059414045, 0.05770638385521514, 0.0390248762975846, 0.034772666969469616, 0.020896057565031306, 0.026310000269274627, 0.05602033629215189, 0.036669426797223945, 0.07942956034094095, 0.07645979576877185, 0.05713205145938056, 0.022913072457803146, 0.0623989352690322, 0.010911901614495685, 0.014737139389451061, 0.005665607525900538, 0.07551548536866903, 0.10333658821348633, 0.017386586239029254, 0.04320914391428232, 0.050136134893234284, 0.09166683762201241, 0.021534004315201725, 0.0052214215393178165, 0.03193859922300492, 0.019643873774579594, 0.018113862124404738, 0.08147372850882155, 0.007839460275135934, 0.0684443430176803, 0.04615957023841994, 0.015348306058772972, 0.018181868296648775, 0.05947018135339022, 0.07519345943416868, 0.039792899907167466, 0.019895430454718213, 0.040953744402421374, 0.027094819316906587, 0.040199433985565386, 0.08962241839617491, 0.03410759747826627, 0.03601877956784197, 0.033900159145040173, 0.008556665852665901, 0.026846377112503563, 0.04616261686065367, 0.048431244412703175, 0.019222880114934275, 0.020985345988135253, 0.01729333177874131, 0.022410997256104435, 0.027129792708105276, 0.03944005151944501, 0.0812470910272428, 0.07677212543785572, 0.04404560795852116, 0.06151122147483485, 0.044909332147134204, 0.008693528910433608, 0.024523444706574082, 0.014512647774868777, 0.039688965305686, 0.03672633892191308, 0.43393185681530405, 2.179444057600839, 10.304023912974767, 21.56225609779358, 30.590986796787806, 39.18802070617676, 48.11119958332607, 44.27126720973423, 34.7813515663147, 33.49613632474627, 36.09842777252197, 38.16055931363787, 24.028013706207275, 19.21553155354091, 19.31069929259164, 23.799119200025284, 25.73844654219491, 25.266679491315568, 56.573052815028596, 39.04601342337472, 32.089435304914204, 31.99296998977661, 26.28572314126151, 20.812418665204728, 15.544504676546369, 14.47616182054792, 11.816076125417437, 10.300257120813642, 8.926970856530325, 8.20676749093192, 9.537883400917053, 8.432575259889875, 6.914627066680363, 7.190081885882786, 8.638278416224889, 9.639320152146475, 9.488822170666285, 10.474858403205872, 15.064689874649048, 22.952832085745676, 24.628551721572876, 28.31181263923645, 29.91596235547747, 32.855456829071045, 30.40836034502302, 32.481827872140066, 28.674482549939835, 23.70752283505031, 25.153807742255076, 20.67705386025565, 16.632879189082555, 24.40826777049473, 25.283435072217667, 21.943894590650284, 30.36075128827776, 30.61585439954485, 34.32730415889195, 34.48284305844988, 36.46239525931222, 37.349582944597515, 22.720157759530203, 9.489921723093305, 2.716601473944528, 0.3276177958718368, 0.01314893996875201, 0.026178133773750493, 0.022104703156011443, 0.0596119137480855, 0.04277955660862582, 0.08560236982469048, 0.028619538393935988, 0.022919759420411925, 0.0176061024955873, 0.06177630475057023, 0.04111099150031805, 0.05282884343926396, 0.041236435661890676, 0.048803766923291345, 0.035447782171624045, 0.04102538752236536, 0.03734122735581227, 0.03814438211598566, 0.07031112856098584, 0.013705862004176846, 0.030955754819193056, 0.02884686119588358, 0.12679452768393926, 0.048295126895287206, 0.038841471674719026, 0.01754703262953886, 0.0337406491328563, 0.030588820044483458, 0.038253317520554574, 0.04373120875763042, 0.039969665064875565, 0.020289264053904583, 0.01920982001216284, 0.02035458492381232, 0.02116945119840758, 0.04848973752398576, 0.058115350481654914, 0.04799947561696172, 0.03684513004762786, 0.0521105666245733, 0.017719624796882272, 0.019097456309412206, 0.01306329358236066, 0.03487987210974097, 0.018203684893835868, 0.04320642298885754, 0.03925968334078789, 0.09996348207018205, 0.028151305126292363, 0.027818588872573206, 0.07410914011831794, 0.26946302929094856, 0.06641676503100566, 0.1564191494669233, 0.19679799489676952, 0.1232119577803782, 0.12075446679123811, 0.19006941094994545, 0.10264073019581181, 0.1325912116361516, 0.1339949241706303, 0.11528041266969272, 0.14250392972358636, 0.12612121738493443, 0.12802426383963653, 0.3103941615138735, 0.10510256380907126, 0.14859570855540888, 0.08682433675442423, 0.14728165763829434, 0.1655070132442883, 0.14161283682499612, 0.13736361983631337, 0.1474446417497737, 0.15115887458835328, 0.14960957558027335, 0.1213458100599902, 0.159488014078566, 0.18906735043440545, 0.10354709691767182, 0.12360542666699205, 0.18871121454451764, 0.16685887213264192, 0.1769915712731225, 0.16264575320695127, 0.1571382473089865, 0.08736846755657877, 0.14182406477630138, 0.17388986556657723, 0.14893494892333234, 0.10763803882790463, 0.128045420561518, 0.1276117009775979, 0.09007438378674643, 0.16664381724383148, 0.12490286704685007, 0.10538334838513817, 0.08841911117945399, 0.06610809945102249, 0.14163761692387716, 0.08705735246517829, 0.11193294836474316, 0.1287946453584092, 0.2891781356717859, 0.16772175154515676, 0.12871799804270267, 0.19410228383328232, 0.10837993544659444, 0.11192838860941784, 0.07812534139624663, 0.10856487695127726, 0.1432738226971456, 0.3911441984985556, 1.4627473609788078, 9.1866580418178, 20.702998433794292, 31.97876787185669, 44.52111400876726, 58.23075403485979, 58.087996346609934, 50.81854084559849, 43.62137787682669, 45.82402631214687, 48.12069777079991, 41.67446483884539, 37.41383293696812, 30.587849685123988, 34.22087165287563, 28.43485655103411, 21.26303366252354, 63.716148376464844, 53.099339144570486, 38.27847024372646, 37.47234371730259, 27.18667868205479, 25.214003460747854, 19.331922565187725, 19.040021794182913, 14.666401760918752, 12.974717770303998, 10.887914044516426, 10.46986699104309, 10.099982244627816, 9.718254293714251, 8.52479088306427, 8.44123705795833, 9.828020198004586, 10.850511022976466, 13.051301683698382, 16.373410872050695, 21.42727518081665, 21.504824025290354, 23.40770980290004, 28.34038884299142, 33.58773790087019, 31.01414598737444, 28.530941452298844, 33.85661928994315, 30.2641087940761, 27.03505335535322, 29.591342517307826, 28.42933620725359, 29.71539565495082, 35.4570951461792, 41.468690463474815, 37.10913011005947, 43.35053709575108, 44.24568394252232, 45.837158407483784, 43.00998503821236, 44.878383432115825, 40.89545713152204, 24.200064999716624, 7.811025023460388, 1.6880337979112352, 0.19359825445072992, 0.13641609996557236, 0.17450138846678392, 0.14002767045583042, 0.1272878497838974, 0.0906847667481218, 0.21841654128261975, 0.17612886827971252, 0.08724426850676537, 0.07877169349896056, 0.1588586728487696, 0.07352192234247923, 0.2973277483667646, 0.15177915059030056, 0.12814409312392983, 0.21565787574010237, 0.10575844254344702, 0.08130305659558092, 0.16454661477889332, 0.21810707503131457, 0.12282467713313443, 0.14537091659648077, 0.16154135603989872, 0.26225104342613903, 0.12911309541336127, 0.07352277729660273, 0.1921126970223018, 0.16124062931963376, 0.14435904446457112, 0.24532805436423846, 0.10276045091450214, 0.14536229920174393, 0.0952029957302979, 0.15698465412216528, 0.0975925110812698, 0.13779362104833126, 0.13187473293926033, 0.1543366847825902, 0.12283148962472167, 0.1460139506629535, 0.13513653219810554, 0.19457592841769966, 0.081172289326787, 0.16966249740549497, 0.23474836349487305, 0.13815143970506533, 0.1240763571113348, 0.16358158870467118, 0.25095555239490097, 0.09631641741309847, 0.1406091885375125, 0.1482053745005812], [0.03768896298216922, 0.06314387850995574, 0.014313853977780257, 0.023751360064904605, 0.00691392451491473, 0.019525045329438787, 0.017931680560910275, 0.017088510894349644, 0.014475652349314519, 0.015406593913212419, 0.05782910369868789, 0.022722607678068534, 0.03934493108785578, 0.022571447039289132, 0.03895897019122328, 0.011506422123472606, 0.031519620812364986, 0.038179635402879546, 0.06991790394697871, 0.03391621667625649, 0.04878951429522463, 0.0364874097784715, 0.01772751276647406, 0.009471287801196533, 0.03724382704656039, 0.036994896296943934, 0.06967056436198098, 0.008659498682910842, 0.045647249157939634, 0.021507517700748782, 0.04718663816207221, 0.02476624658863459, 0.08351701458117791, 0.03131143269794328, 0.016066072275862098, 0.007882492117849844, 0.013782565299022411, 0.03741969993071897, 0.01383351903807904, 0.0505039653341685, 0.08382279638733182, 0.03973120411059686, 0.10532753209450416, 0.05855805386922189, 0.025866168817239146, 0.02719056569705052, 0.027602536537285362, 0.10194127594253846, 0.006477936503610441, 0.028063037898391485, 0.027593252481892705, 0.03393739036151341, 0.06419829478753464, 0.10126982482948474, 0.04066987927736981, 0.03959323758525508, 0.04533161502331495, 0.029211828219039098, 0.00676604501703488, 0.08327526612473385, 0.0711052588054112, 0.13326331414282322, 0.06575694400817156, 0.11563300660678319, 0.6867077286754335, 2.4360047706535886, 5.376891706671033, 10.070421133722578, 18.404275519507273, 33.90932832445417, 40.339354583195274, 39.30244711467198, 40.47487572261265, 37.92649187360491, 38.75760759626116, 36.127884660448345, 34.86783926827567, 26.915264674595424, 22.89222468648638, 28.278205939701625, 80.2336562020438, 41.46189859935215, 17.30416897365025, 20.04620780263628, 19.81926052910941, 22.334544897079468, 19.38556092126029, 17.486811058861868, 18.32215997150966, 19.785883120128087, 20.05401757785252, 15.354148353849139, 21.85811734199524, 18.055741718837194, 19.744523968015397, 18.58675605910165, 21.245522465024674, 24.416468381881714, 43.38037266050066, 32.98394986561367, 16.316520759037562, 18.03945514133998, 17.111955744879587, 21.591726882117136, 22.89577521596636, 24.818065575190953, 32.7388139452253, 27.225736243384226, 27.417393616267614, 28.456703424453735, 29.137060608182633, 34.117148944309776, 35.19610343660627, 39.730810506003245, 37.22858006613595, 35.35420274734497, 32.74540778568813, 26.319147450583323, 21.752044405255997, 16.967249086924962, 5.281350936208453, 0.7212125371609415, 0.04045542149937578, 0.026935144759980694, 0.021505568608907715, 0.0526773096062243, 0.03746269530217562, 0.09000513928809337, 0.043293801335883994, 0.01983545983343252, 0.06530169450810977, 0.043547851632216146, 0.04472923877515963, 0.06060355196573904, 0.0583172757178545, 0.030114822621856416, 0.05157903961039015, 0.03208713732393725, 0.03703224625704544, 0.03938487644440361, 0.06479972787201405, 0.02935074469340699, 0.03860283430133547, 0.05602772553850498, 0.027650619225044335, 0.02153503229575498, 0.039615313722086806, 0.07084419924233641, 0.02472049297232713, 0.025156327889167836, 0.024176725186407566, 0.006678419428811009, 0.06613855888800961, 0.011275012844375201, 0.08600617279963833, 0.02019985349449728, 0.012239999902833785, 0.053795508175556145, 0.023369234587465013, 0.018570058180817535, 0.013802213976824922, 0.07791880890727043, 0.02205422523963664, 0.06016236171126366, 0.029168364658419575, 0.025548164899061834, 0.021713188450251306, 0.050312604888209274, 0.0381354763438659, 0.012628862384839781, 0.007220728788524866, 0.009752452356873878, 0.013844350153314216, 0.025292679501165236, 0.034980146014796834, 0.10723374052239315, 0.027265296151329364, 0.014805574735094394, 0.04437760157244546, 0.040795214873339446, 0.025120228129838194, 0.05233232204669288, 0.02297506172076932, 0.06417178442435605, 0.03209546294861606, 0.03812991574938808, 0.02284789577658687, 0.0502212706820241, 0.007716005917505494, 0.028057187230193188, 0.005094944732263684, 0.04006520279550126, 0.0715405186638236, 0.054803007149270604, 0.07123816345951386, 0.05401345362354602, 0.03274454954745514, 0.005628221942710557, 0.02205180626229516, 0.01799807181980993, 0.048787271736988, 0.014162213275475162, 0.03694605195362653, 0.019841522543824146, 0.03281328853751932, 0.03186246080856238, 0.06074584075914962, 0.07067213633230754, 0.015747966577431986, 0.008718577030647014, 0.03876018657216004, 0.0568171060377998, 0.053194790945521424, 0.03833410729254995, 0.03804753142009888, 0.05646634753793478, 0.04240333947486111, 0.03800198136429701, 0.05425173815871988, 0.011826401426722961, 0.014757746497967413, 0.028037223033607006, 0.01981797907501459, 0.07108137437275477, 0.040526107884943485, 0.07489124672221285, 0.042517679410853555, 0.03898822183587721, 0.05910752474197319, 0.029430475950773274, 0.08124549646994897, 0.05775527908865895, 0.056099762208759785, 0.04197925848088094, 0.015416727833715933, 0.008914420048573186, 0.019605051393487623, 0.09142231395734207, 0.055772562444742234, 0.11997362226247787, 1.9013662934303284, 5.357920953205653, 11.188203028270177, 21.026030608585902, 29.34127685001918, 42.99832248687744, 44.754986899239675, 44.85813985552107, 44.90480048315865, 45.41124425615583, 41.13447863715035, 35.295834405081614, 28.855785369873047, 22.415748494012014, 15.209073441369192, 39.586267130715505, 71.50673961639404, 40.77176877430507, 26.41583510807582, 28.432454211371287, 29.705386774880544, 30.819412299564906, 32.95311376026699, 27.556423595973424, 30.37420994894845, 29.12852300916399, 27.322399582181657, 26.993398904800415, 29.68580675125122, 26.95620346069336, 29.939645290374756, 28.896991661616735, 29.653000831604004, 33.49043532780239, 43.99299185616629, 39.17392628533499, 25.5993401323046, 21.92552007947649, 22.48839017323085, 23.954388856887817, 21.385269846235, 19.824661016464233, 26.892045531954082, 21.246260711124965, 22.10973593166896, 24.503256593431743, 27.056036915097916, 32.94666930607387, 36.37902035032, 42.91269636154175, 41.91235726220267, 40.020581654139924, 39.22825425011771, 33.845436164310996, 31.035716669900076, 23.118239164352417, 10.099328245435442, 2.6502207730497633, 0.23803817267928803, 0.10632160625287465, 0.0880396201142243, 0.09218312134700161, 0.04951435932889581, 0.06090046531919922, 0.02521878873397197, 0.025251514477921382, 0.041552853504461904, 0.04319000244140625, 0.02468597928860358, 0.037567990366369486, 0.06715546574975763, 0.037234951808516464, 0.022323853003659418, 0.03994679164939693, 0.03452591770993812, 0.03879464936575719, 0.021591276063450744, 0.032547078893652985, 0.05174366577661463, 0.018398880758988004, 0.01621112779581121, 0.06049115263989993, 0.0018061628922753567, 0.04106740919607026, 0.00893083296250552, 0.04138545552268624, 0.04754155608160155, 0.023239703948742578, 0.024154470934133445, 0.05791381201041596, 0.04981770858700786, 0.09374498682362692, 0.04495021727468286, 0.020856020606255958, 0.018408770406884805, 0.014224036297361766, 0.06397030702126877, 0.05354285566136241, 0.025172392205734338, 0.042154038923659494, 0.00490208260349131, 0.013921620024900352, 0.0700834800622293, 0.017767498835123012, 0.03467476115162883, 0.033957332505711486, 0.024016048093991618, 0.031323720967131, 0.004756407496253294, 0.02213013804118548, 0.011296555483048516, 0.09510948681937796, 0.18071690494460718, 0.08944437759263174, 0.13766531007630484, 0.2072407981114728, 0.08419989222394568, 0.10806649298007999, 0.1214620295379843, 0.20583291937197956, 0.09711372320141111, 0.12529506028762885, 0.09441479588193552, 0.12368702728833471, 0.13887402521712439, 0.11637058774275438, 0.10088362305292062, 0.13498148694634438, 0.22254017501005105, 0.20088072653327668, 0.23775071810398782, 0.1664858814328909, 0.11228262460125343, 0.1012005599747811, 0.11849934208605971, 0.07450041055147137, 0.09901890025607177, 0.09447867995394127, 0.16071935157690728, 0.05113497915278588, 0.13336917917643273, 0.11327702445643288, 0.2321832568517753, 0.1667162983545235, 0.14123810907559736, 0.14203112652259214, 0.10657674220523664, 0.1327312205518995, 0.1338570322841406, 0.13927862207804406, 0.10576529574713536, 0.12723685109189578, 0.2273953373410872, 0.10628075844475202, 0.14510395377874374, 0.11073160211422614, 0.18585591204464436, 0.17807994144303457, 0.1816413817661149, 0.18307927889483316, 0.09876029698976449, 0.08877737766930036, 0.10469553100743464, 0.1237754946840661, 0.17025434279016086, 0.14826342995677674, 0.19507961853274278, 0.11754826669182096, 0.1321828964033297, 0.09205124128077712, 0.06566597960357155, 0.2573928955410208, 0.14145901293626853, 0.19739586567240103, 0.10856646472322089, 0.20534726471773215, 1.184751998100962, 4.6663641418729505, 9.39330528463636, 19.641112191336497, 30.0831846509661, 44.92839656557356, 52.26441580908639, 55.49237516948155, 55.538063049316406, 52.69882065909249, 50.40684618268694, 49.01760598591396, 47.90183993748256, 36.08783176967076, 28.081914118358068, 35.141052859170095, 87.72157001495361, 50.57936647960118, 25.086688143866404, 27.70968869754246, 28.30102903502328, 30.991800580705913, 29.359345640454972, 26.01198148727417, 27.139978102275304, 30.226658003670828, 31.446393421718053, 24.704733507973806, 30.53379270008632, 26.88529188292367, 28.98587301799229, 29.45119387762887, 31.638639654432023, 33.28843035016741, 56.73473392214094, 45.261058943612234, 22.55008670261928, 24.57661393710545, 24.217404229300364, 29.168690545218332, 29.49654129573277, 32.229125363486155, 41.51016426086426, 36.261057308741975, 36.81193481172834, 37.87821578979492, 40.83079719543457, 46.513353620256694, 49.34475844247, 53.05297381537301, 49.44387102127075, 48.21276487622942, 43.45083434241158, 38.186795711517334, 33.197461060115266, 23.401499850409373, 8.753010545458112, 2.1843108364513943, 0.22621924616396427, 0.1593078358897141, 0.2336802679513182, 0.21878799849322864, 0.08498956449329853, 0.18563141194837435, 0.0976019020059279, 0.07311431278607675, 0.12239497447652475, 0.1212901294763599, 0.19198534957000188, 0.14356009662151337, 0.20419265595929964, 0.16105526712323937, 0.12602246339832032, 0.1710290533623525, 0.0868333341287715, 0.1164006604147809, 0.09369016797947032, 0.1306374921862568, 0.10005338117480278, 0.14413280731865338, 0.14714105161173002, 0.11465667613915034, 0.13024035921054228, 0.09951999158199344, 0.08576333868716444, 0.060952603950032165, 0.09929137956351042, 0.09748432545789651, 0.13002203378294194, 0.14692430038537296, 0.14704022130795888, 0.15172760907028401, 0.07091812563261815, 0.19252720049449376, 0.07576839572616986, 0.12474343845886843, 0.15081351383456162, 0.12264178480420794, 0.07491428977144615, 0.21232378536037036, 0.07829948740878276, 0.09524619805493525, 0.08861707377114467, 0.11120395069675786, 0.10461079555430583, 0.14592689462006092, 0.18771000898310117, 0.08664177690765687, 0.15676019473799638, 0.1720220757914441, 0.1246708080704723, 0.20614370198122092], [0.02934816965301122, 0.04857225416760359, 0.031507044165794335, 0.04260984821511166, 0.015913120304633464, 0.05278074209179197, 0.04306059902799981, 0.014158009751034635, 0.007381687472973551, 0.037329054437577724, 0.05638717607195888, 0.0244863356264042, 0.07543624604919127, 0.0671280190082533, 0.035839164563055546, 0.024081424943038394, 0.08802678901702166, 0.04787102893793157, 0.046726771231208525, 0.03177856334618159, 0.03884784311854413, 0.045516203689788065, 0.05267343517126782, 0.030887914888028587, 0.039515223021485975, 0.06238078445728336, 0.012155211015072252, 0.044821102238659344, 0.01488502779310303, 0.010833147447556257, 0.05326233571395278, 0.0629790894953268, 0.043333573666002066, 0.005458888439794204, 0.017314222175627947, 0.12500695431871073, 0.004525756904123617, 0.014581145885001336, 0.05298897770366498, 0.009947906913501876, 0.016213563736528158, 0.053420929703861475, 0.012625894642301967, 0.007443190735232617, 0.055458336270281246, 0.02251537629802312, 0.029992404726466963, 0.010645295875812215, 0.04272897521566067, 0.029872161535812274, 0.01649303874000907, 0.0514680686007653, 0.045726240812135596, 0.045778053746159585, 0.03020678786560893, 0.06920959481171199, 0.03424455298643027, 0.031710533425211906, 0.03110904266525592, 0.021048224131975855, 0.0535678121793483, 0.06749784773481743, 0.022525250678882003, 0.030887996312230825, 0.06099842541984149, 0.029244425041334968, 0.3016993323607104, 0.45849018331084934, 1.3478176423481532, 3.067221471241542, 10.093228595597402, 16.13305183819362, 25.19681361743382, 22.243249041693552, 36.24563578196934, 39.587451798575266, 47.572029794965474, 47.18966695240566, 41.93084641865322, 35.402374608176096, 73.0084537778582, 43.8327316556658, 23.652086632592336, 28.73386880329677, 22.543984447206768, 23.081087146486553, 20.4308340208871, 20.612887246268137, 27.50127226965768, 21.280280828475952, 14.124518701008387, 28.727441719600133, 18.55806347302028, 16.235723631722585, 20.247398103986466, 25.524683475494385, 21.61176896095276, 26.60266521998814, 84.39061055864606, 58.69563020978655, 23.859344448362076, 28.597354071480886, 23.39243071419852, 26.102049248559133, 29.887693609510148, 37.903138978140696, 38.11031688962664, 42.34704351425171, 41.5095910344805, 42.38819422040667, 37.1598276410784, 35.50589581898281, 27.680904047829763, 17.251602377210343, 15.829516308648245, 10.24237949507577, 8.77179934297289, 4.3980933257511685, 1.3139743783644267, 0.6302954128810337, 0.1231241010661636, 0.017533953867054412, 0.011124078666658273, 0.04428996877478702, 0.055089287858988555, 0.029951499242867743, 0.06575471841331039, 0.025895011644544344, 0.03086623569418277, 0.035583658809108396, 0.036976321400808435, 0.02772842174662011, 0.07468076515942812, 0.026232852533991848, 0.07352629210799932, 0.012004887518872107, 0.025302730301128964, 0.027302150780867254, 0.02988639720050352, 0.04373912386862295, 0.011334082710423639, 0.008533846719988754, 0.012418314664890724, 0.0124127540704129, 0.05030840475644384, 0.03666712995618582, 0.044015592961971245, 0.00963032029436103, 0.03262502560392022, 0.02484555376161422, 0.07191956868129117, 0.05844821262040308, 0.04548957458298121, 0.05032966325857809, 0.039689335107271156, 0.05660867365077138, 0.08127166078026805, 0.0087050046339365, 0.05983650205390794, 0.04059289947950414, 0.01877887563646904, 0.016192123726276413, 0.030348221704896008, 0.05235719035512634, 0.009265805345161684, 0.05216343468055129, 0.06872871025864567, 0.010549391736276448, 0.027264100233358995, 0.02190448104270867, 0.0857043197112424, 0.022398451143609624, 0.07337991853377648, 0.016507420289729322, 0.025552717869036963, 0.019621602558930005, 0.05828418356499501, 0.058440999793154855, 0.04775577637233904, 0.01971871788347406, 0.021858866526080028, 0.015878745720588734, 0.020661779779142568, 0.022743703331798315, 0.051684151470128975, 0.05644161493650504, 0.023645808853741204, 0.028148574022842304, 0.052726805343159606, 0.05177747717659388, 0.02011426817625761, 0.021617642237937877, 0.03509501860077892, 0.05347246443852782, 0.05862527633351939, 0.014832325978204608, 0.029785651713609695, 0.05892179613666875, 0.04155465501493641, 0.044066103108759434, 0.08673525189182588, 0.0852774940431118, 0.01371366430872253, 0.061272166802414825, 0.03536422736942768, 0.014123851450027099, 0.0634883910949741, 0.05631165512438331, 0.050262003139193566, 0.03495609534106084, 0.03163395057033215, 0.023750228607761006, 0.033449024959866486, 0.05315257249666112, 0.04280551057308912, 0.010797765239008834, 0.017118346079119613, 0.02302220294118992, 0.01889115961135498, 0.04847885382228664, 0.0388502722739109, 0.07376022384102855, 0.01724666722917131, 0.05166052488077964, 0.06564425969762461, 0.08749979800943818, 0.02996090373822621, 0.04533171680356775, 0.07342587571058955, 0.06548792522932802, 0.009308875355470394, 0.05050016214538898, 0.020780396182090044, 0.08272132370620966, 0.011757139964694423, 0.04150110163858958, 0.023216706700623035, 0.026834443377863084, 0.023404808482155204, 0.03001317468338779, 0.020924067490601113, 0.12041036811258111, 0.40538420581391876, 1.409687116742134, 3.3366695727620805, 8.45914169720241, 18.255818571363175, 25.646844966070994, 36.48868376868111, 32.92169400623867, 44.3999547958374, 46.59438698632376, 52.79401445388794, 47.206922803606304, 33.37495974131993, 28.122574976512364, 81.86980410984584, 46.038847242082866, 17.772708586284093, 19.412379230771744, 19.016804388591222, 21.551370007651194, 17.917547260011943, 16.546097925731114, 21.207802431924, 21.568215915134974, 19.53882254873003, 19.963908127376012, 21.19149500983102, 17.232084887368337, 20.41259673663548, 23.204857145036968, 20.51604151725769, 25.29115799495152, 80.57135949816022, 51.22767162322998, 11.719312037740435, 18.866933482033865, 15.974594695227486, 19.592391422816686, 25.32509994506836, 34.64175878252302, 38.56515986578805, 39.90211834226336, 42.76792369570051, 45.04075935908726, 41.88177129200527, 42.9468537058149, 37.40584945678711, 29.09685833113534, 24.91511627605983, 19.684305667877197, 15.132811750684466, 9.007793171065194, 4.511210433074406, 1.699818268418312, 0.163009162992239, 0.007849421169209694, 0.059066358022391796, 0.03325947280973196, 0.07081886274474007, 0.037730316298880746, 0.034644162614962885, 0.02120005652042372, 0.034078559572143216, 0.04724681404020105, 0.059350528488201756, 0.065521071664989, 0.03883700352162123, 0.060549961269966195, 0.058038072128381045, 0.002628693007864058, 0.04040378498445664, 0.02344697604088911, 0.0051335283538459665, 0.026658913153888922, 0.0234954777240221, 0.042661783285439014, 0.02201178457055773, 0.022551209732357944, 0.030047308387500898, 0.05723807255604437, 0.0012291525095601433, 0.030504630812044655, 0.05710410938731261, 0.02609532536007464, 0.08160153057958398, 0.0759979034108775, 0.031757488048502376, 0.05263128796858447, 0.07046630273440055, 0.04884180559643677, 0.1000364992235388, 0.016984840921525444, 0.032186542704169235, 0.035927387686180215, 0.042959588912448714, 0.03552028363836663, 0.03888746277828302, 0.03844100030671273, 0.05553694794486676, 0.030093204496162276, 0.09958827256092004, 0.06928198771285159, 0.01857922688525702, 0.026562450919300318, 0.055227915955973525, 0.04021805977182729, 0.02291786970038499, 0.07600512980882611, 0.05421676307118364, 0.017648940107652118, 0.15603817919535296, 0.3001404388674668, 0.12663030863872596, 0.08311728281634194, 0.15558886687670434, 0.16090122610330582, 0.14164274664861815, 0.23428533119814737, 0.14675826286630972, 0.14789782171802862, 0.1848130172916821, 0.11058471285338912, 0.15909329668751784, 0.17086320583309444, 0.10333025748176233, 0.16503426432609558, 0.19338709435292653, 0.2116550076752901, 0.1299670317343303, 0.10049022201980863, 0.10670455784669944, 0.1569154571209635, 0.1348288572792496, 0.21286858112684318, 0.19498876269374574, 0.12046542444399425, 0.26907672573413166, 0.2289641781577042, 0.15582883757139954, 0.19402079177754267, 0.14888718005801949, 0.14144074677356652, 0.11483943276107311, 0.10851367469877005, 0.09745708227689777, 0.19987074072871888, 0.1361742972263268, 0.127379818420325, 0.1752557565591165, 0.07113031710364989, 0.09344557646129813, 0.12869753342654022, 0.06850208634776728, 0.16214194095560483, 0.1170293502509594, 0.16053287658308232, 0.13324061036109924, 0.22002545637743814, 0.08494896095778261, 0.17847651802003384, 0.09602099683667932, 0.13242796968136514, 0.15124659559556416, 0.21810844567205223, 0.18486014833407743, 0.116219572989004, 0.12486514049981322, 0.1182645418282066, 0.07828075305691787, 0.11875462053077561, 0.12398361494498593, 0.13557589719338076, 0.13601253447788103, 0.14147432068628923, 0.21898470579513482, 0.23132898126329693, 0.4519698689026492, 0.8892557514565331, 2.4905867789472853, 6.340377126421247, 15.979331629616873, 23.687513760157994, 38.34251873833792, 38.28036710194179, 52.60184465135847, 54.75637681143624, 62.140456744602744, 61.12052372523716, 53.713674545288086, 45.73851135798863, 80.00731863294328, 55.26673242024013, 35.00217921393258, 38.7826315334865, 33.654913084847585, 32.05114030838013, 29.96149042674473, 29.491177286420548, 37.06833723613194, 32.50360352652413, 25.269899981362478, 38.76159586225237, 25.661924294063024, 25.10917251450675, 28.518047332763672, 35.24052674429757, 28.754887104034424, 33.74138341631208, 92.07337270464215, 70.15549564361572, 34.31049994059971, 37.31557846069336, 32.0497020312718, 36.12554311752319, 39.398186343056814, 51.03672817775181, 52.131201471601216, 55.24981008257185, 54.804520879473, 56.09625005722046, 49.73048421314785, 46.549008301326204, 38.824695927756174, 27.64944086756025, 23.283764362335205, 16.701949494225637, 12.644706998552595, 7.062695349965777, 3.511617179427828, 1.063192612358502, 0.2569198752088206, 0.11603335583848612, 0.08707605289029223, 0.09463684646678822, 0.10960059280374221, 0.09801350134824004, 0.17161694967320987, 0.15640456096402236, 0.09729628304817847, 0.20482727619154112, 0.12756781333259173, 0.14720893225499562, 0.1244133176015956, 0.11922589024262768, 0.14837789881442273, 0.11801076973123209, 0.11319045017340354, 0.09440600885344402, 0.08467263435678822, 0.13420893411551202, 0.09794802271894046, 0.19789655666266168, 0.18112296744116715, 0.07589939369687013, 0.17643369335149015, 0.14662396721541882, 0.17923965278480733, 0.06417016272566148, 0.08398619440517255, 0.09190225534673248, 0.2603903646980013, 0.14075576567224093, 0.11502703412302903, 0.10233912816537277, 0.19588924651699408, 0.23624274187854358, 0.2740054412611893, 0.09255525709262916, 0.16486905461975507, 0.10919390605496508, 0.11381593732429401, 0.13625907339155674, 0.15335202190492833, 0.18686076812446117, 0.17137235136968748, 0.1941268875130585, 0.22391389629670552, 0.12607084294514997, 0.1080599586878504, 0.0635652012590851, 0.24561048778040068, 0.15173834349427903, 0.14540507404931954, 0.23222394181149347, 0.19635002607745783, 0.17696976315762314], [0.050871235983712335, 0.027954102493822575, 0.038444698322564363, 0.0445792486092874, 0.041949097599302015, 0.01954216816063438, 0.050874601517404826, 0.017273011351270334, 0.03354660847357341, 0.02999012145612921, 0.026959607643740516, 0.020895928643377762, 0.03387230188984956, 0.016710633046126792, 0.029280000632362704, 0.041849502229264805, 0.03128744648503406, 0.061825797094830444, 0.02926315939319985, 0.07310365300093379, 0.06329559894012553, 0.04719961853697896, 0.010662665524120842, 0.06612657595958028, 0.05387139892471688, 0.05375598690339497, 0.0227525225907032, 0.06724451668560505, 0.017837408298094357, 0.007887560774439147, 0.031530694503869326, 0.008886808762326837, 0.05358897568657994, 0.02577646479143628, 0.014162318448403051, 0.006191841966938227, 0.11032510535525424, 0.03718635852315596, 0.030243557678269486, 0.02683757820964924, 0.03519094648904034, 0.018531049202595438, 0.016850555448659828, 0.03446552809327841, 0.019287251035815904, 0.03890615641804678, 0.02249488962947258, 0.03268983248355133, 0.019078143506443927, 0.06503897931958948, 0.02481765070530985, 0.03554426306592567, 0.0188454636705241, 0.024557103436174135, 0.08756560912089688, 0.07059681215988738, 0.04234146047383547, 0.06818973632263285, 0.04563650794859443, 0.05968827607908419, 0.019268620160541365, 0.03280721225642732, 0.013189842059676136, 0.02919060703633087, 0.015493566835565227, 0.05361738934048584, 0.05811678897589445, 0.050538984526480944, 0.1194923102323498, 0.08193606869982821, 0.16234803918216908, 0.4136162469429629, 1.0992001316377094, 3.459697199719293, 12.194640908922468, 23.330353770937236, 29.976213659558976, 38.029637881687705, 44.509805815560476, 50.303168637411936, 47.70079728535244, 45.3649240902492, 45.236285141536165, 40.17754146030971, 40.48732342038836, 43.889859744480674, 40.18627882003784, 41.97019754137312, 43.718951429639546, 36.37101602554321, 35.06409808567592, 39.001121112278526, 37.08253935405186, 33.9393584387643, 35.7567709514073, 36.42210612978254, 38.5880263873509, 32.50374596459525, 56.206069810049875, 64.4561037336077, 39.06286975315639, 38.01993472235543, 38.608325549534385, 45.76601232801165, 40.4012838772365, 41.76124783924648, 39.517726625714985, 33.70796605518886, 22.366298164640153, 14.301559669630867, 10.357243640082222, 5.417068796498435, 2.642605330262865, 0.7060404941439629, 0.3143357442958014, 0.17117662115820817, 0.0454339041773762, 0.07796650313373123, 0.04328849519203816, 0.021872985143480555, 0.03502825075494392, 0.018297234516856924, 0.07159848591046673, 0.04311442721102919, 0.04654790600761771, 0.03969329435910497, 0.043592092115432024, 0.042495440425617356, 0.0918117252045444, 0.08405718952417374, 0.00415115086694381, 0.057975199073553085, 0.035978053896022696, 0.0113588526312794, 0.0553892783687583, 0.05460871203935572, 0.028012157950018133, 0.007687482001659061, 0.026233151089400053, 0.053734355207000456, 0.040614090128136535, 0.05773887889725821, 0.024182112754455636, 0.10519922790782792, 0.026280707912519574, 0.027175084920600057, 0.018953508497881036, 0.014343456764306341, 0.05970159572150026, 0.012344731782962168, 0.06277609217379775, 0.037469039604599984, 0.019738288529749428, 0.0069041324064268595, 0.029805217270872424, 0.010261358709872832, 0.040262592025101185, 0.025891115157199756, 0.02023502535718892, 0.00698221821637292, 0.04723798629960843, 0.03499430025528584, 0.04970097681507468, 0.049034394190779755, 0.018579885064225112, 0.02543137714798961, 0.006246840198790389, 0.022937031529311622, 0.05811734537460974, 0.02771808596194855, 0.024418422752725225, 0.02423282985442451, 0.04373892709346754, 0.019811344698869755, 0.023661942720147114, 0.04448941396549344, 0.041087785602680275, 0.04225828565124955, 0.032038927410862277, 0.016042276052758098, 0.05548572872898408, 0.058891350270382, 0.05068680338029351, 0.037856802011707, 0.019137871551460454, 0.04027609147929719, 0.021988770359062722, 0.026385265069880655, 0.02401020930015615, 0.04260941734537482, 0.02947661972471646, 0.0653313057763236, 0.03971008470814143, 0.030909587296524217, 0.018304284495700682, 0.028737796869661127, 0.10085775051265955, 0.045850117557815144, 0.06706205861909048, 0.08998341259679624, 0.06902400869876146, 0.041236113357756815, 0.06655112175004822, 0.031147118657827377, 0.02294292121327349, 0.059866947920194695, 0.013731002574786544, 0.013048250460997224, 0.0391611770194556, 0.02827236255896943, 0.01714534329117409, 0.021087085528831397, 0.06886090245097876, 0.027167651569470763, 0.019728716096973846, 0.04360479429098112, 0.03586982756054827, 0.024969683261588216, 0.01460512531256037, 0.060515179564910274, 0.006123290422172951, 0.01903164859062859, 0.030304771714976857, 0.031182989411588227, 0.04013889169852648, 0.010202548383469028, 0.023212632097836052, 0.020196454034053853, 0.03882127847256405, 0.023326157791806117, 0.02760441947196211, 0.03800561152664678, 0.06754356063902378, 0.038686534988560846, 0.024608343008107374, 0.03813214473692434, 0.03727803199685045, 0.00458316393529198, 0.03831832796069128, 0.04414485727569886, 0.030711784160562923, 0.06605793535709381, 0.06797590279685599, 0.03581165336072445, 0.0488707586856825, 0.02834687757837985, 0.375268351818834, 1.200088192309652, 3.9994200212614874, 7.874585407120841, 20.094084365027292, 32.58613770348685, 41.594713415418354, 48.014835017068044, 51.598896503448486, 53.35568598338536, 58.393703188214985, 49.107546942574636, 45.22666883468628, 40.60730143955776, 37.62875461578369, 36.24703584398542, 31.939357689448766, 32.990182399749756, 37.082904134477886, 30.236597401755198, 28.013877357755387, 33.332228319985525, 26.312213148389542, 25.810273545128958, 26.28865006991795, 28.98430619921003, 25.976227794374736, 27.69387980869838, 66.69327081952775, 69.6208109174456, 31.946879114423478, 37.38675580705915, 35.74648066929409, 44.31780971799578, 44.19155052730015, 47.035205023629324, 45.157641955784385, 42.59241567339216, 32.16520193644932, 24.578550747462682, 18.693902492523193, 12.177384189196996, 6.835382861750467, 3.2547018911157335, 1.8787913790770938, 0.7166147295917783, 0.2873317876032421, 0.07929032495511429, 0.01544334676249751, 0.049583108496985266, 0.025741311588457653, 0.004466243445806737, 0.07306225557944604, 0.02433030989154109, 0.04626331485009619, 0.019230215078485862, 0.08471173832991294, 0.04231660234342728, 0.11162171113703932, 0.04416707590488451, 0.017642818025446365, 0.047325096625302515, 0.025796322118757025, 0.020101036743393967, 0.02628816501237452, 0.049189439442540915, 0.026337597984820604, 0.0152952531020024, 0.05120903107204607, 0.11417590693703719, 0.01238236079059009, 0.06643384375742503, 0.007707008543158216, 0.09516712158386197, 0.07363035902380943, 0.028329999019790972, 0.011452923029927271, 0.018304269228662764, 0.02336149419923978, 0.010924303538299032, 0.048578995413013866, 0.028812741062470844, 0.015012346407664674, 0.0311584026951875, 0.022633331129327416, 0.054119230447603126, 0.03270542521827987, 0.06807948116745267, 0.039818494248070886, 0.024044188637552515, 0.011295081365720501, 0.022549784808818783, 0.03668604411983064, 0.031789138314447234, 0.029605402278580835, 0.03240182150953582, 0.029134353090609823, 0.023893945717385838, 0.050543741056961675, 0.05340859054454735, 0.046946776032979996, 0.03635032195597887, 0.02572998174998377, 0.00973390375397035, 0.036839786584356, 0.021164314688316414, 0.12851202195244177, 0.12089238581912858, 0.09461369485195194, 0.13557059104953492, 0.14024845218019827, 0.2298078957412924, 0.1457525925444705, 0.15224545342581614, 0.14571259969047137, 0.07967624853232078, 0.06948424543121032, 0.14007797704211303, 0.10350273429815258, 0.10094652324914932, 0.08566655923745461, 0.17976417392492294, 0.17731914083872521, 0.21025468781590462, 0.12200408402298178, 0.202591191178986, 0.2009870529706989, 0.13119923775749548, 0.1225249275032963, 0.17059291819376604, 0.1568983444677932, 0.09908351036054747, 0.11667283438146114, 0.15254505377795013, 0.10597745329141617, 0.2291037935231413, 0.10314520062612635, 0.12018556946090289, 0.17484874411353044, 0.08863597775676421, 0.11010633209454161, 0.1617521768701928, 0.20798961578735284, 0.1453977594418185, 0.06380819821996347, 0.15775442495942116, 0.131819486618042, 0.1118704756455762, 0.046570345160684416, 0.09628054326666252, 0.1816166830914361, 0.09588794969022274, 0.07130206110221998, 0.15493918316704886, 0.16642321193856852, 0.12466797179409436, 0.061053922799016745, 0.1629349584025996, 0.10245289134659938, 0.19553832177604946, 0.24790247050779207, 0.16352126694151334, 0.1786387421722923, 0.13857704401016235, 0.1318928905363594, 0.1391741276851722, 0.18237684587282793, 0.12250979617238045, 0.11822857947221824, 0.21514817380479404, 0.13223012244062765, 0.15521001363439219, 0.14627894572913647, 0.10333393514156342, 0.15056759917310306, 0.1988163651632411, 0.2857933044433594, 0.8805483015520232, 2.7671200888497487, 6.525169679096766, 17.16358780860901, 32.26172283717564, 45.13767630713326, 54.57708549499512, 60.49743012019566, 66.23612798963273, 62.738140787397114, 58.59710475376674, 59.5360495703561, 55.156860555921284, 52.70961815970284, 56.550929750714985, 54.26979793821062, 53.99562897000994, 57.936199051993235, 48.289705753326416, 47.65439721516201, 50.92842313221523, 47.3613395690918, 43.542797224862234, 46.41259431838989, 46.775404930114746, 47.201034205300466, 44.48985753740583, 66.43394320351737, 75.41533756256104, 52.77709559031895, 51.85657739639282, 51.52951874051775, 58.74553912026541, 53.76910727364676, 54.84067930494036, 52.32400356020246, 45.4954286302839, 31.642287458692277, 21.27091986792428, 15.429777758462087, 8.792941842760358, 4.678832249982016, 2.291669624192374, 0.8950072856886047, 0.41662875243595665, 0.16945757982986315, 0.18873319907912187, 0.14568661179925713, 0.11561436046447073, 0.159888946850385, 0.18531784734555654, 0.13582540809043817, 0.07178101861583334, 0.14321379948939594, 0.1293310544320515, 0.14797027568731988, 0.11057728289493493, 0.24891318913017, 0.14675705507397652, 0.12937704553561552, 0.2773133809013026, 0.17672819112028393, 0.09841917029448918, 0.08732527880264179, 0.1558954425688301, 0.1559792280729328, 0.11058324043239866, 0.07891050140772547, 0.1828823680324214, 0.06763197375195366, 0.14892730861902237, 0.0721621313797576, 0.2778577831174646, 0.20864361497972692, 0.09857538262648241, 0.04485710869942393, 0.1018491851698075, 0.13507497550121375, 0.060978646124047894, 0.12039701454341412, 0.1059800452951874, 0.08440911171159574, 0.08176456218851463, 0.06956560856529645, 0.09362748491444758, 0.13546258184526647, 0.11507176315145833, 0.108507669663855, 0.09640200782035079, 0.16230854844408377, 0.1296859961003065, 0.15082720667123795, 0.10045629526887621, 0.16957449141357625, 0.1767685232417924, 0.12529883294233254, 0.18872668514294283, 0.1724161146474736, 0.14641279354691505, 0.11738959806306021, 0.09632422056581293, 0.08824807964265347, 0.13251009956002235, 0.10277275275439024, 0.1477979685046843], [0.029167852364480495, 0.05191538941913417, 0.022534180199727416, 0.046227542483913045, 0.008231162426194974, 0.02765743002029402, 0.030854419006833007, 0.022963579211916243, 0.039205705880054405, 0.03432301877598677, 0.026778055421475853, 0.022760570016024367, 0.03475087581734572, 0.09912813760872398, 0.05767379381826945, 0.03507141576015523, 0.047895174606570175, 0.08211902888225657, 0.02290761364357812, 0.009598683599116547, 0.010370515486491578, 0.03237072764230626, 0.04007720607998116, 0.02093832181500537, 0.013865460225913142, 0.07720209950847284, 0.06287207773753575, 0.05802897297378097, 0.014542365912348032, 0.039787159500909705, 0.03953021186004792, 0.030460179982972995, 0.03205670163567577, 0.022679266253752366, 0.03394436230883002, 0.026946796902588437, 0.07045229777161564, 0.0204238769199167, 0.04222332752708878, 0.03864817401128156, 0.024368475790002515, 0.03902490343898535, 0.0373687792702445, 0.06336862966418266, 0.08844974025019578, 0.04997608883838568, 0.055462244631988664, 0.05659008179126041, 0.05116241232358983, 0.059313446549432616, 0.029015215912035534, 0.024518070709226385, 0.03537968439715249, 0.07217515925211565, 0.043473375628569295, 0.010088313620404472, 0.0354358060285449, 0.061141046695411205, 0.04158746896843825, 0.03706126041444285, 0.04554217801030193, 0.04265713192788618, 0.027521677215450575, 0.0453336472356958, 0.0543556999016021, 0.021110479719936848, 0.02260239332515214, 0.08092946199966328, 0.06686486955732107, 0.01074427377898246, 0.01424170026023473, 0.007713195934359516, 0.05458915326744318, 0.05403074608849628, 0.22828800444092068, 0.6220394330365318, 3.6875271115984236, 9.31085535458156, 16.86948619570051, 24.928950139454432, 28.52265051433018, 36.799605233328684, 39.60032333646502, 41.05987235477993, 39.90033960342407, 44.75217982700893, 46.081807953970774, 49.543713160923545, 45.26780564444405, 50.27818291527884, 48.4482775415693, 48.69744689123971, 48.589371136256624, 48.34945331301008, 51.76327003751482, 50.4863474709647, 48.79511077063424, 46.74499266488211, 45.03152172906058, 47.061135700770784, 43.21896253313337, 36.66658891950335, 33.70121240615845, 25.86222870009286, 22.252055883407593, 14.957576445170812, 6.8436499152864725, 3.928462411676134, 0.9767982768160957, 0.310735111790044, 0.09060456390891757, 0.01246986466659499, 0.023772940871172717, 0.09063109462814671, 0.042309029892619164, 0.037768069987318346, 0.055806149928165336, 0.03980183282068797, 0.06798473732279879, 0.022173033328726888, 0.008692095505206712, 0.04900682870564716, 0.05025509226002863, 0.026416637136467865, 0.08811469322868756, 0.02632372364002679, 0.02323771414480039, 0.040154046778167994, 0.07265123299189977, 0.056736794632992575, 0.07053306379488536, 0.05766215015734945, 0.012204546448109406, 0.012126758345402777, 0.0312872768512794, 0.08141768830163137, 0.02261350942509515, 0.03535122324579528, 0.003925768251065165, 0.09745362174830266, 0.046654676885477135, 0.059268921081508906, 0.026822407862969806, 0.028732969093003442, 0.04076474525832704, 0.03358669632247516, 0.05933968549860375, 0.05181850140382137, 0.024641686218923757, 0.07148337922990322, 0.013415423571132123, 0.041608547658792565, 0.04050782136619091, 0.059088824316859245, 0.06844441765653235, 0.11588673799165658, 0.03721493502546634, 0.031164102389344146, 0.07145038885729653, 0.05904581876737731, 0.026996698064197387, 0.05406434714261975, 0.025478759248341833, 0.04833354215536799, 0.043133494045053206, 0.040664094766335826, 0.03976213173674686, 0.013775104806492371, 0.033146747787083895, 0.03823533634256039, 0.026063108517389213, 0.03852241433092526, 0.02505869518167206, 0.06712354067713022, 0.036590530137930594, 0.07770722133240529, 0.03272320283576846, 0.02909693866968155, 0.04785674238311393, 0.04297685084332313, 0.08066593935447079, 0.033988385660839934, 0.013059358079252499, 0.024367734490494643, 0.03866654195423637, 0.017565997683310082, 0.04368365702352353, 0.050605379178055694, 0.026903669216803143, 0.016490860642599206, 0.007121709325084729, 0.013326869662185865, 0.025630696809717586, 0.07951640603797776, 0.022990929262180413, 0.012503487773106566, 0.03291517396324447, 0.012792708235792816, 0.01739421975798905, 0.03525654386196818, 0.055497324892452786, 0.030892484821379185, 0.051744524123413224, 0.03866616875997611, 0.011757681944540568, 0.06490428333303758, 0.08505622377353055, 0.0293290519288608, 0.10615187750330993, 0.04562836892104574, 0.03293532306062324, 0.07488104155553238, 0.03712608086477433, 0.011704506003297865, 0.019581511317353164, 0.02589860448746809, 0.08585345492299114, 0.05880357498036964, 0.07779989564525229, 0.04293475453076618, 0.02802773372137121, 0.03251575771719217, 0.0774502329794424, 0.026525828688006316, 0.0627843024475234, 0.04174884155924831, 0.013432205438480845, 0.0322699482286615, 0.053206370145614655, 0.03003851796633431, 0.014077893425045269, 0.006921263295225799, 0.04876971125070538, 0.05448570042582495, 0.006119727265156273, 0.006175326424584324, 0.019500930194876025, 0.0454347591314997, 0.05179347363965852, 0.06489387460585151, 0.06864614611757652, 0.029274565566863333, 0.007265024402711008, 0.08613335061818361, 0.02936672080042107, 0.0227023686747998, 0.006090686814526894, 0.07592879461922816, 0.08292841937925134, 0.09449295633073364, 0.8855645752378872, 2.6438408068248203, 8.032691666058131, 16.587599515914917, 26.060926335198538, 35.818311146327424, 40.08364003045218, 46.94303716932024, 47.571060521262034, 48.90301282065255, 47.915892669132774, 53.248701095581055, 53.11407627378191, 55.25855439049857, 51.444403307778494, 54.857612064906526, 53.730805328914094, 52.52405956813267, 52.44761201313564, 53.37398406437465, 54.225861004420686, 54.664789131709504, 54.444896016802105, 49.16985143933977, 50.55358171463013, 56.12228148324149, 52.2046856198992, 45.68916872569493, 42.454143047332764, 37.18491758619036, 32.328442914145334, 23.75027162688119, 14.158868857792445, 8.267336675098964, 3.3684860255037035, 1.342414440853255, 0.36682783759066034, 0.07490540096270186, 0.01833260994005416, 0.05555713775434664, 0.04344193910115531, 0.04920890661222594, 0.054578127073390145, 0.041957477506782324, 0.04822098337379949, 0.06905021372118167, 0.03328227837170873, 0.04695497952135546, 0.02458225503297789, 0.14411143346556596, 0.0706139180277075, 0.029256024597478763, 0.06975982564368419, 0.03843011321233852, 0.019214283076248, 0.03163833051387753, 0.026141935626843145, 0.007362620638949531, 0.01854184130206704, 0.019071904376947453, 0.020638446656188796, 0.027115363660933714, 0.015529047431690353, 0.013181794634354966, 0.033740018095288954, 0.0899892547833068, 0.015955672931990454, 0.03722967280607138, 0.047235373939786635, 0.026050279116524116, 0.041101871989667416, 0.059184531681239605, 0.0625665130625878, 0.02753100198294435, 0.00525685166940093, 0.0723328779318503, 0.03625542883362089, 0.0376764711524759, 0.02721147644998772, 0.030965814100844518, 0.08829279510038239, 0.0820574654000146, 0.0070186377353301, 0.02096638093436403, 0.09701541704790932, 0.016220847809953347, 0.02186620148963162, 0.005437785152545465, 0.0399564947001636, 0.022705788491293788, 0.02529201114417187, 0.03244747334559049, 0.01574009217854057, 0.08464881777763367, 0.011483461346610315, 0.04977467589612518, 0.04998126945325306, 0.022426910598629286, 0.04538230498188308, 0.01833603823823588, 0.015204225932913167, 0.026449841247605424, 0.15445844110633644, 0.10321391586746488, 0.14736661022262915, 0.11695000236587864, 0.1615782683449132, 0.11073368521673338, 0.058884910973055024, 0.13026359224958078, 0.08987709294472422, 0.093402163790805, 0.09326235165021249, 0.13404143096080848, 0.14280355721712112, 0.33522425485508783, 0.1200325462434973, 0.14495494748864854, 0.1645231917500496, 0.27191080365862164, 0.09527057781815529, 0.1561921795031854, 0.09271949649389301, 0.10638718666242701, 0.0822189703051533, 0.08250720519572496, 0.10221230997038738, 0.1508179378828832, 0.16484495305589267, 0.15051600337028503, 0.08904604360993419, 0.20597068912216596, 0.1696819442191294, 0.08321944983409983, 0.15044194805834973, 0.15453466773033142, 0.1409359574317932, 0.1383420266211033, 0.1754115889114993, 0.08843841550073453, 0.1881406344473362, 0.13647631316312722, 0.2135384851800544, 0.11030600459447928, 0.15809439814516477, 0.11979154417557375, 0.17633797920175961, 0.08497973252087831, 0.15881907354508126, 0.15739096089133195, 0.19865388316767557, 0.17489736793296679, 0.11743383854627609, 0.13608853039996965, 0.0968258615050997, 0.13390177488327026, 0.08035495318472385, 0.1053182225940483, 0.13021552482885973, 0.21573259601635592, 0.14023519360593387, 0.1305466363472598, 0.21784438698419503, 0.14703188889792987, 0.0773585561130728, 0.21710247679480485, 0.23049085480826242, 0.18225047551095486, 0.19537672187600816, 0.18182561759437832, 0.11261732556990214, 0.08536797668784857, 0.05915769562125206, 0.14456743613949843, 0.18863014318048954, 0.08587032330355474, 0.41802341331328663, 1.4744472588811601, 5.697332203388214, 13.797910809516907, 24.506046295166016, 36.619653838021414, 45.55565561567034, 50.708655084882466, 54.275005613054546, 55.400130884987966, 55.15929937362671, 61.77297346932547, 62.92425523485456, 67.01648017338344, 61.09452356610979, 66.04551110948834, 62.972559111458914, 65.06855269840786, 65.22872952052525, 64.63503374372209, 67.69679914202008, 68.51037066323417, 66.22127968924386, 61.85115459987095, 61.86507184164864, 63.67336136954171, 62.22031933920724, 54.8342661176409, 47.94797945022583, 38.830775601523264, 30.66599260057722, 20.49973062106541, 10.512455105781555, 5.507965564727783, 1.9949874069009508, 0.6542060641305787, 0.17177826458854334, 0.08813878122184958, 0.12328453388597284, 0.21184316543596132, 0.11889433089111533, 0.2399101693715368, 0.19425674554492744, 0.11770340693848473, 0.2097843951944794, 0.10033381969801017, 0.11611321941018105, 0.10071893581854445, 0.09607670456171036, 0.29105887189507484, 0.10997503556843315, 0.14147227151053293, 0.16593249541308197, 0.12491851406438009, 0.18477624069367135, 0.1379533481917211, 0.1323422435671091, 0.21850690857640334, 0.1490174994937011, 0.11462896476898875, 0.17496063453810556, 0.19128854838865145, 0.11982195611510958, 0.15600677659468992, 0.09723070942397628, 0.20251611806452274, 0.08912667392620019, 0.17725077165024622, 0.1293489406151431, 0.08154285087117127, 0.12017651780375413, 0.08010444484118905, 0.20948445557483605, 0.13574577522064957, 0.11091005003878049, 0.16482689045369625, 0.09137677747224059, 0.11640484019049577, 0.21159655866878374, 0.17630614233868463, 0.16929330650184835, 0.2291707242173808, 0.07351185966815267, 0.08525919395365886, 0.15102137625217438, 0.1685283261218241, 0.13181769528559276, 0.10365044458636216, 0.10619535802730493, 0.1082716683990189, 0.09536570164241961, 0.2487733837749277, 0.07942648657730647, 0.250646384699004, 0.09497505546148334, 0.18934156000614166, 0.11243270976202828, 0.06930490184043135, 0.10356433170714549, 0.1648259133632694, 0.05203065216275198, 0.26747513881751467], [0.021049945914585675, 0.053502303015972884, 0.07942063760544572, 0.04261631465383938, 0.0323208553184356, 0.05056163402540343, 0.029165453743189573, 0.02300676966219076, 0.048399064889443774, 0.052944109575556855, 0.05774033096219812, 0.06024926847645214, 0.06675633109573807, 0.0782977571444852, 0.025641682291669503, 0.04089732760829585, 0.002373598827814151, 0.012960457359440625, 0.01561402206841324, 0.06882597825356893, 0.030280402129782096, 0.03546058952010103, 0.03168558708525129, 0.09411199284451348, 0.06196177551256759, 0.0260903500020504, 0.03285189039473023, 0.03694307318489466, 0.0201294588789876, 0.023061851438667094, 0.035027327947318554, 0.03363418698843036, 0.05355019401758909, 0.015664952906912992, 0.011182412322211479, 0.06649196706712246, 0.05651805190635579, 0.055066733354968686, 0.018058598839810917, 0.020420594506763985, 0.06685934628226928, 0.07512859148638588, 0.01999442701760147, 0.027736084103318195, 0.05730455541717155, 0.06000814427222524, 0.05238921042265637, 0.014883708042491759, 0.03468902735039592, 0.009164634077543659, 0.01616080933516579, 0.0451518134213984, 0.03515060758218169, 0.02804365724192134, 0.04476531308942607, 0.02913367116291608, 0.022411579099882926, 0.02962417055719665, 0.033430412744304965, 0.033338518746729405, 0.050316570925393274, 0.034949974955192635, 0.05404470016115478, 0.03816129120865038, 0.027510316842900853, 0.0332302347357784, 0.03914374206215143, 0.06437586061656475, 0.050533091449843984, 0.041804956405290535, 0.07236924740884985, 0.06615693361631461, 0.056797258888504336, 0.04128254211640783, 0.0572369054758123, 0.016458321495779922, 0.04945462789120419, 0.017501575872302055, 0.3529287805514676, 1.6132424111877168, 2.919833242893219, 4.733196692807334, 7.971387709890093, 9.931974802698408, 11.320260490689959, 13.573261652673994, 13.780724440302167, 15.711690493992396, 18.633821419307164, 17.963294199534825, 18.00036805016654, 16.808392422539846, 17.269876139504568, 16.020494495119365, 16.890191827501567, 19.513072524751934, 21.089613573891775, 25.736945731299265, 24.2849337714059, 23.85270197050912, 15.784660475594656, 7.191166239125388, 3.641346343926021, 1.737199685403279, 0.8624771226729665, 0.1001418282144836, 0.0636681214507137, 0.08475074730813503, 0.03124991332047752, 0.03599212331963437, 0.056345581875315735, 0.05184195835941604, 0.02104482806420752, 0.08405617172164576, 0.015180034463160803, 0.06435051733361823, 0.055335711421711106, 0.013826581865682133, 0.0314905455868159, 0.11660021756376539, 0.0332758187183312, 0.08821477035858802, 0.010382109953622733, 0.04756565425278885, 0.011377095045255763, 0.050121492107531855, 0.034514759201556444, 0.05509225644969514, 0.020465001231059432, 0.02296248677053622, 0.007668542392951037, 0.06072763566459928, 0.02742982392997614, 0.03530722024983593, 0.03325473663530179, 0.02679110534622201, 0.035599967398281605, 0.03733562944190843, 0.018620205311370746, 0.01600210338697902, 0.03636348553534065, 0.05178909708878823, 0.03871816150578005, 0.05287966910483582, 0.07436412000762564, 0.06239950523844787, 0.028068505194304243, 0.02493638585188559, 0.07260972700480904, 0.05789636008973632, 0.06040736035044704, 0.017187364964878986, 0.021512596535363367, 0.026493694965860674, 0.029587522880839448, 0.03152681328356266, 0.05929974014205592, 0.019724753452464938, 0.025886842082919817, 0.0630098542730723, 0.05582747967647655, 0.015001170935907533, 0.010016476269811392, 0.006719772321438151, 0.0631091103756002, 0.0339020997551935, 0.02865780098363757, 0.022951236659927026, 0.024620405664401393, 0.09029597975313663, 0.04632279183715582, 0.05370540890310492, 0.028081609401851892, 0.03876504149021847, 0.07230110213692699, 0.15772170600082192, 0.018300712008827498, 0.05549321975558996, 0.03809809584968856, 0.074385527787464, 0.04550910621349301, 0.026479483049895083, 0.0818846153893641, 0.03671962821057864, 0.03416069284347551, 0.01972685182201011, 0.08385459932365588, 0.04999815479719213, 0.05037665520129459, 0.03243254218250513, 0.04507896250912121, 0.036553661937692335, 0.025804366151403104, 0.022332826629281044, 0.01896879928452628, 0.01908169563726655, 0.020681750761078935, 0.010267797159031034, 0.02401662993777011, 0.04230975592508912, 0.03466254752129316, 0.008477927800933165, 0.03559046112267034, 0.01477536974873926, 0.018428400424974303, 0.036221342626959085, 0.04481517184259636, 0.03728208963626197, 0.03465373335140092, 0.02960800446037735, 0.11853511445224285, 0.02428448502905667, 0.003876050717995635, 0.0116379815819008, 0.07155237945594958, 0.08354370136346136, 0.06374295029257025, 0.05266694837648954, 0.05456108566639679, 0.084660291804799, 0.07567293263439621, 0.008860970996985478, 0.018295573802398782, 0.027374826970377138, 0.014774540239678962, 0.03512368670531681, 0.03346991705309067, 0.11604121327400208, 0.002364597000580813, 0.052497256946350844, 0.014976105852318662, 0.06707782777292387, 0.016604301519691944, 0.0414433108110513, 0.004045276927562165, 0.08909924754074641, 0.029822536877223423, 0.04556761628815106, 0.013762650296225079, 0.036162598457719596, 0.0371110309580607, 0.05124070169404149, 0.01612585290734257, 0.02874377815585051, 0.03015988752511995, 0.043480239010282924, 0.03972333988973072, 0.041537087743303606, 0.0729290320138846, 0.0687690084534032, 0.052780609777463336, 0.0023140510186619523, 0.08360151933240038, 0.11296277453324624, 1.237737006374768, 3.6287818295615057, 6.197074438844409, 9.803578172411237, 15.15866426059178, 18.259396893637522, 19.10056839670454, 22.953620706285747, 24.005362578800746, 27.534237997872488, 28.49609797341483, 30.600742067609513, 29.253948416028702, 28.170692988804408, 28.780465160097393, 27.380458729607717, 28.478286266326904, 30.48006922858102, 30.383569172450475, 35.92796066829136, 34.09519611086164, 33.34409236907959, 24.841969115393503, 15.27131540434701, 8.906451089041573, 4.704253103051867, 2.5061218653406416, 0.701864301093987, 0.1587456696267639, 0.08903868150498186, 0.006095383549109101, 0.008999113093263336, 0.04270986766953554, 0.04081422063921179, 0.05449262487569025, 0.03808109176212123, 0.033038524844284566, 0.00910334285747792, 0.060522609523364475, 0.040687103888818195, 0.010012683259057147, 0.043258799106947014, 0.037664912308433225, 0.07483791386974709, 0.019410981896466444, 0.03218428657523223, 0.03218273951538971, 0.025372132559173873, 0.025680525028812032, 0.047994661411004405, 0.019967867460634028, 0.0583588427730969, 0.032314426199133904, 0.012727485753462782, 0.003557618474587798, 0.016976160762299384, 0.01831689167634717, 0.01893555955030024, 0.017647235288417766, 0.020173714629241397, 0.023571957102311508, 0.010450539362084652, 0.02327611074516816, 0.05567831393065197, 0.03355437430686184, 0.07575253157743386, 0.04377117447022881, 0.015473466931975313, 0.025933866256049702, 0.025794595247134566, 0.030926984934402362, 0.008546795712650886, 0.11335962252425295, 0.0412856226653925, 0.03986069234088063, 0.03669448170278754, 0.046154678000935485, 0.06660726373749119, 0.02264767705595919, 0.018185021788147942, 0.028023377526551485, 0.024357692172218646, 0.0518791319004127, 0.020372455839865973, 0.02059623160000358, 0.054986808715122085, 0.02126995750170733, 0.06376678722777537, 0.032628265608634265, 0.06412736752203532, 0.02527358552574047, 0.013554714087929045, 0.04108537680336407, 0.022064790029876998, 0.045054877908634286, 0.014926493068092635, 0.05813890921750239, 0.053946872374841144, 0.11248815285840205, 0.18878932749586447, 0.1614290584943124, 0.22712521255016327, 0.10510103031992912, 0.1299642768821546, 0.07443139675472464, 0.09321305608110768, 0.14880381524562836, 0.11277771089226007, 0.12399198806711606, 0.12370750547519752, 0.1916625840323312, 0.23305726423859596, 0.15089393380497182, 0.07578144395457846, 0.10567773080297879, 0.11305189332259552, 0.07782204981361117, 0.18826211935707501, 0.0809181033234511, 0.10446649151188986, 0.06965886641825948, 0.19916606854115212, 0.08158114738762379, 0.06972317796732698, 0.0811685166720833, 0.09155798024897065, 0.16387871918933733, 0.11449450626969337, 0.15741456033928053, 0.14761689464960778, 0.13975283663187707, 0.13368083031049796, 0.22383650259247848, 0.15383226184972695, 0.12961512990295887, 0.11942012767706599, 0.1368281335702964, 0.13756978591637953, 0.148030570309077, 0.19103630978081906, 0.13322283274361066, 0.1533101155821766, 0.15853507949837617, 0.16090893426111766, 0.18749332561024598, 0.10968845630330698, 0.09929218702018261, 0.12034111682857786, 0.15229660139552184, 0.1632032918610743, 0.13413129613867827, 0.15664006689829485, 0.12390221788414887, 0.14971419210944856, 0.21271323731967381, 0.13779405531074318, 0.14084073182727608, 0.14443159342876502, 0.21707012424511568, 0.11333145653562886, 0.15271613959755215, 0.09986374420779091, 0.10840226603405816, 0.20173759412552628, 0.10473494032131773, 0.15834981229688438, 0.11719008162617683, 0.07992807323379175, 0.1244796376143183, 0.17253161487834795, 0.22406017487602575, 0.09347827506384679, 0.1308948333774294, 0.07446670093174491, 0.15228874396000588, 0.12763785171721662, 0.7103487572499684, 2.6340075859001706, 4.478751489094325, 7.1198108451707025, 11.709663595472064, 14.108420593397957, 15.897554806300572, 20.24707327570234, 21.209339720862253, 24.603359290531703, 25.59225470679147, 27.398345129830496, 27.324640376227244, 24.230805567332677, 25.983837808881486, 25.816994190216064, 25.70579869406564, 26.94465208053589, 30.119158949170792, 35.13591814041138, 33.96178722381592, 32.23711231776646, 22.9213775907244, 12.6982923746109, 7.253848544188908, 3.3130687134606496, 1.3992716584886824, 0.3759268836251327, 0.13216338173619338, 0.16629279750798429, 0.14751348591276578, 0.15670521983078547, 0.08743018031652484, 0.19921812574778283, 0.11633712239563465, 0.19444531042660984, 0.08579359456364598, 0.12693149676280363, 0.14510484944496835, 0.10954118706285954, 0.15876286370413645, 0.20352189695196493, 0.12063298188149929, 0.2406248567359788, 0.17102591853056634, 0.16478266354118074, 0.1769443859479257, 0.12468177319637366, 0.1751235779374838, 0.1705650304044996, 0.06963325172130551, 0.12839338688978127, 0.10011814734233276, 0.15283720381557941, 0.14195807544248445, 0.13551313270415577, 0.08885439817926713, 0.15975237132183143, 0.08350357958780867, 0.12114478727536541, 0.10717925416039568, 0.07982083077409438, 0.1040446666468467, 0.12223481307072298, 0.09398003813943692, 0.18440273430730614, 0.1900569259056023, 0.11398386795605932, 0.09914516205234186, 0.0677418557128736, 0.13768789172172546, 0.14331973237650736, 0.16017934626766614, 0.14960607433957712, 0.09186050508703504, 0.09233292152306863, 0.08422414985086236, 0.1244026781725032, 0.18875503433602198, 0.11531404086521693, 0.08455495602850403, 0.20137392649693148, 0.13839265890419483, 0.08364577338631664, 0.08423870442701237, 0.08469457817929131, 0.11126976859356676, 0.15932424286646502, 0.11296983808279037, 0.15783229363816126, 0.09002165483044726, 0.12278646204088416, 0.10043299437633582, 0.225733523656215, 0.19532265620572226, 0.13548577417220387, 0.16692891051726683, 0.3052938037684986], [0.03242312750912138, 0.021734043224049465, 0.049998785834759474, 0.08601841357137475, 0.04252729085939271, 0.06812965883208172, 0.009702305226320667, 0.08875447711242096, 0.019111142360738347, 0.055094373478953323, 0.01738517318985292, 0.028194721189460585, 0.04033525973292334, 0.06371778342872858, 0.01761743742307382, 0.004363351667832051, 0.08665656897106341, 0.03873999337000506, 0.118094053119421, 0.01862720100741301, 0.045485768001526594, 0.04623556276783347, 0.05035830422171524, 0.02914884320593306, 0.018912986386567354, 0.00804968738728868, 0.04438987287825771, 0.08892060962638684, 0.06824653648904391, 0.06942335369863681, 0.020890196718807732, 0.016072896641812155, 0.04457000356965831, 0.021954694330426197, 0.01905332608813686, 0.005144954459475619, 0.048387987805264335, 0.05252074782869645, 0.02158957633322903, 0.023759823092924695, 0.01466973711337362, 0.06044359412044287, 0.047342294095350165, 0.017375178369028226, 0.029006679941500937, 0.02177303014988346, 0.12920567473130568, 0.02898798630173717, 0.08378542946385485, 0.023442083803404654, 0.09695732766496283, 0.03170891851186752, 0.05308635426419122, 0.012644148930641157, 0.01643280009739101, 0.014935985773003526, 0.0029555700436633614, 0.026785498950630426, 0.09676550581519093, 0.05409975309989282, 0.024212226138583252, 0.008419756993784435, 0.031005365907081535, 0.02912551856466702, 0.03658570236127291, 0.07817585832838501, 0.030362922166075026, 0.016257688868790865, 0.02464135204042707, 0.04352950404531189, 0.07661220830466066, 0.030343665342245783, 0.007940936035343578, 0.019650771083044152, 0.025228125375828574, 0.035738178196230104, 0.0665289947230901, 0.021671614609658718, 0.031641645157443624, 0.08575561017330204, 0.05434918257274798, 0.011214380651446325, 0.04697249251018677, 0.035893786632056744, 0.08217470946588687, 0.13625747204891273, 0.2290994237576212, 0.2743246241339615, 0.3430581587765898, 0.3652367815375328, 0.5879588989274842, 0.3110315501689911, 0.11318812279828958, 0.15288368346435682, 0.040642110231731615, 0.20949755130069597, 0.5506974469338144, 0.3725258761218616, 0.381283700466156, 0.3571951916175229, 0.2602791392377445, 0.07721091367836509, 0.07850593168820653, 0.06315386654543025, 0.015500207997060247, 0.03035375176529799, 0.022475532721728086, 0.022674901577244912, 0.01244831269806517, 0.04188297775440982, 0.03246837900951505, 0.04851172545126506, 0.033347723074257374, 0.07274646538176707, 0.030218346709651605, 0.020087902001770477, 0.041988238891852755, 0.01237778492005808, 0.02203891409694084, 0.038692180399916, 0.04186783285279359, 0.04608779141147222, 0.027371083153411746, 0.009269755267138993, 0.08362849788474185, 0.024793866356568675, 0.006812362241492207, 0.06449086551687547, 0.014971200044133832, 0.0392183096680258, 0.027172223199158907, 0.06964042383645262, 0.03241536167583295, 0.04352489679253527, 0.015140693002779568, 0.039489238522946835, 0.02918316689985139, 0.025491946576429263, 0.016723452268966606, 0.07088520311351333, 0.032670134611959965, 0.03507008583151868, 0.03841207775154284, 0.02287695573509804, 0.0294119383740638, 0.05623218510299921, 0.07935620392007486, 0.05949274942811046, 0.021669246522443633, 0.04250644965629492, 0.010237980633974075, 0.030719030914562087, 0.011776065154533302, 0.022297658159264495, 0.0257365177385509, 0.02133415369982166, 0.03702882304787636, 0.08017115161887237, 0.027012619888409972, 0.040396965707519224, 0.057360520985509665, 0.03367156069725752, 0.02309861616231501, 0.049834702496549914, 0.022184590476432016, 0.019979811373299787, 0.06581809358405215, 0.0743184613862208, 0.013226586427273495, 0.004070707147807947, 0.032267553000045676, 0.01217213283026857, 0.014517567153753979, 0.03898654246170606, 0.02588844172922628, 0.09672609650130783, 0.025999626477382014, 0.02436193640876029, 0.05004187959379383, 0.04781410663521715, 0.01554187004720526, 0.03716176502140505, 0.09766590821423701, 0.08263780961611442, 0.013198501862851637, 0.05323775917557733, 0.012002419347741773, 0.03588936936908534, 0.04148254031315446, 0.018412436192323054, 0.016438604964475547, 0.014458950209830488, 0.09669320112360374, 0.02326365453856332, 0.052610555331089666, 0.04701207824317472, 0.10170789382287435, 0.008940052557071405, 0.04098539806104132, 0.035663780224110396, 0.026395743346906135, 0.004429988895675966, 0.03661452992154019, 0.007812642026692629, 0.031447037921420166, 0.06205767286675317, 0.0511352675301688, 0.025477203706811582, 0.018632332428491542, 0.04057437886617013, 0.07037956560296671, 0.019250128384945647, 0.022762181536693658, 0.04073194826820067, 0.01219852699432522, 0.02521532990171441, 0.02558631553048534, 0.041526740084269216, 0.025232963330511535, 0.036395617561148744, 0.011877828443955098, 0.00865069214653756, 0.052387558189885955, 0.03628635645977088, 0.08445181870566947, 0.05717811041644641, 0.06527042761445045, 0.01727799349464476, 0.08484134530382496, 0.038045254935111315, 0.03458497400528618, 0.035564500372856855, 0.008142868905062122, 0.013229934149421751, 0.02138276394855763, 0.023605322365515997, 0.0194489052186587, 0.024841450321088945, 0.011035048086861414, 0.04066584538668394, 0.044096165602760654, 0.0446939108494137, 0.07317846148673977, 0.0030435798523415413, 0.04306842592943992, 0.024037406680041125, 0.026090579007619193, 0.015722618205472827, 0.0401659414970449, 0.03471647748457534, 0.036181139427104166, 0.07338110597005912, 0.03058298464332308, 0.022900840167754462, 0.05650093246783529, 0.0499720142355987, 0.07760949871901955, 0.03399488263364349, 0.19606676484857286, 0.21829847618937492, 0.2469468760703291, 0.6638889216950962, 1.2808034611599786, 1.0590595198529107, 1.4444511256047656, 1.5148877288614, 1.800142656479563, 1.396094160420554, 1.2637372740677424, 0.9809332149369376, 0.4907161997897284, 1.0786912207092558, 1.7223010105746133, 1.8033771514892578, 1.2187426941735404, 1.1972663551568985, 0.7468653949243682, 0.20714160986244678, 0.0900431711758886, 0.028954303823411465, 0.008759240786145841, 0.0958956510626844, 0.034941513623510084, 0.03835244130875383, 0.027368090813979506, 0.03621648092355047, 0.043810560035386255, 0.01313524882841323, 0.0608967605179974, 0.053384465231959305, 0.03176200030637639, 0.06049790406333549, 0.013908723618702164, 0.04757094682593431, 0.025352622981050184, 0.04018094729898231, 0.016589763906917403, 0.009175795130431652, 0.035382714056010754, 0.008372130620825504, 0.07062971432294164, 0.018436566593923738, 0.03968934867797153, 0.04127208589177046, 0.006995499691194189, 0.01806870222623859, 0.01384446126342352, 0.07197790912219457, 0.029091493426156894, 0.0536707255856267, 0.02841996428157602, 0.037592604224170954, 0.04523459469367351, 0.07796314438538891, 0.03947798841233764, 0.04437837510236672, 0.021750139771029353, 0.014833908661135604, 0.04835104835884912, 0.015233713368486081, 0.006210531365858125, 0.04227222954588277, 0.03942512035635965, 0.036558995222938914, 0.017208280806828822, 0.021280261055965508, 0.0501696647011808, 0.09131072887352534, 0.03422655484506062, 0.005002499424985477, 0.07080613342779023, 0.06505017514739718, 0.01999078837356397, 0.03375196031161717, 0.017813050587262427, 0.03670932126364537, 0.02007069774637265, 0.060511291559253416, 0.051057263144424984, 0.037119190341659954, 0.017246176987620335, 0.05350019955741508, 0.0662584492404546, 0.02603805870083826, 0.026620231568813324, 0.025531898718327284, 0.047782497081373415, 0.016334731431145753, 0.02640555496327579, 0.028848435397126844, 0.05700746564460652, 0.04592396930924483, 0.11869044468871184, 0.16749494442982332, 0.2031456764255251, 0.14343141924057687, 0.05167437717318535, 0.12216581963002682, 0.12512207456997462, 0.15825899716998848, 0.13242490270308085, 0.14460502697953156, 0.12497807586831705, 0.12371024675667286, 0.12213299210582461, 0.12815957729305538, 0.07462678091334445, 0.07231099517749888, 0.21362993812986783, 0.12051974795758724, 0.12164270984275, 0.12393522182745592, 0.15117655721093926, 0.10845228763563292, 0.1366560978016683, 0.11630468842174325, 0.13749950325914792, 0.08959745509283883, 0.12151157616504601, 0.2510939192559038, 0.09405024615781647, 0.13003283606043883, 0.17295602496181214, 0.07643161620944738, 0.1587972790002823, 0.2668575905263424, 0.12590009639305727, 0.08969342030052628, 0.09812570389892374, 0.2139119915664196, 0.09464460890740156, 0.16321983454482897, 0.06953464022704534, 0.13756534829735756, 0.0652966597782714, 0.11723922113222734, 0.1413433091448886, 0.12062311598232814, 0.2548932268151215, 0.2081756293773651, 0.18924607655831746, 0.1344831979700497, 0.20506637836141245, 0.1319270208477974, 0.1365947446652821, 0.16816111654043198, 0.1569705813058785, 0.09398770558514766, 0.0978280170155423, 0.1371984915541751, 0.1090245165729097, 0.13230074436536857, 0.11761673087520258, 0.13787372889263289, 0.12890376736010822, 0.12210728919931821, 0.16892674831407412, 0.24122050191674912, 0.10059565279100623, 0.11113193098987852, 0.06603310776076146, 0.20186638007206575, 0.14441947479333195, 0.12133219864751611, 0.07469029179108994, 0.09448517353406974, 0.1887808186667306, 0.1590957801256861, 0.19624535526548112, 0.11605160843048777, 0.09286868598844324, 0.1635672716157777, 0.18844047907207692, 0.06818321560110364, 0.16448414884507656, 0.17440946054245743, 0.17871020548045635, 0.2825934418610164, 0.6054976178067071, 0.5379403914724077, 0.6707480964916093, 0.7235537001064846, 0.9626855083874294, 0.6925075746008328, 0.7102199984448296, 0.6271978190967015, 0.2966075512979712, 0.4539336035294192, 0.9857646014009203, 0.9993284621409008, 0.7141162550875119, 0.7780003270932606, 0.40574057240571293, 0.210580099640148, 0.19935980385967664, 0.0962362824273961, 0.12166096243475165, 0.17111127823591232, 0.22142842252339634, 0.1281109806150198, 0.1413034384271928, 0.09453332916434322, 0.15543566724019392, 0.07414792517998389, 0.13837467772620066, 0.14417771276618752, 0.07530507165938616, 0.15517615473696164, 0.11235224907951695, 0.11101022216358356, 0.11233022383281163, 0.09866574313491583, 0.11644133180379868, 0.11239192302205733, 0.11053107466016497, 0.07583319582045078, 0.13101023861340114, 0.08747485506215266, 0.0909732866234013, 0.07330128311046533, 0.061715311237743924, 0.07826508568333727, 0.10724002375666584, 0.1876068309481655, 0.14412056654691696, 0.11237417933131967, 0.07977986761501857, 0.16189066586749895, 0.1825754123606852, 0.09913471261305468, 0.16482353849070414, 0.14826579125864164, 0.12021944192903382, 0.06418469016041074, 0.20684215878801687, 0.13947934630726064, 0.09952333675963537, 0.16424799151718616, 0.15632988139986992, 0.09762271267494985, 0.1560236449752535, 0.134122190198728, 0.08040360414556094, 0.20101514432047093, 0.08536909627062933, 0.06986721738108567, 0.1800819725862571, 0.1257996732102973, 0.15940034735415662, 0.12514384197337286, 0.13711085197116646, 0.13817916464592728, 0.1565082682562726, 0.17451421277863638, 0.0935669324493834, 0.09149644390812942, 0.05040345733453121, 0.14792564165379318, 0.19292848610452243, 0.1252359463168042, 0.12385934804167066, 0.05999676523996251, 0.22946930676698685, 0.04061901968504701, 0.06699976231902838, 0.12014029760445867, 0.20486603411180632, 0.12072577833064965], [0.03218548418954015, 0.003312370049700673, 0.04344291279890707, 0.012759671213903596, 0.015530055056193044, 0.007395333660367344, 0.017158398304932883, 0.038282450421580246, 0.012890706504029887, 0.04081522487103939, 0.021010550171402947, 0.027935771870293787, 0.06611516300056662, 0.06141476772193398, 0.050502411488975794, 0.022566456414226974, 0.02487904455379716, 0.028834281156637838, 0.044925925721015246, 0.026981889037415385, 0.040594086915786774, 0.018400234436350207, 0.03051619983411261, 0.031343432409422736, 0.030205515612448965, 0.011205330690635102, 0.040827974544039795, 0.03806236419560654, 0.021434261363797953, 0.07379389953400407, 0.03845243701445205, 0.044009967906666655, 0.036240402675632916, 0.07411268885646548, 0.04005161513175283, 0.03124920425138303, 0.02071271401031741, 0.025461444731003473, 0.0638815885675805, 0.010818661573076887, 0.018599562579765916, 0.02685698600752013, 0.037805911885308366, 0.024609978277502314, 0.055657289523099146, 0.02144405262411705, 0.04436325394947614, 0.024136825630973493, 0.036691689531185796, 0.01834760556396629, 0.054480509632932286, 0.060169058851897717, 0.046153161475168805, 0.05798993006880794, 0.030323346611112356, 0.02153536138523902, 0.03496364065046821, 0.02051737395647381, 0.019799149728247097, 0.04712184824581657, 0.03613569115155509, 0.016681690134906342, 0.030534326897135804, 0.028136696267340864, 0.013971946967233504, 0.04368729397122349, 0.02219042757392994, 0.047853627907378335, 0.0836330915668181, 0.050445543469062874, 0.007325296972080001, 0.06382502588842597, 0.03647347945453865, 0.005611433714096035, 0.037085012532770634, 0.08459669950285129, 0.018594241168882166, 0.0023645454743278344, 0.026767419385058538, 0.027046263350972106, 0.04042973216356976, 0.03340352240151592, 0.024922991570617472, 0.0438586308487824, 0.04772344417870045, 0.011439783199291145, 0.03140005276405385, 0.02235948627016374, 0.05458378266277058, 0.04322101488443358, 0.0057817209827979756, 0.007392707729845175, 0.02334276832906263, 0.06825267723096268, 0.023699272324198058, 0.024591844429128935, 0.0055956645602626455, 0.07745627872645855, 0.006890863230052803, 0.018000658734568527, 0.03856787278449961, 0.030889628188950673, 0.11331239648695503, 0.048220033424773386, 0.008996382837982049, 0.053811111088309965, 0.031374278611370494, 0.020051427351843034, 0.03852157973285232, 0.02408379133391593, 0.04303159165595259, 0.014776798064953514, 0.041116311214864254, 0.09659026736127478, 0.030303747127098695, 0.04655485420620867, 0.0946368125400373, 0.057794668046491485, 0.029102295703653778, 0.032814034926039834, 0.013802437045212303, 0.0512349748584841, 0.05711207538843155, 0.012606555546101714, 0.02721210748755506, 0.05347902587215815, 0.02728908389274563, 0.014754087497879351, 0.02906158020985978, 0.07984053543103592, 0.027541402228442684, 0.01255958226309823, 0.023439332343904034, 0.01811741934424, 0.061903231511158605, 0.02418944432533213, 0.020721024367958307, 0.04751350883660572, 0.007239893161957818, 0.04355955636128783, 0.015317926349650537, 0.037242704071104527, 0.05216433713212609, 0.02671810006722808, 0.021750456986150572, 0.030271306367857114, 0.02552839069228087, 0.023326966944815855, 0.013559378168013479, 0.02015289887120681, 0.0304107283508139, 0.03916859340720943, 0.012237373972311616, 0.019728980725631118, 0.02694894785859755, 0.02271430580211537, 0.07094773690083198, 0.016913793216060315, 0.02631241755027856, 0.047915228709046326, 0.0686468653646963, 0.05990478303283453, 0.048960851172783544, 0.031800493597984314, 0.02053841363106455, 0.056048763516758165, 0.013685749378055334, 0.04399851084287677, 0.031238744634070566, 0.027050164927329336, 0.009407397792009371, 0.016735993292448775, 0.05665417620912194, 0.02209405185255621, 0.05912572983652353, 0.03193745928417359, 0.016679607032399093, 0.0067408493154549175, 0.02673361137775438, 0.015733371289180856, 0.030247591568955352, 0.06813325506768056, 0.007277497572691313, 0.02244945492462388, 0.050401336912597926, 0.00814767717383802, 0.022391285813812698, 0.011273780455147582, 0.05529122327321342, 0.06110908091068268, 0.023221507335879972, 0.01118742415149297, 0.023175063310191035, 0.05769115752939667, 0.024568217839779596, 0.04144660849124193, 0.025598432469580854, 0.07432291936129332, 0.019321715525750602, 0.045515060358281643, 0.005561955364620579, 0.07038734839963061, 0.06979147930230413, 0.015633560484275222, 0.02616764871137483, 0.01397474592418543, 0.019754536050770963, 0.04099342513031193, 0.0022279498017659144, 0.042074121069163084, 0.06553428274180208, 0.03295109899980681, 0.0513501901046506, 0.02547435385973326, 0.03935002688584583, 0.020615147459985952, 0.06416750286838838, 0.0626389059637274, 0.028237921817760383, 0.03354147196348224, 0.04817550456417458, 0.07235940186572926, 0.02703626174479723, 0.014406633463555148, 0.02285219429593001, 0.03754027560353279, 0.04742075649223157, 0.08887733266289745, 0.039329833683690855, 0.040164638709809096, 0.015695992491341064, 0.02000626745367689, 0.0550815355964005, 0.01781752722204796, 0.04611889545672706, 0.0216728037422789, 0.10049288866243192, 0.01547049664493118, 0.004170590471143701, 0.03202740927892072, 0.03135367828820433, 0.02278252910556538, 0.03727133824889149, 0.05604209351752486, 0.013728131523488887, 0.0595329933400665, 0.022020975327385322, 0.04505047421636326, 0.07296679248767239, 0.007455450166682047, 0.004995374383205282, 0.013564382363776011, 0.04659693694806524, 0.052800344968480725, 0.044778188291404925, 0.046713119106633325, 0.07102009587522064, 0.06107372245086091, 0.03096982424280473, 0.013654036347621253, 0.015679273388481567, 0.06970985153956072, 0.016282472360346998, 0.06092716567218304, 0.006613585407779152, 0.033870212001992125, 0.038863191580665965, 0.02967543727053063, 0.035368892297680886, 0.051348280028573105, 0.00805777043569833, 0.03052432189828583, 0.023349950622235025, 0.03477044476728354, 0.043908757623285055, 0.031057769166571752, 0.05648774513974786, 0.020467650910307254, 0.10464693432939903, 0.10638657598091023, 0.03545058112857597, 0.15168226936033793, 0.019395451926227127, 0.04109569053564753, 0.024365580141810433, 0.030301921867898533, 0.016376362947214926, 0.05102748902780669, 0.012562021596490272, 0.03508615693343537, 0.022149854572489858, 0.034248230646231344, 0.07373935888920512, 0.03511428560263344, 0.03039509490398424, 0.024755347619897554, 0.026522429227562885, 0.04537303280085325, 0.017105808448312537, 0.015838608677898134, 0.018370796194566146, 0.030143514475119964, 0.02534993428603879, 0.025071541545912623, 0.014390682801604271, 0.036140559640313895, 0.10130863703255143, 0.010804559919051826, 0.04488490488646286, 0.08055488352796861, 0.055456147994846106, 0.03783697521846209, 0.05417823585282479, 0.03148995526134968, 0.022779155090185146, 0.010361308614457292, 0.005127476669648396, 0.02194456210626023, 0.06138333119452, 0.026875849281038557, 0.04277279839984008, 0.03266091671373163, 0.03403223259374499, 0.1496056400771652, 0.020284894288384488, 0.03370510068322931, 0.031019784776227813, 0.014934593079877751, 0.014349058070885283, 0.039315292678241215, 0.07287884077855519, 0.014066829063397433, 0.04948435451037117, 0.019020912470296025, 0.050377252312111, 0.05882687587291002, 0.009133114429589893, 0.013279210210644772, 0.01949688103715224, 0.07033003933195557, 0.026683779765984843, 0.014895975955628922, 0.010921880320113684, 0.02360035040016685, 0.035621354822069407, 0.02036658481561712, 0.02680706448986062, 0.027007016885493482, 0.07185250228004796, 0.04853775744725551, 0.048379906453192234, 0.02270374440455011, 0.09453290168728147, 0.08860246491219316, 0.1600995912615742, 0.15116601277674946, 0.10502485119338546, 0.10680730161922318, 0.06791100770767246, 0.23045958791460308, 0.10313409300787107, 0.19754698899175438, 0.2006316091865301, 0.2040677105209657, 0.09447166390184845, 0.15725038200616837, 0.061587522737681866, 0.07273616522018399, 0.06704206897744111, 0.13142600416072778, 0.11485893385750906, 0.10609397132481847, 0.0878256033839924, 0.09625222800033433, 0.11348686819630009, 0.13029061151402338, 0.10068381484597921, 0.17045467346906662, 0.1574894841760397, 0.09567452328545706, 0.1845134033688477, 0.11234352990452733, 0.12331289664975234, 0.14301619652126515, 0.16955410822161607, 0.13633581570216588, 0.1506208370306662, 0.12061920762062073, 0.10439008168343987, 0.08590897265821695, 0.11923895882708685, 0.11930694803595543, 0.11229657528123685, 0.2022540678403207, 0.11806168699903147, 0.13527198135852814, 0.07067897596529552, 0.10846850462257862, 0.18106321564742497, 0.08824906351843051, 0.10739827169371502, 0.06340282104377236, 0.1806988694838115, 0.20705433668834822, 0.15042346476444177, 0.12722450175455638, 0.11801557375916413, 0.0879148103828941, 0.14569695267294133, 0.0806234155648521, 0.10454482837979283, 0.09842941617327076, 0.2400224804878235, 0.15642117150127888, 0.11270388628223113, 0.14555063338152, 0.11726738033550126, 0.1059477673843503, 0.14678917692175933, 0.13283347577920981, 0.1186780682099717, 0.1928172063614641, 0.06543708938573088, 0.16566855886152812, 0.14046039937862329, 0.1959170393113579, 0.11950482241809368, 0.1674967221915722, 0.1263854932039976, 0.17329815588891506, 0.1294977976275342, 0.09338214022240468, 0.1791262153003897, 0.15258398811732019, 0.25980934873223305, 0.12668950403375284, 0.13687545460249695, 0.12477003703159945, 0.12187149828033787, 0.1441144733024495, 0.15877661082361424, 0.08543869360749211, 0.12427663350743906, 0.11227759665676526, 0.20676068030297756, 0.19138874086950505, 0.1284196869071041, 0.11756676355642931, 0.08798442807580743, 0.15047298425010272, 0.09064906223544053, 0.14262206267033303, 0.09529638250491448, 0.11770841452692236, 0.3272796411599432, 0.26541231093662127, 0.08765791023948363, 0.2970824715282236, 0.10781027137168817, 0.10103549954614469, 0.08612539140241486, 0.10067535351429667, 0.11538553131478173, 0.06959769648632833, 0.06548253766127995, 0.13013107436043875, 0.1746240404567548, 0.14126683824828692, 0.23571269746337617, 0.1620251786495958, 0.108604964800179, 0.10489178369087832, 0.10860710218548775, 0.24171539821795054, 0.11839315135564123, 0.12230540785406317, 0.14294007846287318, 0.11055814820740904, 0.07516197540930339, 0.14574480296245643, 0.04750058274450047, 0.21061302215925284, 0.12264206978891577, 0.1067992609792522, 0.12012432489011969, 0.12506617685513838, 0.16849089813019547, 0.10478036145546607, 0.09443079573767525, 0.1292372401803732, 0.06711654498108796, 0.12787170202604362, 0.08810474590531417, 0.11472178835953985, 0.1270474312560899, 0.1260140902761902, 0.12990196022604192, 0.11943999518241201, 0.12869190158588545, 0.27053829016430037, 0.10473334576402392, 0.0988266577145883, 0.16597799797143253, 0.17708448985857622, 0.16233378994677747, 0.08676130763654198, 0.1259902058435338, 0.1204316605414663, 0.2322893797286919, 0.09059581759252719, 0.08786267175206117, 0.1921466373439346, 0.14603858148413046, 0.1973953228443861, 0.11530232935079507, 0.12629880357001508, 0.08571157325059175, 0.11412397186670985, 0.12858588727457182, 0.1596990656107664, 0.1320254219962018, 0.128400145098567, 0.03954110234709723, 0.10372288498495306, 0.2115503775754145, 0.10967232752591372, 0.11216396918254239, 0.13162421781037534], [0.046488252601453235, 0.04834216633545501, 0.06901439385754721, 0.01993373206018337, 0.04231989663094282, 0.05380248351554785, 0.03195002914539405, 0.043428646600139995, 0.05857169920844691, 0.029398771402026926, 0.013304987756003226, 0.027646240977836505, 0.028131488511072736, 0.019633994304708073, 0.015924058289134076, 0.03174690290221146, 0.028415367206824676, 0.024882576328569224, 0.03573276687945638, 0.025677256186359694, 0.034310493019542525, 0.006624628141123269, 0.022658940737268755, 0.007553750383002418, 0.027359687157773545, 0.03333419987133571, 0.050219072228563685, 0.038526604284665415, 0.00123312342371459, 0.013885156401166958, 0.013632525091192551, 0.0042655425412314275, 0.03160026469933135, 0.0320958429282265, 0.009427432386603738, 0.019183720162670528, 0.029835446005953208, 0.06470824778079987, 0.019501859787851572, 0.10364060582859175, 0.020378869692129747, 0.029735826887190342, 0.018412975627662878, 0.02804639852339668, 0.06085277787808861, 0.03758937779015728, 0.05327368081946458, 0.02482725367216127, 0.03467097831889987, 0.015998330732275332, 0.027565987248505865, 0.034106206481478045, 0.03521319904497691, 0.059232253049101145, 0.012989533433158482, 0.04203467443585396, 0.0031312294013332576, 0.033129743699516566, 0.046920754215014834, 0.015501027328095265, 0.04248322679528168, 0.03429012679095779, 0.017351163318380713, 0.01857938464464886, 0.04178863424541695, 0.0610927010753325, 0.026682697502630096, 0.03097520163282752, 0.01510769923749779, 0.037827669110681326, 0.06215127677257572, 0.03682149667292833, 0.033588470691548925, 0.05593899690679141, 0.05518012334193502, 0.06169019865670374, 0.038914895949086974, 0.020885341800749302, 0.01597848697565496, 0.03029277521584715, 0.06181445198931864, 0.07028851298881428, 0.060981747029083114, 0.012685109545210642, 0.02495727964144732, 0.029092935313071524, 0.014160131869305457, 0.04415596150127905, 0.03665767117802586, 0.014191820302845111, 0.07994182713861976, 0.01169965956692717, 0.01796511876662927, 0.034932268583881, 0.028313936399562017, 0.02643902539940817, 0.04372694077236312, 0.04985163873061538, 0.026944232040217946, 0.056508827222777266, 0.08270150369831494, 0.0812656150332519, 0.013055750817459608, 0.009194923032607352, 0.036520905659667084, 0.07556020761174814, 0.06299546254532677, 0.07830316506858383, 0.0012476079199197037, 0.028301337700603262, 0.019700477165835242, 0.05582106752055032, 0.01877715385385922, 0.02447076155138867, 0.052465437046651325, 0.07006499676832131, 0.028571990052504197, 0.019037634965830615, 0.04738658546869244, 0.018573111588401452, 0.017504240818587796, 0.01877315219358674, 0.015297767074246491, 0.017858870360734205, 0.02108111442066729, 0.03234153367312891, 0.037390665417271, 0.018520496286717907, 0.026346529202003564, 0.022286821955016682, 0.022175028221681714, 0.08199994598648377, 0.05147980725658791, 0.018904486039121236, 0.049836816133133004, 0.03640554452847157, 0.058798384187476974, 0.0704464487997549, 0.021696847630664706, 0.030120325540857654, 0.03325459753562297, 0.0641067468428186, 0.008388033785325075, 0.03894241054409316, 0.006090283086190799, 0.003653569263406098, 0.03400171548128128, 0.039977413934788535, 0.025833634759432504, 0.05004282954281994, 0.06167960672506264, 0.01471009467994528, 0.06094235807125058, 0.06377311795949936, 0.0441448912024498, 0.04442223221329706, 0.06649754462497574, 0.053258827687906365, 0.02240681748038956, 0.04626950987481645, 0.005768352146593055, 0.028053250030747483, 0.028427287370764782, 0.013469315366819501, 0.024186389221410667, 0.08862527047416993, 0.012257996347865887, 0.04450080996113164, 0.019034998857283165, 0.0993032335702862, 0.032835805722113164, 0.01915416487359575, 0.06262076193732874, 0.036813021770545414, 0.04297985336078065, 0.019670394315783466, 0.047675641386636665, 0.032487140502780676, 0.046237306602831395, 0.02406702303726758, 0.012139612343162298, 0.06473646805222545, 0.036072729887174707, 0.024273428300927793, 0.0494129522703588, 0.024391445896721313, 0.051216053909489086, 0.005107820782411311, 0.013452294315876705, 0.03435790565397058, 0.07177761237003974, 0.024664042251450673, 0.058902098265077384, 0.017063668030979376, 0.018500433702554022, 0.016932142499302114, 0.07390435824968986, 0.03688969962032778, 0.026108473672398498, 0.03924448076369507, 0.05475357587316206, 0.01999683242424258, 0.053227828815579414, 0.014012453811509269, 0.03207380071814571, 0.04140474966594151, 0.08067038375884295, 0.019029774137639573, 0.066219494545034, 0.015707578476784483, 0.028875593761248246, 0.055121077224612236, 0.05825176316180399, 0.008809404031905745, 0.03069141793197819, 0.12040436986301627, 0.04396058073533433, 0.04042128440258758, 0.0336889413717602, 0.011914342109646116, 0.04357271654797452, 0.031867790701133866, 0.04290553002751299, 0.01134854313983981, 0.020290414170761193, 0.06346146004008395, 0.01958570127109332, 0.048916329097534926, 0.02587687101082078, 0.041877936239221265, 0.029271681793034077, 0.014043115112664444, 0.022903606894293, 0.03364840568974614, 0.04488259447472436, 0.04949398970763598, 0.018032051157206297, 0.023008559298302447, 0.02822524169459939, 0.04152488089831812, 0.08878431908254113, 0.042516759995903285, 0.03862457117065787, 0.02849087119102478, 0.021436785514067327, 0.01004502223804593, 0.03532858731757317, 0.02443569486162492, 0.007421422483665603, 0.041724180203995535, 0.039068974288446565, 0.007552859805790442, 0.058788212947547436, 0.05286525362836463, 0.04498507361859083, 0.00864903991376715, 0.03275773009019239, 0.05104816398982491, 0.07600253101970468, 0.005523938743863255, 0.05843795317092112, 0.007059642030591411, 0.05458599129425628, 0.018500964656206112, 0.02011130128188857, 0.039988602977246046, 0.05316057242453098, 0.021657263594014303, 0.047698949064527235, 0.058918749514435015, 0.06977212748357228, 0.0475730570698423, 0.020037466493834342, 0.09180304674165589, 0.03794379359377282, 0.015666703527261103, 0.06590400290276323, 0.050034093404454846, 0.05579804822004267, 0.04253305162170103, 0.05239243685667004, 0.017426889522799423, 0.04695850790345243, 0.022758037384067262, 0.02282671021696712, 0.03967713165496077, 0.02785537564860923, 0.061741129495203495, 0.02837238710240594, 0.01594514206850103, 0.02293212741746434, 0.01103843906561711, 0.039992379024624825, 0.04048041194411261, 0.00922521622851491, 0.037441935523280075, 0.04078486042895487, 0.01753344157311533, 0.020355716380955916, 0.02936412879664983, 0.002579318347021139, 0.013794527023232408, 0.044343671428837945, 0.014445820557219642, 0.06066273379006556, 0.03642655875799911, 0.010932603717914649, 0.088829360237079, 0.07519897592387029, 0.01760432473383844, 0.03658078298238771, 0.023323938982295137, 0.023488627913008844, 0.049074746668338776, 0.03328337759843894, 0.03150707469987018, 0.05365971974762423, 0.029635301924177578, 0.014673116217766489, 0.015134187548288276, 0.020349794466580664, 0.017910323671198318, 0.05435370500864727, 0.08902316340910536, 0.03434965806081891, 0.0239053111789482, 0.09992616264415638, 0.04434744408354163, 0.00740319533672716, 0.013705272526879395, 0.03449810116684862, 0.039070317787783485, 0.03132289654708334, 0.030444899374353032, 0.0062349798307488, 0.029074089002928565, 0.042816143216831345, 0.15943685253815992, 0.01030696983382638, 0.04121909909216421, 0.05792903833623443, 0.0332228556674506, 0.008342426054046621, 0.02028499437229974, 0.04650280039225306, 0.08094561791845731, 0.018799718535904373, 0.010204279495935355, 0.006077656821746911, 0.006722825304937682, 0.010102222740117992, 0.03241844561749271, 0.18238326481410436, 0.1525439681219203, 0.18234471045434475, 0.11174680585307734, 0.131724301725626, 0.1317742011908974, 0.12969655410519668, 0.12793547074709619, 0.19520829591367925, 0.1418654147003378, 0.16995593665965966, 0.08815051309232201, 0.09624116787953035, 0.11432392256600515, 0.19473223574459553, 0.06737130773918969, 0.13829079722719534, 0.10206060989626817, 0.1331057311700923, 0.16954478515045984, 0.1656909640878439, 0.06164313546781029, 0.184629012165325, 0.1577825027384928, 0.09222930922572102, 0.11197180127991097, 0.12943165403391632, 0.13294596331460135, 0.12712919472583703, 0.16080553909497602, 0.11508803442120552, 0.07761825182076011, 0.09371966389673096, 0.08373599140239613, 0.1750040879206998, 0.09082162047603301, 0.11692356664155211, 0.1213044465652534, 0.11133833455720119, 0.20091770669179304, 0.09061703538256032, 0.10971948570970978, 0.11551905343575136, 0.0915098517600979, 0.11738887881594044, 0.1239940779549735, 0.160843998459833, 0.07101134277348008, 0.16388521955481597, 0.17631127206342562, 0.1307561815317188, 0.14304066449403763, 0.26248084966625485, 0.13099361450544425, 0.0876223821459072, 0.10426683258265257, 0.09779753043715443, 0.09743660409003496, 0.11411824503115245, 0.13477255244340214, 0.14882835107190268, 0.13594154614423, 0.11920386499592237, 0.10898546688258648, 0.1472260991909674, 0.1298490073531866, 0.22735941569719995, 0.1129454243928194, 0.12778642374489987, 0.11505408052887235, 0.15750758749033722, 0.10775170022887842, 0.1183247414550611, 0.18569965900055, 0.1311950986938817, 0.17738277385277407, 0.13081503765923636, 0.12736322145376885, 0.07149480575961725, 0.07907532434910536, 0.1470462874110256, 0.10779455650065627, 0.142482121608087, 0.06150100273745401, 0.12351416370698384, 0.06701030675321817, 0.11024137413395302, 0.13422714599541255, 0.10021388184811388, 0.15224820827799185, 0.22740618033068521, 0.0794752664597971, 0.1279663983732462, 0.07838358503899404, 0.11347424065960304, 0.09330522827804089, 0.12106447587055819, 0.16001207381486893, 0.18888932998691285, 0.12545381034059183, 0.1676396895200014, 0.16215866005846433, 0.10483528207987547, 0.13461013830133847, 0.28131584184510366, 0.12011699671191828, 0.10496843100658484, 0.1584102561963456, 0.07127140489007745, 0.11556329391896725, 0.13510002701410226, 0.17837677337229252, 0.11994064546057157, 0.09541644249111414, 0.11584655514785222, 0.11195370475096361, 0.16821503293301376, 0.1879789259816919, 0.15632795436041697, 0.14021242197070802, 0.09775939676910639, 0.12047755665012769, 0.10082031573568072, 0.08713931271008082, 0.14425579857613358, 0.10278195368924312, 0.13080072057034287, 0.08304915790046964, 0.15391787939838, 0.07961064098136765, 0.06681481402899538, 0.27206884803516523, 0.2501268982887268, 0.16662314906716347, 0.0848770294604557, 0.1466681941279343, 0.10974152452711548, 0.152026734447905, 0.091854099716459, 0.08666368001805884, 0.229887311479875, 0.13300529441663198, 0.0798263404784458, 0.11300517618656158, 0.1268059949257544, 0.10660444679004805, 0.14633417847965444, 0.18263037369719573, 0.0835645120324833, 0.14326607382723264, 0.13790950125881604, 0.08014132321945258, 0.09187636923577104, 0.12301754392683506, 0.1351113449782133, 0.08973629014300448, 0.16847478970885277, 0.13723165834588663, 0.10150987016303198, 0.18758173872317585, 0.1468338788087879, 0.23547371742980822, 0.0823658663513405, 0.10839003204767193, 0.06211248492555959, 0.19515793504459517, 0.09613596781023911, 0.07324408260839325, 0.0833524494831051, 0.26275329504694256, 0.10074255562254361, 0.12460195033677987, 0.1582642083189317, 0.06550003029406071, 0.07619325364274637, 0.1439714924033199], [0.03745066487629499, 0.0695068406473313, 0.03271743868078504, 0.018334966152906418, 0.05786697273807866, 0.02242138223456485, 0.023174486555425183, 0.04741835787094065, 0.04184481015961085, 0.031012134293892553, 0.029346992394753864, 0.0288377654339586, 0.03331795235031417, 0.0426101298071444, 0.04129879642277956, 0.057590476503329616, 0.032640916894056966, 0.05128643834697349, 0.0333370666817895, 0.007010750189822699, 0.04251138939123068, 0.05639303182916982, 0.04491845165778484, 0.04190108785405755, 0.043632051042680225, 0.0742083147966436, 0.01295498667085277, 0.04019675377224173, 0.055591685364821126, 0.02434814688084381, 0.03356125804462603, 0.017685370652803352, 0.026419283423040594, 0.02953927904101355, 0.029314853583595583, 0.013044961262494326, 0.0025766879636129098, 0.008516459260135889, 0.04251644108444452, 0.025122759065457752, 0.01807831706745284, 0.028930850260491883, 0.043710435408034494, 0.043471228065235276, 0.007390957957665835, 0.04424096836841532, 0.027102944773754904, 0.03270302659698895, 0.026786854324330176, 0.028838410042226315, 0.04018234508112073, 0.013270806554438812, 0.028547969912844043, 0.03000623666282211, 0.012988333274344248, 0.05199048288964799, 0.03296991477587393, 0.048014888539910316, 0.03769191800217543, 0.03578844067773648, 0.09286316949874163, 0.011851745557838252, 0.01633351176444973, 0.0169336301873305, 0.014730829013777631, 0.02157789365654545, 0.03494516074923532, 0.05922081973403692, 0.014299716700666716, 0.02565511898137629, 0.023444117712123052, 0.011438345553220382, 0.02628246701455542, 0.06473834759422711, 0.02963534602895379, 0.04502482219998326, 0.08143036333577973, 0.024129086939085807, 0.01914904871955514, 0.03364346256213529, 0.05553638476080128, 0.0579756944041167, 0.02715989082519497, 0.02195940336345562, 0.04414253668593509, 0.019185603097347275, 0.04866560023011906, 0.035227105620184114, 0.05063227630619492, 0.02032289733844144, 0.0093938525366996, 0.049397844688168595, 0.07480707445314952, 0.018677115739722337, 0.02710093800643725, 0.0648276156612805, 0.01487138754289065, 0.04517142986878753, 0.08046294881829194, 0.044816725687789064, 0.057795176947755475, 0.013407948659732938, 0.022330677369609475, 0.014860585265393769, 0.018254446098580956, 0.06155555695295334, 0.03266135097614356, 0.020399273240140507, 0.02044535255325692, 0.09372760954179934, 0.020045608914058124, 0.0800351799864854, 0.053819341718086174, 0.04691199093524899, 0.06480755138077907, 0.043877589117203436, 0.03327442772154297, 0.05056582397914358, 0.013805733877234161, 0.028618167753198316, 0.022638306487351656, 0.04041474671768291, 0.029943163440163647, 0.060701790265738964, 0.038918132561125925, 0.025619075201185684, 0.031309179961681366, 0.07309894396790437, 0.027601820682840686, 0.018626597111246417, 0.04593648149498871, 0.036089058832398484, 0.017529986133532863, 0.030138269399425814, 0.059940765744873455, 0.03576618133644972, 0.01950755269665803, 0.05288267840764352, 0.07857162744871207, 0.014744448907939451, 0.06995457876473665, 0.040892479475587606, 0.03101676868806992, 0.039599164588642974, 0.020099966354402046, 0.09353637801749365, 0.007352266194564956, 0.05427789907636387, 0.02923334456448044, 0.013362185713568968, 0.026758394869310514, 0.01167179552638637, 0.006413548195268959, 0.014392647160483258, 0.007034249977940428, 0.026582776435783932, 0.01120957831985184, 0.03671519737690687, 0.06703872379979917, 0.05155248514243534, 0.03285744081118277, 0.018850286358169148, 0.02360307302192918, 0.010520817778472389, 0.03698518306815198, 0.02694251704295831, 0.013445511510196542, 0.05147902015596628, 0.06358083470591477, 0.010677050466516187, 0.0467961684002408, 0.042171327995934656, 0.02105334707136665, 0.02093147030765457, 0.003597299202478358, 0.04144387060244169, 0.0427211313508451, 0.072288440673479, 0.022849145977358733, 0.005044866727465498, 0.05566811554932168, 0.026825797145387957, 0.029963200579264333, 0.026283742660390477, 0.02157961204648018, 0.03818606112950614, 0.030331970791199377, 0.039686251165611405, 0.03962128483025091, 0.030820315836795738, 0.053706402956907234, 0.03657207398542336, 0.02473158193086939, 0.011730106281382697, 0.0510737719014287, 0.014673233265057206, 0.0208333066465067, 0.02327797671646944, 0.04403106356039643, 0.01894905391548361, 0.030473411415836642, 0.04006360823820744, 0.05444226400660617, 0.024512352355356728, 0.029874088575265238, 0.0423473196237215, 0.0175023052974471, 0.032567278881158145, 0.015834491666672484, 0.029107710413102592, 0.03552346936027918, 0.026861613616347313, 0.03681558324024081, 0.02129943815193006, 0.04970619814204318, 0.01548819792723017, 0.031117575243115425, 0.018388007235314165, 0.017716515410159315, 0.05441537705649223, 0.014018853244903897, 0.014307743769937327, 0.012169241422920354, 0.023538946373654262, 0.04298928160486477, 0.026123637233727744, 0.02925556319366608, 0.015109093626961112, 0.016917650687641332, 0.03586239081674388, 0.018465572269633412, 0.06255507974752358, 0.022429595900965587, 0.06167496554553509, 0.07054282112845353, 0.025671612471342087, 0.08321282733231783, 0.007668719660224659, 0.030812980873244147, 0.07010187514658485, 0.08117483383310692, 0.04573704648230757, 0.027791966551116536, 0.06360567587294749, 0.05181674060544797, 0.014163912157528102, 0.06200096769524472, 0.021079850649195056, 0.07380375186247484, 0.09140712834362473, 0.044632571283727884, 0.021643645396190028, 0.06744264891105038, 0.027486564724573066, 0.0320029175574226, 0.023808122911889638, 0.00927382817358843, 0.014576894863109504, 0.06119689691279616, 0.02793117649187999, 0.02615258693029838, 0.06003324328256505, 0.042037493748856444, 0.08977712438042675, 0.06086694568927799, 0.02845721415776227, 0.0323428941358413, 0.04023860241951687, 0.03653740084597042, 0.027626924782193134, 0.030302546120115688, 0.018954292205827575, 0.048204912271882804, 0.02635812197279717, 0.032966328718300374, 0.03244950555797134, 0.04087503434025815, 0.05751627869904041, 0.03616926506427782, 0.05593102751299739, 0.04086409296308245, 0.017546276062993065, 0.04164656936856253, 0.031617516452180486, 0.09474366144942385, 0.036407054268888066, 0.0013954701363607974, 0.08150547716234412, 0.043602402455040386, 0.02050203058336462, 0.007775217427739075, 0.016003163597945656, 0.04012569079973868, 0.013793013890140822, 0.02868344621466739, 0.029398218395986726, 0.032041017298719714, 0.07057990306722266, 0.030966981181076596, 0.026298163225874305, 0.05014138336160353, 0.0661352544224688, 0.06217103571231876, 0.06394581190709557, 0.04324226999389274, 0.0355507736094296, 0.023188208229839802, 0.05646712785320623, 0.02965314400249294, 0.07506115189088242, 0.02009509108029306, 0.011428001286861087, 0.03977353451773524, 0.04745531088805624, 0.013826776944499995, 0.03009536223752158, 0.0661488590495927, 0.08543167755539928, 0.11062213405966759, 0.013621588803029485, 0.018348753984485353, 0.0472193299792707, 0.03400638719488468, 0.03532903854336057, 0.008984631459627832, 0.026595838234892914, 0.05455950807247843, 0.052731911319174936, 0.012937670457176864, 0.020671905217958347, 0.0067903806754787055, 0.025287941630397524, 0.010804274934343994, 0.03735937138221093, 0.04931723812062826, 0.03120166269530143, 0.0440225954433637, 0.02584598579310945, 0.042441744556916614, 0.018542507962722863, 0.00933961383998394, 0.038150913015540154, 0.04363471768530352, 0.032554953292544396, 0.03687532485595771, 0.017821690034387366, 0.021023460996470282, 0.03841590129637292, 0.023805464750954082, 0.02327996482407408, 0.015729356058208004, 0.047129135711916854, 0.12424680510801928, 0.19421197580439703, 0.11342810706368514, 0.1312716238732849, 0.13085576333105564, 0.16829301017735684, 0.08427042593913418, 0.12642783378916128, 0.08262788943414177, 0.15161987128002302, 0.11695305577346257, 0.10824866606188671, 0.0940804070393954, 0.14016116543539933, 0.14850536840302603, 0.10111561417579651, 0.14402543593730244, 0.12341131136885711, 0.13591251841613225, 0.07422986506883587, 0.09092093764671258, 0.10519710409321956, 0.221571769831436, 0.11383826112640755, 0.15710380487143993, 0.1630858238786459, 0.14370155760220119, 0.12121717339115483, 0.09211128484457731, 0.09376695778753076, 0.11866884013371808, 0.14547952291156563, 0.15954425106091158, 0.10378149683986392, 0.09862385038286448, 0.17177499404975347, 0.10485752445778676, 0.09356213520680155, 0.0934974504634738, 0.06941561161407403, 0.10062478908470698, 0.15062322547393187, 0.10059709807059594, 0.1764805665505784, 0.09456427036119358, 0.09068982183401074, 0.0874891382242952, 0.17234786759529794, 0.18823895417153835, 0.11518610987280097, 0.13497357522802694, 0.12999586947262287, 0.10063468212527887, 0.10434452484228782, 0.0985420597717166, 0.0894841601007751, 0.07223122660070658, 0.13072667882910796, 0.2026366258838347, 0.1664597714053733, 0.23181454092264175, 0.1046328479424119, 0.13807722154472554, 0.11570573199008193, 0.17269717742289814, 0.12037471788270132, 0.167637273935335, 0.14348475209304265, 0.09402209373989276, 0.10998540358351809, 0.12875545317573206, 0.058482057947133265, 0.1521095157201801, 0.15337024735552923, 0.12236292048224381, 0.10692309362015553, 0.21205371485224792, 0.12490773892828397, 0.09531506257397787, 0.1859280267464263, 0.0844512962337051, 0.11725836939045362, 0.12106609078390257, 0.13341397605836391, 0.12438392346458775, 0.11527541865195547, 0.15513594475175652, 0.1972939632833004, 0.09864814872188227, 0.12072492337652616, 0.14228379939283642, 0.1509622758520501, 0.15704180034143583, 0.13396618142724037, 0.07813831498580319, 0.10356480668165854, 0.11480276472866535, 0.1177473081541913, 0.2161107435822487, 0.1461091355553695, 0.10287477049444403, 0.08432662899472884, 0.07583297190389462, 0.10472382591771227, 0.08950309801314558, 0.16697335456098827, 0.14149756729602814, 0.07792723631220204, 0.19215947522648744, 0.1495874146265643, 0.10181168932467699, 0.21161247710032122, 0.0870685890050871, 0.10663364415190049, 0.2366116749388831, 0.10216986081962075, 0.0889500987582973, 0.11106019626770701, 0.10546388370650155, 0.1288392793919359, 0.22174204140901566, 0.13850509215678486, 0.09604368704770293, 0.193971028019275, 0.12482502550951072, 0.16910820214876107, 0.10451359541288444, 0.18236859488700116, 0.14237310817199095, 0.07978122468505587, 0.1228828275842326, 0.08060588900532041, 0.0751311970608575, 0.13922135372247013, 0.15470263228884765, 0.06668614343340908, 0.13243734703532287, 0.15321741412792886, 0.2050390334001609, 0.12354582415095397, 0.2929741048387119, 0.226799624306815, 0.13747741015894072, 0.15245153808168002, 0.12837057454245432, 0.17299358866044454, 0.12842743577701704, 0.13977176775889738, 0.09865423518099956, 0.1356967578509024, 0.13787455670535564, 0.1938921008259058, 0.0437631474009582, 0.06591580262673752, 0.06293334266436951, 0.12102474085986614, 0.08084411586501769, 0.11037761718034744, 0.16840585055095808, 0.07765150682202407, 0.1597541490835803, 0.08389822234000478, 0.11546654839600835, 0.11740961484611034, 0.09030884477709021, 0.07662901561707258, 0.07345098829162972, 0.2690255641937256, 0.13492780125566892, 0.06786220746913127, 0.14381735638848372, 0.12526760676077434, 0.07052744552493095, 0.08837529817329985, 0.08577167788254363, 0.15416977873870305], [0.03096196341461369, 0.027353493829390833, 0.037115546608609815, 0.05335878946685365, 0.024731961910479834, 0.024095341696270874, 0.012201007039818381, 0.029108433052897453, 0.06020509584673813, 0.030531117426497594, 0.0434135322325996, 0.03212751694289701, 0.036176050414464304, 0.026338987285271287, 0.02245899343064853, 0.00658045254281855, 0.07357614407581942, 0.01132977316488645, 0.03866196862821068, 0.04684539272316864, 0.02533808197560055, 0.04493572037400944, 0.045925492620361705, 0.03296187752857804, 0.05873027962765523, 0.0376606578938663, 0.02771799944873367, 0.020874771921496307, 0.051670434884727, 0.023591115538563048, 0.027500851279390708, 0.09456111517335687, 0.015451492575396384, 0.02421434147150389, 0.03125867660024336, 0.013849653752653726, 0.0120168017456308, 0.0190163306625826, 0.004463980531519545, 0.0463397212858711, 0.028789073761020387, 0.032485474699309895, 0.020316424114363532, 0.08056367734181029, 0.013726903375105133, 0.040978582176778994, 0.07142687083355018, 0.0485129094948726, 0.0029612553189508617, 0.04572192532941699, 0.027686108302857195, 0.033740506640502384, 0.015736665576696396, 0.06593822820910386, 0.07385356990354401, 0.009908766469119914, 0.051126297297222276, 0.09370736884219305, 0.04466640982510788, 0.00437319721095264, 0.040861012414097786, 0.02830734952086849, 0.008880751989116626, 0.07782388185816151, 0.040572746989450285, 0.039191317544983964, 0.01949353246683521, 0.052529945370874236, 0.08386035330061402, 0.013895605840454144, 0.03359925939834543, 0.04472576467586415, 0.026020781502925923, 0.004843666675567094, 0.02667848888917693, 0.03206113925469773, 0.052590799784021716, 0.0382534566202334, 0.04246613110548683, 0.03156907922987427, 0.03565370058640838, 0.043195512145757675, 0.053929064223276715, 0.04767506802454591, 0.004666697109184627, 0.031708097484494956, 0.03604477424440639, 0.055823734163173606, 0.01578436998118247, 0.017753490479663014, 0.07455783497009959, 0.05242909471105252, 0.022649858546044146, 0.025037127946104323, 0.04168887941965035, 0.06516789418778249, 0.029283651150763035, 0.06589494446026427, 0.0077632311066346505, 0.062388227986437936, 0.060413188966257234, 0.004793542445570762, 0.011717882473021746, 0.026780392974615097, 0.036000615185392756, 0.12708092374461039, 0.018441708193027546, 0.02167581983043679, 0.07353849216763463, 0.06973316600280148, 0.006868400752344834, 0.03963587672582694, 0.008137673871325595, 0.027413413560550128, 0.05152666688497577, 0.04800034753446068, 0.023187773967427865, 0.059314362571707795, 0.040458946488797665, 0.07217270295534815, 0.027855738664844205, 0.01178635174541601, 0.012533798780558365, 0.035034961466278346, 0.035608985128679445, 0.02411552980941321, 0.0286927794638489, 0.05511256500280329, 0.012444143100375575, 0.03576909225167973, 0.02221267164817878, 0.02385629211286349, 0.04172186300690685, 0.02611993921787611, 0.033400927005069594, 0.029396603482642343, 0.06403719021805696, 0.018110930853124176, 0.05204749679458993, 0.0558251421233373, 0.023177889408543706, 0.02176865190267563, 0.041083724570593665, 0.02852771564253739, 0.039830724841782024, 0.0340894127397665, 0.039470568631908724, 0.03215908917731472, 0.030372214703155414, 0.012815927704130965, 0.02839027837451015, 0.07229210476257972, 0.015217967963378345, 0.028069417823904326, 0.062012482434511185, 0.03842021677909153, 0.00950261830751385, 0.02547370076977781, 0.03482454436432038, 0.00529355405264401, 0.01310115329189492, 0.02299506832579417, 0.11582344424511705, 0.10078383769307818, 0.02148839319124818, 0.08065769515399422, 0.024553390153284584, 0.03883908323145338, 0.026570795203692148, 0.04497253089877112, 0.04453078085290534, 0.03566012970571007, 0.04079446169946875, 0.048107654454984834, 0.024591113307646344, 0.052916628907301595, 0.01792910212783941, 0.011421208303155643, 0.06558513894144978, 0.04382440893511687, 0.014293854158105595, 0.030768974484609704, 0.016052667816568698, 0.005020766435856265, 0.02782373216801456, 0.020601351146719286, 0.03579989095617618, 0.04199803354484694, 0.023485454065459113, 0.05094448723165052, 0.058424667455255985, 0.03042524560753788, 0.029801868700555394, 0.008663501191352094, 0.031690292725605626, 0.03501652906249676, 0.05679032426061375, 0.06942167093179055, 0.02338716826800789, 0.042883654058511765, 0.0452003592093076, 0.05063631698223097, 0.006898225759089525, 0.025115804081516604, 0.057888075177158625, 0.03048139438033104, 0.031756327753620486, 0.029816626837210994, 0.031051251837717633, 0.04404418982033219, 0.05338629049115947, 0.03573437500745058, 0.03762272439364876, 0.056017296455268345, 0.03966964402102998, 0.014258797646367123, 0.036932881588914564, 0.07370207338993039, 0.031220705780599798, 0.032990033339176855, 0.0377470082603395, 0.0406558743145849, 0.019376668380573392, 0.045858575496822596, 0.03643721515046699, 0.06647963808583361, 0.029630545393696854, 0.012740588264672883, 0.02560344853970621, 0.005458467748082642, 0.02734362453754459, 0.025676867725061517, 0.028097633006317273, 0.06276664018098797, 0.014043054892681539, 0.04260483044864876, 0.05070612805762461, 0.04253121618447559, 0.005413395635384534, 0.049205378230128965, 0.023157155074711357, 0.04487676925158926, 0.010900612488122923, 0.06016880100859063, 0.04225813637354544, 0.032922776948128424, 0.04847489796312792, 0.04032451852357813, 0.08707082817064864, 0.01598016974250121, 0.050135934725403786, 0.015019688156566449, 0.07549048135323183, 0.03446336017389383, 0.02899407615352954, 0.009080215839536061, 0.04353366007230111, 0.04255169776401349, 0.010798208831277276, 0.03227069800985711, 0.0209293464930462, 0.022505934483238628, 0.003020462588340576, 0.029671193033988987, 0.019059393887541125, 0.061680237762629986, 0.04130161912845714, 0.051828777816678794, 0.04596322595274874, 0.034271334763616323, 0.03724767094744103, 0.03288615980584707, 0.027713463442134004, 0.05239851992311222, 0.01746677211485803, 0.04863619930776102, 0.0091474306703146, 0.005679101466999522, 0.03455326606386474, 0.04735746613836714, 0.01874619230095829, 0.07433264276811055, 0.006297888084580856, 0.03422989663002746, 0.03214787977880665, 0.019048252342534915, 0.02481737420228975, 0.05910774865852935, 0.010434034845924802, 0.006993866118136793, 0.05034525599330664, 0.014203022916002997, 0.030398131348192692, 0.030867820073451315, 0.03615795388551695, 0.0782754197716713, 0.02622822322882712, 0.06007713092757123, 0.02116471332763987, 0.05990728682705334, 0.019648421655542085, 0.028522921792630638, 0.003799249035572367, 0.03629531990736723, 0.030204928679657832, 0.012835726507806351, 0.03287288087553211, 0.023166461182492118, 0.04137925710529089, 0.008517508444908475, 0.08677964843809605, 0.029880175034382513, 0.013514023191029472, 0.03662262823698776, 0.03646630055404135, 0.009981675056873687, 0.045605179986783435, 0.007438824362387615, 0.01895587149608348, 0.031023096027118818, 0.026187293996502246, 0.010455753903702965, 0.04231087550786989, 0.051294268641088686, 0.0393264477939478, 0.01008571483128305, 0.055025142551000626, 0.03979776839592627, 0.029299545833574872, 0.050879083241203, 0.06002625437187297, 0.007489006267860532, 0.0020673043036367744, 0.041612696900431595, 0.03106956889054605, 0.049769210296549966, 0.03526417398825288, 0.026452833587037664, 0.03881345496379903, 0.03228194133511611, 0.0402449602926416, 0.01139035277135138, 0.04358316259458661, 0.033041893770652156, 0.014957734516688755, 0.07729329461497919, 0.02710658172145486, 0.00828731119898813, 0.024787693384236524, 0.04163220478221774, 0.04057142723883901, 0.04710077294813735, 0.10149147507867642, 0.09464681414621216, 0.12344968930951186, 0.10504262202552386, 0.11868270938949925, 0.07606004364788532, 0.13859632797539234, 0.1736181258623089, 0.1637497975357941, 0.09044105732547385, 0.14739847422710486, 0.10224661670093026, 0.11713312539671149, 0.17771480817879948, 0.20547936191516264, 0.151394679078034, 0.0950215147542102, 0.13004427616085323, 0.10447567209069218, 0.12905357432152542, 0.13017927748816355, 0.1698504923177617, 0.13461331384522573, 0.17730242173586572, 0.13729614631405898, 0.17338784464768, 0.0887091306171247, 0.07244187779724598, 0.18287079222500324, 0.09289123370711293, 0.10844475589692593, 0.14415621677679674, 0.12574017925986222, 0.17864664031990937, 0.15706027006464346, 0.125325811494674, 0.11985273446355547, 0.11808764774884496, 0.11149327124335937, 0.2032937327665942, 0.13190675979214056, 0.07917856345219271, 0.11029900889843702, 0.13491110929421016, 0.13277400897017547, 0.20571541067745003, 0.2645966847028051, 0.16224498328353676, 0.09140865504741669, 0.1361990908959082, 0.16584360732563905, 0.08601440342941455, 0.07021389449281351, 0.19816818780132703, 0.12218901195696422, 0.141122717410326, 0.09962668442832572, 0.14538900634007795, 0.11964845471084118, 0.05860622985554593, 0.11307445461196558, 0.14098479838243552, 0.08148851378687791, 0.2127962221524545, 0.12389049279902663, 0.13236733579209872, 0.08555445168167353, 0.17958656059844152, 0.14894579191293034, 0.11693659451391016, 0.08442439910556589, 0.1629598063549825, 0.1749827954918146, 0.05232232722586819, 0.12829091453126498, 0.0996672608224409, 0.13968737157327787, 0.1435803576771702, 0.0969422777582492, 0.11905640576566968, 0.20633380035204546, 0.11654685756989888, 0.1430833036346095, 0.25383091238992556, 0.09435956313141755, 0.14527174191815512, 0.14570577362818377, 0.10281766498727457, 0.08943284928266491, 0.12398832397801535, 0.10764688692454781, 0.08715400977858476, 0.1285954410476344, 0.12013161235621997, 0.10668477855090584, 0.17042557788746698, 0.14886085289929593, 0.15417197719216347, 0.10511810226099831, 0.17570455319115094, 0.20442565131400312, 0.08732601840581213, 0.11640781217387744, 0.11780955695680209, 0.08079326645072017, 0.22174007365746157, 0.09375578910112381, 0.07597813768578426, 0.2389416013445173, 0.11967626107590539, 0.1326219221310956, 0.11673633168850626, 0.13849435773278984, 0.12566184917730944, 0.1508842036128044, 0.11818284621196133, 0.07330002103533063, 0.11434205302170344, 0.17227431439927646, 0.17693864554166794, 0.1589202702577625, 0.16998993126409395, 0.07290962591235127, 0.10990971978753805, 0.12924274988472462, 0.09377784148922988, 0.10054422662194286, 0.11397751686828476, 0.23067823903901236, 0.15130979434720107, 0.06350821110286883, 0.07309572092656579, 0.13210785043026718, 0.08851495425083808, 0.17203749210706779, 0.11684658005833626, 0.12863930155123982, 0.1880469016198601, 0.23324896395206451, 0.11801398598722049, 0.21908966159181936, 0.06531740937914167, 0.13321720090295586, 0.17336412306342805, 0.08956195414066315, 0.0791714863319482, 0.13134780978517874, 0.14773063068943365, 0.0802638598584703, 0.08118036389350891, 0.07677420175501279, 0.21597973204084805, 0.0941521010494658, 0.1825587068285261, 0.10659964276211602, 0.19189985415765218, 0.09692617612225668, 0.0712173595758421, 0.07894042480204787, 0.11006015778652259, 0.09501044106270586, 0.2150151945118393, 0.23021496246967996, 0.1725076897335904, 0.11557271198502608, 0.1278342604637146, 0.11106322931924037, 0.1875285008656127, 0.0687208663938301, 0.2315587332206113, 0.17322822606989316, 0.1402621857289757, 0.19779348719332898, 0.1295226862920182, 0.14242980655814919, 0.15909474875245774], [0.03643038908817938, 0.06089783938867705, 0.020224243435742598, 0.03197115533319967, 0.036826941916452985, 0.024912309733086398, 0.02195316762663424, 0.04302056206922446, 0.07483030070683785, 0.02545930225668209, 0.051765779232872386, 0.07063725284699883, 0.024971932605175034, 0.009158039565331169, 0.03270850237458944, 0.09812992438673973, 0.022953713312745094, 0.054020076125328026, 0.02013293806729572, 0.05665054604677217, 0.052895899662481885, 0.045437768434307406, 0.01845892093011311, 0.04078826667474849, 0.025489206991291473, 0.06974046703960214, 0.050035884736904075, 0.04955170250364712, 0.004820370023870575, 0.007873771246522665, 0.014419696959001678, 0.08975524162607533, 0.04208178851487381, 0.0070765816573319686, 0.014808025942849261, 0.04739731650001236, 0.061438720008092265, 0.03495347958856395, 0.03318873214136277, 0.050698128129754744, 0.01806905845712338, 0.016105300081627708, 0.03513234820482986, 0.04444381641224027, 0.04830260435119271, 0.05027364680011358, 0.020198891671108346, 0.11454777126865727, 0.030757710803300142, 0.021973815447251712, 0.01852910519976701, 0.012162428931333125, 0.024800485465675592, 0.052555855230561326, 0.08545296319893428, 0.024960290640592575, 0.028006785649007986, 0.012318050937860139, 0.043863930207278044, 0.02390107712043183, 0.04387168925521629, 0.030154282825865915, 0.03575089394247957, 0.054588376344846826, 0.0654731195952211, 0.040012806321361234, 0.014137266935514552, 0.048754087981901, 0.05082572664001158, 0.00345540968451782, 0.03664711317313569, 0.04258484759234956, 0.0886349735249366, 0.04615863046741911, 0.04798826282577855, 0.0984859788524253, 0.005774579825811088, 0.009354799453701292, 0.03248685212539775, 0.08596731309912034, 0.024927632750145028, 0.034869870503566096, 0.03588779177516699, 0.019132517910163318, 0.015665840091449872, 0.02700457924843899, 0.03534497393827353, 0.07172959244676999, 0.06129316746124199, 0.030849676047052656, 0.024920650624803135, 0.03188165317156485, 0.007848138738024448, 0.036364917244229994, 0.03027464815282396, 0.020607103427339877, 0.01719169401829796, 0.055288736442370076, 0.046922979809875996, 0.06418672576546669, 0.03326921657259975, 0.03883097813065563, 0.03351978598428624, 0.06279606824474675, 0.08201969135552645, 0.1085437745121973, 0.03893657175025769, 0.1246132275887898, 0.044636611959763935, 0.01237657543138734, 0.04156962689012289, 0.010926686892552035, 0.026527876167425087, 0.03098614640267832, 0.06532680030379977, 0.019993492335613285, 0.03634852723085454, 0.051299842806266885, 0.03770676774105855, 0.029516938275524547, 0.031755615291850905, 0.004946509683837316, 0.03388816603858556, 0.015543062572500535, 0.02319695963524282, 0.05245564578633223, 0.1013404263981751, 0.03493511164560914, 0.015398387032161866, 0.013169540291918176, 0.022125903982669115, 0.04315064401764955, 0.05463349553091185, 0.03550361203295844, 0.04036758514121175, 0.057800320243196826, 0.01897045660630933, 0.04253633912386639, 0.04308725188353232, 0.026936825830489397, 0.05987029309783663, 0.018855025925274407, 0.07464188510285956, 0.06691738138241426, 0.04918115452996322, 0.047989273842956336, 0.029269598690526824, 0.062057001117084704, 0.05045251202370439, 0.04182226583361626, 0.02516749657557479, 0.03663881129718252, 0.034326618404260704, 0.05587634098316942, 0.0851266353524157, 0.04607438016682863, 0.025087132584303617, 0.0009489610155079779, 0.0404791600470032, 0.013104633328371813, 0.03398889795477901, 0.01562506522584174, 0.04195653095043131, 0.05059381015598774, 0.009916057327895291, 0.10283504905445234, 0.026065641149346317, 0.013774106511846185, 0.023348781845665405, 0.03384413250855037, 0.04039460779832942, 0.021132654244346277, 0.032059069722890854, 0.07943644068603005, 0.07487840883966003, 0.07130373708371605, 0.05789581047637122, 0.030359356464552026, 0.015820101635264497, 0.05599830765277147, 0.010954400807219957, 0.024002882818292295, 0.05934052009667669, 0.003826927751236196, 0.008222712968875254, 0.03266615839675069, 0.08456545975059271, 0.05591834908617394, 0.03236555042011397, 0.018905339296907187, 0.014555378517668163, 0.07994061256093637, 0.07954552876097815, 0.01505765219085983, 0.028902755518044745, 0.022231580722810965, 0.04486453865787812, 0.04755570014406528, 0.034406383588377915, 0.01889510189981333, 0.04887832774381552, 0.02905572105997375, 0.046839336798127205, 0.01814998054344739, 0.04447104941521372, 0.019631560060328672, 0.024577330565080047, 0.02868718494262014, 0.06857867938067232, 0.029796501488557885, 0.012552804546430707, 0.05891945519085441, 0.0186003734291132, 0.038734161361519776, 0.04593476480139153, 0.06562515893684966, 0.0168066915523793, 0.03567878602604781, 0.01629452144594065, 0.05628271221316286, 0.01937775912561587, 0.013343473414092191, 0.028528370428830385, 0.12096266847636018, 0.008971458550409546, 0.022012815943786075, 0.028576125723442862, 0.04349182499572635, 0.014799186327893819, 0.034850525470184426, 0.01250494662339666, 0.018317578693053553, 0.036601420624979904, 0.06401019809501511, 0.08129557913967542, 0.01033658703922161, 0.06525767794145004, 0.028307702359078184, 0.061637992172368934, 0.01699309190735221, 0.07952270284295082, 0.0436195117155356, 0.06863280611910991, 0.008880544187767165, 0.048560339092676125, 0.0518214428531272, 0.030388340087873594, 0.04068511238853846, 0.0342989070340991, 0.024103830169354166, 0.08469497851495232, 0.047921589974846156, 0.05296567002577441, 0.029958454226808887, 0.045947524652417214, 0.06828999665698834, 0.05287879718733685, 0.058377013940896304, 0.044206546286919286, 0.03713433863595128, 0.03532773914879986, 0.04331145003171904, 0.003946184521607522, 0.03400364591340933, 0.02951856336689421, 0.023727663925715854, 0.02266942410330687, 0.032366171279656034, 0.015546465425619056, 0.03063225307102714, 0.0038527052965946496, 0.01491751944247101, 0.013954192250301796, 0.04137505018817527, 0.05054333732862558, 0.06741390616766044, 0.023106278519013097, 0.035299488343298435, 0.01338524233350264, 0.050051358728004355, 0.016834664158523083, 0.06857891686792884, 0.015165072765999606, 0.017691497824021747, 0.061563930075083456, 0.045950768049806356, 0.03338564978912473, 0.008190400283118444, 0.019502480647393634, 0.041807280387729406, 0.07309352247310535, 0.028097266597407203, 0.05796304651136909, 0.04646009000550423, 0.024753047386184335, 0.038677439226635864, 0.007058774778020701, 0.010862937679381242, 0.047529026932482205, 0.027423540695703456, 0.041291753229285987, 0.0763496763205954, 0.012872553147774721, 0.07245067161108766, 0.06829545886388846, 0.026927071889596324, 0.013271355319635143, 0.005960604017933032, 0.02976301239271249, 0.03864056424104741, 0.02626590397475021, 0.024460851547441313, 0.05521014512383512, 0.04805034877998488, 0.042118758495364866, 0.009986697912349232, 0.022692229665283645, 0.020601179816627076, 0.03486868306728346, 0.040152065455913544, 0.0266644974970924, 0.035106652083673646, 0.031046848145446608, 0.09287411426859242, 0.022553708437564116, 0.026025914620341997, 0.029773814670209373, 0.04563300331522312, 0.01843008997717074, 0.04404245616335954, 0.052197693913642845, 0.025307917701346532, 0.03747410826118929, 0.03993632524673428, 0.03754805500752159, 0.020387612615845034, 0.01734706835954317, 0.03403849207929202, 0.027674374736047218, 0.05510398492749248, 0.06664883757808379, 0.06745009244020496, 0.022502216111336435, 0.01446395440559302, 0.028477429412305355, 0.038735226661499055, 0.039209431037306786, 0.05015236545088036, 0.031964095176330636, 0.04363166767039469, 0.06722846933241401, 0.028575949304338013, 0.17575066643101828, 0.12545915719653877, 0.1371069164680583, 0.17859334817954473, 0.07587460002728871, 0.09920068657291786, 0.09167926159820386, 0.065349877279784, 0.1943785154393741, 0.1242087392934731, 0.1259271835110017, 0.11627039526190076, 0.07678000322942223, 0.1419218009603875, 0.17821073585322925, 0.13565341303391115, 0.1793689408472606, 0.08151944819837809, 0.168611025969897, 0.09960423848990883, 0.12432517590267317, 0.16289857535489968, 0.10060277740870203, 0.16250159165688924, 0.27904972487262314, 0.12191994568066937, 0.1251415620957102, 0.11551267520657607, 0.10285121854394674, 0.10065606954906668, 0.10035697809819664, 0.13867545872926712, 0.1948524314377989, 0.11267280937837702, 0.059611683046179156, 0.09534212255052157, 0.09589802593524967, 0.201740348977702, 0.09315294466380562, 0.08088194419230733, 0.10279161602790866, 0.07557521680636065, 0.10533783904143743, 0.11572222039103508, 0.15899846463331155, 0.10050192674888031, 0.1366096724356924, 0.3073146167610373, 0.18986405911190168, 0.1197655698550599, 0.1289135246936764, 0.08577293317232813, 0.13261823090059416, 0.10844071182821478, 0.17657987693590776, 0.09948117937892675, 0.15908911691180297, 0.14003605714866094, 0.19619784424347536, 0.13726554438471794, 0.22991095163992473, 0.1304590781884534, 0.17932201336537087, 0.07321299213383879, 0.18039301303880556, 0.12911390965538366, 0.16582475762282098, 0.12197402492165565, 0.14772081907306397, 0.14173354820481368, 0.09992509734417711, 0.13767795796905244, 0.20836366500173295, 0.08002471019114767, 0.22016131265887193, 0.2872275103415762, 0.14598577788897923, 0.16037452008043016, 0.15621189773082733, 0.12679287205849374, 0.1700380393969161, 0.1854656051312174, 0.16041031958801405, 0.13154827617108822, 0.062210614659956524, 0.1740478285189186, 0.11896848119795322, 0.123743508543287, 0.19958112841205938, 0.1635934766381979, 0.04776395271931376, 0.155780715867877, 0.13513949061078684, 0.060538527954901965, 0.08121007015662533, 0.13258766968335423, 0.16731856603707584, 0.15899584548813955, 0.13706051824348314, 0.1739721582936389, 0.07976733507322413, 0.09401189535856247, 0.10672221332788467, 0.20768199515129837, 0.13699171479259217, 0.30184852864061085, 0.13033012939350946, 0.25513793368424686, 0.16243482381105423, 0.17214004588978632, 0.16932378629488604, 0.06535797898790666, 0.11767721548676491, 0.1364925844328744, 0.2237765472382307, 0.07458999752998352, 0.1535413060337305, 0.16215172543057374, 0.12066613510251045, 0.10788634193262883, 0.12880225852131844, 0.1327677257359028, 0.13834421150386333, 0.12572717852890491, 0.10262550386999335, 0.13030406007809298, 0.14320740768952028, 0.17931575727249893, 0.14079977545355046, 0.14069096557796001, 0.07243622560054064, 0.08592630922794342, 0.0802392629640443, 0.12227262104196207, 0.14181635661848954, 0.15518270938524178, 0.08403166303677218, 0.10275997593998909, 0.1112534294703177, 0.1119876518579466, 0.10927007839615856, 0.12645364526127065, 0.17997491333101476, 0.2518821326749665, 0.08446467015892267, 0.11622711829841137, 0.12433377972670964, 0.20026198402047157, 0.18296073882707528, 0.14047548999743803, 0.13088502176105976, 0.12896279990673065, 0.10861039986567837, 0.20056185578661306, 0.21113828968788895, 0.08728935037340436, 0.1538493066493954, 0.10375523074929204, 0.20912594481238297, 0.18186984450689384, 0.17799380820776733, 0.07494577379631144, 0.13182792759367398, 0.21081808901258878, 0.16563631487744196, 0.21991068896438393, 0.16681544589144842, 0.15015428992254393, 0.08462078071066312, 0.11298647576144763, 0.10345178988895246, 0.08304710193936314, 0.17351365861083778, 0.1515509049807276, 0.21315310443086283, 0.13343948897506508], [0.026160580072818056, 0.010566830086255712, 0.042300093586423566, 0.11080872440444571, 0.061766703480056355, 0.01855148498101958, 0.003099757886957377, 0.09057108499109745, 0.03175966953858733, 0.04287710619558181, 0.014756340234141265, 0.023655593328710114, 0.026958974909835627, 0.0017913220591643558, 0.023231617507657835, 0.03651904986639108, 0.008834217209368944, 0.04281725940693702, 0.09501345375818865, 0.012314510681400341, 0.030948083980807235, 0.04552348776321326, 0.01482277050880449, 0.04770358006602951, 0.006165276472789368, 0.021897693996184638, 0.02378357181857739, 0.03680706762575677, 0.040531946678778956, 0.04609822728005903, 0.0658847935763853, 0.04271622893533536, 0.02447770974997963, 0.05444982288671391, 0.020308556500822306, 0.06114331300237349, 0.06390098109841347, 0.057205061827387126, 0.05416114694838013, 0.028230208570935895, 0.02770199959299394, 0.09114657768181392, 0.006934853079396167, 0.009503357062515403, 0.040497653518936465, 0.1649879746671234, 0.018118881587205187, 0.020312995816181813, 0.032340733001806905, 0.010298736659543855, 0.04233272094279528, 0.024398166786081026, 0.02089535697762455, 0.051025100584541044, 0.0891703919374517, 0.03599751767303262, 0.022586366328011667, 0.07481729997588055, 0.04215863939108593, 0.05756102129817009, 0.10754220932722092, 0.030413218574332337, 0.01009280891490302, 0.03924827038177422, 0.020786218012550046, 0.02375242536488388, 0.026531124653826867, 0.011387670013521398, 0.03562964991267238, 0.007698671044116574, 0.031120703289551393, 0.035529684741050005, 0.038633253026221476, 0.00674979792009773, 0.030472807519670044, 0.046035601890512874, 0.029210684887532676, 0.05012641827176724, 0.04166622652805277, 0.052191203726189475, 0.08097734621592931, 0.037499668675341775, 0.08504627645015717, 0.03490434686786362, 0.06431839548583541, 0.025812503482614244, 0.015495838231540151, 0.08920117707124778, 0.025022264636520828, 0.052694289945065975, 0.07485910451837949, 0.03327318260978375, 0.06371388863772154, 0.03922729007899761, 0.04613427445292473, 0.043263324935521395, 0.024438826300735985, 0.05175441037863493, 0.04008941292496664, 0.026132066334996904, 0.07922944000789098, 0.05114568643538015, 0.03270144900307059, 0.02868916965754969, 0.04156221389504416, 0.039104909503034184, 0.04058537791882243, 0.038284655660390854, 0.014171716158411332, 0.012137038999104073, 0.06212673416095121, 0.031856486307723184, 0.022440803603136113, 0.012682309740089943, 0.013048761058598757, 0.06505130830087832, 0.028050045649121915, 0.03910231410658785, 0.057746539557618756, 0.09937396406063012, 0.04794056520664266, 0.02192153093138976, 0.024992951923715215, 0.03741197820220675, 0.0463196875394455, 0.022593692809875523, 0.03989664791151881, 0.039160939532199075, 0.03508756828627416, 0.02562305480907006, 0.022413763982642974, 0.03877312623496566, 0.034360911564103196, 0.040200967474707534, 0.07061100032712732, 0.00195540242878321, 0.07745020583804164, 0.05466282181441784, 0.039834585706038136, 0.043418597496513806, 0.103795508587999, 0.01810811154012169, 0.010281004843169024, 0.022628873154254894, 0.0039009805186651647, 0.03605544420757464, 0.05360180339110749, 0.015072525678468602, 0.0540972018082227, 0.04389464748757226, 0.008898971502536109, 0.042402610049716065, 0.02785322129992502, 0.07378171304506914, 0.0321601035871676, 0.0492349827129926, 0.07038889545947313, 0.04454177312020745, 0.02136228745803237, 0.02658869495748409, 0.039289348891803196, 0.01986130353595529, 0.016137206494542103, 0.018971342094508663, 0.0681930272174733, 0.028405377475012625, 0.06453822726117713, 0.07681880186178855, 0.027307506118501936, 0.00970116104664547, 0.026197775666202818, 0.03827349715200918, 0.01803499091017459, 0.008244242036848195, 0.01931087762516524, 0.018410656734236648, 0.017356795159035494, 0.05797491408884525, 0.043613231873938015, 0.02557783553908978, 0.011945230720032538, 0.07148878715400185, 0.0027583504478181048, 0.11058792232402734, 0.05390483034508569, 0.048464726723198376, 0.029953874115433012, 0.04393501014315656, 0.010174879421746092, 0.02594991191290319, 0.03280810113730175, 0.015244167896785905, 0.02300734132794397, 0.0647821266736303, 0.018469580715256076, 0.04031146690249443, 0.062418626355273385, 0.057862955810768266, 0.04189236189371773, 0.039320215449801514, 0.036042833634253056, 0.007840409375993269, 0.02019120386934706, 0.016352334325867038, 0.023135764258248464, 0.023360815664221133, 0.02131793162386332, 0.03217934684029647, 0.040788758612637005, 0.012557910522446036, 0.042269505227782896, 0.03299867108996425, 0.020947487126769762, 0.03627642609977296, 0.004923479781220002, 0.029627441095986536, 0.04798536208857383, 0.06871753478688852, 0.05161341419443488, 0.04550824786669441, 0.017092931549996138, 0.08037885797343083, 0.027953854828540767, 0.05742665779377733, 0.04098903840141637, 0.03848676749372056, 0.03253297554329038, 0.01602921594998666, 0.00937483150378934, 0.03639858954453042, 0.049306822608092, 0.014059810466798288, 0.011007957576241876, 0.032287732631500275, 0.07079216239175626, 0.043247722022767575, 0.042161333175109963, 0.06091235325272594, 0.023950023244002035, 0.024103965876357894, 0.03417136619931885, 0.04148505428539855, 0.01640592671797744, 0.022876209346577525, 0.02012375239948077, 0.026932659625474895, 0.07287314108439855, 0.06630773123885904, 0.05011667111622436, 0.019422019964882305, 0.01878615970989423, 0.03547029935621789, 0.05769506589110408, 0.07903919914471251, 0.01798136459131326, 0.06523417348840407, 0.050639899647129435, 0.06930399938885655, 0.049757383431174924, 0.02629281297725226, 0.06775417112346206, 0.03523106487201793, 0.017356879975912825, 0.05314011120104364, 0.060145072638988495, 0.038518204021134546, 0.03567350363092763, 0.05761194535131965, 0.04815134532483561, 0.03332790985171284, 0.06112664818231549, 0.016520753502845764, 0.035081617534160614, 0.026585987602759684, 0.0890143628099135, 0.027579581697604487, 0.06357149127870798, 0.014061691705137491, 0.014505982864648104, 0.005356945338592465, 0.033257345602448495, 0.037251287539090426, 0.06035548634827137, 0.005752089782617986, 0.04931475807513509, 0.006230017195256161, 0.0976960826665163, 0.028458172588476112, 0.023554759632263864, 0.011555229995532759, 0.026730367980365242, 0.019280260428786278, 0.01686085730658046, 0.021205496674935733, 0.033391648038689575, 0.01965312220688377, 0.02850851310150964, 0.017395683697291782, 0.07764573248901538, 0.03673729726246425, 0.05002449552661606, 0.06089419565562691, 0.026984676120004485, 0.01564255616228495, 0.04299254875097956, 0.01383977004193834, 0.08277547758604799, 0.032656563911587, 0.036394460658941946, 0.02842024926628385, 0.004842297731166971, 0.04822095623239875, 0.06939509950046029, 0.04471763243366565, 0.025685710732692053, 0.00675549719016999, 0.0607062889529126, 0.0852569140759962, 0.021715422526800206, 0.06309634034654923, 0.0362348895786064, 0.024601267584200417, 0.020673150329717567, 0.03398762570161905, 0.036395603990448375, 0.026329520025423596, 0.02770878833585552, 0.05964907032570668, 0.022292348622743572, 0.057532461759235175, 0.03008804763002055, 0.004696748576991792, 0.02836329982216869, 0.02201175912549453, 0.045354909130505154, 0.02049901958421937, 0.03182642720639706, 0.04507785988971591, 0.07182169679020133, 0.003998048769842301, 0.027270653185301592, 0.012220297790398555, 0.06432102820170776, 0.048457059277487655, 0.061602301230388026, 0.024515519417556267, 0.03654954323012914, 0.025527266020487462, 0.049398068604724746, 0.029670070058533123, 0.028026424148785214, 0.021287372102960944, 0.11168890645993607, 0.15633463114500046, 0.20800762410674775, 0.16512444163007395, 0.12857752772314207, 0.19026408264679567, 0.0796313973675881, 0.18163051163511618, 0.13116095481174334, 0.11745427602103778, 0.1497182361781597, 0.1724571795868022, 0.06379460037818976, 0.10748270180608545, 0.09325635340064764, 0.07963194019560303, 0.10105589630880527, 0.1246555003204516, 0.1814405761126961, 0.08006669793810163, 0.1357724823589836, 0.1948962512293032, 0.20960689043360098, 0.1840356740036181, 0.10535010695457458, 0.10431199587349381, 0.09892835654318333, 0.08395094451095376, 0.15198267038379396, 0.15700914923633846, 0.11842999580715384, 0.09881238812314612, 0.06624829157122544, 0.11170172398643834, 0.12432646511920861, 0.10772185825875827, 0.11855880889509406, 0.12917429927204335, 0.09795716258564166, 0.09629860586885895, 0.08444709610193968, 0.1429394134985549, 0.10538474616727658, 0.0896273445604103, 0.0895445022199835, 0.20861735567450523, 0.11148035872195448, 0.16330497711896896, 0.08465299755334854, 0.07868686983627932, 0.1272868998348713, 0.10104458513004438, 0.1096779525812183, 0.15228548699191638, 0.18824966145413263, 0.0997891528531909, 0.1327816764158862, 0.11958540523690836, 0.19363277831247874, 0.14668945941541875, 0.22568447914506706, 0.17413618734904698, 0.1371773619736944, 0.10792670798088823, 0.07770103309303522, 0.12446430272289685, 0.12111334396260125, 0.0961402425808566, 0.16058521877442086, 0.13527089570249828, 0.1940481231680938, 0.22626447730830737, 0.1782016163425786, 0.1253436298242637, 0.21442815315510544, 0.1347235215029546, 0.13073277207357542, 0.22586245888045856, 0.1360645509724106, 0.10702063981443644, 0.12327533295111996, 0.16788259148597717, 0.1570209286042622, 0.11826485395431519, 0.20006077124604157, 0.17379639058240823, 0.04085351799481681, 0.1699520961514541, 0.14931492853377545, 0.14649523555168084, 0.24020438215562276, 0.11695477925240993, 0.13391132865633282, 0.13512187584170274, 0.09213780199310609, 0.11424522607454232, 0.13053003938070365, 0.08850576010133539, 0.18259658265326703, 0.12595416206334317, 0.13623547394360813, 0.09270226170441934, 0.11751341713326317, 0.11777116544544697, 0.07931166488145079, 0.09981939515897206, 0.10887173084276063, 0.12287327381117003, 0.14046270639768668, 0.053932036206658394, 0.17635762957589968, 0.18084864930382796, 0.09877135032521826, 0.10557901752846581, 0.12098512798547745, 0.17930876836180687, 0.14897334043468746, 0.14102643329117978, 0.14134624041616917, 0.1764035935380629, 0.12045368578817163, 0.0904719578102231, 0.1506345977208444, 0.11577807739377022, 0.10766756867191621, 0.11982298748833792, 0.10218623386962072, 0.15127627471727983, 0.12028430987681661, 0.08501863293349743, 0.10215968279434101, 0.09103339804070336, 0.10059028557900872, 0.1267682412373168, 0.24549166272793496, 0.13516500352748803, 0.1741852861429964, 0.10494151352239506, 0.09721572737076453, 0.16165752123509133, 0.20029762067965098, 0.17758173389094217, 0.09294296521693468, 0.1611315073179347, 0.13452069381518023, 0.1150170053754534, 0.08553693869284221, 0.15450619640094893, 0.14214818738400936, 0.10751735458948783, 0.11060749127396516, 0.1935230184878622, 0.0728800892829895, 0.13696557762367384, 0.07477878632822207, 0.1306473445147276, 0.17607127422732965, 0.13013756115521702, 0.08300387925867524, 0.06880794957812343, 0.09306039927261216, 0.11122897506824561, 0.13427956961095333, 0.16385898739099503, 0.3087353605244841, 0.06141134790543999, 0.14382644875773362, 0.15192377354417527, 0.18822623842528888, 0.13330108140196117, 0.08053473782326494, 0.09077784818198, 0.059069499639528136, 0.07597912834691149, 0.08578672100390707, 0.0712037074512669], [0.03654381978724684, 0.05802681523242167, 0.01954289080042924, 0.034046624321490526, 0.01823681266978383, 0.04635408247954079, 0.030463179107755423, 0.021065016177349856, 0.059631659117128165, 0.011523175153083034, 0.03480212217462914, 0.02925496269017458, 0.05935253016650677, 0.038807758662317476, 0.02883406063275678, 0.02672100589344544, 0.026925200829282403, 0.03153662829260741, 0.012109475210309029, 0.03322620423776763, 0.026578296408323304, 0.05004919080861977, 0.006867056404839137, 0.026703910203650594, 0.012022942487549568, 0.06293680319296462, 0.06721373155180897, 0.0670287221936243, 0.010885743241358017, 0.00890205629236464, 0.029353567399084568, 0.018030018944825445, 0.013506284499141787, 0.021962950405265604, 0.006272488398410912, 0.012226741328569395, 0.06502697603510958, 0.07752980478107929, 0.024129821453243494, 0.02264255750924349, 0.07636898742722613, 0.057225587511701245, 0.06630049805556025, 0.008331890101544559, 0.04264532881123679, 0.04951494626168694, 0.020506132327552353, 0.041850268973835876, 0.027421506786985055, 0.06177011651120015, 0.07369776469256197, 0.025560256393094147, 0.025417063451771225, 0.09059481336069958, 0.039316008532685895, 0.009912384757106858, 0.030530293006449938, 0.01405230162864817, 0.11609302620802607, 0.02887467434629798, 0.03265251984287586, 0.008148821353513216, 0.045389819757214615, 0.04628149280324578, 0.04746038632999573, 0.014838943390973976, 0.03236429173765438, 0.046474091575614045, 0.045415838182504685, 0.04071793652006558, 0.06211652220892055, 0.05663907201960683, 0.014790797938725777, 0.07212746502565485, 0.03243807563558221, 0.07720159739255905, 0.06563404774559395, 0.022563056953783547, 0.0568738858481603, 0.030133166816085577, 0.014301633562094398, 0.05210341147280165, 0.021245777906317796, 0.0359692668675312, 0.03413410105609468, 0.0456271882701133, 0.04398118445117559, 0.03572193406788366, 0.05984121787228754, 0.01176068022115422, 0.004581131722911128, 0.043151383620819876, 0.026199129343565022, 0.022502697871199677, 0.03831374445664031, 0.013855864892580678, 0.04735447719161, 0.04332950245589018, 0.04162286135501095, 0.02744619019462594, 0.04534137574955821, 0.011832936567121317, 0.08768745365419559, 0.010266614811761039, 0.04935789593894567, 0.01742068601639143, 0.011235120074291314, 0.08347143059862511, 0.054941200983843634, 0.04498114829350795, 0.006523813104390034, 0.046889005561492274, 0.04614002164453268, 0.030520257473524128, 0.037494956249637265, 0.029782231897115707, 0.008569371420890093, 0.00961206600602184, 0.019528388810743178, 0.007659996244391161, 0.027872230458472456, 0.03640669464532818, 0.03231878578662872, 0.09131609608552285, 0.06233803675110851, 0.08876266024474587, 0.05892605733658586, 0.06661285486604486, 0.028401211269998124, 0.05206160693030272, 0.04970205907842942, 0.01250881512117173, 0.04706769097330315, 0.018771588170368756, 0.020606582651713064, 0.01500156957523099, 0.03609314361321075, 0.028230912551017742, 0.003366175332173173, 0.01291870794791196, 0.026100775692611933, 0.03390197761889015, 0.009120267217180558, 0.028466762841812203, 0.00519264698959887, 0.05162350061748709, 0.10386410169303417, 0.028233658921505724, 0.05738650209137371, 0.06243615970015526, 0.04494780169001647, 0.04861989750393799, 0.09066954042230334, 0.058541701175272465, 0.026200172591156194, 0.014091159632828618, 0.06321453436144761, 0.05938555446586438, 0.025999662100470493, 0.03962301170187337, 0.0346677009947598, 0.025662128248118928, 0.007203439716249704, 0.03183000647862043, 0.026121085942057625, 0.03306209375815732, 0.011449521873146296, 0.011496234768336373, 0.01721315099192517, 0.007977528580730515, 0.003854483482427895, 0.038281086566192765, 0.020567081735602448, 0.03227514919957944, 0.039041042394403896, 0.026350690318005424, 0.010853775760291942, 0.022632944364366785, 0.03767418788213815, 0.006252806642026241, 0.018415879757542695, 0.07272467083696808, 0.02260095652725015, 0.014547049500314253, 0.06884087209722825, 0.026489369305116788, 0.07612571905234031, 0.06431224117321627, 0.07184900782470192, 0.013410851093275207, 0.05536895963762488, 0.07632847210126263, 0.02002226052406643, 0.07457238954624959, 0.027614622942305038, 0.07495194846498114, 0.06933844861175333, 0.059931245898561816, 0.022042920846225958, 0.012357993749901652, 0.036263228593660254, 0.04540705454668828, 0.04530062972168837, 0.014236350011612688, 0.006798612153423684, 0.03362421252365623, 0.03759059915319085, 0.00837198643213404, 0.01416124721124236, 0.023574033419468572, 0.040696179294692617, 0.024538355513608882, 0.027882995416543314, 0.03635372480909739, 0.031645665477429114, 0.029506556689739227, 0.06256548168935946, 0.018338284189147607, 0.04404416267893144, 0.027417625566678386, 0.04201817246420043, 0.052360467679266415, 0.02487575705163181, 0.004044323585860963, 0.04282724744241152, 0.0070264162911501315, 0.029211804470313445, 0.03403989664678063, 0.04447064568687763, 0.06367447253848825, 0.053920996441904984, 0.0431219996618373, 0.06194084270724228, 0.01369276034113552, 0.01335149200167507, 0.03545549372211099, 0.06632223153220755, 0.017477338601435934, 0.012281620392708905, 0.018010137868779044, 0.022536093668480004, 0.05075515899807215, 0.005181475334601211, 0.05581505230761, 0.05044603879962649, 0.018654220271855593, 0.0643466632547123, 0.05197676969692111, 0.008282636092709643, 0.009745395592679935, 0.009094560917999064, 0.023492008713739257, 0.05234632361680269, 0.004819194886035153, 0.01193622316765998, 0.06151042080351284, 0.04749752255156636, 0.051021494170916934, 0.0549048213288188, 0.04402184905484319, 0.047486937405275445, 0.04289264804018395, 0.057579362099724155, 0.05789972562342882, 0.033720659491206915, 0.016818396281450987, 0.02814995144893016, 0.047107473481446505, 0.011661000034239675, 0.023940640801031674, 0.0815620127000979, 0.009530944600036102, 0.033221725906644545, 0.049523390629994016, 0.011296253534965217, 0.05110835683132921, 0.06818434875458479, 0.02740124742766576, 0.019171516710360135, 0.05238010109003101, 0.07438161942575659, 0.03057356657726424, 0.018222517633278455, 0.010804609112840678, 0.01358278253714421, 0.004969741026538291, 0.032648190789456875, 0.05300041101872921, 0.036244823331279416, 0.028503766749054193, 0.019564005113872032, 0.06048624683171511, 0.034719290012227635, 0.04931394383311272, 0.02004533410737557, 0.03802216099575162, 0.035278362155492814, 0.01892327467378761, 0.03311027313715645, 0.04178543834547911, 0.09814694883035761, 0.04768855730071664, 0.025837539728464823, 0.020273997015984993, 0.0047198857729589296, 0.015172896274764622, 0.03360615670681, 0.025309676803382378, 0.005955889471806586, 0.06086684390902519, 0.036406545367624076, 0.023402864479326775, 0.015020517665626747, 0.02953758948881711, 0.019976532352822166, 0.02477499290502497, 0.03434294056413429, 0.05667147206674729, 0.033672541180359464, 0.09525654571396963, 0.008025170220727367, 0.014553685572796633, 0.0635042077462588, 0.01746828864062471, 0.010383662950646664, 0.046939162870070765, 0.032257914410105774, 0.018090149021840522, 0.03342304385400244, 0.019675905716472437, 0.05699529951172216, 0.016272903320246508, 0.003921208495739847, 0.044576765171119144, 0.024972972460091114, 0.06303168274462223, 0.07970840430685452, 0.04115074686706066, 0.0447433115914464, 0.036294885644955296, 0.011631895970952297, 0.03461175238979714, 0.01373439100903592, 0.018052761742312993, 0.044695264526775906, 0.08787225945187466, 0.009589237543488187, 0.04250387800857425, 0.01617949449324182, 0.04868189185591681, 0.04543000938636916, 0.051405110729060004, 0.11072734091430902, 0.18407520545380457, 0.04990224387230618, 0.14636973371463163, 0.08501338107245308, 0.22608929313719273, 0.04829039072085704, 0.10417943048690047, 0.10062444981719766, 0.12312404678336211, 0.12379480579069682, 0.10705533330993992, 0.21049966609903745, 0.08690877365214483, 0.11906472460499831, 0.20477726816066674, 0.14926379413477012, 0.1978645705218826, 0.073048718805824, 0.17056687601975032, 0.13017650906528744, 0.11729001626372337, 0.09014683775603771, 0.04248559827517186, 0.08120694211018936, 0.15151130567703927, 0.13222392063055718, 0.09558955713042191, 0.1329686806670257, 0.0777280048600265, 0.13778982125222683, 0.09586937140141215, 0.0842637423692005, 0.08562980978084461, 0.11415035330823489, 0.14096795714327268, 0.14391735887953214, 0.17880723598812306, 0.14514864209507192, 0.12382251716085843, 0.1848079011376415, 0.15124351504657949, 0.11033421808055469, 0.07461964272494827, 0.12534422693508013, 0.14371694677642413, 0.15768666645245893, 0.1529797911643982, 0.101978954992124, 0.13901982882193156, 0.1694072461021798, 0.15341367359672273, 0.1569612989468234, 0.17822581290134362, 0.16660708135792188, 0.14434480879987988, 0.13615133560129575, 0.07599662776504244, 0.2555807184960161, 0.14604912591832026, 0.18817749246954918, 0.09226166856076036, 0.06755510930504117, 0.12494874958481107, 0.1323530865567071, 0.12241109646856785, 0.11664813570678234, 0.13732104854924337, 0.16422695693160805, 0.08531008408005748, 0.16969467353607925, 0.2546629048883915, 0.09786651709250041, 0.11728845563318048, 0.24769739008375577, 0.08788384204464299, 0.1290712705148118, 0.17886995976524694, 0.21501357959849493, 0.12058701791933604, 0.14539793586092337, 0.19477171291198048, 0.16662335262766906, 0.1728199922612735, 0.19684481381305627, 0.132792912955795, 0.1581498073147876, 0.1901778815580266, 0.1521315002547843, 0.14804886361317976, 0.08600706168051277, 0.12046413522745882, 0.2248144886855568, 0.1459708229771682, 0.1805567028267043, 0.11649105484996523, 0.15060388722590037, 0.13060319902641432, 0.1558716395603759, 0.1133250647357532, 0.164951320205416, 0.10439105198851653, 0.17799581667142256, 0.17261711029069765, 0.21268069478017942, 0.17719576960163458, 0.15855376635278973, 0.13723217403250082, 0.14601139937128338, 0.09270093177578279, 0.06919086045984711, 0.17215361659015926, 0.1917518928114857, 0.13971972412296704, 0.10927957788641963, 0.147120492000665, 0.09571480112416403, 0.1345260813832283, 0.14854874036141805, 0.08365803451410361, 0.09269350860267878, 0.08473403499062572, 0.11178860361022608, 0.13676663115620613, 0.15455667940633638, 0.19510449362652643, 0.08433134481310844, 0.1498932032180684, 0.10109023018074886, 0.11873917707375117, 0.1877832364823137, 0.11843650974333286, 0.13808438687452249, 0.11942354749355998, 0.10016835893371276, 0.10094412802053349, 0.09575475326606206, 0.1455523975725685, 0.0477902357732611, 0.14312489783125265, 0.07283373177051544, 0.15082844160497189, 0.12953329857970985, 0.14663709008267947, 0.0855635983337249, 0.0883403332637889, 0.27457375505140846, 0.09316708533359425, 0.12128022286508765, 0.17572557420602866, 0.18179231509566307, 0.11747560916202408, 0.27826235283698353, 0.08620579101677452, 0.12472486017005784, 0.06506719959101506, 0.11046356042580945, 0.1058325996356351, 0.1303403074187892, 0.1527236441948584, 0.19744689150580338, 0.10354819614440203, 0.12286266152347837, 0.12927390821278095, 0.12733894347080163, 0.15672823573861802, 0.07028807194105216, 0.16445951802389963, 0.08196460109736238, 0.145548231367554, 0.07640464444245611, 0.09826899013881173, 0.07028214154498917, 0.0961964659925018, 0.10717544079359088, 0.10953328891524247], [0.02667989006399044, 0.022441984254068563, 0.058499048464000225, 0.06357758452317544, 0.005166627716140023, 0.008801721319157099, 0.08079070837369987, 0.014104202772224588, 0.07479610254189797, 0.10703582542815379, 0.03286180039867759, 0.022748020510854464, 0.02874950159873281, 0.052341316028365066, 0.03437838384083339, 0.043458783732993264, 0.05230360305202859, 0.05440526009936418, 0.03015758389873164, 0.023384094504373412, 0.06770427844354085, 0.00467352317147223, 0.035116697794624736, 0.018078620711873685, 0.028717423855726208, 0.0612608827650547, 0.018143519193732312, 0.02972660559628691, 0.05629685627562659, 0.05658166456435408, 0.044926543187882216, 0.03208332056445735, 0.03877718387437718, 0.0200977305815156, 0.01629571397123592, 0.024336186004802585, 0.018350058468058705, 0.018420022213831544, 0.029325727107269422, 0.044557647446968725, 0.0528590416402689, 0.017587904186387147, 0.09311863793326275, 0.06725280159818274, 0.012734225302535509, 0.0701056138745376, 0.013122170914097555, 0.03556916190843497, 0.08773510716855526, 0.013121557688074452, 0.027289845548304062, 0.05789753395531859, 0.050829645179744275, 0.031255674082785845, 0.051802627077060084, 0.02455442661552557, 0.03207053696470601, 0.018796565044405203, 0.020791636114673953, 0.05372293546263661, 0.04839961789548397, 0.04555550443806818, 0.05440099211409688, 0.02115557006826358, 0.05225909794015544, 0.04696247733331152, 0.012185315069343363, 0.0384190768402602, 0.04241352089281593, 0.03509353939443827, 0.14644572963672026, 0.05464851490354963, 0.012649393158166536, 0.0018688154232222587, 0.051526242800589116, 0.043868313543498516, 0.027296013431623578, 0.0168911572878382, 0.043196295853704214, 0.013455909211188555, 0.04636457263092909, 0.038886438190404854, 0.040013525568481, 0.0624760507739016, 0.02349557780793735, 0.02898759614410145, 0.025815434753894806, 0.0025891948483019534, 0.01889214518346957, 0.018118060559832623, 0.023735906429854885, 0.04183603670181973, 0.036382820390697033, 0.022438971558585763, 0.004588858964520374, 0.02161956758105329, 0.029648502822965384, 0.020833795191720128, 0.02707999332674912, 0.06374271959066391, 0.00914316947039749, 0.07022696986262288, 0.03761488731418337, 0.0949423432882343, 0.03951028667922531, 0.031089185337935175, 0.011937241818356727, 0.019558261314939176, 0.030067559265132462, 0.02140288081552301, 0.04724855448252388, 0.049992349930107594, 0.0544710644254727, 0.03667284322104283, 0.017183066445535848, 0.04685868861685906, 0.039292225880282264, 0.03523970262280532, 0.022373570960813334, 0.035162132499473434, 0.018370075251108835, 0.05087927323100822, 0.023766610139448727, 0.025917447404935956, 0.01006152166519314, 0.05392186835940395, 0.023710364675415412, 0.06827384073819433, 0.043966677372476885, 0.0628372621057289, 0.011020396819471248, 0.051994594811861, 0.052100320745791705, 0.01791652717760631, 0.010763110759268914, 0.04831020055072648, 0.031095010561070273, 0.05554366883422647, 0.05570953332685998, 0.036142357758113315, 0.02802312307591949, 0.06982250192335673, 0.024012321240401695, 0.037538239998476844, 0.035019229631870985, 0.030622974104647125, 0.039835800283721516, 0.004371377040765115, 0.03697955462017229, 0.027451589637036835, 0.054813728002565246, 0.013410455846626843, 0.03704638692683407, 0.015384531347081065, 0.022113539378291795, 0.040250995861632485, 0.024671589257195592, 0.03794622953448977, 0.06317066707249198, 0.04418969826240625, 0.07047181922410216, 0.06847452425530978, 0.011505090498498507, 0.022231770712616186, 0.0482073753540005, 0.029370330606720278, 0.037527186663023064, 0.010462546039239635, 0.0187936541291752, 0.05841300343828542, 0.013225181011616119, 0.04881557682529092, 0.04723011529339211, 0.026624146715870926, 0.0421236134134233, 0.0445490266595568, 0.030124590133449862, 0.06274089656238045, 0.027775198254468184, 0.0466848174110055, 0.0361272535685982, 0.047612035513988564, 0.010272339950980884, 0.011680416313798299, 0.05661832920408674, 0.05522583285346627, 0.014147734186345977, 0.04366145535771336, 0.047222373208829334, 0.04850832938349672, 0.04659755102225712, 0.030704907208148922, 0.054136102220841816, 0.06778195034712553, 0.02075897652788886, 0.02816717266770346, 0.0135509337997064, 0.04612049340669598, 0.04913016262331179, 0.0337267425576491, 0.04593110071229083, 0.03558733307623437, 0.051253895807479105, 0.03166892905054348, 0.10985880251973867, 0.009079386330475765, 0.026430297742730806, 0.09311631734349898, 0.02811235043087176, 0.023608906726752008, 0.05078174739277788, 0.04630346376714962, 0.0345889807545713, 0.05063322964789612, 0.022178687221769775, 0.03026114869862795, 0.06341034599712916, 0.05817999451288155, 0.06891263396080051, 0.04326122147696359, 0.013360740433979248, 0.0689276499407632, 0.03321840787040336, 0.04807045377258744, 0.0345308438741735, 0.015500128269195557, 0.04624471959791013, 0.044407087311680825, 0.08344714583030768, 0.02372817791599248, 0.04163160427872624, 0.015601577736171228, 0.03784771982048239, 0.011270968775664057, 0.02344416351323681, 0.020930333761498332, 0.002671076213508578, 0.031476852750139575, 0.03067703638225794, 0.026045531067731123, 0.02161889922405992, 0.04620609738464866, 0.03173237886013729, 0.014472605727080787, 0.02047408342228404, 0.09030115697532892, 0.04700324371723192, 0.023395288635843565, 0.03726158770067351, 0.056780587283096144, 0.04008968094629901, 0.053565573013786755, 0.08565012511930295, 0.02824860026261636, 0.03117611924452441, 0.056969345547258854, 0.03423675322639091, 0.03802080053303923, 0.026629208587110043, 0.02272627855251942, 0.06793173695249216, 0.009247254197751837, 0.03945834143087268, 0.01421731201532696, 0.05958853143134287, 0.0361011503264308, 0.012739968253299594, 0.04948678705841303, 0.0908105264284781, 0.012005816263678883, 0.009769933963460582, 0.050732421289597235, 0.03344898424776537, 0.031177852901497057, 0.03906488272228411, 0.007506475151915635, 0.033767074679157565, 0.013712021405808628, 0.0296467861293682, 0.040597360847251754, 0.0654347687959671, 0.042476146282362084, 0.011532813743022936, 0.05051301699131727, 0.04014499851369432, 0.03270642266475728, 0.07507045460598809, 0.08983989565500192, 0.04383587956960712, 0.008449069706590047, 0.018735476536676288, 0.012680916198795395, 0.04843963110553367, 0.0289274779414492, 0.03311383544600435, 0.001642117933702788, 0.019570351112633944, 0.019739776217777814, 0.005105833522975445, 0.01968093026828553, 0.03065270072381411, 0.029990630357393196, 0.017551833264795796, 0.03325849571930511, 0.015582692410264696, 0.08060560402061258, 0.019019078729408126, 0.02420874186126249, 0.04966962171186294, 0.0948726102443678, 0.02787123470833259, 0.046185955072620084, 0.022408922635284916, 0.027530828956514597, 0.03399211421076741, 0.018403164011293223, 0.0156604304710137, 0.03218437139210956, 0.03715010778978467, 0.008112823374436369, 0.01228329467786742, 0.02078009762668184, 0.01586371277725058, 0.04909049207344651, 0.04347456306485193, 0.018000092157827954, 0.01649009559436568, 0.020679219825459377, 0.015691946726292372, 0.01495550383281495, 0.01270437060988375, 0.019331301529226557, 0.03420690107824547, 0.04253699051748429, 0.054774199945053885, 0.018956334596233707, 0.04089546502966966, 0.04548839053937367, 0.03132845035621098, 0.03211348144603627, 0.006536233687906393, 0.03037919004314712, 0.05664160634790148, 0.015813641981886964, 0.021085082154188837, 0.05351681009467159, 0.006515254233298557, 0.030847752400274788, 0.04063424601086548, 0.02885627926194242, 0.03478873467871121, 0.042921930218913724, 0.08355822201286044, 0.17277366189020021, 0.17726887496454374, 0.11277053877711296, 0.08535503702504293, 0.10525304252015692, 0.14178814313241414, 0.06849455460906029, 0.16485428969774926, 0.13862960333270685, 0.13759884078587803, 0.10227879283151456, 0.09681477424289499, 0.08234985971025058, 0.11652506302509989, 0.13258116931787559, 0.19667623857302324, 0.1509489222828831, 0.1534899409328188, 0.12089444856558527, 0.13049506768584251, 0.07628596866769449, 0.15818370692431927, 0.10018251317420176, 0.1276896239391395, 0.1543674495603357, 0.10723906023693935, 0.10166864057204553, 0.19586509067033017, 0.13070002597357544, 0.11899221635290555, 0.2543674164584705, 0.08754278998821974, 0.11055913886853627, 0.12551722622343472, 0.14866152645221778, 0.12239341384598187, 0.07488714158535004, 0.08418212817715746, 0.1629843014691557, 0.08082867919334344, 0.09930708764919213, 0.13646785861679486, 0.15454840127910885, 0.06855708161102873, 0.13414530110146317, 0.08955607802740165, 0.1495937385729381, 0.21540436148643494, 0.07735098366226469, 0.1528320469494377, 0.1062851349956223, 0.153097055586321, 0.09073018109691994, 0.18791001396519796, 0.1384277120232582, 0.19641583040356636, 0.09192372419472251, 0.09703577309846878, 0.1335649365293128, 0.06598725236420121, 0.12290741769330842, 0.11842759379318782, 0.13924468175641128, 0.11906632594764233, 0.10810044008706297, 0.08355061563530139, 0.07628972096634762, 0.133133591817958, 0.17313601316085883, 0.23834807319300516, 0.13229528894381865, 0.08430491587413208, 0.1629901775824172, 0.15918652739908012, 0.13484210228281363, 0.16794644163123199, 0.1590832679399422, 0.07782074702637536, 0.13337509600179537, 0.0951997319768582, 0.1602532115897962, 0.07947103240128074, 0.15158428890364511, 0.10376525271151747, 0.09701085050723382, 0.07732945374612298, 0.19738997598843916, 0.1558663198458297, 0.09066533350518771, 0.14364747836121491, 0.11686561975095953, 0.17639788027320588, 0.10395440791866609, 0.07399498338678054, 0.10352761617728642, 0.14445021242967673, 0.11051563120314054, 0.1305664088577032, 0.12444799074104854, 0.13088491319545678, 0.11715662984975747, 0.1398414397346122, 0.18621943039553507, 0.09764992192919765, 0.10820702436779227, 0.08484372696174042, 0.15076202659734658, 0.09945325766290937, 0.12028869321303708, 0.1676193606108427, 0.16678058276219027, 0.1975265108048916, 0.11416886374354362, 0.10411346331238747, 0.09318496473133564, 0.1512733841581004, 0.12638421755816254, 0.06752851751766034, 0.10058993274079901, 0.08160218875855207, 0.07398472393729857, 0.1414447637008769, 0.13763587522719586, 0.044468599903796396, 0.16310677704002174, 0.11150879612458603, 0.13579410048467772, 0.06880537114505257, 0.2441206962934562, 0.10326251254550048, 0.12942280593727315, 0.1430961008050612, 0.25920911665473667, 0.13367480491953238, 0.11520266612725598, 0.0665783445749964, 0.13119930561099732, 0.12357536756566592, 0.09400527285678045, 0.07326253197555031, 0.13727273685591562, 0.12099373180951391, 0.19241737281637533, 0.0744887465345008, 0.08078233525156975, 0.14877549319394998, 0.10969299570258174, 0.08650290793074028, 0.16721599868365697, 0.1232485579592841, 0.19684197753667831, 0.17146608419716358, 0.1348741834184953, 0.09318845240133149, 0.08486058855695383, 0.11392818737242903, 0.10464265955878155, 0.12792082796139376, 0.11920090658324105, 0.18438026122748852, 0.12850763861622128, 0.11075202601828746, 0.1670887190848589, 0.13275274368269102, 0.07436005558286395, 0.08801570175481693, 0.08386660260813576, 0.07378435933164187, 0.09591125736811332, 0.14031516574323177, 0.17683501967361995, 0.10643631259777717, 0.10846819928182022, 0.19379542315644877, 0.11414540000259876], [0.03023658912362797, 0.04660400728295956, 0.02907694224268198, 0.04066575039178133, 0.037991209620875974, 0.03993730912251132, 0.025358154737789716, 0.07866129585142646, 0.034838512007679255, 0.018437382532283664, 0.007169445959984192, 0.013476842864682632, 0.017902603639023643, 0.012489684674489712, 0.035025404300540686, 0.024367600479828458, 0.0242475947764303, 0.04214823744925005, 0.035781936919582744, 0.033230950590223074, 0.007855120015197566, 0.0068528181956415725, 0.01943080360069871, 0.011325097210439188, 0.012203920499554701, 0.01444082145046975, 0.07536370387034756, 0.06222525066030877, 0.03629253452111568, 0.05722648996327605, 0.042082297416137796, 0.03778803927291717, 0.062050303976450644, 0.025978230571906482, 0.03764894637944443, 0.07246485299297742, 0.039240131354225535, 0.02285653183103672, 0.04032832171235766, 0.02822751139423677, 0.023053858296147416, 0.04287254983293159, 0.04598564135708979, 0.04240286789302315, 0.03571859567559191, 0.07337336388549634, 0.013618402232948159, 0.03572677880791681, 0.03914725348087294, 0.008559340976976922, 0.015019869664683938, 0.037507638069135804, 0.027064253010654023, 0.027666608902758787, 0.04707225412130356, 0.03100415811474834, 0.025658939133531282, 0.03145634402920093, 0.03728863410651684, 0.03589663647913507, 0.02637489026944552, 0.03393258972625647, 0.033906744327396154, 0.030894401682806865, 0.05250597272866538, 0.03450471688328045, 0.07428093161433935, 0.0308994058785694, 0.022601931921339462, 0.04689184523054531, 0.07455234562179872, 0.007439327326470188, 0.058577561751008034, 0.021708594768175056, 0.034603918703006845, 0.03417239078719701, 0.017149745287107568, 0.1259723332311426, 0.03879654247845922, 0.022233748642195548, 0.03127871373934405, 0.048819142526813915, 0.03624481993860432, 0.024612678846876537, 0.011085938213260045, 0.056312170810997486, 0.03038904576429299, 0.015451092239735382, 0.04718149486663086, 0.005524859431066683, 0.015169423871806689, 0.007902265476462032, 0.009007068068188216, 0.06137618622077363, 0.015744056519387022, 0.07269476779869624, 0.040166582712637525, 0.03861646267718502, 0.08592324224965912, 0.04449360391923359, 0.04680548807872193, 0.07225680737090961, 0.04024589667096734, 0.015221516701525875, 0.023793603958828107, 0.02448428645064788, 0.04064993713317173, 0.0032155882675267223, 0.00926847368412252, 0.039915568860513825, 0.06265326376472201, 0.0538392601135586, 0.07538049761205912, 0.02981487282418779, 0.03408713964745402, 0.020024962789778198, 0.029775534756481647, 0.07890832331031561, 0.0712229371336954, 0.08166090239371572, 0.028029979672282934, 0.01519147795625031, 0.07999309724462883, 0.06564531142690352, 0.039702485115932565, 0.05031209598694529, 0.05189054146675127, 0.005254253304363894, 0.06648752944810049, 0.027344114779095565, 0.039062596059271266, 0.03372827943946634, 0.04103100918499487, 0.022701932716050317, 0.0810033544631941, 0.026654092162581425, 0.04722879893545594, 0.02774910519032606, 0.028546297324023077, 0.04943644993805459, 0.015134481014683843, 0.023050911757828932, 0.037114912178367376, 0.027873048093169928, 0.019946140769336904, 0.04772372577073319, 0.02809466271927314, 0.03209416016138025, 0.012428312030221735, 0.028889334095375876, 0.03810211616967406, 0.042532739495592456, 0.06859169368233, 0.0687128257538591, 0.0306235372887126, 0.0615527138912252, 0.03009176260924765, 0.03275452061955418, 0.08876751855547939, 0.07325777544506959, 0.10864723074649062, 0.0057757405447773635, 0.03349722130224109, 0.06692926253059081, 0.03214592220527785, 0.02646280126646161, 0.056233593063162904, 0.05652976681345275, 0.027804276872692362, 0.012779895798303187, 0.026705216383561492, 0.03541883247505341, 0.007976273290946015, 0.06034074856766632, 0.06499188220394508, 0.05047872722414987, 0.04360256530344486, 0.049646202075694285, 0.05593671363645366, 0.022776284887056266, 0.012795928732625075, 0.020442538329267075, 0.07958694653851645, 0.04521803504654339, 0.02695345163478383, 0.030757100121783357, 0.03262073726260236, 0.022729013048644577, 0.0348818161125694, 0.03204468138782041, 0.043500910579626045, 0.007613793946802616, 0.01617070576841278, 0.04463949573359319, 0.026863649221403257, 0.03992078679480723, 0.023008459214387194, 0.05616820264341576, 0.047269480502499, 0.040509103797376156, 0.0025572084954806735, 0.09410683597837176, 0.033475684600749185, 0.05556759058630892, 0.05159800805683647, 0.020430665662778274, 0.10653471374618155, 0.05965021026453801, 0.030385001695581844, 0.028698893064366918, 0.009771985683723219, 0.08178470789321832, 0.06051869437630687, 0.038754761684685946, 0.01463443972170353, 0.10294580632554633, 0.029379663855901787, 0.04337208392098546, 0.047859310638159513, 0.06014296918043068, 0.06499376174594675, 0.02091725160633879, 0.04466672534389155, 0.00393994284760473, 0.02330623769999615, 0.012083142114404057, 0.037597526995731254, 0.03828515099095447, 0.019933056917839816, 0.03153555281460285, 0.07545091597629444, 0.015997306144397174, 0.11552836293620722, 0.018684678012505174, 0.046907339577696154, 0.04796216297628624, 0.04711465916729399, 0.042202418470489125, 0.02942388059039201, 0.02225965680554509, 0.014251065739829625, 0.04772218210356576, 0.02928439753928355, 0.04589554886998875, 0.06620449892112187, 0.06839174976838486, 0.07983440147446734, 0.022055785870179534, 0.021624400446723615, 0.019664645427837968, 0.027418982636715685, 0.027157936644341265, 0.03984492997239743, 0.07126066368073225, 0.006215507996135524, 0.016128928367314593, 0.04827011948717492, 0.025600873499310443, 0.05867364230964865, 0.04154071451297828, 0.02718769888659673, 0.10176267195492983, 0.021599584724754095, 0.07063268630632333, 0.03289498754643968, 0.013801799222294773, 0.02068749286367425, 0.033438083582690785, 0.09316202346235514, 0.018994145960147892, 0.022523924142920544, 0.058607308726225577, 0.026534800617290393, 0.041370344547820945, 0.006762488221284002, 0.037974649973745854, 0.004818974362154092, 0.005515402349244271, 0.05101916679580297, 0.03839913130338703, 0.05813672433474234, 0.03916429488786629, 0.05457969448928322, 0.025876954131360565, 0.03824930737859436, 0.0800073261239699, 0.06516316479870252, 0.033684985512601476, 0.028498138301074505, 0.062422385439276695, 0.020005912919129645, 0.010267794614524713, 0.016792159028617398, 0.028153018427214453, 0.06371145948235478, 0.03012031197015728, 0.05932948711727347, 0.0074915550150243294, 0.02323333080857992, 0.027902459193553244, 0.010117024981549807, 0.007847942811037813, 0.013981958751433661, 0.03440686195556607, 0.03280558716505766, 0.042644928475575786, 0.02194925587225173, 0.03248411084392241, 0.025992165984851972, 0.047552826548261304, 0.07583974368338074, 0.0035853442636185457, 0.018350479159770266, 0.021396633204338805, 0.0192149344698659, 0.036733704419540505, 0.044585911823170524, 0.02125565567985177, 0.034330357132213454, 0.055152629102979384, 0.012921043804713657, 0.04049996053799987, 0.02983095749680485, 0.0161951177620462, 0.021051744032385092, 0.020289733939405, 0.02792703064291605, 0.03979311703837343, 0.08639219815709762, 0.06008941919675895, 0.027642673579975963, 0.06255900846528155, 0.06165142038038798, 0.01516396675391921, 0.0571150134450623, 0.021389394932027374, 0.05942914355546236, 0.011736450583807059, 0.07245252401168857, 0.0453642729137625, 0.03863101386065994, 0.024085597933403084, 0.04838484958080309, 0.023420416483921663, 0.052654738138828955, 0.04431513224595359, 0.04548216837325266, 0.017189120674239736, 0.034360161782907586, 0.09777627193502017, 0.011224738488505994, 0.013798101206443139, 0.14770059872950825, 0.1227183642664126, 0.1054671203185405, 0.13541444657104357, 0.1493415678186076, 0.09738991409540176, 0.27205625442521914, 0.10000133753887244, 0.10617837429578815, 0.08231337488229785, 0.06661408301442862, 0.11074056556182248, 0.07392518927476235, 0.05936920177191496, 0.11230264138430357, 0.12604086526802608, 0.15154198903058255, 0.11994696940694537, 0.08435204013117722, 0.12839283049106598, 0.0851195582321712, 0.13602211539234432, 0.14402998212192739, 0.08913320143307958, 0.14086267564977917, 0.13436615067933286, 0.13632364278393133, 0.1645164063998631, 0.16517313330301217, 0.20751936387802872, 0.2346977719238826, 0.190698575760637, 0.14643785863050393, 0.09909112352345671, 0.08820149142827306, 0.20337590335735253, 0.13034329297287123, 0.10317401122301817, 0.07926859826381717, 0.18290372831480844, 0.13515179923602513, 0.11354657249259097, 0.20974919279771193, 0.1729754310633455, 0.14875816340957368, 0.2390276395848819, 0.13341419318956987, 0.15162852938686097, 0.19751216657459736, 0.07982988921659333, 0.1361443738320044, 0.091023233586124, 0.08478147137377944, 0.19074137774961336, 0.13262507053358213, 0.10769483899431569, 0.20339068185005868, 0.13266788609325886, 0.13449573729719433, 0.11625077202916145, 0.24165093739117893, 0.21645926630922727, 0.22694526506321772, 0.08602532784321479, 0.12301241420209408, 0.2241780228380646, 0.11879958026111126, 0.18299915747983114, 0.17169134425265448, 0.1415797243160861, 0.16064260926629814, 0.10310017304228884, 0.14113725163042545, 0.14112194388040475, 0.20354822411068849, 0.14852371598993028, 0.16190300163413796, 0.2691684365272522, 0.10440028006477015, 0.0867911156799112, 0.11806110345891543, 0.10856798464166266, 0.1268776889358248, 0.2001228572002479, 0.13111359306744166, 0.17338781750627927, 0.08266134121056114, 0.22585507641945565, 0.19387178548744746, 0.06192496498780591, 0.08832703397742339, 0.19752495017434868, 0.1723998433777264, 0.1338239876287324, 0.07959080740277256, 0.1839629757617201, 0.1633616347930261, 0.1366471547101225, 0.17723865301481315, 0.0918296995971884, 0.113039102937494, 0.12675445340573788, 0.10221540409007243, 0.12412833289376327, 0.1429607059274401, 0.08692998465682779, 0.10585252142378263, 0.12597640444125446, 0.11461810820869037, 0.22386398326073373, 0.22668620039309773, 0.1316448181335415, 0.13270132429897785, 0.12266999829028334, 0.13789789830999716, 0.10715874204678194, 0.07906131938632045, 0.1308882244463478, 0.13049844679023537, 0.12410340351717812, 0.10299727320671082, 0.07736750598996878, 0.21782709791191987, 0.17008959448763303, 0.09235971008560487, 0.13449558801949024, 0.1736548753189189, 0.13346321055931704, 0.16619305286024297, 0.1432892797248704, 0.10080730143402304, 0.18441508364464554, 0.1790066845715046, 0.14784196471529348, 0.1441949475556612, 0.07263873437685625, 0.10884232992040259, 0.09508757013827562, 0.07984263210424355, 0.12320258042642049, 0.0900828790451799, 0.12854406237602234, 0.14427641247000011, 0.12094225814299923, 0.060830854411636076, 0.22188457447503293, 0.13580649053411825, 0.17992975004017353, 0.04149842481794102, 0.32024366727897097, 0.07508303464523383, 0.08515913717980896, 0.1781213456498725, 0.13202513701149396, 0.10885205332721982, 0.09418461644755942, 0.12925273792019912, 0.07952672655561141, 0.11402710420744759, 0.1226537541619369, 0.16373913096530096, 0.1068843560559409, 0.1286397629550525, 0.10443527890103203, 0.1710059153182166, 0.13881108430879457, 0.1610573162989957, 0.13427738472819328, 0.07989266727651868, 0.1635284729834114, 0.11267282973442759, 0.11133030070258038, 0.09711518205170121, 0.17874604570014135, 0.1444639459784542, 0.07909514435700007], [0.01849671363431428, 0.018834795403693403, 0.010498750971497169, 0.09002578710871083, 0.024590041222316877, 0.03371208620124629, 0.03801013396254607, 0.03248161383505378, 0.024849884511370744, 0.03272103152370878, 0.041090326716325114, 0.02100152904833002, 0.022688450225229775, 0.043412181947912486, 0.02799870090426079, 0.033682159414248805, 0.04168656900791185, 0.0337867861214493, 0.0535643482580781, 0.023944379528984427, 0.04424065963498183, 0.08026839247239487, 0.07349036367876188, 0.044404712439115555, 0.02467490729343678, 0.009922158205881715, 0.021309882502204607, 0.038033618059541495, 0.02612595273447888, 0.05988868818219219, 0.012709734429206167, 0.015564930059814026, 0.008776915775212859, 0.010900504770688713, 0.009913577282402133, 0.02393482405958431, 0.020335394257147397, 0.02126723318360746, 0.038714538128780465, 0.02446658516834889, 0.09129163489810058, 0.009669520110557122, 0.027664461339424764, 0.044763053567813973, 0.03223930897989443, 0.04560094592826707, 0.018494016457615153, 0.042075562956077714, 0.050744414396051846, 0.012959555756034595, 0.03157853800803423, 0.06088299982781921, 0.01991558464110962, 0.025831928243860602, 0.053716319746204784, 0.08479369857481547, 0.027429974904017787, 0.04674487115283098, 0.009338299178385308, 0.036989902279206684, 0.02990960649081639, 0.041706762210066826, 0.09046515888933625, 0.05614491192890065, 0.016289739470396723, 0.03463070387286799, 0.042275001361433945, 0.04972520390791552, 0.05599379878757255, 0.044097139300512414, 0.04928128594266517, 0.01605852018110454, 0.04726850680474724, 0.05694851452218635, 0.020867218130401204, 0.049417990392872264, 0.02666005987807044, 0.0488080552646092, 0.019883269410846487, 0.050465563644788096, 0.05102532110842211, 0.04984682791733316, 0.041271414142102, 0.10671707003244332, 0.03224484243297151, 0.049238867325974364, 0.017596324805968573, 0.024350328370928764, 0.052385777035462, 0.06749689100044114, 0.07179243157484702, 0.010244179051369429, 0.08038325488035168, 0.03477523861719029, 0.010296790112209107, 0.08369354225162949, 0.013352358830161393, 0.008454982291108795, 0.04472913699490683, 0.0655447186103889, 0.014891492535493203, 0.05120738223195076, 0.038597731717995236, 0.02103741167645369, 0.005802941741421819, 0.0627025186217257, 0.05263587147263544, 0.05103710386902094, 0.07003845247839179, 0.054845608970416446, 0.021571427217817733, 0.03950887532638652, 0.025372907785432677, 0.09805551623659474, 0.026017351508406655, 0.09382168163678475, 0.03742561336340649, 0.042746379638889005, 0.020936554231281792, 0.034338350274733136, 0.06988648099026509, 0.0171931545649256, 0.055861236793654304, 0.02656604376222406, 0.03563894584242787, 0.06386477446981839, 0.09418910156403269, 0.01736512078371431, 0.05829229884381805, 0.038098906699035845, 0.027936767620433654, 0.02038713764133198, 0.037835302629641125, 0.03332966047206095, 0.05076173060972776, 0.02462761170629944, 0.029797264840453863, 0.07276523366038289, 0.03085585410839745, 0.08393361472657748, 0.025426033684717755, 0.012402871207866286, 0.009118658241017588, 0.07756844735039131, 0.062136511850569925, 0.0071140486647241884, 0.021184311115315983, 0.05748291513217347, 0.060361498168536594, 0.07940253429114819, 0.007695322473799544, 0.010030222541120435, 0.021650948129328232, 0.007532630980546985, 0.07682517330561366, 0.02032100422573941, 0.02254973561502993, 0.02159238207553114, 0.027907156352219836, 0.05345865964357342, 0.026914798887446523, 0.019362366558717828, 0.06772842750485454, 0.10942530006702457, 0.03176218011815633, 0.02922595871080245, 0.021537797325955968, 0.027644951761301075, 0.019266311445140412, 0.07656129782221147, 0.03434628913445132, 0.035902210644313266, 0.08599563515079872, 0.022652236811284508, 0.05380427484799709, 0.03147099699292864, 0.039580396310027154, 0.04098112668309893, 0.02556546584569982, 0.003623579711919384, 0.06277991232595273, 0.034766882458435636, 0.02540721112330045, 0.054611069948545525, 0.00635881713658039, 0.01583600988877671, 0.06291108671575785, 0.06775560961770159, 0.02019598923756608, 0.037412490496145825, 0.02010118093208543, 0.036257932627839703, 0.04821035751540746, 0.038027053233236074, 0.021247012840051736, 0.0352498535066843, 0.020254774118906686, 0.022475999214553406, 0.04343412916309067, 0.03353630491931524, 0.0660606494971684, 0.0244863610714674, 0.01249506969803146, 0.02892013619254742, 0.01166490839594709, 0.09496447031519242, 0.02615863606998963, 0.028485561654503857, 0.01735736512845116, 0.054616253956088, 0.011242388880678585, 0.02488521413345422, 0.028913065857653106, 0.003308620719638254, 0.056938465418560166, 0.04221767193770834, 0.04712817219219037, 0.025976410401718955, 0.020975098413016115, 0.04611354520810502, 0.04193289418305669, 0.047610030443008454, 0.03197773712288056, 0.01217570192446666, 0.025768184967871224, 0.03039173615564193, 0.010358718307023602, 0.032419663587851186, 0.054142629727721214, 0.024934942268633416, 0.010769282035263521, 0.07959815593702452, 0.03399971041030117, 0.04019454514075603, 0.037825531725372584, 0.01747277714977307, 0.02785305505884545, 0.05968792324087449, 0.09034936688840389, 0.007298355739164565, 0.020768888228173767, 0.01472852538738932, 0.0476207037988518, 0.024058252972151552, 0.020860504026391676, 0.08163874822535686, 0.047297707559274774, 0.035609731517199955, 0.026249907511685575, 0.09082113193081957, 0.021384665542947393, 0.03725380151133452, 0.03169720360477056, 0.018169142372374023, 0.017328853086967553, 0.05479319214022585, 0.0019191837137831108, 0.08810697150017534, 0.012090391412909542, 0.04165906798360603, 0.02687554563661771, 0.03131195516990764, 0.03104033420926758, 0.02391695144719311, 0.022873461279751997, 0.05596610098811133, 0.04702976765111089, 0.0073914668589298215, 0.0529354005785925, 0.04482652712613344, 0.029722500459424088, 0.014805172703095844, 0.03382707753085664, 0.032146020592855554, 0.042141469062439034, 0.07372546927737338, 0.028247004008984992, 0.028477137642247335, 0.021472615555727055, 0.01574300818278321, 0.050617256933557134, 0.012104740732216408, 0.06416423232959849, 0.05028664753107088, 0.05057121493986674, 0.05602398681055222, 0.010570684165161635, 0.01671263642076935, 0.0498443987619664, 0.08474410445030246, 0.02003168367913791, 0.028336041374132037, 0.03800090927896755, 0.03520589122282607, 0.015933891957891837, 0.05107915946947677, 0.09159415973616497, 0.014532500013176883, 0.04914694279432297, 0.016955260187387466, 0.03744002544720258, 0.09640989918261766, 0.04012444229530437, 0.022305692013885294, 0.06192656633044992, 0.05965537391602993, 0.09969334370855774, 0.07459870991962296, 0.034700358885207346, 0.02115644877111273, 0.031419027995850356, 0.07852205368024961, 0.05770833125071866, 0.045870432896273475, 0.028285712735461335, 0.07882956575070109, 0.021866936003789306, 0.026349063530298214, 0.05000050252835665, 0.08157666905650071, 0.01330606747485165, 0.019445819580661397, 0.005452427514163511, 0.032799538025366407, 0.02568116963707975, 0.029699365807963268, 0.02007678590182747, 0.02653772340688322, 0.03527751059404441, 0.036903365315603356, 0.05201451320733343, 0.028159461117216518, 0.01915163224163864, 0.016767095641366074, 0.02317636440108929, 0.0196304150324847, 0.014750335199226226, 0.026614847393440347, 0.021931004976587634, 0.016743499586092572, 0.015149198439238327, 0.007648797872077141, 0.054959368758967946, 0.01848775357939303, 0.029021896089294126, 0.02681443507650069, 0.016961918312257955, 0.018990641326776574, 0.024431075734485472, 0.04883782938122749, 0.04878504274945174, 0.04832334716671279, 0.08795725953366075, 0.10374828933605126, 0.09062156121113471, 0.15910985294197286, 0.12262404789882046, 0.09466738732797758, 0.10733430619750704, 0.13323180297655718, 0.09139352371650082, 0.12405966514987604, 0.17480504645832948, 0.12726369393723352, 0.12244658385004316, 0.14665440629635537, 0.11009386740624905, 0.09284003145460572, 0.16194162384739944, 0.08425207835222993, 0.21756947173603944, 0.12382273429206439, 0.1846113973962409, 0.14454701223543712, 0.18200685429785932, 0.19572870513158186, 0.22497623786330223, 0.13542017340660095, 0.12402839825621673, 0.1561116645378726, 0.14665743256253855, 0.20593107624777726, 0.12922913847225054, 0.08658947542841945, 0.09142135722296578, 0.1198772702898298, 0.0846475421317986, 0.07640480729086058, 0.18356509639748506, 0.05454700267208474, 0.11737494170665741, 0.19305111095309258, 0.19791510781007154, 0.09326754922845534, 0.07580910782728877, 0.09469692395733935, 0.2502531058021954, 0.13177549040743283, 0.12166302518120833, 0.07908991963735648, 0.18777578616780893, 0.07870899686323744, 0.06645827101809637, 0.16876071079501084, 0.1408895184951169, 0.0835339440298932, 0.100271849094757, 0.19370748501803192, 0.09715066943317652, 0.1022909182522978, 0.12214994191059045, 0.10642602600689445, 0.08571858930268458, 0.16149936829294476, 0.18757997453212738, 0.06987288314849138, 0.05623433266633323, 0.0714331337117723, 0.08377630316785403, 0.1384905579366854, 0.1495624581085784, 0.15757860296538898, 0.11190241428890399, 0.08294991536864213, 0.14988051461321966, 0.10113601093845707, 0.19221028392868383, 0.20567442716232368, 0.10409483752612557, 0.10219524481466838, 0.06605890566217047, 0.14045944942959718, 0.11310651539159672, 0.21727665673409188, 0.12091559171676636, 0.3529220223426819, 0.10839166053171669, 0.14050601050257683, 0.062241013028791974, 0.12981930109007017, 0.1453730064843382, 0.13790524005889893, 0.1769463401287794, 0.08289348161114113, 0.17697323725691863, 0.13601372869951384, 0.12266176087515694, 0.14246308191546372, 0.07602743325488907, 0.12687536834606103, 0.16030365388308251, 0.14382004338715756, 0.10549720656126738, 0.13460684062114783, 0.10450822820088693, 0.10856617973851306, 0.13343962468206882, 0.08690690768084355, 0.19661990659577505, 0.12099070554333073, 0.18913356188152516, 0.15557269060185977, 0.18000122691903794, 0.15320982810642036, 0.13056267691510065, 0.2531389423779079, 0.07693291788122483, 0.15412172488868237, 0.14865402185491153, 0.07085114065557718, 0.12014347314834595, 0.10564324765333108, 0.21995407449347631, 0.09821702114173345, 0.2479323260486126, 0.18380326218903065, 0.12731011930320943, 0.23882562613912992, 0.24432365968823433, 0.13901113000299248, 0.19928264085735592, 0.15047438203224114, 0.22052251041999885, 0.25069472353373257, 0.19050762243568897, 0.1729242695229394, 0.11471732359911714, 0.09700312877872161, 0.13801687264016696, 0.18768024843718323, 0.1190187470721347, 0.17351991470370973, 0.09606165465499673, 0.06900770350226335, 0.13122684056205408, 0.20186609508735792, 0.12948209632720264, 0.08102923378880535, 0.06012549690370049, 0.1462609509804419, 0.12826916069856711, 0.1217874006501266, 0.09920996893197298, 0.08337680889027459, 0.15685824304819107, 0.12899357825517654, 0.08133075439504214, 0.08253174102199928, 0.23690776047962053, 0.08177807860608612, 0.08527300892663853, 0.16099816161606992, 0.08460138817983014, 0.15013805936489785, 0.2209622146827834, 0.1931952317910535, 0.0952934648043343, 0.1987133635474103, 0.1859235077032021, 0.07648188886897904, 0.09936647981937442, 0.16906161393438066, 0.11089742250208344, 0.09518543524401528, 0.13914181584758417, 0.09038074913301639, 0.19306126183697156, 0.1824075292263712], [0.03431695267292006, 0.019829498903293694, 0.061655410166297636, 0.030974065086671283, 0.021328854341326014, 0.04461933306551405, 0.02207168733834156, 0.02014878185998116, 0.0417312742876155, 0.03941142412700823, 0.014322954828717878, 0.02859306874285851, 0.02462825461822961, 0.07473533973097801, 0.03371693094127944, 0.028329340840822885, 0.03268346443240132, 0.01997917185404471, 0.03087312282462205, 0.06299538112112454, 0.07374322653881141, 0.05792198835739067, 0.03635671714852963, 0.022927859432197044, 0.029066126394484724, 0.08459868082510573, 0.030708991988961185, 0.014670466538518667, 0.03581281704828143, 0.015057699688311135, 0.023301352247861878, 0.048341199423053434, 0.036128681884812455, 0.026727172080427408, 0.05369250316705022, 0.053900480935616155, 0.08582281228154898, 0.03242309018969536, 0.021319933302168335, 0.02122080951396908, 0.032562084695590396, 0.0596975584381393, 0.04445694267217602, 0.030844712563391243, 0.008207967554751252, 0.013528380992024072, 0.03566914404343281, 0.015043274033814669, 0.04913192342168518, 0.05698968802711793, 0.07002106162586383, 0.06800587368862969, 0.036937784004424296, 0.03544349383030619, 0.05643620022705623, 0.09111397407416787, 0.034090691778276644, 0.030167334446949617, 0.06073162545050893, 0.04604433124352779, 0.014482744736596942, 0.04337393292891128, 0.04315302228288991, 0.06989081004368407, 0.05103211663663387, 0.04466445564425417, 0.026740327178101455, 0.025827248048569475, 0.02936406433582306, 0.06393824624163763, 0.03333393185000334, 0.04803007754630276, 0.022479788832632557, 0.013975187820116324, 0.02772824023850262, 0.06500893378896372, 0.013671184623880046, 0.034541289920785596, 0.043588166790349145, 0.04104300907679966, 0.010345517408235796, 0.01297690165561757, 0.017468281855274524, 0.09132650481270892, 0.0640465540013143, 0.02335816089596067, 0.06015561028782811, 0.04662209363388164, 0.06076933164149523, 0.04132487591622131, 0.029901097661682537, 0.007470660377293825, 0.0532939011630203, 0.02144153186652277, 0.02088518743403256, 0.023977149377710054, 0.033127290795424154, 0.049425549272980006, 0.02502474468201399, 0.039230774356318374, 0.05547163894932185, 0.03677112562581897, 0.07010790053755045, 0.013865873284105743, 0.07387797002281461, 0.011120343331380613, 0.03580561100638338, 0.014718182817367571, 0.021825959274013127, 0.02299190465626972, 0.02777984961202102, 0.03840282253388848, 0.05176880889173065, 0.06322334174598966, 0.04515822557732463, 0.024630641365157704, 0.07097346694873911, 0.07110244288508381, 0.01270090414410723, 0.020391120641891445, 0.04252136724867991, 0.07094839507980005, 0.0405427659196513, 0.04096188682264515, 0.009801983716897666, 0.03805115818977356, 0.006934392947836646, 0.022603149891697934, 0.023868670287941183, 0.04250885506293603, 0.062493638401584964, 0.016478087220873152, 0.04361567460000515, 0.07349600230476686, 0.009079818048381379, 0.006645715313165316, 0.010825005027332475, 0.10832096396812371, 0.027304944648806537, 0.029086509586444924, 0.039091644143419604, 0.02950738789513707, 0.026819761576397077, 0.04387965864901032, 0.047149993878390105, 0.03426839331431048, 0.017751924760107483, 0.0435679532321436, 0.05231481245053666, 0.07170025937791381, 0.02258314498301063, 0.010348877852915652, 0.016368205259953226, 0.07883795922888176, 0.014018556385833238, 0.05682758601116283, 0.03167956508696079, 0.05095648712345532, 0.02325642474793962, 0.044343254129801474, 0.02998847940138408, 0.014958855795807071, 0.06036893491234098, 0.04990479516397629, 0.042181519591914754, 0.050503405542778115, 0.0225886088862483, 0.023211198692609156, 0.030992198935044662, 0.028636321957622255, 0.03253201202356389, 0.07458208581166607, 0.031520370593560595, 0.013450033946095832, 0.022340310870536735, 0.02990695002621838, 0.047899422235786915, 0.016956530744209886, 0.02044273171174739, 0.023655861350042478, 0.031038821076175997, 0.01245394877956382, 0.02158892833228622, 0.043205778380589824, 0.0441737051920167, 0.02625243166195495, 0.03927417006343603, 0.027811367563637238, 0.031338153406977654, 0.029057067951985767, 0.011971851345151663, 0.01917629868590406, 0.03256420511752367, 0.04611227974029524, 0.04686065636841314, 0.017095730506948063, 0.06569267317120518, 0.10358236038259097, 0.046789803741765876, 0.041031758966190476, 0.06852596399507352, 0.030754114567701305, 0.021515997692144344, 0.0632824150047132, 0.025565560840602432, 0.03799173887819052, 0.010559323792611914, 0.03807001128526671, 0.020509621693885753, 0.03416801084365163, 0.0320427305996418, 0.02754457777232996, 0.024068436086443917, 0.04679006837042315, 0.05797375379396336, 0.027805559303877608, 0.037874956216130934, 0.05888546737177031, 0.04069564325202789, 0.018607755890116096, 0.021064203631665026, 0.007895240942681474, 0.04045273789337703, 0.02564357710070908, 0.03749929887375661, 0.06500931376857416, 0.05152923853269645, 0.012192488880828023, 0.012310067125196968, 0.06102115634296622, 0.03333961797345962, 0.11772602929600648, 0.02174077259509691, 0.010987023922747799, 0.020525485842621753, 0.018050756671332886, 0.020084132739741887, 0.02291247365064919, 0.05213044091526951, 0.08736698835023812, 0.040724949179483313, 0.019598344074828283, 0.04215760462518249, 0.06377503821360213, 0.02131277645405914, 0.041579509752669504, 0.02027340160150613, 0.019520007206925323, 0.02538412736196603, 0.04996614490768739, 0.027135361784270833, 0.03620260148974402, 0.0318136028945446, 0.005457976658362895, 0.04078134222488318, 0.038525460953158994, 0.036461062263697386, 0.0738108561241201, 0.05721844932330506, 0.09867894742637873, 0.008943781955167651, 0.03413481691053935, 0.0469067628229303, 0.034021250504468165, 0.04559131073100226, 0.054575297582362375, 0.04625684841136847, 0.007075639341824821, 0.06460032000073365, 0.007294225157238543, 0.029529185832611153, 0.040316562700484476, 0.02833870462408023, 0.05666915486965861, 0.052911427936383655, 0.013127065696088331, 0.05360193231276103, 0.020822249918377826, 0.04107237267973168, 0.06224209189947162, 0.03249356283673218, 0.02055651694536209, 0.02441299956158868, 0.04136801378003188, 0.03298123613266008, 0.020824880937912633, 0.06686490348407201, 0.01917046498108123, 0.050556290562131574, 0.008945955811733646, 0.013845364563167095, 0.027370075528909053, 0.04458048693569643, 0.04240276272009526, 0.003576589889624821, 0.06507302820682526, 0.038435324361281734, 0.02179416990838945, 0.018916524946689606, 0.010977197887508996, 0.050708981297378025, 0.03533506393432617, 0.03832214132749608, 0.04368194711527654, 0.04918124273951564, 0.034123414129550965, 0.05822837405971118, 0.0507241567330701, 0.045054480965648375, 0.041470618452876806, 0.010859346532795047, 0.013147209704454457, 0.025683335860126784, 0.047386029069977145, 0.04865372247461762, 0.04767927494166153, 0.12379157596400805, 0.013167312152550688, 0.019915650798273937, 0.01202091112333749, 0.02398470656148025, 0.04584625669355903, 0.02797880965018911, 0.01643646588282926, 0.06379691418260336, 0.028024135789434825, 0.05240963093404259, 0.03016399944733296, 0.02041974294531558, 0.12314270649637495, 0.02620078666534807, 0.005013632912388337, 0.032499245567513366, 0.05102640676445194, 0.037361624118472846, 0.05708439115967069, 0.04346796431179557, 0.042594886517950466, 0.019155993525471007, 0.013083865915957307, 0.03708749257826379, 0.07613353577575513, 0.03504676797560283, 0.042695869492100816, 0.002735145398349102, 0.023892032248633246, 0.008851559716276824, 0.01372028426599822, 0.009955762652680278, 0.017452300659247806, 0.04284314891057355, 0.04034379570345793, 0.08099679302956377, 0.049563478478895764, 0.12719594900097164, 0.08380146324634552, 0.07986920353557382, 0.14096125321728842, 0.10160619499427931, 0.1817874839263303, 0.12382230002965246, 0.07775582479579107, 0.09774450292544705, 0.12057274154254369, 0.06813676987907716, 0.14392056156482014, 0.08455913580421891, 0.10724353856806244, 0.1104785492643714, 0.08905985179756369, 0.11097347270697355, 0.18794166083846772, 0.12075491462435041, 0.26915896417839186, 0.13021595909127168, 0.20609890509928974, 0.1664483313049589, 0.10470226207481963, 0.07105978338846139, 0.17955488658377103, 0.0904984681734017, 0.13618907571903296, 0.08670557277011019, 0.10325485188513994, 0.12391179879861218, 0.15337867476046085, 0.1028937084068145, 0.09993869518595082, 0.23468314270888055, 0.08683167171797582, 0.2646175021571772, 0.11298598043088402, 0.11321746943784611, 0.14322901224451406, 0.15873432452125208, 0.09327383924807821, 0.10896606756640331, 0.08142087063086884, 0.11658216853226934, 0.11258571262338332, 0.0913807333313993, 0.15718537835138185, 0.15922772804541246, 0.16628618857690267, 0.1877417101391724, 0.11993992621345179, 0.1917100136301347, 0.309697794594935, 0.15944084232406958, 0.2546519126210894, 0.15893895711217607, 0.13030568856213773, 0.08631495373057467, 0.09681766480207443, 0.17705637136740343, 0.22079206524150713, 0.10745130599077259, 0.16193941182323865, 0.12563554915998662, 0.12089894046740872, 0.12384717512343611, 0.15316058003476687, 0.16892731828348978, 0.13091409020125866, 0.10248277402882065, 0.13972509812031472, 0.13983873916523798, 0.16762917222721235, 0.10173195467463561, 0.09277051554194518, 0.19711640423962049, 0.1660458514732974, 0.11459091252514295, 0.15399832651019096, 0.16730992150093826, 0.18589452068720544, 0.1679895557463169, 0.16775680466422013, 0.11312052035438162, 0.2084661102188485, 0.11367645766586065, 0.14820119472486631, 0.13444057240017823, 0.09255449713340827, 0.24374872339623316, 0.10197888713862215, 0.07596358989498445, 0.07109943697495119, 0.07630892350737538, 0.13902778125235013, 0.28599292944584576, 0.1130827327391931, 0.20451373873012407, 0.15107514336705208, 0.15466618138764585, 0.07794137698199068, 0.10989412705280951, 0.06624280222292457, 0.086355862606849, 0.17791755444237164, 0.1340398160474641, 0.09035906993917056, 0.08813131733664445, 0.11223100844238486, 0.15501910102154526, 0.08417913583772522, 0.09422101985130991, 0.09646166461919035, 0.21704554770674023, 0.1586291380226612, 0.1472244028534208, 0.16867127987955297, 0.0734218316418784, 0.13814310729503632, 0.12198854557105474, 0.13023609801062516, 0.09576000512710639, 0.12943572524402822, 0.1323557464139802, 0.09963150202695813, 0.1690904652433736, 0.21095581805067404, 0.13249233551323414, 0.0913926348356264, 0.1350435864712511, 0.2868597986442702, 0.06680620341960873, 0.06519468953566891, 0.10953235253691673, 0.25809862624321667, 0.13094904832541943, 0.14480728469789028, 0.13549175885106834, 0.1391462263252054, 0.10378047225198575, 0.2000551801174879, 0.16198084317147732, 0.09448036950613771, 0.11475164390036038, 0.16025709281010286, 0.09740596823394299, 0.10629970314247267, 0.17560529708862305, 0.11228186464203255, 0.07792716167335, 0.377838561045272, 0.07912527131182806, 0.18242354265281133, 0.09199191696409668, 0.10564725779529129, 0.1306226865521499, 0.17928269904639038, 0.1512632875570229, 0.1122144657586302, 0.1503907593765429, 0.09492751051272665, 0.17832201559628758, 0.15351497887500695, 0.13858061310436043, 0.10463067663035222, 0.07499029926423516, 0.10649199996675764, 0.16933924332261086, 0.14787215952362331, 0.08037332112767867, 0.17548891476222447, 0.09891663145806108, 0.09838118590414524], [0.00869580963626504, 0.015536316238077623, 0.04319666226261428, 0.020397064608654807, 0.0382740399800241, 0.012716777622699738, 0.05963558104953595, 0.029132928167070662, 0.034565140426691086, 0.05481817919228758, 0.06403823516198567, 0.031009925662406852, 0.05764140734182937, 0.030969349268291677, 0.08874436015529291, 0.04701134203267949, 0.03179594402068427, 0.00832415565050074, 0.032276414667389224, 0.025257005522559797, 0.05481637768181307, 0.027543429351810898, 0.04257601306640676, 0.014152188768743404, 0.03748732612335256, 0.045996633624391894, 0.019351671150486385, 0.030592473955558877, 0.03472561395860144, 0.020918247356478657, 0.04940825680802975, 0.010368868342733808, 0.06292416887091738, 0.030036621460957185, 0.06756198965013027, 0.05727138862546001, 0.04456660410921488, 0.004343504518536585, 0.04522261855059436, 0.027855121197977235, 0.03880050851564322, 0.06742490522031273, 0.02632095691348825, 0.04170753573998809, 0.03686105526451554, 0.030014446936547756, 0.05419438498626862, 0.019159552441643815, 0.08034630864858627, 0.02930318278127483, 0.02434309688396752, 0.01572417713967817, 0.026472064965803708, 0.008404292332540666, 0.032582532348377366, 0.014253184465425355, 0.018384051376155446, 0.021525095150406872, 0.021222909579851797, 0.051101262747709236, 0.033320432395807335, 0.03482668174962912, 0.07027688968394484, 0.013641892267124993, 0.009585242668565894, 0.024362915195524693, 0.10743875987827778, 0.028961577718811374, 0.033505485858768225, 0.029385858880622045, 0.01799353411687272, 0.0414654480160347, 0.08823854622564145, 0.03250415137569819, 0.037680549147937975, 0.06562117593629019, 0.04163146857172251, 0.03860108368098736, 0.02386096043379179, 0.042046769322561364, 0.002824938905957554, 0.03178849370617952, 0.061482044469032965, 0.011213347581880433, 0.04059230576136282, 0.037575023381837776, 0.06008264741727284, 0.005581791063637606, 0.031036944926849434, 0.007434904974486146, 0.032205792742648294, 0.0828683961715017, 0.07662362126367432, 0.043679124409598966, 0.018033303054315702, 0.038971638440021446, 0.06460408587008715, 0.034550378897360394, 0.016073461522215178, 0.026607736346444914, 0.09032126196793147, 0.017106532784444944, 0.03148269493665014, 0.04549686544175659, 0.03720355260052851, 0.06924925518355199, 0.03271531825885177, 0.0395702827455742, 0.061103123373218944, 0.048930232280067036, 0.042147080547043254, 0.05758937727659941, 0.04950357401477439, 0.02974603544654591, 0.017324454483709166, 0.03462652748982821, 0.03298699689496841, 0.041041353451354165, 0.030412166845053434, 0.07372985261359385, 0.040041844227484295, 0.026584079223019735, 0.033534106465854814, 0.02596376250897135, 0.02593950318571712, 0.08595337598983731, 0.039942913821765354, 0.025467285221176486, 0.003907632706354239, 0.06228546385786363, 0.0832906010161553, 0.05274409441543477, 0.014088926404448492, 0.04334492216418896, 0.06111512665769883, 0.02408734007206346, 0.07955968978681735, 0.03203739731439522, 0.040028114071381946, 0.035008712339081934, 0.0428525126938309, 0.03455866380993809, 0.044988822524568865, 0.01754366879218391, 0.013723783810356898, 0.07817619081054415, 0.007291035194482122, 0.026791934855282307, 0.02772329711089177, 0.0906618729765926, 0.012226747265750808, 0.025848194424595152, 0.024804158036464026, 0.042190276086330414, 0.026015098772144744, 0.05150696901338441, 0.023767755167292695, 0.01691023599622505, 0.055303084065339396, 0.029880300563360964, 0.008672956576836961, 0.04763692417847259, 0.05782113769756896, 0.06484880630991288, 0.007560416989560638, 0.10406766898397889, 0.026882648201925412, 0.01604022178798914, 0.03731441843722548, 0.03277380797745926, 0.0529580432921648, 0.010438318098230022, 0.013927189101065909, 0.03209378018176981, 0.01978087847653244, 0.00720557794972722, 0.010160904144868255, 0.008008345944939979, 0.04483008264963116, 0.036644619556942155, 0.03743124520406127, 0.06766426523349114, 0.009965162907194878, 0.02283978389043893, 0.014049548472810005, 0.0170281891311918, 0.01784600194410554, 0.03635076639641609, 0.10427114806537117, 0.014065064872348947, 0.0449140513581889, 0.08097687124141625, 0.0020406898277412567, 0.02034373175618904, 0.020277566110183085, 0.009867620953757848, 0.09603230801544019, 0.019189825281500816, 0.04318115434476307, 0.01954641070083848, 0.06515893074018614, 0.0540180303422468, 0.044696831942668984, 0.03227442316710949, 0.05105465078460319, 0.020810733482773815, 0.07022819801100663, 0.03035191972074764, 0.03317150413723929, 0.013901746582372912, 0.057465361431241035, 0.012673394638113678, 0.017356031807139516, 0.018702704991613115, 0.07137172629258462, 0.010045466678483146, 0.02222759263323886, 0.04895204718091658, 0.03346033613862736, 0.02788811835593411, 0.05951188411563635, 0.013675992044487169, 0.0799654537279691, 0.05624170494931085, 0.08839337434619665, 0.03055200951972178, 0.03323472324492676, 0.015409477687041675, 0.06502866558730602, 0.025303502134712677, 0.061351528258195946, 0.009955073091467577, 0.03736821608617902, 0.03449278145230242, 0.056184826751372645, 0.0525537076672273, 0.01233626196959189, 0.02564873905586345, 0.017641216682802354, 0.08372589480131865, 0.04262570218582239, 0.037729902392519374, 0.020782067074573467, 0.021922460524365306, 0.027517193795314858, 0.035517952870577574, 0.029633055973265852, 0.04426557204819151, 0.0598863743777786, 0.009617622359655797, 0.009923254039936831, 0.047959754176970036, 0.01336023916623422, 0.01504126048114683, 0.009473928998756622, 0.006217853606878114, 0.028636074292340448, 0.007569528018523539, 0.11208188680133649, 0.045286234601267746, 0.02607407873230321, 0.0749410240511809, 0.03462570985513074, 0.01686528474757714, 0.024564314567084824, 0.012559184471943548, 0.0494295220955142, 0.03764279545950038, 0.09212990384548903, 0.011054789215060217, 0.012507382564113607, 0.019137259173606123, 0.040724704906876595, 0.03674916144726532, 0.04457655143258827, 0.09565374654318605, 0.11355727977518525, 0.019709505074258362, 0.011197297684183078, 0.028432693598525863, 0.007201042791296328, 0.004412975902336517, 0.04974436912951725, 0.0398492590258164, 0.02163135543066476, 0.037947841055159054, 0.018456870058019246, 0.007575580550889883, 0.030041588337293694, 0.012865939127680446, 0.03326313689883266, 0.012772570164608104, 0.06975641261254038, 0.019860680980075682, 0.019778155854770114, 0.016027728261958276, 0.03873214950518949, 0.015061684385208147, 0.007097833374116037, 0.006854755413119814, 0.05435193742492369, 0.005324888375720808, 0.035758479963988066, 0.038164744951895306, 0.01011497835029981, 0.05117768953953471, 0.00982367224059999, 0.04606305881004248, 0.011233739255528365, 0.04038079961069992, 0.06218280150954213, 0.027797421972666467, 0.07898749477629151, 0.10862308168517691, 0.04705417455573167, 0.018914521572047045, 0.03694277462948646, 0.03669015943471875, 0.046730252115854194, 0.060150032729974816, 0.025678340146051984, 0.030018117810998644, 0.07441332058182784, 0.012480365844177348, 0.03579864584441696, 0.0672398687207273, 0.027721383642139177, 0.0498247178537505, 0.030693375505506992, 0.015407152008265257, 0.023431018593588045, 0.009547968195485217, 0.016871367814019322, 0.012916787693809186, 0.04076564431722675, 0.030601912377668277, 0.0132948224532551, 0.058025709220341275, 0.007649706260833357, 0.025950090028345585, 0.04121977423450776, 0.06276363427085535, 0.040623009470956664, 0.030066256477896656, 0.0779526542340006, 0.0622967750366245, 0.048406769654580524, 0.035738758343671045, 0.027841933869889805, 0.01903500055362071, 0.1019436711711543, 0.014664335974625178, 0.13750274665653706, 0.15196782403758594, 0.13940512814692088, 0.10015657278043882, 0.12153280074042933, 0.15475880141769136, 0.21098743778254303, 0.10435865194137607, 0.10545178542711905, 0.10115963752780642, 0.13090022094547749, 0.09326164597379309, 0.20739790610969067, 0.1006939657298582, 0.15061202964612416, 0.19960417146129267, 0.18800741088177475, 0.19487395456859044, 0.13175098172255925, 0.1010581354743668, 0.17534248690520013, 0.17408810635762556, 0.1376567062522684, 0.07888167724013329, 0.10090452871684517, 0.15327698950256619, 0.09526596378002848, 0.13691324900303567, 0.15822365906621727, 0.125395089920078, 0.12252872729940073, 0.1534327675721475, 0.15695930405386857, 0.16527716629207134, 0.14221944713166781, 0.120310922020248, 0.10228167660534382, 0.0992608590583716, 0.1768217882407563, 0.11873691076678888, 0.10368629837674753, 0.11281973256596498, 0.11933802493980952, 0.15526082233658858, 0.22162101790308952, 0.14326364467186586, 0.19833878507571562, 0.17604950682393142, 0.17841330569769653, 0.12295091178800378, 0.14180145598948002, 0.09820646313684327, 0.16029510434184754, 0.08002968385283436, 0.11729691017951284, 0.11623744560139519, 0.07145439221390656, 0.11647334508597851, 0.13049153930374555, 0.21348105397607597, 0.16283878284905637, 0.14007561574024813, 0.1209936368146113, 0.24401679901140078, 0.1202158864055361, 0.11133674678525754, 0.24163036420941353, 0.08746074153376476, 0.11506419070065022, 0.12816561625472137, 0.07988072506019048, 0.10225896603826966, 0.15908797697297164, 0.047004207236958404, 0.13238774612545967, 0.1181737267013107, 0.09180455987474748, 0.09340393476720367, 0.12932080855326994, 0.20615618702556404, 0.11318365125251667, 0.11719648699675288, 0.17622042979512895, 0.11591481577072825, 0.12741257809102535, 0.1888231456811939, 0.07864243257790804, 0.1073602330205696, 0.09990851394832134, 0.15059465914964676, 0.13267794198223523, 0.19688397885433265, 0.15918451893542493, 0.08863792515226773, 0.13155027106404305, 0.17638658945049557, 0.1401882389826434, 0.144465140200087, 0.11776200522269521, 0.20532069328640187, 0.14193652517029218, 0.11565899449799742, 0.10324560345283576, 0.10437600886715309, 0.09794339511011328, 0.16387934344155447, 0.15785621878291878, 0.1007657547348312, 0.12573013694158622, 0.15985221096447536, 0.23033321755273, 0.16431541075663908, 0.070540473397289, 0.09989808486508471, 0.10855473963809864, 0.09946320498628275, 0.12906962846006664, 0.10519624913909606, 0.08199916567121233, 0.19916539000613348, 0.09981427221958127, 0.14337484299072198, 0.051586873297180445, 0.1251588918800865, 0.10613390989601612, 0.2255551910826138, 0.1310266184487513, 0.13756731604891165, 0.09684658396456923, 0.1559295728802681, 0.21946171591324465, 0.23142223911625998, 0.06797372469944613, 0.13287387575422013, 0.1426763047597238, 0.19447344248848303, 0.2734844349324703, 0.1891074925661087, 0.16994425228663854, 0.06926651711442641, 0.106041595206729, 0.10749954983059849, 0.10852495195077998, 0.10393897803234202, 0.14802557629133972, 0.14810048655739852, 0.25271464086004664, 0.09515689606113092, 0.09419349168560334, 0.23386542658720696, 0.1585993231939418, 0.11536945003483977, 0.10396598372608423, 0.08036721431251083, 0.08159762900322676, 0.10356247930654458, 0.12855581460254534, 0.07837846888495342, 0.14956997627658503, 0.11489271133073739, 0.049787018448114395, 0.1621694623359612, 0.08249549368130309, 0.2358633050961154, 0.14519301828529152, 0.32512149267963, 0.08449401679847922, 0.2233417419982808, 0.16664917767047882, 0.206309332379273, 0.1612921165568488, 0.11621489109737532, 0.10676260651754481, 0.0706255684739777, 0.16209185150052818, 0.15748539939522743], [0.025021365577621118, 0.029037254729441235, 0.06699862916554723, 0.03246028069406748, 0.028076527174562216, 0.012215827940963209, 0.0257288876122662, 0.004525309071011309, 0.04294492577069572, 0.008415159919033093, 0.04760237317532301, 0.02702649762587888, 0.025845434483406798, 0.0150901726779661, 0.041485749783792665, 0.039638601043926816, 0.00883480838300394, 0.05406335648149252, 0.02391767578332552, 0.04998837371489831, 0.025808089612317935, 0.04576010649491634, 0.07396941618727786, 0.02521618315950036, 0.05018976969378335, 0.03697786167530077, 0.009362761213976358, 0.015794112047712718, 0.07148229357387338, 0.05305761830615146, 0.004937891016847321, 0.027672447696594254, 0.0302626279049686, 0.035876246501824686, 0.030089981454823698, 0.038428929168730974, 0.030245983440961157, 0.02785798461575593, 0.01729111296923033, 0.03750906977802515, 0.01855817872897855, 0.07110430885638509, 0.027602312620729208, 0.02272918268239924, 0.05717154898281608, 0.005814210511744022, 0.04688026263777699, 0.02564074082433113, 0.032644245108323436, 0.053448166099510024, 0.02717336144165269, 0.04030993002067719, 0.06696348783693143, 0.03769863549886005, 0.08144422580621072, 0.036198815264339955, 0.006175288681073913, 0.033319903138492785, 0.06413062449012484, 0.057714112369077544, 0.05054509473432388, 0.0510445507908506, 0.033876882001225433, 0.08089174223797661, 0.06191992347261735, 0.07383504589753491, 0.059744913397090774, 0.026520727801003625, 0.03834450923438583, 0.0570391532299774, 0.024163953461019055, 0.05669633358983057, 0.014613669764782702, 0.02395601979722934, 0.06690763761954648, 0.009701541026255913, 0.0339595852419734, 0.036144376399793794, 0.02922992474798645, 0.07718571288777248, 0.026336388496149863, 0.03936042882768171, 0.022157747631094286, 0.03421069069632462, 0.08931654159511838, 0.019285719243011305, 0.05399364379367658, 0.054351143538951874, 0.06095681765249797, 0.06146396829613617, 0.033866354530411105, 0.0583706424970712, 0.016274160306368555, 0.03396704573450344, 0.033804173581302166, 0.039051688608846495, 0.047039005905389786, 0.0554773861409298, 0.03205851671685066, 0.028203586249479225, 0.06709107956183807, 0.035146251387361965, 0.06540075383548226, 0.09339546665017094, 0.03210991574451327, 0.0548148068732449, 0.02209135806853218, 0.04888616482328091, 0.04195353521832398, 0.035642545470701795, 0.038672971073538065, 0.08163960996483054, 0.05977050095264401, 0.02760814462921449, 0.0441169762717826, 0.055260088693882735, 0.05667778244242072, 0.022106650551514964, 0.040055723661290746, 0.022086613412414278, 0.011559073896413403, 0.0551568394127701, 0.017519007436931133, 0.03908252124009388, 0.034087702831519504, 0.015228023852354713, 0.024865801246570687, 0.054741711688361, 0.028007688100582788, 0.042185485629098754, 0.024094205150114636, 0.020510312103267227, 0.053577759502721686, 0.05095960159919091, 0.029177049906658273, 0.04726303102714675, 0.023745516182056496, 0.04729525465518236, 0.050263611267187765, 0.03230946610814758, 0.0418892643813576, 0.05863737461290189, 0.08425876870751381, 0.03576216101646423, 0.025539986855749573, 0.02224177571146616, 0.03951079897316439, 0.010691743294176246, 0.08384731185755559, 0.030899796036205122, 0.023739251607496823, 0.028452366025054028, 0.05203073697962931, 0.08731472758310181, 0.023921657087547437, 0.01786633763861443, 0.04240973127473678, 0.023916893771716526, 0.0787465198497687, 0.041842146909662654, 0.06399445608258247, 0.028955168955560242, 0.03808291023597121, 0.025048771607024328, 0.03923622299251812, 0.04089201128642474, 0.02449631518019097, 0.05267217309613313, 0.07269512063690595, 0.06281096887375627, 0.012189845138761615, 0.050568317595337114, 0.03026355749794415, 0.0012144577735203452, 0.005980654727734093, 0.041643868799188306, 0.031587942503392696, 0.02019038623464959, 0.02846891719049641, 0.024274335841515234, 0.0695053410849401, 0.028846525321049348, 0.012404102748925132, 0.037091692710029225, 0.03242922414626394, 0.04768165659957698, 0.01404064948604043, 0.009852011255653841, 0.033091745738472254, 0.02412623369933239, 0.04034449798720224, 0.01825022730710251, 0.01347887168438839, 0.04700683995283075, 0.0294903532734939, 0.04096320318058133, 0.04655511544219085, 0.023444765713065863, 0.07141813808786017, 0.00866256735753268, 0.06684384175709315, 0.010685626300983131, 0.017517565550016503, 0.03434533579275012, 0.034516255371272564, 0.0436723763788385, 0.016417626358036484, 0.02773418420526598, 0.008831903404955353, 0.027919873794806854, 0.051048862880894115, 0.06351286585309676, 0.04261584985735161, 0.03217774549765246, 0.030319651987935816, 0.08835633311952863, 0.0350455262565187, 0.11207979012812887, 0.07020503282546997, 0.03812565115679588, 0.022321915786181177, 0.018211352339546596, 0.02030558791011572, 0.04240248452073761, 0.068422209205372, 0.024254103623596684, 0.04600480318601642, 0.06151886177914483, 0.02874650586662548, 0.028211557339610796, 0.0998734879706587, 0.007575092005676457, 0.051140047809375186, 0.06843516922422818, 0.03302923230720418, 0.046217819077095816, 0.04093413134770734, 0.06486790028533765, 0.02769781812094152, 0.03962355452988829, 0.0527377026155591, 0.03920573302145515, 0.012813862413167953, 0.06048963950680835, 0.03361262653821281, 0.025044797088152597, 0.02565603330731392, 0.01290470383329583, 0.024204779216753583, 0.023568761202373674, 0.02322037927141147, 0.0409070917272142, 0.06302236645881619, 0.01514799234324268, 0.08496565970459155, 0.014849431846024734, 0.06671840098819562, 0.04345710435882211, 0.021178044844418764, 0.05081491418448942, 0.12166267234299864, 0.05096278732110347, 0.02704543384191181, 0.08190131413617305, 0.010177222912066748, 0.012414753204211593, 0.022122212752167667, 0.028912373751934086, 0.014272634671734912, 0.02804607113025018, 0.026944091244201576, 0.04068677819200924, 0.025754358120528714, 0.04602703877857753, 0.013563716551288962, 0.03252035479194351, 0.028666292849395956, 0.04963844642043114, 0.022162826465708867, 0.07406527961471251, 0.014413563002433096, 0.02631823598806347, 0.054113561287522316, 0.04363154214141624, 0.05323989316821098, 0.03437868918159178, 0.03734896604769996, 0.05298665711390121, 0.016025584091299346, 0.03283332567662001, 0.02112130744249693, 0.02709609835541674, 0.042519307894898314, 0.03043596985350762, 0.020015838190114925, 0.025947341961520057, 0.03741712489032319, 0.024306540809837834, 0.05597656060542379, 0.06024741607585123, 0.033023430832794735, 0.026149231574631164, 0.04096429901463645, 0.05631881027615496, 0.02451371112173157, 0.016338787374219725, 0.03330750969637718, 0.07854732910969428, 0.04612478853336402, 0.007974204607307911, 0.034783852619252036, 0.02537175766857607, 0.017442950446690832, 0.014447935890140278, 0.012547686696052551, 0.043540893255599906, 0.03071399957739881, 0.016525323436196362, 0.08486660716256925, 0.03172461302684886, 0.026794148575780646, 0.04228336430553879, 0.016258852556347847, 0.05481839293081846, 0.04260889148073537, 0.0161152949024524, 0.10192832949438266, 0.03668754707489695, 0.017123050023136393, 0.03717611603704946, 0.056716438582433124, 0.033897746953048875, 0.0074678037448653155, 0.016296867480767623, 0.07039665111473628, 0.06675150671175548, 0.008270022974881743, 0.021448975395677344, 0.012359609511414809, 0.02203985726061676, 0.08514277091515915, 0.03190870636275836, 0.011065974016673863, 0.025818430486002138, 0.0164316245354712, 0.019812857831961343, 0.02072298194148711, 0.04405183351731726, 0.04516660548480494, 0.0246762032953224, 0.03490968354578529, 0.05327806415568505, 0.11328295485249587, 0.1114873747740473, 0.13928395536329063, 0.18282034993171692, 0.18447612465492316, 0.14900467518184865, 0.0947759257895606, 0.10946443118155003, 0.11364831203328711, 0.15126638167670794, 0.1761806947844369, 0.15651049385113375, 0.12419200661991324, 0.09371238321598087, 0.07682753460747854, 0.11988447633172784, 0.05604062109653439, 0.17158351146749087, 0.07599603065422603, 0.13562495527522905, 0.09733283572963305, 0.13558558667344706, 0.2562571907682078, 0.08319977231855903, 0.21950504715953553, 0.08712357069764819, 0.0695483059223209, 0.14946012145706586, 0.10235205425747804, 0.08826350952897753, 0.16668348440102168, 0.10082355913306985, 0.07534587875540767, 0.09561011674148695, 0.1391963836337839, 0.10490747820585966, 0.08091387605028492, 0.08670904686940567, 0.09526256431958505, 0.22213105910590716, 0.13010334941957677, 0.2558514268270561, 0.12785898627979414, 0.1038861201543893, 0.15006540183510098, 0.10021646028118474, 0.08413642205830131, 0.056880443889115534, 0.1120185252012951, 0.13942146727016994, 0.05391363433695265, 0.2245252834899085, 0.1750613155641726, 0.10581912393016474, 0.16611152009240218, 0.08779648744634219, 0.12420339243752615, 0.22072978929749557, 0.15530025879187243, 0.14967228578669683, 0.1567192655056715, 0.16674603175904068, 0.1505265206630741, 0.17234898039272853, 0.15921997917549952, 0.13325848297349044, 0.12945876829326153, 0.12578048423996993, 0.11983928589948586, 0.11915373482874461, 0.08578485503260579, 0.18769432125347002, 0.15738010433103355, 0.20197072518723352, 0.3450018901910101, 0.19982036628893443, 0.1459353898784944, 0.11093280131795577, 0.11990027262696198, 0.14634491290364945, 0.12216995869364057, 0.2068705622638975, 0.07517849773700748, 0.12140562970723424, 0.2814561900283609, 0.12428382597863674, 0.10840245602386338, 0.16432885932070868, 0.13518787015761646, 0.1012463950152908, 0.07420564815402031, 0.13703253545931407, 0.09961366334131785, 0.11292144496526037, 0.08605540051524128, 0.16369480905788286, 0.09076583811214992, 0.12647413701883384, 0.07952091151050159, 0.14608617393033846, 0.21419605346662657, 0.1550891122647694, 0.15685593602912767, 0.20992593759936945, 0.10799426292734486, 0.20262586431843893, 0.10285423123942954, 0.15279718382017954, 0.16075874732009002, 0.13514402322471142, 0.13288427091070584, 0.16559858833040508, 0.11843773110636643, 0.14458103398127214, 0.08679614362439939, 0.16244353620069368, 0.18204532723341668, 0.18959462642669678, 0.0991640185405101, 0.13792570467506135, 0.17114947975746223, 0.08819326758384705, 0.09687962183462721, 0.1664395917739187, 0.13867859356105328, 0.0928000318152564, 0.12123750230031353, 0.18304950477821486, 0.13841738472027437, 0.14802644481616362, 0.09956295641937427, 0.15742961024599417, 0.1604427264205047, 0.16941051664096968, 0.10109775513410568, 0.15541698038578033, 0.1047012714136924, 0.13870714631463799, 0.15953613578208856, 0.11867519122149263, 0.2125697543046304, 0.21572515927255154, 0.23052809281008585, 0.0885913030111364, 0.10785676459116594, 0.12822730865861687, 0.08170248301965849, 0.20260614609079702, 0.13541455513664655, 0.10564309159027678, 0.16981902186359676, 0.09020864551088639, 0.1542970176254, 0.15494177517082008, 0.12101165870470659, 0.15081203462822096, 0.05558226390608719, 0.07097310732517924, 0.18814482779375144, 0.1536910180002451, 0.07366941549948283, 0.17460011531199726, 0.09123213416231529, 0.10921576845326594, 0.07640874957931892, 0.09683104551264218, 0.13414519253586019, 0.1280990248279912, 0.17740192211100034, 0.19429072657866137, 0.10840647295117378, 0.1025808901925172, 0.10400529125971453, 0.13731823941426619, 0.07123570037739617, 0.09778157129351582], [0.0790192298591137, 0.0672875154497368, 0.00712701546893056, 0.11077935740883861, 0.02217649724999709, 0.02132258637409125, 0.02522140448646886, 0.008483559641587948, 0.004407881376599627, 0.07989249085741383, 0.07191264083875076, 0.014143739311423684, 0.029492795999561037, 0.015593650750815868, 0.021100710512005856, 0.008568815870343574, 0.04934913605185492, 0.030683920120022128, 0.049332722289753814, 0.013787761180927711, 0.039517038102660856, 0.011300239928199776, 0.013124693368029381, 0.07497368872697864, 0.030410779240940298, 0.08865998432572399, 0.029324085052524294, 0.07982393846447979, 0.03353447287476488, 0.048730413895100355, 0.03550497928102102, 0.003841323295741209, 0.016906984117148176, 0.012854771289442266, 0.01862463784138007, 0.017500213713252118, 0.028138277253934314, 0.028144531650468707, 0.027666027058980296, 0.022256330287616168, 0.022801941992448907, 0.018322642260630215, 0.007526949097934578, 0.015608335944956966, 0.027311638396765505, 0.0200147711937981, 0.07363641834152596, 0.0437834254199905, 0.04221845903832998, 0.058556798579437394, 0.013990782251182412, 0.014635206466274602, 0.021794792464269058, 0.06249341448502881, 0.04491331854036876, 0.07738460507243872, 0.014445703509928924, 0.026657410198822618, 0.04301154433882662, 0.04665896861947008, 0.0419153201260737, 0.06882339303514787, 0.032850906518953185, 0.026043281724144305, 0.054442230079855235, 0.021579674810969403, 0.019895657763949463, 0.056443063608769856, 0.021553993956851106, 0.04181494104808994, 0.02892645335357104, 0.020725288960550512, 0.059564965910145214, 0.023360423810247864, 0.01348198955279908, 0.0626320324039885, 0.021857251612735645, 0.002084289731491091, 0.04794036843148725, 0.04524305263268096, 0.058076572205339155, 0.07593818554388625, 0.02114670331190739, 0.027863143178235208, 0.031201968036059822, 0.01896382731917713, 0.06628070518906627, 0.0784766800435526, 0.03181570635310241, 0.06321216627423253, 0.04103539930656552, 0.018233637125896554, 0.019373065359624367, 0.11200032689209495, 0.060132926862154684, 0.01974447168010686, 0.01267530132151608, 0.021602711074852517, 0.022824133480233804, 0.04790745269773262, 0.03470281178929976, 0.035076023012931855, 0.0064617055218799836, 0.04476837328236018, 0.03749490875218596, 0.04063349622966988, 0.033768028020858765, 0.02581029145845345, 0.008836493694356509, 0.05732249588306461, 0.04094063510586109, 0.05483962768422706, 0.06479948359940733, 0.01659149077853986, 0.027061947687928165, 0.014952214634312051, 0.015972663448857408, 0.07373931139175381, 0.024488673179543445, 0.046318914009524245, 0.041180049401840994, 0.04722039188657488, 0.011616697634703346, 0.026965733118621365, 0.02274041243695787, 0.04894191665308816, 0.043119553543095074, 0.055041159370115826, 0.07006252690085343, 0.018414612593395368, 0.07674352518681969, 0.023458964058331082, 0.028775160400463, 0.03517026474167194, 0.021879994410223196, 0.03632573523957815, 0.016719525247546177, 0.03687492112762161, 0.03085558269438999, 0.02922926317634327, 0.04208010574802756, 0.02541220174836261, 0.0485206922915365, 0.023707516524674635, 0.04986678023955651, 0.023445954845686044, 0.031053236552647183, 0.024657845530392866, 0.007960327718007778, 0.02899506002930658, 0.038807399038757594, 0.028950792404689958, 0.051401629844414334, 0.007938992032515151, 0.06225599508200373, 0.016193918451400738, 0.03562394682584064, 0.03739727434835263, 0.02087448863312602, 0.05285686015018395, 0.04607128943981869, 0.09237506533307688, 0.016498534873660122, 0.009259115838046585, 0.016993675447468246, 0.037167590244540145, 0.032034435509038825, 0.0289042822218367, 0.04652792315131851, 0.026699464102940898, 0.04731335457680481, 0.06435404571571521, 0.04020953397931797, 0.02590070285701326, 0.03824914453018989, 0.023369548409911137, 0.07121954445860215, 0.009012996767913657, 0.012279103875958493, 0.04173310293949076, 0.004294898934728865, 0.0330145114899746, 0.031292260690991364, 0.05998722503760031, 0.02707218678135957, 0.008340860334491091, 0.04323268907942942, 0.02021319349296391, 0.054383526622716866, 0.03945454163476825, 0.006432264311505216, 0.01225464862571763, 0.04087207932025194, 0.03423359125320401, 0.03912147254283939, 0.01762802935471492, 0.04672129884628313, 0.0035868875067015843, 0.01820702837514026, 0.04160238316814814, 0.026594331887151514, 0.034178117622754405, 0.007476114950674985, 0.10187600087374449, 0.02066884163234915, 0.059105957326080115, 0.01935987124618675, 0.031390278467110226, 0.012370165819967431, 0.02921262549768601, 0.0029095609165129383, 0.00702062329842842, 0.0351463362042393, 0.010298086114094725, 0.01108082799640085, 0.04811943721558366, 0.042568433830248456, 0.014472093433141708, 0.046090790536254644, 0.08995962315904242, 0.03592064304809485, 0.035630257201514075, 0.05025846797174641, 0.021579518747915114, 0.02613022580875882, 0.006480485250774238, 0.08342489666704621, 0.02293776604346931, 0.04433125423799668, 0.05757254960813692, 0.06929796721254076, 0.06516997729028974, 0.028171515291822807, 0.025142992979713848, 0.08289215846785478, 0.03502405062317848, 0.044501169584691525, 0.04947843089965837, 0.009169360073948545, 0.0205768204094576, 0.02076356003193983, 0.04532135896650808, 0.024562494396897297, 0.033203544560819864, 0.03842040337622166, 0.06028968880751303, 0.02568084902928344, 0.011293145844579806, 0.04293121597064393, 0.051203643503998, 0.028502735375825847, 0.01799612951331905, 0.03552507409559829, 0.12461427253271852, 0.03143820000280227, 0.05809485872409173, 0.036068539933434556, 0.025766676923792278, 0.041532612804855616, 0.006978666085550296, 0.0324396362661251, 0.02332371676207653, 0.061436121218970845, 0.0399878226619746, 0.05012715448226247, 0.05424746338810239, 0.015031757598210658, 0.06668281182646751, 0.006805188430007547, 0.016252654138952494, 0.02035971634489085, 0.01725423798364188, 0.009382872143760324, 0.0681847898023469, 0.01333174408812608, 0.04858776887080499, 0.02897805254906416, 0.027052343024739196, 0.012813701261101025, 0.042217529445354424, 0.024067954326580678, 0.015494345454499125, 0.0209677261300385, 0.036297253732170374, 0.05398252260472093, 0.020262529774169837, 0.003657390687814248, 0.05521613319537469, 0.0668783113360405, 0.02271819211143468, 0.030830734742007086, 0.022854411409103444, 0.016479822574183345, 0.07280346232333354, 0.006479427160229534, 0.010103204919557487, 0.02229608904703387, 0.04138393899691956, 0.06021061233643975, 0.028278728913781897, 0.027718038464497243, 0.030167205525296073, 0.019990520352231603, 0.03704739794401186, 0.07307692550654922, 0.032514336186328104, 0.01840199693106115, 0.01022240231811468, 0.04515330959111452, 0.062194187327155044, 0.013973302340933254, 0.04053595003538898, 0.04148698132485151, 0.04860421655965703, 0.011000748141668737, 0.03779525888551559, 0.007378036106404449, 0.029126037643956285, 0.028825134504586458, 0.03235359124041029, 0.060776374834988794, 0.02505634575416999, 0.04598811800990786, 0.013266355364716478, 0.017840341265712465, 0.03468203165435365, 0.029552462976425886, 0.0277753916369485, 0.04000587847882083, 0.027854368024106537, 0.02669019192191107, 0.027760248431669812, 0.05503286088683775, 0.022178687221769775, 0.039855199599904675, 0.05812543351203203, 0.0592980438045093, 0.07264451549521514, 0.013173971973758723, 0.04183930045525942, 0.07973034134400742, 0.0421986152817096, 0.021375983687383786, 0.010183432355656155, 0.04063016462272831, 0.03720490627789071, 0.03869818543483104, 0.05458717533786382, 0.01336237570337419, 0.014217284873926213, 0.023569439737392322, 0.01729973714931735, 0.21068827169282095, 0.13139339376773151, 0.12015888946396963, 0.15875993243285588, 0.08747972694358655, 0.11871833247797829, 0.09281491208821535, 0.13225707385156835, 0.13232605372156414, 0.15982711873948574, 0.192299253440329, 0.054074436958347044, 0.11131559684872627, 0.08982614175017391, 0.11038164089300803, 0.09071838137294565, 0.12038299600992884, 0.1297604992453541, 0.12528428515153273, 0.14752253756991454, 0.11545718461275101, 0.09971703815140895, 0.11872439858104501, 0.15370876847633294, 0.10266836692712136, 0.2040980817484004, 0.1000842477328011, 0.15553432623190538, 0.13386855380875723, 0.22936312960726873, 0.09498646163514682, 0.058644404235695086, 0.09116578700819186, 0.08528993159000363, 0.10634806911860194, 0.12258208729326725, 0.1026305996679834, 0.0850402374884912, 0.12296818728957858, 0.1292998825332948, 0.17312336526811123, 0.13599407832537377, 0.07207654775785548, 0.13752830028533936, 0.22756319333400044, 0.08971682297331945, 0.1240867522678205, 0.126795246931059, 0.1325997476066862, 0.07453037465789489, 0.1668205349040883, 0.057178218982049396, 0.1494210378399917, 0.18163463712802955, 0.1827766387058156, 0.14448656833597592, 0.1067300368366497, 0.12401834236724035, 0.16024741690073693, 0.09446388789053474, 0.16751733608543873, 0.14662133449954645, 0.1573297841740506, 0.12544798851013184, 0.09987607997442995, 0.16116869103695664, 0.1587853639253548, 0.18492152861186437, 0.08722303036068167, 0.17935380951634475, 0.11433106075440135, 0.10595915320196322, 0.15929415662373814, 0.14545656128653459, 0.16243335817541393, 0.17678028903901577, 0.07295439565288168, 0.24714074709585734, 0.13443489984742232, 0.18940627867622034, 0.10097464174032211, 0.1257786929075207, 0.10245129678930555, 0.20175466606659548, 0.10815665671335799, 0.10604145949972527, 0.1184248389410121, 0.22572125574307783, 0.09856579492666892, 0.24354641139507294, 0.0830869319449578, 0.15011215289788588, 0.09421127608844213, 0.2964939645358494, 0.14374605592872414, 0.08486876490392856, 0.05803512728640011, 0.09670222563935177, 0.07473550257938248, 0.1567573177495173, 0.12241048578705106, 0.11534609485949789, 0.0726219949179462, 0.1292472282158477, 0.06414975239230053, 0.114151303257261, 0.1377507783472538, 0.1745766651417528, 0.12082765357834951, 0.1627789767725127, 0.16953927544610842, 0.13811124329056057, 0.1618194468319416, 0.0850539371105177, 0.1209753570812089, 0.10447213013789483, 0.058497664252562184, 0.18383216778082506, 0.11679642274975777, 0.12618419900536537, 0.13088760019413062, 0.14280260726809502, 0.09662171067403895, 0.07245831191539764, 0.07485926736678396, 0.10812684188463859, 0.08930506756795303, 0.18861307123942034, 0.17184755658464773, 0.16230846701988152, 0.12438884962882314, 0.07553863698350531, 0.08806623225765568, 0.22956823717270577, 0.13535234704613686, 0.1474302839487791, 0.10500493619058814, 0.17968645452388696, 0.15178905720157282, 0.09595231552209173, 0.11146132581468139, 0.1057742659800819, 0.09757712869239704, 0.10624607851994888, 0.12314381929380552, 0.15050771167235716, 0.13810979122562067, 0.06519432312675885, 0.12573327177337237, 0.15170790441334248, 0.1446192083614213, 0.053801869441355975, 0.1138627358845302, 0.13602590161774838, 0.09472080160464559, 0.1312381313847644, 0.09093408087002379, 0.10467339719512633, 0.09257006272673607, 0.2009472365358046, 0.08827658489878688, 0.1532133836299181, 0.12744368213628018, 0.13764378694551332, 0.1639642688844885, 0.11091443337500095, 0.08544887163277183, 0.15050210697310312, 0.1418039258569479, 0.21149148073579582, 0.17139470231320175, 0.21213256062141486, 0.16772105943943771, 0.08751510575945888, 0.07072529955101864, 0.1221048329025507], [0.0990970539195197, 0.035770113446882794, 0.03793096249657018, 0.05685974517837167, 0.01446632418914565, 0.03694989585450717, 0.055098495579191616, 0.02572237197974963, 0.04891411368069904, 0.035234756102519374, 0.016022819061098353, 0.046066434521760256, 0.051630611664482524, 0.006036367965862155, 0.016368425783834288, 0.030545424337365797, 0.07573002457086529, 0.02199270755850843, 0.006075916379424078, 0.01173333017089005, 0.024604516070602194, 0.03724416292139462, 0.03870882486392345, 0.017180903615163903, 0.07415790643010821, 0.04190252974097218, 0.041289395320096185, 0.033034952357411385, 0.030401432421058416, 0.0665975742574249, 0.030330366055880274, 0.11353832150676421, 0.03605549170502594, 0.007633095723576844, 0.015161057535026754, 0.02529865569834198, 0.023029794051711048, 0.013845879401612495, 0.032435727904417684, 0.015997409620987516, 0.03619697304176433, 0.020513138201619898, 0.022323503558124815, 0.048171708160745244, 0.025484670984691808, 0.03424082782917789, 0.026426229925294007, 0.075788704279278, 0.04552942494462643, 0.04758868033864668, 0.04098880769951003, 0.03207588382065296, 0.048856468738189766, 0.03506120041544948, 0.06647445407829114, 0.060908098838159015, 0.07039153496069567, 0.022505856451711485, 0.04698049922340682, 0.047657361653234274, 0.06543749650674206, 0.061555380533848486, 0.03118037705176643, 0.06424461837325778, 0.06779011312339987, 0.020361258315720727, 0.035534604119935205, 0.010062728609357561, 0.07994403237743036, 0.002223318800263639, 0.05245491296851209, 0.04065979963966778, 0.01871742750518024, 0.013944828467044448, 0.029837783559092453, 0.04075403119038258, 0.01299276580435357, 0.060099312237330844, 0.010832432441280355, 0.016206238951001848, 0.0076404391688161665, 0.018831314519047737, 0.017722740968955413, 0.045649664742606025, 0.04705689548115645, 0.06973630083458764, 0.021630721000422324, 0.0226195585647864, 0.024080206972679923, 0.033590926988316436, 0.011745259664686663, 0.09708758603249278, 0.02222157402762345, 0.03867000248283148, 0.04446075603898082, 0.0399285797694964, 0.023992730238075768, 0.03391270525753498, 0.059909227437206676, 0.07867952808737755, 0.02967206834416304, 0.04776391200721264, 0.06116638997835772, 0.053409401393894634, 0.01769832897532199, 0.04889166434960706, 0.0752775842057807, 0.04924390544848783, 0.03681297427309411, 0.03654101065226963, 0.022407333167003732, 0.01537090806024415, 0.026832736862291182, 0.032657825986721685, 0.039269291396651945, 0.05466291341664536, 0.04895342799967953, 0.03513887571170926, 0.020309465737747293, 0.059155836435300965, 0.00342849750138287, 0.05228795603449855, 0.021177995650629913, 0.023910171186019267, 0.04335731899897967, 0.07383740719939981, 0.012560085227180804, 0.029650253443313495, 0.04264146794698068, 0.04080670925655535, 0.04140361990513546, 0.04392404162458011, 0.09024555103055068, 0.031195549094783406, 0.01937193050980568, 0.01937564548903278, 0.130020106743489, 0.03760678221338561, 0.02297109059457268, 0.07519714387931994, 0.015538492639149939, 0.06046186028314488, 0.06957776112748043, 0.05152100111757006, 0.0278903558251581, 0.03485564501690013, 0.06862890454275267, 0.04094975461651172, 0.0501037484167942, 0.0351001483255199, 0.054591972580445666, 0.026427095057442784, 0.02209520196941282, 0.07228315488568374, 0.016005121171474457, 0.02207470342649945, 0.03336197570232408, 0.08731644427669899, 0.043267240082579, 0.004927070927806199, 0.008584321243688464, 0.02406138101858752, 0.025398990671549524, 0.06680502276867628, 0.03826019447296858, 0.021382838587409685, 0.04505544448537486, 0.01670096392211105, 0.05778111770216908, 0.04903059100200023, 0.056074503742690594, 0.011842715104908814, 0.042178415294204435, 0.012531570641190877, 0.007694126555829176, 0.04229384088622672, 0.03462642910225051, 0.03611857849838478, 0.030866378186536685, 0.053389934224209616, 0.041442062306616984, 0.05400119249575904, 0.04294504112164889, 0.012210192707633334, 0.03157951509846108, 0.00519527164786788, 0.037289529772741456, 0.06330087794257061, 0.021029825654945204, 0.034568916474069865, 0.0770677767161812, 0.02715112076007894, 0.008130757054979247, 0.04204042162746191, 0.01888859474898449, 0.08524102278585945, 0.017115582745256167, 0.0060897690959141725, 0.03917159592466695, 0.01721834178481783, 0.026627281547657082, 0.015931824122422507, 0.032594874900366576, 0.027476137337673987, 0.09440556102033172, 0.0792862062475511, 0.03714294245998774, 0.06750708938177143, 0.07046930864453316, 0.03862835739606193, 0.0759782191099865, 0.04958315599443657, 0.02832734934054315, 0.019836528526086892, 0.02619122780327286, 0.05310767722715225, 0.04797210690698453, 0.006945062062836119, 0.020085861307701895, 0.0055831192959366095, 0.029753536651177064, 0.0449060175035681, 0.024252456479838917, 0.06148637352245195, 0.04104536359331437, 0.05517587910539337, 0.04283534575785909, 0.03310052937428866, 0.027160023139523606, 0.03519855625927448, 0.08169470700834479, 0.0469029969535768, 0.07442154442625386, 0.04833694161581142, 0.01068452707425292, 0.04741251229175499, 0.02349068726679044, 0.042737100672508986, 0.07056260042424713, 0.0655225712273802, 0.023957137683672563, 0.05077668891421386, 0.02949483838996717, 0.030904237047902176, 0.028456442324178557, 0.02214932531517531, 0.02669494166704161, 0.026227576924221854, 0.025325466313266327, 0.031319425840462954, 0.037506660978708944, 0.019573443535981432, 0.04610610167895045, 0.040849501067506414, 0.05615845209519778, 0.04705399813662682, 0.009306702347073172, 0.029958908845271384, 0.028061928493635993, 0.026909645413979888, 0.01687653485818633, 0.039401235923703225, 0.020062319535229887, 0.03650658178542342, 0.02107345376030675, 0.09805075970611402, 0.015273165090807846, 0.08134292052792651, 0.020967290171289017, 0.033625810473625145, 0.02476636363592531, 0.007476834197794753, 0.006028714939020574, 0.07483633288315364, 0.017506235711542622, 0.05951769916074617, 0.06515701048608337, 0.08253517440919365, 0.04679042460130794, 0.049610436494861326, 0.046927542957876406, 0.07548475451767445, 0.06371160876005888, 0.046712912153452635, 0.08093899541667529, 0.05071525774630053, 0.04253907361999154, 0.023652852047234774, 0.03564480499231389, 0.02540955037277724, 0.04704183539641755, 0.10698509136480944, 0.07738350584570851, 0.004016824681977076, 0.030207093206367323, 0.05931960764740195, 0.04974675757278289, 0.03122485162956374, 0.01930994972852724, 0.02446711781833853, 0.0489796465928001, 0.06477877471063818, 0.02809764996969274, 0.059964677318930626, 0.020871986535244753, 0.04257010302639433, 0.04529973405546375, 0.06541193609258958, 0.027993245482710854, 0.03376783803105354, 0.04871856328099966, 0.016009078726970723, 0.03563357863043036, 0.06356788825775896, 0.011142002169175871, 0.034633031247981956, 0.04115294532052108, 0.01829500892199576, 0.056236924670104466, 0.05276954626398427, 0.05976447556167841, 0.023822210995214324, 0.0634025496297649, 0.042646852122353654, 0.04707906661289079, 0.04278988051893456, 0.029838960817349807, 0.008336115678373193, 0.08370734365390879, 0.03397499477224691, 0.04525379044935107, 0.02745421726389655, 0.052785267920366356, 0.015597006106483085, 0.07814486963408333, 0.022823912956352745, 0.05005950114822813, 0.053292656051261086, 0.05549958102138979, 0.018969452374481728, 0.04383554369477289, 0.020065964964617575, 0.05067629287285464, 0.014146288906756257, 0.03691502254722374, 0.023689554006393467, 0.04114414472132921, 0.04312553482928446, 0.01659441865714533, 0.04879378567316702, 0.04034603826169457, 0.03543232514389923, 0.19387346825429372, 0.09020735629435096, 0.14311695897153445, 0.14316250224198612, 0.11930747729326997, 0.12127611094287463, 0.10083470746342625, 0.11565997158842427, 0.0979060349719865, 0.10549803437399012, 0.134779351364289, 0.19904334869767937, 0.14735400304198265, 0.0919303127697536, 0.1321847148771797, 0.12374595126935414, 0.16848974462066377, 0.11960106582513877, 0.0868408183700272, 0.13420205377042294, 0.12933697125741414, 0.13392683996685914, 0.11978733725845814, 0.14299503979938372, 0.17307100950607232, 0.12251632367925984, 0.09096067265740462, 0.08857003772365195, 0.14743668931935514, 0.11404157057404518, 0.12251229318124907, 0.24028287508658, 0.10306120477616787, 0.0774859239214233, 0.21204025271747792, 0.191800041656409, 0.07520789865936552, 0.09527240307735545, 0.15940449998847075, 0.07452987932733127, 0.15840150309460505, 0.16016361782593386, 0.07765060437044927, 0.08823585922696761, 0.10348335533801999, 0.1925309460077967, 0.12089647059994084, 0.1426053164260728, 0.16190229595771857, 0.15215161203273705, 0.12527973896690778, 0.09472037412758384, 0.1652482199881758, 0.14673485340816633, 0.20067693532577582, 0.13178353783275398, 0.2385595589876175, 0.07906220826719489, 0.09658831996577126, 0.12094050752265112, 0.10591224607612405, 0.221640247585518, 0.1510502818439688, 0.11121087853929826, 0.13751012911753996, 0.11270551476627588, 0.09261572134814092, 0.058604764219905646, 0.18826606843088353, 0.07292982589985643, 0.12904647684523038, 0.14217154255935124, 0.06521539163908788, 0.27416918533188955, 0.08471372643751757, 0.14766459566141876, 0.13861634475844248, 0.13744869455695152, 0.22683769012136118, 0.12852415415857518, 0.1491516051547868, 0.06589290206985814, 0.08387796806969813, 0.12033369365547385, 0.0942348280389394, 0.12837621995380946, 0.10548701496528727, 0.14090562691645964, 0.1487806907721928, 0.19131167286208697, 0.11322951343442712, 0.23443846298115595, 0.1557128895074129, 0.07915661962968962, 0.15533846031342233, 0.05265890773651855, 0.06641391518392734, 0.12253681543682303, 0.12233158573508263, 0.16606856882572174, 0.19396728250597203, 0.17096923371510847, 0.15185131957488401, 0.10733545970703874, 0.0858442879148892, 0.21890697282339844, 0.17999540508857795, 0.12072865531912871, 0.2551767187459128, 0.12483760554875646, 0.26668670826724594, 0.17051333960677895, 0.15291792234139784, 0.08032950133617435, 0.11921271309256554, 0.24889003751533373, 0.21143552873815807, 0.06339628675154277, 0.08764794256005969, 0.21217838887657436, 0.13317062625927584, 0.15446989477745124, 0.1888993587344885, 0.07201535746987377, 0.10972029316638197, 0.2078449928334781, 0.07374199160507747, 0.18702247659010546, 0.06343229660498244, 0.12522104568779469, 0.22896773368120193, 0.11748520364718777, 0.0975989910906979, 0.1518701964191028, 0.15167654252478055, 0.09743969142436981, 0.28344763602529255, 0.18002066016197205, 0.16177884329642567, 0.11643647349306516, 0.10884397876049791, 0.14306127838790417, 0.18479081562587193, 0.21346030437520572, 0.13071713862674578, 0.2068252225539514, 0.2013010246945279, 0.10147404351404735, 0.15458686064396585, 0.14246856447841438, 0.18329585370208534, 0.08320443385413714, 0.17059669084846973, 0.15847322424607618, 0.11083906849047967, 0.13635462469288281, 0.27314761014921324, 0.10457771697214671, 0.1884094157389232, 0.11643453288291182, 0.07015170675835439, 0.1131192311378462, 0.122279786371759, 0.11284106570695128, 0.12286222726106644, 0.09690677002072334, 0.21043625021619455, 0.13057558265115532, 0.14947803478155816, 0.12487188513789858, 0.1354270808930908, 0.1638546311961753, 0.06853891044322934, 0.11732447227197033, 0.10926414800009557, 0.19979516549834184], [0.06652260970856462, 0.07808608136006764, 0.06190103305769818, 0.04322636852573071, 0.042783068027347326, 0.02148550602474383, 0.004861062617107693, 0.04527155449613929, 0.02343486588714378, 0.029141582881233523, 0.027614232784669315, 0.044843236050967655, 0.028162636661103795, 0.020514283229463866, 0.033231907324599366, 0.033578424980597835, 0.025562118971720338, 0.01989436345840139, 0.06431218689041478, 0.005833822294204895, 0.02616287182484354, 0.10725309234112501, 0.044235577407692156, 0.004121505671979061, 0.014776989751096283, 0.06289848632046155, 0.028269287098997405, 0.03383401555142232, 0.007127145238752876, 0.036481096010122976, 0.004984662435682756, 0.017477928926902156, 0.0825100007600018, 0.04591418483427592, 0.044686636954013786, 0.056456423963287046, 0.03634981305471488, 0.046079845766403844, 0.0105615519319794, 0.062343695733164034, 0.05355894711932965, 0.03279253215129886, 0.011027183017826505, 0.01923854579217732, 0.07517074886709452, 0.03459723513307316, 0.011715142887883952, 0.05158068166513528, 0.036256178614816496, 0.05335492520992245, 0.02912022259884647, 0.02243505301885307, 0.021609382770423378, 0.06610029629830803, 0.04684067351211395, 0.07294127957097121, 0.031227338460407088, 0.03878348067935024, 0.06381127876894814, 0.05607216618955135, 0.024289982859045267, 0.03617160601009216, 0.014031384938529559, 0.001202777005216506, 0.0464886190103633, 0.037027805245348384, 0.025716158295316354, 0.052379514157239876, 0.07197455715920244, 0.02724618012351649, 0.004082315609723861, 0.08230517817927258, 0.03151206871760743, 0.04145607405475207, 0.024709275092131326, 0.039225987291761806, 0.009017059496337814, 0.030272531123565774, 0.04486300516873598, 0.02214948307456715, 0.06644421855786017, 0.01630440091581217, 0.025573596391560774, 0.030536484638495103, 0.02195357983665807, 0.0674705570563674, 0.05571508374331253, 0.03281627409160137, 0.025520877613286887, 0.03284130185576422, 0.02097688296011516, 0.033561312327427525, 0.10321196847196136, 0.04666295162002955, 0.058474668700780184, 0.0033271549036726356, 0.036005887402487655, 0.036379458249679635, 0.06329302729240485, 0.009997166859518205, 0.015533520673800792, 0.05598490658615317, 0.054548434380974085, 0.017167855386755297, 0.05930860859474965, 0.05550216623981084, 0.07384863016860825, 0.027191140755478824, 0.059699159780783315, 0.02330312322426055, 0.030934414892856563, 0.031127118838152716, 0.041067076713911126, 0.008972324530727096, 0.05031330717195358, 0.04368311080283352, 0.07949784810521773, 0.02445192033025835, 0.07878229221595184, 0.025266041912670647, 0.04646593558468989, 0.0603867464565805, 0.021923956694081426, 0.02844291233590671, 0.08304995857179165, 0.059552528363253386, 0.015429692941584756, 0.010074947328705872, 0.039771444629877806, 0.019067549878465276, 0.014465601549350789, 0.03867937305143901, 0.0045035819556298, 0.059080105141869614, 0.05966886319220066, 0.026318027338545238, 0.025597896426916122, 0.05677444314850228, 0.06252658127674035, 0.06458020143743072, 0.0453381187814687, 0.03899694101086684, 0.015582756871091468, 0.04307654799361314, 0.09653685986995697, 0.01774424035102129, 0.07678079711539404, 0.030636724616800035, 0.04471125081181526, 0.06439338717609644, 0.0424022402481309, 0.04353375506720372, 0.024561171253610934, 0.028435394167900085, 0.030244341386216025, 0.008572369697503746, 0.011123629985377192, 0.02104962700312691, 0.020440675750640885, 0.07144987317068235, 0.0198698836112661, 0.09765015263110399, 0.05262024820383106, 0.02698691698190357, 0.011717944389342197, 0.041935594752430916, 0.07494091548557792, 0.038012685254216194, 0.018578872350709777, 0.03974908011566315, 0.020698675120781575, 0.02281999950563269, 0.05313143952350531, 0.018740602868742177, 0.0024547210819686627, 0.04735503698300038, 0.03868350872237768, 0.027237710310146213, 0.04091016549084868, 0.029465271226529564, 0.03325799360339131, 0.05368471697771123, 0.04855220006512744, 0.01627973447154675, 0.05397789499589375, 0.056561854734484635, 0.028890555458409444, 0.019510007297087992, 0.03667063458955713, 0.01088991538355393, 0.045485751038151126, 0.03797512494825891, 0.019021860722984587, 0.01519393255668027, 0.04963089432567358, 0.0299293315038085, 0.042410671045737605, 0.05930740758776665, 0.03172698111406394, 0.048303842677601745, 0.036481435277632306, 0.0304794571628528, 0.021164655652163283, 0.006351725597466741, 0.02351302803227944, 0.06204989007008927, 0.0284748950840107, 0.028433171965714012, 0.03646962198295763, 0.05471664660477212, 0.0237817346850144, 0.0737002074186291, 0.01632503346939172, 0.08486379124224186, 0.0682570877085839, 0.02113285441217678, 0.03601460997015238, 0.032703942619264126, 0.09078910507793937, 0.022869995662144253, 0.037556560443980355, 0.02580268168821931, 0.016885247247825776, 0.050633456957127364, 0.030893197283148766, 0.05498869504247393, 0.021137979047905122, 0.034175481514206955, 0.023429386716868197, 0.036365521140396595, 0.02576025458984077, 0.04327872768044472, 0.006628541167758937, 0.022555642262367264, 0.03937846089580229, 0.021933220393423523, 0.033956243457006555, 0.015632766598303403, 0.018244351193841015, 0.06392047540949923, 0.009111288502546293, 0.026306633039244583, 0.048873659422887225, 0.034337430859782865, 0.01797702196719391, 0.023792140019525374, 0.043317767192742655, 0.057010166213980744, 0.014888944636498178, 0.06502282340079546, 0.041862577599074156, 0.015409576074619378, 0.02491585847123393, 0.015035676137943352, 0.06444565472858292, 0.046868093112217526, 0.03467750921845436, 0.009964008549494403, 0.0811094366280096, 0.06305061387164251, 0.042509336822799275, 0.013358802368332232, 0.04597880172410181, 0.02779043136563684, 0.02231902861967683, 0.04463379603943654, 0.03308904516909804, 0.015275070077872701, 0.04004601721784898, 0.041033078716801744, 0.05780747878764357, 0.03222599273015346, 0.0288741111622325, 0.03983713021235807, 0.09919292413230453, 0.031690869480371475, 0.04577718861401081, 0.025021207818229283, 0.020179619580241184, 0.04761524159195168, 0.019242311661530818, 0.024117305874824524, 0.02280834736302495, 0.04866727621161512, 0.06875818581985575, 0.02967348648235202, 0.04924093007243105, 0.01074966389153685, 0.06142985834074872, 0.028943158885730163, 0.08035812194326095, 0.04606558974566204, 0.03629595773028476, 0.024568390866209353, 0.018961248886106268, 0.022854426676141362, 0.018192341484661614, 0.04494283142100487, 0.019727616870243634, 0.05887328088283539, 0.009789425730040031, 0.05954515268760068, 0.031548112497798035, 0.03386166585343225, 0.007515260484069586, 0.019086928838597875, 0.020430528259437, 0.023201329400762916, 0.010571098919691784, 0.016800616967624853, 0.05659011911068644, 0.01683466076584799, 0.038753726918782504, 0.03070028977734702, 0.042742379674954076, 0.06845751338239227, 0.01625934279789882, 0.08001034560480288, 0.019050813812230314, 0.02468354843689927, 0.04875825757959059, 0.044175191183707545, 0.03774326274703656, 0.01905354152300528, 0.03715116969708886, 0.06215557189924376, 0.04445481885756765, 0.03711650334298611, 0.04808032984978386, 0.03616527867104326, 0.05058066014732633, 0.07155605033040047, 0.01001181049338941, 0.030915673755641495, 0.03142937904755984, 0.05481805366330913, 0.05342656493719135, 0.07855186850896903, 0.04586582225082176, 0.0379622768876808, 0.00908900541253388, 0.04656129011086055, 0.013404463534243405, 0.01920012035407126, 0.06103098153003624, 0.040137565162565024, 0.015278863088626946, 0.0771290755697659, 0.07969742561025278, 0.06921197646962744, 0.038562312190021784, 0.04473414797601955, 0.17293849161693028, 0.13778192310460977, 0.10311959949987275, 0.11827998528523104, 0.09662558510899544, 0.13544949969010694, 0.12686354826603616, 0.10043553888265576, 0.10302490315267018, 0.08942907662796122, 0.11342489759304694, 0.13498174478965147, 0.14731384733957903, 0.14791422869477952, 0.1330464407801628, 0.13506012915500573, 0.07694829348474741, 0.06707201951316424, 0.12416080757975578, 0.08955738759998765, 0.08489865437150002, 0.17699847875961236, 0.15545985022825853, 0.08292753728372709, 0.07864237150975636, 0.12920089784477437, 0.09578409990561859, 0.1109740494617394, 0.13960917719772883, 0.17121755039053305, 0.16399438226861612, 0.08852983452379704, 0.2003549568887268, 0.16677227749356202, 0.20256419905594417, 0.2197568786463567, 0.09059788033898387, 0.09518965573183127, 0.13539751033697808, 0.09348060922431094, 0.11442131948258195, 0.192996583878994, 0.17192579167229788, 0.11877655078257833, 0.1035271751295243, 0.04625617326902492, 0.08628404646047524, 0.09594221892101423, 0.06754350635622229, 0.11671356005328042, 0.1461520596806492, 0.11536210828593799, 0.1475698043193136, 0.15002600609191827, 0.19703848127807888, 0.19518568712685788, 0.11750623823276587, 0.1475964571748461, 0.10725587433470146, 0.09998533089778253, 0.10361704030739409, 0.18149887584149837, 0.12350047087030751, 0.14861431398562022, 0.24481120066983358, 0.19358889066747256, 0.16090673580765724, 0.19978350826672145, 0.13237032134618076, 0.09365048046622958, 0.13507174567452498, 0.11416940657155854, 0.11082693628434624, 0.11706476977893285, 0.09573873983962194, 0.17294151788311346, 0.11211900266685657, 0.11534263433090278, 0.16286605995680603, 0.09147234912961721, 0.18859342086528028, 0.06476650679750101, 0.14825995585748128, 0.10318570916673966, 0.15067878392125877, 0.12314314075878688, 0.1758675237319299, 0.11500780444060053, 0.09999626209693295, 0.23073607736400195, 0.14330627024173737, 0.1333478596061468, 0.18177189119160175, 0.13956066194389546, 0.11503919347056321, 0.09984429739415646, 0.13188411029321806, 0.13449318600552423, 0.23173441950763973, 0.10637448448687792, 0.0692555723445756, 0.1368705691503627, 0.2010525180292981, 0.11268505015011344, 0.18176828138530254, 0.13709672487207822, 0.1371828852487462, 0.14213700512690203, 0.27546543149011476, 0.1055119986246739, 0.08197060613227741, 0.08474201456244503, 0.10496290773153305, 0.08221216459891625, 0.21508839486965112, 0.136752544769219, 0.20510369778743812, 0.1387556887098721, 0.2119671744959695, 0.10344652445720774, 0.1099599449496184, 0.1747668177953788, 0.09808980261108705, 0.15034649175192627, 0.1158154918146985, 0.2039469312876463, 0.12169638196272509, 0.15772982127964497, 0.10446915136916296, 0.13835920712777547, 0.08228284080645867, 0.10441946903509752, 0.08476412123335259, 0.09668963202940566, 0.19436753674277238, 0.09689041054142372, 0.09743299428373575, 0.14728657023182937, 0.12507307077092783, 0.17171630077064037, 0.07757637942475931, 0.1964860452072961, 0.1636937776846545, 0.20412822227392877, 0.1697226291788476, 0.08587199249970061, 0.13313437891857965, 0.06979166250675917, 0.17431817044104847, 0.20145989688379423, 0.08887130727193185, 0.12439454932297979, 0.09099413800452437, 0.0899025040811726, 0.13423047081700393, 0.16495792913649762, 0.13094252081854002, 0.20677613733070238, 0.07267126334565026, 0.07910845042871577, 0.13008006209773676, 0.23144959764821188, 0.11632323956915311, 0.0686751331335732, 0.15894874158714498, 0.1146407848490136, 0.16881204875452177, 0.11905949988535472, 0.12875409610569477, 0.09045432947043862, 0.11659655347466469, 0.20039275128926548, 0.11303951684385538, 0.09914704159434352, 0.09691194724291563, 0.13767794439835207], [0.04423070213358317, 0.06070331696953092, 0.033742118161171675, 0.049954056806330166, 0.012429044848041875, 0.08537667550678764, 0.03970063950068184, 0.026662165032965795, 0.02733486465045384, 0.028056846266346316, 0.03229250951803156, 0.04366320597806147, 0.13003880716860294, 0.0362869976753635, 0.008043073367194405, 0.014435946176360761, 0.04150666223306741, 0.08489697839000396, 0.009579719393514097, 0.048504739933248074, 0.08556945409093585, 0.10132526114050831, 0.011155485508165188, 0.09747152150209461, 0.022546158039144108, 0.051816282594310384, 0.019118382329387323, 0.04569850230057325, 0.04184355826250144, 0.0321609076511647, 0.053220046018915515, 0.002527268985951585, 0.020173198942627226, 0.008087357107017721, 0.024468763265758753, 0.07229102589190006, 0.02619799110107124, 0.009820171848072537, 0.030408726672508886, 0.06643530939306531, 0.019121081202424, 0.03773333238703864, 0.04805516977129238, 0.011275090875902345, 0.047794432512351444, 0.007675522821955383, 0.005130444836270596, 0.02543490213741149, 0.06850425087447677, 0.03758376291287797, 0.005704421849389161, 0.06647990271449089, 0.028575124884290353, 0.024038505906771337, 0.008812677963370723, 0.061259389988013675, 0.06960860054407801, 0.016405592539480755, 0.04920630103775433, 0.038398208495761664, 0.02895560661064727, 0.04481028978313718, 0.008192161081491836, 0.08767585070537669, 0.03505109024367162, 0.013828365564612406, 0.018731932887541394, 0.04013971272589905, 0.016310823249763677, 0.01362642930221877, 0.004955605021677911, 0.07311038406831877, 0.03136994616527643, 0.014856780380276697, 0.03623095068282314, 0.03161577261718256, 0.03276434241394911, 0.03506191287721906, 0.025128222968695418, 0.04275199790884342, 0.07316425974879946, 0.019086694744016443, 0.048458555447203774, 0.03726706008559891, 0.028993865807673762, 0.02742759494243988, 0.04276547361431377, 0.019190853262054067, 0.05205986988065498, 0.03362176301223891, 0.02759238056439374, 0.031556695965783935, 0.006112259139107274, 0.09487455085452114, 0.046141097122537236, 0.010121171678682523, 0.020668507453852465, 0.027511918185544864, 0.018454284839598194, 0.05108189396560192, 0.038552456468875916, 0.05705319890486343, 0.03020693375063794, 0.09350741135754756, 0.04450572255466666, 0.06377142840730292, 0.10276284614311797, 0.039358060740466626, 0.011516811342776885, 0.028091756893055778, 0.023149935462112938, 0.040577968316418786, 0.0460341328621975, 0.05557019955345562, 0.05007485639570015, 0.049027561343141964, 0.020064962429127524, 0.05311905286673989, 0.032772057357111146, 0.030204450312469686, 0.018095592569027628, 0.027487277186342647, 0.06563023437878915, 0.060180858575872014, 0.04526264872401953, 0.0769107433568154, 0.03951760467940143, 0.05474967768947993, 0.021746182215533087, 0.04297862521239689, 0.0464809888840786, 0.023457043804228306, 0.024968629835971763, 0.020633612094180923, 0.04448297806084156, 0.02329764575032251, 0.05781759574477162, 0.026897743909752796, 0.02678441838361323, 0.036792316274451356, 0.06660908899669137, 0.027508008127499903, 0.05360299761274031, 0.055991203391126225, 0.032113118429801295, 0.0184179357186492, 0.04421385410907013, 0.005228867612978709, 0.012314962755356516, 0.02734479501045176, 0.04561400772737605, 0.045107817210789235, 0.022681841294148138, 0.033603944682649205, 0.08396346348204783, 0.03211058070883155, 0.030002681139324392, 0.09907026535698346, 0.01739418413490057, 0.03919123612078173, 0.011746486964901643, 0.06036869063973427, 0.013941978619966124, 0.07146851252764463, 0.02344840605344091, 0.04931842555691089, 0.06288431172392198, 0.06625652220100164, 0.0575489162334374, 0.03818946398262467, 0.03464538737067154, 0.02649394772015512, 0.08353460899421147, 0.02646868416507329, 0.038110394296901565, 0.009416762423435492, 0.05227816477417946, 0.0358502314692097, 0.026115901934515153, 0.0490005352933492, 0.021738550392910838, 0.032791192044637034, 0.019828002733577575, 0.015273884337927614, 0.015785416621448736, 0.036383068055978844, 0.06919004621782474, 0.08513741727386202, 0.028343722390543138, 0.02899128058925271, 0.028284438785963824, 0.020965300367346833, 0.036696588554020436, 0.035692387260496616, 0.04087738207142268, 0.02731950601030673, 0.07384221122733184, 0.018048402154818177, 0.027472980453499725, 0.04590886172705463, 0.0603668653805341, 0.06652714232248919, 0.018095161699290787, 0.030216884466686418, 0.026454762322828174, 0.017028933823374764, 0.020884827810472677, 0.1023887697873371, 0.0016492119113016607, 0.04325487378186413, 0.02483905339613557, 0.0271091957776142, 0.022692709728809338, 0.04454367980360985, 0.028794861664729457, 0.03525221820122429, 0.020586360611819794, 0.053535066079348326, 0.034706363920122385, 0.03500528234456267, 0.07158566159861428, 0.04812799354216882, 0.10462346380310399, 0.028974503810916628, 0.07640885814492192, 0.027422205678054264, 0.03881977212482265, 0.03886714743982468, 0.06453649699687958, 0.029121650915060724, 0.023624356969126632, 0.03204466103176985, 0.024019534067649926, 0.020805440909628357, 0.06230151799640485, 0.06617304882300751, 0.029874549979077916, 0.01350179429365588, 0.02656818793288299, 0.012247519767177957, 0.023725214414298534, 0.008360097650438547, 0.028554460100297416, 0.006259609803756965, 0.050242695425237925, 0.049559963667499166, 0.01543565047904849, 0.0439432746996837, 0.05371767342356699, 0.09592842430408512, 0.07952267570155007, 0.0036441596790349907, 0.01597639878413507, 0.014511278830468655, 0.07800737808325461, 0.03176569153687783, 0.015722212780799185, 0.027331392247495905, 0.019320519607780234, 0.05064901915778007, 0.01954661595768162, 0.0618085487346564, 0.035649934717054875, 0.04114872144003, 0.040090518937047036, 0.032339793230806074, 0.01626135635056666, 0.02124881774320134, 0.02071173522355301, 0.03241222684404679, 0.060282333487910886, 0.03429588755326612, 0.019443887452195798, 0.05697255501789706, 0.04405700395415936, 0.05901136275913034, 0.03245098815698709, 0.023043335914345722, 0.043202283925243785, 0.07255784621728317, 0.05918369029781648, 0.04364623242456998, 0.020844896024625217, 0.010102920783018427, 0.028802824273173298, 0.07511495971786124, 0.05281807169584291, 0.08999074756034783, 0.026018616976216435, 0.03088232036679983, 0.038788060790726116, 0.03575748251751065, 0.016885211624737297, 0.016356931400618384, 0.026223441253283193, 0.03871327605364578, 0.04111104239044445, 0.03055937501734921, 0.038346205571932454, 0.0229497693279492, 0.020017112139612436, 0.03682152381432908, 0.007435019477270544, 0.01353610017602997, 0.016598461029518927, 0.03214779156925423, 0.040385763094361336, 0.04561137840417879, 0.040596465181027136, 0.04289404921499746, 0.02638019302061626, 0.015514681149008018, 0.01425784600100347, 0.017270928248763084, 0.014846129076821464, 0.036433730873146226, 0.04023811048162835, 0.03993548047063606, 0.02424995947097029, 0.10307675679879529, 0.07375033758580685, 0.058180869823055606, 0.029774025016065155, 0.013473332294129899, 0.013585500069893897, 0.025753272464498878, 0.02601437782868743, 0.01891335958082761, 0.031173852937562124, 0.0339563723786601, 0.07044526136347226, 0.030892912298440933, 0.010553612224092441, 0.08634732663631439, 0.05071109154128602, 0.029760379676840136, 0.008534740689875824, 0.033150137069502046, 0.03270522505044937, 0.06833772481020008, 0.019207299254568558, 0.04834279398034726, 0.0787324606041823, 0.018262856540137103, 0.01244352393717106, 0.03263554968205946, 0.010979593964293599, 0.04126640994633947, 0.05056956949244652, 0.03479596786201, 0.03776418537433658, 0.04042894506294813, 0.13996029192847864, 0.09892795620752232, 0.16630630035485539, 0.11581037566065788, 0.078831418151302, 0.12922999342637403, 0.06945937712277685, 0.1449905162943261, 0.07869153815720763, 0.0924313837396247, 0.13051067399127142, 0.23318322747945786, 0.16885825698929174, 0.10007854125329427, 0.16800551488995552, 0.0943980903497764, 0.10194040063236441, 0.13317384251526423, 0.05739621192749057, 0.14833166343825205, 0.2783450526850564, 0.2100015264004469, 0.11541078638817583, 0.21933911820607527, 0.10417172911443881, 0.18091007029371603, 0.08200517749147755, 0.10538506507873535, 0.09560283606073686, 0.11665640026330948, 0.12387500862990107, 0.15055355349821703, 0.09027342524911676, 0.17716702685824462, 0.0912795230480177, 0.14013373904994555, 0.14127848190920694, 0.13157126493752003, 0.09773195002760206, 0.17001917612339768, 0.09645077413214104, 0.12055813946894237, 0.12532260880938598, 0.11856441359434809, 0.1513056552835873, 0.10807129700801202, 0.17370845244399138, 0.11195417972547667, 0.17347541637718678, 0.2091134869094406, 0.11270989810249635, 0.14283023721405438, 0.2075975989656789, 0.08603022008069924, 0.06559332207377468, 0.1778598382536854, 0.14029941016009875, 0.0864527438368116, 0.164054486900568, 0.11494626131440912, 0.07414447822208915, 0.13438704955790723, 0.0458839730625706, 0.1961073683840888, 0.11843066077147212, 0.11625710954623562, 0.1228641000177179, 0.1060496833441513, 0.08225589618086815, 0.1505269142133849, 0.06229167923863445, 0.2742822564073971, 0.16873093667839253, 0.1604605990328959, 0.1380633930010455, 0.07662252203694411, 0.13285940938762256, 0.22775994134800776, 0.12834498020155088, 0.12067997721689087, 0.1320745072194508, 0.09168439810829503, 0.13513076465044702, 0.10772251643772636, 0.08950001067881073, 0.18086371278124197, 0.23831973757062638, 0.11587333013968808, 0.21894393941121443, 0.1040396997705102, 0.13360601503934177, 0.13694056682288647, 0.09987765417567321, 0.22978482555065835, 0.16585322895220347, 0.0736109936343772, 0.12456064112484455, 0.17360280454158783, 0.1988145195479904, 0.13751824439636298, 0.09353517701051065, 0.15307709308607237, 0.17061159147747926, 0.12602927588990756, 0.2107548631195511, 0.134429647986378, 0.19066246412694454, 0.1324351757232632, 0.18234688176640443, 0.1374618038535118, 0.1402836681476661, 0.18229529953428678, 0.11052340721445424, 0.18371771249387944, 0.20750624101076806, 0.1425259413995913, 0.11805591945137296, 0.17565146461129189, 0.1014753734426839, 0.09589624817350081, 0.10097981217716422, 0.07785090790795428, 0.08595178143254348, 0.12915291184825556, 0.09193939156830311, 0.1685705581413848, 0.1058875270453947, 0.13453083112835884, 0.0767214320866125, 0.07901292626879045, 0.21915803078029836, 0.17236637803060667, 0.15818210558167525, 0.10945576628936188, 0.09149150417319366, 0.0991451959790928, 0.11950152473790304, 0.09963779204658099, 0.06249633897095919, 0.13873724612806523, 0.13514840656093188, 0.09854119803224291, 0.11403048331184046, 0.21488274447619915, 0.1498353106102773, 0.1277418304234743, 0.1427762665386711, 0.12012524769774505, 0.10884513905537979, 0.0691774051104273, 0.11916129370885235, 0.12023183197847434, 0.14688075200787612, 0.17684914677270822, 0.24620675721338817, 0.09644250279026371, 0.08800525910087995, 0.15704899281263351, 0.1306208816490003, 0.2280734788094248, 0.12554382479616574, 0.20360025417591843, 0.089441839871662, 0.2521514839359692, 0.10236609314701386, 0.08920733138386693, 0.1749723189111267, 0.1351883587028299, 0.10460310096719436, 0.09155317622103862, 0.1052514004654118, 0.20512480022651808, 0.15958176047674247, 0.0882913362500923, 0.21522024779447488, 0.07057385053485632], [0.03046491615740316, 0.0687554038262793, 0.032646660692989826, 0.0936832537076303, 0.04654024534725717, 0.03883818417255368, 0.029405444793935333, 0.016840168773861866, 0.062431586374129565, 0.03751161767702017, 0.05703514308801719, 0.01633871273536767, 0.04517432042796697, 0.028122336770008718, 0.014399356175480145, 0.04261626376371298, 0.033610061675842316, 0.03180177263649447, 0.03177641239017248, 0.03183247634608831, 0.08027429572705712, 0.016427029157057405, 0.09530327642070395, 0.03260955161281994, 0.03310789487191609, 0.05722757561930588, 0.030685219514582838, 0.04648687517536538, 0.03661213130024927, 0.031056045687624385, 0.014812673907727003, 0.05352396863911833, 0.047400899164910824, 0.02453742592063333, 0.06843283506376402, 0.06375128270259925, 0.023230777820572257, 0.056947008174444945, 0.03938659653067589, 0.04484435224107333, 0.0419300273726029, 0.07208109394248043, 0.05773758289537259, 0.012402645594972585, 0.05542408042986478, 0.04821168744404401, 0.050289711116680076, 0.05099568609148264, 0.06765735774700131, 0.04540352277191622, 0.02082861457685275, 0.04256817937961646, 0.007621126365847886, 0.025912707837830697, 0.024201797055346624, 0.039673023125422854, 0.019726314083007828, 0.038083215576729605, 0.01575900973486049, 0.02202937050190355, 0.04885160703478115, 0.016758429052840387, 0.047254607014890225, 0.03951663098164967, 0.040772558589066775, 0.012808362886841809, 0.07502459242407765, 0.02179086035383599, 0.030396709817328622, 0.007249620809618915, 0.03691576893574425, 0.05964818823018244, 0.015767114835658243, 0.04686826953132238, 0.013595542388169892, 0.03091059152835182, 0.0331560844289405, 0.012411700644796448, 0.03760445483827165, 0.029572357623172656, 0.06387343936200653, 0.04656309501401015, 0.02489146513731352, 0.049741783911096196, 0.008263326682416456, 0.0376872157544962, 0.023032698181590865, 0.029048304672219923, 0.058587997619594843, 0.02879508218861052, 0.021267623341243182, 0.04694214163880263, 0.023015846764402728, 0.03985310971204724, 0.00925630670306938, 0.042920233881367106, 0.03432765317016414, 0.06072705212448325, 0.03189257758536509, 0.019415071766291345, 0.028587508148380687, 0.041791806396629126, 0.06150328940046685, 0.09711451030203275, 0.028689054306596518, 0.029602589750928537, 0.07029421946832112, 0.028733430496816124, 0.05832165226872478, 0.030441408311682086, 0.026284039519461136, 0.030603109991976192, 0.03299898321607283, 0.0701171150431037, 0.031729668112737794, 0.11926443103168692, 0.030203361263764755, 0.03739042114466429, 0.028783296035336595, 0.032764702037508996, 0.055104799169514856, 0.010987855128145643, 0.015097090342481221, 0.04749994492158294, 0.03454074030742049, 0.038104820131723366, 0.05670186025755746, 0.036105984888438664, 0.01697802503726312, 0.07387014651404959, 0.05095997140077608, 0.030083165570561374, 0.03758366791797536, 0.025456728912623863, 0.022150371955441575, 0.04304939302216683, 0.017653635569981167, 0.03335113949807627, 0.04908781186012285, 0.03148573477353368, 0.028693156050784246, 0.04693600768223405, 0.0032237675830921425, 0.049220119403409104, 0.03307432435186846, 0.022580680204555392, 0.041177521858896525, 0.023902495258620808, 0.07611442144427981, 0.016082139985103692, 0.014545488869771361, 0.009288896740015064, 0.006502783183740186, 0.027928645556260432, 0.04117832931556872, 0.012449148992475654, 0.03896421526691743, 0.04063665481018169, 0.010112751059101095, 0.019638861097129326, 0.05357331849102463, 0.032291529034929614, 0.07337129435368947, 0.035442567630005736, 0.03486010977732284, 0.06571553980133363, 0.023241306987724135, 0.021292634142030562, 0.025732010569689528, 0.02769694450710501, 0.044550614431500435, 0.05721623729914427, 0.05668420138369713, 0.039052862474428754, 0.06759371116225209, 0.027047856211928383, 0.013879246361154531, 0.044141026945518594, 0.025594385008194616, 0.049151899492634196, 0.02575739795741226, 0.054513625534517426, 0.012757767923176289, 0.032325164015804014, 0.03515384419422064, 0.0428654116445354, 0.04760882604335036, 0.030193861773503677, 0.03176305203565529, 0.08156071669821228, 0.054190541085387976, 0.01960333639622799, 0.0462058293633163, 0.022881886988346065, 0.011556833034514316, 0.058118797439549646, 0.030142574704119136, 0.018022419352616583, 0.045251700561493635, 0.04703057510778308, 0.030563324091157744, 0.04302233304562313, 0.01346911774349532, 0.03507433346073542, 0.04158991847985557, 0.03272586269304156, 0.03151473196755562, 0.044958142563700676, 0.06380514481237956, 0.07801282671945435, 0.05178037112844842, 0.036236663947680166, 0.02130573834957821, 0.06790405272373132, 0.021186933653163056, 0.0015900390987683619, 0.01770317541169269, 0.06999130786529609, 0.048840658872255256, 0.03345640742086938, 0.015363269452271717, 0.02266262687875756, 0.018579462676176002, 0.012729411944746971, 0.024503003839137297, 0.06487031587000404, 0.026035370005826865, 0.022657067980617285, 0.014368411585954683, 0.04434748479564275, 0.019787645167005912, 0.0684614624562008, 0.08248845048780952, 0.0456925515484597, 0.05946393883121865, 0.0448585268376129, 0.043721047695726156, 0.0442655279434153, 0.016307350846805742, 0.03647535899654031, 0.054416232010615725, 0.017473598177145635, 0.01780617024217333, 0.0987356390271868, 0.04925251605787447, 0.028526589274406433, 0.013852802155140256, 0.017624132867370332, 0.016174927952566316, 0.06708964106759854, 0.019297564768099358, 0.014735644916072488, 0.0564274301619402, 0.04100703315011092, 0.05343881927962814, 0.0317931722051331, 0.06702998426875897, 0.0629311374255589, 0.039832896153841696, 0.05178782822830336, 0.06878007535955735, 0.03356064736310925, 0.004912005754054657, 0.057811821411762915, 0.04652440155457173, 0.029013472077037607, 0.010649501944759061, 0.03556455126298325, 0.018784917990810106, 0.02538434279683445, 0.012616435015973235, 0.03900928695553115, 0.05317596159875393, 0.038344879035970995, 0.01343771259832595, 0.03543439806838121, 0.03517539785908801, 0.04066816258377262, 0.03855284662651164, 0.01771337040034788, 0.02791763123657022, 0.05647050017224891, 0.03716225017394338, 0.05842738838068076, 0.019201014323958328, 0.035394317004829645, 0.036331265299980126, 0.05310603517240711, 0.04503516985901764, 0.041506794547396045, 0.02283867957469608, 0.07573385829372065, 0.02644195158167609, 0.07687258254736662, 0.05279999891562121, 0.05619255865791014, 0.05946068186312914, 0.014493172123496021, 0.03627172385209373, 0.04798009665682912, 0.008496259272630726, 0.0288365101441741, 0.035046635661274195, 0.02414060676736491, 0.03927495716405766, 0.045011326138462336, 0.007876945942241167, 0.052402299363166094, 0.10202257800847292, 0.02231747647082167, 0.028382263179602366, 0.033457557537725995, 0.01573612614135657, 0.027758231486326883, 0.00349964719914299, 0.06693671963044576, 0.01716294788223292, 0.03664595627092889, 0.05776711952473436, 0.017462215752207806, 0.03321204999727862, 0.036901472202901325, 0.02517956940989409, 0.0329965913801321, 0.0359494875717376, 0.028562097011932304, 0.07478702374334846, 0.003402298628186275, 0.04640209901013544, 0.021848632521661263, 0.023153660619365315, 0.0074311170527445415, 0.02512788539752364, 0.08647285561476435, 0.03351562995729702, 0.004059594440540033, 0.0727377597774778, 0.05480799438165767, 0.04147103235923818, 0.013887412530103964, 0.024022305883201103, 0.07487745210528374, 0.034136062022298574, 0.041692675823079686, 0.028214295228411044, 0.01871451658995024, 0.03697899143610682, 0.04492393422073551, 0.08060854207724333, 0.10381785274616309, 0.07540001227919545, 0.002732068029997338, 0.08149577411157743, 0.19144989044538566, 0.1656425166875124, 0.1695868814630168, 0.15590213292411395, 0.1473591870495251, 0.10813442790614707, 0.08490387909114361, 0.1229505996618952, 0.10908644646406174, 0.09794214660567896, 0.10170638068978276, 0.10385372010724885, 0.1623034051486424, 0.069485507506345, 0.1548427226287978, 0.15214674015130314, 0.06618794266666685, 0.11152652624462332, 0.1175888159445354, 0.14583753155810492, 0.08797672670334578, 0.2411021382680961, 0.2034732052790267, 0.09725478384643793, 0.12151583736496312, 0.12789432438356535, 0.15172128512391023, 0.09724895523062774, 0.1282682514616421, 0.20663517846592835, 0.09362354262598924, 0.07651853654533625, 0.14589850471488067, 0.18379501120320388, 0.21874459939343588, 0.08371400008244173, 0.15663769202572958, 0.11004845305745091, 0.10432305599429778, 0.1785215048917702, 0.2154884184045451, 0.12163905932434968, 0.15505705827048846, 0.14038098364004067, 0.09993159092430558, 0.12131131333964211, 0.20095950444894178, 0.10042937778468643, 0.2200757765344211, 0.08315126385007586, 0.12221964102770601, 0.050986454622553926, 0.07176705436514956, 0.14227686476494583, 0.1172842758574656, 0.18340394433055604, 0.12177563485290323, 0.09795013974819865, 0.13372334731476648, 0.2101821524224111, 0.10663466873977866, 0.14026912035686628, 0.09194469092679874, 0.19872227949755533, 0.07217017201972858, 0.07282779458910227, 0.17262091008680208, 0.09489195527774946, 0.2186578419059515, 0.062358949200383255, 0.13689173944294453, 0.09435192282710757, 0.11086864583194256, 0.1580085770360061, 0.07112354532416378, 0.11903758320425238, 0.09694419801235199, 0.2271221320011786, 0.1125500216814024, 0.1791330413626773, 0.1151369432253497, 0.1391391017075096, 0.12136942307863917, 0.08142310301108019, 0.15207809954881668, 0.10734239433492933, 0.15258720437330858, 0.1538364959082433, 0.23834022932818957, 0.07518292178532907, 0.163796548598579, 0.14480794966220856, 0.10593495664319821, 0.11836549426828112, 0.15126180835068226, 0.13996570663792746, 0.1437689225588526, 0.16397538328809397, 0.08829888155949966, 0.07116318533995322, 0.1878630593419075, 0.1348894097443138, 0.22645690983959607, 0.08878845814615488, 0.12725815709148133, 0.17992728017270565, 0.14828090901885713, 0.08900205418467522, 0.14104662649333477, 0.11473196638481957, 0.09877850886966501, 0.09347527593906436, 0.2711351295667035, 0.10254167765378952, 0.2824671800647463, 0.11850991366165024, 0.17103691079786845, 0.14829331263899803, 0.11307101443942104, 0.17645476864916937, 0.1489373780786991, 0.13460025883146695, 0.12503554778439657, 0.06845752695309264, 0.1154505078281675, 0.10833650920540094, 0.06752126397831099, 0.11777644444789205, 0.1307164600917271, 0.14541316218674183, 0.20581811373787268, 0.11940635341618742, 0.17456750491900103, 0.08460541867784091, 0.17025707050093583, 0.08701074389474732, 0.06265712462897811, 0.20115823378520353, 0.1858712062239647, 0.19852839490132673, 0.10520165706319468, 0.10720929969102144, 0.1381141881325415, 0.13728879099445684, 0.1988007588578122, 0.15926880655544146, 0.12859569889094147, 0.16910064326865332, 0.16983202259455407, 0.13953897596469947, 0.15701260976493359, 0.17420471938593046, 0.17727211836193288, 0.19060112456125872, 0.052094899250992706, 0.12364094118986811, 0.1306265949138573, 0.16296469180711678, 0.09082717767783574, 0.16930246672460011, 0.10605141360844884, 0.1010741014033556, 0.08979457630110638, 0.16044888751847403, 0.2185021588312728, 0.09095249631042991, 0.09165347048214503, 0.1565657944551536, 0.12196639818804604, 0.09018934797495604, 0.14525499567389488, 0.1633643489331007, 0.1677585281431675, 0.18963350648326532, 0.11546954752079078], [0.07690795457788877, 0.04382280759247286, 0.02211279298977128, 0.016965041269681284, 0.039177648457033296, 0.056857923311846595, 0.05161623011476227, 0.03971930599904486, 0.021039981627836823, 0.034415838973862786, 0.04770796000957489, 0.011697536600487573, 0.03710508359862225, 0.04409324111683028, 0.023968643941251293, 0.050193026661872864, 0.04249329286228333, 0.04995826372344579, 0.09424469393811055, 0.024479697857584273, 0.0024243354356648134, 0.02824292262084782, 0.02581009129062295, 0.049275833913790326, 0.015851695922070315, 0.06764428237719194, 0.02574601044346179, 0.05306344013661146, 0.05067820634160723, 0.08303011142249618, 0.03407646629161068, 0.010227576995800649, 0.01444417002078678, 0.06817290865417037, 0.09599637280085258, 0.027152810312275375, 0.03401116068874087, 0.07206142999764, 0.01158399394314204, 0.03383624453895858, 0.031216288517628397, 0.02351448348989444, 0.01189210482074746, 0.06440539046057633, 0.037348457146435976, 0.030050341439034258, 0.074374684797866, 0.004480915917416236, 0.02476092517775084, 0.04121785058772989, 0.013279276367809092, 0.02341761752696974, 0.021985939171697413, 0.005830980080645531, 0.06052823457866907, 0.012409649772702583, 0.04980623795251761, 0.030108061020395586, 0.056341144256293774, 0.0407748554301049, 0.036496006817157776, 0.041398015205881426, 0.021979216586000154, 0.03499273962474295, 0.05923835986426898, 0.02155111527203449, 0.023591207140790563, 0.037875970625983815, 0.06946433042841298, 0.06214840656944683, 0.019366705790162086, 0.05721182003617287, 0.017164783319458365, 0.04248091299086809, 0.06172023740197931, 0.04901971747832639, 0.040930904913693666, 0.008583233043152307, 0.07010746627513852, 0.0279155345633626, 0.06149572373500892, 0.035303885250219276, 0.006947698171383568, 0.00222824072365516, 0.025698857348678366, 0.00579025737741696, 0.04723319584237678, 0.03120418345289571, 0.043396450113505125, 0.05656151546697531, 0.054400517139583826, 0.03290607820131949, 0.05110630765557289, 0.05383574190948691, 0.013340748247823544, 0.021027169190347195, 0.038165362418762276, 0.030444071561630284, 0.047759772943598885, 0.044991438277065754, 0.032451836325760396, 0.03825140744447708, 0.04501893251602139, 0.06878065889967339, 0.0426826753786632, 0.045147182419896126, 0.013879523712343403, 0.05726199091545173, 0.012193832380164946, 0.024425221673612083, 0.01582173351198435, 0.0324674494165395, 0.009252669755369425, 0.03708536537098033, 0.02722508616612426, 0.04105513449758291, 0.025174651727346436, 0.0514199706459684, 0.095086674472051, 0.05909345871103661, 0.02703029233297067, 0.024765473058713332, 0.02236422074825636, 0.04782499372959137, 0.020282505845118846, 0.03697536127375705, 0.0205792292087738, 0.0399026291977082, 0.039403502230665514, 0.06345776202423231, 0.05179815553128719, 0.04230085354564445, 0.002884732896096206, 0.015357137192040682, 0.04070352782894458, 0.026316907755764465, 0.05444105960694807, 0.013475913271707083, 0.02680963953025639, 0.019599687574165206, 0.07033259062362568, 0.033746945937829356, 0.05787003971636295, 0.03145922441035509, 0.023170735953109603, 0.032233670353889465, 0.042597899213433266, 0.05086909520572849, 0.06566640029528312, 0.045233234230961115, 0.07239689092550959, 0.07394065308783736, 0.04542237586740937, 0.011096449568867683, 0.0389956076895552, 0.032513647473284175, 0.02473913741830204, 0.012277341381247555, 0.01972770338345851, 0.060853904246219566, 0.01648495908427451, 0.01002193593220519, 0.057137398315327506, 0.1213581593973296, 0.03914507877613817, 0.0309255600108632, 0.03929166608889188, 0.03657217237300106, 0.01661108517354088, 0.05077500954004271, 0.038363040025745115, 0.04648341125409518, 0.020204416642497693, 0.03379835853619235, 0.00603405076877347, 0.06947055937988417, 0.028746112316314663, 0.09874885010399989, 0.01643133955076337, 0.030357358178922107, 0.026549624911110316, 0.02278232724139733, 0.0460849415643939, 0.049146766375218115, 0.0413604243658483, 0.05177558745656695, 0.029777448225234236, 0.051849045657685826, 0.047791742121002505, 0.025947419993047203, 0.030957848099725585, 0.00903082188285355, 0.02934671758807131, 0.04715407865920237, 0.02909077417903713, 0.021028991056872264, 0.04241013839574797, 0.07437791462455477, 0.046091669239103794, 0.015290676383301616, 0.014174728853894132, 0.004113031617764915, 0.05603031075692602, 0.04102468863129616, 0.00798876172796424, 0.03437962555991752, 0.007405589717174215, 0.040440032325152836, 0.04793714539014867, 0.04176776250824332, 0.04431925095351679, 0.05276589235290885, 0.026481296434732418, 0.0433154330322785, 0.01854165131226182, 0.06820276419499091, 0.009439636687082904, 0.015295858694506543, 0.03374103589781693, 0.00848726783546486, 0.026253542763047984, 0.05268974376044103, 0.052329363634011576, 0.012133959298288184, 0.012329640315978654, 0.059469224619013925, 0.025406882033816407, 0.03594223403238824, 0.05276447421471987, 0.004100778123496899, 0.08962248624967677, 0.027157911199278066, 0.05324754025787115, 0.09388505002217633, 0.045440251872475655, 0.03530774950715048, 0.04781728217910443, 0.01289368442459298, 0.027842074665906172, 0.01609749353623816, 0.03343394112640193, 0.013381680872823511, 0.04601991755355682, 0.03182801837101579, 0.10036197890128408, 0.06510455972914185, 0.017379130835511854, 0.03414840118161269, 0.09257540958268301, 0.0853090255654284, 0.006601551589223423, 0.011335654367160584, 0.03219365714383977, 0.040561761507498365, 0.013579472982590752, 0.056143069706325016, 0.023572577961853573, 0.04809558331700308, 0.010212132690607436, 0.03792967328003474, 0.023043084856388823, 0.02196373580954969, 0.021287841988461356, 0.04321976298732417, 0.07657916364925248, 0.030765079693602662, 0.051132692489773035, 0.02062683692201972, 0.028063524747267365, 0.018686184360246574, 0.021044670304815685, 0.010989779623092284, 0.01860282463686807, 0.04664278216660023, 0.033608283914093456, 0.025220824339027916, 0.00792689884214529, 0.03944681312090584, 0.024381792039743493, 0.04127876267635396, 0.02132108511536249, 0.011034302546509674, 0.0654256764267172, 0.004060748374156121, 0.024925870255434086, 0.0615188278523939, 0.061140897417707105, 0.04912143666297197, 0.021413235259907584, 0.06337360332586936, 0.0486436903343669, 0.08261874956744057, 0.03761295348938022, 0.056756584106811454, 0.05642212741076946, 0.04000638738008482, 0.027382066939026117, 0.03181732465912189, 0.012331448611803353, 0.02607603630583201, 0.02176502513300095, 0.04137989832088351, 0.016834837184952836, 0.05163838428312114, 0.030856519072715725, 0.07958367599972657, 0.012273103930056095, 0.018975579545700123, 0.023641305077554922, 0.048593824795846424, 0.015999172115698457, 0.040875231115413566, 0.04427211991112147, 0.00614340856139149, 0.04770458769053221, 0.03748668830043503, 0.08615474482732159, 0.04877902753651142, 0.07459905597248248, 0.014298352845279234, 0.04782549923818026, 0.04753680294379592, 0.08186163340828248, 0.05096619017422199, 0.07709024301064865, 0.04530714705054249, 0.02469498005562595, 0.022331532323732972, 0.05837584686066423, 0.07229895796626806, 0.07246637969676938, 0.052263711978282244, 0.034447319606052976, 0.028113266453146935, 0.026340167936203734, 0.03412757694189038, 0.06796489695885352, 0.018097025974254524, 0.04492510808631778, 0.06148736418357917, 0.011569633597641118, 0.029794448920126473, 0.09491406873400722, 0.00692455715865695, 0.05412125926730888, 0.06480136314140898, 0.03461060566561563, 0.03080658907336848, 0.01874081660727305, 0.02686696047229426, 0.03754291510475533, 0.06403824873268604, 0.17406479189438478, 0.18536721755351337, 0.10765802168420383, 0.13701175871704305, 0.11255251190492085, 0.09327541344932147, 0.09975152130105666, 0.18381198814937047, 0.15920430501656874, 0.1356410908379725, 0.19175223207899503, 0.1406154039182833, 0.1503057117973055, 0.1250580344349146, 0.13505820211555275, 0.13843565088297638, 0.2412293500133923, 0.11124397747750793, 0.20749476019825253, 0.13054134377411433, 0.15061599229063305, 0.12758698873221874, 0.10423396434634924, 0.07835786856178727, 0.10425332973578147, 0.13669318652578763, 0.10783237125724554, 0.12986666283437184, 0.14691245316394738, 0.17170661129057407, 0.0875107767060399, 0.10812348313629627, 0.09531428225870643, 0.19221309306366102, 0.18119311439139502, 0.08460653826062169, 0.13525120461625711, 0.13687127482678207, 0.09601267799735069, 0.12069037237337657, 0.12100830674171448, 0.13856724596449307, 0.16322044522634574, 0.11487145961395331, 0.1091788357922009, 0.08610738308301993, 0.138179408918534, 0.059791888376431804, 0.05958843643644026, 0.15997028962842055, 0.14400855398603848, 0.13188550807535648, 0.09401424987507717, 0.08174010778644256, 0.1371150996003832, 0.08187961458627667, 0.23212957116109983, 0.18562753072806767, 0.10702714696526527, 0.12067506462335587, 0.12508225813508034, 0.13565242237278394, 0.09287405320044075, 0.08504684641957283, 0.2012637731220041, 0.14022531413606235, 0.19695867198918546, 0.12327801994979382, 0.20168569976730005, 0.150598852496062, 0.1368482724896499, 0.12606844093118394, 0.11770321694867951, 0.14479880301015718, 0.0925485056691936, 0.18238124277974876, 0.10300618237150566, 0.14787381514906883, 0.1504589385752167, 0.14194913235093864, 0.14195902539151056, 0.11544921861163207, 0.09461914348815169, 0.06559194464768682, 0.10098169171916586, 0.11941669428987162, 0.10894259704010827, 0.06964487502617495, 0.11804085597395897, 0.14286660669105394, 0.15682164286928518, 0.09252156104360308, 0.14789805241993495, 0.10630953511489288, 0.0681433245273573, 0.1872840111276933, 0.16284250122095856, 0.23028520441481046, 0.09179961335446153, 0.0849602110683918, 0.07407038219805274, 0.09102960502994911, 0.1295655154223953, 0.2775539351361138, 0.1115691043170435, 0.08277016465685197, 0.08273583757025854, 0.22354072917784962, 0.12369263198758874, 0.10747939734054462, 0.1125482167782528, 0.14588179918272154, 0.13943912275135517, 0.1755555604717561, 0.20559901478035109, 0.1330343899982316, 0.11238891711192471, 0.11469524406961032, 0.2285289115139416, 0.14699807071260043, 0.17482518537768296, 0.05189707236630576, 0.06837719519223485, 0.1167743703616517, 0.12082663577582155, 0.1487727112003735, 0.1269785870930978, 0.1736903762710946, 0.09796583426317998, 0.28302767713155064, 0.08527879004499742, 0.21235019394329616, 0.05124575677993042, 0.1267851639006819, 0.10559547200266804, 0.08416939886020762, 0.16295973850148066, 0.1479161421635321, 0.16955161121274742, 0.09360581250595194, 0.15047204787177698, 0.11707810977739946, 0.16233894681291922, 0.07116941429142441, 0.21168897513832363, 0.11720743855195385, 0.32299319974013735, 0.11374456901103258, 0.15792974483753952, 0.10479360645903008, 0.09941345479871545, 0.19938976796610014, 0.13034961691924504, 0.11462819123906748, 0.08088750139411006, 0.11663114518991538, 0.1256934960505792, 0.08549982282732214, 0.25977544912270134, 0.15146325182701859, 0.19717657672507422, 0.15247869305312634, 0.15037241178963864, 0.21381726807781629, 0.11044789305222885, 0.23938009781496866, 0.14884986063199385, 0.12320795442376818, 0.1115459119901061, 0.20905944838055543, 0.17936120554804802, 0.12949159581746372, 0.11087946168013982, 0.16267015332622187, 0.08191821644348757, 0.12316313040043626], [0.05647297003971679, 0.02248663185829563, 0.04167424002662301, 0.03090639818193657, 0.01308195838438613, 0.04052829276770353, 0.024939956642421227, 0.05218896795330303, 0.042922866597239456, 0.035637269860931804, 0.02754577199396278, 0.0286769153151129, 0.02604006546815591, 0.06079069870923247, 0.038040488226605315, 0.06353856875960316, 0.011497261052552079, 0.0213534868588405, 0.05308195057192019, 0.054519142024219036, 0.049306680115738084, 0.03673286642879248, 0.040894080818231614, 0.06373235836092915, 0.03016078658401966, 0.0521880790724286, 0.021589662846443907, 0.04506373279062765, 0.03651347230853779, 0.02287237223104707, 0.06156889695141997, 0.04722695332020521, 0.033951001773987494, 0.010796016314998269, 0.04443386569619179, 0.025240956473031213, 0.027556162061435834, 0.03295841360730784, 0.020391049395714487, 0.01895019385431494, 0.04151179535048349, 0.045718040716435225, 0.05636698965515409, 0.06611217744648457, 0.011324361848112727, 0.061207665263542106, 0.0029952348683894214, 0.05242380213790706, 0.010858321096748114, 0.013617744902148843, 0.014881803055426903, 0.054397609617028914, 0.05845561543745654, 0.016569809888356497, 0.013955262639293713, 0.011681323854385741, 0.07959122809448413, 0.021097643533721566, 0.11955915950238705, 0.06006299704313278, 0.05622127765257444, 0.018923188160572733, 0.026491459192974225, 0.024615523604942218, 0.025960583572408984, 0.058090081837560446, 0.03674605375687991, 0.03689542645588517, 0.06161246568496738, 0.029701068930860077, 0.0214402884511011, 0.03872107581368514, 0.02783980835894389, 0.01606891194491514, 0.02171430633669453, 0.025200398738629053, 0.05606750126129814, 0.05593335488811135, 0.0286224934139422, 0.07126932857292038, 0.014675587781571915, 0.06454839850110666, 0.04935805878735014, 0.020649710337498357, 0.054994275993002315, 0.01008247652290655, 0.019051587342151573, 0.020968657419351593, 0.023947051260620356, 0.06005250010639429, 0.03355979240898575, 0.010310873954689928, 0.07185496536216565, 0.06305952982178756, 0.03810964112303086, 0.017378762730264237, 0.0272765734033393, 0.02461336586358292, 0.06816484765814883, 0.03647464653477073, 0.06365775343562875, 0.02462901797012559, 0.02450568405246096, 0.03474279446527362, 0.03785994362884334, 0.03888990550435015, 0.0175817278213799, 0.01126778983910169, 0.03589952025296433, 0.027047199729297842, 0.034780595651162524, 0.010957853702296103, 0.05210560653358698, 0.03844908165878483, 0.03469894413969346, 0.05075961358046957, 0.02985961881599256, 0.03902350904952202, 0.012219288469558316, 0.022718565305694938, 0.015685522696003318, 0.02367466694808432, 0.02928706757458193, 0.015137627720832825, 0.01965464891067573, 0.01825756057431655, 0.04494619695469737, 0.03621710856844272, 0.04688208789697715, 0.047031871109668694, 0.024238439642691186, 0.035993782337754965, 0.029420063830912113, 0.03937898336776665, 0.051491260927702696, 0.05965496679501874, 0.016690217623753206, 0.02308167314289936, 0.0799089724730168, 0.049035517166235616, 0.007658539938607386, 0.01885317182833595, 0.019812920596450567, 0.025337111670523882, 0.02779981550494475, 0.06286088190972805, 0.04766159910442574, 0.03291866841859051, 0.021823967773733393, 0.042970347085169384, 0.03158168980319585, 0.08879360144159623, 0.010594178440182336, 0.06799565495124885, 0.05575689846383674, 0.039579632958131175, 0.019213226257956455, 0.051616297968264134, 0.037192434804247956, 0.03432019607030919, 0.016579538384186368, 0.03320724596934659, 0.020499112882784436, 0.025143686781770418, 0.0633802597544023, 0.023401719451482807, 0.025559981586411595, 0.031148255203983614, 0.03584731037595442, 0.06539640442601272, 0.0566053997193064, 0.05485159704195602, 0.06878986661987645, 0.05240432818287185, 0.059343715996614525, 0.05859242845326662, 0.04548493340345366, 0.030318922562790767, 0.040607711898961237, 0.04524948175198265, 0.03146206747208323, 0.013199241466021963, 0.05533951461049063, 0.031174646823533943, 0.011409548527028943, 0.030505126142608266, 0.015737679986549274, 0.02932907228491136, 0.011092476746333497, 0.06421084768537964, 0.038709784990974834, 0.06019596955073731, 0.049729845087443075, 0.09565162951392786, 0.07627941401941435, 0.07391659223607608, 0.04112006012084229, 0.05507494362869433, 0.020944705133193305, 0.013992564253775137, 0.02113104272367699, 0.05079836132270949, 0.002615150297060609, 0.02434704256510096, 0.07182900461235217, 0.026840864015477042, 0.052074526237057786, 0.02881878341681191, 0.019638411567679474, 0.042078908133719645, 0.032610494776495864, 0.06675883488995688, 0.03162418305873871, 0.030468369900648083, 0.02202799986116588, 0.020343200802536945, 0.0421142258814403, 0.030549176636018922, 0.02502155556742634, 0.07345799077302217, 0.01274883670599333, 0.01801400212571025, 0.040535441134124994, 0.04838148404711059, 0.052252451689647775, 0.03743330116516777, 0.03349625438983951, 0.04253639340666788, 0.040669553580560854, 0.01361794676631689, 0.024976572088365043, 0.041850475927016566, 0.02508143797915961, 0.030274312277989726, 0.014370903505810668, 0.049138332184936316, 0.02986499620601535, 0.0029667141331758884, 0.03595880725021873, 0.022612788481637836, 0.012703619980519372, 0.05689735637445535, 0.06880691820489508, 0.02779189869761467, 0.03792110677542431, 0.07076190651527473, 0.014228395884856582, 0.031169218543384756, 0.03852676374039479, 0.043995433686567206, 0.0261944203105356, 0.0669265483905162, 0.05039946076327136, 0.06328470845307622, 0.020970265547345792, 0.06758823538465158, 0.06486359158796923, 0.046540038394076486, 0.023835856334439347, 0.02492786684472646, 0.0140538927932669, 0.023107209808326194, 0.04570244798170669, 0.010634123796730168, 0.012009554991631635, 0.06745330869619336, 0.0384267069665449, 0.016786386391946247, 0.03702169503750546, 0.021969248906576207, 0.016699927459870065, 0.023349796255518283, 0.019485888769850135, 0.022900092082896402, 0.03330126717420561, 0.045141173992305994, 0.016916934833196656, 0.02089923480525613, 0.0019281745148223958, 0.031899664883634875, 0.025846260599792004, 0.07971466039972645, 0.034927227068692446, 0.016967019199260643, 0.04794213262253574, 0.019487237358199697, 0.022510930197313428, 0.023675136833584735, 0.024846430768125823, 0.046391608858747144, 0.058915051498583386, 0.05163676258442657, 0.013548866812405842, 0.046432802719729285, 0.03891506219016654, 0.024871221045032144, 0.030782470546130623, 0.03685787972062826, 0.01148906265318926, 0.03708182002550789, 0.06637665682605334, 0.041192229105425734, 0.0045276436555598465, 0.04655980411916971, 0.02012079398679946, 0.015431455436295696, 0.025335072672792842, 0.02149529049971274, 0.039084611127951314, 0.03529818555606263, 0.04544938834650176, 0.02366090625790613, 0.05116718921012112, 0.04019153583794832, 0.06065723765641451, 0.02915332492973123, 0.0284021018472101, 0.02943323758829917, 0.01674511280309941, 0.02419835518646453, 0.10893012556646552, 0.01859249733388424, 0.019464385995109166, 0.028524031197386127, 0.016390926005052667, 0.003312664576307205, 0.06373699275510651, 0.07836245545851332, 0.034483400705669603, 0.05960014795086213, 0.06939886536981378, 0.03935531945899129, 0.035430479528648515, 0.02803001020635877, 0.005887721299326846, 0.021085192416129366, 0.036035088157015185, 0.0062485903950541145, 0.029047626137201275, 0.033172284452510734, 0.021171909191512635, 0.015941018271925192, 0.022915111455534185, 0.015264364491615976, 0.030656544624694755, 0.033923225942999125, 0.029702208869691406, 0.047313520817884376, 0.0448970336999212, 0.05269445279347045, 0.05748182947614363, 0.063897398433515, 0.08137753259922777, 0.14449871411280973, 0.21699719530131134, 0.12850044614502362, 0.11138450886522021, 0.15956691413053445, 0.1302404406347445, 0.09943689818360976, 0.16068157074706896, 0.14816790579685143, 0.12050950207880565, 0.11105716321617365, 0.05896094760724476, 0.16754518316260406, 0.11332642859114067, 0.10083617988441672, 0.11849767288991384, 0.15214995640729154, 0.20516051830989973, 0.21451025589236192, 0.12352755798825196, 0.15153597721031734, 0.09044121338852815, 0.07919089243348156, 0.14561129441218718, 0.20113361653472694, 0.0978741573968104, 0.07018903296973024, 0.10774271642523152, 0.09269618881600243, 0.27397243731788223, 0.11179718707821198, 0.1374299805611372, 0.12225723186773912, 0.16895688883960247, 0.13676999668989862, 0.2203960179218224, 0.08926724602601357, 0.1248979273119143, 0.15762991378349916, 0.15260456129908562, 0.1708899401128292, 0.11335629770266158, 0.212893863341638, 0.08195079969508307, 0.20588831497090204, 0.10770257429352828, 0.16848910679774626, 0.13013332709670067, 0.1305591892451048, 0.1396226529031992, 0.12823006351079258, 0.12073762555207525, 0.1221998685172626, 0.13806975765952043, 0.10342272823410374, 0.17214377783238888, 0.17473286390304565, 0.13443914747663907, 0.11307677520172936, 0.12640333867498807, 0.08300305144595248, 0.14983307144471578, 0.16177748622638838, 0.0854581268504262, 0.11702656825738293, 0.12429165627275195, 0.10296232186790023, 0.1409142171697957, 0.18027798778244428, 0.18838308858019964, 0.12439849839678832, 0.08688378320740801, 0.124277868441173, 0.08493484064404454, 0.16352242045104504, 0.16965791050876888, 0.2712720036506653, 0.10448788572102785, 0.18978705895798548, 0.18230526042836054, 0.16530954598316125, 0.18577864047672066, 0.18100492948932306, 0.20118297317198344, 0.11613823021096842, 0.11163126491010189, 0.09192101005464792, 0.11372966838202306, 0.16257814397769316, 0.13081369415989944, 0.11340510472655296, 0.1453008782118559, 0.10423625100936208, 0.10369784025741474, 0.15233335085213184, 0.1339446311550481, 0.0987861423886248, 0.13872856087982655, 0.10095279969807182, 0.10831508106951203, 0.13524178655019828, 0.0647704830127103, 0.08197156286665372, 0.07937390011336122, 0.19575929349022253, 0.1451183251504387, 0.04514912303004946, 0.1391657002802406, 0.127225288855178, 0.10155512844877583, 0.06329207055802856, 0.12918872492653982, 0.10507494743381228, 0.14271012294505322, 0.13128976789968355, 0.14095164516142436, 0.1301224705364023, 0.1280615832656622, 0.1360810258026634, 0.11590315853910786, 0.08612536426101412, 0.12179916644734995, 0.10469783802649804, 0.0853580700765763, 0.13585257663258485, 0.12682084127196244, 0.14030900464526244, 0.09770633533064808, 0.11794910446873733, 0.17794717928128584, 0.09947208700967686, 0.10482380126735993, 0.13724195850746973, 0.12399851557399545, 0.0809245833328792, 0.057409328009401045, 0.1411225138498204, 0.12857979403010436, 0.11370917662445988, 0.0740580532167639, 0.08937050548515149, 0.0782399188194956, 0.10766604875347444, 0.22975868838174002, 0.12357690105480806, 0.16890454664826393, 0.14388884683804853, 0.13124632808778966, 0.1668467399265085, 0.15574739979846136, 0.19594836048781872, 0.11442722273724419, 0.11274344487381832, 0.22537102310785226, 0.12205095722207002, 0.09311413924608912, 0.13612811613295758, 0.12580302517328942, 0.23464229490075791, 0.0747633089444467, 0.1273067266281162, 0.18981850227074964, 0.08097751584968396, 0.1824016531131097, 0.08632967794047934, 0.09398146984832627, 0.10147658802036728, 0.10988324335111038, 0.18358865513333253, 0.07971156628004142, 0.19061417957501753, 0.1610995890306575, 0.15340348200074264, 0.17295005385364803, 0.14908852853945323], [0.04725624228428517, 0.009235818338181292, 0.02077570920144873, 0.02763549467947866, 0.03526573122612067, 0.05500317158709679, 0.05135155735271318, 0.030676680151373148, 0.19840647572917597, 0.04369819802897317, 0.011418904676767332, 0.03895481416423406, 0.014399507149521793, 0.09753594840211527, 0.018673246393778493, 0.02498254828554179, 0.018490847699078064, 0.03829504403152636, 0.07923606250967298, 0.0468033947981894, 0.040922070387750864, 0.04903309140354395, 0.03655947698280215, 0.023092151419924836, 0.019154337900025502, 0.0042465567073252585, 0.033941410681498904, 0.03422665323263832, 0.04127493913152388, 0.07502466027757951, 0.06461880329464163, 0.03323302351470504, 0.01925865757013006, 0.0029212631010783036, 0.05085835399638329, 0.04118891106918454, 0.04376963419573648, 0.0552491608874074, 0.030301643668540885, 0.04987029844362821, 0.06454164707767111, 0.004352718600005443, 0.030432970728725195, 0.023097669605963995, 0.06452480583850827, 0.02271891475122954, 0.04666518060756581, 0.03703481111941593, 0.010691225063055754, 0.014522344040285264, 0.014906206567372595, 0.026970667764544487, 0.046705631472702534, 0.043558453741882525, 0.019151063968560526, 0.025872465622212206, 0.017677667584004145, 0.033318186444895606, 0.028595582715102603, 0.01675673950064395, 0.030004818524633135, 0.0713864437171391, 0.027407369509871517, 0.07014690273042236, 0.03571959651474442, 0.011803081026300788, 0.06566629851503031, 0.05465977179950901, 0.047836732385413985, 0.033379247811223776, 0.03176128105925662, 0.017390782978119593, 0.047149939595588615, 0.0353426770972354, 0.06403233869267361, 0.027869355166330934, 0.028016500574137484, 0.04071028603773032, 0.06441526993044785, 0.07135971622275454, 0.05224771212254252, 0.05098223413473793, 0.02074369422293135, 0.06552012171596289, 0.03451145812869072, 0.008536295383237302, 0.04374183461602245, 0.03935226944408246, 0.03139533355299916, 0.06807181372174195, 0.06257776995854718, 0.0460252474461283, 0.01521262789278158, 0.05581887245976499, 0.019623163189472895, 0.007705646384108279, 0.026897114568523, 0.03447299197848354, 0.05200744287243911, 0.0696460013943059, 0.029836568981409073, 0.019237273539017354, 0.047568015554653745, 0.051737728595201454, 0.05831631898347821, 0.0066574510003972265, 0.038767759022968154, 0.04278779402375221, 0.030589291626321416, 0.049501948923404725, 0.03853725049910801, 0.017533193907833526, 0.0159418189432472, 0.03273803221860102, 0.05612839977922184, 0.05399786088881748, 0.015728674130514264, 0.1134327007457614, 0.02734585352508085, 0.020486902645123855, 0.03265448080907975, 0.05712101169462715, 0.015144511458597012, 0.05693691835871764, 0.052860547988010306, 0.04066725673952273, 0.043119648537997685, 0.02968901475625379, 0.046990941877343824, 0.011255755172377186, 0.05234358912067754, 0.01829500213664557, 0.04849128458382828, 0.06903010194322892, 0.089627297062959, 0.047194329356508594, 0.03478660747142775, 0.07065859277333532, 0.020599654809172665, 0.037943915730076175, 0.010591524520090647, 0.007123974783878241, 0.01694126200995275, 0.022785329758854847, 0.08721802277224404, 0.09407256317457982, 0.026871024897055965, 0.05849525545324598, 0.01814116976623024, 0.010173536770577942, 0.018166833656973073, 0.02152351416381342, 0.017863294409055794, 0.028865955171308348, 0.04383511621771114, 0.024308167597545043, 0.10003660100379161, 0.04452519650970187, 0.035622077461864264, 0.03267070118870054, 0.06555085256695747, 0.03200329075168286, 0.07223860227635928, 0.0055062726605683565, 0.02281545501734529, 0.026433164553184594, 0.051341470929660966, 0.030776896380952427, 0.03368551816259112, 0.015697978902608156, 0.06807535567453929, 0.04120337404310703, 0.01209303769948227, 0.050602332555821965, 0.004417140835097858, 0.008571347654131907, 0.028127503814175725, 0.08141614802713905, 0.02625768691567438, 0.035909725419644795, 0.02435884907442544, 0.018965096179662005, 0.04035482189751097, 0.012498501388888274, 0.08586605531828743, 0.01135099774026977, 0.013686730709326054, 0.011153741673167263, 0.009014883095265498, 0.055894074495881796, 0.059376618159668784, 0.009376666092846011, 0.040612688953323026, 0.01405625494330057, 0.03452655892553074, 0.04977630438016994, 0.028221891427944814, 0.015952548278229575, 0.05820205368633781, 0.03830432299790638, 0.03783400323508041, 0.031643673977149386, 0.057630211514021666, 0.0287161210684904, 0.04862245897363339, 0.021971608512103558, 0.02181415955003883, 0.03794127283617854, 0.002070288797507861, 0.013118837610818446, 0.03613731624292476, 0.04194558957325561, 0.0193779932201973, 0.034957194567791054, 0.0902225011959672, 0.027499402607125894, 0.025145846219467263, 0.0688238272975598, 0.06735686172864266, 0.06555796361395291, 0.04108572964157377, 0.023710249324462244, 0.022750817771468843, 0.02663367334753275, 0.0450433258499418, 0.01827149768359959, 0.017521755503756658, 0.05984558763780764, 0.08510684248592172, 0.06295440439134836, 0.004479989717115781, 0.007808777769761426, 0.009583103586919606, 0.04940190232758011, 0.025443633186763952, 0.06517162613038506, 0.012550669705628284, 0.05978517087974718, 0.006801650293969682, 0.01770336540149791, 0.07248784854475941, 0.008924031497112342, 0.05454125548047679, 0.039255452674946616, 0.031054749685738767, 0.058134417315678935, 0.04219740070402622, 0.038404769929392, 0.006409851027586098, 0.04451582594109433, 0.03578096322183098, 0.03260244735117469, 0.05923713171588523, 0.03706877858244947, 0.07240762534950461, 0.023470796012718762, 0.043384663960231204, 0.002980532498830663, 0.07051312165068728, 0.031820130401424, 0.0267066430034382, 0.03707737562113574, 0.036864790599793196, 0.02739286752018545, 0.012298197003214486, 0.025466920508603965, 0.04039180205602731, 0.03469108331150242, 0.05466183115329061, 0.03266096421118293, 0.013259713355052685, 0.04761675811771836, 0.005496109478242163, 0.07205363363027573, 0.022795336454042366, 0.014578835473262837, 0.025900409390617694, 0.025720933485510092, 0.02495210581193013, 0.02653663944719093, 0.020914757990145257, 0.030053917318582535, 0.03413100354373455, 0.07637576599206243, 0.004221482293879879, 0.010674907992194806, 0.06834697324250426, 0.002558866241348109, 0.07087647036782332, 0.06374930138034479, 0.07946922749813114, 0.05362816108390689, 0.03800067179171102, 0.031199043550129448, 0.031205007872943367, 0.03742361847045166, 0.04299258607040558, 0.055526040494441986, 0.014630507611270462, 0.042204905301332474, 0.013020797782311482, 0.05314597374360476, 0.03714088310620614, 0.040147166433078904, 0.03953246798898492, 0.04120603050770504, 0.02825067997244852, 0.0316061136711921, 0.020856327643351893, 0.05840955648039069, 0.024366031367597834, 0.04758544372660773, 0.03278905465932829, 0.019628491385706832, 0.022949268908372948, 0.015808210309062685, 0.03587962221354246, 0.03181775892153382, 0.05720642568277461, 0.046631854360124896, 0.03936433040403894, 0.07801480125635862, 0.04022637182580573, 0.028773172292858362, 0.007911688631533511, 0.012796059350616165, 0.03324846357905439, 0.033115969438638, 0.05273349569844348, 0.04640617700559752, 0.04631782156814422, 0.05062586415026869, 0.11451031613562788, 0.0367783384530672, 0.05611209797539881, 0.018830291627507125, 0.044656404826257906, 0.010297808762905853, 0.027537292002567222, 0.0240359647931265, 0.04204358360064881, 0.02424263468544398, 0.06487332856548683, 0.023482994376016513, 0.011547888246630984, 0.03901166182809642, 0.03766949920515929, 0.039985172982726774, 0.04255670874512621, 0.020464851953355328, 0.07297854471419539, 0.034863957070878575, 0.10846106109342404, 0.1785344649106264, 0.05698932161820786, 0.13953221775591373, 0.09425512980669737, 0.08909821616751806, 0.0936267656673278, 0.1187385121094329, 0.25346265786460465, 0.13257295904414995, 0.1401454098522663, 0.1009971351761903, 0.07375774718821049, 0.19329551926680974, 0.14007927982934884, 0.06009552601192679, 0.1358411501028708, 0.14646650637899125, 0.15712607439075196, 0.14757126995495387, 0.08948017031486545, 0.13972432459039347, 0.20829786067562445, 0.16509890157197202, 0.1736819352954626, 0.1337725275329181, 0.1218657578740801, 0.12646266977701867, 0.10755577324224369, 0.13364387729338237, 0.1057358541126762, 0.11294885099466358, 0.10233433092279093, 0.10565063011433397, 0.11152566450514964, 0.10959471669048071, 0.13893494409109863, 0.15146329253911972, 0.1663368751427957, 0.402809491114957, 0.16153385144259247, 0.07634677219071559, 0.15155505761504173, 0.11744502080338341, 0.11809858573334557, 0.15327476390770503, 0.19215872883796692, 0.1755104921758175, 0.10851193086377212, 0.21555532195738383, 0.11521870669509683, 0.0922588865671839, 0.16441922661449226, 0.08424054325691291, 0.1149918045848608, 0.10188472004873411, 0.08184336724558047, 0.08910404478332826, 0.2335205679493291, 0.11958916432091168, 0.11717790870794229, 0.13263353865061486, 0.13061657973698207, 0.1402540433087519, 0.13140134619815008, 0.10327268378543002, 0.05900457062359367, 0.12608210662645952, 0.1583799799638135, 0.12098516869757857, 0.12529417819210462, 0.1306651085615158, 0.07624685112386942, 0.1401038427970239, 0.16702250763773918, 0.159239900963647, 0.11818872232522283, 0.09307898434677295, 0.14482404451285089, 0.11269245975251709, 0.1197174752929381, 0.1495373658835888, 0.17863742581435613, 0.11698382055120808, 0.10325724032840558, 0.0937740213370749, 0.07478034695876495, 0.116791483014822, 0.1312973674918924, 0.13885281421244144, 0.13697519925023827, 0.1643640481467758, 0.08764290783022131, 0.11215244765792574, 0.11771821257259164, 0.13840692171028682, 0.08900457833494459, 0.10157564734773976, 0.1692543857331787, 0.12632511715803826, 0.14524001362068312, 0.08703597182674067, 0.15320946169751032, 0.1626013634460313, 0.10000534089548246, 0.1414009439093726, 0.1948564619358097, 0.1671358094151531, 0.12136180991572992, 0.10743787099740335, 0.20339840357857092, 0.07735312104757343, 0.17131880138601574, 0.1554433618273054, 0.24922854506543704, 0.19079209145690712, 0.09873502834567002, 0.1564534426267658, 0.11198737365858895, 0.18863960195864948, 0.1067618601290243, 0.2245483129684414, 0.08519889254655157, 0.18815225096685545, 0.14064990063863142, 0.14565127369548592, 0.17387938898588928, 0.1300960483827761, 0.11716953558581215, 0.08640453392373663, 0.11841368382530552, 0.0812647125816771, 0.10828775646431105, 0.14342927506991796, 0.13754462583788804, 0.08647876565477677, 0.1041598818930132, 0.1516784695642335, 0.12720688698547228, 0.1625675724021026, 0.11506417712994985, 0.08680324110069446, 0.14062661331679138, 0.09169068134256772, 0.21486785741789, 0.1992111639784915, 0.09072585882885115, 0.1201270797422954, 0.13965311912553652, 0.07528337210948978, 0.08929945608334881, 0.11693474889865943, 0.11032108842794384, 0.13685636062707218, 0.11096159155879702, 0.18335293206785405, 0.266993731792484, 0.17939723575753824, 0.16295003545071396, 0.19476650176303728, 0.16303426878792898, 0.08491675768579755, 0.13449121825397015, 0.0705196898696678, 0.07048361216272626, 0.08138205164245196, 0.1467925017433507, 0.07144045510462352, 0.2568214604897158, 0.1934619096240827, 0.12054459590997015, 0.18200659645455225, 0.15167697678719247, 0.1568830774298736, 0.1537610021020685, 0.09556128936154501], [0.03677509166300297, 0.045031736471823285, 0.0639113558988486, 0.07684896952871766, 0.017398974592132226, 0.04047586236681257, 0.02614728587546519, 0.1353139148226806, 0.02731108708706285, 0.020236845527376448, 0.03195563045197299, 0.023573051240029078, 0.0073663008432569245, 0.06374338455498219, 0.03707310085051826, 0.037399866352123876, 0.0523770951798984, 0.038703311766896925, 0.03853487562654274, 0.019342556728848388, 0.010891776265842574, 0.04815172530444605, 0.07362392651183264, 0.004491500215538378, 0.007764611077228827, 0.032960048876702785, 0.014056916514943753, 0.013428442113633667, 0.048695995206279416, 0.01851433518874858, 0.06520650961569377, 0.02982040966993996, 0.05441263916769198, 0.028894626668521335, 0.02491117488326771, 0.08738936643515315, 0.0168002912708159, 0.028553723889802183, 0.04165452179898109, 0.026622538587876728, 0.03348443770248975, 0.02326220247362341, 0.01684758346527815, 0.01678564169976328, 0.021569649456068873, 0.04673244717663952, 0.00654165306228346, 0.0654707175812551, 0.03187347003923995, 0.012851877337587731, 0.027962716495884315, 0.020600060233846307, 0.07679022196680307, 0.04025676340929099, 0.045542717445641756, 0.05413612936224256, 0.016242538878161992, 0.046158080854054005, 0.039043400303593705, 0.027436614369175265, 0.0721755935145276, 0.030866927799901793, 0.024430651650098816, 0.015751863064776574, 0.02296420176779585, 0.04990820140976991, 0.07795899853642498, 0.029495191228176867, 0.02966264688542911, 0.010918987216427922, 0.07379547373524734, 0.027844513999298215, 0.06867501778262002, 0.015453002315812876, 0.04874984374535935, 0.048313572869769165, 0.03440742513963154, 0.0544841669366828, 0.02891513199678489, 0.006292963616683015, 0.12906178459525108, 0.03528208052739501, 0.021002219457711493, 0.0750598083915455, 0.020967626046123247, 0.014677640350003327, 0.10984531324356794, 0.005190658457909844, 0.022809913082580482, 0.06596429073917014, 0.053215089320604286, 0.02219090933379318, 0.004451304225118032, 0.04858206917664834, 0.0319798745081893, 0.039912444206752946, 0.02205614888641451, 0.017255123471841216, 0.030591893808117936, 0.022038515457617383, 0.03897574018420918, 0.03129657956638506, 0.05905942339450121, 0.0028934264139804456, 0.036087993532419205, 0.024782750256625668, 0.03273870736094458, 0.025098891596176794, 0.017737275189054862, 0.05451699785356011, 0.020831306664539233, 0.022449285290869217, 0.009767147729040256, 0.04447425549317684, 0.016965541689257537, 0.02841664115632219, 0.019008783656837683, 0.034310808538326194, 0.027201274675982337, 0.017835240378709774, 0.026400581301589097, 0.019863449402951767, 0.039402019631649764, 0.03744237996371729, 0.07170272246003151, 0.013570456100361688, 0.023565356652917605, 0.07316235985074725, 0.023048255293230926, 0.03154185640492609, 0.04247465689799615, 0.027505833422765136, 0.0047477888292633, 0.01722444859998567, 0.03065632749348879, 0.050133536104112864, 0.041265860332974365, 0.023200360792023794, 0.028654058863009726, 0.09330297554177897, 0.013308490693036999, 0.07388736094747271, 0.017833920628098503, 0.024827292687924843, 0.03348779305815697, 0.04240723765854325, 0.030203999086682285, 0.06165058578231505, 0.041134855576923916, 0.026148834631645253, 0.04002799532775368, 0.047617385762610605, 0.02499067034971501, 0.015683324242542897, 0.045204505058271546, 0.015674671224717582, 0.03269764581429107, 0.05928000155836344, 0.06599452625960112, 0.03342259941356523, 0.015752505976706743, 0.06015027021723134, 0.07167503823127065, 0.006414811966741192, 0.015364153244133507, 0.005451389779669366, 0.03423712642065116, 0.028985865879803896, 0.016646933874913623, 0.01052974645114903, 0.06232608774943011, 0.04063131134690983, 0.0992228610973273, 0.03358684220750417, 0.018238025551129664, 0.024822210460635166, 0.0270435051061213, 0.05262205989233085, 0.006719236278773418, 0.012980987284598606, 0.009071942801321191, 0.011914398088785154, 0.01476344110311142, 0.06152422220579215, 0.03926180037004607, 0.04960215836763382, 0.028357048818309392, 0.01636427314952016, 0.005182525367542569, 0.023167629959061742, 0.02354359264219446, 0.04303417008902345, 0.04740987618320754, 0.030146360929523195, 0.014026683539019098, 0.06412546083863292, 0.05680082459002733, 0.030114486747022187, 0.075681475390281, 0.025627553496243696, 0.02293210706141378, 0.06263831563826118, 0.019361141803009168, 0.030213973551456417, 0.03261790098622441, 0.008929878772635545, 0.03425785227279578, 0.044081329434577904, 0.03919690188818744, 0.01809746871835419, 0.03451668284833431, 0.06013975292444229, 0.07185849374426262, 0.03025690106941121, 0.02721008036418685, 0.025261633131386976, 0.056583279477698464, 0.02366319631359407, 0.007650133737895105, 0.021036314146061028, 0.02834935423119792, 0.029697513407362357, 0.01763230582166995, 0.05461703087868435, 0.028163428850738064, 0.04688536861379232, 0.047728112499628744, 0.02258572680875659, 0.022700102367837514, 0.06072490795382431, 0.03574112303821104, 0.09063066715108496, 0.02826531427646322, 0.059131490598831854, 0.043705390500170846, 0.03524728185896363, 0.0072291137850178135, 0.0222603302515511, 0.06002561654895544, 0.029316543135792017, 0.03182917866589768, 0.01614662116792585, 0.044727006394948275, 0.04405033056225095, 0.056786724632339816, 0.02643826713652483, 0.045752486546656916, 0.0634356757093753, 0.03864627072055425, 0.03782593206103359, 0.049619756173342466, 0.04382227494248322, 0.03169722735349621, 0.010913022893614002, 0.006059211271349341, 0.07377649511077575, 0.04137274656178696, 0.017475077383486286, 0.035782710449504, 0.019785974274522493, 0.022352812878255333, 0.03348840373967375, 0.06233963809375252, 0.021049228363803456, 0.02250191246691559, 0.030009948249374117, 0.05675734745870743, 0.04428368893318942, 0.02462786446059389, 0.0417180699961526, 0.040524330123194625, 0.03314570962850537, 0.045580545772931406, 0.012804628399732922, 0.020584867834778767, 0.01595598166542394, 0.025736897718161345, 0.03520369616204074, 0.03859184203403337, 0.031237540234412466, 0.044607760650771, 0.047162696053939204, 0.02922042865040047, 0.030946201046130488, 0.05241029929103596, 0.055192089306988885, 0.03892611552562032, 0.028668565941708427, 0.04085537039541772, 0.012255352605799479, 0.021125873983172432, 0.015590018892128552, 0.03379189549013972, 0.03497898232723985, 0.02683884198112147, 0.00425380897442145, 0.023465103103912303, 0.0023462053089003477, 0.016854648711159825, 0.0581578810566238, 0.014756472548469901, 0.009767726180143654, 0.023494685534387827, 0.0712325723309602, 0.05250566738790699, 0.03889081813395023, 0.008136109848107611, 0.05950691723929984, 0.024459509744441936, 0.031061989654387747, 0.10026626475155354, 0.023510600573250225, 0.020268522934722047, 0.02196220401674509, 0.035599163334284506, 0.019453593895637562, 0.04622651789603489, 0.0388591576899801, 0.014929838245734572, 0.02231575808088694, 0.02425224443764559, 0.0457456638770444, 0.021084003283509185, 0.07597324544829981, 0.05422797925504191, 0.037510270785008154, 0.03905853163450956, 0.054345362420592985, 0.04046254950974669, 0.06195537692734173, 0.02821934861796243, 0.0394930688531271, 0.022300684425447668, 0.08320508524775505, 0.020946947691429938, 0.032851469703018665, 0.02312972699292004, 0.0617025683500937, 0.04570985758411033, 0.026765076742906655, 0.05321891625810947, 0.012611067803975726, 0.013144616004345673, 0.04119011886151774, 0.05234028465513672, 0.04165997043518083, 0.011438114851314043, 0.025075989342959862, 0.05930728545146329, 0.0327426598274282, 0.015593163901939988, 0.048590381230626783, 0.1606760203306164, 0.11593233554490975, 0.10483726340212993, 0.21690251252480916, 0.12113349645265512, 0.13207899912127427, 0.12921925900237902, 0.18752573244273663, 0.1538664735853672, 0.10585914392556463, 0.10932292948876109, 0.18561819408621105, 0.0861752297995346, 0.12445698811539582, 0.10748397745192051, 0.11658051290682384, 0.10658422644649233, 0.12538686607565197, 0.16198609503252165, 0.1326334843678134, 0.10656592635703938, 0.1567028449582202, 0.20445572398602962, 0.10425603709050588, 0.08263130925063576, 0.24278536651815685, 0.09967547109616653, 0.12209719259824071, 0.1324679489646639, 0.11587099597922393, 0.18226980018828595, 0.1446571656103645, 0.16356624024254934, 0.12012473201113087, 0.09735741226800851, 0.12088615686765738, 0.12737049534916878, 0.15722921171358653, 0.08790851357792105, 0.1088849487049239, 0.16396189401192324, 0.07134444918483496, 0.10742681087659937, 0.12096165067383222, 0.16865538858941623, 0.13688707112201623, 0.06543917927358832, 0.14213146828114986, 0.1275824425475938, 0.18177375037755283, 0.14434909714119776, 0.10693678645683186, 0.14112453588417598, 0.11821029973881585, 0.14114046788641385, 0.14606296803270066, 0.06947337530021157, 0.1263368015310594, 0.09650211887700216, 0.1320983645107065, 0.12310237437486649, 0.0726908255102379, 0.06558089809758322, 0.1273638999887875, 0.100471860862204, 0.11923465691506863, 0.17272570303508214, 0.13595156132110528, 0.1257077452859708, 0.1611050444522074, 0.13866012383784565, 0.10535507383091108, 0.11818284621196133, 0.17489059615348065, 0.2122856652630227, 0.23615379950829915, 0.13052516749926976, 0.18227642269006797, 0.08998903765210084, 0.13427810397531303, 0.24839400127530098, 0.05612376877771957, 0.12411339155265264, 0.06886579468846321, 0.15809108689427376, 0.09230204139436994, 0.16621467098593712, 0.18634277449122497, 0.11843984813562461, 0.1044164224128638, 0.16046222751694067, 0.144779111923916, 0.08023703736918313, 0.12032431630151612, 0.0948395316622087, 0.13918606990150043, 0.139839431270957, 0.11985376583678381, 0.09208858784820352, 0.09294713820729937, 0.08774833181606871, 0.14033047349325248, 0.12459991473172392, 0.13929053715297154, 0.13731123693287373, 0.11305656842887402, 0.11832635636840548, 0.10455029737204313, 0.1726460973066943, 0.1534726247191429, 0.17465719367776597, 0.10260792302766017, 0.12014763935336045, 0.08917784903730665, 0.1162783612630197, 0.11263352220079728, 0.08925020122634512, 0.07793887997312204, 0.07949140202254057, 0.13396922126412392, 0.10371073242276907, 0.06372408023370163, 0.12400387600064278, 0.19778824890298502, 0.21477470813052996, 0.07190206926316023, 0.10762493631669454, 0.12109870117689882, 0.17041123365717276, 0.16013194381126336, 0.11655259797615664, 0.12761566362210683, 0.14363506117037364, 0.14607352603759083, 0.16542941597955568, 0.10536280913012368, 0.09516046515532903, 0.1279314945318869, 0.13085576333105564, 0.11979617178440094, 0.18392024162624562, 0.16295853070914745, 0.15932744555175304, 0.10193104363445725, 0.10931255468832594, 0.09041285741009883, 0.08617568441799708, 0.17040313194905007, 0.12728988538895333, 0.14413261732884816, 0.20103362761437893, 0.1617078006799732, 0.15511249458151205, 0.14425110311380454, 0.16932430198150022, 0.18471268910382474, 0.10198780308876719, 0.20770345042858804, 0.26977165415883064, 0.1396964910839285, 0.169678252988628, 0.11740877346268722, 0.13388342729636601, 0.1411870696714946, 0.13385258109441825, 0.08708941324480943, 0.14757029286452703, 0.1486670904393707, 0.14116028110895837, 0.09549901341753346, 0.11134004446544818, 0.09934592699365956, 0.17175310451005185, 0.21936396615845816, 0.18772045842238835, 0.09295417461544275], [0.13622191681393556, 0.014514221976112043, 0.056979163948978694, 0.05234811155657683, 0.003751495013213051, 0.06287433047379766, 0.01744572226224201, 0.006861156542851988, 0.11538198936198439, 0.021033630540062274, 0.023872951843908856, 0.01758357004395553, 0.028063397521951368, 0.028469456625836234, 0.009184975709233965, 0.032269846448408704, 0.04582221959052341, 0.021438554794128453, 0.03051905646654112, 0.028257724862279635, 0.05638677573629788, 0.01234754515878324, 0.02690576419367322, 0.05122646602935024, 0.041053119248577526, 0.07531611142413956, 0.02254098081695182, 0.059035600029996464, 0.05934956496847527, 0.10675073894006865, 0.05125279997342399, 0.039229373181504865, 0.010905740516526359, 0.02260783008698906, 0.0038075029899898383, 0.007868308191453772, 0.026313917112669775, 0.01143894944938698, 0.1013421363064221, 0.02656814213176923, 0.040969550875680785, 0.04626081105587738, 0.0485754636382418, 0.043890026664095264, 0.06392286385276488, 0.04715134755575231, 0.03295530591692243, 0.040127203932830265, 0.050295152967529635, 0.021931518966864263, 0.038553894963115454, 0.002494609823250877, 0.044389896626983366, 0.03772917975272451, 0.0504816245686795, 0.0037884883183453765, 0.005229779394410018, 0.028960342785077434, 0.04691721565489258, 0.04452652643833842, 0.062180311286023686, 0.03820564365014434, 0.04494859557598829, 0.06338582374155521, 0.009437639249621757, 0.041346511005290916, 0.03927601567868676, 0.07930084224790335, 0.033621790153639655, 0.04809795479689326, 0.0461510037338095, 0.04390047610338245, 0.06579524730997426, 0.03768716825704489, 0.028953479403363805, 0.07412113661744765, 0.03654851185690079, 0.050310867838561535, 0.05080685658114297, 0.023953120756362165, 0.01939723647332617, 0.06784315420580761, 0.03624857562993254, 0.08109925181737968, 0.022986493339495997, 0.007744399215360838, 0.06879047730139323, 0.034588733089289496, 0.03463164364386882, 0.05400626454502344, 0.010611107040728842, 0.040462705572800975, 0.01148517888837627, 0.01605333447722452, 0.0082631918235815, 0.020814548545916165, 0.03376058449170419, 0.029963047908885137, 0.04055035533383489, 0.06913730369082519, 0.06593820106770311, 0.02425191195548645, 0.0317051662132144, 0.03843826241791248, 0.016948573224778687, 0.02723328795816217, 0.023260002323825444, 0.021705563412979245, 0.009314189981003957, 0.040993984921702316, 0.06429869761424405, 0.01543899904936552, 0.026847009846408452, 0.03894419848386731, 0.025316804813753282, 0.03195498923638037, 0.03605337806844285, 0.015897100092843175, 0.06675337946840695, 0.07473514974117279, 0.05834253757659878, 0.05574334133416414, 0.021702778026727692, 0.03244026391101735, 0.010917140753008425, 0.053181773251188655, 0.04770991758310369, 0.005776586593128741, 0.016795142886361906, 0.048594221738832336, 0.07126252965203353, 0.05321068902100835, 0.05136743846482464, 0.05475946555712393, 0.05589903458686812, 0.0824358504531639, 0.019205765765426413, 0.01609825519179659, 0.04680044317085828, 0.0595886196408953, 0.02984886064327189, 0.12052049434610776, 0.04516778613573738, 0.027153795884389962, 0.030042042955756187, 0.04267797991633415, 0.05045106674411467, 0.06638149478073631, 0.06873688660562038, 0.017247669764661362, 0.017535792696954947, 0.024973934283480048, 0.08060035894491843, 0.06960281942571912, 0.013416437980985003, 0.03131691186821886, 0.013351552221657974, 0.041314555398587666, 0.01785559982194432, 0.08471176547131368, 0.028457919834181666, 0.025106628591726934, 0.023362400043489676, 0.05867203418165445, 0.022697490008015717, 0.07615867549819605, 0.05083726852067879, 0.023813866710822498, 0.0795574981187071, 0.024636374986065284, 0.02571625498655651, 0.032872253230639865, 0.042593088400151045, 0.024758701279227222, 0.045384544147444625, 0.07211892226977007, 0.011103410489990242, 0.017048241537330405, 0.05990233352141721, 0.06155341278229441, 0.012520880321972072, 0.03180525352114013, 0.07030672486871481, 0.02325708292690771, 0.0369757344680173, 0.015141424124262162, 0.02823797949323697, 0.03298718009942344, 0.08027994792376246, 0.01118210782962186, 0.0466520305989044, 0.020785341006038443, 0.06037608667143753, 0.04036417550274304, 0.01180037367157638, 0.013521636353938707, 0.07103479972907475, 0.03535957940454994, 0.012696656514890492, 0.03660797527326005, 0.005690812133252621, 0.02032662758470646, 0.008889055561407335, 0.04922766471281648, 0.036112668458372355, 0.06114992871880531, 0.0572813834462847, 0.002984272499036576, 0.018593462549948266, 0.004910652076692453, 0.03315895123939429, 0.026663113285654357, 0.01760535780340433, 0.04382847675255366, 0.06495902753834214, 0.019769234815612435, 0.02043182765399771, 0.030459436987127577, 0.048877102988106866, 0.03520048329872744, 0.015583713605467762, 0.04523669815223132, 0.051560010095792155, 0.04418149816670588, 0.046010088973811696, 0.03921531732859356, 0.01895729302694755, 0.09856541494705848, 0.018451760689328824, 0.0405323775485158, 0.06725328335804598, 0.013874628930352628, 0.05186922189646533, 0.02307564944827131, 0.06773660385182925, 0.09432363470218011, 0.010735801421105862, 0.003552581200243107, 0.01504702802880534, 0.010649472258851995, 0.0453353537512677, 0.011841154474365925, 0.004000716684718749, 0.05369171606642859, 0.03434181419600334, 0.05705531593412161, 0.05600941187835165, 0.060293142550757954, 0.0525676651325609, 0.029814333388847963, 0.018117483805066774, 0.009632528077677956, 0.08026413805782795, 0.028291012093956982, 0.06058748425649745, 0.06833934650889464, 0.018768310846228684, 0.05875854739653213, 0.05729794648608991, 0.03447576718670981, 0.029569955609206642, 0.016117345774546266, 0.021350869410006062, 0.04764220318091767, 0.07504819187202624, 0.06488062960228749, 0.021941663065393056, 0.041279478530798636, 0.05825484371078866, 0.05553073934944613, 0.06551668832876853, 0.03188302041962743, 0.035834374105823893, 0.04910390671076519, 0.035783921634512286, 0.005560346812541995, 0.009655934143146234, 0.05413487067978297, 0.016242291212880185, 0.0280595671917711, 0.030184986535459757, 0.01932216335886291, 0.07561501967055456, 0.024814095181812133, 0.018502504930698445, 0.018017172580584884, 0.028521503654441664, 0.03024666876132999, 0.03430681875241654, 0.017620684213138053, 0.02121395291760564, 0.020326826056199412, 0.06383668312004634, 0.016835536076022044, 0.046524323523044586, 0.01710450226840164, 0.02868732064962387, 0.05904810543039015, 0.04628888883494905, 0.028898562171629498, 0.029530488619846956, 0.029307773070675985, 0.03808087802359036, 0.027394543501681516, 0.015865553303488662, 0.006972558422213686, 0.04320324405229517, 0.03592924347945622, 0.054372076344277175, 0.031193326892597333, 0.02659020130522549, 0.02736175838591797, 0.04180563833298428, 0.053177206710513146, 0.04336100344413093, 0.036422786103295426, 0.03303664530228291, 0.04145017419276493, 0.00863083906006068, 0.037252909237785, 0.05684987249385033, 0.05414746768240418, 0.03019476422507848, 0.0857305790164641, 0.030502859835645983, 0.03612793888896704, 0.024818914476782084, 0.025148209217669706, 0.06134920766843217, 0.05750525929033756, 0.009193046883280789, 0.04011200814108763, 0.030732778034039905, 0.018263942196166942, 0.01187971222680062, 0.018746707987572466, 0.022079017212880508, 0.01486843591555953, 0.02960404860121863, 0.04085213717605386, 0.05450569006747433, 0.015276851232296653, 0.050401503153677495, 0.05163678294047713, 0.03409137709864548, 0.03579545672982931, 0.03411389428323933, 0.03674375691584178, 0.04617408070979374, 0.04385972668283752, 0.03345330651583416, 0.055082502508802075, 0.21120109488921507, 0.1800505564148937, 0.18433075531252793, 0.145230948392834, 0.10900986021650688, 0.08725212594228131, 0.16387046820351056, 0.17302856035530567, 0.20644422514098032, 0.08928628571863685, 0.15412958232419832, 0.1418174694159201, 0.14935629202851228, 0.13105195494634764, 0.07542029369090285, 0.07949216198176146, 0.16787387909633772, 0.08403323723801545, 0.20456196899924958, 0.081244478667421, 0.11106806048857314, 0.07225294650665351, 0.17440624428646906, 0.14489088021218777, 0.14097284259540693, 0.19229843919830664, 0.11830718096877847, 0.1385627133505685, 0.103363464985575, 0.25292976360235897, 0.13495358558637754, 0.06267084460705519, 0.12981588127357618, 0.21775700524449348, 0.11898635381034442, 0.09038384325270142, 0.09755012978400503, 0.10524061854396548, 0.12690768018364906, 0.11157221879277911, 0.11711667770785944, 0.11914367893976824, 0.16300657098846777, 0.15168805047869682, 0.10289634790803705, 0.1320649127342871, 0.12047698668071202, 0.16072444058954716, 0.12481453535812241, 0.16126816427069052, 0.20912445203534194, 0.11186755794499602, 0.21946765988000802, 0.13505149818956852, 0.15411595734102385, 0.11002880268331085, 0.09108346035437924, 0.0765789058059454, 0.12514561973512173, 0.20310784131288528, 0.08727290946990252, 0.12921782050813946, 0.16443817131221294, 0.20617682806083135, 0.1559790109417268, 0.10784612516207354, 0.13582164900643484, 0.17205042498452322, 0.18469754420220852, 0.14681897817977838, 0.1395365060972316, 0.12816748901137284, 0.16642022638448647, 0.17388306664569037, 0.09696895775518247, 0.1322544275649956, 0.16094006544777326, 0.13359457493892737, 0.08580009492912463, 0.13750580006412097, 0.07955664316458361, 0.12092435838920729, 0.2375522330403328, 0.17393006198108196, 0.10391305120927946, 0.06430496727781636, 0.09973024244287185, 0.06870109388338667, 0.17853849540863717, 0.140691766249282, 0.09963021959577288, 0.13891705790800707, 0.20102169896875108, 0.14242163699652466, 0.12105131229119641, 0.12436896855277674, 0.09179326226668698, 0.20581102983227798, 0.08624781269047942, 0.11303752195090055, 0.13803781223084244, 0.17794229382915155, 0.1721775417349168, 0.11765312749360289, 0.07998637974794422, 0.16699784967516149, 0.14380147866904736, 0.08007855873022761, 0.12406166004283087, 0.09752923769078084, 0.10389798773186547, 0.1044370566627809, 0.12082001327403954, 0.1429023654865367, 0.14139588203813347, 0.1543423980474472, 0.1260682102292776, 0.09897463941680533, 0.1316878508244242, 0.20387145105217183, 0.10926763567009143, 0.1530743653752974, 0.155228781913008, 0.1174439215766532, 0.091978101991117, 0.07032728447977986, 0.14659481735101768, 0.0855857457167336, 0.08970193591501031, 0.13069534408194677, 0.16657641157507896, 0.11180186218449048, 0.18184415517108782, 0.13365868292748928, 0.1315774531768901, 0.26979206449219156, 0.10285745428076812, 0.12568249021257671, 0.10831972224903957, 0.1393518495772566, 0.095807292232556, 0.14279183213199886, 0.12946311091738089, 0.10544488472597939, 0.11998242964701993, 0.1686810100717204, 0.18348372647804873, 0.16297746183616774, 0.14555101336113044, 0.12721626433942998, 0.0758180780602353, 0.05528090614825487, 0.14732292613812856, 0.13001679549259798, 0.11523811279663018, 0.15686994099191257, 0.13854919693299703, 0.08137966319918633, 0.11458936546530042, 0.17129688470491342, 0.10167434705155236, 0.09878040198236704, 0.15613250913364546, 0.15099062504512922, 0.15382493367152555, 0.1393309642693826, 0.11732909988079752, 0.25712891827736584, 0.2194652035832405, 0.06915728654712439, 0.18022869899868965, 0.12937904042857035, 0.14057619816490582, 0.0878059733659029, 0.0752865205119763, 0.1489249744585582], [0.020659125010882105, 0.028323888811948042, 0.0482156602665782, 0.005226117001646864, 0.028889174639646496, 0.008305975152844829, 0.04790270973795226, 0.044747827241995504, 0.05950171287570681, 0.04223269470302122, 0.04044058872386813, 0.03778707914586578, 0.018514053596715842, 0.03218956897035241, 0.02656762644515506, 0.03813336270728281, 0.021817813461114253, 0.0036020726963345495, 0.019073232609246458, 0.07148980495652982, 0.012178818096539803, 0.007853907133851732, 0.011308172002567776, 0.11854381327118192, 0.005701848929415324, 0.03897415241226554, 0.016270726919174194, 0.002409599775481703, 0.048442596303565164, 0.04647043087918844, 0.06806439054863793, 0.04343548962580306, 0.08314586271132741, 0.02839937074376004, 0.014184617653622158, 0.033034792901682, 0.023085647661771094, 0.0328326742830021, 0.02756982436403632, 0.015603927163673299, 0.03700034832581878, 0.02862147900408932, 0.06859725088413272, 0.06752009011272873, 0.013746179706816162, 0.052013274880924394, 0.06744119684611048, 0.027552212987627302, 0.027320718891652565, 0.03416934755763837, 0.030865757326994623, 0.03326944727450609, 0.05885496043733188, 0.04454419549022402, 0.05105992978704827, 0.028635840197759013, 0.021119531377085617, 0.06049238757363387, 0.02088056321788047, 0.01812287137311484, 0.07822968651141439, 0.03231624128030879, 0.004167772854478764, 0.018949533979009305, 0.021458447744537677, 0.01651036852438535, 0.008884202339686453, 0.06902685854583979, 0.06799615706716265, 0.04674502721588526, 0.0295015491013016, 0.07426989863493613, 0.11595562286674976, 0.043437922173844914, 0.013679768940034722, 0.029639179751809155, 0.0564951038520251, 0.06354526590023722, 0.029750021839780465, 0.012713197502307594, 0.05045664090929287, 0.03569056539397154, 0.014813773134457213, 0.040736172148691754, 0.05800429465515273, 0.02198210884151714, 0.020179967329438244, 0.012850919755042663, 0.02506822520600898, 0.006482360976016415, 0.04685750457325152, 0.05350669653021863, 0.017975880332025032, 0.02987996468852673, 0.01919877515839679, 0.027816585497930646, 0.01206466051683362, 0.06407339684665203, 0.005668307247105986, 0.014240604426179613, 0.045076451929552216, 0.01716559416880565, 0.007814590270364923, 0.01622645420554493, 0.015330779499241283, 0.030724184388028722, 0.040734567413372655, 0.019548461572932344, 0.029360542739076272, 0.04857816081494093, 0.03959488642535039, 0.021229923935607076, 0.09542233217507601, 0.021120681493942226, 0.019815029144021015, 0.032733404609773836, 0.011836249514349868, 0.0386354005895555, 0.015433701387207423, 0.07146643621048757, 0.012647225238781954, 0.06298058227236782, 0.029378920860056366, 0.04119922819414309, 0.02909848912219916, 0.07331465703568288, 0.05532976745494774, 0.03595509905634182, 0.08003535640559026, 0.04397040592240436, 0.08990758630846228, 0.00801747478544712, 0.03899989942354815, 0.10809046562228884, 0.0111329886796219, 0.028517215313123803, 0.018906584408666407, 0.07869227097502776, 0.057542850130370686, 0.051116041240415404, 0.0787907060501831, 0.06159814181072371, 0.029422082472592592, 0.06715534361345427, 0.03328571854425328, 0.009199392033873923, 0.016010082958798324, 0.020245410335649337, 0.017951524317530648, 0.02287182940303215, 0.024463731928595474, 0.06097508381519999, 0.04257728531956673, 0.02543987749543573, 0.0177614293393812, 0.04288842076701777, 0.04900915947343622, 0.04305459399308477, 0.032726615866912265, 0.03245461492666176, 0.025729959697595665, 0.017396837206823484, 0.03285939159936138, 0.03302559196682913, 0.07410992043358938, 0.08590341545641422, 0.0676953624933958, 0.04685195415679898, 0.05018026002549699, 0.047710063468132696, 0.06872891381915126, 0.017274478683248162, 0.0623695207759738, 0.020312381741989936, 0.016905499821794883, 0.0340867494898183, 0.023424031379233514, 0.0320531698609037, 0.06526394081967217, 0.03273955213704279, 0.020629574810819964, 0.0287306824299906, 0.038297432474792004, 0.03140147090224283, 0.01954996113532356, 0.031010220825139965, 0.025099965377843807, 0.05215763320614185, 0.06591775002224104, 0.047635475506207774, 0.0325391909240612, 0.01400768625483449, 0.022759898266355907, 0.01834463018790952, 0.022625283704006245, 0.0945974982210568, 0.046177198578204424, 0.11280192102172545, 0.04191951007981386, 0.03122251746909959, 0.013984195372488881, 0.026755446634654487, 0.016111079503649046, 0.016385931987315416, 0.06916479114443064, 0.054304138025535006, 0.04044016124680638, 0.02705987815612129, 0.042365534896297116, 0.013019595927159702, 0.01627606698977096, 0.04565021435597113, 0.04765146518392222, 0.01655351826255875, 0.015231676067092588, 0.008889001278605844, 0.04241123762247818, 0.02692656129199479, 0.06167523017419236, 0.05198041682264634, 0.009817285529736961, 0.06656136084347963, 0.039410287580851994, 0.048726817659501515, 0.028501999165330614, 0.03424322645046881, 0.01822554729213672, 0.02918398453454886, 0.014897120983472891, 0.04207018217337983, 0.07562367099204234, 0.056663010735064745, 0.05119834075282727, 0.02666866879111954, 0.02177369681053928, 0.020161020935380032, 0.04324925211923463, 0.013585327891632915, 0.01537566289438733, 0.01849423528515867, 0.042869326791593006, 0.03136442628289972, 0.03133128323991384, 0.06323888698326689, 0.06241241775985275, 0.020039310412747518, 0.029183258502078906, 0.02604836395143398, 0.03277963659326945, 0.03152022470853158, 0.033284565034721575, 0.00960279128048569, 0.038934593820678334, 0.02687956256392811, 0.06477709194379193, 0.12127740015941006, 0.06346495449542999, 0.02795566482070301, 0.043873901279377084, 0.06887656303920917, 0.024320980035034672, 0.05380914333675589, 0.041371240214045556, 0.04899326139794929, 0.025378968799486756, 0.049673458827393394, 0.03746125680793609, 0.0031300786483500686, 0.01805257853785796, 0.0706412765596594, 0.05521163450820105, 0.0024438091786578298, 0.02994782497574176, 0.03559701916362558, 0.03095259963135634, 0.0366298885616873, 0.050018744942333014, 0.02571600392859961, 0.04165298152448876, 0.01599871919357351, 0.012444106629118323, 0.05222777337101953, 0.012746165822526174, 0.02158356112028871, 0.05868303323430674, 0.018831718247383833, 0.031260104916457615, 0.009692769264802337, 0.043982952034899166, 0.02150248297091041, 0.017890040563153367, 0.04026035285953965, 0.03508089150169066, 0.027585941267066767, 0.010043895869914974, 0.044362643267959356, 0.0657156551522868, 0.048689372704497406, 0.04086814042446869, 0.031756419355848005, 0.03259037282051785, 0.042016089361693175, 0.03716704063117504, 0.016551928794277564, 0.019975855514141064, 0.015088941136907254, 0.03969743003004363, 0.00888989694483046, 0.03735111021835889, 0.09027348631726843, 0.006643088110389986, 0.024404567067644427, 0.010322990045616669, 0.015829991283161298, 0.03654237111498203, 0.03978106625644224, 0.044414381563131294, 0.045120163155453544, 0.0077636755470718655, 0.0371408525721303, 0.057793412756706984, 0.04274082922243646, 0.017113772753093923, 0.03080104204959103, 0.020321728561871817, 0.009667246170075876, 0.023345938783937266, 0.03977928510201829, 0.043265777839613814, 0.023687233416629688, 0.0479252845980227, 0.04721507217202868, 0.036861910218639035, 0.030426575536174432, 0.07239922508597374, 0.03622989895354424, 0.02697585177208696, 0.04988261724689177, 0.016555894831461564, 0.012482364977976041, 0.028538646841687814, 0.05328101578301617, 0.05970152786799839, 0.02705381205305457, 0.08719390085233109, 0.04541039293898003, 0.02799174252764455, 0.013232341252400406, 0.02884800113471491, 0.03212634986266494, 0.04129789736387985, 0.05015758677784886, 0.134783463286502, 0.1597848188664232, 0.19283980157758507, 0.10477603240204708, 0.09762634962264981, 0.1675144862383604, 0.19320884320352757, 0.11294294774000134, 0.07593858587954726, 0.10730848794004746, 0.14595468741442474, 0.14147490422640527, 0.12990479650241987, 0.11933940915124756, 0.14250071346759796, 0.14172875774758203, 0.13858978689781257, 0.06639738607087306, 0.15516873156385763, 0.158256323742015, 0.1430614683777094, 0.21145597978362016, 0.10031041702521698, 0.14951947970049723, 0.08332063976143088, 0.07982401988868203, 0.10315854740994317, 0.05750570712344987, 0.14042719187481062, 0.088266691858215, 0.190108983112233, 0.10979307961783238, 0.16233201218502863, 0.038708550057240894, 0.14674227658127034, 0.1233965600175517, 0.11889006969119821, 0.09650905350489275, 0.11977363085108143, 0.10547993784504277, 0.0898210730935846, 0.12903867369251593, 0.11371697977717433, 0.13875066755073412, 0.07940802363944904, 0.1632709689438343, 0.12429388186761312, 0.18957105412014894, 0.05422699198658977, 0.10009874124079943, 0.09779259070221867, 0.1511046596403633, 0.1496137689266886, 0.11684839853218623, 0.155852396307247, 0.10346579485173736, 0.10975501380328621, 0.12446795324129717, 0.2037483240876879, 0.07409662793257407, 0.1282600276172161, 0.12022554874420166, 0.17964253973748, 0.09600430487522058, 0.13285282759794168, 0.1285936768565859, 0.0826548815571836, 0.1610672636223691, 0.2604219844298703, 0.09637994864689452, 0.15793680160173348, 0.17239951768091746, 0.19343341115329946, 0.1739528878991093, 0.08446412054555756, 0.10866223315575294, 0.1839017447616373, 0.20104537984090193, 0.25302345571773394, 0.23107070369379862, 0.22534260606127127, 0.13086904904672078, 0.04883717798760959, 0.18954073717551573, 0.2189343584967511, 0.07879164242850882, 0.13248983850436552, 0.14458524089838776, 0.0668483879417181, 0.24858507673655236, 0.07621090912393161, 0.13202433634017194, 0.1368143321680171, 0.1999308725020715, 0.1273469366133213, 0.08231218066066504, 0.08134947517620665, 0.13788539969495364, 0.12144016713968345, 0.08065542206168175, 0.1923024154135159, 0.10341872487749372, 0.0649533210588353, 0.08104018534400634, 0.05075917931805764, 0.1140086751963411, 0.16029338086290018, 0.16997038945555687, 0.14489956546042645, 0.12589092259960516, 0.10956027425293412, 0.1300022748431989, 0.12964843240167412, 0.1275462494896991, 0.0758794244112713, 0.0825739526855094, 0.2131374574133328, 0.16813325589256628, 0.11816586926579475, 0.17958018236926623, 0.1391280958695071, 0.10460243600287608, 0.09518923504011971, 0.11333441494831017, 0.13880241263125623, 0.14917033272130148, 0.12430646190685885, 0.07309565307306391, 0.1689813161002738, 0.11741494813135692, 0.19736694650990622, 0.16010702800537857, 0.10893640201538801, 0.1908817666449717, 0.07031832103218351, 0.09323419244693858, 0.08537508773484401, 0.16324905226273195, 0.10110833349504642, 0.30693626563463894, 0.2641496386911188, 0.14497659275574343, 0.1522161000009094, 0.11347221862524748, 0.12098691931792668, 0.10421286869261946, 0.10195172538182565, 0.09750020317733288, 0.15839258714446, 0.0822807169918503, 0.09672573687774794, 0.12425220624676772, 0.0912384106112378, 0.09800873124705893, 0.15982015697019442, 0.2080825615142073, 0.1732161617172616, 0.10971295141748019, 0.20612204314342567, 0.16038748009928636, 0.1250767484307289, 0.09386843948491982, 0.08137969034058706, 0.1148306525179318, 0.1760337105286973, 0.14452821681542055, 0.1515100436019046, 0.13150399497577123, 0.19992859262440885, 0.09816288083259549, 0.12381338407950741, 0.07865812709288937, 0.1220985089561769, 0.08733475793685232, 0.1714418333555971, 0.12024283781647682], [0.08118529684309449, 0.03162618134436863, 0.037548346777579615, 0.04431368696636387, 0.04806295935330646, 0.06795478000172547, 0.06306540593504906, 0.048475844519478936, 0.02520243264734745, 0.08200948618884597, 0.03862231843439596, 0.07149901946208306, 0.04124415060505271, 0.058414516571377, 0.05153562693989702, 0.028635297369744097, 0.05557990599689739, 0.09059486085815088, 0.0778037022267069, 0.02947598529447402, 0.046253306458571126, 0.10144909378141165, 0.029026038545582975, 0.03407652396708727, 0.05772726916308914, 0.062250797503760884, 0.0026352410828362084, 0.011923676206996399, 0.08377090881445579, 0.058838288831923685, 0.025872280721419623, 0.024213298223912716, 0.02688554215377995, 0.05134959299383419, 0.05098951481548803, 0.06304511095264129, 0.028432546017159308, 0.04156657687521406, 0.0114203262076314, 0.026243637848113264, 0.026196903748703853, 0.037366394219653945, 0.023055395177964653, 0.020488003568191613, 0.05268567255032914, 0.02444058540277183, 0.01875928633048066, 0.025967284105718136, 0.014097071369178593, 0.017795328948912875, 0.013246450539944428, 0.023012857817645584, 0.03500614408403635, 0.019020973538447703, 0.03815687055300389, 0.0318817278104169, 0.032788311663482866, 0.03825950915259974, 0.024125773991857256, 0.038135384741638384, 0.09821066326860871, 0.07539380368377481, 0.09424204765153782, 0.02512277602883322, 0.05217196047306061, 0.02194177502367113, 0.10976563966167824, 0.06185133715293237, 0.030164956181709255, 0.035936480055430105, 0.021203603562233702, 0.013441851661939706, 0.03795852119635258, 0.07729987640466009, 0.039200152070926766, 0.031246256016727005, 0.020729378830375414, 0.02561093108462436, 0.03620623165209379, 0.04157068540475198, 0.014386682837669338, 0.04206125604520951, 0.013199607874932033, 0.03066817471491439, 0.022287400406120077, 0.024850244134930626, 0.033626003856105466, 0.02780440409800836, 0.03745460716475334, 0.0872251270338893, 0.023989795574120114, 0.04291086670543466, 0.022160538106358478, 0.04267806812588658, 0.06410182746393339, 0.05930041189172438, 0.020203405625319908, 0.004767418847352798, 0.013112333004495927, 0.0076970832721729365, 0.03010393213480711, 0.0175201524647751, 0.03410765854641795, 0.03299469148207988, 0.023734691852171506, 0.015857997816056013, 0.0616650182221617, 0.025814389809966087, 0.03912442756284561, 0.012225696384640676, 0.06682485634727137, 0.009123911798399473, 0.04468657588586211, 0.0984065563284925, 0.06003204906093223, 0.009026609028556516, 0.050097787486655374, 0.06629366520792246, 0.03476732011352267, 0.011516688358304756, 0.018980889082221047, 0.023260504439739243, 0.01057187414595059, 0.035765248350799084, 0.04072757850268057, 0.060640932459916384, 0.022317544324323535, 0.062282634366835864, 0.01091930188704282, 0.06170385078127895, 0.011447544791735709, 0.05503873021474906, 0.048291795288345644, 0.035042859613895416, 0.015253489271604588, 0.05673565808683634, 0.05879632822637047, 0.009759952713336264, 0.05163072023008551, 0.028175220093024627, 0.030525577188070332, 0.06323786239538874, 0.037838837797088284, 0.012234366365841456, 0.03472286928445101, 0.06892007748995509, 0.06214183156511613, 0.03963169016476188, 0.03624967485666275, 0.03036636233861957, 0.026983349584043026, 0.04737488413229585, 0.021976499053250467, 0.015320235065051487, 0.0006860958071359034, 0.034022000285663774, 0.02114435049173023, 0.021067743888124824, 0.018431928807071278, 0.019930855071704303, 0.028150808099391203, 0.030305338291717426, 0.024208775788013424, 0.04118529447753515, 0.044244466216436455, 0.012732601059334618, 0.02616195410623082, 0.03121499590841787, 0.027008602961099575, 0.017602409568748305, 0.008419683203101158, 0.013763025186822882, 0.03767107679907765, 0.05561204480805567, 0.08373991333480392, 0.03205550402136786, 0.022065076710922376, 0.044559048621782234, 0.08888350733156715, 0.018756144713344317, 0.04486278464485492, 0.04525670475725617, 0.027888442356405512, 0.03201523296801107, 0.017496473288961818, 0.03682140167802572, 0.015367927595174738, 0.019719610157023584, 0.026031904388219118, 0.0352994578092226, 0.08228184335998126, 0.0203606459378664, 0.019945226443399276, 0.07050046697258949, 0.032391748657183986, 0.0842684106901288, 0.029706066341272423, 0.02222151804848441, 0.07001357738460813, 0.04442968592047691, 0.033465733884700706, 0.008611105565380837, 0.03713776523779545, 0.027240590691300373, 0.030226214323192835, 0.02048857184126973, 0.05840267613530159, 0.03392768052539655, 0.011971017595247498, 0.04007470567843743, 0.01669539823862059, 0.027345539702634727, 0.014356450709913458, 0.048149482746209414, 0.04626382714403527, 0.0179015213756689, 0.046680603708539686, 0.04998813962031688, 0.06572724453040532, 0.04099152523225971, 0.03825882383223091, 0.031750787515193224, 0.04626269738322922, 0.03439428870167051, 0.0440672226915402, 0.02971111124913607, 0.017555824747042995, 0.03805581294000149, 0.03945027364950095, 0.03836939789886985, 0.027741749870723913, 0.06252311396279506, 0.01767801363686366, 0.05701009836047888, 0.020292638069284812, 0.04836397445095437, 0.04836859188175627, 0.019339786609634757, 0.014067352383530565, 0.03834369499236345, 0.08251038752496243, 0.03562083913545523, 0.02249192612777863, 0.01586425899794059, 0.05330736669046538, 0.03592318416173969, 0.011487037226158594, 0.040978945193013976, 0.007611363943267081, 0.023181548408631767, 0.07381740398705006, 0.05407889832609466, 0.028527145673121725, 0.020389909456883158, 0.047837536449411085, 0.03857493633404374, 0.036608704698405097, 0.007185139626796756, 0.01781708447794829, 0.056513726245611906, 0.04777308240798967, 0.017858162987977266, 0.07638721966317721, 0.051712005332644494, 0.03256851720756718, 0.02981111713285957, 0.01989980530925095, 0.03281155148787158, 0.02087473460207028, 0.010708773674975549, 0.0361505001783371, 0.04930738239948239, 0.04737678403034806, 0.03432730372462954, 0.04190986131184867, 0.04821904615632125, 0.03423034107046468, 0.055478994268924, 0.04054950037971139, 0.015459847037813492, 0.06135485986513751, 0.039999038845832856, 0.07151177592043366, 0.02975333309067147, 0.05158589620675359, 0.011294819281569548, 0.04973702738061547, 0.06274732907435723, 0.038367104450506825, 0.136288263968059, 0.045999218842812946, 0.017714868266401545, 0.025523844507655928, 0.06087649267699037, 0.0036244206712581217, 0.050064491773290296, 0.05070523578407509, 0.023056918489081518, 0.042982486076653004, 0.06932624176676784, 0.02587727304281933, 0.02603423685234572, 0.01629352230312569, 0.02191299496085516, 0.042279642540961504, 0.017278807736667137, 0.02603325297656868, 0.04370681542371001, 0.05658254326720323, 0.04150884711582746, 0.06960166591618742, 0.058019181713461876, 0.03284895233809948, 0.051971541584602425, 0.021902269018547874, 0.037101775740406344, 0.032934936295662604, 0.0025169864238705486, 0.04067181310217295, 0.03305269604814904, 0.023266182081507783, 0.07254131031887871, 0.023266500992966548, 0.07597531498010669, 0.007383492376123155, 0.07246158245418753, 0.027327672179256166, 0.016863508682165827, 0.017912781664303372, 0.07296147277312619, 0.06316293177327939, 0.03438503687669124, 0.008448945873949145, 0.08535009729010717, 0.00572468714588987, 0.054264039998607974, 0.0329568767254906, 0.05325625943286078, 0.011502158379049172, 0.014107107750273176, 0.05407533262457166, 0.047385167330503464, 0.0157448962064726, 0.017667199485003948, 0.022518897894769907, 0.020343531588358537, 0.013065134108598744, 0.039694105208452256, 0.04188856888296349, 0.038982206622936895, 0.01146669898714338, 0.010841638465145869, 0.1236414975885834, 0.13200366816350392, 0.16625287250748702, 0.1816051887082202, 0.08481492993554898, 0.11652051684047494, 0.26285721947039875, 0.15451929212680884, 0.11254362309617655, 0.10229496232100896, 0.18346164694854192, 0.13432036313627446, 0.14496197711144174, 0.1213875806757382, 0.20089953552399362, 0.08077463387910809, 0.1389077076954501, 0.14162578327315195, 0.3281932207090514, 0.17539149070424692, 0.15736438946000167, 0.15948409214615822, 0.16867901517876557, 0.19860662998897688, 0.1424880927162511, 0.13301415608397552, 0.1432019251265696, 0.08612153053815876, 0.15373204222747258, 0.1148674019745418, 0.1628634679530348, 0.09387721972806112, 0.1735014585512025, 0.1446121244558266, 0.10563273036054202, 0.11052805517933198, 0.14091431216469832, 0.09882733624960695, 0.07759648441736187, 0.1308786299611841, 0.08352979139557906, 0.15994112619331904, 0.09515551184969288, 0.08491938361631972, 0.17946259225053446, 0.12550757745546953, 0.09235710451113326, 0.12481822658862386, 0.12607203716678278, 0.15729076841047832, 0.053814571616905074, 0.09930404102695839, 0.09818181195961577, 0.12630318690623554, 0.1079660290852189, 0.15222318390650408, 0.2268774929855551, 0.09163391510290758, 0.14007664711347648, 0.2146954552403518, 0.1982248861874853, 0.15862812022013323, 0.2331852088017123, 0.24732093885540962, 0.1835110035857984, 0.1163118944636413, 0.1543419502143349, 0.10777702994112458, 0.09604171251079865, 0.10168751741626433, 0.13105998880096845, 0.13270224710660322, 0.12295634006815297, 0.16468061187437602, 0.1734488449458565, 0.10385131130793265, 0.11208014975168876, 0.13744530188185827, 0.0962742328909891, 0.0862950590838279, 0.1286909244954586, 0.1503900129880224, 0.07482196151145867, 0.07344311050006322, 0.14406495381678852, 0.06223430231745754, 0.14794949894504889, 0.14082965813577175, 0.1134390246921352, 0.15580309395279202, 0.0690070181818945, 0.09240359094526086, 0.12922415802521364, 0.10769004853708403, 0.23564720526337624, 0.11698126925953797, 0.15510015881487302, 0.10429578567189829, 0.09196033794432878, 0.10635449484522853, 0.16860086151531764, 0.09195051954260894, 0.13531330414116383, 0.16756422285522732, 0.10201503948441573, 0.22271165437996387, 0.22580528551978724, 0.10423401184380054, 0.07026141908551965, 0.10721293663872139, 0.09968846504177366, 0.0997592294588685, 0.1577207560517958, 0.35129741951823235, 0.11084991148007767, 0.1291429102420807, 0.15777304396033287, 0.16102907567151956, 0.2138566773916994, 0.09881092248750584, 0.12730367322053227, 0.1222332524401801, 0.12562640250793525, 0.1923696989459651, 0.11906248543943677, 0.16429661533662251, 0.14215410420937197, 0.11505135281809739, 0.07265563668417079, 0.11829940495746476, 0.08134984837046691, 0.2343202078981059, 0.10397720669529267, 0.1222300361841917, 0.18014996179512568, 0.126032166449087, 0.13726718643946306, 0.12895456249160425, 0.1119532094204, 0.15414856773402008, 0.15028908768934862, 0.1297993114484208, 0.2325106364275728, 0.09880966041237116, 0.11580870646451201, 0.20720554143190384, 0.1637876190777336, 0.10324176294463021, 0.12068003149969236, 0.14283018293125288, 0.11616372955696923, 0.14056543659951004, 0.10982295551470347, 0.11244724398212773, 0.2421409482402461, 0.10854088395301785, 0.08734707334744078, 0.11110281505222831, 0.07437260848070894, 0.1049453065331493, 0.16667006297835282, 0.2587872850043433, 0.08433682737605912, 0.14185025622802122, 0.14004067118678773, 0.07666818744369916, 0.10377598713551249, 0.10631520088229861, 0.09306728640305144, 0.06190531461366585, 0.09031922636287552, 0.14048998350543634, 0.07879133708775043, 0.24153724206345423, 0.18905942514538765, 0.17159393376537732], [0.05635183796818767, 0.044815137915845425, 0.07525532825716905, 0.06838054036987679, 0.06931600945868663, 0.03655457795996751, 0.030576236612562622, 0.0730895394725459, 0.017736652633175254, 0.008918757583679897, 0.029360658090029444, 0.0271219233982265, 0.03231509794880237, 0.03762211371213198, 0.04744827447991286, 0.013327866260494505, 0.040431499747293334, 0.03318865750251072, 0.04933737364730664, 0.045646838644253354, 0.03530939156189561, 0.03492264695731657, 0.06610187728490148, 0.059716984895723205, 0.040515614340880086, 0.050027260556817055, 0.04147449628050838, 0.08862009325197764, 0.005846841260790825, 0.09095525116260562, 0.01517683856322297, 0.023417469945603182, 0.03391466961641397, 0.05608992684366448, 0.01887761096337012, 0.015855929980586683, 0.020779843176049844, 0.009255478890346629, 0.05430563080257603, 0.03964370362726705, 0.008963396706219231, 0.026822297601029277, 0.09730616930340018, 0.013008973461442759, 0.022831302202705826, 0.038455826296870194, 0.04191128284271274, 0.02996474763910685, 0.06583264816020216, 0.035812976504010816, 0.03502036617802722, 0.02802552339354796, 0.047639818130327125, 0.05883801741791623, 0.043404473790100644, 0.0457510887645185, 0.07488910255155393, 0.06593557513718094, 0.03705325709389789, 0.009382014645130506, 0.026315845848460282, 0.03292292622583253, 0.029800090938806534, 0.05000618186646274, 0.04802137872736369, 0.00831746614338564, 0.027490897170667137, 0.04817914829722472, 0.042094382124819925, 0.0248852243114795, 0.06966910551169089, 0.013028377866638558, 0.03530821091096316, 0.053815450319754224, 0.06356512662023306, 0.02482937748676964, 0.00490134851341801, 0.019086282533992614, 0.084319321172578, 0.028712440016014234, 0.05641450746251004, 0.029823201841541698, 0.01768647666488375, 0.013263536899882768, 0.021227472727852206, 0.02196264167183212, 0.04712025368852275, 0.0445032900066248, 0.04115437363673534, 0.028217231588704244, 0.110359262808093, 0.045407495594450405, 0.0225130285668586, 0.017336885245250802, 0.01917283815730895, 0.03895529931677239, 0.013387585823823298, 0.012353189721969622, 0.03876867165256824, 0.0149199095820742, 0.011632792485345687, 0.017479335190728307, 0.02016458154789039, 0.04354331223294139, 0.017030072065868547, 0.07224091608077288, 0.03370424233643072, 0.033065988549164364, 0.06044978235981294, 0.041188503948173354, 0.03231890453025699, 0.09528935966747147, 0.0672525708962764, 0.032226918930453916, 0.05082986570362534, 0.018745642687593187, 0.03852772047477109, 0.06206421394433294, 0.015892762557736466, 0.028302024717309644, 0.015385561023971863, 0.03431942932573812, 0.05279612448066473, 0.08859976434281894, 0.008869041322863527, 0.06270308180579118, 0.04845576327560203, 0.030202180612832308, 0.047322351951152086, 0.020474156364798546, 0.04925930819341114, 0.05174698381285582, 0.04246564256027341, 0.09524500383330242, 0.021140681313616887, 0.027073465819869722, 0.018267836987173984, 0.01337516269580062, 0.05362331634387374, 0.013526977272704244, 0.02497461621117379, 0.07178032651011433, 0.025171126737924557, 0.07895847383354392, 0.033228670712560415, 0.08056194029216256, 0.020698407099449208, 0.07657020698700633, 0.006309565672251795, 0.023838395751746635, 0.03857861399384482, 0.040893673697220426, 0.0028394101495255847, 0.09942504417683397, 0.03705433935725263, 0.03400958988017269, 0.06045172975531646, 0.039493051889751635, 0.0380593175733728, 0.08088079746812582, 0.03140250566814627, 0.023722067708149552, 0.024701376944514256, 0.020792609812425714, 0.006875618668605706, 0.05213806764887912, 0.03222578238429768, 0.04125160431223256, 0.10099421747561012, 0.02374464426455753, 0.05867083317467144, 0.01082077860233507, 0.05397655828190701, 0.007748825808188745, 0.023777580354362726, 0.01733167579264513, 0.004358982326396341, 0.005390132062270173, 0.07155708170362882, 0.02483798809615629, 0.03623259273756828, 0.010220189445785113, 0.018115395613546883, 0.07996402880442993, 0.03932956226968339, 0.03551584601934467, 0.02968997149063008, 0.009204299538396299, 0.012613791273906827, 0.023353667297799672, 0.016112105787864754, 0.061454434879124165, 0.03350251048271145, 0.003778417162331087, 0.0340585868938693, 0.0719865740143827, 0.02272752027160355, 0.051985326023506265, 0.06047300861350127, 0.03957109359492149, 0.05422245258731501, 0.03375391449247088, 0.029483177765671695, 0.02547807223163545, 0.03640606700043593, 0.0326280484774283, 0.006834609284331756, 0.018397018180361817, 0.056366901445601664, 0.05407740215637854, 0.05028833029791713, 0.04830323878143515, 0.0328600870977555, 0.005557714096669639, 0.0398185383528471, 0.00888842876468386, 0.019013541883655956, 0.04335157520004681, 0.06100416582609926, 0.03859319910407066, 0.009259142131278557, 0.04917916642235858, 0.007151094980404845, 0.010751151579565235, 0.015373467833602002, 0.06876257594142642, 0.011526520330724972, 0.01621549077598112, 0.021741303548749005, 0.017954930563324263, 0.04202340057651911, 0.023246989718505313, 0.02087294666229614, 0.043648909245218546, 0.03130467448915754, 0.022350648351545845, 0.10611596264477287, 0.014320289882432138, 0.02765443259184914, 0.027212679153308272, 0.029931926900254827, 0.016847554627539854, 0.016232415135683756, 0.06059591166142907, 0.013918724376708269, 0.012071291500303363, 0.033687580909047804, 0.04459518400420036, 0.03158414609996336, 0.04849730997479387, 0.04470227379351854, 0.06290584164006369, 0.014467055310628243, 0.05481927841901779, 0.038656655699014664, 0.04144219462094562, 0.02010522160812148, 0.03277937535728727, 0.046531933293278725, 0.039836960578603406, 0.016949803069499985, 0.03451108154175537, 0.03730506143931832, 0.07296767458319664, 0.011386721760832837, 0.04619816531028066, 0.017775373234014426, 0.01771801327621298, 0.015938777410026108, 0.04970439663156867, 0.023298461688682437, 0.007654135398167584, 0.02751653052733413, 0.06914230449391262, 0.00829428738714861, 0.03215266005801303, 0.06934036208050591, 0.05840431819004672, 0.02927830768749118, 0.03541598602065018, 0.028934097050556114, 0.027502245668854033, 0.01593706919811666, 0.07391025471900191, 0.05283881451136299, 0.011192233268437641, 0.017142417108906165, 0.08141779686723437, 0.04857339071375983, 0.05511119436206562, 0.08731396083853074, 0.03531283173444016, 0.01559008504929287, 0.019356587136696492, 0.03509561571159533, 0.03320025705865451, 0.021755836072510908, 0.06062990626586335, 0.03389685467949935, 0.036860386907522164, 0.00847244608615126, 0.030009581840464046, 0.023783456467624222, 0.030677453681294407, 0.036429615558258126, 0.03312264283054641, 0.005020248204735773, 0.015143877028354576, 0.06209105678967067, 0.021928991423919797, 0.02162572189367243, 0.020434456977194974, 0.02675556198560766, 0.009723507749315883, 0.05063511597524796, 0.028962595521339347, 0.03739979849862201, 0.039580426844103, 0.06370685222957816, 0.011809785800453807, 0.03605107783472963, 0.04776540817692876, 0.032843557984701226, 0.03881255590489932, 0.008962276275269687, 0.03284818220085331, 0.01461584446951747, 0.015865546518138478, 0.05262754584795662, 0.041346507612615824, 0.02022218917097364, 0.06866697714264904, 0.07617926225066185, 0.01126552777298327, 0.03159548781280007, 0.06760465593210288, 0.026229490392974446, 0.04693172951894147, 0.029853847875658954, 0.016946786981342093, 0.050038992427289486, 0.02270356798544526, 0.0353004111509238, 0.03525783307850361, 0.054259181687874455, 0.03573972186339753, 0.015459373759637986, 0.08203003222921065, 0.01527103957986193, 0.018764658631490808, 0.025365350601662482, 0.07487055818949427, 0.1283502999160971, 0.11114945076406002, 0.19261333372976097, 0.17026207808937344, 0.10441992365356002, 0.07277574416782175, 0.10049145016819239, 0.15570503207189695, 0.13047262174742563, 0.08153026404657535, 0.11955191274838788, 0.07898894684123141, 0.09517769994480269, 0.11992845897163663, 0.1255925300398043, 0.18649045085268362, 0.09046877548098564, 0.09575406794569322, 0.09722488080816609, 0.179505801360522, 0.12479975686541625, 0.15663566999137402, 0.22903838274734362, 0.1870273213301386, 0.11494909759078707, 0.09467291060302939, 0.13343890543494905, 0.11262134249721255, 0.08907564809279782, 0.24096081299441202, 0.12589530593582562, 0.10608305369636842, 0.13749511992292746, 0.18530788645148277, 0.12868713827005454, 0.1488287446222135, 0.10180990477757794, 0.13317731661455973, 0.15615612215229444, 0.1417059182588543, 0.08576956763863564, 0.1556995902210474, 0.2231818384357861, 0.14333901634173735, 0.10013890372855322, 0.1354270266102893, 0.10077693699193851, 0.08556112168090683, 0.0912666783801147, 0.16383686714938708, 0.13460962261472428, 0.11639468930661678, 0.14993128260331495, 0.08818548478718315, 0.1357336701559169, 0.08216212264129094, 0.16111713594623975, 0.31335436552762985, 0.1393774574888604, 0.09711419817592416, 0.1779903205377715, 0.12374639910246645, 0.1523353321743863, 0.18113831590328897, 0.1387021794383015, 0.08312577128942523, 0.11155951661723, 0.11090285756758281, 0.11030519713780709, 0.13069184284125054, 0.18348854407668114, 0.11327201008264508, 0.08324425707438163, 0.11700488227818694, 0.20185434286083492, 0.09009358632777419, 0.11242523909147296, 0.18153783732226916, 0.14924687147140503, 0.2044106421193906, 0.07933354085045201, 0.1400867844266551, 0.1341214438102075, 0.0900569793635181, 0.1164693824414696, 0.05694694032094308, 0.11491175102336065, 0.11229919442640883, 0.0616024165813412, 0.17409878649881907, 0.15846645246659005, 0.09346097242087126, 0.1010235912565674, 0.15338309880878243, 0.09557655639946461, 0.1189656313508749, 0.08389862946101598, 0.09789082900221859, 0.14791607431003026, 0.0832604333492262, 0.2247555104217359, 0.13365626734282288, 0.07892245719475405, 0.17159573866852693, 0.11076809372752905, 0.15472233694578919, 0.12188808167619364, 0.18767353094049863, 0.16294979117810726, 0.12311583650963646, 0.048580230346747806, 0.18445293232798576, 0.1833305132708379, 0.1442463940807751, 0.19943163357675076, 0.1137524943000504, 0.08613819535821676, 0.1029912071036441, 0.19579673505255155, 0.09544494774724756, 0.2295328447861331, 0.1570441345019, 0.12419633567333221, 0.12741696142724582, 0.10746643053633825, 0.14969306252896786, 0.11878032343728201, 0.21207189959074768, 0.11252420342394284, 0.08437025879642793, 0.12056838534772396, 0.10692399607173034, 0.12690706950213226, 0.1756151629877942, 0.1090053818853838, 0.115107372669237, 0.13912767517779553, 0.061616102632667334, 0.07181400220308985, 0.13077471910842828, 0.13495152283992085, 0.12226134378995214, 0.1645819257412638, 0.18694190734199115, 0.10780092794448137, 0.1964495943060943, 0.07487528757857424, 0.09349394922277757, 0.10425267155681338, 0.11955507472157478, 0.14085606671869755, 0.1502648097063814, 0.13628749043813773, 0.23877821011202677, 0.11549819526927811, 0.23495184257626534, 0.12091115409774439, 0.12799146345683507, 0.09688639361411333, 0.2486412322946957, 0.10016981099865266, 0.07773175037332944, 0.07242350985429116, 0.125625628978014, 0.07625383324921131, 0.1230251028069428, 0.0979543263092637, 0.08938444259443454, 0.18647154686706408, 0.0922291192359158, 0.13232218607195786, 0.19530227301376207, 0.19334229747099535, 0.11376622784882784, 0.11410751060715743, 0.15554925400231565], [0.17762085822011742, 0.019121408595570495, 0.1012900723144412, 0.045521570901785574, 0.010918128021460558, 0.05854722445032426, 0.03280078652980072, 0.06750879929001842, 0.019496577392731394, 0.017123501248923794, 0.04642364249697753, 0.02296769791947944, 0.036161964027477164, 0.014109266339801252, 0.03146672561498625, 0.019123013330889598, 0.05321628014956202, 0.028394403867423534, 0.074639754502901, 0.005836421507410705, 0.03175005469737308, 0.03941947833767959, 0.019940286708463515, 0.035253073155347786, 0.020716305156903606, 0.00931455978258912, 0.025067668807293688, 0.03429819457232952, 0.03485355852171779, 0.05189153552055359, 0.02926770897049989, 0.02211387694946357, 0.034460489970764945, 0.03204645575689418, 0.07019121785249029, 0.08854048073823963, 0.045507375949195454, 0.025136144865038137, 0.0752858759037086, 0.020543852089239017, 0.03174886726109045, 0.041681286612791676, 0.03243390603789261, 0.04295545324151005, 0.1256569501544748, 0.06560161377170257, 0.03708713295470391, 0.0032020114179301474, 0.017065922463578836, 0.01846037638772811, 0.004784249908490372, 0.048411668677415164, 0.03373184174831424, 0.07400533783116511, 0.01590199233032763, 0.0334316001805876, 0.062263180767851214, 0.03768959062706147, 0.004528281902561763, 0.061290928295680454, 0.03814638040161558, 0.03114274889230728, 0.013103442499414086, 0.03693123614149434, 0.03385643774111356, 0.04694901859121663, 0.06382391987634556, 0.03424469887145928, 0.0600893445579069, 0.019307237284790193, 0.06294076583747353, 0.00282794884489184, 0.04090706458581345, 0.020350837714171836, 0.008264120568388274, 0.03181105499554958, 0.0560705343128315, 0.040384378882923296, 0.0351408638193139, 0.08430273099137203, 0.026943383871444633, 0.0340563748697085, 0.02475101687014103, 0.0461541216022202, 0.015678442183083723, 0.04964069237134286, 0.04477397458893912, 0.028681142588279078, 0.013672104886999088, 0.01958699557664139, 0.060968488454818726, 0.04450959020427295, 0.029765485652855465, 0.0695448928911771, 0.024207149000306214, 0.02494317968375981, 0.05068390264308878, 0.021093872575355426, 0.06255951736654554, 0.0577177493167775, 0.03239660696791751, 0.04685115009280188, 0.04848806493516479, 0.026965225913694928, 0.024291601165064743, 0.022316032887569497, 0.015921758055420857, 0.006735210265365562, 0.02003129861051483, 0.006768602669970798, 0.052495424901800494, 0.016594561149499247, 0.011725957887912435, 0.01998860857981656, 0.08689012750983238, 0.08395870016621691, 0.060912251472473145, 0.016205470510093228, 0.028067792732534663, 0.021855931862124374, 0.055972065310925245, 0.009465605918584126, 0.02365771883965603, 0.037126152110951285, 0.020628916631851877, 0.08313058888805763, 0.041519194774861844, 0.05370027578568884, 0.023867935773783495, 0.025154838504801904, 0.04915327013337186, 0.039775987421827655, 0.028231579211673567, 0.048910917780761204, 0.06582910620740481, 0.020125933889565722, 0.016321411788729683, 0.05099272428612624, 0.03794066554733685, 0.008173677787583853, 0.022804455964693, 0.004641203700365233, 0.032389746978878975, 0.029661018401384354, 0.022831151228664175, 0.04886773581217442, 0.02485480049758085, 0.026653659596507038, 0.048024333747369904, 0.023856975736894777, 0.014564984877194678, 0.05471691462610449, 0.03215105871536902, 0.07369055865066391, 0.010769588224190687, 0.005504441464186779, 0.05629477317311934, 0.07896142546087503, 0.056091809778341224, 0.025289388606324792, 0.027546357230416367, 0.015361347501831395, 0.030705643418644155, 0.01559040226441409, 0.015112613527370351, 0.00759976777979838, 0.022302862522857528, 0.009823615413292177, 0.01742758841386863, 0.017944910297436372, 0.10167322068342141, 0.024673606202538525, 0.035333812037216764, 0.013824106909201613, 0.03252141330657261, 0.07982171286961862, 0.056711407245269845, 0.012159901388388659, 0.06310408243111201, 0.04666315518053515, 0.035518142860382795, 0.060773362139506, 0.09952582698315382, 0.055310076368706565, 0.008876537438482046, 0.026945641696719185, 0.017280320869758725, 0.04295447615108319, 0.05391899137092488, 0.023229814300845777, 0.011347616091370583, 0.07710368478936808, 0.025980205108810748, 0.034200699268175025, 0.0479955672552543, 0.027928525116294622, 0.04843576006325228, 0.036184688165251694, 0.024984112308759774, 0.00906494031992874, 0.014023004182880478, 0.025786960031837225, 0.03848125778936914, 0.006620941151465688, 0.026650187193549106, 0.04734648744176541, 0.05128495914063283, 0.03203770265515361, 0.03155782911926508, 0.040294805475111516, 0.02965005666815809, 0.02694480709864625, 0.02795924070025129, 0.0034925825893878937, 0.0464587024013911, 0.020931582265932645, 0.02755753100583596, 0.011483481702660876, 0.04565919137426785, 0.08499036516462054, 0.11638988527868475, 0.030625861271151474, 0.020736915658095052, 0.05479613358953169, 0.023180720595909015, 0.01683135630030717, 0.026279518779899393, 0.032674809718238454, 0.02209875749291054, 0.07012364933533327, 0.01908866928092071, 0.027910158869677355, 0.042879369109869, 0.025794054115457193, 0.006854137946252844, 0.03222544311678835, 0.007348782765412969, 0.030915836604045968, 0.09852859085159642, 0.07190751111400978, 0.045923097391745875, 0.0988114924569215, 0.026440664061478207, 0.004881423332595399, 0.050779979809054306, 0.014470366561519248, 0.07712672105325119, 0.022497758136263916, 0.04594076644363148, 0.03736477252095938, 0.030389001659516777, 0.02374465953159545, 0.034880815273416896, 0.013386260984199387, 0.03207686430375491, 0.052622578971620114, 0.014227524815526391, 0.05821735465100833, 0.09562215395271778, 0.04414047733215349, 0.04182708343224866, 0.037406933294343095, 0.017635047103145292, 0.027793793506654244, 0.017256224394908974, 0.012955033320135303, 0.06133687190179314, 0.027111372178686515, 0.06089802937848227, 0.04000984112332974, 0.011017498626772846, 0.06436437301869903, 0.06189134357763188, 0.05732470112187522, 0.04025855474174023, 0.021049560845962594, 0.04000497941992112, 0.055105830542743206, 0.07165399007499218, 0.04301482166296669, 0.053741361081068, 0.07147434114345483, 0.028257188819614903, 0.017406681053606526, 0.022855839725317698, 0.020393705860312496, 0.044020013617617745, 0.06485719978809357, 0.036290878895670176, 0.02890215501455324, 0.03259800294680255, 0.017552895172099982, 0.06182870801006045, 0.053363478143832514, 0.011319738480129411, 0.04880277965483921, 0.046134922453867536, 0.07950863681201424, 0.04012695626754846, 0.015544582490942307, 0.006050444598908403, 0.059410158145640574, 0.02043564441347761, 0.014037086329023753, 0.022851688787341118, 0.057035930188638825, 0.010126325152149158, 0.04554734844714403, 0.022456345447738255, 0.0506116522343031, 0.05127193805362497, 0.018974880654630915, 0.046884907209979634, 0.048175806512257884, 0.046321638327624114, 0.03277760777356369, 0.038132358475455215, 0.021447840545858656, 0.05354565801098943, 0.03314767398738435, 0.049482926194156916, 0.01879865493226264, 0.035968394950032234, 0.06519336639238255, 0.0027386837464291602, 0.04707786560590778, 0.03136635671502777, 0.03834340661498053, 0.023267791905839528, 0.09733298500733716, 0.042737192274736505, 0.07815690684531416, 0.034235301161451, 0.02984521012487156, 0.03168407395215971, 0.05370440806395241, 0.08328126437429871, 0.053004197244133265, 0.022386156089071716, 0.06663176563701459, 0.02801955058904631, 0.019899214983784726, 0.028867678650255715, 0.009231184792172695, 0.05941879589642797, 0.04502365511975118, 0.05120499718136021, 0.01967432812255408, 0.023767600800575953, 0.07810140268078872, 0.008598120949630226, 0.03642363087939365, 0.23265071319682257, 0.1205510962754488, 0.20188626114811214, 0.08761425329638378, 0.11342082638293505, 0.16576970129140786, 0.16948573903313705, 0.13645365009350435, 0.15092359935598715, 0.16018529023442948, 0.13430281622069223, 0.2324978799692222, 0.12673400236027582, 0.13299131659524782, 0.08439099482659783, 0.21495260644171918, 0.15050680243543216, 0.12008787398891789, 0.12180984658854348, 0.0762020271005375, 0.11939840098576886, 0.12847068559910568, 0.0733286552131176, 0.11868573565568243, 0.06371623636888606, 0.1332175401704652, 0.1470276684101139, 0.14628908304231508, 0.1398929405425276, 0.13017140648194722, 0.188544362783432, 0.12568950626466954, 0.14765475690364838, 0.15348060429096222, 0.19553180783987045, 0.2259298509785107, 0.10087759766195502, 0.07368451290364776, 0.1303534031446491, 0.0619773343205452, 0.16007532684930734, 0.0822829765134624, 0.10463748233658926, 0.19483218395284244, 0.2554091034190995, 0.13497240814779485, 0.1348303229148899, 0.22050868187631878, 0.10860725146319185, 0.1113932483962604, 0.23640939007912362, 0.09999962763062545, 0.16585846724254744, 0.18362891940133913, 0.11844303725021225, 0.18060561163084848, 0.1465496812015772, 0.19665118706013474, 0.09710331447422504, 0.12210399151912757, 0.10356843684400831, 0.09772714599967003, 0.12845750844904355, 0.22814434500677244, 0.15602684766054153, 0.1265355037259204, 0.21192111553890364, 0.09783987780766827, 0.20084522558110102, 0.0746200294899089, 0.11408179412995066, 0.11998390885336058, 0.13744414837232657, 0.10339737138045685, 0.09105979305292879, 0.13954524562827178, 0.1649084910750389, 0.11467544441776616, 0.08358497664864574, 0.2531023014869009, 0.1030752436657037, 0.15417147507624968, 0.15661506966820785, 0.24742594893489564, 0.06946225411125592, 0.11215018135096345, 0.1377921011298895, 0.1292163548724992, 0.09178543875792197, 0.14710238868636744, 0.16951908224395343, 0.08753734135201999, 0.18733906745910645, 0.2067383157887629, 0.0759587451549513, 0.19190388465566294, 0.1230518099452768, 0.13274579548410007, 0.11667651204126221, 0.17265988513827324, 0.1601722352206707, 0.09239229333720037, 0.1001935393682548, 0.07747767293559653, 0.13797100367290632, 0.10504748033625738, 0.15558710268565587, 0.08131334997181382, 0.11522271005170685, 0.0717473022107567, 0.14519011415541172, 0.10176854128284113, 0.11919422979865756, 0.09391425416937896, 0.142911254295281, 0.1567331211907523, 0.227369023753064, 0.0956120505662901, 0.08209937172276632, 0.11653308330902032, 0.1633796973952225, 0.16567839761929853, 0.1004531875784908, 0.13536200938480242, 0.06561506233577218, 0.18021010713917868, 0.08354814576783351, 0.17541187389620713, 0.11305407820535557, 0.16349370484905584, 0.14264810484434876, 0.12978508935442992, 0.1484240527663912, 0.1395074919398342, 0.11919743248394557, 0.06826146425945417, 0.11707696983856813, 0.12751502330814088, 0.1457190186317478, 0.07773735507258347, 0.12666555174759456, 0.11960209719836712, 0.13915297096329077, 0.13720162638596126, 0.13274210425359861, 0.10006811217005764, 0.18097782880067825, 0.1630174818315676, 0.14333799853920937, 0.09279446104275328, 0.08900081246559109, 0.12335130173180785, 0.09275855296956641, 0.2368181124329567, 0.06081741263291665, 0.15075705972101006, 0.11334662857864584, 0.12361168275986399, 0.06636140335883413, 0.13609584500747068, 0.15681884730500834, 0.07184258888342551, 0.12082757215414729, 0.1676275437431676, 0.10256065627826111, 0.11741669875170503, 0.12215648298817021, 0.09326296233172927, 0.09259349932628018, 0.10519275468375001, 0.11596014190997396, 0.13725106444741997, 0.13056465823735508, 0.1489830706268549, 0.08317660713302237, 0.1331464975540127], [0.015014806097107274, 0.016877098042251806, 0.04766276618465781, 0.022727040208077857, 0.03843868310962405, 0.032375473994761705, 0.05480041514549937, 0.05467756977304816, 0.05439765711448022, 0.04403501602688006, 0.036218180653772185, 0.01830312759349389, 0.020206715179873363, 0.0456657935199993, 0.015104437180395638, 0.05621066875755787, 0.009340362773010773, 0.002327490040832864, 0.05378786787124617, 0.04165045737421938, 0.08144276695592062, 0.033279852609017065, 0.01891467084975115, 0.061653523838945797, 0.044830086042306254, 0.030837041725005423, 0.0186717620984252, 0.008571803968931948, 0.02777377502726657, 0.06009428429284266, 0.026607810985296965, 0.02657717512920499, 0.05310750759339758, 0.03826171439141035, 0.0018866835827273981, 0.03866553772240877, 0.04205541725137404, 0.06704677122512034, 0.015093404200992413, 0.0994691557383963, 0.028494569206876413, 0.03444785225604262, 0.020765829731577208, 0.03791311702557972, 0.05970474412398679, 0.030112027057579586, 0.039340028672346046, 0.018313337849186997, 0.04978129839790719, 0.01705338652910931, 0.01601844759924071, 0.0213221588970295, 0.04475098242983222, 0.03878554681848202, 0.054286319695945294, 0.056559150772435327, 0.03959442502153771, 0.041937145204948525, 0.010126581299118698, 0.0934073342276471, 0.023015924795929874, 0.030078018882444928, 0.043729332608303854, 0.019609046268409917, 0.028884258653436388, 0.02245477633550763, 0.04578708843993289, 0.02730344169374023, 0.016154912865853736, 0.00853008424331035, 0.04585846353854452, 0.05393697254891906, 0.0632492753544024, 0.02903234552858131, 0.045626706510250054, 0.052840171581400294, 0.0660539794979351, 0.0705730566488845, 0.05219306969749076, 0.06793617457151413, 0.007145001735937382, 0.06398016613508974, 0.05081985052675009, 0.04321052473304527, 0.048332107053803544, 0.05089289482150759, 0.055390818643250635, 0.032049380242824554, 0.10017954797617026, 0.0028155159629282673, 0.031091570388525724, 0.0382818193840129, 0.05136405936043177, 0.015706073825380633, 0.08988110308668443, 0.030988280395311967, 0.034574439749121666, 0.03556581333811794, 0.06474353160176959, 0.025660136747839193, 0.07813255422349487, 0.06295932377023356, 0.032533813534038405, 0.016074555659932748, 0.01774961774104408, 0.050176548438944986, 0.04551763879135251, 0.006862097586105976, 0.017650612696473087, 0.011059851086299335, 0.08938771991857461, 0.060056170980845175, 0.022192235869754637, 0.07666988378124577, 0.022262715302141647, 0.08386021759361029, 0.05069519346579909, 0.013506076697792326, 0.05029624880158475, 0.025755492970347404, 0.019610410123797398, 0.03539623725893242, 0.07926671872181551, 0.008583325493548597, 0.0319124518760613, 0.03393574491409319, 0.0312940520234406, 0.0603372473269701, 0.034069107579333444, 0.08029366111648933, 0.038808993596051417, 0.027997320085497837, 0.034713396935590675, 0.009256741813650089, 0.05934347172400781, 0.0253517866866397, 0.05678411227251802, 0.004299149956620697, 0.04254338910271015, 0.030537017288484743, 0.02619746184375669, 0.020595939829945564, 0.02991926882948194, 0.03040104904877288, 0.01047155274344342, 0.04199713448594723, 0.05033514242885368, 0.031179505134267465, 0.02777751375521932, 0.016874092132119194, 0.0020953294962445007, 0.030372336839458773, 0.020058689372880117, 0.02155752233894808, 0.01766941150916474, 0.06601603581969227, 0.05249174384932433, 0.046759456263056824, 0.01381186698563397, 0.05360774735787085, 0.009438166810598756, 0.03307512163051537, 0.021171932940238287, 0.00771940961879279, 0.0658877994865179, 0.020438557025045156, 0.027216266907219375, 0.04398990701884031, 0.014040801308250852, 0.004120823744285319, 0.06528779132557766, 0.06481047586670943, 0.019295157665120702, 0.023956815379538705, 0.0353156205133668, 0.018750618045617427, 0.06911643873900175, 0.03241465260673847, 0.059327214024960995, 0.03317059490031429, 0.016923849105036685, 0.03262960232262101, 0.029507024878902093, 0.05407235724851489, 0.041435575511838706, 0.05422840333942856, 0.026478667111535157, 0.015081082005053759, 0.02602702402509749, 0.03589042788371444, 0.057638347148895264, 0.024154637175213014, 0.04691972623446158, 0.06354766112885304, 0.042065910795437436, 0.09776086240474667, 0.051644270574407916, 0.018444105117980922, 0.05062918557918497, 0.06345190626702138, 0.006316632190386632, 0.004581432822825653, 0.0017663644809675003, 0.053751885159207244, 0.03198629005679062, 0.016475797165185213, 0.01328889629803598, 0.006181616020122809, 0.010712665073307497, 0.08830159569957427, 0.007022978239027517, 0.03630327233778579, 0.08069247007369995, 0.027235267584079077, 0.040664037090859244, 0.03247542559568371, 0.02159052967493023, 0.004368276559814278, 0.0448521011109863, 0.07842228189110756, 0.06499546486884356, 0.020029312199247733, 0.05646240524947643, 0.07940345709877354, 0.03164814891559737, 0.009504797253092485, 0.020662527864000628, 0.021579342328810265, 0.07008921368313686, 0.04032539722642728, 0.047703532568578205, 0.05275678302028349, 0.04595342790707946, 0.003048242024046236, 0.02445604751950928, 0.0335134790012879, 0.01295207321111645, 0.07479311020246573, 0.031932902921523364, 0.0181995526155723, 0.03809676252837692, 0.06418404555214302, 0.02370266160661621, 0.04898566859109061, 0.024903979019394944, 0.017883389223633066, 0.00965753463762147, 0.05026824226869004, 0.027533953610275472, 0.01531974143082542, 0.0115097876571651, 0.038265894167125225, 0.05651391962809222, 0.038029017592115064, 0.008200729282439818, 0.03274531289935112, 0.016019395851929272, 0.01867966533505491, 0.09668140139962945, 0.016984996984579732, 0.019626835760261332, 0.046996105528835735, 0.008475535964992429, 0.038875931075641086, 0.021480674855411053, 0.02306019072420895, 0.035388383216091564, 0.016097142394366007, 0.0768847893923521, 0.04803295114210673, 0.010235607457746352, 0.024814459894384657, 0.04472827186275806, 0.04742971654715283, 0.03071427099140627, 0.034161038896335025, 0.04040073836222291, 0.04379345756024122, 0.08102257057492222, 0.0011427257018762507, 0.02211344099071409, 0.09135048424026795, 0.06462399408753429, 0.03503511752933264, 0.008878199849277735, 0.01718535310854869, 0.1292922015168837, 0.058423758218331, 0.009479902651427048, 0.01861759804056159, 0.07621633061873061, 0.06614351897899594, 0.04052307822608522, 0.011462455598770507, 0.04764889692887664, 0.07821302169135638, 0.01980379599678729, 0.023324831255844662, 0.10187042331589119, 0.05832297541201115, 0.03455619054979511, 0.018559264385008385, 0.07672458048909903, 0.030141329592359916, 0.024772049759381583, 0.0796746811164277, 0.023516458026798706, 0.037951623887888024, 0.06135005583720548, 0.019402376376092434, 0.03840098709666303, 0.025491831225476096, 0.10970512790871517, 0.041919577933315716, 0.032795602522258244, 0.018955483034785305, 0.010485624711561416, 0.062366467368389876, 0.013857428067629891, 0.05459970448698316, 0.007260781862506909, 0.013966464404282826, 0.12124597041734628, 0.014145947942909385, 0.02563975185954145, 0.012007794193258243, 0.019770479927371656, 0.059714705018060546, 0.04597702396235295, 0.05029207581122007, 0.07001863247049706, 0.014874542730727365, 0.04712676423202668, 0.08806276494371039, 0.011315113415808549, 0.03456363407894969, 0.0417317797962044, 0.03540013204993946, 0.006224442181909191, 0.04131226534289973, 0.023074102388428788, 0.017731158195861747, 0.03616061374279005, 0.050455623106764894, 0.022889688444722976, 0.011647487009343292, 0.03448710889954652, 0.04872109082394412, 0.02570198200243924, 0.03770905779674649, 0.045194791829479594, 0.06814840675464698, 0.14117334969341755, 0.1517883650958538, 0.19592963292130403, 0.07968367849077497, 0.10689855100853102, 0.08735423189188753, 0.12885228012289318, 0.13412288230444702, 0.09259385894984007, 0.16088789967553957, 0.11650758396301951, 0.1086502977247749, 0.12774713656732015, 0.13388405154858316, 0.10017137841454574, 0.10673205887100526, 0.08216538639473063, 0.08986969691302095, 0.09024601921971355, 0.19480185343750886, 0.144429992086121, 0.07701085441346679, 0.15510452858039311, 0.1533230213182313, 0.10474053823522159, 0.08026894887111016, 0.20714874805084296, 0.11007891249443803, 0.07574810752911226, 0.1303198699440275, 0.13524265507502214, 0.14652654315744126, 0.09432994507785354, 0.16852515057793685, 0.07312822953930923, 0.08928950875997543, 0.15196858399680682, 0.1216767994420869, 0.09053202851542405, 0.1466500229601349, 0.13397129758128098, 0.09979791274028164, 0.14189708871500833, 0.14111324506146566, 0.14514214172959328, 0.10689348235194172, 0.16251984424889088, 0.13957778816776617, 0.13083361594804696, 0.0820136388231601, 0.18959147802421025, 0.09181331976183824, 0.16322170730148042, 0.1306720839015075, 0.12315292523375579, 0.17046761991722242, 0.1566393476511751, 0.10032723790832929, 0.09259332290717534, 0.18978190209184373, 0.16599341428705625, 0.17097065863864763, 0.17450837737747601, 0.09233060771865503, 0.09450173657387495, 0.1454449583377157, 0.10941103726093258, 0.09767135006508657, 0.19675048387476377, 0.08433316328695842, 0.08277515188923903, 0.11660796643367835, 0.19184148657534802, 0.08483202901801892, 0.11782542110553809, 0.18105176197631018, 0.1248109255518232, 0.13989953590290888, 0.08942195201026541, 0.07888835402471678, 0.1523209743733917, 0.17357372253068856, 0.228644886719329, 0.09782006458512374, 0.08899074979126453, 0.16879864090255328, 0.13607677817344666, 0.10013619637382881, 0.19551696149366243, 0.10839463251509837, 0.12782754296702997, 0.10650189979267971, 0.13391322855438503, 0.21780968670334133, 0.14621434919536114, 0.10786742437630892, 0.11564621089824609, 0.14707306240286144, 0.10997973781611238, 0.19411808012851647, 0.11697833798825741, 0.16253437846899033, 0.18065492755600385, 0.051734722685068846, 0.11339395639619657, 0.2376661454992635, 0.18670246590461048, 0.0847053804567882, 0.08327151382608072, 0.0848778233464275, 0.19265673282955373, 0.18809743890804903, 0.06966907158493996, 0.11820907837578229, 0.18329297671360628, 0.24986748078039714, 0.0745048074583922, 0.11694883528564658, 0.29473699309996193, 0.11653315116252218, 0.10272410857890334, 0.13194251858762332, 0.20582958097968782, 0.12640990689396858, 0.10039602778851986, 0.1067620636895299, 0.1310695968568325, 0.13997792026826314, 0.16108003365142004, 0.15673906515751565, 0.08407023775258235, 0.13624615408480167, 0.12247626297175884, 0.10484935489616223, 0.1193403455295733, 0.08901126190487828, 0.11951827098216329, 0.10268578492105007, 0.1119063226506114, 0.17338678613305092, 0.1674554401210376, 0.1656995950532811, 0.0795872722353254, 0.13674143036561354, 0.13655731667365345, 0.0987480358619775, 0.17092751738216194, 0.10319720354995557, 0.1288584005087614, 0.07904147223702498, 0.048781558472130976, 0.16645342031759874, 0.15578686339514597, 0.10465506317892245, 0.22146833395319326, 0.21787664453898156, 0.09002252335527114, 0.18308738060295582, 0.11743767905448164, 0.09611555069152798, 0.18277627229690552, 0.10686297541750328, 0.14680812161947998, 0.12349509687295981, 0.10902742748813969, 0.07542737759649754, 0.1204916023250137, 0.2050966274525438, 0.08203704828130347, 0.12774788295584066, 0.15132867119141988, 0.11503586864897183, 0.08928089815058879, 0.10488323414964335, 0.12313080499214785, 0.17948821373283863], [0.022980763111263514, 0.044459690739001544, 0.010350710745634777, 0.04060324713853853, 0.01265985531998532, 0.07234734429844789, 0.022140512841620615, 0.04041663304503475, 0.03919352278379457, 0.042763685674539635, 0.028858219872095754, 0.01112052908034197, 0.06850511939930064, 0.03525475931486913, 0.030170788190194538, 0.018563832622021437, 0.06880291484828506, 0.08729286518480096, 0.01735590797449861, 0.041532053013465235, 0.014162499108351767, 0.034534999901162725, 0.09230671650064842, 0.02235210720183594, 0.021362412987010818, 0.033969264544014416, 0.0683698398726327, 0.07788281262453113, 0.06365102915359394, 0.020510493611384715, 0.04049928539565631, 0.020829579792916775, 0.05881936449025359, 0.03361697255500725, 0.012895199254022112, 0.02377377207657056, 0.07241331147296087, 0.0379653879707413, 0.047286186034658124, 0.04312853056139179, 0.04900573626426714, 0.08770131612462656, 0.04791869602299162, 0.02496403785023306, 0.05988182819315365, 0.0497396736671882, 0.005251830086178545, 0.08531777188181877, 0.04203787372846689, 0.022748661726447086, 0.0110318928990247, 0.024117626482620835, 0.00968933672577675, 0.10641923387135778, 0.033487603068351746, 0.018675775633060505, 0.014938241901940532, 0.02488027439851846, 0.03125097183510661, 0.006949464058769601, 0.02023196855692991, 0.052042764012834856, 0.03541997580655983, 0.0718420392700604, 0.035572747966008525, 0.01457937151592757, 0.03325979172119072, 0.02100271139560001, 0.10881226403372628, 0.006521945012666817, 0.0413130863702723, 0.026083262703780617, 0.009363424481957086, 0.014195259627220886, 0.0217540566144245, 0.014663932246289082, 0.017388679519561783, 0.012737032741175165, 0.01410724176093936, 0.01916150831883507, 0.012519056759109455, 0.030964470601507595, 0.04927450059247868, 0.01076991731367473, 0.016858701261558702, 0.07032632096005337, 0.017009877167376022, 0.018690766167959998, 0.049908259085246494, 0.01656858852532293, 0.025457437981718352, 0.05660475850371378, 0.03162537728037153, 0.015162506207291569, 0.03390559760321464, 0.02212105076094823, 0.019048530541892563, 0.027540026498692374, 0.0539590419004006, 0.15394325660807745, 0.036593020361449034, 0.018515181661184345, 0.02891133220068046, 0.05846985110214778, 0.03847385157964059, 0.03151618403249553, 0.049518210015126636, 0.038341713670108996, 0.019121244050828472, 0.021863466993506466, 0.01606537338479289, 0.04275512595527938, 0.04887060262262821, 0.03247400067214455, 0.026959183559353863, 0.01912336956177439, 0.002489024631878627, 0.03173470962792635, 0.07174502233309404, 0.020824158298117772, 0.029325313200908046, 0.04145629457863314, 0.11710407052721296, 0.026308594005448476, 0.03402031412614243, 0.021557113521599343, 0.05244109799553241, 0.021981895102986267, 0.016088760790548155, 0.08415872550436429, 0.030362036677875688, 0.021574190551681176, 0.07024336326867342, 0.023644546778606515, 0.03882457615275468, 0.03853454653705869, 0.07232993987521955, 0.023352379777601788, 0.04479789294834648, 0.02530212131594973, 0.017592246810506498, 0.05540433166814702, 0.025526906396927576, 0.06454337055661849, 0.03538402023592165, 0.042872655005859475, 0.03801471407392195, 0.045628711581230164, 0.019624469369383793, 0.08168254766081061, 0.006967502488155982, 0.051882395653852394, 0.02759799374533551, 0.058236373987581046, 0.056187255906739404, 0.022832801765097038, 0.03183040342160633, 0.04772318294271827, 0.014001688853438412, 0.010036127492120224, 0.04110326977180583, 0.03670105331444314, 0.032998213078826666, 0.05648974342537778, 0.04946558623175536, 0.027190117863938212, 0.04803890867957047, 0.02172945802366095, 0.07326341407107455, 0.06643084463264261, 0.03876486846378871, 0.03662887754450951, 0.016138119124142185, 0.023004467732139995, 0.11454949474760465, 0.019611723089058484, 0.004018388705195061, 0.03779755233387862, 0.03981998363243682, 0.026940316893160343, 0.01688761024602822, 0.023145487665065696, 0.017728874925523996, 0.009513817527996642, 0.03854544720213328, 0.09434615527944905, 0.04342087058882628, 0.06450599684779133, 0.05749366991221905, 0.08321717674178736, 0.037608729608889134, 0.02263128704258374, 0.052090427705219815, 0.09546900859900884, 0.008831849122153861, 0.09613092629505054, 0.015436101704835892, 0.040391632422272644, 0.03070402511262468, 0.015665809557374035, 0.005566669062578252, 0.03509902535006404, 0.006512491747603885, 0.03763168444857001, 0.01436489338188299, 0.004766895103135279, 0.04735577319349561, 0.012633838591032794, 0.04576877138710447, 0.04054625019697206, 0.03173364093527198, 0.01141419988458178, 0.0674695528245398, 0.014633881626650691, 0.017424613037811856, 0.025388363116819943, 0.03911468379997781, 0.016317857961569513, 0.024359939819467918, 0.007064678032682943, 0.04050161616344537, 0.007975795771926641, 0.04313989941562925, 0.01617443940735289, 0.055104799169514856, 0.04539840661787561, 0.03338809930054205, 0.019163323400009955, 0.04408531243513737, 0.042000734114221165, 0.04487957838656647, 0.00809536551657532, 0.04348640689360244, 0.07654604435499225, 0.05489335747967873, 0.009958624374121428, 0.021914000889020305, 0.022561961119728427, 0.03701985960028001, 0.049667117917644124, 0.02962657596383776, 0.021626507297956517, 0.02680833843935813, 0.015054449505571808, 0.023385751826156462, 0.024694835866934488, 0.024759225447529128, 0.0894288391407047, 0.04798520263284445, 0.038339542358049324, 0.029488124285957644, 0.003631491430236825, 0.0287591469740229, 0.04760117216834, 0.01761799382178911, 0.017730732415137545, 0.05304901448211499, 0.017542898654937744, 0.03277441865897604, 0.05410117802343198, 0.026656977632748227, 0.11011295459632363, 0.018904358813805238, 0.0656590246196304, 0.04751274548470974, 0.01605185866355896, 0.060787380672991276, 0.02082330164765673, 0.027616743364238312, 0.010244525952397712, 0.025920012267306447, 0.026430630224889944, 0.014875903193439757, 0.031138192529657056, 0.04713871662638017, 0.06812317882265363, 0.038742446274097474, 0.009894162699181055, 0.018326392862945795, 0.047211995015719106, 0.031392069799559455, 0.024970872394208397, 0.016468930390796492, 0.048824828650270186, 0.010951029336346048, 0.07322987408510276, 0.003406661396313991, 0.024053596525586078, 0.027851567370817065, 0.023850560188293457, 0.0486931385738509, 0.0088785314832681, 0.02315998456573912, 0.015919481570433294, 0.054976386417235644, 0.011823035044861692, 0.04520811147189566, 0.018289964014132108, 0.05231814405747822, 0.03636005554082138, 0.031671602478516955, 0.007275697758554348, 0.02933598994942648, 0.04188960364886692, 0.039668527830924304, 0.10204583818891219, 0.009423670758094107, 0.04683369817212224, 0.04069317338456001, 0.02647393093710499, 0.04888834631336587, 0.05905345907168729, 0.04520465772865074, 0.03418496743376766, 0.05073883005284837, 0.06344284103917223, 0.014648889124925648, 0.013504262464786214, 0.028601726849696467, 0.0589031974918076, 0.02895109774544835, 0.05296775991363185, 0.01964213672493185, 0.05983363863612924, 0.02323943592741021, 0.041272462478705814, 0.052686975337564945, 0.07087525579013995, 0.016684414453006217, 0.02818998501503042, 0.022719730689589466, 0.0074525536703211916, 0.04026471244703446, 0.024147668620571494, 0.023744903804202164, 0.032171221383448155, 0.06650900508144073, 0.015848840985979353, 0.03266179541658078, 0.04868801224178501, 0.057250727234142165, 0.0493245934402304, 0.03763820177742413, 0.05873877488608871, 0.07608677792762007, 0.03359103894659451, 0.0425667544560773, 0.03226744443444269, 0.06351807700203997, 0.02470095455646515, 0.013148113004198032, 0.008320298178919723, 0.18231428494410856, 0.2083884043885129, 0.09911046855683837, 0.07348888447242123, 0.1190866684275014, 0.1433315931686333, 0.1104237779176661, 0.08352178468235902, 0.1475820993738515, 0.13929591115031922, 0.16575177439621516, 0.08185967244207859, 0.16895086344863686, 0.16495768486389092, 0.1891633224274431, 0.13723130550767693, 0.16194702498614788, 0.18523389899304935, 0.08775909338146448, 0.2265626120248011, 0.0974683595289077, 0.11973412654229573, 0.1737004593014717, 0.08511833686913763, 0.1687676589936018, 0.17901846393942833, 0.10444513122950282, 0.1250687688589096, 0.11945218167134694, 0.05065358569845557, 0.19535401809428418, 0.096000572932618, 0.11468974793595926, 0.12116059714129992, 0.14309728145599365, 0.089234296365508, 0.16328234119074686, 0.07316315373671906, 0.11023286530481917, 0.13206282284642967, 0.13536606702421392, 0.12053722701966763, 0.09507908845054251, 0.08356740259166275, 0.2068453479026045, 0.10961486239518438, 0.11969166382082871, 0.139341820829681, 0.1905737660293068, 0.20015149137803487, 0.09979732920016561, 0.11317719159913914, 0.1046057879658682, 0.19372119142540864, 0.13263484143785068, 0.0932688180889402, 0.07825110786195312, 0.20241876186004706, 0.08854508799101625, 0.09446880726941995, 0.1151935737580061, 0.13261721309806618, 0.10319637573723282, 0.15712873424802506, 0.08368202751236302, 0.08597145894808428, 0.1734466329216957, 0.13878768842135156, 0.1827673834881612, 0.12297718466392585, 0.11679581206824098, 0.1691225463790553, 0.07505949626543693, 0.14922507692660603, 0.1345833090267011, 0.13710374092417105, 0.1420662882072585, 0.12445236050656863, 0.16321701183915138, 0.12313383125833102, 0.13157769744949682, 0.08230344791497503, 0.107188835074859, 0.09565114775406462, 0.12714381037013872, 0.13849737042827265, 0.12977633625268936, 0.17598683732960904, 0.1256245704633849, 0.1159118302166462, 0.14698726843510354, 0.14742147656423704, 0.12201654192592416, 0.10687951810125794, 0.15114828944206238, 0.13334495547626699, 0.15950827513422283, 0.06415486176099096, 0.15232792257198266, 0.22599830159119197, 0.11193959800792591, 0.12088431125240666, 0.15344973094761372, 0.12825078597026213, 0.09474370894687516, 0.08587349206209183, 0.1406644077173301, 0.15840923839381763, 0.108884697646967, 0.1268497740051576, 0.09972621194486107, 0.1271360750709261, 0.1452179340911763, 0.13693916904074804, 0.08417826052755117, 0.12377351336181164, 0.06705028603651694, 0.09996123611927032, 0.17501066971038068, 0.09768316335976124, 0.17540879334722245, 0.18460199290088244, 0.2101860607841185, 0.13406076920883997, 0.13040837805185998, 0.18396164583308355, 0.1372847469257457, 0.14283909888139792, 0.12741185884390557, 0.21310366636940412, 0.10389586391725711, 0.0993624764627644, 0.15526996898863996, 0.09103892810110535, 0.11398057027586869, 0.21557981707155704, 0.17224615519600256, 0.10431364471358912, 0.11147599574178457, 0.17225724245820725, 0.17358717109475816, 0.1506804802588054, 0.04342560337058135, 0.1185088280056204, 0.14071962689714773, 0.1720827775342124, 0.11866312686886106, 0.14137840297605309, 0.14981025909738882, 0.1436547522566148, 0.1171902987573828, 0.20625308182622704, 0.10791285908115761, 0.12596963266176836, 0.1007834237867168, 0.10889575776777097, 0.19279979515288556, 0.13673388505620615, 0.072847906367055, 0.10275850351899862, 0.11400510610214301, 0.07014042272099427, 0.14541655486183508, 0.11533685321254389, 0.141396519861051, 0.1323268815342869, 0.17504983475165709, 0.12590632534452847, 0.13484795125467436, 0.14137427748313972, 0.13471924673233712, 0.05870172008872032, 0.14677810323025497, 0.12949401140213013, 0.15999578897442135, 0.11050371612821307], [0.007863380330880838, 0.08669888920017652, 0.03761950135231018, 0.062403997140271325, 0.02870380226522684, 0.0426216784731618, 0.03073284249486668, 0.06159780254321439, 0.010463786910154989, 0.03323468253282564, 0.08429920260927506, 0.05037279772971358, 0.03016483743808099, 0.0968907769503338, 0.050127510713147264, 0.01965094410947391, 0.02515701829854931, 0.03513928622539554, 0.0409322416276804, 0.0428444788392101, 0.07012387325188943, 0.13456615566142968, 0.03141043434983917, 0.04716640424781612, 0.01133967807982117, 0.042358084581792355, 0.020694212056696415, 0.029834716580808163, 0.026898773586643592, 0.03772041986563376, 0.10104971485478537, 0.05852144690496581, 0.044488335094813786, 0.017620355123654008, 0.045024435435022624, 0.02900748739817313, 0.02029192560751523, 0.016159842422764217, 0.03851540506418262, 0.04930913641250559, 0.07853423338383436, 0.02358978391358895, 0.06639646326324769, 0.03089431008057935, 0.04887179684426103, 0.027373931304152523, 0.03995345486328006, 0.045792723673262765, 0.03424155725432294, 0.047475188571427546, 0.034701498824038675, 0.03088689030015043, 0.023761231053088392, 0.011271755028116916, 0.02490120381116867, 0.09797197500509874, 0.05329247284680605, 0.023408918708030666, 0.04272661730647087, 0.04527318637285914, 0.02351777608107243, 0.03993799105020506, 0.017186326806300452, 0.04487417046246784, 0.05307595571503043, 0.027355816115492156, 0.05771799358938422, 0.057676229758986404, 0.0459424627811781, 0.028310759159337198, 0.011308021028526127, 0.03601219777816108, 0.03611568793920534, 0.011915986708897566, 0.06613534941737141, 0.03518553177959152, 0.023139221394168477, 0.07401793822646141, 0.032460351940244436, 0.052323019331587214, 0.048356052554611645, 0.05147222462775452, 0.02889239089563489, 0.039686098495232205, 0.028051541818838035, 0.03398542046280844, 0.030575378265764033, 0.05637475209576743, 0.03602364127125059, 0.025220150893021907, 0.04377044165240867, 0.009155171058539833, 0.014361096978453653, 0.023469074230108942, 0.040501039408679516, 0.024931804044172168, 0.03619338359151568, 0.03382816657956157, 0.06035991718194314, 0.06399674274559532, 0.014185102806160492, 0.013446825323626399, 0.01473108007173453, 0.010323261459624129, 0.07577389864517109, 0.008579605425308858, 0.030491392593830824, 0.03681104723364115, 0.06223235492195402, 0.011523622986195343, 0.028014746561114277, 0.030951344341571842, 0.027932285896635482, 0.04695933910885027, 0.022564765165692995, 0.03180161318076508, 0.02644582771297012, 0.008599295663381261, 0.033121645384069, 0.020295174093917012, 0.017074202287143896, 0.062135860456952026, 0.0494299699286265, 0.10334548380758081, 0.021304430473329763, 0.006421079085807183, 0.07852128693567854, 0.04918942926451564, 0.03694239125720092, 0.07304787742240088, 0.04045936039515904, 0.04241409764758178, 0.07053188314395291, 0.0338384938825454, 0.05797952812697206, 0.03553819017750876, 0.04326642584055662, 0.011581107624806464, 0.01449101438213672, 0.018257591108392392, 0.03252933520291533, 0.019116397614457777, 0.02632197641235377, 0.028935983377907957, 0.015262754667284233, 0.009825591646533991, 0.04761138412037066, 0.04260082369936364, 0.029807154488350664, 0.03147042363083788, 0.01915522338822484, 0.04111815343743988, 0.008637690567411482, 0.03365410877657788, 0.100290332388665, 0.0742408437654376, 0.009204157046042383, 0.031019560859671662, 0.007391454136398221, 0.028771696479192803, 0.04569808839421187, 0.025029209442436695, 0.04227050267426031, 0.024276552954688668, 0.045729246722268205, 0.014273060452459114, 0.031501303759536574, 0.03590566099488309, 0.017654831487951533, 0.07270336483738252, 0.023689910237278258, 0.03582338523119688, 0.018244902503543665, 0.06988313581262316, 0.06154487681175981, 0.058068531565368176, 0.028986306927566017, 0.053370735075856955, 0.03742231568321586, 0.04013897990807891, 0.021217935918165103, 0.02617011179349252, 0.05058766941406897, 0.008907348865510097, 0.03396059625915118, 0.05641542009211012, 0.03382550332961338, 0.041638647472219806, 0.033309972778494866, 0.03376771589475019, 0.018445533434195176, 0.0659101911421333, 0.012628747882055385, 0.038659329126988135, 0.047511503765625615, 0.0312298931447523, 0.010349294303783348, 0.03271229877801878, 0.014476643010441746, 0.023319311373467957, 0.03825091550658856, 0.04686259697856648, 0.040804191891636164, 0.04966616118326783, 0.06474312448075839, 0.06254610272922687, 0.07667337145124163, 0.03160031219678266, 0.06289084601615157, 0.02026555434401546, 0.05803314596414566, 0.033217875220413716, 0.03591533690424902, 0.03266011604240962, 0.017370033377249326, 0.04391894582659006, 0.017336844533149685, 0.07803301313625914, 0.0400669941279505, 0.03920369063104902, 0.053295546610440524, 0.01883022377400526, 0.04173406306654215, 0.017701775933216726, 0.04032510545636926, 0.06230539921671152, 0.0366031305332269, 0.023567906248250177, 0.06641249026038817, 0.04524510520111237, 0.050694799915488274, 0.006915819748038692, 0.013446439406834543, 0.022188775341159532, 0.022767781146935055, 0.038551031545336754, 0.03371980792975851, 0.030094415681170564, 0.019473386762131537, 0.007543967604371054, 0.10071468818932772, 0.020066129509359598, 0.06888891916189875, 0.010184066785898591, 0.020786104357934425, 0.0192305730057082, 0.01817364275588521, 0.04617546831390687, 0.02331135215769921, 0.029662514571100473, 0.056139588821679354, 0.04165949546066778, 0.035895513503679206, 0.004406862301818494, 0.021590526282255138, 0.020419429122869457, 0.007503168990037271, 0.0376375130643802, 0.011830413265020719, 0.019202456210872958, 0.03117735417825835, 0.038257585505821874, 0.004034913153321083, 0.007663076793375824, 0.05124793487734028, 0.04140322635482464, 0.07864026126584836, 0.058352057422910414, 0.03824222008032458, 0.015831092206229056, 0.04921377510098474, 0.04099810362926551, 0.050577504959489615, 0.03959189747859325, 0.03652446796851499, 0.04873670391472323, 0.012521824333816767, 0.024790443147399595, 0.03343392416302647, 0.046624478684472184, 0.06373043132147618, 0.03016172635502049, 0.030707621348223517, 0.05457317037507892, 0.05701309069991112, 0.0699854249666844, 0.025589265461478914, 0.018984836459692036, 0.013401118356601467, 0.055577127395996025, 0.03539389292044299, 0.062314233742654324, 0.06682773333575044, 0.022782915870526006, 0.028122287576219866, 0.014875094040430017, 0.011921500654092856, 0.11613821664026805, 0.05783765323992286, 0.05426229277093496, 0.04874963679217866, 0.022158556784104024, 0.08407296546335731, 0.06985681543924979, 0.019795078518135206, 0.08778244855680636, 0.04833415622955986, 0.03731282387993165, 0.04836410676528301, 0.04071336658671498, 0.0456244741300387, 0.04651364677452615, 0.04124315994392548, 0.02346072655304202, 0.02853887075824397, 0.01164683307121907, 0.024774847019995962, 0.034294890106788704, 0.038731392938643694, 0.09288972735937152, 0.013463146635331213, 0.0374406700554703, 0.08515916432120971, 0.03547204319121582, 0.03082160505333117, 0.014298644615337253, 0.008650333371146448, 0.04958470644695418, 0.06802472339144774, 0.017651114812386886, 0.053970112199229855, 0.03252837507586394, 0.02580117534047791, 0.040999521767454486, 0.07970910998327391, 0.05933185520448855, 0.05031076266563364, 0.07847559438752276, 0.03748545675937619, 0.09023883353386607, 0.032427032478153706, 0.02975712270875062, 0.07525846987430539, 0.04120018832119448, 0.057116404441850524, 0.05239593470469117, 0.016009535041770766, 0.013440101889760366, 0.06537222143794809, 0.02654423055771206, 0.0214928257212575, 0.021831553795241883, 0.1370822177933795, 0.18875279517046042, 0.15225207592759812, 0.15937274454959802, 0.12104097141751222, 0.14155938183622702, 0.13569259164588793, 0.056865743427936516, 0.05938552732446364, 0.08036117535084486, 0.19369010095085415, 0.14183635983083928, 0.1343516707420349, 0.1451391154634101, 0.12381180987826415, 0.23501217791012355, 0.11026956047862768, 0.11577594679381166, 0.1068247671106032, 0.13093502979193414, 0.1313685051032475, 0.25385704955884386, 0.2124509292521647, 0.09037751252097742, 0.12092779177640166, 0.14135592989623547, 0.10558683425188065, 0.14400909681405338, 0.16837839702410357, 0.13034770345049246, 0.1831557090793337, 0.08752254928861346, 0.1485157771302121, 0.08283790280776364, 0.12402066295700413, 0.2002692986279726, 0.09319799938904387, 0.08101588700498853, 0.1585943970297064, 0.09257804229855537, 0.24323368817567825, 0.13699927367269993, 0.0970083060009139, 0.12576007390660898, 0.13468662276864052, 0.10572411545685359, 0.10725968770150628, 0.09611265334699835, 0.09907278272190265, 0.19281005460236753, 0.16081809199282102, 0.07405396165060145, 0.16174763068556786, 0.12498722252036844, 0.11296012146132332, 0.12312591954001359, 0.14010757473962648, 0.1952161533491952, 0.15180911469672406, 0.1947915397052254, 0.0944895093728389, 0.21212212475282805, 0.11276304775050708, 0.10418076041553702, 0.25240517460874146, 0.10322648233601026, 0.13549387588032655, 0.10929756584976401, 0.13431113506002085, 0.09483364197824683, 0.1277570431785924, 0.1545193056975092, 0.10372057796588965, 0.13826598998691353, 0.2373612118618829, 0.0981758204954011, 0.1931164674460888, 0.14054389989801816, 0.09684332699647971, 0.12832888535090856, 0.13110528779881342, 0.05806633989725794, 0.08801428361662797, 0.11462790625435965, 0.09509568541709866, 0.12390428063060556, 0.08850934955158404, 0.10338915432138102, 0.10371717850544623, 0.12295021968228476, 0.17926349650536264, 0.13224381527730397, 0.09950704513383762, 0.08046739322266408, 0.09153424509401832, 0.12692883690553053, 0.12590946017631463, 0.13465245174510138, 0.23383736237883568, 0.12960841240627424, 0.09116735442408494, 0.06559252818780285, 0.10357194487005472, 0.1802153182881219, 0.17715956297303947, 0.09765844432903187, 0.10498287701713187, 0.15329431928694248, 0.11351737513073853, 0.20612220599183015, 0.08003761592720236, 0.12707356842500822, 0.11394388867276055, 0.17465899858091558, 0.1266908339623894, 0.15798382407852582, 0.11629016777234417, 0.13800969373966965, 0.14328385144472122, 0.04704596767468112, 0.11040110127734286, 0.23057423319135392, 0.1347362236785037, 0.23711810633540154, 0.12583700620702334, 0.14497359363096102, 0.12381342479160853, 0.13386548683047295, 0.12591258143740042, 0.24366691921438488, 0.16269681975245476, 0.13433527733598435, 0.1277647241950035, 0.18733716756105423, 0.13315340504050255, 0.1242690339152302, 0.1333691927471331, 0.1075970892395292, 0.07450689056089946, 0.08107639197260141, 0.2564004702227456, 0.1497237187411104, 0.097731475053089, 0.1763032924916063, 0.15778307270790848, 0.04233682947233319, 0.16438049583562783, 0.15049380170447485, 0.10370054761213915, 0.20534175501338073, 0.12591209289218697, 0.2236443143337965, 0.1857359063412462, 0.06526567786931992, 0.17515769467822143, 0.12067490177495138, 0.1400298960506916, 0.11957612287785326, 0.09604439272412232, 0.1234767357153552, 0.16549965792468616, 0.14099051164729254, 0.12039679741220814, 0.16052121935146196, 0.1503384578973055, 0.09472249115684203, 0.10667638507272516, 0.11292403696903161, 0.1631064513432128, 0.19994371038462433, 0.14344090516013758, 0.12727239275617258, 0.1378115750849247, 0.15639021673372813, 0.16518379987350532, 0.13648362777062825], [0.02021402300202421, 0.025190258032775352, 0.012593940731936266, 0.06736667334501233, 0.019788662969533886, 0.05160860677382775, 0.035234515222587755, 0.03519052919000387, 0.06016740322645221, 0.029730401999716247, 0.024356185824477246, 0.0535147948456662, 0.02179834120241659, 0.05267392032380615, 0.04906460256980998, 0.0333644761038678, 0.03512671636417508, 0.059172284124153, 0.019525474502838085, 0.023879318198721324, 0.026779000281489322, 0.009945676229628069, 0.04372924779142652, 0.019846428352008973, 0.03356911887281707, 0.031411523398544104, 0.01410115699815963, 0.01752596750988492, 0.03716477432421275, 0.028024210428286876, 0.017172974933471, 0.02816790039651096, 0.026108695892617106, 0.07419522585613386, 0.041105013606803756, 0.03491906089974301, 0.05733480450830289, 0.01545539075907852, 0.02469120400824717, 0.05818250509245055, 0.03168852514188204, 0.015896497893014123, 0.04998560529202223, 0.058058502817792554, 0.010202366875351539, 0.0324182488423373, 0.0356308984171067, 0.01865078858099878, 0.021297115865828734, 0.03202988932441388, 0.05356882319652608, 0.03474876557343772, 0.04871560826099344, 0.022197733699743236, 0.03027642930724791, 0.03386770820777331, 0.011646618484519422, 0.05243763068158712, 0.008492434879631867, 0.037531807486500056, 0.01850455241011722, 0.04796143355114119, 0.011057959669934852, 0.03053154829623444, 0.03747554336275373, 0.020993352701355304, 0.051041884148227315, 0.027380572465647544, 0.04087336853678737, 0.0369198605019067, 0.06176966867808785, 0.04858859668352774, 0.06365996545978955, 0.018005143851041794, 0.03854279413021036, 0.04577486123889685, 0.034121843320982795, 0.033987296612135, 0.010830718292189496, 0.04522228267576013, 0.013742368884517677, 0.01510725649339812, 0.006956704875587353, 0.018059823595519577, 0.01954520121216774, 0.053691122348287275, 0.04917414187054549, 0.042398155467318635, 0.014508330595812627, 0.05318339494988322, 0.018923924371067966, 0.0271736311593226, 0.055183780645685535, 0.047612914216837714, 0.013552342608038868, 0.033826714514621666, 0.09589774773589202, 0.02438537809731705, 0.056538139935582876, 0.034283833378659825, 0.035698290515158854, 0.0681807321629354, 0.020695742153163468, 0.03617042535915971, 0.06058987269976309, 0.01485213071906141, 0.058121681213378906, 0.02962693219472255, 0.0028163891526803908, 0.07716568931937218, 0.023810796339863112, 0.017298383471955146, 0.021205932633685212, 0.029351684464407817, 0.03750925298248019, 0.045040140128029246, 0.051867454312741756, 0.07164721151015588, 0.01953742011184139, 0.03509173109861357, 0.0412679502208318, 0.028174517809280326, 0.02419039766703333, 0.008161377644033303, 0.04204911705372589, 0.013555764969039177, 0.0025490978815858917, 0.02084075696101146, 0.02309368151639189, 0.027913860278204083, 0.025286991681371416, 0.03924142735611115, 0.020915904714326774, 0.041861922812781165, 0.03676201290051852, 0.047840382903814316, 0.018467512879786745, 0.038012759893068244, 0.010392891026900282, 0.05168840588469591, 0.059109662127281935, 0.04251121636480093, 0.0251508249701666, 0.030066202195095162, 0.015420576823609216, 0.017649445616241013, 0.03759864657851202, 0.045915609757815085, 0.03289837343618274, 0.024531906038256626, 0.023652119229414632, 0.01069965077164982, 0.014307373968352164, 0.03049732298989381, 0.03744424932769366, 0.041450130087988715, 0.020703626730080162, 0.005819537011640412, 0.025681668360318457, 0.041699203329959085, 0.04362338275781699, 0.019238276074507406, 0.03163594885596207, 0.02351469044307513, 0.026641934511384795, 0.01631839570057179, 0.01193211633445961, 0.02420784280236278, 0.061860144537474425, 0.047956405606653006, 0.04159729076283319, 0.017412545292505195, 0.014541527921600001, 0.0027808377344626933, 0.006407962579812322, 0.023277457637180175, 0.031836975033261945, 0.031126219779253006, 0.044887652953288386, 0.031221041655434028, 0.08999597906534161, 0.02630602744674044, 0.04738809181643384, 0.08635227315660034, 0.034867078331964355, 0.06632325612008572, 0.011585344227829149, 0.015211160560803754, 0.02225625904143921, 0.018117760308086872, 0.00981767229469759, 0.0648499530340944, 0.032052016351372004, 0.05510169826447964, 0.0056557450194044834, 0.04682053459276046, 0.04157763360334294, 0.021066022105515003, 0.026750084511669617, 0.03383766267714756, 0.01840933189461274, 0.04325113844658647, 0.01722878952776747, 0.01298627900957529, 0.026528793886037808, 0.014282247816611613, 0.01411216368433088, 0.009767637122422457, 0.024368041527590582, 0.05209567278091397, 0.01495674385556153, 0.02086438694303589, 0.08367554071758475, 0.0316656551190785, 0.034871119008000405, 0.03392345664490547, 0.08502800350210496, 0.02545234896907849, 0.06009108839290483, 0.04711077455431223, 0.008595733354533357, 0.07368920158062663, 0.007564901257865131, 0.020790484301479797, 0.011362166426676725, 0.023436562224690403, 0.055581785538899045, 0.025835948563846092, 0.047281602530607154, 0.03431014357400792, 0.023754309995898178, 0.04824657092935272, 0.0351438256246703, 0.028624318673142364, 0.008750391841333891, 0.07648825352745396, 0.02670410867514355, 0.052416012555892975, 0.051994191083524904, 0.034826746210455894, 0.029694690701684782, 0.04461900058335491, 0.03066118241154722, 0.03151405343253698, 0.024804824697119848, 0.06900115563933339, 0.017745709379336665, 0.03191884367593697, 0.023525974480435252, 0.022822533833927343, 0.041750890735004625, 0.006127714894578925, 0.054907192808708975, 0.05273495454873357, 0.03009900257789663, 0.022900799455653344, 0.03409044411299484, 0.03447606574211802, 0.037748575676232576, 0.047298610010849576, 0.012399399653077126, 0.015886657438906174, 0.019639970501884818, 0.01827277841844729, 0.041333584913185666, 0.0341796239704958, 0.06907391494938306, 0.0198823601739215, 0.05552380811423063, 0.05386570601591042, 0.03380625329113432, 0.047795294251825125, 0.11595607069986207, 0.05805439089557954, 0.04339541195492659, 0.03725795753832374, 0.05576199765450188, 0.07843454301889453, 0.04872577950092299, 0.02445627313240298, 0.02987081803647535, 0.030801686657858745, 0.03930829019684877, 0.015023179219237395, 0.019522505912131498, 0.008270469111656504, 0.06578809555087771, 0.0458381889121873, 0.03163805909987007, 0.03756255530087011, 0.037662198168358633, 0.010554131303381706, 0.03055907306926591, 0.06287484616041183, 0.04550327420500772, 0.019621897721663117, 0.07074402711753335, 0.02340612653642893, 0.030967367946037223, 0.0433489187354488, 0.017570209689438343, 0.033161363431385586, 0.04326209339446255, 0.037158908388976536, 0.10115866722272975, 0.04430808226710983, 0.032378710606800656, 0.0688045569030302, 0.07165356938328062, 0.03546187873663647, 0.10625133716634341, 0.03307899606547185, 0.02247873371067856, 0.014535315933504274, 0.0177882128129048, 0.051137703470885754, 0.021761679955359017, 0.008818402254421796, 0.02033423226592796, 0.009847289500092822, 0.03212215651624969, 0.005425666093028018, 0.024859076964535883, 0.02959339220875076, 0.0622372335887381, 0.03274593036621809, 0.013757322099991143, 0.03842184865581138, 0.0519731090004955, 0.0651276231344257, 0.0207906335791839, 0.05698221057121243, 0.018184383965230415, 0.005231233579771859, 0.019626223382407, 0.01508440513030759, 0.06471563702715294, 0.025794741132163575, 0.02863733976015023, 0.036718905570783784, 0.025610556194026555, 0.0472695313926254, 0.03072798757680825, 0.022002924599551728, 0.047973223097090206, 0.026332235861835734, 0.07652032787778548, 0.057127539201506546, 0.042565047940505404, 0.017500958405435085, 0.020848132636664168, 0.03868089636255588, 0.08224247475819928, 0.1121806815000517, 0.1183201681290354, 0.1112836989174996, 0.19447783939540386, 0.11720423586666584, 0.08785503823310137, 0.2495515820171152, 0.09749879182449409, 0.11187715243015971, 0.18764505961111613, 0.06797791804586138, 0.10211280959525279, 0.17681718777332986, 0.11554698193711893, 0.21481535237814697, 0.13219421436744078, 0.1787053064576217, 0.13348575149263653, 0.21697249662663254, 0.13005832183573926, 0.05244277736970356, 0.12346791476011276, 0.12048651331237384, 0.1613621956535748, 0.1397886225687606, 0.06645878670471055, 0.12603137934846537, 0.09258665290794202, 0.08303016570529767, 0.09485632540392024, 0.11172969319990703, 0.13915309309959412, 0.24496731800692423, 0.16968142853251525, 0.0885890367041741, 0.11676215673131601, 0.09789690189063549, 0.12969191292566912, 0.13502658238368376, 0.15047336422971316, 0.13316609364535126, 0.1450641102024487, 0.08636194228061608, 0.09503568256539957, 0.15898378113550798, 0.10699666717222758, 0.1309819029910224, 0.11683105517710958, 0.13139981270900794, 0.1856338411037411, 0.11958839079099041, 0.1580089705863169, 0.11350797063538007, 0.11003475343542439, 0.19405869474368437, 0.08571177002574716, 0.15919271563845022, 0.08803249549652849, 0.11464109697512218, 0.12278961044337068, 0.13463847392371722, 0.1307759676128626, 0.10221341598246779, 0.12802378886512347, 0.07595117948949337, 0.12330290861427784, 0.17856778098004206, 0.11675185656973294, 0.12465552746185235, 0.12142449298075267, 0.09818146590675626, 0.10455122696501867, 0.08685491154236452, 0.1288138750408377, 0.2533280093755041, 0.2160662995385272, 0.08998295119298355, 0.12301829031535558, 0.15180315715926035, 0.11610389633902482, 0.10703196456389767, 0.20236400408404215, 0.11658972741237708, 0.08609187177249364, 0.15139623970857688, 0.07811909208872489, 0.1648726508553539, 0.08273758819060666, 0.1426820723073823, 0.0858140184677073, 0.13594867076192582, 0.1879958893571581, 0.1398924384266138, 0.092846810019442, 0.176988422870636, 0.22213770874908992, 0.11842650813715798, 0.11556295465145792, 0.10304603273315088, 0.1633655431547335, 0.266738412635667, 0.10113822296261787, 0.10497403570583888, 0.16436229752642767, 0.1375324529196535, 0.15659100881644658, 0.16489323760781968, 0.05947223731449672, 0.24667489209345408, 0.18816420675388404, 0.13013757472591742, 0.09384714705603463, 0.07991837696837527, 0.15676520232643398, 0.15821497381797858, 0.11960179864295892, 0.13864994581256593, 0.1071742737133588, 0.1263174225709268, 0.15998012838619097, 0.09008480608463287, 0.1037375752681068, 0.14929309327687534, 0.25673610078436987, 0.0841132365167141, 0.1767558753490448, 0.07261207473597356, 0.13486206478306226, 0.16031072421797685, 0.1342602585043226, 0.11273606241281543, 0.17498944513499737, 0.06919145078531333, 0.19622801191040448, 0.14549975682582172, 0.07746117774929319, 0.15979176706501416, 0.11010596568563155, 0.17510019562074117, 0.09072713447468621, 0.11689660165991102, 0.13759441673755646, 0.053532389258699756, 0.11464505961963109, 0.08350781364632504, 0.18426180258393288, 0.12992228913520062, 0.11609052919915744, 0.1036004161994372, 0.08071646307195936, 0.09589840591486011, 0.14574602432549, 0.11764223022120339, 0.134872826348458, 0.18309322957481655, 0.13190540272210324, 0.08344444526093346, 0.07618253278945174, 0.12784172434891972, 0.1339240986853838, 0.23709620322499955, 0.09093952272087336, 0.08185391167977027, 0.11022019027067081, 0.131427686927574, 0.0966554202937654, 0.08098102387573038, 0.11920252149658543, 0.13452931120991707, 0.16858017976794923, 0.08728008158504963, 0.18765861674078874, 0.14779304234044893, 0.10014332777687482, 0.10688559777502503], [0.03211610737655844, 0.023678303895784274, 0.023190832464024425, 0.039541824986892085, 0.03473589376413396, 0.08721952233463526, 0.06851373679403748, 0.029847683385014534, 0.054481293340878825, 0.03522757380934698, 0.05632723089573639, 0.029529491173369542, 0.0650547824001738, 0.06885876506567001, 0.10494969665471997, 0.04863811277651361, 0.08285477797367743, 0.025692809905324663, 0.013594681496864982, 0.01244632713496685, 0.03939655063939946, 0.048347543725477796, 0.025633729861250946, 0.008344012129652714, 0.048956549260765314, 0.07995150983333588, 0.005218528011547667, 0.06726049618529421, 0.031944729786898406, 0.06617553904652596, 0.06414559975798641, 0.05288241377898625, 0.009974561465371932, 0.018214186919586997, 0.08463527421866145, 0.03375467784436686, 0.023772460807647024, 0.054336650030953546, 0.05999630383614983, 0.07223285508475133, 0.028592875360378196, 0.040165612407560856, 0.023127038297908645, 0.03338709167603936, 0.019348587208826627, 0.05157264781051448, 0.04773972562647291, 0.05154636475656714, 0.03973968240565487, 0.016292412898370197, 0.02363919822632202, 0.03451752083908234, 0.07812998936112438, 0.03668055816420487, 0.01629513891280762, 0.03347887032266174, 0.026480875743020858, 0.02064013620838523, 0.04820171637194497, 0.023750997048669627, 0.0715304763455476, 0.018877783989799873, 0.01847938893895064, 0.016793265040697794, 0.04534833751884954, 0.03562516818887421, 0.01888132424625967, 0.00978746306749859, 0.044752465028847964, 0.04628376250288316, 0.030090581958315203, 0.01867876118714256, 0.007314644820455993, 0.05930002512676375, 0.03149605529116733, 0.05552836786955595, 0.011961343382219118, 0.02410801503408168, 0.01483766604880137, 0.01936696532980672, 0.020289754295455556, 0.0277389950185482, 0.05370708488460098, 0.014104467400881861, 0.048753894599420686, 0.03874335890369756, 0.017842214022363936, 0.01314851249169026, 0.004259353877776968, 0.013958099763840437, 0.01253186071491135, 0.027603873251272098, 0.031069073559982435, 0.07049576472491026, 0.05807963918362345, 0.03609919275290199, 0.03283627051860094, 0.03220400819554925, 0.03291165915184787, 0.027683884404333572, 0.06306873075664043, 0.03200619148888758, 0.010165117847334062, 0.07054972182959318, 0.05366385541856289, 0.0609839115557926, 0.026904083123164516, 0.04782448482832738, 0.05821429445807423, 0.03308939800730773, 0.02808591809922031, 0.032212791831365654, 0.056732848951859136, 0.08248278472040381, 0.007535938838762897, 0.03371500390182648, 0.05787442305258342, 0.07088915218732186, 0.009677601462629224, 0.02355737199208566, 0.07617394932146583, 0.0417430740115898, 0.02078839441362236, 0.050416810903698206, 0.007531640319419759, 0.021349809199039425, 0.0728498198358076, 0.03751983134342091, 0.03797856851347855, 0.035552279957170994, 0.02244037782241191, 0.029177555415247167, 0.013756220328754612, 0.06167188499655042, 0.07386697775551251, 0.06865797298295157, 0.02240928395518235, 0.04809197351070387, 0.021174027917108366, 0.03187717484044177, 0.013596320158935018, 0.04385845782235265, 0.038540259801915715, 0.037535919408713064, 0.06166988331824541, 0.0557647966114538, 0.028247417915346365, 0.0329279134582196, 0.031807662320456336, 0.031215643909360682, 0.06382667472852127, 0.03918661868997982, 0.04954391970698323, 0.03911075508221984, 0.06088890986783164, 0.02094034893837358, 0.013341719401068985, 0.026722876953759363, 0.012500125632089163, 0.08072107032473598, 0.01890992619363325, 0.035572171211242676, 0.017263041975508844, 0.05619581562599965, 0.0652304890432528, 0.08498853312007018, 0.032706802644367726, 0.03715911194948213, 0.05083633214235306, 0.03434696088411978, 0.03807155155975904, 0.05131191394424864, 0.0451026128471962, 0.08701173455587455, 0.029924707287656407, 0.054012310292039595, 0.03952589637732931, 0.0648040162133319, 0.008603354999130326, 0.039666587220770974, 0.009076701028139463, 0.005385001489360417, 0.05791757109441927, 0.025113827848274792, 0.020127961012933935, 0.07725457740681511, 0.025209392720301236, 0.036978509676243575, 0.04186479980126023, 0.056339179897414784, 0.02332442413483347, 0.012996127097202199, 0.024291797940220152, 0.006902442006061652, 0.030684995598026683, 0.05862600915133953, 0.015236955069537674, 0.05150529642456344, 0.04678569181955286, 0.02357386378571391, 0.011657246887417776, 0.00744308895497982, 0.07411847676017455, 0.054846073766904216, 0.060349399889154096, 0.07247397928897824, 0.05411856887595994, 0.048696833197027445, 0.022060072515159845, 0.030010033066251447, 0.07818057414676462, 0.02248122902320964, 0.03973562476624336, 0.062176267217312536, 0.03312992011862142, 0.019508860572906475, 0.009162053099966474, 0.07884094478296381, 0.0562278730129557, 0.008065836520732513, 0.012774504837580025, 0.040639382520956654, 0.02894658888024943, 0.03881716655035104, 0.027984390600717494, 0.0053525908401102894, 0.05139830841549805, 0.060567766028855524, 0.07952815147915057, 0.018386110729937042, 0.01632235155973051, 0.03155940332050834, 0.008828878835109728, 0.01794491708278656, 0.06438421338264431, 0.03457566789750542, 0.012761485446909708, 0.046364260504820516, 0.04291216949267047, 0.007750904669852129, 0.04164790947522436, 0.017029174703306386, 0.015668571194899932, 0.009978386706539562, 0.040187593549489975, 0.052023710749511204, 0.013042717856088919, 0.021553827715771537, 0.020812706323340535, 0.05160531248631222, 0.05103304283693433, 0.17794879419463022, 0.015621072047256997, 0.014533902884327939, 0.031117045985800878, 0.03676265411611114, 0.001873896802343162, 0.03387118909241898, 0.04594241528372679, 0.027502722339704633, 0.020507391010011946, 0.03682616838653173, 0.0018571600999816187, 0.07779017902378525, 0.037013142103595395, 0.0019048307897589567, 0.02742005472204515, 0.02896140469238162, 0.022994941100478172, 0.06722199610833611, 0.058645971651588163, 0.01881023243601833, 0.049434173453067026, 0.02476037386804819, 0.03507729187341673, 0.03336674580350518, 0.03303168860397168, 0.022789261869287918, 0.027495791104489138, 0.03572477034426161, 0.03153855872473546, 0.011033892032823392, 0.04083112973187651, 0.0396496034892542, 0.03657565665032182, 0.08046433981508017, 0.04255347552576235, 0.05993802446339812, 0.06209869709398065, 0.02839280422111707, 0.02693508708450411, 0.014855060294004423, 0.052361967241657634, 0.09483126710568156, 0.032595617896212, 0.018192634951057177, 0.0329726424866489, 0.03167113768202918, 0.03911672279770885, 0.014633399866787451, 0.04470340355432459, 0.05193368272323694, 0.03663439403421112, 0.05627615756488272, 0.04857950092160276, 0.02183531966459538, 0.03687274981556194, 0.03578682237171701, 0.05490845827651875, 0.02533273003064096, 0.030829499808273146, 0.015418023835601551, 0.02967835157843573, 0.08367480111441442, 0.026353180541523864, 0.02327973921118038, 0.02586545465913202, 0.028849673723535876, 0.008460601409231978, 0.01740132741230939, 0.030453180894255638, 0.061936228669115474, 0.07924961963934557, 0.013827262945207102, 0.019544298760592937, 0.04257810634693929, 0.006045557874520975, 0.04267850238829851, 0.07685289146112544, 0.02813384302758745, 0.06333582928138119, 0.04487753938883543, 0.06522666889109782, 0.05068220630554216, 0.054521683137863874, 0.018356579189587916, 0.015597857667931488, 0.026406696598444666, 0.12285583546119076, 0.03621318663603493, 0.09650694326098476, 0.08823212728436504, 0.015225396225494998, 0.01679176208563149, 0.034513748184378655, 0.03170467766800097, 0.04127356170543602, 0.057017820088991096, 0.03209527295881084, 0.10984679923525878, 0.02693651370438082, 0.05419457497607384, 0.31643277034163475, 0.23027700771178516, 0.07208569440990686, 0.13843827002814837, 0.10194101809923138, 0.10069689021578856, 0.21103838219174317, 0.08293833956122398, 0.21887103760881083, 0.12541604308145388, 0.13342396409383842, 0.1485620260770832, 0.1317256045128618, 0.12784659623035363, 0.20438613343451703, 0.1240454837679863, 0.18854288357709134, 0.1921006462403706, 0.09056318684348039, 0.10824297993843045, 0.2088181884693248, 0.13735154191298143, 0.10141649017376558, 0.08088646323553153, 0.057565241785986085, 0.27723182099206106, 0.1472565789840051, 0.1819384443972792, 0.14226527538682732, 0.1809941136411258, 0.12260935083031654, 0.05325399651857359, 0.08484687536422696, 0.1934199354478291, 0.1580734449837889, 0.15146692948681967, 0.11142033551420484, 0.10355010961315461, 0.14627704583108425, 0.11526441281395298, 0.06300501631838934, 0.22971659206918307, 0.16592826135456562, 0.1446835741932903, 0.10077922365495137, 0.16942152247897216, 0.1359209729624646, 0.15431160612830094, 0.2664504423737526, 0.12358406638460499, 0.14141036197543144, 0.14336389143552097, 0.1969178377517632, 0.1470828875899315, 0.07027501692729336, 0.16680722204702242, 0.11426461860537529, 0.08874405481453453, 0.17176250900541032, 0.1865055686128991, 0.15623080171644688, 0.161312391183206, 0.09519761494760003, 0.08658350432025534, 0.12490123856280531, 0.09226408414542675, 0.1399767260466303, 0.10791655031165906, 0.17110488643603666, 0.09718292698796306, 0.20419333449431828, 0.13854554641459668, 0.07397242209741048, 0.12129882829529898, 0.14021132274397782, 0.20924718544951507, 0.11172256858221122, 0.06621806283614465, 0.09105658358229057, 0.13948260327535017, 0.09857635293155909, 0.14258988653974874, 0.1764094289392233, 0.10189419239759445, 0.10819914657622576, 0.1600361346666302, 0.12231071399790899, 0.0842419071123004, 0.11839142787669386, 0.09515435834016119, 0.05415685860706227, 0.0941454717623336, 0.16543343290686607, 0.23048914490001543, 0.14343036072594778, 0.09732402155974082, 0.11038407683372498, 0.12450281637055532, 0.13366852168525967, 0.09999284228043896, 0.09852109303964035, 0.11561887950769492, 0.05305291945114732, 0.12518725464386599, 0.1392143512410777, 0.09409653581678867, 0.11985092956040587, 0.06292156329644577, 0.10835474144135203, 0.16155891652618135, 0.146468243428639, 0.12881076735045227, 0.1733351360474314, 0.18631498169686111, 0.11467975990048476, 0.12303252598004681, 0.12245757611734526, 0.22675717515604837, 0.1052270478435925, 0.12256783805787563, 0.278300975050245, 0.14434155183179037, 0.10600222660494701, 0.09836893156170845, 0.1478014833160809, 0.07439318166247436, 0.1188477562474353, 0.19397747410195215, 0.11878377039517675, 0.06869222543069295, 0.15945202458117688, 0.07560849216367517, 0.13244477020842688, 0.08914775600922958, 0.18268808988588198, 0.10826524945774249, 0.08251278275357825, 0.15790337696671486, 0.07845607293503624, 0.07042115301425968, 0.09707940290016787, 0.10657631472817489, 0.07649737982345478, 0.09365776114697967, 0.12271383165248803, 0.21128904659833225, 0.19904155736523016, 0.15080934762954712, 0.1168194522282907, 0.12338298931717873, 0.12226335225360734, 0.18048191469694885, 0.11040288582444191, 0.13441150395997933, 0.10628217658294098, 0.13693359148289475, 0.1906505354813167, 0.10839476822210209, 0.2061816728008645, 0.09033523300396544, 0.06410380878618785, 0.22068377105253084, 0.15048587641545705, 0.199623577562826, 0.20049382586564335, 0.1840046920946666, 0.1715044757085187, 0.0978542220379625, 0.11241774806486708, 0.09110815902905804, 0.14035382866859436, 0.16498302136148724, 0.09037310204335622, 0.23723408154078893, 0.16804424566881998, 0.1836170857506139], [0.02049846657817917, 0.038801662025174925, 0.03975852871579783, 0.037139973869281154, 0.06195741931774786, 0.010268361191265285, 0.019415002216451933, 0.011551660053165895, 0.03860312946406858, 0.05377945064433983, 0.005667122779414058, 0.023538347566500306, 0.06109022442251444, 0.031376524562282224, 0.03459416136943868, 0.023217851728467003, 0.029149569238403013, 0.02524253915596221, 0.12985200647796902, 0.025996539143047163, 0.03343013793762241, 0.024817085824906826, 0.055027402072612724, 0.006749532019187297, 0.05204646881403668, 0.06506285696689572, 0.020925753650122454, 0.044028617441654205, 0.025864150175558667, 0.058749617875686715, 0.02207456941583327, 0.035056640660124164, 0.0612579718498247, 0.04675847577995487, 0.027577803935855627, 0.058481311558612754, 0.02816192589567176, 0.051815631200692484, 0.035788464426462135, 0.01863767928443849, 0.045710637899381776, 0.030317758875233785, 0.015101495731089796, 0.031029952623482262, 0.007449060063143926, 0.036198760981538465, 0.008858693663829138, 0.04444642877206206, 0.06583722148622785, 0.014302298526412674, 0.071442219295672, 0.030665976261453967, 0.04263375639649374, 0.03904467934210386, 0.010023651777633598, 0.06383633028183665, 0.0331960942463151, 0.02550914235013936, 0.008020633365958929, 0.016290385775001984, 0.020862295358840908, 0.01905131762448166, 0.03384537083495941, 0.02673703458692346, 0.025232169444539716, 0.08699098495500428, 0.05507659246878965, 0.034964176693132946, 0.008497622279849435, 0.04562362935394049, 0.07943222698356424, 0.10449883049087864, 0.11250777609114136, 0.02187795880516725, 0.004752194217871875, 0.019444002803148966, 0.0286064290973757, 0.02881770793880735, 0.05207255509282861, 0.012229823573891605, 0.057518545006002696, 0.014382121386006474, 0.05673315768529262, 0.029755945450493267, 0.014620575554934996, 0.03390367395643677, 0.026423181606722728, 0.069437406158873, 0.03218396087842328, 0.040537558163383176, 0.04547819555071848, 0.018647772492840886, 0.005690213326098663, 0.04453844829861607, 0.042518337589821646, 0.02544293599203229, 0.06407455035618373, 0.009828560237240578, 0.06293653177895717, 0.053962234407663345, 0.03437647715743099, 0.028348387318796346, 0.02014881917940719, 0.034157856567097564, 0.022287907611046518, 0.05297799900706325, 0.012610070357498313, 0.050036013658557615, 0.038447242828884294, 0.050989521600838215, 0.041941823703902106, 0.08974559964346034, 0.023430173817489828, 0.06207610187785966, 0.04313388081001384, 0.02542075977128531, 0.03413974986012493, 0.01582336369236665, 0.10892177280038595, 0.09445581332381282, 0.021817801586751426, 0.023409967044634477, 0.024261080659925938, 0.045693800052894015, 0.036443976751927815, 0.030355658448700393, 0.03744522302544542, 0.03609978307836822, 0.07401675757552896, 0.027002418114404594, 0.019991399055080752, 0.029052199463226965, 0.015495655027085116, 0.05937222125274794, 0.07017217137451683, 0.02065017174131104, 0.024126367709998573, 0.037589425287608585, 0.029802665979202305, 0.014004324961985861, 0.02494775640246059, 0.011189071295250739, 0.11531205954296248, 0.015605577700106161, 0.06606615241616964, 0.03821976396388241, 0.04799490568361112, 0.015286847749458892, 0.0477966648925628, 0.03734158697937216, 0.05207103856706193, 0.05097907894690122, 0.053983034898660014, 0.0280146346028362, 0.0415195204716708, 0.02439254512345152, 0.07331039583576576, 0.01829083762796862, 0.08950476042394127, 0.06860257059867893, 0.0213642535132489, 0.04600540029683283, 0.07622007613203355, 0.017146298329212835, 0.02023788877496762, 0.04882973785113011, 0.06888335517474584, 0.056815698077636104, 0.023986655653321316, 0.016721545585564206, 0.045717796443828514, 0.016813753405585885, 0.01994141816560711, 0.04294349406180637, 0.013579328793899288, 0.04400608329368489, 0.0320435346636389, 0.0057669882912055725, 0.024000311170571616, 0.03770685934328607, 0.021623465764735426, 0.008767386599044715, 0.03525280174134033, 0.022208342594759803, 0.027491998093734895, 0.08389366258467947, 0.03316980440701757, 0.006036790353911263, 0.05077343533879944, 0.004221153628480221, 0.010748135491407343, 0.04917730384373239, 0.026661437304158295, 0.02588391081163926, 0.024804426057796394, 0.0415344312787056, 0.014551661842103516, 0.07795464234160525, 0.04795588313468865, 0.02931948458509786, 0.04202332593766706, 0.038070136814245155, 0.017227676730336886, 0.035484616445111375, 0.041647590563765595, 0.029652071917163472, 0.020602078875526786, 0.004746017852864627, 0.013543321484965938, 0.016955674093748842, 0.016750554653948972, 0.05387994846595185, 0.03393901206020798, 0.024822056093918424, 0.02342180748070989, 0.054124014119484594, 0.04988432036978858, 0.047820752885724814, 0.06599033291318587, 0.02395166869142226, 0.020092085170160447, 0.031133605632930994, 0.010323405648315591, 0.03252034800659333, 0.061023938336542675, 0.07104269787669182, 0.031993292538183074, 0.02570535771415702, 0.027747078066957847, 0.043869674006210904, 0.02378473211345928, 0.007193215889856219, 0.06861852974231754, 0.028710088892174617, 0.0092927185885076, 0.010393218420046781, 0.024006170320457647, 0.022196597153587, 0.011716819717548788, 0.02720131878075855, 0.01901155716872641, 0.012003898554082428, 0.02678031155041286, 0.013815672718919814, 0.0741285937173026, 0.0008084786095423624, 0.0008045413570861065, 0.07945685780474118, 0.04591820515426142, 0.03769201299707804, 0.01416885104429509, 0.02004127137895141, 0.02857547772250005, 0.03322092862799764, 0.023403140982346873, 0.01245922693384013, 0.01907181616739503, 0.05747779897813286, 0.041176252998411655, 0.03853753209114075, 0.01641570440759616, 0.01721000428577619, 0.010336428431661, 0.02711443915697081, 0.005529710532365633, 0.06531924142369203, 0.03261453205985682, 0.006837070246027517, 0.04119290764044438, 0.035948961707098145, 0.02584637764708272, 0.024959976818146448, 0.04279072190235768, 0.02854306749733431, 0.020330856554210186, 0.09915188633437667, 0.03415052160354597, 0.010183983665358807, 0.013985251342611653, 0.013139554981275328, 0.06612664381308214, 0.05068470670708588, 0.031521639454045465, 0.03906896071774619, 0.05675231272886906, 0.023625298436465006, 0.032538698986172676, 0.12046341598033905, 0.0395689765656633, 0.004462045434463237, 0.038877162616699934, 0.028754895952131067, 0.03797963381345783, 0.026705109514296055, 0.0680990976148418, 0.050379895206008635, 0.033751380164176226, 0.01176839940516012, 0.024668430676683784, 0.020707175468227694, 0.015424327425924795, 0.03849518811330199, 0.0382900025163378, 0.042534330660211186, 0.04329920247463243, 0.02412122441455722, 0.012445613825028496, 0.027611096256545613, 0.037245730337287695, 0.023754096257367303, 0.07330222627414124, 0.025972133934763924, 0.049437956285795996, 0.027556251967325807, 0.013205514522269368, 0.026958559307136705, 0.024083884632480995, 0.042699910168136866, 0.055278951967401166, 0.02605612639204732, 0.030668110254087617, 0.046043818949588707, 0.02552560530602932, 0.04368888513584222, 0.03224235899480326, 0.023748306657320688, 0.044488782927926095, 0.013790247163602283, 0.03633791833583798, 0.010182706323186201, 0.025553448990519558, 0.03162652400455304, 0.0021061782109817223, 0.055037899009351215, 0.049447177576699426, 0.027939020356695567, 0.002039415666201551, 0.0557262422516942, 0.020944779772045355, 0.01583491575105914, 0.11070725627775703, 0.009375809442384966, 0.05027606917013015, 0.03681277071258851, 0.029074584333492175, 0.05721227465463536, 0.012125650636984833, 0.029839408650462116, 0.051009881044072766, 0.056737948142524273, 0.04531355242111853, 0.013201493354115103, 0.14612011425197124, 0.19025465101003647, 0.15636184039924825, 0.20941372508449213, 0.11020360687481505, 0.08066382232521262, 0.12715886027685233, 0.08400142073099102, 0.14099442000899995, 0.14266471538160527, 0.1020696819094675, 0.12710627381290707, 0.18174632399209908, 0.09563721743013177, 0.1006381833659751, 0.1625647632671254, 0.0774033869217549, 0.09684844315052032, 0.17145681540880883, 0.08688936076526131, 0.08270233829638787, 0.08522215951234102, 0.15823933322514805, 0.1363588451806988, 0.16209604484694345, 0.11309894294078861, 0.15507284099502222, 0.11233432896967445, 0.1371068214731557, 0.08837730663695506, 0.10222968725221497, 0.07688543400061981, 0.19375738448330335, 0.0693051257569875, 0.12010285604212965, 0.1514275066022362, 0.08544164523482323, 0.12942148957933697, 0.07087411585130862, 0.1749260156814541, 0.16759561188519, 0.1591153083635228, 0.09298417943396739, 0.08047162728118044, 0.07410742342472076, 0.07457373304558651, 0.09404934370624167, 0.10590632925076143, 0.15293126233986445, 0.11136567273310252, 0.14100636222532817, 0.06658044803355422, 0.1529930361679622, 0.14005555824509688, 0.11503707644130502, 0.14040751435926982, 0.1703651747001069, 0.11987257482750074, 0.11567233449646405, 0.0781449374875852, 0.12443181446620397, 0.1128940117944564, 0.05660055158659816, 0.06526132167450019, 0.087876201740333, 0.25562240768756184, 0.1311361204300608, 0.10833285190165043, 0.14673754040684017, 0.10247440090669052, 0.15016264947397368, 0.19168671273759433, 0.14357026107609272, 0.09896357251065117, 0.08071168618542807, 0.10236099734902382, 0.11825167680425303, 0.11211820878088474, 0.061775368372244496, 0.0665227182741676, 0.1370272428861686, 0.14063571925674165, 0.11894015914627484, 0.10706435782568795, 0.0859725513894643, 0.12482436054519244, 0.07859868063990559, 0.15023570055408136, 0.11009259176041399, 0.07768061597432409, 0.2757299244403839, 0.06828701110290629, 0.10733334946313075, 0.13844882803303854, 0.143663491787655, 0.05916648943509374, 0.186644776857325, 0.13254633333001817, 0.15445727402610437, 0.22360182447092875, 0.13500092018927845, 0.1017559544582452, 0.12031943084938185, 0.1590039471962622, 0.15697633528283664, 0.16593083978763648, 0.10892409339014973, 0.11321227864495345, 0.19358978633369717, 0.08484928416354315, 0.13941341984484876, 0.18095592569027627, 0.2228089291602373, 0.12533746872629437, 0.11489261633583478, 0.11980480274983815, 0.08550447079219989, 0.10631209319191319, 0.16447819130761282, 0.15824176238051482, 0.1252416324402605, 0.13024106488696166, 0.11746338196098804, 0.10992502753755876, 0.10180356047515358, 0.16579681555075304, 0.1136537945962378, 0.14595369675329753, 0.13040437469524996, 0.07848552135484559, 0.13805250929934637, 0.10960359871387482, 0.16675141932708876, 0.18377646005579404, 0.10086969272898776, 0.0767594843304583, 0.18750853836536407, 0.09308321161993913, 0.06906714316989694, 0.10395077775631632, 0.0915839070720332, 0.06446580721863679, 0.19444509329540388, 0.05614260830251234, 0.15319021844438144, 0.13031948996441706, 0.1099345948813217, 0.18081473612359591, 0.1300162933766842, 0.11922290468854563, 0.17467858110155376, 0.1600146522479398, 0.16897151805460453, 0.08422347131584372, 0.15324964454131468, 0.08234756626188755, 0.09898234078926699, 0.14645476772316865, 0.19990036556763308, 0.1406958374593939, 0.10215860392366137, 0.10454250100467886, 0.12823156985853398, 0.09202200320682355, 0.20650150706725462, 0.09710645609136138, 0.16377488976078375, 0.15385854829634937, 0.06835978398365633, 0.11236658652446099, 0.11127377873552696, 0.08824008650013379, 0.15212373781417096, 0.16858178111059324, 0.18030474920357975, 0.09359264892659017], [0.07724268268793821, 0.061425678565033844, 0.016683983583269373, 0.027454843212451254, 0.02463612223177084, 0.04017177689820528, 0.02329326411043959, 0.011682708913992559, 0.03530212105917079, 0.01298267429228872, 0.010775952034496834, 0.018666612017633658, 0.027803652620475208, 0.07603706845215388, 0.039990265388041735, 0.058987485111824105, 0.06340282104377236, 0.031814583377646546, 0.01567505968601576, 0.015370265148313982, 0.025607295833261948, 0.02257063958261694, 0.031894311242337735, 0.03302403133628624, 0.05965457324470792, 0.03185911563092044, 0.02553905556643648, 0.04561355650158865, 0.026967610964285474, 0.011961498597104634, 0.0334352642696883, 0.031620210236204524, 0.07089165598154068, 0.03049327213583248, 0.009330247512220271, 0.050578926490353684, 0.010397938479270254, 0.09414259477385453, 0.016264285925509672, 0.014537237883944596, 0.030768831992255788, 0.034225391157503636, 0.009256081938344454, 0.021655273790072118, 0.02162569135959659, 0.05185013131371566, 0.05031190599714007, 0.053668394817837646, 0.027488703806219355, 0.006312572854637567, 0.0194852034494813, 0.016997448102171932, 0.03848356480843254, 0.032427928144378323, 0.04000246884035213, 0.028813633336020366, 0.018103992832558494, 0.023161253426223993, 0.01140048838819244, 0.0211915052828512, 0.030164236934589486, 0.044985077011265924, 0.025763750741524354, 0.00498170402300145, 0.018278698636484996, 0.016750279847266417, 0.038606953008898666, 0.014185692283457943, 0.02091126692747431, 0.032647814202521525, 0.03976927331781813, 0.011254913788954062, 0.009461187807443951, 0.03648862435615488, 0.018892538733780384, 0.08017476142517158, 0.02192812629177102, 0.02998835387240563, 0.02768714476509818, 0.008657791319170167, 0.024509517775316323, 0.016424338765708462, 0.0799408500481929, 0.05051802797242999, 0.05957524571567774, 0.05228657182306051, 0.015175313555768557, 0.030599992123565505, 0.032930654739694934, 0.05807954418872084, 0.0667170574888587, 0.04955531909529652, 0.08740194647439889, 0.061440402774938514, 0.038514309230127504, 0.022402910815019692, 0.04433606844395399, 0.04180990971092667, 0.014373424263404948, 0.030689775877233063, 0.01926583986330245, 0.08979719544627837, 0.031890864284443, 0.017013453046924303, 0.01575677396197404, 0.030184932252658263, 0.021159164607524872, 0.032402303269399066, 0.046157724623169215, 0.06521123900477376, 0.019369423322911774, 0.005817401746753603, 0.028250464537580098, 0.034959135177944384, 0.01417167714264776, 0.013606872226643776, 0.04488044351871524, 0.058269669700946124, 0.011915591462249202, 0.0627909724467567, 0.03780131141788193, 0.020712876858721887, 0.006303094144511435, 0.017871267195524912, 0.05759805573948792, 0.056934048155588765, 0.062227279480014525, 0.06820842317704644, 0.04990879512791123, 0.04686803204406585, 0.042857859549777846, 0.009877430873789957, 0.03055635214384113, 0.03827837921146836, 0.0055924864718690515, 0.01930497945951564, 0.07619426465992417, 0.02238383380297039, 0.07844125373022896, 0.03254263788195593, 0.0043275754848894265, 0.03396282524668744, 0.06962586247495242, 0.023220416590837494, 0.05079841899818607, 0.030744781318519796, 0.0167058341072074, 0.05136710258999041, 0.029037705955228636, 0.047918387289558134, 0.016252267373991863, 0.05557216051965952, 0.0352584369746702, 0.04663964394213898, 0.024451031449383924, 0.026842109127236263, 0.02969325560012034, 0.013063052702429039, 0.00867733227953847, 0.04174012577693377, 0.018949125161660568, 0.006172879033588937, 0.058028403004365306, 0.030087528550731282, 0.05809551011770964, 0.017027878701420765, 0.07773505483887025, 0.020359368595693792, 0.03688156398545418, 0.05020822923896568, 0.034583884956581254, 0.02273879582727594, 0.06754566409758159, 0.027463869424536824, 0.023000406700053384, 0.026538917628516043, 0.016134885904778327, 0.05575893406889268, 0.02716600612205054, 0.016533187657062496, 0.008615990169346333, 0.019960391701066067, 0.04733264872006007, 0.01508814555459789, 0.014307613151946237, 0.03299142433596509, 0.05300371887694512, 0.034441124581332715, 0.007006225633501474, 0.06195291384522404, 0.0377569996884891, 0.03944529998781426, 0.042111420139138184, 0.03182486318317907, 0.01908769897584404, 0.017621715586366396, 0.06714758795819112, 0.02632323170213827, 0.05876775511673518, 0.06628418607371193, 0.04036704231319683, 0.04294219805992075, 0.017201977216505578, 0.05436706875583955, 0.03542871194492493, 0.016705767950043082, 0.022275565059057305, 0.03470648944910083, 0.02255416814503925, 0.032433671943311176, 0.04089512576216033, 0.028919220170272247, 0.01958898707692112, 0.04296408759962235, 0.032947682575987916, 0.041897128602223735, 0.04346152162179351, 0.02432311063499323, 0.013552815886214375, 0.016872124380565116, 0.03289835647280727, 0.057147650979459286, 0.08421752734908036, 0.0070385858167095906, 0.04149385488459042, 0.03666411726070302, 0.07838674022683076, 0.011010278166005654, 0.03682755259796977, 0.02303852340472596, 0.025044722449300543, 0.04848802083038858, 0.07400252191083771, 0.09392736346593925, 0.03217319931302752, 0.017619298305362463, 0.03136665187776089, 0.03813607006200722, 0.052125915086695125, 0.02583981112443975, 0.03610351841364588, 0.03951357078871556, 0.010891796621893133, 0.0073884524671094754, 0.022483717550390532, 0.028859590512833426, 0.06262872115309749, 0.012490919608223652, 0.04396223296810474, 0.034538423110331805, 0.027426197160301462, 0.04979431609223996, 0.02428244094231299, 0.02172946820168623, 0.06713917412395988, 0.03971604224560516, 0.00776363059412688, 0.025449880797948157, 0.04599087286208357, 0.057522046246698925, 0.01671571357707892, 0.06630144800458636, 0.04330994707665273, 0.01598263960996909, 0.005155291940484728, 0.05675704211794904, 0.04980900976806879, 0.027017240711886967, 0.00924912780257208, 0.01415248732415161, 0.049994707839297395, 0.016110648633912206, 0.042632731808615584, 0.021955013241884962, 0.05080595073689308, 0.059638152697256634, 0.031570239524756155, 0.07722573288317237, 0.08145210359777723, 0.024967320263385773, 0.028735991966511523, 0.10353476115103279, 0.07560818003756659, 0.020289233519828746, 0.04751701007730194, 0.0766164016510759, 0.07486403068261487, 0.00780591180747641, 0.07411483981247459, 0.07775583158114127, 0.041953518254948516, 0.011779782678266721, 0.055529501023037095, 0.03841630841738411, 0.012263125224438096, 0.04377246368676424, 0.057166677101382186, 0.010560874245129526, 0.012594058627395757, 0.01692311798355409, 0.06838882528245449, 0.024727573485246727, 0.060505028681031296, 0.06633840780705214, 0.011653249467989164, 0.03306773238416229, 0.015214975623946105, 0.01739131732444678, 0.01523258360768003, 0.06142141057976654, 0.01766672620682844, 0.019304494306977307, 0.06740494950541429, 0.01634116903213518, 0.04186503728851676, 0.01749342666672809, 0.03576454267437969, 0.03798693485025849, 0.035839782029922516, 0.007086536614224315, 0.04946178304297583, 0.04433185134881309, 0.01926128350065223, 0.02442065343659903, 0.026018479572875158, 0.03987505692722542, 0.00827384991238692, 0.06116997942860637, 0.027913989199857627, 0.029604686424136162, 0.02105309601340975, 0.027099584329075048, 0.06441018091780798, 0.018657769010003124, 0.005159643894460584, 0.043697974112417014, 0.024017495069918886, 0.04709975514560938, 0.009128373166147088, 0.022932369993733506, 0.07213237761918988, 0.025686896472637142, 0.0467243251124663, 0.10454307097409453, 0.040800151215600114, 0.03803553492096918, 0.06249222704874618, 0.046591182971107106, 0.02350833426628794, 0.01378901392620589, 0.05673180740060551, 0.006032094891582216, 0.14816055047724927, 0.19095534698239394, 0.1106986388830202, 0.1282651030591556, 0.13355117583913462, 0.08901071907686335, 0.11447264387139253, 0.05362913817433374, 0.13643728382885456, 0.07222566939890385, 0.1470304096915892, 0.10584189556539059, 0.07206861568348748, 0.12700262080345834, 0.09629427681543998, 0.14200420225305216, 0.2294177652469703, 0.21858215810997145, 0.1644007840326854, 0.11433140002191067, 0.09466984362474509, 0.09506942611187696, 0.09268218385321753, 0.13570658303797245, 0.1560948911522116, 0.11219657957553864, 0.05679131492174097, 0.17393619593765053, 0.12487708271614142, 0.14817646890878677, 0.1435959775532995, 0.1647193290825401, 0.08489511920405285, 0.11318265380603926, 0.09373679012060165, 0.10113373106079442, 0.10434616011168275, 0.2129734419286251, 0.13317829370498657, 0.1259203710194145, 0.10817824769765139, 0.07272490832422461, 0.05849137423293931, 0.18522286601364613, 0.1414701680519751, 0.25350193147148403, 0.17715193623942987, 0.2502977805478232, 0.2057593526052577, 0.09441831747868232, 0.10186996191207852, 0.06342939926045281, 0.13087578011410578, 0.12896510692579405, 0.1469293079738106, 0.14019016602209636, 0.10040304384061269, 0.13748376124671527, 0.13583524684820855, 0.14550177886017732, 0.121301230309265, 0.10175237857869693, 0.14400913752615452, 0.1078998651355505, 0.116830743051001, 0.11827144931469645, 0.12409733741411141, 0.10770037584006786, 0.1029238353616425, 0.19688047761363642, 0.10053106982793127, 0.1267675898436989, 0.15309305222971098, 0.1305129945810352, 0.16451285087636539, 0.14252716276262486, 0.15033703297376633, 0.050012855258371146, 0.09933934520397868, 0.11486950543309961, 0.0939138809751187, 0.0955107927854572, 0.14470160965408596, 0.14309747144579887, 0.14614887056606157, 0.12184614821204118, 0.07200534229299851, 0.1149513910391501, 0.10921952075191907, 0.1865490355661937, 0.1313131230750254, 0.14132170458989485, 0.2366862323667322, 0.12266393218721662, 0.15013212896883488, 0.0554840120353869, 0.2979133783706597, 0.08637278527021408, 0.09939910378307104, 0.1011561837845615, 0.08649930490979127, 0.10835052095353603, 0.18920778004186495, 0.09019769395568542, 0.12337270272629601, 0.21713093455348695, 0.1703466506940978, 0.06928913268659796, 0.09768275623875004, 0.13896675381277288, 0.18123145161994866, 0.08216218370944262, 0.0922072296962142, 0.13112003915011883, 0.058758465972329886, 0.07423401091779981, 0.1053087298891374, 0.1158369742333889, 0.06742829789540597, 0.14298396610787936, 0.17284200393727847, 0.08131322783551045, 0.08997934817203454, 0.06073543203196355, 0.20219742373696395, 0.13156086978103432, 0.15062545106879302, 0.18854688693370136, 0.09627179695027215, 0.1107213290940438, 0.19264457348201955, 0.1422953616295542, 0.06738221858228956, 0.15281312939311775, 0.08404209890535899, 0.08480009716004133, 0.15896453788237913, 0.07287031159337078, 0.1999060788324901, 0.15047089436224528, 0.09230870460825306, 0.10999294889292546, 0.13962353499872343, 0.09934319249753441, 0.0834969842274274, 0.10937826401953187, 0.08114944983805929, 0.10217161822531905, 0.08017388611499753, 0.1762482633015939, 0.17304333884801182, 0.12662473108087266, 0.0961076525439109, 0.1338080827678953, 0.09632705684219088, 0.11020625316138778, 0.14501068235508033, 0.12118517367967538, 0.08996537035065037, 0.17779239187283175, 0.16221564342933043, 0.12087995505758695, 0.15483254460351809, 0.09896693125899349, 0.1519407369196415, 0.10982195806822606, 0.14223277355943406, 0.1664152323667492, 0.13224381527730397, 0.18007682929081575, 0.1419721618294716, 0.10721006643559251, 0.0960952624944704, 0.1339662628514426, 0.24778177269867488, 0.13570502240742954]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.01782262302003801, 0.04803363985515066, 0.047508433394666226, 0.04958400416320988, 0.09653339255601168, 0.03929182554462126, 0.054415478836745024, 0.0451932820890631, 0.04581126803532243, 0.01594215821075652, 0.052103574321206124, 0.025234959919803908, 0.05295723583549261, 0.025704004036794816, 0.11042742165071623, 0.039661481244755645, 0.048342529351689985, 0.039574788218098025, 0.06571598763444594, 0.02806419988961092, 0.05739983530449016, 0.01780124068526285, 0.04352795698546937, 0.04533956745373351, 0.004758982112564678, 0.006633962662557938, 0.08107522489236933, 0.08166445113186326, 0.058050421465720446, 0.027961793688258955, 0.05222208724756326, 0.04562533926218748, 0.05251991662329861, 0.01732200836496694, 0.02245901378669909, 0.06162172768797193, 0.019181781248854737, 0.026812950781147395, 0.031207806829895293, 0.020767268225816742, 0.036202350431787114, 0.05437126549492989, 0.016473792094205107, 0.04180620490972485, 0.054757009260356426, 0.042172372939863374, 0.012044640341108399, 0.03524022509476968, 0.03815888919468437, 0.04668395906420691, 0.04672276108924832, 0.019050347319404994, 0.019106278960992183, 0.044181158899196556, 0.033263842575252056, 0.03632667840325406, 0.023502704121970704, 0.05406214190380914, 0.019958976955552186, 0.006524016664895628, 0.07756757882556745, 0.03065400690372501, 0.005349045494637851, 0.019986885100869194, 0.04439616968323078, 0.024559347690748315, 0.03829636038946254, 0.0434785460654114, 0.01079782291448542, 0.0449785630750869, 0.03776515228673816, 0.00945555342228285, 0.045773918075220923, 0.038278314750641584, 0.06431971862912178, 0.02989637845062784, 0.03692679512979729, 0.0054568579237508985, 0.026230002686913525, 0.045935948844999075, 0.0644661532714963, 0.012351486599072814, 0.005697811646054366, 0.08667382411658764, 0.029532907597188438, 0.0504905099847487, 0.022158938460052013, 0.029004491666065793, 0.025937074030350362, 0.018358297579522644, 0.04647603557844247, 0.03833886721570577, 0.01822779493938599, 0.007532744635162609, 0.026714079747242585, 0.024920204488028373, 0.027445691471387233, 0.03954922101859536, 0.017009454779326916, 0.017098105379513333, 0.04075232128213559, 0.013221712849502052, 0.02206513438639896, 0.021562163518475633, 0.0377686433494091, 0.029034618620893786, 0.04668628304664578, 0.047097672043102126, 0.03934691580278533, 0.013776400808377989, 0.01491392999222236, 0.03293833236343094, 0.03753940707870892, 0.058012423504676135, 0.016556191690532223, 0.016059108810233216, 0.0047526144854990494, 0.05175582512414881, 0.029673483089676926, 0.014112773517678891, 0.0929783983156085, 0.02675731260595577, 0.07421104929276875, 0.02563501738144883, 0.04414421606010624, 0.03621607040986419, 0.02644790572646473, 0.06492392013647727, 0.0224591342266649, 0.023852734893028225, 0.014816682353349668, 0.03245796349697879, 0.020037987269461155, 0.08677903775657926, 0.01319192601035216, 0.02569978354897882, 0.05967031525714057, 0.04433723213151097, 0.06043938041797706, 0.08533084046627794, 0.014503719950360911, 0.023995094932615757, 0.027366087439336946, 0.015314145213259118, 0.06589646437870604, 0.02889657745669995, 0.0424927534269435, 0.03185520387653794, 0.005574871278700552, 0.014491131429427435, 0.025240990399782146, 0.03871307588581528, 0.031012331069047962, 0.016657831147313118, 0.056906004303268025, 0.1207825852824109, 0.02645539675307061, 0.05066181972090687, 0.04593807265960744, 0.04707165701048715, 0.06655897918556418, 0.028351579826059084, 0.026602540464539613, 0.04515756739835654, 0.019597972576905574, 0.026648972615865723, 0.02812278799579612, 0.04161329061857291, 0.030629087705165148, 0.03915353332247053, 0.016404099762439728, 0.07854508315878254, 0.06342848323817764, 0.01831307491686727, 0.031046471558511257, 0.013006553635932505, 0.03283213824033737, 0.09687145905835287, 0.009202726185321808, 0.05866770512823548, 0.07281848508864641, 0.016683225320386033, 0.02723325912042388, 0.029716566670686007, 0.015807180632171885, 0.05386875603081925, 0.04760866319494588, 0.04111956139760358, 0.03802132300500359, 0.01822062112790133, 0.040595457556524446, 0.03796439052426389, 0.029740525742194483, 0.004063638933335564, 0.01559212404702391, 0.04495278213705335, 0.03543791966512799, 0.053952107272510014, 0.009087598300538957, 0.05610646952741912, 0.027371680264228156, 0.029153833830995218, 0.08895022767995085, 0.04919833842931049, 0.058263182906167846, 0.04453919129446149, 0.061736936148788245, 0.022311615624598095, 0.05027738552806633, 0.012691436036090766, 0.01794270166595067, 0.003407867280267445, 0.027270195174164007, 0.053306460846215487, 0.08809300724949155, 0.026882135907986333, 0.026736856471481066, 0.026631671669227735, 0.014498088109706129, 0.02799611398950219, 0.06636694698993649, 0.049564000950860124, 0.03119003939043198, 0.029231468415153877, 0.014294987311586738, 0.030848417364593064, 0.047258223606539626, 0.018428554791691046, 0.014629494897755129, 0.02211303047702781, 0.049607949664017985, 0.04218861028285963, 0.030301674202616726, 0.06495626590081624, 0.011762642883695662, 0.025046057466949736, 0.04473294357636145, 0.07077896488564354, 0.06952006529484477, 0.0231255302538297, 0.07913759350776672, 0.036590160336345434, 0.03548840945586562, 0.012960244469078524, 0.06148346260722194, 0.004711328598205, 0.0660058781504631, 0.060735689875270636, 0.035157423466444016, 0.028777704906782935, 0.029600384512117932, 0.01477634344649102, 0.006733195016360176, 0.02630930137820542, 0.02116754451500518, 0.02619463574540402, 0.038446608398641856, 0.01860877199630652, 0.03761912137269974, 0.03426328394562006, 0.03168743270050202, 0.024962434811251502, 0.03182856119903071, 0.0416437704116106, 0.011816133495553263, 0.06174988938229425, 0.023169594317940728, 0.08068645146808454, 0.027425559337383935, 0.014612277071656925, 0.0341373546315091, 0.039392632099666765, 0.024933929555118084, 0.04515767935663462, 0.01351463217620871, 0.013319089410028287, 0.03047353694481509, 0.030273799984050647, 0.067381797890578, 0.03431296967236059, 0.048324873870504756, 0.03485794185793825, 0.045782450653080425, 0.07482559167380844, 0.07834121731242963, 0.041978451024208746, 0.08131100224064929, 0.04351849142195923, 0.010024242103099823, 0.06876395336751427, 0.04418255328865988, 0.06259023464683976, 0.0279760547980134, 0.04253523311178599, 0.06184567138552666, 0.04814504851986255, 0.013204117588299726, 0.004333212414556848, 0.10396543411271912, 0.01966047752648592, 0.041564453060605695, 0.02904045402205416, 0.04193415625819138, 0.023649301612749696, 0.009535324543581476, 0.03402945399284363, 0.0725907212389367, 0.021022760409063528, 0.036667591359998496, 0.11987387761473656, 0.05130492164088147, 0.07591046738837447, 0.015381147153675556, 0.02199711973246719, 0.056392645064209185, 0.03241411656407373, 0.03128184178578002, 0.03486370601292167, 0.0644288949136223, 0.010113854526675172, 0.04098486541105168, 0.08846341951617173, 0.05218027252703905, 0.010638313750470323, 0.0120274445673983, 0.06628201476165227, 0.05765169393271208, 0.047028617534254274, 0.035365078930876086, 0.020396894974900142, 0.023590582888573408, 0.030271652420716624, 0.011973230467577065, 0.02015040016600064, 0.04324142861046961, 0.054678451868572404, 0.01747842425746577, 0.03738285208653126, 0.014962981288720454, 0.014516213476391775, 0.10040531693292515, 0.05110013298690319, 0.06546043777572257, 0.020046183972486427, 0.02132909861393273, 0.016905294564951743, 0.04368790126006518, 0.03402567455278976, 0.021661219453173022, 0.0407010545688016, 0.03544998401775956, 0.06258124405784266, 0.11214927211403847, 0.14631287248006888, 0.13592887111008167, 0.13741368214998925, 0.18009239488414355, 0.12840384989976883, 0.0663964564778975, 0.1496115026197263, 0.12246216301407133, 0.11874742805957794, 0.11578037084213325, 0.13717304649097578, 0.09764565394393035, 0.13652668760291167, 0.1565348668290036, 0.13934046375964368, 0.12684165872633457, 0.1189514228275844, 0.18204835349959986, 0.13208210681165966, 0.14773540757596493, 0.11982619017362595, 0.09375535483871188, 0.12962623073586396, 0.0964528504492981, 0.055010438697146516, 0.1907290962657758, 0.12327730070267405, 0.1616282220929861, 0.15548081696033478, 0.15957477156605038, 0.19558614492416382, 0.17503768897482327, 0.1229744433824505, 0.1178866113935198, 0.1913218508873667, 0.11437047006828444, 0.10331516007759742, 0.17400385944971017, 0.053286576377494, 0.10466860673789467, 0.0849634680364813, 0.1026541923305818, 0.1357727266315903, 0.2151995931885072, 0.18118984385260514, 0.09890173761440174, 0.09888748837901012, 0.11220526482377734, 0.12874431163072586, 0.18853936876569474, 0.09080974611320666, 0.16322820766695909, 0.07816980579601866, 0.07104946965617792, 0.09468372645122664, 0.15019044226833753, 0.11663360148668289, 0.06340316031128168, 0.08930722530931234, 0.13021002869520867, 0.10789495932736567, 0.11935109352426869, 0.15992511276687893, 0.26652527121560915, 0.11254200818283217, 0.10975851504398243, 0.15298834070563316, 0.16593136904495104, 0.11071387199418885, 0.18756727235657827, 0.09322455046432358, 0.11642553550856453, 0.07665703911334276, 0.10784191824495792, 0.08221223923776831, 0.10474551868225847, 0.11792880270097937, 0.12392659086201872, 0.1139615848660469, 0.23434637220842497, 0.07128964391137872, 0.18010182652090276, 0.17906083166599274, 0.10759449045040778, 0.09390215588999645, 0.09295964360769306, 0.142234225624374, 0.09487598934876067, 0.23715073029909814, 0.09386615282190697, 0.19124501358185494, 0.10874489907707487, 0.08706087406192507, 0.09778129987950836, 0.14252489645566258, 0.14516750536859035, 0.15751833548503263, 0.0978633144072124, 0.14922301418014935, 0.18453124883983815, 0.10286412428000144, 0.14855334082884447, 0.16178516724279948, 0.0872352100642664, 0.14489098877779075, 0.08446350986404078, 0.1282910638089691, 0.12451277726462909, 0.17052423687917845, 0.1847105585038662, 0.11234615583504949, 0.159512319202934, 0.09874270257673093, 0.17320255030478748, 0.14312408358923026, 0.09744586609303951, 0.16076273710599967, 0.09789694260273661, 0.07287163473665714, 0.10270555743149348, 0.20353645831346512, 0.138314654518451, 0.06400805392435618, 0.16277075292808668, 0.17322951528642858, 0.16531934402883053, 0.13010761061949389, 0.15361377357372216, 0.10443567245134286, 0.16614821526621068, 0.12305068357714585, 0.09181854448148183, 0.23665691965392657, 0.1525319716227906, 0.17435554414987564, 0.091108084390206, 0.16300009776438984, 0.21314355065780027, 0.17024686533425534, 0.11984242073127202, 0.15786527044006757, 0.14156117316867622, 0.1077083893386381, 0.10204064061066934, 0.13100326327340944, 0.12076726396168981, 0.1257631273141929, 0.058792385937912126, 0.25535050513488905, 0.0875028446316719, 0.1338811202773026, 0.12642411541725906, 0.11705662735870906, 0.15167916166995252, 0.18838448636233807, 0.12112430908850261, 0.17873524342264446, 0.14649030938744545, 0.1160060108772346, 0.21007372252643108, 0.12934237239616259, 0.09325477919940438, 0.09396893052118165, 0.1513013398008687, 0.12244633957743645, 0.15692663937807083, 0.13870380792234624, 0.193465777273689, 0.052997781695531945, 0.10663532691874675, 0.13854326653693402, 0.10313089032258306, 0.1336635005261217, 0.08160239910440785, 0.10527721872287137], [0.01826479036494025, 0.03619119531608053, 0.010855567092741174, 0.03759907066289868, 0.08851633846227612, 0.0219756525808147, 0.01898362866735884, 0.017026828668479408, 0.033149875833519866, 0.019681328907608986, 0.059124834170298915, 0.05181389754371984, 0.040696386247873306, 0.05069344284545098, 0.006287872059536832, 0.03559247297900064, 0.03724854625761509, 0.004913096923181521, 0.02366208521250103, 0.027695509405540567, 0.01784859225153923, 0.017657381083284105, 0.05381131464881556, 0.011212140637716013, 0.037641190724181275, 0.03330596602920975, 0.08694888185709715, 0.03776796481439045, 0.055106295339230976, 0.009082525403105786, 0.02271721841368292, 0.04311865448419537, 0.007599430208626602, 0.03340035364297884, 0.05999499426356383, 0.004905899787055594, 0.060706974273281436, 0.03630022910822715, 0.03332115503560219, 0.046174280877624235, 0.05710360048604863, 0.07455705465482813, 0.06441857439598866, 0.05079773707049234, 0.03517672100237437, 0.03764389468623059, 0.015554238044257675, 0.03903043010671224, 0.012118258846125432, 0.0233018187406872, 0.05961299940411534, 0.010274246634383286, 0.020108353047232543, 0.05271047300526074, 0.011159975713651096, 0.047801373925592215, 0.11570407636463642, 0.03801156906411052, 0.0585576467482107, 0.044813994584339004, 0.005096627923194319, 0.02970036325444068, 0.04724785219877958, 0.015019484596060855, 0.02198228017160935, 0.023954515145825486, 0.07781679795256682, 0.02076485942650054, 0.0611126364341804, 0.022277824580669403, 0.016127299883269837, 0.0646559191601617, 0.019324360115985786, 0.06410275705690895, 0.04825987021571823, 0.06636155942188841, 0.10878089535981417, 0.03324933210387826, 0.08562921267002821, 0.025723844400740097, 0.026609507322843586, 0.0502813142458243, 0.03648184918399368, 0.016817302143733417, 0.03446761119578566, 0.01542004247728203, 0.05909349263778754, 0.029680862158004726, 0.06163151216294084, 0.044061970830495865, 0.04544271495459335, 0.030844875411795716, 0.045584002908851416, 0.03249799367040396, 0.03702606480302555, 0.05184721022046038, 0.022729260713926384, 0.04006742160501225, 0.0318654599333448, 0.0052616552732485744, 0.018624062782951763, 0.010164607249732529, 0.02654943322496755, 0.044163479669285674, 0.027058443054556847, 0.03653040514992816, 0.03161368951467531, 0.03738275030627847, 0.04261950376842703, 0.039878748157726865, 0.03437389533168503, 0.02373447472096554, 0.06275861989706755, 0.08330097581659045, 0.027103153423273137, 0.02036413869687489, 0.03259276465645858, 0.012977047540646578, 0.01844009497602071, 0.014675845624879003, 0.11295773980340787, 0.08002617582678795, 0.004369427524839661, 0.047800050782305856, 0.028953048533626964, 0.010180981147901287, 0.03007248542936785, 0.06425620775137629, 0.03577889029734901, 0.031290136876383, 0.01036761305294931, 0.04566740843334368, 0.022057010625888194, 0.09035063574888877, 0.11173531146986143, 0.03647037176415324, 0.045538938005587885, 0.033197505599153895, 0.052323056651013236, 0.019671312034396187, 0.038825512531080415, 0.05702290910163096, 0.056167914266032834, 0.015609871130436659, 0.044342809689364264, 0.013350106942068254, 0.09348932161395039, 0.02191209250928036, 0.01844172685274056, 0.03387031038956983, 0.04336031812376209, 0.0791513134858438, 0.04370535657341991, 0.00865820437736277, 0.07000389468989202, 0.016045672120526433, 0.06206791874553476, 0.029537426640412638, 0.01953178148583642, 0.03434054194284337, 0.013034357456490397, 0.052904842754027674, 0.029021475397582566, 0.02517457539215684, 0.032438438651817184, 0.03284697440852012, 0.019487177986385565, 0.07033001219055482, 0.0062460289253587166, 0.12247021043939249, 0.020084531379065344, 0.05374308116734028, 0.04201305631015982, 0.025776893964835575, 0.025674056893746768, 0.03775972739926406, 0.03263393137603998, 0.024365663262350217, 0.04005365412948387, 0.04548284690827131, 0.016698568693495223, 0.039091369336737056, 0.04659744245665414, 0.06709711173815386, 0.011943446172933494, 0.03849968680047563, 0.05469750852457114, 0.03413498315161892, 0.027959698711388876, 0.004680053646942335, 0.017095518464754735, 0.03586403287148901, 0.06846575079751865, 0.023232857530404414, 0.0013908699869976512, 0.023476768817220415, 0.0400704546565456, 0.03435257236872401, 0.040248783837471686, 0.06512769098792758, 0.03196062446971025, 0.03499744526509728, 0.09526704943605832, 0.03900548715942672, 0.03304190734135253, 0.02175465033256582, 0.03630456155432122, 0.023729650336982946, 0.03024085032354508, 0.007109287045230823, 0.04355186516685145, 0.02706952522774892, 0.048358790443411896, 0.02728070568160287, 0.07567692242030587, 0.03331142145075968, 0.05089659283735922, 0.05233197599383337, 0.021993867853390317, 0.03807476442307234, 0.03383792730580483, 0.02578671575923051, 0.033641881575541835, 0.02622616387504552, 0.022067683981731534, 0.05870754870453051, 0.08697356017572538, 0.027108239043237906, 0.041063799389771054, 0.04328672421563949, 0.023384679740827, 0.028785175577338253, 0.01869987041157271, 0.009781424105832619, 0.03058730691139187, 0.07017983203487736, 0.02928711167935814, 0.040287433192133904, 0.012499631149694324, 0.036874571682087014, 0.007419643025579197, 0.010854126053995319, 0.0380495805958552, 0.019253258127719164, 0.03906832968017884, 0.010676650979023958, 0.08977706331227507, 0.018651326320001056, 0.04033956503761666, 0.034939688364309926, 0.04136955744719931, 0.047370728105306625, 0.06821585992085082, 0.030686149107558385, 0.048628324908869605, 0.02757340363625969, 0.06685731746256351, 0.011025231381479119, 0.022539308228130852, 0.039893770923039744, 0.02885273052379489, 0.057304792904428074, 0.04584710146965725, 0.029379653677876507, 0.11444106485162463, 0.013839647057466209, 0.056166682724973986, 0.023489952752632753, 0.024721354711800814, 0.023908561361687522, 0.05207808854590569, 0.061825328905667574, 0.035195696234170876, 0.01198789700200515, 0.02333436636919422, 0.02399708643289549, 0.019107140700465867, 0.032319165766239166, 0.006699719491215157, 0.03478082635306886, 0.06594685238919087, 0.012452320295519062, 0.02491006038949958, 0.02208917318577213, 0.03632063265623791, 0.02804174886218139, 0.05188458053661244, 0.04455457368333425, 0.026791522645258477, 0.025791976101962582, 0.007033763129064547, 0.05031790424670492, 0.015938171817521964, 0.017050696137760366, 0.02680205011607281, 0.03646889595048768, 0.03965855336615017, 0.04525651816012604, 0.033820875720786195, 0.02483138595042484, 0.02487336521569107, 0.05897506113563265, 0.015911873496536697, 0.05257522740534373, 0.05846802584294762, 0.01662088491554771, 0.05539494413616402, 0.08272433640169245, 0.11724840849637985, 0.11885622436446802, 0.036311862591121874, 0.05248455137812665, 0.04992712914411511, 0.07834783981421165, 0.043287046519773345, 0.06489455314087016, 0.052231756371579, 0.03499115524547441, 0.020594877922641378, 0.011538240326834577, 0.03637271361159427, 0.033784000735197744, 0.04364841391465493, 0.021677889362243668, 0.023844577205766524, 0.06721142453274556, 0.02382621944083699, 0.08423238726598875, 0.030604626517742872, 0.022402783589703695, 0.025825068254822066, 0.006811054365243763, 0.037747937853315046, 0.028402602266786352, 0.05419257329776883, 0.02228014517043318, 0.025908126030117273, 0.0803126533116613, 0.01555197682630803, 0.025191671081951687, 0.03486853039690426, 0.054830019628362994, 0.1119730429989951, 0.04573904476793749, 0.02775276079773903, 0.12058082967996597, 0.06271875596472196, 0.04304234982867326, 0.060739747514682155, 0.009835824802783983, 0.050272934338344, 0.040185795431690555, 0.10546624500836645, 0.13888980794165814, 0.07586674259177276, 0.19733638529266628, 0.12984245270490646, 0.12267360809658255, 0.08294734372092144, 0.10887142550200224, 0.11289091088942119, 0.10433283368391649, 0.11527376302650996, 0.10341658749218498, 0.15940791980496474, 0.09624618903866836, 0.09330441403601851, 0.09766843236450638, 0.19113929782594952, 0.11365618303950344, 0.09614736041320221, 0.09655952293957983, 0.09778341012341635, 0.1526267493941954, 0.09120897576212883, 0.07534619766686644, 0.1474712538932051, 0.1173087302595377, 0.24339311676365988, 0.229656989553145, 0.12007540251527514, 0.10917815725718226, 0.0999217385958348, 0.08492241666785308, 0.08907574987305061, 0.12240280477063996, 0.17056542395481042, 0.0902677323403103, 0.20703624694475106, 0.10886214992829732, 0.15154494744326386, 0.14730493138943399, 0.1874151448053973, 0.19508732669055462, 0.17925496053482803, 0.09838366934231349, 0.07123513719333069, 0.15881414738084587, 0.06554451504988329, 0.14245339243539742, 0.11672703575875078, 0.15290501660534314, 0.12297493192766394, 0.11099737071033035, 0.06718237644859723, 0.15486633564744676, 0.09518606628158263, 0.20145197159477643, 0.18075848557054996, 0.12737671072993959, 0.14082733754600796, 0.10992496646940708, 0.10729438119700976, 0.11046406932707344, 0.11224598371024642, 0.13710579009992735, 0.15485336205789021, 0.10797905695757695, 0.11670760251581669, 0.15415757867906774, 0.1313611769250461, 0.1250155988548483, 0.12848555908671447, 0.09083841421774455, 0.1203181552035468, 0.13733164726623467, 0.11085234063544444, 0.14293029398790427, 0.16776524563985212, 0.15440117275076254, 0.10985625801341874, 0.08458034002355166, 0.10832180535154683, 0.14711388306958334, 0.11311760265380144, 0.09239611348935536, 0.09571767132729292, 0.1219487019947597, 0.15693619315113339, 0.10370693262666464, 0.19843512347766332, 0.07601815768118415, 0.1428001916834286, 0.1424067635089159, 0.1236222136233534, 0.16028073297015258, 0.1076227378632341, 0.12796092938099587, 0.11025642404066664, 0.1427714353693383, 0.09305958503058978, 0.08880451907004629, 0.15180279075035027, 0.09438434323029858, 0.16658740384238108, 0.10808196357850518, 0.1520550972116845, 0.09417802108717815, 0.09651925188622304, 0.09568893536925316, 0.09395801967808179, 0.1143179243164403, 0.10418829893959419, 0.19358088395425252, 0.11732014321855136, 0.1380368351404156, 0.0922931254442249, 0.1425638036536319, 0.11070427750902516, 0.08370437167052712, 0.09636802678661686, 0.15012524862374577, 0.22379864033843788, 0.17253274124647888, 0.13932742231658526, 0.13756359767700943, 0.12818834717784608, 0.09647470606224877, 0.1325253937393427, 0.14937982362295898, 0.058746510185301304, 0.06686353284333434, 0.11288087535649538, 0.1615099941513368, 0.14691120465951307, 0.2092391380241939, 0.13947376874940737, 0.18747420449342045, 0.08560676673161131, 0.19281327085835592, 0.0844665632716247, 0.16952619329094887, 0.09235289759401764, 0.1801463384181261, 0.12904026146445954, 0.0728242119242038, 0.09910887399954454, 0.12803206699235098, 0.13265313474195345, 0.14082864033324377, 0.13543332341526235, 0.12005731277167797, 0.13660081076834882, 0.15590237719672068, 0.1284590419381857, 0.12234278156289033, 0.20713217822568758, 0.10212429040776831, 0.1652217706931489, 0.10855753520237547, 0.13083413163466112, 0.07574411774320261, 0.09483315343303339, 0.16805177740752697, 0.12723119210984024, 0.1134777283295989, 0.17291159448879106, 0.1344329456665686, 0.17581177529479775, 0.13449690437742642, 0.05741122790745326, 0.2684086672961712, 0.08159850431340081, 0.15356101069067205, 0.13076626456209592, 0.11953309018697057, 0.12175550950425011, 0.15301626920700073], [0.033702345831053596, 0.009074390616400965, 0.06280099440898214, 0.04140808466555817, 0.01107005201213594, 0.0557835750680949, 0.02278867324015924, 0.03574401020471539, 0.009541120928978282, 0.03604577847623399, 0.03471734600939921, 0.05629633719633732, 0.060761786332087855, 0.008624449804691332, 0.04545762236895306, 0.022553679599825825, 0.020202440409255878, 0.02742651098274759, 0.02102007171405213, 0.02616154189620699, 0.013546743845966245, 0.03263772099411913, 0.035026785119303634, 0.014933804282918572, 0.045224460773169994, 0.02151181113107928, 0.02805244257407529, 0.03885065225352134, 0.050961067234831195, 0.029079042308564697, 0.07924515487892286, 0.020048467242824178, 0.0013379407568468846, 0.05255169241822191, 0.03539154858195356, 0.030090378397809606, 0.04699847700872591, 0.10021334580544915, 0.031288488036287684, 0.04615811138812985, 0.014506798803008028, 0.043600550054439476, 0.011516299048837806, 0.05717249893184219, 0.012636477244086564, 0.05623280596254127, 0.018164882868794457, 0.03916165877931884, 0.035225629806518555, 0.04348129073956183, 0.07617688737809658, 0.018989328361515487, 0.04424225079960056, 0.08147607623998608, 0.025686524974714433, 0.04011426766269973, 0.058083201492471356, 0.02363438402036471, 0.04989301918872765, 0.0982026836967894, 0.034275735063212256, 0.009107911942659743, 0.05990939707096134, 0.05004432571253606, 0.019807032608826245, 0.04916088668895619, 0.026346875254863074, 0.054046942719391415, 0.0318498977326921, 0.02466018308353211, 0.03801409660705498, 0.040485154903892956, 0.05790005810558796, 0.04520684261141079, 0.04450734764603632, 0.0728560962847301, 0.023682705891717757, 0.010830664857556778, 0.006961569123502288, 0.025072885045249547, 0.069895064458251, 0.05507406492584518, 0.05379077200112598, 0.02613669055114899, 0.06449043803981372, 0.026693587989679406, 0.03443603217601776, 0.056241413179252825, 0.015734930223386203, 0.007914463839759784, 0.026223364918093597, 0.014743027377075382, 0.05662305859316673, 0.05411992933867233, 0.07635346254599945, 0.07744603963302714, 0.037835061749709506, 0.009662256393182491, 0.007190182838322861, 0.05642580507057054, 0.04949508893436619, 0.04945107915305665, 0.035013390838035514, 0.03580590956179159, 0.024599678115919232, 0.05201229100514736, 0.019443744959841882, 0.03804276131891778, 0.03574193049488323, 0.059795389617128034, 0.028921730749841248, 0.032731908440057716, 0.019330117485619018, 0.02410275299501206, 0.01788090239278972, 0.011187326612084039, 0.05019495709400092, 0.013161798207355397, 0.007044238013414932, 0.016911691453840052, 0.008408666338904627, 0.03158565584037985, 0.018935551068612506, 0.02378734277694353, 0.018705336011147926, 0.057041867370052, 0.02931702828833035, 0.020772489552785243, 0.04284830916939037, 0.02843872068582901, 0.07968136468636138, 0.03209466906264424, 0.014481370703184178, 0.061974504829517434, 0.07589547854981252, 0.0447232303475695, 0.06254122406244278, 0.04680825650159802, 0.016374692054731504, 0.014476936476837312, 0.057873167762798924, 0.0681288174486586, 0.0656775486256395, 0.03404723161033221, 0.04692194504397256, 0.014414156720574414, 0.04015098997790899, 0.04319140022354467, 0.029835167806595564, 0.01751286499867482, 0.03158977794061814, 0.05600548655326877, 0.02784801523999444, 0.042120950163475106, 0.01954883137451751, 0.014461140181603176, 0.0510934494169695, 0.029123140299426656, 0.05747768362717969, 0.012762328526670379, 0.0491336706493582, 0.018070176343566606, 0.019148660258256962, 0.043862210121005774, 0.04648779459031565, 0.020702938017036234, 0.02792049804702401, 0.03243922914511391, 0.034272868252758465, 0.01751638829175915, 0.037744589282998016, 0.039526483310120444, 0.04919316799246839, 0.034078349226287434, 0.03925824823922344, 0.030895511087562357, 0.045466789377055, 0.026325774512120655, 0.031949744160686216, 0.07822011238230125, 0.054268270664449246, 0.06366424701575722, 0.03920166859669345, 0.0076376351228516015, 0.049753363111189434, 0.05805283026503665, 0.045112458390316794, 0.027688813961244056, 0.03597998772082584, 0.040341200307011604, 0.057233594224921296, 0.04409623684893761, 0.019066462526097894, 0.038115707226097584, 0.01568172120356134, 0.05044173688760825, 0.027832580264657736, 0.06821898796728679, 0.01683253186222698, 0.0162679873340364, 0.02103791888138013, 0.02265310363977083, 0.03293681923033936, 0.03224605701065489, 0.035676540075136084, 0.0563766248524189, 0.03139338615749564, 0.03233576273279531, 0.021318401509363736, 0.07014561351388693, 0.01687486226936536, 0.025769267231225967, 0.04783068663839783, 0.09380463005176612, 0.011243802778023695, 0.04996393627620169, 0.042395013850182295, 0.027764935412311127, 0.06066947164280074, 0.06487392567630325, 0.02954970473157508, 0.033933536282607486, 0.04971836766760264, 0.09389492949204785, 0.03650409834725516, 0.08238603241209473, 0.02742533033181514, 0.03601523422236953, 0.040451645451997004, 0.025153815613261292, 0.030180423387459347, 0.02759878254229469, 0.024403467840914215, 0.06666362964149032, 0.030502673238515854, 0.020732747756743004, 0.036120977119675705, 0.017384126549586654, 0.05401949937056218, 0.08488720070038523, 0.017880086454429796, 0.04315953282639384, 0.01964551243664963, 0.039990170393139124, 0.02356654917821288, 0.03983569511079362, 0.020725658762135675, 0.04782167908602527, 0.023391392148498977, 0.03370819141023925, 0.020271723923672522, 0.03679486756612148, 0.03879870700516871, 0.06444173958152533, 0.03909412418891277, 0.013008679146878421, 0.05638936434739402, 0.02766892101083483, 0.011612613702059855, 0.02653874290574874, 0.017730447430429713, 0.023727190647540346, 0.04041291128045746, 0.07951220590621233, 0.006196743110194802, 0.049771863368472884, 0.07358012707637888, 0.01646677264943719, 0.011520513599472386, 0.04578780768705266, 0.03557934671906488, 0.05684887844004801, 0.029419395473918745, 0.0540681333680238, 0.01565739741948034, 0.015880318225494454, 0.04825631469222052, 0.03631911952314632, 0.05811257527342864, 0.048008449242583344, 0.04425274095098887, 0.06186870764940977, 0.03175663648705397, 0.07539121846535377, 0.027311176992952824, 0.027637452253007462, 0.04774124215223959, 0.027131860543574606, 0.012874989936660444, 0.10314217435994319, 0.03917510395071336, 0.03250419208779931, 0.0034478438070176965, 0.012448232122031706, 0.044656011275947094, 0.017298305440428, 0.01605983993171581, 0.05278234004176088, 0.0075435876247606105, 0.03296583338773676, 0.031065796235842363, 0.086167494500322, 0.030187191774270365, 0.016845159398924028, 0.04085714815716658, 0.016375061856316667, 0.04043777619621583, 0.00845888556380357, 0.0511544972125973, 0.005133412154724023, 0.0256344813387841, 0.08829388754176241, 0.02022048774441438, 0.02597578106048916, 0.02277477684297732, 0.04405066304441009, 0.036015312253896675, 0.034124465858829875, 0.03291001709710274, 0.013452815939672291, 0.04454273324725883, 0.05972228425421885, 0.028828082739242485, 0.01953868897232626, 0.018909476664183394, 0.02723351526739342, 0.024666335699813705, 0.07220249064266682, 0.030737541349870817, 0.009206342776971204, 0.017642346443608403, 0.042410033222820075, 0.021020025912938372, 0.06719910233680691, 0.04141191838841353, 0.017432580735268335, 0.06056568292634828, 0.02795192100373762, 0.018208180188334415, 0.012703933802965497, 0.058865118106561046, 0.02301512412460787, 0.06344719044864178, 0.007867061383357006, 0.024796499072441032, 0.028207733794780712, 0.017524890335542814, 0.003008137423811214, 0.031294920548264465, 0.02436569210008851, 0.00825747855872448, 0.05729551054537296, 0.12488352879881859, 0.12762991285749845, 0.10692413177873407, 0.14672088915748255, 0.12041639350354671, 0.1983571190919195, 0.08698627592197486, 0.10001352402780737, 0.10541763475963048, 0.12897770053574018, 0.12622583391410963, 0.11880898475646973, 0.1941376490784543, 0.08030515549970524, 0.11859132429318768, 0.11460983008146286, 0.11241306617323842, 0.16363071464002132, 0.08883426604526383, 0.072824110143951, 0.07736939910267081, 0.06328286962317568, 0.1448525565543345, 0.10177284319485937, 0.16417137134288037, 0.12083762804312365, 0.12581233467374528, 0.16197052943919385, 0.15743824121143135, 0.15160688411976608, 0.09932806795196873, 0.1290176933897393, 0.08598223408418042, 0.15254871786705085, 0.07590284065476485, 0.133189516674195, 0.1333573048136064, 0.18010204365210875, 0.07516316284558602, 0.11307360644319228, 0.11487072679613318, 0.1213300001940557, 0.1266212569815772, 0.09851741537983928, 0.09166281390935183, 0.15140495209821633, 0.11905111319252423, 0.24961305728980474, 0.1235619732843978, 0.20645410461085184, 0.16240832023322582, 0.09256218493516956, 0.13191392512193748, 0.13608836755156517, 0.09747006265180451, 0.1789088398218155, 0.13094585921083177, 0.15047139647815908, 0.11930498028440134, 0.13481873353677137, 0.18197763657995633, 0.0693918289616704, 0.11125641502439976, 0.1589028454784836, 0.06817398752485003, 0.1848944550646203, 0.08244030842823641, 0.20037704998893396, 0.12329893239906856, 0.14607016050389834, 0.12359573718692575, 0.17775951006582805, 0.15141328450824532, 0.13876324758997985, 0.11198421168540205, 0.12138113459306103, 0.12359793564038617, 0.1056056364572474, 0.13135714642703533, 0.2099223006516695, 0.09436769876629114, 0.12393712172550814, 0.06966278835066728, 0.1187396656189646, 0.18029846596930707, 0.1329066218542201, 0.1540332982050521, 0.1811883510755641, 0.06114935874938965, 0.1382639950939587, 0.14384299144148827, 0.07812376719500337, 0.2277570100767272, 0.16351039681051457, 0.2384088970720768, 0.13412486362670148, 0.17247027531266212, 0.12106765141444546, 0.07065372767725162, 0.1704615131020546, 0.12604930624365807, 0.13676264137029648, 0.12474349274166993, 0.22458314895629883, 0.14573733907725128, 0.12974772921630315, 0.08709623930709702, 0.15982300681727274, 0.07998445270849125, 0.09479421230831317, 0.08638548066041299, 0.10586601748530354, 0.09314281413597719, 0.19786904885300569, 0.14142154423253878, 0.083783651702106, 0.13059857141758713, 0.08391844268356051, 0.13580893326018537, 0.07844777445175818, 0.07813722254442317, 0.0993313995589103, 0.09873715216027838, 0.05486368514331324, 0.1301975707922663, 0.17614546524626867, 0.16219219325908593, 0.10325038033936705, 0.12643387275082724, 0.14108997131032602, 0.12340668376002993, 0.06397021202636616, 0.10370747545467955, 0.15532852656074933, 0.15911000221967697, 0.20568161963352136, 0.16856693476438522, 0.14181124046444893, 0.12337536258356911, 0.13475045934319496, 0.246745622583798, 0.2111186393137489, 0.18545158659773214, 0.18557939545384475, 0.1244209986180067, 0.19448362051376275, 0.15010652105723107, 0.17604247720113822, 0.12108652825866427, 0.0642747792548367, 0.09962679299392871, 0.20303977067981446, 0.16023098278258527, 0.07254534760223967, 0.13129799174410955, 0.09335546701082162, 0.07812503605548825, 0.12168600037693977, 0.12075449393263885, 0.11224689294717141, 0.11384904304785387, 0.0924768184444734, 0.08634874477450337, 0.12685121249939713, 0.16903462181133883, 0.1074038560369185, 0.1301150337925979, 0.06675681285560131, 0.09139993587242705, 0.1716861738158124, 0.2282661556133202, 0.12784010943557533, 0.09865821139620883, 0.05987752628113542, 0.15002494757728918, 0.24249826478106634], [0.01466947587739144, 0.03598077482144747, 0.023907923538769995, 0.05329258819775922, 0.06857815012335777, 0.028104053643931235, 0.029259413879896914, 0.020045261164861064, 0.05654551561123558, 0.0076456986633794645, 0.02009709445493562, 0.03407075981210385, 0.012294418411329389, 0.038610094626035006, 0.04190727609342762, 0.009547137838256146, 0.02936529248420681, 0.018427462350311022, 0.025637950349066938, 0.04950543659340058, 0.0218021766216095, 0.01501802065675812, 0.025934303911136727, 0.03184353307421718, 0.033931439609399865, 0.01554673005427633, 0.03777366790122219, 0.023427554672317843, 0.05247871258429118, 0.02625795154433165, 0.035081223983849795, 0.030961176313992058, 0.024685088711391603, 0.028764700783150535, 0.02711979449460549, 0.007520061967495296, 0.020180874870025685, 0.017737834980445247, 0.04274228807272656, 0.04498831701597997, 0.08324243860053164, 0.011703344860247203, 0.007141913553433759, 0.010050272402752723, 0.030532332004180977, 0.06996470929256507, 0.010585543233901262, 0.03409241186454892, 0.022950061098007218, 0.031683157929884534, 0.010637503749291812, 0.017691864232931818, 0.06536084919103555, 0.012180081019843263, 0.044113529313887866, 0.005112123542598316, 0.015491721220314503, 0.06050088283206735, 0.0377376173356814, 0.016670307709968517, 0.022706277036507214, 0.06519023834594659, 0.019242577986525636, 0.04242577184257763, 0.05890480561980179, 0.06408424662160021, 0.018172982880579572, 0.06257012286888701, 0.023836151497172456, 0.023687859365184392, 0.07834923759635005, 0.049591556257967434, 0.01967385484437857, 0.01290401172757681, 0.010683469407792603, 0.059738989786377976, 0.031058695366872207, 0.025689220455076014, 0.0575894790568522, 0.029402530486030237, 0.025150394100429754, 0.04039942200428673, 0.061010727259729586, 0.04368314133690936, 0.0131636412780998, 0.019941645474838357, 0.03469688478591187, 0.020712052438674227, 0.013891458295152655, 0.055265160743147135, 0.032455330781106434, 0.01456887457918908, 0.051982089411467314, 0.04871228004672697, 0.016123571333342364, 0.04026761657691427, 0.0602651054837874, 0.05296837738049882, 0.07134404884917395, 0.01931816339492798, 0.022685753048530648, 0.03625444156516876, 0.03151678453598704, 0.026355282303744128, 0.020513584338394657, 0.039738386403769255, 0.005882076312056077, 0.02633070576536868, 0.031658187841198275, 0.05668503258909498, 0.02884620301691549, 0.02032406272233597, 0.07493692569966827, 0.08293608682496206, 0.01562701940669545, 0.01757991443654256, 0.02972980828157493, 0.031401945876755884, 0.10296336002647877, 0.07176305100853954, 0.01712833241825657, 0.013582613751558321, 0.03142727219632693, 0.057575867644378116, 0.04646826295980385, 0.09795913033719574, 0.06730171040232692, 0.025837251351081898, 0.016253945051825473, 0.025990016725180403, 0.025184783951512406, 0.05768229586205312, 0.036262590770742724, 0.016601217578032186, 0.00457893538987264, 0.03778386628255248, 0.024268727749586105, 0.060861347775374136, 0.016409477152462517, 0.014452475289415036, 0.013079763323600804, 0.035198257703866274, 0.021609136801479117, 0.028822064133627073, 0.054111634248069355, 0.025227942171373537, 0.021939389973080585, 0.03197218331375292, 0.07940259535929986, 0.08103349498872246, 0.043726862740835974, 0.06246077695063182, 0.026276575634256005, 0.03784238314256072, 0.07060226079608713, 0.05630644736811519, 0.04700417670288256, 0.035362683702260256, 0.028436306797500168, 0.057363492968891344, 0.03975672720532332, 0.04299714921840599, 0.07089399014200483, 0.03495809701936586, 0.041754914447665215, 0.05368599940889648, 0.015634291605757814, 0.03652440690036331, 0.01410433423838445, 0.022354524482839873, 0.016828662516283135, 0.04343821055122784, 0.0147817496742521, 0.06729335763624736, 0.013650982940037335, 0.022706131151478206, 0.03931152680888772, 0.031455265158521276, 0.014294083163674389, 0.037022678913282495, 0.029816199360149245, 0.08947700834167854, 0.012635612111937786, 0.019816138548776507, 0.030781364534050226, 0.01704893194671188, 0.03154037719858544, 0.04278466597731624, 0.016564083052799106, 0.02487165361110653, 0.09892597488526787, 0.024616339543302144, 0.05296864200915609, 0.0636939261374729, 0.015669309101732712, 0.013675590860657394, 0.01285006819359426, 0.0570753530732223, 0.089362519127982, 0.03052239485883287, 0.05614697128268225, 0.04803545154365046, 0.05244637021262731, 0.010791069794712322, 0.030989552648471932, 0.02775181084871292, 0.041752220663641176, 0.007746783417782613, 0.02421113369720323, 0.019492921785318425, 0.00528241420397535, 0.021375529068921293, 0.047992340821240626, 0.020452558595154966, 0.0377135734472956, 0.042154510505497456, 0.04798348593924727, 0.007539554582243519, 0.04186954276104059, 0.05131927265652588, 0.022753952603255, 0.04485509005774345, 0.020926086132281592, 0.044085953650729995, 0.06569608620234899, 0.05831441908542599, 0.074737449974886, 0.025671933079138398, 0.029011850378343036, 0.04080919948007379, 0.010413595674825566, 0.017481453916324035, 0.0027235509312179473, 0.022738441292728697, 0.0110251525017832, 0.02441026167278843, 0.04899116133206657, 0.04044035802196179, 0.013616467559976237, 0.0464223532804421, 0.03933207963460258, 0.05167793269668307, 0.014600250038451381, 0.06454282094325338, 0.025311994000471065, 0.08923010980444294, 0.025030413842094795, 0.07600329776427575, 0.07081969734281301, 0.036087002871291976, 0.02286005173144596, 0.03533816823203649, 0.009541449170293552, 0.0597207032676254, 0.08612643634634358, 0.013311527137245451, 0.03171130695513316, 0.013362820143811405, 0.01840552022414548, 0.06982545355068785, 0.049800657001989226, 0.04895068671820419, 0.02830718158345137, 0.05739566231412547, 0.0017511236302587868, 0.038593745324760675, 0.02722981894787933, 0.0805295809571232, 0.032656496058085134, 0.06749210054320948, 0.03727411684979286, 0.036027342679777315, 0.02321716471176062, 0.057162219126309664, 0.0384840872803969, 0.06132666673511267, 0.019986444053107073, 0.013202708779967256, 0.021009724055017744, 0.02236445484283779, 0.02527374498146985, 0.022462469226281558, 0.03683945070952177, 0.013838370563462377, 0.11081421375274658, 0.015858437167480588, 0.014110179817570108, 0.023286795975374322, 0.08406254995082106, 0.03353440162858792, 0.03364754734294755, 0.0590191659118448, 0.021192541745092188, 0.015758399053343704, 0.08815339686615126, 0.06118119561246463, 0.05472575593739748, 0.053817865904420614, 0.02389742829836905, 0.04456745906333838, 0.04663445654192141, 0.0492777066704418, 0.036575117214981995, 0.0709038492558258, 0.03171828229512487, 0.03131943941116333, 0.03625038731843233, 0.01864452570277665, 0.007322677826908017, 0.008178765952054943, 0.012713935409140373, 0.07586721078093563, 0.023595361471442238, 0.036138524035257955, 0.041350249733243666, 0.024066364858299494, 0.021377551103276864, 0.02569506942693676, 0.05035323556512594, 0.024004054987537007, 0.08084121852048806, 0.063752510850983, 0.02669456508010626, 0.06455326359719038, 0.04137536570695894, 0.06705124955624342, 0.04505624176402177, 0.020367600921807543, 0.02745520113967359, 0.02865376030760152, 0.030973060854843686, 0.09964691155723163, 0.031330055091530085, 0.013874259128767465, 0.04119692796042987, 0.04435000216056194, 0.0072404665240485755, 0.027973456008891975, 0.07536155969968863, 0.061617378278502395, 0.048142229206860065, 0.011155386272418712, 0.040611165642206154, 0.01744452295159655, 0.02382349512273712, 0.016024374602628604, 0.04056638911632555, 0.030467443700347627, 0.07873940201742308, 0.06882876024714538, 0.0032677370763849467, 0.020920033599915247, 0.0913846959759082, 0.174525042197534, 0.05710816024137395, 0.1652118640818766, 0.16584945629749978, 0.34090250730514526, 0.09561038815549441, 0.08629488266472306, 0.12944765388965607, 0.13069572406155722, 0.1267091001250914, 0.20778252689966134, 0.10625328456184693, 0.08912060103778328, 0.1083256865718535, 0.16190480653728756, 0.17714372596570424, 0.1454209517687559, 0.12280026344316346, 0.0998603447473475, 0.07453122282666819, 0.12185583769210748, 0.14088976276772364, 0.08145325710730893, 0.20100892893970013, 0.10308550990053586, 0.16295209819717066, 0.10393154128853764, 0.09897453763655253, 0.13130240222173079, 0.09706345054187945, 0.15307148838681833, 0.14130326200808796, 0.0876448687964252, 0.07164542017770664, 0.1227437143347093, 0.11541172276650156, 0.09275731125048228, 0.12531277005161556, 0.08926600430692945, 0.15164550633302756, 0.05296202629272427, 0.12081458499389035, 0.1322716080716678, 0.15369422068553312, 0.13478296117058822, 0.08046361378261022, 0.1370261436594384, 0.14665672688611917, 0.1359685654086726, 0.15238449882183755, 0.15154616880629743, 0.12132812743740422, 0.21010485371308668, 0.1465795367423977, 0.09606354776769876, 0.08390336563544613, 0.13798586358981474, 0.09024216514080763, 0.059681049681135585, 0.16267993780119078, 0.15545070357620716, 0.07869555508451802, 0.1259849811238902, 0.13856077274041517, 0.15435256250202656, 0.16635691906724656, 0.09983631782233715, 0.0758069297298789, 0.128953788961683, 0.1324326108608927, 0.20903793882046426, 0.09228948849652495, 0.09046593920460769, 0.14492266279246124, 0.14364757335611752, 0.09492662163185221, 0.117035267076322, 0.13552564488989965, 0.1613660633031811, 0.10074831638485193, 0.13535815530589648, 0.16913797626537935, 0.12726273041750702, 0.1518200391105243, 0.0946989052795938, 0.09838353363530976, 0.12252122270209448, 0.12494490907660552, 0.16044294355171068, 0.10860569761799914, 0.11762453402791705, 0.18184381590357848, 0.18482171611062118, 0.090129019426448, 0.1339976383107049, 0.1625402681529522, 0.11433034150728158, 0.1379404424556664, 0.07612574619374105, 0.124646964349917, 0.09301749550338302, 0.0958360078345452, 0.057081894150802066, 0.0685348053063665, 0.07512437778392009, 0.10411946156195231, 0.1438601312360593, 0.13496540566640242, 0.1273718795606068, 0.12554363480636052, 0.11791850253939629, 0.16914852069956915, 0.1295300144702196, 0.06651509832590818, 0.11713556812277862, 0.07485318090766668, 0.10253289741064821, 0.21756917318063124, 0.17594828296984943, 0.18182922740067753, 0.13550268326486858, 0.1778383015521935, 0.11572416100118842, 0.1267328624214445, 0.25006895139813423, 0.11940866043525082, 0.18728544962193283, 0.15868594497442245, 0.09729723978255476, 0.12396772365484919, 0.10281554117266621, 0.15455464380128042, 0.10987960640341043, 0.04440477689994233, 0.18207568489015102, 0.11355980392545462, 0.15044686065188476, 0.10609539624835763, 0.06216948186712606, 0.06774489554975714, 0.12838129539574894, 0.14390188828110695, 0.05654302538771715, 0.17427952108638628, 0.10477453283965588, 0.12918158673814364, 0.10305916917111192, 0.17183649646384375, 0.13305414893797465, 0.13673327437468938, 0.24516927716987474, 0.11239820625633001, 0.09789264747606856, 0.1575754817043032, 0.1367011253855058, 0.10576485469937325, 0.09912030731460877, 0.10209531017712184, 0.09251742876533951, 0.132503354921937, 0.07001631866608347, 0.19112708419561386, 0.13640195929578372, 0.1420739556529692, 0.13197203486093453, 0.15001776867679187, 0.095951670913824, 0.07954397491578545, 0.22666797494249685, 0.08773708170545952, 0.15688351169228554, 0.09040201442050082, 0.25343703638230053, 0.03776248225143977, 0.07251028091247592], [0.02220817974635533, 0.032171655645860095, 0.04318951389619282, 0.028235881123691797, 0.07455529724912983, 0.06876609075282301, 0.03488592464210732, 0.017971939739904234, 0.04931442898565105, 0.08972001208790711, 0.011730743256131453, 0.027528679696843028, 0.04075410922190972, 0.020822926757058928, 0.03705584570499403, 0.04449986679745572, 0.03339508142588394, 0.0528635606834931, 0.014192598073610237, 0.03197669217895184, 0.04311631014570594, 0.057923603270735056, 0.008224489034286566, 0.0119685197382101, 0.02389729768037796, 0.030757076373057704, 0.03623710499544229, 0.022296122973784804, 0.04120938925604735, 0.02428913299393441, 0.03075943428224751, 0.021524450542139154, 0.019732610887980888, 0.0792287682582225, 0.019270206236147454, 0.022187667632741586, 0.029318103766334907, 0.07470648163663489, 0.02810605532223625, 0.052675036513911824, 0.024300366141168133, 0.04053932574710675, 0.031685682080153904, 0.02654715165096734, 0.04344182714287724, 0.010095916605288429, 0.02579127042554319, 0.06791490928402968, 0.05878397888903107, 0.038199309525745254, 0.04612381483561226, 0.017047965034310306, 0.034761026701224704, 0.05526991727362786, 0.016186354482280355, 0.037259820116949935, 0.041003766003996134, 0.040758584160357714, 0.030336537331874882, 0.03212616326553481, 0.03851991732205663, 0.05734616996986525, 0.020026681179712926, 0.028387124883010983, 0.07273495742785079, 0.0535857831793172, 0.007797548015202794, 0.0443321974016726, 0.008468071231618524, 0.022922035905399492, 0.036825371107884815, 0.01798641967720219, 0.051066820310162644, 0.016966245669339384, 0.16740929973976953, 0.05783755824502025, 0.025629085289048295, 0.05122425061251436, 0.019226949628708617, 0.03709914641720908, 0.01574436016380787, 0.012333161912725439, 0.0778522581926414, 0.03155451108302389, 0.04953080362507275, 0.013528917034688805, 0.01813891533363078, 0.04418597989050405, 0.028629414471132413, 0.01815991599245795, 0.03217470905344401, 0.0329530124685594, 0.012285595759749413, 0.07135156701718058, 0.006047030719595828, 0.02168178415325071, 0.04829719642709408, 0.03274443080382688, 0.03786920902452298, 0.010105691750400832, 0.02199354046024382, 0.028372689050489237, 0.06406140034752232, 0.04851294342162354, 0.02372037137060293, 0.0486473544234676, 0.029260645420955758, 0.019306526519358158, 0.04849743889644742, 0.05287607626191207, 0.06206075341573783, 0.024375676742887924, 0.041224106680601835, 0.011448130028189292, 0.022977904782497456, 0.0328181672043034, 0.021611465872930627, 0.059278332362217565, 0.007988339339915131, 0.04515190502362592, 0.05381987436807581, 0.05423693930996316, 0.012786543745148395, 0.021246525991175855, 0.04919559036248496, 0.06179488303938082, 0.022150263389838592, 0.014237586641684175, 0.038671027070709636, 0.009526029461994767, 0.04995408394773092, 0.020061025229681815, 0.05437486173052873, 0.04687193362042308, 0.015868252176525335, 0.026901771015088474, 0.042739550183926306, 0.07153652209256377, 0.03875887021422386, 0.00967861247980701, 0.021243650699034333, 0.07567773666232824, 0.04654596200478928, 0.062011417134531906, 0.019717622049418942, 0.01957086510291057, 0.027417922425749044, 0.016212905557560067, 0.05286761832290462, 0.044980703853070736, 0.04295589768194726, 0.015097373630851507, 0.017932640687961663, 0.08251496085098811, 0.016926288438428725, 0.013117392331228724, 0.05308719904028943, 0.021146632065730434, 0.014218069430041527, 0.015603703247117144, 0.049080544750073125, 0.045796465793890614, 0.06887647482965674, 0.015184982679784298, 0.03479906876704522, 0.04676565807312727, 0.012425979566095131, 0.029799965409828082, 0.01945423341489264, 0.0837656230266605, 0.057151898608676026, 0.06039464460419757, 0.046899953724018166, 0.012583773732850594, 0.021043365821242332, 0.002344586366754291, 0.022886782618505613, 0.03579931759408542, 0.03617126334990774, 0.030997684890670434, 0.05500805703923106, 0.046756145012165816, 0.07880418175565344, 0.022737029939889908, 0.029284960723349025, 0.029934389982372522, 0.03299283229612878, 0.03107524144330195, 0.017031081386708787, 0.054058057122996876, 0.04252621877406325, 0.022580373167459453, 0.03599162459639566, 0.08419415181768791, 0.0247044931165874, 0.021934830217755268, 0.03877809311130217, 0.01848399788806481, 0.005906330122213278, 0.0032084193330125083, 0.01920112288956131, 0.020039670036307404, 0.02436859792630587, 0.028752443048038652, 0.02729084638745657, 0.06769825983792543, 0.07818632133837257, 0.03233170509338379, 0.04950820840895176, 0.044187479452895265, 0.017242568877658675, 0.0518740598511483, 0.0611921064555645, 0.025572107007194842, 0.04283152899837919, 0.054973736737987826, 0.018640608859381506, 0.03934570122510195, 0.03974387575207012, 0.013484639232046902, 0.025474767766094635, 0.020543361847688044, 0.05255507491528988, 0.13267593351858004, 0.01778521708079747, 0.003815468991108771, 0.07132745188261781, 0.05023020359554461, 0.02380692190490663, 0.019812057160639336, 0.03666561343041914, 0.043266656542462964, 0.046947831154934, 0.012634107460533934, 0.0163123414718679, 0.0808791961254818, 0.0045513173182761026, 0.029663830929036652, 0.051597034359084706, 0.05192010523751378, 0.04819165709029351, 0.04285218021167176, 0.025836140249988863, 0.0681453329910125, 0.035723606656704626, 0.05105940392240882, 0.04923374777925866, 0.019828474315415536, 0.033217664874557934, 0.032450994942337275, 0.1087833855833326, 0.018592924810945988, 0.02452393325178751, 0.09743047013346638, 0.02821964378069554, 0.03837629520733442, 0.002987978360449363, 0.07086395139672927, 0.02936562496636595, 0.04114853823557496, 0.022973144859341637, 0.026876619418284724, 0.015947306595210518, 0.016140994416283708, 0.036903121042996645, 0.013193989604977625, 0.01679283077828586, 0.012857340392656624, 0.03820128406264952, 0.03335155001176255, 0.004948212382649737, 0.029675908852368593, 0.024444051020379578, 0.036120844805347066, 0.02034993695893458, 0.02068719091559095, 0.04150203123156514, 0.0699879355462534, 0.02666473837702402, 0.03088512271642685, 0.05438899561496718, 0.022559632048276917, 0.012895314604975283, 0.03769395360723138, 0.06390897424093314, 0.06499216718865292, 0.021376014221459627, 0.025961535217772638, 0.009653991836655353, 0.04433541365766099, 0.007598859391042164, 0.03383998665958643, 0.0026632688199502547, 0.020047535953511084, 0.04326591015394245, 0.04809509477178965, 0.09846231155097485, 0.01985948166943022, 0.031071909836360385, 0.021919926196070652, 0.029088908207735846, 0.025544617857251848, 0.03976709861308336, 0.041026381576167684, 0.07375974208116531, 0.04774648044258356, 0.012379939268742288, 0.0654512300555195, 0.028632104862481356, 0.025239212638033286, 0.02966170372175319, 0.027296778479857103, 0.04061623429879546, 0.016389753835807954, 0.03295173682272434, 0.05314848432317376, 0.03552644134366086, 0.004727310218316103, 0.05163650134844439, 0.01669150005493845, 0.0327477318766926, 0.016578881901555827, 0.059854917494314056, 0.019969182122232657, 0.036499674298933575, 0.053593521871204884, 0.01843446652804102, 0.040379476467413564, 0.00809112297637122, 0.07381886283734015, 0.03517580158742411, 0.061791076457926204, 0.0179260707726436, 0.0995053555816412, 0.028982449455985, 0.03455970536119171, 0.06528252589383296, 0.02248348854482174, 0.029897118053798164, 0.007305040157267025, 0.009389251221104391, 0.031956271667565615, 0.030379342713526318, 0.006228901429234871, 0.030832733027637005, 0.03039254361231412, 0.022105018674795116, 0.02248100171397839, 0.011727688152209988, 0.0354542825371027, 0.012604288390970655, 0.019207255149792348, 0.11365682086242096, 0.1282977813056537, 0.10909390356391668, 0.08837382575230938, 0.21813956328800746, 0.23378535945500645, 0.15505886317363807, 0.1839463109416621, 0.13155612003590378, 0.14486615439610823, 0.09912057872861624, 0.17373802300010407, 0.13879099967224257, 0.15646891322519096, 0.1220781257642167, 0.1314966260854687, 0.09349035977252892, 0.1920936301882778, 0.1354141208742346, 0.17202236077615193, 0.24362748275910104, 0.17665032244154386, 0.11587919268224921, 0.11191196806196656, 0.07620773358004433, 0.06371622279818569, 0.0721602246963552, 0.16993712766894273, 0.08163064651723419, 0.12540210597217083, 0.1539982586566891, 0.0687341181827443, 0.09175508788653783, 0.15372768603265285, 0.06276906933635473, 0.10574610677680799, 0.08522895843322788, 0.15398805349000863, 0.14719152104641708, 0.11853864283433982, 0.09048975578376225, 0.08617847319692373, 0.13136767729052476, 0.13085064717701503, 0.13010401438389504, 0.06847854796797037, 0.13459584835384572, 0.20000549778342247, 0.10199220678103821, 0.07533762098423072, 0.15172539704612323, 0.13197071850299835, 0.1318330301770142, 0.25512002035975456, 0.10030971813414778, 0.09136970035199608, 0.1620107665657997, 0.0719559992264424, 0.06394486874341965, 0.16262918338179588, 0.14485761842557363, 0.12263593583234719, 0.2410867219524724, 0.10943273681082896, 0.18597606702574662, 0.1559034221406494, 0.09212309813925199, 0.1382713368428605, 0.15715618777487958, 0.23155846180660383, 0.1057612584637744, 0.05480729888326355, 0.07484815974852868, 0.11830363901598112, 0.2469186218721526, 0.12307192172322955, 0.15641039636518272, 0.15513784464980873, 0.1340781668467181, 0.10224899835884571, 0.08140611249421324, 0.12637441951249326, 0.1764991312686886, 0.09228373451956681, 0.09094066944505487, 0.17230091297200748, 0.12580120669943945, 0.07635267544537783, 0.14593954251280852, 0.13483545263963087, 0.09497599862515926, 0.07398289189274822, 0.0941678159204977, 0.18736443109810352, 0.07924484953816448, 0.0919036463435207, 0.1192468162626028, 0.10461018487278904, 0.1278770353112902, 0.07363931568605558, 0.11871401699525969, 0.14292749842362745, 0.18756852086101258, 0.20350520499050617, 0.19334153751177446, 0.19098668172955513, 0.073623247976814, 0.10199064615049533, 0.3258120241974081, 0.2388410967375551, 0.22198763037366526, 0.06988107306616646, 0.16334319221121923, 0.09661803979958807, 0.11631816412721362, 0.13827569303768023, 0.11272513121366501, 0.12431844483528819, 0.10210033812161003, 0.15026584107960972, 0.1549147151942764, 0.0807823556076203, 0.07033796462097339, 0.07860408177865402, 0.11556333463106837, 0.08740016871265002, 0.12929448139454636, 0.11608571160052504, 0.13063230817871435, 0.10787047778389283, 0.07057634754372494, 0.1309537302170481, 0.1450501595224653, 0.2235722267734153, 0.12326485637043204, 0.10444942635617085, 0.11357851113591876, 0.1360742404524769, 0.08472401981375047, 0.12115355394780636, 0.18841366336813994, 0.15658302924462728, 0.17504933263574327, 0.14090929100556032, 0.12799066278551305, 0.11988538556865283, 0.07429050574345247, 0.09828007061566625, 0.09058397037110158, 0.13459815537290915, 0.1010567309068782, 0.11325608486575739, 0.06003816944680043, 0.20317507056253298, 0.1258968665663685, 0.13304018468729087, 0.15332293989402906, 0.2177146239472287, 0.04737519286572933, 0.10208836197853088, 0.18380736054054328, 0.11653137340077332, 0.11325518241418259, 0.08323363121598959, 0.08877432426171643, 0.08956656817878995, 0.09716654715261289, 0.14681436414165155, 0.11183044886482613, 0.18862056226602622, 0.13323124657784188, 0.1368465625814029, 0.16660831629165582, 0.08557323353098971, 0.12280056199857167, 0.09496350679546595], [0.029280373826622963, 0.05759730256561722, 0.04014662699773908, 0.011481515647444342, 0.01528153651660042, 0.04466341409300055, 0.039372672992093224, 0.04667227469118578, 0.05025634754981313, 0.04942320154181548, 0.017431803812671984, 0.049801834260246584, 0.034385657736233304, 0.031242310335593562, 0.040220831587378464, 0.015573956271899598, 0.05234816244670323, 0.017513075344530598, 0.05738975227411304, 0.04946575925818511, 0.039736303301262, 0.010005139645987322, 0.014866223891398736, 0.03441468207165599, 0.016244163969531655, 0.0494022076683385, 0.05903413439435618, 0.022684451957632388, 0.01754717681823032, 0.02471284588266696, 0.03134207194671035, 0.0662896754220128, 0.04460876148992351, 0.045198791793414524, 0.05290598947820919, 0.01322167128923216, 0.017881370581952587, 0.04794153890439442, 0.03402137603344662, 0.03933942477617945, 0.047379182651638985, 0.033124637723501237, 0.0150456183723041, 0.05668256950697728, 0.01718351088597306, 0.00906328299814569, 0.01701089836257909, 0.06213766536010163, 0.05481100029179028, 0.04475195952025907, 0.03434703891564693, 0.037969469358878474, 0.03463032728593264, 0.03273614589124918, 0.020317889750003815, 0.0277796087320894, 0.026892247776101743, 0.017448511041168655, 0.02547481356720839, 0.08701335625456912, 0.03300252177619508, 0.0212942219139742, 0.01106617588084191, 0.037153262977621386, 0.050597915292850563, 0.03056720531146441, 0.009652697531107281, 0.0041559099419308555, 0.015497356453644378, 0.0419793772245092, 0.028178248055545346, 0.04232183724109616, 0.037641638557293584, 0.01902312788713191, 0.006374774583881455, 0.021771299885585904, 0.07519547468317406, 0.017865993282092468, 0.009646449071754302, 0.03192325076088309, 0.010291253266456937, 0.021844892097370963, 0.05020417159955416, 0.027025154126541953, 0.06873729372663157, 0.06375116735164608, 0.023735109151207974, 0.0286053739754217, 0.018885573571813957, 0.03791602794080973, 0.04607970666672502, 0.04828744587887611, 0.05600685380133135, 0.03987862602142351, 0.002343305419864399, 0.022943791434434906, 0.06277758495083877, 0.02196153057073908, 0.030920148694089482, 0.028228878642299345, 0.04196486336046031, 0.09898170296634946, 0.02685423454801951, 0.003551560217082234, 0.02428329250376139, 0.04282091331801244, 0.03194805121581469, 0.04102375564564552, 0.055408796428569725, 0.10285763748522316, 0.03589163228337254, 0.03199514154610889, 0.04391595348715782, 0.0723619463720492, 0.02432752280895199, 0.027954960840621164, 0.023280529704477106, 0.0316653531709952, 0.023121957766956518, 0.07841059073273625, 0.022336545001183237, 0.025769733724051287, 0.0389031369372138, 0.02241046290977725, 0.022986006490620117, 0.015020736493170261, 0.025169477897829244, 0.018089838592069488, 0.07519971552704062, 0.07334342692047358, 0.0701719813847116, 0.024729290178843906, 0.030316992130662714, 0.028341369570365975, 0.08266555491302695, 0.05855571970875774, 0.011236172651738992, 0.04400056341130819, 0.01446478221831577, 0.028079801106027195, 0.038769859088850875, 0.02898985566571355, 0.005901413711918784, 0.0120596877033157, 0.033956338451909165, 0.07008681845452104, 0.04757635475003293, 0.04879393155819603, 0.05484856399042266, 0.01159192601751004, 0.008506315161607094, 0.04248685356495636, 0.026818792967657958, 0.014472500554152896, 0.007809411351835089, 0.026064019450651746, 0.016745818479518806, 0.017010879702866077, 0.008634434447490742, 0.03685818845406175, 0.033207907540989776, 0.08171536839966263, 0.03752442841817226, 0.043411730722125084, 0.03686011549351471, 0.058571522789342065, 0.027877607848495245, 0.06030247240726437, 0.015116143605804868, 0.05191461928188801, 0.07400977545018707, 0.03237088031268545, 0.014087214799863952, 0.04968314830745969, 0.04897160256015403, 0.015807090726281916, 0.04482021675046001, 0.02975746536893504, 0.0349874911563737, 0.03533842607534357, 0.02686632434571428, 0.06069109655384507, 0.025599190732464194, 0.10084211028047971, 0.006788870935062212, 0.04658761387690902, 0.05798540424023356, 0.0640375701976674, 0.02639855587455843, 0.04566314384075148, 0.021895344568682567, 0.02680314425379038, 0.03461822561387505, 0.02940609279487814, 0.010931283967303378, 0.030963866705340997, 0.020506106882489154, 0.011918325110205581, 0.05396266867007528, 0.03324178679447089, 0.043812734740121026, 0.025827063147776892, 0.009872478416322597, 0.028576322498598268, 0.026964074100500772, 0.016917572656114186, 0.01550309346722705, 0.06545733687068735, 0.031308314829532585, 0.013919345236250331, 0.0411183468199202, 0.01889522573245423, 0.01967705922600414, 0.0362152120630656, 0.0729771333613566, 0.02812767175159284, 0.025018720987385938, 0.01703950539896531, 0.025339890271425247, 0.013730766783867563, 0.07093453939471926, 0.05284956929140857, 0.01928392282154943, 0.012343540105835667, 0.017801795387640595, 0.02915239194408059, 0.026135287679997937, 0.022081193613952825, 0.03579236600281937, 0.050943822267332246, 0.07200678078723804, 0.05662611200075064, 0.02867824863642454, 0.05795387950326715, 0.025422398433355347, 0.04914026940241456, 0.049665211234241724, 0.024600590745519315, 0.034109310779188357, 0.025325327213587503, 0.025136155043063418, 0.017582725267857313, 0.03541624386395727, 0.044492881279438734, 0.04197091928550175, 0.058181168378463814, 0.03666961339435407, 0.026761553449822322, 0.031630218627729585, 0.018543537639613663, 0.025424328865483403, 0.04019106425611036, 0.05166449091796364, 0.01885401490809662, 0.05074445510815297, 0.03972943991954837, 0.025302167117063488, 0.004167706697314445, 0.009843857809236007, 0.05323901107268674, 0.05600320328293102, 0.032461844717285464, 0.07990180714321987, 0.06650445211146559, 0.07946686619626624, 0.07410737592726946, 0.030938004343105212, 0.011980746939246143, 0.03721945406869054, 0.06781549033309732, 0.06202706415206194, 0.03225923076804195, 0.018673636551414217, 0.016648133185559084, 0.032926132303795645, 0.031475322653672526, 0.04544780396723321, 0.04820086481049657, 0.020609590258183222, 0.012886211209531342, 0.02234324553449239, 0.010247746449229973, 0.02879818987899593, 0.021468610502779484, 0.042170578214739046, 0.05108694905149085, 0.026816399435379674, 0.017382515028917363, 0.03977926813864282, 0.01793395365322275, 0.0585614126175642, 0.033523236334856064, 0.06486427690833807, 0.06919465347060136, 0.021514988371304104, 0.03824644396081567, 0.0349096292629838, 0.025392963584246378, 0.015123363218403288, 0.021119763775329505, 0.02160529968594866, 0.020021434407681227, 0.017743327721421207, 0.009232505390952741, 0.01857541860746486, 0.015595839026251009, 0.0343289797061256, 0.023298643196799924, 0.038609473766492944, 0.010390550081085945, 0.04197058001799243, 0.07576125075242349, 0.023678108816966414, 0.0446916038303503, 0.035278945695608854, 0.04419828173039215, 0.029743311128446033, 0.012263448376740729, 0.025012882193550467, 0.025398308743855784, 0.07345803827047348, 0.07141733063118798, 0.010451047415179866, 0.008271070463316781, 0.0613828290786062, 0.04795670755473631, 0.10316543454038245, 0.06454742819603, 0.026747445010447075, 0.02946647223351257, 0.020461045371900712, 0.06032487763358014, 0.03002369197617684, 0.005401890225974577, 0.0268875743661608, 0.08113770439688649, 0.03329084148364408, 0.00902091187890619, 0.06459238114101545, 0.017002832277544906, 0.053685884057943306, 0.013039042740794165, 0.033287503091352325, 0.021148034936881492, 0.018925688562116454, 0.09609493001231126, 0.07749098579266242, 0.008560972005527998, 0.03137625654094985, 0.03772940027660557, 0.039827698575598855, 0.045259578353060145, 0.24594286137393542, 0.11960665695369244, 0.09416331723332405, 0.11005888214068753, 0.14231110364198685, 0.161713106823819, 0.11639124234872204, 0.17101852249886307, 0.2012860562120165, 0.1506128167467458, 0.1729657415832792, 0.20179555458681925, 0.08378755327846323, 0.11943576112389565, 0.12988533611808503, 0.06445256221507277, 0.11119350804282085, 0.12201945962650435, 0.14947582275739738, 0.17883758007415704, 0.14179586486092635, 0.0991060377231666, 0.13531478334750446, 0.10428798251918384, 0.06359232908913068, 0.14455127343535423, 0.13406683531190666, 0.06566115521958896, 0.188399875536561, 0.14666311868599483, 0.07692565755652529, 0.19532395899295807, 0.09799747435109955, 0.09888776657836777, 0.12184369191527367, 0.14109401537903718, 0.1262861963893686, 0.0714174731235419, 0.14765274843999318, 0.11024833590324436, 0.09591677385781493, 0.0806899798501815, 0.09046782553195953, 0.17219232022762299, 0.12812585410262856, 0.11884878762066364, 0.1078371142170259, 0.10421037168375083, 0.13840730168989726, 0.1561419271997043, 0.11477147069360528, 0.12608023386980804, 0.10092240811458655, 0.06754539268357412, 0.09689322646175112, 0.06486866702990872, 0.08534598536789417, 0.12392775794225079, 0.12626744168145315, 0.17176290255572113, 0.08991297387651034, 0.10513644984790257, 0.14272180731807435, 0.12513973005115986, 0.11552153687391963, 0.07371663475143057, 0.1356958214725767, 0.17584712696926935, 0.12325497690056052, 0.18994461478931562, 0.10687736714524881, 0.13537775139723504, 0.17604658912335122, 0.2465958020516804, 0.12852632547063486, 0.15707332507840224, 0.24546115579349653, 0.15893540158867836, 0.15484273619949818, 0.11366872236664806, 0.12621999851294927, 0.06910887985889401, 0.13832823878952435, 0.13212565518915653, 0.08725601394793817, 0.08751581143587828, 0.17882867769471236, 0.15654428489506245, 0.25135594233870506, 0.16523338721266814, 0.14968190741326126, 0.08408003579825163, 0.2277965008148125, 0.21332128612058504, 0.09904022661170789, 0.1344285894717489, 0.13114222724522862, 0.0986881415758814, 0.13746122031339578, 0.10126179097486393, 0.14881836303642818, 0.09843787750495331, 0.08005727308669261, 0.12967785368008272, 0.10337353444525174, 0.09168846931840692, 0.146940856639828, 0.2054051301841225, 0.17690998422248022, 0.30565340018698145, 0.11760180310479232, 0.09318792314401694, 0.27485811550702366, 0.1297014666987317, 0.15614716549004826, 0.11641113699546882, 0.1446910109370947, 0.12680136731692723, 0.09790234374148504, 0.13255463859864644, 0.126770249700972, 0.07711511131908212, 0.06848071928003005, 0.09970051582370486, 0.09185950764055763, 0.08219552013490881, 0.0637429231511695, 0.1334305458835193, 0.13877330347895622, 0.2738720141351223, 0.19828292807298048, 0.14686306938529015, 0.07423509657382965, 0.0779805691646678, 0.17112388541655882, 0.22337288675563677, 0.1051020413371069, 0.10466579081756727, 0.0949343094336135, 0.15379798226058483, 0.10166699173195021, 0.0726221441956503, 0.14917561172374658, 0.11125868811671223, 0.1521615186440093, 0.08343735456998859, 0.18832176258521421, 0.09212149001125779, 0.14592329838446208, 0.09324210416525602, 0.13650709151157311, 0.12188342692596571, 0.13421631657651492, 0.12716237508824893, 0.12436153180897236, 0.21036565543285438, 0.14203664979764394, 0.12423867625849587, 0.07788303654108729, 0.13249655600105012, 0.1388271248766354, 0.10435300653002091, 0.1323914916387626, 0.14265334313469274, 0.10469331898327384, 0.11113151708351714, 0.18842407209532602, 0.19063556699880532, 0.16089864767023496, 0.2165130605655057, 0.1453015296054738, 0.10722287039139441, 0.07270885418568339, 0.13430406472512654, 0.09418699810547487, 0.10661520157009363], [0.024865904723161032, 0.059568148239382675, 0.03097869948084865, 0.008808097851994847, 0.0327234844278012, 0.0800147492970739, 0.045269189801599295, 0.010011348241407956, 0.011094400393111365, 0.04020269434633, 0.004320148495025933, 0.03686947249142187, 0.029229364956596067, 0.012815855609785234, 0.037257760763168335, 0.09457253491772072, 0.03372199959786875, 0.016956771624141505, 0.016781241400167346, 0.014010228216648102, 0.032273893909794946, 0.039150015118398836, 0.04204401107771056, 0.038770544409219704, 0.10136138634490115, 0.04648818474795137, 0.04977197193407586, 0.07485864989991699, 0.02325144430090274, 0.03043899611969079, 0.03627616486379078, 0.022813984292692373, 0.03324693348258734, 0.057115658053330014, 0.05456730783251779, 0.04951643564605287, 0.02818634976366801, 0.055875289253890514, 0.04132244676085455, 0.03189838584512472, 0.029371402692049742, 0.04786974650674632, 0.04391588902633105, 0.017355198905404125, 0.009189588051023228, 0.05495778777237449, 0.035275240894407034, 0.09688265488616057, 0.03754695238811629, 0.05457783530333212, 0.04209341860509344, 0.04015939024143985, 0.040128659390445263, 0.02031223924963602, 0.02890313889033028, 0.04869531327858567, 0.019338051256324564, 0.04028378267373357, 0.04187639257205384, 0.0021114124725240147, 0.03597354503082378, 0.04655485420620867, 0.012899007531814277, 0.0257720373504396, 0.01648315927013755, 0.017060095544106195, 0.02518529794178903, 0.05079178971105388, 0.054084072155611854, 0.016543625221986855, 0.025799996385883008, 0.02073113962874881, 0.005624143099079707, 0.015570248078022684, 0.05755972529628447, 0.042994720063039234, 0.029409258160740137, 0.07425795641860791, 0.018147473356553485, 0.032405268467430554, 0.016954301756673625, 0.0650498087384871, 0.04005834280646273, 0.056720251949237924, 0.0072094252432829565, 0.021801744055535113, 0.011112589372455009, 0.04393361575369324, 0.007034816554680998, 0.03185260169474142, 0.0607280292149101, 0.03497932498742427, 0.04217843904293009, 0.05438990145921707, 0.016556637827306986, 0.05479170275585992, 0.04223733588254877, 0.04229334216298802, 0.04194519602294479, 0.03782107035762497, 0.08623061861310687, 0.023946515217955624, 0.03192679949903062, 0.01985468273051083, 0.052914925784404786, 0.026205773897735134, 0.08728635803397213, 0.03694299854604261, 0.06900921663535492, 0.011083709225723786, 0.02936011186933943, 0.03861107171646186, 0.015407530291538154, 0.043818943335541656, 0.1195734358791794, 0.04062401370278426, 0.008383763255551457, 0.06475797761231661, 0.015299076646832483, 0.0296862463333777, 0.019713905373854295, 0.07501480794910874, 0.05233108711295894, 0.009783771836997142, 0.045664409308561256, 0.02340711041220597, 0.040038529583918195, 0.01628324928294335, 0.024662086374259422, 0.03373605545078005, 0.03828413997377668, 0.005366132278660578, 0.023507397887962203, 0.029862064934734787, 0.0640597107953259, 0.08150650175022227, 0.040230490533368926, 0.06646908686629363, 0.0030525066166384412, 0.017290699062868953, 0.016926704041127647, 0.04543537659836667, 0.021656088032094494, 0.0614907636440226, 0.025729971571958492, 0.03884106794638293, 0.007285183678115053, 0.04204178887552448, 0.007939675656546439, 0.06271454226225615, 0.01957352156750858, 0.11380717065185308, 0.02519799842100058, 0.05095986283517309, 0.021777720523199866, 0.01811918183895094, 0.0537209812817829, 0.033717015758156776, 0.017028874451560632, 0.05331952603799956, 0.027090152692315832, 0.044672106126589436, 0.00989941880106926, 0.04483439813234976, 0.03231457208416291, 0.07541186628597123, 0.08219871603484664, 0.04664624608787043, 0.0449838352921818, 0.04833241578723703, 0.02314401524407523, 0.017669962818867395, 0.017352649310071553, 0.03157785268766539, 0.04103795738358583, 0.028960705801312412, 0.0887425145400422, 0.043808782273637395, 0.0332865599276764, 0.040096055782799206, 0.029974515150700296, 0.06969970065568175, 0.08443982899188995, 0.022760602246437753, 0.05026674609897392, 0.041035287348287444, 0.03572986953492675, 0.02581212859201644, 0.08173598907887936, 0.040853711377297125, 0.06006317346223763, 0.07135749062789337, 0.025848861085250974, 0.02028993241089795, 0.07665828083242689, 0.064584577988301, 0.014269701704116804, 0.03051883594266006, 0.024118405101554732, 0.03494217519515327, 0.07194150571844407, 0.029977945145219564, 0.03163939242118171, 0.07651767480586256, 0.018592750088178685, 0.08668913865195853, 0.010825423174537718, 0.0425565119699708, 0.02984006004408002, 0.034229000963802846, 0.05806627204375608, 0.011097963550128043, 0.05405233368011458, 0.05363533998440419, 0.061234881303140094, 0.02459033977772508, 0.010457362031697162, 0.062319309184593816, 0.01824818322035883, 0.028545289699520384, 0.028353834258658544, 0.010557227967573064, 0.07322887663862535, 0.022606973436528018, 0.014654546410643628, 0.025683323985763958, 0.02502449362405709, 0.029270073665039878, 0.06710675372076885, 0.02470478997565806, 0.06802689470350742, 0.008633482802127088, 0.025573206233925054, 0.010541789599561265, 0.05744438112846442, 0.013562568130769899, 0.07023841674838747, 0.07916644481675965, 0.007983676107999469, 0.05756188303764377, 0.03213566275579589, 0.04173651936330965, 0.048834965963448794, 0.06491781332130943, 0.035906845038490634, 0.06324793864041567, 0.0326473256573081, 0.03145897335239819, 0.06351511180400848, 0.025802267781857933, 0.023285837544660484, 0.02188706983413015, 0.07922446634620428, 0.03126005741900631, 0.0369145407873605, 0.04475320802469339, 0.018520496286717907, 0.05202651988448841, 0.05026597596172776, 0.019122965833438293, 0.00796447865598436, 0.023506855059947287, 0.03626122013000505, 0.00965270516462624, 0.031000354925968816, 0.07021016255021095, 0.009440766447888953, 0.04877163829015834, 0.03287721671430128, 0.05869521972324167, 0.045048743952065706, 0.022468229988589883, 0.08100486759628568, 0.03798679235790457, 0.01573175298316138, 0.021512867949370826, 0.007935925902399634, 0.025906799494155815, 0.011787844522457038, 0.027329390569190894, 0.014432355029774564, 0.013032601747129644, 0.02004117299137371, 0.028993401011185985, 0.029279410306896483, 0.05158919049426913, 0.03405890580532806, 0.018871561823678867, 0.030072546497519528, 0.07562831895692007, 0.039195432859872065, 0.017862174826275026, 0.03151833838117974, 0.051248983213944097, 0.02368679067253002, 0.05702968766646726, 0.059527307216610224, 0.03915751971570509, 0.009380008725981628, 0.05297699477523565, 0.006280668562145105, 0.05970462877303362, 0.00798339960497937, 0.05475321964227727, 0.05736925373119967, 0.014167186937161853, 0.05514271570635693, 0.017180907007839, 0.06251087997640882, 0.030672028793820312, 0.024321215825953653, 0.0938337052773152, 0.024585825823513523, 0.025607986242643425, 0.03978402127644845, 0.01962076796085707, 0.020865581164668714, 0.03660712371181164, 0.02461453464015254, 0.02218423254920968, 0.023746566214997853, 0.03278621159760015, 0.054755075435553274, 0.018517660010339956, 0.03871089778840542, 0.030978020945830003, 0.02457910493415381, 0.019105217053688, 0.02100842126778194, 0.030495402735791037, 0.043720966271523914, 0.05487891825448189, 0.05950682902974742, 0.05319640585886581, 0.03587123891338706, 0.01374428320143904, 0.029182376406554664, 0.022609836854306713, 0.042702529313308854, 0.02229252504184842, 0.018986822870959128, 0.05605760482805116, 0.028799662299986397, 0.013387260127014347, 0.03113754792138934, 0.05807113713983979, 0.015538283989631703, 0.013226853600437087, 0.10266821764941726, 0.03704415115394762, 0.046652783772775104, 0.025927800152982985, 0.17104274619902882, 0.13796716316470078, 0.08188689526702676, 0.127079308831266, 0.13152291253209114, 0.2042456359735557, 0.1403635045779603, 0.255449326975005, 0.1645500345953873, 0.12493425607681274, 0.1394481879792043, 0.10305835492908955, 0.14105125410216196, 0.08791627601853438, 0.14816660300961562, 0.16220657820148127, 0.19288310568247521, 0.15143615113837378, 0.1635174128626074, 0.10129001124628953, 0.19022829670991215, 0.11633686455232756, 0.13842331511633738, 0.14868858642876148, 0.1712730409843581, 0.1585578647043024, 0.1650099999138287, 0.22381557657250337, 0.10334434386874948, 0.21839315896587713, 0.14414483095918382, 0.14774208436054842, 0.10777987300285272, 0.11613858304917812, 0.11183205699282033, 0.16099201408880098, 0.1009093327447772, 0.18944319098123483, 0.10401249051626239, 0.09866796194442681, 0.09404833268906389, 0.2179769727268389, 0.08521603234112263, 0.10409459325351886, 0.07573011278041772, 0.13827718581472123, 0.12694041271294865, 0.15274946923766816, 0.14974552685660975, 0.1390741794769253, 0.120189029989498, 0.09016600637031452, 0.16853123025170394, 0.13781498133071832, 0.14115406572818756, 0.1289750135370663, 0.07388643135449716, 0.12584115884133748, 0.21752665617636271, 0.10419309618217604, 0.12718936721129076, 0.15746314344661577, 0.0885900477213519, 0.09626676900578396, 0.11650470697454043, 0.08863295149058104, 0.11865227030856268, 0.10309710606400456, 0.3108656347862312, 0.13572655910892145, 0.06063050337667976, 0.07693668375057833, 0.10893387786511864, 0.07808632563267436, 0.15987134565200123, 0.11729095264204911, 0.19754245637782983, 0.12248439182128225, 0.12133555061050824, 0.1956565768590995, 0.11072430786277566, 0.23181038828832762, 0.18618387516055787, 0.21604032521801336, 0.10887027877782073, 0.06030591257980891, 0.10233011722032513, 0.1638176238962582, 0.11282759000148092, 0.19724915283066885, 0.13303950615227222, 0.10806114612413303, 0.08753519039601088, 0.09953881414341074, 0.12759722104029997, 0.07811109216085502, 0.1696475153522832, 0.11697195975908212, 0.11458348935203892, 0.09251051449349948, 0.22973442396947316, 0.07877560864601817, 0.06410871459437267, 0.14496112215731824, 0.11934023696397032, 0.1223982178739139, 0.2046076072646039, 0.11883452481457166, 0.12251298528696809, 0.14021216412740095, 0.11199911231441156, 0.10784890715565, 0.11774585608925138, 0.1378233137407473, 0.23978909158280917, 0.10214007313230208, 0.06530257660363402, 0.13312645362956183, 0.0949355104405965, 0.11816016957163811, 0.09941535469676767, 0.11651343293488026, 0.1322166874472584, 0.1734997486429555, 0.12339738783027444, 0.12250807269343308, 0.09746964196009295, 0.12515596060880593, 0.10213148966431618, 0.11862191265182835, 0.14240654637770994, 0.07710018354867186, 0.1217895041086844, 0.0654953144756811, 0.10647519265434571, 0.20632430086178438, 0.11958255538983004, 0.14772079193166324, 0.08327886236033269, 0.12149421923926898, 0.0954880550769823, 0.17010741281722272, 0.07159577855574233, 0.18113180196710996, 0.14004844719810144, 0.1802550804402147, 0.13441123254597187, 0.11191209698362009, 0.13890377219234193, 0.09924636555037328, 0.1272365389657872, 0.2122548326317753, 0.1862972312207733, 0.13062587566673756, 0.13944893436772482, 0.12923814941729816, 0.1101538770432983, 0.09185097167002303, 0.1522988405610834, 0.09966954070010356, 0.10909378142761332, 0.09522989964378731, 0.1298773836876665, 0.1150895000568458, 0.0992146779650024, 0.16972029501838343, 0.15242534662996018, 0.19077121971973351, 0.10591256498758282, 0.12214615568518639, 0.059883653452353816, 0.05786509319607701, 0.3101030428494726, 0.07182287065578358, 0.11416145414113998, 0.15612268394657544], [0.04282397351094654, 0.06375339973185744, 0.014587558040927564, 0.041719240469059775, 0.05648455263248511, 0.04231575078197888, 0.03207443854106324, 0.04669058495866401, 0.13605832202093943, 0.0808249811774918, 0.011571590323001146, 0.02782580509249653, 0.030463640511568104, 0.042285240454865355, 0.017581909329497387, 0.03649992196421538, 0.03228077764755913, 0.02626365632750094, 0.06076640037021466, 0.058272085285612514, 0.0428659646505756, 0.03814795121018376, 0.05312432847650988, 0.014589203488347786, 0.015410118902634298, 0.016280099184119275, 0.019214366196787784, 0.039941139452691586, 0.01885520912972944, 0.06153647654822894, 0.05994662828743458, 0.044668662561369796, 0.027962341605286514, 0.027623710222542286, 0.03851685034377234, 0.04629310253741486, 0.020853677964104072, 0.02400563427779291, 0.042942208237946033, 0.00929086109889405, 0.019275181594171693, 0.030915236100554466, 0.01944706299608307, 0.015515200228297284, 0.05672803474590182, 0.021309460114155496, 0.042782090936920474, 0.06086554790713957, 0.09528397209942341, 0.04932720919272729, 0.03866639267653227, 0.03896210163033434, 0.06085471848824194, 0.06449045161051409, 0.041785970995468755, 0.027402468790699328, 0.013447180706342416, 0.008847446097726268, 0.013240833118158792, 0.02979527334017413, 0.02667083331782903, 0.04623480620128768, 0.025513384890343462, 0.01272887590208224, 0.03527904408318656, 0.008459061982908418, 0.022850886419681565, 0.030632035939821174, 0.05084325659221836, 0.08782281460506575, 0.030957688643996204, 0.0888934207281896, 0.07502172222094876, 0.08644359039941005, 0.0245269493399454, 0.018282527270327722, 0.027995869716895477, 0.05644702625327876, 0.002465443419558661, 0.027731135886694704, 0.045958469422268014, 0.023603057754891257, 0.033734840873096666, 0.037974205533308644, 0.02414157028709139, 0.037815038181309185, 0.030200134829751084, 0.05714442115277052, 0.03072403171764953, 0.010200665448792279, 0.02846981624939612, 0.02228286100684532, 0.053125644834446054, 0.014514569725309099, 0.05404794016586883, 0.014164287048125905, 0.044870567441518815, 0.06844688752400023, 0.06112911126443318, 0.014672985599775399, 0.03665139812177845, 0.038946644602609534, 0.01461334406797375, 0.04548983581896339, 0.040490433906338046, 0.03411874580862267, 0.021501407492905855, 0.025963407974424105, 0.015272391560886587, 0.028042347669335346, 0.06759950585131135, 0.013658543516482626, 0.029715436909879957, 0.041179448898349486, 0.05137786415538617, 0.03583338683737176, 0.030207150881843906, 0.07137150237602846, 0.03167758037203124, 0.024938034691980908, 0.04911488201469183, 0.0390815543276923, 0.015640605374106338, 0.027714286165844117, 0.042115803475358655, 0.0448545608004289, 0.048165238329342434, 0.020672091815088476, 0.06496551433312041, 0.015314096019470265, 0.07778327832264559, 0.0817422451717513, 0.011411554446177823, 0.05292715298544083, 0.021973688221935714, 0.05609402519517711, 0.007133887332331921, 0.07465925559933696, 0.06604166408734662, 0.03246166151283043, 0.0444742215664259, 0.0187925260647067, 0.019029512901657393, 0.07922614911305052, 0.055271087746535025, 0.023707575896488767, 0.04760214925876685, 0.06675971020013094, 0.039181346472884925, 0.05216433713212609, 0.014449883285643799, 0.05080475990793534, 0.05610528548381158, 0.03756397683173418, 0.03587147979331868, 0.01840096725417035, 0.02821917728787022, 0.05139824395467128, 0.017384874634444714, 0.0041145646828226745, 0.07328026888093778, 0.04345265995444996, 0.06239734749708857, 0.03699442471510597, 0.039573699169393094, 0.00866710506046989, 0.08111642553870167, 0.06830748250441891, 0.01668504549057356, 0.01732253931861903, 0.04779160302132368, 0.011098417320421763, 0.026099479690726315, 0.0539431811443397, 0.017782085641686405, 0.03199914490271892, 0.04169261136225291, 0.04758141322859696, 0.045155504651899846, 0.03841855097562075, 0.01952726922796241, 0.03502786398998328, 0.016800986769210016, 0.006173935851880482, 0.06542338976370436, 0.021071810009224073, 0.005394603608043066, 0.034907522411750894, 0.0744009373177375, 0.04883441635008369, 0.03898000816947647, 0.03837042248674801, 0.015535985452256032, 0.019019606290385127, 0.06456291915050574, 0.0767748463632805, 0.020434479029583077, 0.0472198287025094, 0.0860198927777154, 0.02508526830933988, 0.01716231514832803, 0.05131330154836178, 0.0259348704878773, 0.02855301821338279, 0.053867514311735115, 0.10048035612063748, 0.02686531502487404, 0.11153669748455286, 0.04480981820129922, 0.020933455022584115, 0.03131974475192172, 0.030425622194473232, 0.036028540294085226, 0.034348429912435155, 0.07221335398831538, 0.04004280774721077, 0.03369846800342202, 0.06403402145951986, 0.053444016857870986, 0.035632611718028784, 0.05569123663008213, 0.04334688652306795, 0.026003075131614293, 0.03105942139934216, 0.025293022161349654, 0.010272068536973425, 0.02921203856489488, 0.029664621422333375, 0.012882804963737726, 0.03962250958595957, 0.03487702226266265, 0.053626393500183306, 0.04101019851597292, 0.023476207329492484, 0.01731307036243379, 0.0076417020921196255, 0.029914783713008677, 0.0156972783152014, 0.018773264151864817, 0.03410902918715562, 0.03783021361700126, 0.022929289444748844, 0.03527032830087202, 0.058505331698272905, 0.047129624257130284, 0.05108499487063714, 0.03078872663900256, 0.015503493802888053, 0.028870382612305026, 0.06477375355150018, 0.019945708203262517, 0.02054938893499119, 0.02292747775624905, 0.02493035197923226, 0.014620468685669559, 0.04525288460510118, 0.0414761960107301, 0.04728230481435146, 0.029264075415475026, 0.015198711139549102, 0.029284322900431495, 0.0014723347953154839, 0.04008866314377103, 0.058596438595226834, 0.053842489940247366, 0.019847585254215767, 0.0036530875035428573, 0.045138911078018804, 0.04517306853085756, 0.02065033628605306, 0.048562323807605674, 0.11442307010293007, 0.04270317392157657, 0.060295890617583475, 0.05995335935481957, 0.04411994146981409, 0.01155377708242408, 0.05464972948123302, 0.05727098150444882, 0.06575031472103936, 0.06144897945757423, 0.045839939532535415, 0.027078200297962342, 0.01969123212620616, 0.038652075587638786, 0.025060727394052913, 0.003797379247511604, 0.03849658250276532, 0.059464115250323496, 0.013453760799685759, 0.026156639480697255, 0.005818479769264481, 0.026254579225288968, 0.037357288279703686, 0.0708435003512672, 0.01474601632383253, 0.042671703467411656, 0.06041440354394061, 0.042044340167194605, 0.06269822349505765, 0.020599493657105734, 0.020204920454749038, 0.01682765149910535, 0.015591562559295977, 0.0456343671706106, 0.07288707819368158, 0.04729936318472028, 0.0800333750833358, 0.009516431584155985, 0.05270783689671329, 0.07313438385192837, 0.018033696604626517, 0.01072219933848828, 0.08231632650962897, 0.06649116639580045, 0.01963132426940969, 0.02591562893108598, 0.035528039293629785, 0.017710637600560273, 0.039902378139751296, 0.02123150322586298, 0.023120261429409896, 0.03902341405461941, 0.030941050965338945, 0.04222791442381484, 0.0632434535239424, 0.09357166183846337, 0.016019731726763502, 0.0381759916698294, 0.05354783950107438, 0.03934934495815209, 0.03751322580501437, 0.022204571636393666, 0.025438249011390975, 0.010410080015260195, 0.01760736626705953, 0.06213650506521974, 0.02500622746135507, 0.025656803444560086, 0.04158725183723228, 0.08784677367657423, 0.06433558277785778, 0.008806074121301728, 0.062441146932542324, 0.05548152859721865, 0.0043269257876090705, 0.10903259113963161, 0.02473416375661535, 0.047006510863346715, 0.028581157060606138, 0.022294333337673118, 0.06990748843444244, 0.09947015318487372, 0.23490298805492266, 0.11402451220367636, 0.13953034499926226, 0.08761578678552594, 0.11406093596347741, 0.10932189811553274, 0.12067078985273838, 0.28121444157191683, 0.08957047654049737, 0.17647996943976196, 0.15809632518461772, 0.09564320889434644, 0.2055410271776574, 0.08828928707433598, 0.09983120166829654, 0.14772767227675232, 0.12431706062385015, 0.17802975699305534, 0.3170861452817917, 0.10450727146651063, 0.11136645983372416, 0.16869467576699598, 0.12506814460669244, 0.11322287057659455, 0.119141996172922, 0.07203935046813317, 0.1586742198893002, 0.18220922058182104, 0.20755669687475475, 0.10043131839483976, 0.18149578172181333, 0.12838429452053138, 0.12294446570532662, 0.18204866562570843, 0.11882507960711207, 0.15387868721570286, 0.10658246904079403, 0.18071349869881356, 0.10712183652711765, 0.08837799874267407, 0.1960286854633263, 0.09462715020137173, 0.057916682213544846, 0.10844408414725747, 0.11403253248759679, 0.24408690524952753, 0.10173249750265054, 0.14644192984061583, 0.10029957403561898, 0.13014343726847852, 0.11861815356782504, 0.14986760887716497, 0.1130940778447049, 0.1650569545371192, 0.10668000166437455, 0.1214640380016395, 0.06853207759559155, 0.09095720534345933, 0.09777908785534756, 0.14891575995300496, 0.11227083166262933, 0.07552170753479004, 0.0858817430479186, 0.10849594457873277, 0.1259694562426635, 0.13791026121803693, 0.18813528759138926, 0.13609830130423817, 0.18688922588314327, 0.0977758512433086, 0.1400040845785822, 0.18495677172073297, 0.20750500607703412, 0.12481237761676311, 0.16743131141577447, 0.10608349474413054, 0.11032237764447927, 0.11372316123119422, 0.1577567591198853, 0.08715517007346664, 0.1674181478364127, 0.11716135245348726, 0.08745823773954596, 0.13073125215513365, 0.11311304968382631, 0.09867900170918022, 0.09144916358803, 0.11705905651407582, 0.13768885524145194, 0.09194492162870509, 0.18875092241380895, 0.12495850691837923, 0.09907713213137218, 0.14678471216133662, 0.1334353227700506, 0.11140465456992388, 0.18189820727067335, 0.13347751407751016, 0.07741176004388503, 0.1530727097498519, 0.14237135755164282, 0.14320295649979795, 0.16636537361357892, 0.16929863978709492, 0.1178998699677842, 0.06478663214615413, 0.11912993182029043, 0.08547658978828362, 0.20809906348586082, 0.12052520337913718, 0.177744080179504, 0.10999733222914593, 0.09536926395126752, 0.0958674850740603, 0.10774280463478395, 0.1046901773661375, 0.0989315863698721, 0.15981917987976754, 0.08004805858113936, 0.12120577400284153, 0.11983872950077057, 0.12317351198622159, 0.1371107298348631, 0.10806164145469666, 0.22480086370238236, 0.11445082218519279, 0.13004076134945664, 0.1300913393497467, 0.1779327807681901, 0.1625308772282941, 0.13999207450875215, 0.11786854879132339, 0.09445155212389571, 0.1521388827157872, 0.11442178088639464, 0.14151363500526973, 0.18639423458703927, 0.15249154450637953, 0.08656913294856038, 0.12195859503533159, 0.09453403484076262, 0.0933051197124379, 0.12346612342766353, 0.10823452539209809, 0.0772198431992105, 0.11856130590396267, 0.13150645127253874, 0.1467836129346064, 0.13674183748662472, 0.12955502527100698, 0.059591720545930524, 0.1316771028297288, 0.09282628433512789, 0.17608678553785595, 0.1297004081841026, 0.06891699015562024, 0.07678008465362446, 0.1296964862516948, 0.07558732865644352, 0.1485836442027773, 0.1432170428867851, 0.12039888730006558, 0.1805097074913127, 0.14177854864725045, 0.13244037330150604, 0.12333861312695912, 0.15575423943144934, 0.1284790722919362, 0.09389182858701263, 0.14533200939851149, 0.1082297960030181, 0.1219750020120825, 0.10234708059579134, 0.10409958048590592, 0.14212175165968283], [0.004824844538234174, 0.05404993166614856, 0.007912882853166332, 0.01803566944519324, 0.023595905995794704, 0.03941135288083127, 0.032286463771015406, 0.038175330098186216, 0.07535139524510928, 0.017210866025249873, 0.035017937022660456, 0.004722012980242393, 0.020866924664005637, 0.04534055472218564, 0.02640884416177869, 0.03340035364297884, 0.01491045589292688, 0.040565686832581244, 0.016871545929461718, 0.013923645451931017, 0.005698987632058561, 0.008746011897788515, 0.03349045291543007, 0.06037464139184781, 0.01892757828214339, 0.03073219788659896, 0.019752069575978175, 0.07618038861879281, 0.0036540196410247256, 0.039190197962203195, 0.036521838645317724, 0.022131987049111297, 0.021766601030581763, 0.009472853520752063, 0.04579306633344718, 0.07556684368423053, 0.010982348816469312, 0.09689805763108389, 0.017289633762889674, 0.022925415009792362, 0.038703630678355694, 0.02284103918022343, 0.0765880388872964, 0.08057785193834986, 0.016959930204653313, 0.030341578847063438, 0.02568319845678551, 0.03823421336710453, 0.009136094046490533, 0.040157358029059, 0.0908131862857512, 0.03263257769867778, 0.010528986491928143, 0.011427472877715315, 0.035561809981507916, 0.073322229486491, 0.07457070677940335, 0.02666992916991668, 0.022731218287455182, 0.03771034022793174, 0.01882743669141616, 0.012784704915247858, 0.011333746835589409, 0.06449138798883983, 0.08173985672848565, 0.04778580493958933, 0.030390769243240356, 0.04162086985473122, 0.040239620222044845, 0.03354029470522489, 0.013819676923698612, 0.024233832389914563, 0.05907902627118996, 0.012843164099779512, 0.049286290138427696, 0.10443266654121024, 0.08983607550284692, 0.018895358046782867, 0.03253062441945076, 0.03466859326830932, 0.017400547097037946, 0.047727796980845075, 0.03998568527666586, 0.06281706211822373, 0.00024403830008980419, 0.026414996778060282, 0.030969033749508004, 0.011471765947395136, 0.03794442802401526, 0.025913435566638197, 0.03829924416329179, 0.04707090383661645, 0.038870163527982574, 0.04650684106828911, 0.024174708241064633, 0.04768736647175891, 0.036124318904642544, 0.015239972854033113, 0.016543236760688678, 0.005127937225292304, 0.00874076088491295, 0.04406815906986594, 0.020051542702796202, 0.017818850365334322, 0.026760493238855685, 0.03267579698669059, 0.018809949147648046, 0.04341898086879935, 0.030231496718313013, 0.0628944422517504, 0.02248237405105361, 0.04248553381434508, 0.07332957123539277, 0.03744796769959586, 0.0426930162523474, 0.0588509842221226, 0.03230678928749902, 0.039066076943916936, 0.018808975449896286, 0.020663883237700378, 0.017228294197203856, 0.06193468160927296, 0.020579660078510642, 0.024807545622544627, 0.04334757184343679, 0.0332964020781219, 0.060709830905709944, 0.034652600197919776, 0.016895640707973923, 0.034057111080203734, 0.0453916348383895, 0.021556022776556865, 0.03402226830699614, 0.019006866795410002, 0.10121675660567624, 0.021860810528908457, 0.02509545481630734, 0.019236528846834387, 0.028362946983958994, 0.014492882049775549, 0.05300500470080546, 0.012205327611549624, 0.03331389471090265, 0.028880540281534195, 0.04910436811457787, 0.06366979743220977, 0.06886310768978936, 0.03547861480287143, 0.03816858546010085, 0.03203887312806078, 0.03795045680765595, 0.014465789842818464, 0.005661886609492025, 0.03625543222629598, 0.04245817528239318, 0.02431529900059104, 0.05078931645091091, 0.03182207440425243, 0.03487316818375673, 0.024386745345379626, 0.022353058847199594, 0.026063211993979554, 0.011665997444652021, 0.034969934062766175, 0.027125772388119782, 0.06384435735110726, 0.04511964407616428, 0.005872802010604313, 0.034787028163139305, 0.024745917679475884, 0.055334676655807664, 0.038890519578542025, 0.020456042872475724, 0.07004187229488577, 0.006458320056221315, 0.04305311817941921, 0.023949161504528353, 0.027102215348609855, 0.02516486046702734, 0.08226794696279935, 0.018666625588334033, 0.04639883864937084, 0.006912775670311281, 0.02987945917993784, 0.011486323916220238, 0.02245079672762326, 0.024501416067193662, 0.0073037450035501805, 0.008215160025948924, 0.035680183808186224, 0.02711209312214383, 0.023410219798928926, 0.014622743474319577, 0.048154870314257484, 0.023659618737708246, 0.03997199243998953, 0.024988907855004072, 0.010015329545629876, 0.03705615443842752, 0.024739581858739257, 0.062443202893648825, 0.01503478895340647, 0.029960513580590487, 0.03717842984146305, 0.022863091568329504, 0.029588859594826187, 0.05966564015086208, 0.03541267816243427, 0.02091839154517012, 0.002364389199231352, 0.054518209038568397, 0.02244404700052525, 0.003377460005659876, 0.05466985482988613, 0.029339352090443884, 0.05249642913362809, 0.036784065288624594, 0.004521491887447025, 0.059013303369283676, 0.11335826545421566, 0.035886943606393676, 0.038631573652050326, 0.022769287494676452, 0.04521827253379992, 0.032205741852521896, 0.030008031387946436, 0.022173126627291952, 0.017793259417105998, 0.02456172595598868, 0.017314551265111992, 0.052724345653717, 0.059621894998209815, 0.05831880242164646, 0.05525218715359058, 0.036715370403336625, 0.06705667105104242, 0.05155045971540468, 0.041658457302089245, 0.04013882384502462, 0.02015071059577167, 0.047009951035891256, 0.0572190328634211, 0.029916612364883934, 0.02959112250911338, 0.04059474848742996, 0.10904326449547495, 0.034514257085642645, 0.021758307636316334, 0.004987105161749891, 0.030022460435117995, 0.011949859177028494, 0.021194216030250703, 0.063846494736416, 0.04972052201628685, 0.02311138279869088, 0.023187212479699935, 0.05591915315017104, 0.037547091487795115, 0.02452968722874565, 0.06144570213343416, 0.03653494454920292, 0.031405613358531675, 0.00890030143117266, 0.01731471241717892, 0.026281011556940417, 0.013865104843197125, 0.03773466231567519, 0.06095341819205454, 0.003325066712152745, 0.03852208863411631, 0.08274711482226849, 0.015667913015931845, 0.05589131964370608, 0.032814374193549156, 0.020706619069512402, 0.019866160150351267, 0.04238424210676125, 0.041213928655322106, 0.02872730671827282, 0.023727054940536618, 0.021708194432514052, 0.01603903265536896, 0.016875829181766937, 0.047201046853193214, 0.02446610849749829, 0.013808621891907282, 0.04017145459407142, 0.012343242398596235, 0.06569568586668798, 0.032403327857277224, 0.04811859243948545, 0.009383977307671947, 0.03376111714169383, 0.010767922420719904, 0.006858529340076659, 0.010649114331629659, 0.04174108251131006, 0.060491016932896206, 0.04283140686207584, 0.02122832089662552, 0.03893944873873677, 0.03173030932833042, 0.045203697601599355, 0.03587951704061457, 0.06579773074814252, 0.0292491272890142, 0.04568570513012154, 0.02955293795093894, 0.04358011597235288, 0.011594894608216626, 0.020377831533551216, 0.02805995734940682, 0.013732611550949514, 0.03852882309417639, 0.06793808804026671, 0.05007899885198899, 0.03270879075197237, 0.00748745835984924, 0.023569563570033227, 0.06993946100452117, 0.02731000991272075, 0.009634567075408995, 0.03080658907336848, 0.030075023150337592, 0.0285764073154756, 0.04648774030751415, 0.03694344637915492, 0.05035953915544918, 0.04929697706497141, 0.042943161579647234, 0.0171691581739911, 0.027656106877007654, 0.05741353492651667, 0.05213323647954634, 0.020721431488969495, 0.02214875873843474, 0.03065367442156587, 0.031909052415617874, 0.0403888945334724, 0.0411866210134966, 0.04548823447631938, 0.038745479325630834, 0.013749518947276686, 0.006265833242131131, 0.07236337808093854, 0.0422397853939661, 0.021196709646444236, 0.014424485719895788, 0.02840843257893409, 0.062002399404134066, 0.047145993914455175, 0.04018922881888492, 0.14633693333183015, 0.13988398388028145, 0.12265230209699698, 0.19647213523941381, 0.07827339095196553, 0.11163083743304014, 0.12944711106164114, 0.10407275121126856, 0.2560529517275946, 0.05960520303675106, 0.15152673556336335, 0.20340047989572796, 0.08251257240772247, 0.16176550329795905, 0.10501985717564821, 0.1252365027155195, 0.05397743359208107, 0.11550141152526651, 0.12011524609157018, 0.15521721967629024, 0.0796411954132574, 0.1266187328313078, 0.1275658184396369, 0.13791487525616372, 0.09679373965731689, 0.08897281611072165, 0.1366851119590657, 0.08303739888859646, 0.14861341831939562, 0.08319093779261623, 0.12525099622351782, 0.18906048366001674, 0.0915265233655061, 0.08059151763362543, 0.12239462163831506, 0.13473198961998734, 0.13419220144195215, 0.16736842479024613, 0.06412679755261966, 0.10795007672693048, 0.11916034375982625, 0.12830855644174985, 0.09844433715833084, 0.29731488334281103, 0.17796081783516066, 0.11738526900964123, 0.15776053177458899, 0.09854387824556657, 0.16745567082294396, 0.13010295586926596, 0.16121557780674525, 0.1747396763946329, 0.053111561840134006, 0.09845300205051899, 0.11718016144420419, 0.1762995741197041, 0.12230276156749044, 0.1871896404772997, 0.12153273288692747, 0.1762197512601103, 0.1505027719374214, 0.1449424760150058, 0.08732714477394309, 0.17376846208104066, 0.13587571467672074, 0.12016252641166959, 0.20415574365428515, 0.1777018888720444, 0.1049854215234518, 0.17834812562380517, 0.1239976877612727, 0.10535831722830023, 0.17710461520722934, 0.1446376916553293, 0.16489557176828384, 0.14984760566481523, 0.16612909414938518, 0.12758732799972805, 0.11481928027101926, 0.08936418832412787, 0.16169078302170548, 0.17494939799819673, 0.06465970538556576, 0.13439789254750523, 0.11460041201540402, 0.17564334933246883, 0.15749639166252954, 0.14039242374045507, 0.1354775774691786, 0.08137175148086888, 0.0940253846347332, 0.11385441704520158, 0.10504026072365896, 0.1606831992311137, 0.20573142410389014, 0.12149052800876753, 0.08875451782452208, 0.08280751800962857, 0.06936974943216358, 0.08376882571194853, 0.08750576911760227, 0.08402949172471251, 0.11736898416919367, 0.1136691023462585, 0.09691561133201633, 0.06014551368675061, 0.09373045260352747, 0.12279004470578261, 0.10284165120018379, 0.13992576806672982, 0.13797907823962824, 0.10979439597576857, 0.1909117036099945, 0.08698026410170964, 0.2525626761572701, 0.12504721858671733, 0.07551933266222477, 0.15312118429158414, 0.08742775794650827, 0.06141773291996547, 0.15399226040712424, 0.15831113580082143, 0.13475253566035203, 0.16911954725427286, 0.1347584253443139, 0.09550369530916214, 0.12460577727428504, 0.10121164723698582, 0.12368216897760119, 0.13240734221679823, 0.11154980678111315, 0.12942910274224623, 0.09795240605516092, 0.13985290697642735, 0.26128019552145687, 0.142841175198555, 0.09911580862743513, 0.10897162476820604, 0.10284048411995173, 0.09342778527310916, 0.16234409010836057, 0.07161759345659188, 0.1434408373066357, 0.1528144728924547, 0.08588367008737155, 0.09901417765234198, 0.16256632389766829, 0.17938286438584328, 0.08382483877773796, 0.1832147959087576, 0.07799718648727451, 0.14266300547335828, 0.20933042812560285, 0.17186986681606087, 0.1265968025795051, 0.11776769134615149, 0.1630842089653015, 0.1319925401891981, 0.08333157774593149, 0.08274985610374383, 0.11905951345605509, 0.103561766844775, 0.06890829133668117, 0.06322790828666516, 0.11634525124515806, 0.12630763809595788, 0.11469855532050133, 0.10026500946176903, 0.23216276509421213, 0.09175209554710559, 0.13815361101712498, 0.08687784602599484, 0.13797295785376004, 0.22032454104295798, 0.16797631074275288, 0.14697075289274963], [0.024172221410221288, 0.04766762449539133, 0.010828084728148366, 0.0062019466256190625, 0.02777646541861551, 0.00885977253450879, 0.04581730021163821, 0.042163864110729525, 0.0761618171153324, 0.02316725337212639, 0.018174311112878577, 0.01019436864381922, 0.044461492249476056, 0.012979474999675793, 0.019705942765410458, 0.03159959973501308, 0.061645591764577796, 0.019163822123248662, 0.04619303897821477, 0.010227803456863123, 0.008820283492760999, 0.004539523107398833, 0.0836644195286291, 0.02136712541271533, 0.031000700978828327, 0.04517328226938844, 0.04005904509020703, 0.030689521426601068, 0.057214697024651935, 0.008446587116590567, 0.05346134664224727, 0.02248307124578527, 0.03258645428078515, 0.010358935438229569, 0.021571103217346326, 0.04462567736793842, 0.05832503137311765, 0.03781817640577044, 0.005242485810802984, 0.04926839377731085, 0.06943800326968942, 0.033476393669843674, 0.0536044089655791, 0.01807149439784033, 0.021903522611994828, 0.024930726869830062, 0.017793278076819012, 0.04450690999094929, 0.052726445719599724, 0.022573163732886314, 0.03376905939408711, 0.02397977700456977, 0.05009959917515516, 0.08424143213778734, 0.029785169953746454, 0.030414419581315348, 0.0437756969061281, 0.019839598897046277, 0.05537644048620548, 0.0195763714145869, 0.06500271840819291, 0.018754709611779878, 0.07809938743178334, 0.01812149055435189, 0.03692858985492161, 0.025720102280112248, 0.04729702902425613, 0.027065621955054145, 0.00789539615756699, 0.004308882269210049, 0.050656374477382214, 0.02763714182323643, 0.06260835831718785, 0.04872796099100794, 0.022227563795500567, 0.02066115043791277, 0.014703648597268122, 0.07724057244403021, 0.028232744595568095, 0.03659593127667904, 0.008510438958182931, 0.03607434819319418, 0.04780102108738252, 0.03458894343514528, 0.043021919139261754, 0.04314816736483148, 0.01995149949964668, 0.03268915394853268, 0.016334934991651347, 0.019070211432075927, 0.04267471277021936, 0.04314928016226206, 0.015560687519609928, 0.015310565941035748, 0.01486243088064449, 0.028643426219267503, 0.026512960271377648, 0.03595267668632524, 0.03213991038501263, 0.007453529912579272, 0.040386716436062536, 0.043921534437686205, 0.028422481646495204, 0.045286590832152536, 0.02847330052671688, 0.04681921823482428, 0.047858564249638996, 0.06366866427872862, 0.04715656888272081, 0.030045364384672472, 0.07572569551744632, 0.019648404692166617, 0.01891266238609595, 0.021527281729504466, 0.014788297537182058, 0.06183995133531945, 0.04101769293525389, 0.038962376437016895, 0.017020036532942737, 0.018172592722943852, 0.02993966219946742, 0.030781741120985577, 0.08365044849259512, 0.04869593074545264, 0.05241658591798373, 0.036829055553036075, 0.01844520604104868, 0.03355574155492442, 0.029289011577410356, 0.01675147406889924, 0.042485275971038, 0.05649519545425262, 0.04955323599278927, 0.0403324675613216, 0.012858946824313273, 0.14028262320373738, 0.0349057616133775, 0.015368260077333875, 0.05003209511882492, 0.02678307658061385, 0.08374253926532609, 0.028684236707964113, 0.023796158643173318, 0.003785677911115012, 0.03404588811099529, 0.02218411210924387, 0.019746330866057957, 0.08764749472694737, 0.01898393570445478, 0.08017065628830876, 0.03333777575088399, 0.10127159580588341, 0.09503835599337306, 0.011869065164189254, 0.04328464450580733, 0.028705020235585313, 0.022408903975571905, 0.013636300290402557, 0.030613542467887913, 0.043005800539893765, 0.04048801492899656, 0.06451016305280582, 0.008580805584123092, 0.0576151819633586, 0.05957042133169515, 0.020089140328179513, 0.006337195618211159, 0.0420120622563575, 0.01610880301866148, 0.040496696784560166, 0.06315330336136477, 0.026365144810240184, 0.06967958209237882, 0.04573870889310326, 0.023104397280673896, 0.02060195504288588, 0.0193319325667939, 0.026561232948941842, 0.035299322102218866, 0.03120671438851527, 0.029239332636020014, 0.03998206868501646, 0.014956825279763766, 0.05112740670197776, 0.035949216157730134, 0.048535514889018874, 0.054347177501767874, 0.07691091299057007, 0.027073046824495708, 0.03318542428314686, 0.017216938913666775, 0.01629266225998955, 0.03744064969941974, 0.05151306565052696, 0.06338189502379724, 0.03986831568181515, 0.05275681694703443, 0.021025666235280887, 0.043917683751455376, 0.02608023813393499, 0.020607978737513934, 0.07651760016701051, 0.03908079776114651, 0.056093173633728705, 0.009279197081923485, 0.00535713617656646, 0.01755632007760661, 0.013615954417868384, 0.0065696299092711085, 0.09253586456179619, 0.04190648899280599, 0.008142030914314091, 0.02319975519951965, 0.0657906604132482, 0.04366850872923221, 0.02208355491581772, 0.043884584813245704, 0.021401157336575643, 0.024673850475145236, 0.04158254958955305, 0.03516275675169059, 0.0402892414879586, 0.0016555128510974879, 0.022545772970521023, 0.038994365970471075, 0.03762820017124925, 0.05565414112061262, 0.03898277659235256, 0.01564052903891674, 0.04635766514443925, 0.0106942394548761, 0.019638263986312916, 0.09711062229637589, 0.020097839147118584, 0.030367732979357243, 0.024688885114820938, 0.032459449488669634, 0.024098798832190887, 0.07032856012561492, 0.021090413743097867, 0.05166735094306724, 0.017808066747550453, 0.0431059353452708, 0.015505073093143957, 0.016643495398706624, 0.06298163400164672, 0.015411665962476815, 0.05200944794341922, 0.04661008356405156, 0.029529019591531584, 0.016591919951939156, 0.07671177653329712, 0.02664491328011666, 0.05614158710730927, 0.05805356308285679, 0.026227977259882858, 0.02406426309607923, 0.017524473036506345, 0.05759734327771834, 0.04688444919884205, 0.04858878328065787, 0.03432746996570911, 0.02909630084676402, 0.07993788485016141, 0.05542476575023361, 0.030003132365111793, 0.017421184739630138, 0.004777842417492398, 0.0511137851114784, 0.01973981692987893, 0.02616479547162141, 0.02188691377107586, 0.0337494836587991, 0.03347470751032233, 0.01109492456141327, 0.031469707776393206, 0.027766898074852567, 0.01311940503572779, 0.012943957932293415, 0.01238232771200793, 0.02108568435401789, 0.035241863756839714, 0.030639971406864266, 0.018255686121327535, 0.023891737085900137, 0.03503077829788838, 0.1211731636098453, 0.07011099465723548, 0.02994995896837541, 0.030800909735262394, 0.06055565417877265, 0.02258093126251229, 0.03724078042432666, 0.01644065583656941, 0.01661091553978622, 0.03914252069911786, 0.03538074969713177, 0.12359672784805298, 0.028288832300209572, 0.0872112645634583, 0.009045982899676477, 0.00823247030244342, 0.02155045878940395, 0.05339232606015035, 0.029882502409496477, 0.03401319629379681, 0.05405527173674532, 0.034210164831685166, 0.03206206884767328, 0.03426859348214098, 0.07138053367712668, 0.06384715970073428, 0.012243676714466085, 0.04284200897174222, 0.007059357045883579, 0.01583660699959312, 0.03262764135641711, 0.034369742697370906, 0.04539624209116612, 0.03419499957401838, 0.06298271965767656, 0.032354632791663916, 0.01711226301267743, 0.03938446593071733, 0.008485650377614158, 0.061752522098166604, 0.06662753157849823, 0.04112897267831223, 0.014076035087262946, 0.03573459892400673, 0.052577721021537266, 0.028382278446640288, 0.0074174479647938696, 0.034172394179872105, 0.028874274010636976, 0.03331285994499922, 0.02847352105059794, 0.08346404813762222, 0.04569829195471747, 0.03669130615890026, 0.06170832232705184, 0.02787881394449089, 0.052661543845066, 0.0250542830077133, 0.028641855410699333, 0.02884326156760965, 0.04038182759125318, 0.023687431888122643, 0.012896132239672755, 0.02473507638621543, 0.0399959040140467, 0.008271686233846205, 0.1535782047680446, 0.1118973863444158, 0.14068603941372462, 0.1598690114915371, 0.13107448230896676, 0.12022443594677107, 0.09497580863535404, 0.11760147740798337, 0.09023059611873967, 0.08423338471246616, 0.18992453015276364, 0.12039751665932791, 0.10118932343487229, 0.11923373410744326, 0.06441265757062606, 0.1127221253035324, 0.2615466426525797, 0.10888745249914271, 0.14428379493100302, 0.15715782982962473, 0.10275285810764347, 0.08874236526233809, 0.12295425018029553, 0.1289556345769337, 0.1187229465161051, 0.19326939566859178, 0.09065867029130459, 0.11550206291888442, 0.10639225531901632, 0.04811234991731388, 0.0959301884951336, 0.07351640585277762, 0.12392850433077131, 0.18071982264518738, 0.10920668286936623, 0.1168997229209968, 0.13487948956234114, 0.21749492787889071, 0.06938754740570273, 0.11634324278150286, 0.09659429107393537, 0.18312365508505277, 0.19554278653647217, 0.1466531985040222, 0.06662092264741659, 0.06972343581063406, 0.09163209662905761, 0.1897206168089594, 0.19300620550555841, 0.1370981905077185, 0.12851447824920925, 0.10691450336681944, 0.07418731413781643, 0.16369334342224257, 0.08279417122581176, 0.0612779547061239, 0.17172498601887906, 0.13164624305708067, 0.09598729400230305, 0.07200329990259238, 0.11056266046528306, 0.08687950843679053, 0.1799319213522332, 0.0820599759795836, 0.11057772394269705, 0.08677236775734595, 0.10452569369226694, 0.10750432671712977, 0.08885654234992606, 0.17351374003504003, 0.15610691479274205, 0.1372464368385928, 0.1182814644915717, 0.2315263535295214, 0.0882089010306767, 0.22070594557694026, 0.12722455603735788, 0.10972609464079142, 0.1637783231479781, 0.10049461214137928, 0.11818613032145159, 0.15043369707252296, 0.13553359732031822, 0.10491382929363421, 0.14338002699826444, 0.07839390555662767, 0.1291921447430338, 0.13800978873457226, 0.1965553779155016, 0.11797263606318406, 0.1475256181188992, 0.1522424135889326, 0.0979976032727531, 0.0832104796011533, 0.06561254497085299, 0.10297716142875807, 0.13534955148186, 0.08358878323010036, 0.16441196628979274, 0.1485436377780778, 0.16035841165908746, 0.1580292180712734, 0.1172645033470222, 0.07828857656568289, 0.11504102551511355, 0.12755369980420384, 0.16874704509973526, 0.10266319649027926, 0.0710093682365758, 0.08681867777236871, 0.22100490810615675, 0.1431554454777922, 0.05124458969969835, 0.06237078285110848, 0.17234575056603976, 0.13977905522499764, 0.1008063650556973, 0.21897383566413606, 0.06603306026331016, 0.12162638429020133, 0.12717069392757757, 0.17605356446334294, 0.1580107347773654, 0.12001778132149152, 0.16598020999559335, 0.11284019039677722, 0.0872575067249792, 0.07148987959538187, 0.09350391011685133, 0.0859188928401896, 0.10322178008833102, 0.15048469576452458, 0.1433342530259064, 0.21990602064345563, 0.17639127134212426, 0.29726421034761835, 0.12162339873611927, 0.12228404757167612, 0.1866526614342417, 0.13505911135247775, 0.13239321511770996, 0.0817783907321947, 0.12379202379712037, 0.09210494732750313, 0.11159043745802981, 0.18011262879839965, 0.12319917418062687, 0.14928030967712402, 0.07237033985022988, 0.1826661460633789, 0.16790925791221006, 0.18098286353051662, 0.133279788973076, 0.10465200298598834, 0.08199027686246804, 0.08292153903416224, 0.11935851669737271, 0.22330858877726964, 0.13146990537643433, 0.10346388138298478, 0.09259083268365689, 0.14385930342333658, 0.11449314919965607, 0.16426445277673857, 0.14401827060750552, 0.0604518111795187, 0.09069898884211268, 0.13224359814609798, 0.10565700155815907, 0.16430578913007463, 0.12014892856989588, 0.12775632393147263, 0.14970723034015723, 0.11033284065446683, 0.11803776185427393, 0.14182405120560101], [0.04514776596001216, 0.06300861255398818, 0.02028325562631445, 0.0174800663122109, 0.04316125291266611, 0.03661753583167281, 0.007892992447263427, 0.0821644432310547, 0.013300770660862327, 0.052577799053064415, 0.03024760853233082, 0.03746884282944458, 0.04558051523885556, 0.054498151543417146, 0.021952158305794, 0.05187428037502936, 0.044260384647973945, 0.011100000003352761, 0.044125675090721676, 0.021685763761135082, 0.035000519028731754, 0.027505114175645367, 0.041075063071080616, 0.02411965360598905, 0.05231976914884789, 0.0343614611774683, 0.08217574762446539, 0.044627746899745295, 0.006325146532617509, 0.06006252885396991, 0.06610571779310703, 0.03626655002257653, 0.05016915240724172, 0.05605318756507976, 0.03703403758949467, 0.06857166332857949, 0.027488795408446873, 0.04604416839512331, 0.035390466318598816, 0.019347776359479343, 0.0315204180910119, 0.04313882393762469, 0.0708660412845867, 0.05863048748246261, 0.06566570818956409, 0.03093974817810314, 0.03760411896343742, 0.04108817915299109, 0.02974398627078959, 0.020196808568601097, 0.0521374264332865, 0.09852808195033244, 0.055244397571576495, 0.04463004034810832, 0.046453677849578004, 0.029832029582134316, 0.048648942195411236, 0.04403182012694223, 0.02966883173212409, 0.018771515227854252, 0.025635366826983433, 0.038916354799377065, 0.053431087373090644, 0.00788620370440185, 0.025004112128434435, 0.027360735494377356, 0.07130395421492201, 0.03820295665147049, 0.020018396267135228, 0.019966032023408582, 0.03258154168725014, 0.024634539548839842, 0.02391818298825196, 0.0789330287703446, 0.015844059010435427, 0.063920794320958, 0.010193541679265243, 0.009975379948238177, 0.01773636764846742, 0.013745963423778968, 0.038388335811240334, 0.004558280783904982, 0.06851727874683482, 0.03822791316945638, 0.027996052921350514, 0.052835849313331504, 0.018109867249482443, 0.008754938025958836, 0.046627545662756474, 0.022623226046562195, 0.08371936050908906, 0.005700475320086947, 0.007240621738934091, 0.06522503362170287, 0.07592443163905825, 0.01657754009855645, 0.05193067002775414, 0.07091058032321078, 0.0009378633632357897, 0.04668255110404321, 0.0335508798515158, 0.03841808617913297, 0.03342045863558139, 0.06321169129971947, 0.008050779828668704, 0.00663275911106861, 0.037199559421943765, 0.02482901107785957, 0.04927018510976008, 0.011226795297781271, 0.018900148504014527, 0.005970743027449186, 0.012062028649130037, 0.030586964251207452, 0.06047656413699899, 0.05807095393538475, 0.02385779337159225, 0.05504238412582448, 0.029270857372986417, 0.02942487464419433, 0.06732470595410892, 0.0159618492969977, 0.07348075562289783, 0.031132038217037916, 0.042386426989521296, 0.09037180604147059, 0.05419055465608835, 0.021974929941019843, 0.04908253625035286, 0.052569626098764796, 0.05839109354253326, 0.035180001719189544, 0.013952791075488287, 0.0344754245265254, 0.037941520501460345, 0.009219001695912863, 0.04497442740414824, 0.029461654634880166, 0.018570916527616124, 0.14636423758098058, 0.014995852917698877, 0.06466250094984259, 0.005671310612732279, 0.061371707889650545, 0.026389371903081025, 0.02494976656245334, 0.014375005249998398, 0.026806779505152787, 0.01587496797687241, 0.026231261369373118, 0.02953689738309809, 0.012348666437901556, 0.01490006921812892, 0.013868159947118588, 0.023748613694416623, 0.01992478727230004, 0.0386400180203574, 0.03566973436889904, 0.09510736979011979, 0.02682086080312729, 0.029160697212708846, 0.02989323004814131, 0.08678094443998166, 0.016117411931710582, 0.024751641122358184, 0.08037082411881004, 0.025085195366825377, 0.023307128277208124, 0.06735286515738283, 0.016521622027669634, 0.021377537532576492, 0.02630778994145138, 0.024008132982999086, 0.024520320052813207, 0.06206960829773119, 0.016656586035553898, 0.0347542481363884, 0.03948008847822036, 0.01232852497404175, 0.0431215484360499, 0.01576102159119078, 0.04057984446574535, 0.009259299042501619, 0.040101368711995225, 0.01087324632265206, 0.03456783760339022, 0.03077001603586333, 0.057443994363503795, 0.08275410373296056, 0.07355907892010041, 0.045508705877832005, 0.057464140068207464, 0.07448249044162886, 0.02241065289958247, 0.06800286777849708, 0.0665308539090412, 0.008232478784131152, 0.03213939469839845, 0.02774530030520899, 0.05698743529085602, 0.011727653377290283, 0.08199861605784722, 0.029006825826529945, 0.004283862986734935, 0.009167606909094113, 0.024658447730221918, 0.01194114763555782, 0.023309640553114668, 0.010431270663892584, 0.020246105834043453, 0.0681083324764456, 0.05368243370737348, 0.023729234734284024, 0.01520305885268109, 0.030848369867141758, 0.023802216264552305, 0.039135121274739504, 0.024332762795633504, 0.005577135041156518, 0.031164987877543484, 0.0307957359057452, 0.034244037299816094, 0.022137863162372793, 0.06400962812559945, 0.056426544673740864, 0.01908420960951064, 0.10819334510181632, 0.056633711592959504, 0.06411554744201046, 0.015543181316128798, 0.023802686150052717, 0.036003607524824996, 0.03002559526690415, 0.043298364483884404, 0.011587486702150531, 0.026790364046714137, 0.03895022048215781, 0.036466765350529125, 0.02465209155343473, 0.02863821167764919, 0.019839766834463392, 0.037562467091317685, 0.02420453155147178, 0.012730041285976768, 0.02962447589795504, 0.07231330898191247, 0.03369333488600595, 0.010880739045595484, 0.02660474570335022, 0.030435505057019845, 0.03408509047169771, 0.02982775481151683, 0.03700701832505209, 0.051267517397978475, 0.0362009526496487, 0.04837187599124653, 0.025490139976942112, 0.002198804178208645, 0.04118821217811533, 0.02098866572071399, 0.02461207834338503, 0.03580526156084878, 0.08294483314135245, 0.027560962696692774, 0.00585258421155491, 0.027493112587503026, 0.04174635812108006, 0.051772215137524266, 0.022172532909150635, 0.029696108839873756, 0.014339212527764695, 0.04033888989527311, 0.04032755157511149, 0.11227303011608974, 0.0050754682327221546, 0.02129125501960516, 0.05755280423909426, 0.06408111178981406, 0.015741710484560047, 0.06631688467626061, 0.012224654833387052, 0.04272351979411074, 0.03848915593698621, 0.01217998517677188, 0.019058946054428816, 0.010430963626796646, 0.019532522785344293, 0.046319188816206794, 0.0693606977750148, 0.040769793558865786, 0.06737014065895762, 0.046761573292315006, 0.0462432811036706, 0.007135835576004216, 0.04053280163290245, 0.06844147281455142, 0.0399497704181288, 0.04033208079636097, 0.06783081843916859, 0.03310779309166329, 0.059955489954778125, 0.03241987393370696, 0.04721237160265446, 0.04721140808292797, 0.05369161767885089, 0.04289064636187894, 0.03010170314727085, 0.01695359608025423, 0.04268465330824256, 0.04550354561901518, 0.03470722565959607, 0.03522119218749659, 0.012616753927432, 0.036305243482014964, 0.018376565438562205, 0.04384391003155282, 0.01802658725396863, 0.01490962808020413, 0.03451506793498993, 0.054466212900089364, 0.02790895277368171, 0.07628392627728836, 0.0275738769144352, 0.030331516172736883, 0.028412339244303957, 0.0205028702704502, 0.04023098247125745, 0.0427135012245604, 0.04928152682259679, 0.04121929925999471, 0.03857271752453276, 0.08227542441870485, 0.0171493279880711, 0.06662506171103035, 0.029166753137750284, 0.023129825380497744, 0.04181801141904933, 0.09543837952826704, 0.018342270582382168, 0.03406104997598699, 0.0651172890460917, 0.03037574647792748, 0.0054895387147553265, 0.020434658841363022, 0.004349574438362781, 0.01906808083211737, 0.07094099226274661, 0.05960276709603412, 0.07985738345554896, 0.030959700500326495, 0.03323181911504694, 0.031533859869731326, 0.14480028221649782, 0.17968635952898435, 0.10431401112249919, 0.11889495514333248, 0.09453407555286374, 0.11287506031138556, 0.07068132369646005, 0.16012561986488955, 0.13278979169470922, 0.13755640520581178, 0.07058436104229518, 0.10782926356686012, 0.10451485748801913, 0.1811541257692235, 0.11613570606069905, 0.2805130806352411, 0.12443486787378788, 0.08319674605237586, 0.12751036855791295, 0.15118484890886716, 0.0596947968006134, 0.19360141642391682, 0.16973976897341864, 0.19494819987033093, 0.1853716280311346, 0.11434484858598028, 0.16197275503405503, 0.06987715791910887, 0.16061675708208764, 0.15896255656012467, 0.10179211358938899, 0.2024279356534992, 0.07808853765683514, 0.14000451884099416, 0.13025828610573495, 0.12593422670449528, 0.08903702587953635, 0.08598350973001548, 0.08877156940954072, 0.08928221450852496, 0.132099911570549, 0.12208937587482588, 0.0767989411417927, 0.12602088919707707, 0.16271258890628815, 0.1850326590772186, 0.07412729093006679, 0.14545722625085286, 0.16580380446144513, 0.08201912138611078, 0.14940726357911313, 0.23318227753043175, 0.17672179932040827, 0.09949236163603407, 0.10353778063186578, 0.16336729377508163, 0.08351375761308841, 0.09109551792166062, 0.10789637746555464, 0.09024595136621169, 0.13534288826797689, 0.06596327972199235, 0.1447281946561166, 0.08650341683200427, 0.14935458212026528, 0.21692490418042454, 0.16515019881938184, 0.08427042593913418, 0.08142388332635164, 0.22287823472704205, 0.1068241089316351, 0.14848380456013338, 0.10292819155646221, 0.15588407032191753, 0.09523158919598375, 0.16741656006446906, 0.10047719414745059, 0.19766999381993497, 0.07158933925841536, 0.1934942486030715, 0.1060671488355313, 0.07389466876962356, 0.15984001090484007, 0.16677940211125783, 0.06970963440835476, 0.09919523793671813, 0.28022893731083187, 0.08725321838366133, 0.1566946618258953, 0.0974774518981576, 0.2614238549556051, 0.20352463823344025, 0.09714395193649189, 0.10897602167512689, 0.10862458124756813, 0.09522360962416444, 0.12737828493118286, 0.19196010806730815, 0.16711830321167195, 0.13048114414725984, 0.13517488299735955, 0.1871511268296412, 0.21749008313885757, 0.13457537016698293, 0.2205179642353739, 0.2057301348873547, 0.16820079726832254, 0.11655107805771486, 0.08734112259532724, 0.07690510473081044, 0.09105401871992008, 0.11960749833711556, 0.17951862567237445, 0.09223564674279519, 0.1825297333832298, 0.1254284738429955, 0.09813747648149729, 0.09193973083581243, 0.16636971623769828, 0.09261346861187901, 0.17815846151539258, 0.101972732826003, 0.1645931622811726, 0.07753809647900717, 0.15962503744023188, 0.11569693817624024, 0.11008212875042643, 0.10243764466473035, 0.16021267590778215, 0.09870437213352748, 0.1675094243671213, 0.11708082391747407, 0.10440297384879418, 0.14418441669217177, 0.13294741537954124, 0.10537390317767859, 0.11394359011735235, 0.13506543529885157, 0.06185871961393526, 0.18559232833130018, 0.06001491605171135, 0.1310724195625101, 0.07146492307739598, 0.1914457513817719, 0.09675730911216565, 0.1614207803670849, 0.14318565385682241, 0.12487888761929103, 0.11535410157271794, 0.1290669957441943, 0.08285591791250876, 0.1325634324124881, 0.09783918570194926, 0.10542813848171916, 0.10286985111555882, 0.10109022339539868, 0.08983650297990867, 0.1310130206069776, 0.15738393126853875, 0.08542490577591316, 0.12273919529148511, 0.16454635693558625, 0.09293113156620945, 0.15886562104736054, 0.22448709553905896, 0.11788178022418704, 0.11964400352111884, 0.07645691878029279, 0.13922362002943242, 0.12270870192774705, 0.1029608358762094, 0.1656492477548974, 0.14933898938553675, 0.08438802284321614, 0.12778578592198236, 0.15699324437550136], [0.042284595846597633, 0.04865853328789983, 0.07949394652886049, 0.019033253325947692, 0.026975561698366488, 0.012807225492516798, 0.047968771907367876, 0.06831300577947072, 0.03330247157386371, 0.06252236078892436, 0.036807522244219265, 0.007284826599061489, 0.01650540334438639, 0.07469648003046002, 0.03696585499814578, 0.059005445933767726, 0.03128361615485378, 0.04220642861244934, 0.015077553622956787, 0.05077168471845133, 0.03324648564947503, 0.03500369457261903, 0.05127968692353793, 0.023864498993914043, 0.013968857088392335, 0.020111895000029887, 0.02283297309518925, 0.034184794407337904, 0.05212309577369264, 0.025181716973228113, 0.04170062146814806, 0.10589510628155299, 0.054592939492847235, 0.06020859030208417, 0.05719552841037512, 0.0067463174595364505, 0.03781334523643766, 0.017641895217821002, 0.025430294884634868, 0.028958972144339765, 0.035194142388978174, 0.0611341188528708, 0.04048151456351791, 0.03576618812179991, 0.007005436836542296, 0.05693070976329701, 0.0691136499600751, 0.03789295096482549, 0.020423401945403645, 0.08653630542435817, 0.09286778353686843, 0.033511266977127106, 0.010030360792630484, 0.01440652659428971, 0.03441645983340485, 0.026063829460846524, 0.024221306633470312, 0.006389204903306174, 0.07271566667727061, 0.03148930047505668, 0.05591864764158215, 0.02345317615462201, 0.05456994394106524, 0.010198218481881278, 0.05744411649980715, 0.032797722944191525, 0.02788826932997576, 0.008518689095840921, 0.04706898018983858, 0.024205571406387856, 0.02420823465633605, 0.012624032063675779, 0.016754452837631106, 0.020591320702806115, 0.04271338926628232, 0.00540509248717821, 0.030087867818240608, 0.018512499751523137, 0.048305840963231664, 0.024881717981770635, 0.04022892651015094, 0.06807011738419533, 0.05204260116443038, 0.016683573069583093, 0.024381798825093677, 0.04320862822766815, 0.0698750341045005, 0.01654314006944852, 0.03660793456115893, 0.021107243107897893, 0.02674692593115781, 0.039429093178893836, 0.02270907599345914, 0.0035506005141152336, 0.02004292530805937, 0.019245685676911047, 0.03407815245113202, 0.006496427431037384, 0.02830785502945738, 0.044229212749217234, 0.017661089277161018, 0.022794898798955337, 0.04008374037221074, 0.027304237276049595, 0.049596930255315134, 0.0050039001757145995, 0.04020086230177965, 0.04823971772566438, 0.0270250065451754, 0.02994720750887479, 0.013387116786491658, 0.021853256737813354, 0.03941420951325979, 0.007843631569163075, 0.022159946084554707, 0.04540513429258551, 0.04141386239124196, 0.03000232151576451, 0.004936498323721545, 0.06366223855210201, 0.022349847680223838, 0.07358091417700052, 0.05957041454634496, 0.03494137452383127, 0.01639662230653422, 0.009068625613248773, 0.02144436475022563, 0.0101324540197051, 0.035102122862424166, 0.04665425958644066, 0.03033307001792959, 0.021287287286083614, 0.03734877945056983, 0.059154336872909746, 0.025861658255702684, 0.028825633227825165, 0.01926671008446387, 0.02106412560013788, 0.06433170155755111, 0.005238255569046097, 0.024229087733796666, 0.037151892336883714, 0.07639135194144078, 0.041190821145262034, 0.016029132829446877, 0.030731845048389266, 0.04179598956501909, 0.06579746611948524, 0.05030643021953957, 0.015202672087720462, 0.031039849056729248, 0.035942393488117626, 0.03359248761885932, 0.0544614767256592, 0.06490812384124313, 0.04628988628142646, 0.010127753468363412, 0.06463204829820565, 0.006241042117056037, 0.03002657914268119, 0.010206818065073873, 0.0376275759190321, 0.06528984050133399, 0.0035678851335043354, 0.023885898292064667, 0.017095374276063273, 0.030566041623907428, 0.011333555149446641, 0.03838796940233026, 0.036010111282978735, 0.020649625520621027, 0.02120353570873184, 0.05195469695276447, 0.020988387521356344, 0.07276424299925566, 0.03791410768670695, 0.07260776603860514, 0.00746057225790407, 0.07093364372849464, 0.03154810231977275, 0.04258049139752984, 0.05034301004239491, 0.019891771454630152, 0.014009281660297086, 0.047674016295267005, 0.05687098850363067, 0.040478630789688656, 0.004501622685763452, 0.04786312739763941, 0.044801814880754263, 0.019019204258386577, 0.015809104278949753, 0.04303469256098781, 0.041165440542889495, 0.007162631772059415, 0.017296863553513373, 0.059517339537186284, 0.0632061001711658, 0.010690444747784307, 0.005046279352557446, 0.02199987119196781, 0.03353030327707529, 0.048858972532408576, 0.021497487256835614, 0.03163053753918835, 0.04433853831142187, 0.01944720379209944, 0.070287848024496, 0.02645181069549705, 0.03756094038752573, 0.09801440379981484, 0.012226981360332241, 0.031100676328475987, 0.05774310617042439, 0.023871876365904297, 0.05576486446495567, 0.06232276292783873, 0.042119915397571664, 0.018691682190235172, 0.14258034633738653, 0.01802152707906706, 0.01879725036477404, 0.034665020781436136, 0.017368922276156287, 0.03262964982007231, 0.0192311005666852, 0.11240003151553017, 0.005052935781090387, 0.05804360218878303, 0.03313180983864835, 0.0166254327965102, 0.046143807869936736, 0.0398740628734231, 0.042934130278549025, 0.05531540626127805, 0.02160498247082744, 0.01130021024229271, 0.016864838610802377, 0.023233790516055057, 0.025791658886841366, 0.015465892784829651, 0.020736572997910634, 0.04943967976474336, 0.016049862074266587, 0.03373135320310082, 0.05683602698679481, 0.01830877300484904, 0.02005453673856599, 0.028377655926825743, 0.06250845760639225, 0.027391866681032946, 0.06268188437180859, 0.09027024970522948, 0.07145331334322691, 0.022729050368070602, 0.012649436414773976, 0.029962247237563133, 0.014376591325604489, 0.02543096324162824, 0.03336709864171488, 0.017756272473239472, 0.05276368711409824, 0.03452832650925432, 0.008985268434376588, 0.02950436502162899, 0.026810774380075078, 0.03510489807065044, 0.031499169766902924, 0.029598240341459, 0.04441348250423159, 0.053467792724924426, 0.0013606501576889838, 0.05532379634678364, 0.04191251438377159, 0.012282367629398192, 0.0822683201570596, 0.03499131130852869, 0.02959055593237281, 0.05959073667015348, 0.027007880321304713, 0.024755541002377868, 0.011943178999769901, 0.05089621625042387, 0.018483222661806003, 0.016015187238476107, 0.021482433957446898, 0.04411231812887958, 0.032247400509991815, 0.014103006006085446, 0.03487845736422709, 0.025706629967316985, 0.03479639194639666, 0.08490360767713614, 0.047026615855949264, 0.0026878578688151068, 0.051760255957820585, 0.10045064985752106, 0.009484034929690617, 0.013597561029850372, 0.039711838721164634, 0.006059251135281686, 0.04754589531304581, 0.0446144374353545, 0.03947962028905749, 0.03255278876583491, 0.014290447912311979, 0.03694734117016196, 0.05610545172489115, 0.03051232879183122, 0.06103330211980002, 0.0981392271018454, 0.018626205257273147, 0.03787551261484623, 0.05493260733783245, 0.006614988278930208, 0.02605236221903137, 0.020091688227174536, 0.02409166912548244, 0.02078536645110164, 0.03690943141867008, 0.0336020379992468, 0.03119883659694876, 0.02844856113993696, 0.04617698823234864, 0.03198104837377157, 0.026934237219393253, 0.021551810770428607, 0.012901892153812307, 0.028349673142656684, 0.02949902495103223, 0.04302341530897787, 0.024720168971855725, 0.016903204677094306, 0.03444814063342554, 0.02031886514409312, 0.03970750627507057, 0.02131781118389751, 0.03961070646931018, 0.03378863173670002, 0.034335055987217596, 0.03786486640040364, 0.04459864114012037, 0.022967448557860086, 0.09161139452563864, 0.0567589182672756, 0.008748893127111452, 0.017902800414179052, 0.011866256877380823, 0.035264411475509405, 0.02485805407299527, 0.04799563171608107, 0.017766097660309503, 0.1672599677528654, 0.17008550970682076, 0.14681531409067766, 0.06125604481037174, 0.0905739212674754, 0.11111950701368706, 0.21038932273430483, 0.15622412493186338, 0.17900580247598036, 0.18240904914481298, 0.15840566929961952, 0.11347631019140993, 0.10568268410861492, 0.13923601007887296, 0.10517474636435509, 0.1316375985209431, 0.1363401583262852, 0.11719127584780965, 0.11251251905092172, 0.12857788056135178, 0.21571823821536132, 0.1783951073884964, 0.11750576325825282, 0.11189394617187125, 0.06561589014849492, 0.0811421080891575, 0.17356434517673083, 0.10092033179742949, 0.13744007716221468, 0.11907782033085823, 0.0854661064222455, 0.16523289866745472, 0.09470864225711141, 0.16225798401449407, 0.12378890253603458, 0.0854111857978361, 0.1578854907836233, 0.24057920489992413, 0.0876267926235284, 0.15708798143480504, 0.18361647506909712, 0.09312550470765148, 0.09881457979125635, 0.2025698580379997, 0.1353034246712923, 0.13782183453440666, 0.19994311327380793, 0.10001026705971786, 0.10983095544257335, 0.19400534832051822, 0.16865628425564083, 0.1237780459757362, 0.10600361760173525, 0.14858258568814822, 0.09662242992115871, 0.12594824523798057, 0.17370500548609666, 0.06452042928763799, 0.15683454860533985, 0.15691201016306877, 0.1371696809572833, 0.1496292802372149, 0.15100191586783954, 0.11475714003401143, 0.1568343857569354, 0.19250331606183732, 0.1639761703887156, 0.12039382542882647, 0.12561180043433393, 0.1470091851162059, 0.1525279546954802, 0.10403124522417784, 0.1057783846876451, 0.10677886421659163, 0.10840707006199019, 0.10554433760366269, 0.17956020629831723, 0.1363802326044866, 0.1261817698499986, 0.09435754109706197, 0.12170069744544369, 0.11307302290307623, 0.15808526506381376, 0.10083055482911212, 0.11663888048912797, 0.19499227750514234, 0.13884970652205603, 0.12519576347299985, 0.09407113146569047, 0.12377615964838437, 0.10231031078313078, 0.13289786875247955, 0.0893844086676836, 0.08900327554770879, 0.12778715656272002, 0.10407106844442231, 0.1621409502944776, 0.18663081260664122, 0.09150897644992385, 0.14639105328491755, 0.18507391400635242, 0.08763059241963284, 0.16278196232659475, 0.09440173408282654, 0.25172758953911917, 0.09674879349768162, 0.13559207346822533, 0.11945086531341076, 0.06598336435854435, 0.16359570223305905, 0.14880054470683846, 0.1412719272609268, 0.15994996071926185, 0.07746474684349128, 0.1414743342569896, 0.19548044273895876, 0.1752405030918973, 0.12126050463744573, 0.09534586127847433, 0.187542519399098, 0.20680378084736212, 0.1832393045936312, 0.10703965915100914, 0.13944039839719022, 0.050598814351750274, 0.15884073238287652, 0.06323960623038666, 0.0671325855489288, 0.09476510994136333, 0.1482898656811033, 0.13449948281049728, 0.15139267061437878, 0.1382237443966525, 0.12512507369475706, 0.12693551369011402, 0.13218486415488379, 0.11388523610574858, 0.11898833513259888, 0.2062880942331893, 0.11390559215630804, 0.07262021037084715, 0.11423164180346898, 0.11659611921225276, 0.18690869983817848, 0.07774450683168002, 0.12738759443163872, 0.11634453199803829, 0.14563308895698615, 0.15251096417861326, 0.11314478476664849, 0.08279647824487515, 0.13544222579470702, 0.13727177333618912, 0.10767010639288596, 0.15147287345358304, 0.10971350781619549, 0.13056562175708158, 0.3103231596095221, 0.07617610706282513, 0.0968153170709099, 0.1779147588780948, 0.1427402498998812, 0.165532363312585, 0.11277135301913534, 0.10149682193462338, 0.1628684484000717, 0.10597028117626905, 0.20230387231068953, 0.09449204030845847, 0.07694555898862225, 0.09063500977520432, 0.12007625746939864, 0.13613766990602016, 0.06052607683730977, 0.13693403931600706, 0.07212443875947169], [0.08544290052460772, 0.055537059903144836, 0.04825489316135645, 0.03350416950083204, 0.03921249462291598, 0.08286392462572881, 0.05611337022855878, 0.044413319655827115, 0.04152798180335334, 0.030751373286225965, 0.05539825538705502, 0.018080308567732573, 0.03128381632268429, 0.028876404610595534, 0.025624869890244942, 0.07580076863190957, 0.0090416665687891, 0.016781260059880357, 0.03941007723499622, 0.044956229094948084, 0.023145148397556374, 0.0329943284658449, 0.025868606454293643, 0.023337058456880704, 0.023560662886926105, 0.013365389247025763, 0.03651424923113414, 0.05386847443878651, 0.0807315536907741, 0.014646505770672644, 0.018137992526005422, 0.04503328013899071, 0.027202446845227053, 0.016932296866018857, 0.036870025497462065, 0.03729314297171576, 0.03930317743548325, 0.03964375451739345, 0.06277188525668212, 0.05984292778053454, 0.030063745898327658, 0.040154589606182914, 0.004256008700135031, 0.060303564848644395, 0.008480066882579454, 0.03796792908438614, 0.009191995154001882, 0.028525588435253928, 0.026376907214788452, 0.015228936481954796, 0.020747965600873743, 0.03091087651305965, 0.016796080961025188, 0.036374345488314114, 0.0689929114388568, 0.022172366668071066, 0.0333724081782358, 0.024972042867115567, 0.03849007874461157, 0.030978054872580936, 0.05200269651998367, 0.05812366932098355, 0.019262291125154922, 0.019111096559624587, 0.04408220135207687, 0.017593966896778772, 0.0357885865627655, 0.049844280018338134, 0.027624247961544564, 0.03653522614123566, 0.04139107379264065, 0.02281462720462254, 0.024713632983288596, 0.02854365443012544, 0.03844030820099371, 0.028762095208678926, 0.0317253967347954, 0.02585207564490182, 0.04261939859549914, 0.0308853975231094, 0.014512274580608522, 0.02907479807202305, 0.016128846943112354, 0.03104275997195925, 0.018470741010137966, 0.038688848792974434, 0.03365382718454514, 0.03341890139771359, 0.033245094652686796, 0.03819706018215843, 0.04002277060811009, 0.03720354920785342, 0.05317096758101668, 0.01585374679416418, 0.014412019335265671, 0.037552760647875924, 0.024176217981481125, 0.025869400340265462, 0.031102759430983236, 0.04676547486867223, 0.0540976055365588, 0.1115856741421989, 0.023045083142018745, 0.04530237694936139, 0.02408497198484838, 0.036323842126876116, 0.042321304591106515, 0.021044999394299727, 0.0405867960570114, 0.026682923115523796, 0.058719796261617115, 0.0367819550447166, 0.0512264388879495, 0.02338786207006446, 0.031307904315846305, 0.053007868118584156, 0.038662589487752745, 0.025436934349792342, 0.010854746913537383, 0.06685302233589546, 0.029239390311496596, 0.01117029199044087, 0.06775681062468461, 0.03971003721069012, 0.07858724732484136, 0.018457908216597776, 0.03235475492796727, 0.020051625823335986, 0.03094847753111805, 0.01949532379928444, 0.029878994383450066, 0.046555074730089734, 0.044581969534712176, 0.058547970838844776, 0.06412475516221353, 0.015356526510523898, 0.021513590589165688, 0.03423078890357699, 0.13286919386259147, 0.03144592512398958, 0.02964361397815602, 0.030377792261008705, 0.04871328088587948, 0.05268969626298972, 0.04574749592159476, 0.01696606755389699, 0.06231093606246369, 0.010452344265234257, 0.05405738876600351, 0.09108840687466518, 0.009689234945523952, 0.05231535527855158, 0.03705748436706407, 0.04463501740247011, 0.04909519771380084, 0.030948385928890536, 0.040719897486269474, 0.05094117258808442, 0.017613703784133707, 0.038174003562224765, 0.04470950019146715, 0.0516795238613018, 0.04855994554236531, 0.09724102315625974, 0.01585153307366584, 0.01872265731383647, 0.016548067930021455, 0.019510877518249408, 0.06850083105798278, 0.01787265479963805, 0.0259412962145039, 0.08260154191936765, 0.02587890831221427, 0.02275717055558094, 0.016666372206860354, 0.017328958259895444, 0.018724192499316165, 0.03181344343881522, 0.043934762477874756, 0.04101022905004876, 0.09199218159275395, 0.15662114934197494, 0.0525149497469621, 0.016794218382398998, 0.03871812079367893, 0.058913402658488066, 0.01465123176707753, 0.029393600965184823, 0.05204179710043328, 0.022220522298344543, 0.03026480260970337, 0.07579567961926971, 0.02151595358736813, 0.0318943790958396, 0.04442934326029249, 0.0398474575153419, 0.010592813736626079, 0.07132367244256393, 0.013712090107479265, 0.03739626333117485, 0.049167736499969444, 0.027380340067403655, 0.018833663946549808, 0.013260945744280304, 0.02150256948412529, 0.011613422855069595, 0.02977710895772491, 0.026566255804417387, 0.022536322674048797, 0.06063267468873944, 0.029828701367867843, 0.03544865069644792, 0.01931694712090705, 0.07861153887850897, 0.04929267176027809, 0.05326281747381602, 0.023819931117551665, 0.029599295463413, 0.023292463439117585, 0.06481082191956894, 0.021845200830804448, 0.06761741917580366, 0.03565788036212325, 0.02560863593992378, 0.020295769508395876, 0.03337038275120514, 0.03222293932256954, 0.027120454369911125, 0.03062838881409594, 0.015176679107493587, 0.020571858622133732, 0.033716679883322546, 0.01666262499721987, 0.019448883166270595, 0.05417317058891058, 0.009992551125053848, 0.10511869258646454, 0.01820421075847532, 0.06471742157425199, 0.016895537231383578, 0.029201945356492485, 0.07811909208872489, 0.01924419798888266, 0.013606727189783539, 0.011406915811156588, 0.027761534255530153, 0.03079867735505104, 0.07603721772985798, 0.05064325500279665, 0.02136490321052926, 0.023850795979212438, 0.02592609533374863, 0.007544244107391153, 0.009655923965120954, 0.029381824989936182, 0.018047983159444163, 0.010367879377944129, 0.038504748671714745, 0.041309615663651905, 0.04233652073889971, 0.060323337359087806, 0.025019043291519796, 0.05164178374356457, 0.0762322558356183, 0.07243611024958746, 0.018955544102936983, 0.04766240656109793, 0.021623757534793446, 0.03037821634539536, 0.03523478663659521, 0.022701866558886, 0.008398254219043468, 0.022496894700452685, 0.01166255387943238, 0.01406660005782864, 0.025945248680987527, 0.07049424480646849, 0.07722846737929753, 0.04894703619980386, 0.02625684892492635, 0.028875678578125577, 0.040346119685896804, 0.04822783997016294, 0.039671805155064375, 0.019815994360085045, 0.012486013800038822, 0.0439149085432291, 0.05044360964425972, 0.06780844035425357, 0.050466886788074455, 0.021829514797510843, 0.028647812948163067, 0.014792036265134811, 0.03843461189951215, 0.010709262220188975, 0.05650701892695256, 0.045883267386151214, 0.023563595854544213, 0.08439463177429778, 0.03593998129612633, 0.051138134340622594, 0.02630608681855457, 0.02360864549076983, 0.01533129348951791, 0.06233383661934307, 0.013988705085856574, 0.06801212978150163, 0.002051073745990704, 0.06752017153693096, 0.039616056717932224, 0.045758695142077546, 0.010840947207595621, 0.022205716664237634, 0.03522384186674442, 0.050294667814991305, 0.0754406972389136, 0.023845817228513103, 0.018466354281242405, 0.057538134311991077, 0.01746981025540403, 0.03693040832877159, 0.029085569815444093, 0.01885820146916168, 0.037069562290396006, 0.027174774490829025, 0.04302639068503465, 0.05271944323820727, 0.03945123038387724, 0.017586586132113422, 0.07610527479222842, 0.031105907833469764, 0.007888326670841446, 0.0952320166730455, 0.03742843267640897, 0.03837023249694279, 0.016770649468526244, 0.04984646150842309, 0.02424373391217419, 0.01473828950630767, 0.05061483117086547, 0.05828841083816119, 0.008166591337482845, 0.04469045710616878, 0.01915801047081394, 0.03007467370480299, 0.06624485139868089, 0.024122873254652535, 0.051437252932893376, 0.010039272501931658, 0.01625660660543612, 0.007809056817287845, 0.0682531725615263, 0.14615965927285807, 0.14760086765246733, 0.1410187387040683, 0.20326124450990132, 0.1710448767989874, 0.22982054363404, 0.16646631248295307, 0.12011595176798956, 0.27621496841311455, 0.13367728835770062, 0.10510689964784042, 0.0979892233652728, 0.07251727660851819, 0.12543026517544473, 0.16279778576322965, 0.1100467974320054, 0.10934182668903045, 0.13520707269864424, 0.08222236976559673, 0.12120495976081916, 0.13595276911343845, 0.15244699189705507, 0.10707779281905719, 0.14383171418947832, 0.15598473777728422, 0.11238890354122434, 0.06574185338935681, 0.12808047368058137, 0.11323657019862107, 0.06558302191219159, 0.11041459733886377, 0.1937800475529262, 0.1446758931768792, 0.10789067777139799, 0.10989412705280951, 0.15591890630977495, 0.16522671042808465, 0.10706246471298592, 0.1751305397067751, 0.18820058980158397, 0.10454299633524247, 0.10837849016700472, 0.08959495129862002, 0.1715243567845651, 0.10226473358592816, 0.12412023118564061, 0.11565089278987475, 0.13449436665645667, 0.0693685823519315, 0.13846520786838873, 0.09940323606133461, 0.1273973517652069, 0.13395643766437257, 0.12899779874299253, 0.15941849138055528, 0.2197063277874674, 0.06929806220744338, 0.0864332698817764, 0.1706159883844001, 0.1545886384057147, 0.22237013413437776, 0.12512032394962652, 0.14518243313900062, 0.2113667388579675, 0.12200250982173852, 0.15216793758528574, 0.18069554466222013, 0.11227372900715896, 0.15030962015901292, 0.16822734155825206, 0.2077415840966361, 0.14743564437542642, 0.19273274232234272, 0.18421126529574394, 0.07660569436848164, 0.09228321883295264, 0.09049569296517543, 0.17654339889330523, 0.07551367368016924, 0.0854574211740068, 0.13571817241609097, 0.10756366460451058, 0.11165502720645495, 0.1496322929326977, 0.16995513598833764, 0.08014098395194326, 0.1581913607993296, 0.2105689173830407, 0.09154081331299883, 0.0867144547935043, 0.07244250883481332, 0.14342337181525572, 0.13661436789802142, 0.11036602780222893, 0.12633306958845683, 0.06470123851405722, 0.10205149717096772, 0.19322538588728222, 0.10002364098493542, 0.1344765211854662, 0.11727716481047017, 0.18103170448115893, 0.10144573503306933, 0.1006666479100074, 0.08440995988036905, 0.11022594424762897, 0.1426218726805278, 0.08519419029887233, 0.10683795783136572, 0.10404698045126029, 0.1227099232907806, 0.13257116771170072, 0.15322208244885716, 0.07182713864105088, 0.08415273404014961, 0.09299424889364413, 0.180476825684309, 0.06451635129217591, 0.08621976883815867, 0.10069290042987891, 0.11796918910528932, 0.10858443911586489, 0.2436542170388358, 0.11055788357875176, 0.1876752001366445, 0.1319058776966163, 0.11267453964267458, 0.08319230164800372, 0.20481571395482334, 0.12350709337208952, 0.1080202983160104, 0.07068956111158643, 0.11894735161747251, 0.14641314638512476, 0.11798818808581148, 0.15166207615818295, 0.1490523490522589, 0.09538174899561064, 0.21924043207296304, 0.0993142801203898, 0.10214609852326767, 0.0892016181190099, 0.1467827579804829, 0.14728937936680658, 0.11357258073985577, 0.10986250053559031, 0.15578646984483513, 0.15462403079228743, 0.10506926809570619, 0.26028185337781906, 0.21154755486973695, 0.08057819120585918, 0.07441573616649423, 0.16476845501789025, 0.14100002470825398, 0.09194628548409257, 0.18827790208160877, 0.15560331967260155, 0.14388633625847952, 0.11256971276764359, 0.12657438378248895, 0.13245412042098387, 0.14655159467032977, 0.11743472064180033, 0.1277317881051983, 0.1035753714718989, 0.15986321680247784, 0.09873763392014162, 0.12785847059317998, 0.14378094619938306, 0.0954608933201858, 0.1213882320693561, 0.16550675540098123, 0.06200163944491318, 0.06085928502891745, 0.12231905997863837], [0.006686420628934034, 0.05168446698891265, 0.02899655280634761, 0.0949831096721547, 0.025849868709753667, 0.023627803927021365, 0.04629869366596852, 0.038500918341534476, 0.060265193693339825, 0.013676126055153353, 0.02494181752470987, 0.023708174703642726, 0.02491770069380956, 0.02412167564034462, 0.0038733119810266154, 0.038423165013747554, 0.0581341323309711, 0.022921706815915446, 0.007297615287825465, 0.030921176674642732, 0.03791640792042017, 0.012295348004304936, 0.0507742597588471, 0.04440667001264436, 0.0364680308183389, 0.013732340136942054, 0.04325239034369588, 0.009369878198153206, 0.026240350345947912, 0.021226892580411265, 0.013424372599859322, 0.03106179627190743, 0.0345783888229302, 0.01648470463364252, 0.035837610717862844, 0.08703202275293213, 0.053175500194941244, 0.018439248503584946, 0.05615924937384469, 0.07139557679849011, 0.0716572402577315, 0.07127368476774011, 0.034985872850354226, 0.04615699519802417, 0.040814034042081664, 0.02825091067435486, 0.026484687413488115, 0.003062763945698472, 0.02264404689360942, 0.020566455787047744, 0.028709844619567906, 0.019198010110163262, 0.04318288800173572, 0.057046332130474706, 0.033813622181436846, 0.01765478229416268, 0.05583032952355487, 0.031519753126693625, 0.009201597272684532, 0.04326199161420975, 0.04978865711018443, 0.01956408653807427, 0.057940213807991574, 0.06966615388435976, 0.029915462248027325, 0.022605460303436433, 0.050263672335339446, 0.029196262625711303, 0.03194442783881511, 0.03781910599874599, 0.03925347474536725, 0.03556388969134007, 0.03671139758080244, 0.06818756501057319, 0.026386072526552846, 0.01688462299560862, 0.03690338906432901, 0.014474568389622229, 0.045959578827023506, 0.056457428195114644, 0.023805495285029923, 0.03886486416948693, 0.013179324766887086, 0.061030818681631765, 0.03534944548404642, 0.024664101623264805, 0.05247391534170934, 0.03556463607986059, 0.0248425257990935, 0.027362981445289085, 0.02616510759772999, 0.017127932082595568, 0.03175940830260515, 0.05821073893457651, 0.0735134067279952, 0.030086514140878404, 0.023714602126606872, 0.013234024867415428, 0.05640399356239608, 0.08578505180776119, 0.07460797192262751, 0.04103945694597704, 0.04369780108598726, 0.03932001188929592, 0.0626056238210627, 0.03444493116278734, 0.032342456480754275, 0.014017564876537238, 0.03213815637198942, 0.027783206664025784, 0.015398024015926888, 0.020542111646916186, 0.022540870555011288, 0.018049823685682247, 0.025411999884194562, 0.03579953133261629, 0.09087335877120495, 0.049870376475155354, 0.034970700807337246, 0.03722381704886045, 0.033757117177758894, 0.0664083036993231, 0.037419319951108525, 0.041584412168179236, 0.027834393649495075, 0.023673399783936993, 0.03947229889620628, 0.020410533528774977, 0.017020435172266195, 0.07942505486841712, 0.04307232750579715, 0.03332526017246502, 0.01924556862962033, 0.04259414352210505, 0.012439971806348434, 0.019415753693985086, 0.007760268453109477, 0.0239076436430748, 0.0318069261099611, 0.03907442970999649, 0.024812027346342802, 0.03830071319160717, 0.04853820528036781, 0.027792382153815458, 0.016496684169396758, 0.024025749448420744, 0.021085178845428994, 0.004768555393509034, 0.052677882968315055, 0.033872400277427266, 0.027880708753530468, 0.01289146052606936, 0.04351407076631274, 0.0572842468640634, 0.027450821196128215, 0.02010040740216417, 0.016356430981042128, 0.08160437364131212, 0.026965263233120953, 0.02229842490383557, 0.05562491661735943, 0.010331913629280669, 0.02582353137300483, 0.013952560373581946, 0.02130958903580904, 0.03054989588313869, 0.039346535823174884, 0.025868450391239355, 0.028980552950607877, 0.04031093425250479, 0.032107540871948004, 0.005351013246191931, 0.027043123430173312, 0.08104380193565573, 0.026378593374309794, 0.006944526444255773, 0.07164241426757403, 0.06922697209353958, 0.02882740759689893, 0.015302141928779227, 0.0021566304702511324, 0.0164930981118232, 0.01775815031890358, 0.057348117365368774, 0.06041622880314078, 0.03436280128413013, 0.024931727708982568, 0.022177437020997916, 0.059453469035880904, 0.014607627410441637, 0.011590728403202124, 0.055378387881709, 0.0761328504553863, 0.0069126794031555095, 0.014957602202360119, 0.03626858562763248, 0.10836934351495334, 0.028399330031658922, 0.051565814962876697, 0.03671575377562216, 0.05615262347938759, 0.013912840629927814, 0.046884194748210054, 0.04362796626186796, 0.015990432584658265, 0.027437426914860095, 0.006980983706723366, 0.012051872676238418, 0.003201688265627516, 0.021301697673542157, 0.01113792841455766, 0.0587949575856328, 0.07374570319162947, 0.016561904955389242, 0.03284846040021096, 0.052381458160068305, 0.03201528725081256, 0.07325956677751881, 0.04070481365280492, 0.0029447058498460266, 0.036942896765789816, 0.041232808892216, 0.05558058113924094, 0.02851120349285858, 0.057133042120507786, 0.015204919734969735, 0.03692933624344213, 0.014004316480298127, 0.03865109849721193, 0.08630500640720129, 0.040129694156348705, 0.05282107760597553, 0.07052864653191396, 0.035747012722172906, 0.024685643413769345, 0.05598070306171264, 0.03242729032146079, 0.028626157503042902, 0.06432282631950718, 0.005440479784738272, 0.005381994731059032, 0.028424695366993546, 0.00650795446875106, 0.018179637612774968, 0.03237297698589308, 0.05321543198078871, 0.05850436817854643, 0.12368343105273587, 0.08084874347384487, 0.02298190813910748, 0.02192750882490405, 0.007150621702229338, 0.022136100667661855, 0.03619365161284804, 0.05552617280877062, 0.04386466641777328, 0.045079966740948815, 0.05753595621458121, 0.04327879214127149, 0.011578563118486531, 0.03594168781169823, 0.06726041476109199, 0.04287539628733482, 0.04621886062834944, 0.03251290447743876, 0.01523412048949727, 0.08061160905552761, 0.08706590200641326, 0.022707230378208414, 0.04728682046490056, 0.01837160874025098, 0.0075387360993772745, 0.06417312792369298, 0.007859766283737761, 0.04847657394462398, 0.015049767613943135, 0.03397473692893982, 0.011862506275065243, 0.042180796952119896, 0.03745420682909233, 0.004804098754123385, 0.034286452523831806, 0.04372415538611157, 0.06163003295660019, 0.01198284191611622, 0.010788110533862241, 0.007663710375449487, 0.04653753799253276, 0.032436199486255646, 0.04509080633787172, 0.04254464099981955, 0.017686327387179648, 0.04561005526089242, 0.05159206409007311, 0.02640209613101823, 0.025331652856298854, 0.04408297488199813, 0.039007532942507944, 0.026272899670792476, 0.04262827383354306, 0.047032831236720085, 0.03580536673377667, 0.012594592973722942, 0.06062333804688283, 0.061405743206185956, 0.0711367360449263, 0.04831802745216659, 0.006004047646586384, 0.03397322379584823, 0.03010267684502261, 0.02683158844177212, 0.046460266424609084, 0.06724873038807086, 0.004387084278278053, 0.041098448780498335, 0.09452592634728976, 0.05652498314157128, 0.020327172109058926, 0.08437656238675117, 0.04458046657964587, 0.07647174477045025, 0.017362813764650906, 0.025799255086375133, 0.02093007761452879, 0.11255787911691836, 0.026593232660421302, 0.03270699941952314, 0.06210673773395164, 0.01679546688683331, 0.03885144613949316, 0.0381692639951195, 0.039366857946983407, 0.010795420900519406, 0.10626000205853156, 0.03824859830949988, 0.03774112196905272, 0.04866235683272992, 0.022692331445536444, 0.1364428342453071, 0.038685143991772614, 0.01552737653920693, 0.02949124215436833, 0.027459954277479222, 0.05195904975490911, 0.055505796402160607, 0.015296781502131904, 0.01603902587001877, 0.042456468766821284, 0.02880963676476053, 0.05754237515585763, 0.03445535006799868, 0.01831810625403055, 0.14981726157878125, 0.09759876717414175, 0.11767919680901937, 0.1952998438583953, 0.19757319401417459, 0.07935520647359745, 0.12359838347349848, 0.10733073031795876, 0.23953659513166972, 0.11083507870457002, 0.18216006750507013, 0.06581075862050056, 0.14511098340153694, 0.08155203823532377, 0.05812244117259979, 0.16669811361602374, 0.2521255096154553, 0.10613637297813382, 0.190368848453675, 0.10376656906945364, 0.18931737701807702, 0.09578690904059581, 0.18159814551472664, 0.15494568353252752, 0.16810578879501137, 0.07998538908681699, 0.14896076039544173, 0.12952397550855363, 0.09680636719401393, 0.10936754316623722, 0.13784024997481278, 0.1562039317297084, 0.11486797194395747, 0.06079901076321091, 0.08395668491721153, 0.16432355317686284, 0.13069842463093145, 0.17331245940710815, 0.11352095101028681, 0.16785072748150143, 0.18811964057385921, 0.2057214089270149, 0.23328609338828496, 0.10630714667162725, 0.13611803310258047, 0.08844065466629607, 0.19910174342138426, 0.1124950535595417, 0.10055044878806386, 0.11934494599699974, 0.06256499992949621, 0.12603391706943512, 0.10939750048731055, 0.14896105895084993, 0.09392936514424426, 0.13578274180846556, 0.10233513159411294, 0.1445118369800704, 0.1457894912787846, 0.13996105188769953, 0.092203911659973, 0.08199745576296534, 0.12060145714453288, 0.09459421411156654, 0.13927811996213027, 0.22389165391879423, 0.1427161619067192, 0.16680245873119148, 0.14536349342337676, 0.12345538900366851, 0.1214309526341302, 0.17600489993180546, 0.15878070917512688, 0.09656277312231915, 0.09882351609745196, 0.11156360818339245, 0.12831079560731137, 0.09576489736459085, 0.1371197679213115, 0.160068473645619, 0.11633899515228611, 0.16373537188129766, 0.0979979018281613, 0.18045458330639771, 0.15789836937827723, 0.19314845358686789, 0.17384102461593492, 0.13078628134514603, 0.12394990532525949, 0.10472913884690829, 0.1933113969862461, 0.1546031590551138, 0.15273812413215637, 0.16121392218129976, 0.13426380045711994, 0.06773846982313053, 0.10654314115111317, 0.11504815013280936, 0.09672742642994438, 0.2753074685377734, 0.12330898828804493, 0.11423350098942008, 0.1119401544066412, 0.1215410517262561, 0.09232061289783035, 0.1546426633638995, 0.11757966929248401, 0.1810298724366086, 0.09634601511061192, 0.09025562049022742, 0.09945696924946137, 0.16033808274992875, 0.111076460752104, 0.08617408307535307, 0.12362525346023695, 0.14381262021405355, 0.18563086912035942, 0.08031819015741348, 0.15361462852784566, 0.07216847568218197, 0.14804986784500734, 0.12899144765521797, 0.09305881150066853, 0.175489661150745, 0.10520339411284242, 0.08048709787960563, 0.07860925900084631, 0.18818283932549612, 0.13844580176685536, 0.18512803395943983, 0.12366547701614243, 0.1230299746883767, 0.15706666186451912, 0.09064633452466556, 0.1399564921323742, 0.10497145048741784, 0.16749803854950837, 0.10974958552313702, 0.13352760353258677, 0.11324325376855475, 0.13388684711286, 0.12482461838849954, 0.162071468308568, 0.1070627293416432, 0.14742058089801244, 0.18267865824912274, 0.07130999996193818, 0.11228113182421241, 0.15056894267243998, 0.08054654433258943, 0.07359721937349864, 0.08377628281180348, 0.10012010830853667, 0.1457493762884821, 0.08711983875504561, 0.09800349295671497, 0.07997044774570636, 0.31718591707093374, 0.1304722281971148, 0.11218982815210309, 0.15670246497860976, 0.1535314672759601, 0.23813371040991374, 0.10709864420018025, 0.08902743139437266, 0.08034803891288382, 0.07311452313193254, 0.1414933196668114, 0.11742733818079744, 0.07223363540002278, 0.11097478227955954, 0.054370230729026456, 0.2215364860104663, 0.177425779402256, 0.14742370215909822, 0.1422734178070511], [0.0742871877072113, 0.015314292794625674, 0.04234064623181309, 0.04958915424400142, 0.023944827362096736, 0.026845778305349604, 0.024813791537391286, 0.008796955458819866, 0.01709346080731068, 0.0171416724167232, 0.035995726340583394, 0.03827843688694494, 0.055397027238671265, 0.07363210964415755, 0.06918509291218859, 0.03641474207064935, 0.009177443970526968, 0.010213481278957, 0.11853096181792871, 0.060841256353471956, 0.07743383278804165, 0.003616740078931408, 0.03392447105475834, 0.025843868763851266, 0.016165389446541667, 0.05825824995658227, 0.024340978158371787, 0.038296964285629134, 0.07579960833702769, 0.051908817807478566, 0.03543376024546368, 0.02216016491209822, 0.024890067355175103, 0.09328771528920957, 0.06913051155528852, 0.017134276385019933, 0.03739098432872977, 0.05709125793405941, 0.03155591565051249, 0.039116115508867164, 0.07816639276487486, 0.006489826981643481, 0.043573815774704726, 0.08070032072386571, 0.03636566363275051, 0.03086720939193453, 0.03467746511367815, 0.026468523013006364, 0.0880869140050241, 0.016088508036253706, 0.09525662035282169, 0.02650045826365905, 0.024731573449181657, 0.006848884388870958, 0.07363033188240868, 0.02813748676063759, 0.02616855625196227, 0.03025755246302911, 0.04194558278790542, 0.059439382648893764, 0.02958244065354977, 0.022041853849909136, 0.016368368108357702, 0.009527208416589668, 0.02720468770712614, 0.04040319126631532, 0.031772860259349854, 0.06761752774140664, 0.027133757048951726, 0.03737203284565892, 0.04089800953598959, 0.027383729349821806, 0.013696749278876399, 0.018596705947337405, 0.013296830068741525, 0.015355664771050215, 0.016585458602224077, 0.04342714364507368, 0.029235797468572855, 0.0705081412036504, 0.051226225149418624, 0.03001139352896384, 0.04068354157997029, 0.0010555082948745362, 0.03670210504372205, 0.03669925180396863, 0.020091767955039228, 0.05954926460981369, 0.06852113282574074, 0.007485052953208131, 0.037046997608350854, 0.03295044421351381, 0.020037218828552535, 0.04623662128246256, 0.013404566162664975, 0.037424293612795215, 0.02235863640505288, 0.005929035600274801, 0.026621435968471423, 0.009465437132998236, 0.019865298410877585, 0.024891395587474108, 0.021482802062694515, 0.03574684987376843, 0.04045117047748395, 0.025805494215871607, 0.022766188285978775, 0.01669152041098901, 0.016405441565439105, 0.04032677125984004, 0.029356963466852903, 0.008550207895625914, 0.0487526800217373, 0.010030860364037966, 0.030189736280590296, 0.044070048789892874, 0.05155533498951367, 0.0195357068109193, 0.04526799897264157, 0.08368098935378449, 0.031667856965214014, 0.04342321153464062, 0.02614918746985495, 0.016088433397401656, 0.06957529126001255, 0.009869561563911182, 0.059779355834637365, 0.026439819285379987, 0.024045369288484966, 0.046005820988544395, 0.07971816842577287, 0.009076399080056165, 0.060041562121893675, 0.06055063980498484, 0.06085004338196345, 0.025941526916410242, 0.02459327274534319, 0.017391522581289922, 0.030069767896618162, 0.03499104328719633, 0.06752543018332549, 0.052643423567392995, 0.03617480191002999, 0.026024510052853396, 0.03344790537708572, 0.02119233988092414, 0.017212762530626993, 0.01665572090340512, 0.01836099136354668, 0.028883366379886866, 0.024514949448140602, 0.038672910005386384, 0.05340746756909149, 0.029976543970406055, 0.055557130968996456, 0.0408444391962673, 0.01775266945229045, 0.03579513781837054, 0.018807536955656748, 0.019757411342912486, 0.03784679362018194, 0.06829868869057723, 0.0313593169142093, 0.041879076178052595, 0.041119096601115804, 0.026221522695517967, 0.08245424553751945, 0.039969237587813816, 0.03506197394537074, 0.019174073091042892, 0.05847370518105371, 0.04108897303896291, 0.03197461586179478, 0.008417187890570079, 0.01714052229986659, 0.028184424420552592, 0.04316391955528941, 0.04804284418267863, 0.0029766922026673065, 0.028511624184570143, 0.015206119045615196, 0.04624425480142236, 0.06506554396556956, 0.04359922691115311, 0.06885388639888593, 0.03503681725955435, 0.011899237920131003, 0.07317607982882432, 0.00907622096461377, 0.014447411721838372, 0.04931795736774802, 0.018662447508956705, 0.026444172087524618, 0.019506450077252727, 0.04687368424077119, 0.06309015889252935, 0.08935154721673046, 0.08053551813853638, 0.04326138093269297, 0.04445839134444084, 0.016406374551089745, 0.019932902551123073, 0.028124160332871333, 0.0811120422024812, 0.0021223464282229543, 0.031145734446389333, 0.007052774832118303, 0.043224427915577374, 0.03347969813538449, 0.04446136672049761, 0.027027339009302, 0.03207107300737074, 0.08299768423395497, 0.040598130984497924, 0.01493698321948094, 0.016212038729073744, 0.09229220942194973, 0.0497854578175715, 0.016654223037351455, 0.019877927643912177, 0.036787111910858324, 0.041397845572126765, 0.015570936791066612, 0.08400109503418207, 0.05125426221638918, 0.07085312197783164, 0.03682408867669957, 0.040897975609238656, 0.04592131284464683, 0.04380439893741693, 0.057753175630101135, 0.017287694849073887, 0.08992205946041004, 0.0870261194982699, 0.041723671302731545, 0.04763935672651444, 0.03044956430260624, 0.0379933029014085, 0.0696832122547286, 0.049200180651886125, 0.030191113706678152, 0.05637311343369739, 0.023432418072064008, 0.04210297577083111, 0.02986720823017614, 0.028852326795458794, 0.06539805326610804, 0.022231173601799777, 0.020085133578894392, 0.016038025030866265, 0.026608894944989255, 0.021491080189922025, 0.07588314956852368, 0.016892948620287434, 0.031431825166302066, 0.04436737604971443, 0.03912655137745397, 0.06210595741868019, 0.15673039347997733, 0.03441122493573597, 0.0372741439911936, 0.0812783647062523, 0.03689645104376333, 0.053890615036445, 0.02953388468761529, 0.02410927371654127, 0.036089469346084764, 0.020316585266430463, 0.02822740113229624, 0.05266907897644809, 0.03693433365385447, 0.018067185700471913, 0.050340261975569386, 0.021080403655235256, 0.02467051717186613, 0.04294517682865262, 0.04366301938093134, 0.04064896682809506, 0.010826508830567556, 0.07554093721721854, 0.05790719629398414, 0.013290289839330529, 0.03616996395534702, 0.0668101389227169, 0.004829477236073996, 0.06632826370852334, 0.03415982431865164, 0.04056729496057544, 0.057912977412343025, 0.08987066721809761, 0.006267619909652109, 0.025761034905112216, 0.052387799069817574, 0.03548292010756476, 0.034899838002664704, 0.009822594218089111, 0.03625590041545885, 0.022857692125918608, 0.03299395527158465, 0.03356515622830816, 0.016881729043754082, 0.018155222226466452, 0.019217663876978413, 0.017273959603958895, 0.0575704529349293, 0.08458798032786165, 0.05241993448830076, 0.018722842214629054, 0.07020568421908788, 0.05324780149385333, 0.043879064930869, 0.058020023096885, 0.04647035624033638, 0.0389701558410057, 0.0788407005103571, 0.024074792263231108, 0.030919351415442567, 0.03163114822070513, 0.0067075485130771995, 0.02208271692506969, 0.06034739142549889, 0.03635185205244592, 0.02242698354114379, 0.0707670905228172, 0.004591321198469294, 0.0069174986981254604, 0.07756156021995203, 0.033266366725521426, 0.044711651147476265, 0.05580609564536384, 0.05198922759986349, 0.02084782051055559, 0.03748108360118099, 0.062120498424129825, 0.029423354725752558, 0.033674732848469696, 0.01526278180868498, 0.020331467235726968, 0.013975867203303745, 0.020021997591746703, 0.033137210977396796, 0.01677389456225293, 0.08504063103880201, 0.003613491168445242, 0.015351089748686977, 0.012351272012373167, 0.04580848943442106, 0.020364924101158977, 0.02506577060557902, 0.01505956905228751, 0.018049114616587758, 0.04187472337590797, 0.19433787119175705, 0.12212383188307285, 0.11805722223860876, 0.11342139635235071, 0.051078162022999356, 0.14599381174360002, 0.11882338326956544, 0.1591454760304519, 0.168510019247021, 0.11939332554382937, 0.10704354037131582, 0.1331894759620939, 0.1181076102490936, 0.1419592560934169, 0.10267483336584908, 0.10823745666337864, 0.11461463410939489, 0.0502822200900742, 0.25066519368972096, 0.1605254534099783, 0.18379247348223413, 0.1604086503918682, 0.09687069909913198, 0.13646203678633484, 0.08655334343867642, 0.10432254709303379, 0.1377965658903122, 0.13813500558691366, 0.16086104325950146, 0.13911436232072966, 0.10229842284960405, 0.17250475846230984, 0.10770185504640852, 0.1730004282934325, 0.13496335649064609, 0.07669523384954248, 0.15288421272167138, 0.1404627471097878, 0.1092874285365854, 0.11521048285067081, 0.20591194156025136, 0.12243209034204483, 0.13266194212649549, 0.20500019405569347, 0.08105693837361676, 0.15261118380086763, 0.11959079280495644, 0.12437270049537931, 0.15696667294417108, 0.09424676346991744, 0.15339600454483712, 0.14827086670058115, 0.09473679467503514, 0.08685931523463555, 0.138550323301128, 0.1185413705451148, 0.13781099154480866, 0.09451922242130552, 0.1186987499573401, 0.1210813442511218, 0.09852839407644101, 0.1766824307186263, 0.1991185982312475, 0.08261634755347456, 0.13308692217937537, 0.18797167922769273, 0.14800693014902727, 0.16220503114163876, 0.08609839927937303, 0.12072564262364592, 0.1949205563536712, 0.09179676350738321, 0.08525051549077034, 0.13210300569023403, 0.11523472012153693, 0.09107221024377005, 0.1315963300211089, 0.07577478752604552, 0.10171505236732108, 0.1523949618318251, 0.17238229646214417, 0.1458439640700817, 0.2517414859363011, 0.05322279069306595, 0.14450594729610852, 0.13022345011787756, 0.09892758301326207, 0.11377103187675987, 0.1354053813431944, 0.13324838637241296, 0.12605244107544422, 0.065552291061197, 0.10731062532535621, 0.12669964134693146, 0.12373335765940802, 0.18253513452197823, 0.13969460475657666, 0.11160320748708077, 0.1117478304409555, 0.1597116592207125, 0.13036322833171912, 0.10556157239313636, 0.111113719109978, 0.1320363599807024, 0.18189634808472224, 0.1367337086371013, 0.15302234888076782, 0.14546098533485616, 0.07932864182761737, 0.1739571083869253, 0.1090356038351144, 0.0827055884791272, 0.13250024723155157, 0.15410985052585602, 0.13420540573341505, 0.20236609397189959, 0.22019594508622373, 0.06658477708697319, 0.07092416459428412, 0.16494940673666342, 0.09380768345935003, 0.11378812417387962, 0.16048119935606206, 0.11514256149530411, 0.18030540059719766, 0.07931405332471643, 0.09748741957758154, 0.16923078628523008, 0.15535644149141653, 0.19147157642458165, 0.1893118673137256, 0.09304367338440248, 0.2753644111965384, 0.1153766560767378, 0.15692803716020925, 0.11393373778888158, 0.1138616366578, 0.1436945822622095, 0.11604691296815872, 0.13565607289118425, 0.17344579153827258, 0.11834892444312572, 0.059106486583394666, 0.1124872707628778, 0.18641927252922738, 0.060601855628192425, 0.16209447064570018, 0.13377342319914273, 0.13892456250531332, 0.12545444816350937, 0.16504822857677937, 0.10763774027249642, 0.10547484204705272, 0.14282307188425744, 0.10494615470192262, 0.09670304666672434, 0.12668514783893312, 0.16608663142791816, 0.05674514400639704, 0.23829018058521406, 0.11318629075373922, 0.1918764989823103, 0.08030714360730988, 0.14335804246366024, 0.0925770719934787, 0.13822461292147636, 0.2523571343294212, 0.10486225384686675, 0.06309433188289404, 0.14139748338077748, 0.1756720513637577, 0.10075426713696548, 0.10046770822788988, 0.06392669757562024, 0.18177475460938045, 0.05695468919085605], [0.013230651700203972, 0.03031488527942981, 0.03741309778498752, 0.04188675040911351, 0.056464037126196284, 0.0407791234153722, 0.0203838891549302, 0.004398807667062751, 0.07152793183922768, 0.015747902116605213, 0.007989786315842398, 0.04440921451896429, 0.044630345688866715, 0.045078093984297345, 0.014398684425811683, 0.05961466860026121, 0.035525291226804256, 0.014717643382027745, 0.01730068031299327, 0.045054277405142784, 0.04206919829760279, 0.015279461895780904, 0.006474175299185195, 0.03744858177378774, 0.03148470000763025, 0.040549300211880884, 0.025011867783697586, 0.036031193366008143, 0.06422726823283093, 0.038299359514244964, 0.03155268243114863, 0.05755235640598195, 0.092698611186019, 0.0727701937513692, 0.011887692646788699, 0.055180788306253295, 0.011972144811547228, 0.043830054346472025, 0.04460073781332799, 0.042168016745043654, 0.04462100565433502, 0.006102606554382614, 0.008402092182742698, 0.05017446533643773, 0.03781683290643351, 0.048390834259667566, 0.03008725374404873, 0.02186095471759992, 0.008817567656348859, 0.032110292331448624, 0.023297143634408712, 0.014423595142683812, 0.009916594218728798, 0.00891036240916167, 0.04034892882087401, 0.020932793450940932, 0.029640468968344585, 0.06682207435369492, 0.01115072812951569, 0.06135484629443713, 0.02902849144967539, 0.052733312493988445, 0.044734246363597255, 0.024577649476538812, 0.040910019605819664, 0.04398050591615694, 0.02280930070472615, 0.04939576837101153, 0.007806362185095037, 0.045990238431841135, 0.01722851302474737, 0.022602086288056204, 0.026005919889679978, 0.024220602653388466, 0.02011151671675699, 0.050901688635349274, 0.03789745983002441, 0.13374480259205612, 0.024804405701745833, 0.028629261800753217, 0.12033849768340588, 0.013869398273527622, 0.02565959222348673, 0.034681482040988545, 0.031634018423834016, 0.036832926595317464, 0.041889104925628216, 0.018441351962142756, 0.04496332657124315, 0.0570841875991651, 0.04017215348514063, 0.0059089920999083135, 0.02929216337257198, 0.0097846344246396, 0.03769771608390978, 0.021035357411684732, 0.04515710599454386, 0.04262173275596329, 0.01123492923631732, 0.041017309562968354, 0.04800346879554646, 0.013589149740125452, 0.035580306846116266, 0.035536059577550204, 0.029895655810832977, 0.023751550054709827, 0.00806695525534451, 0.03658871505675571, 0.02431447627688093, 0.03784591831000788, 0.08810522766517741, 0.02594426989422313, 0.03234593736539994, 0.03136550515357937, 0.017543129356844083, 0.02745699416846037, 0.023148922748597603, 0.01429853604973427, 0.1038693128419774, 0.07039399125746318, 0.03471660979890397, 0.040720348712056875, 0.044731722213327885, 0.059798721224069595, 0.08585110040647642, 0.025586670065032582, 0.03358041987355266, 0.01873209573594587, 0.062138160690665245, 0.022658849135041237, 0.027854479982384613, 0.029939153298203434, 0.027750358783773015, 0.013545355393684335, 0.020577785625521625, 0.013260432602172452, 0.030351790799094096, 0.01929603636796985, 0.005967397001638476, 0.043964940322829146, 0.019276119668834975, 0.028934928255953958, 0.018337790554921542, 0.02932564907574228, 0.03733931727973478, 0.0169948781507888, 0.0037482656106086715, 0.02404006484097668, 0.03777162211814097, 0.036250153223850896, 0.053743559534528425, 0.021440181581835662, 0.029542586899229457, 0.02697985852137208, 0.038110377333526096, 0.02248622982629708, 0.03256765886076859, 0.04815754374223096, 0.031490620225667953, 0.009787622523227972, 0.0322867182216474, 0.0353959929863257, 0.024028928384983113, 0.05446341394313744, 0.051389002307717285, 0.06969367526471615, 0.06368188892624208, 0.030664381704160144, 0.025591226427682807, 0.03342546283134392, 0.017436953893463527, 0.01911002447429512, 0.030053415202668736, 0.07228436946336712, 0.011801787568921489, 0.018787772926901068, 0.01837346962253962, 0.02684711671567389, 0.018309381990028278, 0.026364094777298824, 0.05738931122635092, 0.04081186612269708, 0.016576970129140785, 0.009988329789069082, 0.027110088051163723, 0.10168901697865554, 0.006731656014121005, 0.020115187591207877, 0.09821844606527261, 0.04015478977401342, 0.01873305586299726, 0.040800100325473716, 0.03997433338580387, 0.03572795267349907, 0.018795822048559785, 0.027829945852447833, 0.014588294251422797, 0.0285954843275249, 0.011593294961910163, 0.09941168382231678, 0.10359294552888189, 0.046082899173987765, 0.02729735353828541, 0.05266999499872327, 0.05731813968824489, 0.08125028692718063, 0.061234942371291776, 0.01961277990735003, 0.04446050837369902, 0.025521340713437115, 0.05583878746256232, 0.040934640248971324, 0.03364298080227204, 0.029104741822396005, 0.059383315300302844, 0.03778748626687697, 0.01600643583307309, 0.010108569587048675, 0.027445679597024406, 0.016631717727120434, 0.07315171363630465, 0.03538696847057768, 0.036424730106123855, 0.036928454147917886, 0.029244173983378068, 0.009963057752299522, 0.02947969688102603, 0.020367047915767347, 0.015779520152136683, 0.012809718260541558, 0.022053117531218698, 0.029119011413838183, 0.02063839746239994, 0.10549863148480654, 0.041844487855476994, 0.01168596588208207, 0.018082561303994486, 0.030605206665183817, 0.023056664038449526, 0.015346121176012924, 0.04394410590508154, 0.02719697785297675, 0.03193314040877989, 0.01503728935495019, 0.017465267463454177, 0.018830878560298255, 0.020305323281458447, 0.029900425912014077, 0.035536772039319785, 0.030967656323420148, 0.03932382186342563, 0.04668355194319572, 0.007920899744411665, 0.03031156724318862, 0.11003296888832535, 0.017677126452326775, 0.12326983681746892, 0.02225820643694273, 0.02622041159442493, 0.021951201571417705, 0.022650565918801085, 0.03269178666440504, 0.06710902002773114, 0.0031309917020345373, 0.02751234735894416, 0.013847361152459468, 0.027076191834307144, 0.06205539298909051, 0.036590085697493384, 0.05415884332199182, 0.05580422628138747, 0.05148943227582744, 0.01623911057998027, 0.07061553972640208, 0.055514831095933914, 0.06008990774197238, 0.017847077422110096, 0.051904468398009024, 0.07301153508680207, 0.06952482182532549, 0.028848537177379643, 0.028889391770852462, 0.07850764159645353, 0.08863438319947038, 0.03322178018944604, 0.0648272085402693, 0.04459582861246807, 0.020055361158613647, 0.02264964480751327, 0.04107350244053772, 0.09417174463825566, 0.0714250048622489, 0.021550452004053762, 0.02261822185079966, 0.02786770971891071, 0.048307398201099465, 0.06369011277066809, 0.03468324623203703, 0.00956321572552302, 0.05203216529584356, 0.057470579365534444, 0.0334887294364827, 0.016550873672323566, 0.030641854341541017, 0.02712572319433093, 0.030262912889676433, 0.027481328130566647, 0.0553173400860812, 0.08244562135743243, 0.023015938366630247, 0.04503100026132805, 0.013853268647965575, 0.019750363060406277, 0.05304278213796871, 0.05376030917146376, 0.04854274807231767, 0.0702133991622499, 0.038895248967622004, 0.04301987335618053, 0.014973144046962261, 0.05055370534371052, 0.034533076254384856, 0.009497027178960187, 0.02024971055133002, 0.029281171105269874, 0.05347299708851746, 0.0380394873874528, 0.0379654931436692, 0.0568597791051226, 0.06028396197195564, 0.053319553179400306, 0.03260674926319292, 0.019530736541907703, 0.05438365554437041, 0.009927591575043542, 0.009538580663502216, 0.06385589923177447, 0.06495775189250708, 0.037201656095151386, 0.0008972303538549957, 0.03184040842045631, 0.02162362352412726, 0.022212071144687276, 0.04042369659457888, 0.009983984620443411, 0.04632144833781889, 0.08492971091930356, 0.0162530765270016, 0.04534089059701987, 0.03441850561648607, 0.01123252128516989, 0.0368076070610966, 0.14527068340352603, 0.15241533145308495, 0.14816185326448508, 0.0730260828776019, 0.1301365297819887, 0.1519194444907563, 0.1304844689688512, 0.10577552805521659, 0.10015328188559838, 0.15847473059381756, 0.08350047868277345, 0.10118082817643881, 0.15641198413712637, 0.10541458813739674, 0.08600877837410995, 0.1337661085916417, 0.13114658344004834, 0.11036139340805155, 0.09473095927387476, 0.09131847095808812, 0.06913460312145096, 0.11299187011484589, 0.1154131612607411, 0.21032038357641014, 0.19491717724927834, 0.1282302127884967, 0.16230569859700544, 0.1276812779584101, 0.1767819853765624, 0.21635922310607775, 0.13374731317162514, 0.09761582554451056, 0.14611136115023068, 0.15264589765242167, 0.08648248402667896, 0.18254227271037443, 0.13433130112077507, 0.08353758776294333, 0.12925679555961064, 0.15143380340720924, 0.14247809111007623, 0.08840777285929237, 0.12982729423258985, 0.12389350549450942, 0.1148813526545252, 0.2341208000268255, 0.12813920767179557, 0.08733272911714655, 0.12607897179467337, 0.11078841585133757, 0.09999811449753386, 0.16670825092920236, 0.08189674081014735, 0.1442128608801535, 0.09586230785186801, 0.15702461983476365, 0.08607193641364574, 0.13284087181091309, 0.11015064043125936, 0.11044903977641038, 0.13328087462910584, 0.10252164051468883, 0.12768040943358624, 0.0864627929404378, 0.20902474809970173, 0.09854412930352346, 0.09403459235493626, 0.14901808303381714, 0.12984038995844976, 0.17943384950714453, 0.04518348404339381, 0.19949252530932426, 0.1391523874231747, 0.15646765115005629, 0.16902296457971844, 0.13718711930726254, 0.09118591235684496, 0.20682963303157262, 0.1727645830916507, 0.13477916137448379, 0.2063850433166538, 0.14044840287949356, 0.07474497492824282, 0.15037953640733445, 0.08267952594906092, 0.12065013524677072, 0.2182241358927318, 0.06399320757814816, 0.15371825439589365, 0.1569072739886386, 0.11137682106345892, 0.14268877623336657, 0.16999789726521286, 0.17937499337962695, 0.12451232943151679, 0.10588965086000306, 0.1525157003530434, 0.12988615036010742, 0.1891033806438957, 0.17924797162413597, 0.10952526184597186, 0.08007923047989607, 0.18891157236482414, 0.15015709905752114, 0.15052483789622784, 0.0671007079737527, 0.1491202704076256, 0.1763874308339187, 0.09326032283050673, 0.12128314056566783, 0.19794280560953276, 0.10160065136317696, 0.08401387184858322, 0.14435517681496485, 0.18852577092392103, 0.12989487632044724, 0.06868468012128558, 0.05103353477482285, 0.10970168773617063, 0.13312768856329577, 0.15745319612324238, 0.15582222864031792, 0.10244797875306436, 0.11206471986536469, 0.14087988329785212, 0.11205059276627642, 0.09550772580717291, 0.19189473800361156, 0.12238288298249245, 0.15516521675246103, 0.14709725896162645, 0.21518200556082384, 0.16803045783724102, 0.16666060420019285, 0.11920611773218427, 0.10924055533749716, 0.09238232565777642, 0.16908552550843783, 0.08582672064325639, 0.09447045610951525, 0.09461067537111895, 0.10785314121416636, 0.09095443013523306, 0.08716283751917736, 0.13367637912077562, 0.10526613824601684, 0.06452815780150038, 0.12329643539019994, 0.13195344300142356, 0.1541065935577665, 0.11366007783051048, 0.11577477971357958, 0.13138660841754504, 0.1269244264279093, 0.11711754623268332, 0.09979540894606284, 0.1450968834438494, 0.12532886490225792, 0.15002289840153285, 0.14641306496092252, 0.1404367863599743, 0.13083768715815886, 0.1351430732756853, 0.08394773504031555, 0.15010371192225389, 0.1050617770691003, 0.29453231979693684, 0.12149656697043351, 0.12529033768389905, 0.1283284510884966, 0.21310354423310074, 0.07675854795213256, 0.1255097080554281, 0.21567455413086073, 0.10324331678982292, 0.10705354876284089], [0.02821853946495269, 0.05183523068470614, 0.04767808750537889, 0.07524615446371691, 0.016957945489723767, 0.05374287760683468, 0.05562484197850738, 0.04074104742280074, 0.054755492734589746, 0.0114374074785571, 0.027816575319905366, 0.029623997530766895, 0.04058421762394054, 0.028435334796085954, 0.008066709286400249, 0.035241850186139345, 0.030314512085169554, 0.03923298977315426, 0.016107815750209347, 0.01076340931467712, 0.027450339436264973, 0.08490777388215065, 0.03439704355384622, 0.04381612741521426, 0.023231593758932183, 0.08337868164692606, 0.036355305795690844, 0.0184098543665771, 0.01190102331539882, 0.04986966062071068, 0.020063064227412854, 0.05759329242365701, 0.026790401366140162, 0.06992184623543705, 0.0313548962585628, 0.012719333155213721, 0.009883230651861854, 0.024358516592266302, 0.02814223650576813, 0.04909067188522645, 0.045969475260270495, 0.046836140898189375, 0.04074306606448122, 0.021383517122428333, 0.060679826087185314, 0.012097158103383012, 0.005273736165171223, 0.028117361411984478, 0.027167731297335455, 0.022980632493272424, 0.00152181219060107, 0.08201979992112943, 0.017281511698716452, 0.02284591954334506, 0.04120461915486625, 0.018667461882744516, 0.018750823302460567, 0.08952131667839629, 0.013083748020497816, 0.018182826727362614, 0.020439725801614777, 0.06835898331233434, 0.03809135799695339, 0.02674540431637849, 0.025325093119006072, 0.040506779814937284, 0.008172343618103435, 0.04408243205398321, 0.022919881556715285, 0.02544047969526478, 0.05619219224900007, 0.012879616697318852, 0.02283334798578705, 0.04610184047903333, 0.026962998622496213, 0.01749628160281905, 0.005596886771464986, 0.013080675953200884, 0.022606654525069252, 0.05368909013590642, 0.03840201507721629, 0.08815647741513592, 0.06978440218205963, 0.0365731596414532, 0.021646556311420033, 0.02694908865461392, 0.048560698716236014, 0.024732038245669434, 0.04884951375424862, 0.008496587513945997, 0.007287927504096712, 0.019317282995741283, 0.025437078538483808, 0.012694822774002594, 0.045773005445620844, 0.0319438273353236, 0.010702409016500627, 0.09509419264005763, 0.08045747304069144, 0.06637606650058712, 0.042835165946079154, 0.05411766981706023, 0.030699533210801225, 0.014182627001511199, 0.04149288457951375, 0.025879295077174902, 0.027305733445765715, 0.06849302111991815, 0.041883452728922875, 0.024747770080076795, 0.031061507894524505, 0.03257874273029821, 0.020823364412145953, 0.011228984421385186, 0.005464028766644853, 0.024369038974067996, 0.04011069517582655, 0.016636701566832404, 0.04392491014940398, 0.05249332822859287, 0.02133660830025162, 0.05181279153163944, 0.013156891551001795, 0.007710223950977836, 0.013012020931845265, 0.01082382776907512, 0.04728507323722754, 0.024716438725590706, 0.03933651725362454, 0.04606506388102259, 0.028290533726768832, 0.024859838620094315, 0.06817358718918902, 0.03160984900646976, 0.023842322773167064, 0.020952647385586585, 0.058877786355359216, 0.08708357784364905, 0.0374172707753522, 0.032383090550346036, 0.012542988689217185, 0.0483000496668475, 0.04730084578373602, 0.03366562690851944, 0.0648617527580687, 0.04527585980083261, 0.03668230539187789, 0.03835666858192001, 0.021125241249267544, 0.020670164775635515, 0.08587633512381997, 0.036019074730575085, 0.020883216289803386, 0.01324934364363019, 0.025190130807459354, 0.07312425332409994, 0.018621728622487614, 0.012461611136261905, 0.03196386447442429, 0.02628531855797129, 0.018805435193436484, 0.051655249271009646, 0.05579409236088395, 0.029295277848307575, 0.059076603901173384, 0.036828217562288046, 0.019094842253252864, 0.0418064797164074, 0.061325859278440475, 0.06586067165647234, 0.021671997981944253, 0.021151697329644645, 0.019742643028231602, 0.040345872020615, 0.02429228987810867, 0.08297771494835615, 0.028551959698753696, 0.03272923840475934, 0.02758375977698181, 0.13316084178430693, 0.047629419581166337, 0.07055108568498067, 0.04509359511679836, 0.055687725211360624, 0.038285927913550816, 0.02697002824528941, 0.02004397873367582, 0.015244870180530208, 0.049777865010712824, 0.0410068465529808, 0.013460930370326554, 0.006972086416291339, 0.04771725933200546, 0.03345704524378691, 0.033438979248915396, 0.048778769693204334, 0.044852029864809344, 0.04167592618614435, 0.020432187277557592, 0.039410891477018595, 0.02448879192317171, 0.06451749801635742, 0.06367494072765112, 0.028277268367154256, 0.016855298408440182, 0.11915594685290541, 0.035134536480265, 0.02519049552003188, 0.0464399748348764, 0.01857508612530572, 0.014992182043247988, 0.05747123754450253, 0.031137938079025065, 0.022145861393905113, 0.043508547491260936, 0.00945009121538273, 0.00839878517269556, 0.02342718487073268, 0.09409352990665606, 0.06892555326755558, 0.03268640588170715, 0.05319467220189316, 0.010540409628967089, 0.03752111716728125, 0.031334207725844214, 0.05569288207750235, 0.007861974915223462, 0.012464250637484449, 0.0407264589198998, 0.016498487376208817, 0.03997126640751958, 0.07221927081367799, 0.078383001498878, 0.06377352508051054, 0.02914526393370969, 0.012379039361673807, 0.02970803070015141, 0.036421622415738444, 0.028024442826530764, 0.013891238619440367, 0.1034668805077672, 0.027149846810581427, 0.016480292459683757, 0.01671591035223433, 0.022631775587797165, 0.06961315351405314, 0.01599274978174695, 0.04284853647862162, 0.06552732097251074, 0.016295702096873095, 0.0172516917809844, 0.028841205606503145, 0.02928230765142611, 0.01632865854272885, 0.04563809232786298, 0.05723382492682763, 0.042394918855279684, 0.04946328939071723, 0.08447110945624964, 0.04653162455984524, 0.0026810896940462825, 0.011930825421586633, 0.03912491610805903, 0.007837223654080714, 0.051213451727692566, 0.0135583383130974, 0.018910915158422928, 0.04705768258177808, 0.015343527475904142, 0.022741794952058365, 0.029684363398700953, 0.06430310130651508, 0.05345214570739439, 0.09567906268473182, 0.0667005419465048, 0.02561912778764963, 0.04250623591776405, 0.06802056397178344, 0.0630959060841373, 0.02205041017649429, 0.032780396552490335, 0.05060704837420157, 0.008150850173218973, 0.052593395180468044, 0.04747347527050546, 0.0189292050698506, 0.0659059774396675, 0.027480563082333122, 0.08929062155740601, 0.01746072297516678, 0.021551072863595824, 0.03631567256525159, 0.03201774354758007, 0.005768951801915786, 0.015304357345615114, 0.013820615846530666, 0.05176138571862664, 0.08272233472338744, 0.06224177298801286, 0.049875801362629445, 0.04495089580970151, 0.023709004212703024, 0.023841196405036107, 0.03455384960398078, 0.026476007254262055, 0.0155277683931802, 0.031463404186069965, 0.03758797661534377, 0.0489395349951727, 0.01976594392077199, 0.03998531547508069, 0.03655870684555598, 0.021757077791595032, 0.07710883487015963, 0.022543226767863547, 0.012859639778201069, 0.02593314870526748, 0.04917096632665821, 0.0036596451204137076, 0.017074719670095613, 0.028944583809269325, 0.03174362557807139, 0.05459884614018457, 0.03504887482683573, 0.03184160264208913, 0.06649657431989908, 0.016776556115863577, 0.01658800819755665, 0.020080921572766135, 0.04809917276725173, 0.03565151570364833, 0.03761410699891193, 0.019224062462204268, 0.06173572835645505, 0.0073083938165966955, 0.0769716418747391, 0.029350551310926676, 0.09257395751774311, 0.02703706920146942, 0.013173562308241214, 0.040891916291522126, 0.009652580483816564, 0.05281658231147698, 0.014119892198193287, 0.020635464494781833, 0.06376445306731121, 0.04920003137418202, 0.05598720681986638, 0.06651782603668314, 0.04847459601504462, 0.030117058394742862, 0.05837849314723696, 0.11471002256231648, 0.10275608793433223, 0.1460556805666004, 0.26886920258402824, 0.194609705890928, 0.20448046337280953, 0.23702091297933034, 0.09657280865524497, 0.13006244732865266, 0.11873510586363928, 0.18311507840241703, 0.1538700833916664, 0.13277577316122396, 0.14642164164355823, 0.0944430229387113, 0.1155665780284575, 0.11683683629546847, 0.11628844429339681, 0.14217961712607316, 0.11027481233967201, 0.1744151466659137, 0.12457312616918768, 0.11736031249165535, 0.14023937338164874, 0.1518667766026088, 0.31717503336923464, 0.12483882691179003, 0.17275899196309702, 0.08027171729398624, 0.2483791820704937, 0.08798422451530184, 0.19550203372325214, 0.13105164282023907, 0.11262762573148523, 0.10902568365314178, 0.20941348081188543, 0.12489708592849118, 0.05544035169961197, 0.08881707875324146, 0.09373045938887767, 0.15127022218491348, 0.1314157447112458, 0.14906152284571103, 0.11837877998394625, 0.18942242780966417, 0.1230019104800054, 0.12786034334983143, 0.11665293973471437, 0.11049397236534528, 0.20431937915938242, 0.10403199839804854, 0.11844343080052308, 0.08056004039411034, 0.11367597590599741, 0.1379115232931716, 0.15569884383252688, 0.10195526054927281, 0.11558207576828343, 0.2008708334927048, 0.13358253772769654, 0.06176540069282055, 0.11595662709857736, 0.12622420543006488, 0.12749355446015084, 0.29332802870443886, 0.08033985578055892, 0.09306703534509454, 0.17692974316222326, 0.09551305909241949, 0.2860868658338274, 0.13706684218985693, 0.09917909558862448, 0.15378471011562006, 0.13438494609934942, 0.0878482460975647, 0.1421822634126459, 0.07754427793302707, 0.13166511990129948, 0.16128695969070705, 0.12774107046425343, 0.1339389043194907, 0.17880853877535888, 0.1753788020993982, 0.1351230429219348, 0.16740054663802895, 0.12720669699566706, 0.23663406659449848, 0.10198857661868845, 0.1791145580687693, 0.1002147775143385, 0.07326152774372272, 0.09889324914131846, 0.07417603688580648, 0.10701822422977005, 0.11168650444597006, 0.1534239873290062, 0.11482272722891398, 0.19094333691256388, 0.21552850625344686, 0.184015548654965, 0.11028960440307856, 0.15977143815585546, 0.18975660630634852, 0.09130831328885895, 0.12207322674138205, 0.1436758411249944, 0.14228492576096738, 0.13873443699308804, 0.1405507938138076, 0.058184445702603886, 0.1566116362810135, 0.08588127485875573, 0.10218991831477199, 0.1228532570281199, 0.12120859670851912, 0.09170396705823285, 0.1317152093563761, 0.12431252800992557, 0.08442058573876109, 0.11987209985298769, 0.18809365268264497, 0.14664411970547267, 0.22407417983881064, 0.12069666917834963, 0.12873848980026587, 0.09963139346135513, 0.20332171555076325, 0.14615260250866413, 0.10864338345293488, 0.1477496160992554, 0.12296509316989354, 0.09942114938582693, 0.15761239400931767, 0.08939339925668069, 0.12047112413815089, 0.13404239448053495, 0.08357958908059768, 0.2184266514543976, 0.11064987935658012, 0.08864107355475426, 0.06963833394859519, 0.1395563736025776, 0.12457062916031905, 0.12341330626181193, 0.14147893472441606, 0.1470774593097823, 0.17734986490436963, 0.17091028259268828, 0.17996473530573504, 0.12476901922907148, 0.11450248584151268, 0.16125327721238136, 0.0803480524835842, 0.09836346256945815, 0.11864715415452208, 0.15085111824529512, 0.07686492188700608, 0.15716659650206566, 0.12913681699761323, 0.15352958094860825, 0.1053620423855526, 0.17979402946574347, 0.11849702149629593, 0.08723024997328009, 0.15334746214960301, 0.08458842816097395, 0.14323767035135201, 0.13748294700469288, 0.10538436618766614, 0.13065966671066626, 0.11400872947914259, 0.09988234285265207, 0.15238915357206548, 0.12221772755895342, 0.13951230953846658, 0.18886259570717812], [0.019493264445502843, 0.026355814953733767, 0.01867007593890386, 0.03640984983316489, 0.036546849446105104, 0.029047744880829538, 0.03748932440898248, 0.029104670576219047, 0.058506213793797154, 0.015300104627385736, 0.03485037279980523, 0.00532047704993082, 0.04135699097865394, 0.006828530034649053, 0.05110892680074487, 0.02334040872353528, 0.0964688638757382, 0.023001108983797685, 0.030386667499052625, 0.016896860374669944, 0.023662504207875048, 0.01404919139375644, 0.03285017030845795, 0.08092448155262641, 0.09653018308537346, 0.034127163035529, 0.03207215527072549, 0.034499797504395247, 0.04238860847960625, 0.0314356249624065, 0.031859610961484056, 0.030122035449104648, 0.05881919485649892, 0.044839236087032726, 0.026230745682758943, 0.052121779415756464, 0.014507463767326303, 0.04586990703163402, 0.02497083507478237, 0.0198263080923685, 0.0051145607555684236, 0.009788581802110587, 0.022642966326592222, 0.028278404913310493, 0.012820214349111276, 0.01078323441158448, 0.019458207933764373, 0.013803828890169305, 0.01586228615737387, 0.04714623818706189, 0.03616729731272374, 0.06695845989244324, 0.029445546213537455, 0.028245877640854036, 0.014181563397869468, 0.07866857653217656, 0.018785021467400447, 0.008114265261350997, 0.05449048409770642, 0.024058241097788726, 0.035157800053379366, 0.06360501090862922, 0.01127644200875823, 0.04467431475807514, 0.0350181677245668, 0.024360377474554946, 0.04193403072921293, 0.06494837453854935, 0.08851834014058113, 0.01772248142931078, 0.01898314181848296, 0.029440986458212137, 0.03439717247549977, 0.010766710387542844, 0.04609627649188042, 0.013384406887260931, 0.01932350855453738, 0.03340578870847821, 0.008774038786733789, 0.032716919601495774, 0.029583678979958807, 0.05006947900567736, 0.06860626182918038, 0.03790099839014666, 0.07112058691148247, 0.06979057006537914, 0.021383666400132433, 0.0053935959835403734, 0.030339773943913833, 0.021246951771900058, 0.046511465284441195, 0.006353031353293253, 0.019328899515260543, 0.0050768825541516495, 0.020561122501801168, 0.1277165210672787, 0.04773901655737843, 0.07372228016278573, 0.009751208093283432, 0.007079456525389105, 0.04537214391997882, 0.034626893898738284, 0.03465986391529441, 0.03237114833401782, 0.05420317201476012, 0.025645273438255702, 0.006920683147784854, 0.08284527169806616, 0.03839981323108077, 0.06735817808657885, 0.029357258629586016, 0.015677098683746796, 0.029646304369504963, 0.018793786443503838, 0.07100672195000307, 0.030215846308107887, 0.030463996742452894, 0.036674006908599815, 0.03536727059898632, 0.03716236213222146, 0.009035242538500046, 0.03983625150950892, 0.06751976441591978, 0.03167598242206233, 0.023811803964365805, 0.02276070911570319, 0.02114059988941465, 0.09890846189643655, 0.031109734770974944, 0.020595727787752236, 0.023583953601441214, 0.014564728730225136, 0.03564509336969682, 0.037523162950362475, 0.12156686319836549, 0.0037145822841141906, 0.056098751191581996, 0.05419940614540662, 0.032766048929521015, 0.007414483614931149, 0.041972971853933165, 0.01942035076873643, 0.02868486096018127, 0.06564689919884716, 0.034278595088315864, 0.05376820392640574, 0.1130046130024961, 0.029068826963858943, 0.03029709748391594, 0.05662010357316051, 0.03667583895315017, 0.043259263903434785, 0.03337097307667136, 0.06049518992326089, 0.015287205676681228, 0.0511423514357635, 0.024690016571964537, 0.059453021202768595, 0.03878808453945177, 0.04158500588632055, 0.037719256178076775, 0.06676340821598258, 0.005481257618937109, 0.013357434272100883, 0.02313851741408663, 0.027664710701044117, 0.0068462228352603105, 0.04800925330658044, 0.010123431200294622, 0.027185693815616623, 0.02063427196948656, 0.011336732389671462, 0.023533738617386137, 0.05703249680144446, 0.026863123356763805, 0.0427993969725711, 0.04615285274173532, 0.014255238730194313, 0.009683251114828246, 0.015856138630104915, 0.0036959993303753436, 0.07216611438031707, 0.08203007294131176, 0.017153796141168902, 0.043510861295674524, 0.06692437707845654, 0.030511378842805113, 0.03309087721364839, 0.06903797973479543, 0.01564350611131106, 0.0731954180768558, 0.04302392081756677, 0.04713338673380869, 0.019471856665664485, 0.01613628538325429, 0.014271923906302877, 0.07860041768955332, 0.005707575764972717, 0.017483026421229755, 0.054539138451218605, 0.04589797802535551, 0.017457908751176934, 0.05020684502752764, 0.03210085051666413, 0.031813473972891054, 0.026999488539461578, 0.032178274754967005, 0.09679382108151913, 0.026219765289819667, 0.009465993531713528, 0.039652351556079726, 0.0216259135798152, 0.04276913770341447, 0.10958223843148776, 0.062490727486354966, 0.021207703610083888, 0.02310769326452698, 0.03574666666931339, 0.03838620860395687, 0.04216670038710747, 0.07948844360985927, 0.009469247107127947, 0.01882855797053448, 0.027174779579841664, 0.04255389282479882, 0.051093758150402985, 0.04119822396231549, 0.03758160856419376, 0.016704855320443, 0.01019433471706829, 0.08272688769336257, 0.04575187925781522, 0.033196810100759776, 0.05914566519537142, 0.04998531012928911, 0.02924065917198147, 0.014787893808845962, 0.029984974768012762, 0.03312049865988748, 0.04831087230039494, 0.018293997904817973, 0.013935166128378893, 0.03761890084881868, 0.024904265700440322, 0.017615040498120443, 0.03485161451888936, 0.00269554800304052, 0.09998387883284263, 0.03323563926720193, 0.025852345362571732, 0.015177579862730843, 0.0762260743815984, 0.034976461569645574, 0.016579801316506097, 0.032036226841488054, 0.0681563795411161, 0.12627783683793886, 0.030636232678911517, 0.04434923880866595, 0.01007827469480357, 0.034727279762072225, 0.05804630275815725, 0.06926699887428965, 0.04428397731057235, 0.016390047302203517, 0.04211869064186301, 0.03923113737255335, 0.014356508385390043, 0.01973256847954222, 0.013402446588900472, 0.02712770112391029, 0.09249967150390148, 0.06673780030437879, 0.024993786521788155, 0.032342880565140925, 0.02544900888044919, 0.018587508405159627, 0.027270159551075528, 0.03215215794209923, 0.020005144478221024, 0.021540960995480418, 0.048220274304705005, 0.016249027369277816, 0.026497774657660296, 0.03411217758964215, 0.05849643610417843, 0.010439218005298503, 0.03783075644501618, 0.04339529660397342, 0.03321664707202997, 0.021304450829380324, 0.009825589102027672, 0.038984245620667934, 0.025467451462256055, 0.02871113722877843, 0.026358846308929578, 0.042596141807734966, 0.01480950684552746, 0.029517911973276308, 0.011678973578714898, 0.04415630416146346, 0.018966638150491884, 0.041943577716925314, 0.012160942939642285, 0.0512211157807282, 0.02676608776008444, 0.022171029954084327, 0.01028354765315141, 0.022663271487025276, 0.01493250488835786, 0.06225817996476378, 0.013265587771976632, 0.02045808356654431, 0.02018500375561416, 0.03546155643250261, 0.04531875339203647, 0.03685962694830128, 0.036084624606051614, 0.04855993875701513, 0.04885933554864355, 0.028218943193288784, 0.026997223928836838, 0.06462034356913396, 0.06702792830765247, 0.028718675752835612, 0.04582549352198839, 0.01139734422654978, 0.027909300522878766, 0.0604229937972767, 0.030398860773337737, 0.06702235753514937, 0.04835216794162989, 0.014237009886918324, 0.13298482980046952, 0.036278906145266125, 0.04137473806206669, 0.02681102374169443, 0.02599350778785135, 0.01188901748641261, 0.036358542407729795, 0.015245292568579316, 0.07206471410713025, 0.019807293844808425, 0.026675995272983397, 0.03717118648013898, 0.029133416712284088, 0.06141567695885897, 0.00834634544194809, 0.07758686957614762, 0.0413878371806017, 0.03176332005698766, 0.018779048662898794, 0.16744653774159296, 0.058972197717853954, 0.10528025177440473, 0.08742536950324263, 0.12398980318435601, 0.12553811153130873, 0.09994587408644812, 0.098338933528534, 0.0913119095244578, 0.09548460133373737, 0.16766470032078878, 0.0999324255223785, 0.13342160279197351, 0.12260217192981925, 0.18439349266035215, 0.109214933855193, 0.18500276282429695, 0.11435958636658532, 0.08486611183200564, 0.08919851042862449, 0.18977028557232448, 0.15631279588810035, 0.13981680891343526, 0.16781553865543433, 0.15484319760331086, 0.1430800873786211, 0.22725289926997252, 0.1437429075262376, 0.1166501170290368, 0.12983672586934908, 0.14783258736133575, 0.19062494114041328, 0.1044250058808497, 0.09727843079183783, 0.12039306546960558, 0.12984036281704903, 0.14884612868939126, 0.15783895685204438, 0.10852866353733198, 0.12485112196632794, 0.06936312014503138, 0.11353227575974804, 0.08122716245374509, 0.15389471421284334, 0.10267957632562943, 0.088434066091265, 0.1295602907027517, 0.112693911817457, 0.12108863171722208, 0.19863732691322053, 0.16611157437520369, 0.2469118908047676, 0.07865467334964446, 0.11054947652987071, 0.1107375935784408, 0.21875738299318723, 0.0828104153541582, 0.07607529711510454, 0.12427233159542084, 0.09770987728344542, 0.09895264809685093, 0.21105349995195866, 0.170205773253526, 0.13907712431890623, 0.07027621114892618, 0.10904007538088731, 0.08527550593550716, 0.21074240521660872, 0.13800981587597302, 0.15490303082125528, 0.11711770908108779, 0.15108395075159414, 0.13122352931116307, 0.10985417491091148, 0.1810134926012584, 0.09653032557772738, 0.1561487532619919, 0.10845906620046922, 0.08982072704072509, 0.15015367924102715, 0.13645058311522007, 0.2488000909132617, 0.14649021439254284, 0.10290974218930517, 0.09312738424965314, 0.12129852973989078, 0.1992621355290924, 0.09318487652178321, 0.08615532158208744, 0.1538000042949404, 0.1111849517162357, 0.08684697946799652, 0.11288030538707972, 0.0730693598410913, 0.08121607519154038, 0.24279445888740675, 0.20112748257815838, 0.1775387012000595, 0.10548497936023132, 0.08869294755692993, 0.12603880252156938, 0.1945671753159591, 0.1810693224625928, 0.15474103737090314, 0.12942667358687945, 0.11993232662124292, 0.08022855568145003, 0.16057562428925717, 0.12267381165708814, 0.1752080148352044, 0.09549273018326078, 0.10324275360575744, 0.17445178755692073, 0.13714074822408812, 0.17885028224970612, 0.09448254760354757, 0.10045852086373738, 0.06875938682683877, 0.09999679813959769, 0.10145095296736274, 0.1424131960208927, 0.08362709331725325, 0.10180954515401806, 0.10314734479678528, 0.07505996445459978, 0.11384991157267775, 0.08542200843138353, 0.15833154613418238, 0.14848783505814417, 0.13066281511315278, 0.10686523493911539, 0.11212052258529834, 0.0854885930727635, 0.07136794006718056, 0.2087408219064985, 0.10697816352226905, 0.11327718730483737, 0.11764047960085527, 0.1088996593441282, 0.15825705655983516, 0.14301433733531407, 0.10115272325596639, 0.15664164109953813, 0.15463305530803545, 0.09155989371772323, 0.13225501110511168, 0.18458542307572706, 0.11549139634839126, 0.12498491550130503, 0.13502020415450844, 0.08275307235973221, 0.09899637289345264, 0.17573375733835356, 0.2261911141020911, 0.18218505116445677, 0.20423381589353085, 0.1446012814662286, 0.20814205546464237, 0.1278879325836897, 0.06063446602118867, 0.1398842010114874, 0.11061090430510895, 0.10148447259728398, 0.11482502067727701, 0.10965030227920838, 0.1528468390128442, 0.09441600367426872, 0.11623125736202512, 0.1423945634492806, 0.10997979209891387, 0.09901555507842984, 0.12944749104125158, 0.14449578284152917, 0.20589634882552282, 0.07394314331135579, 0.1045320447800415], [0.06835694770727839, 0.03186826228297182, 0.03217257506081036, 0.07348931873483316, 0.08995519911072083, 0.02937455109453627, 0.008417374487700207, 0.022843151120468974, 0.05291023710742593, 0.044878855746771605, 0.0152280560827681, 0.03803014396024602, 0.04208638558962515, 0.08563527877309493, 0.050825791100838354, 0.008898640716714519, 0.02290547625826938, 0.028206576892573918, 0.028178599197417498, 0.033383848278650215, 0.06434040037649018, 0.043154074012168815, 0.04047188615160329, 0.00953523039684764, 0.03181593705500875, 0.045869869712207995, 0.013084463026773716, 0.07744703029415437, 0.03171504568308592, 0.007256487584007638, 0.012307642210674073, 0.024193522320794206, 0.005193367508971798, 0.017574878010366644, 0.022240754516263093, 0.033627930895558426, 0.07487834098615817, 0.043466227262147834, 0.02288913883135787, 0.024241723752181445, 0.013318389670790305, 0.0346191552068506, 0.016342783945479562, 0.026338062781308378, 0.023183019133284688, 0.0223260718131704, 0.053439131405736716, 0.03325902497661965, 0.05378871943269457, 0.012607711600139737, 0.05368953457634364, 0.04818361645032253, 0.00530656665796414, 0.08026071145598378, 0.023092343106067607, 0.020713109256965772, 0.07045189743595463, 0.05791664828679391, 0.042583700868168047, 0.044801221162612946, 0.022611680773219893, 0.01833345471615238, 0.02865346514486841, 0.015369333859000887, 0.08412496160183634, 0.03521901748276182, 0.03302945961643543, 0.005607396854819464, 0.03092325638447489, 0.058260584117046425, 0.06757201161235571, 0.04581050129075136, 0.010824161947571805, 0.022050172689237764, 0.007490233568075512, 0.06239259775195803, 0.05369819946853178, 0.025563961194295968, 0.03547750200544085, 0.029592272625969987, 0.0538549715919154, 0.0429289700197322, 0.015766015608928034, 0.012362859694154134, 0.03339443003226604, 0.04640736444188016, 0.026601241069978902, 0.09509322912033115, 0.08278298896870442, 0.010390145504581077, 0.049096595495939255, 0.10720830224454403, 0.03980258260188358, 0.049843984855605025, 0.007650298282637128, 0.02100026697319533, 0.016448796560455645, 0.026256955794191787, 0.009028409690862256, 0.023310013747374927, 0.02149894441078816, 0.02284137505505766, 0.04614084945725543, 0.01608054882048496, 0.016076501359098723, 0.028613658887999396, 0.027803800201841762, 0.048836859076150825, 0.016387614754161665, 0.011580557163272585, 0.03021535776289446, 0.06755727383175067, 0.025574078151424016, 0.03001455550215074, 0.016392003179394772, 0.043564876075834036, 0.032176836260727475, 0.04069401816065822, 0.024666530778631568, 0.047973691286253076, 0.052604957417185814, 0.02028068737126887, 0.04579731056998883, 0.006533187913841435, 0.03682140167802572, 0.023448307665863206, 0.04803464747965336, 0.013679172677387084, 0.04918301371591432, 0.029211509307580333, 0.023929977623213614, 0.08416557870805264, 0.028463471946971755, 0.15529402984040125, 0.030271632064666067, 0.01475796362917338, 0.013721346173302403, 0.03687587786199791, 0.005502807467044997, 0.021981896799323813, 0.014447632245719433, 0.0323272301549358, 0.04410641826689243, 0.06646228794540678, 0.0439609980343708, 0.029129247114594494, 0.0222655261334564, 0.03447245254314371, 0.07470839510538749, 0.012834606925025582, 0.037440734516297064, 0.018969182656811814, 0.031156855635344982, 0.12019930300968033, 0.027547336017180766, 0.035474625016961775, 0.020859564255390848, 0.0498038834360029, 0.019340414254527007, 0.02663803463136511, 0.07047521868454558, 0.02972450553040419, 0.0026805341434997638, 0.07487807635750089, 0.04007429516475115, 0.022254197991320064, 0.03451921378395387, 0.059824308779622824, 0.012364984356931277, 0.021742869268304536, 0.02197770684558366, 0.021620522619092038, 0.021311212430841157, 0.031903128804905076, 0.08200099771576268, 0.01551425367194627, 0.03607522011069315, 0.03419085372505443, 0.04863033337252481, 0.03259165525170309, 0.024408300706584538, 0.06205802570496287, 0.019427015678957105, 0.02786564527611647, 0.06352349849683897, 0.04087612678163818, 0.030783892076994692, 0.012116235115432313, 0.05400790320709348, 0.02493650120283876, 0.07848569777395044, 0.029791022318282297, 0.039344839485628266, 0.05489993587668453, 0.027646081522107124, 0.06297611751194511, 0.05087493060688887, 0.03101918427273631, 0.03286649246833154, 0.05741476307490042, 0.06184041952448232, 0.028778522541480403, 0.03733143948816827, 0.020777921225609522, 0.0428139040512698, 0.028232663171365857, 0.04302535591913121, 0.10305872133799962, 0.09018573816865683, 0.02957277831488422, 0.025912343125258173, 0.028294116391667297, 0.07312193951968636, 0.03140902638967548, 0.017420015963060514, 0.027943700551986694, 0.022718728154099414, 0.048873377830854485, 0.009699732730431216, 0.03797281114384532, 0.015222872075225626, 0.021685080137103796, 0.04516264284029603, 0.04739097898293819, 0.026547054959727184, 0.07184136073504176, 0.021574925065838864, 0.029308831585305076, 0.050889885518699884, 0.028938965539314916, 0.021970621243651425, 0.015086020043651973, 0.03982198191806674, 0.017930713648508703, 0.0385369553363749, 0.029642762416707616, 0.0170090103388897, 0.03862615215725132, 0.05622925043904355, 0.044750259790037356, 0.03808257096846189, 0.031726692736681016, 0.00599005922309256, 0.007185885167148496, 0.013112390679972512, 0.04492671960698707, 0.09542738047561475, 0.032191424763628414, 0.009120117939476455, 0.0590278986575348, 0.015459368670625346, 0.042470514441707304, 0.04544373614979642, 0.010875021539894598, 0.026003592514566014, 0.06551461879696165, 0.0778297647567732, 0.028184122472469295, 0.055802499409765005, 0.028971056853021895, 0.03839488706684538, 0.04654713926304664, 0.014020410482771695, 0.10835542676172086, 0.02239144696587963, 0.031700056844523976, 0.044515781836318116, 0.07098249824983732, 0.05334341725600617, 0.008059185181212212, 0.02204343822917768, 0.014741463353857398, 0.024444359753813063, 0.03931793896481395, 0.025535808776372244, 0.054063349696142335, 0.0016772876759724958, 0.03127077827230096, 0.04849370356116976, 0.02382349342639957, 0.008289892176565315, 0.021879974054172635, 0.03540223550849727, 0.03647212238450136, 0.05170232942327857, 0.06933915428817272, 0.03001078624012215, 0.053070330659725835, 0.076995288820139, 0.05792127589562109, 0.09856333184455122, 0.02661914421644594, 0.04363177623599768, 0.02568894564839346, 0.0452381637878716, 0.010122823911452932, 0.016607327785875117, 0.025894465423854332, 0.07207211013883352, 0.028644342241542678, 0.032319742521005015, 0.024996634672528932, 0.02006197178603283, 0.013686971589257675, 0.02389798978609698, 0.046493002346583774, 0.018714413113359894, 0.06714863968747002, 0.015857248034860407, 0.036228877758341174, 0.030220898001321723, 0.040801012955073795, 0.0429382082740111, 0.027459665900096297, 0.0406751548871398, 0.029757743568292687, 0.06233553974223988, 0.01749586091110749, 0.049507149894322665, 0.01261561653310699, 0.020744064024516513, 0.0199676554184407, 0.015579033410176635, 0.032885142003319094, 0.03330792021006346, 0.03808120032772422, 0.026163484202697873, 0.07168163359165192, 0.04953024722635746, 0.041210600441055636, 0.013567075299631273, 0.07351339315729481, 0.03570816659235528, 0.006252549222803542, 0.010427656616749508, 0.04088850665305342, 0.08499687910079956, 0.0004885254935028829, 0.06622157086219106, 0.0650975504623992, 0.025628230334924798, 0.041539309945489676, 0.05592292919754982, 0.04281542057703648, 0.06970034526394946, 0.024496323661878705, 0.03931508233238544, 0.06352482164012534, 0.017442911430927258, 0.03954009472259453, 0.011362646490202417, 0.019888146381293024, 0.13070413789578847, 0.10894151138407843, 0.1363683311002595, 0.33101760915347506, 0.15749175048300199, 0.17265544751925127, 0.1069395752357585, 0.10009030026516744, 0.196787206189973, 0.12524450942873955, 0.12025970619704042, 0.05749310672815357, 0.13273753092757293, 0.14573539846709796, 0.14545088873377868, 0.150857007929257, 0.0881863600973572, 0.17832574753889016, 0.20582536049187183, 0.1487263265464987, 0.13834346511534282, 0.1569159049540758, 0.07520089617797307, 0.12141244219882147, 0.1695223527827433, 0.1102392774607454, 0.10360503023756401, 0.13747890293598175, 0.10382063473973956, 0.07860883830913476, 0.11951915307768754, 0.22196628366197857, 0.1926597590957369, 0.08704811081822429, 0.14158237060265882, 0.14077097842735903, 0.15099332561450346, 0.09536591877362557, 0.11031004866319043, 0.1356110588780471, 0.06466786137648992, 0.13022406079939433, 0.059806782220091136, 0.12094075179525784, 0.14652468397149018, 0.13910488997186932, 0.11357082333415747, 0.11327387605394636, 0.08906826563179493, 0.14380389425371373, 0.15516870442245687, 0.1828752841268267, 0.11875580118170806, 0.14054935531956808, 0.07159767845379454, 0.16807913593947887, 0.2039458727730172, 0.11560038264308657, 0.1475147751293012, 0.14452232713145868, 0.15272212427641663, 0.08310900468911443, 0.14779803635818617, 0.11851843606148448, 0.15298794715532235, 0.17082640209368297, 0.08474453192736421, 0.13140225543507508, 0.13700707682541438, 0.1360714313174997, 0.16667060580636772, 0.1095554091568504, 0.12179687299898692, 0.10170555287706, 0.09584372956305742, 0.1486842166632414, 0.1663740181497165, 0.08259342664054461, 0.14083267083125456, 0.1104017865977117, 0.1193425575537341, 0.1512683629989624, 0.18475083634257317, 0.12389376333781651, 0.09242649828749043, 0.061368532345763276, 0.05708033352025917, 0.2226979886846883, 0.12467880121299199, 0.10779718921652862, 0.13322307701621736, 0.20445414978478635, 0.12834751792252064, 0.08366882322090012, 0.1073225811123848, 0.13864417826490744, 0.1483923787517207, 0.13165191560983658, 0.11229373221950871, 0.12595101366085665, 0.09097058605402708, 0.2633008728069918, 0.16243244893848896, 0.06487393924700362, 0.13990756975752966, 0.08730873611888715, 0.095057456754148, 0.12282230226056916, 0.0906010762389217, 0.21945632834519657, 0.09374151272433144, 0.18863745778799057, 0.14064954780042171, 0.13773302787116595, 0.14737106141235146, 0.08674948755651712, 0.16860732116869517, 0.11493400697197233, 0.1101364115519183, 0.11014456075749227, 0.1352839507162571, 0.0798960735223123, 0.21191944634275778, 0.07419261349631207, 0.10280755481549672, 0.1375544781663588, 0.0848152692030583, 0.12276237404772214, 0.13214402991746152, 0.15190643018909863, 0.06994177480893475, 0.20759212997342857, 0.11142410138355834, 0.22244066106421606, 0.07207996757434947, 0.1520224596772875, 0.08996543141880206, 0.15514146802680834, 0.12034398024635655, 0.08291612432471343, 0.14773498688425335, 0.1462178775774581, 0.08651113177516631, 0.06871475279331207, 0.11551122314163617, 0.1770852498177971, 0.07158655047948871, 0.16318661347031593, 0.1228680219501257, 0.11069935134478978, 0.08746362530759402, 0.13611717814845697, 0.1098986528813839, 0.16282690848623002, 0.19005190474646433, 0.13853881534721169, 0.08328735083341599, 0.09609667384730917, 0.0858226494331445, 0.07876118977687188, 0.19791615275400026, 0.130380653110998, 0.0908303600070732, 0.15997600289327757, 0.12301444980715003, 0.09591559999223266, 0.13850775201405796, 0.19185551867953368, 0.18945530961666787, 0.11798091419041157, 0.10238218799765621, 0.11758694318788392, 0.09948292999927487, 0.12693932705691882, 0.14395078351455076, 0.06467693338968925], [0.03517315869352647, 0.045572016587747, 0.06581305206886359, 0.09696128352412156, 0.0062322669629273665, 0.017980664003906504, 0.05869503651878663, 0.04567223621000137, 0.037721597123891115, 0.03246983785980514, 0.06555567695094006, 0.041317530774644444, 0.014041582471691072, 0.043117351696959565, 0.044673313918922625, 0.010313512607743698, 0.017739694166396345, 0.07291559702051537, 0.04667463938572577, 0.033200667572340796, 0.03483385047210114, 0.06878307448433978, 0.016576522296028476, 0.04979357648906963, 0.011073802614451518, 0.008250395501298564, 0.011425079345437033, 0.018891811004972885, 0.031836880038359334, 0.07511063744979245, 0.0249930604893182, 0.019826450584722415, 0.02216435147316328, 0.04624832261885915, 0.021232197027919546, 0.0710350711430822, 0.0035115919599775225, 0.045095732502107105, 0.06088610751820462, 0.07239324719245945, 0.04132942549352135, 0.044996958159442456, 0.03809191778834377, 0.05408640292340091, 0.04873085155018738, 0.02784289908595383, 0.01668983425146767, 0.023601227406678454, 0.02797599203352417, 0.03495546769616859, 0.03547796680192862, 0.07002656454486506, 0.0552462024747261, 0.07186878712049552, 0.05955328832247427, 0.06677652429789305, 0.025021750646244203, 0.04015643522143364, 0.0030798647245059586, 0.006690463425392019, 0.008280277335351067, 0.046734628666724475, 0.04088009621149727, 0.040429029879825454, 0.055345037885542424, 0.013130907052462655, 0.007842352530652923, 0.04215377429500222, 0.028327873508845056, 0.03959217567795089, 0.010165062716363795, 0.005359747264135096, 0.047986318822950125, 0.02307107612224562, 0.02426939780291702, 0.010201569596704627, 0.037366998115820546, 0.006897528988442251, 0.03197989486423986, 0.041268292881016216, 0.05629406071134976, 0.03834029213924493, 0.07424655024494443, 0.014922213208462511, 0.007123219065501222, 0.008921589619213981, 0.024896827260298387, 0.04340545427320259, 0.010673307497719569, 0.03096558339893818, 0.03632246470078826, 0.007055463951214084, 0.005731412276093448, 0.026654539995693734, 0.03896175557747483, 0.02200549285459731, 0.06689235022557632, 0.06987966171332768, 0.04892404064802187, 0.05676168669015169, 0.036751980760267804, 0.03693135488512261, 0.01473005548385637, 0.05717718760882105, 0.031156604577388083, 0.04720596283940332, 0.056632985560489554, 0.04180458999638047, 0.0478682503370302, 0.020087211592389003, 0.017262499147493924, 0.03162504819088748, 0.05067919021738427, 0.021577630724225725, 0.0546250375919044, 0.058355226181447506, 0.06664819975516625, 0.015699831303209066, 0.030103067002658333, 0.022308955767324994, 0.04669011676950114, 0.03089661370696766, 0.04078928447727646, 0.03469048620068601, 0.06584175410015242, 0.018530423254040734, 0.055981642832713466, 0.006321231385559908, 0.03392097320673721, 0.009123223085355545, 0.05391373611720545, 0.05365794198587537, 0.029949087050876448, 0.04349074612504669, 0.05224002432078123, 0.10141881754887955, 0.025968456274962852, 0.02885141077318362, 0.044223709830216, 0.06866004930010863, 0.0021209696382616778, 0.02304232320083039, 0.04540007242134639, 0.025592256104573607, 0.019809297219450985, 0.057823444716632366, 0.03491182093109403, 0.02218659215473703, 0.017846911181030527, 0.01713058345818094, 0.012652744272989886, 0.007805373220305357, 0.0362689248951418, 0.022219658862533312, 0.0317344314285687, 0.038700244788612635, 0.018462717333542447, 0.04920696260939751, 0.03929178822519524, 0.06376735041184084, 0.044579720191125355, 0.11079767785434212, 0.015598123992926307, 0.016512314223551323, 0.047469970637134144, 0.024047289542587738, 0.0409262196293899, 0.02121579514018127, 0.01574081481833543, 0.02033798286824354, 0.03549336276150175, 0.02861903967069728, 0.02709996939769813, 0.053141939852918894, 0.020239183080515692, 0.01782432953560991, 0.029595502452658753, 0.02935148768925241, 0.0027940638662715045, 0.02601372473873198, 0.049165422695555856, 0.042955867147871425, 0.07359547553850071, 0.07031057894762073, 0.04813904009227242, 0.01131022033015532, 0.007294796822991754, 0.06648043197180543, 0.05436026304960251, 0.027427627172853266, 0.030597138883812085, 0.026186963210680654, 0.029845203339521374, 0.05215149924957326, 0.010495149646885693, 0.08924724281366382, 0.021667862311005592, 0.056172480806708336, 0.008719336141699126, 0.00722739878775818, 0.050754626348082504, 0.03363487909414938, 0.016753674218697206, 0.03839193883218935, 0.03502490896997707, 0.017188248756740774, 0.02001701544837228, 0.08652414607682399, 0.03552723862230778, 0.030681263655424118, 0.04065770975181034, 0.03156229727236288, 0.013823884688983006, 0.03320352081209421, 0.02884612837806344, 0.03851863489087139, 0.042326861792909246, 0.05140262050554156, 0.059383973479270935, 0.03143232049686568, 0.0049407790315204436, 0.03439918772450515, 0.032733502997351546, 0.04729788058570453, 0.03650024426834924, 0.03841015749744006, 0.03358586511707731, 0.034747459393526824, 0.06182376827512469, 0.05376915726810694, 0.06130040064454079, 0.01208783418405801, 0.030839810147881508, 0.028486019665641443, 0.015576035981731755, 0.03436278092807957, 0.0397203916550747, 0.053670505061745644, 0.01465066519033696, 0.03199539599674089, 0.0061976213889595655, 0.025004293636551926, 0.00967672954513026, 0.02259069198875555, 0.08557488237108503, 0.029319939203560352, 0.025309753138571978, 0.0025196772393038763, 0.03363124214644943, 0.04542174482984202, 0.02388982192081, 0.041549596536372385, 0.023670507528420006, 0.029691647472126142, 0.02832929334337158, 0.08520373728658472, 0.09542136865534953, 0.029608513361641338, 0.013687975821085274, 0.02955707022920251, 0.04441621700035674, 0.04761242227894919, 0.06426983273455075, 0.02813884213433734, 0.016299842856824398, 0.029913728591054678, 0.02253967633337847, 0.012576881513398672, 0.02788700895117862, 0.039681158760296445, 0.026887889884944473, 0.07209279188620192, 0.05054593951042209, 0.028858063809041466, 0.03441469564235636, 0.05964367597230843, 0.029486370272934437, 0.026463851299402968, 0.050899558035390716, 0.04518436613891806, 0.06547586087669645, 0.013110730813683143, 0.027816395508125424, 0.03621629432642034, 0.015410480222531726, 0.042671944347343276, 0.03062292660719582, 0.03602090338245034, 0.020780219762985195, 0.030416044672685008, 0.015495975634881427, 0.09735363282795463, 0.06768198178282805, 0.013923156906717589, 0.033457727171480656, 0.028801365422883203, 0.05358343205547758, 0.032455690404666324, 0.05109372761632715, 0.04663782886096409, 0.00736152650123196, 0.03716556481750948, 0.008489382320216723, 0.0327793583939118, 0.009882871028301972, 0.05274780260931168, 0.033612232987901995, 0.04593617954690542, 0.029459330652441298, 0.09279188260968242, 0.0563254667046879, 0.06895347498357296, 0.04687954678333231, 0.06344579945185355, 0.026126845008028404, 0.09352974194501128, 0.05711280820625169, 0.035163353862507005, 0.03597148906971727, 0.02275245134452624, 0.032602657697030475, 0.06365972118718283, 0.03194171369874051, 0.045382559432515075, 0.007278087898157537, 0.030228022619017532, 0.0552788298310978, 0.04925701813772321, 0.03368968436760562, 0.027326240470366817, 0.03233878899897848, 0.06235153281262942, 0.012820873376248139, 0.03239130082407168, 0.04425333466913019, 0.05301182397774287, 0.03067351478551115, 0.05936504913760083, 0.013204712154609817, 0.01819369855469891, 0.047950678771095614, 0.029400854504534175, 0.032941674148397784, 0.03581477122913514, 0.07111204415559769, 0.01990399695932865, 0.0984845200021352, 0.0489387343238507, 0.028205565875396132, 0.09099371052746262, 0.07835473373000111, 0.07152597765837397, 0.0981008695172412, 0.1239674658115421, 0.17132235690951347, 0.25260645523667336, 0.12618715741804667, 0.140017248157944, 0.12912495620548725, 0.17037521701838287, 0.10631662580583777, 0.03310340636276773, 0.0877263947789158, 0.16096001437732152, 0.17054562430296624, 0.13995005962039742, 0.14840183752988065, 0.08704344928264618, 0.09638119715132884, 0.1502701294209276, 0.2845559279833521, 0.17252423241734505, 0.12890175889645303, 0.2566369261060442, 0.11541141064039298, 0.10841859158660684, 0.10978105597730194, 0.10477679914661817, 0.08778323565742799, 0.13692998167659554, 0.08185604227972881, 0.13315275364688464, 0.04937979904934764, 0.11035498125212533, 0.1269360158060278, 0.12555962109139987, 0.09201409148850612, 0.14661973315690244, 0.04872078887586083, 0.17351044235484941, 0.11679307078676564, 0.20496508665382862, 0.14139026376817906, 0.15445130291794026, 0.1396299403692995, 0.20041886131678308, 0.11191391545747008, 0.07197161910257169, 0.1321094517729112, 0.13300832068281515, 0.15075361276311533, 0.09127564861306123, 0.13881550835711615, 0.1469995499189411, 0.13479655901236193, 0.09259495817657028, 0.14175294073564665, 0.16103746236435004, 0.10357945625271116, 0.1147276373314006, 0.08448544690119368, 0.0724556724141751, 0.10252687880503279, 0.14513482712209225, 0.1072328177147678, 0.12668700702488422, 0.06404088144855839, 0.10091576525675398, 0.12257887103727885, 0.15577838170741284, 0.1247039477207831, 0.1304415584142719, 0.08407750486263207, 0.04843773799283164, 0.1314890943467617, 0.0942427668986576, 0.05861055212361472, 0.09036816909377064, 0.09743028692901134, 0.10215327063841478, 0.16160204421196664, 0.17364924347826413, 0.1651796336684908, 0.13528874117348874, 0.16829497792891093, 0.12312074910317149, 0.08980262372642756, 0.13729440926441125, 0.12002531306019851, 0.16646783240139484, 0.10838534337069307, 0.1425054632127285, 0.10075721197894641, 0.0804987618965762, 0.0753323080550347, 0.13657166090394768, 0.11814707384577819, 0.13405004835554532, 0.10269051431013004, 0.140175889645304, 0.1034647159810577, 0.2713730510856424, 0.09855271277150937, 0.17862670496106148, 0.13576381068144525, 0.13084810945604528, 0.15055245427148684, 0.06484381907752582, 0.11108520706849438, 0.1368654394256217, 0.1331224502729518, 0.10389916159744773, 0.09467876636024032, 0.12624521287424223, 0.12117046304047108, 0.07748317585459777, 0.16253607480653695, 0.20487831559564385, 0.15096475929021835, 0.19986816229564802, 0.15552827369953903, 0.10252284152167183, 0.12130882990147386, 0.14819546788930893, 0.09948149829038552, 0.08523187613380806, 0.14586917843137467, 0.10942131028111492, 0.13448466360569, 0.11566100296165262, 0.07636410197509186, 0.1508773775505168, 0.11130451637187175, 0.13470928583826336, 0.09776718635112047, 0.138124284733619, 0.12014101685157844, 0.25694568668093, 0.09683196832026754, 0.14345123246312141, 0.1468353715858289, 0.2207711935043335, 0.13042836769350938, 0.09609123199645962, 0.13271793483623437, 0.19016498939267226, 0.1577740889042616, 0.16343760357371398, 0.10057567672005721, 0.10520076139697007, 0.10762201861611434, 0.06849315682692186, 0.08559536734329802, 0.09528456921023981, 0.13840175127344473, 0.10940995160490274, 0.2301376909017563, 0.06474188276167427, 0.0919059601479343, 0.0911129019888384, 0.08244490211031266, 0.10641356810395207, 0.13008610105940274, 0.20440509170293808, 0.1133015195706061, 0.10039838909038476, 0.18134471268526145, 0.07645177548485142, 0.10714905256671564, 0.12720884116632597, 0.12545311823487282, 0.08894780530993428, 0.16709551800574574, 0.10840551621679749, 0.13747116763676914, 0.18662408153925622, 0.11089006718248129, 0.1363233442285231], [0.06570309546909162, 0.01248782464036984, 0.016270674332710247, 0.05553588943023767, 0.031001067387738397, 0.030523612829191343, 0.03882615374667304, 0.04650461547342794, 0.011499126175684589, 0.03068409993180207, 0.031609153508075645, 0.09146807435899973, 0.04599150389965091, 0.024579288138608848, 0.016532122357083217, 0.03956078325531312, 0.04099074152431317, 0.02206326162974749, 0.086673037015966, 0.046129290613212755, 0.03829601772927812, 0.0427247954399458, 0.033129723343466005, 0.025236690184101462, 0.05097278553460326, 0.03690081063125815, 0.00709351704322866, 0.02016975368107004, 0.03860666463151574, 0.053016322664916515, 0.021497566984700303, 0.02180649888967829, 0.03500453256336706, 0.02254731154867581, 0.04641631771145122, 0.06604296687458243, 0.03779686701350978, 0.05420609650069049, 0.029877715344939913, 0.021213230277810777, 0.026410738970818262, 0.02214529990617718, 0.017430599413013885, 0.04467281858835902, 0.03424371160300715, 0.04226573257307921, 0.030678162750388895, 0.004113990048478756, 0.02814564953691193, 0.039063250845564265, 0.03722744042586003, 0.02557404083199799, 0.014573217203308429, 0.00799270486459136, 0.05043475815494146, 0.08801157626190356, 0.027069593081250787, 0.04206835352150457, 0.006106709570823503, 0.027868754662839428, 0.08022180425801448, 0.0812796199960368, 0.05508583411574364, 0.07026460141475711, 0.0303866301796266, 0.043985082634857724, 0.05560892693964498, 0.07774650172463485, 0.050726945511996746, 0.026667045396087424, 0.038367494608142545, 0.008641090876023685, 0.02167627614523683, 0.011268542164803615, 0.013153776227097427, 0.052515221160969565, 0.03485990960949233, 0.05907622392156294, 0.040614877228758166, 0.018224514222570827, 0.030085978098213673, 0.022356872214004397, 0.006663662988492953, 0.039527100776987414, 0.018353442661464214, 0.038992123412234445, 0.07033227849751711, 0.05180396039837173, 0.02488051527845008, 0.07708482151584965, 0.021127650048583746, 0.06361501251480409, 0.009780416481329926, 0.05595777536343251, 0.034013433781053336, 0.0481279053326164, 0.030748126496161734, 0.014718683236943824, 0.06516526825726032, 0.016842165363154242, 0.011009284112203335, 0.024753106757998466, 0.03975009113284094, 0.033540674684835334, 0.02564656944014132, 0.021620195225945542, 0.03214502653905323, 0.05910394207707473, 0.03587745090148278, 0.01741147829618837, 0.020267138723284006, 0.022307578341237137, 0.004581760640056538, 0.03562643365668399, 0.025471125729382038, 0.036953237639474015, 0.030440034278269325, 0.05173340971980776, 0.05092663836798497, 0.03200451211471643, 0.022025290810103928, 0.015269957316507186, 0.008456356324521559, 0.026046755823439786, 0.034740931886647425, 0.0329255012662283, 0.021086137276142836, 0.004978545018405254, 0.05312462703191808, 0.014445662797827805, 0.03583275919247951, 0.03892800185297217, 0.036716415347265344, 0.05854510742106608, 0.016902880676622902, 0.06388010936123983, 0.030569390194224458, 0.022781843785196543, 0.028928553419453756, 0.06606206763535738, 0.024077201062547307, 0.05776252584265811, 0.04041425817246948, 0.04657384300870555, 0.008627507453119116, 0.029433179912822585, 0.11399220036608831, 0.033182425158364434, 0.01807985225293253, 0.04906431758510215, 0.009971671754361262, 0.040528954339346716, 0.007097478839568794, 0.035615722981414626, 0.004426690791400948, 0.012413684511557221, 0.017466800952596322, 0.04736114040549312, 0.0449010506272316, 0.011720684822648764, 0.013985065593650299, 0.06112849379756621, 0.055104931483843496, 0.07407669257372618, 0.01511362284821059, 0.01767815273654248, 0.025565097740452205, 0.03865223504336817, 0.06255450299275772, 0.035568405341889174, 0.03517608657213194, 0.016424930787512233, 0.031768707625035725, 0.011520682385058274, 0.03845016052946448, 0.061317459014909606, 0.02715795360771673, 0.026854378736710975, 0.0361422661558858, 0.029213256535253355, 0.01681386536386396, 0.00435125593295587, 0.02444653445854783, 0.037294764670410326, 0.020603775213073407, 0.05209843781111496, 0.038369085772761276, 0.07078451530209609, 0.03274574376908796, 0.08308565629912273, 0.050878323281982114, 0.0966516612097621, 0.023447722429409623, 0.026709190902433226, 0.057512377122683186, 0.07889197740171637, 0.06845597989325013, 0.03153809392824769, 0.019927972994212593, 0.023621729342266917, 0.061786496346550326, 0.024749266249792914, 0.01627581932448915, 0.009881731089470642, 0.059704452353928766, 0.065813248844019, 0.028124804941139052, 0.04635832332340734, 0.012822233838960528, 0.0056621550549087775, 0.04253976233303547, 0.05916819255799055, 0.012483040120319595, 0.059731186633663516, 0.04436969663947821, 0.06081079691648483, 0.02723879087716341, 0.033400910041694126, 0.058728793635964394, 0.008874215152380722, 0.0348039508265044, 0.052872083083327324, 0.015509078146091529, 0.018403331948710338, 0.10208273692322628, 0.038216914116804085, 0.023505514953285456, 0.009822491589667541, 0.03239532792940736, 0.020673637178593447, 0.020353880943730474, 0.05016527457961014, 0.07905762137046882, 0.010645663981059832, 0.04074211611545511, 0.01198223462727453, 0.040714811866304705, 0.01929389050097338, 0.0842832706070372, 0.030305263652865375, 0.024031155676181828, 0.030768357017742734, 0.0423601710769747, 0.1007299552272473, 0.026902008502345, 0.07057972664811782, 0.02128494973294437, 0.041885026930166144, 0.05515328049659729, 0.04970450180449656, 0.044305412231811454, 0.021022882545366883, 0.016611127581979548, 0.0102516734706504, 0.025770330834867697, 0.04205273364537528, 0.004065673690222735, 0.057666112801858356, 0.033670709135809114, 0.02705563391957964, 0.00859625158565385, 0.03675842345026987, 0.08081631628530365, 0.06039239186793566, 0.02126932985681508, 0.049987844457583766, 0.019619103853723834, 0.04922151718554752, 0.03647135224725519, 0.034107980850551806, 0.008222103135527244, 0.02294859546236694, 0.006669363106733986, 0.05242064355739525, 0.040884862920003276, 0.017792886222845743, 0.03563852175804121, 0.02737339526148779, 0.054875705391168594, 0.015908273868262768, 0.05224220920354128, 0.017989827619333352, 0.032177752283002646, 0.06268625413732869, 0.03869697764249785, 0.04662990017927118, 0.02224008276659463, 0.050041313017053266, 0.016836530129824365, 0.04871947930327483, 0.02106833421359105, 0.009885114434707378, 0.0063932485479329315, 0.03453053853341511, 0.021183671596060907, 0.04995892529508897, 0.0449681713112763, 0.01974589829998357, 0.0166979020328394, 0.03209806513041258, 0.015159312003691281, 0.07379307172128133, 0.03284747652443392, 0.03187285935772317, 0.004366992856375873, 0.015924168551074605, 0.06596707951809679, 0.025285812726776515, 0.02764224779925176, 0.024503239630056278, 0.042553312677357874, 0.048430284285651784, 0.017865077259817293, 0.03936014384297388, 0.01747602054716221, 0.032756298381303034, 0.03727360116317868, 0.03925777326471039, 0.041458659273173125, 0.05629447801038623, 0.03353767216737781, 0.021189732610114982, 0.0546287525711315, 0.030330410160656487, 0.002878961743720408, 0.03109154663980007, 0.050804539384054284, 0.05733467558664935, 0.05843804816582373, 0.07462343573570251, 0.04825243686458894, 0.025329669837706854, 0.02494917793332466, 0.006893784323308084, 0.014141160030184048, 0.01851256930136255, 0.022377969564071724, 0.043507156494472704, 0.09719790904117481, 0.016286248407725776, 0.019853997410141995, 0.04901333246380091, 0.004859536337400121, 0.06604422216436692, 0.0390503281461341, 0.03979291347786784, 0.03639520704746246, 0.007417693085569356, 0.012612999084272554, 0.02493629085698298, 0.03850129832114492, 0.00880460170031126, 0.12508730643561908, 0.12868017650076322, 0.1254288809640067, 0.10366360138037375, 0.08015724843634026, 0.09617958404123783, 0.21003481532846177, 0.15941855923405715, 0.06245792031820331, 0.19385526994509356, 0.10794202930160932, 0.12952920022819722, 0.1501748359629086, 0.11637225693890027, 0.20155143125780992, 0.1298827034022127, 0.10946993410055127, 0.09990876500627824, 0.1614165191671678, 0.17880905446197304, 0.07704648428729602, 0.14124452801687376, 0.11055602439280067, 0.07536358173404421, 0.15527659149042197, 0.13281208835542202, 0.11059238708445004, 0.09958380101514713, 0.23079828545451164, 0.09682453836181334, 0.15609219058283738, 0.11334838598434414, 0.17561873208199227, 0.1256149216954197, 0.08057457461420979, 0.13230617264551775, 0.15950039055730614, 0.16294061738465512, 0.1411556535001312, 0.25471876189112663, 0.09612491447478533, 0.08779884874820709, 0.11117674822786025, 0.10130276770464011, 0.17448236234486103, 0.1103576003972973, 0.08293920808604785, 0.07652450765350036, 0.19258151043738636, 0.13913659112794058, 0.16647138792489255, 0.0592151607519814, 0.07867546366261584, 0.0658932209813169, 0.10914731784058468, 0.24021184604082788, 0.18685703618185862, 0.11120950789856059, 0.07322375369923455, 0.19832426442631654, 0.12901400215923786, 0.15991713319505962, 0.24946277535387448, 0.11951433547905513, 0.13436172663101129, 0.1443674854402031, 0.1480130505348955, 0.1257326475211552, 0.11799353494175843, 0.17838123813271523, 0.09650825283357076, 0.1807150864707572, 0.09481682109513453, 0.09826987223433596, 0.09573372546583414, 0.1846166628279856, 0.15784524008631706, 0.13959093817642756, 0.08295923165444817, 0.10115204472094774, 0.11712359876504966, 0.2400104297058923, 0.11300841279860054, 0.10906761711729424, 0.10292663092591933, 0.15181576433990682, 0.23911356925964355, 0.1103461127994316, 0.0494979964569211, 0.14692127411918982, 0.09721802081912756, 0.18655629589089326, 0.1249336182538952, 0.10979143756308726, 0.07792611672942128, 0.19041676659669193, 0.10020426700689963, 0.14584599967513764, 0.12347771280578204, 0.12418475986591407, 0.08072985056787729, 0.08173438095088516, 0.11006119594510112, 0.1179459560662508, 0.08568989405674593, 0.13272083896611417, 0.14698941260576248, 0.13279931832637104, 0.17681432435555117, 0.13471622046615395, 0.11491959488817624, 0.14905754663050175, 0.12483654703412737, 0.10242819945727076, 0.12773804419807025, 0.10444457483078752, 0.10048133321106434, 0.13195534289947577, 0.18402666305857046, 0.1790301754538502, 0.12311671860516071, 0.12271217602704253, 0.10216835447187934, 0.10226393969995634, 0.09640502730118376, 0.15621115134230681, 0.08509228112442152, 0.0936778729249324, 0.14611202611454896, 0.11055449768900871, 0.17642199540776865, 0.10574249697050878, 0.1359129391078438, 0.15455950211201394, 0.10424813215753861, 0.19115882606378623, 0.19268725333469255, 0.09944107117397444, 0.06258737801441125, 0.1156865158783538, 0.07091565576515027, 0.1386039275676012, 0.18611158403967107, 0.10051784518041781, 0.11564451456069946, 0.17671956015484674, 0.20380127696054323, 0.17250228859484196, 0.07293211256286927, 0.16785793352339948, 0.19017828867903777, 0.12914482371083327, 0.16665062973541872, 0.1469527988561562, 0.09704242274165154, 0.08172885089048318, 0.14513485426349299, 0.11772288089351994, 0.12632001457469805, 0.10214172875774757, 0.0763362684686269, 0.13968509169561522, 0.2336090217743601, 0.16349123498158796, 0.16457011923193932, 0.1368954035320452, 0.10198196768760681, 0.25151789507695604, 0.09783330280333757, 0.11092332896909543, 0.16628564574888774, 0.1128088217228651, 0.07700676284730434, 0.09391024402741875, 0.18817464262247086, 0.13257134413080557], [0.11082266151372876, 0.05118669369923217, 0.045540339180401394, 0.019442732246326547, 0.04824681180928435, 0.04156041577724474, 0.0355101598958884, 0.01727156776801816, 0.08045266901275941, 0.04054931717525635, 0.04689735832757183, 0.01647846550414605, 0.023781320778653026, 0.07049260275172335, 0.061933813084449084, 0.011184576000752193, 0.06397545031671013, 0.07914569521588938, 0.014868171286902257, 0.02943897120920675, 0.028462213264512162, 0.00899217083185379, 0.05455703481233545, 0.04383173032796808, 0.055366031759019406, 0.007816319686493703, 0.04189275883670364, 0.07314986123570374, 0.030568077228963375, 0.04039527615532279, 0.035492945462465286, 0.0059163291838818365, 0.04105105650212083, 0.026067379895331602, 0.01165151665918529, 0.02908179716074041, 0.05261784618986504, 0.05970327170299632, 0.0402950633184186, 0.02138879442853587, 0.0333235604422433, 0.03716940532571503, 0.09827889675008399, 0.05965365722243275, 0.03445512954411762, 0.021234953576432805, 0.04670783671151314, 0.0182991293258965, 0.028068398325038806, 0.05786628741770983, 0.02831099325391863, 0.03993707502792988, 0.016270691296085715, 0.021869024195309197, 0.028009752543377023, 0.021018550099272813, 0.02174164790527097, 0.04326255140560014, 0.023696181597188115, 0.01576849565442119, 0.03224548364856413, 0.05953855732721942, 0.031924356772963486, 0.07965321905378785, 0.023560143807636838, 0.0534629886969924, 0.06131177967680352, 0.09678662861032145, 0.03237536882183381, 0.05037220061889716, 0.0412730188774211, 0.026175546858991896, 0.046433250552841594, 0.01851641320224319, 0.07101806027016469, 0.004378030924791736, 0.07296271449221031, 0.008905262370327753, 0.07087430584111384, 0.02921932263832007, 0.047896019382668395, 0.032599142885633876, 0.018032690676461374, 0.02573486720211804, 0.023165865768013254, 0.02277979800211532, 0.016928763394909244, 0.04374870478308626, 0.014265560944165503, 0.029747019322322946, 0.0350628458628697, 0.019876896270683835, 0.0018305174224743886, 0.03705054295382329, 0.010522565854314183, 0.019571282401947037, 0.03462903467672212, 0.047284333634057214, 0.040102230451468907, 0.03588190209120512, 0.10892190850738968, 0.03240300555314336, 0.021643918506535034, 0.04889392387121916, 0.041128935358886204, 0.04718439560383558, 0.06335858734590666, 0.06486433797648974, 0.05768002276974065, 0.04053666249715856, 0.019431889256728545, 0.017570143532274023, 0.031960332699652226, 0.01771711421731327, 0.059727183277053494, 0.019382184870275, 0.050575543993285725, 0.01761002273165754, 0.01897757443865495, 0.04823722071679575, 0.05570157750376633, 0.02869477096412863, 0.05675266556707876, 0.04552580835297704, 0.02264354477769562, 0.05101394207615938, 0.04075453669897147, 0.07368621602654457, 0.016106892942583988, 0.05139971976833684, 0.052649798403893194, 0.0273534853477031, 0.02453548870315509, 0.02128167580147939, 0.012557203997857869, 0.023279192990490367, 0.04172974079847336, 0.043602697617773495, 0.02292183064855635, 0.02745631563344172, 0.006221464261346097, 0.04650960949116519, 0.012354133733814316, 0.03515450915853892, 0.046214484077479155, 0.010794557464708174, 0.03062073154641049, 0.02307527625401105, 0.05899484043142625, 0.02856283661510263, 0.06469629877912146, 0.04326701955869794, 0.038689676605697186, 0.04100648353674582, 0.027240629707063948, 0.05698352014379842, 0.058077542510415824, 0.011992761249920087, 0.020313716759639125, 0.013700798436600183, 0.026228716863053184, 0.017641432117670774, 0.019651520864239762, 0.03602864207433803, 0.038165827215250046, 0.05743292745734964, 0.06661366232271705, 0.014643834039036716, 0.02436192114172237, 0.04727278836071491, 0.07157253873135362, 0.0336467704203512, 0.05715261785579579, 0.01278907128809286, 0.01889107988349029, 0.023829230439982245, 0.042875701628093205, 0.08718944966260876, 0.05907777098140546, 0.022752037438164865, 0.03777990024536848, 0.03655536166791405, 0.021380689327738116, 0.04179810659427728, 0.005792343024430531, 0.014740140210571033, 0.05295762599312833, 0.08225951277251754, 0.04787514764549477, 0.01740306955096977, 0.045034392936421294, 0.0284207530785352, 0.056142021369721205, 0.0632555043058736, 0.052144415343978574, 0.06338001548179559, 0.03406532135392938, 0.04576163659138339, 0.013591412654412644, 0.017819678178057075, 0.01648230092333896, 0.008241040199728948, 0.03877480900181191, 0.029260204373193637, 0.023752433846571615, 0.08286210615187883, 0.03157809017492192, 0.033350080983447175, 0.041868507995137146, 0.029909864334123473, 0.03856837490041341, 0.02747776242904365, 0.06182868765400989, 0.04107081204918878, 0.011338325250627739, 0.02004757327293711, 0.018448250966944864, 0.0378136777185968, 0.0336684563995472, 0.09661603812128305, 0.012303304675567363, 0.012772398834515895, 0.03963978848020945, 0.002924787878457989, 0.022929398010351827, 0.030090269832206622, 0.023656387214681933, 0.04266474509079542, 0.0374130570728864, 0.05394175282812544, 0.020059761458209584, 0.029494482159082378, 0.039591079843895774, 0.019005440175533295, 0.03045210541625108, 0.01975673620056893, 0.021483955572226217, 0.0594094931813223, 0.016604360891506076, 0.10317479153828961, 0.03148731915280223, 0.05015537814636316, 0.013111400018845285, 0.03762952331453562, 0.08467292612684624, 0.013043295459023543, 0.0547985423888479, 0.06066915951669216, 0.07590037757264716, 0.08074503618159465, 0.04509145773148962, 0.018503397204247967, 0.039904617305312834, 0.05407892207482031, 0.057714207363980155, 0.021607560903898308, 0.031848401562975984, 0.007515678631274828, 0.03128008438008172, 0.03146107341828091, 0.003878634240079139, 0.0845860940005098, 0.06541258748620749, 0.03408065624535084, 0.046037583212767325, 0.026733998142715012, 0.053435653913766146, 0.021118542412295938, 0.03459430725446769, 0.03165600635111332, 0.04303024137126548, 0.011820962120379721, 0.04887919966131449, 0.0323545920795628, 0.026761061511933804, 0.05707778222858906, 0.05581166981054204, 0.020225741301796267, 0.01850816560909152, 0.06798956170678139, 0.026291265917409743, 0.02668957954405674, 0.05615665737007346, 0.08818931851003851, 0.09103985090873071, 0.05913582643760102, 0.07783078255930118, 0.025158751955521957, 0.029271566442080905, 0.025661325880459378, 0.0529463453484433, 0.046801776492169926, 0.012153022739637111, 0.02170660496423287, 0.01351170175309692, 0.038184344435908964, 0.02949272475338408, 0.054289597020085366, 0.02097556660217898, 0.016705759468355348, 0.03298136166163853, 0.01789221357155059, 0.005155495076905936, 0.07932093366980553, 0.07228639828307287, 0.038701313481267006, 0.013979080066617047, 0.10418313528810229, 0.009832659436921989, 0.013388379709795117, 0.018510708419073905, 0.03979115607216954, 0.06093604091022696, 0.032258002619658194, 0.018201674733843123, 0.012141539382615259, 0.06709219235926867, 0.016547330023188676, 0.030535314165587937, 0.03683823613183839, 0.025627679025222148, 0.03517215785437396, 0.036373130910630734, 0.020075517041342597, 0.010299459299338716, 0.026293954612421136, 0.02177434990049473, 0.08343060314655304, 0.05176325168992792, 0.022670872775571685, 0.0402280444146267, 0.0444056454247662, 0.04099759133532643, 0.0386631153523922, 0.044189162219741514, 0.06947121077350207, 0.031069867445954254, 0.006448591136307056, 0.015787862740190964, 0.025636404985561967, 0.02364884190527456, 0.046716013058487854, 0.034587236919573376, 0.010894045965479953, 0.05576778555821095, 0.015535876886653048, 0.03270602911444647, 0.03020660805382899, 0.046236879125769646, 0.05285918413262282, 0.04279333765485457, 0.020562796786959683, 0.16055631318262645, 0.2072362790682486, 0.19488399688686642, 0.14531801800642694, 0.11148352069514138, 0.12725268809923104, 0.11262495908886194, 0.14042411132582597, 0.1544530535382884, 0.18722154519387654, 0.17740435126636708, 0.10463521602962698, 0.16355638791407856, 0.1507303932947772, 0.12985586055687495, 0.13005672049309525, 0.15753357538155147, 0.18307060721729482, 0.11839091219007969, 0.1375293723706688, 0.11018807520823819, 0.12432239390909672, 0.20018537741686615, 0.10100347269326448, 0.14882905674832209, 0.09663371395851884, 0.13671451966677392, 0.12429572748286383, 0.07357988958912236, 0.14861089416912623, 0.12117243079202515, 0.07848716340959072, 0.18277967854269914, 0.08618719915726356, 0.08614922833761998, 0.12071926439447062, 0.1283067651093006, 0.11836837125676018, 0.13058605923184327, 0.08325908984988928, 0.11563122884503432, 0.12212433399898664, 0.14755464584699698, 0.18084617943636008, 0.11238719363297735, 0.08959560269223792, 0.08020019291767053, 0.07838366646319628, 0.11631995545966284, 0.20679789116340025, 0.12756731121667794, 0.07669658413422958, 0.11438330795083727, 0.1663213095494679, 0.13642805575260095, 0.14155901542731694, 0.13520606846681663, 0.1573303270020655, 0.1838277844446046, 0.05560925942180412, 0.11468273188386645, 0.16398222292108194, 0.11050141589449984, 0.19391460104712419, 0.05102548734950168, 0.0831786495234285, 0.10229427021528993, 0.13826212233730725, 0.15356403695685522, 0.05757418487753187, 0.15713684952684812, 0.14233630443257944, 0.1336610849414553, 0.13834197233830178, 0.11532436816820077, 0.1382504515349865, 0.137432884691017, 0.12307573509003435, 0.11382277695728199, 0.09757227038166352, 0.1598546944026436, 0.1778155163462673, 0.11131320840546063, 0.08474315450127635, 0.09712018285478864, 0.15031849539705686, 0.103415169353996, 0.131818577381117, 0.15862734669021197, 0.12163539523524897, 0.07045968023261853, 0.08959081223500626, 0.1375083920678922, 0.13035752863756248, 0.1520237081817218, 0.05479971964710525, 0.10740641411393881, 0.1410010289400816, 0.11977110670081206, 0.17427656267370495, 0.13214754472885812, 0.0892999649846128, 0.11090294577713523, 0.18784121051430702, 0.1705195956996509, 0.1315548579607691, 0.18725363990025862, 0.14414723297314985, 0.20365015364118985, 0.17415589200598852, 0.1672281851725919, 0.07155866269022226, 0.10634368578238146, 0.1350260938384703, 0.19457985035010747, 0.13299998827278614, 0.13918364074613365, 0.1546378457652671, 0.13437600300780364, 0.06942664459347725, 0.1523630978273494, 0.1898698673716613, 0.10555399315697805, 0.14560727748487676, 0.15864893767450536, 0.09937636607459613, 0.0965789629678641, 0.13168158116085188, 0.1256101040967873, 0.16115763091615268, 0.17077946104109287, 0.22723892144858837, 0.11753423458763532, 0.11263684702238866, 0.09667616310928549, 0.09415309849594321, 0.23386276672993386, 0.10098590542163167, 0.06882068568042346, 0.10187171931777682, 0.17209625323968275, 0.14150941451745375, 0.09027913172862359, 0.16771837244076387, 0.14543488887803896, 0.10935067478567362, 0.18438928574323654, 0.07148560482476439, 0.2516832947731018, 0.16381851956248283, 0.21058486295597895, 0.20041711069643497, 0.1322429874645812, 0.14670403434761933, 0.12968102922397, 0.11671882548502513, 0.1450419221073389, 0.10595756543001958, 0.1970575074000018, 0.15003659123820917, 0.09369105686034475, 0.09893166100872414, 0.10417164090488638, 0.06608557208840336, 0.14239498414099216, 0.12953679982040608, 0.1811029099460159, 0.0799344786043678, 0.14780092691736563, 0.11181805203003542, 0.1719021379415478, 0.06811670559857573, 0.14270920013742788, 0.09404293155031544, 0.07379387239260332, 0.16688296012580395], [0.04467687962044563, 0.05872502098126071, 0.019264984909178953, 0.06282414602381842, 0.042214730488402505, 0.007407146955042013, 0.056452793800937276, 0.04793744055288179, 0.08247072715312243, 0.04568915208801627, 0.0648219838206257, 0.10492365448070423, 0.004872418324729162, 0.04209498941366162, 0.016246218234300613, 0.04446673732517021, 0.028370124188118746, 0.04422120603599718, 0.03656354480023895, 0.02995586900838784, 0.04587050074977534, 0.024796975743291632, 0.0130225577325161, 0.03968458875481572, 0.07874040624925069, 0.014599295000412633, 0.023781020526907275, 0.03645550845456975, 0.02133333945779928, 0.0579303614795208, 0.048758586669074636, 0.0302413422614336, 0.022789027774706483, 0.03700454167223402, 0.034080330548541884, 0.038872246630489826, 0.024719320803082416, 0.0212404547990965, 0.013660529927749718, 0.041115863381751945, 0.08214736450463533, 0.03658556326159409, 0.032479225391788144, 0.06213604366140706, 0.039423651328044276, 0.02788353485188314, 0.05967435932585171, 0.00873604930737721, 0.032865966603692086, 0.04195949275578771, 0.02060594143612044, 0.07368048919098717, 0.017470069795048664, 0.045627646281250885, 0.024721575235681872, 0.02783105695354087, 0.01348572997708938, 0.04262250628588455, 0.05260134082553642, 0.028240924335217903, 0.009564502397552133, 0.0338180089103324, 0.020462153080318655, 0.03388339593740446, 0.013921112819973911, 0.008903741603717208, 0.02984015503898263, 0.04900704922952822, 0.04561797376456005, 0.05489320820197463, 0.022536755240123187, 0.053163079611424885, 0.0325299526697823, 0.021032139459358792, 0.018721697186785083, 0.017369139407362257, 0.062186927002455504, 0.02157462990310575, 0.017291245283558965, 0.03255620179697871, 0.03425898542627692, 0.03460366764504995, 0.028805711439677646, 0.013731245999224484, 0.055874525901994536, 0.05363715167290398, 0.028145144028323035, 0.01343858621216246, 0.035717866250446866, 0.0343045320894037, 0.016799336232777153, 0.043894837477377484, 0.07122433491583381, 0.025734992731096487, 0.019325603531407456, 0.05685048317536712, 0.06468899095697062, 0.05243755943541016, 0.10480314666139227, 0.044084182674331326, 0.02827901389848973, 0.07750984228083066, 0.05631604863862906, 0.019932492037436793, 0.015889144269749522, 0.034037959429302385, 0.028647748487336294, 0.015208290357674872, 0.055610372219234705, 0.018704543821513653, 0.032454553858510087, 0.01529929377803845, 0.031231236644089222, 0.09320343445454325, 0.053719837950276475, 0.04697186147261943, 0.021767147251271775, 0.0704780210341726, 0.06901340998177018, 0.01707080113036292, 0.0390552509176944, 0.038098180666565895, 0.017941022291779518, 0.004937733681539872, 0.038761136521186144, 0.028255034470930696, 0.04107569410864796, 0.05392561387270689, 0.0593233463753547, 0.011752101842180958, 0.01227252887162779, 0.015828781794490557, 0.03583580920738833, 0.031078070934329714, 0.010193718098370093, 0.04573912958481482, 0.05673174972512892, 0.017946080770343542, 0.033985878473946025, 0.0192377519062055, 0.055229534261993, 0.061010618694126606, 0.03271251930189984, 0.06828084321958677, 0.06777999616627182, 0.011354311535667096, 0.00788762777977224, 0.018217930736552392, 0.04897326157827463, 0.02300786379990833, 0.05032578882362161, 0.04041348464254822, 0.02067333014149751, 0.024282739497721195, 0.06979200855961867, 0.04366676828690937, 0.04810233474043863, 0.02836686552369169, 0.055335501075855324, 0.055345791059413126, 0.009329326400932456, 0.02860809150817139, 0.07954569160938263, 0.013816464060385312, 0.018763857960168804, 0.027293139835819602, 0.01518331517997597, 0.019401146531371132, 0.0581580303343279, 0.026583019012053098, 0.017239143972152045, 0.07242201029189996, 0.016939080519867793, 0.03291866841859051, 0.02079326629505626, 0.057695927630577765, 0.027799260802567005, 0.02481867529318801, 0.02023848588578403, 0.014301372326112219, 0.027470364701002836, 0.024516659356387596, 0.048466114327311516, 0.02240198800739433, 0.048694061381476264, 0.02874565769785217, 0.05432030751502939, 0.02171948695156191, 0.020143146626651287, 0.017426769082833613, 0.026774835772812366, 0.05461586719112737, 0.06356656511447259, 0.025108129850455692, 0.008426186961254903, 0.03274021031601088, 0.022801467017935853, 0.06542353904140846, 0.027265793178230524, 0.05995869264006615, 0.007283768932601171, 0.04007896687835455, 0.024397803769846047, 0.01122650267955448, 0.040331697424075434, 0.015660160753343786, 0.007008826967129218, 0.05581578851810523, 0.014110982185229659, 0.038681082959686, 0.008416456769087484, 0.01961402501910925, 0.050264975122575245, 0.011380749804499959, 0.027569184844781245, 0.02177825995853969, 0.06898820240582738, 0.030465340241789818, 0.036162598457719596, 0.03790763785530414, 0.05824868261281933, 0.04344120289066008, 0.01693909239423062, 0.044468521872269254, 0.024144079170322845, 0.04042986787057348, 0.0855758458908115, 0.03323737292417458, 0.04062818669314895, 0.02341505266459925, 0.014537753570558769, 0.030296941420861652, 0.03184968738683632, 0.02127782002623592, 0.01767311631036656, 0.0275898394507489, 0.016452175664848516, 0.023561863893909112, 0.027793432186756815, 0.030100546245064055, 0.014300015256074923, 0.04230572542707835, 0.014294251101091504, 0.0337992372390415, 0.022271030748795186, 0.06370474198567015, 0.013397584037323083, 0.040364117827266455, 0.04112732383821692, 0.01431063941812941, 0.022019416393179978, 0.0798197111913136, 0.02471329371577927, 0.010500560963659413, 0.0063841892572652015, 0.028436081184606467, 0.08626462678824152, 0.06409336613225085, 0.03486220645053046, 0.016770345824105398, 0.03377136641315051, 0.04900127489651952, 0.0325349229387939, 0.03114526964990156, 0.08195807359048299, 0.01339409382282091, 0.022315978604768003, 0.0256036554928869, 0.038689975161105394, 0.027506730785327296, 0.024080878722348383, 0.038036108283059936, 0.03677116294524499, 0.03197357431054115, 0.07111507042178086, 0.029453563104782785, 0.057864034681447914, 0.09213421254285745, 0.0554858678286629, 0.03947025989847524, 0.03197918240247028, 0.08426952348755938, 0.0033953360107261688, 0.03300303407013416, 0.048543528387589116, 0.04064165222059403, 0.048597868864557574, 0.019250189453097324, 0.014765040749417884, 0.06767924728670291, 0.059060386914227686, 0.02242298188087131, 0.032605293805577924, 0.01643549048873995, 0.027936791369159306, 0.04637067944609693, 0.05236865081159132, 0.040578283835202456, 0.041818927441324504, 0.016523298009165695, 0.0525128428957292, 0.026027646580977098, 0.034725630921976905, 0.017923868926508085, 0.0410548868323011, 0.026256869280976907, 0.03087007620238832, 0.0353239529233958, 0.008602605217934718, 0.015630183076219897, 0.030711187049746513, 0.022678643697872758, 0.03895471238398126, 0.03247868595644832, 0.06086953090769904, 0.05259138671681285, 0.12388605518000466, 0.08196952047624759, 0.023794156964868307, 0.024111236379082714, 0.0522418970774327, 0.005693201848771423, 0.041391911783388684, 0.0387438406635608, 0.09598564516220774, 0.032376858206199746, 0.05024517547073109, 0.018849845310407023, 0.003958276439724224, 0.0362430727109313, 0.03103451577148267, 0.07914416172674724, 0.010939793644606002, 0.014696873425106918, 0.018094199875901853, 0.02120186820892351, 0.025323854792597036, 0.02870802614571793, 0.06602674988763672, 0.019739796573828374, 0.009674837280597006, 0.018546049915520207, 0.031637553591281176, 0.014456249640456267, 0.03481156059673854, 0.0493859940740679, 0.04420676341812525, 0.05241780049566712, 0.01634604430624417, 0.06121312068509204, 0.010868218378163874, 0.039408421609550714, 0.15874815306493215, 0.1552241678748812, 0.10239065611468894, 0.09821756396974836, 0.11875698183264051, 0.07600917387753725, 0.160438153094479, 0.13070348650217056, 0.23674423354012625, 0.13621992192098073, 0.15987385623157024, 0.213908476755023, 0.12885734199413232, 0.07981321082583495, 0.14537015663725988, 0.18981960149747984, 0.11800417437085084, 0.11248057362224374, 0.10725165384688548, 0.09930664660143, 0.07541658210435084, 0.12020627834967204, 0.0689755884398307, 0.13040160627237388, 0.13000384904444218, 0.14744230758930954, 0.11609363688954286, 0.1308618972876242, 0.18735452448683126, 0.12741879347179616, 0.16191474028996058, 0.12622914516500064, 0.19489150148417267, 0.114248998729246, 0.16270479932427406, 0.1387117196406637, 0.19220092014542647, 0.09795271818126951, 0.19661770814231463, 0.14276668562420777, 0.17606234470648424, 0.11268799499209438, 0.14022193503166946, 0.18959504711840833, 0.15754079499414989, 0.09437361559165375, 0.10791807701545102, 0.11663380504718848, 0.10125781475965466, 0.1304506372128214, 0.1063482862498079, 0.13305622525513172, 0.16145374359829084, 0.13454176911285945, 0.15697461180388927, 0.1502386996788638, 0.13466471965823854, 0.09029310276465756, 0.1259978732892445, 0.057553191004054885, 0.08308079120303903, 0.09607749844768218, 0.1062505364950214, 0.10398960353008338, 0.05568490929103323, 0.10368994210979768, 0.10663848210658346, 0.16615923467491353, 0.09842140946005072, 0.12101787408547741, 0.11327336036733218, 0.10174722171255521, 0.13858150877058506, 0.10758269751178366, 0.09438060450234584, 0.1035260216199926, 0.1930889460657324, 0.12391683352845055, 0.16694264406604425, 0.08231733752680676, 0.18663408314543112, 0.10503946005233697, 0.13949880669159548, 0.13089878245123795, 0.11924522849065916, 0.1256546974182129, 0.09510720015636512, 0.13542173403714383, 0.16932945884764194, 0.13249789950038704, 0.14582135528326035, 0.1662891334188836, 0.14810497845922196, 0.09560069189007793, 0.09081704715000731, 0.22686892987361976, 0.20744061310376438, 0.10168519682650055, 0.1267331066940512, 0.136310750618577, 0.10180611855217389, 0.1642900335469416, 0.12271341096077647, 0.10472117284578936, 0.11076768660651785, 0.16695202142000198, 0.11946060907627855, 0.18445932412786142, 0.07082687624331031, 0.1195590780781848, 0.10153244502310242, 0.16186505795589515, 0.10659903886594943, 0.3047423990709441, 0.2159873859158584, 0.11845959350466728, 0.15678471699357033, 0.16718694381415844, 0.11933024892849581, 0.0861154847911426, 0.15581561970923627, 0.08834686755601849, 0.11310228133308035, 0.10089612166796412, 0.09823147393763065, 0.12370050299380507, 0.14307071002466337, 0.1305561086961201, 0.11800918195928846, 0.130950269688453, 0.14897070771881513, 0.08257554045745305, 0.08837996649422816, 0.07939910090395383, 0.12295830781970706, 0.09630288742482662, 0.12747192276375635, 0.0792718959440078, 0.12931828440300056, 0.08614569995552301, 0.21409955221627439, 0.2142729993377413, 0.12316131192658629, 0.12215477307992322, 0.13295790553092957, 0.1568643091512578, 0.09175073847706829, 0.11581249268991606, 0.23881577381065913, 0.170610709381955, 0.08151531592011452, 0.17739662953785487, 0.15302967705896922, 0.13049121360693658, 0.1639190920229469, 0.10636207408138684, 0.1301559494542224, 0.10848879960498639, 0.17957225708024843, 0.13605522790125438, 0.11184920357274157, 0.11943947949579783, 0.19628939218819141, 0.11876639989869935, 0.1111573896237782, 0.1900892106017896, 0.1059029840731195, 0.06150164056037154, 0.19123733256544384, 0.11338145778115306, 0.08815807875777994, 0.160668692152415, 0.06348607729056052, 0.12319472299090453, 0.15156169368752412, 0.16258259516741547], [0.013156832179187663, 0.03787740233487316, 0.014297735378412264, 0.014573687088808842, 0.02889546805194446, 0.028394252893381884, 0.029433390258678367, 0.029573182043220316, 0.048891094380191395, 0.020074855469699417, 0.03368656649919493, 0.03809831298089453, 0.04500976890059454, 0.026824704704007933, 0.03742448699527553, 0.052248472081763406, 0.07014082984200545, 0.028617601176457744, 0.03506850823760033, 0.09184489199625594, 0.05589235440960952, 0.037972746683018546, 0.03013936523348093, 0.020267963143331662, 0.0282362051241632, 0.058216900032545836, 0.05632521225405591, 0.011244695051573217, 0.018543727629418885, 0.03904498129018715, 0.06580739987215825, 0.0106508386587458, 0.009732887647779924, 0.006121682294178754, 0.03103158450020211, 0.025098223239183426, 0.08620748056897096, 0.02401087256813688, 0.008019039656833878, 0.03759247190984232, 0.028342920022883585, 0.019970959883981516, 0.009262596722692251, 0.04921750704358731, 0.06210582171167646, 0.005773153205934379, 0.01745484346923019, 0.053624205224748166, 0.04152075879807983, 0.03323179536632129, 0.032697506714612246, 0.12811839021742344, 0.030416502683822597, 0.03707649691828659, 0.021745910801525627, 0.055705014283635786, 0.01820361364765891, 0.018954714593876685, 0.04292448151058384, 0.0195977079482483, 0.037371561263820956, 0.029366340820810626, 0.03874994069337845, 0.03101468219288758, 0.0392961715614157, 0.08286148189966168, 0.004350499366410077, 0.029328733017402034, 0.04701706547556179, 0.03569474856236151, 0.04425832190151725, 0.047710290777363946, 0.005235516832077077, 0.09809408416705472, 0.01775975844689778, 0.03435868936191712, 0.03020622468154345, 0.048049307228731256, 0.019300635139058744, 0.051460428296455314, 0.029285493373338665, 0.020093121632401432, 0.04772103537938424, 0.046219423812414916, 0.03864728852308222, 0.012385533789971044, 0.04070488829165697, 0.0342935873195529, 0.010425866132469049, 0.0399289868905076, 0.020490127382799983, 0.0324191512939121, 0.04373491695150733, 0.025462542261396135, 0.01924811483227781, 0.02608702009144638, 0.018824286592592086, 0.02919676134895001, 0.028017062061865414, 0.01614322679649506, 0.052931482038859806, 0.05337309298504676, 0.03857259878090449, 0.03906010922842792, 0.03966650579656873, 0.058167774097195694, 0.003977727918286941, 0.024175953352823853, 0.041429122643811364, 0.04172942867236478, 0.033146673148231845, 0.05003791016393474, 0.11087096642170634, 0.018224400567955205, 0.0647676195949316, 0.027584166897993003, 0.02134394326380321, 0.018361211887427738, 0.03112352599522897, 0.026298329466953874, 0.028234301833435893, 0.032261151022144725, 0.04467235379187124, 0.05308539752981492, 0.059014572229768546, 0.03767389611208013, 0.03923104237765074, 0.024108462867193987, 0.016485184697168212, 0.09179224446415901, 0.04229654484827604, 0.010806280853492873, 0.0744279972942812, 0.06862474512308836, 0.030468329188546965, 0.021040086800764714, 0.011536136868276765, 0.008396362802678985, 0.052096595588539324, 0.01926778725880597, 0.06455479708633252, 0.01647030103153416, 0.011770873513471867, 0.01878065848723054, 0.026585856984768595, 0.011510075186379254, 0.03384359646588564, 0.04409372626936861, 0.014837945944496563, 0.06785326437758547, 0.07008907119078295, 0.04045382354940687, 0.017822991125285625, 0.03809172101318836, 0.0359731786219137, 0.011133073496499231, 0.03231848383854542, 0.09248242314372744, 0.012320434292113143, 0.019889705315498368, 0.029887618563537086, 0.03173677237438304, 0.020571711040767174, 0.020871918681742888, 0.03166915635977473, 0.045419359779251475, 0.08331064494060618, 0.08431238654468741, 0.05452206311747432, 0.021271251807255403, 0.050992066107158146, 0.03477865504100919, 0.012208071437531283, 0.027826503983565738, 0.04259018087759614, 0.03756044505696211, 0.029660227908087627, 0.021734396062259163, 0.05837068320917232, 0.030947829530175244, 0.014569805868502175, 0.013022655271925032, 0.05657973413222602, 0.038588228835059066, 0.03258781135082245, 0.024104301751192127, 0.04608734357835991, 0.042200155556201935, 0.02151913082759295, 0.027025445896599973, 0.007168545204746936, 0.02450334989199681, 0.02769024736647095, 0.03327861428260803, 0.03703479076336537, 0.03862558897318585, 0.015814615679638724, 0.018244822775678973, 0.025793748774698803, 0.06529903465083667, 0.03381109463849238, 0.04903633140825799, 0.09846149052360229, 0.026962018139394264, 0.010298091203107365, 0.04831393588600414, 0.04112307620900018, 0.04748801288328, 0.009600510554654258, 0.023134546287889992, 0.03092613337295396, 0.05904473311134747, 0.04036100335153086, 0.04178344005984919, 0.08207817428878375, 0.014683601280142154, 0.01119064210381891, 0.012529114344423371, 0.035553514890904934, 0.06706995676670756, 0.10017724095710687, 0.017503940566842045, 0.03273075493052602, 0.02752092743425497, 0.053445886221847365, 0.01400928505297218, 0.008791332099852818, 0.03483668674847909, 0.05141829466447234, 0.027069742358954887, 0.0323936994453626, 0.04337926621415785, 0.024400697721700584, 0.04418458889371582, 0.04110829771629401, 0.01719140903359013, 0.032307749414550405, 0.06941527913191489, 0.02169434892545853, 0.050640666391700506, 0.035740237550011704, 0.03743699239566922, 0.006264667858236602, 0.01076971969035055, 0.031293536336826425, 0.02956436787332807, 0.035202766569065194, 0.09040544102234499, 0.03501788613253406, 0.045289583171584775, 0.013666518847458065, 0.03728959084089313, 0.06079861721290009, 0.04242780405495848, 0.01907391962595284, 0.02504245444600071, 0.07042785694024392, 0.01089180340724332, 0.05017105909064412, 0.041178889106959105, 0.011276235055577542, 0.018569070912365402, 0.049722011400652785, 0.10840479696967772, 0.023015332774126103, 0.02610552543774247, 0.029411371797323227, 0.015633273803229843, 0.015583058819174767, 0.04447856419054525, 0.019180383466716324, 0.020777171444413916, 0.016406973358243704, 0.01565612686265792, 0.03470725280099681, 0.036120285013956685, 0.070165155322424, 0.03296091740152665, 0.012064841176782335, 0.04555161303973623, 0.031517897333417616, 0.021094846273107187, 0.03473614142941577, 0.037235501421881576, 0.05042637146211096, 0.07660478513155665, 0.022843044251203537, 0.06929884252271482, 0.08449866476335696, 0.023564774809139113, 0.03582806033747537, 0.027452853408509066, 0.01656219842178481, 0.06538440792688302, 0.057480472406106334, 0.026844260083245378, 0.013081686970378672, 0.044990820810198784, 0.05920500986810241, 0.05588090752384492, 0.012866335222497582, 0.005564372221540127, 0.03302788541519216, 0.016670809825882316, 0.011913268327979105, 0.030447501556149552, 0.035815609219883165, 0.004837868169748357, 0.06319832415985209, 0.03388057662440198, 0.021572648580851297, 0.01535385986790061, 0.02294243436439761, 0.07253839940364872, 0.07037412375211716, 0.03077618052650775, 0.030956799763121774, 0.040054804246340475, 0.03703770846394556, 0.05854354679052319, 0.05009562974529607, 0.03159097894760115, 0.029021373617329767, 0.038734442953552516, 0.04291982676035591, 0.028678119714770998, 0.04756550158240965, 0.020842219203976647, 0.08963032332914216, 0.08849081876022474, 0.016000725960891162, 0.0011167297530586698, 0.03344789859173553, 0.03303140022658876, 0.04233171671096768, 0.04828649592985, 0.043908927257039716, 0.08245782141706773, 0.018633614859676788, 0.03506128183965172, 0.040960109060896296, 0.01746501131648464, 0.031769983270870786, 0.0848304887435266, 0.0731141838644232, 0.03689642729503768, 0.03950485161372593, 0.05532646638208202, 0.03724304673128894, 0.013200351718946226, 0.009895941309098686, 0.03518200679016965, 0.11105112425450768, 0.11457644615854536, 0.14456937674965176, 0.13511552475392818, 0.1245938486286572, 0.09651810516204153, 0.12408924927668911, 0.1108697314879724, 0.11916376357632023, 0.08102721853979997, 0.13461019258413995, 0.1263150612690619, 0.18821293913892337, 0.07137121739132063, 0.2127630825021437, 0.20021327877683298, 0.1330012096358197, 0.09402298940611736, 0.08712566058550562, 0.14964043535292149, 0.11972443706222943, 0.14956864634794848, 0.15130809800965445, 0.15315914154052734, 0.12449476894523416, 0.18051947839558125, 0.10449018595474106, 0.05213356896170548, 0.12288605741092137, 0.16487858125141688, 0.11720175242849759, 0.14164551507149423, 0.11057557977203812, 0.13516834191977978, 0.07636756928903715, 0.15693612529763154, 0.15875782897429808, 0.12165093368717603, 0.1322739693735327, 0.09911672464971032, 0.09598843394113438, 0.049068646638521125, 0.08694680553994008, 0.10086287345205035, 0.15865420310625009, 0.17508338152297906, 0.11597094418747084, 0.151938172057271, 0.10858270885156733, 0.15006864523249014, 0.12528865491705282, 0.17548554922853196, 0.20130728078739984, 0.11486981755920819, 0.10192951693066529, 0.1254173865807908, 0.12786582591278212, 0.13630453523780617, 0.10251189675182104, 0.05518217930304153, 0.11659869764532362, 0.17302816680499486, 0.19452896022370883, 0.27344450993197306, 0.1305099276027509, 0.21155965993446962, 0.09298802672752313, 0.12365149919475828, 0.16727424412965775, 0.08000457805714437, 0.09416427396770034, 0.11411858429866177, 0.08064417195107255, 0.19299722170191153, 0.05187243136710354, 0.09295383534793343, 0.14893387683800288, 0.13125206849404744, 0.09336199451770101, 0.11614046937652997, 0.1596643246178116, 0.14884037471243314, 0.13476468143718584, 0.10603751721126692, 0.11930914648941585, 0.17183098675949232, 0.08810024043279034, 0.1871538002576147, 0.10837145375886134, 0.09317779940153871, 0.09648174247039215, 0.08947530521878175, 0.08918716532311269, 0.1263278584395136, 0.13125014145459446, 0.09605260299784796, 0.07571810271058764, 0.10466152283229999, 0.09983836699809347, 0.15057648798184736, 0.1330048330128193, 0.12148459761270455, 0.09138647373765707, 0.16602438262530736, 0.09776654174285275, 0.21533050973500523, 0.06469651591032743, 0.2670053211706025, 0.17422848168228353, 0.18508774255003246, 0.045958577987871, 0.15353639344019548, 0.18320593424141407, 0.14890286778765066, 0.18067376368812152, 0.07281360642186233, 0.12642448182616914, 0.11393299140036106, 0.21238566775407108, 0.07869602327368089, 0.14778343428458485, 0.16584079819066183, 0.10423972510865756, 0.1537762148571866, 0.1414939710604293, 0.19430412085992949, 0.1040694128189768, 0.17048557395381586, 0.08596948441118002, 0.18389533939106123, 0.17564968684954302, 0.040981689867164404, 0.18769687254514011, 0.13320371162678513, 0.1285402082971164, 0.06759525143674441, 0.0755423146433064, 0.1613446351672922, 0.17776017503014632, 0.059199703724256585, 0.07974438023354326, 0.13644287495740823, 0.19451492811952317, 0.14221464310373577, 0.12830441737813608, 0.10076151389096465, 0.08415983830179487, 0.13770598146532262, 0.10069408786616155, 0.09877411196274416, 0.14378653732793673, 0.15084355936518737, 0.08637972668345485, 0.14141454175114632, 0.08269893883594445, 0.08867964148521423, 0.08870468621275254, 0.1152160604085241, 0.11275763982640845, 0.11461193354002067, 0.11748467438987323, 0.14519532530435494, 0.12903278400855406, 0.07138443525348391, 0.07371103005217654, 0.13203342870942184, 0.21334772184491158, 0.135621861155544, 0.10839518891381365, 0.13450766594282218, 0.19518872696374143, 0.10805361438542604, 0.14655065829200403, 0.10040244672979627, 0.1838984199400459, 0.13510325684079103], [0.04384476159300123, 0.015039872877033693, 0.04095343227631279, 0.01036881236359477, 0.031023760991437093, 0.06698925181158952, 0.042904810780393224, 0.055208028094576936, 0.049203281556921344, 0.08066431087042604, 0.013373360337157334, 0.044719898740627935, 0.030657328332641294, 0.024292630841955543, 0.0538924742223961, 0.021750411185036813, 0.016649262946365134, 0.057342811221522946, 0.03498722652771643, 0.053314423454659324, 0.019936627708375454, 0.025769762561789582, 0.04046834759148104, 0.017488539518256272, 0.03428005733128105, 0.024252714323146, 0.017445172648876905, 0.07268434550080981, 0.03822986735031009, 0.01576048554852605, 0.04294467132006373, 0.06406338845512696, 0.04396106928054776, 0.034402665216475725, 0.03610476013273001, 0.11203787023467676, 0.04092196182214788, 0.040328141900577714, 0.06549976566540343, 0.0510863214065986, 0.016529140195676258, 0.02110384195111692, 0.022506926840703403, 0.05084111920690962, 0.11046962652887617, 0.009697323082946241, 0.04576904280111194, 0.008560610685630568, 0.03303751043443169, 0.04517418472096324, 0.03226098817374025, 0.025056138800989305, 0.10340284037270717, 0.03685754384579403, 0.08125595269458634, 0.05426964469786201, 0.045621861770216904, 0.03655906307644077, 0.03250456528205957, 0.017215128921504532, 0.022053750265123587, 0.0141371922966625, 0.020495402992569973, 0.06357472789074693, 0.05527005637330668, 0.03556703130847641, 0.0270391132882131, 0.04571062772135649, 0.06127796149147408, 0.01945405190677515, 0.008515600065168525, 0.05528049224189349, 0.016432269143738916, 0.08447319255875689, 0.01046387427153864, 0.0122974370439936, 0.05039295700511762, 0.03104577266744205, 0.02683595651095467, 0.03163012024015188, 0.006501904056806649, 0.03764335525089076, 0.04681914698864732, 0.047961677823747904, 0.059419236944190094, 0.023245361234460558, 0.011135119279580457, 0.02888902536194239, 0.04310174539153065, 0.014962353643828204, 0.036810009075062614, 0.01114877310049321, 0.009478802576528063, 0.08123794437519141, 0.013877596672890442, 0.03343905388776745, 0.0763061008016978, 0.010315238631197383, 0.03213981878278511, 0.014615686710125633, 0.009252663818188012, 0.020770009507292082, 0.02043207023026688, 0.019271536164784005, 0.0027456781702182654, 0.05350052186154893, 0.021811928866165023, 0.07537390225167785, 0.023027074822623814, 0.06808028183877468, 0.04928709759509989, 0.036811942899865766, 0.052037281449884176, 0.015546577383897133, 0.04862871506650533, 0.06095294321754149, 0.03425033749746425, 0.0379925497275378, 0.023628236493095756, 0.053610084911010096, 0.11973017746848719, 0.04199091571250132, 0.017297825376902307, 0.0309751609207264, 0.052899774097438367, 0.023252065160444806, 0.022459811065346003, 0.014222872609804784, 0.0565968128586454, 0.033732893477593145, 0.09013734505112682, 0.030348011359040226, 0.05069415530722056, 0.01610344598468925, 0.03730418952181935, 0.051810803424034796, 0.00800869963131845, 0.026522958484877433, 0.015939291400302733, 0.014123627533470946, 0.06339771846043211, 0.021057786386726157, 0.04614000128848212, 0.022282816902069107, 0.023409758395116245, 0.026607846608385444, 0.09311226648943764, 0.024275781121104956, 0.03740965761244297, 0.006199226548363055, 0.0043186328174280265, 0.015240349440968462, 0.03347617653863771, 0.01910552239444639, 0.013553399426330413, 0.014236585802531667, 0.02719340706244111, 0.06640862939613205, 0.025357011406283294, 0.015184348249541861, 0.030144980110760247, 0.030621664532061135, 0.030864797199943235, 0.02874512504786253, 0.004690403850483043, 0.043975430474217446, 0.029328804263578992, 0.011475661586570953, 0.013681964848988822, 0.01296943861858121, 0.041622352453746965, 0.004736659158619919, 0.05841251489307199, 0.037603328470140696, 0.03443526203877159, 0.06713049566107136, 0.04581953937719975, 0.03935841018600123, 0.048212454188615084, 0.04656638251617551, 0.1038811532780528, 0.018561328827802624, 0.04989603866956063, 0.055520910769701004, 0.013351970368863215, 0.009011382702738047, 0.029367965912180286, 0.010317387890868952, 0.00671309680910781, 0.05157506339518087, 0.05413016164675355, 0.019459522595363002, 0.03715187876618334, 0.06542386473821742, 0.006261951173655689, 0.07179578353783914, 0.01235536442670439, 0.020707864181271622, 0.04162436431007726, 0.08615658365722213, 0.017811322019302418, 0.03623219579458237, 0.049793339001813104, 0.05917252839675971, 0.026696970486747365, 0.02728975733875164, 0.0025083518537160543, 0.02315201347560755, 0.037675202291991026, 0.013300506032205053, 0.022529664549178312, 0.1061025887195553, 0.06264018160956246, 0.00625619719669755, 0.0383377951303763, 0.0591316195204854, 0.0037599050306848115, 0.059476009969200404, 0.03825334805463042, 0.044548086888555966, 0.05703016264098031, 0.006994062045123428, 0.035427090246230364, 0.035644547149006806, 0.03414454710270677, 0.07254871992128235, 0.031163542597953762, 0.041384183269526274, 0.1056126050118889, 0.04131909819053752, 0.06276773940771818, 0.033590397731001885, 0.026736965037084053, 0.027613242123542086, 0.014811695120962603, 0.02789715474604496, 0.04067664087883063, 0.03718836020146098, 0.05968337705624955, 0.018390799406915903, 0.044264391397259066, 0.08956675816859518, 0.022147618799603412, 0.026218004491446272, 0.05016912187316588, 0.013291435715343271, 0.026931270325024213, 0.030514394930963005, 0.1022540263033339, 0.04066681569176061, 0.014108459731297833, 0.018145154463127255, 0.0035586167692339844, 0.03982198531074183, 0.021782694184886556, 0.06198603313948427, 0.0030973834384764943, 0.057548848379935534, 0.01734633554172303, 0.05697421742869275, 0.011643180856481194, 0.02489478317355471, 0.0364745583252183, 0.03576311435816543, 0.0265752362153892, 0.020384952758571932, 0.02597258346421378, 0.09322835026042801, 0.06576120520808867, 0.034445989677416425, 0.0400673944636115, 0.022591663990169764, 0.07239347789436579, 0.025997275353542397, 0.05907815774636609, 0.0569998456963471, 0.0233575943192201, 0.024958592606708407, 0.018324197802160467, 0.02393295639194548, 0.009654747555032372, 0.05396573904103466, 0.06565950637949364, 0.041399765826229534, 0.0217381415755621, 0.015300469339958258, 0.07620101608335972, 0.018686314978237663, 0.00631136166962928, 0.05839287130428212, 0.049658924607293944, 0.021045703374381577, 0.035870051477104425, 0.0414777498559228, 0.05462082388943859, 0.022555236837693622, 0.04819774354941078, 0.01862869887346668, 0.02270858914458326, 0.016337627079337835, 0.038605192210525274, 0.0635491403351937, 0.029277571476995945, 0.03573501283036811, 0.032062058669648, 0.014220576616935432, 0.021690460919801677, 0.0396431777626276, 0.050305235997906754, 0.032121796892689805, 0.022811972436362078, 0.03148142946884036, 0.01601852223809276, 0.03976854049999799, 0.03719835841496076, 0.004106448555830866, 0.01191429970120745, 0.011345397281859602, 0.11222060650054898, 0.024306903826072812, 0.047423239930399826, 0.06681732460856438, 0.04601331540782537, 0.02016712266153523, 0.016452642157673836, 0.015706151856907775, 0.03527779557875224, 0.021665400925225446, 0.010414532901320075, 0.032239845022559166, 0.04677356639876962, 0.017684827824788432, 0.029198545896049057, 0.01551063368762178, 0.03670370638636606, 0.05100069028724517, 0.03591768802808864, 0.040766818182809014, 0.02876080938481859, 0.04123405400397522, 0.032289832697382996, 0.023361663832994442, 0.05461302073672414, 0.02150043549149164, 0.028225621674209833, 0.01500370356786464, 0.042961200433118005, 0.017319499481735483, 0.05052146814497454, 0.031241356993892362, 0.009084638191520103, 0.030840047635138035, 0.11595482219542776, 0.11621981726161071, 0.13403239287436008, 0.1780604132051979, 0.20167079913829053, 0.09582061187497207, 0.09004642135862793, 0.16576051392725535, 0.1471481490880251, 0.13902692629822663, 0.12817208947879927, 0.12644052239401, 0.08663383804793869, 0.1273951804531472, 0.11855306848883629, 0.08196190052798816, 0.08754921571484633, 0.1687433131571327, 0.10239232531083481, 0.11007181501814298, 0.09968271106481552, 0.11567290446587972, 0.1391596341771739, 0.14145009698612349, 0.08939852898142167, 0.060050430574587414, 0.15434413509709494, 0.13718371306146893, 0.09649967615093503, 0.0970268775043743, 0.10769641998090915, 0.10695463192782231, 0.10120912987206664, 0.08625088645411388, 0.10018458270600863, 0.16153119158531937, 0.12414529626922947, 0.09288579864161355, 0.128253147272127, 0.12151346249239785, 0.07771597443414585, 0.12091168335505895, 0.11492722162178584, 0.0886948745963829, 0.19087589053171022, 0.1406224335410765, 0.0880166245624423, 0.15915855818561145, 0.12259523730192866, 0.1959044457014118, 0.12195604374366147, 0.09411339741200209, 0.18346740092550004, 0.13059599298451627, 0.1534562720251935, 0.15095582976937294, 0.09906007376100336, 0.10495800192334823, 0.08446800855121442, 0.25738589305962833, 0.08924485437039818, 0.09008319117128849, 0.13312266740415776, 0.07926859147846699, 0.12290611490607262, 0.11764527005808693, 0.16025992908648082, 0.09037344131086554, 0.18552452911223682, 0.0491876379320664, 0.12253851177436964, 0.10814749649060623, 0.11670089858983244, 0.11423240176268987, 0.1352263702345746, 0.09305400068738631, 0.060575216343360286, 0.09905385159488235, 0.15109750788126672, 0.13670721862997326, 0.13603913305061205, 0.13966058301074163, 0.15286388381251267, 0.15023321711591311, 0.12149219720491342, 0.1377571022936276, 0.09898624236562423, 0.0746099871716329, 0.1250428623918976, 0.10020228568464518, 0.11282744072377682, 0.174980189917343, 0.08731949089893273, 0.1396987573908908, 0.07748181878456048, 0.08988623281142541, 0.1345905964928014, 0.15682688115962914, 0.1835284283650773, 0.08760725760034152, 0.18360560493809835, 0.06414587795734406, 0.07422892190515995, 0.07196722219565085, 0.09712275450250932, 0.10858194889234644, 0.17358175638530934, 0.22629543207585812, 0.10452248422162873, 0.17852995943810257, 0.08867963469986405, 0.08013683810297932, 0.10818132824663605, 0.17867068760097027, 0.24661591382963316, 0.13292077609470912, 0.14008314747895512, 0.11500243044325284, 0.13406231626868248, 0.08929324748792819, 0.18613921398563044, 0.10255898029676505, 0.06334755436650344, 0.060398240839796405, 0.13988900503941945, 0.14511624883328164, 0.11432940512895584, 0.11284523869731597, 0.12810883644436086, 0.07659606595656701, 0.21876927092671394, 0.12127210758626461, 0.15488081558474473, 0.15397735977811472, 0.08928961732557841, 0.13028267265430518, 0.09654404555580445, 0.12459615564772061, 0.12180117491100516, 0.08264521921851806, 0.11931988091341086, 0.17731186694332532, 0.14219458560858453, 0.09156989532389812, 0.1468326167336532, 0.09079694215740476, 0.21121906249650887, 0.09137542718755347, 0.10630380149398531, 0.1469385360500642, 0.10199739757393088, 0.06239098962396383, 0.11946176258581025, 0.10105410497635603, 0.1378173562032836, 0.10948912985622883, 0.11949821348701205, 0.11303901472794158, 0.07557666208595037, 0.06672680803707667, 0.14936242598508084, 0.141086768625038, 0.12511731125414371, 0.15899573692253657, 0.11768774635025434, 0.10823313439530985, 0.1543650882584708, 0.06917078939399549, 0.1446985833879028, 0.18615057266184262, 0.09774007887712546, 0.12964349266673836, 0.12311922918472971, 0.10956802312284708, 0.1595878265798092, 0.13160314251269611], [0.031268393221710405, 0.02377486282161304, 0.02100818038785032, 0.055734347352491956, 0.03705837664061359, 0.020961393701976964, 0.07203157445681946, 0.011670025398156472, 0.01212653866969049, 0.013558739496927177, 0.01996265461535326, 0.06784962742988553, 0.031158389124487127, 0.03489196699644838, 0.04414892170046057, 0.04200114123523235, 0.023813300134081925, 0.030446158056812625, 0.02415746496990323, 0.0299878687198673, 0.04877704282158187, 0.04875826436494078, 0.011049831668580217, 0.024949330603703856, 0.05057979501517756, 0.0708062487787434, 0.023455257560791712, 0.052927950264087746, 0.051705026599977694, 0.02457311686261424, 0.05572615743481687, 0.048063505573996475, 0.06441145656364304, 0.025512879381754568, 0.003968493904851909, 0.07940628658980131, 0.05719603052628892, 0.05241598541449223, 0.015556363555203592, 0.0406770106804158, 0.032450587821326086, 0.03412324110312121, 0.033741253029022894, 0.023512352889935886, 0.04785215548638787, 0.022582549568531767, 0.04469050121094499, 0.0247749538892614, 0.0062373470697951105, 0.014622689191518086, 0.036036187383745394, 0.007203739119826683, 0.02173724421299994, 0.02793730535943593, 0.024618648258703094, 0.054254693178726096, 0.01596822582983545, 0.029990084136703184, 0.013958477198944559, 0.02918770969180124, 0.06702790116625172, 0.02129920236101108, 0.039387281851044724, 0.05094226163678935, 0.02043429243245295, 0.015029089259249824, 0.035673038834439855, 0.022644954434196864, 0.09299617593309709, 0.07153609461550202, 0.06977891283375875, 0.029660655385149375, 0.02694289362989366, 0.04560830803321941, 0.07958634264234986, 0.03229898613478456, 0.02340959893938686, 0.004813950658509774, 0.04158788626747472, 0.010384712983588023, 0.03292196270610605, 0.022491371425400888, 0.039474622878645144, 0.009668873805951859, 0.028529635896640163, 0.015061553767217057, 0.025828420217814188, 0.04368775198236108, 0.04897221663434591, 0.06175840499677828, 0.03454148330326591, 0.044596669995891194, 0.03232231416872569, 0.040775011493159194, 0.03457483329943248, 0.01248311560734042, 0.03813842797119703, 0.04655318840273789, 0.024159290229103396, 0.0223242126272193, 0.042029839873846085, 0.05124295103762831, 0.033519009061689885, 0.057425829981054576, 0.034819129654871564, 0.05210546404123306, 0.03608643290187631, 0.0109877134839605, 0.026080903098253266, 0.012760005392400282, 0.03866592788004449, 0.030402938768799816, 0.10096017537372452, 0.02606734766491822, 0.0456508318228381, 0.02253059414215386, 0.03767289188025253, 0.02702546794898808, 0.06065848616084882, 0.04536114826000162, 0.06127319139029298, 0.02683816514244037, 0.034227053568299325, 0.05206975613587669, 0.021659551953364695, 0.01816096093638667, 0.01614980349716331, 0.03010012555335249, 0.022828355664387345, 0.03296411669413958, 0.020202543885846223, 0.05565780860238841, 0.03368013059454305, 0.024882220097684433, 0.02172619427022125, 0.008386536767440183, 0.045601997657545974, 0.024669399285422902, 0.02168710556413446, 0.036022124745483906, 0.014655175751873424, 0.013378939591348171, 0.043457094180796824, 0.04298435204795428, 0.030961447727999518, 0.05211157424907599, 0.02602207411213645, 0.04511269587757332, 0.03513818360599024, 0.08128388119595391, 0.02481177798472345, 0.018859862183619822, 0.009447500059780265, 0.0516155108676425, 0.035597120943878374, 0.027105876045035462, 0.05717181361147335, 0.11305998146001782, 0.06311082706919738, 0.035140680614858866, 0.028252277922417437, 0.010435112020266908, 0.03196844458580017, 0.019347250494839888, 0.08061107301286288, 0.09625815839639731, 0.0877362403220364, 0.03579265438020229, 0.04475470419440951, 0.04868931842169591, 0.01651121669315866, 0.048418426886200905, 0.0492365908409868, 0.0184672601254923, 0.01691562356427312, 0.031039197663111345, 0.027707120836047188, 0.03613375732675195, 0.05317343744848456, 0.092438162304461, 0.02396748025369431, 0.011663957598752208, 0.02781469068889107, 0.0508834021165967, 0.023969687188842466, 0.029517596454492638, 0.038272214720823934, 0.044027195910790136, 0.022740646531539302, 0.01927438940453742, 0.0472019051999918, 0.021309387171640992, 0.032493963172393184, 0.016304770717397332, 0.046683239817087135, 0.03956016578844615, 0.03042334910216076, 0.007776810288695353, 0.06243797138865505, 0.05416713162724461, 0.03521897677066071, 0.03900751597913248, 0.06264561667506184, 0.05195432036582913, 0.06733849378568785, 0.02957056968339852, 0.04782754841393658, 0.03684431580560548, 0.018105565337464213, 0.039561410900205374, 0.06067987358463662, 0.10720302324209895, 0.026983610820025206, 0.06556025706231594, 0.022058927487315874, 0.024713746637904217, 0.016372496993946176, 0.009273983388473945, 0.012252064255465354, 0.053761778199779134, 0.017473552376031876, 0.04103397438302636, 0.03925931014652763, 0.05842124085341181, 0.018596556669633304, 0.032844718279583116, 0.007078680875045913, 0.006439009373674968, 0.030959544437272207, 0.016137522013325776, 0.0879407711327076, 0.022725549127374376, 0.028104509958731275, 0.03736800913299833, 0.08605312063757863, 0.02330488062995885, 0.01895967298852546, 0.030650420846151452, 0.06497314106673002, 0.0068960646250551295, 0.009981042322968798, 0.04280377013076629, 0.0067420087621680325, 0.037342899944633245, 0.07106835328574691, 0.01796183635347656, 0.01117032761352935, 0.11295613846076386, 0.0230875509524984, 0.050963930652609894, 0.04991644900292158, 0.021308064028354626, 0.04832721820899418, 0.028579029853322675, 0.019164368343938674, 0.023444060036646466, 0.053016953702483854, 0.046244397293776274, 0.06647585186042956, 0.026943750280354704, 0.009790481700162803, 0.023767368402332067, 0.018385988593633686, 0.0041091088371883544, 0.030278220639697144, 0.023865917132103016, 0.021021269328360046, 0.023531355263133134, 0.056563184663121185, 0.017982692823612263, 0.03173399716615677, 0.04457411209919623, 0.008528371790557035, 0.052695243286767175, 0.028822138772479126, 0.016675128701276014, 0.04241829438667212, 0.07219784946313926, 0.04237062730161207, 0.028525513796401874, 0.026854838444186107, 0.03234902809240988, 0.025721781654283404, 0.00841217690945736, 0.03869031442861472, 0.05469849918569837, 0.054879874988858185, 0.0717869150851454, 0.09853952205074684, 0.030098507247333015, 0.07577799699668374, 0.017851844130616103, 0.013217895241853381, 0.03520840858774526, 0.02448667828658862, 0.03312476325247969, 0.04134715561355863, 0.02051902110023158, 0.02463244796464486, 0.0036264333757571876, 0.021132920569341098, 0.02954129429001893, 0.016455563250929117, 0.025175974870632802, 0.01615560836424785, 0.017485732079616616, 0.014237444149330258, 0.012579951884358056, 0.08454350235738925, 0.042843260868851624, 0.020866412370066558, 0.022443166601338556, 0.02369214770650225, 0.02076012664474547, 0.020816239794450145, 0.021891624500442828, 0.004704861311308507, 0.02763064654677042, 0.01871812978892454, 0.026706870312669446, 0.01637873612344265, 0.01386737878367837, 0.03345197319452252, 0.038990515284240246, 0.06305376227412905, 0.03815279255754181, 0.00320340008225425, 0.031826868254159174, 0.038277510686644485, 0.0031002248038670844, 0.0480077673148896, 0.050623302680573294, 0.07950951890753848, 0.08606852338250194, 0.053706609910087924, 0.02105666510760784, 0.01801598853697734, 0.02596671922531511, 0.012784204495671605, 0.05729681333260877, 0.06907756546778338, 0.029380176149840866, 0.0048960461863316596, 0.025428467929097157, 0.01978738053834864, 0.008554474184555667, 0.0382853375880846, 0.05697148971791778, 0.04074700156758938, 0.03104868358267205, 0.0713339861748474, 0.055194705059485774, 0.09015297849795648, 0.12788031942078046, 0.12633552588522434, 0.13029812968203, 0.12504415160843305, 0.04744567908346653, 0.16500411022986683, 0.1062036022277815, 0.1013223095131772, 0.12409180056835924, 0.10437835659831762, 0.17081680760851928, 0.13277246191033296, 0.18980642434741768, 0.10900325128542525, 0.11005658190697432, 0.08692558774990694, 0.14507758590791905, 0.11202556839478867, 0.1389561008129801, 0.1624219859285014, 0.1075867415804948, 0.19230360963514873, 0.12142519865717206, 0.08705882488616876, 0.10636969402964626, 0.13960896006652287, 0.1960038917937449, 0.1260160580277443, 0.1125424492305943, 0.21788068860769272, 0.1505821333932025, 0.25603332849485533, 0.17198774191950048, 0.09867398055004221, 0.16779491119086742, 0.09234775429857628, 0.18681408491517815, 0.16944859602621623, 0.09622673543968371, 0.1410618256777525, 0.17300897783466748, 0.09152786007949285, 0.12404019119484083, 0.1466202081314155, 0.09512334928980895, 0.1439942911799465, 0.09915479724960667, 0.07387477412287678, 0.09791702045393841, 0.14311249421111175, 0.08200004776673657, 0.12285108571606022, 0.10637355489390236, 0.1800545190594026, 0.10806664225778409, 0.1918441735740219, 0.0899992903162326, 0.16119052629385675, 0.12795661389827728, 0.10653558227100543, 0.1282409065003906, 0.20274994123194898, 0.15032411366701126, 0.09201867838523217, 0.08273383589195353, 0.09223618278545992, 0.11980237359447138, 0.11422732632075037, 0.11058867549789803, 0.07572376847799335, 0.21847170617963585, 0.12879620598895208, 0.1356067569660289, 0.1497487159711974, 0.12278118303843907, 0.15126307042581694, 0.12426733757768359, 0.09133546147495508, 0.10174528110240187, 0.12316602095961571, 0.10811570712498256, 0.09483202027955226, 0.10336634875940424, 0.0913507149421743, 0.1200662830046245, 0.09096124262682029, 0.10948921806578125, 0.1351511207010065, 0.20386360718735627, 0.11903094713177, 0.11009645941002028, 0.14692481607198715, 0.13372238379503998, 0.16573973718498433, 0.14277203248015471, 0.07465422086949859, 0.14138635540647165, 0.1067409748211503, 0.09595372687493052, 0.15676841858242238, 0.12973808044833796, 0.12225206143089704, 0.13241488752620562, 0.10003584782992091, 0.1386891651366438, 0.1460810170641967, 0.0807400353785072, 0.10907531170440571, 0.15846364333161286, 0.1941811703145504, 0.11424560605415277, 0.2357896976172924, 0.14023524788873537, 0.20315660083932535, 0.043180204395736964, 0.07743285569761481, 0.08917844614812306, 0.1355060895106622, 0.1238211736615215, 0.13342069355504854, 0.07890393318874495, 0.1241174763334649, 0.1342057450009244, 0.09352974194501128, 0.10912928237978901, 0.14099682202296598, 0.08037049842200109, 0.09304171920354877, 0.09847893565893173, 0.13304610151265348, 0.10729109708751951, 0.16227946643318447, 0.09270156959870032, 0.08820117930216448, 0.056513729638287, 0.1130145535405193, 0.05541167341704879, 0.11234992848975317, 0.037124265783599446, 0.061266161767499785, 0.10915812011808157, 0.19889294462544577, 0.09914689231663942, 0.04913490219041705, 0.12235491376902376, 0.08997775361474071, 0.12614901017929825, 0.10120897380901234, 0.18849694675632886, 0.08642400787877184, 0.0853397428457226, 0.14973454816000803, 0.15092613707695687, 0.15467224749071257, 0.1835792234965733, 0.13987514935433865, 0.16460232250392437, 0.1114411393978766, 0.1116883432758706, 0.07294258914355721, 0.09432637598365545, 0.07317890253450189, 0.14247201143630914, 0.12983907360051358, 0.19641649536788464, 0.1629280373454094, 0.09001274566565241, 0.09745744190045766, 0.09288514046264545, 0.155706524848938, 0.10160661568599087, 0.11996036368821349, 0.14797632821968623, 0.1916875812624182, 0.10397685385708298], [0.02501872946907367, 0.007174506134885762, 0.04905376297288707, 0.02995039662346244, 0.028466861229389906, 0.01084153922939939, 0.09096730872988701, 0.011691124444561345, 0.010943601074229394, 0.03226976163153138, 0.01834911191170769, 0.014000164694152772, 0.043788239625947814, 0.04675274894439748, 0.06649933595742498, 0.017322960010330592, 0.06094131991267204, 0.041319722442754676, 0.012012590587671314, 0.0329604899244649, 0.06461159725274358, 0.025817378756723235, 0.013505025816682194, 0.02927692686872823, 0.007711368978821805, 0.09752623178064823, 0.04984388307535222, 0.033096872070538144, 0.061611800720649104, 0.035628425156963725, 0.02359246921592525, 0.03296666120045951, 0.037329685475145064, 0.013192009979060717, 0.021234921346019422, 0.014096803347846227, 0.029562569755528654, 0.022693449331979667, 0.009439067565836012, 0.010664463641920259, 0.05083643392260585, 0.04750028418909226, 0.03726309744109001, 0.006646908686629364, 0.048032639015998156, 0.0022042638406024446, 0.027357412369123528, 0.039384588067020686, 0.02472283222180392, 0.05424229295126029, 0.029689191175358634, 0.05572229317788567, 0.01556769509001502, 0.036323370545038154, 0.03815635825906481, 0.01665709663315543, 0.012955551551255797, 0.06563853286206722, 0.0066042597921166036, 0.013172004222204643, 0.003902279065057103, 0.06836796033063106, 0.021749976922624877, 0.06923440883734397, 0.013119868135878017, 0.08633423091045447, 0.08050247348312821, 0.04630811173202736, 0.06426371234868254, 0.015666934229167442, 0.005618970541815672, 0.027187926195827977, 0.006927507513734911, 0.011082200333476067, 0.09650842246732541, 0.013748407846183648, 0.05199932759361608, 0.055351999654833756, 0.04994914760547025, 0.022452890008155788, 0.049060358333268335, 0.007258393419241267, 0.004166107051007981, 0.05118237143116338, 0.00974143888535244, 0.010992376715876162, 0.0418230970390141, 0.019409909811136977, 0.02141960840007024, 0.02800377464986273, 0.0040547730251481486, 0.013221267560896064, 0.025499742943793535, 0.07789628833000149, 0.05443063730906163, 0.06542222946882248, 0.0308793246346925, 0.09687893651425838, 0.06049930863082409, 0.03478574233927897, 0.059266695486647744, 0.03308029206735747, 0.006992266895914716, 0.054863376409879754, 0.016978866420686245, 0.02462077376964901, 0.05890129080840519, 0.04767810107607927, 0.010031740763224661, 0.05027296147974474, 0.027327475404100757, 0.0074680726143664545, 0.012862146116926201, 0.034280522127768824, 0.014071078388951719, 0.04977817374414631, 0.006284442913186337, 0.0378687985108367, 0.02481226822627442, 0.05987393004553659, 0.01781850940148745, 0.059758253395557404, 0.011934335992139364, 0.010514528607018292, 0.02084962371736765, 0.025938122366954173, 0.0225260038527527, 0.037706855950610976, 0.011225299976233925, 0.026754332140886357, 0.009900557043563043, 0.022913920626576458, 0.010088410311644631, 0.124470857371177, 0.00369959938273366, 0.025805796163954904, 0.01369614792721612, 0.04355191944965294, 0.014536274364218116, 0.032045624551496336, 0.040876611934176514, 0.07346582106713738, 0.049893066686178954, 0.030323604454419444, 0.03541076469368168, 0.021618780480431657, 0.04900418920442462, 0.043258239315556626, 0.007365646905132702, 0.11833884141274861, 0.01559632078611425, 0.029094967525452375, 0.01881861743251128, 0.04122986065755997, 0.051389188904847415, 0.016826477633523088, 0.017556186066940427, 0.031455546750554016, 0.006795595217097018, 0.045250971136348586, 0.029771802813879082, 0.02551471651531756, 0.03926189875762377, 0.04449951056657093, 0.04623763908499053, 0.020412055143554295, 0.05116769132603492, 0.04236570792272687, 0.018841841989862065, 0.03863056942022272, 0.026705389409991245, 0.04636283218860626, 0.05287235449733479, 0.029557097370603254, 0.025841602456888983, 0.07919779991997139, 0.025473734696528742, 0.0011583843817269163, 0.0060098211314263085, 0.021636503815118755, 0.034033677873334715, 0.03302762417920998, 0.08217251101242644, 0.02275709591672889, 0.045521954274071116, 0.032760909026754756, 0.0439103386098785, 0.05408049288338848, 0.031760236115327904, 0.01594170698496912, 0.02641913584167404, 0.04036316787824035, 0.0024972486883468393, 0.05232983860852463, 0.014278522659359234, 0.005969551350322685, 0.03418371892933335, 0.007900834615741457, 0.025672251990597163, 0.012745833340367036, 0.005969081040737885, 0.04733652654769165, 0.019808818852262836, 0.08558818165745054, 0.05316030101052352, 0.005235739900464458, 0.03244216041639447, 0.02341693051026336, 0.043688325344451835, 0.07802711666694709, 0.01645143097266555, 0.025666204547243457, 0.04689827095717192, 0.012181296445695418, 0.03759536586169686, 0.03390990969325815, 0.010475484005707716, 0.0837858094434653, 0.04588474319981677, 0.009211034846625157, 0.06446809388164963, 0.025900409390617694, 0.01803949468636087, 0.009737855372285205, 0.02432786038012377, 0.05028580614764776, 0.04879408762125032, 0.020356415272025124, 0.030056034347840717, 0.03477852951203074, 0.07845015610967364, 0.04657568523128118, 0.02891284872644714, 0.024254212189199667, 0.052185795802090845, 0.03398328647017479, 0.03248132885034595, 0.0014213203061704657, 0.013269671704620123, 0.022845415731093714, 0.02041998891425984, 0.08502804421420608, 0.022186549746298363, 0.040539013620998175, 0.040393003063010316, 0.04812530993617006, 0.061811507147337706, 0.062140216651771746, 0.03406676324084401, 0.0323676437006465, 0.036514096560754945, 0.09697684233209916, 0.03817805441628609, 0.017071002994530966, 0.05530709420729961, 0.02947945600109441, 0.03978559208501663, 0.03804532278861318, 0.017738433787599206, 0.034212536311575344, 0.02306921354361943, 0.018308041883366447, 0.029361611431730644, 0.012753983394109776, 0.05261563077302916, 0.06264501956424542, 0.0329168160179896, 0.11576006907437529, 0.063304603099823, 0.05004613400836076, 0.025486811762675643, 0.05203057413122483, 0.01220946158615074, 0.08787090238183737, 0.049308854820472856, 0.050628150813281536, 0.03968450054526329, 0.04286094009876251, 0.04028405069506594, 0.007277935227778341, 0.021062112047470043, 0.035613809512662034, 0.0494332845721926, 0.029617123971027986, 0.050219930575362275, 0.07700598931738309, 0.04367557567145143, 0.055908025175865204, 0.02213402435050479, 0.052576228244496245, 0.020404972934297154, 0.01571802282705903, 0.014662855071946979, 0.034431360462414365, 0.020827187956976037, 0.043049912101456096, 0.03421453459720526, 0.02506513787167413, 0.003436723466230822, 0.03990509567250099, 0.0344438930042088, 0.059136002856705866, 0.06685205881616899, 0.03511918801814318, 0.01221253874246031, 0.027914406498894095, 0.017195709249270812, 0.05140612853158798, 0.03274610339264784, 0.059492606935756545, 0.062092590278812816, 0.03437747799658349, 0.036766630331320424, 0.025143596875880445, 0.009340242333044963, 0.05175566906109452, 0.009999975994495409, 0.05408393305593303, 0.04518118720235569, 0.02243544826550143, 0.03326794092676469, 0.06910498506788697, 0.009003439602175993, 0.016062006154762845, 0.030130483210086823, 0.03480308908703072, 0.009337929376800145, 0.01770625596067735, 0.01996045446555529, 0.03560630152268069, 0.03187968542001077, 0.04069732262619904, 0.02540109073743224, 0.07457417409334864, 0.032720084967357774, 0.04752913549808519, 0.05305261071771383, 0.08227125821369034, 0.013391429724703943, 0.056019416877201626, 0.05419388287035482, 0.009147784356693072, 0.04689172987959214, 0.02462540816382638, 0.035048165757741244, 0.02438794804870018, 0.05819722930235522, 0.0713798754981586, 0.033036584234131236, 0.019847712479531765, 0.003528772678691894, 0.08398429450712033, 0.08181837680084364, 0.08010398343737636, 0.15924717485904694, 0.07636053966624395, 0.10894377090569053, 0.10620804663215365, 0.2627055804644312, 0.10155326247747455, 0.11309539420264107, 0.11463261528738908, 0.11636171250471047, 0.1275917249066489, 0.15913467375295504, 0.10732653697154351, 0.1388586496136018, 0.10461363861603395, 0.2187620648848159, 0.11175836808979511, 0.09500883293471166, 0.11756483651697636, 0.10379915910639934, 0.061242100915738514, 0.12381442902343613, 0.06599348810102258, 0.1478995859090771, 0.16056666762701102, 0.14569096799407685, 0.1862511858344078, 0.14006606196718557, 0.08668036519416741, 0.08407163553472076, 0.12535373999604157, 0.09860197441386324, 0.12029273728174822, 0.08177477414054529, 0.12547457351216249, 0.16113788554711, 0.11814547250313417, 0.09789675261293139, 0.08583370955394846, 0.06269139743277005, 0.21923606230744294, 0.13867535016366414, 0.10107832867652178, 0.17856482256736073, 0.07566415917660509, 0.08478634325521332, 0.1464822483914239, 0.14476702042988368, 0.18589884974062443, 0.13702671362885407, 0.08370835467108659, 0.07274126780352422, 0.08716479170003108, 0.1650047751941851, 0.11168852648032562, 0.11370600786592279, 0.14460342563688755, 0.07956380849438054, 0.0586165368024792, 0.05964170822075435, 0.11742152992103781, 0.15542088874748775, 0.15084191731044225, 0.08832249457814864, 0.24548308604529925, 0.10592665815992014, 0.1584486069955996, 0.18347143142351083, 0.17199421514357838, 0.18507159341658863, 0.14534506441227027, 0.09473301523498126, 0.18790179012077196, 0.19431067550820963, 0.16947756947151252, 0.12581855005451612, 0.1012002614193729, 0.15788778423198632, 0.10195279746715512, 0.14969794798110211, 0.11764616572431155, 0.10367325693368912, 0.0835582898663623, 0.11037666723132133, 0.08938362835241215, 0.1857308851821082, 0.11696881135659558, 0.2145191989839077, 0.0994536919253213, 0.14546752641243593, 0.17110203658895834, 0.2026957669960601, 0.12973919324576855, 0.20841452798673085, 0.15099012292921543, 0.0832061641184347, 0.18249379816864217, 0.1618166376969644, 0.11088119194443737, 0.11244835677955832, 0.09134299321366207, 0.14714090233402594, 0.16736009238021715, 0.13903394235031946, 0.1268227140286139, 0.10252855478652886, 0.10110943950712681, 0.14406766795686313, 0.1295834830296891, 0.15474900337202208, 0.1338009581501995, 0.05822318326681852, 0.09076395857014827, 0.15976022875734738, 0.11196625086345843, 0.07785299101046153, 0.1502713236425604, 0.09560727367975883, 0.1477077640593052, 0.0973129817949874, 0.0819341145189745, 0.1232126634567976, 0.1763331208910261, 0.1299165351582425, 0.15864673922104494, 0.12065188586711884, 0.21149703115224838, 0.0891577440447041, 0.11838058488709585, 0.0813148563195552, 0.11762464259352003, 0.18965679380510533, 0.23833629382508142, 0.1587140227534941, 0.31739249027201105, 0.08519980178347655, 0.12972678962562764, 0.10369566216000489, 0.10362410385693822, 0.0815978122076818, 0.177354899634208, 0.12482921885592596, 0.16218079387077264, 0.08200664312711783, 0.12376442099256174, 0.126469740111913, 0.12157856114208698, 0.08880820351519755, 0.22197517247072288, 0.11631474431071963, 0.11677713878452778, 0.08207617261047874, 0.06738168932497501, 0.113986039268119, 0.09737671658928905, 0.1510925002928291, 0.17389589095754282, 0.11528812082750456, 0.09336943804685559, 0.1492197843534606, 0.23526388726064137, 0.08964489826134273, 0.08532862165676695, 0.10103951647345509, 0.11001027189195156, 0.14635967782565526, 0.15367672805275234, 0.15232123221669877, 0.10297762961792094, 0.13501620079789842, 0.16886069971535886, 0.058558800257742405, 0.09544089689318623, 0.1199362078415496, 0.16999077264751705], [0.054699421993323734, 0.0222712495763387, 0.01344393052360309, 0.021251899988523552, 0.05412369520802583, 0.0478643894727741, 0.045733816655618806, 0.06859372928738594, 0.050177145549761396, 0.03874049887859395, 0.006934910330788365, 0.06609433876084429, 0.030245064026010886, 0.021265553809436302, 0.017678341030010154, 0.03760726736592395, 0.027765800544459904, 0.07933464686253242, 0.030651184198047434, 0.05241991413225021, 0.011871387450290578, 0.07149183377623558, 0.009999749533432935, 0.012692898279055953, 0.017167370234216963, 0.037870922325445075, 0.02746397290112717, 0.035191601275333335, 0.10901130549609661, 0.03219669019537313, 0.04155580513179302, 0.029814896572913443, 0.02420857222750783, 0.04465809098577925, 0.01914889265650085, 0.031532394234091043, 0.043942969358925305, 0.006534702743270567, 0.022885230469650457, 0.006036205117457679, 0.02574630730253245, 0.05208611900785139, 0.031329115320529254, 0.0638336907806141, 0.05858598915593965, 0.027914347127079964, 0.00841356790624559, 0.006024732362545494, 0.0641000157754336, 0.033576633648148606, 0.02447448331596596, 0.02241123474336096, 0.05712857057473489, 0.0887900594887989, 0.09327171543346983, 0.03487945141802941, 0.026729915058240294, 0.03274269714685423, 0.01024201706916626, 0.011893505147392196, 0.03828728498358812, 0.02642979223414191, 0.02646549165781055, 0.05590268849794354, 0.021939349260979464, 0.03381227528942483, 0.03813880455813237, 0.10476128105074167, 0.00835090350093586, 0.05077920967180814, 0.012366098002530634, 0.01860304007173649, 0.01885027957281896, 0.06814646614449364, 0.006452649623887348, 0.039656914704080136, 0.017591546223099743, 0.04241149207311017, 0.023731986193784645, 0.06284444779157639, 0.07652275024780206, 0.029955845259662186, 0.042681908634092124, 0.06609153641121727, 0.030327146407216787, 0.014160013125677193, 0.08709168633712189, 0.030644948461226056, 0.0486932403541037, 0.06113577447831631, 0.0069332619147774366, 0.040336654122386656, 0.02270992925124509, 0.03672507684677839, 0.01613015990837344, 0.03094856913334557, 0.08670552527265889, 0.03690415580890008, 0.03650308054472719, 0.03380414304722633, 0.05379269564790385, 0.011349146187837635, 0.032763504423201084, 0.04210036341100931, 0.009210377515825843, 0.04578995525038668, 0.03296484611928463, 0.027493441676987068, 0.017423379800415466, 0.03100425989500114, 0.028835227712988853, 0.08050269061433417, 0.04822864403416004, 0.045382053923926184, 0.03309108077415398, 0.0626768564273204, 0.04812081464167152, 0.06401186729116098, 0.06075000696416412, 0.01042142087992813, 0.04777906708685415, 0.01096375101977693, 0.027334924022267972, 0.02161991024123771, 0.09097878954240254, 0.0722075728699565, 0.010895509904782687, 0.018981679575517774, 0.036183551619095464, 0.0592080293489354, 0.05697788151779345, 0.03642409567588142, 0.06441593489476613, 0.06263972699109997, 0.026747889450884292, 0.05168805983183639, 0.02128677668848208, 0.033489139950168986, 0.020670310660664524, 0.033705243175583224, 0.05637054178597672, 0.026639181355546628, 0.0620452556759119, 0.021356752308617746, 0.03397152067295142, 0.03676189076421516, 0.016406299912237694, 0.033352978327976804, 0.016491098129855733, 0.0692882573764239, 0.05245533366022365, 0.030132037055279528, 0.02980278472283057, 0.04290403725047197, 0.06857907293098313, 0.019293600427252904, 0.022392787072541456, 0.06504592073283025, 0.014041708000669522, 0.014573933057753103, 0.03234584576317242, 0.021509168237181645, 0.09003376668053013, 0.01898678724787065, 0.029383758814739327, 0.0340600423514843, 0.00617117082167949, 0.018754327935831885, 0.017436965767826353, 0.057728185185364315, 0.041911276057362556, 0.021874455868133476, 0.05838273399110351, 0.00797642087231257, 0.016667527412729602, 0.03155792411416769, 0.06451465495462928, 0.036547636546726735, 0.03228431620768138, 0.013966708676889539, 0.11839559408170836, 0.03954104806429573, 0.011198601319587656, 0.025634703559002707, 0.04949952316071306, 0.02222751290537417, 0.05069636054603117, 0.045903732002313645, 0.058136195077427795, 0.023745846967878084, 0.028025355456130843, 0.006187029457318464, 0.038647305486457686, 0.0248472704552114, 0.04318018064701131, 0.03376827907881566, 0.01241805512524609, 0.07786545569875411, 0.044360957108438015, 0.0829373285440462, 0.02252629223013563, 0.06354636512696743, 0.017839387924011265, 0.07349279283412866, 0.045724517333188226, 0.03882937678801162, 0.04648276325315237, 0.025747616875118444, 0.030031376385263035, 0.074875314719975, 0.010390347368749124, 0.01328828392018165, 0.015428208646231463, 0.02682526279906077, 0.030508573100503002, 0.016981210759175674, 0.007760432149682726, 0.012586096867120691, 0.02853124063195927, 0.021853019250556827, 0.09066726054464068, 0.04710453881749085, 0.017033174667241316, 0.01882243249565363, 0.03352523801316108, 0.10874945883240018, 0.025099875471953834, 0.03357029613107443, 0.027342228451743722, 0.00992033803569419, 0.045224369170942476, 0.0031940477492753416, 0.02629336598329246, 0.053660086156534295, 0.005037754408216902, 0.022557727061212063, 0.010462646123154886, 0.011968086323966938, 0.030771379891250814, 0.00503263358924804, 0.02759759171333696, 0.014453750935250094, 0.07410505533750568, 0.0245217789031033, 0.007200557638757995, 0.021329843306115696, 0.012282736582814582, 0.038594637598310194, 0.03880028120641198, 0.029009818165962185, 0.030772794636764696, 0.045283696880298, 0.09073360091341393, 0.009410707346562828, 0.029844249997820173, 0.08376093434968165, 0.06090468580701521, 0.07405037898570299, 0.02271834817448897, 0.0660314317792654, 0.053446598683616946, 0.016698687437123487, 0.10051804195557322, 0.08457178369696651, 0.031145398571555103, 0.022959821824250475, 0.017169421106310825, 0.04201137354331357, 0.013347884739882179, 0.08100753423890897, 0.005227536412088999, 0.045698156247713735, 0.05200821640236037, 0.030521974167121307, 0.02147012363587107, 0.06357360830796616, 0.026781005352469425, 0.022618260866563236, 0.02523839839601091, 0.03128424719242113, 0.03214605451960649, 0.06215285097381898, 0.029544133959071975, 0.040893616021743844, 0.07625703593449933, 0.0513165042336498, 0.05161377042531967, 0.03766894959179418, 0.012610655593951898, 0.03543730219826102, 0.014745202081810151, 0.038371070487690825, 0.009870643827265926, 0.05016199725547007, 0.09441035147756338, 0.009197256344902729, 0.05247014947235584, 0.015324782946013978, 0.022483800670930316, 0.03227524080180696, 0.08487156046820538, 0.10984505540026085, 0.07448971005422728, 0.014346267595621092, 0.05617088285673942, 0.039955483682985814, 0.010707981485341276, 0.030845058616250753, 0.08642959222197533, 0.015664389722847512, 0.012774788125950311, 0.013542488583230546, 0.05252424906939268, 0.01917796448937484, 0.07522769831120968, 0.050119208837194104, 0.008460391911544969, 0.10234891264034168, 0.07693572701620204, 0.01673429356222706, 0.037491400726139545, 0.026597203786617944, 0.015511727825339352, 0.024153205466323664, 0.040094824241740365, 0.026712605629914572, 0.016204630823007653, 0.044802286462592225, 0.030017900679792677, 0.017887658905237913, 0.037667904647865465, 0.010317035052659256, 0.042071783516023836, 0.039841839245387485, 0.012049528337748987, 0.04169635348288076, 0.010533394425043037, 0.04874325517032828, 0.025547973212919066, 0.01185848849958607, 0.04351856945348637, 0.03831045695447496, 0.014122394296074552, 0.011057932528534105, 0.028706933704337904, 0.019265144364908338, 0.02871463168412447, 0.026173092258561934, 0.016138361700411354, 0.019999763695523143, 0.059329195347215445, 0.017823489848524332, 0.27467341827494757, 0.13946934470108577, 0.11534678696521691, 0.08816242138189928, 0.14059130235442094, 0.13410266196089132, 0.06756040866353683, 0.11142785368221146, 0.13379356211849622, 0.09800094845039503, 0.12324600666761398, 0.14600880736751215, 0.12254798412322998, 0.07196302206388541, 0.1535538996436766, 0.054371109431875606, 0.142300884904606, 0.1198126059025526, 0.1928070011947836, 0.2422842276947839, 0.1540041890527521, 0.14187775046697684, 0.11266579332628421, 0.09207940726940121, 0.1643419143344675, 0.12165819401187555, 0.09265467604356152, 0.15034632890352181, 0.18773074501327106, 0.10383222411785807, 0.1051675538931574, 0.14241897713925156, 0.135748774345432, 0.130250320104616, 0.07502194613750492, 0.0824266088062099, 0.1249998432717153, 0.09259634238800832, 0.1785043922385999, 0.08416281707052674, 0.09510157510106053, 0.13064036917473587, 0.17435763403773308, 0.25238519853779245, 0.18935236228363855, 0.14645009940224035, 0.08362338851605143, 0.10584490826087338, 0.10767164666737829, 0.22956527876002447, 0.07747396813439471, 0.12158337874071938, 0.08910058425473315, 0.135207683380161, 0.1610916501709393, 0.08976316691509315, 0.1075943750994546, 0.0860999734806163, 0.08460729821984257, 0.11037254852375813, 0.06462430621364287, 0.09437682506229196, 0.10205428594989435, 0.1114629271573254, 0.11719807476869651, 0.10016167536377907, 0.2212708666920662, 0.18560530192085675, 0.07669873509023871, 0.10070556867867708, 0.1487406843474933, 0.1190003180610282, 0.0965820299461484, 0.12390879967382976, 0.09431619795837573, 0.14769873954355717, 0.18272809631058148, 0.12131729801850659, 0.09706646323736225, 0.10368770294423614, 0.1792961883225611, 0.10565684549510479, 0.0951316070609859, 0.175508619419166, 0.06427478604018688, 0.07635241760207073, 0.16097387006240232, 0.20443672500550747, 0.08918444439768791, 0.11021301137017352, 0.11301608702966146, 0.1464844604155847, 0.10135468920426709, 0.1933601429419858, 0.08411793876439333, 0.1706777757831982, 0.16988656323935303, 0.13559951021202973, 0.06725070492497512, 0.1297328828700951, 0.1767790133931807, 0.1455032987786191, 0.1321604097528117, 0.1325756867549249, 0.09786045098943369, 0.18603417676474365, 0.14107729627617768, 0.13203648211700575, 0.10102777103228228, 0.11407907998987607, 0.06650575489870139, 0.12520062178373337, 0.13251878480826104, 0.15742643470210688, 0.0655446100447859, 0.1249803150338786, 0.1253874089036669, 0.17472050099500588, 0.16444302962294646, 0.07414645275899343, 0.2544995407973017, 0.16076280495950154, 0.18020945574556077, 0.1131996511082564, 0.187475751553263, 0.21980376541614532, 0.16709958921585763, 0.15934922652585165, 0.15166032553783484, 0.1386038732847997, 0.15954917722514697, 0.0832097332126328, 0.12086761929094791, 0.2153285284127508, 0.17904424827013696, 0.10881479496934585, 0.1983101237565279, 0.11236524302512407, 0.12201659620872565, 0.08727217665208237, 0.11822514608502388, 0.15573937951454095, 0.15984383784234524, 0.11530568131378718, 0.15180751335408005, 0.15490474072950228, 0.07450072267757994, 0.11715535420392241, 0.15634000514234814, 0.1222955012427909, 0.11284268062029566, 0.11304597649723291, 0.10214752344680683, 0.07856205331959895, 0.09449410984026534, 0.09670926204749516, 0.133284701566611, 0.11887166782149247, 0.08281331948403801, 0.12334553418414933, 0.1095346799120307, 0.11306830708469663, 0.18197224901190825, 0.08725799527019262, 0.1745264942624739, 0.109739651770464, 0.07190075290522405, 0.11589572179530348, 0.10969122472618308, 0.1436929130660636, 0.10538582503795624, 0.155960242663111, 0.095413199093725, 0.0777066106508885, 0.07492479349353484, 0.182057527293052], [0.02731436780387802, 0.027700919025976743, 0.02161207825078496, 0.05293382637734924, 0.052523489110171795, 0.029078024506036724, 0.03621573792770505, 0.010511984948867133, 0.03336169071761625, 0.04868647875264287, 0.05123110042352762, 0.03314712776669434, 0.04564762235219989, 0.044518021001879654, 0.01636427314952016, 0.043617347188826115, 0.007305152963713876, 0.038625324344528575, 0.033998729927199225, 0.014116425732416766, 0.06808791535773448, 0.023742401706320897, 0.03848610252940229, 0.09624044863241059, 0.03821125852742365, 0.0068877648695239, 0.07027054538152047, 0.04418496208797608, 0.10007640386798553, 0.06083948537707329, 0.006066365150867828, 0.034606449638626406, 0.03293252071099622, 0.024113911503393735, 0.021617119765973518, 0.029044067221028463, 0.04226897257779326, 0.03711875268657293, 0.06422611472329923, 0.020543227837021862, 0.05388673381613834, 0.0274816538273756, 0.014533734946910824, 0.04762461216055921, 0.003446810949493998, 0.009175357475344623, 0.0374087381974927, 0.11182586875345026, 0.032256944105029106, 0.00694538775964507, 0.07931209235851254, 0.019853369765249745, 0.10493879938232047, 0.033789201706115685, 0.0169939248090876, 0.029142770317516158, 0.011838406407540398, 0.06272276610668216, 0.03105344689850296, 0.0186933751351067, 0.08103848222110953, 0.021131962138627256, 0.12022014760545321, 0.02799088248450841, 0.008128271072304674, 0.06578138483954327, 0.059448101823883395, 0.033083270836089335, 0.06475742121360131, 0.03142449698810067, 0.09260711073875427, 0.02657354835953031, 0.02442877210809716, 0.05244928791320749, 0.028444701972018396, 0.033027878629841974, 0.11735274004084723, 0.0076280092554433, 0.023629668201985102, 0.09323751726852995, 0.03999483532139233, 0.02857095528660076, 0.017194392891334634, 0.07105508114078216, 0.017777832923457026, 0.01424057049942868, 0.02355927528281297, 0.03947050417108195, 0.015952896027426635, 0.038270928896963596, 0.055259583185293844, 0.043744633572974374, 0.052523638387875896, 0.020879363907235007, 0.041796651136662276, 0.022003469123904194, 0.07151417114904948, 0.04600496942709599, 0.029201538235481297, 0.03162184550559946, 0.042665172567857165, 0.1160012882735048, 0.03302320691623858, 0.030675407898213183, 0.044875547888555696, 0.016683656190122877, 0.012768217362463474, 0.0432227078293051, 0.026925199132944857, 0.05246116566870894, 0.02727918915583619, 0.027370294356452565, 0.06123345637960093, 0.04062560826007809, 0.005984895571600646, 0.025293559900351932, 0.019083805881174545, 0.012269126866678042, 0.02257808141543397, 0.03712267122630562, 0.011532960476220717, 0.015094771449054991, 0.012815842887253633, 0.03090424383325236, 0.04368724986644728, 0.020360350775133287, 0.017675784649327397, 0.0681625067123345, 0.04834594238283379, 0.04179880548534649, 0.030699010738836865, 0.028457538158233677, 0.04760920941563589, 0.027192436757364442, 0.020787826140544245, 0.011307244954098548, 0.018190231240753616, 0.035383243313325305, 0.0381651995703578, 0.015960310718842914, 0.06318136756973607, 0.04031021500538502, 0.015275981011135238, 0.05319098097139171, 0.06614955115531172, 0.018957589886018207, 0.051344517551894696, 0.030343909614852498, 0.019683663068073134, 0.04526779541213598, 0.006281506552893136, 0.03432054890851889, 0.040253631970179934, 0.06755733489990234, 0.032495764682867696, 0.0425717756152153, 0.05084561789408326, 0.05802337505987712, 0.023860052893204347, 0.029027809521981647, 0.043641180731356144, 0.019704660334225212, 0.025853984024641768, 0.005148691915175212, 0.022511125276131288, 0.042968308087438345, 0.04637216204511268, 0.03575104322018368, 0.038071351391928535, 0.04247230577415653, 0.02404677215963602, 0.03592496870883873, 0.06773304832833153, 0.08196618208395583, 0.05160074255296162, 0.03331471573827522, 0.0033808528927953114, 0.030989932628082376, 0.03178710949474147, 0.037721407134085894, 0.017592584381678274, 0.011455232593496996, 0.04129840965781893, 0.03162562494565334, 0.06803853836442743, 0.00426731606213642, 0.02093902918776231, 0.0333707016626639, 0.09423396629946572, 0.09634984883346728, 0.04447905273575868, 0.09556015620806388, 0.040634330827742815, 0.0958274243665593, 0.040846769964056354, 0.012447026874204832, 0.003527798344813553, 0.06379032560757228, 0.005371536810084113, 0.01796047080175153, 0.02349901628414435, 0.029678561924291507, 0.052389787177422216, 0.054456523420023065, 0.02802798308299056, 0.03803144335480673, 0.03465654927172831, 0.0636612478909748, 0.01990297746046313, 0.03167572457875524, 0.028788252733647823, 0.05811942847711699, 0.037494393065571785, 0.015053406257980635, 0.06891379425568239, 0.04757100450141089, 0.03801506691213165, 0.01053370485481407, 0.02612755916613553, 0.08149145184350864, 0.04607538779133132, 0.04194000523005213, 0.053799735448722324, 0.020349071826785803, 0.04934650672865765, 0.05192612723580428, 0.042120353052658696, 0.01664437579789332, 0.01202128516576652, 0.03597784694284201, 0.03529334081602948, 0.0674789369638477, 0.08697408264768974, 0.07638503478041717, 0.014910354112674083, 0.009123381692916155, 0.08482143030102764, 0.04952452717615025, 0.020518795487337878, 0.014367139332794716, 0.011223534937016666, 0.06278741692325898, 0.018220979055123668, 0.038849790514047654, 0.03875845970053758, 0.05018950167245098, 0.004165659217895674, 0.017034073726141026, 0.009341763099655509, 0.030094436037221124, 0.0137804872855278, 0.015877863625064492, 0.028651225979306867, 0.01931835847374584, 0.036443023410226615, 0.032623943340565474, 0.013397994551009365, 0.01680546679667064, 0.023981644672208598, 0.024332630481304865, 0.046027971764228175, 0.04197741625830531, 0.03812986146658659, 0.0611420034297875, 0.024125617928802967, 0.045172379817813635, 0.03384397644549608, 0.029162234094526087, 0.021757349205602492, 0.026293572936473147, 0.012557327830498772, 0.0420908808841237, 0.02493750543466636, 0.022888989553653767, 0.027635601548744098, 0.02097192286912884, 0.10130483045109681, 0.0450724926777184, 0.014697567227163484, 0.07669268934322254, 0.0925297848880291, 0.02470518182963133, 0.023003911333424703, 0.041024155981306515, 0.03412083230380501, 0.044097702484577894, 0.04319465719163418, 0.009596753166988492, 0.06676014446254287, 0.025466406518327336, 0.04946107058120625, 0.039473900238850286, 0.018877963801579814, 0.06476065104029008, 0.02817083675680416, 0.03305118970040764, 0.02612464316189289, 0.03109337529167533, 0.03210901668561356, 0.061521073803305626, 0.010957984320287193, 0.018241564111251916, 0.046446142718195915, 0.06490236986428499, 0.010225172437328314, 0.013570176204666495, 0.020548627279432755, 0.0783349069367562, 0.021023664556975876, 0.028864414896816015, 0.014989147295377083, 0.0176127283900444, 0.03574905850525413, 0.0234738137972142, 0.01741722209512123, 0.023507138348317573, 0.08639166889978306, 0.006572409782425633, 0.03487584839708038, 0.03644936092730079, 0.019987254902454357, 0.015502323329980885, 0.028490922081151178, 0.046445053669490984, 0.045424815200801404, 0.023249644486765777, 0.010042258904182484, 0.017064955551177263, 0.016703737433999777, 0.09485502940203462, 0.021038845081680586, 0.02164033753797412, 0.02370528584080083, 0.05918670977864947, 0.04232310610158103, 0.019083610802356685, 0.06306189112365246, 0.07282043926950012, 0.016445929750001857, 0.026919758978432844, 0.018848333873652985, 0.014908369397744536, 0.08668922007616077, 0.06232038126992328, 0.04600855887734464, 0.03181557743144887, 0.02207695446642382, 0.013700252215910171, 0.015341232331203563, 0.06666609272360802, 0.005694348997037325, 0.042737864024404965, 0.06677410192787647, 0.08146861235478095, 0.18906388990581036, 0.15807275287806988, 0.09683435676353318, 0.11576114115970475, 0.18627630520079816, 0.1610368245414325, 0.13542982217456612, 0.08976100238838366, 0.11588592374963419, 0.09434376683618341, 0.17345580671514782, 0.1846294735691377, 0.09181667851018054, 0.19002111282731804, 0.08625182961778981, 0.16093948190765722, 0.22871230595878192, 0.10359656890588147, 0.10378061474433967, 0.10718059765973262, 0.09828838945499488, 0.15262835073683942, 0.07563196268997022, 0.08339908519493681, 0.17843824864498206, 0.1418042651244572, 0.17731068629239286, 0.10952937376818486, 0.07776810627962862, 0.13666867784091405, 0.10085747909865209, 0.130285576784185, 0.1609627828001976, 0.14008850790560246, 0.08437068627348968, 0.12547190008418901, 0.16252296550997666, 0.09839595761150122, 0.15035618123199257, 0.15931103857500212, 0.0605922814990793, 0.13614484880651745, 0.0925334489771298, 0.10128890523420912, 0.1318457866353648, 0.1643326591168131, 0.16187839795436176, 0.10683197315250124, 0.12465513391154152, 0.05971613672694989, 0.16947174764105252, 0.17403383712683404, 0.14130178280174732, 0.17863475238638266, 0.17617897130548954, 0.1828764919191599, 0.07602682935872249, 0.06690008552478892, 0.1863853322075946, 0.11897120890872818, 0.1295805110463074, 0.0857654625017728, 0.07222974060901574, 0.2812129487948758, 0.14005079492926598, 0.09376087132841349, 0.1327153564031635, 0.122209707275033, 0.20448753370770387, 0.08311003606234278, 0.09517007321119308, 0.16450846754014492, 0.13762158527970314, 0.0974398474874241, 0.1972484335835491, 0.058305238506623676, 0.13479750896138804, 0.14518495728927, 0.05409387359395623, 0.08319287840276957, 0.1144045325262206, 0.10711733783994402, 0.09403190535626241, 0.08771192841231823, 0.14794929538454327, 0.15449885465204716, 0.13820444686072214, 0.13321580312081746, 0.1581688198660101, 0.11426202660160405, 0.10960806347429752, 0.09368096025926725, 0.09801784397235938, 0.11019967815705708, 0.16519468357520445, 0.13684965670108795, 0.13619173557630607, 0.12252625743193285, 0.22685818187892437, 0.20067145276282514, 0.07814797732446875, 0.19577533405806335, 0.15149124818188803, 0.08190873730927706, 0.09253893154008047, 0.10054624865629844, 0.11520253042025225, 0.18852611019143037, 0.16727033576795033, 0.08658909544880901, 0.18675216180937632, 0.08192399077649627, 0.12169890611299447, 0.138143568698849, 0.139868540423257, 0.15102760520364555, 0.16660493718726294, 0.13399569770055159, 0.13629038099731716, 0.12130782566964626, 0.10933587593691689, 0.11893916848514761, 0.06916386155145508, 0.06305942804153476, 0.20449302984135492, 0.11408349046749727, 0.10496407481176512, 0.15285947333489144, 0.09460390359163284, 0.17635863380772726, 0.15102299116551876, 0.15704745932349137, 0.126577477902174, 0.12000107578933239, 0.07974210714123078, 0.07008945117039339, 0.0987197205956493, 0.17120849873338426, 0.20057235950870173, 0.10125372319349221, 0.10072560581777777, 0.12295175317142691, 0.24475914346320288, 0.11676503371979509, 0.12255512231162616, 0.08698656090668269, 0.13492001167365483, 0.10110872026000704, 0.17285347117909364, 0.0669597898210798, 0.1569417028554848, 0.2124083579650947, 0.0984192042212401, 0.16004465706646442, 0.09753179576780115, 0.12234985189778463, 0.09339398744383029, 0.10129588057420083, 0.12790767795273236, 0.1146312989294529, 0.10065585241786071, 0.08060487798814263, 0.10622460288660866, 0.1159249802253076, 0.12461495106773716, 0.1239035613834858, 0.10247542549456869, 0.14671246175255093, 0.11886328112866197, 0.1298523728868791, 0.22572007509214537, 0.1567599911774908, 0.1695365070232323, 0.1827384236135653], [0.05752324725368193, 0.008029809703917375, 0.04719987977296114, 0.06460382124142987, 0.035922658297100236, 0.05003264473219003, 0.010903279978914984, 0.040534972944962125, 0.04215108390365328, 0.08970365260860749, 0.07234119677117892, 0.05109888787514397, 0.09753999925617661, 0.04854679214102881, 0.007734807274703468, 0.021533653173329573, 0.04492985783144832, 0.026138312249843563, 0.012041802368392902, 0.021512370922469666, 0.02229199239185878, 0.08968363582555737, 0.03777269420347043, 0.06678843937282052, 0.026554113420258676, 0.030242322744535546, 0.0563299857479121, 0.07223983721009322, 0.06430063822439738, 0.03787800283836467, 0.03773682684238468, 0.07134666120899574, 0.031155824262116636, 0.05751904033656631, 0.058880663343838284, 0.051424628788871427, 0.03398726947073426, 0.04573430859350732, 0.09487402838255678, 0.09204664759870086, 0.01734141107382519, 0.06010822818747588, 0.05854298360645771, 0.0519355554798884, 0.0645675603300333, 0.02086339288923357, 0.016537755894075547, 0.024204918316432407, 0.0167509159738464, 0.07790007455540554, 0.006688906611608607, 0.012931527170751776, 0.03824899185981069, 0.02896093650321875, 0.0630154318309256, 0.05463349553091185, 0.004555284627713263, 0.022500389155798724, 0.028449355025908778, 0.029585979213672023, 0.025633156499160186, 0.04011120068441544, 0.02811813324556819, 0.03328753023275307, 0.003386681932689888, 0.011909842574303704, 0.05273536845509495, 0.03268471972218581, 0.027879555243998766, 0.017488174805683748, 0.004681265680119395, 0.06406601438564913, 0.08306196864162173, 0.014598151668906212, 0.026303460888032402, 0.02089548759561564, 0.04347213390948517, 0.04019956290721893, 0.025929957894342284, 0.00592958097279604, 0.018180825049057603, 0.03011414408683777, 0.018549800517835786, 0.029295454267412424, 0.029932632576674223, 0.04276409279555082, 0.04361707577481866, 0.060210476629436016, 0.06328709689634186, 0.02743743878922292, 0.02027777306336377, 0.024141222537894334, 0.015593818688232983, 0.025409562247140065, 0.022123887037326182, 0.025327668159401844, 0.01632998338235276, 0.035042917289372, 0.011684576581631387, 0.06625831353345088, 0.07102206362677471, 0.02544359926001302, 0.00878849667164364, 0.0430798829932298, 0.05228852939658931, 0.021191608759441545, 0.031007007961826663, 0.05808525066822767, 0.02133764136981751, 0.01693985065711396, 0.06065774655767849, 0.03003544420269983, 0.0427941281481513, 0.009220326535536774, 0.006958206558400499, 0.028011922159099152, 0.020643172652593682, 0.023575331117691736, 0.06447294540703297, 0.049562657451523204, 0.01185591091468398, 0.07199573423713446, 0.004089904175738671, 0.011648059523265277, 0.10810069114501987, 0.009647997827934367, 0.021459523222542236, 0.04682664480060339, 0.023440842084320526, 0.016999298806435297, 0.06727441972387688, 0.03547099146193691, 0.05332338011690548, 0.018190879241696427, 0.04559346168701138, 0.012813222893912877, 0.02326024998910725, 0.04846950360972967, 0.0132816944969818, 0.021376360274319137, 0.041493512224406004, 0.10702941327222756, 0.022547107988170216, 0.0194385388999113, 0.04157302974324141, 0.03278018620663455, 0.05602944901745234, 0.07008639097745929, 0.05366032025111573, 0.06998032238334417, 0.04706644925421902, 0.06025740411132574, 0.032070764273937256, 0.05238910185705338, 0.04217897508559482, 0.030224385671317577, 0.014194424180979175, 0.017945049397115196, 0.01537915734973337, 0.016662514735279337, 0.028032836304711442, 0.015309629562710012, 0.0005965641186256626, 0.055799781877015314, 0.06419335505259888, 0.013371943895305907, 0.015223591322345393, 0.07310991587915591, 0.013826687038610024, 0.09928522525089127, 0.052038964216730425, 0.01907752943225205, 0.018626125529408455, 0.045716863458177874, 0.04903537806655679, 0.03019221293340836, 0.04662447529179709, 0.0673815468326211, 0.03734786342829466, 0.05585689416953495, 0.007383947842754424, 0.01658600482291409, 0.06554469825433833, 0.04356654187930482, 0.059744316286274364, 0.04447420799572553, 0.025759642211986438, 0.038350208928542476, 0.07103465723672084, 0.07869370268391711, 0.018025922289650356, 0.02949159499257803, 0.022372090058135133, 0.05860974466694253, 0.034621801493423324, 0.018053219753450582, 0.06089620411928211, 0.04399292989234839, 0.05920634658208915, 0.07157456755105938, 0.02441515899928553, 0.014472156197630932, 0.05044710409960576, 0.03765777412003704, 0.0322817954500871, 0.014537536439352801, 0.021193756322775568, 0.04830551526642271, 0.05882201077682631, 0.06274324429354497, 0.03203700376408441, 0.0578156958467194, 0.05426768712433321, 0.04232954879158309, 0.054142483842692206, 0.02580937204350318, 0.02868826381329979, 0.017371666950306723, 0.06838350556790829, 0.02055556360366089, 0.02291919962902154, 0.00862745741116149, 0.04778776929846831, 0.03487829451582261, 0.03620470155562673, 0.05806790052780083, 0.021218414285353253, 0.04352612494091902, 0.03982372236038957, 0.05304632409076605, 0.06256309324609381, 0.03336670509140406, 0.05415452444659812, 0.04224605505753841, 0.07726278089519058, 0.0357102191607867, 0.01249665577363755, 0.054757470664169104, 0.059573780080037456, 0.020422234865171567, 0.03390875957640154, 0.06671177170106343, 0.04121068525793297, 0.03552310634404421, 0.009909768156441194, 0.06953457915889365, 0.012522166994001185, 0.05162468805376973, 0.07536452489772014, 0.010309721293326999, 0.020881458884105086, 0.03182042217148202, 0.03979692022715296, 0.0008982086105139128, 0.06911745654152972, 0.004107927762171519, 0.01598315529658326, 0.04394509317353368, 0.03553173391680632, 0.029458682651498487, 0.07817503051566226, 0.02827942610851356, 0.03409672734726753, 0.04962125912840877, 0.03545670151444418, 0.03008577793038317, 0.06652301682957582, 0.02372337388806045, 0.01938539434091321, 0.05469825152041657, 0.020982613188347647, 0.037553452753594944, 0.02372750616632402, 0.041148826612957885, 0.01826685480773449, 0.028332156761150275, 0.05868529275591884, 0.04065836453810334, 0.013357964377584202, 0.017452088617054478, 0.04181162640452385, 0.04404519744483488, 0.04544451646506786, 0.041071734856814146, 0.04438009858131409, 0.06899882826421942, 0.020065557843606387, 0.007011338818951377, 0.026994482647361498, 0.0406322816519865, 0.045300975774547884, 0.043654313776642084, 0.039078419495906146, 0.029603580412055765, 0.006155616254545748, 0.05405215047565954, 0.036256626447928805, 0.0408138135182006, 0.011329232033209076, 0.021004794498107264, 0.05370578209736517, 0.11617552249559335, 0.03007289594305413, 0.0415897013486496, 0.028651965582477193, 0.0310868647481714, 0.0034362807221311542, 0.054760205160294256, 0.03127012009333287, 0.005964456824585795, 0.010964091983623803, 0.05980927922895976, 0.053049041623515744, 0.037150189213986905, 0.029819846485874484, 0.025854713449786817, 0.009188003671754683, 0.07024052020694528, 0.02624795163449432, 0.042468329558947256, 0.014389135741761752, 0.0463430325367621, 0.047886329902602096, 0.051274943963757584, 0.02248529514430889, 0.08968471469623701, 0.012920649406234068, 0.05012797890231013, 0.027037488196843436, 0.06073737942746707, 0.007684078300371766, 0.028287943419335142, 0.023211320828912512, 0.036884546146861145, 0.03811304736882448, 0.04855147742533258, 0.01800906578344958, 0.0072483265040708435, 0.05873292591422796, 0.017776387643867304, 0.016028148953669837, 0.008456001789974315, 0.04327834091548409, 0.046980763852064095, 0.009281220812616604, 0.06336356779294354, 0.03232491295784712, 0.015149303612166216, 0.020363394004691924, 0.022715488149385368, 0.030775200043405806, 0.02209781772190971, 0.11624157109430858, 0.15286323241889477, 0.22306447901896068, 0.19714053294488362, 0.10542900022119284, 0.09810675241585289, 0.14647679296987398, 0.10808163109634604, 0.16399404300110682, 0.11747687123715878, 0.16705922995294842, 0.18879998049565724, 0.14497277938893863, 0.21654854794698103, 0.0819353765941092, 0.1183661592325994, 0.1662551930972508, 0.11464454393301692, 0.07055901775934867, 0.11109342412757021, 0.12974585645965167, 0.26291329360433985, 0.22874924540519714, 0.15163395766701016, 0.08640293258109263, 0.07305155508220196, 0.11812917409198624, 0.155584524252585, 0.12925220866288456, 0.10669473944497959, 0.0926921922447426, 0.18003524866487297, 0.11069599938179765, 0.23245920347315924, 0.16048802541834967, 0.11525039428046771, 0.14033435471355915, 0.2216895092278719, 0.23367893802268164, 0.09157747456005641, 0.11447581941527979, 0.1118142997313823, 0.13187740636723383, 0.08281158243439027, 0.10187135969421693, 0.10054196031498057, 0.19022292271256447, 0.13612403135214532, 0.15309674346021243, 0.3117481917142868, 0.13120329539690698, 0.1568938661366701, 0.1203272882848978, 0.10625346098095179, 0.1753179510789258, 0.12095029199762003, 0.14461809556399072, 0.08703538150127445, 0.1683244127780199, 0.08986428220357214, 0.14928610436618328, 0.1612993904522487, 0.09346163059983935, 0.1429353015763419, 0.1000315798446536, 0.09988988137670926, 0.1609084999987057, 0.15014683960803918, 0.08031080769641058, 0.2267068549990654, 0.12227897212973662, 0.14914841604019913, 0.14412486845893518, 0.11179106669234377, 0.10289245311703, 0.07254280988126993, 0.12812926034842217, 0.15083130502275058, 0.1277737622814519, 0.077517204385783, 0.08032733680946486, 0.12507541850209236, 0.08277783888791289, 0.12791466686342443, 0.08224259010915246, 0.10135846864432096, 0.16541682236960956, 0.15171691535839013, 0.08427373719002519, 0.11708656432373182, 0.15313113161495753, 0.08109668695500918, 0.11616880499890872, 0.12629089185169765, 0.06895274895110301, 0.0833825764379331, 0.09886022484196083, 0.12517692734088215, 0.1101598549368126, 0.1147714164108038, 0.16764171155435698, 0.3031928965023586, 0.1182982243065323, 0.12371613644063473, 0.1098914739808866, 0.09583549214793102, 0.14897038202200616, 0.14637893464948448, 0.11736232095531055, 0.13074745557137898, 0.1572807260922023, 0.09107708212520395, 0.2286901314343725, 0.15389612556568213, 0.115911423095635, 0.10003802592733077, 0.12465255547847066, 0.08157306603555169, 0.16863668816430227, 0.1332375705242157, 0.16834903002849647, 0.22280679856027874, 0.10907674341329507, 0.14198388691459382, 0.13168641233018466, 0.1665371786803007, 0.10013354330190591, 0.14198346622288227, 0.12688462356371538, 0.14031925052404404, 0.15152795692639692, 0.07987423826541219, 0.06606420502066612, 0.08188024562384401, 0.13767463314746106, 0.13793589627104147, 0.10540991303111825, 0.11674553262335913, 0.06823943901274886, 0.10829555961702551, 0.09662129676767758, 0.17692728686545575, 0.09191006528479712, 0.21802783571183681, 0.10669769785766091, 0.2235327631767307, 0.1557195662919964, 0.10183120399181332, 0.09493654181382485, 0.15934215619095735, 0.1157398351601192, 0.12742433031754835, 0.11342264485678502, 0.2261946289134877, 0.1408704380903925, 0.09974603195275579, 0.09014524998409407, 0.13300405948289803, 0.1113924952223897, 0.11663829694901194, 0.1475130652210542, 0.11524396176849093, 0.10888547796223845, 0.13263324009520666, 0.15660619443016394, 0.07528403707380805, 0.09398896087493215, 0.15621424546199186, 0.09130408601569277, 0.12181371423814978, 0.16543127516550676, 0.1096477849142892, 0.1542947513184377, 0.12087595170097691, 0.20911306621772902, 0.11923040928585188], [0.0343151749111712, 0.04897554484861238, 0.05345907694260989, 0.09368554715599332, 0.07172082577432905, 0.027410631566973667, 0.06347647602004663, 0.025997178662302237, 0.05544622442019837, 0.034701369902385135, 0.031124075608594075, 0.07283636448638779, 0.029969840044421808, 0.07947267445602588, 0.028547562791832855, 0.02499295022737767, 0.014097974668922169, 0.036164264261190376, 0.08724802080541849, 0.08137441133814198, 0.01641103269399277, 0.03768576708223138, 0.030053018259682825, 0.0866207762488297, 0.05611619971958654, 0.06376825286341564, 0.029502414233450378, 0.03370757394337228, 0.034453718191278834, 0.038245914703501124, 0.012718903981814427, 0.02139910137546914, 0.016576800495386124, 0.03837390676406877, 0.046573408746293614, 0.02690832396703107, 0.007945555162483027, 0.01712188633557941, 0.04527946621445673, 0.011471996649301477, 0.039221529316689284, 0.025473220706252114, 0.0022385580606559025, 0.013540351197921803, 0.01617296359368733, 0.054792459322405715, 0.0067867572984791225, 0.03914695492546473, 0.022589621599763632, 0.05391876745436873, 0.029204225234155144, 0.04999063662918551, 0.04070626571774483, 0.030161166563630104, 0.031145167869648764, 0.032845444312053065, 0.02553262814347233, 0.049978039626564295, 0.0180089317727834, 0.05107413152498858, 0.02955542817445738, 0.05544188518875411, 0.020800270472786257, 0.01680467969604901, 0.023843737518680946, 0.017614640162459443, 0.050656676425465515, 0.013214769739923733, 0.015779509974111403, 0.015568278630131056, 0.04416649236476847, 0.03682816667216165, 0.09499866169478212, 0.07944406741963965, 0.04490578340898667, 0.04114329315988081, 0.04849718783849052, 0.03777600545436144, 0.016806442190759947, 0.03916478004040463, 0.03708003208573375, 0.02757493542906429, 0.03240662893014295, 0.07184888568839856, 0.016036964819899628, 0.008969533207294132, 0.02686072982448552, 0.08465574562017407, 0.015734672380079116, 0.06755977084061929, 0.045336276558893066, 0.042696632843996794, 0.0457968254174505, 0.0299556858039328, 0.04202142603961485, 0.03524550409721477, 0.02384920142191861, 0.0612271460039275, 0.058142145829541345, 0.0390870776027441, 0.0875325712508389, 0.05513077349002872, 0.04387666970225317, 0.05311070688601051, 0.06195190961339644, 0.02565042521538479, 0.04936589925949063, 0.011351999427591051, 0.026360435777210763, 0.056208229424165826, 0.09473330021968909, 0.034182063303887844, 0.06774228318993535, 0.056565450970083475, 0.061504049359687736, 0.00777601046554212, 0.04039795297597136, 0.049422092137059996, 0.010261530888133814, 0.03823963825457862, 0.06888720246830157, 0.011357035005598195, 0.006616477663296142, 0.011307160137221217, 0.028369172542755092, 0.02002859634480306, 0.04073161239336644, 0.01164338696149311, 0.07461884883897645, 0.044822343957743475, 0.022227058286911676, 0.028318080552188412, 0.02872706244566611, 0.049559159603502066, 0.04483177898717778, 0.033337901279862435, 0.06423129194549151, 0.04417764408779996, 0.03773374968607511, 0.07080257111894232, 0.04863978875800967, 0.04973385862207838, 0.017669265624135733, 0.03160798303516848, 0.03432701534724661, 0.05352635708238397, 0.004526126705708781, 0.06429575277226311, 0.0258296212247972, 0.02198931827609028, 0.014239160842927439, 0.037246520830584426, 0.004827983610864196, 0.06871572309838873, 0.028160843632317016, 0.0345841597632638, 0.0038429144603599396, 0.04813490102865866, 0.06835587562194892, 0.03661837042974574, 0.078920380877597, 0.07303825579583645, 0.054817785641976764, 0.024845821782946587, 0.04258175686533962, 0.017559923098555634, 0.04292283945583871, 0.005035256975263889, 0.01798359357884952, 0.056029442232102156, 0.02392121434344777, 0.03848079638555646, 0.04104888179738607, 0.08693174884787627, 0.023609541156994443, 0.006312932902281838, 0.028346207525048937, 0.06920044815966062, 0.011884476390800305, 0.028873045862253224, 0.05889878701418638, 0.029597616089241843, 0.02825559935133372, 0.022325332210000073, 0.016509094574887837, 0.032588310074061155, 0.029774330356823545, 0.016907157143577933, 0.03611002556447472, 0.015530131391382642, 0.04436985609520759, 0.05167655527059521, 0.021329415829053948, 0.09121434975947652, 0.02916427648493222, 0.025056608686489717, 0.04392904921301773, 0.0354478059203497, 0.04199909884482622, 0.028710326379431144, 0.029014391491987875, 0.02660682371684483, 0.04633422515222004, 0.010475770686753094, 0.063671188428998, 0.024461552134848068, 0.05965518392622471, 0.012867480250341552, 0.02912391722202301, 0.03280032851866313, 0.07470841546143804, 0.008288740363371159, 0.0117051786011351, 0.02197155592563961, 0.014643886625500662, 0.03633181152067014, 0.06706601447824921, 0.021912830416113138, 0.021737502056307027, 0.02842636456313942, 0.0802101402410439, 0.06021077518484422, 0.03194349146048937, 0.061404969676264694, 0.06011711699622018, 0.02384139148385397, 0.02866941750315683, 0.06806609367153474, 0.034658187933798344, 0.008000817598908075, 0.006971359959736998, 0.027591866574117115, 0.0562044771255127, 0.04816667003823178, 0.04293267482093402, 0.04520230660481112, 0.005582492499213133, 0.024321049584874084, 0.015426775241004569, 0.03934569443975176, 0.06319034458803278, 0.018660764742110456, 0.04461074620485306, 0.004954900617511677, 0.04917755829436438, 0.010025972367397376, 0.022396067789356624, 0.02640145321908806, 0.06637264668409314, 0.0734217366469758, 0.02243925484695605, 0.025115549630884613, 0.029073234048805068, 0.13679443752127035, 0.022962544446012804, 0.008809253057864095, 0.031224556466830627, 0.02411007778053837, 0.05163887282833457, 0.023808945635599748, 0.054722811095416546, 0.04417811566963792, 0.03558941278606653, 0.05403293436393142, 0.022201889726732458, 0.039279598343585215, 0.028640657796391418, 0.009556248019050275, 0.04260606877505779, 0.06655139316405569, 0.04929361492395401, 0.021137856911601763, 0.018875334478382553, 0.05716342691864286, 0.0421544392593205, 0.020509358761566024, 0.06271780601569585, 0.06403825551803623, 0.017783558062676872, 0.09088649520916597, 0.02218677196651697, 0.05843814994607653, 0.01906828608896051, 0.03514496556350163, 0.037971508356609514, 0.0347135360352695, 0.0557047055502023, 0.051325342152267694, 0.020582766072558503, 0.06143485914383616, 0.030405554521296705, 0.018980658380314708, 0.04754655688468899, 0.04406595043838024, 0.025740743315379535, 0.016748293435999324, 0.02133047434368304, 0.028797056725514785, 0.04232311288693121, 0.06164947298488446, 0.0295384003381644, 0.04527484199830464, 0.025791117755163993, 0.040677675644734075, 0.037335826217063835, 0.06462154457611696, 0.041743206325918436, 0.02293131317544196, 0.030194855827305998, 0.08885193509714943, 0.017783390125259757, 0.0466394335962832, 0.03584318488304104, 0.026201560195269327, 0.02526788752792137, 0.023481908719986677, 0.021543524161513363, 0.05422168584274394, 0.0196602112014911, 0.06119819291468177, 0.013554906622240586, 0.051943772538964234, 0.09045361022331885, 0.08904643037489482, 0.038316326282386265, 0.03426679875701666, 0.03256941626646689, 0.06458225061318704, 0.01613540668040514, 0.02970900439790317, 0.06721590286386864, 0.04165203836081283, 0.006197316896369947, 0.046323049680462906, 0.04814326058008841, 0.04691066439928753, 0.08386364419545446, 0.03894015441515616, 0.030498982008014406, 0.02552933555229434, 0.023166758041562777, 0.032435921286898, 0.03792104909994772, 0.013516290346160531, 0.002313659376730876, 0.017195939951177155, 0.05190892976575664, 0.054193214513361454, 0.040434196923992465, 0.07760577356176716, 0.02510530375210302, 0.04744741952578936, 0.12666335329413414, 0.1430327527757202, 0.12258784127022539, 0.11312828958034515, 0.22511085921100207, 0.11486145800777844, 0.10923027553196464, 0.1463224941066333, 0.13046878123922007, 0.08744727939899478, 0.11618260640118803, 0.18042623411331857, 0.13142985823963368, 0.1371864000601428, 0.08719101707850184, 0.11132289110017674, 0.13081575690635613, 0.18459537039910043, 0.1674533909452813, 0.21313065849244595, 0.20281472775552953, 0.12341524687196527, 0.11007167252578906, 0.12656458573681967, 0.07480997858302933, 0.17580456925289972, 0.1329918187111616, 0.11933522937553269, 0.09966371208429337, 0.1351275076823575, 0.08464858707572732, 0.10081541671284608, 0.0810125893247979, 0.12996631248721055, 0.19321017313216413, 0.08571979030966759, 0.07180838393313543, 0.11698848887213639, 0.08217058397297348, 0.09086854117257254, 0.12662573531270027, 0.12305722465472561, 0.10943612270057201, 0.1039777970207589, 0.13890571280249528, 0.1689089706965855, 0.21613179173852715, 0.09527327838752951, 0.08037773160529987, 0.18664952660245554, 0.08172146842948028, 0.13883353024721146, 0.17905350348779134, 0.10172328299709729, 0.10274711091603551, 0.23836500942707062, 0.12218671850860119, 0.1618862146777766, 0.13970039944563592, 0.1585967040487698, 0.10608890266822917, 0.1512797081044742, 0.11284437695784227, 0.11853658008788313, 0.15523791499435902, 0.1496646183409861, 0.12502743250557355, 0.08963962604424783, 0.09573001387928214, 0.08768917034779276, 0.10566905912544046, 0.0734495905094913, 0.16997866758278438, 0.21650208186890396, 0.12876842676528863, 0.2212223650089332, 0.15098424681595393, 0.14439388045242854, 0.18417489581874438, 0.08351953873144728, 0.1391567707593952, 0.1539144188697849, 0.12530556400971754, 0.15316862746008805, 0.09242948384157249, 0.17743529246321746, 0.05186566976564271, 0.10330177936702967, 0.1207823274391038, 0.11179866628455264, 0.1280667401318039, 0.09645314221935612, 0.08612854659025158, 0.1152817290276289, 0.14628320692905358, 0.10604216517614466, 0.11405040509998798, 0.10386066152048962, 0.1928430042628731, 0.15776662501905644, 0.16754918651921408, 0.15861408811594757, 0.0930000910801547, 0.13809081938649925, 0.11180347709783486, 0.10867490818990128, 0.10876580474099942, 0.09890863153019122, 0.11092326790094376, 0.11805372099791255, 0.17316333098070963, 0.1346506739833525, 0.1510122703122241, 0.14854618906974792, 0.17249517754784652, 0.15651681779750756, 0.19805898437542574, 0.16640722565352917, 0.07205232405768973, 0.14853649958968163, 0.1016599213970559, 0.13072187480117592, 0.06120061528469835, 0.17770138675613062, 0.130798359268478, 0.11951132278357234, 0.10843185016087123, 0.0886270957333701, 0.15546948542552336, 0.21590513390089783, 0.06974276048796517, 0.09462003236902611, 0.06677422406417982, 0.13302316702902317, 0.05663280574870961, 0.09798519965261221, 0.15195456546332153, 0.08907429102276053, 0.10264770553580352, 0.15417224860617093, 0.17455743545932428, 0.09743766260466405, 0.06715927911656243, 0.1588172007884298, 0.10597861358629805, 0.18854987248778343, 0.19395669735968113, 0.18294302906308854, 0.10636945654238973, 0.13577457224684103, 0.08626559709331819, 0.12965111940034799, 0.13263815268874168, 0.22814358504755156, 0.12265123001166753, 0.1416991464793682, 0.06915396172553301, 0.10505852688636098, 0.16011940448411874, 0.16438565270176955, 0.22677454565252575, 0.14810549414583615, 0.07931997693542923, 0.07364606710949115, 0.07739096294556345, 0.14038004726171494, 0.10855535710496561, 0.09650448696421725, 0.10471572420958962, 0.08143238537013531, 0.22379891175244535, 0.11159412868853126, 0.12532487511634827, 0.1580641083419323, 0.09540558593081576, 0.11352042175297226], [0.06851886651877846, 0.035544724469738345, 0.018453507917001843, 0.02614563364269478, 0.04673729870202286, 0.047201311481850486, 0.031404344498046806, 0.05521457935018199, 0.00853325893902885, 0.03333889872633985, 0.03440748620778322, 0.005632207487776343, 0.012527971012916948, 0.024090719176456332, 0.011230176946680461, 0.02482366082923753, 0.03965587315282651, 0.01849836077807205, 0.07431187281118971, 0.039938666192548614, 0.046211793686130216, 0.04825526635561671, 0.07259559990572077, 0.05977575281368835, 0.029485542460211685, 0.011140671392370547, 0.025597577515457357, 0.025546076707541943, 0.06166898086667061, 0.032871930926506004, 0.008160360689674104, 0.04994727824149387, 0.028738465226654495, 0.056789771254573546, 0.015540628328121133, 0.0445610231586865, 0.04668655785332833, 0.030189966982496635, 0.04449356659980757, 0.013646294263058474, 0.06976695026138, 0.01798931023638163, 0.04641106245773179, 0.05444867955520749, 0.03588975274137088, 0.03160793553771717, 0.07466768978961877, 0.015819039727960314, 0.02279749758807676, 0.034652898753327985, 0.06267145528857197, 0.02715490189647036, 0.022481853275426796, 0.0316603829019836, 0.014927154639735818, 0.016432978212833405, 0.027803242106788924, 0.009289038384200206, 0.016838248519759094, 0.032163173958126984, 0.0643073082236307, 0.014440227732328432, 0.015114520210772753, 0.08596796449273825, 0.016110451858756796, 0.020367595832794905, 0.05453280432681952, 0.016492855535554032, 0.045050521713814566, 0.014465236836778266, 0.023706449528357813, 0.06932855557118144, 0.02270036530015724, 0.034401674555348496, 0.04894077332158174, 0.01344484739404704, 0.036029256148529906, 0.07148217822292022, 0.04831186296152217, 0.023999622457527688, 0.049858352834624906, 0.08312359997736556, 0.02512900498030441, 0.012113305540489299, 0.020321279032421962, 0.04391967525173511, 0.019160551584458778, 0.02780491639194744, 0.04719024796837142, 0.029007619712501764, 0.048661603658859215, 0.019307244070140377, 0.05703445098229817, 0.03643691320238369, 0.07308704924902745, 0.07286138885787555, 0.023173577318500196, 0.044838710222393274, 0.043057616866592846, 0.007562567097400981, 0.05521437918235149, 0.04063481258760605, 0.041406483322914155, 0.08140380547514983, 0.04566851444542408, 0.023733536646302258, 0.019266657497999922, 0.056625087412872484, 0.057997909640627246, 0.028275154730571166, 0.013521588856487401, 0.034493415882544856, 0.06262148118444852, 0.04974621474476797, 0.02069925017920988, 0.03670496167615056, 0.061480198853782246, 0.01175686006899923, 0.022532068259481872, 0.08044297953269311, 0.02962295597951327, 0.029102333023079803, 0.0697591674647161, 0.03343601065820881, 0.07344462363315479, 0.0013640890579803713, 0.025161832504506623, 0.04134251104135599, 0.03359483535002385, 0.06461906113794871, 0.01868016066561852, 0.02146487686383937, 0.029311674647033215, 0.04686720083866801, 0.05600186317626919, 0.019453397120482156, 0.02458555101683097, 0.00898620650903987, 0.0895810549014381, 0.03963653151211994, 0.06358377954789571, 0.03256819490343332, 0.025502815011090467, 0.06314574448125702, 0.061121050268411636, 0.09393101398433958, 0.034686889965087175, 0.019941893140120164, 0.015435736992263367, 0.02988793408232076, 0.03444805242387312, 0.01911042141728103, 0.02568871833916221, 0.08391018491238356, 0.02814841965612556, 0.03711177395390613, 0.044503809085914066, 0.12262335579310145, 0.023244599578902125, 0.057882409409752915, 0.05883619894406625, 0.08554140345326491, 0.02318234907995377, 0.0437182114193482, 0.03942080826631614, 0.09212487590100084, 0.029775992767619233, 0.06533193681389093, 0.016141474479809403, 0.03370478855712073, 0.05245915041970355, 0.0511182532645762, 0.02735624528889145, 0.030598685943654606, 0.08858488406985998, 0.015846179432368705, 0.030998919824404374, 0.03977583475144846, 0.04900464043021202, 0.042528122064790556, 0.026750844470890503, 0.008903103780799677, 0.04120905677388821, 0.057880027751837454, 0.03718333564964788, 0.027416517858260443, 0.1040914516363825, 0.02405495020294828, 0.02882944659462997, 0.011059991882315703, 0.04786949884146452, 0.041090330109000206, 0.031425019460065026, 0.019923645637131164, 0.05961107236466237, 0.018744891210060035, 0.05429648415052465, 0.03240507508495024, 0.06948723098529236, 0.032680292281189134, 0.042665338808936734, 0.028475370058523755, 0.09032212370740515, 0.07213970579739128, 0.05005044949107936, 0.04137201713664191, 0.03160334864099111, 0.016542129052270736, 0.008704354936656142, 0.05113554912220154, 0.025939949322491884, 0.07047704394374575, 0.015314978114994509, 0.043875231208013635, 0.04864194310669388, 0.08823834945048604, 0.028467967241470302, 0.014662895784048098, 0.05041193902226431, 0.019337291297103678, 0.0410275757978005, 0.020468556754557148, 0.02492735963980002, 0.0340551229725991, 0.009949197826374854, 0.08566369581967592, 0.02324047408598874, 0.023122254626027176, 0.011439718738464373, 0.04251759120130113, 0.044589039869606495, 0.05632121229012098, 0.0043282739518742475, 0.03879729565232992, 0.00272603246100646, 0.04767900013497897, 0.01738834025205246, 0.026110502492104257, 0.024860126997477243, 0.04318989048312817, 0.03706679726019502, 0.012698517397179135, 0.03994126837434513, 0.0629425843113235, 0.03281981943707381, 0.01563504308329097, 0.0388436938769051, 0.014749509082841021, 0.04887514541457806, 0.06027349217661789, 0.020529378937291246, 0.02547178560468767, 0.039594825357198715, 0.043054420966655016, 0.06186690953161035, 0.02126682097358363, 0.05749758505927665, 0.047479473520070314, 0.05947391329599278, 0.03138675008501325, 0.07363187215690102, 0.040952451793210845, 0.008761881983705928, 0.03744596941396594, 0.043230402416416576, 0.022784785234502385, 0.04860040658552732, 0.02043644678113716, 0.01957256144045719, 0.03543667794604387, 0.019253015551449995, 0.03420701642919864, 0.027682698664388487, 0.01836919824459723, 0.01676819656443383, 0.018766521210116998, 0.00927004449269069, 0.034676240357969484, 0.0413079125407551, 0.003528115984019158, 0.011394382421193379, 0.023535329782004868, 0.02276314844909523, 0.03787360932411892, 0.010694161423348954, 0.037727208608495336, 0.029352308716624975, 0.023872324199016606, 0.07295823616108724, 0.062093764144395075, 0.035384909116796086, 0.030474371542888026, 0.050581565991576226, 0.05616443677406226, 0.06892511221979346, 0.024285110977611372, 0.005457807024608233, 0.05990339882139649, 0.011042592548100012, 0.036980368862194676, 0.06197947170585394, 0.07048733731997864, 0.0023380987238072392, 0.03561090877545731, 0.03239669178479484, 0.08120223986251013, 0.008389686018095484, 0.06146748989288296, 0.004511101819973971, 0.04006856493651867, 0.05091073689982295, 0.03933758594627891, 0.055565096970115385, 0.051011974324605296, 0.03379101339461548, 0.023026445481394018, 0.004095700137051088, 0.030462598960314478, 0.044706263579428196, 0.042185465273048194, 0.04603278597018548, 0.024492361017369797, 0.04192974238789507, 0.02589667744801513, 0.054484889576477666, 0.030670346026974063, 0.07268267630466393, 0.02189136665713574, 0.04938521036612136, 0.0329834854762469, 0.01884797085741801, 0.077027417453272, 0.11533939093351364, 0.049858814238437583, 0.007217963758323873, 0.06577837214406047, 0.03549832285248807, 0.021156738844833205, 0.011963722495628255, 0.024023761340816106, 0.02787837798574141, 0.04696798364498785, 0.020090565251718675, 0.03977718503613557, 0.029082485873784338, 0.01644132928257542, 0.0383825784416071, 0.0534509854125125, 0.049947285026844056, 0.032218871505132744, 0.06177783823971238, 0.02740232290567032, 0.20420074409672193, 0.1642383291785206, 0.10118493331330163, 0.12964768601315363, 0.12820103578269482, 0.1284883003681898, 0.1335391386279038, 0.14494445733726025, 0.07762262158628021, 0.07926329211997134, 0.15185757566775593, 0.04142494626077158, 0.09172925605837788, 0.08285185348774705, 0.13979999481567315, 0.15871653333306313, 0.23635364164199146, 0.10645633616617747, 0.1263329338814531, 0.18301225320569106, 0.1437668191002948, 0.08333631392036166, 0.14294391897107872, 0.14991701979722294, 0.10018361240093197, 0.09786922444722482, 0.19918448398155825, 0.2081704725112234, 0.1477949015264, 0.14321776213390486, 0.08818264172545501, 0.0954952339774796, 0.1441877143723624, 0.26960546736206326, 0.10773970372974873, 0.20381862031561987, 0.1293648997587817, 0.09722842276096344, 0.2541305534541607, 0.09388452755021197, 0.14141805656254292, 0.12845630065671035, 0.10846412128635816, 0.0726679317387087, 0.13870702417833464, 0.08224853407591581, 0.1113853638193437, 0.1151656588273389, 0.11350548041186162, 0.20626001645411762, 0.09775254356541804, 0.14634253803108419, 0.07393715184714113, 0.16625489454184258, 0.14830634051135608, 0.1566426046192646, 0.1037451002214636, 0.11449867247470788, 0.13792356050440244, 0.11472908939634051, 0.1271747922790902, 0.07283556381506578, 0.11256641508745295, 0.26414144198809353, 0.08227352452065263, 0.1003297891999994, 0.13911262527108192, 0.17576935328543186, 0.12008803683732237, 0.09444400681448833, 0.11222572265458958, 0.1868558283895254, 0.11993852843131338, 0.16976853885820933, 0.09136467919285808, 0.10647000864680324, 0.2148818080978734, 0.2176979048443692, 0.0921318715970431, 0.06595451304955141, 0.14817197700696333, 0.11329993858401265, 0.20838426532489912, 0.12251546872513634, 0.1030439699866942, 0.1538371473018612, 0.055518610535987785, 0.16858378957424844, 0.2062564202185188, 0.08554615998374564, 0.1131043644355876, 0.08296244791043655, 0.16931359469890594, 0.06682826259306499, 0.16429326337363037, 0.09326531006289379, 0.1360545629369361, 0.0937215027266315, 0.12152454975460257, 0.0856120525194066, 0.12836684259985173, 0.12429354260010378, 0.15997202667806829, 0.10146499864224877, 0.17046894984585897, 0.11947963519820146, 0.06381838981594358, 0.11502058804035187, 0.20846001697438105, 0.12706852012446948, 0.04497160469847066, 0.1519784363252776, 0.11665341470922742, 0.13726346806756087, 0.07002342292772872, 0.11478038664375033, 0.19319702312350273, 0.16927379183471203, 0.14538600721529552, 0.1408473543290581, 0.04675070316131626, 0.07737697155347892, 0.09581846770431314, 0.15748568437993526, 0.18521295940237387, 0.13166849900569233, 0.0568656043282577, 0.14590443511094364, 0.11167768349072763, 0.16511943404163631, 0.267250869423151, 0.10141571664384433, 0.14024406884397778, 0.09223160267408405, 0.16577014912452015, 0.163618514580386, 0.12357935735157557, 0.11372647926743541, 0.16345364414155483, 0.11892517709306308, 0.1369770855775901, 0.09900534991174936, 0.1411732275571142, 0.11369148721652371, 0.14123103874070303, 0.17625728781734193, 0.12605595588684082, 0.08022058289498091, 0.14395956375769206, 0.08756395349545137, 0.10827601780848843, 0.0956627574882337, 0.1136930003496153, 0.10175275855830737, 0.09196957280593258, 0.13333036697336606, 0.20408923365175724, 0.2255783969802516, 0.1182291494416339, 0.1298948898911476, 0.10317728854715824, 0.2184257015053715, 0.12645459521029676, 0.19868296517857484, 0.09652737395039626, 0.1304448153823614, 0.11578011299882617, 0.12901860262666429, 0.09762207485203232, 0.18616943593536103, 0.12941785263163702, 0.1528136586504323, 0.08336563341851745, 0.09046479248042617, 0.17978215510291712, 0.11659972901855196], [0.03407121103789125, 0.048779994448913, 0.01614753040485084, 0.031633377208241394, 0.0012488626795987199, 0.03135816340467759, 0.045524424141539, 0.030150462673710923, 0.06429234652646951, 0.04365830695522683, 0.024566457041406205, 0.03506582463160157, 0.028767438671950783, 0.01689285023270973, 0.022433953792122856, 0.039712944733245034, 0.013496655239058393, 0.03723133521686707, 0.025454233600092784, 0.02505879526558731, 0.039176762968833954, 0.022719762920002853, 0.03968437162360974, 0.02660131231615586, 0.04500306836728539, 0.025760566715949347, 0.05606583545782736, 0.07680156707231488, 0.053455874257321866, 0.030236517877451012, 0.05301745921107275, 0.01837751199491322, 0.007583220007031092, 0.025555243715643883, 0.05369539711890476, 0.018317984117727195, 0.04296635051390954, 0.02939938208354371, 0.028437930192532282, 0.012138617441191204, 0.0446594209144158, 0.03858933484713946, 0.04904000228270888, 0.021134542268035666, 0.02559710423728185, 0.03322402274768267, 0.017946062110630528, 0.03226131047787411, 0.0362109915752496, 0.030349066480994225, 0.04609198136521237, 0.05768167160983596, 0.05070672177576593, 0.027893076750582883, 0.03269729297608137, 0.05982979812792369, 0.020636212579639893, 0.058548249038202424, 0.04281318819682513, 0.03915230178141168, 0.024612322615991746, 0.018220298823767474, 0.004155705957340875, 0.03451341570221952, 0.01836537809244224, 0.0577674995043448, 0.02439411762835724, 0.03415401605889201, 0.0340840387424188, 0.013538346126941698, 0.07834230975380965, 0.044462618617607017, 0.029772352427244186, 0.09078907793653862, 0.06111335568130016, 0.08608476751084838, 0.015202186935182129, 0.03186107659712434, 0.022277322464755604, 0.013791153856020952, 0.04047755870435919, 0.024235986738598773, 0.019767401074724536, 0.034504883124360015, 0.017060908089791025, 0.016753971077767865, 0.028278131802965487, 0.0077925964059042075, 0.026089924221326197, 0.01214558769217027, 0.02989115033830915, 0.05240596345226679, 0.03819425443985632, 0.05150817341304251, 0.03886428402204599, 0.043742747245622535, 0.0051698193752339906, 0.03191617703331368, 0.03393851672964437, 0.024303874167214547, 0.04195207976070898, 0.025210921120430742, 0.019368315614493828, 0.03713464058403458, 0.03657420797805701, 0.024289877686117376, 0.03368467677916799, 0.09359335460300956, 0.07275149332625525, 0.1002838998766882, 0.012155873434884208, 0.022102618357166648, 0.03921277621494872, 0.04904678424022027, 0.0224975647537836, 0.05210960649752191, 0.02252498096121209, 0.029120497405529022, 0.049468368225331814, 0.036749789092157564, 0.061243396917624135, 0.03468859987333417, 0.0236649876460433, 0.004671278068729277, 0.06036059571696179, 0.05951087988380875, 0.015009630571252533, 0.046398665622941086, 0.005180075856125248, 0.061323464049824646, 0.07616824962730918, 0.023602994990402033, 0.042282709519245794, 0.024362436828336546, 0.0632105717169387, 0.021856931004939333, 0.07149967764105115, 0.040001064272863526, 0.023071276290076118, 0.021016450033390095, 0.01912505572129573, 0.005192213999440095, 0.007202047023123929, 0.032865104864218404, 0.05931970942765474, 0.021235555776261857, 0.050269134542239566, 0.03354552960289376, 0.04801229992881417, 0.04176052253959434, 0.044155042086328776, 0.051162659988871644, 0.09546486953539507, 0.011191430052609315, 0.02201459540187248, 0.05110753580395665, 0.07759280675756079, 0.042326882148959806, 0.03192475710862449, 0.05177707684093288, 0.055513375638318915, 0.02210341902848865, 0.04456429369747639, 0.0245755969081074, 0.11273294793707983, 0.053404902706721, 0.04858817259914108, 0.022120496058570485, 0.058781346173158715, 0.016497440735942552, 0.04211474835340466, 0.05598695236923439, 0.024419102984081422, 0.06606227798121315, 0.01919468698490943, 0.024717512507257716, 0.03259589609556964, 0.03658933252362268, 0.06295058423919336, 0.0463171769598765, 0.002277731159535636, 0.05180195872006672, 0.09183908373649631, 0.06821455034826483, 0.020360617100128105, 0.014225895483312863, 0.032744010112115314, 0.03633537382951804, 0.04835937737620302, 0.04508669441565871, 0.020168305008805225, 0.023153798022706593, 0.025761050172150135, 0.04043866168441517, 0.04838811672691788, 0.03981588528092418, 0.0214560508195843, 0.009749276812986603, 0.01994268872242953, 0.03642418049275875, 0.003227026671603588, 0.027616731489875486, 0.03777339987988983, 0.04455070603372795, 0.025217840481283407, 0.03723141664106931, 0.008026098117365368, 0.024024458535547768, 0.013743077105443393, 0.027378830326987163, 0.07026100517915827, 0.0007285325004236906, 0.06979715864041022, 0.0315963258035481, 0.048363574115293365, 0.03136675365801368, 0.06390257565570728, 0.04889537932883416, 0.05706573823200805, 0.05467787850648165, 0.01122610319206225, 0.056532782901610644, 0.033595150868807516, 0.011335872346535325, 0.05762964832995619, 0.01869267115502485, 0.07959090239767518, 0.059101601131260395, 0.031047435078237737, 0.02439176820085517, 0.01781518797257117, 0.012939737444477422, 0.04005756927654147, 0.044957521704158614, 0.01567861351317593, 0.009942589743461992, 0.03799066340018596, 0.017870527592354586, 0.01844057334320886, 0.03083162023020642, 0.06421967542597226, 0.024554472416639328, 0.04672909860632249, 0.02774797203684492, 0.08300303787525211, 0.00835596876485007, 0.04178749091391053, 0.00029853083781615296, 0.02009555248410574, 0.038825960364192724, 0.03336258977651596, 0.03560014381738646, 0.06670697445848159, 0.06971893033811025, 0.03490599570795894, 0.004711335383555186, 0.09098791583840336, 0.026968353960130895, 0.007658088712819985, 0.039688286770667346, 0.02427919754492385, 0.06180073879659176, 0.013992160525439041, 0.03250905379120793, 0.03815428533458284, 0.03220156886215721, 0.018405788245477846, 0.02617970627865621, 0.01215503883681127, 0.018622508937759057, 0.08129144007606165, 0.02330273306662483, 0.01925591628865472, 0.027878506907394955, 0.01723616011440754, 0.042612623423337936, 0.026043883923973356, 0.01920623904360192, 0.03187883725123746, 0.04537319904193282, 0.038699983552630456, 0.020082059815259914, 0.03998980059155396, 0.04063491776053395, 0.018641205970197916, 0.031513537745922804, 0.01155732582057161, 0.05505360709503293, 0.0526302192759301, 0.07442566991916724, 0.02896334869521005, 0.047775202829922946, 0.06168684669371162, 0.01677758918542947, 0.037308192878429375, 0.03322457575372287, 0.04556214051055057, 0.043431153787033897, 0.01897056008289967, 0.04252340624641095, 0.03623515420726367, 0.015008285375578063, 0.024565069437293068, 0.07153847627341747, 0.031291588941322904, 0.04506764793768525, 0.059697382019034455, 0.025798276299610734, 0.042057415537003956, 0.029410316675369228, 0.05686784349381924, 0.005600787499653441, 0.05822466925850936, 0.04213303826483233, 0.015109266653390867, 0.036127016081341674, 0.010178842914423772, 0.03515136754140258, 0.02883769418778164, 0.01599607799601342, 0.0646407064050436, 0.04006345896050334, 0.012275722227059305, 0.024975216714665294, 0.03398180726383414, 0.02047165426691728, 0.011696537457672613, 0.043650717541043244, 0.07933947803186518, 0.046394095689590485, 0.015650220215320587, 0.011862272180483809, 0.10262128338217735, 0.04314471022891147, 0.02636142474200044, 0.018285166771550263, 0.021848948040444936, 0.05706541932054928, 0.044222407042980194, 0.024361588659563234, 0.03649597628308194, 0.015212582091667821, 0.042233848212552924, 0.013673322857357562, 0.06613988203129598, 0.023108137704964195, 0.024851341665323292, 0.043939213667597087, 0.0374393095927579, 0.060797049797007015, 0.022226696967014244, 0.024037184459822517, 0.22684326767921448, 0.14759025536477566, 0.1468272427363055, 0.11867563905460493, 0.1632219651447875, 0.1861510204949549, 0.1906763876655272, 0.11378682138664381, 0.15464889231537068, 0.10192252123462302, 0.17090501716094358, 0.17359738983213902, 0.0944994024134108, 0.18796409320618424, 0.15995538899941103, 0.11385854253811495, 0.098058800346085, 0.10788210787411247, 0.1312937983976943, 0.1107939730531403, 0.10201113112270832, 0.2042416733290468, 0.192229282909206, 0.11888755911162921, 0.08829527175320045, 0.08374553160475832, 0.20904442561524256, 0.11108591953026396, 0.15439217537641525, 0.08593093005142041, 0.10523431495364223, 0.11640889782990728, 0.1034283261480076, 0.10258182657084294, 0.11510265006550721, 0.09934020015810217, 0.1527717930397817, 0.11132829223892518, 0.08895256862576519, 0.10652467142790556, 0.1093776465526649, 0.13160307465919427, 0.12865038881344454, 0.10127437779945986, 0.13464838053498948, 0.19933749362826347, 0.15948388858565263, 0.1189941433923585, 0.10009221373392002, 0.1761973188923938, 0.1639128223593746, 0.1497415370707001, 0.1645833913769041, 0.11719525206301894, 0.19714885178421224, 0.12901725912732737, 0.1075423178928239, 0.14887446431177004, 0.18445610787187303, 0.08777355296271187, 0.11800676637462207, 0.07465171028992959, 0.04620169708505273, 0.11152314035488026, 0.15256488057119505, 0.11396367475390434, 0.10365444794297218, 0.09901360089757613, 0.1762459155704294, 0.08570787523474012, 0.3036858114813055, 0.11567247020346777, 0.0832757478845971, 0.16429576038249902, 0.14288025881562913, 0.15516841943774903, 0.12738113477826118, 0.18001140494431767, 0.12656826339662075, 0.09865428946380105, 0.30812006496957367, 0.1393089797347784, 0.16069795058241912, 0.14429070241749287, 0.04581967169152839, 0.091921776799219, 0.09841491587992225, 0.11432492679783277, 0.12907836799110683, 0.1306493936904839, 0.08535712691290037, 0.13027522233980043, 0.08905812831861631, 0.07547109560774905, 0.16952163353562355, 0.08961804863065481, 0.08080206704991204, 0.1237513388374022, 0.1477349190307515, 0.07750917731651238, 0.10798303995813642, 0.10246178694069386, 0.10453762233789478, 0.10287527261035782, 0.12599013799003192, 0.061381343086915355, 0.1660702923046691, 0.15109187604061194, 0.1681564346488033, 0.16898848143007072, 0.06513494452727692, 0.20664420298167638, 0.07232086786202022, 0.16730209120682307, 0.10118161527706043, 0.13550663233867713, 0.21346528482224258, 0.08127214932548148, 0.11886868226741042, 0.09579833557030984, 0.0788294571850981, 0.123695916097079, 0.08839474498693432, 0.07804715380604778, 0.1871484126895666, 0.13576883184058325, 0.12418319923537117, 0.1350610926747322, 0.1241695335400956, 0.14262485823460988, 0.1659801692834922, 0.07037560295845781, 0.17067194038203784, 0.13329703733325005, 0.1669021083840302, 0.0558507941397173, 0.145821124581354, 0.08638303793434586, 0.08964607891227518, 0.12579402779894217, 0.1346875320055655, 0.12567585414009436, 0.06033755945307868, 0.09218918066471815, 0.1515844381813492, 0.19181654362806252, 0.1692820428205388, 0.17916003348571913, 0.15019076796514647, 0.1215201121355806, 0.12294035378311362, 0.10122371837496758, 0.364726007516895, 0.09794503037950822, 0.22034925328833715, 0.16310954546289785, 0.28454892550195965, 0.14615786794040883, 0.08720289822667837, 0.11902699805796146, 0.11996841111353465, 0.10929573380521365, 0.13489865139126778, 0.12384385030184474, 0.23221571796706744, 0.11100208652870995, 0.20492088688271387, 0.10189573267208678, 0.1080003697425127, 0.0846980454932366, 0.15407101118138858, 0.1578575215701546, 0.08424525907529251, 0.1706731074622699, 0.07984650653920003, 0.1158331065837826], [0.04733006689431412, 0.06541509806577649, 0.02913688402622938, 0.018124757700466683, 0.034726034650313, 0.047533501870930195, 0.025359170843980143, 0.0408765169392739, 0.04842574827905212, 0.04329647815653256, 0.055192947653787475, 0.06073729121791465, 0.023814937099814415, 0.022925830612491285, 0.038632638952029605, 0.046082325811897, 0.03484415402635932, 0.009041275562984603, 0.05542840948328376, 0.03187019610777497, 0.03727642726153135, 0.06848855635949544, 0.05036966968327761, 0.05216045251914433, 0.05043412372469902, 0.04748590263937201, 0.019097322298746024, 0.01997925667092204, 0.07044082374445029, 0.10411513250853334, 0.019258157150553804, 0.00812433472102774, 0.008156767846750361, 0.05518699690167393, 0.06692174436258418, 0.018975213136790053, 0.035756379898105345, 0.0029836406133004595, 0.012858606708635176, 0.02658912752355848, 0.013308171781578233, 0.053888877986797264, 0.04118733686794128, 0.03402806978140559, 0.07294351873653275, 0.040699168241449764, 0.04830007680824824, 0.05480008266334023, 0.027328350714274814, 0.009107626109783138, 0.04539168912119099, 0.049855258714939864, 0.041473810960139544, 0.06883298073496137, 0.09478665342820541, 0.03983547458691256, 0.02451424377172121, 0.01607642841658422, 0.032855900536690436, 0.026025924798367277, 0.03372747537546924, 0.0777179625417505, 0.04424806584471038, 0.0327468294251178, 0.028763106225856712, 0.024351697315328887, 0.028212196858865873, 0.04248887220663684, 0.04795991702537451, 0.044446055577801805, 0.020294242804603915, 0.01797529848824654, 0.02879849521975432, 0.01996312110817858, 0.0535776509371187, 0.09044512175023556, 0.032780287986887355, 0.02286445033470435, 0.02831148010279451, 0.007694681258206921, 0.032739653917295594, 0.061180591716298034, 0.07763272497270789, 0.022774710685813, 0.02747545201730515, 0.012338799690561635, 0.04626255149820021, 0.031117049378475974, 0.05783420628202813, 0.030854110273399522, 0.06969810609838792, 0.0529461451806128, 0.05910861718335322, 0.044411932051713975, 0.039833778249365945, 0.011566875352790313, 0.034158114410404644, 0.011959480803592928, 0.014898752860192741, 0.019819393820528473, 0.03696538002363273, 0.024030036093401055, 0.02146554522083274, 0.02150351264780121, 0.08052076000188078, 0.05172273297128933, 0.010921314591541886, 0.01589460308397455, 0.025205988170845166, 0.021264724300376008, 0.030960212794265578, 0.03138027007558516, 0.015041221465383257, 0.020427659752645662, 0.030000089135553156, 0.02411682072228619, 0.02719452664522188, 0.014230709689270173, 0.030347132656191076, 0.0043576244081902716, 0.046886817286057134, 0.039340792024242024, 0.024617281010640518, 0.03328949798430715, 0.033107725238161426, 0.025241458588945012, 0.039919623107250245, 0.021100632480478713, 0.02005109826235899, 0.02814068435691297, 0.01588590256869793, 0.028623015885906558, 0.041663078125566244, 0.010781973184618567, 0.05444424193618553, 0.05866905541292258, 0.024825703219643662, 0.020842353214642832, 0.02153355478575187, 0.013934551206018244, 0.01809542632794806, 0.02054467481294913, 0.004032552275540573, 0.032570875116756985, 0.004527203031882111, 0.015479058060528976, 0.02622193829821689, 0.06868553507540907, 0.015588390408083797, 0.07138022833636828, 0.03412600274064711, 0.030928545564945256, 0.034442417190543244, 0.04278866594125118, 0.05810468391116176, 0.07947213841336113, 0.03271306212991476, 0.07749673976962056, 0.023433206869023185, 0.0024710101632600917, 0.0714383041486144, 0.07787322492471763, 0.02533325589528041, 0.027682513763595904, 0.0665619308128953, 0.042847773126725636, 0.08129811007529497, 0.04652026927630816, 0.02507056445548577, 0.06823658916567053, 0.027178479292030846, 0.012900931178592145, 0.04097900286849056, 0.015013930786933218, 0.009412069505612766, 0.026109410050724233, 0.035596187958227735, 0.04835531973679151, 0.024547541181423833, 0.021420688967087438, 0.029248750702078854, 0.03922266586284552, 0.04498424241319299, 0.028981458794857775, 0.0730059507435986, 0.04368329739996365, 0.03206322235720498, 0.03147729040522661, 0.03065386780404619, 0.016265123916257705, 0.024221757859257714, 0.0404920623903828, 0.05300525915143745, 0.035353272421551604, 0.047123317274131944, 0.1311131723757301, 0.03867637731933168, 0.049623471152569563, 0.03780164050736597, 0.06102109527481454, 0.023954908696136305, 0.007911759029541696, 0.01682963451769735, 0.05593413859605789, 0.006475045096262225, 0.06029187369027308, 0.015957559259342294, 0.04411112729992185, 0.03326705204589026, 0.04121573016579662, 0.03200731446434345, 0.025725366015519415, 0.010881953623278864, 0.020416005913700377, 0.05568560478942735, 0.06141030296151127, 0.017395145958289504, 0.028061351738870144, 0.02704910810903779, 0.0652170404791832, 0.04813606471621564, 0.01757141069642135, 0.014843430203784789, 0.014804003926526223, 0.042909021090183935, 0.017548449071390287, 0.1189926370446171, 0.019842280806707482, 0.02582501057934548, 0.03724806110507675, 0.055892256022031815, 0.02038856765388378, 0.016873700278145925, 0.026643223727920225, 0.010164452034847012, 0.027003254408815076, 0.04438808833115867, 0.03446614556014538, 0.051319839233266454, 0.036523093935102224, 0.0246895823095526, 0.04829691144238625, 0.03735373954155615, 0.02267163443113012, 0.02190157012747867, 0.049998276933495484, 0.007613343569183988, 0.03063393583787339, 0.0255729823173689, 0.0340144549762564, 0.029825519038630382, 0.03268038388341665, 0.025930716157225624, 0.01273206077582602, 0.045325016270258596, 0.02522017464174756, 0.029180303482072692, 0.03934297690700207, 0.07274597683655364, 0.020228638646325896, 0.010678464363861297, 0.057628847658634186, 0.06789344722138983, 0.05768196337989398, 0.016044963051431944, 0.03537728577586157, 0.04165097645350865, 0.0194782247168145, 0.030898540746420622, 0.0330601463626538, 0.02916765898200018, 0.04850936754207526, 0.003869585127436689, 0.02402276898335133, 0.020981641186933433, 0.1052471799775958, 0.07936429884284735, 0.050539812339203696, 0.05253775530893888, 0.0689864382147789, 0.020212024716394286, 0.06972842982837132, 0.042450592653559785, 0.03425562667793461, 0.08358309710664408, 0.04696476060364928, 0.03489666245877743, 0.03182039163740618, 0.04988919903657266, 0.02168329559000475, 0.013445830421655305, 0.03522695634248001, 0.03616291058382817, 0.0318340335839561, 0.031913133803755045, 0.011358717772444444, 0.04816574044525623, 0.023455491655373147, 0.023882822832092643, 0.06429618703467505, 0.0029659476006470087, 0.037830081302672625, 0.035999281864081106, 0.018475467006542852, 0.027075779624283314, 0.04224984806829265, 0.049091133289039135, 0.015434924446578537, 0.02079516788944602, 0.035030269396624396, 0.028862121448452984, 0.030246926604637077, 0.024469550366380384, 0.056772207375615835, 0.03770955312731011, 0.00886532464729888, 0.01549341416518603, 0.02405831912931587, 0.027833749041227356, 0.004585103273192155, 0.02074520057067275, 0.018293058133817146, 0.03528834001294204, 0.03505425560953362, 0.06511552485504321, 0.042435949867857356, 0.014471506500350577, 0.02748487177970154, 0.03737071309504764, 0.033379994199744294, 0.017031861701980233, 0.05277327820658684, 0.07448270078748465, 0.035322782450488636, 0.03446921932377985, 0.010675740045761424, 0.06902768635856253, 0.06811726878264121, 0.026973670282002007, 0.01646419591270387, 0.05428806013826813, 0.028106138442776034, 0.0555657958611846, 0.03901083062269858, 0.011853278198811625, 0.035045421083590815, 0.007820826007186301, 0.029073305294982026, 0.036209987343422005, 0.01549440821898835, 0.03777421072923711, 0.03498554376087018, 0.1019169097500188, 0.15452713599162443, 0.0962166999067579, 0.07945771275886468, 0.10788171432380166, 0.14980035248611653, 0.10643103359533207, 0.09854583921177046, 0.18746984829860075, 0.1009241451642343, 0.21278248860367707, 0.07541171022291694, 0.10692394178892885, 0.12343583362443106, 0.07753138576767274, 0.11570429349584238, 0.06681582504617316, 0.07973974583936588, 0.1292331689702613, 0.19548565388790198, 0.12666325829923153, 0.11753625662199088, 0.14938511619610445, 0.18898079650742666, 0.07988228569073336, 0.08768474629947118, 0.10111870829548154, 0.13343448138662747, 0.10909035482576915, 0.16431119026882307, 0.1005282403369035, 0.11291075803871665, 0.08627933064209563, 0.13914766481944493, 0.13012586321149552, 0.08679283237350838, 0.06040354698364224, 0.1163917173232351, 0.09604412809546505, 0.11702943167516164, 0.12679422912853106, 0.1322442495397159, 0.10293089891118662, 0.13403126650622912, 0.10527565809232847, 0.11412273693297591, 0.11233865123774324, 0.08435806552214281, 0.11427361597972256, 0.1473177692719868, 0.24333337854061807, 0.12478910386562347, 0.16923849444304193, 0.15417925108756336, 0.2412170006760529, 0.1068655267091734, 0.17494493323777402, 0.054721443847353966, 0.11665717379323073, 0.14453967048653535, 0.09447094465472869, 0.1419160876955305, 0.10557262572859015, 0.12693821425948823, 0.16234540646629675, 0.061064792930015495, 0.11742166562804154, 0.10419741166489464, 0.15066192911139556, 0.1752797495573759, 0.10159808650080647, 0.07111203058489732, 0.15423803936157907, 0.1222933977842331, 0.09829659972872053, 0.2353320936007159, 0.08592834483299937, 0.07912599734429802, 0.12253450841775962, 0.14618232234248094, 0.10909094515123538, 0.10265118642044918, 0.2575444259813854, 0.06829697199698005, 0.2044223400631121, 0.1259273463594062, 0.175663257549916, 0.13141634182206222, 0.08233591581561736, 0.14818769187799521, 0.12489705878709044, 0.08766067866235971, 0.1216536071151495, 0.1600728298404387, 0.08480098604091577, 0.12264464822198663, 0.10494748463055917, 0.13214196717100485, 0.06835880689322948, 0.22757326279367718, 0.11339801403560809, 0.1553549894264766, 0.13214803327407154, 0.18974530191293784, 0.16649886859314783, 0.13388068601489067, 0.06001416287784066, 0.10042475696120944, 0.1644221307443721, 0.14434848645968096, 0.1856323347559997, 0.10928219703159162, 0.1098923289350101, 0.08637374200459037, 0.13102809765509196, 0.1685190030506679, 0.24380224623850413, 0.09907007536717824, 0.08277640717902354, 0.06308803507792098, 0.10585100829069104, 0.16281936317682266, 0.10243564298642532, 0.17884342904601777, 0.099027314090303, 0.09885410445609263, 0.1003532868676952, 0.05618653326694455, 0.11799516342580318, 0.1500059078846659, 0.08722523559949227, 0.1983534957149199, 0.09322014677205256, 0.06860220418976885, 0.10837535533521857, 0.09158961355154004, 0.17850622428315027, 0.16312824588801178, 0.10644449573010206, 0.10413292369672231, 0.11003419703670911, 0.09655150944100958, 0.10848325597388403, 0.15450055098959378, 0.1208304762840271, 0.13512520066329411, 0.0821596799152238, 0.1626705875886338, 0.2609882083322321, 0.16985919113670075, 0.06641880742141179, 0.09469156353069202, 0.17014199096177304, 0.14401907127882752, 0.10912977771035262, 0.18613329716026783, 0.12055178838116781, 0.17584958326603684, 0.16211317107081413, 0.07218218208955866, 0.12943162689251558, 0.19834565185010433, 0.112663784862629, 0.13812591321766376, 0.1755098950650011, 0.19310839287936687, 0.20926321244665555, 0.15539579652249813, 0.1258136374609811, 0.09758822952530213, 0.08896947093307972, 0.13435640691646508, 0.08959795042340245, 0.1660709979810885, 0.10758227003472191, 0.10352343640157155], [0.022435828245111873, 0.06621570153427975, 0.07035283132323197, 0.05416660576260515, 0.025546136079356074, 0.06062191312334367, 0.0355424378067255, 0.009683890634083321, 0.02979936490633658, 0.060234042150633674, 0.04955188570810216, 0.02285526636322694, 0.025928919735763754, 0.016694010634507452, 0.028654808644205332, 0.05012770409562758, 0.028877005114087036, 0.04475647517080818, 0.015161106728815606, 0.04154017507763846, 0.037319303889359744, 0.02243096993437835, 0.041309747977980545, 0.014362896792590618, 0.06963764184287616, 0.02450166373247547, 0.018833979465333477, 0.03060396833877478, 0.04197990308914866, 0.03118505555072001, 0.029980550719691173, 0.04795347433537245, 0.04823613166809082, 0.017577471710475426, 0.04665193560400179, 0.02376507156129394, 0.007317507390065917, 0.030330298202378408, 0.07504920288920403, 0.07784165269029991, 0.05787188533161368, 0.01267878559883684, 0.042620290869048665, 0.008696284610778093, 0.015160402748733759, 0.039151134701179605, 0.0639768209574478, 0.01782811915368906, 0.021155568371926035, 0.018519680348357985, 0.052299670941595516, 0.051809042625661404, 0.03900951087208731, 0.011053400762778307, 0.1007437159174255, 0.027475731913000345, 0.04146855231374502, 0.04970391147903033, 0.05227874152894531, 0.05902286392769643, 0.04321413793201957, 0.0407035176509193, 0.032827860077044795, 0.04176558101815837, 0.025045214387189065, 0.027849760771329914, 0.021469090566305176, 0.10727884274508272, 0.039319411385804415, 0.019093005119689872, 0.051866480614989996, 0.019872667301180105, 0.044534502617482624, 0.018233316518100243, 0.008101982929344689, 0.026986316478412067, 0.02571133560767131, 0.022810815534155284, 0.03717648244595953, 0.04946365240695221, 0.03201743481414659, 0.011354209755414298, 0.03974243725783058, 0.03108402168644326, 0.019522168340959718, 0.03946801055488842, 0.04058676891561065, 0.03148504266781466, 0.057965584232338836, 0.05249246648911919, 0.05593806052846568, 0.05172631563618779, 0.04083637480757066, 0.021979878157643334, 0.05406551422285182, 0.04752724917073335, 0.06377451574163777, 0.05200385681486555, 0.019649620966187546, 0.007012636517174542, 0.028222497020448958, 0.040292990393936634, 0.07037030359996216, 0.06355950156492846, 0.022972725863967623, 0.02989283649783049, 0.05684320588729211, 0.07271374642316784, 0.11028131270515067, 0.029997347854077816, 0.032321048700915914, 0.03010321288768734, 0.020253907290420363, 0.028173915609451275, 0.03465064601706607, 0.01177886750416032, 0.0034167645706994726, 0.05329345672258309, 0.05091030263741102, 0.02321190945804119, 0.06258179367120777, 0.07223516210381474, 0.029996900020965507, 0.026917367142492106, 0.03939554301489677, 0.009439690969884396, 0.021453012679038302, 0.03422629360907844, 0.01234916940198413, 0.03450384157310639, 0.026943453421284045, 0.058126390246408324, 0.018168463837355375, 0.027064403984695673, 0.04425107514751809, 0.04984818159469536, 0.03929960494861007, 0.03245503222569823, 0.047158428068671904, 0.0269927252416632, 0.004069969240975167, 0.08382530696690083, 0.022543423543018953, 0.0308530178320195, 0.040183797146060636, 0.035174407197960784, 0.01249529531092516, 0.059437177410083156, 0.03129345830529928, 0.071098738083882, 0.039955395473433394, 0.04285382905176707, 0.058492215616362433, 0.017625528953171203, 0.02426626975648105, 0.02881949927125658, 0.034759075913046084, 0.014277990009369594, 0.02608431952207216, 0.062365510634013584, 0.06524954230657645, 0.019703569589182734, 0.0021599928233107285, 0.04204449623024889, 0.03685805613973311, 0.09799492984477963, 0.052195766874189885, 0.039789832928883176, 0.025073834994275655, 0.03349958938945617, 0.043026953869100125, 0.021445908417393054, 0.01984964121532227, 0.05608395573550037, 0.05038884508290461, 0.013105721528907972, 0.04321522358804941, 0.048097663026835234, 0.06319821559424911, 0.034935942851006985, 0.006941923414290483, 0.017190559168479273, 0.0453403783030808, 0.013049564274427081, 0.0674115652218461, 0.03086899054635848, 0.05911818452711616, 0.046302863263658116, 0.024423650865043913, 0.042733735138816495, 0.014868166197889617, 0.016554234117003422, 0.018310504965484142, 0.031605000873761516, 0.02584108677027481, 0.04975544282102159, 0.030237986905766383, 0.04485900181212595, 0.09511340196643557, 0.03180005594289728, 0.03471213486045599, 0.0117289875467707, 0.02151706808113626, 0.01878795782769365, 0.03189487103372812, 0.03673563824434366, 0.09876554206545864, 0.045313901866653135, 0.035083378332534006, 0.027189683601526276, 0.014450003725609608, 0.04703498897807939, 0.04796299757435918, 0.030274407272892337, 0.04263940180784889, 0.02619872391889138, 0.034870688138263564, 0.03943344258836337, 0.029825970264417783, 0.02079607543003346, 0.013008226224753474, 0.03248506418562361, 0.08424352202564478, 0.046040246462715526, 0.020322778594813178, 0.00721959224236863, 0.03976905279393707, 0.012564094520972242, 0.026206315029412508, 0.010007062444596418, 0.015341798907944133, 0.0487187464854547, 0.04177828997905765, 0.03855186614340969, 0.01203155140059867, 0.03882256768909948, 0.03366921975144318, 0.00956259062513709, 0.054528119042515755, 0.08305704926273652, 0.03458415297791362, 0.024023773215178932, 0.04619200760498643, 0.03805767212595258, 0.05327750775696976, 0.024643967792923962, 0.08410436806402036, 0.029184666462242603, 0.07673091122082301, 0.03990045788564852, 0.03480123668642981, 0.059075389323490005, 0.017880181449332407, 0.01739625705938254, 0.049943637901118824, 0.025633678971124545, 0.04327641387603112, 0.05325614068923252, 0.019681847986898253, 0.06648463888892106, 0.052539950369724205, 0.03691473416984081, 0.01861135721472757, 0.011054547486959823, 0.008271748998335429, 0.026679681414472203, 0.027558160347065756, 0.04116104363596865, 0.02328566791090582, 0.07769168966582843, 0.036793435857232125, 0.019565463964162127, 0.034884682923023186, 0.03348182194999286, 0.04627296022538628, 0.015393372658374054, 0.04472890629300049, 0.006243125219563288, 0.007596865346256111, 0.023572410024436455, 0.049750781285443475, 0.043325587308832576, 0.0523431039681392, 0.10243593475648335, 0.04515697368021522, 0.04039999197370239, 0.03660283876316888, 0.03295437293127179, 0.01893111684226564, 0.010311493117894446, 0.021674559451639652, 0.02337668659830732, 0.006721790539034243, 0.061854478770068715, 0.014091316544051682, 0.05208066697897656, 0.0467405895968633, 0.06615367664822511, 0.01510505295092506, 0.02911978494375944, 0.02664748323149979, 0.026541114385638918, 0.02650140312367252, 0.02336538559757173, 0.05145323243258255, 0.013416108043332185, 0.014117294257240636, 0.04096998853076782, 0.03965420734935573, 0.04563369881361723, 0.06572583317756653, 0.024526737297752073, 0.02446003391274384, 0.040349006852401156, 0.025635712879842946, 0.019727219927257726, 0.019182610757915036, 0.07234053180686065, 0.03673023710559521, 0.05267659035910453, 0.008230015702013458, 0.010017693392001092, 0.006249575543084315, 0.016589256701990962, 0.03286451793142727, 0.0390458599930363, 0.0068035938727137235, 0.0018492116983647325, 0.01539403762269233, 0.05604671094832676, 0.020881099260545204, 0.0568764473178557, 0.055756196180092435, 0.02478760008567146, 0.03565181765173163, 0.06864618682967764, 0.033353673826370916, 0.04925395455211401, 0.031203562593353645, 0.05731841788760253, 0.026981351298413107, 0.05223248579672404, 0.0433004713351173, 0.012738366910655583, 0.037206833317343674, 0.036895487524036846, 0.0031791912250420345, 0.02782231572616313, 0.05225870778251972, 0.0535484841093421, 0.03519537393003702, 0.018892450524227958, 0.13019865644829615, 0.17309360472219332, 0.15831327997148037, 0.08972136237259422, 0.13924168263162884, 0.103528728974717, 0.07742016030741589, 0.11494461925966398, 0.1522611275847469, 0.17387358072612966, 0.0913536733548556, 0.08125460919524942, 0.12647717685571738, 0.08619035434510026, 0.13848568605525152, 0.06784382595547608, 0.11765626232538905, 0.10916459334215947, 0.14662950406117098, 0.13276623295886175, 0.1613809232200895, 0.14950669610074588, 0.14954480262739317, 0.08310983250183718, 0.33636194095015526, 0.23562416221414292, 0.05844312360776322, 0.10106065962463617, 0.10084491941545691, 0.1567698163645608, 0.18739383880581173, 0.1849138340247529, 0.15501775752220834, 0.05405217422438519, 0.11577160416969232, 0.10807665743465934, 0.07273538490491253, 0.15702149857367786, 0.17893595408116067, 0.168008079752326, 0.12128087425870554, 0.11762051710060664, 0.11897670504237924, 0.06263020035943814, 0.04226174617984465, 0.16498432414872305, 0.16507922405643122, 0.09312328589814049, 0.09657171621386494, 0.14559081622532435, 0.15750502262796673, 0.15830471685954503, 0.13844444469681808, 0.1496280181620802, 0.18139375719640935, 0.08022400949682508, 0.13915035181811877, 0.14375550113618374, 0.1505912664745535, 0.0807862775400281, 0.0779815733964954, 0.1989380672041859, 0.12804202788642474, 0.1587889330195529, 0.17918672705335276, 0.14784379675984383, 0.10572172022823777, 0.15349972540778772, 0.11574579269758292, 0.1315048635005951, 0.14721429268164293, 0.1278831014143569, 0.3120741599372455, 0.10654833194400583, 0.1808687067989792, 0.1750396295849766, 0.1454241137419428, 0.12176709888236863, 0.09038110875657626, 0.16673395383570874, 0.10072882885911635, 0.17727631170834812, 0.09443645471973078, 0.16612442582845688, 0.12546846669699463, 0.11965027318469115, 0.10244388718690191, 0.09904612986637013, 0.08811219621981893, 0.0912313267056431, 0.1811518594622612, 0.15346976130136422, 0.1251999975315162, 0.24254967059407914, 0.14283444413117, 0.09926708122449261, 0.20098797577832425, 0.13474253405417713, 0.12040993385016918, 0.21323285943695477, 0.10489429427044732, 0.13036929443478584, 0.21516334584781102, 0.12187221752745764, 0.13144181402666227, 0.08949171898088285, 0.20141022812042916, 0.16166267810123308, 0.21006103392158235, 0.1011140128331525, 0.16879294120839664, 0.0598717655188271, 0.1551859663533313, 0.12044539409024374, 0.12265743182173797, 0.0773224580500807, 0.09490969218313694, 0.1256050422255482, 0.07381014366235052, 0.16621506453624793, 0.14165544882416725, 0.12823777166860445, 0.14128099248877593, 0.09236749966761895, 0.0832563689244645, 0.10161997604050807, 0.11688077822327614, 0.09949259233794042, 0.13851649154509815, 0.07810849337173359, 0.11326303306434836, 0.19269539575491632, 0.10402984065668923, 0.0764491224129285, 0.15694903103368624, 0.18434051264609608, 0.12103562456156526, 0.10276805729206119, 0.10980830594365086, 0.15554624130683287, 0.09818534034171275, 0.16639449633657932, 0.24738854808466776, 0.1435998316322054, 0.20849299377628736, 0.08086572720536164, 0.09029432412769113, 0.2213846163025924, 0.09459135747913804, 0.15173611789941788, 0.12033235015613691, 0.08122583931045872, 0.08140147810003587, 0.16190131886729173, 0.14763227025313036, 0.1925568931869098, 0.14006390422582626, 0.16538385913840362, 0.15103904530405998, 0.14903425930866174, 0.1688666979649237, 0.2041570193001202, 0.0944840878780399, 0.15252055866377695, 0.1057500694213169, 0.1406808825475829, 0.10584817879966327, 0.11463011827852045, 0.23040994629263878, 0.13565789136503423, 0.10122334518070732, 0.15789975358971528, 0.12272084770458085, 0.1453989672341517, 0.13344305806926318, 0.1507981110896383], [0.02000142101730619, 0.02536125903550003, 0.07300635786460978, 0.03696274730776038, 0.02711806762298303, 0.016461156075820327, 0.032791270076164176, 0.035738144269479175, 0.0038925980666785365, 0.056836583385510106, 0.05307756723569972, 0.06559143574642283, 0.006403168305821184, 0.013232091890781053, 0.0038171152866977665, 0.06208709414516177, 0.01947746136491852, 0.02021854034891086, 0.0423018340287464, 0.04901260982400604, 0.02363589545711875, 0.07343792649252073, 0.07781939674168825, 0.033500922710767815, 0.035059748350509574, 0.003331281032712598, 0.014505972686622823, 0.023013069859838912, 0.08704849758318492, 0.025940414118979658, 0.021936728419469934, 0.003818117398103433, 0.0034673862516813514, 0.03196476014064891, 0.044419507895197184, 0.008295692802805985, 0.012695469078607857, 0.008679426408239772, 0.0014188320970528626, 0.03524913086688944, 0.04813774748306189, 0.10241956170648336, 0.02760990203491279, 0.015885140913139497, 0.046740620130939145, 0.062142611880387576, 0.004975102301354387, 0.039564779826572964, 0.03294972496639405, 0.0734613970188158, 0.046871238122028966, 0.02443286876327225, 0.017829001249213303, 0.10487013842378344, 0.032292407737778764, 0.05145469128287264, 0.1089169280603528, 0.02759953062715275, 0.029508510870592933, 0.06452912810657706, 0.049001285074544806, 0.049603383123342476, 0.04410282542396869, 0.013009562090571438, 0.03393551081951175, 0.013078841364144214, 0.024675346644861356, 0.03833888417908123, 0.05085727173302855, 0.05977843302701201, 0.02130048139952123, 0.05108623658972127, 0.06803275724606854, 0.01990709956070142, 0.02344958670437336, 0.018586716215525354, 0.03099096060863563, 0.007742249107520495, 0.06281929449843508, 0.037870881613343954, 0.021584734985870973, 0.06203726253339222, 0.03184368235192128, 0.009967452114714044, 0.060992338960724216, 0.02395016573635595, 0.03584482015243598, 0.024603040256936635, 0.033992158315543614, 0.026248662399926355, 0.026639244120035852, 0.008607950377544122, 0.06470562863562788, 0.01201125726635967, 0.03460130634318505, 0.04624005127698183, 0.07662961272788898, 0.040686991930540116, 0.03339836892804929, 0.05698673639978681, 0.0387016697121518, 0.0014977908847088525, 0.052109487753893645, 0.03770321900291102, 0.05017257222373571, 0.031468550874186416, 0.036479165577994924, 0.03261113938476358, 0.033105628564953804, 0.04065520256491644, 0.03592793390687023, 0.08548647604350533, 0.07841329130211047, 0.04230494850448199, 0.03763397789693304, 0.030297840479761362, 0.003574307467455843, 0.02479635488374957, 0.05687011658613171, 0.03455817526472466, 0.01707803431366171, 0.03636772298653211, 0.03901148880166667, 0.01716732104042811, 0.034434318875095675, 0.011878758036930646, 0.032868219339954, 0.027911821280473044, 0.005058902648410627, 0.028110654093325138, 0.07493909022637776, 0.07688265879239355, 0.052633954611207755, 0.09426800840135131, 0.04546078094946487, 0.031189316750637124, 0.07160870464784758, 0.04802808943869812, 0.039138171289648326, 0.028843624583844627, 0.042581543126808744, 0.03936940923865352, 0.045951511045651774, 0.043134505062230995, 0.07812080878232207, 0.031432479952595065, 0.057813639885612896, 0.022003794820713143, 0.04561424860730767, 0.1441140254693372, 0.06969185679086617, 0.038081044264669926, 0.037040303860391886, 0.06184820232114621, 0.050543215192322216, 0.0453493621067277, 0.018099027652559534, 0.011809269265670861, 0.01985200760619981, 0.013350053507435535, 0.03863644553348422, 0.033177688983934264, 0.01727542863227427, 0.011668424903681236, 0.04632831511220761, 0.029413936659693718, 0.017027415601270537, 0.03244640126026102, 0.05353926621111376, 0.02567676085579608, 0.06463143761668887, 0.03113759881151574, 0.058360722315098555, 0.029723151853041987, 0.022399609742153968, 0.024109138009537543, 0.042350529094359705, 0.025336687586137226, 0.06338850395487887, 0.07995703989373786, 0.01671428695720221, 0.06632134265133313, 0.052033576648682356, 0.02707094675861299, 0.022063371891688024, 0.0702605437753456, 0.05627317201080067, 0.09592018010360853, 0.05480630143678614, 0.03590812407700079, 0.017959946633449624, 0.01492594345472753, 0.01570957336973931, 0.007206334516273013, 0.02554216156048434, 0.0959006247243711, 0.04324491967314056, 0.03882566859413471, 0.03570069592179997, 0.012558145465196242, 0.016047617819692408, 0.025514764012768865, 0.027575218717434576, 0.002110292041574472, 0.02525638466301773, 0.048014868183859756, 0.00604918718870197, 0.012728322047873266, 0.025640569494238923, 0.03624868419553552, 0.029798930643924644, 0.07401740218379668, 0.04913510914359774, 0.05302147613838315, 0.022043660449396287, 0.0334359665534326, 0.014900941135627883, 0.05350798235407897, 0.008032686692396445, 0.033109017847371955, 0.017561493907123804, 0.03029685660398432, 0.010362566448748112, 0.04080796454633985, 0.041688163565205674, 0.01598836135651384, 0.012721179618633218, 0.02816840081608721, 0.01773896813392639, 0.07307636232248374, 0.0026628277721881333, 0.02668526066866304, 0.023424267170152495, 0.04715199555669512, 0.014326897117176225, 0.0669184670384441, 0.13836046920291015, 0.05314270659748997, 0.11953341588377953, 0.0034875627025030553, 0.02183105846467827, 0.05746312905102968, 0.045935721535767825, 0.054059288664055724, 0.04470526274027569, 0.00333243963125694, 0.04819506333608713, 0.02431414379472179, 0.04262312375275152, 0.07158542411135775, 0.04674087118889604, 0.0260065356602094, 0.06487522167818886, 0.013307363476737269, 0.07998604726578508, 0.01881757079224501, 0.036861028123114786, 0.010874007978210492, 0.024556100900684084, 0.029912700610501424, 0.029464331455528736, 0.023902345980916704, 0.03501532466283866, 0.03795294363849929, 0.030399318784475327, 0.05001436160611255, 0.032391277075346024, 0.01667982755628015, 0.10377061992351498, 0.046374828687735965, 0.007203532166645995, 0.04563016364617007, 0.08664172941020556, 0.035113084595650434, 0.03154831945097872, 0.04073139186948538, 0.024267764229859625, 0.0469008901023439, 0.033569217260394774, 0.006597936269827187, 0.035510936818484745, 0.044086703431925604, 0.013977616975483085, 0.05803468623863799, 0.02765062770673207, 0.019674015996445502, 0.013759483234025538, 0.02122980688831636, 0.04186336469969579, 0.023172551034284488, 0.051162361433463435, 0.01746685353906027, 0.03158835640975407, 0.028073399128126245, 0.02802500261792115, 0.01723010588570365, 0.02947125251271895, 0.03409482066386512, 0.06033365109137126, 0.06481854364808116, 0.04173514532989689, 0.03528797360403197, 0.018426381783293824, 0.028861307206430604, 0.03702931837843997, 0.09895129102681365, 0.02522467672159629, 0.03211157815530896, 0.01903433389296489, 0.0771111554599234, 0.029740956611931324, 0.011451751708851328, 0.06284886505454779, 0.022695585020950863, 0.015085156607840742, 0.06048569043299981, 0.01355311444162258, 0.014434733295014926, 0.07447996629135949, 0.05209543868633253, 0.058318931343300004, 0.022540185234642456, 0.03127390971141202, 0.017906057382268564, 0.040951780043542385, 0.10573647836489336, 0.043353831328983815, 0.01852990417475147, 0.06494481901505164, 0.06428201243813549, 0.03776199370622635, 0.041795847072665177, 0.058298561722040176, 0.02928538480773568, 0.020905216091445515, 0.009546243868369077, 0.028684782928654125, 0.024328443920239806, 0.014194145133452756, 0.04053360230422445, 0.045509282632597854, 0.026793049349050437, 0.0117398941490267, 0.04433808369295938, 0.022870613129011223, 0.02450602501630783, 0.06415777267622096, 0.05043780816985028, 0.036616334824689796, 0.1223055435610669, 0.054272776136973074, 0.036625237204134464, 0.11621533893048763, 0.1325101809842246, 0.1340086441487074, 0.13649774129901612, 0.09374220483005047, 0.20151906513742038, 0.12886711289840086, 0.10401114701692547, 0.16963462318692887, 0.30457694509199684, 0.0965675160820995, 0.2333608136645385, 0.1412589265299695, 0.12281895029757704, 0.10844576691410371, 0.13878166303038597, 0.09895713321332421, 0.11853683793119021, 0.10588550501103912, 0.11793129970984799, 0.17384915346545832, 0.1293454258037465, 0.17192022768514498, 0.10789753776043653, 0.08845239332211868, 0.06348054723015853, 0.14362396033746855, 0.1528526744140046, 0.23774021438189916, 0.17115032114088535, 0.06923909072897264, 0.08562480219240699, 0.10498003395540373, 0.1144079387720142, 0.1115469162219337, 0.2345971316099167, 0.1005150428307908, 0.14572566827493055, 0.1433511349771704, 0.09932629697557006, 0.08070663788488933, 0.22569499643785612, 0.1037010225866522, 0.10119284503161907, 0.14178541542163917, 0.14954155923000403, 0.08329936768859625, 0.15140383930078574, 0.12591404707304069, 0.1299778747239283, 0.19399945863655635, 0.24748386868408748, 0.1424253282270261, 0.17589200527540275, 0.10861056271408286, 0.08231716110770192, 0.13305401323097094, 0.12266679560499531, 0.15788135172000953, 0.16115354613534041, 0.2187831944652966, 0.13721578062645026, 0.18696423114410468, 0.14934072643518448, 0.10983927428190197, 0.1268501675554684, 0.1945388125521796, 0.15594464992838247, 0.07954518949346882, 0.09582965674677066, 0.14595254324376583, 0.1397402294512306, 0.123992422329528, 0.16716973616608552, 0.12892302418393747, 0.1409545900034053, 0.13088913368327276, 0.06331357333276953, 0.18992841137307032, 0.08956263267568179, 0.1242809354194573, 0.14749353698321752, 0.10963308784578528, 0.1129239894715803, 0.11147153776671205, 0.11402462076927934, 0.12814247821058544, 0.18685215072972433, 0.12591905466147832, 0.10495112836360931, 0.12145156652799674, 0.060205591177301745, 0.11966414244047233, 0.1443863758551223, 0.13093108071812562, 0.17102386935481004, 0.23347776596035275, 0.10875469712274415, 0.13016444471265587, 0.15456418400364264, 0.11536987072655133, 0.15381206864757196, 0.15419192612171173, 0.12548312305339746, 0.10133501168872629, 0.06731818523257971, 0.15159236347036703, 0.13089396485260554, 0.10828242317906447, 0.13251486287585326, 0.10869265188063894, 0.11924172724996294, 0.14210968730705126, 0.10826900175639562, 0.1595647292477744, 0.16730164337371076, 0.07464396820536681, 0.12565507739782333, 0.32584103835480555, 0.1471809766122273, 0.12369050138763019, 0.14003347871559008, 0.13279000882591518, 0.1117314641763057, 0.12253397916044508, 0.10975148542118923, 0.09160566769008126, 0.2033594420978001, 0.13341544169400418, 0.13328939702894005, 0.11854493963931288, 0.2052436252789838, 0.14171007089316845, 0.17714101182562964, 0.1568518512483154, 0.11270532477647066, 0.16497075344835008, 0.11872281080910138, 0.07303571128951651, 0.13131139959607804, 0.09947820739554507, 0.15767625772527286, 0.1514847885285105, 0.1649956421128341, 0.1698395543332611, 0.10387757739850453, 0.15661441827458994, 0.12635172930146965, 0.15677797235548496, 0.24207133054733276, 0.18643430886524065, 0.14745183422097138, 0.1590943687728473, 0.13847252247588976, 0.13189492614141532, 0.11401513484971863, 0.17013406567275524, 0.08381138342831816, 0.10709164171878781, 0.1227739362844399, 0.08119641803205013, 0.1360663151634591, 0.07725651801696845, 0.1586094605071204, 0.21369955582278116, 0.10069906831319843, 0.09212994455759015, 0.21374154356973513, 0.09685449568288666, 0.17872753526483262, 0.11296605185738631, 0.07387203962675162, 0.12998559645244054, 0.250164271997554, 0.08495500670479876, 0.08789119736424514], [0.009320563121166612, 0.04996805837643998, 0.01935450912320188, 0.014114014388594245, 0.05777842391814504, 0.03292400170383709, 0.036373286973685026, 0.035489179593111785, 0.026745353426252092, 0.013529770292474754, 0.004113247476717723, 0.012389616026276988, 0.06857039446809463, 0.024138501612469554, 0.03709203876288874, 0.023914780135133436, 0.01665442999053214, 0.038265853455024104, 0.024573104988251413, 0.09234826998519045, 0.02596222053814147, 0.017157870743955885, 0.01865151970248137, 0.025922392228884355, 0.04920120184708919, 0.012584733859901982, 0.09412278155130999, 0.059213193000427315, 0.023024448892101645, 0.04882283036464027, 0.01272079794268523, 0.042018728862915716, 0.04169932546626244, 0.030761592023606812, 0.04958651813545397, 0.014050201562765454, 0.03650235790493233, 0.0278763508623732, 0.03663372567721775, 0.10029317545039312, 0.05446001109001892, 0.05419784890753882, 0.0031878067113991293, 0.027130444101723175, 0.09986225821610008, 0.042019699167992385, 0.03427205401073609, 0.022646971379539797, 0.05334002458091293, 0.010339698970450886, 0.02182232741532581, 0.02528467957329537, 0.01861840040822114, 0.025604978636173264, 0.0354530272473182, 0.052291196039212604, 0.045166079620165486, 0.07119506970047951, 0.05519091883408172, 0.07023689004459552, 0.03549746450568948, 0.04089666942932776, 0.10306878401232616, 0.03497056510033352, 0.08053282435451235, 0.05481453545923744, 0.019502461987680624, 0.05039088408063565, 0.016090211159150516, 0.011575705637889249, 0.053177976847759316, 0.06812167926026241, 0.09062965613390718, 0.009056318684348037, 0.0203912427781948, 0.04187899814652545, 0.04329263086297682, 0.01101856816759599, 0.011183548868367714, 0.022796849587133954, 0.06320498058838503, 0.049108568246343305, 0.05717704511646714, 0.049206966002072604, 0.010096774103918245, 0.051471580019486804, 0.011080487880722752, 0.018039252110091702, 0.04324107916493501, 0.044803667281355174, 0.023939383814909627, 0.05351277620398572, 0.031459848662572246, 0.05016004985996655, 0.05504249608410256, 0.011604176119102963, 0.05238923077870693, 0.04808899813464709, 0.03346952689545495, 0.012245488402965878, 0.09281835226075989, 0.030759994073637893, 0.018615084068317498, 0.022142344886170964, 0.02784371163163866, 0.02703571891678231, 0.016623213986999223, 0.05665907183928149, 0.04941704383652125, 0.018632907486919845, 0.04020809887775353, 0.027414519572630525, 0.012208009521210832, 0.03772685916296073, 0.03881730904270496, 0.08409118412860803, 0.05356315742912037, 0.02296743498715971, 0.02050173711696906, 0.10178388295961277, 0.053476267627307346, 0.03317266443212118, 0.10183634728725467, 0.056907239237001965, 0.03946702328643628, 0.1279727087489196, 0.044298474211245775, 0.04448966502345034, 0.04119102131309254, 0.019279227359220386, 0.08445731483932052, 0.027198285729225193, 0.014522528941077846, 0.038754011903490336, 0.03625846527782934, 0.0374696876055428, 0.039645708698247156, 0.04236787923478654, 0.04684166078056608, 0.055490736317421706, 0.09875486192426511, 0.04197714484429785, 0.039797690364399126, 0.0345247743784317, 0.008771336521022022, 0.016538027308083007, 0.01582577758069549, 0.019773341648812805, 0.0609972176275083, 0.08101089977260147, 0.07333857539509024, 0.048351716715842485, 0.033439206558146646, 0.07699880363153559, 0.04227871973333614, 0.00407048492758934, 0.005618981992094112, 0.011419994573641037, 0.029820718403373445, 0.03321970047961388, 0.10515553703797714, 0.015398658446169325, 0.009427738575530904, 0.02280175030630614, 0.08788498198347432, 0.05305606785363384, 0.02086392553922321, 0.02893153897353581, 0.010626944048064095, 0.02108047659774976, 0.03504816236506615, 0.02791176360499646, 0.026023863748248135, 0.042335146705486944, 0.021416512584047656, 0.018920540177662457, 0.010965819703415036, 0.03784980631566473, 0.021674476331099868, 0.0458215240921293, 0.03030204400420189, 0.05852068016039474, 0.05382240191102028, 0.013036297218474959, 0.06455457995512656, 0.017839491400601606, 0.018581072500507747, 0.037423455622047186, 0.06576502536024366, 0.03713755828461476, 0.054382295081658025, 0.03519486502877303, 0.013143729667977562, 0.06174201837607792, 0.022692304304135696, 0.09656970096485955, 0.013600575421670718, 0.01528521248006395, 0.025998193072155118, 0.012233328207262924, 0.02549134607293776, 0.031090712041727135, 0.028211708313652446, 0.057092764281800816, 0.061424484343401024, 0.032206376282764335, 0.04011677824226873, 0.023910461259739738, 0.08045658415981702, 0.04891648516058922, 0.03856256324797869, 0.030419562876756703, 0.06343188948397126, 0.04305126238614321, 0.02582943462766707, 0.06618193763175181, 0.07547266302364213, 0.027818551553147178, 0.030013262892940214, 0.024190295886780535, 0.03486311908013054, 0.018500116487432803, 0.043570599518716335, 0.06215164318148579, 0.030339302362075875, 0.025796211856816496, 0.014391400352386492, 0.031860920534070046, 0.015583666108016456, 0.029477444144764116, 0.01944775679813964, 0.0741405359336308, 0.03653266806421535, 0.02977997237550361, 0.01931301670681153, 0.011559341069576996, 0.05507098437686052, 0.04556947886677725, 0.08033788124365465, 0.053751169304762564, 0.014233907285545553, 0.0356727674204324, 0.04510456702804991, 0.029535686198089803, 0.007794833026959428, 0.05928190824176584, 0.02250199219478028, 0.026151967767093862, 0.018252033906589662, 0.012984164524823427, 0.009240451884189886, 0.009554027513201748, 0.030005785437034707, 0.10261961418603148, 0.02095888481874551, 0.015210524434223771, 0.03634798101016453, 0.030540834047964642, 0.060379553985382826, 0.022307597000950148, 0.028281071555933783, 0.017875650531745384, 0.07094044943473168, 0.020982845586591532, 0.020048435012410794, 0.05674781743437052, 0.04207456890227539, 0.05719645121800048, 0.03525209267224584, 0.04316647084695952, 0.06147441095007317, 0.019136901246383786, 0.07413552834519319, 0.04538032705230372, 0.05443287308194807, 0.042264735126601796, 0.0944665681038584, 0.05515081062912941, 0.015199021569320133, 0.03469464562035032, 0.04172857032556619, 0.020808529940300753, 0.029537212901881764, 0.028455796019573296, 0.036880183166691234, 0.020479255555463687, 0.09763857682368585, 0.01789227972871491, 0.04548259585031441, 0.06289759743958712, 0.028716806388859237, 0.0535465231431382, 0.04639080140207495, 0.018176095659977624, 0.03571459910433207, 0.02961654043091195, 0.06172804055469377, 0.015325122213523303, 0.066444503542568, 0.03313892088564379, 0.02527186713580574, 0.022192547995863215, 0.03445030855281012, 0.048772846082491536, 0.04634732087807996, 0.01634777457054172, 0.024918248610837117, 0.044890699575522115, 0.0069289184424893135, 0.07752474290984017, 0.00523940780632464, 0.04668309393205813, 0.02799787648421313, 0.03827018929379327, 0.02618854589361165, 0.04465690015682152, 0.08434121749762978, 0.005155179558122265, 0.03330940959442939, 0.026540452813995734, 0.008475451996283872, 0.04566621421171086, 0.0496514166173126, 0.05100392011393394, 0.0070292177926083756, 0.10079305219863142, 0.03841927022274051, 0.0884533907685961, 0.022663583613133857, 0.049704705365002155, 0.0712237920878189, 0.008319802000187337, 0.020318105184872235, 0.004224127308199448, 0.01709057703348143, 0.034148954187652895, 0.005648030076242451, 0.03781109928552594, 0.0338357831351459, 0.0313472152421517, 0.06852800638547965, 0.08303029462695122, 0.04339410577501569, 0.010214648359189076, 0.04577209960137095, 0.006671236711554229, 0.03447330749726721, 0.01889243864986513, 0.011763517345700945, 0.0394520548039249, 0.0060226081238527384, 0.027996483791087354, 0.13746151886880398, 0.19780374664281095, 0.10523035230913333, 0.150814219510981, 0.1191580095993621, 0.21671026998332568, 0.07917559825416122, 0.09891278416450534, 0.1319062848176275, 0.1727699028061969, 0.1207767091691494, 0.06257578863629273, 0.14791139241840157, 0.054562765040567944, 0.1371736978845937, 0.16756465711763927, 0.10036140893186841, 0.12403341941535473, 0.1320612215037857, 0.16453077777155808, 0.11034609922873122, 0.08448000505034413, 0.07013040754411902, 0.09601799092654671, 0.07858558491404567, 0.1442471676106964, 0.17027777938970498, 0.20095418473439558, 0.17132006346115045, 0.11643928262804236, 0.0676528929865786, 0.15291283332875796, 0.2531854084559849, 0.08737761420863015, 0.18895334298057215, 0.14031192234584264, 0.1659173776528665, 0.1171852775982448, 0.1396978481539658, 0.18762356362172536, 0.1293434580521924, 0.13833400633718285, 0.12159962286906582, 0.08134567538010222, 0.12676088591771467, 0.14047094381281308, 0.1367166502667325, 0.18621482992810862, 0.11175200343132019, 0.0817799445773874, 0.09074354823678732, 0.09278362483850547, 0.09707214936081852, 0.10535573879522936, 0.09748131954776389, 0.18960332524563583, 0.10853900441101619, 0.19818631825702532, 0.13228118898613112, 0.1857050194271973, 0.17354333773255348, 0.10014148216162409, 0.15889855713716575, 0.13695401538695606, 0.13727477246097156, 0.14106259920767375, 0.13411377636449678, 0.1577259400593383, 0.12667905459446566, 0.11716923703040395, 0.1881161800452641, 0.13272889996213572, 0.17192108263926847, 0.12116244275655065, 0.10969348424779517, 0.10126275449459042, 0.1206890017326389, 0.10960602786924158, 0.14999183506837913, 0.18005720605807646, 0.1400425439434392, 0.11834391685468809, 0.12066718004643917, 0.14433881055031503, 0.1065122474517141, 0.11586492987615721, 0.15030283480882645, 0.101443794422916, 0.12207618515406336, 0.13374481616275652, 0.17681055170084747, 0.1523024367966822, 0.12341395765542984, 0.23549819897328103, 0.09395489163164582, 0.06071635841258934, 0.17268774578613894, 0.12254863551684789, 0.08689542008297783, 0.09079987342868533, 0.19693276552217348, 0.11380818166903087, 0.0568263408994036, 0.13008379404033932, 0.10532635822892189, 0.21706130328987325, 0.1159662487251418, 0.1214461111064468, 0.11039557800229106, 0.09332171667899404, 0.16528787357466562, 0.11505614327532904, 0.08283121923782996, 0.18790621416909353, 0.08899678196758032, 0.15204181149601936, 0.13181914735053266, 0.09203104807862214, 0.14128051751426288, 0.144168742533241, 0.15869419596024922, 0.08578446148229496, 0.2099317322884287, 0.10475317255726882, 0.11631848982402257, 0.14900447162134306, 0.1417082795607192, 0.13438660172479494, 0.1024434393537896, 0.050794734553034813, 0.0957992040951337, 0.13404916626002106, 0.09029597975313663, 0.17123630509844848, 0.07638778963259288, 0.1046439894874181, 0.09538489739809718, 0.18621591558413847, 0.14860944210418633, 0.17027522809803486, 0.13941783032247, 0.1077500581741333, 0.17871039547026157, 0.1585552998419319, 0.08174935621874672, 0.16063773738486425, 0.16272349974938802, 0.1075889536046556, 0.1344966601048197, 0.30355129869920866, 0.11216207606984036, 0.1876021083444357, 0.08830633187400443, 0.19238032480435713, 0.1033812358177134, 0.05871540614004646, 0.2334887853690556, 0.06692245003900357, 0.09219782520085573, 0.09497591720095702, 0.21238348287131104, 0.09173956979066133, 0.10716369535241808, 0.1453220620751381, 0.2153547198644706, 0.17113240781639302, 0.0786404919677547, 0.10968501613076244, 0.1549318414181471, 0.09968942177614995, 0.07062677626631089, 0.0916830071115068, 0.09351861397070543, 0.12067917654556887, 0.08064924739301205, 0.043400188841457875], [0.03101978816890291, 0.06958677207252809, 0.031090939350958382, 0.03620919345745018, 0.04070032175098147, 0.06153501769793885, 0.038509467882769446, 0.06441220295216356, 0.013780526301291372, 0.05877735638724906, 0.025397560658997724, 0.05460871203935572, 0.05350905443940844, 0.07345420454761811, 0.07764934908066477, 0.05964813394738095, 0.03398809049810682, 0.057932641357183456, 0.014974214435954179, 0.02116736300688769, 0.021360331580841115, 0.02458974945225886, 0.021327872161886523, 0.050974352950496335, 0.05122629300292049, 0.018398558454854146, 0.03647838865539857, 0.018133789001564895, 0.06018839031457901, 0.041333245645676336, 0.016440423438325524, 0.034002098853566816, 0.05021276863824044, 0.045553957378225665, 0.04197417964626636, 0.010748362800638591, 0.037266218702175787, 0.05761880534035819, 0.019531723810359836, 0.020146507071331143, 0.08330237359872886, 0.031726095625864606, 0.006731814621681613, 0.009979541064240038, 0.048868811290178976, 0.015826278000271747, 0.04304847360721656, 0.05771669080214841, 0.028843977422054325, 0.03409940756059118, 0.03181006094174726, 0.037666818991835625, 0.023468224364998083, 0.035626253844904046, 0.04326197125815919, 0.039648531403924735, 0.03507262355248843, 0.04727719883833613, 0.052316413793180666, 0.010420678732251483, 0.013795227610639163, 0.07411296027047293, 0.021573174445490752, 0.019031205846528922, 0.017150868262563432, 0.03608923525150333, 0.03542567889339157, 0.0459419606652643, 0.029853227016116892, 0.06202173765216555, 0.07760147164974894, 0.06446928810328245, 0.058079381340316365, 0.004613687409021492, 0.07660743820347957, 0.0441786245709019, 0.1344551473323788, 0.1508199599172388, 0.13632935604878835, 0.21604856263313973, 0.227955196584974, 0.4153638274541923, 0.607786452131612, 0.48716252190726145, 0.20302522288901464, 0.11025823572916643, 0.0575588092740093, 0.3679128965096814, 0.07846682092973165, 0.25179215893149376, 0.19422801637223788, 0.11020885195050921, 0.16897725846086228, 0.20635199866124562, 0.15090094985706465, 0.03030810671459351, 0.12137102442128317, 0.06034114890332733, 0.03256534166367991, 0.03221244917118123, 0.058914169403059144, 0.019978993738602315, 0.018863621267623136, 0.05216942275209086, 0.033092101969357045, 0.018746210960671306, 0.0473566315402942, 0.037987297866493464, 0.04385154355051262, 0.08996744666780744, 0.023122821202767745, 0.05795461232108729, 0.09094951075634786, 0.06877656733351094, 0.040837060127939494, 0.01652250751586897, 0.010644404450431466, 0.014401122062866176, 0.051543077254401784, 0.032980140298604965, 0.06625682075640985, 0.04842506295868328, 0.03379668594737138, 0.051256443706474135, 0.018041189327569943, 0.07798192623470511, 0.022644772926079373, 0.0314010366398309, 0.02296844939701259, 0.03180586759533201, 0.059549739584326744, 0.012383486310552274, 0.03780412394553423, 0.004021124049488987, 0.020568579601656114, 0.06618765089660883, 0.05579040791573269, 0.06248109228909016, 0.03282566501625946, 0.05577682703733444, 0.023958984995260835, 0.06399659346789122, 0.030362962878176143, 0.05089417386001774, 0.033954821926142485, 0.019190637827185646, 0.04538325832358428, 0.011762348569131323, 0.038922023959457874, 0.026602476003712842, 0.025103968734453832, 0.01959968078881502, 0.011481601312490446, 0.034793969576380084, 0.04015627237302916, 0.039158469664731195, 0.040418892566646845, 0.01465859217569232, 0.03409109211393765, 0.008605496625282934, 0.11130236541586262, 0.02665885547841234, 0.010733507124574056, 0.04235112281250102, 0.04289705851780517, 0.07619649704013552, 0.04015026394543903, 0.003200784541799554, 0.044201586195932965, 0.02417315948488457, 0.030954682733863592, 0.005642136151436716, 0.026117949413933923, 0.026534909182893376, 0.013209659523064536, 0.05952639119433505, 0.05844488101346152, 0.057420707041663785, 0.022967609709927013, 0.011637180910578795, 0.041475497119660885, 0.06822210244302239, 0.029398832470178604, 0.019077420866649066, 0.02152503577859274, 0.0667790077360613, 0.02564329211600125, 0.03265528487307685, 0.035832202793764215, 0.058158138899930885, 0.07325023013566222, 0.04442275129258633, 0.05023587614830051, 0.006231278422222073, 0.01276043795847467, 0.016285722543086325, 0.046202569002551694, 0.035821431050343175, 0.034647229593247175, 0.03295254088672144, 0.023306582056518112, 0.04346224765426346, 0.045190659551216025, 0.009446859692356415, 0.027484532512192215, 0.05289131276575582, 0.01862665648306055, 0.03185495960393122, 0.04770812964332955, 0.018815029678600173, 0.009394895784290773, 0.016790954628959298, 0.03972719057596155, 0.022606652828731706, 0.041046737626727135, 0.024897278486085788, 0.05109534592234662, 0.02242420663657997, 0.0279730421025306, 0.022353007957073193, 0.02790931748625423, 0.01731284474954009, 0.022459051106125116, 0.02965045700381909, 0.018658260947891643, 0.02740494883619249, 0.03348751146612423, 0.008478636870027652, 0.07917345408350229, 0.005219416892422097, 0.09691634414983646, 0.04676501007218446, 0.03144265797787479, 0.04359468072652817, 0.03544752772099205, 0.04940426362944501, 0.04744553319843752, 0.08033600848700319, 0.03141888889617153, 0.024840505461075475, 0.039565244623060734, 0.018531612386660914, 0.05004982523886221, 0.05959336260067565, 0.04533350135066679, 0.016431129204907587, 0.02361302373797766, 0.06858414837292262, 0.05081184381353004, 0.04567244994853224, 0.09490272362849542, 0.04876205398301993, 0.1954893044063023, 0.14879228015031132, 0.10800809825637511, 0.10201043223163911, 0.30525735286729677, 0.389023912272283, 0.5421320008380073, 0.29374744477016584, 0.2436820369746004, 0.11327418139470474, 0.05183302205322044, 0.1668702715209552, 0.21806311953280652, 0.157620156449931, 0.32464393973350525, 0.08172744632299457, 0.22702712352786744, 0.2699460376586233, 0.2048356221722705, 0.07938106544315815, 0.17499788611062936, 0.034890426721956046, 0.0655208138216819, 0.04711053367438061, 0.009413842178348984, 0.08320682908275298, 0.012939856188105685, 0.040290934432830126, 0.03981434500643185, 0.03612239186518958, 0.012519160235699798, 0.03046992713851588, 0.022536178485357335, 0.01093170211450862, 0.046149422747216055, 0.0679826270788908, 0.03069344675168395, 0.012941466012437428, 0.06106140025492225, 0.014919714503256338, 0.04064231039956212, 0.023415266403130124, 0.009582968728084649, 0.05862050623233829, 0.01276233870469566, 0.03564262350222894, 0.007414434421142297, 0.05492338265425392, 0.03649282788059541, 0.054154789075255394, 0.07916920645428555, 0.04197236117241638, 0.012806233983220798, 0.03326220052050693, 0.04293999282111015, 0.06103533093950578, 0.03837917898116367, 0.011145988562410431, 0.02817100130154618, 0.07659295826618161, 0.029966759495437145, 0.07015271777553217, 0.020718946354463696, 0.06781998223492078, 0.10407751452709947, 0.02404852956533432, 0.08944213164172002, 0.049202348571270704, 0.010720604781194456, 0.0389020309251334, 0.03440449047567589, 0.018770624650642276, 0.057669145853391716, 0.03550424985587597, 0.02499955067677157, 0.0364501615986228, 0.015352536724614245, 0.029348946575607573, 0.04299755633941718, 0.04070644213684967, 0.01827940940191703, 0.047217508112745624, 0.1118382995149919, 0.07409738789179496, 0.08004031649657659, 0.06998426467180252, 0.04439654966284122, 0.01263121435684817, 0.08592656028590032, 0.03209655199732099, 0.027449908566528132, 0.008224936867398875, 0.06215131069932665, 0.005012831816981945, 0.02866481025038021, 0.026021482090332677, 0.05593507158170853, 0.03151553603155272, 0.03188982951853957, 0.041456267437232394, 0.142852927425078, 0.1457329150289297, 0.10371249661381755, 0.12612716135169777, 0.09026220227990832, 0.10913686161594731, 0.10402475164404937, 0.10515687375196389, 0.10547657909670047, 0.13850028812885284, 0.11135490438235657, 0.11817763506301812, 0.08980275943343129, 0.10989103971847466, 0.21275080101830618, 0.10038264029260192, 0.13430886875305856, 0.13419391135019915, 0.13206308068973677, 0.061809369762028964, 0.13014423793980054, 0.12490327416786126, 0.07711336748408419, 0.16200512115444454, 0.14631977996655873, 0.16827156847076757, 0.08466698894543306, 0.14334363037986414, 0.19380281918815204, 0.1590125374495983, 0.0919353271435414, 0.13827923499047756, 0.07023346344275133, 0.07447373055453811, 0.11098028519856078, 0.07050952541508845, 0.0887849840468594, 0.09702583256044559, 0.08529432849692446, 0.10479456997875657, 0.1630256785345929, 0.15126939437219075, 0.10342132366661515, 0.1000568892008492, 0.12312021984585694, 0.13102379574307374, 0.10868585295975208, 0.09081170029406037, 0.10894160637898104, 0.11564655016575541, 0.1016181982787592, 0.14344583132437297, 0.13986050656863622, 0.18854814900883607, 0.2927959215428148, 0.07550383492239884, 0.1162851330425058, 0.24339105401720318, 0.08550459971385342, 0.12573564664593764, 0.14622473078114645, 0.27327797029699596, 0.14732211189610617, 0.08308319321700505, 0.13998835613684996, 0.12238497287034988, 0.09620390273630619, 0.09290348126419953, 0.140426404774189, 0.10896591150334903, 0.16330469213426113, 0.19071662479213305, 0.18923920978392872, 0.16800422567342008, 0.19935360204960617, 0.24522573128342628, 0.3141125062746661, 0.3553690096097333, 0.4085392579436302, 0.5863981598189899, 0.9646331753049577, 0.5735959410667419, 0.8961484187415668, 0.6898369693330356, 0.6921432827200208, 0.20614655182829925, 0.14197068262313092, 0.49065914856536047, 0.8919255424823079, 0.5099759548902512, 0.5665345628346715, 0.4058263935148716, 0.4873084883604731, 0.5738444477319717, 0.4742872385042054, 0.20134506161723817, 0.42338259145617485, 0.32067260997635977, 0.2045968592699085, 0.16598171634333475, 0.08470505475997925, 0.1355471137378897, 0.1502350898725646, 0.13488825623478207, 0.15316721610724926, 0.1557089811457055, 0.1508056835404464, 0.14225912785955838, 0.1847766206732818, 0.15001447099660123, 0.08544317193861518, 0.2022675842578922, 0.15306756645441055, 0.14030502843005316, 0.13444553927651473, 0.07159107630806309, 0.12058521301618644, 0.08952346084905521, 0.14074045792222023, 0.09760525396892003, 0.18861525612218039, 0.09949636499264411, 0.13220998352127417, 0.10615925996431283, 0.11822697812957422, 0.21374846462692532, 0.10527247576309101, 0.1706792414188385, 0.11499719215290886, 0.13615706243685313, 0.11541753102626119, 0.16624194809368678, 0.10354751082403318, 0.11958172757710729, 0.08568749204277992, 0.2694223443312304, 0.1911880573523896, 0.10566783776240689, 0.10384840717805283, 0.20138923424695218, 0.20919929444789886, 0.12530317556645187, 0.1788932199456862, 0.11768701353243419, 0.10922290664166212, 0.12587868182786874, 0.14489586065922463, 0.1002020210559879, 0.15406083315610886, 0.11280399733888251, 0.11616260318883828, 0.09957018960267305, 0.05661477028791394, 0.1496551459921258, 0.16639355995825358, 0.12300020057175841, 0.10501074445034776, 0.1363101399370602, 0.14896050255213464, 0.20995177621287958, 0.22196705719189985, 0.1354358068534306, 0.12132366267698151, 0.14029510824808053, 0.27826726543051855, 0.16532680791403565, 0.11596395527677876, 0.13172161472695215, 0.15333820693194866, 0.12468023970723152, 0.08003777877560683, 0.07989386828350169, 0.14364181937915937, 0.11574150435626507, 0.12439581139811448, 0.1522482761314937], [0.05870717551027026, 0.012439867481589317, 0.019056557611163174, 0.04636873205059341, 0.09759566626910653, 0.002356252504146791, 0.052127787843346596, 0.04413821102519121, 0.030598750404481376, 0.08774255069770984, 0.023628473980352283, 0.035100870965314765, 0.006703756350491728, 0.07616726575153214, 0.01980203010940126, 0.053570777377379794, 0.07944969926029444, 0.08636748591171843, 0.059193814040294716, 0.08143075688609056, 0.03758064843714237, 0.05631675770772355, 0.09871081143085446, 0.061468446627259254, 0.03699548322973507, 0.07282037141599826, 0.05868259897189481, 0.04871711800140994, 0.06748049080904041, 0.006788018949529422, 0.10474173924220459, 0.039995707238891294, 0.03235733336103814, 0.03025177473734532, 0.008528317507755543, 0.0702151565679482, 0.03452037747151085, 0.06799656418817383, 0.03141518070229462, 0.04641343393762197, 0.03930705865578992, 0.036456492330346785, 0.08152411651930638, 0.06299831917775528, 0.005366703096245016, 0.038244326931557486, 0.055604513069348674, 0.02268955623731017, 0.02182432061194309, 0.03319757684533085, 0.08302783154483352, 0.007889545489368694, 0.04146024704511676, 0.027987277767221843, 0.014364850973444325, 0.01426412075358842, 0.02651919431186148, 0.06614972078906638, 0.043272719252854586, 0.07330014995698418, 0.04855999303981662, 0.04398746768544827, 0.06974528463823454, 0.061149575880595615, 0.03749961778521538, 0.07526711441044297, 0.0627746129674571, 0.05671850132888981, 0.02616718052221196, 0.050269209181091616, 0.2901262119412422, 1.025492555328778, 1.3279689188514436, 2.269627549818584, 4.217261246272495, 3.720763385295868, 6.3960113525390625, 5.886729674679892, 7.164924195834568, 5.601363250187465, 9.969839879444667, 11.550103425979614, 13.970020294189453, 13.583799464362007, 12.613253372056143, 16.173889875411987, 12.550093378339495, 19.805338076182775, 25.219028745378765, 18.635417767933436, 12.542853355407715, 12.127450960023062, 13.494034818240575, 17.092049155916484, 16.929053102220806, 10.481133495058332, 8.035919972828456, 7.728335380554199, 5.128694670540946, 3.270323395729065, 1.5279129956449782, 0.4424680716225079, 0.10240299866667815, 0.06092430225440434, 0.05958799538867814, 0.015272444147350532, 0.013876537310092576, 0.04318643334720816, 0.004884688782372645, 0.08813295939138957, 0.019309527340478132, 0.057017664025936804, 0.024360525055921504, 0.04036904738417693, 0.06726171754832778, 0.030515032753880535, 0.05764281190931797, 0.024314415208729248, 0.052868809151862345, 0.04772539157420397, 0.020278536415259753, 0.0283827992222671, 0.08857075697077171, 0.030167748353310993, 0.053256432459290536, 0.043830352901880226, 0.042537903147084374, 0.008792797735493098, 0.02868923411837646, 0.049367541314235756, 0.060622075971748145, 0.1070654366963676, 0.03359322722202965, 0.018449189041608145, 0.03351569781079888, 0.038530926552734206, 0.02020772619705115, 0.012602741331128138, 0.02692442899569869, 0.07075618646506752, 0.04077499792245882, 0.027089246848065938, 0.026599258051386902, 0.0786765425332955, 0.01045263179444841, 0.04949494304933718, 0.09763840718993119, 0.06063868650900466, 0.06567161822957651, 0.05848980003169604, 0.03205684752070478, 0.04146995688123362, 0.05728915945759841, 0.02126761485955545, 0.07120544450091464, 0.024994027401719774, 0.02228603994340769, 0.03054473562432187, 0.043085809996617694, 0.038557955995202065, 0.0520730164966413, 0.04491163916619761, 0.03280981104554875, 0.03487892894606505, 0.03203225062627878, 0.035028919111937284, 0.039803637723837576, 0.0033982859417197426, 0.026332442815016423, 0.032631990765886645, 0.037463261878916194, 0.046748263827924214, 0.023019924759864807, 0.010049766045995057, 0.019394803925284317, 0.030942011092390333, 0.0071850878885015845, 0.01673372189647385, 0.014655206285949265, 0.01749120107186692, 0.07189871051481792, 0.03901666941653405, 0.0037568516231008937, 0.02326029579022101, 0.02787708368019334, 0.04023750997813685, 0.013459591111833496, 0.035413868991392, 0.03757009721760239, 0.03973858317892466, 0.01925719023815223, 0.05578702202598963, 0.08111133652606181, 0.07454258150288037, 0.05226898419537714, 0.06873896970812764, 0.054200196638703346, 0.15887224354914256, 0.08663782104849815, 0.017423118564433286, 0.037436534384531636, 0.03642412960263235, 0.059590071705835204, 0.027199890464544296, 0.08045038234974657, 0.035401519654052596, 0.0016042082882319975, 0.016154454854716147, 0.01531432502503906, 0.027967557843242372, 0.03072100884414145, 0.060475335988615236, 0.045394237020186017, 0.06117189968270915, 0.08060158709330217, 0.03053549737004297, 0.011497153335117867, 0.05312644211309297, 0.06339078383254153, 0.05466441297903657, 0.017187775478565266, 0.1048560995342476, 0.015632700441139083, 0.012824679109533983, 0.017122807446867228, 0.030434969014355114, 0.046795167561088286, 0.07503200202648129, 0.05315721028351358, 0.03590335397581969, 0.043236519409609694, 0.043050115661961694, 0.025505949842876623, 0.02731438137457839, 0.04117757614169802, 0.06645895633846521, 0.08182193232434136, 0.02755538174616439, 0.040187311957457235, 0.0435541993273156, 0.02629250594015632, 0.07800317795148917, 0.08882359947477068, 0.0983540987862008, 0.04029115156403609, 0.05713072831609419, 0.2853471540978977, 0.8663052543997765, 1.4906757537807738, 2.5612977274826596, 4.160331615379878, 4.322125196456909, 6.575194537639618, 6.53054758480617, 7.396835088729858, 7.586874399866376, 12.12321777003152, 14.199499317577907, 16.85015630722046, 16.149011850357056, 14.393498233386449, 17.111325195857457, 13.525438938822065, 22.24122190475464, 28.269390412739344, 21.13292690685817, 15.585889884403773, 12.500921845436096, 15.70829803603036, 18.80420340810503, 19.741030761173793, 13.278958542006356, 10.603314093181066, 10.215159058570862, 6.826949051448277, 4.337006066526685, 1.8510739292417253, 0.5217679707067353, 0.13430054991372994, 0.006513017612243337, 0.05690793473539608, 0.032777719731841765, 0.02723711489566735, 0.05185260457385864, 0.0726622116885015, 0.10208922371800457, 0.05342336225190333, 0.12770200041787966, 0.03895021369680762, 0.05737538090241807, 0.054553391079285314, 0.01800568159004407, 0.03348003740289381, 0.04187212797946163, 0.0896575122273394, 0.046744226544563255, 0.07947695601199355, 0.1311761811375618, 0.06189197461519923, 0.03239146027980106, 0.13305874940540108, 0.029773366837097064, 0.0840275918266603, 0.02526666277221271, 0.02384947962127626, 0.03461917556290116, 0.08003292046487331, 0.08313750994524785, 0.059123300681156774, 0.037872791689421446, 0.013305674772709608, 0.07990467056099858, 0.02581548734035875, 0.01263780886906066, 0.06183853319713047, 0.04973198247275182, 0.05099587608128786, 0.0534230738745204, 0.034242642910352776, 0.0207354618968176, 0.027994164897661124, 0.01963530048461897, 0.06725778204521962, 0.06676410032170159, 0.10123728907534055, 0.046588937020195384, 0.03535225461902363, 0.042619636082755666, 0.025979828521875397, 0.04189768839361412, 0.07978270389139652, 0.10796997815902744, 0.05970568050231252, 0.009117568344143885, 0.03946685704535671, 0.051793687378189394, 0.05243736605292984, 0.042127213041697226, 0.05246677376063807, 0.04673068637826613, 0.04194138604881508, 0.012650061515159905, 0.03785078340609159, 0.03742269905550139, 0.06345747703952448, 0.05508448722373162, 0.08686264684157712, 0.03690159433920469, 0.026175131256292974, 0.04600910170535956, 0.05369988223537803, 0.04761975724250078, 0.06736134684511594, 0.08475187367626599, 0.15027411920683725, 0.08919507704143013, 0.1735243116106306, 0.13450159983975546, 0.1244920819465603, 0.1726306402789695, 0.147919412702322, 0.17299208231270313, 0.1485417921628271, 0.19687285088002682, 0.20817029609211854, 0.15134602811719688, 0.19746069290808269, 0.16221347211727075, 0.15339348039456777, 0.2926814119730677, 0.14422149184559072, 0.19120056953813347, 0.2426609503371375, 0.29859259192432674, 0.23531855004174368, 0.22686723353607313, 0.1553123774273055, 0.17732036220175879, 0.18238392977842263, 0.12271581297474247, 0.18091734418911593, 0.1372057790202754, 0.23724219681961195, 0.18459640177232878, 0.07166331993149859, 0.12165306428713457, 0.10248337113963706, 0.11070786695927382, 0.14750748766320093, 0.11322580184787512, 0.18113074345248087, 0.15562564347471508, 0.1153973921069077, 0.1551777832210064, 0.18620884524924414, 0.19074952016983712, 0.09391748399606772, 0.263079507542508, 0.18906042937721523, 0.16100563907197543, 0.1395382024347782, 0.17172050768775599, 0.19220846545483383, 0.08875435497611761, 0.15528873726725578, 0.08839457535317966, 0.09247620776295662, 0.11364865130079643, 0.13292723574808665, 0.10752899146505765, 0.21916069063757146, 0.12812570482492447, 0.12170467366065298, 0.10189407026129109, 0.17667754526649201, 0.1427295697586877, 0.11782744313989367, 0.2877165712416172, 0.19790256848292692, 0.1814306830721242, 0.1550064938408988, 0.1643717155924865, 0.6095683936561856, 1.472243919968605, 2.417845219373703, 4.766277500561305, 6.772391361849649, 7.765033159937177, 9.305986404418945, 10.636869549751282, 11.131331154278346, 11.048483439854213, 17.06691231046404, 20.6902345929827, 24.91404972757612, 23.290627445493424, 20.606418473379954, 23.039373636245728, 20.77906036376953, 31.571985585348948, 41.897700037275044, 34.18752724783761, 23.8872640473502, 19.38793546812875, 22.543788160596574, 27.221317189080374, 26.135157414845057, 19.858253819601877, 15.800280026027135, 12.884192296436854, 8.631154775619507, 6.221349273409162, 2.6401743292808533, 0.6692491854940141, 0.42390886321663857, 0.11684487015008926, 0.14088152535259724, 0.061115228437951634, 0.1289632205984422, 0.18804261327854224, 0.1277235506900719, 0.18269980140030384, 0.15089292957314424, 0.2043593448719808, 0.12024453415402345, 0.15786478189485414, 0.12642843089997768, 0.08749742992222309, 0.1766515030924763, 0.11720669216343335, 0.17077184787818364, 0.2817104235291481, 0.15631711137081894, 0.21857240077640328, 0.1863134346370186, 0.10293418302067689, 0.24162238463759422, 0.10005217338246958, 0.17219411156007222, 0.14228901054177964, 0.08560324513486453, 0.1482295167765447, 0.1972844230809382, 0.2930059959845883, 0.13715860726577894, 0.10012088862380811, 0.0809679077938199, 0.19426103388624533, 0.149611964023539, 0.11997580714523792, 0.08774083400411264, 0.12033609566943985, 0.11698741678680692, 0.11725469173065253, 0.17060013780636446, 0.15723104375813687, 0.11131900987987008, 0.17967805426035607, 0.17523630974548204, 0.20639632056866372, 0.15696914281163896, 0.16412248968013696, 0.12921733196292604, 0.11101309236671243, 0.1530546878597566, 0.13162492348679475, 0.18312662706843444, 0.23879311074103626, 0.10343855845608882, 0.14031171878533705, 0.1386716589331627, 0.08515007873731, 0.15088357936058724, 0.13912519173962729, 0.11686614900827408, 0.1593863559620721, 0.14904465446514742, 0.1636181753128767, 0.10215189999767713, 0.18772804444389685, 0.10741762351244688, 0.1934409157506057, 0.20675118081271648, 0.22111773490905762, 0.1545304065304143, 0.1125922469156129, 0.16115588029580458, 0.09047766428972993], [0.03247220594702022, 0.05131585284003189, 0.05013407214677759, 0.026091266024325575, 0.03639213667650308, 0.05167514391775642, 0.05044408801144787, 0.03794351539441517, 0.013034610210784843, 0.012199105445428618, 0.06837716126548392, 0.027296166102002774, 0.0254528697447053, 0.0618134681135416, 0.009275303139085216, 0.02815049427694508, 0.014755466620304754, 0.013198734261095524, 0.026495347198631083, 0.04993826729644622, 0.037944777469549856, 0.03441269396405135, 0.016573306040040085, 0.03262696282139846, 0.005745164484583906, 0.0382234348383333, 0.02141279760482056, 0.009800105023064783, 0.06500174810311624, 0.022055936844221184, 0.023135272320359945, 0.0171116251897599, 0.03783809819391795, 0.02891038903700454, 0.03773043164983392, 0.07198491160358701, 0.04501344656039562, 0.03620509171326246, 0.04175121982448867, 0.01916961681230792, 0.027792366886777536, 0.014173376872869474, 0.030880987045488188, 0.019766179711690972, 0.017628098904554333, 0.028511542760367905, 0.035469630999224525, 0.029683393093624284, 0.011745643885140973, 0.03286540341962661, 0.05275725460212145, 0.024330638981025134, 0.07326312230101653, 0.032907255459576845, 0.06229961131300245, 0.009030213745843087, 0.0169564985137965, 0.04318817378953099, 0.036922388044851165, 0.04828737124002405, 0.023065720784610937, 0.027171853397573744, 0.043894070732806406, 0.08076966700277158, 0.04336045043809073, 0.02534442288534982, 0.4097824969461986, 2.2219170928001404, 2.47756672331265, 4.5948784691946845, 8.162366764886038, 17.89401718548366, 30.041238376072474, 35.48933826174055, 37.49786792482649, 37.760162421635215, 43.37291029521397, 47.57855762754168, 57.443116664886475, 65.43701566968645, 67.4250898361206, 71.7983763558524, 76.38117190769741, 72.4124025617327, 74.02446801321847, 74.35759244646344, 69.7363247190203, 75.22295583997453, 78.40436921800885, 76.33626570020402, 65.28944982801164, 49.13027102606637, 57.11770820617676, 61.93438707079206, 67.26519094194684, 62.007954597473145, 57.957217352730886, 60.14625426701137, 47.7467075075422, 36.784718717847554, 25.628882135663712, 13.35138830116817, 2.5895920949322835, 0.26147925055452753, 0.09391054258282695, 0.06276332214474678, 0.043936835402356725, 0.09107953842197146, 0.08072504653994526, 0.041915761173835824, 0.06966243551245757, 0.021797114750370383, 0.06324101758322545, 0.019313376330371414, 0.04591234600437539, 0.04041355249605008, 0.047736010647245815, 0.022442900276343738, 0.04135076202718275, 0.046663429987217696, 0.022310677549934814, 0.0056419508265597475, 0.03136224479281476, 0.029399894377482787, 0.05259469796770385, 0.03361695898430688, 0.0564458048902452, 0.028152524792988385, 0.033296110308063884, 0.028401094222707406, 0.01656666148586997, 0.019494999798813036, 0.019108144932293465, 0.022259168260331665, 0.029310605954378843, 0.02886794667158808, 0.03147039988211223, 0.023857723821752837, 0.08428797964006662, 0.06373605637678079, 0.043371100045208416, 0.03535520624635475, 0.027775654569268227, 0.06348859465547971, 0.057791662136358876, 0.02827874248448227, 0.04761978438390153, 0.01943188247137836, 0.026200111523004513, 0.025438367755019238, 0.0193644394831998, 0.04047828134415405, 0.040323015568511825, 0.0730695566162467, 0.047514475749007294, 0.07185134198516607, 0.06200001774621861, 0.020572284402857934, 0.05647724820300937, 0.030667251907289028, 0.019820672859038626, 0.053146302833088806, 0.05061542149633169, 0.01464729117495673, 0.023212966276332736, 0.07135023708854403, 0.04602299131719129, 0.04116615639733417, 0.0308912227462445, 0.042274020878332, 0.044547415138887506, 0.008014503650234213, 0.04549453467396753, 0.08829763984041554, 0.033369018895817656, 0.12604930624365807, 0.022057716302307587, 0.03777568315022758, 0.0612898019275495, 0.07619235119117157, 0.01780976138875953, 0.025035250100440214, 0.04171518622232335, 0.030994183649974208, 0.033019519078412225, 0.056285809725522995, 0.025762627766068493, 0.0038912473579070395, 0.06817780767700501, 0.016502468680430735, 0.09112983143755368, 0.04278909002563783, 0.07457420123474938, 0.019714127594072903, 0.014430470398760267, 0.06723993657422916, 0.05420294809820397, 0.03362507087045482, 0.06065091371004071, 0.0743832682658519, 0.04219378071970173, 0.008386390882411172, 0.041157678102276156, 0.08539173898420163, 0.009060330522645797, 0.05504520683150206, 0.030856488538639884, 0.011157240369357169, 0.05319391902802246, 0.05438271238069449, 0.02492793639456587, 0.028330964235855, 0.018639935413375497, 0.04966562853327819, 0.03616053231858781, 0.03963608028633254, 0.03349061237115945, 0.04352729541382619, 0.012863992580345698, 0.039660938416740725, 0.029449169590537037, 0.048577288897441964, 0.006125647059109594, 0.07164489770574228, 0.023299228433253508, 0.05952696116375072, 0.03116800057302628, 0.056623163766094615, 0.0877286610858781, 0.02386491629295051, 0.02595633763952979, 0.030107799784413407, 0.024347868681486164, 0.0936386196741036, 0.01090794405899942, 0.04612049001402088, 0.02097735454195312, 0.02405678733651127, 0.09478206653147936, 0.024385033740795085, 0.018157374878813113, 0.024744204378553798, 0.5080716599311147, 2.10779054250036, 2.9436946596418108, 4.637347596032279, 8.09129103592464, 19.37026619911194, 31.188476290021622, 36.61347688947405, 40.80146190098354, 41.38343259266445, 47.24247326169695, 55.55280017852783, 64.57796124049595, 73.45526463644845, 76.53825678144182, 80.47713497706822, 86.22526850019182, 81.98474815913609, 83.83547728402274, 83.67279216221401, 78.25619888305664, 84.69257232121059, 88.50536155700684, 86.71255261557442, 71.29228346688407, 59.047139576503206, 65.23646981375558, 71.76713030678886, 78.84168883732387, 73.06042630331856, 69.04126167297363, 72.22868524278913, 59.86044011797224, 47.54670361110142, 36.80731078556606, 18.666740247181483, 3.6922436356544495, 0.25724516489676064, 0.04482863737004144, 0.09701925755611487, 0.025692453674439873, 0.015167549418817674, 0.04580011631229094, 0.01146957088660981, 0.08918835954474551, 0.06583552514868123, 0.04964731148044978, 0.060087919634367735, 0.027437879836985042, 0.0885384383478335, 0.05888000516487019, 0.011503810611819583, 0.016067619335704615, 0.019860650445999842, 0.01915158304784979, 0.027305197403100983, 0.039770230052194426, 0.020241088067580546, 0.016296699543350508, 0.07020012023193495, 0.055797186480568986, 0.06065231149217912, 0.039568240355168066, 0.004203888304930712, 0.019421317681138004, 0.06720982997545175, 0.041014676847096, 0.0291289417738361, 0.00836259635564472, 0.016449834719034176, 0.024374092363619378, 0.053524609854710956, 0.021760434843599796, 0.03804496995040348, 0.057940268090793064, 0.009326180542952247, 0.03589560171323163, 0.07294598860400063, 0.007834266937736954, 0.02395180270208844, 0.03855436993762851, 0.07698930414127451, 0.016767904794375812, 0.019705891875284057, 0.009259945347106882, 0.03138385274048362, 0.04194578295573592, 0.04172960848414472, 0.037683473633868356, 0.09301085264555045, 0.0281474459583738, 0.0254720230919442, 0.046403208414890935, 0.03670486668124795, 0.011822423515176135, 0.02465895832782345, 0.027229817251541784, 0.022330124363569275, 0.030717259938163415, 0.051684433062161715, 0.034553018398582935, 0.007645441668241152, 0.004949792521074414, 0.0766564691439271, 0.013783645866039609, 0.07236750357385192, 0.03401697912652578, 0.04654124279373458, 0.04073713906109333, 0.06442018930933305, 0.14155350572296552, 0.19830742318715366, 0.13595966302922793, 0.13545579649508, 0.12038621226591723, 0.1142614973442895, 0.12415409008307116, 0.09740103528435741, 0.10250477891947542, 0.12204577321452753, 0.14668442468558038, 0.09263406214969498, 0.14108329452574253, 0.1892469586538417, 0.1845461901809488, 0.07143262481050831, 0.19412099782909664, 0.12025867482381207, 0.0781790745843734, 0.1414564616445984, 0.0992374224588275, 0.09131360586200442, 0.1830898504704237, 0.16194208525121212, 0.15435900858470372, 0.10601015867931501, 0.1327366895441498, 0.15264589765242167, 0.12566385764096463, 0.14994326553174428, 0.12627508198576315, 0.10358806007674762, 0.1385357483689274, 0.2072948637817587, 0.15680634868996485, 0.13032942371709005, 0.18555238976010255, 0.09004531534654753, 0.10353288160903112, 0.09556128936154501, 0.07990151537316185, 0.08454859137002911, 0.110737091462527, 0.08940139918455056, 0.13901598831372602, 0.17717333723391804, 0.12151044979691505, 0.12194620498589107, 0.10509628057479858, 0.20597167978329317, 0.23724781508956636, 0.15475968351321562, 0.17297395185700484, 0.15091209140207085, 0.06770481448620558, 0.17394041642546654, 0.08856305559831006, 0.1629703100770712, 0.26270099356770515, 0.14214331550257547, 0.10434085396783692, 0.19840568862855434, 0.16115171409079007, 0.15785372177405016, 0.15446344869477407, 0.16187352607292788, 0.9479548931121826, 3.500413860593523, 4.961865816797529, 9.116151196616036, 14.512817042214529, 26.633671556200298, 41.24686574935913, 49.713089397975374, 53.40260716847011, 54.15769917624337, 61.63186250414167, 70.28913729531425, 76.8558658872332, 88.23116479601178, 92.2351962498256, 95.88892037527901, 101.06102044241769, 94.86388737814767, 99.01196888514927, 96.86860942840576, 93.99853788103376, 101.84083761487688, 101.86594840458461, 99.86438083648682, 87.19475759778703, 71.9352558680943, 78.39686516353062, 84.3593784059797, 91.0357356752668, 85.93026883261544, 82.96522235870361, 83.51183714185441, 74.01852035522461, 59.78118201664516, 45.40495613643101, 23.332108191081456, 5.647477575710841, 0.7193262098090989, 0.25183965638279915, 0.161927781733019, 0.12430566123553685, 0.14290726450937136, 0.21686732369874204, 0.09624509659728833, 0.1273033203823226, 0.13209117203950882, 0.15015302784740925, 0.10735097780291523, 0.16177268219845636, 0.17717179017407553, 0.19754796608218125, 0.08335839344986848, 0.08987053151109389, 0.10891540814191103, 0.09805690044803278, 0.13467481625931604, 0.0901505086304886, 0.11509529474590506, 0.0971050922359739, 0.12242968832807881, 0.25995659083127975, 0.1646497521017279, 0.178821933056627, 0.2028599860412734, 0.12425511037664753, 0.1410162959780012, 0.11357363925448485, 0.1316062230616808, 0.08292345250291483, 0.13782012462615967, 0.11695306934416294, 0.14517764268176897, 0.21416443373475755, 0.14817603464637483, 0.14577938110700675, 0.0941839243418404, 0.20513767882117204, 0.18371564974742277, 0.09468146692961454, 0.21289300838751452, 0.18523421111915792, 0.21662974144731248, 0.13642283103295735, 0.06218916616801705, 0.12950816564261913, 0.10522441512772016, 0.10138639714568853, 0.11519307164209229, 0.15659991119589123, 0.1763690018228122, 0.1394338844610112, 0.12926980986126832, 0.15087353704231127, 0.17847252823412418, 0.09396728846643652, 0.12075939295547349, 0.14703195675143174, 0.09241155016102962, 0.10678362753242254, 0.18705884606710502, 0.1308761736644166, 0.16413354980094091, 0.09350699745118618, 0.09904347000909702, 0.1709783939378602, 0.22643173619040421, 0.0910281597503594, 0.14352515206805297, 0.1311359711523567, 0.2276707547051566], [0.047178265039942095, 0.010477857181935437, 0.06985093932598829, 0.01243951718788594, 0.021466725871765187, 0.05277302036327975, 0.00885491761645036, 0.06967500198100295, 0.058035005150096755, 0.006453376080441687, 0.012156814902222582, 0.020701289176940918, 0.009385636325792542, 0.019588216939674954, 0.04465043032541871, 0.06380508374422789, 0.028011372545734048, 0.037847811422709904, 0.016742877030212964, 0.02952086360060743, 0.01678909035399556, 0.016480550302990844, 0.019374120481578366, 0.08054506512624876, 0.018777323487613882, 0.0533760378270277, 0.035210213490894864, 0.027284939740119234, 0.07341615230377231, 0.03088124149612018, 0.07503865845501423, 0.05207966613982405, 0.03269002586603165, 0.023290212399193218, 0.08852875565311738, 0.02473481515023325, 0.04377351202336805, 0.04029842545943601, 0.036661847561065636, 0.056945135417793474, 0.006681761213777853, 0.01495237069736634, 0.018120684794017246, 0.012759790805700635, 0.020349098968186548, 0.08280304646385567, 0.05340533018378275, 0.02698026055337063, 0.015736119356006384, 0.02748793875798583, 0.021796044361378466, 0.021256502152287533, 0.012078019175013261, 0.030243469468717064, 0.01012432771468801, 0.13106785980718477, 0.01536524059650089, 0.04958740023097821, 0.03847052675804921, 0.010296270184751068, 0.06735610855477196, 0.09451181960425206, 0.11106372464980398, 0.7607944703527859, 1.8853480901036943, 6.766604380948203, 13.694174204553876, 25.33425419671195, 28.32284116744995, 34.170386041913716, 44.50862809589931, 55.081225940159385, 58.700778824942454, 68.41969667162213, 71.47373567308698, 74.02946376800537, 71.72591359274728, 75.24937289101737, 82.21913174220494, 75.99606105259487, 65.58802086966378, 77.02587441035679, 71.69873223985944, 71.219480242048, 76.63528142656598, 81.11825220925468, 75.98052488054547, 77.74920272827148, 75.10186958312988, 69.08465317317417, 75.42678124564034, 72.57098129817417, 78.03199441092355, 78.91471440451485, 76.19211142403739, 73.52364880698067, 58.49188123430525, 66.74125507899693, 66.39517920357841, 76.81037603105817, 80.5494031906128, 65.02914946419853, 40.91146925517491, 15.227883952004568, 2.538015616791589, 0.3063455873302051, 0.1888773199170828, 0.09345806150564126, 0.15856501646339893, 0.083707241873656, 0.04130023830969419, 0.054781884354140074, 0.10713170921163899, 0.02503460379583495, 0.03520630173651235, 0.0391869850988899, 0.03688764365922127, 0.014637101275314177, 0.04720120970159769, 0.036450192132698636, 0.0212972600545202, 0.06448201063488211, 0.08379908158843007, 0.06971128324845008, 0.033674810879996846, 0.04522731401292341, 0.0219485451068197, 0.047233602963387966, 0.08778806004141058, 0.023358812289578573, 0.00906251710174339, 0.041817136108875275, 0.034785684663802385, 0.06749504538519041, 0.026105131887431656, 0.024350282569815005, 0.045606825434203656, 0.010331174874279116, 0.046038933497454436, 0.047874655707606247, 0.024123380459578972, 0.05024494816149984, 0.030662478413432837, 0.053828905669174025, 0.022411143141133443, 0.08192120878291981, 0.05269042229545968, 0.034568862191268375, 0.029234175769878284, 0.05643527741943087, 0.061438496091536114, 0.01688532527935292, 0.01796532911248505, 0.012426698813214898, 0.11104390464190926, 0.0435741821836148, 0.06325046957603522, 0.01732346212624439, 0.11690505620624338, 0.04898535646498203, 0.03347430717466133, 0.05341784915487681, 0.027856693702882955, 0.04183418769389391, 0.010391234553286006, 0.01820686043772314, 0.016800038516521454, 0.01871206029318273, 0.040670883509197404, 0.04129070828535727, 0.06615997345319816, 0.0045680678033802125, 0.03616195384945188, 0.06141901535115071, 0.0418365489957588, 0.026943312625267675, 0.0751341079760875, 0.012432177983490484, 0.036424407801989994, 0.01517583942040801, 0.024577803843255554, 0.08570370224437543, 0.05202005683843579, 0.006475673589323248, 0.009423047354045724, 0.05678133706429175, 0.032628621839519055, 0.051965702790766954, 0.050824033695140054, 0.06101587734052113, 0.033746287758861265, 0.04097625819434013, 0.02141237012775881, 0.034773114802581925, 0.05779016257396766, 0.012477635588896061, 0.025571350440649048, 0.040476751247687, 0.03113461665010878, 0.03991782159677573, 0.06943915677922112, 0.07108520131025996, 0.02944761574534433, 0.04311626943360482, 0.0341001030589853, 0.06521537806838751, 0.035647315571882894, 0.0724181222862431, 0.05615813657641411, 0.046726964613688846, 0.047033258713781834, 0.026904474977137785, 0.0285713861563376, 0.051368873566389084, 0.048613790688770156, 0.07575489966464893, 0.010518722801602312, 0.06010082537042243, 0.025045302596741488, 0.0038026561295347555, 0.024658832798845003, 0.06706650980881282, 0.008272473334467836, 0.0538359454699925, 0.05825469443308456, 0.003168097813613713, 0.06304778438061476, 0.03259761618184192, 0.01211946239761476, 0.041259217475141795, 0.05501397047191858, 0.14966053356017384, 0.1004028334947569, 0.058504700660705566, 0.06105836720338889, 0.023300950215863328, 0.054418172620769055, 0.0492647500442607, 0.10642388183623552, 0.8822538128920964, 2.5471802907330647, 8.362319418362208, 16.679331370762416, 28.305712120873586, 31.15768882206508, 39.23221124921526, 50.429229804447715, 61.45778233664376, 72.00733648027692, 78.14903681618827, 81.35497733524868, 83.76568957737514, 82.54871259416852, 86.94296877724784, 95.26710523877824, 90.91904762813023, 76.43301936558315, 89.43386323111397, 82.05393137250627, 87.36677415030343, 88.81515393938336, 94.27036530630929, 87.01948234013149, 87.61046137128557, 87.19723115648542, 79.22961371285575, 85.93455587114606, 80.69455105917794, 87.33144950866699, 87.8270297731672, 84.62119347708565, 83.61375331878662, 72.14028331211635, 77.12974997929165, 79.98780114310128, 89.88628823416573, 94.90660490308488, 74.43343203408378, 50.576079981667654, 22.440748112542288, 4.5623257245336255, 0.472366061593805, 0.10441535711288452, 0.08729882950761489, 0.2175227478146553, 0.12856620975903102, 0.024202214354383092, 0.03667586609455092, 0.07822354576949563, 0.11667465285531112, 0.021839916739346724, 0.06900040246546268, 0.05993380397558212, 0.06018107570707798, 0.024985262425616384, 0.03959377023524471, 0.10633636438953024, 0.015588831455845917, 0.04159910245133298, 0.06523902501378741, 0.027295351859980395, 0.013383695273660123, 0.055405071271317344, 0.04253622716558831, 0.06531223894229957, 0.03455355783392276, 0.043941289984754155, 0.10016643189425979, 0.03677483721237097, 0.03486423187756112, 0.07765017010803733, 0.03289418348244258, 0.07287687981235129, 0.04735301494864481, 0.029213551697986465, 0.07064975146204233, 0.06162784128848996, 0.05981457858745541, 0.05081924663058349, 0.033524250744708946, 0.04660035337188414, 0.07336369476148061, 0.07178494733359132, 0.017307282458724718, 0.03988683968782425, 0.027842079754918814, 0.05336658922689302, 0.055729017459920475, 0.05152731827859368, 0.0569369387147682, 0.04367692256346345, 0.04083265982834356, 0.010229906067252159, 0.030202750582247972, 0.05202386002721531, 0.04985046486503311, 0.015815026193325008, 0.032263922837695906, 0.05702347907104662, 0.03128437950674977, 0.055404100966240676, 0.06830740786556687, 0.010661319480277598, 0.042190747668168375, 0.05964830358113561, 0.06361476145684719, 0.07474173153085367, 0.037787893387888155, 0.07332929303603512, 0.004115336940490774, 0.020190830675086806, 0.04006609506905079, 0.11714688608688967, 0.1350312778460128, 0.13452918907361372, 0.11156301785792623, 0.16638699173927307, 0.20823650753923825, 0.10933598450251988, 0.18330528533884458, 0.17182996895696434, 0.1596782345856939, 0.11318693536200694, 0.13561000036341803, 0.17186913399824075, 0.15138365966933115, 0.22387216639305862, 0.16029620356857777, 0.05730895910944257, 0.1319197876644986, 0.20511897839605808, 0.10608164912887982, 0.10434393451682158, 0.17838399298489094, 0.13650886927332195, 0.19569754680352552, 0.11292929561542613, 0.1954752587314163, 0.165742017062647, 0.13566185400954314, 0.17040509970060416, 0.09674053572650466, 0.18386794014700822, 0.15453488486153738, 0.13249354330556734, 0.16093219444155693, 0.1663787950362478, 0.15818521327206067, 0.11754163061933857, 0.11128988037151949, 0.13046743773988315, 0.19263900949486665, 0.12276677095464297, 0.13554114262972558, 0.08448965381830931, 0.09078058946345534, 0.20839559685971054, 0.13635110988148622, 0.09448817265885216, 0.1655761423919882, 0.23425577421273502, 0.11839800966637475, 0.22931278230888502, 0.12236961083752768, 0.12224668743354933, 0.21007890653397354, 0.11089601793459483, 0.3194257340260914, 0.15093242031122955, 0.1507553905248642, 0.17671491897531919, 0.15957979272518838, 0.09921680177961077, 0.1924906817397901, 0.34571722894907, 2.064814631428037, 5.06690216915948, 14.171060340745107, 25.01909954207284, 40.636171204703196, 45.58244786943708, 51.449378217969624, 63.577462332589285, 76.64074271065849, 82.74215044294084, 90.37731742858887, 92.41180556161063, 97.59234769003731, 93.93395437513078, 98.93567071642194, 109.10130909511021, 100.78155694689069, 91.0318238394601, 101.89378983633858, 94.47274548666817, 98.84906836918422, 99.93885162898472, 102.34005873543876, 97.31149455479213, 97.68480042048863, 97.1897690636771, 90.39283275604248, 97.058107648577, 93.75802598680768, 98.43847846984863, 100.10863086155483, 98.0731838771275, 94.54447174072266, 80.751387323652, 91.71074622017997, 91.72225243704659, 103.01253318786621, 108.00448731013707, 85.38665567125592, 58.54349940163748, 27.050978626523698, 6.142114187989916, 0.870433081473623, 0.28485738752143724, 0.1409558927906411, 0.5235780307224819, 0.2501745585884367, 0.18474326389176504, 0.1301849771823202, 0.18684396759739944, 0.21498597679393633, 0.1623619491500514, 0.16422831400164536, 0.17489022974457058, 0.13266301421182497, 0.11296067786003862, 0.15006579538541182, 0.14421679638326168, 0.1702562291175127, 0.2166008222848177, 0.12376566949699606, 0.07600657508841582, 0.20307516306638718, 0.10265780213688101, 0.17132162409169333, 0.16700084879994392, 0.13462471323353903, 0.13020210340619087, 0.22616798962865556, 0.13560842616217478, 0.2134031852973359, 0.1545644418469497, 0.15729416108557157, 0.06835552278373923, 0.15671912979866776, 0.19532721596104757, 0.18096395954489708, 0.1468911471643618, 0.20613079624516623, 0.1274432343031679, 0.13375926895865373, 0.13186478561588696, 0.18851625786295959, 0.12008676119148731, 0.07244361484689371, 0.1664554016398532, 0.1438659666372197, 0.1400881822087935, 0.14120807711567196, 0.1582698265888861, 0.16048113150256021, 0.17466259481651442, 0.1344685958964484, 0.2255297867315156, 0.10139984570975814, 0.17202655412256718, 0.1702432283865554, 0.15528610455138342, 0.08303254736321312, 0.09733105118253402, 0.1804024311048644, 0.0951966717839241, 0.1012957448671971, 0.060511047286646705, 0.10678717627057008, 0.11910405249467917, 0.12923392892948218, 0.18786941042968205, 0.12133214436471462, 0.22713439991431578, 0.09180181859327213, 0.09706636145710945, 0.08619468339851924], [0.034687171557119915, 0.032040888377066166, 0.026494387071579695, 0.005449660363540585, 0.03332709900236555, 0.013943669868500104, 0.03670329587267978, 0.04196149443409272, 0.014441706938669086, 0.032203007356396744, 0.04710508164550577, 0.05848373392862933, 0.0622121345783983, 0.053316001048577685, 0.0535828213739608, 0.03373014880344272, 0.01254241363078888, 0.04717593427215304, 0.04520684261141079, 0.04344692633354238, 0.026452898047864437, 0.11177917875881706, 0.020528837805613875, 0.015592795796692371, 0.06496713603181498, 0.04269314517400094, 0.04840235239160912, 0.028060467947008352, 0.012029638780014855, 0.041266518511942456, 0.045904295186379125, 0.09084573561059577, 0.00616373068520001, 0.03886562752138291, 0.032607105494077714, 0.012918989539944699, 0.06195880352918591, 0.015316703290279423, 0.05717624444514513, 0.07199690131736652, 0.028866036595510583, 0.04274459509178996, 0.027735451369413307, 0.01208127020592136, 0.02342282358690032, 0.07248352627669062, 0.005469648308852422, 0.07229433035744087, 0.06905683622296367, 0.025649197067001035, 0.028700918491397585, 0.056707196935479126, 0.019123814002211605, 0.042695981450378895, 0.07146462452198778, 0.059367960052830834, 0.06093890432800565, 0.044319332377719026, 0.12855861016682216, 0.028267488981197988, 0.843854050551142, 3.082231100116457, 13.4521849496024, 28.74735525676182, 45.840014117104666, 48.379375730242046, 53.54776545933315, 50.76292398997715, 57.72880574635097, 62.962380000523154, 62.94657979692732, 65.02058233533586, 61.17066192626953, 63.463386808122905, 61.993481499808176, 57.08026436397007, 55.86738681793213, 52.011643818446565, 45.20268365315029, 85.75516727992466, 53.322928701128276, 30.75956051690238, 36.01392378125872, 34.860918862479075, 49.06881768362862, 56.01719692775181, 49.664066382816856, 44.48864507675171, 41.50790957042149, 42.239096300942556, 47.70653649738857, 51.27654872621809, 64.06690733773368, 59.57139505658831, 51.19613374982561, 47.54392433166504, 46.412253856658936, 62.314363207135884, 52.48810611452375, 56.44848551068987, 52.75671999795096, 72.55991281781877, 69.1818515232631, 68.61810943058559, 38.77840008054461, 18.567928177969797, 5.513602290834699, 2.164145427090781, 0.4788482966167586, 0.17376639933458396, 0.10709037285830293, 0.01571799738199583, 0.016200612199359705, 0.08733272233179637, 0.046648427577955384, 0.019170079912458147, 0.03681860950642398, 0.04572805589331048, 0.05434296719197716, 0.019464445366923298, 0.03190187012244548, 0.06296570199940886, 0.047355858010372946, 0.045280226173677614, 0.02047828694672457, 0.007199058924535555, 0.06587849677141223, 0.03123016795143485, 0.04124891392088362, 0.023539889537330185, 0.04973861175988402, 0.07802412432751485, 0.04726013707529221, 0.02571428893133998, 0.013926390974250222, 0.04008651218776192, 0.0529260639367359, 0.047626644372940063, 0.03812815495101469, 0.028023201107446636, 0.011655073879020554, 0.06169114860572985, 0.00941163778770715, 0.017023525899276137, 0.038123025226273706, 0.013419211492873728, 0.008878610362964017, 0.045652019259120734, 0.029191930179617236, 0.018211452423461845, 0.003107121688247259, 0.024600022472441196, 0.04619245543809874, 0.020948265745703663, 0.04820736517597522, 0.0327972818964294, 0.0931868917707886, 0.01659984524095697, 0.04157236817159823, 0.010526172267938299, 0.08717326660241399, 0.048705498089215586, 0.036425235614712746, 0.05168300135327237, 0.06369632815143891, 0.02389603730158082, 0.04143579603571977, 0.0360214767445411, 0.015278917371428438, 0.019840974626796584, 0.056990861892700195, 0.0328932199627161, 0.0102467668142968, 0.06399709558380501, 0.04212497726881078, 0.06365936156362295, 0.09296580470566239, 0.04749727149360946, 0.07513487472065858, 0.016715113073587418, 0.058126410602458885, 0.05367882390107427, 0.058583851770630906, 0.02424060756207577, 0.05118289729580283, 0.04387265956029296, 0.0820909036057336, 0.05092462311897959, 0.024587539124435613, 0.03544535640893238, 0.042898792174777815, 0.065255893394351, 0.07939968444406986, 0.047328506263771226, 0.00721426574247224, 0.040699826420417855, 0.03450038104451128, 0.06925952141838414, 0.08801705203950405, 0.04667157240744148, 0.028008054509492855, 0.06935767829418182, 0.07643867297364132, 0.05754280263291938, 0.08476551901549101, 0.014501830230333974, 0.03687847665111933, 0.03894843593505876, 0.07801885889577014, 0.05265594932383724, 0.04915965175522225, 0.01885796058923006, 0.0038178006070666015, 0.04832591202908328, 0.06055872115705695, 0.02791614524487938, 0.0175026326905936, 0.05528279247560671, 0.047783715051731894, 0.016319669650069306, 0.0131081040349922, 0.026935029409027526, 0.03504763310775161, 0.009498261264525354, 0.050984042430562634, 0.01537713361904025, 0.07453336021197693, 0.08567719866654702, 0.08649424303855215, 0.032679077703505754, 0.06840686074325017, 0.06726124935916492, 0.023355543447126235, 0.04672743280285171, 0.0980958551434534, 0.033977552849267206, 1.2730875951903207, 5.225600762026651, 18.788752351488384, 35.408040864127024, 53.363495758601594, 55.904059410095215, 59.27350493839809, 60.956490652901785, 66.9627844946725, 72.56103147779191, 72.29501969473702, 75.76658984592983, 70.79468127659389, 74.86197607857841, 73.2553927557809, 66.01063115256173, 66.94028622763497, 64.73239885057721, 55.821480069841655, 88.13821179526192, 63.26136098589216, 43.35752003533499, 48.961398533412385, 44.347339562007356, 62.91946792602539, 70.9904259272984, 61.51691150665283, 58.57404368264334, 53.04704005377633, 53.65715094975063, 60.59150872911726, 62.29708998543875, 76.61839035579136, 68.99857194083077, 62.42918913705008, 60.29149941035679, 51.53906556538173, 72.02557550157819, 59.06041758401053, 66.55271571023124, 62.401931353977744, 84.17858627864292, 80.23407309395927, 81.50815732138497, 50.2638383592878, 27.00463240487235, 9.357324038233076, 3.8820771064077104, 0.6922615649444717, 0.17720706042434486, 0.15126486175826617, 0.01992674314949129, 0.03051426600930946, 0.004418311732089413, 0.005162368212560458, 0.03381137962320021, 0.04165301884391478, 0.047905254244272194, 0.10266637203416654, 0.02756690327078104, 0.05921577821884837, 0.0348603777986552, 0.016227612804089273, 0.017377102015806094, 0.037095750349440744, 0.038731769525579045, 0.03121528767847589, 0.03550734058288591, 0.020365478803536723, 0.0410465035321457, 0.021258822742051313, 0.0773907865264586, 0.027417014885161604, 0.015000507667926806, 0.028439903033099005, 0.05691687443426677, 0.027385069456483637, 0.034444103350064585, 0.034207671215491633, 0.049733288652662716, 0.07767752185463905, 0.0204302263113537, 0.006788773819737668, 0.01911636538404439, 0.031147366323109184, 0.06952713562973908, 0.06719216092356614, 0.024484383141888038, 0.05859139029468809, 0.09263087982045752, 0.052453430369496346, 0.07564501091837883, 0.06414526727582727, 0.04703119257465005, 0.057410827571792264, 0.03881803507517491, 0.05397758286978517, 0.03985279419326356, 0.020627210116279975, 0.08346388528921775, 0.013833433373032935, 0.05330461183828967, 0.038998220049376996, 0.04252277520884361, 0.026707759193543876, 0.024914489526833807, 0.1055883134582213, 0.04362143196963838, 0.039998363703489304, 0.03720788165394749, 0.040199450948940854, 0.05085934126483543, 0.04296133614012173, 0.061287189567727704, 0.06549803540110588, 0.06361087345119033, 0.14087156445852347, 0.13450822234153748, 0.16923582101506845, 0.14823651925793715, 0.1414813638797828, 0.10975299855428082, 0.12928906668509754, 0.13132482101874693, 0.1856732911297253, 0.15056290371077402, 0.16634351121527807, 0.23391984509570257, 0.11737031409783022, 0.15202353176261696, 0.09930136081363473, 0.14260344366942132, 0.1917034996939557, 0.14342034554907254, 0.12178575859538146, 0.16763320272522314, 0.08594265513654266, 0.24922737798520497, 0.16582511046103068, 0.12651239282318524, 0.17488951049745083, 0.09257545708013432, 0.2079618772757905, 0.12741107174328395, 0.17853724690420286, 0.15132149229092257, 0.06886090245097876, 0.20750012062489986, 0.21588365148220742, 0.12670401111245155, 0.24132928465093884, 0.08231963776051998, 0.21217828031097138, 0.19517472200095654, 0.17101742327213287, 0.16004100654806408, 0.13044746166893414, 0.13227515002446516, 0.1781367076826947, 0.14301779786390917, 0.09186382990862642, 0.1394963368241276, 0.15425614267587662, 0.19969468803278037, 0.15317278009440216, 0.10794582231236355, 0.1053188197048647, 0.25885896544371334, 0.1433726173958608, 0.11406371795705386, 0.23241588579756872, 0.15294864640704223, 0.17700727257345403, 0.17657742063914025, 0.28022709169558113, 0.15387271610753878, 1.7512188702821732, 7.525220428194318, 26.93634029797145, 46.66375085285732, 67.58579472133091, 70.47250025612968, 74.17446572440011, 72.9703151157924, 80.31005164555141, 85.77056448800224, 86.26927144186837, 85.70442458561489, 84.02363450186593, 83.1823535646711, 82.44678252083915, 77.70315701620919, 79.12031854901994, 74.34459236689976, 67.3044204711914, 100.46387835911342, 73.50991916656494, 50.306382179260254, 56.35902050563267, 54.97409861428397, 69.07542596544538, 76.08697128295898, 70.8503224509103, 66.34062889644078, 60.97437531607491, 60.99156515938895, 67.95605727604458, 73.16355841500419, 83.90428529466901, 80.51636450631278, 71.01840632302421, 67.03314195360456, 65.04987594059536, 80.88405622754777, 73.66824081965855, 78.49332700456891, 75.94532530648368, 95.09581129891532, 93.72666181836809, 92.26991639818463, 59.42856788635254, 32.38107204437256, 13.08818359034402, 6.165258637496403, 1.616989444409098, 0.5670238137245178, 0.21288665729973996, 0.14770371999059403, 0.2010413629135915, 0.08620420324483088, 0.14047350867518357, 0.14791500222470078, 0.12551182508468628, 0.10947711300104856, 0.1295457293412515, 0.15556095194603714, 0.13257974439433642, 0.2359764575958252, 0.08641359915158578, 0.12770490454775946, 0.17001145439488546, 0.09600269674722638, 0.17626570165157318, 0.09270369341330868, 0.1450506616383791, 0.12898851638393743, 0.10913083622498171, 0.21505076331751688, 0.16652078527425015, 0.11198021511414222, 0.18959119303950242, 0.15488552461777413, 0.1416848972439766, 0.09836638027003833, 0.09209965475435768, 0.12616980049226964, 0.17237211843686445, 0.12094159317868096, 0.10294398106634617, 0.09519770315715245, 0.10725138243287802, 0.14164556935429573, 0.1545170529612473, 0.16524758216525826, 0.1594792338354247, 0.3123390328671251, 0.1438270187271493, 0.10770712726350341, 0.0976384479020323, 0.1998842300048896, 0.17803711231265748, 0.14289180748164654, 0.23985594085284642, 0.07661431854856865, 0.11083013218428407, 0.13938308932951518, 0.11975142918527126, 0.1142467867050852, 0.11763627268373966, 0.19431979501886026, 0.15719687273459776, 0.130112781056336, 0.2895680218935013, 0.1435186109904732, 0.12196067135248866, 0.1936694870569876, 0.1218528114259243, 0.1263266642178808, 0.1002846055531076, 0.21066070960036345, 0.1316127912806613, 0.17969309059636934], [0.04090064903721213, 0.016013570628794174, 0.04813574580475688, 0.03525512233110411, 0.029899024737200568, 0.021656079550406764, 0.03865158025707517, 0.043071798248482604, 0.0213708064651915, 0.02516662635441337, 0.029651790325130736, 0.011445296296317662, 0.015582856955006719, 0.021825443587398956, 0.018252106849104166, 0.09261029985334192, 0.02852970714281712, 0.027080875422273363, 0.004288308663360242, 0.08448785570050989, 0.01313107498987977, 0.06465477243598018, 0.06284406781196594, 0.035017417943371196, 0.03202318200575454, 0.04066299553960562, 0.026492622880531207, 0.044252849516591856, 0.026056801534390876, 0.025753784758437957, 0.02902987226843834, 0.05720267338412149, 0.05943763881389584, 0.05120283944000091, 0.022146458504721522, 0.04493848540421043, 0.013860957297895635, 0.06578643314008202, 0.05696681461163929, 0.05722291408372777, 0.017184331913345625, 0.03584233332159264, 0.07682889167751585, 0.04860826402104326, 0.009819100610911846, 0.09796864339815718, 0.024754733545705676, 0.019782293222046325, 0.04597389591591699, 0.03019956825301051, 0.043665105876113684, 0.05120860020230923, 0.05737209679292781, 0.020103655888565948, 0.03898850342790995, 0.0728859178987997, 0.12099468175854002, 0.04145363811403513, 0.7480257440890584, 14.69274411882673, 34.46202278137207, 49.32761376244681, 65.14823463984898, 67.51342923300606, 71.13248879568917, 70.57215826851981, 71.44476863316127, 53.40921490533011, 50.82540913990566, 59.23320538657052, 52.1883920942034, 52.45264598301479, 45.45979131971087, 40.41790049416678, 36.20658343178885, 30.912111691066197, 27.998936993735178, 19.491406304495676, 35.74541759490967, 57.64796345574515, 36.85099063600813, 21.107015337262833, 21.743187189102173, 23.250413009098597, 17.75711509159633, 21.06732201576233, 21.41914231436593, 18.88025838988168, 18.686992509024485, 19.96990963390895, 23.397598436900548, 24.837221758706228, 20.09360146522522, 39.202973229544504, 35.59910242898123, 34.12432643345424, 43.90257494790213, 26.99726210321699, 38.42813791547503, 47.291166237422395, 38.294878414699006, 41.47142110552107, 62.34513677869524, 60.79500756944929, 68.78010668073381, 59.44578552246094, 47.68049464906965, 37.56382022585188, 20.816294022968837, 6.380522949354989, 1.8180327479328429, 0.4095829805093152, 0.061690714343317916, 0.09629478571670395, 0.08226179943553039, 0.052352742558079104, 0.021287799580022693, 0.044370795866208415, 0.044082330273730416, 0.04183572457571115, 0.04062551665785057, 0.09302327662174191, 0.10852063646806137, 0.02926200588366815, 0.030659757488008057, 0.011769720852108938, 0.01957236127262669, 0.012782456419829811, 0.09274228169981923, 0.010246547138584512, 0.12323243596724101, 0.02424688570733581, 0.03781311453453132, 0.09569903875568084, 0.08777623317603554, 0.005183694144112191, 0.0444672428337591, 0.05150958815855639, 0.03591574063258512, 0.04768048951934491, 0.05019520815195782, 0.040294018374489884, 0.04761439003050327, 0.027675986256716505, 0.0407522669993341, 0.03686118757884417, 0.05700880914394345, 0.10275358414011342, 0.020086991068507944, 0.07228542797799621, 0.022735616890713573, 0.058417298564953465, 0.09167370439640113, 0.03588176638420139, 0.06468306734625782, 0.03699167664828045, 0.0767127943358251, 0.03262136151481952, 0.016351720251675163, 0.035244279341506105, 0.031847583928278515, 0.04628360304715378, 0.03790668790627803, 0.06337392223732811, 0.02884156523006303, 0.09292528259434871, 0.045233251194336584, 0.06255693893347468, 0.08121925073542766, 0.018412721177030886, 0.06591484589236123, 0.0491360794486744, 0.005275627581535706, 0.011278740546133901, 0.052687762438186576, 0.04455888916605285, 0.028144000696816614, 0.027765013443838273, 0.037034410783754926, 0.013898846693336964, 0.015399969715092863, 0.008419862166712326, 0.03944993777466672, 0.029599990961807113, 0.009696731909311243, 0.06166115735790559, 0.07393242245806114, 0.027954406138243418, 0.022329016655151333, 0.023634170281833837, 0.03132054203056863, 0.03292920946010521, 0.020139072023864304, 0.01563599981766726, 0.04359633295929857, 0.025422730915514485, 0.011002424971333571, 0.04073309838505728, 0.026516313930707316, 0.025992535786437135, 0.04558685275592974, 0.017391644717593278, 0.02040586181517158, 0.026482714572921395, 0.06931146327406168, 0.06623724502112184, 0.014564136708421367, 0.023575594050011466, 0.02022011115747903, 0.018956772251320735, 0.02119675714389554, 0.09440034308603831, 0.026515111227386763, 0.057632192836276123, 0.029916999129844562, 0.005410131033776062, 0.037620050965675285, 0.013010132059987103, 0.07033497228154115, 0.09664712181048733, 0.04024035982521517, 0.02461876530599381, 0.013803415831976702, 0.0637105909575309, 0.04604182744930897, 0.02540627135229962, 0.017556554172188044, 0.049905120860785246, 0.14461181232971804, 0.07915174774825573, 0.07365281174757651, 0.06599324382841587, 0.04249377801482167, 0.023148264569629515, 1.9309710477079665, 18.92850320679801, 42.08852536337716, 59.20321001325335, 74.2751659665789, 76.66957773481096, 80.61742605481828, 78.04653004237584, 79.37900693075997, 61.304748262677876, 64.2792442866734, 69.17588302067348, 60.21880735669817, 60.38530009133475, 56.23365068435669, 52.4700095312936, 46.5782984324864, 43.255100114004954, 41.8558475630624, 34.240719182150706, 45.337662833077566, 67.46256841932023, 53.853465352739605, 28.258285454341344, 34.7154027393886, 34.329051630837576, 29.44282477242606, 36.83594083786011, 32.18363203321184, 30.059835229601177, 34.817544732775005, 36.48198223114014, 41.053678035736084, 39.69021218163626, 34.87708037240164, 52.60395342963082, 47.36669315610613, 45.118798051561626, 54.378464290073936, 41.52068035943167, 52.102217061179026, 60.55667046138218, 49.227410316467285, 52.96254301071167, 70.50471210479736, 70.48319353376115, 78.83150277818952, 69.81281048910958, 60.58184378487723, 47.857909951891216, 26.893935441970825, 8.667206372533526, 2.9903222833360945, 0.5855764810528074, 0.06904595252126455, 0.07318811704005514, 0.03753805679402181, 0.046698221870298894, 0.03397938489381756, 0.09326752887240478, 0.03276219145794, 0.08308067585208587, 0.02703792754826801, 0.022361586336046457, 0.13415511271783284, 0.0288560383820108, 0.10116594790347985, 0.12091864512435027, 0.01423067576251924, 0.03443889898647155, 0.04904216680941837, 0.03330431379643934, 0.01630411423476679, 0.03903559375820415, 0.07128401207072393, 0.008332941830823464, 0.03910680261573621, 0.024757598659821918, 0.08363927980618817, 0.030172430244939666, 0.010623878766117352, 0.04128614853003195, 0.051730736291834285, 0.0315826193961714, 0.02686682646162808, 0.03806072214086141, 0.10818610513316733, 0.0828567525105817, 0.03324235676388655, 0.06721313444099256, 0.016762982022815516, 0.030430826558066264, 0.011445673731421786, 0.06320668371128184, 0.008396159242173391, 0.02819623432255217, 0.04254091584256717, 0.057224908976682594, 0.04954807912664754, 0.023455829226544926, 0.0020056161405851264, 0.04731721204838582, 0.0324198569703315, 0.044525206687727144, 0.004653054738550314, 0.06974707597068378, 0.0506236487334328, 0.042916824242898395, 0.03150383808783122, 0.16017231664487294, 0.12587260215410165, 0.034219107923230956, 0.03711922087573579, 0.00978829596923398, 0.06397840194404125, 0.02885574661195278, 0.026990827039948533, 0.015129278347428356, 0.11760773350085531, 0.10447806053395782, 0.12529003912849085, 0.09346741171819822, 0.10592503646122557, 0.14504399842449597, 0.14500268921256065, 0.10086285309599978, 0.14045969370220387, 0.15108188800513744, 0.18166381413383142, 0.108857590172972, 0.08133219967463187, 0.10873442249638693, 0.12398289569786616, 0.17686900070735387, 0.1443975174001285, 0.1337445718901498, 0.06856655395988907, 0.25234779768756455, 0.1006210707128048, 0.12908317201903888, 0.1438096346599715, 0.20055618323385715, 0.1641163964356695, 0.14702020452490874, 0.11961941341204302, 0.08384298280413661, 0.1514246838965586, 0.18971171442951473, 0.11041515373757907, 0.1444813978991338, 0.08859858369188649, 0.1322006604501179, 0.1092677985184959, 0.24577048633779797, 0.0942824747679489, 0.12168833453740392, 0.19105856572943075, 0.17278032510408334, 0.2247637478368623, 0.10591572017541953, 0.1634312660566398, 0.22498093332563127, 0.1146407848490136, 0.1216630930347102, 0.05942863465419837, 0.14596376621297427, 0.1958667462957757, 0.14264389792723314, 0.1054257500384535, 0.14850430988839694, 0.21723545608775957, 0.13731984075691017, 0.18405849992164544, 0.18962396628090314, 0.2105015931384904, 0.2662359167422567, 3.3968946039676666, 26.087185314723424, 52.37178284781319, 73.43122386932373, 86.67645672389439, 89.0592372076852, 90.29895564488002, 89.08730098179409, 88.45491763523647, 72.90488392966134, 72.09811469486782, 79.24927016666958, 71.26482418605259, 72.94481522696358, 65.7630181993757, 60.2170216696603, 54.88343504496983, 49.99342836652483, 46.21497712816511, 35.370322568076, 51.2579414503915, 72.00434875488281, 51.48896557944161, 36.52421685627529, 36.791750294821604, 38.90094198499407, 29.015222208840505, 33.15475048337664, 36.054817404065815, 31.725811753954204, 31.576897961752756, 32.97837393624442, 41.49296399525234, 43.16311986105782, 34.64698035376412, 54.66724531991141, 51.57263231277466, 50.63265916279384, 63.24463667188372, 44.06336668559483, 56.80667209625244, 65.29805864606584, 58.18804693222046, 62.65609645843506, 82.5566404887608, 81.18888759613037, 90.48725877489362, 81.66319942474365, 71.94829763684953, 57.88909721374512, 34.037939480372835, 12.635267870766775, 4.438902267387935, 1.1695538993392671, 0.34970592920269283, 0.3254022161875452, 0.15022620106382029, 0.19736405595072679, 0.15607662498950958, 0.16984647539045128, 0.16703556265149797, 0.19574152944343431, 0.1710305189979928, 0.11786419259650366, 0.2015168938253607, 0.16225134794201168, 0.18939599208533764, 0.2712675524609429, 0.13542197830975056, 0.12019829877785274, 0.3417636225266116, 0.0878470858026828, 0.22326753740864141, 0.10527394818408148, 0.16415621287056378, 0.2809538569833551, 0.09692122960197073, 0.18374281828956945, 0.25745040816920145, 0.10582209591354642, 0.07220878066228968, 0.14660073417638028, 0.2706629777593272, 0.14177268610468932, 0.14553753765566008, 0.20580163890761988, 0.12281622258680207, 0.13542512671223708, 0.13654761362288678, 0.28451524302363396, 0.13217028922268323, 0.15984864187027725, 0.1063540130853653, 0.11952806902783257, 0.18005854955741338, 0.20887837452547892, 0.08882114996335336, 0.09067386947572231, 0.12345928379467555, 0.12763126992753573, 0.08876195456832647, 0.2289770431816578, 0.09371881572795765, 0.1270267359380211, 0.14862510269241674, 0.2733805647918156, 0.14649010582693986, 0.1337955705821514, 0.16043737956455775, 0.19570110232702323, 0.3264536740524428, 0.09040913225284644, 0.12131139476384435, 0.1671934306089367, 0.17294953816703387, 0.1397852027522666, 0.16668208661888326, 0.13967514437224182], [0.06602951831051282, 0.027592789381742477, 0.035949161874928644, 0.006543006739645664, 0.023436687753668854, 0.031701383380485434, 0.027761552915243164, 0.03737689454906753, 0.02327309804968536, 0.013026617916433938, 0.06626361289194652, 0.027762451974142874, 0.08895620557346515, 0.03844504098274878, 0.036991194888417206, 0.01463788837593581, 0.04649447137489915, 0.020316936408302615, 0.021952470431902578, 0.02304823663351791, 0.028640047114874636, 0.04478014586493373, 0.030535989307931492, 0.01785488396749965, 0.026717489385711293, 0.037594663577952554, 0.04968119751928108, 0.06533748723034348, 0.004554262160257037, 0.05575100877987487, 0.022750022189159478, 0.05860460137150117, 0.037112774793058634, 0.03633590987218278, 0.025125544451709305, 0.03769445911582027, 0.061296519424234114, 0.026309126655438116, 0.05962208498801504, 0.028870477607207637, 0.02689666164639805, 0.027694033591875007, 0.030347936720188175, 0.034925466270319054, 0.027024434879422188, 0.0491352787773524, 0.017272068187594414, 0.017283633816987276, 0.03188472014984914, 0.011283765097946992, 0.07916033800159182, 0.032297690132898946, 0.034946456751120944, 0.03768332774883934, 0.06327854056975671, 0.1759936905332974, 0.9329109575067247, 13.985714537756783, 34.18016563143049, 57.58209105900356, 76.68974835532052, 71.41044453212193, 63.16660145350865, 59.42090402330671, 55.62935890470232, 46.65225158418928, 44.82432644707816, 35.280673435756135, 26.030145815440587, 45.921863896506174, 45.83372252328055, 41.271764619009836, 28.619101933070592, 26.233106170381816, 17.602257115500315, 13.413475666727338, 16.592381613595144, 13.235611336571829, 17.017609630312236, 24.15023078237261, 18.621807983943395, 25.582122496196202, 25.223242827824183, 18.02117269379752, 26.100141968045914, 31.090447630201066, 26.753812858036586, 24.10674548149109, 19.72789866583688, 16.062425136566162, 14.798681565693446, 12.09909623009818, 16.34682011604309, 15.75068552153451, 12.53257783821651, 18.754231963838848, 12.794529267719813, 11.568932175636292, 13.159776960100446, 22.49442294665745, 24.70040304320199, 30.35593966075352, 40.184764112745015, 45.48107712609427, 55.4859550339835, 55.111481870923726, 65.5010016305106, 58.65510136740548, 54.06975930077689, 48.43516976492745, 34.69536066055298, 22.092587777546473, 12.479935680116926, 3.6007975254740034, 1.2872053576367242, 0.3485695458948612, 0.061752013196902614, 0.043603318477315564, 0.02809914613940886, 0.03130139716501747, 0.019004515671570386, 0.017199604040277854, 0.08288252327058997, 0.017833990177937915, 0.019551559085292474, 0.005645544941736651, 0.04435029732329505, 0.032253931409546306, 0.02034895308315754, 0.022412057467071072, 0.0370437609963119, 0.03189615346491337, 0.029579302429088523, 0.07009770894157034, 0.03650830526437078, 0.06390341703913041, 0.041866672557911704, 0.03988837317696639, 0.033749809355608056, 0.04483642355938043, 0.05554463913930314, 0.040761878447873254, 0.018112516928730265, 0.03550387326894062, 0.09420979009675128, 0.04095173593876617, 0.046334289613046815, 0.023556379634620886, 0.03302292532420584, 0.02540861060177641, 0.021126637335068414, 0.006803160458470562, 0.017048538396401063, 0.06629331915506295, 0.053813547029026916, 0.07471490225621633, 0.04418204778007098, 0.06060631360326495, 0.03005288933802928, 0.019868996426729218, 0.014043814003733652, 0.03902286444125431, 0.022567978029006293, 0.04267615465713399, 0.03454406512901187, 0.03681788008127894, 0.10461855799491916, 0.08914313518575259, 0.09450274759105273, 0.006496687394766403, 0.023467898668189133, 0.017528817356963242, 0.027643167214202027, 0.017007902630471756, 0.038344804397118945, 0.05206556957481163, 0.035099544429353306, 0.020312632799946835, 0.055886963448886356, 0.032114709594420025, 0.034223779636834345, 0.02471080349226083, 0.011011199277293469, 0.042524189954357486, 0.01867410134790199, 0.027690997147666555, 0.054238957951643636, 0.07960901928267308, 0.06163298458393131, 0.07886273254241262, 0.027409528947568366, 0.018719490251636932, 0.05794551316648722, 0.05895881700728621, 0.01973216305486858, 0.02856289768325431, 0.017051439133605788, 0.011781523968758327, 0.020078127704826847, 0.012872965357798551, 0.05279757993827973, 0.042186873233211894, 0.02292129460589162, 0.019837917826537575, 0.032161348698926825, 0.033711210891072235, 0.013581930975695806, 0.047549664575074396, 0.040207101431276114, 0.04180333809927106, 0.061959556703056605, 0.06024284953517573, 0.04282589715772441, 0.012793371503773545, 0.021927841307063187, 0.009764810175901013, 0.026553555325205837, 0.05347027616309268, 0.04641637199425271, 0.08742348317589078, 0.04194099928385445, 0.02804441380846713, 0.04122073096888406, 0.03595461729647858, 0.028430625763056532, 0.009651438000478914, 0.06252356179590736, 0.0651021780712264, 0.04450356820598245, 0.02199081953481904, 0.09276084641792945, 0.30417522521955626, 2.042245145354952, 21.11861882890974, 44.536584172930034, 68.62594699859619, 86.37864303588867, 79.11560072217668, 70.91521167755127, 70.95076560974121, 65.15826783861432, 55.626426764896934, 54.956276484898154, 47.143176555633545, 38.133322375161306, 55.34566395623343, 48.644717012132915, 53.65679659162249, 36.72817775181362, 32.186498165130615, 30.47245052882603, 21.63238947732108, 26.23151329585484, 25.47166177204677, 25.398910658700125, 30.400352546146937, 27.4811589717865, 32.859142848423545, 37.922569615500315, 26.28951164654323, 27.845532928194316, 24.78206695829119, 33.71542147227696, 30.318301268986293, 24.000634329659597, 22.695126874106272, 22.394405364990234, 23.057791573660715, 21.533606937953405, 28.392571551459177, 28.81454086303711, 33.45102514539446, 30.98917416163853, 22.875302348818096, 30.427999428340367, 36.455912590026855, 36.98955161230904, 37.44703490393502, 51.045264039720806, 56.21245520455496, 64.52770492008754, 61.58419786180769, 72.28492396218437, 67.30705383845738, 62.74385220663888, 54.87681341171265, 42.756212506975444, 26.477307558059692, 14.594397578920637, 4.3473632250513345, 1.4491912083966392, 0.31757574900984764, 0.03188311880720513, 0.03807783818670681, 0.05172584744702492, 0.041595502823059044, 0.012459619635982173, 0.0676474172089781, 0.026736074459872076, 0.027476541066010083, 0.034064958337694407, 0.031096676364541054, 0.06920810203467097, 0.08609960707170622, 0.04152320830949715, 0.05792159480707986, 0.01686164949621473, 0.05715899608497109, 0.02993055965219225, 0.05905222413795335, 0.03063464829964297, 0.05627266989488687, 0.05423186047534857, 0.024529583752155304, 0.038873888685234954, 0.07407746610364743, 0.04335522911112223, 0.017391817744023035, 0.01118131903266268, 0.0020190543145872653, 0.019484151720202396, 0.04522756507088031, 0.03682864843202489, 0.014359906149495925, 0.008209505284737264, 0.022689588467723558, 0.07881644966879062, 0.055938409974000285, 0.04909172022183027, 0.032365631844316206, 0.035571143230689425, 0.034350937099329064, 0.008551351227132338, 0.05412069947591849, 0.03932039186890636, 0.09411548051450934, 0.008139106428383716, 0.042659221815743616, 0.026502593952630247, 0.02746225960020508, 0.05532759275021298, 0.05626082945881145, 0.04407541939456548, 0.02392348913209779, 0.08930811419018678, 0.06646339395748717, 0.047756217420101166, 0.02587265900469252, 0.008703080987158631, 0.03672476132799472, 0.015344474032255155, 0.022549191090677465, 0.14898594761533396, 0.12132596969604492, 0.2174127030053309, 0.0641807478719524, 0.11228759147758995, 0.1042150603607297, 0.09137204129781042, 0.12117053089397294, 0.09722547113363232, 0.14649121862437042, 0.17677179378058228, 0.1452506666204759, 0.22612602902310236, 0.1490803182657276, 0.08468541795653955, 0.1441656212721552, 0.15208307999585355, 0.11518212008689131, 0.14005753956735134, 0.11810702670897756, 0.1370444776756423, 0.1711731334882123, 0.13096417965633528, 0.10433592101825134, 0.11493699252605438, 0.14341292237596853, 0.0916526290987219, 0.15731872405324662, 0.14887730058814796, 0.13021093793213367, 0.12790949642658234, 0.13169070067150251, 0.12025511930031435, 0.11859493409948689, 0.19220865544463905, 0.11789712868630886, 0.12845658564141818, 0.11401816111590181, 0.16152633327458585, 0.14324322076780455, 0.09544768224337272, 0.15576759300061635, 0.08287570399365254, 0.17579189421875135, 0.12888593545981816, 0.14355012215673923, 0.1269878423107522, 0.13217474041240557, 0.1633532481001956, 0.09909168670752219, 0.1719393352312701, 0.10509524920157023, 0.12638269763972076, 0.07645152442689453, 0.25233153998851776, 0.444185878017119, 3.4965400227478574, 26.67514361654009, 58.33690166473389, 79.6278566632952, 97.27453708648682, 88.38328865596226, 80.26767458234514, 78.10799380711147, 75.02266011919293, 64.81845923832485, 63.07655279976981, 53.168049880436485, 43.09968975612095, 65.46866471426827, 63.476713453020366, 61.562352725437705, 46.88532543182373, 43.22835997172764, 30.69342408861433, 28.39754125050136, 29.149565628596715, 23.71869032723563, 27.82851505279541, 39.97050598689488, 30.55652025767735, 38.89149590900966, 39.37919691630772, 32.11436891555786, 42.991523674556184, 44.190859181540354, 43.44739498410906, 37.86409705025809, 30.5632461139134, 26.743918623243058, 25.710198640823364, 24.10511439187186, 27.427480663572037, 27.154902832848684, 21.942470209939138, 31.790412630353654, 23.325219052178518, 22.40846504483904, 26.791737862995692, 37.27168321609497, 36.811045442308696, 46.32113865443638, 58.78564412253243, 64.88307053702218, 76.00145980290004, 72.79687418256486, 83.20484488351005, 77.46967669895717, 71.47468062809536, 66.97105285099575, 53.29496914999825, 34.92917101723807, 20.046649013246807, 8.69755870955331, 3.2749680493559157, 0.9581335697855268, 0.2087461416210447, 0.12239378025489193, 0.11755430565348693, 0.16157604275005205, 0.11548287394855704, 0.12958646858377115, 0.2181700159396444, 0.126377065799066, 0.09741366282105446, 0.0569797610597951, 0.23022736608982086, 0.32062166556715965, 0.09426602707909686, 0.10850460268557072, 0.1573264186403581, 0.14845366403460503, 0.1194773010377373, 0.1837273205497435, 0.09455303382128477, 0.18503484395997866, 0.1251540064279522, 0.10284023984734501, 0.10527334428791489, 0.20493049493857793, 0.11007359277989183, 0.13009273713188513, 0.09366108596857105, 0.10823997402829783, 0.14001868665218353, 0.15796188025602273, 0.1888438817113638, 0.13932618738285132, 0.13914609061820166, 0.07836568528520209, 0.13151478368256772, 0.13519386840718134, 0.09977482897894722, 0.10181246963994843, 0.19929463735648564, 0.1877212319523096, 0.1062076191550919, 0.20444656376327786, 0.1159573599163975, 0.26866642917905537, 0.11740877346268722, 0.08219461089798383, 0.2580592983535358, 0.07354669565601007, 0.1489278378763369, 0.1428398181285177, 0.1925521841538804, 0.14849030492561205, 0.1653334711279188, 0.1598627282572644, 0.07666689822716372, 0.10650303294616086, 0.14203750475176743, 0.15327168335872038, 0.13683098341737474, 0.15089522302150726], [0.11716701143554278, 0.02659588403600667, 0.05743178751851831, 0.023886264700974737, 0.020200757642409632, 0.017085180983745625, 0.03082925214299134, 0.029000132078570977, 0.008995526187521006, 0.04215146049058863, 0.028442252460601072, 0.0981004691815802, 0.029746079551322118, 0.05717011048857655, 0.039223717592124424, 0.007198920673025506, 0.037470559523041756, 0.040966368546443324, 0.009108426781105143, 0.02021725113237543, 0.06540499467934881, 0.10112933415387358, 0.03892317746898957, 0.027497312719268457, 0.020292161398434212, 0.02601294611979808, 0.06358296530587332, 0.03614581489403333, 0.003172418809429343, 0.042808787897229195, 0.008047678923633481, 0.054417592473328114, 0.010609475164008992, 0.08589601263936077, 0.005977763744470264, 0.0411409386433661, 0.06114629855645554, 0.019702248142233918, 0.07309238253427403, 0.007602343668362924, 0.015284980081820061, 0.04111572088939803, 0.05272295804960387, 0.02791383144046579, 0.009665624471381307, 0.03420778317376971, 0.004262556563064988, 0.036644412603761466, 0.03834905881168587, 0.05822014342993498, 0.04543388042865055, 0.062287553745721064, 0.2878071149545056, 0.9114080199173519, 5.078828317778451, 15.74968671798706, 44.31578779220581, 67.06051090785435, 73.7363748550415, 67.0890610558646, 52.935698645455496, 57.318664005824495, 48.24253790719168, 35.83929818017142, 33.43448495864868, 24.694745472499303, 24.286220925194876, 16.178322826113018, 20.5262188911438, 15.469429390771047, 30.528477328164236, 18.95445125443595, 23.296630689076014, 39.97519949504307, 16.687900236674718, 19.54684771810259, 22.20177698135376, 36.63773305075509, 45.7567503792899, 32.82661485671997, 44.144518171037944, 45.324721813201904, 46.42229052952358, 53.781186716897146, 42.9535413469587, 50.33535269328526, 33.55788843972342, 44.48107154028756, 75.56820487976074, 59.74760832105364, 49.540312017713276, 41.56148712975638, 42.92573118209839, 28.54355069569179, 25.315815414701188, 23.344057355608257, 18.021516629627772, 23.945231131144933, 17.875336953571864, 17.838261365890503, 13.155020918164935, 27.031895399093628, 18.568994726453507, 21.25651798929487, 29.386130946023123, 39.3532314981733, 43.34405442646572, 55.72317695617676, 62.554305349077495, 64.01411492483956, 65.79683508191789, 59.157588141305105, 50.98472785949707, 38.457052843911306, 25.435053450720652, 10.532144563538687, 3.772549177919115, 0.9837120601109096, 0.495341745870454, 0.13097990809806756, 0.011963187301132296, 0.02441675016390426, 0.05453466012009552, 0.05700587787266288, 0.02790163816618068, 0.023703959304839373, 0.03391289185466511, 0.03559136696692024, 0.01010926762994911, 0.026233604011525, 0.0212248417083174, 0.014894841105810233, 0.05693025514483452, 0.03546205176306622, 0.027276841424671665, 0.046974463654415946, 0.022468874596857598, 0.016512042809543864, 0.03155551192217639, 0.05552872070776565, 0.012054142375875796, 0.12069375147776944, 0.05587511283478566, 0.006935418807967965, 0.018938694382086396, 0.016407421191356013, 0.003052749192907608, 0.02105410533424999, 0.043250883995954476, 0.028650784931544746, 0.07674186956137419, 0.06984413361975125, 0.005186810316185334, 0.045563782565295696, 0.05716743706060307, 0.0321664309262165, 0.011362399673089385, 0.06156037455158574, 0.015134905099070497, 0.04879060334392956, 0.026719613200319663, 0.04581598724637713, 0.06817858120692627, 0.003949747254539813, 0.04456515882962516, 0.03144232210304056, 0.040587579764957936, 0.03125612870124834, 0.042456295740391524, 0.04700982550691281, 0.043821297852056365, 0.012324566570376711, 0.08517836686223745, 0.03153581065790994, 0.06148862625871386, 0.01982046420952039, 0.032969080177800994, 0.011824133423423129, 0.05387210799381137, 0.04547605138005955, 0.02811883552931249, 0.01781927444972098, 0.04775975937289851, 0.01922636948126767, 0.02608108121369566, 0.029719277418085506, 0.03886461650420513, 0.04777644794168217, 0.04802632524764963, 0.023789317313847796, 0.04916346851470215, 0.02007390552067331, 0.058984716688948016, 0.027321509384949292, 0.027162660944408605, 0.04046529418389712, 0.05759117539439883, 0.08848941419273615, 0.036872386799326966, 0.01836030773951539, 0.0323481663529362, 0.03663674855072584, 0.018672050475808125, 0.0477202550641128, 0.05614371431459274, 0.023616070360211388, 0.04193199512415698, 0.12496702931821346, 0.038292964321694205, 0.07472922613045999, 0.01777490334851401, 0.00855794913201992, 0.04402217475165214, 0.02204307690928025, 0.022678158545334424, 0.024816268190209354, 0.003093864810320416, 0.08566905624632325, 0.08695927701358284, 0.02689531136171094, 0.011399738606996834, 0.03236195079184004, 0.009596692947005587, 0.018909612371187125, 0.05580854515678116, 0.028886704772178615, 0.06386578548699617, 0.17235500578369412, 0.4354177127991404, 1.2075647796903337, 7.2646143436431885, 21.02358831678118, 55.026765959603445, 78.35978957584926, 80.26803588867188, 74.63050379071916, 63.09538241795131, 68.14866828918457, 55.80274077824184, 46.27672924314226, 42.791860239846365, 31.860467842647008, 37.82121624265398, 24.492266280310496, 24.304715292794363, 30.631762300218853, 43.215578760419575, 22.532512971333094, 28.59101905141558, 39.74052061353411, 16.13524052074977, 20.987683500562394, 29.75996834891183, 29.018319368362427, 29.19931125640869, 35.650703225817, 33.210426398685996, 36.07330308641706, 35.52274867466518, 40.0436566216605, 36.43454340526036, 39.23903438023159, 31.73801279067993, 34.3953617640904, 44.60172006062099, 43.55631147112165, 35.19639526094709, 29.659757954733713, 36.894086837768555, 28.090769597462245, 14.476158346448626, 17.544265713010514, 18.67591881752014, 25.168954815183366, 24.634693929127284, 25.54688470704215, 26.074433633259364, 36.80524369648525, 31.29269232068743, 28.69208059992109, 39.04409572056362, 48.36792857306344, 51.182775838034495, 62.78160176958357, 72.12298229762486, 72.12480967385429, 73.67246532440186, 67.75725541796002, 60.954878670828684, 45.18497616904122, 30.478592736380442, 12.2032436473029, 4.57910475560597, 1.2936703307288033, 0.6725578308105469, 0.13292994988816126, 0.08519737941345998, 0.053076464616294415, 0.06929624373359339, 0.04833610701773848, 0.07231712234871727, 0.0286582386387246, 0.024998359847813845, 0.0545387381155576, 0.06902483651148421, 0.02438741879138563, 0.001108235024730675, 0.05257854204890983, 0.05247676858146276, 0.027269138355872462, 0.04732859447332365, 0.05399771161111338, 0.03095474380201527, 0.04073642320664866, 0.05294230806508234, 0.04652604360931686, 0.04826245543413928, 0.03799580330295222, 0.006019032668388847, 0.020141032990068197, 0.009817936075186091, 0.02626045194587537, 0.04505595677931394, 0.008887923256094967, 0.010302425345538982, 0.07125152381403105, 0.051959904709032605, 0.05738077525581632, 0.0538182730254318, 0.06730204966983624, 0.01927291359087186, 0.03996202476056559, 0.015642103240160004, 0.06302360139255013, 0.04228414122813514, 0.08357665780931711, 0.015323405519926121, 0.02153606366898332, 0.031110928992607763, 0.027148411709016988, 0.029623288461672406, 0.03438996643360172, 0.03474941018170544, 0.01533706103717642, 0.009180530456693044, 0.009158255848368364, 0.05268115011442985, 0.07745733724108764, 0.045412564251039705, 0.04131179376106177, 0.05336611425237996, 0.039776642208120654, 0.17782007610159262, 0.1657591432865177, 0.17412896773644856, 0.14903253582971437, 0.21291464008390903, 0.11467612295278481, 0.12534767389297485, 0.13122092373669147, 0.0968487009938274, 0.10788288818938391, 0.1705628183803388, 0.07658672252936022, 0.13025303424469062, 0.10507981252989598, 0.1244359128177166, 0.07711769653750317, 0.17175459728709289, 0.12203350530139037, 0.15759131871163845, 0.10590205448014395, 0.14942474264119351, 0.20738638458507402, 0.20346352936966078, 0.12108422123960086, 0.11967601680329867, 0.11183720028826169, 0.13806631070162567, 0.10560779419860669, 0.12022820860147476, 0.1438451220414468, 0.08447092625179461, 0.15881165037197725, 0.17804753461054393, 0.2051477889929499, 0.06871380962963615, 0.13000851736537047, 0.15363575810832636, 0.14177278109959193, 0.18366716163499014, 0.05957641279590981, 0.09831422128315483, 0.18499539393399442, 0.1663138320935624, 0.07389377310339894, 0.06548835949173995, 0.11596912571362086, 0.10532416656081166, 0.1736661797123296, 0.16851254339729035, 0.14116716145404748, 0.16610234629895004, 0.202972622854369, 0.5833733049886567, 1.521768833909716, 8.824728114264351, 26.612366642270768, 65.95363507952008, 88.87619386400495, 92.23917061941964, 82.76351615360805, 70.25793988364083, 76.16085842677525, 66.07158769880022, 52.45335469927107, 50.701324735369, 40.19450896126883, 40.20778349467686, 29.028121539524623, 32.630505425589426, 29.687015737806046, 47.150996753147666, 32.896128109523225, 38.98327119009835, 56.19172525405884, 28.904328959328787, 35.066578592572895, 37.893036297389436, 54.09294891357422, 58.572167669023784, 45.53868464061192, 61.13796370370047, 62.72586332048689, 63.768586431230815, 73.81286757332938, 57.683694566999165, 66.75486660003662, 49.624235834394185, 62.20233045305525, 93.64784145355225, 77.05464690072196, 66.68758719308036, 56.38604899815151, 60.056518282209126, 41.335434436798096, 35.97570521490914, 33.45885923930577, 25.6913412298475, 34.352265562329976, 29.020871094294957, 28.17378667422703, 21.547293152127946, 40.904969215393066, 32.286159651620046, 36.85208150318691, 46.268353189740864, 57.09454638617379, 61.76762335641043, 75.71252591269356, 81.83326353345598, 83.38048144749233, 84.9440484728132, 78.31365353720528, 71.41423824855259, 56.29726144245693, 41.075134072984966, 17.740389040538243, 7.931630117552621, 2.5782102942466736, 1.238725061927523, 0.32771230222923414, 0.16789180599153042, 0.1235208133501666, 0.11279781588486262, 0.19299095203833921, 0.07990800216794014, 0.10354417243174144, 0.16163366394383566, 0.15530139873070375, 0.13366571255028248, 0.10848953242280654, 0.07038567241813455, 0.14010043655123028, 0.11912918543176991, 0.11509536259940692, 0.12856553122401237, 0.1843277561877455, 0.16149331576057843, 0.06693022605031729, 0.1690512459192957, 0.1541025766304561, 0.09295944004718747, 0.16721742360719613, 0.14209374173411302, 0.07622086323265519, 0.09173353082899537, 0.09976829468671765, 0.10118994090173926, 0.11554521774607045, 0.0979157244520528, 0.139887023717165, 0.15579754353633948, 0.14537800050207547, 0.13762896774070604, 0.18727219104766846, 0.14933806657791138, 0.17592203723532812, 0.1659192368388176, 0.24751793114202364, 0.15638067653136595, 0.151564163554992, 0.09846841836614267, 0.13758712927145617, 0.13618784078529902, 0.05455553524994424, 0.18185498458998545, 0.17452501505613327, 0.0903931391824569, 0.10784041189721652, 0.13867628654198988, 0.11902228902493205, 0.15452879161706992, 0.15818513184785843, 0.15790503259216035, 0.0956383573689631, 0.2585245833865234, 0.08756679655717951], [0.03445243236741849, 0.092509951309434, 0.04809450783899852, 0.05095033281083618, 0.05943227160189833, 0.04799815586635044, 0.023388006258755922, 0.03910063133974161, 0.026065334112250378, 0.09129229986241885, 0.04148907121270895, 0.033496003331882615, 0.021949243997888904, 0.04648518223049385, 0.028503787105104754, 0.05224557134455868, 0.017878385027870536, 0.129207615341459, 0.10351389619920935, 0.017251422063314488, 0.04667591842423592, 0.029770418602441038, 0.045241878767098696, 0.044205155290131054, 0.035404437354632785, 0.03305584105796047, 0.035476854004498036, 0.0163769295239555, 0.029773410941873277, 0.036229535937309265, 0.04531485860102943, 0.06838282024753944, 0.014157694232250963, 0.05117924338472741, 0.02494514743531389, 0.03624632628634572, 0.03605679788493684, 0.0753690575116447, 0.03186741072152342, 0.06254817904638392, 0.01668531690458102, 0.005596270576851177, 0.0237482998719705, 0.09594314851398979, 0.03063655159037028, 0.021345588711223433, 0.05804666916706732, 0.07296330481767654, 0.1104208127196346, 0.23692043551376887, 2.4219027502196173, 6.474729231425694, 12.710400479180471, 22.632672991071427, 51.1129012789045, 63.06550516401018, 70.82730306897844, 66.59973417009626, 52.83797918047224, 48.98086391176496, 28.61580327578953, 28.878922871180944, 22.3035854612078, 20.3994768006461, 16.017765590122767, 15.757015330450875, 17.50132931981768, 26.464562824794225, 34.02448429380144, 24.85705712863377, 21.309140171323502, 25.81602839061192, 36.36029495511736, 39.56839983803885, 53.48271642412458, 41.25654806409563, 58.6785306930542, 73.6095632825579, 62.13252885001046, 47.03611523764474, 57.68675524847848, 50.72200257437569, 56.61699669701712, 40.20151621954781, 39.49624974387032, 26.968548672539846, 37.834219796316965, 41.93491111482893, 50.137888363429475, 52.448094912937705, 58.87012032100132, 61.55507101331438, 54.375695432935444, 72.40250137874058, 93.73636150360107, 69.18814659118652, 76.83506298065186, 61.97095543997628, 72.91709191458565, 49.10115807397025, 19.51828019959586, 17.393574919019425, 15.528911181858607, 29.506473745618546, 22.39615109988621, 21.888248205184937, 26.195089101791382, 28.18086862564087, 46.34944908959525, 48.944507462637766, 54.61749274390084, 56.10754087993077, 62.49375179835728, 69.85685511997768, 63.41146986825125, 52.39370788846697, 35.53775330952236, 24.568533182144165, 13.132793630872454, 3.052553389753614, 0.8970606412206377, 0.2005508363779102, 0.12554330910955155, 0.06360623905701296, 0.030546995145933967, 0.04132644333211439, 0.02235610886210842, 0.05649050338459866, 0.007099166695427681, 0.02150131928335343, 0.06991862319409847, 0.031098488053040843, 0.035241473599203994, 0.02816347125917673, 0.04312541947833129, 0.05863715748169592, 0.06707855380539383, 0.049139624794146845, 0.05644887186852949, 0.03482499219743269, 0.02247353782877326, 0.08240524173847266, 0.013308761258875685, 0.03526947334674852, 0.021869078478110687, 0.01064748754392245, 0.04924519805769835, 0.05127642995544842, 0.07439797211970602, 0.04966624260747007, 0.03641162420223866, 0.04420521975095783, 0.020591190084815025, 0.04863580236477511, 0.053944667136030536, 0.04432354947285993, 0.04854312465925302, 0.08921431350920882, 0.04193614436579602, 0.06003841371940715, 0.05083092761092952, 0.06808229030242988, 0.07730968123567955, 0.13030217375074113, 0.04110595677047968, 0.012522044857697827, 0.023035938186304908, 0.0574145730850952, 0.02120542373242123, 0.03251947269641927, 0.03757873496838978, 0.018709529357563173, 0.013686296446914119, 0.024702036819819893, 0.03344363060646823, 0.04467070834445102, 0.04828941023775509, 0.03290957944201572, 0.02947742718138865, 0.010268255170168621, 0.042677253883864195, 0.01899688893796078, 0.006651797531438726, 0.014985934432063783, 0.005347858058355216, 0.026609968726656268, 0.038524785810815435, 0.05547519786549466, 0.02372463426685759, 0.07690802243139062, 0.056125129240431955, 0.06673837027379445, 0.059186248374836783, 0.045948257470237355, 0.015860343850882988, 0.05495720762493355, 0.008827336016111076, 0.03354398932840143, 0.011264409886540046, 0.03627035999670625, 0.017656312390629734, 0.033981054089963436, 0.026294020769585456, 0.046736029841537984, 0.04711096454411745, 0.045183680818549225, 0.038576330723507066, 0.08224991828735385, 0.010402336234359868, 0.04266813437321356, 0.10124364694846527, 0.023275238827669194, 0.06958356938724007, 0.029172154276498725, 0.028191739028053622, 0.07778208410101277, 0.021970595798588226, 0.02889714403344052, 0.02791974487315331, 0.06260065694472619, 0.00413453608884343, 0.032054621925843615, 0.041692244953342845, 0.025724546684484397, 0.021717115471671735, 0.23061711660453252, 2.6955753564834595, 8.700411813599722, 17.41846510342189, 29.581910337720597, 61.3539137159075, 73.01926517486572, 80.35832772936139, 72.49057674407959, 63.81254768371582, 54.8689341545105, 39.42698662621634, 38.73382043838501, 36.23812130519322, 31.41454287937709, 29.823863983154297, 26.279933554785593, 25.78953664643424, 28.569305930818828, 33.22360018321446, 21.394514424460276, 26.252936329160416, 29.98324523653303, 35.52274520056588, 38.14355707168579, 41.7027405330113, 35.1767909186227, 36.16248321533203, 45.27279097693307, 55.05997140066964, 42.69964722224644, 39.98998873574393, 42.024254526410786, 37.620694705418174, 33.94522966657366, 27.180526052202495, 21.341871397835867, 23.202652829033987, 27.153542722974503, 44.17856434413365, 39.78278650556292, 47.22284460067749, 47.1559681892395, 43.653040817805696, 49.82761655535017, 65.8304991040911, 51.15803330285208, 49.27930293764387, 40.84036486489432, 44.49012851715088, 45.004215308598106, 21.75518672806876, 26.914350986480713, 24.61925503185817, 39.114630358559744, 32.18031774248396, 28.418705463409424, 37.06617634637015, 40.09622321810041, 54.63670103890555, 55.586863722120015, 62.33961296081543, 65.63325364249093, 71.51621695927211, 79.08964225224086, 72.74752807617188, 58.51319830758231, 40.11906542096819, 27.33798439162118, 15.7800156048366, 3.5538148922579627, 1.1812331697770526, 0.3032834944980485, 0.07311746797391347, 0.034272182932389636, 0.020465138634400706, 0.059669914921479564, 0.04917517324377384, 0.05758688026773078, 0.06297680961766414, 0.015530641988984175, 0.05246928434020706, 0.0779304661388908, 0.028176395654944435, 0.054765161858605485, 0.012975955947435327, 0.07459401445729391, 0.04322646012795823, 0.025719654446999942, 0.06374444985496146, 0.017238144829337086, 0.045997312159410546, 0.039790938940963576, 0.010557667318997639, 0.024892766228211776, 0.013884692452847958, 0.03484872056703482, 0.03956301902819957, 0.018264809024653265, 0.027955456171184778, 0.09165685637188808, 0.03729270192395363, 0.04803480015003255, 0.05945954192429781, 0.04623404624206679, 0.020824865670874715, 0.039188230210649114, 0.032601643287177594, 0.04968661901408008, 0.01797739855412926, 0.04461124832076686, 0.07728895877621003, 0.022922843362071683, 0.05355170375800558, 0.04439920952011432, 0.05215189279988408, 0.07910219433584384, 0.0406917722097465, 0.02756959875114262, 0.01788354867936245, 0.062143867170172076, 0.029717078964625086, 0.03769286795120154, 0.033939632919750044, 0.07687071657606534, 0.048738098304186545, 0.028906501031347683, 0.15630221074180944, 0.092867003221597, 0.08553680977118866, 0.16371952130326203, 0.18257873718227657, 0.1905902951423611, 0.08603779931685754, 0.08832358023417847, 0.15726057360214846, 0.17895289031522615, 0.14583289037857736, 0.10928080603480339, 0.17097228712269238, 0.15547567366489343, 0.21838230240557874, 0.1966205444186926, 0.20552879997662135, 0.23890582897833415, 0.17733462500785077, 0.11067926670823779, 0.17864419759384223, 0.1415483895689249, 0.1247396929455655, 0.11111268773674965, 0.09691046803657498, 0.11169148489300694, 0.1210616124527795, 0.1219007024275405, 0.08562018815428019, 0.1915540862828493, 0.09052676986902952, 0.2727107693042074, 0.10144084279558488, 0.10214572532900743, 0.19337539640920504, 0.17469650799674646, 0.1536819256309952, 0.18632203846105508, 0.1047563481011561, 0.18086626407291206, 0.07080719194241933, 0.14410717226564884, 0.11582750188452856, 0.24968680047563144, 0.12129497421639306, 0.13121918668704374, 0.12141690695924418, 0.20396762660571507, 0.1491703191506011, 0.9185149414198739, 3.2307701238564084, 10.466902715819222, 21.1374797139849, 37.4465902192252, 71.60351412636894, 85.33009038652692, 88.78851454598563, 82.09425871712821, 74.49939128330776, 64.98909309932164, 44.672511781964985, 43.05340780530657, 36.923422132219585, 34.36429984228951, 29.934291703360422, 28.347409997667583, 28.260449818202428, 37.49127755846296, 47.558282784053254, 37.94927154268537, 36.69520507540022, 43.072011607033865, 52.90448038918631, 57.83471366337368, 75.87660762241909, 57.80022627966744, 75.20628711155483, 92.89794322422573, 78.62120165143693, 60.551348141261506, 76.76547677176339, 65.48340879167829, 71.98936149052211, 49.14637347630092, 49.447355542864116, 33.05068383898054, 46.954317569732666, 51.72862631934029, 63.29890210287911, 66.43549960000175, 75.01488508496965, 77.72311919076103, 70.959534236363, 93.75275925227574, 118.91594532557896, 89.49400683811733, 102.25003787449428, 80.12657751355852, 91.01594025748116, 64.55821446010044, 29.155329159327916, 28.159475122179302, 24.750473499298096, 44.00623164858137, 35.20722055435181, 34.99930960791451, 41.26107134137835, 44.52752372196743, 63.553143637520925, 67.22304316929409, 71.1135619027274, 74.57327147892543, 82.7769261768886, 88.32167897905622, 84.02676813943046, 69.57568236759731, 51.61458900996617, 38.749328817640034, 20.907235520226614, 6.9244027478354315, 2.095635537590299, 0.6166026304875101, 0.17703368115637982, 0.16796579344996385, 0.10126379943851914, 0.15633397975138255, 0.11972846756024019, 0.1475275180169514, 0.18673191432441982, 0.09519749281129666, 0.19700094472084725, 0.10539294287030186, 0.11021235319120543, 0.11624640226364136, 0.10654595707144056, 0.13482275046408176, 0.16671594551631383, 0.1005055501258799, 0.14117459819785186, 0.1175281684845686, 0.12306478353483336, 0.1272297129034996, 0.17041660765452044, 0.17199630503143581, 0.07165584247559309, 0.10163633551980768, 0.14655054972640105, 0.0987188181440745, 0.15677718525486334, 0.2439161315560341, 0.14127636487994874, 0.16476719294275555, 0.22608131356537342, 0.1182112768292427, 0.12767743745020457, 0.1634428554347583, 0.11598251999488898, 0.23940303229859897, 0.10981028048055512, 0.23503858649304935, 0.16748708699430737, 0.15963189064392022, 0.1492586372686284, 0.2057762752686228, 0.11794181700263705, 0.1833877002022096, 0.1374064353959901, 0.12431567641241209, 0.09955678853605475, 0.13873519695230893, 0.16296826090131486, 0.1289094127714634, 0.12634896087859357, 0.20160260636891636, 0.17329711094498634, 0.10533914861402341], [0.05958125075059278, 0.042415515785770755, 0.07700253557413816, 0.016270949139392803, 0.01599719248978155, 0.04885697763945375, 0.03996028431824275, 0.03162045111613614, 0.04537899373099208, 0.04440944522087063, 0.04762987419962883, 0.025890153333810822, 0.018476786757154123, 0.06828454123543841, 0.12989274572048867, 0.032442482720528326, 0.12254658634109156, 0.052956323205892525, 0.053815080518169064, 0.08914612073983465, 0.05923271445291383, 0.12019601890019008, 0.04615195029016052, 0.07582591513970069, 0.019026501902512143, 0.07074479386210442, 0.0935790782262172, 0.041966122042919905, 0.07043017074465752, 0.0568498385670994, 0.022239775729498694, 0.06378799144710813, 0.04376290991370167, 0.03264136811984437, 0.06812039682907717, 0.06747561214225632, 0.04807126462193472, 0.07123034673609904, 0.0413350709048765, 0.06122012995183468, 0.03482252232996481, 0.12953268789819308, 0.07213490855480943, 0.016094738684062446, 0.02132817410996982, 0.11072714413915362, 0.054935531823762825, 0.3251818822962897, 2.4119090693337575, 9.795285497392927, 12.494904705456324, 40.595770903996055, 54.66059936795916, 69.8763656616211, 67.02642999376569, 64.23502595084054, 63.845016615731375, 45.82709741592407, 33.10302809306553, 32.6138471194676, 19.099538326263428, 17.63845201901027, 12.045777491160802, 19.00148708479745, 21.280669927597046, 22.973365749631608, 26.147982052394322, 34.319438798086985, 55.99998276574271, 44.602237701416016, 46.444743633270264, 30.1924763407026, 46.83118159430367, 42.14476408277239, 43.31623036520821, 39.19645929336548, 46.70960896355765, 30.76856885637556, 12.622767192976815, 16.092866931642803, 9.85451454775674, 7.81349858215877, 8.407413227217537, 6.52865116085325, 9.157968929835729, 7.72206289427621, 6.589794439928872, 5.803032977240426, 7.422663279942103, 13.762896231242589, 12.565505351339068, 14.797983271735054, 24.274980476924352, 29.556504249572754, 27.963245834623063, 37.602243764059885, 49.624791690281455, 66.14481476375035, 77.8783905846732, 57.511942046029226, 61.47176906040737, 36.31619473866054, 41.17389576775687, 21.688371113368444, 19.861557688031876, 25.922518219266617, 17.01153690474374, 21.163128989083425, 29.87846987588065, 24.865365437098912, 35.60673155103411, 32.68292610985892, 41.60770654678345, 47.74573128564017, 59.32387242998396, 56.81775099890572, 64.54446397508893, 48.73784024374825, 42.33050332750593, 43.56320061002459, 21.9757034437997, 8.187349012919835, 1.3825381164039885, 0.18773922670100415, 0.1276812779584101, 0.10154650426868882, 0.08747912983277015, 0.10717850098652498, 0.13088437036744185, 0.07194993312337569, 0.12431874339069639, 0.040245231706649065, 0.0914163835612791, 0.09731803009552614, 0.10256133481327977, 0.04212496030543532, 0.07214740716985293, 0.06723363298390593, 0.033164091142160554, 0.016493099808160747, 0.033667326638741155, 0.09894038018371377, 0.02532891496749861, 0.12983398458787374, 0.04733658083049314, 0.06119570269116333, 0.04471025675801294, 0.06546496360429696, 0.04802325487669025, 0.05002872279978224, 0.02381434677434819, 0.06093051763517516, 0.058142200112342834, 0.1018147427322609, 0.07821648900530168, 0.09571975442980017, 0.029330917900162082, 0.10490884206124715, 0.037303857039660215, 0.10164633712598256, 0.03209932042019708, 0.07035173888185195, 0.01991104524183486, 0.11893748571830136, 0.06524830737284251, 0.02813200080501182, 0.01710120458821101, 0.07900081441870757, 0.06328455239002194, 0.08190149055527789, 0.044409312906541994, 0.13077309062438353, 0.06331676244735718, 0.07656980665134532, 0.058502210437187126, 0.045598628731178384, 0.013130260747857392, 0.08858052108969007, 0.03124814573675394, 0.025719880059893643, 0.028686238386269127, 0.06258998358888285, 0.047862811878855736, 0.011506301683506795, 0.009393622682962035, 0.036974994864846976, 0.020750445646366904, 0.010229330160655081, 0.029851608710097413, 0.027371877039383565, 0.08820498588361911, 0.09331268537789583, 0.0602997446964894, 0.08787135700029985, 0.08611771038600377, 0.12352907790669374, 0.0568761928672237, 0.09164853074720927, 0.08234337970082249, 0.07492332107254437, 0.07602545193263463, 0.02951000364763396, 0.04089033530492868, 0.02441351185552776, 0.0441561345277088, 0.07762876911354916, 0.040529415743159394, 0.031167878436722925, 0.037659748656941314, 0.01195483623139028, 0.032169409694948366, 0.059590282051690986, 0.0869178795920951, 0.098900509466018, 0.032196065943155966, 0.10164972301572561, 0.12128417193889618, 0.10695168708584138, 0.03398042983774628, 0.036389989113169055, 0.08831470499613456, 0.10580878305648055, 0.02917149949020573, 0.3437318897673062, 2.917847578014646, 10.42181498663766, 20.195736510413035, 51.31126887457711, 66.20627158028739, 81.8241822378976, 76.78150626591274, 72.36272294180733, 72.67081301552909, 56.79272011348179, 43.32259838921683, 44.73489965711321, 25.327559607369558, 26.934848172324045, 20.461419991084508, 22.544934613364084, 26.011997120721, 23.321930817195348, 27.540805782590592, 32.433986050742014, 50.73005206244332, 41.81980030877249, 44.58802168709891, 33.90280744007656, 45.09486845561436, 46.26464632579258, 41.32739537102835, 34.574395997183665, 37.384872845241, 29.150677340371267, 16.37219146319798, 14.260153617177691, 10.890321595328194, 7.614180820328849, 6.468080239636557, 5.034922216619764, 6.527380074773516, 4.864214531012943, 4.679165329251971, 4.519063634531839, 5.535014033317566, 9.803069216864449, 10.901225055967059, 12.715400576591492, 17.99511694908142, 26.063802889415197, 30.692156042371476, 35.63259622028896, 45.541432653154644, 58.1016252381461, 67.6665049961635, 43.42956590652466, 34.11514786311558, 33.11782775606428, 35.230820110866, 34.72177423749651, 31.65324476787022, 32.13352509907314, 27.7664954321725, 30.481246948242188, 37.941433974674766, 32.88221434184483, 45.42662756783621, 41.37891278948103, 49.12798159463065, 54.79518597466605, 69.96047360556466, 66.53757558550153, 74.36660426003593, 58.60067612784249, 50.09765134538923, 51.11432565961565, 26.20673601967948, 10.06259572505951, 1.580631366797856, 0.47611743743930546, 0.05070998552920563, 0.07872500350432736, 0.07170601335487195, 0.12779688675488743, 0.08888020286602633, 0.08837627526372671, 0.014548413355701735, 0.11711453353720051, 0.0413373847092901, 0.05003693646618298, 0.08787449183208601, 0.05332699670855488, 0.06358113326132298, 0.035541837303234, 0.035621259827166796, 0.017896931086267744, 0.03760891281334417, 0.08341529539653234, 0.0344282290233033, 0.07322065957954951, 0.044981972713555606, 0.06255733926913568, 0.05595385682369981, 0.03662453831306525, 0.04571850212024791, 0.05371120359216418, 0.03343442627894027, 0.047756325985704146, 0.07629408394651753, 0.07751456488456045, 0.09582845573978764, 0.07834375503339938, 0.009643210763377803, 0.08138551217104707, 0.05380313830184085, 0.028840493144733564, 0.07967221124895982, 0.03933899051376751, 0.031162395873772245, 0.03974497837147542, 0.031848611908831766, 0.0660476962636624, 0.04616039805114269, 0.08156605676880904, 0.04913377582228609, 0.02827103771934552, 0.017221973643505147, 0.022335786738299897, 0.06420118534671408, 0.0808089134682502, 0.07840014129344906, 0.01287172787955829, 0.21270843329174177, 0.14219956605562142, 0.10411616388176169, 0.10209001760397639, 0.15532419750733034, 0.12240739166736603, 0.11725708017391817, 0.116693787542837, 0.1287441894944225, 0.18000398177121366, 0.1547829301229545, 0.07082621806434222, 0.08333150989242963, 0.23212522853698048, 0.21219476871192455, 0.1421217109475817, 0.2294779648738248, 0.22454939862447126, 0.186783442273736, 0.2664776923401015, 0.16594400336699827, 0.2756810427776405, 0.1710011384316853, 0.1820888484695128, 0.1681548333061593, 0.18907885838832172, 0.18022408496056283, 0.12459720059164933, 0.18408116299126828, 0.21246566703276976, 0.13357936218380928, 0.13136857295674936, 0.1555716185165303, 0.09479035144405705, 0.1740528903901577, 0.1408743600228003, 0.16230575287980692, 0.2469338753393718, 0.2633935606905392, 0.26253838943583624, 0.29297269348587307, 0.2131408229470253, 0.2288362064531871, 0.21037012019327708, 0.2036522435290473, 0.1952646414616278, 0.15149484441748687, 0.865993888250419, 4.515014137540545, 12.843423741204397, 28.36407698903765, 63.158117703029085, 75.58263628823417, 93.46145602634975, 87.30599825722831, 81.91309138706752, 79.67841870444161, 65.84628541128976, 48.41236925125122, 49.96694530759539, 30.208585739135742, 28.75159886905125, 21.35358084951128, 29.745022773742676, 31.801564489092144, 34.22071531840733, 38.98079415730068, 49.06427008765084, 70.47228486197335, 62.93945789337158, 65.74548789433071, 45.29741539273943, 62.83012798854283, 58.97907502310616, 57.46898133414132, 51.6037289755685, 63.34778962816511, 40.26420981543404, 17.859458582741873, 22.489588737487793, 14.082379613603864, 11.27348348072597, 11.230284793036324, 8.248602594648089, 11.417008076395307, 10.384819303240095, 8.920945031302315, 7.409866435187204, 8.944077321461268, 17.10569715499878, 15.792709963662283, 18.63719824382237, 30.305085795266287, 35.07540627888271, 35.67998988287789, 47.90947253363473, 64.23988274165562, 82.4694892338344, 99.35284055982316, 73.90001188005719, 83.0039724622454, 49.84467438289097, 54.8526406288147, 34.594101088387625, 33.809899602617534, 39.10168239048549, 27.860136304582866, 31.85108082635062, 43.8389607157026, 40.0781683240618, 52.32765483856201, 48.164516585213796, 59.27894537789481, 65.62893186296735, 77.19533402579171, 75.43646703447614, 83.31400803157261, 67.80998529706682, 61.15125560760498, 60.600965227399556, 36.389498233795166, 13.896473612104144, 3.7835086584091187, 1.0727172898394721, 0.2359217405319214, 0.2858293210821492, 0.23362150681870325, 0.20245044944541796, 0.23511232967887605, 0.3381221150713307, 0.178285863250494, 0.18876158898430212, 0.36804089535559925, 0.19322933496109077, 0.22921561609421456, 0.2267470649842705, 0.23063467709081514, 0.22777166643313, 0.16437567823699542, 0.07403170570198979, 0.12055075700793948, 0.2078711571437972, 0.22599285974034242, 0.17971103106226238, 0.20498384136174405, 0.21819053483860834, 0.10915820154228381, 0.1142705897135394, 0.25808074006012505, 0.22440708268965992, 0.1510777896536248, 0.13514590955206326, 0.16727048504565442, 0.27884670719504356, 0.137398754379579, 0.19284301783357347, 0.1314290982804128, 0.35217612236738205, 0.19749259762465954, 0.16011989302933216, 0.1429014698203121, 0.18281836860946246, 0.13909191638231277, 0.28278123321277754, 0.10487592632749251, 0.24328208129320825, 0.13383454563362257, 0.2557589289333139, 0.22839662432670593, 0.10850996311221804, 0.12290555850735732, 0.20287108687417849, 0.18358272473726953, 0.18830380854862078, 0.15185780636966228, 0.1057492144671934], [0.022097827899934988, 0.03908798683966909, 0.021595379503976022, 0.020424747141078115, 0.05092925751315696, 0.012006316683255136, 0.03270851255261472, 0.02478665522565799, 0.024946804757096937, 0.02426294663122722, 0.01642174506559968, 0.06877443673355238, 0.05726754133190427, 0.052046838615621836, 0.0392781530639955, 0.004304973059333861, 0.06743275587047849, 0.0352651137592537, 0.060204037332109044, 0.051060872950724194, 0.06422019789793662, 0.04329877160489559, 0.07193409611604043, 0.07631089125892945, 0.05954612299267735, 0.06868788280657359, 0.03624778513663581, 0.03885796686102237, 0.014580782868766358, 0.0412002765307469, 0.011406796219359552, 0.015205951108198081, 0.027327899488487413, 0.05146481841802597, 0.0027756310384055333, 0.10939302894153766, 0.07475349732807704, 0.018241438582273464, 0.00971842382568866, 0.04870887380093336, 0.038092121348849366, 0.04795899421774915, 0.0337288019114307, 0.14752403034695558, 0.04583495569282344, 0.19251604537878717, 2.425426355430058, 10.279761672019958, 22.894534962517874, 36.12259360722133, 55.79867260796683, 62.68283312661307, 63.70674746377127, 59.15881797245571, 44.96498925345284, 54.01824188232422, 33.200823988233296, 15.423149177006312, 14.46283517565046, 10.305409210068838, 28.15047720500401, 32.87177814756121, 32.543069294520784, 36.91700894492013, 57.49421719142369, 65.22716617584229, 59.276457922799246, 55.006383419036865, 47.34005376270839, 42.86207178660801, 40.977463245391846, 42.131819588797434, 31.601091589246476, 15.467134748186384, 15.60097963469369, 9.93474018573761, 2.2229109023298537, 0.9390116930007935, 0.7766465140240533, 0.09818831232509442, 0.10349469365818159, 0.09297403533543859, 0.1656255940241473, 0.43821696830647333, 0.1501316132822207, 0.18898612979267324, 0.055390408129564354, 0.1512234711221286, 0.38474393050585476, 0.3935503108160836, 0.7009106608373779, 0.79855456416096, 0.8305020555853844, 1.2386059654610497, 3.2275876317705428, 8.953580720084053, 9.792424576623098, 13.872711641447884, 14.947244473866053, 35.240516321999685, 56.16475929532732, 61.19584219796317, 72.56933457510812, 55.535610335213796, 40.46906355449131, 38.85733161653791, 27.684284346444265, 25.01240495273045, 24.349079540797643, 15.836851869310651, 17.03415502820696, 28.504465341567993, 26.7996883392334, 34.27937201091221, 31.906902653830393, 45.78321606772286, 60.55401624952044, 62.4917437689645, 68.85142993927002, 67.09207657405308, 61.39413683755057, 44.14091205596924, 26.667577028274536, 11.820032255990164, 2.672511462654386, 0.27410065329500605, 0.055496887237365754, 0.044435969154749594, 0.11675282008945942, 0.0709623796865344, 0.016792712034657598, 0.04419654468074441, 0.03684031244899545, 0.0920080728828907, 0.006405154717088277, 0.03960263190258827, 0.04147783467280013, 0.09090889365013156, 0.11290127890450613, 0.07532392136220421, 0.09165832200752837, 0.017486359724508863, 0.005003961243866277, 0.011292377403671188, 0.040986388722168546, 0.09482817298599652, 0.010885866225830146, 0.032608866292451105, 0.019549781323543618, 0.0409783786162734, 0.03288240411451884, 0.054450297861226966, 0.03687083295413426, 0.04527726097564612, 0.010866347317849951, 0.04521348546924336, 0.028303195190216814, 0.11925129459372588, 0.12176276982894965, 0.011775240734485643, 0.08887780085206032, 0.06417109910398722, 0.019701769775045768, 0.053164823446422815, 0.019116970976548534, 0.02616074801023517, 0.01482775095584137, 0.0500252283444362, 0.06955294710184846, 0.010237667659696723, 0.0216723270714283, 0.06537531555763312, 0.042752272715525966, 0.03132400595183883, 0.0752695571365101, 0.011608925864233502, 0.04832871098603521, 0.08751119739775147, 0.0606725046943341, 0.013963029320750917, 0.06414441232170377, 0.03973895298050983, 0.027693222742527723, 0.014266300547335829, 0.0293210689643664, 0.024849682647202696, 0.02623594835001443, 0.037866393104195595, 0.009775192609855106, 0.04411177530086466, 0.08068696715469871, 0.019220233828361546, 0.0721890963613987, 0.012929869848968727, 0.04285844308989389, 0.05226697912439704, 0.0643375301733613, 0.00572604251958962, 0.071011376700231, 0.0192866250872612, 0.024011601993281926, 0.07693498062768153, 0.028193922214476124, 0.03135846535276089, 0.03537704489592995, 0.028616386598774364, 0.025936012123046175, 0.04994375664474709, 0.07055612720016922, 0.06550445434238229, 0.008866732607462575, 0.05907274303691728, 0.07304926841918911, 0.04062516721231597, 0.04322970352534737, 0.07399375523839678, 0.05238775835771646, 0.09444235797439303, 0.015073965869045683, 0.06634652987122536, 0.04567953385412693, 0.2058140289570604, 2.620084047317505, 12.316061547824315, 29.921586922236852, 50.00414596285139, 71.85527515411377, 75.50232206072126, 71.82509912763322, 69.1966859272548, 55.72309010369437, 64.71393748692104, 46.492859908512656, 26.971585035324097, 25.670071056910924, 22.815513099942887, 36.196376528058735, 33.62052297592163, 32.273475715092246, 33.47164045061384, 49.95162452970232, 55.78076362609863, 43.9205082484654, 47.42779214041573, 45.51765244347708, 40.99620601109096, 41.13103927884783, 36.418395791734966, 29.03538588115147, 19.12741276196071, 14.571215782846723, 9.140515923500061, 3.2201020334448134, 1.1596532591751643, 0.7375463406954492, 0.170148138489042, 0.18710789057825292, 0.1019429654947349, 0.0738043286172407, 0.2843159708593573, 0.14061206552599156, 0.16842871718108654, 0.05713513200836522, 0.06291764814938818, 0.4108603905354227, 0.046989801938512495, 0.34524298725383623, 0.45884595279182705, 0.5904034706098693, 0.8688844474298614, 1.8335974727358137, 4.6722219075475415, 7.294164163725717, 12.546581932476588, 15.742498806544713, 31.41703380857195, 45.20455619267055, 43.78298602785383, 54.23703718185425, 37.97698443276541, 35.30850791931152, 39.36304930278233, 21.6756819656917, 25.92813410077776, 33.07513107572283, 24.669130938393728, 23.9131669316973, 37.094052519117085, 40.002769947052, 48.061742305755615, 42.391286168779644, 53.97849818638393, 70.3273593357631, 71.56727232251848, 76.95368957519531, 75.4712358202253, 70.90644305092948, 53.05180304391043, 31.498748098100933, 14.200058647564479, 3.770192435809544, 0.24490057730248996, 0.06880450262022869, 0.08184407970735005, 0.10778544377535582, 0.07622534156377826, 0.031030580268374512, 0.010600184323266149, 0.04638701517667089, 0.06423390430531331, 0.024225846032745073, 0.08688265683927707, 0.01830444734410516, 0.10952883772552013, 0.015483538087989603, 0.1273190623947552, 0.058690985664725304, 0.04412747660119619, 0.05279088279764567, 0.009103849214235587, 0.07474973824407373, 0.02241950269256319, 0.017381336074322462, 0.06802894387926374, 0.015789491224235723, 0.06873137011591877, 0.043081620042877536, 0.04136541159823537, 0.03930207820875304, 0.02921522767948253, 0.038143170930977376, 0.01696886820718646, 0.04914713617680328, 0.03551028881754194, 0.08556544394897563, 0.01021958894229361, 0.014750528581706541, 0.06137436096157346, 0.0351654132162886, 0.028505001682788134, 0.043360382584588866, 0.03205835047577109, 0.05128408043778368, 0.014536961380924498, 0.013117150603128331, 0.0537404586294932, 0.011621628887951374, 0.015776763603623425, 0.01653290945770485, 0.05492065494347896, 0.020931197197309563, 0.0069414819424439755, 0.11272466302450214, 0.1846511731190341, 0.16019112563558988, 0.10218833732817854, 0.20777629794819014, 0.08158928980784756, 0.1476141805095332, 0.10219776217958756, 0.08295714176659073, 0.06713430902787618, 0.07468521634915046, 0.2020089809915849, 0.10789352083312613, 0.14132269525102206, 0.18829954734870366, 0.06144497610096421, 0.20558237710169383, 0.1816204014633383, 0.11893280382667269, 0.15181169312979492, 0.15022439616067068, 0.24201797055346624, 0.33510754683188027, 0.12190534360706806, 0.11533545543040548, 0.20322320583675588, 0.12550551470901283, 0.0915099603257009, 0.10657323417919022, 0.14690653633858475, 0.15522811694868974, 0.11579364298709802, 0.1624083880867277, 0.2556001517389502, 0.07275541525866304, 0.17521239817142487, 0.24897211311118944, 0.19640182544078144, 0.16750326326915196, 0.11650077147143227, 0.10675343272409268, 0.1860282327979803, 0.1449981023158346, 0.2229427226952144, 0.22299107510064328, 0.45205672138503616, 4.366277090140751, 16.752577543258667, 39.08693831307547, 62.98457254682268, 87.71336419241769, 86.84749358040946, 81.04255853380475, 78.17453670501709, 62.46340901511056, 71.69366700308663, 48.94342006955828, 28.85783682550703, 26.700242246900284, 20.80997289930071, 42.424481187547954, 43.88276563371931, 45.734203474862234, 51.401459966387065, 71.82287570408413, 81.80033602033342, 76.12637451716832, 68.19312981196812, 63.31932980673653, 58.81187357221331, 56.176640714917866, 56.934609276907786, 43.18885251453945, 22.992212738309586, 21.41631613458906, 13.683999436242239, 3.5183942786284854, 1.722729953272002, 1.5338602193764277, 0.4369593715029103, 0.4584335663488933, 0.31950373841183527, 0.46710556958402905, 0.8550439072506768, 0.2729226622198309, 0.47048402258328026, 0.3388216846755573, 0.4558130641068731, 1.1147842896836144, 1.2111206288848604, 1.29043844129358, 1.6609844607966286, 1.3522301827158247, 1.8966547633920396, 5.000688007899693, 12.397166132926941, 13.01917929308755, 19.257634162902832, 21.106671401432582, 49.23604345321655, 74.35433374132428, 77.08595548357282, 90.14517116546631, 69.15330832345145, 54.78785909925188, 54.9087438583374, 39.331223079136436, 35.40183959688459, 37.37046922956194, 29.320605959211075, 30.157116958073207, 41.945121492658345, 41.87903370176043, 51.28624841145107, 48.57959849493844, 64.40252617427281, 78.85338960375104, 79.33718572344098, 86.74106802259172, 84.72930744716099, 79.3321760722569, 63.73873002188546, 41.00168466567993, 19.776424884796143, 6.303095264094217, 0.66700258318867, 0.22088554022567614, 0.16155684020902428, 0.18211772691990646, 0.2031242482896362, 0.11077287061406033, 0.15861571659999235, 0.14752287683742388, 0.13867298886179924, 0.16693701222538948, 0.17866383439728192, 0.1725760589220694, 0.2517281323671341, 0.1905346552708319, 0.1647126522979566, 0.22372687847486564, 0.14602738565632276, 0.19310639798641205, 0.14954576614711965, 0.23683380016258784, 0.16019310695784433, 0.08360250999352761, 0.15591719640152796, 0.13529833565865243, 0.14987621270120144, 0.21660835402352469, 0.1236304510384798, 0.09729218469666583, 0.19255022997302668, 0.2239871509373188, 0.13547855455960545, 0.11548834294080734, 0.2918153570166656, 0.25462170424205915, 0.12974797348890985, 0.13963262736797333, 0.3036220563309533, 0.16601880506745406, 0.14422533235379628, 0.14446036331355572, 0.19379227475396224, 0.09240801499358245, 0.13163195310958795, 0.1803672287080969, 0.16919588244387082, 0.19426634003009113, 0.07264676144612686, 0.1232695925448622, 0.07057486833738429, 0.22191319508211954, 0.09001461842230388], [0.0454094565606543, 0.05071119671421392, 0.033551951936845265, 0.015398331053022827, 0.005352314761174577, 0.010698251293173857, 0.006383274931327573, 0.050199988431164196, 0.08272546276982341, 0.04109492379107645, 0.04728305120287197, 0.056840712271098576, 0.017308027150907686, 0.03832939486684544, 0.045407872181385756, 0.00859396661897855, 0.050883524252900054, 0.03579999952177916, 0.01845462410710752, 0.05384442037237542, 0.04889204093654241, 0.1345337623996394, 0.015702480982456888, 0.035982386342116764, 0.06425033163811479, 0.07247381644057375, 0.08562527716692005, 0.027785671442481022, 0.027678612187238674, 0.02953917047541056, 0.06886238844266959, 0.042399203803922446, 0.02554075020764555, 0.03145690042791622, 0.045333732052573135, 0.01781784274083163, 0.010002423809575183, 0.07825996274394648, 0.03608621237799525, 0.026888375037482808, 0.01422857484846775, 0.0629387709445187, 0.030007186611848216, 0.0963879960722157, 0.7815927086131913, 5.692032899175372, 21.09212187358311, 40.09551797594343, 58.96522031511579, 61.129195077078684, 62.34883322034563, 51.481965269361226, 64.23815264020647, 35.14309562955584, 26.240031787327357, 19.28213003703526, 14.964370046343122, 17.259247132710048, 21.075689383915492, 27.49870491027832, 32.383684567042756, 46.602947166987825, 55.59260640825544, 50.43003232138497, 56.10159322193691, 57.026947362082346, 76.96275697435651, 50.435740266527446, 36.855909960610525, 32.54883629935128, 21.92839663369315, 12.00624224117824, 5.121821599347251, 2.507409019129617, 0.45737250042813166, 0.17636883897440775, 0.2682461445885045, 0.1357878851039069, 0.01737862702326051, 0.06647541759801762, 0.046570304448583295, 0.13516660487013205, 0.018085297496457185, 0.039501978017921956, 0.030140311789831946, 0.03427557560748287, 0.05713662478540625, 0.03518192197329231, 0.03656685944380505, 0.01176110515370965, 0.0595838495397142, 0.041876406142754216, 0.10194430220872164, 0.005016894545406103, 0.253023238586528, 0.3263727383954184, 0.5743887956653322, 1.317284760730607, 4.46527806350163, 4.704410740307399, 8.607621226991926, 20.776661498206003, 25.82663655281067, 51.821471623011995, 65.13271236419678, 47.85350479398455, 47.34478548594883, 52.903618812561035, 26.793850115367345, 15.647881712232317, 19.538558517183574, 21.67549089023045, 12.52944506917681, 11.396856563431875, 19.262027161461965, 34.07198565346854, 41.432115146092, 41.06544133595058, 38.740469864436555, 54.63275793620518, 57.41118969236101, 64.21024172646659, 61.119967869349885, 45.55450221470424, 25.54693681853158, 10.62326671395983, 1.5905933465276445, 0.05533959942736796, 0.023098304036206434, 0.04986453428864479, 0.07766362545745713, 0.019792895331712704, 0.011038584102477347, 0.04940851465133684, 0.02784793890480484, 0.01688345761171409, 0.058255210119698725, 0.02380069125709789, 0.044736441424382586, 0.05179927511406796, 0.03392932936549187, 0.005612396809738129, 0.015211796687383736, 0.03653719389278974, 0.008226918189653327, 0.006914761233409601, 0.05082282251013177, 0.04161751789173909, 0.03895252410854612, 0.029092453553208282, 0.057321796991995404, 0.03497079580223986, 0.0634927133630429, 0.03198034269735217, 0.044942834813679965, 0.008363305424739207, 0.019508913159370422, 0.02048109608170177, 0.020367056397455077, 0.04459341302780168, 0.026215967190052782, 0.0384479451126286, 0.02145401860720345, 0.04364136054313608, 0.025256025039457848, 0.04985204924430166, 0.03998509155852454, 0.018446293393416063, 0.04580669810197183, 0.03245222648339612, 0.06443907293890204, 0.03913221375218459, 0.09281507493661982, 0.058897932060062885, 0.07002863407667194, 0.02440482151827642, 0.062222231179475784, 0.06589024899793522, 0.045655557819242985, 0.04545792770971145, 0.012826556955198092, 0.011222032830119133, 0.02406560320274106, 0.03484311926045588, 0.024122622196695635, 0.005687015305738896, 0.050625436673206944, 0.05100884288549423, 0.04265495722315141, 0.06934463006577321, 0.020371266707245792, 0.06582316902599164, 0.0053301512629591995, 0.026572603499516845, 0.022859446138941815, 0.03607636344219957, 0.03506257784153734, 0.03707521448710135, 0.08780488770987306, 0.015597477688321044, 0.011545954421827835, 0.07454863403524671, 0.014355477012161697, 0.05848494850631271, 0.03929641244134732, 0.06112823595425912, 0.06917049762393747, 0.013526427659339138, 0.044094730501196215, 0.05488332533942802, 0.008920615073293447, 0.029841681742774587, 0.023617904101099287, 0.02982998379905309, 0.023327209521085024, 0.031573964682008536, 0.01518807849580688, 0.05162263548533831, 0.007512598082290164, 0.10539742120142494, 0.8186061424868447, 9.060748866626195, 28.386790650231497, 49.56956393378121, 70.33010387420654, 74.4079738344465, 67.77712726593018, 56.53336817877633, 71.071900503976, 47.8364018031529, 33.745389052799766, 31.209571020943777, 24.761717421667917, 23.93358768735613, 24.24641122136797, 22.911302702767507, 37.114768573216026, 43.623705523354666, 46.788814953395296, 47.3999958719526, 47.99397305079869, 56.488243103027344, 63.69056510925293, 44.954591274261475, 35.68952628544399, 30.896749223981583, 20.532237768173218, 12.326248475483485, 5.592400508267539, 2.3475555053779056, 0.7240307916487966, 0.3077085470514638, 0.025132336587245976, 0.050257738546601365, 0.030186241825244257, 0.040950880984642675, 0.08805205766111612, 0.06691210237996918, 0.022644660967801298, 0.029379945447934524, 0.10591928926961762, 0.012092567813981856, 0.07075724497969661, 0.017478317388200333, 0.030736662647021667, 0.04900601785629988, 0.1609709252204214, 0.13130405784717628, 0.15546704269945621, 0.07653100123362881, 0.16110138036310673, 0.2554447672196797, 0.32939816319516724, 0.9400325353656496, 2.905216621501105, 4.261006670338767, 7.051227782453809, 16.572780745370046, 20.706194605146134, 36.316875662122456, 44.09019715445382, 41.31965855189732, 37.48214067731585, 42.217640263693674, 34.34462949207851, 23.270856346402848, 27.263341631208146, 32.70118597575596, 19.998907940728323, 18.52214128630502, 23.670843294688634, 41.968873909541536, 51.85101536342076, 53.479329177311485, 48.51758234841483, 63.29539326259068, 66.0452470779419, 72.8055385862078, 68.65862437656948, 53.67189850125994, 30.757333619253977, 11.876369987215314, 1.9537563621997833, 0.019925325011302317, 0.09682808709996087, 0.060800605320504734, 0.025392766809090972, 0.09294804744422436, 0.011581806515875672, 0.036989607116473575, 0.011352336998762829, 0.03134912871090429, 0.03441883470597012, 0.027424263335498314, 0.037681003766400475, 0.03447128885558673, 0.0077538317002888235, 0.04630996413262827, 0.06061211507767439, 0.054934483487159014, 0.057758637837001255, 0.04833822065432157, 0.01097685013831194, 0.03439895702259881, 0.0221138379337, 0.01673836137966386, 0.046806448205773316, 0.03087051385747535, 0.02285146656712251, 0.0059196586704014665, 0.03813172404521278, 0.035326090308704546, 0.0485101003598954, 0.006830389220600149, 0.0633586212726576, 0.0479589195788971, 0.029176191559859684, 0.0348671054733651, 0.010228237719275057, 0.014281844088275517, 0.02286648763609784, 0.05864988001329558, 0.07403279135801963, 0.039030229938881736, 0.023747078508936932, 0.027452641366315738, 0.06233450158366135, 0.02979909009965403, 0.028861653259290115, 0.02910717437043786, 0.04900631980438318, 0.056388719739126306, 0.10467095446905919, 0.12372339676533427, 0.09889726606862885, 0.18111535427825792, 0.10397680635963168, 0.08909312036952802, 0.11180888502193348, 0.13477105966636113, 0.14899148446108612, 0.1376949484859194, 0.14980271378798143, 0.17919938851680073, 0.06711967302752392, 0.15038777382246085, 0.16615531274250575, 0.08414620653327022, 0.08904580612267766, 0.10146812668868474, 0.08665643326405968, 0.11484836228191853, 0.14641907678118773, 0.15156348501997335, 0.1331952977925539, 0.1257753273738282, 0.10574089562786476, 0.16910157964697906, 0.13693249225616455, 0.2465900480747223, 0.15987947450152465, 0.23559142968484334, 0.16445256982530865, 0.0664306478574872, 0.15848211305482046, 0.25452461945159094, 0.07405183105064289, 0.18939257226884365, 0.13536955469420978, 0.12032863178423472, 0.09266089142433234, 0.21935031403388294, 0.09697977360337973, 0.14719616222594464, 0.12530481762119702, 0.3035458432776587, 2.1909626509462083, 12.83234657560076, 36.39257628577096, 59.5441928591047, 82.84715162004743, 85.45787470681327, 80.57115800040108, 65.54840918949672, 78.19093445369175, 53.68590259552002, 37.68200213568551, 31.95075273513794, 26.135437079838344, 28.399427686418804, 32.97483382906233, 39.337268011910574, 44.77366713115147, 63.564503942217144, 72.95921884264264, 65.56234727587018, 70.82912349700928, 68.30066013336182, 89.94406945364815, 65.37949848175049, 48.663841928754536, 42.24330343518938, 29.95078672681536, 16.0411045891898, 7.353146553039551, 3.575196019240788, 0.8634694665670395, 0.6804937592574528, 0.523403457232884, 0.33946192317775314, 0.12584489078394004, 0.1647954878530332, 0.24807622975536756, 0.16949712485074997, 0.10597091899918658, 0.12028026580810547, 0.2157158362013953, 0.172363406047225, 0.16493918799928256, 0.08046106927629028, 0.18523702025413513, 0.16886888284768375, 0.27052585940275875, 0.2954041558716978, 0.2790237234107086, 0.17834504507482052, 0.7915184274315834, 0.7131716800587518, 1.2470847219228745, 1.9543903853212083, 6.494467760835375, 6.594184398651123, 11.323168311800275, 26.069498675210134, 33.21568271092006, 64.84223597390312, 78.58608545575822, 65.12654931204659, 67.21120343889508, 71.43363067081997, 40.12965447562081, 28.558536223002843, 32.511840615953716, 34.78032670702253, 20.063498394829885, 20.889119829450333, 30.40605354309082, 49.15341894967215, 57.99043321609497, 58.34000750950405, 55.36398983001709, 70.5106041772025, 74.43441867828369, 82.22767802647182, 79.64849281311035, 63.80735043116978, 39.070450237819124, 16.15033027103969, 3.5680180958339145, 0.24605772378189222, 0.33800850116780823, 0.17216863935547216, 0.1977971512824297, 0.19591963131512913, 0.19479476953191416, 0.12470829034490244, 0.1378656407552106, 0.14522400019424303, 0.11266857531986066, 0.13080162980726787, 0.18867279589176178, 0.20833340233990125, 0.15563172314848217, 0.19115087363336766, 0.12469277903437614, 0.1774383865829025, 0.18893937872988836, 0.1168237677110093, 0.16558816603251866, 0.07319849184049027, 0.1339553112962416, 0.08584640494414739, 0.1278213547276599, 0.08777826199574129, 0.14974627324513026, 0.1143225926373686, 0.07628333595182214, 0.08279815422637121, 0.1289136739713805, 0.0640543367979782, 0.11764370942754404, 0.06855437425630433, 0.08698592986911535, 0.16688690919961247, 0.13223628353859695, 0.12334041803010873, 0.10114165634981223, 0.17425361461937428, 0.1127186104921358, 0.10110592469573021, 0.11581949517130852, 0.13744611612388066, 0.12451634635882718, 0.14829374690140995, 0.1857793732945408, 0.19693416330431188, 0.11530475850616183, 0.18143559566565923], [0.06194469000079802, 0.026773546556276933, 0.057806081005505154, 0.034977082429187636, 0.0185500702355057, 0.023933561984449625, 0.002030158964251833, 0.014767627664176481, 0.023757563571312597, 0.03227725944348744, 0.03749836928078106, 0.04143764165097049, 0.05402262741699815, 0.05687497489686523, 0.026042445429733822, 0.027551970411358134, 0.02424190695663648, 0.02765305177308619, 0.03911111131310463, 0.09120348641382796, 0.03594281417982919, 0.010594835770981652, 0.046450410703463216, 0.027148632232898047, 0.03308060758614114, 0.009888798879858638, 0.05749398882367781, 0.05170987473268594, 0.014931417535990477, 0.03372931420536978, 0.04775588833061712, 0.036623686751616855, 0.0929177033581904, 0.02676500380039215, 0.04439904327903475, 0.007685850124939212, 0.026705877955204675, 0.0314714685747666, 0.03038136474788189, 0.07798179052770138, 0.043701848547373495, 0.29856336063572336, 1.3999849345002855, 5.5482412321226935, 21.402720246996196, 43.61504111971174, 59.26563262939453, 64.79004805428642, 62.26212665012905, 53.33670003073556, 41.10532052176339, 50.750191416059224, 82.84089129311698, 33.2908170563834, 16.896156855991908, 14.612989221300397, 20.25777350153242, 31.10607065473284, 42.09722450801304, 57.56512008394514, 52.681134019579204, 57.720294203077046, 52.675794328962056, 52.85523155757359, 45.1992894581386, 30.242822987692698, 24.826604911259242, 22.29999324253627, 9.703416415623256, 4.207975847380502, 1.3785901282514845, 0.39079928557787624, 0.04688861540385655, 0.03820160297410829, 0.00572591444610485, 0.07589246585432972, 0.017459459203694547, 0.033499837054737976, 0.022678070335782, 0.03198608988896012, 0.055346781720540354, 0.03849263342895678, 0.06878688106579439, 0.03354839641334755, 0.03389547046806131, 0.04496426634224398, 0.09114047765199627, 0.08079546490418059, 0.1486300831394536, 0.06404732753123556, 0.08610064523028475, 0.0314611785912088, 0.05761748219707182, 0.055830448267183135, 0.05194859013759664, 0.01393392525746354, 0.031562402445290766, 0.05282931162842682, 0.03138593923566597, 0.2626720336931092, 0.9016264219369207, 0.44512575758355005, 2.1162662591253008, 3.3616998067923953, 10.468896848814827, 17.66444522993905, 25.987575939723424, 37.16126591818673, 55.04253142220633, 45.539257866995676, 37.434760911124094, 33.613915239061626, 39.80930083138602, 30.13267319543021, 31.77840961728777, 37.54338904789516, 39.65760428564889, 54.634314332689556, 64.0006354195731, 53.85906907490322, 45.419939926692415, 50.69713844571795, 55.41415582384382, 67.12931197030204, 59.64587279728481, 42.66695247377668, 20.994779348373413, 8.58297336101532, 1.29896214391504, 0.061085895369095464, 0.060424038741205416, 0.022952066168987324, 0.05645264113055808, 0.020756233550075973, 0.02796818209545953, 0.046415964873241525, 0.05295304588175245, 0.019792036984914115, 0.04284965606140239, 0.03529678098857403, 0.021024010609835386, 0.04454870096274784, 0.07896172401628324, 0.022446491422929933, 0.035820511635392904, 0.04794051431651626, 0.059177461346345286, 0.03157169837504625, 0.01844768439020429, 0.023460623076451675, 0.05341156931327922, 0.0380315553130848, 0.018880304747394154, 0.01248413256169962, 0.013624531948672873, 0.05177884103198137, 0.04757911978023393, 0.039732191379048994, 0.024966953854475702, 0.03021796333736607, 0.044240951405039856, 0.06541752043579306, 0.048089303475405486, 0.02616020178954516, 0.03449432172679475, 0.058727653697133064, 0.023948635639888898, 0.06383348722010851, 0.028392434419531907, 0.05276935288150396, 0.015266883552872708, 0.02030398147845907, 0.04353758879005909, 0.046969842830938954, 0.04817604060683932, 0.028977010997810533, 0.05919479113072157, 0.029833308620644466, 0.035694219305046966, 0.0053160466403434315, 0.08682234186146941, 0.022185226603012, 0.034158474033964534, 0.006948435230047575, 0.04374595332358565, 0.024156499753839204, 0.0193557287898979, 0.050091504252382686, 0.0811933239123651, 0.036197281775197813, 0.02710633066349796, 0.058593629460249624, 0.04124818110306348, 0.0250888967753521, 0.003556597067342539, 0.0284095572507275, 0.048913072129445415, 0.010774934231968862, 0.03605603114036577, 0.026499141905722872, 0.039349399240953584, 0.04104869520025594, 0.04329551463680608, 0.03224256594798394, 0.052626100568366904, 0.02357261867395469, 0.014780808206913727, 0.01755219797736832, 0.05606479051389864, 0.03753758181950875, 0.010585242133986737, 0.0029913926638463245, 0.05058507401762264, 0.05283268055479441, 0.09712968234504972, 0.12740226435874188, 0.03205075766891241, 0.17852207486118588, 1.8507147942270552, 7.7159232922962735, 28.3486294065203, 56.22510092599051, 69.56897735595703, 74.01000881195068, 69.33910315377372, 60.01282800946917, 52.008840220315115, 62.5579114641462, 84.91599859510148, 35.199681758880615, 21.42449242728097, 20.29085734912327, 24.713536875588552, 35.48901169640677, 37.58042642048427, 52.27024187360491, 43.757934297834126, 48.2053233555385, 47.26676068987165, 45.65487241744995, 38.484116077423096, 26.688152381352015, 24.719251768929617, 18.506632907049998, 10.141648854528155, 5.227645703724452, 2.2504309798989977, 0.598905188696725, 0.03912601872746434, 0.03163061896339059, 0.05333856573062284, 0.04169620759785175, 0.07234170567244291, 0.010510484538307148, 0.12802388386002608, 0.1867028187428202, 0.26003752648830414, 0.05002612401066082, 0.06917941357408251, 0.0465859141466873, 0.031825674032526355, 0.009020654035599103, 0.07036970648914576, 0.08600266477359192, 0.04444263576130782, 0.1121694924575942, 0.04223975146721516, 0.24084964181695664, 0.12634646386972495, 0.14477485072399887, 0.14545847475528717, 0.07456879331065075, 0.08048975773687873, 0.021693259876753603, 0.061283186211117675, 0.07995608315936156, 0.5626950317195484, 0.3462745233305863, 1.4766289932387215, 3.1488541194370816, 9.133193390710012, 14.92210589136396, 22.513007640838623, 35.68394340787615, 39.881760120391846, 35.65400014604841, 31.078885827745708, 30.894244398389542, 30.415159157344274, 24.782680136816843, 31.37270082746233, 45.582774434770855, 48.37310150691441, 51.352169445582796, 60.16003949301583, 58.216718673706055, 54.50557810919625, 59.15522575378418, 64.66751657213483, 74.86795847756522, 71.21547807965959, 50.81516054698399, 24.58106425830296, 10.403503877776009, 1.670380813734872, 0.11576750581817967, 0.11330892238765955, 0.03161653936175363, 0.03869548147278173, 0.055369736560221226, 0.03973942456234779, 0.07166379490601164, 0.06032119318842888, 0.01849145838059485, 0.057340992747672966, 0.044818859680422714, 0.030464064595954757, 0.04287334032622831, 0.04794923349150589, 0.00686607210497771, 0.1112489104270935, 0.08595186285674572, 0.10853899084031582, 0.06045916649912085, 0.06468304699020726, 0.03867438921172704, 0.027101474049101983, 0.015612931323370762, 0.02513620593318982, 0.02768312274877514, 0.05156767414882779, 0.056265738659671376, 0.023122856825856224, 0.0037212828174233437, 0.021974853605830243, 0.03905880304851702, 0.0322144271007606, 0.044235183857381344, 0.03533314707289849, 0.041354232733803134, 0.07757132433887039, 0.014660819466891033, 0.021540652262046933, 0.026598162217331783, 0.014554009573268039, 0.037146749041442356, 0.017227654677948782, 0.009136189041393144, 0.03523914961676512, 0.01811030151189438, 0.04151412611827254, 0.05849582542266164, 0.26730336089219364, 0.23518534004688263, 0.14438861502068384, 0.2814666394676481, 0.14736233545201166, 0.17561623507312366, 0.10298265756240912, 0.12118146887847356, 0.12811763025820255, 0.14133978076279163, 0.13456209802201816, 0.1438094446701663, 0.19805233473224299, 0.12209445131676537, 0.09507445405636515, 0.07985403827790703, 0.16448911572141306, 0.18545622777725967, 0.12427090667188168, 0.23057678448302404, 0.12375220736222607, 0.07861356769821473, 0.15441093008433068, 0.14417095455740178, 0.12085012665816716, 0.12109433141137872, 0.13139358375753674, 0.20972885031785282, 0.14686633992408002, 0.06414016469248704, 0.1398123170116118, 0.06339917731072221, 0.19540071487426758, 0.1414524582879884, 0.09629483999950544, 0.10008156751947743, 0.08169737365096807, 0.08914542184876544, 0.22669382712670735, 0.2428581868963582, 0.19209557079843112, 0.4822004224572863, 2.6791687054293494, 12.313554985182625, 36.7169633592878, 67.13020133972168, 80.53311661311558, 81.98729119982038, 79.94735567910331, 69.50777762276786, 60.61707809993199, 67.94700377328056, 90.51088265010289, 44.23277766363961, 26.485297986439296, 23.42682777132307, 30.94088418143136, 45.21636118207659, 56.254474435533794, 75.5884449822562, 68.00261715480259, 72.72709342411586, 68.91739613669259, 69.24629606519426, 59.352116857256206, 41.11707339968, 31.42862340382167, 28.490412609917776, 14.463351079395839, 6.323741836207254, 2.835251518658229, 1.1193175550018037, 0.2422387387071337, 0.11494764552584716, 0.10162845772824117, 0.18905338618372167, 0.2411576152912208, 0.09351258857973985, 0.26117442548274994, 0.2401015976709979, 0.1620837633631059, 0.16442221216857433, 0.1736034695059061, 0.21438924595713615, 0.11845166821564947, 0.15938828300152505, 0.20045713069183485, 0.22450842868004525, 0.3117274285427162, 0.26011238247156143, 0.10582673709307398, 0.22416715270706586, 0.2604494243860245, 0.1824731028505734, 0.36438505724072456, 0.16074662868465694, 0.22938440846545355, 0.11153260591839041, 0.143545928810324, 0.6390301670346941, 1.6522365702050072, 0.8339322400944573, 2.9616779003824507, 4.873535105160304, 14.360144274575369, 24.12533712387085, 33.987311431339805, 50.63412523269653, 70.07397937774658, 60.306722913469585, 51.91675227028983, 47.314369746616904, 52.2260548046657, 42.27552570615496, 45.53054135186331, 50.229590688432964, 51.29458972385952, 65.27628993988037, 74.40362426212856, 67.5535203388759, 63.41540949685233, 67.90981006622314, 73.87219129289899, 84.00465202331543, 79.72596522739956, 60.04676301138741, 33.23103475570679, 14.337386318615504, 3.0598066576889584, 0.43325638877493994, 0.2678527571260929, 0.2730101118130343, 0.15051133504935674, 0.12030320029173579, 0.09961899662656443, 0.24394921692354338, 0.19155078860265867, 0.1721383902643408, 0.10593628657183476, 0.166176279474582, 0.12756862757461412, 0.1355127798659461, 0.19402311236730643, 0.09419720327215535, 0.1970168495816844, 0.14116010468985352, 0.1832694722605603, 0.11753560522837297, 0.13260642439126968, 0.13736698537000588, 0.14384878613054752, 0.2254006208053657, 0.10776862289224352, 0.169200618618301, 0.1345061460243804, 0.07938095687755517, 0.2030652700258153, 0.12230242229998112, 0.1517005083816392, 0.12930449657142162, 0.14402105260108197, 0.19789389680538857, 0.09403314028999635, 0.14936258883348533, 0.12768572914813245, 0.16688114165195397, 0.21167822714362824, 0.08204781663204942, 0.1729033842150654, 0.10926108102181128, 0.16748764339302266, 0.09297195223293134, 0.15032617641346796, 0.15847504271992616, 0.11834372686488287, 0.11222284566611052], [0.03990685986354947, 0.0425385918601283, 0.06108827024166073, 0.019440795028848306, 0.08979779934244496, 0.08299311090792928, 0.021874566130074005, 0.019904972353417958, 0.043574172005589516, 0.04418864653312734, 0.05053759352969272, 0.03422540472820401, 0.03956529890586223, 0.03381531512630837, 0.06963402525122676, 0.01717373150001679, 0.041366001923701594, 0.013472857319616845, 0.04524514591321349, 0.021235340341393436, 0.11896374502352305, 0.03431497474334069, 0.05458526186911123, 0.01906910372365798, 0.04284404457679816, 0.013619396286750478, 0.03861079351710422, 0.04040334054401942, 0.020177505943658094, 0.07048914222312824, 0.0768828827089497, 0.023131869467241422, 0.0317210778594017, 0.023827074394960488, 0.008540446321213884, 0.04724898195958563, 0.026863248885742257, 0.08667692502162286, 0.08756151755473443, 0.08960127524499382, 1.6913181245326996, 4.9398239595549445, 18.906432253973826, 49.541329928806846, 65.15587765829903, 63.60187830243792, 58.54908575330462, 53.13177333559309, 44.61861113139561, 38.00951937266758, 23.062900236674718, 15.604288714272634, 47.07711655752999, 68.46743079594204, 26.903306824820383, 31.629732063838414, 48.89550529207502, 54.53165469850813, 53.966547284807476, 38.85913814817156, 46.23744412830898, 38.43035091672625, 26.900253091539653, 19.730947187968663, 10.408860938889639, 5.67930770771844, 2.2348598497254506, 1.2101769766637256, 0.7506606855562755, 0.32706674401249203, 0.1184385996311903, 0.050607621736292324, 0.07262297200837306, 0.07760162092745304, 0.05895103421062231, 0.14797697961330414, 0.07156184501945972, 0.12765500508248806, 0.04060962536771383, 0.12785861987088407, 0.08022392807262284, 0.11143166704901628, 0.07643199618905783, 0.03046905522101692, 0.01768699404783547, 0.1540942985032286, 0.035361933921064646, 0.1075461855424302, 0.08033325363482748, 0.07163462468555995, 0.3355325540261609, 0.31524004148585455, 0.0535013937790479, 0.1115606769121119, 0.08807182338620935, 0.08793405363602297, 0.13013861966984613, 0.20339646296841757, 0.2480558194220066, 0.12242822269243853, 0.10186941908406359, 0.04609818656795791, 0.11301154763038669, 0.3871957760836397, 0.535563619009086, 1.3144104863916124, 3.341468172413962, 6.18468666928155, 24.286736828940256, 44.02677399771554, 50.51636021477835, 51.219545704977854, 47.42652062007359, 32.5076265335083, 24.474855831691197, 21.001649379730225, 25.937079906463623, 58.297435896737234, 64.9152615410941, 50.78645406450544, 29.557862622397288, 42.015961851392476, 52.96531186785017, 56.80957644326346, 56.3190336227417, 63.896655627659385, 54.43358434949602, 39.31127827508109, 16.7328359740121, 11.928975667272296, 2.7796715753419057, 0.6555036945002419, 0.03027613753718989, 0.07891938343111958, 0.01626260655133852, 0.016245539699281965, 0.02471260161006025, 0.051842792957488976, 0.0182453622110188, 0.0244699693617544, 0.07290264378700938, 0.03132890497467347, 0.031861500681510994, 0.03536755897636924, 0.04026565561071038, 0.03149959724396467, 0.07328358691717897, 0.04964272119104862, 0.000971953386657073, 0.011009660699138684, 0.0638022203264492, 0.045827987138181925, 0.030004160345665047, 0.02298731097419347, 0.0325358253903687, 0.041465692288641415, 0.04010788604084935, 0.054104238216366084, 0.0301335060835949, 0.025802539195865393, 0.0276321630725371, 0.05421121944008129, 0.10091215545045477, 0.04144910889278565, 0.018539900691913705, 0.0663719613637243, 0.020841725569750582, 0.03801260722268905, 0.047625243198126554, 0.0396019092627934, 0.020951426022553017, 0.06028502727193492, 0.020826039536456977, 0.061099031807056496, 0.04419746409569468, 0.05156242228778345, 0.06593932065048388, 0.020313391062830175, 0.018479958908366304, 0.0353673825572644, 0.04191774928144046, 0.04040039570203849, 0.017027593716712933, 0.04532900605616825, 0.04935192822345665, 0.006907355871849826, 0.0332867125980556, 0.020776691380888224, 0.05194872245192528, 0.02122770682243364, 0.07597146090120077, 0.028854905228529657, 0.05375494874481644, 0.024821484428165213, 0.023590971349871585, 0.030215330621493713, 0.05106116132810712, 0.04201452533847519, 0.06416208137358938, 0.01800523714960686, 0.044787060136773756, 0.03605616345469441, 0.062079677757407935, 0.04313515984852399, 0.053485380352607796, 0.0549903167411685, 0.02114408925574805, 0.029726893973669836, 0.005471103342383036, 0.04372873889016254, 0.06133662084383624, 0.0425149958048548, 0.08292344571756464, 0.07698157562741212, 0.08919952144580227, 0.10354367031582765, 1.4776371334280287, 6.487551697662898, 25.456822156906128, 60.467274938310894, 75.02618980407715, 70.97584165845598, 67.74005167824882, 59.331765583583284, 54.12850979396275, 49.102846486227854, 32.122852666037424, 28.925729410988943, 59.37212072099958, 66.2569169998169, 23.41981530189514, 24.342061860220774, 39.75543144771031, 45.7885696547372, 45.72205802372524, 36.566291672842844, 39.44012219565255, 32.72962842668806, 24.600646018981934, 18.208859171186173, 11.19270806653159, 6.229593745299748, 2.803737095424107, 1.8584133982658386, 0.6073209228260177, 0.2247014990342515, 0.017777266346716454, 0.007098063227853605, 0.0697089626586863, 0.06003766054553645, 0.032840840451951535, 0.07617555744946003, 0.19724208249577455, 0.3089481491063322, 0.1613588844026838, 0.47183300448315485, 0.34938112805996624, 0.08695654251745769, 0.11309185224984374, 0.06016441767237016, 0.04204053019306489, 0.044617884393249235, 0.37323119970304625, 0.13565413228103093, 0.17771634166794165, 0.1454296370169946, 0.778128597353186, 0.34727566103850094, 0.46780565487486975, 0.061886749895555634, 0.21435781621507236, 0.11975985659020287, 0.395249606775386, 0.17573276667722634, 0.25093530490994453, 0.044219882892710824, 0.03948210372722574, 0.18031871345426354, 0.04753174785790699, 0.4088783897459507, 0.390809355037553, 1.1940393511738097, 2.767170246158327, 5.681984935488019, 18.419830799102783, 31.702392850603374, 41.13304730824062, 42.642661571502686, 41.3428064755031, 34.36037758418492, 30.51421615055629, 30.102931431361608, 30.519830295017787, 64.54650674547467, 77.71241201673234, 65.46496132441929, 38.039962904793875, 49.01622676849365, 59.881993430001394, 64.62046337127686, 63.52290507725307, 73.32081004551479, 64.30506379263741, 48.106822218213765, 19.723764487675258, 13.840650047574725, 3.2823301000254492, 0.5930453602756772, 0.043443574370550256, 0.03977554976674063, 0.10148131062409707, 0.02498205634765327, 0.08378723436700446, 0.04875789117068052, 0.06797033202435289, 0.09586625692567655, 0.05090988873104964, 0.0518750131928495, 0.040920950804970095, 0.051521435379981995, 0.004384405761291938, 0.03431213507428765, 0.03600026234718306, 0.04638691678909319, 0.07232401626450674, 0.018070551234164407, 0.034949320168899636, 0.038716692477464676, 0.05021613077925784, 0.030833832254367213, 0.035507591640842814, 0.045503694896719286, 0.06356240569480828, 0.02708620870751994, 0.06126470970255988, 0.04019010073638388, 0.009249892002636833, 0.015984659947987114, 0.0439806755499116, 0.03542355168610811, 0.01743491828840758, 0.03823814887021269, 0.053780468446867805, 0.04043308073388679, 0.045923395947154076, 0.03807134460657835, 0.0488303960300982, 0.0845978462270328, 0.06170510607106345, 0.0025694755604490638, 0.039054192403065305, 0.06268527026155166, 0.22102495203060762, 0.13646886284862245, 0.12312872867499079, 0.2086060784224953, 0.13744018572781766, 0.12511731125414371, 0.13677001026059898, 0.1691096406430006, 0.15714419127574988, 0.10158758956406798, 0.12130623789770262, 0.15301094949245453, 0.15049800862159046, 0.1350400580891541, 0.23137626158339636, 0.14382488812719071, 0.1325197076158864, 0.095874969315316, 0.10923597522612129, 0.12668955831655435, 0.21448116031076225, 0.1468782549990075, 0.2036472630820104, 0.12909613203789505, 0.12971986856843742, 0.16377635539642402, 0.15148013377828257, 0.11543897273285048, 0.1229060741939715, 0.1696692556142807, 0.10041057557931968, 0.13915620078997953, 0.1402154482368912, 0.17868986300059728, 0.10416025508727346, 0.16289822251668998, 0.11391849789236273, 0.20537125771599157, 0.23506010962384088, 0.2516924414251532, 1.9903145262173243, 8.839579020227704, 35.02042865753174, 72.61249678475517, 85.24586432320731, 79.41312953404018, 75.7061961037772, 70.2539655140468, 61.130959919520784, 53.90369388035366, 38.15803016935076, 26.160698992865427, 53.708477292742046, 77.47932079860142, 36.613310132707866, 43.929488795144216, 61.24450043269566, 68.00798116411481, 67.66534464699882, 51.109388964516775, 58.30887263161795, 48.80076660428728, 34.42336995261056, 25.51052130971636, 14.44048890045711, 7.76671028137207, 4.027694846902575, 2.0039182305336, 1.0956903142588479, 0.6508056808795247, 0.2664890917284148, 0.13530322111078671, 0.17806269308286055, 0.2847146780363151, 0.19770852103829384, 0.3064604768795626, 0.40546180307865143, 0.3909390637917178, 0.1459472778120211, 0.3832599472786699, 0.2843179793230125, 0.30484572638358387, 0.207050726882049, 0.19156251368778093, 0.1717089997338397, 0.34492714277335573, 0.5412493624857494, 0.3610096440783569, 0.39055205455848147, 0.2708531032715525, 0.8133519472820419, 0.6352243455392974, 0.6751818071518625, 0.5607672323073659, 0.24017523229122162, 0.3797274939715862, 0.3841388944004263, 0.524325070636613, 0.706897782427924, 0.15970415462340626, 0.1325558056788785, 0.41656659862824846, 0.2214384784123727, 0.9886519036122731, 0.7500654203551156, 2.067174630505698, 4.853114349501474, 8.94230031967163, 31.478476728711808, 55.94337231772286, 67.04614203316825, 67.62750475747245, 62.47688157217843, 46.342448779514854, 36.11756311144148, 30.217437744140625, 33.96074846812657, 65.11073521205357, 71.8735350200108, 63.66247354234968, 44.79276425497872, 58.668150084359304, 71.49348245348249, 74.86456080845424, 73.58008902413505, 84.23998750959123, 74.82859693254743, 57.93454190662929, 28.15601318223136, 18.611540283475602, 5.215676128864288, 1.3107896064008986, 0.20793823711574078, 0.13232570088335446, 0.1628398820757866, 0.15127837817583764, 0.1612468854125057, 0.12493246474436351, 0.12609099543520383, 0.16172016358801297, 0.1922991041626249, 0.17092613317072392, 0.17804693749972753, 0.14993443100580148, 0.21573330169277533, 0.095485388434359, 0.17036448259438786, 0.16467105810131344, 0.1364212432610137, 0.093948676250875, 0.19632858437086853, 0.1535010010536228, 0.1319266680095877, 0.13298343201833113, 0.08632053807377815, 0.15731619990297727, 0.10189338494092226, 0.1579763059105192, 0.1446587805237089, 0.14108292811683246, 0.10054861674351351, 0.1455074107008321, 0.13297888583370618, 0.11920098800744329, 0.11084996576287917, 0.190092426857778, 0.08536033638353858, 0.13387421279081277, 0.10453658417931624, 0.12694001916263783, 0.10049829658653055, 0.13090715557336807, 0.14916271955839225, 0.10655475088528224, 0.11025727220943995, 0.15089180320501328], [0.030487236566841602, 0.06417156729315009, 0.02345730334387294, 0.05429731535592249, 0.03614365036732384, 0.049544784839132, 0.03219749765204532, 0.1030788059745516, 0.05919403117150068, 0.07260393231574978, 0.015731881904814924, 0.03133495072168963, 0.0069233294343575835, 0.10286970183785472, 0.039172013223703415, 0.10094350376831633, 0.04778769465961626, 0.056341819398637326, 0.013274235700789307, 0.048384547632719786, 0.04995788035116025, 0.03328373722199883, 0.019501581588493924, 0.045342074640627415, 0.07440157514065504, 0.003967143196080412, 0.01862195084270622, 0.04346126377848642, 0.09457948990166187, 0.04880952090024948, 0.022391011007130146, 0.10849198871957404, 0.0399051906674036, 0.04347724327817559, 0.02898228321490543, 0.06453456995742661, 0.06864166100110326, 0.018184870814106295, 0.5058539903589657, 2.106600446360452, 11.243144171578543, 40.19404690606253, 61.73400797162737, 61.488416944231304, 60.66046265193394, 57.04494667053223, 54.09835461207798, 40.05687209538051, 32.84147357940674, 22.871958528246196, 15.607100997652326, 15.63406000818525, 18.132720811026438, 29.496853964669363, 40.25367634637015, 43.56992299216134, 61.57763181413923, 47.22265699931553, 32.58438328334263, 21.00058283124651, 10.743862254279, 4.657847821712494, 2.1133875335965837, 0.9840324372053146, 0.3612132045839514, 0.1425312611141375, 0.06124478791441236, 0.057517221862716336, 0.12422891892492771, 0.07636761000113827, 0.041995807949985774, 0.11336638751838889, 0.040355887197490246, 0.0717380198517016, 0.0604801739432982, 0.025913696802620376, 0.09527660320912089, 0.12915638594755105, 0.34248501381703783, 0.8383308297821453, 0.7673417361719268, 0.0970259275553482, 0.10856764537415334, 0.03872665337153843, 0.035535313189029694, 0.04795919099290456, 0.22028465675456183, 0.11243151554039546, 0.0700413091108203, 0.10844658794147627, 0.26887615078261917, 0.8624066093138286, 0.39987669991595404, 0.19359220191836357, 0.11585973229791437, 0.04243891845856394, 0.15989267879298755, 0.0392208168549197, 0.0644357277612601, 0.14550593149449143, 0.23330381672297204, 0.10782494808414153, 0.10316113262836422, 0.04480777920356818, 0.0749301810615829, 0.01565586223400065, 0.046295959169843366, 0.2859076240233013, 0.31253852216260775, 2.8801698854991367, 4.967386594840458, 15.608615704945155, 28.73260075705392, 42.7274990762983, 39.16819749559675, 43.47486121313912, 57.784495558057515, 22.529075350080216, 15.811864410127912, 13.984603694507054, 15.949869530541555, 25.74516371318272, 33.9816312789917, 38.452248164585654, 49.81739228112357, 52.52422285079956, 61.95147269112723, 57.662922927311485, 55.07907199859619, 52.65608923775809, 32.24006530216762, 11.781176192419869, 1.379621827176639, 0.16390914469957352, 0.026553541754505465, 0.09395839287234203, 0.017994606202202182, 0.04465087137318083, 0.036766175712857924, 0.04303001406203423, 0.022504007443785667, 0.07645703413124595, 0.05369655741378665, 0.013748335751837917, 0.03877291928178497, 0.019671593626428927, 0.03600450319104961, 0.0562236050276884, 0.01707737274201853, 0.013578781725040503, 0.010598581284284592, 0.044664336900625906, 0.017926408343815377, 0.003830533316691539, 0.02725667366757989, 0.049710279530180354, 0.05541658601058381, 0.061748444102704525, 0.037563237228563855, 0.04050314286723733, 0.047494835552892516, 0.048210215023053546, 0.03701110989121454, 0.045684853568673134, 0.058856324292719364, 0.0044882474882927325, 0.029155594629368613, 0.14117747518633092, 0.0353893704845437, 0.034767184406518936, 0.05421049001493624, 0.06517068975205932, 0.005767681669177753, 0.02437668776006571, 0.03962069111210959, 0.03119683831131884, 0.06640889402478933, 0.10511117441845791, 0.03067495667242578, 0.10633415915071964, 0.0328551677188703, 0.04318067258489983, 0.039479715283960104, 0.11283794444586549, 0.045057870248066526, 0.034008307448987446, 0.018374249937811067, 0.038861844688653946, 0.05352923407086304, 0.06744949532938854, 0.012685079859303576, 0.028311413945630193, 0.0319525634736887, 0.0050529374774279335, 0.05743288674524852, 0.08759644175214426, 0.011103613202327063, 0.057717158991311274, 0.03612970647269061, 0.036058955626296144, 0.01932864506462855, 0.02865560253017715, 0.08396003009485346, 0.025357086045135344, 0.03235056836690221, 0.036117099292044125, 0.03733035043946334, 0.0313904413155147, 0.03199886331068618, 0.02515191910788417, 0.018908162002584765, 0.04649050873039024, 0.039120139221527746, 0.060151098029954095, 0.5313882402011326, 2.7739751381533484, 16.35841839654105, 48.16130999156407, 72.04160499572754, 69.81916114262172, 69.55453899928501, 66.61117785317558, 60.938543455941335, 50.57164008276803, 44.78136226109096, 32.808764934539795, 28.84954415048872, 23.627394471849712, 28.172615902764456, 42.37930747440883, 40.729200635637554, 39.966635840279714, 49.93032135282244, 38.764361245291575, 27.087625162942068, 18.239639690944127, 9.481474450656346, 4.522552064486912, 2.304875109876905, 1.0244945117405482, 0.3946181078042303, 0.22479980518775328, 0.09351910251591887, 0.02688264989826296, 0.052306517359933684, 0.09249100661171333, 0.04455924200426255, 0.12635114576135362, 0.05713129150015967, 0.07722611286278282, 0.11896052876753466, 0.06595540871577603, 0.3841897302440235, 1.09038026205131, 0.5936561503580638, 0.7612258557762418, 1.0933812324489867, 0.5670687598841531, 0.14968060462602548, 0.06517232502145426, 0.026118587236851454, 0.09988427667745522, 0.6328195631504059, 0.23729474257145608, 0.25969692905034336, 0.3707621193357876, 0.437369098088571, 1.282216551048415, 0.8986263200640678, 0.79690192426954, 0.8545656757695335, 0.2291633417563779, 0.5810276365705899, 0.30120582027094706, 0.07132696333740439, 0.6391685881784984, 0.2795156070164272, 0.1237355289714677, 0.18159673416188785, 0.022535542358777354, 0.076459219014006, 0.026793917873874307, 0.011738361508053328, 0.1335501851780074, 0.3990662305482796, 2.3232153143201555, 6.080435463360377, 13.648008636065892, 24.061556134905132, 35.67641850880214, 36.360753536224365, 31.800602163587296, 51.66511631011963, 31.74628462110247, 26.41333028248378, 21.522229262760707, 29.44191108431135, 37.90698480606079, 42.819875376565115, 45.066189765930176, 53.491919313158306, 61.9050726209368, 71.58380208696637, 66.67699119022915, 64.89494500841413, 62.174836431230815, 39.9242205619812, 15.162291220256261, 2.1493336047445024, 0.1202798993991954, 0.06224996290568795, 0.06128448899835348, 0.05677355766030295, 0.05076962536466973, 0.006802799138573131, 0.05067827758778419, 0.04632967557492001, 0.021518065527613674, 0.02361359540373087, 0.030295862550182, 0.027941318894071237, 0.018935159214639237, 0.017312790466738597, 0.01598216633179358, 0.0636110905823963, 0.03266616178942578, 0.018332608243716613, 0.01830298001212733, 0.044909851226423464, 0.03853243968582579, 0.024660561366805007, 0.015199065674096346, 0.05263889773881861, 0.025887479905837348, 0.05080515006557107, 0.11954495097909655, 0.023738888591261845, 0.0598902895248362, 0.03190460122589554, 0.07503232093794004, 0.024657153424673846, 0.013735873608051665, 0.03568823801885758, 0.10008332492517573, 0.07117697317153215, 0.04266300804114767, 0.04927907731117947, 0.049749325827828476, 0.020674760154049312, 0.05089931037010891, 0.029347514866718223, 0.050622125422315936, 0.19173925848943846, 0.21725663995104177, 0.1929465215653181, 0.15992409496435098, 0.1558076808495181, 0.12512663432529994, 0.17829244504017489, 0.2043126616626978, 0.15435694583824702, 0.1619884291929858, 0.2427779569157532, 0.06559819395520858, 0.09158835826175553, 0.20774967223405838, 0.2038684654980898, 0.19023236792002404, 0.1560309731534549, 0.17238239145704679, 0.1481633596122265, 0.14511514960655145, 0.1956356915512255, 0.10076365127627339, 0.08374916855245829, 0.12162505436156477, 0.1563659251800605, 0.12841215516839707, 0.2155849196548973, 0.10968650890780346, 0.12614590248891286, 0.15286011115780898, 0.16303383452551706, 0.23423970650349343, 0.1023846035823226, 0.08981252355234963, 0.13201037208948815, 0.13572731906814234, 0.20188007290874208, 0.14461501501500607, 1.3403666764497757, 5.190405964851379, 22.255866970334733, 58.891680581229075, 82.5596490587507, 76.46518952505929, 76.29234613691057, 75.16219384329659, 69.64102322714669, 55.38885395867484, 48.182154587336946, 36.275651999882285, 26.32998490333557, 24.454012972967966, 27.32329068865095, 42.38784681047712, 53.387498310634065, 58.65509441920689, 75.35397802080426, 58.57617677961077, 40.93472834995815, 27.232302291052683, 14.27632554939815, 6.677610116345542, 3.1842269642012457, 1.4793393335172107, 0.9575739141021455, 0.415018371705498, 0.3041106286857809, 0.154751256108284, 0.2499088714165347, 0.18647240182118757, 0.15180721479867185, 0.283897341894252, 0.12665074611348764, 0.2575735758457865, 0.23897455100502285, 0.13818968193871634, 0.27051494855965885, 0.7017894993935312, 0.8636760669095176, 0.8907493427395821, 1.3712810575962067, 0.9640063175133297, 0.43799459881016184, 0.17055762080209597, 0.15419689299804823, 0.2674592339566776, 0.7960181459784508, 0.6642685756087303, 0.2634190193244389, 0.292689065848078, 1.1247928440570831, 3.0192665244851793, 1.3252162379877908, 0.8471320803676332, 1.0200460361582893, 0.3716239130922726, 0.3520944267511368, 0.11155228343393121, 0.17760274133511952, 0.7892408839293888, 0.5729568696447781, 0.2818698521171297, 0.44856696150132586, 0.11347396246024541, 0.16185044231159346, 0.12500132247805595, 0.18013857597751276, 0.460402674973011, 0.6549593465668815, 4.025411060878208, 8.537321959223066, 21.52558524268014, 39.00645732879639, 57.01455177579607, 51.815117495400564, 58.33119024549212, 71.20838396889823, 33.70030219214303, 26.936844042369298, 21.550459793635778, 25.725309235709055, 37.56530366625105, 47.88462577547346, 56.23149674279349, 63.77629198346819, 69.43707970210484, 80.90192699432373, 75.98909895760673, 74.8869548525129, 70.21559061322893, 50.30721248899187, 21.67502362387521, 3.340666741132736, 0.39044905294265064, 0.177997797993677, 0.22269087763769285, 0.1344109204198633, 0.14316166085856302, 0.14026042153792723, 0.1605470443942717, 0.17855393886566162, 0.19515860000891344, 0.13824670602168354, 0.08430106858057634, 0.11430621280201844, 0.13924797943660192, 0.1198822371661663, 0.11876819123114858, 0.20674298410969122, 0.10352786044989314, 0.08396509875144277, 0.15810445403414114, 0.12050381595534937, 0.12014290317893028, 0.1469767511423145, 0.11570897538747106, 0.13576431279735907, 0.1631883369492633, 0.1844338790646621, 0.21903323461966856, 0.15805108046957425, 0.09178528948021786, 0.09359728332076754, 0.16743216636989797, 0.22310580180159637, 0.1791612005659512, 0.18345868853586061, 0.18857755671654428, 0.18101514822670392, 0.14691831570650848, 0.1331631759447711, 0.11725391820073128, 0.12311666432235922, 0.15506578423082829, 0.20789953347827705, 0.13533611648849078], [0.018671812988551598, 0.028098959542278732, 0.037881507471735985, 0.03154922190255352, 0.047901569799120934, 0.015906341739797165, 0.09560640515493495, 0.08779380723301854, 0.0072367727490408075, 0.02556086707461093, 0.03572724699707968, 0.06179698649793863, 0.08571643156132527, 0.09283207223883697, 0.03707427471610052, 0.014515165139787962, 0.0329419659184558, 0.004924013703462801, 0.06968491537762539, 0.012305572678867196, 0.01744536094234458, 0.05282531166449189, 0.04554491589910217, 0.029507581277617385, 0.02080342057161033, 0.02498519796478961, 0.044347603539271016, 0.02783210189746959, 0.02126684132963419, 0.052098956890404224, 0.0330960917552667, 0.04718220732840044, 0.037632882062877925, 0.15009542022432598, 0.052041919236736636, 0.02853969857096672, 0.08975442738405295, 2.3538229976381575, 12.144853591918945, 35.49599116189139, 48.93592643737793, 60.11897563934326, 55.53169502530779, 65.89848027910504, 60.72337164197649, 49.130458627428325, 36.53310360227312, 19.360199996403285, 12.280918427876063, 17.17574715614319, 16.41540925843375, 24.002114295959473, 39.066729477473665, 38.530523095812114, 31.842499801090785, 25.27581810951233, 16.867695297513688, 7.353962097849164, 1.8961753376892634, 0.49428165704011917, 0.3578585274517536, 0.1967624125203916, 0.05551474967173167, 0.024111173614593487, 0.006648936658166349, 0.11656740361026355, 0.13562024624219962, 0.06731854485613958, 0.08748063618051154, 0.03195824281179479, 0.05001146426158292, 0.0404988918453455, 0.0675008265035493, 0.05561334080994129, 0.07996915174382073, 0.1617938932031393, 0.66898960513728, 0.6754405189837728, 0.7877593434282711, 1.215579743896212, 0.37557483251605717, 0.12999831219869, 0.03239247129697885, 0.027624945156276226, 0.09093229632292475, 0.04778054290051971, 0.18033000427697385, 0.05801513085940054, 0.11423145181366376, 0.02351774045798395, 1.0759322430406297, 0.4344259931572846, 0.7645160992230687, 0.7186857813170978, 0.9760176901306424, 0.18653216718563012, 1.3123451343604495, 0.23993907496333122, 0.15471080185047217, 0.1003670407725232, 0.18029743459607872, 0.09444189657058034, 0.008754100883379579, 0.11573148917938982, 0.05289905145764351, 0.15042745455035142, 0.06588133304779019, 0.06515951428030219, 0.14985375319208416, 0.1176099998078176, 0.4629288879888398, 1.7552823722362518, 4.401090604918344, 12.356613840375628, 26.482815742492676, 50.60499491010393, 49.14613028935024, 49.54883745738438, 45.94620343617031, 34.37793568202427, 19.425537381853374, 21.820289611816406, 25.923496178218297, 51.744912896837505, 61.242283957345144, 49.083766732897075, 51.67340898513794, 49.15874126979283, 59.99030194963728, 64.88173648289272, 62.737307003566194, 48.82449122837612, 22.279200758252824, 5.597951250416892, 0.3875099649386746, 0.054359862713941505, 0.06580127948629004, 0.031019564252346754, 0.06789430896086351, 0.03576002702383058, 0.04720871090622885, 0.0548535105107086, 0.04573397611134818, 0.04182964150926896, 0.034961438804332695, 0.011103696322866848, 0.02405039723297315, 0.03839186080066221, 0.023248555438060845, 0.03435848580141153, 0.0699949176715953, 0.013507203914092054, 0.005486694804858416, 0.04132294548409326, 0.016973132799778665, 0.021567225389714752, 0.036199755035340786, 0.06933435026024069, 0.06260529133890357, 0.016073232516646385, 0.03374562957989318, 0.1090940935537219, 0.020328050811908076, 0.032756040537995953, 0.023073167706440603, 0.09012356400489807, 0.05454272450879216, 0.05398852424696088, 0.023837854620069265, 0.024995925603434443, 0.030566608200648, 0.07266513617443186, 0.039681962824293544, 0.05259396175720862, 0.013155084951514644, 0.037573042059583325, 0.06335626675614289, 0.04824632665674601, 0.04157701613647597, 0.04530904355591961, 0.13309154978820256, 0.08008433984858648, 0.049501613048570495, 0.03066427992390735, 0.04959897943107145, 0.08620934654027224, 0.0976027569600514, 0.042576718742826154, 0.037972726326967986, 0.08652992719518286, 0.03293761990166136, 0.06247627469045775, 0.03571782893102084, 0.03135587674166475, 0.06962554356349365, 0.02729816608397024, 0.04148761236241885, 0.07653784765196697, 0.02222114146154906, 0.03252139634319714, 0.04789769536416445, 0.04357957314433796, 0.06909600804959025, 0.05445318502773132, 0.08602446610374109, 0.01806570479779371, 0.01807314663061074, 0.046196597894387584, 0.041219563888651986, 0.10241707148296492, 0.08810984848865441, 0.05229634951267924, 0.04118855483829975, 2.8119704936231886, 14.091714518410818, 43.22503178460257, 57.73817886625017, 69.3106711251395, 62.82388155800955, 70.92388302939278, 68.33896555219377, 59.44431250435965, 47.914395332336426, 28.67084343092782, 25.72872427531651, 27.811186245509557, 21.54638467516218, 22.194410153797694, 31.885672433035715, 39.46546227591378, 38.233598777226035, 27.09189656802586, 15.32079005241394, 6.584418705531529, 1.9364633815629142, 0.7438525365931647, 0.28220051580241745, 0.16256498039833137, 0.013679606091630245, 0.07060296647250652, 0.040715463259922605, 0.12147656375808374, 0.025821768878293887, 0.08554401581308671, 0.23958824521728925, 0.3020470408456666, 0.3940351376576083, 0.3911320934338229, 0.4207252040505409, 0.33863161344613346, 0.5015887192317418, 0.7557000837155751, 2.351939384426389, 2.26865154504776, 2.7780554677758897, 1.8104247961725508, 0.9120707043579647, 0.6501162350177765, 0.10491159691342286, 0.039790134876966476, 0.13982212862798146, 0.05754187982529402, 0.27648996508547236, 0.6464355896626199, 0.3714662758367402, 0.6672605350613594, 2.281363274369921, 1.231289078082357, 0.5211525123034204, 1.8392504836831773, 1.4451293349266052, 1.1795695104769297, 3.1634824659143175, 1.9251247899872916, 0.634127670100757, 0.45485668256878853, 0.8858795240521431, 0.40649095071213587, 0.26964322105050087, 0.5619794215474809, 0.20506436989775725, 0.35382895224860733, 0.13999569788575172, 0.00409600675006264, 0.19245359301567078, 0.27308423497847145, 0.2768910878470966, 1.2186630070209503, 3.467944494315556, 11.740132314818245, 22.986159120287212, 45.76534182684762, 49.48676225117275, 44.158737659454346, 36.10098123550415, 25.38583067485264, 18.031859023230417, 28.443613018308366, 34.31826107842581, 57.37178993225098, 69.78016090393066, 57.77006762368338, 59.96888065338135, 58.2043856212071, 68.36513941628593, 75.77067538670131, 74.06169646126884, 58.327827317374094, 29.761125223977224, 8.398691500936236, 0.8624623034681592, 0.029371406084724834, 0.02534174097568861, 0.038348577051822624, 0.07066791584449154, 0.03126872231119445, 0.007586377739374126, 0.07774022527571235, 0.06543422596795218, 0.04227972057248865, 0.024085065283413445, 0.05580523390589016, 0.020303837289767604, 0.12235369240599019, 0.07056747909103121, 0.061466112466795106, 0.05963479394891432, 0.07180060792182173, 0.03725389650623713, 0.03806915633114321, 0.07272901346108743, 0.03979535959661007, 0.008618231031245418, 0.10188265051692724, 0.042953624589634795, 0.0563756172279162, 0.038368990777858665, 0.06549831360046353, 0.038098275661468506, 0.06655678073210375, 0.03957949385845235, 0.045342393552086184, 0.04485126990558846, 0.015507144321288382, 0.023658020787739327, 0.014225483273289033, 0.07525177951902151, 0.022837948453213488, 0.04187074716069868, 0.06885841222746031, 0.015555072642330612, 0.017049637623131275, 0.11523710856480257, 0.08644152086760316, 0.11269691772758961, 0.12251430164490427, 0.296062633395195, 0.1514324734785727, 0.1741212731493371, 0.17068977228232793, 0.2516640786613737, 0.13143827207386494, 0.15973756568772451, 0.11832972190209798, 0.1259109258119549, 0.20031898096203804, 0.12311614863574505, 0.17302846536040306, 0.1135536835395864, 0.17297346331179142, 0.22525655425020627, 0.08147058010633502, 0.1639308306787695, 0.166325570749385, 0.12898424161331995, 0.12395062457237925, 0.11723064444959164, 0.10762925858476333, 0.155399976298213, 0.16867604319538387, 0.2561164897467409, 0.12898975131767138, 0.08308448243354048, 0.1132473521200674, 0.1955868098884821, 0.2627784822668348, 0.2278359101286956, 0.11393194645643234, 0.24591666992221559, 4.236330143042973, 18.85617593356541, 53.55505411965506, 69.73160689217704, 78.09924602508545, 70.9198808670044, 80.02381365639823, 76.3799490247454, 66.58576134272984, 52.5528633253915, 30.62530047552926, 21.789307594299316, 27.113427298409597, 26.096122435161046, 37.93914106913975, 54.037933077131, 53.40235703332083, 45.512656688690186, 33.46487290518624, 22.140391383852275, 10.022352627345494, 2.9055229936327254, 1.151065068585532, 0.7866903522184917, 0.494536351944719, 0.16725951991975307, 0.1524355789380414, 0.11889676004648209, 0.3034570908972195, 0.4034247595284666, 0.347062845315252, 0.5256228095718792, 0.21968924227569783, 0.30570572880761965, 0.2701123873037951, 0.3348244348806994, 0.37159717881253784, 0.4541749991476536, 0.5112095315541539, 2.423101097345352, 3.003591171332768, 1.554899907537869, 3.9104787366730824, 1.4396720677614212, 1.0462664748941148, 0.38913861183183535, 0.15727167443505355, 0.3345322848430702, 0.14048291317054204, 0.6076956370047161, 0.5627054540174348, 0.3606906240539891, 0.5649930398379053, 4.486923439162118, 2.4125363613877977, 2.5429544832025255, 3.693857789039612, 2.9185823500156403, 1.0842682357345308, 4.270363288266318, 1.7815029195376804, 0.44046875461935997, 0.11529768817126751, 0.35399714750902994, 0.40297619359833853, 0.19009340394820484, 0.636823734002454, 0.3274589643946716, 0.5945862318788255, 0.3574311318142073, 0.24081525366221154, 0.5561004312975066, 0.6275198246751512, 0.9175658609185899, 2.3050744363239835, 6.260094165802002, 18.42301481110709, 35.931257588522776, 63.49962166377476, 58.567324774605886, 65.0248554774693, 61.03107261657715, 48.915821824754985, 30.20818621771676, 32.38125964573452, 37.205296652657644, 63.13378511156355, 76.44398362295968, 68.34114728655133, 69.85930783408028, 68.20393426077706, 77.35742160252163, 84.58773095267159, 82.86862850189209, 67.81990037645612, 38.2009665625436, 11.83810886314937, 1.3704465138060706, 0.12968759744295053, 0.11464410967060498, 0.24252176923411234, 0.13137803173490933, 0.17402217989521368, 0.21243750782949583, 0.1374150663614273, 0.16297094789998873, 0.19813830511910574, 0.10647017828055791, 0.11457214424652712, 0.10011154519660131, 0.15523176746709005, 0.14064557158521243, 0.20270616215254578, 0.17193173563906125, 0.1561650109610387, 0.2122522270573037, 0.20186503657272883, 0.12293374485203198, 0.12805563929889882, 0.17533681435244425, 0.1485815814563206, 0.10964227520993777, 0.08345309658242123, 0.09752235734569174, 0.21668312858257974, 0.1129674157127738, 0.07801235853029148, 0.16969664128763334, 0.17218329571187496, 0.1673631322171007, 0.10019125270524196, 0.0818408363099609, 0.11545113208038466, 0.18892126184489044, 0.12300284685833113, 0.1501343274222953, 0.20477454044989177, 0.13747198187879153, 0.07050001913947718], [0.03358037576877645, 0.04766626403267894, 0.03918564159955297, 0.0398661307990551, 0.025316680981112376, 0.03618529884676848, 0.08683736462678228, 0.03447511240041681, 0.02134833508171141, 0.05785352417400905, 0.047199157133166275, 0.05472154902028186, 0.011404127880398716, 0.0327062123189015, 0.022447168261611035, 0.03507787880620786, 0.010313416764672314, 0.025017961028165052, 0.0684957013332418, 0.016907381060134088, 0.06528958944337708, 0.011414985288865864, 0.055360776505299976, 0.007952948649679976, 0.038518465257116725, 0.023454392428642938, 0.036700161040893624, 0.027494322076173763, 0.07364836055785418, 0.020917731669864485, 0.011848301992618611, 0.05787259779338326, 0.01976417124803577, 0.04135414791692581, 0.03408240686569895, 0.15211479472262518, 4.366613209247589, 18.32364341190883, 40.93474224635533, 60.50040394919259, 59.804534912109375, 54.35571241378784, 52.22986936569214, 48.9334910937718, 43.17412233352661, 27.94108281816755, 21.383861098970684, 22.061506748199463, 21.294939790453228, 18.074892691203527, 31.874857561928884, 69.4006780896868, 54.1047226360866, 33.47547238213675, 18.415766102927073, 7.930587019239153, 1.7295067267758506, 0.3346885378871645, 0.07009581582886831, 0.1472912656941584, 0.07498442993632384, 0.0327318202305053, 0.04686024585472686, 0.02895735383832029, 0.06018182888094868, 0.1585569554673774, 0.2830330511288983, 0.09024631777512175, 0.07241689413785934, 0.0719663401001266, 0.1518434892807688, 0.7637405065553529, 0.1725152621843985, 0.43960332391517504, 0.3933235986956528, 0.30585774779319763, 2.733831052269254, 2.7977553478309085, 1.3738953173160553, 1.1246930722679411, 1.161685390131814, 0.2903167445744787, 0.004560388059222272, 0.06910980945186955, 0.027687509477670704, 0.05959833626236234, 0.2336321733891964, 0.12492517727826323, 0.44558775850704735, 0.6989709734916687, 0.8570233296070779, 0.7665324881672859, 0.21667442976364068, 1.2035794449704034, 1.8250961346285683, 0.4153975642153195, 2.0706667516912733, 2.4663353945527757, 0.6717157959938049, 3.7316742283957343, 2.106169875179018, 0.05622651255024331, 0.1321563385426998, 0.050019850954413414, 0.07036638166755438, 0.06077488884329796, 0.09314560291490384, 0.07832991291901895, 0.015607884719169565, 0.041637470213962455, 0.046081477643123696, 0.010242187551089695, 0.03494005477321999, 0.3149889292461531, 1.394797669989722, 2.273221722670964, 13.431967428752355, 29.977419172014507, 58.64355346134731, 46.12560592378889, 67.19937760489327, 26.08896231651306, 12.30391696521214, 18.038713421140397, 24.734223399843486, 30.980346475328716, 41.24702903202602, 44.45873308181763, 41.1499696459089, 55.90815537316458, 60.13670744214739, 69.27452659606934, 68.90047032492501, 45.79284627096993, 19.975157260894775, 0.8872992364423615, 0.14977432388280118, 0.03449183489595141, 0.023246236544634615, 0.05690148526004382, 0.03901881019451788, 0.13890736842794077, 0.08606200266097273, 0.07816418074071407, 0.015982659966019646, 0.01142736176760601, 0.03367644954206688, 0.011523387195276362, 0.015746531475867544, 0.02600875446972038, 0.05877112065042768, 0.0028585147270600176, 0.014677937209073986, 0.05218825549153345, 0.03851898433640599, 0.014086164766922593, 0.04781645775905677, 0.05022566758894494, 0.04141502607879894, 0.0485986593578543, 0.00962210917246661, 0.018749293205993514, 0.026018289583069936, 0.05567849034975682, 0.027833910193294287, 0.09235952009579965, 0.023142150969111493, 0.0940753315974559, 0.08235268920127835, 0.02862779955778803, 0.0014755683327426336, 0.08513686766049691, 0.02902381295072181, 0.017863375833258033, 0.05750047561845609, 0.005047783579876912, 0.020177020791119764, 0.03666319106040256, 0.04579022327171905, 0.050748963973351886, 0.01273035426025412, 0.06622239867491381, 0.015440081312720264, 0.0292003813332745, 0.06183336276028838, 0.020414694644776837, 0.05274116314415421, 0.01390131316812975, 0.02658287651969918, 0.08362911535160882, 0.03266189719683357, 0.09013843070715666, 0.017489465718556727, 0.026523212935509424, 0.027780127811378667, 0.05047924969611423, 0.04758421897089907, 0.04554751808089869, 0.015910904887797575, 0.01271985562717808, 0.05564146608646427, 0.011107072882753397, 0.07356517894991807, 0.045540603809058666, 0.04996468945007239, 0.05004647666854518, 0.0330090899951756, 0.059549949930182526, 0.021082161060933555, 0.035966355952301195, 0.08996674777673823, 0.029272842087915966, 4.67388209274837, 21.524529116494314, 47.7630739893232, 68.71491173335484, 67.1733843939645, 62.54605088915144, 59.587813649858745, 57.245211124420166, 54.511887073516846, 40.2334258215768, 33.85149499348232, 31.00384180886405, 23.617821591241018, 17.546263320105417, 29.392203671591624, 55.90947553089687, 45.35556486674717, 33.31592089789254, 14.866433450153895, 5.412702287946429, 1.2884591817855835, 0.3557475778673376, 0.12708845548331738, 0.03275598625519446, 0.028269075056804076, 0.05887148955038615, 0.10984978478934083, 0.10066778106348855, 0.17569968130971703, 0.3266486850168024, 0.6631930161799703, 0.6820832139679364, 0.3938736191817692, 0.6321890684110778, 1.1953282420124327, 1.6414801073925835, 1.3490429137434279, 1.369775469814028, 1.6490093490907123, 2.07992131795202, 5.84931058543069, 6.0759056721414835, 6.625311894076211, 3.8505144800458635, 1.250366660101073, 0.3072761573961803, 0.030793408530631235, 0.10827433504164219, 0.04472958143534405, 0.17056741884776525, 1.4619824077401842, 0.9583378902503422, 0.6218378267117909, 1.9780622465269906, 2.078497588634491, 2.336807510682515, 3.418863070862634, 4.068719616958073, 4.906575526509966, 3.7774975981031145, 6.647481424467904, 6.739779123238154, 1.765868278486388, 4.608493898596082, 5.480967904840197, 0.10985724867454597, 1.2384946857179915, 0.09724964055099658, 0.45010484755039215, 0.029742286540567875, 0.24414268082806043, 0.1898157609892743, 0.09426330615367208, 0.025516489188053777, 0.21494151917951448, 0.025449641614354084, 0.02074779596711908, 0.12657788502318518, 1.2680980286427905, 2.2785811722278595, 11.549386892999921, 26.770021268299647, 42.098815645490376, 40.292426449911936, 48.67140851702009, 30.945146901266916, 21.027925729751587, 33.08656086240496, 40.7110276222229, 38.796517508370535, 47.06833403451102, 52.925186020987375, 48.87159654072353, 62.9957799911499, 66.95081274850028, 77.2708956854684, 79.7354634148734, 57.93197454724993, 26.958803824016027, 2.2202404056276595, 0.14336984897298471, 0.027643632010689805, 0.04011437622830272, 0.049695389079196114, 0.03870017693511077, 0.08269201777875423, 0.0710517427484904, 0.010154061967373958, 0.03629470244050026, 0.01894299459776708, 0.05136151485411184, 0.020491274106981497, 0.04129251318850687, 0.05271734317232456, 0.031073392435376133, 0.034051655658653805, 0.04579986525433404, 0.06121656085763659, 0.08947408385574818, 0.021966566996915, 0.042336530916924985, 0.0005717640347679012, 0.03222283075696655, 0.05298288445919752, 0.05132576284397926, 0.011231163366963821, 0.01122314393121217, 0.0815038283222488, 0.045184298285416195, 0.03676794329658151, 0.024097110976332, 0.02719779039866158, 0.04307785756619913, 0.031173822403486286, 0.00614426181917744, 0.04458226130477019, 0.004736553137523255, 0.021531493735632727, 0.08337684960237571, 0.05747429773743663, 0.1777582751320941, 0.12264063129467623, 0.11215870375079767, 0.19051375639225754, 0.18942721826689585, 0.13683354827974523, 0.1661415384816272, 0.11654852676604475, 0.12210148093955857, 0.145216468455536, 0.16538354701229505, 0.19181282525616034, 0.06552318869424717, 0.14623402671090194, 0.12329264916479588, 0.17264612444809505, 0.14801363407501153, 0.13379730763179914, 0.09781893821699278, 0.18451313195484026, 0.14300502783485822, 0.12521014841539518, 0.1192174492669957, 0.09671891081546034, 0.13508295507303306, 0.10472755786031485, 0.210336424144251, 0.25956822452800615, 0.15248805683638367, 0.12273106644196169, 0.13007638443793568, 0.16982894204556942, 0.12448051970984254, 0.08743101491459779, 0.18204277594174656, 0.5291403893913541, 7.014905205794743, 29.799159663064138, 58.94721753256661, 78.47770050593785, 75.02550888061523, 71.04258605412075, 69.03500829424176, 63.20713724408831, 56.79551676341465, 39.74376194817679, 34.57549033846174, 33.76539986474173, 28.965488740376063, 27.787647485733032, 46.71135296140398, 84.94010189601353, 69.12940652029855, 43.941147872379844, 23.712360518319265, 10.84799143246242, 2.220397391489574, 0.5971200987696648, 0.3412407434412411, 0.35092875787190025, 0.20307854217078003, 0.24466100015810557, 0.26693643629550934, 0.2080241803612028, 0.277237167848008, 1.0362808278628757, 1.5196411652224404, 0.9056632167526654, 0.2766835646969931, 0.35263771616986817, 0.7843609143580709, 2.127875179052353, 0.7077737982783998, 1.3480167516640253, 1.2197513771908624, 1.8419676635946547, 6.736587728772845, 9.774879506656102, 7.91373416355678, 4.15878564119339, 3.5626953414508273, 1.121606009347098, 0.30482881729091915, 0.22142323851585388, 0.1596322027700288, 0.4265316996191229, 1.6961140100445067, 0.5753678402730397, 1.2835804607186998, 5.02644237450191, 3.5420479008129666, 3.1792173130171637, 2.9393922047955647, 5.060883292130061, 6.772171625069209, 2.943605201584952, 3.5429012264524187, 4.419910669326782, 0.7049765512347221, 8.316331897463117, 3.992437950202397, 0.06458140244441372, 0.6647710715021405, 0.08203354704060725, 0.31913909369281357, 0.1561202412205083, 0.23965867715222494, 0.33611970394849777, 0.24771261640957423, 0.3083006095673357, 0.46282851908888134, 0.09710275129015956, 0.21267552434333734, 0.6029850297740528, 2.3664339780807495, 3.393202070678983, 19.358942372458323, 39.64194304602486, 73.3349357332502, 63.06027317047119, 88.09919766017369, 35.965936047690256, 20.040206296103342, 27.58252624103001, 37.759887967790874, 43.407317774636404, 56.96027939660208, 61.99339117322649, 57.10934604917254, 73.05075441087995, 76.49428163255963, 87.05923993246896, 89.32884120941162, 70.49217755453927, 32.42615195683071, 3.793458478791373, 0.19280324211078032, 0.09738650784960814, 0.1049630366531866, 0.14523204761956418, 0.13510997433747562, 0.19720698866461003, 0.21909561912928308, 0.14378074263887747, 0.13165809027850628, 0.11958379032356398, 0.14054254282798084, 0.06617005648357527, 0.12353787172053542, 0.2984222253518445, 0.1302266935152667, 0.07049853993313653, 0.08899112298552479, 0.16618743459028856, 0.22366933870528424, 0.11678633971938066, 0.19927586907786982, 0.13863442093133926, 0.13805358138467583, 0.25771948801619665, 0.10085277685097285, 0.06379790484373059, 0.18874477488654, 0.21895220396774157, 0.15111390128731728, 0.14766782548810753, 0.1302087259079729, 0.23000961063163622, 0.11603075026401452, 0.1466858767505203, 0.12759764173201152, 0.22098812114979538, 0.11716085033757345, 0.09204145002045802, 0.19235561255897793, 0.12489773732210908], [0.07001118894134249, 0.02248230280487665, 0.02443501293393118, 0.034112191160342524, 0.039990896425609074, 0.05466828062864287, 0.02834718461547579, 0.02047906895833356, 0.027168788115627, 0.036519389133900404, 0.017257735831663013, 0.02406674823058503, 0.08232516103557178, 0.029550060962459872, 0.09088044267679964, 0.01677302603742906, 0.03134369703808001, 0.043424660206905434, 0.012040005098762257, 0.050753337131547074, 0.04036377177440694, 0.016900675437812294, 0.05196996059800897, 0.028339069336652756, 0.04132617191810693, 0.016998179223654524, 0.02170733269304037, 0.035958216924752505, 0.033898344063865285, 0.031852971496326585, 0.03741590691996472, 0.0505836355233831, 0.08436717146209308, 0.15218962356448174, 0.01544211182876357, 3.289306525673185, 23.09172136443002, 50.85455683299473, 61.56173433576311, 54.1184001650129, 62.810978753226145, 47.992506980895996, 51.600498063223704, 24.456024476460048, 13.896835786955696, 16.826726981571742, 13.537181394440786, 25.26733783313206, 38.70842129843575, 39.76886231558663, 46.86997338703701, 51.241463797433035, 26.709128992898123, 7.8017465727669855, 1.6453219183853693, 0.22652438336185046, 0.004117429796938917, 0.16244872020823614, 0.030411657943789448, 0.06347523430096251, 0.07723120866077286, 0.03861595377592104, 0.10358101009790387, 0.05986595047371728, 0.06040645789887224, 0.13378263770469598, 0.10909490779574428, 0.11080368967460734, 0.9024188422730991, 1.4278011790343692, 1.3180884718894958, 2.18487212061882, 1.6547852563006538, 0.8947786465287209, 1.535489029117993, 1.7540668717452457, 4.124723400388445, 2.7966384249074117, 7.1814735020909986, 1.5841725596359797, 0.7472417375871113, 0.6650959540690694, 0.06441940220871142, 0.09058143265013184, 0.11497219492282186, 0.19041964358517102, 0.5299083824668611, 0.7632748686841556, 0.5814453970108713, 1.017489641904831, 0.9894023090600967, 1.5412191216434752, 0.5001730780516351, 1.0657589946474348, 1.2194623755557197, 1.2960853725671768, 4.802477615220206, 5.560739738600595, 2.5274621716567447, 5.29618056331362, 9.435519065175738, 1.4097690837723869, 1.0925572195223399, 0.8237483522721699, 0.5383054433124406, 0.6156227716377803, 0.7097791678139141, 0.07725763081439904, 0.11996378350470747, 0.15547186029808863, 0.18701209500432014, 0.11231775235916887, 0.06895948680383818, 0.06203650935952153, 0.00808231219915407, 0.4771629784788404, 0.3699644064264638, 3.3946053896631514, 13.967756049973623, 32.00073112760271, 41.009987762996126, 56.453814779009136, 37.45612662179129, 22.063535622188024, 18.365297862461635, 21.761679819652013, 21.346424204962595, 23.725263323102677, 32.741072109767366, 38.970166887555806, 46.13131039483206, 56.6034893989563, 61.81364822387695, 68.30161898476737, 57.06420360292707, 27.19565749168396, 4.942292307104383, 0.06843346610133137, 0.04040533204429916, 0.052556842499013455, 0.017153689271903465, 0.014234107453376055, 0.04385410502020802, 0.017581208742090633, 0.11908579990267754, 0.024451024664033736, 0.05322436489430921, 0.06461729694690023, 0.03583044199539082, 0.003788252103342009, 0.03717611264437437, 0.020137041507821, 0.04306117917544075, 0.035274497898561616, 0.06028227920510939, 0.005378419699679528, 0.03044719621539116, 0.03992644577686276, 0.08377386722713709, 0.018847981035443287, 0.013346045909981643, 0.038939458916762044, 0.012474918904315149, 0.08130085135677032, 0.03894457507080265, 0.020651528811348335, 0.03952287011114614, 0.031014895931418453, 0.06240806156503303, 0.022012049199215004, 0.03518545714073947, 0.024034298989655714, 0.04326366759570582, 0.02871293873925294, 0.03914489217900804, 0.039708731030779224, 0.07073713998709406, 0.027553551397951584, 0.030995174311101437, 0.02369417143719537, 0.020013376804334775, 0.005194508720056287, 0.11116085015237331, 0.01310037128028593, 0.030362124887428114, 0.05312950909137726, 0.061442933710558076, 0.06172071916184255, 0.00986594327592424, 0.013367939690527107, 0.03960541050348963, 0.08074392338416406, 0.05268368783539959, 0.059376679227820466, 0.024931731101657664, 0.06256015518946306, 0.04028177081740328, 0.021687222611425177, 0.004769825950331453, 0.0029101149827641037, 0.03223092228706394, 0.023606618367401615, 0.02898273104801774, 0.051020106566803794, 0.04705210841659989, 0.024302181222343018, 0.027619338760684644, 0.05118198127352765, 0.031046865108822073, 0.15225055600915635, 0.13021661048488958, 4.3212388668741495, 29.300699370247976, 60.84316553388323, 70.5292739868164, 63.506958961486816, 71.8895297731672, 55.4710476739066, 57.46797037124634, 35.90135601588658, 24.2586886882782, 25.825886147362844, 24.900830779756816, 30.007758481161936, 35.517117159707205, 38.26278468540737, 42.00474051066807, 53.564927509852815, 26.85478060586112, 6.181466613497053, 1.3961379123585564, 0.08801198338291474, 0.014443248909498965, 0.16138797998428345, 0.020184525388426015, 0.031722638489944596, 0.16040380565183504, 0.12105965827192579, 0.5567576874579702, 0.3091107803796019, 0.6424903699329921, 1.0202364602259226, 0.8127451741269657, 1.071121375475611, 2.917600699833461, 3.410994670220784, 3.8551758527755737, 6.1544042485100885, 3.259166542972837, 3.508023223706654, 4.352056298937116, 5.8493088483810425, 6.552835234573909, 6.5793130823544095, 10.551777567182269, 6.481506764888763, 2.5128147176333835, 1.0134976846831185, 0.2281503975391388, 0.1244406761335475, 0.30227956122585703, 0.0837676857731172, 0.3062720341341836, 1.2508757242134638, 0.9338160689388002, 1.4283685428755624, 1.794250801205635, 3.161680494035993, 3.401300413267953, 4.381971333708082, 3.8067073907170976, 6.143713142190661, 9.81000178200858, 11.80087433542524, 5.0461539796420505, 9.323878015790667, 9.907981804439, 3.221079775265285, 2.178360355751855, 2.0348298975399564, 1.083425223827362, 1.0598752817937305, 1.1776602757828576, 0.5917241711701665, 0.614028377192361, 0.35117677599191666, 0.30550034982817514, 0.10757785277175051, 0.09551385297839131, 0.08030361522521291, 0.05134857858398131, 0.15454222661043915, 0.5393615152154649, 2.1392237586634497, 13.195821608815875, 29.559168883732386, 42.88970824650356, 36.570408480507986, 22.77495472771781, 20.86173697880336, 25.137884208134242, 32.75677851268223, 35.44588770185198, 36.80270760399954, 38.80421263831002, 49.55068220411028, 53.70306464603969, 63.9843418938773, 68.2188173021589, 77.8011474609375, 68.13016523633684, 37.73375579289028, 8.96980823789324, 0.12113953541432108, 0.09834147803485394, 0.01256301480212382, 0.04935483913868666, 0.051660026157540936, 0.03741210712386029, 0.020864721121532575, 0.01821348972485534, 0.01845902779937855, 0.013425529502066118, 0.027791759597935846, 0.043591623926269155, 0.01279263274877199, 0.06029603989528758, 0.013674815634398587, 0.019794221867674162, 0.06672366641994033, 0.06170302975390639, 0.04499932963933263, 0.03556374041363597, 0.05538215375106249, 0.1095574719033071, 0.021238945058680007, 0.017851506559444324, 0.045478738378733397, 0.03071130918604987, 0.01959923465204026, 0.04665883291246636, 0.020253703729914765, 0.021885731423805867, 0.036924033492271385, 0.032098750450781414, 0.03554393397644162, 0.07321986569357769, 0.021212268454421843, 0.05005759107215064, 0.04543040972203016, 0.054967090487480164, 0.013747103362610298, 0.10237235602523599, 0.11856919048087937, 0.10907781549862453, 0.12964149777378353, 0.13194102581058229, 0.13708817533084325, 0.20589698664844036, 0.07899976268942867, 0.10154284017958812, 0.07739983139825718, 0.11515678358929497, 0.137018706915634, 0.2387614638677665, 0.2858603165618011, 0.17547604973827088, 0.15183336553829058, 0.17934943975082465, 0.1312798070056098, 0.11551214594926153, 0.13178893897150243, 0.13719836941787175, 0.08787422720342875, 0.28446104164634434, 0.07032574420528752, 0.24236999452114105, 0.1544527007000787, 0.15057287817554815, 0.17862158880702086, 0.11382177951080458, 0.10656978043594531, 0.17287720633404596, 0.24690027428524836, 0.23657839958156857, 0.25652249796049936, 0.25342555556978497, 7.040174501282828, 39.100011348724365, 71.06251348767961, 77.69326972961426, 72.87581266675676, 78.0097462790353, 63.513198443821494, 64.96435056413922, 36.9461601121085, 24.224871805735997, 24.69949804033552, 22.661607027053833, 34.576317174094065, 50.92236082894461, 57.66118935176304, 62.4066561290196, 65.5066227231707, 33.01963928767613, 10.524589266095843, 2.8228906733649115, 0.7915796041488647, 0.08785373544586556, 0.2720517489526953, 0.2219321804919413, 0.27704231973205296, 0.3620744826538222, 0.2746798236455236, 0.4680737576314381, 0.3212272716420037, 0.4026911003249032, 0.5497203565069607, 0.3929069239114012, 0.5542547617639814, 2.7346787324973514, 4.958536761147635, 5.518357464245387, 5.790046359811511, 4.865269788673945, 4.491684257984161, 5.416055662291391, 6.918488093784877, 12.899297680173602, 8.870402097702026, 17.434079442705425, 8.767623475619725, 4.161457223551614, 2.3169232862336293, 0.22279607770698412, 0.2574025035968849, 0.5662481124911989, 0.42730254254170824, 1.2969576971871513, 3.358311040060861, 2.779705447810037, 4.982435958726065, 2.6272068193980624, 3.430424221924373, 2.7966744686876024, 3.8387034109660556, 2.6206852836268286, 6.732537363256727, 10.55948485646929, 15.769153833389282, 10.202297942978994, 16.30519345828465, 21.45450517109462, 5.749558772359576, 3.1834743874413625, 2.381894371339253, 1.0835805812052317, 2.040374777146748, 1.6186193398066928, 0.6282975886549268, 0.3946897068193981, 0.7110101931861469, 0.6272898827280317, 0.32623643428087234, 0.2971716581710747, 0.23072722926735878, 0.23531475024563925, 0.7313557671649116, 0.7413234465888568, 4.681901182447161, 18.591256754738943, 43.18388455254691, 55.1055793762207, 71.13947173527309, 51.094175883701865, 31.983437061309814, 27.54905503136771, 34.00494943346296, 35.76409087862287, 38.04670960562569, 48.08989988054548, 57.52972248622349, 63.20874227796282, 72.49813638414655, 77.63206304822648, 86.7363988331386, 80.10278688158307, 45.833006858825684, 11.16567349433899, 0.38200403324195314, 0.35527029633522034, 0.15192187364612306, 0.21609585652393953, 0.1363962460309267, 0.12970461510121822, 0.11969258662845407, 0.22100479954055377, 0.11620102184159414, 0.15719320864549705, 0.13912872012172425, 0.09342526790818997, 0.08523917717060872, 0.18830944038927555, 0.07188183534890413, 0.07487946735428912, 0.11307451568011727, 0.09338840310062681, 0.15408159632767948, 0.05630245418953044, 0.14635841575052055, 0.17941856889852456, 0.08454642005796943, 0.14303208781140192, 0.09413996205798217, 0.1521595237510545, 0.1417261114610093, 0.15502442073609146, 0.18061581679752894, 0.13097073430461542, 0.1549573271934475, 0.1395124588161707, 0.0787130816440497, 0.2182545478322676, 0.08677850849926472, 0.10510079961802278, 0.1539533803505557, 0.10560970088200909, 0.1269567518361977], [0.07267329216535602, 0.039972301173423014, 0.031859610961484056, 0.015568465227261186, 0.00880191894248128, 0.06028406375220843, 0.013965262549131044, 0.018285260070115328, 0.03973853228879826, 0.027861126232892275, 0.05362235621682235, 0.03481354870434318, 0.0620556508323976, 0.0172222484501877, 0.07279702302600656, 0.049933290242084434, 0.10325193418455975, 0.05828463139810732, 0.06918230413326196, 0.03752650134265423, 0.04521359742752143, 0.00837320355432374, 0.02002573123068682, 0.0381777490755277, 0.031061267014592886, 0.008749264625034161, 0.015997360427198664, 0.050778836477547884, 0.03879508702084422, 0.04396362735756806, 0.04543661153210061, 0.07738030316042048, 0.07068026518183095, 0.34334735040153774, 6.618661165237427, 36.785875592912944, 59.22911984579903, 61.695313453674316, 57.52586623600551, 50.339354855673655, 38.23695475714547, 46.86900063923427, 28.88116887637547, 18.79814805303301, 15.754011971609932, 17.10568846975054, 21.555571930749075, 51.09912300109863, 52.42096567153931, 34.0968393598284, 45.78161103384835, 21.23919265610831, 3.467518048627036, 0.2837680945438998, 0.03833479600559388, 0.06405121553689241, 0.22765516197042807, 0.1714861145509141, 0.16523368576807634, 0.1357873287051916, 0.03750720041404877, 0.08575243462941476, 0.13371968322566577, 0.31631459668278694, 0.48620649320738657, 0.7270680772406715, 0.7569784979735101, 1.0392226300069263, 2.65247329218047, 2.7246053644589017, 3.6097943569932665, 3.4669129039560045, 3.859535413128989, 2.30589844925063, 5.619406419140952, 3.5526384753840308, 6.927990623882838, 5.963018723896571, 7.5838614872523715, 4.687046757766178, 1.2034438465322768, 0.05732708956514086, 0.07575041454817567, 0.07459311879106931, 0.07043139889304127, 0.664124074791159, 2.262357997042792, 5.011819890567234, 6.281374326774052, 3.6418014509337286, 2.3066423407622745, 0.9271691398961204, 6.932663721697671, 4.770797738007136, 1.8642700782843997, 5.879550448485783, 14.84720083645412, 13.772643685340881, 3.91895249911717, 3.4547833033970425, 6.311216405459812, 2.3322353788784573, 3.1477832283292497, 2.536416228328432, 0.7015607516680444, 1.3062769685472762, 1.1199457155806678, 0.826310011957373, 0.2688448838889599, 0.11448918655514717, 0.06170556068952594, 0.0587395823427609, 0.07386887765356473, 0.05270026105323008, 0.057681712321937084, 0.0582944837265781, 0.015056040670190538, 0.06744936640773501, 0.12940539472869464, 2.5794872428689684, 21.20864142690386, 56.97140693664551, 68.78848620823452, 50.52125174658639, 32.10538836887905, 17.432387556348527, 10.926774450710841, 20.327486515045166, 26.28652392114912, 26.958152430398123, 39.41396222795759, 58.52134159633091, 55.29135683604649, 52.4465628351484, 67.03328091757638, 67.01982225690568, 44.78537137167794, 11.477898614747183, 0.7302574632423264, 0.07301225433392183, 0.027240702649578452, 0.061548629110412936, 0.029879035095551183, 0.03498387456472431, 0.019752722665933625, 0.010449208585279328, 0.15518817837749208, 0.03724256157875061, 0.03160154034516641, 0.03202235419303179, 0.05783715112400906, 0.01404381315556488, 0.014991096387218152, 0.03227238756205354, 0.04589088394173554, 0.08476412123335259, 0.022948960174939463, 0.04316433006897569, 0.0423307497985661, 0.041326344944536686, 0.08970948800976787, 0.02219748942713652, 0.04062055317418916, 0.01637956902517804, 0.027933256201712147, 0.05914355495146342, 0.0816249128963266, 0.05956316100699561, 0.0612056093024356, 0.054756408756864924, 0.028121045857135738, 0.022403519800198928, 0.02230992098338902, 0.052233540918678045, 0.026559887753267373, 0.026391180198905722, 0.04840211829702769, 0.019707082704241787, 0.04758092129070844, 0.05515620158985257, 0.029047544712999036, 0.03134138323366642, 0.04043816635385156, 0.0016877913980611733, 0.006188929779455066, 0.0022560299133017126, 0.04986857496468084, 0.03485368065802114, 0.04149279297728624, 0.0181883313427014, 0.020291280999247516, 0.024248386966064572, 0.08633948277149882, 0.04073210093857987, 0.07618612223970038, 0.012392647381472801, 0.020733270228707364, 0.04020532706220235, 0.08016510587185621, 0.043717750015535524, 0.031312321578817706, 0.027590645211083547, 0.015192317643335887, 0.04998106589274747, 0.024231396449197615, 0.03382485532867057, 0.035137386327343326, 0.02694032876752317, 0.04733450112066098, 0.2869978126670633, 8.4869145154953, 41.84819412231445, 68.78185762677873, 68.3822180884225, 66.94388539450509, 55.46491936274937, 46.85753263745989, 51.29404081617083, 40.71482828685215, 30.170485292162212, 23.19821466718401, 22.804710388183594, 21.13702460697719, 45.320931570870535, 43.11859580448696, 34.73606668199812, 44.60252257755825, 19.517505475452968, 3.3975114737238203, 0.3321367848132338, 0.04494243787069406, 0.016722941671365073, 0.23732883217079298, 0.21637780139488832, 0.23808295599051885, 0.5661095827817917, 0.46814155685050146, 0.47275852624859127, 1.0433735272714069, 0.8634757633720125, 2.040751499789102, 2.466641983815602, 3.4178223609924316, 3.8223916462489536, 6.316813613687243, 7.165971202509744, 8.192771213395254, 7.789533376693726, 7.792026042938232, 7.239623844623566, 6.165524406092508, 8.2533004454204, 7.34417382308415, 5.185296867574964, 7.023322514125279, 6.118875503540039, 3.297528633049556, 1.2909831149237496, 0.3226102888584137, 0.11838959583214351, 0.05159467984257, 0.3559314065745899, 2.5497871679919104, 3.6486701795033047, 4.348326853343418, 1.7594087336744582, 1.6218021575893675, 2.682246757405145, 2.8169829675129483, 8.476670265197754, 6.790392407349177, 7.369712795530047, 11.26280757359096, 6.596958901200976, 5.773447113377707, 4.865957660334451, 8.399584344455175, 5.791251003742218, 2.559561763490949, 4.799758263996669, 2.975086186613355, 2.9600537589618137, 3.1956543624401093, 1.2296971806458064, 0.7336492155279432, 0.3758720579956259, 0.33685724437236786, 0.33170026966503685, 0.503172962793282, 0.08738859969058207, 0.08127211539873055, 0.057383475825190544, 0.05544601407434259, 0.06283704497452293, 0.036451477956558974, 2.8665659640516554, 17.297026225498744, 48.58755070822579, 58.4295836857387, 40.813746316092356, 27.998862300600322, 24.12575922693525, 16.364878484180995, 28.67106924738203, 34.65018694741385, 30.73774664742606, 45.809768608638215, 64.76907839093889, 62.41857923780169, 58.915707451956614, 72.85417597634452, 77.56415135519845, 56.504234382084434, 18.604121344430105, 1.5936721584626605, 0.10259878316095897, 0.022730517700048428, 0.05696384262825761, 0.035711779791329584, 0.012623574052538191, 0.05142343795991369, 0.09356573144240038, 0.028311826155654023, 0.013426573597826064, 0.010783520244461085, 0.014008975471369922, 0.0023186222242657095, 0.010044709263768579, 0.03972133481875062, 0.06584079736577612, 0.06238558848521539, 0.047772006929985115, 0.05080071244654911, 0.05554523625011955, 0.07444591061877352, 0.006608502332320703, 0.034986134086336405, 0.012290566028761012, 0.06066722569188901, 0.046554121388388534, 0.018452188166390573, 0.039542852967445336, 0.05437852921230452, 0.027203296710337912, 0.06300786616546766, 0.03344956100253122, 0.03207384482292192, 0.018611704963924627, 0.013809828836071705, 0.03567252654050078, 0.029721146782061884, 0.028178297249334197, 0.10858407270695482, 0.12370065227150917, 0.07877180206456355, 0.10536951305610792, 0.09135163774979965, 0.11335186008363962, 0.15027281641960144, 0.12647553480097226, 0.09414688311517239, 0.0817849657365254, 0.11025214248469897, 0.17127511730151518, 0.18335196854812758, 0.09130344140742506, 0.16883125129554952, 0.18502871000341006, 0.1963266030486141, 0.1469455656728574, 0.2388641940695899, 0.11462477142257349, 0.1791536281151431, 0.10154839738139085, 0.12798836933715002, 0.17018738495452063, 0.1288015257034983, 0.0801525597593614, 0.1801378024475915, 0.17095351884407656, 0.25640644133090973, 0.1741048526018858, 0.1425201738519328, 0.17052741242306574, 0.1195418161473104, 0.3988135169659342, 12.6440304177148, 52.506758553641184, 79.88928958347866, 76.87758595602853, 75.69408539363316, 65.63985443115234, 54.20808751242501, 59.33164051600865, 43.32241078785488, 29.21456602641514, 23.096826553344727, 25.42198736327035, 31.86576931817191, 60.44908455439976, 65.66150501796177, 48.37397697993687, 60.32105009896414, 29.602782726287842, 4.981899644647326, 0.7459917675171579, 0.18675916429076875, 0.1070779353114111, 0.6000560383711542, 0.33905667492321556, 0.4436122987951551, 0.41665920508759363, 0.3813725342707974, 0.3447887216295515, 0.606998374419553, 1.2444342012916292, 2.352049687079021, 2.0985930817467824, 2.501116991043091, 5.224367456776755, 9.319079416138784, 10.04650022302355, 16.196773767471313, 13.617608530180794, 13.145296045712062, 11.444981523922511, 14.687920331954956, 12.755746160234724, 18.182659251349314, 15.656273399080549, 15.050067390714373, 10.148495435714722, 3.254652819463185, 0.6011046192475727, 0.2197369432875088, 0.1355855731027467, 0.17460901769144194, 0.8613155250038419, 3.901957639626094, 4.3181677630969455, 3.7914795449801852, 1.8293918584074293, 4.681154685361045, 6.638186906065259, 15.253788573401314, 12.671122312545776, 10.34916375364576, 14.587154081889562, 27.310426098959788, 26.222157546452113, 11.992132186889648, 10.452567713601248, 15.928250210625784, 9.139761175428118, 10.793405515807015, 8.735680869647435, 5.5245817473956516, 5.064738239560809, 4.308940989630563, 3.0537348006452834, 1.376401771392141, 0.8365099132061005, 0.5363154358097485, 0.30592188292316025, 0.5046239420771599, 0.20153062737413815, 0.17939539014228753, 0.22314561823649065, 0.1514862948762519, 0.1070463087941919, 0.3429990176643644, 4.010067701339722, 29.233135087149485, 74.80290249415806, 87.48996571132115, 66.55653027125767, 43.97802196230207, 27.4930317061288, 18.344906636646815, 28.98661126409258, 39.229803698403494, 37.42871945244925, 52.74379287447248, 73.84785870143345, 72.2765930720738, 68.09912763323102, 80.59913144792829, 85.60555171966553, 66.73687076568604, 22.431418418884277, 1.9758846376623427, 0.22210717467325075, 0.11169884021260909, 0.2383954892201083, 0.16692900551216944, 0.19095343351364136, 0.17250189504453114, 0.16656687137271675, 0.2146277917282922, 0.16362603274839266, 0.15083168500236102, 0.13401950070900576, 0.13385137330208505, 0.05212555546313524, 0.17084419328187192, 0.10611877856510026, 0.09796230588108301, 0.11479945347777434, 0.12470132857561111, 0.14362360749925884, 0.1932173248912607, 0.1281996922833579, 0.2122599080737148, 0.08407622243144683, 0.13919121319694178, 0.1311785831515278, 0.08693020178803376, 0.14293899280684336, 0.18984389305114746, 0.17690684939069407, 0.15488305475030625, 0.14339776390365191, 0.09411104289548737, 0.13446300476789474, 0.08612651098519564, 0.11227277905813285, 0.1119157135752695, 0.14132380804845265], [0.09402027526604277, 0.06113133007394416, 0.15573590541524546, 0.06846470585358994, 0.0877207765089614, 0.05523933909301247, 0.05663723658238139, 0.039574486270014725, 0.07178039436361619, 0.11332477975104537, 0.15914661596928323, 0.07958934855248247, 0.09125189310205833, 0.07226105500012636, 0.1871748212724924, 0.3209812891270433, 0.29706572528396336, 0.09947020068232502, 0.19222833296017988, 0.018524638743006756, 0.03282155987939664, 0.01472530234605074, 0.030618132757289068, 0.06704169578318085, 0.016123944527602622, 0.03233385265671781, 0.03482661050345216, 0.05877220630645752, 0.10104681072490555, 0.1089399236121348, 0.06317752706153051, 0.044695447731230936, 0.13860170197274002, 9.773654886654445, 40.11288499832153, 61.18197359357561, 60.76713834490095, 60.43469483511788, 45.16038302012852, 49.282832622528076, 32.31023863383702, 28.675201688494, 24.04775701250349, 17.05692253793989, 22.217959335872106, 29.598189967019216, 52.59357282093593, 47.48568800517491, 49.879700251988, 41.24903358731951, 14.846410478864398, 2.4660103491374423, 0.1399322005787066, 0.04973437770136765, 0.19689487612673215, 0.07974826823920012, 0.07957611711961882, 0.33687035366892815, 0.1430011059024504, 0.20444477243082865, 0.11817466307963644, 0.2810083840574537, 1.3262855006115777, 0.6108665125710624, 2.6529164569718495, 3.6650284102984836, 4.653207293578556, 3.165690907410213, 5.113118546349662, 4.542757860251835, 4.208872164998736, 10.45823049545288, 3.134416414158685, 4.657070057732718, 2.9946510110582625, 7.280054543699537, 3.9734285473823547, 3.5387262276240756, 5.17404990536826, 6.150405125958579, 3.050703431878771, 0.6012691504188946, 0.25561383100492613, 0.6565302908420563, 0.11577830809567656, 10.829105360167366, 40.63737324305943, 45.234579358782085, 49.441970688956125, 38.965490749904085, 19.969937426703318, 6.213519087859562, 3.062660630260195, 4.111020249979837, 6.370200966085706, 4.287886645112719, 10.001414230891637, 6.950257863317217, 1.6995192787476947, 4.493444757802146, 4.840092122554779, 2.4695613128798346, 2.2777096075671057, 3.7276733687945773, 1.5620510152408054, 1.7422845725502287, 1.1726359682423728, 1.702664098569325, 2.3196196215493337, 1.2382053583860397, 0.669741150523935, 0.7044781265514237, 0.07550494093447924, 0.0743448631837964, 0.08389912479157959, 0.11731136297541005, 0.1630413934056248, 0.07923472579568624, 0.2629546842404774, 0.10672166371451956, 0.35318806235279354, 3.7122674754687717, 22.433372599737986, 47.970349175589426, 44.32540757315499, 41.75853456769671, 35.042259897504536, 38.41277892248971, 37.82284906932286, 36.983009883335654, 27.470180818012782, 27.818153551646642, 33.91279894965035, 47.08063234601702, 62.712112835475374, 59.6955315726144, 67.62897777557373, 65.36362879616874, 31.699780327933176, 1.6758562113557542, 0.04464644393218415, 0.027798527984746864, 0.02235163901267307, 0.016877993708476424, 0.10743484473122017, 0.12294232153466769, 0.04973945314330714, 0.06016574760100671, 0.027963790277551328, 0.032462872697838714, 0.10352955000208956, 0.15699164303285734, 0.24043948096888407, 0.08324254716613463, 0.15309309294181211, 0.18716510465102537, 0.08873753409300532, 0.03587953739666513, 0.033319292456976006, 0.21872142063719885, 0.09587781237704412, 0.34699472039937973, 0.03452340034501893, 0.13349512884659426, 0.18492251927299158, 0.1807625432099615, 0.18290439327912672, 0.038933172289814265, 0.058494875473635535, 0.05939349332558257, 0.01752820497910891, 0.07703342927353722, 0.018755793571472168, 0.017624989517831376, 0.051255225736115656, 0.024982965584578257, 0.033788268720465045, 0.05046929558739066, 0.12457270547747612, 0.06321726885757276, 0.00807850222502436, 0.07883946557662316, 0.06169868712978704, 0.02795095069866095, 0.054654170492930074, 0.027978561984907304, 0.09753408243081399, 0.0766848794051579, 0.10021209051566464, 0.026428670955023596, 0.21579468197056226, 0.11364626964288098, 0.19165556798023836, 0.07517663855105639, 0.1604248130960124, 0.0606862585991621, 0.06376776431820222, 0.026227210515311787, 0.06282318928944212, 0.06040491083902972, 0.04257836079757128, 0.03761537925207189, 0.04673982285229223, 0.011463516657905919, 0.03538199820156608, 0.13418689529810632, 0.10498810173677546, 0.05838744302413293, 0.2575769956622805, 11.718671066420418, 46.09032991954258, 69.32560280391148, 68.7109373637608, 69.17234638759068, 54.45153502055577, 59.31449931008475, 41.33066102436611, 35.625387464250835, 31.360364300864084, 24.527380738939556, 21.820543221064977, 22.69596586908613, 38.02503817422049, 45.27404860087803, 51.478199345724924, 38.296309743608745, 15.980630942753383, 2.3953395698751723, 0.20992870602224553, 0.014592474027137672, 0.3034443344388689, 0.20897543217454637, 0.15443960497421877, 0.4879187356148447, 0.8120690818343843, 0.6388126015663147, 0.8387955448457173, 1.8679799820695604, 3.665633337838309, 2.865417774234499, 6.146845042705536, 4.822895331042154, 8.06879711151123, 6.5612316983086725, 14.206849643162318, 10.081927350589208, 5.876676934106009, 7.434118253844125, 8.615643790790013, 8.73888920034681, 7.860302516392299, 8.130404182842799, 4.712524933474405, 5.5780320678438455, 5.748489618301392, 6.067917849336352, 3.7360281433377946, 2.3211043647357394, 1.1258192232676913, 0.7577956169843674, 0.5303584411740303, 9.262439438274928, 38.66899374553135, 45.564278330121724, 48.35528285162789, 39.02890001024519, 18.533218451908656, 7.688170450074332, 4.204641580581665, 5.6584592035838535, 7.661766426903861, 7.066790010247912, 6.829648426600865, 6.416515920843397, 2.387157848903111, 7.562288199152265, 8.57596697126116, 2.4253088874476294, 2.513190354619707, 3.3719916088240485, 1.4563239685126712, 2.5123316007001057, 2.07496160694531, 1.8672732199941362, 2.5112848111561368, 2.014838193144117, 2.004883813006537, 1.4849970127855028, 0.6309223249554634, 0.8070656188896724, 0.3255780381815774, 0.11713140191776411, 0.09726392371313912, 0.022519815613382628, 0.010014098004571028, 0.03478840219655207, 0.3831298314034939, 3.8277174404689243, 20.421832629612513, 38.438025202069966, 32.650533608027864, 31.333370549338206, 28.721377679279872, 27.797680684498378, 37.605818612234934, 46.84427547454834, 38.9521814755031, 40.30816759381975, 42.45015478134155, 57.72714860098702, 69.15894331250871, 67.35820647648403, 74.69915199279785, 78.19522149222237, 43.55732243401663, 3.9431239792278836, 0.15823581841375145, 0.04051524114661983, 0.05825898277440241, 0.02585623676090368, 0.06476487152810607, 0.09688329270907811, 0.009425263619050384, 0.11687707342207432, 0.039954981567072015, 0.04595781124329992, 0.07870073909206049, 0.034256522344159226, 0.07788684990789209, 0.11241641135088035, 0.03361944920782532, 0.2074778646762882, 0.04148273369563477, 0.05031441657670906, 0.012884019541421106, 0.04242882185748645, 0.10220340759094272, 0.10357042495161295, 0.03265563092593636, 0.1295372069414173, 0.18529884836503438, 0.2142937896507127, 0.0690501458676798, 0.010830217872613242, 0.058833315170236995, 0.06703227093177182, 0.030330671396638666, 0.06365337009940829, 0.027801109810492823, 0.031982273129480224, 0.08357346190937928, 0.03235131136274763, 0.16864534627114022, 0.13538985646196774, 0.22271416495953286, 0.16468537519020693, 0.18093425328178064, 0.16936410484569414, 0.13050060453159468, 0.12750731515032904, 0.16944006005568163, 0.18520815537444182, 0.23666405784232275, 0.1386425362101623, 0.1988759541085788, 0.12494394555687904, 0.34138090163469315, 0.347640794302736, 0.2749523233090128, 0.2504784065697874, 0.2797735317477158, 0.1304535549134016, 0.20716104310538086, 0.11919618397951126, 0.21970322009708199, 0.17378473335078784, 0.09383749150271926, 0.17739095698509896, 0.16655273070292814, 0.09039932742182698, 0.15039966175598757, 0.23229814640113286, 0.2509820966848305, 0.15086846160037176, 0.45629504110131947, 18.715045860835485, 57.811155796051025, 80.08365154266357, 77.994599206107, 77.72696154458183, 63.98745468684605, 68.35536330086845, 46.87030342647007, 41.84975399289812, 33.9303674697876, 25.00327675683158, 31.171182223728724, 40.879653453826904, 70.59705366407121, 62.21122414725167, 65.16035229819161, 56.23682253701346, 20.09789024080549, 3.834251352718898, 0.30066855624318123, 0.18679093330034188, 0.770142131618091, 0.5269312965018409, 0.3231275768152305, 0.7510435964379991, 0.706453586263316, 0.42878544011286324, 1.1626420702253069, 1.9737148455211093, 4.589409368378775, 5.083734614508493, 9.446673529488699, 12.414612191064016, 16.204871892929077, 15.900744029453822, 12.473357473100934, 14.13541955607278, 13.33605796950204, 21.772275822503225, 9.829974378858294, 12.219287037849426, 11.475986123085022, 15.9280070236751, 12.841763990265981, 11.150317106928144, 15.436918769563947, 12.31473183631897, 8.287054794175283, 2.886595232146127, 1.329804003238678, 1.2481598470892226, 1.7633477108819144, 10.048438770430428, 34.30269711358206, 37.0493825503758, 36.88656541279384, 27.393971238817485, 11.287869725908552, 10.344498038291931, 10.869701947484698, 14.056447199412755, 17.292013100215367, 12.811221446309771, 23.035802262169973, 19.175483873912267, 7.150387261595045, 16.143771171569824, 17.81881856918335, 10.107740776879446, 7.893203105245318, 11.465853912489754, 7.174005925655365, 5.968797019549778, 5.032946756907871, 5.4343902213232855, 6.76667559998376, 3.503754858459745, 2.8528680247919898, 2.925743554319654, 0.7165185947503362, 0.7650867743151528, 0.33211979429636684, 0.27224765558327946, 0.20868035086563655, 0.1824339920920985, 0.3978359379938671, 0.19873977213033608, 0.6719169680561338, 5.247008161885398, 30.175373349870952, 62.06294958932059, 58.951080730983186, 55.8910037449428, 47.205894470214844, 49.40428365979876, 50.747342654636924, 48.94262102672032, 40.17878518785749, 42.36174937656948, 48.1789618900844, 63.235861097063335, 77.98941584995815, 76.94696371895927, 85.36517184121269, 89.91007191794259, 51.01684243338448, 4.112389913627079, 0.35891432794077055, 0.1320829481950828, 0.14033552179379122, 0.08870383125862905, 0.24098011053034238, 0.2021508626639843, 0.12277347488062722, 0.21351439718689236, 0.15379404675747665, 0.1859589000897748, 0.2669963373669556, 0.19890765526465007, 0.23726304141538485, 0.2455220610967704, 0.3209574046943869, 0.37108591624668663, 0.273127769785268, 0.19973459946257727, 0.1791418758886201, 0.2843589356967381, 0.29617841861077715, 0.37319344601460863, 0.15585578898234026, 0.2398550451866218, 0.250569791666099, 0.3182552611189229, 0.3690416802253042, 0.10813702669526849, 0.13127284523631844, 0.14478007544364246, 0.08437160229576485, 0.1581699733755418, 0.10865353433681385, 0.14631576303924831, 0.17439270072749682, 0.10391320727233376], [0.08331793240670647, 0.021748789486342242, 0.16040737474603312, 0.01541456500334399, 0.08514535613358021, 0.0377924904626395, 0.09146299213171005, 0.10545091690229517, 0.06454995913164956, 0.10662227869033813, 0.24862980576498167, 0.11208778327064854, 0.06270774334136929, 0.059982468507119586, 0.148307684010693, 0.23753600248268672, 0.18720521964132786, 0.03969177783333829, 0.20611772766070707, 0.028110665967687964, 0.026365027762949467, 0.11422784200736455, 0.14537785122437136, 0.12410215501274381, 0.09568989888897964, 0.04118258033746055, 0.026045090019969002, 0.03342120163142681, 0.023983929638883898, 0.06694361354623522, 0.027258298758949553, 0.11523552079285894, 4.632984561579568, 31.392468452453613, 52.003747190747944, 61.3600628716605, 57.01297453471592, 46.42907544544765, 44.80149814060756, 26.29043401990618, 17.493324995040894, 18.483785493033274, 22.492354120526993, 27.541625670024327, 36.052878856658936, 35.30635050364903, 51.03790589741298, 44.861516680036274, 21.910571030208043, 8.751438515526907, 0.7921034874660628, 0.1511181082044329, 0.1048366730766637, 0.027705241294045533, 0.05107051493333919, 0.0930844261976225, 0.3219585695437023, 0.3270702181117875, 0.17720701971224376, 1.1816731861659457, 0.404232351907662, 1.1254562884569168, 2.7598216576235632, 1.4244486732142312, 1.910172918013164, 2.459693568093436, 6.454808746065412, 4.858589964253562, 14.994129180908203, 9.222246715000697, 4.21950421163014, 5.316684263093131, 12.555288893835884, 6.666962002004896, 3.482232379061835, 5.8089993085180005, 3.504122461591448, 2.4836131760052274, 4.3903030923434665, 7.489495396614075, 5.1095984152385165, 4.362936743668147, 2.5614249663693562, 1.011797873037202, 9.859995807920184, 49.30613688060215, 66.6483507156372, 58.19389384133475, 66.26423345293317, 60.55876186915806, 59.1408360345023, 38.282555784497944, 8.243421844073705, 8.473534890583583, 6.152839166777475, 6.427754632064274, 4.452645369938441, 2.059240221977234, 2.689137633357729, 4.933196246623993, 5.962906684194293, 3.555497224841799, 1.3200766337769372, 2.3656790128776004, 1.8424970294748033, 1.8917041718959808, 2.4243278886590685, 0.7622327474611146, 0.4734345099755696, 1.49369235762528, 0.5557660492403167, 1.395539607320513, 0.5614046209624836, 0.22493632643350533, 0.36003168512667927, 0.1490409496639456, 0.07372734203402485, 0.02377211645112506, 0.034269651996770074, 0.10264484890337501, 0.09202701758061137, 0.25051333755254745, 4.301150321960449, 25.59719487598964, 41.72550630569458, 52.04708310535976, 33.02838012150356, 92.76356506347656, 82.43663120269775, 23.88641115597316, 15.116149970463344, 28.806673765182495, 26.485407420567103, 27.410881417138235, 51.87915556771414, 50.65533808299473, 61.522866112845286, 64.90923745291573, 71.49733175550188, 37.862686565944124, 2.956509743418012, 0.1920676151556628, 0.04742087184318474, 0.017494975422908152, 0.08008723040776593, 0.04008289220343743, 0.07170095148363284, 0.07223887369036674, 0.10424395916717392, 0.021521612569423657, 0.016095171250136833, 0.16042839576091084, 0.20383140391537122, 0.08737033352788005, 0.09875207314533846, 0.28606580410684856, 0.055218352004885674, 0.028332602897925035, 0.09235590350415025, 0.24970655941537448, 0.25475811692220823, 0.1909449246845075, 0.12879224334444317, 0.07456325646489859, 0.31587390175887514, 0.07145961014819996, 0.10151151221777711, 0.060325603666050095, 0.07108403423002788, 0.03285989710795028, 0.055900710568364174, 0.02064792239772422, 0.035886963962444236, 0.07798865051673991, 0.02368015968906028, 0.08658625238708087, 0.1000482989475131, 0.04045436637742179, 0.10254076163151435, 0.09456209226378373, 0.14385563933423587, 0.030769059301487038, 0.03428442370412605, 0.06573768718434231, 0.03233065675677998, 0.062468166196984906, 0.22273802225078854, 0.06845330646527664, 0.0575929938682488, 0.09404188660638672, 0.15120268080915722, 0.20082425884902477, 0.24059527260916574, 0.13574695587158203, 0.20545299404433795, 0.047137719179902754, 0.018903724383562803, 0.0201959790595408, 0.05557002991970096, 0.0697071577555367, 0.06856738177261182, 0.059714596452457566, 0.06696237503950085, 0.09635403539453234, 0.03412551758810878, 0.056121275161526034, 0.012137601335000778, 0.2649784827870982, 4.870721084730966, 38.88722971507481, 60.698705536978586, 69.94502776009696, 65.23173809051514, 56.52508592605591, 55.588027545383994, 37.16143267495291, 23.765177249908447, 24.361954552786692, 34.67678812571934, 23.975217819213867, 26.650441033499582, 38.52334908076695, 46.24182844161987, 40.43052189690726, 21.13493319920131, 10.047701392854963, 0.2869398929178715, 0.12472313669111047, 0.1208627609802144, 0.1605250598596675, 0.42329492473176544, 0.6656620694058282, 1.056186005473137, 1.512949941413743, 1.9514165563242776, 2.7898997579302107, 2.5430228795324052, 4.88258513382503, 5.96896117074149, 4.801702456814902, 5.177287331649235, 4.866247747625623, 7.776413440704346, 6.851124439920698, 18.94737798827035, 9.687865478651863, 4.875490588801248, 4.823626628943852, 6.586966957364764, 6.730747767857142, 5.459982173783438, 4.491666453225272, 2.5730497368744443, 2.967290524925504, 4.5342185241835455, 4.711378480706896, 2.2369384467601776, 0.523406442786966, 1.3090910975422179, 1.0065383038350513, 10.631510751588003, 54.75531721115112, 77.78293623243059, 71.68317522321428, 75.73662921360561, 74.25482164110456, 67.00732939583915, 44.21677596228463, 10.264967220170156, 1.872011457170759, 1.2315145688397544, 2.2134811111858914, 2.366630047559738, 3.083873914820807, 3.177746683359146, 3.529947830098016, 3.5601347131388525, 3.267738448722022, 0.4979826584458351, 2.2223172656127383, 1.7157111870391029, 2.9437643587589264, 2.623215730701174, 2.425652171884264, 1.805586787206786, 1.7765786009175437, 1.5858241681541716, 2.2702101128441945, 1.6765025023903166, 2.591261399643762, 1.54021141571658, 0.8545841319220406, 0.22874292145882333, 0.3614269159734249, 0.021417616899790506, 0.014048188858266388, 0.020997790320377265, 0.10302064195275307, 3.2653152644634247, 21.45745641844613, 36.69327000209263, 42.59716476712908, 29.2587183543614, 69.61110428401402, 73.56184305463518, 26.64703815323966, 23.61581529889788, 36.19715820040022, 33.773199217660085, 37.196746894291465, 60.86378083910261, 56.725826331547324, 69.14025960649762, 69.9735084261213, 79.62356267656598, 51.917454038347515, 5.764866088117872, 0.15901407093874045, 0.02901250177196094, 0.08926841989159584, 0.09014751629105636, 0.03282648943630712, 0.037419414946011136, 0.05506782240367361, 0.0852921503995146, 0.02355650346726179, 0.042608508108449836, 0.14136313593813352, 0.1888637085046087, 0.05045891400160534, 0.18358302329267773, 0.08970542358500616, 0.14313864495073045, 0.12390018227909293, 0.10713405694280352, 0.15736760571599007, 0.04386122624522873, 0.16049177093165262, 0.141668829534735, 0.06705183988170964, 0.41800558141299654, 0.11781156542045729, 0.08936371334961482, 0.06685254057603222, 0.10340146294661931, 0.06130768811064107, 0.1360020443264927, 0.037267284002155066, 0.023541155005139962, 0.020585468338270272, 0.0449691246529775, 0.08827328721859626, 0.192703497463039, 0.10751181774373565, 0.2325173132121563, 0.20326418935188226, 0.3109010543142046, 0.07342531931187425, 0.12493817800922052, 0.21923652371125563, 0.2998297783945288, 0.19304936033274445, 0.3607900158635208, 0.18016721015529974, 0.19157338381877967, 0.22034670199666703, 0.29664801912648336, 0.5367434556995119, 0.6927886509469577, 0.29451511214886394, 0.46360666304826736, 0.20915187842079572, 0.15554371715656348, 0.1532126236706972, 0.1754957815366132, 0.18474053618099007, 0.31366109049745966, 0.08786632227046148, 0.18556098001343863, 0.19577293204409735, 0.09836222085037402, 0.11755232433123247, 0.15688271102096352, 0.44729313414011684, 10.6761303458895, 48.46525893892561, 69.76949541909354, 77.60827241625104, 74.4912827355521, 65.33984511239188, 60.2443767275129, 39.55599730355399, 31.38473163332258, 32.907825401851106, 31.4151508467538, 38.06929472514561, 50.17789956501552, 51.4739157812936, 65.748183795384, 58.03289713178362, 30.59297398158482, 12.981858781405858, 1.646039211324283, 0.347275118210486, 0.25105331572038786, 0.3848783347223486, 0.5497545003890991, 0.7372525078909737, 1.405418860060828, 1.502342539174216, 2.5635491609573364, 4.9034145304134915, 3.690274689878736, 7.7027017389025, 10.934585094451904, 7.143207601138523, 10.51320811680385, 12.35158942426954, 19.53605716569083, 13.10386654308864, 25.72993152482169, 22.694185393197195, 10.0083589553833, 17.281182595661708, 22.48000717163086, 19.617877415248326, 11.183721440179006, 15.102062497820173, 9.376739042145864, 10.44154873916081, 12.665621076311384, 16.54220519747053, 13.332611663000923, 14.153490952083043, 12.68663763999939, 4.887061945029667, 10.691535370690481, 50.03717075075422, 68.02178028651646, 65.07548005240304, 71.65246418544224, 65.880831854684, 56.81279345921108, 37.349635056086946, 12.44019285270146, 13.201476573944092, 11.896208831242152, 13.272054638181414, 10.120528067861285, 5.039765111037663, 9.781660948480878, 11.407997131347656, 20.221189498901367, 12.415255767958504, 4.958982748644693, 9.60598269530705, 9.466832859175545, 9.483839443751744, 6.684870115348271, 4.416996768542698, 3.50787644301142, 5.426699868270329, 4.1987282293183465, 5.298634145941053, 3.512742353337152, 2.3946764511721472, 1.2434080392122269, 0.7096959522792271, 0.293743373560054, 0.23917477311832563, 0.1907440104654857, 0.16999766656330653, 0.1499167483832155, 0.6406240729349, 6.101531497069767, 33.13040746961321, 54.376793248312815, 66.50284154074532, 44.52315330505371, 102.15780748639787, 91.77517686571393, 34.859331199101035, 25.386501176016672, 39.689951624189106, 40.11116879326956, 39.944537094661165, 68.08407088688442, 65.17469338008335, 77.06818199157715, 79.1333394731794, 92.02101108006069, 61.76239136287144, 6.5342318671090265, 0.2714271710387298, 0.10523720551282167, 0.1823406663856336, 0.22627948650291987, 0.10126380622386932, 0.13788746244141034, 0.2631532778697354, 0.26194705973778454, 0.07524154721094028, 0.1348505975412471, 0.3110714208866869, 0.4951670638152531, 0.34735043559755596, 0.4558063330394881, 0.4385868784572397, 0.2436876009617533, 0.16048004584653036, 0.3135657970394407, 0.3267706584717546, 0.4328240534024579, 0.3517612660569804, 0.39228332308786257, 0.21286151079194887, 0.611530391233308, 0.4215591778712613, 0.1620219081108059, 0.19518515786954335, 0.3115284549338477, 0.09415802466017859, 0.21200963721743651, 0.14381047604339464, 0.08382120861538819, 0.2399749830365181, 0.15102349328143255, 0.22466411175472395], [0.023268692661076784, 0.044560789064105065, 0.07584646118006536, 0.13954570703208447, 0.025097295342545425, 0.060565282590687275, 0.0800647030451468, 0.04324249730312398, 0.03384320291557482, 0.06815433715070997, 0.04467882362327405, 0.08365871983447246, 0.033140559547713826, 0.07645907652165208, 0.0766941210521119, 0.13991956625665936, 0.08419231298778738, 0.11513922310301236, 0.10393102560192347, 0.041718188739780865, 0.07030230082039322, 0.03318794843341623, 0.12509874653603348, 0.14047824484961374, 0.1887470819056034, 0.043699887581169605, 0.025027195889768854, 0.051237529542829306, 0.17469125613570213, 0.06196143624505826, 0.1425837797245809, 2.7893506331103186, 29.743785994393484, 62.42036492483956, 64.13104615892682, 55.58477578844343, 41.35765477589199, 35.88129309245518, 23.529007979801722, 26.99341627529689, 30.242315769195557, 15.471882104873657, 14.530343873160225, 46.67861304964338, 31.669746739523752, 33.02000754220145, 32.080885546548025, 12.236169423375811, 3.2431878575256894, 0.08373998797365598, 0.1387692458395447, 0.06602328935904161, 0.06017282472125121, 0.07841772892113243, 0.13047647582633154, 0.2710048779845238, 0.6029276528528759, 0.47358954165663036, 1.9364748895168304, 0.9982940490756715, 0.988725619656699, 4.00580541576658, 4.142715760639735, 2.9411715950284685, 5.694058733327048, 2.337519483906882, 4.984133056231907, 4.699882251875741, 24.839108194623673, 9.236018913132803, 4.883535734244755, 5.732384996754782, 8.229175431387764, 8.985094274793353, 7.692371504647391, 5.65967036145074, 1.70126197380679, 5.162230585302625, 5.23317950963974, 6.71639061825616, 4.097056976386479, 2.7280725155557906, 3.1738426642758504, 5.741128436156681, 26.425885677337646, 50.52212374550955, 45.08576284136091, 51.748470374516074, 51.445810317993164, 55.05236659731184, 52.69585725239345, 57.094226769038606, 31.474613530295237, 6.822697622435434, 6.074627637863159, 6.692003309726715, 3.2776491854872023, 2.139812618494034, 3.63169573034559, 4.671404191425868, 4.1659084132739475, 2.368055513926915, 2.798367223569325, 1.3453967379672187, 0.6063428010259355, 0.6810493437307221, 0.9535780485187257, 0.9026641462530408, 1.3691794446536472, 1.1633445982422148, 1.8276621912206923, 1.1654651015996933, 1.405666932463646, 1.9249380571501595, 1.12347811460495, 0.23215711968285696, 0.39124972426465576, 0.10791304228561265, 0.22896686515637807, 0.15355383179017476, 0.0738399720617703, 0.03601051161863974, 0.03893783721806748, 0.6109186240604946, 9.054451193128314, 32.37749719619751, 49.31481170654297, 76.07839025769914, 90.71172033037458, 66.54970019204276, 22.79459207398551, 38.047338417598176, 69.52694770268032, 26.07678038733346, 34.940729345594136, 40.86841126850673, 49.63315732138497, 52.40336241040911, 62.093973296029226, 72.47198336465019, 36.353419712611604, 1.1678266205957957, 0.06415477355143853, 0.03579481890691178, 0.07863346913031169, 0.08163241749363286, 0.03296498182628836, 0.030397513881325722, 0.06286759262106248, 0.06588571638401065, 0.07505476687635694, 0.04413161227213485, 0.12471168301999569, 0.10493171547672578, 0.1317688136228493, 0.2635010134960924, 0.031770733052066395, 0.0922456890610712, 0.16677546660814965, 0.08454560581594706, 0.18301595800689288, 0.10919735979821, 0.16627074511987822, 0.13825776614248753, 0.13103033682065351, 0.06974964083305427, 0.038990009775651355, 0.10308879401002612, 0.07207730771707636, 0.01708403256322656, 0.012996729297031249, 0.029773187025317123, 0.01899461754198585, 0.07351204965795789, 0.04709593499345439, 0.0156797839860831, 0.03372283758861678, 0.03919263729559524, 0.10409086809626647, 0.1167648301592895, 0.023056940541469624, 0.03169785160571337, 0.08616942832512514, 0.032252306318176646, 0.06273757174078907, 0.10320496599056891, 0.040520045174551864, 0.04492425313219428, 0.027710396463849714, 0.1172634991151946, 0.009390650699580354, 0.027770178791667734, 0.06113957427442074, 0.06399315329534666, 0.1173072239117963, 0.06973718293011189, 0.0911087832812752, 0.08273966450776372, 0.07035108748823404, 0.08958349762750523, 0.1138983318316085, 0.07617515711379902, 0.020923724830416695, 0.033730783233685155, 0.15774172278387205, 0.07070650413100209, 0.0870414272482906, 3.8743164028440202, 37.9984404700143, 70.89629173278809, 72.18346636635917, 62.92595059531075, 50.76243414197649, 44.677861894880024, 35.54308257784162, 35.18489251817976, 35.94842658724104, 23.6300938470023, 17.599833931241715, 38.903415543692454, 29.187992640904017, 27.455528804234095, 27.766540595463344, 12.168445331709725, 2.404179415532521, 0.027635006134265235, 0.10143816258226122, 0.10147574663694416, 0.17870773561298847, 0.7422399574092456, 1.0577223173209598, 1.6408866878066743, 2.4277190438338687, 3.0436004187379564, 4.1968357137271335, 4.442455836704799, 4.069635476384844, 6.077833362988063, 5.417426628725869, 6.34140328850065, 4.778711301939828, 4.633093995707376, 6.312826216220856, 7.103370538779667, 12.786097628729683, 6.73136442048209, 2.397987050669534, 3.8337354489735196, 2.601076598678316, 4.025806239673069, 2.2646678388118744, 2.795091365064893, 2.055364429950714, 2.1722363872187476, 4.448077363627298, 4.0697479503495355, 5.973190886633737, 5.658177367278507, 4.832964139325278, 7.757364085742405, 33.75815289361136, 60.862891469682964, 55.156259536743164, 58.18748412813459, 57.05425378254482, 61.25178214481899, 62.024616377694265, 65.33472429003034, 34.48385402134487, 7.1413619858878, 3.404200851917267, 2.801746653659003, 2.072638954435076, 1.692777354802404, 1.7511781581810542, 1.8140268943139484, 1.6913782698767525, 1.320310266954558, 2.1269488973276953, 2.3881019353866577, 1.5542325547763278, 1.8863490649632044, 1.8619276668344225, 1.4335188950811113, 2.267248660326004, 2.9890646593911305, 3.5773464867046902, 3.0022256331784383, 3.0529003654207503, 3.5059098856789723, 3.0987517450537, 2.5273903012275696, 1.6605984015124184, 0.589273139834404, 0.494807168841362, 0.3522263882415635, 0.05222133746636765, 0.023761846823617816, 0.04549902657579098, 0.4565591812133789, 7.703448670251029, 25.271756887435913, 41.33214099066598, 73.23477745056152, 86.36183534349713, 52.94491195678711, 20.524339403424943, 46.08400011062622, 69.62124170575822, 27.829732724598475, 47.16373974936349, 49.17464222226824, 58.11321483339582, 58.12473494665963, 68.36622333526611, 82.664705821446, 46.75028371810913, 2.495865889957973, 0.042625681829771826, 0.03301754793418305, 0.05470006999426654, 0.058499028107949665, 0.04673081190724458, 0.015737349200727682, 0.08589919496859823, 0.009381656717908169, 0.020661428637270416, 0.010737824303630208, 0.09863468658711229, 0.06586904477860246, 0.10307115209954125, 0.03339188213327101, 0.06077827473304101, 0.08558467363140412, 0.17871460238737719, 0.12641981350524084, 0.13352328804986818, 0.08784118254802056, 0.24284385623676435, 0.12225896891738687, 0.07741665228136949, 0.10686952328043324, 0.039383746683597565, 0.07929929518806082, 0.04098627676389047, 0.017825401620939374, 0.11398667709103652, 0.04312192502298525, 0.10180077169622694, 0.039080159938228984, 0.058601059418703826, 0.033461411616631916, 0.2119303843272584, 0.11290170638156788, 0.24698015142764362, 0.39443843173129217, 0.16556303309542791, 0.13005144149065018, 0.25702860366020885, 0.16442291784499372, 0.16810435030077184, 0.21156438253819942, 0.16255970139588627, 0.10726120761994805, 0.17558005558592932, 0.275111371917384, 0.24097340660435812, 0.32627036103180473, 0.30381565594247406, 0.37529986298510004, 0.36212059589368956, 0.13021807612052985, 0.36242175687636646, 0.16380298111055577, 0.28045214819056646, 0.25042211530464037, 0.21898169309965201, 0.12508502655795642, 0.11532715016177722, 0.13770488223859242, 0.2381764581160886, 0.22749968245625496, 0.2449634639280183, 7.103952016149249, 48.51510878971645, 80.35488837105888, 82.24795286996024, 72.03615760803223, 59.185387883867534, 50.146660464150564, 36.09698254721505, 38.462340423039024, 43.74516003472464, 26.90462871960231, 21.48582591329302, 63.099954332624165, 43.7004587990897, 45.24565826143537, 43.26607826777867, 17.542667627334595, 4.662073194980621, 0.32182940361755236, 0.2511382411633219, 0.2967312346611704, 0.2659303588526589, 0.6994971366865295, 0.7072266819221633, 1.066906858767782, 2.035672583750316, 3.6772020884922574, 7.901102338518415, 7.062311896256038, 5.984623713152749, 9.881220817565918, 12.81063345500401, 11.24370002746582, 16.537103482655116, 10.58599397114345, 13.791565367153712, 15.143743004117693, 40.068767411368235, 19.25409405572074, 13.568301507404872, 15.275373152324132, 15.260410206658499, 20.556617259979248, 13.998756306512014, 14.114759087562561, 6.235047646931239, 10.123850175312587, 13.272508876664297, 13.864735109465462, 9.38712920461382, 6.942422900881086, 5.229694988046374, 7.294651406151908, 38.14087159293038, 59.25508526393345, 60.014954158238, 61.309737069266184, 62.323743275233674, 64.46054363250732, 64.54252542768205, 68.13448006766183, 36.73505299431937, 10.047402620315552, 11.115416305405752, 12.216814347675868, 7.761637227875846, 8.39988398551941, 6.483636822019305, 14.840183155877249, 14.690294878823416, 4.48905827317919, 6.6057761652129035, 3.839556302343096, 3.943102700369699, 6.03330887215478, 5.860728647027697, 3.3463625269276753, 4.5037007331848145, 4.759402692317963, 5.6980752263750345, 3.9662597434861318, 4.420124760695866, 6.467802745955331, 5.606252610683441, 3.064125180244446, 1.088021131498473, 0.5600094443985394, 0.3630981748657567, 0.3272682689130306, 0.2300556424473013, 0.1102433418855071, 0.16546982952526637, 0.9872672579118184, 12.864627037729536, 41.94788687569754, 61.41224384307861, 81.65973227364677, 92.41790607997349, 80.9678237097604, 33.22866889408657, 47.49109370367867, 74.8705918448312, 37.39943279538836, 50.82358523777553, 55.8667892728533, 65.87589863368443, 69.4068272454398, 78.11692919049943, 94.8791595186506, 54.57612664358956, 3.47906117779868, 0.22341035545936652, 0.19103949889540672, 0.21061849115150316, 0.15590856543609075, 0.1502609827688762, 0.21627747320703097, 0.32850903804813114, 0.11794643104076385, 0.1455501719777073, 0.16737535941813672, 0.3005461756672178, 0.20044266432523727, 0.30887769002999577, 0.36499704154474394, 0.13538765800850733, 0.177770678752235, 0.2906931143786226, 0.41037048825195854, 0.4197236863630158, 0.31156325020960396, 0.3344943140234266, 0.23179622047713824, 0.404362467782838, 0.23768167038049015, 0.17637292375522, 0.1580804746065821, 0.17704798467457294, 0.08743491649095501, 0.18724198266863823, 0.15231519325503282, 0.22144022903272084, 0.2706796968621867, 0.16251077902104172, 0.12496614722268921], [0.0404167551813381, 0.060238873319966454, 0.1184274038033826, 0.014394772671429175, 0.012492526888049074, 0.042207354812749794, 0.0984451649710536, 0.006655411154497415, 0.061458770717893324, 0.0482054686705981, 0.043701041090701304, 0.047139463014900684, 0.04417708429640957, 0.018652730887489657, 0.028030897390895655, 0.06667382802282061, 0.06503415493560688, 0.007144173075045858, 0.051671788562089205, 0.03666543361863919, 0.03638403496838041, 0.11900025020752635, 0.12309662039790835, 0.16302675061992236, 0.21848351268896035, 0.03462249020646725, 0.03204261864136372, 0.08129032049328089, 0.10639907459595374, 0.08978661708533764, 5.267886195863996, 30.425692626408168, 53.92701203482491, 63.4941325868879, 56.16429724012102, 50.95095614024571, 36.358592646462576, 19.00614411490304, 17.63864483152117, 13.087400180952889, 16.740633589880808, 24.944878884724208, 49.13957813807896, 35.40660606111799, 39.91253021785191, 41.76013960157122, 6.142428159713745, 0.24934376031160355, 0.11714075213032109, 0.10289153709475483, 0.059716964539672644, 0.05705510558826583, 0.08880265988409519, 0.4313444127993924, 0.933002152613231, 1.0738088084118707, 2.0877063402107785, 2.1747043005057742, 0.9707741886377335, 3.4255428952830176, 3.578335953610284, 7.145562171936035, 3.686146591390882, 5.60830363205501, 3.4134137289864674, 3.63787984422275, 3.551068833896092, 3.8298336012022833, 12.403718284198217, 5.796273682798658, 4.335750179631369, 2.706805382456098, 1.422939502767154, 3.5624749532767703, 3.9012537002563477, 4.386637483324323, 4.504016441958291, 9.212672097342354, 16.606724432536534, 23.94411073412214, 25.26355106489999, 24.291795117514475, 25.83810976573399, 38.705972058432444, 37.054392201559885, 41.887864862169536, 37.92015859058925, 50.63203729901995, 46.43988684245518, 50.51088503428868, 42.42555815832955, 46.65095574515206, 43.47840479442051, 22.04818184035165, 12.828810811042786, 10.143129689352852, 13.265642319406782, 10.86063367979867, 10.308408226285662, 7.474128586905343, 9.541690145220075, 9.688766138894216, 17.70273675237383, 18.123512710843766, 11.867646523884364, 12.893590603555952, 9.284872565950666, 6.9633482694625854, 3.226114179406847, 3.0212076774665286, 2.517546658005033, 0.6179243624210358, 0.9837833877120699, 3.6400394311973026, 3.8210905960627963, 2.197840064764023, 1.2740422125373567, 1.3242618377719606, 0.28872796839901377, 0.08292541346911873, 0.294863472027438, 0.07575711168880973, 0.3536009373409407, 0.05578868443678532, 0.40309556147881914, 3.928752498967307, 20.64116815158299, 41.73024150303432, 57.36464371000017, 29.074882916041783, 45.429208823612754, 25.160238300051006, 21.272707292011805, 23.58538740021842, 16.40264889172145, 25.151186534336635, 35.40798527853829, 50.20692566462925, 53.921637603214805, 60.33720466068813, 56.61609690529959, 23.672828742436, 0.2722353876701423, 0.04422706179320812, 0.06931143613266093, 0.08691659037555967, 0.03754390915855765, 0.005531675315329007, 0.056179866660386324, 0.04704718564503959, 0.06511540950409003, 0.027772933643843447, 0.03460576431825757, 0.04699398171422737, 0.026611671849553074, 0.08436914599899735, 0.03306955425068736, 0.05723265106124537, 0.12787324908588613, 0.12207291461527348, 0.10733120529247181, 0.15121118963829108, 0.1937993179474558, 0.1040737893698471, 0.04976915940642357, 0.04183196209903274, 0.014064315939322114, 0.03873819525220564, 0.034405002769614966, 0.06914068279521805, 0.0837641709617206, 0.08993214249078717, 0.06217625364661217, 0.14615425813410962, 0.10333821669753109, 0.049905758683702776, 0.06064852526677506, 0.038603475516928096, 0.0702687744051218, 0.053442686929234436, 0.04733957316992538, 0.045240976315523894, 0.07791414737169232, 0.03484499880245753, 0.04025105353710907, 0.04895837791264057, 0.039573217409529855, 0.08093995893640177, 0.028462440573743412, 0.02497554410781179, 0.049862220484231196, 0.003996578045189381, 0.061078282206186225, 0.042125828830259185, 0.008250582098428692, 0.0730516840038555, 0.06601743360183068, 0.07877803101603474, 0.1731505338102579, 0.17411367355712823, 0.1076977499095457, 0.04464972125632422, 0.03944491661552872, 0.21312748294855866, 0.18750901333987713, 0.18724629815135682, 6.453617130007062, 35.45443051201956, 63.17929581233433, 73.23317241668701, 64.3239073072161, 61.21967451913016, 43.94088036673409, 27.242552621023997, 22.14042612484523, 19.999637501580374, 27.727672372545513, 29.408615316663468, 35.65206854684012, 36.840999126434326, 34.14344440187727, 28.662116493497575, 6.024517663887568, 0.23465472566229956, 0.116077596321702, 0.1058959544503263, 0.12608216090926103, 0.2553108244069985, 0.5027906490223748, 1.2666216450078147, 1.9787740026201521, 3.1123076805046628, 3.672907667500632, 5.499150037765503, 4.947611587388175, 6.74415214572634, 5.6309955801282605, 6.646077019827707, 5.0819050669670105, 7.9615038973944525, 5.931137348924365, 3.177809000015259, 3.998948846544538, 5.573662953717368, 6.712708941527775, 6.858883840697152, 4.550443436418261, 3.312576477016721, 2.9038315415382385, 4.073210324559893, 3.010779082775116, 4.866497014250074, 6.486971523080554, 11.247311353683472, 18.52344059944153, 23.976395538875035, 28.63933161326817, 29.50140850884574, 31.726989473615372, 41.364425795418875, 43.64711400440761, 47.49908413205828, 46.17446913037981, 56.574491092136924, 54.32849631990705, 59.54129546029227, 51.37172862461635, 53.44614110674177, 49.61638784408569, 27.228762183870586, 16.86020166533334, 12.113267081124441, 14.659613370895386, 11.326163853917803, 10.535759363855634, 8.754900455474854, 10.50236371585301, 11.302584273474556, 20.162854160581315, 21.23663224492754, 15.09121983391898, 14.526707359722682, 11.84705206326076, 9.139465008463178, 5.436231928212302, 5.0077769075121195, 2.333960052047457, 0.8009142375418118, 1.3011425754853656, 2.625452399253845, 2.813663899898529, 3.2351635566779544, 3.2517078689166476, 2.8881809413433075, 2.3658931042466844, 0.7880589302097047, 0.8892831642712865, 0.07226582510130745, 0.14486823071326527, 0.03537330956065229, 0.19147752039134502, 3.656197249889374, 17.29043585913522, 43.411521434783936, 61.5164737701416, 38.55550534384591, 37.74408081599644, 18.329782145363943, 31.304671015058243, 31.559152262551443, 30.619554315294536, 35.36766140801566, 41.33748762948172, 59.04275526319231, 61.93828501020159, 65.72296183449882, 69.09425558362688, 32.735687255859375, 0.48214103707245415, 0.08033573028764554, 0.03718991404665368, 0.08435658631580216, 0.04078302499172943, 0.0421917383292956, 0.09700530687613146, 0.07473044070814337, 0.05265022588095494, 0.05711013477827821, 0.04027641039075596, 0.054933513182082346, 0.23872672287481173, 0.045762003000293455, 0.049832049424627, 0.061503465819571695, 0.1251667628863028, 0.12585327747677053, 0.10038568012948547, 0.11445648116724831, 0.13114732982856886, 0.052557069808244705, 0.008934868549528931, 0.052966711577028036, 0.06875176687857934, 0.062428390474191735, 0.034036073101950545, 0.040327789062368016, 0.06017136587096112, 0.041859469908688746, 0.0505601412483624, 0.11197764346642153, 0.10729434727025883, 0.0702489951093282, 0.15452733955213002, 0.2094125851456608, 0.31952306308916634, 0.0882777316229684, 0.15627535432577133, 0.1961370339351041, 0.19461119866796903, 0.11071772607309477, 0.12249005080333777, 0.23086926021746226, 0.10451227905494825, 0.23883580416440964, 0.15976615915341036, 0.10274123480277401, 0.13985515971268925, 0.2037936095148325, 0.23813417181372643, 0.18588830530643463, 0.1704893737499203, 0.19214063909436974, 0.17423636625920022, 0.2218108448599066, 0.2637534828058311, 0.30075912709747044, 0.24843729180949076, 0.1483831506754671, 0.14441597355263575, 0.2614586502313614, 0.18507605817701134, 0.24575960263609886, 8.775086709431239, 46.54200104304722, 72.47886902945382, 80.52500111716134, 72.72607898712158, 67.67891447884696, 50.79730020250593, 31.27763557434082, 26.9133973462241, 20.03756250653948, 26.046927452087402, 35.12969255447388, 65.48981503077916, 48.994371209825786, 53.19915696552822, 54.64368397848946, 8.839256797518049, 0.7291937917470932, 0.23007860407233238, 0.3496081387358052, 0.15344423481396266, 0.23781718739441463, 0.35515942371317316, 0.894193749342646, 1.7356796583959033, 3.8429144535745894, 8.382382341793605, 7.553427508899143, 8.146722027233668, 12.029701096670967, 10.64349639415741, 17.21663556780134, 13.161882264273506, 15.426585061209542, 10.68507354600089, 13.848016006605965, 7.641650523458209, 13.558645248413086, 27.143988949911936, 14.586361987250191, 11.273502588272095, 7.162509262561798, 6.927401764052255, 6.861682227679661, 8.666495050702776, 8.349575553621564, 8.697438853127615, 13.343503832817078, 21.07658917563302, 27.843149696077617, 31.293046678815568, 33.84800352369036, 34.250853129795615, 44.30072062356131, 50.18492766789028, 52.37703568594796, 52.49612086159842, 62.3880558013916, 58.360636711120605, 64.36485998971122, 56.86071171079363, 60.78763553074428, 51.48407404763358, 28.975292648587907, 18.2302439893995, 14.880116190229144, 17.607306718826294, 16.07825834410531, 17.26471710205078, 12.27748601777213, 13.684583953448705, 14.13820491518293, 22.81283630643572, 24.62731146812439, 18.03538349696568, 20.56215497425624, 16.012243509292603, 13.71126069341387, 9.788081083978925, 8.08775006021772, 6.7763635601316174, 4.189289101532527, 4.211379596165248, 10.038032974515643, 10.234184094837733, 6.977338901587895, 5.217028422015054, 3.392876591001238, 1.905276392187391, 0.6400124686104911, 1.093492295060839, 0.31183100012796267, 0.6359872903142656, 0.26588134148291176, 0.7043372626815523, 5.202404201030731, 27.609467881066458, 49.46948208127703, 66.25724356515067, 39.17433622905186, 63.324811935424805, 32.990943227495464, 29.913804939814977, 32.770897252219065, 27.669507265090942, 36.802471365247456, 51.82244437081473, 66.40369074685233, 72.36843436104911, 74.87825570787702, 79.68616594587053, 40.37705550874983, 0.998758601290839, 0.1728116734219449, 0.1735776173216956, 0.18708472539271626, 0.08627657578991992, 0.12347033034477915, 0.1829333124416215, 0.2065739474658455, 0.12626824235277517, 0.20279353032154696, 0.2886645660868713, 0.1775863343583686, 0.3467850802200181, 0.2891085722616741, 0.14004969570253575, 0.3067062422633171, 0.17471461131104402, 0.3060897524867739, 0.2786833702453545, 0.23339970729180745, 0.29913362860679626, 0.21208306827715465, 0.26662420162132805, 0.1513462181070021, 0.0913133615893977, 0.09378170235348599, 0.1212988690074001, 0.15601854239191326, 0.169699830402221, 0.23480253773076193, 0.23433556993092808, 0.21296951999621733, 0.21485227825386183, 0.18750552566988127], [0.03436019231698342, 0.03451387371335711, 0.03395438087838037, 0.051705179270356894, 0.057924627858613215, 0.037964214105159044, 0.04527389544195362, 0.03450315286006246, 0.012145653849334588, 0.03753711702302098, 0.01906805538705417, 0.0730214077713234, 0.073909202989723, 0.032679077703505754, 0.09889735427818128, 0.04200895456597209, 0.07846587776605572, 0.03628244470538838, 0.030940416535096507, 0.031184020784816573, 0.026651483195434724, 0.05348011492086308, 0.09854158479720354, 0.04752399559531893, 0.025134942161717584, 0.12191921286284924, 0.05001271615869232, 0.03577600991619485, 0.19721958227455616, 0.7428966164588928, 21.015276534216746, 51.28249985831124, 63.54821736471993, 62.733200618198936, 56.292171886989046, 29.447132655552455, 42.466149534497944, 33.19168710708618, 20.263239996773855, 24.833167484828405, 22.99709905896868, 35.17167704445975, 37.75116103036063, 44.008086817605154, 22.524673666272843, 2.9573546009404317, 0.0625762025426541, 0.12053285725414753, 0.0057332290536058796, 0.042419186660221646, 0.12183400243520737, 0.2339969538152218, 0.730323851108551, 1.0712534998144423, 1.8183062246867587, 3.111916410071509, 3.7613187176840643, 4.247779037271227, 1.04752779006958, 4.253070524760655, 2.9148587669645036, 5.49031366620745, 2.9369488273348128, 5.152401924133301, 4.777774163654872, 3.1431337978158678, 6.152373203209468, 9.443023119653974, 10.854306476456777, 8.326980011803762, 5.273579810346876, 4.454540491104126, 3.954542475087302, 7.36781941141401, 8.254098619733538, 15.573704481124878, 23.46138984816415, 26.14751304898943, 34.529941422598704, 49.333005564553396, 44.24726813180106, 35.682883807591026, 55.703777585710796, 52.46414177758353, 34.27736745561872, 35.556631565093994, 42.42007950374058, 47.317774363926475, 39.41839517865862, 43.55814926964896, 43.74774823869978, 40.599495138440815, 32.886310304914204, 48.914185523986816, 26.974744728633336, 31.769185883658274, 38.634301389966694, 33.77657951627459, 34.35361698695591, 34.28420100893293, 37.94299384525844, 37.62892484664917, 49.93071045194353, 45.935652596609934, 43.7481929234096, 40.70156070164272, 38.854632241385325, 38.08850996834891, 33.75418894631522, 21.899608509881155, 10.977957487106323, 4.379310173647744, 1.9028612417834145, 0.6960023013608796, 1.429493173956871, 2.682126900979451, 4.149944492748805, 2.0111324148518697, 1.9567154262747084, 0.5719312503933907, 0.5099746521030153, 0.1374197753944567, 0.08655629506600754, 0.04575582493894866, 0.07797648438385554, 0.020233985502272844, 2.5448778314249854, 8.676156520843506, 30.120472158704484, 38.63496841703142, 45.4081140926906, 59.949807848249165, 31.292511667524064, 17.4273362159729, 18.799266713006155, 17.847448621477398, 29.456325122288295, 34.45790249960763, 44.82449320384434, 54.445472717285156, 62.8448303767613, 49.80834572655814, 6.4679034948349, 0.26989053349409786, 0.044511775087032995, 0.02274272115235882, 0.07129995085831199, 0.06376235639410359, 0.013356286699750593, 0.02260321095984961, 0.04804479157818215, 0.09579959086009435, 0.03524070006928273, 0.04588048539257475, 0.03276755527726241, 0.009148855593853762, 0.057377993262239864, 0.036894089741898436, 0.020899853968460644, 0.06190871407410928, 0.11520730730678354, 0.04043418335329209, 0.11851019864635808, 0.06473766905920846, 0.021832688645060574, 0.015531795498515879, 0.013944439157577497, 0.04967500249456082, 0.03237841883674264, 0.04900128168186971, 0.04642799190644707, 0.037467288984251876, 0.07290385836469275, 0.07877331519765512, 0.043354435225150416, 0.10756112688354083, 0.06592501713229076, 0.012160625724521066, 0.050159876833536794, 0.034271619748324156, 0.02411665108853153, 0.04688733975802149, 0.028144719943936383, 0.028923382982611656, 0.030174666017826115, 0.04828611595023956, 0.0018503198308670627, 0.02292385437924947, 0.06994279939681292, 0.014141192260597433, 0.03046048871640648, 0.0582213376515678, 0.04712278123146721, 0.038531988460038386, 0.04208246704989246, 0.004066698702185282, 0.03980217548087239, 0.0436130893815841, 0.09296103460448128, 0.030720784927585294, 0.09615768093083586, 0.05573587066360882, 0.019671714066394737, 0.042729575719152174, 0.14110609330236912, 1.0560877536024367, 27.333476747785294, 63.001150948660715, 72.90643337794712, 69.39361871991838, 61.25767421722412, 38.91985845565796, 46.466019017355784, 37.18625858851841, 24.561360904148646, 25.546634571892874, 26.087359019688197, 32.04778780255999, 37.20599147251674, 37.773805209568565, 21.362009014402116, 2.954567287649427, 0.04203508494954024, 0.05198221494044576, 0.17111273030085222, 0.1740998857255493, 0.7728802104081426, 1.408711003405707, 1.7295251829283578, 1.9244773047310966, 3.385244211980275, 6.168536015919276, 4.50777758870806, 4.763887320246015, 4.314454385212489, 4.323649457522801, 5.290600291320255, 6.31369343825749, 3.848407438823155, 2.809661303247724, 2.663916540997369, 4.557923172201429, 4.888795520578112, 8.223273805209569, 10.220906955855233, 9.698946118354797, 7.105292149952479, 5.13514563867024, 5.981429278850555, 8.0926468031747, 9.830592768532888, 18.174363102231705, 23.467497314725602, 29.50633478164673, 38.62068292072841, 52.91548980985369, 49.325664792742046, 39.98605258124215, 61.101763589041575, 55.16306529726301, 41.09880658558437, 41.99799033573696, 46.92137616021292, 51.8773455619812, 46.65455143792288, 50.44538089207241, 49.790679931640625, 45.78269842692784, 37.874606200626914, 51.889928749629426, 29.76121207645961, 34.87169204439436, 42.11596032551357, 37.20068999699184, 38.27065699441092, 36.59283379146031, 40.045192173549104, 41.95211138044085, 52.40099654878889, 48.22051559175764, 43.5857058252607, 42.44074692044939, 40.83118976865496, 39.1620900290353, 35.73503698621477, 24.680694477898733, 12.376001920018878, 5.753334249768939, 2.1467873070921217, 0.5182689556053707, 1.6202747481209892, 2.130614289215633, 5.492157544408526, 4.521171544279371, 3.432964005640575, 1.5076748473303658, 1.5162581524678638, 0.4140699697392327, 0.023530669942764298, 0.018336519998099123, 0.051814453942435126, 0.022168129216879606, 1.2697015425988605, 10.142751881054469, 33.164446694510325, 33.6356908934457, 42.64560065950666, 51.4896673474993, 30.564548901149205, 19.36466768809727, 18.462786299841746, 21.914691311972483, 40.59188686098371, 47.18877410888672, 51.04521887642996, 64.1242925098964, 68.58864212036133, 61.55387592315674, 10.541423014232091, 0.2225311097822019, 0.07265796405928475, 0.024289141475622143, 0.09567196520843677, 0.018157147569581866, 0.0244187128264457, 0.030451901855745485, 0.07974153717181512, 0.06360323314688035, 0.14394637303692953, 0.05260034337905901, 0.02884199270712478, 0.059219700151256154, 0.00788397471686559, 0.06432162531252418, 0.0454112105736775, 0.08667115747396435, 0.08205642724143607, 0.11982225467051778, 0.06765172590634652, 0.11353312392852136, 0.02887981424906424, 0.024437576099964123, 0.05331790433930499, 0.035808467638811896, 0.0491598790644535, 0.038229039537587335, 0.036424448514091115, 0.0710081672295928, 0.038288234932614226, 0.11524670304996626, 0.036887477418141704, 0.11329198615359408, 0.19368931385023253, 0.09154676406511239, 0.12238443004233496, 0.2261281053402594, 0.13407371565699577, 0.11820559070578643, 0.1380794064274856, 0.07239716912486724, 0.08763631246984005, 0.1215098255446979, 0.10686406107353312, 0.1457722700600113, 0.20831206919891493, 0.0847662789747119, 0.29601084760257174, 0.12192169630101748, 0.154673645272851, 0.17515172357005732, 0.08533404315156595, 0.17869387992790767, 0.17517521445240292, 0.149231224453875, 0.17946645990014076, 0.14109215619308607, 0.13126411927597864, 0.20317265497786657, 0.08392543837960277, 0.1909173218799489, 0.21821558635149682, 2.0468824165207997, 37.50440617970058, 70.85821560450962, 80.98795264107841, 79.23112147194999, 71.9747563770839, 41.03800984791347, 52.52161727632795, 42.312920910971506, 30.430684907095774, 36.20290436063494, 33.25993231364659, 46.240011487688335, 49.17667804445539, 57.48742880140032, 29.656322070530482, 4.142418725149972, 0.2768500771905695, 0.22502742654510907, 0.4053289730634008, 0.18716255335935525, 0.6660958975553513, 1.2876598132508141, 1.6504089768443788, 3.427297532558441, 5.6343298469270975, 11.376393250056676, 10.642374260084969, 12.290724073137556, 9.009508507592336, 11.759430067879812, 11.052289315632411, 14.714274849210467, 9.679292270115443, 12.223671351160322, 9.781893713133675, 9.863726122038704, 11.367906025477819, 16.789026056017192, 21.34012392589024, 15.771566595349993, 9.731884922300067, 9.577448180743627, 8.327964050429207, 12.915590337344579, 12.531744922910418, 21.494705711092266, 28.039625644683838, 32.03299856185913, 39.57961423056466, 51.3097367967878, 54.721625396183555, 45.02298934119088, 63.36618150983538, 59.254925455365864, 44.90324061257498, 46.048043182918, 52.13878543036324, 57.58729525974819, 53.109577315194265, 55.86684833254133, 55.04073183877127, 50.705993924822124, 41.706954615456716, 55.91061850956508, 34.294460024152485, 38.42606735229492, 42.95413194383894, 41.13435009547642, 38.46978194372994, 39.17903668539864, 42.37444373539516, 44.84655720846993, 54.41780151639666, 50.419387681143625, 47.676544598170686, 44.51491274152483, 44.59223229544503, 43.07955387660435, 40.10693734032767, 29.62067781175886, 14.737259490149361, 9.39048865863255, 7.217128617422921, 6.007284828594752, 6.098460827554975, 10.582254103251866, 11.418274385588509, 6.2809717655181885, 6.828348244939532, 2.7531904705933163, 2.0119001907961707, 0.24820374005607196, 0.2610538362392357, 0.08558942337653466, 0.19377654631222996, 0.08968837199998753, 3.2734262006623402, 13.633365307535444, 39.543639932359966, 50.84425960268293, 61.909074783325195, 82.9955165045602, 43.923263209206716, 28.381496122905187, 27.104121923446655, 29.102481160845073, 42.963268824986045, 50.352004051208496, 58.17231968470982, 73.18832179478237, 78.75848415919712, 72.48824214935303, 13.675310713904244, 0.4900162230644907, 0.16147411321955069, 0.13978394067713193, 0.15410214236804418, 0.1598829621715205, 0.1010234894763146, 0.21089688049895422, 0.17946063806968077, 0.22138259426823684, 0.22505775706044265, 0.2494990634066718, 0.22897449188998767, 0.09701882329370294, 0.11767063369708401, 0.18033925949462823, 0.13402221484908036, 0.23591609512056622, 0.31863667922360556, 0.21048771031200886, 0.21644417569041252, 0.20026938005217484, 0.19478792989892618, 0.07514653873762914, 0.2047543336770364, 0.2007261426853282, 0.11043804750910827, 0.1947165887270655, 0.1493329368531704, 0.12251135680292334, 0.09334053245506116, 0.19860877415963582, 0.15787529918764318, 0.17803984002343246], [0.06895343427147184, 0.045267564710229635, 0.03850951198754566, 0.021051040052303245, 0.03504958389593022, 0.01918902969919145, 0.04744246622015323, 0.033445286231913736, 0.037481911413903744, 0.027000660708706294, 0.06776697507926396, 0.0475691453154598, 0.02520373882725835, 0.029652363687221493, 0.0512163999623486, 0.025772653120969023, 0.019857442671699182, 0.04546478430607489, 0.06400516336517674, 0.032119924136038334, 0.0206319920918239, 0.05114168307877012, 0.0024360530993102914, 0.0962283503530281, 0.09989366081676312, 0.0050958743252392325, 0.04808165977842041, 0.07614587154239416, 0.1642468651490552, 15.46626969746181, 61.0098945072719, 63.93923418862479, 61.570961543491904, 46.36359562192644, 42.360151290893555, 30.035964693341935, 83.2976380756923, 56.68587418964931, 19.706095218658447, 24.286842788968766, 35.26998710632324, 38.61170584814889, 37.63292700903756, 24.074620485305786, 1.0676256716251373, 0.19292605694915566, 0.06943613729838814, 0.07030378002673388, 0.06135533483965056, 0.13412816130689212, 0.18219027588410036, 0.8234165757894516, 0.8107710172023092, 2.112248246158872, 3.067129190479006, 3.9892352649143765, 0.994530296751431, 4.694844373634883, 3.3835551483290534, 3.0587485773222785, 2.8669140253748213, 1.7289729097059794, 4.905297926494053, 8.969733544758387, 10.06127643585205, 6.980535507202148, 16.109469652175903, 25.376532248088292, 22.411579574857438, 20.5910473210471, 17.927010706492833, 12.779554162706647, 15.326352085386004, 25.200028896331787, 23.56066049848284, 38.62434114728655, 38.746309825352256, 48.965755053928916, 54.75672422136579, 67.76413413456508, 54.395032269614084, 49.89056723458426, 63.09621620178223, 59.92240415300642, 44.99090256009783, 33.745191029139924, 42.67784724916731, 41.59562015533447, 35.70783478873116, 40.87716599873134, 36.599177496773855, 32.94514070238386, 47.671389034816194, 48.362112930842805, 39.35117483139038, 49.22669117791312, 51.52330705097744, 57.05192961011614, 58.584827286856516, 51.44334718159267, 51.93894829068865, 55.71256010872977, 56.14838933944702, 58.227533544812886, 57.11622129167829, 52.36945172718593, 54.01234980991909, 56.0230507850647, 48.4631084714617, 45.26019041878836, 42.64166103090559, 33.633502210889546, 20.660878453935894, 8.66015134538923, 2.738208851643971, 2.1780559378010884, 2.8005756650652205, 3.7565722295216153, 3.7549889087677, 1.5548095809561866, 0.9188117597784314, 0.1776072603783437, 0.052658897558493276, 0.18721887176590307, 0.029106835102928535, 0.08626326293285404, 0.055363524572125504, 0.4770614696400506, 6.021852161203112, 49.12460477011544, 33.37105137961251, 27.080216646194458, 50.715464319501606, 52.915983131953645, 48.40432323728289, 28.370189666748047, 17.18331548145839, 24.949845109667095, 42.14197785513741, 45.467156410217285, 51.41954960141863, 56.548331124441965, 40.158367906297954, 0.845540237213884, 0.07647492709968771, 0.10689129746918168, 0.01828913450507181, 0.06578171053635222, 0.044219543625201495, 0.06209650542587042, 0.02975111428116049, 0.07870179760668959, 0.09631052094378642, 0.021559415451650108, 0.021859268558078578, 0.034124479429530244, 0.06771521642804146, 0.025931443886033127, 0.05593900029946651, 0.062136532206620486, 0.10435363756758825, 0.03582629614642688, 0.15991748603326933, 0.011869936233519443, 0.057205041471336565, 0.00589322718691879, 0.04532956924023373, 0.04357670972655926, 0.047421072011015246, 0.16070237463074072, 0.0413021416004215, 0.018813363875129392, 0.03765404557010957, 0.009196110468889986, 0.06109700298735073, 0.08039561778839145, 0.049080103702311, 0.05855213025850909, 0.03466572306518044, 0.049523332954517434, 0.07806869729288987, 0.024350674423788275, 0.040991382739905796, 0.03194567295057433, 0.12522519832210882, 0.047626515451286516, 0.061344057587640624, 0.016062733883570348, 0.012093328621371515, 0.0768869471337114, 0.051452557290238995, 0.03767530746491892, 0.02875666014317955, 0.02719654867957745, 0.045306271740368435, 0.09266193636826106, 0.10171692512397255, 0.04288662264921835, 0.03467119884278093, 0.06408191924648625, 0.043319056409278085, 0.02129163160654051, 0.04797244617449386, 0.04843432156901274, 0.3837427385151386, 21.90450177873884, 73.15428256988525, 71.72144590105329, 69.22691753932408, 55.22761753627232, 51.3692307472229, 36.258340563092915, 83.21906089782715, 46.72750404902867, 16.000881467546733, 23.973010029111588, 29.864132268088206, 37.016858032771516, 33.49752596446446, 21.323401348931448, 1.1270682705300195, 0.09199363365769386, 0.12205652120922293, 0.06536118167319468, 0.1627703458070755, 0.7276091139231409, 1.3361753927809852, 2.502666873591287, 2.8732043164116994, 3.171180852821895, 4.1309676596096585, 4.950039114270892, 4.20317507641656, 5.634760635239737, 5.833022270883832, 3.953381257397788, 2.4416799289839606, 3.810369525636945, 5.013669414179666, 8.972740377698626, 9.731990882328578, 11.555926016398839, 18.531698533466884, 25.842172724860056, 22.042873416628154, 17.90418413707188, 16.880924667630875, 13.658291101455688, 15.696572950908116, 24.479139396122523, 25.41175787789481, 38.69058527265276, 40.82905667168753, 50.315567697797505, 54.8404152733939, 65.64769894736153, 58.54201943533761, 54.34164925983974, 65.76088510240827, 62.34426130567278, 49.62180049078805, 38.35929863793509, 47.95728656223842, 47.51421383449009, 42.068080289023264, 46.82465376172747, 41.624545506068635, 39.31821257727486, 49.98955474581037, 51.38418674468994, 42.971356528145925, 53.89008583341326, 50.88641432353428, 59.57406316484724, 59.290118081229075, 53.59403003965105, 54.8137446131025, 58.076111452920095, 57.72264616830008, 58.312305041721885, 58.19435937064034, 52.91441283907209, 53.80525180271694, 56.84931666510445, 51.12371615001133, 50.565466608319966, 46.615269797188894, 37.36317014694214, 21.791213137762888, 11.252931577818734, 3.7958725435393195, 1.1777660186801637, 2.4571118780544827, 3.1229699083736966, 2.823322113071169, 3.179123729467392, 2.6541875430515836, 2.473912839378629, 0.5870479792356491, 0.2145741196083171, 0.198536591604352, 0.07065365303839956, 0.05141181465504425, 0.24307765226278985, 5.688966138022287, 40.90585511071341, 36.05310467311314, 38.626213686806814, 55.267121519361226, 45.363405908857075, 43.63175501142229, 29.69706630706787, 30.97417994907924, 31.273932184491837, 48.6659437588283, 51.01722458430699, 61.77591950552804, 64.79146548679897, 56.389422348567415, 4.272631440843854, 0.2560030658330236, 0.07141704564648015, 0.028590622624116283, 0.03399537117885692, 0.015962921382327164, 0.12085978899683271, 0.07113766563790185, 0.07278286878551755, 0.046606687496283224, 0.021689507578100477, 0.06227257169250931, 0.0915761242753693, 0.04170284367033413, 0.05349193500088794, 0.010944774091642882, 0.054937960979129584, 0.10514691285789013, 0.11050867621919938, 0.12598264696342604, 0.05425068303676588, 0.039398230013570616, 0.03987640381923743, 0.1052866910717317, 0.05045311591987099, 0.030348082605217184, 0.1344841479190758, 0.013980551639438739, 0.023566759524068663, 0.030545305593737533, 0.03788205708510109, 0.06063441173838718, 0.07846509066543408, 0.3201987211193357, 0.23014890030026436, 0.11726484261453152, 0.1159812036369528, 0.11885205815945353, 0.05867439548351935, 0.14210025567029202, 0.11381992032485348, 0.24406407933150018, 0.16021780563252314, 0.16306333722812788, 0.11742615752986499, 0.080709318098213, 0.2045723641557353, 0.13170344355915273, 0.08153153290706021, 0.14796870148607663, 0.14930513048810617, 0.17125842534005642, 0.29238519072532654, 0.25476449515138355, 0.17673486790486745, 0.1405165277953659, 0.21303602999874524, 0.20957647849406513, 0.11424662385668073, 0.10741509257682733, 0.13359791333121912, 0.9841101701770509, 30.04831859043666, 84.14207349504743, 80.38767692020961, 79.1946017401559, 63.28516551426479, 60.57617405482701, 42.476592676980154, 91.05402333395821, 64.78654616219657, 29.81068672452654, 34.168360642024446, 47.667901039123535, 50.28577382223946, 49.22329350880214, 31.310806274414062, 1.8663423785141535, 0.4204665736428329, 0.23753236553498677, 0.40366908641798155, 0.19291287979909352, 0.6899586713739804, 1.4074860577072417, 3.133808663913182, 4.403529856886182, 6.626878712858472, 10.645039762769427, 10.751654658998762, 8.640897018568856, 12.648661392075674, 10.335313388279506, 9.57388983454023, 8.461046372141157, 7.151988821370261, 12.350720899445669, 14.269930601119995, 13.720588650022234, 12.402141043118068, 21.2444680758885, 29.95351389476231, 28.6931106703622, 26.352823632104055, 23.62237787246704, 18.101987191608973, 19.922107764652797, 30.18249872752598, 29.793903350830078, 44.36812162399292, 44.75090135846819, 54.893360546657014, 59.06322465624128, 66.37483487810407, 63.406328201293945, 57.48495871680123, 68.71630832127163, 62.61464350564139, 53.95673990249634, 42.04682574953352, 53.11266231536865, 52.61853075027466, 48.18702180044991, 52.47948687417166, 46.88226127624512, 42.72815568106515, 53.439971106392996, 54.79802431379046, 45.17290367398943, 52.19164037704468, 52.109700271061485, 59.014406612941194, 59.35903031485421, 52.63224996839251, 56.662670680454795, 58.700292451041086, 59.432062830243794, 61.719632148742676, 62.948052815028596, 56.97350876671927, 58.13852364676339, 61.20329066685268, 54.74516241891043, 56.409874371119905, 53.25546169281006, 43.681528432028635, 26.514410938535416, 14.078694462776184, 6.603856291089739, 5.892883607319423, 8.317828365734645, 10.756788509232656, 10.667046444756643, 5.883251232760293, 4.085393122264317, 2.2119160294532776, 0.6494215237242835, 0.5449954186167035, 0.25460650505764143, 0.2583119576530797, 0.32527568297726767, 0.7976871792759214, 8.87514076914106, 61.499832834516255, 48.89763144084385, 40.93036835534232, 69.53252710614885, 72.65048953465053, 69.29955400739397, 39.84574065889631, 28.033349684306554, 35.67998988287789, 59.226653235299246, 61.66882692064558, 72.8531129019601, 73.62687819344657, 69.26024109976632, 6.009476985250201, 0.5090131951229913, 0.1059221662580967, 0.16616687497922353, 0.1533197100673403, 0.11514960468879767, 0.1947446393647364, 0.20246172669742787, 0.22029146924614906, 0.25494145708424704, 0.15101954420762403, 0.19484499469399452, 0.13535244204103947, 0.1225647439381906, 0.11615952263985362, 0.10227383274052824, 0.19122260835553917, 0.15790242701768875, 0.21842294665319578, 0.24850620382598468, 0.12803932731705053, 0.11967472758676324, 0.07973084345992122, 0.2077526713588408, 0.1350136495062283, 0.16924108644681318, 0.3031370937824249, 0.1014640758346234, 0.15558200010231563, 0.0807053961658052, 0.16590000715638908, 0.13172278180718422, 0.21665406014238084], [0.10303527795310531, 0.01623481884598732, 0.01585783836032663, 0.05006151639723352, 0.03233826652701412, 0.0681447833776474, 0.010045651579275727, 0.0581725916958281, 0.05904166613306318, 0.04260013498631971, 0.04323303513228893, 0.04103293622444783, 0.04152348990152989, 0.06841607524880342, 0.020331960869953036, 0.010509020599004413, 0.024869492477072135, 0.01523127912410668, 0.12059141482625689, 0.02428213899422969, 0.010546652151138654, 0.023666833261294023, 0.0358296515020941, 0.012667990106690143, 0.03967358630948833, 0.06963879535240786, 0.05377342864604933, 0.05406391288020781, 15.787358113697596, 52.61314589636666, 59.82933303288051, 61.62547710963658, 45.84156356539045, 32.171062741960796, 26.590587513787405, 27.362082481384277, 52.85866744177682, 52.31277527127947, 32.39265816552298, 32.89942502975464, 41.67716073989868, 39.188600880759104, 24.609013387135096, 1.5066639930009842, 0.047187672927975655, 0.11301603274685995, 0.10980177165142127, 0.0860337009653449, 0.1496294702270201, 0.6729017123579979, 0.6064880618027279, 1.8930836064474923, 2.115530835730689, 0.990375273994037, 2.269499008144651, 3.149718518768038, 2.595603806631906, 1.3649339867489678, 2.9152452605111256, 2.7218734196254184, 6.848798964704786, 8.220478892326355, 15.306209257670812, 18.61622510637556, 27.007804257529124, 38.61047601699829, 39.54851756777082, 43.00118861879621, 46.18360948562622, 40.39395352772304, 38.14722572054182, 34.62753234590803, 39.59312152862549, 44.48635911941528, 51.25319583075387, 60.276692799159456, 61.83789048876081, 55.259495871407644, 56.687163080487935, 59.96481595720564, 65.89642361232212, 63.549877984183176, 64.93177740914481, 67.74911212921143, 58.865756852286204, 32.37700734819685, 34.65561696461269, 43.629844256809776, 36.032666546957834, 40.173101561410085, 36.30954531260899, 57.20877824510847, 60.1821278163365, 59.78048024858747, 61.80601910182408, 58.36646624973842, 55.51456771578108, 60.60825388772147, 56.97849062510899, 56.4584561756679, 54.39451462881905, 53.98486621039254, 57.51191425323486, 58.34620530264718, 49.7428172656468, 50.99145024163382, 52.259329727717805, 52.5055113519941, 51.281492369515554, 52.413847242082866, 47.59577178955078, 45.51349394662039, 41.59720434461321, 33.77391488211495, 22.895332268306188, 10.902236018862043, 7.548669729913984, 3.995622830731528, 2.3718099296092987, 0.2981596594410283, 1.8268655368259974, 2.1066215080874304, 0.718547848718507, 0.4192962907254696, 0.11567435653081962, 0.09172627050429583, 0.169071995520166, 0.03895537395562444, 0.3063430631799357, 4.173733387674604, 27.066052743366786, 40.32902608598982, 35.26902478081839, 39.110530921391074, 37.801837716783794, 39.68832574571882, 30.170506136757986, 32.05240488052368, 32.29374361038208, 45.29460137231009, 49.659358978271484, 56.36845963341849, 57.77178382873535, 26.48962845121111, 0.6456257988299642, 0.07971251622906753, 0.14195666408964566, 0.03299476272825684, 0.07277273825768914, 0.05662783208702292, 0.10959625696497304, 0.06571172643452883, 0.06205324203308139, 0.06677480081894568, 0.04091870824673346, 0.052665140080664835, 0.07504058549446718, 0.027775910716237764, 0.06049480315830026, 0.0337368866561779, 0.08769159271780934, 0.05009679343285305, 0.01693816789026771, 0.07143156629587923, 0.038212690236313004, 0.030584504561764852, 0.06420856780771698, 0.03330788628331252, 0.013873745138490838, 0.04694080492481589, 0.04399279418534466, 0.050037567503750324, 0.016288267049406255, 0.07173542106258017, 0.08982597211641924, 0.0469706706436617, 0.1254321786441973, 0.012029997555405965, 0.0048564909874195495, 0.03740529463227306, 0.007677843411719161, 0.04521140915208629, 0.002409001180369939, 0.029640289156564643, 0.045373002266777415, 0.03405814245343208, 0.042230072165174146, 0.005553810823974865, 0.045264419700418196, 0.033194265594439845, 0.0652935995853373, 0.02244162293417113, 0.02177956104943795, 0.024223757841225182, 0.09799264318176679, 0.020785400377852575, 0.029455490144235746, 0.014171108021400869, 0.0892113143844264, 0.02333116198756865, 0.011448436217116458, 0.024752199217411022, 0.040355999155768325, 0.11129022642437901, 22.62115635190691, 60.68920040130615, 69.03233323778424, 69.18896647862026, 54.65417923246111, 42.72238867623465, 40.695192677634104, 28.946964842932566, 57.875485692705425, 57.00374732698713, 29.595302990504674, 29.489005974360875, 37.52477134977068, 38.99731697354998, 19.94383478164673, 1.727946204798562, 0.08154755990420069, 0.07522235824061291, 0.10473389537738902, 0.3572259971073696, 1.005344842161451, 2.022259303501674, 2.0012410027640204, 4.709715255669185, 3.774793880326407, 3.7716941152300154, 4.193385064601898, 5.447743790490287, 3.721022639955793, 3.384522033589227, 3.3359754042966023, 4.106203845569065, 6.677854606083461, 10.549386518342153, 15.723698718207222, 20.65351162637983, 28.83689669200352, 38.85295425142561, 39.652827399117605, 44.9624079976763, 46.313071795872276, 42.262299810137065, 39.44175154822213, 38.03226082665579, 41.12772151402065, 45.854615756443565, 51.84964656829834, 61.25415842873709, 62.94711480821882, 58.40274279458182, 57.91131407873971, 61.022449902125764, 67.55927344730922, 66.29824488503593, 66.22807502746582, 66.70846652984619, 59.11588505336216, 36.61324759892055, 40.67820085797991, 46.62179068156651, 41.21039465495518, 44.52591521399361, 42.1466783114842, 59.10367012023926, 60.3057084764753, 60.22540119716099, 65.03857816968645, 57.5899772644043, 57.129151889256065, 60.534547397068565, 56.95022535324097, 56.23706572396414, 55.073228563581196, 56.63044840948922, 58.68537466866629, 60.322801045009065, 54.18518624986921, 54.26842566898891, 54.502677236284526, 56.27399887357439, 56.990577016557964, 58.43198776245117, 55.04805176598685, 51.52936240604946, 47.251703943525044, 38.54501356397356, 26.325878517968313, 13.757178732327052, 7.288638608796256, 4.071796800409045, 2.3900847775595526, 2.719911639179502, 3.2905116038663045, 2.9741557793957845, 2.833981518234525, 1.6297968200274875, 1.0109253312860216, 0.17323535068758897, 0.12213782327515738, 0.01842930118021156, 0.19588571813489708, 4.307470142841339, 25.912481546401978, 35.38766527175903, 31.148798601967947, 34.562528473990305, 30.61574670246669, 38.501906939915244, 27.023543664387294, 38.68974454062325, 43.72457252229963, 53.97045912061419, 58.512510435921804, 63.868529319763184, 69.67473588671002, 42.05355160576956, 0.29453522392681664, 0.054269912719194374, 0.12307445944419929, 0.04061806634334581, 0.03858619323000312, 0.06647280523819582, 0.1357023354087557, 0.026125336963949457, 0.013998582011221774, 0.05917697958648205, 0.028760334410305535, 0.06878689463649477, 0.06504843809774943, 0.031031808416758264, 0.04311661548646433, 0.022452645735549073, 0.08586139378270932, 0.09463020360895566, 0.09283629951200315, 0.051219829956867864, 0.07089306733437947, 0.02446752493934972, 0.06660442067576305, 0.09498356429061719, 0.05012293738712158, 0.03532414969855121, 0.0537179685863001, 0.02292809183044093, 0.05501750563936574, 0.04889054476682629, 0.13423914249454225, 0.1487330983259848, 0.2278777893100466, 0.16951950293566498, 0.06959311637495245, 0.13763991929590702, 0.09928951359220914, 0.2119898104241916, 0.10379020244415317, 0.19098221696913242, 0.19046707318297454, 0.0905757329559752, 0.13216469809412956, 0.10704381857067347, 0.17205132065074785, 0.17019962572625705, 0.18862377852201462, 0.12425103916653565, 0.07595379863466535, 0.07333667549703803, 0.29393651176776203, 0.08531365995960576, 0.1601592887725149, 0.20210586222154753, 0.1913155269409929, 0.11818541107433182, 0.1774736296917711, 0.13776820312653268, 0.11317109835467168, 0.384431641548872, 30.312315395900182, 76.177950995309, 74.95379652295793, 77.55513259342739, 65.55050754547119, 47.75805044174194, 40.12919936861311, 39.08995730536324, 59.07571751730782, 60.15699618203299, 44.13837596348354, 44.964023453848704, 56.67226266860962, 50.60110739299229, 30.763920511518204, 2.5521458642823354, 0.2598270449255194, 0.2807433754205704, 0.16418087083314145, 0.5546444037130901, 1.8511575247560228, 2.2781278022697995, 2.510152906179428, 6.437700109822409, 9.325152141707283, 6.396267567362104, 7.845158049038478, 9.507082905088152, 8.033532398087637, 6.691559927804129, 9.311248796326772, 8.832702040672302, 13.586745500564575, 14.525794540132795, 21.17238051550729, 22.836812802723475, 32.98777484893799, 44.07910782950265, 47.83360167912075, 48.592115674700054, 49.540412766592844, 44.192745617457796, 42.040356976645334, 41.59196192877633, 43.86713218688965, 47.65235791887556, 54.45350136075701, 65.32595566340855, 65.49419934409005, 61.83119937351772, 62.60995347159249, 64.69523293631417, 69.59412288665771, 66.57683290754045, 66.86604472569057, 67.21266256059918, 62.049518721444265, 41.380298955099924, 45.64087527138846, 52.680543422698975, 46.059837750026155, 51.0883081299918, 46.453321184430806, 60.29618944440569, 60.62766020638602, 61.63077858516148, 62.78366538456508, 56.66261509486607, 56.85851608003889, 61.67152976989746, 57.631933961595806, 56.623646123068674, 57.762389864240376, 57.21303749084473, 60.48321410587856, 60.635650634765625, 53.83689737319946, 55.422451972961426, 54.08674764633179, 56.534469468253, 57.47195168903896, 59.68739523206438, 57.317764214106965, 55.782052516937256, 51.72040312630789, 42.110811710357666, 29.406600339072092, 15.040407657623291, 13.724995544978551, 10.564878395625524, 8.687532458986555, 5.3361930676868985, 5.3693724530083795, 5.96257403918675, 3.0931052480425154, 1.2114989800112588, 0.6220731426562581, 0.2373467997780868, 0.4868969704423632, 0.1554798534406083, 0.4810446873307228, 6.407187095710209, 37.7602527482169, 52.51581900460379, 47.00689458847046, 51.76283924920218, 50.36764097213745, 56.41723946162632, 39.31697232382638, 43.054227692740305, 46.442145006997244, 62.62068843841553, 67.40934521811349, 73.94063104901994, 78.26940740857805, 57.08158104760306, 1.3671702210392271, 0.14461175804691656, 0.22148848644324712, 0.18919395149818488, 0.2079777821366276, 0.2100689456398998, 0.24753209895321301, 0.14245265961757728, 0.1724698817623513, 0.11279221797095877, 0.1788139534848077, 0.15820734708436898, 0.13246077006416662, 0.09922241326421499, 0.16058744436928205, 0.12677273313914025, 0.20159198051052435, 0.1476476187152522, 0.15082650099481854, 0.13266336705003465, 0.14442630085561955, 0.07584211177059583, 0.20337223926825182, 0.1413811171161277, 0.1808412532721247, 0.13687941724700586, 0.10519449173339776, 0.13052220908658846, 0.12513905151614121, 0.2320388645998069, 0.19340044792209352, 0.2569419140262263], [0.09813246889305965, 0.03701701993122697, 0.021038951950946023, 0.049878895482314486, 0.021829029644972513, 0.04407547367736697, 0.04938814163740192, 0.07717047977660384, 0.02906943086002554, 0.02792130720003375, 0.08250964113644191, 0.01918970144885991, 0.014164418514285768, 0.024105470527761748, 0.03542049827852419, 0.041344058101198504, 0.03510031117392438, 0.02656295133887657, 0.020285370959235088, 0.022833454855052487, 0.01680207242523985, 0.023520519058885317, 0.02957161462732724, 0.08623943956834929, 0.04914373332368476, 0.06394035648554564, 0.04942955941494022, 7.793510351862226, 48.568912165505544, 64.42649051121303, 66.3419212613787, 53.92359004701887, 43.95328637531826, 27.870881693703787, 19.803491592407227, 29.187909262520925, 24.82277819088527, 18.35636247907366, 26.462751082011632, 33.298880440848215, 39.8339877809797, 19.11303867612566, 1.1657374926975794, 0.010569300801892365, 0.02776265553464847, 0.0658256999616112, 0.026412219873496463, 0.11090375323380743, 0.5412988141179085, 0.6938638303961072, 1.781934684940747, 2.946177337850843, 2.304700319256101, 1.8493924651827132, 2.0734032562800815, 2.3583032829420905, 2.8894005673272267, 7.686065145901271, 11.139504841395787, 13.47083478314536, 17.496250186647686, 28.569271189825876, 29.770394120897564, 38.77003444944109, 44.475280216761995, 49.054653780800955, 50.894991874694824, 54.79105527060372, 55.2099552154541, 55.03940125874111, 56.56840794427054, 52.750285966055735, 55.759446552821565, 60.389670508248464, 62.450693811689106, 61.78953797476632, 62.722576822553364, 62.66203716823033, 59.20703847067696, 59.15532302856445, 61.716164997645784, 65.13582515716553, 62.832844734191895, 61.71248940059117, 58.37011405399868, 49.390321254730225, 29.98798738207136, 38.21036747523716, 38.83115427834647, 28.61347562926156, 50.142623560769216, 61.90631634848458, 58.44140951974051, 57.993386200496126, 56.9717230796814, 55.560366766793386, 56.38317591803414, 54.39049162183489, 56.04096324103219, 54.22508628027779, 53.14163282939366, 55.73250491278512, 57.57661240441458, 55.37447466169085, 50.23503112792969, 52.661567892347065, 57.17532614299229, 62.77170753479004, 58.52092470441546, 59.05386543273926, 60.171107973371235, 57.25897203172956, 54.16767678941999, 50.25330489022391, 44.16018288476126, 38.004985673086985, 24.92423231261117, 15.15254463468279, 5.9704715354102, 4.446967388902392, 2.310634949377605, 3.6313522287777493, 1.8104474863835742, 0.7234701588749886, 0.6961805117981774, 0.11784687638282776, 0.1113200548237988, 0.046789708746863265, 0.05010355842698898, 0.193176802779947, 2.724983824150903, 24.716832058770315, 48.0732033593314, 48.06346893310547, 50.409243311200825, 47.193863664354595, 53.012128829956055, 13.783039058957781, 16.944683074951172, 36.22586120877947, 42.559335299900596, 48.95564889907837, 53.566369261060444, 46.40965175628662, 19.73712761061532, 0.7806640384452683, 0.08059535814183098, 0.1018868370779923, 0.035852555451648574, 0.04944529803469777, 0.046827123167791536, 0.04553266494934048, 0.01934210380672344, 0.04378048397068467, 0.04113214143684932, 0.08738294749387673, 0.02731634403711983, 0.014306067788441266, 0.01761316943780652, 0.047339169441589286, 0.06868655287793704, 0.060659286832170825, 0.06857250471200262, 0.06379384041896888, 0.06580434646457434, 0.02979159907304815, 0.04446081371445741, 0.15654311781483038, 0.06393952867282288, 0.09646977989801339, 0.06011428750519242, 0.040305258307073794, 0.02339265591997121, 0.07902651732521397, 0.039031871993626864, 0.007034546412926699, 0.08507907004760844, 0.033888539232845814, 0.015286846053121346, 0.020093947748786638, 0.04444102084796343, 0.03362003953329154, 0.007105839663251702, 0.011292364681139588, 0.02417309332772025, 0.04906453810898321, 0.012615592784381338, 0.029266094057155505, 0.06118814381105559, 0.04843450816614287, 0.020349903032183647, 0.01431505668110081, 0.024970616247238855, 0.0625124948897532, 0.06474486831575632, 0.0517203852401248, 0.034546005739165206, 0.012233790459244378, 0.08047130158437149, 0.06705720709370715, 0.04939040794436421, 0.11330301234764711, 0.02963434179712619, 10.856373565537588, 59.672407967703684, 73.53137520381382, 73.59557655879429, 63.241871288844514, 51.49397523062569, 35.72995090484619, 29.07645320892334, 36.35183204923357, 36.72549227305821, 30.352385657174246, 34.400336674281526, 39.257005895887104, 39.10388496943882, 16.248395408902848, 0.7640741829361234, 0.01968626185719456, 0.008864588436803647, 0.33812738050307545, 1.1771040941987718, 1.567497860108103, 1.2453995666333606, 3.0205337022032057, 7.808124150548663, 5.835120626858302, 2.867703731570925, 3.662674273763384, 2.4760413765907288, 2.668532967567444, 3.7222142560141425, 7.125718116760254, 9.776752046176366, 14.788299219948904, 19.287183114460536, 28.937935658863612, 31.35893644605364, 40.20065464292254, 47.703076294490266, 53.974256311144146, 57.576004437037874, 58.69698510851179, 57.36843742643084, 56.39941038404192, 56.66463702065604, 55.78069414411272, 57.12476062774658, 62.41885716574532, 64.62610530853271, 60.693473543439595, 64.14986188071114, 62.71307863507952, 61.14667674473354, 61.113589423043386, 62.92006547110421, 65.0274749483381, 64.29824760981968, 63.65420518602644, 58.752084323338096, 50.53380366734096, 34.046242577689036, 43.44527578353882, 44.31774371010916, 36.11593723297119, 52.416213103703086, 60.11783613477434, 57.88191625050136, 58.138728618621826, 57.40952212469918, 55.602271352495464, 57.20785066059658, 57.65664175578526, 56.053403990609304, 54.98750168936593, 55.49473755700247, 56.232087339673726, 57.899564674922395, 55.775191170828684, 52.66349254335676, 55.09744998386928, 59.29295294625418, 63.620089530944824, 59.73180116925921, 60.54781150817871, 62.816217694963726, 59.70863587515694, 58.6738406590053, 53.85555676051548, 48.54831075668335, 42.832979679107666, 28.446121317999705, 17.51039845602853, 6.855421032224383, 3.6385499111243655, 1.1404941443886076, 3.0227384524685994, 3.3458479259695326, 2.400596316371645, 1.896230923277991, 0.9768041393586567, 0.22107966909451143, 0.11488739161619119, 0.017064149790842618, 0.06882542864020381, 3.072372691971915, 20.879022359848022, 37.2652769769941, 43.49428142820086, 45.026546818869456, 41.4708583014352, 43.306499413081575, 17.748700823102677, 27.921853678567068, 48.12876810346331, 48.83173819950649, 58.87251050131661, 60.30235249655587, 59.83154256003243, 36.58525330679757, 0.5624754577875137, 0.04193372878112963, 0.056988968779998164, 0.028848113092992986, 0.055433003165360005, 0.015501449716144373, 0.053530943979110034, 0.04706387082114816, 0.03754600922444037, 0.033103759200977426, 0.08007177338004112, 0.09340438260031597, 0.022852408034460883, 0.026511701588918055, 0.07801639581365244, 0.0434501290188304, 0.09879497012921742, 0.04751292529648968, 0.04637771585424032, 0.04046662750520876, 0.03909111488610506, 0.011834326715740775, 0.08065595131899629, 0.06279508436896972, 0.06699088708098445, 0.046324254080121, 0.023810579208657146, 0.08839632597352777, 0.08482354733028583, 0.05065828455345971, 0.07147277372756175, 0.20913514574723585, 0.10668222725923572, 0.11278746144047805, 0.10576692423118011, 0.16579722267176422, 0.13661226443946362, 0.14044449451778615, 0.19325486144849233, 0.1901437919586897, 0.07617787125387362, 0.26873867958784103, 0.19501731544733047, 0.14164027678115026, 0.10177968282784734, 0.11457484481590134, 0.1010276081838778, 0.16368970647454262, 0.1202765338655029, 0.19531270888234886, 0.151140852698258, 0.11487144604325294, 0.17548746269728455, 0.22413034896765435, 0.2328819307897772, 0.17311297011162552, 0.1384475930993046, 0.11667199299803802, 15.670058625085012, 72.44739368983677, 80.8231691632952, 82.85630934579032, 70.56106894356864, 59.838782582964214, 39.92234802246094, 30.14057329722813, 40.89628049305507, 35.752351897103445, 26.90120152064732, 36.65245975766863, 45.33904552459717, 50.62229592459542, 24.32608621461051, 1.8410526726927077, 0.11519335662680012, 0.17890504002571106, 0.33353158139756744, 0.8733010590076447, 1.234622367790767, 3.065170232738767, 3.6463516524859836, 6.904066673346928, 9.05654694352831, 8.156115123203822, 8.274669630186898, 6.998649460928781, 6.888499668666294, 8.96521634714944, 14.06467820916857, 17.305240733282908, 19.09669303894043, 22.361457007271902, 35.0422112601144, 34.441626344408306, 46.165888105119976, 53.34848764964512, 56.36310952050345, 56.14236525126866, 63.34932518005371, 60.83807250431606, 58.0274532181876, 58.92521953582764, 59.09832000732422, 60.143134525844026, 65.79020650046212, 66.73530047280448, 64.08336067199707, 66.70637512207031, 66.69224943433488, 64.15046637398856, 63.755912917000906, 63.10419968196324, 66.22350311279297, 65.1753465107509, 66.78167969839913, 62.07135690961565, 54.2565199307033, 39.64034148624965, 47.59051547731672, 47.3522686958313, 41.34109027045113, 53.67664412089756, 61.58945764814104, 59.665126255580354, 59.3472809110369, 56.27643769127982, 55.48646225248064, 56.53075565610613, 58.51494925362723, 57.96970673969814, 55.91127164023263, 55.223403453826904, 58.50857775551932, 58.16506576538086, 57.424808161599294, 53.01421676363264, 53.74574742998396, 58.57532215118408, 65.88666139330182, 61.054529735020225, 63.5797552381243, 64.96218967437744, 64.59487315586635, 61.374417849949424, 55.62388719831194, 47.826736858912874, 44.10095991407122, 32.269188676561626, 22.495920283453806, 10.158631988934108, 9.649084976741246, 7.418445723397391, 9.927020737103053, 5.563146420887538, 3.0783755012920926, 1.773838079401425, 0.5465709769300052, 0.2842961847782135, 0.2614691810948508, 0.20029998198151588, 0.3802957534790039, 4.449649827820914, 33.55330957685198, 62.04221616472517, 63.681212833949495, 60.62809099469866, 59.84739140101841, 70.86336421966553, 22.328522545950754, 28.304247788020543, 51.918861048562185, 57.813483442579, 66.28659275599888, 71.01840632302421, 68.6786629813058, 46.002153805324006, 1.2747992404869624, 0.15960633701511792, 0.23132265731692314, 0.13500041807336466, 0.1648019610771111, 0.11581456900707313, 0.17610138761145727, 0.18149746448865958, 0.08542271410780293, 0.14454640155392035, 0.14771628645913942, 0.14936748785631998, 0.10525380247937781, 0.25208208337426186, 0.2411238785300936, 0.21553568515394414, 0.19070871307381562, 0.21907239966094494, 0.12278567494026252, 0.15098077271665844, 0.23043019377759524, 0.11633353973073618, 0.20185869905565465, 0.29864353633352686, 0.29891991721732275, 0.2070662517632757, 0.11094945935266358, 0.0905556958168745, 0.17737145588866302, 0.17615482902952603, 0.12714132693197044], [0.01421146813247885, 0.02470606392515557, 0.02754888986237347, 0.007775753470403808, 0.04433329323572772, 0.054198605474084616, 0.009343601081387272, 0.03933708383036511, 0.02201744694528835, 0.015149390125381095, 0.0030077699546901776, 0.0193005316624684, 0.04174788482487202, 0.026635298438902413, 0.03552836838311382, 0.004981328284234873, 0.024649740429595113, 0.005543779107808534, 0.05393711843394807, 0.026794691403795565, 0.08621326847268002, 0.005337079953668373, 0.06203291990927287, 0.10687867671783481, 0.04808887599834374, 0.21898143525634492, 0.8752844982913562, 34.260594504220144, 69.3955294745309, 65.67732606615338, 62.663037708827424, 48.518662793295725, 32.191094398498535, 26.05161922318595, 22.74656786237444, 14.860739401408605, 23.5988894871303, 27.9771682875497, 26.471648250307354, 42.51197637830462, 26.6942754813603, 2.0578021620001112, 0.031217513273337057, 0.06761128521923508, 0.030005982212190117, 0.15688333527318069, 0.6522182822227478, 0.9643567672797612, 0.6837335196988923, 3.018133099590029, 2.899951841150011, 7.222593375614711, 1.875478174005236, 1.653320272053991, 5.3190266745431085, 13.939572419439044, 20.67584661075047, 21.867005825042725, 26.4629682132176, 32.86852291652134, 38.479071685246055, 41.67775133677891, 46.47872379847935, 52.79232256753104, 55.217504433223176, 58.47911739349365, 60.62340790884835, 58.97894300733294, 54.24782426016671, 57.67569024222237, 55.072523321424214, 56.37145778111049, 60.028517041887554, 59.43110397883824, 55.24204199654715, 57.66668537684849, 57.866387026650564, 57.5626882144383, 58.27857501166207, 59.10537242889404, 59.3125399180821, 59.79134028298514, 58.61375263759068, 62.650440624782014, 57.60352972575596, 57.36347988673619, 40.469348430633545, 29.55492353439331, 27.185560022081646, 33.73372997556414, 57.53971399579729, 53.40498692648751, 57.2092159816197, 54.36401203700474, 54.92384924207415, 55.86321095057896, 53.09214081083025, 52.83609274455479, 52.71268578938076, 53.559250831604004, 54.006054741995676, 55.10774721418108, 54.36193799972534, 51.991355078560964, 51.75371279035296, 57.23666484015328, 60.103884152003694, 57.35815756661551, 56.633953775678364, 55.35615921020508, 53.377079486846924, 56.650177819388254, 60.74001257760184, 65.38020024980817, 63.0515045438494, 55.50250564302717, 49.03371885844639, 33.870150906699045, 23.016474110739573, 9.606800845691136, 5.764428351606641, 1.3534955148186003, 4.315490969589778, 3.8603852646691457, 2.3928855529853275, 0.5317785878266607, 0.04274725155638797, 0.037413945953760824, 0.11715652128415448, 0.07894243326570306, 0.20012528635561466, 1.3995166910546166, 13.322827730860029, 31.8248096874782, 39.66084214619228, 55.90520238876343, 50.77690723964146, 40.315338134765625, 21.54247110230582, 21.846482583454677, 40.479405948093955, 41.705238410404746, 54.05235753740583, 48.35779115131923, 51.389394419533865, 14.834089585712977, 0.770503546510424, 0.03915312959413443, 0.135352170627032, 0.015943818925214664, 0.0490735795881067, 0.02494093882186072, 0.06599171712462391, 0.027924447120832543, 0.05695465526410511, 0.01093243747683508, 0.05240830439808113, 0.06406036897429399, 0.04570658025997026, 0.043647711630910635, 0.019110892999118993, 0.011156739949780916, 0.08097967359104327, 0.00716407026629895, 0.06557439773210458, 0.06514692745570626, 0.009456338826566935, 0.019699116703122854, 0.05095625302887388, 0.09615086165389844, 0.021760767325758934, 0.07252644361662013, 0.011361324195084828, 0.049973160959780216, 0.04000078607350588, 0.031813816633075476, 0.058816738559731414, 0.016751041502824852, 0.01952477900444397, 0.04563624331993716, 0.021264678499262248, 0.06227597115295274, 0.05446751229465008, 0.07760649280888693, 0.011449536292015441, 0.0306852398706334, 0.05027973325923085, 0.012020356420959746, 0.025997188840327517, 0.01718197570049337, 0.07151889375277928, 0.010835205953169082, 0.07040585204958916, 0.009631480589242918, 0.016120436501556208, 0.024911544684852873, 0.07410746413682189, 0.028880635276436806, 0.013479483214073947, 0.042701952558543, 0.047294776287994215, 0.22971594067556517, 2.004484074456351, 44.87859535217285, 77.38835498264858, 74.35409750257219, 68.8257702418736, 56.48259769167219, 42.23167215074812, 33.26651920591082, 23.41629430225917, 23.51462173461914, 29.663892132895334, 29.277478490556987, 30.560981001172745, 34.19077900477818, 22.15506250517709, 1.771873584815434, 0.038541067258587906, 0.05398626472534878, 0.25492791352527483, 0.7414364633815629, 1.544626127396311, 2.2341244263308386, 3.3284602761268616, 4.612241148948669, 5.980502128601074, 6.008682285036359, 2.94691732100078, 2.14317923784256, 4.961107594626291, 12.46147084236145, 21.436498914446148, 22.437320913587296, 27.062908683504375, 33.51495899472918, 39.18210778917585, 44.48443446840559, 50.608170236860005, 57.470711435590474, 59.45739596230643, 61.42914186205183, 63.76896163395473, 63.112697328839985, 60.13845838819231, 61.20224148886544, 56.852578844342915, 59.27141353062221, 63.27338831765311, 59.8849881035941, 57.29872267586844, 59.33462129320417, 59.97939327784947, 60.05797740391323, 59.95645727430071, 61.17612321036202, 60.19163295200893, 60.504920278276714, 60.556621823992046, 64.67980098724365, 59.997819900512695, 60.858194487435476, 43.025990213666645, 34.64140095029558, 34.14616114752633, 35.86962706702096, 57.57455226353237, 53.1587427684239, 57.67930677958897, 54.91926690510341, 56.42442042487008, 55.00584493364607, 54.71537896565029, 53.97372129985264, 53.248263359069824, 54.0227165222168, 54.86554690769741, 55.59624031611851, 54.8555588722229, 52.8351616859436, 52.812618255615234, 59.61274378640311, 61.66314329419817, 59.124660628182546, 59.42735195159912, 57.21034506389073, 54.9382598059518, 59.1337697165353, 62.27055481501988, 65.78482164655412, 62.504639625549316, 56.04715061187744, 51.40115424564907, 36.502910205296104, 26.538462127958024, 11.374905467033386, 5.819819390773773, 0.6469723380037716, 2.5950692296028137, 3.3244122990540097, 4.875055457864489, 2.428127250501088, 0.7906496854765075, 0.2337473343525614, 0.06249585042574576, 0.03207018073382122, 0.14830159076622554, 1.2533774014030183, 12.87272082056318, 34.818917001996724, 48.20926645823887, 58.81261008126395, 44.393868173871724, 30.675028732844762, 23.946787527629308, 29.199366841997417, 52.3664744240897, 46.26757499149868, 62.0332738331386, 55.90113421848842, 64.91219738551548, 26.26128285271781, 0.6410500300782067, 0.08045677414962224, 0.018382531457713673, 0.04745705811572926, 0.016013660534684147, 0.03009537241554686, 0.04125270353896277, 0.011720798477264387, 0.09390814735421113, 0.025052776659971902, 0.023943360030118908, 0.05540668957733682, 0.03905607194506696, 0.04041752192590918, 0.0029828469393708345, 0.03656761261767574, 0.11423434237284319, 0.05418138086263623, 0.03922800254076719, 0.043677984470767636, 0.033184352197817395, 0.04289353692105838, 0.042690366573099575, 0.039158730900713375, 0.0646362891420722, 0.042566245554813316, 0.03706509413729821, 0.06801041987325464, 0.011227930995768734, 0.014046026876063218, 0.11817735007831029, 0.10477950650134257, 0.12935457245579787, 0.13021441203142914, 0.07746134738304786, 0.2028327632163252, 0.21300192682870797, 0.22084087905074867, 0.05985427288604634, 0.08205859176814556, 0.1153265123388597, 0.0977205370685884, 0.13010674209467002, 0.24363193394882338, 0.18204827207539762, 0.11600759864917823, 0.17947329953312874, 0.14031322513307842, 0.14734009307410034, 0.10280760909829821, 0.17672277641083511, 0.13617669924029283, 0.15587984983410152, 0.20602801176054136, 0.17564442141779832, 0.3710971527865955, 4.542126876967294, 59.66653673989432, 87.66740880693708, 84.02223096575055, 78.28783403124127, 64.30183982849121, 45.7438371522086, 36.28804758616856, 31.24663966042655, 21.550480638231548, 32.22653021131243, 37.48391594205584, 33.79636103766305, 55.10794523784092, 34.15704550061907, 3.284135111740657, 0.15228655907724584, 0.3112952288772379, 0.3281133164252554, 0.667129387812955, 1.4822081795760562, 3.5659401501928056, 4.550329225403922, 8.439011028834752, 7.657303946358817, 13.844006896018982, 6.758390307426453, 5.497268812997, 10.845061898231506, 20.025559493473597, 29.41491038458688, 28.028706550598145, 32.05097007751465, 41.12736715589251, 46.86389718736921, 50.06165272848946, 56.11900888170515, 61.18685122898647, 61.92808505467006, 64.85207462310791, 67.18255601610456, 62.24142101832798, 59.51520497458321, 61.04227311270577, 57.24889366967337, 60.43994767325265, 66.56821714128766, 64.41589450836182, 60.245787211826865, 62.62863022940499, 63.929715156555176, 62.2607786996024, 61.849500928606304, 62.59939220973423, 60.2047233581543, 61.801481928144185, 62.956738063267295, 66.19892038617814, 61.85016795567104, 62.27706527709961, 46.71724155970982, 39.59483773367745, 39.02161482402256, 39.421827588762554, 60.980260440281455, 56.27275514602661, 58.383934020996094, 54.505675383976524, 56.05719075884138, 55.42560992922102, 52.60210868290493, 54.494641644614084, 53.10434184755598, 54.84796796526228, 56.56906802313668, 55.723131792885916, 56.21307359422956, 51.861896242414204, 53.47410760607038, 60.239957673209055, 64.74840055193219, 62.53564943586077, 64.07635688781738, 61.753796441214426, 57.04538093294416, 61.59254959651402, 65.8784486225673, 69.77428272792271, 63.8862680707659, 56.73126329694475, 53.61047642571585, 40.605348995753694, 29.83631862912859, 16.603370189666748, 10.124928014619009, 5.971787350518363, 10.889788321086339, 9.475816879953657, 8.395314676421028, 1.570023421730314, 0.2891831568309239, 0.18545117947672093, 0.20809216957007134, 0.21387170015701226, 0.4786974447114127, 2.3047109586851935, 18.67839585031782, 42.26503045218331, 51.71798167909895, 64.4265877859933, 63.95232459477016, 56.6253136907305, 33.05487012863159, 34.97901739392962, 56.41943161828177, 56.843667779650005, 72.14714118412563, 65.43230479104179, 77.2526775087629, 32.12332166944231, 1.1795854696205683, 0.14019252732396126, 0.19288637622126512, 0.13167091459035873, 0.1222799356494631, 0.09781375420945031, 0.10404663439840078, 0.10262994827436549, 0.13408667567585195, 0.10731269485716309, 0.17202420639140265, 0.1646075336528676, 0.13641148592744554, 0.11287856155208179, 0.07505268377384969, 0.11706592328846455, 0.24483972628201756, 0.1389329084860427, 0.09551567823759147, 0.18957057914563588, 0.07892707123288087, 0.1878812847925084, 0.18290824735803263, 0.23517869040369987, 0.11893436445721559, 0.1632551047950983, 0.13235125451215676, 0.11913871206343174, 0.0781426779659731, 0.14209581805127008], [0.01285810544089015, 0.040206914834145985, 0.03210532884778721, 0.026215161429718137, 0.02028166446169572, 0.033471040028546534, 0.036750335312847576, 0.04273261894871082, 0.058809668224837096, 0.03991356718220881, 0.017979122033076625, 0.012695047538727522, 0.014738182637042232, 0.04562199408454554, 0.03416391588481409, 0.04805122069748385, 0.05194763679589544, 0.015862550786031143, 0.08644644024648837, 0.03197222402585404, 0.050312218123248646, 0.030117855673389773, 0.03770168212109378, 0.07128502308790173, 0.04103919231731977, 0.062189498650176187, 20.15073823928833, 64.16270215170724, 63.49248586382185, 63.1702492577689, 48.41595452172415, 50.35047892161778, 29.921844005584717, 24.470469781330653, 34.11545705795288, 31.08073057447161, 35.79094219207764, 37.23960338320051, 47.343955176217214, 37.996967451913015, 3.025004650865282, 0.01958243751765362, 0.05736891446369035, 0.030215120275637934, 0.12170897557267121, 0.5352585496647018, 2.6627362157617296, 2.4908940196037292, 0.8046700645770345, 3.6554629121507918, 12.61998096534184, 4.881281043801989, 2.2550497949123383, 15.197798252105713, 25.546565089906963, 35.38497979300362, 45.841334274836946, 48.48645441872733, 51.36226865223476, 54.1577547618321, 50.77198791503906, 51.517011983054026, 59.7414939062936, 57.762164047786165, 58.019848414829795, 56.36809485299246, 59.31811237335205, 58.799464089529856, 58.84824044363839, 59.947007724217, 59.712770053318565, 58.720511708940776, 57.35308190754482, 53.79934583391462, 51.68235131672451, 52.98304714475359, 54.26052904129028, 54.97037090573992, 55.064727442605154, 57.24408551624843, 53.28882694244385, 51.63941492353167, 59.22638920375279, 57.84000819069998, 60.187373706272666, 59.476920400347026, 51.50920568193708, 32.05534396852766, 21.775732551302227, 42.20068665913173, 46.73458773749215, 51.346312114170615, 55.08737857001168, 55.06122555051531, 55.379678862435476, 51.13991240092686, 53.540191922869, 50.27986785343715, 52.605475085122244, 52.397769110543386, 52.2601774079459, 54.07809713908604, 53.12644059317452, 52.35295670373099, 57.20000614438738, 57.98930065972464, 56.280123710632324, 54.94416230065482, 48.69123867579869, 48.045768397195, 48.39266416004726, 54.43324041366577, 54.57825974055699, 58.36604240962437, 56.22508355549404, 56.026271275111604, 56.6190116746085, 55.18983670643398, 41.66172879082816, 31.564363411494664, 15.408201864787511, 7.26508595262255, 1.610775800687926, 2.0348939512457167, 3.3987163347857337, 4.224000998905726, 0.590642477784838, 0.35469104456050055, 0.07196330704859324, 0.04703095169471843, 0.042377894411661794, 0.08416173819984708, 0.5009911741529192, 4.83004719870431, 19.494411400386266, 36.715782165527344, 45.746116161346436, 36.422443117414204, 28.75017969948905, 19.389568294797623, 20.16034586088998, 35.57223721912929, 48.15289224897112, 49.987025601523264, 49.76293577466692, 47.968066692352295, 9.307429024151393, 0.20810518387172902, 0.06497006051774536, 0.045914734447641034, 0.077461679865207, 0.02490829789478864, 0.026176732598936985, 0.021544255282995955, 0.01841170676717801, 0.0742274426988193, 0.029382330498525074, 0.0047844428668863005, 0.0889935249994908, 0.027111336555598036, 0.030953814209039723, 0.05915852343397481, 0.05071417887562087, 0.08371413578944546, 0.10095172761274235, 0.030557081568986177, 0.08778158003198248, 0.04856354517063924, 0.045027074936245165, 0.02237242254029427, 0.061213052831590176, 0.033022029657981226, 0.05353397024529321, 0.019211406087768928, 0.012391212279908359, 0.01307328840318535, 0.012049627573495465, 0.13513288167970522, 0.0078372304394309, 0.0533677020243236, 0.013292609580925532, 0.03714518841089947, 0.03588088768135224, 0.013661679196437555, 0.01609108816566212, 0.0389404835046402, 0.01565176048981292, 0.03517934014754636, 0.011645521802295531, 0.019823376821087937, 0.03272714512422681, 0.02750612858549825, 0.010543662356212735, 0.019284518236028295, 0.007023493501557303, 0.07916813436895609, 0.013183630919749183, 0.03508511198950665, 0.029703847531761442, 0.06499347676123891, 0.05255903755979879, 0.12033141377781119, 26.582730838230678, 73.59575721195766, 72.69534015655518, 68.95014994485038, 59.65532234736851, 58.61487824576241, 35.34610462188721, 27.846323285784038, 31.842409474509104, 24.07251865523202, 31.81089244570051, 35.11793967655727, 37.123662267412456, 30.748248849596294, 2.766250478369849, 0.0477227147535554, 0.0465786877487387, 0.04141411344919886, 0.5114960904632295, 1.721453221780913, 2.2281279138156345, 1.7887598787035262, 2.159636046205248, 4.525399957384382, 5.368570804595947, 4.592173448630741, 4.0819737400327405, 14.392577597073146, 25.569930144718715, 37.75726849692208, 44.242790017809185, 48.589503152029856, 49.61406714575631, 52.994265011378694, 53.774384430476594, 54.17646278653826, 59.164112499782014, 60.525570324489046, 58.5866060256958, 57.49292830058506, 61.38613946097237, 61.901313645499094, 58.64004462105887, 59.89225591932024, 61.54027829851423, 60.83284051077706, 58.75641999925886, 57.614431449345176, 54.159919125693186, 56.3176509312221, 55.021860531398225, 56.75408118111746, 57.08346748352051, 59.37194006783621, 56.362591879708425, 52.9575958933149, 60.70562594277518, 59.692835671561106, 59.982735361371724, 60.817068099975586, 53.105769702366416, 34.349983079092844, 25.573418140411377, 43.34834493909563, 51.14977189472744, 51.798424448285786, 55.07556315830776, 55.5904837335859, 55.16763721193586, 50.29280192511422, 52.525702817099436, 51.71392740522112, 52.258377824510845, 54.59784671238491, 53.353420870644705, 54.20547498975481, 52.681863580431255, 51.793758732931956, 57.74279941831316, 60.671871594020296, 57.80084466934204, 57.65150008882795, 52.55528824669974, 50.88776922225952, 51.23639161246163, 56.75502961022513, 57.31130238941738, 61.11406190054757, 56.8447447504316, 56.22598682131086, 57.015986578805105, 56.53731822967529, 46.23645748410906, 35.92188794272286, 19.773239135742188, 8.74162679059165, 1.9648578464984894, 1.4880916752985545, 5.403899788856506, 4.86022105387279, 3.0044885746070316, 1.4868689009121485, 0.5303950277822358, 0.07259017841092177, 0.018183876760303974, 0.21183631223227295, 0.2708820088633469, 5.918312277112689, 18.425971269607544, 41.99730593817574, 49.43795115607125, 36.11958851133074, 23.17089261327471, 29.51062182017735, 31.82146760395595, 47.01259905951363, 55.363538197108674, 56.247359480176655, 57.959016936165945, 59.703389985220774, 18.750730071749004, 0.1868211959621736, 0.025507698766887188, 0.0758953360574586, 0.051778569617973905, 0.050329965206661394, 0.07369721507919685, 0.036031217114733796, 0.034694089221635034, 0.05021819691838963, 0.004853722140459078, 0.01584403356537223, 0.06993720826825925, 0.030319445034755126, 0.021539866857762848, 0.09412224550864526, 0.10617637940283332, 0.028318816762683646, 0.03112847251551492, 0.0470336794054934, 0.061482234458838186, 0.060070243797131946, 0.03942567675507494, 0.03032232541590929, 0.011185942400645996, 0.06621381520692791, 0.00822688002205853, 0.046575471492750306, 0.03761980330039348, 0.03362473499562059, 0.1047297902405262, 0.2032953476799386, 0.1272449256586177, 0.19471595090414795, 0.16284959869725363, 0.15639622855399335, 0.18754139303096704, 0.16216906878565038, 0.16831202272857937, 0.13467164071542875, 0.13068408040063723, 0.07428333362830536, 0.09896596095391683, 0.1486287396401167, 0.08759089812104191, 0.10274332469063145, 0.12987167042280945, 0.13763100334576198, 0.16673680368278707, 0.09467593008386237, 0.15518003595726831, 0.15152141584881715, 0.11603175449584212, 0.154235963044422, 0.13044790950204643, 0.21953784754233702, 37.80849756513323, 85.70726639883858, 81.18769250597272, 79.07902540479387, 65.6395765032087, 65.14409351348877, 41.54972035544259, 34.888496262686594, 46.354302406311035, 41.50300761631557, 46.077187401907786, 48.05871983936855, 60.59715761457171, 48.67844009399414, 4.334942885807582, 0.10875694307365588, 0.17013937181660108, 0.15717908154640878, 0.5536289353455816, 2.3359937029225484, 5.827355580670493, 5.78692227602005, 5.278539955615997, 10.24885174206325, 23.3399110180991, 10.198393923895699, 5.213719342436109, 19.516084568841116, 29.577699729374476, 40.064463002341135, 47.032651560647146, 50.76638419287545, 55.26337991441999, 57.812628814152305, 55.80003445489066, 55.463439396449495, 63.001234327043804, 63.10536697932652, 62.376139640808105, 61.6068559374128, 63.35653741019112, 64.9443119594029, 59.95378221784319, 60.87763554709298, 63.12868513379778, 63.14487443651472, 62.4333302634103, 58.653100286211284, 56.3295636177063, 59.45326178414481, 58.60276058741978, 60.195982524326865, 59.38938004629952, 60.76135744367327, 57.50760637010847, 53.45834214346749, 61.42973940713065, 61.07126794542585, 62.602060317993164, 63.39636448451451, 56.08197150911604, 38.45925542286464, 30.116306713649205, 47.524771622249055, 52.468949931008474, 52.68514660426548, 55.776803152901785, 56.25418955939156, 55.92000552586147, 51.700135231018066, 53.9637575830732, 51.1477986063276, 54.475818974631174, 53.232991218566895, 53.051351411002024, 55.06582178388323, 53.433516229902, 52.14728307723999, 59.255397932870046, 62.92570740836007, 60.47729424067906, 58.866013935634065, 55.4144789150783, 52.95264530181885, 53.496515546526226, 59.457840647016255, 59.25692653656006, 62.88355268750872, 57.41936772210257, 56.77421358653477, 57.29217399869646, 58.48148672921317, 48.6106847354344, 40.314024925231934, 23.747761590140207, 10.686096668243408, 6.1633583051817755, 9.101141350609915, 10.803615893636431, 8.87391528061458, 2.9970870060580115, 0.8004310120429311, 0.39458933791943956, 0.21606743947735854, 0.21956280406032289, 0.3336811305156776, 0.9179781930787223, 8.74821628843035, 28.690713541848318, 50.636223588671, 56.74162653514317, 50.238175187792095, 41.69946445737566, 30.38332598549979, 30.943607875279017, 52.251113482883994, 60.89699322836739, 68.91217803955078, 65.75438853672573, 69.8207036427089, 22.19762543269566, 0.49380022287368774, 0.23366056329437665, 0.1375278253108263, 0.15226937857057365, 0.21475557344300406, 0.11073508978422199, 0.11448050130690847, 0.05938265712133475, 0.14939973184040614, 0.13178798902247632, 0.08988853983048882, 0.16482082435062953, 0.1624501994145768, 0.161414307143007, 0.153542961659176, 0.1595685833266803, 0.16318465928946221, 0.18994221277534962, 0.14412268357617514, 0.23686908398355755, 0.16450810113123485, 0.13104883368526185, 0.08276391534933022, 0.1404428253216403, 0.1452035220073802, 0.08962085776563201, 0.0991140715777874, 0.12006145183529172, 0.16595085657068662], [0.049833264002310376, 0.038692088797688484, 0.0917256801788296, 0.008436998568608292, 0.05914742260106972, 0.017258919875270555, 0.11525856384209224, 0.024666902276554277, 0.06945607265723602, 0.048972956237516234, 0.019963355202760016, 0.03940513071471027, 0.02851378531860454, 0.02204314645911966, 0.05735181538122041, 0.05572877318731376, 0.023158210196665356, 0.024493366945534945, 0.0706775306857058, 0.051366875280759165, 0.0706476072913834, 0.028544200650815452, 0.04579509515315294, 0.08683152244027172, 0.06892372800835542, 2.89338818192482, 42.59304795946394, 61.96379879542759, 62.7319221496582, 53.88639981406075, 41.37356267656599, 32.55787590571812, 29.63399750845773, 23.673853601728165, 42.461244106292725, 40.374300548008506, 37.98332813807896, 45.52030665533883, 33.92776189531599, 2.355542242527008, 0.024924835489530648, 0.024806434521451592, 0.03287617177037256, 0.044835585568632395, 0.5561813126717294, 1.6221358882529395, 1.2825465904814857, 1.5394918429000037, 3.106593655688422, 4.311738073825836, 3.1949669250420163, 7.416322180203029, 27.28590416908264, 37.94854198183332, 48.78054734638759, 57.754489762442454, 59.966844831194194, 57.62313754217965, 57.523173809051514, 54.16791302817208, 54.772847516196116, 56.02607325145176, 58.090337889535085, 51.22597278867449, 51.59763887950352, 52.77770355769566, 59.189376149858745, 59.1142452784947, 58.074551582336426, 56.981763226645334, 57.14502157483782, 53.670703411102295, 52.52204459054129, 50.423744201660156, 53.46032932826451, 51.72150788988386, 53.7494786126273, 54.915587833949495, 57.74006182806832, 55.19208444867815, 54.67455135072981, 54.91517789023263, 59.70989349910191, 54.45329986299787, 55.51296615600586, 54.013847146715435, 63.611633573259624, 42.9082738331386, 20.62302119391305, 48.21598884037563, 49.93449374607631, 60.53112193516323, 54.82231869016375, 56.29683065414429, 56.360000201633994, 53.98258720125471, 52.576990944998606, 55.8026886667524, 54.447786467415945, 54.35372175489153, 51.277385984148296, 53.40089791161673, 50.10805974687849, 54.955984660557334, 57.32750906263079, 54.43535614013672, 54.757881096431184, 46.5370261328561, 43.902098996298655, 43.99339485168457, 47.826670851026265, 55.07334668295724, 59.02988025120327, 59.00962625231062, 54.000857489449636, 56.623621804373606, 56.55033220563616, 55.26050683430263, 56.84142003740583, 47.88295473371233, 39.40038892201015, 28.58008258683341, 12.592371429715838, 2.843136421271733, 4.255521936076028, 5.437169500759669, 4.111685105732509, 1.125313633254596, 0.10821015919957842, 0.0751889811030456, 0.092759557201394, 0.01903889873730285, 0.10161985390420471, 0.27627647082720486, 5.217910408973694, 23.6696013041905, 32.983001436506, 46.82420907701765, 60.29734979357038, 20.14701747894287, 24.99187649999346, 34.586836746760774, 43.43052128383091, 43.08098520551409, 53.8222644669669, 48.6665552003043, 49.81399113791329, 10.747583014624459, 0.4742353984287807, 0.010826031311548181, 0.009823718889882522, 0.07517245198999133, 0.06530501254435096, 0.048315832391381264, 0.005979264579114637, 0.01678384018928877, 0.06745386509490864, 0.06254206544586591, 0.036857791511075835, 0.10625757290316479, 0.03519323993740337, 0.05288614232891372, 0.005108806354525898, 0.014480926262746965, 0.033833577896335294, 0.038398751323776584, 0.04465717835617917, 0.06050570721604994, 0.024567881964945366, 0.08072978949972562, 0.016165214723774364, 0.01953010550434036, 0.02587656058104975, 0.010667232912965119, 0.014355787441932728, 0.037637211116296906, 0.08793793485632964, 0.03173199548785176, 0.05783890174435718, 0.009034809972425657, 0.04562706613380994, 0.06677748781761952, 0.07685188722929784, 0.04517774363713605, 0.029624123059745346, 0.012090309988707304, 0.0383789143525064, 0.05635353769840939, 0.03716026885168893, 0.02748808803568993, 0.014692018507048488, 0.008995116522003497, 0.037334499681102376, 0.08513473706053835, 0.09353715154741492, 0.027053281099402478, 0.020605692074501088, 0.029550359517868077, 0.040160974620708396, 0.038767144948776276, 0.08731790312698909, 6.010859242507389, 55.50410025460379, 70.55273110525948, 70.63711697714669, 62.53152220589774, 50.50778613771711, 43.76623044695173, 40.716058118002756, 33.74891873768398, 50.66304363523211, 32.68385369437081, 36.23942061832973, 39.46518087387085, 25.88680968965803, 2.4873450100421906, 0.060308368876576424, 0.04805017914623022, 0.0682967955778752, 0.6987270265817642, 1.4080048927239008, 2.8895080472741808, 2.9293073288031986, 3.299352535179683, 3.834346456187112, 3.761195387159075, 4.823295286723545, 8.934148345674787, 22.9789833681924, 38.4042534828186, 52.07452848979405, 58.823490960257395, 60.922395842415945, 56.49966941561018, 57.76246282032558, 54.192544392177034, 55.06915691920689, 57.413875171116416, 60.3439930507115, 54.83759430476597, 54.73184272221157, 54.650941371917725, 61.55180535997663, 59.822739192417686, 58.75541945866176, 59.00273363930838, 58.91950811658587, 56.11421462467739, 55.49875708988735, 53.576513631003245, 55.0141931942531, 53.2817884172712, 55.602848052978516, 56.191971915108816, 59.419292041233604, 55.676353045872276, 56.04562200818743, 55.65923615864345, 60.55913707188198, 56.671015466962544, 56.918941089085166, 56.10022790091378, 64.76670210702079, 44.53751870564052, 23.02629712649754, 50.53517941066197, 50.63620969227382, 60.24726022992815, 55.541707379477366, 57.994320733206614, 57.203584466661724, 54.50556073869978, 53.64615542548043, 56.6865724836077, 54.114220823560444, 53.128855092184885, 50.56268038068499, 54.433799743652344, 51.41348729814802, 55.18081447056362, 60.14653219495501, 57.936251163482666, 56.32450532913208, 47.99094363621303, 45.599752358027864, 47.04461983272007, 50.24390050343105, 57.020162446158274, 61.04591396876744, 59.94989817483084, 54.21000868933541, 56.90657329559326, 55.97146735872541, 55.612426144736155, 57.9741153717041, 51.02045897075108, 45.08981711523873, 33.57532841818673, 15.517620359148298, 3.193818952356066, 0.9351757445505687, 2.638345867395401, 4.970731718199594, 3.5374922709805623, 1.3660636118480136, 0.31148554437926834, 0.1510171014815569, 0.01507356553338468, 0.11237457288163048, 0.29036842180149897, 4.672239278044019, 23.3424106325422, 39.50671720504761, 45.327810287475586, 52.161856923784526, 18.06796360015869, 30.566963400159562, 43.82288605826241, 49.7168344770159, 51.748300143650596, 62.147884368896484, 57.68632098606655, 62.66740812574114, 20.786979573113577, 0.45084667631558006, 0.04080891449536596, 0.028715669842703, 0.019885629016373838, 0.09877944524799075, 0.029402537271380424, 0.04025631218350359, 0.04965264815837145, 0.05065891219835196, 0.03907571892653193, 0.07637676343853984, 0.008105788662630533, 0.02947573084384203, 0.038342683975185664, 0.035897549108735154, 0.053558655349271636, 0.01286455406807363, 0.07085885559873921, 0.10935390461236238, 0.016813061299866865, 0.03970493123467479, 0.05092309641518763, 0.017321010918489525, 0.040127539807664495, 0.027072605776733587, 0.020578693166109066, 0.051127087790519, 0.07192982134542295, 0.13140355822231087, 0.08394584871296372, 0.1352014544286898, 0.07027484050818852, 0.11633790949625628, 0.18783585008765968, 0.16012201005859034, 0.09071095819984164, 0.14971368999353477, 0.09072380286774465, 0.11603393937860217, 0.08359280694276094, 0.1428280659019947, 0.09012668526598386, 0.09222277493349143, 0.08644233510962554, 0.13449172036988394, 0.12340620878551688, 0.3292764611542225, 0.15676696651748248, 0.12236859303499971, 0.12879533746412822, 0.17146430643541472, 0.1824898762362344, 0.1417891745056425, 10.53387553351266, 69.857070514134, 76.95883819035122, 81.47027574266706, 69.55241285051618, 56.840735639844624, 44.37444448471069, 42.984912463596885, 34.36870847429548, 54.931384563446045, 53.134385858263286, 48.74690416881016, 60.052356311253135, 43.888987745557515, 3.2866931344781602, 0.16499918406563147, 0.18913303262421063, 0.1921549697539636, 0.6319151031119483, 2.2288991638592313, 3.5812320496354784, 4.901144640786307, 5.275071067469461, 9.668861286980764, 9.140515054975237, 8.376406022480555, 10.703056352479116, 31.67217860903059, 41.34310177394322, 54.25371980667114, 61.38891874040876, 63.108681270054404, 58.36743204934256, 58.08783653804234, 55.7590331350054, 57.14334011077881, 59.14358752114432, 63.44538402557373, 56.17835691996983, 57.816627502441406, 57.69209493909563, 64.25741999489921, 59.1245425088065, 61.073963846479145, 61.86002050127302, 60.84925215584891, 58.58982304164341, 57.488599572862896, 56.422933510371614, 60.009103775024414, 56.024687085832866, 57.13697208677019, 59.416936601911274, 61.902119636535645, 57.42032309940883, 59.04703535352434, 58.124818325042725, 62.244742257254465, 60.83548082624163, 59.537196023123606, 59.36074651990618, 66.96889890943254, 47.69697230202811, 28.40438175201416, 51.77092695236206, 50.264199665614534, 59.994116510663716, 57.40523508616856, 61.45981815883091, 59.23347636631557, 58.24344491958618, 55.29112754549299, 59.01691491263253, 55.70268324443272, 53.85848890032087, 51.63295309884207, 53.68280369894845, 50.06678744724819, 56.65203993661063, 61.691102845328196, 60.391970361982075, 59.95305265699114, 50.53508560998099, 48.50535351889474, 49.79620722361973, 53.281611238207134, 59.239986828395296, 63.89840657370431, 60.050188473292756, 54.13840750285557, 57.375364780426025, 56.66648871558053, 55.29279163905552, 60.87180600847517, 53.05557244164603, 49.12553582872663, 37.11495617457798, 16.851874249322073, 6.08716653074537, 9.671029124941144, 16.132059982844762, 10.875736457960945, 3.302611457450049, 0.847059884241649, 0.283955451633249, 0.28731080730046543, 0.11271888869149344, 0.3152645230293274, 0.5200651735067368, 7.4093236071722846, 32.836481298719136, 46.091146332877024, 55.17960548400879, 73.81705733707973, 30.28544671194894, 36.21655757086617, 45.89992148535592, 58.44723905835833, 58.709484917776926, 73.60122544424874, 64.9935746874128, 76.25570133754185, 25.68346197264535, 0.8663212678262165, 0.09090930077114276, 0.11278915777802467, 0.1555387909923281, 0.19026033713349275, 0.1124067965096661, 0.0914446377594556, 0.13122966326773167, 0.17243739350565843, 0.11494908402008669, 0.1103336073990379, 0.1590090769210032, 0.13202543556690216, 0.10619780075337205, 0.14441515931061336, 0.1121088924950787, 0.07563431042113475, 0.15585725461798056, 0.18603767800543988, 0.14079703417207512, 0.13596861969147409, 0.13367833330162934, 0.10784329567104578, 0.13868807948061398, 0.1678130959293672, 0.20200178852038725, 0.11439381167292595, 0.17988073267042637], [0.03747655777260661, 0.049187291879206896, 0.042678132586713345, 0.04862433512295995, 0.06182137304650886, 0.027219425487731184, 0.024107959054942642, 0.03599779587239027, 0.040016175247728825, 0.01963767535718424, 0.031177734157868793, 0.036441903827445846, 0.031269780825823545, 0.04656737656997783, 0.04548980189221246, 0.1057093505348478, 0.04417405463755131, 0.04204851655023439, 0.018775837495923042, 0.0015091538017648937, 0.03322350027571831, 0.052035819206918986, 0.04796689236536622, 0.016504170106989995, 0.5205799373132842, 23.43789451462882, 62.963880811418804, 59.52641241891043, 55.834761551448274, 39.34959411621094, 40.84407867704119, 24.409603561673844, 14.615322078977313, 22.924492120742798, 30.142824513571604, 58.735089029584614, 40.596670695713584, 24.17867844445365, 2.247730084827968, 0.2764268070459366, 0.03912842074143035, 0.03514517251668232, 0.07759981602430344, 0.47954344217266354, 0.8327064258711678, 2.0895997243268147, 1.5389636712414878, 0.8806333627019609, 0.7254989242979458, 3.232428789138794, 11.365192753928048, 31.44084528514317, 42.787694794791086, 55.787162917000906, 59.4332857131958, 58.86039284297398, 59.05536624363491, 59.36073957170759, 53.14884853363037, 57.30024085726057, 53.93672909055437, 58.61163343702044, 55.24337952477591, 52.23559468133109, 49.42163678577968, 53.3353659766061, 56.55028704234532, 56.0767707824707, 56.1195056779044, 55.2264016015189, 57.41713735035488, 51.26520231791905, 46.64498029436384, 47.224296774183, 49.443839754377095, 51.1036045891898, 55.61467041288103, 52.781188079289024, 53.653794969831196, 52.778248991285054, 52.0070858001709, 52.68961777005877, 56.77609307425362, 54.736581393650596, 51.306335653577534, 50.48815400259835, 58.02471215384347, 44.30259663718087, 23.002233777727398, 62.37938444955008, 55.222218785967144, 58.57091004507882, 51.55618592670986, 56.54527044296265, 51.48418869291033, 53.07374892915998, 54.14737067903791, 55.8452707018171, 54.73525776181902, 55.986159324645996, 51.26060261045183, 52.8137195450919, 50.59514236450195, 56.366236209869385, 54.07607173919678, 53.7716120992388, 46.044951234545024, 43.45006309236799, 43.78402130944388, 45.94331645965576, 52.504194668361116, 57.04826096126011, 57.51844208581107, 54.356049401419504, 53.52312019893101, 52.978256361825125, 56.342518533979145, 59.15497561863491, 56.65126173836844, 60.23503834860665, 55.9585610798427, 43.20194639478411, 33.5001871245248, 16.494042021887644, 5.793160455567496, 1.8040126945291246, 3.359057102884565, 5.7938383391925266, 1.6841783076524734, 0.1505021612559046, 0.014305309525557926, 0.06542355939745903, 0.07910881683762584, 0.016051994370562688, 0.07164679081844431, 2.893608135836465, 23.113120079040527, 43.71150296075003, 50.93995714187622, 64.59308052062988, 26.035105092184885, 16.30718411718096, 29.081917967115128, 37.23700475692749, 35.64435952050345, 46.901921204158235, 47.39004257747105, 44.876316343035015, 9.326606052262441, 0.467476592532226, 0.04084520594083837, 0.043303063338888545, 0.017631978428523456, 0.05331932247749396, 0.08716940573815789, 0.035320539892252, 0.015108996935720955, 0.047503887210041285, 0.010227630430433367, 0.03781789820641279, 0.045848020884607515, 0.036813754588365555, 0.02886665066970246, 0.025272613524326255, 0.043982650086815865, 0.030544301361909935, 0.028980424028954337, 0.033660269874547205, 0.03553000365250877, 0.03232900791668466, 0.03616685626496162, 0.07572777861995356, 0.06450987128274781, 0.05333675404212304, 0.03431409604049154, 0.025405862534950887, 0.02678841325853552, 0.05211909580975771, 0.007468293986416289, 0.0062859250881176975, 0.04754212944369231, 0.02912081970966288, 0.02198466013318726, 0.018034660124353, 0.019752692131857787, 0.009573853458277881, 0.05918942391872406, 0.042204793343054395, 0.016857805595334088, 0.020338196606774415, 0.05180413681747658, 0.02279893777865384, 0.04571025113442114, 0.027012507930131893, 0.039144437560545545, 0.026004756202122996, 0.08582625245409352, 0.0361312196057822, 0.02965348327000226, 0.033811413549951146, 0.6393430531024933, 32.85089881079537, 72.97082928248814, 69.02142456599644, 61.42543152400425, 48.94450398853847, 51.31885630743844, 34.08758783340454, 20.986761127199443, 22.49325738634382, 35.65215539932251, 58.10965040751866, 37.92494589941842, 19.820347922188894, 2.430364353316171, 0.16636149239327225, 0.047872501358922036, 0.09638529550284147, 0.6483799996120589, 1.4668841447149004, 2.136250581060137, 3.9039600236075263, 3.0997629250798906, 3.11076192344938, 2.9049538927418843, 3.647638806274959, 12.009912627083914, 27.508816276277813, 44.883862086704795, 57.34905195236206, 62.99389702933175, 61.358103479657856, 61.11505549294608, 59.558262961251394, 54.67693110874721, 57.25370877129691, 54.77473742621285, 58.56582396371024, 58.146597453526084, 53.648097446986604, 51.295051779065815, 56.07483918326241, 59.369626317705425, 56.4477663721357, 56.9775595664978, 57.8734325000218, 59.50289971487862, 54.47592319761004, 49.68287168230329, 49.0207257270813, 52.52264213562012, 53.382697105407715, 57.301401206425254, 55.77835260118757, 56.53172492980957, 52.80109119415283, 53.41440173557827, 55.9285865511213, 58.76060281481062, 54.61284787314278, 53.10784373964582, 52.128300598689485, 61.17263521466936, 44.608616147722515, 25.84237595966884, 60.78690596989223, 56.76382950374058, 61.439272335597444, 53.33594267708914, 56.248603207724436, 54.75197860172817, 55.81996883664812, 55.24746853964669, 57.64568444660732, 56.10771458489554, 56.26242317472185, 51.49692474092756, 52.330256938934326, 49.52117320469448, 57.59449011938912, 55.835730825151714, 56.27859510694231, 47.77542093821934, 46.002376147678916, 45.22645344052996, 48.15998635973249, 54.782321384974885, 59.8170416695731, 59.55280862535749, 52.234462124960764, 53.51666532244001, 52.92063842500959, 56.61751086371285, 60.47284044538225, 58.44771153586251, 62.1914495740618, 59.095992360796245, 49.55401733943394, 37.8089040347508, 18.874779735292705, 5.0415829334940225, 1.488949994955744, 2.45474927340235, 5.793463136468615, 4.277686255318778, 1.8456866868904658, 0.16227782437843935, 0.18695661798119545, 0.07403964456170797, 0.11117901453482253, 0.05454790173098445, 2.9883127340248654, 24.6465162890298, 50.76933370317732, 59.59551920209612, 48.917246205466135, 24.20580073765346, 31.305272034236364, 42.31626646859305, 44.46904073442732, 43.6885461126055, 55.6144654410226, 54.17768914358956, 60.25191552298409, 15.410995040621076, 0.4891293506537165, 0.036787417251616716, 0.06588321258979184, 0.037947695170130046, 0.04625864652916789, 0.031187199721378938, 0.04822428444666522, 0.059554774314165115, 0.05752544570714235, 0.006339910182370139, 0.03723257015060101, 0.037347856642944474, 0.012752596638165414, 0.07060085622859852, 0.05280471812667591, 0.023050413034590225, 0.037644223775714636, 0.03308161860331893, 0.04167473196451153, 0.03300283729497876, 0.01389007578005216, 0.025386183323072534, 0.07592428236135415, 0.058199631316321235, 0.1219726949930191, 0.050460790150931904, 0.033579568312104256, 0.11538211149828774, 0.14521991541343077, 0.06851365536983524, 0.1394616501139743, 0.22200403735041618, 0.10374396706798247, 0.12278739841920988, 0.1610825170895883, 0.11660283670893737, 0.12254676276019641, 0.08861260222537176, 0.18064734153449535, 0.09943364121552024, 0.1823083952601467, 0.08897435638521399, 0.1837277276707547, 0.11148251646331378, 0.06955249248338596, 0.11031941923179797, 0.08283176206584487, 0.20333383418619633, 0.13261863802160534, 0.15082860445337637, 0.08608856052160263, 1.0611996735845293, 43.32233783176967, 82.32062407902309, 77.61331680842808, 71.83601474761963, 54.85863692419869, 55.31593261446272, 34.79874290738787, 22.421624932970317, 31.65286956514631, 39.079858098711284, 71.44466441018241, 53.29414231436593, 30.10437318256923, 3.451178273984364, 0.4545833415218762, 0.24027106857725553, 0.212897283158132, 0.4210687870425837, 1.3210906365088053, 3.6882141147341048, 8.808746388980321, 7.1412243247032166, 5.645159482955933, 4.789211767060416, 7.721876161439078, 17.37917651448931, 37.78542259761265, 46.81779588971819, 60.70060934339251, 63.532778467450825, 64.22476346152169, 61.24846090589251, 60.81926373073033, 55.267041615077424, 59.31537478310721, 53.977164132254465, 60.304082598005024, 61.13407966068813, 57.18258006232125, 54.317803042275564, 57.71081338609968, 61.00341878618513, 59.77670042855399, 56.94908584867205, 59.36322007860456, 62.08279364449637, 56.69376386914934, 51.75160748617989, 51.23868799209595, 54.52282353809902, 55.829925605228965, 59.9625369480678, 58.60839557647705, 56.356696333204, 54.013753346034456, 54.26650101797921, 57.42699684415545, 59.263680185590474, 58.98671109335763, 56.53197159085955, 55.061774458204, 62.16313566480364, 49.021159989493235, 28.74255231448582, 62.8456711087908, 59.28044618879046, 63.920418466840474, 56.29333223615374, 59.36809771401541, 56.96844005584717, 57.939714840480256, 57.812312671116416, 58.752126012529644, 58.42026615142822, 58.14373826980591, 51.804149763924734, 52.88202033724104, 49.32452876227242, 59.73705400739397, 58.664224352155415, 58.034099170139854, 49.949053696223665, 47.93297134126936, 48.17534187861851, 50.94556781223842, 57.8633576120649, 63.94127001081194, 61.54808112553188, 53.75706257138933, 55.51456076758248, 51.574317250932964, 57.64994369234358, 62.5684449332101, 60.83744021824428, 65.17818137577602, 63.38009180341448, 52.7189530645098, 42.89089638846261, 22.146455424172537, 8.747221827507019, 7.448719893183027, 12.195702246257238, 15.462873765400477, 3.8400991303580145, 0.7597021375383649, 0.12423700706235, 0.5021656368459974, 0.12587930608008588, 0.16400502169770853, 0.1594376124973808, 4.781039382730212, 33.434780257088796, 56.709703036717, 57.2779996735709, 81.05600329807827, 36.80612959180559, 28.5858930179051, 42.02127027511597, 52.01088646480015, 50.561134406498496, 65.30775138310024, 61.83530575888497, 73.46026733943394, 19.047996589115687, 0.7107199430465698, 0.13532318361103535, 0.1932710920061384, 0.14273411594331264, 0.16130312239485128, 0.2129818829042571, 0.0896032904939992, 0.15514521354011127, 0.11094736946480614, 0.0857452896556684, 0.12434787968439714, 0.16561154834926128, 0.1689638506088938, 0.1331164791647877, 0.11895389269505229, 0.15656312102718012, 0.11856098020715372, 0.17632979606943472, 0.12294043520731585, 0.08626045379787683, 0.09218045470437833, 0.11356907949915954, 0.1891370631222214, 0.13992430243108953, 0.22347845323383808, 0.11229736238185849, 0.11261776661766426], [0.07960125005670957, 0.007922333997807332, 0.013323718715193016, 0.03655276627146772, 0.04157880407625011, 0.04063297715038061, 0.028587725279586654, 0.0456941087863275, 0.035619519384843965, 0.05622546760631459, 0.03628963717658605, 0.05471853293212397, 0.0342145685239562, 0.017697674189028994, 0.04365589815591063, 0.08579761149095637, 0.05034451299746122, 0.03722427845267313, 0.07194885425269604, 0.017079460933538418, 0.03980409912765026, 0.0171909968235663, 0.04588958454717483, 0.18197085122976983, 3.440764878477369, 49.12105424063546, 60.84468024117606, 53.93254280090332, 46.63325868334089, 37.94181612559727, 18.926232882908412, 14.608276605606079, 30.077122347695486, 45.59861632755825, 33.00069155011858, 34.50491401127407, 22.440671682357788, 3.8533758350781033, 0.08561144862324, 0.03369475641687002, 0.03431534793760095, 0.1609453580209187, 0.26770812060151783, 1.8120767303875513, 0.8932293068085397, 2.8513335585594177, 2.0653211985315596, 2.347558545214789, 5.168186494282313, 12.601174797330584, 33.76175900868007, 48.453346252441406, 58.02995456968035, 57.17845630645752, 56.055547509874614, 56.992946352277485, 58.78722831181118, 55.79676532745361, 53.98254551206316, 53.9738324710301, 54.43319525037493, 58.96071788242885, 54.635943685259136, 47.285770961216514, 45.11180816377912, 53.960099356515066, 54.417593070438926, 53.83397218159267, 57.52977459771292, 54.585187094552175, 53.56182861328125, 47.74070773805891, 46.61708327702114, 46.84390722002302, 48.93983479908535, 52.45378201348441, 55.47080448695591, 53.73032937731062, 54.747180870601106, 51.1899984904698, 54.05347967147827, 50.03311995097569, 56.63720553261893, 51.17288160324097, 45.89705882753645, 47.58588102885655, 62.06215749468122, 42.370226178850444, 32.26360927309309, 60.158510889325825, 50.429907253810335, 54.048723629542756, 50.57426997593471, 52.28348514011928, 49.473904609680176, 49.53281143733433, 48.89022118704659, 54.14879158564976, 51.97745173318045, 57.88722814832415, 52.91327680860247, 50.95401334762573, 49.67628479003906, 54.71457992281233, 55.116616589682444, 51.609443868909565, 42.554165840148926, 42.425426142556326, 41.18729884283883, 47.056900773729595, 52.80184507369995, 58.00041430337088, 54.57292352403913, 53.08494247709002, 51.54357842036656, 52.859292779650005, 60.6759432383946, 57.049035685403005, 57.93044246946062, 57.27468538284302, 59.61155564444405, 59.445396423339844, 52.89661155428205, 37.678785119737896, 18.360562665121897, 4.4233322228704175, 2.8642259410449435, 3.216415145567485, 5.7585301995277405, 1.68832323380879, 0.38703659176826477, 0.03754557156935334, 0.11300075892359018, 0.09205463395587035, 0.07866557062204395, 0.03974431001448205, 3.646189672606332, 26.00540328025818, 28.160616363797867, 51.41431760787964, 48.538975851876394, 18.443998370851787, 12.607502000672476, 26.573722498757498, 37.08362327303205, 39.62369360242571, 52.28890126092093, 44.875930718013215, 43.79244600023542, 3.5811899261815205, 0.32369629772646086, 0.046460456414414306, 0.03683049404727561, 0.06067749871207135, 0.03225108834781817, 0.04944343545607158, 0.026187073472621183, 0.049424802884459496, 0.0006911926123263713, 0.018110679795167277, 0.01232717723386096, 0.03469716637794461, 0.0939953119627067, 0.035964798714433394, 0.009311373212507792, 0.013798081698561353, 0.0169979162913348, 0.07099983481956379, 0.03518642405314105, 0.041967319657227824, 0.08250861654856376, 0.038146872339504104, 0.07446009878601346, 0.06457136691148792, 0.007545579973209117, 0.04940400578613792, 0.06202850943165166, 0.07838283865047352, 0.06631702716861453, 0.07574954602335181, 0.028666272493345395, 0.004543671924953482, 0.017276707670784423, 0.03171752233590398, 0.037260115279683044, 0.032526424287685325, 0.023391504106777053, 0.006858684979046562, 0.050630244093814065, 0.019100292585790157, 0.02694891732452171, 0.06435381501380887, 0.010461847148170429, 0.03148658633498209, 0.04636471512328301, 0.07279286360634224, 0.03889031941071153, 0.03530636868838753, 0.053813231510243247, 0.17872251410569462, 6.255116650036403, 60.64762238093785, 71.33396571023124, 62.884407315935405, 54.12386839730399, 43.11403431211199, 29.437280109950475, 21.539493799209595, 28.08205655642918, 41.679898330143516, 28.199831996645244, 43.50273391178676, 21.572921582630702, 3.301708843026842, 0.06912703067064285, 0.05761500554425376, 0.07453215920499393, 0.7542946477021489, 1.8382032598767961, 3.1899952718189786, 4.001553118228912, 4.304990938731602, 2.8971677848270962, 2.25598606467247, 4.669821739196777, 12.060413002967834, 29.947663511548722, 49.553662981305806, 60.853177888052805, 60.12184524536133, 58.233227593558176, 59.955776350838796, 61.04707431793213, 57.18620702198574, 54.43681526184082, 54.56205654144287, 53.86126817975725, 59.26131779806954, 56.53040129797799, 50.66576732907976, 47.31670781544277, 56.592792647225515, 56.79299456732613, 55.193150997161865, 56.748595578329905, 57.34933682850429, 55.51197951180594, 50.41504853112357, 49.18275077002389, 48.76310736792428, 52.22863258634295, 53.917649337223594, 58.12979323523385, 55.78660706111363, 54.912176268441335, 54.02398109436035, 54.67030600139073, 52.479472977774485, 58.550822802952354, 51.32038491112845, 48.740845339638845, 49.572853905814036, 62.8137024470738, 45.065745081220356, 34.93095670427595, 63.02509444100516, 52.51351567677089, 56.44095713751656, 52.50510835647583, 54.55854422705514, 51.89485502243042, 51.01905196053641, 52.3746246610369, 57.78049339566912, 53.710877895355225, 58.67413248334612, 52.620775018419536, 50.56071056638445, 51.20740372794015, 56.871161801474436, 57.98650400979178, 54.030321325574604, 43.979369912828716, 43.66872637612479, 42.42220912660871, 49.37871776308332, 55.760252543858115, 59.128773961748394, 55.67616197041103, 52.64016396658761, 53.28342471803938, 53.5422694342477, 61.459185872759136, 60.31252465929304, 61.63671929495675, 58.439853123256135, 61.99636500222342, 61.987770080566406, 58.28002371106829, 43.68791730063302, 22.803350278309413, 4.660671395914895, 2.238611876964569, 4.307017207145691, 8.072435361998421, 4.401226094790867, 1.6214961111545563, 0.29557946217911585, 0.17718014972550528, 0.053942251551364145, 0.06093710621020623, 0.013164631939227027, 4.117294907569885, 28.079834869929723, 34.25441755567278, 49.71124117715018, 39.18564442225865, 18.874573026384624, 22.828674725123815, 44.10787337166922, 46.226333958762034, 48.12401206152779, 61.29397160666329, 54.49134125028338, 55.66661861964634, 5.945494932787759, 0.4168045472885881, 0.058624686008053165, 0.03615647467917629, 0.04204711537542088, 0.02720574282908014, 0.010245469116073633, 0.018415146939722554, 0.052460765333047936, 0.029930206813982556, 0.00971411936916411, 0.01710385935647147, 0.02241317365717675, 0.06857696947242532, 0.019379888029236878, 0.03160171337159617, 0.01681285265034863, 0.06382824214441435, 0.0823635593322771, 0.03489010441782219, 0.07038778944739274, 0.03406073784987841, 0.023571728096742715, 0.11012346510376249, 0.05070860131776758, 0.036052750423550606, 0.01710644966390516, 0.233887112566403, 0.13504263652222498, 0.16272698741938385, 0.10901672020554543, 0.12371376156806946, 0.16693036258220673, 0.10281930025666952, 0.1257387814777238, 0.12124054213719708, 0.18604044642831596, 0.13287021166511945, 0.09562853218189307, 0.09904423675366811, 0.17097338634942258, 0.17472025672239916, 0.21909388207963534, 0.1841843817383051, 0.11286590008863381, 0.2104786043720586, 0.18328571638890676, 0.17769905259566648, 0.1110515653022698, 0.2668770509106772, 0.27588946159396854, 10.301940321922302, 73.35582896641323, 76.58325331551688, 72.63140978131975, 60.80336625235421, 50.464724676949636, 28.74555219922747, 22.846903324127197, 41.87447568348476, 63.16586494445801, 44.049067292894634, 45.36675494057791, 30.639794417790004, 5.309827693871089, 0.1849200086934226, 0.15037307675395692, 0.21945699330951485, 0.6552188726408141, 1.343203061393329, 6.670572025435312, 7.1809806142534525, 7.842142530850001, 7.177495224135263, 7.182034569127219, 10.922170400619507, 17.476336649485997, 36.063485281808035, 52.231682845524375, 63.61127226693289, 61.28910786764962, 60.06708649226597, 62.1867664882115, 63.25293282100132, 57.53853627613613, 54.42725454057966, 54.58507592337472, 53.14637844903128, 61.818074226379395, 59.186624663216726, 52.502652168273926, 50.15309797014509, 59.80821745736258, 59.55196789332798, 56.434484890529085, 59.905179568699424, 59.249068123953684, 56.89536932536534, 52.24998787471226, 52.465468883514404, 50.842512130737305, 53.51042236600603, 56.93955292020525, 59.74113954816546, 57.17999185834612, 55.94545677730015, 53.78339276994978, 56.62742941720145, 55.10256733213152, 60.25347191946847, 55.24010344914028, 50.98387670516968, 51.28663751057216, 65.50419085366386, 47.75790452957153, 36.65950175694057, 65.09062712533134, 55.532101494925364, 59.10275295802525, 55.77343675068447, 57.26452711650303, 53.33539376940046, 53.594863823481965, 55.01615606035505, 60.339143208095, 55.79899917330061, 61.422165870666504, 53.389085974012104, 51.37321206501552, 50.63216584069388, 57.49211883544922, 61.94541386195591, 55.64420025689261, 46.588078022003174, 46.56760515485491, 45.46985578536987, 51.00835173470633, 58.120461804526194, 61.685405322483604, 57.461998394557405, 53.29994406018938, 52.5736141204834, 54.32960108348301, 64.88655853271484, 62.10747364589146, 63.1928517477853, 63.301778657095774, 64.60379464285714, 63.2307402747018, 62.52308014460972, 45.80957753317696, 24.730130910873413, 7.210220805236271, 6.835692056587764, 14.66067123413086, 19.179781334740774, 6.2985164012227735, 0.7909976382340703, 0.15466221874313696, 0.31463573819824625, 0.23280303073780878, 0.1992025872958558, 0.2587394347148282, 5.380803542477744, 39.049536160060335, 39.35241855893816, 58.75020830971854, 62.874186515808105, 26.165873663766043, 21.245692695890153, 39.55783857618059, 51.65921381541661, 52.903344358716694, 72.2355431147984, 61.035192898341585, 66.59590571267265, 7.136491732937949, 0.6514176651835442, 0.12527934541659697, 0.1169438548386097, 0.10527101012745074, 0.1690677207495485, 0.19346474590046064, 0.14754418283700943, 0.1809922137430736, 0.15721771733037063, 0.1611845823270934, 0.065556111213352, 0.1688130936984505, 0.1534004828759602, 0.12543395640594618, 0.11018793950123446, 0.10105337215853588, 0.13632615336350032, 0.16866954282990523, 0.09561955516359635, 0.17247438723487513, 0.16028571341718945, 0.11524478958121367, 0.18054885896188871, 0.1807719205639192, 0.06555683046047177, 0.12663127215845243], [0.04733263175668461, 0.022227701198841845, 0.014177694900094398, 0.010748781796012605, 0.03591041074001363, 0.02968909957313112, 0.07040308362671308, 0.008485343340518219, 0.046517958864569664, 0.013290166854858398, 0.03571585439411657, 0.021404882493828024, 0.07647234188126666, 0.05277814669534564, 0.054834172262677124, 0.05799439482923065, 0.07996557586427246, 0.024650890546451722, 0.03635121762220349, 0.029908670112490654, 0.12665675793375286, 0.014540808674480234, 0.05722076991306884, 0.4548337480851582, 21.293734277997697, 58.577941622052876, 58.50588880266462, 54.609728131975444, 36.93333721160889, 43.106346130371094, 25.439135517392838, 25.377454621451243, 35.925476687295095, 22.732209409986222, 44.899881158556255, 29.67797613143921, 3.267091614859445, 0.04901236555139933, 0.0209577092568257, 0.08051172191543238, 0.046154152136296034, 0.6392646144543375, 2.8835714629718234, 1.788768238254956, 1.5222586819103785, 1.2696948115314757, 1.4678065180778503, 4.928730726242065, 15.999161788395472, 29.98010117667062, 53.129820891789024, 57.2889187676566, 59.106171471732004, 55.24242762156895, 53.31719643729073, 54.04347079140799, 56.75320223399571, 57.529812812805176, 53.689748423440115, 52.95994438443865, 52.15836892809187, 54.363150460379465, 55.46060453142439, 48.89300046648298, 41.6624687739781, 48.36221020562308, 54.59072133472988, 53.126041071755544, 55.727985109601704, 50.082903793879915, 50.15169095993042, 46.33615023749215, 44.99944884436471, 46.4545510155814, 50.88389212744576, 52.891039099012104, 55.986767292022705, 53.321917738233296, 52.99519954408918, 52.08460685185024, 50.62625987189156, 48.337776865277974, 59.384599685668945, 49.13160160609654, 43.586685521262034, 46.28627259390694, 59.69709491729736, 39.458333424159456, 34.968786171504426, 61.78030381883894, 50.812926701136995, 52.61195428030831, 45.39027806690761, 50.063473156520296, 47.725421701158794, 48.663393769945415, 43.97328676496233, 49.010636942727224, 51.84843758174351, 51.762415409088135, 53.85133225577218, 52.1779385294233, 48.90854706083025, 54.84398317337036, 51.7396114213126, 50.11103357587542, 38.467374392918174, 41.30227415902274, 39.36985158920288, 47.7567789213998, 53.11478499003819, 56.71518516540527, 52.44920662471226, 49.519714082990376, 51.961925983428955, 54.80657754625593, 55.444533348083496, 55.056994097573416, 53.23161547524588, 54.800202574048726, 54.71227312088013, 54.94942556108747, 58.75836549486433, 58.477616582598, 45.15507459640503, 24.6963209765298, 5.087299908910479, 2.565287296261106, 6.1015371424811224, 5.633604194436755, 2.2378008919102803, 0.3662319209958826, 0.047501098431114636, 0.0566743286991758, 0.08039170264133386, 0.020614231437710778, 0.043796175092990906, 9.959782361984253, 44.40196977342878, 33.2387125151498, 50.73134790148054, 40.37711456843785, 18.530376638684952, 9.75414000238691, 25.62112968308585, 30.77488476889474, 43.2193203653608, 50.20701599121094, 50.084929193769185, 28.948561191558838, 0.17752732895314693, 0.09133685247174331, 0.06649831136954681, 0.024139302283791558, 0.0708668419559087, 0.022101385119770254, 0.05398011380540473, 0.0231709395136152, 0.032891242033136744, 0.04207845690793224, 0.043654578405299356, 0.016047280248520628, 0.019247478705697825, 0.04963608511856624, 0.05729487272245543, 0.05260884203016758, 0.075775751045772, 0.05152565247512289, 0.025149847879739742, 0.02843262065601136, 0.04395455534436873, 0.017109056934714317, 0.10029578102486474, 0.035811680502125194, 0.06620541494339705, 0.014911667077935167, 0.019882482310224856, 0.00248780963011086, 0.029212116596422026, 0.022374880533399324, 0.01488852224844907, 0.02623725961893797, 0.03452499150963766, 0.020016481102045094, 0.038620981720409224, 0.008995141967066696, 0.007026352254407746, 0.028329384945599095, 0.020019330949123417, 0.07761284389666148, 0.06728051975369453, 0.07504745226885591, 0.03396061661520174, 0.04076601751148701, 0.02423807153744357, 0.019066649123228023, 0.056522852541612725, 0.01945443358272314, 0.07028702699712344, 0.4747167240296091, 28.91908172198704, 69.00713906969342, 67.2149624143328, 60.80174732208252, 46.547604765210835, 49.51136234828404, 33.697703565870015, 22.6239686352866, 37.918477126530235, 27.33988298688616, 41.22779641832624, 24.6714186327798, 2.4202877283096313, 0.1083401936505522, 0.019051780724631887, 0.2412259301968983, 0.29835635317223413, 1.897860927241189, 4.146838213716235, 4.40164863211768, 3.5300570470946173, 3.079895636865071, 1.2842529160635812, 4.4436070663588385, 15.151547568184988, 30.54950257710048, 52.11526230403355, 59.742286000932964, 59.8062024797712, 56.755762645176475, 53.778073923928396, 58.20480251312256, 57.944411822727744, 58.45561163766043, 54.14910078048706, 53.398261070251465, 52.643617221287315, 56.41347701208932, 57.23162044797625, 50.67461585998535, 42.87592996869768, 51.019402844565256, 56.03122534070696, 54.94934565680367, 57.359731333596365, 52.749316692352295, 51.50026682444981, 48.804205962589805, 47.77703986849104, 49.06563193457467, 52.21966246196202, 54.92610393251692, 57.14520222800118, 53.92470175879342, 54.75967025756836, 52.21706730978829, 52.49663502829415, 50.93347447259085, 60.40913241250174, 50.912921701158794, 44.77451133728027, 49.453230244772776, 62.47925785609654, 41.581591742379324, 36.45722232546125, 64.87929071698869, 52.97123173304966, 53.9077342578343, 46.999147347041536, 54.04597561700003, 50.37271315710885, 50.37443283626011, 46.0131493295942, 50.93549639838082, 53.62079797472273, 54.83266108376639, 55.26203196389334, 52.48887389046805, 48.94951711382185, 56.61271660668509, 55.133879389081685, 51.29855019705636, 40.5978935786656, 42.66137654440743, 40.833538259778706, 50.568346636635916, 56.25160830361502, 58.050531659807476, 54.04022250856672, 51.51634495598929, 51.81982489994594, 57.385953835078645, 57.08151156561715, 56.30079460144043, 55.319146156311035, 58.188720907483784, 56.543818269457134, 58.452297346932546, 59.996937479291645, 62.23721040998186, 50.1395628792899, 29.693349020821707, 6.478724445615496, 2.0023933180740903, 5.353472803320203, 8.14004828248705, 5.830994699682508, 2.4008405889783586, 0.2864419567797865, 0.2940523512661457, 0.11938860294009958, 0.03748258316357221, 0.03821436282513397, 9.455340538706098, 39.672070435115266, 40.359869139535085, 49.35812330245972, 25.817550046103342, 17.53994393348694, 19.077734879084996, 40.1591009412493, 35.57578774860927, 48.07823732921055, 58.418897356305806, 58.900497845241, 38.45008380072457, 0.19055631410862717, 0.08120102528482676, 0.023680873847167407, 0.07097599788435868, 0.049096388542758565, 0.04022703000477382, 0.04075907270557114, 0.059690196333186965, 0.04761664955211537, 0.033473007780100615, 0.009933103823901286, 0.02436941895367844, 0.07614548477743353, 0.037398516067436764, 0.06765353080949613, 0.014361526151852948, 0.0446312074283404, 0.06799693738243409, 0.01549953455105424, 0.036967887210526636, 0.06337219197303057, 0.023126950088356222, 0.0693231001496315, 0.020327039794730287, 0.002516634645871818, 0.0374870547093451, 0.21606895939580031, 0.20411507226526737, 0.1386617658925908, 0.11164396708565098, 0.2098693342081138, 0.20593613811901637, 0.15138718805142812, 0.06579348990427596, 0.16297891390110764, 0.12739641538688115, 0.12521123407142504, 0.14706782411251748, 0.18438260895865305, 0.17981296059276375, 0.13354422764054366, 0.2686577982136181, 0.14839566286121095, 0.09947167988866568, 0.09494503707225833, 0.11789799721113273, 0.20206585579684802, 0.08900714998266526, 0.17933630331286363, 0.8301211531673158, 38.69773844310215, 79.06741496494838, 76.79687568119594, 71.73952511378697, 52.24527699606759, 56.821579456329346, 36.55680390766689, 36.672762393951416, 51.07680538722447, 31.984027658190044, 55.1817490032741, 38.84754507882254, 4.8344423685755045, 0.31657208715166363, 0.12993330854390348, 0.464316899222987, 0.3049513878566878, 1.7646763367312295, 7.29968363898141, 6.123647613184793, 6.188653222152165, 7.0851797206061224, 5.322733538491385, 10.36824437550136, 21.917300360543386, 33.939052718026296, 58.676821436200825, 61.00692762647356, 62.2444087437221, 59.707378251211985, 57.0404303414481, 60.53338704790388, 61.33142934526716, 61.57953562055315, 55.07592099053519, 54.090895720890586, 52.715357371738975, 56.591840744018555, 61.32820538112095, 54.61388315473284, 45.55251155580793, 52.83094760349819, 59.05674198695591, 58.32556915283203, 59.91031428745815, 53.70032010759626, 54.990166323525564, 50.62680183138166, 48.97325216020857, 50.71491888591221, 54.867037296295166, 56.69890901020595, 58.89732946668352, 54.11713211877005, 55.09602560315813, 53.12339728219168, 55.60138545717512, 53.547727244240896, 64.57827390943254, 53.96275009427752, 46.963200841631206, 50.283529554094585, 63.201773234776084, 43.71838167735508, 39.588417598179404, 66.0676828111921, 56.53575141089303, 57.472726413181846, 48.69552571432931, 56.05250767299107, 53.31341314315796, 52.103269713265554, 47.820195129939485, 54.224763189043315, 56.224298409053254, 56.507058824811665, 57.92979976109096, 51.68014178957258, 48.88093144553048, 56.99420050212315, 56.70851836885725, 54.13202210835048, 41.569613048008506, 45.33830901554653, 43.855045795440674, 52.389031750815256, 59.05726310185024, 60.13779136112758, 54.541229316166465, 51.29432569231306, 52.57089390073504, 58.258967195238384, 60.27364253997803, 59.35297843388149, 58.96156556265694, 60.06976849692208, 59.24334280831473, 59.62536866324288, 64.23809705461774, 64.58256789616176, 52.888329301561626, 30.57858078820365, 9.008495807647705, 8.131647910390582, 17.229029417037964, 19.13790454183306, 6.869571907179696, 1.3950282633304596, 0.29745805423174587, 0.40833434036799837, 0.21638278184192522, 0.17341349327138492, 0.10977146827748843, 14.416233607700892, 59.4557283946446, 44.82065085002354, 62.03953416006905, 58.7837472643171, 28.86567439351763, 14.991681677954537, 38.347066334315706, 41.09788942337036, 56.61927918025425, 67.84487220219204, 67.26446138109479, 45.694980893816265, 0.4265338166483811, 0.13862169161438942, 0.16751753964594432, 0.231445417872497, 0.2101212064070361, 0.1233367675117084, 0.1910292665873255, 0.08913147116878203, 0.10955846934978451, 0.22508146507399424, 0.13649020956030913, 0.12290596562836852, 0.13029624335467815, 0.08284728016172137, 0.14562185241707734, 0.18187159512724194, 0.1548288126609155, 0.15664506091603211, 0.11451848569725241, 0.08455162442156247, 0.0939093144344432, 0.08691832742520741, 0.19096050384853566, 0.09963232305433069, 0.17458161844738893, 0.12819624532546314], [0.057406634225377014, 0.03130430808024747, 0.03712928694273744, 0.009555630552183305, 0.045917200922433815, 0.04240548364552004, 0.023310269894344465, 0.024491031088733246, 0.03449040997241225, 0.12999969641012804, 0.01755245412433786, 0.08608020775552307, 0.02341205862882946, 0.03136140001671655, 0.021928167003872137, 0.026711920309545736, 0.014031350163609853, 0.017606580862775445, 0.011699701127197062, 0.03708880893619997, 0.07851391804537602, 0.016257286836792315, 0.013603179299804782, 2.954655660050256, 46.79100711005074, 63.10736806052071, 55.30300549098423, 40.74050188064575, 33.625351973942344, 30.894647393907817, 17.27793083872114, 39.76090662819998, 34.56080184664045, 35.62828138896397, 40.6769814491272, 7.175848066806793, 0.12059806446943964, 0.05211710770215307, 0.06444239097514323, 0.09800873803240912, 0.35783952847123146, 1.6174200155905314, 3.888436879430498, 1.8751455289976937, 3.2704462919916426, 3.139644065073558, 7.381656748907907, 19.90682520185198, 40.835740838732036, 51.811688559395925, 58.11064052581787, 56.55173226765224, 54.02126087461199, 49.23762764249529, 49.29217447553362, 52.430783476148335, 52.808098452431814, 52.87022577013288, 54.93176324026925, 51.80937133516584, 53.1519786970956, 52.489610399518696, 55.0846757207598, 50.84418317249843, 43.04558413369315, 41.62039048331124, 47.59554597309658, 49.65938329696655, 49.36755895614624, 48.39456101826259, 47.03126539502825, 40.70237711497715, 45.50719540459769, 46.74185902731759, 51.08526481900896, 53.982239791325156, 54.572461468832834, 51.87979480198452, 55.11832584653582, 51.76273850032261, 50.2287152154105, 49.77207612991333, 55.73671899523054, 42.56549835205078, 45.16242231641497, 48.45055307660784, 60.66697311401367, 36.49295343671526, 35.15169055121285, 59.94159507751465, 47.67244863510132, 48.570079462868826, 44.94589212962559, 50.473402976989746, 48.042780671800884, 48.37047856194632, 43.35183293478829, 40.67971903937203, 45.73201131820679, 53.72617088045393, 54.98102944237845, 53.589975765773225, 46.57169764382498, 55.21114683151245, 52.53269965308053, 49.04041692188808, 39.96667752947126, 39.97651965277535, 39.868888582502095, 47.35717759813581, 50.556854316166465, 56.49763706752232, 53.44340699059622, 50.873348236083984, 51.079977239881245, 53.195193018232075, 57.52431678771973, 54.617009844098774, 51.65619134902954, 48.31630345753261, 52.60596145902361, 55.2526136807033, 55.28071914400373, 56.90981463023594, 58.789979798453196, 50.96113177708217, 28.37931959969657, 5.210339478084019, 2.3213505915233066, 4.1596889070102145, 6.02238586970738, 2.4607438317367007, 0.04733186501211353, 0.022595236477042948, 0.236906213419778, 0.08697748889348336, 0.029655054078570435, 0.2289970192526068, 17.158420085906982, 39.0141281400408, 44.09335511071341, 65.9629248210362, 40.37053462437221, 22.4946939264025, 18.94094569342477, 38.042089053562705, 39.81554378782, 49.58317198072161, 46.57594646726336, 44.150976521628245, 9.0433349439076, 0.34577267883079393, 0.0406111452861556, 0.055197646508791616, 0.037675500847399235, 0.01910527133648949, 0.07325288320758513, 0.037494393065571785, 0.0054891421958538035, 0.05089501863611596, 0.015477146288113934, 0.05885092993932111, 0.03101694510717477, 0.01719005705256547, 0.00795771281367966, 0.07111228164285421, 0.05219396536371537, 0.0703965900465846, 0.029583237932196686, 0.028964013659528325, 0.0924904230715973, 0.008733700728043914, 0.08144062957061188, 0.03317259657861931, 0.04685313141505633, 0.025742599108655537, 0.006174336611625871, 0.03593265651060002, 0.032382618968508074, 0.03378609740840537, 0.02804416275051023, 0.05552683098773871, 0.030302010077450956, 0.007680420996621251, 0.04234940611890384, 0.036315964335309606, 0.04063389656533088, 0.03579919545778206, 0.04133150181067841, 0.00668744309639026, 0.050676957837172916, 0.04089895609234061, 0.03378717627908502, 0.03122030883761389, 0.03602183297542589, 0.031511648025895865, 0.03984160175813096, 0.04615235062582152, 0.0611076627724937, 4.344795865671975, 58.935447284153526, 70.57893971034459, 63.325687408447266, 47.66973188945225, 44.03025851930891, 38.37774610519409, 21.744043554578507, 39.23098489216396, 36.474210671016145, 32.13425465992519, 34.25380264009748, 6.9134953788348605, 0.14189772653792584, 0.08512949198484421, 0.030040282157382796, 0.22163039525704725, 1.3996730255229133, 2.0640933215618134, 4.066932192870548, 4.09734011547906, 2.283245150532041, 3.1693389288016727, 5.9360449484416415, 20.67735263279506, 39.63509559631348, 53.17481395176479, 59.57607814243862, 59.90367875780378, 55.91546835218157, 51.26356949125017, 51.33623027801514, 55.481911182403564, 55.52041809899466, 56.86106954302107, 58.234203815460205, 51.98166234152657, 52.008763790130615, 52.9869589805603, 57.203629629952566, 52.59755066462925, 44.99416126523699, 43.553601673671174, 49.66331945146833, 50.43623011452811, 52.60101086752755, 50.214773654937744, 49.132098402295796, 43.65187699454171, 48.48027399608067, 48.64652006966727, 55.8568047114781, 55.01239013671875, 56.821673257010325, 52.05887419836861, 56.05098949159895, 51.83797359466553, 52.88947922842843, 53.42176682608468, 57.049661023276194, 44.35329416819981, 46.36182730538504, 50.66392953055245, 62.16196141924177, 39.372436319078716, 37.65932321548462, 61.71182932172503, 50.72824205671038, 51.618987219674246, 46.12955597468785, 53.55520003182547, 51.119463852473665, 50.2170352935791, 45.711899757385254, 41.90453359058925, 47.963522570473806, 56.83287027903965, 57.12868635995047, 54.31806359972273, 49.27091646194458, 57.71046945026943, 54.69802583966936, 52.58304282597133, 41.465734004974365, 42.05018172945295, 41.84078734261649, 49.40475961140224, 54.299407686506, 57.7186335836138, 54.420080525534495, 50.13207619530814, 50.50208861487252, 55.676832471575054, 60.066454206194194, 56.46634932926723, 54.59855890274048, 51.11572919573103, 54.99492931365967, 56.87097420011248, 57.73002168110439, 59.40324170248849, 62.656812122889924, 53.238462924957275, 30.992533615657262, 7.025875542845045, 2.0832831604140143, 5.87549443755831, 5.86961669581277, 6.028277507850102, 2.1684003302029202, 0.16664913695837769, 0.24136703833937645, 0.047949708466018946, 0.05676372229520764, 0.30304199031421114, 18.161821603775024, 41.28539003644671, 50.12840754645211, 67.66749164036342, 36.56097977502005, 18.861145632607595, 27.28968746321542, 47.20328194754464, 47.24130596433367, 56.48500176838466, 54.73938151768276, 55.54522316796439, 11.568076678684779, 0.33702120557427406, 0.11995114918266024, 0.044266766269824336, 0.05556482894878302, 0.03780434446941529, 0.06425295078328677, 0.013631048429358219, 0.018112829054838846, 0.032716437841632535, 0.0395034640096128, 0.02932221908122301, 0.04636245560167091, 0.009021302036541914, 0.010280556161887944, 0.02459058235399425, 0.05467345445816006, 0.026836677454411983, 0.05704070707517011, 0.04785474070480891, 0.03218846295827201, 0.0710624839578356, 0.016091690365491167, 0.030013252714914933, 0.07727960856365305, 0.05775673793894904, 0.08170362974384002, 0.1397257223725319, 0.08516242128929921, 0.1392978381897722, 0.0679589801334909, 0.11914994860334055, 0.10840800644031592, 0.06912282375352723, 0.10556086671671697, 0.3020164253456252, 0.12889562493988446, 0.16149973470185483, 0.11004083310919148, 0.10226051988346235, 0.20410756766796112, 0.10236930940300226, 0.08620558745626893, 0.08095644733735494, 0.14938004075416497, 0.12911903938012464, 0.25056949311069077, 0.17482572820569786, 0.1624369951231139, 7.041000468390329, 69.15555259159633, 78.32825865064348, 71.69586263384137, 55.87350123269217, 46.80663013458252, 43.84778145381382, 25.048264605658396, 54.312762124197825, 45.89437682288033, 46.13685505730765, 52.36297600609915, 9.294751167297363, 0.4482111105961459, 0.17854472436010838, 0.171591884589621, 0.15625244698354177, 1.055811128446034, 5.891913899353572, 11.915126170430865, 8.886908411979675, 8.72549307346344, 8.0052957875388, 11.62536631311689, 24.665332010814122, 45.294597898210796, 56.19939259120396, 61.79007298605782, 60.313608578273225, 58.18152257374355, 53.64974764415196, 53.06117268971035, 58.31464658464704, 57.73232500893729, 58.821621894836426, 59.46644251687186, 51.7866507257734, 53.30410950524466, 53.11418397086007, 60.67308752877371, 55.181839329855784, 46.742432253701345, 45.241920130593435, 52.19987746647426, 53.5399626323155, 54.977631773267476, 52.824742862156455, 51.41992827824184, 45.63236025401524, 50.84883499145508, 50.38547004972185, 55.43272488457816, 56.985115732465474, 57.88758250645229, 52.24751431601388, 56.08675881794521, 54.088484695979524, 55.75861276899065, 55.1308673449925, 60.06693363189697, 46.77940361840384, 48.47585494177682, 52.498080253601074, 64.83708735874721, 42.610342025756836, 40.3280394417899, 63.745115416390554, 51.83757407324654, 53.778080872126985, 49.503754070826936, 55.95274543762207, 54.014962332589285, 53.73194830758231, 47.59989207131522, 44.13205657686506, 50.02120726449149, 58.858905928475515, 61.366441317967, 53.58412538255964, 48.958601883479524, 59.1693514415196, 57.64930098397391, 53.4704042162214, 43.56402744565691, 43.473714760371614, 43.202071462358745, 51.94648361206055, 54.552634784153526, 59.75958701542446, 56.40529898234776, 52.23003264835903, 50.757125718253, 57.36251756123134, 63.23345702035086, 58.94117954799107, 58.4815353666033, 52.79364619936262, 58.021331855228965, 61.15612629481724, 61.2658383505685, 61.68238285609654, 65.2019372667585, 57.330903257642476, 33.60514661243984, 9.615787472043719, 8.406226822308131, 11.269530824252538, 15.521893501281738, 7.735706550734384, 1.008370891213417, 0.09701080300978251, 0.32632714084216524, 0.1671446303703955, 0.19323104486933776, 0.655877377305712, 25.021910088402883, 51.86109719957624, 52.66955484662737, 76.49096734183175, 55.28071566990444, 29.50646332332066, 26.86271892275129, 50.43151923588344, 54.701413086482454, 64.50986889430455, 63.434850556509836, 65.58649921417236, 13.975650072097778, 0.6708964513880866, 0.186483733355999, 0.10323129993464265, 0.18700953014194965, 0.10909371357411146, 0.1715234611183405, 0.10053143623684134, 0.13956856009151253, 0.13382970089358942, 0.10926274343260697, 0.174905089661479, 0.09538439528218337, 0.13433664797672204, 0.06116406260324376, 0.11236909710403, 0.11094921508005687, 0.1826559408966984, 0.08983485413981335, 0.11361984748925481, 0.23788086112056459, 0.08679343626967498, 0.11279488461358206, 0.07926595197724444, 0.13085215352475643, 0.16810325107404164], [0.03389542975596019, 0.023924785133983408, 0.07540886037583862, 0.014107554735216712, 0.061022588051855564, 0.015997691213020256, 0.008347135087076043, 0.03250937270266669, 0.03509749864627208, 0.028649295547178814, 0.03196765069982835, 0.01960388770593064, 0.027688866547708, 0.0414299063517579, 0.02117418228382511, 0.04482553646500621, 0.010596331940697772, 0.024121651891618967, 0.052485358834798844, 0.02309041776295219, 0.031186490652284453, 0.10595204215496778, 0.2500139900616237, 12.210848450660706, 55.11701263700213, 60.26539502825056, 57.16156870978219, 33.17100231988089, 19.354349613189697, 35.618425369262695, 35.50396421977452, 23.193872043064662, 28.518934965133667, 45.018716199057444, 12.170462046350751, 0.18739902281335422, 0.06151443773082324, 0.017519745343763913, 0.007288329536095262, 0.6259745561650821, 1.1156530316386903, 3.1025428559098924, 2.929932883807591, 3.797003362859998, 2.3446591922215054, 12.056691374097552, 26.320019449506486, 48.77424880436489, 54.78719554628645, 58.17864254542759, 54.9004442351205, 51.08702271325247, 48.91072532108852, 51.70015607561384, 51.26024825232369, 49.97993496486119, 49.4203895841326, 54.30327088492257, 55.2028089932033, 53.14103181021554, 51.23452254704067, 49.72586018698556, 55.00790854862758, 52.271593298230854, 47.97354187284197, 43.488764558519634, 41.42455203192574, 42.8633120400565, 42.23485442570278, 41.94497905458723, 43.8878447668893, 41.270889145987375, 46.061039788382395, 47.10490935189383, 51.476528303963796, 51.91216993331909, 54.76111895697457, 50.5344672203064, 53.15045356750488, 49.09314680099487, 50.3164883341108, 52.16475084849766, 48.96432719911848, 38.6072416305542, 46.99292523520333, 47.95468098776681, 58.88735185350691, 34.65792029244559, 34.04502316883632, 60.483408655439106, 47.25563314982823, 46.88197292600359, 42.443116256168906, 49.356646810259136, 48.417663778577534, 50.48485360826765, 43.77226843152727, 41.151967253003804, 42.447677748543875, 51.29218564714704, 52.327734742845806, 54.45648908615112, 46.91689804622105, 53.24169383730207, 53.37626654761178, 51.237089906420024, 42.746422495160786, 39.05491753986904, 41.923314571380615, 50.01965781620571, 52.51785830089024, 55.10314055851528, 47.81755134037563, 48.407210213797434, 49.829259804316926, 53.62268441064017, 52.59027937480381, 56.264021260397776, 49.67962339946202, 46.78711264474051, 47.34005028860909, 52.460556507110596, 54.29834113802229, 56.22931848253523, 54.694127900259836, 61.73647458212716, 51.45227214268276, 28.322424275534495, 6.591738632747105, 4.172373277800424, 5.91554993391037, 5.51083517074585, 1.2694431564637592, 0.6661308013967105, 0.23003886906164034, 0.16838564377810272, 0.052364701737782786, 0.08032368629106454, 1.9388987251690455, 29.96219219480242, 36.064895766122, 51.13624722617013, 55.77783843449184, 50.274476051330566, 24.782117332730973, 16.896651915141515, 29.099788733891078, 37.21756717136928, 44.134571824754985, 56.4443895476205, 33.73574147905622, 0.28427648012127193, 0.024791995296254754, 0.043328108066426854, 0.05436806620231696, 0.12182834345315184, 0.03327776272115963, 0.0715749068185687, 0.029061149340122938, 0.010225224175623484, 0.018848800366478305, 0.041307708980249505, 0.05866877721356494, 0.019614676412727152, 0.06671801422323499, 0.03517138432445271, 0.033840074869138856, 0.03922596354303615, 0.04118810021983726, 0.06605163855212075, 0.027907232687409435, 0.01049683750274458, 0.027461363933980465, 0.06422446588320391, 0.03796201225902353, 0.025954548003418104, 0.022368887372847115, 0.02393539233266243, 0.017610462083082114, 0.016606944413589578, 0.05091200915298291, 0.047209280875644515, 0.01208276128662484, 0.04182538030935185, 0.009450712074924792, 0.057535623732422075, 0.030005782044359615, 0.03621556829395039, 0.03551926922851375, 0.01319925842939743, 0.026998467344258512, 0.06780441664159298, 0.03745917370542884, 0.051494948765529056, 0.013791234432054418, 0.02527875087356993, 0.010954712933328534, 0.06387004668691329, 0.3223646320402622, 17.50199634688241, 65.58374077933175, 68.7262442452567, 63.56291280473982, 42.92289284297398, 30.12881694521223, 40.74449362073626, 25.568339007241384, 30.337023190089635, 28.320068836212158, 38.73991053444998, 12.517814653260366, 0.031321210387562, 0.040421735628374984, 0.08298783869083438, 0.015997686124007617, 1.0587075501680374, 1.9749353400298526, 1.411477580666542, 2.2130125420434132, 3.880458176136017, 3.1052535218851904, 11.730046136038643, 26.63878195626395, 50.593127386910574, 57.2001451083592, 61.50473131452288, 56.56040014539446, 52.34596334184919, 52.97405270167759, 51.9674254826137, 52.29511989865984, 52.71259893689837, 53.72432613372803, 55.756875719342915, 56.40141841343471, 53.193931920187815, 50.922920158931184, 50.65798882075718, 56.256704807281494, 54.78095258985247, 49.115863936288015, 44.3193313734872, 43.11561155319214, 44.80501740319388, 44.64200919015067, 42.4824743270874, 45.57354375294277, 44.346224376133506, 47.42055211748396, 48.275521005902974, 54.14351095472063, 54.294342449733186, 54.59671415601458, 51.42056056431362, 53.20632055827549, 49.33059106554304, 51.722438948495046, 54.547180448259624, 52.151900155203684, 40.38704007012503, 48.75512736184256, 50.00047731399536, 61.27917889186314, 36.97430031640189, 36.08970430919102, 62.08083425249372, 48.65780394417899, 47.726717540196006, 45.520424774714876, 51.53581380844116, 48.94467421940395, 51.68063511167254, 45.477318150656565, 43.16004875728062, 44.084860937935964, 53.3981533731733, 54.681707995278494, 53.5570239339556, 47.975542954036165, 54.35890858513968, 55.606120654514854, 53.51691198348999, 43.827760219573975, 41.18746559960501, 42.28477028438023, 51.175716468266074, 54.8152106830052, 56.49798100335257, 49.34408794130598, 48.86201844896589, 48.55397701263428, 54.73217623574393, 55.55272722244263, 57.76964030947004, 52.355732509068076, 49.82133885792324, 49.32046059199742, 53.712927613939556, 55.863884925842285, 58.19403280530657, 57.00198943274361, 64.421140398298, 55.38631786618914, 30.736551557268413, 7.678422127451215, 2.416614736829485, 4.169161907264164, 5.521844591413226, 6.229410920824323, 2.5544172738279616, 0.6567578443459102, 0.019078379297362905, 0.0888323729325618, 0.05582480285582798, 1.9345456787518092, 28.276984793799265, 41.20565945761544, 63.52581637246268, 46.644365378788535, 33.12258032390049, 21.861257927758352, 24.628096614565166, 37.68966599873134, 44.80510425567627, 50.61964866093227, 65.23505932944161, 39.958412647247314, 0.3877638184598514, 0.03109265604455556, 0.024046463426202536, 0.08035128231027297, 0.04964404433433499, 0.037147814341421635, 0.13969752245715686, 0.05181041665907417, 0.04630709392949939, 0.07421807891556195, 0.02137293367247496, 0.03932896515886698, 0.037030424390520365, 0.02842334338596889, 0.028042826036523496, 0.038084111242954216, 0.06941736901977233, 0.03890426330534475, 0.03446092762585197, 0.017973591972674643, 0.060886602848768234, 0.03320330028821315, 0.07018300757876464, 0.039132600517145226, 0.02152544289960393, 0.09517102994556938, 0.04255774351102965, 0.18567136409027235, 0.10238342971674033, 0.12558609752782754, 0.06924424080976418, 0.12381727887051446, 0.09834641098443951, 0.12016902677714825, 0.1349299182849271, 0.08882632718554564, 0.0779535159734743, 0.12253437271075589, 0.08832227744694267, 0.11794225126504898, 0.06632773445120879, 0.11577475257217884, 0.09531056388680424, 0.12847582889454706, 0.18932948208280972, 0.14833960229797022, 0.2321137205830642, 0.39650459800447735, 24.44613892691476, 76.81124455588204, 77.5892413003104, 74.3700019291469, 47.00122138432094, 30.24113804953439, 46.269148758479524, 45.54516383579799, 34.20800011498587, 36.757714544023784, 57.91050461360386, 16.811293295451573, 0.38208290615252083, 0.17066789631332668, 0.1982922511441367, 0.08752892073243856, 1.7520942347390311, 4.664854211466653, 6.979905392442431, 7.55948633807046, 10.536161490849086, 7.8345333848680765, 15.70753720828465, 30.949329716818674, 55.56386171068464, 58.791821071079795, 63.84214006151472, 58.95934908730643, 55.22239943913051, 54.21472304207938, 56.089684009552, 55.071314334869385, 54.32286480494908, 53.37109013966152, 58.29276670728411, 59.37052958352225, 55.09372922352382, 50.87162160873413, 51.03928858893258, 57.70984411239624, 57.624680042266846, 50.62613827841622, 47.96238306590489, 45.1054470879691, 46.80467421667916, 46.041247844696045, 44.956793853214805, 47.25733198438372, 45.80688163212368, 50.54821423121861, 50.804779938289094, 56.082294600350515, 56.62911435535976, 55.7573447227478, 52.297343322208945, 53.8090489932469, 53.731190953935894, 55.469571181706016, 57.03853348323277, 54.40452003479004, 43.08952106748308, 51.87272153581892, 52.08481182370867, 63.53316756657192, 40.17522076198033, 39.28608063289097, 63.58320154462542, 52.567496231624055, 49.84771769387381, 47.64276245662144, 53.52851894923619, 52.31652035032, 53.79988431930542, 47.55685492924282, 45.42975773130144, 45.95198086329869, 54.56359904153006, 56.27875491550991, 54.81796564374651, 46.854485852377756, 56.03445277895246, 58.39512756892613, 55.585929189409526, 47.07242999758039, 42.47201034000942, 45.512201581682476, 53.05839341027396, 56.56883525848389, 58.85211753845215, 50.01107679094587, 50.43962778363909, 49.56303262710571, 56.65008054460798, 58.770865304129465, 60.90701253073556, 55.6267602784293, 52.59852341243199, 51.75340359551566, 57.344528675079346, 58.73789610181536, 61.46232645852225, 59.64239174979073, 68.74759605952671, 57.284937449863975, 33.40697704042707, 10.969472868101937, 11.852300558771406, 16.848707607814244, 16.081574371882848, 7.10406231880188, 2.01738383940288, 0.46929311220135006, 0.2888764318610941, 0.37972461698310717, 0.20851417763956956, 3.2507989576884677, 40.664398261478965, 48.0058787890843, 56.875671182359966, 65.39306831359863, 67.59098502567836, 35.93242835998535, 26.793535709381104, 41.952375411987305, 51.806817872183665, 59.578857421875, 71.90760203770229, 45.79723405838013, 0.7278064861893654, 0.09215089093361582, 0.15372270558561596, 0.13090294865625246, 0.29746171832084656, 0.12085144301610333, 0.20366330364985125, 0.17997065213109764, 0.10274116016392197, 0.17599861669753278, 0.15950425820691244, 0.08871609238641602, 0.09708498045802116, 0.10938979232949869, 0.13787740655243397, 0.2054823338985443, 0.18747748860291072, 0.09477044322660991, 0.10928485010351453, 0.08834734253053154, 0.13509431374924524, 0.09436901512422732, 0.188432404505355, 0.1411622352898121, 0.12373052138303008], [0.03224389926929559, 0.025861205333577733, 0.039244674146175385, 0.028526426426001956, 0.03870514381144728, 0.011895760428160429, 0.010377734250921224, 0.059839426539838314, 0.02207714954524168, 0.04022419033572078, 0.07130736724606582, 0.021529546340129206, 0.01527418798234846, 0.005786014413128474, 0.05456258183611291, 0.03282406028094036, 0.021747844626328776, 0.06866950807826859, 0.013653729310525315, 0.08426965240921293, 0.10111374141914503, 0.03160091609294925, 1.8888601873602187, 55.082890033721924, 68.30842127118791, 62.59399345942906, 42.98590605599539, 32.947134835379465, 22.750813211713517, 36.12329190117972, 51.10682855333601, 27.521092006138392, 47.536357743399485, 24.117638519832067, 0.5905978030392102, 0.060160353247608454, 0.08433592492448432, 0.07225745197917734, 0.14329652647886956, 0.8584986818688256, 2.2507912005696977, 0.3951435653226716, 0.7917241592492376, 3.1249403740678514, 14.608339139393397, 37.49920197895595, 46.09330722263881, 57.499866076878135, 54.936588764190674, 54.60747691563198, 52.40910857064383, 50.1995918410165, 52.16471610750471, 51.352857317243306, 53.85713747569493, 52.34967367989676, 51.42639010293143, 53.27506603513445, 55.46894931793213, 52.76505436216082, 51.61220230375017, 51.95583241326468, 54.098114899226594, 52.31732286725725, 49.12778009687151, 49.63537727083479, 46.982846873147146, 47.52836036682129, 46.65796995162964, 41.00242117473057, 41.935182094573975, 43.69599805559431, 45.916829926627024, 47.3619510105678, 51.85597290311541, 53.503435952322825, 52.354728494371685, 48.80030802318028, 50.239957400730674, 47.011324065072195, 52.95317683901106, 49.28246089390346, 44.65766000747681, 37.89869213104248, 48.52420398167202, 48.788044452667236, 59.15947110312325, 34.950272696358816, 38.17681115014212, 58.964671407427105, 46.36369637080601, 45.4545384815761, 42.02088117599487, 48.57536704199654, 50.6410664830889, 50.08102430616106, 45.580811568668906, 38.144693102155415, 39.87342923028128, 51.166207858494346, 52.85444988523211, 53.36070953096662, 47.501832144601, 52.87377977371216, 54.280442578451975, 51.9238463810512, 43.078007902417866, 38.263587202344624, 42.25454214641026, 50.18560511725289, 52.684017521994456, 54.77025931222098, 50.4008846282959, 50.078248500823975, 50.11770037242344, 52.122068064553396, 53.27830389567784, 53.84180280140468, 53.51431335721697, 47.11009965624128, 44.643586431230815, 46.721156869615825, 49.50195101329258, 51.77090610776629, 55.41462482724871, 53.276862144470215, 58.89889281136649, 50.36641461508614, 24.315644809177943, 4.070182647023882, 2.7999244885785237, 7.0553363391331265, 7.04239227942058, 1.285530950341906, 0.661348432302475, 0.10309490761054413, 0.1511299554258585, 0.1594493104411023, 0.012947784021629818, 7.331529838698251, 34.47050305775234, 20.64144434247698, 49.51871006829398, 76.2999266215733, 63.8878036226545, 27.925515379224503, 25.33104760306222, 32.82453734534127, 48.38129343305315, 52.36560589926583, 48.03551633017403, 5.605875670909882, 0.17012536685381616, 0.04692126311627882, 0.059169190004467964, 0.07297159651560442, 0.04056651803797909, 0.0379009780340961, 0.06901829543390445, 0.050904460450900454, 0.026515576023874537, 0.02929723881451147, 0.022621222671919634, 0.02434708158086453, 0.08324585841702563, 0.04213919597012656, 0.07928636909595557, 0.029070899888340915, 0.03654582825090204, 0.07081821135112218, 0.01590210259226816, 0.04360504534893802, 0.006524838540436966, 0.0500801014713943, 0.08229261171072721, 0.010562464561579483, 0.019166956955034817, 0.035966389879052124, 0.07716986909508705, 0.038972347509115934, 0.05170328615765486, 0.01555691147223115, 0.03870757296681404, 0.07129272446036339, 0.014586677641740866, 0.02489562625331538, 0.037814254473362646, 0.04182749394593494, 0.04200353646384818, 0.024864245705040436, 0.03843774673129831, 0.05191102304628917, 0.023393787377114807, 0.034652372888688526, 0.0703013576567173, 0.08580491252775703, 0.0491699179900544, 0.03916274782802377, 2.551561129944665, 64.03149931771415, 76.83400685446603, 69.38466249193463, 51.16028104509626, 39.074525356292725, 23.374417509351456, 41.06888764245169, 43.37948676518032, 22.022753170558385, 41.095009395054404, 23.026104313986643, 0.9306506216526031, 0.022627102177856222, 0.09375230143112795, 0.3014261270208018, 0.761946297117642, 1.5989564806222916, 5.92331063747406, 2.7053940296173096, 2.0700177465166365, 4.049491345882416, 16.316208090100968, 38.12727744238717, 50.320375851222444, 59.56244577680315, 58.28095129558018, 56.322646686008994, 54.45878546578543, 52.40993193217686, 55.18312474659511, 54.0653715133667, 55.84275892802647, 53.094107151031494, 52.10129295076643, 54.30217654364449, 56.656240122658865, 53.65157502038138, 51.3537084715707, 51.459008421216694, 56.30300065449306, 54.47637135641915, 52.29791307449341, 50.50639302389962, 48.94107157843453, 49.327311515808105, 48.618570940835134, 44.88863549913679, 43.81720243181501, 44.212613991328645, 48.02583054133824, 48.914286272866384, 53.58101953778948, 56.10461221422468, 52.058269705091206, 49.10761989865984, 51.2062086377825, 48.88979387283325, 55.72034903935024, 51.701566559927805, 46.677734102521626, 38.79095547539847, 51.315382208142964, 50.82607964106968, 62.393933977399556, 37.71785136631557, 39.80281816210066, 61.35219751085554, 49.71408993857247, 47.678378922598704, 43.76188087463379, 51.95582546506609, 51.56825842176165, 52.41429540089199, 48.3080872126988, 41.819407735552105, 42.314626693725586, 52.89996753420149, 53.985470703669954, 53.296601976667134, 47.75428799220494, 51.5706763948713, 55.8511905670166, 54.373586654663086, 45.54332603727068, 39.57788412911551, 44.61188874925886, 52.59297180175781, 55.21688951764788, 55.85637392316546, 51.694885866982595, 52.15176466533116, 49.38192088263375, 53.71860081808907, 55.600214685712544, 56.426018510546, 56.92913409641811, 48.850710255759104, 46.976499693734304, 49.11462715693882, 52.420937878744944, 54.80912753513881, 56.004919460841585, 55.78553703853062, 61.39499841417585, 54.61246919631958, 26.66812767301287, 6.220954963139125, 2.3078999647072385, 5.444191523960658, 7.164483853748866, 4.863953973565783, 2.3553526869841983, 0.48021084921700613, 0.13326339556702546, 0.0848151199253542, 0.008867498503864875, 7.5117261580058505, 36.12029375348772, 18.15337085723877, 46.398944582257954, 64.81269223349435, 52.48384339468819, 29.206502641950333, 32.38344485419137, 39.96093831743513, 53.88443694795881, 57.69388410023281, 55.96929604666573, 7.052904035363879, 0.1930736383157117, 0.06076918236379113, 0.04112879965188248, 0.021948982761906724, 0.028044732719925896, 0.026910905792777027, 0.042531260289251804, 0.018908482610381076, 0.03224049302350197, 0.04604726590748344, 0.03793237045673387, 0.06776272745004722, 0.03196167619898915, 0.05741751792707613, 0.08984884553189788, 0.06104540718453271, 0.046832415740936995, 0.06562492823494331, 0.04325576266273856, 0.03657558201146977, 0.06045316146420581, 0.034593180886336734, 0.03897740598767996, 0.025977750508380786, 0.07243994397244283, 0.09295097193015472, 0.14273296243378095, 0.16967154906264373, 0.10417316082332816, 0.14081221978579248, 0.1897256379680974, 0.26718358589070185, 0.10576247982680798, 0.1369178630411625, 0.2057533407849925, 0.10273725180221455, 0.07971133557813508, 0.17072800094527857, 0.11415631084569863, 0.11219577211886644, 0.10983134899288416, 0.11425174001072134, 0.1991239586578948, 0.18881288623171194, 0.22891060103263172, 0.15937218815088272, 3.7195917453084673, 75.12078257969448, 82.61407429831368, 77.5766372680664, 57.50643559864589, 45.06742307118007, 31.73645986829485, 43.735849448612754, 64.34580108097622, 36.805205481392996, 60.19790022713797, 33.02309601647513, 1.221029845731599, 0.29664158661450657, 0.28015682260904995, 0.3534516324954373, 0.6446234669004167, 2.7916583035673415, 10.645991665976387, 5.490820016179766, 4.423249278749738, 7.280552642686026, 18.664004393986293, 42.91545827048165, 49.717911447797505, 62.25406673976353, 59.950141361781526, 58.23222357886178, 56.576568603515625, 53.654958793095176, 55.52079677581787, 57.06203229086739, 58.95337363651821, 56.43465859549386, 54.444072655269075, 57.16746425628662, 57.47503668921334, 53.843296664101736, 51.78476428985596, 52.577588490077424, 57.49869530541556, 57.00701992852347, 54.28200939723423, 53.61249140330723, 51.72137934820992, 51.60269021987915, 51.272042819431846, 46.74112946646554, 46.661850520542686, 47.61342716217041, 50.5428397996085, 50.78587736402239, 57.50749519893101, 58.79092475346157, 54.13497856685093, 49.27354288101196, 52.28145279203142, 53.170110021318706, 56.94709171567644, 52.81058243342808, 49.84516423089163, 41.25612422398159, 52.408024651663645, 53.65672016143799, 65.23428807939801, 41.29604162488665, 42.692549637385774, 62.84180791037423, 53.377329621996196, 49.964617661067415, 47.36918408530099, 53.78786046164376, 54.21481684276036, 54.47221285956246, 51.14353936059134, 43.489796366010395, 44.190543038504465, 56.11359970910208, 57.13046162469046, 54.70233024869646, 47.70993069240025, 53.92401041303362, 57.93173483439854, 56.414651257651194, 47.36838156836373, 41.09699310575213, 48.28583213261196, 55.501022202628, 56.983059065682546, 57.98878301892962, 51.616399015699116, 52.36635283061436, 51.089458056858604, 54.39956596919468, 59.35229056222098, 59.76598630632673, 59.18030875069754, 51.405465602874756, 49.121849809374126, 51.148722716740195, 54.882747173309326, 57.32915925979614, 59.727152824401855, 57.110492501940044, 63.75520420074463, 56.41066646575928, 28.807026386260986, 9.80467425073896, 10.727296880313329, 15.874155010495867, 16.98868601662772, 6.884660788944789, 1.7100294062069483, 0.3517792336642742, 0.22681404996131146, 0.2752196661063603, 0.11352461509938751, 11.351996387754168, 47.91742822102138, 29.369698456355504, 56.40101194381714, 82.19465323856899, 75.09144033704484, 38.834833349500386, 37.88575111116682, 46.325008801051546, 62.8059413092477, 65.80947385515485, 64.18802833557129, 8.83261171409062, 0.3977767697402409, 0.13616800042135374, 0.11088138193424259, 0.20442828402987548, 0.17127561941742897, 0.12461581959256104, 0.1347238200583628, 0.13004950088049683, 0.10304139155362334, 0.07642527190702302, 0.12368621304631233, 0.171833158071552, 0.1515729030860322, 0.148362808195608, 0.25524177668350084, 0.17964437178203038, 0.19526124878653459, 0.17360318452119827, 0.1455547045916319, 0.10267399198242597, 0.1342124082148075, 0.13316514369632515, 0.1550880130380392, 0.09804529071386371], [0.020455637447802082, 0.06839577348104545, 0.030116040592214892, 0.045830138094191036, 0.02235132179755185, 0.019505859751786505, 0.02634198641005371, 0.05866955752883639, 0.03745557746983, 0.025821117484675984, 0.03951573192274996, 0.014034935373014637, 0.02782288908825389, 0.061004349030554295, 0.034750387272132297, 0.033016472456178496, 0.03543993152145829, 0.06173032721770661, 0.03253332159614988, 0.03189914580434561, 0.015770295468558158, 0.05654478957876563, 12.781897442681448, 62.65334497179304, 58.120496545519146, 54.58864382335118, 40.498315470559255, 26.278231246130808, 28.81984233856201, 28.990003722054617, 54.68643624441964, 53.939279079437256, 37.921308517456055, 4.0397838439260205, 0.07056740445217916, 0.05344730096736124, 0.07503567290093217, 0.2450141097818102, 0.5589664546506745, 1.4255354149000985, 1.085187894957406, 0.2807033418544701, 3.249059736728668, 22.39055780002049, 38.847961970738, 49.770870617457796, 54.99676363808768, 55.88914510181972, 53.31320469720023, 53.53598826272147, 53.08015169416155, 54.00362287248884, 55.208638531821116, 56.75704458781651, 56.33764784676688, 52.95057821273804, 53.22250638689314, 55.262275150844026, 56.50878545216152, 52.832854884011404, 50.807833671569824, 51.13695594242641, 52.06513799939837, 53.43718835285732, 53.16612522942679, 52.624419348580496, 50.70661578859602, 53.49885708945138, 51.77976853506905, 49.142388684409006, 46.255832535879954, 43.33194719042097, 46.50547088895525, 46.89217288153512, 51.88427986417498, 52.56548820223127, 52.439882142203196, 49.64192247390747, 47.905960219247, 47.54674877439226, 54.38612815311977, 43.95323773792812, 40.29500770568848, 39.07893746239798, 49.236008712223594, 47.19535057885306, 58.663175174168174, 33.495045457567485, 35.45283590044294, 56.542029108319966, 48.5953882762364, 45.23002828870501, 37.70592825753348, 47.753412519182476, 47.97948258263724, 52.00760344096592, 43.1307030405317, 40.17741986683437, 38.68782683781215, 48.45220674787249, 50.853910650525776, 51.6485344341823, 48.73146527154105, 50.279749734061106, 51.7479110445295, 52.604867117745535, 43.026441846575054, 38.84382084437779, 43.057760851723806, 50.88684163774763, 54.91024466923305, 50.44271278381348, 48.14527702331543, 46.9331498827253, 48.93649966376168, 52.84237044198172, 54.269540854862754, 52.147519315992085, 53.71831941604614, 49.53323875154768, 42.91355446406773, 44.02019057955061, 46.47302280153547, 49.78751155308315, 51.051076207842144, 54.1768171446664, 55.064908095768516, 60.19130638667515, 52.51540558678763, 22.651761429650442, 3.3047879806586673, 1.7634013422897883, 7.644355109759739, 4.7237375889505655, 0.7956424547093255, 0.32561258918472696, 0.2696298674813339, 0.06065037088202579, 0.09770919196307659, 0.5163488100681985, 21.886872461863927, 66.64523097446987, 74.87542084285191, 77.03773498535156, 74.63541616712297, 30.213880266462052, 20.833808694566997, 35.4999794278826, 41.019336564200266, 49.281811237335205, 51.45617355619158, 14.5442750113351, 0.15397749548511847, 0.039669111371040344, 0.1877284244235073, 0.012059501106185573, 0.07617109947438751, 0.022302402815382396, 0.03876393547813807, 0.06690381746739149, 0.03640533757529088, 0.021257698070257902, 0.038511130293565135, 0.015679744970319525, 0.05203811265528202, 0.014877879426681569, 0.035741754075778384, 0.03146605725799288, 0.0014200058566140278, 0.09041131713560649, 0.054550714258636744, 0.03695666763399329, 0.04608359806505697, 0.0740351662305849, 0.04274279697399054, 0.0456260822580329, 0.05723977567894118, 0.024701348106775965, 0.035501023421862295, 0.05772007669189146, 0.028877442769174064, 0.017256779097286717, 0.07650124747306108, 0.05810533530477967, 0.013313542386250836, 0.05872588950608458, 0.056551479934049506, 0.060854650634740076, 0.033992931845464876, 0.014081517650213624, 0.06544215804232018, 0.06772868534816162, 0.04793470944943173, 0.014621376226257001, 0.014144087060620742, 0.07072679911340986, 0.021088210200624805, 0.03166202495672873, 15.935029915400914, 72.9223586491176, 66.03566551208496, 63.96904196058001, 47.32064396994454, 35.22365651811872, 31.038923263549805, 36.8750696182251, 53.25895316260201, 42.44011116027832, 38.26021385192871, 4.251661777496338, 0.02367963212808328, 0.10547199898532458, 0.03895481077155896, 0.6133824661374092, 2.284821305956159, 5.642985999584198, 4.836842971188681, 2.370150612933295, 2.5699213104588643, 21.296020235334122, 40.942072595868794, 52.626441274370464, 59.3953138078962, 59.83901187351772, 55.35098627635411, 55.6744179725647, 55.29300355911255, 56.92262363433838, 56.628072125571116, 58.32371398380825, 57.923817362104145, 56.009241240365164, 55.526973724365234, 56.90906769888741, 57.00117301940918, 53.9167217527117, 52.093229566301616, 50.96963289805821, 52.77314901351929, 54.55151959827968, 55.499097551618306, 53.76799556187221, 54.50059972490583, 54.902417523520334, 54.5206105368478, 50.955507210322786, 48.00260271344866, 45.36196763174874, 48.08266333171299, 49.352606432778494, 53.175074509211946, 54.39259345190865, 53.69732543400356, 49.87191826956612, 49.61284078870501, 51.0151366506304, 55.998464584350586, 45.686653477805, 42.541131019592285, 40.264855997903005, 52.61787067140852, 48.65858561652047, 61.55650929042271, 35.356811795915874, 38.10407393319266, 59.3252203805106, 50.99027599607195, 46.712839875902446, 39.64122738157, 49.32672439302717, 50.871427059173584, 53.931945255824495, 45.86081007548741, 42.57997839791434, 40.68455498559134, 49.615161487034385, 52.3426490511213, 52.52079391479492, 49.26523630959647, 49.75676230021885, 52.93818262645176, 54.42241859436035, 46.159363746643066, 40.30074691772461, 44.60428394590105, 53.28474140167236, 56.87814474105835, 52.45643275124686, 48.648740019117085, 47.50547994886126, 50.13729429244995, 54.605576583317344, 56.569467544555664, 55.53338691166469, 55.806173188345774, 51.81820249557495, 44.03857898712158, 46.3090626852853, 48.12101738793509, 51.98757873262678, 53.29199879510062, 56.06862054552351, 55.847858905792236, 62.55101190294538, 56.17836734226772, 26.006634848458425, 4.980800092220306, 2.5623584134238104, 6.388865564550672, 5.879553922585078, 3.493922288928713, 1.4940823252711977, 0.6971645504236221, 0.0052782369727667955, 0.11619875553463187, 0.6112847072737557, 22.25597987856184, 56.8950114931379, 71.80412251608712, 78.13256958552769, 72.75543512616838, 37.529763630458284, 26.31822681427002, 39.00046450751168, 47.58686072485787, 54.41285787309919, 59.37762369428362, 18.14053406034197, 0.1651936929140772, 0.01722643161857767, 0.10188823486013071, 0.011886287231131323, 0.04294587911239692, 0.02827023365534842, 0.01757425206181194, 0.04792027022423489, 0.03713312066559281, 0.05194170300715736, 0.024143967212044766, 0.024461994878947735, 0.0397239030737962, 0.013972394800345813, 0.08105790867869343, 0.016717509998540794, 0.04491034655698708, 0.04218835583222764, 0.032018927591187615, 0.06419019986476217, 0.04535980136798961, 0.013163616681205375, 0.016259354672261646, 0.07215147159461464, 0.06922988979411976, 0.12670562602579594, 0.09723131332014288, 0.16641432312982424, 0.13623863591679505, 0.11265170015394688, 0.10260853370917694, 0.13737060874700546, 0.34411311788218363, 0.12950660501207623, 0.12011665744440896, 0.10694260828729187, 0.13289710879325867, 0.1209383090691907, 0.13677117734083108, 0.10754037049732038, 0.14558229382549012, 0.11371837755931274, 0.19486099454973424, 0.12115146405994892, 0.1613877492823771, 0.07770433755857603, 20.228997537067958, 80.64173780168805, 73.5039506639753, 71.33987862723214, 54.9733829498291, 37.791901792798726, 37.9931320462908, 37.14621959413801, 61.13244683401925, 66.58629635402134, 51.2753119468689, 6.2498481784548074, 0.2629516715449946, 0.1315811036952904, 0.11515919917396136, 0.5291529830013002, 1.7992729374340601, 7.707120793206351, 5.644991857664926, 3.354784829275949, 5.346964512552534, 25.67384566579546, 42.573457513536724, 51.8589745249067, 58.36899539402553, 61.39669377463204, 57.64644874845232, 58.14187615258353, 57.791301318577354, 59.28046008518764, 58.210784912109375, 60.602069990975515, 61.11522224971226, 56.614074979509624, 56.42771734510149, 59.937037059238975, 59.09447070530483, 56.76404142379761, 50.7190009525844, 51.51491710117885, 54.726034028189524, 57.16736003330776, 56.34165000915527, 57.71841818945748, 55.91659048625401, 57.31064578465053, 55.70835297448294, 53.75789635522025, 49.36100680487496, 48.70399556841169, 50.86190455300467, 52.70801659992763, 55.85162135532924, 57.00979573386056, 54.36340406962803, 50.28934172221592, 52.311389105660574, 53.288840838841026, 58.43778950827462, 48.23541252953665, 43.975544929504395, 41.76866156714303, 54.70136097499302, 52.05065100533621, 63.68037210191999, 38.65560804094587, 41.14231620516096, 60.12402697971889, 52.91841152736119, 49.23672437667847, 41.72119494846889, 52.97467456545149, 53.0590500150408, 56.110980238233296, 47.424081802368164, 45.01994603020804, 43.830786160060335, 54.31886959075928, 54.856274536677766, 54.56665972300938, 50.29278802871704, 51.857247897556846, 55.59388140269688, 56.50302539552961, 47.46264083044869, 42.57487147194998, 46.79098973955427, 54.17194645745413, 59.84149238041469, 53.151766777038574, 49.58098677226475, 46.69147416523525, 50.266207695007324, 56.2358706338065, 57.11556468691145, 58.970084054129465, 58.39933817727225, 53.708195890699116, 47.38400459289551, 48.816427843911306, 51.04062264306204, 55.40089518683297, 56.7450624193464, 58.57020827702114, 58.9300902230399, 64.95326123918805, 58.60824271610805, 27.167673621858867, 7.577937279428754, 8.093339017459325, 18.02350034032549, 13.694474714142935, 6.900282076426914, 0.842785005058561, 0.5531181884663445, 0.16035368905535766, 0.24657620596034185, 0.8149845568197114, 31.971777984074183, 79.06389222826276, 76.56204741341728, 81.43602807181222, 80.44531222752163, 39.245454515729634, 32.8361234664917, 48.432685783931184, 55.73859848294939, 62.34210041591099, 66.60225636618478, 22.012006044387817, 0.3316705769726208, 0.1149116288870573, 0.2554354305778231, 0.14770093799701758, 0.1558436160641057, 0.12252234907022544, 0.09345682657190732, 0.15047405633543218, 0.1521843174206359, 0.1231914253107139, 0.1037021828815341, 0.0958684893058879, 0.1883951122207301, 0.09735844364123684, 0.21854869276285172, 0.08517857042274304, 0.0986819669072117, 0.15843572840094566, 0.13772696176809923, 0.1006757877767086, 0.14078165856855257, 0.187312781012484, 0.05763205712927239, 0.22508085439247744], [0.051265739636229615, 0.05662719765678048, 0.08333141489752702, 0.040141351387969086, 0.011144631492373134, 0.06979746398116861, 0.04693701869941183, 0.03972965365807925, 0.012194959596464676, 0.05383587422381554, 0.04606475175491401, 0.03239854418539575, 0.02406901623388486, 0.017201882221602967, 0.03494049242830702, 0.000746290132935558, 0.03267367317208222, 0.03952132644397872, 0.08418020113770451, 0.08058622506047998, 0.02392213884741068, 0.30432819415416035, 31.443756580352783, 66.30105890546525, 58.10193790708269, 51.69174528121948, 41.48955242974417, 24.44859858921596, 20.127866506576538, 30.41399880817958, 49.836864607674734, 56.50079502378191, 15.414194686072213, 0.06308957535241332, 0.03472520683759025, 0.07826499068843466, 0.10557906502591712, 0.620267316699028, 2.321537107229233, 1.2766126117535999, 4.873280193124499, 3.3869263274329047, 17.803209441048757, 36.75018617085048, 52.208583559308735, 57.17561796733311, 58.84910202026367, 58.72411782400948, 57.29862192698887, 55.18281207765852, 56.180215563092915, 56.28609568732125, 55.864475522722515, 54.87805366516113, 53.88507270812988, 54.73418773923601, 56.6559031350272, 52.10340172903878, 51.346843651362825, 50.84009763172695, 52.93188408442906, 49.405885219573975, 50.913078035627095, 52.76510994774954, 53.3073855808803, 52.70287145887102, 54.1684376171657, 50.45026894978115, 53.47429173333304, 51.369157791137695, 50.7530505997794, 45.10858072553362, 46.57180881500244, 48.85434763772147, 51.595328603472026, 52.3782377243042, 53.02037286758423, 45.293201310294016, 49.50181204932076, 51.386497020721436, 51.48705135072981, 38.965424742017476, 39.21278756005423, 39.41635240827288, 49.82092891420637, 47.407437392643516, 57.88748523167202, 35.373244285583496, 34.734843799046104, 56.33241237912859, 48.1552129473005, 47.434167112622944, 38.05283791678292, 48.19571399688721, 47.029830592019216, 51.062836033957346, 44.450138160160606, 41.84704419544765, 36.711178983960835, 45.49529661451067, 49.98227998188564, 53.77432884488787, 49.28532007762364, 48.13724837984358, 52.56823968887329, 51.8067900793893, 45.07717834200178, 36.04299851826259, 43.541786261967246, 52.09434127807617, 52.118972642081125, 51.5839752469744, 48.51888166155134, 49.30667536599295, 54.65014232907976, 52.84027556010655, 56.949217864445274, 54.487429414476665, 53.26700612476894, 52.48390940257481, 42.97248561041695, 43.19739532470703, 43.929238659994944, 43.570134912218364, 45.50662217821394, 48.64694390978132, 53.599852630070274, 55.53860848290579, 58.70899854387556, 45.03755276543753, 16.498104981013707, 4.281990230083466, 3.34902976666178, 6.349014171532222, 4.450857077326093, 1.372427510363715, 0.19203367483403, 0.07464807334222964, 0.10852707576538835, 0.0663117142394185, 4.1601548705782205, 26.826953070504324, 58.35031863621303, 65.19662884303501, 68.85739844185966, 42.01072985785348, 24.963927371161326, 34.10746315547398, 37.352105140686035, 49.87136936187744, 54.96020221710205, 25.336517572402954, 0.43000427899616106, 0.09792278800159693, 0.029745010858667747, 0.04802502246041383, 0.05305780829595668, 0.007301700068637729, 0.02917213731312326, 0.04096095044431942, 0.041626257422779284, 0.017717979349462048, 0.03751082718372345, 0.01081145807568516, 0.04054867935233882, 0.05661673803946801, 0.07981477145637784, 0.05686240842831986, 0.03282500344461628, 0.06068766995200089, 0.04250638858814325, 0.08341868807162557, 0.11112704553774425, 0.008305953100456722, 0.04711110025112118, 0.06437565027070896, 0.04722737740459187, 0.06437282756503139, 0.030542554134236913, 0.06407905582870756, 0.028540811368397305, 0.023885737139997736, 0.0268290880402284, 0.0270517136835094, 0.02773013335120465, 0.033814348213906796, 0.029826082222695862, 0.020329435023346117, 0.033170750963368585, 0.07130995924983706, 0.019925006099843552, 0.07501189024852854, 0.027091699752158353, 0.058738299911575656, 0.05820799086775098, 0.016295807269800986, 0.008386555427153195, 0.4816563459379332, 40.447558879852295, 75.97180489131382, 65.1816485268729, 58.843043191092356, 49.3310044833592, 29.550056321280344, 21.917018958500453, 27.57145254952567, 51.13202966962542, 60.398640632629395, 15.213414328438894, 0.2255745836134468, 0.04627866670489311, 0.09710237131054912, 0.5434726231864521, 1.91610472542899, 3.845833565507616, 5.244886355740683, 5.9307951501437595, 3.2213768107550482, 18.628365346363612, 39.646240506853374, 53.929374422345845, 59.87357221330915, 58.9226348059518, 59.77872930254255, 58.944347926548545, 56.80663735525948, 58.26108986990792, 57.2153616632734, 57.346731254032676, 56.374167578560964, 54.04250151770455, 55.21257816042219, 58.08815615517752, 54.308832917894634, 54.24381514957973, 51.54148701259068, 52.48357936314174, 49.994856221335276, 49.376876490456716, 53.74573700768607, 55.17562764031546, 55.003586769104004, 55.389385495867046, 51.95841714314052, 55.844006129673545, 52.70351069314139, 51.70719460078648, 47.66233900615147, 47.780628613063264, 48.83239827837263, 54.092542443956646, 52.66808877672468, 53.32594074521746, 47.980132239205496, 52.235337597983225, 51.888403620038716, 53.448795318603516, 40.317697048187256, 39.79655088697161, 41.71529245376587, 51.69424663271223, 50.24859053747994, 60.08742386954171, 37.18936790738787, 37.03254359109061, 58.102941921779085, 51.15667493002755, 50.0545516695295, 39.59325701849801, 49.648776871817454, 50.473625319344656, 53.25037908554077, 47.92909772055489, 43.45641027178083, 38.46630089623587, 47.42031587873186, 52.26570469992501, 55.65829815183367, 49.37372200829642, 48.28764908654349, 53.37767008372715, 55.755562509809224, 46.144195829119, 38.79204286847796, 44.47405385971069, 54.13860900061471, 54.164265223911826, 51.0430406161717, 49.167527266911094, 50.08719083241054, 55.871441091809956, 54.68468182427542, 57.572370529174805, 56.696765490940635, 56.67426027570452, 53.45601797103882, 45.54998241152082, 43.968513352530344, 45.962295464106965, 46.328232765197754, 47.81243746621268, 51.86948020117623, 54.783273288181846, 56.87468106406075, 59.88002708980015, 47.7351839201791, 18.230759893144878, 4.62805220910481, 2.774940286363874, 7.176450388772147, 9.175136191504341, 5.011173273835864, 1.111119766320501, 0.3659788817167282, 0.14080291028533662, 0.0829816097393632, 4.673390073435647, 31.508524213518413, 66.1983367374965, 76.90761607033866, 68.2198942729405, 31.401751245771134, 28.269296612058366, 38.30109010423933, 43.966651235307964, 56.08905867167881, 62.29401888166155, 31.260007994515554, 0.5622504555753299, 0.07764482325209038, 0.02564838621765375, 0.054542259712304385, 0.06124723742582968, 0.0697275341621467, 0.016744493639894893, 0.023130878806114197, 0.043423723828579695, 0.1020978411127414, 0.010096666386484035, 0.029391090385615826, 0.07118956678147827, 0.06060398622815098, 0.035363321525177786, 0.0346573058382741, 0.00852545493814562, 0.07166023938251392, 0.05859516294939177, 0.0561161725781858, 0.05043179974226015, 0.04215974879584142, 0.026793851716709987, 0.023382674669846892, 0.18251551128923893, 0.17615701391228608, 0.23297849989363126, 0.17909445986151695, 0.11391760222613811, 0.130599548508014, 0.06877104405845914, 0.17957621972475732, 0.06692135759762355, 0.1103226151317358, 0.15537640399166516, 0.11046210836086955, 0.0873842163543616, 0.16449051350355148, 0.10068315666701112, 0.18592301915798867, 0.07531306480190583, 0.2309084524001394, 0.12235085612961225, 0.18266552181116172, 0.135689429672701, 0.6625961767775672, 46.75011696134295, 84.16443279811314, 71.5067674091884, 67.67699677603585, 55.67282683508736, 35.90364892142159, 27.980044841766357, 42.72239909853254, 58.20354488917759, 69.69361414228166, 22.03852731840951, 0.3870128430426121, 0.10886343914483275, 0.21619484121245996, 0.6629958067621503, 2.196928982223783, 8.202774013791766, 7.415150540215628, 10.925275376864843, 7.580471634864807, 21.464932680130005, 40.54092877251761, 53.60854482650757, 60.124784333365305, 59.93518189021519, 62.327766282217844, 60.82448877607073, 58.87247576032366, 60.418491636003765, 58.321275166102815, 57.76583617074149, 56.78644241605486, 54.94064998626709, 57.72402885981968, 60.05135577065604, 55.4984062058585, 55.087538378579275, 51.68871586663382, 52.68100547790527, 50.59393685204642, 51.16281018938337, 54.746597221919465, 57.21648032324654, 56.44413941247122, 57.50953449521746, 54.95408432824271, 56.7594382422311, 55.70057446616036, 54.96129308428083, 50.38570281437465, 49.97620725631714, 52.93901293618338, 55.778439453669954, 54.707649094717844, 54.89456953321184, 49.02078478676932, 54.397894927433555, 53.91627706800188, 55.90538304192679, 42.020933287484304, 41.340583051954, 43.79050397872925, 53.86979014532906, 51.189505168369834, 60.31030123574393, 40.696822030203684, 39.37487513678414, 60.4355286189488, 53.537280627659385, 51.976604052952354, 43.408391271318706, 53.38311052322388, 52.44263710294451, 55.49016216823033, 49.62482295717512, 46.6957368850708, 41.25112499509539, 49.370435510362896, 54.4420542035784, 58.43361364092146, 51.45048298154558, 47.83131224768502, 55.63215555463518, 57.65564816338675, 48.78235387802124, 40.42673512867519, 48.345975739615305, 56.480784211839946, 55.70091840199062, 52.84785257066999, 49.17540305001395, 50.80200413295201, 58.34901932307652, 57.70796809877668, 61.053577831813264, 60.19874790736607, 60.25688348497663, 56.116698605673655, 48.65259279523577, 46.2787754876273, 49.05757897240775, 47.27165222167969, 49.36841011047363, 55.44273029054914, 58.53340366908482, 58.98543957301548, 64.6218113218035, 52.1820900780814, 22.25978228024074, 9.553598489080157, 8.286383424486433, 19.022402899605886, 16.452802726200648, 4.878093991960798, 0.5305800235697201, 0.2359265988426549, 0.22245486958750657, 0.22293611376413278, 6.532982928412301, 38.488635880606516, 64.47735827309745, 69.32701328822544, 76.9074354171753, 51.495444774627686, 36.979452405657085, 45.35240691048758, 51.78925977434431, 63.35055501120431, 69.69272477286202, 37.211883544921875, 0.7812660889966148, 0.1747779729110854, 0.27247499195592745, 0.1831574732703822, 0.15766606612929276, 0.23564128843801363, 0.10901144120310034, 0.14155848617000238, 0.14593013801745006, 0.18134450912475586, 0.16552158817648888, 0.19843470278595174, 0.16424097546509334, 0.0967915751306074, 0.18850291786449297, 0.10048908886632749, 0.08243114820548467, 0.13519361056387424, 0.12707671682749475, 0.14760645878102097, 0.15097169391810894, 0.10744484633739505, 0.19227298056440695, 0.10469021129288844], [0.020181617865871106, 0.017763771981533085, 0.04261317303670304, 0.021903419135404483, 0.02390689555821674, 0.017944162212578312, 0.031148445193788836, 0.013463242478402597, 0.02851349694122161, 0.04452277413968529, 0.047076043739382706, 0.04244772923578109, 0.00805242357975138, 0.013085457080576037, 0.06526833772659302, 0.036658220791390965, 0.05531412043741771, 0.034292342207793675, 0.026243429198595028, 0.03989497193002275, 0.08506385729249034, 1.5624936372041702, 43.7765519959586, 63.645026615687776, 52.20638792855399, 48.72141122817993, 30.071643693106516, 26.83830295290266, 26.092769929340907, 50.711173806871685, 44.656193937574116, 31.5279791695731, 3.2907649959836687, 0.03434690999399338, 0.14153408605073178, 0.05966925674251147, 0.39809299420033184, 1.700932802898543, 3.084074978317533, 6.068556649344308, 7.069510229996272, 8.505651201520648, 33.46349368776594, 55.48850154876709, 58.10238606589181, 56.69481304713658, 54.58193186351231, 55.234492778778076, 56.500419821058, 56.20863022123064, 56.08303805759975, 54.987831728799, 54.01989902768816, 52.56345932824271, 52.666160651615684, 50.421993255615234, 50.49515083857945, 51.17690461022513, 51.01133598600115, 51.48541852406093, 52.00457750047956, 49.02598898751395, 52.754625116075786, 51.22932876859392, 52.01301261356899, 50.87693350655692, 50.805356638772146, 48.184478759765625, 51.916776588984895, 52.933701038360596, 52.42058004651751, 48.32628801890782, 46.33913796288626, 46.95053774969918, 49.6418981552124, 50.74656793049404, 51.794734954833984, 46.79193469456264, 50.798616886138916, 52.074875899723594, 45.118103231702534, 36.80815151759556, 39.44742822647095, 40.911708968026296, 49.69867883409773, 47.89757374354771, 56.96579279218401, 35.547345297677175, 35.83939892905099, 55.798422472817556, 49.55348580224173, 50.20782545634678, 36.23272255488804, 44.40623596736363, 47.34924275534493, 49.834252085004536, 46.58458655221121, 41.06593118395124, 35.827041557856965, 41.410242216927664, 47.16528919764927, 52.97810002735683, 51.71233974184309, 48.798154081617085, 50.611428941999165, 53.28199338912964, 43.56825542449951, 36.230367115565706, 41.21910074778965, 52.5758375440325, 52.36876732962472, 50.37286949157715, 45.87104477201189, 51.90177195412772, 52.76643010548183, 50.87744767325265, 51.43295267650059, 52.13353954042707, 50.802636419023784, 50.84646218163626, 41.0230712209429, 40.539320264543804, 42.518868991306846, 44.84285381862095, 44.91123104095459, 50.148324557713096, 50.05634083066668, 56.154951913016184, 54.51256104878017, 56.74120269502912, 33.7454376901899, 13.045288017817906, 2.441300166504724, 3.12168818286487, 4.678853963102613, 4.987175064427512, 2.3930540468011583, 0.19259651963199886, 0.0816069927864841, 0.15271429398230144, 0.028309797335948263, 13.343858190945216, 27.521383830479213, 29.2564115524292, 53.81704636982509, 61.825029373168945, 27.763247149331228, 18.615943704332622, 34.71404784066336, 42.50185980115618, 52.31208392551967, 38.44899640764509, 4.545622255120959, 0.16036354138382844, 0.05793373379856348, 0.05856847616710833, 0.03414539187880499, 0.011754398683219083, 0.040399584852691205, 0.03222317002447588, 0.05623262615076133, 0.054069130814501216, 0.011575153480017824, 0.024323236163971678, 0.03659250128215977, 0.02513145449172173, 0.018265843790556704, 0.049394061855439625, 0.04055536292227251, 0.05299023299344948, 0.049189531044768434, 0.040521799187575064, 0.05724176378654582, 0.029233402239957025, 0.015794629430664436, 0.029670918227306435, 0.03377864030855043, 0.05551874624299152, 0.03622625182781901, 0.0038556993323644356, 0.036503562304590426, 0.03038671499650393, 0.04862825705536774, 0.022545035063688244, 0.012948234399248446, 0.10217542480677366, 0.052676257876945395, 0.010129996874768819, 0.012242772566553737, 0.04514444453109588, 0.053124226696257076, 0.033332330507359335, 0.0494450334060405, 0.012642836813548846, 0.026291572954505682, 0.05002971346090947, 0.07365368027240038, 2.167959119592394, 53.59272377831595, 71.77518326895577, 59.626820836748394, 54.846936157771516, 38.517019271850586, 32.15157304491316, 26.398211002349854, 39.02749300003052, 48.03592279979161, 35.550972257341655, 3.3629550422940935, 0.08429674631250755, 0.08291856026543037, 0.2777671036975724, 1.1157497635909488, 3.101671725511551, 5.789622953959873, 5.999518045357295, 3.8213433367865424, 12.875680753162928, 36.01341308866228, 56.21293463025774, 57.434962953839985, 57.309944016592844, 55.04711723327637, 56.74701486315046, 59.11321694510323, 57.13918856212071, 57.267959526606965, 56.79088231495449, 54.613657338278635, 54.2889541217259, 53.263382639203755, 52.408323424203054, 53.04996871948242, 54.17388153076172, 53.78294808523995, 51.8723532812936, 53.009891510009766, 51.10248940331595, 51.96080732345581, 52.032867091042654, 52.8796648979187, 51.429176330566406, 51.14114918027605, 47.32595934186663, 53.18052537100655, 53.82729843684605, 52.36281272343227, 49.99722555705479, 48.0713586126055, 48.69494553974697, 51.13298157283238, 51.78943347930908, 52.36276756014143, 48.87178414208548, 52.75548321860177, 52.000540597098215, 46.66674552645002, 39.39828709193638, 41.624785218920024, 42.639830180576865, 51.35213123049055, 50.77611167090279, 58.94828060695103, 36.25954260144915, 37.622000966753276, 56.30486624581473, 51.60063007899693, 50.45752286911011, 38.63848767961775, 46.30628340584891, 49.6698750768389, 53.14680923734392, 49.10787698200771, 42.967152867998394, 37.98453712463379, 42.80330392292568, 49.146915435791016, 54.620671544756206, 52.29857315335955, 48.27217544828142, 51.518116746629985, 54.57573407036917, 45.489237785339355, 38.54888718468802, 43.409735747746055, 54.14699895041329, 53.67889533724104, 51.07230642863682, 46.342441831316265, 52.76980692999703, 54.118379320417134, 53.072831766945974, 53.41578442709786, 55.34191540309361, 53.02708830152239, 52.335443769182476, 42.80041694641113, 42.180637632097515, 43.77264016015189, 46.8695182800293, 45.73020131247384, 51.55871854509626, 52.477673394339426, 57.66156455448696, 57.01315518787929, 59.60979775020054, 36.73505299431937, 13.355743084635053, 2.131933795554297, 1.719056093267032, 6.3456825103078565, 7.972778218133109, 3.218011277062552, 1.974245297057288, 0.11270391342363187, 0.053711681959352324, 0.16715674900582858, 14.373211230550494, 36.4109125818525, 37.994882992335725, 58.462990624564036, 53.31479236057827, 25.64012953213283, 23.799122674124582, 38.40728637150356, 49.03811706815447, 56.62037352153233, 48.26356315612793, 5.768311960356576, 0.059012509483311854, 0.014562620182654687, 0.025075422766219293, 0.09714153635182551, 0.06505748975489821, 0.05114658210160477, 0.03357388897399817, 0.07385539516274418, 0.11463158391416073, 0.020214043358074765, 0.01771713457336383, 0.031751971558800766, 0.049802132815654786, 0.03688275142173682, 0.05004770481692893, 0.05994421270276819, 0.05110925589022892, 0.07753971139235155, 0.01867759749958558, 0.06215350915278707, 0.03368126374802419, 0.009479506556609911, 0.04615092909495745, 0.08364965460662331, 0.15720535442233086, 0.13398701245231287, 0.13150358785476002, 0.0830716174095869, 0.18524970885898384, 0.1447448187640735, 0.06305542468492474, 0.18440429493784904, 0.18800576882702963, 0.11282279954424926, 0.14113262402159826, 0.10080542867737156, 0.1275072880089283, 0.13919444302363054, 0.1294617945594447, 0.16143806943936007, 0.13792094135923044, 0.16539548922862324, 0.12505099124142102, 0.1708990324820791, 3.4586438962391446, 64.50942420959473, 79.76691790989467, 68.27283954620361, 63.15601934705462, 43.17698499134609, 37.832514013562886, 38.05859797341483, 65.33334159851074, 58.16654225758144, 42.071484906332834, 5.233320210661207, 0.17567784605281694, 0.44083293793456896, 0.30857848322817255, 0.9013685786298343, 6.456014258520944, 10.507427215576172, 11.508377756391253, 12.969797577176776, 12.085971082959857, 35.6005858693804, 56.77017668315342, 57.833039147513254, 57.953684193747385, 54.76438113621303, 56.6971823828561, 59.738881383623394, 57.36919130597796, 58.80363995688302, 58.511808667864116, 55.70670277731759, 53.9187193598066, 55.46354709352766, 52.792200974055696, 54.47213642937796, 56.02800137656075, 54.483013834272114, 53.05678142820086, 52.65191684450422, 50.94927815028599, 52.122015953063965, 51.83621570042202, 53.16301243645804, 51.89398997170584, 51.01079750061035, 48.967558111463276, 53.880750928606304, 55.88643530436924, 55.61762339728219, 52.83688483919416, 50.75521496364048, 51.01092256818499, 53.325534275599885, 53.427589416503906, 53.15309040887015, 49.613017967769075, 54.19093935830252, 56.50238616125924, 48.891794954027446, 41.65803929737636, 43.684262548174175, 45.75968599319458, 53.83058146068028, 54.774105140141074, 60.34972531454903, 40.26373038973127, 39.98588235037667, 59.546173095703125, 54.52802773884365, 53.89757946559361, 41.11685105732509, 49.09293488093785, 51.86597483498709, 55.425408431461875, 52.72406346457345, 45.747985226767405, 39.87114674704415, 45.42047841208321, 52.06942503792899, 57.8406891141619, 54.53327015468052, 48.4163818359375, 52.31571088518415, 58.03321327481951, 47.946190289088655, 39.6403032711574, 45.12689617701939, 56.17965623310634, 56.399806431361604, 50.63375002997262, 47.66575057165963, 54.46152305603027, 56.72712217058454, 56.47537503923689, 55.935562542506624, 56.488020760672434, 55.20767273221697, 56.32705184391567, 46.0820163999285, 45.7080956186567, 46.663205419267925, 49.753104073660715, 47.93467712402344, 54.633147035326274, 55.72430951254708, 60.62285205296108, 59.63892459869385, 61.4927248273577, 40.37175055912563, 19.293196780341013, 5.814969113894871, 7.5376481498990735, 12.175352709633962, 16.16248788152422, 5.652909329959324, 0.8913417852350644, 0.1562033753309931, 0.2965025412184851, 0.19431115048272268, 20.07718460900443, 39.219763551439556, 37.739026001521516, 60.40715912410191, 72.43506758553642, 37.349301542554585, 28.985546452658518, 47.37203632082258, 55.190774713243755, 65.45623438698905, 54.96214771270752, 6.666678428649902, 0.30957250988909174, 0.08010904530861548, 0.17995678287531647, 0.19256373281989778, 0.13908685451107367, 0.1463384668209723, 0.07970809218074594, 0.16245026726807865, 0.16690801163869246, 0.08270220937473433, 0.12027229980698653, 0.1828045400657824, 0.15497568835105213, 0.09428579958954028, 0.2015359742300851, 0.16337048288966927, 0.12860848249069282, 0.20899908590529645, 0.13461927138268948, 0.078529890759715, 0.11344135206724916, 0.09443091787397861, 0.09694195206144027], [0.011751568344022547, 0.027936672625531043, 0.02723090799658426, 0.03102930122986436, 0.03046106207849724, 0.05118066830826657, 0.024507317625518357, 0.05572193016165069, 0.030677243335438625, 0.012857290350698998, 0.031158646967794214, 0.028405799863061736, 0.043062258046120405, 0.03251921485311218, 0.015628773419718658, 0.01157277521477746, 0.03358715433361275, 0.019617661966809204, 0.006055683313336755, 0.02230161571476076, 0.034646201612693925, 12.203628403799874, 54.571919509342735, 52.763028962271555, 61.34088584354946, 44.34204503468105, 33.95801435198103, 14.223550507000514, 44.4330039024353, 45.85868740081787, 39.24818863187517, 17.336606638772146, 0.07273702017430748, 0.028506402857601643, 0.06777203695050307, 0.08490993162350995, 0.51998961184706, 2.6651693880558014, 2.207294825996671, 4.243432939052582, 9.302637372698102, 33.85011230196272, 54.918325424194336, 61.10798222678048, 59.7020628792899, 57.80559376307896, 55.623300075531006, 53.469170910971506, 53.55169813973563, 56.07679510116577, 52.7701404435294, 52.66856820242745, 54.3675035067967, 53.956566197531565, 54.42520134789603, 53.53252111162458, 51.741080965314595, 51.657233578818186, 50.84877940586635, 49.96333919252668, 51.4409361566816, 50.58286837169102, 49.3816568510873, 49.077558517456055, 51.0421964100429, 51.26223543712071, 51.0366586957659, 51.101224831172395, 48.31086301803589, 50.46989761080061, 52.904876436506, 48.09967252186367, 47.584685938698904, 46.644511290958945, 51.36165721075875, 50.493194920676096, 52.082560607365195, 49.50107554027012, 51.98619951520647, 48.13596296310425, 39.980348110198975, 36.37282950537545, 40.974649224962505, 40.60297966003418, 49.74205296380179, 47.39524677821568, 59.18985557556152, 34.90829515457153, 35.87899323872158, 53.94413934435163, 49.37293338775635, 51.107905524117605, 38.48191697256905, 43.12126043864659, 45.41523252214704, 50.366407666887554, 45.53821563720703, 41.39404249191284, 36.70476579666138, 38.31275265557425, 44.972906725747244, 49.80103274754116, 50.45438923154558, 49.545054163251606, 49.104691232953755, 53.744534969329834, 41.988818713596885, 37.99288885934012, 41.56191096987043, 51.53337846483503, 51.79984188079834, 49.2274763243539, 45.86642074584961, 52.35168865748814, 51.92468016488211, 50.91642359324864, 47.94714566639492, 48.3976286479405, 48.68497487476894, 44.761719703674316, 40.672392163957866, 42.20453943525042, 42.710858140672954, 46.79888636725289, 48.88697290420532, 51.60479899815151, 52.87535006659371, 54.61418192727225, 53.114996910095215, 57.64007030214582, 52.152174609048025, 31.493491785866873, 9.013246638434273, 1.5795049986668994, 6.5037579366139004, 7.372825588498797, 2.8418644666671753, 2.195253380707332, 0.1030231796737228, 0.04664302304653185, 0.015158811584115028, 0.8442635057227952, 24.8194135257176, 35.76936456135341, 25.686130080904277, 37.55918230329241, 28.45791588510786, 21.87079954147339, 34.43598788125174, 44.28361415863037, 49.55431611197335, 53.11394425800869, 9.256882616451808, 0.19504143058189324, 0.01661786373837718, 0.04180620830239994, 0.012076155748218298, 0.03494852967560291, 0.027691821567714214, 0.006842301751021296, 0.03687654961166637, 0.040736843898360214, 0.018596314093364135, 0.022957608103752136, 0.05858868293996368, 0.03664212254807353, 0.0944022633401411, 0.020701163647962467, 0.04693384315552456, 0.046257269103080034, 0.03239318375874843, 0.004380762876410569, 0.019189465657940934, 0.07341907678970269, 0.03598610810669405, 0.0595124608704022, 0.01844253939842539, 0.03208085748233965, 0.06270085621093001, 0.03635421335431082, 0.0850376251286694, 0.06763405685446092, 0.024134579680061767, 0.020179578868140067, 0.0320029175574226, 0.05193121624844415, 0.020648390586887087, 0.09521301090717316, 0.026164030423387885, 0.017324790358543396, 0.01852744278897132, 0.016518806107342243, 0.02572043306593384, 0.08447968613888536, 0.06802717968821526, 0.03595748071425727, 0.02215239398979715, 15.525770596095494, 65.93408284868512, 60.392852783203125, 68.08689880371094, 49.06236975533621, 36.34932027544294, 16.313656364168438, 39.510993821280344, 47.89252587727138, 44.17632702418736, 18.47539554323469, 0.028769043407269886, 0.1137988246711237, 0.15309552209717886, 0.5231152698397636, 3.246409216097423, 5.2842952353613715, 4.595650153500693, 3.0627841779163907, 9.400751147951398, 33.268138136182515, 56.056867667606895, 63.092234883989605, 60.80830642155239, 57.73345756530762, 56.30673878533499, 53.77093464987618, 55.60441139766148, 55.9168301991054, 53.660044874463765, 54.353211062295095, 56.58075836726597, 54.77851724624634, 55.227099895477295, 54.74666322980608, 53.672562054225374, 51.70555135181972, 51.789607184273855, 51.145113127572195, 52.3092177936009, 51.52566943849836, 49.08163711002895, 50.24026312146868, 51.5652984891619, 51.75159011568342, 51.47893932887486, 51.067223821367534, 47.89718117032732, 52.21432971954346, 54.919120992933, 50.807892731257844, 49.55560152871268, 49.108213969639365, 53.883436407361714, 51.81638901574271, 51.07272332055228, 50.549652508326936, 53.81306505203247, 49.8408841405596, 42.3703373500279, 37.77225923538208, 42.543437821524485, 43.644029004233225, 51.29527759552002, 48.847639151981895, 59.910376821245464, 36.17980507441929, 37.117377621786936, 56.05049269539969, 50.20365653719221, 53.37435231889997, 39.99405690601894, 45.78973695210048, 48.010770320892334, 51.63037879126412, 47.7432473046439, 43.651369776044575, 38.83783497129168, 40.62939671107701, 46.9089423588344, 52.79203074319022, 51.778469221932546, 49.33283880778721, 50.94006831305367, 56.61352259772164, 44.52594995498657, 38.78437900543213, 42.932220799582346, 53.82070459638323, 52.86865895135062, 49.52579723085676, 46.73521307536534, 53.949576309749055, 53.04633133752005, 52.07565409796578, 49.215560163770405, 49.593021052224294, 50.63379519326346, 47.39895364216396, 43.760032653808594, 43.86116368430001, 45.292273725782124, 49.04695865086147, 52.12507316044399, 53.53813178198678, 56.018718583243235, 56.70138256890433, 54.95972626549857, 58.5778443472726, 53.61626080104283, 32.58528307506016, 9.258564949035645, 0.7547861784696579, 1.50388688487666, 6.188717058726719, 8.317003267151968, 4.143477891172681, 0.5435810259410313, 0.0761582548064845, 0.03841141278722456, 1.3023607901164462, 23.288098301206315, 30.57907063620431, 31.87485408782959, 40.56457001822335, 29.987890107291086, 27.93834696497236, 38.95040968486241, 48.220442635672434, 54.138504777635845, 58.88427380153111, 12.398472394262042, 0.1251341796347073, 0.028272169176489115, 0.03561877638899854, 0.04770648419590933, 0.05405219458043575, 0.0586311456614307, 0.012176998774521053, 0.030536203046462367, 0.0017647638804711668, 0.02040188729629985, 0.02962231815659574, 0.08083829403455768, 0.028549140385751213, 0.034551949705928564, 0.05318649246224335, 0.048537167121789286, 0.05282145080023578, 0.016855678388050625, 0.06650126299687795, 0.03909225821761148, 0.09834714380225965, 0.04070214701018163, 0.05077058209904602, 0.10380886894251619, 0.12496820996914591, 0.13880284689366817, 0.16248126274773053, 0.14891358864094528, 0.2047101610473224, 0.10569725225546531, 0.099108453307833, 0.08669027859078986, 0.1453981258507286, 0.15138595311769418, 0.17517891925360474, 0.1690317719642605, 0.11968386066811425, 0.07274843991867133, 0.10390683582850865, 0.09633594565093517, 0.16132824176124164, 0.1845324837735721, 0.13855619941438946, 0.13685991615056992, 18.739025831222534, 77.17794963291713, 68.46134417397636, 76.53014128548759, 56.80261434827532, 45.3744535446167, 21.654799154826573, 57.61153057643345, 55.297287123543875, 53.30525943211147, 23.52572843006679, 0.1416575387120247, 0.3661761182759489, 0.2540820517710277, 0.42280333968145506, 3.288586735725403, 8.222136037690298, 7.807650804519653, 11.048949837684631, 12.49800968170166, 37.33466516222273, 59.04108769553048, 65.81522001538957, 62.56209427969796, 58.959654808044434, 55.32644176483154, 53.294767652239116, 55.69446699959891, 55.938591957092285, 54.49549627304077, 55.11218016488211, 57.98292221341814, 56.322476455143516, 56.78500761304583, 57.06250824247088, 54.62034845352173, 53.67260026931763, 53.65470518384661, 52.757772650037495, 52.65026317323957, 55.69391114371163, 49.55413545880999, 51.34824023927961, 53.232862676892964, 52.89475291115897, 53.139624800000874, 52.550004141671316, 48.450247355869834, 52.93620933805193, 56.924016748155864, 52.20608220781599, 51.83462803704398, 51.87796395165579, 55.509919370923726, 53.938420976911274, 52.55233178819929, 51.829274450029644, 55.8021571295602, 51.338776792798726, 44.33171306337629, 40.368477957589285, 45.206564222063335, 45.326118401118684, 52.798589842660085, 51.14347335270473, 61.3142603465489, 40.39953293119158, 39.97742639269148, 59.13717433384487, 53.43958895547049, 55.367919036320274, 42.212255409785676, 47.86497279575893, 50.4466871534075, 54.98758506774902, 50.627229145595, 45.69247259412493, 41.4292003767831, 43.14837230954851, 49.57568877083914, 54.386569363730295, 54.80825553621565, 51.06967306137085, 52.44886268888201, 59.113487924848286, 47.93967982700893, 41.933313029153005, 45.665499687194824, 56.91918427603585, 54.902820519038606, 50.87166329792568, 47.50584472928728, 54.96114369801113, 55.456331389290945, 55.650877475738525, 51.710602692195344, 52.059398787362234, 52.480407510484966, 50.399296964917866, 45.45393746239798, 46.956982203892295, 47.90148210525513, 51.54627432141985, 54.728900160108296, 56.09605898175921, 57.78120558602469, 59.213326590401785, 55.941360814230784, 60.96645436968122, 54.37521948133196, 37.34970453807286, 12.847647377422877, 4.729848095348903, 14.679982015064784, 14.450784393719264, 12.248531137193952, 4.462282521384103, 0.2845078877040318, 0.1700349859893322, 0.09853341523557901, 1.5211519641535622, 37.42105906350272, 50.77969346727644, 36.19779396057129, 46.04769924708775, 36.9405529158456, 34.134960651397705, 46.15110581261771, 56.71101624625069, 61.46524470193045, 66.49604620252336, 16.26664137840271, 0.33968111713017735, 0.205339108726808, 0.21871796010860375, 0.14084595654691967, 0.16847063707453863, 0.1079721562564373, 0.0757122469533767, 0.12806653657129832, 0.0906928481001939, 0.06963446629898888, 0.07203255154724632, 0.15468748738723143, 0.13291909332786286, 0.2153230458498001, 0.09961873878325735, 0.16493413969874382, 0.1564633763794388, 0.0792392719803112, 0.13210330424564226, 0.14328115087534699, 0.12482509336301259, 0.14642743633261748, 0.1707155837544373], [0.06834013360951628, 0.03577666809516294, 0.03971739931564246, 0.03126244246959686, 0.032095700435872586, 0.0321768226900271, 0.022600198264366815, 0.04416032787412405, 0.05535622014264975, 0.03393015039286443, 0.010564022647616054, 0.04510439060894506, 0.06159050829176392, 0.007167004930254604, 0.012790871102229824, 0.03663359675556421, 0.08584718525941883, 0.037084191505398066, 0.034253546968102455, 0.03356474232194679, 0.19847872613796166, 28.51339030265808, 63.98233386448452, 52.1523483140128, 49.08048370906285, 38.12566198621477, 30.57874059677124, 31.55840880530221, 44.93548372813633, 28.216599736894878, 37.347310883658274, 3.0017683548586707, 0.054375631867774894, 0.018673030958910073, 0.09942983463406563, 0.1872184103620904, 1.9556718936988284, 3.390880286693573, 4.936178760869162, 8.201827321733747, 28.790097100394114, 54.91778693880354, 58.46592971256801, 59.43199334825788, 56.08225985935756, 55.531107902526855, 58.46169131142752, 55.88341283798218, 52.076783180236816, 53.99202980313982, 54.42702872412545, 53.605463300432476, 55.83509506498064, 53.776444571358816, 52.76494319098336, 54.09066643033709, 52.64515972137451, 51.61883435930525, 51.996621813092915, 52.01026112692696, 51.752896377018516, 46.53610897064209, 52.9880359513419, 51.06643172672817, 52.86602210998535, 52.462870257241384, 52.74682576315743, 49.70377881186349, 49.97398035866873, 49.31759098597935, 52.62982504708426, 49.0548483303615, 49.73493800844465, 47.118496554238455, 52.289085388183594, 48.746563707079204, 47.630453722817556, 47.914548192705425, 52.68005704879761, 44.269391196114675, 39.376150131225586, 37.499872480119976, 41.00736134392874, 40.38059561593192, 48.7998320715768, 47.238797664642334, 58.27945743288313, 33.647117206028526, 34.69686494554792, 53.05002430507115, 47.14953415734427, 53.89670746667044, 39.36938258579799, 40.27158185413906, 45.304620674678254, 48.46431050981794, 45.2775296483721, 42.291371073041645, 36.90292147227696, 37.37168863841465, 40.60852779660906, 48.83561529432024, 52.39463894707816, 48.37368515559605, 50.59158141272408, 51.305237838200156, 38.68049301419939, 37.87645442145211, 42.51604107448033, 50.66158103942871, 51.434450013296946, 49.31362703868321, 46.10627950940813, 53.791192122868125, 50.44571440560477, 47.37203632082258, 43.68303271702358, 43.7697879246303, 43.65880782263619, 41.521302223205566, 39.82941239220755, 44.397178990500315, 46.174059186662944, 50.97298540387835, 51.89314923967634, 56.48130532673427, 54.31672259739467, 56.93856280190604, 56.59919541222708, 54.6404322215489, 52.713644640786306, 50.9960812159947, 31.666039875575475, 6.57024872303009, 1.6690943113395145, 5.822438861642565, 3.9783474377223422, 7.752701844487872, 1.8501176834106445, 0.02023162759308304, 0.16502689543579305, 0.045363512954541614, 8.294479812894549, 38.87599100385393, 37.5022418158395, 27.404296261923655, 13.36086390699659, 17.054766859327042, 30.178468772343226, 42.73430136271885, 42.95645611626761, 54.87966217313494, 23.30416774749756, 0.1455458700656891, 0.06593003829142877, 0.038458940772605796, 0.04139392024704388, 0.05800763304744448, 0.01704210418808673, 0.016509864712134004, 0.05400976239304457, 0.02994279024590339, 0.11636107468179294, 0.038421336361872296, 0.032329920546284745, 0.060287680343857834, 0.020202674503837312, 0.02357290026598743, 0.06097878861640181, 0.14441119666610444, 0.07445353735238314, 0.06539035867899656, 0.025639302330091596, 0.05251623557082244, 0.047617942161325894, 0.009157052296879036, 0.02146848667013858, 0.0519770275402282, 0.02664110330598695, 0.04127424702580486, 0.048595137761107514, 0.034483855324132104, 0.03718618210405111, 0.03523914961676512, 0.025199940727491463, 0.043771812293146334, 0.007273461985667902, 0.009453535628771144, 0.05371009758008378, 0.04120433756283351, 0.03805859832625304, 0.030190245181854283, 0.046275843999215534, 0.01069242098102612, 0.03946548640461905, 0.008606205694377422, 0.13086226369653428, 35.33066919871739, 71.23610033307756, 58.407259123665945, 55.743816580091206, 45.643908160073416, 37.129835741860525, 32.15865673337664, 47.00949668884277, 33.56608036586216, 41.37304850987026, 3.4491767585277557, 0.09328111314347812, 0.01290470128878951, 0.1455600243061781, 0.6946254723838398, 5.09171244927815, 3.3765945732593536, 2.2807789742946625, 6.923367031982966, 30.889863559177943, 56.26687002182007, 61.13453824179513, 60.917129107883994, 59.47581563677107, 57.68245083945138, 58.77422823224749, 56.231038161686485, 54.137347902570454, 53.71336187635149, 55.01201145989554, 56.36208118711199, 56.1947511945452, 53.66038533619472, 55.46426970618111, 54.663958821977886, 54.95906271253313, 53.27621248790196, 53.53327151707241, 51.5901244027274, 52.698619161333355, 48.1811123575483, 53.83453845977783, 53.33445576259068, 53.84649978365217, 52.960833753858296, 53.9987348147801, 50.04612350463867, 51.698443344661165, 49.73217262540545, 54.329962389809744, 50.56914567947388, 50.843919140951975, 51.21479313714163, 54.278375489371165, 50.06249346051897, 48.6135230745588, 50.29457024165562, 55.676089014325825, 46.59428971154349, 39.97988952909197, 38.749182905469624, 42.954086780548096, 42.25972202845982, 50.160372734069824, 49.332508768354145, 58.9112606048584, 35.98185437066214, 35.531204632350374, 54.705943311963765, 49.93572357722691, 55.95499317986624, 41.78981188365391, 42.761163098471506, 48.14813968113491, 50.649716990334646, 48.41075726917812, 43.837647506168906, 38.607161726270405, 38.59538105555943, 42.83350426810128, 49.80541706085205, 53.99492372785296, 49.978948320661274, 52.456061022622244, 52.70177364349365, 40.572087969098774, 39.237616947719026, 44.23844044549124, 53.38554586683001, 53.058984007154194, 50.38581051145281, 46.65759127480643, 55.01518331255232, 52.11583205631801, 49.82154035568237, 46.47324514389038, 46.43675667898995, 46.321312359401155, 43.23055560248238, 41.77674927030291, 45.09823833193098, 49.400809560503276, 52.966260296957834, 54.79060016359602, 57.14567470550537, 57.02187865121024, 58.37545721871512, 59.528809547424316, 55.26876129422869, 54.67192840576172, 52.3123688016619, 34.15751450402396, 8.17231137411935, 1.3939821251801081, 4.791027852467128, 4.40157915013177, 5.767640590667725, 4.095181831291743, 0.06728542556187936, 0.14949061482080392, 0.03652175722111549, 8.675209828785487, 40.07771669115339, 38.65050458908081, 36.237725257873535, 18.265935148511613, 19.82793014390128, 34.94786514554705, 48.48296294893537, 49.6883225440979, 61.679617473057334, 29.993618897029332, 0.3145979030856064, 0.08733967731573752, 0.03978220958794866, 0.05637520671422992, 0.05799565011901515, 0.02603014019717063, 0.02429104476634945, 0.030114999040961266, 0.041449566903923235, 0.08445991362844195, 0.05252625074769769, 0.03913914838007518, 0.027347224165818522, 0.040352518271122656, 0.016358851654721156, 0.09979536144861154, 0.06378902282033648, 0.07234313738133226, 0.12410281997706209, 0.012364550094519342, 0.006606324234910841, 0.013450564051579152, 0.055914084493581734, 0.18066627266151564, 0.12341238345418658, 0.1110454381310514, 0.083033816223698, 0.17086851197694028, 0.13531248989914144, 0.11829764076641627, 0.11419339956981794, 0.07610204496553966, 0.1569481896502631, 0.09443876173879419, 0.10670223725693566, 0.11055634330425944, 0.16479164734482765, 0.0678237277482237, 0.18445013676370892, 0.23920088314584323, 0.08480068070015737, 0.12115421891212463, 0.18200419444058621, 0.37640533223748207, 44.46844318934849, 78.4287782396589, 67.59885038648332, 63.892438071114675, 52.56544998713902, 40.16593449456351, 46.00697932924543, 57.571067741939, 37.1651291166033, 50.67850685119629, 4.8342373967170715, 0.2177506677274193, 0.11121426442904131, 0.2484471441379615, 1.1514479794672556, 6.659378043242863, 8.147491540227618, 11.899236508778163, 11.801583051681519, 31.887124606541224, 59.76751491001674, 61.66724967956543, 65.02807944161552, 61.236572538103374, 59.75431333269392, 60.67512335096087, 56.47100114822388, 54.296715259552, 54.75785330363682, 56.111595153808594, 59.146269525800435, 58.831029755728586, 55.71078484398978, 55.89535331726074, 58.067005838666645, 56.49632038388933, 55.34900951385498, 54.6441946710859, 52.919867174965994, 53.316008295331685, 49.37229415348598, 55.00109583990914, 55.813642501831055, 55.67900725773403, 55.06690570286342, 55.90107863289969, 51.83020898274013, 51.682563236781526, 50.102747849055696, 55.19306761877877, 52.11877114432198, 53.914248194013325, 52.78817449297224, 56.429760115487234, 50.99931560243879, 49.96927990232195, 52.02919496808733, 57.8562912940979, 48.859680380140034, 42.531792640686035, 42.455977371760774, 46.12945522580828, 45.368436404636924, 52.454973629542756, 53.314781938280376, 60.95020948137556, 38.963691166469026, 38.19471318381173, 55.69225399834769, 52.74076345988682, 58.3266669682094, 44.05697781699044, 44.68723848887852, 51.6506918498448, 54.29965782165527, 49.207979679107666, 46.12241322653634, 42.4803968157087, 40.54765462875366, 44.29160458700997, 53.300281047821045, 57.505261353084016, 52.48341260637556, 55.39588206154959, 55.45154408046177, 42.99833985737392, 41.26691130229405, 47.04574891499111, 54.713694027491975, 55.30361693246024, 50.095931666237966, 46.05995239530291, 58.25856767381941, 55.39730991636004, 51.948453426361084, 47.398571491241455, 49.064926692417686, 48.09689324242728, 46.25065960202898, 44.21951355252947, 49.426184381757466, 51.84718690599714, 55.11167989458357, 57.13416501453945, 60.112631934029714, 58.56222479684012, 61.689456122262136, 61.43292168208531, 58.13856186185564, 55.79845026561192, 53.801124572753906, 37.04325076511928, 9.460074867521014, 4.678726289953504, 15.506802013942174, 10.517761792455401, 17.91559134210859, 4.311516599995749, 0.1276941836944648, 0.30841503771288054, 0.19141143108052866, 11.900374276297432, 52.972082887377056, 51.340962001255576, 38.74923849105835, 19.57928364617484, 27.136187859943934, 42.01835897990635, 56.6774251801627, 56.43143810544695, 67.1931381225586, 36.53660896846226, 0.7531659454107285, 0.22867029107042722, 0.14723238242524012, 0.13588727691343852, 0.16650348263127462, 0.10151193290948868, 0.08081229935799326, 0.11154728263084378, 0.14409669568496092, 0.2232805517102991, 0.09118232290659632, 0.12108133068042141, 0.11515723142240729, 0.07581051239477736, 0.13228547732744897, 0.14396123295383795, 0.28680600438799175, 0.1328492856451443, 0.13218457917017595, 0.11255331936159305, 0.11924007162451744, 0.12376611733010837, 0.1739630252122879], [0.028320711571723223, 0.0421686443899359, 0.03714795683377555, 0.03332646457212312, 0.06625828639205013, 0.02729988277756742, 0.016055071526872258, 0.017666276677378585, 0.0499717631776418, 0.08555433633072035, 0.055640098838401694, 0.019812393035473566, 0.031793294341436455, 0.045562825830919404, 0.009395829618110188, 0.021979903602706533, 0.042862049503518004, 0.057367238482194285, 0.0472564288814153, 0.03950519088123526, 3.2534800938197543, 48.28729820251465, 58.896850040980745, 48.896116733551025, 45.429768153599326, 26.478106600897654, 13.794598255838666, 16.070413827896118, 18.43071515219552, 47.2319780077253, 17.952208348682948, 0.3186942461345877, 0.030377721014831747, 0.06691748316266707, 0.2882644204156739, 0.17478303478232451, 5.649562469550541, 3.499268276350839, 2.509132823773793, 18.553554092134746, 53.22857911246163, 59.486814635140554, 57.86987154824393, 53.7948260307312, 55.693504674094065, 54.54529401234218, 55.69430719103132, 57.12355858939034, 51.822826521737234, 51.22652864456177, 55.96589142935616, 53.85052973883492, 52.15697928837368, 49.92537423542568, 49.63094779423305, 50.87657567432949, 50.415229184286936, 50.19787563596453, 53.769875049591064, 49.72672176361084, 48.30979994365147, 50.34225920268467, 51.10709605898176, 49.30832208905901, 49.5837139402117, 47.65053401674543, 50.947231905800955, 50.36716154643467, 50.71505437578474, 48.93054505756923, 51.485668659210205, 51.03864240646362, 49.95432390485491, 48.72854355403355, 52.24894911902291, 48.98008223942348, 46.86091293607439, 48.891735894339426, 52.23631034578596, 40.90546253749302, 37.94546740395682, 36.16195167813982, 40.72677918842861, 41.72370324816023, 49.14747476577759, 47.70070348467146, 57.08788306372506, 31.362170832497732, 30.742540904453822, 55.2240947995867, 46.61562762941633, 53.09142862047468, 42.45714814322335, 39.795039653778076, 42.91091414860317, 47.01617390768868, 45.56250653948103, 43.60411855152675, 37.337270736694336, 37.256414549691335, 39.0342674936567, 46.13644858769008, 47.70692559650966, 49.75514336994716, 51.109732900347026, 44.71214083262852, 38.253203119550435, 37.45863492148263, 40.18529564993722, 50.905358586992534, 51.896050112588064, 49.579148973737446, 46.01027624947684, 53.89203480311802, 51.26542118617466, 48.35313933236258, 43.33895097460066, 41.80384029660906, 42.417501722063335, 39.199756213596885, 40.97825186593192, 45.00894008363996, 46.950972012111116, 51.45299128123692, 54.25215298788888, 54.10906873430525, 55.16692502158028, 53.684189864567344, 52.90544966288975, 54.013273920331685, 55.145601000104634, 55.25736972263881, 54.682489667619976, 31.888024398258754, 11.808746644428798, 2.6475661269256046, 6.914367377758026, 4.071579234940665, 1.8883186621325356, 0.5668565141303199, 0.051897683047822545, 0.002507700672140345, 0.37499745349798885, 17.92018931252616, 33.660204138074604, 18.093816110066005, 16.840037993022374, 22.683151653834752, 30.50097288404192, 36.973219871520996, 47.2383634022304, 52.17704221180507, 38.24230139596121, 1.3360887574298042, 0.07588798752320663, 0.05449972574466041, 0.026983544662860886, 0.0005350707163285863, 0.05314825362126742, 0.0503872437402606, 0.05610940419137478, 0.031015767848917415, 0.008496920844273908, 0.04631439496630004, 0.06598576637251036, 0.0769391061205949, 0.045720683610332866, 0.06040373018809727, 0.023161653761884997, 0.012760749236414475, 0.036578693094530275, 0.047568487136491706, 0.05772004955049072, 0.01660783838347665, 0.06119721582425492, 0.04707944659250123, 0.06178689668221133, 0.045327503101101944, 0.03589654487690755, 0.08595096040517092, 0.049178084159003835, 0.011903203109146228, 0.045853109897247384, 0.03699412276702268, 0.03756341025499361, 0.06644987075456552, 0.07788741987730775, 0.034924285619386604, 0.04855381158579673, 0.06155685295483895, 0.030894632384713207, 0.014771914309156793, 0.0504113385187728, 0.027462212102753774, 0.03784498871703233, 0.03816520296303289, 4.725637052740369, 59.084562574114116, 66.33093615940639, 56.978247438158306, 52.57103633880615, 34.57927015849522, 21.53057404926845, 22.380623613085064, 25.847472463335308, 44.55770322254726, 22.573069606508525, 0.27547449671796387, 0.04816786765253969, 0.06416188459843397, 0.42251469088452204, 3.732305645942688, 5.534231492451259, 3.1944369077682495, 2.6179600698607306, 22.13306450843811, 54.435679231371196, 61.98321206229073, 59.06363459995815, 57.86658157621111, 57.10449273245675, 57.163246699741904, 57.58587782723563, 58.41364451817104, 51.921980789729524, 52.2508807182312, 56.51375688825335, 55.94059303828648, 54.713506426130024, 52.310110637119834, 51.58922808510916, 52.54391057150704, 52.77634865897042, 52.02144772665841, 55.57955074310303, 50.45154047012329, 49.922744342258994, 52.54066923686436, 53.43395396641323, 51.494183676583425, 51.99639252253941, 49.25395243508475, 53.19177450452532, 52.09055798394339, 51.1593291418893, 48.522675377982004, 52.47678402491978, 52.68518829345703, 52.45799957002912, 51.19073152542114, 54.01912777764456, 48.773818016052246, 48.08339984076363, 50.84025049209595, 55.03472164699009, 42.63326760700771, 39.184623037065776, 37.914867537362234, 42.747200693402974, 43.44707884107317, 50.451259068080354, 50.60327870505196, 57.86291987555367, 33.36760854721069, 33.089677129473, 57.06743104117257, 48.840677056993755, 54.170223304203574, 43.57385219846453, 42.60156297683716, 44.95693629128592, 48.63687597002302, 48.31644936970302, 45.44457476479666, 39.25613042286464, 39.20572819028582, 39.901944637298584, 47.31178501674107, 49.69175495420183, 52.74832657405308, 53.72118902206421, 47.47138166427612, 39.307213578905376, 40.00747735159737, 41.54984194891793, 52.84809228352138, 52.61159644808088, 49.842680249895366, 47.661810943058555, 54.59713452202933, 52.71874114445278, 51.98108564104353, 43.95561402184622, 44.078850746154785, 43.31864833831787, 42.43979154314314, 43.37108986718314, 47.23888104302542, 50.45684194564819, 53.151877948216026, 55.90638358252389, 57.15673623766218, 56.53095020566668, 55.105461256844656, 54.499741622379844, 56.510307107652935, 56.78160299573626, 58.18851593562535, 54.187058789389475, 36.48146111624581, 10.83850019318717, 3.2793725558689664, 5.987919764859336, 9.339525359017507, 7.316868271146502, 2.321254619530269, 0.09122690265732152, 0.03717135950656874, 0.22718831630689756, 19.951206820351736, 37.7358124596732, 24.77344945498875, 17.658871037619456, 26.032344920294626, 38.67716135297503, 43.261815547943115, 52.67956372669765, 58.47230121067592, 47.85519320624215, 2.6203943278108324, 0.025569704993228828, 0.03496491629630327, 0.029503615240433385, 0.020958981509985666, 0.056256887170353105, 0.007123650783406836, 0.05090089474937745, 0.035623258112796714, 0.040662876795977354, 0.033090008688824515, 0.0624867444857955, 0.04244730854406953, 0.038217986202133555, 0.029802886503083364, 0.008644172273177122, 0.022186641348525882, 0.008182893989474645, 0.019516597568456615, 0.03974570440394538, 0.012729732552543283, 0.009591218865742641, 0.028278382860922387, 0.23165560087987355, 0.12959967287523405, 0.13064832160515444, 0.3520552617098604, 0.17802101746201515, 0.07317365745880774, 0.1498470085539988, 0.11571751135800566, 0.13808657175728253, 0.2630418081368719, 0.15021702727036818, 0.10876741286899362, 0.17645688567842754, 0.1833448303597314, 0.09644630937171833, 0.1186914760619402, 0.18400060731385434, 0.1268281830208642, 0.10777437686920166, 0.2988639516489846, 6.338834626334054, 67.63850375584194, 75.11436244419643, 64.01290593828473, 59.20333508082798, 38.038368293217246, 23.389835562024796, 24.199186052594865, 28.17819356918335, 63.96834019252232, 26.6862815788814, 0.6717368577207837, 0.19228694481509073, 0.20854810439050198, 0.3697496365223612, 4.188846588134766, 12.56878229549953, 9.69539385182517, 7.180712240082877, 22.606436593191965, 57.425992829459055, 64.30026258741105, 62.72648865836007, 57.877191475459504, 60.051876885550364, 59.249359948294504, 60.526258196149556, 60.574492590767996, 53.51438283920288, 52.46052524021694, 57.93719611849104, 57.87779944283621, 56.26323611395699, 53.42919445037842, 54.43943820680891, 55.4027989932469, 54.76129961013794, 54.43633236203875, 58.240207059042795, 51.09978307996477, 51.074950218200684, 53.664682797023225, 55.14745269502912, 53.21594033922468, 55.29202733721052, 52.12412473133632, 55.969685145786826, 54.59715189252581, 53.265619959150044, 49.44501747403826, 53.731527941567556, 53.44078057152884, 53.75718069076538, 52.352928910936626, 56.99597576686314, 49.49002095631191, 49.24331821714129, 53.63044554846627, 56.95028441292899, 44.85592338017055, 40.86477736064366, 40.5743704523359, 45.33247600282942, 47.06308814457485, 52.61588001251221, 53.15146105630057, 60.1368533543178, 36.83331094469343, 34.54934426716396, 58.48244558061872, 52.20407765252249, 57.41282946722848, 47.27171128136771, 44.70283372061593, 48.06783587591988, 51.107314927237375, 50.365490504673545, 48.18460382734026, 41.5864520072937, 40.964289460863384, 43.4717241014753, 49.65820905140468, 51.801999296460835, 54.41298641477312, 56.26917682375227, 49.64424664633614, 41.51541362489973, 41.75326088496617, 43.31623036520821, 56.975391728537424, 58.179795946393696, 50.122487681252615, 47.674897875104634, 55.73914739063808, 56.8402874810355, 54.37443086079189, 47.73063979830061, 46.44372919627598, 46.415536880493164, 44.53785221917288, 45.43671635219029, 49.70264278139387, 52.653136253356934, 54.92408548082624, 59.08286026545933, 57.474734442574636, 59.154468400137766, 56.29767486027309, 56.13806779044015, 57.701839787619456, 59.914441517421174, 60.71012837546212, 58.771164076668875, 38.33537251608712, 15.495497294834681, 8.969437377793447, 15.039888279778616, 12.87545667375837, 7.075227294649396, 1.653087073138782, 0.27484079929334776, 0.12781953625380993, 0.798264856849398, 26.010723863329204, 48.36814396721976, 26.73605326243809, 24.213270051138743, 33.921359130314414, 42.71623257228306, 50.01439108167376, 59.43582875388009, 63.925692149571006, 56.6969496182033, 3.985008154596601, 0.23323102348617145, 0.14835995834852966, 0.18064853575612816, 0.09357317497155496, 0.17222000445638383, 0.12652031811220305, 0.15469473414123058, 0.1603767592459917, 0.10390165182096617, 0.1514042735631977, 0.1703605470912797, 0.1502525960760457, 0.09636080717401845, 0.1611912048288754, 0.09199089237621852, 0.08614551675106798, 0.09607578853943519, 0.16353080714387552, 0.19956084021500178, 0.09845212674034493, 0.07733243251485483, 0.11634245568088122], [0.026205723007608737, 0.049155933383320055, 0.025589506341410533, 0.061856704364929876, 0.0622953161863344, 0.024680308432185223, 0.0857807295396924, 0.05830002057233027, 0.06479620627526726, 0.05609530084101217, 0.09114153616662536, 0.03995184673528586, 0.02653411020790892, 0.043521066462355, 0.03768869156816176, 0.03882292391998427, 0.03787350754386612, 0.09717066586017609, 0.12137894971030098, 0.23697583111269133, 9.442700896944318, 59.72555473872593, 51.316691943577354, 53.54940870829991, 38.09976952416556, 28.990191323416575, 18.401904446738108, 34.73743200302124, 40.836796964917866, 38.52911955969674, 7.914374266351972, 0.06632741553975002, 0.06903344033552067, 0.09285791763769728, 0.05986031184771231, 1.286010918872697, 5.069240237985339, 2.0221841761044095, 10.475084219660078, 43.12543283190046, 61.1492406300136, 56.53843341554914, 55.18741178512573, 51.708827427455354, 48.7762325150626, 51.31894663402012, 54.131035464150564, 54.42987053734915, 52.724122524261475, 51.482323101588655, 54.400493553706575, 51.49600063051496, 50.685090269361226, 45.53140640258789, 45.704395702907014, 45.32767479760306, 47.998722144535606, 48.71531070981707, 53.22766889844622, 49.37039729527065, 48.4777170589992, 51.391332966940745, 50.96692310060774, 49.2910349709647, 44.81423071452549, 44.443408829825266, 48.65538944516863, 48.74918665204729, 51.03456728799002, 48.89047827039446, 51.47421107973371, 51.47094542639596, 51.45317540849958, 51.370116642543245, 50.32523264203753, 46.37315286908831, 46.49627147402082, 49.435606139046804, 49.920885699135916, 37.25570930753435, 38.189307485307964, 35.71644360678536, 42.21787302834647, 40.63057790483747, 48.18205383845738, 46.73110668999808, 56.83880056653704, 32.43546601704189, 31.950724942343577, 53.46630825315203, 44.77499771118164, 52.39388159343174, 44.27625601632254, 39.154044015066965, 40.57420022147042, 46.50384153638567, 45.97227307728359, 42.61801978519985, 37.234631947108674, 37.028426783425466, 36.247518743787495, 39.68576880863735, 43.311130387442454, 46.16957412447248, 43.426039695739746, 38.77858073370797, 37.644655568259104, 37.14435052871704, 39.75189134052822, 49.82574054173061, 50.533984320504324, 50.19031252179827, 45.97951657431466, 50.92602947780064, 49.78907489776611, 49.264232294900076, 42.93116814749581, 39.72978912081037, 37.56821148736136, 38.797691753932405, 40.5062746320452, 45.5578408241272, 50.966131005968364, 53.88389151436942, 53.92002214704241, 51.65282494681222, 51.504720619746614, 53.40480627332415, 54.63770157950265, 54.24096638815743, 51.08294064658028, 53.110914843423025, 54.11733709062849, 52.08916139602661, 32.22262184960501, 7.172248465674264, 2.233327554804938, 5.5197853190558295, 6.6072635139737805, 1.624115364892142, 0.18987491567220005, 0.035095931230379004, 0.01890143602421241, 4.618934001241412, 34.01502084732056, 29.694002151489258, 22.195362057004655, 13.417960728917803, 17.92731121608189, 31.87851926258632, 43.639293806893484, 45.93337706157139, 57.997186865125386, 12.221362812178475, 0.25244640239647453, 0.05408014004517879, 0.04233075658391629, 0.02906487449737532, 0.05366959243214556, 0.03824719374201127, 0.03418422443792224, 0.02250463848135301, 0.05378837337983506, 0.052422594345573864, 0.001167891505506954, 0.03911520287926708, 0.028401988192594478, 0.02520070068671235, 0.028527145673121725, 0.024048069857859185, 0.03202874260023236, 0.053179486588175805, 0.08429886334176574, 0.038615855388343334, 0.04472334569852267, 0.027109153369175534, 0.030924067233822176, 0.04646195597680552, 0.06000054468001638, 0.0294231816993228, 0.07241311469780547, 0.028526402677276304, 0.019228647662592784, 0.01312514120114169, 0.04177652578800917, 0.020726949675008655, 0.03498163539916277, 0.028150290716439486, 0.05647485297439354, 0.054602900386921, 0.046648967013295205, 0.01788193715869316, 0.05558521553341832, 0.045874103770724366, 0.04189775624711599, 0.2291531908724989, 13.052934510367256, 69.15685190473283, 58.266516413007466, 57.51696211951119, 47.535440581185476, 36.0120199748448, 25.537648814065115, 26.38383517946516, 37.25060932976859, 46.30355971200125, 7.872360246522086, 0.06929914786347321, 0.07087838383657591, 0.10311392016176667, 1.1699409357139041, 3.7017704844474792, 3.661085741860526, 2.6403267553874423, 11.71434928689684, 45.09517070225307, 62.61423356192452, 59.989586285182405, 57.03122745241438, 55.3514518056597, 50.79515320914132, 53.39611060278756, 56.364384514944895, 57.07980578286307, 53.72323179244995, 51.46393469401768, 55.18924958365304, 53.5484915460859, 53.372441564287456, 47.46309246335711, 47.41007423400879, 47.949448994227815, 49.637399196624756, 50.458377497536794, 54.8155893598284, 51.07292481831142, 49.60180010114397, 52.20475510188511, 52.26359939575195, 51.21547753470284, 45.677214350019185, 47.68682098388672, 49.923105648585725, 51.286561080387656, 52.633535385131836, 50.42120116097586, 50.24163539069039, 53.38459743772234, 51.41897290093558, 52.10058076041085, 50.64412369046892, 47.7171950340271, 47.8953537940979, 51.25018726076399, 51.77508544921875, 39.29847274507795, 39.18991756439209, 38.308597632816856, 44.6717266355242, 44.500380584171836, 50.5127853666033, 49.091253416878835, 57.7291635785784, 34.605308532714844, 32.37026412146432, 56.106998920440674, 47.42638165610177, 53.65538610730852, 45.67552593776158, 40.74150242124285, 41.69345773969378, 49.36299746377127, 47.81690168380737, 44.69380453654698, 39.18343142100743, 38.29298503058297, 38.056315490177695, 43.17262847082955, 44.84251683098929, 48.8694669178554, 45.90251316343035, 40.81436470576695, 37.62716695240566, 39.31751080921718, 41.35466357639858, 51.499405247824534, 53.33772141592843, 51.84160055433001, 44.81623179571969, 52.6740642275129, 52.09072126661028, 51.76824147360665, 45.4951993397304, 40.8696654183524, 40.020807470594136, 40.53782640184675, 42.3755658694676, 47.77962112426758, 51.53938170841762, 55.668463366372244, 54.92149032865252, 53.60605737141201, 52.86519180025373, 55.063879762377056, 56.39147554125105, 55.38618585041591, 53.367946079799104, 55.798884528023855, 57.34912838254656, 55.02561255863735, 36.585989815848215, 9.49312310559409, 2.3412756366389136, 8.941368392535619, 10.390356148992266, 6.5088531374931335, 0.7433617115020752, 0.05377802911347576, 0.1077577934733459, 5.52626017161778, 35.794534410749165, 34.13641282490322, 24.322837931769236, 16.131927967071533, 25.5915755203792, 35.265126841408865, 50.724972929273335, 50.22799260275704, 66.87833608899797, 19.614512750080653, 0.22910151364547865, 0.061376125152621946, 0.09052436106971332, 0.013567479027967368, 0.07681887650064059, 0.07129950981054987, 0.02743228870843138, 0.03216229864795293, 0.07238867386643376, 0.027339741620900374, 0.03791481675580144, 0.08580471575260162, 0.033259218359099965, 0.014950596328292574, 0.05281977481873972, 0.047341785194086175, 0.027838417362155657, 0.014101956821312862, 0.08811134126569543, 0.0173135436406093, 0.06652238579200846, 0.0510929981911821, 0.15679956333977835, 0.1831950641104153, 0.14432675976838383, 0.16826221825821058, 0.29514992237091064, 0.12773170668099607, 0.174342312717012, 0.15779490635863372, 0.11010952799447946, 0.17567688253309044, 0.10293627290853433, 0.09849051825170006, 0.12210384224142347, 0.13262690257813248, 0.1995759444045169, 0.09243843371846847, 0.11266034469008446, 0.1433041396417788, 0.2806828229555062, 0.32731834479740685, 16.984407663345337, 78.72381264822823, 64.45101765223912, 68.97909614018032, 54.192478384290425, 42.80278628213065, 28.503364052091325, 48.02969373975481, 54.81565884181431, 53.72987427030291, 11.104759505816869, 0.19342061398284777, 0.25767831451126505, 0.23598560424787657, 1.5580017353807176, 4.885684898921421, 11.921248401914324, 6.918711304664612, 14.882740872246877, 47.37170628138951, 64.53025490897042, 61.23956721169608, 58.69617911747524, 57.09901407786778, 52.60215037209647, 55.4147881099156, 57.081792967660085, 58.888866560799734, 54.44993346078055, 50.90693930217198, 57.82505566733224, 56.42277717590332, 56.00899110521589, 49.20121213368007, 49.607452460697715, 49.45981018883841, 51.41370964050293, 52.57899897439139, 56.92493738446917, 52.95945801053728, 52.81961856569563, 54.644323212759836, 53.91905982153756, 54.64505624771118, 48.413487911224365, 48.82202114377703, 52.755816732134136, 52.58094099589756, 54.70423405511038, 50.046648093632285, 52.38176046098982, 53.70126853670393, 54.19287443161011, 54.363244261060444, 51.87078646251133, 48.05657284600394, 49.91663687569754, 53.14437736783709, 55.51776736123221, 42.16525084631783, 40.53030150277274, 40.83004331588745, 47.35835531779698, 46.806678771972656, 52.90830189841134, 52.54066228866577, 60.53327587672642, 38.26620667321341, 35.47891248975481, 56.09635428019932, 51.17604998179844, 56.626835346221924, 48.3652674130031, 43.09213359015328, 44.8292909349714, 51.75688811710903, 50.90247161047799, 46.59744766780308, 42.581691128867014, 40.78622102737427, 40.94986152648926, 44.328680174691335, 45.73533603123256, 49.52112109320504, 48.143213408333914, 42.35093450546265, 40.43120629446847, 42.17632974897112, 43.48535646711077, 54.09540857587542, 54.711182253701345, 53.299329144614084, 45.74609184265137, 53.38838420595442, 54.73403140476772, 54.0573776108878, 48.02742862701416, 43.09018462044852, 42.56056860515049, 43.405004024505615, 44.53651816504342, 50.21870633534023, 55.777762004307334, 58.385615485055105, 57.97701971871512, 54.712012563432964, 54.55742556708199, 56.608672755105154, 59.40194933755057, 58.8122626713344, 56.32391473225185, 58.05537802832467, 60.28409263065883, 56.172985962459016, 38.2201053755624, 10.473292452948433, 7.818055731909616, 16.394960709980555, 15.004633120128087, 6.012245408126286, 0.6676540853721755, 0.2004142337079559, 0.12807324049728258, 6.733003761087145, 48.324116706848145, 42.485066005161826, 32.03536442347935, 20.247502326965332, 27.168382338115148, 44.302843298230854, 56.4626007761274, 57.59609515326363, 72.57976382119315, 25.033008098602295, 0.4208188418831144, 0.14280609493809088, 0.15869743935763836, 0.08757841307669878, 0.1273554725838559, 0.17272650370640413, 0.16450483059244497, 0.08948297944984265, 0.12032975815236568, 0.10227832464235169, 0.10492687752204281, 0.20589622668921947, 0.07111294660717249, 0.14562966914049216, 0.09708910595093455, 0.1320487093180418, 0.06823755268539701, 0.0971953102520534, 0.2022342546177762, 0.16810220613011292, 0.16395025035100325, 0.1624512036464044], [0.0640252683577793, 0.043178413063287735, 0.0913061284060989, 0.05123853038198181, 0.014671760844066739, 0.034574585634150674, 0.024569374741986394, 0.09684435158435788, 0.08242983863289867, 0.02667312676619206, 0.05159238978688206, 0.01910882007463702, 0.047628534092966995, 0.006861458490935287, 0.04211726911099894, 0.0557106800510415, 0.028913557795541625, 0.04013301558526499, 0.03114130700539265, 0.057151315068559985, 27.694032669067383, 57.34167991365705, 51.952226298195974, 54.38155971254621, 36.2715664591108, 16.570506947381155, 23.70631558554513, 41.891345909663606, 39.651573249271934, 26.504919699260167, 0.9611940341336387, 0.08900148421525955, 0.06172843410500458, 0.06200906940336738, 0.633001790515014, 3.637870724712099, 1.918715728180749, 5.400547283036368, 29.66361767905099, 56.2165025302342, 57.503777912684846, 56.23688507080078, 53.336425576891216, 49.77864565168108, 44.58978305544172, 48.39818797792707, 54.2779655456543, 53.94485848290579, 55.135550430842805, 52.26284899030413, 54.16559927804129, 53.2558125768389, 47.13703087397984, 43.67242281777518, 41.44277368273054, 41.46035262516567, 44.253827231270925, 46.5309499331883, 48.81806067058018, 50.309606143406455, 50.91553769792829, 51.030916009630474, 49.1950421333313, 42.63091564178467, 38.85354137420654, 40.70995759963989, 43.16409260886056, 47.7314110483442, 48.97384623118809, 48.13946485519409, 51.242141246795654, 48.46991770608084, 51.57903855187552, 50.48267534800938, 50.54436492919922, 45.446996212005615, 48.396242482321604, 50.21768147604806, 43.69331605093819, 36.042272431509836, 38.14344937460763, 36.53023747035435, 41.99346705845424, 39.04792070388794, 47.80810873849051, 45.362443583352224, 56.79834468024117, 32.96423087801252, 30.429493291037424, 55.07595920562744, 43.96610232761928, 51.81653492791312, 43.361963408333914, 38.669261251177105, 38.80501168114798, 44.24258157185146, 41.60691792624337, 43.21879577636719, 36.94840438025338, 38.550613812037874, 34.7177859715053, 37.33061783654349, 37.79394456318447, 39.46588611602783, 37.91328682218279, 37.88280507496425, 36.663163457598, 36.978576932634624, 36.049602781023296, 46.88915736334664, 49.93205492837088, 52.36967754364014, 45.699125494275776, 49.026159218379426, 52.52989258084978, 49.3271621295384, 46.23274367196219, 38.442791666303364, 39.026047774723594, 39.13624620437622, 40.2166702406747, 43.42950684683663, 50.22634935379028, 50.984352656773154, 53.41794531685965, 50.90916619982038, 53.99064016342163, 53.58112723486764, 52.4799211365836, 49.510674476623535, 51.37350041525704, 53.281090123312815, 53.117380142211914, 55.900560992104666, 48.149438994271414, 22.306501967566355, 5.405641615390778, 6.393755793571472, 11.177965726171221, 6.415973092828478, 0.8550952587808881, 0.09566770400851965, 0.03585424500384501, 0.055711786063121896, 18.31940848486764, 34.073535101754324, 25.669200795037405, 16.56726734978812, 26.95370384625026, 38.05998413903372, 40.49668264389038, 52.102422033037456, 48.76653977802822, 42.48426696232387, 0.827822493655341, 0.07483698427677155, 0.009088299736114485, 0.033207042408840995, 0.06770258210599422, 0.048002705443650484, 0.03779651078262499, 0.040877544919827154, 0.029188089671411684, 0.0493328783528081, 0.03992680540042264, 0.03523441004965987, 0.027180421598521725, 0.04136627333770905, 0.03757954242506197, 0.07458678805934531, 0.033852454740554094, 0.050286321834261925, 0.07802709631089653, 0.012802403653040528, 0.03585341040577207, 0.025126792956143618, 0.04865593110610332, 0.021019014895760586, 0.042546432332268784, 0.10583223322672503, 0.0517182274987655, 0.03805428284353443, 0.02843892085365951, 0.07205526211432048, 0.021412778945107545, 0.04292511933350137, 0.013681632366829684, 0.059732061943837574, 0.008966693538241088, 0.037947769808982096, 0.009809198240483446, 0.022087962000763843, 0.006604902279962386, 0.04404823728171842, 0.05136231891810894, 0.079096087520676, 35.387512411390034, 66.22249562399728, 57.769188676561626, 61.60814135415213, 42.94385208402361, 21.918594462530955, 23.537043571472168, 43.06376756940569, 41.80343730109078, 27.85850347791399, 1.4720349311828613, 0.1355919920440231, 0.031199301393436532, 0.4482663433466639, 2.798281022480556, 7.1905547976493835, 2.730560622044972, 4.745150634220668, 32.13022470474243, 57.13322005953108, 60.35627746582031, 59.91558102199009, 54.57182570866176, 52.16651916503906, 47.58744089944022, 52.27456712722778, 56.041911670139854, 56.36449221202305, 55.10263681411743, 52.03800180980137, 56.58036579404558, 54.38773318699428, 49.92589535032, 45.626072134290425, 43.99412093843733, 45.33705833980015, 46.387521743774414, 48.519493103027344, 50.95731026785714, 51.60161672319685, 52.619298526218955, 52.443672384534565, 51.371061597551616, 45.473597390311106, 40.195200307028635, 42.11876392364502, 45.4356289591108, 49.97193758828299, 51.36310938426426, 49.52686725343977, 51.754928725106375, 50.261541979653494, 53.69502905436924, 51.41935505185808, 50.53849022729056, 47.46594817297799, 50.92088781084333, 53.0243889263698, 46.671876771109446, 37.75292934690203, 40.1351192338126, 36.44266932351248, 43.828145844595774, 42.09151656287057, 51.18332821982247, 46.22429813657488, 58.75824042728969, 35.1483484676906, 31.444600786481583, 55.7171493938991, 46.5035114969526, 52.68479224613735, 46.2498779296875, 40.85550498962402, 41.545784200940815, 46.57336868558611, 44.93091876166207, 45.22512286049979, 38.630664008004324, 39.32492801121303, 37.78421361105782, 39.72736767360142, 38.94599757875715, 41.258865288325715, 39.53064332689558, 37.88328102656773, 38.595645087105886, 38.171815395355225, 39.45237534386771, 48.38034152984619, 50.95223808288574, 54.0764399937221, 46.43122591291155, 50.26351874215262, 55.011587619781494, 50.64296334130423, 48.417107922690256, 41.46512256349836, 40.42176716668265, 41.142079966408865, 41.826269081660676, 44.466695717402864, 52.140307085854666, 52.299118586948936, 54.928570543016704, 52.26999521255493, 54.9125896862575, 54.70403255735125, 54.027465615953716, 53.06991352353777, 53.41478041240147, 53.97625739233834, 55.482786655426025, 57.08414145878383, 50.986600399017334, 23.724750893456594, 5.156193469251905, 5.301211493355887, 9.2928786277771, 8.326872314725604, 3.9110267758369446, 0.19488578821931565, 0.02628464680830283, 0.09245964472315141, 20.84013329233442, 33.613640785217285, 22.823852675301687, 20.853954996381486, 32.923886162894114, 44.23842307499477, 44.98043162482125, 58.05341168812343, 53.543454102107454, 53.184291294642854, 1.8546922036579676, 0.05975939333438873, 0.006337063303882522, 0.07904716514583145, 0.02529105101712048, 0.006167411313591791, 0.043640061148575375, 0.023550415311806967, 0.014390725210042936, 0.051242170722356865, 0.053994854978684864, 0.03887814649247697, 0.019744403826604997, 0.04512370850092598, 0.04431960718440158, 0.026515837259856716, 0.04535222891718149, 0.07463782067809786, 0.02149122268227594, 0.03520363509388907, 0.07470505671309573, 0.05795249529182911, 0.1196120445217405, 0.11038998008838721, 0.16500014758535794, 0.20923546036439283, 0.15035516342946462, 0.12898950704506465, 0.11726781459791319, 0.26650684220450266, 0.17587949308965886, 0.07896339321242911, 0.18558881351990358, 0.19891931249627046, 0.0706525741677199, 0.12031527821506773, 0.13627268480403082, 0.08711794564234358, 0.09982267926846232, 0.09863514120557479, 0.07211891548441988, 0.3819262188460146, 45.345910344805034, 74.31410367148263, 67.12038353511265, 66.98631804330009, 49.11382811410086, 24.375939539500646, 32.5400641986302, 56.2845253944397, 53.93523522785732, 36.35137694222586, 1.864930591412953, 0.25639118786369053, 0.23038999736309052, 0.40792461378233774, 3.1410167685576846, 14.792527198791504, 8.095515540667943, 9.761905482837133, 33.77287612642561, 60.99011993408203, 62.2107447215489, 63.081687518528526, 57.39045279366629, 53.75045483452933, 48.7702431678772, 53.956197943006245, 58.289473261152, 59.75424385070801, 56.293175901685444, 53.60947935921805, 57.796561104910715, 57.47509574890137, 51.50170857565743, 48.24261086327689, 44.63449818747384, 46.29773017338344, 48.771219389779226, 49.83952924183437, 53.924614906311035, 55.46371037619454, 54.993734223502024, 56.495799268995015, 53.96689469473702, 47.5835360118321, 42.906512464795796, 43.21841015134539, 47.36501864024571, 52.00970874513899, 53.749937193734304, 51.38001782553536, 52.71360295159476, 51.65579877580915, 54.22873408453805, 53.42411184310913, 52.74317101069859, 48.85669265474592, 52.83623170852661, 55.52898175375802, 49.115735394614084, 39.76165355954851, 42.14804015840803, 39.902229513440815, 44.33302279881069, 44.57585539136614, 51.56758792059762, 49.54125697272164, 59.33032035827637, 38.69162055424282, 33.788711071014404, 57.57465648651123, 49.03735624040876, 55.656741755349294, 48.72941902705601, 43.179997035435264, 44.20139612470354, 48.56323201315743, 46.788669041224885, 48.65529564448765, 40.82013518469674, 42.702402182987754, 39.145289284842356, 41.23655809674944, 42.2767207963126, 42.488084997449604, 42.07912792478289, 40.48826142719814, 40.90557370867048, 41.294537339891704, 40.686719349452424, 50.226926054273335, 53.87536260059902, 57.45588745389666, 46.14671802520752, 50.71135098593575, 57.240948404584614, 53.25742455891201, 50.82926539012364, 43.647662912096294, 43.377853938511436, 43.1247866494315, 43.91368859154837, 47.007002285548616, 55.44832011631557, 54.75346551622663, 57.92007923126221, 55.59292255129133, 58.881133215767996, 57.276578766959055, 57.48161663327898, 54.073625973292756, 56.16505111966814, 58.02687999180385, 58.70362063816616, 60.38478592463902, 54.82037319455828, 27.674268518175396, 9.218803882598877, 13.738361273493085, 21.233507292611257, 13.297637905393328, 2.6990820254598344, 0.2085628014590059, 0.1609683603580509, 0.22107987265501702, 26.181357724326, 49.19866909299578, 34.63761418206351, 25.889201607022965, 35.19068731580462, 49.82244709559849, 50.93314095905849, 64.90225451333183, 58.08459867749895, 60.316936765398296, 3.1402578949928284, 0.21649837706770214, 0.13995195951844963, 0.12297025003603526, 0.1418175779815231, 0.0988376499818904, 0.14126857529793466, 0.06424178888223, 0.1111726023788963, 0.13067695578294142, 0.1225366797298193, 0.1377818009683064, 0.14032906214041369, 0.09016990794667176, 0.2870085878031594, 0.1465313471853733, 0.11157088886414256, 0.11161768742437873, 0.15688379667699337, 0.09693566882716757, 0.15285529355917657, 0.21827647808407033], [0.04817600668008838, 0.012306973853680705, 0.041521108243614435, 0.0697759340650269, 0.08043963435505118, 0.013930965148444687, 0.03863773814269474, 0.04840141940595848, 0.0518238550451185, 0.04087491898930498, 0.1085467804223299, 0.02532803626464946, 0.04351922423977937, 0.005770265191261257, 0.04167736807305898, 0.04001735929133637, 0.015240885483633195, 0.024489621432232003, 0.0396617526587631, 1.2537555353982108, 39.9960823059082, 56.529800278799875, 58.122056416102815, 40.0528838293893, 32.910278115953716, 21.523054361343384, 35.78713457924979, 38.985147203717915, 36.51964841570173, 15.148707492010933, 0.012749781566006797, 0.05030730213703854, 0.029072239995002747, 0.23781783878803253, 0.9449588081666401, 3.8521308047430853, 1.4989370533398219, 17.59110004561288, 51.005416120801655, 60.99945136478969, 56.8539719581604, 55.23533698490688, 51.304671560014995, 47.34317002977644, 41.90156670979091, 45.42390387398856, 51.18622561863491, 54.88702726364136, 52.49047545024327, 52.112882546016145, 53.78509507860456, 50.22013419015067, 47.27646384920393, 41.328041553497314, 38.87019273212978, 37.99756152289254, 41.90018054417202, 43.740223339625764, 46.782665797642295, 48.510516030447825, 50.10864339556013, 48.98958042689732, 49.198641300201416, 38.4977901322501, 37.54323271342686, 37.87595762525286, 41.582887581416536, 47.099281311035156, 49.33528109959194, 50.61800193786621, 50.57135173252651, 47.639792101723806, 47.19538531984602, 45.642431667872835, 46.737245423453196, 45.58878115245274, 50.6707352910723, 46.98724160875593, 38.647165979657856, 36.83384943008423, 37.55761201041085, 37.50182492392403, 41.15439564841134, 39.43096446990967, 47.40300096784319, 45.24490090778896, 55.52051189967564, 34.526578494480674, 28.56433970587594, 54.885877336774556, 43.582561765398296, 49.809193406786235, 43.563061646052766, 39.287508487701416, 35.06869084494454, 40.37673936571394, 40.05323123931885, 40.21480464935303, 36.95553323200771, 39.12390620367867, 35.21259151186262, 37.43981225149972, 37.460889611925396, 38.85107476370675, 35.594999517713276, 37.79301697867257, 36.40592377526419, 38.312995842524934, 36.88906329018729, 44.05483429772513, 49.182698658534456, 50.77178641727993, 49.185974734170095, 46.48640503202166, 50.28232404163906, 49.51817853110177, 45.98519325256348, 40.4201899256025, 37.925887380327495, 38.01625912530081, 38.24575465066092, 39.78127874646868, 45.927179268428254, 54.45543295996529, 53.43203278950283, 52.8971118245806, 51.98623078210013, 50.11553600856236, 49.51244279316494, 48.02282544544765, 45.4961199760437, 47.58618327549526, 52.97650194168091, 51.880399295261924, 52.87387010029384, 30.472495692116873, 7.516579474721636, 4.586201906204224, 7.871219004903521, 10.247423018727984, 1.6826272308826447, 0.2697200040732111, 0.031655677261629274, 0.10533042265368359, 4.044353587286813, 33.29956831250872, 46.118261677878245, 25.702949932643346, 19.463101080485753, 42.55778237751552, 30.06738097327096, 45.2557817867824, 45.02749177387783, 51.67293998173305, 5.518662750720978, 0.2522197174174445, 0.05381391004526189, 0.06470949628523417, 0.007823424796307725, 0.03887226698654039, 0.06812477337994746, 0.05263858561271003, 0.02612237515859306, 0.036980216191815476, 0.029995359746473174, 0.023729431509439434, 0.06329755990632943, 0.017457759473472834, 0.027827679545485547, 0.026713533526552573, 0.018438225612044334, 0.01350963391762759, 0.009847346327400633, 0.02934564889541694, 0.02984519994684628, 0.027829881391621063, 0.057642167301050255, 0.03720469253935984, 0.04522342600726655, 0.012938265023486955, 0.021784560156187842, 0.03326534213764327, 0.031171813939831088, 0.04759311456499355, 0.04048755691785898, 0.006211353241399462, 0.03569487748401506, 0.03834600201142686, 0.020370837533846498, 0.047243217804602215, 0.03077924411211695, 0.020776837265917232, 0.037110101365085156, 0.04797906867627587, 0.02270612775880311, 1.8997901380062103, 48.56670263835362, 62.2377940586635, 63.32928657531738, 47.114039284842356, 37.19131687709263, 22.747066395623342, 30.50669472558158, 37.535381249019075, 39.86387545721871, 17.183596883501323, 0.022258640699354664, 0.17794390874249594, 0.1800251520637955, 1.279959037899971, 4.130735329219273, 4.069517357008798, 1.9833094392504012, 17.512029545647756, 54.0305506161281, 63.46911907196045, 60.77360711778913, 58.78264944893973, 54.61916031156267, 49.86146123068673, 44.42150115966797, 47.96355036326817, 55.09732839039394, 56.760452679225374, 53.269142695835654, 52.22271619524275, 55.00677946635655, 52.088202544621055, 49.200725759778706, 41.96373571668352, 41.083537919180735, 41.616700989859446, 44.442540305001394, 46.63848025458199, 47.910295895167756, 51.37149238586426, 51.9708057812282, 51.4002023424421, 49.59836769104004, 40.29808923176357, 39.49715648378645, 40.424438749040874, 43.5227620942252, 48.219070366450715, 51.085316930498394, 51.59902157102312, 51.914487157549175, 48.20713683537075, 49.001795360020225, 47.54320171901158, 46.57930244718279, 46.235783508845735, 53.41780982698713, 48.45237003053938, 41.56885569436209, 39.765857219696045, 39.243071283612935, 39.85674660546439, 42.78668730599539, 40.637491362435476, 48.03244522639683, 48.063517570495605, 56.24429532459804, 34.08548600333077, 30.539747306278773, 55.11817298616682, 46.413650444575715, 52.09137439727783, 45.52990211759295, 41.30823918751308, 36.8504695211138, 42.97196102142334, 42.71710457120623, 42.0888032913208, 38.48961557660784, 40.46205282211304, 37.81540060043335, 38.825432436806814, 39.14414630617414, 40.15461240495954, 37.387520108904155, 38.18687561580113, 38.000441551208496, 39.8639623097011, 37.76767689841134, 44.9562657901219, 50.87781940187727, 52.20480721337454, 49.74505805969238, 46.61477994918823, 52.761441298893516, 50.99104029791695, 48.68404729025704, 42.4268296786717, 39.56537389755249, 40.206612723214285, 40.516339097704204, 40.455698694501606, 48.52051101412092, 55.088354791913716, 55.05538558959961, 53.996956075940815, 55.337659631456646, 52.98067086083548, 51.37132910319737, 49.981696333204, 47.48643841062273, 49.56602035249983, 55.63756472723824, 53.862178393772666, 56.82489374705723, 32.2439215523856, 9.84223621232169, 5.07945408991405, 6.639595219067164, 7.091556429862976, 8.673630850655691, 0.7318120141114507, 0.10624702846897499, 0.11978684871324471, 4.214328237942286, 35.47201292855399, 38.15410096304757, 24.017000811440603, 21.174280847821915, 49.13423497336251, 34.44027491978237, 53.17514399119786, 49.0935880116054, 59.70177105494908, 12.378214921270098, 0.04916928355981197, 0.05060314679784434, 0.018681504164955447, 0.04207981737064464, 0.0377957542160792, 0.0718854655112539, 0.06262771013591971, 0.009859063779003918, 0.03608497405158622, 0.0323583070587899, 0.07601434431437935, 0.03993861869509731, 0.029418571053871086, 0.05483429439898048, 0.04800690557541592, 0.033886856465999565, 0.028697390109300613, 0.052203159513218064, 0.04681169667414256, 0.02938512267012681, 0.012370289652608335, 0.22348042098539217, 0.07328400082354035, 0.16733818926981517, 0.0810780543833971, 0.21212300684835228, 0.13248666296047823, 0.11555196238415581, 0.16040882681097302, 0.19216517492064408, 0.10248412431350776, 0.2179286474628108, 0.1281589258994375, 0.12712510994502477, 0.12289909885397979, 0.10241133786205735, 0.12508727929421834, 0.15172941397343362, 0.13796784169971943, 0.11101254953869752, 3.3234695153576985, 55.60384511947632, 70.94463729858398, 72.44833169664655, 56.11845302581787, 44.631149155753, 29.932676247188024, 48.56450005940029, 49.43711042404175, 49.02592645372663, 21.119350126811437, 0.15119529834815434, 0.23642543064696447, 0.2040538141237838, 1.537840342947415, 7.387190989085606, 10.532507606915065, 8.172174147197179, 22.69800169127328, 54.59139878409249, 64.4066742488316, 62.209000723702566, 60.67221205575125, 55.83952801568167, 52.93283946173531, 45.82253244944981, 49.69822720118931, 54.66610581534249, 58.852902684892925, 53.155247824532644, 51.82968091964722, 56.56815086092268, 53.281447955540244, 51.31736939293997, 44.913249492645264, 43.97458955219814, 42.72720725195748, 46.653200013296946, 48.83338492257254, 48.97397477286202, 54.00483185904366, 53.235117367335725, 52.77798843383789, 53.09699065344674, 42.72231919424874, 41.052917207990376, 42.3604987008231, 44.881520543779644, 50.40105485916138, 53.89798246111189, 51.64099563871111, 54.56384570258004, 50.58781896318708, 48.86207750865391, 47.23464264188494, 48.62066582271031, 49.687057971954346, 55.33071838106428, 50.41155358723232, 43.61524261747088, 41.87492036819458, 40.44276114872524, 41.82221828188215, 45.67301416397095, 43.953807490212576, 50.00593512398856, 50.81531340735299, 58.34763663155692, 38.11891875948225, 31.594591549464635, 56.67287758418492, 49.28221770695278, 52.76186861310686, 47.043219770704, 44.202177797045024, 38.63573966707502, 43.809205055236816, 44.715000016348704, 44.635199955531526, 42.06329298019409, 43.66619723183768, 39.52958720070975, 41.25243125643049, 41.732103620256694, 43.847406251089915, 40.230236598423545, 40.70966577529907, 40.52164057322911, 42.9985066141401, 40.23401294435774, 47.52540043422154, 54.1669784954616, 55.62892116819109, 51.09711497170584, 48.43709441593715, 53.70224823270525, 54.44231128692627, 50.5609815461295, 44.19828333173479, 41.311046259743826, 42.16113403865269, 41.11525991984776, 43.72731706074306, 50.42723567145211, 59.699443408421104, 57.741034575871055, 58.134295667920796, 57.46721996579851, 55.31653363364083, 53.665308134896414, 53.34257820674351, 49.76722281319754, 51.452876635960166, 57.52527911322457, 56.28908688681466, 57.77561576025826, 35.8024206161499, 11.628949846540179, 11.584033216748919, 13.934866751943316, 18.74092616353716, 6.64610698393413, 0.6513144192951066, 0.2577638642064163, 0.3594862243958882, 6.2311084525925775, 49.55592461994716, 57.10510069983346, 35.08387613296509, 25.974621023450577, 50.912966864449636, 39.93584489822388, 59.175389426095144, 56.487273829323904, 67.460143498012, 18.259487220219203, 0.4183808927025114, 0.18581226867224487, 0.11388913089675562, 0.10275352307196174, 0.1655908937432936, 0.19133713149598666, 0.09544996890638556, 0.1089402696649943, 0.1581410270716463, 0.1392656620591879, 0.14218300980116638, 0.19818604684301785, 0.09179286193102598, 0.22135102881916932, 0.09837307741067239, 0.0995893921437008, 0.08458948667560305, 0.13320372519748552, 0.13260261102446488, 0.11926314181515149, 0.07334365083702973], [0.06296670623123646, 0.05678762708391462, 0.037537924479693174, 0.05446651145549757, 0.03807850993637528, 0.03785600134038499, 0.0484688827501876, 0.04419786443135568, 0.049899784182863574, 0.04770571066598807, 0.02085371358719255, 0.025989831824387823, 0.058858346327074935, 0.03165082234357085, 0.02306342903258545, 0.03365883816565786, 0.02234684007375368, 0.05528475344181061, 0.053022870527846475, 4.726311462266104, 47.77543136051723, 56.14377920968192, 56.63810879843575, 42.6455728667123, 27.233050959450857, 18.456953287124634, 32.501095226832796, 48.35931975500924, 30.954064914158412, 2.7865609313760484, 0.04383036307990551, 0.06365996545978955, 0.102476673999003, 1.1005085642848695, 3.491754016705922, 5.050224755491529, 4.0633886115891595, 29.799347264426096, 58.12412003108433, 55.20015825544085, 55.522061347961426, 52.33285209110805, 50.74576193945748, 45.295188495091026, 42.53185864857265, 43.647252968379426, 51.262568950653076, 55.645850454057964, 51.86505419867379, 51.88378654207502, 52.295199802943635, 49.008253710610525, 45.32343292236328, 37.36319099153791, 39.81149646214077, 36.41645377022879, 38.914133140019004, 40.08836133139474, 43.341872692108154, 45.69201053891863, 49.29026024682181, 47.80678163255964, 43.51302766799927, 35.782503604888916, 36.620383398873464, 35.526594502585276, 41.167934213365825, 44.7550424848284, 48.37104136603219, 49.263725076402935, 50.26918847220284, 49.99543292181832, 47.337145941598074, 46.864935943058555, 47.69921309607369, 46.45549944468907, 50.01176813670567, 40.11407314028059, 38.43279320853097, 35.29450382505144, 37.41717849458967, 36.889403751918245, 40.3375688961574, 40.54117543356759, 47.720818519592285, 45.467232840401785, 55.20944104875837, 37.47298642567226, 32.44712509427752, 51.99950531550816, 44.22068779809134, 51.41723237718855, 44.10621622630528, 41.24763352530343, 34.96538850239345, 39.12468787602016, 38.64758634567261, 38.91986192975725, 36.34514093399048, 39.33108411516462, 37.09010246821812, 35.36391632897513, 36.06235619953701, 39.16634580067226, 38.24272176197597, 37.753207274845664, 38.13964523587908, 37.74569627216884, 37.356357438223704, 41.65239041192191, 46.05818060466221, 51.13403075081961, 49.07370574133736, 47.23132487705776, 50.11089808600289, 48.11498982565743, 47.2697171483721, 43.98402867998396, 41.498876912253245, 39.167078835623606, 36.68236827850342, 38.22413533074515, 38.75718723024641, 43.58831834793091, 49.08786964416504, 48.60525819233486, 48.263309546879356, 45.5109543800354, 45.169228076934814, 44.00709669930594, 43.710273129599436, 48.68669802801949, 51.474923270089285, 55.447062492370605, 57.48811319896153, 42.4932336126055, 19.750146797725133, 5.41364290033068, 4.42942579303469, 7.171149347509656, 10.524373003414699, 0.5619167249117578, 0.07723084903721299, 0.0642875764252884, 0.13925578258931637, 13.413899506841387, 37.05281148638044, 41.62406260626656, 23.51239136287144, 14.368661028998238, 25.034738200051443, 36.62310709272112, 47.3463488306318, 47.012738023485454, 41.088787283216206, 1.2200586178473063, 0.05200341237442834, 0.05463048962077924, 0.027447421735684787, 0.006096752069424838, 0.016655512253886888, 0.05177461375881519, 0.05201558529266289, 0.07025723930980478, 0.03623730855594788, 0.06587103967155729, 0.0499995763280562, 0.04625465674325824, 0.04863664714087333, 0.014876603780846511, 0.036791267937847545, 0.05909779454980578, 0.04050106994275536, 0.07821051111178738, 0.0343311374474849, 0.061064569013459344, 0.03289278909297926, 0.0712671640462109, 0.10936603681849581, 0.06370068434625864, 0.07616852782666683, 0.01127390852863235, 0.042512027214148214, 0.08199950493872166, 0.02877304337120482, 0.02159560002785708, 0.04352397398490991, 0.08103986643254757, 0.05598013309229698, 0.017542221816256642, 0.016331372682803443, 0.050287315888064246, 0.060258476196655204, 0.09259005915373564, 0.021858416996630173, 6.303408367293222, 58.18430185317993, 64.22053895677838, 62.473004477364675, 49.53708110536848, 35.277508531297954, 24.596761975969585, 35.01021133150373, 45.309216908046174, 34.14836025238037, 3.3202027763639177, 0.05247497385633843, 0.03908896053742085, 0.1323956578437771, 2.876475615160806, 5.5870503953525, 6.828839829989842, 4.1831308262688776, 32.74207265036446, 59.08611897059849, 58.085234437670024, 57.58235856464931, 54.47216074807303, 52.938005447387695, 47.62249803543091, 43.17331286839077, 46.23932361602783, 54.3794196673802, 57.58468273707798, 53.697012765066965, 52.69371025902884, 55.40282678604126, 52.99701302392142, 47.78523874282837, 40.22226701463972, 40.12711143493652, 38.638185432979036, 42.03041410446167, 42.771984917776926, 47.42690971919468, 47.494870049612864, 51.88005535943167, 49.14396939958845, 45.706556592668804, 38.13404498781477, 38.34697948183332, 37.33978598458426, 41.65559005737305, 47.440427439553396, 50.934440272195, 50.426127433776855, 52.23583092008318, 52.12284626279558, 48.562721320560996, 48.01351138523647, 48.844244956970215, 49.85111883708409, 51.40476730891636, 41.49974543707711, 39.17328357696533, 37.066172872270855, 38.164467675345286, 38.59343555995396, 42.08409936087472, 40.77722658429827, 49.431972231183735, 47.57468400682722, 56.79118456159319, 38.70367220469883, 31.91867290224348, 54.24037231717791, 46.191485268729075, 54.15919303894043, 45.20030736923218, 42.344827038901194, 37.010451793670654, 40.575218132564, 40.02499028614589, 42.42357792173113, 38.98566484451294, 39.67069469179426, 38.48259442193167, 38.152332646506174, 38.81269291469029, 40.04350028719221, 38.621652194431846, 40.4252655846732, 38.532531125204905, 39.77882603236607, 39.89189406803676, 44.300460066114155, 48.6365077154977, 53.30402612686157, 51.07861886705671, 46.21908003943307, 50.88493088313511, 52.30252667835781, 47.72925363268171, 45.28147275107247, 42.89471442358834, 40.58740527289254, 39.31907067980085, 41.15191166741507, 40.63875593457903, 45.64656237193516, 49.944082260131836, 49.8648658479963, 49.984840393066406, 48.064657075064524, 46.173767362322124, 44.36297300883702, 46.4484782900129, 50.06521020616804, 53.62802757535662, 55.99896138054984, 59.82615770612444, 45.70117521286011, 23.030565057482036, 5.795743014131274, 5.844382575580052, 7.8749996934618265, 10.578732235091072, 2.5766869017056058, 0.3842881992459297, 0.052887536718377044, 0.10065973363816738, 15.855240276881627, 36.836486271449495, 31.959802763802664, 16.219468321119034, 20.397161313465663, 32.474031993321006, 39.856555530003135, 53.57748985290527, 53.590208530426025, 50.65820074081421, 2.8608669212886264, 0.09014807947512184, 0.12086088822356292, 0.028601268838558878, 0.03165072734866824, 0.03249971714935132, 0.043954948894679546, 0.03101585605846984, 0.059556491007762294, 0.029077576672924415, 0.019626216597056816, 0.1032076801306435, 0.1292453147470951, 0.040040924812534025, 0.07373538945934602, 0.023325416492298245, 0.08746652943747384, 0.003939999250828156, 0.035477077921054194, 0.02440861113635557, 0.04114602765600596, 0.06800683720835618, 0.12788068582969053, 0.23270002912197793, 0.20665714942983218, 0.13890180444078787, 0.1654819617313998, 0.13359291931348188, 0.15133722073265485, 0.11051708326808043, 0.09661692021680729, 0.10191036188708884, 0.14343525974878243, 0.13521446873034748, 0.12211912285004344, 0.09089112960334335, 0.12233428630445685, 0.12917307790900978, 0.21361150911876134, 0.13589550075786455, 9.08517004762377, 69.38548237936837, 72.03398282187325, 71.03944546835763, 57.38282367161342, 39.76254987716675, 26.560781478881836, 43.8265824999128, 60.80394990103585, 43.924308913094656, 4.7656347921916415, 0.13465802930295467, 0.1776439691228526, 0.7018083355256489, 5.541777236121042, 11.569840652602059, 17.339682953698293, 9.048579096794128, 34.80342946733747, 60.8190552847726, 58.71255602155413, 60.219891275678364, 56.830563477107454, 55.605540479932515, 49.46815497534615, 46.08692877633231, 48.60594258989607, 55.677047865731375, 60.5610408782959, 53.91262231554304, 53.60869073867798, 57.68073116030012, 54.07112809589931, 49.8984569140843, 42.9386339868818, 43.561011927468435, 41.055383818490164, 43.21043709346226, 43.94858244487217, 50.40320185252598, 49.367621489933555, 54.46740123203823, 53.22156490598406, 48.765250887189595, 39.16520629610334, 41.02419682911464, 41.51134198052542, 43.95018400464739, 50.64640269960676, 52.07725913184029, 53.01769086292812, 53.87909378324236, 53.0177047593253, 48.49023076466152, 48.6661730493818, 50.30589927945818, 51.54842478888375, 53.97231428963797, 42.634813581194194, 42.27367401123047, 40.174591950007844, 39.448213372911724, 41.55471611022949, 45.912636688777376, 43.20432962690081, 51.41395282745361, 50.54025159563337, 59.05235072544643, 41.42486470086234, 35.3065311568124, 55.23848104476929, 48.48028094427926, 56.28277792249407, 46.889907768794465, 44.84514672415597, 39.15310600825718, 43.123820849827354, 42.11879519053868, 43.97456523350307, 41.802739007132395, 43.105522768838064, 40.63910334450858, 40.25433989933559, 41.157928807394846, 42.940398829323904, 42.21801894051688, 41.45989056995937, 41.31487471716744, 41.746913705553325, 42.17962319510323, 46.681454862867085, 50.01483924048287, 57.976870332445415, 52.88887473515102, 47.319789341517854, 52.96462399618966, 54.06741428375244, 50.568579401288716, 47.63308014188494, 45.580870628356934, 43.330842426845, 40.7773551259722, 42.77691813877651, 43.49072395052229, 48.36943285805838, 52.132743971688406, 53.417194911411826, 52.54199634279524, 48.869720527103965, 48.7241210256304, 47.18545634405953, 49.69296046665737, 53.82147584642683, 55.780944279261995, 58.718913623264854, 62.19345760345459, 46.90788623264858, 24.363908733640397, 11.180053659847804, 13.047579186303274, 16.087407384599956, 17.8752726827349, 1.1878539345094135, 0.19026773316519602, 0.17670928713466438, 0.27337692784411566, 19.803215401513235, 50.293486322675435, 53.56606701442173, 32.88802303586687, 23.850278786250524, 36.67065014157976, 48.75297689437866, 61.343651226588655, 58.76542486463274, 59.68201732635498, 3.8202138202530995, 0.35216214454599787, 0.12917203296508106, 0.09496803940939051, 0.1047171355624284, 0.09240991489163466, 0.1462930863989251, 0.1923375499567815, 0.19821607880294323, 0.1099849489650556, 0.09031248172479016, 0.17961351200938225, 0.19557627902499267, 0.13782097958028316, 0.13108054841203348, 0.13702450160469326, 0.15236296212034567, 0.11284598508583647, 0.10037721879780293, 0.13917997665703297, 0.17137598831738743], [0.0968108998079385, 0.033512444235384464, 0.027082566670807343, 0.027468644614730562, 0.006696461674956871, 0.00708931903188516, 0.01122402772307396, 0.04610921276201095, 0.0652951602158802, 0.01803579497417169, 0.04964761682120817, 0.010486461854140674, 0.0825453931465745, 0.02906752417662314, 0.042652578957911046, 0.0796111702386822, 0.1014338538848928, 0.022359438772712435, 0.007793313108517655, 17.49731499808175, 54.98218979154314, 50.03233480453491, 51.549123082842144, 32.49645383017403, 19.795113801956177, 23.815859147480555, 40.3156647000994, 41.19988203048706, 17.77265473774501, 0.3027368395456246, 0.03514970513060689, 0.16684239730238914, 0.1589359851287944, 1.6702356615236826, 3.169615771089281, 1.9412778317928314, 8.857433285032, 46.27552373068673, 60.71374143872942, 56.28266327721732, 54.85604177202497, 48.286540848868235, 47.56218767166138, 44.46955142702375, 41.91255528586251, 39.395306314740864, 51.20999540601458, 54.808509145464214, 52.39783511843, 50.72847829546247, 51.993866852351594, 49.75515031814575, 43.53377151489258, 35.57101433617728, 38.51172127042498, 36.668020248413086, 36.67340857642037, 37.412217480795725, 40.719761507851736, 40.72157498768398, 43.453127247946604, 42.55860226494925, 39.64080006735665, 36.7424875668117, 35.74348946980068, 35.78196164539882, 40.92406633922032, 43.78963197980608, 47.824475220271516, 46.15832846505301, 49.355635847364155, 48.692541463034495, 48.197058473314556, 44.683107784816194, 47.10801519666399, 49.034184387751985, 45.42077718462263, 35.75579820360456, 37.52530983516148, 35.67694309779576, 36.90633303778512, 38.162324156079976, 42.87978621891567, 40.32252604620797, 43.908255100250244, 44.86650201252529, 54.02431460789272, 36.621196338108604, 31.098486695970806, 51.169285910470144, 44.59369141714913, 48.79039641789028, 42.58667646135603, 38.55953529902867, 35.95674358095442, 36.11479425430298, 36.88061080660139, 37.55407190322876, 36.02505826950073, 37.41698047092983, 37.75265141895839, 37.14550392968314, 37.991256032671245, 39.83181994301932, 39.3915890284947, 39.42914056777954, 39.1228083883013, 37.14138017381941, 39.56432819366455, 41.765076296670095, 48.082854407174246, 49.89287403651646, 50.39059087208339, 45.365761348179404, 48.35070398875645, 49.33872740609305, 47.84998205729893, 46.66211455208914, 42.26356438228062, 39.837072781154085, 37.59693186623709, 37.27108219691685, 39.09806932721819, 37.79252365657261, 38.59326532908848, 41.378277029309956, 42.07361452920096, 41.30068302154541, 41.43480409894671, 40.262427602495464, 46.075856821877615, 50.8509715625218, 53.38014364242554, 52.48274557931082, 52.63946219852993, 47.253135272434776, 34.85152837208339, 13.65207941191537, 4.497798672744206, 3.3045408853462765, 14.263705015182495, 1.902918347290584, 0.4753511814134461, 0.2443098718566554, 0.04065239682261433, 3.5945358957563127, 26.261960302080425, 26.074063641684397, 19.987943683351787, 16.254615783691406, 19.793401071003505, 33.599654061453684, 42.334255354745046, 43.12270218985421, 43.27400616237095, 13.289481588772365, 0.07153778416769845, 0.007830873414474939, 0.029165192507207394, 0.06293862845216479, 0.0026430406308333787, 0.0038482570754630224, 0.0503786093821483, 0.018679454989199127, 0.012975346962256091, 0.0018984633747355214, 0.05329576713432159, 0.041079269988196235, 0.011798053929981376, 0.01883148924181504, 0.040901904326996634, 0.02901024225034884, 0.039025612508079836, 0.061869331901626926, 0.05483215701367174, 0.02659598072724683, 0.05640755926391908, 0.04162869675617133, 0.033882853109389544, 0.017683502985164523, 0.028581961124603237, 0.01931153071512069, 0.006993592583707401, 0.029891513354544128, 0.0386979038427983, 0.04295437776350549, 0.02955038326659373, 0.013773405076270657, 0.021814439445734024, 0.008885025911565338, 0.03751636063680053, 0.04130558855831623, 0.024802224211660878, 0.05107867092426334, 0.1195092328957149, 24.075959750584193, 63.601079259599956, 55.44423804964338, 59.2226927621024, 38.67175218037197, 25.727317265101842, 21.789255482809885, 32.76313264029366, 43.07400574002947, 21.304934774126323, 0.34553687434111324, 0.031226049243871654, 0.08133638623569693, 1.0824929709945406, 4.553635699408395, 4.911090552806854, 2.9134660874094283, 10.248702355793544, 48.9004350389753, 62.477076121738975, 57.7221736907959, 56.03578335898263, 52.76158373696463, 49.99673918315342, 46.19440003803798, 43.015251772744314, 41.391155515398296, 52.786663259778706, 55.75987386703491, 54.673477854047505, 51.87770339420864, 54.75336824144636, 51.811174392700195, 46.95707253047398, 37.83336864198957, 40.089511258261545, 38.37015519823347, 39.103954451424734, 38.374876499176025, 41.35544524874006, 42.92425468989781, 45.6577593939645, 43.7400461605617, 41.30782576969692, 38.88151134763445, 37.06067337308611, 37.69027049200875, 42.10762248720442, 45.475327491760254, 48.65403454644339, 48.22792584555489, 52.21909965787615, 51.74906097139631, 48.545114585331504, 45.4222606250218, 49.700332505362375, 51.265827655792236, 47.27088791983468, 37.93628535951887, 38.74256822041103, 37.11453928266253, 37.34100191933768, 39.42106328691755, 45.51765244347708, 41.48967054912022, 46.508132049015586, 46.177825110299246, 54.48782893589565, 38.295521123068674, 31.75544582094465, 51.44902038574219, 46.78019571304321, 51.5744423185076, 44.999782357897075, 40.27460779462542, 38.51137038639614, 38.42904812949044, 38.63209186281477, 40.532059397016255, 39.49197312763759, 41.1310635975429, 39.96026086807251, 40.66732692718506, 41.36688893181937, 41.9099566595895, 41.14614813668387, 41.19253431047712, 40.40919092723301, 39.82589660372053, 40.77774422509329, 45.0470335824149, 49.43351125717163, 51.1353509085519, 51.20823751177107, 45.679993629455566, 50.01752124513899, 52.43583134242466, 50.48048666545323, 49.26125846590315, 45.05388103212629, 41.48659597124372, 39.450811999184744, 39.576876640319824, 40.66127157211304, 39.24599647521973, 40.36642129080636, 43.96773515428816, 42.490280628204346, 43.07276201248169, 43.46078763689314, 41.86280618395124, 48.440627574920654, 53.11337103162493, 55.09164823804583, 53.76621682303292, 53.00066777638027, 49.14026600973946, 35.98574536187308, 12.631136298179626, 3.15081416283335, 5.511640727519989, 10.661339368138995, 8.183887941496712, 1.6366973583187376, 0.4130340910383633, 0.06526716386101075, 3.46137193271092, 30.250393050057546, 34.88867344175066, 24.147388969148906, 15.544117314474923, 26.789217403956822, 39.775786195482524, 47.370615414210725, 47.82098375047956, 51.85864101137434, 17.149625403540476, 0.10137609698410545, 0.014883058345211404, 0.027782056547169174, 0.014350980021325606, 0.011846901665973877, 0.03344847195382629, 0.05296735957797084, 0.0500484715615, 0.03629430889018944, 0.029147360606917312, 0.025908041213239943, 0.004379109371387, 0.0584205419623426, 0.027293204296646372, 0.04696568680394973, 0.07978385061557804, 0.013876578022193695, 0.05625156406313181, 0.006199301187215107, 0.025766581928889667, 0.15324967168271542, 0.06388508980827672, 0.15084579853074892, 0.14192925127489225, 0.09884539885180336, 0.0823042146595461, 0.10211758648178407, 0.07910756154784135, 0.1590590849518776, 0.15392652393451758, 0.1255077945866755, 0.0982899907976389, 0.15935868530401162, 0.08942496470574822, 0.10441313830337354, 0.16158717072435788, 0.17351733627063887, 0.15605671677206243, 0.29738265542047365, 31.24954400743757, 71.94469846997941, 63.223340443202424, 67.32466057368687, 45.016016823904856, 30.152666636875697, 32.160095010484966, 51.00624295643398, 55.33049603870937, 26.708626985549927, 0.6894747944814819, 0.1587496865540743, 0.25422530408416477, 1.0765372791460581, 7.38093934740339, 12.472452470234462, 7.891288876533508, 13.332956467356, 51.14737476621355, 64.72207382747105, 59.83712196350098, 60.744966643197195, 54.180155754089355, 52.862627914973665, 48.43309572764805, 45.604616097041536, 43.54414864948818, 56.10683216367449, 59.592726026262554, 54.5946991784232, 51.21815259116036, 57.672931807381765, 54.4980080468314, 49.585690702710835, 39.78813661847796, 42.62454066957746, 40.5191878591265, 41.57503959110805, 40.539598192487446, 44.70953178405762, 44.40959194728306, 47.69889347893851, 46.222595827920095, 43.29527807235718, 41.87346472058977, 40.040793963841026, 38.96080418995449, 45.10811172212873, 47.429358959198, 52.2590274810791, 49.80354452133179, 54.39911781038557, 53.77512788772583, 48.832050868443076, 46.26413910729544, 51.70144844055176, 54.94458614076887, 48.69542496544974, 39.03201280321394, 40.8798097882952, 39.36936868940081, 40.15359796796526, 42.147897720336914, 47.66943311691284, 44.68035977227347, 48.099464075905935, 48.39768075942993, 56.975468158721924, 40.24516480309622, 33.231566292899, 52.881777150290354, 49.11369609832764, 54.44571590423584, 46.49529177801949, 42.12655980246407, 40.56061996732439, 39.60870286396572, 40.861028807503835, 42.1174750328064, 41.626536164964946, 43.32968207768032, 42.195704800742014, 42.36363581248692, 43.19945199148995, 43.879416601998464, 44.020975725991384, 43.145287309374126, 44.52074575424194, 41.74093130656651, 43.158061572483604, 46.73430633544922, 51.06029994147164, 53.52769558770316, 54.10380547387259, 46.38241829190935, 51.18411684036255, 53.063246726989746, 52.79768657684326, 51.804358209882466, 46.985761642456055, 43.9431037902832, 42.221413135528564, 41.512432847704204, 42.10531568527222, 40.87701313836234, 42.104832785470144, 46.69206823621477, 45.24629749570574, 45.48439141682216, 46.20597226279122, 45.23566327776228, 51.52349812643868, 56.23826428822109, 58.402284213474815, 55.37550299508231, 56.2100441796439, 49.954268319266184, 39.50663382666451, 16.82239999089922, 9.08303087098258, 10.610444681985037, 29.036851951054164, 8.051844375474111, 0.7191694953611919, 0.5777762053268296, 0.17272514663636684, 5.406718586172376, 40.65504598617554, 38.94677577699934, 29.679800033569336, 24.5678904737745, 28.795459372656687, 45.2680001940046, 53.916419506073, 54.45361600603376, 59.47013201032366, 19.510718822479248, 0.24094452815396444, 0.0812776115323816, 0.2330210576100009, 0.09450468820120607, 0.0778500461684806, 0.12147522025874682, 0.1317763589322567, 0.08431707522166626, 0.07960174538727317, 0.10932700069887297, 0.1309949444340808, 0.1079716541405235, 0.10766125829624278, 0.13831670369420732, 0.1915934413139309, 0.10638635206435408, 0.11503931560686656, 0.11219209445906536, 0.1367851144501141, 0.1331947006817375], [0.015751501744879142, 0.07826474641582795, 0.058690497119511874, 0.012119388606931483, 0.03134055881361876, 0.012699610686727932, 0.026048728664006506, 0.026617324046258415, 0.03479231734360967, 0.009485403025921966, 0.0959280307537743, 0.05069416548524584, 0.036850273343069215, 0.08841648524893181, 0.006362094884804849, 0.04007475996123893, 0.040710767797593556, 0.02370184227558119, 1.2477238476276398, 38.79194559369768, 54.86569629396711, 53.55398062297276, 52.20348705564226, 42.290940284729004, 22.28990272113255, 32.266117572784424, 45.4055050441197, 34.04844168254307, 7.494593637330191, 0.1545473834765809, 0.03058167846341218, 0.04516836289050324, 0.06507237002785717, 2.155080416372844, 3.632441141775676, 5.075949157987322, 22.31448892184666, 56.07297011784145, 56.04735558373587, 53.99743202754429, 50.69321966171265, 47.414152826581685, 43.34994649887085, 41.72427300044468, 42.107466152736116, 38.84821557998657, 46.741351808820454, 53.4972242627825, 52.43674155644008, 52.273667335510254, 51.70650672912598, 51.00127499444144, 42.261545930589946, 37.03202942439488, 38.167278221675325, 36.89189120701381, 37.8168979372297, 37.722079345158164, 37.508189473833355, 37.8780768258231, 38.941644532339915, 38.46888215201241, 37.31493575232369, 35.03605168206351, 35.720237323216026, 36.31709453037807, 40.52227633340018, 41.354118142809185, 44.62687948771885, 44.52600901467459, 46.62688718523298, 49.500290393829346, 49.51269292831421, 44.88015522275652, 48.871162278311594, 46.70385932922363, 40.28575617926461, 36.35463912146432, 36.21376092093331, 34.29834059306553, 37.79467759813581, 40.128184931618826, 41.5550148827689, 39.99461623600551, 46.92836257389614, 44.28267962591988, 53.849067143031526, 35.321612221854075, 29.074705736977712, 53.52327653339931, 44.57240908486502, 50.75954369136265, 41.3112963948931, 39.723313399723594, 35.51974010467529, 35.99861689976284, 36.07208020346505, 35.89492893218994, 35.64795868737357, 37.0160242489406, 38.44471979141235, 39.19010516575405, 38.70840392793928, 41.46619258608137, 40.53526599066598, 41.42017814091274, 40.842199189322336, 40.78520311628069, 41.20592696326119, 47.531973430088584, 47.78154577527727, 51.10109976359776, 50.444064208439414, 47.09841973440987, 47.85166004725865, 47.93514960152762, 48.8547819001334, 48.91562032699585, 47.66157470430647, 44.72041961124965, 38.741515568324495, 38.20243263244629, 37.70057119641985, 36.6647059576852, 39.370754855019705, 37.35705573218209, 38.24775225775582, 38.03954948697771, 37.967520986284526, 38.59067365101406, 44.86693280083792, 53.02641085215977, 51.38405820301601, 55.04741947991507, 51.926722935267854, 51.09093107495989, 48.315000670296804, 28.932922533580236, 8.298308270318167, 6.5751350436891824, 8.7429313148771, 7.921634265354701, 3.4707758852413724, 0.09467379948390381, 0.03718547642763172, 0.3948158329086644, 11.389494947024755, 31.134665966033936, 26.207260608673096, 19.546125105449132, 15.87379891531808, 32.37267862047468, 37.151180607931956, 43.46449102674212, 47.62103196552822, 25.05101088115147, 0.869257967386927, 0.007056681921572557, 0.04751850963969316, 0.09906536633414881, 0.02092882402108184, 0.06606999970972538, 0.037996152748486826, 0.10729910380073956, 0.03282798560602324, 0.017073839270908917, 0.012621166949559535, 0.03929863125085831, 0.028412566553535204, 0.02177916919546468, 0.0344733142826174, 0.04367089717249785, 0.028252774949318597, 0.06090351872678314, 0.017119674311418618, 0.049816907915685854, 0.028448863088020256, 0.04431469798354166, 0.04623235668987036, 0.04254482759694968, 0.0297171230694013, 0.055648088588246276, 0.06522489791469914, 0.049016582646540234, 0.046108897243227275, 0.04204163620514529, 0.05053462493898613, 0.057457972184887955, 0.04836634253816945, 0.02615900756791234, 0.01012603338209114, 0.029666494178984846, 0.06062984519771167, 0.011352213166121925, 2.2854286219392503, 48.3658823285784, 63.63745307922363, 59.51143905094692, 58.45405524117606, 47.333296639578684, 24.391616412571498, 28.839229549680436, 42.34237085069929, 41.015098163059776, 9.053210939679827, 0.08061918829168592, 0.027272098464891315, 0.3835506316806589, 2.714632962431226, 5.462718026978629, 3.0135123303958347, 3.412075332232884, 25.191305433000835, 56.69845042909895, 57.57085929598127, 55.7581924029759, 53.183613845280235, 49.90096868787493, 46.790058680943076, 43.70541981288365, 44.4395386832101, 41.118053095681326, 49.34641211373465, 54.78164740971157, 53.26306997026716, 54.41625206811087, 54.22083050864083, 53.04092563901629, 43.02184213910784, 39.15592350278582, 40.9777272769383, 38.8863160269601, 39.070717743464876, 39.21635546003069, 39.411752700805664, 39.61602973937988, 40.54740101950509, 39.419367926461355, 39.31213985170637, 37.31878852844238, 36.990736280168804, 37.71430083683559, 42.19122321265084, 45.497169154030935, 45.56995848246983, 46.22008752822876, 49.01896783283779, 51.22822747911726, 50.906543254852295, 47.06989390509469, 51.45596858433315, 49.1895044190543, 42.48728942871094, 38.12173972811018, 37.763132776532856, 36.335156372615266, 40.52358954293387, 41.794078077588765, 44.081963539123535, 42.20226042611258, 48.42997251238142, 46.415821756635395, 55.02223226002285, 37.716739654541016, 30.741130420139857, 54.33754634857178, 47.06846605028425, 50.99188450404576, 43.82822922297886, 41.708427633558, 37.671861239842, 39.1304166657584, 38.00570828574044, 38.45019497190203, 37.67664507457188, 39.36692639759609, 40.559216431209016, 41.48456709725516, 41.5507104737418, 42.86032084056309, 43.217635427202495, 43.21787861415318, 42.46932486125401, 40.690888268607004, 42.741180079323904, 47.97564022881644, 50.12546845844814, 53.07281787054879, 51.293773310525076, 46.62916966847011, 49.43401847566877, 49.66606051581246, 50.626193864004954, 51.14112833568028, 50.32101508549282, 47.44794191632952, 41.050610406058176, 39.51253284726824, 39.714919975825715, 38.779862676348, 39.887367316654746, 39.66202333995274, 39.93088388442993, 38.98502908434187, 40.04106494358608, 40.64247669492449, 47.087368624550955, 54.26898152487618, 53.031302383967805, 55.963553360530305, 54.07884407043457, 53.480256761823384, 48.044041769845144, 29.60718093599592, 8.601401720728193, 2.2838932871818542, 4.430598735809326, 10.369421226637703, 7.019808028425489, 0.7652747013739177, 0.034506901766040494, 0.26807539803641184, 14.88657454081944, 30.561373574393137, 26.76237824984959, 22.29579653058733, 19.852992296218872, 38.17849261420113, 42.445225034441265, 48.42489685331072, 54.5951577595302, 32.314852237701416, 0.8814557471445629, 0.0489882334534611, 0.043867153248616626, 0.03909738454967737, 0.07564986922911235, 0.010581640809375261, 0.05404597580698984, 0.050965705021683655, 0.0277615105068045, 0.018623224792203734, 0.016652747223685895, 0.06417413894087076, 0.04590900421940854, 0.009028807482016938, 0.03379701503685542, 0.07315351175410406, 0.019416880062116042, 0.015708560656223978, 0.02420332545547613, 0.046829202877623696, 0.06134848163596221, 0.12772470419960363, 0.16276992511536392, 0.09211976653231041, 0.1033875122666359, 0.0966340396553278, 0.18153448535927705, 0.12588584715766565, 0.07261857510145221, 0.1480769006801503, 0.20488207467964717, 0.09107480903289147, 0.18734399362334184, 0.12721900562090532, 0.05939832449491535, 0.13067695578294142, 0.15746189494218144, 0.1338048122291054, 3.427811482122966, 57.79665143149239, 69.9432351248605, 69.1826297215053, 65.23424639020647, 55.25545201982771, 33.58187014716012, 44.70676292691912, 59.00130231039864, 47.741732597351074, 11.294374108314514, 0.17596509706761154, 0.2949595254446779, 0.1962223257869482, 2.188225929226194, 11.880644866398402, 11.600824407168798, 9.59951044831957, 27.375819069998606, 58.079901695251465, 59.46643556867327, 59.50180189950125, 55.07567432948521, 53.63923154558454, 48.27260276249477, 45.47937829153878, 47.727850096566335, 41.92008713313511, 50.61712646484375, 57.60013553074428, 55.0022040775844, 54.898318086351665, 56.362095083509175, 55.27898209435599, 45.33480364935738, 41.43181984765189, 42.907127380371094, 41.79522453035627, 41.93930932453701, 41.40559734616961, 41.04656655447823, 41.13268600191389, 43.25880697795323, 42.57650777271816, 41.23129483631679, 38.939011165073936, 39.63250739233834, 39.854095867701936, 45.14904703412737, 47.40705871582031, 48.42902755737305, 48.53818723133632, 49.352898257119314, 52.836679867335725, 53.2648035458156, 48.957924434116904, 52.57816866465977, 51.619244303022114, 43.941880907331196, 39.95371219090053, 39.350587708609446, 39.300678798130576, 43.94439615522112, 44.28403452464512, 46.577770369393484, 42.688992159707205, 50.82297379629952, 48.77407162530081, 56.07406793321882, 40.433339391435894, 33.76230444226946, 55.57455151421683, 49.110169887542725, 53.53123222078596, 45.768753392355784, 44.71665716171265, 38.285651206970215, 41.726555483681814, 40.98832675388881, 40.33232995441982, 40.86222389766148, 40.59215089253017, 43.03234781537737, 43.783416816166465, 43.82436255046299, 45.27254778998238, 45.67484501429966, 45.583351135253906, 44.25592558724539, 44.20160109656197, 45.129189082554404, 49.901677404131206, 52.20182991027832, 55.644162041800364, 52.98060137884957, 48.127771036965505, 50.130564962114605, 51.83790758677891, 53.74683829716274, 53.43156378609793, 53.153396129608154, 48.856550216674805, 43.81846352985927, 42.47588048662458, 41.9838090624128, 39.80811268942696, 42.052721296037944, 41.88185467038836, 42.013252053942, 41.08074821744646, 42.09344121388027, 42.9703768321446, 50.56543186732701, 57.43730449676514, 55.43095309393746, 59.80501433781215, 54.42266525541033, 53.895501954214915, 49.8016163962228, 33.381348609924316, 12.275301677840096, 12.565044164657593, 15.712684086390905, 15.954288584845406, 5.380376662526812, 0.20389462980840886, 0.13751304681812013, 0.39570702080215725, 18.935486146381923, 46.71460819244385, 38.40906163624355, 27.596827370779856, 23.555933986391338, 41.84406341825213, 50.03135510853359, 55.31153787885393, 62.05467428479876, 38.401255335126606, 1.325480920927865, 0.11720150815589087, 0.13937897740730218, 0.18372388716254914, 0.14954943023622036, 0.11953351087868214, 0.15704341525478022, 0.2022836519671338, 0.11974862005029406, 0.1695582472852298, 0.11284947954118252, 0.14909345470368862, 0.12590392333056244, 0.0788913124373981, 0.13538142905703612, 0.22955216946346418, 0.14379731246403285, 0.10471531030322824, 0.09773548519504921, 0.12905742840043136], [0.023276346536087136, 0.044433594282184324, 0.017695672510723983, 0.01656271580473653, 0.03455073852092028, 0.035235638198043616, 0.028078225208446383, 0.03261138705004539, 0.045126022305339575, 0.04677959178973522, 0.006523344915227166, 0.014571279985830188, 0.013374249218031764, 0.03569535245852811, 0.0427600860462657, 0.007185536569782666, 0.045740232204220126, 0.04053157687719379, 5.228083005973271, 45.55998434339251, 57.681377342769075, 49.740197794778005, 44.463885171072825, 22.87619866643633, 13.928463986941747, 28.49178487913949, 32.8362763268607, 27.36526128223964, 1.8843041232654025, 0.12109834833868913, 0.05581350864044257, 0.43065811534013065, 1.78575456568173, 3.4554386053766524, 1.787024131843022, 12.470218624387469, 46.57113831383841, 56.859926564352854, 57.183879375457764, 53.418240615299766, 53.248374530247276, 48.892204897744314, 45.831662382398335, 39.91781084878104, 40.457936014447895, 38.092296736580984, 40.831099442073274, 50.30853264672415, 53.134618622916086, 52.55420085362026, 53.332274028233115, 47.331882681165425, 38.946299825395855, 37.44287988117763, 37.41770655768258, 36.43987267357962, 38.289045401981895, 37.55497516904558, 39.64512879507882, 37.05509049551827, 36.491720131465364, 37.566724572862896, 37.09252044132778, 34.44888721193586, 35.66366856438773, 34.05920444216047, 38.370443548474995, 41.08845376968384, 42.880425453186035, 41.35469831739153, 45.62974425724575, 47.768615177699495, 50.70051179613386, 47.94980682645525, 49.97267757143293, 42.17844547544207, 37.01808786392212, 35.915905543736045, 35.618432317461284, 35.771612303597585, 41.42017466681344, 41.767021792275564, 47.61491755076817, 44.70536286490304, 50.562496253422324, 45.50976276397705, 54.606309618268696, 35.924500465393066, 30.048127514975413, 53.35091951915196, 45.88606677736555, 47.946697507585796, 38.04050486428397, 41.2596504347665, 35.15756177902222, 36.87410729272025, 35.0297600882394, 36.11371728352138, 34.646282059805735, 36.68835762568882, 36.23197214944022, 40.45970433098929, 38.97037533351353, 42.73622253962925, 42.05326325552804, 42.67036403928484, 41.409418855394634, 41.69760234015328, 44.791603905814036, 48.92882885251726, 48.7433432170323, 49.55124500819615, 49.918596267700195, 45.40831906454903, 45.69875723975045, 51.95909806660244, 50.18674462182181, 48.35532454081944, 47.19034787586757, 47.466142722538535, 41.3605625970023, 38.554011481148855, 37.41591739654541, 37.063181672777446, 39.116468157087056, 41.476771218436106, 42.51012468338013, 40.68815067836216, 39.266319956098286, 39.52745062964303, 42.866876465933665, 49.85437406812395, 51.993095602308, 49.41841629573277, 53.25746972220284, 51.72829975400652, 55.069410528455464, 46.54078163419451, 22.96623342377799, 6.387358673981257, 4.031548057283674, 11.692108103207179, 7.635003702981131, 1.0685521704810006, 0.09541242556380373, 0.06249513117862599, 3.5380511667047227, 30.63512522833688, 40.30771596091134, 15.25775078364781, 16.609152827944072, 20.026884862354823, 30.97005271911621, 42.50004284722464, 42.67687102726528, 40.221499238695415, 1.1045452505350113, 0.24817421021206038, 0.008042593303668712, 0.04032437263854912, 0.026415042579174042, 0.08843086340597697, 0.06780514267406293, 0.052803652826696634, 0.01932959331731711, 0.04525140879143562, 0.016936781982492124, 0.00309804394990871, 0.007952997843468828, 0.03485932267670121, 0.01694613728406174, 0.026184203269492303, 0.04315601462232215, 0.04230798834136554, 0.05837231847856726, 0.030009978783449957, 0.02157601241820625, 0.014039198269269295, 0.05336591747722455, 0.015705103520303965, 0.035469335836491415, 0.04508404473641089, 0.04065257663439427, 0.08067670091986656, 0.04144583156864558, 0.020156712238011614, 0.015281436432685171, 0.02128870033525995, 0.04435424300442849, 0.02655679193724479, 0.040274866723588536, 0.013314091151447167, 0.026241251101185168, 0.034345301865999184, 7.159930178097316, 55.161474159785676, 64.60435744694301, 55.21020187650408, 52.231606415339876, 31.52422366823469, 20.626477922712052, 30.093228272029332, 37.07561547415597, 31.030727863311768, 2.216795836176191, 0.12966512436313288, 0.054769857320934534, 0.7813523443681853, 5.081012223448072, 4.220182529517582, 1.533204157437597, 14.286364827837263, 47.65089879717146, 57.774246965135845, 58.15417446408953, 55.23675094332014, 57.16344472340175, 51.059361934661865, 47.9846624646868, 42.23215157645089, 42.97123146057129, 39.460358824048726, 42.68618508747646, 54.34951114654541, 54.121405260903494, 53.212883131844656, 53.97094202041626, 48.862174783434185, 41.75977482114519, 40.39359222139631, 39.809821946280344, 39.19492026737758, 39.70660645621163, 40.79336724962507, 41.32578338895525, 39.99696125302996, 38.43668072564261, 39.532929284232004, 38.20676136016846, 37.21008048738752, 38.107457705906455, 37.258505957467214, 41.17309325081961, 43.69888503210885, 44.65744808741978, 42.715822628566194, 47.9820499420166, 49.20039572034563, 51.24707446779524, 50.6053284236363, 51.11411721365792, 45.21431146349226, 38.01936844417027, 37.65913561412266, 37.330836704799104, 37.64600351878575, 44.09687089920044, 44.066837310791016, 48.196321964263916, 46.84009265899658, 52.094164099012104, 47.78741005488804, 56.83480535234724, 37.39140067781721, 31.16079466683524, 56.181851863861084, 47.65318822860718, 49.91770689828055, 40.026011671338765, 42.505354745047434, 37.79218666894095, 39.73638296127319, 35.95712225777762, 38.70402308872768, 35.97582333428519, 38.65518420083182, 38.04334320340838, 42.19684083121163, 41.16559961863926, 44.82755388532366, 44.072993414742605, 45.44004453931536, 42.76126037325178, 44.54833705084664, 47.22060380663191, 50.98189994267055, 51.60206140790667, 51.660662514822825, 49.434192180633545, 46.30663081577846, 46.82152707236153, 53.30079868861607, 50.681828090122764, 51.433206285749165, 49.84162412370954, 50.5710460117885, 43.80902092797415, 39.28576101575579, 39.58718081883022, 39.410408224378315, 40.08073915754046, 43.80409118107387, 45.18985033035278, 41.827589239392964, 41.38193525586809, 40.58231919152396, 44.45209060396467, 53.054832458496094, 54.09386954988752, 53.151322092328755, 54.50904873439244, 55.85350431714739, 57.533377238682334, 49.34878492355347, 24.702445813587733, 4.440203317574092, 1.7408616031919206, 6.138993578297751, 11.726805669920784, 4.290321554456439, 0.26868434250354767, 0.08188618959060737, 3.1313787485871996, 33.49939850398472, 40.37198679787772, 19.782134566988262, 19.737926653453282, 27.35385581425258, 36.27305684770857, 48.3407506942749, 47.25695678165981, 49.585433619362966, 3.3768349375043596, 0.4411245451441833, 0.03471523576549121, 0.03744018151025687, 0.039003027469984124, 0.03238966555467673, 0.02051433072691517, 0.05899190916014569, 0.07857951202562877, 0.039954832289367914, 0.054987840088350434, 0.015419406350702047, 0.063875712454319, 0.0137358184770814, 0.04443203365164144, 0.0989908699744514, 0.016037266767982925, 0.010562311043031514, 0.06572568389986243, 0.048644341727984805, 0.08624561423701899, 0.1754367897020919, 0.07617396967751638, 0.11563084886542388, 0.2081639857164451, 0.12254539211945874, 0.24922653660178185, 0.18411787173577718, 0.12034657225012779, 0.13442142414195196, 0.07467537080602986, 0.13536389571215424, 0.16092455413724693, 0.1410215206976448, 0.18225362391344138, 0.09208308492920228, 0.2572535244481904, 0.04672429797106555, 11.056639756475176, 67.02717345101493, 71.83279078347343, 63.754599707467214, 57.53432566779, 33.50858402252197, 22.190348931721278, 40.85078021458217, 43.58990601130894, 38.80510548182896, 2.8089832024914876, 0.23836313667041914, 0.11610487342945167, 0.7869828279529298, 7.531436460358756, 11.905090366091047, 7.152440454278674, 16.02037637574332, 48.455034664699006, 59.662444250924246, 60.72512953622, 58.49776635851179, 57.60538142068045, 53.61290829522269, 51.27310241971697, 44.37212378638131, 44.76424189976284, 42.53228596278599, 44.170038904462544, 56.66331338882446, 56.5695161819458, 55.39077513558524, 57.62511430467878, 50.48111547742571, 43.82719394138881, 42.2319917678833, 41.31418684550694, 41.256961481911794, 42.973739760262625, 42.22566543306623, 44.01385382243565, 40.75419330596924, 39.47881671360561, 41.40180015563965, 41.0768016406468, 38.488281522478374, 40.29914535794939, 38.82492174421038, 42.7862217766898, 45.96412631443569, 47.079548427036826, 45.37530469894409, 49.98479175567627, 52.052985600062776, 53.81043515886579, 51.856073651994976, 54.061292920793804, 47.988570826394216, 40.132256575993125, 39.24595478602818, 38.797924518585205, 39.48075873511178, 46.16581514903477, 47.217584814344136, 50.84603486742292, 49.468432903289795, 55.01874426433018, 50.37000683375767, 58.11050851004464, 38.70227909088135, 34.28032391411917, 58.20080729893276, 51.934741156441824, 51.58007730756487, 42.80580874851772, 45.040377208164756, 40.95286314828055, 42.1624298776899, 39.2051236970084, 40.03221641268049, 38.64561653137207, 40.80604771205357, 40.62264653614589, 45.991356304713655, 43.00703205381121, 47.60144846779959, 45.732695715767996, 48.45136601584298, 45.44697189331055, 46.50753102983747, 49.571721349443706, 53.00620549065726, 54.06724752698626, 52.142381123134065, 50.36702258246285, 47.85817745753697, 49.89065408706665, 55.162742206028526, 53.30472789491926, 53.313993317740305, 53.345489501953125, 51.501402854919434, 47.18093306677682, 41.604763984680176, 41.38974155698504, 41.6942845753261, 43.29877996444702, 46.19658177239554, 47.516385146549766, 44.23344816480364, 42.27336829049246, 42.86467041288103, 46.77617965425764, 55.24625260489327, 56.37403208868844, 55.44377946853638, 57.87352282660348, 56.64180176598685, 58.52241856711251, 50.832280908312114, 27.05247596332005, 10.020784071513585, 10.255906769207545, 24.477445772715978, 11.689600672040667, 3.535564797265189, 0.20013663146112645, 0.4491226002573967, 4.854595184326172, 47.78320639474051, 55.90928445543562, 22.60667978014265, 24.76706232343401, 30.44844102859497, 41.95769773210798, 54.967699323381694, 54.48807559694563, 58.60568577902657, 5.7467955606324335, 0.7342008916395051, 0.15584899006145342, 0.1410764820341553, 0.1330598893442324, 0.20382685773074627, 0.10862253207181181, 0.10378376993217639, 0.1775084656796285, 0.08126825453447444, 0.25209131145051544, 0.06865164225122758, 0.15712110751441546, 0.1799886468797922, 0.14264418291194098, 0.1651412964399372, 0.14175530203751155, 0.12636132378663334, 0.12443364651075431, 0.12732643128505775], [0.00509311311179772, 0.02422190035161163, 0.02559622044542006, 0.009221853239328733, 0.02896924177184701, 0.02465228663225259, 0.03371612687728234, 0.010433386844981993, 0.06838164638195719, 0.026632419754085795, 0.011121573176101913, 0.07608130893536977, 0.030939191779387847, 0.062086245976388454, 0.025421828463939682, 0.00819862327937569, 0.06766085898769753, 0.17480936194104807, 22.075745344161987, 57.231808049338206, 54.734222480228965, 49.67985963821411, 34.494012287684846, 17.838898863111222, 19.332276923315867, 35.042985984257285, 37.43080391202654, 20.51088421685355, 0.18597731553018093, 0.03218004233869059, 0.016074553963595202, 1.5500603786536624, 5.413408398628235, 2.7146850739206587, 3.5963074692658017, 32.82939413615635, 55.32153981072562, 57.403918402535574, 57.256658281598774, 53.39701386860439, 51.067380155835835, 52.89015667779105, 49.96437100001744, 45.05613224846976, 39.39760269437517, 39.904046467372346, 37.35740314211164, 44.381906849997385, 51.78138051714216, 52.87054886136736, 47.917841638837544, 42.823964391435894, 39.109863894326345, 37.440385477883474, 37.64028515134539, 38.078594888959614, 37.95811659949166, 40.339938231876914, 39.83080203192574, 38.51364244733538, 37.58006164005825, 37.54624128341675, 34.80479826245989, 34.55289132254464, 33.991720063345774, 35.0884028843471, 39.18425130844116, 38.68865367344448, 40.92481327056885, 40.668268408094136, 44.166505745479036, 47.31530427932739, 50.35454361779349, 49.44476733888899, 45.763969557625906, 37.37382868358067, 35.92497294289725, 34.821317604609895, 36.38771602085659, 37.49029786246163, 45.15599175861904, 45.51562704358782, 52.42664234978812, 46.52686786651611, 52.91336366108486, 46.80996526990618, 54.90246616091047, 32.7595716885158, 28.750488894326345, 54.26605633326939, 42.39597620282854, 47.79698119844709, 39.69832072939192, 41.98595952987671, 36.90094818387713, 37.52899932861328, 33.76845359802246, 36.493349484034944, 34.15656607491629, 36.39449051448277, 36.48074197769165, 39.221830640520366, 39.85339757374355, 42.26743800299508, 41.991504192352295, 44.819532190050396, 42.93519115447998, 45.71461302893502, 47.522767066955566, 51.24339887074062, 47.42533942631313, 47.0907107080732, 47.7611528124128, 48.59513814108712, 51.17553234100342, 49.86174610682896, 47.2721802847726, 48.83479193278721, 50.38801309040615, 48.319218226841514, 40.637269020080566, 38.626112937927246, 37.21876573562622, 38.441721643720356, 43.73115594046456, 48.9625415120806, 48.60377822603498, 48.687636034829275, 42.14301661082676, 40.75564547947475, 38.583433628082275, 42.78031928198678, 47.030351706913535, 50.52451045172555, 50.04124934332711, 51.33044242858887, 53.31417744500296, 55.75075088228498, 46.484963280814036, 14.831895692007881, 1.3038519386734282, 6.130683967045375, 11.129642742020742, 6.655305964606149, 0.043876713807029386, 0.011876780955520059, 0.43149464045252117, 13.390101058142525, 27.206357717514038, 24.242515019008092, 14.681602682386126, 21.588838168552943, 29.84703622545515, 41.59146513257708, 45.667410441807334, 47.58785431725638, 18.207285404205322, 0.269503904240472, 0.009281537179569048, 0.07569070346653461, 0.07062513421156577, 0.059276120338056765, 0.007047904647021953, 0.0069159461251859155, 0.034070868377706835, 0.04691575341192739, 0.04117697563820651, 0.04544617548318846, 0.03189788033653583, 0.010596448139819716, 0.019952837909970964, 0.010967025799410684, 0.11962341676865305, 0.034810936344521384, 0.02177101998989071, 0.02857951500586101, 0.062212785972016196, 0.013569580790187632, 0.01969266213875796, 0.028172344800883105, 0.01726279261388949, 0.03712299692311457, 0.029467238978083645, 0.08492488653532096, 0.03596101588170443, 0.01994813566229173, 0.04540157198373761, 0.036736245533185344, 0.05347274603056056, 0.030854856661920036, 0.040270483387368064, 0.04912332299032381, 0.07052579668483563, 0.1475439385644027, 28.53537961414882, 65.4011560167585, 59.76155335562569, 56.43615245819092, 42.79649468830654, 23.01972586768014, 19.404562507356914, 32.522019726889475, 40.62965032032558, 23.496226378849574, 0.10115570881004844, 0.042420849071017334, 0.07281806439693485, 1.5280961458172118, 4.026711676801954, 3.2937742173671722, 4.764137889657702, 33.65684468405587, 55.702909060886924, 57.150385584150044, 58.59670870644705, 56.13554559435163, 53.120538098471506, 54.364289964948384, 52.30179711750576, 45.93090697697231, 41.00482177734375, 42.335592882973806, 39.31675692967006, 47.27014446258545, 53.578347955431255, 54.50845813751221, 51.94062628064837, 44.21010569163731, 40.9777307510376, 39.944908823285786, 39.54080159323556, 40.311864035470144, 41.16678428649902, 42.882638454437256, 41.91420895712716, 39.117152554648264, 38.46255234309605, 39.14194025312151, 37.332452160971506, 36.63627740315029, 36.519669260297505, 36.9242593901498, 40.624807425907676, 41.37206881386893, 44.04146943773542, 42.551945890699116, 47.05623722076416, 50.07372522354126, 52.04830251421247, 50.29064103535244, 48.424292360033306, 39.47114937646048, 38.461673395974294, 36.228188855307444, 37.810258933476035, 39.2518572807312, 45.325889110565186, 48.34552410670689, 53.396520546504426, 50.240318707057405, 54.48000526428223, 49.37686259405953, 55.1527750151498, 33.637702396937776, 29.722170148577007, 54.9680050441197, 45.921922956194194, 50.02010597501482, 42.86314875738961, 43.871596404484336, 38.91311870302473, 40.06431361607143, 36.35017490386963, 38.65210267475673, 36.75589064189366, 37.7072935785566, 37.107170718056814, 40.35446344103132, 41.56883484976632, 44.550956521715435, 45.13767630713326, 46.29220288140433, 46.04445096424648, 47.44884518214634, 51.031808853149414, 53.16228634970528, 48.22441005706787, 47.827938897269114, 48.635618346078054, 50.57363074166434, 52.19726841790335, 50.08457830974034, 49.66342714854649, 51.4249518258231, 52.41516739981515, 50.58131544930594, 41.605886118752615, 40.101326669965474, 38.96478203364781, 40.13570983069283, 45.57339436667306, 51.31998538970947, 50.11516080583845, 49.46780756541661, 45.34385020392281, 41.880781173706055, 40.708373410361155, 44.220170157296316, 49.41706139700753, 52.98431519099644, 53.09835597446987, 55.008252484457834, 54.35058464322771, 57.87045519692557, 49.121412072862896, 16.28172939164298, 0.84851971162217, 3.0546152676854814, 15.578689813613892, 5.523431820528848, 0.17635211987154825, 0.03454090994117515, 0.3895112904054778, 16.143991776875087, 29.65320232936314, 26.281043529510498, 18.661461353302002, 27.267086710248673, 36.95168045588902, 46.239848205021445, 52.245850222451345, 53.343474524361746, 25.564626932144165, 0.15004512720874377, 0.08676890044340066, 0.013076707371510565, 0.02319487483639802, 0.04254139760243041, 0.02030318759248725, 0.026037785590493252, 0.033491569105535746, 0.07251564133912325, 0.028375749243423343, 0.06694687729967491, 0.06716852076351643, 0.013573840293767197, 0.015991913487336466, 0.05502076939280544, 0.01864240358450583, 0.05111026690740671, 0.04562621457236154, 0.0042784669369991335, 0.11988286141838346, 0.1032321752448167, 0.11168806507651295, 0.08384140860289335, 0.10412355312811476, 0.09645749162882566, 0.16492753076766217, 0.15899993026895182, 0.10181806755385228, 0.13185129633971623, 0.11842185338693005, 0.14683534444442817, 0.15869498306087085, 0.1020091837272048, 0.13897151712860378, 0.09739178685205323, 0.13955569506755897, 0.30145370268395966, 36.602898257119314, 72.57969433920724, 68.71683638436454, 63.60004397800991, 47.04209416253226, 26.149710416793823, 28.026801007134573, 45.732765197753906, 51.35390649523054, 27.687742812292917, 0.4131539746054581, 0.1268498690000602, 0.1578158595200096, 2.559363088437489, 16.242225408554077, 9.880062205450875, 7.563165409224374, 35.614565644945415, 56.792841706957134, 57.074521677834646, 60.16095665522984, 58.04266282490322, 56.00977972575596, 55.722273690359934, 54.71905108860561, 48.52770239966256, 43.202672481536865, 44.40200451442173, 42.08463784626552, 49.20625305175781, 55.63803720474243, 57.537289074489046, 52.50382988793509, 46.68629775728498, 42.94979279381888, 42.000807830265586, 42.24316447121756, 42.92509542192732, 42.12364503315517, 46.66779123033796, 44.29374115807669, 41.91701602935791, 41.093081269945415, 41.42327356338501, 38.21440437861851, 37.90365661893572, 38.00571870803833, 39.39791883741106, 43.037256717681885, 42.755475997924805, 46.75197907856533, 45.32301950454712, 50.23959609440395, 52.866692611149375, 55.3174855368478, 53.90098408290318, 49.69580922807966, 42.480709484645296, 40.8466842515128, 39.96191801343645, 39.45474815368652, 40.69865982873099, 47.97368778501238, 49.48615428379604, 56.17908648082188, 51.54408911296299, 57.935393060956685, 51.17034898485456, 55.466562611716135, 35.24268068586077, 32.57631989887783, 56.96463591711861, 46.88794142859322, 51.94649403435843, 44.995512689862935, 46.0806302343096, 40.80483872549874, 41.89135980606079, 38.303556714739116, 40.81086976187569, 38.938712392534526, 39.840126514434814, 39.14535876682827, 43.62041555132185, 45.92011642456055, 46.41698905399868, 45.65699509211949, 48.90844978604998, 48.83871766499111, 49.254171303340364, 53.00734846932547, 54.91117572784424, 49.88203832081386, 47.7981276512146, 50.30337708336966, 53.19343859808785, 54.75911440168108, 53.412376335689, 51.981467791966026, 53.14818498066494, 53.97920690264021, 53.437619141169954, 44.58573920386178, 42.189614704677034, 42.33756269727434, 43.03391463415963, 48.56568125316075, 53.5945268358503, 53.6529472896031, 51.21450826099941, 47.573332582201274, 45.648841381073, 43.18105663572039, 47.34145035062517, 51.28782217843192, 55.2078082220895, 55.6325272832598, 56.33881861822945, 57.611412457057405, 61.20329066685268, 52.68499721799578, 17.84797842161996, 4.746611927236829, 12.998528378350393, 22.862474237169536, 12.653430461883545, 0.21594982221722603, 0.09766323478626353, 0.8713933442320142, 20.063024180276052, 38.198569434029714, 35.69851378032139, 23.17955354281834, 30.35101686205183, 41.113773005349294, 51.89658859797886, 58.869856289454866, 59.54132325308663, 32.048069204602925, 0.39790965403829304, 0.21379411646298, 0.09329659052725349, 0.11881581081875733, 0.1286488146122013, 0.10094167172376599, 0.1110790256144745, 0.1127126325986215, 0.15843632551176207, 0.14981785868959768, 0.20608103248689855, 0.23752118327787944, 0.12096964381635189, 0.18614735640585423, 0.2578195855021477, 0.18634519007589134, 0.12393896734075886, 0.15737987362912723, 0.07775117004556314], [0.025425580762592808, 0.04495633087520089, 0.08323780420635428, 0.023871253810024688, 0.05748833662697247, 0.014645284407639077, 0.015072566390569721, 0.055241832709206004, 0.03163715325562017, 0.007165948960131833, 0.04374802964074271, 0.03479900769889355, 0.01775649978247072, 0.04331743810325861, 0.009274849368791496, 0.013858283869922161, 0.019453724513628652, 0.656418034008571, 36.09938314982823, 55.1254095349993, 50.05292231695992, 43.66739232199532, 27.613681963511876, 18.62665261541094, 31.55847828728812, 34.72983067376273, 37.84544113704136, 10.51441102368491, 0.12093920473541532, 0.09716179062213216, 0.1004834095282214, 0.7384923270770481, 3.1940684361117224, 1.497862036739077, 16.90247103146144, 49.38389417103359, 57.0102265221732, 57.64534051077706, 54.91009528296334, 55.96867765699114, 54.19382633481707, 51.76332562310355, 51.40751532145909, 51.24154370171683, 43.42109257834298, 40.239352634974885, 39.0366541998727, 36.869792461395264, 41.567580699920654, 44.34887163979666, 42.61538641793387, 38.27432564326695, 36.96435744421822, 38.46859032767159, 38.82073198046003, 40.30104916436331, 41.41947289875576, 40.90267630985805, 41.095818860190256, 42.17821618488857, 38.7335181917463, 35.56574065344674, 37.345872606549946, 35.27590002332415, 36.170821053641184, 35.92710256576538, 34.916570459093364, 37.95892259052822, 38.93825381142752, 38.070215361458914, 41.02383204868862, 40.12252909796578, 42.5949969291687, 43.879767486027305, 38.05142395836966, 34.4044326373509, 37.43180792672293, 36.192423003060476, 37.72552565165928, 41.95316750662667, 48.58254453114101, 47.575024468558176, 50.645273617335725, 47.65200356074742, 50.806280749184744, 43.000848157065256, 51.04244654519217, 33.30460575648716, 26.637439216886246, 56.84712103434971, 44.51139347893851, 48.37121507099697, 42.72030769075666, 45.24752385275704, 40.2716235433306, 43.46313612801688, 34.926072120666504, 35.774707726069856, 33.35381637300764, 36.05724579947335, 35.44945560182844, 36.1631189755031, 36.00680535180228, 43.31049462727138, 42.27691534587315, 45.00067867551531, 44.736619336264475, 48.313416481018066, 49.365592615945, 47.357222761426655, 46.61951862062727, 49.387507234300884, 49.032898971012656, 51.78518465587071, 44.8239859853472, 46.91847876140049, 47.56628710883004, 48.22294051306588, 48.33593906675066, 42.1618983404977, 37.26944242204939, 38.38609089170183, 37.15805237633841, 39.563602106911794, 49.56241076333182, 53.26531423841204, 52.0096218926566, 49.62476737158639, 46.956554889678955, 41.91129418781826, 38.023582526615684, 37.79043919699532, 39.693241596221924, 43.62534877232143, 47.2597325869969, 50.82703154427664, 51.529324190957205, 53.56857878821236, 55.76557486397879, 43.396874632154194, 8.049575788634163, 1.5032097612108504, 14.012520687920706, 11.796690651348658, 4.26486292055675, 0.04114723884101425, 0.04355460984100189, 5.928218236991337, 27.563218934195383, 35.413460459027974, 24.527474539620535, 14.55599227973393, 24.39731046131679, 40.50283874784197, 42.39027867998396, 45.17772919791085, 34.02635683332171, 1.3280480631760188, 0.016735085751861334, 0.07814900869769709, 0.003751272792994444, 0.035379962596510134, 0.014023080518070077, 0.016169021305228983, 0.02972575064216341, 0.02215086728600519, 0.056641440106821914, 0.026696549795035805, 0.05757050043238061, 0.054242231883108616, 0.01238422082470996, 0.028964956823204244, 0.04284687406782593, 0.03726680563496692, 0.038660696375050714, 0.03248628554865718, 0.06112971516059978, 0.054044299825493775, 0.044982664819274626, 0.09609784092754126, 0.06894187203475408, 0.006977431575900742, 0.04012571794113942, 0.043103339948824475, 0.04551921977794596, 0.031136285846254656, 0.03159776429778763, 0.06869420675294739, 0.0520787874369749, 0.038153013081422875, 0.03339943762070366, 0.002435435208358935, 0.0567489302318011, 1.4688808832849776, 43.564048290252686, 61.4347699029105, 56.930878094264436, 48.835181031908306, 31.691602298191615, 21.6812196799687, 30.155456338609966, 35.956476075308665, 41.44119644165039, 11.95608493259975, 0.11045570977564369, 0.04081845469772816, 0.14221602731517383, 4.484528047697885, 5.41824825320925, 2.4333455647741045, 19.065671069281443, 51.8383001599993, 58.44246564592634, 57.42835521697998, 56.04254048211234, 56.73789535249983, 55.0244973727635, 53.273672921316965, 53.727101939065115, 51.88446051733834, 45.15700966971261, 42.665048667362754, 39.31967864717756, 39.27343143735613, 44.34580748421805, 47.00757551193237, 43.62706845147269, 39.95534501756941, 39.82653931209019, 39.577092034476145, 40.916388579777305, 41.27069459642683, 42.509805066244944, 43.28309440612793, 42.809783118111746, 43.45421116692679, 40.782993589128765, 37.904723167419434, 39.42456865310669, 37.44693068095616, 38.00209869657244, 38.25398131779262, 37.517649446214946, 40.434121063777376, 40.18991272790091, 40.640534673418315, 41.21817316327776, 43.3811925479344, 45.58898959841047, 45.73847314289638, 40.055697849818635, 37.655373164585654, 38.160177162715364, 38.28390026092529, 39.886999062129426, 42.67143406186785, 49.32371582303728, 49.169757638658794, 52.92736428124564, 48.18066419873919, 53.33283683231899, 45.4303274835859, 51.38833481924874, 33.43606914792742, 28.5003467968532, 56.988725321633474, 45.64098296846662, 50.54052952357701, 45.46663529532296, 48.428982394082205, 41.85907500130789, 43.81901591164725, 37.49445635931832, 37.852382387433735, 35.940474373953684, 37.2097157069615, 37.41454512732369, 37.84699753352574, 39.15446785518101, 44.47385931015015, 44.289808477674214, 47.80593047823225, 46.69517755508423, 49.988397870744976, 51.474252768925254, 49.74948058809553, 48.23210171290806, 50.29424715042114, 50.31737075533186, 53.51589754649571, 48.028599398476736, 50.49653353009905, 51.10555703299386, 51.41370269230434, 50.39710133416312, 44.04190022604806, 38.22616420473371, 39.02271958759853, 38.59190695626395, 41.91565070833479, 51.87808207103184, 56.25353990282331, 53.908189364842, 52.07767602375576, 48.735571656908306, 44.07860061100551, 39.27401161193848, 40.83022396905081, 41.34347350256783, 45.71912240982056, 50.578077588762554, 52.160526343754356, 53.622475964682444, 57.30572298594883, 57.23145716530936, 45.72668899808611, 8.809033002172198, 0.7146501807229859, 5.986478882176535, 14.068162730761937, 6.07899284362793, 0.14326806872018746, 0.09081039750682456, 6.30626277412687, 32.22919831957136, 27.8672582081386, 21.821307522909983, 21.76853769166129, 32.49093001229422, 44.611454486846924, 48.60765184674944, 50.92592525482178, 41.14381006785801, 2.275440586464746, 0.03226308484694787, 0.03309007654232638, 0.040735218806990554, 0.024811072308304052, 0.017772226527865444, 0.02624116458797029, 0.08571316102253539, 0.004018742391573531, 0.03380288775744183, 0.04279926126556737, 0.031534395912396054, 0.025036820909008384, 0.04153147625869938, 0.04492403260831322, 0.05446653859689832, 0.052640879061073065, 0.01262229586219681, 0.042562276124954224, 0.13520480639168195, 0.1366283728608063, 0.15762038715183735, 0.15471688152423926, 0.23695468796151026, 0.07738887305770602, 0.10420068220368453, 0.1365020160696336, 0.11472712164478642, 0.048870456737599204, 0.18439400834696634, 0.15121416162167275, 0.09663772410047905, 0.19599120318889618, 0.09649240225553513, 0.16730445250868797, 0.08553414312856537, 2.2276204781872884, 50.858583314078196, 69.75609234401158, 63.15429619380406, 58.268590450286865, 38.04790122168404, 27.248884166990006, 41.6268801007952, 48.0795852797372, 50.119941166469026, 14.775531905038015, 0.29703928955963677, 0.2556627398090703, 0.19759059165205273, 7.248759857245854, 9.987946016447884, 4.182060369423457, 20.494064365114482, 53.64555788040161, 59.722726821899414, 58.30366843087332, 56.821509974343435, 58.00566019330706, 58.12124695096697, 55.481900760105674, 55.32765769958496, 54.421202659606934, 47.635581493377686, 45.17565516063145, 42.60516561780657, 40.88679272787911, 45.8156224659511, 46.86528335298811, 46.86493246895926, 41.38832759857178, 41.631893226078574, 41.28432348796299, 42.508321625845774, 44.5676599911281, 46.249957833971294, 45.35728801999773, 44.69853278568813, 45.86119570050921, 43.46505035672869, 38.71344484601702, 41.77246223177229, 39.39110265459333, 40.88184213638306, 41.155347551618306, 39.15767444883074, 42.6398023877825, 42.60353626523699, 42.17401252474104, 44.574952125549316, 45.21349157605852, 46.5471705027989, 47.29375096729824, 41.360173497881206, 39.57898889269148, 40.95324182510376, 40.17169107709612, 40.54848493848528, 45.37682982853481, 52.65413679395403, 51.84947633743286, 54.4585040637425, 50.22531407220023, 54.54669754845755, 45.75236259187971, 52.73961353302002, 36.64861045564924, 31.524380002702983, 59.50341388157436, 48.76673780168806, 52.782459599631174, 46.99847684587751, 49.67458595548357, 43.67169673102242, 47.544358594076975, 40.29554966517857, 39.47739233289446, 37.264818395887104, 40.22923258372715, 40.52412108012608, 39.74351181302752, 40.65137038912092, 46.212503569466726, 47.36131525039673, 50.31438650403704, 49.11184092930385, 51.48415742601667, 52.2028443472726, 50.16268995829991, 48.94521617889404, 53.38441331045968, 52.03818246296474, 55.52026523862566, 49.68228455952236, 52.62807410103934, 53.32648965290615, 53.20184939248221, 53.26945883887154, 46.07355349404471, 40.42392110824585, 41.808860370091026, 40.84416552952358, 43.45275551932198, 54.003310203552246, 57.9340729032244, 56.43011794771467, 53.345454760960166, 50.212706565856934, 46.984226090567454, 41.791830335344585, 43.27467666353498, 43.47382593154907, 48.37261165891375, 53.3205246244158, 54.84642546517508, 56.01212126868111, 59.457215309143066, 59.999001094273154, 48.84273024967739, 10.968300359589712, 5.889846376010349, 24.04633089474269, 23.717008863176616, 7.226001901285989, 0.23222223190324648, 0.31948245955365046, 8.568908470017568, 41.99840027945382, 44.75205823353359, 34.977499212537495, 22.67113127027239, 35.3939151763916, 52.02978209086827, 55.75025756018502, 57.27572413853237, 47.981032030923025, 3.424294173717499, 0.1454763745090791, 0.14549937684621128, 0.11484568885394505, 0.1500198992767504, 0.1967481497142996, 0.14426825647907598, 0.12141849473118782, 0.19454049531902584, 0.14009147988898413, 0.16797328447656973, 0.15554924043161528, 0.07907214880521808, 0.11157721959586654, 0.13601062100912842, 0.15373265290898935, 0.14836769364774227, 0.10742969465042863, 0.12947638306234563], [0.0738377668229597, 0.06896087780062642, 0.029380518810025284, 0.02970572028841291, 0.055550016529325924, 0.08095647447875567, 0.010098513698072305, 0.07473839313856193, 0.033252297301909754, 0.04093571233430079, 0.05288794044671314, 0.02194723383789616, 0.05137689045763441, 0.0992441467408623, 0.03552846677069153, 0.03767249832994171, 0.03815791549693261, 5.626062793391092, 50.63696704592024, 52.68722064154488, 49.23895474842617, 36.94035489218575, 18.24512529373169, 13.834419250488281, 29.501373767852783, 33.89951746804373, 37.443574701036724, 3.306139405284609, 0.20398209297231265, 0.08989720472267695, 0.30379706408296314, 0.618807272187301, 1.7005955981356757, 3.69497948884964, 35.46062135696411, 55.383416993277415, 58.99069241115025, 54.65168482916695, 57.637079102652415, 52.80863346372332, 55.86030660356794, 53.47297852379935, 52.50204072679792, 51.01079402651106, 48.81416620526995, 42.17002773284912, 38.96123150416783, 39.415800026484895, 39.96378013065883, 38.548480715070454, 37.860529150281636, 38.7096163885934, 39.36661720275879, 36.97886528287615, 42.040200642177034, 43.74310336794172, 44.61695051193237, 42.156996386391775, 43.41096905299595, 43.02649048396519, 41.023418630872456, 36.50261838095528, 38.03116301127842, 36.13851887839181, 36.545454025268555, 35.98490810394287, 36.816489355904714, 36.785875592912944, 35.875963824135916, 36.07671465192522, 37.474876335689, 35.298672744206016, 36.87256826673235, 35.76641852515084, 37.284540857587544, 35.01698929922921, 37.0988780430385, 35.860417229788645, 37.593367440359934, 38.35791942051479, 48.629017557416645, 50.25314508165632, 51.07229253223964, 47.407447814941406, 49.81539467402867, 44.160742214747835, 50.989216395786826, 27.575565883091517, 22.887050015585764, 56.266480922698975, 44.081063747406006, 50.7666551726205, 44.51370375497, 47.86218309402466, 45.499260561806814, 46.04794938223702, 39.68268380846296, 36.121061529432026, 33.98379564285278, 36.73201663153512, 35.83101940155029, 36.25459895815168, 35.704562187194824, 39.027704920087544, 43.6013879094805, 44.20886196408953, 46.785789012908936, 50.14099768229893, 47.599110398973735, 48.763010093144004, 48.849271978650776, 48.60022422245571, 48.694942065647666, 46.654329095567974, 47.85852139336722, 49.7288235936846, 47.598363467625205, 45.21810170582363, 40.70562539781843, 37.07730736051287, 35.92825596673148, 38.753504684993196, 37.21427025113787, 38.72954382215227, 49.66398647853306, 49.755178110940115, 52.583626474652974, 51.19269439152309, 50.16959646769932, 45.25686917986189, 40.48554468154907, 37.90598773956299, 38.153336661202566, 38.75010701588222, 42.61471939086914, 43.48537383760725, 47.55277633666992, 50.869446822575156, 51.72656617845808, 53.41528763089861, 33.436357498168945, 3.6691777876445224, 10.835534180913653, 4.218917088849204, 1.3448438133512224, 0.6106897134866033, 0.07992814108729362, 1.5838884434529712, 22.49348667689732, 40.83927747181484, 35.33859709330967, 17.627571140016826, 26.023353951317922, 37.95461818150112, 43.97421087537493, 45.06734664099557, 39.46905102048601, 11.374870726040431, 0.09419771895876952, 0.004557454667519778, 0.028664050291159322, 0.03764456982857414, 0.01741723736215915, 0.06759791129401752, 0.0341507590908025, 0.03427890042907425, 0.04572780144267848, 0.04985598814008491, 0.017861431830429604, 0.028865015400307517, 0.034987687931529114, 0.012768866211575056, 0.04220942434455667, 0.04172312168936644, 0.0358032429191683, 0.028117892365636568, 0.014615120133385062, 0.028104404785803387, 0.014161617860996296, 0.05389065235587103, 0.010698623639265341, 0.029444345206554447, 0.048336731269955635, 0.1467510432537113, 0.052010920364409685, 0.017273730598390102, 0.020964983152225614, 0.028376792491014515, 0.029745726713112423, 0.06868127387549196, 0.0389475131274334, 0.03266056387552193, 0.03155560352440391, 6.885954022407532, 60.69093745095389, 59.402331488473074, 55.679559639522004, 43.31076560701643, 26.00224879809788, 15.806111301694598, 29.466129030500138, 35.440405573163716, 45.00186334337507, 4.066020676067897, 0.16418836185974733, 0.20820940685059341, 1.5872546285390854, 4.701936747346606, 3.2019976334912434, 5.766849364553179, 39.48245062146868, 58.30762195587158, 60.14783845629011, 56.27912317003523, 58.82403291974749, 53.59035791669573, 56.64367083140782, 54.27530091149466, 53.769058636256624, 51.24188068934849, 52.07238497052874, 43.5443570954459, 40.853173868996755, 40.29825946262905, 40.39996371950422, 40.129178524017334, 39.82918310165405, 39.63149642944336, 40.72083500453404, 40.579411370413645, 43.792001315525596, 45.374762739454, 44.92014557974679, 45.179646900721956, 46.10895456586565, 45.133854797908235, 43.58096367972237, 38.26605033874512, 39.11817741394043, 38.701084000723704, 37.6762455531529, 39.160457202366416, 38.161594595227925, 37.27282966886248, 38.127815927777974, 38.443809577396934, 39.46608066558838, 38.00902952466692, 39.125427859170095, 37.58618300301688, 38.902567863464355, 36.626070499420166, 37.92590822492327, 38.52404042652675, 38.615152154650005, 40.65420178004673, 50.43356895446777, 50.40782240458897, 52.25014073508126, 49.26696988514492, 51.64355604989188, 46.88666296005249, 51.41676337378365, 28.59631531579154, 24.03484378542219, 57.310593673161094, 46.978573731013704, 51.76609100614275, 47.96199744088309, 50.115153857639854, 47.113024847848074, 46.56578125272478, 40.424438749040874, 38.126975195748464, 35.4165871483939, 38.594272817884175, 37.53687163761684, 38.096430914742605, 37.062743936266216, 42.21512154170445, 45.77779647282192, 47.8815928867885, 48.64090939930507, 51.087401390075684, 50.33461618423462, 50.50632701601301, 51.83333567210606, 51.11733422960554, 50.50558703286307, 48.96174941744123, 50.76916694641113, 51.2110550062997, 49.40400225775582, 47.38385173252651, 42.259548323495046, 38.66206291743687, 38.558378423963276, 39.75761318206787, 39.532623563494, 40.65762724195208, 51.89853409358433, 51.14705514907837, 54.248129980904714, 52.76805598395211, 53.08259398596627, 47.888360432216096, 43.08716215406145, 40.18061603818621, 40.1851601600647, 40.811825139181956, 43.61681638445173, 45.09901653017317, 48.91554389681135, 53.8363310950143, 53.39206327710833, 54.947153500148225, 37.255830901009695, 3.281832652432578, 3.286040872335434, 9.58814753804888, 6.725611312048776, 1.2573177899633134, 0.08214498284671988, 1.5144686656338828, 25.425612585885183, 37.955180985586985, 30.11504214150565, 17.589653083256312, 30.65257215499878, 42.76245893750872, 50.10492263521467, 50.58444561277117, 47.78216069085257, 16.884047882897512, 0.1048631766544921, 0.02882654246475015, 0.026942574718434895, 0.0401715665523495, 0.03765929743115391, 0.09202548409146921, 0.013721511566213198, 0.026946863059752753, 0.04613185886825834, 0.02379437070339918, 0.10578614034290824, 0.04825887276924082, 0.006123954114238066, 0.0242790974610086, 0.04877941090879696, 0.031458142147000344, 0.008092530936534916, 0.020390543887125592, 0.11407453380525112, 0.13289565672831877, 0.09378962085715362, 0.13014307085956844, 0.09690866991877556, 0.15156242650534424, 0.14633784256875515, 0.25451237867985455, 0.13030849769711494, 0.17443197433437618, 0.21218668057450227, 0.1653883917523282, 0.09264778212777205, 0.1339955348521471, 0.11897956846015793, 0.1060685534030199, 0.17908217837767942, 9.351919208254133, 69.35027585710797, 65.7381922858102, 64.32441452571324, 50.94285454068865, 28.841129881995066, 22.072220870426722, 39.58338015420096, 46.74906430925642, 50.23132773808071, 4.728610447474888, 0.44426849644098965, 0.3283763165984835, 1.293973337326731, 5.33137058360236, 8.300298929214478, 7.690152423722403, 42.24506480353219, 58.93498870304653, 61.281471797398154, 56.391968863351, 60.53026730673653, 55.73984221049717, 58.16482605252947, 55.99635233197893, 56.51466710226876, 53.547418049403596, 53.91729497909546, 44.99566207613264, 42.93422882897513, 43.148639815194265, 41.96474320547921, 42.252162388392854, 42.02646057946341, 42.34300313677107, 41.931006227220806, 41.09472451891218, 47.13627699443272, 47.40572118759155, 48.63040372303554, 45.908332279750276, 47.80144541604178, 48.968600341251914, 45.460399287087576, 40.71726015635899, 41.76398195539202, 39.94780274799892, 38.96895442690168, 39.36121497835432, 41.10253429412842, 42.03617068699428, 40.158308846609934, 41.281940255846294, 42.13040215628487, 39.26432234900338, 41.083871432713096, 40.00324937275478, 41.06681360517229, 37.865493638174875, 41.387896810259136, 39.81323003768921, 40.570430823734824, 41.351012298039024, 52.272037982940674, 53.279144627707346, 54.95802048274449, 50.921704224177766, 55.12291513170515, 49.17191852842058, 52.02922970908028, 30.977251052856445, 26.908610037394933, 57.27912528174264, 49.80788714545113, 53.18331159864153, 48.70960276467459, 51.93217727116176, 49.61877802440098, 48.928530079977854, 43.96704033442906, 39.61892366409302, 37.863402230399, 40.47117233276367, 38.90342596599034, 40.272769996098106, 38.83327347891671, 43.862351826259065, 49.04506526674543, 50.44996322904314, 50.84188331876482, 53.17593955993652, 51.34023591450283, 50.99995136260986, 52.8388546534947, 53.77390847887312, 52.958832672664094, 50.52955136980329, 53.70076479230608, 54.37452118737357, 52.082004751477925, 50.14448915209089, 45.057598318372456, 41.61792734691075, 39.944109780447825, 42.32018525259835, 42.05609812055315, 42.289515904017854, 54.489020551954, 54.56086145128523, 55.83049883161272, 54.80089739390782, 56.27558306285313, 50.95455878121512, 45.42551238196236, 41.945892742701936, 43.002064091818674, 42.975890227726524, 47.059773853846956, 47.79684918267386, 51.415755884987966, 56.38047654288155, 56.38902630124773, 58.05457551138741, 39.05062355313982, 5.402792853968484, 18.357059035982402, 10.821175728525434, 5.367423917566027, 1.2351062446832657, 0.19935824322913373, 2.2326220955167497, 31.616617338997976, 55.10209138052804, 46.62285723005022, 24.913596357618058, 36.003063746861045, 48.20859595707485, 57.451416288103374, 57.78111525944301, 55.94374404634748, 20.48666627066476, 0.16907773592642375, 0.1138846254242318, 0.14700101555458137, 0.15456579891698702, 0.07910003659448453, 0.1901979119117771, 0.10954791134489433, 0.11017238069325686, 0.1663586696875947, 0.1425084759082113, 0.18637725764087268, 0.14940655790269375, 0.10908173743103232, 0.09220097360334226, 0.11025305172162396, 0.13672815822064877, 0.11848976117159639, 0.1546195796025651], [0.05061173026583024, 0.01267739205754229, 0.0656674588099122, 0.06943707367671387, 0.038155557587742805, 0.010513378490161682, 0.018579859619161913, 0.008022044718797718, 0.054870765656232834, 0.05956381240061351, 0.03682948981544801, 0.014973700445677553, 0.05290541272344334, 0.02802746230736375, 0.07636333523052079, 0.0811894562627588, 0.07845780998468399, 12.761280400412423, 55.994903632572715, 49.42482600893293, 41.08269023895264, 29.6998872756958, 16.57405400276184, 20.819813285555156, 40.0499655859811, 36.844813687460764, 26.277784824371338, 0.3001273295709065, 0.053730446845293045, 0.14478639939001628, 0.2623901159635612, 3.4437120003359656, 3.33273189834186, 7.044261344841548, 41.83397463389805, 57.12481273923601, 56.10456010273525, 56.34803887775966, 55.7490416254316, 54.623930249895366, 49.58625003269741, 50.525813238961355, 52.33832032339913, 53.20878022057669, 50.74629347664969, 45.19886909212385, 40.295254366738455, 38.82023865836007, 38.501007148197715, 36.80922154017857, 38.99746635981968, 37.38394178662981, 38.3479973929269, 41.256575856889995, 44.49132708140782, 47.37836960383824, 48.604407038007466, 47.880599294389995, 48.02707426888602, 45.79530940737043, 42.483308110918315, 37.241003445216585, 37.16538272585188, 34.75607401984078, 36.699773515973774, 33.85627882821219, 37.060916560036794, 35.27333613804409, 35.31252745219639, 34.61573083060128, 36.936543805258616, 34.811604022979736, 37.68921436582293, 35.73923717226301, 36.622853483472554, 34.017136573791504, 37.96033654894148, 37.15499864305769, 38.81258174351284, 37.2113276890346, 41.98891598837716, 45.39943579265049, 49.35454498018537, 46.46920476640974, 51.7832739012582, 45.46143456867763, 54.165338720594136, 33.113578932625906, 21.24800992012024, 51.47565630504063, 42.973423617226736, 48.35118688855852, 46.18019444601876, 50.395659582955496, 47.838392462049214, 48.76200260434832, 44.17569126401629, 37.69405378614153, 36.25374780382429, 36.03772830963135, 36.523125989096506, 36.97233050210135, 36.0675117628915, 37.504913398197715, 41.01439292090279, 44.68038409096854, 46.147367681775776, 50.324006284986226, 50.23218584060669, 51.54730265481131, 47.71544061388288, 47.69770186288016, 43.56356539045061, 44.29176786967686, 44.904699734279085, 43.76337821143014, 40.746591976710725, 37.85826751164028, 35.0844841003418, 36.74300173350743, 36.94931806836809, 37.858514172690256, 36.1046325138637, 38.96740845271519, 45.87883022853306, 49.2014205796378, 50.719303199223106, 49.899394920894075, 50.41853652681623, 48.29827635628836, 48.59340456553868, 42.48108468736921, 44.02476944242205, 46.246014731270925, 47.24019772665841, 43.778445380074636, 44.83617312567574, 45.53899730954851, 54.13241468157087, 51.49433306285313, 57.06413412094116, 17.832226855414255, 1.7629847760711397, 9.226478167942592, 2.885330008608954, 6.43217716046742, 0.34294698759913445, 0.10496421730411903, 12.334839923041207, 33.737773827144075, 26.11883088520595, 25.98426686014448, 20.250755820955547, 32.97639717374529, 40.46798658370972, 44.015795843941824, 45.86713988440377, 28.75077029636928, 0.816009090415069, 0.03230386819424374, 0.037033457442053726, 0.021770287172070572, 0.020836533080520372, 0.008358425061617578, 0.02899259694718889, 0.04529709116156612, 0.030404584216220037, 0.028378549896712815, 0.03025319966088448, 0.07987358687179429, 0.0268596882732319, 0.0379808551764914, 0.07035006290035588, 0.018819971109873483, 0.029539401177316904, 0.04324430559894868, 0.09728729245918137, 0.051337986652340205, 0.0319974960626236, 0.052953758343522034, 0.06406695754932505, 0.03400088766855853, 0.048269624156611304, 0.02724242952120091, 0.031213462419275726, 0.04248656518757343, 0.06135875465614455, 0.04841987555846572, 0.06833820657006331, 0.04708881716110876, 0.08072646467813424, 0.1430296315146344, 0.11634074577263423, 17.027554239545548, 65.82033388955253, 56.425386224474224, 47.30487503324236, 36.50730494090489, 22.1538622038705, 23.031944274902344, 34.88930572782244, 38.72897754396711, 31.429568358830043, 0.20443904559527123, 0.06234372965991497, 0.07876413461885282, 3.231920919248036, 8.47681096621922, 5.432679661682673, 9.242672681808472, 41.890925543648855, 58.668726784842356, 57.12326676504952, 57.11399439402989, 57.819695132119314, 56.46218735831124, 52.924352237156455, 52.29618992124285, 53.76171439034598, 54.113904680524556, 52.56735726765224, 47.24822637013027, 42.17610393251692, 40.72049106870379, 40.09650462014334, 39.699512345450266, 40.61915159225464, 38.79666689464024, 39.59890937805176, 42.45891298566546, 47.18522705350603, 48.47347170966012, 51.15115458624703, 49.771412576947895, 50.05334963117327, 47.51207726342337, 44.54408127920968, 38.042012623378206, 40.59463139942714, 37.81815208707537, 38.55579716818673, 37.35386650902884, 38.50585699081421, 37.151222297123496, 38.16842467444283, 35.79346786226545, 36.80202668053763, 36.61773613521031, 38.758264201028005, 38.564471994127544, 39.51087917600359, 35.73867436817714, 39.93242638451712, 37.43790149688721, 39.87214033944266, 37.99072102137974, 44.09468569074358, 47.738508633204866, 50.53734030042376, 49.854711055755615, 52.76580476760864, 47.21093191419329, 55.1097343989781, 34.07289934158325, 22.882043838500977, 51.92240115574428, 44.89621945789882, 49.49019813537598, 48.1434531211853, 52.213839871542795, 50.376100403921946, 50.408812522888184, 46.074828488486155, 40.4218088558742, 37.12156738553728, 37.659687995910645, 37.884701933179585, 38.39877830232893, 37.35570430755615, 39.2056621823992, 42.550452028002056, 46.44515010288784, 48.63725812094552, 52.566989013126914, 52.51152154377529, 53.73429332460676, 49.466143471854075, 49.398923124585835, 45.34180743353707, 46.24302005767822, 45.900793484279085, 46.49419396264212, 41.871734619140625, 40.45114762442452, 37.15185110909598, 38.0937419618879, 38.31401375361851, 38.71894087110247, 37.640462330409456, 41.03017922810146, 48.774696963174, 51.87598718915667, 51.8597457749503, 51.430531229291645, 53.131891454969136, 50.95326294217791, 49.87311683382307, 44.75469854899815, 44.97762107849121, 47.35461023875645, 48.49054690769741, 45.80407108579363, 46.21071788242885, 47.259093352726524, 56.565548760550364, 53.51602956226894, 58.34937368120466, 19.062902212142944, 1.463412759559495, 3.1310393725122725, 4.91644674539566, 3.2486137492316107, 0.24879968379225048, 0.05720956729991095, 13.811920114925929, 39.39026539666312, 28.883183853966848, 29.590439251491002, 26.580908673150198, 39.98392990657261, 44.296968596322195, 49.92422430855887, 51.621749128614155, 36.26015056882586, 1.3485515458243233, 0.0733538560037102, 0.08451712770121438, 0.025384787237271667, 0.022496889611440044, 0.021031730642010058, 0.03475429563383971, 0.030923076572694948, 0.07814492391688482, 0.06803520675748587, 0.045234560766922574, 0.05945452076515981, 0.03386210350851927, 0.016372101747297814, 0.035359782965055535, 0.02870716101356915, 0.05908851897610085, 0.04340027365833521, 0.12327370446707521, 0.1777006403676101, 0.1722015890159777, 0.18150538977767738, 0.13131335377693176, 0.08412857819348574, 0.08652188655521188, 0.06956051276730639, 0.2094531072569745, 0.13991924055985042, 0.09196579336587872, 0.12482319346496037, 0.15213106599237236, 0.15104372719568865, 0.13783003123743193, 0.2844523292567049, 0.28948616342885153, 21.741104466574534, 72.25246892656598, 63.864506312779014, 55.999142033713206, 43.386994293757844, 25.110579524721416, 30.024635655539377, 52.511705671037944, 50.07865844454084, 34.91584437234061, 0.5456344357558659, 0.22409825426127228, 0.20083318836987019, 4.176120962415423, 15.329419715063912, 9.515878455979482, 11.437099661145892, 44.16877433231899, 60.690110615321565, 60.50968674251011, 60.02980940682547, 60.04870155879429, 58.06466429574149, 54.11029509135655, 55.19045162200928, 55.78865677969796, 55.69625963483538, 55.32125146048409, 48.693114689418245, 43.78535188947405, 42.401510443006245, 42.14252328872681, 41.208202498299734, 44.17083099910191, 40.85414661679949, 41.19253431047712, 45.303661823272705, 49.13264383588518, 51.25679152352469, 53.560185364314485, 52.98568051201956, 51.47984259469168, 50.13737072263445, 46.74417972564697, 40.3006774357387, 41.250659465789795, 38.315115043095176, 41.07623188836234, 38.28477920804705, 41.29904672077724, 39.66542100906372, 40.214356490543906, 37.90443481717791, 40.13034234728132, 38.477383272988455, 40.28879254204886, 40.044740540640696, 42.01663930075509, 38.45722654887608, 40.48561416353498, 40.62985529218401, 41.061154297419954, 39.110815797533306, 45.48181363514492, 50.62095839636666, 53.64262921469552, 52.41792236055647, 54.97358097348894, 50.65809651783535, 56.556391034807476, 35.45134898594448, 25.589022057397024, 53.40527180262974, 45.38081809452602, 50.43265526635306, 49.98739733014788, 53.32672241755894, 51.68369926725115, 52.406155586242676, 47.60606901986258, 41.92037548337664, 40.11362150737217, 39.750282832554404, 40.40595306668963, 40.187995025089805, 39.896465982709614, 40.87486614499773, 44.91925968442644, 48.17613397325788, 51.16450554983956, 53.966331890651155, 52.740037373134065, 55.71627392087664, 52.5840676852635, 52.24051400593349, 48.25187976019723, 48.17880555561611, 49.56274775096348, 48.48838601793562, 43.80354574748448, 42.24829918997628, 38.17367056437901, 40.222982679094585, 41.57383407865252, 40.938695771353586, 40.43019185747419, 42.90885053362165, 50.23780345916748, 54.11588144302368, 54.02326542990548, 54.15832451411656, 54.287310872759136, 52.17834152494158, 54.29492262431553, 47.9473888533456, 48.28599541527884, 49.35463878086635, 52.88416733060564, 48.17939267839704, 48.74199526650565, 49.34793724332537, 60.12619481767927, 56.932094029017854, 62.921538489205496, 21.60146825654166, 5.445167745862689, 19.933963128498622, 7.208027780056, 10.244344098227364, 0.5748037333999361, 0.4823785243289811, 16.70394536427089, 46.392771107809885, 38.24249594552176, 37.03271034785679, 27.53947172846113, 44.79278857367379, 50.57695892878941, 56.713753836495535, 56.88891792297363, 45.14818893160139, 2.117046845810754, 0.17269883304834366, 0.1369646955281496, 0.10021449931498085, 0.14061161769287928, 0.06796771287918091, 0.12128502689301968, 0.1081001754584057, 0.12813915338899406, 0.1357487336333309, 0.1814591951136078, 0.16873966263873236, 0.1937898320278951, 0.08987121683146272, 0.18034201434680394, 0.12365096993744373, 0.0843387476301619, 0.1285382541162627], [0.013057090075952666, 0.030046585747706037, 0.061672923155128956, 0.04834682447835803, 0.05049761424639395, 0.05683117885408657, 0.03374626061746052, 0.017693984654865096, 0.03073810792661139, 0.08984813985547849, 0.00980469276795962, 0.04587121321154492, 0.0217337497576539, 0.06340464630297252, 0.05642356590500899, 0.034465338103473186, 0.6632116894636835, 25.554968936102732, 50.83021034513201, 49.69376993179321, 46.067487716674805, 33.657063552311485, 15.27036350114005, 24.812168291636876, 34.439566203526084, 37.280931268419536, 17.510989052908762, 0.16856868538473332, 0.01884862394737346, 0.036336920889360566, 3.5968737474509647, 5.910104283264705, 1.4189010794673647, 10.282725947243826, 49.38210848399571, 56.6182404245649, 56.19839899880545, 52.9580579485212, 53.75700351170131, 53.41753537314278, 55.5156238419669, 47.3112986428397, 50.52834933144705, 52.63646057673863, 52.317659854888916, 47.69098990304129, 41.10883978434971, 37.73030253819057, 38.386591162000386, 36.074897697993684, 39.463683537074495, 37.39432239532471, 42.638913018362864, 43.98719358444214, 47.64066410064697, 49.674530369894846, 49.900586536952424, 47.77985041482108, 48.40768616540091, 47.47474111829485, 42.87853206907, 35.48824044636318, 37.32272468294416, 36.0619740486145, 36.104045391082764, 35.1757938521249, 36.6875307900565, 36.834318433489116, 35.73995631081717, 35.64371681213379, 36.72697918755667, 34.75605664934431, 35.37657247270857, 34.677889415196006, 37.33347354616438, 35.417566844395225, 35.01809058870588, 35.09681020464216, 39.24062204360962, 36.846425669533865, 38.134718963078086, 35.50237308229719, 40.35657221930367, 41.48847198486328, 46.83747318812779, 43.82154505593436, 54.249898297446116, 34.47196912765503, 19.828855991363525, 50.24087803704398, 39.55555609294346, 47.75322491782052, 44.12590742111206, 48.37594679423741, 45.62213945388794, 50.53262594767979, 46.87714740208217, 41.28348275593349, 34.43504292624337, 37.42062132699149, 34.59717219216483, 35.91911561148507, 35.86166443143572, 36.64146075929914, 36.7460172516959, 41.56736877986363, 46.09929656982422, 49.3705084664481, 49.872220516204834, 49.04428359440395, 44.37936380931309, 41.21816621507917, 38.362734522138325, 39.070057664598735, 37.61803354535784, 39.72632196971348, 35.42151689529419, 36.75065170015608, 36.287349292210166, 37.02471991947719, 34.923268522535054, 36.6105933870588, 37.471652371542795, 40.16064691543579, 45.829859324863975, 48.19887890134539, 49.6651086126055, 49.98756756101336, 50.23018128531319, 50.513660839625764, 49.590130601610454, 48.49543496540615, 48.317891120910645, 50.39164005007063, 51.939629214150564, 52.51245955058506, 50.38525118146624, 46.34198325020926, 47.14655338014875, 53.645116669791086, 52.13747222082955, 38.861219133649556, 4.846096234662192, 7.5848351035799295, 5.076023851122175, 7.305641719273158, 2.423101314476558, 0.17894259015364306, 2.0492958298751285, 27.189350264413015, 38.41368218830654, 18.586283581597463, 16.56958631106785, 25.05951373917716, 40.10343197413853, 42.59006718226841, 46.84663438796997, 40.4933614049639, 6.473674408027104, 0.019998552510514855, 0.02408977770911796, 0.037930969281920364, 0.003548592686586614, 0.020405390233333622, 0.08201932494661637, 0.01222507213242352, 0.019207024447886006, 0.015535076215331043, 0.06253120210021734, 0.034653383905866315, 0.024751308640199046, 0.04994958186788218, 0.036902181271995814, 0.0179503691116614, 0.023290829866060188, 0.07684618074979101, 0.029120331164449453, 0.0343489625624248, 0.041859171353280544, 0.0200059112227921, 0.034090060740709305, 0.006467031597691987, 0.016377864205943685, 0.00569530700366678, 0.005008006584830582, 0.052967183158866, 0.01369315558778388, 0.03507113756079759, 0.037393332059894285, 0.04781575547531247, 0.02465279892619167, 0.029883252190692083, 1.0111052244901657, 33.870098795209614, 59.473807607378276, 57.169680731637136, 51.81138631275722, 41.34841019766671, 19.655020747865947, 27.32282863344465, 34.5858188356672, 41.18990094321114, 19.37372292791094, 0.14452345349958964, 0.0487488157648061, 0.12731477405343736, 4.50720088822501, 6.705593551908221, 4.221780615193503, 11.623198475156512, 51.83452033996582, 58.14563512802124, 57.19729287283761, 54.80589314869472, 56.57163190841675, 55.218369483947754, 55.20683547428676, 51.24855443409511, 52.92100320543562, 55.01753527777535, 54.76447146279471, 49.54701008115496, 41.8556147984096, 39.08065366744995, 40.20017869131905, 37.157121317727224, 41.042241300855366, 39.427643230983186, 43.52724020821707, 45.63314192635672, 50.48223066329956, 51.85458326339722, 50.84957497460501, 49.554528032030376, 50.24468912397112, 49.49006264550345, 44.08970383235386, 38.262437275477815, 37.92910787037441, 37.964759077344624, 37.087681021009175, 36.997990199497764, 38.540907178606304, 38.48352895464216, 37.938390663691926, 37.616744654519216, 37.830530302865164, 37.05839783804757, 36.92325190135411, 36.32687759399414, 38.63228988647461, 36.817451681409565, 37.378643785204204, 37.19699008124215, 41.3497234072004, 38.06816216877529, 38.89468513216291, 37.187769821711946, 42.71058021272932, 43.50812223979405, 49.88773931775774, 45.54445511954171, 55.62990433829171, 36.01927736827305, 20.34496991974967, 50.34031023297991, 41.093664918627056, 48.97457231794085, 44.52438313620431, 50.47019638334002, 45.77524300983974, 51.47344330378941, 49.11389412198748, 41.890984603336875, 36.48396941593715, 38.94641099657331, 36.18605497905186, 38.57970591953823, 36.86893088476998, 39.22507544926235, 37.98888669695173, 44.55980852672032, 48.617619037628174, 49.81051703861782, 51.116514342171804, 50.178733348846436, 46.06579235621861, 44.16270855494908, 40.694841793605256, 40.29248898369925, 39.853880473545615, 41.611854621342246, 37.71904298237392, 38.24299274172102, 38.20377710887364, 39.05692556926182, 37.7567195892334, 39.75675160544259, 40.17553343091692, 41.130149909428184, 47.436345372881206, 50.06778103964669, 52.51707662854876, 51.069162368774414, 52.26401628766741, 51.26944419315883, 52.174752780369346, 51.02684089115688, 50.39662190846035, 52.66664007731846, 53.12812205723354, 54.62717853273664, 51.125922203063965, 48.36171688352312, 49.71295738220215, 56.50295243944441, 54.85801158632551, 42.48618813923427, 4.342991505350385, 2.302602831806455, 7.68907458441598, 9.817061151776995, 2.908495302711214, 0.08515769190021924, 2.35085437979017, 32.76568957737514, 32.92063440595354, 15.924043076378958, 19.043924944741384, 30.339010374886648, 44.18593985693795, 47.50673757280622, 52.17373834337507, 50.011017731257844, 10.326241646494184, 0.00949085081395294, 0.016984576292868172, 0.11155697211091008, 0.04527806843231831, 0.027493339896734272, 0.05512332656819906, 0.023944555948089277, 0.03493027708360127, 0.03754609064864261, 0.012680613402543324, 0.029732142442039082, 0.04284765777577247, 0.04461164865642786, 0.014990724889295442, 0.015812296786212494, 0.06610670166888408, 0.014532749374796237, 0.06962552999279328, 0.10025443110082831, 0.12640084166611942, 0.10092352091201715, 0.10504931916615792, 0.10296597917165075, 0.13430455327033997, 0.14313310810497828, 0.16993389784225396, 0.21164151839911938, 0.10270822407411677, 0.1759346986987761, 0.10440973884293012, 0.11596603159393583, 0.13282522479338305, 0.14652878232300282, 1.6498088261910846, 40.905709198543, 68.28763226100376, 64.63832718985421, 61.19925376347133, 46.38865082604544, 22.354613031659806, 34.574395997183665, 46.512248856680735, 49.04059410095215, 23.02590455327715, 0.3694615034120423, 0.12822741722421988, 0.17147057609898703, 6.290196367672511, 11.478917394365583, 5.048544594219752, 15.222002301897321, 54.88613442012242, 61.024242537362234, 60.19743469783238, 56.92397158486502, 59.265146255493164, 57.40606886999947, 58.63396494729178, 52.33079889842442, 53.54869304384504, 56.12170825685774, 57.08597925731114, 51.75011362348284, 44.233958857400076, 41.78304781232561, 42.53991161073957, 39.62384646279471, 43.17608172552926, 41.834071908678325, 46.81738247190203, 47.87072590419224, 50.989390100751606, 54.76262671606881, 51.70115314211164, 51.17060259410313, 51.59356376102993, 50.75407198497227, 45.71147244317191, 39.72004427228655, 39.54191677910941, 39.21745327540806, 39.322586468287874, 39.40642690658569, 39.741906779153005, 40.8477577481951, 39.64866195406233, 40.01811851773943, 39.9776348386492, 38.29592064448765, 38.557999747140066, 38.148542404174805, 40.62292446408953, 37.37981455666678, 38.99810906818935, 38.90357535226004, 43.40298209871565, 40.723902634211946, 40.455472878047395, 39.44886302947998, 43.256104128701345, 44.43606110981533, 52.66952357973371, 47.75410386494228, 57.648408140454976, 38.95076404299055, 23.486286980765207, 50.52958263669695, 41.758576256888254, 50.63370139258248, 45.65585906164986, 51.15339190619332, 47.08215052740914, 53.09683779307774, 50.82467263085501, 43.85776254108974, 38.28603335789272, 41.94723721912929, 38.89734976632254, 39.71798413140433, 40.040450028010774, 40.70686565126692, 39.942317145211355, 46.78114414215088, 52.80182422910418, 52.87925148010254, 53.23484986168997, 53.926379748753135, 48.081746169498985, 46.718276841299875, 43.021623270852224, 42.785120487213135, 41.38419689450945, 44.99528687340872, 38.68811518805367, 40.47623756953648, 39.775984219142366, 41.321791648864746, 39.158782686506, 41.63429035459246, 41.87369053704398, 44.79791981833321, 50.22696426936558, 52.931849343436106, 54.483281339917866, 53.88580921718052, 55.633031027657644, 53.11117192677089, 54.84090164729527, 53.308511189052034, 52.414069584437776, 54.75332307815552, 56.198138441358296, 57.87175451006208, 53.87892702647618, 52.06653111321585, 52.36516121455601, 58.12649284090315, 56.97176824297224, 45.95869977133614, 6.473276623657771, 15.500916889735631, 13.316318137305123, 11.785546609333583, 3.4252234952790395, 0.214020326467497, 3.1146051457950046, 38.09395388194493, 51.134343419756206, 25.851174116134644, 24.834366049085343, 35.187727383204866, 52.92504358291626, 55.46695865903582, 58.812137603759766, 55.97090802873884, 14.262080005237035, 0.15759909472295217, 0.07269884579415832, 0.1758449285158089, 0.1712815226720912, 0.09613390506378242, 0.19171241564410074, 0.08587712900979177, 0.1098816352231162, 0.12119259685277939, 0.15906116126903466, 0.10040928636278425, 0.13376842918140547, 0.1407054862273591, 0.15634655979062828, 0.0522149388811418, 0.19771173729428224, 0.15988400711544923], [0.04884321355660047, 0.024685046302952936, 0.03684979836855616, 0.04239458976579564, 0.04275826078706554, 0.03350018310759749, 0.034788585401007106, 0.09648283491177218, 0.05058022927758949, 0.013710457382590642, 0.022027853976136873, 0.015492576174438, 0.05014405000422682, 0.10282692020492894, 0.06027485603200538, 0.04917480683486376, 2.8068585736410956, 32.851527622767854, 50.087458338056294, 46.94456924710955, 37.168895040239605, 20.162871531077794, 20.100507974624634, 39.16857269832066, 31.966601576123917, 39.61122158595494, 9.299485496112279, 0.2005539983510971, 0.19590040163270064, 0.263653711016689, 2.380905772958483, 5.600806960037776, 5.156073178563799, 16.032916137150355, 54.41184343610491, 54.26203680038452, 53.21801437650408, 49.44943652834211, 51.1722423689706, 52.15989753178188, 52.963359424046104, 55.0514702796936, 52.14648750850132, 51.113213947841096, 52.792381627219065, 44.602175167628694, 37.99700566700527, 36.1978634425572, 37.10578455243792, 36.66308355331421, 37.24461998258318, 38.02015706471035, 44.91620247704642, 49.37175914219448, 49.234844888959614, 48.26636675425938, 48.490852628435405, 48.423347405024934, 49.637569427490234, 47.36014100483486, 41.710915088653564, 35.94441400255476, 38.03690569741385, 36.07161814825875, 36.61037104470389, 36.09942136492048, 36.65385634558541, 36.388160705566406, 35.348202977861675, 33.58339180265154, 36.145738056727815, 34.64119250433785, 37.04279218401228, 35.70836632592337, 36.31503438949585, 34.25630051749093, 38.85876294544765, 41.32042980194092, 45.53224713461739, 43.03660011291504, 45.18152986254011, 40.22094685690743, 40.42719718388149, 36.509128843035015, 44.20059013366699, 44.708295004708425, 52.251655442374094, 33.27791772569929, 18.820535148893082, 49.303566047123496, 43.81765406472342, 49.53195333480835, 45.09238447461809, 49.27115617479597, 44.68878446306501, 47.318597725459504, 47.39279753821236, 42.98518691744123, 35.952988079616, 37.512024879455566, 34.49256706237793, 37.31820835386004, 36.42942258289882, 38.12105533054897, 36.78745630809239, 37.20406334740775, 39.55125168391636, 42.4439708845956, 42.22313281467983, 42.6581768989563, 36.166360310145784, 37.763070242745535, 35.45697355270386, 36.633411271231516, 32.89452307564871, 35.447444098336355, 35.09521906716483, 35.45534420013428, 34.41744313921247, 35.613252435411724, 35.099266392844065, 37.71381098883492, 38.9298152242388, 46.0184577533177, 48.100235325949534, 51.70680897576468, 48.26107222693307, 45.693205629076274, 42.77232537950788, 50.55294248035976, 51.504328046526226, 51.344015734536306, 50.214954308101106, 50.30191796166556, 49.32096086229597, 51.73608521052769, 47.06982094900948, 48.99333940233503, 46.890679018838064, 51.88922003337315, 50.09231512887137, 55.975525106702534, 14.93906991822379, 0.5503724015184811, 5.152654230594635, 0.4597051409738404, 2.903762059552329, 0.03333030168765357, 0.6878401221973556, 19.438051087515696, 43.97578116825649, 39.346366677965435, 22.855006660733903, 20.929471492767334, 37.093142305101665, 34.35622256142752, 46.53166907174246, 43.10804843902588, 25.024951662336075, 0.2486209576683385, 0.03781396270330463, 0.02577264463928129, 0.03998804318585566, 0.06776829822255032, 0.05612824032349246, 0.033496970244284184, 0.03917963656463793, 0.01214671490847, 0.04906736760001097, 0.014195379219017923, 0.019703164164509093, 0.032835720905235836, 0.023951770471675054, 0.04268043960577675, 0.07511227950453758, 0.07159735954233579, 0.038304916716047695, 0.035792695092303414, 0.03512446702058826, 0.05336990047778402, 0.04397908438529287, 0.02530206533681069, 0.010044290268394564, 0.03158942849508353, 0.0513083685987762, 0.055842611007392406, 0.025137140615178005, 0.016141728930441395, 0.03759366613147514, 0.0515618455330176, 0.018744709701942544, 0.043473562225699425, 3.4395736966814314, 42.07109580721174, 57.36904191970825, 52.695739133017405, 42.728037561689106, 26.110769237790787, 19.529807261058263, 32.69045100893293, 33.98152705601284, 46.00087881088257, 8.534257803644453, 0.28690797463059425, 0.07213342934846878, 1.1489385941198893, 8.759190968104772, 6.072956596102033, 2.7439775935241153, 16.918726342064993, 57.98681320462908, 55.78989355904715, 57.14585883276803, 52.04526267732893, 54.26818595613752, 52.95241948536464, 55.578984464917866, 54.32464354378836, 53.98022133963448, 52.46730668204171, 55.41944687707083, 46.13688285010201, 40.670623847416465, 38.01696784155709, 38.69984722137451, 39.70179830278669, 39.49941117422921, 41.58654580797468, 46.59601286479405, 50.30422823769705, 51.835475717272075, 49.15692431586129, 50.060541016714915, 49.33655261993408, 51.6697472844805, 50.248621804373606, 44.26543072291783, 37.05104316983904, 39.4966527393886, 37.04206609725952, 39.342354093279155, 37.34702253341675, 39.220010212489534, 37.89105258669172, 37.84498255593436, 35.58390324456351, 38.54953684125628, 35.81034851074219, 38.39648192269461, 36.47938013076782, 37.733547346932546, 34.96620838982718, 40.93713937486921, 42.459100587027415, 46.20959227425711, 45.04268053599766, 45.91729198183332, 41.57105132511684, 41.97249739510672, 38.94247484207153, 47.054149287087576, 47.72058228084019, 54.839181968144004, 35.395916257585796, 18.94935996191842, 49.50494916098458, 45.20039422171456, 49.836326122283936, 46.44067546299526, 50.92592178072248, 46.878519671303884, 49.001573017665315, 48.852409090314595, 45.050865513937815, 36.88573162896292, 40.11343043191092, 38.16154943193708, 39.478358132498606, 38.39279242924282, 38.839575495038716, 38.86955002376011, 38.185673577444895, 41.53011948721749, 45.745070457458496, 43.931083406720845, 44.1683782849993, 38.31921100616455, 39.62094906398228, 37.22022485733032, 37.92572757175991, 35.7711398260934, 37.21711206436157, 36.47279323850359, 37.58934790747506, 36.666158131190706, 37.92764180047171, 36.366593497140066, 39.72529363632202, 40.348060676029746, 48.843591826302664, 50.944112164633616, 51.97239691870553, 49.97841330936977, 44.893082346235005, 44.452222619737896, 51.36921337672642, 53.972206592559814, 52.28871018545968, 51.678071226392476, 52.08668436322893, 51.459265504564556, 52.653695583343506, 48.683098861149375, 50.31477212905884, 48.62995209012713, 54.91914531162807, 52.26773009981428, 57.30931520462036, 17.720327854156494, 0.5199777239135334, 6.269039971487863, 2.746385144335883, 4.552396748747144, 0.062217427151543755, 0.31489523713077816, 22.758233887808665, 45.44629791804722, 29.915878977094376, 27.649565935134888, 27.144011531557354, 43.27541664668492, 41.48086370740618, 53.06905542101179, 51.53794343130929, 33.04135588237217, 0.9110407424824578, 0.04846333572641015, 0.02969914528408221, 0.01919476332009903, 0.054607460142246315, 0.0617256656821285, 0.008345250456061746, 0.026259836175345948, 0.06891648803970643, 0.052512585052422116, 0.055337370439831696, 0.053754894462014945, 0.021936536733327166, 0.0643442612407463, 0.051102012528904846, 0.11162950750440359, 0.057006162857370715, 0.17792070284485817, 0.12597259107444966, 0.19935704900750092, 0.2246675451419183, 0.1805291407342468, 0.13761796190270356, 0.12979648874274322, 0.12114884491477694, 0.10754620589848075, 0.12240357830056123, 0.10778782543327127, 0.08380850643983909, 0.12865569495729037, 0.20538892676787718, 0.14486603225980485, 0.1487836627555745, 4.5920852933611185, 51.520072664533345, 65.1501384462629, 60.45863832746233, 50.07757452556065, 30.51264238357544, 27.953829288482666, 50.889023372105186, 43.67948913574219, 53.914359365190776, 10.949693083763123, 0.4507442446691649, 0.267695282718965, 1.3361859236444746, 8.835896474974495, 14.735697882516043, 9.600371156420026, 20.321879318782262, 58.84004156930106, 59.498202732631135, 57.98413119997297, 52.78706278119768, 55.970286164964946, 55.25825561795916, 57.343858173915315, 57.891789640699116, 56.36019822529384, 54.8491005216326, 57.34140893391201, 48.72296067646572, 42.247190952301025, 39.29961919784546, 39.874794551304404, 41.09217105593, 40.57698992320469, 43.39554057802473, 48.8455616406032, 53.6079055922372, 53.46913616997855, 50.1902882031032, 51.97101075308663, 52.32933282852173, 54.55818292072841, 52.22443240029471, 45.516738755362375, 39.92179911477225, 42.164243357522146, 39.750241143362864, 40.731191294533865, 39.47319562094552, 40.10457147870745, 40.19118077414376, 40.10252523422241, 36.72192437308175, 40.11985056740897, 37.207294259752544, 41.17773117337908, 39.16584553037371, 39.51062209265572, 38.18613910675049, 42.838465281895225, 45.90684536525181, 49.25380652291434, 48.07009751456124, 49.11306381225586, 44.92830623899187, 45.530002866472515, 41.7888182912554, 47.90486587796892, 49.68165227345058, 56.63370711462838, 36.6322682925633, 21.61561131477356, 49.49833447592599, 46.72174399239676, 50.87558903012957, 48.36357205254691, 53.12783023289272, 49.395070348467144, 50.655522210257395, 49.76337003707886, 46.40862342289516, 38.758785315922324, 42.33592987060547, 39.882298605782644, 42.50389214924404, 40.7441531590053, 42.92343132836478, 41.682875633239746, 41.259327343532014, 44.336166858673096, 48.438484055655344, 45.475799969264436, 47.12567751748221, 39.90406036376953, 42.13324049540928, 39.14603969029018, 40.2467976297651, 37.024164063589915, 39.01542050497872, 38.964375564030235, 39.33437756129673, 38.497209957667756, 39.841154847826274, 39.683663504464285, 40.4757650920323, 42.57505559921265, 51.862743922642295, 52.90044348580496, 53.97182444163731, 51.12006834575108, 46.14372682571411, 45.296671935490195, 53.07415887287685, 57.47167028699602, 54.87183155332293, 53.70552430834089, 54.248258522578645, 53.10750675201416, 57.12443058831351, 51.23882000786917, 52.94981043679373, 50.60953208378383, 56.201754978724885, 53.50910915647234, 61.7961665562221, 19.964688062667847, 2.1760120817593167, 12.680507591792516, 1.0466150790452957, 4.4656767163957864, 0.1813081939305578, 0.8601716778108052, 27.355257613318308, 57.226259912763325, 54.611503396715435, 31.948987892695836, 30.802149500165665, 47.34026915686471, 44.512112617492676, 61.68512739453997, 58.23341866901943, 40.476397378104075, 1.6097979503018516, 0.15583779423364572, 0.13446833805314132, 0.12412586302629539, 0.1526645709361349, 0.19173832211111272, 0.09307460101055247, 0.10720077729118721, 0.21747417827802046, 0.15702893531748227, 0.14689072647265025, 0.11364111956208944, 0.14342386036046914, 0.16655506486339228, 0.1365697474351951, 0.25211571156978607, 0.13212432526051998], [0.0514012464721288, 0.007815472365889167, 0.036483918715800555, 0.041847368236631155, 0.060068242118826935, 0.005432317008463932, 0.14208933125649179, 0.053374229531202994, 0.014518194798646229, 0.033699913283011744, 0.0477625752932259, 0.05019478406757116, 0.014175818750767835, 0.05604179835479174, 0.05696290624993188, 0.018417143529014926, 7.954116225242615, 43.30882011141096, 51.803302083696636, 45.78843763896397, 41.59219816752842, 24.400796719959803, 27.366934061050415, 45.9973143850054, 33.728574412209646, 39.35660137448992, 2.1715747884341647, 0.06588906156165258, 0.052616112532892396, 0.8960912589515958, 6.662290206977299, 4.3380522046770364, 3.1194360979965756, 21.565485273088726, 60.75937720707485, 52.52112395422799, 55.42986222675869, 48.0398520060948, 49.64761304855347, 47.10306460516793, 50.80096190316336, 47.89083399091448, 49.51796661104475, 48.05382830756051, 45.12862975256783, 38.375269072396414, 37.86537551879883, 38.94751228604998, 36.960407393319265, 36.15481240408761, 38.94677925109863, 42.381940841674805, 47.94094787325178, 48.4286801474435, 50.221874713897705, 45.73647206170218, 47.22745125634329, 48.43318952832903, 49.28006029129028, 45.337662833077566, 37.93756035396031, 36.190064089638845, 38.57056903839111, 37.71657984597342, 36.98634154456002, 35.430629457746235, 36.3209924697876, 36.79802451814924, 36.78563935416085, 35.27514961787632, 36.846185956682476, 35.829435212271555, 36.828238759722026, 35.107044901166645, 35.475681577410015, 39.23619951520647, 45.71403980255127, 45.843880789620535, 49.80881472996303, 46.43448461805071, 49.39931917190552, 46.52285875592913, 46.98161704199654, 43.19491481781006, 49.403046880449565, 42.73747321537563, 55.03691380364554, 31.682878834860666, 22.178307703563146, 51.39618280955723, 45.4288683618818, 50.785342352730886, 44.17594139916556, 48.44390712465559, 47.372501850128174, 48.14825432641165, 47.33263308661324, 40.0891603742327, 34.54995918273926, 39.14349317550659, 36.121058055332725, 37.488845688956125, 36.43653753825596, 36.23688105174473, 34.76057645252773, 37.12763316290719, 34.54341745376587, 35.37705189841134, 35.01371669769287, 36.065048626491, 35.493972710200715, 37.57044185910906, 35.49716540745327, 35.59296716962542, 34.661898136138916, 37.345073563711985, 36.15067475182669, 36.277823311941965, 36.11815370832171, 36.80071347100394, 35.767530236925396, 36.243589537484304, 42.140247753688264, 48.29027203151158, 49.109054701668875, 47.060750075748985, 46.13559743336269, 47.49249723979405, 48.19378934587751, 50.140702383858816, 49.60068491527012, 50.2825151171003, 51.600987911224365, 49.73677233287266, 52.77776609148298, 46.64428200040545, 46.93906627382551, 45.12916128976004, 43.7484986441476, 48.775711400168284, 49.991330010550364, 48.959581579480854, 37.91216121401106, 1.4328879117965698, 4.698980288846152, 3.144836106470653, 4.074200877121516, 0.31510514872414724, 0.14944410803062574, 7.711283632687159, 29.539863313947404, 33.23166356767927, 11.785524027688162, 22.35573169163295, 40.50574656895229, 29.079229014260427, 48.01116636821202, 42.93233544485909, 41.021761485508506, 6.316172208104815, 0.06043018626847437, 0.050079551858029196, 0.024946350138634443, 0.0075875872280448675, 0.022524784186056683, 0.02203887508117727, 0.122643060450043, 0.017774620060143725, 0.058884402071791034, 0.02322624351031014, 0.05184294902054327, 0.02125028846785426, 0.051550622563809156, 0.03569202085158654, 0.022824245438511883, 0.04354604333639145, 0.07115054423255579, 0.04110930194812162, 0.038257904417280636, 0.05210527065875275, 0.049814142885484865, 0.02713852036478264, 0.10227930173277855, 0.0548033599874803, 0.010357948169777436, 0.005361958440127117, 0.043154725405786715, 0.0318436755665711, 0.045603422581085136, 0.06319917911397559, 0.062447565873818736, 0.014542879902624657, 10.670735938208443, 53.134017603737966, 58.96469225202288, 51.353875228336875, 46.51233223506382, 29.87851503917149, 26.54932563645499, 44.9206736428397, 34.504705565316335, 43.65339170183454, 1.7057950219937732, 0.028242198284715414, 0.07401896281433956, 3.3265912107058933, 12.788986342293875, 7.075259864330292, 3.968188737119947, 22.74806867327009, 61.831261907305034, 54.429325103759766, 57.485872404915945, 49.81761809757778, 50.273736068180625, 51.70468282699585, 51.350686005183626, 50.37456832613264, 51.07160813467843, 51.3161221912929, 46.76161275591169, 39.98932865687779, 38.5792612348284, 40.04751287187849, 38.31974254335676, 37.802028792245046, 40.429326806749614, 44.648338999067036, 49.64767558234078, 49.73089763096401, 51.24906512669155, 46.022348744528635, 48.413984707423616, 50.46145902361189, 50.70252329962594, 46.56925882611956, 39.87188673019409, 37.7048339162554, 40.11883960451399, 39.63136788776943, 38.999338899339946, 36.98024797439575, 37.86597306387765, 37.85061059679304, 37.66637563705444, 35.46225765773228, 39.41183955328805, 36.70825726645333, 38.82151712690081, 36.16928897585188, 37.68212372916085, 39.50812421526228, 48.76423992429461, 47.822373390197754, 52.187815393720356, 47.555128301892964, 51.16438743046352, 48.698860849652974, 50.562642165592735, 44.7422890663147, 49.60142837251936, 45.236278193337576, 56.06029660361153, 32.948145798274446, 24.01252269744873, 50.716360637119834, 47.278364181518555, 53.33691542489188, 45.91588844571795, 50.08804893493652, 47.832663672310964, 49.201229504176546, 47.58952535901751, 41.999949727739605, 36.43623529161726, 40.01128496442522, 37.69736112867083, 38.553737027304514, 35.70842885971069, 38.02494089944022, 36.89162370136806, 37.53529439653669, 36.758513586861746, 36.59649201801845, 36.55700193132673, 37.31500176021031, 36.76522554670061, 37.9136620249067, 36.228376456669395, 36.380757399967735, 36.77805886949812, 38.121590341840474, 38.659787382398335, 38.00866821834019, 37.126646518707275, 37.62866428920201, 37.60994931629726, 38.31763029098511, 43.234811374119346, 50.97893306187221, 51.32605116707938, 49.38482175554548, 46.89482361929757, 47.42219884055001, 48.300253118787495, 50.60049942561558, 51.64757210867745, 50.70929084505354, 52.59463936941964, 51.27048989704677, 54.0822764805385, 48.466791016714915, 48.623142855507986, 45.442073413303916, 46.12322269167219, 51.036550998687744, 52.15938336508614, 52.35745218821934, 40.15334783281599, 2.2216445931366513, 4.268252772944314, 9.193686144692556, 5.760620304516383, 0.3713604786566326, 0.07739242179585354, 7.890166742461068, 35.62373726708548, 32.25535133906773, 14.501128435134888, 25.75149699619838, 46.20031295503889, 33.90727513177054, 52.953423500061035, 48.82545355388096, 48.52839027132307, 9.005519373076302, 0.08177143574825355, 0.01858242617786995, 0.03740426665171981, 0.06272585344101701, 0.0048718402977101505, 0.022096759207280617, 0.009837549978068896, 0.034935905531580956, 0.015537866690595235, 0.0040291163438398924, 0.029569290644888366, 0.03860229147332055, 0.02682036377622613, 0.021564857302499667, 0.06137561625135796, 0.031041195948741267, 0.13832316334758485, 0.11946531810930797, 0.12539647413151606, 0.16115650454802172, 0.2358363808265754, 0.17058241447167738, 0.1502925075058426, 0.18125581102711813, 0.10373523432229247, 0.1341385700340782, 0.09248477087489196, 0.17517279886773654, 0.1219133503202881, 0.1255617652620588, 0.1427268691893135, 0.06167880605374064, 13.647253887993948, 63.02941622052874, 65.80541610717773, 60.43532017299107, 55.106969015938894, 36.0812657220023, 36.80284309387207, 57.538994857243125, 45.029082911355154, 49.41626582826887, 2.234375212873731, 0.232016635792596, 0.19230188615620136, 3.1089380213192532, 11.24503321307046, 10.465852669307164, 8.156882030623299, 25.497413533074514, 64.54156657627651, 56.345999581473215, 58.92119652884347, 51.393320151737754, 52.84086268288748, 53.601707799094065, 54.93229825156075, 51.900424003601074, 52.63528633117676, 53.74915552139282, 49.39139475141253, 42.873237541743684, 39.88470615659441, 42.45344475337437, 39.69027124132429, 40.489088262830464, 42.54245465142386, 47.76602349962507, 51.66417135511126, 51.973123005458284, 53.328355244227815, 47.33727100917271, 49.651941776275635, 52.03364181518555, 54.11972379684448, 49.094717093876426, 41.841791357312886, 40.083653926849365, 42.37420054844448, 41.476906708308626, 41.53379855837141, 37.95453480311802, 39.30402782985142, 38.488205092293875, 39.11271960394723, 38.36351619447981, 40.85772841317313, 38.48608589172363, 41.46441732134138, 38.23889677865164, 39.0476462500436, 42.871816635131836, 51.372809069497244, 50.05934592655727, 54.549369130815776, 48.66468266078404, 54.068539891924175, 51.0446525982448, 50.93854318346296, 46.44094296864101, 52.71039635794503, 48.07309913635254, 58.372066497802734, 35.781155654362266, 26.216051816940308, 52.70779773167202, 48.817730631147114, 53.37357759475708, 47.699112347194124, 50.86731719970703, 50.43436104910714, 52.5573970249721, 50.61951664515904, 44.40490886143276, 37.85021802357265, 42.58858374186924, 40.25761597497122, 41.378336088997976, 39.302780628204346, 39.92602709361485, 38.714667728969026, 40.36418744495937, 37.55000025885445, 38.270799432482036, 37.494477203914094, 39.409077644348145, 40.165854590279714, 40.52352353504726, 39.818757329668315, 39.01124811172485, 38.703418595450266, 40.19152818407331, 41.693857261112754, 39.4102657863072, 39.258993080684114, 40.4421775000436, 38.809201444898335, 40.46732997894287, 45.75852911812918, 53.40984371730259, 53.435100419180735, 51.737589495522634, 47.61889886856079, 48.77451283591134, 49.93337508610317, 52.992611340114046, 52.32252706800188, 51.8458320072719, 54.0902738571167, 51.88105590002877, 57.53313405173165, 50.654149941035676, 53.25713620867048, 49.161673409598215, 48.068044321877615, 53.62555749075753, 55.61864478247506, 53.895331723349436, 45.242733069828574, 2.688323825597763, 15.662495510918752, 15.958377599716187, 6.946518863950457, 0.7136241272091866, 0.2793873910393034, 10.149778246879578, 43.587303910936626, 44.23075573784964, 18.501400913511002, 29.586770602634974, 49.95436559404646, 40.33820118222918, 60.539119311741416, 55.96918140138899, 54.7312764440264, 11.572309000151497, 0.1629672295280865, 0.17895670368203095, 0.09761493666363613, 0.20109266016100133, 0.1557069726820503, 0.06003861049456256, 0.16349409839936666, 0.12757085316947528, 0.1106968814773219, 0.12574559396931104, 0.14321658148297242, 0.14524181852383272, 0.13927877135574818, 0.15068598996315682, 0.15574761692966732, 0.1475140694528818], [0.02355221682228148, 0.026487404946237803, 0.03519671742937394, 0.010122688204449202, 0.00487481864235763, 0.03673548896663955, 0.038376997491078715, 0.010803397079663617, 0.031388419281159124, 0.01726418700335281, 0.051044951126511605, 0.02354508711557303, 0.0618238089872258, 0.04882102546149066, 0.0367205544108791, 0.07762771738427025, 14.55516197000231, 46.9609009878976, 50.24764558247158, 40.666354179382324, 22.735626186643326, 12.694333638463702, 32.556173597063335, 31.60473939350673, 36.360426970890586, 29.669172763824463, 0.1381802638726575, 0.011645289404051644, 0.07168940960296563, 3.228264864001955, 20.65359500476292, 5.442235606057303, 1.4870641018663133, 28.20125985145569, 60.02379921504429, 52.33055223737444, 51.74863018308367, 43.992849418095176, 43.21837888445173, 42.07700177601406, 41.135691097804475, 41.208838258470806, 39.03725869315011, 36.95867729187012, 36.93065173285348, 36.71997192927769, 37.01045874186924, 36.686620576041086, 36.20431137084961, 35.53737810679844, 37.00001907348633, 39.52497707094465, 47.35498891557966, 47.16197838102068, 50.59152582713536, 48.40945100784302, 44.90109361921038, 49.455742018563406, 48.25363418034145, 45.380227497645784, 37.67869131905692, 36.2841010093689, 37.04642956597464, 36.84336151395525, 38.246890681130544, 34.71140405109951, 33.98571334566389, 34.65653760092599, 36.989683628082275, 35.93839686257498, 36.35768243244716, 35.47009175164359, 37.166536126817974, 33.401446274348665, 39.82621274675642, 45.37828895023891, 50.9115355355399, 46.60083491461617, 47.60840361458914, 46.2772399357387, 49.74966124125889, 47.13910491125924, 49.81683989933559, 45.63150909968785, 51.00833783830915, 45.81141185760498, 55.97126933506557, 27.598519257136754, 23.93003715787615, 54.48747110366821, 44.5206241607666, 49.70057569231306, 44.14577579498291, 47.267250537872314, 43.9330393246242, 45.39334569658552, 39.900933674403596, 38.75801753997803, 33.69110972540719, 36.2774133682251, 35.34512839998518, 38.555932658059255, 37.396326950618196, 36.34752764020647, 36.97844839096069, 35.932584694453645, 36.05375780378069, 35.71415070125035, 35.43514231273106, 34.76403318132673, 36.320870876312256, 36.54754195894514, 35.40017202922276, 35.279731954847065, 35.94567510059902, 34.919770104544504, 37.113920892987935, 35.69871527808053, 35.70694541931152, 36.999011584690635, 35.23516968318394, 37.24399811880929, 46.14007554735456, 49.41858652659825, 49.399572781154085, 48.41827522005354, 49.689166750226704, 50.185233388628276, 50.62501614434378, 48.17766605104719, 49.095359802246094, 46.37213148389544, 51.59160784312657, 49.79564789363316, 47.294529165540425, 40.90500395638602, 41.515622070857454, 43.16550656727382, 51.047827925000874, 48.34578466415405, 53.673944745744976, 54.151779311043875, 47.27270139966692, 11.087276101112366, 3.2054891032832007, 7.494208012308393, 4.973757658685956, 1.6184997005122048, 0.10793554250683103, 2.114328363112041, 26.32717956815447, 35.199091162000386, 33.62961121967861, 22.377795696258545, 26.441480909075054, 39.67147289003645, 42.47160039629255, 45.04866988318307, 43.82436602456229, 16.13876846858433, 0.07645462533192975, 0.011196410499646195, 0.028046595298552086, 0.07415219316525118, 0.07892262004315853, 0.019359350470559936, 0.040800677080239565, 0.02154648257419467, 0.012447843660733529, 0.018892508199704543, 0.023139955908326165, 0.0901563304609486, 0.026087530689047914, 0.023071540918733393, 0.04406433552503586, 0.02116205686304186, 0.10406542303306715, 0.031077541677015166, 0.04304064331310136, 0.043936258647590876, 0.04686846969915288, 0.05571207783317991, 0.011341778145703887, 0.03983290972454207, 0.07506976250026907, 0.020398621846522604, 0.019328246425305094, 0.019195750588551164, 0.08107162187142031, 0.023044993236128773, 0.03369869191997817, 0.12568668355899199, 20.13980003765651, 53.986106463841026, 55.89051389694214, 46.269002846309114, 32.265252522059846, 21.86299671445574, 30.848417554582866, 34.31648928778512, 41.53774513517107, 34.219211033412385, 0.10636672204626457, 0.02121732184397323, 0.1428809780627489, 4.605043249470847, 11.15079653263092, 6.402689005647387, 3.5905517552580153, 30.845676490238734, 61.60067204066685, 54.98203345707485, 55.44100366319929, 47.43379538399832, 46.37998294830322, 44.14767612729754, 43.877992221287315, 42.71556207111904, 41.088373865400044, 38.997709546770366, 38.93078102384295, 38.65101875577654, 39.016650336129324, 38.31003590992519, 37.54776988710676, 37.86300618307931, 38.73703398023333, 41.18608638218471, 49.47470712661743, 48.22795711244856, 52.20413671221052, 49.33152559825352, 45.68800490243094, 51.02564580099923, 51.35461868558611, 47.43890230996268, 38.79466233934675, 36.88093042373657, 38.788593087877544, 38.65002516337803, 39.14834649222237, 36.12680768966675, 36.31684439522879, 36.13103566850935, 36.99375874655587, 37.35192101342337, 37.72702646255493, 37.187634331839426, 38.42566435677664, 35.7678359576634, 39.602508544921875, 47.03375979832241, 52.4992128099714, 49.70950412750244, 49.44251612254551, 48.33322579520089, 50.481421198163716, 48.14317519324166, 50.85801703589303, 47.03959281103951, 52.88021033150809, 47.35055249077933, 56.9826352255685, 29.95170041493007, 25.408308097294398, 56.54791423252651, 45.20740147999355, 50.574356828417095, 45.22152369362967, 47.3085367338998, 45.317071846553254, 48.59902913229806, 42.04286527633667, 38.777302265167236, 36.00074652263096, 38.52439825875418, 35.25911317552839, 39.331000736781526, 38.83970056261335, 38.26520613261631, 38.849587849208284, 36.20611095428467, 37.34072051729475, 37.329662459237234, 36.44669580459595, 38.269347258976524, 37.235163484300884, 38.03428622654506, 37.1579828943525, 36.37547329493931, 37.25047383989607, 37.17500945499965, 38.87383706229073, 38.3259333883013, 37.27700901031494, 38.912145955221995, 36.59128086907523, 38.38136264256069, 48.21420662743704, 51.766900471278596, 50.355123792375835, 50.17795862470354, 48.791584559849326, 51.60135963984898, 53.06114489691598, 50.580891609191895, 51.35977077484131, 47.23562233788626, 52.357893398829866, 52.5066682270595, 49.62153993334089, 43.57776403427124, 43.70744868687221, 44.72903537750244, 53.0379170690264, 50.99263143539429, 54.80888087408883, 55.18323591777256, 50.31568929127285, 14.78279972076416, 2.697514121021543, 7.829842482294355, 11.790324364389692, 2.9912487821919576, 0.04360372559832675, 1.9039660053593772, 29.894728660583496, 38.72169583184378, 32.07483713967459, 25.451051677976334, 32.059439931597026, 40.654917444501606, 48.72483321598598, 50.47909702573504, 52.36451850618635, 20.164275067193167, 0.12247981849525656, 0.01231508149898478, 0.02465041896461376, 0.04395359521731734, 0.06459949897336108, 0.04812279935660107, 0.09100939147174358, 0.06402227601834706, 0.008592186312723373, 0.04947709757834673, 0.050090564481381855, 0.043412782451403994, 0.07639815764767782, 0.029109033556388955, 0.07137224876454898, 0.07596356953893389, 0.21216203618262494, 0.09116160044712679, 0.13400835916399956, 0.11962908932140895, 0.10193064329879624, 0.19446183953966412, 0.0803154149491872, 0.08694992680102587, 0.12950756853180273, 0.11019339492278439, 0.11672335809894971, 0.11545197346380778, 0.18427542756710732, 0.1537890663104398, 0.09325659088790417, 0.4505503193608352, 25.311997379575455, 63.15594291687012, 60.543732915605815, 54.03776979446411, 33.96837411608015, 21.71569664137704, 41.61323036466326, 42.19830690111433, 49.8520325251988, 40.28132322856358, 0.19503590730684145, 0.11430907621979713, 0.14848521591297217, 8.509017603737966, 33.39591898236956, 14.268764172281537, 4.626847999436515, 31.94734811782837, 64.53074823107038, 57.56335176740374, 56.71991341454642, 49.337980474744526, 47.88404560089111, 46.66547053200858, 45.29766205378941, 45.215909549168174, 43.67975664138794, 40.50119897297451, 40.45657416752407, 40.27578204018729, 41.09211547034127, 39.682763712746755, 38.86647891998291, 40.09873846599034, 40.890586444309776, 42.574180126190186, 53.288952010018484, 50.906379972185405, 55.08400869369507, 51.47000047138759, 46.04773398808071, 52.601205417088096, 54.24507277352469, 49.898067814963206, 40.243083817618235, 39.32255172729492, 40.39420713697161, 40.86887679781233, 42.196795667920796, 37.13082933425903, 36.97938639777047, 37.644492285592214, 39.97400093078613, 39.51437759399414, 39.652518204280305, 39.18521015984671, 40.1494186265128, 37.007356371198384, 42.50829383305141, 48.70332159314837, 54.455804688589915, 51.412205355507986, 50.20954166139875, 49.93202018737793, 52.91901254653931, 51.49871390206473, 52.183517932891846, 49.595862865448, 54.86410515648978, 49.937408515385215, 58.518034253801616, 31.735865797315324, 27.28027786527361, 56.98450081689017, 49.53029618944441, 54.0309362411499, 48.54749434334891, 48.73037093026297, 47.5671625818525, 49.14872196742466, 44.05035965783255, 41.974672181265696, 38.58024787902832, 39.76253945486886, 37.46100773130144, 41.87062985556466, 40.65160315377371, 40.71419947487967, 41.07596090861729, 38.78158235549927, 39.117631980351035, 39.91651848384312, 40.12601361955915, 38.09876203536987, 39.414035184042795, 40.50629547664097, 38.82694714409964, 39.0082117489406, 39.24390506744385, 38.90697302137102, 41.57883678163801, 40.979408740997314, 40.06503970282418, 41.176963397434776, 39.58029515402657, 41.5290390423366, 50.784723963056294, 55.857068743024556, 52.10885259083339, 50.28968913214547, 50.165809699467246, 54.21587644304548, 55.21949509211949, 52.39315203257969, 53.164912768772666, 47.64183834620884, 54.63517243521554, 55.02446263177054, 51.892468316214426, 45.81464624404907, 46.12732560294015, 46.338144370487754, 56.536067553928916, 52.57732793263027, 57.76551307950701, 57.79138469696045, 53.30066319874355, 16.802519457680837, 7.118668735027313, 17.87088315827506, 11.01694209235055, 2.3303356979574477, 0.3532007916697434, 2.7619693023817877, 37.18468829563686, 49.73847811562674, 46.00535692487444, 29.535298347473145, 35.10037463051932, 50.64570093154907, 53.6116680417742, 58.76220090048653, 58.14546142305647, 25.33880874088832, 0.278204297380788, 0.07217841622020517, 0.19262068904936314, 0.17781768765832695, 0.14200777134725026, 0.15136813478810446, 0.1587713046797684, 0.1502223198435136, 0.05576247262901493, 0.11688066965767316, 0.09458285543535437, 0.19040551648608275, 0.15542109230799334, 0.06866824600313391, 0.1552585560296263, 0.11418683135083743], [0.029972649179399014, 0.0628808851220778, 0.02072784534123327, 0.02412555686065129, 0.033422494240637333, 0.011964549460182232, 0.055622908153704236, 0.029195163398981094, 0.028389710101432035, 0.047749666164496114, 0.04293726511033518, 0.05643166761313166, 0.05221559366743479, 0.0274417932877051, 0.07654265167989902, 0.5935156121850014, 24.36006464276995, 53.83805077416556, 51.498342173440115, 35.965703283037456, 17.361224106379918, 17.763510908399308, 36.45150743212019, 38.619473934173584, 40.72530617032732, 16.61622088296073, 0.2244069469826562, 0.06055662448384932, 0.5177292217101369, 4.22771828515189, 7.979325158255441, 4.12289993252073, 3.4884473255702426, 38.538096632276265, 59.609457288469585, 52.18809332166399, 48.63455874579293, 41.75437607084002, 41.22377341134207, 39.802602767944336, 38.476174286433626, 37.59927340916225, 39.10031706946236, 40.0971542767116, 41.09596129826137, 40.77175487790789, 41.17970446177891, 40.244164262499126, 38.58883932658604, 37.256362438201904, 36.8083530153547, 37.971912247794016, 40.26881647109985, 45.85934053148542, 47.64725794110979, 50.18148830958775, 46.958559444972444, 46.2827741759164, 49.569199153355186, 46.90538488115583, 44.5539095061166, 36.15840114865984, 36.82500784737723, 37.26695844105312, 35.861667905535015, 35.97644172395979, 36.06997837339129, 34.86538308007376, 36.25941753387451, 35.12685421534947, 37.88460118430001, 34.77274969645909, 37.29478597640991, 33.790263993399485, 41.763248920440674, 48.32043068749564, 48.53713457924979, 42.73837300709316, 46.56370026724679, 44.33757734298706, 46.98192276273455, 44.17718860081264, 48.45889786311558, 44.53078590120588, 49.72040237699236, 42.1273067338126, 53.32878950663975, 24.29778446469988, 27.645000968660625, 56.25171947479248, 44.736549854278564, 48.59085805075509, 40.46458544049944, 42.88774190630232, 38.92472914287022, 38.52294955934797, 33.88199063709804, 36.38503401620047, 33.518978527614046, 34.9205378804888, 34.70466429846627, 36.321339879717144, 35.58070707321167, 37.77045617784773, 36.422641141074045, 37.428528376988, 35.386911392211914, 35.672603947775706, 35.98245538984026, 34.223876748766216, 36.18219872883388, 36.55683170046125, 35.261055197034565, 36.083412715366904, 35.51626253128052, 35.81477451324463, 36.992598397391184, 40.33296571459089, 38.6223053250994, 38.11550719397408, 36.774918283735005, 38.44249636786324, 44.877705982753206, 46.21172537122454, 48.69798190253121, 48.01924017497471, 50.89974444253104, 50.210031509399414, 48.434214387621196, 48.0791996547154, 51.77971642357962, 49.52846186501639, 51.75124965395246, 47.99303504398891, 43.03296273095267, 39.3171112877982, 45.94247920172555, 49.24214744567871, 48.63683775493077, 50.97956534794399, 54.53207853862217, 50.04527235031128, 49.72647162846157, 25.444671494620188, 5.763033066477094, 7.307766130992344, 4.012745363371713, 1.7898680078131812, 0.030228304211050272, 0.22372017454888138, 16.14994638306754, 36.835808822086875, 28.111558607646398, 14.653049060276576, 15.600891045161656, 30.2404362814767, 38.23403998783657, 44.518181868961875, 46.75196170806885, 28.769825731004985, 0.7461123296192714, 0.020359629831675972, 0.00977183216517525, 0.020686541218310595, 0.01758505603564637, 0.07242310273327998, 0.06485490633973054, 0.030767980430807387, 0.04765385701986296, 0.012758255620220942, 0.029987800866365433, 0.02316853410697409, 0.03408623380320413, 0.031536384020000696, 0.09305507277271577, 0.03884895930864981, 0.06833722269428627, 0.041886631665485244, 0.06338245142251253, 0.04201711394957133, 0.0158743963111192, 0.02333913477403777, 0.046971267754478116, 0.05946787433432681, 0.03162969954844032, 0.01707686553709209, 0.02484363011483635, 0.08916339624140944, 0.055225612329585214, 0.04722256659130965, 0.07058453067604985, 1.3310900713716234, 32.84293964930943, 59.98418753487723, 56.99344662257603, 43.05200774329049, 22.479611124311173, 14.981629371643066, 39.338727133614675, 38.43702118737357, 46.98342704772949, 17.909476927348546, 0.19073725225669996, 0.018251263769343495, 0.7579985803791455, 5.708198317459651, 11.204202992575508, 5.605977722576686, 4.073006655488696, 41.365137985774446, 60.11769717080252, 55.21162625721523, 50.48502731323242, 43.34417254584176, 41.83113282067435, 40.49169731140137, 38.879680497305735, 39.12890543256487, 39.27747528893607, 40.03431476865496, 42.45887129647391, 44.06153583526611, 43.57916062218802, 41.30019664764404, 40.5482417515346, 38.93202127729143, 38.21833011082241, 38.941727910723, 42.522822516305105, 48.078341552189414, 49.39507729666573, 51.12577281679426, 48.47388860157558, 48.98351117542812, 51.93286861692156, 49.740892614637104, 44.85430097579956, 38.18380798612322, 38.989649636404856, 38.31373929977417, 37.12565640040806, 37.09908996309553, 38.09980773925781, 36.18863276072911, 37.800131934029714, 37.20455666950771, 38.87013714654105, 37.73029906409127, 39.36218077795846, 35.66069820949009, 43.739417348589214, 50.681511947086875, 49.95114857809884, 44.138893604278564, 46.4393309865679, 44.43513699940273, 47.25240223748343, 45.2713040624346, 49.88010672160557, 47.0809554372515, 51.50718723024641, 44.238701002938406, 52.81722143718174, 26.03448670251029, 29.702058587755474, 57.21241562707083, 46.24499682017735, 50.02840559823172, 41.74415179661342, 43.863991601126536, 40.86924852643694, 40.806996141161235, 34.581504004342214, 37.73571865899222, 34.58196605954851, 36.91047069004604, 37.035423619406565, 38.60303797040667, 37.07364913395473, 39.69080625261579, 38.53593921661377, 38.586390086582725, 36.8101977620806, 37.44306400844029, 37.292944703783306, 37.49864264896938, 37.529534339904785, 38.055064814431326, 37.72402136666434, 36.73117937360491, 36.546096733638215, 37.90814515522548, 38.59490857805525, 40.70644528525216, 40.52843591145107, 40.79786968231201, 38.28054428100586, 39.93049131120954, 45.79317283630371, 50.15518242972237, 49.78472185134888, 48.418323857443674, 53.50479779924665, 51.56055286952427, 50.306295326777864, 49.83053479875837, 52.402820450919016, 50.458523409707205, 52.26857778004238, 51.52267129080636, 45.08434540884835, 41.37788445608956, 48.984021868024556, 51.59488044466291, 51.684758867536274, 52.08671563012259, 55.95491327558245, 51.921365874154226, 51.56227602277483, 27.045394011906215, 5.754065547670637, 3.43355764235769, 5.542779513767787, 3.252033348594393, 0.04012224044916885, 0.120674196098532, 18.517748287745885, 41.149368626730784, 27.402385507311138, 18.634759426116943, 24.83307715824672, 37.87770857129778, 43.2437606539045, 50.729944365365164, 53.337797846112935, 37.45591817583357, 1.259418751512255, 0.014679725148848124, 0.048734695451068025, 0.05531063616009695, 0.0952095775199788, 0.0892943467146584, 0.030883338169327805, 0.014478607369320733, 0.019138031007189835, 0.010781926535336035, 0.034827479028276036, 0.04919461327205811, 0.03670566395989486, 0.08160086561526571, 0.04131954941632492, 0.01360718096007726, 0.14428986103406974, 0.148367829354746, 0.18332405361746038, 0.12753687213574136, 0.10708857474050351, 0.13440447433718614, 0.18919515929051808, 0.16830248252621718, 0.12768758833408356, 0.13106054519968374, 0.2089932912162372, 0.14287559049470083, 0.18916045900966438, 0.0957932397723198, 0.09514833973454577, 1.6843919647591454, 42.09214537484305, 66.925048828125, 65.91963754381452, 48.6100628716605, 28.684505326407297, 25.115401574543544, 48.80899327141898, 48.8922187941415, 53.83292647770473, 20.87802529335022, 0.3271119073033333, 0.2689647674560547, 0.8295491210051945, 11.413340296064105, 20.305179323468888, 11.311024597712926, 8.293612156595502, 43.27272421973092, 63.92088399614607, 56.50430038997105, 53.67013365881783, 45.507931913648335, 45.16679620742798, 43.95364073344639, 41.81684037617275, 41.76713991165161, 42.2848675591605, 43.311147757938926, 45.13184676851545, 44.940486431121826, 45.49207959856306, 43.78640801565987, 42.93683440344674, 41.66635281699044, 40.191503865378245, 40.66972752979824, 45.561499050685335, 50.02273934228079, 52.16592509405953, 52.309384550367085, 50.328731060028076, 48.9188095501491, 54.219010080610005, 52.08952965055193, 48.556968212127686, 39.56879241125924, 41.060872895377024, 41.29042053222656, 38.787120069776265, 39.04882396970476, 40.68262338638306, 37.99389982223511, 40.44528681891305, 38.59789282935006, 40.54187372752598, 38.28375087465559, 41.633456570761545, 38.37999732153756, 46.23849678039551, 52.61072792325701, 52.36646400179182, 45.916433879307334, 47.79216957092285, 45.62819133486067, 46.57986525126866, 45.06131560461861, 51.30741262435913, 49.11447082247053, 51.55930914197649, 45.50743859154837, 53.04427467073713, 27.745518820626394, 31.776311261313303, 59.97035367148263, 49.46767554964338, 51.93227802004133, 44.37898860658918, 45.432408469063894, 43.067363262176514, 41.96193960734776, 37.15493958336966, 39.70157943453108, 35.960078716278076, 37.979353768484934, 38.58858919143677, 40.40816259384155, 39.232179982321604, 40.6950432913644, 40.85812793459211, 40.86098711831229, 40.31432717187064, 39.851608412606375, 39.0783121245248, 38.944389070783345, 39.43039124352591, 41.412080015454976, 39.87712567193167, 39.44334963389805, 39.11605126517159, 40.369440283094136, 40.64532545634678, 43.89156552723476, 42.090529918670654, 43.420189312526155, 40.39516946247646, 41.15649053028652, 48.858332429613384, 52.109394550323486, 51.42766857147217, 48.445053577423096, 55.63149547576904, 55.34575775691441, 51.96308980669294, 54.17828321456909, 56.826853139059885, 53.2575808933803, 55.820444788251606, 54.824031421116416, 46.91511583328247, 42.36939934321812, 50.34257187162127, 53.23771946770804, 54.09139599118914, 55.15981701442173, 58.29628944396973, 54.069439683641704, 53.01467881883894, 30.3417375428336, 9.190278921808515, 16.5621725831713, 8.811226027352468, 3.6391900139195577, 0.120533820773874, 0.43241758378488676, 21.484669038227626, 49.56957088197981, 38.74557679040091, 23.08410266467503, 25.357388223920548, 42.43569558007376, 50.72191572189331, 58.372066497802734, 59.95210770198277, 43.1254015650068, 1.835151480776923, 0.1471813837332385, 0.20743620262614318, 0.13766642287373543, 0.10663266027612345, 0.1763606829834836, 0.1754010444773095, 0.10910903489483254, 0.1204262865441186, 0.10173365779753242, 0.10683098249137402, 0.16300287975796632, 0.11555850346173559, 0.11170865182897874, 0.14451541964496883, 0.12380286678671837], [0.08883648485477481, 0.035658073744603565, 0.020806969309757863, 0.05378676525184086, 0.09037315632615771, 0.04079924876402531, 0.05292563645967415, 0.014179442975936192, 0.04225302021950483, 0.010195012403918164, 0.021079312910192778, 0.03568165622917669, 0.018557744466566613, 0.030809564449425255, 0.03353605725403343, 4.819434693881443, 42.77963488442557, 50.67613751547677, 45.77322455814907, 36.86787128448486, 39.212860516139436, 25.468554190226964, 37.80764293670654, 32.66069882256644, 41.41400466646467, 5.747834750584193, 0.11511779496712343, 0.17777124872165068, 0.23006915886487278, 2.9124694551740373, 6.082971121583666, 3.40240170274462, 3.9087560176849365, 40.15135022572109, 56.70171955653599, 49.88491487503052, 47.58872284208025, 47.78309522356306, 47.12719569887434, 45.68412433351789, 43.65484387534005, 42.639878817967, 45.42618983132498, 46.426667894635884, 48.272449902125764, 48.02371481486729, 49.652653966631206, 45.05343287331717, 41.130014419555664, 37.63577924455915, 36.04829651968819, 35.99322509765625, 36.62923887797764, 39.051467759268625, 45.09327036993844, 47.58322334289551, 48.78649500438145, 43.69955900737217, 48.33200291224888, 47.51148319244385, 45.66497162410191, 42.664166246141704, 41.77668326241629, 40.82294225692749, 39.205717767987935, 34.990676471165244, 35.273356982639854, 35.95431865964617, 35.15642574855259, 36.52303566251482, 36.19142941066197, 35.85553959437779, 35.287465299878804, 35.529088905879426, 45.69471338817051, 47.83920540128435, 46.04546887534005, 42.26285914012364, 47.91014303479876, 46.11338056836809, 49.80605282102312, 45.29153721673148, 46.2328131539481, 44.91627890723092, 48.93995639256069, 41.86688825062343, 49.894173349652974, 26.25016052382333, 29.321981702532085, 54.72740282331194, 42.298093455178396, 48.19158329282488, 36.263808795383994, 35.98562724249703, 33.63140385491507, 36.79714904512678, 37.49423401696341, 40.951146943228586, 37.75954055786133, 35.89922639301845, 31.990875107901438, 34.93712670462472, 32.43502133233206, 35.27456249509539, 35.138753005436485, 36.62735939025879, 34.62423195157732, 37.9522453716823, 34.1294298853193, 37.48464550290789, 33.92987067358834, 36.16065583910261, 33.55381679534912, 36.2824820790972, 36.10210336957659, 41.81706271852766, 45.034321853092735, 48.5146849496024, 44.394587312425884, 41.926479475838796, 37.9186612537929, 39.45816319329398, 46.332419054848806, 49.071840150015696, 47.8218731198992, 47.14937434877668, 50.610758440835134, 48.26610272271292, 44.326210090092246, 43.831276008060996, 48.989524841308594, 50.20775250026158, 50.728711060115266, 43.73579386302403, 35.86625371660505, 43.48388344900948, 49.82154382978167, 55.30777890341622, 54.91241250719343, 52.73062603814261, 54.73585878099714, 54.16208348955427, 54.652991090502056, 45.15382044655936, 9.114317740712847, 3.824994615146092, 9.328977125031606, 7.770057576043265, 1.146541791302817, 0.1416660746825593, 9.776102389608111, 37.992138453892295, 39.11933428900582, 29.60552031653268, 12.564909543309893, 23.07811679158892, 30.59267520904541, 46.812490940093994, 43.48711436135428, 41.57021754128592, 9.47185206413269, 0.10861235404653208, 0.03019109335062759, 0.04097607159721, 0.029765309233750616, 0.04329897516540118, 0.05473312822037509, 0.03188647755554744, 0.023411564994603395, 0.03118511661887169, 0.02803158780027713, 0.028872313044433082, 0.021058838116005063, 0.04712205180632217, 0.05279348497944219, 0.018347262903781872, 0.05486257913123284, 0.04230391373857856, 0.026306858652138283, 0.02430497169760721, 0.01488157913887075, 0.08615274993436677, 0.05049830295943788, 0.05057201221851366, 0.005143283142907811, 0.04094555787742138, 0.04165700862982443, 0.03285607695579529, 0.03414097461583359, 0.021506180986762047, 0.09576970139252287, 6.7804330331938605, 50.95448929922921, 55.67877796718052, 50.09509440830776, 42.19962705884661, 41.39510209219796, 20.9614314692361, 38.05088199887957, 34.327095712934224, 46.3650860105242, 6.949999042919703, 0.27616326404469355, 0.38080446475318497, 2.3183070634092604, 4.972182588917868, 7.983155352728708, 5.648502435003008, 5.758255311420985, 42.82152904782976, 58.559417724609375, 50.76189565658569, 48.34037896565029, 50.17681564603533, 49.42571537835257, 47.0918675831386, 44.742483615875244, 43.90799454280308, 48.337005615234375, 48.68236582619803, 51.36496107918875, 51.27264036451067, 52.49988678523472, 48.15477173668997, 43.64098916734968, 37.82978337151663, 37.535752977643696, 37.570309843335835, 37.50829717091152, 41.13397836685181, 47.59286049434117, 50.008412156786235, 50.291075297764365, 44.11728818075997, 50.64222683225359, 49.34793724332537, 47.22311558042254, 43.32674298967634, 42.96651015962873, 43.741717202322825, 40.831408636910574, 35.824536732264924, 36.196814264569966, 37.3118577003479, 37.13445281982422, 37.273385524749756, 38.27417278289795, 36.563144138881135, 36.1292256627764, 37.196472440447124, 46.88975838252476, 49.67007657459804, 46.983677182878765, 44.18492889404297, 49.515260287693565, 48.94956922531128, 49.6501977784293, 46.0562663759504, 46.78185633250645, 44.89478465488979, 49.48165532520839, 42.63721765790667, 50.42348711831229, 27.044381311961583, 29.989832128797257, 56.62514693396432, 45.399817943573, 50.364747047424316, 38.33341312408447, 38.70140709195818, 35.52683768953596, 38.77128859928676, 38.569214139665874, 42.41311046055385, 39.51272739682879, 37.02662372589111, 34.18256623404366, 37.28413438796997, 35.85680416652134, 37.88973937715803, 36.64520583833967, 37.920700550079346, 37.542586530957905, 38.60427474975586, 36.48213161740984, 38.99771302086966, 35.64959846224104, 38.393330914633616, 34.42748328617641, 37.42211171558925, 36.09865706307547, 42.45170770372663, 46.85297809328352, 50.13957330158779, 45.09680700302124, 44.261605739593506, 38.68997035707746, 41.51647669928414, 47.7636159488133, 50.477262701307026, 49.186523641858784, 48.294378416878835, 50.85593605041504, 51.755623544965474, 46.19617877687727, 46.12609577178955, 50.15538045338222, 52.183500562395366, 52.53267533438546, 45.266537598201204, 38.347854954855784, 46.09663540976388, 51.56121294839041, 57.96296003886631, 56.406007698604036, 55.098652022225515, 55.11758933748518, 54.53401361192976, 55.08762870516096, 46.418031283787315, 12.150873337473188, 0.8810612740261214, 3.8287722638675143, 7.817570226533072, 1.4199691478695189, 0.2820782166506563, 10.39198897566114, 43.89805861881801, 28.67860630580357, 29.24717739650181, 20.20663823400225, 29.342843668801443, 36.45099326542446, 51.85409688949585, 49.66820056097848, 50.025657585689, 12.716862303870064, 0.10501657985150814, 0.10214942334485905, 0.047585677821189165, 0.04174092984093087, 0.027508233740393604, 0.07135022351784365, 0.027347253003556813, 0.025760325836017728, 0.025819441503179923, 0.0312965626030096, 0.03678910341113806, 0.022176263155415654, 0.05722134666783469, 0.029690290402088846, 0.03304395651710885, 0.2054561831589256, 0.0877708795347384, 0.11487736286861555, 0.17683075847370283, 0.1668290708746229, 0.13391301142317907, 0.18618603290191718, 0.14657465129026345, 0.09617364007447447, 0.09527973804090704, 0.11716040250446115, 0.09526564486856971, 0.22836125908153398, 0.17659324407577515, 0.1445311073746, 8.665504932403564, 60.05829702104841, 62.605833189828054, 58.35392475128174, 47.102630342756, 46.97455767222813, 35.587537152426584, 48.772935594831196, 42.03759159360613, 53.37438358579363, 7.128492619310107, 0.34628966823220253, 0.6072721768702779, 2.531562260219029, 8.933968561036245, 12.575232829366412, 11.429725016866412, 8.043625525065831, 44.623648575374055, 61.716887610299246, 53.52479818889073, 51.62541082927159, 52.979097093854634, 51.00331081662859, 49.858980723789756, 46.44117225919451, 45.91265753337315, 49.6685722896031, 50.85446303231375, 52.621827670506065, 52.4604766028268, 54.481068338666645, 50.60301119940621, 45.82706267493111, 40.33160386766706, 40.315536158425466, 39.44656317574637, 40.2386508669172, 42.37645871298653, 48.72879021508353, 51.18914386204311, 52.95971509388515, 45.008005550929475, 51.24417012078421, 51.39463683537075, 49.347489084516255, 45.21991171155657, 45.61131068638393, 46.67578860691616, 43.942051138196675, 38.23942831584385, 37.994083949497764, 39.31808056150164, 39.015809604099815, 40.61976650782994, 40.20458384922573, 37.82292897360665, 38.061915738242014, 40.63998923982893, 48.901175022125244, 51.933361939021516, 49.210748536246165, 46.42866897583008, 50.934051173073904, 51.779205730983186, 51.67877994264875, 48.653919901166645, 47.542204652513774, 45.72464622770037, 50.47477177211216, 43.248541014535085, 51.505613463265554, 30.829244000571116, 33.29358243942261, 58.46422740391323, 48.017649037497385, 52.60722255706787, 39.41516774041312, 41.45754902703421, 37.66701487132481, 41.26700857707432, 41.849660192217144, 45.359073707035606, 42.56173242841448, 39.37747376305716, 35.37448801313128, 38.783843994140625, 36.013569423130576, 38.142615590776714, 38.81855719430106, 41.042779786246165, 38.361608913966585, 40.50559718268258, 37.01023292541504, 41.21680089405605, 37.0123347554888, 40.81081417628697, 36.80178001948765, 39.44283199310303, 38.78016839708601, 45.10351548876081, 48.645745345524375, 53.617528847285676, 48.84677062715803, 46.04931470326015, 41.02734783717564, 44.09769426073347, 51.61351203918457, 52.43861409596035, 51.22755002975464, 50.28040286472866, 52.24596834182739, 54.07607173919678, 49.17535441262381, 47.497916834695, 52.627316747392925, 54.60201563153948, 56.2195771081107, 47.428712776729036, 39.30371863501412, 49.056189332689556, 52.78506864820208, 60.449251311165945, 58.81932898930141, 56.52065992355347, 57.519453048706055, 57.89422151020595, 58.68232440948486, 49.307689802987234, 15.665794168199811, 13.011683923857552, 18.171312843050274, 13.946893215179443, 1.5635824416364943, 0.3307233692279884, 12.102677157946996, 50.945491382053916, 52.052335943494526, 39.662568773542134, 20.327088730675833, 32.960117544446675, 40.792693274361746, 59.435293742588584, 55.089522089277, 57.5709114074707, 15.138352939060756, 0.32251437114817755, 0.19030494402561868, 0.18498395383358002, 0.1470300704240799, 0.2588685192167759, 0.13165635322885855, 0.18612333626619407, 0.1578876892370837, 0.08589489305657999, 0.12756585915173801, 0.08628069449748312, 0.13169983375285352, 0.16951630025037698, 0.08376328886619636, 0.10402886356626238], [0.03481544181704521, 0.011901470300342356, 0.028015109577349255, 0.007326939874993903, 0.04400309434692774, 0.05758349437798772, 0.07128982711583376, 0.056941566323595386, 0.03646847865145121, 0.05666641019550817, 0.053685269983751435, 0.02103006144586418, 0.018948896156091775, 0.06493741619799819, 0.09364758312169995, 8.370180436543055, 45.47885022844587, 50.16405527932303, 44.116725376674104, 32.748131479535786, 28.438050985336304, 25.340742077146256, 32.48184176853725, 41.63795552934919, 34.618763719286235, 2.508795836142131, 0.2657850437930652, 6.329916179180145, 10.318250349589757, 2.3962871304580142, 7.48648248400007, 3.081709985222135, 2.9635502227715085, 37.64238003322056, 55.62059027808053, 51.1727739061628, 54.39928109305245, 51.95277867998396, 51.83510051454817, 50.93095227650234, 51.11350577218192, 49.57098831449236, 49.28976692472185, 54.01167236055647, 52.341669355119976, 49.61610991614205, 49.24873086384365, 46.398472104753765, 41.21878807885306, 36.368240220206125, 36.557227747780935, 35.05866459437779, 38.16464138031006, 37.9583180972508, 41.41463000433785, 46.1076865196228, 48.29369401931763, 47.965030329568044, 46.211405754089355, 48.33573409489223, 48.46872609002249, 47.26238679885864, 46.255043915339876, 44.49240057809012, 45.820958682468955, 37.60711792537144, 36.67316886356899, 35.06290299551827, 36.47566631862095, 34.539752279009136, 36.00623559951782, 35.17308405467442, 36.20561763218471, 35.36090428488595, 45.03200115476336, 47.170451709202354, 49.567448207310264, 47.36707878112793, 49.59544249943325, 45.63086986541748, 48.50504779815674, 48.20874881744385, 50.663675921303884, 47.6930569921221, 52.40092706680298, 43.73418188095093, 54.16735717228481, 27.751897266932897, 31.221834591456822, 52.77781820297241, 43.82954590661185, 46.07255642754691, 35.066953795296804, 39.72289650780814, 41.37122460774013, 47.604238169533865, 44.58545780181885, 47.197278703962056, 45.55227531705584, 46.86308077403477, 39.57339211872646, 33.588960783822195, 34.48264503479004, 35.30017702920096, 33.633457047598704, 36.18130588531494, 34.01856790270124, 37.02372285297939, 33.21809026173183, 35.44489410945347, 37.06830596923828, 38.035290241241455, 34.96832759039742, 37.821337836129324, 41.91428191321236, 48.56360721588135, 48.40070669991629, 49.89083474023001, 47.37112610680716, 43.49111304964338, 42.45563343593052, 43.27536106109619, 43.75264324460711, 49.09056207111904, 47.38041237422398, 45.19580841064453, 48.5529591015407, 47.7515538760594, 43.74101890836443, 39.66598381314959, 43.2107949256897, 44.57244035175869, 42.49334825788225, 37.93200526918684, 40.94838503428868, 47.98134469985962, 54.26792539869036, 40.765775953020366, 31.324931962149485, 57.47106579371861, 46.87314871379307, 56.35277754919869, 49.72482490539551, 56.962322166987825, 25.843107257570537, 2.8939787788050513, 0.7694942663822855, 13.343317968504769, 4.758789079529898, 0.3975600999380861, 3.709241969244821, 30.947359902518137, 39.84942667824881, 34.181273869105745, 23.16216914994376, 24.4616733619145, 34.62153605052403, 40.75044475282942, 44.03790153775896, 50.21576377323696, 15.839255946023123, 0.08567747008055449, 0.033789897204509804, 0.026146715906049525, 0.03820510421480451, 0.05665711426575269, 0.025648754322901368, 0.07396430003323726, 0.025232508712049042, 0.04790485730128629, 0.032707403147859235, 0.014043740213050373, 0.0780338884464332, 0.018847059924155474, 0.042221668508968184, 0.06353957977678094, 0.03710773667054517, 0.06767109129577875, 0.06126369868538209, 0.042988100953932316, 0.0230816273417856, 0.06985258816608361, 0.0485308329973902, 0.04411327825593097, 0.03639274396534477, 0.05703310748296125, 0.03160618831004415, 0.06613907457462379, 0.022961033009258763, 0.04087341603423868, 0.05306107883474656, 11.161662646702357, 53.180150168282644, 56.27915791102818, 48.84793792452131, 37.77505241121565, 33.60578237261091, 30.93917145047869, 37.0262519972665, 44.09407772336687, 40.27489961896624, 2.512623425040926, 0.31290083272116526, 8.143439871924263, 14.136661546570913, 4.4520261117390225, 6.95972695520946, 6.225235487733569, 4.095669507980347, 37.68858207975115, 59.237235341753276, 51.906864983694895, 56.6497539792742, 52.403042793273926, 53.55190658569336, 52.539474146706716, 51.41498463494437, 52.1780948638916, 51.14524514334542, 54.619083881378174, 54.344334738595144, 50.88989189692906, 51.726305621010916, 48.63071986607143, 42.771314416612896, 37.74524463926043, 38.62415702002389, 38.434471198490684, 40.054516656058176, 39.49566609518868, 43.7760135105678, 48.28496013368879, 51.31968314307076, 48.046685559409006, 45.64340441567557, 50.0394914490836, 50.091814858572825, 48.30735765184675, 49.18654796055385, 46.46174587522234, 48.170141151973176, 38.88096591404506, 37.96418932506016, 35.77758080618722, 38.147357736315044, 36.907420430864605, 37.5928567477635, 35.91330344336373, 37.95895038332258, 37.44394295556204, 46.51261363710676, 47.62184490476336, 50.87570367540632, 48.21941082818167, 50.692205224718364, 47.29931647436959, 50.814795766557964, 50.22017240524292, 51.61357109887259, 49.21882234300886, 52.067305837358745, 44.97095775604248, 56.62015117917742, 28.238323279789515, 33.15629645756313, 55.10584340776716, 45.45362479346139, 48.58028289249965, 37.74242714473179, 40.60809700829642, 42.654212951660156, 48.99993324279785, 47.22284460067749, 50.07980489730835, 45.87179170336042, 48.60985789980207, 41.55723830631801, 35.23134469985962, 36.151459898267476, 37.25384371621268, 36.62278052738735, 37.765575068337576, 35.900942598070415, 37.929298945835654, 35.37501607622419, 36.85548612049648, 37.69535657337734, 39.60782044274466, 36.200594084603445, 38.66333096367972, 44.279928139277864, 49.720989499773296, 50.868220465523855, 52.04731239591326, 50.090314047677175, 46.3545560155596, 44.907812527247835, 44.93980203356062, 46.12279885155814, 50.97897475106375, 49.07547058377947, 45.380203178950715, 50.003534521375386, 51.58911343983242, 45.81263821465628, 41.42178317478725, 44.80673360824585, 46.361789090292795, 43.54615320478167, 40.232765742710654, 43.20046990258353, 50.0039826801845, 55.81807197843279, 42.36452170780727, 34.42145572389875, 58.07560076032366, 49.27812869208199, 56.38430847440447, 50.49522726876395, 57.26384966714041, 28.044602291924612, 2.063072153500148, 1.3853919804096222, 19.140398945127213, 7.250211596488953, 0.3540962407631533, 3.607304947716849, 35.043065888541086, 42.282571179526194, 32.83251387732369, 23.191530500139507, 27.790293012346538, 38.565236295972554, 45.57777520588466, 49.64267635345459, 57.9379882131304, 20.185199567249843, 0.20234455727040768, 0.04650129404451166, 0.09294610683407102, 0.044732543240700445, 0.0727082435041666, 0.01237853554942246, 0.020542488233851533, 0.06929468310305051, 0.010295465272585196, 0.008905108851779784, 0.015585808582337839, 0.020593402108975818, 0.039775912782975605, 0.00391651557791712, 0.03066459883536611, 0.13920361681708268, 0.18227658553847245, 0.16386029017823084, 0.12495560278849942, 0.14716527531189577, 0.13204242608376912, 0.12399557073201452, 0.1311363647026675, 0.10816238354891539, 0.11591763847640582, 0.11832014098763466, 0.12931185189102376, 0.19281595785702976, 0.14657298209411757, 0.22080414316483907, 14.696836607796804, 62.375007084437776, 62.25113459995815, 57.28572259630476, 43.9078277860369, 35.93611785343715, 34.339050088609966, 40.60206249782017, 52.466198444366455, 44.19851609638759, 2.890695537839617, 0.4344637468457222, 10.508224521364484, 16.22319950376238, 10.113167319978986, 21.056779861450195, 10.430211016110011, 6.470527308327811, 41.48216649464199, 60.84096990312849, 54.22704567228045, 59.48397282191685, 54.49843536104475, 56.270761013031006, 55.186265332358225, 55.94069378716605, 53.816688537597656, 53.23845597675869, 56.23368195125035, 57.20032923562186, 52.345681939806255, 53.44712775094168, 50.87203502655029, 45.782448291778564, 41.79478331974575, 40.416128703526084, 40.11668913705008, 42.544903891427175, 42.153504916599815, 46.48858676637922, 50.675011907305034, 52.217251437050955, 49.73846421922956, 46.39806563513619, 51.873367718287874, 52.705581256321494, 51.96515342167446, 51.08725895200457, 46.86156259264265, 50.444383825574604, 41.334704875946045, 39.92349100112915, 36.69623688289097, 39.63435213906424, 37.84632355826241, 38.394692761557444, 38.55306652614048, 39.98914105551583, 38.59956387111119, 48.865631512233186, 50.03575331824166, 53.53485918045044, 50.19438764027187, 52.33470378603254, 48.494076592581614, 51.60535485403878, 51.317859240940635, 53.29891572679792, 51.46970517294747, 54.69120618275234, 48.17436565671648, 58.47128677368164, 30.978574684688024, 35.96671077183315, 55.0703832762582, 48.39196586608887, 50.440371240888325, 39.31309175491333, 44.03390632356916, 45.628573485783164, 50.89221954345703, 50.51919507980347, 52.696510383060996, 47.800087043217246, 51.92090729304722, 43.76910352706909, 36.42790787560599, 38.296344484601704, 38.128476006644114, 37.26288332257952, 39.63403599602835, 37.15884447097778, 40.118415764399934, 37.027620792388916, 38.79612840924944, 39.93888126100813, 42.4185335295541, 37.689846651894705, 41.17805773871285, 46.452299799237935, 52.120584624154226, 52.84496906825474, 53.820117473602295, 50.640892778124126, 47.73769916806902, 46.120405197143555, 47.82345036097935, 48.64106573377337, 54.18490137372698, 50.42552294049944, 46.13612897055489, 52.30684150968279, 52.62491961887905, 47.15692009244646, 44.37247814450945, 47.43947901044573, 48.296959672655376, 46.30921901975359, 40.85618243898664, 45.58048152923584, 53.76717914853777, 57.039492334638325, 46.35818297522408, 39.57377774374825, 59.07630811418806, 51.29552425657, 59.0734315599714, 53.60582460675921, 58.64252512795584, 31.046295302254812, 4.457445706639971, 8.747305205890111, 21.110635348728724, 7.015122337000711, 0.6150200154100145, 4.456701380865915, 41.62517431804112, 53.173695291791645, 47.494998591286794, 32.58928871154785, 34.00098548616682, 45.49114506585257, 54.251319204057964, 56.890686239515034, 64.83990832737514, 27.492536646979197, 0.32853672227689196, 0.14896545585777077, 0.13867396595222609, 0.231281972357205, 0.19650447421840259, 0.16994746854262693, 0.16742239546562943, 0.0970585040215935, 0.13715605597410882, 0.10680296578045402, 0.061172510364225934, 0.09406960476189852, 0.09270013110446078, 0.1332202000277383, 0.21987763073827538], [0.01078998583502003, 0.05640732856201274, 0.053948758702192984, 0.054362705775669644, 0.027598658709653785, 0.02220465136425836, 0.04010972147807479, 0.026838789394657527, 0.03805051018883075, 0.1240527576633862, 0.033648263197392225, 0.007358914141410163, 0.06786241781498704, 0.06458815386784927, 0.12848280423453876, 13.957587361335754, 45.11686645235334, 47.75107792445591, 38.84836149215698, 25.37860628536769, 9.240259051322937, 15.856360673904419, 20.39316609927586, 43.266720976148335, 23.91654896736145, 0.6920939396534647, 0.13626180110233171, 5.545798071793147, 18.445438385009766, 3.6206826184477126, 6.2251399500029425, 3.8565337913376943, 5.502536416053772, 27.815308264323644, 61.52973093305315, 49.37279789788382, 54.42456906182425, 44.51112249919346, 51.507833412715364, 47.58241387775966, 50.16423940658569, 49.91619913918631, 54.1080265045166, 49.19230454308646, 47.330242906297954, 48.88783795492989, 50.1664593560355, 41.65514537266323, 36.87558725902012, 36.048411164964946, 37.51131616319929, 40.15316717965262, 48.4507337297712, 43.866760458265034, 44.647446155548096, 42.80913693564278, 48.25828947339739, 47.709670134953086, 44.20599930627005, 44.977350098746165, 47.72155155454363, 48.017708097185405, 48.25123010362898, 48.97864048821585, 49.60460369927542, 42.482519490378245, 35.72408315113613, 35.303894315447124, 35.81647334780012, 34.09898982729231, 34.409605571201865, 34.34182936804635, 34.927246366228374, 36.63745164871216, 41.42375298908779, 41.96307216371809, 45.0684757232666, 42.538754735674175, 46.74228286743164, 42.726116384778706, 47.62215757369995, 44.90422378267561, 47.698848315647666, 43.16668776103428, 49.00567592893328, 44.903139863695415, 53.072439193725586, 29.894450732639857, 33.66854197638375, 52.01581621170044, 44.89198105675833, 44.2447007724217, 39.26099763597761, 45.72790840693882, 47.01669502258301, 47.50080033711025, 46.867534569331575, 46.807147775377544, 46.32606145313808, 47.279719080243794, 44.26963785716465, 40.62369224003383, 35.16386032104492, 35.575589724949424, 35.58000183105469, 35.07253667286464, 35.126037802015034, 36.93104083197457, 34.98939452852522, 37.85164587838309, 36.57415008544922, 33.21456057684762, 37.66557659421648, 44.46242952346802, 47.101511682782856, 48.84485987254551, 46.311220100947786, 48.3022437776838, 49.35561500276838, 49.48930876595633, 47.054593971797395, 45.370503493717735, 47.721443857465474, 48.429927349090576, 45.942381926945274, 46.94258901051113, 46.82016175133841, 49.19149160385132, 47.49413354056222, 38.42894390651158, 36.85784155981881, 35.93158762795584, 39.07127359935215, 36.10019261496407, 41.48448371887207, 48.87624141148159, 51.68951143537249, 36.54742383956909, 35.4041359765189, 56.336876596723286, 49.47545405796596, 52.00027656555176, 49.51558337892805, 55.12887668609619, 45.77453776768276, 9.702751125608172, 1.0717217432601112, 6.989689758845738, 5.141395109040396, 0.33375975915363854, 0.7531199135950634, 25.69156183515276, 34.345508439200266, 27.803049904959543, 33.34951891217913, 20.949188743318828, 27.38052647454398, 39.97783981050764, 45.108292375292095, 45.99437182290213, 17.717899458748953, 0.40803258227450506, 0.045879338668393235, 0.03753374131130321, 0.028438578193475093, 0.03320582104580743, 0.014028122881427407, 0.02354576395425413, 0.029220876483512775, 0.01728612743318081, 0.05912216752767563, 0.08414980276886906, 0.04288417992315122, 0.07433621186230864, 0.028599426615983248, 0.01774660843823637, 0.01744220745084541, 0.020388715235250335, 0.07098687480070762, 0.029294324506606375, 0.02520800002717546, 0.07851173994796616, 0.052390014486653466, 0.02050698219266321, 0.07487979983644825, 0.08011298081172363, 0.06685048461492572, 0.03333113628572651, 0.05365576049579041, 0.03449598074491535, 0.26160901359149386, 19.280585799898418, 54.309982844761436, 52.524010930742534, 45.69070427758353, 28.853092942919048, 16.93729713984898, 26.32528965813773, 23.708203758512223, 48.73186131886074, 27.099871362958634, 0.4202239838029657, 0.2331361100077629, 7.671262877328055, 21.217350993837627, 6.188746588570731, 7.683869515146528, 4.921666579587119, 5.221166942800794, 29.68573726926531, 64.00872312273297, 50.534123284476145, 56.08358349118914, 48.26283706937517, 53.91373402731759, 49.50691202708653, 52.88280200958252, 50.64564534596035, 54.758704457964214, 50.78904226848057, 50.22568580082485, 50.44741671425955, 51.61932420730591, 44.38457495825631, 39.18973691122872, 37.50591393879482, 39.08004570007324, 41.93952819279262, 49.069547244480674, 46.69353083201817, 47.96916103363037, 45.96105521065848, 48.96926736831665, 49.56385251453945, 43.16207415716988, 46.41409512928554, 50.45603595461164, 50.295174734933035, 50.512017590659006, 50.26638487407139, 52.39044223512922, 45.69421311787197, 36.63047913142613, 36.12540415355137, 37.4849442754473, 35.60575532913208, 37.05941227504185, 35.37687471934727, 36.494054726191926, 37.74187476294381, 43.158631324768066, 43.69696385519845, 47.03231109891619, 44.678598403930664, 47.77128676005772, 46.04471846989223, 48.2935585294451, 48.04434749058315, 49.91810294560024, 44.95090178080967, 50.6274619102478, 46.14959110532488, 54.19589342389788, 31.852939469473704, 34.67324454443795, 54.23211785725185, 45.7705078125, 45.41952303477696, 40.87999391555786, 48.03302192687988, 47.72729424067906, 49.457972390311106, 48.744378498622346, 48.87469891139439, 48.780102661677766, 48.42514698845999, 46.120370456150596, 41.57150990622384, 36.206458364214214, 38.15541417258126, 35.29667861121041, 38.303059918539866, 36.99460295268467, 38.60498694011143, 36.372388294764924, 38.725892543792725, 37.70240204674857, 36.2085462978908, 39.46702562059675, 47.52072777066912, 49.289485522678916, 51.6921135357448, 48.38393374851772, 50.31621388026646, 51.31661898749215, 50.04894099916731, 49.588629790714805, 48.928213936941965, 50.04288911819458, 52.10343994413103, 45.47096402304513, 46.92688608169556, 47.556465830121724, 49.848492418016704, 48.743794849940706, 41.00873361315046, 38.55722502299717, 37.45477867126465, 39.15683371680123, 38.58089058739798, 43.68237263815743, 51.89565406526838, 53.07341194152832, 41.44580657141549, 40.688650948660715, 56.90129961286272, 50.30284902027675, 53.140833786555696, 50.73218863351004, 56.21802765982491, 46.918079239981516, 12.125646165439061, 1.0659388878515788, 6.461188929421561, 4.16177944626127, 0.3303820661136082, 0.4865379439932959, 27.610805409295217, 39.93886389051165, 29.473636559077672, 30.719726494380406, 27.349009445735387, 32.63182210922241, 44.89318656921387, 48.86568014962332, 52.98300545556204, 26.213868345533097, 0.35233606664197786, 0.04151073683585439, 0.025740000319534113, 0.017560864565894008, 0.04815796782661762, 0.06418564010943685, 0.031298662668892314, 0.07395163856978927, 0.031160272059163878, 0.0458689129778317, 0.04414526100403496, 0.014987001428380609, 0.02094404525788767, 0.01493214356846043, 0.08126578466700655, 0.04813991879512157, 0.15813683372523102, 0.24827181068914278, 0.09917312448046037, 0.10176523681730032, 0.14890552764492376, 0.18879646568426064, 0.08466502797922917, 0.1912229883351496, 0.17626726228211606, 0.18721184214310987, 0.14473248299743446, 0.25294648270521847, 0.1383232447717871, 0.5136997007897922, 25.730103492736816, 61.7673454284668, 58.155644008091514, 52.04640218189785, 34.52055788040161, 15.133862665721349, 24.946902547563823, 30.0314587865557, 54.54333809443882, 30.33832597732544, 1.0484249762126376, 0.23225949704647064, 8.97330231325967, 24.735418490001134, 8.669686879430499, 11.345710005078997, 13.301216227667672, 9.946208187511989, 30.40121759687151, 66.69121415274483, 51.10756158828735, 57.52666180474417, 49.2519166128976, 55.03470080239432, 50.556486061641145, 53.91391120638166, 52.615741048540386, 55.170333112989155, 52.439048358372276, 52.91795989445278, 53.23097971507481, 54.7475699697222, 46.06720631463187, 40.63730376107352, 39.37465279442923, 42.29652663639614, 44.586225577763145, 52.43408734457833, 48.48988682883126, 49.919659342084614, 47.068306241716655, 52.69309881755284, 50.99780089514596, 43.72887693132673, 47.28282839911324, 50.20330217906407, 50.68053919928414, 51.251378876822336, 53.34638581957136, 53.97868578774588, 47.281879970005576, 38.2792067527771, 37.350336824144634, 39.61721440723964, 37.79441009249006, 37.56102705001831, 37.87124327250889, 38.084650244031636, 39.89004932131086, 45.979231698172434, 45.37597172600882, 48.36933558327811, 44.88496337618147, 50.525608267102925, 48.289618900844026, 50.69996983664376, 49.170136315482004, 51.70002405984061, 47.26424196788243, 53.54323523385184, 48.82998030526297, 57.28455529894148, 34.27996955599104, 38.297063623155864, 55.024691922324045, 48.42606067657471, 48.651474135262625, 44.193603719983784, 50.15617254802159, 52.07165193557739, 50.44506127493722, 50.952488218035015, 50.85103757040841, 50.53690603801182, 51.495434352329795, 46.99158075877598, 44.646348340170725, 37.30216496331351, 39.912363461085725, 39.07140908922468, 39.581524985177175, 39.76575647081648, 40.78139202935355, 39.98105335235596, 40.74780443736485, 39.20841366904122, 37.38090542384556, 41.77868434361049, 49.68852751595633, 51.30470977510725, 53.752699102674214, 48.629205158778596, 51.759413787296836, 53.81398916244507, 52.55800151824951, 53.10998378481184, 50.451338972364155, 52.61593212400164, 53.31578942707607, 46.50709329332624, 48.06501490729195, 48.62800312042236, 52.34314932141985, 50.86552456447056, 42.184723172869, 40.52711575371878, 39.91119268962315, 41.21918760027204, 40.77371426991054, 46.14949035644531, 54.65275485174996, 55.77965191432408, 43.47555603299822, 41.25032942635672, 61.250559261866975, 54.19724832262312, 56.359694480895996, 54.0246376991272, 57.95419488634382, 50.427002906799316, 16.159717287336075, 3.497555762529373, 11.114336729049683, 7.238610710416522, 0.4777188886489187, 0.7217437486563409, 31.85267196382795, 49.42611142567226, 39.401729924338206, 45.2161214692252, 29.484632083347865, 37.18586254119873, 51.84888574055263, 57.02136101041521, 59.10676901681082, 34.577147483825684, 0.6642360059278352, 0.11678807676902839, 0.1322564903114523, 0.11515165386455399, 0.11622821752514158, 0.11789030262402125, 0.13354295199470861, 0.2116020005196333, 0.08787659529064383, 0.13880633456366404, 0.1375018781317132, 0.10612088202365808, 0.11358348479760544, 0.14529521922980035, 0.12242573925427028], [0.04999247545908604, 0.04254615752558623, 0.046468476698334725, 0.020957741487239088, 0.0025769975452151683, 0.031334940543664355, 0.003000871798056843, 0.02133979062948908, 0.030870096558438878, 0.027202641924044917, 0.044792308605143, 0.056731593662074635, 0.06515345496258565, 0.07167660564716373, 1.0506998598575592, 24.255480357578822, 46.81343242100307, 47.814125878470286, 42.28470427649361, 26.32096787861415, 16.765883343560354, 30.74666813441685, 35.03614895684378, 45.76869085856846, 17.77010648591178, 0.011741108726710081, 0.06635056715458632, 0.43907371376241955, 4.009088439600808, 3.6860414998871938, 2.512764994587217, 5.470590335982187, 3.752166203090123, 24.234465530940465, 54.25643655232021, 46.36217818941389, 51.1083710534232, 49.7788645199367, 53.33043622970581, 45.9605028288705, 47.67646469388689, 46.809412888118196, 49.548257282802034, 44.133689403533936, 51.13375282287598, 47.27329199654715, 43.01269136156355, 34.81289986201695, 37.702360357557026, 35.574040276663645, 40.52851928983416, 44.9777044568743, 47.873918601444785, 47.909677505493164, 49.647491455078125, 46.36919239589146, 48.39419971193586, 45.28520393371582, 46.29956102371216, 45.01172283717564, 47.29152059555054, 44.499515533447266, 44.59878444671631, 46.47444370814732, 48.94965260369437, 46.03342069898333, 36.62801946912493, 33.03644003186907, 35.62205580302647, 35.589861324855256, 35.48756647109985, 34.64802605765206, 36.37537949425833, 34.44167845589774, 37.71417924336025, 37.833094188145225, 40.68876211983817, 41.4081369127546, 42.68703971590315, 39.9927784374782, 42.45339959008353, 41.81763594491141, 45.01044436863491, 41.89816904067993, 47.67282731192452, 43.56823805400303, 54.26639679500035, 33.614839349474224, 36.70641599382673, 52.09313576562064, 44.187781129564556, 46.548171043395996, 44.01499332700457, 47.320956638881135, 46.946521690913606, 46.62097774233137, 43.90605252129691, 42.50561530249459, 43.3409867967878, 48.77143130983625, 47.10718141283308, 46.379882199423655, 39.64189788273403, 34.88306277138846, 35.11572667530605, 35.14111539295742, 35.47147791726248, 35.22668940680367, 35.88915845326015, 35.26515810830252, 36.15615340641567, 36.05957344600132, 45.36677578517369, 47.679640020642964, 49.196779182979036, 46.236909117017476, 43.89597068514143, 46.226233209882466, 45.66829286302839, 50.504384994506836, 51.622183391026084, 47.46814727783203, 47.351139613560264, 43.87165199007307, 45.3568502834865, 48.93919209071568, 48.47838756016323, 49.18027721132551, 43.98408773967198, 36.23803097861153, 34.8967159816197, 38.36975915091378, 37.21578843252999, 38.22511502674648, 38.70041349955967, 50.57244259970528, 50.85828801563808, 55.054635184151785, 56.60519518171038, 51.89929492133004, 45.93650027683803, 43.89503615243094, 48.32756648744856, 54.77630771909441, 53.85609177180699, 24.18653859410967, 1.9538277983665466, 6.240567556449345, 5.340140513011387, 0.07857031109077589, 0.0800560177969081, 10.082987819399152, 44.31075382232666, 24.159317289079937, 53.059018748147146, 29.743515014648438, 23.911197117396764, 37.67153467450823, 45.99095678329468, 48.76047052655901, 32.92672102791922, 0.39876363107136314, 0.09012439181762082, 0.033559588848480155, 0.08558076526969671, 0.016844577555145537, 0.022764793896515454, 0.060195209591516426, 0.02777030601698373, 0.06986598923270192, 0.010768572966169034, 0.03603399571563516, 0.037049623538873026, 0.05930615229798215, 0.08252519994441952, 0.02105761505663395, 0.022389925351100307, 0.043794044493032355, 0.010139291108186756, 0.01699887981106128, 0.02022937316048358, 0.0609880302633558, 0.026639235638348118, 0.026635345936353718, 0.07076002697327308, 0.027245545693274056, 0.04094426866088595, 0.016572532510118823, 0.09021991597754614, 0.04500516504049301, 1.3864793734891074, 32.70924241202218, 53.60629708426339, 53.821944849831716, 48.12047890254429, 31.151341642652238, 12.205044099262782, 29.49352925164359, 34.620427812848774, 49.974445887974326, 19.364228214536393, 0.0646241908626897, 0.07749474487666573, 1.9063338211604526, 9.144277504512242, 5.025308949606759, 8.132449558803014, 5.064022575105939, 5.115968610559191, 25.922288928713115, 55.64487770625523, 47.90037039348057, 52.04823998042515, 49.73433698926653, 53.15474755423409, 47.20955964497158, 48.77483940124512, 47.84925249644688, 50.940982001168386, 45.593203680855886, 52.047986371176584, 49.36424813951765, 46.66650928769793, 35.64813239233834, 38.55072150911604, 36.52933420453753, 41.513634886060444, 47.08974838256836, 50.64020490646362, 49.895628997257774, 50.314237117767334, 48.69855860301426, 50.327261516026084, 46.236950806209016, 47.06805610656738, 45.236792360033306, 46.895403793879915, 44.838302748543875, 46.77417509896414, 47.490992954799104, 49.48097092764718, 47.267472880227224, 39.271815981183735, 34.90327855518886, 37.382263796670095, 37.838155950818745, 37.764588424137656, 35.45051520211356, 36.97141681398664, 36.62694944654192, 39.88833311625889, 39.65009675707136, 43.527670996529714, 42.686112131391255, 43.564142090933665, 42.94837883540562, 45.64810139792306, 43.50424861907959, 46.416137899671284, 43.635402815682546, 49.24373163495745, 45.04056133542742, 56.44491066251482, 34.927694525037495, 38.12954602922712, 52.95657798222133, 46.1844710622515, 47.868300982883994, 45.46148320606777, 49.39774540492466, 48.49014391217913, 47.46379770551409, 45.241458075387136, 45.184680870601106, 43.93751743861607, 49.55585513796125, 50.46801812308175, 48.865124293736045, 42.23676865441458, 36.67859888076782, 36.96125854764666, 36.72976541519165, 37.821004322596956, 36.65048994336809, 37.976216656821116, 36.7982816014971, 38.633141040802, 38.21316065107073, 46.757989270346506, 50.42285483224051, 50.52776568276541, 47.487984384809224, 42.694679260253906, 46.28897891725813, 47.49792725699288, 53.97085516793387, 53.56912422180176, 49.79720776421683, 49.79102734157017, 43.23470715114048, 46.31092132840838, 49.36425856181553, 50.7107013293675, 51.36187260491507, 45.111971446446006, 37.95884963444301, 37.038817814418245, 39.66365964072091, 40.88292605536324, 39.7740387235369, 40.75497497831072, 53.41431835719517, 52.83044385910034, 56.09753547395979, 56.59355694907052, 53.69237831660679, 47.260253701891216, 47.182906355176655, 50.38394144603184, 58.044125420706614, 54.39614398138863, 27.74654367991856, 1.9273093470505305, 6.451999502522605, 10.209343416350228, 0.1589353337351765, 0.04845005340342011, 11.11036149093083, 51.7627454485212, 24.838941437857493, 42.636453356061665, 30.299753052847727, 29.4859105518886, 44.01449653080532, 51.27422455378941, 54.55315242494856, 41.904484953199116, 1.4517555279391152, 0.10442379808851651, 0.04345532998974834, 0.043409450844462426, 0.07473118031131369, 0.007477624691091478, 0.0609765358801399, 0.029074896459600756, 0.03462814918852278, 0.024952519718291502, 0.02172313746996224, 0.03180473104917577, 0.016233716226582016, 0.0350568747547056, 0.014509341612990414, 0.16525231833968843, 0.12453888729214668, 0.1183427633451564, 0.09888417712811913, 0.12018442952207156, 0.16760838191424096, 0.10401392222515174, 0.06443636558417763, 0.14914940670132637, 0.15900297010583536, 0.1331813471125705, 0.10656011131192956, 0.15530842835349695, 0.1573159284889698, 2.1743553706577847, 40.85988582883562, 60.0320953641619, 59.89870384761265, 55.685931137629915, 37.17850092479161, 24.53975200653076, 41.85640341894967, 46.31757075445992, 56.54494387762887, 22.55146939413888, 0.22285639947014196, 0.22311192218746456, 1.707246435540063, 7.778304219245911, 11.141970583370753, 9.94011982849666, 13.758007305009023, 7.561443993023463, 27.7676488331386, 57.033332756587434, 47.13247980390276, 54.56612818581717, 48.32124015263149, 54.643593651907786, 47.8616862978254, 49.75238146100725, 47.49897990907942, 52.769160747528076, 48.49482004983084, 55.38898944854736, 51.00273411614554, 47.20334448133196, 38.25439820970808, 41.06620216369629, 38.15212767464774, 44.20742021288191, 47.23037644795009, 51.04270710263933, 52.09142303466797, 52.50845391409737, 50.87345245906285, 52.1956911768232, 47.386995792388916, 48.491974762507844, 46.11471809659685, 47.841623374394004, 46.05870519365583, 44.477065903799875, 47.88886070251465, 52.86612285886492, 49.28807156426566, 42.13919162750244, 36.56890419551304, 38.85983296803066, 39.43141262871878, 38.21460587637765, 37.511312689099995, 40.12054886136736, 38.03677715573992, 42.311753613608225, 39.87839719227382, 45.07835953576224, 44.75661972590855, 47.244123458862305, 44.19768926075527, 46.45334897722517, 44.58221994127546, 48.897513321467805, 44.92429365430559, 51.87291261128017, 47.26244238444737, 57.92889302117484, 37.073746408735005, 40.53576626096453, 54.67187629427229, 49.04804604394095, 50.6430640901838, 48.28800344467163, 51.81520087378365, 51.707687922886436, 49.1067270551409, 46.4872179712568, 45.19611760548183, 45.705649852752686, 52.0239178112575, 53.6298097882952, 50.59373535428728, 43.95616292953491, 38.25539180210659, 38.497310706547324, 38.770183835710796, 39.43007162639073, 38.135354723249165, 40.66271332332066, 39.12976006099156, 41.07747561591012, 40.00791161400931, 49.19237749917166, 52.44056306566511, 54.10462188720703, 48.96770402363369, 43.93284477506365, 47.954587187085835, 48.51801661082676, 53.955457959856304, 55.31280592509678, 50.88671657017299, 50.73311274392264, 43.597840854099815, 47.3547283581325, 50.36765834263393, 52.42123317718506, 53.35971941266741, 47.69049310684204, 40.06384113856724, 40.22761017935616, 42.49883386066982, 42.82658386230469, 42.66727556501116, 43.82123933519636, 55.57594462803432, 57.423710346221924, 58.33991718292236, 59.91836724962507, 55.83715867996216, 49.75181865692139, 47.49823645183018, 53.785824639456614, 61.659620557512554, 58.14630215508597, 29.559231417519705, 4.744506188801356, 9.554957730429512, 9.060481360980443, 0.19528586603701115, 0.13101646756487234, 13.17016885961805, 58.262079988207134, 34.11721495219639, 63.0884759085519, 38.532597133091514, 33.856591497148784, 48.786415100097656, 60.32366956983294, 60.403691973005024, 50.5765837260655, 2.4201661348342896, 0.21471786046666758, 0.16510719326989992, 0.20235481671988964, 0.1604166706757886, 0.13843668225620473, 0.12439331438924585, 0.10010592014129673, 0.14927850477397442, 0.06995944386082036, 0.1395785752683878, 0.10994108846145016, 0.16137557636414254, 0.15977901060666355, 0.1126479682113443], [0.011171498934605291, 0.05382979455004845, 0.04837641539052129, 0.06238965969532728, 0.05149910139984318, 0.031067903087075268, 0.016137723877493824, 0.020793045771175196, 0.07223310614270823, 0.034175345807203224, 0.0650406281596848, 0.0030725940097389476, 0.012879576833386506, 0.02367042440788022, 1.9691008073943002, 34.05018220629011, 52.39728968484061, 40.710892132350374, 36.52102763312203, 23.641652175358363, 27.452369110924856, 39.68452855518886, 28.42801604952131, 48.43072291782924, 9.197736075946263, 0.040648807372365675, 0.0676172970395003, 1.2893260781254088, 3.14978409239224, 6.5956917234829495, 7.83095679964338, 3.526150639568056, 6.950741197381701, 26.936380250113352, 51.59339005606515, 49.11747939246041, 53.61733429772513, 51.472685950142996, 52.13977207456316, 51.34773302078247, 52.46155704770769, 48.68532575879778, 50.33372681481497, 49.4430650302342, 48.365851061684744, 41.93835047313145, 35.561596052987234, 34.69565595899309, 35.77542339052473, 38.077601296561106, 45.59156390598842, 46.51383999415806, 49.1621458871024, 46.353642327444895, 46.48490422112601, 45.77485391071865, 45.10031584330967, 45.026974133082796, 48.46615178244454, 48.908060686928884, 49.287359373910085, 47.37260954720633, 46.37180144446236, 38.382217270987375, 47.529360907418386, 47.23202664511544, 36.502733026232036, 33.342209407261436, 35.15871517998831, 35.37413712910244, 35.438157830919536, 35.819634778159006, 34.70560577937535, 34.90487664086478, 37.789310114724294, 36.4358183997018, 39.73610850742885, 39.34237493787493, 40.31195436205183, 40.12816408702305, 43.59472458703177, 40.82298742021833, 43.52976240430559, 41.14729806355068, 44.049008233206614, 43.09038264410836, 53.5856922013419, 35.96227434703282, 35.054846559252056, 54.24908535821097, 43.46162836892264, 47.0573593548366, 46.443732670375276, 49.732711110796245, 45.27992330278669, 43.53196150915963, 43.427856649671284, 44.84151629039219, 42.374370779309956, 41.71821069717407, 45.185889857155935, 46.59821196964809, 47.3401962007795, 39.52622079849243, 34.56782994951521, 34.794435024261475, 35.509560993739534, 35.926574502672466, 36.39167996815273, 36.89473649433681, 36.3029271534511, 44.60944645745413, 46.86347682135445, 49.24714320046561, 45.36516032900129, 42.94504370008196, 45.69214950289045, 43.79403018951416, 44.916723591940745, 40.961152349199565, 49.29089600699288, 44.72889641353062, 44.14763791220528, 50.420714787074495, 48.97364820752825, 49.1130325453622, 46.24893644877842, 45.13601916176932, 36.74892507280622, 39.267337867191856, 42.40674243654524, 46.97285883767264, 41.37096752439226, 38.442749977111816, 37.37328324999128, 40.34435381208147, 46.108391761779785, 44.810666288648335, 43.44580732073103, 41.78847088132586, 40.43417317526681, 46.67557668685913, 49.79717302322388, 52.53440196173531, 55.5551312991551, 44.278444698878694, 3.765485031264169, 0.7772608324885368, 4.808344066143036, 0.34269109847290175, 0.10650590314928975, 4.849910361426217, 34.916695526668, 39.385769912174766, 84.01904174259731, 43.78813116891043, 19.585272993360245, 28.76724100112915, 46.9645904813494, 46.82130820410592, 39.503489766802105, 6.292147074426923, 0.12068455054291657, 0.06271366695208208, 0.010512080791938518, 0.03432690338896854, 0.04981041433555739, 0.04081320283668382, 0.07530877646058798, 0.013911126480836953, 0.05625673449997391, 0.07438930722751788, 0.04943358991295099, 0.05585370505494731, 0.01784340145864657, 0.04739306547812053, 0.01983869814180902, 0.05498809114630733, 0.056849173602781126, 0.06805370362209422, 0.03724486520513892, 0.05315617212493505, 0.0560196306157325, 0.008543617624257292, 0.06147909962705203, 0.04083232734618442, 0.07076134333120924, 0.01948889807265784, 0.011010975360737314, 0.02878100597964866, 2.528217136859894, 44.548503807612825, 57.66601487568447, 46.67118195125035, 39.92968879427229, 28.433376584734233, 29.895899432046072, 37.146212645939414, 32.697159494672505, 53.47153329849243, 10.39868356500353, 0.16418961036418164, 0.128700871818832, 1.2675566119807107, 4.600864776543208, 6.616771255220685, 10.152547972542898, 5.608828221048627, 8.617760385785784, 29.4115891456604, 50.52368361609322, 49.932746274130686, 54.563626834324424, 52.68950659888131, 52.89950200489589, 51.764180251530235, 53.47833905901228, 50.329578740256174, 52.70137759617397, 51.69620255061558, 49.72519315992083, 43.53033563068935, 37.36598069327218, 36.49572229385376, 38.3722049168178, 39.9742545400347, 47.327936104365754, 49.383279255458284, 50.66571174349104, 47.89894601276943, 49.09216710499355, 47.767527784620015, 45.63682794570923, 44.97849655151367, 48.957024642399375, 48.92275612694876, 50.86805023465838, 49.051516669137136, 46.47091749736241, 39.75356238228934, 48.99889101300921, 49.12535170146397, 38.49753999710083, 35.66225808007376, 37.171511037009104, 36.8324111529759, 35.89879560470581, 36.06307533809117, 37.35695150920323, 37.145451818193706, 39.754802635737825, 38.68344947269985, 42.2286114692688, 40.77045209067208, 44.04131310326712, 41.700847148895264, 44.10321460451399, 41.67321763719831, 44.81556476865496, 43.09730652400425, 46.90174055099487, 45.73104204450335, 53.09843935285296, 36.5185158593314, 36.65914045061384, 55.77323872702462, 45.636431898389546, 47.57758140563965, 49.18652711595808, 50.461577142987935, 47.448452608925955, 44.74884121758597, 44.72564813068935, 45.686021191733225, 44.512564250401084, 42.81257976804461, 47.77922855104719, 48.87110669272286, 46.70589862551008, 41.32493223462786, 35.75740671157837, 36.84000900813511, 37.18862445013863, 37.83126333781651, 38.154142652239116, 38.38861656188965, 37.213530267987935, 46.820748874119346, 48.82644019808088, 51.222040108272004, 46.91529648644583, 42.53073304040091, 45.666736466544016, 45.39098678316389, 44.55144984381539, 43.36596557072231, 49.39682476861136, 46.471918037959504, 45.61835615975516, 50.71676015853882, 50.1029007094247, 51.7458370072501, 49.16317074639456, 47.7171950340271, 38.51833595548357, 39.11862209865025, 44.250867298671174, 47.81706496647426, 43.970073223114014, 40.24906621660505, 37.86722026552473, 42.79074157987322, 47.769421168736045, 48.48390095574515, 45.71360554013933, 44.509531361716135, 42.67685713086809, 48.532750265938894, 52.39235993794033, 54.25478288105556, 55.37943567548479, 46.29790040424892, 4.703242574419294, 0.5198387056589127, 10.98505333491734, 0.9045522106545312, 0.1065405627180423, 5.032564605985369, 40.50116075788225, 38.62904855183193, 75.81470612117222, 48.03345966339111, 23.832361119134085, 32.65921538216727, 52.98323474611555, 52.61905533926827, 48.47785602297102, 9.475411278860909, 0.09186029474117927, 0.06607147213071585, 0.032080243408147774, 0.041801461949944496, 0.06025151442736387, 0.012995261116884649, 0.09251168157373156, 0.015181491617113352, 0.052935780558202944, 0.0365172822826675, 0.05532472254708409, 0.07538555269794804, 0.02721961717387395, 0.046236916445195675, 0.06692158829952989, 0.13092627669019358, 0.1545313021966389, 0.12819220125675201, 0.1631674516413893, 0.09499931308840003, 0.10197044616299016, 0.08608297617839915, 0.2129620425403118, 0.09046334041548626, 0.1976020181817668, 0.10509908970977579, 0.0922688813880086, 0.16381743390645298, 3.341887887035097, 52.95186015537807, 64.38395363943917, 52.39012261799404, 48.01035342897688, 33.1252692767552, 38.13817916597639, 52.50143623352051, 37.066603660583496, 59.729751450674875, 11.760240401540484, 0.4817406471286501, 0.3027931036693709, 3.872439954962049, 6.101012119225093, 13.392912472997393, 15.79338915007455, 11.182706134659902, 10.227754405566625, 29.805517264774867, 50.63950661250523, 51.42258596420288, 55.88251304626465, 53.839530740465435, 56.16842099598476, 54.82018559319632, 56.55455323628017, 52.06020825249808, 55.0475514956883, 51.90720891952515, 53.05334554399763, 45.58473382677351, 37.858667033059255, 39.18534564971924, 40.02741520745413, 42.01070901325771, 49.50609213965279, 51.34484951836722, 52.84754337583269, 49.19189807346889, 49.3012627192906, 48.76404537473406, 46.254974433353965, 47.10687916619437, 51.39000586100987, 51.48931646347046, 52.54958724975586, 51.073897566114155, 46.596551350184846, 40.622920989990234, 50.58272245952061, 50.662578105926514, 39.79265294756208, 38.650268350328716, 39.83984163829258, 38.46689149311611, 37.66120965140206, 39.56564835139683, 38.980679512023926, 38.81543050493513, 43.06270796912057, 40.18968343734741, 44.19411441258022, 43.88214724404471, 44.95547022138323, 44.460984298161094, 48.165148871285574, 44.35994012015206, 47.13084350313459, 45.90505273001534, 48.554307052067344, 46.67335326331002, 56.85892602375576, 39.80597959245954, 38.37379258019583, 57.64051846095494, 46.86572108949934, 49.56958825247628, 50.83594955716814, 53.94174568993704, 48.10260813576834, 45.22711699349539, 45.700932025909424, 46.517202922276084, 45.15592575073242, 45.107392583574565, 47.51898029872349, 50.49991035461426, 49.29540538787842, 43.508410590035574, 38.13957922799246, 38.43056978498186, 39.273667676108225, 39.966097354888916, 40.31832586015974, 40.954951081957134, 40.5699896131243, 50.93951940536499, 51.92313071659633, 53.16937698636736, 49.49157040459769, 42.94250413349697, 47.41099834442139, 45.54513256890433, 46.148496764046804, 44.45564113344465, 50.37364421572004, 47.058978285108296, 46.2494158744812, 53.172441141945974, 53.40044627870832, 53.77623265130179, 50.77719211578369, 50.337030683244976, 40.9975574357169, 43.507854734148296, 46.637479713984895, 50.53102786200387, 45.35104853766305, 42.82896362032209, 40.13047088895525, 45.707980973379954, 51.21071801866804, 51.29836259569441, 47.57263081414359, 46.50082949229649, 44.89404467173985, 52.152191979544504, 54.08378423963274, 57.45965685163225, 58.01929950714111, 50.925459725516184, 7.2890633174351285, 3.625861414841243, 7.852214813232422, 0.8856667897530964, 0.16782752158386366, 6.099546917847224, 48.468642711639404, 51.32063504627773, 90.36200359889439, 54.49219587871006, 30.03382464817592, 39.318421023232595, 58.68469374520438, 57.133741174425396, 57.23354509898594, 11.415881599698748, 0.22017178923955985, 0.1874054010425295, 0.1057878163244043, 0.1267379242926836, 0.13255329509930952, 0.0802211392936962, 0.15782128780015878, 0.14588911379022257, 0.1296298269714628, 0.0870467469628368, 0.17208637376981123, 0.18369841495794909, 0.18910941960556166, 0.1065299707864012], [0.03125384543091059, 0.045111973237778456, 0.012642444111406803, 0.02278424071014992, 0.040868435587201796, 0.0660866102469819, 0.028825134504586458, 0.045608267321118286, 0.026091361019228185, 0.09441248207752194, 0.06137172146035092, 0.03607390036008187, 0.03401552366891077, 0.07798402969326292, 3.713259765080043, 39.11730541501726, 45.64628791809082, 41.16429683140346, 32.712257930210654, 18.02825117111206, 9.959163103784833, 29.23152310507638, 36.117003781454905, 48.91690921783447, 6.2138630236898145, 0.06071880792400666, 0.1547416616231203, 0.7859978122370583, 5.6942146335329324, 3.2398622759750912, 9.510398932865687, 4.3924466116087775, 15.25507572719029, 38.27003860473633, 49.36384514399937, 52.0714886529105, 52.720707484654014, 46.51409707750593, 48.449194703783306, 47.394360882895334, 51.46385826383318, 49.5947824205671, 50.06642614092146, 45.12142447062901, 42.6089072227478, 35.26185423987252, 36.119432176862446, 38.20190109525408, 40.42862851279122, 43.43631260735648, 47.6538587297712, 49.75936440059117, 47.02433109283447, 42.981379304613384, 45.40392085484096, 45.05734123502459, 45.53842755726406, 47.54198578425816, 48.58901677812849, 44.069057260240825, 44.592822892325266, 47.033026763371055, 48.70968266895839, 44.57922874178205, 48.71298653738839, 45.347685609545024, 34.99859741755894, 33.9754821232387, 35.418174811771934, 35.047307763780864, 35.05388075964791, 33.48100314821516, 34.85976546151297, 34.62940835952759, 36.28798157828194, 34.857590675354004, 38.31155409131731, 38.50238289151873, 39.7501334462847, 38.381685733795166, 40.69493906838553, 41.80155086517334, 44.46849530083792, 41.529042516435894, 45.588562284197124, 44.162552220480784, 54.71469109398978, 34.62257828031267, 30.889655113220215, 51.847464833940776, 46.73691190992083, 49.77743666512625, 46.61767387390137, 43.9853766305106, 40.57438782283238, 41.56003148215157, 42.88394818987165, 42.24388360977173, 39.426406451633994, 43.94903407778059, 46.51798112051827, 47.70859316417149, 46.570182936532156, 46.624642917088096, 37.01026766640799, 34.48535483224051, 37.5540406363351, 36.64575127192906, 34.239294801439556, 34.563796520233154, 38.76553201675415, 47.95515693937029, 51.38330084936959, 46.62608119419643, 45.590851715632844, 49.46820708683559, 48.14126443862915, 49.731088706425254, 45.38563667024885, 41.759958948407856, 41.11775432314192, 44.80299547740391, 47.939794472285676, 47.2252174104963, 46.80213117599487, 44.95528262002127, 42.89390843255179, 39.31387342725481, 39.38978597096035, 46.67455530166626, 49.90531478609358, 50.98098278045654, 49.249859946114675, 44.38038519450596, 36.907489912850515, 36.71406943457467, 37.33454704284668, 38.8159099306379, 37.646774768829346, 40.48935924257551, 48.18021603993007, 52.63285446166992, 53.58545248849051, 53.49070685250418, 55.23460047585623, 43.081805092947825, 4.576559977872031, 0.2732214076178414, 12.814997792243958, 4.541100714887891, 0.060810315156621594, 0.8756745745028768, 33.22874185017177, 47.93345076697213, 49.723820890699116, 23.16280143601554, 20.564458302089147, 32.1446978024074, 42.257564612797324, 50.1670812198094, 42.59068557194301, 12.098960740225655, 0.1750124203307288, 0.04404118391019957, 0.09971401188522577, 0.09167431507791791, 0.12728417212409632, 0.041326080315879414, 0.028982045727648904, 0.011137524686221565, 0.09284131388579096, 0.055061586666852236, 0.06220509817025491, 0.10415790057075874, 0.02440010061088417, 0.03352507177208151, 0.011152886719043766, 0.04370033202160682, 0.03914555035797613, 0.045753640056188614, 0.04150587173977068, 0.021324085936482464, 0.06376853106277329, 0.018230062942685824, 0.06516776526612894, 0.07354665494390897, 0.009647416832324649, 0.027912211438108767, 0.03275947053251522, 0.049345387145876884, 5.5273896881512234, 49.78553826468331, 52.00613737106323, 48.481145995003835, 42.15106609889439, 26.120887551988872, 15.362576518739973, 36.14026287623814, 36.05538368225098, 53.967523506709504, 5.8144475647381375, 0.09237941474254642, 0.1634180210530758, 3.777302614280156, 6.326287048203604, 6.329113662242889, 7.322791610445295, 4.617558692182813, 16.732439926692418, 39.37666777202061, 50.793419633592876, 52.81519603729248, 55.718167304992676, 48.598865849631174, 50.632898875645225, 49.2576071875436, 53.30844865526472, 51.336390086582725, 52.967563084193635, 47.63859353746687, 46.564634799957275, 37.036761147635325, 38.781478132520405, 39.52792310714722, 40.9681213923863, 44.53802245003836, 49.586521012442454, 51.50886174610683, 47.82904018674578, 42.93057407651629, 45.66546842030117, 44.49723999840872, 46.470358167375835, 47.98195961543492, 51.09482206617083, 46.06589657919747, 47.86626516069685, 48.312770298549104, 50.79342310769217, 47.05530268805367, 49.10985721860613, 46.50992121015276, 36.93494571958269, 34.52649164199829, 37.561416149139404, 34.819104603358674, 36.84363944189889, 35.42956985746111, 35.79443713596889, 36.36724662780762, 38.20283910206386, 36.78954771586827, 39.525494711739675, 39.642964431217735, 41.44786671229771, 41.292539732796804, 43.77659021105085, 43.56201594216483, 46.210203715733115, 44.11294903073992, 49.08357218333653, 46.55133594785418, 55.37653480257307, 35.033519063677105, 31.781633581433976, 52.826535497392925, 46.27404376438686, 52.22791344778878, 47.94437680925642, 46.3345764705113, 42.33770860944475, 43.44454622268677, 43.47490985052926, 43.14807006290981, 42.28642048154558, 46.07423789160592, 46.74737242289952, 46.98487227303641, 47.838725975581575, 49.78969676154, 36.67658737727574, 36.02494362422398, 38.995361055646626, 38.390499523707796, 36.31535053253174, 35.96685320990426, 41.71795013972691, 48.952831404549734, 52.67090974535261, 47.29063122613089, 44.42778927939278, 50.76745421545846, 49.49168157577515, 49.95120416368757, 45.75369317190987, 41.49708080291748, 43.05688885280064, 45.48091384342739, 49.078680651528494, 48.75165326254708, 48.88885586602347, 46.72157028743199, 45.82664230891636, 40.95284577778408, 40.03536394664219, 47.74574865613665, 53.34288740158081, 51.99028158187866, 51.930325576237266, 45.78468561172485, 38.41961594990322, 38.28438663482666, 38.994141646793906, 41.03576905386788, 41.21512985229492, 42.85103109904698, 50.633645806993755, 54.27041980198452, 55.156242166246685, 55.03265108380999, 57.98376294544765, 47.35059417997088, 5.576248986380441, 1.028550522668021, 13.07294271673475, 9.17813868182046, 0.13436214732272284, 1.0336831786802836, 34.6641389301845, 48.610132353646414, 54.03222860608782, 27.79154542514256, 24.499183212007793, 36.828683444431846, 46.55050563812256, 53.765733923230854, 49.72341442108154, 15.998717103685651, 0.1555412065769945, 0.07311249431222677, 0.03796330486823406, 0.011096050929544228, 0.054629926436713765, 0.09396214517099516, 0.026925565541854928, 0.047068132021065266, 0.05953620281070471, 0.07860316575637885, 0.04856524829353605, 0.058098855295351574, 0.049039276250238927, 0.04983237512143595, 0.13940102979540825, 0.14951904543808528, 0.178283461236528, 0.08780855858432395, 0.10085481924137898, 0.14048843644559383, 0.20831082069448062, 0.10524701034384114, 0.1702535149774381, 0.15285841482026236, 0.1666915996798447, 0.14986344267215046, 0.1254724429122039, 0.1998142594737666, 7.718544500214713, 60.76789569854736, 57.56550918306623, 55.70820358821324, 44.67222343172346, 28.54551008769444, 16.42700059073312, 42.09320150102888, 44.68374701908657, 58.54057421003069, 7.778149621827262, 0.24791126432163374, 0.16715396701225213, 6.624095959322793, 14.795073713575091, 10.197724291256495, 19.930892024721416, 11.52509251662663, 19.026040281568253, 42.91360657555716, 52.71071597508022, 54.44145665849958, 57.18181576047625, 50.76455334254673, 52.25692217690604, 51.594963823046, 56.3404028075082, 54.542361872536794, 54.71564647129604, 49.97727380480085, 47.578272751399446, 39.55316243852888, 40.76199613298689, 42.232895033700125, 44.304608140672954, 48.03995622907366, 50.936034883771626, 54.33778606142317, 47.897827352796284, 43.79621887207031, 46.86908401761736, 47.24973412922451, 47.35773345402309, 50.85886819022042, 52.45697471073696, 48.51846129553658, 48.42634902681623, 50.02119336809431, 52.723170621054514, 48.2395293372018, 52.22808367865426, 48.11556305204119, 37.712674958365305, 37.40549857275826, 39.150184290749685, 39.05009201594761, 38.566969871520996, 36.821436473301475, 39.25618600845337, 38.68057986668178, 40.92675181797573, 38.433418546404155, 42.48489230019705, 43.68509285790579, 43.297539710998535, 43.462423937661306, 45.73416873386928, 45.944768633161274, 47.941757338387625, 46.820099217551096, 49.29735088348389, 49.8015330178397, 56.824383054460796, 38.70710114070347, 34.12345096043178, 53.833312102726524, 48.51885386875698, 53.36432606833321, 48.85154751368931, 48.13768611635481, 44.56301859446934, 42.87350852148873, 44.752937180655344, 44.4980286189488, 41.84768342971802, 48.76114797592163, 47.71892860957554, 49.487453596932546, 49.39722081593105, 51.09483248846871, 39.726617268153596, 37.17997741699219, 42.76082958493914, 40.49478578567505, 37.84660496030535, 36.837361744471956, 43.35796124594552, 51.24177994046892, 55.13711724962507, 48.81929397583008, 47.13912228175572, 52.07822493144444, 52.45149605614798, 51.77687461035592, 46.98622022356306, 42.990846225193565, 43.27800832475935, 46.67970391682216, 50.97007063456944, 51.8153988974435, 50.977974210466655, 49.349872316632954, 46.555466651916504, 42.485819884708945, 42.94582884652274, 50.507796560014995, 54.570352690560476, 54.908326966421946, 54.03120027269636, 48.359111309051514, 41.87480224881853, 40.69072151184082, 41.303500516074045, 42.753262996673584, 41.50780882154192, 44.69210570199149, 52.44919967651367, 58.11118943350655, 57.57663324901036, 58.9499203818185, 58.95028863634382, 49.01545899254935, 6.3268594060625345, 1.806722383413996, 20.5188763822828, 6.294152498245239, 0.2406565307506493, 1.3293883055448532, 43.80379935673305, 58.50395025525774, 56.84000260489327, 31.52827446801322, 28.266315834862844, 43.46787827355521, 54.7301230430603, 60.73070893968855, 58.21504763194493, 21.116367612566265, 0.2485464545232909, 0.1675803041351693, 0.15444531823907579, 0.18045781313308648, 0.21775107484843048, 0.24182355669992311, 0.18063164023416384, 0.1401375931288515, 0.2468090248959405, 0.17159629506724222, 0.14380542774285587, 0.2009062258792775, 0.12296293542853423, 0.16094385167317732], [0.036024126423788924, 0.006331677432172, 0.06078056139605386, 0.031987138225563934, 0.07206568441220693, 0.028545398265123367, 0.03093684744089842, 0.03696533591885652, 0.0788216201056327, 0.032218925787934234, 0.013217013994497913, 0.050591967933412106, 0.05565432432506766, 0.05482194506164108, 8.70173110280718, 46.02949844087873, 42.240517207554404, 40.01034000941685, 25.023688827242168, 16.368811164583477, 25.795725754329137, 30.129299845014298, 40.55742727007185, 43.053789956229075, 2.557184611048017, 0.03979766322299838, 0.16182498367769377, 1.3095958190304893, 3.900640521730695, 4.580388001033238, 8.29510601929256, 6.339900306292942, 28.154772928782872, 41.76848438807896, 48.28444249289376, 50.518010411943706, 50.90375355311802, 47.27483797073364, 46.221498012542725, 39.03186689104353, 43.42000865936279, 43.43028851917812, 41.97878551483154, 38.37209374564034, 35.9354681968689, 37.05264472961426, 39.924019064222065, 44.218773569379536, 46.20131696973528, 46.559291635240825, 47.97823190689087, 49.01782832826887, 44.71399252755301, 45.319799014500205, 49.24740028381348, 47.590074266706196, 50.66663237980434, 44.03091164997646, 47.57232509340559, 41.65957484926496, 44.82097046715872, 43.717217854091096, 47.65329939978463, 45.80603395189558, 48.743204253060476, 39.47350481578282, 34.15150431224278, 35.34281117575509, 34.84456627709525, 33.640547684260774, 34.764172145298545, 34.53536796569824, 36.50347648348127, 34.617099625723704, 36.03011308397566, 33.30627679824829, 35.043225697108674, 35.685423374176025, 38.06460121699742, 38.69334370749337, 40.05104603086199, 39.406472069876536, 43.474215030670166, 39.382299286978586, 44.07867356709072, 44.42403377805437, 54.82439967564174, 34.282908643995015, 28.006277765546525, 48.521414279937744, 40.04132897513253, 44.917744977133616, 39.563970361437114, 44.457635266440256, 42.78665256500244, 44.16728046962193, 42.10068123681204, 46.01364959989275, 46.06338480540684, 47.5776925768171, 42.807990482875276, 51.57624190194266, 47.15929290226528, 48.93039567129952, 42.6715521812439, 33.34761163166591, 33.88079902103969, 35.45312772478376, 33.8406697000776, 35.57030214582171, 40.157554967062815, 50.50301619938442, 41.698498657771516, 41.723126547677175, 50.47598770686558, 47.273656776973176, 45.82016658782959, 46.120773451668875, 45.73272350856236, 45.93327283859253, 41.140999521527974, 46.27974476133074, 49.01100867135184, 47.470662525721956, 44.724081311907085, 42.30445105688912, 37.3565867287772, 39.50300686700003, 46.55051953451974, 46.79550606863839, 47.03887367248535, 47.27507768358503, 48.94433375767299, 44.94076088496617, 39.60393292563302, 39.45654078892299, 42.840028626578196, 42.48061568396432, 45.62823649815151, 51.27857065200806, 49.51716409410749, 54.17011560712542, 50.579314368111746, 46.996507031576975, 48.59504781450544, 48.5081466947283, 8.137605122157506, 0.4113715173942702, 11.462382418768746, 10.896058201789856, 0.3892751330775874, 0.16730171122721263, 22.49822882243565, 45.250125953129356, 37.41043526785714, 36.076221329825266, 17.544295242854528, 25.60782735688346, 39.24147319793701, 43.39915016719273, 47.493643692561555, 14.00488201209477, 0.5843638575502804, 0.058433027006685734, 0.018374297435262373, 0.00681426638038829, 0.042698787192681005, 0.044506278953381946, 0.05309384868347219, 0.04583486409059592, 0.028254832606762648, 0.06133378456745829, 0.025982486682810953, 0.11738290770777635, 0.03471391601487994, 0.017808477261236737, 0.009930047023642277, 0.029810994996556213, 0.05134198322360005, 0.03857006784528494, 0.07427148640687976, 0.032188656340752325, 0.05116157094016671, 0.018086267801533853, 0.07370513358286448, 0.02241218808506216, 0.04821177565359643, 0.051103993851159296, 0.04422546384323921, 0.04566075200481074, 12.848118117877416, 55.81729030609131, 48.081499508449006, 46.89987843377249, 29.197348390306743, 20.898725714002335, 25.47670269012451, 31.756918839045934, 44.81395278658186, 45.801708698272705, 2.572555546249662, 0.10467488997216735, 0.32139052716749056, 3.5199643543788364, 4.895811898367746, 9.189886348588125, 3.7892231174877713, 5.76397020476205, 27.835134949002946, 45.20134612492153, 49.411072049822124, 51.922272614070344, 51.61821944372994, 48.52381835665022, 46.490903990609304, 42.27924646650042, 44.3645259312221, 43.92955132893154, 43.529651233128135, 40.95335994447981, 38.16976567677089, 37.63332653045654, 41.96663658959525, 45.0167498588562, 50.25340216500418, 49.17868954794747, 51.80685608727591, 48.452686173575266, 44.39814479010445, 46.268773555755615, 48.96287849971226, 49.25354596546718, 51.80523715700422, 46.48378208705357, 49.585551738739014, 43.3974791254316, 46.41664859226772, 46.48886122022356, 48.81142861502511, 47.44802182061331, 49.88994189671108, 41.753233092171804, 35.149428912571494, 35.68122318812779, 35.709689957754954, 35.317821979522705, 36.13004207611084, 35.70445796421596, 37.830558095659526, 36.47099365506853, 37.58568620681763, 35.772588525499614, 37.78632238933018, 37.845399447849815, 40.64252533231463, 40.79420798165457, 41.80352415357317, 41.93109655380249, 44.363212721688406, 41.96316596439907, 47.121807370867046, 45.92106832776751, 54.058326039995464, 37.08153533935547, 29.31452281134469, 48.48176438467843, 42.24857711791992, 46.52250787190029, 40.893511635916575, 44.28999260493687, 43.58113738468715, 46.02734449931553, 42.404699666159495, 47.65075288500105, 47.278649057660786, 49.32694673538208, 45.95831067221505, 52.78994975771223, 46.72730949946812, 50.001964228493826, 43.36101497922625, 35.72601127624512, 35.66311270850045, 36.574205671037944, 35.57948766435896, 37.59183536257063, 42.17518677030291, 52.148273195539204, 44.61486952645438, 42.95644221987043, 50.83371223722185, 48.635559286390034, 47.69148669924055, 47.424186025347026, 46.935380254473, 47.56305619648525, 43.27317585263933, 47.718306745801655, 49.67066717147827, 47.82596908296858, 46.27922364643642, 45.064105306352886, 39.0557131086077, 42.22978571483067, 48.00346776417324, 48.309219769069124, 48.7259692464556, 50.08132307870047, 50.87611014502389, 47.96259151186262, 41.91092593329293, 40.837259020124165, 44.235886982509065, 45.21060112544468, 46.59820849554879, 53.953512464250835, 50.83529642650059, 55.86844294411795, 53.031840869358604, 49.63906329018729, 47.7684588432312, 51.435419287000386, 9.30564854826246, 1.2915455933128084, 8.07127674988338, 9.201436860220772, 0.7164110062377793, 0.09492777514138392, 25.316833325794764, 50.1792961529323, 42.3472067969186, 37.165869099753245, 22.424303463527135, 29.40065962927682, 43.60027967180525, 48.41857051849365, 54.486039774758474, 20.468192747661046, 0.6259722762874195, 0.04526626192299383, 0.029940683394670486, 0.033145478926599026, 0.062207283053014956, 0.009776619229731815, 0.1062019940997873, 0.06259720320148127, 0.024098157616598264, 0.0135320824005508, 0.036792652149285586, 0.05631935310416988, 0.06385223514267377, 0.005130150521706257, 0.1040885407211525, 0.06710164435207844, 0.1218963869448219, 0.13779352605342865, 0.14206377762768949, 0.12210274301469326, 0.0975376447396619, 0.07179992260145289, 0.16488004688705715, 0.17636009944336756, 0.24704303805317196, 0.12439832197768347, 0.12965235433408193, 0.14153028625462735, 15.952796459197998, 66.48051697867257, 52.396438530513215, 55.09263488224575, 32.67683253969465, 25.034713881356375, 36.005808285304475, 42.91974878311157, 50.180585043770925, 52.72506053107125, 3.234892359801701, 0.20083811453410558, 0.41660405376127785, 5.235320857592991, 13.976649744170052, 14.15697113105229, 15.396853719438825, 10.948769841875349, 31.749894210270472, 46.50438696997506, 50.15409503664289, 53.6131341116769, 54.7478791645595, 51.468002864292686, 51.24662978308541, 43.00806386130196, 46.799730573381694, 45.921384470803396, 46.53988879067557, 42.632062094552175, 38.25825793402535, 39.393180165972026, 43.637570653642925, 46.92916161673409, 51.694156306130544, 51.23715591430664, 54.21930537905012, 50.647879191807334, 45.186119147709434, 46.94748749051775, 52.39576802934919, 51.1770053591047, 54.30728694370815, 47.83704103742327, 51.41034671238491, 45.493302481515066, 48.30204227992466, 47.396195207323345, 51.41987269265311, 48.82685708999634, 53.37357759475708, 44.946805817740305, 37.36495930807931, 39.347645146506174, 37.857440676007954, 36.77234397615705, 37.22517544882638, 38.432963439396445, 40.35833011354719, 38.50914001464844, 39.44099766867501, 38.19717979431152, 39.32338203702654, 39.6807348387582, 42.82241494315011, 42.697371687207905, 44.57139464787075, 44.230853012629915, 46.1719399860927, 43.62586293901716, 49.63695451191494, 48.00552095685686, 57.54655449731009, 39.65228543962751, 31.7936817577907, 48.01657554081508, 42.559293610709055, 46.38232101712908, 43.78168324061802, 46.66336522783552, 43.978442328316824, 45.88751547677176, 44.6424469266619, 49.06594112941197, 49.348680700574604, 50.81030723026821, 47.74401160648891, 51.656073229653494, 47.69576678957258, 52.92012078421456, 45.178403173174175, 36.699016162327354, 38.025343894958496, 38.34592335564749, 37.00927059991019, 40.622768129621235, 44.84581722532, 53.27101870945522, 46.62817260197231, 45.169631072453086, 52.339303493499756, 50.74130467006138, 49.729521887642996, 49.30428171157837, 49.12836027145386, 49.089693546295166, 44.00302505493164, 48.65888091496059, 51.6669019971575, 51.38165760040283, 48.51370872770037, 47.29388645717076, 41.97129535675049, 44.431478772844585, 50.49456718989781, 50.89544350760323, 51.18410989216396, 51.92356497900826, 52.975418022700715, 49.298549447740825, 44.789811270577566, 44.096172605242046, 46.71855476924351, 47.548114095415386, 50.71927193232945, 56.96711294991629, 52.510430676596506, 57.974528789520264, 54.364984784807476, 50.492969104221885, 50.440954889569966, 53.828503949301584, 10.545502475329808, 1.7786246282713754, 20.96422985621861, 15.467638492584229, 0.9060148064579282, 0.20022957718798093, 29.289630889892578, 57.179609707423616, 46.60557011195591, 46.00875111988613, 27.230299472808838, 34.66629981994629, 50.84068475450788, 56.47164038249424, 64.00721536363874, 27.39360124724252, 0.9500814761434282, 0.17083856144121715, 0.13076971151999064, 0.1348026522568294, 0.18079885840415955, 0.1297991621707167, 0.22141977798725876, 0.23818289062806539, 0.06887139938771725, 0.1224218173218625, 0.22613361504461083, 0.16010164043733052, 0.13776248986167566, 0.0618930399151785], [0.01703238587028214, 0.07183486715491329, 0.045986567557390244, 0.06604651561272995, 0.03046538434656603, 0.04987384718177574, 0.036350199819675515, 0.020719087150480067, 0.06179797715906586, 0.05007367913744279, 0.051475993889783106, 0.035029444976576736, 0.03499327566740768, 0.10210039240441152, 11.829793606485639, 48.92555972508022, 46.10491418838501, 45.418029172079905, 31.280199459620885, 13.964261106082372, 29.718612670898438, 35.223701681409565, 42.552605969565256, 38.201571055821006, 0.35615309753588265, 0.03184410982898303, 0.2548673339188099, 2.8705266543797086, 4.183108244623456, 5.070119619369507, 1.8321368311132704, 8.337092246328082, 38.95978627886091, 49.35204015459333, 56.91078737803868, 51.59269871030535, 54.46263476780483, 47.75049080167498, 49.863465785980225, 42.582128865378245, 38.66279942648751, 36.72474186761038, 36.09505442210606, 35.790375913892476, 38.25246313640049, 42.811419418879915, 46.06432628631592, 46.72587817055838, 48.40667520250593, 50.02942698342459, 47.272291455950054, 50.879240308489116, 44.51848064150129, 45.80852140699114, 47.91665349687849, 43.437907218933105, 46.38417966025216, 43.68253244672503, 43.490772587912424, 39.073684624263215, 39.51724025181362, 43.039768491472515, 45.6605977330889, 44.75722769328526, 43.45908185413906, 33.88967534473964, 34.04003436224801, 34.13840348379952, 35.462778772626606, 34.0196726662772, 34.107254709516255, 33.35377468381609, 35.44022839409964, 33.13905450275966, 33.830945696149556, 33.19533838544573, 35.969288553510395, 34.38380690983364, 38.51464646203177, 36.64667190824236, 38.64721114294869, 37.295258453914094, 39.991958550044465, 40.05025046212332, 45.251678875514436, 43.340844358716694, 50.59151887893677, 37.06437676293509, 23.950718470982142, 45.36957243510655, 38.81989472252982, 45.435556003025596, 44.23100239889962, 49.007301807403564, 45.36272498539516, 48.67046703611101, 48.5772465297154, 48.07771621431623, 44.28654282433646, 46.49926962171282, 45.36613655090332, 42.83312211717878, 50.297703879220144, 48.582846777779714, 47.69857733590262, 35.952977657318115, 34.464676993233816, 36.70821557726179, 34.900787625994, 33.72254684993199, 39.82388162612915, 50.15375110081264, 42.62508610316685, 46.587831360953196, 46.022348744528635, 44.784065110342844, 43.854507310049875, 43.700462273189, 47.574954986572266, 46.82399715696062, 42.82566670009068, 47.33891078404018, 45.705055781773154, 44.39737354006086, 43.937830107552664, 39.323764187949045, 40.12227896281651, 46.82726975849697, 46.14229897090367, 48.933452878679546, 47.958926337105886, 47.737567152295796, 50.308449268341064, 46.71468462262835, 42.19460003716605, 41.23696804046631, 44.66576508113316, 49.2036509513855, 52.814966746738975, 51.126342569078716, 51.21149274281093, 57.16292360850743, 50.71774680273873, 52.354214327675955, 31.96451711654663, 31.063401767185756, 10.71706565788814, 1.190436493073191, 7.418432695525033, 26.432819979531423, 7.411245652607509, 0.6363158641116959, 16.01655486651829, 41.644518102918354, 41.544300760541645, 29.7671388898577, 20.448400803974696, 26.04275505883353, 41.55783237729754, 44.193475178309846, 48.12550939832415, 27.493669203349523, 0.34736045077443123, 0.05030051000150187, 0.061875934047358375, 0.0333254705183208, 0.0483934262634388, 0.007334639551118016, 0.019778512085654905, 0.07011543227625744, 0.05938007190291371, 0.02062754599111421, 0.044685870209442716, 0.026612905086949468, 0.06973442807793617, 0.022199916886165738, 0.04599759035876819, 0.07377137217138495, 0.016389436620686735, 0.02476576991778399, 0.10630906014037983, 0.027902930775391202, 0.024329471900793057, 0.033818256575614214, 0.0607721068497215, 0.021214938489720225, 0.09530090833348887, 0.07006457607660975, 0.05718629354877131, 0.1522601233529193, 17.60291372026716, 58.62230587005615, 49.5661176272801, 49.860498905181885, 35.9698235648019, 18.851239238466533, 27.815768582480295, 34.222796303885325, 48.73062106541225, 40.52881458827427, 0.36452608395900044, 0.040120486436145644, 0.5730730348399707, 4.292516316686358, 8.568282263619558, 8.461901000567845, 5.1498497639383585, 11.30340850353241, 36.02454062870571, 52.267493861062185, 56.071688175201416, 53.929485593523296, 54.67896345683506, 51.4967371395656, 50.63442053113665, 44.38769817352295, 40.2996004649571, 39.64004271371024, 37.755600929260254, 37.08416870662144, 40.27802630833217, 43.55493572780064, 47.64038617270333, 48.80329922267369, 50.082222870418, 51.57062428338187, 47.8550056048802, 50.141900948115754, 45.63281536102295, 47.57160595485142, 49.369858809879844, 46.27449887139456, 48.53395577839443, 44.163403374808176, 45.0116776738848, 41.19905172075544, 40.070612158094136, 45.66441229411534, 46.83968618937901, 45.64595440455845, 45.18397215434483, 36.12782907485962, 35.1595732825143, 36.695166860307964, 35.54980843407767, 37.36230509621756, 35.58520950589861, 36.47241456168038, 37.37951578412737, 35.41482925415039, 36.28764111655099, 35.19441849844796, 37.23748418263027, 36.690330914088655, 40.74639742715018, 38.51288161958967, 41.66714838572911, 39.04659012385777, 40.782632282802034, 41.35262080601284, 46.66170113427298, 44.34181921822684, 51.8241605758667, 38.95455081122262, 24.435796533312114, 45.22876024246216, 39.018366541181294, 45.34414897646223, 45.50580923897879, 49.03280864443098, 46.73258318219866, 50.0271966116769, 50.13622774396624, 50.0370317867824, 47.76513760430472, 48.806120191301616, 46.264990261622835, 45.72426060267857, 50.193251609802246, 48.706844329833984, 49.63831288473946, 37.96453326089041, 36.54088905879429, 38.46768706185477, 36.104920864105225, 35.79981851577759, 42.004271507263184, 52.322280406951904, 45.69715567997524, 50.56809650148664, 48.2902581351144, 47.182673590523855, 45.19599253790719, 45.68639292035784, 49.53861665725708, 48.5998455456325, 43.516404492514475, 48.20933246612549, 46.97512742451259, 47.52141564232962, 45.54004301343645, 41.126807825905935, 42.67528336388724, 48.04956211362566, 48.415555000305176, 51.30935117176601, 49.73017154421125, 49.04680231639317, 51.24030344826834, 49.03268010275704, 44.037352630070274, 43.90940850121634, 46.48378208705357, 51.63388415745327, 53.15483440671648, 52.833501066480366, 53.64641945702689, 59.9383989061628, 49.10325642994472, 52.73546198436192, 31.97488730294364, 33.01945516041347, 10.939412355422974, 1.2361571597201484, 6.413531235286167, 23.351269585745676, 10.658071109226771, 0.5785350246088845, 16.54265683037894, 46.98468467167446, 44.95578983851841, 30.54682752064296, 20.531952892030986, 29.73249864578247, 47.75398227146694, 49.12977422986712, 53.46578366415841, 34.58748640332903, 0.4272312420819487, 0.08557316567748785, 0.0138565697208313, 0.01527436270511576, 0.031142684431480508, 0.007892297797038086, 0.036516512145421336, 0.03993326166112508, 0.059468064324132035, 0.02445923663409693, 0.038017719984054565, 0.017316547854404365, 0.04558221157640219, 0.05925596784800291, 0.08896854134010417, 0.12049772271088191, 0.1173120957932302, 0.1492966352296727, 0.31283897746886524, 0.15001923431243214, 0.13954614129449638, 0.13787843792566232, 0.18864996997373445, 0.09127408119716815, 0.23981275888425962, 0.14531987719237804, 0.10551906217421804, 0.24718819026436123, 24.410965408597672, 66.97251197269985, 57.31701380865914, 57.40452984401158, 40.2559484073094, 22.06185415812901, 39.40419653483799, 45.60714871542794, 53.28549875531878, 46.322205202920095, 0.4652545803359577, 0.22055589434291634, 1.0860618480614253, 9.323985712868826, 8.702409420694623, 11.10936963558197, 8.034047433308192, 11.473511695861816, 41.28434433255877, 51.830743994031636, 59.111042158944265, 54.99846247264317, 58.194335051945274, 52.26570469992501, 52.97171115875244, 47.60055562428066, 41.96781778335571, 40.07326636995588, 39.18707227706909, 39.463617529187886, 41.322038309914724, 46.644657203129356, 51.87494495936802, 50.408805574689595, 52.19906105313982, 54.05377844401768, 48.9785293170384, 50.48174776349749, 43.997258050101145, 49.366867610386436, 51.705620833805625, 49.190442425864084, 49.52708264759609, 47.89422123772757, 46.99355404717581, 41.92980418886457, 42.32169648579189, 48.6647868837629, 49.286185128348215, 48.94681773866926, 48.13326358795166, 37.68749121257237, 37.616623061043875, 38.70125770568848, 37.82456180027553, 38.24873890195574, 36.78976658412388, 38.00132049833025, 38.71854134968349, 36.432208810533794, 38.837122780936106, 38.26584536688668, 39.78788995742798, 38.947758947099956, 43.745549133845735, 41.62985045569283, 43.48360552106585, 41.65773357663836, 43.077507632119314, 42.31772559029715, 49.74215718678066, 47.21362086704799, 54.53084870747158, 40.2578661101205, 27.794086728777202, 45.70470142364502, 39.96966872896467, 45.539890153067454, 47.16830471583775, 49.47833061218262, 48.56026860645839, 51.574609075273784, 53.45817538670131, 53.112304483141216, 48.41993931361607, 50.843078408922466, 49.59553977421352, 47.01841122763497, 49.217745372227256, 51.17325333186558, 53.3290570122855, 40.091140610831125, 38.59579447337559, 40.75227212905884, 38.92490284783499, 37.713102272578645, 43.65830407823835, 54.966723101479666, 46.55111360549927, 50.7000149999346, 50.11714799063546, 48.906757899693076, 48.96160697937012, 46.968130588531494, 53.44401495797293, 50.342912333352224, 43.728939465114046, 50.21106679098946, 48.83681385857718, 48.539285046713694, 47.67477628162929, 42.557507923671174, 44.76979003633772, 51.005878176007954, 50.29964937482561, 53.86365488597325, 51.14913266045706, 50.82715661185128, 56.30038465772356, 50.892306395939414, 45.52089377811977, 45.55981411252703, 50.101365157536094, 54.248713629586355, 56.81327288491385, 54.82508059910366, 54.5824738230024, 60.184955733163015, 50.20909002849034, 54.304796014513286, 36.84914588928223, 36.84204830442156, 14.201947689056396, 3.7211316398211887, 13.37838465826852, 36.47903619493757, 8.348444734300886, 0.5983682232243674, 19.50114941596985, 54.24957868031093, 51.905510084969656, 39.38623891557966, 30.789601053510392, 39.092309270586284, 54.333488600594656, 57.73114728927612, 60.21719537462507, 41.641259397779194, 0.6717285524521555, 0.1172930153885058, 0.13726774283817836, 0.1955703486289297, 0.19791920616158418, 0.15973519081515924, 0.11741307537470545, 0.11021150502243213, 0.17296044901013374, 0.10873396787792444, 0.17896955513528415, 0.08389412398849215, 0.16763940453529358, 0.12673572583922318], [0.08370367277945791, 0.05930685118905135, 0.02498851769736835, 0.007192189605640513, 0.0034827544337271577, 0.08549520878919534, 0.014414670710851039, 0.04483525647914835, 0.0388353071840746, 0.03858332981222442, 0.0921516033953854, 0.031091930012085607, 0.016270581034145186, 0.1935375119958605, 20.77361297607422, 48.766793387276785, 43.888539586748394, 39.85158061981201, 22.164732660566056, 13.519465225083486, 31.465806688581193, 30.367327758244105, 50.65987525667463, 25.828823498317174, 0.15034977586141654, 0.045305803551205566, 0.18331383488007955, 2.98507530774389, 4.067787689822061, 11.936960015978132, 2.226774100746427, 19.84976659502302, 53.770476068769185, 54.94828258241926, 49.975105966840474, 53.501848288944785, 49.0523921421596, 51.568393911634175, 48.47051872525896, 50.249813420431956, 41.76217542375837, 40.120149339948384, 37.18009206226894, 37.9493271282741, 35.72052219935826, 42.45461205073765, 48.0750481060573, 46.58073377609253, 50.38713761738369, 49.048660959516255, 47.69804927280971, 43.63471146992275, 44.249977929251536, 46.73238863263811, 46.34282398223877, 44.73401723589216, 41.78411783490862, 37.70632083075387, 36.33698027474539, 37.550285134996685, 35.1226818220956, 36.43310860225132, 38.044479233878, 39.410783427102224, 33.566219329833984, 32.732136726379395, 35.62614481789725, 33.60619926452637, 34.565460613795686, 35.887393610818044, 35.37611041750227, 33.90806722640991, 34.42140013831002, 34.50838811056954, 34.52557795388358, 33.845609869275776, 35.55066653660366, 33.5179397719247, 35.89395618438721, 34.69012171881539, 35.56872837884085, 34.20678765433175, 37.919404711042134, 35.912740639277864, 43.005812644958496, 43.620068141392295, 53.24788120814732, 38.469983441489084, 26.750130312783376, 45.61470488139561, 42.495328494480674, 50.88599395751953, 46.682768072400776, 47.72387225287301, 45.856932980673655, 47.64659786224365, 44.40085458755493, 46.14180217470442, 46.46163122994559, 44.49270282472883, 46.37093986783709, 45.40099913733346, 43.77267142704555, 51.25995295388358, 44.90212542670113, 40.49288545336042, 32.729082993098665, 36.563324792044504, 35.2601762499128, 35.58338907786778, 35.01496042524065, 48.43222720282418, 49.845004422324045, 48.49365970066616, 47.86656740733555, 40.4620806149074, 38.0222623688834, 44.204005173274446, 46.70914690835135, 49.296207904815674, 44.01237733023507, 48.60470928464617, 46.54728167397635, 45.61197076525007, 40.107819761548726, 44.268446241106304, 46.69131088256836, 47.90038776397705, 47.656092575618196, 46.75525515420096, 42.594983032771516, 46.83750098092215, 48.67305524008614, 46.63258818217686, 44.97244814464024, 45.83709934779576, 50.15596757616316, 49.39343752179827, 50.61291585649763, 53.03882033484322, 45.83332300186157, 49.51306118283953, 47.52741888591221, 48.55374077388218, 33.68930319377354, 23.351476294653757, 10.881566865103585, 0.5160829871892929, 4.84643235376903, 7.090649255684443, 3.1887936677251543, 0.13648664046611103, 5.516597832952227, 42.76446001870291, 40.09184237888881, 39.80694191796439, 23.20540257862636, 27.317671333040508, 37.39668130874634, 40.20656755992344, 45.77572938374111, 35.76051255634853, 0.7879887425473758, 0.054958486663443704, 0.03511824146179216, 0.020853586361876557, 0.024931564860578095, 0.08517175793115582, 0.04940011778048106, 0.02185893607591944, 0.08920190988906793, 0.05886851756700447, 0.033067260802324326, 0.013860137966860617, 0.01181282224466226, 0.03573111464668598, 0.015362495922350457, 0.10077462318752493, 0.033831705139683824, 0.016756179709253565, 0.030696154106408358, 0.01310703279783151, 0.05393461124705417, 0.03387578616717032, 0.020313348654391508, 0.052899998013994524, 0.06595032648848635, 0.054466684481927326, 0.06779138876923493, 0.1931264961936644, 27.54217110361372, 56.21122189930507, 50.822171279362266, 44.96958896092006, 27.461914198739187, 16.69915979249137, 29.17115715571812, 35.27835621152605, 51.99795586722237, 29.579238755362375, 0.10755820239761046, 0.014112747224446918, 0.6715267832790102, 3.6234610293592726, 5.608409592083522, 12.163151672908239, 4.074735019888196, 19.230016810553415, 57.15981428963797, 57.67137541089739, 52.378911699567524, 53.681514808109824, 52.32954127447945, 52.013050828661235, 50.67968804495675, 50.958911827632356, 42.996741771698, 41.13985654285976, 38.77289710726057, 38.187594754355295, 36.75615119934082, 43.31099489756993, 50.78848988669259, 49.851580892290386, 50.925786290849956, 51.52777821677071, 47.87237957545689, 45.988469328199116, 43.968780858176096, 46.735160963875906, 48.60451820918492, 45.71364722933088, 43.65893636431013, 39.80854000364031, 38.72115387235369, 38.32282754353115, 35.885687828063965, 38.353986740112305, 41.80016122545515, 42.11322620936802, 35.635438033512656, 35.92181151253836, 37.553328445979524, 35.82720831462315, 36.81521783556257, 37.74067619868687, 36.1994754246303, 35.60660648345947, 36.543088163648335, 36.11851154054914, 34.730251039777485, 35.47433362688337, 36.6497152192252, 35.7834346635001, 38.68589176450457, 36.37533780506679, 36.755220140729634, 35.97441284997122, 38.90459326335362, 37.47475126811436, 43.25407872881208, 45.47894402912685, 55.14988456453596, 40.11273561205183, 28.778802803584508, 46.8157114301409, 43.49621302740914, 51.384277071271626, 48.354292733328684, 49.301790782383506, 47.721245833805625, 48.97387749808175, 46.62373270307268, 47.84566375187465, 46.53899942125593, 47.138295446123394, 46.92294297899519, 45.23335647583008, 46.40213033131191, 52.78044809613909, 48.34370367867606, 40.76205171857561, 34.64754663194929, 38.053289549691335, 36.361205169132774, 35.86934219087873, 37.43608801705496, 50.50721985953194, 49.97113159724644, 49.43824298041207, 47.676148550851, 42.21604912621634, 39.82808876037598, 46.016626902988975, 48.502212933131624, 49.72556488854544, 45.000237464904785, 49.35123068945748, 49.064926692417686, 48.427936690194265, 42.47629043034145, 46.74047633579799, 49.55998236792428, 50.717229161943706, 50.312951701028005, 48.37860100609915, 43.102764333997456, 46.93338959557669, 50.04951422555106, 47.90345886775425, 46.57869100570679, 48.01125322069441, 52.167564868927, 52.25439650671822, 52.66783169337681, 54.403967653002056, 47.206974915095735, 49.669503348214285, 48.92706748417446, 51.05205242974417, 36.88608946119036, 22.6095598084586, 12.117147650037493, 0.6264138668775558, 5.233146505696433, 7.0539640699114114, 4.663606141294752, 0.1778645608574152, 6.242685454232352, 46.68362964902605, 44.50413955960955, 43.08934041431972, 29.475700174059185, 35.8189503805978, 42.675863538469585, 45.462098121643066, 54.30179786682129, 42.232724802834646, 1.0817235665661948, 0.10706720088741609, 0.037227565954838476, 0.022075080013434802, 0.047526373860559294, 0.011844578531703778, 0.045747224507587295, 0.04370888834819198, 0.11007351135568959, 0.08135523593851499, 0.058205337795828066, 0.017903633315914443, 0.06254684911774737, 0.025147735939494202, 0.13221710813896997, 0.20546560122498445, 0.11379113008401223, 0.10006271781665937, 0.1024097500901137, 0.21281108206936292, 0.18080016119139536, 0.13346979234899792, 0.11925012751349381, 0.1278512374098812, 0.17708843893238477, 0.14366013982466289, 0.09917747388992991, 0.45636653155088425, 35.009328910282676, 64.34291063036237, 58.485301290239605, 51.83349895477295, 30.688789640154155, 21.625934600830078, 42.924939087459016, 41.61999443599156, 58.69303158351353, 32.05071299416678, 0.3278540889067309, 0.14733095999274934, 1.7855999682630812, 8.398677604539053, 10.553967118263245, 24.14003951208932, 4.233695472989764, 22.28568169048854, 56.411281381334575, 60.27290603092739, 54.261397566114155, 57.54007877622332, 52.84748779024397, 53.68901538848877, 51.62599100385393, 53.9805131639753, 45.320049149649485, 43.77561746324812, 40.60338960375105, 41.545089381081716, 37.75012574877058, 45.56527887071882, 50.71241406032017, 52.34994465964181, 53.23632982798985, 53.32815374646868, 50.394544397081646, 47.440597670418875, 45.12192474092756, 50.01032985959734, 50.07689707619803, 48.294093540736604, 43.795284339359824, 41.204627650124685, 39.393795081547324, 40.60248286383492, 37.89622899464199, 39.728229250226704, 43.06024830681937, 43.272877080099924, 36.75672789982387, 38.73704092843192, 39.95776299067906, 37.72887120928083, 37.01463460922241, 39.706877435956685, 38.56802599770682, 37.91288382666451, 38.98304884774344, 38.25743109839303, 38.0454033442906, 38.8489590372358, 39.66021680831909, 37.72369132723127, 40.532795906066895, 40.387095655713765, 39.75377777644566, 38.90438134329659, 41.18151446751186, 39.051999296460835, 44.73870379584176, 47.27278825214931, 55.20601558685303, 42.15364735467093, 30.103480339050293, 46.23290695462908, 44.01241554532732, 53.564156259809224, 50.75265455245972, 51.48911496571132, 49.281588894980295, 51.61383165631975, 47.996397972106934, 51.00138963971819, 48.391465595790315, 49.10633795601981, 48.97674363000052, 46.825286047799246, 48.08468178340367, 52.98851537704468, 50.35403987339565, 42.93038994925362, 35.4142872946603, 40.304961000170024, 39.51286636080061, 37.90625524520874, 38.793550627572195, 52.21617794036865, 52.29563406535557, 52.703670501708984, 51.635690689086914, 43.852276938302175, 42.038863113948274, 50.417595045907156, 50.967228821345735, 50.87306335994175, 44.905797549656455, 51.00136532102312, 51.463142599378315, 50.6708916255406, 45.62492915562221, 50.51481424059187, 51.04693855558123, 53.7147341455732, 51.730686460222515, 49.52929217474801, 43.87374339784895, 47.84737648282732, 51.5850487436567, 50.19640261786324, 48.84213270459856, 51.29799434116909, 55.62043741771153, 54.20089612688337, 55.356628213609966, 56.78022377831595, 46.8589049066816, 50.583969661167686, 49.02342510223389, 53.044215611049104, 39.5712103843689, 25.626660449164255, 14.53765250955309, 3.459844631808145, 8.62769717829568, 8.33710787977491, 4.878796194280897, 0.23160234945161, 7.590413638523646, 51.497202668871196, 52.621497631073, 52.70756149291992, 32.63419839314052, 36.84621722357613, 48.03731591360909, 52.048253876822336, 60.70140143803188, 52.456474440438406, 2.094140806368419, 0.23652859511119978, 0.08714258324887071, 0.11073445874665465, 0.10918347697172846, 0.16032536700367928, 0.1333537357194083, 0.08200694168252604, 0.22644648754170962, 0.10361397332910981, 0.11606312995510441, 0.12475683274013655, 0.1093023834483964, 0.08090318233839103], [0.022510285589045713, 0.025441171800983802, 0.03641502705535718, 0.05090226539011512, 0.046085158695599863, 0.06842725072056055, 0.03876292785363538, 0.05708747170865536, 0.06276123225688934, 0.053942611174924035, 0.040401959725256474, 0.052293045047138415, 0.04840090371934431, 1.1264403270823615, 27.5666252885546, 45.32073702130999, 39.48906183242798, 33.19978175844465, 18.085483482905797, 17.710150480270386, 27.484853676387242, 32.01378331865583, 51.41873318808419, 18.435248851776123, 0.0766713290608355, 0.03852709622255393, 1.1799593695572443, 2.2731166311672757, 8.713500482695443, 9.069698146411351, 10.175995537212916, 43.76785632542202, 51.38646922792707, 52.34459107262747, 51.351293972560335, 50.07265172685896, 48.932817118508474, 50.68561485835484, 51.070114271981375, 49.110017027173726, 41.45488439287458, 36.45744119371687, 35.81021302086966, 35.09510442188808, 35.65864154270717, 40.158788272312705, 44.90572459357125, 47.06534283501761, 47.35858808244978, 47.72239228657314, 46.70364393506731, 48.99107081549508, 46.01155471801758, 43.60032483509609, 48.15369476590838, 45.3858242716108, 44.03746380124773, 40.00802973338536, 37.50019557135445, 33.811685289655415, 34.77595976420811, 35.153441497257774, 34.92373057774135, 32.56329550061907, 35.13184649603707, 34.73531975064959, 33.616298471178325, 34.60859503064837, 34.81653029578072, 34.41338539123535, 35.19339711325509, 33.37346587862287, 33.84015900748116, 32.85421657562256, 35.47235686438424, 34.59752655029297, 36.71647351128714, 34.890778745923726, 35.607551438467844, 35.27413518088204, 35.72873844419207, 35.56203031539917, 38.93350124359131, 39.771902152470176, 41.392295019967214, 42.3028564453125, 50.09868662697928, 40.330610275268555, 25.389212710516794, 51.54467970984322, 45.22336496625628, 45.81864840643746, 46.60286726270403, 46.27094834191458, 43.52046571459089, 45.582955087934224, 43.43350206102644, 44.38186863490513, 45.37863983426775, 46.2255870274135, 45.87283393314907, 46.31694541658674, 41.78485434395926, 48.286315032414024, 45.44624580655779, 38.48360538482666, 32.249344621385845, 34.26044511795044, 35.80751364571707, 34.882329736437114, 35.59554842540196, 40.38318381990705, 45.3552383014134, 45.56746407917568, 41.23610298974173, 35.38298913410732, 39.89174815586635, 45.0067583492824, 49.78331484113421, 44.325060163225444, 43.93647173472813, 48.65964869090489, 46.24348211288452, 42.71073307309832, 40.251880237034385, 44.87343284061977, 47.252937248774934, 47.990498951503206, 46.686926569257466, 46.88669770104544, 46.86514786311558, 47.53136893681118, 48.42916652134487, 50.60877125603812, 46.73378522055489, 48.61918585641043, 48.1814215523856, 52.50482695443289, 50.54403836386544, 48.366657052721294, 48.42446606499808, 52.78765337807791, 50.88610165459769, 51.46800981249128, 46.688416957855225, 39.704490729740684, 21.987996544156754, 0.5701108223625592, 4.023657074996403, 7.421965854508536, 1.4154865826879228, 0.03256299393251538, 1.8023427384240287, 36.89157158987862, 36.79901116234915, 33.77931015832083, 19.501057352338517, 11.791868601526533, 31.506491865430558, 46.60851614815848, 49.51145267486572, 34.37585122244698, 0.8639484037246022, 0.06492839168225016, 0.023293813723804693, 0.05892210826277733, 0.07669936612780605, 0.01966663183910506, 0.01814747166021594, 0.012869503981034671, 0.028677288509373153, 0.014253462664783001, 0.0177973492869309, 0.025819351597289954, 0.0219926481866943, 0.04259195185399481, 0.03236855293757149, 0.03227852491129722, 0.00816768208252532, 0.017604034660117965, 0.04082865647173353, 0.0035848264565824395, 0.043103580828756094, 0.08774118684232235, 0.033089411578008106, 0.03726076328062585, 0.008739186683669686, 0.045795006943600516, 0.074017741451306, 1.336175175649779, 35.746914931706016, 52.619684151240754, 44.84992013658796, 41.444715704236714, 23.030988897596085, 20.626361540385656, 33.29752901622227, 36.39590447289603, 55.739442689078196, 19.852997507367814, 0.12119737373931067, 0.14116684932793888, 2.8404044764382497, 5.648184989179883, 9.508135557174683, 9.075437358447484, 9.241765073367528, 42.39478806086949, 57.25828416006905, 53.32434960774013, 53.86409609658377, 51.559208393096924, 52.30435752868652, 51.76993335996355, 52.46828637804304, 50.4271696635655, 43.98265988486153, 39.001267024448936, 38.242207595280235, 36.61719764981951, 37.20814888817923, 41.416384424482075, 47.55896718161446, 47.98915447507586, 48.658154828207834, 50.672475814819336, 49.89873831612723, 48.37073564529419, 46.887628759656636, 44.71735545567104, 48.48712839399065, 46.96823828560965, 45.31463997704642, 41.9669805254255, 38.92208187920706, 35.31040825162615, 36.17654636928013, 36.1070157459804, 37.080673762730186, 35.59909895488194, 35.515838691166465, 36.29449551446097, 35.8312452180045, 36.08552496773856, 35.27479525974819, 35.93621860231672, 37.65608535494123, 35.015658719199045, 36.24575390134539, 34.621508257729666, 36.74047606331961, 37.14744247709002, 38.17917353766305, 36.78715058735439, 38.222485133579795, 36.99219192777361, 37.959520135607036, 36.4912302834647, 41.324404171534944, 40.94033554622105, 44.335711751665386, 44.74073266983032, 51.471873010907856, 40.67384433746338, 27.629701035363333, 52.272364548274446, 46.85007722037179, 48.47567081451416, 47.67331715992519, 47.94343185424805, 46.4939820425851, 45.98517935616629, 45.74769687652588, 46.850685187748496, 46.2374267578125, 47.34251689910889, 48.00244985307966, 48.85069983346121, 42.34920787811279, 48.614471503666465, 47.75544834136963, 41.002073764801025, 33.975238936288015, 37.04390736988613, 36.99859816687447, 36.349195207868306, 36.878085136413574, 42.51557207107544, 48.16368280138288, 46.3088299206325, 42.64847026552473, 37.87110430853707, 41.8835118157523, 47.850364208221436, 50.78413684027535, 46.299230984279085, 46.17823505401611, 50.27348245893206, 46.64040143149239, 46.2676305770874, 42.65390375682286, 47.97162764413016, 47.8682975087847, 50.05840791974749, 48.12698589052473, 47.56521708624703, 48.12251125063215, 47.26468317849295, 49.548319816589355, 52.499539375305176, 48.85430942262922, 50.96098239081246, 52.3498717035566, 54.03080769947597, 51.9990119934082, 47.15395321164812, 48.4590368270874, 53.19394929068429, 52.36823926653181, 54.17938797814505, 52.408684730529785, 43.699406147003174, 24.79493154798235, 1.197676733136177, 2.873681787933622, 4.408889089311872, 0.811938151717186, 0.04678767653448241, 1.7870919853448868, 41.06014680862427, 42.22357055119106, 42.46149771554129, 20.54029073034014, 16.98688817024231, 35.20673418045044, 51.46744353430611, 53.86458247048514, 43.838144302368164, 1.7531619774443763, 0.13608473060386522, 0.02007700133669589, 0.04561913405944194, 0.05399019344310675, 0.03425897864092674, 0.023749007244727442, 0.026037242762478333, 0.04592490229489548, 0.043119614611246755, 0.012792536057531834, 0.018911493609526327, 0.031935433857142925, 0.03005491815773504, 0.09872711662735258, 0.07632779356624399, 0.08466538760278906, 0.17289855304573262, 0.14707987489444868, 0.16691539409969533, 0.13925304130784102, 0.15624777866261347, 0.10855412217123167, 0.15606262002672466, 0.12985070369073323, 0.15035425419253962, 0.13556064372616156, 2.493501982518605, 44.85003130776541, 59.0901906149728, 52.02370589120047, 45.058178492954795, 27.60039005960737, 26.92932435444423, 38.96137741633824, 41.282395362854004, 61.480607169015066, 21.909167494092667, 0.24562622979283333, 0.18807161386523927, 4.016908202852521, 11.180700710841588, 19.02383770261492, 16.91820001602173, 14.799200943538121, 48.600324971335276, 56.51993383680071, 56.88768114362444, 57.22079862867083, 54.91320807593209, 53.972411564418245, 54.508538041796, 53.70594120025635, 53.638477666037424, 45.54967321668352, 41.23327159881592, 39.393503257206504, 39.35809523718697, 39.05930185317993, 42.396014417920796, 48.63423912865775, 49.88716261727469, 50.55511726651873, 53.2448274748666, 50.038237299237935, 50.87279238019671, 48.15584870747158, 46.431667123522075, 50.67763485227312, 49.52833332334246, 46.96719952992031, 43.67271811621529, 41.611427307128906, 37.91228628158569, 37.65438652038574, 38.797941889081685, 38.36312362125942, 36.70926822934832, 37.36092587879726, 39.28208541870117, 37.08035067149571, 38.042182854243684, 36.71953419276646, 38.05934143066406, 39.03121028627668, 37.34509093420846, 38.20331505366734, 38.00736543110439, 39.91450350625174, 38.727205753326416, 40.89782299314226, 38.94374983651297, 39.68162420817784, 39.66645629065377, 39.9315231187003, 38.088214669908794, 43.98865965434483, 42.43961436407906, 45.55779218673706, 46.17880828039986, 53.909273283822195, 42.88463953563145, 30.10361930302211, 53.60997615541731, 48.71737085069929, 50.3294050352914, 50.22440733228411, 50.806197370801655, 48.150168555123464, 47.62627785546439, 48.904346874782014, 48.112092426845, 49.21701233727591, 50.25294358389718, 50.93101828438895, 49.587601457323345, 43.841979707990376, 51.26812056132725, 49.38086823054722, 41.92653853552682, 35.16607679639544, 39.34705107552664, 39.48493807656424, 37.42905644008091, 39.52175658089774, 45.89176777430943, 50.53694772720337, 49.35548298699515, 44.11802121571132, 40.03784097943987, 43.03336225237165, 49.39798511777605, 52.10678550175258, 46.58780704225813, 47.610376902988975, 51.97483573641096, 50.05861289160592, 48.57350492477417, 44.80350964409964, 49.64211702346802, 50.8873245375497, 53.02588626316616, 49.55985382625035, 49.84791224343436, 49.790096282958984, 48.48738200323922, 51.09772293908255, 55.10110126222883, 52.34624126979283, 53.66349812916347, 53.553730487823486, 57.51330041885376, 53.27397864205496, 49.26047331946236, 49.599309171949116, 55.96450873783657, 53.7765348979405, 56.16653456006731, 54.07385873794556, 47.45148549761091, 25.4561117036002, 2.6556885710784366, 8.457010337284633, 12.483443651880537, 3.279671762670789, 0.11739111798150198, 2.3458254039287567, 45.16703939437866, 49.05856214250837, 43.278209822518484, 28.148132187979563, 20.282839127949305, 42.66619512013027, 59.343695640563965, 61.60975333622524, 51.85371126447405, 3.5294032650334493, 0.21041513420641422, 0.10838362667709589, 0.11663825623691082, 0.12401638818638665, 0.18606487368898733, 0.07228077322776828, 0.10385220697415726, 0.0882200968584844, 0.0877098860219121, 0.11526046374014445, 0.07149251231125422, 0.139735004731587, 0.08053167763033084], [0.04950946369873626, 0.05929760954209736, 0.07667086087167263, 0.08460750856569835, 0.007902305340394378, 0.05295171256044081, 0.04960162571764418, 0.056445591151714325, 0.008972221054136753, 0.04133909461753709, 0.09260386734136514, 0.03424904828092881, 0.029410679691604207, 2.6949723831244876, 39.78324161257063, 47.82939454487392, 45.23111915588379, 25.783804382596696, 17.814802510397776, 19.51980185508728, 21.5837208202907, 35.123970712934224, 48.1395378112793, 9.026475140026637, 0.129160022895251, 0.025855639650087272, 0.24568580516747066, 2.4312011769839694, 3.8320726581982205, 11.451848081180028, 24.32767561503819, 51.766101428440635, 52.55723374230521, 50.64956412996565, 45.17992830276489, 43.426345416477744, 43.57761812210083, 43.682059969220845, 45.07140438897269, 42.203611850738525, 37.73841803414481, 37.094198431287495, 34.7928021975926, 35.85887820380074, 36.71659857886178, 35.50177901131766, 39.39797094890049, 39.20054830823626, 41.16211857114519, 43.474607603890554, 45.33653027670724, 47.10101836068289, 49.0058148929051, 44.609363079071045, 44.78848763874599, 46.30189561843872, 47.44639941624233, 44.97859730039324, 42.74182973589216, 37.543142386845176, 34.08207791192191, 35.131335803440635, 36.01543154035296, 35.14100769587925, 35.257872922079905, 34.45488698141915, 34.57614346912929, 34.48731769834246, 35.25674383980887, 34.029038837977815, 34.636273179735454, 33.534615448543, 33.41824007034302, 34.56109019688198, 35.79311350413731, 37.10966512135097, 37.26231357029506, 37.41900587081909, 35.27534416743687, 35.683338914598735, 36.132404463631765, 39.59417418071202, 45.21508271353585, 44.522736413138254, 46.54303979873657, 44.371769428253174, 50.661824226379395, 41.11493335451399, 25.03427788189479, 51.53471599306379, 42.14425686427525, 48.099721159253804, 41.847485406058176, 41.75621039526803, 39.534979002816335, 41.91619961602347, 41.87241554260254, 42.45256233215332, 43.0157972063337, 47.12824487686157, 47.07739101137434, 46.487311771937776, 41.417558670043945, 44.91759559086391, 46.27863999775478, 39.23269067491804, 34.02234424863543, 36.18081603731428, 34.93652221134731, 36.13408245359148, 35.96399402618408, 35.523346219744, 36.692331995282856, 38.03153126580374, 34.48429523195539, 36.814397948128835, 41.36134426934378, 49.555393082754954, 46.39696781975882, 42.03497559683663, 47.27536603382656, 47.93942274366106, 45.33151715142386, 39.75072404316494, 43.981614180973594, 46.572864941188264, 49.05736010415213, 48.45381872994559, 48.797758034297395, 48.267402035849436, 47.84335000174386, 48.4505044392177, 45.71744441986084, 46.671883719308035, 48.81211996078491, 50.88643864222935, 48.69647066933768, 48.79784836087908, 45.37290062223162, 50.46820225034441, 52.61264910016741, 52.488731452396934, 50.25094945090157, 54.92227894919259, 54.08748068128313, 56.943662779671804, 33.986651352473665, 1.5439790764025279, 0.7857326407517705, 3.2263256652014594, 0.34673421723502024, 0.07967814843037299, 0.5567994309323174, 30.360296181270055, 43.4957857131958, 32.75647279194423, 60.73202909742083, 21.61355291094099, 26.632320131574357, 40.81707450321743, 44.25474786758423, 42.251203536987305, 4.906667155878885, 0.13791355889822754, 0.046858905748065026, 0.025718292287950004, 0.027770328069371835, 0.0695713489715542, 0.04161197426063674, 0.04938565141388348, 0.019502957318244234, 0.03977455571293831, 0.011738827152709876, 0.0036745720426551998, 0.03232246683910489, 0.007090617154192711, 0.022635672075141753, 0.040175057615020444, 0.04291357745283416, 0.08415130233126027, 0.007347779381754143, 0.006598114809353969, 0.025305468189929212, 0.09073136853320257, 0.04316658619791269, 0.017961066216230392, 0.04233716534716742, 0.021952056525541202, 0.06214936330382313, 4.121856834207263, 50.224292687007356, 53.3277507509504, 50.81157875061035, 33.44384070805141, 21.014579977308, 20.54152750968933, 26.718441316059657, 40.611122948782786, 52.61424023764474, 9.589053409440176, 0.1542958641158683, 1.1303403292383467, 2.821765933718, 7.704274637358529, 7.617273637226649, 5.377105363777705, 21.650437423161097, 55.82166767120361, 53.60824257986886, 53.15230526242937, 46.928247928619385, 45.925636768341064, 45.86069195611136, 46.77695785249983, 45.8558976990836, 43.23879616601126, 38.08128384181431, 37.89097268240792, 36.41417128699166, 37.773231983184814, 37.410219873700825, 37.50604248046875, 40.050757680620464, 42.647539206913535, 43.12142719541277, 46.584666456495015, 48.463532311575754, 49.12890917914254, 50.25548662458147, 43.734060287475586, 44.17359638214111, 48.122584206717356, 48.99373197555542, 47.74074247905186, 44.474842480250764, 39.95748853683472, 35.80813203539167, 36.96495846339634, 37.496888228825156, 37.71019097736904, 35.7922032901219, 36.59571729387556, 36.1470582144601, 35.259689876011436, 36.906006472451345, 35.63774136134556, 35.91106612341744, 35.618776253291536, 35.86551373345511, 36.57996225357056, 37.698132378714426, 38.79464496885027, 38.9533348764692, 39.356590952192036, 37.57727541242327, 37.111218043736045, 37.46627446583339, 41.31503799983433, 45.626826013837544, 45.85278838021414, 48.28163194656372, 45.71566220692226, 50.98389407566616, 42.6549459866115, 26.582185404641287, 51.695340973990305, 44.38989380427769, 49.037057467869346, 43.76806129728045, 43.104616028921946, 42.53127152579171, 44.004727363586426, 43.52967207772391, 45.48750768389021, 45.171423707689556, 50.330898897988455, 49.2238632610866, 47.007540770939414, 42.25418084008353, 47.270630836486816, 47.28802217755999, 40.620134762355256, 34.69379384177071, 38.12861844471523, 37.15551280975342, 38.538308552333284, 37.79387160709926, 37.289856229509624, 37.674095085689, 39.3935102054051, 36.32348687308175, 38.02367632729666, 43.81888389587402, 50.220474651881624, 47.4840030670166, 41.68413325718471, 48.939463070460725, 49.79990713936942, 46.55849954060146, 43.11496884482247, 47.18314954212734, 49.29102454866682, 50.84596191133772, 49.072455065590994, 50.24590853282383, 50.92700569970267, 48.967120374952046, 50.22413982663836, 47.29893432344709, 47.99023491995675, 50.91440861565726, 53.26123911993844, 51.89724520274571, 49.35455192838396, 45.921693665640696, 50.22991377966744, 54.78873804637364, 52.49974087306431, 53.01800005776541, 56.40468059267317, 56.030339445386616, 57.84470517294747, 37.47115210124424, 2.248926043510437, 2.804684656006949, 6.91184344461986, 2.2375577049595967, 0.0638735004301582, 0.3539654463529587, 33.28727347510201, 48.517974921635215, 26.7137200151171, 48.06032487324306, 26.71215319633484, 30.167365550994873, 44.881034169878276, 49.99985892432076, 51.79540198189871, 7.414247274398804, 0.18713081149118288, 0.15695437788963318, 0.03630868365455951, 0.044973440135696104, 0.08818447377000536, 0.027012628370097706, 0.059279825139258585, 0.05537361099517771, 0.04531367116474679, 0.003719223039557359, 0.006809338943899742, 0.010144233387628836, 0.10037632313157831, 0.18590174029980386, 0.20513024207736763, 0.19565793392913683, 0.11981651426426002, 0.10368841540600572, 0.12347754995737757, 0.1352216069187437, 0.2327177253152643, 0.1168185972741672, 0.13132419676652976, 0.13927887992135116, 0.1489753896104438, 0.2978073369179453, 5.801284636769976, 59.59087085723877, 59.83869225638253, 58.707192012241904, 36.65388066428048, 26.299907888684952, 27.015593188149587, 30.49017538343157, 45.65057495662144, 57.955911091395784, 10.626851984432765, 0.2565804177096912, 0.5420031877500671, 1.3772925521646227, 7.6719055856977185, 7.949152605874198, 19.796876907348633, 27.10391695158822, 56.57665198189871, 56.75588076455252, 54.18412317548479, 48.69217668260847, 48.66909129279, 47.05899912970406, 47.68003259386335, 48.3573568889073, 44.933187348502024, 40.394426005227224, 39.93156828199114, 38.25796958378383, 40.9803397996085, 39.919714655194966, 39.368302140917095, 42.53478384017944, 44.08968298775809, 45.41938059670584, 47.97864532470703, 50.13362911769322, 50.300260816301616, 52.21324232646397, 45.432589122227256, 44.73699106488909, 49.48512595040457, 50.11608839035034, 50.6032509122576, 46.64924648829869, 42.71191774095808, 38.072591645377024, 38.828322887420654, 39.98215464183262, 38.973105975559776, 38.59129204068865, 39.14429569244385, 37.414868218558176, 37.960075991494314, 38.37480354309082, 37.15878888538906, 38.211288111550466, 36.885356426239014, 37.677027225494385, 39.07427869524275, 39.050119808741975, 40.785335132053916, 40.681233746664866, 42.33235502243042, 39.94760472433907, 39.34773894718715, 39.496579783303396, 45.315004757472444, 47.89434977940151, 48.486186913081575, 50.32092823301043, 47.416407517024446, 55.04745422090803, 45.11932611465454, 30.55970253263201, 53.434704371861045, 46.26060594831194, 51.24380881445748, 44.543310029166086, 45.58717611857823, 43.247290338788716, 46.478452818734304, 45.72949954441616, 47.784668990543906, 47.67814268384661, 52.424332073756624, 51.62021705082485, 48.11661223002842, 44.75991317204067, 51.40142869949341, 49.475412368774414, 42.988859040396555, 36.42205401829311, 40.628976345062256, 39.07052666800362, 39.42546844482422, 40.01170880453927, 38.997125898088726, 39.25775282723563, 41.98444482258388, 36.88490826742989, 39.25604357038225, 46.361181122916086, 54.35644892283848, 48.56311389378139, 42.90055438450405, 50.26763207571847, 52.73907157352993, 49.18868453162057, 45.923336914607454, 48.48621470587594, 50.55202531814575, 53.54691777910505, 51.37763459341866, 52.361812182835166, 54.52460922513689, 51.70811523709978, 52.654817717415945, 48.95418282917568, 49.544296809605186, 51.82242005211966, 55.01497834069388, 52.49512032100132, 50.39130653653826, 45.76508126940046, 52.919387749263215, 57.487595558166504, 57.05746732439314, 54.46309682301113, 59.21169376373291, 57.913054602486746, 62.08367606571743, 37.77054303033011, 2.910755204302924, 3.3925472029617856, 6.589715838432312, 4.028842168194907, 0.20012319646775723, 0.8621646708675793, 38.349536418914795, 54.360937459128245, 46.70422410964966, 72.50169386182512, 30.28890691484724, 36.25661393574306, 53.828580379486084, 56.53017200742449, 59.63720144544329, 9.930115291050502, 0.34199565436158863, 0.2647917499499661, 0.05693528987467289, 0.14715610151844366, 0.23662956112197467, 0.0866749979821699, 0.12495261723441736, 0.15356101069067205, 0.16575535706111363, 0.08933165256998368, 0.08708678052893706, 0.10317040141671896, 0.13266167071248802], [0.052897843665310314, 0.0327657062693366, 0.028229726811072657, 0.08644650809999023, 0.041191085773919306, 0.05028370608176504, 0.06648022841129984, 0.0756625442632607, 0.0505324807683272, 0.08434281884027378, 0.03905242821201682, 0.10570525218333517, 0.04969129412035857, 9.45199932370867, 43.57923010417393, 37.53580508913313, 39.273803165980745, 28.855540445872716, 15.646620614188057, 28.69981220790318, 31.381538936070033, 36.35101563589913, 46.24692147118704, 4.780754940850394, 0.17008067853748798, 0.8417131368603025, 3.8871996658188954, 5.431450264794486, 8.599029779434204, 8.728813443865095, 42.4766343661717, 54.98403453826904, 51.59212895802089, 48.2743432862418, 44.478910650525776, 37.5560417175293, 36.75430645261492, 36.16751023701259, 37.187210491725374, 35.36781774248396, 38.27248437064034, 39.57994426999773, 43.64826740537371, 41.60908923830305, 39.69689634868077, 36.42593111310686, 35.076205321720664, 35.199389934539795, 36.56957817077637, 40.3903717313494, 44.27299036298479, 45.609795979091096, 49.03785651070731, 48.42017207826887, 45.97808871950422, 43.48687812260219, 45.522491863795686, 45.659121240888325, 45.43849161693028, 42.835421970912385, 35.73983819144112, 35.30416529519217, 35.852492809295654, 35.16422510147095, 34.76408529281616, 35.144103118351524, 37.30085870197841, 34.06790706089565, 33.85979809079851, 33.81977299281529, 36.14623485292707, 33.51815864018032, 34.3731483731951, 35.454024042402, 38.51228060041155, 39.11091307231358, 39.19968673161098, 35.872788497379844, 37.42797599520002, 34.182878902980256, 41.60759884970528, 46.328277928488596, 48.65985713686262, 46.12753752299717, 48.30687822614397, 46.307026863098145, 48.59336287634713, 39.51399196897234, 25.634207929883683, 48.03155933107649, 44.43151698793684, 45.12960250037057, 39.88083600997925, 42.28616687229702, 42.461542878832134, 44.10973201479231, 43.68594748633248, 45.430838176182334, 45.2627716745649, 47.30149820872715, 46.650524956839426, 42.3204597064427, 41.143622466496055, 41.70955671582903, 46.336310046059744, 39.25092274802071, 34.34083924974714, 35.972846031188965, 34.18241337367466, 36.50717987333025, 33.231719153267996, 36.543713501521516, 33.18238694327218, 35.70704616819109, 34.91360010419573, 39.193162373134065, 45.184826782771516, 49.031373841421946, 41.48900352205549, 44.57891607284546, 47.73918260846819, 45.46076059341431, 43.947811194828574, 42.56661353792463, 46.21094369888306, 46.506235190800254, 46.79090983527047, 46.46632473809378, 49.31989083971296, 45.3270320892334, 44.57412528991699, 47.56217724936349, 47.96193143299648, 46.45468650545393, 47.72329207829067, 45.082945346832275, 44.480991636003765, 45.87706191199166, 48.35459150586809, 52.450325284685405, 51.10896165030343, 48.23570087977818, 48.32839332308088, 49.85254669189453, 52.89594800131661, 52.66509757723127, 41.328632150377544, 4.261221630232675, 1.0125799796410968, 0.7967263736895153, 0.25890236454350607, 0.16550879100603716, 0.11960975107337747, 21.057566744940623, 45.947040694100515, 56.720500537327354, 71.18605245862688, 23.542087963649205, 19.408267634255544, 40.46649966921125, 48.884805066244944, 49.712328570229666, 8.84501338005066, 0.08652023092976638, 0.06202097090759447, 0.07924191826688391, 0.06052642289016928, 0.013903364888392389, 0.032542939830039225, 0.02587381929957441, 0.05731142897691045, 0.07724894556616034, 0.010832361195103397, 0.0529324421659112, 0.039908247467662604, 0.05208357110885637, 0.023787812662443945, 0.022688322999913777, 0.04294301908729332, 0.06680334000183002, 0.023363862286454866, 0.04621965790699635, 0.062019756329911094, 0.050525274726429155, 0.04821337699624045, 0.034574660273002725, 0.020034141672242965, 0.08072267845273018, 0.046866332313844135, 13.260400772094727, 52.65225730623518, 44.93869379588536, 48.5518091746739, 34.87597908292498, 21.409225497926982, 24.78485839707511, 28.42168971470424, 41.60133852277483, 50.508474009377615, 4.842741123267582, 0.2595076449215412, 1.193736236010279, 5.792535551956721, 9.820252980504717, 9.302840607506887, 8.348497714315142, 42.94743735449654, 58.082861627851216, 52.51427303041731, 49.96111576897757, 46.12699556350708, 39.94280004501343, 38.02240828105381, 38.76746014186314, 38.351679938180105, 36.90997736794608, 39.51147672108242, 41.20108754294259, 44.7541218485151, 43.31444467817034, 40.79283223833357, 38.892576353890554, 36.56302601950509, 36.8254143169948, 38.67049108232771, 42.111582960401265, 44.97012397221157, 48.1251654624939, 48.773772852761404, 49.710716588156565, 45.75503764833723, 43.953744956425254, 46.26918349947248, 46.94684478214809, 46.68250751495361, 43.578212193080354, 37.37777178628104, 36.86612033843994, 37.76614134652274, 35.891183853149414, 35.53179522923061, 37.12952307292393, 38.422853810446604, 37.448000703539165, 36.627133573804585, 34.696805885859895, 37.993691376277376, 34.122210706983296, 37.394628116062705, 38.99349546432495, 40.757226194654194, 41.93577963965279, 40.78666571208409, 37.72493852887835, 38.07688215800694, 37.393669264657156, 44.0725348336356, 48.233296803065706, 50.72255148206438, 49.11483212879726, 50.02832569394793, 47.429862703595845, 50.83595650536673, 40.55336257389614, 28.038473980767385, 50.442438329969136, 45.54995114462716, 47.24579797472273, 42.13582175118582, 42.846844809395925, 43.894167627607075, 45.38339587620327, 45.53342832837786, 47.34418446677071, 47.01867873328072, 48.99284608023507, 47.38490438461304, 43.99929734638759, 41.692359924316406, 44.18271589279175, 48.402339526585166, 40.69223969323294, 36.258031368255615, 38.10410867418562, 36.33544472285679, 37.27178396497454, 34.844590595790315, 37.874359539576936, 35.27757453918457, 37.86530603681292, 37.52445868083409, 39.779552119118826, 47.69045141765049, 51.463997227805, 43.391798973083496, 45.568711280822754, 49.83260536193848, 48.40051909855434, 46.17404876436506, 45.92808600834438, 48.52208825520107, 49.63312952859061, 49.57817622593471, 49.34026295798165, 51.04582336970738, 47.632854325430735, 46.349775654929026, 48.83450705664498, 50.2862845148359, 48.44299691064017, 48.36643818446568, 48.06364958626883, 45.37682982853481, 46.499933174678254, 49.120262145996094, 53.717916420527864, 52.48588963917324, 50.40385150909424, 49.37654297692435, 51.93880932671683, 54.29182372774397, 57.43089478356497, 44.56591599328177, 4.746180270399366, 2.2728076534611836, 4.1947464772633145, 2.24272130216871, 0.2898446741913046, 0.15510786697268486, 24.744925362723215, 47.57454851695469, 57.51339421953474, 70.86621992928642, 25.9036260672978, 25.307098899568828, 47.17767783573696, 53.759292943137034, 56.64485549926758, 12.203156794820513, 0.11690584330686501, 0.01310788351111114, 0.05366193516446011, 0.045218496450356076, 0.031511990686080286, 0.01562822380635355, 0.06490255306874003, 0.008563631014632327, 0.04991305632782834, 0.017179144513128058, 0.026949546665751507, 0.003083935722575656, 0.0756679182606084, 0.14321727358869143, 0.13711167978388922, 0.1348911060818604, 0.1645198669284582, 0.11318315592195306, 0.1334097148584468, 0.13048410255994114, 0.1904413431350674, 0.16455353583608354, 0.12303329950996808, 0.09652998631021806, 0.19434192883116858, 0.12003152844096933, 17.848160811832972, 59.509625571114675, 51.36479432242257, 52.334585666656494, 38.815795285361155, 24.943157468523296, 39.58297368458339, 41.99575996398926, 46.81339420591082, 55.6153895514352, 6.05528689282281, 0.3736856553171362, 1.3251526185444422, 8.552469032151357, 13.885022112301417, 17.55391502380371, 13.162000383649554, 47.200242110661094, 59.09730557032994, 56.16098642349243, 51.696744510105674, 47.691670826503206, 40.62399448667254, 39.38449144363403, 39.34201710564749, 40.630939211164204, 38.36721958432879, 42.59296458108084, 43.199920994894846, 47.346150806971956, 46.13273824964251, 42.29892723900931, 41.078615120479036, 39.170420919145855, 37.56504658290318, 41.316285201481406, 44.76568712506975, 47.01684440885271, 49.91635199955532, 52.665990420750205, 51.83981139319283, 46.81445033209664, 44.038151672908235, 47.7117372240339, 48.93808732713972, 48.520976543426514, 46.232604707990376, 39.02161829812186, 39.879290035792756, 38.32950823647635, 38.73112106323242, 37.69374111720494, 39.65402248927525, 40.7995719909668, 38.046567167554585, 38.07648958478655, 36.44862740380423, 41.212781361171174, 35.633534227098735, 39.55486822128296, 39.14084938594273, 42.79109593800136, 42.70422955921718, 43.22211354119437, 40.21800429480416, 40.863102844783235, 38.42063386099679, 46.7904234613691, 50.41561828340803, 52.050182001931326, 48.43467991692679, 50.98841735294887, 49.980122566223145, 52.50403138569423, 41.313436440059114, 30.774440084184917, 50.33110734394619, 48.441631589617046, 49.23294803074428, 44.944130761282786, 44.533971650259836, 46.79829577037266, 47.75106750215803, 48.27604559489659, 48.2539016859872, 48.41723646436419, 49.935049601963584, 49.57822486332485, 45.0185946055821, 42.34349645887102, 47.15876136507307, 51.44546985626221, 42.700397627694265, 39.19726875850132, 40.76858649935041, 38.580320835113525, 39.38100692204067, 37.095688819885254, 40.48400565556118, 37.342568738119944, 39.08150829587664, 39.27452577863421, 41.597353730882915, 50.999774183545796, 50.305482387542725, 43.56495155606951, 46.65078551428658, 52.93841539110456, 51.62156500135149, 48.88242878232683, 46.95057249069214, 50.9453558921814, 50.44188594818115, 51.27296692984444, 50.96855592727661, 55.671927043369834, 48.50821965081351, 49.64237410681588, 52.407955169677734, 53.34022971561977, 49.18207679476057, 51.0639442716326, 47.85477631432669, 45.426596300942556, 46.37063414709908, 50.06443200792585, 56.110771792275564, 54.4919387953622, 52.09020709991455, 53.26493556158883, 55.19345324380057, 58.528255053928916, 58.326757294791086, 46.38433599472046, 5.859287330082484, 4.1377573524202615, 3.2687105451311385, 3.299327782222203, 0.4801335505076817, 0.2282823318881648, 27.91010253770011, 60.421673910958425, 69.57707895551408, 71.54132080078125, 31.11099692753383, 28.87372735568455, 54.77338252748762, 59.651459148951936, 67.10707773481096, 16.859159435544694, 0.255328927721296, 0.11266144391681467, 0.1407013200223446, 0.19982970293079103, 0.09757113722818238, 0.12171933001705579, 0.13712537262056554, 0.13117274775036744, 0.14063197374343872, 0.16478672118059226, 0.19409886401678833, 0.12474224423723561, 0.11292217099773032], [0.06795796911631312, 0.020713328084509288, 0.03068195915381823, 0.1172844251351697, 0.053502754241760285, 0.015302623688642467, 0.029666137948100055, 0.01291006341177438, 0.052402994861560206, 0.0656061124588762, 0.03264683032674449, 0.024432102018701177, 0.09248351558510746, 16.72113347053528, 48.287183557237896, 47.875944001334055, 33.93352542604719, 20.58415470804487, 14.776131187166486, 22.528255462646484, 29.54791280201503, 42.18905537469046, 39.14634888512747, 1.9886484784739358, 0.17274052223988942, 4.902983742100852, 6.541090607643127, 8.570353695324489, 10.114131382533483, 20.53069700513567, 51.67765780857631, 51.09881728036063, 51.28123181206839, 46.72280011858259, 42.238682883126394, 36.58735861097063, 38.191159180232454, 35.975128514426096, 38.19244112287249, 36.97785084588187, 40.52716439110892, 44.872783184051514, 47.89553792136056, 47.861502170562744, 45.88714722224644, 42.917417662484304, 40.68051808220999, 40.36535126822335, 39.42679207665579, 39.95045348576137, 42.3983907018389, 42.80300167628697, 45.611150877816335, 44.65581178665161, 46.76888057163784, 44.55332933153425, 42.01500299998692, 44.702566214970176, 46.27421399525234, 44.25606802531651, 38.28668301446097, 33.014355182647705, 35.12623929977417, 34.402678217206685, 34.90787478855678, 34.00580406188965, 34.57884284428188, 34.60744162968227, 34.601896967206685, 35.3803106035505, 36.37239524296352, 33.97715663909912, 35.3390383039202, 35.244178022657124, 38.47584772109985, 39.785510199410574, 40.69404969896589, 37.81060634340559, 35.2914639881679, 37.994420937129426, 46.1759352002825, 46.38817140034267, 46.506777150290354, 45.39195258276803, 44.289808477674214, 46.23764215196882, 47.258495807647705, 37.701457091740195, 25.574158123561315, 47.69371012278965, 46.359933921269004, 44.18154164722988, 41.517911502293174, 43.22830786023821, 43.9615547316415, 45.48174067905971, 48.073283263615195, 44.72646106992449, 44.779152733939036, 43.29359313419887, 42.817936829158235, 41.344241278512136, 40.40814174924578, 44.72164249420166, 43.9699307850429, 38.01235771179199, 34.32906205313546, 35.14997434616089, 36.1121643611363, 35.811863218035015, 35.16331488745553, 32.618231432778494, 34.79231582369123, 36.511942863464355, 35.27999251229422, 40.219449520111084, 46.04622275488717, 46.45307452338082, 41.4943015234811, 44.35702187674386, 47.383983748299734, 44.42575345720564, 43.2556802885873, 43.86946678161621, 48.04830796377999, 47.27949673788888, 48.02979448863438, 47.604008878980366, 45.19230999265398, 41.16324765341622, 40.887671675000874, 46.29024348940168, 47.062209197453086, 48.34851878029959, 41.15817894254412, 41.30613388334002, 47.81506388528006, 47.09859343937465, 51.91264588492257, 49.77299329212734, 49.78775821413313, 45.968778133392334, 45.65816586358206, 47.57167543683733, 53.85357304981777, 53.222075598580496, 50.523061752319336, 10.049880521638052, 2.525858440569469, 6.2072778684752326, 2.1906675696372986, 0.11361175256648234, 0.030415203289261887, 11.380642942019872, 48.70776844024658, 29.509249550955637, 43.488639490945, 28.912744964872086, 18.236810037067958, 42.94139589582171, 46.904981885637554, 46.06637600490025, 12.415743010384695, 0.0053152247648020935, 0.09198638011834451, 0.02582617087422737, 0.01730588128391121, 0.007988912702005888, 0.03215396963059902, 0.050054089831454415, 0.019336834982303635, 0.061148904130927155, 0.009829057264141738, 0.039780530213777504, 0.039800065236964395, 0.05960136252854552, 0.01546635418864233, 0.02366130320089204, 0.018975981577698673, 0.03712511055969766, 0.03918096310059939, 0.023141019511967897, 0.11721681590591158, 0.028482355576540743, 0.017368606757372618, 0.07810712951634612, 0.034560855478048325, 0.018933378060215285, 0.0595062862017325, 21.20222650255476, 56.60147442136492, 53.50573580605643, 39.305473055158345, 25.94363726888384, 20.38555087362017, 21.12889174052647, 31.45061445236206, 45.35329975400652, 43.76828363963536, 2.0619543620518277, 0.10044949634798936, 3.1138445351805006, 6.941303372383118, 13.602266039167132, 7.6946079560688565, 18.332161903381348, 53.978612831660676, 53.3047730582101, 53.17746121542794, 48.67619235174996, 44.50186749867031, 38.69596317836216, 38.453905309949604, 36.906923634665354, 39.06753199441092, 38.62013053894043, 42.320275579180034, 46.93777043478829, 50.23438841956002, 49.92109761919294, 46.559566089085166, 45.038765226091655, 42.714829036167686, 42.204476901463096, 40.850411960056846, 42.06990419115339, 44.10814435141427, 44.494644846235005, 46.70103488649641, 47.60256017957415, 47.284846850803916, 44.63598162787301, 41.03792994362967, 46.60920401981899, 48.66583258765084, 46.77803482328142, 39.819153376988, 35.817206382751465, 36.5065267426627, 35.09449645451137, 36.89123807634626, 35.9204809325082, 37.14848470687866, 35.057848181043354, 37.27869047437395, 36.727118151528494, 38.35904155458723, 36.0403790473938, 36.75384439740862, 37.443182127816335, 40.224372318812776, 41.93676280975342, 42.39643130983625, 38.405927998679026, 36.88422039576939, 39.90733643940517, 48.43827213559832, 47.78800065176827, 48.902057443346294, 46.52265725816999, 47.03866522652762, 47.01842164993286, 46.78885316848755, 37.212182317461284, 27.773464475359233, 49.213027545383994, 47.751501764569966, 45.9523525919233, 43.0836637360709, 43.85838093076433, 44.578440121241975, 46.45945296968733, 49.26759869711739, 47.38998351778303, 45.893532616751536, 43.512461389814106, 42.507936000823975, 41.62582744870867, 42.47880915233067, 46.043530327933176, 45.246749128614155, 39.29743051528931, 36.308134828295024, 36.323716163635254, 37.35570430755615, 37.754246030535015, 37.83414684023176, 34.59730768203735, 37.04521710532052, 37.6945366859436, 37.22578689030239, 41.08058146068028, 47.61353833334786, 48.29146017347063, 41.32519974027361, 44.88036019461495, 48.86368254252842, 47.16247517721993, 46.971243381500244, 46.03364304133824, 50.1838333266122, 47.975595065525596, 48.737645694187705, 49.617701053619385, 47.02440057482038, 43.81365885053362, 44.14888858795166, 47.32277011871338, 49.07202080317906, 49.76965120860508, 43.37116629736764, 42.99617896761213, 47.09911802836827, 49.40770217350551, 53.537221567971365, 52.001732213156565, 52.240875312260215, 47.422153677259175, 46.18996013913836, 50.40314279283796, 55.7866279057094, 54.30127675192696, 53.772327763693674, 10.915545293263026, 3.4511817480836595, 13.486458676201956, 5.072094644818987, 0.34642912074923515, 0.07765128290546791, 14.486828173909869, 55.76041235242571, 38.44835022517613, 47.249834878104075, 28.18782377243042, 23.725404024124146, 50.36300304957798, 51.272480555943076, 53.646752970559255, 17.4634234224047, 0.014606304267155272, 0.0943182199927313, 0.00978336386781718, 0.02774558020090418, 0.04325268889910408, 0.04121582516069923, 0.041403362061828375, 0.03819766407832503, 0.022468345339543054, 0.039605091592030864, 0.09119268413633108, 0.05651854045156922, 0.04190688932846699, 0.20034377463161945, 0.07856083874191556, 0.13769000875098364, 0.20532694937927382, 0.1712061781436205, 0.0704317856580019, 0.2171695160546473, 0.12284550815820694, 0.12858701364270278, 0.18786352074572019, 0.12827978655695915, 0.14690450073352881, 0.278418063053063, 27.68382750238691, 62.21584469931466, 60.930309840611045, 47.23146384102957, 29.94701385498047, 23.04001808166504, 33.359267234802246, 41.00120176587786, 53.33800629207066, 47.362253257206504, 2.8897243099553243, 0.3118061386048794, 9.604047621999468, 20.075589997427805, 19.644449063709803, 19.858292034694127, 24.349152496882848, 56.756982054029194, 55.07220023018973, 55.36187062944685, 50.930260930742534, 46.97497803824288, 40.606318269457134, 42.54509496688843, 38.72076824733189, 40.80407094955444, 40.25091443743025, 45.313531739371165, 49.030772822243826, 52.9843464578901, 51.82540430341448, 50.04258687155587, 47.28282839911324, 43.78980221067156, 44.89516680581229, 43.69344459261213, 44.93865210669381, 46.46481350490025, 46.577301365988596, 48.85106461388724, 49.41111026491438, 49.6873220035008, 45.80804198128836, 41.42835964475359, 46.76957886559622, 50.31142657143729, 48.668281827654155, 42.109720843178884, 36.616231850215364, 39.1760698046003, 38.62831204278128, 38.858248778751914, 38.37427200589861, 38.168917996542795, 36.81633302143642, 40.212470054626465, 39.401000363486155, 39.6901843888419, 37.12955086571829, 39.88905225481306, 39.87459305354527, 40.579564230782644, 44.18371990748814, 44.46548325674874, 41.148076261792866, 38.9782372202192, 40.86691740580967, 48.44969497408186, 50.65183619090489, 50.35636404582432, 47.65018660681588, 48.00277989251273, 49.119199071611675, 47.81853798457554, 37.18236412320818, 30.74344069617135, 49.195663997105186, 50.293889318193706, 47.940927028656006, 45.08192048754011, 45.238362652914866, 45.98627369744437, 48.95783758163452, 51.275353636060444, 48.53424760273525, 48.776044913700645, 45.225755146571565, 44.67063924244472, 41.147190366472515, 43.948634556361604, 48.13493115561349, 46.94294336863926, 41.35048770904541, 37.65474782671247, 38.057395935058594, 39.7797258240836, 39.78525659016201, 39.339248248508994, 36.0513676234654, 40.20503200803484, 40.02039752687727, 38.67562232698713, 43.68490525654384, 50.17954976218087, 49.28580297742571, 43.198830127716064, 45.34379809243338, 51.40454496656145, 48.624480383736746, 49.77875682285854, 48.590111119406565, 52.677051952907014, 50.342082023620605, 49.88088839394705, 51.76372514452253, 48.749231815338135, 46.41623517445156, 46.07512378692627, 49.42547566550118, 52.352414744240896, 52.06260190691267, 46.66938236781529, 45.02334369931902, 48.62058244432722, 51.006830079214915, 56.40940884181431, 53.98458480834961, 55.09633827209473, 49.482075691223145, 49.53390577861241, 52.27191986356463, 59.316625458853586, 56.68458182471139, 57.49214662824358, 12.265054821968079, 7.470393061637878, 14.988099881580897, 5.2076974255698065, 0.19641356409660407, 0.11571551646505084, 17.13666180201939, 61.75621441432408, 40.50360999788557, 53.88174104690552, 41.7296404838562, 27.71915214402335, 56.54802540370396, 59.02220943995884, 63.122633252825054, 24.24960044452122, 0.1034555828997067, 0.1613927704415151, 0.07975135557353497, 0.08624303580394813, 0.09631034452468157, 0.17980052983122213, 0.16719174784209045, 0.15056146521653446, 0.15626871825328895, 0.13254173286259174, 0.16886239605290548, 0.11909265310636588, 0.23439243116549083], [0.011033282199475383, 0.04746780271774956, 0.03809131049950208, 0.044108667610479255, 0.017281615175306797, 0.0036820113309659064, 0.03047916878546987, 0.04474439046212605, 0.00661371644985463, 0.024917722746197666, 0.05951379758438893, 0.1004216628415244, 0.06529562840504305, 20.684443269457134, 50.17385918753487, 40.494490487234934, 38.82314647947039, 25.585171018327983, 22.16199333327157, 22.527195862361364, 25.843777758734568, 41.8132620538984, 35.01887226104736, 0.7941931039094925, 0.07402871336255755, 0.8506726218121392, 4.8510589855057855, 10.071812510490417, 12.126466052872793, 32.3225473676409, 55.44543661390032, 50.960773944854736, 49.56795195170811, 44.09912558964321, 39.8466717175075, 38.11914110183716, 38.12874698638916, 37.40582166399275, 36.71343714850289, 36.773879528045654, 41.141642229897634, 47.05160972050258, 46.92494753428868, 47.80170597348894, 48.4949312210083, 45.23408603668213, 44.72319541658674, 43.285012108939036, 43.26633882522583, 43.427582195826936, 44.9784722328186, 44.48866592134748, 43.693455014910015, 44.90612758908953, 45.663682733263286, 45.57033715929304, 41.72342184611729, 41.55029705592564, 46.82243381227766, 45.098568371364046, 40.37718752452305, 33.8878618649074, 34.262894357953755, 34.400652817317415, 35.051528794424875, 33.855778557913645, 33.7826418195452, 33.376561301095144, 32.7699418749128, 34.82437481198992, 37.398786612919395, 33.080675738198416, 35.61036893299648, 35.81631701333182, 40.89889301572527, 42.220874650137766, 41.21823569706508, 38.20348875863211, 36.60379804883684, 40.29894038609096, 48.001577854156494, 45.8499048777989, 43.70784820829119, 44.24585764748709, 47.08465535300118, 46.35811696733747, 48.322400501796174, 43.304390634809224, 28.63409267153059, 48.537992681775776, 44.721562589917866, 43.843435355595176, 41.36849396569388, 46.00456483023507, 45.54859972000122, 46.952636105673655, 44.91740798950195, 44.7927051952907, 45.38849932806832, 44.15343965802874, 45.14745242255074, 45.024462359292166, 44.17841495786394, 45.523110253470286, 43.02669892992292, 35.02473654065813, 34.65696144104004, 34.13263995306832, 34.86204447065081, 36.155006953648154, 33.420783111027305, 34.77379887444632, 33.55823237555367, 35.72820690699986, 33.79717745099749, 41.49489212036133, 47.42203208378383, 46.575526101248606, 44.378596033368794, 46.01413597379412, 46.186930724552695, 45.92111349105835, 43.54749420710972, 44.75652592522757, 46.7982679775783, 49.89397880009243, 49.288165364946636, 46.49158838817051, 40.68855367388044, 37.1340046610151, 39.11423083714077, 43.66565874644688, 48.51283325467791, 46.568640436444966, 47.059440340314595, 48.616288457598, 52.61388240541731, 49.695614678519114, 50.62006207874843, 48.6082181249346, 42.96543666294643, 39.40899774006435, 42.87557908466884, 47.74575907843453, 51.830149923052105, 51.84903860092163, 52.71955755778721, 18.511189188276017, 3.541788863284247, 16.83704505647932, 8.487531168120247, 0.45972766833645956, 0.045090908118124516, 7.320017542157855, 46.28340993608747, 35.26919501168387, 44.91768591744559, 31.314968245370046, 23.439188616616384, 40.24162817001343, 45.24701663425991, 52.44890437807356, 20.223583153315953, 0.2181273903697729, 0.0483764086051711, 0.00868485723289528, 0.02490310201288334, 0.05228729785553046, 0.04904190896611128, 0.010689689029407288, 0.04009327718189784, 0.03485036940713014, 0.034735018453959904, 0.10674739376242671, 0.01889733597636223, 0.03359332900228245, 0.009882082231342793, 0.016619702568277717, 0.04143085290810891, 0.009989338261740548, 0.03293931284653289, 0.0033012365622978124, 0.032482930192989964, 0.025994620585281934, 0.04384531799171652, 0.0199944897820907, 0.007995955895499458, 0.04795714520982333, 0.1913145769919668, 26.876326969691686, 57.216549805232454, 46.016147477286204, 45.706893580300466, 28.246508257729666, 25.545757361820765, 22.405169861657278, 27.547269344329834, 47.95523336955479, 37.36376769202096, 1.0050078545297896, 0.11346124671399593, 1.3305133708885737, 6.247919184820993, 10.801270008087158, 6.4030559573854715, 32.76431730815342, 56.28890970775059, 53.96063436780657, 51.039483138493125, 45.09248522349766, 40.86922073364258, 39.29051010949271, 40.604209491184776, 39.68646362849644, 38.384496280125205, 38.44066899163382, 42.284054619925364, 48.24159295218331, 49.49729572023664, 50.5662065914699, 49.800240652901785, 46.688844272068565, 46.00486012867519, 44.75190884726388, 45.066207136426655, 44.73212732587542, 46.4392580304827, 45.622417381831575, 46.21184001650129, 47.238575322287424, 47.47959096091134, 46.72564888000488, 42.99460172653198, 42.324246474674766, 47.98891476222447, 45.952303954533164, 43.36954736709595, 36.12363583700997, 35.514845098767964, 35.34195307322911, 35.98467533929007, 36.20761523927961, 36.0841839654105, 35.645453861781526, 35.66404376711164, 37.25891590118408, 38.951882702963694, 34.64400999886649, 37.64180333273751, 38.34624644688198, 43.75483192716326, 44.11374112537929, 41.962811606270925, 40.11207900728498, 36.858498164585654, 41.510494300297324, 49.90520361491612, 47.176173550742014, 45.63493456159319, 46.36780970437186, 49.397206919533865, 47.168217863355366, 50.29558120455061, 44.10845354625157, 30.09038645880563, 50.66488490785871, 47.129189831869944, 45.473097120012554, 44.46769278390067, 48.819307872227256, 46.32487678527832, 47.57425321851458, 46.855969292776926, 45.598769187927246, 45.45444815499442, 46.78101907457624, 46.68383462088448, 46.4812981060573, 44.9228310585022, 48.46596418108259, 44.919895444597515, 36.5837698663984, 35.53824315752302, 36.11991160256522, 36.69637932096209, 36.73335068566458, 35.33337204796927, 37.01661831992013, 35.280416352408274, 37.612085887363975, 36.30966690608433, 43.388470785958425, 49.953900064740864, 47.46412079674857, 44.837041650499614, 46.46388939448765, 47.95065450668335, 47.917799949645996, 44.54800353731428, 45.81463234765189, 48.34294285093035, 50.90466029303414, 50.625516414642334, 49.89155387878418, 42.55445071629116, 39.648359707423616, 41.14707224709647, 46.449339866638184, 48.70071254457746, 49.514002663748606, 47.483384677342, 50.21112585067749, 53.00408629008702, 52.39123085566929, 51.21547406060355, 51.894320011138916, 45.154820987156455, 43.19272266115461, 44.60427699770246, 50.70868982587542, 53.185906750815256, 55.214742524283274, 54.57485164914812, 21.363759960447037, 0.8043406765375818, 15.247531720570155, 8.658450773784093, 0.5981582030653954, 0.011981253296003809, 8.439617259161812, 52.903233187539236, 37.11197887148176, 49.021667207990376, 33.402099405016216, 29.732370104108536, 43.838557720184326, 51.616920130593435, 59.01906190599714, 27.260737793786184, 0.0685712562075683, 0.033218475723905225, 0.05296581591080342, 0.03866997534143073, 0.05008900724351406, 0.04035835706495813, 0.032309079343186956, 0.030380967804895978, 0.02238679051931415, 0.035905518502529175, 0.04849383926817349, 0.02111016589749072, 0.06035208688782794, 0.07985819091222116, 0.09112005374793496, 0.10952549254787819, 0.08884963486343622, 0.12868531979620457, 0.07438097481748887, 0.10011659349714007, 0.12883208692073822, 0.09655567564602409, 0.09538952500692435, 0.16645196825265884, 0.20417065785399505, 0.604031710752419, 33.561973980494905, 65.07708508627755, 53.067196777888704, 50.32555225917271, 35.199233600071494, 31.909376212528773, 32.36931569235665, 36.65861586162022, 51.96236719403948, 42.21758120400565, 1.2529222943953104, 0.19268143150423253, 2.05978587269783, 11.275542753083364, 15.920933757509504, 18.18691154888698, 34.410376821245464, 58.570291655404226, 55.772137437547954, 54.833988189697266, 47.08053159713745, 42.7374176297869, 40.98329973220825, 42.2431366784232, 40.889495577131, 40.278627327510286, 39.35507277079991, 44.63496371677944, 51.6546071597508, 51.229234967912944, 52.276224272591726, 50.87402221134731, 48.50457879475185, 48.01834385735648, 46.86365400041853, 47.26112222671509, 46.827499049050466, 49.085844244275776, 47.385741642543245, 47.480893748147146, 48.451560565403526, 47.851538453783306, 47.45205177579607, 42.000293663569856, 42.440931047712056, 49.90884447097778, 48.684207098824636, 45.831405299050466, 37.22263240814209, 37.49761431557791, 37.59153311593192, 39.648290225437705, 37.970675468444824, 36.155906745365684, 36.789196831839426, 36.396074703761506, 39.26042093549456, 42.17801121303013, 35.59777879714966, 39.21073089327131, 40.01584645680019, 44.9582633972168, 46.76310314450945, 44.617603642599924, 41.04821327754429, 40.255524567195344, 43.36325577327183, 52.196052483149934, 48.50043419429234, 46.90976572036743, 49.38355023520333, 49.17175871985299, 49.35840817860195, 52.89251559121268, 45.23086207253592, 33.13088689531599, 52.37202603476388, 49.927128655569895, 47.07761335372925, 45.837123666490825, 49.003511565072195, 47.94866384778704, 49.233274596078054, 48.85261058807373, 47.28811945234026, 47.12121329988752, 47.842655181884766, 47.685264587402344, 48.07898426055908, 47.5394218989781, 49.4526743888855, 47.21004254477364, 37.60621813365391, 39.08110877445766, 37.83278499330793, 39.02609988621303, 40.01913295473371, 36.97399459566389, 38.21223654065813, 37.71118804386684, 40.201279980795725, 37.151368209293906, 46.52309152058193, 52.14978095463344, 51.61138241631644, 44.97613763809204, 48.88078900745937, 48.68345669337681, 50.60168409347534, 46.60490655899048, 47.78861556734358, 50.39983197620937, 53.90300600869315, 53.281225613185335, 51.39938940320696, 45.05618783405849, 41.54869202205113, 43.12156615938459, 47.58358812332153, 52.52545615604946, 51.55534519468035, 49.806897027151926, 50.92079401016235, 56.804601533072336, 54.27697890145438, 54.1827335357666, 54.0614457811628, 47.769129344395225, 44.49466916493007, 47.644412653786794, 53.54052196230207, 55.204480034964426, 57.05384383882795, 57.39963831220354, 23.027214288711548, 8.151562316077095, 24.6361791065761, 12.841957671301705, 1.0197307616472244, 0.20713500093136514, 10.54786138875144, 59.53825909750802, 45.247777462005615, 56.70299802507673, 39.78522184916905, 34.71312720435006, 51.10126304626465, 59.8413325718471, 67.48313508714948, 35.3154422215053, 0.37110800934689386, 0.1114045392189707, 0.15990406461060047, 0.11229531320610217, 0.1798844374716282, 0.14284276297049864, 0.13593841131244386, 0.09044895547309093, 0.14137104765645095, 0.12630379758775234, 0.14919034950435162, 0.07956399169883557, 0.17203352946255887], [0.02287052322312125, 0.028707374752100025, 0.001614315597440249, 0.072205008007586, 0.0077003622926505545, 0.014623941088627492, 0.013501451633471464, 0.03413116639213903, 0.02185754507913121, 0.026700123978246535, 0.023023906064086726, 0.06924658175557852, 0.711116370345865, 25.056526013783046, 46.044746262686594, 47.31309822627476, 40.74936778204781, 19.83716082572937, 11.638417635645185, 21.877766847610474, 35.771549769810264, 41.664066859654014, 29.918331691196986, 0.1999851553035634, 0.09401913532721144, 6.9615703991481235, 2.04994136095047, 13.185269900730678, 14.808787720543997, 47.76109722682408, 52.90893071038382, 49.465174198150635, 46.45731292452131, 38.871877670288086, 40.63488231386457, 43.40423277446202, 43.14832714625767, 41.51432623182024, 37.31796864100865, 36.867683683122905, 41.09089606148856, 45.17823641640799, 47.88543176651001, 45.779446669987266, 49.11476959500994, 44.90118047169277, 46.36745187214443, 46.17352417537144, 45.855081285749165, 46.05502264840262, 46.72334555217198, 45.57042748587472, 45.72839478084019, 45.64906024932861, 45.18557024002075, 44.17490611757551, 41.307051045554026, 42.68790824072701, 46.81612137385777, 45.264609473092214, 40.482296398707796, 34.82282883780343, 33.34037855693272, 34.44559723990304, 34.021923882620676, 32.932752064296174, 34.01805373600551, 34.75568839481899, 35.55788571493966, 34.34658540998186, 33.73077351706368, 34.23847491400582, 34.128957407815115, 38.25840732029506, 43.55055488858904, 40.80343171528408, 40.09318685531616, 38.96738760811942, 37.43804740905762, 39.322322436741416, 45.02419832774571, 45.83831875664847, 45.440548283713206, 47.625093187604634, 46.83068132400513, 46.150956426348, 46.622891971043174, 45.9163852419172, 32.22651284081595, 45.95951271057129, 47.653480052948, 43.54126862117222, 43.131137302943635, 45.92007820946829, 47.4224385534014, 42.827146666390554, 44.69381495884487, 46.563741956438335, 46.23154510770525, 46.99573578153338, 46.63082333973476, 47.93365921292986, 49.639497552599224, 43.94581706183297, 39.80943979535784, 34.00902802603585, 34.892022473471506, 33.81186941691807, 34.24680927821568, 36.107450008392334, 35.70902293069022, 36.15920713969639, 36.76839739935738, 34.77041857583182, 34.68529966899327, 38.01308379854475, 47.43293033327375, 45.811321531023296, 46.62512581689017, 44.52147878919329, 47.68219000952584, 46.35211719785418, 44.462787355695454, 43.86810493469238, 48.544027192252024, 47.469926016671316, 45.35492563247681, 38.516717025211875, 36.97490133558001, 36.86166654314314, 37.72784634998867, 40.489397457667756, 45.43341943195888, 48.73369216918945, 49.786212239946636, 49.6189169883728, 48.61605569294521, 46.66902106148856, 46.090778078351704, 40.60721458707537, 39.36272621154785, 39.88411555971418, 46.826015608651296, 48.22901323863438, 54.62199865068708, 53.53677340916225, 57.62610442297799, 29.66772059031895, 4.748484466757093, 11.08282925401415, 5.220020924295698, 1.3613278716802597, 0.16747802176645823, 3.843370429107121, 41.790200982775005, 38.45524978637695, 36.12293406895229, 27.356173038482666, 13.3763245173863, 32.16673401423863, 43.34196301868984, 46.68134369168963, 23.340435607092722, 0.25229655472295626, 0.07470939933721508, 0.06262792048177548, 0.06230339075305632, 0.028276367611917, 0.012944983368340348, 0.01808941281134529, 0.06991439592093229, 0.052964085646505864, 0.015979118013222302, 0.0068814137817493504, 0.053360109217464924, 0.007233721037794436, 0.019097804058609263, 0.021199554404509918, 0.027789405081421137, 0.03369528228150947, 0.0019205607157865806, 0.04518945515155792, 0.022316319568614875, 0.015271409381447094, 0.0652738135041935, 0.021293908091528074, 0.042010796788547716, 0.05227900955027767, 1.143651340688978, 31.801984855106898, 54.01461839675903, 54.99535662787301, 46.00653811863491, 26.118705817631312, 10.852812613759722, 20.7918815272195, 38.83549690246582, 48.45285293034145, 34.363438265664236, 0.2710879849536078, 0.27384728831904276, 7.110125490597316, 4.6330006292888095, 3.6278900716985976, 13.60691785812378, 48.679920060294016, 54.75317716598511, 51.57264968327114, 47.646941798073904, 41.48785706928798, 41.17377764838082, 44.65829924174717, 44.83852856499808, 42.72585582733154, 38.06555659430367, 38.45229680197579, 42.45312166213989, 47.295470646449495, 48.62319844109671, 48.12922321047102, 50.49835048403059, 47.88262469427926, 48.12037467956543, 47.78130258832659, 47.51097597394671, 46.604354177202495, 47.02854864937918, 45.780725138528005, 48.38887391771589, 46.41573143005371, 47.93871055330549, 44.997725691114155, 42.06446375165667, 43.37946592058454, 48.230003356933594, 46.702275139944895, 42.31239979607718, 36.74949829918997, 34.621299811771934, 36.61893817356655, 35.02598374230521, 34.34295497621809, 35.18955823353359, 35.72864811761038, 36.97673218590872, 35.79564264842442, 35.254520416259766, 34.70205872399466, 36.2925569670541, 39.476874692099436, 46.201542786189485, 41.877633639744346, 43.44595670700073, 39.85933133534023, 39.04820558003017, 42.49971628189087, 45.44406754629952, 45.43256132943289, 47.399301052093506, 49.65671518870762, 48.82604762486049, 47.52639055252075, 48.23078155517578, 48.02917609895979, 34.631471974509104, 47.50412505013602, 48.437480040958945, 44.673616545540945, 46.62373617717198, 47.91639641353062, 48.12028087888445, 45.01407132829939, 45.14962026051113, 48.58817604609898, 47.93623699460711, 49.175444739205496, 48.54833160127912, 49.47894205365862, 49.79357385635376, 46.67745270047869, 41.1576578276498, 35.28432124001639, 36.09857368469238, 35.76978840146746, 37.599926539829795, 38.17371225357056, 37.46754251207624, 36.705981731414795, 38.65280096871512, 36.06953716278076, 36.577096121651785, 40.34199489865984, 47.86596291405814, 46.861256871904644, 46.130188260759624, 45.26520701817104, 48.74171386446272, 47.8083484513419, 46.17666128703526, 46.375421455928254, 50.52465983799526, 48.742690086364746, 48.019664015088765, 40.33935110909598, 38.37209027154105, 39.31201131003243, 39.944015979766846, 42.79254463740757, 46.96413190024239, 50.96208715438843, 49.783846378326416, 51.27418981279646, 50.87799310684204, 48.3622727394104, 47.06636422021048, 42.716989925929475, 40.80219841003418, 40.861490862710134, 47.530267647334504, 50.882575443812776, 55.177937916346956, 55.97154031481062, 58.310623577662874, 32.97528893607003, 3.269933645214353, 1.7442472215209688, 7.789138197898865, 1.6439874299934931, 0.13445621941770824, 5.220793911388942, 47.21992983136858, 40.77340507507324, 43.59469332013811, 27.745577880314418, 18.805044140134537, 38.25277927943638, 50.499597685677664, 53.449403285980225, 33.7391391481672, 0.5399946698120662, 0.13613838915313992, 0.04021286219358444, 0.06765146127768926, 0.03693392314016819, 0.04903568679999028, 0.05582431431061455, 0.013018853779483055, 0.017871959301243936, 0.04501607927626797, 0.02221501768300576, 0.07888753299734422, 0.0070979453323941144, 0.11863096430897713, 0.12400319746562413, 0.11849988491407462, 0.15566003162946018, 0.12888930099351065, 0.12677600367793015, 0.08903244576816048, 0.09286937809416226, 0.09010896193129675, 0.08576589676418475, 0.12412067901875291, 0.05996785964816809, 1.6511267040457045, 39.308790819985525, 60.83469567980085, 60.33372361319405, 51.81860201699393, 30.46369927270072, 20.12747914450509, 30.82626669747489, 49.335739680698936, 53.377774306706016, 37.807979924338206, 0.4154352364795548, 0.3535524899406092, 14.465670909200396, 6.9061585153852185, 20.733143193381174, 17.83551335334778, 52.67714575358799, 55.038918358939036, 53.69438634599958, 50.30480146408081, 43.63962384632656, 44.48793288639614, 46.597339970724924, 45.95075798034668, 45.78346272877285, 40.47088050842285, 41.02985266276768, 45.060811860220774, 49.97853490284511, 51.145311151232036, 48.80049909864153, 50.95299196243286, 49.556654180799214, 49.53441994530814, 50.173185212271555, 49.19137348447527, 48.83491700036185, 50.02105787822178, 49.02372734887259, 49.08084848948887, 47.63800294058663, 49.14966344833374, 45.254878520965576, 42.43710953848702, 44.491222858428955, 49.79316391263689, 49.21861042295183, 44.45510612215315, 39.091058594839915, 35.84099006652832, 38.0636944770813, 36.297469343457905, 35.16659443719046, 38.51232576370239, 39.317170347486226, 39.28320755277361, 37.572151115962434, 36.49187994003296, 36.06096655981881, 37.829314368111746, 41.76006317138672, 47.861630712236675, 44.836141858782085, 45.47487933295113, 41.82289225714547, 42.143669741494314, 43.79984583173479, 48.43393298557827, 46.10226692472185, 48.144363335200715, 51.513075828552246, 52.096710613795686, 49.3967205456325, 50.911806515284944, 50.4653673853193, 37.31158324650356, 49.68844761167254, 50.604327883039204, 46.95639508111136, 47.87273393358503, 51.181327138628276, 50.67994512830462, 45.63299601418631, 48.53894111088344, 50.6090908731733, 48.87393808364868, 51.081064632960725, 51.7291613306318, 51.51679311479841, 53.98681170599801, 47.06211887087141, 42.891966411045615, 37.32028933933803, 38.55180195399693, 36.44578559058053, 39.26937368937901, 40.257737568446565, 39.667884145464214, 39.11418219975063, 39.53998517990112, 38.5610465322222, 38.17806877408709, 41.75034611565726, 51.20902613231114, 49.37007767813546, 48.457219873155864, 46.85062960215977, 53.50109093529837, 49.72729846409389, 48.04120690482003, 48.33772127968924, 53.48067365373884, 50.24322305406843, 49.39754043306623, 41.39400427682059, 41.22926943642752, 40.73568677902222, 42.21544810703823, 44.375295639038086, 48.51648800713675, 52.769775663103374, 53.300006593976704, 54.62738350459507, 51.85653918130057, 50.833166803632466, 49.523768356868196, 45.093920026506694, 42.79420873097011, 43.480312074933735, 50.79797417776925, 52.351633071899414, 59.42280088152204, 56.76194306782314, 60.89664581843785, 33.61274446759905, 9.38061613695962, 21.425951548985072, 14.22186383179256, 3.8222526822771346, 0.24793751005615505, 6.144380169255393, 53.98096827098301, 48.0705109323774, 49.9674733706883, 34.8357629094805, 22.619247334344045, 44.501426288059776, 56.681340490068706, 60.57531247820173, 42.787316117967876, 1.3847826016800744, 0.25500947343451635, 0.1690304691770247, 0.2032237486647708, 0.15213589716170514, 0.08138627213026796, 0.17680078079657896, 0.16155685377972467, 0.13581616644348415, 0.10616291726806334, 0.062160328429724486, 0.13961639681032725, 0.1459784632814782], [0.03357680667457836, 0.00953683428399797, 0.043556177256894965, 0.053729232267609665, 0.044168327801993916, 0.027045561067227806, 0.02132907825788217, 0.05934976174363068, 0.042913509599332295, 0.07446497066744737, 0.029360305251819745, 0.12470918601112706, 1.7041399393762862, 30.588197095053538, 46.783353669302805, 38.46069022587368, 29.610627242497035, 18.176138366971696, 28.9544289452689, 37.52425718307495, 30.84922354561942, 41.46926368985857, 25.845144816807338, 0.1116537515606199, 0.7474403040749686, 2.304869247334344, 6.3251462408474515, 14.635023696081978, 20.287466628210886, 52.41815512520926, 48.81965528215681, 47.69705220631191, 38.41138233457293, 43.50519357408796, 45.65148169653756, 48.30715615408761, 47.32392699377877, 47.43628978729248, 40.306229046412874, 35.3743942124503, 39.43440382821219, 45.690992627825054, 47.83803810392107, 46.575241225106375, 43.57929263796125, 44.328096526009695, 43.08087056023734, 48.342783042362754, 46.04042100906372, 44.43166290010725, 45.781683989933555, 45.87484196254185, 47.02335834503174, 48.55681535175869, 44.91584464481899, 42.71862622669765, 41.01867995943342, 42.39105340412685, 45.05762958526611, 44.87938049861363, 38.157752241407124, 34.50574084690639, 33.32936913626534, 34.16306264059884, 34.91690049852644, 34.407541956220356, 33.30380323954991, 33.78231872831072, 35.15645006724766, 34.87083741596767, 33.11802577972412, 33.94225236347744, 33.24636248179844, 40.90203012738909, 43.80607836587088, 42.29694700241089, 43.83901630129133, 39.94089623859951, 35.63121352876936, 38.42755079269409, 41.631688254220144, 45.75535726547241, 46.31314475195748, 46.24212374005999, 43.091751439230784, 44.24430125100272, 45.50535065787179, 48.75492933818272, 36.64148160389492, 47.71135854721069, 45.22921882356916, 43.04506301879883, 42.60533584867205, 47.041552203042166, 43.28624888828823, 44.20758349554879, 48.1841139793396, 45.33920185906546, 45.890485831669395, 44.298837661743164, 41.87097379139492, 40.16124446051461, 39.03185646874564, 36.67966890335083, 34.458802291325156, 34.380280699048726, 34.12409019470215, 35.23529822485787, 35.48542295183454, 34.464916706085205, 36.371728215898784, 34.00004400525774, 34.82204369136265, 34.91748762130737, 36.10866246904646, 36.82390308380127, 44.58560023988996, 45.0736278125218, 45.47791916983468, 45.445068086896626, 46.539961746760774, 48.57359177725655, 43.714660917009624, 44.19020257677351, 41.730338777814595, 41.40922777993338, 36.98436825616019, 37.74315323148455, 40.188356331416536, 39.13278252737862, 37.523385184151785, 37.523128100803916, 39.73915876661028, 44.53892224175589, 48.93959856033325, 47.94258764811924, 44.62443719591413, 40.17162159511021, 38.249788079942974, 35.913171427590505, 38.710766315460205, 39.57646322250366, 43.396617548806326, 49.94205338614327, 51.5267915725708, 54.67496476854597, 52.43493502480643, 46.15169988359724, 5.981564334460667, 1.3994557857513428, 1.6955997347831726, 0.7131621805684907, 0.05993634169655187, 1.7031301707029343, 37.84878669466291, 38.94414240973336, 32.72581386566162, 37.68848480497088, 22.954199143818446, 34.35724394662039, 42.910361766815186, 45.697965145111084, 35.04714100701468, 1.9861684058393752, 0.1052051108064396, 0.022500631732067893, 0.029322120693645308, 0.015247168717905879, 0.08587048615195922, 0.02610249238620911, 0.005162958538026682, 0.02783399840284671, 0.01582370126353843, 0.1154351457953453, 0.04051895612584693, 0.0471689758955368, 0.03986720966973475, 0.11972420636032309, 0.09360424509005887, 0.010555238163630878, 0.04416434480143445, 0.07415337381618363, 0.03359136125072837, 0.016439956945500205, 0.04811378162620323, 0.01306851236482284, 0.020784143391730528, 0.20579520639564308, 2.601045766047069, 38.51219374792916, 52.27312190192086, 46.892155511038645, 39.71069894518171, 27.060633148465836, 26.125014781951904, 36.06490271432059, 36.953007561819895, 45.371841021946494, 29.97837802342006, 0.11753693515700953, 1.08219604407038, 8.587437578610011, 12.615354333605085, 6.774702072143555, 23.98021009990147, 54.927868774959016, 50.87786109106881, 49.92907067707607, 39.76853922435215, 45.784814153398784, 47.17198726109096, 50.347053459712434, 49.06001779011318, 48.84621129717146, 42.00361837659563, 36.899718352726524, 41.733055523463655, 47.53675031661987, 48.53571367263794, 47.72113813672747, 44.902841091156006, 44.21436493737357, 44.71139390127999, 48.42563336236136, 47.6369502885001, 46.30738469532558, 48.255934034075054, 47.88661296027047, 48.26499448503767, 49.12765155519758, 45.940290519169395, 44.55577162333897, 42.76412650517055, 44.95146458489554, 47.57271419252668, 47.192508765629356, 40.53853164400373, 36.10813788005284, 35.246536936078755, 36.84995535441807, 36.687589849744526, 35.174039431980674, 34.19623334067208, 35.04537616457258, 35.87524468558175, 36.13061530249459, 33.17685270309448, 35.24048852920532, 35.4606283051627, 42.81018263953072, 45.226811272757395, 45.27752270017351, 45.95450305938721, 40.543610777173726, 37.648463181086946, 40.13903454371861, 42.97951371329171, 46.35565035683768, 47.624964645930696, 47.7853672845023, 44.79683589935303, 44.50816604069301, 48.06556728907994, 49.14720378603254, 37.3984044619969, 48.861730098724365, 48.087964807237896, 44.113074098314556, 45.333879538944785, 48.79398168836321, 45.77276250294277, 43.59471069063459, 50.28326899664742, 48.176908697400776, 47.27779790333339, 45.94888891492571, 43.171492440359934, 42.0779641015189, 41.26491716929844, 40.04699175698416, 36.51488195146833, 35.4318836075919, 35.13747453689575, 36.43986225128174, 37.284189973558696, 35.29266950062343, 38.115323066711426, 35.66887971333095, 36.1840261050633, 36.350796767643516, 38.63173055648804, 39.22536727360317, 45.488765307835166, 46.8819694519043, 46.56601749147688, 45.94054412841797, 48.6006133215768, 50.237601961408345, 46.45850454057966, 45.04797158922468, 43.74434362139021, 42.36180148805891, 40.57566629137312, 39.28635161263602, 41.83058391298567, 40.12340109688895, 39.44066762924194, 39.83703456606184, 43.04061617170061, 47.47031511579241, 49.94079576219831, 49.43039151600429, 47.12280443736485, 41.78758151190621, 40.82935891832624, 37.08743783405849, 40.63527141298567, 40.53483172825405, 45.88553524017334, 50.94646760395595, 54.42139026096889, 55.0026661327907, 55.191118649074006, 45.521838733128135, 7.151167631149292, 0.5898614025541714, 4.8478211249623975, 1.5589603696550642, 0.20112712973994867, 2.134379561458315, 41.417541299547466, 43.771250520433696, 40.78386558805193, 38.3160982131958, 25.847910199846538, 41.36781651633126, 49.5779573576791, 52.576699120657786, 43.45575019291469, 2.694924614259175, 0.10696257757289068, 0.03055243021143334, 0.0459367393382958, 0.01703520179060953, 0.014612487417512705, 0.02314700249449483, 0.01905168403339173, 0.0635464804779206, 0.042161021049001386, 0.08500733532543693, 0.08024258778563567, 0.07062619272619486, 0.1159829678280013, 0.2220416281904493, 0.14843326727194445, 0.09021283207195145, 0.1108870951990996, 0.16389410836356028, 0.11669975865100111, 0.0852896466052958, 0.12627111934125423, 0.12762217755828584, 0.2075181696563959, 0.25432656865034786, 3.6035008089882985, 47.8731404032026, 60.440934317452566, 52.32542099271502, 42.52550452096121, 26.568375859941753, 38.9664044380188, 48.56858560017177, 42.96370308739798, 52.285656452178955, 33.97209487642561, 0.162196671590209, 0.9388053097895214, 7.162005952426365, 15.187798057283674, 21.579164539064678, 24.67068386077881, 57.388552461351665, 51.803548744746614, 52.60534306934902, 41.730022634778706, 49.1553818157741, 49.261289732796804, 53.198236329214915, 51.689622606549946, 52.22721862792969, 43.76044954572405, 38.543120179857524, 42.450457027980256, 50.0157425062997, 50.45816905157906, 49.898349217006135, 45.55135120664324, 44.872373240334646, 44.24428040640694, 51.4457060950143, 48.113311835697715, 47.71587487629482, 49.67047957011631, 49.2350880759103, 50.1149662562779, 49.57383707591465, 47.14790480477469, 45.58465739658901, 42.04764216286795, 45.69596058981759, 48.89612715584891, 49.47875445229666, 41.87933594839913, 39.30015768323626, 36.77685683114188, 39.03679663794381, 37.428535325186594, 36.97481795719692, 35.945338112967356, 36.40146997996739, 37.708078724997385, 38.058014324733186, 36.207608291081016, 37.726599148341585, 36.71375676563808, 45.84285593032837, 46.83975567136492, 47.43276705060686, 47.787146023341585, 43.612977504730225, 40.652318818228586, 41.718683174678254, 45.12174756186349, 49.00607197625296, 49.969891343797954, 49.920663356781006, 47.11859382901873, 47.12863745008196, 50.187032972063335, 52.0275274004255, 41.06477083478655, 50.723746572222026, 47.9091876574925, 46.951802321842735, 47.447254044669016, 48.70458616529192, 46.0933906010219, 46.312265804835725, 50.88358293260847, 48.84345981052944, 48.99525015694754, 47.86816201891218, 44.57184280667986, 44.1655399458749, 42.536559104919434, 40.50923456464495, 37.679608481270925, 38.70346375874111, 36.870119026729036, 39.36010326657976, 38.89751304898943, 37.45321880068098, 40.03671537126814, 38.60292679922921, 38.54009076527187, 39.48139796938215, 41.08950294767107, 41.66305589675903, 47.732686042785645, 48.87478576387678, 48.985418455941335, 46.65020186560494, 50.24217735018049, 52.29470648084368, 49.05785690035139, 49.045350142887656, 45.66848393848964, 45.17886175428118, 41.277635846819194, 41.722285815647666, 45.17626312800816, 42.211345195770264, 40.36576816013881, 41.04391929081508, 45.31876025881086, 49.22996377944946, 52.388086795806885, 51.55756861822945, 47.77403129850115, 44.7474376814706, 43.26370198386056, 38.463893345424104, 43.0782858303615, 43.059338092803955, 48.15157209123884, 54.43646090371268, 56.715230328696116, 59.32398360116141, 56.37825659343174, 51.161132199423655, 8.667812602860586, 3.8690370747021268, 6.231493643351963, 1.0774916793618883, 0.30910011380910873, 2.304046320063727, 48.259623527526855, 49.54842403956822, 47.49368190765381, 47.146487372262136, 34.80808476039341, 45.64749690464565, 57.624464648110525, 59.15532997676304, 54.687704290662495, 3.559425128357751, 0.30823224037885666, 0.1911302868809019, 0.0754598726385406, 0.0825727991759777, 0.2339564859867096, 0.13782585146171705, 0.0892789303990347, 0.13503517263701983, 0.12387541575091225, 0.21225829316037043, 0.15903399272688798, 0.1161730797695262], [0.03915026956903083, 0.0720834688150457, 0.009691528393886983, 0.01565221171560032, 0.004285251439016844, 0.02124763878860644, 0.010713520027430994, 0.08194216194429568, 0.02130753986005272, 0.021768986081172313, 0.060322434907513, 0.07808061236781733, 4.672406903335026, 37.55694498334612, 42.55657686505999, 38.26547016416277, 17.877925157546997, 9.758034467697144, 22.29235369818551, 36.567062922886436, 37.36084597451346, 41.45943546295166, 25.779189041682653, 0.12629389097648008, 0.8242334776691028, 2.0185976028442383, 3.35531028679439, 1.059565326997212, 16.216746364321025, 53.285745416368755, 49.31404740469796, 47.35640982219151, 45.44087832314627, 47.00914927891323, 47.77442387172154, 48.75931365149361, 49.84843683242798, 47.63108600888933, 43.66704838616507, 38.2428503036499, 38.49068907329014, 42.671489647456575, 47.130794865744456, 46.547243458884104, 41.56966168539864, 42.390198775700156, 45.2029025214059, 44.195490155901226, 43.285234451293945, 44.878699575151714, 43.87878779002598, 43.39679820196969, 42.851295130593435, 42.355426515851704, 41.083030700683594, 41.87270041874477, 45.498121057237896, 45.31582464490618, 45.77228307723999, 41.58348512649536, 36.36555821555001, 33.93595034735543, 33.55370215007237, 33.6210857800075, 34.420747007642476, 33.34153890609741, 32.94933046613421, 33.41005856650216, 33.21613086972918, 34.142016547066824, 34.13502318518502, 33.77383845193045, 35.51069702420916, 44.33169569287981, 45.45669937133789, 43.90147018432617, 44.04408890860421, 39.878775869097026, 34.29921606608799, 37.09162412370954, 40.477571623665945, 42.899967261723106, 40.76199960708618, 40.41559369223458, 37.85291739872524, 42.90951061248779, 45.59455163138253, 46.749592372349326, 35.081687450408936, 46.87557710920061, 46.3329610143389, 43.81747341156006, 43.370985644204275, 46.25945602144514, 44.937363215855186, 45.536092962537495, 40.62790979657854, 42.664166246141704, 46.146120480128694, 43.46424436569214, 42.48130702972412, 37.98994977133614, 35.64656209945679, 33.915810993739534, 34.10416276114327, 35.02551473890032, 33.600880418504985, 35.09934977122715, 34.0335100037711, 34.74119445255825, 35.23307132720947, 36.44217600141253, 34.7041848727635, 34.74567951474871, 34.91542748042515, 33.257291998182026, 38.958090918404714, 45.06026642663138, 44.531845501491, 46.64852040154593, 43.7688638142177, 47.016059262411936, 47.237665108272004, 44.62080328805106, 41.7981219291687, 40.12187596729824, 42.290245464869905, 41.90144511631557, 42.48457963126046, 40.34086581638881, 39.077759742736816, 37.634629317692344, 36.516521726335796, 37.87435259137835, 39.2234982081822, 38.88535022735596, 40.26506791796003, 37.13373020717076, 36.72057294845581, 40.06581790106637, 38.63153600692749, 39.776877062661306, 39.03259992599487, 45.51437289374215, 52.71139342444283, 54.149045194898335, 54.354197706495015, 52.133199078696116, 18.63554457255772, 0.3852919696697167, 4.329771254743848, 0.24926996284297534, 0.14727966274533952, 1.1308347369943346, 32.698048864092144, 46.83089671816145, 29.752151625497, 47.54074553080967, 23.80334891591753, 21.52642250061035, 42.584703172956196, 44.19684158052717, 35.58640112195696, 1.990437422479902, 0.09506494099540369, 0.008793518678950412, 0.01586564490571618, 0.10457705200782844, 0.05019876706813063, 0.04125155681478126, 0.008920442895032465, 0.0374447853703584, 0.04943876374246819, 0.035749072075954506, 0.020563879050314426, 0.09694387910089322, 0.02739585137792996, 0.01870310871994921, 0.05416127587003367, 0.053942268514739614, 0.02125205605157784, 0.01320701917367322, 0.05666868668049574, 0.025510085513815284, 0.032186997322631736, 0.04174955741369298, 0.08757177021886621, 0.11427713079111916, 6.054937745843615, 45.784522329057964, 50.34004272733416, 43.137123176029746, 21.642427887235367, 15.885028941290718, 24.7709515775953, 39.80490609577724, 40.55168110983712, 46.712075574057444, 28.3555063860757, 0.040704318322241306, 0.8593537988407272, 4.4057020374706815, 9.210479940686907, 4.729353470461709, 16.767738512584142, 54.48472309112549, 50.239203521183555, 49.8427323613848, 47.01686177934919, 48.360261235918315, 48.73027712958199, 52.5361007962908, 51.05089555467878, 49.94640990665981, 44.70438664300101, 40.09089394978115, 40.24430322647095, 44.26135560444423, 47.94076027188982, 47.031331402914866, 42.81859343392508, 44.08202954701015, 43.848205293927876, 45.21705947603498, 43.510324818747385, 45.36802993501936, 44.50872884477888, 44.21305867603847, 43.502681800297324, 41.98131118501936, 41.536289487566265, 42.437140805380686, 46.46823896680559, 47.04773609978812, 47.865174293518066, 44.00508172171456, 36.68567214693342, 35.04026229040963, 34.45451872689383, 35.124168736594065, 34.39271102632795, 35.03696189607893, 34.92564133235386, 35.55573524747576, 34.952492645808626, 34.781247343335835, 33.72223765509469, 34.71377338681902, 36.60460751397269, 45.04189886365618, 48.29882526397705, 46.074606146131245, 45.96975435529436, 40.79670933314732, 36.27493633542742, 38.320267132350374, 40.19226469312395, 45.029392106192454, 43.2980295589992, 42.445301464625764, 39.58423130852835, 44.000739097595215, 48.75215005874634, 48.90867212840489, 36.87940182004656, 48.94688722065517, 49.182570116860525, 44.37325634275164, 44.71813712801252, 48.49643203190395, 46.389571462358745, 44.106935364859446, 43.66629103251866, 44.56283794130598, 47.761121545519146, 45.63233593532017, 44.87022277287075, 39.382538999829976, 37.21311337607247, 35.51314973831177, 36.44676181248256, 35.67558125087193, 36.06986720221383, 36.55280521937779, 36.68411922454834, 35.113534518650596, 36.92992912020002, 36.07468925203596, 36.62137699127197, 36.29768821171352, 36.44970090048653, 35.43300574166434, 39.69701099395752, 46.57477569580078, 46.39555038724627, 46.538599899836946, 44.758999483925955, 48.927091802869526, 48.69652278082711, 46.88886901310512, 44.27973011561802, 43.446363176618306, 44.66773836953299, 44.427268164498464, 43.565754073006765, 43.59009708677019, 40.911048889160156, 38.56421491077968, 37.58805206843785, 39.45187854766846, 42.12880059650966, 41.49234560557774, 40.65065472466605, 39.553224972316194, 38.757652759552, 41.344925676073345, 41.52977902548653, 40.753185817173545, 42.45171812602452, 49.59271533148629, 54.444913387298584, 55.23498610087803, 56.51374299185616, 54.456534249441965, 21.08233186176845, 0.1941182158355202, 2.7117709560053687, 2.0125311740807126, 0.05315531038546136, 0.8961390820997102, 37.286958830697195, 49.846262046269004, 37.6071491922651, 49.44111606052944, 25.380788019725255, 27.97216558456421, 47.9210204396929, 50.26411281313215, 44.57956920351301, 2.6628452156271254, 0.06772732149277415, 0.03501486325902598, 0.022416240635461042, 0.02295141138269433, 0.022397331560828855, 0.038723464256950786, 0.048975463424410136, 0.027244556728484373, 0.04273919056036642, 0.0285852418414184, 0.09173840271042925, 0.020023062891725982, 0.13339842403573648, 0.14316461927124433, 0.18190481620175497, 0.1371344785605158, 0.09684473156396832, 0.08275352019284453, 0.11117689072021417, 0.18579174977328095, 0.11241888121834823, 0.19917081828628266, 0.15810741244682244, 0.12098150460847787, 7.614280700683594, 55.96122223990304, 55.558608872549875, 51.280231271471294, 26.89722888810294, 18.009756803512573, 30.38084547860282, 46.52873345783779, 47.501790455409456, 51.67753274100167, 31.726516996111187, 0.16370125514056, 1.04840977702822, 4.43891008411135, 9.037130202565875, 2.8262755317347388, 18.648631504603795, 55.76204170499529, 53.24384430476597, 52.48260661533901, 49.03819349833897, 49.94516965321132, 52.4231196131025, 55.07196051733834, 52.982331480298726, 50.858076095581055, 47.64158821105957, 42.00038399015154, 43.10770797729492, 45.025824206215994, 50.99565390178135, 49.53268984385899, 45.31008195877075, 47.280723094940186, 45.514157499585835, 45.8661984034947, 42.649922439030235, 47.33976193836757, 45.12847341809954, 43.487367970602854, 45.54762349809919, 42.804019587380544, 41.72502340589251, 43.137251717703684, 47.010792527879985, 47.47617244720459, 49.67670168195452, 45.93400934764317, 39.19280801500593, 37.9837589263916, 36.61906671524048, 37.36368778773716, 36.97376877920968, 36.06319693156651, 35.921418939317974, 36.755949701581685, 35.53416109085083, 37.0137174470084, 35.944236823490684, 36.87123768670218, 39.235952854156494, 46.99004520688738, 50.22645010266985, 48.28444249289376, 48.19589465005057, 43.534883226667134, 38.44321550641741, 40.1333578654698, 43.85674810409546, 46.91935076032366, 44.12447261810303, 43.44149248940604, 41.130743980407715, 44.963627406529014, 50.64632279532296, 51.74280064446585, 41.60339171545846, 49.93338550840105, 51.09682662146432, 46.23613439287458, 47.47790949685233, 50.05833148956299, 48.39083330971854, 45.96754830224173, 42.35486371176583, 46.55650888170515, 50.188165528433665, 48.70532267434256, 46.44923564365932, 42.444849831717356, 38.79719843183245, 37.37372446060181, 38.76092883518764, 38.21050296510969, 36.80933618545532, 37.32294007710048, 37.776841572352815, 38.16343239375523, 39.809821946280344, 39.432239464351106, 38.827798298427034, 37.79649107796805, 38.86882046290806, 35.75636795588902, 43.7026162147522, 49.731846060071675, 49.15171316691807, 50.02067920139858, 45.0679372378758, 51.96746022360665, 50.54932246889387, 48.92825215203421, 46.18875462668282, 44.46369756971087, 47.63312183107649, 46.35008832386562, 46.3916837147304, 44.25648144313267, 43.39055871963501, 42.00008521761213, 40.11658491407122, 40.9148599760873, 44.275832176208496, 43.364047867911204, 43.974492277417866, 41.49316896711077, 41.246928283146445, 44.592058590480256, 43.45963076182774, 42.622817516326904, 42.586245673043386, 49.739846910749165, 58.20020627975464, 58.392355237688335, 59.15112631661551, 55.63816922051566, 26.592922108513967, 1.8364890090056827, 12.001694645200457, 5.86214998790196, 0.13928656093776226, 1.3949734377009528, 40.382318769182476, 57.80946043559483, 42.81641864776611, 56.643531867435996, 32.17738560267857, 33.52004855019705, 54.14880200794765, 57.79917710168021, 56.613939489637104, 5.211881543908801, 0.2856584931058543, 0.10912920774093696, 0.13210867824298994, 0.15912186301180295, 0.10822436093751873, 0.1534209203507219, 0.08953929785639048, 0.09299217257648706, 0.12244868730860096, 0.12033509143761226, 0.13483526264982565, 0.2076300736516714], [0.029217351494090896, 0.05312528521088617, 0.014199991560807186, 0.027769456151872873, 0.029407555037843328, 0.048824061905699115, 0.020503891465653266, 0.04835657163390091, 0.028635609495852674, 0.016105328919366002, 0.033874398563057184, 0.0664758790018303, 6.1644904272896905, 39.086368560791016, 40.86108439309256, 43.81924867630005, 22.470769541604177, 26.712033339909144, 45.444474015917095, 52.46082748685564, 36.94082042149135, 41.11479091644287, 22.026196002960205, 0.16282143949397973, 1.0990916746003287, 9.219767945153372, 15.522326026644025, 3.6450827377183095, 17.889325414385112, 51.9127779006958, 49.37347534724644, 48.46644013268607, 48.14693416867937, 48.35326439993722, 51.33109903335571, 45.03035790579659, 42.39881106785366, 48.0180971963065, 45.33219460078648, 39.46903712408883, 37.28211246218, 42.3412070274353, 45.5007301058088, 48.87378869737898, 42.02778768539429, 40.746908119746614, 45.66270998546055, 43.27171325683594, 45.69250733511788, 45.710315568106516, 46.04757765361241, 46.24643857138497, 46.306495325905935, 46.005370821271626, 45.12357146399361, 45.04118667330061, 46.98217289788382, 44.476843561444966, 42.906578472682405, 37.418578556605745, 33.066397190093994, 32.8695581981114, 33.07916103090559, 34.44292218344552, 34.07784645898001, 33.863581384931294, 35.02855110168457, 34.76769835608346, 34.26469741548811, 33.167771407536094, 34.89999900545393, 33.48031875065395, 38.224423680986675, 44.1523939541408, 45.867942401341026, 44.86374357768467, 43.62835734231131, 39.34848240443638, 36.0258538382394, 35.98629426956177, 36.54604114804949, 37.85942438670567, 37.97206163406372, 37.15011753354754, 38.11773061752319, 44.777870791299, 47.08292872565133, 47.37979051045009, 31.191623823983328, 45.57601383754185, 47.57220697402954, 42.42176791599819, 44.93552541732788, 44.51234885624477, 48.16548933301653, 39.92409896850586, 40.221721581050325, 45.76181909016201, 45.38122109004429, 46.118991238730295, 43.824706486293245, 47.16027954646519, 43.376252378736226, 39.473108768463135, 32.436351912362234, 33.258921350751606, 34.636773450034006, 34.61185373578753, 33.81647607258388, 34.06919247763497, 35.240200178963796, 35.73704848970686, 34.123093128204346, 34.366988795144216, 36.32661356244768, 33.87003626142229, 35.36560126713344, 42.65937893731253, 44.43557126181466, 46.581379958561485, 45.63645969118391, 43.12028421674456, 48.53063453946795, 44.531550203050884, 45.797703061785015, 43.39250768933977, 45.66786207471575, 44.979639530181885, 46.5620049067906, 42.50293329783848, 41.578437260219026, 38.08579322269985, 38.34781673976353, 35.3623286655971, 36.050141266414094, 36.09128849846976, 36.74714633396694, 38.07087196622576, 40.65228407723563, 42.341550963265554, 42.29030105045864, 40.28771557126726, 42.314178534916465, 43.09890113558088, 48.761460644858225, 49.85068110057286, 54.10881165095738, 54.0608343396868, 40.68052503040859, 2.3850527618612563, 1.581259310245514, 1.992034639630999, 0.06505469419062138, 0.6025161892175674, 27.408322743007115, 53.97810213906424, 32.475129808698384, 44.26526049205235, 37.37407534463065, 29.055858748299734, 45.56857926504952, 40.333250590733115, 36.946549211229595, 2.220490323645728, 0.17359349504113197, 0.05099365727177688, 0.038173440378159285, 0.038059042766690254, 0.05187324221645083, 0.012696969489167844, 0.06058613397181034, 0.02611621914963637, 0.02748200496924775, 0.06090421761785235, 0.03342799376696348, 0.025773954211867282, 0.01967489130661956, 0.03189280489459634, 0.004956576599007738, 0.056986342849476, 0.011480779436949109, 0.011725555855913885, 0.005976894371477621, 0.04009775551302092, 0.11100750123815877, 0.060438966511615684, 0.03554245477010097, 0.026545070244797637, 8.575097577912466, 48.00412436894008, 49.783467701503206, 49.72912931442261, 28.817863839013235, 22.78096318244934, 42.507901259831016, 58.45843955448696, 41.66046074458531, 45.72924246106829, 23.831878219332012, 0.09107186419091054, 0.6822256520390511, 6.985252031258174, 6.566457177911486, 4.629061869212559, 20.50857741492135, 53.39073269707816, 51.858613218579976, 51.136632851191926, 49.049988065447124, 50.086172921316965, 52.44712216513497, 46.56877940041678, 43.60118988582066, 50.019859313964844, 46.607116086142405, 41.17353446143014, 38.318974767412456, 45.15620715277535, 47.165918009621755, 49.88391433443342, 44.185415267944336, 43.30551971708025, 47.855457237788606, 41.99618033000401, 46.76788697923933, 47.29583542687552, 47.02018301827567, 47.277533871786936, 46.017759459359304, 46.153402192252024, 45.79523297718593, 47.19542006083897, 48.021727630070274, 46.62027597427368, 45.34386757441929, 39.70887851715088, 35.03228228432791, 34.21909638813564, 34.26940482003348, 36.340086119515554, 34.03242955889021, 36.388820784432546, 36.23197562353951, 37.34684535435268, 35.18561513083321, 34.20035014833723, 35.38835661751883, 34.4794453893389, 39.711303438459126, 47.67847967147827, 46.68937928336007, 47.166869912828716, 47.14158541815621, 40.95739337376186, 37.64091048921858, 38.24005017961775, 38.397875036512104, 40.12890059607369, 40.63250255584717, 39.160405090876985, 39.69281775610787, 46.46951743534633, 49.7159138407026, 49.20667689187186, 32.63304846627371, 46.63367210115705, 49.10512202126639, 45.10739605767386, 46.13859210695539, 47.463776860918315, 47.581420285361155, 43.364176409585134, 42.17459964752197, 47.72078725269863, 46.466456753867014, 47.723132269723074, 45.46267134802682, 47.78068767275129, 44.43441438674927, 41.26186343601772, 33.55533150264195, 36.44115114212036, 34.4082020350865, 34.38838577270508, 35.232574531010215, 35.3398060798645, 36.363129820142476, 36.9287930897304, 35.314493792397634, 36.702274867466514, 35.38179404394967, 36.38311978748867, 37.251036643981934, 43.937128339494976, 47.35286276681082, 47.46175493512835, 46.172492367880686, 45.1264271736145, 49.446473121643066, 48.023325715746196, 47.360464096069336, 45.49928488050188, 47.650634765625, 46.33008793422154, 47.96499211447579, 45.07817540849958, 42.83165257317679, 39.49669790267944, 38.88378340857369, 39.16653340203421, 37.42371327536446, 38.217162813459126, 37.89989416939871, 40.13969462258475, 42.42196593965803, 44.5179352079119, 44.592392104012625, 42.18396929332188, 42.988713128226145, 44.75718600409371, 51.933028425489155, 51.67914819717407, 57.53737245287214, 56.08723476954869, 43.113874503544395, 3.039173330579485, 0.7671517463667052, 0.5463497202311243, 0.04173853461231504, 0.45570183864661623, 27.833962440490723, 57.99313259124756, 38.12024239131382, 49.966695172446116, 38.48171894890921, 33.29172032220023, 51.86605473927089, 46.945552417210166, 47.451360430036274, 5.884657374450138, 0.20411393232643604, 0.016036130221826688, 0.03519234087850366, 0.07374991689409528, 0.016239193700520054, 0.03271801543555089, 0.03202830155247024, 0.03541054077712553, 0.04650779101731522, 0.05355397006496787, 0.056079650430807045, 0.02946662829656686, 0.14038514984505518, 0.08966017208461251, 0.12218169734946319, 0.15715772126402172, 0.16099889443389007, 0.15250861644744873, 0.10479098052850791, 0.09157410902636391, 0.21427458710968494, 0.1792077344975301, 0.2036813119692462, 0.10919002483465842, 11.919412340436663, 57.48934997831072, 55.68975612095424, 58.44225719996861, 32.009062017713276, 38.27710492270333, 54.49109806333269, 59.99743774959019, 45.618766103472026, 50.713866233825684, 26.38540894644601, 0.20748834125697613, 1.6887327432632446, 21.3398859500885, 22.962140934807913, 6.2563681943075995, 19.767161199024745, 56.916505745479036, 53.28328227996826, 52.788539273398264, 52.840907846178325, 52.37857471193586, 54.64088038035801, 47.975980690547395, 46.89733191898891, 52.28734833853585, 49.7764048576355, 42.38301086425781, 40.73536368778774, 46.10353149686541, 48.94016831261771, 51.31328732626778, 45.229990073612754, 44.5119389125279, 48.41041333334786, 44.25605065482003, 47.75860629762922, 48.419584955487935, 48.778567109789165, 49.9066036769322, 48.93009342466082, 48.900789397103445, 47.13158001218523, 48.62218400410244, 50.935895919799805, 47.93697697775704, 47.33048609324864, 41.72558968407767, 36.865908418382915, 35.74754721777779, 36.784093379974365, 38.72348846708025, 36.185314995901926, 37.430824756622314, 37.98612131391253, 38.606466906411306, 36.41102722712925, 36.21739830289568, 37.46736880711147, 37.59605291911534, 42.219842842647004, 48.57063184465681, 49.546784264700754, 49.15110519954136, 48.47035196849278, 42.11346244812012, 38.84097555705479, 40.20340265546526, 40.86810554776873, 42.29507098879133, 42.85003750664847, 41.12368113654, 42.11327484675816, 48.77207401820591, 51.1779329436166, 49.297906739371165, 35.0168433870588, 48.09422166006905, 50.626607281821116, 47.37660476139614, 48.65722376959664, 48.354859011513845, 50.64043419701712, 42.74896900994437, 43.932771818978445, 48.91449819292341, 48.65899903433663, 50.90823861530849, 47.218911920275005, 51.09588514055525, 46.953740869249614, 42.729826722826274, 36.31924499784197, 38.168994426727295, 36.51263073512486, 36.559086390904014, 37.0604510307312, 37.67854193278721, 38.88058723722185, 38.84230266298567, 37.440764154706685, 37.88417387008667, 39.71684462683541, 37.874067715236116, 38.66752767562866, 47.33517612729754, 48.447881494249614, 51.24586200714111, 47.151802744184224, 46.633175304957796, 51.683831283024375, 50.6180088860648, 50.51027011871338, 46.87830427714756, 49.74495036261422, 47.59923546654837, 50.740297181265696, 46.40704270771572, 45.559442383902415, 42.696246079036165, 41.88103478295462, 40.79032046454293, 39.41228771209717, 39.980132716042654, 39.60019826889038, 42.459812777382986, 45.891944953373496, 46.52402605329241, 47.395309312003, 43.83379125595093, 46.56692770549229, 45.7440629686628, 54.84624481201172, 53.135139737810405, 60.88574409484863, 58.42693642207554, 48.45298147201538, 4.353302197796958, 5.737739886556353, 7.8897237948008945, 0.12891857299421514, 1.025986203125545, 33.25817789350237, 64.15856797354562, 44.795859677451, 55.7291385105678, 45.62798636300223, 40.720748152051655, 57.47986568723406, 55.17349106924874, 57.739123821258545, 12.121192370142255, 0.2996510522706168, 0.23148547857999802, 0.1567213689642293, 0.1882873201476676, 0.15517563905034745, 0.11624086541788918, 0.10304779013884918, 0.12622276693582535, 0.16349933668971062, 0.19451619019465788, 0.1819994311247553, 0.10151702870747872], [0.016798415121489337, 0.02426857507920691, 0.03521636101816382, 0.00824883911159954, 0.03581391966768673, 0.02521399318772767, 0.082051548574652, 0.006204600121626365, 0.0738524706768138, 0.08512998731540782, 0.023490395496732423, 0.038603824962462695, 8.230675373758588, 38.76355178015572, 46.135892731802805, 36.72825418199812, 13.763202820505414, 30.33988584790911, 48.65156446184431, 55.72748483930315, 31.650288309369767, 44.37489264351981, 18.384518316813878, 0.351556837026562, 2.319285673754556, 20.319815703800746, 5.024868607521057, 8.300031423568726, 19.61520756993975, 52.79915959494454, 50.62856667382376, 51.91095052446638, 49.731074810028076, 52.3162841115679, 45.285575662340435, 45.62934126172747, 47.43540736607143, 52.251321928841726, 44.53885970796858, 37.53610038757324, 35.03722940172468, 43.99416610172817, 46.05468566077096, 47.10636499949864, 44.45078086853027, 42.14149495533535, 43.12548841748919, 47.14048760277884, 47.444843019757954, 47.029632568359375, 44.338352067129954, 45.434621470315115, 44.73239483152117, 45.33631835665022, 46.675562790461946, 44.47263642719814, 44.48535163061959, 41.34912586212158, 35.26115942001343, 34.4122702053615, 32.2429210117885, 32.46087210518973, 32.22748906271798, 34.13556514467512, 32.84766789845058, 34.21867602212088, 34.92144462040493, 32.86416639600481, 33.94924572535923, 33.56776530402047, 32.55253621510097, 34.07740177427019, 41.39870820726667, 46.788061073848176, 43.480972153799875, 43.817727020808626, 46.21230901990618, 39.812771456582205, 36.98968015398298, 36.629482064928325, 36.593330587659565, 37.577348368508474, 39.80133819580078, 38.97736174719674, 40.60793719972883, 44.96354055404663, 46.84139544623238, 44.679157733917236, 29.79706130708967, 41.969732012067524, 46.259810379573274, 43.73785400390625, 42.343979358673096, 44.0942097391401, 46.911346435546875, 37.65666900362287, 40.86433267593384, 46.26997559411185, 46.06982578550066, 46.54929665156773, 46.43846246174404, 47.78508240836007, 46.22502422332764, 46.57468884331839, 41.83004542759487, 35.1083094733102, 34.639302594321116, 34.29737479346139, 34.97016886302403, 34.748316356113975, 34.856906277792795, 35.53688825879778, 38.226275375911165, 35.447152273995535, 34.51204981122698, 34.95662334987095, 34.41276005336216, 37.42204223360334, 43.32610722950527, 44.30330882753645, 47.236852169036865, 44.44604567119053, 47.10184519631522, 48.93255308696202, 45.81816898073469, 46.02027818134853, 49.606139251164024, 47.12950250080654, 47.73358236040388, 46.20370715005057, 46.01262126650129, 43.50533948625837, 40.37191731589181, 37.42641959871565, 36.407025064740864, 34.55200890132359, 36.25555780955723, 39.56420660018921, 45.165868622916086, 43.13535833358765, 45.911017758505686, 43.38782112939017, 43.60124199731009, 41.149410315922324, 46.97447429384504, 48.13052947180611, 54.12243012019566, 53.5209002494812, 56.242975166865754, 10.188108852931432, 1.2173531630209513, 0.9739383331366948, 0.034624515633497915, 0.10971075296401978, 21.677738632474625, 55.17278235299246, 38.65656341825213, 39.06173024858747, 28.588995388575963, 21.972856419427053, 28.969492639814103, 45.818307944706504, 37.33911895751953, 8.289101907185145, 0.041748393726136, 0.042018186034900804, 0.07207044094268765, 0.03991609811782837, 0.03253384746078934, 0.03887442812057478, 0.04071663373282977, 0.045704632864466736, 0.02060895073892815, 0.04615548545760768, 0.03968341488923345, 0.02249023996825729, 0.07530497666448355, 0.022495714049520235, 0.028439265210181475, 0.05873380122440202, 0.0591878497174808, 0.018597454032195464, 0.0178471249195614, 0.019977848710758344, 0.01870771766906338, 0.03773847568248, 0.04606743875358786, 0.016572200027959685, 11.81974824837276, 47.13007920128958, 52.10860940388271, 43.34202555247715, 17.933917215892247, 32.21601758684431, 54.22681985582624, 60.93674387250628, 36.73270102909633, 47.11094733646938, 20.95579821722848, 0.4358085761112826, 2.9502151097570146, 23.25622865131923, 7.357866985457284, 4.825934299400874, 19.779396976743424, 53.02243995666504, 51.125922203063965, 54.08921773093087, 52.48058468954903, 54.23723520551409, 46.799723625183105, 45.057424613407676, 48.0532238142831, 52.585676193237305, 45.780811991010395, 39.26532983779907, 36.9104220526559, 44.383286067417686, 47.96572862352644, 48.951160362788606, 44.00791311264038, 43.43883827754429, 42.62047597340175, 47.01770945957729, 47.36806889942714, 47.21254389626639, 47.19723701477051, 47.9671391078404, 45.587061473301475, 47.49177115304129, 49.26626811708723, 46.68330308369228, 46.23413678577968, 43.44962535585676, 38.416312081473215, 35.88889789581299, 33.76982239314488, 34.021434034620015, 33.761123248508994, 35.42170797075544, 34.671604769570486, 34.54786777496338, 36.489955289023264, 33.357644830431255, 35.24116597856794, 35.005632468632285, 34.832841191973, 34.85272346224104, 41.41114548274449, 47.590390409742085, 45.665423257010325, 45.72893326623099, 48.140597411564414, 41.05026299612862, 38.911416394369944, 38.712968894413535, 39.65605136326381, 38.903297424316406, 40.36366980416434, 39.6436106136867, 42.37790046419416, 47.3058443069458, 46.83981473105294, 47.96869203022548, 31.249693393707275, 44.0239634513855, 49.69127900259835, 45.74876342500959, 45.16374594824654, 45.4335549218314, 46.8295452935355, 40.46692698342459, 43.1506860596793, 48.32906035014561, 47.97836739676339, 48.11307212284633, 47.952641691480366, 48.793068000248496, 47.56742313929966, 48.321809904915945, 43.22859968457903, 36.29416200092861, 35.283720220838276, 36.49334600993565, 35.90372882570539, 36.04780667168753, 37.37104940414429, 37.46719510214669, 39.34050587245396, 37.52616098948887, 36.12795761653355, 37.417327880859375, 35.32814700262887, 38.10160384859358, 46.77755887167794, 46.433904443468364, 48.80493204934256, 45.26065942219326, 47.775295870644705, 49.9384229523795, 48.38164431708199, 48.27547584261213, 50.26388699667794, 50.105037280491416, 48.924156188964844, 47.6225015095302, 47.430564471653526, 44.910247870853965, 41.59472731181553, 40.0700979913984, 37.63145399093628, 36.44645956584385, 38.439216818128315, 40.88530928747994, 47.46495805467878, 44.35326637540545, 46.97737864085606, 45.046012197222026, 46.43259470803397, 44.09611007145473, 48.87270130429949, 49.4066356250218, 56.443548815590994, 55.832756996154785, 58.780245372227256, 11.445860471044268, 0.3767591746790068, 0.6799262868506568, 0.08014274135764156, 0.05392557316060577, 24.853734152657644, 60.001926285879954, 42.06200756345476, 46.07354654584612, 35.942885398864746, 28.110790831702097, 36.51923499788557, 52.610286712646484, 46.64221838542393, 14.128609452928815, 0.0147202760979001, 0.014096516666800847, 0.05380551656708121, 0.02775953257722514, 0.05215815228543111, 0.05031474566619311, 0.04108865412750414, 0.04335297637486032, 0.033643435420734544, 0.021048398854743158, 0.05370980920270085, 0.019467700638675263, 0.1636010626597064, 0.12571180292538234, 0.16988857170300825, 0.16781695000827312, 0.11866425323699202, 0.1081219157204032, 0.129374697804451, 0.0840898881267224, 0.17787175332861288, 0.13711679593792983, 0.22044766800744192, 0.10464139069829669, 15.899495090757098, 58.24210391725813, 58.735346112932476, 49.951291016169954, 22.329875707626343, 39.98390906197684, 54.43588767732893, 59.56192466190883, 40.83330202102661, 54.053420611790244, 22.237275327954972, 0.44462657294103075, 2.902532662664141, 33.969392027173726, 11.713901996612549, 15.031619923455374, 22.401367459978374, 54.2736576625279, 53.37657574244908, 55.95874868120466, 53.86828933443342, 55.052800859723774, 47.46657698495047, 46.95049606050764, 48.34800113950457, 55.991738728114534, 49.25125305993216, 41.28537614004952, 38.9458065032959, 46.66221182686942, 50.35048239571707, 50.192973681858604, 45.22983373914446, 44.1560834475926, 44.2677583694458, 48.78591135569981, 49.35981866291591, 49.86799948556082, 49.82846770967756, 49.13486725943429, 47.786426884787424, 48.386115482875276, 51.09702811922346, 48.35684272221157, 48.938955851963584, 45.04640129634312, 39.995467390332905, 38.65148775918143, 35.17875031062535, 34.506060464041575, 36.123736585889546, 37.65156207765852, 36.1110109601702, 36.115204198019846, 37.987330300467356, 35.87363965170724, 35.993374483925955, 36.09185477665493, 36.82542126519339, 37.50933245250157, 44.54033967426845, 50.62901830673218, 46.39308377674648, 46.9834166254316, 50.61575419562203, 43.1023439679827, 40.26264647075108, 40.872878960200715, 40.07557317188808, 42.117405550820486, 44.423040185655864, 40.9876423563276, 44.39484786987305, 48.73325790677752, 49.32319123404366, 49.383289677756174, 35.40269422531128, 46.561323983328684, 50.78596421650478, 47.05189459664481, 46.89377791540963, 47.547523498535156, 49.270808764866416, 40.75655916758946, 43.85912091391427, 49.74519007546561, 50.054555143628804, 49.729813711983816, 48.94314214161464, 51.83766092572893, 50.30824777058193, 48.99887364251273, 45.06218760354178, 39.67197316033499, 37.04758991513933, 39.18688120160784, 38.12285491398403, 38.19608545303345, 38.93282379422869, 40.2105210849217, 41.18037148884365, 38.16903611591884, 37.29619993482317, 39.73940890175955, 37.84294673374721, 40.27023042951311, 47.477857385362896, 47.352779388427734, 50.363357407706125, 46.807258946555, 50.08102083206177, 53.00570869445801, 49.56841400691441, 50.61091477530343, 53.408558300563264, 51.76006344386509, 51.1562545640128, 50.587169306618826, 50.2766821043832, 46.855983189174104, 43.759647028786794, 41.903908252716064, 40.233272961207796, 38.88066019330706, 39.971909523010254, 42.92447703225272, 50.829897676195415, 46.74886975969587, 50.41229357038225, 47.53317199434553, 48.19836473464966, 46.19625173296247, 51.31348534992763, 51.59392854145595, 59.94246360233852, 59.76917552947998, 61.78592491149902, 13.983722141810826, 2.6410621787820543, 3.464793703385762, 0.23106959089636803, 0.3668338901230267, 27.438740219388688, 65.59665053231376, 49.55872821807861, 50.443320751190186, 37.2654367855617, 32.24843788146973, 43.03529385157994, 59.79531465257917, 56.71894414084298, 19.89837966646467, 0.1002383633915867, 0.09405898568885666, 0.17837967750217232, 0.07761952746659517, 0.1882418990135193, 0.12436436808535031, 0.14700016060045787, 0.10450149713350193, 0.09503855955387865, 0.12233594192990235, 0.2011286225169897, 0.11435482305075441], [0.02434396031977875, 0.011404584195198757, 0.03331227979755827, 0.012755208149818438, 0.04786882369912096, 0.13393942000610487, 0.0540604014614863, 0.0375580939331225, 0.02816384275709944, 0.038323681601988416, 0.08691372695778098, 0.0458936150451856, 11.604227287428719, 41.263336454119, 42.85707255772182, 39.28439916883196, 41.13621916089739, 38.21178838184902, 51.652043274470735, 47.420513902391704, 25.2825665473938, 52.878851958683555, 14.106488994189672, 0.15304938171591076, 2.5759108747754778, 35.97940165655953, 10.217406800815038, 3.3981300805296217, 23.93728412900652, 32.85280956540789, 39.80286679949079, 52.06617675508772, 46.42609814235142, 49.65374830790928, 48.86976569039481, 52.28764016287667, 47.68719618661063, 47.966864653996055, 41.942675726754324, 35.86024005072457, 37.92146832602364, 42.298409598214285, 46.55095032283238, 46.5056654385158, 42.909726006644114, 42.76940713609968, 42.07724496296474, 44.70111404146467, 44.733985968998496, 45.22464690889631, 40.019862515585764, 40.65147461209978, 40.96256283351353, 42.60982438496181, 41.2600291115897, 41.68649911880493, 38.228867053985596, 36.57376446042742, 32.941353934151785, 32.04557132720947, 32.32171705790928, 33.21706887653896, 34.589275564466206, 33.77836867741176, 33.4260915347508, 33.80040488924299, 33.085563795907156, 34.15958506720406, 33.9617212159293, 33.87989922932216, 32.818033831460134, 35.06809677396502, 44.384915419987266, 44.5827306338719, 46.06877313341413, 45.74289219720023, 44.59576892852783, 41.732225213732036, 40.555766650608604, 40.13756847381592, 38.14666291645595, 39.994720458984375, 39.037043298993794, 39.07255206789289, 42.48630625861031, 48.42619616644723, 46.155469281332834, 48.349567958286826, 28.322538920811244, 43.56401702335903, 47.0930175100054, 40.257438795907156, 44.08889089311872, 44.06326246261597, 48.2160826410566, 38.47786617279053, 42.39632361275809, 44.64743225915091, 44.6239195551191, 44.42755651473999, 44.57630007607596, 44.37800891058785, 44.83622176306588, 45.74526500701904, 46.11113977432251, 39.06818165097918, 34.10916199002947, 33.75752755573818, 33.130737509046284, 33.4602940423148, 37.504048347473145, 35.09383290154593, 36.93007503237043, 34.9532083102635, 33.52728162493025, 33.94580636705671, 32.96803501674107, 35.17111076627459, 38.03891372680664, 43.89915643419538, 44.42399903706142, 47.00825990949358, 44.87806034088135, 45.95641033990042, 46.281137875148225, 47.58516536440168, 47.800722803388325, 47.341064725603374, 49.57852363586426, 49.28951678957258, 47.534547737666536, 45.70201594488961, 45.04031467437744, 42.63915620531355, 39.65126405443464, 36.64686298370361, 38.435878208705354, 42.28629193987165, 46.27827869142805, 47.458357266017366, 50.37361989702497, 44.86254848752703, 45.19769137246268, 46.38803243637085, 46.975394930158345, 47.77080038615635, 52.16416025161743, 52.42710787909371, 56.15008469990322, 33.705009596688406, 1.0268768753324236, 0.6729058378509113, 0.12331164814531803, 0.05922586124922548, 12.067626970154897, 55.89891079493931, 37.94801391874041, 33.98848567690168, 32.606860705784385, 27.33415593419756, 34.90583896636963, 41.06950603212629, 40.244410923549104, 14.043124897139412, 0.060110311289983134, 0.03265921359083482, 0.05128821950139744, 0.09546622660543237, 0.04202114444758211, 0.07776911051145621, 0.038445129192301204, 0.028054493446169153, 0.05035426354567919, 0.053417672735771964, 0.029271525729979788, 0.03372448642871209, 0.06194378076387303, 0.012094946927390993, 0.030672975350171328, 0.018494119934205498, 0.012390733064551438, 0.022291544558746473, 0.02774369896256498, 0.09205168911388942, 0.068642597379429, 0.05003388984394925, 0.11339176472808633, 0.013542536928850626, 14.209658452442714, 49.49351242610386, 50.46691683360508, 42.62426968983242, 39.02623537608555, 34.95086676733834, 55.43852315630232, 53.998352663857595, 29.16712372643607, 55.89127472468785, 16.343665633882793, 0.40494902059435844, 3.6566536596843173, 45.79396145684378, 6.084622621536255, 2.9989599798406874, 23.163918358939036, 36.0406882422311, 42.24257387433733, 53.73720809391567, 45.98105212620327, 50.838506494249614, 49.05539376395089, 52.36150298799787, 48.93551301956177, 49.415213176182334, 44.12384033203125, 39.083134174346924, 39.82784904752459, 44.04138953345162, 47.80549274172102, 49.089047363826204, 44.16785717010498, 44.11378628867013, 42.86872468675886, 47.0429870060512, 45.10155609675816, 46.97247668675014, 41.669993673052105, 43.57257720402309, 43.565246854509624, 43.98029054914202, 43.85098109926496, 44.407913957323345, 41.15487854821341, 39.25337546212332, 34.64259256635393, 33.602603571755544, 33.29625749588013, 35.40493501935686, 34.98342602593558, 36.040643078940256, 34.910327502659385, 33.723703724997385, 33.38718857084002, 35.41776139395577, 35.87137801306588, 35.404250621795654, 33.62434101104736, 35.47756801332746, 47.551466601235525, 46.466053758348735, 46.37108925410679, 47.803165095193044, 45.046335288456504, 44.162698132651194, 43.005142143794465, 42.34623752321516, 39.84762362071446, 41.38396760395595, 40.273311955588206, 42.386116709027974, 43.601537295750205, 49.59199966703142, 47.074316433497835, 49.193100111825125, 30.694844995226177, 44.41415343965803, 49.27504716600691, 42.306778703417095, 45.63877691541399, 45.80337974003383, 50.18447603498186, 41.026246547698975, 43.11956507819039, 45.549186842782156, 44.60437427248274, 45.69699239730835, 44.61733613695417, 45.15176377977644, 45.50557994842529, 46.221341678074424, 46.95048563820975, 41.28168664659773, 36.029543331691194, 35.71069049835205, 34.49886213030134, 35.58231905528477, 37.20574828556606, 35.34958914348057, 38.561050006321494, 37.41524689538138, 35.848841530936106, 35.261475563049316, 35.1940849849156, 37.260211740221294, 40.264202867235454, 44.45352193287441, 46.837160519191194, 48.172628607068745, 45.59230041503906, 47.3012307030814, 48.14590930938721, 48.12820182527815, 49.590714250292095, 49.02619743347168, 51.377877780369346, 50.23494774954659, 49.057853426252095, 47.222684792109895, 46.1033091545105, 43.370916162218364, 41.827589239392964, 38.69394472667149, 39.89759159088135, 43.80309411457607, 48.74799503598894, 49.48292337145124, 50.44824007579258, 48.09302656991141, 48.680663517543245, 47.15359885351998, 49.171234130859375, 50.75657333646502, 54.907048497881206, 55.21335983276367, 58.94063064030239, 37.68365233285086, 1.1428665199450083, 0.9850762954780033, 0.02859814079212291, 0.037393990238862376, 13.778902275221688, 59.99556173597063, 42.54045704432896, 37.23719235828945, 32.78003413336617, 31.711032935551234, 41.67266525541033, 48.37683616365705, 49.31070532117571, 20.13102272578648, 0.005923910116377685, 0.00910470332019031, 0.04767618082197649, 0.050210539650704177, 0.05908264286283936, 0.03438187829617943, 0.04853066336363554, 0.031104242029998983, 0.03329586942813226, 0.03357527318543621, 0.031157842903797115, 0.0706005169610892, 0.09427225603056805, 0.13594713727278368, 0.1355514292206083, 0.08952474328024046, 0.12021243944764137, 0.17393192116703304, 0.0914219000509807, 0.17464555001684598, 0.13110722840896674, 0.1348379903606006, 0.2408028771834714, 0.1518336505229984, 18.32368162700108, 58.474934577941895, 56.400914669036865, 50.82979692731585, 50.427395480019705, 47.37629904065813, 55.460034779139924, 52.24157360621861, 36.226576873234336, 62.67391858782087, 18.023705312183925, 0.4221384839287826, 2.7750299615519385, 40.66815028871809, 16.18257164955139, 6.775541067123413, 27.46106825556074, 37.93913759504046, 46.921765259334016, 53.93157352719988, 47.594684396471294, 50.62529059818813, 49.860926219395225, 54.29882403782436, 51.8082492010934, 52.320341859545024, 45.69505384990147, 38.9931515284947, 41.79248694011143, 46.62377091816494, 50.11906221934727, 50.78035354614258, 45.80559968948364, 45.6687444959368, 43.97014965329851, 46.42546933037894, 47.354245458330425, 49.83220584051949, 42.53623948778425, 46.18017360142299, 45.18211351122175, 46.64299658366612, 45.27756091526577, 45.20332636151995, 43.34377997262137, 41.436742646353586, 36.60147040230887, 35.342286586761475, 34.53350237437657, 37.064088412693565, 37.30295010975429, 37.82818528584072, 37.75767149244036, 35.318405628204346, 34.81609950746809, 36.980345249176025, 38.82193749291556, 37.63290269034249, 35.45468759536743, 37.50690058299473, 48.76118619101388, 48.58768967219761, 47.392655100141255, 49.00793409347534, 46.9938701902117, 46.421738147735596, 44.66126959664481, 44.36334473746163, 42.6876094681876, 41.73135321480887, 44.149163041796, 43.948026588984895, 45.2897515296936, 53.077643394470215, 49.925832816532676, 50.969101360866, 31.732499395098003, 48.421349797930034, 50.998151779174805, 44.13254295076643, 47.46274157932827, 48.26789535794939, 51.77371317999703, 40.43389524732317, 44.54046474184309, 47.84959643227713, 46.365912846156526, 47.63978167942592, 46.18542643955776, 46.914014543805806, 49.04129239491054, 48.152614321027485, 49.68742970057896, 43.69627250943865, 38.7510415485927, 37.216538837977815, 35.93560716084072, 36.925857475825715, 40.99505955832345, 36.68665879113333, 40.76645687648228, 39.30887072426932, 37.8819191796439, 37.20177739007132, 36.12909712110247, 38.9241281236921, 41.179947648729595, 47.23385402134487, 48.18486091068813, 50.370986529758994, 47.06073270525251, 49.47747598375593, 49.10236011232649, 50.64482198442732, 50.804988384246826, 50.79435764040266, 53.34302289145333, 52.436175278254915, 51.33293683188302, 49.62923158918108, 47.94225760868618, 46.03983736038208, 44.584981850215364, 41.19487932750157, 41.19243008749825, 46.04943282263619, 50.83592871257237, 52.216445446014404, 54.44895723887852, 49.81023563657488, 51.51344060897827, 51.31877292905535, 51.513117517743794, 52.29264633996146, 57.02376856122698, 56.85418735231672, 59.62295069013323, 41.76258536747524, 2.5138712780816213, 2.1788447754723683, 0.3708695721413408, 0.11634822322853974, 16.033029045377457, 66.83033793313163, 48.691975184849326, 44.55809926986694, 42.91515949794224, 37.09969793047224, 47.953472001211985, 56.00875834056309, 58.42477553231375, 26.392612491335186, 0.13109202922454902, 0.14943984683070863, 0.11736802064946719, 0.20561774234686578, 0.15303981437214784, 0.15845721081963607, 0.14966620611292974, 0.20443690142461232, 0.17164804014776433, 0.11628560801701886, 0.11490168156368391, 0.12596086598932743], [0.022599804714055996, 0.07827183710677282, 0.07049158494919538, 0.0020291129601121482, 0.041611634993127415, 0.0333981144774173, 0.027026458610115305, 0.03752753610855766, 0.019567969454718486, 0.06277440940695149, 0.12480336667171546, 0.04651204203920705, 13.362543634005956, 44.36396312713623, 42.99009929384504, 40.417243889399934, 23.087020908083232, 29.99406358173915, 37.289084979466026, 28.163767371858867, 30.20128665651594, 53.72170666285923, 11.567688448088509, 0.0796756310654538, 0.9393778847796577, 4.3730281335966925, 4.777089331831251, 3.12660750746727, 18.80628613063267, 14.2275196654456, 22.14779816355024, 45.91996356419155, 49.32984413419451, 50.32092128481184, 51.0321284702846, 46.77842044830322, 44.7776449748448, 42.14064727510725, 35.7885867527553, 36.30762413569859, 34.989488329206196, 38.78958320617676, 43.265081201280864, 47.86173493521554, 47.5211238179888, 44.17481231689453, 42.22728088923863, 43.8917670249939, 42.56462982722691, 41.275304726191926, 39.05275665010725, 35.79209906714303, 33.52548204149519, 34.92205606188093, 34.07207945414952, 32.715082372937886, 31.682479313441686, 32.854393754686626, 32.48630598613194, 35.44998713902065, 34.30422224317278, 33.25627408708845, 33.62235730034964, 34.08912338529314, 31.96932874407087, 33.0858382497515, 33.097268036433626, 32.609084129333496, 33.2229574748448, 35.91818107877459, 32.61077601569039, 36.085045542035786, 45.51996619360787, 47.34996884209769, 49.161124501909526, 47.22762496130807, 44.15967914036342, 43.05625309262957, 41.23682907649449, 40.5351687158857, 39.72096143450056, 41.57189553124564, 37.91902603421892, 39.2349523135594, 41.34156622205462, 47.62679897035871, 46.885860443115234, 46.42430550711495, 35.43330104010445, 45.88776561192104, 47.70569576535906, 40.92582423346383, 43.04551117760794, 42.83113145828247, 44.907642296382356, 40.69261489595686, 44.603196552821565, 41.30110338756016, 40.69820819582258, 41.96838058744158, 42.0861872945513, 44.16478606632778, 41.89093596594674, 45.29726600646973, 43.881250926426475, 39.07620334625244, 34.7673578943525, 33.3055750301906, 34.07074192592076, 34.50823872429984, 34.513811179569785, 33.845085280282156, 37.805096421922954, 35.02109568459647, 34.2732332774571, 33.41652039119175, 32.82290799277169, 34.66301679611206, 35.30469683238438, 39.02491174425398, 43.47728613444737, 46.1871600151062, 46.76930441175188, 46.150779247283936, 43.59073632104056, 43.5136147907802, 43.633342674800325, 42.83919831684658, 43.84131962912423, 46.51991966792515, 46.642367771693635, 47.40066984721592, 46.723692962101524, 43.97995703560965, 41.25298711231777, 38.94699117115566, 38.37906626292637, 39.10440261023385, 49.206801959446494, 49.193913051060264, 49.29778514589582, 49.69288056237357, 49.10758515766689, 50.68455178397042, 52.32505621228899, 51.78733164923531, 53.45251955304827, 56.03252117974417, 59.968081610543386, 41.69905798775809, 9.04758289882115, 0.3348045130925519, 0.1007400518283248, 0.04070087136434657, 9.927544457571846, 54.77888202667236, 42.4894676889692, 38.55504328863961, 31.439705780574254, 21.929539612361364, 34.505254473005024, 47.277985504695344, 43.307030950273784, 22.2154631955283, 0.3028680139354297, 0.11438105521457535, 0.030660700651683977, 0.04207340521471841, 0.05026348573820932, 0.04782148231086986, 0.013342097684341882, 0.04413654522172042, 0.048885255586355925, 0.04791185299732855, 0.017872510610946586, 0.02555985775377069, 0.039423352772636075, 0.08012178141091551, 0.04180620490972485, 0.020164342364296317, 0.03224202311996903, 0.05101600482261606, 0.00920706202409097, 0.02342922895747636, 0.017082022403233817, 0.021860401711559722, 0.06972767665450062, 0.06855096122516052, 16.70204676900591, 51.897380692618235, 48.99553503308977, 46.501538208552766, 30.74714756011963, 37.42419964926583, 41.335364954812185, 35.58958339691162, 32.8518055507115, 59.95898641858782, 12.204571621758596, 0.075342798206423, 0.3072353367294584, 7.022264650889805, 8.312258516039167, 3.3407034363065446, 19.38187837600708, 13.929395914077759, 24.730940376009258, 46.94317613329206, 50.19462735312325, 50.831638199942454, 50.269139834812705, 47.82127210072109, 46.88825757162911, 44.59992742538452, 37.69055536815098, 37.64935255050659, 36.15325253350394, 40.315098421914236, 45.51242739813668, 49.59527574266706, 48.5887006350926, 45.24583544049944, 43.79091739654541, 45.049003396715435, 44.2211845942906, 44.22932093484061, 40.14585072653634, 39.29138558251517, 36.26371846880232, 36.58704941613333, 36.16194820404053, 35.90463556562151, 33.088151999882285, 33.34231015614101, 34.274761881147114, 35.65509101322719, 36.015730312892366, 34.225693702697754, 34.39126580102103, 36.12625183377947, 34.14861386162894, 34.758780343191965, 34.6416198185512, 34.13488074711391, 34.907586438315256, 37.08334534508841, 34.56979628971645, 37.49469607216971, 47.880290099552695, 48.31337479182652, 48.140805857522146, 48.693656648908345, 48.187581130436485, 44.84485142571585, 42.14719942637852, 42.069185052599224, 41.61384528023856, 42.18393455232893, 40.94717952183315, 41.00398104531424, 43.47905445098877, 49.43660320554461, 47.76094436645508, 48.3052453994751, 37.08408532823835, 47.839069911411826, 50.15058272225516, 43.57437331335885, 43.58885683332171, 45.43600763593401, 47.54192672457014, 43.5781044960022, 43.00727871486119, 42.003715651375906, 43.16399185998099, 43.4844844681876, 42.91525329862322, 43.332923412323, 43.66237572261265, 45.45526456832886, 46.0118465423584, 40.98875059400286, 36.99852868488857, 34.94534294945853, 35.65206159864153, 35.5066670690264, 35.371347427368164, 36.427150521959575, 38.999585560389924, 37.104412283216206, 35.821792193821494, 35.90779004778181, 34.40001358304705, 36.31070566177368, 37.78713880266462, 41.73236417770386, 45.35423081261771, 47.649429253169465, 48.408360140664236, 47.26331785746983, 45.47487933295113, 44.22631583895002, 42.93365560259138, 43.47300604411534, 44.639942101069856, 47.28679582050869, 48.034164905548096, 48.78045701980591, 49.56643724441528, 45.88753979546683, 42.63501855305263, 41.09625312260219, 40.68047986711775, 41.47021906716483, 50.751563685280935, 51.3518602507455, 51.379097189222065, 51.16703816822597, 51.03088821683611, 53.4641751561846, 54.228546483176096, 54.28135974066598, 54.311570508139475, 58.50141416277204, 60.26258100782122, 45.72333649226597, 13.559071694101606, 0.267959042851414, 0.04919725955863084, 0.06263400015554257, 11.267187544277736, 59.74024323054722, 48.352708544049946, 40.326323236737935, 39.36071470805577, 32.69962610517229, 42.01080281393868, 53.752226625170024, 50.02510172980172, 28.634203842708043, 0.35815510153770447, 0.043897158067141256, 0.022889272842024053, 0.04402244955833469, 0.05698301802788462, 0.02491258453976895, 0.03339355132941689, 0.0209815054799297, 0.04669222701340914, 0.008861342494908189, 0.02924837072246841, 0.02203230177318411, 0.10525664554110595, 0.1541326493024826, 0.11061981346990381, 0.09481732999639851, 0.1536210338984217, 0.11286855316055672, 0.08523062762937375, 0.15921939563538345, 0.1834480491067682, 0.19612233686660016, 0.22782660062823976, 0.214907008888466, 21.66024480547224, 60.09307970319475, 54.91061292375837, 53.58219378335135, 32.56341709409441, 38.03101709910801, 41.953257833208355, 38.23395660945347, 40.34847756794521, 63.497106415884836, 14.959336076463972, 0.33945817766445024, 1.75349722802639, 6.144458336489541, 7.912164739200047, 5.599157631397247, 21.13877902712141, 14.986588648387364, 26.49746949332101, 50.74186052594866, 51.148156438555034, 53.41346025466919, 52.08075060163225, 50.16190481185913, 48.124623503003804, 46.829128401620046, 39.73384339468819, 39.4299396106175, 38.49271099908011, 41.94108806337629, 46.21197203227452, 51.57085704803467, 49.63255630220686, 47.62374871117728, 45.317881311689106, 46.740014280591694, 45.62156275340489, 45.114021165030344, 44.34708942685808, 42.2086249760219, 37.793836866106304, 39.21631377083914, 38.29691423688616, 37.48922436577933, 34.99138866152082, 34.4290257862636, 36.97529738289969, 39.03619909286499, 37.513206073216026, 35.93545430047171, 36.731047357831685, 37.919533252716064, 34.41618551526751, 35.77548592431204, 36.652393749782014, 36.08251987184797, 35.413880825042725, 39.634056840624126, 36.207941804613384, 38.68778167452131, 49.840244906289236, 49.851382868630544, 50.04413979394095, 50.822226864951, 49.62869657788958, 46.44229786736624, 44.38649613516671, 44.24933522088187, 43.82653733662197, 45.89676352909633, 43.157960823604036, 43.15987852641514, 45.93948800223214, 51.75550889968872, 49.770519733428955, 49.18759366444179, 39.047469070979524, 50.23162998471941, 51.95173645019531, 45.10773304530552, 47.545525891440256, 46.18076419830322, 48.26790230614798, 42.70274611881801, 44.6083972794669, 44.32349681854248, 41.792997632707866, 44.2132636478969, 43.98289264951433, 45.71417876652309, 44.342124938964844, 48.48639535903931, 46.32106569835118, 43.063093594142366, 38.91149282455444, 36.0748108455113, 37.41996124812535, 37.18875994001116, 36.451959065028596, 37.12727880477905, 41.96699442182268, 39.17256791251046, 36.53666455405099, 37.565487793513704, 36.63233430044991, 38.473971707480295, 40.61219991956438, 43.1778952053615, 48.45649378640311, 50.04380628040859, 50.01172644751412, 48.75961937223162, 45.39752503803798, 46.412705489567344, 44.12906190327236, 44.291510786329, 44.13293204988752, 49.85959216526577, 50.7931694984436, 51.08374663761684, 50.70498991012573, 49.09418208258492, 45.10825416019985, 44.50912836619786, 41.233431407383506, 43.58469486236572, 53.489105292728965, 54.696389538901194, 53.42499426433018, 53.56811325890677, 53.39651359830584, 55.802150181361604, 56.2789876801627, 57.3078248160226, 57.178650856018066, 62.396796635219026, 62.4526184626988, 48.98709992000035, 16.817977462496074, 1.422473430633545, 0.439979476588113, 0.13773101940751076, 12.792016625404358, 67.01886340550014, 52.862912791115896, 50.730340412684846, 41.06853675842285, 32.23158502578735, 46.268756185259136, 60.783932140895296, 58.17683253969465, 37.01820250919887, 0.7339952141046524, 0.12761467296097959, 0.16850345102804049, 0.15840883127280644, 0.12581050262919494, 0.14402213825711183, 0.12657286386404717, 0.09410824054586035, 0.20021679358822958, 0.09551713030253138, 0.1164513605513743, 0.14030376635491848], [0.01542635285295546, 0.11339907933558736, 0.08218329971922295, 0.023956143629870245, 0.06429471461368458, 0.027620232730571712, 0.023215251243008033, 0.04504788560526712, 0.006830018146761826, 0.04122539250446217, 0.03606470621057919, 0.048246279159294705, 16.18799298150199, 51.63950525011335, 41.918127741132466, 39.05474383490426, 17.02401760646275, 13.907516036714826, 23.150555235998972, 32.87982068743025, 35.862407888684956, 51.28482403073992, 8.492539082254682, 0.030281117984226773, 0.4681218521935599, 3.8948344332831244, 2.750310008014951, 3.286728309733527, 25.515061957495554, 29.057778188160487, 36.07245888028826, 49.83117055892944, 50.085519790649414, 48.58964211600167, 46.32771165030343, 41.896088055201936, 38.49657767159598, 35.93297379357474, 38.40517064503261, 40.06221873419625, 40.37063537325178, 39.33956091744559, 42.149158818381174, 45.251678875514436, 45.11425740378243, 43.995448044368196, 43.72046613693237, 44.28033808299473, 44.83396359852382, 42.28568744659424, 40.83388566970825, 36.632355145045686, 35.82316446304321, 32.771411418914795, 32.96441847937447, 31.800136634281703, 31.820908273969376, 34.06532233101981, 32.912317412240164, 33.29048006875174, 33.98509495598929, 35.575207574026926, 32.992530890873496, 33.39217390332903, 33.54638569695609, 32.6076979637146, 34.520620414188926, 34.87348467963082, 35.07506234305245, 32.72973959786551, 33.55045734133039, 37.649741649627686, 46.81718097414289, 42.94811480385916, 45.07535096577236, 47.84372520446777, 46.38066039766584, 45.3261079788208, 44.20021145684378, 44.82937431335449, 42.29437269483294, 43.460801533290315, 42.24214308602469, 39.971145221165244, 39.785270486559185, 43.38009820665632, 44.74153866086687, 47.343131814684185, 38.042700495038716, 41.14692633492606, 47.16797815050398, 42.39546203613281, 44.1565455027989, 43.95453010286604, 45.21713938031878, 43.87440000261579, 44.073823724474224, 42.702033928462434, 43.43157046181815, 45.392869744982036, 47.410713468279155, 47.037848813193186, 46.83437429155622, 44.30730056762695, 43.98100968769619, 39.55488559177944, 34.08970355987549, 32.71607943943569, 34.4929700578962, 34.37418018068586, 33.03713832582746, 33.78488608769008, 34.81782613481794, 36.51321785790579, 35.390976088387625, 33.748793670109336, 35.14801148005894, 33.53126294272286, 34.59000512531826, 36.00544350487845, 38.38730682645525, 42.16127300262451, 45.89596448625837, 46.780084541865754, 47.18388605117798, 46.60256849016462, 46.8499174118042, 42.449366160801475, 44.15993969781058, 45.02837419509888, 50.2231045450483, 49.177477087293354, 46.26771395547049, 46.26541062763759, 42.26601709638323, 40.99902697971889, 38.36557633536202, 38.79788630349295, 49.523476532527376, 50.79132127761841, 51.53164488928658, 50.95739017214094, 52.12612233843122, 51.64835030691964, 52.909990310668945, 53.174567290714805, 55.96810443060738, 51.6576817376273, 55.2572272845677, 44.788987909044536, 13.548781411988394, 0.7763319994722093, 0.056922499489571364, 0.06285409655954156, 5.02603416783469, 52.44398505347115, 46.40613944189889, 34.28713314873831, 15.601754358836583, 17.725882938929967, 31.255967617034912, 45.14285618918282, 45.86021253040859, 26.40617711203439, 0.08967464523656027, 0.03184726840949484, 0.035673737725509067, 0.05280536612761872, 0.02970495693651693, 0.059022782503494194, 0.03896120935678482, 0.07561793058578457, 0.02206848295671599, 0.08570480825645582, 0.05100193879167948, 0.032874030992388725, 0.014445119969812887, 0.14520676540476934, 0.04001055019242423, 0.05308580804350121, 0.039919066708534956, 0.04498265124857426, 0.05617342057770916, 0.06823554422174181, 0.06569223212344305, 0.009644985980620342, 0.08363894732402903, 0.1736517676285335, 19.030059814453125, 59.0154835837228, 47.360307761601035, 45.524145535060335, 21.5861040524074, 17.88020416668483, 26.546786069869995, 35.67049516950335, 40.54251643589565, 56.553861890520366, 9.311020374298096, 0.08407953368233782, 0.12166320160031319, 4.746242369924273, 4.31645416361945, 3.3809517451695035, 29.26864038194929, 29.507130350385392, 38.219622475760325, 51.58245359148298, 52.633389472961426, 48.590934480939595, 48.248124258858816, 43.015390736716135, 40.05538865498134, 37.5879339490618, 39.22216067995344, 42.518208912440706, 41.79897655759539, 39.690403257097515, 43.65371479306902, 45.75017390932356, 47.110850061689106, 45.54014376231602, 44.00855582101004, 45.00420488630022, 45.60036727360317, 44.946513993399485, 42.366943155016216, 39.251044341496055, 36.20754228319441, 34.891952991485596, 32.90632806505476, 33.19446986062186, 34.34516797746931, 34.01618119648525, 34.13625996453421, 35.928718021937776, 35.49147135870797, 35.88408974238804, 34.477649280003135, 35.441020488739014, 34.82958596093314, 33.89432716369629, 35.508567401341026, 35.86348833356585, 35.25381864820208, 34.842763219560894, 35.08642612184797, 39.53397151402065, 47.71689278738839, 44.66287463051932, 45.65560892650059, 48.24620655604771, 48.10656860896519, 46.993171896253315, 45.41776514053345, 45.73831680842808, 43.97143159593855, 46.01022413798741, 43.523366587502615, 42.147828238351, 41.26319401604788, 46.484817368643625, 46.55459117889404, 49.02392537253243, 39.75379514694214, 42.81391382217407, 48.95276192256382, 43.93784400394985, 44.432798930576865, 45.98597839900425, 49.0646070752825, 45.504207679203574, 43.64184032167707, 42.685354777744834, 44.94082689285278, 46.29082018988473, 48.19351141793387, 49.164459637233186, 48.359378814697266, 46.274964400700156, 45.59051820210048, 41.54731280463082, 35.65493467875889, 35.63526085444859, 35.66063220160348, 37.073437213897705, 35.39790344238281, 35.75339412689209, 36.68150322777884, 36.5348128591265, 36.684911319187705, 35.78814206804548, 36.46093961170742, 35.71553686686924, 36.97617285592215, 36.97216721943447, 41.507742813655305, 44.761872564043315, 47.72911466870989, 48.1500678062439, 48.94036633627755, 48.15073135920933, 47.055247102464946, 43.1556852885655, 45.40056487492153, 45.30406481879098, 50.756177289145334, 51.14350461959839, 48.7780807358878, 48.223736081804546, 45.67426136561802, 42.77707099914551, 39.43296555110386, 40.50894274030413, 50.915624550410676, 52.64360679898943, 54.00386953353882, 53.40298931939261, 52.89814363207136, 53.8375574520656, 56.429530824933735, 55.467660427093506, 58.39357812064034, 52.932200227464946, 56.21857309341431, 45.07160588673183, 16.978958538600377, 1.331560594694955, 0.09756671996521098, 0.15200751833617687, 5.7093938418797086, 58.29265553610665, 50.090529441833496, 41.709567138126914, 17.22636651992798, 17.603525161743164, 34.52976771763393, 51.435881342206685, 52.83621433803013, 33.1166535105024, 0.07921907199280602, 0.015279543319983142, 0.049848602286406925, 0.004343726738755192, 0.05886036157608032, 0.011692501870649201, 0.05630994860881141, 0.013731568303358341, 0.01072606529175703, 0.017474677047825286, 0.08001414540090732, 0.02067361173353025, 0.07406420074403286, 0.3302898124924728, 0.1484465529876096, 0.15081248246133327, 0.23219357058405876, 0.14845183199005468, 0.15578632056713104, 0.1324990801513195, 0.12290299364498683, 0.050806734444839616, 0.16607424137847765, 0.25771595963409966, 23.663089105061122, 67.6655808857509, 54.94988414219448, 50.28073637826102, 27.051590067999705, 21.425347055707658, 31.420542648860387, 44.250884669167654, 46.07018709182739, 60.480594635009766, 11.408600756100245, 0.2857363075017929, 1.0470100407089507, 9.877870917320251, 8.047783153397695, 4.649228147097996, 30.96149253845215, 33.60982275009155, 40.33922256742205, 54.000659465789795, 54.37920079912458, 51.62496614456177, 50.271172182900564, 45.15000935963222, 41.992935521262034, 39.91921091079712, 42.27213498524257, 45.14226906640189, 44.72140972954886, 42.34162391935076, 46.529348373413086, 47.36562660762242, 49.181781496320454, 46.668909890311106, 45.64787558146885, 46.88554082598005, 47.87491566794259, 47.22752768652779, 45.3626937185015, 41.35185650416783, 39.64139066423689, 36.48684597015381, 36.16841002873012, 35.41098690032959, 35.112669467926025, 37.53607954297747, 36.143003940582275, 36.299390520368306, 37.76783670697893, 37.1159428187779, 35.36390243257795, 37.117606912340435, 37.49351487840925, 36.21408748626709, 37.30275208609444, 38.027897357940674, 37.04065561294556, 36.19469158990042, 38.06619235447475, 42.455299922398154, 49.91185304096767, 46.90372773579189, 45.554682867867605, 51.468621253967285, 51.50070456096104, 48.369238308497835, 46.74380799702236, 48.47197437286377, 46.21010644095284, 48.684891496385845, 45.9575845854623, 45.19363015038626, 44.60756696973528, 48.06151648930141, 48.49971852983747, 50.37947375433785, 42.02616875512259, 44.16221523284912, 51.050888606480186, 46.6716057913644, 46.38183464322771, 47.17113263266427, 49.71610491616385, 46.669583865574424, 43.9281964302063, 43.50726066316877, 46.71050180707659, 48.83751562663487, 51.15822090421404, 51.81375217437744, 49.0306408064706, 47.821713311331614, 47.95386110033308, 42.8962082862854, 37.675397872924805, 37.001318386622835, 37.99096768242972, 38.77689926964896, 37.44771235329764, 37.27129064287458, 38.9647090775626, 38.762189933231895, 38.87765857151577, 37.34724487577166, 38.62210382734026, 37.51751395634243, 38.84777436937605, 39.28609452928816, 42.40690919331142, 46.38224458694458, 49.440528937748496, 50.693105016435894, 50.74152701241629, 50.848206179482595, 49.878428731645855, 44.241546290261404, 46.598361355917795, 45.93997090203421, 50.23857470921108, 51.15242263248989, 49.705887590135845, 49.58866800580706, 47.282949992588584, 43.5755614553179, 42.27805485044207, 42.38090903418404, 53.99695955004011, 54.61110734939575, 56.54019478389195, 54.71298878533499, 55.59328385761806, 55.09011268615723, 58.70815781184605, 58.45131765093122, 61.50843470437186, 53.48596123286656, 56.65867894036429, 45.447433948516846, 21.630317177091325, 1.9177727273532321, 0.15925305097230844, 0.23208383790084294, 6.508139210087912, 63.425220353262766, 56.84639147349766, 46.55622747966221, 24.25204794747489, 29.190188271658762, 42.402375493730815, 61.015112604413716, 59.864741052900044, 42.898803438459126, 0.7419709861278534, 0.14594202595097677, 0.18556468481464045, 0.11445296635585171, 0.2292985330734934, 0.14084056897887162, 0.12131022768361227, 0.1237821171858481, 0.11921578007084982, 0.15667650422879628, 0.13674413093498775, 0.13958381355873176], [0.0202965091115662, 0.03507455059194139, 0.04790137980931571, 0.02715202490799129, 0.01879650227991598, 0.019861288268917372, 0.06520429080618279, 0.034094664600810835, 0.017377554937931042, 0.00688826952994402, 0.004836137905450804, 0.1005485760314124, 17.566185542515345, 46.58173084259033, 43.378461905888145, 36.80192245755877, 29.373391423906597, 19.687927416392736, 21.883306298937114, 36.62106432233538, 37.24756254468645, 52.18545995439802, 6.036942345755441, 0.06801608564066035, 0.06952712884438889, 4.081364035606384, 8.89076292514801, 2.2432765066623688, 26.85378875051226, 47.705914633614675, 49.762793336595806, 48.68121589933123, 49.007902826581685, 46.002633231026785, 42.37785530090332, 39.92447417122977, 41.09687498637608, 43.40344067982265, 45.37448133741106, 47.668561117989675, 43.326600551605225, 44.25333390917097, 41.58612544195992, 44.789484705243794, 47.248240266527446, 45.91590234211513, 42.338507652282715, 44.24503081185477, 45.504423073359895, 44.346568311963765, 39.93297529220581, 36.85355799538748, 34.660036018916536, 34.237408365522114, 34.76401581083025, 33.739128725869314, 33.69270781108311, 31.252597740718297, 33.641416209084646, 33.96198524747576, 33.195609365190776, 33.24467754364014, 33.53262478964669, 32.80076060976301, 33.35540403638567, 32.98111152648926, 33.651567527226035, 34.51981789725167, 33.23510292598179, 33.71223224912371, 32.961197989327566, 34.712164878845215, 43.24540042877197, 44.09163890566145, 35.28077071053641, 44.51250171661377, 46.29940468924386, 46.4885242325919, 44.34673506872994, 47.72010980333601, 48.29356895174299, 45.8892560005188, 47.230643953595845, 47.394583225250244, 42.90720381055559, 43.930534499032156, 43.85603938783918, 48.07178940091814, 39.97543920789446, 42.15535661152431, 48.10101005009243, 40.81179387228829, 40.9143944467817, 43.52902242115566, 47.41726214545113, 42.495915617261616, 40.1434188570295, 44.505765438079834, 43.774609974452424, 46.36751440593174, 44.70597778047834, 43.28291722706386, 44.24469035012381, 44.56217091424124, 41.85759156090872, 38.98325381960188, 32.62838275091988, 34.18818385260445, 32.861817904881065, 34.54371970040457, 34.989804472242085, 34.0480352129255, 34.61693286895752, 35.267100129808696, 36.12097120285034, 36.51663984571184, 35.12893520082746, 34.19447544642857, 34.57412849153791, 34.010268279484336, 36.266185079302105, 36.72338696888515, 40.75471789496285, 45.92380939211164, 46.95066629137312, 47.77115821838379, 46.67353391647339, 47.38510588237217, 45.202284131731304, 44.52416426794869, 45.56177003043038, 47.483679975782124, 48.77180303846087, 49.01148809705462, 46.43477644239153, 45.944296155657085, 40.622313022613525, 38.68924427032471, 47.117211137499126, 51.73217337472098, 49.36913619722639, 52.54198244639805, 53.564687797001426, 52.62120233263288, 54.633140087127686, 53.82256323950631, 54.841773646218435, 50.966148376464844, 54.89340223584856, 43.35447672435215, 15.78783232825143, 0.6532807594963482, 0.15035354851612023, 0.04583854853574719, 2.7172452679702213, 48.84044429234096, 48.149953160967144, 37.45247186933245, 36.10968732833862, 46.12074565887451, 37.62351219994681, 40.78462641579764, 47.60440492630005, 32.09821435383388, 1.1435110739299228, 0.06841787336660282, 0.04074987855606845, 0.08690901113940136, 0.04908004602683442, 0.040363781952432225, 0.023710011837205718, 0.021053233416751027, 0.03388917366308825, 0.044891222047486475, 0.013768511142448654, 0.062166143474834304, 0.039438782658960135, 0.07103387692144938, 0.030848536108221327, 0.0069421282470492375, 0.04343203927523323, 0.02178752874689443, 0.027290686931727186, 0.026823122021076933, 0.02778552725378956, 0.09453912385340248, 0.05380930618516036, 0.13934138656726905, 18.917598009109497, 53.239963735852925, 49.18586008889334, 42.80471093314034, 30.775572640555247, 21.18945050239563, 23.670739071709768, 38.923172746385845, 41.583360058920725, 55.65121793746948, 7.219036766460963, 0.12112097069621086, 0.023437761535335864, 2.780667773314885, 5.712624754224505, 2.960567057132721, 27.21385829789298, 51.23007917404175, 52.6358699798584, 51.710689544677734, 49.624062129429404, 47.39043862479073, 42.990144457135884, 41.14500168391636, 41.89121389389038, 45.6677439553397, 47.55771650586809, 48.88354049410139, 46.56838682719639, 45.07119594301496, 44.225315298352925, 47.959079197474885, 46.67971781321934, 46.201039041791645, 42.8769131387983, 46.0067708832877, 47.2774088042123, 46.09443283081055, 40.6639917918614, 38.550957747868125, 35.46215690885271, 35.27762317657471, 36.24701847348894, 35.386765480041504, 36.27875089645386, 32.16657073157174, 34.429946422576904, 35.046109199523926, 34.77529273714338, 35.114013944353374, 34.85675689152309, 34.23689419882638, 34.01264108930315, 33.99427352632795, 34.898459979466026, 35.350450720105854, 34.888822828020366, 35.95484324863979, 34.28927319390433, 35.75698981966291, 45.04100602013724, 46.04798412322998, 36.32615498134068, 44.58708715438843, 48.33146095275879, 47.76618330819266, 46.89941985266549, 49.45580455235073, 49.18072189603533, 48.72593450546265, 47.69175073078701, 48.53165939876011, 43.48919882093157, 45.399550437927246, 45.796511445726665, 48.95634371893746, 41.293672289167134, 44.301481451307026, 49.306265422276084, 43.26230887004307, 43.71532446997506, 45.506816727774485, 49.94905717032296, 43.54991912841797, 40.72671665464129, 44.843267236437114, 46.71306569235665, 48.21238967350551, 47.80897726331438, 45.315313952309744, 46.69823128836495, 46.34063182558332, 43.51431655883789, 39.72311190196446, 34.25737401417324, 35.08693334034511, 34.25625188010079, 35.62835781914847, 35.26221554619925, 35.379786014556885, 35.48194537843977, 36.131667954581125, 36.887492997305735, 37.51643698556082, 36.362320355006624, 37.09990290233067, 36.05588047845023, 37.27550472532, 37.50488560540335, 39.01500013896397, 42.55216128485543, 46.715702533721924, 49.67400230680193, 49.61706529344831, 49.3864233153207, 48.91782290594918, 46.15113360541207, 45.13581418991089, 46.6385566847665, 49.157223088400706, 50.42261511938912, 51.30656841823033, 48.29892948695591, 46.81253262928554, 42.428830759865896, 40.50806726728167, 49.42080995014736, 53.16925539289202, 52.62965134211949, 53.847420419965474, 55.566123349326, 54.37041827610561, 55.28130279268537, 55.49927125658308, 56.169167927333284, 50.83010959625244, 54.12658166885376, 45.867806911468506, 19.029766253062657, 0.7125693038105965, 0.23282034695148468, 0.008274461442072476, 2.509871069874082, 54.32943780081612, 49.83433198928833, 42.026165281023296, 34.13417897905622, 47.34829780033657, 46.2435759135655, 46.896004813058035, 53.32781328473772, 38.88933154514858, 1.767138387475695, 0.09961099669869457, 0.06397251226007938, 0.07146931319896664, 0.0022657132441444056, 0.06135858502238989, 0.04815484995820692, 0.019000776943617632, 0.06063402497342654, 0.03891733188980392, 0.05017401411065033, 0.06891154151942049, 0.08792940567114524, 0.18678033458335058, 0.10555258858948946, 0.06953794469258615, 0.1368574055710009, 0.12975551879831723, 0.14816017049763883, 0.10143904467778546, 0.0790824761082019, 0.21795369897569927, 0.15654196430529865, 0.2544914526598794, 22.425118139811925, 61.736926215035574, 55.448604992457796, 48.9003655569894, 39.33930730819702, 29.104530879429408, 29.117345094680786, 48.008755343300955, 45.85491452898298, 62.00641209738595, 7.667605519294739, 0.22920850504721912, 0.15002806883837494, 9.949580669403076, 15.245033843176705, 3.837266436644963, 30.767710753849574, 50.16898502622332, 53.913706234523225, 52.235858712877544, 52.60318565368652, 48.79268932342529, 46.42109891346523, 43.43056297302246, 45.037729944501606, 47.78704874856131, 49.71839782169887, 50.936549050467356, 46.632685456957134, 48.632488182612825, 46.000045027051655, 48.726122106824604, 49.65057298115322, 47.56418527875628, 44.18313973290579, 47.537917613983154, 49.599924087524414, 47.561207975660054, 44.092236450740266, 40.8255478313991, 37.2346180507115, 37.01820598329817, 38.33586931228638, 37.449647426605225, 38.27405118942261, 34.29853514262608, 37.65859365463257, 37.27945825031826, 36.429731777736116, 36.66191625595093, 36.36788586207798, 35.683700220925466, 36.790044512067524, 35.295424461364746, 37.39180019923619, 37.05577836717878, 36.400174140930176, 37.482644421713694, 35.944469588143484, 38.07690300260271, 46.00618028640747, 48.77486719403948, 39.196285588400706, 45.61113698141915, 50.212734358651296, 49.39551503317696, 49.047757693699424, 50.84741061074393, 52.75618151256016, 50.00030360903059, 51.70458902631487, 51.193201610020225, 45.765821252550396, 47.503068923950195, 48.492714745657786, 51.3868340083531, 44.701701164245605, 46.69730370385306, 51.71392045702253, 46.02689634050642, 44.689969130924766, 47.1071640423366, 49.909678254808696, 47.24486691611153, 44.596894536699565, 44.94141401563372, 49.081032616751536, 49.560753617967876, 48.94067553111485, 47.32346493857247, 47.327105794634136, 49.23120403289795, 45.6771240234375, 41.677848611559185, 35.49403871808733, 36.21112060546875, 36.605806078229634, 38.370818751198904, 37.677920069013325, 36.38292176382882, 38.692475182669504, 37.0682121685573, 39.4849728175572, 39.68328135354178, 38.61052465438843, 38.25262294496809, 38.538576057979036, 38.92364174979073, 39.38664885929653, 41.286682401384624, 44.51474598475865, 50.64608308247158, 51.66071115221296, 51.17413922718593, 51.863431794302805, 51.65012557165963, 48.727657658713206, 46.989819390433176, 47.72750963483538, 50.883047921316965, 51.3972806249346, 53.77188655308315, 49.412256717681885, 48.775899001530235, 45.139719077519004, 42.72528954914638, 53.018931116376606, 54.89354119982038, 54.480748721531455, 55.51637077331543, 57.17540257317679, 55.68785926273891, 57.14909669331142, 56.913830689021516, 57.433837345668245, 51.0129132270813, 55.504659584590364, 47.463425976889475, 20.382625682013376, 1.208224967122078, 0.3820775050137724, 0.16652937552758626, 3.5743861198425293, 59.74143137250628, 57.38216011864798, 48.706107820783345, 45.822108609335764, 55.165966170174734, 46.54420709609985, 54.73049824578421, 59.278771672930034, 48.207133361271445, 2.5252943336963654, 0.23819450714758464, 0.11542439780064992, 0.20856251647429808, 0.13955956271716527, 0.17143089537109646, 0.12231880213533129, 0.06755774202091352, 0.20803654326924256, 0.1708166040480137, 0.0842310098399009, 0.14752158762088843], [0.029654592674757754, 0.016727915333051766, 0.031280946119555404, 0.04748307654101934, 0.03669616107695869, 0.03553719951638153, 0.028204576910606453, 0.0734420587707843, 0.0701126977801323, 0.056388363508241515, 0.027730764388771992, 0.11640775789107595, 13.611917087009974, 48.71209716796875, 43.319926806858604, 44.135687010628835, 31.341823032924108, 19.347041845321655, 22.960515056337627, 33.66501923969814, 38.40300975527082, 48.312103271484375, 4.3995307343346735, 0.10275669861584902, 0.13552497992558138, 0.8547785186341831, 2.427461091961179, 3.289341049534934, 24.115215335573467, 49.66044289725167, 50.92060988289969, 49.331608976636616, 46.41825362614223, 44.34875004632132, 43.61087220055716, 46.08336435045515, 48.509915011269705, 48.11892250605992, 48.02081741605486, 46.76168918609619, 46.79953602382115, 47.406485489436555, 44.53274181910923, 47.3384313583374, 45.95798410688128, 44.12498678479876, 44.526526655469624, 41.91965634482247, 45.83023452758789, 43.07975537436349, 43.036742550986155, 38.64183323723929, 34.58724669047764, 32.34782491411482, 33.32184076309204, 34.98390892573765, 35.45936025891985, 34.49680198941912, 32.88044949940273, 34.889663560049875, 33.77085072653634, 33.102027552468435, 32.81979867390224, 33.09841448920113, 33.521587576184956, 33.0811447416033, 32.97368737629482, 34.13528374263218, 32.77724095753261, 33.05752781459263, 32.8657922744751, 34.27252803530012, 39.46929768153599, 45.35864986692156, 38.03063147408621, 39.96629537854876, 41.81754214423043, 47.67526265553066, 44.17430509839739, 47.0618131501334, 44.99821553911482, 47.57678236280169, 48.87919092178345, 46.29117454801287, 43.52699702126639, 42.677913257053916, 43.708480494362966, 48.57553032466343, 40.497356619153706, 43.395828928266255, 48.11517742701939, 41.46801996231079, 45.27287088121687, 48.18333578109741, 45.98612778527396, 43.88425949641636, 32.162314959934776, 42.9278747013637, 45.696644987378804, 42.83254541669573, 43.179826804569785, 43.73449454988752, 41.24900232042585, 39.7343784059797, 38.428822313036235, 34.33374861308506, 34.38181625093733, 34.82683447429112, 32.19692393711635, 33.316184929439, 33.278873103005544, 34.50597708565848, 32.69393900462559, 33.235210623059956, 35.05050046103341, 33.730314935956685, 34.862735816410606, 34.96974849700928, 34.55951642990112, 35.968909876687185, 35.35164928436279, 36.52587400163923, 38.781811646052766, 39.88328524998256, 41.938114234379356, 44.711560658046174, 46.53822122301374, 47.47842713764736, 47.36757557732718, 47.736663886478965, 46.37175975527082, 48.210298265729634, 47.478972571236746, 47.48013639450073, 49.24099057061331, 48.067022936684744, 43.907320567539756, 37.45993423461914, 42.71570798328945, 48.433613368443076, 49.83920267650059, 51.39075626645769, 51.45145225524902, 53.252696309770855, 54.7425742149353, 50.63946839741298, 54.20557573863438, 55.52403811046055, 57.09106533867972, 50.019390310559956, 31.882587432861328, 0.7662663395915712, 0.20668302875544342, 0.10788658620523554, 0.8494027299540383, 39.64039707183838, 50.86667101723807, 41.639313902173726, 31.895177568708146, 24.364794628960745, 28.690154211861746, 44.45607886995588, 50.77217204230172, 32.685726233891074, 2.0613852611609866, 0.042007882480642626, 0.032511944350387366, 0.03467983998624342, 0.03322203464007803, 0.029260794698659862, 0.05789100644843919, 0.047335308577333174, 0.04704188967921904, 0.03690660192764231, 0.013817866083367594, 0.04423738570351686, 0.0440263104225908, 0.013269150080824537, 0.008685544249601662, 0.025520154973492026, 0.04510306068030851, 0.01854419581858175, 0.04448397211464388, 0.047989704712693176, 0.016023707941972783, 0.03574507889736976, 0.04314274926270757, 0.056663909793964455, 17.15872928074428, 55.76955965587071, 49.37386097226824, 48.04741512026106, 35.37668364388602, 18.350237642015728, 23.786106961114065, 40.3215046610151, 44.118656975882395, 53.623358385903494, 4.640808233192988, 0.1250380583639656, 0.1394960925515209, 4.3926659141268045, 5.218170097896031, 2.501289393220629, 25.169477667127335, 49.946764264787944, 53.08936153139387, 50.487636361803325, 47.83021790640694, 44.94379377365112, 45.15357378550938, 47.18328850609915, 48.888501507895334, 50.27902364730835, 49.63388340813773, 48.165708201272146, 47.60473843983242, 49.12655026572091, 47.83875724247524, 47.75277328491211, 47.53497157778059, 45.91582243783133, 44.108484813145225, 44.510344300951274, 46.25063875743321, 44.45715931483677, 44.98545864650181, 40.669373171670095, 36.296121392931255, 33.52573217664446, 34.8671236038208, 36.213184220450266, 36.83260917663574, 36.039336817605154, 34.82966933931623, 35.887122631073, 34.61833987917219, 35.593436173030305, 33.796454838344026, 33.32729509898594, 34.62691395623343, 34.73893976211548, 35.015273094177246, 36.21428550992693, 33.99942214148385, 36.10336446762085, 33.31761973244803, 35.34041057314192, 42.99127006530762, 47.59701551709856, 40.218601839882986, 41.53185306276594, 43.22374636786324, 46.240664618355886, 45.10906362533569, 46.41946608679635, 46.5625433921814, 48.07442624228341, 50.35325125285557, 48.61396428516933, 45.1179712159293, 43.66317823954991, 45.163405486515586, 50.21262318747384, 43.31705720084054, 45.785251889910015, 49.61901078905378, 43.790972982134136, 46.81004170009068, 48.997807094029014, 47.41453845160348, 44.823527404240195, 33.51442398343767, 44.09896230697632, 48.412647179194856, 46.238375186920166, 45.154404095241, 45.21168157032558, 44.29200758252825, 41.83272048405239, 39.99832657405308, 35.70155709130423, 35.38892984390259, 36.30858646120344, 34.92509937286377, 35.188884258270264, 35.10270227704729, 35.62920549937657, 34.97486237117222, 35.46034342902047, 37.18381977081299, 36.12042576926095, 36.74927943093436, 36.48759290150234, 36.604194096156526, 37.39926603862217, 37.15010363715035, 36.794974258967805, 40.77413811002459, 43.16056292397635, 44.44314479827881, 46.64240946088518, 47.246284348624094, 49.69536106927054, 47.21811635153634, 49.42441259111677, 46.67702538626534, 48.73696477072579, 48.369752475193565, 48.778865882328574, 51.23030151639666, 49.41152368273054, 44.6114753314427, 40.97349582399641, 44.372575419289724, 49.20997381210327, 52.465177059173584, 53.137967654636924, 54.4732620375497, 55.266510077885215, 54.18712132317679, 53.05169187273298, 53.89995922361101, 55.83547026770455, 55.39746972492763, 52.83078779493059, 35.294472558157786, 0.4796437567898205, 0.28066618527684895, 0.022810116643086076, 1.016319521835872, 44.079726219177246, 56.079411097935264, 43.96872527258736, 40.09880794797625, 29.785937241145543, 31.762098721095494, 49.09439400264195, 57.21865510940552, 41.247275693076, 3.4735421368053983, 0.04255448315026505, 0.0173714769605015, 0.007643876796854394, 0.09254159139735357, 0.06484242808073759, 0.030213081277906895, 0.07449762855789491, 0.030791881826839278, 0.020228133137737, 0.019081257982179523, 0.0588702139045511, 0.11194729259503738, 0.08055146371147462, 0.14905437108661446, 0.13219999548579964, 0.14706398360431194, 0.11232913817678179, 0.19860087601201876, 0.22860344180038997, 0.09801274138901915, 0.13248671724327973, 0.10077357145824603, 0.237442174660308, 19.90140734400068, 63.34798417772566, 56.491682461329866, 54.91437189919608, 39.87070901053292, 27.731761387416295, 31.91059214728219, 45.50507967812674, 47.083613123212544, 56.68777452196394, 5.447601352419172, 0.21342921390065125, 0.552306660584041, 6.52608814409801, 8.110468064035688, 4.583814765725817, 28.11245492526463, 51.57671437944685, 53.079109464372905, 52.307977540152415, 50.577306338718955, 46.6969701903207, 47.99440383911133, 49.79098565237862, 51.52676725387573, 51.76046643938337, 51.48957354681832, 48.80114528111049, 50.83192307608468, 50.655880042484824, 49.97901432854788, 49.791065556662424, 48.777913979121614, 46.53375353131975, 45.08757979529244, 45.302254813058035, 49.05360460281372, 45.55882052012852, 46.90160158702305, 42.68701539720808, 37.345354965754915, 35.45000103541783, 36.986140046800884, 38.891419478825156, 39.7810320854187, 37.67842033931187, 35.46655511856079, 36.90049655096871, 36.317389828818186, 38.28511272157942, 36.64282260622297, 34.691480091639924, 36.45462717328753, 36.79518617902483, 35.033157757350374, 37.05177967888968, 36.5791597366333, 36.745402336120605, 36.145988191877095, 37.27229118347168, 44.366471426827566, 49.406100613730295, 41.79381404604231, 42.74048178536551, 43.67757143293108, 47.92623853683472, 46.64776304789952, 49.0008156640189, 47.89418649673462, 49.45602689470564, 53.45769248689924, 49.71607712336949, 45.829268727983745, 46.331456729343955, 48.0413111277989, 53.47423267364502, 46.53098120008196, 49.39375366483416, 51.77362980161394, 45.90125901358468, 50.308887004852295, 50.747783865247456, 49.62807124001639, 47.086562633514404, 36.84875679016113, 45.23890461240496, 50.42506088529314, 46.85319001334054, 46.77817726135254, 47.579342773982454, 44.949696268354145, 44.43788848604475, 41.93000568662371, 37.16216918400356, 37.96622862134661, 38.20900215421404, 35.96339995520455, 37.44854266302926, 36.83735132217407, 37.85249703271048, 35.803692136492046, 37.353039673396516, 38.63054241452898, 36.91146775654384, 37.58976132529122, 38.22868640082223, 38.29405505316598, 40.41735506057739, 40.23807069233486, 38.76779018129621, 43.02219649723598, 43.886920656476704, 47.13496378489903, 49.661624091012136, 49.21822827202933, 51.64763464246477, 50.58778769629342, 52.12814426422119, 49.019933632441926, 50.931129455566406, 48.443570137023926, 50.12024341310774, 52.556709153311594, 51.68945584978376, 47.75863061632429, 42.19674703053066, 47.534943784986226, 51.93498086929321, 53.62444230488369, 54.26193952560425, 55.56115191323416, 57.137969153267996, 57.598756313323975, 54.673095703125, 57.49178532191685, 58.922301292419434, 58.42460877554757, 52.68072407586234, 34.85977588381086, 1.4018296812261855, 0.5965215223176139, 0.2662899009883404, 1.1848900935479572, 49.412899426051546, 62.59518160138811, 53.83542088099888, 39.06172330038888, 32.83423703057425, 37.46541288920811, 57.19464908327375, 65.02881595066616, 52.28991222381592, 5.700491896697453, 0.129450598731637, 0.15775236221296446, 0.12496245599218778, 0.13898750341364316, 0.14623923785984516, 0.17622359176831587, 0.14926414697297982, 0.13827960139938764, 0.11852245298879487, 0.13805183076432773, 0.1831879394927195], [0.02927126449399761, 0.03929965923141156, 0.10108695964195899, 0.003336189385403746, 0.03086936374061874, 0.0472316793166101, 0.017965286704046384, 0.024189673330900923, 0.047591028069811206, 0.009945718638066734, 0.03437805814402444, 0.03536862427634852, 7.572728736060006, 45.50737258366176, 47.99366038186209, 37.536677088056294, 26.808007069996425, 17.10527331488473, 18.910295452390397, 30.8750638961792, 39.35402706691197, 47.867283071790425, 4.6617197053773065, 0.21935511806181499, 0.2378186530300549, 1.5305710073028291, 3.0260388467993056, 2.866330159561975, 21.26614819254194, 50.28246300561087, 49.88033601215908, 48.30473470687866, 47.050828048161094, 48.242791516440256, 47.546946798052105, 48.21307407106672, 47.182357447487966, 46.78911025183541, 45.21914046151297, 44.94286618913923, 43.69439649581909, 45.60339321408953, 45.81010907036917, 46.89850616455078, 44.07324702399117, 43.3223169871739, 41.70982769557408, 41.55982651029314, 45.08143411363874, 44.871650627681184, 41.322271074567524, 37.91852923801967, 33.34235184533255, 31.994196346827916, 33.99156025477818, 32.50383281707764, 33.41808026177542, 33.42803703035627, 33.38436760221209, 33.911815779549734, 32.094580445970806, 33.783138615744456, 33.7498254776001, 32.56785699299404, 32.441128798893516, 32.054440702710835, 33.19640840802874, 32.69672870635986, 33.80404574530465, 33.616812637874055, 32.57394014086042, 34.02884776251656, 35.97809886932373, 41.919524329049246, 45.15081535066877, 45.287649699619834, 43.151408672332764, 46.039781774793354, 42.63022082192557, 43.81303351266043, 40.235426902770996, 44.626240253448486, 43.27466624123709, 47.50567102432251, 45.895238399505615, 43.57989018304007, 41.210328647068565, 49.12961094720023, 41.257159505571636, 43.81148059027535, 45.97992304393223, 42.14315210069929, 45.49974693570818, 46.64523042951311, 44.61063807351248, 42.58179535184588, 41.63623585019793, 43.55462653296334, 44.312619413648335, 41.666349342891145, 37.9545521736145, 36.80882896695818, 36.79354640415737, 35.05346039363316, 33.965445450374055, 32.463397775377544, 34.613232953207834, 33.9866235596793, 33.560250827244346, 35.285888058798655, 34.2217367036002, 34.20533548082624, 34.12550067901611, 33.38792160579136, 34.104878425598145, 35.22759962081909, 33.92290163040161, 34.639139311654226, 34.7363098689488, 34.48230457305908, 36.24197408131191, 37.23034838267735, 37.306010791233604, 35.78032534463065, 37.62689249856131, 42.49300084795271, 42.480633054460796, 45.89710051672799, 45.785474232264924, 46.8197135925293, 44.73257895878383, 45.82972036089216, 45.87691599982125, 45.306739875248496, 47.67336579731533, 50.13328170776367, 47.149179799216135, 39.0594026020595, 40.688435554504395, 47.973031180245535, 48.10194458280291, 51.2261951310294, 53.90757097516741, 55.53958123070853, 52.40151766368321, 52.149878229413716, 51.10244424002511, 54.89896774291992, 57.04879249845232, 66.50327232905796, 37.26117753982544, 0.9017225024955613, 0.19043297001293727, 0.0884276335792882, 0.3517095888299601, 34.64159549985613, 51.98995154244559, 38.555717263902935, 33.90639271054949, 26.100803783961705, 36.25813906533377, 42.241708823612754, 51.92460720879691, 27.48186595099313, 1.972587717430932, 0.10265606508723327, 0.08082750532776117, 0.08716991463942186, 0.03756962563576443, 0.03937736845442227, 0.07548855431377888, 0.03312034938218338, 0.017289893302534307, 0.048754301720431874, 0.030213956588080952, 0.031094440591654608, 0.04555081236841423, 0.023864202134843384, 0.05583075700061662, 0.04777806285502655, 0.019614303218466893, 0.057824374309607914, 0.010159973703723933, 0.004260629947696413, 0.049807968216815164, 0.11689330397972039, 0.06203308275767735, 0.1094166012480855, 10.805795890944344, 52.955129282815115, 50.51674236570086, 46.04607336861746, 29.84943335396903, 22.71138218470982, 26.381309509277344, 33.1472499029977, 44.08010837009975, 51.17708873748779, 5.172799229621887, 0.22140489092894963, 0.011950681900738605, 3.1425994379179816, 3.1017726915223256, 3.5447377221924916, 25.00608904021127, 50.18554605756487, 52.964398179735454, 50.55606916972569, 49.60984264101301, 48.88664286477225, 50.63634865624564, 49.27792372022356, 50.213880811418804, 47.12894664491926, 45.658596651894705, 44.41759279796055, 45.128317083631245, 46.451452119009836, 48.35906267166138, 48.884857177734375, 44.4041862487793, 43.8380400793893, 42.41328763961792, 42.03163003921509, 45.52641759599958, 45.86560433251517, 42.56805876323155, 39.7008707182748, 35.574915749686106, 33.92504514966692, 35.07322107042585, 34.38943147659302, 35.01265362330845, 35.31887115750994, 34.971263204302105, 34.79880196707589, 34.294630255017964, 35.29118258612496, 34.5603015763419, 33.2988144329616, 34.5572269984654, 32.4356883593968, 34.79527228219168, 34.929098061152864, 34.1149012020656, 34.61082192829677, 34.3831398827689, 34.90329245158604, 37.3210814339774, 44.549327169145855, 46.72332123347691, 47.04738521575928, 44.65698603221348, 45.62481451034546, 43.635152680533274, 44.29714924948556, 41.66595329557146, 44.4342337335859, 45.54044600895473, 48.06961114065987, 46.59738513401577, 45.1093658719744, 43.32370662689209, 50.27216230119978, 43.36282498495919, 44.443544319697786, 47.87435981205532, 45.44633265904018, 47.50643880026681, 47.08473525728498, 47.055657046181814, 44.595358984810964, 43.2547561781747, 44.09489761080061, 46.12123203277588, 43.76882559912545, 40.67349345343453, 38.83607707704817, 39.11788558959961, 36.221414361681255, 35.184684072222026, 34.32865905761719, 35.73056582042149, 35.17265326636178, 34.36905241012573, 35.62492193494524, 35.64882026399885, 34.766326086861746, 35.36723409380232, 34.909882817949565, 36.732652391706196, 36.214375836508616, 34.92690937859671, 36.623471873147146, 37.00439643859863, 36.27227864946638, 38.65215131214687, 39.584061077662874, 37.597421714237754, 37.82044846670968, 40.06635291235787, 45.56846809387207, 44.9371269771031, 47.58381393977574, 48.14358513695853, 49.250151770455496, 47.11061034883772, 47.52866956165859, 48.24374341964722, 47.72560930252075, 49.907044887542725, 51.79383863721575, 47.87687158584595, 40.43715395246233, 42.27875314440046, 49.426920890808105, 50.18141187940325, 53.62738834108625, 54.18555450439453, 57.58226128986904, 54.24622964859009, 55.34286035810198, 52.651329721723286, 56.85006359645298, 58.94362531389509, 66.66592270987374, 38.12706552233015, 0.8142099955252239, 0.33491297012993265, 0.09420787662799869, 0.5389062996421541, 37.16615397589547, 54.801745074135916, 43.494434288569856, 37.44670486450195, 28.84085542815072, 39.085166522434776, 49.20366137368338, 58.79469762529646, 36.818035330091206, 2.8290739187172482, 0.007968148682266474, 0.0708726162889174, 0.08071742659168583, 0.022744409008217708, 0.03851231433717268, 0.06102699174412659, 0.031197659338691404, 0.036380150355398655, 0.048029497398861816, 0.040709108779472966, 0.026692578668839166, 0.15640024548130377, 0.07802979688027076, 0.13755188616258757, 0.14695753503058637, 0.07389862462878227, 0.2120985117341791, 0.08444842603057623, 0.14002646266349725, 0.13768168991165503, 0.31221059975879534, 0.18394594453275204, 0.14892097110194819, 14.313682539122444, 60.403622491019114, 58.59893907819475, 50.20948954990932, 37.0898106438773, 25.723681620189122, 27.14262362888881, 42.86914505277361, 48.39188943590437, 57.58995641980852, 6.384110825402396, 0.5083018732922417, 0.4583927999649729, 6.115845654691968, 9.270298719406128, 4.047251420361655, 23.959916148866924, 52.62666709082467, 55.0005920955113, 52.31369938169207, 50.72120005743844, 52.20972306387765, 51.401616300855366, 50.84783445085798, 51.4798321723938, 47.98045185634068, 46.57588740757534, 45.894421986171174, 44.90889992032732, 49.439747265407014, 49.54071848733084, 50.51162154333932, 46.16437339782715, 45.58251735142299, 42.985582964760916, 43.37440068381173, 46.79385239737374, 48.09142501013619, 45.24927479880196, 42.11906269618443, 38.12815291540963, 34.5902795791626, 37.843985489436555, 36.24773761204311, 37.539463315691265, 35.55748619352068, 36.90352596555437, 35.802378926958355, 36.451153073992046, 37.724542481558665, 36.52129166466849, 35.23746953691755, 35.696974754333496, 33.188070569719585, 36.71236712591988, 36.403012480054585, 35.744010584695, 36.29292869567871, 35.76154088973999, 36.45669426236834, 40.85627623966762, 46.12710673468453, 47.43674142020089, 48.81344011851719, 46.840259415762766, 47.82033061981201, 46.06967292513166, 44.66873891013009, 41.414077622549875, 45.37855645588466, 45.805196693965364, 49.9103696005685, 48.482559953417095, 47.48793574741909, 45.0602525302342, 52.639048780713765, 46.2912266595023, 47.421990394592285, 48.842490536826, 45.91513456617083, 48.797997747148784, 49.59247561863491, 48.50098310198103, 45.64869199480329, 45.950393199920654, 47.66629600524902, 47.40940373284476, 46.1689453125, 42.29321929386684, 41.13311331612723, 40.90192243031093, 39.01299558367048, 38.17487955093384, 35.51339292526245, 38.40340232849121, 37.4246061188834, 36.2959372656686, 37.33404677254813, 38.184652192252024, 37.00366340364729, 37.11664458683559, 36.471115248543875, 38.61055244718279, 38.51504945755005, 37.07359702246529, 37.152886390686035, 38.181959765298025, 38.55227095740182, 41.2044608933585, 42.388451303754536, 40.21916464396885, 38.92592770712716, 41.48877770560128, 46.23553337369646, 46.828690665108816, 49.383220195770264, 50.11048466818673, 51.730009010859895, 49.27146536963326, 50.3563814163208, 50.42770120075771, 48.79559367043631, 52.76778847830636, 54.26787676130022, 50.87663473401751, 43.7129864011492, 44.81278201511928, 52.27492148535592, 53.258039474487305, 55.007154669080464, 56.625633307865684, 59.575362477983745, 56.5181759425572, 58.343717847551616, 55.164767605917795, 59.810545103890554, 62.666442326136995, 64.3832449231829, 38.73489740916661, 1.1218830687659127, 0.6282122018081802, 0.36453732049890925, 0.5742731732981545, 42.45763104302542, 61.951597758701865, 51.755804198128835, 43.37662410736084, 37.01824072429112, 47.33946316582816, 54.95046084267752, 65.53617341177804, 46.62846442631313, 5.1406451378549844, 0.20308059134653636, 0.13882493999387535, 0.15093498517360004, 0.11375801757510219, 0.1456636908863272, 0.19283549966556685, 0.07477808065180268, 0.16923613314117703, 0.20158965992076056, 0.12056924030184746, 0.11258766001888684], [0.014340221848604935, 0.061249008402228355, 0.009305094219078975, 0.05305067350023559, 0.015139383430193578, 0.024064013734459877, 0.022291052620857954, 0.034197235346904824, 0.021360226407913224, 0.017290670225130658, 0.06644261721521616, 0.0819757426423686, 10.48767522403172, 42.326723507472444, 47.74952500207083, 33.53040484019688, 30.613585812704905, 21.048176254544938, 16.322268656321935, 31.24101856776646, 34.32455267224993, 49.879842690059114, 4.035342642239161, 0.060027957494769774, 0.11888697557151318, 4.728055460112436, 3.3883051105907986, 2.418519194637026, 22.044704266956874, 46.64766577311924, 53.48851122174944, 50.62356744493757, 49.09243113654, 48.645592485155376, 48.194588388715474, 47.671006883893696, 47.154641083308626, 46.28836052758353, 47.9901967048645, 45.47452844892229, 43.673656123025076, 43.696123123168945, 41.66321570532662, 40.57997070040022, 44.13738237108503, 44.23237119402204, 46.76876245226179, 46.265042373112266, 44.302009514399934, 43.76778336933681, 40.00109543119158, 36.049609729221885, 32.18208605902535, 31.82724850518363, 31.181698322296143, 32.017069816589355, 32.40706525530134, 31.981821605137416, 30.280346734183176, 32.06160429545811, 32.52640404020037, 33.01284742355347, 31.94434997013637, 32.68948868342808, 31.859759126390728, 33.537742137908936, 33.207442147391184, 33.752104486737935, 32.59240845271519, 33.73473399026053, 33.0938321522304, 32.094295569828574, 31.63292476109096, 38.22899906975882, 43.62034606933594, 45.54099144254412, 44.246048722948345, 44.028747286115376, 46.488666670663015, 45.310273034232004, 46.28663042613438, 44.369368825639995, 44.50937850134713, 45.419734954833984, 46.09433903012957, 45.355248723711284, 42.44900138037545, 46.83481550216675, 41.94988448279244, 41.44929109300886, 45.64818477630615, 42.21785218375069, 45.58455317361014, 45.046707017081125, 43.629562854766846, 43.67976706368582, 46.048133509499685, 46.83052846363613, 43.83816862106323, 42.817474773951936, 41.82153041022164, 38.16566971370152, 35.52565996987479, 35.03167084285191, 34.27136073793684, 33.656834261757986, 34.46574354171753, 33.83132437297276, 32.982702663966585, 34.08157416752407, 34.6654486656189, 32.89359201703753, 34.29782295227051, 33.50137179238455, 34.2396456854684, 33.44358015060425, 35.309004715510774, 35.5892915725708, 34.5962724004473, 34.9698075566973, 36.76271377290998, 35.60398006439209, 35.14494037628174, 35.4302716255188, 34.817193848746165, 35.93920980181013, 37.66836977005005, 40.9728114264352, 42.83298315320696, 44.33782747813633, 46.4704623903547, 47.50377764020647, 48.7079074042184, 47.353224073137554, 48.04311418533325, 50.82400907788958, 45.638412134987966, 41.67580236707415, 38.476552963256836, 45.02237442561558, 49.15104613985334, 50.446141719818115, 52.010476521083284, 52.119323526109966, 50.42141655513218, 48.6862324987139, 51.104122229984824, 52.23885686056954, 54.738846506391255, 56.38000406537737, 28.39751693180629, 0.5707006050007684, 0.05490533701543297, 0.007571935969670969, 0.239087024969714, 31.72141007014683, 52.88055426733834, 40.883923121861045, 39.12672369820731, 19.35608492578779, 29.035915681294032, 40.637550422123496, 49.36588791438511, 34.31260177067348, 4.308268317154475, 0.1103417430339115, 0.021411678022039787, 0.039404153624283414, 0.009394612495920487, 0.042339000784392865, 0.02757577002713723, 0.02280633889936975, 0.02143213924552713, 0.015496267404939448, 0.023947885858693292, 0.04090569394507578, 0.04396734233679516, 0.02616946548888726, 0.013058580308487373, 0.10716120512889964, 0.010150053521751292, 0.02828159572423569, 0.012290191138163209, 0.005577810607584459, 0.05488903860428503, 0.06627731929932322, 0.012271972472912498, 0.03480538932074394, 12.351585950170245, 49.4530530657087, 54.485807010105674, 39.93875271933419, 34.32763419832502, 19.63784306389945, 19.195998430252075, 39.5156386920384, 40.01443944658552, 55.14265496390206, 4.144437611103058, 0.0819555019427623, 0.21333226481718676, 3.881220740931375, 3.9163034984043668, 4.717063409941537, 24.74083808490208, 46.50916038240705, 54.68251746041434, 51.37457391193935, 50.79112325395857, 51.3042824608939, 50.144655908857075, 48.89047827039446, 47.970203263419016, 46.79059716633388, 47.28216137204851, 45.48681286403111, 43.829594544001985, 43.10857997621809, 42.250689370291575, 41.020844323294504, 43.2704313141959, 44.921087060655864, 46.36456836972918, 46.85154676437378, 45.10578407560076, 46.04744911193848, 40.87624536241804, 38.50674636023385, 33.92486449650356, 33.99125453404018, 33.30935137612479, 33.61954327992031, 34.012217249189106, 32.33079835346767, 32.466058935437886, 34.592968532017295, 33.75427232469831, 36.083708013807026, 33.93901102883475, 33.92807109015328, 33.45767804554531, 35.59617723737444, 35.15445246015276, 35.42808641706194, 33.33927379335676, 35.07405138015747, 34.307390621730256, 32.17231341770717, 33.92783832550049, 40.470241274152485, 44.75986800874983, 47.387242453438894, 47.548739433288574, 46.44068935939244, 47.03332553591047, 48.14535345349993, 46.78406238555908, 43.224823338644846, 44.58359568459647, 48.650265148707796, 47.57464231763567, 45.819701058524, 44.41652972357613, 48.85478884833199, 43.945139612470356, 44.456165722438264, 47.31753812517439, 45.33647469111851, 48.99731377192906, 46.33381911686489, 44.821220602308, 45.342043672289165, 46.64537286758423, 46.43216391972133, 45.417667865753174, 44.223300320761545, 43.1465379851205, 39.28539623532976, 37.13603700910296, 35.82990768977574, 36.485994815826416, 34.9421398299081, 36.29872349330357, 34.99189935411726, 33.40376697267805, 35.52516317367554, 36.62322173799787, 34.526863370622905, 35.76485865456717, 35.748099599565776, 34.52976771763393, 35.20291614532471, 37.52527856826782, 36.69347149985177, 37.501373291015625, 36.225110803331646, 38.00307491847447, 37.85954598018101, 36.848867961338584, 36.20469699587141, 36.07336562020438, 37.86589663369315, 41.22214753287179, 41.8300176348005, 45.524506841387065, 47.116505895342144, 47.85486316680908, 50.563399519239155, 50.667962959834504, 48.91170154299055, 49.52397680282593, 52.16192640577044, 47.365265301295686, 42.949438435690745, 40.864502906799316, 47.15703821182251, 50.30410664422171, 53.674038546425955, 55.478628158569336, 54.48683186939785, 52.174485274723594, 50.935972349984304, 51.892638547079905, 54.12223557063511, 55.03050756454468, 57.66792910439627, 29.886550630841935, 0.6475927904248238, 0.30089486124260084, 0.03633202525920101, 0.2776308538658278, 35.616194997514995, 57.67151090076992, 42.94204555238996, 40.09242950166975, 23.93252808707101, 33.32236187798636, 45.70598684038435, 55.34843976157052, 41.29708385467529, 5.700813685144697, 0.0523837719644819, 0.028613224625587463, 0.043610857001372745, 0.0032854830995867296, 0.04175737413710781, 0.03436721854710153, 0.020589714271149466, 0.03415139012836984, 0.02181258874147066, 0.029644730168261697, 0.005221570392937532, 0.10291187957461391, 0.11426863553268568, 0.06221917777189186, 0.21552033669182233, 0.11939118137317044, 0.09931584753628288, 0.07723452669701406, 0.08051664807966777, 0.18825085567576544, 0.19976119803530829, 0.15479777646916254, 0.2272095408822809, 16.308608497892106, 56.98033537183489, 61.78187411172049, 47.05498307091849, 40.604233809879844, 27.85052694593157, 24.785808563232422, 42.64332512446812, 44.197119508470806, 58.38371862683977, 5.060389535767691, 0.34276603588036125, 0.32887674974543707, 12.969223482268196, 7.340790918895176, 4.88425270148686, 24.52247531073434, 49.16730145045689, 56.683956486838206, 53.72959981645857, 53.06236777986799, 53.25846331460135, 50.41057736533028, 49.08435385567801, 46.9490647315979, 48.62545313153948, 48.834597383226665, 48.20384338923863, 44.87023319516863, 44.18909781319754, 41.68024921417236, 41.16368191582816, 45.645544460841585, 47.35419682094029, 49.23457390921456, 49.42101492200579, 46.72523546218872, 47.69039235796247, 43.88752862385341, 40.598876748766216, 36.23947272981916, 36.48458085741316, 35.1113840511867, 36.00543655667986, 34.86375025340489, 34.497965812683105, 33.296083790915354, 35.95501695360456, 35.8059537751334, 36.12852736881801, 35.6241124698094, 35.494118622371126, 34.026679924556184, 37.84519100189209, 36.71483721051897, 37.74731520244053, 34.69788633074079, 37.28197349820818, 35.688251291002544, 34.61201354435512, 35.47444827216012, 42.991961411067415, 46.67216512135097, 48.40938152585711, 48.883971282414024, 47.67701360157558, 49.46875252042498, 49.94080965859549, 48.63869639805385, 47.15845911843436, 46.92117118835449, 49.06458970478603, 50.76797185625349, 49.03799894877842, 45.94040169034685, 49.32030425752912, 45.21462065832955, 47.104725224631174, 48.022081988198416, 47.54365335191999, 51.12787464686802, 48.43333196640015, 44.906339509146555, 47.706171716962544, 47.245888301304404, 49.934073380061555, 47.36778749738421, 46.71837759017944, 45.28511013303484, 41.95101356506348, 39.3713767187936, 37.75535079411098, 38.242964948926655, 36.71362822396414, 38.22142205919538, 36.83721235820225, 36.01956919261387, 37.72058548246111, 39.699873651777, 35.31473003114973, 36.71861355645316, 37.35799373899187, 36.097948346819194, 37.98150771004813, 39.9594965662275, 38.1530031476702, 39.061181340898784, 38.36941174098423, 40.64901147569929, 38.75521394184658, 38.839822156088694, 39.14193330492292, 38.74207837241036, 39.831430843898225, 42.67263262612479, 43.90366928918021, 47.75721318381173, 48.4815559387207, 50.4922638620649, 52.563876220158164, 53.612383706229075, 51.88949448721749, 52.07677970613752, 53.98884405408587, 50.592151165008545, 45.10389763968331, 42.20603677204677, 49.54870891571045, 54.260365758623394, 55.72090836933681, 56.831293037959504, 57.58177144186837, 54.85652814592634, 52.43526159014021, 54.31339093617031, 57.03868286950247, 57.987469809395925, 60.974729674203054, 31.92017718723842, 0.9818021740232195, 0.40020633222801344, 0.16986300450350555, 0.3652179182640144, 38.51180464880807, 63.83519186292376, 53.29999269757952, 50.26541212626866, 29.71379062107631, 40.496085098811555, 54.82031066077096, 62.991895948137554, 52.90428931372506, 9.555438893181936, 0.19480591107692036, 0.20644186383911542, 0.200454443693161, 0.09097340197435447, 0.18656591751745769, 0.15168354500617298, 0.18501518001513823, 0.11797889215605599, 0.09987435649548258, 0.11447866926235811, 0.12598500826529094], [0.040046614328665395, 0.06694789510220289, 0.07730976944523198, 0.007169639342464507, 0.050149332399347, 0.04081146917971117, 0.015053560624697378, 0.01737789250910282, 0.10825733095407486, 0.07296821741121155, 0.029279064254036972, 0.15584514955324785, 7.724775297301156, 46.226907185145784, 44.149423599243164, 42.898150307791575, 19.848441226141794, 31.616763251168386, 31.370223794664653, 23.849321671894618, 39.364220074244905, 45.16430875233242, 5.051116296223231, 0.08598055810268436, 0.09812482180339949, 1.9052431711128779, 1.9610723810536521, 5.945334689957755, 23.00310230255127, 41.49127210889544, 51.101370743342805, 48.48435606275286, 50.74272905077253, 47.98685114724295, 49.76734093257359, 47.24388722011021, 49.695590359824045, 47.89580542700631, 48.824616295950754, 47.443703515189036, 47.72145427976336, 49.51416942051479, 44.914038113185335, 42.77642134257725, 46.16476249694824, 46.48926074164254, 44.01275600705828, 43.419873169490266, 42.349732467106406, 38.95054170063564, 35.5893680027553, 33.296271392277305, 33.82794754845755, 31.47799035481044, 31.85540955407279, 33.16396032060896, 32.996654646737234, 32.317544664655415, 33.862150056021555, 31.953921113695415, 31.620327677045548, 32.04953874860491, 32.19440521512713, 32.71850436074393, 33.44565071378435, 33.30069392068045, 33.32139607838222, 32.04857989719936, 32.66886643001011, 32.63058532987322, 32.04186793736049, 33.83676133837019, 31.641005516052246, 32.925935881478445, 37.763087613242014, 41.20833451407296, 41.43184764044625, 41.96342999594552, 42.851364612579346, 43.834131717681885, 43.793571608407156, 43.327698366982595, 45.7986375944955, 49.535396167210166, 45.19151094981602, 43.225497313908164, 42.675957339150564, 47.22548839024135, 43.073237964085166, 43.37527963093349, 46.434634004320415, 43.42744323185512, 46.473856585366384, 43.71896185193743, 46.167996883392334, 45.33432422365461, 46.29764679500035, 44.966364996773855, 46.96008457456316, 45.73083012444632, 45.633034229278564, 44.51884889602661, 43.04052584511893, 38.81204325812203, 34.68494531086513, 31.805806364331925, 34.59182555334908, 34.15916470118931, 33.924927030290874, 34.268192359379356, 34.963710512433735, 33.41334506443569, 33.34359557288033, 34.587951932634624, 33.50289692197527, 32.99203756877354, 34.222761562892366, 34.899849619184224, 34.30432299205235, 34.81359815597534, 34.75980520248413, 35.397347586495535, 35.07512835093907, 36.21171815054757, 35.89183003561837, 35.86319998332432, 34.94794157573155, 37.2125575201852, 38.53980588912964, 39.99576963697161, 40.15188871111189, 42.530291829790386, 46.00235182898385, 50.20692219052996, 49.83286244528634, 49.847644737788606, 45.613843304770334, 42.20233685629708, 37.28339787891933, 42.77805069514683, 49.03823518753052, 51.246428285326274, 53.71978896004813, 53.40057829448155, 48.92614337376186, 48.18186623709542, 49.422630378178184, 53.23175096511841, 53.49208606992449, 58.39072241101946, 23.180062498365128, 0.31448293211204664, 0.5851611090557916, 0.05613704092268433, 0.17767150407390936, 28.80376594407218, 53.70904704502651, 43.76787717001778, 35.5609255518232, 19.879713330950054, 31.80316604886736, 43.858947208949495, 48.17948995317732, 40.502894333430696, 6.834533878735133, 0.037238697321819406, 0.046411306730338504, 0.040558735241315196, 0.02409185911528766, 0.06471803225576878, 0.09028775590871062, 0.03737652135480728, 0.046911750055317364, 0.02068331478429692, 0.012851660206381763, 0.03363707076225962, 0.03286662478266018, 0.05003212226022567, 0.04895955517089792, 0.003308460203697905, 0.11841126824063913, 0.007236849084230406, 0.028048954904079437, 0.052108049259654114, 0.03962963420365538, 0.06640798478786435, 0.02821156582129853, 0.10597581123667103, 10.387491754123143, 53.65682438441685, 49.23647771562849, 47.72228111539568, 27.34942286355155, 40.91434580939156, 30.33037028993879, 30.22505991799491, 40.97646270479475, 51.945813110896516, 5.101981452533177, 0.05931048813675131, 0.008327279456092842, 2.6716663880007605, 4.03010413476399, 7.532368387494769, 25.258204426084244, 42.568260260990684, 51.484782763889854, 49.21624803543091, 52.406447410583496, 49.47269214902605, 51.031867912837434, 47.3331298828125, 50.1199620110648, 49.44757093702044, 50.45827674865723, 49.93251003537859, 49.58367225102016, 50.02845770972115, 46.052121775490896, 43.465700013296946, 46.645994731358115, 46.99062885556902, 45.54590381894793, 44.22804594039917, 43.77853570665632, 41.23839936937605, 37.364042145865305, 33.902022293635774, 35.11136668069022, 32.1747487613133, 33.856282302311485, 34.16321897506714, 34.821463516780305, 33.38863032204764, 34.0831618309021, 34.774618761880056, 33.58157484872, 34.626858370644705, 32.59114040647234, 34.80006306512015, 33.53978838239397, 33.79896313803536, 33.84637417112078, 34.43352474485125, 33.859850202287944, 33.53602245875767, 34.22414425441197, 34.98528119495937, 34.30971132005964, 34.46110561915806, 39.17155000141689, 44.31446416037423, 43.72019168308803, 44.13015277045113, 45.978081771305625, 46.29856048311506, 44.659313678741455, 44.597252368927, 47.57073048182896, 49.6452054977417, 46.735921791621614, 46.261957372937886, 45.26250416891915, 47.317499910082134, 45.26714556557791, 45.36358656202044, 48.95686483383179, 46.06524344852993, 45.88515656335013, 45.36982257025582, 46.91994135720389, 48.463883195604595, 48.20135246004377, 47.51027767998831, 48.09367970057896, 47.90738112585885, 47.41475731985909, 45.69399424961635, 45.02686643600464, 39.90137488501412, 36.26807846341814, 34.40613147190639, 35.38211366108486, 34.533533641270225, 35.10381746292114, 36.02209833690098, 35.80860103879656, 34.68847846984863, 34.9306127684457, 35.5432562828064, 35.457133361271445, 34.443488461630686, 37.62468644550869, 35.84977606364659, 36.524032729012625, 37.25683838980538, 36.095728397369385, 37.39616366795131, 36.977138655526296, 37.08923741749355, 37.29130492891584, 38.14849376678467, 37.31729119164603, 37.56307676860264, 39.00841672079903, 40.309077807835166, 41.72066688537598, 45.6854236466544, 48.39345972878592, 49.7059258052281, 50.86032036372593, 52.2687897000994, 48.05817787987845, 44.93155104773385, 38.78863477706909, 45.52430534362793, 51.5530001776559, 53.149657998766216, 55.68895360401699, 55.58557483128139, 50.99239867074149, 50.504940850394114, 50.906216689518516, 56.421168667929514, 56.1138185773577, 60.27710274287632, 25.84481998852321, 0.42029894835182596, 0.669524507863181, 0.010986397974193096, 0.10090033537042992, 30.6294971874782, 58.53742667606899, 47.50955854143415, 40.08042648860386, 25.720895392554148, 42.13230248859951, 49.147308009011404, 53.672298022678916, 47.05890532902309, 9.520253215517316, 0.054213699485574446, 0.03928774754915919, 0.011683321291846889, 0.056263262006853304, 0.04823739035055041, 0.0547483884729445, 0.04757211051349129, 0.039927293945636065, 0.0475169320457748, 0.023825659649446607, 0.011192787970815386, 0.18665860540100507, 0.11015859964702811, 0.14891392790845462, 0.10497191189123051, 0.2280485358621393, 0.06215506299797978, 0.11451446876994201, 0.1909796656774623, 0.15244802327028342, 0.16249320496405872, 0.09799332171678543, 0.2091031460357564, 12.542918494769506, 62.80965164729527, 53.06551878792899, 54.599875586373464, 29.41303437096732, 40.50613219397408, 39.95690141405378, 34.04325137819563, 48.058021545410156, 56.53466401781355, 6.078843891620636, 0.21194764625813278, 0.33075042920453207, 4.6879174539021085, 7.687793510300772, 9.7934034040996, 26.467465434755596, 43.000948905944824, 53.3995360646929, 50.55087539127895, 53.35986532483782, 52.00184685843331, 53.94926711491176, 49.418610845293315, 52.859240668160574, 50.931230204445974, 52.71483973094395, 51.38038955415998, 51.522438526153564, 53.01957729884556, 48.10737460000174, 45.62965045656477, 48.58576502118792, 49.638924326215474, 47.84595210211617, 46.45796258108956, 46.24288804190499, 43.4340683392116, 39.514023235866, 35.71693345478603, 37.19009746823992, 34.211425576891216, 35.7399354662214, 35.493673937661306, 36.61035714830671, 34.59445892061506, 36.97269180842808, 37.00661986214774, 34.48689733232771, 36.95906291689192, 34.80447169712612, 36.419528348105295, 35.32914754322597, 35.27925600324358, 35.87961857659476, 35.66706623349871, 35.28257724217006, 34.902927671160015, 35.71200370788574, 37.521516118730815, 36.33723388399397, 36.67088290623256, 41.298678466251914, 44.980890205928254, 46.38697978428432, 45.48525994164603, 48.77699681690761, 48.325739111219136, 46.63954332896641, 45.68113660812378, 49.89279760633196, 52.303593226841514, 48.82012775966099, 47.633205209459575, 47.57712977273123, 49.97562708173479, 47.20229877744402, 47.83325774329049, 51.22076163973127, 48.12387309755598, 47.99648135049002, 47.5252024105617, 49.501551491873606, 49.38842439651489, 50.33572442190987, 50.348022733415874, 50.981858253479004, 51.72761188234602, 49.85035106113979, 49.489055156707764, 47.435007844652446, 42.218144008091514, 38.15689066478184, 34.792034421648296, 37.97470194952828, 36.73935740334647, 37.40603705814907, 37.905126162937705, 38.51555667604719, 36.80434043066842, 37.72272552762713, 37.532063484191895, 36.85318626676287, 35.46100698198591, 38.71421609606062, 37.550646441323416, 38.38816145488194, 39.362754004342214, 37.55987017495291, 39.652688435145784, 39.78591666902815, 39.45582512446812, 40.150325366428916, 39.308474676949636, 39.799865177699495, 40.28141008104597, 41.208400521959575, 44.49850109645298, 42.89614575249808, 45.769156387874055, 50.8895514351981, 52.64845664160592, 54.05803768975394, 53.84414781842913, 50.084029402051655, 47.24598557608468, 40.68045554842268, 46.952333859034944, 54.373687403542654, 55.28028835569109, 58.34852600097656, 57.938290459769114, 53.719462394714355, 54.627077783857075, 53.094930512564524, 57.30918318884713, 58.731211934770855, 61.394873346601216, 26.43510593686785, 0.9298389852046967, 1.7984877909932817, 0.1743880052651678, 0.39039729429142817, 35.68718474251883, 63.27132470267159, 55.87918833323887, 47.30914470127651, 29.688071863991873, 43.77152497427804, 55.0828274999346, 62.0279723576137, 55.74047449656895, 13.781218630926949, 0.1462637058326176, 0.14184960483440331, 0.08927580235259873, 0.09623966153178896, 0.09085803745048386, 0.13188773367021764, 0.15774787031114101, 0.12915401107498578, 0.08506083781165735, 0.0954555736056396, 0.22370478537465843], [0.02102707080276949, 0.0135432146157005, 0.040669682502214394, 0.025981438346207142, 0.04777729271778038, 0.033885197447878976, 0.049328810535371304, 0.03158273474712457, 0.012712060107982584, 0.03739763057923742, 0.001677123661335957, 0.0563715528031545, 5.237073106425149, 41.75954205649239, 48.22089426858084, 39.7170079095023, 18.26131980759757, 9.498373338154384, 34.38946621758597, 38.23360225132534, 35.39599616186959, 43.545357636043, 5.450134839330401, 0.06557184644043446, 0.06129509450069495, 2.1313112803867886, 3.3297715314796994, 4.946765209947314, 23.797779934746877, 39.453233446393696, 53.87221506663731, 46.711613518851145, 52.24063212530953, 46.68258741923741, 46.293015820639475, 40.76437241690499, 45.11137042726789, 39.92236539295742, 42.21418006079537, 43.07536063875471, 44.232346875326975, 45.32093504496983, 45.91560009547642, 44.89813368661063, 46.093717166355674, 42.22390406472342, 40.62485606329781, 38.716957160404746, 36.2244541985648, 34.23178032466343, 31.9396390914917, 31.28267649241856, 31.93593222754342, 30.9220997265407, 32.37749024799892, 32.469633783612935, 32.66529853003365, 30.975336824144634, 32.383941650390625, 31.522806235722133, 32.85639830998012, 32.054854120527, 33.539541721343994, 32.406769956861226, 33.09392942701067, 31.68964638028826, 32.462473664964946, 33.525596686771934, 31.977885450635636, 32.219675813402446, 32.41451372419085, 32.907189641680034, 33.137313979012625, 32.71424511500767, 32.54285042626517, 34.2420323916844, 36.52100331442696, 38.373990603855674, 41.138015270233154, 43.58846773420061, 44.984819412231445, 43.91830914361136, 47.01256431852068, 46.606508118765696, 46.133200304848806, 45.00759560721261, 43.526694774627686, 46.46511575153896, 43.37797900608608, 41.66928495679583, 46.127290861947195, 43.596934114183696, 47.08767087118966, 45.358576910836355, 46.04400280543736, 46.20931782041277, 46.23893799100603, 44.26638610022408, 45.022044386182515, 44.41015822546822, 47.42885174070086, 47.82437794549124, 45.377184186662944, 43.871613774980815, 38.441874504089355, 34.03732803889683, 33.28319835662842, 33.04331180027553, 33.167549065181184, 33.13345772879464, 34.407555852617534, 33.53658178874424, 34.28280094691685, 33.496949263981406, 33.29901245662144, 33.426400729588096, 34.207753453935894, 33.2129624911717, 35.08098915645054, 35.227481501443044, 35.587287017277305, 34.51423849378313, 34.57762343542916, 35.15630068097796, 35.329373359680176, 35.12384564535958, 34.17842510768345, 34.83149324144636, 34.84998934609549, 35.684308188302175, 34.61205870764596, 36.429089069366455, 36.69541352135794, 40.122028827667236, 42.50986760003226, 42.35465179170881, 39.75415645326887, 38.90148047038487, 38.31458698000227, 41.794342109135215, 51.05094419206892, 51.6516090120588, 53.92034523827689, 51.8671212877546, 48.062325954437256, 46.5405592918396, 51.511901582990376, 53.79370737075806, 53.65807506016323, 51.46749217169625, 19.428726605006627, 0.11943743032004152, 0.34137034362980295, 0.03580654399203403, 0.03289785774956856, 25.206746067319596, 57.429994991847444, 42.72720725195748, 42.6015282358442, 17.53679813657488, 17.208844900131226, 37.87167753492083, 48.2658143724714, 41.67632695606777, 4.99693728344781, 0.0553916905607496, 0.020342579942994883, 0.07800884371889488, 0.015441446864445294, 0.04712265570248876, 0.025057904688375335, 0.0201277014732893, 0.05077212576621345, 0.07393656152167491, 0.0542919413585748, 0.008189585192927291, 0.024495429691991637, 0.02092597078132842, 0.052890478167682886, 0.014730676343398435, 0.0260722772218287, 0.044132762388991456, 0.029807575180062225, 0.022534261623929654, 0.06630129194153206, 0.008314431395514734, 0.028794254375887767, 0.07825351666126933, 7.5935863597052435, 49.633796555655344, 53.16914769581386, 45.923100675855366, 24.17083740234375, 15.039141348430089, 27.6058600289481, 32.656991958618164, 40.31147493634905, 47.558362688337056, 6.115334527833121, 0.16750714448945864, 0.07612630259245634, 6.240976197378976, 5.443143214498248, 6.884953481810434, 20.68939733505249, 41.565180097307476, 53.49247516904558, 48.99127231325422, 52.34839173725673, 48.98095771244594, 46.8612186568124, 44.61867713928223, 45.865465368543354, 41.435342584337505, 43.22020626068115, 45.461000306265696, 46.25661768232073, 47.28867530822754, 46.84800318309239, 46.288016591753276, 47.050536223820274, 44.80920716694423, 42.190069811684744, 40.201759406498496, 37.826872076307026, 36.681808948516846, 33.807276657649446, 33.054109300885884, 33.46348326546805, 33.23160798209054, 33.8600378036499, 34.29856640951974, 34.14033160890852, 34.775174617767334, 34.059489318302695, 33.144585268838064, 33.442058495112825, 33.78335748400007, 33.34498173849923, 34.11816685540335, 33.72643436704363, 33.93847949164254, 34.40272338049752, 34.47741651535034, 34.25297927856445, 34.139546462467735, 34.82357924325125, 33.863265241895405, 35.216572829655235, 34.13422761644636, 34.80090727124895, 36.73024831499372, 38.19059637614659, 40.842060225350515, 42.33571447644915, 45.992033754076274, 46.74045549120222, 45.56027964183262, 47.23688691002982, 47.17124032974243, 48.18336009979248, 45.7931797845023, 45.20996536527361, 48.98999384471348, 44.48301356179373, 43.309546198163716, 48.27567039217268, 45.77777910232544, 48.549926212855745, 46.982409136635916, 47.363455295562744, 46.39812469482422, 47.385074615478516, 46.05646787370954, 46.39852769034249, 44.10598693575178, 47.0913325718471, 48.64148609978812, 47.694137437003, 46.771399293627056, 40.544798919132774, 35.31469529015677, 34.24282101222447, 34.631951400211875, 35.03326198032924, 35.43433632169451, 35.10028082983834, 35.855004583086284, 35.30319949558803, 35.73952899660383, 34.964582511356895, 35.69517169679914, 35.32570123672485, 35.0821008682251, 36.5188250541687, 36.04684087208339, 35.96879523141043, 35.3511073248727, 37.21876573562622, 36.07163551875523, 36.14154134477888, 37.84498603003365, 37.35754210608346, 37.13480370385306, 37.68132816042219, 37.40743364606585, 36.389797006334575, 39.27694027764456, 38.550391469682964, 43.095437458583284, 44.2028100831168, 45.16932187761579, 42.21602480752127, 39.418304852076936, 39.35160214560372, 43.57006890433175, 52.65667288643973, 54.69605255126953, 55.74586629867554, 52.37352337156023, 49.15279013769967, 48.0354676927839, 51.997959341321675, 56.59168093545096, 55.90644611631121, 53.608173097882954, 20.33297211783273, 0.3926949224301747, 0.8751139960118702, 0.0482066696775811, 0.07553470148039715, 27.535177741731914, 60.06980323791504, 46.06637947899954, 43.205194677625386, 19.86529060772487, 22.84088965824672, 43.16120563234602, 53.8061238016401, 50.44711446762085, 8.283262814794268, 0.04608472782586302, 0.049525470339826176, 0.025437195585774522, 0.00843303422776184, 0.10487446069185223, 0.01804236149681466, 0.02076599936533187, 0.018309208963598524, 0.053699410653540065, 0.04165897638137851, 0.0290362674609891, 0.08498110994696617, 0.07742303729589496, 0.12520584650337696, 0.1342561872942107, 0.17342586975012506, 0.14571536811334745, 0.0735039140230843, 0.10202853554593665, 0.17115032114088535, 0.17095486234341348, 0.14133790800614016, 0.11625633601631437, 9.722533515521459, 58.729266439165386, 59.136819975716726, 52.14976705823626, 28.159369162150792, 16.78192847115653, 41.83131694793701, 46.9795812198094, 43.160747051239014, 53.99515996660505, 7.343023027692523, 0.23514061101845332, 0.17290924675762653, 9.631014449255806, 10.093190380505153, 8.294420753206525, 25.73233039038522, 42.79540034702846, 55.85287550517491, 50.09515694209507, 55.96157659803118, 50.46803549357823, 49.65687499727522, 44.99925776890346, 48.47521570750645, 43.60408728463309, 45.488285882132395, 46.7064961705889, 48.44871527808053, 48.002877167293, 48.57369252613613, 47.08412034170968, 48.43299845286778, 46.84162473678589, 44.41570288794381, 41.982662609645296, 40.451022556849885, 40.63502822603498, 34.665816920144216, 35.0365172113691, 34.18127734320504, 35.66862262998308, 35.63050481251308, 36.33194630486624, 36.477118492126465, 36.29652091435024, 36.208303110940115, 35.99946457999093, 36.89318357195173, 36.093550137111116, 35.925646918160574, 35.45121349607195, 36.28424692153931, 34.287716797419954, 35.54984664916992, 35.76008524213518, 35.036485944475444, 35.29836007526943, 36.152863434382844, 35.125044209616526, 37.09828397205898, 35.07714680262974, 37.28314774377005, 39.040541716984336, 39.09883362906319, 40.848938941955566, 43.87303468159267, 48.05141380855015, 49.4831839288984, 48.159413133348735, 49.558995723724365, 49.247681685856406, 49.622286864689414, 47.358789580208914, 46.60877670560564, 50.37501648494175, 46.078636101314, 44.684959479740684, 50.426502636500764, 47.2142253603254, 49.78099414280483, 47.70215218407767, 48.95235545294625, 49.20070491518293, 49.116173131125315, 46.89175598961966, 48.56196396691458, 44.882670470646445, 50.61588968549456, 49.874509947640554, 49.56739262172154, 47.54029042380196, 42.51528024673462, 38.44385126658848, 36.903786523001536, 36.51886674336025, 37.364865507398335, 36.935452938079834, 37.15718732561384, 38.741018772125244, 37.47351448876517, 38.45518030439104, 36.78300598689488, 38.351009437016074, 38.8524956703186, 37.17669439315796, 38.63636153084891, 38.509841782706125, 38.75902155467442, 37.274104663303916, 38.0427873475211, 38.283069951193674, 38.84171206610543, 38.54979739870344, 39.113421372004915, 39.39404174259731, 38.79388761520386, 39.11921616962978, 38.31114067350115, 40.81568833759853, 40.06831577845982, 45.26483528954642, 47.20893430709839, 47.12927321025303, 43.374956539699006, 42.39198793683733, 41.50595712661743, 45.39705950873238, 53.5106759752546, 56.187622342790874, 58.91795866830008, 54.91241945539202, 51.362046309879844, 50.81118270329067, 55.860059942517964, 59.992692129952566, 58.24830865859985, 55.785266058785574, 22.77278515270778, 0.7548757450921195, 1.1540559423821313, 0.14501830908868993, 0.1922631553773369, 31.106821060180664, 66.2896569115775, 54.807129928043906, 54.60205384663173, 27.32622630255563, 28.451066698346818, 51.48061384473528, 60.95152963910784, 60.07026181902204, 12.703883068902151, 0.13670217032943452, 0.12151872792414256, 0.1930017407451357, 0.10755046709839787, 0.11940904041486126, 0.07624287490866014, 0.15050673458193028, 0.12112000717648438, 0.17198951968124934, 0.12395252447043147, 0.13154101584638866], [0.05782575173569577, 0.056889576970466545, 0.04026928577306015, 0.046836290175893476, 0.05132536590099335, 0.04209302505478263, 0.047640082758984396, 0.05758505500853062, 0.05229724517890385, 0.026948710371341025, 0.03286178343530212, 0.043686958096389256, 7.772134218897138, 39.889844349452424, 47.37404087611607, 40.57847336360386, 26.94314432144165, 43.08516454696655, 46.1660235949925, 43.464574405125205, 32.14586509977068, 43.879246371132986, 9.000088487352643, 0.08563335173364196, 0.14260729774832726, 2.0113690878663744, 1.5924842336348124, 6.99104118347168, 21.938572270529612, 45.80014187949044, 51.91315310341971, 47.62390504564558, 47.53732354300362, 45.0758512360709, 43.9394142968314, 39.47899736676897, 37.26943894795009, 37.06841366631644, 37.22221204212734, 37.73411015101841, 37.14224522454398, 40.4499386378697, 40.20626531328474, 40.99206835883004, 36.60001475470406, 34.7965646471296, 35.608906337193076, 32.18447276524135, 32.012181758880615, 31.09623200552804, 31.72571795327323, 32.51288979394095, 32.833830560956685, 32.69960526057652, 31.902428013937815, 33.53244066238403, 32.89171947751726, 31.829801968165807, 30.64158010482788, 32.20076976503645, 30.866847651345388, 32.1048081942967, 34.01712267739432, 33.5828081539699, 32.28430795669556, 33.09013223648071, 34.260799476078574, 32.846615246364046, 32.750959396362305, 31.822746072496685, 31.77048519679478, 31.714222158704484, 33.132325172424316, 32.6448187146868, 32.054079396384104, 33.174952370779856, 35.88851921898978, 37.12494421005249, 41.64906569889614, 43.79907805579049, 43.061919348580496, 42.60837915965489, 47.38027341025216, 46.78984328678676, 45.670009068080354, 47.96757684435163, 44.42403377805437, 45.749062197549, 44.51817839486258, 39.543500968388145, 49.868096760341096, 46.27629498073033, 44.65415464128767, 44.886092458452495, 45.81506661006382, 46.375147002083914, 44.82419095720564, 43.35907990591866, 42.29439006532942, 39.8584315436227, 40.21788617542812, 42.456495012555806, 45.517037527901785, 45.421631813049316, 41.511036259787424, 34.83965737479073, 32.05973523003714, 33.14790998186384, 33.43239007677351, 33.4592205456325, 33.716001646859304, 33.3244115965707, 34.040770871298655, 34.046774114881245, 33.7378328868321, 33.46877431869507, 34.35244274139404, 33.38373531614031, 31.58704580579485, 35.19711439950125, 34.73044906343733, 34.84357615879604, 34.87678507396153, 35.03391858509609, 34.845757893153596, 36.332516057150706, 35.82737507138933, 36.59704787390572, 35.88978726523263, 34.93686614717756, 35.72669219970703, 35.68902254104614, 36.1273809160505, 35.62757962090628, 35.930423804691856, 37.67645399911063, 37.61488601139614, 37.327425139290945, 38.86845915658133, 41.034709453582764, 48.705722195761545, 51.995284284864155, 50.72159263065883, 52.350587368011475, 47.110273361206055, 47.101817403520855, 50.914106369018555, 54.14764513288225, 54.12776633671352, 57.96251882825579, 22.33864607129778, 0.235172800719738, 0.4432917045695441, 0.04133145431322711, 0.03367415948637894, 19.720689909798757, 57.05656058447701, 41.238423688071116, 38.80831902367728, 36.914823736463276, 28.345415864671978, 38.22806453704834, 49.53745630809239, 38.689397130693706, 6.7599679827690125, 0.02439289117631103, 0.023371351616723195, 0.04384313650163157, 0.02658972972338753, 0.030300680148814405, 0.06118910054543188, 0.01569350735683526, 0.03786243045968669, 0.08763310978455202, 0.056254641219441376, 0.04009762659136738, 0.05421733304059931, 0.019946688686364462, 0.011863307794556022, 0.024463029644851173, 0.0320940855225282, 0.021921508879001652, 0.07189571139003549, 0.07123710494488478, 0.052234830135213475, 0.013036049553193152, 0.10011691919394902, 0.10512362553605012, 10.037332074982778, 48.94231183188302, 51.641315255846294, 47.99268415996006, 29.68220063618251, 26.68395045825413, 39.06027807508196, 43.5208409173148, 35.718781675611226, 48.429520879473, 9.148353491510663, 0.20020953326353005, 0.11698842101863452, 2.8679024066243852, 5.6941308208874295, 6.157539188861847, 20.273538964135305, 47.09103032520839, 52.2071452822004, 47.4409624508449, 49.78543751580374, 47.06078134264265, 45.89689554486956, 40.96871893746512, 38.42643560682024, 39.06298439843314, 38.437379019601, 39.767038413456504, 40.62014865875244, 42.45017562593733, 42.73023666654314, 42.83930253982544, 39.33250502177647, 38.2752879687718, 37.47110346385411, 34.26728909356253, 33.335546084812705, 33.4844286101205, 31.70415074484689, 35.25629220690046, 34.053343636649, 34.96145929609026, 33.23903560638428, 35.15249306815011, 35.35340370450701, 33.394980975559776, 32.183239459991455, 34.356208665030344, 32.57220656531197, 34.12423610687256, 36.04351268495832, 34.64012942995344, 33.66248662131173, 34.23976033074515, 35.131294114249094, 35.516516140529085, 34.862221649714876, 32.44415126528059, 33.340170110974995, 32.6419734273638, 34.50916978291103, 33.70592328480312, 33.837813990456716, 33.910245486668174, 36.13792828151158, 40.17905964170183, 42.892946107046946, 46.250020367758616, 45.74100228718349, 45.57147666386196, 48.95702116830008, 48.42181185313633, 48.46145132609776, 48.95080600466047, 47.218998772757395, 47.73396103722708, 46.634960991995676, 41.44945090157645, 51.433171544756206, 48.52486753463745, 45.68908534731184, 46.027750968933105, 47.25283302579607, 46.7404693875994, 46.2507256099156, 46.64492470877511, 42.98555169786726, 42.06029135840279, 42.612141609191895, 43.62075253895351, 46.35871451241629, 47.72561625071934, 44.46260322843279, 36.95375449316842, 33.938038281032014, 35.40063755852835, 34.25691543306623, 34.27165951047625, 34.24424539293562, 35.457220213753835, 36.362320355006624, 34.73844991411482, 36.3314460345677, 35.34397152491978, 35.684523582458496, 35.92158569608416, 35.30462735039847, 37.106323037828716, 36.77022477558681, 35.88384655543736, 35.94296530314854, 36.73504952022007, 36.483017512730186, 36.87947130203247, 38.54737247739519, 38.714334215436665, 37.67149993351528, 37.051373209272114, 38.452828339168, 37.48665005820138, 37.364118576049805, 37.146890095302034, 37.29144736698696, 38.46830892562866, 39.340415545872276, 39.47800724846976, 40.72497960499355, 42.20715543201992, 49.905088969639365, 54.56515196391514, 52.06766366958618, 53.909349714006694, 47.360547474452424, 49.05963216509138, 54.03803730010986, 55.62159776687622, 56.45917878832136, 58.46043368748256, 24.035420485905238, 0.47484759986400604, 0.640674175960677, 0.033804092157099924, 0.07370833626815251, 22.679618494851248, 62.52741582053048, 48.9177360534668, 41.83100775309971, 37.750035422188894, 32.01066357748849, 45.02077633993966, 56.773206097739084, 45.91575295584542, 9.603913869176592, 0.0392986855336598, 0.029673011507838964, 0.03244817562933479, 0.06416615258370127, 0.07150938069181782, 0.03360483356352363, 0.01332346850540489, 0.06525564233639411, 0.07846868011568274, 0.02326136957188802, 0.05445364982421909, 0.20267868148429052, 0.16686002564217361, 0.12038375596914973, 0.14523060912532465, 0.10489030448453766, 0.13533132603125914, 0.09236149463270392, 0.11891987094921724, 0.17789763265422412, 0.11163535647626434, 0.2727911078504154, 0.164953722219382, 12.69429976599557, 58.406529562813894, 56.55872910363333, 55.14449623652867, 34.83823994227818, 56.60774517059326, 54.89489957264492, 53.920247963496614, 41.3048415184021, 54.934872559138704, 11.574283157076154, 0.3752743500683989, 0.380729038800512, 5.841452607086726, 6.531561587538038, 10.448375344276428, 24.790879011154175, 49.27891036442348, 54.46446214403425, 51.19106156485421, 51.49754313060215, 49.70178467886788, 47.49386256081717, 41.81880324227469, 39.98235961369106, 40.79998540878296, 41.44989211218697, 42.477211066654746, 41.23163877214704, 44.71797384534563, 43.766595227377756, 45.363979135240825, 38.750770568847656, 38.56183515276228, 39.853529589516775, 35.16604552950178, 35.04161718913487, 33.68321657180786, 35.24218736376081, 36.66740185873849, 36.55345835004534, 36.872314657483784, 34.69425589697701, 37.6114536012922, 37.64033031463623, 35.77751132420131, 34.00670732770647, 35.722502435956685, 33.375578130994526, 35.54614673342024, 39.23451805114746, 37.35711826596941, 35.54249198096139, 36.453279222760884, 36.455895219530376, 37.45359747750418, 36.2169953073774, 34.902302333286826, 35.20077610015869, 34.88962881905692, 37.57035500662667, 35.42822538103376, 34.27324022565569, 35.581697191510884, 38.81682014465332, 40.48012161254883, 46.22559397561209, 47.941225801195415, 47.16778360094343, 45.312468664986746, 52.38844462803432, 50.445842947278706, 50.92691537312099, 51.32901804787772, 48.08883680616106, 49.692623479025706, 48.8181266784668, 44.10303395135062, 52.730632986341206, 51.26932259968349, 46.852262428828645, 49.09027372087751, 49.25770793642317, 50.47983006068638, 48.02627175194876, 47.29571383340018, 44.46552494594029, 42.09263869694301, 41.873885086604524, 43.972303594861714, 48.44421284539359, 48.408460889543804, 45.868432249341694, 38.40834249768938, 35.539497307368684, 37.62410627092634, 36.68052700587681, 35.85803052357265, 35.70034115655081, 36.95279911586216, 38.59864323479788, 36.70214979989188, 38.084066595349995, 36.68233353751046, 38.69701930454799, 36.899888583592, 36.26009498323713, 39.04765667234148, 38.72046252659389, 37.760610580444336, 38.3889604977199, 37.568756920950754, 37.884392738342285, 39.669565609523225, 39.850246565682546, 40.72397211619786, 39.818826811654226, 38.38907514299665, 40.348043305533274, 39.24990831102644, 40.066460609436035, 38.790601117270334, 40.60144758224487, 42.136315073285786, 42.64117465700422, 40.23964098521641, 42.8816031728472, 45.361022676740376, 52.8076502936227, 56.353177070617676, 53.84192092078072, 56.749262605394634, 50.33713143212454, 51.342900548662456, 58.031066281454905, 58.56928416660854, 59.7109009878976, 60.48602812630789, 25.94344793047224, 1.204958228128297, 1.9698040953704288, 0.2512981854379177, 0.15359907650521823, 24.854517562048777, 67.8434339250837, 52.52099193845476, 51.65111916405814, 49.30846105303083, 39.753096852983745, 51.57317079816546, 64.20079217638288, 57.51280014855521, 14.561525651386805, 0.17666159969355377, 0.05340820038691163, 0.1892856758620058, 0.16132308489509992, 0.09197006135114602, 0.10812011760260377, 0.10913225436317069, 0.1726458394633872, 0.17541883566549846, 0.2089915405958891, 0.08580740275127546], [0.02488172476712082, 0.02296857662232859, 0.029743093997240067, 0.028381114759083306, 0.020454623037949204, 0.061371694318950176, 0.011534376918072147, 0.0039721982819693425, 0.029779538113091673, 0.025096396283645715, 0.002246766001917422, 0.12978593073785305, 7.422325423785618, 46.93849304744175, 47.19390535354614, 37.06934472492763, 19.7186210836683, 41.35403823852539, 72.82270758492606, 50.79266227994646, 33.38297101429531, 48.64401871817452, 10.155065826007299, 0.24888032089386666, 0.11220869142562151, 4.024701041834695, 4.774073813642774, 7.082669683865138, 32.156860624040874, 50.76771477290562, 47.332688672201975, 48.72437463487898, 45.93853609902518, 45.002783979688374, 41.815113748822895, 41.191884653908865, 39.94367551803589, 38.0176557132176, 35.33345890045166, 33.16880668912615, 32.4255370412554, 32.34139435631888, 32.96656894683838, 34.21614340373448, 32.516752992357524, 33.921522412981304, 33.49719245093209, 32.49368149893624, 31.716987541743688, 32.2081869670323, 32.930386202675955, 34.756695883614675, 34.927746636526926, 34.75381932939802, 34.49086127962385, 32.80942153930664, 33.76740789413452, 33.663143226078574, 32.06529726300921, 32.44433191844395, 31.1625143459865, 31.36682959965297, 33.07186542238508, 33.14290380477905, 32.13800321306501, 32.04858684539795, 34.69571501868111, 33.45674351283482, 31.88946614946638, 32.994056020464214, 32.04891341073172, 31.46164471762521, 31.896563734327042, 32.208503110068186, 30.42222547531128, 32.95784200940813, 37.25947870526995, 40.838638237544465, 42.150777748652864, 44.23685278211321, 44.006363664354595, 45.08417517798287, 43.49157510484968, 46.89936426707676, 45.3087409564427, 46.566941601889475, 44.455137389046804, 43.608252729688374, 41.98313161305019, 37.68937417439052, 42.277349608285085, 40.1871542930603, 43.48695455278669, 43.40200587681362, 44.481231348855154, 43.30467203685215, 43.29188387734549, 42.243338176182334, 41.999564102717805, 42.60771213259016, 43.450118677956716, 44.15372453417097, 41.80218662534441, 43.454207692827495, 42.514960629599436, 35.140966006687705, 33.34117065157209, 34.05250290461949, 34.49316460745675, 33.13408306666783, 34.167863845825195, 33.75079127720424, 33.060772623334614, 34.49242115020752, 32.45208263397217, 32.88014725276402, 33.344481468200684, 33.12958410808018, 33.50057622364589, 33.430791991097585, 34.07700572695051, 34.5435459954398, 35.36934287207467, 32.83003337042672, 35.39477327891758, 36.42322826385498, 37.216392925807405, 36.78353752408709, 37.10509320667812, 35.213025774274556, 35.308063234601704, 36.15966919490269, 36.02826486315046, 35.78701993397304, 36.21516098294939, 38.3452285357884, 38.13697712762015, 38.04272828783308, 37.10609027317592, 37.43907921654837, 39.49000678743635, 45.90914521898542, 44.67846638815743, 45.43481254577637, 43.89927107947213, 45.72151606423514, 49.890657561165945, 52.801112038748606, 53.09788697106497, 59.08615371159145, 27.114506006240845, 0.34032406977244783, 0.7201825210026332, 0.2340642644890717, 0.023093511882637228, 19.031689167022705, 59.1424480165754, 35.898885931287495, 46.7346259525844, 25.980073622294835, 17.161576305116924, 36.52044398444039, 49.14045013700213, 48.04505273274013, 10.016508323805672, 0.11195107882044145, 0.0435524928117437, 0.08515759690531663, 0.03464474954775401, 0.04615034216216632, 0.11522916970508439, 0.00423546859695177, 0.039737823219703775, 0.021767464466392994, 0.02350245476035135, 0.041021200961300304, 0.027417681545817425, 0.09141886021409716, 0.07919213415256568, 0.05485333748427885, 0.030946543706314902, 0.004147041913321508, 0.037214955381516895, 0.06354817681546722, 0.08440514228173665, 0.02921521750145725, 0.058043615759483407, 0.12086358879293714, 9.118615201541356, 54.711199624197825, 50.54416343144008, 42.32067162649972, 25.615223714283534, 53.99083123888288, 72.83339391435895, 57.052919728415354, 38.321364947727744, 51.81936979293823, 11.04047303540366, 0.22409601509571075, 0.167632469907403, 2.7326945875372206, 3.5637412624699727, 6.086707515375955, 31.51631314413888, 52.134432383946006, 48.23089272635323, 49.938026905059814, 47.91055645261492, 46.51387473515102, 42.62992899758475, 42.92231961659023, 42.29400791440691, 38.959609099796836, 36.84671401977539, 34.52744354520525, 34.58668041229248, 34.75619561331612, 34.267327308654785, 35.75486019679478, 35.16020209448678, 34.42920296532767, 34.00388983317784, 33.82085691179548, 33.227310521262034, 33.130271979740684, 33.37309414999825, 35.52106373650687, 37.460392815726145, 37.28967557634626, 35.31058890478951, 33.62484475544521, 35.24461228506905, 35.15566839490618, 34.64362089974539, 34.178213187626426, 33.99447849818638, 33.14203527995518, 35.701355593545095, 33.651737758091514, 33.19224991117205, 32.9567928314209, 36.255724566323416, 34.03234270640782, 34.105462074279785, 34.529163224356516, 33.68398434775216, 33.76291240964617, 32.83000905173165, 33.29709127971104, 31.543042864118302, 34.023782525743755, 39.91561869212559, 42.27013042994908, 41.92080627168928, 46.39404957635062, 45.96966750281197, 45.16461794716971, 45.001557622637065, 47.94629103796822, 47.32795000076294, 47.38532475062779, 46.75398015975952, 45.77230739593506, 44.54471703938076, 38.674885817936485, 44.07481036867414, 41.43344225202288, 42.88150937216622, 45.43596942084176, 47.37958206449236, 46.96196753638131, 47.40882355826241, 43.10355295453753, 44.49698986325945, 43.93799686431885, 45.07617085320609, 46.181830746786936, 44.134273052215576, 46.117268085479736, 43.9157452583313, 38.174775327954976, 35.16851561410086, 35.26683609826224, 34.76660401480538, 35.56020988736834, 35.475983824048726, 34.66114773069109, 35.18683106558663, 34.74103116989136, 33.92732763290405, 35.52900205339704, 35.467767579214915, 35.10106250217983, 35.50540597098214, 35.338489396231516, 34.97340324946812, 35.909673009599956, 37.6631030355181, 36.253966672079905, 37.487806933266775, 36.931725229535786, 38.55832978657314, 38.495459011622835, 39.01311717714582, 37.7398111479623, 37.499236719948904, 38.08510882513863, 39.70170102800642, 37.715350014822825, 39.176698616572786, 39.39922857284546, 39.7980169568743, 39.743768896375386, 39.2858304977417, 40.27171386991228, 42.26061487197876, 48.014411176954, 48.10921587262835, 47.07094308308193, 46.52175051825387, 47.322370597294395, 51.87203713825771, 56.18165731430054, 54.36149331501552, 61.85864475795201, 27.88993886538914, 0.8963485051478658, 0.7888675811035293, 0.04489227377676538, 0.06617643471275057, 21.298026527677262, 64.59877109527588, 42.01355777468, 45.7512925692967, 36.86823606491089, 22.39472324507577, 43.01044014522007, 54.586302280426025, 53.66421379361834, 13.538296580314636, 0.05872931610792875, 0.08013586779790265, 0.04394963596548353, 0.024537977230335985, 0.05047841849071639, 0.059261552191206386, 0.05366814036720565, 0.021705573591004525, 0.01241125535619046, 0.02499306557833084, 0.04362602565171463, 0.16846033691295556, 0.18710186518728733, 0.1751854196190834, 0.19125941209495068, 0.09825778752565384, 0.125640475324222, 0.08595802395471505, 0.10850190890154668, 0.14686657062598638, 0.17629779635795526, 0.1515417176165751, 0.17912232050938265, 11.410118068967547, 63.102594648088726, 58.64007936205183, 49.95833996364048, 29.887179442814418, 51.83195645468575, 73.5004209790911, 58.64190673828125, 43.691672801971436, 58.01805230549404, 12.338175926889692, 0.41397378061498913, 0.3026713744870254, 9.237132361957006, 10.380569611276899, 9.607486980301992, 34.444224970681326, 54.01273543494088, 50.24740239552089, 53.60164179120745, 50.32954052516392, 49.74309866768973, 46.938760553087505, 45.600061552865164, 42.86714397157942, 40.99144996915545, 39.27830212456839, 36.1197761126927, 37.010983330862864, 36.15816838400704, 35.13456324168614, 37.58384493419102, 36.23399060113089, 36.40335294178554, 37.27291999544416, 35.199886730739046, 35.23119183949062, 35.62020410810198, 36.1070122718811, 38.31900256020682, 39.23784276417324, 38.73994180134365, 37.80646174294608, 36.70838928222656, 36.60786621911185, 36.81915399006435, 35.929214818137034, 36.00303942816598, 34.85800061907087, 35.9180177961077, 36.33238751547677, 36.13843897410801, 35.09418725967407, 35.052727358681814, 37.70553568431309, 35.741015911102295, 34.46066788264683, 36.64924968991961, 35.581002371651785, 36.28460475376674, 33.67635522569929, 34.7087150982448, 32.949862003326416, 35.40419503620693, 41.86889975411551, 43.589301518031526, 45.0700877053397, 48.44997985022408, 47.60909496034895, 47.10098361968994, 46.14739547457014, 49.93084246771676, 48.32579469680786, 49.49232428414481, 46.620185647692, 46.012871401650564, 46.57757581983294, 40.255448137010845, 43.402516569410054, 42.38976451328823, 43.639276436397004, 45.400439807346885, 47.9939626285008, 48.4953932762146, 48.970823764801025, 45.38850280216762, 46.640686307634624, 46.06314161845616, 46.60190493719918, 48.24786022731236, 46.09509290967669, 48.37473085948399, 46.591482639312744, 39.27026653289795, 37.19610071182251, 38.146287713732036, 37.39044530051095, 36.822690623147146, 38.22710568564278, 35.73165668760027, 37.27285051345825, 36.896282468523296, 36.005200317927766, 35.86151157106672, 37.26303618294852, 37.78428309304373, 38.564173221588135, 37.14021635055542, 37.41143580845424, 37.456755433763774, 40.40006446838379, 36.35376017434256, 40.214467661721365, 39.807112148829866, 40.7309376852853, 40.536784172058105, 40.897291455950054, 39.81484201976231, 39.26001793997628, 40.703742436000276, 40.86753232138497, 38.646057741982595, 40.97697687149048, 41.869264534541536, 41.93341725213187, 43.16324840273176, 40.019320556095664, 42.14323895318167, 43.260641302381245, 49.655130999428884, 48.661694935389924, 49.26562193461827, 48.32731982639858, 50.66678524017334, 53.94749879837036, 59.48195784432547, 57.094845158713206, 64.84934398106166, 30.03213276181902, 2.73571531687464, 2.613323232957295, 0.47984454887253897, 0.14050363563001156, 23.58968833514622, 67.37893295288086, 48.49485131672451, 56.226358549935476, 35.58427149908883, 28.552710158484324, 50.81635216304234, 63.54957921164376, 62.43482412610735, 17.555579117366246, 0.3136421729411398, 0.17325605957635812, 0.13314661969031605, 0.09980642835476569, 0.11839412844606809, 0.2485344037413597, 0.19711436863456452, 0.16425757243164948, 0.10623102861323527, 0.1208944892776864, 0.14651257890675748], [0.03404830369566168, 0.04032278486660548, 0.061771025748125145, 0.02524459850974381, 0.05719541305942195, 0.06934952908860785, 0.04439786941345249, 0.007553389063104987, 0.007036902201694569, 0.05486151383125356, 0.051190632595015426, 0.07197755628398486, 6.604734369686671, 45.92543527058193, 46.34619038445609, 38.535977431706016, 17.3903683253697, 24.507323026657104, 36.695545537131174, 27.23181070600237, 32.91240079062325, 51.55726637159075, 11.121772170066833, 0.23300661838480405, 0.051416991877236536, 1.2543037916932787, 7.1413997667176385, 8.08383822441101, 40.31852388381958, 53.691832883017405, 50.46109076908657, 45.609591007232666, 46.24810266494751, 46.19937147412981, 46.7300192969186, 44.74991124016898, 45.00174522399902, 43.28940684454781, 42.054635524749756, 37.73019136701311, 35.40093633106777, 33.80753026689802, 33.210120677948, 32.59359312057495, 33.42158910206386, 33.08225992747715, 32.01946694510323, 30.897878306252615, 31.245180538722447, 31.83642360142299, 34.22254269463675, 37.843540804726736, 39.87281084060669, 39.69640302658081, 39.85347400392805, 38.87354523794991, 34.84485810143607, 33.64503622055054, 33.506989410945344, 34.86685609817505, 32.15509230749947, 32.89846270424979, 31.64955527441842, 32.72293036324637, 32.10878603799002, 31.515955311911448, 32.92122847693307, 33.35018941334316, 30.980502809797013, 33.45710481916155, 32.46654878343855, 32.628598145076204, 33.29630960736956, 31.050564970288956, 32.8421162877764, 33.741136755262104, 41.98018210274832, 43.38305466515677, 42.86156109401158, 44.152150767190115, 43.08618245806013, 43.043447562626426, 44.48384039742606, 47.11827768598284, 46.07508209773472, 46.36372068950108, 45.37171942847115, 45.043955530439106, 39.474609579358784, 35.94332660947527, 41.87204728807722, 42.29573106765747, 45.11532047816685, 46.3848432132176, 45.490422453199116, 45.4369386945452, 46.31526395252773, 45.713219915117534, 46.17674813951765, 45.731236594063894, 46.22900901521955, 45.183607373918804, 44.28875582558768, 43.997487340654644, 42.43000847952706, 34.916115352085654, 32.158938135419575, 31.88578360421317, 33.018711703164236, 32.19062886919294, 34.487133571079795, 33.47203649793352, 33.935898235866, 32.86610494341169, 33.74053226198469, 31.91515016555786, 32.67383786610195, 32.816088335854666, 33.745521068573, 32.92203794206892, 33.04205765042986, 34.68164144243513, 35.58051947184971, 36.33040380477905, 36.76071616581508, 35.47562599182129, 35.196294512067524, 34.13307768957955, 36.551207133701865, 37.53157711029053, 36.57501861027309, 35.47330181939261, 36.676184381757466, 38.44796807425362, 37.992909703935894, 37.238609790802, 36.82351745877947, 36.93879502160208, 37.25477824892317, 37.73562833241054, 38.29047325679234, 38.053143637520925, 39.56031213487898, 40.99914162499564, 42.25139808654785, 44.46479538508824, 47.31946972438267, 53.79929372242519, 54.000881808144705, 57.55884238651821, 34.31502321788243, 2.1448324748447964, 0.39951151236891747, 0.08143617159553937, 0.014629420258903077, 18.664714847292217, 55.215010029929026, 47.259902817862375, 45.18256514413016, 26.999469893319265, 25.474640812192643, 41.684056827000205, 49.32913194383894, 43.64617599759783, 9.061974355152675, 0.18472189003867762, 0.020955000205763748, 0.014678595388042075, 0.04484761938718813, 0.009173121702458178, 0.052511760632374456, 0.022630822246095965, 0.039847396447190216, 0.027940713301567093, 0.08407341329646961, 0.04318282354090895, 0.00929830377987985, 0.015817624982446432, 0.023487426906025836, 0.025348740064405968, 0.0836687350113477, 0.020779056075428213, 0.02744162026127534, 0.07544020190834999, 0.014152262559426683, 0.02969216655141541, 0.054927582786019356, 0.06583317063216652, 7.874273606709071, 52.05780764988491, 53.7384101322719, 42.90648119790213, 22.39203429222107, 32.02174595424107, 55.854761941092356, 41.56112929752895, 37.710976123809814, 55.47786038262503, 12.775394797325134, 0.1614448819309473, 0.05190266349485942, 2.721397033759526, 2.2084110975265503, 8.80810020651136, 41.762898036411826, 55.447805949619834, 51.26382657459804, 48.054623876299175, 47.53137935910906, 46.19022764478411, 47.219075202941895, 45.32714673451015, 47.182930673871724, 43.465543678828645, 43.03125, 37.69881330217634, 36.393861702510286, 36.15910291671753, 34.69768830708095, 34.513331753867014, 33.47144590105329, 35.03450223377773, 32.72438601085118, 32.04021079199654, 32.925883769989014, 32.81923934391567, 35.333375522068565, 37.99355936050415, 41.39816624777657, 41.6824483190264, 40.10433176585606, 39.34803771972656, 36.23288583755493, 34.28426354272025, 35.235541411808555, 35.299127851213726, 33.915744985852925, 34.57740109307425, 33.674027579171316, 34.367176396506174, 33.43476983479091, 32.07069253921509, 35.20164809908186, 34.845876012529644, 32.30896711349487, 34.62079954147339, 33.812164715358186, 34.384359291621614, 34.45023168836321, 34.078732354300364, 34.57096358707973, 34.78816427503313, 42.398241315569194, 45.30646889550345, 43.904669829777305, 45.35060732705252, 45.12338038853237, 45.6755815233503, 46.87017488479614, 48.29259967803955, 47.921246256147114, 48.96094690050398, 46.975950786045615, 45.8316832269941, 40.79255778448922, 38.1809036391122, 41.298536028180806, 43.97878973824637, 48.24769694464547, 46.81173358644758, 47.91076489857265, 46.81109435217721, 48.289181164332796, 46.25500570024763, 46.70550257819039, 47.99717617034912, 47.32381929670061, 46.57639810017177, 46.542174748011995, 45.877746309552876, 44.23307991027832, 36.63301869801113, 34.298146043504985, 34.21267972673689, 35.144825731004985, 34.31854248046875, 35.23737226213728, 35.40923595428467, 35.13873910903931, 34.089040006910054, 35.061405658721924, 34.36389684677124, 34.36376830509731, 35.47636250087193, 35.92372574125017, 35.473058632441926, 35.69829838616507, 36.15761947631836, 36.997562885284424, 37.09145041874477, 39.559905665261404, 38.15752989905221, 35.69622434888567, 35.293374742780415, 37.47632156099592, 39.37161990574428, 37.80339411326817, 36.98902007511684, 39.53955439158848, 39.61692605699812, 39.0837664604187, 38.714410645621165, 38.53723158155169, 38.10226740155901, 38.56174482618059, 39.842398575374055, 38.85643529891968, 40.07266535077776, 42.79079021726336, 43.89354228973389, 44.717761925288606, 46.063252789633616, 49.63145153863089, 56.11288057054792, 55.917615345546174, 59.03632123129708, 37.82771975653512, 2.499351062944957, 0.4448610746434757, 0.14789164704935892, 0.003591929445974529, 19.971545934677124, 61.268430028642925, 47.73847041811262, 50.03882442201887, 28.45343429701669, 27.12328679221017, 47.025918756212505, 56.27170944213867, 54.35494811194283, 11.625957778521947, 0.0892312361725739, 0.01774077982242618, 0.039260928452547104, 0.03311372688040137, 0.03451746316360576, 0.031007686496845314, 0.07016968793634858, 0.02592030743003956, 0.03090995709810938, 0.03687847325844424, 0.06092275519456182, 0.11501000289406095, 0.10328843936856304, 0.16341456052448067, 0.08818652294576168, 0.1467164379677602, 0.15795645197587355, 0.17954709700175694, 0.13811990139739855, 0.11548337606447083, 0.12995656872434275, 0.15344304059232983, 0.09690567079399313, 9.689322863306318, 61.61606924874442, 59.70516872406006, 50.45132507596697, 25.355110951832362, 33.36625712258475, 44.450815609523225, 36.63213627679007, 42.632447719573975, 61.13976328713553, 14.739686148507253, 0.2510058454104832, 0.21392565726169518, 5.402116707393101, 13.904433642114912, 10.384687287466866, 44.72978925704956, 56.02834531239101, 55.42580100468227, 49.20499195371355, 50.29596682957241, 49.425437450408936, 49.58435664858137, 46.944471972329275, 50.10887268611363, 45.322112764631, 46.22525698798043, 40.13203770773751, 39.06698308672224, 37.671468666621614, 37.875269753592356, 35.83394806725638, 34.92884792600359, 36.782429286411826, 35.04112734113421, 33.53816597802298, 34.47442878995623, 35.03738921029227, 38.49279090336391, 41.83016354697091, 43.94421202795846, 44.159321308135986, 44.17158487864903, 42.32356902531215, 39.54811109815325, 36.73301717213222, 36.04227590560913, 37.40420968191964, 35.239102363586426, 37.30321414130074, 35.13273933955601, 35.788975851876394, 36.79395982197353, 32.286545276641846, 36.24465261186872, 37.26893867765154, 34.23121057237898, 36.15459353583199, 35.425192492348806, 37.1129446710859, 36.45096894672939, 34.55308934620449, 36.09315756389073, 36.799938746861045, 45.28294229507446, 48.3170781816755, 46.27627413613455, 47.67034680502755, 47.541596685137065, 46.66039834703718, 48.117783001491, 50.69492891856602, 49.03439283370972, 49.84712709699358, 48.473162514822825, 46.37043612343924, 42.577008043016704, 40.974947997501914, 41.640425613948274, 44.490482875279014, 47.98713254928589, 48.3655766078404, 49.88621766226632, 48.08046770095825, 50.75094876970564, 48.17913906914847, 48.44341032845633, 49.35561500276838, 49.7347469329834, 48.74884271621704, 47.499980449676514, 47.60741349628994, 46.533729212624685, 38.94687305177961, 34.849589824676514, 35.714981010981965, 37.146890095302034, 36.37187760216849, 37.753422669001985, 36.95612382888794, 37.98140696116856, 36.11141742978777, 37.61417382104056, 35.82545042037964, 35.88786608832223, 37.18036304201399, 37.10025378635952, 36.326144559042795, 36.70206642150879, 38.510234355926514, 39.39625474384853, 41.095370701381135, 41.48592547007969, 40.71222966057913, 38.86754546846662, 38.002995014190674, 40.86096279961722, 42.046332427433555, 39.775768824986045, 37.90672077451433, 40.62477963311331, 42.68582378114973, 40.5236486026219, 41.05946935926165, 41.271250452314106, 40.169696944100515, 39.951853547777446, 41.8616076196943, 42.01519060134888, 41.80670295442854, 43.774481432778494, 45.49940994807652, 45.66449219839913, 49.38731615883963, 51.53035947254726, 59.484278542654856, 58.670158113752095, 62.523872239249094, 40.490314619881765, 3.547414515699659, 1.086739297424044, 0.3246786535850593, 0.07106392245207514, 24.03789578165327, 64.92591312953404, 57.627525329589844, 54.51511103766305, 37.579356397901265, 36.614682401929585, 54.98215505055019, 63.32652119227818, 62.902972902570454, 15.926089320863996, 0.25581950853977886, 0.13768211060336658, 0.13531550259462424, 0.1513026018760034, 0.1415691798818963, 0.1169952606516225, 0.24606450913207872, 0.14569906970219954, 0.18523338330643518, 0.165777965847935, 0.2092434535069125], [0.026069608882867863, 0.017473628711221472, 0.04534465307369828, 0.008614578816507543, 0.020117995029847537, 0.04762055791382279, 0.05228297219478658, 0.05863466725817748, 0.06126850949866431, 0.08853843156248331, 0.06861882151237556, 0.08649586473724671, 6.062595529215677, 45.8862578528268, 45.341692788260325, 39.68523032324654, 25.043437344687327, 27.647853204182216, 21.117519276482717, 32.890573024749756, 37.764074257441926, 51.80985076086861, 12.368467467171804, 0.18953676096030644, 0.1339996467743601, 1.411516772849219, 0.12573382817208767, 16.10748941557748, 49.43386908939907, 50.24380670275007, 51.07889679500035, 47.28703900745937, 47.99070392336164, 46.23315014157976, 47.23731075014387, 45.21936280386788, 46.477896962847026, 45.63105051858084, 43.60621690750122, 39.23522676740374, 36.951291356767925, 34.66735594613211, 33.08211401530674, 33.04973540987287, 33.89349685396467, 34.01661545889718, 33.883484499795095, 31.232986450195312, 31.565944126674108, 31.973813806261333, 34.361218316214426, 37.78872299194336, 41.38276209150042, 42.066117422921316, 41.174100739615305, 42.12273481913975, 42.138910225459504, 36.05177756718227, 32.279788153512136, 33.71372263772147, 32.98062515258789, 31.727211815970286, 34.216636725834434, 33.06230122702462, 33.36094175066267, 32.963084425245015, 33.87234306335449, 33.12756565638951, 32.05973523003714, 32.20443146569388, 31.83301203591483, 32.23211656297956, 33.87036977495466, 32.4952517918178, 31.822141579219274, 37.55960961750576, 44.019158772059846, 44.7254570552281, 46.37628650665283, 43.68712173189436, 43.09402002607073, 44.12381601333618, 47.03915160042899, 45.873730250767295, 45.604890550885884, 45.38140174320766, 45.18866218839373, 46.68102407455444, 46.84221533366612, 37.54649836676461, 45.220446722848074, 46.894976479666575, 45.65812417439052, 46.72868524278913, 44.44198792321341, 44.65163939339774, 44.04027087347848, 43.73605442047119, 45.214617184230256, 42.94891732079642, 44.09797913687569, 43.06665107182094, 42.834615979875835, 40.022735595703125, 40.935555185590474, 33.171905585697715, 32.55818510055542, 34.517646585192, 33.03454664775303, 33.22715766089303, 33.60967683792114, 34.05295106342861, 34.1275816644941, 34.045255933489116, 33.588189533778596, 32.903993470328196, 32.86184917177473, 32.90750231061663, 32.72121068409511, 34.50660242353167, 34.32591451917376, 34.79009240014212, 35.12146936144148, 40.70981168746948, 44.28195006506783, 45.978015763419016, 43.91675969532558, 35.38634163992745, 32.2867294039045, 34.838434491838726, 36.54041658129011, 37.21391241891043, 39.58416877474104, 39.84763056891305, 41.52221243722098, 38.80929871967861, 37.05340903145926, 37.28978674752371, 40.331937381199424, 44.93723120008196, 46.74695553098406, 45.83267681939261, 42.82414504459926, 41.03087404796055, 39.9976213318961, 42.75155373982021, 47.254285199301584, 53.32565586907523, 54.882761069706504, 56.41235835211617, 33.62114136559622, 1.2308910765818186, 0.3563370890915394, 0.08199770682092224, 0.03923303048525538, 16.15590967450823, 59.89340932028634, 43.85585526057652, 38.28171852656773, 27.47116051401411, 27.492045061928884, 36.7574713570731, 48.95337683813912, 38.34531191417149, 8.952784282820565, 0.10306959146899836, 0.05276562772425158, 0.015381160724375929, 0.009283979905636182, 0.026991134077044468, 0.0009549414535285905, 0.009248018397816589, 0.04325405275449157, 0.04230543026434524, 0.04994473712784903, 0.03188702038356236, 0.039026284257748296, 0.008110344177111983, 0.0647938789001533, 0.04941240604966879, 0.025027552120653645, 0.00910570755201791, 0.06074674999607461, 0.015810264573831643, 0.0621246781998447, 0.011588417143294854, 0.02348588154252086, 0.09903609433344432, 7.302041683878217, 52.2413512638637, 51.90306779316494, 45.707466806684224, 27.000034434454783, 27.40534543991089, 26.025704179491314, 36.122791630881174, 41.949314730507986, 55.814799376896445, 13.937227402414594, 0.057277400445725234, 0.024915188417903016, 1.381324244397027, 1.0907228950943266, 16.512515544891357, 50.46373455865042, 49.66146428244454, 52.286684785570415, 49.69265127182007, 50.36434057780674, 47.51754896981375, 48.13339212962559, 48.379743984767366, 47.111815861293245, 45.304783957345144, 44.851990699768066, 41.95805556433541, 38.93054478509085, 36.22327995300293, 34.32829775129046, 33.738958495003835, 35.50848749705723, 34.6692076410566, 35.342105933598106, 33.55325746536255, 33.438629559108186, 33.16514151436942, 35.26549857003348, 38.784504073006765, 41.62460456575666, 43.92113011223929, 43.57647514343262, 45.234999724796836, 43.3921776499067, 37.36916644232613, 34.213523932865684, 35.56787722451346, 35.13020324707031, 33.37784324373518, 35.14398847307478, 34.66459403719221, 34.30064739499773, 33.91781554903303, 34.48111990519932, 35.41960614068167, 34.674519538879395, 33.918934209006174, 33.67347519738333, 33.23041636603219, 34.6673698425293, 33.97445726394653, 33.40118224280221, 40.066530091421946, 46.460884298597065, 46.19523729596819, 49.46090453011649, 46.114231722695486, 45.46941804885864, 44.63562726974487, 47.311430658612935, 47.56789561680385, 48.284876755305696, 46.776304721832275, 47.474709851401194, 47.76693023954119, 46.62484788894653, 39.40887614658901, 46.61314712251936, 47.672111647469656, 47.03334290640694, 47.66414553778512, 47.65684298106602, 45.07645572934832, 46.209929261888774, 45.46689237867083, 46.48642240251814, 45.70401355198452, 46.66862154006958, 44.60082721710205, 46.29447146824428, 41.581334659031455, 41.789599963596885, 35.55859095709664, 35.18382249559675, 36.50097165788923, 34.4855181149074, 35.35119765145438, 34.17430830001831, 34.11955302102225, 36.205096517290386, 36.39282294682094, 34.71078566142491, 35.91684702464512, 35.32619455882481, 35.02365609577724, 36.12490388325283, 35.66640615463257, 35.779408182416645, 35.930732999529155, 36.80400691713606, 42.183521134512766, 45.776771613529746, 47.0675801549639, 45.199900899614605, 36.1319910458156, 34.43898950304304, 37.161210332598, 37.75917230333601, 37.19384602137974, 41.67712252480643, 41.72814662115914, 43.221800872257774, 40.251796858651296, 39.538772719247, 38.56353398731777, 42.1311490876334, 47.44974497386387, 48.137863295418875, 45.562013217381065, 43.90486090523856, 42.878556387765066, 41.22554520198277, 44.40888670512608, 48.52904340199062, 56.4155649457659, 55.40893077850342, 58.65905489240374, 34.78413084575108, 2.107387329850878, 0.6918811510716165, 0.12366432350661073, 0.03596521262079477, 18.26489118167332, 63.126552036830354, 47.729726110185894, 41.77920893260411, 31.434751714978898, 32.29577248437064, 41.85768188749041, 55.651151929582866, 45.491381304604666, 12.194788558142525, 0.0850076067394444, 0.10163118543901614, 0.055239345878362656, 0.02220995581176664, 0.011309384035744836, 0.009284420105229532, 0.026368939517331973, 0.019649632840550373, 0.04840666108897754, 0.06909583841583558, 0.03716548339330724, 0.09632414592696087, 0.16840673264648232, 0.11518726338233266, 0.16526465410632746, 0.11168904895228998, 0.09297082586480038, 0.2014102145497288, 0.10697703715413809, 0.1665971747466496, 0.19704016404492514, 0.23973936853664263, 0.24587381365043776, 8.870103325162615, 59.10617841993059, 57.28187676838466, 51.814766611371724, 34.84932926722935, 38.423034463609966, 27.961847509656632, 44.487293652125764, 48.837348869868684, 62.101887294224326, 15.624257837023054, 0.28505367413163185, 0.1178584521902459, 3.5737940030438557, 3.546293033020837, 18.221855776650564, 51.905819279806956, 53.263955865587505, 54.66483776909964, 51.57261494227818, 53.171600409916465, 49.52582154955183, 51.01650891985212, 49.212676661355154, 49.64490325110299, 47.814862387520925, 47.478628635406494, 44.29621124267578, 41.07497773851667, 38.736895016261506, 35.97955451692854, 36.31475298745291, 38.43127850123814, 36.83987699236189, 36.63522822516305, 35.4075162751334, 35.117342131478445, 35.44612741470337, 36.88812875747681, 40.88350970404488, 43.82125670569283, 45.872882570539204, 45.77438490731375, 46.7217161996024, 45.86751161302839, 39.86201681409563, 36.01235696247646, 36.2910908971514, 37.03650753838675, 34.76742042813982, 37.76431049619402, 35.602517468588694, 35.63384689603533, 35.79652854374477, 35.43354075295584, 37.70792933872768, 37.03495461600167, 35.19438028335571, 35.66419315338135, 36.09926503045218, 37.7660927091326, 36.434807436806814, 35.80699947902134, 41.79460961478097, 48.23891789572579, 48.379702295575825, 50.79138381140572, 47.712525844573975, 46.60265186854771, 45.47356612341744, 49.486946378435405, 49.23901380811419, 49.0417023386274, 48.05828210285732, 48.72426346370152, 50.89456456048148, 50.10546459470476, 41.508045060294016, 49.03349651609148, 49.477830341884065, 48.36369712012154, 48.55233028956822, 49.17740413120815, 46.48813165937151, 48.496564047677175, 47.97690827505929, 49.95830174854824, 48.953210081372944, 48.632498604910715, 48.12732982635498, 47.85247993469238, 43.958549635750906, 45.13343095779419, 36.07708638054984, 37.03292921611241, 38.74298858642578, 37.67773594175066, 37.41056728363037, 36.13227244785854, 36.85067449297224, 38.95327581678118, 36.86696107046944, 36.253459453582764, 38.29877635410854, 37.7496463230678, 37.13852446419852, 37.0802811895098, 37.427600792476106, 37.99032844815935, 37.8667026247297, 39.76178557532174, 44.161763599940706, 48.84038175855364, 49.94608334132603, 48.594860213143484, 39.28391626902989, 36.56972060884748, 38.31765113558088, 40.14577429635184, 39.740124566214426, 45.09134224482945, 44.50868715558733, 45.939915316445486, 42.29253142220633, 40.78790249143328, 40.1602543422154, 44.31424181801932, 48.687045437949045, 51.36112567356655, 49.626216070992605, 47.115178789411274, 45.965845993586946, 44.033857686179026, 46.75347294126238, 51.63465888159615, 59.82697064535958, 58.03600297655378, 60.773864201136995, 39.373482022966655, 2.4700561548982347, 1.5914883613586426, 0.6946726441383362, 0.2572523573679583, 20.105052096503123, 71.19882324763707, 53.1028653553554, 51.303504262651714, 38.75920568193708, 38.36393656049456, 49.10538605281285, 63.89685712541853, 54.11716685976301, 16.17643117904663, 0.17660612267042908, 0.210506817858134, 0.1900821402668953, 0.23340293711849622, 0.10851770519678082, 0.13227666994290693, 0.09564654728663818, 0.12364351962293897, 0.13552118012947695, 0.11442848481237888, 0.14337020181119442], [0.03198452586574214, 0.046494970098137856, 0.014079360757023096, 0.026582337084359357, 0.06613256063844476, 0.04409133782610297, 0.0811865453475288, 0.06773901265114546, 0.017469199573887245, 0.01355807198810258, 0.032188917576734505, 0.04547543391319258, 2.9344568124839236, 37.35200786590576, 44.526655197143555, 43.642733165196006, 33.046751158578054, 21.53431565420968, 30.220244816371373, 38.47403424126761, 36.05970893587385, 53.297185625348774, 15.581333603177752, 0.08360735473356076, 0.01723453332670033, 0.823774299451283, 0.6581761453832898, 17.911191395350865, 45.015398434230256, 50.9810140473502, 50.78088508333479, 46.92827572141375, 44.86216981070382, 43.88589232308524, 45.43643842424665, 42.87675333023071, 42.84771680831909, 41.53170715059553, 40.90066480636597, 40.90352399008614, 38.180417265210835, 35.09303733280727, 34.002225739615305, 33.92195667539324, 35.512958662850515, 32.254455021449495, 31.983874797821045, 30.92888116836548, 29.642231123788015, 32.23509039197649, 34.05416004998343, 37.958043643406455, 41.40922777993338, 43.45470448902675, 41.44078997203282, 42.96463067190987, 43.39715256009783, 42.5007689339774, 35.056955337524414, 32.84459679467337, 31.956255708421978, 31.586747033255442, 32.268761362348286, 32.57652834483555, 31.849097115652903, 32.895005975450786, 33.66934796742031, 33.73811428887503, 32.57053204945156, 34.71804652895246, 32.06535632269723, 31.520610604967388, 31.226396083831787, 32.17960902622768, 32.32979781287057, 43.458890778677805, 43.732437883104595, 47.989717279161724, 39.1352595601763, 37.17540897641863, 43.50929648535592, 45.69851057870047, 47.78442580359322, 45.261851038251606, 45.199025426592144, 46.521493434906006, 47.21256126676287, 45.61115435191563, 45.9287565095084, 43.11618825367519, 46.51767887387957, 46.09516586576189, 42.975945813315256, 43.59589883259365, 45.432915687561035, 45.47327082497733, 43.43972417286464, 43.43700395311628, 45.81071703774588, 43.29574012756348, 42.70194707598005, 38.51044280188424, 39.19771344321114, 37.72094331468855, 35.01669747488839, 33.12170832497733, 33.41721173695156, 32.09766544614519, 33.96395853587559, 32.277978147779194, 33.2963547706604, 32.29871504647391, 33.00581932067871, 32.94913591657366, 31.52778114591326, 32.616483960832866, 32.12859535217285, 32.21128933770316, 31.95577280861991, 32.537677492414204, 34.03731066840035, 34.43651247024536, 36.604895864214214, 44.96322093691145, 45.00705712182181, 48.29806443623134, 45.4107266153608, 40.37182698931013, 35.264233997889924, 35.36470147541591, 34.95488282612392, 33.64778075899397, 38.50076396124703, 41.97382797513689, 42.91451678957258, 40.66363743373326, 38.56500005722046, 35.83064419882638, 45.16000781740461, 51.74099063873291, 50.41250549043928, 52.785999706813264, 50.97247123718262, 50.935124669756206, 46.585833753858296, 47.23280831745693, 46.676292351314, 51.79840360369001, 53.43864400046212, 58.11248179844448, 30.18713665008545, 0.9907840234892709, 0.43684244634849684, 0.08812398237309285, 0.013764433995155352, 11.174591507230486, 58.16070229666573, 43.03934465135847, 45.25003910064697, 27.9034617968968, 27.88779534612383, 42.98843172618321, 43.83736610412598, 40.83377797263009, 6.084321243422372, 0.0669241463765502, 0.03785874601453543, 0.05975201765873602, 0.017102929763495922, 0.015184772333928516, 0.023051512261320437, 0.05474433083353298, 0.023103698389604688, 0.054345403132694106, 0.08818764252854244, 0.03651629162154027, 0.03784745858450021, 0.04759219175736819, 0.044921247222061665, 0.024789932549798062, 0.07554062509110995, 0.03549978170277817, 0.04489141882264188, 0.0416291140552078, 0.07606255422745432, 0.020546886837109923, 0.058130135759711266, 0.06374516910208122, 3.5425596790654317, 43.139353547777446, 51.05761793681553, 49.078889097486226, 37.38626248495919, 26.572188683918544, 30.569145134517125, 40.13741908754621, 39.50136709213257, 57.788619313921245, 16.208283458437236, 0.08464662610952343, 0.0524061602274222, 0.9105258158275059, 1.2970766850880213, 19.931192534310476, 46.96203007016863, 52.03489943913051, 53.684561593191965, 48.63936342511858, 46.51819998877389, 44.59072801045009, 48.02549702780587, 44.665810244424, 45.99927030290876, 44.288985116141184, 43.78558118002755, 43.17075245720999, 39.92246266773769, 36.70898682730538, 35.83686978476388, 35.18321105412075, 36.767261368887766, 33.99685825620379, 33.12030478886196, 31.362751007080078, 31.689125265393937, 35.08882672446114, 34.376198632376536, 38.675549370901926, 42.552776200430735, 45.069094112941194, 43.570291246686665, 45.22664104189192, 45.657422406332834, 44.883931568690706, 36.95940685272217, 34.01105342592512, 34.297930649348665, 32.993250029427664, 34.10269669124058, 34.55428096226284, 33.69952746800014, 34.958068575177876, 34.54274000440325, 34.65834413255964, 33.769280433654785, 34.81969520023891, 34.198390756334575, 32.03135878699166, 33.52344274520874, 33.96916968481881, 33.06146049499512, 46.04471846989223, 45.57692057745797, 49.827585288456504, 41.889098167419434, 37.776473317827495, 44.76893193381173, 46.22492694854736, 49.2883494922093, 47.58807665961129, 46.05763864517212, 47.881568568093435, 47.44784116744995, 47.649026257651194, 48.50366163253784, 43.7955379486084, 47.16109595979963, 46.869087491716655, 47.87822995867048, 47.47613423211234, 47.96804584775652, 46.56151505878994, 47.34329162325178, 44.99087129320417, 46.88936928340367, 45.84225838524954, 44.812278270721436, 40.561109815325054, 40.54003592899868, 40.40785687310355, 37.011094502040315, 34.94034719467163, 34.95224945885794, 35.05690322603498, 34.1185177394322, 33.46286140169416, 35.116167885916575, 34.31117391586304, 35.585219928196494, 35.47294051306588, 33.335323742457796, 34.13744463239397, 33.97982474735805, 34.29878180367606, 35.55257034301758, 34.9762659072876, 36.57988929748535, 36.84224285398211, 38.9835421698434, 45.22203091212681, 48.032459122794016, 50.95089013235909, 47.60946668897356, 42.275206089019775, 36.77126700537545, 37.25789451599121, 36.64554630007063, 36.08578552518572, 39.745551109313965, 41.98956217084612, 45.13888529368809, 43.181490898132324, 41.04095935821533, 37.381662777491975, 46.831949370247976, 54.75377123696463, 51.464031968797954, 53.601766858782085, 52.15494694028582, 51.5567695753915, 47.9529960496085, 48.46699251447405, 48.31998600278582, 54.20675345829555, 56.88980729239327, 59.54867444719587, 32.749639238630024, 1.2689726331404276, 0.7707734405994415, 0.06806650079254593, 0.07493122600551162, 13.12483707496098, 62.538671902247835, 46.30462278638567, 48.067238330841064, 31.865783214569092, 36.940650190625874, 48.12263284410749, 51.93135390962873, 46.84578323364258, 9.496380942208425, 0.056398107271109305, 0.030645898410252163, 0.036664897575974464, 0.02343325436647449, 0.05006788105570844, 0.017814146421317543, 0.02932106557169131, 0.0762309462630323, 0.03797943703830242, 0.04671291554612773, 0.04966870568958776, 0.1649767245565142, 0.13598642445036344, 0.10254592528300625, 0.1351065273795809, 0.2771299050322601, 0.15508846087115152, 0.12725836065198692, 0.14556704035827092, 0.15619124312485966, 0.08042683039924928, 0.12551555702728884, 0.14916681790990488, 4.1769013319696695, 48.82002701078142, 59.07879556928362, 55.9895396232605, 43.253394331250874, 32.002357006073, 40.2029892376491, 49.0058148929051, 44.82416663851057, 62.98813697269985, 19.06138924189976, 0.17133675542260918, 0.09885643861655678, 4.1370052099227905, 2.8974192227636064, 21.423429352896555, 47.535353728703086, 53.30826800210135, 55.230066776275635, 51.73212473733084, 47.47917406899588, 47.25647735595703, 50.82734073911394, 46.61673934119088, 48.1723506791251, 46.061606066567556, 46.65291166305542, 45.585244519369944, 40.77845294134957, 38.88575669697353, 36.39860037394932, 37.4495119367327, 39.347061497824534, 35.09734869003296, 34.89039659500122, 34.114234175000874, 32.78566217422485, 37.11105128696987, 36.58958898271833, 40.37207017626081, 45.26398760931832, 47.67672177723476, 44.73853703907558, 47.30449983051845, 48.09644160951887, 47.02299703870501, 38.56391961233956, 36.939038208552766, 35.893858909606934, 33.912100655691965, 35.81878709793091, 37.25084209442139, 34.3318760735648, 36.12649849482945, 36.10903419767107, 37.52185310636248, 35.13433395113264, 37.09562628609793, 34.44533320835659, 33.99427005222866, 34.81341402871268, 35.946091992514475, 34.87689624513899, 48.56042841502598, 47.40986578805106, 52.14288486753191, 42.15516901016235, 38.9191358430045, 45.72279453277588, 47.71996736526489, 52.31998055321829, 50.503526891980854, 48.36122008732387, 49.62234245027815, 50.74720369066511, 49.30654682431902, 51.30640166146414, 46.76978383745466, 47.92736414500645, 49.60547569819859, 47.71451302937099, 48.155476978846956, 50.12258495603289, 48.229371070861816, 48.38649068559919, 48.83348914555141, 49.30930873325893, 48.12543296813965, 46.670084135872976, 42.29848255429949, 43.51272542136056, 43.5153865814209, 41.098354952675955, 36.408782958984375, 36.31162977218628, 36.27584654944283, 35.82806641714913, 34.68799557004656, 36.09170191628592, 35.96438659940447, 37.74620001656668, 36.87604584012713, 34.349295207432334, 35.64274059023176, 36.151525906154085, 36.45606892449515, 36.53408677237374, 37.559897967747276, 39.38092006955828, 39.35818208966936, 40.97115775517055, 49.17460400717599, 50.57148722239903, 51.052663871220176, 48.45044885362898, 45.39164686203003, 38.08038405009678, 40.343652044023784, 39.272267614092144, 36.87643493924822, 41.833550793784006, 45.93588188716343, 47.879108905792236, 45.75238691057478, 42.134143761226106, 38.36661161695208, 48.59002079282488, 56.91540445600237, 55.008759702954976, 57.089880670819966, 55.588750158037456, 55.16911717823574, 49.69429104668753, 52.16623428889683, 51.315639291490825, 56.40041439873831, 59.86736052376883, 62.20328235626221, 33.9265251159668, 2.3694542731557573, 1.610495918563434, 0.41354494648320334, 0.12502861315650599, 13.926722594669886, 70.43687684195382, 52.94931364059448, 56.55957678386143, 39.83868823732649, 39.26989827837263, 55.75047990253994, 58.038612025124685, 58.35369546072823, 14.035513145583016, 0.23096946626901627, 0.13231647280710085, 0.17009138582008226, 0.11326303306434836, 0.09679490673754897, 0.11564999712365014, 0.10095517457063709, 0.12657196819782257, 0.18866400207792008, 0.1355661941426141, 0.1231959443539381], [0.03283535449632576, 0.057723523649786196, 0.07052217330783606, 0.01762026352142649, 0.03411361947655678, 0.03386583545112184, 0.025389801611059477, 0.08563291747123003, 0.03092969228912677, 0.034146477534834824, 0.025122021158624972, 0.12776118224220617, 0.8069630786776543, 27.150169372558594, 42.613232476370676, 46.610218456813264, 33.601189613342285, 19.18446442059108, 22.81808740752084, 33.45249121529715, 37.49628373554775, 51.752177238464355, 18.75308551107134, 0.02003962593153119, 0.052611359395086765, 0.09636400985930647, 0.25205437200410025, 11.933419908796038, 46.101572104862754, 52.364428179604666, 50.94482782908848, 48.117557185036794, 40.909409114292686, 37.29843725476946, 36.64858266285488, 34.925154958452495, 33.80921867915562, 34.92139250891549, 36.892492226191926, 34.42765351704189, 34.22122253690447, 32.529728753226145, 32.1783618245806, 32.06659310204642, 34.46131753921509, 36.60779673712594, 39.672890322549, 37.465729032244, 36.05489730834961, 34.04464796611241, 35.226640769413535, 34.50198881966727, 36.64862782614571, 40.34034470149449, 42.72084270204817, 42.70708874293736, 44.12700176239014, 41.88417189461844, 38.49234969275338, 31.517046179090226, 32.90851674761091, 32.81561933244978, 32.48459325517927, 32.212661606924875, 31.683827263968332, 32.84001445770264, 32.79486158915928, 32.50349235534668, 32.77713673455374, 35.08375106539045, 32.325097356523784, 32.905400480542866, 32.95078958783831, 30.53735712596348, 35.73019061769758, 44.746857506888254, 46.85097701208932, 43.09332868031093, 43.088888781411306, 41.71925640106201, 42.06225422450474, 45.65030745097569, 47.172383308410645, 44.01609809058053, 44.868093150002615, 42.651843615940635, 43.44317742756435, 45.09378106253487, 46.678831917899, 42.61500079291207, 47.66558728899275, 44.3001890863691, 46.53885350908552, 46.30961159297398, 44.53948504584176, 42.554113728659495, 43.429211548396516, 42.608420848846436, 45.13847534997122, 43.32902547291347, 41.89872489656721, 39.39304467609951, 37.03204679489136, 35.179514612470356, 33.82417120252337, 32.29816961288452, 33.987106459481375, 33.16084752764021, 33.718419619968955, 31.866550990513392, 34.45378221784319, 31.72713885988508, 31.989940575190953, 32.72446938923427, 32.46533979688372, 33.153812476566856, 33.01630762645176, 32.8494223185948, 32.59646620069231, 33.76791858673096, 33.695695536477224, 33.458275590624126, 37.46305397578648, 43.13872820990426, 45.055906432015554, 42.52976376669747, 45.285422801971436, 44.833320890154155, 38.42140163694109, 34.727454389844624, 33.44860717228481, 33.95808730806623, 35.864190101623535, 39.870920930589946, 43.759407315935405, 42.96495028904506, 39.619545527866904, 38.34519726889474, 43.26635272162301, 52.27756527491978, 50.037198543548584, 52.306243964603965, 50.38714803968157, 54.57107182911464, 51.15804719924927, 51.29879338400704, 50.53390441622053, 52.04063170296805, 52.86289542061942, 53.639936787741526, 23.978356667927333, 0.6665532301579202, 0.4877485047493662, 0.05178617599553295, 0.03610272792034915, 14.34614278588976, 56.971010889325825, 44.08925914764404, 36.42183862413679, 29.032919270651682, 20.522008282797678, 39.7698906489781, 43.441089493887766, 40.024639402117046, 8.218407460621425, 0.10513639556510107, 0.011006798129528761, 0.023413793982139657, 0.041094143475805006, 0.056569396651216915, 0.024173096720395342, 0.004070773304972265, 0.03171203638027821, 0.003385509763445173, 0.022867155993091207, 0.048505228478461504, 0.014752067159861326, 0.002414945783259879, 0.006132613917413566, 0.06260601058602333, 0.04144370436136212, 0.07287584843912295, 0.0088383562729827, 0.05639265524223447, 0.0394350880357836, 0.02966222958639264, 0.006021736206353775, 0.07400332258215972, 1.0175952762365341, 33.29126174109322, 49.82772772652762, 54.22511059897286, 38.30750329153878, 21.800568887165614, 23.235038382666453, 36.81103154591152, 41.475739410945344, 55.46225472858974, 20.374317373548234, 0.05673186507608209, 0.03246879630855151, 1.0374903572457177, 0.9816773235797882, 13.687993781907217, 46.97294569015503, 53.575638157980784, 50.75011151177542, 49.75658164705549, 44.16470268794468, 39.593076365334646, 38.29837335859026, 37.46635784421648, 36.3793295451573, 36.142163208552766, 38.21796185629708, 37.440816266196116, 36.34472056797573, 33.89250326156616, 34.078235558101106, 34.75781454358782, 36.14909403664725, 36.40068135942732, 40.97377722603934, 38.87636968067714, 36.612907137189595, 34.53179659162249, 37.50322151184082, 35.83772093909127, 38.45649003982544, 40.662709849221365, 44.443117005484446, 44.442095620291575, 45.143418993268696, 44.463214669908794, 41.547472613198416, 33.239744322640554, 34.93384715488979, 34.03502818516323, 33.302635942186626, 33.558270590645925, 33.097584179469514, 35.14011137826102, 34.36624533789498, 34.03915541512625, 34.185974325452534, 36.24759864807129, 34.01454489571707, 34.92032943453108, 33.93739557266235, 32.116171973092214, 37.110481534685405, 46.51414224079677, 48.48843812942505, 47.281108719961985, 43.88397462027413, 41.25932386943272, 42.189374991825645, 46.8721273286002, 49.34616545268467, 44.61758279800415, 45.85603666305542, 45.30176496505737, 46.17098808288574, 47.7095103263855, 47.942358357565745, 44.52786765779768, 48.26682880946568, 46.36325168609619, 47.99517856325422, 48.284362588609966, 46.10173191343035, 45.16288784572056, 44.913225173950195, 45.03102840696062, 47.41658122198922, 43.7377393586295, 42.865761280059814, 40.54800203868321, 39.59696388244629, 36.46763072695051, 35.42165238516671, 33.29010139192854, 34.737633500780376, 33.725082942417686, 35.81249550410679, 34.295418875558035, 34.66625813075474, 34.06929670061384, 33.76756770270211, 34.057707105364116, 34.78692749568394, 33.98136724744524, 33.864199774605886, 34.486782687050955, 35.10890701838902, 35.04398305075509, 34.88295160021101, 34.75182867050171, 39.40333495821272, 45.85457059315273, 48.09845658711025, 46.85267584664481, 47.46131719861712, 47.75762660162789, 39.587827001299175, 35.506225858415874, 35.75889362607683, 35.21723290852138, 37.94705159323556, 42.722538062504356, 45.56262813295637, 44.56829922539847, 42.05295753479004, 39.08551393236433, 46.638167585645405, 54.24960994720459, 51.28685637882778, 54.92628805977957, 52.230362687792095, 56.16793114798409, 52.81066581181118, 54.87730325971331, 55.21993282863072, 54.47159794398716, 55.422090666634695, 55.97945778710501, 25.927835328238352, 0.8263818281037467, 0.43663709451045307, 0.1226340223635946, 0.08662301541439124, 14.499705791473389, 61.705645424979075, 49.16234738486153, 43.44966009684971, 29.448584829057964, 27.322769573756627, 48.57874386651175, 49.60741771970476, 47.82950919015067, 10.10503011090415, 0.06692172400653362, 0.02429378604782479, 0.03625953057780862, 0.04986857835735593, 0.0131876758366291, 0.00840620495312448, 0.053171238995024135, 0.026280867368248955, 0.010086009145847388, 0.009831193801281708, 0.03061949661267655, 0.062196060083806515, 0.1035576481372118, 0.12553120404481888, 0.17037499988717691, 0.13033360349280493, 0.28375240681426867, 0.0872009711872254, 0.17579311558178493, 0.14446003761674675, 0.11250525194087199, 0.08310878077255827, 0.2814711720815727, 1.575292436139924, 37.227027143750874, 57.64860269001552, 60.42312608446394, 45.94112777709961, 28.028593642371042, 31.17784207207816, 43.40045642852783, 46.853155272347585, 60.00267669132778, 23.453767674309866, 0.23928374584232057, 0.2181091242070709, 2.3430139890738895, 1.6786179031644548, 14.405420473643712, 49.05691889354161, 55.39164366040911, 54.93290621893746, 51.79646853038243, 43.880229541233604, 41.0382912499564, 40.23563882282802, 39.52153076444353, 37.49367816107613, 37.84465251650129, 40.668515069144114, 38.99617746898106, 38.08210372924805, 35.89362267085484, 35.67812776565552, 36.20994635990688, 37.90397276197161, 39.96001420702253, 44.78662552152361, 41.546590191977366, 39.00510243007115, 36.218739305223735, 39.071996212005615, 37.85514777047293, 39.47175734383719, 43.81361368724278, 47.15134416307722, 46.71327761241368, 46.73274646486555, 46.00768804550171, 43.400185448782786, 35.834097453526084, 37.41150181634085, 36.77025604248047, 35.60162462506975, 35.14588533129011, 35.583739961896626, 35.89038828441075, 35.12108373641968, 34.53037221091134, 36.107578550066265, 36.74898065839495, 34.66519158227103, 36.85894284929548, 36.16735390254429, 33.282652923039024, 39.43714141845703, 48.09343303952898, 50.8143093926566, 48.76041841506958, 45.95787293570382, 43.18484340395246, 42.60782330376761, 47.70004687990461, 50.45277724947248, 46.913858209337505, 48.97617735181536, 47.27576902934483, 47.41524369376046, 49.20326880046299, 49.0378669330052, 47.53898068836757, 49.48001207624163, 47.30840819222586, 51.00270632335118, 50.24835777282715, 48.003637995038716, 44.843423570905415, 46.49042109080723, 47.293858664376394, 49.68631451470511, 46.143567017146516, 44.51245655332293, 43.419511863163535, 40.88878338677542, 37.9582451411656, 37.412457193647114, 35.07444395337786, 37.08520746231079, 35.87360838481358, 38.41503013883318, 35.73294905253819, 37.863502979278564, 35.41445057732718, 35.2178304536002, 35.770292145865305, 36.485640457698274, 35.76863847460066, 36.56001050131661, 36.6662415095738, 38.568262236458914, 36.3968494279044, 37.562110968998496, 37.13180555616106, 42.37539216450283, 47.41994762420654, 50.20257261821202, 47.650999546051025, 49.68925360270909, 49.859821455819265, 42.051255226135254, 37.70237077985491, 36.89563281195504, 36.763040338243755, 39.66755758013044, 44.54465797969273, 47.58508546011788, 47.401913574763704, 43.87914909635271, 41.10945469992501, 48.02486474173409, 56.70371716363089, 52.86426421574184, 56.46319832120623, 52.98079245431082, 57.731637137276785, 56.00695180892944, 58.1100811958313, 56.6393837928772, 56.94475712094988, 58.070907252175466, 56.763120787484304, 28.457686594554357, 1.4275452899081367, 1.1454565695353915, 0.5457703056080001, 0.16527418073798927, 16.957306214741298, 65.31659643990653, 55.25548676082066, 48.5890862601144, 40.128570556640625, 31.84592526299613, 53.77242156437465, 57.50336796896798, 56.806178774152485, 14.644982201712471, 0.12291166532252516, 0.12884443625807762, 0.14803681283124856, 0.18370629953486578, 0.14603493096573011, 0.12731011930320943, 0.1075032614171505, 0.12592806560652597, 0.08552450793130056, 0.10110691535685744, 0.13933556473680905], [0.04032003340710487, 0.01626218925230205, 0.023557363510397927, 0.006899329226663602, 0.037312552465924194, 0.020891599589958787, 0.0981911893135735, 0.014996019158778446, 0.08776878286153078, 0.04824385339660304, 0.052279450598039796, 0.044475856835820844, 0.11209989512073142, 17.565417766571045, 43.70652805055891, 44.46792554855347, 40.37067706244332, 29.58219521386283, 23.08090649332319, 28.887637649263652, 37.04994535446167, 50.73021534511021, 24.31662450517927, 0.04742046132949846, 0.0671388077150498, 0.25382814396704945, 0.44208795630506104, 9.946949907711574, 39.7054009437561, 53.270042487553184, 50.44174698420933, 45.003642082214355, 39.52721439089094, 37.526928765433176, 38.09537478855678, 37.07096365519932, 35.90576464789254, 34.82143572398594, 34.330573286329, 33.602311747414724, 33.67083488191877, 32.51060731070382, 32.22314643859863, 35.66472121647426, 43.914438996996196, 45.88792194638933, 44.322729042598176, 41.13571194240025, 42.46225854328701, 41.655416352408274, 37.12004920414516, 38.09836251395089, 39.33119528634207, 40.10899748120989, 43.26199967520577, 43.28860085351126, 42.910636220659526, 44.10707780293056, 41.64210360390799, 32.809786319732666, 31.924106393541607, 33.27532952172415, 32.22661706379482, 32.0327136857169, 33.15687663214547, 33.13434362411499, 32.984557832990376, 32.50249181474958, 33.91116959708077, 33.27600349698748, 33.4456159727914, 31.19073792866298, 32.29894086292812, 31.951753275735037, 33.580814020974294, 42.26066698346819, 44.84759943825858, 46.26689406803676, 46.74913379124233, 46.628502641405376, 45.823866503579275, 45.48973110743931, 46.29368979590279, 45.190110887799946, 42.92822558539254, 38.08037710189819, 41.80780076980591, 46.58595534733364, 45.194387504032676, 44.36132975987026, 45.45207534517561, 46.57759666442871, 44.3691395350865, 43.99977329799107, 46.95133331843785, 44.93592146464756, 44.38940395627703, 41.67323848179409, 43.180521624428884, 46.40981503895351, 43.17201355525425, 41.45768451690674, 36.14309079306466, 34.103686809539795, 32.740585735866, 33.66883380072457, 33.36271006720406, 32.76847580501011, 32.95492376599993, 32.63908297674996, 33.38021952765328, 33.3383913721357, 33.775874274117605, 34.70411539077759, 34.214580059051514, 33.30284786224365, 32.779172556740896, 33.94187021255493, 32.7209848676409, 33.97586080006191, 33.345655713762554, 34.58969245638166, 39.50838129861014, 43.032934938158306, 43.816406863076345, 42.058818340301514, 43.709157943725586, 47.36922924859183, 42.73459666115897, 37.028742926461355, 32.88590383529663, 35.99212728227888, 35.732507841927664, 36.96185261862618, 40.77952296393258, 43.57428298677717, 42.233999797276084, 38.181522028786794, 38.02691418784005, 47.24515526635306, 49.23951407841274, 53.20183202198574, 53.626307896205354, 53.614311831338064, 53.132541111537385, 52.987080574035645, 51.13374587467739, 53.51984064919608, 54.39935057503836, 50.36195387159075, 15.899456875664846, 0.4741031655243465, 0.77130752908332, 0.2008609404521329, 0.12099747732281685, 16.208808047430857, 56.92764718191964, 45.562888690403526, 41.46098838533674, 31.494349888392858, 22.96614830834525, 37.31307710920061, 49.161715098789756, 41.861503396715435, 7.664359842027936, 0.07166318422449486, 0.028123417337025915, 0.017470702528953552, 0.06437220331281424, 0.026075520619217838, 0.039876112049179416, 0.031491634635520835, 0.03801339432331068, 0.05099582519116146, 0.03953933137069855, 0.01080639026726463, 0.006962122553626874, 0.016540527709626725, 0.03318288316950202, 0.030390409619680474, 0.07707870791533164, 0.03754841463108148, 0.05363328063062259, 0.015280630672350526, 0.05703571984278304, 0.020822321164554784, 0.03736358169200165, 0.04924396312396441, 0.2098297756165266, 21.499420063836233, 49.42386368342808, 50.78756577627999, 44.45576967511858, 30.411337648119243, 25.92138566289629, 35.56500761849539, 42.3991584777832, 54.84722798211234, 26.556421484266007, 0.06962225266865321, 0.10983380528965167, 0.2453001258628709, 0.8660104445048741, 9.279732636043004, 42.7651617867606, 55.03181382587978, 51.89443465641567, 46.86011389323643, 39.46331180844988, 37.71463435036795, 39.176861899239675, 37.941486086164204, 36.518105915614534, 36.3134571484157, 35.07221358163016, 35.898232800619944, 34.71750109536307, 33.843018191201345, 33.24625131062099, 37.69641964776175, 43.89054414204189, 45.858895846775596, 46.28813818522862, 41.454387596675325, 43.59026731763567, 40.894522598811555, 38.259376593998496, 38.931781564440044, 41.256120749882285, 41.89609152930123, 44.06858478273664, 44.604996136256624, 43.7759370803833, 46.23565149307251, 42.98672594342913, 34.86118289402553, 33.961106300354004, 34.169340338025776, 33.07610729762486, 34.23060955320086, 34.35965844563076, 34.30495875222342, 34.380555152893066, 34.21434382029942, 34.729650020599365, 34.6011118207659, 33.87552881240845, 34.47943844114031, 34.2208125931876, 33.367893423352925, 35.41542679922921, 44.79482786996024, 47.635855947222026, 46.792400223868235, 48.165871483939036, 46.951573031289236, 45.93551710673741, 45.9163817678179, 47.605051108769004, 47.304517201014924, 46.27250126429966, 41.00537068503243, 43.042916025434224, 48.26083946228027, 47.70239884512765, 46.214963231767925, 46.28951045445034, 49.47123997552054, 47.873567717415945, 44.6739570072719, 47.53722626822335, 45.79197079794747, 46.394174643925254, 42.347161633627756, 45.51540470123291, 46.815134729657856, 45.69506427219936, 42.23516362054007, 37.20073863438198, 35.19597142083304, 34.25239215578352, 35.20344073431832, 34.6297036579677, 34.1674017906189, 35.16344690322876, 34.63621064594814, 34.385474477495464, 34.6726713180542, 36.18634680339268, 35.50830684389387, 35.33422667639596, 34.23505640029907, 34.811996596200125, 34.66333988734654, 34.92728458132063, 35.177753244127544, 33.97288349696568, 36.65495763506208, 40.118794441223145, 46.32378939219883, 46.99091720581055, 44.70845133917672, 46.095433371407644, 50.166435037340435, 45.1592469896589, 38.47813367843628, 34.325362137385774, 36.37253073283604, 36.03402491978237, 38.71535907472883, 43.298276220049175, 45.37566600527082, 43.7814678464617, 41.606890133449006, 39.991847378867014, 50.34403099332537, 51.23256662913731, 54.63900089263916, 53.63287394387381, 53.61560072217669, 53.57632255554199, 55.64837959834507, 53.689001492091585, 56.23463385445731, 56.568849154881065, 51.765271118709016, 16.403215169906616, 0.47249362617731094, 1.2587118808712279, 0.19164483355624334, 0.05996466374823025, 17.12368256705148, 62.11694404057094, 49.986365522657124, 46.30400092261178, 34.646427971976145, 25.203892094748362, 42.24193116596767, 55.66552427836827, 49.38863979067121, 10.850478887557983, 0.04585352719628385, 0.015061241641108478, 0.0039745163272268, 0.01446125892523144, 0.03661313553207687, 0.04358323723343866, 0.045770796814135144, 0.050775979845119376, 0.0321196391513305, 0.0396687313914299, 0.026946678158960173, 0.19196257793477603, 0.1233925430902413, 0.18713910318911076, 0.165970737646733, 0.21680531916873796, 0.09947595465928316, 0.14472472055682115, 0.22419000576649392, 0.20365441484110697, 0.13218201430780546, 0.06915280821600131, 0.1288252608584506, 0.33486495699201313, 24.693029267447336, 58.53116634913853, 56.83630963734218, 51.743582316807334, 40.872673988342285, 34.39839117867606, 38.62381655829293, 46.45650693348476, 59.940476417541504, 30.592800276620046, 0.28141667214887484, 0.17662799863943032, 1.287287324666977, 2.3726573927061896, 11.439708709716797, 43.03148971285139, 55.45793642316546, 53.67249952043806, 49.265945025852744, 42.64789703914097, 40.48750407355172, 42.50216899599348, 40.29671696254185, 39.8562776020595, 38.5678106035505, 36.73128359658377, 37.50955826895577, 35.72497599465506, 35.57549245016915, 35.1636449268886, 39.740628310612266, 48.21065609795706, 49.12188802446638, 48.58833238056728, 44.55454526628767, 46.48702342169625, 44.02365773064749, 39.88164894921439, 40.792484828404014, 44.65268857138497, 43.024659633636475, 45.789393016270225, 47.108265331813264, 45.24877452850342, 48.68556547164917, 45.865586962018696, 36.890897614615305, 36.50113494055611, 36.01048789705549, 34.82315192903791, 36.06186287743704, 36.02703850609915, 36.20802518299648, 36.04470777511597, 35.550395556858604, 35.905761173793245, 35.10918147223336, 35.966905321393696, 34.774385997227256, 35.325169699532644, 35.29465321132115, 37.67402212960379, 45.44746174131121, 49.94473539079939, 48.965782846723286, 50.2091977255685, 49.61226756232125, 48.09039667674473, 47.08976922716413, 49.6248368535723, 49.51515259061541, 48.13119649887085, 42.28797687802996, 44.544345310756135, 51.44679348809378, 48.52159145900181, 47.873765741075786, 48.1975622177124, 50.25148098809378, 50.063473156520296, 47.88366344996861, 50.48438113076346, 46.588720730372835, 47.40889304024832, 44.20587771279471, 46.444736685071675, 50.05106019973755, 48.19924020767212, 46.26707124710083, 39.38332414627075, 37.61039400100708, 36.360298429216655, 36.477271352495464, 37.618818691798616, 36.315965448107036, 36.604503290993826, 35.88274526596069, 35.843995162418906, 35.668667793273926, 37.06907374518258, 38.05156987054007, 37.91214731761387, 36.15983942576817, 36.86715562002999, 36.94848428453718, 36.42238405772618, 37.14101191929409, 37.52643544333321, 38.739448479243684, 42.97558103288923, 47.43519197191511, 50.129321234566824, 46.69084882736206, 46.13139377321516, 51.78513254438128, 47.2697171483721, 40.30146605627877, 34.64934968948364, 39.872154235839844, 38.163668632507324, 40.712017740522114, 43.63515615463257, 48.387470381600515, 46.67276266642979, 42.86514983858381, 42.680803707667756, 51.632199219294954, 54.002896785736084, 57.52720029013497, 57.406878335135325, 54.00594009671892, 55.8136876651219, 59.92862279074532, 56.76603903089251, 58.175026008060996, 59.92976229531424, 54.558422633579795, 18.997702053615026, 0.786949064050402, 2.669293361050742, 0.5949123629501888, 0.20622048500393117, 19.300666093826294, 66.55610643114362, 57.1680131639753, 54.74611432211739, 44.448449747903005, 32.34143604551043, 50.150186674935476, 63.121785572596956, 58.970417567661826, 15.267790930611746, 0.12878397878791603, 0.10433169374508516, 0.15176605486444064, 0.11753987999899046, 0.12956818885036878, 0.25486383267811363, 0.0939483776954668, 0.1252356341906956, 0.1703448457909482, 0.08907019267124788, 0.06268541275390557], [0.02385287738538214, 0.03825660163004484, 0.04235779620440943, 0.0075106023411665645, 0.06714306212961674, 0.0860574971884489, 0.02601744480697172, 0.0312625238937991, 0.009919634055612343, 0.11792429722845554, 0.02712792673680399, 0.03249584949974503, 0.04901223662974579, 10.343224780900137, 44.79534203665597, 45.64393595286778, 37.775865350450786, 25.895229169300624, 17.45868127686637, 31.772708620343888, 40.5303292955671, 49.74423817225865, 32.32235976627895, 0.526976459792682, 0.11400839021163327, 0.5774918720126152, 0.07593967832092728, 4.082770611558642, 36.012926714760916, 52.39081743785313, 48.127777985164094, 45.11891964503697, 44.02441855839321, 44.64679649897984, 43.6853152002607, 45.3388683455331, 45.58762775148664, 42.71931757245745, 38.719965730394634, 33.99664633614676, 31.752426828656876, 31.784061976841517, 38.3935741015843, 43.52494035448347, 45.34681361062186, 41.28610222680228, 41.626887048993794, 38.8398881639753, 38.83732080459595, 39.483183656420024, 43.65562554768154, 42.148762771061485, 42.577094895499094, 41.709612301417756, 44.3563027381897, 43.92871407100132, 42.121862820216585, 44.97675950186593, 40.08156599317278, 32.4280001776559, 32.530618122645784, 34.0544171333313, 32.52372898374285, 31.750609874725342, 33.30967794145857, 32.66806738717215, 33.599654061453684, 32.507723808288574, 35.38641807011196, 33.47502074922834, 32.62092733383179, 32.736732959747314, 33.35014077595302, 32.260534695216585, 31.456576006753103, 35.28475202832903, 42.68852315630232, 42.669047355651855, 43.987078939165386, 44.57939897264753, 46.281533922467915, 45.14271027701241, 47.70669283185686, 47.07959706442696, 44.71249519075666, 40.865058762686594, 41.41714872632708, 44.263259410858154, 48.33486557006836, 42.25192614964077, 45.91272701535906, 45.06993831907, 48.19267068590437, 51.13983597074236, 45.85293081828526, 40.23397820336478, 39.133539881025044, 39.43329211643764, 40.67422996248518, 44.53572607040405, 42.72120748247419, 40.163040569850374, 35.29960380281721, 32.82319981711251, 32.40205907821655, 33.49235303061349, 32.71792071206229, 33.34196274621146, 32.49773924691336, 32.924511500767295, 34.2582494871957, 32.36652946472168, 32.54170397349766, 33.869327545166016, 32.362965038844514, 32.01084075655256, 32.12392963681902, 31.79985523223877, 33.24703993116106, 33.71862806592669, 33.709984506879536, 36.42018495287214, 41.09118441173008, 42.55533313751221, 45.03087902069092, 39.21618870326451, 42.37107385907854, 50.57085146222796, 44.477562699999126, 41.16731929779053, 36.69917944499424, 34.722601073128835, 33.44608845029558, 34.406416348048616, 38.161671025412424, 43.21933078765869, 40.22452170508248, 39.92039557865688, 37.48917572838919, 37.47521332332066, 45.57572896139962, 50.63057817731585, 50.03980759211949, 49.82632419041225, 51.673037256513325, 55.14369024549212, 54.53867237908499, 55.18748474121094, 54.8291140283857, 40.10620430537632, 8.04931002003806, 0.3575616819517953, 0.3568904751113483, 0.046641316530959945, 0.07447666861116886, 15.331410373960223, 55.830064569200786, 45.77166468756539, 40.57972056525094, 24.462620053972515, 17.70188386099679, 37.45331954956055, 44.489662987845286, 39.2822174344744, 7.724030103002276, 0.14017374547464506, 0.020698529235752564, 0.06805031094700098, 0.07971445005387068, 0.046222137952489514, 0.03417342894577554, 0.010687309067829378, 0.051450457224356275, 0.06502228735813073, 0.07036033592053823, 0.025123093243954436, 0.05122090882754751, 0.01292083176252033, 0.04721510609877961, 0.08207396058631794, 0.0341753050951021, 0.021850354304271083, 0.042145041549312215, 0.03891661942803434, 0.02298013207369617, 0.040284121941242895, 0.06045343966356345, 0.06321101276470081, 0.024638602277264, 13.373504417283193, 51.61655535016741, 51.070020471300396, 44.3691325868879, 31.501166071210587, 23.569764375686646, 34.85840361458914, 44.301540510995046, 53.54217215946743, 34.30330855505807, 0.45703301578760147, 0.0798200097467218, 0.6918153603162084, 1.1293385944196155, 5.198709496429988, 37.26476975849697, 54.136045115334646, 50.33621079581124, 48.151551246643066, 45.11576863697597, 46.12809337888445, 45.998679706028526, 47.01131364277431, 47.816714082445415, 44.3580710547311, 39.457030636923655, 35.69780158996582, 33.31981883730207, 34.11325447899954, 39.531522274017334, 45.26417868477957, 46.202796936035156, 42.921037673950195, 43.14201123373849, 39.56910855429513, 40.781947885240825, 42.01319299425398, 44.86783259255545, 44.80581644603184, 42.77452448436192, 43.795458044324604, 45.89599922725132, 43.88943590436663, 43.633127280644004, 44.3307055745806, 42.9523914200919, 33.30415064947945, 32.222496782030376, 34.62106704711914, 34.46876948220389, 33.79413414001465, 34.1120593888419, 33.800356251852854, 34.22607585362026, 33.65934256144932, 36.28198528289795, 34.712619985852925, 33.629110949380056, 34.69892856052944, 34.053479126521516, 33.195272377559114, 34.12534087044852, 37.458513328007285, 45.255760942186626, 46.16920239584786, 46.258705615997314, 46.40741443634033, 47.161485058920725, 46.86877482278006, 47.4159072467259, 47.93420464651925, 47.08352974482945, 43.29877301624843, 43.28445625305176, 48.256646224430625, 48.27999564579555, 44.39209985733032, 48.33704730442592, 45.61769955498831, 47.521770000457764, 51.61493294579642, 46.420313767024446, 43.787655217306956, 41.83634049551827, 40.92609173910958, 43.644532748631065, 45.68050084795271, 44.175698212214876, 41.08656733376639, 37.02942732402256, 34.40178189958845, 34.80103581292288, 34.461418288094656, 33.83051143373762, 34.280970096588135, 33.75505747113909, 32.728645256587434, 35.188988481249126, 33.859183175223215, 34.792625018528526, 35.68741750717163, 34.66379499435425, 33.14706924983433, 33.95643711090088, 34.22368567330496, 34.46283572060721, 35.47762359891619, 34.62927981785366, 38.862435068402974, 44.0741468157087, 44.497576986040386, 45.35589838027954, 40.215343134743826, 43.653753008161274, 49.96435362952096, 46.23566886356899, 42.417776175907676, 37.4553518976484, 36.428804193224224, 34.4604629107884, 36.313203539167134, 40.650276047842844, 43.57784741265433, 44.458774771009175, 43.13647699356079, 38.73375790459769, 39.05720002310616, 47.73435361044747, 51.570905685424805, 51.449670042310444, 50.29318755013602, 51.494809014456614, 56.539378370557515, 55.17715971810477, 56.19931616101946, 57.22641972133091, 42.950383390699116, 10.517144271305629, 0.28567010962537354, 1.29734006524086, 0.025039049896544645, 0.07029369021100657, 16.525689329419816, 61.60007449558803, 49.335149083818706, 45.73660755157471, 30.778390135083878, 21.187124592917307, 43.40965584346226, 51.92075443267822, 46.9949506350926, 10.473226445061819, 0.13149653109056608, 0.06643258168229035, 0.02135990240744182, 0.03708762489259243, 0.048454697975622754, 0.02718242666950183, 0.049908822269311974, 0.009437293196762246, 0.0531656851858965, 0.012182768866685885, 0.036093584660972865, 0.26723442173429895, 0.04659230594656297, 0.1426490412226745, 0.146752997434565, 0.21115978567727975, 0.10516213239835841, 0.1341129621224744, 0.17186963611415454, 0.10701065856431212, 0.1445647898529257, 0.13386588038078376, 0.28941646431173595, 0.13469528087547847, 14.286840779440743, 57.693324770246235, 58.85257611955915, 50.381228174482075, 36.5345001901899, 26.6154169014522, 41.74477366038731, 50.002339431217735, 57.80204323359898, 39.21320097787039, 1.0322060350860869, 0.223001361691526, 2.6064718748841966, 2.119563613619123, 5.119355423109872, 39.71303006580898, 55.72169004167829, 53.20637961796352, 50.56396927152361, 47.899811063494, 47.66524682726179, 48.46791662488665, 49.47541584287371, 51.02636841365269, 46.8640569959368, 42.8675400188991, 36.65620136260986, 34.41283300944737, 35.82077775682722, 42.59928396769932, 46.298435415540425, 47.56999397277832, 43.859419686453684, 43.94600813729422, 40.93154607500349, 43.44004031590053, 44.16132933752877, 47.44520780018398, 47.22190659386771, 44.58751446860177, 45.02376059123448, 46.8612186568124, 44.45473786762783, 44.879060881478445, 48.752070154462544, 43.59410272325788, 34.247955730983186, 34.86648089545113, 37.766099657331196, 36.23826721736363, 34.68302065985543, 36.255526542663574, 34.63519273485456, 36.49969318934849, 35.54512882232666, 38.26232263020107, 36.776057788303916, 34.68591111046927, 35.75258813585554, 36.193409647260395, 35.39012145996094, 35.6174248286656, 39.605322565351216, 46.72344977515084, 48.867226123809814, 48.80762447629656, 49.0434741292681, 50.04042945589338, 47.43870081220354, 50.14381170272827, 50.504280771527974, 48.83490310396467, 46.054588385990684, 46.24761976514544, 49.07872928891863, 52.81751326152256, 46.947164399283274, 49.8110659463065, 47.37139361245291, 48.91629777635847, 49.768271991184776, 46.46375043051583, 43.24728339059012, 42.878684929439, 43.00853633880615, 44.172217164720806, 47.48447207042149, 45.9870206287929, 44.76102835791451, 39.02072892870222, 36.01735271726336, 36.057030405317036, 37.06801414489746, 35.77075072697231, 36.79074975422451, 34.91045604433332, 34.9904054914202, 37.72754757744925, 35.50662190573556, 36.33692121505737, 38.28976454053606, 35.19713871819632, 34.82026495252337, 36.03024162564959, 35.23870979036604, 35.82788576398577, 37.806993280138286, 35.31369474955967, 42.28676094327654, 46.372746399470735, 45.16646269389561, 49.04751450674874, 43.640315192086355, 44.24281433650425, 53.640107018607004, 48.86525630950928, 44.62540646961757, 39.76505817685808, 38.09608350481306, 36.02098315102713, 38.17686326163155, 41.950690473829, 46.120036942618235, 45.0298159463065, 45.8097825050354, 41.22985308510916, 41.442443643297466, 49.30394472394671, 55.18902724129813, 54.4459799357823, 53.820339815957205, 54.37674808502197, 57.13777460370745, 56.95727777481079, 58.47428839547293, 57.79890612193516, 45.05932494572231, 11.290541308266775, 1.6958804854324885, 1.9340310777936662, 0.16648182379347937, 0.13459392131439277, 17.85145946911403, 65.70563302721295, 56.041397503444124, 53.276709284101216, 35.66521801267351, 30.18852628980364, 53.073116643088206, 59.946771485464915, 56.72467640468052, 14.654971974236624, 0.25960291123815943, 0.163685499557427, 0.13907762643482002, 0.22483910593603337, 0.16684200375207833, 0.13712929455297335, 0.08485746729586806, 0.23559829645923205, 0.2278968154319695, 0.12427634852273123, 0.2275870641959565], [0.02957079020727958, 0.07936463132500648, 0.07036062769059624, 0.04103060545665877, 0.02098117469410811, 0.0171394128951111, 0.021496477935995375, 0.05180927672024284, 0.07371214284960713, 0.011747057782486081, 0.01066592164404158, 0.033225152508488724, 0.06310535129159689, 4.287859286580767, 38.074787276131765, 44.16554341997419, 38.988996505737305, 30.12739951269967, 24.280512980052404, 27.68720085280282, 41.26180785042899, 45.18364558901106, 43.86945635931832, 2.8432588832718984, 0.03718988011990275, 0.15963989735714026, 1.1070131638220377, 2.5369167157581876, 20.99511112485613, 50.83509145464216, 48.65397548675537, 46.76754304340908, 46.99158075877598, 48.716860158102854, 47.83460569381714, 44.80062961578369, 47.65391778945923, 48.397486209869385, 39.61252784729004, 31.35298878805978, 32.523176601954866, 41.05916363852364, 44.84261757986886, 43.042214257376536, 39.497427463531494, 42.91494410378592, 40.995761326381135, 42.18838139942714, 44.383459772382466, 37.857055050986155, 40.917451654161724, 42.928513935634065, 44.15710135868618, 43.03106587273734, 40.29348257609776, 40.851405552455354, 43.135757855006624, 43.198753697531565, 40.359869139535085, 32.16926663262503, 33.02297789709908, 32.87015921728951, 32.23690734590803, 33.317557198660715, 32.45815188544137, 33.83940165383475, 33.11678205217634, 31.993258340018137, 33.30827440534319, 32.656144278390066, 33.706948144095286, 32.45583813531058, 32.85005807876587, 32.198209353855674, 32.91275862285069, 33.54127877099173, 34.93415287562779, 36.80601494652884, 37.9053624016898, 40.06844779423305, 41.13958556311471, 44.596818106515066, 47.87184803826468, 45.8108560017177, 44.881874901907786, 37.99750593730381, 39.66069623402187, 46.88522120884487, 45.72014726911272, 45.415249892643516, 44.18140268325806, 50.712949071611675, 50.55074337550572, 38.10620355606079, 37.172480310712544, 37.107403482709614, 40.707404136657715, 41.40094205311367, 42.2419103213719, 44.920204639434814, 42.8368741444179, 36.80434043066842, 33.25275135040283, 33.301854269845144, 32.67281648090908, 33.29106024333409, 31.96150507245745, 32.805342946733745, 32.255646637507844, 32.68736948285784, 32.19939749581473, 33.8119284766061, 32.87806626728603, 33.28415025983538, 33.68224729810442, 36.20410639899117, 33.37503269740513, 31.924540655953543, 33.24241590499878, 33.065129143851145, 33.22523648398263, 38.177363531930105, 40.58965648923601, 45.7388413974217, 43.58193295342581, 42.08117069516863, 39.748215743473594, 46.00813620431082, 45.591084480285645, 47.42546796798706, 42.55740370069231, 38.372260502406526, 35.403211866106304, 34.138973236083984, 36.28651203427996, 37.920030048915315, 39.927173546382356, 40.36004979269845, 39.72967447553362, 37.3907128061567, 38.04689373288836, 43.84621810913086, 47.925679206848145, 52.54524115153721, 50.32905762536185, 50.56687361853463, 51.289701666150776, 53.33442449569702, 49.52532475335257, 32.101209027426584, 4.099130145141056, 0.17862285088215554, 1.046506404876709, 0.01775814183721585, 0.05345067667907902, 14.564303193773542, 57.122620582580566, 45.71311569213867, 38.11636529650007, 26.934294053486415, 27.319616828645977, 41.15869658333914, 43.861837659563335, 38.90577793121338, 7.934262616293771, 0.0912094439512917, 0.08393789628254515, 0.09624890996409313, 0.10589448202933584, 0.027690856351650188, 0.027327974127339463, 0.022290974589330808, 0.11484163121453353, 0.026200562748791914, 0.04525157842519028, 0.018022653447198014, 0.015532775981617826, 0.08925396031034843, 0.02852707781961986, 0.04608485335484147, 0.10667757929435798, 0.02599710232711264, 0.024086022017789737, 0.03095526966665472, 0.0699631893741233, 0.022211078787222505, 0.021761143912694285, 0.05332906963303685, 0.024285007501021028, 5.846030167170933, 44.57414266041347, 49.819938795907156, 44.136739662715364, 34.63753775187901, 24.09306447846549, 34.99712092535836, 46.67723035812378, 49.39873552322388, 47.275244440351216, 3.056394223655973, 0.025226006650232842, 0.440316735633782, 1.428998874766486, 4.131708511284419, 23.592114993504115, 52.928451674325125, 51.44672748020717, 48.87472323008946, 47.427479471479145, 50.48388433456421, 50.167911529541016, 47.6281920841762, 49.75830480030605, 49.711307185036794, 40.43901606968471, 33.35197162628174, 34.413173471178325, 40.705628871917725, 46.61309848512922, 45.41327313014439, 41.81647212164742, 42.47493553161621, 41.561768531799316, 42.50240523474557, 44.28264488492693, 38.54485375540597, 43.64070776530674, 44.32291316986084, 45.36387491226196, 43.377510002681184, 42.310190268925254, 41.86870173045567, 44.579572677612305, 44.57529606137957, 41.674916471753804, 33.8448942048209, 34.80129289627075, 33.62773173195975, 33.203349658421104, 33.826134068625315, 34.4805223601205, 35.91496753692627, 35.1766345841544, 33.5174012865339, 34.95052630560738, 33.51397582462856, 34.18990700585501, 35.14995002746582, 34.31598901748657, 33.79857403891427, 34.30672706876482, 34.90794774464199, 36.50310822895595, 38.50299085889544, 39.5313207762582, 43.748884269169395, 44.38736465999058, 45.90764788218907, 48.97347797666277, 47.54497698375157, 46.7669107573373, 39.728340421404155, 40.64310203279768, 48.08670718329293, 48.405702454703196, 47.931456633976524, 44.817617961338584, 50.00686618259975, 51.90806007385254, 42.363333565848215, 38.22566046033587, 38.82078061785017, 40.38156488963536, 42.17021880831037, 43.43979365485055, 46.679533685956685, 44.29172270638602, 38.24958310808454, 35.7650705746242, 34.02813557216099, 33.62890945162092, 33.7482899257115, 34.19440596444266, 34.577713762010845, 33.92449624197823, 33.68524891989571, 33.28829138619559, 35.18927683149065, 34.08828265326363, 34.0523361478533, 34.786569663456504, 37.34349284853254, 35.90972164699009, 33.972195625305176, 34.35943957737514, 35.918900217328755, 35.338496344430105, 39.38155582972935, 43.71794046674456, 48.1908016204834, 45.83366346359253, 43.42787054606846, 42.11606107439314, 47.18007843835013, 47.37415204729353, 48.42461197716849, 43.89218391690935, 38.557801723480225, 36.91646351133074, 34.92990057809012, 39.13591963904244, 40.245321137564524, 42.69139276232038, 43.06449713025774, 42.45838144847325, 39.93848173958914, 39.10127592086792, 47.120195388793945, 50.077647481645855, 55.01257078988211, 51.917839663369314, 53.15962866374424, 52.80616685322353, 53.78196491513933, 49.80547612054007, 34.024453026907786, 5.8437893731253485, 1.6211227540458952, 1.1734354453427451, 0.10972184701157467, 0.011260035032007312, 15.863802194595337, 61.330539975847515, 49.672668252672466, 45.05616004126412, 29.68767581667219, 27.932647705078125, 47.42234475272042, 51.321871825626914, 48.541848931993755, 10.225537930216108, 0.09433934278786182, 0.027068519299583774, 0.026788803416171243, 0.04497960801901562, 0.06270753978086369, 0.021019578079826066, 0.06013016522462879, 0.03936770611575671, 0.024843180585386496, 0.05485949858224817, 0.08244231689189162, 0.14309870637953281, 0.2432331182062626, 0.14702894405594893, 0.12197477131017617, 0.13645187233175549, 0.08334322819220168, 0.09438947974038975, 0.09709441888013057, 0.15324968525341578, 0.08296956574278218, 0.10762421706957476, 0.11006932479462453, 0.17627906879144056, 5.984308438641684, 50.28111505508423, 57.163840770721436, 50.675022329602925, 41.476024287087576, 32.14920023509434, 36.43118395124163, 52.189229352133616, 52.992475850241526, 53.34250177655901, 4.100466370582581, 0.16939269831137999, 0.938994865332331, 3.5412864216736386, 4.893569801534925, 23.122805867876323, 55.162321840013774, 54.31574637549264, 50.18072748184204, 50.313167095184326, 53.061040673937114, 52.051456996372764, 50.422354561941965, 51.35560532978603, 52.554093156542095, 43.35177040100098, 34.310468673706055, 37.1216333934239, 43.938851492745535, 48.70819575445992, 46.50273329871041, 42.01007672718593, 44.00956678390503, 42.70640434537615, 43.08137777873448, 45.50174454280308, 39.90916381563459, 45.151280879974365, 45.275500774383545, 46.18535000937325, 44.46411793572562, 41.60954087121146, 43.02219649723598, 46.10417420523507, 46.00192104067121, 44.82993016924177, 35.447822775159565, 37.87143087387085, 37.10636820111956, 36.67744547980172, 35.21391861779349, 35.81167214257376, 37.23448256083897, 36.42465264456612, 36.058812618255615, 37.56631462914603, 35.254141739436555, 35.84918894086565, 37.86100510188511, 35.651644706726074, 35.514278820582796, 36.02595806121826, 37.07907567705427, 38.84779173987252, 40.10253913061959, 40.53872619356428, 44.58891453061785, 46.4708480153765, 47.472524642944336, 51.232656955718994, 50.29507398605347, 49.24078212465559, 42.42842081614903, 42.73775461741856, 49.655954360961914, 49.329531465257915, 49.63196223122733, 47.00233309609549, 50.604293142046245, 50.17951154708862, 42.32334320885794, 40.74545247214181, 41.107300758361816, 41.33117866516113, 44.12924950463431, 44.96943957465035, 49.04016331263951, 46.57862499782017, 40.47298581259591, 36.711085183279856, 35.93933139528547, 36.314721720559255, 36.64230843952724, 35.421117373875205, 35.92402451378958, 37.084609917231965, 35.652426379067556, 34.976512568337576, 38.37216670172555, 34.84211703709194, 36.31025055476597, 36.43781253269741, 40.024201665605815, 37.0243308203561, 35.5171206338065, 35.64264331545149, 37.51201793125698, 37.822341850825715, 42.73001085008894, 44.87808813367571, 50.509512765066965, 46.77159036908831, 42.911716665540425, 41.6729223387582, 46.243304933820454, 47.93691791806902, 52.05565370832171, 46.77161816188267, 41.746750422886436, 38.71650205339704, 36.581529072352815, 41.21134655816214, 42.76327187674386, 44.06029210771833, 44.58187600544521, 44.57775572368077, 40.69920178822109, 41.03693287713187, 49.10656029837472, 51.833401679992676, 58.62938608442034, 54.48476825441633, 55.286447933741975, 54.24451344353812, 56.19402163369315, 51.162077154432026, 36.47876868929182, 6.446698461260114, 2.130045188324792, 3.109178602695465, 0.4758649138467652, 0.11096585954406432, 18.214806829180034, 67.60566656930106, 54.75105101721627, 52.3083701133728, 38.13469811848232, 38.59164292471749, 55.05943291527884, 57.53970009940011, 56.579896790640696, 12.662036674363272, 0.2300991229712963, 0.1345552448183298, 0.1764062126832349, 0.2568791631077017, 0.13048556819558144, 0.09984908106603793, 0.18349332096321241, 0.17820073424705438, 0.1405177762998002, 0.09312435798346996, 0.13206025798405918], [0.04508169700524636, 0.004346601182727942, 0.059968192130327225, 0.018821519866053547, 0.0690640015527606, 0.048988593077020984, 0.06644768587180547, 0.029900904279202223, 0.03248875541612506, 0.0638245034164616, 0.02716536999547056, 0.030030382331460714, 0.0254236520268023, 1.1510297847645623, 26.97266548020499, 44.35280432019915, 37.7385048866272, 27.2876273223332, 20.493331330163137, 21.842139959335327, 35.1576486315046, 42.52637651988438, 47.10600369317191, 5.364888693605151, 0.06163177000624793, 0.21792821320039885, 0.5516010927302497, 1.766349658370018, 11.327861819948469, 43.114406040736604, 51.107836042131694, 49.34777396065848, 48.3170781816755, 46.751162665230886, 40.85834680284773, 46.73429591315133, 47.429091453552246, 47.48243277413504, 37.10158436638968, 33.572333744594026, 39.17616013118199, 44.41231216703142, 42.69660043716431, 40.42051649093628, 41.8156452860151, 43.52953658785139, 43.41681248801095, 43.43042400905064, 40.41502741404942, 43.14368574959891, 38.50630514962332, 43.74238770348685, 41.6751457623073, 40.982684816632954, 38.252327646527974, 43.329397201538086, 43.51829787663051, 41.8584566116333, 37.019936084747314, 30.710329055786133, 30.623222964150564, 32.976025445120676, 31.83354009900774, 32.85316392353603, 33.188018458230154, 32.62035410744803, 33.21121849332537, 33.76189797265189, 32.34080375943865, 33.38184540612357, 33.131724153246196, 32.50884941646031, 34.32167264393398, 30.767460618700298, 33.09807750156948, 36.51976306097848, 36.92300871440342, 36.48380265917097, 36.358137539454866, 33.53570631572178, 35.39246300288609, 39.49850443431309, 41.203074727739605, 40.114163466862266, 38.2885868208749, 39.344299588884624, 45.84806707927159, 44.73040417262486, 47.905654498508994, 42.830321993146626, 51.44641828536987, 48.98671776907784, 32.92065872464861, 38.624327250889365, 41.33485426221575, 44.21433367047991, 42.6067567552839, 45.365754399980815, 44.824145793914795, 44.6154670715332, 39.132014751434326, 34.137566225869314, 32.375263350350515, 33.36242866516113, 35.45941584450858, 33.59312622887747, 32.4715758051191, 32.429963043757844, 33.023245402744834, 32.14668151310512, 33.32694074085781, 33.93979964937483, 32.855456829071045, 32.54183598927089, 34.64687613078526, 36.14697483607701, 32.60211508614676, 32.760957854134695, 33.034369468688965, 31.185109887804302, 33.5801226752145, 42.102227210998535, 44.78296382086617, 44.500217301504954, 44.03894029344831, 43.09553473336356, 42.57291555404663, 39.91987793786185, 47.120692184993196, 46.14751706804548, 47.79694645745413, 46.385524136679514, 39.948011193956646, 37.252064977373394, 34.3578553880964, 36.789811747414724, 37.81404570170811, 38.532204559871126, 37.34823499407087, 37.7867705481393, 36.47781331198556, 36.731193270002095, 40.445919104984824, 47.82727534430367, 49.36396673747471, 52.81967762538365, 51.1258944102696, 55.90027959006173, 51.43694789069039, 24.969789913722447, 1.9334409151758467, 0.41682617898498264, 1.1010102459362574, 0.08051948435604572, 0.03117771719449333, 14.279089195387703, 58.4939865384783, 45.075389180864605, 43.443100997379844, 27.973944323403494, 21.069639239992412, 39.20965739658901, 43.908915179116384, 34.94056258882795, 4.0139830112457275, 0.0617463474294969, 0.002892512724169397, 0.062326773069798946, 0.01791157726464527, 0.029793895914086273, 0.048723659078989706, 0.0848276185403977, 0.037994205352983305, 0.019566554709204605, 0.04510504539523806, 0.07247567562652485, 0.06186120305210352, 0.024662936239370277, 0.08668787657682385, 0.06979493983089924, 0.016512600904596702, 0.036867555629994185, 0.061063693703285286, 0.042278221010097435, 0.04133653314784169, 0.027073676165725504, 0.029538471584341357, 0.006211060623172671, 0.04366030863353184, 1.8626813292503357, 33.1312620980399, 51.132140840802876, 43.74599381855556, 31.599816594805034, 22.175825459616526, 25.661644629069738, 44.13509293964931, 47.007328850882395, 50.79761981964111, 5.344289456095014, 0.03837784565985203, 0.3928415131356035, 1.619841571365084, 3.145556547812053, 12.941788520131793, 45.12106663840157, 52.63329219818115, 51.91515071051461, 50.770223072596956, 48.87275341578892, 41.283013752528596, 48.94010925292969, 49.19575432368687, 48.75965758732387, 38.75606509617397, 33.94499690192086, 39.02995613643101, 48.310334954942974, 44.27888938358852, 40.764025006975444, 42.31582873208182, 43.30945239748274, 42.377042361668174, 43.898968832833425, 42.303658962249756, 43.65237379074097, 39.690969535282676, 43.52093819209507, 41.457218987601145, 42.52869374411446, 38.26625183650425, 43.55899000167847, 45.35387645448957, 45.052724157060894, 37.28200476510184, 31.71577855518886, 33.18439844676426, 33.9212201663426, 34.34607471738543, 34.574003423963276, 35.279120513371055, 34.96249457768032, 34.06829963411604, 34.716253893715994, 34.236268860953196, 35.10989366258894, 34.224957193647114, 34.352394104003906, 35.34965167726789, 34.589591707502095, 32.91596174240112, 37.610842159816194, 38.62470940181187, 37.86348908288138, 36.67079257965088, 36.10242646081107, 37.59380170277187, 41.42587218965803, 42.766513211386545, 43.40259647369385, 39.074723379952566, 41.80614015034267, 48.17782933371407, 45.24625580651419, 48.69455296652657, 44.1440144266401, 49.577578680855886, 52.70246498925345, 37.26838629586356, 39.84946836744036, 42.148001943315776, 44.674259253910606, 45.36609486171177, 46.42702225276402, 47.38067293167114, 46.52362653187343, 41.82285404205322, 35.470341886792866, 34.496857575007844, 35.68642391477312, 35.52808141708374, 34.389035429273335, 36.140266350337434, 34.50632449558803, 33.97664247240339, 34.02663476126534, 34.57891927446638, 34.6420783996582, 33.202442918504985, 34.11010694503784, 35.479103565216064, 35.870380946568076, 34.67285197121756, 34.55905090059553, 33.92637920379639, 34.26010118212019, 36.020111152103965, 42.27493858337402, 45.810376576014924, 45.72156817572457, 46.47177559988839, 44.16988604409354, 44.39047050476074, 42.32094260624477, 47.13535983221871, 47.154495171138215, 50.297610078539165, 48.33378165108817, 42.0667462348938, 39.10131761005947, 36.67019156047276, 38.453818457467214, 39.94180645261492, 41.68131923675537, 38.70345681054251, 38.93463379996163, 38.47571570532662, 40.38885702405657, 43.168577671051025, 47.97928803307669, 51.300822257995605, 55.14409671510969, 55.261545589991975, 57.13082987921578, 52.212742056165425, 27.894719226019724, 3.0652153960296085, 1.7487789669207163, 1.6814779554094588, 0.1785490805549281, 0.048207382139350684, 15.418561628886632, 64.1160866873605, 49.19651515143258, 47.1532792363848, 32.23476035254342, 26.934455599103654, 45.82931736537388, 49.746148926871165, 43.75405025482178, 6.2083748153277805, 0.11655223156724658, 0.0242542715610138, 0.024487049784511328, 0.059246359792138846, 0.07155736668833665, 0.028753002839429036, 0.020646595861762762, 0.03877388619418655, 0.023429274758590118, 0.07115409297070333, 0.014614243126873459, 0.14989765440779074, 0.10204215374376092, 0.24033683219126292, 0.1830192692577839, 0.17054839272584232, 0.10939988893057619, 0.16307184605726174, 0.12212052063218184, 0.10580074241650955, 0.15488149411976337, 0.14681437771235192, 0.11812983905630452, 0.07360912087772574, 2.0349008994443074, 37.073607444763184, 57.7613719531468, 50.65895809446062, 37.20866652897426, 27.51599202837263, 29.099309308188303, 47.462216990334646, 51.575811113630024, 55.47022778647286, 7.220743417739868, 0.20324901730886527, 1.755807938320296, 2.9769934671265736, 3.522510434900011, 13.740443127495901, 46.4163567679269, 54.290218693869456, 54.369313512529644, 51.98192637307303, 48.798967020852224, 42.691135678972515, 50.03206035069057, 51.24084540775844, 51.34776776177542, 41.59378235680716, 37.651395320892334, 42.22407776968819, 48.55108656202044, 43.985380104609895, 42.788816928863525, 43.78945827484131, 46.21595335006714, 43.90276949746268, 46.475982734135215, 42.88315609523228, 45.63307591847011, 40.94674178532192, 45.06285115650722, 42.09222180502755, 41.32998704910278, 40.33391761779785, 45.11691508974348, 49.434105328151155, 47.20910453796387, 39.723459311894004, 32.71209464754377, 34.66142913273403, 36.530980927603586, 35.038097926548545, 35.77634402683803, 36.96964502334595, 37.16830096926008, 35.09225566046578, 36.32320894513811, 35.73989725112915, 36.58537490027291, 37.09686653954642, 35.56041138512747, 38.73098904745919, 36.120849609375, 35.11346851076399, 40.247791222163606, 40.731757572719026, 40.74759946550642, 39.118705477033345, 37.87201452255249, 37.68608767645699, 42.98502016067505, 46.24140807560512, 44.576313972473145, 41.31296048845564, 43.53295162745884, 49.30699150902884, 48.228554657527376, 50.13969142096383, 46.70103488649641, 51.344262395586284, 49.5220764705113, 40.361849376133506, 44.364772592272075, 44.82625804628645, 45.95695577348982, 44.96976613998413, 47.945978369031636, 49.27034323556082, 49.867325510297505, 44.23320845195225, 36.70724630355835, 36.502465520586284, 37.70256185531616, 38.66652366093227, 37.37970338548933, 36.45443957192557, 36.20100055422102, 36.61285155160086, 34.321488516671316, 36.493196623665945, 36.49270330156599, 35.20713022777012, 35.80551603862217, 38.135775089263916, 37.57299184799194, 36.66405282701765, 36.11666679382324, 35.70267227717808, 34.90866340909685, 38.6114626611982, 45.19632952553885, 48.94879102706909, 46.76435729435512, 47.844506876809255, 43.78639759336199, 45.42455700465611, 44.02471733093262, 47.39933231898716, 48.03806631905692, 51.27067402430943, 50.755353927612305, 44.26424258095877, 41.13373517990112, 39.065940856933594, 40.31176676068987, 43.627565247671946, 43.50651373182024, 42.02967759541103, 41.51718888963972, 41.05679430280413, 41.614091941288535, 44.342597416469026, 51.426490851810996, 55.36621672766549, 57.26179647445679, 56.14691284724644, 60.50141838618687, 54.563421862465994, 29.400864601135254, 3.787588119506836, 1.943070684160505, 2.4020206970827918, 0.6982448324561119, 0.1300642250904015, 16.48337827410017, 69.44355542319161, 55.45694283076695, 57.37002508980887, 38.596336432865684, 33.40554918561663, 52.29081201553345, 58.25504493713379, 53.21133368355887, 9.19193606717246, 0.3332698568701744, 0.09942969214171171, 0.11307888544563736, 0.12254368221121174, 0.06884790172002145, 0.09276059535997254, 0.1602823750248977, 0.22346843805696281, 0.09174544590392283, 0.19318575944219316, 0.1391350712094988], [0.03434925772515791, 0.02510509340624724, 0.00988609915865319, 0.02285958523862064, 0.018452880272109593, 0.020958289404266646, 0.054961295798420906, 0.058921131172350476, 0.0186898857687733, 0.05018082660223756, 0.06636856868863106, 0.01891862670890987, 0.059444810929042954, 0.12557834865791456, 13.00528723852975, 43.721814087459016, 40.25674745014736, 33.30253866740635, 22.98971312386649, 31.921104771750315, 36.44185291017805, 42.37276227133614, 50.50336708341326, 8.542750239372253, 0.06101777045322316, 0.3057524120169026, 2.8573533041136603, 2.898589559963771, 2.647301878247942, 29.767566204071045, 45.95098727090018, 50.613245895930696, 44.502704756600515, 41.25722203935896, 42.21487488065447, 46.748570987156455, 44.978500025612966, 41.27843141555786, 31.109885215759277, 40.872166769845144, 44.109599999019075, 43.14348772593907, 40.200995104653494, 44.68962172099522, 43.70947061266218, 45.139180592128206, 44.58004515511649, 45.99153348377773, 42.06519678660801, 44.00422361918858, 42.26720176424299, 43.068603515625, 44.07244798115322, 40.11047049931118, 44.94277238845825, 44.1842931338719, 43.50961610249111, 38.24859993798392, 31.839227199554443, 30.585876396724156, 32.55985614231655, 34.49706254686628, 33.01752356120518, 31.87984984261649, 32.50292260306222, 32.4193149294172, 33.87591096333095, 34.06806686946324, 33.451699120657786, 33.10329212461199, 32.91349860600063, 33.374341351645334, 33.95307765688215, 32.813670362745015, 32.81227030072893, 36.319446495601106, 38.88348463603428, 42.13634981427874, 42.75715398788452, 41.26490674700056, 36.419073241097585, 33.372857911246165, 34.100994382585796, 32.66823761803763, 35.64517593383789, 45.170266832624165, 45.61619874409267, 46.57733263288225, 45.64849397114345, 43.75759383610317, 49.64526455742972, 33.54861954280308, 41.180771010262625, 43.481639180864605, 42.8929009437561, 43.00976964405605, 43.14410958971296, 44.17134516579764, 43.35320520401001, 41.71576145717076, 37.850718293871196, 33.02847739628383, 33.338075229099815, 34.797169140407014, 32.37522513525826, 34.055650438581196, 33.43684387207031, 32.60491868427822, 33.94907202039446, 33.02160562787737, 35.15299333844866, 32.9882994379316, 33.41531835283552, 33.47575378417969, 34.13892112459455, 32.678232601710725, 33.72670534678868, 34.82601458685738, 33.487301690237864, 32.96488400868007, 33.596885204315186, 39.803287165505544, 45.243848255702424, 46.6543846811567, 45.422479493277415, 43.960102558135986, 46.37912137167794, 43.88681295939854, 42.23353426797049, 42.15066310337612, 44.165425300598145, 46.068060943058555, 45.51801722390311, 43.04863439287458, 36.43821900231497, 37.70813431058611, 35.91620431627546, 33.978136335100444, 35.243715967450825, 36.73512595040457, 34.70626238414219, 36.66951411111014, 35.67358364377703, 38.618650572640554, 44.72355324881417, 50.543829917907715, 50.89345979690552, 55.892928395952495, 51.77971294948033, 20.071424552372523, 0.8311301618814468, 1.3936314582824707, 0.8601280344384057, 0.07164044651601996, 0.05694372406495469, 13.22749410356794, 57.035038539341514, 45.07979781287057, 44.81832667759487, 34.384112630571636, 28.78022371019636, 45.824387618473594, 49.95361518859863, 39.04840707778931, 4.424964181014469, 0.2121166829019785, 0.04059492490653481, 0.005648918533032494, 0.05547811895874994, 0.03360010417444365, 0.08308089298329183, 0.018873032548331788, 0.031113799195736647, 0.028808072741542543, 0.04395861976913043, 0.04093753759350095, 0.005985737803192543, 0.02685891304697309, 0.06883490098906414, 0.016401029391480342, 0.0321574437298945, 0.07104566986007349, 0.07950438239744731, 0.0396185299780752, 0.03699962229334882, 0.009866710020495313, 0.03472015175170132, 0.062123341485857964, 0.05700216628611088, 0.3352791347673961, 19.322290624891007, 50.54329143251692, 46.278462818690706, 36.70546409061977, 22.803150517599924, 30.46869155338832, 39.060142585209434, 46.11860908780779, 55.93924161366054, 8.48474407196045, 0.03182151800553713, 0.12136365553098065, 2.664983306612287, 3.6708418812070573, 4.968946899686541, 32.272892066410606, 49.52639477593558, 51.62705407823835, 45.48349857330322, 40.42630781446184, 42.582257407052175, 47.66272463117327, 47.607743535723, 44.20177480152675, 33.07805626732962, 40.728363377707346, 46.34977912902832, 44.04607956750052, 40.737142426627024, 45.10701043265206, 45.531788553510395, 47.001822403499055, 47.061917373112266, 46.27501303809029, 43.404267515454976, 43.437153339385986, 42.970189230782644, 43.356766155787874, 44.293685572487966, 40.95971754619053, 46.294756344386506, 45.74370513643537, 45.5460010937282, 39.9455897467477, 31.985181059156144, 31.976336002349854, 33.97365822110857, 35.4538642338344, 34.992771353040425, 33.5611367225647, 33.22922822407314, 34.471965653555735, 35.3069862638201, 34.97504997253418, 34.87359585080828, 34.65735054016113, 33.918187277657644, 35.80258389881679, 35.73939003263201, 33.68007946014404, 34.9900997706822, 37.68168946674892, 40.287065914699006, 42.35444334575108, 44.9781665120806, 39.81814241409302, 39.69206387656075, 35.98162160600935, 36.004404749189106, 34.52253464290074, 37.620406355176655, 45.48084783554077, 48.53923988342285, 47.711462770189556, 48.14805282865252, 44.10963126591274, 51.36071572984968, 38.70648275102888, 41.4862311908177, 45.12126118796212, 45.486347334725515, 46.45782361711775, 44.105295589991975, 46.21097843987601, 45.141324111393516, 44.342913559504915, 40.50991201400757, 34.654428822653635, 35.25245680127825, 35.81691108431135, 34.00806222643171, 35.03732320240566, 33.99461398805891, 34.4823636327471, 35.968892506190706, 34.75911733082363, 35.80958420889718, 34.796707085200715, 35.329380307878765, 35.13392053331648, 34.50240223748343, 35.177951267787385, 34.62338079724993, 36.38383892604283, 35.63746690750122, 34.32789475577218, 34.96470410483224, 43.22965233666556, 47.63244090761457, 46.965608392442974, 45.90741164343697, 45.805266175951274, 47.388479232788086, 44.54831968035017, 43.88350214276995, 43.14229263578142, 43.73864262444632, 48.64297996248518, 48.57137877600533, 44.67475952420916, 37.65592902047293, 38.32623563494001, 37.1368464742388, 36.86890309197562, 36.58848769324166, 38.93916402544294, 37.54301037107195, 37.97133902141026, 38.34731994356428, 41.60306167602539, 46.920761244637625, 52.11211824417114, 53.39438744953701, 56.58355849129813, 53.42577593667166, 21.889568362917217, 1.722823971084186, 3.765625298023224, 0.5346448825938361, 0.07303684444299766, 0.062377826044602055, 14.79917141369411, 62.19973182678223, 51.65565633773804, 49.82530975341797, 35.76384769167219, 30.093725068228586, 48.797983850751606, 56.16065290996006, 46.02687202181135, 5.99693809236799, 0.2191578679318939, 0.07963569927960634, 0.05053678946569562, 0.06079603199447904, 0.026634207693859935, 0.0720869836264423, 0.046553351251142364, 0.0017268196721228638, 0.06499367353639432, 0.027448280082483376, 0.10344183578022889, 0.14026556483336858, 0.09480221223618303, 0.15999439119228295, 0.16391449155552046, 0.1418176322643246, 0.08004075075898852, 0.1636196273778166, 0.2105633398251874, 0.10389284443642412, 0.1483305370701211, 0.11559347515659672, 0.18443526327610016, 0.1536250915378332, 0.5161635428667068, 22.792596203940256, 56.89619268689837, 52.5921345438276, 43.14085783277239, 33.983205045972554, 43.300652503967285, 47.45492485591343, 50.2892062323434, 62.52334417615618, 9.890547037124634, 0.21826395232762608, 0.4647584898131234, 7.726461103984287, 5.702065663678305, 3.392876591001238, 34.026012897491455, 47.871604851314, 54.03858273369925, 46.417312145233154, 43.96415683201381, 43.93005854742867, 50.851173060280935, 50.02600152151925, 45.72014032091413, 35.09781421933855, 44.43710681370327, 47.99414675576346, 44.95993096487862, 41.97178520475115, 46.30782243183681, 46.32921246119908, 47.695864064352854, 48.85112019947597, 48.32886927468436, 44.30732141222273, 45.62062822069441, 44.614612443106516, 44.14091553006853, 45.43833180836269, 44.403248241969514, 47.9025799206325, 48.59321696417672, 47.739700249263215, 41.888799394880024, 33.00737919126238, 34.42825106212071, 36.08743919645037, 37.60250084740775, 36.63817078726632, 34.8271610396249, 34.2458747455052, 36.30343089784895, 37.824280398232595, 38.39230258124215, 36.614098753247944, 36.64340278080532, 36.05064153671265, 37.362548283168245, 37.34101928983416, 37.382041454315186, 36.437319210597444, 41.64312498910086, 42.37196670259748, 44.46399286815098, 46.22539595195225, 43.46860783440726, 41.73760659354073, 37.50005660738264, 37.679479939596995, 36.27703816550118, 39.86128030504499, 47.59074476787022, 50.01222324371338, 50.15922975540161, 48.42340299061367, 45.98528357914516, 48.49104717799595, 40.60463333129883, 43.94718933105469, 45.22127703257969, 47.5216657774789, 49.04141051428658, 46.8492225919451, 47.279771191733225, 47.39680664879935, 46.03610965183803, 41.527937752859934, 36.682031290871755, 37.3342239516122, 38.536227566855295, 34.98738302503313, 38.482125418526785, 35.61163003104073, 36.33922106879098, 37.883722237178254, 36.63965422766549, 37.54483774730137, 37.563097613198416, 37.04650947025844, 36.316573415483745, 35.64973742621285, 36.4959967476981, 36.68777397700718, 38.696994985852925, 37.547259194510325, 36.50872584751674, 36.48254156112671, 44.494644846235005, 49.0598440851484, 49.30214514051165, 47.225085394723074, 47.42650324957711, 47.38343136651175, 45.394231591905864, 44.187968730926514, 44.289971760341096, 45.27977739061628, 50.579811164310996, 49.74447093691145, 47.7845196042742, 39.582733971732004, 41.8350168636867, 39.4680609021868, 37.09850631441389, 38.55639123916626, 42.17978300367083, 39.457982540130615, 40.34458657673427, 39.57333653313773, 42.21544115883963, 49.44579914637974, 55.5582788331168, 56.83942937850952, 59.823503494262695, 55.97576829365322, 24.18423179217747, 2.0113973149231503, 5.705290062086923, 2.6220753576074327, 0.3438137210905552, 0.17969142140022346, 15.469387701579503, 66.99503803253174, 56.73682532991682, 56.0587923186166, 45.5147203036717, 40.480024337768555, 57.72691583633423, 64.71170711517334, 55.811540671757285, 9.28225656918117, 0.3966051297528403, 0.1522812529334, 0.1198479032942227, 0.22415413840540818, 0.11635477787681989, 0.20137930049427918, 0.1755850360329662, 0.11158431028681141, 0.10974220984748431, 0.10581567018691983, 0.18147489641393932], [0.06543071794190577, 0.01978939239467893, 0.03427106674228396, 0.03651298037064927, 0.03244308661669493, 0.01749870227649808, 0.05554109040115561, 0.01709708757698536, 0.06681319911565099, 0.03406994217740638, 0.022546741579260145, 0.11409395347748484, 0.03835352696478367, 0.04971214550148163, 10.878679020064217, 45.988837582724436, 44.38854585375105, 40.41532966068813, 26.091849293027604, 19.090524775641306, 34.75932577678135, 42.40788541521345, 48.53722490583147, 12.318976317133222, 0.05065309376056705, 0.16586321698767797, 1.553323752113751, 2.135082415172032, 0.7369537353515625, 11.710882135799952, 37.30278335298811, 49.496413299015586, 47.50973572049822, 48.96510192326137, 46.30222218377249, 45.750094005039756, 37.775573526109966, 31.760222707475933, 36.87724093028477, 46.052781854357036, 43.04621989386422, 43.445623193468364, 45.43760919570923, 44.70075273513794, 42.77072034563337, 43.1346252986363, 41.85596568243844, 42.96947009222848, 42.14397546223232, 45.16783496311733, 42.98064626966204, 42.99617549351284, 41.302677154541016, 43.73308753967285, 44.1636118207659, 41.6257266998291, 40.96162830080305, 33.843643529074534, 31.02260194505964, 33.014577525002615, 32.48488507952009, 32.9323525428772, 32.380099296569824, 33.02663959775652, 33.497428689684185, 33.73570326396397, 32.93398536954607, 34.554211480276926, 33.67745304107666, 33.282562596457346, 33.876838547842844, 33.96690109797886, 32.177819865090505, 34.33853939601353, 32.18880149296352, 39.440111773354666, 41.74089309147426, 45.67783273969378, 44.411026750292095, 49.71429491043091, 48.54753950663975, 42.46724387577602, 37.18868350982666, 34.3252718108041, 36.02997759410313, 45.895023005349294, 46.36070169721331, 46.45671885354178, 40.91383859089443, 43.421905517578125, 41.200701917920796, 37.64111198697771, 43.337731565747944, 41.98117569514683, 48.505704402923584, 44.69182082584926, 46.961012159075054, 44.9504188810076, 41.31539930616106, 37.879879883357454, 35.761836188180105, 31.00523144858224, 32.15551267351423, 32.551886558532715, 34.704129287174766, 33.36266837801252, 32.438717773982454, 32.954312324523926, 32.377191475459504, 34.03677218300955, 33.05297327041626, 32.15835796083723, 33.95999458857945, 33.989979539598735, 34.03095654078892, 35.26208005632673, 33.61897005353655, 33.79726777757917, 32.049688134874614, 32.50963108880179, 32.90523024967739, 36.37644951684134, 43.83090080533709, 45.52981179101126, 47.13795845849173, 45.20410803386143, 46.78440284729004, 44.42760515213013, 46.49608734675816, 45.49647086007254, 44.81917435782296, 43.62402861458914, 45.40421615328108, 47.31065246037075, 44.77293062210083, 42.789810521262034, 44.190001079014365, 38.763075828552246, 33.423975808279856, 33.70606572287423, 33.917718274252756, 35.688081060137065, 38.03345244271414, 38.150237764631, 39.522920404161724, 45.873139653887065, 49.82063014166695, 52.655488218579976, 51.457952295030864, 15.353882585253034, 0.938934502857072, 1.6472103084836687, 0.724675997027329, 0.08842632400670222, 0.06360720936208963, 12.147422688347952, 55.05398552758353, 47.882913044520784, 44.651698453085764, 30.600425924573624, 24.657911334718975, 39.772881848471506, 52.831499985286165, 36.7155876159668, 2.4845913520881107, 0.04296313425792115, 0.06841077589030777, 0.02101642798100199, 0.017156267704974328, 0.01582617113100631, 0.027274330845102668, 0.10585317281740052, 0.04840323109445827, 0.04093573947570153, 0.06029646737234933, 0.021212066590253795, 0.010505985851133508, 0.04537064435758761, 0.02880179289994495, 0.05312706636531012, 0.04815130461273449, 0.04507481326748218, 0.03407059357102428, 0.020781639597511718, 0.0713876515094723, 0.009404645484339978, 0.12147733728800501, 0.014333100623584219, 0.08981319530201809, 0.050056016870907376, 12.509609699249268, 50.03392941611153, 49.660988330841064, 45.35165997913906, 28.150397300720215, 27.24765259878976, 45.124148164476665, 45.878336906433105, 54.72541216441563, 13.436379534857613, 0.07369254675826856, 0.12476124321775776, 5.0768702285630365, 5.8769144756453375, 1.2015468797513416, 15.009220668247767, 39.33871671131679, 48.401259081704275, 47.2751020022801, 51.34992170333862, 48.75395311628069, 46.83428396497454, 41.433192116873606, 33.759049211229595, 38.71257979529244, 48.28911515644619, 44.18792356763567, 44.88343129839216, 45.146993841443745, 46.66394887651716, 45.229100704193115, 45.6081805229187, 44.03528554098946, 46.97472095489502, 44.176462514059885, 46.228692872183665, 43.39747217723301, 43.50622885567801, 42.47690882001604, 45.267927237919395, 45.765314034053254, 43.25125428608486, 42.63079057421003, 36.20183086395264, 32.90664768218994, 35.37431083406721, 33.561143670763286, 35.53166321345738, 34.968212945120676, 33.79095881325858, 34.25152015686035, 36.033173765454976, 34.62710850579398, 37.32158170427595, 36.21129083633423, 35.18819638660976, 34.49162558146885, 35.794301646096365, 34.87225137438093, 35.84809807368687, 33.37875345775059, 39.34386532647269, 42.11620698656355, 46.45276880264282, 47.966402598789756, 49.77995538711548, 48.435506752559114, 43.262638909476145, 38.906486647469656, 36.597617626190186, 37.217660972050254, 47.43771416800362, 47.400294644492014, 47.92987939289638, 42.01168870925903, 44.52651970727103, 46.053132738385884, 39.67282084056309, 44.94877215794155, 42.35845940453665, 48.49411480767386, 45.57356112343924, 47.52934006282261, 46.089131355285645, 42.1829583304269, 40.695415019989014, 35.987784658159526, 32.61836344855172, 33.5178668158395, 33.681615012032644, 34.922719614846365, 35.23794201442173, 35.59058741160801, 34.05885008403233, 33.804490430014475, 36.841753005981445, 34.52520622525896, 34.49066325596401, 36.06761598587036, 36.46652596337454, 34.06464140755789, 35.72399629865374, 35.04014764513288, 34.60042742320469, 33.23242439542498, 34.074695450919016, 33.81064305986677, 39.439819949013845, 46.0811687197004, 47.21005991527012, 48.591045652117046, 46.508750438690186, 47.80121612548828, 46.581595352717805, 47.110572133745464, 47.47320556640625, 46.22176204408918, 43.683654580797466, 46.38435336521694, 48.398799419403076, 46.15645939963204, 43.26775278363909, 44.7449745450701, 40.73335565839495, 35.60210057667324, 35.79349912915911, 36.39138119561331, 38.41693047114781, 40.21135139465332, 38.17489692143032, 40.81491361345564, 48.62103755133492, 51.66779136657715, 54.430078983306885, 52.477673394339426, 17.77205719266619, 1.26286538371018, 4.149566684450422, 2.417892553976604, 0.07397956707115684, 0.04652294609695673, 13.766899262155805, 59.81707641056606, 52.400152342660085, 51.71159628459385, 40.514136518750874, 32.27219377245222, 48.72989845275879, 60.00952761513846, 43.44127709524972, 3.5916476164545332, 0.09325389710388013, 0.02347484856311764, 0.023874878883361816, 0.025728733245549456, 0.01790421176701784, 0.012828932675932134, 0.023893335035869052, 0.010463331443523722, 0.021730212893869196, 0.08053633238055877, 0.004653433869991983, 0.2233268277985709, 0.1222307418606111, 0.20704293730003492, 0.13680737039872579, 0.08208890871277877, 0.14667050114699773, 0.19682167576892035, 0.07252937488790069, 0.1246275853897844, 0.2093091764088188, 0.22397018756185258, 0.1360484289803675, 0.2307464453790869, 0.14743674360215664, 14.645772559302193, 58.80886500222342, 54.997104099818635, 50.983779430389404, 36.1609719821385, 26.34628537722996, 45.360994883946006, 51.736672333308626, 58.64740971156529, 15.289686441421509, 0.3026408946939877, 0.3203779086470604, 5.159652803625379, 5.244778658662524, 1.5554116857903344, 14.581440925598145, 39.57641111101423, 49.63103812081473, 50.73470388139997, 53.99519123349871, 50.45334700175694, 48.55708633150373, 41.219368253435405, 35.669147218976704, 39.67984546933855, 49.75852714266096, 45.15476540156773, 45.558695452553884, 47.13544321060181, 47.45561620167324, 47.074233055114746, 47.6128191947937, 45.98402942929949, 47.2036258833749, 45.09544168199812, 48.03911897114345, 44.469954422542024, 45.40776320866176, 44.895885944366455, 46.902779306684224, 47.36791951315743, 45.63224560873849, 45.343099798474995, 36.87664338520595, 35.2685592515128, 36.8343323298863, 35.56156131199428, 36.39151668548584, 36.08304793494088, 35.3972989491054, 36.2109260559082, 37.74537318093436, 35.59933171953474, 38.78497655051095, 36.408018657139365, 37.238835607256206, 36.594265120370046, 37.90954174314226, 36.45992170061384, 38.281492710113525, 35.18786634717669, 41.554427759987966, 43.696199553353445, 49.5979334286281, 50.25157478877476, 51.02326256888253, 48.57027053833008, 45.632777145930696, 40.249531745910645, 38.91386216027396, 39.29317821775164, 50.84491968154907, 48.46028750283377, 50.1062011037554, 43.16304690497262, 44.48510149547032, 44.629075118473594, 41.522594588143484, 44.46510457992554, 44.865855830056326, 50.644321714128765, 47.91696616581508, 49.674888202122276, 48.137074674878804, 43.61256061281477, 42.12941551208496, 38.04525743212019, 34.61480672018868, 36.31326954705374, 34.9434426171439, 38.343164920806885, 37.5554962839399, 35.40027625220162, 35.72150536945888, 35.90809576851981, 39.923570905412944, 36.56173365456717, 36.12971898487636, 37.1649797303336, 37.56898968560355, 36.486449922834126, 38.921741417476106, 37.173473903111045, 36.63964033126831, 34.301557609013145, 36.0638986996242, 37.58582169669015, 41.16528000150408, 47.14549030576433, 48.90730333328247, 50.90527173451015, 47.952339444841655, 50.5677421433585, 49.832834652491975, 48.366201945713584, 49.86593934467861, 46.868229389190674, 45.32799094063895, 47.05294030053275, 50.64038903372628, 48.60947574887957, 46.260550362723215, 47.92231280463082, 43.50188970565796, 37.867414815085276, 36.494242327553884, 37.71491575241089, 38.747167927878245, 42.91231421061924, 41.34606865474156, 44.12018557957241, 50.41737617765154, 54.73409046445574, 55.15676328114101, 55.7010087285723, 18.72620814187186, 3.411333394902093, 6.288840166160038, 5.6849305374281744, 0.4517112656363419, 0.1988031201596771, 14.7318503175463, 64.83405794416154, 57.900843143463135, 57.34598432268415, 41.73285402570452, 37.221597126552034, 54.89140115465437, 66.71439334324428, 50.84472165788923, 5.268884999411447, 0.29695306132946697, 0.23509832471609116, 0.10944318625011615, 0.09157659246453217, 0.11578566341527871, 0.11455763716782842, 0.14280671919030802, 0.10634731594473124, 0.08874741356287684, 0.1654656090374504, 0.10435700310128075], [0.015523044093112861, 0.025757798293073262, 0.06699408298092228, 0.0733979811359729, 0.0680017481957163, 0.07751478201576642, 0.037809480979506455, 0.07622431019054991, 0.03832545257838709, 0.04076807347259351, 0.02736816884550665, 0.05717601374323879, 0.04980805642636759, 0.026649640972859094, 5.958687824862344, 41.185384614127024, 49.3481456892831, 37.48954050881522, 23.714041982378276, 19.771460396902903, 32.542419637952534, 38.62120056152344, 50.70163740430559, 19.596381425857544, 0.24768327655536787, 0.029149267290319716, 1.5115322917699814, 6.736378414290292, 1.6563168998275484, 2.915504080908639, 28.600769111088344, 50.4101048878261, 45.78667974472046, 46.157380035945344, 42.38929550988333, 36.74724013464791, 32.692493779318674, 38.81183133806501, 42.17164666312081, 46.48365354537964, 44.651010581425254, 46.02194227491106, 44.71849496023995, 44.04110813140869, 42.493581022535054, 42.037647179194856, 40.41987030846732, 40.1468825340271, 43.00562851769583, 42.47906970977783, 45.62837893622262, 44.200239249638145, 42.71503053392683, 43.221314498356406, 41.223578861781526, 41.73449380057198, 34.22345985685076, 32.507115840911865, 31.063085624149867, 31.897710187094553, 33.565312589917866, 33.101787839617046, 32.24011046545846, 32.11862816129412, 33.564649036952424, 33.79277229309082, 34.16121094567435, 33.14118412562779, 33.496984004974365, 32.63140174320766, 33.67118924004691, 32.402548926217214, 33.09562131336757, 33.45372452054705, 34.39107125146048, 36.13740716661726, 44.92635726928711, 44.83491202763149, 47.010285309382844, 39.442950112479075, 50.766398089272634, 48.26616873059954, 42.535558564322336, 40.41726473399571, 34.66137702124459, 43.2772718157087, 46.59700993129185, 47.963463510785786, 47.006411688668386, 44.846734387534006, 39.62264095033918, 40.243427753448486, 42.42357792173113, 44.389306681496755, 43.80579696382795, 44.51034082685198, 43.27662215914045, 43.09414856774466, 41.12357691356114, 37.2655097416469, 31.623506477900914, 32.5562743459429, 33.99230718612671, 32.75565637860979, 34.44936663763863, 33.37425797326224, 35.093812056950156, 33.692103317805696, 32.535645144326345, 32.33793762751988, 33.71106495176043, 32.96200050626482, 33.78397934777396, 32.80464465277535, 34.10634102140154, 33.60381603240967, 32.92427178791591, 33.00468676430838, 32.76807280949184, 33.00627442768642, 33.62594951902117, 33.39293820517403, 38.482187952314106, 43.90538896833147, 45.55184800284249, 44.15317562648228, 42.78744813374111, 42.88750566755022, 42.66279745101929, 43.88466944013323, 46.196192673274446, 47.5753128187997, 44.51031650815691, 46.014809949057444, 45.87077726636614, 47.16599096570696, 48.53922598702567, 45.69021095548357, 38.89889921460833, 35.505471978868755, 34.88488667351859, 33.91111053739275, 37.648060185568674, 40.12531532560076, 42.81981284277779, 45.88005311148507, 49.0515444619315, 52.33553409576416, 50.49486943653652, 11.777317336627416, 0.9899098532540458, 2.485157196010862, 0.4839532141174589, 0.08898160313921315, 0.09568259785217897, 11.46846296106066, 55.62225784574236, 44.88992438997541, 39.39033487864903, 24.813252210617065, 29.955254418509348, 40.012212548937114, 52.50931201662336, 31.457983016967773, 1.5510072878428867, 0.05600116767787507, 0.027312286397708312, 0.043206287281853814, 0.057976990406002314, 0.02491904758582158, 0.03137402755341359, 0.028665329329669476, 0.050285952032676766, 0.05031310021877289, 0.018053112884185145, 0.04501007763402803, 0.03836096031591296, 0.033730013096438985, 0.01761112704740039, 0.023697777850819484, 0.07698285127324717, 0.02909818717411586, 0.030511494193758284, 0.04033809940197638, 0.024423292937821577, 0.013013181226727153, 0.10272110266877071, 0.023602574298690473, 0.06549188787383692, 0.04794854138578687, 8.48168773310525, 48.67211375917707, 54.73056077957153, 42.339716638837544, 25.160246985299246, 18.05748224258423, 38.49266583578927, 46.7965726171221, 54.349257537296836, 21.91801428794861, 0.13121761248580047, 0.04010445265365498, 2.2920732711042677, 6.559582803930555, 2.992897025176457, 4.258302084037235, 32.22983407974243, 51.87282575879778, 49.49505145209176, 48.676042965480256, 43.989034857068745, 38.44879490988595, 33.0190486907959, 38.23429012298584, 45.11862087249756, 45.986106940678184, 44.8648796081543, 46.31732756750924, 46.769502435411724, 44.913516998291016, 43.942718165261404, 44.1174966267177, 42.59111288615635, 42.62817805153983, 44.67240408488682, 44.64874199458531, 45.82509633472988, 47.23189115524292, 43.61523219517299, 46.3073673248291, 43.5356753213065, 43.45055988856724, 36.49690696171352, 33.88364083426339, 33.08534492765154, 33.92273834773472, 33.64851379394531, 33.64471312931606, 33.06544181278774, 34.368635518210276, 34.20607546397618, 34.49823331832886, 35.86704928534371, 36.003081117357524, 34.13107313428606, 34.21554585865566, 34.379234995160786, 33.455916677202495, 35.11858238492693, 35.279492241995676, 36.9458578654698, 39.29423781803676, 45.25813027790615, 46.44327756336757, 48.364190442221506, 43.902911935533794, 50.97305141176496, 48.75783715929304, 45.57471799850464, 41.152311188834055, 36.44131442478725, 44.88137115750994, 48.141868931906565, 50.241795199257986, 46.917922905513215, 47.2098445211138, 42.12374578203474, 40.68803603308541, 44.29753140040806, 46.70863968985421, 46.3789997782026, 45.46837581907, 45.6013400214059, 44.76951905659267, 42.222358090536936, 39.49093089784895, 34.8609744480678, 34.99482454572405, 35.75181341171265, 35.05436018535069, 34.708607401166645, 33.47218935830252, 36.90679856709072, 35.60730825151716, 34.48176956176758, 35.06881243841988, 35.494959354400635, 34.69204289572579, 35.17484542301723, 36.271955558231895, 35.407380785260884, 35.631185735974995, 35.183499404362266, 35.97094569887434, 35.000914641789024, 34.49537760870797, 34.73215137209211, 35.144165652138845, 40.46960203988211, 46.81508609226772, 47.014798164367676, 46.88612447466169, 44.50888517924717, 45.54245056424822, 44.075147356305806, 46.223488671439036, 47.32048068727766, 49.96043484551566, 46.019552094595774, 47.35839353288923, 47.63145078931536, 49.71036570412772, 50.59862688609532, 47.07536908558437, 40.184805801936555, 37.15987975256783, 37.707495076315745, 36.65662520272391, 40.54429170063564, 41.647544043404714, 44.78734813417707, 47.58289677756173, 51.714907101222444, 53.419828278677805, 51.91997970853533, 11.974046894482203, 1.116262736065047, 5.780183391911643, 2.0903301537036896, 0.04431446388896022, 0.05611754321892347, 12.788165586335317, 60.09945814950125, 49.339460441044395, 44.194451400211875, 26.80345947401864, 31.105466161455425, 45.85156202316284, 58.06549113137381, 37.83817679541451, 2.573518523148128, 0.11234230175614357, 0.019676299266783253, 0.04568763556224959, 0.01165178043967379, 0.04725585551932454, 0.028256666347650543, 0.042957848470125876, 0.025850783035691296, 0.06007189942257745, 0.02405972539314202, 0.022507634213460342, 0.12329304271510669, 0.07227625418454409, 0.20529144842709812, 0.20363499516887323, 0.15812065745038645, 0.15362766997090407, 0.11251884299729552, 0.08235692325979471, 0.07575443147548608, 0.11650560264076505, 0.2156195520822491, 0.11510058731905051, 0.18380563706159592, 0.11217399793011801, 9.531980906214033, 54.755223410470144, 61.20356164659773, 50.88935341153826, 32.87308440889631, 27.897224051611765, 43.146666526794434, 49.60251229149954, 59.68192005157471, 25.681320190429688, 0.297515621142728, 0.14868228962378843, 3.916752960000719, 14.186970846993582, 4.71657486472811, 4.913100753511701, 33.41743407930647, 53.30973754610334, 51.16802133832659, 51.178950854710166, 47.30735901423863, 39.55807134083339, 35.78894805908203, 42.50451053891863, 47.96587453569685, 48.94536556516375, 44.95469202314104, 48.192906924656455, 48.52913720267159, 47.924032483782085, 46.692575454711914, 46.439463002341135, 43.06978470938546, 44.13038206100464, 45.18792567934309, 45.7432222366333, 47.78975854601179, 49.2619115965707, 47.17605543136597, 46.66872228894915, 45.834903717041016, 45.21098327636719, 37.69419969831194, 35.88160923549107, 34.32060956954956, 34.89629908970424, 36.29274109431675, 35.94041531426566, 33.94156796591622, 36.31933879852295, 37.596351691654746, 37.30667781829834, 37.128567695617676, 37.47954205104283, 36.12994132723127, 37.1785843031747, 36.83095897947039, 34.32973950249808, 36.05141626085554, 37.04857308523995, 38.6858674458095, 41.01671709333147, 47.79334034238543, 48.72217900412423, 49.64678968702044, 44.9883143561227, 51.92376300266811, 50.59627839497158, 48.28066962105887, 44.038255895887104, 37.71676744733538, 45.82160139083862, 50.96365744726998, 51.385451316833496, 50.78099625451224, 49.909351689474924, 41.57890278952462, 43.253043447222026, 44.90973717825753, 48.28216348375593, 48.542602811540874, 47.01006644112723, 47.94324425288609, 47.34941646030971, 44.255171707698274, 40.77337033408028, 34.39639009748186, 37.45516777038574, 37.550646441323416, 35.77662542888096, 37.55763632910592, 35.34354421070644, 39.360363824026926, 37.77600431442261, 35.94211762292044, 36.41718333108084, 36.19001545224871, 35.695970739637104, 36.98965236118862, 37.28414828436715, 37.10920654024397, 36.962877477918354, 36.805188110896516, 37.84930780955723, 36.28260019847325, 34.41858264378139, 36.37837764195034, 35.82293864658901, 41.15279408863613, 48.566733905247276, 49.413955552237375, 48.59511729649135, 47.26854985100882, 46.61304289954049, 46.87531655175345, 49.22135148729597, 49.672890595027376, 51.7843473979405, 47.50518117632185, 49.286612442561555, 49.0304080418178, 51.88507195881435, 52.67630154745919, 49.909111976623535, 42.474424839019775, 40.264717033931184, 39.35834884643555, 38.60279825755528, 41.350842067173545, 44.657385553632466, 46.87069599969046, 51.223686831338064, 54.14973654065813, 57.98365872246878, 54.95270511082241, 14.707748753683907, 3.488217600754329, 10.474752443177358, 2.8096070204462325, 0.32415908575057983, 0.17657879127987794, 14.253549354416982, 65.8068265914917, 56.36819560187203, 51.45664255959647, 35.274697984967915, 40.45528180258614, 54.56368241991316, 68.00957230159214, 46.213486739567344, 4.512964418956211, 0.19548990151711873, 0.11513368625726018, 0.1506946887820959, 0.16382949825908455, 0.14745253989739077, 0.09628080110996962, 0.12693047896027565, 0.15297247655689716, 0.14260843768715858, 0.09839328418352775, 0.132384557010872], [0.04601930008668985, 0.03683665853792003, 0.019572424037115912, 0.031078179499932697, 0.060867726004549434, 0.041410001526985846, 0.0978083869974528, 0.017924089450389147, 0.024891217472031713, 0.02377447096763977, 0.049916418468845744, 0.03907607855009181, 0.04977181926369667, 0.0900886058807373, 2.1195881494453976, 32.29797853742327, 50.394474915095735, 43.394130093710764, 30.73053789138794, 25.59974660192217, 34.67040273121425, 39.36515460695539, 45.07468741280692, 28.735263654163905, 1.776944792696408, 0.13559151706951006, 7.523258430617196, 9.992560488837105, 1.3184638917446136, 2.8736498696463446, 27.52509937967573, 49.18860115323748, 45.17376525061471, 43.25587831224714, 35.68142121178763, 34.00964641571045, 38.27029916218349, 43.549453599112375, 46.1465026310512, 46.97584656306675, 46.37966333116804, 46.17898198536464, 40.675828048161094, 42.42881338936942, 40.98558568954468, 39.02206645693098, 38.735668659210205, 40.631512437547954, 40.37454373495919, 41.97673579624721, 41.14698192051479, 44.83269902638027, 41.74718121119908, 42.399578843797954, 38.74081032616751, 34.68279831750052, 30.850349153791154, 32.71969250270298, 32.233551365988596, 32.5422111919948, 31.04954011099679, 33.179701464516775, 32.962268011910574, 32.62674992425101, 33.837546484810964, 33.44307293210711, 33.967390945979524, 33.61967876979283, 34.00701304844448, 33.60483741760254, 34.353669098445344, 33.008515221732004, 32.93274164199829, 32.18477848597935, 36.079546042851035, 35.56970460074288, 38.05212920052664, 45.28210851124355, 44.89788702556065, 43.975829805646626, 39.37254401615688, 51.403919628688264, 46.69732107434954, 43.516866547720774, 37.30165079661778, 37.74384805134365, 44.256415435246055, 46.584058489118306, 46.687027318137034, 42.688762869153706, 40.30439472198486, 43.65676505225045, 44.64081062589373, 44.849048137664795, 45.44773619515555, 45.6953387260437, 42.41783176149641, 41.170241015298025, 38.237184047698975, 34.56375135694231, 32.349614075251985, 32.244887351989746, 32.511514050619944, 34.315339360918315, 32.18731457846505, 32.85373714991978, 31.898561341421946, 33.22674076897757, 32.78221239362444, 33.204756668635774, 33.155028411320274, 32.17308119365147, 32.65262848990304, 32.31289284569876, 33.09999173028128, 33.43347746985299, 33.88612134116036, 33.2124205316816, 33.95701033728463, 33.852043901171, 32.51467548097883, 34.085687501089915, 33.17721053532192, 36.6142828805106, 38.36553117207119, 39.46892595291138, 39.64035538264683, 39.31515884399414, 40.585112367357524, 41.537842409951345, 42.85473448889596, 43.6781724521092, 47.717559814453125, 47.094024998801096, 46.226128986903596, 46.123827184949604, 50.78596421650478, 49.60295350211007, 42.62164674486433, 41.351307596479145, 38.24432332175118, 36.73878070286342, 34.07112407684326, 36.26801592963082, 39.945575850350515, 47.2070756639753, 49.4540570804051, 51.946928296770366, 53.93657970428467, 7.804256609507969, 0.42443174230200903, 3.399999580213002, 2.698078445025853, 0.1166336964815855, 0.06073088584733861, 14.172255430902753, 56.77928229740688, 42.18994474411011, 42.94242075511387, 36.30105113983154, 26.865612847464426, 35.67063760757446, 46.18053490774972, 29.079230751310075, 1.1981767863035202, 0.023780954369742955, 0.05763624369033745, 0.0460059193761221, 0.010769513585338635, 0.014165259897708893, 0.03356608242860862, 0.07303142294819866, 0.07317186612635851, 0.004478909150098583, 0.0661624093939151, 0.01814798395415502, 0.05434687555368457, 0.04774458732988153, 0.045793246145227125, 0.010836177954583295, 0.06275636716080563, 0.021709663460829427, 0.09039457767669644, 0.009903368723046566, 0.01720702551704432, 0.07661335502884217, 0.021001393341326287, 0.02418542909435928, 0.06045846760805164, 0.0270989312391196, 2.90403499347823, 39.78833811623709, 55.9533360345023, 48.94226319449288, 32.94436945234026, 23.659668854304723, 37.949615478515625, 43.04942648751395, 50.771484170641216, 32.323134490421836, 1.2254864637340819, 0.1566808468529156, 5.187518988336835, 8.83494804586683, 2.267313148294176, 4.051247068813868, 28.184459107262747, 51.5632209777832, 46.67833512169974, 46.735775879451204, 38.3512213570731, 34.16123179027012, 39.818003450121196, 44.7584297316415, 48.62760707310268, 46.56328337533133, 48.14069121224539, 47.67173644474575, 42.70087357929775, 44.538481031145366, 42.15669066565377, 40.56482015337263, 40.76739488329206, 41.20493337086269, 41.79043027332851, 43.39104509353638, 44.00541870934622, 46.24997520446777, 44.41287497111729, 43.242614201136995, 41.26639018739973, 37.12427370888846, 33.63917194093977, 34.116652148110525, 33.14439419337681, 33.12444938932146, 33.58384690965925, 35.14472845622471, 34.47348383494786, 34.98056336811611, 34.92233746392386, 33.81818185533796, 35.93843855176653, 34.789366313389365, 34.235754694257466, 33.3646034513201, 34.826292514801025, 34.27835757391793, 34.97729424067906, 35.13025883265904, 37.767683846609934, 36.406972953251426, 41.73317016874041, 46.7644476209368, 45.42507117135184, 43.238712787628174, 41.09349121366228, 52.93107461929321, 46.64137417929513, 46.00226845060076, 37.94800002234322, 39.94216081074306, 44.65522118977138, 48.1131728717259, 47.96712173734392, 45.61445127214704, 43.08154453550066, 44.56575618471418, 46.495423793792725, 45.830074719020296, 46.4245799609593, 45.72117212840489, 44.713936941964285, 42.75389528274536, 41.219607966286794, 36.61478315080915, 34.13500234058925, 32.427076067243306, 32.74854837145124, 36.06206784929548, 33.11478097098214, 34.80945702961513, 35.18659830093384, 34.1773933001927, 34.494192940848215, 34.15730953216553, 35.82121549333845, 33.48190641403198, 34.239242689950125, 34.9910238810948, 33.657067026410786, 33.64899321964809, 35.924156529562815, 35.35236842291695, 35.35668325424194, 35.13008860179356, 34.30089405604771, 34.46391269138881, 35.02849899019514, 38.082579680851524, 42.6590245791844, 42.03404106412615, 41.84514733723232, 40.90620946884155, 42.36628655024937, 43.288500104631694, 46.074432441166465, 46.41521378925869, 49.485789503370015, 47.651572772434776, 47.62363753999983, 47.586350032261436, 52.819959027426584, 50.99696363721575, 45.3482414654323, 41.632546356746126, 41.12424046652657, 37.56497710091727, 35.70117146628243, 38.804448877062114, 43.89238541466849, 49.018724645887104, 52.258558477674214, 54.4670364516122, 54.52115944453648, 8.269831078393118, 1.4212800775255476, 4.661466096128736, 3.045026319367545, 0.055163387275700054, 0.04753865534439683, 15.221330063683645, 60.03376293182373, 46.40064689091274, 44.01193264552525, 36.465851988111226, 31.400945254734584, 42.12272439684187, 53.029811995370046, 37.40001644407, 2.1922176693167006, 0.0524580715490239, 0.05372573781226363, 0.03428556364295738, 0.025315473188779185, 0.018778490567845956, 0.038065963823880465, 0.02554777474142611, 0.03316170609157, 0.019431853633640066, 0.07393253102366414, 0.02631512320866542, 0.15437210431056364, 0.13178053870797157, 0.16314575209149293, 0.16731777893645422, 0.12096565403044224, 0.1463356983980962, 0.1857835394995553, 0.13045416559491838, 0.1024258177993553, 0.10224743772830282, 0.11872975900769234, 0.08288095585469689, 0.18229249039930956, 0.14714968257716723, 4.085774404661996, 45.44694062641689, 62.62346076965332, 55.40191657202584, 41.540434088025776, 33.761227471487864, 46.48948655809675, 48.33281237738473, 53.9202618598938, 37.71116372517177, 2.088615034307752, 0.17521480018539087, 12.97095010961805, 19.582054240362986, 4.072465564523425, 4.998044652598245, 32.1310202734811, 52.674078123910085, 49.90134389059884, 48.384048393794465, 40.67290980475289, 36.874569347926546, 42.531653676714214, 47.73295702253069, 50.47869055611746, 47.754451274871826, 51.36640977859497, 49.504296030317036, 44.56492587498256, 46.8493789264134, 44.30605336597988, 42.16198519298008, 43.90363107408796, 44.12275293895176, 44.66644253049578, 45.452526978084016, 44.15357862200056, 47.65769413539341, 45.54804039001465, 46.939292090279714, 41.91372605732509, 38.90932151249477, 33.87499032701765, 35.98599549702236, 35.718541962759836, 36.22918244770595, 34.25274303981236, 37.07231160572597, 36.4803910936628, 37.27926022665841, 37.13379968915667, 36.075411864689414, 37.87828527178083, 37.35498169490269, 36.79779870169503, 36.58565282821655, 36.79473802021572, 37.08351557595389, 36.728111743927, 35.51878472736904, 38.73983063016619, 38.11490617479597, 43.63953351974487, 49.27280637196132, 47.410060337611604, 45.708710534232004, 42.46580907276699, 54.16947289875576, 49.527277197156636, 46.350991589682444, 39.99795831952776, 41.38994652884347, 47.28549998147147, 49.43524135862078, 51.113231318337576, 47.728989601135254, 43.82501220703125, 45.79222788129534, 48.469945498875205, 47.206599712371826, 47.24318892615182, 48.499239104134695, 47.733655316489084, 45.21094853537423, 42.81993096215384, 38.20955106190273, 36.660696847098215, 34.793972969055176, 35.57800422395979, 38.58838769367763, 34.15408904211861, 36.243857043130056, 36.08085230418614, 36.30287504196167, 36.53315918786185, 36.41444574083601, 37.82053531919207, 33.60650845936367, 35.79470116751534, 36.77221196038382, 36.20248052052089, 36.37473331178938, 37.63288879394531, 37.45315626689366, 38.1236435345241, 36.51715053830828, 36.21353163037981, 36.89487893240792, 37.04804849624634, 40.49978848866054, 42.6507180077689, 44.06986672537667, 43.34682675770351, 42.43195397513253, 44.02844156537737, 44.37250593730381, 48.067547525678364, 49.08609785352434, 52.674310888562886, 49.01363509041922, 48.086797509874614, 48.918187686375205, 52.7728328704834, 54.03871474947248, 47.87324115208217, 45.8585136958531, 41.94373185294015, 40.151628153664724, 38.122441496167866, 41.531839166368755, 45.85879857199532, 52.09171833310808, 53.447996275765554, 56.91696432658604, 57.614928245544434, 9.645307762282235, 2.2395038519586836, 8.0744503395898, 5.754515877791813, 0.2568966421697821, 0.13743061838405474, 16.38057620184762, 66.67845031193325, 51.84121492930821, 54.44296441759382, 50.013755321502686, 40.08020762034825, 48.841639382498606, 60.351101057870046, 45.65449374062674, 3.4641948555197035, 0.21657281235924788, 0.1753029011722122, 0.13398858665355615, 0.12140626753015177, 0.1284999575998102, 0.16330619848200253, 0.1457218820495265, 0.11868420216654028, 0.14516176496233257, 0.13916450605860778, 0.1399008794022458], [0.027072308917662928, 0.056795942530568154, 0.03792436035083873, 0.04185049967574222, 0.0229797911098493, 0.011100059375166893, 0.08245309202798776, 0.04567338971953307, 0.06483657232352666, 0.02221501768300576, 0.02466092099036489, 0.029474010757569755, 0.036286743224731514, 0.06184771377593279, 0.747829023216452, 26.499177013124736, 49.252090317862375, 42.40086078643799, 25.41188989366804, 19.294833081109182, 27.581914799554006, 41.258497033800396, 44.81432451520647, 39.1783766065325, 3.5943843381745473, 0.029267943065081323, 1.356951157961573, 4.696756431034633, 3.673856965133122, 3.2485405760151997, 34.906134264809744, 47.56167697906494, 46.257899624960764, 41.831695624760215, 36.35430908203125, 41.059149742126465, 43.58370474406651, 48.12521062578474, 45.236938272203716, 45.48660094397408, 46.6493889263698, 42.50953756059919, 42.77453490665981, 40.399081298283164, 40.08039174761091, 38.055596351623535, 37.994643279484336, 38.46209723608834, 39.61204842158726, 41.02485343388149, 41.5020626613072, 40.02796411514282, 40.348779814583914, 36.935588427952354, 34.16162436349051, 33.13259615216936, 32.589848041534424, 33.47332886287144, 32.60491173607962, 33.21076338631766, 32.57260608673096, 32.47083582196917, 31.45109040396554, 32.93300914764404, 32.67391429628645, 33.79692384174892, 32.911598273685996, 32.913939816611155, 33.60287455150059, 32.92484501429966, 32.98467942646572, 35.11332259859358, 32.83014454160418, 33.86204235894339, 31.303587096078054, 33.332777227674214, 32.83208308901106, 42.59431947980608, 44.10374961580549, 49.22542660576956, 41.09519699641636, 36.02582951954433, 47.4717811856951, 43.96949652263096, 39.91456604003906, 36.051378045763286, 41.295774119240896, 46.116264070783345, 47.936494077954976, 41.895368916647776, 38.839342730385916, 42.976519039699006, 42.92662402561733, 45.194568157196045, 43.57917104448591, 43.82159716742379, 41.37197848728725, 40.746730940682546, 37.155175822121755, 34.6169467653547, 32.50519118990217, 31.44924565723964, 34.065878186907085, 33.040372712271555, 34.84118945258004, 34.67371702194214, 34.58432149887085, 33.82735000337873, 34.87489863804409, 34.54906981331961, 33.803229331970215, 33.53800616945539, 34.01975951875959, 32.848116057259695, 34.17929710660662, 32.94524839946202, 33.807801246643066, 33.705770424434114, 33.006639208112446, 32.87366805757795, 34.85022211074829, 35.231855392456055, 33.94671310697283, 33.61599275044033, 33.182609285627095, 34.13951866967337, 32.7762508392334, 34.30418750217983, 37.95556313650948, 38.382859979357036, 40.48161200114659, 41.74471460069929, 42.95415278843471, 46.69549369812012, 47.26996380942208, 44.981696196964805, 38.60682473863874, 51.55172865731375, 46.59453289849417, 45.33475153786795, 46.3910687991551, 45.45571967533657, 43.45909227643694, 36.27697563171387, 39.709681034088135, 43.57973384857178, 48.56612941196987, 52.9668995312282, 50.32021256855556, 3.945184120110103, 0.7333223244973591, 3.858692075525011, 2.300141215324402, 0.09692217276564666, 0.0558906071819365, 13.648732117244176, 54.6718623978751, 42.34847831726074, 32.97459064211164, 25.57847469193595, 32.0771369934082, 37.92853116989136, 44.94756664548601, 23.352688755307877, 0.4131320986364569, 0.08338999282568693, 0.052846325894019434, 0.01899943344428071, 0.04350127359586103, 0.04986910761467048, 0.04128615192270704, 0.07670157136661665, 0.052307847288570235, 0.0759722547871726, 0.018791162209319215, 0.10837034096143075, 0.011044620519636996, 0.01249278218684984, 0.03414804155805281, 0.033673314710280726, 0.04101168450766376, 0.04127775165917618, 0.03811179207903998, 0.037775415128895214, 0.04471556629453387, 0.005089269210917077, 0.0445597169787756, 0.020594418215166246, 0.014116921062980379, 0.06147422096026795, 1.0192388509001051, 31.704720497131348, 53.81216178621565, 48.80889252253941, 29.914037704467773, 18.63064088140215, 35.09202984401158, 46.24502113887242, 48.709220613752095, 42.68763031278338, 3.5037175118923187, 0.057554466649889946, 1.4310523931469237, 4.280376945223127, 1.6639328854424613, 4.07645947592599, 35.52837324142456, 50.34135593686785, 47.66703251429966, 44.033444268362864, 37.36738075528826, 42.63075235911778, 45.29019621440342, 50.448000362941194, 46.53359719685146, 47.233319010053364, 49.4714275768825, 45.1882244518825, 44.08496863501412, 42.23112671715872, 42.5253655569894, 39.20893130983625, 40.22609894616263, 40.8511449950082, 40.48669113431658, 43.418535641261506, 43.26019661767142, 42.565956933157786, 41.35924243927002, 38.76942648206438, 35.947787352970664, 33.41246264321463, 32.630220549447195, 34.761403288160054, 33.52268539156233, 34.33915778568813, 33.99973481042044, 32.92378888811384, 32.724372114454, 33.81366900035313, 33.90874467577253, 35.81770665305001, 33.74634443010603, 35.19109378542219, 34.764199938092915, 33.46484511239188, 34.44643449783325, 35.530794688633506, 35.658530371529714, 35.83828721727644, 33.841767515454976, 34.39554589135306, 34.859779357910156, 45.24396637507847, 46.32015201023647, 48.92446885790144, 41.94489567620413, 38.173000063214985, 50.05987746374947, 44.51197712762015, 41.95538398197719, 38.6121609551566, 42.60685403006417, 48.60026591164725, 50.024424280439106, 44.172543730054585, 41.346641881125315, 44.891651017325266, 45.160935401916504, 46.58645561763218, 46.72307109832764, 46.020563057490754, 44.2108838898795, 42.52354165485927, 39.641380241939, 36.3657979284014, 33.89502198355538, 33.94940553392683, 34.576160839625764, 34.75988858086722, 35.00311722074236, 37.255813530513215, 36.18462017604283, 34.50490706307547, 35.89873654501778, 36.10055044719151, 35.56456640788487, 34.61321210861206, 35.05490214484078, 34.0696336882455, 36.42252996989659, 35.73544692993164, 35.42478602273123, 34.83711086000715, 34.494321482522146, 35.06128059114729, 35.464432443891255, 36.44932222366333, 35.45338828223092, 33.95283446993147, 34.8342273575919, 35.11352409635271, 35.78737081800188, 37.16810294560024, 39.91820689610073, 41.658435344696045, 42.794226101466585, 44.129701137542725, 46.142323289598735, 47.83808674131121, 49.3097881589617, 45.20008502687727, 41.312512329646516, 54.40949147088187, 49.760879107883994, 48.22839484895979, 47.71734094619751, 47.88003649030413, 44.482773848942344, 37.94728783198765, 42.218435832432334, 46.40624019077846, 49.76767444610596, 55.10202537264143, 51.057072503226145, 5.174062064715794, 1.8620963777814592, 7.084641235215323, 3.1572297385760715, 0.0802551271127803, 0.07360139914921351, 15.772478546415057, 60.78599575587681, 45.37275471006121, 43.51782192502703, 33.04002182824271, 34.887655530657085, 43.14804227011544, 52.352637086595806, 29.859292847769602, 0.7806049787572452, 0.022317773329892328, 0.04983830891017403, 0.015702396165579557, 0.054671198329223056, 0.035719135110931735, 0.029698273366583244, 0.014966295932286551, 0.03934601674388562, 0.1228896536465202, 0.01741390405888004, 0.04462865274399519, 0.07228767392890793, 0.15946313898478234, 0.1093668985579695, 0.12444286101630755, 0.1090545349621347, 0.14890883889581474, 0.23969871071832521, 0.13780451832073076, 0.13008426901485237, 0.1699727371867214, 0.1374633644840547, 0.15014860379908765, 0.08903819295976843, 0.16464615586612905, 0.9332315517323357, 36.27334867204939, 61.883880615234375, 55.04782247543335, 36.192099911826, 28.81068287576948, 37.6474209512983, 51.667093072618755, 54.15353373118809, 49.142016955784385, 4.631708264350891, 0.3068613282271794, 3.271697836262839, 10.571782299450465, 10.242867606026785, 4.714193369661059, 39.188944816589355, 52.142784118652344, 50.230851786477224, 47.69873367037092, 39.7654299054827, 45.42391082218715, 48.3556615284511, 50.67954213278634, 48.438817569187705, 48.9967440196446, 51.862222807747976, 46.74590287889753, 47.2426678112575, 45.17284461430141, 44.516364915030344, 41.88311576843262, 42.84075471333095, 41.31885950905936, 43.089489800589426, 44.772239276341026, 44.04789999553135, 43.36742469242641, 43.493499755859375, 40.115674700055806, 38.1968879699707, 36.3638003213065, 34.25735664367676, 36.45374127796718, 35.77297067642212, 36.98144653865269, 35.376304967062815, 36.19191925866263, 35.05791071483067, 35.13487243652344, 36.33469084330967, 37.632881845746724, 36.50375093732561, 36.972420828683035, 36.935230595724924, 35.80391795294625, 37.019276005881174, 38.57781948362078, 37.39145973750523, 37.21299178259713, 34.98707383019583, 36.08154364994594, 35.89817026683262, 45.51351131711687, 48.66330691746303, 50.345118386404856, 43.2341547693525, 41.04986694880894, 50.516269888196675, 47.12012938090733, 43.27692093167986, 40.12303631646292, 45.192243984767366, 50.76239592688424, 51.46581070763724, 47.32876293999808, 41.34183720179966, 45.48942538670131, 46.95625959123884, 48.471592221941265, 47.87688200814383, 47.97179440089634, 46.61285877227783, 45.14045558656965, 41.31459331512451, 38.33087008340018, 35.44577305657523, 34.442665100097656, 37.31720781326294, 35.65637295586722, 38.92665726797921, 39.77628299168178, 37.1742764200483, 36.82853405816214, 37.974879128592356, 38.364481994083945, 38.274749483381, 35.97106729234968, 36.86861821583339, 36.562355518341064, 38.64077711105347, 37.29408073425293, 38.89908334187099, 38.40032775061471, 36.29079907281058, 36.59231962476458, 37.03515611376081, 38.81948477881295, 37.86597653797695, 37.14143923350743, 36.73816926138741, 36.02240405763899, 36.60150514330183, 37.59394414084298, 43.83357586179461, 42.28635447365897, 46.13896383558001, 45.82888657706124, 47.84820679255894, 51.88294233594622, 51.791469301496235, 46.93790592466082, 42.441889899117605, 53.83549036298479, 52.10529163905552, 49.290732724326, 49.23448705673218, 50.12489523206438, 48.09801190240042, 41.440446036202566, 44.245451177869526, 48.7875337600708, 52.935629163469585, 57.14207206453596, 54.348993505750386, 6.091719337872096, 3.2073885670730045, 11.016832658222743, 6.08362294946398, 0.5872247783201081, 0.2226234855396407, 16.517844813210623, 66.03954955509731, 52.798350129808696, 47.82618795122419, 38.46924693243844, 45.71251119886126, 52.41649797984532, 59.84029729025704, 38.00093834740775, 1.7542727121285029, 0.11215230516557183, 0.12030068971216679, 0.1000647669924157, 0.1165374123624393, 0.13673982902296952, 0.05706733278930187, 0.17952121767614568, 0.11615021313939776, 0.24029270027365002, 0.07547895982861519, 0.1934433856180736], [0.026519022981769273, 0.04020426854757326, 0.03267473168671131, 0.016543204530275295, 0.0076526053017005324, 0.05873724818229675, 0.018396957112210136, 0.0363234960740166, 0.0612151970022491, 0.030841126505817686, 0.0586535848144974, 0.03177876690668719, 0.026155735332784907, 0.0054958783522514355, 0.1881009265780449, 15.96618390083313, 46.068206855228965, 45.68615320750645, 29.929184777396067, 20.32871287209647, 24.532216685158865, 37.61197471618652, 42.379436016082764, 42.671962124960764, 7.102371735232217, 0.10835039203188249, 0.6126345576984542, 2.1775602272578647, 1.5273493230342865, 4.4995161805834085, 29.92359495162964, 48.600776604243684, 45.40513678959438, 42.469029562813894, 44.64187717437744, 44.963766370500835, 46.935150963919504, 38.71863167626517, 45.293507031032014, 46.86654792513166, 42.52919748851231, 41.05710697174072, 39.09579379217965, 36.246608529772075, 37.13245521272932, 38.15483399799892, 36.08958966391427, 36.49507958548409, 38.52167803900582, 37.97988877977644, 38.50255312238421, 37.00929144450596, 34.85531166621617, 33.61216081891741, 31.768022060394287, 30.834100791386195, 31.85273102351597, 33.41883066722325, 32.66336693082537, 31.63125719342913, 32.42954267774309, 34.02238246372768, 33.63220289775303, 31.79294524874006, 32.331263882773264, 30.910808903830393, 33.66550561359951, 34.344580854688374, 34.15723657608032, 34.40345294134957, 35.10590192249843, 32.29815571648734, 31.503090722220286, 32.56459133965628, 35.104161398751394, 33.84628731863839, 32.84372132165091, 39.33593395778111, 45.263872964041575, 50.72706781114851, 38.59236553737095, 42.24388360977173, 45.62208039419991, 45.948009967803955, 40.280729157584055, 36.9121139390128, 40.28563805988857, 47.85358817236764, 46.37972933905465, 41.010234424046104, 35.41990491322109, 45.85229505811419, 44.393757002694265, 46.20601742608206, 45.02942337308611, 41.211051259722026, 40.244661058698384, 37.38585601534162, 36.92626394544329, 33.57559592383248, 33.43795905794416, 33.90772329057966, 32.58173254558018, 32.444397926330566, 34.62760182789394, 34.02708986827305, 34.245707988739014, 32.61566407339913, 32.92138133730207, 32.78672872270857, 34.638725893838064, 32.51017999649048, 34.190692152295796, 32.80331407274519, 35.3702426637922, 33.24104363577706, 30.81351327896118, 32.96725334439959, 32.930917739868164, 32.48584393092564, 33.72911637169974, 34.70775972093855, 34.810968262808665, 32.60867418561663, 34.01479850496565, 32.87335886274065, 31.706169196537562, 30.99129683630807, 31.681444031851633, 34.64211661475045, 35.925476687295095, 40.49934032985142, 40.390712193080354, 42.09062371935163, 45.29918023518154, 47.55621222087315, 45.01819508416312, 45.287361349378315, 51.9664249420166, 44.978062289101736, 47.49630832672119, 48.32088579450335, 48.03614166804722, 42.29170111247471, 36.47181354250227, 45.16707066127232, 48.74547978809902, 52.41515697751726, 45.53311218534197, 2.3527534093175615, 1.0565626195498874, 3.3246995636395047, 2.1105014256068637, 0.10634108020790986, 0.06508936054472413, 16.04543157986232, 53.01637070519583, 43.85170718601772, 35.35572787693569, 24.921793494905742, 25.99269676208496, 40.58276735033308, 49.68559537615095, 18.11880530629839, 0.24473629040377481, 0.03537286851289017, 0.037268966769001315, 0.0793544329436762, 0.016630637160103236, 0.05046961449884942, 0.04541921728689756, 0.0241893340633916, 0.04734313887144838, 0.032705679668911865, 0.0399915885313281, 0.04104033564882619, 0.023108336176457148, 0.027722435371418084, 0.02607779880054295, 0.032220011443964074, 0.02164744688863201, 0.020808857333447252, 0.046534199600241015, 0.02963362933535661, 0.11422816770417349, 0.03013339073264173, 0.1012766712478229, 0.05600372236222029, 0.033295676045651944, 0.06650345466498818, 0.2571270726621151, 19.938997098377772, 52.93410750797817, 51.429030418395996, 32.97236027036394, 24.796319450650895, 32.238206659044536, 45.471985408238, 45.38243702479771, 47.62317201069423, 6.990150077002389, 0.04305734884526048, 0.4647030127899987, 3.3844584141458784, 2.11611231310027, 4.5781320078032355, 33.11540978295462, 47.8493914604187, 49.28637967790876, 43.47255093710763, 47.62593044553484, 47.237890924726216, 48.589794976370676, 38.53523050035749, 46.618504183632986, 47.85475546973092, 44.305956091199604, 42.50834941864014, 41.90135478973389, 38.35838147572109, 38.86352940968105, 38.84429679598127, 37.18869740622384, 39.292573724474224, 40.07787649972098, 39.56312962940761, 40.65220417295183, 39.56978600365775, 37.27882596424648, 35.19611038480486, 34.35451330457415, 32.56152718407767, 32.219408307756694, 33.68269198281424, 34.42919601712908, 33.94568477358137, 34.11596427645002, 35.86437770298549, 35.0415164402553, 35.04658167702811, 33.72764335359846, 33.05075332096645, 34.859056745256694, 36.19172818320138, 34.9281461579459, 33.96138422829764, 36.17542423520769, 34.50921147210257, 34.03267969403948, 34.575862067086355, 35.411007744925364, 35.01859780720302, 34.64181784221104, 40.7304721559797, 45.937393120356965, 51.49549341201782, 42.57481241226196, 43.04687302453177, 47.292875494275776, 47.421295574733186, 42.83159351348877, 38.55563735961914, 42.862846510750906, 47.293771811894004, 48.89048521859305, 42.92360850742885, 39.87586457388741, 44.96997806004116, 46.81116036006382, 47.1394488470895, 47.24684367861067, 43.4741142817906, 41.63428340639387, 40.18175554275513, 37.84851918901716, 35.08170134680611, 35.15721089499337, 34.73835611343384, 33.5646698815482, 34.171945912497385, 35.41352646691458, 35.70464556557791, 36.609912463596885, 34.19495139803205, 34.89377689361572, 33.856574126652305, 36.08419786180769, 34.982394218444824, 36.30645336423601, 34.54188190187727, 35.57872336251395, 34.98249844142369, 31.840637683868408, 34.57165493283953, 34.2204304422651, 35.20574058805193, 35.66485670634678, 34.85893862588065, 37.1115654536656, 35.394578729357036, 36.22429438999721, 34.149683884211946, 34.22678109577724, 33.706225531441824, 34.85695491518293, 36.02410636629377, 38.05964715140206, 42.608636243002756, 42.823922702244346, 44.32082871028355, 47.75851944514683, 48.13656745638166, 44.792878900255474, 46.74261290686471, 53.69509506225586, 46.95949397768293, 50.42000954491751, 50.31290306363787, 50.58120427812849, 44.91444458280291, 39.362086977277485, 46.786518573760986, 49.029108728681294, 55.26148305620466, 46.72078514099121, 2.909665639911379, 2.298204622098378, 5.990746378898621, 3.538136716399874, 0.09478322682636124, 0.031513110268861055, 17.440895625523158, 58.45799486977713, 47.685837813786094, 39.99714538029262, 31.299643993377686, 33.28603669575283, 46.51449659892491, 55.864948000226704, 24.450200148991176, 0.3445971576230866, 0.052480775330747874, 0.0370051557464259, 0.049182090908288956, 0.032206746084349494, 0.03652781993150711, 0.06489392210330282, 0.026699418301827142, 0.08603529552263872, 0.04784883405747158, 0.0020277968142181635, 0.019263459901724542, 0.09515273664146662, 0.15938332969588892, 0.08294842937695128, 0.10134987839098487, 0.14716815230037483, 0.17174991539546422, 0.11033257602580956, 0.09157995121287447, 0.1549601498991251, 0.12756283288555487, 0.19062616250344686, 0.13182255359632628, 0.17012311411755426, 0.12939224472003324, 0.330897969858987, 23.144838605608257, 59.42765767233712, 57.26848758969988, 41.1665688923427, 30.23112916946411, 33.42157173156738, 48.272554125104634, 50.614506993974956, 53.106996059417725, 9.273819719042097, 0.17587246346686566, 2.194111053432737, 6.533227852412632, 5.512044157300677, 6.934724731104715, 33.88673278263637, 51.48650244304112, 51.841857637677876, 45.707157611846924, 50.318517208099365, 49.285608427865164, 49.39613689695086, 39.75322192055838, 47.654737676892964, 50.664558342524934, 46.8702825818743, 45.56710277284895, 44.30611589976719, 39.95503234863281, 41.36424861635481, 42.48054620197841, 39.54451193128313, 42.24099315915789, 41.7865184375218, 41.20260919843401, 43.053567613874165, 41.71107489722115, 38.48050301415579, 36.059993812016074, 35.67611973626273, 34.926381315503804, 34.52250337600708, 36.16779858725411, 36.87293304715838, 36.042355809892925, 35.8579888343811, 38.888907705034526, 37.09176656178066, 35.24752358027867, 35.91914340427944, 34.0185991695949, 37.63396576472691, 37.963112354278564, 37.223681586129324, 36.641582352774485, 39.97749934877668, 35.78477566582816, 35.048030376434326, 35.44046810695103, 37.683072158268516, 38.19946575164795, 36.6920679637364, 42.89257090432303, 48.544214793613975, 51.914101532527376, 43.205861704690115, 43.746810231889995, 49.85739653451102, 49.66158240182059, 42.697215352739605, 41.19758217675345, 43.811056750161306, 51.03262179238455, 49.04777159009661, 44.05036660603115, 39.5459988457816, 47.69686113085066, 48.05896650041853, 49.43244123458862, 48.57925803320748, 45.75476666859218, 43.43255363191877, 42.87156997408186, 41.33353410448347, 37.01207767214094, 38.063520772116526, 37.56063447679792, 35.657835551670615, 35.76158605303083, 38.304404394967214, 35.53399780818394, 38.057593958718435, 35.01231663567679, 36.87879037857056, 35.647399357386995, 39.22165693555559, 36.74551350729806, 38.527104582105366, 36.6254277910505, 38.43757356916155, 35.97106729234968, 33.107266494206016, 36.101481505802695, 36.46158579417637, 36.904470920562744, 36.73414625440325, 37.32235295431954, 38.599886962345664, 36.38759095328194, 37.356468609401155, 35.990536144801546, 34.664298738752095, 34.598836285727366, 36.836065905434744, 38.94020972933088, 40.26353236607143, 44.687481675829204, 43.85716152191162, 45.891149384634836, 49.614049775259836, 50.158364704677034, 45.56149557658604, 46.54523542949131, 55.68073388508388, 49.70608213969639, 51.65140404020037, 54.203564235142295, 53.08848605837141, 48.29559782573155, 41.26397916248867, 47.80340133394514, 52.963130133492605, 56.474301542554585, 49.76360280173165, 3.333272772175925, 3.4357862770557404, 10.476926360811506, 5.964823518480573, 0.4010282281254019, 0.10243900173476764, 19.246162687029155, 62.13024984087263, 53.35760021209717, 48.701640129089355, 35.76196125575474, 36.26108857563564, 54.1176358631679, 63.53185435703823, 32.16109555108206, 0.7859130767839295, 0.22999522568924086, 0.12830502805965288, 0.1648101984922375, 0.12506578330482754, 0.13682425234998974, 0.13571065424808434, 0.13924523815512657, 0.09224601475788013, 0.13792585395276546, 0.12404975853860378, 0.1907477288373879], [0.017040333211688057, 0.08505114154624087, 0.07753157575747796, 0.030903483874031475, 0.05896881861346109, 0.021607104589098265, 0.03940794663503766, 0.06331482183720384, 0.01987690814504666, 0.031020100295011486, 0.02422514544533832, 0.0446092703911875, 0.09117390907236508, 0.04408443373228822, 0.07229177906577076, 12.337084191186086, 45.863968031747, 44.11932747704642, 36.64276702063424, 13.906243647847857, 26.44316758428301, 40.852882044655935, 40.5311735016959, 46.670038972582134, 11.8701365845544, 0.030865390918084552, 0.1060409438131111, 1.197769773857934, 0.5347462828670229, 2.02789711526462, 23.970222064426967, 44.08126524516514, 48.83434724807739, 45.069601331438335, 47.788361958095, 46.939642974308555, 47.299973079136436, 47.290009362357004, 47.814699104854036, 44.439385822841096, 43.681219237191335, 39.98036895479475, 35.690474714551655, 33.17318058013916, 33.624264580862864, 32.713512080056326, 36.11485678809029, 34.89018814904349, 35.654601165226524, 35.40700210843767, 34.64267594473702, 31.35697705405099, 32.43895401273455, 31.336622306278773, 31.277816227504186, 31.08514268057687, 31.60324205671038, 32.83065523420061, 31.525220734732493, 31.354576451437815, 33.8505847794669, 32.38336147580828, 31.86942059653146, 30.635173865727015, 32.584025451115195, 31.766945089612687, 33.39054455075945, 33.213282108306885, 34.58508580071585, 31.286748136792863, 34.406725542885916, 32.88074827194214, 31.742296355111257, 30.960287025996617, 32.82166426522391, 31.96284260068621, 33.85608775275094, 42.114848613739014, 47.102272510528564, 41.120891434805735, 34.50691161836897, 49.613851751599995, 50.07723406382969, 46.11404064723423, 42.499678066798616, 39.7774954523359, 41.201876163482666, 46.21370560782296, 47.8307911327907, 43.50737530844552, 36.94144228526524, 44.25141273226057, 43.50714601789202, 45.53102772576468, 43.39322682789394, 40.77857106072562, 38.27374199458531, 37.49207312720162, 33.07835503986904, 32.34885324750628, 31.00596100943429, 33.62927770614624, 33.322358403887065, 34.23324639456612, 33.82273292541504, 35.00197076797485, 33.96268006733486, 33.680201053619385, 33.480297906058176, 32.756156648908345, 33.266123158591135, 32.9806946345738, 32.50189774377005, 34.603807721819194, 33.77684007372175, 31.416366781507218, 31.46238817487444, 32.10581568309239, 32.69809750148228, 31.825653893607004, 32.567579065050396, 32.61499357223511, 34.06706632886614, 30.96965319769723, 33.64472355161394, 33.424069608960835, 33.81475291933332, 31.447129930768693, 33.99273450034005, 33.539677211216514, 35.209471770695274, 36.30352469852993, 38.47958585194179, 41.463923999241416, 42.77289860589163, 45.92391014099121, 48.364798409598215, 39.757925851004465, 43.017044407980784, 49.246309416634695, 45.45674106052944, 49.69784852436611, 48.92600788388933, 47.85862561634609, 40.819610595703125, 43.658915519714355, 48.80783987045288, 53.22641127450125, 38.22492395128523, 1.0655413206134523, 1.4533887888704027, 7.420044677598136, 2.9309566574437276, 0.16411183668034418, 0.08561660548938171, 17.29105598585946, 56.39325428009033, 42.49214621952602, 38.33505984715053, 19.426866224833898, 27.073555060795375, 39.484951972961426, 48.48395654133388, 15.79348816190447, 0.11251894477754831, 0.00024150696689113308, 0.054016744518386464, 0.014568650662632925, 0.06103254894592932, 0.03284325264394283, 0.021056286824334945, 0.03111872196729694, 0.04856690391898155, 0.09608876212899174, 0.03671691067782896, 0.10869375110736915, 0.08268220616238457, 0.029141057016594068, 0.019863736083997146, 0.01651592572618808, 0.07784517428704671, 0.03539404898349728, 0.03405478031241468, 0.03430252701842359, 0.02673246804624796, 0.0145346255241228, 0.023299884915884052, 0.0657675630812134, 0.03883222663508994, 0.08355802523770503, 0.06768107933125325, 14.29159595285143, 50.44979994637625, 49.76212630953108, 41.026830196380615, 18.699624334062847, 27.273480790002004, 44.46107462474278, 47.17068794795445, 50.06571742466518, 12.629936865397863, 0.06606033737105982, 0.18795034608670644, 1.7911221576588494, 1.7846844345331192, 2.8324513946260725, 27.394685166222708, 45.11303104673113, 51.021132946014404, 47.24237598691668, 51.7818877356393, 48.98703391211373, 48.40375001089913, 47.68682098388672, 50.65578276770455, 46.389272689819336, 46.159516607012065, 42.09713418143136, 38.87490013667515, 34.59852014269148, 35.317745549338206, 35.17160756247384, 37.396431173597065, 36.62083503178188, 37.95941243852888, 37.13562706538609, 36.447345461164204, 34.6528446333749, 34.19804334640503, 32.748155798230854, 33.19885417393276, 32.422924518585205, 32.85180902481079, 33.71845088686262, 33.62612669808524, 32.768580027988975, 34.65937941414969, 34.22593688964844, 33.4945000239781, 33.41134050914219, 34.36015524183001, 33.16782351902553, 35.206650802067344, 33.83348873683384, 36.05193042755127, 33.85082796641758, 35.42392444610596, 34.21069254193987, 33.88969618933541, 33.12215300968715, 34.4420918737139, 34.16124568666731, 36.04548249925886, 44.2380895614624, 48.15132543018886, 43.863321099962505, 34.46827616010393, 48.143265519823345, 53.147889682224815, 47.932120186941965, 43.616896288735525, 40.70238406317574, 42.3711051259722, 47.37984957013811, 48.49388551712036, 45.828865732465474, 39.70645012174334, 45.99245759419033, 45.55187232153756, 46.05237191064017, 45.12478045054844, 41.963103430611746, 39.48944745744978, 38.79099369049072, 35.423931394304546, 33.5471430506025, 33.867277826581685, 34.94956398010254, 35.57075725282942, 35.87978185926165, 35.34250545501709, 34.60581227711269, 35.763833795275005, 34.469728333609446, 35.11328785760062, 34.775911126817974, 35.223461968558176, 35.01828513826643, 34.003125531332834, 36.30802365711757, 34.617426191057476, 33.585934843335835, 33.62005397251674, 33.96843664986746, 34.396650654929026, 34.066468783787315, 33.619060380118235, 34.191644055502756, 36.633557183401926, 33.43845585414341, 34.75541046687535, 34.43369844981602, 33.71080786841256, 34.24922725132534, 35.768377917153494, 34.26498923982893, 35.92270088195801, 39.42283855165754, 40.26050295148577, 43.31185300009591, 46.114478383745464, 48.05266795839582, 48.83213077272688, 43.39239304406302, 46.431590693337576, 49.85885565621512, 48.11845350265503, 51.82141603742327, 50.656189237322124, 49.682607650756836, 43.752393109457834, 46.13556964056832, 51.10316685267857, 56.749349457877024, 41.04299865450178, 0.8735115677118301, 2.4765570632049014, 5.414020708629063, 2.788267582654953, 0.047134631845567904, 0.0786304564348289, 18.265841347830637, 61.65537520817348, 47.33471754619053, 45.88689361299787, 23.37545452799116, 29.394847461155482, 45.29976388386318, 54.69250896998814, 19.467118876320974, 0.14687265029975347, 0.07063586185021059, 0.04098103168819632, 0.011010513108755862, 0.018383428820275834, 0.04864238076178091, 0.05227094855425613, 0.05691613483109644, 0.05472056853717991, 0.05991466250270605, 0.05776089735861335, 0.02742789519418563, 0.15362312378627913, 0.12478930742612906, 0.15947757820997918, 0.12551742978394032, 0.1873385382017919, 0.13310604329620088, 0.16219735012522765, 0.20666701532900333, 0.20618843100965023, 0.13737307861447334, 0.11300223134458065, 0.19943138930414403, 0.1822464857250452, 0.1436982870634113, 0.17341257046375955, 16.02586545263018, 58.27019548416138, 56.23682253701346, 48.23466559818813, 22.536242416926793, 35.40468488420759, 52.8436975479126, 49.424631459372385, 56.921848910195486, 14.131517274039131, 0.09936951965625797, 0.34951992918338093, 5.560062723500388, 4.428224188940866, 2.8747663583074297, 27.132246494293213, 46.38738972800118, 52.30249541146414, 50.29720360892159, 53.84102807726179, 49.96510056086949, 49.21330199922834, 51.153576033455984, 52.569709232875276, 48.78588356290545, 49.55743932723999, 45.151590074811665, 40.2942989894322, 35.384382247924805, 37.2122483253479, 35.86720561981201, 38.956513677324565, 39.952537945338655, 39.270082405635286, 39.32593550000872, 36.79680163519723, 36.06011887959072, 35.03818825313023, 35.26621423448835, 35.50246688297817, 34.19710186549595, 34.39873858860561, 35.508900914873394, 35.7211023739406, 35.132982526506694, 37.44862256731306, 36.09925808225359, 35.61292239597866, 36.48610946110317, 36.440845421382356, 35.27400663920811, 37.53152847290039, 36.761855670383994, 37.76278189250401, 35.914887632642476, 36.89016457966396, 34.99084670203072, 34.75219692502703, 34.188684122903005, 36.18818807601929, 35.90166868482317, 37.49214260918753, 46.712624481746126, 49.80145311355591, 43.336539949689595, 37.559821537562776, 47.508856773376465, 52.29470648084368, 50.218622956957134, 46.42332233701433, 42.33624253954206, 43.770520959581646, 47.83328206198556, 49.78221355165754, 48.49564688546317, 39.65177127293178, 46.808221272059846, 48.15011296953474, 47.99197891780308, 47.41556331089565, 43.06493139266968, 43.21979979106358, 41.056019578661235, 37.34808560780117, 35.32369668143136, 35.16247068132673, 36.56610059738159, 36.20136533464704, 37.210997649601524, 36.97808013643537, 37.456216948372976, 37.51361949103219, 36.85749762398856, 37.07930844170706, 36.26456962312971, 36.0953288759504, 37.03068494796753, 36.948890754154746, 39.04207379477364, 36.97921616690499, 35.19510637010847, 34.67610720225743, 35.54826940808977, 36.86275741032192, 35.21986974988665, 35.3681651524135, 36.71171399525234, 37.967965670994346, 34.34951754978725, 37.110054220472065, 35.7410888671875, 36.4521883555821, 35.51384803227016, 38.64268439156668, 36.28393425260271, 38.61199767248971, 40.27392339706421, 42.33796569279262, 45.70618486404419, 47.352418082101, 50.49771819795881, 51.52083349227905, 45.39150789805821, 46.907042026519775, 52.089265619005474, 50.06649562290737, 54.00812530517578, 52.669996057237896, 53.627631528036936, 47.18713433401925, 48.96372617994036, 53.55195869718279, 58.11173834119524, 43.87442084721157, 1.9320121918405806, 3.592216065951756, 16.98329595157078, 7.5085369348526, 0.21291434152850083, 0.1884227693080902, 20.807464599609375, 68.10404000963483, 54.27415793282645, 51.08525787081037, 29.573280675070627, 39.56757995060512, 52.421726499285015, 63.58906582423619, 24.803872142519268, 0.5203745311924389, 0.2621248630540711, 0.13520410071526254, 0.06652368857924428, 0.07797318670366492, 0.18803209598575318, 0.1481437770915883, 0.19050577682043823, 0.11346190489296402, 0.16669615943517002, 0.15048468219382422, 0.20159882014351233], [0.026760985176744204, 0.015114228440714734, 0.0469208186758416, 0.007449628336222044, 0.07009031290986709, 0.039502653160265515, 0.09492182438927037, 0.048342770231621604, 0.01720701703535659, 0.04015054214479668, 0.02761925564014486, 0.06678902969828673, 0.05126949532755783, 0.008927955125857676, 0.04209731000342539, 5.925319969654083, 42.440809454236714, 44.70655100686209, 39.56752436501639, 33.55919817515782, 26.179382698876516, 36.696129185812815, 39.41747454234532, 45.78757953643799, 16.96522889818464, 0.03412179921620658, 0.13955621075417313, 1.6995364321129662, 1.7233408519199915, 1.107166349887848, 14.205862130437579, 35.01556144441877, 51.23289319447109, 46.52793094090053, 48.673607621874126, 47.85870552062988, 48.179281507219585, 47.29090567997524, 45.02066516876221, 43.78400393894741, 41.17432655606951, 36.16785764694214, 33.03681523459298, 33.23901128768921, 33.58168601989746, 33.017672947474885, 33.26702989850725, 33.03271232332502, 31.88338300159999, 30.828761100769043, 31.710213048117502, 30.611080987112864, 30.864158698490687, 31.160353456224712, 32.686712878090994, 30.934196540287562, 32.55675029754639, 31.9801436151777, 31.920872007097515, 32.62010397229876, 31.69178989955357, 31.037141050611222, 32.127320357731406, 30.78440032686506, 32.063924993787495, 33.064090388161794, 32.945418630327495, 33.746900285993306, 33.52791043690273, 33.926684924534385, 35.021359716142925, 34.004362310682026, 31.76626764025007, 32.953367369515554, 32.5452093396868, 31.766410078321183, 34.61527919769287, 43.8016072000776, 44.97686719894409, 38.8730206489563, 37.670207568577354, 42.99947588784354, 46.36693770544869, 42.621222904750276, 41.79057618549892, 40.24303865432739, 41.55795744487217, 46.870289530072895, 47.523614747183665, 41.37104395457676, 37.30576065608433, 44.91062307357788, 42.63306958334786, 44.91454880578177, 41.036383969443186, 38.63417632239205, 38.79122298104422, 34.89119563783918, 32.934603759220664, 32.23729297092983, 31.210311004093715, 33.21207659585135, 32.75760187421526, 33.372857911246165, 33.74001809528896, 33.952719824654714, 33.99598625728062, 33.63078546524048, 32.72232934406826, 35.14769533702305, 33.51527166366577, 33.443774700164795, 33.8871670450483, 32.27495220729283, 32.734005791800364, 34.53262690135411, 33.1601561818804, 32.27902037756783, 32.74181209291731, 34.35492672239031, 34.89473227092198, 33.444417408534456, 31.95494944708688, 33.61952938352312, 32.21388448987688, 32.882596492767334, 32.670120579855784, 31.755595207214355, 32.025070667266846, 33.42861720493862, 34.171747888837544, 33.45194925580706, 36.347777775355745, 40.01484939030239, 42.98294612339565, 44.03581707818167, 46.279501574380056, 45.658735615866526, 42.649338790348594, 48.1391487121582, 46.801137583596365, 46.89429555620466, 47.73017079489571, 48.56566040856497, 40.845020157950266, 48.21352570397513, 49.18063851765224, 57.29899365561349, 31.44598695210048, 0.6013602912425995, 2.5145921536854337, 3.2957338265010288, 2.8038890872682845, 0.0679280050098896, 0.12834601157477923, 20.614495754241943, 52.85314014979771, 43.500086648123606, 34.44741766793387, 25.021679060799734, 32.85357386725289, 40.29007795878819, 49.38013866969517, 14.437396083559308, 0.25638432108930176, 0.03621981931584222, 0.04635937166001115, 0.05167672151167478, 0.02180182547973735, 0.014763123887990202, 0.022653637986098017, 0.02848450992522495, 0.058802319690585136, 0.028934076694505553, 0.055108205415308475, 0.04110863698380334, 0.06053031089582613, 0.024967478022777607, 0.07750495682869639, 0.01627947323556457, 0.020376593207142184, 0.05225250257977417, 0.0663109610655478, 0.08157874537365777, 0.042056947347841094, 0.039756849341626675, 0.06993336097470351, 0.03805392661264964, 0.02516333037056029, 0.0855177157957639, 0.021053621878049204, 7.655353239604405, 48.65612595421927, 49.47445351736886, 44.301422391619, 30.41903277805873, 29.120228597096034, 41.29896681649344, 42.89528070177351, 53.04407664707729, 18.158309289387294, 0.04670163829411779, 0.05002426143203463, 0.8227278898869241, 2.3330947841916765, 1.906872740813664, 16.103577579770768, 37.62933826446533, 52.215691566467285, 48.631664821079795, 50.87910829271589, 49.39553587777274, 50.54098463058472, 47.7857529095241, 45.53175728661673, 45.09801251547677, 42.84654256275722, 37.7212108203343, 35.32614592143467, 34.87653146471296, 34.68603965214321, 35.00674418040684, 34.877056053706575, 34.101928915296284, 34.01989500863211, 32.77085556302752, 32.81311103275844, 32.40655108860561, 31.22274480547224, 31.935039384024485, 34.08540609904698, 32.30294302531651, 34.16460861478533, 32.397139753614155, 33.330831732068745, 33.07605518613543, 33.620509079524446, 33.79675708498274, 34.20880610602242, 33.238177503858296, 33.64621046611241, 34.42246668679373, 35.72176245280674, 35.540991170065745, 35.75719479152134, 34.74178157533918, 35.828917571476524, 36.84367070879255, 33.57032224110195, 33.48079470225743, 34.398637839726035, 34.16879143033709, 37.35827166693551, 44.833473750523154, 48.269038336617605, 42.23180416652134, 38.502355098724365, 43.74373912811279, 46.66723190035139, 44.943314347948345, 43.951670919145855, 41.485737868717735, 42.78227867398943, 48.45377704075405, 48.99559409277779, 44.67936617987496, 40.24244458334786, 48.24319798605782, 44.843902996608186, 46.873812266758506, 42.92811441421509, 40.73312636784145, 39.81175354548863, 37.67987598691668, 34.760579926627024, 34.88420227595738, 33.719381945473806, 33.88789313180106, 34.33105271203177, 34.30151244572231, 36.07522426332746, 35.62693343843733, 35.460864543914795, 35.42391402380807, 35.03369624274117, 36.29404388155256, 34.57384014129639, 35.88601091929844, 34.83172600609915, 35.31281232833862, 34.89522211892264, 35.27033451625279, 34.801313740866526, 34.97074556350708, 36.26629625047956, 36.40518726621355, 36.29483945029122, 36.05921561377389, 34.115992069244385, 35.42724915913173, 33.27010447638375, 34.367819104875835, 33.937798568180625, 33.45552410398211, 34.749577454158235, 34.71331133161272, 36.32963602883475, 35.316963876996724, 39.35263047899519, 42.10989107404436, 44.85233463559832, 46.40987409864153, 48.39880984170096, 47.93206112725394, 44.2955824307033, 49.623162337711875, 48.95412029538836, 49.51679583958217, 50.63280507496425, 51.0027688571385, 41.94276605333601, 49.84608834130423, 52.59126949310303, 58.46902860913958, 34.701488971710205, 0.630617907004697, 3.6458995853151595, 3.9807185104915073, 3.3419004806450436, 0.09951908234506845, 0.07311009908361094, 23.258406911577495, 59.081922258649556, 47.65951803752354, 37.72898585455758, 26.994892767497472, 39.152199268341064, 46.399785314287456, 55.76496689660208, 19.04162856510707, 0.31095384433865547, 0.028885632686849152, 0.017432718138609613, 0.031202945126486675, 0.027740007732063532, 0.024043947757620896, 0.04014373643855963, 0.030577949913484708, 0.07336116382586104, 0.03617687483451196, 0.021400392288342118, 0.04218162137216755, 0.12002179824880191, 0.06154219659843615, 0.1544218816395317, 0.0901566832991583, 0.12777594716421195, 0.14171925825732096, 0.24823278135487012, 0.22352384722658566, 0.11892197440777506, 0.1153839435428381, 0.22700262841369423, 0.13046293226735933, 0.13134452567568847, 0.2277031343962465, 0.09393719543835946, 8.719396029199872, 55.415333543504985, 55.303728103637695, 50.97933258329119, 43.877050740378245, 36.72413737433297, 46.463104248046875, 47.97070005961827, 56.960008416857036, 20.52515060561044, 0.12712040091199533, 0.2763722256890365, 4.6777934942926676, 5.245048335620335, 1.824063024350575, 16.902425868170603, 37.361665861947195, 55.02252755846296, 49.556011472429546, 52.78972741535732, 51.69898877825056, 51.71976736613682, 51.72520433153425, 48.41582945414952, 47.57047687258039, 43.82496009554182, 40.19493280138288, 37.23136281967163, 36.69292606626238, 37.449432032448904, 37.5554233278547, 36.82390308380127, 35.14057690756661, 35.193129607609336, 34.31972367422921, 34.80980096544538, 34.014659540993826, 33.629051889692036, 33.51235342025757, 35.33838169915335, 34.271263463156565, 35.9328522000994, 34.30724818365914, 35.57410281045096, 35.04859318052019, 34.12298195702689, 34.65934467315674, 35.78410863876343, 35.36104324885777, 35.94434452056885, 36.785483019692556, 36.976176330021445, 38.44206210545131, 37.513737610408235, 37.33687121527535, 38.569891589028494, 37.72064106804984, 35.77795948301043, 35.52782433373587, 35.46386963980538, 35.14715337753296, 38.137136936187744, 47.30794961111886, 48.227981431143625, 43.123212882450645, 39.354735783168245, 45.55218846457345, 49.982061113630024, 45.66525650024414, 44.834436076028005, 43.807711192539756, 45.12906401497977, 49.86957325254168, 51.19041190828596, 45.645252636500764, 41.062870502471924, 48.7326568875994, 46.798399993351524, 48.18237345559256, 44.39238820757185, 40.75338384083339, 44.87088285173689, 38.66622141429356, 36.479845660073416, 36.09665250778198, 34.29685715266636, 36.55796078273228, 35.465742179325645, 35.9864228112357, 36.77271917888096, 36.792309624808176, 36.25680848530361, 38.078869342803955, 37.14412818636213, 39.49891785212925, 37.84177943638393, 37.6058464050293, 36.688194343021934, 36.63149356842041, 37.27430963516235, 38.339850630079, 38.133725370679585, 37.069653919764924, 38.63308892931257, 38.29137304850987, 38.446161542619976, 37.50468063354492, 36.03846134458269, 36.61006532396589, 35.60941355569022, 36.36559643064226, 35.53038821901594, 35.48164313180106, 36.52901111330305, 38.41552693503243, 39.04090302331107, 37.1157934325082, 41.57934052603585, 43.62455667768206, 47.06421722684588, 48.16999176570347, 50.72581366130284, 50.095417499542236, 45.982174260275706, 51.6249418258667, 50.35870558874947, 50.381002358027864, 51.78717878886631, 53.671825545174734, 44.640233925410676, 53.539973054613384, 55.347546918051584, 60.238317898341585, 35.805012294224326, 1.1310808552162988, 7.295866472380502, 9.94699593952724, 6.398010262421199, 0.3796494895858424, 0.1871940509549209, 25.226551907403127, 63.290605953761506, 53.67912115369524, 47.12200192042759, 36.690014771052766, 46.03571707861764, 52.83136796951294, 65.02389662606376, 23.848133529935563, 0.6596224020634378, 0.09327994606324605, 0.13370136278016226, 0.18752166123262473, 0.04504134452768734, 0.13407102865832193, 0.10881824192724057, 0.1790577918291092, 0.13901768465127262, 0.07506885326334409, 0.1146484115826232, 0.13702370093337127], [0.04170017363503575, 0.040113996248692274, 0.019485174611743008, 0.037868974929941554, 0.043813406489789486, 0.029578223558408872, 0.06148167127477271, 0.03542668651789427, 0.04024205955543688, 0.07007130035864455, 0.009273699251934886, 0.023048372340521643, 0.02420226015549685, 0.005875520391522774, 0.05094569502398372, 3.283582947083882, 37.18852022715977, 46.59449815750122, 41.603964941842214, 25.104484217507498, 20.294828244618007, 29.62703193937029, 38.04697016307286, 46.082777227674214, 24.988768918173655, 0.11357992927410773, 0.06259537794228111, 0.6607050725391933, 1.2157296729939324, 0.5209532401391438, 4.336221354348319, 20.063362904957362, 38.37826027188982, 48.722613266536165, 45.88676854542324, 46.73389639173235, 45.57449565614973, 41.71245411464146, 42.74853474753243, 39.27872249058315, 35.83695663724627, 34.32807888303484, 33.25071552821568, 32.182912894657676, 33.04470491409302, 31.088752269744873, 32.17312288284302, 31.238736084529332, 31.86355631692069, 31.059479509081157, 34.02144793101719, 32.229931354522705, 32.78286552429199, 33.57868092400687, 33.25762203761509, 31.461978231157573, 30.899761268070765, 33.17009905406407, 31.67944642475673, 32.36706795011248, 34.58101415634155, 33.16455091748919, 32.65595667702811, 31.472032274518693, 32.68225908279419, 32.78924397059849, 33.57300771985735, 35.358871936798096, 32.96591929027012, 33.18710824421474, 34.29835796356201, 32.253513540540425, 32.83052321842739, 31.161913326808385, 33.372256892068044, 32.00447620664324, 35.328591687338694, 43.775502817971365, 43.35028348650251, 38.487246240888325, 40.2012174470084, 43.658606324877056, 47.78586755480085, 44.54900407791138, 40.902850014822825, 41.46919073377337, 42.68662282398769, 45.469661235809326, 46.99618741444179, 40.386779512677876, 37.21474967684065, 44.52816295623779, 44.54508529390608, 43.03023208890642, 43.789652824401855, 38.065285614558626, 37.81716891697475, 35.40017897742135, 34.15827533176967, 33.2360200881958, 31.43447378703526, 32.77222783224923, 32.619742665972026, 33.98255886350359, 34.6471505846296, 34.552596024104524, 32.01339421953474, 33.86685051236834, 32.464735303606304, 33.48254564830235, 33.3520758492606, 32.92446633747646, 32.0985061781747, 31.4780980518886, 31.973685264587402, 32.675352573394775, 31.840523038591655, 33.64047820227486, 33.976069246019634, 34.10815102713448, 33.44690833772932, 35.02303770610264, 36.04148728506905, 34.23589365822928, 33.62280893325806, 32.68444081715175, 31.735396793910436, 30.952980995178223, 31.872668879372732, 33.222106320517405, 30.842011315482004, 33.69553572790963, 34.706908566611155, 38.89432035173689, 39.312136377607075, 43.94442047391619, 44.77167647225516, 48.58840881075178, 46.269457953316824, 46.80836023603167, 48.97715009961809, 47.86240891047886, 48.86119508743286, 52.29511295046125, 47.1971640586853, 46.25101048605782, 49.168559074401855, 54.89931862694876, 25.071370840072632, 0.3455836661159992, 2.0009153059550693, 2.3371486238070895, 1.4774086028337479, 0.027457187550940683, 0.20147600530513696, 19.390653950827463, 55.438512734004426, 38.51205825805664, 35.679062298366, 19.13559947695051, 29.024769033704484, 42.79943377631051, 44.36461278370449, 8.61539191859109, 0.09585485753736325, 0.037635202652641704, 0.061020342100943835, 0.009252947954727071, 0.07112100760319404, 0.029137847545955862, 0.027998351458726183, 0.04991090876449432, 0.043697136121668985, 0.017278573642085706, 0.0712132001561778, 0.02949685024629746, 0.04120703134685755, 0.04472485204626407, 0.06938345583954028, 0.09134547665183033, 0.06781041489115783, 0.015045218036643096, 0.11176492273807526, 0.05451593255358083, 0.03595192351245454, 0.041935258877596686, 0.03019647752600057, 0.045564454314964156, 0.04610322129779628, 0.01049007844579007, 0.031991518169109306, 4.363709730761392, 43.424855027879985, 52.64450659070696, 48.154577187129426, 31.306508813585552, 25.051170689719065, 37.16834960665022, 41.99940429415022, 50.209809167044504, 26.835054670061382, 0.07067628896662168, 0.030371556524187326, 1.2587668150663376, 2.7160536519118716, 1.0500183935676302, 6.426242964608329, 23.707486357007706, 40.685520785195486, 49.112699031829834, 47.663534096309114, 47.843707833971294, 46.91659927368164, 43.88755989074707, 44.590547357286724, 42.87927205221993, 37.40189593178885, 36.900149141039165, 34.89426326751709, 34.869364397866384, 34.78202206747872, 32.15509230749947, 32.8767044203622, 33.685596329825266, 32.41708108357021, 33.39419930321829, 34.82535450799124, 33.41317483357021, 34.64773423331124, 34.08503784452166, 33.71107537405831, 32.9232052394322, 33.8085481779916, 34.53854676655361, 32.93497201374599, 34.085583278111045, 33.98402493340628, 35.65270430701119, 35.31771428244454, 32.565890652792795, 35.483081408909385, 34.22762182780674, 35.19043370655605, 36.19262102672032, 34.78356804166521, 33.48939309801374, 34.844840730939595, 33.88120896475655, 34.33409602301461, 33.289465631757466, 34.002600942339214, 33.96005712236677, 36.42821707044329, 45.27481290272304, 46.370905126844136, 42.24625641959054, 41.56256410053798, 45.03874090739659, 48.928589139665874, 46.649253436497276, 42.94551617758614, 42.49972670418875, 44.09404298237392, 48.275496687207905, 46.920823778424946, 42.71293912615095, 39.46979795183454, 48.515497888837544, 46.2963787487575, 45.77559041976929, 43.67945439474923, 41.66228812081473, 39.563105310712544, 37.84576422827584, 34.26471478598458, 35.06593241010393, 34.19100482123238, 33.96318728583199, 35.141507966177805, 35.15108953203474, 35.809935092926025, 36.022289412362234, 34.58930335726057, 34.75402430125645, 33.194303103855674, 35.72044924327305, 35.94872188568115, 36.10737705230713, 34.23958315168108, 34.41533783503941, 34.453500815800254, 34.175538131168906, 33.47303703853062, 36.19861037390572, 34.55856452669416, 35.19156626292637, 36.95067644119263, 36.37032815388271, 37.46115364347185, 36.9031994002206, 35.77281434195382, 34.74011400767735, 33.37722485406058, 34.108891010284424, 33.54002809524536, 34.09167684827532, 33.0404943057469, 36.11679186139788, 36.706735610961914, 40.065800530569895, 41.51663303375244, 46.74057361057827, 47.389146259852815, 50.91280010768345, 48.15993077414376, 47.94883755275181, 50.36595950807844, 48.66061101640974, 50.46479415893555, 53.49270445959908, 49.34081186567034, 49.944829191480366, 52.38639143535069, 56.09931768689837, 28.195294822965348, 0.6564481609633991, 4.013695095266614, 4.435125921453748, 2.8453166357108524, 0.012249855623979653, 0.1374134650187833, 21.993676696504863, 59.13571521214077, 45.07625423158918, 47.18065166473389, 26.334207671029226, 33.43097264426095, 47.36139515468052, 52.183868816920686, 11.41748229094914, 0.12993473346744264, 0.012028868642768689, 0.04155133019334503, 0.025858335130448853, 0.025246076019746915, 0.014836134255996771, 0.05895251341696296, 0.035176242635186226, 0.04372319186638508, 0.017082777273442065, 0.022840068875146762, 0.04637319341834102, 0.09593753024403538, 0.10182941265936409, 0.1240810254322631, 0.13023027618016514, 0.20336919943136827, 0.06377607637218066, 0.18600932881236076, 0.12678479749177182, 0.2252829492624317, 0.13657892122864723, 0.1693151281880481, 0.1544008334832532, 0.14315776606755598, 0.14124774427286216, 0.09351338925106184, 4.9068847213472635, 47.90896531513759, 61.90539918627058, 54.215202467782156, 35.18845694405692, 29.78364780970982, 39.89197744641985, 48.061603341783794, 54.102183069501606, 30.756687436785015, 0.23130794667771884, 0.2612016483076981, 3.1668212924684798, 6.387178020817893, 1.5930112110716956, 6.056703891072955, 24.02573296001979, 41.00284154074532, 50.96220874786377, 49.12487922395979, 50.00674111502511, 48.62794058663504, 46.45966836384365, 47.97862448011126, 44.275582041059224, 39.28591387612479, 40.69979585920061, 36.91576869147164, 36.858063902173726, 37.14696305138724, 34.04495021275112, 35.23154967171805, 34.90431383677891, 34.845921175820486, 35.59358903339931, 38.45581953866141, 35.45972156524658, 36.36977229799543, 35.801204681396484, 35.7935026032584, 35.19477980477469, 33.92077200753348, 37.474421228681294, 35.13958331516811, 35.54427766799927, 37.34568847928728, 36.893426758902415, 36.685675621032715, 34.35605927876064, 38.035651547568186, 36.10243688310896, 35.37100001743862, 38.58834947858538, 37.141998563494, 35.52598306110927, 37.404060295649934, 34.80101496832711, 36.42838035311018, 34.92022521155221, 36.041275365012034, 35.676008565085276, 38.43099709919521, 47.03663982663836, 48.00908538273403, 40.65257590157645, 42.284853662763325, 45.70143577030727, 50.23595871244158, 48.26783977236067, 44.34322622844151, 45.33637741633824, 46.325679302215576, 49.021517821720664, 48.714879921504426, 45.370006697518484, 41.083329473223, 48.93393577848162, 49.056050368717735, 46.79370648520333, 46.42058474676949, 42.320251260484966, 42.277846404484336, 41.48156200136457, 37.679754393441335, 37.927405561719624, 34.03275612422398, 36.95999050140381, 37.348478181021555, 36.92981794902256, 37.23749113082886, 37.98433215277535, 36.54888296127319, 36.753257274627686, 35.4896057673863, 37.25712326594761, 38.641993045806885, 36.99238995143345, 37.08175073351179, 35.39494350978306, 36.120186056409565, 36.568938936506, 35.42622777393886, 37.66507979801723, 37.185136454445974, 38.31795685631888, 39.002201557159424, 39.00345223290579, 40.0820905821664, 39.70710672651018, 37.443060534340994, 36.94991908754621, 35.34258883340018, 35.21655893325806, 35.4803056035723, 37.925578185490195, 35.00667469842093, 38.80888877596174, 38.48379298618862, 42.65018994467599, 44.23238509041922, 48.408975056239534, 48.727873052869526, 53.81419760840279, 50.12262317112514, 50.28216423307146, 52.69326557431902, 50.23452738353184, 51.244465419224326, 56.54483618055071, 51.894782066345215, 52.2918507712228, 54.67142466136387, 57.52906240735735, 29.72439009802682, 1.2845383350338255, 5.1584003908293585, 10.291514549936567, 5.879535683563777, 0.16739477909037045, 0.28088722484452383, 23.364326987947734, 65.27658176422119, 51.264799322400776, 48.28300074168614, 29.07765177318028, 40.685006618499756, 53.421078954424175, 60.37085478646414, 15.659533841269356, 0.2068177315273455, 0.14774483921272413, 0.1757704389414617, 0.07969192947660174, 0.1840224832828556, 0.16604312376252242, 0.11167549860796758, 0.11389056939099516, 0.1586303458149944, 0.12388841648186956, 0.101695910894445, 0.23805177052106175], [0.05883364086704595, 0.055690758262893984, 0.04898603500000068, 0.004392736050899008, 0.03374570082607014, 0.08537476882338524, 0.02510004849838359, 0.042214974761009216, 0.03248388692736626, 0.038206909117954116, 0.004922139250473785, 0.0586280311856951, 0.03978196870801704, 0.04603517780612622, 0.011243871479694332, 0.7278074089969907, 26.781169652938843, 40.746532917022705, 39.165084702628, 30.12647192818778, 25.390456438064575, 29.72473750795637, 34.9266870362418, 46.050141538892476, 32.202277524130686, 1.1892214268445969, 0.04813567116590483, 0.2826346696487495, 1.4529311848538262, 0.7417548320123127, 0.8178667021649224, 7.128971610750471, 26.825954266956874, 46.3682404926845, 48.82451554707119, 44.76620476586478, 43.37720080784389, 39.28541360582624, 36.52616235188076, 33.91411910738264, 34.05146414893014, 33.67607382365635, 32.37448167800903, 32.5748781476702, 31.3191545350211, 31.833592210497173, 32.02007491247994, 32.55134807314192, 32.675265720912385, 32.66909224646432, 33.06590039389474, 33.823087283543174, 31.094300406319753, 31.98373235974993, 32.690530913216726, 31.40569087437221, 31.277097088950022, 33.20752552577427, 31.538547379629954, 33.32734373637608, 31.945329666137695, 33.17944090706961, 32.21591683796474, 32.09445537839617, 33.2798284803118, 30.794218131474086, 35.9413845879691, 39.34631109237671, 32.22098207473755, 34.95150947570801, 33.07146937506539, 35.699351038251606, 33.015307085854666, 31.841398511614116, 31.70424107142857, 33.81779970441546, 37.038664954049246, 43.35179819379534, 42.71117775780814, 36.691161223820274, 43.78918729509626, 45.072193009512766, 47.56004415239607, 44.95846142087664, 43.03254583903721, 41.80535500390189, 42.58394929340908, 45.07510083062308, 44.87509346008301, 40.45158188683646, 37.36568539483206, 41.51911701474871, 43.840194020952495, 45.56562628064837, 42.07290581294468, 37.53350870949881, 35.81751210348946, 36.07376514162336, 33.51173503058297, 32.42044401168823, 32.60518618992397, 31.82486527306693, 32.86114740371704, 33.989395890917095, 34.28460053035191, 35.69672809328352, 34.27736050742013, 34.02941056660244, 32.532403809683665, 33.393771989004954, 34.95508779798235, 34.32563311713082, 32.85623850141253, 32.71064247403826, 33.75908742632185, 32.56029735292707, 33.82438312258039, 33.59809766496931, 35.80314670290266, 35.7732902935573, 36.583707332611084, 35.30160140991211, 35.452933175223215, 34.654376711164204, 34.824506827763145, 35.25290148598807, 32.73815734045846, 33.06463582175118, 30.730527469090053, 32.37007999420166, 33.62484475544521, 32.428997244153706, 34.57716485432216, 35.614058426448274, 39.87115369524275, 41.25497777121407, 46.92265810285296, 45.3652263368879, 47.16502864020211, 43.80410507747105, 47.59786319732666, 47.45529311043875, 48.67125218255179, 43.26809671946934, 44.13580513000488, 50.62462704522269, 51.32184055873326, 48.18583018439156, 18.541360003607615, 0.8884121967213494, 2.8252517580986023, 2.422674651656832, 2.4317678894315446, 0.15298056469431945, 0.23382390024406569, 25.139418022973196, 54.095346042088096, 38.07873732703072, 34.56180933543614, 18.79364562034607, 29.321443217141287, 43.83912399836949, 41.18434238433838, 6.509316495486668, 0.04123919729941657, 0.08625217567064933, 0.06350758006530148, 0.03214578310559903, 0.03704264819888132, 0.030373052693903446, 0.06191411521285772, 0.0992199976795486, 0.02550587520402457, 0.02904413507453033, 0.0326754407558058, 0.02526562800630927, 0.058474030877862654, 0.08170750417879649, 0.021674527221226265, 0.06084057103310313, 0.011559415708429046, 0.057186354616922994, 0.022007099286253964, 0.013949268630572727, 0.0515856451487967, 0.08297325697328363, 0.032014659605920315, 0.061072819999286106, 0.061323294416069984, 0.04035804154617446, 0.040654442605695555, 1.3126185025487627, 32.57428755078997, 49.36408485685076, 44.24551371165684, 32.444474356515066, 26.074119227273123, 33.40154702322823, 39.68924290793282, 51.20503786631993, 34.450989042009624, 0.9378021636179515, 0.11513308914644377, 0.32929760430540356, 2.211574047803879, 1.8876329617840903, 2.353205910750798, 9.794106909206935, 29.18104444231306, 46.976999964032856, 50.007185799734934, 45.82843147005354, 44.14166246141706, 41.05161789485386, 39.155447551182334, 36.27918863296509, 35.59533303124564, 35.34811265127999, 34.51144879204886, 34.37830741064889, 34.44974531446184, 33.06627907071795, 33.81015321186611, 33.26097106933594, 34.069744859422954, 34.043703011104036, 34.11759015492031, 34.960972922188894, 32.49597787857056, 32.692483357020784, 33.292842456272666, 33.83800506591797, 33.76160614831107, 32.96683645248413, 34.0433486529759, 34.872838497161865, 32.786443846566335, 35.069628851754324, 34.72575208118984, 34.551560742514475, 34.66362476348877, 32.51056214741298, 38.38679265975952, 40.06592212404524, 33.378558908190044, 36.24116461617606, 35.19028084618704, 35.97842196055821, 35.04777329308646, 34.02842044830322, 35.04196112496512, 34.76389421735491, 37.34125552858625, 46.13938420159476, 45.81949608666556, 43.17948981693813, 45.85942390986851, 45.142164843423025, 48.361025537763325, 46.172662598746165, 45.929374899183, 44.24025045122419, 44.03543145315987, 46.067393915993826, 46.74270323344639, 42.23033462251936, 38.689508301871165, 42.92337226867676, 47.18575511659895, 46.101506096976145, 43.33932270322527, 41.35683488845825, 37.55778571537563, 35.546171052115305, 35.71195159639631, 34.58592653274536, 33.281676701136995, 33.253661564418245, 34.778287410736084, 35.26518937519619, 36.26606001172747, 36.20755965369088, 36.960244110652376, 35.11923204149519, 33.465557302747456, 35.32401977266584, 37.4146979876927, 35.62268808909825, 34.16647073200771, 33.25335584368025, 34.928132261548726, 35.37845196042742, 36.07466493334089, 35.93257427215576, 37.273177078792024, 37.19038929258074, 37.4579644203186, 36.70023904527937, 36.690911088671, 36.91598408562796, 37.2371506690979, 36.5592496735709, 34.85801451546805, 33.78036281040737, 33.640961102076936, 33.78073453903198, 35.35854884556362, 35.053352696555, 36.72533246449062, 38.717815262930735, 41.794199671064106, 43.03098596845354, 48.448704855782644, 47.701078687395366, 48.96731839861189, 46.53362498964582, 49.3869583266122, 49.4088590485709, 48.84937967572893, 44.762900897434776, 48.084115505218506, 52.501502241407124, 52.762288979121614, 49.670086996895925, 20.77517110960824, 1.4125905952283313, 3.0029371721403937, 5.1789509909493585, 3.1811328445162093, 0.16258180806679384, 0.045243710811649046, 26.341591869081768, 58.81832844870431, 46.451862062726704, 36.91033172607422, 20.222488812037877, 35.537037645067485, 49.31146614892142, 47.3696357182094, 8.018146480832781, 0.00458848916293521, 0.04987084466431822, 0.03974474427689399, 0.028406346083751748, 0.06398335524967738, 0.00329463484065075, 0.01539004105143249, 0.04421904490196279, 0.013454357062333396, 0.05932876108480351, 0.03224251845053264, 0.0541759729385376, 0.14167010518057005, 0.2111259674919503, 0.1526825385434287, 0.11542492705796446, 0.15717437251337937, 0.1829526371189526, 0.14789446975503648, 0.09037122250135456, 0.14280742486672743, 0.15930831086422714, 0.195382828691176, 0.1140391007065773, 0.15127928741276264, 0.2508096673658916, 0.17661670781672, 1.4475809633731842, 34.81195838110787, 56.14450529643467, 49.83199739456177, 42.315766198294504, 35.00473615101406, 39.044064453669954, 46.42690065928868, 54.33201905659267, 38.88261611121041, 1.4443920659167426, 0.20380230833377155, 1.199695076261248, 5.532049758093698, 2.981728013072695, 2.1743221495832716, 9.337928141866412, 29.475637640271867, 49.74425901685442, 52.388576643807546, 47.516145433698384, 46.12278495516096, 42.90582111903599, 40.955090045928955, 38.792880126408164, 38.497467041015625, 37.52413558959961, 35.42939962659563, 36.60775852203369, 35.25101157597133, 35.410920892442974, 35.270365783146445, 35.96324014663696, 36.5801568031311, 36.1571261542184, 36.11719485691616, 35.99616071156093, 33.71084608350481, 35.08133656638009, 35.252915382385254, 36.02453368050711, 35.491467884608674, 34.686883858272004, 36.19035938807896, 37.27239888054984, 34.500342096601216, 36.16141319274902, 35.888939585004536, 36.33542387826102, 37.40431390489851, 33.266602584293906, 39.785871505737305, 41.2021610396249, 35.406043257032124, 38.31616769518171, 37.649957043784006, 39.48070314952305, 36.46571997233799, 36.04954024723598, 36.14823593412127, 37.304829597473145, 39.67307792391096, 46.943572180611746, 47.150798729487825, 39.50159985678536, 44.95359073366438, 49.597155230385916, 50.37227542059762, 47.82327318191528, 46.863918031964985, 47.3877774647304, 45.44365412848336, 48.6844676562718, 48.06318058286394, 45.78682565689087, 40.57578093664986, 43.16340821129935, 47.685094356536865, 49.9360362461635, 45.3356374331883, 42.668060711451936, 40.23822702680315, 38.94177654811314, 37.77517400469099, 36.75233316421509, 35.475966453552246, 35.19688163484846, 37.417835099356516, 38.48129163469587, 38.43888677869524, 39.111184052058626, 38.01297957556588, 37.001690115247456, 35.74318374906267, 39.06113270350865, 40.135018484933035, 38.10449777330671, 36.337539604731965, 36.32527950831822, 36.98917293548584, 37.432523591177805, 37.40388311658587, 37.112781388419016, 39.153442995888845, 39.704348291669575, 40.72645957129342, 39.46627174104963, 37.5956985609872, 39.42041710444859, 38.993891511644634, 39.01675108500889, 36.29068790163313, 36.9095778465271, 35.58002962384905, 35.507341044289724, 38.28240639822823, 37.29196848188128, 37.45425408227103, 41.827683040073936, 42.92300401415144, 45.931775501796174, 51.98284353528704, 50.32097339630127, 50.3078795160566, 47.64130680901663, 52.59127991540091, 49.714916774204795, 49.57877377101353, 46.37109272820609, 50.222044944763184, 53.91253546306065, 55.39248439243862, 50.730732985905235, 22.348905086517334, 2.152475927557264, 8.96766037600381, 7.481933150972639, 6.4729244368416925, 0.5210518719894546, 0.33399089532239096, 30.194376673017228, 65.84250559125627, 49.769679001399446, 45.79951654161726, 28.66251254081726, 44.0690781048366, 56.45583323069981, 55.610932282039094, 11.400294184684753, 0.1471240475241627, 0.19515397240008625, 0.07897496901984725, 0.10107397926705224, 0.17450241984001227, 0.19384760249938282, 0.16759976451950415, 0.19335814804903098, 0.12391426866608006, 0.11800599284470081, 0.15855246356555394, 0.07345010619610548], [0.0034084650272104356, 0.043268451267587285, 0.006422780088282057, 0.02929232961365155, 0.028595060243138244, 0.019356539639245187, 0.0389661423063704, 0.06759956691946302, 0.01373944100591221, 0.0744732352239745, 0.03208087783839021, 0.026867213226588707, 0.04005986951025469, 0.02845788760376828, 0.04415504887167897, 0.0423678520933858, 18.58145805767604, 39.61461925506592, 42.17229979378836, 26.659209660121373, 19.635077680860245, 31.656725815364293, 37.37763977050781, 46.31884574890137, 38.09829650606428, 4.1870856540543695, 0.11315566168299743, 0.15564560597496374, 1.4614837659256799, 0.46350699982472826, 1.1205229588917323, 2.3321645941053117, 14.294389997209821, 41.89546619142805, 48.85648768288748, 45.370444434029714, 43.50317859649658, 38.31605652400425, 37.54788105828421, 36.78355836868286, 34.89947094236101, 33.54002114704677, 34.398134095328196, 34.57058491025652, 35.56493813650948, 36.01133905138288, 35.862508637564524, 35.83210332053048, 35.86940472466605, 36.75989280428205, 35.089566707611084, 35.41517666407994, 33.433783190590994, 35.260454177856445, 33.6080961227417, 32.15977886744908, 31.800470147814067, 33.663410731724326, 32.20791251318795, 31.939402852739605, 33.01172181538173, 32.38878107070923, 34.38674599783761, 32.444095679691856, 33.90501349312918, 34.36529343468802, 32.96007932935442, 34.19868605477469, 32.88124506814139, 32.08489465713501, 33.178433418273926, 34.40536717006138, 33.58562217439924, 30.180532387324742, 33.078615597316194, 32.78701359885079, 37.45752668380737, 41.601366315569194, 43.46418530600411, 34.68515375682286, 44.90490470613752, 46.36011110033308, 45.645982197352815, 47.428000586373464, 41.365506240299766, 42.87221615655081, 41.39575522286551, 46.423982415880474, 46.82398326056344, 40.39953987939017, 33.43875462668282, 43.327903338841026, 43.34722280502319, 43.92702565874372, 42.55537135260445, 38.00226892743792, 35.30918884277344, 35.54995434624808, 34.02558558327811, 32.67821523121425, 30.674354757581437, 32.20476150512695, 32.084227630070274, 33.811393465314595, 32.97898537772042, 34.80355453491211, 32.68443734305245, 32.51747213091169, 34.2253497668675, 34.37732424054827, 33.402922766549246, 33.44350372041975, 33.42470536913191, 31.9673068182809, 31.7408059665135, 34.74318511145455, 32.105624607631135, 33.51706429890224, 31.676722730909074, 34.76830284936087, 34.01338802065168, 35.007828099387034, 34.110443932669504, 34.20938975470406, 34.82719578061785, 34.139626366751536, 33.433011940547395, 33.14204570225307, 32.011375767844065, 34.26298468453543, 33.1338780948094, 32.042545386723106, 34.27226052965437, 35.255722454616, 38.97007656097412, 40.361422061920166, 47.50650133405413, 47.885640212467735, 49.19685908726284, 44.79258360181536, 47.51926517486572, 46.90157379422869, 50.224608830043245, 40.57825796944754, 42.12221023014614, 50.60341419492449, 50.17183378764561, 41.316104548318044, 13.646409681865148, 0.6222908166902406, 3.0147436814648763, 4.023644047124045, 1.195539076413427, 0.025190380169078708, 0.24486135797841208, 27.20974496432713, 49.51671593529837, 45.54085595267159, 43.359409945351736, 28.707194668906077, 30.0652756690979, 45.0209014075143, 37.68870367322649, 4.110014498233795, 0.12009707492377077, 0.0628888171964458, 0.053244625949966054, 0.02252073333199535, 0.06390887246068035, 0.032108307616519075, 0.12113356430615697, 0.05779082753828593, 0.004187878271165703, 0.042265634185501506, 0.05031615023368171, 0.03853480777304087, 0.022666058569614376, 0.01840710629975157, 0.036255612038075924, 0.007927518005349805, 0.009282739882889603, 0.029009753705135415, 0.0284710308270795, 0.050811484189970155, 0.0353632129595748, 0.0019101943970391794, 0.02282944810576737, 0.027622419309669306, 0.04010375376258578, 0.05107829773000308, 0.019301023600356917, 0.10298462531396321, 21.231421095984324, 46.202282769339426, 49.06293255942208, 34.27982016972133, 22.691402639661515, 35.530607087271555, 42.98530503681728, 51.37073850631714, 42.28585767745972, 4.5203134417533875, 0.07945204699145895, 0.14127263293734618, 1.4979538832392012, 2.434745626790183, 2.8919472992420197, 4.493601526532855, 16.225561891283306, 42.44202538899013, 50.17475203105381, 46.777187143053325, 45.68101501464844, 39.81962585449219, 39.16446283885411, 37.48101854324341, 36.747382572719026, 35.15858663831438, 35.942739486694336, 35.14976937430245, 36.74743815830776, 36.771117619105745, 36.93514026914324, 36.78225558144705, 38.344175883701865, 36.856552668980186, 35.92187752042498, 35.94966336659023, 34.435366017477854, 35.72923871449062, 34.60289403370449, 33.18508979252407, 33.70198713030134, 34.70619290215628, 33.97254303523472, 34.97771808079311, 34.68394824436733, 34.158285754067556, 35.764049189431326, 34.10409675325666, 36.04942560195923, 34.794452394757954, 35.746279171534944, 36.06377363204956, 34.04411990301949, 34.013853549957275, 34.444739137377056, 35.35751356397356, 34.95024490356445, 32.56185027531215, 33.681236335209434, 34.181204387119834, 37.62895263944353, 43.18824107306344, 45.73229619434902, 39.406840324401855, 48.776114395686555, 45.15453611101423, 48.9523936680385, 47.24476269313267, 44.16496671949114, 44.700509548187256, 43.16815035683768, 47.25490706307547, 48.816469533102854, 41.778503690447124, 38.35481357574463, 44.37547281810215, 45.42198269707816, 45.7732766696385, 43.772594996861045, 39.177369117736816, 36.61352900096348, 35.94547012874058, 34.88311488287789, 34.249463490077424, 33.15171759469168, 34.13047558920724, 34.25800977434431, 34.840209756578716, 34.66438559123448, 35.96330268042428, 34.286817005702424, 34.08138656616211, 35.48757689339774, 35.42691217150007, 35.89498104367937, 35.265939780644004, 34.39039727619716, 33.08805819920131, 33.68206317084176, 35.46600273677281, 33.68768078940255, 35.003422941480366, 35.02784585952759, 36.822655882154194, 36.51222773960659, 37.34896455492292, 35.52466985157558, 36.07521384102957, 37.61686624799456, 37.12838356835501, 35.25308213915144, 34.36575896399361, 35.09613275527954, 35.181432315281455, 34.828231062207905, 34.30399990081787, 36.59769058227539, 38.403534344264436, 41.44072049004691, 43.62225682394845, 48.444487299237935, 49.38989394051688, 51.07566588265555, 46.929283210209434, 49.633271966661724, 48.52296372822353, 50.865013871874126, 41.037745816367014, 43.43306085041591, 53.728644439152305, 52.19719546181815, 44.38498837607247, 15.873738118580409, 1.0011079609394073, 3.58122119307518, 3.8747220039367676, 2.8235244793551306, 0.13608254572110517, 0.23981856714401925, 30.03943531853812, 57.76511008398873, 47.921868119921, 47.630332129342214, 30.349102633340017, 36.00442559378487, 50.2561605998448, 45.61304773603167, 5.877126395702362, 0.0892349002616746, 0.04004248544307692, 0.009474247910215386, 0.03937486805287855, 0.03663570699947221, 0.06623975560069084, 0.044373252162975926, 0.05496472240026508, 0.030713972435998063, 0.03504246945625969, 0.0454697477897363, 0.03731770933206592, 0.12523498279707773, 0.0970070982085807, 0.09193432969706399, 0.19543285029275076, 0.1425081230700016, 0.06109190718936069, 0.1852125387106623, 0.16856945891465458, 0.12385925304676805, 0.10896882241857903, 0.13937250418322428, 0.13339195081165858, 0.1479246781340667, 0.15604405530861445, 0.09800846661840167, 0.22624081000685692, 25.644034419740947, 54.25120108468192, 55.37779937471662, 38.64341742651803, 30.679051739828928, 42.24356746673584, 47.51318202699934, 54.77063798904419, 47.54720040730068, 5.5102211236953735, 0.370933110160487, 0.5585537967937333, 5.206390295709882, 3.537680740867342, 4.082729356629508, 4.274319853101458, 16.076759270259313, 47.111746379307334, 51.86158357347761, 50.850127356392996, 48.831845896584646, 42.956452642168315, 40.96812834058489, 41.580872603825156, 38.80160706383841, 38.41760444641113, 37.92905575888497, 39.65324429103306, 39.20303576333182, 39.37683800288609, 39.348673479897634, 39.1554718698774, 40.331065382276265, 39.10470833097185, 38.20100825173514, 39.49269921439034, 35.960856914520264, 38.26468849182129, 36.73157889502389, 35.28161491666521, 35.199911049434114, 36.943505900246755, 35.88164745058332, 35.48007978711809, 36.09096540723528, 35.31988212040493, 37.74184002195086, 36.01619931629726, 38.922950404030935, 37.98539522715977, 35.336259024483816, 37.12895679473877, 35.733821051461355, 35.45159217289516, 37.276480947222026, 37.35564177376883, 36.29757356643677, 33.747866085597444, 35.155081272125244, 35.59773710795811, 39.05530663899013, 44.91695288249424, 46.169619287763325, 39.47846582957676, 43.91629416601998, 49.15463488442557, 49.007360867091585, 50.05943972723824, 45.06784691129412, 46.90560374941145, 45.17970248631069, 49.38635730743408, 49.393065793173655, 46.50233377729143, 40.231824261801584, 45.748937129974365, 48.01522759028843, 48.050183977399556, 47.0000193459647, 40.548488412584575, 38.80808973312378, 39.78204652241298, 37.73989800044468, 37.3085503578186, 34.712550503867014, 35.93764993122646, 37.17207384109497, 36.79842751366751, 37.62134436198643, 37.433680466243196, 36.65096936907087, 35.67146096910749, 38.38478463036673, 38.0330286026001, 38.82719727924892, 36.940195083618164, 36.148937702178955, 36.08755384172712, 35.94720023018973, 39.94413757324219, 35.26790264674595, 37.48184537887573, 36.26727247238159, 38.524495533534456, 37.90399708066668, 39.50085987363543, 37.761534690856934, 38.68506145477295, 39.436012336185996, 39.45640877314976, 37.565856048039024, 36.81095511572701, 36.83950873783657, 38.90991905757359, 37.1198616027832, 36.94248104095459, 36.34311900820051, 39.849061897822786, 44.59641858509609, 45.9678053855896, 50.51914644241333, 51.25364746366228, 53.18258898598807, 49.22343594687325, 52.41823502949306, 48.49105412619454, 51.76933928898403, 40.732838017599924, 44.44242565972464, 53.98891353607178, 52.77178021839687, 45.302452836717876, 16.815093960080826, 1.7820898251874107, 9.880149926458087, 12.705950157982961, 4.36387084211622, 0.3189165884894984, 0.2818982963051115, 33.51936067853655, 60.8123711177281, 57.40081950596401, 56.37641879490444, 39.62330102920532, 42.41756078175136, 57.40898016520909, 54.13927255358015, 7.832594837461199, 0.1738116169082267, 0.18890097364783287, 0.18293355671422823, 0.13398710744721548, 0.17239095456898212, 0.1732086706906557, 0.15758073356534752, 0.16234434795166763, 0.06806092323469264, 0.06625922955572605, 0.16780694840209825, 0.08289591755185809], [0.04712754115462303, 0.01499216168719743, 0.05911502255392926, 0.035422058909067085, 0.04650718712114862, 0.040738421492278576, 0.036525316137288294, 0.04237000644207001, 0.0653891848134143, 0.012438667322775083, 0.06605672077941042, 0.07862384750374726, 0.017453457561454604, 0.016516446501814892, 0.038608520424791744, 0.13925965023892267, 9.054674404008047, 41.14657892499651, 48.24378163473946, 27.012138196400233, 26.539794445037842, 22.50544105257307, 31.609623977116176, 44.20333119801113, 41.994815008980886, 10.263389110565186, 0.11738894666944232, 0.13307659487639154, 0.9104916719453675, 1.521514573267528, 1.7542796603270938, 1.1760443853480476, 7.383299997874668, 35.606804507119314, 50.39547198159354, 45.47449023383004, 45.2042886870248, 41.743380546569824, 39.6299261365618, 38.6289894921439, 37.81491422653198, 37.76210444314139, 38.77770526068551, 39.739846638270784, 41.281530312129426, 40.80622489111764, 39.93264177867344, 40.06098542894636, 40.04544925689697, 39.66362142562866, 37.869891847882954, 37.08789641516549, 36.15320042201451, 35.70525353295462, 35.73118421009609, 33.93012080873762, 32.80272347586495, 30.99025113242013, 33.319488797869, 32.75432579857962, 32.25086975097656, 32.718698910304475, 33.19449070521763, 32.23153638839722, 33.3100392477853, 32.648004463740754, 35.573380197797505, 31.084305422646658, 34.762845039367676, 32.876353536333355, 32.68688310895647, 33.740157059260774, 33.799960204533164, 31.333961146218435, 33.68191378457205, 30.449719497135707, 37.1969553402492, 41.76216500146048, 45.15090915134975, 35.9187091418675, 35.24424055644444, 52.668307644980295, 42.674070903233115, 47.08427667617798, 44.381681033543174, 40.70314489092146, 42.61493478502546, 45.882721219744, 46.35719633102417, 39.83424833842686, 36.53729336602347, 42.90338577542986, 45.21140711648123, 42.73028530393328, 40.71797582081386, 36.654975005558555, 34.86871474129813, 35.53013113566807, 33.977552686418804, 33.7352933202471, 31.860186440604075, 32.44246980122158, 34.038762841905864, 33.734713145664756, 33.094523497990195, 36.22900526864188, 33.3496926171439, 33.89394153867449, 32.44666303907122, 34.19934960774013, 34.7270097051348, 32.62584318433489, 34.354766913822715, 34.14832203728812, 33.18088960647583, 32.09107507978167, 32.977456774030415, 33.996976375579834, 33.17663036073957, 32.59577138083321, 32.233242171151296, 32.97575446537563, 34.47809396471296, 35.131200313568115, 34.37029961177281, 33.6798814364842, 34.56924390792847, 31.635929856981548, 32.79234634126936, 31.48185007912772, 30.88976628439767, 33.20446137019566, 34.61292723246983, 36.287085260663716, 36.367663519723074, 39.76128530502319, 43.39480406897408, 46.84173590796334, 46.36655902862549, 45.54465314320156, 45.25606318882534, 46.299832003457205, 47.15628433227539, 49.33927631378174, 51.27966846738543, 47.43713051932198, 48.26334776197161, 34.835064615522114, 9.29565703868866, 0.5241395320211137, 0.8379978590777942, 3.0059244632720947, 3.045332908630371, 0.5622764570372445, 0.38740992173552513, 28.969796623502457, 47.0987845148359, 41.38294621876308, 29.302314826420375, 23.955420664378575, 34.412652356284006, 43.311491693769185, 31.711852822984966, 1.9208729267120361, 0.04166260315105319, 0.033459107990243604, 0.03996934276074171, 0.03250679766227092, 0.03382332183952842, 0.06482918307717357, 0.027746034819366674, 0.03847155473860247, 0.02647537282401962, 0.05452010215127042, 0.020161070129168884, 0.04787554798115577, 0.014763685375718134, 0.008134495782932, 0.04937517483319555, 0.021680837596899698, 0.03864060834582363, 0.054086786295686445, 0.012839019947153116, 0.016106562156762396, 0.04196229171273964, 0.05007878511345812, 0.06317194950367723, 0.0895003770877208, 0.01844564199979816, 0.03239825241533773, 0.028918463603726456, 0.19589102427874291, 12.668281367846898, 47.43937131336757, 53.285154819488525, 30.275785241808208, 26.5702223437173, 33.61976909637451, 38.008233955928254, 47.28664296013968, 45.45053284508841, 9.702612161636353, 0.05232835600950888, 0.11470566636749677, 1.6044079938105174, 3.1672240708555495, 2.7804775663784573, 2.6004110915320258, 9.139311279569354, 38.50293179920742, 51.790996823992046, 47.713279724121094, 47.76837893894741, 44.0411046573094, 41.48378195081438, 40.227509430476594, 39.028983388628276, 36.969471318381174, 40.80319895063128, 42.36455644880022, 42.37812975474766, 42.52082143511091, 42.15465484346662, 41.13860934121268, 40.87956312724522, 40.67315993990217, 39.7824147769383, 38.29045936039516, 38.120930262974326, 36.45404699870518, 37.60978603363037, 35.09709855488369, 33.40121003559658, 32.81849588666643, 34.752245562417166, 34.423713888440815, 34.60909530094692, 34.71717800412859, 33.98838840212141, 34.972517354147776, 35.14423860822405, 34.894249371119905, 37.33688511167254, 34.321943623679026, 35.519389220646445, 33.25662497111729, 33.68832002367292, 34.77193675722395, 33.936342920575825, 32.1855080468314, 35.82195200238909, 31.972021171024867, 39.22074672154018, 42.68095309393746, 47.59215177808489, 38.15054695946829, 41.952298981802805, 54.4145428112575, 41.165783745901926, 49.709344318934846, 45.6377729007176, 43.553011076790945, 43.94366659436907, 46.74781015941075, 47.749288763318745, 42.5658666065761, 38.349682331085205, 46.473335470472065, 46.58246735164097, 45.28785467147827, 42.669554574149, 40.168272563389365, 36.084236076899934, 38.55366407121931, 35.52200869151524, 35.50115714754377, 33.18605211802891, 33.89694316046578, 36.067626408168245, 34.98378733226231, 34.745933123997276, 36.00638151168823, 34.63504334858486, 34.07482399259295, 34.72837502615792, 35.908342429569785, 37.89377628053938, 35.05759457179478, 34.74502985818045, 35.2274398122515, 33.95305681228638, 34.79583508627755, 35.194640840802876, 35.626356737954275, 34.11715589250837, 35.07890122277396, 32.9660130909511, 35.0452059337071, 35.95968614305769, 36.61931337629046, 35.71912908554077, 36.8024366242545, 35.5271121433803, 34.859108856746126, 34.457200731549946, 34.06367213385445, 34.05243342263358, 35.73397738592965, 36.90168816702706, 38.34718097959246, 38.225340843200684, 43.20607015064785, 45.352205412728445, 49.01131091799055, 49.76692056655884, 47.12771681376866, 48.11654622214181, 48.17851025717599, 48.29821382250105, 48.52411712918963, 49.90301145826067, 48.53925725391933, 47.725765636989046, 38.35274648666382, 10.390320539474487, 1.313972098486764, 2.8673882399286543, 4.690211227961949, 2.1816316545009613, 0.4412348749382155, 0.30717234153832707, 30.375867094312394, 52.227166516440256, 45.56515727724348, 35.64760780334473, 27.874835218702042, 42.11056157520839, 50.02092586244856, 38.41712154660906, 3.150339296885899, 0.094199483149818, 0.052852425923837085, 0.03595315844618848, 0.0356193972485406, 0.03396869457459875, 0.0628843524360231, 0.02132092565963311, 0.020012226687478166, 0.03317602996581367, 0.05545411917514034, 0.029824294282921722, 0.023074019267889004, 0.11791616837893214, 0.11491818353533745, 0.13245300762355328, 0.11843577692551271, 0.13172441029122897, 0.16021738494081156, 0.11553242057561874, 0.12047615886798926, 0.16247345959501608, 0.1266768697117056, 0.14644537679851055, 0.2538498570876462, 0.10958274733275175, 0.1298711547361953, 0.15934461248772486, 0.24401137073125156, 13.8158050264631, 53.95743472235543, 59.82506683894566, 39.31512410300118, 37.33808715002877, 33.123945644923616, 40.58365324565342, 52.428004196711946, 49.820915017809185, 13.54679422719138, 0.29048765397497583, 0.5749071964195797, 4.029422342777252, 6.686350950172969, 4.647715611117227, 3.0689109691551755, 9.792570488793508, 41.10687344414847, 54.54191371372768, 49.87636511666434, 48.85282250813076, 46.01048469543457, 44.02810457774571, 42.48202616827828, 40.85693631853376, 39.822033405303955, 42.94820165634155, 44.29902178900582, 45.391351563589915, 44.99652017865862, 43.31723437990461, 43.58346503121512, 43.68207733971732, 43.040730816977366, 42.80981091090611, 41.474627699170796, 39.53287022454398, 39.08229691641671, 40.49208641052246, 36.73215559550694, 34.80959251948765, 34.749243940625874, 36.67687572751726, 35.93698985236031, 35.546924931662424, 36.08382613318307, 36.48765196119036, 36.10879795891898, 37.12925556727818, 37.727842875889365, 38.55255583354405, 35.160459177834646, 37.24144465582711, 35.448687825884136, 34.79800639833723, 37.18836736679077, 35.87818724768502, 34.52996574129377, 37.54713065283639, 33.61923061098371, 39.66064412253243, 44.642856870378765, 47.14431258610317, 40.83741882869175, 39.32705415998186, 51.24605655670166, 45.654900210244314, 50.232387338365825, 48.571107796260286, 44.930588722229004, 47.59399652481079, 49.29799011775425, 48.6952269417899, 44.198457036699565, 39.664781774793354, 46.95192044121878, 49.522239753178184, 46.65265110560826, 45.24589450018746, 41.963308402470176, 37.683124269757954, 39.88835743495396, 38.28587702342442, 37.68340914590018, 34.910244124276296, 35.70484011513846, 38.45187643596104, 37.41650799342564, 36.88410575049264, 39.386628014700754, 36.150532313755576, 35.918643133980886, 36.35947854178292, 37.983786719185964, 40.39785494123186, 36.550435883658274, 36.71680007662092, 37.16527502877371, 34.69235903876168, 36.122621400015696, 36.24949203218733, 37.32036229542324, 35.025313241141184, 35.52797024590628, 36.178651673453196, 36.41243423734392, 39.5725131716047, 38.01249667576381, 37.46287332262312, 37.84020219530378, 38.57353939328875, 35.57723644801548, 37.0133387701852, 35.85142626081194, 34.00238902228219, 39.890935216631206, 39.79284054892403, 41.837483474186485, 40.48274803161621, 45.21349157605852, 47.126094409397666, 50.47174235752651, 51.598448344639365, 49.47108016695295, 50.41392292295183, 49.64956201825823, 49.67038924353463, 48.60495941979544, 50.66814013889858, 48.86528410230364, 48.62526553017752, 40.12643051147461, 11.8472900390625, 2.4877249896526337, 5.608308843203953, 10.703333411897932, 8.433904102870397, 1.308983291898455, 0.3462541401386261, 35.13227728434971, 58.46173300061907, 52.09475122179304, 41.03622416087559, 35.09417336327689, 49.29101412636893, 55.32897785731724, 48.19672843388149, 4.710529931953975, 0.23267964593001775, 0.09742364407117877, 0.09897064963089568, 0.18532980313258512, 0.13839991922889436, 0.13064198408808025, 0.12071192264556885, 0.10082369484007359, 0.12001624783234936, 0.12704711912998132, 0.07974792218634061, 0.11566564414118018], [0.020825457692678486, 0.024505977518856525, 0.05594113429210015, 0.04261863185092807, 0.03504044742190412, 0.046764860794480355, 0.07169571997863905, 0.018795560812577605, 0.053855802797313244, 0.016687004760439907, 0.0387465005208339, 0.07934777651514326, 0.0773426919643368, 0.003673622941797865, 0.0428993010760418, 0.010405711097908872, 4.1695015004702976, 33.16667706625802, 45.6753557068961, 43.99968991960798, 27.345180988311768, 24.819807835987636, 40.73564508983067, 47.37291179384504, 46.63783754621233, 21.194849252700806, 0.4300376357776778, 0.050685612551335774, 0.25148404975022587, 1.142247261745589, 3.031719650541033, 1.1574995347431727, 3.587162120001657, 31.23993812288557, 48.427721296037944, 48.32793474197388, 46.072966371263774, 45.240787574223106, 41.36946323939732, 41.19909340994698, 42.25056430271694, 43.48434550421578, 44.60450281415667, 43.11753273010254, 44.550880091530935, 43.972491196223665, 42.710097312927246, 42.46320349829537, 42.86358649390084, 40.45004980904715, 38.4077136857169, 37.25717190333775, 38.04912063053676, 38.66959823880877, 34.98034449986049, 33.25013882773263, 32.75135196958269, 32.06073924473354, 32.14609439032418, 33.24530635561262, 33.47691065924508, 33.24599422727312, 31.808773245130265, 33.64946222305298, 35.16100461142403, 33.23082978384835, 33.56778267451695, 33.01824269975935, 32.709763526916504, 33.22537544795445, 32.5798739024571, 33.488114629473, 31.897762298583984, 32.236876079014365, 31.960980483463832, 32.19133758544922, 35.623619147709434, 42.580721855163574, 43.837553705487935, 44.21324280330113, 27.200342314583914, 37.120111737932476, 55.08994592939104, 44.45321273803711, 45.70895372118269, 41.578617913382395, 41.92848055703299, 46.838859353746685, 49.02534280504499, 39.30241584777832, 41.07837888172695, 40.82135459354946, 45.22431686946324, 43.39252505983625, 39.32371555055891, 36.782547405787874, 36.219503607068745, 33.70326907294137, 34.637364046914236, 34.12085233415876, 31.190925530024938, 31.7749285697937, 33.292060783931184, 34.43795074735369, 33.774081638881135, 33.26541791643415, 33.88330732073103, 33.748991693769185, 33.264413901737754, 33.845022746494834, 33.386045592171804, 32.76719733646938, 31.50436919076102, 33.534115178244456, 33.36456871032715, 32.94772890635899, 33.89664438792637, 33.72521495819092, 34.74014874867031, 32.660973276410786, 33.931308950696675, 33.912288257053916, 32.903562682015554, 34.003108160836355, 34.141092436654226, 32.44856684548514, 32.047819069453645, 33.478682449885774, 32.528012548174175, 31.609387738364084, 33.26865577697754, 33.75248316356114, 35.17340019771031, 36.16365398679461, 38.494406359536306, 41.016651085444856, 45.54990945543562, 47.58828163146973, 47.59745672770909, 44.63954257965088, 45.03230687550136, 45.45416327885219, 47.17777163641793, 47.28217874254499, 45.30880349023001, 47.18261105673653, 45.33407061440604, 28.1930262361254, 5.310055681637355, 0.5298921519092151, 1.851149925163814, 1.0207939445972443, 0.7279508784413338, 0.123666698379176, 0.5200451974357877, 28.882633209228516, 47.17235551561628, 39.7546706199646, 31.22790036882673, 24.92958242552621, 37.155047280447825, 39.280483858925955, 26.69406703540257, 0.9805310879434858, 0.0089255963684991, 0.05395371540050421, 0.014502959991140025, 0.022741477736937146, 0.03254633250513247, 0.06114320443677051, 0.06014844495803118, 0.02635786073681499, 0.03040850954130292, 0.06199175997504166, 0.043229574603693824, 0.004475882035746638, 0.021173218764098625, 0.035226712069873295, 0.0722910055358495, 0.045535060177956305, 0.032188734372279475, 0.037852455994912555, 0.12520877777465753, 0.026852322775604467, 0.02404501136126263, 0.013343215570785105, 0.0752648413181305, 0.04516424418294004, 0.09629059237028871, 0.06405489998204367, 0.12252456109438624, 0.03862642357125878, 5.3108416966029575, 40.43445110321045, 51.493249143872944, 47.62151139123099, 29.58207709448678, 24.993219239371165, 43.28535257066999, 49.660894530160085, 51.388063839503694, 22.000503301620483, 0.37662387479628834, 0.1532758359930345, 1.185646144407136, 3.341435602733067, 6.575678740228925, 3.1148526753698076, 4.648006132670811, 34.32486186708723, 49.73511518750872, 49.85824074063982, 47.442209652491975, 46.33602516991751, 42.983772959027974, 43.31040777478899, 42.86424657276699, 45.30192477362496, 45.046707017081125, 44.43031842367989, 46.35979495729719, 44.515722206660676, 43.37482452392578, 44.00203493663243, 43.35502563204084, 42.32129349027361, 41.15226255144392, 39.37812341962542, 39.60720205307007, 39.74323388508388, 37.30684110096523, 35.896877901894705, 33.45599658148629, 33.41401209150042, 34.20828151702881, 35.611873217991416, 34.269686222076416, 35.842786175864084, 33.87808574948992, 34.55299554552351, 35.230667250497, 34.93190165928432, 35.558674335479736, 34.27297272000994, 33.89481006349836, 35.0357529095241, 33.32839291436331, 35.53044727870396, 33.51873186656407, 33.355115686144146, 33.367052691323416, 33.15721014567784, 37.49740586962019, 44.21237775257656, 45.786137785230366, 45.81510135105678, 30.461812836783274, 43.9743116242545, 55.26406083788191, 44.025050844464985, 48.054342474256245, 43.835604735783164, 44.01655319758824, 49.35910994665963, 49.636471612112864, 41.33825887952532, 42.0679725919451, 43.859051431928364, 46.00045149666922, 45.590570313589915, 43.021161215645925, 39.51749038696289, 38.09009068352835, 35.67358711787632, 36.316274642944336, 36.26095308576311, 32.808910846710205, 33.87453869410923, 33.9611827305385, 34.80233860015869, 35.97256810324532, 35.700771944863455, 35.2354302406311, 34.7829635483878, 34.46214090074812, 35.70631660733904, 34.32509463174002, 35.17570699964251, 34.8326153755188, 36.07751716886248, 35.08012410572597, 34.64444426127842, 35.50308179855347, 35.18737997327532, 36.393434388296946, 34.27190964562552, 36.906280926295686, 35.743989740099224, 34.57072040012905, 35.70491654532296, 36.396769523620605, 34.47530426297869, 34.65008272443499, 35.05450957162039, 34.276655265263145, 34.65045097896031, 36.11350883756365, 35.10626670292446, 37.29921892711094, 37.757410934993196, 40.38650853293282, 42.34461859294346, 46.51082795006888, 49.10799857548305, 48.737388610839844, 47.94030169078282, 47.622324330466135, 47.37123727798462, 47.79669632230486, 48.717509814671104, 47.3730194909232, 48.76795026234218, 46.77709681647164, 30.784810270581925, 6.272631321634565, 1.2420593287263597, 2.08508990917887, 2.5710888249533514, 1.8759808327470506, 0.1479705606720277, 0.3452050435755934, 32.03195285797119, 54.40469721385411, 46.25703110013689, 37.49905606678554, 27.700218302862986, 43.91472734723772, 45.65433740615845, 35.7901987348284, 1.0252540366990226, 0.11126916469740016, 0.07054426640804325, 0.02512087782711855, 0.0541509689231004, 0.01644003836970244, 0.0033411643193435986, 0.021936200858492936, 0.02421670955871897, 0.03384151336337839, 0.028831712901592255, 0.01025371246838144, 0.04644839545445783, 0.11588322318025998, 0.10286878581557955, 0.10436213961137192, 0.1958634214741843, 0.168433901188629, 0.16043131346149103, 0.288101924849408, 0.14013700958873543, 0.08685500653726713, 0.1127135418355465, 0.18214124494365283, 0.11013588907995395, 0.21461682660239084, 0.16051151630069527, 0.24526229075023107, 0.14932448230683804, 5.883045392377036, 44.55441672461373, 57.293323925563264, 54.64458377020699, 37.754829679216655, 33.96068593433925, 50.7559723172869, 55.87030158724104, 55.97207185200283, 26.51179494176592, 0.8986421706421035, 0.5178833305835724, 2.888639739581517, 8.387212208339147, 10.825785858290535, 5.789165241377694, 4.72114634513855, 37.079628058842246, 51.522560119628906, 53.672023568834575, 49.38348422731672, 49.82984345299857, 45.02390997750418, 45.79487861905779, 45.45274237224034, 47.93736955097744, 47.710820061819895, 46.76659461430141, 47.92460223606655, 46.89504943575178, 43.294100352696006, 46.151223931993755, 44.67485679898943, 44.14405958993094, 42.66979776109968, 42.19142818450928, 41.563637597220286, 43.3839544568743, 39.11790990829468, 37.573120389665874, 35.54930468967983, 35.02905484608242, 36.18218830653599, 36.35025133405413, 36.39927782331194, 38.14057282039097, 34.37447200502668, 36.563401222229004, 38.57296964100429, 36.611621720450266, 36.07880258560181, 35.42517512185233, 36.15095962796892, 37.06608601978847, 35.24107217788696, 37.42804895128523, 34.472462449754985, 33.90449237823486, 34.569730281829834, 35.60382372992379, 38.53933688572475, 45.62102426801409, 46.3275032043457, 48.708317347935264, 33.47962393079485, 40.162425654275076, 53.94178043093, 46.39224999291556, 49.14353166307722, 44.977548122406006, 46.0119229725429, 50.904288564409526, 52.3488746370588, 45.253144945417134, 45.74780109950474, 44.61684628895351, 48.20254060200283, 46.77537018912179, 43.74540669577462, 41.6620831489563, 38.702171393803184, 37.58866350991385, 39.25375761304583, 39.262852805001394, 34.06848723547799, 36.7154347555978, 36.82533441271101, 37.41165815080915, 37.350381987435476, 37.991950852530344, 36.394775390625, 35.88880409513201, 37.310009479522705, 37.39860943385533, 35.96992083958217, 37.45331607546125, 34.801466601235525, 37.95114408220564, 36.53571959904262, 35.98013816561018, 36.51649393354143, 35.97264105933053, 39.24473190307617, 34.88278136934553, 38.82191317422049, 36.431927408490864, 36.728928157261436, 38.44893387385777, 38.6180808203561, 35.34803622109549, 35.17327165603638, 36.106859411512104, 36.37237439836775, 36.146064622061594, 38.297640323638916, 37.47392790658133, 39.23036650248936, 40.39191770553589, 42.80972753252302, 44.906405517033164, 50.3296343258449, 52.188937527792795, 50.71246269771031, 50.013918604169575, 48.8816088948931, 49.441977637154714, 48.68983513968331, 51.10932295663016, 48.6810039792742, 49.87183836528233, 48.84712845938546, 32.74584204810006, 7.8648839848382135, 2.257013746670314, 4.257468734468732, 6.323872114930834, 3.815769578729357, 0.35132108681968277, 0.6770682973521096, 35.171750000544954, 58.784275327410015, 49.62291915076119, 42.93693862642561, 35.519493443625315, 52.06720508847918, 53.50746243340628, 44.012564931597026, 1.7617496252059937, 0.1814744621515274, 0.182076702692679, 0.1465247246835913, 0.14000096331749642, 0.15236632765403815, 0.15569684893957206, 0.1960129163094929, 0.1066132066771388, 0.12622005279575074, 0.16265134433550493, 0.11633249478680746, 0.1675691083073616], [0.08161616657993623, 0.028889266241874014, 0.07555015172277178, 0.026731168651687245, 0.10140492793704782, 0.004672941751778126, 0.02200205607472786, 0.06113876003239836, 0.042023872158357074, 0.05878675409725734, 0.05360963707789779, 0.021995760966092348, 0.017226418047877293, 0.045687920546957424, 0.0405375445926828, 0.03264791937544942, 1.5105283856391907, 21.665381261280604, 48.85140854971749, 38.691523279462544, 28.52741003036499, 31.55375698634556, 38.399348054613384, 43.10193402426583, 46.36558280672346, 33.69816214697701, 1.4958600870200565, 0.06879325250961951, 1.077895109142576, 2.09145011646407, 3.073789473090853, 1.8472771729741777, 3.291684980903353, 24.743217842919485, 47.06503711427961, 48.801541328430176, 47.27269792556763, 44.33303322110857, 44.702969210488455, 44.89593458175659, 44.250929832458496, 45.12834140232631, 42.36862461907523, 44.703914165496826, 45.34844296319144, 45.375992570604595, 43.27317237854004, 43.35819053649902, 43.84402247837612, 42.1362247467041, 42.32654632840838, 40.70641054425921, 39.297583375658306, 38.99094894954136, 37.37260927472796, 35.554599217006135, 35.56079701014927, 33.15230471747262, 33.95659691946847, 33.103306021009175, 32.99085290091378, 32.79143612725394, 32.682092326028005, 32.07222809110369, 33.52899782998221, 33.23319217136928, 34.72492177145821, 32.881627219063894, 33.49615369524275, 32.94617598397391, 33.106700216020855, 33.460460799080984, 33.70825787952968, 31.867134639195033, 33.96181501661028, 33.05098261151995, 38.91336188997541, 44.06132391520909, 44.55330848693848, 45.930076667240684, 42.52026905332293, 29.46609776360648, 36.47730261938912, 49.945058482033865, 48.11026157651629, 42.69249405179705, 43.15985073362078, 45.51073898587908, 48.702814374651226, 42.517017296382356, 39.42037888935634, 41.47319289616176, 44.78293602807181, 42.48196016039167, 39.09411927631923, 35.03292499269758, 33.76952362060547, 36.774574347904746, 34.94186537606375, 34.59421225956508, 34.64645576477051, 32.128418173108784, 33.69096728733608, 33.25457872663225, 33.226702553885325, 33.544634750911165, 33.98755461829049, 33.59636408942086, 33.8937782560076, 33.55267381668091, 34.072697843824116, 34.5432402747018, 32.77103621619088, 33.661805697849815, 33.63505860737392, 35.154087679726736, 34.857719217027935, 32.54858269010271, 34.43004022325788, 33.58620582308088, 33.540458883558, 34.0358168057033, 33.73698173250471, 32.86854376111712, 33.124383381434846, 32.499226161411826, 32.34670278004238, 32.526563848767964, 30.596607889447892, 31.99711459023612, 32.24009656906128, 35.105088983263286, 36.0232378414699, 37.92937537602016, 38.92746325901577, 41.13380813598633, 41.63150412695748, 48.172225611550466, 45.47484459195818, 45.93976245607649, 44.79665872028896, 46.60743917737688, 45.36528887067522, 49.04741028376988, 48.633363655635286, 49.26404469353812, 42.667477062770296, 25.223657982689993, 3.809828434671674, 0.04716861627197691, 2.137745746544429, 2.524067976645061, 2.1293010796819414, 0.0525621418575091, 0.5679353305271694, 31.61978919165475, 46.849090576171875, 38.4887227330889, 29.334957463400706, 25.283139773777553, 40.82794148581368, 38.33143983568464, 20.98794058391026, 0.1798183617315122, 0.034315693990460465, 0.025676603096404245, 0.010847311017901769, 0.019074545574507544, 0.03501867662583079, 0.030104220512190034, 0.0576875273670469, 0.03510445702288832, 0.01729651919699141, 0.06172177767647164, 0.033844040906322856, 0.03184799783463989, 0.0750582477610026, 0.025203838911173598, 0.035320102237164974, 0.04126038794804897, 0.025818211658458625, 0.010316957869300885, 0.028219111130705903, 0.06491554022899695, 0.02792516806428986, 0.02886659638690097, 0.05592010649187224, 0.026867252242352282, 0.04884539165401033, 0.11421243926244122, 0.020172401663980315, 0.013237987511924334, 2.2837441180433546, 27.4569479737963, 53.46742691312517, 45.202329295022146, 32.96949066434588, 30.693375451224192, 41.49891512734549, 49.13251182011196, 50.84636490685599, 36.25023896353585, 1.4828415513038635, 0.08282322609531027, 0.33315059755529675, 4.940108835697174, 3.7958486591066634, 3.667412510940007, 4.413019793374198, 27.028113842010498, 48.75021151133946, 49.485761710575645, 49.123350620269775, 46.34915379115513, 46.54606921332223, 45.375110149383545, 45.1683908190046, 47.31957394736153, 44.41731834411621, 45.842963627406526, 46.442798137664795, 46.80235004425049, 45.03829969678606, 45.716110365731375, 45.603219509124756, 44.01502111979893, 42.35205316543579, 42.127122606549946, 40.85589756284441, 39.43392440250942, 38.10477917534964, 36.15430865968977, 37.29905564444405, 35.183294432503835, 34.964412280491416, 34.74204560688564, 34.66413198198591, 35.77517325537545, 34.65172944750105, 34.123840059552876, 35.033091749463765, 34.069685799734934, 36.63595083781651, 35.6605418750218, 32.931536129542756, 35.525263922555105, 34.27435541152954, 35.15087761197771, 35.03252894537789, 34.45948321478707, 34.708100182669504, 33.31227656773159, 41.0970139503479, 46.58854355130877, 47.62144190924508, 47.699192251477925, 43.61992917742048, 31.60387781688145, 42.16218669073922, 53.67355217252459, 47.17759793145316, 45.08267436708723, 44.1486245564052, 47.74326467514038, 50.726800305502756, 43.04479203905378, 42.47522040775844, 44.2422411101205, 46.25563451222011, 44.105743748801096, 39.06327274867466, 38.66252844674246, 37.470988818577354, 36.85274853025164, 35.72139767238072, 37.35050358091082, 36.08835983276367, 34.1640180179051, 34.24602065767561, 33.55515432357788, 35.81760590417044, 35.124238218579976, 34.7649816104344, 35.83329493658883, 34.79242352076939, 35.2893830026899, 36.29425927570888, 35.92996522358486, 34.6330874306815, 35.63685894012451, 34.46716792242867, 36.812167576381135, 36.16537366594587, 34.18605422973633, 35.313878876822336, 35.04158244814192, 34.11349071775164, 35.85244417190552, 35.474962438855854, 34.83401543753487, 35.19482844216483, 34.65980672836304, 35.08649560383388, 33.937218393598286, 33.48572097505842, 33.51087692805699, 35.723753111703054, 38.55413654872349, 37.76614134652274, 40.112405572618755, 42.53536401476179, 44.84319428035191, 44.84361812046596, 50.17534262793404, 47.70363909857613, 46.84971243994576, 47.436522551945274, 48.40734917776925, 46.81651047297886, 48.444817338671, 49.77482761655535, 49.479108810424805, 44.26190103803362, 26.37258604594639, 4.086913474968501, 1.053166036094938, 3.684251035962786, 3.1528627957616533, 2.623957233769553, 0.08023166337183543, 0.4934805514557021, 34.808626719883506, 51.04975257601057, 41.71871444157192, 28.495422261101858, 30.080037117004395, 48.09746994291033, 47.13698918478829, 26.335804019655498, 0.3334117792546749, 0.012357349989802709, 0.031493710952677896, 0.025099600665271282, 0.060425782576203346, 0.04612937203741499, 0.04120331976030554, 0.040965825718428404, 0.025885758123227527, 0.008255365770310163, 0.02689553697460464, 0.016956422178606902, 0.03582155657932162, 0.19754261922623428, 0.19271090706544264, 0.1699656532811267, 0.1522303085241999, 0.2521669273929936, 0.10679048752146107, 0.13878236870680535, 0.22170723256255898, 0.11213998296963316, 0.15968838546957287, 0.09606201427855662, 0.08203357418200799, 0.15543508370007786, 0.21681396370487555, 0.13235696777701378, 0.09705253969877958, 2.442133298942021, 31.66163124356951, 61.881865637642996, 50.814795766557964, 39.289902142116, 39.23054715565273, 47.76907723290579, 52.65727390561785, 55.53050340924944, 41.29332487923758, 2.28616578238351, 0.2277426522757326, 3.0370593411581854, 5.6783245376178195, 8.83654178891863, 6.395592723573957, 5.6990132331848145, 28.918095077787125, 51.042630672454834, 52.26495429447719, 52.71036856515067, 47.85871246882847, 49.689802510397776, 48.39566578183855, 46.91805492128645, 49.088269165584016, 46.059393065316335, 47.26207412992205, 49.358891078404014, 48.4046949659075, 45.551340784345356, 46.65258509772164, 47.550730092184885, 46.530984674181255, 45.285593032836914, 44.38435609000069, 42.09402138846261, 42.362201009477886, 40.63414927891323, 39.3450152533395, 40.37681926999773, 37.92544616971697, 37.766311577388215, 36.28790862219674, 36.95641565322876, 37.14561857495989, 36.86796161106655, 35.319458280290874, 38.01930243628365, 35.01847621372768, 38.96139131273542, 37.16404172352382, 35.51871177128383, 36.66584546225411, 36.26998574393136, 38.129462650844026, 37.21520825794765, 36.775251797267366, 36.53464262826102, 37.010382311684744, 42.10654551642281, 47.84434012004307, 48.10528319222586, 49.73884984425136, 45.88539627620152, 35.58799920763288, 41.525898456573486, 49.46944734028408, 48.960363251822336, 48.22454902103969, 46.1142247744969, 49.98703602382115, 52.73419393811907, 45.59762968335833, 43.91731902531215, 45.13024868283953, 47.82731703349522, 46.994182859148296, 41.669531617845806, 39.992052350725444, 39.4505410194397, 40.02725887298584, 38.55670043400356, 39.53412437438965, 39.22621842793056, 35.618647711617605, 36.27396706172398, 35.56756802967617, 38.60777316774641, 36.688239506312776, 36.15730333328247, 37.63480997085571, 36.67258174078805, 37.35601002829415, 38.54864052363804, 37.17515536717006, 36.84207262311663, 37.50410393306187, 36.71224205834525, 39.35155003411429, 38.34665639059884, 34.59029000146048, 37.0141795022147, 36.37730414526803, 35.51162460872105, 37.80317177091326, 37.260520935058594, 36.43814952032906, 36.98267984390259, 36.179353441510884, 37.27997241701399, 35.402433667864116, 33.77293171201433, 35.12194183894566, 37.06302533830915, 39.85385962894985, 39.292702266148154, 43.42060620444161, 44.5511337007795, 46.97645105634417, 45.5758991922651, 52.50537238802229, 48.85960394995553, 49.10330506733486, 47.55726487295968, 50.30529131208147, 49.1930445262364, 51.50590876170567, 51.36895281927926, 49.692626953125, 45.45360394886562, 29.421285356794083, 5.15837607213429, 2.2593283653259277, 8.047812683241707, 8.103964550154549, 7.767145412308829, 0.2835880113499505, 0.984209941966193, 39.67574255807059, 57.1409638268607, 50.21599306379046, 40.558924606868196, 36.044148445129395, 54.244100025721956, 54.20569038391113, 33.009303842272075, 0.794135564139911, 0.11218875606677362, 0.11469964097653117, 0.09010226479066269, 0.09241289366036654, 0.15789412174906048, 0.11758633250636713, 0.10353419118161712, 0.11262898958687272, 0.10352463062320437, 0.06955792076353516, 0.07889392479721989, 0.1000650180503726], [0.03209140870187964, 0.024096907415826405, 0.030787987035832236, 0.013133966397227985, 0.02938053577340075, 0.05758236800985677, 0.032028671354055405, 0.039981529249676635, 0.05100997943165047, 0.022181348775380423, 0.02446447662077844, 0.0338195695408753, 0.046589442528784275, 0.04527455022824662, 0.032848490934286795, 0.12622869733188832, 0.358550524605172, 10.733638848577227, 44.694169316973, 39.414472920554026, 27.255467585154943, 24.327877112797328, 40.86359964098249, 43.1576828956604, 47.391942909785676, 38.90953343255179, 5.417802265712193, 0.029356067800628285, 0.3763888031244278, 2.560657624687467, 3.6762710298810686, 1.8709136417933871, 2.0186358179364885, 21.05635949543544, 43.486082553863525, 47.701704025268555, 48.26279885428292, 47.33815690449306, 46.36614908490862, 45.07596240724836, 45.49862827573504, 44.528044836861746, 44.79189225605556, 45.86808483941214, 44.2829783984593, 44.62031691414969, 43.726497173309326, 46.3751539502825, 42.76114572797503, 42.78220224380493, 44.37772056034633, 40.9113233430045, 42.30642434528896, 39.55914831161499, 38.96036992754255, 40.199803488595144, 37.49666588647025, 36.42810589926583, 35.73819841657366, 33.6327657018389, 33.89402839115688, 32.105134759630474, 31.780528817858013, 32.956831046513145, 33.380334172930034, 34.87110839571272, 33.32566922051566, 33.40399973733084, 34.5506157875061, 34.65695449284145, 34.19668844767979, 33.012305464063374, 33.81683390481131, 31.711880615779332, 33.8604998588562, 33.94667141778128, 44.68827377046858, 45.46644074576241, 43.475886072431294, 43.59489829199654, 42.53287655966622, 42.75450325012207, 33.925434248788015, 34.29876095908028, 46.91767624446324, 46.53458036695208, 42.16486522129604, 44.711845534188406, 46.08848864691598, 40.15115567616054, 40.1432659966605, 41.770711285727366, 45.87157283510481, 43.285911900656565, 39.274953092847554, 36.134617464882986, 34.08273799078805, 34.91296781812395, 38.043238980429514, 35.8656005859375, 34.178616183144705, 33.75479343959263, 33.8017042023795, 32.70052242279053, 33.94889484133039, 34.200096539088655, 34.12009150641305, 34.57674101420811, 34.00788852146694, 34.847713811056956, 33.8119215284075, 33.28426143101284, 32.85576949800764, 34.54583542687552, 33.46614442552839, 33.746459075382774, 35.543280601501465, 33.86338683537075, 34.59775584084647, 33.48084681374686, 33.8732602255685, 33.52533960342407, 33.47763327189854, 33.9593414579119, 33.88206359318325, 32.715971742357524, 32.16273880004883, 33.451681750161306, 32.82450955254691, 31.559228692735942, 34.542243208204, 35.036788191114155, 37.46199784960066, 38.0620824950082, 42.55631978171212, 40.85807582310268, 43.33908299037388, 44.08888047082083, 45.55556876318795, 45.89567961011614, 45.91514846256801, 48.9320250238691, 48.47858558382307, 50.18159948076521, 49.20371348517281, 46.89112370354788, 38.9219776562282, 16.889295509883336, 1.8051385198320662, 1.0272377473967416, 0.765326487166541, 1.4455199539661407, 1.132342821785382, 0.07811189283217702, 1.6390504091978073, 35.046255111694336, 42.97656420298985, 32.548471518925254, 33.80318764277867, 30.581596306392125, 38.327600955963135, 38.42810664858137, 13.934800744056702, 0.14930358342826366, 0.04427919703136597, 0.051705912088177035, 0.0532820030514683, 0.0370844255999795, 0.010161497014840799, 0.03142984723672271, 0.049811001268348525, 0.026842887746170163, 0.055414465588650534, 0.03428503777831793, 0.034819472315055985, 0.026208443933033516, 0.029885620277907168, 0.009743320123691643, 0.0426848806174738, 0.015053175556074296, 0.011381168799873973, 0.030145991127938032, 0.030629301443696022, 0.0343316904535251, 0.10212977975606918, 0.0443552913410323, 0.043017939531377385, 0.03603246561916811, 0.029718276578933, 0.058445227066321034, 0.0095875496876293, 0.11168993104781423, 0.4900088406034878, 16.36565841947283, 53.654455048697336, 43.63472884041922, 33.52486712591988, 28.67434184891837, 44.890011242457796, 47.61155462265015, 50.55677441188267, 43.43189355305263, 5.230965639863696, 0.05511189325313483, 0.3530901361789022, 3.3180529602936337, 5.593411471162524, 3.2007558601243153, 3.0129923011575426, 24.614688328334264, 45.59325926644461, 49.184216839926584, 49.18890687397548, 48.58273213250296, 47.111954825265066, 45.9840224811009, 47.329190254211426, 46.18329681668963, 47.20062773568289, 46.74983555930001, 45.73924786703927, 44.569271973201204, 46.4504828453064, 46.94201578412737, 43.751931054251536, 44.384717396327424, 45.651103019714355, 43.16899108886719, 44.379606996263774, 42.29021767207554, 41.98983315059117, 40.81634841646467, 39.20371668679373, 36.86735711778913, 36.93272924423218, 36.22091409138271, 35.69190604346139, 33.5595247404916, 34.80638245173863, 34.86626550129482, 35.526650088174, 35.839294706072124, 34.64634459359305, 34.68429912839617, 35.72546236855643, 34.47708995001656, 34.865421295166016, 34.515305042266846, 34.319952964782715, 32.609914439065115, 35.68558318274361, 36.147179807935444, 45.556902817317415, 46.59946264539446, 45.34097364970616, 45.38392741339547, 45.31871509552002, 41.89125905718122, 33.755568163735525, 40.53327880586897, 49.565461022513254, 46.45246308190482, 43.38571235111782, 47.29737792696272, 48.1906487601144, 43.31891236986433, 43.28310482842581, 44.05730438232422, 46.07626676559448, 44.25098194394793, 42.12247426169259, 38.99333218165806, 36.19187756947109, 36.835037572043284, 38.2221794128418, 37.68706737245832, 35.92604643957955, 35.19765288489205, 34.954507623400005, 34.084864139556885, 34.110951151166645, 35.549711159297395, 36.140995911189485, 35.67671728134155, 35.20221785136631, 35.688174860818044, 35.1549596786499, 35.421221596854075, 35.455736773354666, 35.966748986925396, 34.95996543339321, 34.462547370365684, 36.50728757040841, 35.32746607916695, 35.96730484281267, 36.37938513074602, 34.76026725769043, 34.80621916907174, 35.75085803440639, 35.82680879320417, 34.743164266858784, 34.70583159582955, 32.50542395455496, 35.090605463300435, 34.08081333977835, 33.31132466452462, 34.85812568664551, 37.03981488091605, 39.38467557089669, 41.25690589632307, 43.885701247623985, 42.455362456185476, 45.24835763658796, 46.25191722597395, 47.261761460985454, 47.26575320107596, 45.0337347303118, 49.92656237738473, 50.450275897979736, 51.252379417419434, 49.71775163922991, 48.48625292096819, 40.27636568886893, 19.9928925377982, 2.7487453605447496, 1.714059795652117, 3.1348617502621243, 3.244690839733396, 2.321039442505155, 0.08986844840858664, 1.5009716813053404, 38.863515513283865, 47.77236025674002, 38.13515322549002, 33.192159584590364, 30.337381022317068, 43.96463278361729, 45.034992354256765, 17.972462347575597, 0.12243160179683141, 0.018052003479429653, 0.028535362732197558, 0.015633718243667057, 0.07860386464744806, 0.04453921504318714, 0.04399186459236911, 0.08089763870728867, 0.037539033884448667, 0.012126778701453336, 0.03751388398398246, 0.007675965566055051, 0.022032406946112002, 0.12378540129533835, 0.14051819699151175, 0.16293680401785032, 0.09007434307464532, 0.07057482083993298, 0.11300719143556696, 0.11839906818100385, 0.16478727757930756, 0.13206789828836918, 0.1217357369938067, 0.103967903980187, 0.08888643181749753, 0.18242578181837285, 0.20772193372249603, 0.09589812093015228, 0.18137117555098875, 0.583016992679664, 19.6222756249564, 59.254925455365864, 48.84627383095877, 38.612074102674214, 32.56006458827427, 50.955576692308696, 52.75297144481114, 56.428620610918315, 46.227570738111226, 6.622817925044468, 0.12820981602583612, 1.5229850943599428, 10.833117076328822, 11.525122914995466, 6.463409747396197, 3.9903613073485236, 26.92915759767805, 47.97917686189924, 49.79308748245239, 51.90001058578491, 51.76306506565639, 49.346380846840994, 47.138587270464214, 50.049340520586284, 47.376629080091206, 47.56861822945731, 48.900223118918284, 47.85326508113316, 47.06895589828491, 46.78307226725987, 50.166726861681255, 45.82754210063389, 46.59020069667271, 48.67013004847935, 44.902677808489116, 46.519356863839285, 42.406627791268484, 43.94212062018258, 43.857130255017964, 41.70344924926758, 39.74748618262154, 39.845622539520264, 37.40163190024239, 38.233400753566194, 35.380043097904746, 35.15070390701294, 35.29433012008667, 37.001426083701, 37.60377584184919, 35.83442401885986, 36.496455328805105, 38.01658916473389, 37.64704574857439, 37.02470602308001, 34.828453404562815, 36.9868974004473, 34.13101407459804, 37.63651575360979, 36.471323694501606, 47.79330907549177, 48.4231459072658, 48.142230238233296, 46.24116836275373, 45.20912115914481, 44.4783547946385, 37.33407803944179, 40.764678137642996, 49.51767478670393, 48.99811628886631, 45.45206144877842, 48.628194195883616, 49.71556295667376, 45.46846614565168, 43.9530153955732, 46.17434058870588, 48.42442090170724, 46.37468842097691, 44.85249097006661, 41.357300417763845, 37.46545805249895, 39.17636857713972, 42.46009417942592, 39.37715067182268, 37.91597230093819, 38.69852706364223, 38.00476680483137, 35.87979228155953, 36.71643877029419, 38.72040694100516, 38.42340966633388, 38.1476217678615, 37.34614706039429, 37.751518862588064, 38.250305720738, 37.17039237703596, 36.193451336451936, 38.12350109645298, 37.650495529174805, 36.511307103293284, 38.57923691613333, 35.23900508880615, 37.15971646990095, 37.77120310919625, 36.03913531984602, 37.696767057691304, 36.31848417009626, 37.14044911520821, 37.60537392752511, 35.211900166102815, 34.43382004329136, 37.75961351394653, 35.98037787846157, 35.5511702810015, 37.8148238999503, 37.85826751164028, 41.97518982206072, 43.26365682056972, 47.944408076150076, 44.7485111781529, 47.90613045011248, 47.771842615945, 47.98661143439156, 48.61296721867153, 47.222531931740896, 50.028565406799316, 52.25288527352469, 53.0692777633667, 52.004851954323904, 48.70833124433245, 43.8370395387922, 20.45889605794634, 3.476968901497977, 2.6987391752856116, 6.368636318615504, 6.783191033772059, 4.672947560037885, 0.5270660806979451, 2.212462765829904, 41.84424407141549, 53.50472831726074, 43.80681487492153, 45.01435967854091, 40.7074145589556, 51.88528387887137, 53.12637458528791, 23.08023078101022, 0.4664131924510002, 0.11170512344688177, 0.14712954365781375, 0.17413470814270632, 0.15175639252577508, 0.11577745314155306, 0.16133711699928555, 0.15131883243364946, 0.1692617546234812, 0.19688226894608565, 0.07787593906479222, 0.10685082964066948, 0.10491690305726868], [0.023744011530652642, 0.08807083272508212, 0.016433186862351637, 0.024022307579538653, 0.05476732638531497, 0.01561205431685916, 0.05144912390304463, 0.0031587068889556186, 0.018255519880247966, 0.016433042673660175, 0.06083228612052543, 0.021957452575277005, 0.01851148873434535, 0.11677242975149836, 0.0549964914098382, 0.12246229872107506, 0.011919733070369278, 7.797569836888995, 38.63714320319039, 41.69802965436663, 29.285771165575298, 25.638844115393503, 38.99749067851475, 38.88251188823155, 43.86925138745989, 41.15715060915266, 9.536314845085144, 0.013537729508243501, 0.11676003970205784, 2.1621104734284535, 2.565200226647513, 1.6656837229217802, 1.8591090866497584, 13.949354614530291, 44.86984757014683, 44.65994943891253, 47.27356992449079, 46.77529028483799, 46.37810346058437, 45.1385726247515, 44.98433998652867, 43.91109691347395, 44.65134409495762, 44.57751601082938, 43.50395679473877, 44.725127015795024, 46.27346706390381, 45.081958702632356, 41.91765178952898, 43.81464202063424, 45.53011056355068, 43.77558619635445, 45.5443126814706, 41.03541816983904, 43.756954601832796, 41.112709930964876, 40.509661878858296, 38.95782688685826, 38.90298822947911, 37.0211763381958, 34.9599689074925, 33.72888013294765, 34.10830736160278, 33.546302318573, 34.50863824571882, 33.383294105529785, 33.3728266443525, 32.09146417890276, 32.79158551352364, 33.51969766616821, 31.780421120779856, 33.375814369746614, 33.96638693128313, 31.513419219425746, 31.719561849321636, 35.84181342806135, 46.40768541608538, 45.28645460946219, 45.29411847250802, 45.31163488115583, 46.555084500994, 44.28148800986153, 43.62618603025164, 41.619726930345806, 37.684288093021934, 43.94464976446969, 46.994078636169434, 42.31297649656023, 48.572678089141846, 42.391373021262034, 40.95918948309762, 43.081367356436594, 44.582411016736714, 40.90023054395403, 39.19786977767944, 35.90230097089495, 35.54738698686872, 36.54006222316197, 37.333567346845356, 37.96656560897827, 38.99523251397269, 36.99762889317104, 35.42578656332833, 34.15334905896868, 33.8478993007115, 32.693515164511545, 33.39275060381208, 34.41715478897095, 33.71296180997576, 33.6299204145159, 33.55638068062918, 33.33248540333339, 31.737363134111675, 33.978515011923655, 33.419299670628135, 34.66861704417637, 33.664935861315044, 34.1952223777771, 35.43545150756836, 33.46663079942976, 32.97311067581177, 35.32749734606062, 35.5872175352914, 34.76299442563738, 34.426611287253245, 33.542185510907856, 32.386769567217144, 31.347447599683488, 31.818351336887904, 32.32684482846941, 32.029983043670654, 36.91130794797625, 39.31310217721121, 42.66930791309902, 42.860032490321565, 46.09911939076015, 45.96472038541521, 45.53469984872, 47.21517031533377, 41.56288371767317, 45.83452156611851, 45.68573978969029, 46.7266389983041, 45.61061239242554, 47.46134499141148, 49.002542291368755, 34.77269063677107, 8.890266128948756, 0.3537663370370865, 1.1330594633306776, 2.506539842912129, 1.737773346049445, 0.7409066089562008, 0.1090125607858811, 2.1602405394826616, 40.12065308434622, 43.319318839481895, 32.58339663914272, 20.752111775534495, 31.481627736772808, 45.10062851224627, 39.521423067365376, 7.6540078946522305, 0.10952285983200584, 0.038953060151210854, 0.03342922191534724, 0.06830658005284411, 0.0325662000104785, 0.058522858257804594, 0.027922107871355753, 0.03565473535231181, 0.009192844170943966, 0.02771124802529812, 0.037169591922845156, 0.056149281694420745, 0.0358902955693858, 0.06749857376728739, 0.023350649513304234, 0.030017490166106393, 0.0859261192381382, 0.07859266881964036, 0.0743990849171366, 0.037969771306961775, 0.020189928223512003, 0.014802908092471105, 0.04399078572168946, 0.05322023600872074, 0.023005909619054625, 0.03807962951915605, 0.06503357818084103, 0.042919087157185586, 0.016086083969899585, 0.09245255403220654, 10.623126881463186, 45.38647740227835, 44.8166869027274, 34.082633767809185, 25.643052986689977, 44.38275105612618, 45.608989988054546, 49.58943230765206, 45.98434557233538, 10.60633134841919, 0.054940732794680765, 0.4315516916768891, 3.5095427078860144, 7.111515998840332, 3.006174381290163, 2.3574931664126257, 17.793506281716482, 46.48207630429949, 45.93927608217512, 50.02706112180437, 47.77312108448574, 46.64256579535348, 47.43448672975813, 46.97901841572353, 45.87463699068342, 46.60930129459926, 45.52588953290667, 45.11069645200457, 45.41091421672276, 46.446484157017295, 47.09776312964303, 42.818770612989155, 44.395924840654644, 45.65992375782558, 44.689010279519216, 45.6753557068961, 42.4760924066816, 43.961335863385884, 43.269180638449534, 42.10422134399414, 40.88852630342756, 40.255312647138325, 39.69442973818098, 35.93625334330967, 35.39521101542881, 34.86906909942627, 35.6526209286281, 36.397061347961426, 35.9248617717198, 35.106099946158274, 33.30180563245501, 34.85760804585048, 35.53054107938494, 34.67538806370327, 34.51371737888881, 36.092316831861226, 32.36404200962612, 32.70949602127075, 37.482164996010916, 47.59201281411307, 47.394051688058035, 47.17961638314383, 45.322929177965435, 47.12866176877703, 44.684216022491455, 43.98743329729353, 42.46209526062012, 40.35772214617048, 48.016603333609446, 48.30818101337978, 44.508631569998606, 50.97264494214739, 44.33190066473824, 42.48983941759382, 45.16042818341936, 47.20307002748762, 42.27553960255214, 41.619435106004985, 38.118349007197786, 37.19512448992048, 37.662859848567415, 39.941340923309326, 40.26460238865444, 38.418438230242046, 37.78334508623396, 36.724050521850586, 36.24836989811489, 35.66549594061715, 35.290981088365825, 36.12058557782854, 36.42972482953753, 35.85167292186192, 35.623157092503135, 35.69662734440395, 36.132130009787424, 33.673982415880474, 35.97338799067906, 35.040929317474365, 36.580080372946604, 35.136404514312744, 35.61401673725673, 36.14220837184361, 34.79521322250366, 34.51899453571865, 36.07341773169381, 36.52769790376936, 35.70891523361206, 34.87925863265991, 34.85915054593767, 35.1729485648019, 33.269149099077495, 32.56592539378575, 33.22574370247977, 33.720597880227224, 38.70864016669137, 41.172394956861226, 44.40505477360317, 44.04376234327044, 45.974823066166465, 46.09878587722778, 47.68781805038452, 48.147441387176514, 45.29900653021676, 45.980027266911094, 46.34041295732771, 47.14981208528791, 46.894959109170095, 48.45632355553763, 49.106473445892334, 36.284837518419536, 10.541490759168353, 1.5038411787578037, 2.4276510817664008, 4.707458828176771, 3.5181532629898618, 1.5079971786056245, 0.12210336726691041, 2.5209501896585738, 42.85765620640346, 48.64839260918753, 40.16619505201067, 27.143525157655986, 35.38972888674055, 48.920949595315115, 45.84711170196533, 10.342250296047755, 0.0762679942750505, 0.0601476307160088, 0.038229897884385924, 0.09344449080526829, 0.008586439121115421, 0.11385538056492805, 0.04944420559331775, 0.009161026815750768, 0.0386961973272264, 0.046943895651825836, 0.04146203159221581, 0.011597948015800543, 0.0028345189722520964, 0.11386466292398316, 0.10611548088490963, 0.08667649075921093, 0.11103726856942688, 0.12982472937021935, 0.10567258750753743, 0.1263983446572508, 0.15817004122904368, 0.12100298702716827, 0.13068801590374537, 0.20252590253949165, 0.1806183952305998, 0.1207042687705585, 0.14341411659760134, 0.107111224239426, 0.22217132337391376, 0.149168677095856, 14.680609089987618, 53.53324372427804, 52.264071873256135, 39.05653299604143, 35.1395138331822, 49.26677533558437, 48.80750983101981, 53.15182931082589, 50.2002067565918, 13.118097322327749, 0.13177170418202877, 1.2361015741314207, 10.382424780300685, 10.614007370812551, 6.804036063807351, 3.3727135700838904, 19.800693205424718, 50.33535964148385, 47.28572579792568, 52.423682417188374, 49.78411735807146, 47.963546889168875, 48.833037512642996, 49.02123294557844, 47.002791677202495, 47.97281926018851, 46.833755901881624, 46.49101863588606, 48.23417575018746, 47.95004653930664, 48.91184050696236, 44.51604182379586, 45.854209286826, 49.37271799360003, 47.20937899180821, 47.84180055345808, 43.70349863597325, 45.725365366254536, 44.161642006465364, 45.73004845210484, 42.28578472137451, 42.754353863852366, 41.3057656288147, 36.9351715360369, 37.06723942075457, 37.52165508270264, 36.95302145821707, 38.21750674928938, 38.00930745261056, 36.672786712646484, 35.67079046794346, 36.93570307322911, 36.769557748522075, 36.292793205806184, 36.470885957990376, 39.28172063827515, 34.6940370287214, 34.23960747037615, 39.07507773808071, 50.657981872558594, 49.68358734675816, 48.10411589486258, 46.91663401467459, 48.48291778564453, 46.010634081704275, 44.393242835998535, 46.196071079799104, 42.764644145965576, 47.38014139447893, 48.40791545595442, 45.29962144579206, 52.662672655923025, 47.071735177721294, 46.416412353515625, 45.36357961382185, 49.17042466572353, 43.96373994009835, 43.43565252849034, 39.032207352774485, 39.270384652274, 40.03877551215035, 41.01179082053048, 43.75346313204084, 41.320322104862754, 40.01967144012451, 38.75036062513079, 38.420540060315815, 36.333707673209055, 37.18944433757237, 37.267639364515034, 37.553974628448486, 37.245293957846506, 36.8443273135594, 38.17214543478829, 38.80513327462332, 36.54233775820051, 36.55454574312483, 37.2527493749346, 37.5315180506025, 36.85572583334786, 36.88522441046578, 39.29361942836216, 35.458463941301616, 35.713653905051096, 38.526972566332134, 37.37313733782087, 37.518052441733225, 36.90713555472237, 36.22462442943028, 37.6965377671378, 33.822187491825645, 35.550465038844514, 35.62623167037964, 35.31911781855992, 41.03379576546805, 43.39249726704189, 46.928306988307405, 46.823889459882466, 50.432335649217876, 49.06959935597011, 50.50357205527169, 49.98691095624651, 45.15103421892439, 47.73520129067557, 47.38257326398577, 47.66859933308193, 45.53705528804234, 48.68744495936802, 49.12903772081648, 38.96403162819998, 11.40233782359532, 1.6775221505335398, 3.9070593544415066, 8.380117229052953, 7.693491901670184, 4.7850198319980075, 0.21149313636124134, 2.7604676229613165, 47.31168079376221, 53.9103433064052, 44.72185788835798, 32.226002148219514, 43.394609519413535, 55.672573225838796, 52.94962978363037, 13.70763633932386, 0.24149395152926445, 0.1357310102986438, 0.14188682926552637, 0.14815035888126918, 0.07190424057521991, 0.23441905687962258, 0.1290588126118694, 0.16459270087735994, 0.17461521950151238, 0.12744828260370664, 0.07600704327757869, 0.1387857613818986, 0.08324503738965307], [0.046410563734493086, 0.09913608325379235, 0.035578753000923564, 0.02071060037373432, 0.04206309148243495, 0.05348850839904376, 0.03906232125258871, 0.041902034410408566, 0.02128998955179538, 0.022343927462186133, 0.042771370083625825, 0.024146599927917123, 0.013797387048336012, 0.05639177993206041, 0.048773758712091615, 0.11402881411569459, 0.0528644631350679, 4.369168409279414, 33.94543811253139, 47.45721776144845, 30.881768907819474, 32.872066497802734, 37.91118499210903, 36.21777697971889, 44.83595425742013, 45.10569722311837, 17.1000691141401, 0.21361420968813555, 0.06180379220417567, 1.5097936136381966, 4.620019657271249, 2.91401412657329, 0.7374686620065144, 14.57215986933027, 41.27550622395107, 44.62277657645089, 47.279983111790244, 45.10348422186715, 47.86560855593, 45.67925712040493, 44.37262405667986, 43.300454480307444, 45.031751019614084, 43.59542635508946, 44.086653573172434, 44.560954979487825, 44.08242906842913, 43.71152033124651, 42.62489850180489, 43.801058292388916, 44.40396043232509, 44.28450700214931, 46.335385935647146, 43.6398218699864, 43.97087574005127, 43.447082315172466, 41.56971032278878, 41.68670409066336, 42.781271185193745, 39.38257374082293, 37.50961038044521, 34.10651820046561, 32.0128835269383, 33.423888955797466, 32.892553261348176, 32.3556798526219, 33.120488916124614, 32.58362592969622, 31.977934088025773, 32.403347969055176, 33.79540913445609, 32.6543481690543, 33.78412873404366, 31.642172813415527, 32.08115305219378, 31.617381640842982, 42.097116810934885, 45.30229997634888, 45.56080075672695, 45.65362868990217, 46.86226783479963, 47.01674713407244, 46.22639996664864, 44.229473795209614, 46.69691113063267, 39.52081857408796, 44.15616682597569, 47.81952462877546, 46.61192076546805, 42.34556354795183, 40.847778592790874, 44.24133784430367, 44.61700957162039, 43.60879468917847, 37.80718435559954, 36.366763728005544, 34.06399869918823, 38.88612495149885, 38.9056077003479, 39.3088880947658, 38.670300006866455, 34.989880902426584, 33.30893101011004, 33.979519026620046, 33.851533208574565, 32.70850590297154, 33.76092869894845, 33.97165713991438, 34.55501052311489, 35.2519530568804, 33.876914978027344, 32.368606976100374, 32.74741234098162, 33.83445801053728, 32.72881201335362, 33.15133891786848, 33.0668488230024, 33.423829896109446, 33.67418738773891, 33.493871212005615, 35.37832341875349, 37.89768464224679, 39.28591735022408, 38.8707902772086, 38.053435461861746, 35.58933673586164, 31.17105368205479, 32.356843675885884, 31.425194467817033, 32.395506926945274, 32.32415934971401, 37.04950761795044, 40.0657935823713, 46.28913177762713, 44.37854739597866, 46.46984052658081, 46.1112231527056, 44.59034933362688, 45.58637012754168, 47.223886830466135, 47.00306960514614, 48.292690004621235, 48.203214577266145, 48.10535267421177, 46.73876013074602, 46.217766829899375, 28.549534831728252, 6.199690001351493, 0.6441459953784943, 2.2251942540918077, 2.2072865750108446, 1.6143477175916945, 0.8088464204754148, 0.09373461880854198, 2.6482487874371663, 42.2602014541626, 41.206635679517476, 32.61887066704886, 21.103402273995535, 28.140718460083008, 41.93647445951189, 36.99813263756888, 3.549693524837494, 0.126634895535452, 0.02832934762617307, 0.05155278030516846, 0.01514503053788628, 0.09764051743383918, 0.03806552277611835, 0.03517567266577056, 0.07674755568483047, 0.03209759354857462, 0.021124357457405755, 0.06717052244182144, 0.06358223248805318, 0.034693454791392596, 0.045623364725283215, 0.015233229912285293, 0.004041026753839105, 0.0640564945393375, 0.010885099481259073, 0.01041564145790679, 0.0459534075510289, 0.03554355738950627, 0.016298803001908318, 0.04427685269287654, 0.08061268792620727, 0.04906449739688209, 0.017907996296084354, 0.10822968065206494, 0.022865023696795106, 0.102821573348982, 0.07220604616616454, 5.8746854066848755, 41.501597132001606, 53.07275186266218, 34.921757289341514, 33.13458333696638, 44.26781742913382, 40.642316886356895, 49.16039146695818, 50.13856928689139, 18.50875210762024, 0.07673444638827018, 0.14826277856315884, 1.6850272906678063, 4.183195531368256, 3.954209395817348, 1.6941568979195185, 15.131027800696236, 45.58080809456961, 46.50327525820051, 47.8827462877546, 47.39390924998692, 47.79849590573992, 47.786326135907856, 47.940326009477886, 45.10975497109549, 45.98395994731358, 44.61081525257656, 45.79904753821236, 45.96879550388881, 47.42176457813808, 45.6264716557094, 43.52325194222586, 45.062114647456575, 43.42992026465279, 45.28194522857666, 47.39067486354283, 45.90070315769741, 45.75587838036673, 45.14315496172224, 42.48737975529262, 44.03837054116385, 43.42341327667236, 40.014297008514404, 39.79264252526419, 34.568899972098215, 34.26825489316668, 35.71727739061628, 34.47807312011719, 34.67963688714163, 34.20327186584473, 34.85434239251273, 33.42491034099034, 34.677906785692485, 35.08836119515555, 34.05294064113072, 34.581854888371055, 33.44541447503226, 33.97882073266165, 33.60085262571062, 44.57991313934326, 48.46930973870413, 46.36819185529436, 47.24580839702061, 49.202935286930625, 49.53233201163155, 46.69502122061593, 45.08163561139788, 45.01528378895351, 40.68609748567854, 49.51107052394322, 49.05657148361206, 49.21380574362618, 44.194176946367534, 42.09634903499058, 46.55824245725359, 48.14408540725708, 43.820249216897146, 39.7179285458156, 37.61847128186907, 36.272796290261404, 39.869187355041504, 40.949816363198416, 40.84039265768868, 39.49399505342756, 35.6943552834647, 35.761766706194194, 35.55343886784145, 35.276952675410676, 34.6006532396589, 35.18182488850185, 36.91737372534615, 35.24268763405936, 35.276164054870605, 35.609462193080354, 34.03207867486136, 34.584978103637695, 35.54213414873396, 33.95907047816685, 34.22862236840384, 34.11681890487671, 35.27373913356236, 34.27391072681972, 35.65242985316685, 36.818205560956685, 38.33289548328945, 40.573467186519075, 39.771172591618125, 39.12263468333653, 37.00624465942383, 32.11442102704729, 33.86321660450527, 33.76561525889805, 33.738812582833425, 34.5490802356175, 38.6817958014352, 42.5320462499346, 46.10947915485927, 47.48376682826451, 47.871997424534385, 47.377098083496094, 48.02850559779576, 46.81942524228777, 48.1811922618321, 47.43575130190168, 48.52222374507359, 49.54772227151053, 47.90936483655657, 46.16814974376133, 47.31382778712681, 31.613917963845388, 6.770938319819314, 1.7067426911422183, 3.3637178242206573, 4.07825688804899, 4.12669712305069, 1.6169041118451526, 0.12725129031709262, 3.1767420172691345, 45.76365688868931, 48.018232686179026, 38.324762616838726, 25.5615645136152, 33.73078046526228, 47.65803459712437, 42.49864278520857, 4.838871410914829, 0.1040056101711733, 0.08015158945428473, 0.03150747164285608, 0.08383821270295552, 0.014432222715445926, 0.015310068914134587, 0.062360218060868125, 0.07827550119587354, 0.04100626640553985, 0.02183947229890951, 0.07824610705886569, 0.06755014242870466, 0.043528934075896225, 0.200779258406588, 0.13378787599503994, 0.09286802780947515, 0.1487228117351021, 0.10517210686313254, 0.21011180191167764, 0.11354745458811522, 0.11279756482690573, 0.09215028703744922, 0.11163995694369078, 0.19422843706394943, 0.19371961722416536, 0.1452809021409069, 0.1666231354964631, 0.15776320520256246, 0.17955804855695792, 0.25061414071491783, 6.68304534469332, 48.561554023197715, 59.18877165658133, 41.42433316367013, 43.3402989251273, 48.50951548985073, 44.987563950674875, 52.86768967764718, 54.47296673910958, 21.88592403275626, 0.3022846638091973, 0.8758796006441116, 3.70100314276559, 13.707129120826721, 7.247732392379215, 1.930899828672409, 18.265455722808838, 44.93803719111851, 49.0392496245248, 48.78068631035941, 48.435225350516184, 48.86836215427944, 48.68061140605381, 49.72596093586513, 46.16347360610962, 47.50450372695923, 46.29325900759016, 46.78355169296265, 47.38366413116455, 48.478700229099815, 46.601849351610454, 44.87022277287075, 45.9590437071664, 46.5389438356672, 48.76284333637783, 49.47578757149832, 47.69224057878767, 47.028076171875, 47.04107972553798, 43.66882017680577, 46.137761797223774, 46.06159564426967, 43.185847418648855, 40.73340776988438, 36.46981593540737, 35.71325438363211, 36.90462030683245, 35.647399357386995, 36.64566789354597, 36.49803951808384, 37.69378975459507, 34.25838845116751, 35.30826473236084, 37.123398235866, 36.123733111790244, 36.687357085091726, 35.25440229688372, 36.14146491459438, 34.19638272694179, 45.62549195970808, 52.5953619820731, 49.66732161385672, 50.20889547892979, 50.85593605041504, 51.959421157836914, 48.83945417404175, 45.686775071280344, 46.736293520246235, 43.383349963596885, 48.532159669058665, 49.06341545922415, 50.86519105093819, 47.58137859616961, 44.400514125823975, 47.74576950073242, 49.39663369315011, 46.81476994923183, 41.41384138379778, 39.43179825374058, 37.607447964804514, 43.63139370509556, 43.178343364170615, 43.317415033067974, 42.66813366753714, 37.858066013881135, 37.34389236995152, 36.85678890773228, 36.40358918053763, 35.90115104402815, 36.071771008627756, 38.111341748918804, 38.868754455021445, 36.76813684191023, 38.25730603081839, 35.98905617850167, 35.68142121178763, 36.73999316351754, 36.46323251724243, 35.391490255083355, 35.533667768750874, 37.48712600980486, 36.46359729766846, 38.59222657339913, 38.933463028499055, 41.00143453053066, 43.639707224709646, 42.241187708718435, 41.27202517645699, 39.05474730900356, 33.028074400765554, 35.01535994665963, 34.75201627186367, 35.484703813280376, 36.60535444532122, 39.95694310324532, 45.153441769736155, 50.14218929835728, 48.393411091395784, 50.81031765256609, 49.29625654220581, 49.41851357051304, 48.7936829158238, 51.13630975995745, 49.773392813546316, 50.30707352502005, 51.08587973458426, 50.73380756378174, 48.69523388998849, 49.382706029074534, 34.952277251652305, 8.50049911226545, 2.2798893877438138, 6.028352635247367, 7.065072068146296, 7.179086361612592, 3.645772780690874, 0.23114732386810438, 3.7180991853986467, 49.7978435243879, 52.862252712249756, 43.21759373801095, 33.20562866755894, 39.44988094057356, 53.860139097486226, 48.296528884342735, 5.889576264790126, 0.23360049937452587, 0.11972074583172798, 0.08074578257011515, 0.11751347141606466, 0.15907422985349381, 0.1223663402987378, 0.12379713995116097, 0.20418470352888107, 0.08439627382904291, 0.10633918709520783, 0.2026866339147091, 0.21075612519468578, 0.14607721726809228], [0.03486463560589722, 0.057992766345185895, 0.0564710056808378, 0.038986474608204195, 0.08943806721695832, 0.027806473629815236, 0.012483822131928588, 0.04575718540166106, 0.005623734705815358, 0.025012907638613666, 0.011781694450681763, 0.014815673032509429, 0.02942495606839657, 0.06962195411324501, 0.05853024071880749, 0.05068940216941493, 0.021057431852178912, 1.4509187042713165, 24.989312614713395, 44.66712345395769, 41.40327664784023, 31.855763912200928, 23.657622609819683, 34.660748209272114, 38.74245704923357, 45.07334293637957, 25.325874669211252, 1.1915337656225478, 0.26353450598461287, 1.6961346375090736, 3.624733418226242, 2.597304161105837, 1.8809038485799516, 15.36121814591544, 41.21445935113089, 45.90716845648629, 46.491581439971924, 46.466217041015625, 45.50919648579189, 43.88633005959647, 45.04804801940918, 43.59865379333496, 45.29185683386666, 44.55477803094046, 46.02382871082851, 44.04226500647408, 44.131306171417236, 43.045566763196675, 39.921350955963135, 42.28206048692976, 41.0876338822501, 45.025883265904014, 44.31392567498343, 45.37863983426775, 44.33153935841152, 44.31299809047154, 44.267598560878206, 44.57903071812221, 41.24195337295532, 42.785856996263774, 40.02796758924212, 35.57801117215838, 33.41469301496233, 33.14038508278983, 32.80809095927647, 32.580700738089426, 32.65632493155343, 33.175390107291086, 33.55317061288016, 33.23875420434134, 33.412483487810405, 33.09715339115688, 33.875115394592285, 32.885094370160786, 32.794392585754395, 32.34241574151175, 36.1546664919172, 42.84785229819161, 43.82581124986921, 46.35308994565691, 45.007870061056956, 44.02958106994629, 45.76680094855172, 46.437454972948345, 42.67761101041521, 47.63517154966082, 41.66446985517229, 45.62500558580671, 50.566946574619834, 42.92426858629499, 42.675502232142854, 44.428650856018066, 45.951192242758616, 40.90024791445051, 39.01400307246617, 36.15077897480556, 36.095127378191265, 38.766952923366, 40.44112137385777, 40.282136167798726, 38.64410529817854, 36.055355889456614, 33.121142046792166, 32.94459179469517, 32.99845770427159, 33.34046540941511, 32.48725094114031, 34.657899447849815, 33.289448261260986, 36.32996259416853, 34.96391895839146, 33.331988607134136, 34.91986737932478, 33.58793592453003, 33.47618109839303, 33.35701949255807, 33.24659524645124, 33.51600817271641, 35.18051862716675, 38.883522851126536, 42.281963212149485, 43.43679550715855, 45.413339138031006, 45.09926666532244, 43.010422774723594, 42.35803209032331, 37.54937144688198, 31.8758442061288, 32.61124849319458, 33.220080920628135, 31.513068335396902, 33.13370091574532, 41.02541971206665, 44.90586008344378, 46.36028480529785, 44.032742500305176, 45.65615783418928, 45.911590984889436, 48.43330764770508, 47.203341007232666, 47.85293851579939, 46.8353887285505, 47.425610406058176, 49.22262300763811, 49.026871408735005, 43.84501607077462, 25.0275103364672, 3.110307250704084, 1.5405674023287637, 2.665264057261603, 3.946695787566049, 3.1985094206673756, 1.117004673395838, 0.17198468851191656, 3.278360507317952, 39.77915954589844, 40.222107206072124, 32.985422883714946, 24.778205496924265, 29.973879064832413, 43.64600576673235, 25.19814419746399, 1.109036609530449, 0.09201679884323052, 0.007104383781552315, 0.02580224912214492, 0.017756934044882655, 0.024568647013178894, 0.08997915139687912, 0.043515186956418414, 0.02388967603578099, 0.06269525829702616, 0.024694187865991677, 0.04729738186246582, 0.09724090780530657, 0.055087119939603975, 0.04739477538636752, 0.045114158120538504, 0.0316526543881212, 0.04755681972684605, 0.03750962278406535, 0.020860977304567183, 0.04302974943337696, 0.04242063872516155, 0.025290894954066192, 0.054068981536797116, 0.015529079662103738, 0.038158329403293986, 0.05568405772958483, 0.00513500883243978, 0.06490114171590124, 0.04307494665096913, 0.014256609370931983, 2.5907261712210516, 31.5902350289481, 51.64666189466204, 41.868260519845144, 37.043577330453054, 30.678051199231827, 40.890311990465435, 45.26286547524588, 50.2829841205052, 27.619629621505737, 0.9112012024436678, 0.23466973485691206, 1.4080872940165656, 4.663293472358158, 3.7757340584482466, 1.928200887782233, 17.946307591029576, 43.571757316589355, 46.59706204278128, 47.26153564453125, 46.75787462506975, 46.52546433040074, 45.13107899257115, 47.41568490437099, 45.34781762531826, 47.15964726039341, 46.10047081538609, 46.48218747547695, 46.36784791946411, 44.801842076437815, 44.85061148234776, 41.58573981693813, 42.99342400687081, 41.4175934110369, 46.61771208899361, 46.38985286440168, 46.37463630948748, 46.08708511080061, 45.21713243212019, 45.85094363348824, 44.53874853679112, 43.661889348711284, 44.569480419158936, 41.7596184866769, 36.88273695537022, 34.11615187781197, 34.88079765864781, 34.64907176154, 35.31647055489676, 34.70808628627232, 34.25319814682007, 34.99868427004133, 35.622635977608816, 33.98042924063546, 34.385314668927876, 34.76862941469465, 34.16192313602993, 34.28721652712141, 34.20773260934012, 38.81762613568987, 46.16475207465035, 44.89287042617798, 45.87532486234392, 46.53729016440255, 46.60203695297241, 48.428169454847065, 46.71414613723755, 42.70881537028721, 48.311363288334434, 43.3361473764692, 50.13745410101754, 50.97438546589443, 45.208700793130056, 44.82180425098964, 46.77932024002075, 48.03341450010027, 43.62549121039254, 38.884738785879954, 38.55361543382917, 37.663478238242014, 41.45030900410244, 42.067677293504985, 41.8632230758667, 40.561995710645405, 36.8174204145159, 34.35478775841849, 34.85684721810477, 34.905543667929514, 34.82183524540493, 34.57932226998465, 36.17006022589547, 36.91599798202515, 39.278760705675396, 35.00787673677717, 35.67800269808088, 36.76209190913609, 36.4529561315264, 35.76189872196743, 34.260886328560964, 34.86329167229788, 35.711423533303396, 35.75089277539934, 39.57998595918928, 44.94825799124581, 44.08076844896589, 46.67013277326311, 46.49578162602016, 45.54867615018572, 43.74597297395979, 39.045617376055034, 33.75387280327933, 33.415835993630544, 35.266189915793284, 33.74579899651663, 34.75710235323225, 43.44552591868809, 46.515351227351594, 47.243831634521484, 45.15672479357038, 46.98328808375767, 47.42810828345162, 48.86577047620501, 48.10577998842512, 48.451956612723215, 49.09910488128662, 48.74646643229893, 48.88781016213553, 50.54058163506644, 45.21616663251604, 27.4102942943573, 4.035631426743098, 1.7366945296525955, 3.7230780039514815, 6.1533806920051575, 5.138155077184949, 1.2450541108846664, 0.06669523580265896, 3.024885662964412, 43.77828209740775, 43.50517272949219, 38.662584032331196, 25.261312007904053, 36.2934741292681, 48.72043153217861, 33.12799991880144, 1.9128668648856026, 0.03159340810296791, 0.03178318416965859, 0.03685187129303813, 0.007457563803265137, 0.035082465702933927, 0.02865789258586509, 0.012092759500124624, 0.044133339143757305, 0.07765546268118279, 0.031412836363805194, 0.009388663440144487, 0.03488294587337545, 0.029554213596773998, 0.15605265913265093, 0.1218541142131601, 0.2247856238058635, 0.09247575314449412, 0.23787896122251237, 0.15773056766816548, 0.12695724038141115, 0.12029950906123434, 0.09552476382149117, 0.1360514009637492, 0.13513129390776157, 0.13123834851597035, 0.14032258891633578, 0.1592541773404394, 0.17945440911820956, 0.26179210948092596, 0.08947280142456293, 3.0981754788330624, 38.71934734072004, 59.54538794926235, 50.096463203430176, 44.96335295268467, 32.959353242601665, 44.559902327401296, 47.27011319569179, 55.40776695523943, 31.775084904262, 1.6566297858953476, 0.860660548721041, 5.829207709857395, 9.300507749829974, 7.024356927190508, 4.178602772099631, 19.47242556299482, 44.36049597603934, 49.056435993739534, 49.09733656474522, 47.31219148635864, 48.94170386450631, 46.80427469526018, 49.13473871776036, 45.96962581362043, 47.999066080365864, 48.79572916030884, 48.9280298096793, 48.287148816244944, 46.44422599247524, 46.685880865369526, 43.89538703645979, 42.55507605416434, 42.69888292040144, 47.180144446236746, 48.57554074696132, 49.175837312425884, 47.178007875170024, 46.43965755190168, 47.19953339440482, 46.624205180576865, 45.130460602896555, 46.29235921587263, 44.46085575648716, 39.63745450973511, 36.66029037748064, 37.258300985608784, 37.662397793361116, 35.807062012808665, 36.660241740090505, 36.20930017743792, 35.731712273189, 37.56144394193377, 36.72730575289045, 37.09316314969744, 36.63465152468, 35.296921798161094, 35.7548428262983, 34.92560659136091, 38.84406055722918, 47.68080384390694, 47.55653878620693, 49.573100566864014, 48.010391644069124, 47.77841561181204, 49.73895754132952, 48.56844316210066, 44.48295102800642, 50.028648785182405, 45.08268478938511, 50.486427375248496, 50.426565170288086, 49.189549582345144, 47.51703827721732, 48.397976057870046, 50.125725541796, 44.20789963858468, 40.77001782826015, 41.13212319782802, 38.18217168535505, 43.54072666168213, 43.91567925044468, 44.24283518110003, 42.620142459869385, 41.02054902485439, 36.2753358568464, 36.5840026310512, 35.74801622118269, 35.094062192099436, 35.8699814251491, 37.70684194564819, 36.727719170706614, 39.15406485966274, 37.6216778755188, 37.05426018578665, 39.62932511738369, 38.59403657913208, 36.95603002820696, 36.97678082329886, 36.25859417234148, 37.4325270652771, 38.89557450158255, 41.77858706883022, 47.432906014578684, 46.84341737202236, 48.74844666889736, 48.81150157111031, 47.27170433316912, 45.396375111171174, 40.95937361036028, 35.168793542044504, 34.96737221309117, 36.945965562547954, 35.675192151750835, 36.6661650793893, 44.42891836166382, 48.67122438975743, 48.902873856680735, 47.88737031391689, 46.35854428155081, 49.39277744293213, 50.89203889029366, 48.92271096365792, 51.394230365753174, 52.10430499485561, 50.44259466443743, 52.07283660343715, 52.11557149887085, 47.14967312131609, 29.271509987967356, 4.757220089435577, 3.1283912403242926, 8.483941555023193, 8.838549818311419, 11.439513291631426, 4.893102535179683, 0.27741016713636263, 4.131574758461543, 48.41190024784633, 49.603526728493826, 45.10066672733852, 36.343782561165945, 42.09515741893223, 54.487575326647075, 40.0087697165353, 2.7494364891733443, 0.31453859912497656, 0.06865323002317122, 0.11705046626073973, 0.10871461605919258, 0.10124602182103054, 0.18440965536449636, 0.1115033949858376, 0.1453112597976412, 0.13006535145853246, 0.14006219431757927, 0.14897205121815205, 0.24621967652014323, 0.1603923655514206], [0.03477358638441988, 0.023059602095080272, 0.029053797413195883, 0.09801344706543855, 0.02567994488137109, 0.03289216144808701, 0.0015296037870159904, 0.06510369120431797, 0.033734576244439395, 0.05563887408269303, 0.06075534703476088, 0.03028187115809747, 0.02261566716645445, 0.0382389461488596, 0.01650259081673409, 0.008090757415629923, 0.03697921535266297, 0.6599606924823352, 20.856167997632706, 45.90704686301095, 46.735160963875906, 33.329938888549805, 30.211754117693218, 32.53510318483625, 36.87624386378697, 41.942265783037456, 35.48594406672886, 2.903425071920667, 0.043243121555341144, 0.5898422950080463, 1.7948212048837116, 3.2543345051152364, 0.5417159774473735, 9.003206491470337, 36.88799326760428, 47.39872087751116, 46.393962723868235, 48.498176029750276, 44.87432221003941, 44.115113394601, 43.011009897504536, 44.744627135140554, 44.85231031690325, 44.91801943097796, 42.82525675637381, 44.457666533333914, 43.513951778411865, 42.527366638183594, 37.52324274608067, 43.55779143742153, 45.5614469391959, 42.94130209514073, 46.469559124537874, 44.767420700618196, 43.63825852530343, 44.05429233823504, 42.941736357552664, 44.300689356667654, 44.007221766880576, 42.08309187207903, 42.860119342803955, 38.087745666503906, 33.075898851667134, 33.78616803033011, 32.2106431552342, 34.22498151234218, 31.818212372916086, 34.51877566746303, 33.63626759392874, 32.719824518476216, 32.00762721470424, 33.76966953277588, 35.08568613869803, 33.178450788770405, 32.93618447440011, 32.584807123456685, 32.55824416024344, 33.177617004939485, 36.948359216962544, 38.750992911202566, 40.52661200932094, 43.24086325509207, 42.948066166469026, 46.822249685014995, 44.791249547685894, 37.93872765132359, 45.611484391348704, 40.79812676565987, 54.13386338097708, 44.320787021092, 41.91666514532906, 47.66857501438686, 44.50442443575178, 42.03389515195574, 38.06351382391793, 36.99467243467058, 37.76595721926008, 38.5289180619376, 42.73341546739851, 43.479255948747905, 42.70045321328299, 35.96328183582851, 33.87174551827567, 33.66962936946324, 32.760700770786826, 34.209282057625906, 33.96377093451363, 34.531827858516145, 32.567964690072195, 33.82690184456961, 34.17180347442627, 33.00149754115513, 34.093069962092805, 34.11091293607439, 31.492703165326798, 34.22086817877633, 34.12494829722813, 33.23392868041992, 38.31982592173985, 43.80697120938982, 45.37739610671997, 43.778563499450684, 42.4809387751988, 42.598592621939524, 45.02055747168404, 44.86658886500767, 43.86912979398455, 42.68807847159249, 35.37857355390276, 32.42022514343262, 32.8347373008728, 31.489058835165842, 35.1672614642552, 45.02678305762154, 46.051982811519075, 45.94838169642857, 45.64388036727905, 47.75219311032976, 47.249619483947754, 46.48125294276646, 45.93442971365792, 45.36333990097046, 44.043032782418386, 46.325901644570486, 49.37340586526053, 45.4407046181815, 21.507342747279576, 1.7847347004073006, 0.8304155830826078, 1.710005304643086, 3.709391789776938, 3.1390914661543707, 0.4868449132357325, 0.11397409705179078, 4.2638232963425775, 43.310668332236155, 40.12204967226301, 28.53860878944397, 27.33809208869934, 34.121324811662944, 42.158573627471924, 17.814427307673864, 0.1126048473109092, 0.07359118041183267, 0.035882587411573956, 0.007541419705376029, 0.05551602531756673, 0.024807157161246454, 0.07023242528417281, 0.04245450780061739, 0.04816880742354052, 0.03187406036470618, 0.052807842780436785, 0.07553393473582608, 0.0522406417876482, 0.046020840361182175, 0.05043497867882252, 0.04727312423554914, 0.01882928909201707, 0.029930481620665108, 0.024287774227559566, 0.04884028907067009, 0.004051692052079099, 0.018445144972897003, 0.07174296637198754, 0.020093610177614858, 0.05805181924785886, 0.02673945017158985, 0.009757724573968776, 0.015836685031120266, 0.03495153558573552, 0.032076399507267137, 0.07887679178799901, 0.746304870716163, 26.078322887420654, 51.55675220489502, 50.70942286082676, 36.82039424351284, 33.893482957567485, 39.04047570909773, 40.5360163961138, 47.31775351933071, 37.17054523740496, 2.9569496512413025, 0.11601941872920309, 0.8659726636750358, 4.112766853400639, 3.5208925902843475, 1.361867334161486, 11.27913931437901, 39.157104696546284, 50.08694764545986, 47.70995501109532, 48.24646363939558, 44.9959990637643, 45.42166655404227, 45.558170863560264, 47.16737018312727, 46.05722522735596, 46.03399739946638, 44.11969920567104, 45.358997276851106, 45.036989961351665, 45.40609564099993, 39.27681868416922, 44.19216544287545, 45.22450794492449, 44.501745905194966, 46.3263532774789, 46.32432787758963, 45.95300572259085, 45.34482642582485, 43.22819321496146, 45.784661293029785, 45.01063196999686, 44.467133453914094, 44.310792037418906, 38.52628469467163, 34.24861233575003, 35.664172308785574, 33.74264798845564, 36.118452480861116, 32.51648201261248, 35.58841609954834, 34.74367495945522, 34.82238415309361, 33.99667412894112, 35.327750955309185, 35.72950274603707, 33.911482266017366, 35.37505776541573, 34.87977627345494, 34.06678145272391, 36.01841926574707, 38.25678491592407, 40.573262214660645, 41.82508788790022, 46.144133295331685, 44.936112540108816, 48.50856706074306, 45.107865061078755, 42.61722421646118, 46.42458690915789, 44.07094022205898, 56.031958375658306, 46.184651715414866, 44.23811388015747, 48.87124218259539, 47.468022210257395, 44.56279277801514, 39.13458211081368, 38.835132122039795, 39.14816583905901, 40.70283569608416, 43.465713909694124, 45.92325701032366, 44.61125646318708, 37.71887969970703, 36.098987102508545, 34.53759833744594, 34.82375989641462, 34.85449177878243, 35.59639263153076, 35.95725774765015, 34.76468978609358, 36.08185979298183, 36.262488637651714, 34.35979046140398, 36.05056163242885, 35.14923088891165, 33.95680883952549, 35.5713825907026, 35.64936222348894, 34.93073436192104, 40.07020916257586, 47.167338916233604, 47.0770331791469, 46.30481733594622, 45.518444538116455, 46.046591009412495, 47.293104784829275, 46.47096266065325, 45.60502256665911, 43.05696528298514, 37.124860831669395, 33.397503171648296, 34.39576823370797, 33.783128193446565, 37.99495594842093, 47.52509471348354, 47.01045901434762, 48.07577766690935, 46.53249590737479, 48.694674560001914, 47.763060092926025, 48.8916768346514, 47.78583281380789, 47.42129210063389, 46.682990414755686, 48.40756457192557, 50.53357785088675, 47.64350938796997, 22.938499689102173, 3.2845819677625383, 1.8241162214960371, 4.149915397167206, 6.845916765076773, 7.062727051121848, 1.3982501647302081, 0.11523237239037241, 3.9619175536291937, 47.58425167628697, 47.01465572629656, 35.494778701237266, 32.88993031638009, 38.70456157411848, 49.88009629930769, 22.786914314542496, 0.2934785277715751, 0.0618093494059784, 0.057828045184058804, 0.007094039515193019, 0.07253756480557577, 0.032789471958364756, 0.022076847597158382, 0.03512567820559655, 0.060616803754653246, 0.04030787405957069, 0.04182464409885662, 0.0064572941960899955, 0.05096773723406451, 0.019367789749854376, 0.2079564489956413, 0.12755973876586982, 0.10285009896116597, 0.14744998860572064, 0.11814297549426556, 0.11176093973751579, 0.1528310291469097, 0.10804447451872484, 0.20553456752427987, 0.10916860348411969, 0.14999833543385777, 0.13191092599715504, 0.1177811399102211, 0.13932502030261926, 0.18455630035272666, 0.11985219163554055, 0.2134068493864366, 1.31761306311403, 30.200605733054026, 60.030191557747976, 55.88341283798218, 42.449529443468364, 40.355151312691824, 42.07276684897286, 46.13576419012887, 51.60923194885254, 42.120542662484304, 3.76522273676736, 0.4542667099407741, 3.0200195355074744, 6.911630221775599, 9.549285394804818, 1.4071097693272998, 11.437529580933706, 40.244327545166016, 50.663547379629954, 49.82959679194859, 50.73831694466727, 47.06253923688616, 46.769839423043386, 46.552166257585796, 48.06725222723824, 47.20958743776594, 46.53526823861258, 45.63796050207955, 46.54985250745501, 45.79120997020176, 46.703869751521516, 40.54337453842163, 44.8579557282584, 46.4570871080671, 45.595020634787424, 49.207336970738, 48.626922675541465, 48.11292968477522, 46.48532458714077, 44.8943121773856, 47.68009860174996, 46.68318843841553, 46.533958503178184, 46.606970173971995, 40.34795992715018, 36.394709382738384, 36.964180265154155, 35.44214609691075, 39.22091000420706, 33.630233083452495, 36.8294130052839, 37.62502343314034, 37.33959143502371, 35.15198237555367, 37.12669168199812, 36.68677691050938, 35.53673539842878, 36.893631730760845, 36.7341045652117, 35.41511413029262, 36.24038641793387, 39.781730379377095, 42.90691893441336, 42.573964732033865, 48.10914291654314, 46.69541379383632, 49.81174339566912, 47.218759059906006, 42.77507339205061, 48.36966214861189, 45.31122841153826, 53.608728953770225, 48.18873453140259, 44.85070875712803, 50.9868609564645, 49.374302182878765, 47.593777656555176, 42.214280809674946, 40.66230337960379, 41.03020007269723, 42.55311666216169, 46.88290398461478, 47.191223348890034, 46.28575495311192, 39.628602504730225, 38.648284639631, 35.89948000226702, 35.85501153128487, 36.367663519723074, 36.953007561819895, 37.337937763759065, 35.49579661233084, 37.39000061580113, 38.47068868364607, 35.80009991782052, 38.53594616481236, 37.16375684738159, 34.64805385044643, 38.59585005896432, 36.830646310533794, 35.71399784088135, 42.21873460497175, 47.68738031387329, 49.429665429251536, 47.7025134904044, 45.11803722381592, 47.666855335235596, 48.54295022147042, 48.54762288502285, 47.67763893944876, 46.29605565752302, 39.3422394480024, 35.70537512642996, 35.542387757982524, 35.015082018715994, 40.276278836386545, 50.14097336360386, 49.20760447638375, 49.79376840591431, 48.163856506347656, 50.669463770730154, 50.42251437050955, 50.35738890511649, 50.35342148372105, 48.68337678909302, 48.62557125091553, 50.49061713899885, 52.6141916002546, 49.60345377240862, 25.746621097837174, 3.760314268725259, 3.073183459894998, 7.15020443711962, 12.533389040402003, 8.457535794803075, 3.162806970732553, 0.20801018896911824, 5.590446327413831, 52.35600001471383, 50.84254339763096, 39.99186474936349, 37.99711683818272, 46.05949034009661, 55.60271256310599, 28.28285254750933, 0.5562172478863171, 0.20470184220799378, 0.13513944989868573, 0.10775635497910635, 0.09543208950864417, 0.10945959322686706, 0.09925902701382126, 0.11932579773877348, 0.1741077567317656, 0.14899688559983457, 0.17782648147216865, 0.14655232748814992, 0.16266912195299352, 0.0784643782036645], [0.07760928837316376, 0.028651310796184198, 0.06278395639466387, 0.023865571079243506, 0.027364818578852073, 0.0027339513887584743, 0.014087276716184403, 0.00963363833060222, 0.10022536266062941, 0.026016235318300978, 0.03633160117481436, 0.088164775898414, 0.09585962763854436, 0.035949650420142074, 0.033969227224588394, 0.023478363374514238, 0.0909142472914287, 0.1078112552474652, 12.508557915687561, 42.053106921059744, 45.632408891405376, 25.72706539290292, 22.29762738091605, 25.50090847696577, 40.00723763874599, 45.60998010635376, 40.6147221156529, 5.439876692635672, 0.13475723112268106, 0.3180557446820395, 3.0030411779880524, 1.249639813389097, 0.9668246805667877, 5.791163282735007, 32.7832407270159, 49.49831015723092, 47.944595677512034, 48.6264397757394, 46.25369943891253, 45.41701473508562, 43.78923940658569, 44.27051680428641, 42.62630898611886, 44.43063109261649, 43.49897493634905, 41.152662072862896, 42.13024582181658, 41.07428986685616, 42.676308223179404, 47.73108100891113, 44.70125995363508, 46.41845512390137, 43.57000984464373, 44.91783530371529, 43.94014733178275, 44.79896204812186, 43.76074137006487, 44.46420131410871, 40.9808782849993, 43.06217990602766, 43.877248764038086, 35.533907481602256, 32.11637347085135, 32.73724365234375, 32.08885165623256, 34.175287996019634, 32.72831174305507, 32.44199384961809, 33.470150062016074, 33.110337597983225, 33.01632152284895, 32.94938952582223, 33.11301960263933, 32.236309800829204, 31.664546012878418, 30.64958095550537, 33.62787069593157, 32.74047456468855, 33.96944761276245, 35.96632514681135, 37.16524723597935, 40.779529912131174, 44.21656404222761, 45.200870173318044, 46.77173628125872, 41.1749484198434, 41.2221405846732, 40.18759202957153, 46.64856556483677, 46.336970124925884, 40.08907699584961, 49.10558407647269, 43.67121730531965, 42.590282576424734, 38.134812763759065, 38.63257476261684, 38.08120393753052, 42.14435761315482, 40.626471519470215, 45.52277673993792, 41.050488812582834, 38.50059025628226, 32.09821087973458, 34.03829383850098, 32.051456451416016, 34.34700230189732, 34.23779746464321, 33.83845322472708, 32.89794506345476, 36.24607351848057, 33.76484053475516, 34.06094149180821, 32.312020846775596, 34.70851012638637, 31.504608903612407, 33.65012577601841, 32.64677810668945, 34.64466312953404, 40.7221725327628, 46.89309351784842, 43.46122537340437, 42.84559760774885, 44.36038827896118, 42.8371034349714, 41.94835935320173, 45.86138677597046, 45.37444659641811, 45.13377489362444, 43.25408220291138, 37.466368266514365, 33.15127638408116, 33.07746567044939, 32.14880766187395, 36.984270981379915, 44.6124723979405, 45.341949871608186, 45.84177548544747, 46.043467794145855, 45.210476057870046, 43.01954575947353, 41.89599772862026, 42.49065235682896, 43.44417101996285, 45.59742818559919, 49.46371160234724, 44.2756723676409, 21.68725766454424, 1.7227612201656615, 1.8540790251323154, 1.2396348416805267, 4.443238811833518, 6.653363943099976, 0.515781500509807, 0.0739982132134693, 7.498380405562265, 43.69341679981777, 37.98278617858887, 31.321117401123047, 18.77888069834028, 36.52963992527553, 39.181697845458984, 9.894266060420446, 0.04753828554281166, 0.009434753779454954, 0.007322536182722875, 0.022602405199514966, 0.03192178512524281, 0.04069089689957244, 0.0376790326221713, 0.05816718377172947, 0.030688520587448562, 0.03968818499041455, 0.06565502804837056, 0.042654509390039105, 0.04081658533375178, 0.030342352376984696, 0.0840991297736764, 0.08021282045436756, 0.00653275110692318, 0.025569716867591654, 0.02942198747768998, 0.010668757920419531, 0.06866589827196938, 0.019360210513696074, 0.0387770244186478, 0.021419340378737876, 0.05193774714799864, 0.03480116544025285, 0.08751036958502871, 0.03695738688111305, 0.038721907019082985, 0.06820056574153048, 0.016554388483720164, 0.2900296428373882, 15.299360070909772, 48.121844223567415, 50.34540673664638, 32.15649584361485, 29.75650119781494, 33.660033907209126, 45.24070072174072, 49.71589994430542, 43.66650990077427, 5.9102818965911865, 0.07560301638607468, 0.33831886308533804, 4.416897756712777, 5.229371896811894, 1.3261213494198663, 6.159549389566694, 34.743789604731965, 49.50494916098458, 48.8148193359375, 49.19333635057722, 47.85367155075073, 45.935979161943706, 45.15628358295986, 46.34292473111834, 45.844165665762766, 44.850006989070344, 45.42654766355242, 41.830900056021555, 44.17607341493879, 42.177354608263286, 44.044748987470356, 47.23981557573591, 46.12845468521118, 46.539801938193186, 44.98996107918875, 45.72010210582188, 45.58815581457955, 46.31892217908587, 45.54922158377511, 45.59934936250959, 44.36051334653582, 45.640065806252615, 44.6877179145813, 38.20282867976597, 33.155174323490684, 34.113264901297434, 33.80607809339251, 34.42986651829311, 34.78867844172886, 33.77455759048462, 33.98979888643537, 35.957737173352925, 34.556379318237305, 35.06479637963431, 34.90156235013689, 34.0489558492388, 33.81970003673008, 34.08753572191511, 34.2348027910505, 33.79338026046753, 34.99706881386893, 36.69148431505476, 38.35194744382586, 42.34745345796858, 47.034357343401226, 47.97524070739746, 47.846435001918245, 42.91219956534249, 43.235273429325645, 43.35462611062186, 49.745016370500835, 46.2675541469029, 42.79148851122175, 49.99570737566267, 46.09835508891514, 43.89657170431954, 38.769634928022114, 39.77724879128592, 39.80659103393555, 44.62440592902047, 43.42192983627319, 47.30627162115914, 41.951089995247976, 40.0030791418893, 33.62784290313721, 35.55430391856602, 34.1428016935076, 34.70631796973092, 35.72288806097848, 35.57069819314139, 34.3166629927499, 37.93854352406093, 35.83748817443848, 33.653283732278005, 34.264443806239534, 36.05598817552839, 34.52566828046526, 34.89373867852347, 34.02040570122855, 35.63545192990984, 42.34644944327218, 48.14761509214129, 45.95095600400652, 44.27115951265608, 45.26175376347133, 44.15624325616019, 43.85654313223702, 48.59963015147618, 47.56643649509975, 47.292170252118794, 43.933716773986816, 37.92782940183367, 34.18560607092721, 34.42217486245291, 34.381295136043, 39.62041752679007, 46.00695153645107, 47.73104279381888, 49.14488656180245, 48.03250776018415, 46.46716547012329, 45.26258059910366, 45.103637082236155, 44.482485498700825, 45.98849712099348, 48.57322699683053, 51.70775045667376, 46.60531997680664, 22.404733862195695, 2.3802634988512312, 2.0263520096029555, 5.544826192515237, 6.397587725094386, 4.71528206552778, 1.2457999565771647, 0.02643456233532301, 7.839982509613037, 47.05323212487357, 42.64208139692034, 34.408525126320974, 23.84202606337411, 42.81754425593785, 46.07898003714425, 13.568496056965419, 0.07060198259672948, 0.04375096769737346, 0.06828293310744421, 0.015194231112088476, 0.02798476379497775, 0.01446286026787545, 0.04375945617045675, 0.006796853899556611, 0.045995178166776896, 0.061438027902373245, 0.044563991749393086, 0.02575023771662797, 0.0339978410463248, 0.03405096694560988, 0.2983913112963949, 0.17810204811394215, 0.16855462613914693, 0.10110308841935225, 0.0929586665172662, 0.09612071434301989, 0.15992931968399457, 0.11695837548800878, 0.17202274075576238, 0.08347993942775897, 0.15816081315279007, 0.12555420638195106, 0.12725495440619333, 0.162036428760205, 0.12000931320445878, 0.15753761945026262, 0.14088707576904977, 0.38633561081119944, 16.756128072738647, 54.98567083903721, 57.399631364004954, 36.09531497955322, 31.183748040880474, 36.003466742379324, 49.670899936131065, 56.42431272779192, 48.85563652856009, 8.054476874215261, 0.3570399156638554, 2.249473431280681, 9.45761867931911, 6.828245759010315, 2.9575426365647997, 7.094533732959202, 37.29691907337734, 51.806133474622456, 52.37121309552874, 51.88771227427891, 48.988986355917795, 47.39475345611572, 45.42572430201939, 47.499535764966694, 45.789309637887136, 46.06416300364903, 46.88152824129377, 42.64511775970459, 43.85038702828543, 42.83518920625959, 46.36555848802839, 49.66240576335362, 46.19892678941999, 49.676534925188335, 45.0922976221357, 48.26699209213257, 47.44523559297834, 50.22745411736624, 48.48743411472866, 47.874530042920796, 45.580894947052, 47.0120119367327, 47.232099601200645, 39.45177085059029, 34.900183132716585, 36.40302985055106, 35.30265753609793, 37.9041360446385, 37.14077568054199, 35.3252843448094, 36.15361731392996, 37.65008905955723, 35.60170452935355, 35.711499963487896, 36.26703970772879, 35.81996134349278, 35.18524687630789, 34.67170204435076, 36.900055340358186, 35.996171133858816, 37.838968890053884, 39.50599806649344, 40.7194036756243, 45.63102272578648, 48.055600098201204, 49.22883469717843, 49.8036869594029, 45.95263746806553, 45.15865986687796, 46.065035002572195, 46.19884688513619, 46.530248165130615, 45.90121037619454, 51.21449783870152, 46.762439591544016, 45.260134833199636, 42.79671008246285, 40.999867711748394, 41.37834998539516, 45.79735912595476, 45.03309202194214, 48.035054274967735, 44.14561946051461, 41.6376428604126, 35.447169644492014, 38.1500049999782, 35.53028399603707, 36.59809357779366, 38.09825481687273, 37.34042174475533, 35.7335535458156, 38.834239278520855, 38.42983327593122, 36.24814060756138, 37.27900314331055, 38.42499385561262, 35.24052674429757, 37.37220627920968, 36.27867446626936, 36.84255204881941, 45.11995145252773, 49.62578875677926, 48.55016939980643, 48.920160974775044, 45.19587441853115, 44.467647620609824, 43.819227831704275, 48.54848098754883, 49.42882122312273, 48.567779609135215, 47.18469551631382, 40.383621556418284, 36.152717522212434, 35.53860446384975, 36.18795531136649, 39.57063020978655, 48.67638690131051, 48.12871251787458, 50.36218663624355, 49.59791258403233, 49.0745256287711, 46.3178973197937, 46.6432397706168, 46.4104334286281, 47.75470488412039, 50.936205114637104, 53.796663829258506, 47.81882980891636, 25.8262266090938, 3.1181823824133192, 5.03678867646626, 7.059566055025373, 13.98730741228376, 14.841734341212682, 3.4352312896932875, 0.17196419675435337, 9.10585309777941, 51.93128790174212, 47.88122115816389, 41.90978990282331, 28.03249158178057, 47.814664363861084, 53.251574175698416, 17.906866141727992, 0.23406990990042686, 0.10663657542318106, 0.15033752151897975, 0.06231960095465183, 0.11820291727781296, 0.11017283531171934, 0.1351389613534723, 0.09998616549585547, 0.22699718656284468, 0.11916856760425226, 0.1953847828720297, 0.0903765218598502, 0.11666024077151503, 0.14506314668272222], [0.05365900728585465, 0.026585012208670378, 0.01950071645634515, 0.05096489417233637, 0.04266826329486711, 0.008785463620110281, 0.03800947917625308, 0.06284504490239279, 0.0021340032357589473, 0.036735237908682654, 0.020890963463378803, 0.021179018542170525, 0.020611943078360388, 0.03330215605508004, 0.03710092078628285, 0.016004393442666957, 0.015295851909156357, 0.03688548591786197, 5.757038073880332, 38.029450280325754, 42.82273803438459, 29.925794056483678, 24.38824827330453, 32.83411543709891, 37.16830791745867, 41.719798360552105, 43.029377460479736, 9.59151133469173, 0.09781006297894887, 0.3356451636978558, 2.3419602513313293, 4.243820301124027, 0.5396155044436455, 4.119418016501835, 29.53445761544364, 50.231484072549, 48.12887927464077, 48.96637691770281, 46.21157945905413, 46.57628345489502, 46.091559750693186, 45.49840940747942, 43.661437715802876, 42.48340538569859, 43.04402078901018, 41.49066414151873, 42.52507720674787, 44.5246958051409, 45.36942304883684, 46.629558767591206, 45.28556176594326, 43.881313460213796, 43.464602197919575, 43.624692167554585, 44.267265047345845, 43.73247957229614, 44.30590050561087, 43.74401010785784, 41.57731860024588, 45.710520539964946, 42.19438116891043, 34.63502945218767, 32.04890993663243, 33.99710144315447, 32.15793064662388, 33.40802621841431, 32.85047149658203, 32.66674028124128, 35.261260168892996, 33.078042370932444, 34.40853207451956, 32.63348967688424, 31.496385710580007, 31.24093518938337, 33.61572871889387, 34.9382175718035, 31.379687241145543, 31.883313519614084, 32.68315887451172, 35.09020594188145, 34.03244692938668, 37.54072093963623, 39.890438420431956, 43.61990485872541, 45.9728810446603, 43.15767594746181, 43.487222058432444, 36.94651099613735, 45.675696168627056, 45.17282376970564, 39.86163466317313, 47.915156160082134, 43.03919873918806, 43.28714868000576, 37.84273828778948, 39.10484382084438, 39.452646323612754, 42.528113569532124, 42.01718473434448, 44.313963890075684, 43.50290414265224, 40.8532190322876, 31.703629629952566, 32.82962690080915, 32.55801139559065, 33.99179996762957, 33.200973374503, 34.40587786265782, 32.40429639816284, 34.397970812661306, 33.656542437417166, 34.24272721154349, 33.11552790233067, 34.621310234069824, 32.96265016283308, 32.11763456889561, 32.445485319410054, 33.429169586726594, 41.270955153873985, 47.060235909053254, 41.09984186717442, 47.06151785169329, 46.51633439745222, 46.12787798472813, 43.95585373469761, 44.78299856185913, 46.05892753601074, 48.324717726026265, 43.99622971670968, 43.435892241341726, 36.28897517068045, 33.540938309260774, 31.68541145324707, 31.177268845694407, 37.195649078914094, 40.70496184485299, 41.69485780170986, 41.6476274217878, 42.529572691236226, 40.89765623637608, 38.13439587184361, 39.25082547324044, 43.53954546792166, 46.60415267944336, 49.293008259364534, 44.16737079620361, 20.743119069508143, 1.6207613391535622, 0.8105277759688241, 3.399728383336748, 4.299572212355478, 4.544613029275622, 0.8563265555671283, 0.10392112577600138, 10.44227135181427, 47.70179435185024, 34.88283000673567, 29.295196396963938, 32.07853358132498, 38.670067242213655, 37.56661687578474, 6.440039915697915, 0.049926107948912044, 0.024771917445052947, 0.02322869302172746, 0.006057176938546556, 0.01776616890648646, 0.024201610458216498, 0.015445467184430786, 0.0621358740276524, 0.024440081590520482, 0.035907669458538294, 0.022721652640029788, 0.13068021275103092, 0.047577915380575826, 0.02588737303657191, 0.0033661435258441736, 0.032732529299599786, 0.024074480137122527, 0.06708552236003534, 0.05556347866409591, 0.018363086340416754, 0.0439147083753986, 0.013313003799079784, 0.02347261957558138, 0.0513739863277546, 0.06477044230060917, 0.03916161467454263, 0.028037957547764693, 0.04701418848708272, 0.028563908700432097, 0.01676602864504925, 0.05874626591269459, 0.1372924686542579, 8.52608585357666, 45.12448515210833, 50.94016906193325, 32.07671662739345, 25.02472758293152, 34.2250440461295, 42.97378492355347, 46.14528669629778, 46.337640626089915, 9.367081914629255, 0.028727992038641657, 0.45434023599539486, 4.178681373596191, 3.898945161274501, 1.0690922843558448, 4.99398820740836, 31.893124376024517, 52.38708625520979, 49.350799901144846, 51.672787121364046, 48.0916543006897, 47.4215144429888, 46.51077583857945, 46.398652757917134, 44.24786220278059, 43.87595639910017, 42.79491744722639, 43.075631618499756, 41.91298260007586, 45.857721601213726, 46.81597893578665, 47.43979515348162, 45.65931579044887, 45.576232705797466, 45.6990316935948, 44.468411922454834, 46.725968497140066, 45.32375948769705, 46.15623358317784, 45.31498738697597, 44.306213174547466, 46.495809418814524, 43.372410024915425, 35.893122400556294, 33.51228393827166, 35.33508825302124, 33.07862254551479, 36.31180347715105, 36.21285765511649, 33.65876586096627, 36.84443848473685, 35.00058807645525, 33.54380791527884, 35.24977479662214, 32.13227442332676, 32.98800413949149, 35.5885203225272, 37.052231311798096, 34.12300974982125, 34.314894676208496, 35.71200370788574, 35.604351793016704, 36.80931881495884, 38.80244779586792, 42.624464239392964, 46.04698358263288, 47.41565711157662, 45.76711361748831, 44.81394236428397, 39.356236594063894, 47.76343876974923, 46.37199599402291, 41.96944713592529, 49.966177531651084, 44.37296451841082, 44.72092335564749, 39.34129101889474, 40.39719486236572, 41.15709849766323, 44.210453101566856, 44.53405155454363, 46.83844593593052, 45.26919181006295, 42.86840854372297, 33.85214465005057, 34.01188720975603, 33.91693312781197, 34.88344839641026, 34.11848994663784, 36.365856988089426, 34.314842564719065, 34.98563207898821, 34.41859654017857, 34.82148436137608, 35.102052620479036, 35.406241280691965, 33.62076268877302, 33.26178400857108, 34.24415506635393, 35.008755683898926, 43.79978677204677, 49.0299459866115, 44.13787221908569, 48.00307866505214, 46.76659114020211, 46.715299538203645, 44.641303947993684, 45.44272654397147, 47.148439816066194, 49.94708388192313, 45.608628681727815, 45.03678151539394, 38.548828125, 34.230599130902974, 33.54489183425903, 33.52557584217617, 39.78182418005807, 43.0463102204459, 44.728462151118684, 43.04183210645403, 44.73468426295689, 42.462779658181326, 40.62578017371041, 39.76787567138672, 46.91538333892822, 49.854547773088726, 49.761396748679026, 45.82486704417637, 22.78601278577532, 2.392341639314379, 1.6152593429599489, 7.325855766023908, 7.472219569342477, 4.961244821548462, 1.1667343420641763, 0.058302246167191436, 10.608765823500496, 51.04400988987514, 38.13702229091099, 34.7894983291626, 30.421089444841655, 43.7302804674421, 44.7170740536281, 8.483180727277484, 0.034088785094874244, 0.05660590522789529, 0.09756125097296067, 0.07483196990298373, 0.05351507304502385, 0.029113114944526126, 0.03423452423885465, 0.011771550352152969, 0.05042937397956848, 0.029339416551270654, 0.035033282092107196, 0.1441571395844221, 0.028579816953944306, 0.027140784975407378, 0.1045229524107916, 0.20861247022237095, 0.13375964893826417, 0.13654617512864725, 0.18021358123847417, 0.13372044318488666, 0.11263272831482546, 0.13805474846490792, 0.10672282400940146, 0.24167240623916897, 0.12624956906906196, 0.12686745662774357, 0.11057260778865644, 0.12034384453935282, 0.10509971396199294, 0.09859529084392957, 0.1273792213095086, 0.32612083905509537, 9.340386067117963, 51.0984524999346, 54.85814707619803, 40.81195020675659, 32.582542010716026, 42.41524008342198, 48.43956797463553, 50.31157595770699, 51.42765120097569, 13.290839093072073, 0.18693567839051994, 1.2404977210930415, 8.608468907220022, 10.377703479358129, 3.288853155715125, 5.603085969175611, 34.72171170370919, 53.24627270017351, 51.11341544560024, 52.57827983583723, 50.27165508270264, 48.07941852297102, 47.969258308410645, 48.09337397984096, 45.047495637621196, 44.660633836473735, 45.05285964693342, 43.09966196332659, 43.58703987939017, 46.87223849977766, 48.042335987091064, 50.16768571308681, 48.57651349476406, 47.138587270464214, 46.93004403795515, 45.96411936623709, 47.7647693497794, 48.56888089861189, 47.61702980313982, 46.17032452992031, 45.600336006709504, 48.80639464514596, 45.678482396262034, 37.91230712618147, 36.143688338143484, 37.67967448915754, 34.78409610475813, 37.39590311050415, 37.7906094278608, 36.13512815747942, 38.85953419549124, 36.22974872589111, 36.22118854522705, 36.22036170959473, 34.3296491759164, 34.24476998192923, 37.19583668027605, 39.504184586661204, 35.798640796116416, 35.28495352608817, 37.468341554914204, 38.83260645185198, 39.52873257228306, 40.8375369480678, 44.625816413334434, 46.80365630558559, 50.935743059430806, 47.27474764415196, 45.7711956841605, 41.91117606844221, 47.043219770704, 46.4201991217477, 43.19369193485805, 48.70205354690552, 45.51323338917324, 46.19596338272095, 41.4351931980678, 42.19645868028913, 44.292869159153526, 46.773935386112754, 45.30700738089425, 47.35539538519723, 47.678566523960654, 44.037210191999165, 34.29476921898978, 36.6102876663208, 35.41740008762905, 36.66878802435738, 36.64451796667916, 37.65562677383423, 35.779182365962434, 36.89963150024414, 36.874364376068115, 35.97383614948818, 37.28401974269322, 37.5808606828962, 36.45616272517613, 34.903896944863455, 36.054205962589805, 36.509292125701904, 44.94202198301043, 51.192482471466064, 43.697116715567454, 49.89919689723423, 48.11354807444981, 48.618046351841514, 46.264392716544016, 46.08493116923741, 47.16044282913208, 53.13050528935024, 46.560253960745676, 46.820568220955984, 39.52514730181013, 36.427887031010215, 35.21387692860195, 34.28471517562866, 41.36549581800188, 43.343255383627756, 45.79020595550537, 45.20400728498186, 46.80812052318028, 45.750128746032715, 41.90743098940168, 42.048562799181255, 48.11173112051827, 50.79062645775931, 51.0467266355242, 47.67406061717442, 25.186935016087123, 3.451992516006742, 4.107995178018298, 11.463746871267047, 11.28085117680686, 13.837578075272695, 3.2874878346920013, 0.1771165438528572, 11.642332077026367, 56.77983120509556, 43.90528474535261, 40.19704852785383, 42.17948423113142, 51.1925311088562, 51.828649112156455, 10.973759906632559, 0.08990529964544944, 0.136167281174234, 0.15205973839121206, 0.15442507075411932, 0.1708143920238529, 0.12142906630677835, 0.14498185818748816, 0.1882220179374729, 0.15595883131027222, 0.12238584139517375, 0.10451239440590143, 0.2857714013329574, 0.11687997755195413, 0.13109421410730906], [0.03705292800441384, 0.164931127003261, 0.03431599593854376, 0.015385505044832826, 0.020225544526640857, 0.04866538309891309, 0.026739563826205473, 0.034399947683726034, 0.02696871867270342, 0.03230521847893085, 0.04323419542717082, 0.08890722891581909, 0.07423495408147573, 0.03982674523389765, 0.022700246556528976, 0.08604292904159852, 0.054658808279782534, 0.0017218433599087543, 1.534058568733079, 25.34645175933838, 44.047524792807444, 30.029228414808, 16.739382914134435, 21.72905629021781, 38.788704259055, 41.880103724343435, 43.830126081194194, 21.154775517327444, 0.22873648894684656, 0.3081545074071203, 2.6252415648528507, 2.8663824881826128, 0.4561738818883896, 3.1890038507325307, 27.19011456625802, 46.079973629542756, 48.4770257132394, 47.771342345646445, 48.119485310145784, 45.4758312361581, 45.37218843187605, 44.45104142597744, 43.900976862226216, 42.94012090138027, 41.93129457746233, 42.901304789951865, 46.40923833847046, 46.020931312016074, 43.96237114497593, 42.77889142717634, 42.897316523960654, 40.91809436253139, 41.06405864443098, 42.58808694566999, 42.36836058752877, 44.203532695770264, 44.90739910943167, 44.676204749516074, 45.530527455466135, 45.230952399117605, 41.165370328085764, 32.09753690447126, 33.21574177060808, 33.35159294945853, 32.36856876100813, 32.492726121629985, 31.922084467751638, 32.60024949482509, 34.25673130580357, 33.12801381519863, 34.380426611219136, 34.223223618098665, 32.74779101780483, 32.30115039008004, 34.149194036211284, 33.90042420795986, 33.25051055635725, 32.45586245400565, 35.30863298688616, 35.72281510489327, 34.4075072152274, 31.785753863198416, 37.50325277873448, 40.2309626851763, 44.464837074279785, 42.70055396216256, 47.42930337360927, 39.55992303575788, 41.02235903058733, 44.65492936543056, 39.12556334904262, 49.897536277770996, 44.05472660064697, 43.56790106637137, 37.12622962679182, 39.36505733217512, 39.058377742767334, 45.17365060533796, 43.585552964891704, 43.99477754320417, 44.20927538190569, 43.3399133001055, 33.72695895603725, 33.02961342675345, 33.235603196280344, 33.93664864131382, 32.700991426195415, 34.59422615596226, 32.79686267035348, 33.03653730664934, 32.03705978393555, 34.558008670806885, 33.845331941332134, 33.52399860109602, 33.62121432168143, 33.36807060241699, 33.3022711617606, 33.33133895056588, 38.396322114127024, 43.76179749625069, 44.67561067853655, 45.919709954942974, 45.20402465547834, 44.59140893391201, 47.62638555254255, 45.93194920676095, 42.498958928244456, 45.29023790359497, 47.664058685302734, 44.61319153649466, 42.49382420948574, 36.328218596322195, 33.906020981924875, 31.950624193464005, 32.64145578656878, 34.12621634347098, 37.091495582035606, 39.06743471963065, 37.9193491254534, 37.36414636884417, 37.467921188899446, 40.079040322984966, 46.13032375063215, 45.24138511930193, 50.66451665333339, 41.58696617398943, 19.92611861228943, 1.5835440733603068, 0.7079942407352584, 6.474964601652963, 5.559545516967773, 2.0963205865451267, 0.4219718628696033, 0.011689073572467481, 11.576188700539724, 44.12873533793858, 32.752811091286794, 24.983463968549454, 28.48726855005537, 42.28207090922764, 27.529344729014806, 3.3214017748832703, 0.1350296086498669, 0.03487256428759013, 0.09103119280189276, 0.014690956599744303, 0.09117849596909114, 0.04998820747381874, 0.030386253592691252, 0.042852879102740965, 0.03811010931219373, 0.06583078218890087, 0.03513266033093844, 0.061239278210060935, 0.02059106625217412, 0.08440879958548717, 0.038419368610318215, 0.06681863418115036, 0.020967466590393866, 0.018155743002093265, 0.0450687776984913, 0.02430604717561177, 0.028449419486735548, 0.013592477106223149, 0.026266701253397123, 0.026062669165964638, 0.060696328058838844, 0.009840812883339822, 0.08040770249707357, 0.04101980657183698, 0.03970400503437434, 0.055373573675751686, 0.07232116641742842, 0.02829038444906473, 2.508762615067618, 30.623354979923793, 49.59986850193569, 37.645392077309744, 22.49622426714216, 29.37460388456072, 45.758556910923545, 46.02762590135847, 47.75742162976946, 20.501582315989904, 0.16038708654897554, 0.2880221834140164, 4.5305103574480325, 4.820952006748744, 1.5717275760003497, 4.009551363331931, 28.87032447542463, 47.84629603794643, 49.414261272975374, 49.86868040902274, 48.385695116860525, 44.833560603005544, 47.214822905404226, 45.22683211735317, 44.99716636112758, 43.42193678447178, 43.363363470349995, 43.118255342756, 46.08020639419556, 46.733093874795095, 46.73566470827375, 45.27410071236746, 45.207457065582275, 43.53739847455706, 42.614851406642366, 44.571280002593994, 45.79043524605887, 45.648059708731516, 46.04078231539045, 45.01099327632359, 47.0134710584368, 46.54998104912894, 43.20137316840035, 34.81073202405657, 33.23509250368391, 34.23020655768258, 35.162147590092246, 34.60758406775338, 33.80562646048409, 33.99061182567051, 36.35282564163208, 36.10389600481306, 34.79407024383545, 34.30061960220337, 34.08126149858747, 34.31286232812064, 35.58171108790806, 36.40625728879656, 35.63974939073835, 34.9367584500994, 36.62071691240583, 35.99348218100411, 36.45227868216378, 33.138790471213206, 39.06989785603115, 42.5533390045166, 46.01697431291853, 46.57429279599871, 48.115722860608784, 41.10572351728167, 42.24824707848685, 45.04813139779227, 42.35720872879028, 50.54433018820626, 46.2786990574428, 45.69086756025042, 40.5051212310791, 40.02693578175136, 41.01571307863508, 46.91275691986084, 44.75095694405692, 46.51709522519793, 45.65726259776524, 43.6304418018886, 35.09163727079119, 33.849705832345144, 33.78103331157139, 34.8184688431876, 34.60862282344273, 35.96529333932059, 34.60761186054775, 34.87893206732613, 33.10559892654419, 36.017901624952046, 36.75451489857265, 34.209299428122385, 35.44697162083217, 35.482793058667866, 33.98526518685477, 35.849835123334614, 40.39497491291591, 44.7939385005406, 47.41730383464268, 47.256651060921804, 46.71852697644915, 46.21866314751761, 48.56661925997053, 46.18387351717268, 44.17914799281529, 47.0661974634443, 47.95113393238613, 45.67859009334019, 43.853333064488, 37.190392766680034, 35.84627069745745, 34.36249678475516, 33.007785660879954, 36.03882612500872, 39.08526727131435, 39.564880575452534, 39.72680139541626, 39.744710377284456, 38.83986037118094, 42.35505826132638, 48.272647925785606, 47.86880472728184, 52.279104300907676, 42.80587475640433, 21.362733364105225, 1.5830369634287698, 2.553009177957262, 10.338658945901052, 5.854106145245688, 4.251215355736869, 0.799786620906421, 0.014912630597661649, 12.057030967303685, 49.6187606539045, 35.54397889545986, 26.07591359955924, 32.61617824009487, 48.800193377903526, 35.48808063779558, 5.100701681205204, 0.11190560340349164, 0.037712993299854655, 0.14341140245752676, 0.056759932677128484, 0.037293214217892716, 0.014672980510762759, 0.023233856673219373, 0.07755553482898644, 0.026434472429433038, 0.06230850690709693, 0.006436189636588097, 0.06886498044644083, 0.03795446016426597, 0.032933351916394064, 0.12428518304867403, 0.2536498249641487, 0.14869949727186135, 0.07839502513940845, 0.1521023775317839, 0.10200550606740372, 0.08197396488061973, 0.13186097224908216, 0.19786552047090872, 0.06879322536821876, 0.15105433948338032, 0.24088359570928983, 0.191058430022427, 0.09600181465170213, 0.13222919963300228, 0.1846446863242558, 0.16636842702116283, 0.12220594819102969, 2.702065625361034, 34.655516215733115, 57.95717913763863, 42.61369105747768, 25.75438744681222, 31.768960067204066, 47.9012701851981, 51.32822942733765, 52.79146099090576, 25.905474288122996, 0.29111424035259653, 1.0339218058756419, 9.542549984795706, 9.002643687384468, 3.0461955709116797, 4.9334646207945685, 32.12318270547049, 48.96835715430123, 51.33565705163138, 51.48659971782139, 50.7576642036438, 46.35539327348982, 48.12350484303066, 48.01230934688023, 46.7039600781032, 45.01726402555193, 42.37816102164132, 44.17242908477783, 48.07990837097168, 48.628989764622276, 48.18805013384138, 48.26040172576904, 45.828316824776785, 44.64970779418945, 44.39897162573678, 45.477300780160085, 46.73265266418457, 47.2965406690325, 46.43228203909737, 48.860469000680105, 48.39343541009085, 48.477029187338694, 45.20585897990635, 35.386011600494385, 35.303748403276714, 36.690014771052766, 35.11372906821114, 35.880705969674246, 36.19183588027954, 35.472947461264475, 37.64555883407593, 37.264939989362446, 36.149212156023296, 37.720658438546316, 35.743930680411204, 35.7087276322501, 38.15393073218209, 37.29930577959333, 38.63826881136213, 35.34684460503714, 38.29332201821463, 39.39091852733067, 37.83831228528704, 34.709771224430625, 40.80206639426095, 45.069858414786204, 48.822233063834055, 46.088763100760325, 49.4197017124721, 42.18292358943394, 44.416567938668386, 46.31770624433245, 43.73257337297712, 51.91511596952166, 48.62376124518258, 47.17477001462664, 42.48589284079415, 41.54120533806937, 42.693355628422324, 48.24980224881853, 46.497344970703125, 47.53213323865618, 47.90303502764021, 46.80291632243565, 36.146346024104524, 36.71036604472569, 35.87570674078805, 36.71069261005947, 36.440991333552766, 36.61723586491176, 35.43520484651838, 36.38422802516392, 34.79844413484846, 38.18544428689139, 39.55361407143729, 37.87836517606463, 37.19109106063843, 36.43366098403931, 35.90714039121355, 36.883650643484934, 41.78182145527431, 46.40370062419346, 47.99026966094971, 49.66458054951259, 48.76888132095337, 48.4606522832598, 49.58938019616263, 48.27285289764404, 45.03006955555507, 47.42878573281424, 50.509210518428254, 47.35391541889736, 44.9346603666033, 40.370920249394004, 37.2245466368539, 35.15828439167568, 34.46494449887957, 37.14068187986101, 40.94350739887783, 42.494532925742014, 41.890126500810894, 40.57466227667672, 41.37319789613996, 44.27775682721819, 51.77186148507254, 49.61047840118408, 53.68958166667393, 44.31692034857613, 23.73342571939741, 2.23951427425657, 5.084459832736424, 14.593430042266846, 11.901494673320226, 5.885764743600573, 2.5467690442289626, 0.09963587857782841, 13.950867584773473, 54.934334073747905, 44.21205813544137, 36.82698460987636, 39.32553597858974, 54.67504119873047, 40.02837405885969, 6.711350568703242, 0.19257852488330432, 0.1310841582183327, 0.16349690753434384, 0.08515478098498923, 0.14051356938268456, 0.14966019429266453, 0.1237954164722136, 0.19497937176908764, 0.12653979206723825, 0.13814720564654895, 0.12331244881664004, 0.13487212067203863, 0.09539859702012368, 0.13844983226486615], [0.017902591764660816, 0.052410869260451624, 0.02426041060659502, 0.06261996126600675, 0.03862847613969019, 0.02286773614053215, 0.06577851463641439, 0.05872004731957402, 0.031947817121233256, 0.045843515412083695, 0.045344228989311626, 0.028167359264833585, 0.043155349658003876, 0.05766851481582437, 0.06471508062843766, 0.03432651323133281, 0.03252914182043501, 0.03494332531200988, 0.5667769898261342, 14.977080038615636, 40.62127079282488, 32.332577092306956, 24.360719510487147, 23.24423953465053, 32.638384682791575, 41.02720887320382, 45.49517502103533, 32.38797855377197, 2.3865657321044376, 0.31199672552091734, 2.1316523935113634, 1.8397724671023232, 0.6990956610866955, 2.501777287040438, 23.826519421168737, 46.08480610166277, 48.23682301385062, 47.13800362178257, 46.92658730915615, 46.87219681058611, 43.07125077928816, 42.51833398001534, 43.46283040727888, 44.3710607119969, 43.38362789154053, 47.17332478931972, 44.853988306862966, 44.54357058661324, 42.63082878930228, 41.77178478240967, 40.05673313140869, 41.442117077963694, 40.82909836087908, 39.51442275728498, 39.98250552586147, 43.53199972425188, 43.56583397729056, 45.417059898376465, 43.95318910053798, 42.663481848580496, 35.490800857543945, 32.691646099090576, 33.55366393498012, 33.991911138807026, 32.72178391047886, 32.21781369618007, 31.833884034837993, 31.99724313191005, 32.1579966545105, 32.63254124777657, 32.60221583502633, 33.61680221557617, 32.28451987675258, 32.3413804599217, 33.0293424470084, 32.5459041595459, 31.85068825313023, 33.0600117955889, 36.91132879257202, 35.70782784053257, 36.719787802015034, 33.752962589263916, 33.36434984207153, 37.048764160701204, 41.79202141080584, 42.446538243974956, 46.2295092855181, 42.542100293295725, 41.186927114214214, 37.94032226290022, 42.489867210388184, 47.20043666022164, 45.23255048479353, 43.664154461451936, 39.02667658669608, 41.452160699026926, 41.82075221197945, 43.96720709119524, 44.32180840628487, 41.655544894082205, 44.17761244092669, 45.00662285940987, 37.09874255316598, 31.963391508374894, 31.819671494620188, 33.4634485244751, 35.13514689036778, 33.88223729814802, 33.847843715122764, 33.55336168834141, 31.818542412349156, 33.694351060049875, 33.632824761526926, 33.10000562667847, 33.31455557686942, 32.74286821910313, 33.94716126578194, 33.563245500837056, 34.655603068215505, 40.479260035923545, 39.8107008934021, 42.36651931490217, 41.276583194732666, 42.45660618373326, 44.95503943307059, 44.94384241104126, 44.11598539352417, 43.26487275532314, 45.35282727650234, 47.62946707861764, 42.359567642211914, 41.524731159210205, 35.67589391980852, 34.84936400822231, 34.65829202107021, 33.08962501798357, 32.933439935956685, 34.58077096939087, 36.155302252088276, 35.12024647848946, 38.83888414927891, 45.31503255026681, 45.00637967245919, 48.513840743473594, 47.55818550927298, 42.095049721854075, 17.757135936192103, 0.6739079526492527, 0.8504730782338551, 7.569019266537257, 5.732843143599374, 2.840605757066182, 0.43421681438173565, 0.04609504495082157, 16.10823460987636, 44.17215463093349, 30.119687012263707, 30.957684925624303, 32.620882170540945, 39.87915802001953, 20.862388372421265, 1.227027769599642, 0.10745355872703449, 0.038020600365208726, 0.04098719617884074, 0.015372997948101588, 0.02330230050055044, 0.11669211834669113, 0.03271415796396988, 0.0897427565817322, 0.03621328502361264, 0.023641987005248666, 0.05522232822009495, 0.022650710107492547, 0.014107966097071767, 0.07167711454842772, 0.00891248622377004, 0.03563982793795211, 0.07338466149355684, 0.04018382089478629, 0.015055701402681214, 0.00975460500922054, 0.07828790481601443, 0.01288811958927129, 0.06060281236256872, 0.01609798038511404, 0.00972041956681226, 0.06209202030939715, 0.034428144206425974, 0.03879403868424041, 0.0525524014873164, 0.06636451783456973, 0.05095406136076365, 0.05055349839052983, 0.8398156272513526, 19.699732405798777, 48.07256065096174, 36.83695527485439, 24.730672870363506, 24.39082952908107, 41.099313804081504, 46.59646449770246, 49.58999858583723, 34.177622590746196, 2.2373225518635342, 0.05274055585531252, 2.51186346582004, 3.719914836542947, 1.2880256793328693, 2.8771647896085466, 25.767196450914653, 46.91811745507376, 48.34963049207415, 48.900719915117534, 48.920786312648225, 47.71116747174944, 44.42018447603498, 44.71782793317522, 45.75174420220511, 45.13398681368147, 42.92516490391323, 47.825614724840435, 45.155574866703574, 45.84109803608486, 43.962784562792095, 43.99384995869228, 42.89692742483956, 42.4119987487793, 41.82759618759155, 40.80184057780674, 42.68266582489014, 45.65174225398472, 45.42077023642403, 46.75888211386544, 46.26168639319283, 45.54598372323172, 37.91261979511806, 34.87022944859096, 34.8075601713998, 35.06168358666556, 35.51862839290074, 34.04413032531738, 34.04302903584072, 33.99626765932356, 34.5801352092198, 34.4293349811009, 34.01485409055437, 35.17859050205776, 34.09721108845302, 33.09840406690325, 35.10290377480643, 34.453587668282644, 33.614061151232036, 35.72061252593994, 38.62068639482771, 37.92066580908639, 38.62379571369716, 36.931885038103374, 35.134396484919954, 39.71676124845232, 43.837192399161204, 45.347317355019705, 48.69962167739868, 43.68065643310547, 40.80771180561611, 40.24909053530012, 44.1577718598502, 48.56836673191616, 46.122910022735596, 44.89666761670794, 40.625741958618164, 42.14897469111851, 42.630981649671284, 45.13959748404366, 44.222862584250315, 46.292251518794465, 46.55550834110805, 45.80513416017805, 37.717323303222656, 32.85307012285505, 33.79506172452654, 35.85941668919155, 35.57882758549282, 34.331803117479595, 35.62975788116455, 35.0389039175851, 34.75236715589251, 34.15803214481899, 35.270014899117605, 34.05771752766201, 34.22644410814558, 33.52635056631905, 35.20932585852486, 35.33894450323922, 36.69584778376988, 43.019326891217915, 42.80068097795759, 44.01549012320382, 43.140194279806956, 43.25416905539376, 46.30808993748256, 47.108334813799175, 45.2765325818743, 43.34207418986729, 47.95056070600237, 49.35420799255371, 44.09604058946882, 43.77939033508301, 37.16441692624773, 34.736553055899485, 36.33859920501709, 34.9266140801566, 35.928613798958914, 36.76894283294678, 37.84205041612898, 36.80450371333531, 41.59325429371425, 45.04586281095232, 47.509447370256694, 50.731924601963584, 47.86849205834525, 43.12715598515102, 19.875577415738785, 1.768419787287712, 2.924122018473489, 7.771938800811768, 8.081712075642177, 3.4444000891276767, 0.20586019647972925, 0.056955415223326, 17.09166179384504, 49.02516562598092, 35.855306829724995, 33.97225815909249, 37.610029220581055, 45.963813645499094, 25.68304681777954, 1.8675294348171778, 0.16113742414329732, 0.025481442854340588, 0.01609810591409249, 0.007786251255311072, 0.052152571334902725, 0.03907208537150707, 0.036193203779735734, 0.033723634867263694, 0.053673894344163794, 0.009974126354791224, 0.02409281924233905, 0.038090000926916084, 0.028334621539605514, 0.10413758523230042, 0.13899561869246618, 0.15909850783646107, 0.2376666883272784, 0.1719324141740799, 0.17472940337445053, 0.09156469774565526, 0.31987210150275913, 0.1079049337921398, 0.15732451874230588, 0.1595178967607873, 0.13065118502293313, 0.12136818814490523, 0.0667086232985769, 0.06728814648730413, 0.16042180040052959, 0.13087105751037598, 0.1292382308415004, 0.08454835388277258, 1.1468857271330697, 21.113968747002737, 54.51382909502302, 44.34793015888759, 35.70067467008318, 31.325856072562082, 42.63471283231463, 51.550950459071565, 54.22338049752371, 39.99317448479788, 3.9008081470217024, 0.5682420826383999, 8.20833604676383, 7.362993887492588, 2.7364107881273543, 3.9234484178679327, 27.224336181368145, 48.13279111044747, 50.00105401447841, 51.561789648873464, 49.92265748977661, 49.271586963108604, 45.85433782849993, 45.393039975847515, 47.05235317775181, 46.25991807665144, 43.88233831950596, 50.323276724134175, 47.91628871645246, 47.7675382069179, 46.40619502748762, 45.32566329411098, 45.65674843106951, 45.32300213405064, 45.33943462371826, 42.82051113673619, 44.80544819150652, 47.69074324199131, 47.56467860085623, 49.957269941057476, 47.25375018801008, 46.83491972514561, 39.369848115103586, 35.803421156747, 37.11425788061959, 37.67106914520264, 36.691807406289236, 36.04501002175467, 34.97650214603969, 36.047851834978374, 36.441342217581614, 35.422694614955354, 35.835900511060444, 36.627783230372835, 35.23371403557913, 35.73669760567801, 36.36462368283953, 36.88371665137154, 34.87603119441441, 36.286498137882774, 41.31920344488961, 41.505290099552695, 41.29333530153547, 39.0304286139352, 36.420417717524934, 41.41893441336495, 44.58667026247297, 45.95049394880022, 49.87139368057251, 44.74141706739153, 44.559773785727366, 44.16378205163138, 45.549572467803955, 48.690595967429026, 47.38271222795759, 45.824227809906006, 42.65901068278721, 45.612728118896484, 45.018716199057444, 47.219005720955984, 47.20642948150635, 46.482680797576904, 47.78056607927595, 48.16592359542847, 39.88868400028774, 34.74352557318551, 35.39730937140328, 36.79799672535488, 38.65506260735648, 37.47408076695034, 37.21428762163435, 36.59250375202724, 35.33706848961966, 35.611195768628804, 35.949274267469136, 36.590568678719656, 35.89883034569876, 35.21791730608259, 37.64932823181152, 36.72018384933472, 37.86878708430699, 43.770298617226736, 44.01378434044974, 46.651956285749165, 44.769744873046875, 46.12635285513741, 49.11634683609009, 48.93188605989729, 47.54400076184954, 43.866666657584055, 48.675973483494346, 51.24904080799648, 45.443661076681956, 46.04466635840279, 39.19410037994385, 37.3004800251552, 39.166109561920166, 36.13332509994507, 37.502547536577495, 37.77023730959211, 40.25272791726248, 38.209801197052, 43.849660941532676, 49.130458627428325, 49.32794727597918, 52.82985326222011, 49.56142064503261, 43.37782961981637, 21.121215718133108, 2.0682859080178395, 3.7456809282302856, 14.477928400039673, 13.564697997910635, 10.730403593608312, 1.7674054588590349, 0.23765461040394648, 20.303244250161306, 53.32805299758911, 40.93667731966291, 42.15118074417114, 44.23932981491089, 51.99074016298567, 33.286936487470356, 2.9791799783706665, 0.3352039802287306, 0.13361889363399573, 0.10271963024778025, 0.07335667870938778, 0.13121248276105948, 0.1803666315972805, 0.13374786957034043, 0.0959818521514535, 0.12320784585816519, 0.14851424364106997, 0.15404306910932064, 0.2077883623008217, 0.12241348491183349, 0.2008204319115196], [0.028562853578478098, 0.049389837974948544, 0.09585066419094801, 0.03235398139804602, 0.03442523329119597, 0.016518074985859648, 0.05288160971498915, 0.06478742603212595, 0.05805634507643325, 0.03328819858974644, 0.0528074356594256, 0.02349892637825438, 0.030072142769183432, 0.044548439726765664, 0.043516459209578376, 0.08247299346008471, 0.061134369910827706, 0.10595078007983309, 0.43407421346221653, 8.807368908609662, 31.50233336857387, 41.22924164363316, 25.47920056751796, 28.197156940187725, 38.20216512680054, 43.18492678233555, 39.98933907917568, 42.96421725409371, 6.908796225275312, 0.14727979845234326, 0.8664369444761957, 2.738996603659221, 0.6057571438806397, 1.5914413524525506, 23.0121488571167, 42.796519007001606, 49.66021013259888, 45.41437094552176, 44.480407987322124, 42.783630098615376, 45.08244160243443, 41.244597162519185, 44.14467797960554, 43.50690630504063, 47.52599450520107, 44.62427738734654, 44.18946606772286, 41.60648018973214, 40.8941057068961, 40.010711738041465, 37.74454287120274, 39.202459062848774, 38.01559904643467, 39.271367822374614, 41.226101057870046, 40.03342192513602, 41.94847052437918, 42.04495668411255, 41.13230732509068, 36.460018975394114, 34.180023193359375, 33.21224682671683, 33.531850065503804, 32.364288670676096, 34.18878139768328, 32.67804152624947, 33.82609237943377, 31.471056052616664, 34.80862324578421, 36.39916317803519, 32.86899191992623, 33.055703912462505, 32.54176303318569, 31.970610686710902, 33.055978366306846, 32.481167793273926, 30.97324194226946, 34.18471670150757, 39.258385113307405, 42.318364824567524, 41.03551891871861, 38.80388954707554, 36.16209411621094, 35.793933391571045, 38.66252844674246, 41.92082364218575, 44.88245160239083, 46.09265061787197, 38.9979944229126, 32.862335545676096, 42.82501009532383, 48.07127523422241, 45.72199896403721, 43.2228569984436, 39.076300621032715, 42.272006443568635, 43.23330361502511, 44.832455839429585, 44.880269868033274, 42.38649538585118, 43.83283240454537, 45.867942401341026, 37.37619454520089, 31.927938325064524, 33.13416991915022, 33.05762161527361, 33.91546705790928, 32.995883396693635, 34.57093232018607, 34.771829060145784, 32.99699510846819, 32.97616788319179, 32.83642223903111, 32.276852539607454, 32.410612310682026, 31.86326449257987, 33.78088739940098, 34.1976820400783, 32.68765435900007, 33.35606064115252, 35.451654706682476, 37.538254329136436, 39.93288149152483, 40.24491466794695, 44.368184157780235, 43.23472104753767, 44.95899295806885, 43.2419958114624, 42.77250950677054, 47.532550130571636, 44.35839762006487, 43.33825962884085, 40.2976063319615, 38.74108130591256, 36.570186138153076, 36.73850277491978, 37.98469345910208, 36.08235658918108, 35.54853343963623, 38.313263348170686, 44.202754497528076, 45.32309593473162, 45.3752247946603, 46.26627567836216, 46.36544384275164, 40.531597341809956, 14.546417662075587, 1.1106758415699005, 3.473197332450322, 9.721273286002022, 5.424282329423087, 1.9263088064534324, 0.3019735962152481, 0.4166888434972082, 17.977329560688563, 37.06102425711495, 30.086624009268625, 22.150011164801462, 25.154737063816615, 44.62331853594099, 15.747869764055524, 0.22967829555273056, 0.07756200805306435, 0.03740746255165764, 0.0579175575237189, 0.015531907456793954, 0.01960072573274374, 0.034213699999132326, 0.035435921379498074, 0.10584750704999481, 0.024921434332749674, 0.028646130181316818, 0.03868491668254137, 0.0435589185383703, 0.0523413465624409, 0.026302034268155694, 0.03237411692472441, 0.025022717558645775, 0.0552621650110398, 0.050872562519673786, 0.07202094181307725, 0.04695363602201853, 0.04154091468080878, 0.014105390208507223, 0.062414935124771934, 0.02940082736313343, 0.06687043354447399, 0.03480259036379201, 0.04526285906987531, 0.009952202888338693, 0.04290766741282173, 0.02551992087891059, 0.055432029467608245, 0.07085804814206702, 0.43438796805483954, 12.827524525778633, 38.655945028577534, 47.28297431128365, 31.216328144073486, 32.13990354537964, 39.88860409600394, 46.52428661073957, 45.71405022484915, 44.800820691244944, 7.159521102905273, 0.22753006725439004, 2.4043739650930678, 7.915680527687073, 2.117679783276149, 1.8692354347024644, 24.86825588771275, 43.15735633032662, 49.527798312050955, 46.995965072086875, 45.67308017185756, 45.277807576315745, 46.138543469565256, 41.93077346256801, 44.65007604871477, 42.81006799425398, 47.513890743255615, 47.35807738985334, 45.269712924957275, 42.93714359828404, 42.4429738180978, 40.55329309191023, 40.11495556150164, 40.14068821498326, 40.49078014918736, 40.23466954912458, 43.07620137078421, 41.575359208243235, 42.68930830274309, 43.8923784664699, 42.70103338786534, 38.593671798706055, 36.12621709278652, 34.538661411830354, 33.748227391924175, 33.70088931492397, 35.539035252162385, 35.14286286490304, 34.64221388953072, 34.01772717067173, 35.234488759722026, 37.87018019812447, 34.432836873190745, 34.491583892277305, 33.83712959289551, 33.681090423039024, 33.80342040743147, 33.69040795734951, 32.940384660448345, 36.48119361060006, 40.67262840270996, 43.590930870601106, 41.20716721670968, 40.31172159739903, 37.439999852861675, 37.14432273592268, 40.936190945761545, 44.77984407969883, 47.21335336140224, 46.47664628710066, 41.020552498953684, 35.895137378147666, 45.44686072213309, 49.23965651648385, 47.86474697930472, 43.49515342712402, 40.798943178994314, 43.52710124424526, 44.334106717790874, 46.187246867588584, 46.1262138911656, 44.39504589353289, 46.12955944878714, 46.220813614981516, 38.858464172908235, 32.86687271935599, 34.53329045431954, 35.07526731491089, 34.95573398045131, 34.6260905947004, 35.87571021488735, 36.74896328789847, 34.56345953260149, 34.36987577165876, 33.869035720825195, 34.240451676504954, 34.693324838365825, 34.128432818821494, 34.98024722508022, 35.75582947049822, 34.931912081582205, 36.12105458123343, 37.68207509177071, 40.105981963021414, 42.05168948854719, 41.988314969199045, 45.77062593187605, 45.00784226826259, 46.39868402481079, 44.04234838485718, 44.394132205418174, 48.87652628762381, 46.155504022325786, 44.616377285548616, 43.13920068740845, 39.85536738804409, 37.415622098105295, 38.01720755440848, 38.70768131528582, 37.935173647744314, 38.83690391268049, 39.565293993268696, 45.6054116657802, 46.03141614368984, 48.751288482121055, 48.691870961870464, 47.54566485541207, 41.480860233306885, 17.716865914208547, 0.9905836113861629, 5.098443516663142, 6.9567548632621765, 7.654103432382856, 4.57397655078343, 0.44411748168723925, 0.2868318701429026, 20.57865694590977, 43.88099036897932, 34.218411990574424, 29.313438892364502, 31.983183452061244, 50.32396459579468, 21.851325477872575, 0.33128856175712174, 0.10008090934050934, 0.1464051396719047, 0.11793081116463457, 0.05597729342324393, 0.02369733849939491, 0.05928926356136799, 0.11394703707524709, 0.030156063980289867, 0.030471419915556908, 0.0005786769283336721, 0.05123100203594991, 0.05026656289451888, 0.06453625950962305, 0.02147309053024011, 0.1611683110573462, 0.14818508630352362, 0.25899589381047655, 0.1455109255122287, 0.19540713381554398, 0.13971107958682946, 0.1380439597581114, 0.11651206229414258, 0.14001309552362987, 0.17277443542012147, 0.1631692565445389, 0.16134276241064072, 0.09958435741386243, 0.0754195608730827, 0.16988686179476126, 0.23135620408824512, 0.1869285266314234, 0.20260092137115343, 0.7129117197224072, 14.984742164611816, 44.495013100760325, 55.994021211351665, 35.67093290601458, 37.57210595267159, 47.20265313557216, 52.54443516050066, 49.1008870942252, 53.29090445382254, 9.130797999245779, 0.2547020156468664, 7.046255912099566, 10.78478193283081, 3.622774677617209, 2.7408847766263142, 28.19991363797869, 45.80637093952724, 51.31855753489903, 47.930351870400564, 45.93248769215175, 44.56923028400966, 46.66942058290754, 42.15039907182966, 44.63373735972813, 42.700018950871055, 49.73096363885062, 48.681271484919954, 49.531202929360525, 45.119089875902446, 45.063942023685996, 43.115736620766775, 42.467490536826, 43.23249067578997, 42.02485901968819, 42.655189173562185, 45.303522859300884, 43.50215373720442, 44.216994830540244, 45.54670286178589, 44.53111246653965, 39.27155194963728, 37.21945708138602, 35.692788464682444, 36.29794182096209, 35.55209786551339, 38.21319191796439, 35.99138729912894, 37.32226957593645, 36.7305714062282, 37.52341992514474, 39.76789999008179, 36.85625737054007, 36.38446773801531, 35.94770050048828, 36.16291052954537, 36.374705518995015, 35.35999754496983, 35.2528007371085, 38.01969500950405, 43.713306018284385, 46.10775252750942, 44.6681934765407, 42.328328541346956, 38.52009732382638, 39.22075366973877, 43.42510516302926, 45.06583888190133, 49.60395404270717, 47.81962537765503, 45.07103613444737, 40.88808856691633, 45.894234384809224, 52.40933091299874, 49.13628816604614, 46.791722774505615, 42.82875517436436, 46.1098439352853, 45.923913615090505, 46.918798378535676, 47.282685961042134, 45.0790821484157, 47.49864986964634, 48.79864740371704, 39.96590975352696, 35.188053948538645, 35.86485365458897, 37.62456137793404, 36.18987301417759, 36.21565430504935, 37.13479675565447, 38.721202509743826, 35.68327290671212, 36.230064868927, 35.428680488041465, 35.71690566199166, 35.37619726998465, 35.12203911372593, 35.85228436333792, 36.48158270972115, 36.16755540030343, 36.8663009916033, 39.07712050846645, 40.97192900521414, 44.89962060110909, 44.32344470705305, 47.34509120668684, 47.495682988848, 50.1259583064488, 46.3625533921378, 44.02960886274065, 50.488838400159565, 48.07557269505092, 48.3611193384443, 43.71145779745919, 41.62822805132185, 39.38678434916905, 40.591636725834434, 41.58507626397269, 38.81026799338204, 41.21704755510603, 41.53678628376552, 48.128816740853445, 49.02345289502825, 50.08833728517805, 48.75910520553589, 48.04003265925816, 41.467300823756624, 18.69295927456447, 1.4619333360876356, 7.912290675299508, 19.92277479171753, 15.358730690819876, 9.027742317744664, 0.8428813027484077, 0.537664851972035, 23.16384540285383, 47.10246358598982, 40.81088365827288, 32.5797974722726, 36.714041641780305, 57.24169881003243, 26.559089592524938, 0.6147335107837404, 0.1505583439554487, 0.18536674257900032, 0.22211332220051969, 0.1285243984311819, 0.0968152695734586, 0.17289178126624652, 0.17717677062111242, 0.18824107120079653, 0.1203503313341311, 0.03582933598331042, 0.21602547887180532, 0.16405125707387924, 0.116525212302804, 0.09978063045335667], [0.021388494176790118, 0.011154969821551015, 0.023506941573162164, 0.09868917973445994, 0.032128103875688145, 0.043728884775191545, 0.023535441740282943, 0.0523772953477289, 0.03986381360196641, 0.013589617081119545, 0.01542801526375115, 0.04328920765380774, 0.024784678992416178, 0.044962912664881775, 0.034221516722547154, 0.028624454380146096, 0.008829036594501563, 0.05711668264120817, 0.1128275967868311, 5.104365118912288, 28.06209785597665, 38.66973720278059, 30.127573217664445, 22.640116248811992, 20.676287821360997, 31.477632522583008, 40.38576854978289, 42.21448230743408, 8.33107076372419, 0.20785209030977317, 1.4864816474063056, 4.130319305828639, 1.1430324081863676, 1.1651706716844012, 19.485140766416276, 41.1774115562439, 47.531511374882285, 45.49889925548008, 45.24453265326363, 41.2993072782244, 45.777518544878276, 42.1741167477199, 43.04535831723894, 48.01539434705462, 45.93263707842146, 43.64862871170044, 42.583011286599294, 38.81761571339199, 39.63527624947684, 38.06717899867466, 37.3774973324367, 36.24035862513951, 37.68590702329363, 36.507218088422505, 37.516516889844624, 39.68420198985508, 38.239904267447336, 38.08800274985177, 33.88469001225063, 32.18311786651611, 32.67704793385097, 33.51024464198521, 32.21484681538173, 33.29373182569231, 33.30203839710781, 31.94512469427926, 32.16624069213867, 32.195732321058, 38.25850806917463, 34.674880845206125, 31.89391299656459, 33.17712368283953, 33.113578932625906, 33.776628153664724, 31.70090593610491, 31.59128073283604, 33.9962329183306, 36.711290155138286, 42.8655424118042, 44.349080085754395, 45.09278399603707, 43.711079120635986, 39.58876848220825, 37.1146365574428, 37.2539826801845, 39.49574599947248, 42.09084606170654, 45.351159708840505, 37.789063453674316, 31.79695783342634, 44.935178007398335, 47.03822749001639, 44.171188831329346, 41.54811879566738, 40.51901762826102, 42.944977692195344, 45.8158552306039, 43.59326546532767, 46.34261901038033, 41.28219039099557, 42.63615458352225, 46.08641113553728, 39.56724991117205, 31.58996057510376, 31.56318916593279, 32.84059115818569, 33.77463402066912, 34.823495864868164, 33.01408420290266, 35.00324576241629, 34.64112302235195, 32.52285351072039, 32.5775705746242, 32.943205629076274, 33.362689222608296, 32.8694782938276, 33.334406580243794, 33.58348560333252, 32.23716442925589, 32.16556324277605, 32.90331949506487, 32.856624126434326, 34.066409724099294, 36.03595304489136, 38.56769943237305, 41.45305701664516, 44.38023233413696, 45.53642995016915, 43.2059450830732, 43.973905154636924, 47.32285349709647, 45.17053781236921, 44.380704811641145, 42.53668417249407, 41.77326474870954, 42.03722333908081, 39.51158789225987, 41.55323614392962, 40.285085678100586, 43.75597837993077, 43.35566486631121, 46.13318293435233, 46.956683431352886, 49.259677750723704, 43.43843528202602, 36.96619871684483, 7.334331699780055, 3.724028604371207, 6.18856897524425, 2.5811845575060164, 8.412613953862872, 1.9712543146950858, 0.2863606411431517, 0.29789237092648235, 18.666795832770212, 30.713000638144358, 30.854323523385183, 21.855928659439087, 30.848427976880753, 41.87177630833217, 9.696381364549909, 0.07942711082952363, 0.025053300828273808, 0.030517818140132085, 0.029472002293914557, 0.047553277774048705, 0.03646735228332026, 0.07883253094873258, 0.02993435605562159, 0.010208014831213015, 0.021600292097511034, 0.019200686930811832, 0.04255811670528991, 0.04228793423888939, 0.05405949561723641, 0.04033979234684791, 0.024701538096581186, 0.026387066580355167, 0.03218264791316219, 0.031485456574176035, 0.013850081229715474, 0.05798594028289829, 0.061413580285651345, 0.034114230158073564, 0.011915809441623943, 0.026978545556110994, 0.019983567064628005, 0.029447731096297503, 0.029898322453456264, 0.016919370773913603, 0.0760130143857428, 0.00918131586097713, 0.040349376653986316, 0.049378611613065004, 0.0672334497794509, 7.968800374439784, 33.970590591430664, 45.95249155589512, 31.204825401306152, 24.704598018101283, 27.758685656956263, 40.38938161305019, 45.51489053453718, 50.8362135887146, 9.390215941837855, 0.11779939250222274, 2.220309670482363, 5.686579431806292, 1.3870933119739806, 1.42742315360478, 21.6561610017504, 42.90097822461809, 47.0892550604684, 45.687650544302805, 45.95595175879342, 44.115165506090435, 46.59122208186558, 42.20044347218105, 43.52738264628819, 48.442454951150076, 48.803917612348286, 44.7075445992606, 44.04124362128121, 40.94055094037737, 41.12215600694929, 40.83913503374372, 39.582487310682026, 38.35280902045113, 39.28647320611136, 38.272143908909385, 39.60431160245623, 41.030019419533865, 40.969163622174946, 40.450689043317524, 37.20951073510306, 34.17386014120919, 34.72981677736555, 34.87482568195888, 35.11819675990513, 35.24387925011771, 35.76078353609358, 33.52055924279349, 34.77390309742519, 33.1417121887207, 39.33419343403408, 36.228762081691194, 34.03692504337856, 34.51014947891235, 34.05119316918509, 33.94786303383963, 34.20564814976284, 33.55354928970337, 34.35909564154488, 38.160701751708984, 46.28764138902937, 46.39707204273769, 45.55262967518398, 44.65176446097237, 40.342085225241526, 38.88806002480643, 39.69800458635603, 40.99791874204363, 44.8412765775408, 47.35945313317435, 40.05962358202253, 33.578927585056846, 45.5869641985212, 47.57887029647827, 45.759911809648784, 44.34237854821341, 42.74543932506016, 43.68508243560791, 46.629409381321494, 45.145364488874165, 46.343550068991526, 42.71792445863996, 45.06656844275338, 46.273661613464355, 41.22870315824236, 33.178593226841514, 33.90460007531302, 34.0711727142334, 34.528732436043875, 34.97773545128958, 34.79534176417759, 36.90871974400112, 35.30338362285069, 33.52855314527239, 34.546578884124756, 34.748924323490684, 34.91595901761736, 34.17190769740513, 34.64065749304635, 34.715242930821006, 32.6958532333374, 32.525629316057476, 33.9677209854126, 35.41613898958479, 35.42280926023211, 38.047578130449565, 40.9675794328962, 43.51673453194754, 45.11055053983416, 46.89010579245431, 43.41717379433768, 45.905083996909006, 48.852099895477295, 45.88234601702009, 46.216154847826274, 43.40126936776297, 42.74081877299717, 43.1571478843689, 41.956009319850374, 44.042456081935335, 42.4511935370309, 45.07676492418562, 45.22541121074131, 47.33461332321167, 48.476772103990825, 51.30921915599278, 43.40634502683367, 38.03967802865164, 9.987677642277308, 5.988998906952994, 12.307394538606916, 6.6561866487775525, 7.141705921718052, 3.1438025619302477, 0.24388852875147546, 0.25367818772792816, 20.42956597464425, 34.80559383119856, 34.729351248059956, 23.38256253514971, 33.72939429964338, 48.6125225339617, 13.48011497088841, 0.057771543573055945, 0.07479140029421874, 0.03189890492441399, 0.02929107771654214, 0.010382512833790054, 0.04869132349267602, 0.029042184286351715, 0.035012311967355866, 0.031273760433707914, 0.04009834923116224, 0.0409168287047318, 0.059459833694355826, 0.03214745908709509, 0.01061190092670066, 0.015733834389331083, 0.11783794686198235, 0.11667653918266296, 0.11470049593065466, 0.18838749905782087, 0.08787187268691403, 0.13812630676797458, 0.1206666100770235, 0.2546428202518395, 0.10853497391300541, 0.08952076706503119, 0.0882010707365615, 0.2061960713139602, 0.11187674530914851, 0.11153077387384006, 0.1762990720037903, 0.07437899349523441, 0.11401993887765066, 0.19062415403979166, 0.33038722297974993, 9.94240231173379, 39.83495705468314, 49.712825366428916, 39.80080665860857, 34.4475531578064, 32.08485991614205, 40.27222456250872, 47.78410618645804, 49.86708927154541, 11.714220745222908, 0.3077994707439627, 4.09437323468072, 10.293413145201546, 3.987641521862575, 2.4948464589459554, 23.934928689684185, 45.252151353018625, 48.681177684238975, 46.935133593423025, 46.635714871542795, 44.39475406919207, 49.61662060873849, 43.30193097250802, 45.10915395191738, 50.15254211425781, 49.24824448994228, 46.6131922858102, 45.70941925048828, 42.63545281546456, 44.34076656614031, 43.30123962674822, 42.03563220160348, 39.842784200395855, 42.614198275974815, 40.07766110556466, 42.208583286830354, 43.81586837768555, 43.45760536193848, 41.996169907706125, 36.64126968383789, 35.62573487418038, 37.617832047598704, 36.29726784569876, 35.75675358091082, 36.6620135307312, 37.78772592544556, 35.46465826034546, 37.000352587018696, 35.10358817236764, 40.92359038761684, 35.216736112322124, 36.6507921900068, 35.40410818372454, 36.20105266571045, 36.928900786808555, 35.96972976412092, 35.58724880218506, 37.36288527079991, 41.135263783591135, 48.581655161721365, 48.633002349308555, 48.201637336185996, 47.60307782036917, 43.97637176513672, 41.41299370356968, 40.93511744907924, 42.69359881537301, 46.57777384349278, 49.25573812212263, 44.18775333677019, 37.98811892100743, 48.043725626809255, 49.40013905933925, 47.482342447553364, 44.973921162741526, 43.77026735033308, 47.12609093529837, 48.24823890413557, 45.846323081425254, 48.50771938051496, 42.9765294619969, 45.3310273034232, 48.60134635652815, 43.425584588732036, 34.78887299128941, 35.11618525641305, 36.75072118214199, 36.58481209618704, 37.4735666002546, 36.16321972438267, 38.36891841888428, 38.74403429031372, 35.21313694545201, 35.24175310134888, 35.639520100184846, 37.056355067661826, 36.109072412763325, 36.12465722220284, 36.87577486038208, 35.22972576958792, 34.11929941177368, 35.759977545057026, 35.63321113586426, 37.065015997205464, 39.918974672045024, 42.61861733027867, 44.88437972749983, 47.9988055229187, 49.06073692866734, 43.9075220652989, 46.55256577900478, 49.76557261603219, 49.53324222564697, 49.56845569610596, 46.14875037329537, 45.77017082486834, 44.27093022210257, 43.21168776920864, 46.57969849450247, 44.08493389402117, 47.03922803061349, 47.63244785581316, 50.82984209060669, 49.493411677224294, 52.52313198362078, 45.63543830599104, 41.25079148156302, 11.192058409963336, 10.952513183866229, 21.173782314573014, 8.04413708618709, 19.185299941471644, 6.392122966902597, 0.8762261963316372, 0.36088495648333, 24.033824137278966, 41.25477627345494, 40.596010616847444, 31.149284975869314, 41.839630467551096, 56.8666524205889, 17.671282257352555, 0.289164130709001, 0.11612407597047941, 0.12184860450880867, 0.09861376735248736, 0.09245429786720447, 0.1761307953191655, 0.19498619783137525, 0.11932093942803995, 0.1083781983969467, 0.08954740634986333, 0.14630038743572576, 0.17913310921617917, 0.1670750533895833, 0.12702577241829463, 0.10080926918557712], [0.024689770603020276, 0.0274324532531734, 0.10294446961155959, 0.02211310002686722, 0.015418089992765869, 0.019275003478729298, 0.03185413518388357, 0.054180793929845095, 0.03925737292904939, 0.025604695347802978, 0.03904608051691737, 0.052486244322998185, 0.00855633252233799, 0.012454529775173535, 0.07141452828156096, 0.06054254488221236, 0.04956442842792187, 0.07214182282664947, 0.02980534279985087, 3.3075051605701447, 22.3664927142007, 38.94742195946829, 45.29381969996861, 44.2376309803554, 42.84059143066406, 34.1005323273795, 26.76036674635751, 41.12548419407436, 13.762635673795428, 0.07546937891415187, 1.5739615304129464, 10.28278500693185, 6.289070325238364, 4.356729831014361, 18.646296909877233, 38.40980509349278, 47.787517751966206, 44.640695980616975, 45.41337040492466, 41.69271080834525, 39.52405643463135, 43.5219178880964, 45.276358876909526, 47.23510122299194, 44.9167548588344, 42.49091291427612, 39.431826046534944, 39.43526193073818, 36.94089337757656, 36.990798813956125, 35.62965018408639, 36.01077624729702, 36.41818387167794, 34.66108519690377, 35.90571253640311, 34.41850968769619, 32.81337506430489, 32.04563733509609, 33.41304976599557, 32.88476433072771, 33.10971573420933, 33.759726660592214, 32.923590864454, 34.07444878986904, 36.193048340933665, 33.52738584790911, 32.36884668895176, 33.44150263922555, 35.09863758087158, 34.275929178510395, 32.838270459856304, 32.86460760661534, 32.29049185344151, 34.101251465933665, 33.32235492978777, 32.254093715122764, 30.712545531136648, 37.47629376820156, 45.22898605891636, 45.311944075993125, 46.253379821777344, 43.48753472736904, 43.58724137714931, 38.891669613974436, 38.0388685635158, 39.189844608306885, 44.085951805114746, 45.22113112040928, 42.12428774152483, 36.27333130155291, 39.611374446323936, 47.874238218579976, 45.74075910023281, 42.627174036843435, 43.92901284354073, 44.47368560518537, 44.86561264310564, 46.083472047533306, 45.74281924111502, 41.69885996409825, 41.593368938991, 46.206892899104524, 41.52353259495327, 33.60790504728045, 31.761021750313894, 33.477053097316194, 32.668748310634065, 33.016137395586284, 33.045552594321116, 35.711423533303396, 32.8170610836574, 33.79572875159127, 32.8695512499128, 34.087282112666536, 31.697251183646067, 31.313655035836355, 32.347943033490864, 33.08249616622925, 33.4506846836635, 32.743705477033345, 32.60146195547921, 32.49365718024117, 32.714773178100586, 34.332171372004915, 37.56144741603306, 38.671998841421946, 41.96070977619716, 43.00255046572004, 44.959298678806846, 43.833256244659424, 46.38900171007429, 45.68160213742937, 47.17502709797451, 44.74514825003487, 43.94492769241333, 44.167044230869834, 44.19050134931292, 44.932030473436626, 42.94236516952515, 43.305102825164795, 48.002592291150776, 47.22148275375366, 45.967638628823416, 44.750046730041504, 41.62198509488787, 26.186754737581524, 6.218073197773524, 5.528647746358599, 2.2782602523054396, 6.690400881426675, 6.475473991462162, 2.6167339299406325, 0.391608967844929, 0.44812903500029017, 24.77004483767918, 35.97828994478498, 27.493549346923828, 29.577814374651226, 37.9455577305385, 37.68684155600411, 6.96637464421136, 0.022613372021753873, 0.04381039718698178, 0.05642891276095595, 0.02522380819677242, 0.010624038221846734, 0.04193747429443257, 0.0477554947803063, 0.038871998965208016, 0.02253342024050653, 0.03310376259365252, 0.06074840562152011, 0.049317886121571064, 0.05226542188652924, 0.06408775464764663, 0.057972145665969164, 0.017658649943768978, 0.07105343230068684, 0.01499810056494815, 0.06048197206109762, 0.03331168607941695, 0.04389730395217027, 0.033426090476236174, 0.10915262398443051, 0.03073450151298727, 0.03697742062753864, 0.07774844912013837, 0.03214673644730023, 0.01603463914112321, 0.04720477540312069, 0.023199490570862378, 0.06081205220626933, 0.04784580779128841, 0.0534787001753492, 0.040489982680550644, 4.803903732981, 28.910695246287755, 45.80398423331124, 46.5864382471357, 39.93799189158848, 34.89387764249529, 35.46151072638375, 33.65006671633039, 46.40386043276106, 13.611590521676199, 0.027796897804364562, 1.100426054426602, 7.194603426115854, 8.09655429635729, 3.8091379574366977, 21.011149304253713, 39.81667634419033, 48.064848150525776, 44.957909039088655, 45.95822729383196, 42.39003896713257, 42.864698205675396, 42.98392929349627, 46.969819000789094, 47.66497237341744, 46.5806017603193, 42.97034556525094, 42.85355676923479, 41.44425017493111, 38.74084506716047, 39.00488008771624, 38.582155159541536, 37.339129379817415, 38.061460631234304, 36.57906593595232, 38.36554854256766, 35.55786487034389, 35.2355831010001, 33.76216547829764, 34.71863712583269, 33.54533999306815, 33.76182501656668, 34.83709001541138, 35.10982765470232, 35.54642118726458, 36.200878960745676, 34.39960363933018, 33.950704847063335, 35.096101488385884, 37.39269304275513, 35.741255623953684, 35.379699162074495, 34.086879117148264, 34.57131447110857, 35.76556737082345, 34.73286703654698, 33.29373182569231, 33.31010178157261, 39.38719081878662, 47.67022173745291, 46.09050709860665, 48.2241599219186, 45.331308705466135, 44.346543993268696, 39.32911082676479, 39.86307988848005, 39.99407080241612, 45.39720542090279, 46.74490928649902, 43.98381675992693, 37.72704035895211, 42.723799160548616, 49.390151023864746, 48.26544611794608, 44.704324109213694, 44.23097113200596, 46.75832625797817, 46.442815508161274, 46.354979855673655, 45.741603306361604, 44.530573981148855, 43.67635897227696, 47.34769678115845, 43.33619948795864, 33.756381102970664, 33.49651500156948, 33.57513734272548, 34.584849561963765, 33.918308871132986, 35.50408928734915, 36.598652907780235, 33.89609200613839, 34.70082194464547, 34.102255480630056, 34.704153605869834, 33.562713963644846, 33.439529350825715, 33.6294653075082, 34.76842444283621, 34.71907833644322, 33.74386044910976, 33.03329944610596, 33.305679253169465, 34.49175064904349, 35.568182945251465, 40.11102288109915, 41.94914449964251, 44.017779554639546, 46.07468605041504, 45.87828826904297, 42.936035360608784, 47.293160370418, 46.42912060873849, 48.39311926705496, 45.8166959626334, 45.614228929792134, 45.74673802512032, 45.38257251467024, 46.44640077863421, 45.841890130724224, 45.77022641045706, 48.64102404458182, 50.036298751831055, 48.82892765317644, 46.64046049118042, 43.472165312085835, 30.067308017185756, 7.993645395551409, 8.45423800604684, 4.203671004090991, 8.853002939905439, 8.362448828560964, 3.6833434275218417, 0.198142389899918, 0.3913995176553726, 27.357774598257883, 38.29286343710763, 30.805116380964005, 30.581120354788645, 42.927905968257356, 42.89810167040144, 9.365230219704763, 0.034855482168495655, 0.006445770551051412, 0.02733709872700274, 0.03858731281278389, 0.057461765195642195, 0.01458478283270129, 0.03682581554832203, 0.01627216541341373, 0.08847175871155091, 0.011433321849576064, 0.09468184690922499, 0.03637207918135183, 0.05228131656934108, 0.017354276097778763, 0.06967730900006634, 0.09871057394359793, 0.18888600516532147, 0.21422517618962697, 0.20560786287699426, 0.049596557061054876, 0.09320899844169617, 0.10525980751429286, 0.1976218856871128, 0.10933664268148796, 0.0916463051523481, 0.18722830340266228, 0.12319770854498659, 0.09419410236712013, 0.11407199608428137, 0.157028053221958, 0.14898936743182795, 0.12677178319011415, 0.15850029779332026, 0.14359284272151335, 5.691788409437452, 33.815673555646626, 52.663023539951865, 55.55225821903774, 52.68442051751273, 51.27268205370222, 45.4755984715053, 35.308712891169954, 51.850765228271484, 17.89516363825117, 0.14908661507070065, 3.4194067674023763, 19.653071778161184, 12.082407525607518, 5.28542605468205, 24.392022882189067, 42.379231044224326, 50.216104234967915, 45.74988555908203, 45.89962271281651, 43.217857769557405, 42.95333290100098, 45.14101144245693, 47.54371588570731, 50.013164724622456, 49.263707705906455, 46.15104675292969, 43.70873062951224, 43.13160630634853, 41.49822378158569, 41.71475396837507, 40.400429248809814, 39.13004493713379, 40.20767232349941, 37.866581031254356, 39.97105142048427, 37.55981111526489, 36.14795800617763, 35.33597067424229, 36.97018698283604, 35.909759862082346, 35.31016853877476, 36.6824586050851, 36.596992288317, 37.86461469105312, 38.15790857587542, 36.567337376730784, 36.85586132322039, 37.093649523598806, 39.44459336144583, 38.064514364515034, 36.70410919189453, 37.07821757452828, 35.86873769760132, 36.99471412386213, 36.68252113887242, 34.173349448612754, 35.20557383128575, 41.221213000161306, 49.93652956826346, 48.89768007823399, 50.53768423625401, 47.12592417853219, 46.74335983821324, 41.73672069822039, 42.33286918912615, 42.415556226457866, 46.88839306150164, 48.76349299294608, 47.70158243179321, 41.69841527938843, 43.833763463156565, 52.21387113843645, 50.49609579358782, 45.037660462515696, 46.31340878350394, 47.888197149549214, 47.90759999411446, 46.83347797393799, 46.25736461366926, 42.641633238111226, 45.648351533072336, 49.02364049639021, 45.56435823440552, 37.59771006447928, 35.473753452301025, 35.700556550707134, 36.10456998007638, 35.977640288216726, 36.40578828539167, 38.46578672954014, 35.87398706163679, 37.264439719063894, 35.06606442587716, 37.26413747242519, 35.754794188908164, 34.668603147779194, 33.52533265522548, 35.5468623978751, 37.270356110164094, 35.451585224696565, 34.90013449532645, 35.45807831627982, 37.146188327244346, 37.67274366106306, 41.38712903431484, 43.176491669246126, 45.32213360922677, 47.26036139896938, 47.71499245507376, 43.021015303475515, 48.35396269389561, 48.43547548566546, 50.75852230616978, 48.44955253601074, 46.802638394492014, 48.28177785873413, 47.60027074813843, 48.80026980808803, 48.084216254098074, 46.029825006212505, 51.84441804885864, 51.01301397596087, 49.85207768848964, 47.598603180476594, 45.34620564324515, 32.12328692844936, 12.887441447802953, 9.999605962208339, 8.794377514294215, 13.908449700900487, 12.884224431855337, 9.71306312084198, 1.1468226505177361, 0.47381020124469486, 31.058951445988246, 45.87292078563145, 37.85562024797712, 39.90818759373256, 50.02987514223371, 49.972722734723774, 12.328317301613943, 0.18400338930743082, 0.09017753468028136, 0.07327964462872062, 0.1161223796329328, 0.12097607632832867, 0.0934256071756993, 0.1363813861140183, 0.08379704598337412, 0.11568498238921165, 0.12657720648816653, 0.27928181099040167, 0.14787791350058146, 0.1822279074362346, 0.17648478703839438, 0.17379278077610902], [0.05570735862212522, 0.09240787928657872, 0.08701638252075229, 0.04529160859861544, 0.054684718139469624, 0.05528764060831495, 0.048031851915376525, 0.056185366186712465, 0.05002343361931188, 0.0480927131138742, 0.040171125504587374, 0.035220282950571606, 0.03860199970326253, 0.048126270063221455, 0.03334415737273438, 0.044081254795725854, 0.054235626344702074, 0.012617511342146566, 0.06055926398507186, 0.8836464924471719, 16.843513829367502, 40.268330097198486, 41.64089809145246, 49.749414580208914, 65.24339716775077, 54.3568171773638, 29.792166301182338, 45.14470441000802, 25.779732738222393, 1.3813609395708357, 1.0541292301246097, 4.945144976888384, 24.71846488543919, 11.229950410979134, 23.851352282932826, 38.62255546024868, 45.57152877535139, 44.525557381766184, 45.7449175970895, 47.72048848015921, 43.53692947115217, 41.375230244227815, 45.52476045063564, 46.243718351636616, 45.310196604047505, 41.75873953955514, 39.36000599179949, 37.5947709764753, 37.17978981563023, 37.143617493765696, 34.65913275309971, 34.39938824517386, 33.65466294969831, 32.705302783421104, 32.99889544078282, 32.89291456767491, 33.72224112919399, 32.23825182233538, 33.622652598789756, 32.193658283778596, 34.00612020492554, 32.87389039993286, 34.215292249407085, 36.29193162918091, 35.453721795763286, 33.45439502171108, 31.682739870888845, 32.78781264168875, 34.20608936037336, 32.72980907985142, 33.888073784964426, 31.7145938873291, 31.844598157065256, 32.718493938446045, 32.156568799700054, 31.791871752057755, 31.754497391836985, 38.41998420442854, 46.264628955296104, 43.41050699778965, 42.524142674037385, 45.72775207247053, 46.23000260761806, 40.21907779148647, 39.5252445765904, 39.00450141089303, 42.759985378810335, 41.98402793066842, 46.884137289864675, 40.581930092402864, 37.544386114392964, 48.040168149130686, 45.0805447442191, 45.66969987324306, 46.538033621651785, 44.760389123644146, 49.49503060749599, 41.88069779532296, 46.485202993665425, 40.00547974450247, 39.88098887034825, 46.4442572593689, 40.41735506057739, 33.46820109231131, 30.704398768288748, 32.953641823359895, 32.60136815479824, 32.957880224500386, 32.13788856778826, 32.78344569887434, 33.928831917899, 32.32832479476929, 31.768275669642858, 32.66500670569283, 33.92379447392055, 31.846397740500315, 32.72665459769112, 33.36918231419155, 31.944082464490617, 32.90221473148891, 33.32835817337036, 32.72580691746303, 34.993261201041086, 34.99934434890747, 38.47697680337088, 41.14294501713344, 43.204003061567036, 44.09511300495693, 44.11254950932094, 44.520266328539165, 41.42733825956072, 43.99545151846749, 43.574140548706055, 40.991602829524446, 45.06547062737601, 43.14490168435233, 46.855906758989605, 46.49806758335659, 46.625622613089426, 45.516120365687776, 46.422568457467214, 43.8422645841326, 46.61107655933925, 43.719479492732454, 32.22918789727347, 18.586799485342844, 10.630914075034005, 3.500768218721662, 3.1587079678262984, 9.832947339330401, 6.159208493573325, 1.5457973331212997, 0.06031326789941106, 1.001604974269867, 26.63282561302185, 34.36889954975673, 29.512007985796245, 28.742501940046036, 37.03533329282488, 28.615414176668438, 2.8779154121875763, 0.04988445268411722, 0.035184398626110384, 0.023056095765371407, 0.012722315316620682, 0.03997362770938447, 0.023163506162485907, 0.043740426655858755, 0.09035619973604168, 0.07555553929081985, 0.06630208582750388, 0.06466172741992132, 0.05119381831692798, 0.06067430281213351, 0.06352171394973993, 0.06370227211820227, 0.02298451880259173, 0.05676883166389806, 0.04948984046599694, 0.04220433533191681, 0.06962202875209705, 0.030364618503621647, 0.046201537629323344, 0.028443757112004926, 0.032114370326910696, 0.06446140352636576, 0.06878367838050638, 0.09442823087530476, 0.08239234957311835, 0.01763459587735789, 0.027274498782519783, 0.067874787508377, 0.034280932641455104, 0.02086195778766913, 0.03754777680816395, 1.5516155809164047, 21.847123554774694, 46.378860814230784, 47.04998731613159, 54.21302768162319, 60.71528393881661, 49.656023842947825, 30.435197762080602, 47.496937138693674, 25.880234956741333, 0.9441231787204742, 0.289808630411114, 5.733689521040235, 25.47505075590951, 13.796716587884085, 26.501271894999913, 42.318347454071045, 47.09880188533238, 45.77836275100708, 46.20305054528372, 46.22759158270699, 43.451643807547434, 42.78773995808193, 46.829701628003804, 47.95684535162789, 46.79433877127511, 44.08357204709734, 41.36997740609305, 39.46817902156285, 39.14645658220564, 38.09120239530291, 38.49000120162964, 35.50542334147862, 34.58603770392281, 35.685569286346436, 33.727483545030864, 34.491295542035786, 34.2791496685573, 33.76382957186018, 34.89778253010341, 34.215653555733816, 35.64264331545149, 33.26419850758144, 35.91564498628889, 37.44335583278111, 37.147258349827354, 34.04002046585083, 33.2981230872018, 33.93763181141445, 36.06918280465262, 34.75098099027361, 35.56222486495972, 34.724605628422324, 33.831758635384695, 34.46918984821865, 34.401184354509624, 33.44609539849417, 33.72909205300467, 39.97274330684117, 47.427976267678396, 45.14272764750889, 44.02520717893328, 46.10480996540615, 47.97210012163435, 42.343326228005544, 42.13450854165213, 40.597615650721956, 43.63325234821865, 43.94174541745867, 47.72305931363787, 41.263221808842246, 38.934150900159565, 47.69839320863996, 47.96320990153721, 47.752092361450195, 46.97787891115461, 46.24905456815447, 49.315141745976035, 43.86689247403826, 44.543865885053364, 44.3317860194615, 41.66350405556815, 47.16279826845442, 42.27831193378994, 36.01240907396589, 32.30778244563511, 34.880676065172466, 34.53737946919033, 34.60436357770647, 32.49550887516567, 34.80526031766619, 34.75050503867013, 33.98475796835763, 33.67298187528338, 34.721562317439485, 35.18619530541556, 33.776131357465474, 34.32684905188424, 34.82175186702183, 34.5101112638201, 34.964068344661165, 34.59539345332554, 35.2204464503697, 35.807558809007915, 37.467243739536826, 39.25722129004342, 41.865818228040425, 44.90365750449044, 46.00759424482073, 45.78070081983294, 44.458840778895784, 41.5079790524074, 46.40769583838326, 46.42072023664202, 44.05598075049264, 47.27662018367222, 45.34909609385899, 48.707563468388145, 47.23563276018415, 47.59086288724627, 47.89708736964634, 50.40635633468628, 46.14215653283255, 46.88358838217599, 44.11762516839163, 36.594365869249614, 24.620120082582744, 13.511548621313912, 4.503431056227003, 2.552356915814536, 7.012102476188114, 9.040153537477766, 3.7553206852504184, 0.16630604251154832, 0.976087497813361, 29.82559061050415, 39.029959610530305, 35.06385489872524, 34.35487461090088, 40.08961548124041, 35.78847558157784, 4.332869717053004, 0.03277447294177754, 0.02134608064911195, 0.02610616834967264, 0.01562186423689127, 0.014788219505654914, 0.012937099639592426, 0.030365809332579374, 0.058351724940751276, 0.03701140166127256, 0.029894291955445493, 0.04077805133004274, 0.03499456149126802, 0.0705673840961286, 0.04578319025625076, 0.06526173558086157, 0.11243484714733702, 0.16036120722336428, 0.20854110190910952, 0.1642204565661294, 0.08953274999346052, 0.1387524317417826, 0.13717558421194553, 0.1740353570452758, 0.08434613687651497, 0.18371936811932496, 0.1569878025246518, 0.16819982017789567, 0.20269056941781724, 0.1467880776950291, 0.13006828272981302, 0.21249046070235117, 0.17488363438418933, 0.08692498385374035, 0.11769728655261652, 1.9399316183158328, 24.954495191574097, 52.32437528882708, 52.572710854666575, 59.55432333265032, 67.23242323739188, 58.120350633348735, 38.174087456294465, 54.23153073447091, 32.62004491261074, 2.4580134068216597, 2.2058834731578827, 11.829680698258535, 37.325941698891775, 18.413589579718455, 32.415128639766145, 44.54170152119228, 46.827943733760286, 45.73934514181954, 47.406596660614014, 48.22572674070086, 45.01480088915144, 43.115375314440044, 48.270024980817524, 48.92815835135323, 50.09660564150129, 46.55698830740792, 43.95319257463728, 41.25489786693028, 41.21785702024187, 41.34111111504691, 38.37769399370466, 38.38861656188965, 37.0249422618321, 37.370483125959126, 36.504532609667095, 36.30652632032122, 36.170786312648225, 35.17919152123587, 37.653146266937256, 35.97232491629464, 39.0787741797311, 35.09640720912388, 37.72503580365862, 39.211043562207905, 37.93584762300764, 35.73425531387329, 34.56765277045113, 36.36079522541591, 38.08494554247175, 36.282367433820454, 37.588385581970215, 36.23522390638079, 34.5057304246085, 36.25126382282802, 36.23635993685041, 36.03060640607561, 35.49105099269322, 42.391373021262034, 51.17093958173479, 47.47251074654715, 47.24043049131121, 48.9112777028765, 50.721078463963096, 44.2618385042463, 43.867250306265696, 43.102326597486226, 45.058032580784385, 46.10227387292044, 49.80265167781285, 44.14625869478498, 41.62167590005057, 49.325973987579346, 49.137344292231965, 49.04207059315273, 48.867465836661204, 48.40310035433088, 50.45321151188442, 43.86343574523926, 43.79732363564627, 43.45888383047921, 44.98113686697823, 48.243305683135986, 44.301693371364046, 36.42470475605556, 34.20095116751534, 36.6028287751334, 36.395001207079204, 36.36348417827061, 33.681392669677734, 37.113827092306956, 37.552814279283794, 35.053526401519775, 35.67256920678275, 35.873125485011506, 36.01733534676688, 34.91593817302159, 35.50614595413208, 36.871473925454275, 35.60939965929304, 35.26116636821202, 36.032562323978965, 37.017278398786274, 38.44996568134853, 39.04884828839983, 42.64182778767177, 44.44197750091553, 45.80869858605521, 48.17678362982613, 46.764221804482595, 46.71071025303432, 40.76724549702236, 46.61229249409267, 46.289149148123606, 45.359914439065115, 48.90995407104492, 47.280799525124685, 49.25435890470232, 50.34159912381853, 49.8222838129316, 49.89541012900216, 50.81045314243862, 47.09398678370884, 46.42033461162022, 46.77342816761562, 38.58809239523751, 32.097512585776194, 15.610246794564382, 5.944739316190992, 9.038577164922442, 19.25912628855024, 14.256628274917603, 6.360553392342158, 0.4026947644140039, 1.4492073846714837, 34.85299791608538, 44.6413699558803, 39.88362223761422, 38.993891511644634, 47.95866577965872, 42.07081093106951, 6.272186636924744, 0.14933651951806887, 0.12492882779666356, 0.1983267885765859, 0.10211342706211976, 0.11751613127333776, 0.07798372435250453, 0.1817383308495794, 0.10257903100656611, 0.14034237499747956, 0.17353864227022442, 0.23044172887291225, 0.20959460894976342, 0.12629585872803414, 0.09998350563858237, 0.09160844968365771], [0.019787336433572427, 0.016057577017428618, 0.032282100790845494, 0.024264868581667542, 0.041886953969619105, 0.02097664716919618, 0.03372703093503203, 0.01442210066930524, 0.0367162389281605, 0.07228063073541437, 0.0679369888135365, 0.040525113831141164, 0.00545482147052618, 0.053045971252556355, 0.019024289878351346, 0.05048793833702803, 0.019822805155334727, 0.006480631983972022, 0.0569209252883281, 0.2396406281207289, 10.981046829904828, 41.32259069170271, 38.69389608928135, 44.83348069872175, 55.61433342524937, 61.10889938899449, 44.71014322553362, 38.98657853262765, 30.980409009116038, 1.0166483670473099, 0.6109799093433789, 4.515761068889073, 19.912369864327566, 15.666846820286342, 20.84285351208278, 27.22334258896964, 46.29883146286011, 45.917542116982595, 43.723981925419395, 46.773355211530415, 46.27791738510132, 42.50846058981759, 44.14863150460379, 45.001126834324424, 44.23135675702776, 41.09169857842581, 41.16081925800869, 40.15083258492606, 38.39720106124878, 38.21365744726998, 36.27791016442435, 34.72661018371582, 34.79882281167166, 31.799365384238108, 33.20920351573399, 30.912059579576763, 32.248688016619, 31.634435994284495, 33.33694267272949, 33.28001260757446, 33.76859951019287, 34.22736127035958, 37.2876467023577, 35.26487670625959, 34.932735443115234, 32.95029626573835, 32.64118480682373, 31.338428837912424, 33.98473712376186, 33.70467608315604, 34.330319677080425, 32.741346563611714, 33.073557308741975, 32.80419301986694, 33.462826660701204, 31.447202886853898, 33.24603591646467, 37.8982960837228, 45.77791459219796, 41.93380635125296, 40.882734979902, 44.318226609911235, 46.57194083077567, 43.48521055494036, 42.054788385118755, 40.18973207473755, 41.754862444741384, 44.0992819241115, 46.035664967128206, 40.86280754634312, 37.76921592439924, 44.978903021131245, 46.11858824321202, 46.38485016141619, 46.096565927777974, 45.94998673030308, 42.83276775905064, 48.21638141359602, 52.07443468911307, 33.336310386657715, 44.626556396484375, 45.089031968797954, 43.88314778464181, 33.85431248801095, 33.021153994968955, 33.13741820199149, 33.28343459538051, 32.76013796670096, 33.263378620147705, 33.64502579825265, 34.35683747700283, 32.603595052446636, 33.21278878620693, 32.476998874119346, 32.396976470947266, 33.118140425000874, 32.595371859414236, 33.04689359664917, 32.2325508253915, 31.685602528708323, 32.49480710710798, 33.961655208042686, 36.704025813511436, 39.08558341435024, 40.14757735388619, 40.116720403943745, 40.609663827078684, 43.10177074159895, 44.57395158495222, 41.640133789607454, 40.90696334838867, 38.8924686568124, 39.90471696853638, 44.58176483426775, 45.01800748280117, 46.46690491267613, 45.36751924242292, 44.16960116795131, 44.64304099764143, 44.72679110935756, 45.20096049989973, 43.654249804360525, 44.54129505157471, 37.01920999799456, 20.42504964556013, 7.097211394991193, 2.3582628965377808, 1.2883725464344025, 0.7904849914567811, 2.9060567021369934, 3.8721702780042375, 2.6154971505914415, 0.0709620336336749, 2.0274750122002194, 30.83615745816912, 35.05935594013759, 24.258021661213466, 19.850876569747925, 36.69422537939889, 24.563089268548147, 1.13869423525674, 0.08186587425214903, 0.006808645141843174, 0.009459866360495133, 0.029143326716231446, 0.05676540845472898, 0.03193789693926062, 0.0328480905986258, 0.0004158124616619066, 0.03823334823495575, 0.046225839361016235, 0.08277154208293983, 0.03443464457190462, 0.04917038957189236, 0.0007791309627853999, 0.010106752809536244, 0.025349087813603025, 0.02244404700052525, 0.08803550819201128, 0.007970342046714254, 0.029728159441479614, 0.017871004263205186, 0.032007270359567234, 0.020747478751997863, 0.019549715166379298, 0.07124222109892539, 0.07115166381533657, 0.018506130004035573, 0.04004462282838566, 0.01767481943326337, 0.028926164976188114, 0.058167156630328724, 0.0653954612623368, 0.027823920461482236, 0.04875921431396689, 0.3780203270060675, 14.682488577706472, 48.366855076381135, 44.75247859954834, 52.434240204947336, 60.189270564488, 61.52927235194615, 45.35120834623064, 43.8806985446385, 35.352208614349365, 1.6561352695737566, 0.7475208597523826, 5.1487232872418, 24.116054330553325, 20.23873543739319, 25.59721745763506, 30.398302827562603, 47.11042274747576, 46.85017796925136, 45.37735789162772, 48.710172516959055, 48.6969188281468, 43.25771263667515, 46.84798581259591, 47.80948100771223, 47.10722310202462, 42.53705937521798, 43.52349860327584, 40.994149344308035, 39.409362520490376, 39.63282353537423, 38.207171303885325, 36.185544286455425, 35.901859760284424, 33.999224117824006, 34.65894167763846, 34.17097316469465, 33.55280583245413, 32.8016916683742, 34.0201347214835, 34.30099480492728, 35.102233273642405, 34.46768208912441, 38.91916363579886, 35.763267517089844, 36.64294419969831, 34.65641253335135, 34.49158041817801, 33.77477298464094, 36.07177448272705, 34.06260905947004, 36.52711078098842, 34.16013397489275, 33.5101751599993, 34.21511854444231, 34.54802063533238, 32.7577269417899, 35.08914634159633, 40.45967653819493, 47.48700468880789, 42.80561072485787, 43.349779742104666, 45.05726133074079, 48.5056140763419, 45.00066130501883, 43.8415732383728, 41.206712109701975, 42.855137484414236, 45.654736927577424, 47.97698817934309, 43.526180607931956, 39.758919443402974, 45.89499173845564, 47.29232311248779, 46.64892339706421, 46.262391635349815, 45.8171580178397, 45.56576871871948, 42.7856068611145, 53.42903116771153, 38.529908180236816, 44.47291088104248, 45.285294260297505, 44.6651223727635, 34.7791976247515, 32.57227257319859, 34.187662737710134, 34.126907689230784, 33.870647702898296, 33.53206545966012, 34.21554238455636, 36.067181723458425, 34.518296241760254, 34.03864124843052, 33.62551525660923, 34.30166530609131, 34.81713478905814, 33.525315284729004, 34.895809241703574, 34.07665484292166, 33.06286403111049, 34.018147536686485, 35.80325787408011, 38.097855295453755, 40.13076271329607, 40.97896058218819, 42.80894933428083, 43.413432189396445, 45.19858769008091, 46.07364729472569, 42.95455578395298, 41.92418309620449, 40.770844663892476, 41.318025725228445, 46.143667766026084, 45.50017077582223, 48.02895723070417, 47.14180081231253, 46.129205090659006, 45.167873178209575, 45.55404710769653, 45.3421687398638, 44.501374176570344, 45.860344546181814, 40.43668842315674, 27.53027057647705, 11.619749563080923, 4.519821422440665, 1.6616709211042948, 2.9628944865294864, 1.9800793954304285, 2.9591598297868456, 2.392708156790052, 0.0782515692657658, 2.0907255496297563, 33.64813164302281, 40.02680376597813, 29.53046587535313, 25.762753077915736, 40.7504551751273, 30.869140556880406, 1.7659414517027991, 0.05394432447584612, 0.026013336277433803, 0.04869714532313602, 0.035888738331518004, 0.042114432834620984, 0.01463233626314572, 0.034912129664527516, 0.024023433947669606, 0.05301119972552572, 0.010661556967534125, 0.059546184060829024, 0.010923546123584467, 0.031811723352542946, 0.04220937345443027, 0.060723713732191494, 0.12222561213587012, 0.1127838244927781, 0.1743934606867177, 0.09523712604173593, 0.1298920807561704, 0.11088216903486423, 0.1524681214775358, 0.1377839179975646, 0.1314690639930112, 0.20546030865183898, 0.22546520376844065, 0.09196386632642575, 0.13263640206839356, 0.16725957420255455, 0.08192108664661646, 0.1395966378705842, 0.19597434837903294, 0.09457787498831749, 0.19706961246473448, 0.46615486059870037, 17.413108042308263, 54.452459130968364, 48.89701999936785, 55.313674449920654, 60.98257419041225, 64.76062938145229, 50.94452558244978, 48.421144826071604, 40.87250375747681, 2.2361559058938707, 1.7844640463590622, 11.288971015385219, 29.65365743637085, 27.565546580723353, 28.392489910125732, 33.5034944670541, 49.15050070626395, 46.68646451405117, 45.49853100095476, 51.45137929916382, 50.4875807762146, 43.24915245601109, 47.040968554360525, 48.373243944985525, 48.28645747048514, 44.96626772199358, 45.79979794366019, 44.978979451315745, 41.61877850123814, 41.343820912497385, 39.56387308665684, 40.049406255994526, 38.002380098615376, 35.52984973362514, 36.82547337668282, 34.159098693302695, 35.21497474397932, 34.951592854091096, 35.489136763981406, 36.63808046068464, 36.917203494480674, 36.26080369949341, 40.011184215545654, 37.26972382409232, 38.53701271329607, 36.66385480335781, 37.26647901535034, 33.99499961308071, 36.98110260282244, 36.97566911152431, 39.17000750132969, 35.46187898090908, 35.58927072797503, 36.16835444314139, 35.62205580302647, 36.740076541900635, 36.76066058022635, 43.55287906101772, 49.68950373785836, 45.48762232916695, 43.84052753448486, 46.09803547177996, 51.025729179382324, 48.34885229383196, 45.167803696223665, 45.36774505887713, 45.13344485419137, 47.560488837105886, 50.250317164829795, 46.13418000085013, 41.74894257954189, 45.6721247945513, 49.26472214290074, 47.82043831689017, 49.397359779902864, 46.19906575339181, 45.58964272907802, 43.06234666279384, 51.43205288478306, 42.315887791769846, 46.256714957101, 47.28495454788208, 46.53500073296683, 36.84709964479719, 36.14823940822056, 36.704797063555034, 36.49829660143171, 35.79940857206072, 35.385632923671174, 37.00060272216797, 37.905074051448274, 36.264274324689595, 36.00011076245989, 35.63151577540806, 35.70791121891567, 36.04126494271414, 34.573117528642925, 36.90051392146519, 34.83095475605556, 34.39023746762957, 34.79863521030971, 36.533569131578716, 39.50655392238072, 41.71769305637905, 42.28862306049892, 43.00394010543823, 44.314832414899556, 47.90441077096121, 46.96753304345267, 42.69464799336025, 43.25512095860073, 41.81438766207014, 41.9509162902832, 45.819072246551514, 45.65003994532994, 49.41534866605486, 47.776987757001606, 46.508833817073274, 44.338678632463726, 45.3061249596732, 45.87387268883841, 44.59063768386841, 45.89615208762032, 41.726829937526155, 31.415032727377756, 12.309171540396553, 3.7129023671150208, 3.9159947378294806, 8.48010093825204, 8.61117957319532, 10.390768698283605, 6.0153899022511075, 0.20548932280923637, 2.8375676572322845, 38.39730528422764, 44.61399057933262, 35.879100935799734, 30.322053296225413, 46.755199568612234, 35.55613129479544, 2.4518612112317766, 0.2774728094892842, 0.08537742189530816, 0.100112807271736, 0.08403489286346094, 0.11123388766178063, 0.11769074547503676, 0.10936255593385015, 0.06027835048735142, 0.14544577257973806, 0.10125752298959664, 0.15121148819369928, 0.0487240662000009, 0.1907548534550837, 0.14378653732793673, 0.24453951524836676], [0.048407722996281724, 0.038765665742435625, 0.04079007497057319, 0.01712099745470498, 0.01946516122136797, 0.057740453098501475, 0.035158617688076835, 0.07055555723075356, 0.034609462334109206, 0.0544025391739394, 0.07272785316620554, 0.06915077939629555, 0.02359505613068385, 0.05206576295729194, 0.036012150280709775, 0.03587013968665685, 0.03475744742900133, 0.05572027114353009, 0.05200326648939933, 0.04863382104252066, 3.997461063521249, 30.377458231789724, 43.6956193787711, 27.500890118735178, 29.552741800035747, 43.63049391337803, 36.08014358792986, 45.779352869306294, 32.20307656696865, 0.6519109872835023, 0.16175828368536063, 0.358612271291869, 11.431322234017507, 4.037728914192744, 9.508873803274971, 31.623040948595317, 40.24670730318342, 50.93926232201712, 45.73118448257446, 37.679848194122314, 39.98179333550589, 46.37347943442208, 42.724546091897146, 48.19329602377755, 44.75578246797834, 44.16058240618025, 41.78127949578421, 41.778632232121055, 41.05928175789969, 39.161221504211426, 35.925240448543, 36.675565992082866, 34.97070040021624, 34.49989741189139, 31.941501208714076, 34.1252818107605, 31.598850795200892, 32.10625689370291, 31.071972370147705, 33.43814665930611, 32.933439935956685, 34.64640365328108, 33.656695297786165, 34.20955303737095, 32.668491227286204, 32.195906026022776, 34.56718029294695, 33.286512647356304, 33.174643175942556, 35.05659055709839, 32.288181577410015, 33.990674359457834, 32.55879654203142, 32.70400694438389, 31.911901882716588, 31.726954732622417, 32.49499818256923, 36.369508266448975, 43.34857075554984, 44.0032890864781, 45.781701360430034, 44.50615453720093, 43.749269894191194, 43.63310991014753, 42.87443263190133, 39.00919839314052, 42.3214567729405, 42.915326254708425, 47.14652211325509, 41.846616881234304, 35.47264174052647, 42.46343278884888, 41.81469685690743, 43.919361795697895, 43.00481905255999, 42.94098942620413, 49.21454572677612, 46.3009854044233, 34.364980765751426, 41.07020085198538, 44.92382117680141, 45.92204107557024, 41.352259499686106, 34.549090657915386, 32.139625617435996, 33.4582964352199, 33.26204456601824, 33.13918651853289, 33.68793092455183, 32.80769838605608, 33.80399710791451, 32.47523055757795, 32.21973834718977, 32.100368295397075, 33.33088731765747, 33.63716043744768, 32.005063329424175, 34.18162822723389, 32.51870543616158, 33.34506859098162, 36.25978231430054, 40.25368676866804, 42.84481593540737, 41.745475428445, 42.52308654785156, 43.58418416976929, 43.89859710420881, 44.23174238204956, 41.361698627471924, 38.994391781943186, 40.82304300580706, 43.71484504427229, 46.289593832833425, 42.15740285600935, 43.9564790725708, 40.69344867978777, 43.1866568837847, 44.69096619742257, 44.58467265537807, 44.653077670506065, 44.99167728424072, 41.57694339752197, 43.76129027775356, 31.246663979121617, 13.141219190188817, 1.8193569225924355, 0.6061093849795205, 1.2586620492594582, 2.5538755314690724, 1.550878094775336, 1.8513403492314475, 2.4082834124565125, 0.07949283373142992, 1.9577355086803436, 29.245607103620255, 33.64762789862496, 37.873209612710134, 35.78608887536185, 36.76017420632498, 18.194992303848267, 0.4032490461000374, 0.062173722710992606, 0.0782057885080576, 0.06265808814870459, 0.053780356488589726, 0.07632279276315655, 0.0813218452302473, 0.020614865867953216, 0.07440146657505206, 0.059657029541475434, 0.08750950784555503, 0.03789221475433026, 0.04898927839738982, 0.03410227776372007, 0.010466573144575315, 0.054799322704119344, 0.08750750616725002, 0.008855361208718802, 0.026303749265415326, 0.026931992964819074, 0.06276092013078076, 0.03981481658826981, 0.09648027683475188, 0.05313888644533498, 0.0071670388570055366, 0.012216474245568472, 0.033254957159182856, 0.018806393624150326, 0.03495456524459379, 0.03730307672438877, 0.028706434981099198, 0.038769913371652365, 0.052611043876303096, 0.09353618802768843, 0.076464240173144, 0.07168845286858933, 6.4842265503747125, 38.56855753489903, 48.628270626068115, 33.38007708958217, 45.708752223423545, 53.33131865092686, 42.47375086375645, 47.807386125837056, 35.213015351976665, 0.8441674251641546, 0.0920623963964837, 1.248576630439077, 15.06729371207101, 8.464189563478742, 11.823602761541094, 33.835302216666086, 40.54064737047468, 50.71327911104475, 45.630598885672434, 41.585072789873394, 43.55851752417428, 45.639318874904085, 45.213105951036724, 48.254593031747, 46.832112652914866, 45.519181047167095, 42.70487226758684, 43.74440615517752, 42.89284883226667, 41.854548249925884, 38.32702425548008, 38.36769206183297, 36.33241530827114, 35.84696551731655, 33.90903650011335, 35.787235328129356, 34.86221122741699, 33.617997305733816, 33.27304356438773, 35.249614988054546, 35.406762395586284, 36.25323016302926, 34.568820067814414, 35.70044885362898, 34.99628019332886, 34.04159770693098, 35.65897158214024, 35.366785934993196, 34.425471782684326, 36.543671812329976, 34.46885633468628, 35.54866892950875, 34.60951566696167, 34.34834677832467, 33.52507209777832, 33.7952423776899, 34.57250261306763, 38.29921409061977, 45.41534716742379, 44.54342467444283, 45.863815171378, 45.87087801524571, 46.29542337145124, 47.20895515169416, 45.082087244306294, 41.23756905964443, 43.51021712166922, 44.13542992728097, 47.16474028996059, 44.72040571485247, 37.85122203826904, 42.222090584891184, 43.345252990722656, 44.877438477107454, 43.504241670881, 45.062708718436106, 45.637974398476736, 49.42774077824184, 39.12776592799595, 39.637930461338584, 46.359127930232454, 46.133387906210764, 44.73774494443621, 34.83907720020839, 34.21200227737427, 34.29456424713135, 34.86005728585379, 33.96718944822039, 34.89282846450806, 34.195569787706646, 35.17935480390276, 34.33788626534598, 33.78597695486886, 34.60750068937029, 35.05618061338152, 35.24825314113072, 34.839942250932964, 34.900843211582725, 34.50806501933506, 34.75599064145769, 38.59781639916556, 40.71724625996181, 43.56786632537842, 43.915283203125, 45.47319092069353, 44.9092230115618, 45.10311944144112, 46.19042566844395, 42.786603927612305, 39.12858581542969, 42.73101486478533, 43.10502944673811, 45.11360774721418, 43.15454230989729, 43.99653196334839, 41.665630204336985, 45.25728259767805, 45.4797500201634, 44.75938163484846, 44.320182527814595, 44.94980049133301, 42.97275659016201, 45.1252737726484, 34.29346990585327, 16.375290359769547, 2.4924838542938232, 1.135949696813311, 2.521115860768727, 0.7656626605561802, 1.8123973246131624, 0.7200814464262554, 1.3778156212397983, 0.08989679760166577, 2.2938383306775774, 34.72497040884835, 38.86686454500471, 38.77522127968924, 33.95815331595284, 43.81466286523001, 23.028840167181833, 0.7754628232547215, 0.04480080047090139, 0.007720800615581018, 0.11768132740897791, 0.041295776941946576, 0.0423070553557149, 0.020052124546574693, 0.07321422706757273, 0.057807560211845806, 0.05986871211124318, 0.10579929713691984, 0.08941007764743907, 0.06349298477705036, 0.022434506798163056, 0.03592038181211267, 0.036787006737930436, 0.1779626091676099, 0.1251115029943841, 0.17394817886607988, 0.12418743329388754, 0.1129839312551277, 0.06420453052435603, 0.18494793719479016, 0.12479031165795666, 0.10862316310937915, 0.12144981590764863, 0.08028069431228296, 0.12696511138762745, 0.10622019240898745, 0.12167223968676158, 0.10316151260797467, 0.13752462262553827, 0.15514989543173993, 0.23436637542077474, 0.13734354877046176, 0.11997694708406925, 6.790465363434382, 43.44335808072771, 55.841862610408235, 37.021033900124685, 40.68564932686942, 51.73849970953805, 43.887382711683, 53.89646775381905, 38.206347942352295, 1.0659772115094321, 0.6084041904125894, 2.257831245660782, 14.73950549534389, 7.909229125295367, 13.449483837400164, 38.93573161533901, 41.15500014168875, 51.48701660973685, 46.97881691796439, 42.93559414999825, 45.74385799680437, 46.705207279750276, 46.07317134312221, 50.257546765463694, 47.88437564032418, 48.19083636147635, 44.63885818208967, 45.32575709479195, 44.38853195735386, 43.46017272131783, 39.955129623413086, 40.68323482785906, 38.57312250137329, 37.795302936008994, 36.85442999431065, 37.665878840855186, 36.547013895852224, 35.488195283072336, 33.279164927346365, 36.54443958827427, 37.22843762806484, 37.5989225251334, 37.08257062094552, 39.015476090567454, 36.94227606909615, 35.66114984239851, 37.95875235966274, 36.46295806339809, 36.275651999882285, 39.457760197775706, 35.039067200251985, 37.454834256853374, 37.07331909452166, 35.12694106783186, 34.41433382034302, 35.17579732622419, 36.110614912850515, 40.16956492832729, 47.18255199704851, 46.29160533632551, 48.74427774974278, 48.02580969674246, 47.98951230730329, 47.731126172201975, 46.58303015572684, 43.27174799782889, 43.998234272003174, 47.629661628178184, 50.23018823351179, 45.656154360089985, 40.03214693069458, 42.90202740260533, 44.727923665727886, 44.385464327675955, 45.89921276909964, 45.34728608812605, 45.94486590794155, 46.28067234584263, 42.187721320560996, 42.22966412135533, 47.98575333186558, 48.167285442352295, 46.00866774150303, 38.043162550245015, 36.365433147975374, 36.21786035810198, 36.41488347734724, 36.358849729810444, 37.050806931086946, 35.5642328943525, 38.05712842941284, 36.40610442842756, 35.69073179789952, 36.18242801938738, 35.732712813786094, 36.27147265842983, 35.19268144880022, 36.87461103711809, 36.293446336473735, 36.5522597857884, 40.404580797467915, 44.203883579799104, 47.37492329733712, 46.91291325432913, 47.176448004586355, 47.76283427647182, 46.21210752214704, 47.324753829411094, 43.35228456769671, 40.27709524972098, 42.79673787525722, 43.41616630554199, 46.37351417541504, 42.59496913637434, 45.74922548021589, 42.84744235447475, 45.52566024235317, 46.58577469417027, 45.31540427889143, 44.15763636997768, 45.263949394226074, 42.28304018293108, 45.9263003213065, 37.38808291299002, 19.497637101582118, 3.289560569184167, 1.515262823019709, 3.639116406440735, 5.137746870517731, 8.004486322402954, 7.0627131547246655, 5.14056089094707, 0.1785107704677752, 2.27156240599496, 39.568285192762104, 42.96369613919939, 47.48864098957607, 45.330433232443674, 50.00466707774571, 27.434609515326365, 1.0130296583686556, 0.19557323918810912, 0.25056984594890047, 0.17362348628895624, 0.13471939601004124, 0.2496346618447985, 0.18560370057821274, 0.09244185353496245, 0.1887600283537592, 0.11565743386745453, 0.18825449262346539, 0.14488220853464945, 0.21048860597823346, 0.10299074569983141, 0.1199417853994029, 0.13557363088641847], [0.03654409798660448, 0.011391219599837703, 0.05691557843238115, 0.0402865307405591, 0.03606293523418052, 0.02735531739225345, 0.0448145475903792, 0.005909770718842212, 0.031441568929169855, 0.021571164285498004, 0.061082339845597744, 0.015151729374857885, 0.04674896611166852, 0.11411261319049767, 0.023154174609641944, 0.044510506226548126, 0.04363819856994918, 0.02465865129072751, 0.04543719846489174, 0.03959208407572337, 0.5659956431814602, 18.566033056804113, 45.15546716962542, 36.014726298195974, 19.366100754056657, 25.8749942779541, 36.768536363329204, 39.9597293308803, 34.74533210481916, 1.1754833183118274, 0.3258221750812871, 0.8020409313695771, 9.64501072679247, 1.111982754298619, 0.3706838163946356, 18.89402277129037, 37.584654399326865, 46.860367502485005, 46.326596464429585, 48.260943685259136, 47.12604577200753, 47.7199638911656, 45.24873283931187, 46.261064529418945, 44.739294392721995, 47.103815010615754, 44.4045649256025, 44.29843119212559, 41.790270464760916, 40.88015372412545, 37.2303101675851, 38.051625456128804, 35.755044324057444, 33.442676884787424, 33.449246406555176, 32.64663914271763, 31.99722228731428, 32.417883600507466, 32.47092267445156, 32.897542067936485, 33.30275753566197, 33.44889552252633, 33.524123668670654, 33.076600619724815, 33.432668004717144, 34.05709218978882, 33.91427196775164, 33.42699827466692, 33.17106485366821, 33.26103360312325, 32.676217624119346, 32.61844335283552, 32.642449378967285, 31.717182091304235, 32.19853244509016, 31.292066982814244, 33.54193537575858, 38.249412877219065, 41.6315666607448, 43.29713324138096, 42.69109746388027, 44.30578933443342, 45.824398040771484, 46.00309528623308, 46.59044735772269, 43.50541591644287, 42.26249783379691, 44.412649154663086, 45.831523418426514, 40.96643992832729, 36.83461025782994, 43.01507806777954, 43.66476590292794, 45.95553486687796, 44.63817031042916, 45.43565675190517, 40.68248094831194, 35.20188086373465, 44.68103722163609, 48.471439361572266, 43.77873720441546, 44.74822282791138, 39.29630838121687, 32.03519419261387, 31.4041587965829, 33.85549020767212, 32.405515807015554, 32.36609867640904, 34.24905007226126, 33.747720173427034, 33.855264391217915, 34.41712004797799, 31.388375963483536, 32.080524240221294, 31.426108155931743, 33.66226427895682, 32.1858172416687, 33.03248650687081, 31.887079443250382, 37.302967480250764, 38.76345450537545, 43.15782185963222, 43.73082937513079, 44.167481967381065, 44.4918030330113, 44.12233257293701, 41.61606870378767, 40.5230302129473, 38.85293688092913, 41.81328984669277, 45.02370153154646, 44.068345069885254, 42.35811199460711, 43.879715374537874, 44.144844736371724, 44.350254331316265, 43.221887724740164, 44.81609630584717, 43.1971104485648, 43.03734009606497, 42.90684250422886, 43.5275285584586, 39.40704182216099, 21.007164512361797, 5.675116641180856, 0.15200156079871313, 0.46815550753048485, 1.432259316955294, 0.2473260142973491, 0.6270938675318445, 0.5218027116996902, 1.536302619746753, 0.0402513894119433, 2.6531518271991184, 24.23347888674055, 30.80395950589861, 29.840960025787354, 27.581006322588237, 39.35048001153128, 14.590162651879446, 0.030786154991281883, 0.052198630291968584, 0.03498977781938655, 0.007623876977179731, 0.006638186543049025, 0.026320668536105325, 0.06406515264617545, 0.03979180407311235, 0.13679226620921067, 0.09747477847018413, 0.025790761524279202, 0.01831342266606433, 0.10352986212819815, 0.020213296969554255, 0.06542454327323607, 0.06887579629463808, 0.07032258223210062, 0.0696260796061584, 0.03807153459638357, 0.008859543528939997, 0.023290792546634163, 0.04583080645118441, 0.011253100404116725, 0.03564719682825463, 0.02598892937281302, 0.010916051704303494, 0.018344346899539232, 0.035297242392386706, 0.07451819495431014, 0.03126380293230925, 0.024438086697565656, 0.022239940274240713, 0.03781070912789021, 0.03823664252247129, 0.070266670946564, 0.06586582173726388, 1.0952063288007463, 23.614609786442347, 53.197635310036794, 35.08315699441092, 21.530405555452617, 37.63457373210362, 42.25244379043579, 45.507459436144146, 37.76831613268171, 1.0363893934658595, 0.1410823581474168, 0.9818648163761411, 15.36192512512207, 4.170037380286625, 0.6528211470161165, 26.462115321840557, 40.131151812417166, 49.237641538892476, 45.331315653664724, 47.85767371313912, 45.81762702124459, 47.689829553876606, 46.55065502439226, 48.37990379333496, 46.814523288181846, 48.11962080001831, 45.81338514600481, 46.44231871196202, 42.44344629560198, 42.90413965497698, 39.50044992991856, 39.22936596189226, 37.361023153577534, 36.45536715643746, 35.22611618041992, 35.482643672398154, 34.053795269557405, 35.351882049015586, 34.64267594473702, 34.685692242213655, 34.30107470921108, 34.50321865081787, 35.37464782169887, 34.69661133629935, 35.25037234170096, 34.78848736626761, 35.6932053565979, 35.459124020167756, 33.874813147953574, 35.537867954799104, 34.76453692572457, 33.63552761077881, 35.697659151894705, 33.567386627197266, 32.73288713182722, 33.77811854226248, 34.061368806021555, 38.93093041011265, 43.70240082059588, 44.70066588265555, 45.25713668550764, 45.20699153627668, 46.76884583064488, 48.75385236740112, 46.400094509124756, 44.40037516185215, 44.36746154512678, 46.81828921181815, 47.01602452141898, 43.08910764966692, 36.27151434762137, 42.13349757875715, 43.393442222050254, 48.806780270167756, 45.053471088409424, 45.17348037447248, 42.48045934949602, 38.84552662713187, 42.93843943732125, 47.89633696419852, 45.848167828151155, 46.61023235321045, 40.92030736378261, 34.447261333465576, 33.09294973100935, 34.55351666041783, 34.503468785967144, 33.44313199179513, 34.955716609954834, 35.24754095077515, 35.78783287320818, 34.88002988270351, 33.91755499158587, 33.723773206983296, 33.13480567932129, 36.09027753557478, 34.92005498068673, 34.79777710778372, 33.07768453870501, 37.62331765038626, 40.91333484649658, 44.17950929914202, 45.62994228090559, 45.327045985630576, 44.735247067042756, 45.15020043509347, 44.1592309815543, 41.44462537765503, 39.42696230752127, 42.1116281236921, 45.711746897016255, 44.279542514256065, 43.80038431712559, 45.45828356061663, 44.305956091199604, 43.695014885493684, 44.115742206573486, 44.82467038290841, 44.28583410808018, 44.84194360460554, 43.227206570761545, 43.57644387653896, 42.02343463897705, 26.30415323802403, 9.073008963039943, 0.5110524371266365, 1.2712968055691038, 1.4926667383738925, 1.5134771359818322, 0.1685552503913641, 0.26784103204097065, 0.42075440819774357, 0.08893461458917175, 3.1429016845566884, 30.036388533455984, 37.07855108806065, 35.53868089403425, 35.391764708927695, 43.97337361744472, 18.029248237609863, 0.14877565604235443, 0.04188872155334268, 0.019131591709862863, 0.0308531162195972, 0.02205569257161447, 0.043364962695964744, 0.014515511192647474, 0.043960689300937314, 0.0698656499651926, 0.019087646389380097, 0.03547383452366505, 0.03937814537701862, 0.034208271718983135, 0.03999802104330488, 0.0437813185687576, 0.04144239818145122, 0.14222967943974904, 0.11048211835856948, 0.15211484900542668, 0.13702763643647942, 0.08141589696918215, 0.1507142170199326, 0.07182194784815822, 0.10021798019962651, 0.07531986372279269, 0.05975887764777456, 0.08168212696909904, 0.10573769294257675, 0.17537589796951839, 0.1542397356991257, 0.08740445705396788, 0.08513648089553628, 0.12518036072807653, 0.1617402889366661, 0.08786328243357794, 0.13861074005918844, 1.1058111254658018, 29.495109966823033, 57.988258429935996, 42.98737907409668, 29.15786177771432, 36.17036942073277, 47.965537548065186, 47.16182552065168, 42.479809692927766, 1.3210611066647937, 0.5981306816850389, 4.670678973197937, 17.908964497702463, 3.582144869225366, 0.636229120194912, 28.007578815732682, 43.48708656855992, 47.59849200929914, 45.28768444061279, 48.93715974262783, 47.979951586042134, 49.559363978249685, 47.31909104755947, 48.93586042949131, 48.466242109026226, 50.53857707977295, 46.885995932987754, 47.629748480660574, 44.86724199567522, 45.58517503738403, 41.10852711541312, 42.73829657690865, 39.91139766148159, 37.69227157320295, 38.54090370450701, 37.11535569599697, 34.877750873565674, 37.24892439161028, 36.516907351357595, 36.90062856674194, 36.38784108843122, 37.13528312955584, 37.148272786821636, 36.67453071049282, 36.928671496255056, 36.78021975925991, 37.04359817504883, 38.42165524618966, 35.65150574275425, 36.97558920724051, 36.082745688302175, 35.04799563544137, 37.2262350491115, 35.65255144664219, 34.80193213054112, 36.040365150996614, 37.02145079204014, 40.31843703133719, 44.3099547794887, 46.84525169645037, 46.365318775177, 48.18483311789376, 48.973860127585276, 50.37122624261038, 48.48499182292393, 45.83491761343819, 45.6344655581883, 49.31942183630807, 49.092445032937185, 45.06485571180071, 40.60502937861851, 43.53116594042097, 45.39572892870222, 49.58306428364345, 46.783027103969026, 47.98081316266741, 45.408235686165945, 44.376219749450684, 46.480391366141184, 51.295659746442524, 47.211063929966514, 49.62274891989571, 43.22865874426705, 34.833727087293354, 35.78114870616368, 36.74078525815691, 35.89129849842617, 34.48301328931536, 38.14765650885445, 36.56927245003836, 38.37179497310093, 37.33826085499355, 35.524742807660786, 35.09198815482003, 33.77835478101458, 37.41780730656215, 35.70457260949271, 35.72206122534615, 34.154905455453054, 40.1560263633728, 42.60060065133231, 45.767064980098176, 48.17499099458967, 47.165713037763325, 46.53787728718349, 46.32996981484549, 43.81749078205654, 43.65171371187483, 41.530116013118196, 41.94844967978341, 45.82191058567592, 45.19760799407959, 44.58970662525722, 45.580929688044954, 46.18891790934971, 45.04493522644043, 44.9302065713065, 47.00344828196934, 45.81448296138218, 44.702052048274446, 43.588505949292866, 45.16228682654244, 44.81493943078177, 29.039976903370448, 10.22946366242, 0.8960035379443849, 1.3202898566211974, 4.671397243227277, 4.46553384406226, 1.6771961280277796, 3.4317713039261952, 5.852718242577144, 0.15623975837869303, 4.187817386218479, 31.902494021824428, 41.744898727961946, 39.333522932870046, 39.62068850653512, 49.55620949608939, 21.49471092224121, 0.27098408767155235, 0.1393917610070535, 0.12725580936031683, 0.08515988356832947, 0.126438812485763, 0.10786789935082197, 0.1525780577212572, 0.13118288506354603, 0.18120448663830757, 0.18976853495197638, 0.11721606951739107, 0.12919259257614613, 0.10702640736209494, 0.22524989103632315, 0.16401220059820584, 0.21670516739998544], [0.023588934048478092, 0.06938470434397459, 0.05871145028088774, 0.013860476386201168, 0.04688247126926269, 0.01022476701265467, 0.050153685201491625, 0.033340544173760076, 0.054697718870426924, 0.019296799719865834, 0.030418612927730595, 0.06184257726584162, 0.06689042318612337, 0.04160199301051242, 0.03259133294756923, 0.04448787369100111, 0.004760848083865962, 0.023596854248483266, 0.019267107027449777, 0.02894682976018105, 0.02998350913237248, 6.718577563762665, 41.7498562676566, 40.94795077187674, 35.332621642521445, 18.671235731669835, 30.718038082122803, 37.454775197165354, 41.94396461759295, 4.706720147814069, 0.08140932196485144, 0.5177098970328058, 4.720223971775599, 2.5494004573140825, 0.14044465736619063, 2.708417147397995, 17.96804503032139, 44.74398790087019, 45.97709860120501, 45.66438797542027, 46.27341495241438, 46.612320286887034, 44.87598630360195, 45.1463302884783, 44.99958780833653, 46.67578860691616, 45.69714873177664, 45.13856220245361, 42.80410296576363, 42.21010841642107, 38.488941601344514, 36.3774813243321, 36.3024685723441, 34.20726013183594, 34.10993324007307, 32.53046873637608, 32.91050393240792, 31.679821627480642, 31.45067698614938, 32.77042130061558, 33.96662317003523, 33.93980312347412, 34.28649391446795, 32.63905865805489, 34.40551308223179, 33.82624176570347, 32.42428636550903, 33.877568108694895, 34.297718729291645, 33.15453856331961, 33.0168912751334, 33.121656213487896, 33.67556660515921, 33.124880177634104, 32.787413120269775, 32.16402074268886, 33.15966285978045, 36.87126547949654, 41.480585779462544, 42.06987639835903, 42.93327692576817, 44.90001317432949, 45.50353717803955, 44.604638304029194, 46.238243171146934, 44.54366091319493, 44.80189766202654, 43.40898881639753, 46.236763204847065, 39.142843518938335, 37.7194425037929, 47.36769717080252, 45.049184049878804, 46.709143434252056, 43.74835968017578, 42.86690425872803, 40.375912530081614, 47.86573709760393, 45.63752623966762, 43.71240275246756, 43.056878430502756, 42.92130865369524, 35.36142192568098, 33.31904411315918, 31.748448984963552, 32.435153348105295, 32.85257332665579, 31.192735535757883, 33.61937304905483, 32.82946014404297, 32.64114659173148, 33.87869719096592, 31.53199175425938, 31.9742237499782, 33.35697085516793, 32.150617667606895, 32.774798665727886, 32.36469166619437, 31.021993977682932, 35.158451148441856, 39.81471695218767, 41.687239101954866, 43.05714593614851, 41.11250148500715, 41.40196343830654, 39.86152696609497, 41.16036415100098, 42.260653087071006, 43.448881898607524, 44.568903718675884, 43.02415936333792, 41.66271890912737, 44.25279542378017, 43.208991868155344, 45.115633147103445, 42.5165239742824, 44.87964105606079, 42.15092018672398, 41.24298865454537, 42.14149842943464, 43.75399119513375, 38.43850810187203, 32.703673430851524, 11.711493577275958, 1.368165767618588, 0.2696512277637209, 2.1548172533512115, 0.8374936261347362, 0.9372797459363937, 0.17487530197416032, 0.3250696254628045, 0.22436423998858246, 0.049788168564971, 3.605756367955889, 23.054816007614136, 31.437437193734304, 34.95577914374215, 25.12451934814453, 34.58622530528477, 7.123393075806754, 0.1333471539297274, 0.08212088806820766, 0.014639659352334482, 0.048626452152218134, 0.052236136315124373, 0.034736952278763056, 0.007921842059918811, 0.03739206659208451, 0.05878954287618399, 0.03080295891101871, 0.06798226745533091, 0.08801640064588614, 0.024996804306283593, 0.04651406407356262, 0.03783736876877291, 0.02124581183306873, 0.05698450401957546, 0.07017215780381646, 0.08657237634594951, 0.07706141205770628, 0.018778531279947077, 0.016647354566625187, 0.038036539152796776, 0.03933778272143432, 0.06126416687454496, 0.054426633952451606, 0.011947533498252077, 0.09622898139059544, 0.03944030257740191, 0.035591716412454844, 0.03607082998912249, 0.044336132904780765, 0.03731492055313928, 0.012879799053605114, 0.044599553769720454, 0.052336861445967636, 0.06441287470183202, 9.667363950184413, 47.66435398374285, 46.026583671569824, 32.910278115953716, 24.9123352595738, 41.11186572483608, 41.280310903276714, 44.04205656051636, 3.9299975293023244, 0.02825292931603534, 0.6791381548557962, 8.793663586888995, 3.8250871130398343, 0.43228355954800335, 4.238840614046369, 24.74037081854684, 46.28868014471871, 47.00396939686367, 45.573884214673726, 47.621636458805625, 46.45249087469918, 46.71113061904907, 45.605661800929475, 47.61137744358608, 48.58766882760184, 46.77186482293265, 45.275226320539204, 44.90064198630196, 42.39248473303658, 41.53886726924351, 39.10771690096174, 38.66955654961722, 35.02443081992013, 35.845822538648335, 35.01754168101719, 34.97498743874686, 33.99948467527117, 34.81142684391567, 34.794195311410085, 34.51483951296125, 34.64332907540457, 35.987211431775776, 34.21356214795794, 35.28482151031494, 35.45946795599801, 34.01219640459333, 35.898132051740376, 36.5928372655596, 34.28579562050955, 34.74494995389666, 34.284228801727295, 35.20754711968558, 34.91761268888201, 35.55832345145089, 34.381006785801475, 34.36648505074637, 38.3831205368042, 42.753975187029155, 43.25326926367623, 44.91502128328596, 46.327840191977366, 47.43263503483364, 46.74966880253383, 46.708636215754915, 46.99620825903756, 45.82152496065412, 46.41692999431065, 46.53622014181954, 43.198590414864675, 39.19352715356009, 47.82360669544765, 46.039302349090576, 46.7821273122515, 45.671391759599956, 45.800440652029856, 41.55927412850516, 47.34183597564697, 47.72057185854231, 45.49939257758004, 46.08453164781843, 44.66488265991211, 37.434503827776226, 34.292820249285015, 33.2775216783796, 33.56126526423863, 33.593702929360525, 32.44448825291225, 34.756164346422466, 34.986090660095215, 33.91700955799648, 35.19619376318795, 33.02777215412685, 33.62197514942714, 33.82835749217442, 33.505294050489155, 34.74302182878767, 33.203061308179585, 32.587895597730366, 37.029309204646516, 42.062257698604036, 43.530346052987234, 43.22936051232474, 41.87526082992554, 42.36078357696533, 41.748258181980674, 40.357749938964844, 41.17373595918928, 44.62382228033883, 44.84360422406878, 45.21966505050659, 43.01320552825928, 45.27391658510481, 44.84531348092215, 46.91168689727783, 43.75533219746181, 45.87736068453108, 43.90831763403756, 41.92269270760672, 43.069774287087576, 45.31748179027012, 42.1645108631679, 36.53952373777117, 15.172381741659981, 2.3496204231466566, 0.8573573316846574, 0.8260733932256699, 1.5012587287596293, 0.6003479712775776, 0.04953602495204125, 0.21230281862829412, 0.32763649629695074, 0.008169526001438498, 3.7570894360542297, 27.823814596448624, 34.04398441314697, 35.95126492636544, 29.063651153019496, 40.54495177950178, 9.966288481439863, 0.11552807795149939, 0.03240244236907788, 0.010775132703461816, 0.055409379968685765, 0.05691652498873217, 0.05426660146830337, 0.05527508771046996, 0.032600900291332176, 0.05546722847170063, 0.02368591875503106, 0.017410753960055963, 0.033878418883042674, 0.023361947121364728, 0.033443471150738854, 0.0033388937715374467, 0.021858773227514963, 0.15531745286924498, 0.21416423017425196, 0.17039531522563525, 0.190177460866315, 0.2553507765488965, 0.08931227360985108, 0.21438338341457502, 0.09966834647847073, 0.17881959889616283, 0.09981941551502262, 0.06672597343900374, 0.1416640662189041, 0.21648287932787622, 0.22132761936102593, 0.12267868353852204, 0.14771826778139385, 0.15794917808047362, 0.14884794716324123, 0.13678307884505816, 0.17959814997656004, 0.1348632454339947, 9.608767185892377, 57.13980695179531, 51.00782019751412, 44.62943295070103, 27.361071518489293, 41.18993221010481, 46.390839508601594, 50.1584689276559, 5.948601646082742, 0.14954537259680883, 1.5692374067647117, 9.118969559669495, 5.121635300772531, 0.3193871932370322, 4.3781611153057645, 24.86522647312709, 50.30935600825718, 45.74304505756923, 45.121233395167756, 47.23086282185146, 49.50033208302089, 48.16501685551235, 49.13259867259434, 48.364576067243306, 50.407655647822786, 47.598287037440706, 47.439117704119, 45.80731242043631, 46.16311577388218, 42.777831826891216, 40.88054282324654, 39.59444863455636, 37.030757904052734, 38.18940823418753, 36.712721484048025, 36.288172653743196, 36.093824590955464, 35.464116300855366, 37.10006965909685, 37.04856613704136, 36.88874019895281, 38.73815611430577, 36.30284030096871, 37.11039120810372, 38.490709917885916, 34.39726209640503, 37.71785831451416, 38.45739677974156, 37.02470602308001, 36.16025284358433, 35.806520053318565, 36.68624537331717, 36.21081835883004, 37.38646050861904, 35.055385044642854, 35.77728203364781, 41.36114624568394, 45.59946400778634, 45.52345071520124, 46.67806761605399, 47.837249483381, 49.883455753326416, 48.08141960416521, 48.610656942640034, 47.446298667362754, 47.26566982269287, 48.56226621355329, 47.266812801361084, 44.846303599221365, 41.21444545473371, 49.09270906448364, 48.71048518589565, 49.49604851858956, 46.96500389916556, 48.3463578905378, 44.92015600204468, 50.17505080359322, 48.97244616917202, 47.55747331891741, 47.240708419254844, 45.734547410692485, 38.0885203906468, 36.28130783353533, 34.02585308892386, 34.42717409133911, 34.989210401262554, 34.75449330466134, 35.80694736753191, 37.18613004684448, 34.35477386202131, 37.65412596293858, 35.040748664310996, 34.31312983376639, 37.31507819039481, 34.547617639814106, 35.350176266261506, 34.81905944006783, 34.243547098977224, 38.675615378788535, 44.05561249596732, 45.01458896909441, 45.00353438513619, 42.62938356399536, 43.6967762538365, 41.76859555925642, 41.615662234170095, 42.02368824822562, 42.64142826625279, 45.191823618752615, 45.48914398465838, 42.696239130837576, 47.126427922930034, 46.745416504996165, 48.86225816181728, 45.840493542807444, 48.62675244467599, 45.16457625797817, 45.0999093736921, 46.882438455309185, 46.795513016836985, 42.9923539842878, 38.56130361557007, 16.73010359491621, 4.874665490218571, 2.191584731851305, 5.154303124972752, 7.151974490710667, 1.980671729360308, 0.4529320587004934, 0.8566080118928636, 1.246266788669995, 0.10945266538432666, 4.946007422038487, 33.663428102220806, 40.646093232291086, 40.5742940221514, 35.42813852855137, 47.0216942514692, 11.891623888696943, 0.25968001995767864, 0.13266492768057755, 0.13243038526603154, 0.22046452281730516, 0.1767843466784273, 0.13530559598335198, 0.15425402564661844, 0.15254042616912297, 0.1166049265967948, 0.08238176442682743, 0.15824507363140583, 0.19856186024844646, 0.11012761095272643, 0.08994845447263547, 0.18622751853295735, 0.13051649582173142], [0.1035632664071662, 0.003525519527361861, 0.03271612910819905, 0.008670464656980974, 0.03529077595365899, 0.025013067094343047, 0.040103933574365716, 0.060107468228254995, 0.029357122922582284, 0.049503842036106756, 0.037223691519881995, 0.028615317906119993, 0.02457685728690454, 0.019027819956785867, 0.0347980272157916, 0.06992272833096129, 0.011423661207248057, 0.04655690677464008, 0.03811871652890529, 0.032884653458105664, 0.029002167683626925, 0.6803252654416221, 15.20016758782523, 40.838134493146626, 34.41931567873274, 25.802861554282053, 31.839532920292445, 28.13961022240775, 40.69466461454119, 10.22612852709634, 0.10481782337384564, 0.4246809275022575, 3.74292596748897, 3.552044838666916, 0.31259630620479584, 0.39773532482130186, 5.523946421486991, 30.246602807726177, 48.702692781175884, 48.21128838402884, 47.17114652906145, 48.80878482546125, 43.95347397668021, 44.37311390468052, 45.57374177660261, 46.193389075142996, 44.90557173320225, 46.95969894954136, 42.76993172509329, 41.28037691116333, 40.075145857674734, 37.01039620808193, 35.07717112132481, 36.34209067480904, 34.60691009249006, 33.72351264953613, 32.322422300066265, 32.90049852643694, 32.69192055293492, 35.30865730558123, 33.17963545663016, 32.99511562074934, 34.26246356964111, 34.084478514535085, 32.523510115487234, 33.12400123051235, 34.09349380220686, 34.924717221941265, 34.159710134778706, 33.66825015204293, 30.490237917218888, 32.18402113233294, 34.55366604668753, 34.268588406699045, 34.69492639814104, 33.203405244009836, 32.6076215335301, 36.57073851994106, 38.470351696014404, 40.620899064200266, 42.55645179748535, 43.41429724012102, 44.88767664773123, 46.39115912573678, 46.98658847808838, 44.53643478666033, 44.86959743499756, 44.44270011356899, 43.7901530947004, 40.17780201775687, 36.32776696341378, 45.94292736053467, 44.04854270390102, 44.450155530657085, 42.238331999097554, 42.022048473358154, 43.624442032405305, 42.01190062931606, 43.29938098362514, 43.1862747328622, 40.424424852643696, 35.696537017822266, 32.7389702796936, 32.88641800199236, 30.694514955793107, 31.906614303588867, 30.803726741245814, 32.95661565235683, 31.392072405133927, 32.00592838014875, 31.554107870374406, 33.58737659454346, 32.189103739602224, 32.80496079581124, 32.884972776685444, 33.877060890197754, 32.822623116629465, 33.05744096211025, 32.316481590270996, 33.596728869846885, 38.49619552067348, 41.18568338666643, 42.99736016137259, 43.323873383658274, 40.799613680158345, 43.077716078077046, 42.541884899139404, 43.167368684496196, 41.25616243907383, 41.361663886478965, 42.98200811658587, 45.08084004265921, 42.72564043317522, 43.50132690157209, 43.78821454729353, 44.41569593974522, 42.97743272781372, 42.69223696844918, 42.11077002116612, 40.732435022081646, 42.53896318163191, 37.505754130227224, 25.30924936703273, 4.890446152005877, 0.26781443346823963, 1.3770048533167158, 1.463494292327336, 0.329338044992515, 0.21610748661415918, 0.06748061294534377, 0.16115117126277514, 0.16295637296778814, 0.04184296454436012, 4.733465066977909, 30.467736176082067, 27.3538019657135, 49.82429879052298, 39.32911082676479, 28.12579025541033, 3.1881301147597174, 0.15694687329232693, 0.026081069339332835, 0.09062698270593371, 0.12472579654838357, 0.00735654350968876, 0.03944049256720713, 0.017118631063827446, 0.03246625858758177, 0.033494425737964253, 0.025763363976563727, 0.016519482946023345, 0.04924979852512479, 0.030244477093219757, 0.048959039484283755, 0.024241053698850528, 0.058550189648355754, 0.03547138161957264, 0.03708711599132844, 0.013210721430368721, 0.009809995519130357, 0.0747119506288852, 0.04847103709887181, 0.03537049703299999, 0.02296466826062117, 0.041479951702058315, 0.043272142498088736, 0.060768483472721915, 0.10217435272144419, 0.01038439492029803, 0.03197587115157928, 0.007428130650493715, 0.008309660446164864, 0.029641588551125357, 0.00561472842569596, 0.011129963261607503, 0.04531690777678575, 0.016172514064237475, 0.7503202238253185, 25.330324990408762, 48.059709957667756, 38.969635350363596, 20.548147405896867, 34.12022352218628, 36.49797351019723, 44.02517591203962, 10.950083919933864, 0.032158146013638804, 0.5032578610948154, 5.2987770182745795, 5.117211903844561, 1.1270229986735751, 0.9932541080883571, 7.0703427110399515, 36.15398209435599, 48.24694306509835, 47.81038079942976, 46.9918725831168, 48.914717061179026, 44.54942096982683, 46.82925694329398, 46.14755180903843, 48.80613061359951, 46.21876389639718, 47.61413240432739, 44.41261788776943, 43.97964089257376, 40.77329737799508, 39.243071283612935, 36.811302525656565, 37.14083821432931, 35.70167868477957, 35.62802083151681, 33.96752643585205, 34.894284112112864, 34.10569483893258, 37.07730736051287, 36.10818304334368, 34.57708147593907, 36.29680231639317, 36.60714708055769, 34.73857498168945, 34.55773769106184, 34.29387290137154, 37.563740321568076, 35.72687632696969, 35.24410159247262, 34.362159797123496, 34.677753925323486, 35.161352021353586, 35.86799771445138, 35.471359797886436, 33.43594408035278, 33.79886586325509, 38.1327908379691, 40.158857754298616, 42.546008655003135, 43.08132914134434, 46.39896890095302, 47.00994832175118, 47.200982093811035, 46.71369103022984, 46.75203466415405, 46.237096718379426, 45.787395409175325, 43.81811611992972, 41.482274191720144, 38.30739212036133, 47.488620144980295, 46.747671195438926, 45.92705767495291, 44.48343392780849, 43.46845497403826, 45.387637751443044, 45.42280605861119, 44.23959732055664, 45.55849395479475, 42.52295453207833, 37.43514653614589, 33.6847243309021, 34.69415862219674, 32.9729300226484, 34.01077202388218, 33.55311155319214, 35.766939640045166, 34.04575620378767, 33.38646248408726, 34.13767392294747, 35.42710672106062, 33.211121218545095, 34.549090657915386, 33.92397165298462, 35.90415961401803, 33.31974935531616, 34.234337261744905, 34.02529375893729, 35.977511746542795, 40.518406186785015, 42.48915849413191, 44.32190915516445, 44.60552767344883, 42.0771198953901, 44.04391172954014, 42.82435696465628, 42.25798497881208, 42.03517362049648, 42.26093101501465, 44.76331084115164, 45.07050807135445, 45.072877407073975, 45.12732349123274, 44.52801704406738, 45.99644238608224, 45.0587135042463, 44.57138422557286, 45.06532818930489, 42.35943562643868, 43.43033715656826, 40.87145457948957, 26.988111325672694, 6.779058592660086, 0.711797510938985, 1.3949939565999168, 2.005812917436872, 0.7899867839046887, 0.10895459353923798, 0.12546846669699463, 0.09487490369273083, 0.0845543182055865, 0.0826259148972375, 4.3668255635670254, 32.3357697895595, 31.48609890256609, 51.701677731105256, 40.40318768365042, 33.733761242457796, 4.425100105149405, 0.10919202651296343, 0.013180085574276745, 0.02138450608721801, 0.07127753206129585, 0.06930198413985116, 0.02299778246586876, 0.03377146480072822, 0.053108586464077234, 0.016952613900814737, 0.03947063987808568, 0.007497416709416679, 0.007029015504355941, 0.017756476033745066, 0.05221292023946132, 0.023297418441091265, 0.021927130541631153, 0.31216318373169216, 0.18236433368708405, 0.07168678367244345, 0.07578157287623201, 0.1134078460080283, 0.13589787563042982, 0.08118319338453667, 0.18267378636768886, 0.1083533436592136, 0.1136618759483099, 0.15803111796932562, 0.2068053957607065, 0.09324812277087144, 0.05888294322150094, 0.13284024755869592, 0.13991780206561089, 0.06951224857142993, 0.1706049825463976, 0.0996505960023829, 0.13622072259230272, 0.09447831354503121, 1.078951126762799, 28.32997349330357, 57.262418338230674, 45.96476902280535, 34.58639901024954, 42.22785758972168, 37.02551896231515, 49.30394124984741, 12.560100521360125, 0.2300848737359047, 1.9522781329495567, 10.05523063455309, 10.679666110447474, 2.60113240139825, 1.0024216047355106, 8.822826044900076, 38.523536682128906, 49.314707483564106, 49.56108365740095, 48.01834038325718, 47.65506076812744, 44.22953980309622, 47.0489033971514, 47.61524411610195, 50.46686472211565, 46.6336338860648, 50.31352492741176, 47.0941743850708, 45.64916794640677, 42.47229869025094, 41.25281688145229, 38.76197106497628, 39.935997758592876, 38.86363363265991, 36.802262919289724, 36.15667799540928, 36.99293538502285, 35.59326246806553, 39.27590847015381, 37.79978799819946, 35.16150140762329, 38.49476071766445, 37.639374937329976, 36.267522607530864, 35.58103016444615, 36.95896564211164, 38.143379892621724, 37.90874964850289, 36.99518312726702, 34.10008416857038, 36.14038099561419, 38.453467573438374, 37.593718324388774, 37.02943079812186, 36.505880560193745, 35.51656477791922, 41.253463063921245, 41.812900747571675, 44.49183777400425, 45.55144500732422, 47.167495250701904, 48.24059588568551, 49.171182019369944, 49.339168616703574, 48.84696517671858, 48.06626558303833, 49.490212031773154, 44.272153105054585, 42.92768710000174, 42.43661969048636, 50.39006280899048, 47.61492102486746, 48.276069913591655, 46.70018720626831, 45.11591107504708, 45.573067801339285, 46.35873883111136, 45.96802772794451, 46.42323201043265, 45.45735250200544, 38.621464593069895, 34.737984384809224, 35.256139346531455, 34.1358083316258, 36.063724994659424, 34.03659847804478, 36.862806047712056, 34.5960431098938, 33.21595369066511, 35.47417034421648, 37.343263557979036, 35.106527260371614, 36.131487301417756, 36.909428460257395, 37.554891790662495, 35.93024662562779, 35.91113560540335, 34.63580765042986, 38.016450200762065, 41.74897037233625, 44.070756094796316, 47.219005720955984, 46.55920478275844, 43.111946378435405, 44.868770599365234, 43.5115442276001, 43.97719860076904, 43.58014726638794, 42.96438748495919, 44.82624067578997, 45.9146968296596, 46.98897171020508, 45.758268560682026, 45.903333050864084, 47.42854949406215, 45.85978521619524, 45.24621411732265, 46.38634055001395, 42.64867523738316, 45.51681171144758, 39.937779971531455, 28.990663800920757, 7.461858068193708, 1.2237300894090106, 4.4628900544984, 5.195861603532519, 2.9643698930740356, 0.69024501315185, 0.3782096111348697, 0.4302366908107485, 0.43578862718173433, 0.26086441640342983, 7.055393661771502, 41.59189592088972, 36.059385844639365, 54.90034348624093, 48.73200028283255, 38.98756865092686, 5.091822751930781, 0.19968411645718984, 0.0922359927956547, 0.1982432473450899, 0.18078422918915749, 0.13273434181298527, 0.10682317255330936, 0.12383269518613815, 0.14163969324103423, 0.07749585088874612, 0.09404815626995904, 0.10000317636877298, 0.1028302585972207, 0.048831488471478224, 0.13552194008869783, 0.08465996610799006, 0.07869906311056443], [0.03169068966859153, 0.012092382913189275, 0.03137898764439991, 0.03737437379147325, 0.042749165025140555, 0.08759144773440701, 0.0377752726365413, 0.042621559729533534, 0.05323128934417452, 0.03907595641378846, 0.013776841007971337, 0.04794431411262069, 0.04393768357113004, 0.042942713746534925, 0.09178581873753242, 0.05157373685921941, 0.05414454998182399, 0.022229448426514864, 0.03275379119440913, 0.06001257510589702, 0.08794202642249209, 0.13427118291812284, 5.216730952262878, 28.72483961922782, 39.33669131142752, 28.129920959472656, 29.283954211643763, 26.3805730002267, 36.56257438659668, 10.289522153990609, 0.03213682644335287, 0.21842381517801965, 4.664442530700138, 3.99712016752788, 0.7637576056378228, 0.7645452490874699, 1.328134264264788, 15.821388653346471, 40.3610885483878, 48.15838132585798, 48.65726893288748, 46.384224823543, 47.26844910212925, 44.5369941166469, 44.265635694776265, 45.27883243560791, 48.245834827423096, 45.459575925554546, 44.21999645233154, 43.02622645241873, 43.33755438668387, 41.63462039402553, 38.98754780633109, 40.201116698128835, 40.90907907485962, 36.98578568867275, 37.85453980309622, 37.642459937504356, 35.05933856964111, 34.840664863586426, 34.34846142360142, 34.79515763691494, 33.58937767573765, 32.87952191489083, 32.56009932926723, 33.14311919893537, 36.10188102722168, 34.17787272589547, 32.07865170070103, 33.48099272591727, 33.61033691678728, 34.78481871741158, 33.7563533101763, 33.15179402487618, 31.94763994216919, 32.340647424970356, 34.19690384183611, 35.78425455093384, 38.45683397565569, 38.60310050419399, 40.77828965868269, 44.002573422023225, 45.67037384850638, 46.20347091129848, 44.873582226889475, 44.06582287379673, 43.60079383850098, 42.85392502376011, 42.26218169076102, 39.06001056943621, 39.13428681237357, 46.72844205583845, 42.814000674656455, 43.16845260347639, 39.69598960876465, 39.56185463496617, 37.31850017820086, 39.17778948375157, 36.86928176879883, 35.70782784053257, 32.71371357781546, 32.123488426208496, 32.204830987112864, 32.184927872249055, 32.54122454779488, 32.20811401094709, 31.913923808506556, 31.149382250649587, 31.95111404146467, 32.720988341740195, 32.54165186200823, 31.513950756617955, 32.2208639553615, 32.76897954940796, 33.63426651273455, 35.208342688424246, 36.970586504255024, 32.976383277348106, 31.499178886413574, 31.09459570475987, 34.36941024235317, 36.26576471328735, 39.92633628845215, 41.7478551864624, 43.61002452032906, 45.19775390625, 42.083626883370535, 41.946313108716694, 42.886814321790425, 41.043276582445415, 39.30388191768101, 43.51978479112898, 42.46870994567871, 43.31604623794556, 41.73230511801583, 40.88607358932495, 42.20030798230852, 44.46417352131435, 41.20127167020525, 43.07209498541695, 42.54786729812622, 33.3908884865897, 11.0304502589362, 0.41875617685062544, 0.058061271240668635, 0.08632488748324768, 0.3328745966511113, 0.15788905987782137, 0.0886673057185752, 0.04923075543982642, 0.05289491578670485, 0.08162871947778122, 0.13394224271178246, 6.681818553379603, 28.682415655681066, 24.784191370010376, 38.96422617776053, 45.489811011723106, 14.995195729391915, 0.22210279133703026, 0.009665654157288373, 0.031029603177947656, 0.03956076629193766, 0.04743723471515945, 0.04183644721550601, 0.0323379747569561, 0.024994122396622385, 0.009043236529188496, 0.05755638011864253, 0.010304811244298304, 0.03368182693208967, 0.036318848109138865, 0.03290665495608534, 0.008222874969110956, 0.05024339431630714, 0.035612482976700575, 0.02613883641814547, 0.040887895971536636, 0.031828988676092455, 0.05046545168651002, 0.07447688574237482, 0.028063638401882987, 0.006488013172721756, 0.014728771356333579, 0.025984378099175434, 0.03728274781523006, 0.03239682409912348, 0.028057585869516646, 0.06250900043440716, 0.03272859379649162, 0.035986783249037604, 0.006909849488043359, 0.04374977347574063, 0.03852130153349467, 0.0054561700588757435, 0.032057780506355424, 0.05196085465805871, 0.18194166065326758, 7.097972222736903, 38.012180532727925, 45.219307218279155, 30.369262831551687, 33.14788218906948, 32.65121105739048, 43.958025046757285, 12.145531909806387, 0.09151783811726741, 0.19455918217343943, 3.2728125878742764, 4.186450328145709, 0.3115802950092724, 0.13470896014145442, 1.6321598589420319, 19.978275265012467, 45.058334827423096, 48.41491229193551, 49.10015753337315, 45.3879017829895, 47.04015908922468, 45.88281849452427, 46.693673270089285, 46.455548082079204, 49.64788055419922, 47.77479212624686, 45.04605736051287, 44.40676403045654, 44.04407501220703, 43.10301794324602, 41.13369001661028, 40.73847300665719, 42.62828574861799, 37.68515314374651, 39.17435359954834, 39.40079191752842, 36.207848003932405, 36.50841665267944, 35.81017827987671, 35.87724576677595, 35.49713066646031, 34.20352547509329, 34.399256229400635, 34.95350708280291, 37.336343152182444, 35.602243014744346, 33.63337019511631, 34.713794231414795, 35.30170215879168, 36.31335987363543, 34.645302363804404, 34.56546756199428, 33.173389026096885, 34.25153752735683, 35.21756294795445, 36.6301907811846, 39.03543826511928, 40.46189301354544, 42.09545966557094, 45.593665736062185, 47.090714182172505, 47.67743396759033, 46.74137612751552, 45.256240367889404, 44.847839151109966, 44.587375504629954, 42.86553546360561, 39.89753253119332, 40.33181231362479, 47.956883566720144, 43.91032566343035, 43.27609409604754, 41.360354151044575, 40.59299162455967, 40.308785983494346, 41.11905711037772, 39.223321029118125, 38.06872844696045, 34.43250683375767, 35.06627287183489, 32.81139482770647, 33.19137791224888, 33.742165088653564, 33.843257904052734, 33.58409357070923, 33.25126096180507, 34.19070257459368, 34.092270919254844, 33.99597236088344, 33.14703450884138, 32.72788095474243, 33.75983435767037, 34.15298080444336, 36.203081539699006, 36.85109485898699, 33.469319752284456, 32.98689242771694, 33.70337677001953, 35.491016251700266, 38.347375529153005, 41.35511868340628, 44.273379462105886, 45.21678154809134, 46.622072083609446, 44.05475786754063, 44.29649611881801, 42.4080764906747, 41.52233403069632, 42.07862070628575, 44.52781902040754, 43.85030712400164, 44.68915966578892, 43.80600193568638, 43.38110569545201, 44.73065778187343, 46.70275109154837, 44.036661284310476, 45.477821895054404, 44.422442640577046, 35.72904069083077, 13.725857990128652, 0.8724825286439487, 0.21929824325655187, 0.7024381788713592, 0.6618330148713929, 0.24304177133100374, 0.09905089318220105, 0.00969422557058611, 0.02474740706384182, 0.09720560362828629, 0.3352487092571599, 7.3192072084971835, 36.66999353681292, 29.59352077756609, 42.135189465114046, 50.190197876521516, 19.637417486735753, 0.4813767895102501, 0.039240616506763866, 0.05467628055651273, 0.021942869161388705, 0.01342683907465211, 0.04802562635658043, 0.001786233258566686, 0.04894984872745616, 0.017768406375710453, 0.053246050873505216, 0.004346730528465871, 0.07380730738597256, 0.048940257634967566, 0.03863066780780043, 0.11383910929518086, 0.04188531870022416, 0.026168980336348926, 0.14754403355930532, 0.15319418108889035, 0.1842813172510692, 0.11877566868705408, 0.15161680430173874, 0.1091484645647662, 0.10522372980735131, 0.13499786678169454, 0.09976264927536249, 0.17974635559533322, 0.10197411025209085, 0.12267999989645821, 0.152716533147863, 0.1291166373661586, 0.15327777660318784, 0.08372041223836796, 0.11686913456235613, 0.13402183486946992, 0.10042572048093591, 0.13645446433552674, 0.1661580540239811, 0.2803018391132355, 9.206804343632289, 44.100032329559326, 51.97106981277466, 38.15151275907244, 41.4039888381958, 35.26441465105329, 47.083578382219585, 14.344444819859095, 0.1743645008121218, 0.6719288559896606, 9.916240606989179, 11.778082506997244, 2.411766197000231, 2.404191357748849, 2.564433970621654, 21.181296791349137, 44.78021580832345, 48.72587891987392, 49.00608587265015, 47.099416800907676, 48.91025979178292, 46.876866000039236, 47.92478288922991, 48.20758499417986, 51.67262383869716, 49.81548500061035, 47.47790254865374, 47.143100125449045, 47.95677586964199, 45.884399209703716, 43.4725717817034, 43.33836385181972, 45.89405025754656, 40.491937024252756, 41.54413400377546, 42.255337715148926, 36.980737822396414, 38.57928555352347, 38.300016607557026, 37.602816990443635, 36.600007806505474, 36.84749916621617, 36.5638632774353, 37.252857072012766, 40.05547203336443, 37.87375852039882, 35.396208081926616, 36.207927908216206, 36.95895869391305, 37.44546113695417, 35.909176213400706, 35.80575922557286, 34.805830069950645, 35.4281975882394, 37.39913054874965, 40.71396323612758, 42.37120934895107, 41.915459632873535, 43.3804977280753, 47.071495464869905, 49.576651096343994, 50.08329289300101, 48.045150007520405, 46.77686405181885, 46.68937233516148, 46.52421712875366, 44.51832430703299, 40.8077187538147, 43.720139571598594, 49.50960792813982, 46.54945993423462, 45.87070778438023, 43.99179329190935, 43.00760875429426, 41.467655181884766, 42.277735233306885, 40.77340507507324, 38.6927079473223, 34.08632673536028, 34.82080691201346, 35.41200481142317, 35.569263390132356, 36.37153019223894, 36.49111911228725, 34.731494767325266, 34.24972404752459, 35.35705498286656, 36.8252649307251, 36.89352055958339, 34.8564407484872, 34.38458858217512, 35.24069002696446, 37.322467599596294, 38.49897480010986, 38.75497422899519, 35.23905720029558, 34.556250776563374, 34.34698493140084, 37.53179597854614, 40.32877247674124, 43.67646666935512, 45.36924239567348, 46.5201906476702, 49.599041666303364, 45.88578537532261, 46.525144713265554, 44.27439389910017, 42.8127361025129, 42.92530386788504, 45.118308203560964, 44.2800566809518, 45.6698214667184, 45.35096515927996, 45.2170421055385, 45.99675505501883, 48.08075952529907, 46.26308298110962, 48.36205734525408, 45.67515073503767, 37.72464323043823, 14.902602297919136, 1.3051756790706088, 0.25724432351333754, 0.808070284979684, 1.556529151541846, 0.7810605743101665, 0.3397258461586067, 0.2129914095359189, 0.24523482365267618, 0.6923546056662286, 0.8352405641760144, 10.615916388375418, 40.5815236227853, 34.51440177645002, 46.302850995744976, 56.385110991341726, 23.518523148127965, 0.4817041690860476, 0.16176174421395573, 0.13013579696416855, 0.09753827577722923, 0.10669274455202477, 0.13863884497966084, 0.22984722363097326, 0.09029667185885565, 0.08886449478034462, 0.13068857230246067, 0.1216838290648801, 0.22792007561240876, 0.1746595414089305, 0.10191152896732092, 0.18770483854625905, 0.11409153789281845, 0.10756280286503689], [0.06842428552252905, 0.05016949846010123, 0.039367024188062975, 0.01713944342918694, 0.03997798729687929, 0.045047003509742875, 0.04497700922989419, 0.004266078159811774, 0.06561331171542406, 0.021603145337264453, 0.012108569366059132, 0.04668646285842572, 0.0231449601040887, 0.13386474044195243, 0.07026262687785284, 0.029494614473411014, 0.08103818366570131, 0.021014489067186202, 0.051996179191129546, 0.021949702009026493, 0.02849367693332689, 0.03574001702613064, 0.9203982289348329, 18.599830831800187, 41.31503452573504, 21.65524557658604, 18.706721918923513, 29.89643791743687, 25.09782784325736, 15.552536794117518, 0.41428001703960554, 0.1219444815069437, 1.7284316016095025, 1.949249586888722, 0.31055188019360813, 0.0359489311730223, 0.1494764605803149, 3.362769829375403, 24.41748629297529, 44.663232462746755, 47.43025875091553, 48.2183130128043, 43.340225969042095, 45.35905286243984, 43.98675584793091, 44.53954063143049, 44.63512005124773, 46.678553989955354, 45.45752273287092, 44.95760679244995, 43.85203375135149, 44.18940353393555, 42.611293928963796, 42.1084041595459, 42.39161968231201, 41.657816955021445, 45.10714939662388, 40.2261962209429, 41.012655871255056, 40.365955761500764, 36.869552748543875, 35.61552102225167, 32.67532825469971, 32.811370509011404, 32.71215718133109, 33.40579237256731, 33.111682074410574, 33.532847132001606, 33.79066351481846, 37.50429848262242, 38.15183932440621, 31.48028326034546, 33.433414936065674, 33.45920317513602, 33.5607476234436, 31.785093784332275, 33.434780257088796, 32.99025535583496, 37.167755535670686, 38.81645883832659, 40.731250354221885, 41.123180866241455, 42.993309361594065, 44.59264571326119, 46.30082212175642, 44.613205432891846, 44.87439169202532, 40.53912918908255, 40.547373226710725, 37.76611702782767, 41.93771818705967, 46.45228590284075, 42.922298771994456, 41.91052293777466, 37.06956706728254, 35.18910312652588, 34.738568033490864, 31.374441351209367, 32.444182532174246, 33.702042715890066, 32.28077827181135, 33.14090272358486, 31.710480553763254, 31.819532530648367, 30.870822020939418, 33.205281257629395, 31.775887421199254, 32.651367391858784, 32.8763952255249, 31.82002932684762, 33.76335709435599, 32.286458424159456, 33.68943868364607, 31.614946297236852, 32.13914966583252, 32.17679500579834, 33.18454783303397, 36.02034739085606, 34.675540924072266, 32.017976556505474, 31.525856494903564, 31.158407960619243, 34.85983146939959, 38.688281944819856, 38.246515478406636, 40.29319075175694, 41.386653082711355, 42.38256270544869, 44.130885805402485, 41.28168317249843, 39.924592290605815, 41.07266051428658, 41.17286743436541, 42.906922408512656, 42.8097414289202, 43.157172203063965, 44.02079159872872, 40.81797776903425, 39.32392399651663, 43.048523221697124, 38.03263602937971, 21.97692632675171, 3.2778951951435635, 0.15243073419800826, 0.39263417997530525, 0.11191054992377758, 0.23031226439135416, 0.0793009643842067, 0.055734927499932904, 0.10819992010614701, 0.004427502064832619, 0.24340812595827238, 0.3533989781779902, 13.903745770454407, 31.799987248012, 23.11577950205122, 33.418941838400706, 33.867576599121094, 6.869683512619563, 0.1095132382054414, 0.012130930487598692, 0.026648550227816616, 0.024973057276968445, 0.016117601921515803, 0.015514693023370845, 0.013159785502856331, 0.0409267726354301, 0.019572011827092086, 0.00994409354669707, 0.05159539230433958, 0.034660993676100454, 0.03381664505494492, 0.04383152676746249, 0.0019000134031687463, 0.05258329179404037, 0.0774012834631971, 0.03218567078667028, 0.034530830303473134, 0.00977458362467587, 0.03405348091785397, 0.044948561649237356, 0.02675715654290148, 0.007325699852247323, 0.027614115737378597, 0.03138073826474803, 0.06147542875260115, 0.0032225782384297675, 0.028399048439626182, 0.05885584931820631, 0.016692528035491705, 0.0925595590046474, 0.03647652607677238, 0.021181296723495637, 0.024116125223892074, 0.02211059453631086, 0.028787452062325816, 0.019160451500543525, 0.03369342309555837, 2.0504807148660933, 24.992778028760636, 45.56344107219151, 25.618690865380422, 24.689447471073695, 33.33235338756016, 30.030986309051514, 15.459477833339147, 0.1492342371493578, 0.03589130658656359, 0.9542936044079917, 2.0028990166527882, 0.08617779466190509, 0.31687712935464724, 0.2397224594439779, 5.694017478397914, 28.28314437185015, 46.477681568690706, 49.300769397190635, 49.57434776851109, 45.41831752232143, 45.848407541002544, 44.9042307308742, 46.806393895830425, 47.740506240299766, 47.33646501813616, 47.45650904519217, 46.087700026375906, 46.16072906766619, 44.643860885075156, 45.22145421164376, 44.96698686054775, 43.4242262159075, 43.86944246292114, 46.004116671425955, 41.68426874705723, 41.621175629752024, 41.74430465698242, 38.36779975891113, 36.708125250680105, 33.69262095860073, 34.45399066380092, 34.772482190813335, 34.569181374141145, 35.08813190460205, 34.430675983428955, 34.42621176583426, 38.410086495535715, 40.25613600867135, 33.3366265296936, 35.23373488017491, 34.44362047740391, 35.9316987991333, 32.991082191467285, 35.11187737328665, 35.707202502659385, 37.8823812348502, 39.54109341757638, 42.30528484072004, 42.1319967678615, 45.55957439967564, 45.541561194828574, 47.408879143851145, 44.444548334394185, 46.405642645699636, 43.12838929040091, 40.70907517841884, 39.432409695216585, 44.195945262908936, 48.03126750673567, 46.627515997205464, 44.07872567858015, 39.31487396785191, 36.90299095426287, 36.413372244153706, 35.40112393242972, 34.37719917297363, 34.43619980130877, 33.56580591201782, 34.5545380456107, 32.62709733418056, 32.864934171949116, 32.600954736982075, 34.60657657895769, 33.81591674259731, 34.1586331639971, 34.68389613287789, 33.87130083356585, 34.38323368344988, 34.00843742915562, 34.427914074489046, 33.94648381641933, 33.38748386928013, 32.95201594488961, 36.379068987710134, 36.99225446156093, 34.64874519620623, 33.03911508832659, 34.05404193060738, 33.58409704480852, 36.93089839390346, 40.70722000939505, 41.19628981181553, 42.46076120649065, 43.72172723497663, 44.021173749651226, 44.98241880961827, 42.568691049303325, 41.79066998617989, 41.94181762422834, 42.7686949457441, 44.261751651763916, 44.105611733027864, 44.4107939856393, 45.88611194065639, 43.08313914707729, 41.5982083593096, 44.685914857046946, 39.361305304935996, 24.9468834400177, 4.48079469374248, 0.5896431856921741, 1.6419932969978877, 0.2345532439649105, 0.21216253829853876, 0.14470811001956463, 0.28073365879910334, 0.14640461041459016, 0.07948713403727327, 0.40748280606099535, 0.3401906155049801, 15.148068257740565, 38.664303711482454, 27.684798513139995, 38.34303290503365, 39.30821759360177, 9.256237302507673, 0.035971461928316524, 0.03339459288067051, 0.036746294636811526, 0.022583402826317718, 0.02441018194492374, 0.12968828954866954, 0.020234652162928666, 0.026294991074662124, 0.09051013219037227, 0.045228521805256605, 0.0510942025908402, 0.059237023150282245, 0.032600262468414645, 0.016192980376737456, 0.035565674238439114, 0.04288357263430953, 0.04464804866750326, 0.16651319925274166, 0.23633304131882532, 0.12146776994424206, 0.11635830625891685, 0.18629154509731702, 0.09833087253251246, 0.12276029773056507, 0.12038383739335196, 0.15632362530699798, 0.10897472567324128, 0.09040522389113903, 0.1260022430547646, 0.14054597621517523, 0.18126840463706426, 0.13807658372180803, 0.11127033856298242, 0.09531407191285066, 0.07446468568273953, 0.16899952798017434, 0.09196184429207019, 0.14859232945101603, 0.11919466406106949, 2.196469098329544, 29.75916235787528, 52.60042721884591, 31.071750027792795, 27.119093554360525, 39.15330750601632, 32.899643898010254, 19.778948817934307, 0.8265160694718361, 0.2902675100735256, 5.50055878502982, 6.369768440723419, 0.37375179891075405, 1.3577535663332259, 0.5515002352850777, 6.029209000723703, 28.430394070489065, 47.15706947871617, 49.691970348358154, 51.01789508547102, 44.82615729740688, 47.09943764550345, 46.05879899433681, 48.15299647194998, 48.95441559382847, 48.89196171079363, 50.33121504102434, 47.91491992133004, 47.45959751946585, 47.71640293938773, 47.18935775756836, 46.02169213976179, 45.83267681939261, 45.73907763617379, 47.35873746871948, 43.945521763392854, 44.31290428979056, 43.51392051151821, 39.6771183013916, 38.40183898380825, 35.07688624518258, 35.844707352774485, 37.33584288188389, 36.63602726800101, 37.34830447605678, 37.12404094423567, 36.60243967601231, 40.66908482142857, 41.64630726405552, 34.89151872907366, 36.604218414851594, 36.23534549985613, 37.30045223236084, 34.55555248260498, 36.0363768850054, 36.964249747140066, 39.72512687955584, 43.11577136175973, 44.34951434816633, 43.3844964163644, 46.97448819024222, 47.98722634996687, 50.31146478652954, 48.010478496551514, 49.76450606754848, 44.32896157673427, 40.8556022644043, 41.11021205357143, 46.812567370278494, 49.448126792907715, 48.262864862169536, 45.814330101013184, 40.85837459564209, 37.996682575770784, 37.832948275974815, 36.892019748687744, 35.27520867756435, 35.541203090122764, 35.96122516904558, 36.73867300578526, 34.43995530264718, 35.380001408713206, 33.12848629270281, 36.565433570316856, 34.432235854012625, 35.92392723900931, 36.65245975766863, 33.94429860796247, 36.296798842293875, 34.29586008616856, 36.8867495400565, 34.8586676461356, 34.50043589728219, 34.4505478313991, 36.6125180380685, 37.81366702488491, 35.456567083086284, 34.562948840005056, 36.330636569431846, 36.007472378867014, 37.738744599478586, 41.43864645276751, 41.6238819531032, 44.462005683353965, 44.95515407834734, 45.857791083199636, 47.88040474482945, 45.44558572769165, 43.25206027712141, 43.62196152550833, 42.145361627851216, 44.93508768081665, 44.7602710042681, 46.01111350740705, 46.57279198510306, 45.78648519515991, 42.099645955221995, 45.867188521793906, 40.41710492542812, 27.240464687347412, 4.5408744641712735, 0.7656079977750778, 2.3335891919476643, 0.6346685439348221, 1.0185078786952155, 0.4513510178242411, 0.4992003845317023, 0.3674919062427112, 0.22191322222352028, 1.343723850590842, 0.8146692280258451, 20.149874925613403, 42.43302747181484, 32.488564150674, 44.51560756138393, 42.40203850609915, 11.08918251310076, 0.18364225939980575, 0.13972474528210505, 0.16105163017553942, 0.11817931782986436, 0.10078275882239852, 0.2812040192740304, 0.10233353025146893, 0.13451264638985905, 0.1902707051485777, 0.22963576497776167, 0.19653572754136153, 0.14804997641061032, 0.08074486654783998, 0.1185387513999428, 0.17795483315629618, 0.15925552083977632, 0.16088173857757024], [0.0178719508195562, 0.04146675080327051, 0.05007607097338353, 0.03578418626316956, 0.007172429817728698, 0.09032121447048017, 0.0251787365081587, 0.05280831436227475, 0.010001082006575806, 0.01528629643975624, 0.03780761161553008, 0.009599366374979061, 0.022339109863553728, 0.05720656138977834, 0.04392773964043174, 0.03227866740365114, 0.02036867131079946, 0.06112517576132502, 0.0594885628670454, 0.00829022126604936, 0.03611097890617592, 0.02130472393972533, 0.17083187108593328, 9.762970294271197, 38.60630362374442, 37.26069116592407, 22.216142381940568, 27.010048525674, 28.388623237609863, 15.432718583515712, 0.8326847670333726, 0.021614246170169542, 0.6803881792085511, 0.8386695001806531, 0.35766180657914703, 0.1409922351262399, 0.28993250376411844, 0.38593902066349983, 7.232331275939941, 33.39850371224539, 47.47968128749302, 47.84925249644688, 47.04895898274013, 45.58231585366385, 46.26174545288086, 46.34117031097412, 45.78628717150007, 45.90871443067278, 46.14163194383894, 49.032110350472585, 46.761529377528596, 47.152952671051025, 46.59891026360648, 44.62995753969465, 45.225088119506836, 45.04574121747698, 45.103241034916465, 43.93896613802229, 41.480335644313264, 40.34307186944144, 37.78483200073242, 34.477538108825684, 33.32275445120675, 33.600887366703574, 32.64008699144636, 34.39056403296334, 34.644034317561555, 32.20404931477138, 32.899233954293386, 33.73450122560774, 32.93040704727173, 35.00287750789097, 33.87371185847691, 33.83254030772618, 34.47078793389456, 33.531026703970774, 33.51539673124041, 32.369708265577046, 35.01184068407331, 37.68908929824829, 39.98179333550589, 39.01859583173479, 42.73970358712332, 43.31427444730486, 45.039967264447895, 42.28408588681902, 42.62178223473685, 40.21422447477068, 42.06702068873814, 38.67592804772513, 40.390635762895855, 48.13166202817644, 43.35186767578125, 43.443702016557964, 38.7759438923427, 37.79771743501936, 34.72080496379307, 34.62729958125523, 33.79809808731079, 31.44404493059431, 32.754739216395784, 33.12181602205549, 31.475412573133195, 32.39680971418108, 32.674991267068044, 33.63583333151681, 32.60401541846139, 34.696430683135986, 32.81644269398281, 32.84085866383144, 32.71719462530953, 31.710793222699845, 32.988990783691406, 32.46632991518293, 32.63269410814558, 33.11125476019723, 32.19330392565046, 32.91011135918753, 33.70953287397112, 32.50584084647042, 31.620782784053258, 31.859033039637975, 31.457652977534703, 32.575176920209614, 35.82673931121826, 36.07143749509539, 39.16010979243687, 43.303695814950125, 44.22459268569946, 42.82375594547817, 42.24054152624947, 40.58011313847133, 40.837095737457275, 42.82660470690046, 42.89256395612444, 40.19734730039324, 38.96622725895473, 39.59222173690796, 44.220837184361045, 43.60782541547503, 33.004099641527446, 11.294629454612732, 0.5230176150798798, 0.3255532852240971, 0.735016219317913, 0.16539042735738413, 0.16034120401101454, 0.01491510046512953, 0.07392719773841755, 0.14154655752437456, 0.020992163568735123, 0.5580981469580105, 2.8671096605913977, 19.14092353412083, 27.84573790005275, 22.328343629837036, 34.739440032414024, 19.437813111713954, 0.876364888889449, 0.033615581558219025, 0.010458014273483838, 0.020617327253733362, 0.04425376553886703, 0.02086869564040431, 0.0317749976446586, 0.04122100577556661, 0.015766175064657415, 0.021701125793957284, 0.020737704455054233, 0.11194476844476801, 0.026715535204857588, 0.06961601014648165, 0.06364526160593544, 0.01502276531287602, 0.04495534021407366, 0.041660852530705075, 0.03828677947499922, 0.04988679702260664, 0.03892317068363939, 0.027536526954333698, 0.03638734282659633, 0.01831996883265674, 0.014354340466005462, 0.04971476125397852, 0.018787141889333725, 0.0011207582366686048, 0.03865017908226166, 0.047955845815262625, 0.02785936034550624, 0.01841458714833217, 0.021122896910778115, 0.07858152048928396, 0.020663737352671366, 0.008074000993344401, 0.023545884394219944, 0.04105412008773003, 0.037097266875207424, 0.03234006803748863, 0.24281318645392144, 12.647084150995527, 45.973864214760916, 39.06987353733608, 22.11938350541251, 30.550583021981375, 30.687427793230327, 16.598259789603098, 0.6798460568700517, 0.03814565436914563, 0.20315590873360634, 0.4700075824345861, 0.5623984304921967, 0.16776961540537222, 0.09639952438218252, 0.8358673676848412, 9.533045717648097, 36.21998650687081, 48.41308838980538, 48.9215749331883, 47.422376019614084, 45.89093746457781, 46.47866473879133, 47.13941410609654, 46.01899971280779, 48.4751010622297, 49.179387841905864, 51.006659848349436, 49.69976275307791, 48.55227817807879, 47.636481285095215, 45.67354917526245, 46.613091536930625, 45.40284040996006, 47.40497773034232, 45.73770884105137, 42.75169965199062, 42.47322627476284, 40.008870465414866, 34.56516531535557, 34.35451330457415, 35.38378470284598, 34.49659354346139, 35.06144734791347, 35.608468600681846, 34.64504528045654, 35.20471225466047, 35.5406368119376, 35.83675513948713, 35.32124744142805, 35.4145131111145, 35.63215153557913, 35.734661783490864, 34.92502294267927, 34.70259026118687, 33.93139927727835, 36.69571229389736, 39.53543063572475, 40.95431532178606, 42.24026359830584, 43.621732234954834, 45.75096252986363, 46.75432062149048, 44.938263007572715, 43.56668513161795, 41.86832652773176, 41.48269803183419, 39.77538319996425, 43.44225679125105, 48.74528523853847, 45.38298940658569, 44.70292752129691, 42.065738746098106, 39.611030510493684, 35.82504047666277, 35.413074834006174, 35.14194222858974, 32.864194188799175, 33.635131563459126, 33.90026787349156, 31.956696919032506, 32.97932583945138, 34.53073351723807, 35.376089572906494, 33.397218295506065, 33.970951897757395, 34.05801977430071, 34.79415362221854, 34.66376372746059, 34.37672669546944, 35.015794209071565, 33.41965750285557, 34.25706481933594, 34.84789446422032, 33.64474092211042, 33.96007101876395, 34.708895751408164, 33.95481123243059, 33.60534463609968, 33.101589815957205, 31.557050432477677, 34.92775705882481, 36.85973146983555, 38.70751108442034, 40.979836055210654, 43.75576993397304, 45.760120255606516, 43.91543953759329, 43.38510090964181, 42.55888714109148, 42.54299661091396, 44.06977987289429, 43.869914940425325, 42.85884782246181, 41.86234760284424, 42.91486072540283, 45.49091924939837, 45.71178163800921, 33.244632380349294, 13.290588957922798, 0.9960982011897224, 1.8526631125382014, 5.349478023392813, 1.0552145604576384, 0.1926946493663958, 0.02560281241312623, 0.1425804549029895, 0.10633736862135784, 0.05273036425933242, 1.105548939534596, 2.8795013385159627, 23.404254811150686, 32.044932092939106, 23.70390977178301, 38.958896909441265, 25.603453465870448, 1.8945833316871097, 0.16072468486215385, 0.03782427982826318, 0.07247891223856381, 0.0208184467295983, 0.034464082813688686, 0.03497840217979891, 0.03771007899194956, 0.02460524719208479, 0.02462025808303484, 0.07259540313056537, 0.03635533293709159, 0.031108750895197903, 0.02898879036573427, 0.03455360872404916, 0.015642077795096805, 0.04778563530583467, 0.0048149794872318, 0.1735109444707632, 0.15575829707086086, 0.12186258233019284, 0.09777481987008027, 0.12874849140644073, 0.15400412119925022, 0.06499904074839183, 0.07509473258895533, 0.12029740560267653, 0.13757317859147275, 0.1415284134979759, 0.12115434104842798, 0.06125438918492623, 0.14706171729734965, 0.17283768845455988, 0.1356706071112837, 0.14672344044915267, 0.10235761145928077, 0.143820640497974, 0.24597252692495072, 0.08094439655542374, 0.13988181256822177, 0.2930447810462543, 14.682719605309622, 52.671548979622976, 46.523268699645996, 29.365192549569265, 37.029180662972585, 36.41872583116804, 20.664284808295115, 1.1495652347803116, 0.12659839035144874, 2.533372917345592, 3.086953486715044, 0.7783715671726635, 0.6228711541209901, 2.254590779542923, 1.7309906014374323, 10.635068229266576, 36.76393665586199, 48.77028138296944, 48.56035893304007, 47.967757497514995, 46.32320574351719, 47.30172749928066, 48.15839869635445, 47.85410581316267, 49.19346489225115, 48.93075697762625, 54.593959195273264, 51.80247177396502, 50.6673515183585, 49.200124740600586, 48.97212307793753, 48.547723633902415, 48.18258537564959, 48.92062650408064, 46.59859412057059, 45.30506535938808, 43.49830443518502, 42.497687407902305, 36.81509971618652, 35.53161110196795, 37.603570869990754, 36.22377674920218, 38.390464782714844, 38.28722149985177, 35.35014499936785, 36.47119862692696, 37.128189018794465, 37.2032538822719, 38.168779032570974, 37.06164264678955, 37.29862833023071, 37.851628507886616, 36.56371736526489, 36.32110711506435, 34.416063921792166, 38.43332821982247, 40.32300894601004, 42.90095043182373, 43.40506655829293, 45.720928941454204, 47.865042277744834, 47.82990871156965, 45.08180931636265, 44.97275733947754, 42.084297384534565, 42.09730093819754, 41.60413517270769, 46.8220134462629, 51.84691940035139, 46.679283550807405, 47.1824859891619, 43.645519392830984, 41.517689159938264, 38.50034359523228, 37.52965593338013, 37.052074977329795, 34.163139070783345, 35.53722177233015, 36.07406391416277, 32.87468596867153, 34.48387834003994, 36.852557454790386, 36.653356075286865, 35.97169610432216, 37.82780660901751, 37.016962255750386, 37.05531978607178, 35.88601439339774, 35.315018381391255, 36.346374239240376, 34.94187232426235, 36.79571076801845, 36.32128082002912, 34.81768717084612, 35.44282354627337, 37.15548849105835, 34.83803844451904, 35.72672346660069, 34.78974151611328, 34.00008569444929, 35.97905077253069, 39.0716210092817, 39.21317318507603, 42.257936341421946, 45.9010922568185, 47.02124956675938, 45.40701975141253, 45.676905155181885, 43.29800524030413, 45.27862746374947, 44.17597614015852, 45.5792030606951, 45.2871390070234, 44.30622707094465, 45.58105475561959, 46.55709253038679, 47.22694403784615, 35.59697280611311, 13.999576193945748, 1.1953443097216743, 1.0784855974572045, 4.047224061829703, 1.406835749745369, 0.35097421971814974, 0.30791465884872843, 0.35691598802804947, 0.37945437005587984, 0.20852252362029894, 2.405802688428334, 6.635230881827218, 26.621652909687587, 36.2246105330331, 29.80496140888759, 45.87229197365897, 29.289742061070033, 2.0677580620561327, 0.22654699214867183, 0.1303250946636711, 0.17355211797569478, 0.16364303683596, 0.17379033805004188, 0.14588869309851102, 0.18068635729806765, 0.0847899734175631, 0.08776014511074338, 0.09177173913589545, 0.1853602286428213, 0.10781158094427415, 0.09763230037476335, 0.12701818639678614, 0.06175267816122089, 0.16673118541283266, 0.10545825865119696], [0.0638885639075722, 0.01095055605817054, 0.04192844299333436, 0.012398361494498593, 0.017093599906989505, 0.08379490859806538, 0.02896836306899786, 0.026767587322475653, 0.014390670927241445, 0.042744004766323736, 0.03407422712604914, 0.01484916721736746, 0.03550241781132562, 0.031108655900295292, 0.02356608268538756, 0.012010712742007204, 0.02281616408643978, 0.04023043964324253, 0.0065337693335355395, 0.03477768134325743, 0.06193552977804627, 0.02581388769405229, 0.021993983204343488, 2.3341682808739797, 21.352941615240915, 36.013089997427805, 34.081390040261404, 28.479774917875016, 30.669230461120605, 20.822804485048565, 1.446427128144673, 0.06920240234051432, 0.16993936683450425, 0.39231895974704195, 0.23451736303312437, 0.18483639960842474, 0.5535020221556936, 0.6775679705398423, 1.2284613783870424, 15.81159690448216, 40.400505678994314, 47.80798714501517, 47.33411652701241, 46.42364195414952, 46.61216047831944, 45.66758762087141, 45.24030120032174, 46.56259897777012, 45.091484682900564, 45.006556851523264, 45.157798290252686, 45.99382986341204, 44.51975563594273, 44.71984985896519, 44.430193356105256, 43.0935822895595, 45.6388463973999, 45.27286045891898, 44.80670581545149, 42.4508878162929, 38.946386677878245, 36.25960513523647, 36.40362392153059, 32.29728719166347, 31.502312523978098, 32.93925905227661, 33.97866439819336, 31.916446004595073, 33.54709441321236, 33.816701889038086, 35.32206732886178, 34.744484424591064, 34.79804808752877, 31.884793485913956, 33.88891799109322, 32.222583634512766, 31.76725775854928, 33.24462195805141, 33.80374002456665, 34.39646305356707, 38.924072538103374, 43.176870346069336, 43.3861083984375, 45.640590395246235, 44.93716866629464, 43.04680701664516, 40.83897175107683, 39.85848365511213, 39.601942266736714, 39.17096287863595, 39.51219585963658, 47.626552309308735, 43.445015226091655, 42.34271131243025, 41.34831987108503, 42.422612122126985, 39.03590032032558, 37.5865547316415, 36.35635185241699, 36.261915411267964, 32.74418142863682, 32.17901495524815, 34.24384239741734, 34.5827442577907, 32.74774238041469, 32.352872780391145, 32.8288209097726, 33.47586842945644, 32.37085819244385, 34.55231809616089, 32.3537517275129, 34.44128935677664, 33.05786827632359, 33.23142385482788, 31.917710576738628, 32.339622565678184, 31.4601925441197, 32.35768788201468, 32.872959341321675, 32.01533624104091, 31.850632667541504, 30.7590810911996, 30.690738609858922, 30.489890507289342, 31.119140216282435, 33.085820879255024, 37.262261458805625, 40.40063769476754, 41.45764282771519, 43.019823687417166, 44.939412934439524, 43.37676307133266, 41.14996269771031, 40.04699523108346, 38.059515135628835, 39.238096373421804, 41.672807693481445, 43.830862590244834, 43.89907652991158, 34.25692238126482, 18.89002582005092, 2.9489870156560625, 0.08574739989957639, 2.5063463790076117, 5.059480624539511, 0.8417076000145504, 0.1522087175399065, 0.08970560000411101, 0.035995224224669595, 0.09131526827280011, 0.12002048189086573, 0.1895344132291419, 8.18304373536791, 30.305731977735245, 25.237604754311697, 29.57354470661708, 35.11790493556431, 6.4735033086368015, 0.05961707739957741, 0.021285875933244824, 0.042669864637511115, 0.048412923967199664, 0.07221260081444468, 0.020342026936954687, 0.046234293907348595, 0.038606895333422084, 0.05291074600868991, 0.05158114306894796, 0.06003942473658493, 0.058945565218372006, 0.057737535397921286, 0.05986811500042677, 0.04800562992958086, 0.010839026953492845, 0.02937858159254704, 0.047682043364537616, 0.042659181103642495, 0.02338824713868754, 0.05115120292508176, 0.03385369306696313, 0.020128215463565927, 0.043522121584309, 0.055666459923876185, 0.016475920997826115, 0.008157836539404733, 0.03596852047901068, 0.013051029910067362, 0.04908774061394589, 0.05077197648850935, 0.03987951150962284, 0.0527207324547427, 0.017087520233222415, 0.023276046284341385, 0.05433628362204347, 0.020068621429215585, 0.025087824690022638, 0.024312318535521626, 0.00960435954454754, 0.0864732355943748, 3.7885734609195163, 28.226559979575022, 42.085753032139365, 32.150318895067485, 32.04008225032261, 35.54266568592617, 22.369536025183542, 1.6060440774474825, 0.06328223858560834, 0.048717036577207704, 0.25257833674550056, 0.21389569315527165, 0.1308153769267457, 0.4184889426188809, 0.8676344230771065, 1.5069842615297862, 18.615695306232997, 42.30898128237043, 48.0655950818743, 49.18283414840698, 46.935974325452534, 46.2004588672093, 46.5792155947004, 46.71411487034389, 46.72701072692871, 47.13731575012207, 47.47087097167969, 46.140204089028494, 47.975122588021414, 45.54136317116873, 46.2879992212568, 46.35334702900478, 45.65034566606794, 46.748074190957205, 46.968335560389924, 46.892978872571675, 43.573716708592, 41.45603779384068, 37.044692516326904, 37.48751163482666, 34.10387093680245, 34.02624566214425, 34.136023725782124, 34.886411803109304, 33.20746646608625, 35.3611717905317, 36.24765770775931, 36.751832893916536, 36.04664979662214, 36.67139707292829, 35.31496974400112, 35.42191989081246, 33.85036938531058, 33.16758033207485, 33.75968149730137, 35.03482532501221, 37.90784638268607, 40.41517332621983, 43.09398528507778, 46.16684695652553, 46.46568897792271, 45.052255153656006, 44.395257813589915, 41.611013889312744, 40.70818928309849, 39.42670522417341, 39.258027281079976, 41.986459800175254, 48.80477918897356, 46.21828447069441, 45.103703090122764, 42.664597034454346, 44.259906905038015, 39.88300384793963, 38.80553279604231, 37.37041711807251, 36.414751461574006, 33.8379807472229, 32.401416369846885, 36.08367327281407, 36.221192019326345, 33.84490115301949, 33.85989189147949, 35.22809989111764, 35.88601786749703, 33.88981430871146, 35.7477765083313, 34.156510489327566, 35.433578968048096, 33.92884234019688, 34.039065088544575, 33.760397161756245, 34.09386900493077, 35.70094217572893, 33.77067354747227, 34.14946501595633, 33.44557428359985, 33.12082937785557, 32.316575390951975, 32.66501365389143, 31.533815656389507, 33.62211758749825, 35.2644077028547, 38.331964424678254, 41.83018439156668, 43.67648751395089, 43.934692995888845, 45.49648128237043, 44.73855440957205, 43.72819948196411, 41.91891983577183, 41.2253680229187, 40.62942450387137, 43.66222981044224, 44.46878712517874, 44.85744156156267, 37.46172339575631, 21.48544202532087, 4.60910837990897, 0.879661212010043, 3.4218499277319228, 8.3790237562997, 1.781079187989235, 0.2905425881700856, 0.15200374568147318, 0.03197776087160621, 0.11460065628801074, 0.11476431893450872, 0.4058565747525011, 10.679657425199236, 31.861423219953263, 24.94055015700204, 30.710558346339635, 40.867038999285015, 10.081852657454354, 0.0644315140587943, 0.04874130438214966, 0.070895014729883, 0.03518596264932837, 0.061969924718141556, 0.05732188520154782, 0.025327484954946806, 0.02922164662075894, 0.03985698075432863, 0.0089327752689964, 0.04886472650936671, 0.014140496762203318, 0.04650562649060573, 0.11127113244895424, 0.06935406848788261, 0.03002944595313498, 0.049790200777351856, 0.0649717975673931, 0.16885110523019517, 0.10841744486242533, 0.127241153003914, 0.17903478949197701, 0.11227080452122859, 0.14204509077327593, 0.15267773451549665, 0.09115676249244384, 0.08339862379112414, 0.14224912625338348, 0.10049869692219154, 0.14020913786121778, 0.2244659388171775, 0.10172446364802973, 0.16150152603430407, 0.1414570723261152, 0.1424255317875317, 0.10794380706335817, 0.08362939355096646, 0.11169434152543545, 0.11379217502794095, 0.119654670091612, 0.20733249533389295, 3.7798404438155035, 31.015990734100342, 49.029973779405864, 43.030506542750764, 37.09494883673531, 39.678914410727366, 28.287987266268047, 2.5528936641556874, 0.16741213601614746, 0.5260516979864666, 1.4348532749073846, 0.7431357321994645, 0.6607677148921149, 1.3054860681295395, 2.719405289207186, 2.2987606951168607, 20.069953271320887, 40.74062694822039, 49.26042468207223, 47.53743471418108, 47.06539494650704, 46.89828382219587, 47.50007772445679, 46.49637222290039, 48.20554917199271, 47.7763728414263, 47.65831252506801, 47.39452763966152, 49.16914619718279, 46.604878766196116, 48.114479133060996, 47.16355562210083, 46.55691882542202, 47.476398263658794, 48.6445745740618, 48.52171305247715, 46.43476949419294, 43.783632210322786, 39.64008787700108, 40.675650869097026, 36.60402039119175, 34.91747372491019, 36.193468706948416, 36.067411014011924, 35.149567876543315, 37.8321144921439, 38.499336106436594, 40.27607039042881, 37.14883211680821, 38.51212774004255, 36.3623377255031, 36.90652411324637, 34.96314770834786, 34.96245983668736, 36.3642623765128, 37.72390672138759, 39.2449438231332, 42.834247725350515, 45.93773705618722, 46.332940169743125, 48.50161191395351, 45.64254631314959, 45.033929279872346, 41.229787077222554, 41.50696808951241, 38.380466324942454, 40.948829718998496, 44.99545015607561, 50.97930131639753, 47.485927718026296, 45.722130979810444, 44.86512974330357, 47.70114816938128, 42.199015617370605, 42.06770508629935, 39.40976899010794, 40.100239276885986, 36.89737680980137, 35.145263467516216, 37.054048265729634, 37.90414299283709, 36.470823424203054, 34.512035914829795, 37.10138634272984, 36.464142731257844, 35.58449036734444, 37.39679247992379, 36.30895471572876, 37.26386996677944, 35.61379092080252, 36.71723781313215, 34.18263571602957, 35.716756275721956, 36.340541226523264, 36.25715936933245, 35.94003316334316, 33.96741873877389, 34.53427015032087, 33.31757109505789, 33.758826868874685, 33.05888966151646, 35.5948987688337, 35.648420742579866, 40.3743109703064, 44.38334860120501, 45.3170371055603, 46.76809542519705, 48.38477448054722, 46.90921681267874, 44.42595148086548, 44.94011122839791, 43.80286829812186, 42.45318767002651, 46.071639265332905, 45.47057144982474, 45.57242161887032, 36.56859500067574, 21.832342999322073, 3.989845837865557, 0.6265468054584095, 4.346926357064929, 11.688529780932836, 3.2356128011431013, 0.4625683416213308, 0.30953923453177723, 0.1930354367941618, 0.2548351985003267, 0.42935098548020634, 2.5657254670347487, 14.811963047300067, 40.75747980390276, 33.21110037394932, 38.46325063705444, 46.327239172799246, 11.844528130122594, 0.14422800578176975, 0.12460224889218807, 0.18243589199015073, 0.09688081605626003, 0.2928566097148827, 0.13186083654207842, 0.11796667852572032, 0.07482562560055937, 0.15788817778229713, 0.2298542803951672, 0.1858184297702142, 0.15229660139552184, 0.16737554940794194, 0.21037208794483117, 0.14293497587953294, 0.14993387460708618, 0.11963066352265221, 0.1305656081863812], [0.01887823182291218, 0.007544462086765894, 0.04771298795406308, 0.006745435788096594, 0.019975663827998296, 0.034865897681031904, 0.047357798620526276, 0.011308140620323164, 0.0533156923151442, 0.039473564364016056, 0.04885556289393987, 0.04387535334431699, 0.06242542527616024, 0.024719805955620747, 0.02068330460627164, 0.07731757938329663, 0.023519813382465924, 0.014229415383722101, 0.03589372895658016, 0.015290559336010898, 0.02714665260698114, 0.06534294265189342, 0.0297093911628638, 0.27576493684734615, 8.793224113328115, 36.32643290928432, 36.10207557678223, 27.845890760421753, 33.376029763902935, 27.0651581627982, 3.0603837924344197, 0.03551019721531442, 0.19650553273303167, 0.09993522108665534, 0.171461551583239, 0.039013619401625226, 0.45178856434566633, 0.07228845424417939, 0.18007817279015267, 3.021447390317917, 22.02206356184823, 43.52710819244385, 49.814446244921, 47.15131984438215, 48.52369328907558, 47.95294393811907, 44.12072059086391, 44.985118184770855, 46.71970469611031, 44.97641904013497, 44.066983222961426, 43.935592787606375, 44.89191852297102, 43.70195266178676, 42.907040527888704, 44.48372227805001, 43.457723481314524, 46.291452475956504, 45.24761765343802, 45.94560241699219, 41.38157047544207, 37.47388621738979, 32.94056878771101, 33.759434836251394, 32.463373456682476, 33.06044258390154, 32.820323262895855, 32.903031144823345, 34.39393738337925, 34.14240912028721, 36.41154834202358, 36.674252782549175, 36.71214478356497, 35.04467787061419, 33.295983042035786, 31.9241897719247, 32.62386294773647, 33.358099937438965, 33.520934445517405, 37.52020985739571, 38.34444338934762, 43.519149030957905, 39.15583317620413, 42.53508261271885, 43.53399385724749, 44.145112242017476, 42.653611932482036, 41.761900969914024, 44.02558585575649, 40.52993672234671, 38.412667751312256, 47.38140596662249, 43.18393318993704, 44.30613327026367, 42.864785058157786, 42.694387435913086, 41.87278727122715, 43.24501480375017, 42.36374003546578, 41.156674657549175, 39.830333028520855, 31.578843457358225, 32.33003405162266, 31.209383419581822, 32.079923221043174, 32.24336222239903, 31.994519438062394, 33.136619159153526, 32.802282265254426, 33.48631157193865, 30.586998530796595, 35.31967714854649, 35.27493422372, 32.72800254821777, 32.65852403640747, 32.91985273361206, 32.95923859732491, 31.460258552006312, 31.756800719669886, 32.95183876582554, 31.64048092705863, 30.314174039023264, 31.039506912231445, 29.929639884403773, 30.99196038927351, 30.68109451021467, 32.1579132761274, 36.33553504943848, 37.701380661555696, 41.59355654035296, 42.70430946350098, 42.704059328351704, 42.757011549813406, 39.778822558266775, 39.55306168964931, 42.07084219796317, 43.06329161780221, 43.03498465674264, 39.635651452200754, 25.489921637943812, 8.394770111356463, 0.9772107175418309, 0.5791116165263313, 5.969246481146131, 11.132630467414856, 2.2112205582005635, 0.31997293180653025, 0.10374557519597666, 0.03819572686084679, 0.0359905525110662, 0.3432475786123957, 1.0944486494575227, 13.097297889845711, 28.87708854675293, 29.88167299543108, 37.4792606489999, 18.18223888533456, 1.2051337787083216, 0.023946208180859685, 0.041070856153964996, 0.030575751460024288, 0.03890601731836796, 0.050052251001553874, 0.02252140677800136, 0.04222690001396196, 0.08262017449097973, 0.018394624648083533, 0.033555527816393545, 0.04145811305248311, 0.012945721275173128, 0.01980816406596984, 0.050773825496435165, 0.06735961658081838, 0.04808913044897573, 0.06985813179718596, 0.0307178197295538, 0.01946564807024385, 0.01182815374340862, 0.046389678426619084, 0.02503782514083598, 0.018963615276983807, 0.05782541246818645, 0.07527288874345166, 0.04064223236803498, 0.02216088755189308, 0.035850652160921266, 0.025506017696378485, 0.02527873051751937, 0.028868889835264002, 0.01580149450871561, 0.1103735731116363, 0.06670471493686948, 0.023559237963386943, 0.02026859248456146, 0.09921816563499825, 0.028842264121132236, 0.005974620430996376, 0.09877207635768823, 0.060912366823426316, 0.5072455842580114, 12.740342003958565, 41.64590426853725, 40.100690909794395, 28.675707169941493, 34.6214804649353, 30.41178580692836, 3.4071686012404303, 0.01794969057664275, 0.6749457312481744, 0.2486867212823459, 0.1431723545704569, 0.13724765820162638, 0.355813667178154, 0.6363966369203159, 0.6013174621122224, 3.68714930330004, 25.839728696005686, 44.47572490147182, 48.45389516013009, 47.89223057883126, 47.15602377482823, 47.66895369121006, 46.583989007132395, 46.14657211303711, 46.44408008030483, 44.97894818442208, 45.27785621370588, 44.959076336451936, 46.22817175728934, 44.69157416479928, 43.38902316774641, 44.925238609313965, 45.641087191445486, 47.48820672716413, 46.2139071055821, 46.1305183001927, 43.233122961861746, 39.24368272508894, 35.2704804284232, 34.09685673032488, 34.295043672834126, 33.89042922428676, 34.52269445146833, 34.92852830886841, 35.3664767401559, 35.63298184531075, 37.480448790958945, 38.46103763580322, 37.82152196339199, 36.07730524880545, 35.231709480285645, 33.841680662972585, 33.591611521584646, 34.93117904663086, 36.52019384929112, 39.81184734616961, 39.112691811152864, 44.47144133704049, 43.057451656886506, 43.03948014123099, 44.839692388262065, 43.78632811137608, 42.385998589651926, 40.66187259129116, 42.87524904523577, 40.96165261949812, 40.16536126817976, 48.03294549669538, 45.732490743909565, 45.96253865105765, 44.465650013514924, 43.96624476569039, 42.74025249481201, 44.136211599622456, 43.92899547304426, 41.20128904070173, 38.90560075214931, 32.277231216430664, 34.115536962236675, 33.280717849731445, 34.79076637540545, 33.99003859928676, 34.0946159362793, 33.93681539808001, 33.375241143362864, 34.621087891714915, 32.669220788138254, 38.490716866084504, 36.421824727739605, 32.840466090611045, 32.97924246106829, 33.59930665152413, 34.001933915274485, 33.639227526528494, 33.57690218516758, 34.09377173015049, 33.632387025015696, 32.06460591724941, 32.569277899605886, 32.24224008832659, 32.88848509107317, 32.314206055232454, 34.871028491428916, 38.02593796593802, 39.33447483607701, 43.19275740214756, 43.795200960976736, 44.11284828186035, 43.30414744785854, 41.4614817074367, 41.37815890993391, 42.30844974517822, 44.939961842128206, 42.82546867643084, 41.03435509545462, 28.476017679486954, 11.350816062518529, 1.8556816705635615, 1.8157748005219867, 5.159151230539594, 6.693013838359287, 4.4063034909112115, 0.4232155904173851, 0.1288393743868385, 0.05121499539485999, 0.08182875160127878, 0.6139037438801357, 1.2905890217849185, 15.821161099842616, 38.787418842315674, 32.62374135426113, 41.066351549965994, 24.98213859966823, 2.3931600068296706, 0.03029166241841657, 0.02912129129150084, 0.07281388462121997, 0.007907681882248392, 0.012044312099793127, 0.022931001049333384, 0.07497823491160359, 0.02861794044396707, 0.05269365890749863, 0.05833390661116157, 0.04791845514306, 0.03052105475217104, 0.037187026880149326, 0.04272425600460597, 0.0448263948118048, 0.08008325419255666, 0.07133022709084408, 0.04298107811648931, 0.14199320998575005, 0.08670035483581678, 0.1554346087255648, 0.06441651164953198, 0.09290789174182074, 0.13510964864066669, 0.16723001721714223, 0.0971581061769809, 0.12526800031108515, 0.10619897461895432, 0.10909601380782467, 0.10841643384524755, 0.13974516918616636, 0.15151946166796343, 0.23325588500925473, 0.13258026008095058, 0.1481599397957325, 0.10188617889902421, 0.22136993280478887, 0.09353094295199428, 0.0805650276264974, 0.1863686673875366, 0.1009597343259624, 0.5988364123872348, 13.74800797871181, 48.91571760177612, 47.08222000939505, 36.99548537390572, 42.91674368722098, 35.95893226351057, 5.7421033552714755, 0.2249128355511597, 1.8245928244931358, 0.9115961641073227, 0.45111714037401335, 0.23917992998446735, 0.9116552237953458, 1.0104504653385706, 0.4742852843233517, 5.108028556619372, 25.855443784168788, 45.30993257250105, 50.69023541041783, 48.81149114881243, 48.21361950465611, 48.982458523341585, 47.24148661749703, 46.54230328968593, 47.64297785077776, 47.15068755831037, 46.13906805855887, 47.256685801914756, 47.86070660182408, 46.432806628090994, 44.70662743704659, 46.97772257668631, 46.41695431300572, 48.5470427104405, 48.775068691798616, 49.40897021974836, 45.07941913604736, 41.978632654462544, 37.009715284620015, 36.75532783780779, 35.43420778002058, 35.904500075748985, 35.081979274749756, 37.263223784310476, 37.30146319525582, 38.0656156539917, 40.23197364807129, 40.07596574510847, 40.193921838487896, 37.80663892201015, 36.852067606789724, 35.11661604472569, 35.72059168134417, 37.11358390535627, 38.35250677381243, 42.233975478581016, 40.488310064588276, 46.90184129987444, 44.62778970173427, 45.424657753535676, 46.44200951712472, 45.385921546391074, 43.203811986105784, 42.681376934051514, 43.03497423444475, 42.69553736277989, 42.12869637353079, 48.00974546160017, 46.470907075064524, 47.57304423195975, 46.83090714045933, 46.61986950465611, 45.415128299168174, 45.952449866703574, 45.79378080368042, 43.620808124542236, 42.84201928547451, 33.989781515938894, 35.59873417445591, 34.13993903568813, 35.99547978809902, 35.846774441855295, 35.21783740179879, 36.48484141486031, 36.24156413759504, 36.98246444974627, 33.1965126310076, 39.28224522726876, 38.89542511531285, 35.8540735244751, 34.807539326804026, 34.76959521429879, 35.97015013013567, 34.683559145246235, 35.72790118626186, 35.77440547943115, 35.014157908303396, 33.59055192129952, 34.46898487636021, 33.40182842527117, 34.75370815822056, 33.98312166758946, 34.98627478735787, 39.93314552307129, 41.337637015751426, 45.65910039629255, 46.72710452760969, 46.14348016466413, 47.220961638859336, 42.40716627665928, 42.10491616385323, 43.09247405188424, 45.75743130275181, 44.21463244301932, 42.42401565824236, 28.5250198500497, 10.364407232829503, 1.7460612441812242, 2.143078923225403, 11.380963427679879, 19.88927926336016, 5.933197055544172, 1.4949056868042265, 0.24853092964206422, 0.13173285126686096, 0.17339239083230495, 1.320859826036862, 2.7346635333129337, 22.13427870614188, 39.97038091932024, 37.53618376595633, 48.168407576424734, 28.436972277505056, 3.051958450249263, 0.1743861325085163, 0.08928729673581463, 0.07941041886806488, 0.11929229167955262, 0.16386375070682593, 0.12349293913160052, 0.16853044315108232, 0.21415995540363447, 0.16082016830997808, 0.2806368182812418, 0.11190764579389777, 0.11284515727311373, 0.07683896792254277, 0.11709352609302316, 0.19332895747252873, 0.13313592597842216, 0.14673374061073574, 0.09241691737302712], [0.017751083376684358, 0.010372540913522243, 0.04469350712107761, 0.025568622729874084, 0.03946755932910102, 0.04767113930678793, 0.05064819473773241, 0.05417223421058484, 0.03208816869716559, 0.03341031453705259, 0.046147644985467196, 0.02382479451729783, 0.030671027954667807, 0.02307386659750981, 0.026035970509318367, 0.011105475780953254, 0.035800403250115256, 0.01267931146347629, 0.08328916930726596, 0.037762417790613005, 0.06338234285690955, 0.01466800006372588, 0.03317016403057745, 0.02045001239249749, 1.2904499492474963, 22.33621767589024, 37.67891713551113, 30.39918177468436, 26.762392146246775, 30.482862404414586, 7.099543384143284, 0.07555579713412694, 0.6019192412495613, 0.09435783286711999, 0.058191644959151745, 0.03985360164993575, 0.14192769064434937, 1.2725346705743243, 0.7968301624059677, 0.08549893394644771, 7.54728182724544, 28.386226109095983, 42.98161901746477, 46.25362300872803, 47.08037873676845, 44.61709295000349, 46.35010916846139, 43.367032119206016, 44.28135599408831, 44.071381432669504, 45.8093968800136, 45.75437062127249, 46.02829640252249, 43.951893261500764, 44.88179152352469, 44.1822121483939, 42.7355694089617, 44.68393462044852, 46.82734966278076, 45.58639097213745, 41.909379959106445, 37.22413321903774, 35.73311928340367, 32.291426386152, 32.68776900427682, 33.55054766791207, 33.63339103971209, 32.32626812798636, 32.36875983646938, 34.690444810049875, 39.02031898498535, 40.19431093760899, 39.778600215911865, 37.21272775105068, 34.555642809186665, 32.20197180339268, 33.77971315383911, 32.698333740234375, 34.45489392961775, 37.08784430367606, 40.72685214451381, 43.13214826583862, 46.331404617854524, 41.63531173978533, 41.99222680500576, 40.98280988420759, 44.5429869379316, 45.96004772186279, 43.183551039014546, 41.20488820757185, 39.274765491485596, 45.32966545649937, 44.378648144858225, 45.10570069721767, 43.84343188149588, 45.222506863730295, 46.60766499383109, 44.569608960832866, 44.20727777481079, 45.193459919520784, 43.510161536080496, 40.12460313524519, 31.90761831828526, 32.852493422372, 32.53050000326974, 32.895613942827495, 32.56515761784145, 32.29091221945626, 32.92100960867745, 33.737183230263845, 31.78436769757952, 34.00385856628418, 33.44764484677996, 34.29931681496756, 34.37774460656302, 32.886748041425435, 32.02861772264753, 31.71312086922782, 31.407952513013566, 32.986416476113455, 32.13586664199829, 31.51570517676217, 30.446492058890207, 31.34763867514474, 30.938240391867502, 31.045034204210552, 32.88749497277396, 32.94471338817051, 36.66763462339129, 37.61228738512312, 41.81309182303292, 41.41687427248274, 42.30128615243094, 45.73277562005179, 41.77417148862566, 42.9739134652274, 41.28488629204886, 39.13060079302107, 26.857127359935216, 13.747372218540736, 3.438244636569704, 0.6626157728689057, 1.2655073276587894, 1.464823135307857, 4.288435118538993, 2.4020083206040517, 0.6203963469181741, 0.11158667158867631, 0.03380176817466106, 0.18379041073577745, 0.11855001508125237, 3.704944508416312, 23.62648252078465, 22.451394489833287, 25.879503658839635, 35.80842385973249, 8.82021004813058, 0.2746612860688141, 0.061825254266815524, 0.06726093044770615, 0.025567872948678474, 0.05295586519475494, 0.018662057351320982, 0.042166649496981075, 0.03089612516175423, 0.049751751590520144, 0.03982113374929343, 0.056438330827014785, 0.025655381913696016, 0.08116970410836594, 0.0007362703441426025, 0.035255641410393376, 0.02703284701731588, 0.048127956222742796, 0.040856147318014076, 0.04022109621603574, 0.04922104221103447, 0.04416108104799475, 0.02739520846599979, 0.027638230871941363, 0.016294803037973385, 0.02505034750460514, 0.022539505003286258, 0.00563010063654344, 0.03307828360370227, 0.04898613338757839, 0.027149778957079564, 0.0425125361154122, 0.0365909304735916, 0.05545376294425555, 0.0196607387624681, 0.015297327722821916, 0.06292598055941717, 0.015350976094071354, 0.06021635274269751, 0.06847089409296002, 0.04709420133648174, 0.04513623086469514, 0.029716261329927614, 0.07644761606518712, 2.9833673536777496, 30.662153720855713, 43.56446518216814, 31.9543171610151, 32.343697684151785, 34.501575401851106, 7.399114966392517, 0.022434652683192065, 0.5274966518793787, 0.7529072878616196, 0.032772389839270284, 0.010319269129208155, 0.12400798792285578, 0.3689296133816242, 1.3583249471017291, 0.3395073578826019, 8.575466700962611, 31.715934889657156, 46.68909788131714, 46.97240720476423, 47.20030117034912, 45.407429695129395, 46.24077926363264, 44.74023239953177, 45.605585370744976, 45.29841593333653, 45.46788944516863, 46.557773453848704, 46.609318665095735, 44.742997782570974, 45.08450174331665, 45.10197993687221, 44.69848414829799, 45.902808461870464, 45.56577566691807, 46.05514424187796, 44.270721776144846, 40.20436498097011, 35.84134789875576, 34.15285226276943, 34.81254550388881, 34.88502563749041, 33.712940965379985, 34.214708600725444, 33.88805294036865, 36.29433223179409, 40.60198259353638, 42.64351619992937, 41.125247955322266, 38.67739411762783, 35.18438877378191, 34.66077600206648, 34.143413134983604, 34.09993478230068, 35.57405764716012, 37.92924683434622, 41.906687532152446, 43.39213943481445, 46.342973368508474, 42.267264298030305, 42.62684052331107, 41.75532797404698, 44.08548280170986, 45.354425362178254, 42.18337174824306, 42.79278087615967, 41.486255509512766, 47.180359840393066, 46.73533814293997, 45.47183602196829, 45.98292466572353, 45.465148380824495, 47.87994268962315, 47.568291664123535, 44.730383328029085, 46.34056234359741, 44.51645871571132, 39.15875489371163, 33.52803203037807, 34.9074752671378, 33.247634002140586, 34.85114622116089, 34.64263078144619, 33.193319933755056, 34.14863123212542, 34.80345378603254, 33.63455138887678, 35.21085793631417, 34.52822174344744, 34.99308402197701, 34.8669707434518, 34.272812911442344, 33.349737780434744, 33.48992810930525, 33.072469915662495, 33.76153319222586, 32.440427030835835, 33.69962126868111, 32.3574412209647, 32.998860699789866, 33.0117461340768, 32.058838912418906, 33.93401527404785, 35.55103131702968, 37.938630376543315, 40.106232098170686, 42.119712352752686, 43.37554018838065, 43.762777192252024, 46.624875681740896, 41.926006998334614, 43.4158536366054, 42.53511387961251, 40.582239287240164, 29.94734389441354, 15.806583779198782, 5.328900064740862, 2.2414662837982178, 2.784829310008458, 9.380382503782, 5.048235399382455, 1.6403134614229202, 0.49963220421757015, 0.2314107311623437, 0.14726164085524424, 0.11877418948071343, 0.4271824689848082, 3.4951234587601254, 29.794229916163854, 26.81395820208958, 29.19226230893816, 42.24780239377703, 12.51997641154698, 0.1175077852926084, 0.052127767487296035, 0.1248768927263362, 0.021958612870158892, 0.04022252792492509, 0.008750031369605234, 0.02158592751116625, 0.034855495739196024, 0.009332842908666601, 0.04987832212022372, 0.03094118327966758, 0.01879128095294748, 0.020347765646874905, 0.06693534898970808, 0.02396422837461744, 0.01610780048317143, 0.008168010323840593, 0.01927884907594749, 0.008334549110648888, 0.15441387492631162, 0.06430735572108201, 0.14664462182138646, 0.10744899218635899, 0.10997851645307881, 0.13663886301219463, 0.08788916175918919, 0.15991768959377492, 0.14586559576647623, 0.15379396533327444, 0.08887982288641588, 0.11240405522819076, 0.0818609209465129, 0.1685290996517454, 0.16738660952874593, 0.08451147550450903, 0.32538584992289543, 0.11775690263935498, 0.25157768758279936, 0.07710323017090559, 0.1345316589410816, 0.1421341145677226, 0.08130431867071561, 0.1312962682651622, 3.114061666386468, 33.698130880083355, 48.784080505371094, 39.44572244371687, 36.23663439069475, 40.84585394178118, 11.533536314964294, 0.1898629463144711, 2.0351358354091644, 1.0581202102558953, 0.17133157141506672, 0.13522508101803915, 0.6099330655166081, 3.2013349490506307, 3.197439180953162, 0.3678417588983263, 9.063500353268214, 31.35049091066633, 44.87943261010306, 46.111820697784424, 48.22064413343157, 45.572115898132324, 47.16389608383179, 45.23824453353882, 46.434727805001394, 45.923218795231406, 47.66407952989851, 47.91557305199759, 49.02883080073765, 44.64786999566214, 46.59806605747768, 45.862557547433035, 46.08642850603376, 47.05046326773507, 48.4651894569397, 48.80455337251936, 45.741648469652446, 43.33413239887783, 39.553020000457764, 35.77834858213152, 37.398790087018696, 36.87467009680611, 36.3424346106393, 35.06013413837978, 36.09139619554792, 38.45235586166382, 42.534895011356895, 44.875124726976665, 43.62605748857771, 40.522377082279746, 37.47650221415928, 36.397780486515586, 35.987343447549, 35.87763486589704, 37.111176354544504, 40.22998298917498, 44.16075611114502, 46.115784645080566, 49.813532556806294, 43.177898679460796, 44.35835245677403, 42.30481583731515, 44.916407448904856, 46.69159575871059, 42.43814482007708, 43.60471262250628, 42.77372891562325, 47.46000051498413, 48.25892523356846, 47.63737760271345, 47.02523783275059, 47.54550852094378, 50.79465293884277, 49.270895617348806, 47.59725522994995, 48.16821302686419, 45.618276255471365, 41.96776219776699, 36.36277893611363, 35.6211907523019, 35.67156171798706, 35.71994897297451, 36.411020278930664, 34.89698001316616, 35.15968792779105, 36.78531973702567, 34.694276741572786, 37.28024687085833, 36.183991364070344, 37.81809650148664, 39.41954163142613, 35.48779576165335, 36.1588944707598, 34.41590411322457, 34.05590404782976, 36.063836165836875, 34.748608180454795, 35.546959672655376, 33.435235364096506, 35.36659485953194, 33.66452244349888, 33.895591735839844, 35.35626983642578, 37.26887961796352, 39.31689589364188, 40.99323913029262, 43.79727847235543, 45.990981101989746, 45.11722428458077, 49.551304067884175, 42.833313192640034, 44.47303942271641, 43.35391392026629, 41.3179076058524, 28.76777080127171, 15.744932413101196, 4.87630135672433, 1.6398592229400362, 3.0935497156211307, 6.577394511018481, 10.847342644418989, 6.818014970847538, 2.494778496878488, 0.2740373324070658, 0.4167754245655877, 0.36456562897988726, 0.7311164342931339, 7.535622750009809, 34.72636004856655, 30.065105438232422, 36.4658658845084, 46.81749364307949, 15.173423971448626, 0.31930357058133396, 0.15537653969866888, 0.23143901250192098, 0.08778221785490002, 0.24440402537584305, 0.08134961088321038, 0.17631490901112556, 0.09517546756459133, 0.16383457370102406, 0.0926699498668313, 0.1940204660807337, 0.09466456462230001, 0.2056289246039731, 0.0795863155009491, 0.13700745680502482, 0.08414198604545423, 0.10329872595944575, 0.16950883636517183, 0.11246225996209042], [0.027647355471604636, 0.007326015371030995, 0.03695837414956518, 0.04776793232719813, 0.11472936081034796, 0.04906927767608847, 0.07034576777368784, 0.030761782013412033, 0.03877586751644101, 0.03100614282967789, 0.021836773425872837, 0.012311148540382939, 0.05820599597479616, 0.0030776770851973978, 0.019002498726227453, 0.04693477953385029, 0.010438878737789179, 0.009144009157483066, 0.028826959763786623, 0.045587612715150626, 0.01623689685948193, 0.04763051202254636, 0.012256087119957166, 0.06580980188612427, 0.0815860056983573, 8.399542655263629, 31.715681280408585, 28.644494124821254, 24.834426845823014, 35.83360065732683, 15.459802661623273, 1.2645869084766932, 0.9437914022377559, 0.04743424237572721, 0.017276987566479614, 0.023538883609165038, 0.0416510002022343, 0.09963498291160379, 0.8022738045879773, 0.6534882283636502, 1.3128917621714729, 15.41500415120806, 34.3210438319615, 45.30331093924386, 51.02968617847988, 46.703810691833496, 46.54927928107125, 45.6334684916905, 46.0802446092878, 45.2460994720459, 44.09579740251814, 45.00887754985264, 45.69560275759016, 45.37086827414376, 45.24274696622576, 45.117974690028596, 44.73273181915283, 44.28395462036133, 45.30879306793213, 44.594295910426546, 41.91866970062256, 35.83347906385149, 34.03576816831316, 33.217551776341026, 34.28815800803048, 33.32014887673514, 33.08777679715838, 34.795661381312776, 35.20267295837402, 35.665186745779856, 41.373618262154714, 42.24772596359253, 41.330629757472444, 39.20929609026228, 37.266437326158794, 33.216530391148154, 33.200427940913606, 31.726450988224574, 32.733029569898335, 33.62794712611607, 37.85082251685006, 42.26445722579956, 45.41192865371704, 46.12241322653634, 47.14813756942749, 44.91821050643921, 45.48368270056588, 45.75387035097395, 43.836414200919016, 40.13138805116926, 37.371021611349924, 44.59452520098005, 42.764453070504324, 45.5640629359654, 46.712805134909495, 44.63857330594744, 48.02123430797032, 46.718516554151265, 45.444321155548096, 43.982670307159424, 46.31482969011579, 43.83211326599121, 36.237502915518625, 31.573986666543142, 32.67546721867153, 32.1042731830052, 32.83710663659232, 31.097399302891322, 31.981026036398752, 33.49451739447457, 36.19641474315098, 36.254487786974224, 36.04047284807478, 35.145134925842285, 33.39757265363421, 34.03133521761213, 32.213022913251606, 32.703426769801546, 32.57459674562727, 31.99915041242327, 31.865564346313477, 32.315442834581646, 30.364562375204905, 31.1022595678057, 30.325054918016704, 32.06966767992292, 29.604794229779923, 31.425861494881765, 32.11348302023751, 36.16334131785801, 38.74066093989781, 40.074461460113525, 43.17308357783726, 43.70523221152169, 41.419872420174734, 40.71666261128017, 39.694707666124614, 28.814898695264542, 16.184960092817033, 6.484644310814994, 1.6660555601119995, 1.9168809694903237, 2.2556974972997392, 12.494217702320643, 2.9213446932179585, 1.8481739248548235, 0.366021737988506, 0.05282125063240528, 0.1089451415464282, 0.14475920370646886, 0.1278768860335861, 10.806499396051679, 26.609672478267125, 28.572316237858363, 34.99896567208426, 27.92332669666835, 3.4796997606754303, 0.12072056718170643, 0.05560697954414146, 0.052253442350775, 0.032776993699371815, 0.013196669818301286, 0.009559318390009659, 0.016168522581990277, 0.04844666412100196, 0.03195034805685282, 0.015074103272386959, 0.07524005443389926, 0.07187482608216149, 0.0384187240020505, 0.06082927342504263, 0.0031848945239159676, 0.01315028261992016, 0.033553658452417166, 0.04296031155224357, 0.03755164106509515, 0.020877411422718848, 0.05420265632814594, 0.015686077398381064, 0.04230045660265854, 0.09266416196312223, 0.02340135982792292, 0.042232253655259094, 0.044145800439374785, 0.035458686229373725, 0.04246626681249056, 0.03483470203354955, 0.01394394806785775, 0.04803515638091734, 0.07196889139179673, 0.05091552735705461, 0.040639212887201986, 0.11964289072368826, 0.0355918894388846, 0.004506772766554994, 0.009194436183731471, 0.0053847427978845576, 0.04087898002139159, 0.030351258149104457, 0.015158390892403466, 0.12655223639948027, 12.155486072812762, 39.35293272563389, 33.62006092071533, 27.35175919532776, 41.0130032811846, 17.470993484769547, 1.4653886535337992, 1.7218672909906931, 0.030804156525326625, 0.042014990134962966, 0.026052143391487852, 0.037193985256765566, 0.06034549831279686, 0.8343793675303459, 1.1008538029023578, 1.1785360745021274, 18.418736457824707, 35.21150759288243, 46.44151619502476, 50.29088422230312, 46.02743135179792, 46.805709498269216, 44.881402424403596, 45.943490164620535, 46.29535041536604, 46.76961013248989, 46.5299528666905, 47.98838669913155, 45.44714559827532, 47.22034672328404, 45.601881980895996, 44.47611052649361, 45.1695442199707, 46.11957836151123, 45.95978021621704, 43.86534649985177, 38.72769212722778, 36.56713935307094, 34.19887365613665, 35.01755905151367, 35.113124574933735, 35.054297651563374, 35.58954170772007, 36.318605763571604, 37.20273624147688, 42.37842157908848, 44.276242119925364, 44.64071682521275, 40.350110394614084, 37.65446989876883, 35.27910314287458, 34.022000312805176, 32.876037393297466, 34.245075702667236, 35.17076335634504, 40.52426699229649, 43.46825347627912, 48.197093214307515, 47.75926290239607, 48.20161301749093, 46.64753723144531, 47.51145887374878, 47.06026370184762, 44.40636798313686, 40.754259313855854, 38.927897521427695, 44.4722056388855, 45.52210276467459, 46.827797821589876, 46.71459777014596, 46.24143239430019, 48.32541254588536, 47.41391658782959, 46.44831848144531, 45.58984770093645, 47.039040429251536, 44.70099244798933, 36.87430184228079, 33.11161954062325, 34.88185378483364, 33.70917156764439, 33.9281336239406, 32.54992716653006, 34.01135914666312, 34.93750538144793, 37.4007112639291, 38.57432106563023, 36.69835260936192, 37.04935475758144, 34.333717346191406, 35.27505929129464, 33.40333271026611, 33.87117576599121, 33.384433610098704, 33.45179986953735, 33.552739824567524, 34.005859647478374, 31.75841964994158, 33.21253865105765, 32.1457712990897, 31.904908520834788, 31.647279739379883, 32.31539419719151, 33.588377135140554, 38.8883900642395, 40.11354160308838, 43.17276396070208, 44.495141642434255, 44.21039056777954, 40.967256341661724, 41.99723645618984, 41.318557262420654, 33.26551171711513, 17.74687692097255, 8.076827492032733, 2.8198126213891164, 3.6796860694885254, 4.983713558741978, 10.406702654702322, 6.5645729133061, 4.286137001855033, 0.8353428329740251, 0.08153677119740418, 0.09385275854063885, 0.23672556025641306, 0.03592160317514624, 12.239271794046674, 33.46323660441807, 28.776697499411448, 35.97308226994106, 33.85046666009085, 5.1962094477244785, 0.10314120405486651, 0.08126488900078194, 0.07738932089081832, 0.021711012049178992, 0.054774240657155, 0.023463025090417693, 0.0428521089654948, 0.04005795264882701, 0.03909148808036532, 0.0046494309374663445, 0.018418373373736228, 0.0767125907753195, 0.0486480092097606, 0.03212637361139059, 0.020240460422688296, 0.06529298890382051, 0.04657301858865789, 0.011709538188629916, 0.030121570652616874, 0.09500089407499347, 0.11186059617570468, 0.10258678666182927, 0.11977037388299193, 0.21856691821345262, 0.2243324438376086, 0.134559872427157, 0.12598268767552717, 0.1577092752392803, 0.08187358919531107, 0.11935019785804407, 0.09827407915145159, 0.16754983791283198, 0.17903314743723187, 0.0932673660240003, 0.1215924032564674, 0.1886653591479574, 0.11500829298581396, 0.06478705283786569, 0.09157998513962541, 0.09821429343095847, 0.14654228516987391, 0.13413909929139273, 0.13377657160162926, 0.2289929480424949, 14.494275774274554, 44.75278432028634, 39.64418036597115, 34.917025566101074, 46.78397900717599, 22.698158025741577, 3.2057985152517046, 3.526524756635938, 0.22376577210213455, 0.19976723699697427, 0.24818930083087512, 0.15175665036908217, 1.4942981536899294, 3.265692855630602, 2.001632056065968, 1.8577906659671237, 18.010832037244523, 37.30489560535976, 48.08860751560756, 52.521346296582905, 46.1086870602199, 47.41984340122768, 45.76358393260411, 48.482775347573416, 49.02381420135498, 47.50242274148123, 48.14700365066528, 49.824972765786306, 47.53679895401001, 47.49615894045149, 47.32435430799212, 46.18728508268084, 47.6533966745649, 47.77561548777989, 47.17061499186924, 46.24671302522932, 39.369785581316265, 37.51794474465506, 36.50262532915388, 37.67483159473964, 36.57306964056832, 35.84275838306972, 38.40327031271798, 39.01023367473057, 38.79678153991699, 44.4955724307469, 45.93745218004499, 45.443942478724885, 42.805496079581125, 40.375134331839426, 38.13595921652657, 35.9980263028826, 35.840024266924175, 36.6593975339617, 35.935252802712576, 41.73791926247733, 46.36421748570034, 51.12021425792149, 48.50866780962263, 49.256898471287315, 48.83631706237793, 49.56556524549212, 48.77198716572353, 46.87430558885847, 43.13661595753261, 39.62743173326765, 45.530569144657676, 45.601513726370676, 48.14939035688128, 49.640828132629395, 47.222035135541645, 51.838303634098594, 48.41881717954363, 46.6782100541251, 47.08978312356131, 50.173980781010215, 46.028358936309814, 39.46051863261631, 34.61890615735735, 36.88111455099923, 34.80971758706229, 35.68219941002982, 33.75303554534912, 35.312325954437256, 36.16548136302403, 39.19461107254028, 40.361439432416645, 39.14353486469814, 38.55634954997471, 35.40212447302682, 38.08775608880179, 34.34842668260847, 35.581200395311626, 35.73928580965315, 35.604181562151226, 34.728757177080425, 35.87372997828892, 34.02475527354649, 35.110439096178325, 34.684580530439106, 35.12190362385341, 32.617776325770784, 33.50146559306553, 34.91228689466204, 40.160778931209016, 42.1921056338719, 44.57866593769619, 46.59112133298601, 45.19221271787371, 41.961123194013325, 42.468053340911865, 41.360833576747346, 32.69540160042899, 18.665117842810496, 8.575198326792036, 3.1390406574521745, 4.257901259831019, 8.607305083956037, 23.26203908239092, 7.852959139006479, 7.048954418727329, 1.4697897945131575, 0.14763853991670267, 0.31793700105377604, 0.4604222710643496, 0.3927558277334486, 17.529545954295568, 37.274868965148926, 37.353296756744385, 44.25071096420288, 38.421575341905864, 6.4577804037502835, 0.24768438935279846, 0.19393791551036493, 0.16355815210512706, 0.1200321934052876, 0.16351452230342797, 0.06686681016747441, 0.13462514749595098, 0.15747748767691, 0.10456747787871531, 0.12125169725290366, 0.1929138840309211, 0.12815849163702556, 0.16045736920620712, 0.1268583642584937, 0.10280116980097123, 0.10222605708986521, 0.10023110306688718, 0.15253171377948352, 0.1934829442096608], [0.0374804797050144, 0.08410573191940784, 0.06735994906297751, 0.05636188707181385, 0.04327712294512561, 0.02495514225613858, 0.046286191658249924, 0.036836068212453804, 0.0702589899301529, 0.052535085273640494, 0.04762855784169265, 0.050618773459323814, 0.018828459582956772, 0.0307910166946905, 0.06590055594486849, 0.05609762482345104, 0.04976212978363037, 0.08363192448658602, 0.016700763754280548, 0.023023907760424272, 0.03170161747506686, 0.01663788900311504, 0.014715188781597784, 0.07274058248315539, 0.02411583684650915, 1.0290435190711702, 20.737336431230815, 39.30182177679879, 30.696967669895717, 30.660142217363628, 27.77831605502537, 2.7453183787209645, 0.7712174196328435, 0.012424784496293535, 0.03891027173293488, 0.04832139637853418, 0.07465921488723584, 0.25615234353712624, 0.5278478073222297, 0.26423128002456253, 0.0401578601449728, 2.99839500444276, 16.197642292295182, 35.187623160226, 44.19402061189924, 46.606608867645264, 45.631790501730784, 45.44657932009016, 46.05179868425642, 45.16910300936018, 45.669331618717735, 48.591208934783936, 45.55581195013863, 46.865484850747244, 47.38572774614607, 45.312989779881065, 42.7022944859096, 44.26142508643014, 46.47339105606079, 43.688257762363975, 40.714519092014854, 35.85672773633684, 32.946749210357666, 34.00319153921944, 33.710008825574604, 33.86536359786987, 34.14506333214896, 33.80995866230556, 33.122771399361746, 37.67308064869472, 42.505354745047434, 43.79089307785034, 44.57752990722656, 41.07106590270996, 36.770964758736746, 32.608833994184224, 33.088753019060405, 32.51027727127075, 32.12804644448416, 33.003001826150076, 35.33379936218262, 40.117182459150044, 44.635012354169575, 43.50657973970686, 45.152302265167236, 43.760282788957866, 45.431001458849224, 44.755303042275564, 45.034571988242014, 43.09872048241751, 37.646361351013184, 42.463328565870015, 41.92606953212193, 44.682551928928916, 44.882833753313335, 46.68214620862688, 44.86652980531965, 45.25525024959019, 39.645684650966096, 39.90764910834176, 45.60824653080532, 41.588685853140696, 33.14343534197126, 32.03353704724993, 32.50063664572579, 31.960431575775146, 32.52910688945225, 33.10316358293806, 35.29667861121041, 38.88128900527954, 38.30746855054583, 36.95117323739188, 35.62477254867554, 34.82025105612618, 34.64601455415998, 33.62397970472063, 32.561155455453054, 32.79323918478829, 31.37399319240025, 31.189713069370814, 32.48423889705113, 31.634644440242223, 33.32277876990182, 32.66953693117414, 31.74804946354457, 32.113222462790354, 31.241741180419922, 32.36381619317191, 33.65272092819214, 34.83160441262381, 37.21651451928275, 39.53270346777779, 41.4930682182312, 42.9241053036281, 42.92644337245396, 42.06443248476301, 31.27054146357945, 17.165849447250366, 5.407890660422189, 0.947197430900165, 0.8356204352208546, 4.523534366062709, 3.2168081530502866, 10.97516257422311, 8.438903331756592, 1.939504738364901, 0.2160362268665007, 0.05301398850445237, 0.02925875230825373, 0.05012230634955423, 0.5453572677714484, 15.693159648350306, 33.58100857053484, 22.87961891719273, 34.156288146972656, 17.913037879126414, 0.34132170623966623, 0.035846852364816835, 0.029976262378373315, 0.01928032997862569, 0.028447497536295226, 0.016307211747126918, 0.029384372888931205, 0.03136073165972318, 0.011855023730147098, 0.02375671370620174, 0.03935991653374263, 0.03824595880827733, 0.035277483452643664, 0.030723536387085915, 0.03746635599860123, 0.027002267140362943, 0.03382404108664819, 0.03646769494350467, 0.02626104057500405, 0.017208591236599853, 0.024107489169442227, 0.0372030063798385, 0.018445360407765423, 0.045840838591435125, 0.054309895395168235, 0.05742958906505789, 0.03793819567986897, 0.024878282898238728, 0.03486065260533776, 0.017129887959786823, 0.04777165748445051, 0.020668210594781806, 0.03600128014971103, 0.08936421546552863, 0.022753318173012564, 0.07375923996525151, 0.023575383704155684, 0.06689872845475163, 0.042835518784288845, 0.05673886416479945, 0.020185801034261073, 0.04443820153496095, 0.07316779491624661, 0.025884509618793215, 0.02466266991437546, 2.3000485002994537, 27.268797704151698, 41.69887038639614, 32.42062813895089, 35.394766330718994, 31.31952973774501, 3.0590030550956726, 0.8988511051450456, 0.11534271575510502, 0.0173922859331859, 0.04293284445468869, 0.0556105248896139, 0.1740319100873811, 1.07767330961568, 1.8984000640256065, 0.2884863556495735, 4.495786300727299, 18.35415642602103, 36.98332255227225, 47.55165767669678, 47.71643073218209, 46.85966573442732, 45.220592635018484, 44.71393346786499, 45.54805081231253, 46.74987377439226, 48.622868401663645, 47.41986077172415, 47.715482303074424, 48.19060359682356, 46.070128032139365, 43.83833190373012, 45.51475504466465, 47.3894693510873, 46.418719155447825, 42.56336178098406, 38.05742372785296, 34.85666309084211, 34.94904286520821, 35.527501242501394, 35.81796721049717, 35.474542072841096, 34.56039537702288, 35.517256123679026, 38.47752571105957, 44.73917279924665, 46.42676516941616, 45.921752725328716, 43.05970982142857, 38.02455527441842, 35.41625363486153, 34.56765277045113, 34.87302262442452, 32.98681599753243, 34.39476769311087, 38.070979663303916, 41.9998767716544, 46.92283180781773, 45.428017207554404, 46.757857254573274, 46.95538411821638, 46.997250488826204, 46.96902690614973, 46.603496074676514, 44.49609701974051, 39.550758361816406, 42.40966067995344, 42.715763568878174, 45.48211588178362, 45.62722206115723, 47.815102100372314, 46.21572058541434, 45.814375264304026, 41.953688621520996, 42.50001505443028, 46.31369365964617, 44.63498803547451, 35.119374479566304, 34.526057379586355, 33.41801077978951, 34.113306590488975, 33.23245913641793, 34.034545285361155, 37.0340895652771, 40.022940567561555, 40.35512351989746, 38.12448079245431, 37.13291379383632, 36.885940074920654, 36.270927224840435, 34.45795808519636, 33.623878955841064, 33.6027112688337, 32.28837265287127, 32.64995690754482, 34.362621852329795, 33.535598618643625, 34.35041386740548, 34.22220918110439, 32.88336426871163, 33.351943833487375, 32.74050235748291, 33.43572521209717, 35.382308210645405, 35.795701708112446, 38.33301707676479, 41.33724444253104, 42.85846567153931, 44.571957451956614, 42.812597138541086, 40.74072422300066, 33.457056181771414, 20.51926895550319, 8.251757945333209, 1.834723515169961, 2.1074394413403104, 4.897175482341221, 4.433455313955035, 9.87173044681549, 4.61289210830416, 4.825585152421679, 2.287977090903691, 0.05546402917908771, 0.08955963355089937, 0.010957338863850703, 0.622672153370721, 18.52795692852565, 34.92217418125698, 25.03364733287266, 39.52114166532244, 22.316837412970408, 0.7392887643405369, 0.05390254707474794, 0.023357616371608207, 0.03733122914231249, 0.05117679726598518, 0.020727992922599827, 0.02807902418343084, 0.028172360067921023, 0.050001425335982015, 0.04290712458480682, 0.049416925092892985, 0.04653894256002136, 0.024046607614893998, 0.03370338059695704, 0.016748354504151002, 0.04169776822839465, 0.029800769473825182, 0.02247192970077906, 0.02891398187992828, 0.04006239366052406, 0.10163664086056606, 0.1317842435091734, 0.11318832635879517, 0.12773794920316764, 0.14019364012139185, 0.1988418237971408, 0.13361147046089172, 0.07219743555677788, 0.2640540195362908, 0.16310471429356507, 0.12757443583437375, 0.1403188162616321, 0.238554483545678, 0.14769734176141874, 0.11212179823113338, 0.13575785314398153, 0.1468956254954849, 0.18538118180419716, 0.1218810249119997, 0.16670723312667438, 0.15296717041305133, 0.1549586435513837, 0.10603706937815462, 0.14627528164003575, 0.13410999013909272, 2.387299418449402, 33.118303707667756, 49.8224436214992, 41.857122557503835, 38.03903879438128, 39.53036887305123, 5.307929532868521, 1.7039570063352585, 0.27427834804568973, 0.1437913549265691, 0.30241586534040316, 0.2978760860860348, 0.4165625274181366, 3.6693640862192427, 1.6292862359966551, 0.3873363956809044, 4.630111915724618, 17.407733610698156, 37.94231292179653, 46.83523934228079, 47.82046263558524, 46.29986327035086, 46.32316058022635, 47.71224791663033, 46.299394266945974, 47.8217237336295, 51.058847767966135, 49.098823479243684, 48.67958654676165, 50.30863339560372, 47.75806086403983, 43.937308992658345, 46.82948623384748, 49.023595333099365, 47.241962569100515, 44.38646139417376, 39.627195494515554, 35.340855257851736, 36.348517758505686, 37.46317556926182, 37.28363411767142, 38.092143876211985, 36.28756816046578, 37.297283853803364, 40.74591105324881, 46.40123748779297, 49.59781183515276, 49.00457116535732, 46.19133240836007, 40.331673349652974, 36.18520035062517, 36.15280090059553, 36.05613061359951, 34.42163290296282, 35.76403529303414, 40.133125100817, 43.57463387080601, 49.74329669134957, 47.366251945495605, 48.37163543701172, 47.8513890675136, 49.58787243706839, 49.04886245727539, 47.69104201453072, 46.14943477085659, 40.53334133965628, 43.32041318075997, 43.26517847606114, 45.225095067705425, 46.35914877482823, 49.20304645810808, 47.40594352994646, 45.85398347037179, 40.92752654211861, 42.077495098114014, 48.84787539073399, 45.54061276572091, 36.70408139910017, 36.83230345589774, 34.367245878492085, 34.484364713941304, 35.66961622238159, 36.52132640566145, 39.127227442605154, 42.477812085832866, 42.831246103559224, 39.84612628391811, 38.48831278937203, 38.58282218660627, 38.45132752827236, 36.44818271909441, 35.06467131205967, 35.314410414014546, 33.943030561719624, 35.31356273378645, 35.76978145326887, 34.54898643493652, 36.154777663094656, 35.161428451538086, 34.62660823549543, 36.0260831287929, 34.851639543260845, 35.341376372746055, 37.24278218405587, 37.43339211600167, 39.73901285443987, 43.65790803091866, 43.906247070857454, 46.64116225923811, 42.536236013684956, 41.75601584570748, 32.23232153483799, 20.46890320096697, 7.082349632467542, 1.6046337016991206, 1.978680853332792, 9.316242814064026, 8.760798607553754, 19.74166304724557, 15.18400434085301, 7.246096960135868, 1.9999584087303706, 0.18895680350916727, 0.18229893648198672, 0.12049036739127976, 0.9842269867658615, 22.186230387006486, 44.67051417487008, 31.150914328438894, 45.68378039768764, 25.15041354724339, 0.875870481133461, 0.1781113033315965, 0.06044311236057963, 0.1258816130991493, 0.14291219067360672, 0.1043665229475924, 0.08156289479562215, 0.08168984191226107, 0.18768260973904813, 0.15464206625308308, 0.20879456187997544, 0.12400972497250352, 0.23964573070406914, 0.14393448510340281, 0.10093118835772787, 0.13552470851157392, 0.20072440563568048, 0.10295432194003037, 0.1453690981226308, 0.1587325467595032], [0.009237935367439474, 0.03167666434975607, 0.0527375499451799, 0.02756085922010243, 0.050470649264752865, 0.01138456741214863, 0.032652309497020075, 0.03713303924139057, 0.04041538114792534, 0.02857379156297871, 0.051361915189772844, 0.06627307845545666, 0.02954674631889377, 0.051961865675236495, 0.08865446783602238, 0.02360017058838691, 0.00842963985633105, 0.02547623000905982, 0.02928774950227567, 0.0520036837884358, 0.026267233903386762, 0.020731762184628418, 0.01814752763935498, 0.014451661047392657, 0.008758518994519753, 0.08050047859017338, 7.7675788061959405, 30.248051507132395, 32.55746248790196, 29.275067465645925, 34.467143603733604, 10.080796531268529, 0.38729245375309673, 0.4260886976761477, 0.03941722899409277, 0.15634649193712644, 0.04923994619665401, 0.03166637775887336, 0.7326545374734061, 1.4474121438605445, 0.337678000330925, 1.1507184186152049, 4.510882564953395, 17.81153164591108, 35.95480850764683, 46.08037315096174, 45.190638950892854, 44.276283809116904, 45.7875656400408, 45.3688394001552, 46.91802018029349, 48.140743323734824, 48.29897117614746, 46.35032108851841, 46.93049914496285, 45.49100610188076, 44.074417795453755, 47.714575563158306, 45.34886680330549, 43.664574827466694, 37.89085456303188, 34.714815616607666, 33.47644860403878, 35.45147752761841, 33.191826071058, 32.72085632596697, 34.938224520002095, 34.87555871691023, 33.79860530580793, 37.7278185571943, 43.691964626312256, 45.283654485430034, 45.77709470476423, 44.23522342954363, 38.227699756622314, 34.63288245882307, 33.06826625551496, 32.49766976492745, 32.69198656082153, 33.51822117396763, 32.9364971433367, 35.36576107570103, 37.89441204071045, 42.47337218693325, 42.94036756243025, 41.5704642023359, 42.86178691046578, 44.23603984287807, 46.280262402125764, 44.31035777500698, 39.62573637281145, 40.24276420048305, 41.620772634233745, 42.29725967134748, 42.58060720988682, 44.37834242412022, 43.94429888044085, 44.1066643851144, 45.35867765971592, 48.34670182636806, 42.55271366664341, 40.87436587469918, 33.86429010118757, 32.04361193520682, 31.838275296347483, 31.55602557318551, 32.675484589168, 35.713712964739116, 40.79009117398943, 41.78378779547555, 39.53814390727452, 37.55223757880074, 35.01403284072876, 34.19235624585833, 33.13906145095825, 32.716788155691965, 31.721020971025737, 31.80116149357387, 31.548111574990408, 31.647978033338273, 33.26095369883946, 33.908977440425325, 35.38656050818307, 35.136831828526084, 34.497521127973286, 34.29112488882882, 33.07611424582345, 32.436560358319966, 34.84435435703823, 35.0311393056597, 37.86748429707119, 41.63401242664882, 42.56036015919277, 43.95275136402675, 42.777755396706716, 36.18249750137329, 19.72025043623788, 6.171199781554086, 1.5072005242109299, 0.5356911835925919, 1.739624281014715, 3.057893297501973, 2.523700373513358, 5.522214582988194, 3.9735436269215176, 3.443815354790006, 2.024965843984059, 0.29384211397596766, 0.2090485646788563, 0.042274855476404936, 1.8164520327533995, 24.46275554384504, 27.719296319144114, 28.66030475071498, 33.1932122366769, 5.020969799586704, 0.07024915795773268, 0.043994266606335125, 0.07802556282175438, 0.03057686086477978, 0.014720194673697864, 0.03572274152455585, 0.032956713877086125, 0.0355564461621855, 0.09179132844188384, 0.04469234682619572, 0.016398362748857056, 0.016100426503856267, 0.02062068769841322, 0.021648822618382316, 0.08030375093221664, 0.05327667994424701, 0.060651320831051896, 0.0581320288724133, 0.019622131816244552, 0.05328587409374969, 0.049488273050103865, 0.04800806587029781, 0.051504767167248895, 0.030953186564147472, 0.0488106642317559, 0.04711181949824095, 0.05259724925937397, 0.05154636136389204, 0.024072524259931276, 0.024121797776647975, 0.019839646394497583, 0.05076955072581768, 0.027251574476914744, 0.07621949259191751, 0.012289573671296239, 0.031074379703828266, 0.06335153736706291, 0.020626609612788473, 0.0418502045130091, 0.03918218107095786, 0.07620627472975425, 0.04464768225859318, 0.0512553546577692, 0.015683241122003113, 0.006701279697673661, 0.08215906923370701, 12.555636303765432, 37.80510337012154, 37.83737775257656, 30.58956241607666, 39.947288581303184, 12.074608172689166, 0.792817197740078, 0.33252333264265743, 0.0060306792978995615, 0.1349478858922209, 0.04349581817431109, 0.15151378911520752, 2.5079511957509175, 2.2698770335742404, 1.1717601695231028, 2.156382769346237, 5.949258250849588, 22.260593482426234, 36.574824060712544, 48.50289038249424, 45.478766850062776, 46.407383169446675, 45.768444197518484, 45.21421071461269, 46.73764494487217, 49.158421652657644, 47.76565177100045, 48.554762159075054, 47.693779604775564, 47.00866290501186, 43.477171489170615, 47.910698890686035, 47.694901738848, 46.41531801223755, 39.214514187404085, 37.25154038837978, 34.619302204677034, 37.564813818250386, 35.20178706305367, 35.11858933312552, 35.83007444654192, 35.817119530269075, 35.71124635423933, 39.35299178532192, 45.323057719639365, 46.9542932510376, 47.02989312580654, 46.2050655228751, 39.935396739414756, 36.72892120906285, 35.43621233531407, 34.243300437927246, 33.43817445210048, 34.56431416102818, 33.67564303534371, 37.00832564490182, 41.87815128053938, 44.62363815307617, 43.77560356685093, 43.586001123700825, 43.62537656511579, 46.952344281332834, 46.991566862378804, 46.11556230272566, 40.568363734654014, 41.148013728005544, 42.20031145640782, 42.76857335226876, 43.268468448093955, 45.064720221928184, 44.154346397944856, 43.81670910971505, 44.76887287412371, 49.77687038694109, 46.04928691046578, 42.86928054264614, 35.2958448273795, 33.41844156810215, 33.8832552092416, 34.34535905293056, 33.80224963596889, 37.03369699205671, 42.071415424346924, 42.613614627293174, 40.66451290675572, 39.262793745313374, 36.286171572549, 36.678247996738975, 34.22154910223824, 34.68572003500802, 32.14449283054897, 33.095398971012656, 33.826637813023154, 34.07482399259295, 35.10780920301165, 35.43983929497855, 36.265465940747944, 36.42467696326119, 36.561024938310894, 35.4851519720895, 34.14967693601336, 33.63724381583077, 35.43930080958775, 37.286437715802876, 39.20043018886021, 41.602714266095845, 43.95239700589861, 45.26004103251866, 44.00552640642439, 39.05787052427019, 22.73820744241987, 8.715388655662537, 2.343981525727681, 1.984947259937014, 3.201734470469611, 6.297497621604374, 5.698460417134421, 6.805896443980081, 5.790916187422616, 5.979744340692248, 4.786341292517526, 0.733366782111781, 0.31988393515348434, 0.042876230885407755, 1.6319215574434824, 28.1764269896916, 33.18734795706612, 27.703061853136333, 37.59156438282558, 8.597349183900015, 0.11227643636188336, 0.04403908045164176, 0.0196990166192076, 0.03364945402634995, 0.022229367002312626, 0.026736946377371038, 0.020617391714560132, 0.040829694630312066, 0.07615565601736307, 0.06754805254084723, 0.020061274591301168, 0.011225981903927667, 0.02637368078077478, 0.05438759444015367, 0.05083477490448526, 0.06871379605893578, 0.0346393857284316, 0.01568687637336552, 0.010141245289040464, 0.08182928085859333, 0.15403842792979308, 0.15644762079630578, 0.15064568498304912, 0.12496067823043891, 0.13089738466909953, 0.0917759867651122, 0.10992876626551151, 0.13538965290146215, 0.1500334156943219, 0.08237908421350376, 0.129904728648918, 0.18707196893436567, 0.1649384144693613, 0.14049599532570156, 0.20162716933659144, 0.1010850936706577, 0.1125070500586714, 0.1425747009260314, 0.18109425183917793, 0.11865976133516856, 0.1404628013925893, 0.10432440627898489, 0.16588410229555198, 0.11183656925069434, 0.11867877388639109, 0.21202430714453968, 13.749551347323827, 43.59175770623343, 44.86606427601406, 38.874038560049875, 45.35135425840105, 17.21398135593959, 1.6882400725569044, 1.6032984533480235, 0.16386742836662702, 0.323449826666287, 0.1832376896802868, 0.3412373779075486, 2.9111592854772295, 4.69547665970666, 1.9610951798302787, 3.4940551732267653, 6.761826625892094, 20.630443607057842, 38.38161277770996, 48.050208296094624, 45.3091265814645, 46.043391363961355, 46.12643275942121, 46.01085294995989, 48.76973942347935, 50.52021299089704, 51.05008956364223, 48.83903728212629, 49.40418291091919, 47.349451201302664, 44.71406200953892, 50.63040099825178, 48.39483199800764, 47.887339047023225, 40.793061528887065, 38.729974610464915, 36.16724273136684, 40.4364834512983, 37.208333015441895, 36.48255545752389, 37.6076842035566, 37.508258955819265, 37.82931089401245, 40.69805186135428, 46.96769980021885, 48.21175043923514, 48.732570035117014, 49.41156884602138, 41.88027048110962, 39.11641604559762, 37.631370612553184, 36.641874177115305, 35.182186194828574, 36.663413592747276, 35.79383264269148, 38.58582380839756, 42.79554278509957, 47.010483333042686, 45.90150567463466, 43.92361409323556, 46.57416078022548, 47.923893519810264, 50.72551836286272, 47.59077256066458, 42.8391045161656, 42.07916266577584, 43.00722312927246, 42.931129932403564, 43.4693478175572, 45.54396179744175, 45.13351781027657, 44.243245124816895, 46.78222458703177, 52.099951948438374, 47.15224395479475, 44.73715782165527, 36.24064350128174, 34.7311612537929, 34.01107774462019, 35.38081087384905, 35.66070515768868, 38.694816725594656, 43.53223248890468, 45.27701200757708, 43.76382289613996, 41.44640759059361, 37.92170803887503, 37.778866972242085, 36.502132007053916, 36.4005389213562, 35.36812693732125, 34.68813105991909, 33.91713115147182, 35.47403832844326, 37.579992158072336, 37.558292933872764, 38.827106952667236, 38.86534636361258, 38.32794141769409, 37.99378170285906, 36.76041739327567, 35.34460033689226, 37.41195344924927, 40.680358273642405, 40.721029554094585, 44.51627458844866, 47.034537996564595, 47.185880184173584, 43.646679741995676, 38.66397367204939, 22.824570076806204, 7.975765075002398, 2.43059755223138, 2.1543699630669186, 4.745836768831525, 8.619389738355364, 8.166436672210693, 11.511432358196803, 9.96583684853145, 10.001781616892133, 5.330866839204516, 0.37888250074216295, 0.7056915642959731, 0.14798210933804512, 3.1899572738579343, 32.755812713078086, 37.05101537704468, 35.64911903653826, 44.57075888769967, 9.126932195254735, 0.20954684008445057, 0.178748325577804, 0.15568767514611992, 0.1370010514344488, 0.0988687268857445, 0.097733184961336, 0.1645694135555199, 0.18921808020344802, 0.15438906768602983, 0.18635444529354572, 0.12596090670142854, 0.17939541728368827, 0.12415483647159167, 0.13203387654253415, 0.16753158532083035, 0.14479094557464123, 0.15416758028524263, 0.21369963724698338, 0.08108099244002785, 0.13458980939217977], [0.048036045261791775, 0.03968523336308343, 0.027282561474878873, 0.04249142689098205, 0.031782909362976036, 0.059825977975768704, 0.03646387479134968, 0.05755295351679836, 0.038570454610245566, 0.016446462399991493, 0.07519915912832532, 0.04932696831279567, 0.060859760003430505, 0.0649602489013757, 0.027200155093201568, 0.021916173897417526, 0.028370546576167856, 0.015958417606140887, 0.10065117731158223, 0.06863400034074273, 0.038905823935887644, 0.023102343015904938, 0.007347275569502796, 0.04545595995815737, 0.05084060012762036, 0.041947954267795594, 0.6456700393131801, 20.3280371597835, 35.1852434022086, 27.32589626312256, 28.828546694346837, 22.5088369846344, 2.9718502802508215, 0.22999137161033495, 0.03104083293250629, 0.02976022700646094, 0.1044245512623872, 0.0764366780806865, 1.4838110421385085, 3.049828175987516, 0.8426463125007493, 1.3209080291645867, 0.76863936654159, 3.5296835814203535, 14.402683751923696, 31.55098465510777, 45.54982607705252, 45.17163562774658, 45.64780609948294, 45.356263160705566, 45.47653647831508, 46.49687944139753, 47.79331602369036, 46.925941126687185, 46.30855894088745, 47.84048039572579, 45.38976737431118, 46.468044417245046, 46.0707221031189, 40.51291363579886, 36.809593268803184, 35.76552220753261, 36.82536220550537, 34.59629324504307, 32.03237322398594, 34.444971902029856, 33.2352488381522, 33.87173162187849, 34.33016334261213, 38.73179851259504, 46.734490462711875, 45.39607286453247, 48.070531776973176, 44.60013934544155, 41.762700012751985, 35.91875777925764, 32.535335949489046, 33.517213685171946, 33.93963984080723, 32.99287135260445, 32.336829389844624, 32.10270636422293, 33.65410361971174, 33.747765336717876, 34.53955078125, 35.101263999938965, 38.630441665649414, 43.667687620435444, 46.252455711364746, 46.47888708114624, 40.04893030439104, 42.853292737688335, 42.727624143872944, 45.98282044274466, 45.81643540518624, 46.498519216264995, 47.902013642447336, 46.766622407095774, 44.66882923671177, 43.23252889088222, 43.50910888399397, 36.23987919943673, 30.359194891793386, 32.01229987825666, 32.32517726080758, 32.01979003633772, 32.03059101104736, 39.183240345546174, 43.07331092017037, 45.05577094214303, 42.937431948525564, 39.551863125392366, 33.25226845060076, 33.58913101468767, 33.02149098260062, 32.46598250525338, 31.214167254311697, 31.904908520834788, 34.242272104535786, 34.928448404584614, 34.76195566994803, 36.06598315920149, 36.73353828702654, 37.6802407673427, 37.06423085076468, 36.24837337221418, 37.28426987784249, 34.904418059757774, 35.896071910858154, 35.34518051147461, 37.975289072309224, 41.308173179626465, 43.00211272920881, 41.47073323386056, 41.85420083999634, 25.176434550966533, 9.73398848942348, 2.159124485083989, 0.7456941891993795, 2.2800830687795366, 1.821297749876976, 6.341987805707114, 3.6974339400018965, 6.399339539664132, 3.7752867681639533, 4.948589546339853, 5.1334585291998724, 0.873569596026625, 0.17350700896765503, 0.05595095269382, 5.128265619277954, 29.32383339745658, 23.016840628215245, 30.043020589011057, 21.07985656602042, 0.8828753509691784, 0.12776570128543036, 0.04308195931038686, 0.05977611243724823, 0.07036848512611218, 0.056371997243591716, 0.03238844419164317, 0.02157160363692258, 0.02880793364186372, 0.019575513067788312, 0.030730837423886572, 0.03712638959820781, 0.08053613560540335, 0.006763429688622377, 0.051015523062752824, 0.025657753393586193, 0.06056026143154927, 0.03430694428139499, 0.0068719291344418055, 0.021353429183363914, 0.06539084722420999, 0.019719749256702404, 0.05193819498111095, 0.05105769062148673, 0.0864353801256844, 0.04541555319779685, 0.06654137798718043, 0.007928198236706001, 0.020577819552272558, 0.02964861478124346, 0.03200910918946777, 0.056069716678134034, 0.06143274889992816, 0.030729358217545917, 0.033810979287539206, 0.04917158379352518, 0.024050068143489103, 0.055391086664583, 0.05052849776776774, 0.012197811139880546, 0.03989426964627845, 0.060038176232150624, 0.07929146489394562, 0.0396246028664921, 0.028133775174085583, 0.03715549875050783, 0.01086787402164191, 1.088629424571991, 24.627328838620866, 39.4739043372018, 31.371530055999756, 35.097053391592844, 27.124395029885427, 2.922724562031882, 0.4792185596057347, 0.1775138396769762, 0.03002260292747191, 0.08871817548892327, 0.22732031850942544, 2.135331464665277, 2.624536539827074, 1.435504559959684, 3.0668988142694746, 3.0628243471894945, 6.713163614273071, 18.071366480418614, 35.89432791301182, 46.435071740831646, 45.61888769694737, 46.56119196755545, 46.15189790725708, 44.91612604686192, 47.569618770054404, 49.185366766793386, 48.18607684544155, 48.73537710734776, 47.794771671295166, 46.7390832219805, 46.904144627707346, 48.20028938565935, 42.38654402324131, 38.31506987980434, 38.095513752528596, 37.13550547191075, 36.76881429127285, 34.327971185956685, 35.56015430177961, 34.104218346732004, 35.55264677320208, 35.877214499882285, 40.586717401232036, 48.57289348329817, 47.59631027494158, 49.10441330501011, 46.780970437186106, 43.27949523925781, 38.14469657625471, 34.51047951834542, 35.36130380630493, 35.37329639707293, 35.00037963049752, 33.86315754481724, 34.90697152273995, 33.73574842725481, 35.474799156188965, 35.61258888244629, 37.49181604385376, 39.91450350625174, 46.22484009606497, 48.345614433288574, 47.14265891483852, 41.89141539164952, 42.93775156566075, 42.6438045501709, 44.95986148289272, 45.77290494101388, 46.91254152570452, 48.283942222595215, 46.995607239859446, 46.556470666612896, 45.241131510053364, 45.00685909816197, 38.471216746738975, 32.2157917703901, 33.52892139979771, 35.092345987047466, 33.00867503029959, 33.92425305502755, 39.94773326601301, 44.88963256563459, 45.87310143879482, 44.48766885484968, 39.879290035792756, 36.08696671894619, 35.366358620779856, 33.76130042757307, 32.84562860216413, 31.906899179731095, 32.43281875337873, 34.627740791865754, 35.29452466964722, 37.627514362335205, 38.00793170928955, 38.11634792600359, 37.93101167678833, 38.577798639025005, 38.84570380619594, 38.26027985981533, 35.32537119729178, 37.70457683290754, 36.86522402082171, 39.582518577575684, 42.050261633736746, 44.34671769823347, 42.47372654506138, 43.040070738111226, 26.96842360496521, 12.936963864735194, 3.5348193858351027, 2.481663554906845, 3.0096380582877567, 4.728604367801121, 6.562998712062836, 7.209206368241992, 8.74034137385232, 6.19405197245734, 4.636517286300659, 3.276953931365694, 2.043957442045212, 0.1889840941876173, 0.021235623629763722, 5.918083420821598, 34.905467237745015, 24.473672900881084, 34.605885233197895, 26.502908195768082, 1.49335178732872, 0.046057810341673236, 0.09646382236054965, 0.09893136923866612, 0.03794009218524609, 0.025181660994089076, 0.04328947228246501, 0.05564357293769717, 0.029838987958750555, 0.013734565731803221, 0.06500129348465375, 0.03155000561050006, 0.07006686952497278, 0.029133708482342105, 0.026101496636069248, 0.0279025813298566, 0.032214376210634194, 0.03372114125107016, 0.028079809587714926, 0.018845684194405164, 0.055729465293032784, 0.1277302410453558, 0.1338521061199052, 0.16528912207909993, 0.20256417191454343, 0.12432174251547881, 0.14618296016539845, 0.15522781839328154, 0.15059024867202553, 0.14050113862114294, 0.15079546480306558, 0.1426318742867027, 0.11371708834277731, 0.11738739960959979, 0.12149990536272526, 0.13099391306085245, 0.138613562764866, 0.16196210203426226, 0.13785707764327526, 0.15220209503812449, 0.14662373651351246, 0.166266334642257, 0.08413191658577748, 0.1477593191500221, 0.10059745769415583, 0.15187296484197887, 0.1180020844829934, 1.7376550095421928, 30.346239975520543, 45.66884871891567, 37.56206233160836, 39.01018156324114, 32.37732349123274, 7.238530806132725, 1.5663067868777683, 0.24323309106486185, 0.1327208253954138, 0.37008051733885494, 0.6198654611195836, 4.848577610083988, 5.476651770727975, 4.024782248905726, 2.655672720500401, 1.6354222553116935, 4.005302105631147, 17.622591018676758, 34.189969539642334, 46.47728552137102, 45.79608760561262, 46.09597880499703, 45.3926682472229, 46.51869331087385, 47.790772983006065, 51.08289548328945, 49.31711850847517, 50.14138330732073, 49.7578774860927, 46.96978773389544, 48.65136991228376, 50.722572326660156, 43.863501753125874, 39.394302300044465, 40.11566775185721, 40.0198312486921, 38.268749713897705, 34.94142416545323, 37.42701019559588, 35.69913216999599, 36.57873589651925, 38.359038080487935, 42.57622984477452, 50.788180691855295, 48.44021415710449, 50.60476909364973, 48.31066846847534, 44.928334031786235, 38.608137948172434, 36.16275419507708, 37.89116028376988, 36.3321339062282, 35.87865277699062, 35.50365155083792, 35.87274333408901, 35.66916111537388, 37.10528775623867, 36.763366903577534, 38.56507996150425, 41.16583585739136, 48.73332044056484, 49.63202823911394, 49.97963619232178, 42.84050110408238, 42.21482971736363, 43.83941582271031, 47.001770292009624, 47.21428789411272, 48.103775433131624, 51.86447054999215, 48.56783519472395, 47.16673789705549, 45.71521404811314, 46.71549408776419, 38.40472943442208, 33.705926758902415, 34.779069083077566, 36.462746143341064, 35.533480167388916, 35.77326944896153, 42.57942949022566, 46.898808411189485, 48.30368552889143, 45.8288448878697, 42.63746779305594, 37.15027734211513, 35.41462080819266, 35.40206888743809, 34.946541513715474, 34.33185175486973, 33.723599502018516, 36.55779750006539, 37.92364658628191, 39.31308480671474, 39.30168628692627, 39.81686741965157, 39.95354543413435, 40.39132363455636, 40.431386947631836, 40.204820087977815, 37.89642007010323, 39.74542604173933, 38.944302218300955, 41.73780114310128, 44.081664766584126, 46.835086481911794, 42.665427344185964, 43.897422858646934, 26.977192231587, 13.094771351133074, 2.8943274915218353, 2.476734459400177, 3.4418086281844547, 6.343266708510263, 12.381962605885096, 10.797881892749242, 17.313873870032175, 10.926406196185521, 14.064479316983904, 8.705689838954381, 3.430865432534899, 0.9861615172454289, 0.2865668072232178, 7.794096606118338, 37.764630113329204, 31.372662612370082, 40.68283878053938, 31.247688838413783, 1.697427328143801, 0.19951856748334, 0.17880161771816866, 0.23465032875537872, 0.1219283188027995, 0.1751312589538949, 0.1328329329511949, 0.09769548555569989, 0.11814954371324607, 0.12571330927312374, 0.16465197769658907, 0.11549098922738008, 0.16647832255278314, 0.10660249939454453, 0.10035824017333132, 0.18565469927021436, 0.11005514341273478, 0.09627485035785607, 0.10190347475664956, 0.057137452598128996, 0.1659617538430861], [0.11706694109099251, 0.028314370661973953, 0.02789926329361541, 0.06951762935412781, 0.07831328202571188, 0.02661808909449194, 0.027047121697770696, 0.0176177970466337, 0.041214189891304286, 0.025435377111924545, 0.039328147524169514, 0.02388945551189993, 0.017202209614749466, 0.04394469962322286, 0.04189040092751384, 0.042318176544670544, 0.031212641391903162, 0.023285840937335576, 0.046920245313750844, 0.04463626929957952, 0.039636317773589065, 0.04912475130653807, 0.037013420302953036, 0.012784946643348252, 0.008083678599047874, 0.02939895460648196, 0.0684141210679497, 7.553631612232753, 29.35705620901925, 26.621578216552734, 25.373612267630442, 22.964706557137625, 7.453127656664167, 2.6791595859186987, 0.0556411980651319, 0.12611136505646364, 0.03234663286379405, 0.07053713500499725, 2.529157532112939, 2.0238819250038693, 1.1709787143128259, 3.9531115804399763, 1.7324793615511485, 1.6078801389251436, 2.396037212439946, 15.61413778577532, 29.772266660417827, 44.650256701878135, 46.23084333964756, 47.80902937480381, 46.09618725095476, 48.840162890298025, 46.149003982543945, 47.18759986332485, 45.841059820992605, 45.00494834354946, 46.36930356706892, 45.0581819670541, 41.70799337114607, 39.81551946912493, 39.8631910596575, 43.50804928370884, 42.61409405299595, 43.79142114094326, 37.94198635646275, 34.1341164452689, 32.96025998251778, 33.940185274396626, 33.983309268951416, 40.80799668175833, 46.91117967878069, 47.283533641270225, 47.82698004586356, 44.2645309312003, 43.52584709439959, 37.9492506980896, 32.52855798176357, 33.86756270272391, 33.13367312295096, 33.49805750165667, 32.00828034537179, 33.6688164302281, 32.92419188363211, 33.89930902208601, 35.45230088915144, 37.62119844981602, 40.87171513693673, 43.92949226924351, 43.66229234422956, 46.17250973837716, 41.145567962101524, 44.185877323150635, 46.50142008917672, 47.02604034968785, 45.154084478105815, 45.127493722098215, 42.22162505558559, 46.32017632893154, 44.834227630070274, 44.5724264553615, 36.401595047542024, 33.39405339104788, 32.011288915361675, 32.613044602530344, 31.75027288709368, 32.99359049115862, 33.95555121558053, 42.08114637647356, 43.69132539204189, 45.79903016771589, 43.9189692224775, 43.38406910215105, 35.46052755628313, 33.40298530033657, 33.94305488041469, 32.9154371534075, 32.046592712402344, 33.655187538691926, 35.02083512714931, 37.764237540108816, 37.31032909665789, 38.08113098144531, 37.99914223807198, 39.171998160226, 37.019088404519216, 40.428298473358154, 38.79774039132254, 37.588086809430806, 37.323565414973665, 38.81101492473057, 39.59169019971575, 41.247539724622456, 41.07474497386387, 42.20189911978585, 35.671558243887766, 14.923370463507515, 4.460192850657871, 0.9958767273596355, 1.752628268940108, 2.4406730915818895, 3.869974647249494, 6.543793456895011, 5.8351592762129645, 4.281314083508082, 4.572964285101209, 2.6424639778477803, 3.9046600546155656, 2.618880054780415, 0.08219252101012639, 0.2734549050884587, 11.991228052548, 32.15746859141758, 24.05533923421587, 35.54739046096802, 9.49861913067954, 0.21380713076463767, 0.03397095748888595, 0.025810132002724067, 0.00452811608556658, 0.0656344820080059, 0.025253623025491834, 0.07523018853472811, 0.015779438727934445, 0.015203700068273714, 0.04189437375004802, 0.037117358297109604, 0.015801221398370605, 0.02722751532149102, 0.03650351480713912, 0.055768355527626615, 0.051112360187939236, 0.02751769421489111, 0.043369379958936145, 0.032070686242410114, 0.01172443712130189, 0.037259915111852546, 0.030115175460066115, 0.014481606494103159, 0.038466119673103094, 0.02428329420009894, 0.06759341260684387, 0.02044778340496123, 0.05662889738700219, 0.0214439270951386, 0.07283854258379766, 0.021245654073676894, 0.03217261238023639, 0.06896110171718256, 0.014104573421978524, 0.012070093885995448, 0.03552097235141056, 0.05255219792681081, 0.014064805332704313, 0.0403117315311517, 0.006484812607855669, 0.01881331468134054, 0.017820846954626695, 0.061316916186894686, 0.05874152973826442, 0.05753842608204909, 0.050851836667529175, 0.05540350724809936, 0.2105198593011924, 11.378450785364423, 36.98293692725045, 30.97268956048148, 30.812814985002788, 28.628183228628977, 11.23559842790876, 2.8166737726756503, 0.054516522879047055, 0.03747182838352663, 0.15565317842577184, 0.1830590721219778, 2.9825689622334073, 2.0809633306094577, 1.3441633241517204, 4.743275489125933, 6.32221714087895, 4.0274620822497775, 4.008348456450871, 17.441289935793193, 32.03714663641793, 45.22173908778599, 46.626178468976704, 48.14988020488194, 46.16529056004116, 49.071263449532644, 47.44205331802368, 48.23208086831229, 45.67227765492031, 45.71346310206822, 46.48232991354806, 47.55118172509329, 44.13490533828735, 40.72552851268223, 41.99052102225167, 44.436314719063894, 44.115610190800254, 43.56463541303362, 38.036516598292756, 36.04718828201294, 35.6140375818525, 36.32600212097168, 35.50287682669503, 41.913229261125835, 47.71179975782122, 48.9531649180821, 50.33850370134626, 47.028156076158794, 45.60439028058733, 40.07778269904, 34.35288742610386, 35.68918929781233, 34.96102155957903, 34.990971769605366, 34.28955112184797, 35.16702175140381, 33.82686710357666, 34.995627062661306, 36.91310058321272, 37.727088996342246, 41.959132535117014, 45.799606868198936, 46.10096066338675, 47.35273769923619, 41.46107176371983, 43.45292575018746, 46.96857874734061, 48.79526015690395, 46.739180496760774, 46.556401184626985, 43.95482540130615, 47.72175652640206, 46.10667903082711, 44.48873192923409, 39.380068915230886, 34.31685406821114, 33.36588886805943, 33.70823008673531, 33.19667591367449, 33.11800146102905, 35.27953393118722, 42.09742253167288, 44.767816747937886, 46.12693302971976, 45.62764242717198, 45.62648555210659, 35.730346952165874, 34.56425857543945, 33.78453172956194, 33.16980722972325, 33.939017977033345, 34.90036725997925, 35.947933265141074, 39.5396203994751, 38.05528020858765, 39.202132497514995, 38.942794459206716, 41.6002893447876, 40.71933766773769, 42.10683734076363, 40.18968343734741, 38.04442017418997, 38.85853018079485, 39.57667861665998, 41.39059965951102, 43.561234269823345, 41.69984313419887, 43.91473082133702, 36.82013716016497, 18.10906045777457, 5.9400749036243985, 2.2468698109899248, 3.1859108167035237, 4.819960151399885, 5.774693446499961, 7.776617544037955, 7.303103889737811, 8.317742381777082, 6.620016498225076, 5.160923455442701, 2.40019114954131, 2.4915727717535834, 0.14180201238819531, 0.2199563815125397, 13.540384513991219, 37.20679746355329, 26.043482882635935, 39.534044470105854, 13.06630892413003, 0.31743667647242546, 0.02099114067719451, 0.039071383087762764, 0.013673350846927081, 0.05360922317153641, 0.022724539806534137, 0.04339890641027263, 0.014885738558535064, 0.008742815997850682, 0.0064364733490427685, 0.021966025865237628, 0.0388726605368512, 0.02003135798232896, 0.00782684122012662, 0.0890074349673731, 0.008487812359817326, 0.053370124394340177, 0.031398115546575615, 0.03976664399462087, 0.02242797759494611, 0.010871319283199097, 0.21925659477710724, 0.19656239396759442, 0.1386782271521432, 0.09086804584200893, 0.23563995850937708, 0.12463560567370482, 0.14415939232068403, 0.1161001372550215, 0.12862161892865384, 0.10125484277627297, 0.10521809796669654, 0.1507937413241182, 0.1318895521440676, 0.09782119773860488, 0.10248236012245927, 0.10014105468456234, 0.10249606652983598, 0.11682527405875069, 0.16588355946753705, 0.1140624423112188, 0.08366243142102446, 0.1305608312998499, 0.14564747389938149, 0.14493854051189764, 0.09820404076682669, 0.07700457117919411, 0.2424962291760104, 11.626740319388253, 42.59281866891043, 36.92471102305821, 34.44700077601841, 33.420578139168875, 14.974427563803536, 5.685307042939322, 0.1216459260987384, 0.18714155948587827, 0.322462938193764, 0.5236478926880019, 5.813885194914682, 5.128019826752799, 3.3148418068885803, 7.738902722086225, 7.038411395890372, 3.2694327235221863, 3.575608568532126, 18.221214805330547, 31.899037293025426, 45.950737135750906, 46.65974521636963, 50.15542214257376, 47.5389528955732, 51.39657538277762, 48.43417617252895, 49.90930305208479, 47.24563469205584, 46.691665240696494, 48.48059708731515, 48.93465839113508, 45.50439528056553, 43.85949959073748, 44.63432795660836, 47.91347469602312, 46.47248431614467, 47.57386064529419, 42.109925815037315, 37.9533987726484, 36.45902190889631, 37.749059200286865, 37.57344348090035, 45.15860775538853, 48.79313400813511, 51.53447280611311, 50.88547631672451, 47.99055453709194, 48.304230962480815, 41.693131174360005, 35.41218546458653, 37.200366905757356, 37.13250732421875, 37.654185022626606, 34.82633420399257, 37.57530559812273, 35.81056390489851, 37.50744949068342, 38.788276944841655, 40.43085888453892, 44.491340977805, 46.649340288979666, 47.808928625924246, 49.30307967322213, 43.62382364273071, 43.48054831368582, 49.15785537447248, 51.11341197150094, 48.33242327826363, 48.19636712755476, 44.751881054469514, 51.64159318378994, 50.08440807887486, 47.903907026563374, 41.82490028653826, 36.521906580243794, 34.11431407928467, 34.84055716650826, 34.35014288766043, 35.45659834997994, 37.08146933146885, 44.63487686429705, 46.5590032849993, 48.34263365609305, 46.931583063943044, 47.89575678961617, 37.99122823987688, 35.26805550711495, 36.884064061301096, 34.85583625520979, 35.57539170128958, 36.89154379708426, 38.31952714920044, 40.954798221588135, 40.70106390544346, 41.566611426217214, 41.528813225882395, 41.83952971867153, 40.74649470193045, 43.83030326025826, 42.37435340881348, 40.35975449425833, 41.56612157821655, 41.53237417766026, 44.133255141122, 44.416067668369834, 44.93422263009207, 44.365227699279785, 37.659361430576865, 17.585739510399954, 5.664153252329145, 2.1117054181439534, 3.245736760752542, 6.406876163823264, 10.517493418284825, 14.670735699789864, 14.355857236044747, 13.060091154915945, 10.124881114278521, 8.862565398216248, 7.782401050840106, 6.170404647077833, 0.6710188048226493, 0.5356384207095418, 15.906165361404419, 43.41774354662214, 32.575743198394775, 47.72024529320853, 15.4028673853193, 0.484403055693422, 0.10316819617790834, 0.15441257213907583, 0.09096259969685759, 0.20609824013497147, 0.0770886145266039, 0.1485121130411114, 0.09920385533145495, 0.06449212080665997, 0.1581998560577631, 0.08702242826776845, 0.10062577296048403, 0.07874788370515619, 0.12164490829621043, 0.14884673937090806, 0.09603770236883845, 0.10129003838769027, 0.16742629025663647, 0.1203071086534432, 0.20008196868002415, 0.17648902109691075], [0.031624983730060716, 0.043100999003010135, 0.014472914460514272, 0.021013452604945217, 0.009367419356879379, 0.017577403856973563, 0.029657143966427872, 0.06493407780570642, 0.03612211366583194, 0.019883425473900776, 0.017076600908434818, 0.03620916631604944, 0.012479813686305923, 0.03874109938208546, 0.026017658545502594, 0.1160902442144496, 0.07170146038489682, 0.040606341258223565, 0.026619990688881705, 0.06002659363938229, 0.05012960399367979, 0.0018760011090697454, 0.0562935857368367, 0.06320572019155536, 0.054964322064604075, 0.025247689236753752, 0.0837814871753965, 0.8200883886643818, 17.060405322483607, 30.97534724644252, 23.98201142038618, 31.170873028891428, 13.319496938160487, 1.4790543488093784, 0.020080991122605543, 0.020563076682654873, 0.032685757880764346, 0.19523511161761625, 0.9327589656625475, 1.103484021765845, 0.5896291807293892, 5.207471174853189, 6.768593737057277, 2.9183680415153503, 0.1704351452312299, 2.641238055058888, 14.748941149030413, 33.04113701411656, 43.731982776096885, 45.553550311497276, 43.895213331495015, 47.48994377681187, 47.35966852733067, 45.804710320064, 44.05472312654768, 46.348427704402376, 42.91409294945853, 44.80243962151663, 42.88065821783883, 43.52521480832781, 44.405787808554514, 45.60571043831961, 44.2981914792742, 46.499412059783936, 43.706646169934956, 38.30924728938511, 32.67619330542428, 34.28295728138515, 32.69450528281075, 39.81171185629708, 46.046066420418875, 46.48983744212559, 44.58513123648507, 46.674183573041645, 47.301526001521516, 40.711545263017925, 34.79537650517055, 34.405634675707134, 33.637789249420166, 33.34710441316877, 33.13599034718105, 33.3154171534947, 33.048192909785676, 33.295423712049214, 35.39259154456002, 39.69803932734898, 41.66752011435372, 44.83353281021118, 44.702739919934956, 45.84621885844639, 39.984857491084504, 46.77890682220459, 46.18826477868216, 44.67136532919747, 43.312426226479666, 42.622372831617085, 43.542790276663645, 42.79585892813546, 39.81278187888009, 35.597900390625, 31.57826328277588, 31.747424125671387, 31.65289040974208, 33.65442671094622, 31.27362993785313, 32.40446662902832, 32.62028809956142, 41.38518353870937, 43.81129993711199, 43.81743172236851, 43.854823453085764, 43.506388664245605, 40.305259772709434, 32.085499150412424, 31.639508179255895, 30.911927563803538, 31.849131856645855, 35.60161420277187, 39.01381894520351, 39.87023305892944, 40.05006286076137, 40.025469711848665, 39.80598654065813, 42.8062082699367, 40.41506215504238, 40.98250763756888, 40.08479690551758, 40.98806619644165, 41.01352439607893, 38.10332005364554, 40.117439542497905, 42.75301286152431, 40.85299321583339, 40.11428853443691, 25.149850743157522, 9.503178017480032, 1.9077171640736716, 2.6680852430207387, 4.785843193531036, 3.712139802319663, 4.67168515920639, 4.02349031823022, 5.4842179247311185, 7.780901108469282, 4.423396059444972, 3.523341396025249, 0.9242782550198692, 1.375847001160894, 0.21273695890392574, 1.7754756829568317, 25.679178408214025, 29.819399765559606, 20.399565390178136, 28.808527197156632, 1.8990729536328996, 0.05931222518639905, 0.022889763083575026, 0.014063156492608999, 0.0668079743960074, 0.02189102738962642, 0.022664492850058844, 0.015045440256861704, 0.10653749573975801, 0.042545553629419634, 0.018609012876238142, 0.02906237748850669, 0.0486260687799326, 0.07175602138574634, 0.03715007725570883, 0.05573263065889478, 0.07397771467055593, 0.0625004983906235, 0.01831067629557635, 0.02090503627966557, 0.031599854185645065, 0.00454597597542618, 0.006516897560296846, 0.05542457576042839, 0.022993884282186627, 0.022639816227768148, 0.023711577556761246, 0.05439319235405751, 0.02986967809764402, 0.08694204222410917, 0.047749947756528854, 0.029075449465640953, 0.025318406156397293, 0.02827710042973714, 0.05216498174039381, 0.009791657262082611, 0.044639122539332936, 0.10081981361976691, 0.05232349769877536, 0.05539908998512796, 0.03860555861943534, 0.01974627997593156, 0.056835060074393234, 0.01626018587765949, 0.04465966857969761, 0.05218575169731464, 0.039360191340425184, 0.05273577218343105, 0.033256639926029105, 1.681621479136603, 24.401026010513306, 35.47124515260969, 25.04731617655073, 31.040604727608816, 14.593365771429879, 2.8821336201259067, 0.027317270237420286, 0.06698572342949254, 0.14788735870804104, 0.3265146607799189, 2.7417333253792355, 2.1529273433344702, 2.543540737458638, 5.361558335168021, 10.364660842078072, 7.820617880140032, 0.7550440760595458, 4.795073006834302, 16.639123882566178, 34.833261557987754, 46.95839616230556, 45.623772280556814, 45.889784063611714, 48.19457449231829, 48.479429789951865, 46.77593299320766, 45.579731123788015, 48.84784759793963, 44.675648893628804, 47.83016926901681, 44.911887645721436, 45.31784309659685, 46.571958201272146, 46.15984664644514, 46.83793871743338, 47.85207346507481, 46.76320389338902, 39.34805509022304, 33.86694778714861, 35.3245895249503, 34.51225825718471, 40.741318293980186, 48.00645201546805, 47.360102789742605, 47.87685421534947, 48.26577615737915, 47.92107949938093, 42.30605609076363, 35.84079204286848, 35.12546804973057, 34.7702761377607, 35.400297096797395, 34.53998156956264, 33.880396025521414, 34.27138505663191, 35.3103700365339, 36.04791784286499, 40.584289005824495, 44.58850458690098, 46.15365580150059, 47.17023631504604, 46.97239678246634, 41.572520869118826, 47.4481086730957, 47.84544835771833, 46.01959030968802, 45.281288623809814, 44.24320690972464, 45.65904828480312, 45.13336494990757, 41.77902133124215, 37.5294440133231, 33.54031644548689, 33.74073723384312, 33.111605644226074, 35.20973232814244, 32.762931142534526, 34.08851194381714, 35.265804290771484, 43.58090114593506, 47.28810903004238, 45.271651472364155, 46.304727009364534, 45.66252933229719, 41.437684127262656, 33.17974662780762, 34.71911655153547, 32.723889214651926, 34.28589289528983, 35.89087813241141, 40.60144410814558, 40.689248493739534, 41.36887959071568, 41.532224791390554, 41.53230469567435, 44.24717433112008, 42.195756912231445, 41.81722600119454, 41.47037887573242, 41.10288517815726, 41.90728160313198, 39.69101817267281, 42.02021414893014, 42.93233544485909, 43.35711703981672, 42.263116223471506, 26.87618453162057, 11.114079645701818, 2.6177292593887875, 2.742244452238083, 4.595993220806122, 5.173290814672198, 5.937447616032191, 7.5882570913859775, 7.657878909792219, 7.69224122592381, 8.16284097943987, 3.211953750678471, 1.4886140929801124, 1.3098792838198798, 0.23234477532761438, 1.6756723012242998, 30.69710315976824, 32.54738065174648, 23.315606219427927, 35.67568894795009, 3.331262137208666, 0.09917382337152958, 0.018444339212562357, 0.08198771200009755, 0.02247544451217566, 0.060637736559978554, 0.05615951739517706, 0.009485047643205948, 0.04568151517638138, 0.02119564265012741, 0.04950052060719047, 0.05999238868909223, 0.006515851344114968, 0.012340082969915653, 0.06107634838138308, 0.039459735820336, 0.04338884712862117, 0.01742359862795898, 0.012672508301745568, 0.005307990309250141, 0.032645890555743656, 0.0009692044716627736, 0.11925379160259451, 0.1065029108098575, 0.0664640317804047, 0.11182983139795916, 0.08259753856275763, 0.12067849801055022, 0.09554667371724333, 0.16187705445502484, 0.11601222625800542, 0.11609074633036341, 0.1057827001703637, 0.10326526739767619, 0.12053023810897555, 0.11875445768237114, 0.1423735695758036, 0.1945915347231286, 0.16989870901618684, 0.12990124097892217, 0.12010650656052999, 0.17437820721949848, 0.24798666313290596, 0.07167112986956324, 0.1460896616003343, 0.1831567675939628, 0.07974113683615412, 0.11435733363032341, 0.09199005777814559, 2.0424153762204305, 28.99242169516427, 42.29174974986485, 32.56722470692226, 41.688892773219514, 18.344394207000732, 3.0630197652748654, 0.2537522023277623, 0.23657329699822835, 0.6807613191860062, 0.37715793613876614, 3.195062679903848, 3.689540352140154, 3.1668775294508253, 11.054296476500374, 16.51538688795907, 10.574304495538984, 0.2843438722193241, 4.23648213488715, 16.164928436279297, 34.61811406271798, 46.35002926417759, 46.64268738882882, 45.42365721293858, 49.56090995243618, 48.98523432867867, 49.172033173697336, 47.090019362313406, 50.53591591971261, 44.89788007736206, 49.56690277372088, 46.669670718056814, 48.13275984355381, 47.51052434103829, 47.69374138968331, 47.32345451627459, 49.32106508527483, 47.519550051007954, 40.55109051295689, 36.59528303146362, 38.115990093776155, 35.43707391193935, 43.57673222678048, 49.96414518356323, 49.95976434435163, 47.695485387529644, 50.24222251347133, 50.8788685798645, 45.50499629974365, 37.872830935886924, 38.14903572627476, 36.491859095437185, 37.695043904440745, 36.15369374411446, 37.03358582087925, 35.48720169067383, 37.10889387130737, 38.402822153908865, 42.21271399089268, 45.446989263807026, 49.35493407930647, 48.23344618933541, 47.94788217544556, 42.21957186290196, 49.10061958857945, 49.90328938620431, 47.48364870888846, 46.75823940549578, 46.090837138039724, 46.16628415243966, 46.89614030293056, 43.30661058425903, 39.36041940961565, 35.01796204703194, 35.21203565597534, 34.847043309892925, 36.663886070251465, 34.419055121285574, 36.64836726869856, 36.24815450395857, 44.13497829437256, 47.671229226248606, 45.29603964941842, 46.73300354821341, 47.44889381953648, 44.113529205322266, 34.80947092601231, 35.262476103646414, 34.89620181492397, 34.696805885859895, 38.27179649897984, 43.56629255839756, 43.520149571555, 42.74741608755929, 43.38974230630057, 42.53960241590227, 45.926071030753, 43.899423939841135, 43.1668267250061, 43.01304224559239, 44.0365640095302, 45.63135623931885, 40.57233115604946, 45.2003664289202, 46.17311075755528, 45.400825432368684, 42.995814187186106, 29.10963085719517, 11.45751346860613, 3.0023183482033864, 5.244868550981794, 9.648225137165614, 8.03819637639182, 10.502261229923793, 10.973020792007446, 13.184635877609253, 18.8567213671548, 15.29711753981454, 10.289815715381078, 2.646029055118561, 3.7482126780918668, 0.6219865615878786, 3.024026257651193, 35.400144236428396, 37.74598462241036, 29.858010905129568, 38.61354712077549, 3.8845198324748447, 0.18120105325111321, 0.05598103554387178, 0.12857262870030745, 0.16385530973119394, 0.1784627301884549, 0.10097522528043815, 0.07697176401104246, 0.1505290719547442, 0.15385900970016206, 0.1163958835282496, 0.19485095223145826, 0.10589718259871006, 0.07778052347046988, 0.24037165460841997, 0.13680286492620194, 0.14865622030837194, 0.20259352533945016, 0.1192009337246418, 0.05173427824463163, 0.11589141988328525, 0.10410954137997967], [0.016475084703415632, 0.02630018356389233, 0.02732944654832993, 0.08104920985975436, 0.032495092933199236, 0.008947572421415575, 0.027630012116527984, 0.022481670070971762, 0.03856881594817553, 0.046361807600728104, 0.05477889540738293, 0.01799205830320716, 0.05486819740118725, 0.013863504348721887, 0.01022131581391607, 0.057870887885136266, 0.06739272230437823, 0.016240503273106048, 0.03596277668007782, 0.01960132284356015, 0.030553356411733797, 0.066857772081026, 0.029416029940226247, 0.016093861677550843, 0.01568923767523042, 0.02950751342411552, 0.06514763991747584, 0.14481693346585545, 8.437770775386266, 31.11550283432007, 28.459425381251744, 26.47673954282488, 20.04329650742667, 4.134143854890551, 0.08613202747489725, 0.1145209012819188, 0.037636101711541414, 0.5672951734491757, 3.833612552710942, 1.7344129149402892, 0.2955436355301312, 7.1642714994294305, 9.69414838722774, 6.843163975647517, 2.401052074772971, 0.5515492526548249, 4.807155055659158, 18.24508707863944, 35.298099517822266, 44.50995520183018, 47.5369587625776, 45.56477165222168, 46.37471968787057, 45.13470942633492, 45.46278599330357, 46.08545923233032, 46.56865085874285, 45.01471751076834, 46.768362930842805, 44.01680333273751, 46.82758937563215, 46.93646764755249, 46.46512964793614, 44.9843156678336, 47.89679207120623, 41.76315859385899, 35.764796120779856, 35.27895723070417, 32.89811529432024, 37.260788440704346, 45.563652992248535, 46.14943824495588, 46.0906252179827, 45.12171629496983, 46.933212416512625, 42.369788442339214, 36.97549888065883, 33.56276260103498, 34.407764298575266, 32.37902579988752, 34.23623411996024, 33.57277495520455, 35.606849670410156, 38.56459011350359, 41.798792430332725, 43.616166727883474, 45.182186467306956, 43.461927141462056, 45.2050564629691, 43.52224792752947, 40.10862227848598, 46.179232120513916, 44.23602942058018, 44.575115408216206, 41.231767313820974, 39.29266405105591, 39.57766873495919, 36.46758903775896, 34.979246684483115, 35.04142958777291, 33.133541107177734, 33.39654432024275, 33.24901669366019, 32.49436937059675, 32.036920819963726, 32.275911058698384, 35.03369624274117, 41.441953795296804, 46.50463015692574, 44.45527982711792, 42.28173392159598, 45.77055992398943, 42.54545627321516, 35.86667060852051, 31.04616676058088, 32.32564626421247, 31.516969748905726, 36.25203159877232, 41.62600115367344, 43.625136852264404, 42.413867814200266, 41.553166661943706, 40.4960538319179, 41.643607888902935, 41.848451205662315, 41.444441250392366, 42.844402517591206, 41.0422864641462, 39.76788261958531, 41.05525875091553, 40.91614539282662, 42.72224276406424, 40.05759818213326, 35.01620762688773, 18.742989778518677, 5.32662843806403, 1.0165662914514542, 2.1517578746591295, 2.500948714358466, 4.9813702787671765, 4.065317605222974, 6.59304359129497, 4.195394831044333, 4.466239520481654, 4.938166814191001, 2.65737698333604, 1.5037177396672112, 1.2109216281345911, 0.040037986755903275, 8.69370072228568, 32.77797399248396, 18.244244609560283, 34.216431753976, 16.00744230406625, 0.20252721889742784, 0.07937962694891862, 0.08328693014170442, 0.05526519127722297, 0.014802154918600405, 0.01655693638271519, 0.059493224402623515, 0.03309028349550707, 0.031106233530278717, 0.03328012402302452, 0.025254873226263692, 0.05111363583377429, 0.07003915815481118, 0.05111717778657164, 0.0008244320280417533, 0.0726556298988206, 0.057415841945580075, 0.02112413862986224, 0.03689819827143635, 0.036700982068266184, 0.04492995621902602, 0.05935081347290959, 0.017494015295856764, 0.02334099735266396, 0.02296877170114645, 0.03227182437798806, 0.0324084609746933, 0.027075374199609672, 0.029950020036527088, 0.02028444815160973, 0.019364159587504606, 0.015650181199557016, 0.04823984664731792, 0.009474524413235486, 0.041462269079472334, 0.015670357438336526, 0.014889022668025323, 0.009555130980775824, 0.03514420560428074, 0.02780892144489501, 0.05872379961822714, 0.05009958560445479, 0.011003994083564197, 0.08495848080409424, 0.055263254059744735, 0.03625831939280033, 0.03795316755505545, 0.027604085293465426, 0.022242673074028323, 0.18324238514261587, 12.433389697756086, 36.62858574731009, 29.934712069375173, 34.728826659066335, 25.34769548688616, 3.8159246104104176, 0.09527272198881422, 0.11328205240092107, 0.0799150996442352, 1.1927647909947803, 5.16637692281178, 3.638942050082343, 3.508137434720993, 12.996264134134565, 12.581679020609174, 9.764203599521093, 3.5275711119174957, 1.39347642660141, 6.953946488244193, 20.540431431361608, 36.37288509096418, 46.03353534426008, 47.78562436785017, 46.404621260506765, 47.05470514297485, 45.48119871956961, 45.419408389500205, 46.68423414230347, 47.37653875350952, 45.98095832552229, 49.403484616960796, 46.03334426879883, 49.631507124219624, 47.075570583343506, 47.94947678702218, 46.51093217304775, 48.39456101826259, 43.24006073815482, 37.888224669865195, 35.490661893572124, 34.82964154652187, 40.806360380990164, 48.83027907780239, 48.50970309121268, 47.37718493597848, 45.96984120777675, 48.339062282017295, 43.997469970158164, 37.85707936968122, 35.15139525277274, 36.01443794795445, 34.08194242204939, 36.2256840297154, 35.54016433443342, 36.225736141204834, 38.78192976542881, 43.766841888427734, 45.09399993079049, 47.74574865613665, 44.21036972318377, 47.246927056993755, 44.37565347126552, 41.57855537959507, 47.77735253742763, 46.937871183667866, 47.45647777829851, 43.22502136230469, 42.088890143803184, 41.40460722787039, 38.032792363848, 37.58715227672032, 35.85590090070452, 34.720037187848774, 34.61954191752842, 34.58707298551287, 33.98144020353045, 33.4779702595302, 33.87521961757115, 35.729061535426546, 43.48011405127389, 48.136741161346436, 44.58442946842739, 44.60600709915161, 47.50194331577846, 43.500308990478516, 36.83299132755825, 32.57714326041085, 32.47180509567261, 32.95114394596645, 38.066133294786724, 43.84076377323696, 45.09171049935477, 43.47977706364223, 42.520824909210205, 41.72048623221261, 42.42814636230469, 43.52361324855259, 42.174610069819856, 44.29527670996529, 42.66196019308907, 41.36332450594221, 42.0733504976545, 42.24127803530012, 44.34963941574097, 42.3142306464059, 37.404946190970286, 21.565686770847865, 6.099776642663138, 2.1538601389953067, 3.4970947929791043, 3.9612253393445696, 4.376227344785418, 6.563596257141658, 9.314520529338292, 8.828531384468079, 7.486346994127546, 5.601982508386884, 0.9596031137875148, 0.5971894721899713, 0.1349854495908533, 0.020931046223267913, 7.268015921115875, 36.006058420453755, 23.731235299791607, 33.981318610055105, 21.152025767735072, 0.28930757301194326, 0.0026204765849148054, 0.05432831762092454, 0.0380122815258801, 0.02728318063808339, 0.02434513418536101, 0.06857529349092926, 0.07019461731293372, 0.011471429224392133, 0.02467254938424698, 0.02575791534036398, 0.019005207777289406, 0.05231506350849356, 0.05510067706927657, 0.013861956440710595, 0.0342761659329491, 0.05249564881835665, 0.02043106090942664, 0.026692880616922463, 0.04897132436079638, 0.07531522254326514, 0.03961627384913819, 0.1401347704231739, 0.11741584379758153, 0.18203907114054474, 0.15382833991731915, 0.07482177152165345, 0.12816237285733223, 0.1831317160810743, 0.1534189118870667, 0.1097254500325237, 0.10241805535874196, 0.1935783326625824, 0.07892817724496126, 0.22785349775637898, 0.11816364367093359, 0.11925755068659782, 0.13364158384501934, 0.17577489013118403, 0.06845209867294345, 0.1401354760995933, 0.13304208458534308, 0.07362527679651976, 0.12372607019330774, 0.1253625473805836, 0.12285556404718331, 0.15593027855668748, 0.10922142743532147, 0.08365319655942065, 0.2722834550908634, 14.064560089792524, 42.22013814108712, 38.547785895211355, 37.87835127966744, 27.67171331814357, 5.56457427569798, 0.2477251828781196, 0.45753062622887747, 0.28359452528612955, 3.6592162421771457, 11.971568124634878, 5.781686808381762, 2.4382968076637814, 16.26152229309082, 15.993856838771276, 13.443905302456447, 5.977151794092996, 1.1784995964595248, 6.921679053987775, 20.932304620742798, 36.89951338086809, 47.88466051646641, 48.87624488558088, 45.761593273707796, 49.07298312868391, 46.049978256225586, 47.21301637377058, 47.866817542484824, 49.04237631389073, 47.47536645616804, 51.07598202569144, 48.450619084494456, 49.966111523764475, 49.02811861038208, 48.22927727018084, 47.31764929635184, 51.3497063091823, 46.36568355560303, 40.01298727308001, 38.358933857509065, 36.04953677313668, 41.84648486546108, 51.937520435878206, 50.435121876852854, 49.59242698124477, 46.37145750863211, 50.73738241195679, 46.175775391714915, 40.10867786407471, 37.3830315726144, 37.97093949999128, 35.21942853927612, 38.02869987487793, 37.31891359601702, 38.96336112703596, 41.874229022434776, 47.07074505942208, 46.626803806849885, 51.117157050541465, 46.848951612200054, 49.087932177952354, 46.40457957131522, 45.09363167626517, 48.391465595790315, 47.920825890132356, 49.79325771331787, 44.08918271745954, 43.724593366895405, 43.91388661520821, 39.079548903873985, 39.19776208060128, 38.254300934927805, 35.51265641621181, 36.311994552612305, 36.197634152003694, 35.29846429824829, 35.115146500723704, 35.22855499812535, 37.15616594042097, 45.2189667565482, 50.72997563225882, 45.95933553150722, 45.765977587018696, 50.381433146340505, 46.107801164899556, 38.229176248822895, 33.55271897997175, 35.269570214407786, 34.11709335872105, 39.01646968296596, 45.630855969020296, 48.09771660396031, 44.438468660627095, 44.67675713130406, 43.41444662639073, 44.48493126460484, 44.053072929382324, 44.134280000414165, 46.293957301548545, 45.18392351695469, 42.57244655064174, 43.94845737729754, 44.8692569732666, 46.033761160714285, 42.80695867538452, 38.79469013214111, 22.813239301953995, 6.450258544513157, 3.2195735360894884, 5.328905710152217, 6.72135727746146, 9.581632733345032, 10.684235419545855, 16.753602402550833, 12.579475573131017, 13.740040131977626, 12.330405235290527, 6.061675761427198, 3.3493871646268025, 3.171294412442616, 0.08744341853473868, 12.322738766670227, 39.50856195177351, 27.936519588742936, 44.0135828426906, 23.67902132443019, 0.5478978657296726, 0.22476658411324024, 0.16806097834237985, 0.1387424844184092, 0.11571189308805124, 0.16722942010632583, 0.11324541829526424, 0.19902535394898482, 0.14807156739490374, 0.09879645612090826, 0.11959985803280558, 0.11335849615612201, 0.18597834690340928, 0.16245887109211513, 0.08333389833569527, 0.1899530014821461, 0.16239333818001406, 0.10097355608429227, 0.10770005014325891, 0.0912546750956348, 0.14131717197597027, 0.14319983523871216], [0.040960197270448716, 0.03828958521730133, 0.0605617542085903, 0.020148388309670345, 0.04632122442126274, 0.11564192255692822, 0.021859521312373023, 0.038602685023631365, 0.030179280055952922, 0.038605996274522374, 0.03730152966454625, 0.03107954335532018, 0.011751422458993537, 0.03131128681291427, 0.05146477770592485, 0.023950281087309122, 0.033880763221532106, 0.04249229880848101, 0.009798309449771685, 0.06522126775234938, 0.023080690963459865, 0.0025505032972432673, 0.04476965232087033, 0.035813739855906794, 0.08327441117061035, 0.050906496055956395, 0.05151502661673086, 0.0861201056146196, 1.3184162314449037, 16.93363717624119, 28.55012890270778, 22.37804409435817, 27.12437071119036, 10.814288326672145, 0.2948603236249515, 0.07393158785998821, 0.056174251783107004, 0.6558726547019822, 1.8751726703984397, 1.4014360223497664, 7.75123143196106, 10.510956900460378, 9.333342330796377, 8.678735171045576, 2.4085168285029273, 1.0901138420615877, 0.7871751519186156, 9.562808326312474, 22.211443662643433, 40.577233110155376, 46.59956339427403, 46.68871920449393, 45.06850004196167, 47.77680362973894, 45.170016697474885, 45.29273925508772, 46.42320769173758, 48.352284703935894, 46.92037214551653, 47.077919074467246, 47.437536988939556, 47.96132346561977, 46.40548978533064, 47.66110570090157, 47.08247709274292, 40.84264039993286, 35.94245113645281, 35.01790298734392, 32.524156297956196, 37.111211095537456, 45.29079375948225, 46.563596044267925, 45.7960250718253, 45.195527008601594, 47.58196224485125, 44.846088205065044, 39.13260882241385, 34.05873196465628, 33.67500727517264, 32.78966086251395, 32.97952733721052, 34.289356572287424, 38.00999532427107, 42.46052496773856, 45.434604099818635, 47.06651708057949, 46.27566964285714, 46.19664083208357, 45.08652714320591, 41.47609724317278, 39.570918560028076, 46.841141836983816, 43.07009737832205, 42.88645648956299, 37.576087270464214, 36.04955414363316, 33.86185475758144, 32.65780142375401, 33.329355239868164, 32.23234585353306, 31.90145526613508, 31.507457665034703, 32.34238447461809, 31.68066930770874, 31.800164427076066, 31.01466362816947, 33.79398127964565, 41.52631882258824, 45.876620701381135, 43.90899508340018, 45.1047487940107, 44.33166095188686, 45.16956506456648, 38.88796969822475, 32.81068958554949, 32.03319311141968, 30.80105515888759, 38.32451942988804, 44.97902461460659, 41.98447956357683, 43.78717926570347, 43.63895681926182, 40.60297966003418, 42.01615292685372, 44.200121130262104, 41.03632838385445, 42.26509646006993, 40.96424429757254, 44.12081091744559, 41.57539394923619, 43.54201207842146, 42.43244729723249, 38.817799840654644, 31.188403333936417, 11.865149515015737, 2.7899216881820132, 1.175205607499395, 2.028824048382895, 2.2640461921691895, 2.541194200515747, 5.5225763235773355, 5.517580568790436, 6.273527204990387, 5.490784406661987, 6.553572612149375, 0.6556956384863172, 0.5480931752494403, 0.05191659042611718, 1.594243539231164, 22.792333909443446, 53.91015917914254, 21.630831343787058, 29.746304716382706, 5.49762099981308, 0.09727064799517393, 0.022893259235258614, 0.02806427961747561, 0.03861903093223061, 0.03555027488619089, 0.03454257235197084, 0.06484250950493983, 0.044894102428640635, 0.0597793897613883, 0.10018953601164476, 0.013138378571186746, 0.028400342745174254, 0.06805183086544275, 0.03933184214734605, 0.04698702673028622, 0.014601376406582338, 0.06178657098540238, 0.05392942723951169, 0.04980928796742644, 0.00970058683638594, 0.025552532968244383, 0.010588909615762532, 0.038731467577495744, 0.03055984659918717, 0.02633469894395343, 0.027446230906727057, 0.031668155520622215, 0.05600454338959285, 0.006023137381167284, 0.033420607913285494, 0.011414981048021997, 0.05727893393486738, 0.008418780751526356, 0.025597799735675966, 0.045793205433126004, 0.0061599830514751375, 0.019551684614270926, 0.032228764545704634, 0.021947366152224795, 0.049049115008009334, 0.05634386857439365, 0.05013228759967855, 0.01399817573837936, 0.01504368963651359, 0.045933292380401065, 0.03271151167739715, 0.0655946112903101, 0.06921712655041899, 0.04531851590477994, 0.11450821267707006, 2.487333502088274, 26.790283952440532, 33.67226273672921, 25.287928819656372, 29.169097014835902, 11.403280173029218, 0.12890767572181566, 0.12261500981237207, 0.018076556269079447, 0.27292049090777126, 3.96768890108381, 4.884074219635554, 8.379536185945783, 13.797513025147573, 10.550316708428518, 10.54366033417838, 6.300719848700932, 1.383956091744559, 2.1973391430718556, 11.880253161702838, 23.728462968553814, 42.683847018650596, 48.67487219401768, 46.77041959762573, 47.25229454040527, 47.13481787272862, 45.736937591007774, 46.78439589909145, 47.01507609231131, 48.712340354919434, 47.288001332964214, 47.86395141056606, 48.37628378186907, 49.48144687925066, 46.56018100466047, 48.96294450759888, 47.69107675552368, 41.400594643184114, 36.80801255362374, 36.65983179637364, 34.922118595668245, 40.41571181161063, 47.611116886138916, 49.33564240591866, 48.287294728415354, 46.869243826184956, 49.02738904953003, 45.690110206604004, 41.032729216984336, 36.26908595221383, 35.52998522349766, 33.96955530984061, 34.67949792316982, 36.39566476004464, 39.75816903795515, 44.0643880707877, 47.836120401109966, 48.88025747026716, 47.64775126320975, 47.88150603430611, 45.75315121241978, 42.444255760737825, 41.3759320122855, 49.04605885914394, 45.76107563291277, 44.419465337480815, 40.101368359157014, 39.27079112189156, 35.90962437220982, 34.91713326317923, 34.18559912272862, 33.962794712611604, 34.31560686656407, 34.049490860530305, 33.81941516058785, 33.07951886313302, 33.06244019099644, 33.57677016939436, 34.576650687626426, 41.50153807231358, 47.01184170586722, 45.387707233428955, 44.728034836905344, 45.46411657333374, 45.240881374904085, 39.74948031561715, 34.45072501046317, 33.87895427431379, 33.102197783333914, 40.038580962589805, 45.90981224605015, 43.66851793016706, 45.148115975516184, 43.943902833121165, 41.74109806333269, 43.64229195458548, 43.84535305840628, 43.322810309273855, 43.039330754961284, 42.01228625433785, 44.15544073922293, 43.09846339906965, 43.59038891111101, 41.89652231761387, 40.929597105298726, 32.95375299453735, 14.872573920658656, 4.127401062420436, 2.2707433870860507, 3.581633742366518, 4.0217441490718295, 4.700771621295384, 5.6216007471084595, 7.807415434292384, 8.286901933806282, 6.451431053025382, 3.5499369289193834, 0.35460359496729715, 0.024840369754071747, 0.10330986071910177, 0.900986156293324, 24.364134550094604, 47.39321790422712, 20.467041083744594, 37.73480497087751, 8.072899154254369, 0.07586307171732187, 0.008502224443613418, 0.013798468463521982, 0.102632404571133, 0.04964086200509753, 0.10627140144684485, 0.08000231175018208, 0.037355510517954826, 0.012335028732195497, 0.04357303885210838, 0.02128186239860952, 0.027696059018905674, 0.01889859126614673, 0.05697362710322652, 0.04773474857211113, 0.010112350723440093, 0.05091506934591702, 0.04826093551569751, 0.02769952972552606, 0.03831053159332701, 0.03259763314521738, 0.012851136038079858, 0.09917239166264023, 0.15111893601715565, 0.18134837677436216, 0.15777088621897356, 0.08571309316903353, 0.16484419309667178, 0.1455369269741433, 0.07733289391866752, 0.10135766118764877, 0.10888487406607185, 0.10516594576516322, 0.08496527972498111, 0.07989193445869855, 0.09648615973336355, 0.12176187416272503, 0.14745579686548027, 0.08088337590119668, 0.1490381405289684, 0.15297690060521874, 0.1677727230957576, 0.06541927105614118, 0.06373347794370991, 0.09712001322103397, 0.20832942612469196, 0.12173610340271677, 0.13847702794841357, 0.15298065968922206, 0.13712424625243458, 2.0975834216390337, 31.80591753550938, 38.72905050005232, 31.477625574384415, 37.398230757032124, 13.768092615263802, 0.5767681737031255, 0.47300317883491516, 0.20269554986485414, 2.78481411082404, 8.23926682131631, 8.187445419175283, 16.41539362498692, 15.209024803979055, 21.22192464556013, 16.88211280958993, 6.884120566504342, 2.3689978633608137, 1.881817102432251, 11.740421533584595, 24.727059807096207, 43.519506863185335, 50.093444211142405, 46.87978424344744, 46.1707900592259, 47.81640141350882, 46.54727472577776, 47.757425103868755, 48.82339341299874, 50.234169551304404, 48.61557626724243, 48.61868211201259, 48.966526303972515, 50.28520406995501, 48.866187368120464, 50.94944143295288, 50.88027906417847, 43.872523988996235, 39.46756410598755, 39.27654423032488, 35.8749007497515, 41.493603229522705, 49.38264002118792, 50.436796392713276, 48.97491972787039, 48.4203770501273, 51.00948429107666, 49.19268669400896, 42.99073505401611, 37.20089149475098, 37.865861892700195, 36.34329618726458, 37.09881898335048, 37.751664774758474, 41.769019399370464, 47.44944620132446, 50.102379594530376, 51.69620949881417, 49.86392784118652, 50.01705224173409, 46.85843937737601, 41.90495048250471, 43.22734553473336, 49.42713975906372, 46.909630230494905, 47.044605936322895, 41.17805426461356, 39.63391440255301, 36.78618131365095, 34.93121031352452, 37.6136839730399, 35.416409969329834, 35.30986629213606, 34.76071889059884, 34.97354916163853, 34.01906469890049, 34.922024794987266, 34.74411269596645, 36.77929217474801, 43.74339519228254, 49.93730776650565, 47.12810591288975, 44.9898499080113, 46.32684659957886, 47.19784498214722, 43.43809482029506, 36.555615765707834, 35.56102630070278, 34.29649584633963, 42.18873575755528, 47.93179014750889, 45.010399205344065, 46.81727824892317, 45.82953970772879, 43.30188233511788, 45.181515966142925, 45.78498438426426, 43.92693880626133, 45.54790490014212, 45.11552892412458, 45.5163357598441, 44.96763999121529, 44.93949978692191, 44.13483238220215, 41.665046555655344, 35.25074407032558, 13.464641332626343, 4.219709183488574, 3.479259635720934, 5.72307962179184, 7.4277163573673795, 8.231064472879682, 12.205746735845294, 12.020921179226466, 16.20465997287205, 13.330101626259939, 13.718014342444283, 2.308435844523566, 1.5302192547491618, 0.30889978313020294, 2.7755580246448517, 28.429426533835276, 57.02773598262242, 27.92083055632455, 42.27325364521572, 9.54813894203731, 0.1659054761486394, 0.11742284627897398, 0.08408390344785792, 0.10614914979253497, 0.11431084041084562, 0.15334301095988068, 0.11160356032529048, 0.08878812566399574, 0.11206936104489224, 0.17976483888924122, 0.06438934989273548, 0.08833579386451415, 0.12442116146641118, 0.16274103309426988, 0.16586237560425485, 0.07420298829674721, 0.2489208701465811, 0.2028415570301669, 0.1270771510899067, 0.18917534606797354, 0.09973351976701192, 0.08942716994455882], [0.020370603439265063, 0.027515227740098323, 0.04363661079800554, 0.024688450852409005, 0.09996051008680037, 0.03481455972152097, 0.029159353713371923, 0.024415454162018638, 0.02657710897204067, 0.01809500393989895, 0.037318296264857054, 0.04630587935181601, 0.09083810209163598, 0.0169559963978827, 0.05679904004292829, 0.05558308493345976, 0.05326645102884088, 0.015488711917506797, 0.10372752616448061, 0.06550541786210877, 0.05305948767012783, 0.04362922155165246, 0.022675245933766876, 0.03320444701239467, 0.06287279019930533, 0.02081255365296134, 0.008607257423656327, 0.030636005369680266, 0.1329656136887414, 5.900362040315356, 29.420118059430802, 35.65211023603167, 40.44620745522635, 15.874033417020526, 2.432627729007176, 0.06054671787257705, 0.08275365589984826, 0.10139836650341749, 4.090079682213919, 3.8447939412934438, 4.364772805145808, 7.449909772191729, 9.414220230919973, 10.645178726741246, 5.113698720932007, 1.680113828607968, 1.090886177761214, 4.638824088232858, 14.523508582796369, 30.061572279248917, 43.79185887745449, 49.11313329424177, 46.8052613394601, 48.59579127175467, 46.66709293637957, 46.28414297103882, 48.84345286233084, 47.13691275460379, 47.7128141948155, 47.12797737121582, 49.18699264526367, 46.636357579912456, 47.280952385493684, 47.630349499838694, 43.04783535003662, 37.960788181849885, 34.98324884687151, 35.033133438655305, 34.44859191349575, 39.597467626844136, 45.3938946042742, 47.61686999457223, 46.50164590563093, 45.94378546306065, 45.950247287750244, 46.39461932863508, 40.30683701378958, 34.7353892326355, 34.28293296269008, 33.2614609173366, 33.611872468675884, 36.504515239170615, 42.73187296731131, 45.96575219290597, 44.93969086238316, 47.955855233328684, 46.21634939738682, 43.62918070384434, 41.912346839904785, 43.09436396190098, 40.75971017565046, 47.83358083452497, 43.535946301051546, 43.92028938020979, 37.36852720805577, 36.02111169270107, 31.98804371697562, 33.59911905016218, 33.142577239445274, 31.9142746925354, 31.31897735595703, 32.376010281699045, 32.278089318956646, 33.04658440181187, 31.527138437543595, 33.36219590050833, 33.46315322603498, 41.166895457676475, 44.516347544533865, 45.53590188707624, 45.164030824388774, 46.14897618974958, 43.964869022369385, 41.51140104021345, 35.32694149017334, 31.36576305116926, 31.707951409476145, 37.9093576158796, 43.835462297712056, 43.63043485369001, 43.22272150857108, 43.47475699016026, 40.93631253923689, 41.96503850391933, 42.97570957456316, 42.10715348379952, 40.73360231944493, 41.31551047733852, 41.39001601082938, 43.454346656799316, 43.49146393367222, 41.38408572333199, 38.01735346657889, 26.188220807484218, 9.951132723263331, 1.8842802388327462, 1.9596790501049586, 2.588244144405637, 2.6272880264690945, 3.2066592233521596, 4.630937448569706, 6.897217920848301, 7.162399394171579, 4.874104857444763, 1.1940621499504362, 0.23862553973283085, 0.15838478399174555, 0.13029716616230352, 6.166229213987078, 27.847923108509608, 34.0216772215707, 35.85427154813494, 21.132423162460327, 1.4723570453269141, 0.12139986215957574, 0.03473209736070462, 0.07710530648806266, 0.04491583929796304, 0.025468898438183323, 0.030107267134423767, 0.038693886915487904, 0.01912090478331915, 0.02196405302467091, 0.01804655653956745, 0.0255159514490515, 0.060036622386957915, 0.052445121708192995, 0.03829824332413929, 0.04608735375638519, 0.05966388274516378, 0.020626282219641974, 0.021264098351821303, 0.04639115763295974, 0.06224811050508704, 0.11201864733759846, 0.04515404240893466, 0.03927739310477461, 0.046977493313274214, 0.05146725096606782, 0.042080672324768136, 0.05008487496525049, 0.07475777209869452, 0.006110936843989683, 0.042993447809879265, 0.029616872913071086, 0.06127975282392331, 0.0028811012494510835, 0.04171146445774606, 0.0401705623205219, 0.009363698440470865, 0.09293383892093386, 0.030194143365536417, 0.08067296897726399, 0.05948082756783281, 0.07587545498141221, 0.03495080955326557, 0.018304605103496994, 0.04190225154161453, 0.03550302170749221, 0.030995296447404792, 0.0772287795054061, 0.06561917425798518, 0.01049738287526582, 0.06840403803757258, 0.19668378388243063, 10.31281772681645, 34.934562819344656, 37.73436376026699, 44.07328871318272, 17.865359340395244, 2.270600297621318, 0.11006950799907957, 0.022479614109865258, 0.25933602984462467, 2.2674115087304796, 5.580526905400412, 7.212467678955623, 6.9662104930196485, 8.206684112548828, 10.271323953356061, 5.810270828860147, 2.6972776651382446, 1.7198036760091782, 5.9313497032438, 16.72377552304949, 32.18001549584525, 46.64581755229405, 49.132824489048545, 48.53488336290632, 49.061591557094026, 46.18290424346924, 47.29258714403425, 48.034831932612825, 48.53302819388253, 49.458938189915244, 49.097204548971995, 48.388241631644114, 47.75640024457659, 49.88726684025356, 48.75289351599557, 44.851577281951904, 39.94491229738508, 37.02534873144967, 37.808622632707866, 35.52588926042829, 40.261708463941304, 46.91582107543945, 49.7817063331604, 47.53121607644217, 46.487277030944824, 48.35764871324812, 47.67756598336356, 41.42862367630005, 35.21053484507969, 36.61742346627371, 34.54749257223946, 34.681637968335835, 36.73403508322579, 45.19578756604876, 48.14893872397286, 47.44718108858381, 49.17488193511963, 47.15000663484846, 45.297967774527415, 42.157972608293804, 41.94435371671404, 42.83355637959072, 48.092561040605815, 45.42309093475342, 45.55254977090018, 39.075974055698936, 36.01981585366385, 34.30833905083792, 34.13458892277309, 35.49256917408535, 33.47169256210327, 32.8253607068743, 33.25366851261684, 33.09881748471941, 33.21482113429478, 32.42437669209072, 34.034229142325266, 34.87160866601126, 42.945776735033306, 45.93405103683472, 46.90128891808646, 43.942179679870605, 46.167670318058555, 45.689648151397705, 43.75930309295654, 35.981413160051616, 32.98690979821341, 32.678816250392366, 37.9842974117824, 45.5227871622358, 44.557328019823345, 44.17582675388881, 44.158814089638845, 43.974638189588276, 42.31209407533918, 44.338397230420796, 43.12061425617763, 42.53230333328247, 41.983847277505056, 42.6899927003043, 44.208618777138845, 44.70168726784842, 42.57768201828003, 40.94934041159493, 27.777332884924753, 11.146367924554006, 2.31790645633425, 3.1279207170009613, 3.7467366201536993, 3.943158285958426, 4.0231689640453885, 6.67819550207683, 6.809286296367645, 6.422584738050189, 5.0198728527341565, 1.44841659281935, 0.3499173878559044, 0.16945570707321167, 0.10790848253028733, 6.904571720532008, 36.3582626070295, 43.67303425925118, 33.48242405482701, 27.26261728150504, 1.979743710586003, 0.10123581665435008, 0.05834782336439405, 0.04244063175948603, 0.06376087040241275, 0.015737610436709862, 0.012676446349360049, 0.027360350425754274, 0.04555443235273872, 0.07898813259920903, 0.004908865833255861, 0.0391371331310698, 0.045946425425687006, 0.027551999249096428, 0.02224567559148584, 0.04277779920292752, 0.0650826905454908, 0.03846042676429663, 0.006028891782209809, 0.027878454320931008, 0.04346194231350507, 0.09890318967934165, 0.02121631082679544, 0.1194928123482636, 0.18908795075757162, 0.14536168852022716, 0.12459264083632401, 0.24304744388375962, 0.1628532763570547, 0.14409510791301727, 0.1353788370532649, 0.1923329902014562, 0.14356100585843834, 0.08416076789477042, 0.180096086114645, 0.12888381843055996, 0.12236080345298563, 0.10942856382046427, 0.05270626608814512, 0.2048947497137955, 0.07991822090532098, 0.14404362067580223, 0.18996704715703214, 0.14319226278790406, 0.11342666856944561, 0.07117318016077791, 0.12880665542823927, 0.17191637360623904, 0.1612257422613246, 0.0908355779413666, 0.11802801809140614, 0.44261680649859564, 14.106914571353368, 44.21382992608206, 41.478268555232454, 49.22702816554478, 22.495465176446096, 3.684636660984584, 0.24616903066635132, 0.17228979856840201, 0.5345974394253322, 8.259278501783099, 11.879244804382324, 12.442866172109332, 18.247067315237864, 20.295563016619, 18.579472609928676, 11.500570586749486, 4.096412965229579, 1.8342983722686768, 6.077141582965851, 16.652601650782994, 32.891403334481375, 47.1188509123666, 50.40231595720564, 48.29640729086739, 49.95062746320452, 49.538550649370464, 47.65831599916731, 49.49097285951887, 50.03653151648385, 50.62516900471279, 49.20378296715872, 50.237636702401296, 49.31216791697911, 52.11712442125593, 51.289069380079, 46.5955924987793, 42.91906091145107, 38.029029914310996, 39.43149253300258, 37.59940195083618, 44.25890983854021, 48.95082337515694, 52.62957838603428, 48.45213031768799, 46.62203386851719, 50.791067668369834, 50.39720903124128, 44.303545066288535, 37.05227300098964, 37.87353965214321, 36.02051762172154, 36.563915388924734, 39.62281812940325, 46.70904963357108, 50.08574560710362, 48.71358060836792, 51.43814298084804, 48.83720990589687, 46.2109888621739, 40.770577158246724, 42.89695521763393, 45.60706533704485, 50.18262781415667, 46.85902650015694, 48.37511995860508, 42.29560947418213, 39.49199397223336, 36.19572687149048, 35.381568227495464, 37.45331954956055, 34.55012246540615, 35.24682181222098, 35.330710887908936, 35.54878010068621, 34.91696650641305, 33.901115553719656, 35.20936059951782, 36.25887904848371, 44.198620319366455, 48.408443519047324, 48.142532484872, 45.833771160670686, 48.24837439400809, 47.36941684995379, 44.47409207480294, 37.757334504808696, 33.9346684047154, 34.48475728716169, 39.57808910097395, 47.40487003326416, 45.59332874843052, 45.10845218385969, 44.78787967136928, 45.22083582196917, 44.673925740378245, 46.09138257162911, 43.531565461839946, 44.15160533360073, 44.13765682492937, 43.55346270969936, 45.06669351032802, 45.32101147515433, 44.31697940826416, 42.691479614802766, 28.297176258904592, 11.284109013421194, 2.8485516735485623, 5.34146067074367, 6.641155958175659, 6.8876780441829135, 8.973502942493983, 12.755169459751674, 15.483445644378662, 11.85819957937513, 12.679025888442993, 3.541404975312097, 1.0253430604934692, 0.6119522228837013, 0.2467819649193968, 9.283121619905744, 35.65798493794033, 42.92423037120274, 43.38067143304007, 31.180947916848318, 2.577520251274109, 0.2422490252980164, 0.17810284878526414, 0.2193249368241855, 0.17582682520151138, 0.0866475851674165, 0.19439680874347687, 0.13729924043374403, 0.1599184495529958, 0.16158347949385643, 0.11436430897031512, 0.1333777830004692, 0.13971102530402796, 0.11560712728117194, 0.24725273251533508, 0.1039084168151021, 0.12233714972223554, 0.08717505114951304, 0.10772453847208194, 0.10346401030463831, 0.11801790791962828, 0.23787537855761393, 0.11745145331536021], [0.028224325672324215, 0.06333175128591911, 0.007988376659341156, 0.035238311626017094, 0.05603133195212909, 0.02678962274720626, 0.054647469959620915, 0.06281689248446908, 0.02843123474823577, 0.033547989292336364, 0.0484460432614599, 0.013813449668564966, 0.014413961641756552, 0.04908608838117548, 0.01890643682729985, 0.03833130155024784, 0.04821980272286704, 0.0588833639132125, 0.04686963677938495, 0.026587687332981398, 0.026672441445823227, 0.017319187355626906, 0.020557183606017913, 0.05472577290077295, 0.05737985244819096, 0.05911955516785383, 0.040924031353954754, 0.02468065109236964, 0.05599379878757255, 4.808745758874076, 32.251644475119456, 32.37567329406738, 27.48510902268546, 25.029080629348755, 7.938592212540763, 0.4124011535729681, 0.0914041292188423, 0.4023457260004112, 1.9247482844761439, 4.097912473337991, 3.350975262267249, 4.763279787131718, 4.4584961874144415, 5.709517172404698, 6.442859581538609, 1.5498811368431364, 1.5690853063549315, 2.318021970135825, 10.297727976526533, 22.999027184077672, 35.29947873524257, 45.35264662333897, 50.73439121246338, 48.82743031638009, 49.07366752624512, 49.65311254773821, 47.60179935182844, 47.71030242102486, 48.821684156145366, 48.4641124861581, 47.50051198686872, 45.248899596078054, 43.767734731946675, 41.97403989519392, 38.83703245435442, 35.41388429914202, 34.59565053667341, 33.870810985565186, 34.15720878328596, 37.70578581946236, 46.164953572409495, 46.83793871743338, 47.699560506003245, 46.11186238697597, 47.59604971749442, 46.542390142168315, 43.24554286684309, 35.78420243944441, 35.716388021196636, 34.010309968675884, 34.49232734952654, 36.5860002381461, 44.0899088042123, 46.17340953009469, 46.56632668631417, 43.90389510563442, 44.11144127164568, 41.933236598968506, 44.939756870269775, 41.986299991607666, 39.18601962498256, 45.44620064326695, 46.39610971723284, 44.08838020052229, 42.51151779719761, 37.939728191920686, 34.11449473244803, 33.300138064793174, 31.65330730165754, 31.729772227151052, 32.7415063721793, 33.23659331457955, 32.975219454084126, 32.67680474690029, 33.258712904793875, 32.43454885482788, 32.81796087537493, 38.72057022367205, 44.83166721888951, 43.25709772109985, 44.43060677392142, 45.327355180467876, 44.893346377781455, 41.11397450310843, 40.658388069697786, 33.59468262536185, 31.20408889225551, 34.69276550837925, 43.29041085924421, 43.443976470402305, 45.634628840855186, 43.19144766671317, 43.56662259783064, 41.41950069155012, 39.91724804469517, 40.85714476449149, 40.596528257642476, 40.78488349914551, 42.3620342527117, 39.900812080928254, 42.88488967078072, 39.51581934520176, 36.47388410568237, 20.01983765193394, 5.650259460721697, 2.176795708281653, 2.627466074057988, 3.1473913065024783, 2.802195029599326, 3.3579519050461903, 3.79670980146953, 4.418376420225416, 5.38668475832258, 1.4198710045644214, 0.7886058837175369, 0.3050447814166546, 0.022024625845785652, 0.9542554978813443, 16.003758021763392, 27.995978798185075, 19.647532326834543, 31.604180063520158, 11.973291277885437, 0.06701785884797573, 0.040994975582829545, 0.0460009999972369, 0.02263404189475945, 0.03751111895378147, 0.018827451958454082, 0.01955544200193669, 0.0680840341374278, 0.05736737418919802, 0.022604766501379863, 0.07465092318930797, 0.06820655042039496, 0.022675186561952745, 0.018112942709454467, 0.0011360447824699804, 0.03648599503295762, 0.006516084590527628, 0.00234983822779863, 0.04554341972938605, 0.036256962322763035, 0.04695247233446155, 0.02781369154607611, 0.027612850269568816, 0.01929025524961097, 0.05024956898497684, 0.04228223454473274, 0.048716548031994274, 0.04844570738662567, 0.01694305334240198, 0.025055726590965475, 0.003930295775977096, 0.058176438989383836, 0.018113551694633703, 0.1067305321672133, 0.017136537602969577, 0.026206857857427428, 0.04260906789984022, 0.08776970566915614, 0.02405060757882893, 0.05244887739952121, 0.06189042077000652, 0.027050811231934598, 0.03868757653981447, 0.029692214048866714, 0.0459119897734906, 0.01821854989975691, 0.0379602718167007, 0.11686875458274569, 0.009871474184494997, 0.019835191812100153, 0.013029374464947199, 0.06858543080410787, 5.631915782179151, 38.75674254553658, 35.288698605128694, 36.821162019457134, 31.614251477377756, 8.010561653545924, 0.5431858471461705, 0.04789455035435302, 0.07123083528131247, 0.8982974205698285, 3.8561399153300693, 5.731491718973432, 9.876494305474417, 8.177398324012756, 9.390992403030396, 7.531182851110186, 3.134689565215792, 3.0434590663228716, 2.24289413860866, 11.538129942757742, 24.52607795170375, 39.592218262808665, 47.71422815322876, 51.742109298706055, 49.994185720171245, 50.30017396381923, 50.59530912126814, 49.71765089035034, 49.68228803362165, 49.90491526467459, 50.37071555001395, 48.75488070079258, 48.250660351344514, 45.84108066558838, 45.54020629610334, 42.02935103007725, 37.93386738640921, 35.81090784072876, 34.92609296526228, 35.981506960732595, 39.02614852360317, 48.42069319316319, 47.78701400756836, 50.96720450265067, 45.60811104093279, 46.36619772229876, 48.87098857334682, 44.57218674251011, 38.433494976588655, 35.902863774980815, 36.154656069619314, 34.9992436000279, 37.74013423919678, 44.78730297088623, 46.54777499607631, 48.604483468191965, 44.39028985159737, 45.19279636655535, 43.39122922079903, 44.20251478467669, 42.619471958705354, 41.58351986748831, 47.9547678402492, 47.091905798230854, 46.11987018585205, 42.74736050197056, 39.30445861816406, 35.14908497674124, 35.71399784088135, 33.80899633680071, 34.822585650852744, 33.93260478973389, 34.27226747785296, 34.76845918382917, 34.12318345478603, 34.3210403578622, 34.449522972106934, 35.24425445284162, 40.152941363198416, 46.41924374444144, 45.54042863845825, 44.38002388817923, 45.48516961506435, 45.624373299734934, 43.08444193431309, 41.59935481207711, 35.22195768356323, 32.928447655269075, 35.58840915134975, 44.46093566077096, 44.99512359074184, 44.894478934151785, 42.364000592912944, 43.58519860676357, 42.769386291503906, 41.526958056858604, 41.37570966993059, 42.709531034742085, 42.42930671146938, 43.29239109584263, 41.604093483516145, 43.08786392211914, 40.98996652875628, 37.27692910603115, 21.940205097198486, 6.4957127911703925, 1.4282588916165488, 2.6210272652762274, 4.329528936317988, 4.495443667684283, 5.7266774858747205, 6.303570347172873, 5.311178684234619, 6.086901196411677, 2.58025176184518, 0.1578135389302458, 0.12414121148841721, 0.08406462626797812, 0.5212851251874651, 17.993920121874126, 31.047361850738525, 23.850270101002284, 37.59995780672346, 17.26296615600586, 0.012926081079058349, 0.022737842485574738, 0.04349694114976695, 0.034740989562124014, 0.06322842397327934, 0.021800683844568472, 0.011795566250969256, 0.07347717295799937, 0.011836425085285944, 0.019795402518606613, 0.06503627875021525, 0.017021894022556286, 0.022390517372904078, 0.02382032127518739, 0.0595644705795816, 0.03583159211224743, 0.03194951685145497, 0.04912340780720115, 0.06799619099391357, 0.024007664793836217, 0.03959685417690447, 0.03168692719191313, 0.045255795520331175, 0.08231300847338778, 0.14016465310539516, 0.09169534287814583, 0.12052673686827932, 0.1530288356755461, 0.0906909889142428, 0.14365931201194013, 0.12671238423458167, 0.17213786100702627, 0.202119378639119, 0.24610980812992367, 0.11897450658891882, 0.1344628283487899, 0.17293311761958258, 0.1412364263087511, 0.10318325965532235, 0.07850458140351943, 0.22283835043864592, 0.07716917698936802, 0.10470759536006621, 0.0915531830063888, 0.11646304492439542, 0.17761734340872082, 0.15080583281815052, 0.2071026890937771, 0.16644759848713875, 0.10513124548430954, 0.07498740191970553, 0.12455158946769578, 8.721940806933812, 45.04558488300869, 41.383547237941194, 35.88620546885899, 33.85365240914481, 10.28643194266728, 1.153168418577739, 0.2170911045478923, 0.7821955734065601, 3.7259489127567837, 9.033858469554357, 13.121301310403005, 12.048140747206551, 15.473968301500593, 11.907466650009155, 12.745503646986824, 5.051417240074702, 3.6123078678335463, 3.4519373646804263, 12.184533017022268, 25.76202699116298, 39.332355635506765, 48.50139651979719, 53.033456325531006, 52.99783985955374, 50.711090428488596, 53.31889527184622, 50.71271630695888, 51.69930492128645, 52.241931438446045, 51.74974536895752, 50.10495390210833, 51.11955417905535, 46.58548634392874, 46.09978641782488, 42.35400560923985, 39.14582429613386, 38.888570717402864, 36.1027113369533, 37.35468987056187, 40.46450901031494, 50.85328183855329, 49.66064786911011, 52.5924402645656, 45.65430266516549, 49.97064869744437, 50.5432254246303, 47.86649445125035, 39.7188526562282, 38.64670739855085, 37.64222369875227, 37.89333506992885, 40.02104718344552, 46.09404720578875, 49.66617863518851, 50.384855134146555, 45.676088741847444, 45.60386569159371, 43.687754017966135, 44.40182386125837, 43.33759260177612, 42.73617042813982, 48.6332802772522, 50.96900061198643, 48.228710991995676, 45.154213019779746, 40.72430215563093, 37.04494612557547, 37.182829652513774, 35.34224489756993, 36.618274620601106, 35.513344287872314, 37.039495263780864, 35.71806948525565, 35.6834431375776, 37.29900353295462, 35.40348284585135, 36.86199310847691, 42.18046045303345, 48.62585265295846, 47.73229694366455, 45.15711736679077, 46.38262326376778, 47.91439880643572, 45.16694906779698, 43.98703030177525, 37.134518827710835, 34.187638419015066, 37.84315865380423, 45.6906486919948, 47.12526062556675, 47.496183259146555, 44.60010807854788, 45.720098631722585, 44.5883378301348, 42.56075273241316, 42.69102798189436, 44.028736863817485, 44.97366407939366, 45.25372511999947, 42.02751670564924, 45.12974493844168, 43.75033296857561, 38.586219855717246, 21.246291978018625, 7.236170589923859, 3.799575064863477, 6.131037022386279, 7.401446955544608, 7.750167489051819, 9.011456608772278, 8.745009694780622, 11.342411347797938, 13.260284389768328, 6.37475768157414, 2.5899560068334853, 0.8118691582764898, 0.1665552548531975, 1.4303218552044459, 21.53267240524292, 34.30539301463536, 28.27370524406433, 44.27506787436349, 21.109377724783762, 0.13097538905484335, 0.135307889431715, 0.09548694906490189, 0.08237632257597786, 0.14281567585255417, 0.09685951684202466, 0.08514401941959347, 0.1837300889726196, 0.16275806432323797, 0.1347451667700495, 0.2124694532581738, 0.13090625990714344, 0.15229132239307674, 0.18086743115314416, 0.13061002508870193, 0.1946343638535057, 0.1363659697983946, 0.1256804410368204, 0.10409048133130584, 0.14237346101020062, 0.11581763598535742, 0.12465323401348931, 0.11727459994809968], [0.02396161771113319, 0.07377561980060168, 0.05812235974839755, 0.017714807198249867, 0.031304331828973124, 0.010494678065047731, 0.02088395250029862, 0.03263038942324264, 0.008351951837539673, 0.04188567493110895, 0.029260401148349047, 0.06196389254182577, 0.04842205365587558, 0.07276615646800824, 0.009751968052504318, 0.048157516600830216, 0.012505336781032383, 0.03095070312597922, 0.026226705006722893, 0.032443453025604994, 0.05229700429897223, 0.013831735339148768, 0.05769674187260015, 0.07040047126689128, 0.03276171987610204, 0.04408775516120451, 0.07613684024129595, 0.06655535580856459, 0.174387286018048, 1.5403818637132645, 21.330662216459, 29.687338829040527, 28.28382703236171, 30.69126319885254, 19.34998788152422, 2.9583664323602403, 0.10801533822502409, 0.04126577212342194, 0.7848979341132301, 3.2491229219096045, 3.5056026450225284, 5.855798900127411, 5.847216137817927, 9.274679558617727, 5.37628938470568, 2.250154137611389, 2.70948087317603, 0.6304109266826085, 6.952922931739262, 18.613668169294083, 32.21462447302682, 47.86256177084786, 53.43911647796631, 49.80347503934588, 48.783712250845774, 46.21305595125471, 47.19708068030221, 45.156005655016216, 44.2259475844247, 41.11459289278303, 41.03226716177804, 39.55942971365792, 38.91330630438668, 36.37024130140032, 35.76135676247733, 34.033565589359824, 33.51761320659092, 34.74041278021676, 35.68299150466919, 39.63619341169085, 45.897176946912495, 48.4903176171439, 45.80686773572649, 46.4236558505467, 48.670845712934224, 46.813665185655864, 44.1330258505685, 37.74670723506382, 34.17985643659319, 34.07023818152291, 34.18062073843819, 35.18521908351353, 42.17198712485177, 45.73174728666033, 46.731850147247314, 45.16519117355347, 46.13038975851876, 44.49588162558419, 44.04337671824864, 43.46906988961356, 38.09845978873116, 44.99555090495518, 45.38038035801479, 43.803295612335205, 44.18076344898769, 42.376066139766145, 40.57656608309065, 32.70890889848982, 34.383855547223774, 31.593184539249965, 32.89541939326695, 34.463422843388145, 31.846098967960902, 31.060181277138845, 32.73004879270281, 33.13670253753662, 34.0222122328622, 38.753317083631245, 42.93276275907244, 45.188325200762065, 45.88682065691267, 45.50721624919346, 43.34480135781424, 43.08801678248814, 42.318260601588655, 37.863124302455354, 32.603303228105815, 32.31313255855015, 39.417877537863596, 43.09993641717093, 42.18253796441214, 44.2204897744315, 42.86541734422956, 42.703013624463765, 41.05427210671561, 43.48532520021711, 40.231438636779785, 42.70635918208531, 41.780056612832205, 43.74214104243687, 38.89629364013672, 37.26980025427682, 28.11287702832903, 13.83723327091762, 3.4405394962855746, 0.9983197791235787, 1.911388635635376, 2.3514905742236545, 3.041594994919641, 2.79745266692979, 4.50531097820827, 3.0303295765604292, 3.6916135208947316, 2.620802100215639, 0.1893135772219726, 0.3290387839078903, 0.08599716863994088, 4.884419023990631, 26.434294734682354, 24.90212140764509, 19.84487680026463, 26.772076198032924, 3.8866724712508063, 0.04588845817904387, 0.052861497937036414, 0.03736243836049523, 0.06800407557083027, 0.02465898886189929, 0.015207045245915651, 0.043332189454564025, 0.02969325560012034, 0.04687967570498586, 0.04415460103856666, 0.026654772393937622, 0.021445043285244277, 0.025209050060116818, 0.02737810938352985, 0.030595493436391865, 0.057900234524692805, 0.05962905354265656, 0.03824339055323175, 0.03889621588002358, 0.014947929685669286, 0.007910819258540869, 0.05800422680165086, 0.00942836537225438, 0.058722490045641146, 0.04451299984274166, 0.012988759903237224, 0.04756877212119954, 0.018434838025963733, 0.011839985697796302, 0.020556103039000715, 0.04221505279253636, 0.03945976635441184, 0.05395398342183658, 0.016980026715568135, 0.014555234328976699, 0.04983919779104846, 0.05546266871637531, 0.040252695591854196, 0.015287119163466352, 0.015697146000872766, 0.019146098788561564, 0.052131699597729106, 0.017553319256486635, 0.030744421694959913, 0.03034097495089684, 0.04964151679139052, 0.03451959376356431, 0.02867173809292061, 0.031016069797000716, 0.07122147149805512, 0.04657077942309635, 0.11942848722849574, 2.9371349087783267, 29.24699674333845, 35.612988403865266, 26.865934201649257, 33.15705033711025, 20.236491169248307, 2.9602915176323483, 0.0430594014136919, 0.08131548057177237, 0.07578773397420134, 1.3942549505404063, 4.4261045541082105, 7.9365702867507935, 6.975903230054038, 8.836764999798365, 5.722180264336722, 3.233704217842647, 2.5702363678387234, 1.534960314631462, 8.083429149218968, 18.76164048058646, 34.15669114249093, 48.43505859375, 54.06858158111572, 50.613496031079976, 49.429964201790945, 47.378043038504465, 48.22283976418631, 47.698806626456125, 47.18268401282174, 43.23033673422677, 43.689623083387104, 42.089793409620015, 42.693967069898335, 38.44096776417324, 37.14151913779122, 36.363505022866384, 35.79355124064854, 36.55006068093436, 37.69397735595703, 41.00661441258022, 47.38214594977242, 49.04540572847639, 47.64637551988874, 47.239370891026084, 48.7262784412929, 48.034411566598074, 45.75018433162144, 39.10618134907314, 34.537164075034006, 34.671253885541645, 35.72631352288382, 37.01477009909493, 44.03858246122088, 48.44509179251534, 47.661536489214214, 46.071826866694856, 45.545910767146516, 44.98504522868565, 44.69531576974051, 43.50232744216919, 39.6373051234654, 46.04985318865095, 48.047112873622346, 46.78983981268746, 45.69008241380964, 42.90510892868042, 40.22566468375069, 34.29354286193848, 35.44481420516968, 32.36531352996826, 33.13208198547363, 35.42342070170811, 33.88092408861433, 32.9348087310791, 34.28992632457188, 33.95940746579851, 35.155734402792795, 39.21868658065796, 44.41646024159023, 45.73524917875017, 46.854065486363, 45.55367190497262, 45.388308252607075, 45.97475358418056, 44.72701345171247, 38.69656072344099, 33.332443714141846, 33.88550295148577, 41.48293774468558, 44.333123547690256, 43.87789842060634, 45.43472916739327, 43.1853540965489, 44.27749279567173, 42.24113212312971, 43.7093003817967, 41.296218803950715, 43.89575181688581, 42.7550174168178, 45.04186412266323, 39.7550562449864, 40.714546884809224, 31.0163311958313, 16.230521168027604, 3.5839086260114397, 2.3845034199101582, 2.787598818540573, 4.121303583894457, 4.417208254337311, 5.632472940853663, 5.313294844967978, 6.551532881600516, 4.509168531213488, 0.41025318311793463, 0.2676916186298643, 0.16753242670425347, 0.0627737580133336, 5.382385994706835, 29.805034364972794, 26.865098680768693, 22.88174159186227, 33.40510450090681, 5.452499398163386, 0.15951772034168243, 0.02651535889266857, 0.061164279734449725, 0.0292603231168219, 0.07680298521050385, 0.03918004368564912, 0.03417214990726539, 0.017434433135869246, 0.06885345892182418, 0.05537242016621998, 0.06114995586020606, 0.024911614234692285, 0.08073869187917028, 0.01951905556156167, 0.021089031227997372, 0.06183744754110064, 0.11775276357574121, 0.059397998798106394, 0.04388693254441023, 0.019132673973217607, 0.011388624203391373, 0.05768001598439046, 0.0705056374094316, 0.11777658015489578, 0.17729805197034562, 0.11581363262874739, 0.13004290552011558, 0.09658209101430007, 0.11287271258022104, 0.11839168572000094, 0.14906634044434341, 0.12795301766267844, 0.11029139573552779, 0.15039275426949772, 0.07660318378891263, 0.15872810914048127, 0.17470097275716917, 0.1691954346107585, 0.14193679658429964, 0.06821599562785455, 0.10425675633762564, 0.12835464254021645, 0.1459592878818512, 0.11099454121930258, 0.11088603668447052, 0.09276125353894063, 0.13328042679599353, 0.1420092505535909, 0.0982835582856621, 0.17579683395368711, 0.1143343448638916, 0.24797200677650316, 3.179014946733202, 34.8818051474435, 41.507555212293354, 36.18134062630789, 39.13608292170933, 25.667599235262188, 4.552497063364301, 0.7433629600065095, 0.1683584480945553, 2.1254522119249617, 8.648459264210292, 11.60601818561554, 14.95337973322187, 12.7640266759055, 18.622707775660924, 11.76429293836866, 6.604052143437522, 4.828535965510777, 2.102346194641931, 8.62553802558354, 20.758151497159684, 36.33964490890503, 51.43516220365252, 56.3212605203901, 53.82639169692993, 52.37837321417672, 50.186748095921104, 50.452454158238, 49.186506271362305, 47.77781111853463, 45.06228487832205, 44.313286440713064, 43.542342117854524, 41.76325934273856, 40.49386167526245, 38.79964419773647, 37.8087477002825, 37.390024934496196, 38.01383072989327, 40.122473512377056, 42.92981324877058, 49.08618470600673, 51.64754431588309, 48.88817841666085, 49.23761722019741, 50.827702045440674, 51.3512453351702, 47.43771069390433, 41.572100503104075, 36.05540452684675, 36.2471296446664, 37.37674692698887, 39.36996276038033, 45.52123771395002, 51.36887638909476, 50.273659637996126, 47.82166467394148, 47.93046304157802, 44.88517529623849, 44.307783467429026, 44.60592024666922, 42.836700439453125, 45.88360711506435, 48.71741601399013, 47.28051812308175, 48.79194586617606, 45.712636266435894, 43.34600339617048, 36.798635959625244, 38.603267260960166, 34.78636816569737, 36.478157247815815, 37.5945451600211, 34.959944588797434, 33.30673885345459, 35.81618847165789, 34.94508934020996, 37.85551602499825, 40.63674790518624, 46.42652545656477, 48.49944060189383, 48.39944907597133, 46.85690382548741, 45.08290365764073, 47.99786751610892, 45.914950438908164, 41.30745751517159, 35.71986212049212, 35.71110739026751, 43.366014208112446, 45.23780679702759, 45.187682492392405, 46.549730913979666, 44.61954913820539, 45.44227491106306, 43.62331295013428, 45.747460637773784, 44.0267253603254, 44.93789822714669, 43.52232435771397, 46.124674865177695, 40.9884865624564, 41.00166382108416, 30.451911653791154, 15.91268971988133, 5.403064267975943, 3.344186220850263, 5.2331178443772455, 6.521882746900831, 8.90044697693416, 9.66595607144492, 10.795609831809998, 12.778775095939636, 10.91000063078744, 4.5827595080648145, 0.9318281241825649, 0.6427321455308369, 0.1980462550584759, 7.327132497514997, 34.547426564352854, 31.56195933478219, 28.42673758098057, 39.29144811630249, 6.8003734946250916, 0.1644878943583795, 0.12523853832057544, 0.2347433151943343, 0.19421999608831747, 0.14925956007625374, 0.11350955162197351, 0.13986685765641077, 0.09109567398471491, 0.21840305200644902, 0.17960885725915432, 0.08338666121874537, 0.1190279344362872, 0.14147312646465643, 0.11714236704366547, 0.1894523919160877, 0.11544828223330633, 0.33037001533167704, 0.1291065136236804, 0.1052626912881221, 0.11434703346874033, 0.07105111849627324, 0.1315340269356966, 0.10994127845125538], [0.025264913848202144, 0.003937935656202691, 0.03554831731266209, 0.014322775016937937, 0.03962480642699769, 0.054990588155175955, 0.0207743436497237, 0.030553393731159822, 0.06615035861198391, 0.01769470390198486, 0.016732619277068546, 0.03202105140579598, 0.04237453905599458, 0.0279151817251529, 0.025149495041530048, 0.021119086936648403, 0.01630991740551378, 0.04981048218905926, 0.023295866292236105, 0.0183961225141372, 0.049072371795773506, 0.10019889979490212, 0.02761869245607938, 0.07655246329626866, 0.01201470846509827, 0.022691422208611454, 0.08853383109505687, 0.013218280310476465, 0.027057369272889834, 0.1911789242710386, 9.399581245013646, 32.139361585889546, 28.890720912388392, 41.0040922164917, 28.16593520981925, 11.894159981182643, 1.0775944909879138, 0.12841875052877835, 0.034117320885083506, 0.4874578203473772, 2.3115095538752417, 8.447733623640877, 5.912137499877384, 9.810414331299917, 5.855659936155591, 2.3658870245729173, 2.7048134207725525, 0.34618050551840235, 4.638470598629542, 14.386627333504812, 29.319574151720317, 43.27602808816092, 51.65633378710066, 48.8950640814645, 47.69771923337664, 45.85428919110979, 44.4987199647086, 42.652017320905415, 43.17350046975272, 38.22367327553885, 38.98363249642508, 36.53061614717756, 36.952691418784006, 38.01814556121826, 39.08772693361555, 39.25502218518938, 37.83840261186872, 35.91562761579241, 35.383260113852366, 37.40633583068848, 45.80729157584054, 45.66582972662789, 48.28062445776803, 42.53720876148769, 45.925456115177695, 48.34131697246006, 46.31331845692226, 41.444149426051546, 37.30137634277344, 34.339505195617676, 35.04868350710188, 34.30487537384033, 37.84297800064087, 44.4204763003758, 46.313982009887695, 47.58452960423061, 47.978058201926096, 45.296088286808555, 44.3524603843689, 43.690936292920796, 38.62487963267735, 43.47529547555106, 46.918899127415244, 46.324974060058594, 45.67901740755354, 44.55063690458025, 44.5606701033456, 39.55734525408064, 33.21020405633109, 32.047099930899485, 34.811482429504395, 33.67383650371006, 31.798211983272008, 33.595099517277305, 32.66448906489781, 33.55296911512102, 31.73979500361851, 34.510896410260884, 40.87265314374651, 43.66120147705078, 45.10822984150478, 45.61255093983242, 44.99239294869559, 45.484717982155935, 42.56987919126238, 41.7610741342817, 34.972531250544954, 31.446949277605327, 35.37786831174578, 38.78144686562674, 40.9733429636274, 43.25327968597412, 44.56522464752197, 43.92986747196743, 42.32684857504708, 42.928145681108745, 40.902978556496755, 41.987859862191335, 43.29835959843227, 39.84415299551827, 36.9652224949428, 34.47135421207973, 18.65718994821821, 8.247875639370509, 1.182092357959066, 1.5213929797921861, 1.2556406685284205, 2.9284170908587317, 3.0465019430433, 4.250479715211051, 4.551872594015939, 3.938405283859798, 2.672046801873616, 0.4623001845819609, 0.14449458861989634, 0.058893908347402296, 0.9524587371519634, 12.396653703280858, 30.318554878234863, 18.06057940210615, 25.375641141619, 16.484017508370535, 0.5820984191128186, 0.016440672799944878, 0.06574058452887194, 0.06096954018409763, 0.0411485687696508, 0.010631343499491257, 0.04072688300428646, 0.03902070330721991, 0.031724368754242144, 0.032578695232846906, 0.02391097185734127, 0.05064626091292926, 0.0389348109518843, 0.013953864857155298, 0.02475522717993174, 0.016564746320779835, 0.045219504074858766, 0.07448537421545812, 0.02743441761205239, 0.035229354963770936, 0.07838880297328744, 0.04266639053821564, 0.02548675239086151, 0.1002790347806045, 0.03235795761325529, 0.07135020994714328, 0.1227545573243073, 0.08195506768035037, 0.09484143156026091, 0.02252723030479891, 0.038093369853283675, 0.015599737209933144, 0.010948846998092319, 0.05340641923248768, 0.055464005430362055, 0.009461151336186698, 0.04137595263975007, 0.04583317453839949, 0.06025955506733485, 0.033206614931779246, 0.04725224232035024, 0.015548222831317356, 0.016210841114765832, 0.01715538900212518, 0.11030272048498903, 0.013329754284183894, 0.06412498586411987, 0.0404236864165536, 0.02385474505302097, 0.047241741990936656, 0.04685936036652752, 0.03843113101486649, 0.028877524193376303, 0.29606548324227333, 13.959974067551748, 37.2076347214835, 29.795094966888428, 39.550549915858674, 33.537870679582866, 11.732137543814522, 0.9751683814185006, 0.021557759826204607, 0.05570011865347624, 0.4059292051408972, 2.0729375098432814, 5.712683379650116, 6.5382513999938965, 8.349533864430018, 6.508334628173283, 5.578949664320264, 2.610194589410509, 0.8913091612713677, 4.7393228326525, 15.92561684335981, 31.480255467551096, 46.4645425251552, 52.65880250930786, 51.339426449366975, 48.704367297036306, 48.53195122310093, 45.30308512278965, 45.452526978084016, 44.256641251700266, 41.2111485345023, 40.37028796332223, 38.077667304447715, 37.07075868334089, 39.31266096660069, 39.717379638126914, 39.47294895989554, 37.14758491516113, 37.54507051195417, 36.63675682885306, 39.647400856018066, 48.387977600097656, 48.37227814538138, 48.718232427324565, 44.25816985539028, 48.63021264757429, 49.718863351004465, 48.23085103716169, 43.903120381491526, 37.803425380161826, 35.725511005946565, 36.26792212894985, 35.67800269808088, 40.15795796258109, 46.22659799030849, 49.502545084272114, 48.57739244188581, 48.38386426653181, 47.037487506866455, 44.11170877729143, 44.618399211338584, 39.84746381214687, 43.806769711630686, 46.977514130728586, 48.15124205180577, 47.37731695175171, 46.41408470698765, 45.64040626798357, 41.59673881530762, 34.47461986541748, 34.25245121547154, 36.41822556086949, 35.46147945949009, 32.53726060049874, 34.7598295211792, 33.96829073769705, 34.40842090334211, 34.324712480817524, 36.790061882564, 43.515004430498394, 44.83857372828892, 46.32946259634835, 46.794363089970176, 44.47306374141148, 46.38965136664254, 44.67508608954293, 42.919800894601, 35.74602903638567, 33.65764372689383, 36.456718581063406, 40.796723229544504, 42.43361806869507, 44.659553391592844, 45.97512183870588, 43.59850093296596, 42.97426087515694, 43.65158517020089, 41.44468443734305, 43.161768436431885, 43.18590995243618, 41.52995620455061, 39.898317677634104, 34.978294781276155, 21.88896213259016, 9.978973286492483, 1.6718402611357825, 1.9787592376981462, 2.44098966888019, 4.820891644273486, 3.811366157872336, 5.169528799397605, 5.4685410516602655, 3.7350823198046004, 1.8454823664256503, 0.13680731611592428, 0.032629951768155606, 0.028786417296422378, 0.8420868196657726, 12.923767498561315, 33.8215343611581, 20.37109340940203, 25.910061836242676, 22.576750414712087, 1.100598999432155, 0.039112638016896586, 0.08129451383969613, 0.007414692264449383, 0.04073913734672325, 0.02352559450082481, 0.0333628204784223, 0.041732634750327895, 0.03300663709108319, 0.04355029096560819, 0.039492084977350066, 0.033583646307566335, 0.06463007376130138, 0.01097396042730127, 0.035566875245422125, 0.050803192492042265, 0.0493718330482287, 0.01430147241002747, 0.0417163159831294, 0.045058297725128274, 0.009722411915260767, 0.06242828869393893, 0.012872259681379157, 0.044273853568094115, 0.11777500595365252, 0.12822198894407066, 0.18093019564236912, 0.2517947916473661, 0.14795153455010482, 0.1484884185982602, 0.18202335626951285, 0.0807987761550716, 0.14024311889495167, 0.12257359203483377, 0.14054115861654282, 0.13020056991704873, 0.11282546618687254, 0.10252346577388899, 0.2204391456076077, 0.16145656630396843, 0.1635499961142029, 0.07903774707977261, 0.15154694233621868, 0.1004480646391, 0.16964077071419784, 0.24943473828690393, 0.12203235179185867, 0.12353811599314213, 0.10462389806551592, 0.14789661392569542, 0.14551901364965097, 0.11989369083728109, 0.11421077006629535, 0.44107894759093014, 16.17620015144348, 45.270022119794575, 37.71681955882481, 50.13016544069563, 37.61472620282854, 16.92663860321045, 1.6247365772724152, 0.3475098913269383, 0.4652369927082743, 1.6130330967051643, 6.61623363835471, 18.094938244138444, 13.621310182980128, 20.441145147596085, 15.238224608557564, 6.960429157529559, 7.019481897354126, 1.3450921028852463, 5.6287851844515115, 15.308686290468488, 33.15296827043806, 48.13760968617031, 55.44563463756016, 53.62159006936209, 51.901205675942556, 49.16324717657906, 48.34891830171858, 46.80035591125488, 46.405288287571494, 42.47668995176043, 41.983135087149485, 39.60757378169468, 38.94789791107178, 41.86267416817801, 42.228316170828684, 42.041951588221956, 41.00075708116804, 39.997833251953125, 39.07766246795654, 41.00289017813546, 51.04256466456822, 48.52839027132307, 49.96571200234549, 46.02189016342163, 49.26910645621163, 52.21430540084839, 51.12633909497942, 46.544182777404785, 39.923143591199604, 37.459208147866384, 39.073111397879465, 37.35559661047799, 41.08785275050572, 48.93115997314453, 50.95981856754848, 50.4899640083313, 50.826784883226665, 48.00738307407924, 45.84672607694353, 44.465118476322715, 42.92973681858608, 42.98065321786063, 49.084350381578716, 51.21273647035871, 49.388726643153596, 47.749108110155376, 48.0655186516898, 43.9541722706386, 35.51810032980782, 35.58232600348336, 37.978975091661724, 36.60948167528425, 34.52100256511143, 36.7891377721514, 34.97981643676758, 37.55761548451015, 34.43522357940674, 37.80171264920916, 45.404445443834575, 47.08857066290719, 48.67458036967686, 48.53669684273856, 45.392835003989084, 48.32374497822353, 45.80757992608206, 44.82776927947998, 38.330859661102295, 34.92026342664446, 38.82278864724295, 41.84415374483381, 43.345499651772634, 46.57088817868914, 47.27839197431292, 45.673285143715994, 43.638925552368164, 45.01826804024832, 41.077277592250276, 43.91633585521153, 43.73584597451346, 43.49169669832502, 41.34722900390625, 35.48381444386074, 20.360304594039917, 10.240182995796204, 2.9356814324855804, 4.100093339170728, 3.0290628331048146, 7.760990176882062, 8.873274309294564, 11.775917274611336, 12.414798055376325, 10.337799106325422, 6.72545063495636, 1.0010123146431786, 0.4003720304795674, 0.2509132389511381, 1.5545010375125068, 17.33928516932896, 38.051462173461914, 26.301398277282715, 34.29532854897635, 25.044861725398473, 1.3645175290959222, 0.09913951664098672, 0.18302209196346148, 0.11223002456660781, 0.12714603596499988, 0.10217718899782215, 0.11306040893707957, 0.1315295621752739, 0.12257276422211102, 0.14889598744256155, 0.18435279412993363, 0.12755933164485864, 0.12817983834871224, 0.1630668384688241, 0.14469635779304163, 0.10893993039748498, 0.13999864272773266, 0.1295769012400082, 0.11672829783388547, 0.11418460575597626, 0.1758717985025474, 0.08963401455964361, 0.1303492369396346, 0.131062119400927], [0.028507810817765336, 0.029920245919908797, 0.0753524876864893, 0.05364333991227405, 0.02843703791898276, 0.028101721179804633, 0.03362180033166494, 0.045036428541477234, 0.03045003249176911, 0.046320142157907994, 0.05261578344340835, 0.02141890611632594, 0.005335868768660086, 0.042538544362677, 0.028606798898960863, 0.030956589417265992, 0.008158876394320811, 0.015423514880239964, 0.0485246074385941, 0.09932424779981375, 0.03925257229379245, 0.03853423780362521, 0.025275629612484148, 0.04315215715074113, 0.09108928218483925, 0.035142383737755675, 0.027172382654888288, 0.02010579327387469, 0.06430151353457145, 0.05135810860831823, 2.783779480627605, 27.095634698867798, 30.20861005783081, 24.280644995825632, 29.030817440577916, 25.159588643482753, 7.14514354297093, 1.199147797056607, 0.017348542476871183, 0.17353144979902677, 1.638017407485417, 2.5192613431385587, 4.111649930477142, 5.805609021868024, 1.7023948558739253, 3.9735614316804067, 0.47835296605314526, 1.131432933466775, 2.0228950636727467, 12.026688184056963, 27.033272879464285, 42.16386120659964, 50.81138072695051, 50.22950036185128, 48.39956719534737, 46.4397999899728, 44.9246758052281, 43.56625781740461, 41.30175651822771, 38.98653336933681, 41.10255513872419, 38.33904811314174, 42.31105184555054, 44.66518143245152, 45.83953469140189, 45.05483988353184, 44.66119316646031, 38.4680483681815, 35.56216580527169, 38.103327001844136, 44.49452672685896, 46.90347760064261, 46.645042828151155, 44.80155372619629, 43.985817841121126, 50.00946133477347, 45.76602622440883, 44.12974282673427, 37.54765524183001, 35.100517068590435, 34.15134102957589, 33.85254069737026, 35.90424646650042, 39.48199551446097, 43.56367656162807, 44.73694937569754, 45.43683794566563, 47.60960217884609, 47.47046797616141, 46.55511924198696, 38.03180571964809, 44.81046479088919, 45.77079963684082, 44.95189189910889, 47.0239246232169, 44.807987758091514, 45.657029833112446, 44.47169494628906, 37.96369252886091, 33.018478938511436, 33.635951450892854, 31.935327734266007, 31.98671313694545, 32.18899951662336, 34.06806686946324, 33.40469455718994, 31.61833701814924, 32.96067687443325, 36.95985153743199, 43.192680971963064, 43.962339878082275, 45.162394523620605, 43.84721170152937, 44.04693419592721, 44.08655629839216, 41.14253854751587, 40.93835530962263, 35.20255136489868, 34.69101456233433, 36.2454377583095, 37.65424755641392, 41.06083468028477, 42.927905968257356, 42.19454097747803, 43.961631161826, 41.29514183316912, 39.63551248822893, 42.33914341245379, 40.34407935823713, 36.968759128025596, 36.24268627166748, 21.532899958746775, 11.172129239354815, 4.567174698625292, 0.5151018798351288, 1.2322084116084235, 1.9246379818235124, 4.452456031526838, 2.5871862811701636, 3.582017630338669, 2.3669624754360745, 2.7384351023605893, 1.4029536609138762, 0.061058156857533116, 0.04448509509009974, 0.28442526928016115, 5.576371014118195, 26.617548261369976, 26.755233764648438, 19.58674601146153, 27.70381920678275, 7.868230410984584, 0.06303720601967402, 0.02696367376483977, 0.06550815914358411, 0.011002292657004935, 0.005034773094978715, 0.02642747334071568, 0.05110704047339303, 0.07520963570901326, 0.023064419693712677, 0.03615517867729068, 0.02640335650981537, 0.059363841345267634, 0.04944572551175952, 0.0392542041705123, 0.030251211553279842, 0.020439686785851206, 0.04841644895662155, 0.05112238893551486, 0.056138221573616774, 0.04590700932645372, 0.04094276909849473, 0.04674544790759683, 0.028118396177887917, 0.027345169901049564, 0.030017418919929435, 0.02790121068911893, 0.050155422251139364, 0.053339403721370866, 0.006390612863469869, 0.02582343977077731, 0.07334382047078439, 0.04087663907557726, 0.05014127818867564, 0.03662032800327454, 0.035617365036159754, 0.03167886619589158, 0.03400088766855853, 0.026844568816678863, 0.03232596468712602, 0.01605447950506849, 0.018744372130770768, 0.021114286301391463, 0.022246264220614518, 0.01066216595271336, 0.023643347467961054, 0.0374786714091897, 0.05969765343304191, 0.01638916351034173, 0.031826949678361416, 0.016743353701063564, 0.010587491477573556, 0.03381527441420725, 0.06613090501299926, 0.07611575815826654, 5.079206126076834, 33.10125630242484, 35.27520867756435, 30.884305000305176, 35.921797616141184, 25.71482961518424, 7.554236105510166, 0.6432070114782878, 0.04308325870494757, 0.02570261643268168, 0.3768357134291104, 2.769011301653726, 5.676941411835807, 6.621599384716578, 6.193411869662149, 5.246759763785771, 4.182190648147038, 1.5226173826626368, 2.15001865369933, 12.691260797636849, 28.139815194266184, 42.192727497645784, 50.73896312713623, 50.91283484867641, 49.329069410051616, 47.524187973567415, 46.34855624607631, 44.97791985103062, 43.340465681893484, 39.93499721799578, 41.317862442561555, 39.89104291370937, 43.059320722307476, 42.95908600943429, 47.93042482648577, 46.87229755946568, 46.09343229021345, 39.55970416750227, 36.588553701128276, 39.67733369554792, 47.66601807730538, 48.44979224886213, 47.62533637455532, 45.00495181764875, 45.294517993927, 50.979509762355256, 47.626458508627756, 46.182567255837576, 39.23628289358956, 36.303232874189106, 35.05740349633353, 35.82633978979928, 37.86330842971802, 43.11184910365513, 45.8689637865339, 47.52198886871338, 47.78151798248291, 50.119270665305, 47.582076890128, 46.1465790612357, 39.54377542223249, 44.84544549669538, 46.20419004985264, 45.60659633363996, 47.762149878910606, 46.635516847882954, 46.73901373999459, 44.484816619328086, 38.295125075748985, 34.410654749189106, 35.4530200277056, 33.1355630329677, 33.54420048849923, 33.83484363555908, 35.24318095615932, 34.03863777433123, 33.69090822764805, 34.437176023210796, 38.48862893240792, 46.32743372235979, 44.63103103637695, 47.0851035118103, 45.08757979529244, 44.80880764552525, 45.61112655912127, 43.23301526478359, 41.23226063592093, 35.99428817204067, 36.19179419108799, 37.750448840005056, 39.25081157684326, 42.39069209780012, 43.59276172092983, 43.12068721226284, 44.79027679988316, 41.9482273374285, 41.16389036178589, 42.53928279876709, 41.98841571807861, 39.32065486907959, 38.390572479793, 24.781033413750784, 12.982107179505483, 6.320998166288648, 1.897660732269287, 3.0893493124416898, 4.314477401120322, 4.0018536278179715, 4.973175747053964, 4.419875928333827, 4.763001424925668, 2.3104562503950934, 0.19424761246357644, 0.07691485527902842, 0.10077904723584652, 0.33057352155447006, 5.193395861557551, 28.39851747240339, 30.42883668627058, 20.10834206853594, 32.25449671064104, 10.681957278932844, 0.09824127198329993, 0.05428572937047907, 0.05522192109908376, 0.029873759485781193, 0.03193855172555361, 0.05460494617000222, 0.04229650752885001, 0.04639668769336172, 0.006877517718489149, 0.05226136085444263, 0.03436298109591007, 0.04852689749428204, 0.03358588208045278, 0.038546956942549775, 0.014854517465989505, 0.029297686647623777, 0.029336447960564067, 0.035177962721458504, 0.032456833736172745, 0.05393664345943502, 0.08959868324122258, 0.03570272474150572, 0.012129436862388892, 0.09862985541777951, 0.16437079278486116, 0.14599565735885076, 0.19185071465160164, 0.09584215536181416, 0.1432528831064701, 0.1355146797639983, 0.14232410437294415, 0.13921375413026127, 0.11230948101729155, 0.16193645341055735, 0.11487511013235364, 0.13248635083436966, 0.0928015788750989, 0.16963098623922893, 0.10031919726835829, 0.10065090589757476, 0.08877034126115696, 0.08905269325311695, 0.11151621251233987, 0.36096206520284924, 0.1389417022998844, 0.16060507270906652, 0.19502266230327742, 0.14350502671939985, 0.18602284522993223, 0.11762700389538493, 0.13171858846076898, 0.1469537623758827, 0.14056184036391123, 0.13585838489234447, 5.318197667598724, 37.28573594774519, 42.735659735543386, 34.13682276862008, 37.74092633383614, 31.93304177692958, 9.9575354882649, 1.661990646805082, 0.10650112626275846, 0.9700449534824916, 6.324579528399876, 8.918265632220677, 10.766910297530037, 13.282582896096365, 9.21012818813324, 9.804509231022426, 5.128384607178824, 2.6930627141680037, 3.2211297154426575, 14.084602168628148, 30.054182870047434, 44.62050451551165, 53.944980076381135, 54.25903517859322, 53.99061584472656, 50.36725534711565, 49.36374092102051, 46.24096686499459, 46.147603920527864, 42.67054121834891, 45.59993301119123, 42.323878220149446, 44.93222502299717, 46.95446000780378, 51.28507763998849, 48.30288996015276, 49.26556287493025, 42.43722070966448, 38.95624617167881, 41.95538398197719, 48.43508986064366, 49.90354299545288, 47.462164878845215, 45.90189477375576, 45.784977436065674, 52.05049467086792, 48.884634835379465, 48.28252131598336, 40.42574153627668, 37.79888473238264, 37.437248366219656, 37.2156320980617, 39.82826246534075, 43.60726261138916, 47.02912882396153, 49.068237509046284, 48.49987833840506, 51.231750215802876, 49.13458238329206, 46.678091934749055, 42.37836946759905, 45.24072504043579, 46.96393387658255, 47.338407039642334, 49.92190708432879, 48.443518025534495, 49.38547488621303, 47.212078366960796, 41.47213676997593, 35.942079407828196, 36.774393694741384, 34.99679088592529, 34.50644261496407, 35.804609298706055, 36.63199036461966, 36.54915394101824, 35.04776981898716, 36.64698805127825, 40.072821685246055, 47.71462767464774, 45.579053674425396, 49.11291790008545, 45.8412196295602, 44.614303248269216, 46.092733996255056, 44.13662501743862, 43.97416223798479, 38.466554505484446, 37.63078696387154, 38.88591997964041, 40.34519454411098, 44.82328074319022, 45.66634736742292, 45.20310401916504, 44.12096030371529, 42.122189385550364, 41.91385459899902, 41.82018940789359, 44.24826519829886, 40.95340510777065, 38.05747583934239, 23.64211596761431, 12.45489958354405, 6.4932014516421726, 2.278519941227777, 4.007505553109305, 6.068891031401498, 7.370291233062744, 7.925887431417193, 9.06813132762909, 8.470727818352835, 8.097164000783648, 3.3775992393493652, 0.40824148963604656, 0.3100424361016069, 0.7463277780583927, 8.22188242844173, 33.79373114449637, 34.28856100354876, 26.564295530319214, 37.80727120808193, 11.52336415222713, 0.17096346616744995, 0.23544644032205853, 0.21908725957785333, 0.12581536093992846, 0.08865856618753501, 0.12845859410507338, 0.15547435730695724, 0.1684099081903696, 0.11846280976065568, 0.09569215162524156, 0.11356986659978117, 0.16825972124934196, 0.169099503329822, 0.14519736090941088, 0.10965813257332359, 0.10377446043172053, 0.13234529697469302, 0.1663314061505454, 0.11929192527064256, 0.17071851502571786, 0.21935734365667614, 0.0945557818881103, 0.1346030001129423, 0.19361338578164577], [0.02151450321876577, 0.04607993736863136, 0.07197946296738726, 0.05862724408507347, 0.042104387123669894, 0.019155175890773535, 0.08197712685380663, 0.03326921657259975, 0.030126215224819522, 0.05344081077990787, 0.02618083095044962, 0.05766025025929723, 0.060062963116381846, 0.045785113903028626, 0.1570677610912493, 0.08627587689885072, 0.005293476869285638, 0.053595730502690585, 0.03285305068961211, 0.06706780581069843, 0.07700173490281616, 0.04826562758535147, 0.10174066027892487, 0.017046348424628377, 0.05175687685342772, 0.08552872841911656, 0.049897490734500546, 0.03835409014884915, 0.0355313437591706, 0.024455815121265392, 0.28655133662479265, 11.929182376180377, 30.130078043256486, 24.12559073311942, 26.339898245675222, 30.94716535295759, 23.180090291159495, 7.624970504215785, 0.8091349878481456, 0.03222484600597194, 0.3795991965702602, 1.4993187699999129, 5.668244438511985, 3.8533133012907843, 7.475572075162615, 5.964840454714639, 1.7057259742702757, 1.1302517397063119, 0.15439073688217572, 5.578969640391214, 19.96331753049578, 35.519889490945, 45.68414517811367, 48.72317954472133, 47.00148541586739, 47.46444041388375, 47.62086173466274, 46.65786920275007, 44.94093458993094, 44.71368333271572, 44.69096967152187, 45.775767598833355, 46.17867626462664, 46.966098240443635, 47.72624853679112, 48.37526587077549, 49.46816192354475, 44.799458844321116, 36.37580680847168, 37.29386534009661, 45.04201698303223, 45.60835770198277, 47.90692949295044, 46.86741644995553, 48.27346781321934, 46.612500940050396, 48.92573690414429, 46.707812854221885, 41.73289571489607, 36.76566675731114, 34.0547958101545, 33.77643707820347, 35.30411318370274, 38.3909581048148, 42.13864966801235, 43.24243007387434, 45.05208492279053, 45.59178972244263, 47.570640155247276, 45.43979787826538, 39.446646554129465, 51.300110067640034, 44.916362285614014, 46.699315207345144, 44.11874730246407, 47.92031519753592, 46.88574232373919, 44.02645785467965, 40.33701651436942, 34.622623443603516, 32.70228726523263, 32.702457496098106, 31.80133867263794, 33.04397882734026, 32.1974207333156, 31.354347160884313, 33.606101989746094, 33.964792319706504, 32.73580190113613, 37.62992538724627, 40.65109246117728, 44.832667759486604, 44.089742047446116, 44.19539982931954, 46.38871683393206, 44.92630515779768, 42.31593295506069, 41.196772711617605, 38.516880307878765, 36.60902656827654, 37.72776991980416, 38.38193586894444, 41.662739753723145, 41.959844725472585, 43.46715913500105, 40.64756972449166, 41.70132310049874, 39.84174197060721, 39.08566331863403, 36.792427744184224, 26.218289136886597, 14.829792124884468, 5.070751471178872, 1.6399511780057634, 0.9204407866512025, 1.4563678290162767, 3.7854702217238287, 3.434156055961336, 3.24503955245018, 3.1410519438130513, 4.750744368348803, 1.4751469641923904, 0.4307224947427, 0.08037197762834174, 0.24443721930895532, 2.8066553388323103, 15.04445150920323, 27.23955273628235, 20.595770359039307, 26.623275314058574, 16.62993836402893, 1.0681805504219872, 0.11380968801677227, 0.012441889515944889, 0.04429492886577334, 0.049063727259635925, 0.039804258583379645, 0.10326734371483326, 0.027069755929655263, 0.06154516179646764, 0.0585043817492468, 0.028586785508585826, 0.034971467551908324, 0.015210314088367989, 0.00934404382548694, 0.0455734211552356, 0.06394115037151746, 0.0775038440312658, 0.03994403340454612, 0.013774649339861103, 0.035575540137610266, 0.06060669358287539, 0.0485608547792903, 0.020884846470185688, 0.03680944928367223, 0.009268844333876456, 0.009256940285143043, 0.032702982492212734, 0.03751984152144619, 0.07836099660822324, 0.01750308900539364, 0.020249116833188703, 0.01970151362807623, 0.05239991770525064, 0.07141988870820828, 0.013021288872031229, 0.03543776699474879, 0.06336668905402933, 0.05155455806691732, 0.04773037541391594, 0.034887841503534994, 0.02032536550957177, 0.041473905955042155, 0.031179983501455615, 0.026986151933670044, 0.150754182732531, 0.05325579124369791, 0.06526926731956856, 0.04451324411534837, 0.06661748926022223, 0.08460277917661838, 0.007645985344424844, 0.0022154077180727783, 0.041849254563982995, 0.023995797216360058, 0.04895049333572388, 0.7139546009046691, 18.067984444754465, 34.47509581702096, 26.1742844581604, 29.695871216910227, 37.77051523753575, 24.113295895712717, 6.637009620666504, 0.6053303724953106, 0.06015219047133412, 0.33465906232595444, 0.49509655045611517, 4.908979168960026, 7.655650275094168, 6.913664741175515, 5.449988058635166, 4.7611870765686035, 1.5376934536865778, 0.9396433276789529, 7.722016862460545, 21.521154029028757, 38.438984053475515, 48.32075725282942, 51.16587781906128, 47.160008566720144, 49.507509572165354, 49.69642761775425, 48.334629331316265, 45.95840794699532, 45.13814183643886, 45.18236364637102, 47.85088879721505, 47.3260566166469, 48.805706773485454, 49.930960587092805, 49.82473305293492, 48.98018993650164, 45.83794355392456, 38.271827765873496, 39.35388115474156, 47.04173285620553, 49.21458741596767, 48.263934884752544, 48.49319417136056, 49.00367137363979, 48.8851455279759, 50.24975436074393, 48.464911528996055, 43.577760560171946, 38.3891133580889, 34.92394249779837, 35.83038016727993, 37.33455399104527, 39.56320605959211, 44.146140575408936, 45.40958016259329, 47.453107901981895, 47.31802797317505, 49.319025788988384, 46.311004706791465, 39.79008558818272, 50.023163182394846, 46.007889543260845, 45.96529361179897, 44.72494636263166, 48.4388245173863, 47.67712477275303, 46.47572565078735, 40.83142253330776, 36.539287499019075, 34.52028342655727, 34.07249982016427, 32.88555989946638, 34.08940131323678, 34.323013646262034, 33.31969724382673, 34.509232316698345, 35.19092355455671, 34.78199427468436, 38.49801942280361, 43.53538697106497, 46.3922951562064, 45.68480178288051, 44.03517436981201, 46.13146325520107, 46.742783137730186, 44.5967903137207, 42.22128111975533, 39.44810220173427, 37.36668593542916, 38.11101170948574, 39.42400932312012, 42.18208285740444, 43.541365895952495, 45.01884126663208, 41.56320333480835, 42.3213768686567, 42.19206394468035, 40.934697083064485, 38.85253388541085, 29.038034881864274, 16.599527835845947, 7.053022154739924, 3.001278289726802, 2.3029298314026425, 3.2278853186539243, 4.736073247023991, 4.510588135038104, 6.857161555971418, 5.340435377189091, 3.169572344848088, 1.1713617337601525, 0.07985309511423111, 0.095692931940513, 0.06789409182965755, 2.52415200642177, 17.557656628744944, 33.57285833358765, 23.14800524711609, 28.232333932604107, 23.11762945992606, 1.7885766199656894, 0.05385650847373264, 0.03837203061474221, 0.05165916781074234, 0.02023058264915432, 0.053786117250898054, 0.06395752342151743, 0.04768475750461221, 0.02424022418979023, 0.03998261151303138, 0.09299304788666111, 0.0599118737237794, 0.040760009083896875, 0.046362648984151225, 0.053659098888082166, 0.020266621340332285, 0.05191314007554736, 0.044769659106220515, 0.0655578143362488, 0.004406454332638532, 0.05177922101159181, 0.048098992955471785, 0.013580706219987145, 0.026767197164839933, 0.04228030411260469, 0.12151860578783921, 0.1903345552938325, 0.13597487578434603, 0.15477611763136728, 0.17529437877237797, 0.1114830117938774, 0.21156588888594083, 0.12449904371585165, 0.26022412361843245, 0.09569801416780267, 0.10086513975901262, 0.09250285383313894, 0.21670718943434103, 0.10769967016364847, 0.19675216664161, 0.2179835138044187, 0.11929587434445109, 0.12908363342285156, 0.1238538519080196, 0.2003653384745121, 0.19879922536867006, 0.23038826031344278, 0.20351816500936235, 0.20267621161682264, 0.1009305166080594, 0.1819032555712121, 0.14491278332258972, 0.1687035510050399, 0.11812745061303888, 0.11168147650148187, 0.5802038407751492, 19.531935146876744, 41.09911230632237, 34.73830052784511, 33.95385932922363, 41.44398266928536, 29.191209656851633, 10.068950721195765, 1.4225283648286546, 0.1694148728357894, 1.175853309886796, 7.634615472384861, 15.143795115607125, 11.122872591018677, 15.17959918294634, 13.385141781398229, 6.948093933718545, 2.7550067731312344, 1.0803333840199878, 6.387494163853781, 23.04465253012521, 37.67698553630284, 49.76400579724993, 52.89190067563738, 49.81028079986572, 51.716821329934255, 53.18999229158674, 49.946851117270334, 48.268214975084575, 47.748097147260395, 47.39397178377424, 50.12911626270839, 49.69273117610386, 50.00003262928554, 50.76190955298287, 50.521765913282124, 52.56856625420706, 48.70603139059884, 40.200480937957764, 39.95947919573103, 49.7432723726545, 49.57773848942348, 50.32141808101109, 49.112890107291086, 50.533299922943115, 50.54455600466047, 52.313508306230815, 51.241317885262625, 45.73418263026646, 41.20536068507603, 37.26753861563546, 36.9478554725647, 39.32638018471854, 42.16882916859218, 46.53109237125942, 47.829380648476736, 48.94334363937378, 50.23318638120379, 51.61568335124424, 46.93805878502982, 42.44990464619228, 51.40308237075806, 45.91939728600638, 47.726863452366416, 45.942135265895296, 50.826329776218955, 49.68079764502389, 48.14110115596226, 43.11114386149815, 39.343476227351594, 37.67394222532, 36.06457962308611, 35.30333151136126, 35.419668674468994, 35.598206111363, 34.04613140651158, 36.82480982371739, 37.200822012765066, 36.395661285945344, 40.76450790677752, 45.11038030896868, 49.30744661603655, 47.86008473805019, 43.66713523864746, 47.32915203911917, 49.22668770381382, 45.303731305258616, 44.47382109505789, 40.54648733139038, 39.62186970029558, 40.22065503256661, 41.321197577885215, 45.50694179534912, 45.11715480259487, 46.54727472577776, 43.426303727286204, 44.02093056270054, 44.14853770392281, 41.347003187452046, 38.03892067500523, 28.47528464453561, 17.16753785950797, 6.913631737232208, 3.0069104560783932, 4.089880355766841, 4.745134132249015, 8.924301011221749, 7.567608782223292, 10.549339618001666, 9.951850993292672, 12.704294749668666, 4.027153321674891, 1.4801431532417024, 0.4137013080929007, 0.5123062612754958, 3.8671740889549255, 19.32100347110203, 35.65847826004028, 28.228437730244227, 36.61043357849121, 25.502355439322336, 2.1512662896088193, 0.2823473779218537, 0.059554326481052806, 0.11465244208063398, 0.12052244852696146, 0.15202620519059046, 0.1540126164576837, 0.09135662498218672, 0.182721202394792, 0.13545670573200497, 0.1579063218086958, 0.2023521704333169, 0.12114135388817106, 0.17060418187507562, 0.14922765535967691, 0.14743484370410442, 0.1162729329828705, 0.16488322243094444, 0.0933116947167686, 0.14888654223510198, 0.09942274394312076, 0.14573201936270508, 0.09814546283866678, 0.09856285008468799, 0.15481011223580154], [0.03551394272861736, 0.011526898613997867, 0.01801990538037249, 0.03994176031223365, 0.01338646115202989, 0.03034841169470123, 0.028180505880819898, 0.062354701571166515, 0.03528647404164076, 0.028410461398639848, 0.012081701923826975, 0.05142958548718265, 0.05372570388551269, 0.10847643669694662, 0.02020868462776499, 0.018189946256045784, 0.02178409875237516, 0.027427040240062133, 0.027627192803525498, 0.029513406500752484, 0.08961099865181105, 0.059670871655855856, 0.026462918313752328, 0.09693941434047051, 0.0577746784048421, 0.036694678477942944, 0.015791632002219558, 0.01122830927904163, 0.07087937449770314, 0.05705450847744942, 0.03996516637770193, 3.8016456280435835, 26.59938567025321, 29.64573996407645, 27.404332739966257, 25.46047690936497, 28.220483779907227, 20.569210869925364, 5.951278873852321, 0.23633950097220285, 0.06460518509681736, 0.41942830649869783, 1.7013870413814272, 8.189875551632472, 4.490024941308158, 2.479594511645181, 6.116334634167807, 1.4465981189693724, 0.6153364841427121, 1.0906548244612557, 10.20200959273747, 25.94236053739275, 39.13734401975359, 49.7161466053554, 52.06227534157889, 48.29892948695591, 49.12339925765991, 48.334031786237446, 46.49547243118286, 48.27916881016323, 47.632013593401226, 48.15496628625052, 47.10319314684187, 49.057380948747905, 49.31821979795183, 48.59517288208008, 49.01108162743704, 44.526286942618235, 39.821689469473704, 37.55450963973999, 46.16591937201363, 47.79281922749111, 48.13988869530814, 43.605987616947715, 40.81682089396885, 48.585959570748464, 47.09343440192086, 47.30571229117257, 42.780103887830464, 38.58496917997088, 33.47471155439104, 35.01251813343593, 33.75922291619437, 37.961628913879395, 39.10143225533621, 42.464409010750906, 44.7786420413426, 46.14553683144705, 46.28647061756679, 48.87140546526228, 39.12837389537266, 40.615569795881, 46.746889523097444, 46.163668155670166, 48.7447953905378, 48.603990146092, 47.00005061285836, 44.56467921393258, 40.017778056008474, 35.43502071925572, 31.66462939126151, 32.148432459150044, 33.98730795724051, 32.94354609080723, 33.8565046446664, 32.79375682558332, 34.56427942003523, 35.44049589974539, 35.99153668539864, 35.29540709086827, 39.662318638392854, 43.58891241891043, 44.806490421295166, 46.360844135284424, 46.502549171447754, 43.72000060762678, 41.87412479945591, 42.863753250667024, 41.314905984061106, 43.058969838278635, 39.48800570624215, 42.30979074750628, 40.61732769012451, 43.21644728524344, 43.675146511622835, 43.92389896937779, 39.12208924974714, 40.8226261138916, 43.1417680467878, 31.572972229548864, 16.023497853960308, 7.0686503904206415, 1.8434035522597176, 1.9245695854936327, 1.968640923500061, 3.358691453933716, 4.841212519577571, 3.595355131796428, 4.960275547845023, 3.5525815870080675, 1.7539473410163606, 0.38009726841534885, 0.04584032290482095, 0.2895981217069285, 1.9145400779587882, 12.756946461541311, 24.397736038480485, 30.93497473852975, 21.44820315497262, 24.977335657392228, 7.222407077039991, 0.10972428973764181, 0.030973752960562706, 0.05696630571037531, 0.01639286322253091, 0.05757289566099644, 0.013250238461686032, 0.02871720672452024, 0.035771467124245, 0.03717650280201009, 0.029649320457662855, 0.06571551265993289, 0.036221376553710015, 0.04974370416519897, 0.03349120269662567, 0.008798899461648293, 0.024444819461288195, 0.07223020201282841, 0.05284454473959548, 0.0490984309331647, 0.03678964623915298, 0.057129350890006335, 0.022086645642827665, 0.014290627724091922, 0.01404016263716455, 0.020478191951821958, 0.0294778546584504, 0.05405280526195254, 0.04676746636895197, 0.014603591823418225, 0.023572829019810473, 0.03773502872458526, 0.019732590531930327, 0.004157251320845846, 0.041575377474405935, 0.01818548488829817, 0.017248031084558794, 0.0604778669242348, 0.04777577279933861, 0.05305790329085929, 0.017295562462615113, 0.02143509765820844, 0.008021462875019227, 0.02488838119565376, 0.03905040957033634, 0.08793342259845563, 0.05763693579605647, 0.0384940278184201, 0.0358362773965512, 0.051536084951034615, 0.02552173426374793, 0.014295791375583835, 0.014936594758182764, 0.062458714204175134, 0.03016899007239512, 0.029477576459092752, 0.06944581320775406, 6.195402962820871, 32.57217877251761, 33.44293049403599, 30.25662558419364, 33.82164205823626, 36.71771376473563, 23.078111580439977, 5.137115887233189, 0.200321817238416, 0.02652285331194954, 0.2138294138546501, 0.8915758526750973, 4.564278602600098, 3.8598202892712186, 5.301386501107897, 4.377128873552595, 3.7610920327050343, 1.1581561395100184, 1.7342951212610518, 11.001529250826154, 28.49011904852731, 41.84746108736311, 51.44246823447091, 52.63173232759748, 50.07672684533255, 49.834106172834126, 48.133541515895296, 48.75796570096697, 49.37225593839373, 48.05511025020054, 47.922531672886436, 49.55411808831351, 50.26382098879133, 50.257230622427805, 50.76862151282174, 50.74217666898455, 45.900640623910085, 40.17766652788435, 39.56361600330898, 48.546316623687744, 48.405702454703196, 49.90219851902553, 44.57732840946743, 43.79452003751482, 48.98273645128523, 47.461761883326936, 49.43766975402832, 44.81411606924874, 40.828942026410786, 35.0390567779541, 36.895664078848704, 35.20017160688128, 39.93027591705322, 40.99893317903791, 43.859464849744526, 46.43785449436733, 48.12689208984375, 47.36353519984654, 49.69701474053519, 41.75117642538888, 43.6488857950483, 47.11732925687517, 46.38724034173148, 48.314410073416575, 48.668462480817524, 48.87389986855643, 45.783949102674214, 42.440663542066304, 36.60003559929984, 34.25966344560896, 33.00097642626081, 35.435354232788086, 34.304687772478374, 35.163940225328716, 34.37615346908569, 35.84409243719918, 37.29196500778198, 38.54615306854248, 36.6172775541033, 42.20226042611258, 45.246655327933176, 46.23139572143555, 45.130940028599326, 46.391732352120535, 46.02145937510899, 43.88841451917376, 43.99781043188912, 42.29451165880476, 42.56221880231585, 41.884484563555034, 43.73093359810965, 41.96716117858887, 43.905614784785676, 44.733120918273926, 42.863378047943115, 42.08479070663452, 42.17723648888724, 43.47175536836897, 32.506257738385884, 19.349532774516515, 9.028068883078438, 2.354854805128915, 2.3561790883541107, 3.265594712325505, 3.8394907287188937, 5.085317935262408, 6.202993869781494, 8.72935106073107, 4.963249811104365, 1.5929207759244102, 0.21039929719907896, 0.026220443824838315, 0.0402589686481016, 2.5561410784721375, 12.706550308636256, 27.389883960996354, 30.211764539991105, 23.030288866588048, 29.21020950589861, 10.53599647113255, 0.09568347316235304, 0.025666165531479886, 0.008804745889002723, 0.023699967822592174, 0.08874510654381343, 0.04046037819768701, 0.03250555594318679, 0.024919466581195593, 0.042255829354482036, 0.030738627005900656, 0.0718160310227956, 0.10056660470685788, 0.033067057241818736, 0.05541248426639608, 0.03338346829903977, 0.03157241762216602, 0.06352256890386343, 0.005464265405732606, 0.02767061734838145, 0.030080906048949276, 0.04500372315357838, 0.04265660606324673, 0.033247150613793304, 0.03401163566325392, 0.030398806490536247, 0.1411812478410346, 0.07939422223716974, 0.09371857824070112, 0.14999241860849516, 0.10845203657767602, 0.08462420731250729, 0.1136007806552308, 0.10940604324319533, 0.10993186717054673, 0.0980923403320568, 0.0915608097399984, 0.19797218617584023, 0.12053167660321508, 0.1360536537000111, 0.06929578232978072, 0.08973920105823449, 0.10349171488944973, 0.16929364576935768, 0.10873467355434384, 0.1537309837128435, 0.1539339471076216, 0.13882256512131008, 0.12959142188940728, 0.13371945252375944, 0.1707865720880883, 0.10534520114638976, 0.1309954465499946, 0.07644770427473954, 0.15580493956804276, 0.11702308058738708, 0.19146408539797577, 6.268967015402658, 37.25846426827567, 41.37668589183262, 37.776250975472585, 35.81037630353655, 37.266343525477815, 25.629073211124965, 8.530203529766627, 0.5308615884610585, 0.3372398024158818, 1.4862253240176608, 6.1302770631653924, 14.711146422794886, 12.4254618031638, 10.878418462617056, 12.081249782017299, 4.854950845241547, 2.0230781052793776, 2.0661595421178, 11.109776973724365, 28.8428304536002, 42.38944142205374, 53.08099242619106, 55.92170088631766, 51.519197191510884, 52.024626527513774, 50.85030800955636, 49.64862748554775, 52.29258380617414, 52.39610154288155, 51.10160003389631, 51.96490328652518, 50.439075401851106, 51.4924327305385, 51.198784487588064, 52.09459836142403, 48.388814858027864, 43.196026529584614, 41.70731592178345, 51.46924311774117, 50.47493158067976, 50.118124212537495, 44.9526492527553, 44.921764510018484, 49.26307541983468, 49.19429520198277, 51.32082264763968, 46.53984710148403, 42.02435874938965, 37.494984422411235, 38.67132486615862, 37.49021100997925, 41.33447905949184, 42.10939080374581, 47.033457551683696, 48.75872652871268, 49.317483288901194, 49.03911760875157, 50.24300071171352, 45.45796046938215, 43.55046108790806, 47.2608825138637, 48.94865901129586, 50.710951464516775, 51.178540910993306, 50.757427964891704, 48.39502307346889, 44.77794374738421, 38.22423955372402, 35.04675885609218, 35.03663880484444, 38.03290353502546, 35.08477939878191, 35.97627149309431, 35.70939465931484, 37.97509799684797, 38.70867143358503, 40.34521538870675, 37.98841421944754, 44.51322085516793, 47.94993536812918, 46.90812247140067, 45.888832160404746, 46.31229012353079, 47.441257749285015, 44.74794142586844, 45.76667935507638, 43.30718033654349, 46.19455984660557, 43.32135813576834, 45.750882625579834, 43.78090156827654, 45.976254395076204, 46.09266798836844, 43.68943895612444, 44.44287381853376, 43.742738587515696, 43.16294615609305, 33.397683824811665, 18.09860863004412, 9.177180698939733, 3.236335196665355, 3.9764240894998824, 5.283394140856607, 6.612576280321393, 12.482776624815804, 10.573581882885524, 12.147282855851309, 10.530533449990408, 6.561435801642282, 1.352876256619181, 0.10287260596773454, 0.46029144951275414, 3.25089145558221, 16.36082594735282, 31.97703082220895, 37.203521387917654, 29.46389865875244, 34.58406094142369, 11.21701373372759, 0.18915846411670956, 0.1243549364485911, 0.09760579679693494, 0.15499665508312838, 0.17198101085211548, 0.11953823348241192, 0.19855333784861223, 0.17651010996529035, 0.11372981765972716, 0.09883980772324971, 0.1501373401177781, 0.1454682999423572, 0.14881220193845884, 0.2164101539445775, 0.06835901045373508, 0.11026563854621989, 0.19692949498338358, 0.08181880427790539, 0.09833525586873293, 0.10303175635635853, 0.1597412840596267, 0.08828619974000113, 0.09336699532078845, 0.10722251755318471, 0.07429350486823491], [0.013324220831106817, 0.05226611738492336, 0.05103750081200685, 0.026875387877225876, 0.033450802721615346, 0.0445810569051121, 0.04480345015014921, 0.0066322362150198644, 0.0407802769249039, 0.011066636436485817, 0.02881195056917412, 0.04469585824491722, 0.05508161362792764, 0.08599509232278381, 0.04027793709454792, 0.01702961405473096, 0.03076974122918078, 0.04891027317249349, 0.011599838583996254, 0.04777299080576215, 0.03640765816505466, 0.04135759148214545, 0.052992903028747866, 0.038460433549646816, 0.04431501350232533, 0.056049140103693516, 0.058242304383644035, 0.040143108793667386, 0.021296824095770717, 0.030876691918820143, 0.009286313217931559, 0.18529595780585492, 9.856622457504272, 28.21832983834403, 29.432788099561417, 20.11744941983904, 28.27614058767046, 32.11670003618513, 20.33417763028826, 3.2787943354674747, 0.10528044176420995, 0.11928177438676357, 0.9075607806444168, 2.6481667118413106, 2.3796442406518117, 2.94631912452834, 2.7373031973838806, 2.3230133822986057, 1.4119421328817094, 0.7668825036713055, 0.9000556947929519, 11.960290329796926, 23.784184047154017, 41.19546297618321, 48.38498640060425, 52.53738273893084, 49.506095613752095, 48.73858370099749, 48.79465218952724, 50.984783445085796, 49.809349741254536, 50.227294308798655, 47.39367995943342, 48.70361341748919, 49.36238602229527, 48.65545545305525, 47.25515719822475, 43.29054287501744, 37.883201122283936, 39.723580905369346, 44.79996606281826, 50.737646443503245, 48.20387118203299, 46.21678365979876, 42.912890911102295, 47.40181629998343, 49.53079298564366, 50.200050422123496, 43.4163156918117, 40.14954021998814, 34.35726826531546, 35.54920046670096, 35.638446603502544, 36.90577718189785, 38.025666986192974, 41.80536195210048, 42.3601929800851, 47.71570464542934, 47.270106247493196, 49.78388459341866, 35.69162116731916, 41.588581630161826, 50.06656857899257, 47.64590651648385, 46.029654775347026, 46.44323240007673, 46.19729743685041, 45.16652870178223, 39.53895684650966, 35.383096831185476, 32.26180968965803, 34.40936933244978, 33.32337978907994, 34.17083420072283, 34.615042958940776, 36.27781636374337, 40.076003960200715, 42.68244000843593, 41.87746688297817, 41.97160107748849, 40.90960018975394, 45.06642600468227, 43.62627983093262, 44.86913537979126, 42.9195750781468, 42.50398594992501, 44.44277654375349, 42.28989110674177, 44.10512883322579, 43.20700120925903, 43.773136956351145, 41.072021280016216, 42.402382441929404, 42.657561983381, 42.066176482609336, 38.04097039358956, 38.59032276698521, 39.94679178510393, 33.97971357618059, 18.261736699513026, 8.413028240203857, 2.4696614103657857, 0.6437694355845451, 2.017187769923891, 1.5456847505910056, 2.8804712636130194, 2.7844434678554535, 4.698310221944537, 5.844993148531232, 4.698869117668696, 0.9743021364722932, 0.20415395232183592, 0.15109682934624807, 1.7851661401135581, 10.085762756211416, 22.293114525931223, 28.435089315686906, 25.126369306019374, 23.521041870117188, 14.214447498321533, 0.9025494466934885, 0.027850195033741847, 0.016580990449126278, 0.021370959135570695, 0.05022912472486496, 0.03471682693010994, 0.024485117656045725, 0.04661794099956751, 0.018616897453154837, 0.037406563492757935, 0.019457590466897403, 0.01111230778042227, 0.028904044734580175, 0.05472897897873606, 0.03223747354266899, 0.013128280273771711, 0.039963310584425926, 0.00819882853621883, 0.035520633083901236, 0.038930091740829606, 0.025440396574724997, 0.029244866089097092, 0.015393930753426892, 0.033918717077800205, 0.04366840355630432, 0.04115607336695705, 0.005473821723301495, 0.10572540467338902, 0.0351654132162886, 0.021868343963953, 0.04359629903254764, 0.034217421763709614, 0.04496771330013871, 0.04050534810604794, 0.024225533906636492, 0.01656793204269239, 0.02372933821087437, 0.10660490819386073, 0.0036735207374606815, 0.03382180192108665, 0.06025358395917075, 0.06938327942043543, 0.04778367433963077, 0.036434439942240715, 0.03112476092896291, 0.07452040019312076, 0.016173078944640498, 0.05733572053057807, 0.08083716766642672, 0.03988145551245127, 0.04312539572960564, 0.05300433973648718, 0.06239151888127838, 0.025841414163421308, 0.023641240616728152, 0.05008357896336487, 0.014918720449454017, 0.38382720255425995, 15.530248710087367, 35.57764639173235, 32.127490588596885, 23.34077606882368, 31.293119634900773, 38.22631706510271, 20.041840859821864, 3.393531024456024, 0.0648801274863737, 0.06625135854950973, 0.250765399741275, 2.6766773419720784, 3.35128966825349, 4.3418563434055875, 6.767738674368177, 3.5512158317225317, 2.6657632419041226, 1.6503119191953113, 2.8899060487747192, 12.6665312903268, 28.10527048792158, 43.054905142102925, 51.8231600352696, 53.47941950389317, 50.186664717538015, 49.94345692225865, 51.30832631247384, 52.17727845055716, 49.80542400905064, 49.922761712755474, 49.3942608833313, 49.61221545083182, 50.66607304981777, 51.39203820909773, 49.62565326690674, 45.12479782104492, 40.75355407169887, 40.83991323198591, 46.63276536124093, 51.14194474901472, 48.91428974696568, 45.64671523230416, 43.474360942840576, 47.86533062798636, 50.392341818128315, 49.75292689459664, 44.94537796292986, 41.466762338365825, 35.208120346069336, 36.87843949454171, 37.01496464865548, 38.63491977964129, 41.071378571646555, 42.941736357552664, 44.859647614615305, 49.224735260009766, 50.03308173588344, 50.446013178144185, 38.07388053621565, 40.64240721293858, 49.220736571720664, 49.177689007350374, 48.25722639901297, 48.255624839237754, 48.78735658100673, 46.367034980228965, 41.865953717912944, 37.944657938820974, 33.856428214481895, 35.746796812329976, 34.576084409441265, 35.400752203805105, 35.61942938395909, 36.10910715375628, 41.267654759543284, 43.995378562382285, 43.153020654405864, 42.738136768341064, 42.647987365722656, 47.03485413960048, 44.71213388442993, 43.646394865853445, 44.640765462602886, 42.66264111655099, 45.13635614940098, 44.59494209289551, 44.62687948771885, 44.362396308353965, 45.271359648023335, 43.005836963653564, 43.17855528422764, 44.994164739336284, 43.24912813731602, 40.88571228299822, 39.90158333097185, 42.143669741494314, 34.106601578848704, 20.33989599772862, 10.829443216323853, 3.8013820307595387, 2.309619643858501, 2.621744666780744, 3.525311210325786, 2.559677060161318, 5.224526396819523, 5.438100125108447, 8.508138656616211, 2.718253408159528, 0.19841712872896874, 0.23672395891376904, 0.034507071399795156, 1.7143328381436211, 8.739306960787092, 26.710872990744456, 29.996891498565674, 29.058799573353358, 27.36808225086757, 19.733879327774048, 1.9925468521458762, 0.013226225107376064, 0.008042960560747554, 0.050320693025631566, 0.0437520499607282, 0.010804293594057006, 0.017820672231859395, 0.051943070255219936, 0.02784656996040472, 0.03495692654645868, 0.06551226428044693, 0.041468328397188864, 0.020373678899237087, 0.03196005789296968, 0.016969921632802913, 0.028104684681498578, 0.03532047543142523, 0.05821526476315089, 0.018955204835427657, 0.03081742867029139, 0.024910905165597796, 0.062357727837349684, 0.05261888774111867, 0.03866757332746472, 0.03854296376396503, 0.07340955694339105, 0.10875825943159205, 0.21455752264176095, 0.11585795453616551, 0.08960333120610033, 0.1535885456417288, 0.09090217615344695, 0.13179765136114188, 0.06727213306086403, 0.08332562020846776, 0.09678512904793024, 0.10811135771551303, 0.22011160318340572, 0.12598872663719313, 0.10657055396586657, 0.1720463266330106, 0.13448364580316202, 0.10146313945629767, 0.13402035566312925, 0.12222786487213202, 0.19565478552665028, 0.13120747517262185, 0.0846041226759553, 0.13785622268915176, 0.10124657143439565, 0.12389547324606351, 0.1673419347831181, 0.17134614634726728, 0.13674318098596164, 0.10842944814690522, 0.1244466065296105, 0.15227255411446095, 0.48199490777083803, 15.637980529240199, 41.495823178972515, 39.703858443668906, 29.459691524505615, 37.93685858590262, 40.41966186250959, 26.24893937792097, 4.439022123813629, 0.3396952035171645, 0.3402907672737326, 3.2008444496563504, 9.663195031029836, 10.236347590173994, 9.549150773457118, 9.034105130604335, 5.550142432962145, 4.733775998864855, 2.5122847003596167, 1.4664711611611503, 13.530886326517377, 25.19966411590576, 44.774254253932405, 51.813481194632395, 55.56548064095633, 52.705598626817974, 53.44454302106585, 53.836574281964985, 55.121400424412315, 53.056718894413535, 53.11372538975307, 49.47713204792568, 50.66515588760376, 52.31453316552298, 53.352660042899, 52.127967085157124, 46.98469161987305, 42.02798918315342, 42.48577472141811, 48.60666172845023, 53.85784271785191, 50.09636245455061, 46.40373536518642, 44.38171230043684, 50.36341299329485, 51.555862835475374, 51.70532553536551, 45.75506544113159, 44.12534809112549, 38.68055902208601, 39.470999990190776, 39.53947101320539, 39.62937722887312, 42.33816719055176, 44.378759316035676, 47.592773641858784, 50.35754523958479, 51.03237860543387, 50.755499839782715, 39.86821460723877, 43.56827279499599, 50.77866513388497, 51.93667622974941, 48.59935917173113, 49.74185494014195, 49.6939366885594, 49.48784964425223, 43.3343825340271, 40.06363269260952, 34.60651751926967, 38.488958971840994, 37.00012329646519, 37.66023342950003, 37.443807465689524, 39.40917839322771, 43.44855880737305, 45.985724789755686, 46.373295307159424, 45.15284422465733, 44.572301387786865, 49.012328829084126, 46.1139121055603, 44.02432475771223, 43.80169405255999, 43.48491178240095, 45.14651788984026, 45.154160908290315, 45.95954050336565, 46.44055386951992, 47.40896947043282, 44.0313389641898, 45.26172597067696, 46.41169800077166, 44.1072758265904, 42.23780393600464, 42.55210222516741, 43.598014559064595, 37.336179869515554, 21.109415939876012, 11.138405288968768, 3.7525431428636824, 1.9646361555371965, 4.714930747236524, 3.6648890120642523, 5.76980538879122, 7.009728363582066, 11.311744604791913, 14.365998131888253, 9.086131504603795, 2.18550158398492, 0.8281746261886188, 0.3462992491466658, 2.713319535766329, 13.271779315812246, 28.964033092771256, 34.220489501953125, 33.49384689331055, 34.36875363758632, 22.694075959069387, 2.1234348458903174, 0.1064728449231812, 0.07940659871590988, 0.1534718240478209, 0.12278781911092145, 0.13538247400096484, 0.13980371318757534, 0.13829484129590647, 0.17377074195870332, 0.17974256936992916, 0.13726007539246762, 0.1428089447851692, 0.1310882701405457, 0.15042216197720595, 0.06922081099557024, 0.20244397622134003, 0.14863814413547516, 0.15788545007152216, 0.12859605172915117, 0.1388720167534692, 0.13181309481816633, 0.1556615922600031, 0.14176790921815804, 0.09128282072820834, 0.14827461221388408, 0.17908919442977222], [0.01774723269045353, 0.12408492022327014, 0.04803511906149132, 0.037696755956858397, 0.05787242815962859, 0.007524801534600556, 0.009184990128103112, 0.017900037080315605, 0.02798003949491041, 0.03983494193692293, 0.013181701335789902, 0.015102725575811096, 0.04630255792289972, 0.08560576249978372, 0.00818085329540606, 0.021864269361166016, 0.007459778371932251, 0.07338950623358999, 0.014787103315549237, 0.014082264886902911, 0.021032967272081544, 0.006807079422287643, 0.01641790964640677, 0.05825352056750229, 0.03188851655327848, 0.04435079265385866, 0.05794758948364428, 0.050807613147688765, 0.02866755153185555, 0.03182771642293249, 0.0455133741987603, 0.028341934450768998, 1.358726639832769, 15.152376140866961, 33.195866448538645, 26.7176387991224, 22.229644468852452, 33.74146679469517, 32.50054979324341, 18.278497491564067, 2.158930152654648, 0.13139585006449903, 0.13363304787448474, 1.1733124405145645, 1.083005509206227, 3.3664836415222714, 4.520875811576843, 4.24617964880807, 1.4389301304306303, 1.3419886465583528, 0.8846127263137272, 1.5670893277440752, 12.560259461402893, 24.270273072378977, 40.41264418193272, 50.15610654013497, 48.92093569891793, 47.14986072267805, 49.839199202401296, 49.29213278634207, 48.685047830854145, 47.10666377203805, 48.46109001977103, 49.73216915130615, 49.945548330034526, 47.73692791802542, 45.951654297964915, 41.70093400137765, 41.14896215711321, 43.164502552577424, 46.019698006766184, 51.064333370753694, 48.21357086726597, 48.23715305328369, 49.14683553150722, 47.84765788487026, 50.95957885469709, 46.462041173662456, 45.18005337033953, 38.149699279240195, 34.895142214638845, 35.157877922058105, 35.44063138961792, 37.07811682564871, 38.271063464028494, 41.76719897133963, 43.81011526925223, 45.91072246006557, 48.3098520551409, 49.11323751722063, 39.05134269169399, 47.092986243111746, 50.244553634098594, 44.91653599057879, 46.11347089494978, 43.0131117275783, 42.395420346941265, 39.8162386076791, 38.88906751360212, 33.55070052828108, 33.73136758804321, 31.73790509360177, 34.49740300859724, 32.77714368275234, 37.28277601514544, 43.01113843917847, 45.92992728097098, 43.72475664956229, 44.14274985449654, 45.440864426749094, 44.38959155763899, 44.474321365356445, 44.7535069329398, 44.87235934393746, 41.480627468654085, 44.78927278518677, 44.68488652365548, 44.624103682381765, 44.04242134094238, 43.79898772920881, 46.41706895828247, 43.56579576219831, 43.577826568058555, 41.26677928652082, 39.712519373212544, 40.1620261328561, 43.996149812425884, 36.293762479509624, 21.967615740639822, 10.686714189393179, 4.116487613746098, 1.6315883696079254, 1.0019667148590088, 2.3105524395193373, 3.7357832193374634, 2.9943824197564806, 4.448066941329411, 5.111643356936319, 7.92851037638528, 2.0963427339281355, 0.21294317926679338, 0.0032050629171343254, 0.7236455466066087, 7.003605263573783, 22.394744089671544, 26.738803012030466, 25.280528988157, 24.520788635526383, 20.712435824530466, 6.492461468492236, 0.023933285481429527, 0.03739590370761497, 0.01921896157520158, 0.10036325454711914, 0.04997384288747396, 0.01922147554744567, 0.038825417536177805, 0.03258503274992108, 0.02848123260108488, 0.03197411035320588, 0.053749954727079184, 0.007692709265808974, 0.04369701737804072, 0.03777058395956244, 0.026262965918119465, 0.023167899676731656, 0.026226506535229937, 0.032440596393176487, 0.04622204974293709, 0.014297575922682881, 0.06977867534650223, 0.03372544316308839, 0.024891833242561136, 0.023169329689283456, 0.03132967171924455, 0.06549518555402756, 0.01999836930605982, 0.03569784268204655, 0.05458758245887501, 0.020641047141647766, 0.008892075890409095, 0.03395952756649681, 0.021154552265735607, 0.03694804345390626, 0.09519701783678361, 0.035023307627333064, 0.05853009144110339, 0.021055638823392134, 0.0551325919638787, 0.05076653803033488, 0.06554816556828362, 0.014971936254629066, 0.023096448242930428, 0.054687096404709985, 0.017149082019126842, 0.060190907679498196, 0.024942855683288405, 0.0270636117950614, 0.03616267988192184, 0.007551507824765784, 0.041942156186061244, 0.0717647269900356, 0.022509746153705885, 0.033559683843382766, 0.02005657403995948, 0.049318445912961445, 0.05811562868101256, 0.05569656312997852, 2.633789151906967, 20.303815739495413, 37.822803906032014, 27.383488144193375, 25.45439897264753, 38.50752803257534, 36.99572161265782, 16.662153686795914, 1.9264284457479204, 0.030057276066924845, 0.011027105834468134, 0.25525521167687004, 2.1277950576373508, 4.095941790512629, 7.174947840826852, 3.82572808435985, 2.9841368666716983, 2.0297967961856296, 1.9608491701739175, 2.5532030761241913, 12.55585082939693, 27.50791127341134, 41.30077682222639, 49.91258260181972, 49.57949985776629, 49.057012694222585, 50.21566302435738, 50.526508058820454, 48.3178459576198, 49.54467896052769, 49.12698800223214, 51.34965072359358, 51.54889031818935, 49.25025946753365, 48.376117025102886, 44.147561482020784, 41.3298202923366, 43.431886604854036, 47.068976742880686, 52.08742434637887, 48.0780462537493, 48.03226457323347, 50.02091544015067, 47.84257180350167, 52.487310545785085, 49.646463121686665, 44.53286688668387, 39.64450345720564, 36.42088324683053, 36.497209208352224, 35.47914525440761, 39.112994057791575, 40.215780871255056, 43.94653967448643, 46.420279026031494, 47.93097720827375, 49.87344339915684, 51.799494470868794, 40.83070339475359, 49.06663247517177, 49.8613326890128, 47.4521837915693, 48.79379756110055, 46.786327498299734, 44.760482924325125, 42.13231291089739, 39.89752558299473, 35.32209512165615, 34.330680983407156, 33.20388119561331, 35.902877671378, 34.712147508348735, 37.186706747327534, 44.11447416033064, 46.15617452348982, 45.4915063721793, 46.01271506718227, 47.18226712090628, 45.01085431235177, 46.016456672123496, 43.977688448769705, 45.95607335226876, 42.1326915877206, 44.26877280644008, 44.73603221348354, 45.48894248689924, 44.35555580684117, 44.16109657287598, 47.1067019871303, 44.4733555657523, 45.25159202303205, 43.09510741915022, 40.553831577301025, 41.66129800251552, 44.7790207181658, 37.32257529667446, 26.45435244696481, 11.988708462033953, 5.37839903150286, 2.5931949530329024, 2.391699799469539, 3.4196859981332506, 5.441394005502973, 4.031453388077872, 5.019500689847129, 6.502225858824594, 6.20865752015795, 0.791771222438131, 0.12189338782003947, 0.06806158819901091, 0.7805021128484181, 6.443857082298823, 24.208673817770823, 31.072417054857524, 26.962185859680176, 27.343195540564402, 25.620410544531687, 9.394621099744525, 0.07638095678495509, 0.12931367036487373, 0.02769649837033025, 0.07742908304291111, 0.03995575509699328, 0.020854561755965863, 0.00295735034991854, 0.0547135456997369, 0.013660428147496921, 0.021099029441497157, 0.027917017162378346, 0.039690210417445214, 0.05185408378019929, 0.03317306476778217, 0.004555612869028534, 0.03574404752414141, 0.06164506929261344, 0.015805850703535334, 0.02544198095399354, 0.041156439775867124, 0.027109414605157714, 0.06276736621345792, 0.04540555837697216, 0.03944800394986357, 0.0559622503018805, 0.030954370607755015, 0.06929014370377574, 0.26654394449932234, 0.12877709844282695, 0.17119491446231092, 0.09295118227601051, 0.07679932790675334, 0.09264270668583256, 0.08193910853671175, 0.21926195520375455, 0.12888670898973942, 0.11631663063807146, 0.0746203755427684, 0.11683750125978674, 0.1439705424542938, 0.130666316353849, 0.06130361011517899, 0.062377371426139555, 0.12621534376272134, 0.12149746263665812, 0.15061703723456177, 0.1039940140077046, 0.1004119733614581, 0.14960405230522156, 0.16298806055315904, 0.15123622758047922, 0.1828521460826908, 0.18685536698571273, 0.15484612887459143, 0.1583708468824625, 0.21006520012659685, 0.14998906664550304, 0.16099740165684903, 2.4087291828223636, 22.513568707874843, 44.524588108062744, 36.98107828412737, 31.356730393001012, 41.92767456599644, 40.14319651467459, 22.47880165917533, 2.716593222958701, 0.274603827723435, 0.13208054618111678, 4.156864898545401, 6.756216389792306, 7.948683602469308, 11.064809969493322, 8.380636606897626, 4.621185651847294, 3.7551287412643433, 3.2560105408940996, 2.6887005482401167, 14.503537722996303, 25.165081194468907, 43.01431376593453, 50.654407024383545, 51.030856949942454, 51.036370345524375, 51.77889306204659, 51.69055713926043, 51.64942032950265, 49.350007806505474, 51.56428057806832, 53.77243198667254, 54.33920349393572, 51.04898827416556, 49.91924245016915, 46.825748103005544, 44.5072523525783, 45.74632460730416, 49.80456590652466, 53.71655804770333, 49.69822720118931, 48.09934943062918, 52.16169711521694, 48.0999504498073, 53.02577856608799, 50.254784856523784, 46.63908474785941, 40.882655075618196, 38.359996931893484, 37.749153000967844, 38.10468190056937, 41.05830553599766, 42.9482398714338, 45.314226559230256, 48.3571970803397, 49.17797040939331, 51.82770068304879, 52.122168813432964, 42.842318058013916, 50.08739233016968, 51.867211614336284, 49.73821060998099, 52.05218308312552, 47.04996299743652, 46.14881290708269, 43.344909054892405, 42.17236927577427, 37.293097564152305, 36.25669036592756, 35.20298910140991, 38.43947737557547, 35.3391112600054, 39.58039590290615, 46.37071752548218, 48.71280241012573, 47.546630655016216, 46.433887072971885, 49.343910762241904, 47.23715441567557, 48.028033120291575, 44.99614150183541, 44.95937858309065, 42.55865785053798, 45.04230533327375, 46.099362577710835, 45.20495571408953, 46.84904888698033, 45.448316369737896, 47.70286784853254, 44.489440645490376, 45.04201350893293, 45.08312252589634, 43.14251150403704, 41.35536534445626, 45.096595082964214, 38.787085328783306, 25.583972454071045, 13.172467844826834, 5.417517823832376, 3.0285037202494483, 3.7427987286022733, 6.007391657148089, 9.22871288231441, 9.037693875176565, 10.833509649549212, 11.666888747896467, 11.52437424659729, 3.9650824580873762, 0.8436435418469566, 0.18844830936619214, 1.222158385174615, 8.989082540784564, 28.02987037386213, 34.1547977583749, 33.061620303562705, 32.12408249718802, 29.74694742475237, 9.92607751914433, 0.1672725613628115, 0.21985612117818423, 0.11122796405106783, 0.20497241483203002, 0.10347832060818161, 0.09074929542839527, 0.14218713529407978, 0.1533670989530427, 0.0850708054910813, 0.09894017662320818, 0.1494090956236635, 0.13250184857419559, 0.12455844267138413, 0.12107344610350472, 0.14202736743858882, 0.061543743658278666, 0.1423229780048132, 0.15094019632254327, 0.0930972776508757, 0.09546919180346386, 0.10378835004355226, 0.17904755952102797, 0.15454841484980925, 0.11824266585920538, 0.09777156290199075, 0.1497169333909239], [0.04474196469943438, 0.03751202140535627, 0.019721851018922668, 0.05307617623891149, 0.04007575401504125, 0.003809352422000042, 0.005071114582408751, 0.056233708414116075, 0.032343389466404915, 0.019222193098227893, 0.03841451708493488, 0.029526081534900835, 0.05199593152584774, 0.04061658374433007, 0.03437865525484085, 0.003983514125658465, 0.013558703873838698, 0.045417392027697394, 0.019783392448776534, 0.0319842917711607, 0.0388346557904567, 0.0399481622901346, 0.047812451009771655, 0.026516157867653028, 0.08666274363973311, 0.019250099547207355, 0.009957794016892356, 0.052737108897417784, 0.030403189826756716, 0.05772597994655371, 0.0292167984880507, 0.03040692176935928, 0.07450096695018665, 3.773874981062753, 18.96021131106785, 28.285183668136597, 24.745660134724208, 22.239528281348093, 30.462684835706437, 30.342793669019425, 12.99878806727273, 2.529250464269093, 0.25722898862191607, 0.11495322308370046, 1.0100959986448288, 2.9200149817126135, 8.353243333952767, 2.189521551132202, 2.0147665398461476, 0.9604616505759103, 1.8118840264422553, 0.1042704356036016, 1.0342794209718704, 8.358865295137678, 18.77668333053589, 34.897455964769634, 45.61288097926548, 48.460343088422505, 47.96310567855835, 48.057083538600374, 48.585584368024556, 49.25070415224348, 50.985916001456125, 49.44914470400129, 47.846598284585134, 43.92193610327584, 42.32462862559727, 41.74831376756941, 40.132426806858604, 44.953552518572124, 48.713507652282715, 49.44877297537667, 47.519668170383994, 43.467774050576345, 50.46825088773455, 51.6543778691973, 46.68587391717093, 47.20303528649466, 44.73442023141043, 37.11903476715088, 35.69369520459856, 36.10545934949602, 35.92377437864031, 38.78256899969918, 38.54672976902553, 42.768184253147666, 42.703739711216514, 46.662785053253174, 48.11913442611694, 49.83356073924473, 38.521417481558665, 48.28815630504063, 49.442474433353965, 45.23032358714512, 46.20109115328108, 41.07777091435024, 40.10734033584595, 37.54023109163557, 36.66243389674595, 35.06474426814488, 33.817525250571116, 35.09320061547415, 33.68921981539045, 35.741950443812776, 44.12548358099801, 44.70715550013951, 45.670960971287315, 44.456520080566406, 45.67760692323957, 44.96000392096383, 46.48693656921387, 45.104057448250906, 45.079599789210725, 40.82268517357962, 43.481333460126606, 46.113905157361714, 44.350382872990195, 45.84535033362252, 43.33120373317173, 43.75071859359741, 43.33705064228603, 43.68820217677525, 41.91162422725132, 41.492032936641145, 43.50957441329956, 43.84374107633318, 40.63053968974522, 31.938444001334055, 18.112963608333043, 5.2489701594625195, 1.7985968994242805, 2.0584196831498827, 3.2026301366942267, 2.067767615829195, 3.8601129821368625, 1.804792738386563, 3.5991531908512115, 5.341384240559169, 5.70791300705501, 0.9958696705954415, 0.0923345432217632, 0.802505972129958, 5.845032232148307, 17.5791335105896, 28.374584402356827, 24.824687208448136, 26.80900239944458, 26.260271889822825, 12.447537098612104, 0.8783096788184983, 0.07559305549200092, 0.085509532663439, 0.03513019046347056, 0.03578217101416417, 0.06390503873782498, 0.0029431706643663347, 0.01627380577182131, 0.030598560414676155, 0.04783480873863612, 0.019254162275631512, 0.03011597613138812, 0.015845570447189466, 0.026621753183592643, 0.028817450095500265, 0.034569384663232734, 0.010473371217293399, 0.014655825449153781, 0.09653626275914055, 0.04114683511267815, 0.06865719266768013, 0.031255280532475026, 0.07811106501945428, 0.03374699004260557, 0.07123485899397305, 0.023455116764775345, 0.09203031526080199, 0.0065855428277115735, 0.051334811108452935, 0.061099513566919735, 0.01244348576957626, 0.025247441571471945, 0.014889051505763615, 0.06501084047236613, 0.03238408121147326, 0.1143476984330586, 0.01975105346978775, 0.04275839988674436, 0.04296556002061282, 0.07223949115723372, 0.014562630360679967, 0.06101062547947679, 0.027950577504400696, 0.05496186576783657, 0.031179481385541812, 0.06874474404113633, 0.033549597420330556, 0.05318366297121559, 0.030176372533398013, 0.03148718683847359, 0.04233906524521964, 0.013937177136540413, 0.02891961032790797, 0.02266701530399067, 0.1106442203745246, 0.07413219673825161, 0.07846796765391316, 0.022032018484813825, 0.053084006533026695, 0.12990816203611238, 6.105567531926291, 26.49307996886117, 33.344832352229524, 25.45622287477766, 25.80515272276742, 36.737606457301546, 35.808142457689556, 13.39052402973175, 1.921080721276147, 0.15018565181110585, 0.08182854804077319, 0.9751908544983182, 2.381953648158482, 5.648746056216104, 4.880699132169996, 5.166722161429269, 5.144252555710929, 1.755674728325435, 0.6607384564621108, 2.413770100900105, 11.35697911466871, 23.130763292312622, 38.52893543243408, 46.92148733139038, 50.91003472464425, 47.218602725437705, 48.949326038360596, 49.30957276480538, 50.91590247835432, 50.481275285993306, 52.1521120752607, 50.21892867769514, 46.44728667395455, 43.981245926448274, 43.57020092010498, 41.819914954049246, 46.25123977661133, 50.075153078351704, 51.514368193490164, 48.53345898219517, 44.41758584976196, 48.33622394289289, 52.61681801932198, 48.771160330091206, 48.752695492335725, 45.40548072542463, 37.89150421960013, 37.142057623182026, 37.783609117780415, 38.65219994953701, 40.54440287181309, 41.10030392238072, 43.56490291867937, 44.48682812282017, 49.302718366895405, 49.48958669389997, 51.46606431688581, 40.81041465486799, 48.88072994777134, 51.06279781886509, 46.81884854180472, 48.0353877885001, 43.63641030447823, 42.42476258959089, 39.1704660824367, 38.3681297983442, 36.19262450081961, 34.59974649974278, 37.28159482138497, 35.53559589385986, 36.41617931638445, 46.2986091205052, 46.15924910136631, 48.6268219266619, 46.14541523797171, 47.10763651984078, 45.06779132570539, 47.935007163456504, 46.39235074179513, 44.13165705544608, 43.77499212537493, 43.658554213387625, 47.2139960697719, 46.2394243649074, 45.99574409212385, 44.173999377659385, 44.82124492100307, 42.89588172095162, 44.8534255027771, 43.37872246333531, 42.96571111679077, 44.55427428654262, 45.69343144553048, 41.58272777284895, 32.374370506831575, 20.35512297494071, 7.701770680291312, 3.0172604492732455, 2.5296482486384253, 4.188682871205466, 2.9546183134828294, 6.030680281775338, 6.49598377091544, 9.402525544166565, 4.730562891278948, 2.584402007716043, 0.458709648677281, 0.08856215314673525, 0.6092508935502597, 5.369682516370501, 18.451795986720494, 29.537893499646867, 26.598574468067714, 28.474756581442698, 30.45149823597499, 17.217717749731882, 1.868109609399523, 0.03750965671081628, 0.04509364261424967, 0.03973285973604236, 0.010197210857378585, 0.012890385896233576, 0.0234676391285445, 0.04419216134452394, 0.03040261985734105, 0.047273633136813126, 0.02455353773465114, 0.08117536309042148, 0.04162217264196702, 0.01360659911629877, 0.08962540395025696, 0.021306488130773817, 0.016948162711092403, 0.020443564613482783, 0.053272316964077096, 0.058941575432462354, 0.09719186329415866, 0.07478091692818062, 0.052994752036673684, 0.0193146384055061, 0.06339750132922616, 0.02691726536223931, 0.02257263277923422, 0.1309292215321745, 0.12144955806434155, 0.17532948617424282, 0.07121830952486821, 0.09962803471301283, 0.08052183887256043, 0.15222355031541415, 0.12233624048531055, 0.13229328048016342, 0.20899437687226705, 0.12635159359446593, 0.17116647027432919, 0.18562172246830805, 0.1287353413977793, 0.13462867587804794, 0.07055074641747133, 0.1753893329628876, 0.138267062072243, 0.11654514766165189, 0.11533834598958492, 0.14760909149689333, 0.08936507720500231, 0.1267548876681498, 0.0975295633875898, 0.18320332866694244, 0.14084668936473982, 0.09043809212744236, 0.24485975663576806, 0.10798502128039088, 0.15804700925946236, 0.1704351452312299, 0.08848505799791642, 0.31535028985568453, 5.989152201584407, 29.228629180363246, 40.899737221854075, 33.741317408425466, 29.868322031838552, 38.68486343111311, 37.63146788733346, 17.121288912636892, 3.060228326490947, 0.4180532959955079, 0.8919317307216781, 3.2431435627596716, 9.367144448416573, 18.763250725609915, 8.617475509643555, 5.228045659405844, 5.708952631269183, 4.569778101784842, 0.5514602288603783, 1.4747855493000575, 9.920035191944667, 20.5307126385825, 37.35988712310791, 46.99944264548165, 51.30342435836792, 48.69024855749947, 49.62465967450823, 50.69185086659023, 51.32000970840454, 53.699302196502686, 54.424239022391184, 51.60985033852713, 47.56740229470389, 47.336075919015066, 46.48423024586269, 44.0108938898359, 47.21298163277762, 52.214336667742046, 53.161678382328574, 49.0454752104623, 44.6807210786002, 50.40495974676949, 53.04822472163609, 51.86131954193115, 50.95379100527082, 48.29506976263863, 39.406016962868826, 39.15984923498971, 39.11315734045846, 40.117140769958496, 43.13866220201765, 43.70823730741228, 45.9251503944397, 45.0037602015904, 49.80519471849714, 51.93203483309065, 52.37108107975551, 43.19001633780343, 49.89201940808977, 52.871014390672954, 49.023508480616975, 50.209201199667795, 44.24560056413923, 44.711630140032085, 41.3896929195949, 40.52746663774763, 37.84595877783639, 36.9270212990897, 39.17124775477818, 36.68408795765468, 38.67836339133126, 49.2644442149571, 47.95520905085972, 50.08212559563773, 48.3449786731175, 48.22283976418631, 46.04038626807076, 49.20572846276419, 48.290014948163716, 44.63516174043928, 42.99075937271118, 43.91188553401402, 48.35041911261422, 46.54705238342285, 46.491025584084646, 45.654584067208425, 45.638203689030235, 45.26034675325666, 45.70177970613752, 45.901693275996614, 44.510816778455464, 44.74798658915928, 45.10895940235683, 42.80473525183541, 34.1877634865897, 20.63594831739153, 6.652178406715393, 3.090038921151842, 4.322489542620523, 6.5273878914969305, 5.541879722050258, 6.53087762423924, 3.787252868924822, 9.525407910346985, 11.79537831033979, 11.14566355092185, 2.3272789248398373, 0.20375406449394567, 1.18278891486781, 7.680401495524815, 22.691623244966777, 34.53105313437325, 31.224822316850933, 34.81418875285557, 35.53039864131382, 18.82314419746399, 1.7108156383037567, 0.13809643765645369, 0.14265558230025427, 0.11418396793305874, 0.15669790522328444, 0.17684944532811642, 0.1155105581773179, 0.11849399523011275, 0.13229956371443613, 0.12401010495211397, 0.09556705012385334, 0.17829157651535102, 0.1484323851764202, 0.10154053994587489, 0.1533133725502661, 0.13896688951977662, 0.08059809942330633, 0.08053270900355917, 0.20171882584691048, 0.14503147266805172, 0.16740560850926808, 0.12667207925447396, 0.18722344509192876, 0.07744901840175901, 0.15935012219207628, 0.1149438593004431, 0.14961770442979677], [0.03335630654224327, 0.09175011422485113, 0.016610084334388375, 0.0795421428712351, 0.009743746752584619, 0.025415299260722737, 0.03254507721534797, 0.015053698028038656, 0.03363437358556049, 0.03426023053803614, 0.0816076984629035, 0.021442208705203872, 0.02209961075069649, 0.020564554192657982, 0.008812858623319438, 0.05644301611131855, 0.043734944092908075, 0.018313395524663583, 0.03646876024348395, 0.04408492906285184, 0.046716389645423205, 0.007384107298483806, 0.035617493957813294, 0.0489118745151375, 0.0121427615938176, 0.030293531782392944, 0.040665797889232635, 0.026686227581064616, 0.03458529970209513, 0.015939452552369664, 0.007336706538418574, 0.017707999795675278, 0.0260323403469686, 0.08274868902351175, 6.012120340551649, 26.292551483426774, 28.34569900376456, 24.66430194037301, 21.149480990001134, 34.440733500889365, 32.85966396331787, 10.714210816792079, 2.1794173504625047, 0.2210643749151911, 0.58743588413511, 1.3368026848350252, 3.7752702661923, 2.51179724080222, 5.849818672452654, 2.555554824216025, 1.133805200457573, 0.8081359128866876, 0.09897161993597235, 0.8706245911972863, 4.777913996151515, 13.580818687166486, 27.806782824652537, 43.47438178743635, 45.712973254067556, 47.39431919370379, 48.14141035079956, 49.072729519435335, 47.62792110443115, 48.92744616099766, 44.10714381081717, 43.552924224308555, 40.42722150257656, 42.973215171269004, 46.85855054855347, 49.85404750279018, 49.05421951838902, 49.36802448545183, 46.95765617915562, 50.776243686676025, 48.3716493334089, 45.39553437914167, 46.856858662196565, 45.84820604324341, 40.09386430467878, 36.23034974506923, 32.98163958958217, 36.54370655332293, 36.09539835793631, 38.550613812037874, 41.300884519304546, 43.81638601848057, 43.75183725357056, 47.18897213254656, 46.70323051725115, 50.82166406086513, 39.6903407233102, 45.17222275052752, 48.67234999792916, 44.84202698298863, 45.6529894556318, 41.91090856279646, 37.66830028806414, 36.011012486049104, 35.65234300068447, 35.43102550506592, 34.21323905672346, 34.41490704672677, 33.38261318206787, 41.30994497026716, 45.30510704857962, 45.975750650678364, 45.00420141220093, 44.341371059417725, 44.64652551923479, 45.47256905691964, 43.57237918036324, 46.83416584559849, 40.39979348863874, 44.24691724777222, 46.97244541985648, 43.085275718144004, 41.938458170209614, 40.555245535714285, 42.27002273287092, 41.59330293110439, 41.725287437438965, 42.348377568381174, 45.08167035239083, 43.1423100062779, 43.131661891937256, 40.949816363198416, 34.2103625025068, 20.61965479169573, 9.0305380991527, 1.670066950576646, 0.6390507402164596, 1.858191273042134, 3.2560926164899553, 1.449171992284911, 7.5878080640520364, 10.912653105599539, 9.865966047559466, 3.8578830446515764, 2.05386991586004, 0.026876325951889157, 0.45103088500244276, 3.9684188961982727, 15.284178256988525, 25.62597952570234, 24.621706008911133, 22.54628430094038, 26.79735721860613, 20.52603997503008, 2.736733227968216, 0.018862089474818537, 0.0440003055680011, 0.02611570685569729, 0.0350477857781308, 0.05906398993517671, 0.06254911542470966, 0.055680800761495314, 0.0425010383395212, 0.03678594143795116, 0.023338892197768604, 0.037622089963406324, 0.04519002851364868, 0.037793006149253676, 0.023317520041018724, 0.035394839476794004, 0.029013950444225754, 0.03748929048223155, 0.07812762805925948, 0.040308857935347726, 0.04904530503387962, 0.03506226232275367, 0.03992989273475749, 0.04257846257782408, 0.03814750337707145, 0.015216266536819083, 0.005818136684995676, 0.048395807921354256, 0.04493195450465594, 0.05394469427743128, 0.03267867736784475, 0.05411418214706438, 0.051765365326511006, 0.03742626814969948, 0.02433315634594432, 0.021521649888849685, 0.007798307974423681, 0.026802235016865388, 0.017456884163298776, 0.04009936024834003, 0.026384170932163085, 0.01697594023841832, 0.021148708382887498, 0.04297845218596714, 0.05111638390059982, 0.041928917967847416, 0.034126783055918555, 0.034959752644811354, 0.04551572871527501, 0.06306088010647468, 0.028559203060077767, 0.04183292222608413, 0.010403293816904937, 0.04021928792021104, 0.010774387163110077, 0.014034915016964078, 0.015100869782535093, 0.028892153408378363, 0.03563975329910006, 0.042061066055404286, 0.08899725694209337, 0.3798181191086769, 9.573273181915283, 33.47230052947998, 33.065608569553916, 25.52600015912737, 27.02164680617196, 37.65125288282122, 33.9402026448931, 9.929384861673627, 1.8703362899167197, 0.161675556695887, 0.19368562261973107, 0.2976977942245347, 1.6120806506701877, 6.248610964843205, 9.856630274227687, 8.015647734914507, 3.7688262462615967, 3.334607477699007, 1.2016606565032686, 1.8089319105659212, 6.65301479612078, 17.466732501983643, 32.272909436907085, 45.88954782485962, 48.88493013381958, 48.51374346869332, 47.90090887887137, 51.62932961327689, 49.94577414648873, 50.81164823259626, 47.248591150556294, 45.02169350215367, 41.97932052612305, 44.16220481055123, 47.93000446047102, 50.33954593113491, 51.69661944253104, 50.93760517665318, 48.122900349753245, 50.52940198353359, 49.81749997820173, 48.29339524677822, 47.937522411346436, 47.63967398234776, 41.80822113582066, 37.479712281908306, 34.515440532139365, 37.734266485486714, 38.865950856889995, 40.61496182850429, 42.45659576143537, 45.862842423575266, 47.32155418395996, 49.21179076603481, 48.04711634772164, 50.788917200905935, 41.65097297940935, 46.832685879298616, 49.83260883603777, 46.84089170183454, 47.050435474940706, 43.61650718961443, 39.43452542168753, 37.13291379383632, 36.769446577344624, 36.226747104099815, 35.76026242119925, 35.828472886766704, 34.71315152304513, 42.21344007764544, 47.09666184016636, 47.538921628679546, 46.72777502877371, 44.87028530665806, 46.15377739497593, 45.7866450037275, 44.54129505157471, 46.46646022796631, 42.608063016619, 43.7458062171936, 47.03062616075788, 44.17621585300991, 42.97753695079258, 42.54681117194039, 43.10024561200823, 43.93642657143729, 43.641010011945454, 44.586982931409565, 45.24750995635986, 44.109283855983186, 45.00643178394863, 42.2743375641959, 36.99186536243984, 23.615250757762364, 12.06484682219369, 2.971120936529977, 2.103045357125146, 3.1526361107826233, 3.5977357583386556, 3.265474421637399, 6.54538893699646, 11.005507963044302, 10.679415106773376, 3.4348764973027364, 0.6996371863143784, 0.021641645414222564, 0.2074019501784018, 4.080873319080897, 16.87623984473092, 27.081879002707346, 29.463474818638392, 24.487009968076432, 30.064473152160645, 24.78326725959778, 5.274827880518777, 0.049188319859760146, 0.043441871247653446, 0.024229243796850954, 0.013179222986634289, 0.0666700146560158, 0.025136970981423343, 0.01627836891982172, 0.05412716930732131, 0.023926243984273503, 0.03618834886167731, 0.03927560855767556, 0.04998749501204916, 0.015338100892092501, 0.012310503932115222, 0.04132015670516661, 0.02768161640103374, 0.04535166234044092, 0.06684091048581259, 0.0026853411400225013, 0.05272659838997892, 0.02140747449759926, 0.04117591373090233, 0.0247645112353244, 0.029584296446825777, 0.02546691711592887, 0.062261233372347694, 0.001828321089435901, 0.12598179200930254, 0.1841069066098758, 0.11147045211068221, 0.19098577249263013, 0.08137629766549383, 0.14941824227571487, 0.1394671733890261, 0.05505667068064213, 0.07592526623713118, 0.11358058066772563, 0.11613801307976246, 0.14291779537286076, 0.11442613708121435, 0.09151489327528647, 0.08766038010695151, 0.17627792885260923, 0.18876157541360172, 0.09539734173033919, 0.09915323661906378, 0.13026922409023556, 0.128967251096453, 0.1501877959817648, 0.09544701727905444, 0.1181050996695246, 0.156184851324984, 0.12117576918431691, 0.11970785366637365, 0.07222799677401781, 0.08249927312135696, 0.14136194171650068, 0.1863597785787923, 0.1195117434752839, 0.19622740122888768, 0.3122872742159026, 9.952139343534197, 37.43937104088919, 39.613326890128, 32.73969636644636, 30.86315815789359, 44.39140503747122, 39.25617906025478, 13.83780128615243, 3.3328161452497755, 0.379998012312821, 1.7007677831820078, 4.47909151656287, 11.178445151873998, 9.367675117083959, 10.19252964428493, 5.3129787019320895, 3.6446206825120107, 3.83291425875255, 0.7383143337709563, 1.7643001569168908, 6.276154492582593, 17.3623879296439, 31.305987698691233, 48.261544704437256, 50.76471662521362, 52.368749959128245, 52.17249114172799, 54.34550551005772, 49.82829400471279, 52.203163964407786, 47.8176451410566, 47.93780728748867, 43.37400116239275, 46.0475081716265, 50.3266361781529, 52.827657631465364, 52.442650999341694, 51.78092541013445, 47.36884709766933, 51.68153837748936, 50.41168212890625, 49.80704641342163, 49.331195558820454, 48.51018251691546, 43.167632716042654, 40.572525705610005, 36.416043826511924, 40.70240838187081, 40.77740376336234, 42.68266929898943, 45.38446242468697, 47.88681445802961, 48.41681262425014, 51.464615617479595, 49.77760342189244, 52.46576765605381, 45.363687310900005, 47.18097823006766, 50.498767375946045, 49.479254722595215, 49.68227066312517, 45.772029467991416, 40.74172823769705, 38.913233348301475, 38.73593616485596, 39.16959408351353, 38.28661353247506, 37.08829246248518, 36.25811127253941, 44.26447187151228, 47.58171558380127, 49.87980447496687, 47.759947299957275, 45.8631203515189, 47.175659384046284, 47.89351946966988, 44.82341970716204, 46.78401027406965, 41.46072435379028, 45.682085037231445, 48.73267425809588, 46.22211987631661, 44.46544851575579, 44.9903883934021, 45.63136318751744, 45.14004564285278, 45.36089760916573, 44.75205823353359, 47.16198532921927, 45.25396483285086, 46.64051260266985, 44.62877982003348, 37.77530254636492, 23.549190759658813, 11.420073100498744, 3.0327178026948656, 2.585555842944554, 3.9940521035875594, 7.146671278136117, 4.913585390363421, 14.361566918236868, 19.291904415403092, 17.025468042918614, 8.132883821214948, 4.897394350596836, 0.5182051733136177, 0.8336514351623399, 5.52248295715877, 19.347776617322648, 32.84951959337507, 32.24994216646467, 31.442926270621165, 36.42831087112427, 28.755562816347393, 5.343731428895678, 0.13435485985662254, 0.15996050515345164, 0.08520561004323618, 0.09940466098487377, 0.16051110917968409, 0.13192482239433698, 0.18191462781812462, 0.1383019116308008, 0.17665239875870092, 0.09439676720649004, 0.0989188774089728, 0.08984773951981749, 0.09999833162873983, 0.07800975295581988, 0.13333963576172078, 0.19712883500116213, 0.1541107733334814, 0.19646213363323892, 0.0722832295245358, 0.2215035499206611, 0.17040167988411017, 0.12998407653399877, 0.10710983324263777, 0.10881573134767157, 0.12337183420147214, 0.14397256448864937, 0.10724938753992319], [0.03637031838297844, 0.0517015592860324, 0.11665877513587475, 0.04236374017117279, 0.027447800018957684, 0.04547146448333349, 0.01573044341057539, 0.10349977588547127, 0.0446191091489579, 0.07124526093580894, 0.010661123553290963, 0.0321707464089351, 0.0891623105853796, 0.05215300898998976, 0.0800119401620967, 0.07116561449531998, 0.031912424734660556, 0.06456325841801507, 0.033380520064383745, 0.007950761222413607, 0.03959206711234791, 0.025345174362882972, 0.013021649343759885, 0.03906501842928784, 0.10648899405662503, 0.03437526936509779, 0.02759263331868819, 0.09557840880006552, 0.010874586429313889, 0.0792206394086991, 0.0324262318068317, 0.016260394527177726, 0.031582833134702275, 0.03141545890165227, 0.7522345068199294, 10.17098241192954, 24.981264863695415, 26.3813807283129, 22.26152801513672, 27.138400861195155, 30.6636996950422, 30.963875770568848, 13.060364740235464, 2.249547907284328, 0.30465180107525414, 0.16716424003243446, 1.2330769364322935, 4.631799025194986, 11.565438100269862, 15.65088507107326, 3.186963903052466, 2.1348904711859564, 2.637408511979239, 0.43761242074625833, 0.43948550309453693, 1.5658059737512042, 7.983111926487513, 21.461156334195817, 36.59899336951119, 48.80834361485073, 48.442934376852854, 48.995573248182026, 50.033675806862966, 48.21568659373692, 46.70662818636213, 44.382427964891704, 45.8178528376988, 48.08894450323922, 48.71118695395333, 49.961504868098665, 51.78548690250942, 50.41475670678275, 46.92099748338972, 46.920907156808035, 48.06306593758719, 47.651958397456575, 47.45833642142159, 42.52077974591936, 37.83781201498849, 35.03943198067801, 36.0447598866054, 34.81284775052752, 37.727835927690776, 38.4839562688555, 40.50674363545009, 45.334060192108154, 44.83735431943621, 49.27838577542986, 49.02809429168701, 49.45196219852993, 39.13101768493652, 43.47388499123709, 50.2620005607605, 46.4704623903547, 46.54653474262783, 43.90012223379952, 42.22180570874895, 35.017142159598215, 34.04516908100673, 32.91159132548741, 32.8104498726981, 34.07846137455532, 36.37139817646572, 43.94362837927682, 48.01618644169399, 46.5787604876927, 44.96603148324149, 44.97697837012154, 46.33899552481515, 44.99765273502895, 45.89232363019671, 43.789086546216694, 43.386188302721294, 46.35700525556292, 43.077320030757356, 41.70270579201834, 39.43697813579014, 39.5070298739842, 40.155463559286936, 39.55097028187343, 40.08696126937866, 40.895620414188926, 43.34655577795846, 44.14062370572771, 43.32649980272566, 36.97564826692854, 24.43737551144191, 12.028048293931143, 3.979798308440617, 0.4058208023863179, 1.911200382879802, 2.260748403412955, 2.724166759422847, 2.6279552706650326, 5.334188512393406, 13.092243943895612, 13.496641261237007, 3.013161446366991, 0.19062545682702745, 0.34400267952254837, 2.4064436597483496, 16.835653679711477, 28.302538531167166, 38.20423221588135, 18.858043261936732, 18.661148684365408, 23.852113110678538, 8.50438141822815, 0.4431527405977249, 0.06362440343946218, 0.042997807397374084, 0.05482991445543511, 0.05658020571406398, 0.09444903475897652, 0.033237481489777565, 0.031251372170767615, 0.04489288106560707, 0.006567476832840059, 0.04220057964058859, 0.05244690286261695, 0.0474496078012245, 0.048100268601306846, 0.011595277980502163, 0.011095619211638612, 0.039646478835493326, 0.04397173585104091, 0.04751042828762105, 0.030938204510935714, 0.03963952045887709, 0.03350697185045906, 0.066983484263931, 0.017874754865520766, 0.01631428886737142, 0.0293768954330257, 0.044949182508779426, 0.03786518191918731, 0.04208357645464795, 0.04569216478349907, 0.029115208225058656, 0.04457286698743701, 0.03883446580065148, 0.02693206081832094, 0.0063209811757717815, 0.011694162585107344, 0.06126513717962163, 0.08463365251996688, 0.03434170223772526, 0.035972062431808026, 0.08525825078998293, 0.04932054937151926, 0.03658266252438937, 0.024055501512650932, 0.06740888500852243, 0.08177364777241435, 0.04122553838949118, 0.03516709937580994, 0.009913769816713673, 0.020583724503272345, 0.032363514815058024, 0.06612490676343441, 0.011832314011241709, 0.03695343780730452, 0.03517681599727698, 0.04738807485305837, 0.022915421885305216, 0.05318499289985214, 0.06970218409385, 0.049885697795876434, 0.028570853506347964, 0.05161211819254926, 1.3970823245389121, 15.484934295926776, 30.63586868558611, 29.92154175894601, 22.730633905955724, 32.589813300541465, 41.18360240118844, 33.83528137207031, 12.133120690073286, 1.8843106372015817, 0.1540574947638171, 0.2183590286544391, 0.2401829675904342, 4.259875851018088, 8.559919238090515, 11.744355951036725, 10.09971387045724, 7.461036443710327, 4.084670075348445, 1.5341620317527225, 1.28633086170469, 3.114046250070844, 11.897551570619855, 26.10008638245719, 41.07553012030465, 49.62032399858747, 51.78727258954729, 50.85371610096523, 49.59257289341518, 50.98389407566616, 48.53992428098406, 45.274969237191335, 45.42457437515259, 49.05303485052926, 50.43055691037859, 52.64969342095511, 54.63974434988839, 49.018175738198416, 48.93578747340611, 48.58904109682356, 49.73350320543562, 49.0306408064706, 49.674026625497, 45.539848463875906, 41.08398607798985, 36.167809009552, 37.90718282972063, 35.98413685389927, 39.15134116581508, 40.06070402690342, 42.44583995001656, 46.066289152417866, 47.40149320874895, 50.85016209738595, 50.7102427482605, 50.95237704685756, 40.69185059411185, 44.3583767754691, 50.5148663520813, 48.2820279938834, 46.43846593584333, 45.42053747177124, 42.69794143949236, 37.88354505811419, 36.97446707316807, 35.34109149660383, 35.33909041540963, 36.10465683255877, 36.204745633261545, 45.25349235534668, 49.395261423928396, 47.67081928253174, 46.03365693773542, 45.30161905288696, 45.631113052368164, 45.56196457999093, 46.71843317576817, 45.81646319798061, 43.02289479119437, 47.1433641569955, 45.411793163844514, 43.562127113342285, 41.51165117536272, 41.59711054393223, 42.99817657470703, 41.01314919335501, 41.50093010493687, 42.470575537000386, 45.10803529194423, 45.44969211305891, 45.18584816796439, 39.89897428240095, 26.937530176980154, 15.23353110040937, 4.651112411703382, 1.9992312363215854, 3.2796860933303833, 4.43677134173257, 2.8435483191694533, 4.939668493611472, 6.510556748935154, 8.279648883002144, 7.567408152988978, 2.5829318123204366, 0.3860314371330397, 0.1995499293719019, 2.3187135330268314, 14.426218169076101, 30.418845176696777, 39.54883371080671, 20.050420148032053, 23.339923177446636, 29.964047363826207, 12.385072793279376, 1.078508939061846, 0.025444013166374395, 0.044211502985230515, 0.05206667219421693, 0.039806701309446774, 0.01674141309091023, 0.00919816134098385, 0.054957044776529074, 0.03798852940755231, 0.03336711221241525, 0.004841064493770578, 0.0879174227427159, 0.008646110338824136, 0.039529370476624796, 0.03292415776689138, 0.008680740221669632, 0.06766843822385583, 0.04395955275478108, 0.023076355124690702, 0.019414031911375265, 0.040177225534405024, 0.0824914767539927, 0.013350164617544838, 0.09444554030363049, 0.09254643613738672, 0.06038074142166546, 0.006763739270224635, 0.015346119479675378, 0.1450408771634102, 0.09111655929258891, 0.136133625837309, 0.19119472056627274, 0.16401104708867414, 0.16787135494606836, 0.06951193644532136, 0.15244214715702192, 0.10817234444298915, 0.13939165244145052, 0.12067229620047978, 0.11935011643384184, 0.14860866857426508, 0.1831004898995161, 0.16867627389729023, 0.09150379922773157, 0.10102342162281275, 0.3282963037490845, 0.1177245093775647, 0.1647709384560585, 0.10197306530816214, 0.09561078170580523, 0.09388378116169147, 0.20152042220745767, 0.15714837105146476, 0.10808680153318814, 0.13034314369516714, 0.11735626842294421, 0.09835095038371426, 0.12333371410412447, 0.15201925699199947, 0.08264812334839787, 0.11576203682592937, 0.08319067994930915, 1.179836473294667, 15.365769215992518, 36.62672363008772, 39.05353137425014, 31.65662854058402, 36.71800906317574, 39.07104083469936, 37.590820925576345, 16.530426263809204, 3.0632512271404266, 0.4263188567544733, 0.6175465541226524, 3.9986709186009, 11.01114468915122, 21.028841154915945, 23.585456882204326, 10.221879703657967, 6.569217784064157, 6.0128642320632935, 1.6342318334749766, 1.231016795550074, 2.328109017440251, 10.666636501039777, 24.838460275105067, 40.69276080812727, 51.79436322620937, 52.97123173304966, 52.99752719061715, 53.31832204546247, 52.71870640345982, 50.915683610098704, 48.700754233769004, 48.799543721335276, 51.278046063014436, 51.763905797685894, 53.19543273108346, 54.8880729675293, 51.289878845214844, 49.476305212293354, 49.41481712886265, 52.87211568014962, 49.90304619925362, 51.29239409310477, 46.04730667386736, 41.54413400377546, 38.19119739532471, 39.58141381399972, 38.248075348990305, 41.32504687990461, 42.403737340654644, 44.007023743220735, 48.03648212977818, 48.963611534663606, 53.02252333504813, 53.333493437085835, 50.74830150604248, 43.311026164463584, 46.38648646218436, 51.94170672552926, 51.52136502947126, 48.42393800190517, 47.77700860159737, 46.23904568808419, 39.725022656576975, 37.755646092551096, 37.64938381740025, 36.45125034877232, 37.44793816975185, 39.44193914958409, 47.27478238514492, 52.125326769692556, 48.93024281093052, 46.5749910899571, 46.178433077675955, 48.406668254307334, 47.6390312739781, 48.20750856399536, 45.54436131886074, 45.53572470801217, 48.15446949005127, 46.87631014415196, 46.0357483455113, 41.87130730492728, 43.20678234100342, 44.13020488194057, 42.96190350396292, 42.58299739020211, 42.4626476424081, 45.96532140459333, 46.890619959150044, 46.76172392708914, 41.239101137433735, 26.361802441733225, 14.453047769410269, 5.215948845658984, 2.196167937346867, 4.6747141395296365, 6.80982825585774, 5.808634093829563, 7.954848391669137, 12.040859035083226, 19.52712525640215, 19.69923734664917, 5.620888556752886, 1.203828168766839, 0.5236996784806252, 3.617157059056418, 20.52693108149937, 34.74789251599993, 45.11008848462786, 25.062174899237498, 25.96324508530753, 36.32989658628191, 12.985235605921064, 1.1696465057986123, 0.20328997368259089, 0.14612850094480173, 0.1131107901622142, 0.15006355621985026, 0.16802692945514405, 0.13252456592661993, 0.19722885106291088, 0.1374452883111579, 0.15608617876257214, 0.13430073990353517, 0.19399689377418586, 0.13644754327833652, 0.16379390231200627, 0.13127882991518292, 0.08497598022222519, 0.18369211815297604, 0.2513110233204705, 0.1474266741424799, 0.11598420276173524, 0.14070232425417217, 0.10540618108851568, 0.12857041667614663, 0.17033565842679568, 0.16590002072708948, 0.1563121580651828, 0.1507847575204713, 0.12322911114564963], [0.05682377603703311, 0.047890367185963054, 0.058162366173097065, 0.08697157206812076, 0.04594448481553367, 0.01993040893492954, 0.012601765088870056, 0.029939166868903806, 0.03434385997908456, 0.04888986283913255, 0.06439106658633266, 0.04375091341457196, 0.04933946014248899, 0.024091435030901005, 0.007194845222069749, 0.04137604424197759, 0.03593128926253744, 0.05451051445145692, 0.033660551466579945, 0.05444958200678229, 0.026014990206541758, 0.06224098588739123, 0.024328659355108227, 0.05172528426295944, 0.054808225083564005, 0.07072382713002817, 0.032306908031127284, 0.061183814757636616, 0.01925480179488659, 0.046554816886782646, 0.07195675918566329, 0.06719441365982805, 0.02587460640019604, 0.052742163983306715, 0.0276861303552453, 1.2496351450681686, 13.898949776376996, 31.945520741598948, 29.907534190586635, 18.925187179020472, 22.72518825531006, 31.33472544806344, 27.603511537824357, 13.478069594928197, 1.6916614089693343, 0.17962128802069596, 0.12684278509446553, 4.299487965447562, 9.493877853666033, 11.512734276907784, 10.661655511174883, 8.322355117116656, 2.1934854984283447, 1.713711951460157, 1.257241034082004, 0.280462136226041, 1.1060821052108492, 4.284891537257603, 15.372206721987043, 35.93788616997855, 50.522606645311626, 50.921808447156636, 51.81675727026803, 51.95210817881993, 49.18926818030221, 46.36787223815918, 48.44796487263271, 50.20077303477696, 52.77233607428414, 50.170061997004915, 48.53528983252389, 50.2196478162493, 46.70616613115583, 49.61433465140206, 51.74601766041347, 48.00051825387137, 44.10416650772095, 40.032886913844514, 37.16162722451346, 36.59359809330532, 35.22371210370745, 35.87509529931204, 35.36248500006539, 37.85153123310634, 39.61553641727993, 46.46953133174351, 45.971137046813965, 50.01625319889614, 48.016662393297466, 49.442328521183555, 40.26348720278059, 42.35944952283587, 49.87402704783848, 46.45307799748012, 47.954576764787944, 44.99264308384487, 44.75975683757237, 38.47583382470267, 35.98064538410732, 34.467814104897634, 33.82579360689436, 33.916481494903564, 36.56351934160505, 44.72776733125959, 46.14019019263131, 48.11987440926688, 46.830559730529785, 45.46978282928467, 46.74145255770002, 45.99504927226475, 45.13118668964931, 46.81084769112723, 44.8228325843811, 44.85539879117693, 40.91952569144112, 41.542000906808035, 42.417004925864084, 40.90265893936157, 42.15262596947806, 41.75578655515398, 40.978105953761506, 43.34017038345337, 45.45311410086495, 45.189937182835166, 37.627952098846436, 24.67982074192592, 13.25010006768363, 3.365201698882239, 0.6298914402723312, 0.8772876965148109, 2.821303878511701, 4.235681354999542, 1.2169878397669112, 3.3640691425119127, 3.1076595527785162, 5.298582034451621, 3.6971720797674994, 1.2485734820365906, 0.18862170220485755, 2.5673637219837735, 10.91622187410082, 28.078073501586914, 20.761165278298513, 37.160543305533274, 38.052431447165354, 22.427110535757883, 11.88712579863412, 3.672587616103036, 0.00880929037729012, 0.06510369798966817, 0.03840929236529129, 0.05332481861114502, 0.0486721548783992, 0.059255879638450484, 0.0108915116371853, 0.12023675814270973, 0.02433716139889189, 0.010249224807401853, 0.05085747190085905, 0.028887617401778698, 0.048252284194209745, 0.051582612097263336, 0.042114605861050744, 0.09051961132458278, 0.03740994938250099, 0.054864685982465744, 0.02694989102227347, 0.044057299116892476, 0.04377284366637468, 0.044151920825242996, 0.07430674308644873, 0.06469365249254874, 0.030647764381553446, 0.026385556839938675, 0.036414494405367544, 0.03853196471131273, 0.024742428313142488, 0.034882023065750084, 0.045603775419294834, 0.04198686485843999, 0.04126457790178912, 0.028676009470863, 0.030476668383926153, 0.039902001552815945, 0.0407787230797112, 0.025652728841773102, 0.017930852748187523, 0.03181844084922757, 0.028918073446090733, 0.02781036842082228, 0.023437420571488992, 0.10179626622370311, 0.06623490407530751, 0.013496832506332015, 0.016150264900975993, 0.012176217611080833, 0.02509064061035003, 0.06376418165330376, 0.050557471213064024, 0.041505749603467326, 0.03798432249043669, 0.0018085869586294784, 0.04405369270326836, 0.06080539577773639, 0.04522865411958524, 0.027146138616704514, 0.04211045661941171, 0.020884637820667455, 0.022010232421702573, 0.04436928273311683, 0.03313745525000351, 2.438058397599629, 19.636013950620377, 36.554903575352256, 33.52253600529262, 22.507244110107422, 24.903175796781266, 39.70764173780169, 33.175713198525564, 12.709635308810643, 1.267134617481913, 0.1958199002380882, 0.09809630976191588, 0.02016178598361356, 2.3011964729854038, 9.018428257533483, 9.76732247216361, 10.81882723740169, 6.270629371915545, 4.7016909548214505, 2.9567818088190894, 1.2938882218939918, 2.2194863089493344, 6.025453499385288, 21.086361816951207, 37.569271087646484, 52.87763254983084, 52.047180380140034, 54.44423246383667, 52.0160732950483, 51.47962025233677, 48.257608549935476, 51.50784730911255, 51.69450371606009, 52.49633278165545, 50.83130121231079, 50.58187477929251, 52.435285908835276, 48.071646962847026, 50.431408064705984, 53.05633674349104, 50.105381216321675, 45.73723636354719, 41.01665803364345, 39.25436905452183, 38.25862618855068, 37.51724297659737, 37.74421977996826, 36.80060229982649, 39.6336920601981, 41.642263412475586, 46.678769384111675, 48.337432929447715, 52.308602878025596, 50.014054094042095, 49.74728843144008, 41.211360454559326, 43.22141524723598, 50.37315089362008, 48.02414560317993, 49.01763377870832, 47.54645695005144, 46.07243830817086, 40.29127999714443, 37.431929520198274, 35.87556777681623, 35.46446718488421, 34.914409569331575, 37.98353658403669, 45.51128441946847, 47.79216957092285, 47.607917240687776, 47.352685587746755, 47.93023375102452, 48.2494409424918, 48.30787181854248, 45.7853422164917, 46.35422945022583, 47.15882737295968, 46.56795951298305, 42.318767820085796, 42.12106030327933, 42.956932067871094, 42.2293827193124, 43.02289479119437, 44.36666250228882, 42.877305712018696, 45.06345564978463, 45.79841177804129, 46.02694150379726, 39.19765785762242, 27.025907788957866, 16.4594886302948, 6.0515318257468085, 1.400475976722581, 2.35396717275892, 2.7927917284624915, 4.701103397778102, 3.241571532828467, 4.903587801115854, 3.5793328029768805, 3.4277487312044417, 1.1769868433475494, 0.27443164267710274, 0.21937513484486512, 1.8051760835306985, 10.5854937008449, 32.545386518750874, 30.01102066040039, 42.375253200531006, 34.70565789086478, 24.54149079322815, 18.22214933804103, 4.937236624104636, 0.0014158346686079831, 0.031616071172590764, 0.04922809897522841, 0.05572284618392587, 0.041707023446049006, 0.01969803443976811, 0.023088280377643447, 0.05650013858186347, 0.0251285571471921, 0.034038146026432514, 0.032169253631894074, 0.02578846298690353, 0.03961894727711167, 0.047860769488449605, 0.044005513324269226, 0.02892625318574054, 0.030854052597922937, 0.0353537745374654, 0.03110337011250002, 0.023290595771478753, 0.044165671337395906, 0.0009899231143728165, 0.019508495860333954, 0.0544982261822692, 0.056199455966374705, 0.045630078829292736, 0.03524741417329226, 0.05367872890617166, 0.0899547173508576, 0.17404383873300894, 0.14315902814269066, 0.11106917328600373, 0.10688921436667442, 0.06758286138730389, 0.12087599241307803, 0.14751119246440275, 0.11758844953562532, 0.12895449463810238, 0.14656371330576284, 0.1055173251245703, 0.12223318458667823, 0.08749056993318455, 0.09780751847262893, 0.14805218843477114, 0.12798576376267842, 0.13989055209926196, 0.13234807896826947, 0.06899251788854599, 0.11257192479180438, 0.24229269581181662, 0.16893265156873635, 0.12709201100681508, 0.11204278961356197, 0.09395344635205609, 0.14097871870866843, 0.1342023251844304, 0.1254762698497091, 0.13112067697303637, 0.21424165101987974, 0.20064872183970042, 0.10749976017645427, 0.1338698158838919, 0.08234937116503716, 2.170799412897655, 21.620494161333355, 43.35039813177926, 40.9592068535941, 28.657103368214198, 30.47528886795044, 38.88474920817784, 34.55135924475533, 16.756282670157297, 2.8509142782006944, 0.44727022679788725, 0.5524278740797723, 8.128285850797381, 19.344582183020457, 22.702599661690847, 17.200260400772095, 14.139942833355494, 6.698454712118421, 4.457005798816681, 4.381696011338915, 1.4801620436566216, 1.6388142790113176, 5.4534534726824075, 18.42767878941127, 38.04021651404244, 53.267652307237896, 55.45365285873413, 55.40865979875837, 56.59545728138515, 52.791377612522666, 52.066183703286306, 52.256543500082834, 55.52139779499599, 55.54573733466012, 52.46457256589617, 49.682975905282156, 51.50206640788487, 49.44983952386038, 52.70289577756609, 55.26463059016636, 53.1549768447876, 48.19995934622628, 42.94174677985055, 42.212571552821565, 41.209352425166536, 38.84918137959072, 40.194856371198384, 38.98417098181588, 42.755090372903005, 43.70983191898891, 49.745787620544434, 50.50412791115897, 54.26042481831142, 51.92028195517403, 49.977249486105784, 45.22962876728603, 44.66808925356184, 49.78745249339512, 49.77573088237217, 51.1070682661874, 49.4925605228969, 47.69144153594971, 42.44963366644723, 39.552488463265554, 37.770258154187886, 37.052978243146626, 38.20566007069179, 40.54127270834786, 47.49706220626831, 48.96848917007446, 49.398752893720356, 49.12544550214495, 47.56703404017857, 48.97502742494856, 49.08650084904262, 46.83137961796352, 47.98952272960118, 48.2217732157026, 48.10143736430577, 44.4703574180603, 43.56402397155762, 45.21001400266375, 44.86047445024763, 45.94568926947457, 45.618095602308, 45.19315072468349, 46.34843465260097, 47.4328921181815, 46.81303637368338, 40.196374552590505, 26.89640031542097, 15.953499964305333, 4.791361365999494, 1.2335249866758073, 3.3917312238897597, 6.877812036446162, 9.435614602906362, 6.516379773616791, 8.588505864143372, 7.933683310236249, 12.286092230251857, 7.762169633592878, 2.1277627050876617, 0.4783781532730375, 3.2844008803367615, 14.416801622935704, 35.77156366620745, 28.150911467415945, 42.57126883098057, 43.50413397380284, 34.278937748500276, 22.058388744081768, 4.847778567246028, 0.11568658373185567, 0.18013401622218744, 0.15114750234144075, 0.10839873765196119, 0.12192621534424168, 0.13985705961074146, 0.15658610979361193, 0.22736715099641255, 0.16116056218743324, 0.08069139798837048, 0.13428412936627865, 0.09073248811598335, 0.13657508072044167, 0.17744944670370646, 0.15119415840932302, 0.15975003716136726, 0.10021977153207574, 0.15175320341118745, 0.09818373221371855, 0.13847052758293493, 0.12936219918940747, 0.1540456882544926, 0.1312988195568323, 0.15673909229891642, 0.11082220010991607, 0.13182709978095122, 0.11388451685862881, 0.13473697006702423], [0.05304861753912909, 0.05566822411492467, 0.013059308037294872, 0.05074575789538877, 0.032123177711452754, 0.019406727481899515, 0.02191108318844012, 0.015515351202338934, 0.012026989948935807, 0.08837949151971511, 0.017618584147255336, 0.012537046418791371, 0.023982955941132138, 0.03540013883528965, 0.039962486164378266, 0.03284293712515916, 0.02666701825468668, 0.0114026919306655, 0.04225731534617288, 0.04831143209178533, 0.010617570086781467, 0.07415389628814799, 0.041455962096474, 0.04554641546149339, 0.04516649691920195, 0.03287063831729548, 0.022308692835005264, 0.11473181710711547, 0.022367381025105715, 0.06518854200839996, 0.06376176606863737, 0.02880168433434197, 0.029391385548348938, 0.0063833499942640105, 0.05690626214657511, 0.015775469298075353, 2.778140148946217, 18.73262480327061, 28.65905407496861, 26.450635160718644, 19.63940119743347, 30.873083659580775, 37.51819140570504, 30.031107902526855, 14.122736488069807, 2.914194779736655, 0.1479161557342325, 0.27755819633603096, 1.357979491353035, 5.031692607062204, 10.883075492722647, 13.289652688162667, 5.156052768230438, 4.146261513233185, 2.8468135382447923, 1.0731474267584937, 0.10583667763109718, 0.04920514074287244, 3.7406070062092374, 15.388578414916992, 37.336746147700715, 52.00497702189854, 53.454822880881174, 49.660019057137625, 52.061073303222656, 49.56386988503592, 50.69819804600307, 52.308620248522075, 51.31386750085013, 48.51980577196394, 46.14875384739467, 46.559753690447124, 51.55625193459647, 51.02988420213972, 49.181461879185264, 47.61076947620937, 44.36951126371111, 39.19100843157087, 38.800950459071565, 36.30348995753697, 36.95653029850551, 37.68787336349487, 36.77467509678432, 36.168000085013254, 39.69844579696655, 44.820209639413015, 46.694531372615266, 49.86450801576887, 48.86042036328997, 49.62241540636335, 40.928377696446006, 39.09069381441389, 48.19260467801775, 47.20608901977539, 50.28365462166922, 46.55428893225533, 46.12409816469465, 41.8347806249346, 35.93663549423218, 35.64237928390503, 37.56769037246704, 33.5813490322658, 37.02851711000715, 45.42672831671578, 46.56910943984985, 46.99513823645455, 46.90893193653652, 47.05439942223685, 47.82364838463919, 45.01172978537423, 47.141394342694966, 45.273836680821006, 43.602308545793804, 41.33926984242031, 43.05955001286098, 40.66452332905361, 44.580687863486155, 44.64918667929513, 42.31065232413155, 43.3380720274789, 42.976175103868755, 44.29857015609741, 43.54867192677089, 39.1454108783177, 26.00951487677438, 11.484416893550328, 3.0794678883893147, 0.7257899343967438, 1.1325167438813617, 2.33414135660444, 1.9387293628283908, 3.0034013986587524, 2.0804170284952437, 3.87382264648165, 3.219136016709464, 1.6101346122367042, 0.23335687816143036, 0.06950297299772501, 1.4360870144196918, 10.345645359584264, 25.095915351595195, 26.210474150521414, 19.9078483240945, 26.387217215129308, 44.938256059374126, 19.448539393288748, 7.968773450170245, 0.6785247591989381, 0.04159427806735039, 0.03185480693355203, 0.016580644396266768, 0.033256321014570336, 0.03051134491605418, 0.028939352304275547, 0.049243973301989694, 0.031101761984505823, 0.012079845282382198, 0.011399558795216893, 0.010975493068274642, 0.017797992198861072, 0.05279035014765603, 0.003527657124712797, 0.007744749509064215, 0.007592730523486222, 0.049857131471591334, 0.08848604187369347, 0.05401198459523065, 0.011342209015440727, 0.029282670667661086, 0.02125275833532214, 0.05977268583540406, 0.011287373207908655, 0.012921416998973914, 0.034494236909917424, 0.05433775604303394, 0.02670710949626352, 0.027437526998775344, 0.047077427950820754, 0.0073630532050239185, 0.016320231137797236, 0.027205590158700943, 0.029867079308522598, 0.028521954880229065, 0.05427699662478907, 0.008801711141131818, 0.038244588167539666, 0.09990415096815143, 0.013138275942765176, 0.028979385870375803, 0.08325380406209401, 0.028634913997458558, 0.009485761801313077, 0.07741531556738274, 0.028254145590056266, 0.053871035908481905, 0.06155619477587087, 0.0032780675600016756, 0.08578404079058341, 0.05261521686666778, 0.006592188654134848, 0.001868664237138416, 0.029949141333677938, 0.060406267909067016, 0.04347768771861281, 0.022355839144438505, 0.03887330175244382, 0.04326055311997022, 0.017869810041572367, 0.09516234469733068, 0.029496246350130866, 0.02285732571700854, 0.04271284983094249, 5.1871529051235745, 25.133392197745188, 34.12294374193464, 27.327240739549907, 19.173894473484584, 30.925740582602366, 41.769835812704905, 32.04725973946707, 13.47527641909463, 2.050749740430287, 0.061019731419427056, 0.08471965683358056, 0.5568654931017331, 2.0883766242436, 7.208273572581155, 11.033970390047346, 8.729610749653407, 3.316231663737978, 4.832627585956028, 3.1788716401372636, 1.2407203891447611, 0.2581488106931959, 4.660268400396619, 19.87475405420576, 40.636838231767925, 53.040196078164236, 53.459419114249094, 52.83237198420933, 52.88350030354091, 50.18719972882952, 51.311154229300364, 52.523197991507395, 51.798712798527305, 49.809228147779194, 48.906886441367014, 49.15325566700527, 49.806688581194194, 52.935903617313926, 50.35142387662615, 49.68919454302107, 46.445747647966655, 42.041593755994526, 39.726599897657124, 38.26833629608154, 37.99515049798148, 40.86155687059675, 38.07040296282087, 37.659389223371235, 41.03070381709507, 46.56148379189627, 48.85445533479963, 52.23534802028111, 51.452025481632774, 50.03833457401821, 43.01639475141253, 41.779559816632954, 48.89755501065935, 49.36319201333182, 53.409159319741384, 49.078715392521445, 49.01728636877877, 43.24057837894985, 38.41028104509626, 37.52410779680525, 37.638780866350444, 35.18543100357056, 39.049407618386404, 48.389631271362305, 48.739275046757285, 48.3711838041033, 46.3607885496957, 47.76159749712263, 48.75713191713606, 46.24698053087507, 48.2753438268389, 46.95842048100063, 45.12670510155814, 42.77250255857195, 44.93764461789812, 43.0027311188834, 45.0909218788147, 45.39118480682373, 44.77202040808541, 44.800143241882324, 44.02712140764509, 44.951263087136404, 46.636166504451204, 40.75116736548287, 28.891610281808035, 14.580454281398229, 4.658617334706443, 2.064322612115315, 2.444256842136383, 3.3894669796739305, 2.6809854422296797, 3.784273828778948, 2.791660474879401, 3.862935253552028, 4.193407646247318, 1.6153903816427504, 0.32334462659699575, 0.09905604326299258, 1.0948829118694579, 9.858310869761876, 27.74990313393729, 32.972412381853374, 19.4529184954507, 29.715510300227574, 49.3496082850865, 25.85824564525059, 11.371175152914864, 1.3192176627261298, 0.010639648768119514, 0.017955500532739928, 0.009253587473982146, 0.03543129716334598, 0.03371900047308632, 0.05148249086258667, 0.004822471362006451, 0.031875794021678824, 0.03721664832638843, 0.015915780161906565, 0.09585565142333508, 0.012186435500292905, 0.039543361868709326, 0.03990367414163692, 0.01922473421187273, 0.016805673749851327, 0.09424410361264433, 0.05292818096599408, 0.033567276650241444, 0.03688634765733566, 0.03312791504764131, 0.02501184064229684, 0.054601790982165506, 0.0446174501308373, 0.037164984670068534, 0.0347674015377249, 0.04670163829411779, 0.04551378810512168, 0.23411037772893906, 0.09677229116537742, 0.12444989063910075, 0.081731246119099, 0.1952261413846697, 0.13367723407489912, 0.06749680279088871, 0.12183008050279957, 0.11981503505791936, 0.11269404073911053, 0.18353403306433133, 0.10291229348097529, 0.06986636242696218, 0.1468750387430191, 0.10524582969290869, 0.16154548153281212, 0.10883201618811914, 0.1651904359459877, 0.16253824611859663, 0.15688797645270824, 0.08304431994578668, 0.1675625400883811, 0.14181658732039587, 0.11896922758647374, 0.136498501258237, 0.0979856542710747, 0.09024637884327344, 0.13334935238318785, 0.12199225037225656, 0.13918760339064257, 0.09388068704200642, 0.08308254860873733, 0.2237702775746584, 0.09394206053444318, 0.14850118862731115, 0.1516023650765419, 4.932401980672564, 26.663472379956925, 40.9426006589617, 37.66093519755772, 27.013897827693395, 39.84921128409249, 46.67235967091152, 36.47826147079468, 17.756800685610088, 3.7382090091705322, 0.2997573379959379, 0.7704167483108384, 2.005808574812753, 13.285746932029724, 21.836899280548096, 23.563714231763566, 13.985652872494288, 10.546215534210205, 7.187446781567164, 4.643998324871063, 1.0862004863364356, 0.25057934543916155, 5.43626970904214, 18.711834056036814, 40.51396976198469, 55.088764735630576, 57.32939897264753, 54.06799098423549, 56.94326325825283, 53.716870716639924, 54.78393684114729, 55.88979475838797, 52.76120853424072, 49.387517656598774, 49.0272605078561, 48.889297076633994, 52.58561018535069, 53.160042081560405, 52.878098079136436, 51.51138741629464, 48.45935297012329, 43.48205259868077, 42.67661394391741, 39.4797477722168, 39.822457245418, 42.53167452130999, 40.66017375673567, 39.48296478816441, 43.395717757088796, 47.78578765051705, 51.50722891943795, 53.39982441493443, 52.0717248916626, 51.74947091511318, 45.193195887974326, 44.24573605401175, 49.852042947496685, 50.16841179983956, 53.41215746743338, 50.26327902930123, 50.88468769618443, 46.6171875, 39.844774859292166, 39.73713336672102, 40.45098434175764, 36.51920025689261, 40.02796064104353, 50.88768931797573, 49.790672983442036, 49.04043429238455, 48.05791384833199, 48.78813130514962, 50.17548506600516, 48.361487592969624, 49.20723622185843, 47.697114740099224, 46.23694385801043, 44.953114782060894, 46.68399790355137, 43.77065297535488, 46.17636251449585, 46.18695156914847, 44.5637412071228, 46.07526275089809, 45.192098072596956, 46.43694428035191, 46.570353167397634, 41.233448777879985, 29.048585721424647, 13.2261027268001, 4.206606183733259, 1.3148081621953418, 3.001512357166835, 5.322186367852347, 6.102899423667362, 6.874841247286115, 5.260965355804988, 9.805776408740453, 7.5982703140803745, 5.434728077479771, 1.6242143767220634, 0.4356886382613863, 2.446266608578818, 12.154984933989388, 30.251956394740514, 32.40666920798165, 25.331426279885427, 33.93535280227661, 52.153581619262695, 30.800144944872173, 13.657675317355565, 1.2729150844471795, 0.11551217309066228, 0.08987180037157876, 0.11809391741241727, 0.0945157686780606, 0.09897746212248291, 0.21709916554391384, 0.142032795718738, 0.12371374799736909, 0.10811032634228468, 0.05568427825346589, 0.16659850467528614, 0.08447085161294256, 0.09099006679441247, 0.1251318726156439, 0.06859402784279414, 0.07732920947351626, 0.15012385084160737, 0.2701696828007698, 0.10502587578126363, 0.08940009639731475, 0.09156205824443273, 0.10587732866406441, 0.1855377605451005, 0.1616183833352157, 0.11285407322325877, 0.12162407727113791, 0.1438016550881522, 0.1749539306121213], [0.06774437986314297, 0.04372769733890891, 0.00869653990957886, 0.017565073179347173, 0.0423155879335744, 0.009412176374878203, 0.011645000178499945, 0.02742171034749065, 0.028813046403229237, 0.02442726236768067, 0.08498189026223761, 0.06196237940873418, 0.014649223303422332, 0.036241301734532626, 0.044124701392969916, 0.009982010931707919, 0.030704985239676068, 0.057360968818621974, 0.023780447164816514, 0.029142339447779313, 0.026802313048392534, 0.023298322589003613, 0.006913878713800971, 0.030140050553849766, 0.0726607528382114, 0.007408847533432501, 0.056880338716187646, 0.04854525186653648, 0.04179393360391259, 0.05703483096190861, 0.020555495750159025, 0.07135360940758671, 0.014205057672890169, 0.029396345639335256, 0.009546748528789197, 0.05466786672228149, 0.14741961737828596, 3.0732116869517734, 19.260038239615305, 32.63415322984968, 24.824735845838273, 19.95483204296657, 18.782695259366715, 24.80986496380397, 25.54821355002267, 14.016849415642874, 3.304241027150835, 0.20491606928408146, 0.15891687758266926, 2.232494422367641, 2.5164824979645863, 6.119878649711609, 6.276755511760712, 5.019832900592259, 2.8892220854759216, 2.4731906609875813, 3.085878687245505, 0.49981589721781866, 0.1791342898671116, 2.0004454340253557, 18.234263522284373, 37.08522483280727, 52.106882776532856, 53.11244344711304, 51.687871660505024, 51.28247553961617, 50.66178601128714, 51.841624873025076, 52.049820695604595, 49.499800545828684, 46.41739552361624, 51.10628659384591, 50.56585570744106, 50.11874260221209, 49.32434116091047, 48.35016202926636, 46.193833759852815, 40.80058642796108, 39.08079263142177, 36.67885249001639, 37.39120960235596, 38.16502005713326, 37.375225271497456, 38.3041855267116, 38.90732390539986, 42.78269209180559, 46.244934286390034, 49.7573424748012, 49.6975462777274, 50.18396881648472, 40.13951744352068, 36.85236637932913, 47.6096647126334, 45.92224257332938, 50.424345220838276, 48.34891830171858, 48.76951360702515, 41.6937460899353, 38.22041457039969, 35.832846777779714, 38.04205083847046, 35.12020131519863, 40.24392802374703, 45.62150716781616, 46.51524700437273, 48.908078057425364, 49.5669583593096, 48.654295103890554, 47.514773164476665, 46.22891174043928, 45.77794238499233, 42.83861814226423, 43.147430828639436, 42.478128228868755, 43.35584899357387, 45.4286390713283, 45.659875120435444, 43.4003244127546, 42.85892425264631, 44.663215092250276, 43.89078732899257, 40.49263184411185, 32.34506300517491, 22.022537776402064, 13.122732639312744, 2.3801966224397932, 0.5624287745782307, 1.795212909579277, 2.5879154077598026, 1.9990851070199693, 1.2364565836531776, 1.82956143787929, 1.4187324770859309, 1.8490867444447108, 2.78550654223987, 0.5843278680528913, 0.28161176453743664, 1.189481224332537, 7.367767299924578, 22.50640164102827, 24.280855178833008, 24.08001228741237, 20.768221173967632, 25.863583598818096, 21.83126081739153, 8.664355874061584, 2.315889524562018, 0.018870874806972485, 0.01925678481347859, 0.052284064636166604, 0.05311778400625501, 0.033125217870942185, 0.06547644441681248, 0.015190105619175094, 0.01984594319947064, 0.06780642510524817, 0.02853580377995968, 0.03340703042756234, 0.028453227764527713, 0.05545497073658875, 0.0110848813949685, 0.050554210852299414, 0.02686465175689331, 0.036581386878554306, 0.031543885224631855, 0.05610415233033044, 0.020720601979909197, 0.021476400084793568, 0.01710882453647043, 0.062206292391887734, 0.032312719683562, 0.04691391118935176, 0.05815184888030801, 0.02890631104154246, 0.016965446694354926, 0.008894923192981099, 0.09720679784991912, 0.055132463042225154, 0.07199901834662471, 0.03464746029515352, 0.04372767359018326, 0.08199564407446555, 0.004869289430124419, 0.04937560570293239, 0.014970818368185843, 0.02785694136816476, 0.03073623516995992, 0.07762327297989811, 0.08341507147997618, 0.0608614699116775, 0.042093428783118725, 0.048995364856507094, 0.010062113686996912, 0.03501366903739316, 0.034922005741723945, 0.06182041631213256, 0.019016042285199677, 0.060491478336708884, 0.010258569082777415, 0.040732782866273604, 0.03494326763653329, 0.01649528299458325, 0.04819006931834987, 0.05905805275376354, 0.025674637041187713, 0.02172347334479647, 0.014519970864057541, 0.029397193808108568, 0.060304962630782805, 0.03221216757914849, 0.06181961564081056, 0.0629648741866861, 0.3235310880201203, 5.770503682749612, 24.92815283366612, 38.208338601248606, 25.171768835612706, 24.289503949029104, 24.553361790520803, 34.527745791843955, 33.62866973876953, 12.786714281354632, 2.711429625749588, 0.21644786692091397, 0.11107329877891711, 0.7083425191896302, 2.663053010191236, 8.306402921676636, 9.754612479891096, 3.3644441281046187, 4.903191753796168, 3.971010140010289, 3.575449628489358, 1.2672113733632224, 0.3243424530540194, 3.241587383406503, 21.296617780412944, 41.18420342036656, 54.41706500734602, 53.58182552882603, 52.241563183920725, 51.92520127977644, 53.76348270688738, 53.477435793195454, 52.76364040374756, 50.177635533469065, 49.4228492464338, 49.860120228358674, 50.59415224620274, 49.54778133119856, 50.927130767277305, 51.05873659678868, 47.474213055201936, 42.39305101122175, 40.46834094183785, 39.221486704690115, 40.847309589385986, 39.472997597285676, 39.984496184757774, 39.715750285557334, 39.35758454459054, 44.994328022003174, 49.71891893659319, 51.20764691489083, 50.37295981815883, 50.67807258878435, 41.44296475819179, 39.58912284033639, 48.99345057351248, 45.64180980409895, 49.430822304316926, 49.97381707600185, 48.786783354622976, 44.862392153058735, 38.468534742082866, 36.806053161621094, 38.06389250074114, 36.39256238937378, 41.356956481933594, 46.345109939575195, 49.26466308321272, 48.93892805916922, 48.63476371765137, 48.29266568592617, 48.28398738588606, 48.57611744744437, 46.716723918914795, 44.40763602937971, 44.498167582920615, 43.390048027038574, 43.493610927036826, 46.2332752091544, 46.2860780443464, 44.740843841007774, 44.63188566480364, 46.76487840924944, 46.256023611341206, 43.78867312840053, 36.12121786390032, 25.954016140529088, 16.627817426409038, 3.861672852720533, 1.1856640577316284, 2.8848879294736043, 3.98617936032159, 2.787686105285372, 3.054830878973007, 4.583775247846331, 4.410823728357043, 3.1369844249316623, 1.7607343196868896, 0.4156480793442045, 0.1171360295265913, 1.02864399765219, 6.783460276467459, 23.818271909441265, 29.49005515234811, 26.012858697346278, 21.947292259761266, 27.39308708054679, 29.94180965423584, 13.498131649834768, 3.901718361037118, 0.08311568825904812, 0.04184627240257604, 0.06677965234432902, 0.039508641231805086, 0.0075897424248978496, 0.038906967267394066, 0.025112499615975788, 0.05410561564245394, 0.04595181977908526, 0.018866647533806305, 0.02035798947326839, 0.042186628960605176, 0.03006173064932227, 0.013315599195526114, 0.012140643716390644, 0.01647466910071671, 0.027070154568978717, 0.06364146859518119, 0.03629891614296606, 0.03366724521453891, 0.01704805833287537, 0.021800125749515634, 0.0629659327013152, 0.05148774950898119, 0.059083993147526465, 0.007903429164019014, 0.012276118321876441, 0.03620365661169801, 0.07713223075760262, 0.1604417764714786, 0.09235770162194967, 0.16542880529803888, 0.16105492785573006, 0.1477743147739342, 0.15032190164285048, 0.10075058269181422, 0.10775045172444411, 0.11876995542219707, 0.07777405703174216, 0.16141414429460252, 0.14139725267887115, 0.1802456895155566, 0.1330156760024173, 0.09591823270810501, 0.14659989279295715, 0.15811168721743993, 0.1530504673719406, 0.06898300482758454, 0.15093736004616531, 0.10671654077512877, 0.1199358550033399, 0.06061243398913315, 0.10961426528436796, 0.1773066965064832, 0.1314473780138152, 0.12882764930171625, 0.19318461950336183, 0.2150076356317316, 0.13514661522848265, 0.10873869726700441, 0.2211565471121243, 0.14934088928358896, 0.2001747651291745, 0.09242579261107103, 0.2218382983867611, 0.32713245334369795, 6.010130984442575, 29.311215468815394, 44.07108613422939, 34.81046104431152, 30.965501649039133, 27.916805812290736, 34.13521078654698, 32.442904063633506, 18.030469383512223, 4.5363702944346835, 0.3939372386251177, 0.4637299392904554, 4.7012962102890015, 7.5592935255595615, 14.12897423335484, 13.62808380808149, 11.746041757719857, 8.86282421861376, 6.6007934382983615, 6.901358612946101, 1.4928729044539588, 0.5417583723153386, 2.8324103568281447, 21.291502169200353, 41.012767042432515, 54.21184301376343, 55.19001735959734, 56.013597760881694, 56.18809482029506, 54.80568470273699, 54.79232331684658, 54.23274319512503, 51.14905970437186, 48.72385351998465, 50.83100243977138, 50.176082611083984, 52.10243245533535, 51.710387298039024, 53.12039566040039, 49.68800292696272, 46.023915563310894, 42.91543047768729, 40.103685583387104, 42.88038376399449, 41.83313390186855, 42.55923455102103, 41.74064643042428, 41.84087419509888, 45.463168144226074, 49.72563089643206, 54.13063941683088, 52.966336727142334, 52.25191599982125, 43.30105202538626, 42.92616891860962, 51.936429568699424, 46.21973317010062, 50.99825947625296, 53.13289894376482, 50.75000034059797, 46.223179476601736, 39.8580459186009, 38.30530766078404, 40.36628232683454, 38.56246396473476, 42.62387364251273, 48.902571610042024, 50.02376420157296, 50.79796722957066, 49.68852056775774, 50.39966174534389, 49.04017720903669, 50.17769806725638, 48.423847675323486, 46.61490849086216, 45.91139643532889, 45.954913003104075, 45.191893100738525, 48.11350291115897, 47.87469332558768, 46.67818920952933, 46.175226484026226, 47.169159344264436, 46.79204586574009, 42.3808673449925, 35.91938659123012, 24.56358780179705, 15.364683559962682, 3.5843124900545393, 1.1732673857893263, 3.7203451905931746, 6.430314174720219, 7.439053211893354, 4.663946603025709, 6.511688002518245, 6.589217305183411, 6.529302988733564, 6.451188734599522, 2.356682832751955, 0.7194392808846065, 1.8361824197428567, 9.488585063389369, 27.532664230891637, 31.32680102757045, 32.70011247907366, 28.92641380855015, 34.271562235695974, 32.12014981678554, 17.122148752212524, 4.031139850616455, 0.2013565017176526, 0.1006762898926224, 0.16406781332833426, 0.13299534709325858, 0.1143311286079032, 0.15789329393633775, 0.09776411258748599, 0.09425841391618762, 0.1113815979499902, 0.13015548805040972, 0.10606812592595816, 0.08505473099648952, 0.1329665229256664, 0.16204001142510346, 0.1463903204670974, 0.07300956054989781, 0.09005411594573941, 0.09879464443240847, 0.10138467366674117, 0.05636025180241891, 0.1319094467908144, 0.1234321016818285, 0.1263275598841054, 0.1337501494480031, 0.11904738124992166, 0.15830846237284796, 0.11024746737842049, 0.10160803382417985, 0.16046477880861076], [0.040682479672666104, 0.03255347747887884, 0.058507095889321396, 0.01021165941243193, 0.015154436729582292, 0.014806955553857344, 0.004105149585354541, 0.05313356673078878, 0.009689719249893512, 0.049337906297296286, 0.04777680417256696, 0.032621157954313924, 0.008540910269532884, 0.017407439316489866, 0.02884973818436265, 0.01748740127576249, 0.03154720665354814, 0.04114761882062469, 0.03231866704300046, 0.05200949204819543, 0.02122892818546721, 0.048280531607036076, 0.014530673057639172, 0.008240104669571986, 0.03254492115229368, 0.06266044945056949, 0.04514878036986504, 0.014072677187089409, 0.02547591788295124, 0.08954824094793626, 0.03368436465305941, 0.017574857654316083, 0.03092628265065806, 0.02786843235870557, 0.022877257683181336, 0.0360636476959501, 0.02997788746974298, 0.10692051518708467, 4.223951927253178, 19.69544015611921, 31.635651929037913, 20.909415517534526, 21.664425883974346, 13.177869200706482, 23.78508731297084, 27.38524603843689, 16.694857120513916, 4.8056429539408, 0.3677439684314387, 0.18864960356482438, 2.302142079387392, 7.086077341011592, 8.598201206752233, 3.3857488249029433, 3.2008607344967976, 2.8827984758785794, 1.762381259884153, 1.878443317753928, 0.08829307329974004, 0.16109156874673708, 2.666593985898154, 15.67185299737113, 33.473547731127056, 50.98015594482422, 51.754327705928254, 52.23313501902989, 52.65952512196132, 53.740366050175254, 48.44718320029122, 48.29242249897548, 46.646286555698936, 51.37335450308663, 49.55886370795113, 50.96729482923235, 52.972169739859446, 51.868396282196045, 50.23214415141514, 44.30979149682181, 41.733142375946045, 40.078258650643484, 38.293061460767476, 39.638378620147705, 39.17219965798514, 39.38558578491211, 39.637958254132954, 41.854225158691406, 44.77768666403634, 48.180038860866, 50.25192567280361, 52.20533875056675, 41.23471335002354, 34.82975966589791, 50.960377897535054, 47.19097668784005, 51.546430655888145, 49.17370074135916, 47.55973843165806, 41.86888933181763, 38.998154231480186, 36.946413721357075, 38.04665402003697, 37.02116591589791, 41.760695457458496, 47.49332754952567, 48.28213569096157, 48.58300658634731, 50.05986704145159, 47.766256264277864, 48.199125562395366, 46.12452547890799, 44.850059100559776, 43.56720624651228, 44.13753523145403, 43.02591378348214, 43.509998253413606, 45.45402084078108, 46.968189648219514, 43.42948252814156, 44.98146343231201, 40.57588863372803, 36.273432050432476, 25.026011262621196, 17.044905628476823, 7.288533517292567, 2.179542852299554, 0.19794209993311337, 0.3697698568659169, 3.336210991655077, 2.7516824943678717, 1.2580935997622353, 2.373069724866322, 3.090535065957478, 3.460290402173996, 1.954326331615448, 1.8501452590738023, 0.4450407778578145, 0.7759323694876262, 6.970177914415087, 20.808925458363124, 22.387450218200684, 21.411198786326818, 19.80822331564767, 23.71064257621765, 23.03074744769505, 12.131744078227452, 3.517930052110127, 0.1622957784150328, 0.009935152151488831, 0.05491600697860122, 0.009778419892037553, 0.017747100376124893, 0.014083157160452433, 0.014085897593759, 0.035549009418381114, 0.032367301040462086, 0.016465578427804366, 0.05021254472168429, 0.03284568179930959, 0.05177496659702488, 0.04807158353339348, 0.022041487440999066, 0.00893480408870216, 0.0199788258011852, 0.04362002740214978, 0.07204173891139881, 0.05069223505311778, 0.031169398355164697, 0.049570647201367786, 0.0022697524358851035, 0.02664234332873353, 0.04018999556345599, 0.03471164970791765, 0.05358085022973163, 0.009828393147992236, 0.04040247541187065, 0.020857014660058276, 0.025686955844451274, 0.040041596562202485, 0.019314032813001956, 0.06873025731848818, 0.06983470198299203, 0.027713222562202385, 0.029901504782693725, 0.040652288257011344, 0.043662805642400465, 0.08974251230912549, 0.031680219873253784, 0.028557347266801765, 0.03438411746174097, 0.11387645586260728, 0.01419051073025912, 0.033140121892626793, 0.03094460309616157, 0.03731538874230214, 0.030568694695830345, 0.06699546719236033, 0.0915061876709972, 0.04640628557120051, 0.05012822656759194, 0.026588591480893747, 0.057223205853785784, 0.021919900751007453, 0.024210039559485655, 0.06895770904208932, 0.04223155476418989, 0.08452280025397028, 0.02572563912586442, 0.026217605852122818, 0.04927516894947205, 0.0353110539726913, 0.01335169725851821, 0.046156825564269505, 0.017902944602870514, 0.30630134684698923, 7.6876910243715555, 26.917448146002634, 36.13789701461792, 23.788427659443446, 18.91095379420689, 16.924111195972987, 31.538922582353862, 34.33863319669451, 17.27281175340925, 3.4412558121340613, 0.42111788583653315, 0.0228017961074199, 0.8108272541846547, 4.14525966984885, 7.196692228317261, 3.572277124438967, 4.26686704158783, 3.928135846342359, 3.2592494870935167, 3.443697018282754, 1.1503650375774928, 0.3958902252571923, 5.3622779079845975, 19.949643475668772, 37.00570617403303, 53.16897051674979, 53.67842285973685, 53.323501927512034, 52.66374267850603, 55.39535747255598, 51.871887751988, 49.258993353162495, 49.15096623556954, 51.178683349064414, 48.4457414490836, 51.572906766619, 55.41018492834908, 52.51184810910906, 51.80524410520281, 46.18920973369053, 42.08194194521223, 42.35126454489571, 40.18091828482491, 40.13689449855259, 39.195993764059885, 40.971029213496614, 40.94030427932739, 42.94937590190342, 47.3650985445295, 51.071896484919954, 52.13990061623709, 54.99546432495117, 42.45002623966762, 38.63584041595459, 52.37032720020839, 48.30338328225272, 53.485367161887034, 50.7310664994376, 48.82682234900338, 44.54315022059849, 39.80998522894723, 37.95469808578491, 39.37763009752546, 37.96171229226248, 42.88972214290074, 48.587067808423726, 49.683642932346885, 49.595397336142405, 50.68291200910296, 47.9422367640904, 48.797021525246755, 47.0838736806597, 46.037158829825266, 45.53905636923653, 44.87337725503104, 44.41876009532383, 45.95754984446934, 47.15328271048409, 48.24682494572231, 45.364347389766145, 45.37539849962507, 43.41484267371041, 39.4576872416905, 27.686658893312725, 20.44807423864092, 10.012040632111685, 4.752854883670807, 1.163075246981212, 1.4200058430433273, 4.643935356821332, 4.947774870055063, 4.0828843883105685, 4.555013179779053, 2.877616639648165, 3.355564547436578, 1.9633207746914454, 0.481845250087125, 0.25946180309568134, 0.659414390368121, 6.214523102555956, 21.838653700692312, 28.407831532614573, 22.819803612572805, 23.596327338899883, 25.013386385781423, 28.521481479917252, 16.280424867357524, 5.2074824656758985, 0.38871515169739723, 0.025023762502574494, 0.13464870623179845, 0.06036674324423075, 0.046751727749194415, 0.06752817146480083, 0.0859687380226595, 0.021902518380167227, 0.07589412826512541, 0.019986754482878104, 0.051768262671040635, 0.04463112600413816, 0.03855019016191363, 0.05340071275298085, 0.01870542761337544, 0.014409725886902638, 0.05174349614285997, 0.04152721845145736, 0.01456354807929269, 0.04776555745463286, 0.09178840395595346, 0.048156054357865026, 0.02888702368363738, 0.04356759021590863, 0.01348851281883461, 0.016967451765335033, 0.020947264906551157, 0.044439490751496384, 0.05861167170639549, 0.007519223128578493, 0.1823126428893634, 0.18092849930482252, 0.08134524790304047, 0.1970036452902215, 0.10546458259757076, 0.12905632917370113, 0.1804786848702601, 0.1255941992359502, 0.10336360069257872, 0.136448506798063, 0.15369253791868687, 0.10440104002399103, 0.09791512734123639, 0.26498518671308247, 0.1661334503442049, 0.07352266194564955, 0.07334092991160494, 0.09720612610025064, 0.07756920052426201, 0.14554687429751667, 0.1864535521183695, 0.12769867559628828, 0.09278301415698868, 0.08258083981594869, 0.08799631600933415, 0.15927031290318283, 0.10852622759661504, 0.21372589655220509, 0.09422182052263192, 0.2371924194906439, 0.14675544016063213, 0.06135542983455317, 0.08827798946627549, 0.11226725578308105, 0.06373134734375135, 0.17766067465501173, 0.15686117431947164, 0.47061723257814136, 8.201306206839424, 32.05244656971523, 43.10282686778477, 32.56797511237008, 30.421030385153635, 20.587983165468486, 32.280507292066304, 34.92919881003243, 22.564333983830043, 6.030423632689884, 0.739866061934403, 0.6003791838884354, 3.7922577432223727, 12.54454003061567, 15.091018336159841, 5.982279564653124, 9.512694443975176, 7.522242256573268, 3.8929271527699063, 6.206639068467276, 0.9663211533001491, 0.5627918722374099, 3.7299089516912187, 18.739817925861903, 37.08725023269653, 54.00656196049282, 56.25068766730172, 56.997910840170725, 57.28937040056501, 58.01409878049578, 52.5839843068804, 50.15206616265433, 48.76812049320766, 51.46728719983782, 49.13714279447283, 51.99530165536063, 56.25736141204834, 55.22476877485003, 54.96123055049351, 47.26788282394409, 46.09501995359148, 45.167289529527935, 42.83337572642735, 43.04478161675589, 41.89798491341727, 42.600117751530235, 42.86094617843628, 44.56260865075247, 48.468865053994314, 52.53626755305699, 55.00378826686314, 56.27797671726772, 45.748422963278635, 42.12012229646955, 56.383377415793284, 50.912039279937744, 54.46059199741909, 52.92926113946097, 50.91888325554984, 47.96290765489851, 41.487214360918315, 39.457312038966585, 41.432994093213765, 38.655156408037456, 45.3211087499346, 50.96806607927595, 52.053878443581716, 51.670720032283235, 51.05182661328997, 48.85881880351475, 50.80732297897339, 48.17705460957119, 48.152228696005686, 47.04584618977138, 47.650620869227815, 47.431860310690745, 46.898124013628276, 48.12699631282261, 48.17403909138271, 45.051233768463135, 45.801854610443115, 42.771349157605854, 39.67709398269653, 26.515913486480713, 19.587557213647024, 9.32726526260376, 2.955870292016438, 0.8524901728544916, 2.148521099771772, 8.532296674592153, 8.05864839894431, 6.110060410840171, 7.943746907370431, 9.832409722464424, 9.44826032434191, 8.782578604561941, 4.250309484345572, 0.972165891102382, 1.1375549478190286, 8.804605262620107, 26.573533160345896, 30.020494529179164, 27.68176215035575, 29.599541391645158, 33.226188387189595, 32.53400536945888, 18.719926970345632, 5.274064447198596, 0.4535186657948153, 0.07882409675845078, 0.2487298489681312, 0.10215403059763567, 0.203604895355446, 0.12762805367154734, 0.15359199259962353, 0.20822752373559134, 0.10097252471106392, 0.08328039584947483, 0.14679304457136563, 0.186485443264246, 0.14575232113046305, 0.07982712757906743, 0.14650436863303185, 0.05960987814302955, 0.09908182080835104, 0.10239455769104616, 0.11101129424891301, 0.17606108263134956, 0.19207566258098396, 0.14347082855445997, 0.0904931416735053, 0.1303664581584079, 0.12329684251121112, 0.09997047098087412, 0.13177633179085596, 0.12723311914929322, 0.2294132597744465, 0.10431845552687134], [0.05381327900769455, 0.07435078000915901, 0.07514412315296275, 0.05428902026531952, 0.02919430165950741, 0.06424635542290551, 0.01599281424257372, 0.034477677262787304, 0.04659792421651738, 0.06735879555344582, 0.03826687804290226, 0.05728567178760256, 0.04263170382806233, 0.02188693412712642, 0.029175126259880405, 0.0688156984480364, 0.0349993926606008, 0.05029727678213801, 0.040913127296205075, 0.03370970454333084, 0.05496539414993354, 0.058739867327468734, 0.040495821474386115, 0.03207713571776237, 0.07823892815836839, 0.05709516629576683, 0.051252681229795725, 0.0423127279084708, 0.04213896526822022, 0.02978666273078748, 0.03454165972237076, 0.059546034783124924, 0.038930291908660104, 0.03700665530881711, 0.0349777032887297, 0.059288286470941136, 0.11042129447949783, 0.06999221031687089, 0.13742394159947122, 6.022165264402117, 21.894353934696742, 32.67434161049979, 24.700661863599503, 21.24545819418771, 11.08556684425899, 17.772920506341116, 27.865194593157085, 21.80637584413801, 5.147711021559579, 0.5976754661117281, 0.04181555512228182, 5.249476075172424, 8.79541540145874, 1.4209347303424562, 3.662214824131557, 2.168722552912576, 2.9283324096884047, 2.1856592212404524, 1.2003637318100249, 0.09630454983562231, 0.2701469383069447, 2.2630235041890825, 13.031503660338265, 32.161588873182026, 48.271643911089214, 53.618154185158865, 52.74663468769619, 49.90602697644915, 50.0965952192034, 48.946067333221436, 46.846637862069265, 54.94022267205374, 53.09339843477522, 50.28930350712368, 55.05141816820417, 50.11022063664028, 51.227219990321565, 48.27668482916695, 44.287578105926514, 43.037975856236045, 43.004843371255056, 43.95355040686471, 43.04151248931885, 41.71354498182024, 41.54954317637852, 41.33491679600307, 43.08379922594343, 50.17624936785017, 48.88502740859985, 52.56609269550869, 47.90010983603341, 37.5594220161438, 46.90818847928728, 49.66302762712751, 51.14943143299648, 48.156703335898264, 47.055365221840994, 43.31126587731497, 38.9391952923366, 38.99248102733067, 39.232840061187744, 40.443716526031494, 46.52573878424508, 47.0513595853533, 46.809360776628765, 48.74854046957833, 49.04875476019723, 47.81730120522635, 48.682122639247346, 47.91908884048462, 46.18748310634068, 44.62858179637364, 44.938356808253694, 45.33695759092058, 46.752576623644146, 48.12583596365792, 45.52886683600289, 42.73951598576137, 37.22637748718262, 28.185935599463328, 19.47215632029942, 11.513806905065264, 3.871471549783434, 0.9078371886696134, 1.9390524540628706, 0.9682251768452781, 1.0722747764417102, 2.329537740775517, 4.16548935004643, 2.3056572164808, 2.6085839101246426, 2.592328382389886, 1.302716885294233, 1.0371176515306746, 0.23242340396557534, 0.493361020726817, 6.087396689823695, 20.233988080705913, 26.036739655903407, 18.11412569454738, 17.534774473735265, 22.590900421142578, 25.182576758520945, 9.601757322038923, 2.2740639746189117, 0.11294060000883681, 0.054681820794939995, 0.0363157166700278, 0.03454668766685894, 0.036758627010775466, 0.02951740307201232, 0.019142030971124768, 0.04399727251646774, 0.049215742852538824, 0.018169568153098226, 0.08800788503140211, 0.046197985498500724, 0.023267993770007576, 0.04610711269612823, 0.06302974891981908, 0.020655679749324918, 0.031073402613401413, 0.03152823481442673, 0.015654383027659993, 0.024284970181595002, 0.0419596013213907, 0.0021518760601923403, 0.039990401095045466, 0.04840238971103515, 0.1634521106524127, 0.056687010518674336, 0.01519719631011997, 0.0419242564322693, 0.007500028221069702, 0.013061772815750113, 0.017291304655373096, 0.024604763735884, 0.03602468282250421, 0.03154206335810678, 0.08869701876704182, 0.055138301836060624, 0.06641706358641386, 0.08052102463053805, 0.04917739544595991, 0.025953840630661165, 0.02873764080660684, 0.03850718800510679, 0.10004248390240328, 0.030779661411153417, 0.005070813482494226, 0.026948018265622, 0.04313112935051322, 0.05070148009274687, 0.0021529926743824035, 0.04250679910182953, 0.02527786877804569, 0.04479410672294242, 0.012411531859210559, 0.005946659699215421, 0.018131921333926063, 0.05436503315078361, 0.06161258103592055, 0.03277827952323215, 0.02592082311665373, 0.06841239758900233, 0.034993282452757866, 0.033746253832110336, 0.08398464734533004, 0.02337737531135125, 0.053901617481772385, 0.004115479856929076, 0.03326316064755831, 0.02376660335409854, 0.058008908693279536, 0.6329363254564149, 9.147735101836068, 29.55532305581229, 34.63351821899414, 28.003686087472097, 17.500535488128662, 13.587119834763662, 26.998947041375295, 36.92094509942191, 20.891216448375157, 4.386657025132861, 0.49848070314952303, 0.1530959970716919, 0.3260172131870474, 3.049380451440811, 1.6136347672769, 4.029132689748492, 3.189683471407209, 4.098942978041513, 3.991701441151755, 1.9341502828257424, 0.3805549538561276, 0.3537635957556111, 4.232697972229548, 17.032721962247575, 36.721305983407156, 51.23920563289097, 54.63073601041521, 55.04258700779506, 52.16561937332153, 50.947447299957275, 50.58398355756487, 48.52522536686489, 55.87285852432251, 51.67848464420864, 51.774866580963135, 56.02091073989868, 53.18445805140904, 52.19885260718209, 48.561279569353374, 43.715852533067974, 42.88556017194475, 44.370946066720144, 44.43960469109671, 43.22141177313668, 42.40881994792393, 43.38607365744454, 42.734106813158306, 46.006628445216585, 51.98099878856114, 50.589090483529226, 54.032138279506135, 47.62851170131138, 40.24727010726929, 50.32818562643868, 48.90754304613386, 51.673721654074534, 50.1668484551566, 49.12044627325875, 44.51560756138393, 40.34378753389631, 39.75089774812971, 40.425553934914724, 41.05080495561872, 47.33577714647566, 48.20331532614571, 48.86372423171997, 48.35402870178223, 47.92545339039394, 47.88396222250802, 49.42330435344151, 49.25300748007638, 46.96521929332188, 44.891887256077354, 46.98823520115444, 46.34755917957851, 47.02325759615217, 47.74709660666329, 44.85577399390084, 43.45948484965733, 39.06133072716849, 32.680824279785156, 23.090870210102626, 14.565536499023438, 5.883598208427429, 1.9532591317381178, 3.2034730400357927, 1.4240305870771408, 2.0760935119220187, 3.5131192931107114, 4.2383425150598795, 4.946860313415527, 5.619692598070417, 4.617472273962838, 2.922095532928194, 0.7485665093575204, 0.09872489781784159, 0.1710535077644246, 5.471272562231336, 19.76651154245649, 28.870248045240128, 22.352092572620936, 19.898702757699148, 24.75406050682068, 30.17906631742205, 15.149628128324236, 4.953806774956839, 0.5408662887556213, 0.015668162377551198, 0.05611462212566819, 0.013350134931637772, 0.02706048544496298, 0.03376687111865197, 0.03184736001172236, 0.06907170971057244, 0.09167683922818728, 0.06292040978691407, 0.02299246614399765, 0.05284467366124902, 0.04364090592467359, 0.029644862482590333, 0.03779000023912106, 0.034747092984616756, 0.033243486524692605, 0.02635725005529821, 0.012278911341646952, 0.015584400622174144, 0.019691629069192067, 0.02449261716433934, 0.011866170364165944, 0.01583031189095761, 0.03177702985703945, 0.04128163627215794, 0.03770113590040377, 0.007953912169406456, 0.04159541122083153, 0.029414523592484847, 0.0487856636089938, 0.1380280956093754, 0.13861593763743127, 0.11896263222609248, 0.2861735283264092, 0.092697410179036, 0.19279276553009236, 0.16562701894768647, 0.10063508246093988, 0.06457096657582692, 0.10943746619990893, 0.1508740662996258, 0.15536002415631497, 0.09568613980497633, 0.06689171918800899, 0.15782252273389272, 0.18362007130469593, 0.16989595416401113, 0.14736142621508666, 0.23929017835429736, 0.23973483592271805, 0.13942472423825944, 0.1472214308700391, 0.10633105824568442, 0.06667110709739582, 0.22131205376769814, 0.1569702284676688, 0.170846961704748, 0.08117843006870576, 0.20271244538681849, 0.1275200308965785, 0.08723746958587851, 0.12162140384316444, 0.18341573726918015, 0.12001858199281351, 0.14434503950178623, 0.1776303577103785, 0.09647433286798851, 0.1185350873108421, 0.6514852472714016, 9.929302351815359, 33.53457028525216, 44.43935803004673, 35.447228704180034, 29.936223302568706, 18.847956214632305, 26.64292308262416, 36.156611987522666, 26.562450783593313, 6.5886870707784375, 1.206982542361532, 0.5687398016452789, 8.25281320299421, 15.1108033316476, 8.262854218482971, 10.91487739767347, 7.54757365158626, 10.368875793048314, 5.735321913446699, 2.755020235266004, 0.5718176364898682, 0.8017075264028141, 3.495305414710726, 15.0957396371024, 35.49090508052281, 52.17770576477051, 56.44829443522862, 55.86990901402065, 54.0475354875837, 54.942411354609895, 50.806985991341726, 50.26301152365548, 56.27318246023995, 52.05830792018345, 52.16947909763881, 57.39961746760777, 55.78773961748396, 54.47805282047817, 52.047951630183626, 47.978655747004915, 44.78604187284197, 46.96431255340576, 48.494660241263254, 46.457014151981895, 45.15846184321812, 45.923253536224365, 44.336997168404714, 47.10986689158848, 54.798264026641846, 52.92706550870623, 56.42078651700701, 49.99246951511928, 44.14520604269845, 47.26923772266933, 50.0487186568124, 54.59964976991926, 53.34893928255354, 50.13526889256069, 46.45725039073399, 42.349183559417725, 42.24471391950335, 42.21117843900408, 43.83048391342163, 49.66686650684902, 50.0690838268825, 50.04320873532976, 49.06072303227016, 48.82951130185808, 49.050297260284424, 50.668272154671804, 50.06347663061959, 49.94368968691145, 47.664343561444966, 47.480292728969026, 48.40350334984915, 50.11144004549299, 50.18505620956421, 45.220575264522004, 43.66467905044556, 38.270292213984895, 31.165022645677837, 21.436589241027832, 13.49117042337145, 5.107421892029898, 1.6546293560947691, 2.988627574273518, 2.798805828605379, 2.5870203929288045, 5.864092877932957, 9.486906204904828, 6.538292220660618, 6.839355060032435, 7.56940576008388, 5.527978113719395, 3.130306988954544, 0.7131288509283746, 0.8338460932884897, 8.160759993961879, 24.15561737333025, 33.382821628025596, 25.78653155054365, 25.27738492829459, 31.596995626177105, 34.97564056941441, 15.057220561163765, 4.1695140940802435, 0.337637939623424, 0.23274144689951623, 0.16179949790239334, 0.08849758375436068, 0.1531469686222928, 0.08494626038840838, 0.07009177176015717, 0.13026461005210876, 0.1460888066462108, 0.0947440889264856, 0.1790896151214838, 0.10582443685936076, 0.09969459221299205, 0.14470441878906318, 0.12081793695688248, 0.08632538959916149, 0.08253974773521934, 0.07735332460807902, 0.11415190036807742, 0.1688392444380692, 0.10300220615629639, 0.04948920264307942, 0.09310345231954541, 0.13583471759089402, 0.2193694080093077, 0.14034690761140414, 0.06894924771040678, 0.13986746833792754, 0.07929687281804425, 0.0704698379018477, 0.1212813492332186], [0.05812742840498686, 0.023432499496266246, 0.04196957239348974, 0.0727423331035035, 0.057319551041083674, 0.07128882288400616, 0.0470826255290636, 0.02916498216135161, 0.06307998086724963, 0.054402610420116355, 0.05975048416959388, 0.040861721483192275, 0.01763128801914198, 0.024193753022700548, 0.02063280633384628, 0.039193621171372275, 0.07116398601127522, 0.015837256696873477, 0.04312708867447717, 0.05401982167469604, 0.019010164475600635, 0.030122493460242237, 0.04071493739528315, 0.007501309804086174, 0.05028294272986906, 0.003983382235414216, 0.026157541932272058, 0.08031756590519633, 0.08422743396035262, 0.035067568466599496, 0.05829937596406255, 0.017114834660398107, 0.07587508857250214, 0.03358528496963637, 0.037639379035681486, 0.031888421558375867, 0.0035568292535442326, 0.06743791952197041, 0.05489022943324276, 0.5254992076328823, 5.401911301272256, 19.971160309655325, 32.15609632219587, 30.889613424028667, 22.698625292096818, 16.312820843287877, 15.210885184151785, 28.462965488433838, 21.894465105874197, 5.411793376718249, 1.4330744275024958, 0.3083820609109742, 3.065041256802423, 0.6348546796611377, 1.6008065470627375, 1.2172170217548097, 4.007599788052695, 2.2702646127768924, 1.548059623156275, 0.26666016397731646, 0.22924566162484034, 0.16709289886057377, 2.6308131515979767, 11.820566398756844, 27.282549926212855, 39.90125676563808, 48.33272899900164, 51.803104060036794, 46.85050106048584, 45.514070647103445, 46.36023964200701, 50.413891656058176, 54.916112422943115, 50.535168988364084, 54.44611195155552, 51.850911140441895, 51.46147155761719, 51.818143435886924, 50.231359004974365, 49.51370389120919, 50.26836163657052, 51.03305605479649, 51.08505637305123, 47.614820275987896, 46.11189712796892, 44.94339425223214, 43.88826165880476, 47.90620340619768, 49.636436871119905, 52.51187242780413, 50.379150663103374, 41.79720824105399, 50.3895069531032, 50.70188406535557, 52.85973399026053, 48.87354898452759, 49.70821523666382, 44.25780854906355, 42.01520102364676, 41.66983733858381, 42.88845409665789, 44.71618121010916, 47.85974427631923, 47.866834912981304, 51.40739025388445, 50.380387442452566, 48.432001386369976, 48.68782363619123, 47.05696678161621, 46.84728404453823, 46.8815838268825, 47.128769465855186, 45.66804967607771, 46.376734665461946, 47.691445010049, 43.47611883708409, 34.7179388318743, 26.719662461962017, 19.136699029377528, 12.135543874331884, 5.857181591647012, 1.8908853701182773, 0.4377911468701703, 0.18885343548442635, 2.0800335747855048, 1.5529253163508006, 1.7730774687869209, 3.8103217567716325, 3.12893254842077, 4.632912474019187, 6.3749279124396185, 1.7991291965757097, 1.6210259135280336, 0.5514814534357616, 0.4632783606648445, 6.047495790890284, 18.331342015947612, 28.213082211358206, 24.6851395879473, 21.582579578672135, 25.374152490070887, 19.9862048966544, 8.20863047667912, 0.7163502095001084, 0.08189003009881292, 0.07322268161390509, 0.024740329943597317, 0.0682454915451152, 0.017055330531937734, 0.062022809737495015, 0.1150805162531989, 0.04712907464376517, 0.021651901471029435, 0.06571093933390719, 0.028139973591480936, 0.09653165550636393, 0.04507910500147513, 0.06766635512134858, 0.07056275648730141, 0.052614029430385144, 0.03303585480898619, 0.0762322490502681, 0.043922467423336845, 0.03280764312616416, 0.01406429473510278, 0.03431248791249735, 0.020439364481717348, 0.026436262065544724, 0.03369717878688659, 0.04554043078262891, 0.02431808947585523, 0.0758556756856186, 0.0584551336775933, 0.042767821345478296, 0.04155484839741673, 0.04900634016043373, 0.0223040075507015, 0.06897193113608019, 0.013476996383230602, 0.032004373015037606, 0.08417321222701243, 0.01763135247996875, 0.011468667586866235, 0.09917559434792825, 0.026952294732577035, 0.05699652087475572, 0.041185620174344094, 0.028251202444412878, 0.03805162637893643, 0.01740243172805224, 0.04297093741063561, 0.036975744646042585, 0.061758337143276415, 0.07848198618739843, 0.013012734241783619, 0.018638881987759044, 0.029434672689863613, 0.059369717458529134, 0.032486468753112216, 0.015196792581783873, 0.010058477587465729, 0.04807375484545316, 0.09262475943458931, 0.06612694236849036, 0.011684471408703496, 0.04754602762737444, 0.04669308875288282, 0.05276057603103774, 0.02698360233833747, 0.02152030130050012, 0.049025111831724644, 0.04745828626411302, 0.023845345646675144, 0.09680429087685687, 0.02370860048436693, 0.894066510455949, 9.399454440389361, 27.551486900874547, 34.25363935743059, 29.956668376922607, 15.051173891339984, 14.229507718767438, 23.253928797585623, 31.488218103136333, 20.562379053660802, 5.7356250286102295, 0.6675028534872192, 0.36059858756405966, 0.32263699599674767, 0.787506277007716, 3.031414581196649, 2.6801351564271108, 5.034580886363983, 5.257335790566035, 3.7728271058627536, 1.9096906696047102, 1.1319779327937534, 0.3924679388957364, 3.704087708677564, 15.540071725845337, 32.256428309849326, 44.87846681049892, 51.451702390398296, 52.86718593324934, 50.52668176378523, 48.69403185163225, 50.40871524810791, 51.04916197913033, 54.8764625276838, 51.29973833901541, 53.106172697884695, 53.91670090811593, 52.15527350561959, 52.64544112341744, 52.15960223334176, 51.13939128603254, 52.5570878301348, 51.21259750638689, 51.18021890095302, 47.94215338570731, 46.056631156376426, 45.78336197989327, 45.4666804586138, 50.49892718451363, 51.95225061689104, 53.18321432386126, 51.66112109592983, 43.31818280901228, 50.39050054550171, 50.71842425210135, 53.44867025102888, 49.43843405587332, 51.24231495176043, 46.14367471422468, 43.666468211582725, 43.23932770320347, 43.44678701673235, 46.48069013868059, 48.66420670918056, 49.547607626233784, 51.11668804713658, 50.12362371172224, 48.90467344011579, 47.66394404002598, 48.85642862319946, 47.49171209335327, 47.02078056335449, 47.25155108315604, 46.68996640614101, 45.998241969517295, 49.178112847464426, 44.444590023585725, 38.57219839096069, 30.266582352774485, 23.21726315362113, 15.38255432673863, 9.347742472376142, 3.9024900453431264, 1.4203731204782213, 0.8115422129631042, 4.649189497743334, 2.366682593311582, 2.9372048250266483, 4.895489241395678, 3.7301282542092458, 3.746020955698831, 3.4852244470800673, 2.5055848998682837, 0.8425355213029044, 0.1832478812762669, 0.38974082523158615, 5.415340866361346, 18.636932475226267, 31.249068055834087, 28.74347468784877, 21.363263164247783, 26.330624137605938, 25.31187752314976, 13.25340827873775, 2.0958674337182726, 0.17380941845476627, 0.021468864953411475, 0.03823809798008629, 0.011679879422964794, 0.04238329555041023, 0.024324613590059534, 0.053119344636797905, 0.03266397690666573, 0.01724057398470385, 0.06271374837628432, 0.0849528828901904, 0.04354085932884898, 0.04331532107400043, 0.013786066539718636, 0.03257995730798159, 0.045735512993165424, 0.03655550755294306, 0.045030684742544375, 0.07867193528051887, 0.06010468623467854, 0.04100527574441262, 0.04537911247462034, 0.02521416112514479, 0.04942757130733558, 0.025805117628936256, 0.0337491817107158, 0.023338093222784143, 0.015894630225375295, 0.030976653697767427, 0.05361789145639964, 0.043727178259619644, 0.05092626856639981, 0.12705708002405508, 0.23546210091028894, 0.13988287108285086, 0.18539214693009853, 0.11912869688655649, 0.20896475203335285, 0.10166859307459422, 0.13066567853093147, 0.10011693954999958, 0.1153210840587105, 0.13243649208119937, 0.09443806963307516, 0.16163403035274573, 0.06135880893894604, 0.10346701621477093, 0.13749441424650805, 0.17563180066645145, 0.09462281436260257, 0.12653683365455695, 0.12355688427175794, 0.09216151000665766, 0.1077059330418706, 0.07336005102843046, 0.11638713042650904, 0.15016410153891357, 0.09409142644809824, 0.16971979290246964, 0.1122382144842829, 0.16656537859567574, 0.1677774049873863, 0.17845582270196506, 0.1080546864707555, 0.1863913440278598, 0.11556608948324408, 0.1429081466048956, 0.1471784660326583, 0.10225325277341263, 0.20596774428018502, 0.29877715344939915, 0.7795495039650372, 9.628938674926758, 30.44844797679356, 44.08297102791922, 41.63215378352574, 31.10059200014387, 24.502523558480398, 23.187762839453562, 35.49360792977469, 28.083875247410365, 7.46852399621691, 2.0866152559007918, 0.8091299395476068, 5.13929979290281, 4.904872783592769, 8.057390774999346, 6.490924613816397, 9.891016909054347, 7.653505018779209, 5.054057555539267, 1.8413206126008714, 1.3623978942632675, 0.7370595325316701, 3.41329083272389, 14.75688988821847, 30.206331048692974, 42.370827198028564, 51.20263726370675, 52.57695967810494, 52.72977488381522, 50.710121154785156, 50.30528088978359, 50.35333463123867, 54.104719161987305, 51.388716970171245, 54.28780419485909, 56.30774974822998, 54.978170258658274, 55.74923617499215, 55.067610945020405, 54.629297733306885, 54.31825120108468, 53.982118197849815, 55.125604084559846, 51.359218393053325, 49.268904958452495, 48.38409008298601, 47.137611048562185, 51.89221470696585, 53.90417678015572, 55.47208990369524, 53.55169119153704, 46.94884933744158, 49.89422198704311, 51.48929214477539, 55.360710280282156, 51.36048991339547, 53.03425536836897, 48.44604022162301, 46.35669953482491, 45.60311181204659, 45.25509738922119, 48.45484011513846, 50.47667210442679, 51.16746200834002, 54.83305713108608, 52.66137681688581, 48.278762340545654, 47.936956133161274, 49.59617900848389, 48.72392300197056, 48.53460890906197, 50.48446103504726, 48.59658336639404, 48.54136255809239, 50.49145092282976, 43.70564910343715, 35.88884231022426, 28.187657015664236, 21.98067487989153, 13.879487872123718, 7.812075938497271, 2.545328378677368, 1.1603972592524119, 0.6574000641703606, 4.921909332275391, 5.2573622805731635, 4.168647740568433, 9.040205648967198, 7.077931446688516, 11.616648060934883, 13.761430161339895, 6.885638747896467, 4.153577097824641, 1.021283249769892, 0.9419045320578984, 7.359315684863499, 23.180633987699235, 36.200208459581646, 34.0007700920105, 28.682761328560964, 34.22162205832345, 28.585708890642437, 12.644196305956159, 1.743838254894529, 0.17792823458356516, 0.1452589447477034, 0.062947659753263, 0.19490174736295426, 0.1188795795398099, 0.13756711248840603, 0.17994883044489793, 0.12566993731473172, 0.09680372769279139, 0.13636017510933535, 0.13261990009674005, 0.18005328412566865, 0.14001316337713174, 0.177716463804245, 0.14370949646191938, 0.19612180760928563, 0.08479969003903014, 0.17356468444424017, 0.19218322395214013, 0.10898283416671412, 0.12171970999666623, 0.09928557808910098, 0.09954498881208045, 0.1061954190954566, 0.13062194016362938, 0.14749975236398832, 0.08953384243484054, 0.10794586980981485, 0.13528415427676269, 0.19771099090576172, 0.16604560720069067, 0.1374511644244194], [0.016369698036994253, 0.05395492997818759, 0.03802140782188092, 0.022793601100732173, 0.025202142573626976, 0.031530300953558514, 0.021540947424780046, 0.020746905389907103, 0.007937517915187138, 0.014877370525417584, 0.05710408224591187, 0.08730050548911095, 0.05626925686374307, 0.052884228860161135, 0.022842935685600554, 0.07833045574703387, 0.05739691760390997, 0.037400161514856985, 0.08245508692094258, 0.02096613835809486, 0.012879233325033315, 0.08262680377811193, 0.06507128437182733, 0.051410946130220375, 0.009390437809218253, 0.024038848566955755, 0.015146855797086443, 0.08796089648136071, 0.06148656351225717, 0.03978430286848119, 0.011017208553052374, 0.02133723933781896, 0.013782360890348042, 0.08542982515479837, 0.0589835699647665, 0.0437812201811799, 0.06036708251174007, 0.027866729235808765, 0.008792170090600848, 0.12727423837142332, 0.07656470406800508, 3.502674413578851, 20.16733227457319, 34.62207801001412, 30.744413443974086, 15.205679246357509, 20.085857697895594, 19.697580201285227, 29.58196939740862, 15.137058837073189, 8.65298775264195, 1.650241351553372, 0.1534724754414388, 0.13902852764087065, 1.4745055586099625, 2.471924351794379, 2.2559235308851515, 3.980171774114881, 2.0826734559876576, 1.7805371199335371, 0.48247498486723217, 0.14789539256266185, 0.24314564147165843, 1.650915109685489, 8.580242718969073, 18.283501931599208, 27.63582239832197, 36.45012821469988, 45.46084744589669, 48.00184883390154, 45.433634826115195, 49.80471529279436, 58.235652514866416, 47.440976347242085, 54.04597561700003, 53.748283522469656, 54.618031229291645, 51.09600673403059, 51.72960948944092, 52.551862784794395, 51.69554247174944, 52.66515663691929, 52.91707747323172, 51.8608957018171, 51.97115319115775, 48.856619698660715, 49.0839786529541, 48.27487482343401, 50.50022302355085, 53.7936691556658, 53.11151933670044, 38.35439668382917, 52.957272802080425, 51.28459474018642, 51.44235706329346, 49.579822949000764, 48.06032487324306, 46.52576310294015, 43.914591857365195, 42.94234085083008, 45.46915054321289, 48.85573727743966, 50.75109468187605, 49.838855266571045, 49.970673016139436, 50.526876313345774, 50.52261706760952, 49.47907059533255, 49.39774540492466, 49.80382592337472, 48.17774942943028, 47.96499558857509, 47.203674520765034, 45.51687771933419, 38.401338713509695, 25.760126658848353, 17.19908094406128, 10.920039909226553, 6.892262552465711, 2.950541457959584, 1.663025602698326, 1.4491414853504725, 0.49983527617795126, 1.1776939311197825, 4.4086267948150635, 1.2178311773708888, 3.277983784675598, 2.415495425462723, 1.7666735095637185, 2.8628363013267517, 2.5508901945182254, 2.0435049406119754, 0.5479619194354329, 0.8209984398313931, 5.345981776714325, 16.316713571548462, 24.777067729404994, 24.46834363256182, 22.688736268452235, 23.935453278677805, 20.066112654549734, 7.079038381576538, 1.0151497274637222, 0.028822925873100758, 0.015766404070226208, 0.028272074181586504, 0.015116576171879257, 0.020644219292859946, 0.020394379306318502, 0.0015905778979816074, 0.010891703323328068, 0.06625321773546082, 0.007225675308810813, 0.0669465855296169, 0.021333704170371805, 0.027020857303536365, 0.010583493209976171, 0.007749020887006606, 0.022747757578534738, 0.010400438880813974, 0.021624475085575665, 0.02443953536983047, 0.0377049899793097, 0.02897980995476246, 0.03848813474178314, 0.04520276461594871, 0.06577675723071609, 0.023056684394500086, 0.015994569951934472, 0.06248787085392645, 0.022572049239118184, 0.015248079651168414, 0.003744682097541434, 0.03187032163675342, 0.029236760988299335, 0.023518162846033062, 0.02975827961095742, 0.04810689788843904, 0.0737482002004981, 0.003663621759707374, 0.04371152106406433, 0.01817227720416018, 0.03120917407795787, 0.05203739680083735, 0.035304448434284756, 0.03737647046468087, 0.027468943170138767, 0.08543910751385347, 0.0920879432399358, 0.05291708352576409, 0.029171183971422057, 0.014088725388449217, 0.038590603707624335, 0.057634364148335795, 0.0452289255335927, 0.02697700697795621, 0.04082318747948323, 0.03719278085710747, 0.05425400446568217, 0.02502790156618825, 0.023139966086351445, 0.02166140605030315, 0.05223195314673441, 0.06455567239650659, 0.0738172275679452, 0.057481761622641764, 0.03327299940532871, 0.016323001257010868, 0.07682416907378606, 0.009847131740700985, 0.0809981297435505, 0.014868027098210794, 0.11653942082609449, 0.05713360530457326, 0.03519487181412322, 0.02630254316941968, 0.2622554131916591, 6.16826286486217, 28.074889489582606, 37.59990916933332, 31.641992160252162, 14.60348755972726, 12.810701199940272, 28.20418851716178, 38.00684084211077, 17.33293625286647, 9.85036473614829, 0.9004293233156204, 0.26344667641179903, 0.18046486989728042, 1.0602162863527025, 1.9278945156506129, 4.339007581983294, 4.624202907085419, 7.073550173214503, 2.795336289065225, 2.2106319155011858, 0.9663688135998589, 0.6984171803508485, 2.5280427805015018, 11.243039948599678, 23.093491418021067, 33.110122203826904, 40.54787349700928, 48.05221285138811, 51.784211908067974, 47.667428561619346, 53.60551193782261, 57.00070401600429, 48.706621987479075, 54.90976871762957, 55.145694800785606, 56.715452671051025, 53.11672701154436, 53.601964882441926, 55.384462697165354, 54.3229273387364, 54.27919537680489, 55.55352973937988, 54.46495546613421, 54.82347903932844, 49.84295817783901, 50.51224340711321, 51.00026750564575, 52.95539678846087, 52.98027828761509, 53.65568835394723, 41.362883295331685, 52.559342520577566, 51.234647614615305, 53.96569613048008, 53.133743149893625, 50.31374726976667, 48.82868446622576, 44.46673393249512, 43.968033926827566, 47.19117818559919, 49.02270596367972, 51.07558945247105, 51.105984347207205, 51.43057986668178, 51.5276392527989, 49.37039382117135, 50.169787543160574, 48.2933292388916, 50.55553763253348, 47.66069575718471, 47.51875448226929, 47.90538699286324, 47.377594879695344, 39.72347320829119, 30.256497042519705, 20.50813099316188, 13.26490146773202, 8.930004613740103, 4.798282640320914, 2.245266297033855, 2.0739467356886183, 1.3721584847995212, 2.630485934870584, 4.993882247379847, 2.493098335606711, 4.40521913766861, 4.781183992113386, 3.244693228176662, 1.6878316487584795, 1.4889271961791175, 0.5953739296112741, 0.0971049904557211, 0.414577378226178, 3.9386467337608337, 17.31762589727129, 26.617626428604126, 28.175546305520193, 25.858728545052664, 26.88094057355608, 26.534805638449534, 11.373055509158544, 2.0054086191313605, 0.03977228940597602, 0.02110134663858584, 0.046374692980732234, 0.01103567742809121, 0.021582880888932517, 0.011912819646698023, 0.03572571011526244, 0.020999808962057744, 0.023792959350560392, 0.05892655945249966, 0.01953964401036501, 0.04589547762381179, 0.006983071050074483, 0.020252097298258116, 0.021263494455654706, 0.02723419719508716, 0.022062969859689474, 0.07227776053228549, 0.023344573232212236, 0.008790965690942747, 0.025946726190990636, 0.09201567247509956, 0.03359929332509637, 0.020779407217300365, 0.05792806124580758, 0.036446090388510904, 0.05095003764810307, 0.017311711596058946, 0.043084653094410896, 0.0168968807307205, 0.013860987831971474, 0.032853247464767525, 0.006930101637928081, 0.0976252028984683, 0.1536409556865692, 0.22612858031477245, 0.06604315686438765, 0.1071510338889701, 0.12928475120237895, 0.09299631164010082, 0.09169362618454865, 0.1888122484087944, 0.13790601358882018, 0.1378664414265326, 0.2502292756523405, 0.22846350073814392, 0.1628078552229064, 0.09036357541169439, 0.19625843742064067, 0.14482430235615798, 0.18853252913270677, 0.13739194188799175, 0.14494734789643968, 0.07650628898824964, 0.22124382028622286, 0.17865423991211823, 0.10881375681076731, 0.11240878461727075, 0.09077472013554402, 0.09949688746460847, 0.1795084069349936, 0.29053680705172674, 0.19157721075628484, 0.1481120487941163, 0.156492091981428, 0.19266585234020436, 0.10600327154887573, 0.1349849339042391, 0.10787239803799561, 0.16930083824055536, 0.08820060933274881, 0.13800183630415372, 0.22662118316761085, 0.4385942609182426, 6.807121063981738, 29.006314618246897, 46.924878052302766, 42.15657254627773, 23.9492141859872, 27.370798996516637, 28.585860013961792, 40.352469308035715, 20.575089045933314, 11.357933623450142, 2.5906082689762115, 0.693825072475842, 1.13444584608078, 3.095646551677159, 9.254541073526655, 10.693526029586792, 10.930236390658788, 8.5706524678639, 5.1775973950113565, 1.970177561044693, 0.645256512931415, 0.7376502379775047, 2.244161533457892, 9.917337553841726, 21.988413436072214, 29.81306995664324, 40.25813708986555, 48.10355656487601, 55.39807421820504, 50.60581827163696, 54.73920086451939, 55.8611855506897, 47.31959131785801, 56.49394757407052, 56.22591733932495, 58.989636284964426, 55.283446311950684, 56.32069771630423, 58.271727561950684, 56.358825956072124, 56.897092478615896, 57.23967341014317, 55.87815999984741, 56.74739701407296, 52.64521183286394, 53.64043705804007, 52.983193056924, 54.93182577405657, 57.15454060690743, 55.245338916778564, 42.94428982053484, 53.87844065257481, 50.841973645346506, 54.37514999934605, 55.30644484928676, 51.68403625488281, 52.48765448161534, 47.3013870375497, 46.25110081263951, 49.92405407769339, 52.12328052520752, 53.961770398276194, 53.34782062258039, 52.26423168182373, 50.583524976457866, 51.0688601221357, 49.747743538447786, 49.65062509264265, 50.7827159336635, 49.6380558013916, 49.48219381059919, 49.294946806771414, 46.740656988961355, 40.24489729745047, 28.7597108909062, 19.766085965292795, 12.108451979500906, 9.447099106652395, 4.095871874264308, 2.2667043123926436, 2.5699506231716702, 1.4767230110509055, 3.395294998373304, 8.598803094455175, 3.0338796717779974, 8.486722571509224, 9.673835328647069, 7.225736566952296, 9.19872966834477, 7.435159615107945, 4.790955330644335, 0.9870527322803224, 1.3023364714213779, 7.1589444024222235, 22.235119649342128, 31.788943086351665, 32.333407402038574, 31.890001160757883, 33.11912359510149, 30.200772489820206, 11.152182698249817, 1.8141468593052454, 0.11217715311795473, 0.06988852338067122, 0.11091182101517916, 0.09079490655234881, 0.14698661704148563, 0.08118750208190509, 0.11708344306264605, 0.0874324126967362, 0.10223192641777651, 0.1662671895963805, 0.18011805707854883, 0.1033432310713189, 0.13600519272897924, 0.06298489096973624, 0.07200963063431637, 0.09775663513158049, 0.11996113721813474, 0.22309457883238792, 0.08280178438872099, 0.10393787202026163, 0.1370952863778387, 0.17290205428642885, 0.14871207731110708, 0.19287144845085485, 0.11953223523284708, 0.10211660939135722, 0.16676699849111692, 0.12246826982923917, 0.14713660042200769, 0.1404632492257016, 0.08350951676922184, 0.10766836255788803, 0.09351098723709583], [0.061753343125539165, 0.07508391674075808, 0.035491259302943945, 0.042762654301311286, 0.03997877100482583, 0.08176580390759877, 0.0372660592464464, 0.041577175592205355, 0.054305875075182745, 0.017755110482020036, 0.03152822802907654, 0.07319993712008, 0.04984807642176747, 0.008187744666689208, 0.031068004867328063, 0.06328449810722045, 0.06919784937053919, 0.016819230879523923, 0.0235407597584916, 0.027999767900577614, 0.046366601450634856, 0.05173916708944099, 0.05402390306283321, 0.002274415031674185, 0.015199379496542471, 0.05632115461464439, 0.004549052283566977, 0.02535511150823108, 0.006386080249545297, 0.01203874811264021, 0.058062282257846425, 0.049320820785526714, 0.005125430462482784, 0.062214149827403684, 0.05098208824970892, 0.05091571734685983, 0.08594184089452028, 0.05740602354386023, 0.05134877196646162, 0.025107665053967918, 0.04255317018500396, 0.13927365520170756, 1.8617693781852722, 15.110395124980382, 33.56878668921334, 26.83837069783892, 28.380759613854543, 12.097651873316083, 14.34522649220058, 28.854510375431605, 11.520764657429286, 12.488346474511282, 2.026099268879209, 0.23357216375214712, 0.8906985883201871, 1.2239626369306018, 2.8769589492252896, 3.7608592680522372, 7.957905599049159, 2.0964556421552385, 3.654986960547311, 2.1187860667705536, 0.12985033728182316, 0.13450149127415248, 0.5184653507811683, 3.0582506954669952, 8.656218664986746, 15.07033007485526, 22.512187753404888, 32.04398366383144, 45.349099567958284, 36.996517181396484, 53.17742300033569, 61.97410992213658, 53.41044821058001, 52.344000475747244, 53.45644528525216, 53.92028965268816, 55.662967341286794, 54.34903172084263, 51.98826660428728, 51.82465042386736, 53.72944695608956, 52.589594977242605, 51.676775387355256, 52.720839500427246, 51.621575423649375, 51.85315193448748, 53.312860761369976, 55.5241562298366, 51.900535174778526, 38.642062527792795, 44.802887780325754, 53.374713625226704, 54.518282890319824, 50.57191801071167, 51.425709179469514, 47.71357502256121, 46.43795871734619, 45.31709963934762, 48.9823716708592, 50.23162303652082, 51.40192549569266, 52.229761668613975, 50.44534962517874, 47.99633543831961, 49.47306387765067, 48.98200341633388, 48.91826064246041, 47.79079730170113, 49.27509580339704, 47.669745785849436, 42.603334767477854, 31.077346801757812, 19.46549299785069, 11.257851770945958, 4.742707908153534, 2.1788575862135207, 0.7328389904328755, 0.6130374989339283, 0.3997919373214245, 1.499612114259175, 2.1440275694642748, 2.5953052512237003, 4.427011294024331, 2.361755234854562, 2.5590610589299883, 3.3013599131788527, 3.316313087940216, 0.4441285010959421, 0.6368757912090847, 0.16186178741710527, 0.7635341233440808, 5.482105238097055, 16.541121278490337, 27.71702946935381, 23.42924748148237, 21.09289833477565, 26.92056962421962, 20.305809872491018, 7.4474084206989835, 0.5803278769765581, 0.026852421163182174, 0.015142692984747035, 0.033609630806105475, 0.04775254993832537, 0.05740149771528585, 0.02617183866511498, 0.035501776595732996, 0.028111454764647142, 0.006029968956551913, 0.11209330654570035, 0.010811747301236858, 0.047333351003804376, 0.010839804724257971, 0.0693248100578785, 0.01452073930496616, 0.043893717894596715, 0.08555048903716461, 0.08491159403430563, 0.06853809620120696, 0.024548102669151764, 0.014946721893336092, 0.046391968482307026, 0.02721301163546741, 0.016592547596831406, 0.029896866995841265, 0.008542401350236364, 0.06036691287798541, 0.05450783084545817, 0.09698666751916919, 0.02376617587703679, 0.01343165328060942, 0.033878062652157884, 0.0023346579151361114, 0.055909317785075734, 0.012609181476623883, 0.05751446022519043, 0.06491542487804379, 0.015281867302422012, 0.01794267791722502, 0.07158012475286211, 0.029289038718811104, 0.029842024402959005, 0.04260934270652277, 0.035942169571561475, 0.029132605862936804, 0.010862871522216924, 0.03976370593799012, 0.02198433443637831, 0.040191688508327515, 0.04204694234899112, 0.04693125454442842, 0.006183934065380267, 0.034743401754115305, 0.05803933420351573, 0.01569429785013199, 0.048397008928337266, 0.07978653082890169, 0.017636446581621255, 0.03612633754632302, 0.10495201724448375, 0.026420608262664506, 0.021680064066978436, 0.03746681061706372, 0.011532135208004286, 0.022415339880223786, 0.06160606031439134, 0.031225014477968216, 0.02871673514268228, 0.0396877575133528, 0.05686737869733146, 0.03589046859581556, 0.005771089611308915, 0.0314825660149966, 0.010533947431083237, 0.06642182011689458, 0.21966358008129255, 4.303303394998823, 24.083934545516968, 38.09411021641323, 24.680762222834996, 22.134773765291484, 14.226205587387085, 22.523221492767334, 29.49428313119071, 17.251048258372716, 14.51111820765904, 1.51214134480272, 0.167153926300151, 0.4600829492722239, 0.8816473111510277, 1.9453566414969308, 2.3938663346426825, 4.089575069291251, 3.6175144570214406, 7.787452391215733, 4.09075756583895, 1.15661743921893, 0.5727043460522379, 1.4473715403250285, 4.971692306654794, 10.211331469672066, 18.295400721686228, 27.894955464771815, 37.5594220161438, 47.186943258558, 41.562796865190776, 57.732304164341514, 58.7851369040353, 51.758632114955354, 53.35967772347586, 53.2850957598005, 56.57115943091256, 56.42880821228027, 57.08732720783779, 54.756408078329905, 54.75911092758179, 55.66077518463135, 52.912519454956055, 54.973480224609375, 54.39401435852051, 52.20646435873849, 52.54157597678048, 55.94657891137259, 57.92383125850132, 54.106167861393516, 40.44156605856759, 46.248672417231965, 51.17251334871565, 55.62892116819109, 52.057102407727925, 51.899155957358225, 49.87224136080061, 48.07401629856655, 47.248445238385884, 49.294974599565776, 51.379986558641704, 52.45986516135079, 51.74080303737095, 51.19781173978533, 48.23461696079799, 49.30976731436593, 49.50265278135027, 49.684629576546804, 48.45405844279698, 50.692503997257774, 50.03859860556466, 43.95222677503313, 33.861128670828684, 24.080729688916886, 13.841430851391383, 7.745446188109262, 3.6271301124777113, 1.9087146648338862, 1.6505184109721864, 1.55026513338089, 2.6191914209297726, 2.9744313188961575, 3.36193430849484, 4.514663253511701, 4.049433154719217, 3.57074721796172, 4.382595368794032, 3.0454564562865665, 0.8047520858900887, 0.4029706838939871, 0.13808320622359002, 0.501784083034311, 5.657171181270054, 18.636864730290004, 30.163405077798025, 28.083505255835398, 25.888103791645594, 28.943730456488474, 25.207583325249807, 11.07530869756426, 1.533210671373776, 0.012314112042076886, 0.06490245128848723, 0.0402572112424033, 0.014907146338373423, 0.0667111338781459, 0.036899806399430544, 0.031696165446192026, 0.017884457916287438, 0.023273752835978354, 0.07652491477451154, 0.02579376064906163, 0.02629153902775475, 0.05378888228109904, 0.03752975491806865, 0.035481997299939394, 0.041048569671277485, 0.05734029385660376, 0.008732163846226675, 0.030668765040380613, 0.07074227649718523, 0.01365826277261866, 0.01933011070026883, 0.025711031963250468, 0.06081763654947281, 0.03679320854800088, 0.029121233616024256, 0.09088419497545276, 0.08105503169021436, 0.03491094222824488, 0.023658193814169084, 0.05906884824591024, 0.05359721988705652, 0.0059223401559782875, 0.03762436984106898, 0.11368934983121497, 0.13236672511058195, 0.14321911920394215, 0.12861524069947855, 0.09019379916467837, 0.2429196893104485, 0.15347751017127717, 0.116935169590371, 0.13892112911811896, 0.18204064534178802, 0.07098471027399812, 0.13849400489458016, 0.103497401012906, 0.08955080581030675, 0.17568121158650943, 0.1356783424104963, 0.10623485555074044, 0.08713800992284503, 0.1960729259465422, 0.12132625468075275, 0.1529089521084513, 0.14344056589262827, 0.1756457242050341, 0.1387301893638713, 0.18409594148397446, 0.13044017420283385, 0.08438777178525925, 0.12105478639049189, 0.11196131112852267, 0.11944763548672199, 0.12118506511407239, 0.13903509585985116, 0.12454449199140072, 0.15162478387355804, 0.12401382332401616, 0.15895970671304635, 0.19712295888790063, 0.1628686926726784, 0.11406720562704972, 0.1580412552825042, 0.17390923095600946, 0.27757619108472553, 4.8618451952934265, 26.156457117625646, 45.504124300820486, 35.207210132053916, 36.991458892822266, 19.244198083877563, 23.091809953962052, 37.541238580431255, 17.434077705655778, 16.708362681525095, 3.34605159504073, 0.49104629350560053, 1.958300266947065, 3.7102976611682346, 7.597657135554722, 10.106436252593994, 13.94022728715624, 9.32905181816646, 8.595382843698774, 4.473169045788901, 1.1112042303596223, 0.3540709449776581, 1.2588141496692384, 3.7478313956941878, 9.901988114629473, 16.953710521970475, 26.79353744643075, 34.37141479764666, 50.61228357042585, 43.75385570526123, 55.74723161969866, 58.64747224535261, 52.88061332702637, 54.52087804249355, 55.57990162713187, 56.50767721448626, 58.96143354688372, 58.59747300829206, 54.954091276441304, 55.60100678035191, 57.34474406923567, 55.47713082177298, 55.7886255128043, 57.07391023635864, 54.975710596357075, 57.2507974760873, 57.60492978777204, 58.80573831285749, 54.85907118661063, 44.73047365461077, 46.6115768296378, 52.03174843106951, 56.428499017442974, 53.556780747004915, 56.04628208705357, 51.83702169145857, 50.84661851610456, 48.63396120071411, 52.186644622257774, 53.32376595905849, 55.54804066249302, 53.58512592315674, 51.41875403267996, 48.136970451899934, 51.15368720463344, 52.1131465775626, 49.18310860225132, 49.55857188361031, 50.76391410827637, 48.695431913648335, 45.116876874651226, 32.56836421149117, 23.02530700819833, 13.172598123550415, 6.305600523948669, 2.833931578057153, 1.194170932684626, 1.1053644865751266, 1.4744840626205717, 3.2618472448417117, 3.5777918228081296, 5.714913317135402, 10.23994675704411, 10.231224162237984, 6.611633062362671, 9.788160119737897, 10.347090584891182, 3.8229900598526, 1.7325252848012107, 0.9423673472234181, 1.4142935552767344, 7.329185690198626, 20.941820178713115, 34.686678886413574, 32.190253666469026, 30.74422584261213, 35.13094670431954, 29.904334545135498, 11.693888579096113, 1.2348516583442688, 0.1218067253274577, 0.1216732846306903, 0.1253747067281178, 0.13587000141186373, 0.12469077057072095, 0.11793421741042819, 0.18594059321497167, 0.1033175213794623, 0.16434133079435143, 0.16428394030247415, 0.15777882507869176, 0.1325555478355714, 0.08121296750115496, 0.09655625240078994, 0.13306429982185364, 0.11538751263703619, 0.22211485568966183, 0.22429162317088672, 0.18880618230572768, 0.1433958232934986, 0.12005742133728095, 0.09180255141109228, 0.13280508587402956, 0.20597026843045438, 0.1272001966301884, 0.14266372472047806, 0.19587092607149056, 0.10982247375484024, 0.16312048344739846, 0.1160989837454898, 0.1314196259315525, 0.14003550074994564, 0.11105634218880109, 0.11612263747623988], [0.06365503251020398, 0.018449923555765833, 0.13997946732810565, 0.041850323256637366, 0.04354628421632307, 0.06065115798264742, 0.060871335810848644, 0.010772795998491347, 0.04881427064538002, 0.043117857205548456, 0.05040033946612051, 0.08781428541988134, 0.007308683042148394, 0.038447191938757896, 0.06553198929343905, 0.029729017788278203, 0.07305682051394667, 0.03919683742736067, 0.04420137585007718, 0.028547952949468578, 0.08728514345628874, 0.04726764845794865, 0.09203328724418368, 0.0440931291585522, 0.023274295663993274, 0.017879285783107792, 0.021390545048883984, 0.01759002630465797, 0.0387177849188447, 0.04413114408297198, 0.030266532874000922, 0.04899073385500482, 0.019698612890871506, 0.021600281919485757, 0.005506691231857985, 0.03570014630843486, 0.08104285877197981, 0.03310930283207979, 0.05874629983944552, 0.042386165753539116, 0.05525605480319687, 0.05978804786822625, 0.17066058170582565, 2.3004019899027686, 16.132865973881312, 32.618714332580566, 31.23698513848441, 20.940605981009348, 11.369821991239276, 13.823388985225133, 26.80723581995283, 11.811742186546326, 10.231042640549795, 3.083340423447745, 0.5805318717445646, 0.3701063559523651, 1.1990739724465778, 1.6768689113003867, 5.046610389436994, 2.67318109529359, 3.9675186702183316, 4.071353418486459, 1.7044770355735506, 0.501563586294651, 0.4956380756837981, 0.13798940554261208, 0.4554289590035166, 1.8088761078459876, 6.645360921110425, 15.720943757465907, 25.72118721689497, 30.835014479500906, 31.415560790470668, 46.92506912776402, 58.23327623094831, 55.192588193076, 52.02896915163313, 50.47134631020682, 51.32989699499947, 51.62125928061349, 54.80285331181118, 52.18798909868513, 55.96679469517299, 57.31373773302351, 54.63910164151873, 53.31596660614014, 56.14089918136597, 53.92541742324829, 57.800650119781494, 36.972000462668284, 40.93263694218227, 44.59538677760533, 43.52031980242048, 53.29865516935076, 51.27426971708025, 55.780148710523335, 47.03351313727242, 52.529284613473074, 48.149723870413645, 51.16183049338204, 50.219679083142964, 52.35487788064139, 51.810590744018555, 52.98618425641741, 50.049048696245464, 53.00631666183472, 50.15336200169155, 48.66966799327305, 47.90590810775757, 49.74923045294625, 42.35512774331229, 35.98509223120553, 23.20880545888628, 13.893894961902074, 5.32534475837435, 1.8586659218583788, 1.1655210128852298, 0.43222154144729885, 0.23900579075728143, 1.7255065185683114, 1.3510565885475703, 1.8439737388065882, 2.6676383869988576, 2.046874165534973, 2.88590475491115, 1.4193301307303565, 3.7507583243506293, 2.3582027511937276, 1.0449040851422717, 0.5688080351267542, 0.5872402489185333, 1.5182315494332994, 6.3163133433886935, 13.453455601419721, 19.786878449576243, 19.18149753979274, 22.72553219114031, 25.962315763745988, 23.94960502215794, 8.539327383041382, 0.7679015547037125, 0.05446810940546649, 0.06728139506386858, 0.032265490253588984, 0.04316255569990192, 0.052272152953914235, 0.024548699779968177, 0.02475222635881177, 0.0718045909223812, 0.009731766368661608, 0.01580886000634304, 0.02957752806001476, 0.03201254936201232, 0.04719247695590768, 0.006718084465579263, 0.06165365954594953, 0.0646812692284584, 0.03492620587348938, 0.07082138010965926, 0.08485660555639438, 0.027673119446262717, 0.03629557775067432, 0.0028592019558085924, 0.035787623043039014, 0.0009997586915103185, 0.030459742327885966, 0.04545860963740519, 0.022357978226084794, 0.06436575044478689, 0.06545436488730566, 0.027811102934979966, 0.03261228950162019, 0.015089889389595814, 0.06190477178565093, 0.017732410092971156, 0.03369191674781697, 0.06880524900874921, 0.011756005963044507, 0.03412608755752444, 0.005785226888422455, 0.08988254158092396, 0.02131165687127837, 0.05040697893127799, 0.017398145083071928, 0.037819170459572754, 0.009659897635823913, 0.03059998873089041, 0.04554500750132969, 0.026147282482790093, 0.019024486653506756, 0.05836952291429043, 0.058827703685632775, 0.034963589760341814, 0.03800511958875826, 0.026856938510068824, 0.04666383371555379, 0.0384768608824483, 0.04529958138508456, 0.05851063784211874, 0.024555111935894405, 0.012208191877497094, 0.0191772825616811, 0.07485869739736829, 0.018258698816810335, 0.06439334646399532, 0.01810628967359662, 0.03809255900393639, 0.0058429842132941955, 0.0327114845359964, 0.055077094584703445, 0.02559792696099196, 0.02663353594419147, 0.0341334360917764, 0.05122326334406223, 0.06462229096463748, 0.05304488220385142, 0.08822283135460955, 0.07115085635866437, 0.2473835540669305, 3.9793879304613387, 23.895238842282975, 36.74900497709002, 34.39583771569388, 17.421857561383927, 12.969725489616394, 21.409717082977295, 23.980635677065166, 20.91034483909607, 14.789091314588275, 2.90766955273492, 0.5501183037246976, 0.1460051704198122, 0.5672810056379863, 1.1740659943648746, 3.96186283656529, 6.987505853176117, 13.253310135432653, 8.438026990209307, 2.888497084379196, 1.0347669890948703, 1.500593004482133, 0.4073401508586747, 1.2965510104383742, 3.252749013049262, 7.780304431915283, 17.886191776820592, 30.029235363006592, 35.40820067269461, 36.150188377925325, 54.20572859900338, 56.44803735188076, 54.68564067568098, 52.48260314123971, 52.34262473242623, 53.07721260615757, 53.4063001360212, 56.0506386075701, 52.872713225228445, 56.16445357458932, 59.085917472839355, 55.4329263823373, 53.93095513752529, 57.38374778202602, 56.043818950653076, 58.59916142054966, 39.77804088592529, 44.09043339320591, 45.08798973900931, 43.468750272478374, 51.86633961541312, 52.99453946522304, 57.090092590876985, 50.41546194893973, 52.96506173270089, 48.888484137398855, 51.23593650545393, 50.75790044239589, 53.26511968885149, 53.377715247017996, 54.64554956981114, 49.56190354483468, 52.05337469918387, 51.48156574794224, 50.677593163081575, 48.10252128328596, 51.22714008603777, 46.13048703329903, 38.88298436573574, 28.66175866127014, 17.897218567984446, 7.448834538459778, 3.3559812222208296, 2.4706975604806627, 1.1090141364506312, 1.0760319062641688, 2.9729398446423665, 2.6623082501547675, 3.338082879781723, 5.208704914365496, 5.1025998422077725, 3.00957595876285, 4.150454751082829, 3.725765654018947, 1.3269022618021284, 0.9091509410313198, 0.49509019936834064, 0.13175883915807518, 0.9793038623673576, 6.719768311296191, 16.433580534798757, 23.953039169311523, 23.622079099927628, 24.46548965999058, 27.200370107378276, 28.529303414481028, 12.792355350085668, 1.5299608686140604, 0.04397544404491782, 0.01627085923350283, 0.0369477720398988, 0.014598053281328507, 0.008167478522019727, 0.0771583475704704, 0.058176975032048564, 0.05695383423673255, 0.020282154703246694, 0.03285458078607917, 0.021792034219418253, 0.015732643560373356, 0.03470521380326577, 0.06174749415367842, 0.01921779110229441, 0.04239308002537914, 0.04861245058210833, 0.026381109042891433, 0.06609575689903327, 0.02700208223957036, 0.03101343708112836, 0.024500050515468632, 0.09417764110756771, 0.019749486053894674, 0.006693478241296751, 0.10147368389048747, 0.03906814647572381, 0.03699947640831981, 0.028902256794806038, 0.03449060335489256, 0.05353406863287091, 0.022588629242298857, 0.009971740456031901, 0.07314275697405849, 0.0331257098088307, 0.20279575591640814, 0.1004531332956893, 0.19804516940244607, 0.07449345556753022, 0.14686661133808748, 0.1725361474922725, 0.21802338452211448, 0.09358251839876175, 0.117480372477855, 0.1270997463060277, 0.13294457910316332, 0.20462337641843728, 0.16429660176592215, 0.19819342930402073, 0.11807193287781306, 0.15658726330314363, 0.13894379218774183, 0.18348980615181582, 0.12883735235248292, 0.20662403692092213, 0.23469440639019012, 0.061036090898726664, 0.21530484754059995, 0.10298502564962421, 0.12964590825140476, 0.062179225629993846, 0.17015619948506355, 0.12062071396836213, 0.22592411057225295, 0.12695227350507463, 0.10518385230430535, 0.27622612352882114, 0.20816063375345298, 0.1272448849465166, 0.13452163019350596, 0.17158269722546848, 0.21524700921561035, 0.17073474558336393, 0.1402883500392948, 0.2195120903530291, 0.15252507770700113, 0.13076688881431306, 0.24455715715885162, 3.9586041314261298, 25.639658791678293, 46.25884805406843, 43.12708650316511, 27.940532173429215, 20.528065374919347, 22.436440229415894, 34.24573925563267, 19.307692459651403, 14.271561690739222, 4.228536869798388, 1.0870361157826014, 0.8887403905391693, 3.3513261462960924, 7.081650469984327, 11.95745199067252, 6.879498711654118, 11.114730170794896, 9.14759874343872, 3.7945050512041365, 2.0610930025577545, 1.0945769740002496, 0.5121686543737138, 0.9015283329146249, 2.400263671364103, 7.812425085476466, 18.015153816768102, 27.97483195577349, 37.01942886625017, 37.87589856556484, 51.75328547613961, 55.98533943721226, 55.45332976749965, 52.971370697021484, 52.462484632219585, 52.75752598898751, 53.97081000464303, 55.04128074645996, 54.14097138813564, 58.67501490456717, 60.321480887276785, 57.41520575114659, 57.382636070251465, 58.7619229725429, 59.258517674037385, 60.35545063018799, 41.0882522719247, 44.40188986914498, 50.20441736493792, 44.67853587014334, 53.251727036067415, 52.81054769243513, 59.80752958570208, 51.50736788340977, 56.63378701891218, 52.259552070072715, 55.20956611633301, 54.10110609872, 55.60920565468924, 54.89805405480521, 54.268272808619905, 49.35833869661604, 53.10079479217529, 50.45419815608433, 52.45980610166277, 49.28649432318551, 51.08445187977382, 44.332609380994526, 39.59768649509975, 26.014274392809185, 16.482556649616786, 6.794870521341052, 2.4961618397917067, 2.026289692946843, 0.7224042617848941, 1.2646402141877582, 4.117171577044895, 2.5341513327189853, 4.1641848257609775, 6.428247954164233, 6.503572506564004, 7.291026183537074, 6.839745461940765, 9.313406211989266, 8.401662724358694, 4.758638824735369, 1.6479340067931583, 1.2067243733576365, 1.9352335504123142, 8.296925578798566, 17.51582326207842, 27.04687397820609, 26.745250940322876, 30.839711461748394, 34.31554433277675, 32.18861389160156, 13.188044837542943, 1.2918224356004169, 0.1199634170957974, 0.16358731554022857, 0.15507012685494764, 0.1219795753381082, 0.1207608450204134, 0.1635795666703156, 0.12071645525949341, 0.13061101574982914, 0.09259498531797103, 0.11630164858485971, 0.1286507145102535, 0.12159627090607371, 0.1849884864475046, 0.18001246345894678, 0.1926602612116507, 0.2009907713426011, 0.0991701524970787, 0.15954609667616232, 0.2717972168964999, 0.10345174917685133, 0.14732056483626366, 0.16709116181092604, 0.165907281051789, 0.09709365213555948, 0.14930526619510992, 0.21103433812303202, 0.13548622200531618, 0.08318559772201947, 0.1224848667957953, 0.13243318083030836, 0.1620018777570554, 0.1401836792273181, 0.10029191337525845, 0.1526132465473243, 0.12352982429521424], [0.057518592503454, 0.011440009660353618, 0.03819122138832297, 0.01584446782778416, 0.025263337950621332, 0.04077755939215422, 0.05223801924980112, 0.07550810969301633, 0.04624366447595613, 0.055932533860738785, 0.04929304834721344, 0.03167095447757414, 0.03460858702393515, 0.09357214359832661, 0.015392319232757603, 0.036294790650052686, 0.04368384022797857, 0.09545666604701962, 0.04038008714893034, 0.057820337026246955, 0.02253867719056351, 0.03595598115186606, 0.04039237881079316, 0.05998182389885187, 0.056141549787883244, 0.0466432503557631, 0.007375374552793801, 0.019605405928034867, 0.09183153842708894, 0.03901420972709145, 0.0208030846967761, 0.10035239798682076, 0.04121645280559148, 0.05439030518755317, 0.01487341636259641, 0.03831609218780484, 0.021472142277551547, 0.021538864322272793, 0.024745958391577005, 0.019703343976289034, 0.03825991288093584, 0.08291830920747348, 0.02728624761636768, 0.01212380756624043, 1.6250994035175867, 12.806230902671814, 31.097927365984233, 31.469263417380198, 20.974424600601196, 11.88124328000205, 15.744670118604388, 20.56230957167489, 12.92750997202737, 12.236073885645185, 4.294897377490997, 1.406842155115945, 0.18694676565272467, 0.20449843098010334, 0.9032668481980051, 8.40539824962616, 23.26764801570347, 8.165258084024702, 3.16685950756073, 2.4228924342564175, 1.2755000314542224, 0.23582091022815022, 0.13412725206996712, 0.4969373888203076, 0.13044719025492668, 2.2073072024754117, 5.996596762112208, 14.494290539196559, 21.19794988632202, 27.08888452393668, 39.34921196528843, 48.44522033418928, 49.41100256783621, 48.494205134255544, 49.918363503047395, 51.168017864227295, 49.99135085514614, 52.688561643872944, 55.16089398520333, 54.28043910435268, 53.58800942557198, 54.508138520377024, 55.22994865689959, 55.78737483705793, 55.5497464452471, 53.54792526790074, 53.11641434260777, 43.732781818934846, 48.94434765407017, 56.21336541857038, 51.88896642412458, 55.45095000948225, 51.25478349413191, 52.42784091404506, 50.86883538109915, 54.28578574316842, 51.84700277873448, 54.085295472826274, 52.815498283931184, 53.46707950319563, 52.32201984950474, 54.7616400718689, 46.264392716544016, 48.098133495875764, 45.60236835479736, 37.40490450177874, 24.408184392111643, 13.697473730359759, 7.10453827040536, 2.4188142759459357, 0.4617358605776514, 0.19973561726510525, 0.817452035844326, 1.0850201611007964, 1.5017231724091937, 2.6227009126118253, 3.718536053385053, 3.6279189501489912, 4.9994412405150275, 4.507119681153979, 2.112043925694057, 2.62258648446628, 1.5944772809743881, 1.1524775070803506, 0.39111580859337536, 0.3506491200200149, 1.6195553924356187, 7.61096727848053, 18.68424449648176, 25.152669974735804, 21.393677166530065, 19.23381573813302, 25.2852555002485, 23.42281171253749, 9.347110186304365, 0.925187274813652, 0.018039681283490996, 0.0678808603967939, 0.05288571145917688, 0.009227502891527755, 0.035470027942210436, 0.028746390515672307, 0.04302722867578268, 0.0196961057039776, 0.05229808656232698, 0.05006050198738064, 0.03017153457871505, 0.025522765636976277, 0.07320904984538044, 0.05072152062452265, 0.03210946451872587, 0.005464295091639672, 0.014540080945672733, 0.009470537171832152, 0.03219822368451527, 0.020017821208706925, 0.0170290661377034, 0.04448435548692942, 0.043177086527326276, 0.016313891924385513, 0.010296108184515365, 0.04334570247946041, 0.02842132474428841, 0.01955857004837266, 0.04686435438426478, 0.04015702215422477, 0.03181919063042317, 0.033863640390336514, 0.09336261198456798, 0.04456772029932056, 0.01777294068597257, 0.027544611699080894, 0.047535038752747436, 0.019611516135877798, 0.05554986385894673, 0.015605499668579017, 0.029372413709227527, 0.007553523921939943, 0.020238529990560243, 0.07993983224566494, 0.0147887029618557, 0.04105899875451412, 0.02416705266971673, 0.020429230561213832, 0.05253723283697452, 0.013047616030754787, 0.0647805253309863, 0.017376509994002323, 0.04085245269483753, 0.05492514345262732, 0.06490899915141718, 0.017660368333703706, 0.02255752350070647, 0.012620800540649464, 0.015822883628840958, 0.0954609951004386, 0.08166474968727146, 0.012440061712238406, 0.052158895281276534, 0.03418981895915099, 0.029604693209486346, 0.0298871096622731, 0.031533147407961745, 0.037612566724419594, 0.02106480922416917, 0.03857953001611999, 0.06759484431573323, 0.04600701181750212, 0.01856462311531816, 0.07512905289019857, 0.02067101464074637, 0.04299753937604172, 0.06028746321265187, 0.03300364475165095, 0.007843181191544448, 0.103411057431783, 3.0584419880594527, 18.2745543888637, 36.50797544206892, 34.87976585115705, 20.733888387680054, 13.121931859425136, 18.82712377820696, 18.750750916344778, 21.24394174984523, 16.365208523614065, 4.988638094493321, 0.8986727861421449, 0.06921679406825985, 0.20688322372734547, 1.4796019537108285, 7.98989336831229, 14.186479261943273, 9.491905433791024, 3.512686333486012, 5.82245796918869, 3.7074597563062395, 1.272523162620408, 1.093157478741237, 1.860394503389086, 0.6712953214134488, 3.3982492855616977, 8.505071026938301, 18.551518269947596, 23.275362253189087, 30.819245542798722, 44.13824047361101, 49.92184802464077, 50.14321068355015, 50.34811653409685, 51.18152516228812, 52.228306021009175, 51.68438366481236, 54.121888160705566, 56.25035762786865, 55.21341889245169, 55.45886748177664, 56.30272272654942, 57.696420192718506, 56.46576568058559, 56.71213490622384, 55.56663751602173, 54.65881020682198, 43.29247447422573, 49.734409945351736, 56.05043363571167, 52.96665981837681, 55.8887733731951, 52.86617497035435, 52.89379753385271, 52.854706968579976, 56.53260735103062, 53.07087932314192, 54.50919812066214, 52.972673484257285, 53.68504796709333, 52.22179208483015, 52.378387110573904, 48.30529056276594, 50.03231395993914, 47.68372903551374, 41.01295811789376, 28.93414889063154, 18.092063426971436, 10.320408633777074, 3.7174642937523976, 1.4673318692616053, 0.4828983907188688, 1.909672430583409, 2.307733642203467, 2.9124353655747006, 4.63092919758388, 4.642688155174255, 4.517379130635943, 5.11775038923536, 5.659363337925502, 3.749058621270316, 2.491429248026439, 1.9301144651004245, 0.44016164966991966, 0.3852569844041552, 0.2540564031473228, 1.4982724147183555, 7.849381685256958, 19.713637488228933, 23.631375789642334, 19.27376788003104, 20.520547424043926, 26.809228215898784, 29.54853466578892, 14.108563899993896, 1.915289397750582, 0.023899572469027977, 0.007638310265195156, 0.038845227366047244, 0.06655412766018085, 0.045500397216528654, 0.016546229100120918, 0.055474329340670786, 0.0171310295949557, 0.03138876872669373, 0.0456410914526454, 0.08804330455937556, 0.0524978845912431, 0.04204466925667865, 0.06240436354918139, 0.03262351247082863, 0.006953144263076995, 0.06600375433585473, 0.051127396523952484, 0.02643332740158907, 0.07209147552826575, 0.0675878282636404, 0.03001123746590955, 0.11543548506285463, 0.06717900412955455, 0.017082585587299297, 0.0431081948668829, 0.02631795609236828, 0.044758585414716175, 0.01615487045741507, 0.0478175468077617, 0.02781889251699405, 0.055382940851684125, 0.051924505537109714, 0.03330264460029347, 0.019218617218679616, 0.03387349271880729, 0.14605265430041722, 0.09631985080029283, 0.0976416098752192, 0.11502301719571863, 0.07878888079098292, 0.16589472815394402, 0.11563604644366673, 0.1983439555125577, 0.2189754777188812, 0.09696276273046221, 0.15382688785237925, 0.1091504255309701, 0.13368940699313367, 0.293001870491675, 0.14158707963568823, 0.09819332669888224, 0.10884298809937068, 0.26571035065821236, 0.16327907065195696, 0.1143097954669169, 0.12840569551501954, 0.11526540347508021, 0.12571827614946024, 0.29519082446183476, 0.22744164057075977, 0.11367729226393358, 0.09650256671011448, 0.1512751347784485, 0.1472653185150453, 0.11347819651876177, 0.1152741972889219, 0.1538561869944845, 0.08847844906683479, 0.09233833623251744, 0.18892751793776238, 0.13487431912549905, 0.10209619905799627, 0.14811287660683903, 0.07299124688974448, 0.15939244920653955, 0.13987915271094867, 0.1115832110600812, 0.1404610507722412, 0.1536722904337304, 3.153993615082332, 19.74354600906372, 44.75199569974627, 43.09071615764073, 29.80812978744507, 19.64028361865452, 25.453202145440237, 28.63842487335205, 18.331956931522914, 16.920557192393712, 6.842503896781376, 2.216981917619705, 0.6141971967050007, 2.165176583187921, 4.576846156801496, 14.383317385401044, 37.906557491847444, 22.525340693337576, 6.363992316382272, 5.343927715505872, 1.4738313662154334, 0.7557270622679165, 0.6943590523941177, 1.1740744624819075, 0.5138803539531571, 2.6467377713748386, 6.87275505065918, 17.094571352005005, 24.440653324127197, 34.2999838420323, 45.22487619944981, 49.39036641802107, 50.878837312970845, 50.49872916085379, 51.93646778379168, 52.22099651609148, 52.10383946555001, 54.16394560677664, 58.7868253162929, 57.51029879706246, 57.36842005593436, 56.577888761247905, 58.55056571960449, 56.786334718976704, 56.849618911743164, 54.582991463797434, 52.75320420946394, 47.9705993107387, 51.87072740282331, 56.58882522583008, 53.763948236192974, 58.11449677603585, 54.62606334686279, 55.38098512377058, 55.78741652624947, 59.67202581678118, 56.986126695360454, 56.23101731709072, 55.58615500586373, 54.14783273424421, 54.14524105616978, 55.75793531962803, 48.98807266780308, 51.15187719890049, 46.34731599262783, 40.909426484789165, 27.15436782155718, 15.50114791733878, 8.618899021829877, 3.37072508249964, 0.9505958599703652, 0.6252816904868398, 1.835271337202617, 3.588614510638373, 4.268097307000842, 7.0852735212871005, 8.742761952536446, 10.103969642094203, 10.411884273801531, 11.942947626113892, 7.926296506609235, 8.091923321996417, 5.860465049743652, 5.427520624228886, 1.4794170664889472, 1.019379334790366, 2.5440896451473236, 10.379826154027667, 23.993885891778127, 30.65877342224121, 25.896106379372732, 26.666295085634502, 34.162836824144634, 33.455607482365195, 14.503815650939941, 1.5683552026748657, 0.06902501293058906, 0.09226509516260453, 0.1713055699531521, 0.15399456742618764, 0.13172367747340882, 0.05734130487378154, 0.10331521436039891, 0.09672972666365759, 0.14765570685267448, 0.16926045183624538, 0.12618231267801353, 0.1366075011236327, 0.1977630616830928, 0.1574845987239054, 0.12224717597876276, 0.14031929123614514, 0.10923374963126012, 0.12800921393292292, 0.15093801143978322, 0.16243566519447736, 0.10996057598718575, 0.257891021668911, 0.17326919601431914, 0.19280759830560001, 0.22851224669388362, 0.08044973774147884, 0.21256769155817373, 0.12510192207992077, 0.08465596953673021, 0.12407050813947405, 0.06789584245000567, 0.10670222368623529, 0.22108277678489685, 0.1642362800027643, 0.1411419470927545, 0.11933406229530062], [0.033843494685632844, 0.02273173227773181, 0.06635576473282916, 0.04429965825485332, 0.045812363869377544, 0.05911053065210581, 0.051519169073019705, 0.05719840539885419, 0.026078935346699188, 0.04292362316378525, 0.0288590001873672, 0.050610451227320094, 0.047937454123582156, 0.027542732157079235, 0.01652538450434804, 0.05003540976239102, 0.024648254437904273, 0.022367682973189012, 0.07270052177565438, 0.041509491724095175, 0.035464640374162366, 0.023387322634724633, 0.01231643178367189, 0.10234963867281165, 0.028632471271391426, 0.028137685232130543, 0.0306179665162095, 0.003913508395531348, 0.050249358639121056, 0.009364633970627827, 0.043498573026486805, 0.05084582484726395, 0.016155428552467908, 0.02112635743937322, 0.019275603982220803, 0.04087967551978571, 0.07446197832801513, 0.03559718879738024, 0.021634308754333427, 0.028685125588838543, 0.05852239006864173, 0.034305119022194824, 0.017592233239806125, 0.06878819063838039, 0.051109456058059416, 1.576369624052729, 11.293364013944354, 29.70438970838274, 35.24156897408621, 30.504283700670513, 14.051112719944545, 27.15635848045349, 23.698359898158483, 16.42676087788173, 18.879247426986694, 9.367344209126063, 2.8132585159369876, 0.4311923123896122, 1.7125822177955081, 9.296102591923304, 9.948544519288198, 6.401142597198486, 3.3178117275238037, 2.593116351536342, 5.90027345078332, 1.4337520939963204, 1.3464591609580177, 1.3656762497765678, 0.17981007003358432, 0.3211614266037941, 0.07577116414904594, 1.9212995895317622, 6.207446362291064, 13.286056995391846, 19.839832408087595, 25.982738256454468, 31.077975613730295, 36.4582576070513, 40.886368887765066, 48.504384245191304, 51.07618352345058, 52.317437512534006, 54.343205656324116, 56.75162499291556, 55.85175337110247, 56.641405718667166, 55.95566020693098, 56.318849495479036, 55.588399274008616, 57.08942208971296, 46.77880607332502, 42.507911682128906, 44.25683927536011, 50.673392977033345, 56.19261809757778, 56.41137865611485, 52.73757423673357, 55.925240993499756, 53.890210900987896, 54.43185077394758, 56.56732055119106, 55.205515316554475, 54.747566495622905, 53.54491669791085, 50.892667702266145, 50.972735268729075, 49.09605809620449, 42.9958176612854, 29.78501660483224, 16.624683788844518, 7.575864110674177, 2.2201268460069383, 1.0013135841914584, 0.29509599240762846, 0.5064551181026867, 0.24046572670340538, 1.3203162380627222, 2.286448052951268, 1.628958476441247, 4.5467283214841565, 3.5534952751227786, 2.4072075273309435, 3.922941199370793, 3.7805448174476624, 2.1457461629595076, 1.7436955996922083, 0.922722401363509, 0.09948223789355584, 0.43828482180833817, 3.539300105401448, 10.766119071415492, 19.908537932804652, 19.3329039982387, 15.616428954260689, 23.350503546851023, 20.659747634615215, 24.5580917767116, 9.96783879825047, 0.6653744791235242, 0.14109544030257634, 0.004490107522412602, 0.024401600173275386, 0.06060958414205483, 0.07221800873854331, 0.007737596053630114, 0.06017239724418946, 0.03523592657542654, 0.019956927779795866, 0.04446144814469984, 0.03900284765820418, 0.05460563149037106, 0.03585514406274472, 0.03829930183876838, 0.045492936723998616, 0.013079103448295167, 0.041264309880456755, 0.02209235042599695, 0.01900543169384556, 0.06350585658635412, 0.03525503412155168, 0.018547398503869772, 0.04789783785651837, 0.043619440469358645, 0.05707417242228985, 0.03183066126491342, 0.024480605398171713, 0.06682126689702272, 0.02973935187661222, 0.07385022472590208, 0.0549508056470326, 0.012923430551641753, 0.06192444930119174, 0.051062145203884156, 0.04945856678698744, 0.02896313156400408, 0.03685061939592872, 0.01584020153885441, 0.060271130874753, 0.01551152765750885, 0.030428149737417698, 0.05779116680579526, 0.0012530667341447302, 0.076132294056671, 0.08039318184767451, 0.03834655162479196, 0.030747889008905207, 0.060560471777405055, 0.0392485316177564, 0.035151055415294, 0.03706758436081665, 0.026050374111426727, 0.019561487748952847, 0.011665824418222266, 0.051197753820036135, 0.0121503917201023, 0.04607998486608267, 0.01728095530000116, 0.02815796834017549, 0.013526224098833544, 0.024045786587521434, 0.03374091036883848, 0.050713527482002974, 0.06199695755328451, 0.03425754353936229, 0.021650807333311865, 0.04747620976663061, 0.038486608037991185, 0.009518843776147281, 0.03928015474230051, 0.00558424523998318, 0.034412035785083256, 0.017460059707186053, 0.05962455485548292, 0.024610524498192326, 0.02923144127375313, 0.07194447091647557, 0.0553630733463381, 0.04517431703529187, 0.012709254365680473, 0.031729518835033686, 0.12346491563533034, 2.5947548236165727, 17.146712371281215, 34.8900283404759, 37.17098644801548, 27.456536293029785, 15.89775630405971, 21.488228252955846, 15.599416290010724, 20.636681352342876, 21.981869970049175, 9.335449372019086, 0.9232203917843955, 0.5744369445102555, 0.5056667146938187, 2.2199976529393877, 2.378729901143483, 5.06676059961319, 3.5887784446988786, 7.256255660738264, 14.273567983082362, 5.220128187111445, 4.185273477009364, 5.156424496855054, 1.5018651762178965, 0.7997594252228737, 0.9933430233172008, 2.8046021461486816, 9.151904889515468, 16.670340401785715, 22.478150265557424, 29.9376129422869, 35.57272011893136, 39.48147439956665, 44.503458636147634, 49.26842205865042, 52.59058509554182, 53.364593573978965, 54.490670749119346, 56.98646020889282, 58.2207555770874, 58.38838086809431, 58.546528816223145, 56.05456781387329, 56.98690141950335, 58.32020514351981, 50.13838168552944, 41.10418101719448, 45.5293983731951, 53.464428765433176, 56.74778611319405, 56.45331450871059, 54.9615466935294, 55.69399452209473, 54.969113281794954, 54.30966670172555, 56.487694195338655, 54.80522264753069, 55.052199840545654, 53.38815491540091, 52.08236953190395, 52.30531985419137, 51.8168580191476, 46.27564879826137, 33.39116988863264, 20.301868506840297, 11.361890622547694, 4.173478475638798, 2.6932839708668843, 1.171632496373994, 1.756042440022741, 1.889605164527893, 3.3756274708679745, 3.4624968894890378, 3.048346038375582, 4.780781430857522, 5.093496833528791, 4.228876897266932, 3.7287750925336565, 4.549456357955933, 2.093641838857106, 0.9448633790016174, 0.415137169616563, 0.37178364023566246, 0.36568648740649223, 2.6552056712763648, 10.710933004106794, 22.570910453796387, 25.859082903180802, 19.674015385763987, 24.51223714011056, 22.380378689084733, 27.659988233021327, 14.613578081130981, 1.668864260826792, 0.07865180314651557, 0.04506612801924348, 0.04598667612299323, 0.03189717126744134, 0.07711966428905725, 0.03580538708982723, 0.05074607341417244, 0.04036281843270574, 0.04340938638363566, 0.02251826346452747, 0.03171829925850034, 0.02806365366892091, 0.026752941144098128, 0.027139349873842936, 0.06733797131372349, 0.02566587206508432, 0.03574752840878708, 0.05529880250937172, 0.03894681762903929, 0.007258741168438324, 0.013933526618140084, 0.01270599739759096, 0.06082534470728465, 0.10590305871197156, 0.01379822164640895, 0.029461074487439225, 0.019762417235012566, 0.03899701904239399, 0.027759917645848224, 0.046563678554126194, 0.03454945269705994, 0.02509933434027646, 0.029949120977627378, 0.03334351276446666, 0.024263932203341807, 0.01705850098681237, 0.06893556844443083, 0.09447697004569428, 0.23593514838388988, 0.22936858502881868, 0.11125402658113412, 0.10466151604694979, 0.14454805717936584, 0.14912846711065086, 0.25360273463385447, 0.10410369919346911, 0.09743526059069804, 0.09941793991518871, 0.15730922456298554, 0.14867448647107395, 0.10146974838737931, 0.0819263860051121, 0.10285935417882033, 0.10659302026033401, 0.08851603312151772, 0.17654785008302756, 0.0814443886546152, 0.08363351904387985, 0.11878075769969396, 0.20039482760642255, 0.17933084789131368, 0.16373588756791183, 0.17646661587059498, 0.12857125805956976, 0.12581249752214976, 0.2675961080406393, 0.11506318646882262, 0.13573026391012327, 0.2908772144998823, 0.07802398862051112, 0.153649098106793, 0.07151471397706441, 0.08237634293202843, 0.19081280034567627, 0.24000475715313638, 0.12896988381232533, 0.13287882905985626, 0.1658298737768616, 0.13466116413474083, 0.05607911099546722, 0.3158505872956344, 0.17929826463971818, 2.6594423353672028, 17.567264250346593, 40.08318492344448, 46.23982736042568, 38.93056215558733, 24.05977044786726, 36.01121745790754, 32.875092438289094, 22.791804109300884, 25.96198398726327, 12.708489724567958, 3.924835886274065, 1.0220059709889548, 3.5944970292704443, 14.814905609403338, 17.43379804066249, 16.463325772966655, 9.665315100124904, 7.516228590692792, 14.236249208450317, 2.2716868221759796, 3.243437558412552, 3.427624532154628, 0.7456129821283477, 0.9476772908653531, 0.5276839275445256, 2.882029180015836, 7.375584023339408, 15.79947577204023, 22.893419776644024, 28.572053943361553, 34.2707701410566, 39.20305660792759, 43.49108178274972, 50.691673687526155, 53.819818701062886, 56.80875655582973, 57.12387473242623, 58.750652994428364, 58.514886719839915, 60.00974995749337, 59.231857436043875, 58.18574707848685, 55.2636057308742, 57.287841796875, 51.60339198793684, 45.74631418500628, 46.19841957092285, 52.445121083940776, 57.991715158735005, 56.6043370791844, 54.52021101542881, 57.21428121839251, 57.278336661202566, 56.66903175626482, 58.405355317252024, 55.97905479158674, 56.02884210859026, 54.927302496773855, 52.56539787564959, 54.27537734167916, 55.14879717145647, 46.164929253714426, 31.69498954500471, 17.751553058624268, 9.180046830858503, 2.968555965593883, 1.671884338770594, 0.8851952350565365, 1.8195772022008896, 2.133472170148577, 3.07614751798766, 5.46873733827046, 4.462344186646598, 8.816106268337794, 8.615927798407418, 7.8633189031056, 11.043068187577383, 7.822935972894941, 5.149701246193477, 6.282258919307163, 4.648110789912088, 0.5286923391478402, 1.0125231998307365, 4.520493226391928, 12.670175620487758, 25.023560285568237, 26.168998616082327, 23.11374889101301, 31.254657881600515, 28.249336174556188, 33.52820226124355, 16.60529136657715, 1.4327714209045683, 0.27308287790843416, 0.09274175922785487, 0.168592759807195, 0.10394881000476223, 0.14205005764961243, 0.12766310679061071, 0.09907223310853754, 0.1294732346598591, 0.152824162372521, 0.11895359413964407, 0.19481053868574755, 0.15050030206995352, 0.1740320593650852, 0.19368958526424, 0.19277288445404597, 0.19796008111110755, 0.15058320547853196, 0.1327514951782567, 0.20668468438088894, 0.1864316761493683, 0.15668365598789283, 0.1320291267974036, 0.1557886411568948, 0.2593433851642268, 0.22981831803917885, 0.08879060231681381, 0.11025507375597954, 0.1965363382228783, 0.09471986522631985, 0.16943292186728545, 0.10036697291902133, 0.08476743926959378, 0.2136603229280029, 0.11996318639389106, 0.08828153820442301, 0.1379098133849246, 0.1275763628738267], [0.0399930439889431, 0.03233975251870496, 0.06822196673601866, 0.007044665066392294, 0.03643636358901858, 0.09519543006483998, 0.01237094443890133, 0.014170531266635018, 0.033494971958654265, 0.03567660792863794, 0.0486863634016897, 0.06332089472562075, 0.04488253001389759, 0.06469977966376714, 0.013508049538359046, 0.021757564640470912, 0.06755571320120778, 0.06802114072654929, 0.07365204500300543, 0.04728436077545796, 0.02964078787980335, 0.025203835518498505, 0.0331771190145186, 0.08019988079156194, 0.06412754394114017, 0.019866740297792212, 0.040630605670490434, 0.021278300089761615, 0.04665818151884845, 0.03918233713401215, 0.039823389878230434, 0.06477989429341895, 0.0164584080089948, 0.018352811623896872, 0.023030228314122984, 0.025240574797083224, 0.04333986707830003, 0.03548313723877072, 0.09416767342814378, 0.09590105220143284, 0.03164850175380707, 0.08371724347983088, 0.025202466574098383, 0.08894414800618376, 0.002056114625052682, 0.024914971286697046, 0.5394807202475411, 8.241599678993225, 24.12013987132481, 35.18231821060181, 30.55619716644287, 21.458854743412562, 21.392263208116802, 12.121144601276942, 16.934933015278407, 20.84179217474801, 12.481320977210999, 3.3127579987049103, 0.7274267237101282, 0.922107377222606, 1.2172200615916933, 3.5473726093769073, 2.8567518506731306, 12.709364329065595, 22.230707543236868, 14.488050188337054, 5.104040290628161, 8.321103572845459, 2.610717875616891, 0.5263441737209047, 1.220133202416556, 0.01925370087181883, 0.50957312222038, 1.634850223149572, 3.198522448539734, 4.218523212841578, 7.364924618176051, 12.58076706954411, 20.823068516595022, 28.57953541619437, 43.49526112420218, 51.46214553288051, 54.75005047661917, 57.863041469029014, 56.09047610419137, 56.795620986393516, 56.8226876940046, 52.84020607812064, 55.16035549981253, 47.69495037623814, 40.85202741622925, 44.16440391540527, 40.90316615785871, 48.496056829180034, 52.90023503984724, 58.238146918160574, 58.0755729675293, 54.86487640653338, 54.6976888520377, 56.16836888449532, 53.13207905633109, 54.01226643153599, 50.83081136431013, 53.80035332271031, 49.76686150687081, 43.823653834206716, 29.298333508627756, 18.42807831083025, 7.9239228282655985, 2.8386960881096974, 0.8469738460012844, 0.3882554035101618, 1.018571281007358, 0.9577019129480634, 1.930293164082936, 0.8305501501475061, 5.033226856163569, 2.0034223028591702, 3.4862334557941983, 3.525391983134406, 3.0025348280157362, 3.1137257644108365, 1.6341333644730704, 3.3208376680101668, 1.2450665959290095, 0.5010047448532922, 0.3224685564637184, 1.1910660650048936, 5.716498809201377, 13.178188817841665, 17.784435408455984, 15.56593986919948, 13.23380480493818, 15.607245172773089, 27.628130742481776, 26.181289979389735, 13.23908543586731, 1.721882273043905, 0.03219440353236028, 0.037033457442053726, 0.04218639825869884, 0.01798537473327347, 0.010896108711936643, 0.03574543173557945, 0.026452426466026475, 0.07524780330381223, 0.010554308570655329, 0.011757996615155466, 0.03881572466343641, 0.0725191290091191, 0.06236954791737454, 0.05439529241994023, 0.037862688302993774, 0.035250318303172073, 0.06552895624190569, 0.058322765066155365, 0.027309548508908068, 0.02844284787507994, 0.03921083560479539, 0.059252174837248664, 0.048308036024016995, 0.039221139159053564, 0.02583865761490805, 0.029889867907123904, 0.06306453062487499, 0.024302471296063492, 0.04291063939620342, 0.0794318945014051, 0.05200398912919419, 0.014008200245111116, 0.052904113328882625, 0.03175710806889193, 0.02464983033548508, 0.008938681916333735, 0.05441489190395389, 0.0034101484301832636, 0.03989878190415246, 0.015997687820345163, 0.06090212772999491, 0.015042115435270327, 0.023336693744308183, 0.029945772407310348, 0.008338995211358582, 0.0928449033360396, 0.015273719793185592, 0.044576731244368215, 0.021372070236663734, 0.018632464742820178, 0.04110120702534914, 0.027610080150355185, 0.005852904395266835, 0.027951963412176286, 0.039788618351199796, 0.11909875992153372, 0.008043360896408558, 0.05901738815009594, 0.04105757722365005, 0.028690007648297718, 0.019707179395481944, 0.048178914202643294, 0.08509925646441323, 0.03881666443443724, 0.030867538481418575, 0.012004430355903293, 0.01575410392667566, 0.04816652076052768, 0.061383086921913285, 0.07852018770894834, 0.05204780552802341, 0.03962823302884187, 0.008749869369369532, 0.05095334889899407, 0.03081869413810117, 0.03480365905644638, 0.0282547800202987, 0.06764329171606473, 0.033580352020050795, 0.05844184796192816, 0.08946687781385013, 0.03884943428316286, 0.011982161684760025, 0.05233697679692081, 1.17036358160632, 13.319764443806239, 30.582371030535015, 39.44502067565918, 30.54974228995187, 24.40345961706979, 18.685522965022496, 13.90896647317069, 25.790907178606304, 28.839304242815288, 14.417052626609802, 3.115264790398734, 0.4510361775755882, 0.17671286979956286, 0.5890776131834302, 1.3877821607249123, 1.3503825047186442, 5.069448249680655, 11.98804577759334, 6.8162887777600965, 5.7945027606827875, 8.178464872496468, 5.294387059552329, 3.6053913703986575, 4.206967490059989, 0.1725334876349994, 1.0185473965747016, 2.2830838220460072, 4.740079317774091, 6.291230346475329, 10.995499951498848, 16.91849184036255, 23.99703516278948, 33.3291711126055, 45.98127794265747, 52.456787109375, 54.833189146859304, 57.26652472359793, 57.585499150412424, 58.00218956811087, 56.25955356870379, 54.60451003483364, 56.629701478140696, 50.29887465068272, 44.884445735386436, 42.398105825696675, 42.66008070537022, 51.53806502478463, 54.2550573348999, 58.45650100708008, 57.94332095554897, 55.408465249197825, 54.52876424789429, 55.65926047733852, 53.24499075753348, 54.13534682137625, 50.99898208890642, 53.831238065447124, 51.46662017277309, 47.85106597627912, 36.26777969087873, 23.573406968797954, 10.779280696596418, 4.918872969491141, 1.9865620647157942, 1.019359358719417, 2.412368736096791, 1.950470732791083, 3.086776307650975, 2.779683517558234, 4.60422466482435, 3.749313533306122, 3.7189403516905646, 4.20989876134055, 3.290864876338414, 3.7039652466773987, 2.246287247964314, 2.47883585521153, 0.21000441695962632, 0.2482258060148784, 0.27267271706036156, 1.0255283819777625, 4.9582583989415845, 16.030755247388566, 22.49843900544303, 23.45738247462681, 14.393447858946663, 16.212007692881993, 30.455479553767614, 28.46446977342878, 17.470917054585048, 2.8147232830524445, 0.0562707971382354, 0.0665719188483698, 0.05382277849795563, 0.020661085977085998, 0.035923536999949386, 0.02010702820760863, 0.06574980581977538, 0.015042897446879318, 0.03653152812538402, 0.019372485212183425, 0.05311501219070383, 0.009927026694640517, 0.06850971986672708, 0.132692815469844, 0.04168613474549992, 0.07177031133323908, 0.028408223929415857, 0.027065303043595383, 0.009137027880309947, 0.05433686376948442, 0.03158403753436037, 0.034716986385839324, 0.042795413972011635, 0.0520967075468174, 0.0358375835764621, 0.007613580208271742, 0.043969181166695695, 0.013064944118793522, 0.020671530327360545, 0.03823643217661551, 0.052694775097604306, 0.03138609190604516, 0.08542203557278429, 0.01328128228695797, 0.05445857938112957, 0.04848621253456388, 0.03673594697777714, 0.043996441311069896, 0.16143369967383997, 0.153839359326022, 0.19077576590435846, 0.13277432109628404, 0.07879952700542552, 0.1350451742431947, 0.07061031500675849, 0.16293058863707952, 0.047193284412579875, 0.15946087267782005, 0.11879820962037359, 0.1533467293317829, 0.17790656217506953, 0.10086526189531599, 0.11070727663380758, 0.059560704710228105, 0.1321727048073496, 0.22235597989388875, 0.14599671587347984, 0.12262068236512796, 0.13253235550863401, 0.08501363213041, 0.23969501948782376, 0.21094801489795956, 0.1797293515077659, 0.12928585042910917, 0.09464478532650641, 0.12207668726997715, 0.12821829771356924, 0.12982154025563172, 0.1249414621187108, 0.17280612300549233, 0.13550737872719765, 0.2367909981736115, 0.17740490766508238, 0.10792228393256664, 0.1731283457151481, 0.0914702999538609, 0.21314205788075924, 0.24676359019109181, 0.1874747744628361, 0.2930841089359352, 0.12165036371776036, 0.20155428110488824, 0.12059421039053372, 0.20947244550500596, 1.2606096076113837, 13.344580803598676, 34.36905241012573, 46.94580602645874, 41.83452354158674, 32.73654883248465, 30.325701100485666, 19.529928854533605, 24.130365882601055, 27.30009933880397, 16.115940162113734, 4.58437670128686, 1.0616861560514994, 2.426435147012983, 4.7928560972213745, 6.627836261476789, 7.669943588120597, 24.567074060440063, 39.313730989183696, 32.53770875930786, 9.6649147101811, 12.33530284677233, 5.249136916228703, 3.1788542696407864, 3.385946197169168, 0.14399164489337377, 0.8259879520961216, 2.3326937428542545, 4.0499182258333475, 5.703323287623269, 8.95836021218981, 15.599480560847692, 24.053187029702322, 31.200524466378347, 45.31658547265189, 51.13078594207764, 55.03051451274327, 58.793023109436035, 57.2562518119812, 59.60571220942906, 57.114633628300254, 54.26418031964983, 57.074605056217735, 51.629732608795166, 45.95606292997088, 45.28832367488316, 45.754502637045725, 55.34541382108416, 54.83668756484985, 57.38977534430367, 58.408794675554546, 55.64527375357491, 55.53744118554251, 57.27303171157837, 53.250090735299246, 54.449638162340435, 50.39432552882603, 55.75298472813198, 53.2438998903547, 48.5632598059518, 33.354525089263916, 20.161264760153635, 9.789554970605032, 4.291224386010851, 1.5817688086203165, 0.9836671139512743, 2.2489412426948547, 2.4253225667136054, 4.436438696725028, 3.4668599239417484, 9.672210318701607, 6.0922543491636, 7.412280065672738, 7.768145952905927, 8.844680735043116, 8.906660403524127, 7.543667895453317, 9.843294075557164, 4.556315532752445, 1.562501779624394, 0.8919132202863693, 1.9534992788519179, 7.443493979317801, 17.66212453160967, 23.428841011864797, 21.96255224091666, 18.648753098079137, 23.517416647502355, 35.55179214477539, 34.70169046946934, 18.369956629616873, 2.6992094814777374, 0.14700036416096346, 0.1543648982686656, 0.1274186713354928, 0.10638989401715142, 0.15965376661292144, 0.21064901165664196, 0.1477246188691684, 0.22792230120726995, 0.1464520671537944, 0.06430679253701653, 0.13748790031032904, 0.15622454562357493, 0.14674452931753226, 0.3094502107373306, 0.13972213970763342, 0.13864261763436453, 0.152574447914958, 0.1674490211797612, 0.0697476187986987, 0.15726444125175476, 0.10813059418329171, 0.18794465996325016, 0.15157841279038362, 0.09734869309301887, 0.24519473580377443, 0.10507536812552384, 0.23386501946619578, 0.12494294132505145, 0.14403060637414455, 0.15658593337450707, 0.1610694620758295, 0.09980944783559867, 0.1200641252632652, 0.11146570915090186, 0.12230892266545977, 0.16376282540815218, 0.19095071937356675, 0.16068315851901258], [0.054130636621266603, 0.049945137463510036, 0.06583703149642263, 0.08187276138258831, 0.057305430727345605, 0.03492874698713422, 0.023952605069747994, 0.054072852579078505, 0.007438821817881295, 0.01576769328676164, 0.01120601685917271, 0.011798169280934547, 0.06237602114145245, 0.018962154730356166, 0.03827832153599177, 0.022582369756751826, 0.0710765974862235, 0.08912797671343599, 0.0033677321459565845, 0.027071832246812325, 0.033182106246905665, 0.01888070847573025, 0.030263591424695084, 0.010759193067704993, 0.09813762575920139, 0.03259486132966621, 0.008446855986091708, 0.03069900395348668, 0.046917890797236135, 0.10432543086686305, 0.05507016674216304, 0.09182757578258004, 0.02987431249182139, 0.07509292768580572, 0.024247867886775305, 0.029596075814749514, 0.009844949402447258, 0.06663119566759892, 0.037248427513986826, 0.03290487040898629, 0.04084109401862536, 0.054452971289200444, 0.04843696107023528, 0.013711921321893377, 0.0637972466647625, 0.04811923026240297, 0.03751531569287181, 0.2767445242830685, 4.71183489050184, 17.28258092062814, 29.239975588662283, 28.294539417539323, 19.152071918760026, 15.538989543914795, 14.057106409754072, 14.3054358959198, 21.66614556312561, 18.371155193873815, 6.7380008186612805, 3.155263832637242, 0.19513478342975887, 1.4133507715804237, 1.9307385001863753, 6.088552696364267, 9.246514167104449, 5.623449402196067, 6.869327417441776, 10.210089479173933, 6.183913682188306, 2.656881489924022, 4.826098016330174, 1.5042701214551926, 0.0638429799250194, 0.003178704164123961, 0.13236401097050735, 0.19286815077066422, 0.7414072049515588, 1.5075257867574692, 3.8887174129486084, 8.194620302745275, 20.941913979394094, 33.18209511893136, 46.89905507223946, 52.911463328770225, 59.18167059762137, 56.478063992091585, 60.06332751682827, 55.103161403111045, 55.06690917696272, 44.65388713564192, 35.776517731802805, 36.30873932157244, 34.66888107572283, 44.235157421657014, 55.74032163619995, 58.705065863473074, 54.93030411856515, 54.75273595537458, 54.217019421713694, 56.11857461929321, 55.643390791756765, 54.043269293648855, 50.70161655970982, 38.32630511692592, 24.74940173966544, 11.304031235831124, 3.334296545812062, 1.4238845663411277, 0.39278766459652353, 0.07537985978914158, 0.8624302223324776, 0.8918759280017444, 2.394505134650639, 2.3926797126020705, 3.3439910198960985, 3.349565429346902, 3.7564745204789296, 2.9480520486831665, 2.518216507775443, 3.659195831843785, 3.906582534313202, 3.043122512953622, 1.3922826392310006, 1.4952082591397422, 0.5335906563060624, 0.6946988627314568, 2.32633809532438, 9.135357754571096, 14.51855364867619, 16.865954773766653, 15.739491973604474, 18.3896895136152, 16.0107479095459, 23.374580792018346, 21.955937555858068, 10.607083490916661, 1.5548608239207948, 0.07171078345605306, 0.021361958368548324, 0.03538025436656816, 0.025051146479589597, 0.0972409892295088, 0.03583463534180607, 0.09733960072376899, 0.026630940547745143, 0.061787507363728116, 0.0005900988461300065, 0.11514626629650593, 0.037406095303595066, 0.10010594728269748, 0.027898014789181094, 0.04845254362693854, 0.026681308202179413, 0.09141731993960482, 0.05385047969009195, 0.06214948544012649, 0.02017796056212059, 0.010494889259072286, 0.03416998198788081, 0.06407049271677222, 0.033260660246014595, 0.03336038453770535, 0.05876903754792043, 0.033588470691548925, 0.021516311514590467, 0.12714272471410887, 0.007055272689155702, 0.018792970505143915, 0.03759549817602549, 0.03516382883702006, 0.06342090400201933, 0.053516094240226915, 0.012999449374287255, 0.01485704500893397, 0.08240107553345816, 0.06787164589124066, 0.06840344771210637, 0.02634039524543498, 0.02811363964740719, 0.05083180970645376, 0.036219113639422824, 0.023444613042686666, 0.031002309106822525, 0.040753423901540894, 0.03984080787215914, 0.0405177144067628, 0.054625024021204026, 0.03175409537340913, 0.0755426131987146, 0.015797279109912257, 0.054153893409030776, 0.0361953818771456, 0.0975247390036072, 0.06996418003525053, 0.025362573697098663, 0.02427925861307553, 0.06554159056395292, 0.01720302555310939, 0.013810991675459912, 0.05738684135888304, 0.1133512629728232, 0.050746626420212645, 0.004604327442523624, 0.021887609269469976, 0.05032512725197843, 0.014777471510959523, 0.07137181450213705, 0.11350483580359391, 0.03075920358034117, 0.04075483864705477, 0.04558120395189949, 0.012617534242703446, 0.059611452344272814, 0.07169080059975386, 0.10733345124338355, 0.020252494241244028, 0.052717974209891896, 0.0212095780630729, 0.05401484462033425, 0.02840332660291876, 0.016655442704047476, 0.058509932165699344, 0.0623234821749585, 0.8387034269315856, 8.539137176104955, 24.750113930021012, 36.57904161725725, 31.92615611212594, 23.57319504874093, 11.265733633722578, 12.153540577207293, 21.42810549054827, 26.785996913909912, 16.84837235723223, 6.114513771874564, 2.1320571260792867, 0.1498642297727721, 0.1255360080727509, 1.367618271282741, 3.8509270293372015, 1.0754672565630503, 4.575567253998347, 4.186861140387399, 5.537370341164725, 8.875287549836294, 3.081917779786246, 4.644563300268991, 4.303147060530526, 0.7919113806315831, 0.26220664009451866, 0.3766170623047011, 0.7291022166609764, 1.984292826482228, 3.167973824909755, 6.985158230577197, 11.476982321058001, 24.808166129248484, 37.24796554020473, 48.48687825884138, 55.40776000704084, 60.35197653089251, 57.068817206791465, 60.63590771811349, 54.76062216077532, 55.62697219848633, 49.17831781932286, 39.1924467086792, 40.4882926940918, 36.23810740879604, 49.633265018463135, 55.82374518258231, 58.139979294368196, 54.77497713906424, 54.665820939200266, 52.53104945591518, 54.871195793151855, 56.876887117113384, 55.0354859488351, 53.18463870457241, 44.65579441615513, 31.839894226619176, 16.855339663369314, 6.536529983792986, 3.295907748597009, 1.1999800609690803, 0.864724756351539, 1.0416133531502314, 2.780987173318863, 3.392509422131947, 4.580177818025861, 3.265954064471381, 3.2058840649468556, 4.380028443677085, 3.7578441841261725, 4.662889608315059, 3.923146605491638, 3.230631811278207, 1.35602759037699, 1.3276818713971545, 0.6364366976278168, 0.10610328082527433, 0.2013571531112705, 1.59968886418002, 8.24246038709368, 20.937939609800065, 24.29681866509574, 19.669563327516826, 15.883962392807007, 14.586037158966064, 25.79954378945487, 27.070848737444194, 17.05308539526803, 3.62304869719914, 0.07166735042950936, 0.03976086626893707, 0.0311095040690686, 0.018048944982833097, 0.028273163230291436, 0.026022275976304497, 0.053125102006431134, 0.05384678167424031, 0.05627247311973146, 0.052976211067289114, 0.016956113445173417, 0.031613119545259645, 0.056596541444637945, 0.05838014877268246, 0.03952900067503963, 0.024557787060205425, 0.030571551328258853, 0.043569720815867186, 0.01904383677590106, 0.02691999476935182, 0.02569708806861724, 0.025874438462778926, 0.020872312232053707, 0.03727287173803363, 0.0746293186343142, 0.05599478605602469, 0.006974517692080033, 0.060404768346675804, 0.03201025252097419, 0.06134495325386524, 0.014219441767116743, 0.08192606709365334, 0.05106647764997823, 0.019496828450688293, 0.038371274048196416, 0.046632339512663226, 0.0400861186374511, 0.08168003708124161, 0.02491415025932448, 0.1855744964310101, 0.11876508354076318, 0.17413309322936193, 0.10748682051364865, 0.07602838998926537, 0.12330640985497407, 0.11998461452977997, 0.19773521460592747, 0.09737276751548052, 0.18252703281385557, 0.2476149887910911, 0.12343618646264076, 0.20332620745258673, 0.08495903041745935, 0.14091284652905806, 0.13660493626126222, 0.22134270997984068, 0.23701904022267886, 0.2734347390277045, 0.09521985732551132, 0.1906309529606785, 0.14965224186224596, 0.18294378902230943, 0.17789710339690956, 0.1995183639228344, 0.09426452751670565, 0.10368108044245414, 0.08956491255334445, 0.09658564653779779, 0.15891904889472894, 0.17394957664821828, 0.23639405518770218, 0.12324395749185767, 0.19394304523510592, 0.09708308055996895, 0.1337949599006346, 0.12239999563566276, 0.19185371377638408, 0.25072191921728, 0.11193732491561345, 0.11715364429567542, 0.12328434389616762, 0.15164891257882118, 0.10410942602902651, 0.17101164215377399, 0.3101341740361282, 0.1891750610832657, 0.7606428584882191, 8.54590472153255, 27.18452995164054, 42.03350952693394, 41.296965735299246, 29.626615047454834, 23.374082258769445, 21.56924077442714, 20.98165246418544, 29.327161584581646, 23.620406321116857, 8.689821021897451, 4.061975955963135, 0.5461826920509338, 2.870868418897901, 5.026974780218942, 13.574052010263715, 18.43571785518101, 12.278816597802297, 19.576228175844463, 20.72197049004691, 14.079992038863045, 6.164794845240457, 8.4389728137425, 3.1862134976046423, 0.32115211710333824, 0.3162383022052901, 0.23748446096267017, 0.6119161248207092, 1.2472303083964755, 2.3332404792308807, 5.333844576563154, 10.04497596195766, 23.892588104520524, 36.25224004473005, 48.68215043204171, 54.26356887817383, 59.35584109170096, 58.34098025730678, 61.1990453175136, 55.81032821110317, 55.35750716073172, 51.77240344456264, 41.76234565462385, 42.85139240537371, 39.21773815155029, 53.1475943837847, 59.14450468335833, 57.94985921042306, 55.75645882742745, 55.00811004638672, 54.65091010502407, 56.18557609830584, 57.38910831723894, 55.576597758701865, 54.17776557377407, 41.91816248212542, 27.96125864982605, 12.751662356512886, 4.685088234288352, 2.2026920786925723, 0.8012566534536225, 0.35495328477450777, 1.912395907299859, 3.3252087363174985, 6.196902470929282, 7.55143598147801, 6.252851103033338, 7.134774225098746, 8.439374940735952, 6.9957485880170545, 7.43421379157475, 9.223979422024318, 9.472445266587393, 8.26636392729623, 5.988704911300114, 4.35218266929899, 1.7074100439037596, 1.0086506647723061, 3.048926212957927, 11.394640956606183, 19.817106587546213, 23.6186032635825, 22.226389237812587, 24.629018987928117, 23.22815098081316, 32.98679862703596, 31.903956617627824, 17.739054986408778, 3.8106908798217773, 0.14014288570199693, 0.19028925629598753, 0.14096237958541938, 0.09507613003786121, 0.14768738086734498, 0.17595284272517475, 0.1915216658796583, 0.13953947808061326, 0.15185540435569628, 0.12056291635547366, 0.2295658215880394, 0.126008770561644, 0.27475014701485634, 0.12507841762687477, 0.18817544329379285, 0.14965841653091566, 0.20579551852175168, 0.14670381721641335, 0.14426615302051815, 0.162289237337453, 0.17264959854739054, 0.12150683999061584, 0.13811876145856722, 0.11620750863637243, 0.2519836686551571, 0.16597035766712256, 0.08368970174342394, 0.07420418930373021, 0.21351656849895204, 0.16595696338585444, 0.09463557082095317, 0.22433051679815563, 0.17398525401949883, 0.17687134843851837, 0.1733981312385627, 0.06207650899887085, 0.12388988211750984, 0.14321070536971092, 0.1586558451609952], [0.03625973074563912, 0.007305777215931032, 0.03553403075784445, 0.02724330822405006, 0.008128653596421438, 0.0326215209705489, 0.07201200550688164, 0.013704586358341788, 0.04524089149864657, 0.01903798441136522, 0.0987077783793211, 0.02991429516779525, 0.05610590973602874, 0.01509751273053033, 0.030982397496700287, 0.019730393774807453, 0.006625138314640415, 0.06001093305115189, 0.015614088225577558, 0.05719795756574188, 0.008159942542468863, 0.01990571534926338, 0.032823480133499415, 0.053429197653063705, 0.08510708675852843, 0.040540961016501696, 0.04509490129670926, 0.03428004376058068, 0.03157399521608438, 0.02543867309577763, 0.024792375275865197, 0.03506794844620994, 0.05228683984439288, 0.042234279082289765, 0.07607100877378668, 0.005931169592908451, 0.01910411273794515, 0.050751430448144674, 0.0422664416421737, 0.061157562237765105, 0.041470523457974195, 0.042715699678020816, 0.02828430986431028, 0.14030581553067478, 0.0241617210808077, 0.04479630856907793, 0.021783671275313412, 0.03175034986010619, 0.05359972368127533, 2.582634125437055, 16.271420001983643, 33.280432973589214, 32.24358456475394, 31.948268754141672, 17.356169291904994, 17.302937405450002, 15.235674619674683, 19.233245985848562, 21.027366399765015, 12.221184764589582, 5.821607249123709, 1.3438762766974313, 0.4014831722847053, 0.9153251754386085, 2.0509301764624457, 1.3201255968638828, 1.8476423876626151, 4.322791354996817, 8.334864480154854, 5.251916629927499, 5.649929421288626, 5.582418118204389, 1.7445723755019051, 0.33823974590216366, 0.18247079583151, 0.23347149629678043, 0.6554413235613278, 0.5444953654493604, 0.3699551240674087, 0.4378025462584836, 2.550693690776825, 10.918682404926844, 19.800387484686716, 33.909717423575266, 42.88401072365897, 48.37094061715262, 48.585952622549875, 50.42706544058663, 51.263083117348806, 43.2041837147304, 29.889778069087438, 26.452174186706543, 31.144827706473215, 42.92421300070626, 55.15657220567976, 54.81452281134469, 54.739659445626394, 56.445240701947895, 54.86914260046822, 40.55767045702253, 25.26916868346078, 21.131010941096715, 11.409756762640816, 4.430428070681436, 1.6567178325993674, 0.476891781602587, 0.13792630178587778, 0.05839176529220172, 0.31794894327010426, 1.7571745621306556, 1.1918305839811052, 2.0852073771612982, 2.9598531297274997, 3.049969962665013, 2.77077180147171, 2.2451475262641907, 2.912166557141713, 3.1378588122980933, 4.312755116394587, 1.8871235719748904, 1.5678224712610245, 1.313671154635293, 0.918828696012497, 0.568816286112581, 0.806029197360788, 5.33141314131873, 12.435836332184927, 18.387832607541764, 15.478990112032209, 11.098195195198059, 18.41562713895525, 23.26702615192958, 22.08445838519505, 24.015779665538243, 11.517559800829206, 2.4509523000035967, 0.31391944949116024, 0.027539144403168132, 0.006927114387508482, 0.017533153195732405, 0.03481812881571906, 0.04065317713788577, 0.056146944141281505, 0.013737352814392319, 0.0040083650466320765, 0.02993931614660791, 0.024647682772151062, 0.04888477721916778, 0.049744457339069674, 0.03316896302359445, 0.030021961711879288, 0.06324903786714588, 0.01878642094587641, 0.010606191902687507, 0.03351231531373092, 0.049374065428440056, 0.0483569787549121, 0.004416578075116766, 0.06554435220147882, 0.02761504702669169, 0.019037394085898995, 0.04051322929028954, 0.019431186972984245, 0.007761957157137138, 0.03790859458968043, 0.040475723267133744, 0.0386494598351419, 0.03979785999815379, 0.013115214233818864, 0.053055647161922286, 0.03913358100024717, 0.0799893042338746, 0.0377395274117589, 0.07615224977156945, 0.092575117812625, 0.006240843221478696, 0.02651635294647089, 0.03849587343367083, 0.1057585986065013, 0.042548657927129946, 0.04154194944671222, 0.038871815760752985, 0.024775016653750623, 0.0282422814052552, 0.020925000476251756, 0.03911521305729236, 0.021639993181452155, 0.0588862273309912, 0.06551007939768688, 0.002234364502198462, 0.04358421093119042, 0.07706922878112112, 0.05689116474241018, 0.04456587807674493, 0.024404577245669704, 0.041381869465112686, 0.019731325064120547, 0.01461135087135647, 0.028798549502555813, 0.0280919977729874, 0.037192974239587784, 0.012731062481179833, 0.02547406548235033, 0.02268548502719828, 0.030106133980942622, 0.04905675191964422, 0.027386740348967056, 0.028119973771806275, 0.024952372136924948, 0.0320584454706737, 0.07723439099001032, 0.020191804372838566, 0.030921468444700752, 0.022968094862465347, 0.05393238904486809, 0.03495141684210726, 0.03800501102315528, 0.02182075321408255, 0.0648129525195275, 0.027995432061808448, 0.03425961985651936, 0.020967054380370036, 0.05424125479268176, 0.02454792964272201, 0.2486900868160384, 5.104974823338645, 21.801958526883805, 37.70750897271292, 34.24423497063773, 29.866369588034495, 17.006466456821986, 12.85836844784873, 23.78575607708522, 31.636701107025146, 27.536153963633947, 13.222512245178223, 5.319043176514762, 1.3377545880419868, 0.1897761481148856, 0.23130930374775613, 0.650356436414378, 1.2593488352639335, 1.5242276276860918, 2.9410046211310794, 5.476718212877001, 4.722700136048453, 5.093162451471601, 5.188194700649806, 2.6253570786544254, 2.489517624889101, 0.9714456668921879, 1.2582134561879295, 2.732852007661547, 0.9095976884875978, 0.966615800346647, 1.3323380329779215, 4.188476596559797, 14.67211491721017, 24.670508418764385, 37.5030061176845, 46.62440667833601, 51.58480903080532, 51.83297436577933, 54.398436886923655, 56.762519768306184, 49.4423702103751, 34.96291494369507, 31.180597032819474, 34.5645295551845, 48.05353300912039, 59.50283023289272, 57.819104535239084, 57.00785023825509, 58.09705332347325, 59.69417667388916, 45.514713355473106, 32.564115388052805, 28.14739567892892, 17.736015149525233, 7.3870494195393155, 3.065913255725588, 0.9618413022586277, 0.582673111132213, 0.627127577151571, 0.9545830403055463, 2.92848179595811, 4.450144452708108, 3.0833273955753873, 4.73541316815785, 3.830110226358686, 3.938557709966387, 5.690467817442758, 4.390255757740565, 5.520077577659062, 4.614498010703495, 3.5187028220721652, 2.151814111641475, 0.83717357473714, 0.24529627178396496, 0.34940091414111, 0.8274891429713794, 5.021442711353302, 12.930135522569929, 24.117131301334926, 21.747234514781407, 14.521433676992144, 16.477468831198557, 20.600826910563878, 23.446588448115758, 28.615462814058574, 17.253278630120413, 4.001574831349509, 0.2993548853056771, 0.015204044424795678, 0.04064804741314479, 0.036759576959801574, 0.03138071112334728, 0.036486541253647635, 0.03777858049475721, 0.07086028730762856, 0.02040793134697846, 0.022332650210176195, 0.02369963364409549, 0.03648501115718058, 0.02154535790240126, 0.035598101426980326, 0.019705500021310787, 0.04288081099678363, 0.0039856930712371, 0.04432204991046872, 0.03274471239585962, 0.07046551563377891, 0.030759776942431927, 0.017236082082880393, 0.06455097693417754, 0.05643392713474376, 0.0195526260816093, 0.046732460747339895, 0.009611947262393577, 0.05231670556323869, 0.022446801852700964, 0.03635621842529092, 0.0499588608342622, 0.03564161587772625, 0.05368514106209789, 0.04653452529704996, 0.017410602986014316, 0.027623905301360146, 0.009597681911795266, 0.10563045048287936, 0.05274682551888483, 0.02738820937728243, 0.14922842888959817, 0.10194563892270837, 0.1717182956635952, 0.1183482323374067, 0.10743179132363626, 0.11840304439621312, 0.13093718753329345, 0.11256095288055283, 0.11756402227495398, 0.15109511943800108, 0.1892005739999669, 0.1160012882735048, 0.14302353827016695, 0.07506471419973032, 0.1029845235337104, 0.13588534987398557, 0.12173412208046232, 0.17982297576963902, 0.06964985547321183, 0.1272111888974905, 0.09664697253278323, 0.10716676911605255, 0.12229453772306442, 0.14788327392722878, 0.2283206284046173, 0.14053577104849474, 0.11254413199744054, 0.13337775585906847, 0.24541943946055003, 0.15991793386638165, 0.11620038401867662, 0.0762865182810596, 0.08258376430187907, 0.15832800418138504, 0.11194670226957117, 0.10288606810250453, 0.13667916799230234, 0.1766754010958331, 0.11082866654864379, 0.15820524362581118, 0.1893484674926315, 0.14542628505400249, 0.15552034841052123, 0.16496290958353452, 0.08931893682373421, 0.06808651757559606, 0.10093108657747507, 0.12903693664286817, 0.24594448985798018, 5.221654185226985, 23.60639875275748, 44.86493171964373, 44.23018251146589, 43.83663306917463, 27.387617111206055, 24.87871640069144, 23.78407461302621, 26.75707503727504, 27.596655402864727, 14.963951417378016, 7.300350666046143, 1.8533627092838287, 0.684460637824876, 1.1458048479897636, 4.251214052949633, 4.484202350888934, 5.570841550827026, 10.869414465767996, 18.962505953652517, 13.97815924031394, 13.99262191568102, 11.031258855547224, 5.494218119553157, 1.87334030015128, 0.9718665757349559, 1.1497032216617038, 2.4987133485930304, 1.5432816509689604, 0.6839580876486642, 0.7550422304442951, 3.0920426079205106, 12.395117282867432, 21.92088041986738, 35.81630311693464, 44.57567126410348, 49.82960374014718, 50.887685843876426, 54.573104177202495, 59.14335823059082, 55.887755462101524, 38.39660004207066, 36.51210962023054, 38.0540086882455, 52.30177279881069, 62.243762561253135, 57.078610692705425, 59.20029871804373, 59.3214544568743, 65.01931081499372, 44.900978973933626, 27.16733316012791, 22.404956204550608, 13.373178720474243, 4.748472307409559, 1.8943462244101932, 0.8777051312582833, 0.33482622621314867, 0.34522420540452003, 1.0112228010381972, 4.112451578889575, 4.870925622326987, 5.803217104503086, 7.345394100461688, 7.951001695224217, 7.488681588854108, 7.480795383453369, 9.42941767828805, 8.743514963558741, 9.299496786934988, 6.960946798324585, 5.521691296781812, 3.235475791352136, 2.1827058025768826, 1.0011483473437173, 1.1164183105741228, 7.158051558903285, 16.5305825982775, 24.230968849999563, 20.25769533429827, 16.90548654964992, 24.647032192775182, 31.129760537828716, 30.882960523877824, 34.82085902350289, 18.38024343763079, 4.336563987391336, 0.49852809203522547, 0.08247851673513651, 0.12629625227834496, 0.07933432116572346, 0.1454423934753452, 0.19575743430427142, 0.16386267862149648, 0.1772831513413361, 0.14165957431708062, 0.15534542208271368, 0.20150761146630558, 0.13980592521173613, 0.11752033819045339, 0.14647555803614004, 0.11310589792472975, 0.13874913406159195, 0.05365366382258279, 0.1144854546125446, 0.1652845080409731, 0.2327389498906476, 0.1899802243070943, 0.14098703754799707, 0.13470275833138398, 0.12418553339583532, 0.11621718454573836, 0.08500050926314932, 0.12192369119397231, 0.09599055775574275, 0.06561252461480242, 0.15758249775639602, 0.10520228810076203, 0.09184073936194181, 0.12016840252493109, 0.13921839530978883, 0.149335433862039, 0.14693572691508702, 0.10290795764220612, 0.1767975916819913, 0.25155787436025484, 0.13885653258434363], [0.042508624361029694, 0.0947354511756982, 0.05504201093156423, 0.017275409972561256, 0.03280871521149363, 0.09320986696652003, 0.02419261647654431, 0.04010188100593431, 0.029031846805342605, 0.018327573513878242, 0.04213981682966862, 0.049779890437743494, 0.0803949935361743, 0.03380765785862293, 0.042996104274477275, 0.004530422680545598, 0.03196268382349184, 0.06582361007375376, 0.053631577507725785, 0.0430955469741353, 0.049272743186780384, 0.07331269606947899, 0.017484904266893864, 0.08440458588302135, 0.011582177165629608, 0.04371417752866234, 0.02882064938811319, 0.030991595038878064, 0.025451025825792124, 0.12167711156819548, 0.02283783140592277, 0.009126927038388593, 0.01627715434213834, 0.04805773463366287, 0.03939666599035263, 0.02735054729107235, 0.022808247279109697, 0.046468402059482675, 0.02165563002095691, 0.009871920321269758, 0.020294305569093143, 0.03482482595635312, 0.02885480344827686, 0.063564251310059, 0.03087436793638127, 0.054402121874902926, 0.02091914302270327, 0.03441641912130373, 0.15208666266075202, 0.08173398740057435, 1.8322380142552512, 7.882969277245658, 25.031632355281285, 32.63395173209054, 25.454671689442225, 18.27989755358015, 10.617758529526846, 15.362875291279384, 14.685054200036184, 19.49845698901585, 14.555013452257429, 10.53510970728738, 2.7071918760027205, 0.697265733565603, 0.03505199269524642, 1.966924501316888, 0.3350202329456806, 1.2143921447651727, 4.980405781950269, 1.7543776950665881, 2.0680987409182956, 6.960321460451398, 3.3925328723021915, 4.044242850371769, 2.780256961073194, 1.5907091860260283, 2.1471603385039737, 0.14921122124152525, 1.1345533260277338, 0.26941053782190594, 0.054802667881761274, 1.134492854986872, 4.161157148224967, 9.289697221347264, 16.949208089283534, 24.439984560012817, 23.951276063919067, 21.87253311702183, 22.674918038504465, 37.09304503032139, 31.47947379520961, 27.624720914023264, 29.35109465462821, 36.91294424874442, 40.7187123298645, 34.70588023321969, 27.551387889044626, 19.03707923207964, 17.71846399988447, 8.761769618306841, 0.5010483882256916, 0.5879615587847573, 0.37789672506707056, 0.09041465552789824, 0.03545053702379976, 0.06348062865436077, 0.24436885012047632, 0.9625867136887142, 1.1334330375705446, 3.199143009526389, 3.9400328993797302, 2.7816524633339474, 3.2264081750597273, 4.068148561886378, 2.190097383090428, 3.3702085273606435, 3.899447168622698, 3.8994324037006924, 3.0724847316741943, 2.6932613892214636, 1.8575235945837838, 0.3984675998134272, 0.8530015168445451, 3.2839281857013702, 7.202328520161765, 18.262104954038346, 18.196960381099156, 11.880929742540632, 17.838297843933105, 14.139386977468218, 23.02765723637172, 26.22040660040719, 21.31516078540257, 12.884207929883685, 3.117801317146846, 0.174556078389287, 0.030026402723576342, 0.029393875771867375, 0.03829737140664032, 0.03713642852380872, 0.018737059219607284, 0.024593993688800504, 0.02591329307428428, 0.025983982852527072, 0.038352882356515954, 0.054091373192412515, 0.015852287943874086, 0.040011143910565546, 0.024746947356366684, 0.006340322816478354, 0.024546642122524123, 0.023121165577322245, 0.04752823983186057, 0.01104462645681841, 0.02148380968719721, 0.07576796146375792, 0.019244204774232845, 0.03353840159252286, 0.06305245948689324, 0.10372873395681381, 0.08532263697790247, 0.03150619599702103, 0.0651129192805716, 0.09677437426788466, 0.044998695209090195, 0.01715381140820682, 0.004792471208410072, 0.026501031625749807, 0.0213671169310276, 0.010206770567622567, 0.0256279792769679, 0.0067647926958410865, 0.04274595216182726, 0.0275556514638343, 0.06610274580972535, 0.02155017719737121, 0.017130289991785373, 0.007232426732246364, 0.03672987748203533, 0.0561541739319052, 0.02143161677356277, 0.014788336552945631, 0.02693654763113175, 0.02858809508117182, 0.019170151158635105, 0.08467151477400746, 0.05696999694087675, 0.0678275479003787, 0.07224897707679442, 0.034748640044459274, 0.078785026712077, 0.016311771502452235, 0.05669229630646961, 0.020256327964099388, 0.020759644884882227, 0.049644444669995985, 0.02695614711514541, 0.03760496713221073, 0.038618549172367365, 0.048263503770743094, 0.03329254460654088, 0.04339673849088805, 0.025977004119860272, 0.07464345251875264, 0.03568338310079915, 0.06292471169893231, 0.1004059004730412, 0.06258942719016757, 0.030043756256678274, 0.06955996315394129, 0.015171505277976394, 0.007852327843595828, 0.014164963886807007, 0.02411853232687073, 0.08343200771404163, 0.04216514993458986, 0.0697056446224451, 0.04543159037296261, 0.013473813205824366, 0.03056247592238443, 0.012082099714981658, 0.03061474347487092, 0.01735323285018759, 0.02658888155461422, 0.028767974714615514, 0.2015654362205948, 3.973924909319196, 15.280183042798724, 33.82966027941023, 37.14846733638218, 27.8050822530474, 20.066979442323955, 11.260775225503103, 17.253540924617223, 22.809749569211686, 27.73787580217634, 18.03487627846854, 10.544802444321768, 3.039747642619269, 0.6155783140233585, 0.1406928383346115, 0.41456315613218714, 0.28588246394480976, 0.920344597526959, 2.48760296191488, 1.6419424882956912, 3.8156649214880805, 3.6770114472934177, 4.353238795484815, 3.6388221936566487, 2.1249971049172536, 4.814747699669429, 3.0796287826129367, 2.0544242518288747, 1.6719067032848085, 0.8947816320828029, 0.7033564810241971, 2.1661638787814548, 6.230642054762159, 13.891954677445547, 22.401898997170584, 29.313810620989116, 30.388342584882462, 28.277617079871042, 30.47863095147269, 43.957159996032715, 35.98816333498274, 29.62276921953474, 34.38504368918282, 43.10184022358486, 46.972271714891704, 41.66556419645037, 36.13734810692923, 27.765515736171178, 29.336656297956193, 13.248647025653295, 1.2617877615349633, 1.6758617482015064, 0.922969713807106, 0.26483080642563955, 0.13038865982421807, 0.29829273372888565, 0.9809924917561668, 2.1341187868799483, 3.1174999390329634, 3.926789632865361, 4.160517913954599, 5.008965917995997, 5.315802276134491, 4.854572602680751, 5.474324992724827, 5.740649878978729, 2.9446313636643544, 3.4236779553549628, 2.6361856290272305, 1.3727182490485055, 0.5345502676708358, 0.17834261591945375, 0.7658618784376553, 3.8236531785556247, 9.343229617391314, 19.01119371822902, 23.989812510354177, 17.465440137045725, 12.966873254094805, 9.709451794624329, 23.93590838568551, 28.54231217929295, 25.329367876052856, 19.020014456340245, 5.360481798648834, 0.5904067275779588, 0.09265889653137752, 0.08801831411463873, 0.032028277803744586, 0.006154863928843821, 0.051783885939845016, 0.030087487838630165, 0.023516788812620298, 0.056227828908179484, 0.04253923986107111, 0.01556791561389608, 0.037199895296777995, 0.0355505191587976, 0.054020920901426246, 0.03580533280702574, 0.016446135006844997, 0.008409305858159704, 0.03522855429244893, 0.03217308056939926, 0.006809400860220194, 0.061236340153430185, 0.03449329035356641, 0.03761094163304993, 0.015585613503519977, 0.07115197594144515, 0.13123761569815023, 0.02757112036592194, 0.03832003786893828, 0.06635041109153203, 0.018456459544332962, 0.03371943473549826, 0.05499580269679427, 0.011497618131605642, 0.0075403408346963775, 0.03549993098048227, 0.026719848991238644, 0.03421449388510414, 0.02567210610556815, 0.03538087861878531, 0.02986725912030254, 0.04859277645924261, 0.18142524122127465, 0.11040756093072039, 0.19477819970675878, 0.09904026732380901, 0.19013923220336437, 0.20311155968478747, 0.11056819731103522, 0.08531237752842051, 0.07987068274191447, 0.20734077346112045, 0.09075805531548602, 0.1343069417136056, 0.162125791822161, 0.12103916651436261, 0.3136942301477705, 0.1353048767362322, 0.14840542019477912, 0.19154705666005611, 0.19809657521545887, 0.24264138138719968, 0.06149354563759906, 0.20134850857513292, 0.13634701152997358, 0.2124351600983313, 0.09134993462690286, 0.15743643630828175, 0.10963559842535428, 0.11004778809313263, 0.1533361713268927, 0.21873847900756768, 0.1444290014249938, 0.20483499792005333, 0.09162908393357481, 0.16403434798121452, 0.09071104640939406, 0.06450663467070886, 0.0947834982403687, 0.08319625750716243, 0.14841322334749357, 0.1308482994458505, 0.10509252827614546, 0.15036378082420143, 0.0948096557653376, 0.14816574805549212, 0.15672571158834867, 0.15281304796891554, 0.09960434027016163, 0.24409632331558637, 0.19779100375516073, 0.35647882148623466, 3.417626074382237, 15.55281298501151, 38.306891850062776, 45.155345576150076, 36.35553196498326, 29.388052122933523, 15.99145449910845, 22.79310863358634, 23.030413934162684, 27.160706315721782, 19.563255889075144, 12.41882974760873, 3.574526820863996, 1.2443564683198929, 0.2349453829228878, 4.367008822304862, 3.5517593111310686, 4.505806905882699, 10.621670365333557, 6.279189118317195, 8.768164566584996, 14.105789831706456, 10.167551738875252, 10.728704759052821, 6.706374789987292, 6.0923216598374506, 5.958824183259692, 2.7982986101082394, 3.5259415422167097, 1.2039507393326079, 0.5436245607478278, 1.618452365909304, 5.114016166755131, 11.523864422525678, 19.320817606789724, 28.026622091020855, 28.42820017678397, 26.26164937019348, 30.22199923651559, 50.63911403928484, 43.07801137651716, 36.20514862877982, 38.68926511492048, 48.0447678565979, 49.07942063467843, 40.98636736188616, 32.6183808190482, 23.019850935254777, 26.82798661504473, 11.841910396303449, 0.821143103497369, 1.1475566625595093, 0.801533930003643, 0.263374778841223, 0.1843815775854247, 0.14291044005325862, 1.022371728505407, 2.7553177050181796, 4.246668628283909, 9.005046895572118, 10.065281203814916, 8.118138006755284, 8.728656240871974, 8.923370821135384, 10.628741025924683, 9.87098525251661, 8.942120535033089, 11.04247498512268, 9.755033714430672, 5.902540734836033, 4.398234895297459, 1.4071803369692393, 1.056346139737538, 4.067340399537768, 9.592867970466614, 22.669983080455236, 25.086356367383683, 18.27380919456482, 23.279543331691197, 18.536642176764353, 32.77437482561384, 36.293428965977256, 30.984181880950928, 18.774020433425903, 5.230940452643803, 0.4663851825254304, 0.19822859098868711, 0.257326209119388, 0.13918229724679673, 0.1265548419739519, 0.08855559849845511, 0.11422995903662272, 0.07536194646464926, 0.13943711428769998, 0.15426900769983018, 0.09035023541322776, 0.1095975326108081, 0.12085902903761182, 0.15633498398321016, 0.08448737394064665, 0.15417317141379627, 0.07866377928959471, 0.14268796199134418, 0.11953090530421052, 0.07185738773218223, 0.23024253813283785, 0.08540718244122607, 0.15683752058872155, 0.1454625323946987, 0.21074476651847363, 0.14603676301028046, 0.0779513039493135, 0.12873823195695877, 0.23188185159649166, 0.13303194727216447, 0.09474573098123074, 0.12190854629235608, 0.14463520821716103, 0.09080333395728044, 0.08880886169416563, 0.07434587420097419, 0.08591700651283775, 0.1126375798402088, 0.15466092952660151, 0.16671019153935568, 0.12263825642211096], [0.06631424517503806, 0.013401259152617837, 0.020395675308204124, 0.0631394883883851, 0.040434739752007384, 0.014205987265865718, 0.019877591769077947, 0.05164200426744563, 0.013924421526358595, 0.026796696474775672, 0.04922012618875929, 0.04963186802342534, 0.029349275665091615, 0.023620523246271268, 0.051800496477101526, 0.039308653213083744, 0.07926994176315409, 0.054386328972343884, 0.060022407078317234, 0.06588522105344705, 0.0380507849955133, 0.020324956692223037, 0.016177028018449034, 0.03770195692777634, 0.07339462917298079, 0.009249375467853886, 0.03626334733728852, 0.05921483505517244, 0.008948988015098231, 0.022331079401608025, 0.036004540510475636, 0.019952927815860937, 0.02184438149976943, 0.03466064083789076, 0.023266709642484784, 0.008948150024350201, 0.04096187325194478, 0.00796405372342893, 0.07391616475901433, 0.054157730524561236, 0.033265128399112394, 0.04209506405251367, 0.01333538442850113, 0.025973879466099397, 0.011940608200217997, 0.0310845543364329, 0.03854348962860448, 0.0474116539449564, 0.06466120494795696, 0.043540442029812505, 0.012522714911028743, 0.7574910904679979, 4.961780701364789, 19.688160181045532, 32.72504956381661, 28.81976417132786, 28.461343084062847, 24.531301259994507, 13.606342894690377, 14.917042391640798, 19.32713351930891, 23.78305843898228, 14.976710047040667, 8.730296884264265, 2.3469833646501814, 0.7571706048079899, 0.1770173827452319, 0.9570562733071191, 0.9005647046225411, 1.1732123430286134, 2.32770037651062, 1.0758610240050723, 1.5330532512494495, 4.063953586987086, 0.9520433651549476, 3.8396170990807668, 4.858171769550868, 1.8441061888422285, 2.0144271637712206, 0.7769607571618897, 0.5976706349423954, 0.8520700239709446, 0.41728964554412024, 0.9517304790871484, 2.0686350549970354, 2.13573728288923, 2.6761375537940433, 1.6068106591701508, 3.1609415965420857, 8.226683633668081, 12.359248944691249, 12.389874867030553, 13.33765344960349, 13.63077710356031, 10.915711181504385, 5.136879214218684, 1.5143168909209115, 0.161264798736998, 0.16713688150048256, 0.16801833920180798, 0.19694759829768113, 0.02983892010524869, 0.042630916727440696, 0.3325248254196984, 0.8151931656258447, 1.2805438808032443, 1.8120352583272117, 2.156884776694434, 1.9342753504003798, 2.5366431304386685, 3.578139667000089, 2.1191117635795047, 3.179724314383098, 2.39664756825992, 4.004444437367575, 6.451609969139099, 2.331816098519734, 4.058306004319872, 2.2438312768936157, 0.8738489353231021, 0.798270502260753, 2.2944395669869015, 5.065794365746634, 9.177157248769488, 18.835593632289342, 15.6457051890237, 10.40270483493805, 12.10607135295868, 17.842294795172556, 24.96297546795436, 24.447764805385045, 21.38995466913496, 9.316321849822998, 1.9142048273767744, 0.24649869011981146, 0.044319987164012024, 0.04204545635730028, 0.05737809504249266, 0.022425254973183786, 0.029707552332963263, 0.07303970786077635, 0.08377924122448478, 0.028322825208306313, 0.028719517136258737, 0.0034350381548782544, 0.029857973368572335, 0.056405072433075736, 0.04304947444636907, 0.029814231608595167, 0.046436076651194265, 0.08157715081636395, 0.02859571502943124, 0.014653913676738739, 0.04262412119922893, 0.02551011774422867, 0.10034810286015272, 0.023806558888671652, 0.06363844232899801, 0.026294622969414507, 0.03176538280344435, 0.07352080954504864, 0.005532204996727939, 0.0875816157619868, 0.027134401657219444, 0.07037871064884321, 0.036436852134232006, 0.032490353366093974, 0.06055327930620738, 0.053805014451167414, 0.01918883292403604, 0.021300259179302623, 0.035599444926317246, 0.04104803362861276, 0.03275976569524833, 0.03572584242959108, 0.010445885460025497, 0.04585620740960751, 0.008777658771058279, 0.04347551979922822, 0.011307568954569953, 0.032294239782329114, 0.02790420302855117, 0.017066790988402705, 0.017143029486760497, 0.002127732299933476, 0.03899147880396672, 0.009595005939315473, 0.047925556012030156, 0.057424330418663364, 0.041937365728829584, 0.0517947866049196, 0.004756366360067789, 0.042715401122612615, 0.061018998601606915, 0.0057576889687749955, 0.03399104212543794, 0.039454667163746696, 0.04996396681027753, 0.01711680750096483, 0.0463763180721019, 0.028314273970733796, 0.01080808914931757, 0.04652058140241674, 0.02487009806957628, 0.006292403401208243, 0.008308093878440559, 0.08858170174062252, 0.028770027283046926, 0.04201227260221328, 0.07005124964884349, 0.04735064346875463, 0.1067338502034545, 0.028480404788362126, 0.05987449322960206, 0.039324592000671794, 0.03043655339362366, 0.09340658783912659, 0.04977530354101743, 0.08285565328385149, 0.03180519584566355, 0.08358381635376386, 0.0350691732019186, 0.029518817817526202, 0.03457124045650874, 0.04682346925671611, 0.030422758776694536, 0.034412202026162825, 1.2023300720112664, 9.264234679085867, 26.8126380443573, 38.150918688092915, 31.108464309147426, 24.091459444590978, 21.88885964666094, 12.953634330204554, 19.100519759314402, 28.7150912966047, 30.613158498491558, 18.53601336479187, 9.104161211422511, 2.4495387758527483, 0.41628663507955416, 0.02034415414423815, 0.365721445530653, 0.3899245725146362, 0.8232908568211964, 1.8605310789176395, 2.290948748588562, 3.1355131438800266, 4.497210681438446, 2.685544763292585, 4.527332425117493, 2.1975217504160742, 3.774739597524915, 3.568102777004242, 3.1690488415105, 1.2468303527150835, 2.0919599405356815, 1.203548286642347, 1.6763743949787957, 2.6206516282899037, 4.215828614575522, 4.259764679840632, 3.796122678688594, 6.5993499500410895, 15.00055626460484, 18.936896630695887, 17.860255888530187, 18.90027093887329, 20.027273961475917, 16.48720325742449, 8.995427114622933, 2.97407848068646, 1.0932771180357252, 0.37765239817755564, 0.6805805574570383, 0.2413256477032389, 0.14898118429950305, 0.3130000616822924, 0.9231584008250917, 2.0509438557284216, 1.4732713848352432, 2.384739007268633, 3.299807425056185, 3.7950665525027683, 5.127796181610652, 5.070624232292175, 6.913264351231711, 5.894613708768572, 4.424972866262708, 4.5778458288737705, 1.71065930383546, 1.0910726934671402, 0.976922910128321, 0.8005045109561512, 0.33386585488915443, 0.3747028335928917, 2.8366051145962308, 8.719190188816615, 11.941789013998848, 19.533852849687847, 22.23978362764631, 15.592285701206752, 12.500902737889971, 16.978190762656077, 21.536113500595093, 29.030282429286412, 25.948275191443308, 14.731893743787493, 4.294241206986563, 0.5319331852453095, 0.06607403020773615, 0.02129703274528895, 0.04199038984786187, 0.05082022711368544, 0.09127418976277113, 0.06808058039418288, 0.030113472337169305, 0.022270231773810725, 0.038498540076294115, 0.03453495240371142, 0.014475760914917504, 0.03867914913488286, 0.014378861025241869, 0.028944638092070818, 0.014856230766911591, 0.01614846339050148, 0.03021869615518621, 0.030536267507289137, 0.026798063722838248, 0.005389523077090936, 0.06004013041300433, 0.013408264178516609, 0.032824212951319556, 0.06962058347250734, 0.06115366066140788, 0.07379141609583582, 0.016068279211010252, 0.07981349581054278, 0.009610073657573333, 0.02132947350453053, 0.02702283184044063, 0.05985326865421874, 0.04713837396619575, 0.02890357654541731, 0.044967516524983306, 0.05748280656657048, 0.07851535653961556, 0.02429869694502226, 0.028762868738600185, 0.051114619709551334, 0.030973624038909162, 0.14618629855769022, 0.09101238381117582, 0.06915775473628726, 0.1142689340880939, 0.10642635848905359, 0.09142168291977473, 0.1516889732863222, 0.20007983808006558, 0.07911882522915091, 0.1189702996718032, 0.09741459241403, 0.13190830685198307, 0.1231549744095121, 0.16490937317056314, 0.13324119390121528, 0.07480074372142553, 0.12738473101386003, 0.12554116493889264, 0.09651365397231919, 0.1262037679553032, 0.1516278237104416, 0.0962449608902846, 0.09727503811674458, 0.1199044252612761, 0.10815192053892783, 0.0630081511501755, 0.08928511185305459, 0.16751007576073917, 0.08338540592896086, 0.08834594474839312, 0.19314754434994288, 0.1347390870962824, 0.14679820143750735, 0.13550503099603312, 0.09974652049796921, 0.1851749885827303, 0.09996888999428068, 0.17088356188365392, 0.14851104095578194, 0.1535236369818449, 0.2322857699223927, 0.16926961205899715, 0.14632181557161467, 0.09670695502843175, 0.09090953147304909, 0.14177286252379417, 0.07444194797426462, 0.11045828142336436, 0.12268132982509476, 0.22268600575625896, 0.09844513104430266, 1.3957180891718184, 9.348594495228358, 29.149687222072057, 45.46742391586304, 40.395207677568706, 39.03387492043631, 34.31977925981794, 21.32664963177272, 21.550112383706228, 28.99751125063215, 30.66503722327096, 20.637407439095632, 10.95273118359702, 3.137929162808827, 1.232612709913935, 1.0011079609394073, 2.4920604484421864, 4.285530771527972, 5.720356362206595, 7.173390141555241, 5.18272863967078, 5.455355107784271, 10.303433316094534, 5.258376283305032, 9.016368116651263, 10.665293761662074, 7.052352956363133, 5.05242212329592, 3.1667014360427856, 2.2128360143729617, 2.4233073719910214, 0.9929580496890205, 1.576550385781697, 2.576376621212278, 2.944676092692784, 3.6324454843997955, 2.8709858868803297, 5.606984342847552, 12.970605305262975, 16.13405932698931, 16.71997833251953, 18.651091166904994, 20.06776111466544, 13.854671512331281, 7.165494816643851, 2.0942780332905904, 0.9358263782092503, 0.2458916184093271, 0.7754722141793796, 0.4519546968596322, 0.2657555682318551, 0.1931890164102827, 0.7723399879676955, 1.9549256137439182, 3.2728164962359836, 4.968871338026864, 4.718011404786791, 5.611085082803454, 5.6380588582583835, 8.28620363984789, 9.399179118020193, 11.1447594165802, 9.250603181975228, 9.829261319977896, 11.485327107565743, 7.689064162118094, 8.424629994801112, 5.282605954578944, 1.9484029923166548, 1.5946407807724816, 3.3881993676934923, 7.372449517250061, 13.230395845004491, 25.227839061192103, 22.84597052846636, 17.007743188313075, 19.006856305258616, 26.638808012008667, 33.94892610822405, 34.174610546657014, 29.619972569601877, 14.835611241204397, 3.63813562478338, 0.43095791925277027, 0.11854487178581101, 0.12298726769430296, 0.10718804118888718, 0.1437835924859558, 0.20949643850326538, 0.13066528498062066, 0.1772090688880001, 0.12761347873934678, 0.18457734850900515, 0.12077802552708558, 0.08692714159509965, 0.26901687894548687, 0.13084018416702747, 0.08549023512750864, 0.09375127005789961, 0.14073678026241915, 0.13920512316482408, 0.0730615227616259, 0.1671419840838228, 0.16820904825414928, 0.19047545987580503, 0.06719198450446129, 0.19031234005732195, 0.13081423698791436, 0.1216585197086845, 0.19735191017389297, 0.11258438269474677, 0.2008182741701603, 0.07232766678290707, 0.11703270221395151, 0.10291059714342866, 0.15103353559970856, 0.14527718376900467, 0.10785245589379754, 0.11003189680299588, 0.16817316732236318, 0.17412168027034827, 0.10642362399292843, 0.12613606373114244, 0.11049695113407713, 0.057393165305256844], [0.05031897633203438, 0.022302653873339295, 0.025204841446663653, 0.042812621620084555, 0.02622524106742016, 0.02542438654095999, 0.07740815023758582, 0.063054488306599, 0.04209923365020326, 0.04750534266765628, 0.08294473814644984, 0.03639196704274841, 0.02002968030449535, 0.046833403009389124, 0.048535199370235205, 0.03997538172240768, 0.008250419250024217, 0.038507968320378234, 0.03909924712830356, 0.024212646830294813, 0.028239908229027475, 0.06843572562294346, 0.012970967018710715, 0.049174565954932144, 0.02326214310180928, 0.03443019338218229, 0.025412982063634054, 0.04187239260811891, 0.029354792154793228, 0.03850223469947066, 0.04127635048436267, 0.0276070861145854, 0.006166886721205498, 0.03251477384141513, 0.033287279174796174, 0.0070720329282007045, 0.04594315827957221, 0.0660084905102849, 0.058250799642077515, 0.0416634513198265, 0.034045501346034665, 0.01436273055151105, 0.010854378808289766, 0.05278035193415625, 0.014350589863689882, 0.024520004534029534, 0.04045620181464723, 0.08125511809651341, 0.01178413548041135, 0.039110917930624316, 0.05799153819680214, 0.01038617522655321, 0.267085605434009, 4.752619079181126, 15.777736595698766, 31.41594988959176, 32.3499093736921, 24.9301278591156, 19.732206548963273, 16.595883505684988, 12.200037053653173, 13.963008693286351, 19.805155685969762, 19.53579487119402, 13.995979632650103, 7.831791451999119, 2.6243476356778825, 0.4747770865048681, 0.40886188777429716, 0.8093437595026833, 2.0409397525446753, 1.4643109227929796, 3.0245549721377234, 1.8671846304621016, 2.1382907458714078, 3.7489661233765736, 0.7831833032625062, 1.9469955478395735, 1.900514270578112, 3.140748394387109, 1.4724839585168021, 1.6065686664410999, 0.1927105270858322, 0.3577514003430094, 0.0930045083431261, 0.2215842820171799, 0.08453371109707014, 0.043859482410230806, 0.2830098995140621, 0.62843378420387, 0.6544685757585934, 0.5076515653303691, 1.1473388799599238, 0.6172979388918195, 0.12618570535310678, 0.05425302737525531, 0.06588666633303676, 0.17405044766409056, 0.8490389809012413, 0.32403271538870676, 0.1662728757198368, 0.15263578748064383, 0.34097486627953394, 0.31215476989746094, 1.605827814766339, 1.6284817648785455, 1.64765607884952, 2.1008104256221225, 2.389496786253793, 5.254317666803088, 1.2309349370854241, 6.143552030835833, 4.8020650659288675, 3.6360257608549933, 3.6824375561305454, 1.8180368734257562, 0.811426427747522, 0.5677230304905346, 0.34121623475636753, 2.235909027712686, 8.094647884368896, 9.146028450557164, 12.2412303175245, 17.29287988798959, 17.604145288467407, 11.137924994741168, 11.69499855382102, 15.374009779521398, 26.91720495905195, 26.43596577644348, 15.657013382230486, 5.774750334875924, 0.9682781568595341, 0.1947689037770033, 0.054092608126146455, 0.025824250620124594, 0.018103616245623146, 0.012722068499507648, 0.06563029544694082, 0.01913180884106883, 0.03143546889935221, 0.052181907796433995, 0.029133097800825323, 0.049990799477589984, 0.04963990527072123, 0.1547983328678778, 0.04084240359121135, 0.07050506065466575, 0.04215068696066737, 0.01940953322420163, 0.034596756765885014, 0.023956520216805593, 0.03533010045066476, 0.030576460529118776, 0.027014613085027252, 0.017953137534537485, 0.032258179038763046, 0.016265059455430934, 0.11900768695133072, 0.04706989281943866, 0.01569285087420472, 0.044886506229106865, 0.03294198627450636, 0.018431318125554493, 0.05447258434391447, 0.06607443732874733, 0.07368211767503194, 0.028109731285699775, 0.03574720949732831, 0.08980047277041844, 0.04488238073619349, 0.025366926499243294, 0.06001066163714443, 0.03130707650312355, 0.03340172428371651, 0.06931022834032774, 0.04334680849154081, 0.016158064661015357, 0.008666831101956112, 0.025997526411499296, 0.05556417076981493, 0.02975739073008299, 0.02881887841171452, 0.008865231348733817, 0.04189038396413837, 0.05241688786606703, 0.036750165679092915, 0.002415744970286531, 0.00917963479046843, 0.047834374476224184, 0.07400155839111124, 0.017729906298752342, 0.028092867994148816, 0.0369492817803153, 0.05582453144182052, 0.042498877205486806, 0.03193407000175544, 0.03232124208339623, 0.049857708226357184, 0.025646601670554707, 0.025374521002439514, 0.025522355123289993, 0.012202858592250516, 0.05136091435062034, 0.04405822531719293, 0.029187421314418316, 0.019652353765975152, 0.02245618768834642, 0.06504994444549084, 0.003309857985836321, 0.04017261149627822, 0.02079136809334159, 0.11764759064785071, 0.031247324709381376, 0.07505648356995412, 0.024032366861190115, 0.03169958187001092, 0.015272854661036814, 0.03510052151978016, 0.015125865316284555, 0.05168193944596818, 0.01333833096681961, 0.10373529539044414, 0.04707256285473704, 0.025781521573662758, 0.05920510486300502, 0.03751991276762315, 0.0888013503115092, 0.9151717722415924, 8.442076921463013, 23.282565798078263, 37.35311262948172, 37.689263003213064, 29.953656332833425, 21.604893718447002, 12.77926754951477, 14.855041878564016, 19.4588748386928, 26.664290530341013, 26.549584456852504, 18.457345860345022, 9.209707822118487, 2.6409379797322408, 0.2413229878459658, 0.23102190345525742, 0.19045260681637696, 0.6703992752092225, 0.6387993565627507, 0.6861676690833909, 1.0662060678005219, 1.6975821426936557, 4.489718352045331, 3.8467216321400235, 4.455772493566785, 5.627269174371447, 6.507285015923636, 2.0054963401385715, 2.2315566326890672, 1.2318008563348224, 1.052571747984205, 0.3770523289484637, 0.7474756421787399, 0.297256447907005, 0.30554526884640965, 1.1763908181871687, 1.900948098727635, 1.560858747788838, 1.7161398040396827, 2.3591548715318953, 1.6554755164044244, 0.23583358526229858, 0.3193126086677824, 0.04051503758611424, 0.9924539795943669, 2.1508828358990804, 0.6543582188231605, 0.7078583708831242, 0.7456900094236646, 1.569928643958909, 1.949644765683583, 3.0269347301551273, 1.9563808270863123, 2.4837781957217624, 5.32594838312694, 7.333157454218183, 6.889875411987305, 5.138613224029541, 2.770386176449912, 3.6319690985339026, 2.9362950452736447, 0.972213442836489, 1.3775620119912284, 0.762019253202847, 0.07812652204717908, 0.5919473820499012, 2.160223820379802, 6.221241142068591, 13.963917170252119, 16.897780997412546, 20.81491654259818, 23.86268653188433, 13.674981542995997, 10.721152935709272, 15.131489855902535, 27.517145429338726, 29.86792251041957, 22.070006132125854, 10.971559933253697, 2.752977899142674, 0.18696486896702222, 0.052619742695242167, 0.047512100876442025, 0.03127573157793709, 0.029524754998939376, 0.034924139734357595, 0.07334650068410806, 0.011193106034105378, 0.01924376711914582, 0.011666764189223093, 0.03231537275548492, 0.033607537525572946, 0.06639347092381545, 0.010268533369526267, 0.035377163639558215, 0.024014738521405628, 0.07912509489272322, 0.04325365920418075, 0.03269768991906728, 0.035186681896448135, 0.03402446336778147, 0.058576537163129876, 0.011020298431893545, 0.012306838146676975, 0.0796615175370659, 0.11910520600421087, 0.023187994491308928, 0.03421494511089154, 0.03382011576156531, 0.03339553604434643, 0.013632341886737516, 0.05595059307026012, 0.03766201835657869, 0.02714962967937546, 0.025315120350569487, 0.038126930195306025, 0.07819506765476295, 0.01607059980077403, 0.005415272208795483, 0.0134019181797547, 0.00747272651642561, 0.02232187337774251, 0.012099536368623376, 0.14389187310423168, 0.06899018372808184, 0.15582020660596235, 0.09722165098147732, 0.07936037691043955, 0.11932355857321195, 0.24046138407928602, 0.09804554855717079, 0.1966915191816432, 0.1282569742096322, 0.18008517527154513, 0.106931297108531, 0.18700651744646685, 0.14194839953311852, 0.1511992338512625, 0.12695209708596977, 0.10352878325751849, 0.08857005129435233, 0.1774990883256708, 0.11940513205315385, 0.08901068515011243, 0.15464019349643163, 0.08916909593556609, 0.11557872380529131, 0.20507732991661343, 0.13199134596756526, 0.050731227067964416, 0.14639759436249733, 0.07829990810049431, 0.05247801708589707, 0.12265188140528542, 0.11849331669509411, 0.1299428894583668, 0.11386927696210997, 0.139988030440041, 0.05340894677543214, 0.1874161490372249, 0.14039198947804316, 0.14523056841322354, 0.15538985255573476, 0.13151913987738745, 0.09133810097617762, 0.11230033436524016, 0.11470365790384156, 0.20794929723654473, 0.1283932647534779, 0.2412622453910964, 0.17361845155911787, 0.10190553071775607, 0.13221364761037485, 0.12654170553599084, 0.08110839846943106, 0.8130364013569695, 7.652899656976972, 23.317781005586895, 42.73074388504028, 46.19091551644461, 37.49940000261579, 30.80447714669364, 25.001569237027848, 18.06651837485177, 20.452397755214147, 27.088790723255702, 26.13760839189802, 19.207461220877512, 9.74988683632442, 3.7732974120548795, 0.9705529319388526, 1.0655886552163532, 1.0227944829634257, 4.673466069357736, 4.714007071086338, 7.694429039955139, 6.547399137701307, 5.938746929168701, 10.961963602474757, 3.204399973154068, 6.671577777181353, 7.126329558236258, 7.554836256163461, 4.892779878207615, 4.477238518851144, 2.6233486149992262, 1.2972196659871509, 0.29018633014389444, 0.5892212997589792, 0.29163801510419163, 0.17882386009607995, 0.971471831202507, 1.5839745359761375, 1.06980490897383, 1.4088660350867679, 1.7145689683301109, 1.5001140130417687, 0.35682224162987297, 0.38944824093154495, 0.1497879760073764, 0.9714065832751138, 3.254049846104213, 1.4413398525544574, 0.8936686175210136, 0.7652187900883811, 1.8409187027386256, 1.712089221392359, 4.6677533473287305, 5.703340223857334, 5.6958878466061185, 6.798559146268027, 7.190464905330113, 12.747102601187569, 6.0163009847913465, 12.420563323157173, 10.06007092339652, 7.754622152873448, 9.000133650643484, 5.1245127235140115, 2.67379601086889, 0.885074890085629, 0.7485452304993356, 3.0283100392137254, 9.720152020454407, 12.44800523349217, 17.615675824029104, 24.795690638678415, 25.74263630594526, 17.19303948538644, 18.196269035339355, 23.61118085043771, 37.21902976717268, 36.90405055454799, 23.768182345799037, 10.5794609274183, 2.0638095310756137, 0.2661932776016848, 0.2228448372334242, 0.1534954642078706, 0.0837654737489564, 0.09145206093255963, 0.12192508897611073, 0.15844688351665223, 0.11392178200185299, 0.13282469553606852, 0.10129859471427542, 0.12526558472641877, 0.147801741159388, 0.22401969347681316, 0.12118304307971682, 0.11682049717221941, 0.13781541559313024, 0.12692982756665774, 0.10327241915677275, 0.155249558655279, 0.14761565971587384, 0.0834167135347213, 0.1235230660864285, 0.1913877230669771, 0.20450921968689986, 0.14619973355105945, 0.2119515139077391, 0.12337513188166277, 0.08867972290941648, 0.09442268724420241, 0.1565309584672962, 0.1985220302428518, 0.15276784396597318, 0.18469128810933658, 0.12025976047984191, 0.08622363648776497, 0.07425335595118147, 0.14854983958814824, 0.09018041166876044, 0.10744956215577466, 0.1396479486886944, 0.09147811667727572, 0.10676402465573379, 0.15365228722138063], [0.09415716970605509, 0.006272650398646614, 0.013455028812001859, 0.023115391244313548, 0.006184072316890317, 0.07483769673854113, 0.03599646594375372, 0.03400088766855853, 0.037484462705573866, 0.01553757322419967, 0.028537612075784376, 0.07472692589674677, 0.04409685431580458, 0.06736647656985692, 0.039415678541575155, 0.024937985498192053, 0.08353110775351524, 0.018783247098326683, 0.1294663136026689, 0.0387135169335774, 0.042983368172177246, 0.01784636665667806, 0.07384489822600569, 0.07252444193831512, 0.019696202395217757, 0.04130408221057483, 0.07264947558620147, 0.018400392195742046, 0.02528714095907552, 0.017715723220525042, 0.029710829657103335, 0.022087207130555595, 0.04518055955746344, 0.051148105412721634, 0.0712960289259042, 0.05015016021206975, 0.02374496656869139, 0.010952798616407173, 0.029481908905186822, 0.02971950133464166, 0.008811910370630878, 0.04556536015921405, 0.05275409941428474, 0.03859174703913076, 0.009493271487631967, 0.07142553411956344, 0.03125359098027859, 0.06107866218579667, 0.037285020907542536, 0.03732713757615004, 0.045149089103298526, 0.06329753276492868, 0.0476088056872998, 0.21494089492729732, 1.8283798098564148, 9.4281313930239, 21.219067198889597, 32.03431524549212, 32.38474416732788, 28.146023409707205, 23.752698285239084, 21.525173561913626, 15.41652580669948, 16.608042853219168, 18.027740478515625, 18.60974417413984, 16.68598427091326, 9.071059124810354, 3.088844916650227, 1.136409146445138, 0.17891700938344002, 0.6960713490843773, 0.9357764380318778, 1.5770859399012156, 1.5561181221689497, 2.6148761553423743, 3.3464839032718112, 4.279609603541238, 6.51930843932288, 5.4176333376339505, 0.7197270882981164, 1.6807038826601846, 0.7797485589981079, 1.0196280585868018, 0.777246501828943, 0.5553315696971757, 0.036783878691494465, 0.9363737659794944, 1.159434499485152, 0.5343465985996383, 0.05843893026134797, 0.19151531479188375, 0.013123613649180957, 0.09422668561871562, 0.02247417056267815, 0.13235090167394706, 0.10481089553130524, 0.8948884063533374, 3.0804831939084187, 1.426493072084018, 0.3996098185224192, 0.25005755200982094, 1.6512452576841627, 2.1047585223402296, 2.195799682821546, 1.1752649928842271, 1.2074802070856094, 4.1760362812450955, 6.363999264580863, 5.371362677642277, 7.403197033064706, 2.9633760835443224, 2.7226296876158034, 1.6390267418963569, 0.9976146455321993, 0.5838239065238408, 0.745791029717241, 4.450998646872384, 8.493587391717092, 18.13314117704119, 22.90130945614406, 15.024230514253889, 18.391436985560826, 19.101739168167114, 12.826438869748797, 15.535668304988317, 22.744657107761928, 25.646556615829468, 21.38710069656372, 11.961019022124153, 2.8121237882546017, 0.6814774721860886, 0.03396791425932731, 0.05231372679450682, 0.049784511261220486, 0.013343299539493663, 0.05200742590906365, 0.015590468421578407, 0.030810429581574032, 0.037167912548674006, 0.031796771833407025, 0.016541240171396306, 0.027945949895573512, 0.05344342653240476, 0.025535963143088987, 0.040118844381400516, 0.024420777269239937, 0.016767000646463463, 0.032386513759515116, 0.0733292591092842, 0.03693014030743923, 0.04114990548363753, 0.044885105054293356, 0.017043206807492033, 0.042032832213278325, 0.0028092747130098617, 0.044130855705589056, 0.0333824979939631, 0.044843422648097785, 0.01912422281956034, 0.048402019909449985, 0.0519038305750915, 0.0039393635483325595, 0.007214783973592732, 0.07882178973938737, 0.025415341669161404, 0.05657011589833668, 0.04664956073143652, 0.00634237241631906, 0.05324369635699051, 0.046223501807876995, 0.025096185937789933, 0.07551627246929066, 0.004698060694084103, 0.03412112068118794, 0.06958112666117293, 0.0775295537231224, 0.08513508311339787, 0.007706404646991619, 0.054891474545001984, 0.011030793672294488, 0.02375188423320651, 0.06892724281975202, 0.04351296475423234, 0.023451902205124497, 0.05656613629045231, 0.08507046622357198, 0.021581008132281046, 0.05376337954242315, 0.07166154216974974, 0.03690668674451964, 0.01625363462205444, 0.06781247763761453, 0.029750038803155934, 0.0840791469173772, 0.023492890809263502, 0.04365597279476268, 0.043971522112510035, 0.02922065256695662, 0.05755344206201179, 0.016865634193111743, 0.03532237193680235, 0.07111494150012732, 0.024840379932097027, 0.02040629947025861, 0.04816034269918289, 0.023701984767935107, 0.030827898465629135, 0.010617703249278878, 0.022313783543982675, 0.015030164737254381, 0.019817926488550644, 0.03242501722914832, 0.06344107006277357, 0.03903164129172053, 0.035609677234398465, 0.0516966907972736, 0.023535635122763257, 0.039389995991119316, 0.051613702571817806, 0.023023263152156557, 0.02756013658030757, 0.06093153543770313, 0.020623790299785987, 0.07121255554791008, 0.06987162107335669, 0.01998101407662034, 0.029286406002938747, 0.01647948839568666, 0.37333618264113155, 4.452811258179801, 15.879915067127772, 29.36918428965977, 36.629405634743826, 35.7506947517395, 28.846976791109356, 16.42796117918832, 16.521963357925415, 16.600465842655726, 22.740687949316843, 25.019752672740392, 28.37523753302438, 19.12540646961757, 9.678546207291738, 2.635084339550563, 0.4027520056281771, 0.09468428963529212, 0.23090253557477677, 0.5051363717232431, 0.7899994317974363, 1.019800026501928, 1.609079897403717, 2.8004738305296217, 1.7533752002886362, 1.7502969311816352, 4.7937793391091486, 2.7075038935456957, 3.4956921253885542, 2.7096743370805467, 2.2003179660865237, 2.3353518630777086, 1.2713788811649596, 0.45899430768830435, 2.5970668366977145, 1.2934661188295908, 1.3829426318407059, 0.5355111275400434, 0.3693404256233147, 0.2480241996901376, 0.5049127808638981, 0.4258453750184604, 0.8384837987167495, 0.9371215658528464, 1.9026907937867301, 4.3804192798478265, 3.1531897953578403, 1.0634096349988664, 2.045801103115082, 4.380293778010777, 2.865103151117052, 5.131189942359924, 2.197838761976787, 3.283835687807628, 4.120394238403865, 5.35297166449683, 3.049647957086563, 1.6868155832801546, 1.4061244279146194, 0.9667239316872188, 0.35129725666982786, 0.4644960324679102, 0.2763639747032097, 0.5378576102001327, 2.9555632684912, 6.610682896205357, 14.324309808867318, 28.005840029035294, 21.840559244155884, 16.349545546940394, 19.797828810555593, 12.816879885537283, 15.0414377280644, 20.179964099611553, 26.865095206669398, 29.033129453659058, 18.288650546755107, 6.019736434732165, 1.2743433735200336, 0.05849716213664838, 0.08058720893625702, 0.001689355739342448, 0.030505594331771135, 0.05979904692087855, 0.02598504475983126, 0.018453599519229362, 0.038447076587804725, 0.03398377162271312, 0.046370506419667175, 0.02249949348957411, 0.027353984070941806, 0.02174818728651319, 0.034740090503224304, 0.022139866537015353, 0.0490914013103715, 0.0459240371627467, 0.02057955999459539, 0.050486567696290355, 0.036529363598674536, 0.007329469114275915, 0.01609934593683907, 0.037859475439680476, 0.013733519091536956, 0.024356993281149437, 0.03680575466049569, 0.03475353567461882, 0.03537348597975714, 0.04255035426467657, 0.09271580526339156, 0.041348024138382504, 0.006746598627484802, 0.030683512999010936, 0.03171497782958405, 0.04356455037902508, 0.007016865062593881, 0.06660993716546468, 0.06004219315946102, 0.056340550538152456, 0.043097877741924355, 0.04540335313816156, 0.01814398229388254, 0.027309199063373462, 0.060013484342822006, 0.22683569522840635, 0.14934053644537926, 0.2277521789073944, 0.16365810031337397, 0.12936622968741826, 0.09989901445806026, 0.18203786334821156, 0.1501000885452543, 0.1290745681950024, 0.11492068054420607, 0.14694605421807083, 0.1870569461690528, 0.19939051435462066, 0.12037577639733042, 0.15065156109631062, 0.0827218054660729, 0.20430525206029415, 0.055250813120177815, 0.1910589864211423, 0.11471319810620376, 0.1299781868500369, 0.16707452413226875, 0.1919764064784561, 0.12980119777577265, 0.12629431166819163, 0.11391772436244146, 0.142044547945261, 0.11307220187570367, 0.10020978349660124, 0.1824160109141043, 0.14213970569627626, 0.09662249777466059, 0.11063803892050471, 0.16826156686459268, 0.11571570645485606, 0.1329602939741952, 0.15801522667918885, 0.21047989358859404, 0.13442123415214674, 0.16521430680794374, 0.15034680387803487, 0.09786323976836034, 0.12941770335393293, 0.1703505997679063, 0.1278294428650822, 0.1361298124705042, 0.18427010785256112, 0.19252060513411248, 0.20977999828755856, 0.1607155246394021, 0.17045831041676657, 0.1133842533454299, 0.11383988282510213, 0.43464800981538637, 3.8450453792299544, 15.33859133720398, 32.80730581283569, 44.26021957397461, 45.07859577451433, 38.61038221631731, 31.70658608845302, 30.081002916608536, 23.283477749143326, 23.963843618120464, 25.553396906171525, 26.74183590071542, 22.968812942504883, 12.402344277926854, 4.272099469389234, 1.5506720372608729, 0.42256191692181994, 1.8692495482308524, 2.4911736845970154, 3.718931232179914, 5.224576771259308, 8.067929455212184, 8.258943251201085, 12.598583119256155, 13.416455575398036, 17.42769925934928, 5.515390149184635, 6.263694635459355, 3.2102872686726704, 3.381534308195114, 3.001614191702434, 1.811339027115277, 0.4228534698486328, 2.5204481823103766, 4.238220053059714, 1.3224867901631763, 0.4603920898267201, 0.7813931107521057, 0.3119859503848212, 0.5024907365441322, 0.271248960601432, 0.6231788833226476, 0.747073406619685, 2.028125103030886, 4.366317042282649, 4.119487932750157, 1.4301043983016695, 2.307995068175452, 5.730962787355695, 5.936466182981219, 8.031317659786769, 3.036407296146665, 5.831133229391916, 12.464953626905169, 15.9156722341265, 10.668553335326058, 14.95637788091387, 9.913315415382385, 9.331298691885811, 4.557820686272212, 1.9526846025671278, 1.1342668214014597, 1.4800487011671066, 5.384933812277658, 10.356166669300624, 21.177523919514247, 29.657704762050084, 21.47461325781686, 25.824472188949585, 26.114866937909806, 19.749429396220616, 22.43932546888079, 31.2529034614563, 35.886132512773784, 32.87300797871181, 18.145918914249965, 5.645911625453404, 1.0459806216614587, 0.17828261985310487, 0.2262538243085146, 0.17872791524444306, 0.19371842300253256, 0.1411958092025348, 0.12270441358642918, 0.1668300615357501, 0.1204109787940979, 0.10509307788951056, 0.10383364904139723, 0.12997452276093618, 0.0895064499761377, 0.1272281115608556, 0.24550517914550646, 0.1295801717787981, 0.14379527685897692, 0.13427715402628693, 0.09223319044602768, 0.12415262444743089, 0.21327709992017063, 0.12325475976935454, 0.0757324740822826, 0.17304708436131477, 0.11527176813355514, 0.11519394016691617, 0.124964247324637, 0.1288900745234319, 0.11828073167375155, 0.32809914861406597, 0.1956609059125185, 0.18534390309027263, 0.0734720839453595, 0.08108412048646382, 0.11260338167526893, 0.12969141080975533, 0.14986534257020268, 0.12419957907072135, 0.1287088921027524, 0.15743741339870862, 0.078876500017941, 0.11781493095414979, 0.07080626913479396, 0.12495216940130506, 0.2235491701534816], [0.03648221559290375, 0.039754722134343216, 0.024304800367515002, 0.029688329435884953, 0.026819230622744987, 0.025854939062680517, 0.054793914780020714, 0.052397227313901694, 0.021737055919532264, 0.023192092842821563, 0.03362084698996373, 0.055842889206750054, 0.04018053339262094, 0.030302532549415315, 0.02712630503810942, 0.021102968337280408, 0.06961384561977216, 0.05006364021184189, 0.07292766137314693, 0.08682960218616895, 0.041559574393821616, 0.08710263789232288, 0.010276644407505435, 0.03196703662563648, 0.00289338527779494, 0.04103773346702967, 0.03990020343501653, 0.08140589536300727, 0.03617752283545477, 0.02677250330868576, 0.044857268155153306, 0.048837608857346435, 0.029971421031015258, 0.08716068656316825, 0.018611012858205607, 0.010130812813128744, 0.027381746331229806, 0.052043242380023, 0.06490730281387057, 0.017092797539329956, 0.02068218502349087, 0.040160462326769314, 0.06247875812862601, 0.010159605598476316, 0.05653652502223849, 0.016613638161548545, 0.028197560858513628, 0.018763861352843896, 0.027721563453919122, 0.0771812888394509, 0.04100749455392361, 0.073256262311978, 0.020438314448775988, 0.02771503085802708, 0.07275534061981098, 0.6871850916317531, 5.938787315573011, 17.72611744063241, 30.566824436187744, 33.85594184058053, 29.64206784112113, 27.850467886243546, 23.83351799419948, 18.457993779863628, 17.212841851370676, 18.735398871558054, 23.337083101272583, 20.703967707497732, 22.211014611380442, 11.15931155000414, 6.891896903514862, 1.9336539208889008, 0.8850821096982274, 0.11727915970342499, 0.19802513904869556, 1.4691884496382304, 5.535799614020756, 2.258763607059206, 2.1882309232439314, 2.9012574510914937, 2.264730155467987, 2.3495010009833743, 2.750953584909439, 1.8027847089937754, 2.1272439786366055, 1.3441349885293414, 1.5623724779912402, 2.186603524855205, 1.2339659801551273, 2.0545147955417633, 0.3748873679765633, 0.3070638845009463, 0.06407702022365161, 0.38720256143382614, 1.0256212055683136, 0.8865286377923829, 1.6317733653954096, 0.8069542848638126, 0.43659041130117004, 0.39085731389267103, 1.415386593767575, 3.309968731233052, 2.592871210404805, 3.076841469321932, 2.6029493553297858, 2.3657382896968295, 1.865844713790076, 3.445687677179064, 5.399376945836203, 2.1029969368662154, 0.9747398729835237, 0.2405007662517684, 0.2569709824664252, 1.1970972099474497, 2.043661492211478, 6.717664744172778, 14.119510786873953, 19.633663722446986, 25.395858662469045, 56.79860176358904, 23.398107392447336, 15.139888490949359, 14.319054365158081, 17.18921102796282, 26.541126762117656, 25.682984283992223, 26.972239903041295, 16.162852661950247, 6.883453105177198, 2.3216938759599413, 0.10752563271671534, 0.034680359065532684, 0.042975561626787694, 0.03929868892633489, 0.03965574423117297, 0.06278843472578696, 0.0314658469121371, 0.02238306705839932, 0.03545731219596096, 0.020027960218223076, 0.020474232699988142, 0.008891868089059634, 0.03306323030431356, 0.031598469974207025, 0.0231335132183241, 0.03416877419554761, 0.016586798708885908, 0.06453826118792806, 0.08118063530751637, 0.019386983809194396, 0.028431738560487117, 0.04787793642442141, 0.0893777793805514, 0.03773421448256288, 0.041623807911361964, 0.033612809742667844, 0.012988332426175475, 0.027969819061192017, 0.036787865084729025, 0.027600718063435385, 0.05123816736574684, 0.022237163369676897, 0.041926865399416, 0.013879190382015492, 0.04798408644273877, 0.06743202305265836, 0.032919659079717736, 0.04818398625190769, 0.07346277444490365, 0.05694821596677814, 0.036501336709729264, 0.09561944659799337, 0.1049817099368998, 0.034859071618744304, 0.10897133978349821, 0.028931108103798966, 0.016898851874949675, 0.0627279704702752, 0.0973881431190031, 0.04644586451883827, 0.05343285495681422, 0.040553815862429995, 0.01897443282151861, 0.04462528042495251, 0.02986992576292583, 0.014892778359353542, 0.033812567059482844, 0.034551722396697314, 0.016048181003757885, 0.06697205773421697, 0.03765663418120571, 0.0734629983614598, 0.04138913657516241, 0.02519831054710916, 0.037683673801698854, 0.06072796814675842, 0.03006973736254232, 0.04660655857462968, 0.06634302863052913, 0.05394489783793688, 0.03379284543916583, 0.022600944652887325, 0.02431979768776468, 0.0554647823529584, 0.02637596574745008, 0.0016873941370119739, 0.039726786847625456, 0.02723955931807203, 0.057362916214125495, 0.08523409494331904, 0.02264391627561833, 0.02799138968943485, 0.023203475267759392, 0.09238402878067323, 0.022112538539139286, 0.03962927797277059, 0.019339019865063683, 0.020739095451842462, 0.05508716743705528, 0.05540742239515696, 0.04013267971043076, 0.017927399004942605, 0.038267353017415316, 0.009373741606915635, 0.039218316453375986, 0.030176352177347456, 0.025552315837038413, 0.06163214998585837, 0.029224099524851357, 0.02948928458083953, 0.12801994835691793, 1.4643358928816659, 9.368127618517194, 24.323100226266043, 38.48805570602417, 38.58526447841099, 32.96345615386963, 28.34170205252511, 20.746806825910294, 13.986907022339956, 18.253207785742624, 22.951030765260967, 34.07829461778913, 32.01812941687447, 25.571403162819998, 13.515212059020996, 7.15477591753006, 1.841131057058062, 0.2611383545611586, 0.0828622690002833, 0.20822928792663983, 0.39829655470592634, 0.8630872070789337, 0.9892833211592266, 1.0570633241108485, 1.3166617027350833, 1.8154117571456092, 2.6999707434858595, 2.7755806062902724, 1.7095397753374917, 2.855098396539688, 2.5857729741505215, 1.7581156087773187, 2.0604033938476016, 1.8856142929622104, 2.323204674891063, 1.1635997274092265, 1.1269414659057344, 0.7775331693036216, 1.4927399115903037, 0.8183638783437865, 1.7255184607846397, 3.0125845287527357, 2.5531420622553145, 0.9727098047733307, 2.4519144083772386, 2.6037255993911197, 3.052909702062607, 3.4741129747458865, 3.81585556268692, 2.851685745375497, 2.412206973348345, 1.3406408045973097, 1.073038752589907, 0.9137626992804664, 0.4913244385804449, 0.06370566479329552, 0.18397153887365544, 0.09322279984397547, 0.42290810548833435, 1.1060441072498048, 6.219536662101746, 12.720332060541425, 25.756437165396555, 31.914795807429723, 51.34144837515694, 31.539620876312256, 16.222744396754674, 12.238507492201668, 16.642227990286692, 23.750483546938213, 26.40740520613534, 31.609929697854177, 24.263323136738368, 11.23680567741394, 4.0675418972969055, 0.31886510125228335, 0.03978381771594286, 0.03405508904584816, 0.027843957600582923, 0.007291909656487405, 0.031910311098077467, 0.015563248989305325, 0.009462981684399503, 0.0032662964617234786, 0.009629757110295551, 0.01965007558465004, 0.06847093480506114, 0.037154569157532284, 0.04398576456255146, 0.025927211523854306, 0.05970386202846255, 0.02485634246841073, 0.044423629995435476, 0.06162724417767354, 0.030401201719152074, 0.04011344663532717, 0.02112868651082473, 0.04786941063191209, 0.0367511291988194, 0.04130521536405597, 0.06229340271758182, 0.08578735882682459, 0.018141604028642178, 0.05480034389932241, 0.029813980550638268, 0.04405633559716599, 0.02231897603321288, 0.06480382622352668, 0.03026182044829641, 0.016790915613195727, 0.02106803565818284, 0.02775242831557989, 0.055572784771876674, 0.06790987455419131, 0.03107336868665048, 0.03254667855799198, 0.051649451189275296, 0.09216298921299831, 0.02262943464198283, 0.01033633343675839, 0.022066940985886112, 0.08866002503782511, 0.09868331719189882, 0.19373738127095358, 0.10028594226709434, 0.10238679525043283, 0.11496866654072489, 0.13539613969624043, 0.22331431561282702, 0.0652091084048152, 0.15034533824239457, 0.14171397925487586, 0.15286359882780484, 0.09684849743332181, 0.2576691135764122, 0.1338781618646213, 0.12493459534432207, 0.09042596670665912, 0.08248913580817835, 0.1277377049305609, 0.20743766826178345, 0.15508647954889707, 0.14643870001392706, 0.1553475662533726, 0.16065635638577597, 0.08783050919217722, 0.1834612533982311, 0.16431972623935767, 0.14034921463046754, 0.07399191640849624, 0.08096594682761601, 0.14067900979093143, 0.18072772079280444, 0.15883018794868672, 0.15319728877927574, 0.10685981344431639, 0.14524385412888868, 0.07936330139636993, 0.2001140226743051, 0.13223392223673208, 0.08993297030350991, 0.09890831261873245, 0.1797957258032901, 0.1666753419807979, 0.18511379829474858, 0.10272689735782997, 0.08565529555614505, 0.12738538240747793, 0.0855119957455567, 0.11704376233475548, 0.12286969114627157, 0.10261348701481308, 0.17060993585203374, 0.10427382149334465, 0.14291328990033694, 0.20742210266845568, 1.3694440190281187, 9.213268773896353, 24.705624614443096, 44.740836892809185, 48.11813735961914, 40.43444415501186, 37.75611162185669, 33.10399736676897, 27.455504485539027, 22.941824402127946, 25.29994920321873, 32.484211104256765, 29.76727090563093, 28.588300568716868, 15.465970924922399, 9.355523586273193, 3.137187442609242, 1.6094528202499663, 0.5643027797341347, 1.1555715181997843, 3.333774996655328, 10.203326276370458, 5.586562718663897, 7.371891924313136, 7.089475010122571, 8.53038157735552, 9.767096655709402, 8.68315943649837, 8.26676779133933, 6.696741112640925, 4.965476708752768, 5.438853570393153, 6.250757089682987, 5.039421609469822, 5.097591059548514, 2.545768286500658, 1.1572470111506326, 1.297600622688021, 1.9065151257174355, 2.799302624804633, 2.467783008302961, 5.3463044336863925, 3.949684815747397, 3.2058343419006894, 2.624878304345267, 4.096521530832563, 7.607754605157035, 6.491074434348515, 9.865449275289263, 8.283376591546194, 9.877863100596837, 6.758010762078421, 10.188979983329773, 10.343847513198853, 4.547631153038569, 2.343389626060213, 1.4786721978868758, 0.5877517014741898, 1.817142509988376, 2.8733856209686826, 8.858952334948949, 17.70432788985116, 25.919170924595424, 31.104847771780832, 61.530926023210796, 28.568684067044938, 21.17563922064645, 20.36032543863569, 24.89347611154829, 35.621614592415945, 36.921799727848594, 40.18401370729719, 26.506418773106166, 11.416324547358922, 3.3770568455968584, 0.21405133551784924, 0.09461638185062579, 0.12379186094871589, 0.17379371715443476, 0.12927255114274366, 0.20729668225560868, 0.14247502413179192, 0.04446300198989255, 0.12881513711597237, 0.09384644137961523, 0.07427325738327843, 0.2286256706076009, 0.10102665144950151, 0.10586253660065786, 0.13065714256039687, 0.11077160175357546, 0.14444163574704103, 0.2006068155169487, 0.15531224172030175, 0.08523133330579315, 0.08990513001169477, 0.16719094717076846, 0.13716335701090948, 0.12295294739305973, 0.12898554440055574, 0.25175166396158083, 0.1753807562802519, 0.06718983354845218, 0.193586868633117, 0.13987388727920397, 0.1369199664997203, 0.14127255151314394, 0.11738026142120361, 0.11946222398962293, 0.09267970720039946, 0.09703111156289067, 0.11087491549551487, 0.17467220287237847, 0.1590644046664238, 0.18152539299002715, 0.10493629558810166, 0.17219246950532707, 0.19144622635628494, 0.18288114666938782, 0.13324202171393804, 0.11061804249350514], [0.023479325197903172, 0.015163563025583113, 0.007172086309375507, 0.04955679151628699, 0.04828011430799961, 0.021526796576966132, 0.037058844829776456, 0.002332589019455814, 0.013605479533517999, 0.02605301870166191, 0.01716073416173458, 0.01714067327390824, 0.06636759838355438, 0.0376526749293719, 0.02858594073248761, 0.01663001799689872, 0.059862625652125905, 0.08113030836518322, 0.022249488958290646, 0.025235645240172744, 0.022679485081295882, 0.03303687600418925, 0.0703627040077533, 0.027094826102256775, 0.04780774536941733, 0.05530043777876666, 0.03603077945964677, 0.07221293329660382, 0.03160409842218671, 0.0765111812257341, 0.027751332481524775, 0.03762453268947346, 0.021503424438248788, 0.020806244973625456, 0.030123226278062378, 0.02664811087639204, 0.028777820257736102, 0.011598692707983511, 0.028474423502172743, 0.02072246795121048, 0.04290673442717109, 0.027420237926500182, 0.04674298482547913, 0.043406590819358826, 0.023506386870784417, 0.010807294415176978, 0.034896173913564, 0.04332947192181434, 0.07894431959305491, 0.04707555519416928, 0.026425817715270177, 0.011209071114925402, 0.01891848082388086, 0.056744591000356844, 0.06840821781328746, 0.11995030779923711, 0.11873962490686349, 1.9555394436631883, 10.178228514535085, 26.37764780861991, 33.31101199558803, 34.027058601379395, 28.621618918010167, 33.408203397478374, 19.283630847930908, 17.01942832129342, 15.713073185511998, 17.467008692877634, 18.425549166543142, 24.739915711539133, 20.230090141296387, 18.423556770597184, 9.772910560880389, 5.081850349903107, 2.2762302926608493, 0.8943580090999603, 0.3151782676577568, 0.1484966967254877, 0.30734838066356523, 0.36695939196007593, 0.8697375016553062, 1.830775418451854, 2.7082610300609042, 1.5598325857094355, 1.683086789080075, 2.253031994615282, 0.7864795721002987, 2.2426092624664307, 0.4748018394623484, 1.4102299447570528, 0.9686502111809594, 1.1789578518697192, 0.5275582085762704, 1.2505127894026893, 0.341036395835025, 1.7543197210345949, 2.3903918010847907, 2.082579003913062, 0.7876334616116115, 2.228973856994084, 1.807370628629412, 2.3275247173649922, 2.8798051050731113, 2.6020678026335577, 2.8368061780929565, 1.4381745138338633, 0.9471141610826764, 0.30284535086580683, 0.16092401130923203, 0.32602692980851444, 0.23528980729835375, 2.2102074239935194, 6.355777374335697, 11.546093446867806, 19.91534195627485, 25.416029282978602, 25.37063843863351, 20.466174295970372, 23.779264722551616, 54.386267117091585, 22.734481470925466, 14.324439219066075, 18.125664915357316, 23.818190268107823, 26.020347118377686, 21.314962761742727, 11.032362750598363, 4.82983614717211, 0.7042698977249009, 0.013363405380264988, 0.022103507238041078, 0.03315199625545314, 0.018178207600223165, 0.03835640395326274, 0.10152503542069878, 0.025195677831236805, 0.01370387474474098, 0.03424627646537764, 0.0220470158050635, 0.04371287474142654, 0.04017731713663254, 0.04287967784330249, 0.08546260518154927, 0.04391035557325397, 0.0880753585536565, 0.03856122314131685, 0.10116693177925688, 0.015637078688346913, 0.039051776818398914, 0.02604880160652101, 0.03144101592312966, 0.034916149984513006, 0.028050161000075083, 0.03848768690867083, 0.01508783342848931, 0.014805941144004464, 0.050541172801916084, 0.02519005277593221, 0.07028629417930331, 0.03593977773562074, 0.024313994517017688, 0.050327644616897614, 0.013717892430057483, 0.029139730480632613, 0.02268694218115083, 0.017153524727161442, 0.03221805047776018, 0.027428897729675685, 0.019309837770249163, 0.02987577473478658, 0.0311278279072472, 0.04180453232090388, 0.02181625452690891, 0.04559669490637524, 0.06329294586820261, 0.05263020570522972, 0.0322036316086139, 0.03538425433050309, 0.009752877289429307, 0.03457849060318299, 0.04099299765325018, 0.037026424426585436, 0.05477847132299628, 0.04303229393969689, 0.01917285512068442, 0.018997433462313244, 0.024174224784863845, 0.054992627152906995, 0.0291332606492298, 0.02776056225411594, 0.025097575238240615, 0.04351438628509641, 0.09773973282426596, 0.0231299475168011, 0.03754537140152284, 0.04373872014028685, 0.053792146034538746, 0.03481157077476382, 0.03484136524743267, 0.05458976734163506, 0.04882055048697761, 0.026375500950962305, 0.07140023154871804, 0.029019928337740045, 0.011347811170188444, 0.038773560497377596, 0.03843743460518973, 0.02622348366172186, 0.01276686622960759, 0.06487604949091162, 0.04504976175459368, 0.011374038244996752, 0.03388581830742104, 0.025948905984738042, 0.009523215238004923, 0.06692200899124146, 0.06723809095897845, 0.02090721607341298, 0.0989786224173648, 0.04368644580245018, 0.021229857778442756, 0.06516548538846628, 0.013035409185769302, 0.05490062119705336, 0.06956970691680908, 0.04579273385128804, 0.036823257471301725, 0.014504968454795224, 0.02531833151754524, 0.051204491672771316, 0.04925884000424828, 0.03151576334078397, 0.550279035099915, 4.814104991299765, 16.303409508296422, 32.60965388161795, 37.86863769803728, 37.24758686338152, 33.08410814830235, 32.48529849733625, 14.154639141900198, 13.373249939509801, 17.950740541730607, 23.20355783190046, 30.34710850034441, 33.16854265757969, 26.580559526171, 23.325469187327794, 13.095580816268921, 5.654909542628697, 2.374320400612695, 0.7123831680842808, 0.35452795188341824, 0.059469428179519515, 0.3128892976258482, 0.4769519812294415, 0.2552479649228709, 0.5774132162332535, 0.41604230819003923, 0.7830487904804093, 0.3384188248642853, 0.9121864352907453, 1.3040385629449571, 0.470352115375655, 0.7718608879617282, 1.174439242907933, 0.7789469648684774, 0.5427679238574845, 1.2997839855296272, 1.4365290935550417, 1.2649588542325156, 1.4172738982098443, 1.796382595385824, 1.00473752617836, 0.8435706943273544, 1.3641024827957153, 1.2657330355473926, 0.23023078590631485, 0.6806134528347424, 1.8322888229574477, 1.0478172259671348, 0.38618323898741175, 0.6762956902384758, 0.16634376905858517, 0.024557853217369745, 0.09085387124546937, 0.15854149843965257, 1.8645252074514116, 4.533956229686737, 12.320153168269567, 21.835756301879883, 30.08233002253941, 36.771920136043, 29.57543809073312, 27.388032266071864, 63.274972506931846, 21.409838676452637, 8.647445695740835, 18.560406752995082, 26.08402909551348, 30.277272156306676, 29.151337419237407, 17.60558703967503, 7.9452650887625555, 1.6091689211981637, 0.05942609693322863, 0.026089613791555166, 0.06484903022646904, 0.061984757493649206, 0.03090611319722874, 0.08621575869619846, 0.021286627410777977, 0.008059147861786187, 0.013623517538819994, 0.05575493749763284, 0.024499762138085704, 0.01684603470909808, 0.044645124181572876, 0.0212158545119954, 0.014037921775265463, 0.03404086695185729, 0.028516116086393595, 0.04162458822663341, 0.005715054493131382, 0.06450179671602589, 0.02865741421867694, 0.011296421472382332, 0.023481601682890738, 0.02238516033893185, 0.02570390734555466, 0.05086389084213546, 0.02532517284687076, 0.04147339705377817, 0.05207242617117507, 0.025522679123761396, 0.015954315861953155, 0.00648702632835401, 0.033458361601723094, 0.046162029927862544, 0.024407818946721296, 0.03714877446847303, 0.03631861062188234, 0.033064115792512894, 0.024477613058739474, 0.05357396309929235, 0.03159068039219294, 0.12190089241734572, 0.038889176079205105, 0.03395300345229251, 0.02225931584169822, 0.06525799006755863, 0.003746595566294023, 0.10748690872320107, 0.08924501043345247, 0.10158565573926483, 0.12610951944121293, 0.12774723156222276, 0.09654349594243936, 0.06730198860168457, 0.1374814270862511, 0.1339006892272404, 0.10898833708571536, 0.169387568586639, 0.17708488340888703, 0.1723613025886672, 0.21149920246430806, 0.11873144177453858, 0.13364161098642008, 0.2108091866331441, 0.19159460839416298, 0.1392184631632907, 0.10258394360010113, 0.189774343211736, 0.15284863034529345, 0.1404217771653618, 0.0952908049470612, 0.12985999962048872, 0.14897004275449685, 0.1195215822330543, 0.20565065129527024, 0.09189468968127455, 0.1566032903002841, 0.11194097543401377, 0.10924949842904295, 0.0955043670588306, 0.12951849294560297, 0.0956684300409896, 0.11413657904735633, 0.1666883019996541, 0.07661399285175971, 0.13557478439595017, 0.11957194310213838, 0.180894314710583, 0.13537814494754585, 0.1433825647192342, 0.1382831297814846, 0.08003244549036026, 0.1339822355657816, 0.10149990248360805, 0.1313635925097125, 0.2510324439832142, 0.2230594442891223, 0.1364443405930485, 0.10422834607639483, 0.07640276490045445, 0.21300369101975644, 0.2484799309500626, 0.3688733492578779, 0.36327166269932476, 3.667925374848502, 15.391580036708287, 35.88772365025112, 46.35741172518049, 47.03738328388759, 39.532397747039795, 43.78802694593157, 28.04773071834019, 25.02983624594552, 21.60830875805446, 25.725024359566824, 26.451281343187603, 33.75083644049508, 27.95393351146153, 25.568976504462107, 14.073460732187543, 6.7982364892959595, 3.4225388850484575, 1.5909650751522608, 1.159455995474543, 0.5853825286030769, 1.054902108652251, 2.069631252970014, 3.170698170151029, 4.794016012123652, 7.372503365789141, 4.436148175171443, 5.522433451243809, 7.970975160598755, 6.0550267696380615, 6.083694168499537, 3.610546065228326, 6.086240683283124, 5.260219292981284, 3.8241699508258273, 3.391420726265226, 3.8110847558294023, 4.687435856887272, 7.733113135610308, 6.287634653704507, 6.735143371990748, 4.976797929831913, 4.872908464499882, 6.105172787393842, 8.353131294250488, 9.285033243043081, 8.226878183228628, 8.19938155582973, 4.117943261350904, 3.939158294882093, 1.321260541677475, 1.0584769568272998, 0.7335646429232189, 0.618229648896626, 3.6405064804213385, 7.8492679085050305, 15.114428554262433, 25.05742927959987, 32.57460021972656, 32.27775233132498, 26.7323967729296, 28.852773325783865, 61.24488953181675, 26.596411841256277, 19.199284928185598, 28.489507607051305, 35.38421549115862, 36.590575626918245, 30.605776037488663, 18.629355464662822, 7.112600786345346, 1.2136777830975396, 0.088290379515716, 0.10336639625685555, 0.12611321067171438, 0.1188542837543147, 0.15487637796572276, 0.25614506964172634, 0.13144015840121678, 0.10635680864964213, 0.09779179681624685, 0.19174655952623912, 0.15673987939953804, 0.1590291072747537, 0.15503496517028126, 0.1948506265346493, 0.09506009625537054, 0.10274035949259996, 0.15744297738586152, 0.12838856929114886, 0.14627115614712238, 0.1585290405367102, 0.08332487381994724, 0.11765805365783827, 0.11477569118142128, 0.09289472137710877, 0.1515803669712373, 0.12776031371738228, 0.1258436015674046, 0.1720541433564254, 0.1409093045762607, 0.1261231851364885, 0.06609478659395661, 0.10371248982846737, 0.10489352074052606, 0.11569077707827091, 0.14966389909386635, 0.1777845887201173, 0.16996688821486064, 0.16557044269783155, 0.13359414067651543, 0.08503829687833786, 0.1379543931356498, 0.28279347398451393, 0.11282322023596082, 0.12732107085841043, 0.11264372736747776, 0.11780921768929277, 0.16176531330815383], [0.008509622171654232, 0.018207864669550742, 0.019852523292813982, 0.05622916901484132, 0.020489901769906282, 0.016192980376737456, 0.03360401592882616, 0.02381601257781897, 0.057256732269057205, 0.07174048971916948, 0.033630919842315574, 0.05691336980089545, 0.024783569587660686, 0.05786298295216901, 0.017272816272452474, 0.0477740730691169, 0.06613429090274231, 0.05670835044501083, 0.03438869078776666, 0.09060081839561462, 0.058455140462943485, 0.05498762634981956, 0.058977700636855195, 0.049142165907791684, 0.035430459172597954, 0.025297583613012518, 0.02893662459350058, 0.061231305423591814, 0.07007478124329022, 0.05565296386235526, 0.029562641001705612, 0.08064820923443351, 0.04397279436567, 0.030724601687065194, 0.06370334420353174, 0.03731741077665772, 0.008723654168924051, 0.020318402043942894, 0.08121062655534063, 0.025932621144290482, 0.03672958571197731, 0.009885584320207792, 0.032871842716953585, 0.06987225889627423, 0.017436774081683586, 0.03996273382966008, 0.03808555652254394, 0.03793167835101485, 0.028184558431218778, 0.03790419768275959, 0.04982345577861581, 0.04862191275294338, 0.04531144556988563, 0.0198830624576658, 0.028275256510823965, 0.022834167316822068, 0.030735417535262446, 0.0570860942825675, 0.8365788523639951, 7.09631073474884, 16.27628026689802, 27.559263672147477, 34.147651536124094, 35.80366434369768, 34.4294114112854, 24.862497568130493, 25.570143801825388, 18.930349690573557, 19.14643519265311, 18.48241322381156, 19.75088678087507, 19.438605206353323, 21.460673434393748, 17.156898430415563, 14.353670290538243, 8.611916082245962, 5.761018088885716, 3.336418786219188, 1.4852474736315864, 0.906884199806622, 0.15046659245022706, 0.2977489014821393, 0.23304863327315875, 0.15648313531918184, 0.45074524890099255, 0.43269019201397896, 0.8001055323651859, 0.28568416887095993, 0.5416210911103657, 0.6071383697646004, 0.1619330064526626, 0.7671989181212017, 0.9612547223057065, 1.106590952192034, 0.28128848331315176, 0.9939084329775402, 1.6076483513627733, 0.22221430178199494, 0.08381279478115694, 2.007098985569818, 0.9512881828205926, 0.49213965769324985, 0.5817050859332085, 0.6718251215560096, 0.5119464205844062, 0.3902136284325804, 0.12566502472119673, 0.6658448395984513, 3.421679045472826, 4.912860606397901, 12.438388926642281, 19.28239233153207, 24.225707326616558, 23.853167499814713, 19.646233013698033, 17.570952006748744, 16.339533192770823, 12.544304660388402, 22.567606585366384, 35.02507700238909, 27.68423570905413, 27.32274351801191, 28.660377706800187, 23.76077730315072, 17.94303846359253, 3.1685861349105835, 1.137800197516169, 0.5122546926140785, 0.07518683014703648, 0.045600979855018, 0.05654463690838643, 0.10592494825167315, 0.04695258090006454, 0.024853443427543555, 0.01788227812254003, 0.01530365675820836, 0.02642327660162534, 0.021520727081224322, 0.02310250586430941, 0.045089744430567534, 0.020919933515999998, 0.04229572721357856, 0.04324978816189936, 0.02020372453677867, 0.028219223088983978, 0.06660452924136605, 0.04856267664581537, 0.015565830815051283, 0.06664525491318532, 0.026982832201091305, 0.053640853081430705, 0.009157877565095467, 0.02693742803031845, 0.02035145178836371, 0.02275948435999453, 0.04163426413599934, 0.00715897192380258, 0.015596239361912012, 0.043356901699943204, 0.010158382539105202, 0.02791224027584706, 0.043591569643467665, 0.07463192420878581, 0.050904402775423865, 0.05507033298324261, 0.04393124766647816, 0.023228635346250873, 0.0461911662215633, 0.006835774668226284, 0.007184278735491846, 0.04222730374229806, 0.069024938291737, 0.05956860964319535, 0.02473603481692927, 0.04272287179316793, 0.039456170118813, 0.016897523642650673, 0.05976412272346871, 0.028746974055788348, 0.07429655149046864, 0.058919631609959264, 0.021460542721407752, 0.08079550561628171, 0.016648046672344208, 0.033377337735146284, 0.019823934916140776, 0.030524840977575098, 0.02704505216596382, 0.03231068407850606, 0.05644440710810678, 0.08931391566459622, 0.0405325268262199, 0.052435822385762415, 0.06333259266934224, 0.06022655790937798, 0.027796314264248525, 0.08715283591300249, 0.0644580719194242, 0.04574586743755, 0.028611803094723394, 0.05970509696219649, 0.019431492313742638, 0.035425614432564805, 0.04537138735343303, 0.022069405764341354, 0.049653408117592335, 0.03112738685948508, 0.05558636225759983, 0.06144579712833677, 0.024323960500104085, 0.04632574346448694, 0.05062880899224963, 0.008667995637681867, 0.02621021490943219, 0.07359164181564536, 0.023421047521489005, 0.015850376171459044, 0.02892763400450349, 0.06089055870792695, 0.06711163917290312, 0.010361642792953976, 0.03159470749752862, 0.0214600168567683, 0.06102030138884272, 0.013366428253773068, 0.02552920832697834, 0.027357329248583744, 0.02885817237464445, 0.03903569893113204, 0.0392672591842711, 0.0015691994859870257, 0.051824330019631555, 0.02729927548872573, 0.13635805808007717, 1.9749051587922233, 12.029596873692103, 23.708478212356567, 34.90546028954642, 36.1947853905814, 40.62009654726301, 35.49510179247175, 21.23416563442775, 17.72117379733494, 15.453429426465716, 16.45785927772522, 22.71907036645072, 26.33504840305873, 29.904369286128453, 28.686051300593785, 24.34975699016026, 20.415765115192958, 11.568463172231402, 6.8013284376689365, 2.7549188349928175, 1.5080263827528273, 0.7339289890868324, 0.14730985755366938, 0.13488556923610823, 0.18112756790859358, 0.0988943822947996, 0.2795900287372725, 0.15445955390376703, 0.5471863267677171, 0.3466131394462926, 0.27621480556471006, 0.10284370716129031, 0.35013164207339287, 0.182382342006479, 0.08662410785577127, 0.22051918559840747, 0.09533301661057131, 0.1558980481433017, 0.2573343243982111, 0.34728146929826054, 0.046823825487600904, 0.3542048606489386, 0.39249768587095396, 0.1378381193748542, 0.2910397100661482, 0.19431949646345206, 0.14363164135387965, 0.16318191800798687, 0.18459690388824257, 0.9357811063528061, 3.013310398374285, 5.3408796276365, 11.846651673316956, 20.946029050009592, 33.03740930557251, 32.167442730494905, 32.271582330976216, 26.909506355013164, 21.79549149104527, 13.166748608861651, 21.308487040655955, 40.40690149579729, 22.70783339227949, 20.85528210231236, 31.465990815843853, 27.95964319365365, 23.963385037013463, 8.516122136797224, 3.098703976188387, 0.8817303638373102, 0.09506352285721473, 0.03285931356783424, 0.05535597926271813, 0.13687879299478872, 0.05318533216736146, 0.009827623858914843, 0.09187351938869272, 0.022476983090330447, 0.04141240693362696, 0.029237514162170034, 0.022619260009378195, 0.011721208142781896, 0.06892105458038193, 0.013584439010758485, 0.037442519063396115, 0.05012697806315763, 0.04641133047906416, 0.030039508627461534, 0.02238347248307296, 0.010003510313773794, 0.03073288659964289, 0.0555692088923284, 0.024593432201072574, 0.06517395350549902, 0.04567654490736978, 0.070529630407691, 0.03164545173889824, 0.04903849932764258, 0.025859414001128504, 0.0905103086094771, 0.035671695335102935, 0.010338781251838165, 0.029142739783440317, 0.05378203247008579, 0.041070679734860144, 0.05192987274910722, 0.07654668896325997, 0.047695149268422804, 0.04243628913536668, 0.0030435050014472964, 0.07399789430201054, 0.03791926794552377, 0.02797769006740834, 0.04011445425982986, 0.04194964381999203, 0.01962418438467596, 0.08835631954882826, 0.017589310450213294, 0.10968874807336501, 0.16444013906376703, 0.10543498490005732, 0.17647934518754482, 0.08138083706476859, 0.11260335453386817, 0.13552706981343882, 0.10697506261723382, 0.16446633051548684, 0.1863531425063099, 0.17960627882608346, 0.156916312075087, 0.17518197266118868, 0.1575040998203414, 0.15759072160082205, 0.14130205421575479, 0.20060372139726365, 0.20978139606969698, 0.1497390264911311, 0.17841230146586895, 0.2112726667629821, 0.15049165753381594, 0.15788212524993078, 0.11507641790168625, 0.17575008289090224, 0.21916154559169496, 0.1256326043180057, 0.28601656960589544, 0.13837512555931294, 0.18105337688965456, 0.07352237017559153, 0.2552424280771187, 0.12585582876844065, 0.0764855733141303, 0.12123292897428785, 0.12509619524436338, 0.07925822346338204, 0.14045992440411023, 0.14921050199440547, 0.10033966866987092, 0.10251990346504108, 0.10117921326309443, 0.15008501149713993, 0.1852390422884907, 0.14803727423506124, 0.12017232445733887, 0.13511882243411882, 0.1320231556892395, 0.10646829195320606, 0.1751865731286151, 0.19498839628483566, 0.11762783170810767, 0.263316560536623, 0.1275834467794214, 0.13793498703411647, 0.14719708503357, 0.14409257019204752, 0.19116463432354586, 1.6446918036256517, 10.418538911002022, 23.79352763720921, 37.72302082606724, 46.08082478387015, 49.74311603818621, 46.52676016943795, 34.342635359082905, 33.19842685971941, 26.726735728127615, 26.133053847721644, 27.3757461139134, 30.380692618233816, 28.815067189080374, 32.51335532324654, 26.188338926860265, 21.294649703162058, 12.503965156418936, 8.302065508706228, 4.729170211723872, 2.3436289046491896, 1.5626974148409707, 0.5836055268134389, 0.8153397291898727, 0.8689297192863056, 1.3563510073082787, 1.4792548694780894, 2.306053263800485, 1.9743019683020455, 2.127218791416713, 2.3897004553249905, 2.767499851328986, 1.6203272938728333, 2.0218747641359056, 2.8834846104894365, 3.6955431614603316, 2.641197668654578, 4.663869738578796, 4.761966143335615, 2.866513201168605, 1.3403067482369286, 6.0099082078252515, 3.1595602078097205, 2.157304708446775, 2.1267704154763902, 1.9669835610049111, 1.6726661196776798, 0.9627582473414285, 0.5942883821470397, 1.1770611022199904, 4.3829701372555325, 6.42022191626685, 16.024100610188075, 24.74464222363063, 32.29461908340454, 30.472255979265483, 26.94726460320609, 23.126566580363683, 22.45063713618687, 18.01277232170105, 29.90239599772862, 42.47721454075405, 33.85418742043631, 35.37180600847517, 39.4754433631897, 33.075735569000244, 25.44905580793108, 8.606109993798391, 2.3926393261977603, 0.5354129299521446, 0.17328892781266145, 0.14957715517708234, 0.15056263229676656, 0.19638289431376116, 0.1384330860206059, 0.17984706376280102, 0.15065038044537815, 0.21310182075415338, 0.10860798428101198, 0.12690325613532746, 0.09893964736589364, 0.10878521762788296, 0.12280829729778425, 0.12978715210088662, 0.15225647283451899, 0.10858738395784583, 0.1160321616168533, 0.17134496569633484, 0.18751657221998486, 0.09609167982957192, 0.1536684634962252, 0.18095161020755768, 0.1586349191410201, 0.1458741317370108, 0.13313446034278187, 0.11949885130992957, 0.09073044572557722, 0.13050143234431744, 0.11960074012832982, 0.18741188783730778, 0.20851629466882773, 0.09992316351937396, 0.14518341022942746, 0.11915203849119799, 0.2922374600810664, 0.1657301698412214, 0.17115397165928567, 0.14041233195790223, 0.15427990497222968, 0.11201344297400542, 0.09136272501200438, 0.11867329132344041, 0.18511531821319036, 0.16413828597537108, 0.20449628680944443, 0.1765459230435746, 0.27867742627859116, 0.18402378607009137], [0.0137760064098984, 0.05470672303012439, 0.08407772199383803, 0.03120762701811535, 0.025324056656765084, 0.042410918711019416, 0.016438335246805633, 0.01014976599253714, 0.012395662621461918, 0.03968741146049329, 0.12685513443180493, 0.02792694921871381, 0.04021756104858858, 0.023747037796835815, 0.020388029914881502, 0.03748420486226678, 0.050356492533215454, 0.028295079911393777, 0.05398942669853568, 0.012853428638274116, 0.02652251234810267, 0.08460313880017825, 0.04455952359629529, 0.049896662921777794, 0.015915344203157083, 0.03291188646107912, 0.052725604336176596, 0.046366411460829635, 0.08008299634924956, 0.05174064290310655, 0.01939385397625821, 0.10698207188397646, 0.056511758494057825, 0.12048488482832909, 0.05800942437989371, 0.03019454370119742, 0.026810185750946403, 0.03830100835434028, 0.01445095197829817, 0.040457375680229495, 0.07273752907557146, 0.05273503936561091, 0.052316786987440925, 0.026050547137856483, 0.052248634930167875, 0.024272483440914323, 0.04105452381606613, 0.09318797064146825, 0.07513001640992505, 0.009925421959321414, 0.032616292858230214, 0.09005422451134239, 0.05672274895810655, 0.01076164427545986, 0.03531341527455619, 0.02588201260992459, 0.027380170433648994, 0.07024419786674635, 0.11588517736111369, 0.1715628161494221, 1.5110719736133302, 7.641208444322858, 18.641455752508982, 29.205470834459575, 33.17235027040754, 39.23482377188546, 32.70398262568882, 31.09956019265311, 31.040066242218018, 24.820016281945364, 21.54218101501465, 15.814813920429774, 21.397425719669886, 22.348519461495535, 17.24491647311619, 16.973007406507218, 12.56974983215332, 17.505390541894094, 14.023342507226126, 9.228723304612295, 6.716084897518158, 3.7358288168907166, 2.4337724447250366, 0.974130385688373, 0.5935159378818103, 0.32554706984332626, 0.2788222256515707, 0.06898471473583154, 0.16324367826538427, 0.07219191228172608, 0.2389949613383838, 0.24598666759473936, 0.34211570077708786, 0.4606383708970887, 0.1941216220813138, 0.09043752894337688, 0.11599951051175594, 0.09782805094229323, 0.28192074224352837, 0.2006128951907158, 0.22166011509086403, 0.1228719845946346, 0.4320002576070172, 0.928681458745684, 1.8935354564871107, 5.55872997215816, 7.321339436939784, 12.917778151375906, 13.9216981785638, 21.222478764397756, 21.61433458328247, 20.09502237183707, 17.696769986833843, 18.15058810370309, 21.57133913040161, 18.448542492730276, 17.308622768947057, 16.10977189881461, 25.118922574179514, 28.9711480481284, 30.791157449994767, 30.928665774209158, 20.511726685932704, 11.465172120503016, 3.7631834404809132, 0.42185594194701737, 0.02624303734462176, 0.08274358644017152, 0.0845792136554207, 0.01822029203841729, 0.018814076336898973, 0.021669456868299415, 0.032937467231282165, 0.033927378577313254, 0.06093493489814656, 0.040971420239657164, 0.025737868023238013, 0.04602199387071388, 0.05236154654994607, 0.009593396114983728, 0.027024808073682443, 0.017597037267738154, 0.0152127194950091, 0.016603680660149882, 0.049366282631776164, 0.047776715963014534, 0.024693712891478623, 0.03726948245561548, 0.0691509015325989, 0.056502089370042086, 0.06957548803516797, 0.024529982391478758, 0.03890736760305507, 0.058896737838430066, 0.03502886822181089, 0.03427559257085834, 0.027730698231607676, 0.03247688105329871, 0.06111355245645557, 0.05492507220645036, 0.030372133278953176, 0.007660661208709436, 0.022422964917495847, 0.006495569932407567, 0.07712478722844805, 0.04825040804488318, 0.03436064015009573, 0.07843722323221819, 0.009123461420780845, 0.046521066554955075, 0.03744416111814124, 0.017796701285988092, 0.024333037602316056, 0.017190160529155816, 0.032150587133531056, 0.041223489213734865, 0.068500220376466, 0.03657457438696708, 0.057311788600470336, 0.042526646251125, 0.05442399445122906, 0.026623773521610668, 0.0313826585188508, 0.034337882085570266, 0.02487442542665771, 0.02378512905644519, 0.06997604761272669, 0.04919414847557034, 0.06377421718622957, 0.04510720992194755, 0.0371609372086823, 0.027498311862083416, 0.030541960416095595, 0.057545163934784274, 0.012048561425347413, 0.044976194987871816, 0.0029333603202498382, 0.01869431320976998, 0.04522804004539337, 0.0302140821170594, 0.03322360205597111, 0.02317923630055572, 0.06119992317897933, 0.05924099258014134, 0.0775823573182736, 0.013426950184761413, 0.04269935716209667, 0.026791568446372236, 0.039921085350215435, 0.052501565643719265, 0.03420926916546055, 0.026083861510934572, 0.016620910360610912, 0.027043985169646994, 0.02420415496453643, 0.04711534109498773, 0.08984340368104832, 0.044530448370746205, 0.0579584256878921, 0.01777436052049909, 0.06632763945630618, 0.05489642106528793, 0.03783700914521303, 0.11932585202157497, 0.07123055029660463, 0.01981267293116876, 0.03428971288459642, 0.047886737023613284, 0.07934381387063436, 0.04987902779664312, 0.01742875379776316, 0.04737292316609195, 0.03783433910991464, 0.04060358640604785, 0.035155235191008875, 0.4343654949750219, 3.0950355444635664, 12.377348133495875, 26.58480487551008, 36.7983615057809, 40.37813595363072, 41.32333067485264, 33.99490928649902, 28.211068970816477, 25.04833061354501, 19.894518205097743, 19.346065623419626, 14.270331859588623, 22.363789864948817, 25.9507018498012, 25.261207784925187, 26.004595552171978, 23.609271832874843, 22.638790879930767, 13.461470348494393, 11.840322732925415, 7.7957780701773505, 4.173448511532374, 1.9943549036979675, 1.6723068760974067, 0.4219995470983641, 0.20633612094180925, 0.058988835396511216, 0.09245028772524425, 0.09973353333771229, 0.1145435914929424, 0.11535193026065826, 0.04987546888047031, 0.11923695036343165, 0.08357996227485792, 0.21468378443803104, 0.15982163617653505, 0.1591707853866475, 0.10141620518905775, 0.15337800979614258, 0.15166841367525713, 0.17967420018145017, 0.24190454663974897, 0.3621634521654674, 1.248269932610648, 2.7431403355939046, 5.572622460978372, 10.080132109778267, 15.31545557294573, 20.11002700669425, 26.776432718549454, 29.699261937822612, 29.727363927023752, 23.988308225359233, 22.972393001828873, 16.871358735220774, 13.651910049574715, 13.493263568196978, 11.532252635274615, 22.210217305592128, 32.033457142966135, 32.70191206250872, 35.09784548623221, 28.06780927521842, 16.406981093542917, 7.182551341397422, 0.9338337651320866, 0.06570477145058767, 0.060119125459875376, 0.12884185782500676, 0.028317663253151944, 0.04856777244380542, 0.04908284837646144, 0.031423441866146665, 0.010607339475037796, 0.04374109501285212, 0.0210237273214651, 0.004076478936310325, 0.031314452178776264, 0.026419831340068152, 0.007980403024703264, 0.009810268629475363, 0.03935556033892291, 0.05239686429766672, 0.05081740440800786, 0.04912177932315639, 0.057681230562073846, 0.01674901777213173, 0.058152507059276104, 0.05151330313778349, 0.03500243589015944, 0.012616105078320419, 0.05292198594127383, 0.07740561930196625, 0.07317109259643725, 0.02425621047482959, 0.11775338782795838, 0.010393705268922662, 0.07865138924015419, 0.10542041675320693, 0.06601520122161933, 0.05982147250324488, 0.07597657026989119, 0.029701106250286102, 0.039605281581836085, 0.06242192403546401, 0.06808124535850116, 0.06037189332502229, 0.04894924822396465, 0.02151209781212466, 0.05549888552299567, 0.04248371194782002, 0.02002568882224815, 0.02659230137110821, 0.026682130925889527, 0.022375813519049968, 0.026046241833163158, 0.11156518916998591, 0.08775344797010932, 0.1629272773861885, 0.16252696886658669, 0.15670672617852688, 0.15748463943600655, 0.16477754738714012, 0.0872941544013364, 0.14384099654853344, 0.17014123100255216, 0.19358779144074234, 0.16100764753563063, 0.13801147150141851, 0.21754784003964492, 0.12946473940142564, 0.07972831930965185, 0.1361382941582373, 0.15914923511445522, 0.10910153029752628, 0.15724802070430347, 0.0784275880349534, 0.11241364971335445, 0.11332510544785432, 0.12911203689873219, 0.09987382723816804, 0.16940823676330702, 0.15125849709979125, 0.24373536982706615, 0.22456173439111027, 0.14249478307153496, 0.18485291515077862, 0.17516655634556497, 0.17903731364224637, 0.18179954827896186, 0.1272865469966616, 0.10784364850925547, 0.07390448717134339, 0.07025848781423909, 0.05402418465486594, 0.1254018616995641, 0.23500498543892587, 0.21471212006040982, 0.11052737664431334, 0.1737781379904066, 0.13740198420626776, 0.17827044693487032, 0.16704270083989414, 0.195292773523501, 0.18380190511899336, 0.11631178589803831, 0.16757440088050707, 0.21368750504084996, 0.14220200878168854, 0.12575396709144115, 0.137079761496612, 0.183900170560394, 0.17346502122070107, 0.1098772111747946, 0.15174105763435364, 0.30011430169854847, 2.179340268884386, 11.393099325043814, 26.62663303102766, 40.59766428811209, 46.22907154900687, 52.35577072416033, 45.87636709213257, 41.51290879930769, 41.66518551962716, 33.49095296859741, 29.74273681640625, 24.055726596287318, 30.56341634477888, 34.56880269731794, 28.80606927190508, 27.144697666168213, 21.225287573678152, 25.940851041248866, 19.521627494267054, 13.839705092566353, 9.541737045560565, 5.290296741894313, 3.3002390818936482, 1.5925025812217166, 1.1393854724509376, 0.6870796744312558, 0.6731515760932649, 0.5139256258096013, 0.47090216300317217, 0.41647073520081385, 0.5930720674140113, 0.6320259485925946, 1.0110530044351305, 0.87614406645298, 0.8497087763888496, 0.45064664419208256, 0.4473646245896816, 0.386346983058112, 0.4583577332752091, 0.4126652665436268, 0.57346560806036, 0.3758566145386015, 0.9688548573425838, 1.791859209537506, 3.435053676366806, 7.588204111371722, 10.635846427508763, 18.00111845561436, 20.323196002415248, 29.107193776539393, 30.0097838810512, 29.357747554779053, 25.287088087626866, 25.278503588267736, 27.548405374799454, 24.82016393116542, 24.79461019379752, 23.579471009118215, 33.45601395198277, 37.75451353618077, 40.78220844268799, 43.0114927973066, 30.599331583295548, 17.317905562264578, 6.074403124196189, 0.8656992412039212, 0.2106064132281712, 0.13665721059909888, 0.21879899076053075, 0.11253294974033322, 0.21700768545269966, 0.14894926601222583, 0.12224784094308104, 0.1361751521804503, 0.17675093561410904, 0.10217064792024237, 0.14837732884500707, 0.09508725122681685, 0.12451439217797347, 0.1034953925492508, 0.08051165406193052, 0.14561698053564343, 0.11046108377299138, 0.1529406804059233, 0.12883869585181984, 0.10301401266562087, 0.11107682716101408, 0.17633061031145708, 0.1698047454868044, 0.22081243486276694, 0.10827553604862519, 0.11672901708100523, 0.11120353000504629, 0.1146409341267177, 0.09994759078004531, 0.1657053218888385, 0.09615989974034683, 0.17659704387187958, 0.14325843352292264, 0.22753986530005932, 0.18974626543266432, 0.1443161474806922, 0.10483631345310382, 0.07240537261324269, 0.20641282254031726, 0.19533070363104343, 0.11245411754186664, 0.15018915305180208, 0.10004947281309537, 0.19312626549175807, 0.20564071754259722, 0.14887510213468755, 0.11891052073666028, 0.16219668516090938, 0.22790075093507767, 0.17196570310209477], [0.02620161956708346, 0.043647223085697205, 0.019601936917752028, 0.034677926517490826, 0.0069187442339690665, 0.09825935494154692, 0.008047367645693677, 0.06666628949876342, 0.051208423783204386, 0.06572037097066641, 0.09157942874091012, 0.027407681635980095, 0.02394779086379068, 0.041032878548971245, 0.022810674738138914, 0.04446319876504796, 0.04223503904151065, 0.044054527301341295, 0.04214594739356211, 0.03810695751703211, 0.05677973911432283, 0.02039982794251825, 0.03726295834141118, 0.11216104469661202, 0.10198468861303159, 0.08509968394147498, 0.0648990043305925, 0.07307321391999722, 0.028004288640139357, 0.04195792194721954, 0.06123376850570951, 0.02355517862763788, 0.009829133599331337, 0.06583268208695309, 0.06851519564432756, 0.008855893858708441, 0.017525463697633574, 0.039147745418761454, 0.013567089718500418, 0.022518648533150554, 0.0595036738419107, 0.04866773422275271, 0.03138668562418648, 0.061449162662029266, 0.07172027616096394, 0.057357230090669224, 0.02959093251930816, 0.009202120592817664, 0.03766538728294628, 0.11537970948432173, 0.05329950246959925, 0.030246807861008813, 0.11414316083703722, 0.08923422172665596, 0.02998718000682337, 0.0237601725384593, 0.01218786127200084, 0.03295154683291912, 0.06029943935573101, 0.07593332044780254, 0.09210652831409659, 0.11952614198837962, 2.1524859155927385, 5.715890841824668, 14.09247100353241, 23.757732255118235, 35.055489267621724, 32.237647329057964, 34.325438567570274, 32.52595240729195, 29.445333072117396, 29.46748045512608, 24.52421757153102, 24.05987467084612, 23.53954666001456, 20.10526749065944, 13.15594937120165, 16.557723999023438, 37.44142075947353, 22.926163162503922, 19.79530487741743, 19.283630847930908, 13.968604598726545, 13.664964846202306, 12.835644364356995, 8.31513159615653, 8.251494782311575, 6.976037417139326, 5.372275497232165, 5.054323758397784, 4.015894200120654, 3.6378438004425595, 3.03550728729793, 3.0930299035140445, 3.173102681125913, 3.734857371875218, 3.324376255273819, 3.771827433790479, 4.32826566696167, 5.52055743762425, 6.568573338644845, 10.566360098975045, 14.192684871809822, 15.31418752670288, 16.16094364438738, 20.788601977484568, 17.205940553120204, 18.393849747521536, 22.16225389071873, 22.746213504246303, 20.020230225154332, 21.808248383658274, 24.13286897114345, 22.561664138521465, 26.420631102153234, 27.328609534672328, 28.39199311392648, 30.796201842171804, 33.486144815172466, 33.180576937539236, 28.706379992621287, 12.292513234274727, 3.5849593239171162, 0.9459826903683799, 0.0712630453386477, 0.04060470259615353, 0.021016519583229507, 0.04159581155649253, 0.022860557240034853, 0.017806926808719124, 0.07005034719726869, 0.04522809772086995, 0.03181015932932496, 0.04233321966603398, 0.10843735986522265, 0.02335773341889892, 0.04198361128302557, 0.06534405544932399, 0.06436702609062195, 0.07052085694989987, 0.06189088895916939, 0.03986322327650019, 0.04351279851315277, 0.05279428565076419, 0.015763108086373125, 0.029714860155114105, 0.01718340571304517, 0.05693085904100111, 0.040327639784663916, 0.018165432482159564, 0.03858877844842417, 0.0353547278791666, 0.0903557858296803, 0.08825960116727011, 0.01379770935246987, 0.030393391781087433, 0.06335697921791247, 0.06286831865353243, 0.041613124377493343, 0.09187741417969976, 0.059387542573469024, 0.0855760562366673, 0.03242459314476166, 0.043573890413556776, 0.04965089075267315, 0.039582811894693544, 0.05764161768768515, 0.027619934175163507, 0.043597296479025056, 0.0458610826837165, 0.050567293007458956, 0.04416495548295123, 0.03173661291865366, 0.05228327753554497, 0.07045267775122609, 0.0443010221102408, 0.007091246071338121, 0.0332888228419636, 0.04598971935255187, 0.025043723306485584, 0.01765150497002261, 0.05525130845074143, 0.026092723178278123, 0.052668488650981865, 0.028425921819039753, 0.0276228484830686, 0.10210079952542271, 0.045279927618269405, 0.03582861673619066, 0.06497107153492314, 0.012694394448772073, 0.026209375222346613, 0.01990382732557399, 0.03638287128082343, 0.04788179728867752, 0.0339005459100008, 0.032928354505981715, 0.058278321022433896, 0.08113142794796399, 0.08576452612344708, 0.13595760028277123, 0.20892976676779135, 0.08507102940763746, 0.038282521667757204, 0.10802848144833531, 0.041205094129379304, 0.031655660298253806, 0.01512996875680983, 0.038683542649128606, 0.08626297116279602, 0.031941588169762065, 0.023070012518603886, 0.044052505266985724, 0.009800476520987493, 0.026972545610208596, 0.04881795848320637, 0.04186504068119185, 0.05557466770655342, 0.028038793842175176, 0.11362224950322083, 0.0349683666468731, 0.0693821394816041, 0.02694201492704451, 0.10257955347853047, 0.07298587967774697, 0.02894923516682216, 0.0028727679912533078, 0.07544449703501803, 0.04297378725771393, 0.05102610481636865, 0.045859301529292545, 0.06783701346388885, 0.046932747321469445, 0.07658664789050817, 0.03576514317787119, 0.11255224049091339, 0.062581474759749, 0.3715196358306067, 4.083399857793536, 10.548757706369672, 21.783068111964635, 32.85184376580374, 41.757968289511545, 40.15109314237322, 38.64830201012747, 35.32419000353132, 28.913029841014318, 24.093010629926408, 22.511584997177124, 22.057124171938213, 15.943282638277326, 17.952317782810756, 17.02948410170419, 24.923561811447144, 37.95935337884085, 27.754761661802018, 27.05641906602042, 24.494527918951853, 21.078800439834595, 15.760327884129115, 15.45974360193525, 12.349796789033071, 11.513540267944336, 7.959177119391305, 6.776412631784167, 5.769242584705353, 3.8062492438725064, 4.283887956823621, 3.117005314145769, 3.4428723539624895, 3.184468848364694, 3.4315561269010817, 3.2081285502229417, 4.475699492863246, 3.97599720954895, 4.147583842277527, 8.7284642968859, 10.873366253716604, 17.458321707589285, 19.694604635238647, 22.7381066935403, 30.008265699659074, 23.5850556237357, 23.59704647745405, 24.000236545290264, 23.18472821371896, 22.24066604886736, 20.482570307595388, 18.6733375617436, 17.301429646355764, 20.5260260786329, 23.081886189324514, 26.873545953205653, 30.96994502203805, 35.021290234157014, 35.92956917626517, 33.63208825247628, 19.428479943956646, 7.402176516396659, 2.0093647497040883, 0.1973448669803994, 0.08494737997118916, 0.06698030193469354, 0.038316156648631604, 0.03259950590186885, 0.010942428904984678, 0.003990511942122663, 0.03780124017170497, 0.004376538995919483, 0.031347289881003756, 0.024247637184868966, 0.08635965561760323, 0.078770872471588, 0.0806160398891994, 0.10005823270018611, 0.06484353409281798, 0.029543421497302394, 0.05067969911864825, 0.03930273299504604, 0.05779886817825692, 0.019816596559914093, 0.04153592744842172, 0.016266268944101672, 0.04596275437091078, 0.032097179642213244, 0.06517604339335646, 0.01755115812245224, 0.020627425551148396, 0.03454101172142795, 0.08324370746101652, 0.04830501315050891, 0.09478132014295884, 0.0744074716099671, 0.054170144322727404, 0.08714904968759843, 0.027809608461601392, 0.056638349379811964, 0.08360282890498638, 0.03402098587581089, 0.056318270840815136, 0.04968828821022596, 0.07896841437156711, 0.03191607525306089, 0.05880245539758887, 0.01210990608004587, 0.013360512276579226, 0.0401111701503396, 0.04897470685786434, 0.029716763445841413, 0.04239905791889344, 0.01819698605686426, 0.02828676955375288, 0.1317298657127789, 0.21869909683508532, 0.1150207237473556, 0.1509336688156639, 0.06312061154416629, 0.20541454825018132, 0.13951293379068375, 0.12940384766885213, 0.11826788022049836, 0.13744925095566682, 0.2434777436511857, 0.14581978108201707, 0.07768290942268712, 0.17469143255480699, 0.12500156675066265, 0.15898591173546656, 0.14436680690518447, 0.14518852638346808, 0.1436553086553301, 0.22205906654042856, 0.15201928413340024, 0.10621772932686976, 0.18472635479910032, 0.178816111226167, 0.3003350155694144, 0.2424358395593507, 0.19920311655317033, 0.23559829645923205, 0.22137039420860155, 0.22410138909305843, 0.17355031307254518, 0.16109766199120454, 0.10595976388348, 0.23638045734592847, 0.22730134667030402, 0.15249098810766423, 0.11438902121569429, 0.09634187604699816, 0.13844350831849234, 0.09162227144198758, 0.09986426667975527, 0.16325207852891513, 0.08681651324565921, 0.19689902876104626, 0.192933819389769, 0.14296071949814046, 0.10431934440774576, 0.15895735898188182, 0.15989926058266843, 0.2402132845350674, 0.19327476966593946, 0.23326782722558292, 0.23581507482698985, 0.26806353724428583, 0.16108548907297, 0.16599397068577154, 0.11519510724714824, 0.13195857272616454, 0.145901354561959, 0.20064812472888402, 0.27277631578700884, 0.2607755283159869, 3.0896702323641096, 9.69936648436955, 20.755360058375768, 33.203061308179585, 48.04857546942574, 49.98972845077515, 50.358538831983296, 47.02739872251238, 41.44169323784964, 39.71990530831473, 34.59141560963222, 34.44652829851423, 30.34590298788888, 28.990542207445415, 21.57180118560791, 25.058405501501902, 50.80482510157994, 33.542567661830354, 28.33713013785226, 28.40908568246024, 21.040991817201885, 19.632958480290004, 17.503040313720703, 11.784459216254097, 11.251217109816414, 9.718677265303475, 7.177431387560708, 6.812465965747833, 5.5259314349719455, 4.778805102620806, 4.782099851540156, 4.204241190637861, 5.33491416488375, 5.223698692662375, 4.219123797757285, 5.339695394039154, 6.966631727559226, 7.95171822820391, 9.830903700419835, 13.72478015082223, 21.433290583746775, 21.37657938684736, 23.548726967402867, 31.03507743562971, 25.069527830396378, 26.573798928941997, 31.2394517489842, 31.787146977015905, 29.46015010561262, 29.748583725520543, 31.732124192374094, 30.86580889565604, 35.61715037482125, 36.02618735177176, 39.18889617919922, 40.91845219475882, 44.38222994123186, 42.97635923113142, 38.665241718292236, 20.443076746804373, 7.135449068886893, 1.3697617905480521, 0.17481138397540363, 0.24224888959101268, 0.1289461622280734, 0.20805497228034905, 0.12684207941804612, 0.13242491627378122, 0.0849148238609944, 0.1812863586736577, 0.15965192099767073, 0.0961532433118139, 0.2664199625807149, 0.14829537538545473, 0.16555973541523727, 0.15923200281602995, 0.15613215629543575, 0.11510520135717732, 0.13326847100896494, 0.14060670509934425, 0.17563500335173948, 0.16503973331834587, 0.07633535244635173, 0.08499162045440503, 0.13036466682595865, 0.20697496166186674, 0.131763453196202, 0.09537843095936946, 0.1005131768594895, 0.21834051821913036, 0.20049127457397325, 0.3439771666058472, 0.08096152277929441, 0.13876525605363504, 0.1867701836994716, 0.1387002659695489, 0.17096076559807571, 0.20482129151267664, 0.28848505286233767, 0.13802114741078444, 0.2125039364078215, 0.14460527125213826, 0.14895316080323287, 0.09643561565982443, 0.16036522415067467, 0.14647625014185905, 0.09231426859540598, 0.11476388467209679, 0.1084540586120316, 0.16808921896985599, 0.11494740125324045, 0.09991713812840836, 0.13295337291700499, 0.13397973855691298], [0.04634714445897511, 0.050509899122906585, 0.020480777170243006, 0.042691754177212715, 0.039904637661363394, 0.04979598528838583, 0.04021259077957698, 0.07119209771709782, 0.039092336249138625, 0.012398042583039828, 0.059340119761015685, 0.020203103677236607, 0.04396925241287265, 0.062405530629413467, 0.021998478498842036, 0.018262725922146013, 0.025725822330319455, 0.05861458940697568, 0.01045981832846467, 0.05269178615084716, 0.08167307531195027, 0.01496127138047346, 0.05638302683031984, 0.06190883621041264, 0.015377192990854383, 0.052900354244879315, 0.01887103426270187, 0.0721398957871965, 0.009043841273523867, 0.05904881789215973, 0.019292496111510054, 0.010316276789775916, 0.014567894096087133, 0.06290846078523568, 0.015412945000986968, 0.019586395073149885, 0.12179577377225671, 0.07625861013574259, 0.0034843981848098338, 0.04718507413885423, 0.027744292680706297, 0.058576550733830245, 0.032112124375998974, 0.02474941892017211, 0.005587762171801711, 0.12078938420329775, 0.026180661316694956, 0.14039559928434237, 0.022047641753618206, 0.005894498167825597, 0.02914516893880708, 0.018990317326305167, 0.017860944981553724, 0.04842299342687641, 0.024023179497037615, 0.028907915776861564, 0.035029726568609476, 0.048616053603057346, 0.03923383115657738, 0.04703510772170765, 0.021093741957364336, 0.04813198672075357, 0.09559520932712726, 0.050801513117871115, 0.7384124770760536, 3.349096425942012, 9.996008532387869, 20.952113934925624, 25.732302597590856, 35.96696090698242, 38.18337719781058, 41.20778213228498, 38.37806919642857, 26.718234607151576, 32.79188428606306, 30.441183635166713, 24.61419153213501, 22.111837761742727, 59.21258313315255, 43.137373311179026, 17.290637356894358, 22.41904715129307, 15.630992378507342, 15.166623422077723, 12.64051810332707, 14.263501780373709, 13.203466364315577, 14.804834195545741, 15.289556162697927, 15.330215283802577, 21.739336150033132, 18.243768657956803, 20.75663331576756, 16.596152748380387, 16.943512303488596, 17.783730166299, 18.578718730381556, 17.81452805655343, 28.46271014213562, 27.648508071899414, 18.521929366247996, 19.20124432018825, 23.45902224949428, 17.030019112995692, 17.965422085353307, 16.20245565686907, 25.334433112825664, 19.122722727911814, 23.857909645353043, 25.116240569523402, 25.852963277271815, 30.184742995670863, 34.10363817214966, 38.12961203711373, 35.54486131668091, 35.5567809513637, 30.33985458101545, 26.692131962094987, 24.872593300683157, 16.636139631271362, 7.5389474630355835, 1.9588978120258875, 0.06013254009719406, 0.010421191874359335, 0.021759079469900047, 0.06476490545485701, 0.05663931968488863, 0.008589487439686698, 0.04307411883824638, 0.05782127340457269, 0.056189634171979766, 0.052029006715331755, 0.027696885135290877, 0.03949532158938902, 0.025888701268870915, 0.046205819185291014, 0.04274058834250484, 0.017640835006854365, 0.0631902360224298, 0.08993999992630311, 0.00863495861579265, 0.013925178941073162, 0.04713387867169721, 0.030066232729171003, 0.011418429702254278, 0.04042541328817606, 0.042590357296700986, 0.054883637465536594, 0.043975413510841985, 0.029619661691997732, 0.03616461031404989, 0.05028343806043267, 0.0439904634175556, 0.03422433603554964, 0.08799466038388865, 0.019745755807629654, 0.05974964278617075, 0.03940620958538992, 0.03807035394545112, 0.061965432816318104, 0.012378603402924324, 0.07188899389335088, 0.03119253639930061, 0.02190242168892707, 0.04766908334568143, 0.007564526367267328, 0.03649955555530531, 0.019807639897667935, 0.03934723810691919, 0.0839838127472571, 0.004814922659923988, 0.06218867762280362, 0.06876710855535098, 0.025452030057619725, 0.027325209097138474, 0.0326710234928344, 0.05127760721370578, 0.030020703029419695, 0.08056740928441286, 0.02946923387103847, 0.05234201152675918, 0.005372577513168965, 0.02476001254815076, 0.04134519464735474, 0.03559436948437776, 0.05873102601617575, 0.01980906821388219, 0.010595781479163893, 0.013433230874527777, 0.07187006276633058, 0.03694306639954448, 0.04492516576179436, 0.03288919285738042, 0.02506394195370376, 0.02224663062952459, 0.05011456087231636, 0.06016642613602536, 0.020611999057499424, 0.05670470331928559, 0.0251780342244144, 0.012504539502385472, 0.05112995799364788, 0.03306283675400274, 0.036103745722877126, 0.02805118728429079, 0.023438845495028154, 0.020694522486467446, 0.01624459823194359, 0.026020661062960113, 0.04921927123463579, 0.03020984466586794, 0.03652337213445987, 0.08740031799035412, 0.08799280798328774, 0.04244802100583911, 0.07008032487439257, 0.044738192044730694, 0.03191149514168501, 0.05970105289348534, 0.04538024562810149, 0.05356921335416181, 0.02033091422968677, 0.028150326339527965, 0.03294996923900076, 0.008306077781266399, 0.013084917645236211, 0.01576704189314374, 0.031372354964592626, 0.015454086275505168, 0.049189218918659856, 0.05537751596421003, 0.038306735189897675, 0.04778852586501411, 0.024986570301864828, 0.04884642981258886, 0.0651193925046495, 0.06597271135875157, 0.029233398847281933, 0.11863796679036957, 0.40466807995523724, 2.108444324561528, 7.1584284986768445, 15.989482947758265, 27.743609803063528, 34.00510229383196, 42.43545239312308, 43.43321023668562, 44.36131238937378, 38.444865703582764, 27.583059515271867, 27.155450003487722, 24.28766962460109, 14.404750841004507, 16.624756744929723, 60.9229655947004, 36.05520650318691, 21.34391416822161, 28.002379826137, 22.647608143942698, 25.493494749069214, 25.751493522099086, 26.346512930733816, 26.106327601841517, 28.086743116378784, 24.368737731661113, 26.295158794948033, 27.450899566922867, 24.639573301587784, 25.41141220501491, 23.795575618743896, 22.89428656441825, 26.96762456212725, 26.836684022630962, 24.457749366760254, 27.172820499965123, 32.98041670663016, 28.528511319841655, 28.08069470950535, 33.4757468359811, 24.591250317437307, 20.766657829284668, 19.9211037499564, 21.386999947684153, 17.5358236517225, 20.99911502429417, 23.806861230305262, 24.50124682698931, 27.887277705328806, 32.46482910428728, 34.80029582977295, 37.313789299556184, 38.62281601769583, 36.86527960641043, 33.88166059766497, 31.399406228746685, 23.378358875002178, 12.769327282905579, 3.629803649016789, 0.012327972816170325, 0.09471635720027344, 0.027748097565823367, 0.06182437895664147, 0.04328562159623418, 0.09854856013719525, 0.0064914423190722504, 0.040232078305312564, 0.014292958491880978, 0.0365905267452555, 0.03702901643035667, 0.018622115387448242, 0.023787169750513773, 0.0344042835224952, 0.022707910609564612, 0.05703016264098031, 0.02435391103582723, 0.052577999220894914, 0.029089454428425858, 0.045625237481934686, 0.01780682842114142, 0.016366619184347134, 0.009860764357394405, 0.04017875223819699, 0.03640851990452834, 0.046409495041838715, 0.01939619661841009, 0.03756186319515109, 0.06459025054105691, 0.09502250541533742, 0.06247329592172589, 0.019953740361545767, 0.0916395808703133, 0.027459116286731193, 0.03292047671441521, 0.06118555859263454, 0.01234385562461934, 0.015427543681913188, 0.03752582620031067, 0.03902685083448887, 0.06561582229499306, 0.007195455055417759, 0.0502007416050349, 0.004994948178396693, 0.038736200359250815, 0.024412991079900945, 0.011085000986765538, 0.04997770714440516, 0.051149978169373105, 0.023882541240059903, 0.017512700453932797, 0.03199522297031113, 0.023942447400518825, 0.04323057544284633, 0.2121779274727617, 0.12219644870076861, 0.18442427100879805, 0.13866495500717843, 0.16603639269513742, 0.08482353375958544, 0.1453428931002106, 0.14941009985549109, 0.09107805243028061, 0.16850309818983078, 0.14296061093253748, 0.23932804060833796, 0.1154266641076122, 0.1711872470166002, 0.12642085844916956, 0.23950980656913348, 0.16685919782945088, 0.15638480202427932, 0.0735220851908837, 0.1333120736692633, 0.15816590216542992, 0.10402782540768385, 0.17241444545132772, 0.157975898789508, 0.09947765778217997, 0.3208287001720497, 0.08403357650552477, 0.1364625253315483, 0.08385556284338236, 0.16999628235186848, 0.12473302973168236, 0.15125789998897485, 0.12925052589603833, 0.22333411526467117, 0.17774619720876217, 0.11337752906339509, 0.29655847964542253, 0.11878531745501927, 0.1786311018679823, 0.13809251572404588, 0.1328985879995993, 0.13184019550681114, 0.12871786233569893, 0.15908675560993807, 0.0968390657965626, 0.2149334717541933, 0.09934350462364298, 0.2533816950661795, 0.12222418721233096, 0.19143949528889997, 0.07341311925223895, 0.0817344148776361, 0.21168045273848943, 0.10531618698899235, 0.08807409647852182, 0.11664804071187973, 0.1252074749874217, 0.10467296293271439, 0.17570555742297853, 0.10890569152044398, 0.12308950935091291, 0.13374060924564088, 0.2218905184417963, 0.31007212879402296, 1.4533186554908752, 5.95869607584817, 14.246351889201573, 28.156699316842214, 37.40579039709908, 49.94140025547573, 52.362051895686555, 55.566359588078086, 51.60123109817505, 38.50995990208217, 44.435157843998496, 40.659089837755474, 32.87491178512573, 28.018854004996165, 67.21648406982422, 53.44840621948242, 27.121878044945852, 32.86110918862479, 24.87511897087097, 23.93284944125584, 22.697367668151855, 24.136997938156128, 22.203710317611694, 24.334707192012242, 24.092352288109915, 22.31638056891305, 30.65098101752145, 25.357367379324778, 29.077349526541575, 22.945930787495204, 23.966709750039236, 25.01668678011213, 25.744085005351476, 25.82091644832066, 39.58808755874634, 37.62977947507586, 27.34482315608433, 28.122503757476807, 33.25633314677647, 24.224342005593435, 25.23755090577262, 24.178204229899816, 32.55094855172293, 25.633332456861222, 35.15591505595616, 35.656008175441194, 35.26666586739676, 39.60768495287214, 45.58121803828648, 49.488756384168354, 45.95826203482491, 48.320232663835796, 45.58305583681379, 39.124628816332134, 33.8530444417681, 24.58152457645961, 11.76164220060621, 3.2446951823575154, 0.13849115504750184, 0.17846726280237946, 0.07985327153333596, 0.13239111165915216, 0.17759748947407517, 0.1589237850691591, 0.08765632246753999, 0.13276978848235949, 0.1385039250765528, 0.05794910940208605, 0.22933919089181082, 0.14976806778992924, 0.1416670653436865, 0.12697329451995237, 0.14750851903642925, 0.13379052228161267, 0.1507948948336499, 0.16724665489579948, 0.08111692765461546, 0.12088699825108051, 0.20233165153435298, 0.08475309503929955, 0.16992281058004924, 0.15030864306858607, 0.13864009348409517, 0.1556489443672555, 0.05358859909964459, 0.13668262852089746, 0.1521681004336902, 0.19702231857393468, 0.12498369413827147, 0.1035201930041824, 0.18615388391273363, 0.12976249413830893, 0.114434455920543, 0.18124335312417575, 0.17119609511324338, 0.12165956465261323, 0.18769478265728268, 0.10707205241279942, 0.12128742890698568, 0.1134061903825828, 0.1346620326595647, 0.14140151387878827, 0.12223627870636326, 0.12085208083902087, 0.10380784435463802, 0.3000947870314121, 0.08450057823210955, 0.1008288109941142, 0.14172258307891233, 0.08730450206037078, 0.11893113463052682, 0.16243734796132359], [0.015598973858037164, 0.08989816824240343, 0.027914716928665127, 0.02631158973755581, 0.05452745747087257, 0.050640924235007594, 0.02905214178775038, 0.020249688498941914, 0.06893013337893145, 0.05825737464640822, 0.03789014522252338, 0.03048228326120547, 0.0761704955782209, 0.1448076782482011, 0.10268505888858012, 0.13449005117373808, 0.05634823155456355, 0.023521397761734467, 0.022011803230270743, 0.055044297594577074, 0.05595353451956596, 0.05090782259191785, 0.013065879648950483, 0.0409108575965677, 0.009488133281203253, 0.05024990825248616, 0.020009658432432582, 0.06043631343969277, 0.07206090074032545, 0.07578303851187229, 0.02849066423784409, 0.09253084340265819, 0.055525758902409246, 0.05105440990467157, 0.04608916544488498, 0.016874309263325164, 0.021578468714973757, 0.03745635439242635, 0.029085101626281227, 0.022758441112403358, 0.020316810879324163, 0.05461775012580412, 0.03436078942779984, 0.027366031460197907, 0.020965273225946084, 0.03103239874222449, 0.04207354770707233, 0.041653632918106656, 0.04065199987962842, 0.07320421867604766, 0.04161841016528862, 0.024884435514520322, 0.026809454629463807, 0.007369864848442376, 0.0982527324397649, 0.043716257238494496, 0.10386473273060151, 0.02746560308150947, 0.0563424843629556, 0.06404974311590195, 0.03741704346612096, 0.02287045367328184, 0.051042817133877955, 0.05021494334297521, 0.025308586058339903, 0.023440470586397817, 0.19256158864923886, 1.1348905307906014, 4.940897456237248, 7.744834746633257, 13.034751074654714, 17.796994277409144, 28.251842737197876, 33.84320231846401, 38.59437009266445, 36.21457386016846, 39.87928308759417, 35.02874912534441, 46.055689675467356, 73.85144397190639, 36.59033243996756, 30.124040058680944, 30.425251415797643, 19.54588191849845, 21.856515782220022, 18.93149266924177, 25.34074034009661, 17.893188612801687, 21.16413995197841, 16.991117886134557, 16.766062259674072, 18.78468418121338, 14.601832151412964, 18.45498868397304, 14.891895123890468, 13.570837599890572, 19.651435477393015, 23.467601537704468, 64.97145162309918, 41.32975081035069, 16.856975964137487, 21.318839856556483, 24.943730694907053, 26.49729926245553, 24.087655305862427, 27.612393072673253, 35.36542061397007, 36.71702936717442, 36.38865402766636, 39.28569500786917, 36.523501191820415, 34.99910116195679, 30.871256283351354, 24.55384121622358, 22.081892762865337, 14.603244372776576, 13.84507257597787, 6.108706380639758, 3.6720691067831854, 1.3692717254161835, 0.23418268242052623, 0.04840425228966134, 0.014741083374246955, 0.016111305116542747, 0.018103219302637235, 0.022216405287118893, 0.02035665954463184, 0.06259347125887871, 0.07050341181457043, 0.005373953667003661, 0.03097387509686606, 0.036245081174586496, 0.04472232111064451, 0.028476506604679992, 0.009570845851807721, 0.04527535768491881, 0.03575607795002205, 0.060946469993463585, 0.035803602542728186, 0.037224610934832265, 0.007807034782932273, 0.020752141983913522, 0.021746058382892182, 0.01086722856520542, 0.03723986100937639, 0.02402762390140976, 0.07630846888891288, 0.020944895122998526, 0.03211436354156051, 0.08210454215960843, 0.03201457478904298, 0.04886513363037791, 0.04713352244081242, 0.005438383111530649, 0.01339624053798616, 0.012242511330571557, 0.043359911002750905, 0.06596203121755805, 0.14475203837667192, 0.07442844512739352, 0.040128571180892844, 0.029883788233356814, 0.020936281120936786, 0.05641412069754941, 0.0023641241464896923, 0.019308126165664623, 0.0400112660468689, 0.0422035855507212, 0.019356634634147798, 0.05003673290567739, 0.07578601049525396, 0.033253494916217666, 0.012626231365304972, 0.03842497670224734, 0.08092627288507563, 0.024137008835428526, 0.03280707994209869, 0.03735066917059677, 0.005125033943581262, 0.017745448143354485, 0.03969186604289072, 0.03845098494951214, 0.037285112509770055, 0.023896374872752597, 0.07376095665884869, 0.040142599892403395, 0.0474111043315913, 0.0158020763524941, 0.03130043025261589, 0.1222165333373206, 0.08299293448882443, 0.09622335633529083, 0.0467097162535148, 0.06255112388836485, 0.04235119405867798, 0.020405593793839216, 0.03247774279277239, 0.0065635442983226055, 0.0364782766971205, 0.038303793740591834, 0.04002202421958957, 0.06019436142274311, 0.04830593935080937, 0.01927341570678566, 0.09003342062767063, 0.032385122762726884, 0.046861165269677124, 0.1058375732973218, 0.019879210075097423, 0.012467298956055726, 0.018173688556998968, 0.03651296001459871, 0.029807700709040676, 0.00510353032067152, 0.03731559230280774, 0.03004336609904255, 0.013692276036765958, 0.020420764140518646, 0.015497824642807245, 0.028449836785772016, 0.037141001849834404, 0.021506879877831255, 0.004422246811113187, 0.04374608563791428, 0.0533966686842697, 0.042032716862325153, 0.026974620231028115, 0.021123850252479315, 0.0369916020094284, 0.03776580707303115, 0.03868744422548583, 0.005059096030890942, 0.013957395783758588, 0.027220673992165496, 0.006653602010503943, 0.04073186684399843, 0.037239257113209794, 0.021396361790331345, 0.02103565427075539, 0.02367970167792269, 0.04265665356069803, 0.05751809717289039, 0.7700664613928113, 3.8609376464571272, 8.851974606513977, 15.887922866003853, 22.512170382908412, 30.31263848713466, 39.9482752255031, 43.518409047807964, 44.807827949523926, 41.648033891405376, 36.49952295848301, 31.341145583561488, 51.715483801705496, 71.61884185246059, 30.035582542419434, 29.13653428213937, 24.79964416367667, 17.929013524736675, 18.429942165102275, 16.304199865886144, 18.58549322400774, 18.008586032049998, 22.90443614550999, 17.917236328125, 25.73431757518223, 22.689966099602835, 24.00783440044948, 21.330644845962524, 22.08193792615618, 19.407584973743983, 21.77059609549386, 25.360228300094604, 64.13518728528703, 43.00870656967163, 17.47575126375471, 18.00757506915501, 20.278159516198293, 16.180530616215297, 16.281116213117325, 20.464425086975098, 32.27614382335118, 30.860180854797363, 36.05300392423357, 39.393736021859304, 37.75389167240688, 39.196747643607004, 37.732175077710835, 34.72613075801304, 30.013952800205775, 22.40771290234157, 19.15344418798174, 11.436144283839635, 6.977049682821546, 2.6319203036172047, 0.48902219640357153, 0.10469167692852871, 0.05409495585731097, 0.019190327397414615, 0.02511833162446107, 0.012967263913846441, 0.03394484746136835, 0.06474395229348115, 0.03403652772041304, 0.04111295925187213, 0.023684249558885182, 0.008911686400616807, 0.04547366972214409, 0.09062009557549443, 0.009862502255210919, 0.0591649016631501, 0.04500242715169277, 0.0028287607544500914, 0.013435200322419405, 0.0044751377676480585, 0.013383418770640023, 0.016586055713040487, 0.020995032075526457, 0.003798567531963012, 0.08360669655459267, 0.011681608839093574, 0.03730679848896606, 0.0367229632101953, 0.008456872859304505, 0.013855229614169469, 0.0983313542923757, 0.015372416104323097, 0.061317852565220425, 0.01905230658927134, 0.03195679753220507, 0.027158749190026095, 0.028908122730042254, 0.04046931450388261, 0.1144667270460299, 0.036699506254600625, 0.012571253065418984, 0.049818651750683784, 0.04973384505137801, 0.054565458824591975, 0.04119274139936481, 0.05722547894609826, 0.07860733196139336, 0.06754181680402585, 0.0822083240907107, 0.013242994252193187, 0.08660517672875098, 0.10515420032399041, 0.049668990674295595, 0.05212489728416715, 0.0705716452960457, 0.034462457722319026, 0.14501851264919552, 0.1263920749936785, 0.15648598516626017, 0.10280640130596501, 0.09276160637715034, 0.15834772240902695, 0.06568041882876839, 0.15073051543108054, 0.19285919410841806, 0.13481391593813896, 0.1228069673691477, 0.11138193043214933, 0.1717336576964174, 0.3338440332029547, 0.15288333062614712, 0.30127389090401785, 0.17005237005650997, 0.13461391095604214, 0.10479990326400314, 0.19716660226030008, 0.1639948436724288, 0.20312411258263247, 0.13240955424095902, 0.13534739374050073, 0.10545295250735112, 0.10248936260385172, 0.1164635606110096, 0.14037498539047583, 0.14255047722586564, 0.1678517045719283, 0.08080074390662567, 0.19139596048210347, 0.1307921845998083, 0.14572140707501344, 0.09294771496206522, 0.0899781064529504, 0.20271483383008412, 0.07068909970777375, 0.08087128440716437, 0.1950236258230039, 0.10181968246719666, 0.14870818252010004, 0.09267046555344548, 0.11872734342302595, 0.12483058949666363, 0.13814310729503632, 0.06636240759066173, 0.14498215674289636, 0.14788203899349484, 0.23938848450779915, 0.09601624709154878, 0.06839220438684736, 0.11472613098365919, 0.08381329011172056, 0.17819116690329143, 0.14602648999009812, 0.15666822610156877, 0.13429171538778714, 0.19181813140000614, 0.15606294572353363, 0.14895651276622499, 0.17513965921742575, 0.19626272576195852, 0.2678942563278334, 0.1529202972139631, 0.10543246753513813, 0.5391437326158796, 2.982575476169586, 7.417818648474557, 13.684153165136065, 22.313495329448156, 32.27659893035889, 45.473680768694194, 52.85611397879464, 57.978826250348774, 56.234296866825645, 52.7518493107387, 47.844736167362754, 53.84057991845267, 80.40816715785435, 49.52395248413086, 40.28527675356184, 41.35718924658639, 28.61207209314619, 30.91988672528948, 28.12047835758754, 34.57981906618391, 25.95883297920227, 31.055786541530065, 23.971246923719132, 26.80052559716361, 27.693226678030832, 23.34684705734253, 27.717524528503418, 23.91203784942627, 21.357206072126115, 27.223599672317505, 32.2423095703125, 79.01125267573765, 53.35264267240252, 24.320277520588466, 29.795671667371476, 34.01999923161098, 33.9968513080052, 32.49280602591378, 36.78380502973284, 46.2531817981175, 46.826793806893484, 47.83957712990897, 51.72390154429844, 49.19617816380092, 47.504062516348704, 42.80055243628365, 36.160718372889924, 30.895703520093644, 21.490140744618007, 18.783735752105713, 10.696774312428065, 5.817175601209913, 2.1353457953248705, 0.3988542833498546, 0.20443642645009927, 0.22136937640607357, 0.1148636836026396, 0.1615477478397744, 0.09813780217830624, 0.10507990073944841, 0.26546431386045044, 0.11341334892702953, 0.1109082790623818, 0.10877717698791198, 0.106258271794234, 0.10029919405600854, 0.23526551574468613, 0.1294736960636718, 0.12103342610810484, 0.0843610375055245, 0.16991521098784038, 0.11638746969401836, 0.08811345150960342, 0.13915112534804003, 0.11080894153565168, 0.14506671577692032, 0.10042145249566861, 0.15858052777392523, 0.10451329685747623, 0.08128595751311098, 0.12654992938041687, 0.07140916785491364, 0.13227892267916883, 0.18200437085969107, 0.15565547187413487, 0.2171351821827037, 0.0967138557295714, 0.08502469225121395, 0.08011414789195571, 0.13891993489648613, 0.1928083718355213, 0.22304756992629596, 0.13807918929627963, 0.1345576061201947, 0.1707676002489669, 0.1269765379173415, 0.12463105948907988, 0.16758551528411253, 0.1684873697480985, 0.16101963046405995, 0.12432729293193136, 0.1277428346553019, 0.25580439077956335, 0.13160117476114205, 0.17290316708385944, 0.13876324758997985, 0.09027920636747565, 0.11740733496844769, 0.18303847179881164], [0.019780600277174796, 0.024218071717768908, 0.013204233787421669, 0.01924764664311494, 0.047192538024059365, 0.05258391943893262, 0.004071908154790955, 0.036416947309459956, 0.006812367754589234, 0.0589354279051934, 0.07161539500313145, 0.0336488297741328, 0.04008737053456051, 0.11465967526393277, 0.03774500997470958, 0.018892347047637616, 0.038956147485545704, 0.037985598136271746, 0.04634397230776293, 0.018578014003911188, 0.05448620593441384, 0.0294790590581085, 0.028510077124727622, 0.02352731967610972, 0.06308473739773035, 0.014751252917838948, 0.033879633460726054, 0.06707201951316424, 0.04428211812462125, 0.03806898330471345, 0.06129952533436673, 0.056230193602719476, 0.028104701644874046, 0.042482622899115086, 0.05528975424489804, 0.0210908988956362, 0.026160727654184614, 0.01520622252220554, 0.1020681755617261, 0.02399106104192989, 0.0779282609000802, 0.06080137885042599, 0.03737316260646496, 0.016427465115806887, 0.04580458446538874, 0.059982821345329285, 0.020117845752143433, 0.06359704490751028, 0.02413681036393557, 0.014134654575692756, 0.05186037379982216, 0.027251062182975665, 0.026929970930463502, 0.020063154133302823, 0.043854579994721074, 0.014444110648972648, 0.08070184742765767, 0.029501250545893396, 0.028426880249753594, 0.0556308571914477, 0.07428377467606749, 0.03104420525154897, 0.04472186988485711, 0.02919266639011247, 0.011196459693435048, 0.02697146843586649, 0.09235473642391817, 0.03409924471218671, 0.04578255921868341, 0.0600153435287731, 0.4576080877866064, 1.5298735818692615, 5.677251040935516, 12.529360822268895, 21.939524173736572, 27.501154150281632, 32.157729148864746, 42.553898334503174, 40.67877755846296, 44.49228940691267, 48.039584500449045, 47.45539385931832, 39.67172997338431, 34.33031620298113, 38.02605608531407, 28.45396409715925, 32.710072721753804, 27.56780821936471, 26.657545566558838, 33.9095367704119, 22.725638151168823, 19.938661847795757, 24.28695743424552, 24.885355404445104, 25.851636171340942, 25.523467540740967, 25.673390558787755, 30.977209363664898, 80.65824672154018, 57.640775544302805, 23.149889945983887, 40.28097234453474, 32.36361122131348, 39.91200910295759, 35.32684768949236, 45.55879967553275, 39.69795594896589, 40.9512859072004, 27.451933111463273, 26.99910511289324, 14.55345618724823, 12.228146859577723, 8.108442664146423, 2.338183254003525, 1.856626842703138, 0.7605976951973779, 0.283255719180618, 0.09694919203008924, 0.025727749369772415, 0.07768605103982346, 0.0543719134958727, 0.04720073472708464, 0.04561110359749623, 0.048370532491909604, 0.018106537338878428, 0.017855133329119, 0.04158522980287671, 0.04259293233709676, 0.029362442637128488, 0.017159733322582076, 0.015980870329907963, 0.09151933767965861, 0.03261796205437609, 0.0610781939966338, 0.046454637976629395, 0.010705777942868215, 0.015725941330726658, 0.06121659478438752, 0.036248955609542985, 0.037258469832262824, 0.05096644123217889, 0.0713949321902224, 0.05194485480231898, 0.06155612013701882, 0.039917343229587586, 0.03468606215236442, 0.05936184645231281, 0.005547751930342721, 0.013239187670738568, 0.041526214219629765, 0.048390552667634826, 0.05227605113759637, 0.09591682814061642, 0.07451805246195622, 0.06148461611675365, 0.042126632894256284, 0.030839769435780387, 0.05616339522280863, 0.02670098402138267, 0.05202119338459202, 0.02825776387804321, 0.031423648819327354, 0.05394884691174541, 0.019008171278983355, 0.03935493269403066, 0.00512198732134753, 0.02796424998502646, 0.02056629124230572, 0.005563588513593588, 0.025795680903164402, 0.032842940517834256, 0.015495010418817401, 0.026221259763198237, 0.05177599457757814, 0.029335043393075466, 0.015379176009446383, 0.017466298836682524, 0.035447653249970505, 0.03957980598456093, 0.06380697685692992, 0.034594510814973285, 0.056880973146430085, 0.049651073957128186, 0.0356434954197279, 0.04225307110963123, 0.011287813407502003, 0.08064660110643931, 0.05593123107350298, 0.04960079111957124, 0.052968468982726336, 0.03999473014846444, 0.02730049515542175, 0.006877133073950452, 0.09526869149080344, 0.044482421662126265, 0.0408200899671231, 0.039421703932540755, 0.05626233919922795, 0.08089352678507566, 0.017253964873296872, 0.07384435539799077, 0.027028402612943734, 0.018845641785966497, 0.07051737606525421, 0.07386943405228001, 0.04249559648867164, 0.05678315553814173, 0.07622004899063281, 0.017903139681688378, 0.04038104049063154, 0.03408663413886513, 0.08372738079300948, 0.026164885377511382, 0.04916769578786833, 0.042193102184683084, 0.041834706773183176, 0.053063314607633014, 0.04336339867274676, 0.06028645219547408, 0.008155013833727156, 0.009257837647705205, 0.038763647100755146, 0.007224678710502173, 0.014716147212311625, 0.04262863006442785, 0.020462795992248824, 0.06416168103792838, 0.030269087558346133, 0.08484615611710719, 0.04521478147112897, 0.0032060824159998447, 0.01165701448917389, 0.03429153135844639, 0.03337197730849896, 0.06786742540342466, 0.06032607864056315, 0.045860085237239084, 0.016793802779700075, 0.01181666020836149, 0.013810292784390705, 0.0294634968574558, 0.0324443045870534, 0.01047169099495347, 0.011084992505077804, 0.07865277345159224, 0.35130398773721283, 1.3266206426279885, 3.731603443622589, 9.795872620173864, 18.890136991228374, 29.932954175131663, 38.19244807107108, 44.49229982921055, 48.065292835235596, 44.60036168779646, 53.128038678850444, 51.29488502229963, 46.71081100191389, 39.67836897713797, 31.06602818625314, 33.00680249077933, 23.426876408713206, 27.19371894427708, 21.941652059555054, 21.321589606148855, 22.684831380844116, 19.145577090127126, 17.42608901432582, 17.3314528124673, 19.618452378681727, 19.268662691116333, 15.394116129193987, 18.495743342808314, 24.565627098083496, 84.71937847137451, 54.46285016196114, 14.373552560806274, 31.54721178327288, 29.519109044756206, 37.193224157605854, 35.18613971982683, 46.460276331220356, 42.673994473048616, 46.23679794584002, 36.51419060570853, 37.80209827423096, 25.62004402705601, 20.815404653549194, 14.138630492346627, 6.062484358038221, 4.868909341948373, 2.416695509638105, 1.3239472146545137, 0.33393216133117676, 0.10478820532028164, 0.09099540007965905, 0.0268680206832609, 0.07127282302826643, 0.02477636524210019, 0.0674383198576314, 0.058977680280804634, 0.009549802784541888, 0.05057497741654515, 0.0019080156635027379, 0.026643510408965603, 0.030600216040121656, 0.0408163240977696, 0.07336193057043211, 0.029327358983989273, 0.052141256763466766, 0.025361784900139486, 0.06561401060649327, 0.010961702692189386, 0.020380367558183413, 0.022607809730938504, 0.019696830040110008, 0.05241329502314329, 0.024079465673172047, 0.058376661102686606, 0.02988601043554289, 0.052540812109197886, 0.05262226684551154, 0.04124819128108876, 0.026814350259623358, 0.018309253068374734, 0.05381503302071776, 0.08293437691671507, 0.10476023610681295, 0.004076456459837833, 0.060773945679622035, 0.03222482564992138, 0.07014978650425162, 0.04064164882791894, 0.06797949224710464, 0.019927530250112926, 0.038232462746756415, 0.07006172622953143, 0.023240085624690567, 0.04963154911196657, 0.03963806500126209, 0.01965506451337465, 0.06417262580777917, 0.014746313182903188, 0.014644543108131205, 0.02502356912009418, 0.018523144269628183, 0.04625144387994494, 0.027154476115746156, 0.009249507782182522, 0.010914002528547176, 0.028913835994899273, 0.03748708524342094, 0.15684840429042066, 0.10361028888395854, 0.13698947562703065, 0.1338648490075554, 0.08755858628345387, 0.1381365390760558, 0.10648039701793875, 0.13230451702007226, 0.15968115228627408, 0.18879798560270242, 0.1536224316805601, 0.15144494495221547, 0.15451503092689173, 0.2853542651448931, 0.09186931247157709, 0.1619567008955138, 0.1569577841354268, 0.12996799525405678, 0.14551258113767418, 0.16555885331971304, 0.11912021519882338, 0.14588471688330173, 0.13302246135260376, 0.06852074606078011, 0.181407897866198, 0.16272679742957863, 0.0908429129049182, 0.2528267077037266, 0.17720685686383927, 0.127209641837648, 0.1531961488404444, 0.23091955323304447, 0.0726190365052649, 0.17683818164680684, 0.10638717987707683, 0.1713099940014737, 0.08979876964752163, 0.09492698804076229, 0.14335109426506928, 0.07237104552664927, 0.24672502226063184, 0.09532209898212127, 0.12880202781941208, 0.13576503204447882, 0.1442374781306301, 0.220508179760405, 0.07524183898099832, 0.08489095299903836, 0.15884682562734398, 0.15289075379925116, 0.10716263683778898, 0.13440849126449653, 0.13531585543283395, 0.09888411605996744, 0.12045573496392795, 0.12570523470640182, 0.14742196510945046, 0.06941975067768778, 0.15423117258719035, 0.21964274905622005, 0.22083226165601186, 0.08814497624656983, 0.11295691199068512, 0.11503371090761252, 0.11979721672832966, 0.27171801828912323, 0.18212232738733292, 0.15972219008420194, 0.11634662188589573, 0.28067568476711, 1.4447593433516366, 3.167658333267484, 8.58551640169961, 19.311995131628855, 33.57242407117571, 45.277276039123535, 51.78153337751116, 57.79394858224051, 55.79933616093227, 58.298818588256836, 61.63325909205845, 60.54230853489467, 54.60936682564871, 46.29539210455758, 50.81525434766497, 39.836978980473106, 45.630880287715364, 37.073291301727295, 36.23618275778634, 45.15518924168178, 35.007140227726524, 29.519494669778005, 32.24353245326451, 34.76662833350045, 33.978334358760286, 34.93976354598999, 34.5978079523359, 39.03632763453892, 86.78462627955845, 62.241566930498394, 33.164832319532124, 49.142774309430806, 44.05004698889596, 50.846663679395405, 48.11196388517107, 58.18492719105312, 52.08245638438633, 53.560949666159495, 41.035876750946045, 39.018793855394634, 25.501424380711146, 19.157305649348668, 12.638005461011614, 5.376868690763201, 3.239756533077785, 1.4583074620791843, 0.7181904507534844, 0.27680228118385586, 0.13965325483254024, 0.18399441907448427, 0.1692868061363697, 0.1882128305733204, 0.1572178258959736, 0.1120670200990779, 0.21756249639604772, 0.08699300698935986, 0.13397919572889805, 0.11997540002422673, 0.119115289034588, 0.2117397024163178, 0.07308708317577839, 0.1981160898825952, 0.13595970374132904, 0.20106022618710995, 0.0999038184859923, 0.09750126169196197, 0.0792072383420808, 0.15319351612457208, 0.11136398996625628, 0.09545745993299143, 0.14304173657936708, 0.18479260695832117, 0.12199723081929342, 0.13273450466138975, 0.15568049624562263, 0.10559529558356319, 0.18967562993722303, 0.08822191533233438, 0.09639651847204991, 0.11438714845904283, 0.08074585720896721, 0.16681450951312268, 0.20686571752386435, 0.16341663684163774, 0.13220520663474286, 0.15947037216808113, 0.17044019353176865, 0.17327843766127313, 0.12774442242724554, 0.13175505293267115, 0.1634606466229473, 0.15304965312991822, 0.14141142049006053, 0.07288175169378519, 0.07425562904349395, 0.12816311924585275, 0.10855507890560798, 0.10469768874879394, 0.07808244441236768, 0.1118018961112414, 0.11220289673656225, 0.08644217904657125, 0.09011291779045548, 0.16730941938502447, 0.21304118686488696, 0.17682303674519062], [0.022530416026711464, 0.07751999316470963, 0.03955975866743496, 0.027675248349883726, 0.05147221784240433, 0.05088389066181012, 0.024136506719514728, 0.06953166824366365, 0.032961806282401085, 0.030620412634951726, 0.026448119464995604, 0.014398102582033192, 0.039016255510172675, 0.0364341481721827, 0.06513161970568554, 0.05234756872856191, 0.010077263677625783, 0.041903584862926176, 0.07678465119429997, 0.06396599832390036, 0.02532285395344453, 0.023186528855668645, 0.03417365625500679, 0.04266623786783644, 0.034899780327188115, 0.04936446076525109, 0.03156830230727792, 0.09643862835530724, 0.007629786169023386, 0.0879959903125252, 0.019110845501667688, 0.05339582730084658, 0.05052270307870848, 0.032776878348418644, 0.0651866624663983, 0.04081859719008207, 0.05009883243058409, 0.05765643010714224, 0.030366867847208465, 0.04798913474327751, 0.029077871835657527, 0.03583377699500748, 0.02303657940189753, 0.05427303737295525, 0.050090398240302286, 0.015722177157710706, 0.04551529784553817, 0.01996142816330705, 0.048987975610154014, 0.03522925318351813, 0.07213747341717992, 0.062730582830097, 0.06716485667441573, 0.014066309984108167, 0.06039383714752538, 0.01291760363216911, 0.007356906525923738, 0.011698108266240783, 0.04675401780488236, 0.02843698363618127, 0.10464886815420218, 0.036783447821757624, 0.01903532455409212, 0.044735084354345284, 0.033432299071656804, 0.030288666686309234, 0.08036570117941924, 0.05544513876416853, 0.08789025420056922, 0.005798616504762322, 0.07583824412098952, 0.028145072782146077, 0.09492242150008678, 0.12997229716607503, 1.0789807651724135, 4.224324524402618, 8.782646349498204, 21.64429521560669, 30.875265393938335, 35.51088809967041, 40.97615698405674, 42.12760203225272, 43.716488293239046, 45.569475582667756, 46.093557357788086, 43.26558494567871, 42.56859377452305, 40.64614534378052, 46.351773262023926, 48.931778362819124, 41.85581977026803, 46.655624934605186, 50.12865768160139, 45.17020777293614, 45.45488936560494, 43.06471252441406, 43.61988748822893, 39.25888190950666, 52.22998053686959, 44.78554507664272, 42.527557713644846, 42.481977530888145, 39.128255775996614, 31.260939053126744, 28.44653820991516, 26.809459243501934, 19.039591005870275, 12.359808274677821, 4.606937502111707, 3.1929784374577657, 0.9901729077100754, 0.567266403564385, 0.05115611891129187, 0.05446128673585398, 0.017638178542256355, 0.02176037716812321, 0.014431254106706806, 0.03661167328911168, 0.04982736753299832, 0.008156466746835836, 0.022000473391796862, 0.023625797159703713, 0.056685402390680144, 0.04227671805503113, 0.05372250798557486, 0.04357595994536366, 0.02204853911618037, 0.041917535542909584, 0.051786033503179035, 0.04833079408854246, 0.047658413382513184, 0.04265799027468477, 0.016179905006928102, 0.02736360909018133, 0.019362113804423382, 0.00990971811448357, 0.029224869662097523, 0.04493670424978648, 0.028432094791371907, 0.05807241957102503, 0.037276725816939554, 0.012338914193346031, 0.06884715533150093, 0.021198280455012406, 0.025543064012059143, 0.04766479839703866, 0.016479210196329013, 0.05276389406727893, 0.018751713879672543, 0.01227329985704273, 0.04309436632320285, 0.060397813362734656, 0.037895274947264364, 0.025832153856754303, 0.00535652761547161, 0.06636413106960909, 0.07032936079693691, 0.01607595174573362, 0.04046892434624689, 0.09898166903959853, 0.062169230809169154, 0.0561980039014348, 0.0630774295755795, 0.04798108392528125, 0.01128704157391829, 0.03855017659121326, 0.04317758525056498, 0.008964088811938251, 0.06822926098746912, 0.05244626843237451, 0.014213569046530341, 0.08583400810935668, 0.10977266928447144, 0.03016055588211332, 0.02319454913958907, 0.026543007498340945, 0.07763500485037055, 0.06669073033013515, 0.02505082926446838, 0.047137814174805365, 0.07433241206620421, 0.038511096366814206, 0.0434535420499742, 0.07887744318161692, 0.019763497802029763, 0.0540546814112791, 0.02274442257891808, 0.0054298314498737454, 0.016170861831467067, 0.045164091512560844, 0.12401087848203522, 0.06944205412375075, 0.016020160900162797, 0.029189463704824448, 0.01737515122762748, 0.08941298856266908, 0.0403916052808719, 0.06659658359629766, 0.021151631172480326, 0.03800928918644786, 0.07147980335035495, 0.005226280274135726, 0.01574162227500762, 0.024735663319006562, 0.016707684811470763, 0.04997214315725224, 0.03142762842721172, 0.02123181026295892, 0.01285861264581659, 0.011516719740549368, 0.017503189089308892, 0.06900719460099936, 0.005692235360454235, 0.06095010694116354, 0.02205218284923051, 0.12380989640951157, 0.03901370421850255, 0.009693049160497529, 0.00867211858608893, 0.033762117980846336, 0.02821747925398605, 0.0024871402129065245, 0.054038406748856814, 0.04534263103934271, 0.03410821494513324, 0.07936668728611299, 0.04282693192362785, 0.022220345879239694, 0.018303164912919914, 0.022622934276504175, 0.011808753579056688, 0.04957004330520119, 0.04283843309219394, 0.03536327063505139, 0.025035882834345102, 0.00875965045166335, 0.05322104346539293, 0.04462984696562801, 0.042650261760822365, 0.03207215527072549, 0.025082399802548543, 0.04872228504557695, 0.033301816787570715, 0.009592267202346452, 0.07150173360215765, 0.03032117529905268, 0.06703747529536486, 0.12425196197416101, 0.2098314855247736, 0.7093901229756219, 2.4561417358262196, 7.754700320107596, 14.50626836504255, 30.54696648461478, 39.81413330350603, 42.65677336284092, 47.64014298575265, 50.09255831582205, 50.669825077056885, 49.768668038504465, 49.45609637669155, 45.737222467150005, 44.27761786324637, 43.553209100450786, 43.68964392798287, 48.99511119297573, 43.7599492754255, 43.373883043016704, 48.74085576193673, 43.20504181725638, 44.20636408669608, 40.377517563956125, 42.408316203526084, 39.955584730420796, 60.2466070992606, 50.96455723898751, 40.38807882581438, 48.063045092991416, 45.71735061917986, 43.420328276497976, 38.95281376157488, 37.083692755017964, 27.874519075666154, 19.40189787319728, 9.249224833079747, 6.587762526103428, 2.121649158852441, 1.2633761848722185, 0.1803698478532689, 0.13827766078923429, 0.024038919813132713, 0.02866139043388622, 0.025766548002138734, 0.03172999380954674, 0.05493146739900112, 0.03246527810447982, 0.0024561930788747433, 0.027941892256161997, 0.024614841677248478, 0.054898507560470274, 0.014693423074537089, 0.07220317596303565, 0.0244182361555951, 0.03805407928302884, 0.04881287964859179, 0.014710890262254646, 0.07275063158678156, 0.026919434977961437, 0.02488251865309264, 0.05289604554751089, 0.0061937927551168415, 0.016481513822717325, 0.028343089656638246, 0.04537448825846825, 0.019162047754174898, 0.0546747402820204, 0.0341427252361817, 0.02295511109488351, 0.03756526604826961, 0.019805085213322724, 0.03827254381030798, 0.12166928127408028, 0.02646755101159215, 0.027160130008789043, 0.0827179920992681, 0.012253386550582945, 0.04680943715253046, 0.06439709876264844, 0.05511357601998108, 0.03116715918960316, 0.02869564966697778, 0.04677024496985333, 0.04010490048676729, 0.0258215619251132, 0.03864130384421774, 0.035668550325291495, 0.018679249732355987, 0.05265753709578088, 0.03735308475526316, 0.015145057679287024, 0.035354656632989645, 0.021492732422692434, 0.03708115845386471, 0.04100524181766169, 0.05496148578822613, 0.04952268156089953, 0.01778792104284678, 0.08641712074833256, 0.052692902340952835, 0.034855780723903856, 0.0911287118547729, 0.03763911101434912, 0.16362090302365168, 0.1714084901447807, 0.07873520188565765, 0.09505363660199301, 0.1988644190132618, 0.12822224678737776, 0.0774134292400309, 0.18401913131986344, 0.1295268660677331, 0.14248213517878736, 0.07572028759334769, 0.06544941158166953, 0.12407360225915909, 0.14572530186602048, 0.2572158250425543, 0.17626088405294077, 0.13577027033482278, 0.14374886506370135, 0.13816346334559576, 0.15964054875075817, 0.08924871523465429, 0.159250743953245, 0.11179342120885849, 0.15569634682365827, 0.10590691279087748, 0.13960559453283036, 0.05035225847469909, 0.22071676142513752, 0.09227519854903221, 0.14348610916307994, 0.12676406146160193, 0.13367906611944946, 0.15184827973800047, 0.09536544379911252, 0.14438052688326153, 0.19606725339378628, 0.11302556616387197, 0.08949614302920443, 0.1306288205087185, 0.224711378504123, 0.16899028633322033, 0.10876489550407444, 0.11982476525008678, 0.13531734820987495, 0.12799176201224327, 0.09472431641604219, 0.10868663327502352, 0.0954714852518269, 0.09914331643709115, 0.23615263242806706, 0.20358835267169134, 0.16470228428287165, 0.16038547163563116, 0.14812244395060198, 0.14858352206647396, 0.07329077260302645, 0.11287508745278631, 0.08195848071149417, 0.12876588904431888, 0.08407960832118988, 0.18520261852868966, 0.10762688371219806, 0.12030154466629028, 0.1028684601187706, 0.14584906665342195, 0.1426158201481615, 0.20394442070807728, 0.10411285941622087, 0.16332861727901868, 0.10293906847281115, 0.15591018034943513, 0.14730913830654963, 0.19708139183265821, 0.3537817804941109, 1.8597563547747475, 7.046846508979797, 15.161287205559866, 32.367425782339915, 43.58015768868582, 49.098809582846506, 53.71275390897478, 57.41668919154576, 58.39688546316964, 60.57698004586356, 58.78616523742676, 58.798810958862305, 56.96555307933262, 56.69027934755598, 60.565265383039204, 63.90695980616978, 55.8597229548863, 59.5016907283238, 64.13569450378418, 57.953976018088206, 58.140219007219585, 56.46335118157523, 56.76477098464966, 52.513112681252615, 62.268227168491904, 57.679386683872764, 56.487565653664724, 58.57698277064732, 56.05760070255825, 50.29269075393677, 43.35145425796509, 36.918026856013704, 26.871732473373413, 17.472923346928187, 8.30942451953888, 4.8104424221175055, 1.7429132759571075, 0.8302115883146013, 0.21119821790073598, 0.1324006247201136, 0.09628689435443707, 0.12150958127209119, 0.1562080029398203, 0.10058320845876421, 0.15220563699092182, 0.14802065012710436, 0.10938021141503539, 0.15564082908843244, 0.17075849430901663, 0.17525286599993706, 0.12456184891717774, 0.11625947084810052, 0.10567986140293734, 0.09672762999044997, 0.07154678154204573, 0.07970257569104433, 0.10224005526729993, 0.12121892401150294, 0.13552583487970488, 0.14536133568201745, 0.10637616725372416, 0.08091445959040097, 0.07307720370590687, 0.11148922717464821, 0.11864951545638697, 0.10180767239736659, 0.08795772093747344, 0.09001666081271001, 0.1406144539692572, 0.05832892616412469, 0.10172013459461075, 0.24647727555462293, 0.11812891624867916, 0.17560467283640588, 0.13747760014874594, 0.17668347566255502, 0.12792378637407506, 0.15434986193265232, 0.12523601417030605, 0.1391152444162539, 0.08638062913502965, 0.16945207012551172, 0.15233219734260015, 0.13018077026520455, 0.13664748040693148, 0.2011791190930775, 0.10933108547968523, 0.16552537440189294, 0.16314522283417837, 0.12626429327896663, 0.04655277788905161, 0.07672071962484292, 0.09932542166539601, 0.11698548974735395, 0.14925027771719865, 0.26914058945008684, 0.08188987403575863, 0.22208965489906923, 0.21143639726298197, 0.08089548096592937, 0.16594008143459046, 0.08180925050484282], [0.04227618540504149, 0.012030568372990404, 0.03341152232938579, 0.020634022607867206, 0.04756098932453564, 0.01551724092236587, 0.017249691799016934, 0.03533157626433032, 0.00402634749687942, 0.04522762953170708, 0.010192188850071813, 0.027891899492325525, 0.03966956598950284, 0.030745985718177896, 0.029848205856978893, 0.047330765785383325, 0.1094331167904394, 0.08014612724738461, 0.01777936641259917, 0.07918467705271073, 0.02424653626180121, 0.0069177294000318, 0.032132239546626806, 0.06142299835171018, 0.08842550297932965, 0.05969274762485709, 0.014564182509535124, 0.018187970022803972, 0.015371664626789945, 0.035683328817997656, 0.028749376069754362, 0.08678104622023446, 0.01961768910820995, 0.05295721208676696, 0.03668796776660851, 0.04387290044022458, 0.026651783447180475, 0.08249513405774321, 0.0452911268387522, 0.03712455416098237, 0.07627463713288307, 0.026412630387182747, 0.011583006674689906, 0.07423219244394984, 0.02598244257803474, 0.06524597999772855, 0.052453966412161074, 0.07638204244098493, 0.04983478731342724, 0.031696385970073085, 0.013743529179399567, 0.0372647055690842, 0.055698839614966085, 0.014635976603520768, 0.016338485426136425, 0.0636581809126905, 0.033274580391922166, 0.05113889090716839, 0.037960190392498455, 0.07582940280969654, 0.029949338108833348, 0.02379058108532003, 0.06798040826937982, 0.03549297599654112, 0.049182986574513574, 0.030394745458449637, 0.06044215562620333, 0.026056380842679312, 0.013001278874331286, 0.026604710080261742, 0.0580468795129231, 0.038528677209147384, 0.07476585345076663, 0.012484789892498935, 0.037349858321249485, 0.06265526544302702, 0.16372969932854176, 0.9227216414042881, 2.364192315510341, 7.230742744037083, 11.835551057543073, 14.654086078916277, 18.563939911978586, 15.293233496802193, 16.32949651990618, 25.97588906969343, 27.155806098665508, 28.6154454435621, 33.32191719327654, 32.12961673736572, 35.10825736182076, 33.09531559262957, 31.485442297799246, 37.299469062260215, 39.52619995389666, 39.654911858694895, 36.16870880126953, 41.065375328063965, 41.48516116823469, 36.161312443869456, 31.560691288539342, 27.20797143663679, 15.842137711388723, 9.305269871439252, 4.19391964163099, 0.9566961612020219, 0.3180117756128311, 0.1740533925060715, 0.11719115371150629, 0.011383216279292745, 0.06207477194922311, 0.05193895833300693, 0.02850223325991205, 0.03724449879622885, 0.06932432829801526, 0.1251374501734972, 0.047642640836004696, 0.03343810733141644, 0.07262363018734114, 0.028931155601250272, 0.04104703278946025, 0.02502295165322721, 0.032234528700688055, 0.014076045265288224, 0.04302494540544493, 0.028456864712227668, 0.03236587272424783, 0.06329765490123204, 0.0042038569226861, 0.04760721791535616, 0.029247793967702558, 0.012578649945291025, 0.033209512276308875, 0.08129336711551462, 0.026756693442751254, 0.062432577035256794, 0.07437301560172013, 0.05902474346969809, 0.052869782849614105, 0.01777016887042139, 0.10757455509155989, 0.012929359251367194, 0.02248773956671357, 0.03707615765077727, 0.027435835750241364, 0.04347682258646403, 0.037880873041493554, 0.06367156162325825, 0.009771873725445142, 0.021836352734161273, 0.019852216255718043, 0.08733885628836495, 0.07957264302032334, 0.06271942092904023, 0.0037999831256456673, 0.025218761592571224, 0.01575539823222373, 0.022590076218226125, 0.0424706162219601, 0.015202665302370275, 0.05575693239058767, 0.03107664261811546, 0.07162043651832001, 0.10355466258312974, 0.04602848066549216, 0.06857526634952851, 0.01109619511823569, 0.04845699820933597, 0.0257906631367015, 0.02892223625843014, 0.12677094180669102, 0.029552371374198368, 0.03938009277252214, 0.062243781451668055, 0.07261986431798764, 0.02754058798642031, 0.07680021678762776, 0.04804032003240926, 0.03256191506183573, 0.0362484433156039, 0.03044861774625523, 0.044366063084453344, 0.06052282665457044, 0.026985729545620934, 0.034392130960311205, 0.009258041208210801, 0.030010185736630644, 0.023015297151037624, 0.037409107999077866, 0.07190261209117514, 0.001746015003716041, 0.02679860994352826, 0.022567333420738578, 0.013867118395864964, 0.03019891007404242, 0.027283889707177877, 0.045067318848201206, 0.07648015860468149, 0.026523068746817962, 0.029211115757269517, 0.046670144091227224, 0.10225439271224396, 0.018879841647243926, 0.051893696654587984, 0.017341372058061615, 0.05627605578462992, 0.05716445829187121, 0.045906934687601667, 0.03198565223387309, 0.08460594114980527, 0.04313281551003456, 0.020836979217295135, 0.06166355937187161, 0.057473965255277495, 0.022976666456088424, 0.08978046277271849, 0.06421141765479531, 0.0245297364225345, 0.06099733976381166, 0.045005735009908676, 0.005076854564582131, 0.03911733008655054, 0.05539596872404218, 0.04180592331769211, 0.03729817770155413, 0.06713443794952971, 0.03497592213430575, 0.014117549556041402, 0.031322136587862454, 0.020413230705474104, 0.0524670044625444, 0.01125288666558585, 0.04834836475285036, 0.03421245488737311, 0.03678304409342153, 0.03687454793336136, 0.050448383138115914, 0.03233330982870289, 0.012884094180273158, 0.032583706213959625, 0.02037556522658893, 0.03367328417620488, 0.03257797937840223, 0.010599873045326343, 0.015598354694832648, 0.04804348539827125, 0.0589068615809083, 0.010091428944308842, 0.032717859372496605, 0.052545283654970784, 0.06992547639778682, 0.11382993550172874, 0.4604012636201722, 2.2199062407016754, 5.919082658631461, 12.423258355685643, 19.198174953460693, 22.19418954849243, 27.79664887700762, 26.185794149126323, 27.189727204186575, 35.24433783122471, 37.196979658944265, 38.81489896774292, 43.282660143715994, 42.42838607515608, 45.43231814248221, 44.28544848305838, 42.05304091317313, 48.07695191247122, 48.49358674458095, 48.518430028642925, 45.65217999049595, 48.966074671064106, 50.17364031927926, 43.20990555627005, 42.30435030800955, 36.25246933528355, 23.671687500817434, 15.31518633025033, 8.60988633973258, 3.628481319972447, 1.4182535942111696, 0.7420716264418193, 0.12469932011195592, 0.050068250857293606, 0.03505483236429947, 0.029989456491810933, 0.02685227697449071, 0.03084984907348241, 0.055792507981615405, 0.07148502806999854, 0.027853272190051417, 0.0723944753408432, 0.016317213353301798, 0.0501002336053976, 0.015702321526727507, 0.012312430123399411, 0.010675123427063227, 0.058262355093445094, 0.021908404671454003, 0.038661032249884944, 0.005803379396508847, 0.041458082518407276, 0.025045680880014385, 0.05839884241244622, 0.047968039089547734, 0.034884855949452946, 0.10638632492295333, 0.08524930091308695, 0.043008528250668726, 0.03283944606248822, 0.07760122737714223, 0.03689409991992371, 0.026961208986384527, 0.04291221359744668, 0.10707183528159346, 0.015698655741289258, 0.02156869102535503, 0.031661719615970335, 0.03779355236994369, 0.001514390713834603, 0.028927946130612066, 0.056650793712053976, 0.0758352924936584, 0.0315728281358523, 0.020201268240011165, 0.02407768282241055, 0.02904993315626468, 0.01631950001631464, 0.03963702345000846, 0.027903200493061116, 0.02432992143024291, 0.005452697655917811, 0.032277025348906, 0.0373181232384273, 0.02721435174212924, 0.019513184537312815, 0.026629938012255088, 0.03481928911060095, 0.04710267284618957, 0.0232872607718621, 0.017662062974912778, 0.02249642481495227, 0.03593424088986857, 0.01747939795521753, 0.01925014365198357, 0.04735290977571692, 0.11205254694713013, 0.020770253779898797, 0.02326537632117314, 0.02626459949117686, 0.11368319551859583, 0.1633496382938964, 0.1395735948213509, 0.1480261462607554, 0.1900830359331199, 0.0860954544373921, 0.17590666163180554, 0.12370141223073006, 0.08382855036428996, 0.08684643663998161, 0.1925923534269844, 0.14898297563195229, 0.10134310661149876, 0.15230973783348287, 0.10629208319421325, 0.1266002088252987, 0.13887091752673897, 0.12129764764436654, 0.12874359238360608, 0.17070305799799307, 0.1087140596604773, 0.17216312965112074, 0.12127841796193804, 0.18490817504269735, 0.17334091716579028, 0.18377506227365561, 0.10515804083219596, 0.12788418707038673, 0.10814946424216032, 0.19285989978483745, 0.21926260659737246, 0.2871557484780039, 0.07895203453621694, 0.19833936861583165, 0.10631402701671634, 0.13338311628571578, 0.25065857118793894, 0.233397725969553, 0.11951521757457938, 0.1537496027137552, 0.17321286403707095, 0.15850884733455523, 0.18398151333842958, 0.21627056572054112, 0.12520104247544492, 0.16072518697806767, 0.1964191687958581, 0.14589310357613222, 0.13867047828223023, 0.11149306089750358, 0.18666088527866773, 0.16379350876169546, 0.11024539106126342, 0.13898625490920885, 0.08985931532723562, 0.09445427983467068, 0.20743988028594426, 0.152371525232281, 0.1413735310946192, 0.15640215895005635, 0.12013818057520048, 0.14694920262055738, 0.15372345197413648, 0.08460402768105268, 0.09280001145920583, 0.11257936832095895, 0.17297661171427794, 0.159879596637828, 0.08519883147839989, 0.14534704573452473, 0.17002974769898824, 0.11292142460920981, 0.15119594974177225, 0.10646953367229019, 0.16582422836550645, 0.3099841092314039, 0.33939610528094427, 1.6714677725519453, 4.9192794391087125, 10.741174169949122, 16.945000955036708, 19.41328249658857, 26.14532262938363, 24.35673471859523, 25.476789542606898, 34.743000984191895, 38.25071219035557, 41.0615051814488, 43.94546965190342, 44.12099504470825, 49.718502044677734, 48.12237923485892, 45.82891436985561, 51.89918375015259, 51.75726331983294, 54.60848093032837, 51.55804804393223, 55.593964781079976, 56.19958714076451, 51.94566025052752, 46.90528065817696, 38.004214423043386, 25.398443392344884, 14.930481944765363, 7.024671767439161, 2.679079898766109, 0.7648501013006482, 0.43475660255977083, 0.13055769646806376, 0.18588012217410974, 0.22422900795936584, 0.19718777255288192, 0.06517229109470334, 0.10748667802129473, 0.131566352343985, 0.17333885441933358, 0.14206495827862195, 0.17823286966553756, 0.0922133025846311, 0.19356344560427324, 0.11253617956702198, 0.12826362385281495, 0.14253480306693486, 0.13863573728927545, 0.10245481838605233, 0.08239235635846853, 0.10014345669852835, 0.22061085567942687, 0.15827666622187408, 0.11348045604037386, 0.1597670955317361, 0.09549552574753761, 0.1738772719566311, 0.16772696269409998, 0.17536748413528713, 0.1762353168534381, 0.20909056599651063, 0.17158564206744942, 0.08524402869599206, 0.1250519954732486, 0.24272956379822322, 0.09542036442352192, 0.12522624326603754, 0.054811821319162846, 0.18891097525400774, 0.1082467729491847, 0.1484024074992963, 0.15638716332614422, 0.1350503039679357, 0.11457622902733938, 0.1463000210268157, 0.17931237816810608, 0.19201859778591565, 0.13294888101518154, 0.13982489705085754, 0.10998851127390351, 0.183680583057659, 0.08779659601194517, 0.20064824686518737, 0.14801940162267002, 0.09333488025835582, 0.16252296550997666, 0.12233108361916882, 0.10150657926819154, 0.1302884809140648, 0.13503861959491456, 0.14971421925084932, 0.10145967214235238, 0.1256515218743256, 0.11762439832091331, 0.1624588846628155, 0.10568351192133767, 0.2029689180531672, 0.16812706765319618, 0.13987031818500587, 0.07448648701288871], [0.014632697583043149, 0.025851994220699583, 0.01462434820963868, 0.017853302980906198, 0.01549392645912511, 0.03754821785592607, 0.05851746390440634, 0.01330793259798416, 0.05508643461923514, 0.02227701712399721, 0.0823746465944818, 0.036729779094457626, 0.013925688690505922, 0.03507113416812249, 0.03759931832818048, 0.03469578216650656, 0.05739877000451088, 0.07286729211253778, 0.03770866085376058, 0.01730384737519281, 0.009465798452895666, 0.029597290392432894, 0.06352572409170014, 0.049308793752321174, 0.024435642275160978, 0.010438022935496909, 0.02236101127761815, 0.031220838094928434, 0.06051318467195545, 0.032805563416332006, 0.027903802692890167, 0.03504965174943209, 0.05474848346784711, 0.05178217603159802, 0.021476186346262693, 0.027911970558177148, 0.036220837118370194, 0.007011437206529081, 0.0024852820871663944, 0.02966839068436197, 0.04188123731208699, 0.011609604399252151, 0.023008387968210236, 0.04396509638588343, 0.0705090504405754, 0.03076387190126947, 0.03505545322384153, 0.05057116744241544, 0.008912045176007917, 0.06262277718633413, 0.03146828624552914, 0.05659097406480994, 0.06202933045902422, 0.03851266378270728, 0.03162392521543162, 0.03378444178295987, 0.06548877339810133, 0.03658476937562227, 0.10725942985819918, 0.05223474871101124, 0.004441518901980349, 0.07293317107749836, 0.045017745079738755, 0.055135550376560004, 0.05817314809454339, 0.019764615688472986, 0.050940229424408505, 0.019013021108029143, 0.03268606661419783, 0.0074294792388432795, 0.03684301641104477, 0.07559108774044684, 0.02220021713791149, 0.037220309022814035, 0.01514352927915752, 0.04641045177621501, 0.11527057391192232, 0.06484695390931197, 0.09886617559407439, 0.08535059940602098, 0.1037812525672572, 0.18341758288443089, 0.3345416214849268, 0.49909909282411846, 0.8340970426797867, 1.150403904063361, 2.693533020360129, 3.0969931994165694, 2.997102205242429, 3.5418670305183957, 3.505871453455516, 3.302652495247977, 3.68240715776171, 3.9830752526010786, 3.930296301841736, 5.3907924464770725, 5.886305834565844, 7.3573649781090875, 6.031153193541935, 5.230381556919642, 3.833224322114672, 1.2698034857000624, 0.4240605836468083, 0.020133438486871973, 0.04606096213683486, 0.020897584268823266, 0.02037119715740638, 0.053274294893656454, 0.05495164363778063, 0.0526633521408907, 0.0399044849909842, 0.013950584988508905, 0.09451232850551605, 0.11442133305328232, 0.030293708201497793, 0.022681235701643994, 0.008926579396107366, 0.0027680214802135845, 0.10912854956196887, 0.019398966737623726, 0.052031483368149826, 0.05431004806554743, 0.07077753996210438, 0.029723321486796652, 0.023226284222411256, 0.04655959038063884, 0.011803226911329796, 0.04107530055833714, 0.012090436365854527, 0.007901245129427739, 0.02093133290431329, 0.06303568610123225, 0.02474956650153867, 0.030253711954823563, 0.01593720490512039, 0.043399907249425135, 0.0806199007534555, 0.05281451617234519, 0.012621909097236182, 0.04105771293065377, 0.03194506226905754, 0.013276513882114418, 0.14224945195019245, 0.09867151746792452, 0.01925067460563566, 0.012033358848254596, 0.04115285371829357, 0.03737104896988187, 0.023784635422219123, 0.027011652976008396, 0.06606907011674983, 0.02020923254479255, 0.017783931256937127, 0.011965867514455957, 0.009708940450634276, 0.04239312752283045, 0.013046262353392584, 0.06332561732935053, 0.021119337994605303, 0.028974127223981277, 0.028947067247437577, 0.08121639410299913, 0.03777202245380197, 0.04470481490716338, 0.07544879894703627, 0.06110287231526204, 0.021855190562616502, 0.042248049950493236, 0.017990976039852415, 0.06401915475726128, 0.017497299405347024, 0.06183906923979521, 0.03171823140499847, 0.03202935667442424, 0.005483527742658875, 0.032815252896398306, 0.037598443018006425, 0.0382844826339611, 0.057536845095455647, 0.07177696776177202, 0.006773902876635215, 0.07536274035062109, 0.05407639792455094, 0.036626377142965794, 0.076345259057624, 0.042533672481243096, 0.02950101645131196, 0.07250402481960398, 0.04220524796151689, 0.05270169276211943, 0.013125723893088954, 0.0070225032645144635, 0.047323322256228754, 0.06410511157342366, 0.018339877050103884, 0.03371408109420112, 0.02812984136731497, 0.0634550614548581, 0.04696146631613374, 0.05520960908117039, 0.11456107055502278, 0.018723152644400085, 0.038113461275185855, 0.010309225962763386, 0.039526524022221565, 0.036454456725290844, 0.011813099595851131, 0.03796826495922037, 0.04288250733433025, 0.0014168847015493416, 0.00898335242111768, 0.016996893399794186, 0.07957707385399512, 0.052798899688891, 0.04672728352514761, 0.05171131322692547, 0.007482451619580388, 0.02715546338419829, 0.005379899754188955, 0.027767917573718087, 0.05432217348633068, 0.018788193618612628, 0.023148140736988614, 0.04569359988506351, 0.05071161062057529, 0.032276000761027844, 0.020891087296019708, 0.029901694772498946, 0.017190988341878568, 0.01794465075779174, 0.011230392381548882, 0.021294111652033668, 0.039723702905965705, 0.033944813534617424, 0.0014475171649662244, 0.0016001281723479874, 0.017366547403591018, 0.04180391485403691, 0.02292381027447326, 0.03514902998826333, 0.042980952587510855, 0.028982127151851143, 0.06481519168508904, 0.009433749547627355, 0.04374640454937305, 0.04165092556338225, 0.022062572916703563, 0.005707850995739656, 0.03889746777713299, 0.05951524964932885, 0.03681089456326195, 0.05975902692547866, 0.07373937245990549, 0.1097098912245461, 0.12061824410089425, 0.1276673815612282, 0.5856339122567857, 0.987436077424458, 1.5508290231227875, 1.468824646302632, 2.489197790622711, 3.8551280839102606, 5.9678772517613, 6.589561241013663, 6.801016637257167, 8.294739501816885, 7.532369256019592, 7.176597169467381, 7.53705494744437, 8.881753717150007, 9.169254541397095, 10.682821461132594, 10.616784913199288, 12.19155330317361, 11.622745973723275, 9.350073593003408, 6.819828450679779, 2.7489140714917863, 1.1145349144935608, 0.21489357389509678, 0.042107817118189166, 0.14506218316299574, 0.033955585278038464, 0.01939880388921925, 0.01050791034608015, 0.019069161399134567, 0.026321978108691316, 0.05185265207130994, 0.06452433086399521, 0.028415302745997906, 0.07657475995698146, 0.030514092982879708, 0.04896500380709767, 0.027213071007281542, 0.043869042968643565, 0.013673674847398485, 0.07804018525140625, 0.021426839887031486, 0.026354825988944088, 0.08135424527738776, 0.04996702361053654, 0.03920216731993215, 0.01811573318471866, 0.005257631136503602, 0.041440834158233235, 0.019595512887462974, 0.02526035070020173, 0.028538711302514588, 0.05639926078064101, 0.02392283434580479, 0.09052252902516297, 0.01928240290310766, 0.05376031256413885, 0.04818178101309708, 0.0038919059609595153, 0.035043005498924425, 0.007584002018640084, 0.04733943746292165, 0.0662025243842176, 0.0760833988232272, 0.03421548115355628, 0.050501532786126645, 0.019704220982800637, 0.06135913463575499, 0.02153703736673508, 0.02517853125131556, 0.04709176878843989, 0.056664601899683475, 0.019432096209909235, 0.045978903504354615, 0.034669214127851386, 0.014384923735633492, 0.04709702404215932, 0.05033279469768916, 0.01586022849992982, 0.012374871460321759, 0.06397031380661897, 0.0096207970553743, 0.06219823139586619, 0.039018236832427125, 0.10163701405482632, 0.1152933726885489, 0.03728173001270209, 0.03988981845655611, 0.023195186962506602, 0.03892616980842181, 0.08247493407023804, 0.007058765872248581, 0.03177964900221143, 0.03483680549210735, 0.04858575022912451, 0.003199917501271037, 0.13464000741285936, 0.10062440910509654, 0.09988412061440093, 0.11760676998112883, 0.1285267597330468, 0.15728327738387243, 0.11040988830583436, 0.10793004637317997, 0.1455276988978897, 0.06432407482394151, 0.1839074037436928, 0.1471422729747636, 0.11481220993612494, 0.09143914841115475, 0.15414153811122688, 0.1485092089112316, 0.20281402207911015, 0.1223940516688994, 0.12600232447896684, 0.08301562469984804, 0.1401190691228424, 0.19472716030265602, 0.11583104383732591, 0.2243648778115, 0.2562548023249422, 0.16985697911253997, 0.12655109646064894, 0.12193281070462295, 0.11839243210852146, 0.12754790511514458, 0.08919652232101985, 0.11040337436965533, 0.1576763391494751, 0.16415415012410708, 0.1290053440523999, 0.1825691969799144, 0.15000779421201774, 0.0798535497326936, 0.19394866350506032, 0.11086103945438351, 0.16736976828958305, 0.09241794196090528, 0.07923587251986776, 0.11392851306923799, 0.159127250579851, 0.1395204791000911, 0.10870630400521414, 0.25005456645573887, 0.09233402074979884, 0.1309334555906909, 0.10374208752598081, 0.17805840474154266, 0.11542678624391556, 0.17709332438451902, 0.12178653212530272, 0.16592699927943094, 0.11790700815618038, 0.11267335220639195, 0.1457004946257387, 0.16678309334175928, 0.08470764676375048, 0.19242844650787966, 0.14945005199738912, 0.19553260851119245, 0.16213320142456464, 0.09507328697613307, 0.15773913078010082, 0.0948307921311685, 0.13199859272156442, 0.12462877961141722, 0.1733691170811653, 0.096376399908747, 0.10709934309124947, 0.1236781927623919, 0.2109198421239853, 0.12607825254755362, 0.2117441264646394, 0.19964324150766644, 0.20886940429253237, 0.1946847111518894, 0.39603725022503306, 0.5936324287738118, 0.7766621474708829, 0.8079615022454942, 1.5349093973636627, 2.3657267817429135, 4.411921543734414, 4.681027012211936, 5.119658972535815, 5.939153398786273, 5.222956103937967, 5.045679330825806, 5.7775013872555325, 6.636445948055812, 6.773497862475259, 8.388434222766332, 9.018833858626229, 11.07561354977744, 9.961635793958392, 8.834739599909101, 5.567726152283805, 1.9812434358256203, 0.7487645330173629, 0.2115371325718505, 0.15042104917977536, 0.19563167462391512, 0.17369181476533413, 0.10957917145320348, 0.1277977145676102, 0.17309293975787504, 0.11151449581874268, 0.14819907769560814, 0.1826805988592761, 0.11328455619513988, 0.1058399278138365, 0.137639118624585, 0.11300568508782557, 0.10875913474176611, 0.21010352378445013, 0.17765055091253348, 0.1464219537696668, 0.07812488677778415, 0.21244199973131928, 0.11379532343042748, 0.13048716953822545, 0.07956179324537516, 0.10931968609137194, 0.15057191465582165, 0.06378658687961952, 0.13389466383627482, 0.16102243959903717, 0.12393219556127276, 0.1864350823951619, 0.15799700122858795, 0.1246163352791752, 0.10325072639222656, 0.20241660411868775, 0.15070973868880952, 0.06944845949432679, 0.09492193295487336, 0.0904685447790793, 0.1433965153992176, 0.1415104323199817, 0.26369751723749296, 0.1362166242407901, 0.12648454574601992, 0.1736856943794659, 0.09839973705155508, 0.057539688157183785, 0.12025613710284233, 0.18652709174369062, 0.12292079840387617, 0.14274134912661143, 0.10585155790405613, 0.11465826391109399, 0.06896949519536325, 0.10069378252540316, 0.11357123045516865, 0.12683834747544356, 0.14004969570253575, 0.10448050326002495, 0.1960736723350627, 0.17142393360180513, 0.18339747110647814, 0.22637996396848134, 0.23346229536192759, 0.14833014351981028, 0.12767567325915608, 0.07109857523547751, 0.16806187400860445, 0.1657529143350465, 0.09420482322041478, 0.08856016503913061, 0.09739107439028365, 0.11511345234300409, 0.08955538592168263], [0.025874340075201223, 0.041468762659600804, 0.026039142660530548, 0.05661306716501713, 0.02231892683942403, 0.05630172476438539, 0.019317583247487034, 0.025561503201190914, 0.062488800446902, 0.0359821183207844, 0.07482830581388303, 0.02787885465659201, 0.023040945774742534, 0.05210421892947384, 0.03463729923324926, 0.044661137608012984, 0.04241350392944046, 0.035348797483103614, 0.07338807452470064, 0.019430126762017608, 0.0453510686222996, 0.07603355364075728, 0.01837035345046648, 0.01254279276223055, 0.05488124562959586, 0.0712359378646527, 0.05274178400369627, 0.10529334750026464, 0.025182244534205114, 0.06982486322522163, 0.08337612356990576, 0.04973685774686081, 0.032050018065742085, 0.035606159030326774, 0.07710190702761922, 0.030443647477243627, 0.02757333408642028, 0.01919607289268502, 0.06779074416096721, 0.03576904475422842, 0.02705213607155851, 0.06753107559468065, 0.08634893476430859, 0.047661409114620516, 0.06775945691125733, 0.062152023161096234, 0.048773799424192736, 0.0018797167244234256, 0.011976227047853172, 0.05566244638924088, 0.05541985994204879, 0.007087139238137752, 0.038038313521870544, 0.06247613898345402, 0.05244467726775578, 0.0077926252436425, 0.00498887401772663, 0.10079514208648886, 0.07590982956545693, 0.05333477271986859, 0.023961347993463278, 0.10076101177505084, 0.026538103386493664, 0.003560419551961656, 0.03917250516159194, 0.034904947371355126, 0.05641097568773797, 0.041189942442412884, 0.0720828106360776, 0.033651645694460185, 0.05482406209089926, 0.039404716808348894, 0.03616144834086299, 0.0555011314739074, 0.029058201105466912, 0.019649717657427703, 0.04280589733804975, 0.0709213622446571, 0.012888441893405147, 0.019285307032987475, 0.049486349403325997, 0.01391517139771687, 0.03798115712457469, 0.013425510842353106, 0.03915390312405569, 0.149155907066805, 0.01614283663885934, 0.03595199815130659, 0.04676491168460675, 0.0301562980748713, 0.034090169306312285, 0.03114059115094798, 0.03268009889870882, 0.03965827855946762, 0.07726400225822415, 0.014547280202220594, 0.015002623000847442, 0.07550272212496825, 0.028017674439719746, 0.025223521515727043, 0.044634237087198665, 0.00996187879770462, 0.030444505824042217, 0.07241308755640473, 0.055210199406636615, 0.053723447756575685, 0.050131405504154306, 0.06517635551946503, 0.03545705435265388, 0.12201043511075632, 0.08318234075392995, 0.0011708859653611267, 0.07518442813307047, 0.03002001770905086, 0.06544828521353857, 0.018727612315810153, 0.02543518881845687, 0.0435587183705398, 0.04589229190189924, 0.045528759980308156, 0.016067831377897943, 0.056505437940359116, 0.010709787236659654, 0.017402474136490906, 0.025098297878035476, 0.039727838576904366, 0.02561935000786824, 0.025211396094943796, 0.05220152085114803, 0.022527026744293313, 0.015409245288797786, 0.06429599704486982, 0.0077659647545910305, 0.03140824268172894, 0.09065560331302029, 0.022234403428488543, 0.04158672936526792, 0.053118313263569555, 0.028101590561813543, 0.01814808912708291, 0.07650499298636403, 0.0346878331287631, 0.01797453174367547, 0.0463857056040849, 0.05738457505192075, 0.03177651756310037, 0.05590459857402103, 0.04831208009272814, 0.014423216859410917, 0.04005754892049091, 0.05621186637186578, 0.048360171262174845, 0.004097601307356464, 0.04668796920616712, 0.04998536101941552, 0.006186248717962631, 0.10331312447254147, 0.022018052537792494, 0.050132436877382655, 0.0357101139878588, 0.05183700166110482, 0.06856458620833498, 0.06970401613840035, 0.029403860414666787, 0.019967813177832534, 0.044720909757805724, 0.027608110702463558, 0.022067415960399166, 0.08960658817418984, 0.11411781076874052, 0.04083254447739039, 0.03072949731722474, 0.03109577391296625, 0.07908295108271496, 0.046113297542823214, 0.07093283627182245, 0.054996688184993606, 0.02849043353593775, 0.020695250215274946, 0.06442965487284319, 0.046279100967305045, 0.05788591743579932, 0.011434084353303271, 0.03857450885698199, 0.01449361486759569, 0.03650430190776076, 0.06933714582451753, 0.015873790718615055, 0.04556541104934045, 0.028863607440143824, 0.011953923601790198, 0.02306538151710161, 0.07874964789620467, 0.023201405735952512, 0.0924961499071547, 0.04879889164918235, 0.012097047841442483, 0.0669429689379675, 0.027021495126453892, 0.029076999918158566, 0.09959523433021136, 0.10559899359941483, 0.033125574101826975, 0.04037854348176292, 0.024939510505646467, 0.06950036063790321, 0.006176045671704092, 0.04841957700305751, 0.04752241460872548, 0.04575598778735314, 0.0570018541600023, 0.03555496356316975, 0.06037524528801441, 0.06478337517806462, 0.05473579825567348, 0.06546873625900064, 0.04239774834630745, 0.011540617743906165, 0.03890261107257434, 0.006919122093157577, 0.07371856179088354, 0.023794084022353803, 0.04332874928201948, 0.11699846333691052, 0.02109523643074291, 0.01972830219061247, 0.024036914742152606, 0.01320769770869187, 0.05482619269085782, 0.073320119242583, 0.04946438522477235, 0.031989119547818384, 0.012391764437779784, 0.023116409046841518, 0.05342214088886976, 0.01937672944872507, 0.06984910049608775, 0.033135188943041224, 0.03411890187167695, 0.040718886469091685, 0.0058943802723661065, 0.011340111494064331, 0.04597075769145574, 0.028294655827007124, 0.01221453957259655, 0.07459628754960639, 0.05090849094891122, 0.007169611352894987, 0.0489663948038859, 0.01194741899546768, 0.02945950367887105, 0.07444262650928327, 0.02685852119299982, 0.016228245537994162, 0.010153357987292111, 0.06002518228654351, 0.007647160058175879, 0.045820974478764195, 0.06461191616420235, 0.03336914103212101, 0.03208446728863886, 0.0979205963334867, 0.07853148531700883, 0.04761430182095085, 0.056509865381355794, 0.11473378485866956, 0.06930636069072144, 0.040697264950722456, 0.10424711435501065, 0.0322466575141464, 0.05671145813539624, 0.017408769245126417, 0.07615186979195901, 0.08131381816097669, 0.048809826241007874, 0.02444486865507705, 0.043264261313847134, 0.028061536639662724, 0.04091175665546741, 0.058199515965368064, 0.06360131967812777, 0.07152581480996949, 0.037153222265520265, 0.04103678012532847, 0.023433703895924345, 0.10975037940910884, 0.04324405454099178, 0.022884134635595337, 0.031493127412561855, 0.021445618343672583, 0.03660962411335536, 0.07534474560192653, 0.033917984259980063, 0.036593644613666196, 0.031770020590296814, 0.02445781001422022, 0.02487920400952654, 0.06881367641368083, 0.010999708286752658, 0.026158293409805213, 0.007994603914474803, 0.005263810894185943, 0.06002239350761686, 0.04326424774314676, 0.028188219127644385, 0.006726888457446226, 0.03287291819495814, 0.05392121018043586, 0.025499256094917655, 0.01799142556930227, 0.038817712771041055, 0.011930472583376935, 0.03575243082429681, 0.044678609884743176, 0.03876148596672075, 0.06268894113600254, 0.05327856627159885, 0.03587883850559592, 0.03596518887206912, 0.054492183827928135, 0.05333514591412885, 0.05874860007315874, 0.026033520997901047, 0.0469697681920869, 0.013453564024530351, 0.03731318011081644, 0.06368849785732371, 0.0021117519520755324, 0.018635648768395185, 0.07205098055835281, 0.03207045554050377, 0.029451982118189335, 0.06109090295753308, 0.0406861471544419, 0.04626161511987448, 0.012398444615038378, 0.049640817900321314, 0.09063010396701948, 0.07355316888008799, 0.042871535423078706, 0.02957145177892276, 0.041674698037760596, 0.02220747576627348, 0.04201076286179679, 0.025716578987027918, 0.01322705376826759, 0.029516911134123802, 0.02322757683162178, 0.05143907819209354, 0.012383231011751508, 0.021183203406898037, 0.029753828421235085, 0.14438405526535852, 0.1322624749903168, 0.16980558687022754, 0.21990889763193472, 0.08689235310469355, 0.1525067844028984, 0.14617306712482656, 0.11024637493704047, 0.11086420821292059, 0.17137848532625607, 0.14914306918425219, 0.1142247071755784, 0.14898404771728174, 0.13117289702807153, 0.18363552833242075, 0.1538374458572694, 0.13300012397978986, 0.11676058253007275, 0.23112077957817487, 0.0815824908869607, 0.12356061621436051, 0.11342793064458029, 0.04555900567876441, 0.11427604513508932, 0.32174390820520266, 0.1737147628196648, 0.1423030969287668, 0.2125813572534493, 0.06774955029998507, 0.2624279782176018, 0.1746304729687316, 0.12858477447714123, 0.08390130967433963, 0.11637411612485137, 0.1009035109143172, 0.18060928929064954, 0.217339353369815, 0.1562430424881833, 0.1489771538014923, 0.16581026411482266, 0.13852512251053536, 0.19886182700949057, 0.09838643097983939, 0.14976377944861138, 0.1517504621297121, 0.14154062712831156, 0.12907040198998793, 0.2049843706190586, 0.1253455297223159, 0.10038467589765787, 0.1578593264733042, 0.12110050608004842, 0.17722396951700958, 0.2370237899678094, 0.15909875210906776, 0.11564361889447484, 0.11288120783865452, 0.15979077640388692, 0.20364001632801124, 0.08660538707460676, 0.1252079771033355, 0.17504678134407314, 0.09470927329467875, 0.10396451809044395, 0.13676376773842744, 0.19227222060518606, 0.11797860717134816, 0.17517560800271376, 0.11473214280392442, 0.10297086462378502, 0.1694517715701035, 0.10157541664583342, 0.12343881917851311, 0.14786191364484175, 0.16949331148394517, 0.11333788226225547, 0.11971990444830485, 0.1362117523593562, 0.10636833017425877, 0.08232290829930987, 0.0856265053153038, 0.11958244682422706, 0.11953163812203066, 0.07264502439647913, 0.11484146836612906, 0.225032881966659, 0.10096782924873487, 0.08183031901717186, 0.16275218820997647, 0.15793893220169203, 0.14317213743925095, 0.10914232382284743, 0.17562473033155712, 0.10712584666907787, 0.25600952548640116, 0.06276446208357811, 0.12812361493706703, 0.1666794131909098, 0.13650983279304846, 0.10028305170791489, 0.13203672638961247, 0.21125978816832813, 0.14473324295665535, 0.24138199325118745, 0.16117603278585843, 0.0960656376555562, 0.1366956563932555, 0.1630754830049617, 0.10164122775729213, 0.33804234649453846, 0.16794414818286896, 0.12746726801352842, 0.1137937560145344, 0.07445410053644862, 0.11302458907344512, 0.14243982173502445, 0.08652506888444934, 0.12294494067983967, 0.17748726824564592, 0.1506017701966422, 0.07735464775136539, 0.20534189072038445, 0.11605551679219518, 0.13998509916876042, 0.15165815422577517, 0.2201173843017646, 0.12448343741042273, 0.1138666035341365, 0.16473390401474067, 0.1402496735432318, 0.15421271643468312, 0.16883609603558267, 0.12932821815567358, 0.061565110726015906, 0.1770750039390155, 0.10671252384781837, 0.1584829951503447, 0.14186949948115007, 0.27986844522612436, 0.1497498151979276, 0.10898441515330758, 0.12090443660105978, 0.08219212745981556, 0.12059016632182257, 0.10179739259183407, 0.11045343668333121, 0.1669688762298652, 0.18518610298633575, 0.1372329747038228, 0.09274438515837703, 0.17602894721286638, 0.10397832627807345, 0.09067129104265145, 0.13301605598202773, 0.1676075676722186, 0.11200750579259225, 0.17254655621945858, 0.16844744474760123, 0.12749119315828594, 0.13176749726491316, 0.1565236710011959, 0.22937414901597158, 0.15131371627960885, 0.1248412017843553, 0.0957928801487599, 0.11895697324403695, 0.094781944395176, 0.13461606869740145, 0.19348307991666452, 0.1869657782039472, 0.07992168143391609, 0.10140439867973328, 0.13808701959039482, 0.13146135583519936, 0.19620709946112974, 0.13098288008144923], [0.02223455609886774, 0.07109305196042572, 0.06515184683459145, 0.014815725618973374, 0.030359895899891853, 0.009253861432495927, 0.013482090484883105, 0.05106471685160484, 0.029549060123307363, 0.006135634670499712, 0.04775829373725823, 0.00604026360503797, 0.022094472544267774, 0.042845958045550754, 0.0417106943204999, 0.057542130883250914, 0.0742587638752801, 0.025304041570052505, 0.012254707997531762, 0.03862642017858369, 0.04598559046696339, 0.043247294545705826, 0.04040438888062324, 0.012340261085358049, 0.0447747379408351, 0.05405349736767156, 0.04940944424431239, 0.05416379662762795, 0.05434868724218436, 0.01839885701026235, 0.018317346294809665, 0.02515199883574886, 0.0034286115800828804, 0.03538044435637338, 0.021189883584156632, 0.022983840267573084, 0.011989349915113832, 0.020651929147009338, 0.047475582121738365, 0.013685506801786167, 0.04658853668453438, 0.03892317407631448, 0.05628376733511686, 0.03859246289357543, 0.02491686779207417, 0.04666540791679706, 0.030426090383636098, 0.026191684118072902, 0.007193782466596791, 0.027363929697977643, 0.012553311751357146, 0.023456797835284045, 0.023636967542448213, 0.02349066691073988, 0.0036379773768463303, 0.018423625234780566, 0.0497055365704, 0.03134143412379282, 0.025592208607122302, 0.034685655031353235, 0.01055217457802168, 0.01027857229512717, 0.06500535112406526, 0.03913338761776686, 0.07579582889697381, 0.04212318254368646, 0.017003890792173997, 0.010945085369582688, 0.055277208132403235, 0.040121612804276605, 0.03983041271567345, 0.03960052165868027, 0.10601380919771534, 0.03589949311156358, 0.04910604070339884, 0.06411404787961926, 0.027264992506908517, 0.038561158680490086, 0.05481446760573557, 0.017029702264283384, 0.04402415607390659, 0.015139519137197306, 0.00966610707941332, 0.08810693078807422, 0.051703968085348606, 0.03764651383140257, 0.05374875711277127, 0.016678183805197477, 0.044152348302304745, 0.041949324908533266, 0.011240921548700758, 0.04009220509656838, 0.05679161686982427, 0.012282778991253247, 0.0722360849114401, 0.05598925260294761, 0.055158583247768025, 0.06819956829505307, 0.014511392485084278, 0.01170232196870659, 0.01575213617512158, 0.023408657472048486, 0.03303115256130695, 0.05096345228542175, 0.004671337016459022, 0.01401240546588919, 0.010684237000532448, 0.07440998897488628, 0.038188629384551726, 0.04177453089505434, 0.04397484014875122, 0.027917731320485473, 0.05026990467948573, 0.006462905680694218, 0.06886217131146363, 0.020470297196879983, 0.06432444123285157, 0.07100879148180995, 0.030402874307973043, 0.03177982881399138, 0.03992651702303972, 0.036816621398819346, 0.05337866375754986, 0.02441656356677413, 0.017832283662366014, 0.010773004648009581, 0.030944626844887222, 0.03816471441781946, 0.03496409187625561, 0.019948356186172793, 0.028383372584357858, 0.027787281266812767, 0.034676769615284035, 0.0771963455315147, 0.055053783514137776, 0.006177085526620171, 0.023072984501985565, 0.03888328639524324, 0.017024959304503033, 0.03129605030907052, 0.07463621255010366, 0.05130972906148859, 0.025533182845850075, 0.006950171431526542, 0.03434533240007503, 0.023518237484885112, 0.03496077044733933, 0.05701689728136573, 0.01776311549890254, 0.04475423600524664, 0.0696519317903689, 0.024658345949969122, 0.03609415123771344, 0.07430898903736047, 0.0178132643257933, 0.024467859117846404, 0.02655301080085337, 0.0201089518543865, 0.06848338592265334, 0.10749836917966604, 0.003867778103865151, 0.0316082714125514, 0.02865143971783774, 0.016027285517858605, 0.0342029689678124, 0.11817991494068078, 0.04309252749330231, 0.06440682895481586, 0.07230784677501235, 0.015222137561067939, 0.0468801065747227, 0.04646868704419051, 0.030767288325088363, 0.018164996523410082, 0.03818478887634618, 0.05627225938120058, 0.031831512826361825, 0.028211616711424928, 0.03171701004196491, 0.019372972061059306, 0.024405315152502487, 0.021143263139362847, 0.037132981565913985, 0.007167247506523771, 0.022546519359041537, 0.04199847798528416, 0.05653150386310049, 0.013965702748724391, 0.04843100353277155, 0.06547429346080337, 0.02709758434710758, 0.03501257998868823, 0.03116680635139346, 0.022077722907332436, 0.07948535627552442, 0.016055420972406864, 0.07899530471435615, 0.03529410756060055, 0.010357189058725323, 0.03796367806249431, 0.04341336599152003, 0.09781768971255847, 0.05889369121619633, 0.024332637266655053, 0.027926940737026076, 0.042570075884993584, 0.022021962595837455, 0.011670301053007799, 0.015022712726412075, 0.05317804470126118, 0.022515956445464065, 0.06304726869400058, 0.08116193488240242, 0.01609866740182042, 0.07571783129658018, 0.0592049148731998, 0.05603502996798072, 0.022858265488009368, 0.0014217689874515469, 0.03175513353198767, 0.01773035922087729, 0.007619474133077476, 0.06857878116092511, 0.04572863943342652, 0.012773679569363594, 0.035024936111377816, 0.03929674492350646, 0.022385597994018878, 0.05463901202061346, 0.04624451943007963, 0.06995521658765418, 0.012077735038474202, 0.044431592603879314, 0.03210240096918174, 0.05041319091937371, 0.04659212952745812, 0.03266096421118293, 0.034328640438616276, 0.04834758443757892, 0.02326965787714081, 0.046248665279043574, 0.06463637735162463, 0.024581101523446183, 0.030156050409589494, 0.06464257237634488, 0.017083710259092704, 0.014464334385203463, 0.01033185001662267, 0.016414790081658533, 0.04335830287475671, 0.08847190120390483, 0.033936057040201764, 0.033036129615668736, 0.03672708531043359, 0.09009237853544098, 0.02096155485404389, 0.04220427765644022, 0.012098231885050024, 0.013544852429601763, 0.07348479290625878, 0.027071421733126044, 0.03916324994393757, 0.038086062031132836, 0.024177883784951906, 0.013853340742311307, 0.058315844008965154, 0.06331641639449767, 0.09137352728950125, 0.021215028395610194, 0.024570587623332227, 0.031357050607247014, 0.008936443598940969, 0.029819754883646965, 0.10173670441976615, 0.04551124699147684, 0.03440387640148401, 0.023140636139682362, 0.03090813523158431, 0.017140630865469575, 0.0004424804782112395, 0.01615202909202448, 0.05364386238423841, 0.08522483972566468, 0.02705340662838093, 0.06460268808794872, 0.043695097123937945, 0.05558109682585512, 0.024209615475099002, 0.04277741922331708, 0.03885530361107417, 0.049869104221995385, 0.01149122039454856, 0.045696599009845934, 0.00977220366309796, 0.04896455258131027, 0.0786499846726656, 0.027624931585575854, 0.07898621234510626, 0.012873441180480378, 0.023506485258362124, 0.0303071601582425, 0.02600076811255089, 0.010667577269487083, 0.04557127019922648, 0.036675017925777605, 0.043045532157910724, 0.003040720463364518, 0.02038478821382991, 0.058198979922703335, 0.04809094213747552, 0.03302306442388466, 0.06338475165622574, 0.04063793724136693, 0.014171677990816534, 0.030464095130030597, 0.06500661319919995, 0.05839206384760993, 0.020708405312948992, 0.018112109807719077, 0.02384475871388401, 0.035029651929757426, 0.03234924522361585, 0.02903700027880924, 0.047627821631197415, 0.008201231398353619, 0.0644904448251639, 0.03170911528702293, 0.04931192858410733, 0.02969918938885842, 0.0201730852880116, 0.04847085050174168, 0.0270531945861876, 0.03235166420095733, 0.023794660777119652, 0.07173576033008949, 0.10467782124344792, 0.05658458226493426, 0.006549820079401667, 0.05438321788928338, 0.025263748464307616, 0.023126561627058045, 0.11527494367744241, 0.03468068136966654, 0.04921120345326407, 0.05065536006752934, 0.023838075143950324, 0.046274235871221335, 0.007650513717505548, 0.02608279960363039, 0.044864654008831294, 0.007329357155997838, 0.059682657809129784, 0.11654628760048322, 0.12677854139889988, 0.18380886688828468, 0.1262070792061942, 0.13876957153635366, 0.10276288685521909, 0.07378959762198584, 0.19358011042433126, 0.07259052446378128, 0.12848606120262826, 0.15231257410986082, 0.0929723254271916, 0.1737747181739126, 0.08858679753861257, 0.18739402879561695, 0.171609350081001, 0.2695433949785573, 0.13487958455724375, 0.11013834537672144, 0.08001319545188121, 0.13001059368252754, 0.19476293266883918, 0.10726586915552616, 0.10140539612621069, 0.10674533101597003, 0.13018800344850334, 0.10973695120108978, 0.17026226807917866, 0.13078648490565165, 0.1252683802906956, 0.09911502152681351, 0.09932118082152945, 0.08647110499441624, 0.07432831371469156, 0.08220803910600287, 0.15541940954114708, 0.18783737000610146, 0.07578389346599579, 0.22519193057503017, 0.1579512951097318, 0.14032139469470295, 0.12387111383889403, 0.16418273001909256, 0.23522985194410595, 0.08380376348005873, 0.17784322771642888, 0.1827164390789611, 0.1888295646224703, 0.10055468284658023, 0.11851186784250395, 0.12648451860461915, 0.11299887259623834, 0.18260943410652025, 0.1316503006964922, 0.22293502810810292, 0.11783536842891149, 0.11179701065910713, 0.11850984580814838, 0.1071964210963675, 0.10650126875511237, 0.1281094742672784, 0.12038177464689527, 0.1336080642150981, 0.18762317007141455, 0.1565638402742999, 0.1296231366161789, 0.11407727508672647, 0.0927881303110293, 0.26729616842099596, 0.17034183309546538, 0.12776283786765166, 0.12418672761746816, 0.17019151044743402, 0.09245210619909422, 0.16339906278465474, 0.16048968104379518, 0.09923931557152953, 0.12556761423391954, 0.10289289416479212, 0.20106470451823302, 0.2617996005075318, 0.10901197046041489, 0.10047871406589236, 0.16156027359621866, 0.15379673375615052, 0.12721060535737447, 0.19506957621446677, 0.11938408389687538, 0.08631291134016854, 0.15999834026609147, 0.0907162439876369, 0.1541072449513844, 0.11526665197951452, 0.1202370702688183, 0.15397024873111928, 0.136875128905688, 0.12932083569467068, 0.2516649200447968, 0.09372088525976453, 0.13151713141373225, 0.13600839541426726, 0.1026944498132382, 0.10037077950047595, 0.13709433642881258, 0.04402671754360199, 0.07935765598501478, 0.14873347830559525, 0.19424906452851637, 0.18789143567638739, 0.15735456427293165, 0.13789103153560842, 0.11666668685419218, 0.20781321025320462, 0.17794356947498663, 0.16908891818353108, 0.11049043041254793, 0.10117508098483086, 0.15375467815569469, 0.152198729504432, 0.15259975727115357, 0.12235552445054054, 0.11084044591656753, 0.1838651852948325, 0.14149021197642597, 0.12747874882604393, 0.11317818904561655, 0.09740858059376478, 0.15858389330761774, 0.09144216789198772, 0.10976158202226673, 0.07179131877741643, 0.09413860498794488, 0.13955789352101938, 0.19915651476808957, 0.16584894061088562, 0.22761727257498673, 0.10992698850376265, 0.0982564508116671, 0.08922117349824735, 0.1834997534751892, 0.23147025225417955, 0.12194446793624333, 0.08569786684321505, 0.06251914453293596, 0.18677247714783463, 0.07544007977204663, 0.13721903759453977, 0.1884122927274023, 0.16042479952531202, 0.12570337552045072, 0.14615560163344654, 0.1694920901209116, 0.19334575799959047, 0.15026296409113066, 0.07107266876846552, 0.083270577447755, 0.11302421587918486, 0.12351914415402071, 0.22367326063769205, 0.24784132093191147, 0.10130272699253899, 0.094586953786867, 0.1303738406194108, 0.10915023554116488, 0.13709968328475952, 0.27501906401344706, 0.11689793158854757, 0.12126423658004828, 0.14733988951359475, 0.06241519296807902, 0.13951670644538744, 0.13014437364680426, 0.10905643486018692, 0.10475571027823857, 0.14944083749183587, 0.14774572130824837], [0.010383460238309843, 0.015003277787140437, 0.012818461184256842, 0.039756550786218474, 0.04282594465517572, 0.04904771722587092, 0.012973218906803854, 0.004159504905276532, 0.019807112336690937, 0.04930123487221343, 0.023770608407046114, 0.03236034266384585, 0.06459869830203907, 0.006629413933426673, 0.034507217284824164, 0.05888090083109481, 0.07187232228794269, 0.03738923370838165, 0.05676884862727352, 0.01871281346705343, 0.025965477506230985, 0.03135712185342397, 0.07902055978775024, 0.0008032495430338063, 0.09648211566465241, 0.027871955651789904, 0.05506185129550951, 0.01978227965134595, 0.011427220971589642, 0.06350268782781703, 0.025477651539923887, 0.029447459682290043, 0.044804291533572335, 0.03230316251782434, 0.05261372408962675, 0.07900791868035283, 0.024390570586547256, 0.06291806205574955, 0.012262623108524297, 0.007572895248553583, 0.05233138906104224, 0.055949744901486805, 0.07724570895412139, 0.03726779290341905, 0.0061116832325101966, 0.031735581545425315, 0.037961089451398165, 0.01522557603727494, 0.023288687391738807, 0.02476502183292593, 0.018322626993592297, 0.010218788270971604, 0.029835588498307124, 0.10098902668271746, 0.05665237469864743, 0.04593993863090873, 0.048882147895970514, 0.03480106705267515, 0.04204025199370725, 0.02648240075047527, 0.07017936384571449, 0.055708101617970636, 0.029291919099965265, 0.019500348351097534, 0.012628199116859053, 0.017621922539547086, 0.041331579842205556, 0.023237500406269516, 0.010655556173462952, 0.015861119077141796, 0.06457169939364706, 0.03869016854358571, 0.050018653340105496, 0.01202287887489157, 0.036324232284511836, 0.05212446302175522, 0.028871807535844188, 0.021607567689248493, 0.02908450790813991, 0.021876269252970815, 0.034737495106777976, 0.031055112701973746, 0.02694144835030394, 0.04107928355889661, 0.0576358162132757, 0.08265095283942563, 0.06638434462781463, 0.0103697012444692, 0.062348560829247744, 0.021796346309461763, 0.031526558832930665, 0.04114105738699436, 0.03749393844710929, 0.02015695651061833, 0.07874492529247488, 0.03821941112567272, 0.04620068946055003, 0.0024912252057609813, 0.009663337808368462, 0.034168859012424946, 0.02792803487474365, 0.0365403762220272, 0.058137484293963225, 0.03357421467080712, 0.044853207123066695, 0.062375295108982494, 0.07419538870453835, 0.019268688014043227, 0.019973787678671733, 0.027584490898464407, 0.032164113729127815, 0.023571098755512918, 0.0699692147650889, 0.04969908030969756, 0.04488687263801694, 0.07460540027490684, 0.030590641911008527, 0.12553389104349272, 0.029064650580819164, 0.047077505982347896, 0.01234986150770315, 0.016255607462621162, 0.015262844573174204, 0.03714971423947385, 0.03503666119650006, 0.03312236123851367, 0.02982713734464986, 0.053601867851934264, 0.019038233772984574, 0.04820831173232623, 0.02581135166942009, 0.02610397498522486, 0.058991787023842335, 0.05182697291352919, 0.012364314303600361, 0.04150330687740019, 0.028529774996318986, 0.021600627972345268, 0.019721545678164278, 0.05604655149259737, 0.025716719783044288, 0.048082321350063593, 0.015941096303452338, 0.0021748266590293497, 0.006550601242841887, 0.02502283630227404, 0.040944370441138744, 0.017194540472701192, 0.011137727398558386, 0.035876446669655185, 0.023018599920240895, 0.038146838412753174, 0.006603377272507974, 0.035629090121282, 0.056927351014954705, 0.020585000149107406, 0.020671028211446743, 0.031434050761163235, 0.03679597697087696, 0.03470704245514103, 0.05606499746707933, 0.03342227710943137, 0.06836713930325848, 0.06682799117905752, 0.019204128799693923, 0.0662135709343212, 0.020713009173050523, 0.03984694182872772, 0.04034253362832325, 0.058172673120030334, 0.07117935482944761, 0.013813552296986538, 0.03671374191929187, 0.020942791664440717, 0.033784957469574044, 0.0218572499163981, 0.05809866530554635, 0.01630777832386749, 0.026819206874019334, 0.025569162165213908, 0.02838840052884604, 0.07363998065037386, 0.013762804662941821, 0.028194980729105215, 0.06767942370580775, 0.0609461103699037, 0.04263595824262925, 0.036860953484262736, 0.011469254519657364, 0.028955508223069564, 0.044459785733904154, 0.04812232098941292, 0.031556098854967525, 0.04510816665632384, 0.02422066541787769, 0.01336858090611973, 0.03183550600494657, 0.026264436642772386, 0.0395589376400624, 0.015632982033171823, 0.09458463998245341, 0.03475398011505604, 0.01853963267058134, 0.007556585811211595, 0.07822006488484995, 0.05659333875934992, 0.02161704682345901, 0.028977275626467805, 0.013011902188217002, 0.13203949481248856, 0.08078646752983332, 0.03538295832861747, 0.044603085544492514, 0.052029549543346675, 0.025263432945523943, 0.03332352312281728, 0.04280614500333156, 0.022382266387077313, 0.06473014410585165, 0.027683699503540993, 0.01899880919206355, 0.030027566411133324, 0.029745723320437328, 0.0685153788487826, 0.05350314439939601, 0.013592092885768839, 0.052141195695315085, 0.029438879606979232, 0.004803234046058995, 0.05681894486770034, 0.08014080074748822, 0.052782645382519276, 0.08515263002898012, 0.07357556053570338, 0.019929823698475957, 0.0070531637175008655, 0.015507892406146442, 0.0142685990847115, 0.07044386358133384, 0.0333354076636689, 0.022199206120733703, 0.07186666330588715, 0.056361032117690356, 0.032568479888141155, 0.04012825566210917, 0.04564580048567482, 0.0685109140883599, 0.03663958143442869, 0.054344110523483584, 0.08163768292537757, 0.027747381711378694, 0.03712451005620616, 0.039316921162285974, 0.0028253701997787823, 0.05575652187690139, 0.020716018475858227, 0.059798049474401135, 0.08002794680318662, 0.0502390449068376, 0.02365189022384584, 0.03834700285057936, 0.022291359657953893, 0.028294874654550637, 0.015151288327095764, 0.028073292258860807, 0.026442852336913347, 0.014599167775096638, 0.03897296158330781, 0.0651518264785409, 0.026688987522252967, 0.06033816334924527, 0.014527604383017336, 0.030065211533967937, 0.002772737298593191, 0.054697874933481216, 0.012282726404789304, 0.06138521073652165, 0.06549786576735121, 0.04452658750649009, 0.007270702892648322, 0.05980915030730622, 0.08927644017551627, 0.023512166292805756, 0.10840596404990979, 0.04148190927558711, 0.022363128306876336, 0.014218719127321882, 0.06822371057101659, 0.03997599579659956, 0.02230124082416296, 0.06290115296308484, 0.06351809735809054, 0.09589784951614481, 0.011681191540057105, 0.01489566552585789, 0.04683727744434561, 0.060730539794479094, 0.028248067612626722, 0.042043475035045824, 0.05138130772060581, 0.008008110154021, 0.041708048033927164, 0.033847833917077096, 0.02548354461656085, 0.03610706715179341, 0.030334681538598876, 0.016214030229353478, 0.04170701666069882, 0.05945497538362231, 0.03167417073356254, 0.031827546789177825, 0.07887928201151745, 0.05138336368171232, 0.0608774833381176, 0.03348060058695929, 0.013534765158380781, 0.029305686575493643, 0.007086281739507935, 0.05191705522260495, 0.03881983658564942, 0.04728026581662042, 0.14526931276278837, 0.06799555995634624, 0.029654456967754022, 0.01225122796105487, 0.03151345292904547, 0.012422050848337156, 0.07885012536176614, 0.04698307765647769, 0.01675323486727263, 0.02028961180310164, 0.04113950014912656, 0.04139840875619224, 0.019573779410815666, 0.031171301645892005, 0.013785488088615239, 0.01667682164614754, 0.018527088254424076, 0.11554236789899212, 0.022953160306704894, 0.011491434981248208, 0.008485966744566602, 0.027887533119480525, 0.05318454845941492, 0.06788191212607281, 0.015230619248801043, 0.05637630594096013, 0.014313228029225553, 0.03466049495286175, 0.012182729850922312, 0.023319993301161697, 0.0418815358674952, 0.0856737517086523, 0.10813656529145581, 0.09948302499417748, 0.11225910657750708, 0.13967397729200975, 0.15428234769829682, 0.08217317597674471, 0.08687984091894967, 0.14403186844927923, 0.10397274193486997, 0.20396770802991732, 0.13257822447589465, 0.16854980854051455, 0.07186390845371143, 0.11766840810222284, 0.12365766029272761, 0.1970404761710337, 0.22950027510523796, 0.10948867523776633, 0.0678626417315432, 0.14526285310941084, 0.11360138455139739, 0.1095707236922213, 0.07968952746263572, 0.15303494249071392, 0.1993924006819725, 0.1275237492684807, 0.11605759310935225, 0.13739492744207382, 0.21068645321897098, 0.20367966991450104, 0.10880024717854601, 0.13193741600428308, 0.1447907962969371, 0.16271946925137723, 0.23942789382168225, 0.10335419619722025, 0.13024126844746725, 0.09012207122785704, 0.09202129753040415, 0.17389773657279356, 0.13735431033585752, 0.27629788539239336, 0.14956471084484033, 0.08771226089447737, 0.12459416075476579, 0.10823786378438983, 0.16296303618167127, 0.14680025061326368, 0.08054096677473613, 0.08855000058455126, 0.05084200808778405, 0.09915934343423162, 0.19338311813771725, 0.149163655936718, 0.1480358357408217, 0.11121584541563477, 0.14412497702453816, 0.08261438658727066, 0.09224948885717563, 0.08079119691891329, 0.17442024924925395, 0.11739470064640045, 0.09292618504592351, 0.08330117937709604, 0.16120944385017666, 0.12317963237208979, 0.12600136095924036, 0.12564141170254775, 0.1272106867815767, 0.16764737053641252, 0.1626107000878879, 0.18323249210204395, 0.19502374795930727, 0.05984000329460416, 0.15084277226456574, 0.12570440689367907, 0.08212601100759846, 0.11507302522659302, 0.0907195620238781, 0.17542866085256847, 0.1216057568256344, 0.09713957538562161, 0.06625355700297014, 0.13204062118061952, 0.12395329800035272, 0.10316094942390919, 0.11720726213284902, 0.09182240534573793, 0.12780882897121565, 0.15546717840645993, 0.10874003398099116, 0.12538493903619902, 0.14384520346564905, 0.23643628720726284, 0.0730448579415679, 0.09132674908531563, 0.19184493353324278, 0.1326948782163007, 0.07540092151612043, 0.11683575063943863, 0.17915836428957327, 0.1804391262786729, 0.09689583203622273, 0.1874562097447259, 0.1392604780516454, 0.13604648837021419, 0.20594609901309013, 0.10388441703149251, 0.1295953438218151, 0.16651824755328043, 0.07743182432438646, 0.14018259357128823, 0.15784749282257898, 0.1493076817797763, 0.1527061787034784, 0.2277479719902788, 0.1641460619866848, 0.09204921924642154, 0.1528220046311617, 0.17088821663388185, 0.12727346484150204, 0.1905513743736914, 0.15532208047807217, 0.09167831164917775, 0.10636985009270054, 0.12252039488937173, 0.10699933381485087, 0.1293020402746541, 0.17222531060022966, 0.07250254561326333, 0.11278741394302674, 0.10869050092462983, 0.15045937283762864, 0.21758895926177502, 0.14321123462702545, 0.11717850581875869, 0.11405352636107377, 0.12903475176010812, 0.07647019092525754, 0.1403919080538409, 0.1331735168184553, 0.16975974504436764, 0.11519179599625723, 0.10293535688625914, 0.20070814793663366, 0.1735134143382311, 0.14014276356569358, 0.0574601095701967, 0.11511608505887644, 0.15893614797719888, 0.13761355142508233, 0.1348717271217278, 0.09782677529645817, 0.14607021478669985, 0.08750893109078918, 0.13264674294207776, 0.0869736619559782, 0.11250763359878745, 0.09185182662414652, 0.1569068804383278, 0.08830001471298081, 0.18006944682981285, 0.091066714110119, 0.1460007463714906, 0.13608348209943089, 0.10042091645300388, 0.17260880502206938, 0.14009989372321538, 0.10315330233424902, 0.23755120166710444, 0.0848398728828345, 0.107514450459608, 0.1618246715515852, 0.07031557296535798, 0.10904538831008331], [0.017745337881413952, 0.02705217508732208, 0.0811443201133183, 0.05192869209817477, 0.06531109221811805, 0.06168348794536931, 0.11386416080806937, 0.020587721074532186, 0.049334913957864046, 0.022387514855446558, 0.02215018875098654, 0.016312349953555634, 0.016922685417479703, 0.01597011385352484, 0.02921337527888162, 0.020676473454971398, 0.01445363728063447, 0.05909660032817295, 0.07973764916615826, 0.024364121291520338, 0.016183901578187943, 0.03932254961026566, 0.05809570689286504, 0.07189818804285356, 0.04560569567339761, 0.0595227542466351, 0.03224935129817043, 0.018017598361309086, 0.10364589161638703, 0.11916932756347315, 0.035222824064216444, 0.06319941660123211, 0.03228617539363248, 0.01829023373180202, 0.01607799922515239, 0.027171522611752152, 0.060735669519220076, 0.04108826057719333, 0.07504249896321978, 0.053988700666065724, 0.01073540871896382, 0.05671544113595571, 0.01950190558896533, 0.07688174955546856, 0.048905214693929465, 0.06199889137808766, 0.0101390926366938, 0.017955620972705737, 0.04440828492598874, 0.02147532460678901, 0.045692398878080506, 0.08672572526016406, 0.03125771647319198, 0.02689892116801015, 0.003964289532242609, 0.041555682995489666, 0.005217192145729703, 0.0896497294306755, 0.05679735388340695, 0.07300299911626748, 0.027377624230991517, 0.09594893641769886, 0.03849079120638115, 0.019674138132748858, 0.05894499524895634, 0.04153991723433137, 0.03515750828332134, 0.040378706330167394, 0.033502473163285425, 0.07128253286438328, 0.037466420459428, 0.018783152103424072, 0.035857288233403645, 0.05726944801530667, 0.059051498105483394, 0.020538637547620704, 0.08228798410190002, 0.032728919493300576, 0.05065875952797277, 0.0369970235042274, 0.044513535885406394, 0.02527747013872223, 0.018415715212800672, 0.01924786207798336, 0.03653276984446815, 0.013941174555969025, 0.014334160834550858, 0.028581760956772735, 0.030112267937511206, 0.05628005574856486, 0.03522464932341661, 0.017457932499902587, 0.0352722960524261, 0.052280943375080824, 0.01679335325025022, 0.01004241157456168, 0.03410343127325177, 0.03655979928693601, 0.044331637610282214, 0.020806421392730305, 0.032473125361970494, 0.025939336944637553, 0.019730885712695972, 0.06385200444076743, 0.02475133408526225, 0.03802581151415195, 0.039431379841906686, 0.04915639139445765, 0.03834405122324824, 0.046269991634679694, 0.07328364798533064, 0.02688698743336967, 0.05134301459682839, 0.06480712390371732, 0.03193821585071938, 0.028861975563423972, 0.03467049316636153, 0.03478292302627649, 0.03762133678953562, 0.06374693329312972, 0.015418030620951737, 0.011404521430709531, 0.05541312208931361, 0.0241171413300825, 0.07980147217001234, 0.020794887993750826, 0.06467845330813102, 0.048676419470991404, 0.018939428896244084, 0.056659886081303866, 0.035462581020380766, 0.046462207034762414, 0.06424888635852508, 0.023816981186558093, 0.035532378525074036, 0.05172977955745799, 0.028537690107311522, 0.02014769790028887, 0.0184902522845992, 0.019870132972885455, 0.0012142353412595444, 0.01280505333228835, 0.04906585107424429, 0.05197784856760076, 0.021749856482659067, 0.06364815895046506, 0.026059446124626056, 0.0749574920960835, 0.04230438532041652, 0.04263164954526084, 0.028369852774111286, 0.05402519567204373, 0.014938548939036471, 0.04224936291575432, 0.018591133478496755, 0.022236842761880586, 0.0416769066692463, 0.037122613550829034, 0.04288602553840194, 0.016459575089226876, 0.012247436646638172, 0.04271738923021725, 0.07055941809500967, 0.04825644361387406, 0.022005024665434445, 0.10509404140923705, 0.05607863262827907, 0.013551314627485616, 0.016426165721246173, 0.06327691887106214, 0.039794470715735636, 0.0343462484223502, 0.0476784369509135, 0.03053986035021288, 0.055420864173876386, 0.09521733317524195, 0.03744105003508074, 0.03875639695408089, 0.10680757303323064, 0.024242839942287122, 0.01549912743004305, 0.026398710241275172, 0.07882138261837618, 0.010165321407839656, 0.010523520044184156, 0.0625324302486011, 0.034119207212435346, 0.06953321530350617, 0.03651779796928167, 0.03533223444329841, 0.02282544135648225, 0.019528816287804927, 0.037331042545182366, 0.03253251753215279, 0.02640430476250393, 0.04601668094151786, 0.05453001554789288, 0.04527011260922466, 0.010481451721196728, 0.027318835956975818, 0.015869463361533623, 0.0779809287882277, 0.022417870815843344, 0.03314156377954142, 0.04590878708820258, 0.00931591006727623, 0.024992003671026657, 0.050284883340022395, 0.03251922842381256, 0.018252452901963676, 0.040130250555063994, 0.037857789280159135, 0.013394394922735435, 0.008970771533703166, 0.054814942580248625, 0.047546539921313524, 0.00721054312972618, 0.016680093881274973, 0.022322061671210185, 0.0623772492898362, 0.006758634990546852, 0.044582081492990255, 0.0794097064062953, 0.022630761177944284, 0.028782318944909742, 0.017110388559688414, 0.042534442618489265, 0.006627593763239149, 0.026271434035152197, 0.048021429617490084, 0.028983877772199254, 0.036255761315780025, 0.018521892372518778, 0.07406652133379664, 0.0434755333699286, 0.06504913698881865, 0.023363958977695023, 0.002019186204831515, 0.04065681408558573, 0.006919892654488129, 0.03095219929569534, 0.0866982445919088, 0.020060126170782105, 0.02222687847513173, 0.025840993471709744, 0.043360026353704076, 0.019819037589643682, 0.03185829121087279, 0.011410660476290753, 0.022084993410057256, 0.034046994123075686, 0.02174987344603453, 0.06870202347636223, 0.007565118389071098, 0.05719934856253011, 0.022702811418899467, 0.02172414679080248, 0.014249325297506792, 0.010970962150687618, 0.05131495717380728, 0.029426150290029388, 0.041477902526302, 0.014922664434249912, 0.004962529047458831, 0.0497419806862516, 0.05352080327325633, 0.040390027686953545, 0.004109163544074233, 0.021768833410793116, 0.013140146154910326, 0.043839482590556145, 0.045117581329707585, 0.00194178317074797, 0.03248400906366961, 0.07814421824046544, 0.033103945798107555, 0.04391660148810063, 0.05664215935394168, 0.03609075177727001, 0.01754669675470463, 0.015384673839434981, 0.027891634863668253, 0.012720194894687405, 0.03585692521716867, 0.04642981377297214, 0.037403269205242395, 0.042807590282921276, 0.031051835377833674, 0.040073365571775606, 0.03703830896743706, 0.006289513266113187, 0.06247254953320537, 0.02758023139488484, 0.014727300631680658, 0.02360469980963639, 0.021108147255810242, 0.027606200626386062, 0.043105026108345816, 0.11092813299702746, 0.027535409067890475, 0.0305034535537873, 0.025710390747657845, 0.011443013025979911, 0.014332121836819818, 0.008920492088821317, 0.02020369569904038, 0.08359573821404151, 0.02102740328492863, 0.04234325859163489, 0.04661685195086258, 0.048486782503979545, 0.07141560715224061, 0.037028402356164794, 0.02349672792479396, 0.041350086884839196, 0.05079187452793121, 0.02381267079285213, 0.03356274403631687, 0.051040445653987784, 0.02246424529169287, 0.034899559803307056, 0.016826805026669587, 0.025467507441395094, 0.05086786366466965, 0.023249960005549446, 0.0431189394689032, 0.016400652804544995, 0.033074107220662494, 0.055608553745384724, 0.029061380042029277, 0.04021388338878751, 0.057084791495331695, 0.025999921640115123, 0.03818549455276557, 0.03028614932139005, 0.023442916705140045, 0.060944705802415094, 0.04821918186332498, 0.0767572248088462, 0.03345537944031613, 0.013686818070709705, 0.06028204171785286, 0.03743960814816611, 0.009828751075214573, 0.018597052000196915, 0.03691510057875088, 0.08202636814010994, 0.0841792036912271, 0.03924397525510617, 0.08324390423617192, 0.005335437474838857, 0.02961267956665584, 0.12040586264005729, 0.14316635632089206, 0.18160512085471833, 0.1282060705125332, 0.10744727549276181, 0.11322001394416605, 0.21631419552224024, 0.06121323603604521, 0.11385297855096203, 0.08833071163722447, 0.1021375014845814, 0.16416841293019907, 0.11674585832016808, 0.0747907217592001, 0.08256585776273694, 0.1322579423763922, 0.19008568221969263, 0.1614980519350086, 0.15037076973489352, 0.1116053516577397, 0.09496206151587622, 0.1755367379103388, 0.13572783475475653, 0.1138445104339293, 0.1729282864502498, 0.10506759211421013, 0.16428255609103612, 0.11385121435991355, 0.19179549547178404, 0.19994715734251908, 0.08877294005027839, 0.09347924536892346, 0.17619102208742074, 0.12546411050217493, 0.09334506506898574, 0.12513974362186023, 0.15652942497815403, 0.07419677291597639, 0.11998987996152469, 0.11526537633367948, 0.12098793712045465, 0.12572199452136243, 0.13267050523843082, 0.1655827784644706, 0.13949937666101114, 0.10607971530407667, 0.1382674284811531, 0.10631690400519542, 0.15393101583634103, 0.10315193169351135, 0.10741930627929312, 0.12804373779467174, 0.18173043270196232, 0.14912282169929572, 0.0757096888763564, 0.1684067462171827, 0.07890949717589787, 0.2599572150834969, 0.14358109049499035, 0.2115893933389868, 0.1189526306199176, 0.22112107330134936, 0.20128505198018892, 0.10766060011727469, 0.2313706704548427, 0.15859807468950748, 0.14855927122490747, 0.1265366572354521, 0.16726724164826529, 0.15456616532589706, 0.12158552291137831, 0.09413922245481185, 0.0636153585676636, 0.14679997919925622, 0.21617413232369082, 0.059239567656602175, 0.16266536286899022, 0.05946300245289292, 0.18542686078165257, 0.1357217686516898, 0.1379150923873697, 0.10119943360665015, 0.11367194540798664, 0.14303667470812798, 0.10934575540678841, 0.09912158296044384, 0.10056755465588399, 0.10917063230382544, 0.08519604269947324, 0.2014904445303338, 0.08525458670088223, 0.08701834348695618, 0.08025041807975088, 0.14383738674223423, 0.12405053206852504, 0.09628471625702721, 0.08430041718695845, 0.24502974322863988, 0.12874919708286012, 0.09381175466946193, 0.18510353884526662, 0.10088261203574282, 0.12522823815899237, 0.11664098394768578, 0.08146302801157747, 0.15431394028876508, 0.1880286354571581, 0.11711129013981138, 0.07179563426013504, 0.06309211307338305, 0.20091453114790575, 0.043197269551455975, 0.18660878735993588, 0.13440040312707424, 0.06742896285972425, 0.15108287866626466, 0.11732798708336693, 0.26861657042588505, 0.21917992031999997, 0.09256274811923504, 0.10450228423412357, 0.059159330890647004, 0.2094052162553583, 0.09448500390031508, 0.1751746851950884, 0.11180735831814152, 0.1864100308822734, 0.09273192725543465, 0.11594249999948911, 0.15253296228391783, 0.15109654436154024, 0.109880427430783, 0.14344543777406216, 0.12220934086612292, 0.10197866322206599, 0.14298543174351963, 0.11806449613400868, 0.11073898457522903, 0.12349720033151762, 0.15424111991056375, 0.1332166309335402, 0.18593298005206244, 0.20685521380177566, 0.0933773633358734, 0.09135638749493019, 0.05524979192497475, 0.126124148656215, 0.19819623843899795, 0.13228669869048254, 0.1893896817096642, 0.06989228246467453, 0.13197925447353295, 0.11997147809181895, 0.07735457311251334, 0.18563878083867685, 0.16163673092211994, 0.13740233704447746, 0.1887416129133531, 0.20712847342448576, 0.10344521488462176, 0.10238606921796288, 0.15439148327069624, 0.13893388557646955, 0.08317387263689723, 0.1550014726817608, 0.24533212557435036, 0.16578605398535728, 0.12169445492327213, 0.08309605145560843, 0.13533876277506351, 0.14652950157012257, 0.17658155970275402, 0.11582039083753314, 0.145036941660302, 0.14485262440783636, 0.16407834419182368], [0.005476604565046728, 0.04612399125471711, 0.017727852033983384, 0.019616476226864115, 0.026056233261312758, 0.021918983032394732, 0.031320793088525534, 0.03253857345719423, 0.032379440031945705, 0.07374185589807374, 0.05806933223669018, 0.015567781603229898, 0.025257748518405215, 0.05122561786057694, 0.014106518272975726, 0.013897170711840903, 0.022315593536144922, 0.06270004875425782, 0.023398006168593253, 0.02108367589036269, 0.012163537487919842, 0.045794406440109015, 0.04323707580832498, 0.035287664870598486, 0.01965720359502094, 0.008841126392196332, 0.01069152616297028, 0.06907678515251194, 0.05628572151597057, 0.03577323131529348, 0.023355334797608, 0.06839881331792899, 0.04927502306444304, 0.026807624281251004, 0.07886955181935004, 0.042018935816096406, 0.026432957600003908, 0.023281271003984978, 0.05799685112599816, 0.034276505200458426, 0.03187395179910319, 0.02008902158455125, 0.014741118997335434, 0.03394958363579852, 0.02813153770486159, 0.03235347928213222, 0.008119760546833277, 0.03337158375818815, 0.07456971611827612, 0.011738655822617667, 0.018673994478636553, 0.023716111867023364, 0.01006054033392242, 0.06919885360236679, 0.03785300900095275, 0.02029812741758568, 0.06371557818991797, 0.01571248598130686, 0.021377564673977237, 0.049272071437111924, 0.0252269074054701, 0.03558814053290656, 0.00837612125490393, 0.005794167435461921, 0.021743907426883067, 0.0071704561289932045, 0.07043890349034752, 0.035588164281632216, 0.04065112456945436, 0.03237546720941152, 0.01818404809039618, 0.009492933916460191, 0.05127499485388398, 0.026907111085685234, 0.03513575784329857, 0.03447193685652954, 0.07285908183881215, 0.03285259607114962, 0.03099167307040521, 0.04161028131576521, 0.03765101591125131, 0.045228857680090835, 0.03369132302967565, 0.02261390976075615, 0.033247466132576974, 0.0574153262589659, 0.09176954746778522, 0.04704463096069438, 0.019361167248072367, 0.05531418489824448, 0.044648845946150165, 0.05262693516643984, 0.032994657555328946, 0.036507847253233194, 0.038276180758007934, 0.05039651592129043, 0.05819731751190765, 0.03527372097596526, 0.030327394072498595, 0.02162108919583261, 0.024860836066571728, 0.029490159891013588, 0.07073923666030169, 0.04688632195549352, 0.014048482324661953, 0.04754475876688957, 0.024550871092027853, 0.02915947584967528, 0.03350824749629412, 0.03881341425169792, 0.05324972853330629, 0.05498526504795466, 0.019369743930708085, 0.0503101316280663, 0.010579016575190638, 0.021161905889000212, 0.01769810845144093, 0.009318972804716654, 0.021747642762160728, 0.01970888251837875, 0.04930573016671198, 0.06563020723738841, 0.02637526685638087, 0.022382578513185893, 0.05425486959783094, 0.06548759953251906, 0.04596974328160286, 0.025952303748843924, 0.01874402438157371, 0.04082071082666516, 0.059858900494873524, 0.04101926374382206, 0.036523375527134964, 0.020021807601941482, 0.02929971886000463, 0.03739249746182135, 0.06367737666836806, 0.025194700740809952, 0.011092292693709689, 0.027681606223008463, 0.04111285407894424, 0.00996192968783102, 0.012626826779783835, 0.10391264408826828, 0.03153159695544413, 0.022494465545085923, 0.006581093334326786, 0.04790300150801029, 0.027812003690217222, 0.06455253756472043, 0.042971602374953885, 0.0762674921591367, 0.02444044460675546, 0.02318792324513197, 0.053942010671432526, 0.06706849791641746, 0.060723381250032356, 0.015519429197801011, 0.04085192683019808, 0.05389850979138698, 0.03389605740085244, 0.02793026216594236, 0.0600790036842227, 0.04365894477814436, 0.051877781615725586, 0.06721668317914009, 0.02648392745426723, 0.03931770147755742, 0.005851866236688303, 0.017236116009631326, 0.03240866792787399, 0.06724664050021342, 0.018033849275005714, 0.020388788177764842, 0.0683281235396862, 0.03450855060613581, 0.0206330726588411, 0.05701277857380254, 0.05403437285817095, 0.004353082464409194, 0.04951678169891238, 0.026696945041684166, 0.023165779254798378, 0.06437430677137204, 0.006892702059953341, 0.05239714588969946, 0.047422381583601236, 0.016820547237460102, 0.00709599327196234, 0.05592597581978355, 0.027591079473495483, 0.017024514864065816, 0.02878979979349034, 0.020897031262783066, 0.0492337274232081, 0.044840430308665545, 0.021957181161269546, 0.006173699212792728, 0.024782010653455342, 0.008655495326300817, 0.021668186311476996, 0.025593294263152138, 0.014025388385302253, 0.06466141529381275, 0.027154337016067336, 0.011554232549055346, 0.053042191812502484, 0.015018622856587172, 0.04166000096925667, 0.01619840526421155, 0.030294213710086684, 0.04616052697279623, 0.054659374856523106, 0.08394940423646144, 0.012769670275572156, 0.054420890153518746, 0.02511629941208022, 0.04543871159798332, 0.003983530664949545, 0.08082370553165674, 0.06055592559278011, 0.0738771693514926, 0.034400249631809335, 0.049055103079548905, 0.03115671992834125, 0.01749901779528175, 0.021849923434534242, 0.03371734145496573, 0.010003556963056326, 0.02915205606924636, 0.04220359572874648, 0.02593633781985513, 0.030439847681139196, 0.026022793359256217, 0.018978190209184374, 0.06481152081063815, 0.0430488569795021, 0.0455828086872186, 0.01226077155609216, 0.09683151370180504, 0.012229761657571154, 0.02177660772576928, 0.013603152158404035, 0.041319495133523426, 0.02018025909949626, 0.046188519934990575, 0.035173643846064806, 0.023113308141806295, 0.02695216072191085, 0.03558393022311585, 0.0439568284366812, 0.009323151732262756, 0.07627268295202937, 0.05090280143277986, 0.036088665282087665, 0.03454808205632227, 0.029251139145344496, 0.025636067414390187, 0.03409334145752447, 0.06866334019494907, 0.0341795255829181, 0.04810602257826498, 0.04932596408096807, 0.05850580667278596, 0.028163359300898652, 0.0060128859892886665, 0.06194656275744949, 0.06224569492042065, 0.059797520217086585, 0.014519853816766824, 0.006810683291405439, 0.04419040733150073, 0.02835685882850417, 0.03785627614706755, 0.023638989576803784, 0.02336374863183924, 0.0217838273383677, 0.022128328049023236, 0.0119623323470088, 0.05405521745394383, 0.0035825236783629017, 0.04915504789512072, 0.034495862001287084, 0.008649274008348584, 0.027703804496143545, 0.02655923127063683, 0.029820056831730262, 0.04065002195004906, 0.021175590243988802, 0.04661676034863506, 0.016333640686103275, 0.01697059507880892, 0.03699359350970813, 0.04701131149860365, 0.0029172756476327777, 0.0327095269624676, 0.005215630667018039, 0.07782908622175455, 0.08148305157997779, 0.038148840091058185, 0.026023225925330604, 0.031040368136018515, 0.010315701731347611, 0.050360428036323616, 0.07582520946328129, 0.033548399806022644, 0.018494639013494765, 0.027190657299278036, 0.0513371350908918, 0.09906369035265275, 0.020680914466668452, 0.009835058906381684, 0.02023393121947135, 0.026234319865969673, 0.04813789676076599, 0.014784716568621141, 0.007713756573918674, 0.07231478140290294, 0.04222855224673237, 0.02115665402795587, 0.044142115994223526, 0.03395610435732773, 0.02270095392928592, 0.025732443135763918, 0.061899825265364986, 0.07426529138215951, 0.07019872923514672, 0.08084801065602473, 0.014597854809835553, 0.02314202713647059, 0.03627702321058937, 0.06937675191355602, 0.03938512071701033, 0.0369298994275076, 0.056744648675833426, 0.11000572570732661, 0.025222797179594636, 0.06620772196246044, 0.016675050669748868, 0.03944640260721956, 0.026639629188658934, 0.04068010819277593, 0.012349914094167096, 0.02811425202526152, 0.03203913097136787, 0.03442748602745788, 0.07831930063132729, 0.03478625802589314, 0.015147405410451549, 0.03965794268463339, 0.05104153809536781, 0.06796138214745692, 0.10502597756151642, 0.1108289108212505, 0.1671739566539015, 0.1814389204872506, 0.10972332621791533, 0.14797032997012138, 0.09644694719463587, 0.11373899145317928, 0.09550467239958899, 0.1443161881927933, 0.1458058711141348, 0.07018309578831707, 0.04308584053069353, 0.15956198796629906, 0.14765643967049463, 0.13482554602835858, 0.08249356664185013, 0.1628662906587124, 0.12879516104502337, 0.16248863163803304, 0.06260710981275354, 0.17151246885103838, 0.1460598332009145, 0.14867089023547514, 0.11119143851101398, 0.14225718724940503, 0.0968314865604043, 0.11801858645464693, 0.14804243110120296, 0.16069767916841166, 0.1053755045203226, 0.12043793020503861, 0.16567165298121317, 0.09372504467942885, 0.14263982671712125, 0.08866586722433567, 0.10001332046730177, 0.1627717978720154, 0.08610849588045053, 0.09210182606641736, 0.12480853710855756, 0.11906875510300909, 0.07324497148926769, 0.17149802962584154, 0.15927723396037305, 0.08351937588304281, 0.1746685794953789, 0.20049424655735493, 0.13946695625782013, 0.09180341993591615, 0.10210309297378574, 0.13026701206607477, 0.0928929029032588, 0.1395977913801159, 0.07535944267043046, 0.08568044884928636, 0.14935868047177792, 0.06474364695272275, 0.21641303093305655, 0.14468550123274326, 0.17103841714560986, 0.11165457258799247, 0.07220514371458973, 0.17079957281904562, 0.1641605690653835, 0.060226225427218845, 0.1388763865189893, 0.10474702502999987, 0.10620825019265924, 0.10935105476528406, 0.15673257836273738, 0.07489387943808522, 0.13355937254215988, 0.2122484544026, 0.1652056487011058, 0.11640826000698976, 0.23289653286337852, 0.15425237002117292, 0.11987869521336895, 0.14987371569233282, 0.09067464300564357, 0.1669862467263426, 0.10925043480736868, 0.21035767586103507, 0.15406109099941595, 0.11966560807611261, 0.20429123352680886, 0.1573306391281741, 0.05822386180183717, 0.12948023714125156, 0.11018735596111842, 0.15894115556563648, 0.17593518724398954, 0.08972705528140068, 0.11070256081542798, 0.10364028691713299, 0.11966444099588053, 0.1318693318005119, 0.11740840705377714, 0.1475256724017007, 0.12358367283429418, 0.07279322322990213, 0.17861795185932092, 0.18995142728090286, 0.06935640264834676, 0.1496706980147532, 0.12367475937519755, 0.14412243930356844, 0.09511420942310776, 0.1894829531333276, 0.09904856580708708, 0.12345093781394617, 0.09245811801935945, 0.20758360757359437, 0.15330041253140994, 0.0840588655056698, 0.09795171394944191, 0.15565814530210836, 0.14863811699407442, 0.07172641690288271, 0.07914425672164985, 0.2776523769966194, 0.12172262769724641, 0.15892617351242475, 0.10610353866858141, 0.12675058575613157, 0.21716902750943387, 0.1411015742591449, 0.13530476817062922, 0.09865192816193614, 0.07988842643265213, 0.12845174090138503, 0.08507987750428063, 0.2877427355519363, 0.059060142641620975, 0.10501764515148741, 0.21088862951312745, 0.14002468490174838, 0.12187623445476804, 0.11135531150336776, 0.13223420722143991, 0.13907826425773756, 0.11548799010259764, 0.20568813356970037, 0.10981996317527123, 0.18390090337821416, 0.06422645399080855, 0.18016383105090686, 0.16731179425758974, 0.18236741423606873, 0.11466099162186895, 0.15535802926336015, 0.10228237549641303, 0.08082413979406868, 0.17078741347151144, 0.16915420682302543, 0.07885657144444329, 0.12024397775530815, 0.1268789917230606, 0.26367824684296337, 0.1260878470327173, 0.13321167762790406, 0.08592461967574698, 0.14058473413544043, 0.15051313995250634, 0.09160551841237716, 0.09507834206202201, 0.15394111243741854, 0.07782347473715033, 0.10705736891499587, 0.12931532599031925, 0.1683875708175557, 0.08064261132052966, 0.05424504441076091, 0.11558435564594609, 0.12180793311979089], [0.05371785323534693, 0.09097171242215804, 0.041526790974395614, 0.008367670949415436, 0.02498137272362198, 0.03519690402650407, 0.05483725620433688, 0.029080392593251805, 0.010898589605598577, 0.04970958063911114, 0.03683761866497142, 0.07279086871338741, 0.020519194126661335, 0.03823550258363996, 0.017009118904492686, 0.08482309271182333, 0.06904093814747674, 0.04072623500334365, 0.04487984301522374, 0.032169711643031666, 0.07481141029191868, 0.028651253120707612, 0.05340971691267831, 0.03181367074804647, 0.030400645320436785, 0.019730804288493733, 0.022935796595577682, 0.01434536514404629, 0.045448747130909135, 0.02750099207540708, 0.04397108106474791, 0.03587015665003231, 0.02903570088424853, 0.13173977232405118, 0.0193904697828527, 0.024644363039572324, 0.04457930628476398, 0.06051655699099813, 0.008970194778937315, 0.04861938181732382, 0.08448432731841292, 0.017605761531740427, 0.011605835137223559, 0.06901256181299686, 0.04529706741284047, 0.07166590514991965, 0.015316513300474201, 0.06130453970815454, 0.04647246648424438, 0.004435507081715124, 0.018657512863033583, 0.02952386951074004, 0.05479768404204931, 0.024657886242493987, 0.012553751950950494, 0.0810066657140851, 0.03975526156968304, 0.03481504826673439, 0.07197558853243079, 0.009696117835119367, 0.04972897316994412, 0.042804184037127664, 0.011161452375485428, 0.04013703929792557, 0.08164863448057856, 0.04835011876587357, 0.019718583872807876, 0.04963944386690855, 0.024994895926543644, 0.014848366546045457, 0.025223548657127788, 0.07382577710918017, 0.022795151553249786, 0.03131960904491799, 0.01198888851130115, 0.0395366952621511, 0.028543091246059964, 0.043262707468654425, 0.01654279401658901, 0.01616222408067967, 0.020193080018673624, 0.08135258965194225, 0.023817432412345494, 0.021323661852095808, 0.046119305970413346, 0.05865897238254547, 0.032246928928153853, 0.025450713699683547, 0.015576268379975642, 0.025296151904123168, 0.018828323875953044, 0.04884904895776084, 0.0631102638851319, 0.03672265786943691, 0.08831915618585688, 0.014413055797506655, 0.04547689276348267, 0.04973683739081025, 0.025245514532018985, 0.01317529087620122, 0.07263034768402576, 0.04107552786756839, 0.0510819041436272, 0.05542206857353449, 0.036212884687951634, 0.013272349373437464, 0.01743436019335474, 0.028793402814439366, 0.024851278900834065, 0.062252853464867385, 0.04115382741604533, 0.020981393521651626, 0.052816263400018215, 0.038664608129433224, 0.04992607402216111, 0.018761969936479415, 0.023163585890350596, 0.014680098343108381, 0.0322179894096085, 0.05715169504817043, 0.014416675781831145, 0.03786835067772439, 0.047866594711584706, 0.026141689657898884, 0.040737186558544636, 0.043300366162189415, 0.023298266609864574, 0.012822848761321178, 0.0392671574040183, 0.03706865644614611, 0.0918094249708312, 0.04459464456886053, 0.03246266235198293, 0.034124971367418766, 0.031977428389447074, 0.034317488715584786, 0.028868645562657287, 0.049227942912174125, 0.004569783224724233, 0.011532616967867528, 0.041503615610833676, 0.031820198254925866, 0.024469499476253986, 0.11461508194250719, 0.022616344005135552, 0.012768955269296254, 0.044551191186266284, 0.03467859826715929, 0.02389199492920722, 0.06290976357247148, 0.05139850179797836, 0.022602362791076303, 0.06100583502224513, 0.02828473734137203, 0.05731980888439076, 0.011363873790417398, 0.02637248147012932, 0.015084739308804274, 0.0099217137654445, 0.01847145856092019, 0.03268352550055299, 0.0449695249886385, 0.042684103694877455, 0.04908431740477681, 0.05706573823200805, 0.022459475190511773, 0.03773893030094249, 0.017852414100031768, 0.0465788845238941, 0.009621249129330474, 0.04198819478707654, 0.04826484387740493, 0.05167476733082107, 0.03183273418939539, 0.023514076368883252, 0.0469119332597724, 0.00696930187820856, 0.0676006797168936, 0.005131026680049087, 0.03539079201540776, 0.005913290619251451, 0.056233219868902645, 0.02824162152994956, 0.05832800335649933, 0.012021386097850544, 0.04834749962070158, 0.04078020228605185, 0.0444018286652863, 0.023536495165899396, 0.017798182188666294, 0.03543000455413546, 0.061974688033972464, 0.04067598609253764, 0.025592115308557237, 0.04185378039255738, 0.01895988842339388, 0.06859297611351524, 0.037769617047160864, 0.018287375403035964, 0.028732914810201952, 0.024050193672467555, 0.033176328521221876, 0.05245268737365093, 0.02514227542893163, 0.02816621762966471, 0.027314440746392523, 0.07451315343912158, 0.021419940882229378, 0.012637366124960994, 0.06329979907189097, 0.009724061603524854, 0.06676049051540238, 0.012474580484974598, 0.05907536218208926, 0.03741992384727512, 0.046797525470278094, 0.04814767784305981, 0.039502761725868495, 0.0560432741684573, 0.03241797064297965, 0.033390280790627, 0.07047253847122192, 0.05101057993514197, 0.06085078977048397, 0.006252962280996144, 0.0340176169494433, 0.033712076023221016, 0.04647313144856265, 0.07848269186381783, 0.007357833574392966, 0.03460357265014734, 0.08242004058722939, 0.06591818428465299, 0.02061366316463266, 0.05042605933600238, 0.0371166560133653, 0.04666560469195247, 0.09221071736621005, 0.05047762121206947, 0.06247762497514486, 0.012957818706386855, 0.019888305837022405, 0.014068923192098737, 0.03486570769122668, 0.04198378091678023, 0.05691770903233971, 0.018830970162525773, 0.07266419979610614, 0.017061773221939802, 0.015766348091087172, 0.010190014993505818, 0.048158296916101656, 0.04126409953460097, 0.050899520715964694, 0.035357503087392876, 0.0584972028487495, 0.013421606721489556, 0.06659279737089362, 0.019195333289514695, 0.04259987035766244, 0.018341061093711426, 0.055755487110997946, 0.05413498263806105, 0.03577571136078664, 0.053186539959694655, 0.02009481457727296, 0.04936408078564065, 0.023846081857170378, 0.021705448062026074, 0.02229620948699968, 0.058141718352479596, 0.036300609087837596, 0.033975086374474425, 0.01669069259826626, 0.059071311328027926, 0.04135302833414503, 0.0799125347818647, 0.021256888917248164, 0.045828645317150016, 0.017758201209029982, 0.018593840833221163, 0.014311908278614283, 0.01821840231839035, 0.0452273682957249, 0.02811376178371055, 0.09678436908870935, 0.02999462014330285, 0.010085703805088997, 0.015590839919501116, 0.011976060806773603, 0.057213367096015384, 0.03422369821263211, 0.02697441497418497, 0.004756489344539919, 0.017852811043017676, 0.0162725063772606, 0.024311083601787686, 0.048639215395918915, 0.060538962217313905, 0.02725474493178938, 0.11412212625145912, 0.011082556564360857, 0.04854416960318174, 0.04225340359179037, 0.03832904542131083, 0.03280444722622633, 0.07127204271299498, 0.02188285782800189, 0.03150140893246446, 0.01587600783178849, 0.036146157554217746, 0.003949050059808152, 0.02869390243930476, 0.040293292342019935, 0.01958808971435896, 0.00844179920386523, 0.016259500557290654, 0.03607171208464673, 0.029652373865246773, 0.025874233205935786, 0.06781304760703019, 0.04654836741143039, 0.05000279597671969, 0.054294499435595105, 0.05273968054513846, 0.01999394186506314, 0.04989517353741186, 0.03197062607588513, 0.019318680777879696, 0.06230348574795893, 0.023474524562646235, 0.034412724498127184, 0.04744699204872761, 0.05241867919851627, 0.05464856918635113, 0.020893302712855593, 0.04128112397821886, 0.030513109107102667, 0.022297037299722433, 0.0435521433662091, 0.01776101882569492, 0.022747684636020234, 0.035853831097483635, 0.01773167897148856, 0.022450925649276803, 0.02132300367312772, 0.03789009093972189, 0.025534215915415968, 0.0492404042077916, 0.04369059504408922, 0.08259909919330052, 0.0717459519260696, 0.11660078753318105, 0.1677827111312321, 0.09888655878603458, 0.12859867087432317, 0.15207230485975742, 0.12956328982753412, 0.11962857363479477, 0.09596765041351318, 0.0942748412489891, 0.1785039444054876, 0.12847338616847992, 0.16353056287126883, 0.14708424465996878, 0.11938682517835073, 0.10431695596448012, 0.18598779211086885, 0.1584430837205478, 0.17275068669446877, 0.13903392877961906, 0.08420867246708699, 0.17387467995285988, 0.13931207385446343, 0.1443561539053917, 0.1251717840454408, 0.11658546621245996, 0.1305824765669448, 0.16817883987511906, 0.07845683967960732, 0.09797850929732833, 0.07641923294535705, 0.12022056829716478, 0.1421243708048548, 0.2054935840091535, 0.18580333915139946, 0.17991379089653492, 0.12612603498356684, 0.08557051939091512, 0.1488364799214261, 0.09240235601152692, 0.1020323760541422, 0.18074002941804274, 0.07160052830087286, 0.09393899355615888, 0.177758234419993, 0.0876785037772996, 0.12872139071779592, 0.10617471699203763, 0.167166479197996, 0.13201578679893697, 0.12633636726864747, 0.13331853332264082, 0.13641510930444511, 0.24688119388052396, 0.10261173639446497, 0.10043779161891767, 0.18481034386370862, 0.16584416372435434, 0.1166991615401847, 0.0975738377975566, 0.09177455505622284, 0.254597466971193, 0.17058283516338893, 0.08759249267833573, 0.07214558869600296, 0.16997507134718554, 0.08808678508337055, 0.13660497697336332, 0.08312260253088814, 0.14866680545466288, 0.2205369903572968, 0.15468314476311207, 0.1792257156755243, 0.091907914328788, 0.13403833684112343, 0.14269569729055676, 0.18276808916458062, 0.10820027294435672, 0.11153819026159388, 0.08703087602875062, 0.13173483258911542, 0.11723463423550129, 0.15284094932888234, 0.10089493423168149, 0.14285984848226818, 0.1413641401699611, 0.17759575242442743, 0.12160627251224858, 0.10807062525834356, 0.13120101551924432, 0.1147614690874304, 0.12384577734129769, 0.14399962446519307, 0.12220380402037076, 0.08565732437585082, 0.28013828503234045, 0.12922084677432263, 0.13530554170055048, 0.2189276274293661, 0.09719740013991084, 0.14661848465246813, 0.15852404651897295, 0.11419065828834261, 0.15944833335067543, 0.1882323045283556, 0.13007976354232856, 0.06278929646526064, 0.09478178833212171, 0.14114810819072382, 0.15587481510426315, 0.1710296097610678, 0.08521605948252337, 0.12335489796740667, 0.12489289258207593, 0.09760213949318443, 0.10786578910691397, 0.0911367457093937, 0.0924270139741046, 0.07021666970103979, 0.07295105047523975, 0.09382896231753485, 0.08777134093855109, 0.1359561210764306, 0.17911473448787416, 0.11686229492936816, 0.15146222045379026, 0.09746380655893258, 0.19953027899776185, 0.1862454725695508, 0.10541549058897154, 0.15192660982055323, 0.27805260409201893, 0.1396075894257852, 0.09621656419975416, 0.21772002508597715, 0.08773936158312218, 0.1030370896416051, 0.1445104663393327, 0.12148343053247247, 0.08405387148793254, 0.1037749761183347, 0.07677269540727139, 0.07807044791323797, 0.11986513808369637, 0.2297458504991872, 0.16207245896969522, 0.1431358222450529, 0.14796050478305134, 0.0925522715385471, 0.15704534229423317, 0.12287437303790025, 0.1308406184294394, 0.09367991531533854, 0.08394751790910959, 0.09061244848583426, 0.15111481052424225, 0.10610699241182633, 0.22961980583412306, 0.07685166331274168, 0.0931535078478711, 0.06919522344001702, 0.14906923100352287, 0.13917680111314568, 0.11400863448423998, 0.15306458090032848, 0.15877548445548328, 0.10902367518948657, 0.0906452624393361, 0.15025931357273034, 0.19284118578902312, 0.13499997024025234, 0.17519835249653884, 0.07487608146454607, 0.177511030541999, 0.11957904057843344, 0.15657811665109225, 0.12058875496898379], [0.08317904307373933, 0.04438623593055776, 0.026742238950516497, 0.03705522484545197, 0.07874558347144298, 0.04874388960057071, 0.10546488115297896, 0.04504264731492315, 0.040858932704265626, 0.03606834315827914, 0.07581731131566422, 0.005148781396980796, 0.01635525711545987, 0.011485298480173307, 0.03882113258753504, 0.028858511642153774, 0.01833868961382125, 0.03543746165399041, 0.03109728026070765, 0.017598428264526383, 0.04618035037336605, 0.044396610730992894, 0.03465982659586838, 0.03599476282085691, 0.018164672522938678, 0.0720280935721738, 0.04043935379013419, 0.03087815416178533, 0.03110007582498448, 0.060111118746655326, 0.04647576416443501, 0.06929314961390835, 0.041672455479523966, 0.01753610143038843, 0.02606636718181627, 0.007139110355637968, 0.014281898371077009, 0.08449066483548709, 0.017389687144064477, 0.032287959940731525, 0.03087252571380564, 0.02516459414203252, 0.06587732969118015, 0.03953657651852284, 0.04079173398869378, 0.02335242218604045, 0.06659510438995701, 0.006838457850140652, 0.08556461613625288, 0.045700364879199436, 0.0762752749558006, 0.014359149582950132, 0.02333857328630984, 0.1003612189420632, 0.039353724901697466, 0.02679653532270874, 0.016264626889356544, 0.013178919342213442, 0.042876546404191425, 0.03463626107467072, 0.02234824464124228, 0.03570279938035777, 0.051189356949180365, 0.039219883869269064, 0.05610519727425916, 0.02276475996976452, 0.040330296249261925, 0.072140350405659, 0.01843637999679361, 0.06395590172282287, 0.02279921597801149, 0.07298566254654101, 0.010300217562222054, 0.04807678111163633, 0.03170774464628526, 0.06354956781225544, 0.04157618832375322, 0.05310004370819245, 0.03360840265772172, 0.01215938909444958, 0.04349312778296215, 0.04269419351060476, 0.053179316954421144, 0.024554859181599956, 0.030543246239955937, 0.06101516487875155, 0.006908862219591225, 0.03932896176619189, 0.01923357043415308, 0.029818811719971042, 0.018126800090872815, 0.04821180958034737, 0.033352309970983436, 0.04646688892639109, 0.043736664179180346, 0.0873248241841793, 0.031647840182163885, 0.06770357276712145, 0.04225133405998349, 0.01644521389555718, 0.02301155842308487, 0.0959402240280594, 0.04118565070841994, 0.030320700324539627, 0.03453017890985523, 0.03077144774475268, 0.036831566132605076, 0.0469333206835602, 0.026130585432318703, 0.04626802049045052, 0.03976735306371536, 0.026341272251946584, 0.09579792166394846, 0.022660550561600497, 0.017926243799073354, 0.01401442410756967, 0.02390537055076233, 0.026190732472709248, 0.07302712103618042, 0.006343044165987521, 0.10723711284143583, 0.06523247715085745, 0.05887198488094977, 0.028126353697319115, 0.07152447809598275, 0.0250034013630024, 0.05954675403024469, 0.08171687474740402, 0.04440090585766094, 0.024042161514184306, 0.04075389887605395, 0.05165729844676597, 0.021034931630960534, 0.023427749751135707, 0.03229759853067143, 0.01943992480768689, 0.042508081533014774, 0.04991890869236418, 0.022355927353990928, 0.04147631814703345, 0.021567825893206254, 0.02493825351952442, 0.026037926386509622, 0.0313120739135359, 0.07171649672091007, 0.013036483815605087, 0.042224046774208546, 0.029182026961020062, 0.023821247475487844, 0.025134463794529438, 0.010950499230862727, 0.02710650029725262, 0.00917652964458934, 0.043645899942410846, 0.03362748645512121, 0.03527665903259601, 0.03969218834702458, 0.021285312749179344, 0.03752467608345406, 0.010707918720852052, 0.040881378642682514, 0.03108966370512332, 0.03969157088015761, 0.037060130653636794, 0.022863307003197924, 0.026359370477231484, 0.018339639562847357, 0.03886684888441648, 0.028279393878100172, 0.02697026912522103, 0.010105422880899693, 0.04127174662426114, 0.03655616233923605, 0.05421750606702907, 0.03731990439285125, 0.0307431731905256, 0.04792702504034553, 0.038321754562535455, 0.06693359158400979, 0.032766707108489106, 0.012211024761199951, 0.03720917087048292, 0.044601012620010545, 0.044836891748543294, 0.01999679340847901, 0.02624394997422184, 0.09046619704791478, 0.07018197620553629, 0.0176920491337244, 0.040225157248122353, 0.004805532583434666, 0.021090641052329114, 0.017048197432554195, 0.05231299736936178, 0.025136277179366777, 0.04072540379794581, 0.015435976175857442, 0.02194419569735016, 0.06450449050004993, 0.027302415409524525, 0.01594444826644446, 0.04562561067619494, 0.014708193085555519, 0.007956081785128584, 0.01831879496707448, 0.048628833810133595, 0.03497106382357223, 0.05026625755376049, 0.038183523408536396, 0.02945828570851258, 0.01069829030893743, 0.02541859185190073, 0.002264554645600063, 0.07177980403814997, 0.05559083380337272, 0.03296454077852624, 0.031150338306490864, 0.005790199701940375, 0.02050784902114953, 0.03839253255033067, 0.06504437367298774, 0.01456896448507905, 0.03622559704152601, 0.05637169868818351, 0.06470325376306262, 0.009945805999450386, 0.01668245518313987, 0.026531087334400842, 0.006096470901476485, 0.04857228470167943, 0.007195151410996914, 0.009831144607492855, 0.05331019278881805, 0.056666525546461344, 0.02862251376999276, 0.09805725328624249, 0.06510446473423924, 0.013508731466052788, 0.030970553667949777, 0.12381745528961931, 0.005031935970431992, 0.04973353971061962, 0.028726431408098767, 0.04544718310769115, 0.04283315748242395, 0.03161723146747265, 0.007317647337913513, 0.04039906916607704, 0.032033329496958425, 0.037101497541048696, 0.06789851587797914, 0.037586544906454425, 0.03415642485820821, 0.0811012942077858, 0.038047741765954664, 0.011951494446423436, 0.036213539474244626, 0.016572291630187204, 0.06205738788204534, 0.030594957393727133, 0.05172075164903488, 0.01453325488338513, 0.03324861964210868, 0.029243207070976496, 0.022999095431129848, 0.019252589770725796, 0.0668367917782494, 0.031095709452139478, 0.03184498853183218, 0.018198829975777438, 0.02938900049775839, 0.051782817247190645, 0.0649333382025361, 0.02403876375007842, 0.03496130649000406, 0.010936489179065185, 0.05036214812259589, 0.04637161582442267, 0.016059487093506113, 0.015702747307451706, 0.022780683490314653, 0.038608052235628874, 0.05260976144511785, 0.09408918728253671, 0.002689681643719918, 0.04861621305878673, 0.025635940189074193, 0.04896789097360202, 0.027213045562218343, 0.031217791472694705, 0.059729666715221744, 0.004865245785497661, 0.011170545592904091, 0.03400721500760742, 0.023098879094634737, 0.009549889297756766, 0.0852198592786278, 0.0415465770555394, 0.06119882395224912, 0.05658169849110501, 0.01889761587205742, 0.03419082997632878, 0.048755685931869915, 0.06880832955773387, 0.020925889357126186, 0.021995672756539922, 0.019112110969477465, 0.006428653232952846, 0.03571213262953928, 0.030981230416468213, 0.04248987304578934, 0.06183572406215327, 0.06474232380943638, 0.05363330437934824, 0.01650977480624403, 0.056616761788193665, 0.003201887373247051, 0.0358969214638429, 0.00733064637253327, 0.0399103577115706, 0.008115811473024743, 0.01783116577592279, 0.02541001856194011, 0.044374836542244465, 0.03876695156629596, 0.08707919450742857, 0.0422428930843515, 0.01492175689366247, 0.0068257281091064215, 0.03247130688812051, 0.03298957872071436, 0.05621900116758687, 0.06947759578802756, 0.026842785965917364, 0.10257920064032078, 0.017491660779342055, 0.040233482872801166, 0.006310674228838512, 0.016833344407911812, 0.019429185294679234, 0.015163649538797992, 0.021373274636321833, 0.047624116829995594, 0.05091378012938159, 0.08982774309281792, 0.03260844899341464, 0.02457731360170458, 0.06759020313620567, 0.05020871099882892, 0.025990819092839956, 0.011114955763332546, 0.08687925059348345, 0.21643758033003124, 0.12163060477801732, 0.09425481768058878, 0.1039434631488153, 0.19403801299631596, 0.08139199896582536, 0.15215664676257543, 0.10291996092668601, 0.08723905735782214, 0.10888707251953227, 0.2936687075666019, 0.16253121649580343, 0.10588266194931098, 0.110131342895329, 0.10576437293951, 0.13812526182404586, 0.1171899459191731, 0.09860970971307584, 0.13836528680154256, 0.13051456878227846, 0.15744391376418726, 0.16115110340927327, 0.12082958061780248, 0.10047711272324834, 0.11604278747524534, 0.13364979411874497, 0.11683625275535242, 0.15028562716075353, 0.10583623658333506, 0.17393151404602186, 0.17983976272600039, 0.23237349092960358, 0.1559775045939854, 0.0968435373423355, 0.189339280128479, 0.12932139209338597, 0.07268519366958312, 0.17290446987109526, 0.11970691728804793, 0.12496948561498097, 0.13118027948907443, 0.14051675849727222, 0.1708265920834882, 0.09146874610866819, 0.12389024852641992, 0.09140237859849419, 0.08714845936213221, 0.12097999826073647, 0.14251869464559214, 0.12588295659848622, 0.23143268855554716, 0.1007045983736004, 0.14431888876216753, 0.19028773637754576, 0.1210814935288259, 0.12930795710001672, 0.1012923318360533, 0.18372533922748907, 0.13851208106747695, 0.163988411160452, 0.12987061190818036, 0.07601113484374114, 0.139502172225288, 0.2148071556751217, 0.21873765119484492, 0.18193917721509933, 0.19951693899929523, 0.17949820176831313, 0.1078037235087582, 0.18181938864290714, 0.1825417705944606, 0.16519937903753348, 0.12687083573213645, 0.12761319375463895, 0.15265211303319248, 0.15831940035734857, 0.10544007391269718, 0.1570559274405241, 0.14981662375586374, 0.12454227996723992, 0.18522692365305765, 0.08511081191578082, 0.10304197509373937, 0.10541881541056292, 0.10602694563567638, 0.20739002153277397, 0.12010581445481096, 0.1374513272728239, 0.1247192554708038, 0.11578079153384481, 0.10904498118907213, 0.1972810575472457, 0.1563330026609557, 0.08739235877458539, 0.12240049775157656, 0.16295025258191995, 0.18842848257294723, 0.13217053349528993, 0.09023595654538699, 0.0851851725684745, 0.1557517967053822, 0.2107216827571392, 0.11130505919988666, 0.07422089483588934, 0.09398652493421521, 0.12012211286595889, 0.1402459823127304, 0.15887393988668919, 0.092569187416562, 0.13287519211215632, 0.17790705072028296, 0.13241230909313473, 0.2084480476166521, 0.09399025009146758, 0.08329813275486231, 0.11547071460102286, 0.12617391241448267, 0.09088863937982491, 0.09456667916050979, 0.0776587739320738, 0.18306622388107435, 0.126111487192767, 0.16461719599153313, 0.1814428967024599, 0.1295408574598176, 0.12805376654224737, 0.1460464389196464, 0.18562777500067437, 0.10665317238973719, 0.09175853484443255, 0.16848567341055187, 0.11218324636242219, 0.18068147184593336, 0.13178393138306482, 0.250344273767301, 0.1178771797567606, 0.08462113354887281, 0.15716270171105862, 0.15564002841711044, 0.09659315113510404, 0.0894688523507544, 0.16452270320483617, 0.10116218203412634, 0.1320348943450621, 0.1296806221029588, 0.11919193635029451, 0.1513397991657257, 0.11758121635232653, 0.14041895445968422, 0.1301047879138163, 0.14176467939146928, 0.07520238895501409, 0.09117518471820013, 0.07195066594119583, 0.17086304298469, 0.1584712022117206, 0.09578447988522903, 0.08235950847821576, 0.20691385279808724, 0.09077869635075331, 0.16137290293616907, 0.10178001531000648, 0.12656644492277078, 0.12068579904735088, 0.12015807522194726, 0.14667271317115851, 0.1592645046434232, 0.1291836087724992, 0.155485118872353, 0.1289210021495819, 0.12513295827167376, 0.11755321999745709, 0.10998241802943604, 0.10739822419626371, 0.1780039183795452, 0.16372532956302166], [0.04112201430169599, 0.054110996425151825, 0.03320018920515265, 0.07943604713571922, 0.04114197001659444, 0.02590500985804413, 0.09493294557822601, 0.02241472071701927, 0.016682784272623912, 0.0361387988419405, 0.019494955694036822, 0.01223540197991367, 0.028705169513289417, 0.11482122088117258, 0.02486357225903443, 0.0386315363326243, 0.03662670283977475, 0.010548585975941802, 0.039213207084685564, 0.014224222894491894, 0.039798776020428965, 0.021919634426012635, 0.04092975140416196, 0.035709913820028305, 0.06881734050278153, 0.013999238493852317, 0.04669085976534656, 0.019115839519404938, 0.05868014946047749, 0.017199045945225016, 0.030084743164479733, 0.04407012682142002, 0.036806494263666015, 0.055264862187738927, 0.038931245250361304, 0.03330765897408128, 0.06219111356352057, 0.06873022339173726, 0.02531861310957798, 0.03440406299861414, 0.015004790920232023, 0.04072059977001377, 0.026088589203677008, 0.021772465269480432, 0.02082024484739772, 0.031160750426352024, 0.0382602860751961, 0.014320206761892353, 0.0474811868209924, 0.05534445773810148, 0.013110821567741888, 0.007704237575775811, 0.03105707706085273, 0.04030691732519439, 0.03493660781532526, 0.05161947351215141, 0.01591337814794055, 0.04919418579499636, 0.0449081277474761, 0.04080890431734068, 0.030931276668395315, 0.05401591331298862, 0.027860897227323482, 0.06108568502323968, 0.020491854254422442, 0.02722984608928008, 0.020420516475236843, 0.049078692349472215, 0.03686924518219062, 0.02502313655401979, 0.005340068052256746, 0.07843064144253731, 0.018459792847612073, 0.10127697658858129, 0.030036390759050846, 0.015389878203028014, 0.04582301686917033, 0.033007919522268434, 0.008718203836386757, 0.043641801590898206, 0.038066954485007694, 0.008756905777512916, 0.05910677835345268, 0.024939052494508878, 0.017918196373752186, 0.061082543406103335, 0.06289809277015072, 0.03500132309272885, 0.016787256613107662, 0.04508096418742623, 0.04256081048931394, 0.04916093757908259, 0.05080007462363158, 0.012174898708638335, 0.024811786466411183, 0.02435031988924103, 0.026439639473600045, 0.021647781067128693, 0.020200053662327782, 0.012965530256873794, 0.036119084006973674, 0.03001183457672596, 0.044747135136276484, 0.034692874643951654, 0.004926854644769004, 0.03475444491154381, 0.0032274452428932166, 0.023109929037413428, 0.010410532937385142, 0.00428751647372597, 0.020593900832214525, 0.04371137857171042, 0.016323569530088986, 0.013428702501447072, 0.01604115477363978, 0.03191094213564481, 0.029072260351053307, 0.013725518315498317, 0.014404577502448643, 0.037974934958453686, 0.04184832836368254, 0.04477861916114177, 0.04481432367382305, 0.038192856657717905, 0.039556454201894145, 0.05082911592242973, 0.026331536970766525, 0.02509988395364157, 0.038568748094673665, 0.028190253036362783, 0.08580265979149512, 0.01100484055599996, 0.04048561291503055, 0.03512300138494798, 0.03202740927892072, 0.07082403318158217, 0.057180559927863736, 0.043114695232361555, 0.03392559063753911, 0.026288740070802823, 0.062237647495099475, 0.04831339645066431, 0.03863981106717672, 0.05352519678750208, 0.052537164983472655, 0.026444097448672568, 0.1525764563786132, 0.08793792807097946, 0.03457794438249298, 0.02859324516196336, 0.04134174768946, 0.04895607767892735, 0.03151803982577153, 0.01750847148442907, 0.02004131718006517, 0.0384476431645453, 0.047529725823551416, 0.0614691251622779, 0.009834146276781601, 0.005594987297497157, 0.03722919104620814, 0.02077217573033912, 0.018922608013131788, 0.050353167711624076, 0.0533590676662113, 0.030678457913122008, 0.03087744170001575, 0.01644722235921238, 0.039643852904971154, 0.0552237090388579, 0.011531613584208702, 0.04325091453003032, 0.13817824183830194, 0.029784121617142643, 0.043098905722477605, 0.04624504190204399, 0.030400543540183986, 0.054277325714273114, 0.022680608056751744, 0.03884926125673311, 0.045360445976257324, 0.020072405958282094, 0.05244833457150629, 0.05012178048491478, 0.0435519398057035, 0.06059748586267233, 0.0741944523262126, 0.027914755944428698, 0.06654732195394379, 0.005532171069977007, 0.022225606221971766, 0.030015773472509215, 0.03720454665433083, 0.029327179172209332, 0.05058028695306607, 0.02145823570234435, 0.02305308815890125, 0.007701557362452149, 0.03628669233460512, 0.033764082339725325, 0.09590964924011912, 0.013710128293106598, 0.0651269174580063, 0.049759741340364726, 0.034267653711140156, 0.031859220803848336, 0.057483770086296966, 0.008864920918962784, 0.0910618422286851, 0.003674830310046673, 0.04619951220229268, 0.02759788348339498, 0.03724751827706184, 0.012041734514891036, 0.04543290673089879, 0.03336786877896104, 0.038774401880800724, 0.025338592573202083, 0.07963790451841694, 0.03229723212176135, 0.005541235449657376, 0.015068281441926956, 0.016043246357834766, 0.04869727085211447, 0.13003021691526684, 0.05714876377688987, 0.06409717271370546, 0.024240193655714393, 0.04609270739768233, 0.04172720307750361, 0.026716612379199693, 0.014883950618760926, 0.04824120711003031, 0.05886163722191538, 0.028750057997448102, 0.04144029472289341, 0.04709040154037731, 0.035921026420380385, 0.03907656030995505, 0.08783866518310138, 0.03385430374847991, 0.07899089423673493, 0.03466075618884393, 0.024564068598140563, 0.020736985207934464, 0.01568188744464091, 0.028366495722106526, 0.02754288143478334, 0.017431898807574595, 0.01607278298719653, 0.029564798743064915, 0.07815421984664031, 0.008794993644447198, 0.0842952671061669, 0.07369471128497805, 0.08378262032887765, 0.053897563235035965, 0.029654772486537695, 0.03631828153239829, 0.03169791267386504, 0.05441642878577113, 0.055224994862718244, 0.02993453586740153, 0.041327685051198514, 0.021126343868672848, 0.05931068491190672, 0.03831221775284835, 0.02169270856705095, 0.08737695602966206, 0.005379149548908961, 0.01458311194021787, 0.09892903507820197, 0.01985939685255289, 0.004200764075254223, 0.026333609895248498, 0.05001383913414819, 0.05559234693646431, 0.035927479288407733, 0.08186980296990701, 0.037358872658972225, 0.050316438611064634, 0.07061011823160307, 0.09620532765984535, 0.04009237473032304, 0.027296004949935844, 0.049826526149575195, 0.009518975242307144, 0.038565565765436204, 0.029157460600669895, 0.019425417728988186, 0.06307996729654924, 0.06931977532804012, 0.034053972855742486, 0.04750426040430154, 0.026149974570476582, 0.015820993908814023, 0.04928779987884419, 0.016900836589879224, 0.006414808998150485, 0.06987550907901355, 0.027215372937332307, 0.015060697116756012, 0.06549053080379963, 0.013215220117542361, 0.05171138447310243, 0.019104214518197944, 0.04176143856186952, 0.040502427012792656, 0.0306646056207163, 0.055984767486474345, 0.026071697074387754, 0.05357519803302629, 0.042669562689427815, 0.03935140770460878, 0.03703112667426467, 0.06385300188724484, 0.07087041783545699, 0.03143531283629792, 0.013957377972214349, 0.11390476434358529, 0.07091095351747104, 0.03143772502828922, 0.11424996224897248, 0.014434804541191884, 0.011111616522872021, 0.02191606872448964, 0.039137014387441535, 0.0777267970676933, 0.06867625271635396, 0.04450688624222364, 0.0205272449446576, 0.0744996913043516, 0.03207595506682992, 0.029304119159600565, 0.02305724927490311, 0.05527284175955823, 0.020445798690031682, 0.052797970095915456, 0.026928678321252977, 0.03817610702078257, 0.009089070721529424, 0.04030724302200334, 0.011870272108353674, 0.015034792346081563, 0.059280965078089914, 0.047069624798106294, 0.04666777939668723, 0.08353134524077177, 0.03773190746349948, 0.07984552266342299, 0.007331826175296945, 0.037548160180449486, 0.09834240084247929, 0.07534285927457468, 0.1823872003172125, 0.13263537069516523, 0.20013619719871453, 0.12207140826753207, 0.16250038386455604, 0.09152956320238964, 0.11714987164097172, 0.13225962514323847, 0.15742966452879564, 0.09165929909795523, 0.1774572091443198, 0.16304327973297664, 0.07122706941195897, 0.13472582852201803, 0.2354950505707945, 0.055982613137790134, 0.16838944357420715, 0.13211245089769363, 0.13230146361248835, 0.12566784742687429, 0.13932738160448416, 0.11654159213815417, 0.15725860585059437, 0.17152221261390618, 0.22923703065940312, 0.16031928732991219, 0.11156986427626439, 0.13441812646176132, 0.15004079815532478, 0.07238541011299406, 0.12591867468186788, 0.0963549582021577, 0.23768756006445202, 0.1175255086272955, 0.23310229182243347, 0.18142380272703512, 0.08459962398878165, 0.15306566655635834, 0.1431217629994665, 0.11188755437199559, 0.12712360359728336, 0.0799593265567507, 0.10711786709725857, 0.09325089119374752, 0.20268093422055244, 0.17771408893167973, 0.18234029997672352, 0.1361916270107031, 0.16056601623339312, 0.0858452921467168, 0.10949126724153757, 0.08177623977618557, 0.17029441706836224, 0.06850901419030768, 0.13837732401277336, 0.1557354304407324, 0.11955698819032737, 0.1499000699924571, 0.13159398228994437, 0.09564972283052546, 0.13180398887821607, 0.1958589974258627, 0.18057258054614067, 0.1699445644127471, 0.08434932599110262, 0.10603844001889229, 0.06894960733396666, 0.059851043059357574, 0.10224871337413788, 0.16465995726840837, 0.11797723653061049, 0.12073286223624434, 0.07527485649500575, 0.14250433684459754, 0.07012314721941948, 0.18260370727096284, 0.1569248073335205, 0.11898221474673067, 0.18572952811207089, 0.051415400712617805, 0.08987101327095713, 0.08514559362083673, 0.12292263044842652, 0.14288803482694284, 0.1292108315974474, 0.09928881470113993, 0.08214866729187113, 0.11859259993902274, 0.14925259830696241, 0.17433847220880644, 0.19526152020054205, 0.07951702350484473, 0.12607947391058716, 0.19471905859453337, 0.09370363011424031, 0.12094228528439999, 0.10783511932407107, 0.1315339726528951, 0.1255778329713004, 0.141240280387657, 0.12015169699277196, 0.1165850998035499, 0.0949217090383172, 0.17644098081759044, 0.1415054247315441, 0.22473505937627383, 0.12542121351829597, 0.08152780774980783, 0.10185870501611914, 0.16164898526455673, 0.08302184686596904, 0.1135461043034281, 0.10917638628078358, 0.16544038110545703, 0.10428901389241219, 0.26150962178196224, 0.1255828541304384, 0.11847658402153424, 0.1890049252126898, 0.1271456695560898, 0.17626918932156904, 0.1266854599650417, 0.0753022353830082, 0.10976534789162022, 0.25119179114699364, 0.05530593730509281, 0.11114842617618186, 0.11456250904926232, 0.1362375502607652, 0.0931959773546883, 0.10660592599638871, 0.14247882392789635, 0.10876216779329947, 0.1423849282520158, 0.18915235730154173, 0.10818106361797877, 0.13778424369437353, 0.21694148757628032, 0.1426121832004615, 0.10107881043638502, 0.1054357448592782, 0.21890476079923765, 0.15163190849125385, 0.10993302746542863, 0.3413896140243326, 0.12695506906935147, 0.11307995074561664, 0.10196687028344188, 0.11313179082104138, 0.1594183421028512, 0.15460934729448386, 0.09269838726946286, 0.12169666694743292, 0.1617131203945194, 0.19867501274815627, 0.09116108476051263, 0.11502096801996231, 0.24712332231657846, 0.09877735536013331, 0.08320159757775919, 0.12160729031477656, 0.11932009804461684, 0.09099583434207098, 0.12496165532086577, 0.12406588053064686, 0.11360527934240443, 0.16346671272601399, 0.14214176844273294, 0.10500446121607508, 0.11503677788589682, 0.1446773995246206, 0.12900701324854577, 0.09426981330450092, 0.1645605926002775], [0.0400710110552609, 0.05084347711609943, 0.012138139922171831, 0.039582794931318076, 0.05691195505538157, 0.015253540161730987, 0.032625185059649606, 0.05133251426741481, 0.060936665162444115, 0.007162808191164264, 0.03598838119900652, 0.01601335180125066, 0.07540892822934048, 0.040021019987761974, 0.005677656187409801, 0.06691195310226508, 0.014650010404043963, 0.06419864084039416, 0.013825748963946742, 0.04534467003707375, 0.017520713952503035, 0.07602072932890483, 0.0588943629658648, 0.05450281986434545, 0.020231364660763314, 0.029642609746328423, 0.062411589947129996, 0.04557871712105615, 0.05923568643629551, 0.08507004553186041, 0.011060187809302338, 0.04724580641569836, 0.022739124916759983, 0.03783291757905057, 0.05401944508776069, 0.04442767406414662, 0.017825069138780236, 0.04137409345379897, 0.07369560695120267, 0.029050910246691534, 0.04149323741772345, 0.020858269949842776, 0.06090191059878894, 0.05764049131955419, 0.023004326936123625, 0.029473457751529555, 0.05520108328866107, 0.0382439673079976, 0.10177329102797167, 0.039800139875816445, 0.005269448247937751, 0.010668092956101256, 0.05480481205242021, 0.05449432460591197, 0.010921372267018472, 0.04105818111981664, 0.029037916301084415, 0.03819860384932586, 0.0792809883132577, 0.02064625489791589, 0.051519511733204126, 0.04061875505638974, 0.022425385591174875, 0.03914713134456958, 0.035706921480596066, 0.03587817354127765, 0.04011870528172169, 0.02630649563590331, 0.042130734638444016, 0.03740922674270613, 0.05594496801495552, 0.0456553474733872, 0.016951355218355144, 0.0617124613906656, 0.014510254242590495, 0.020584197781447853, 0.05204995309135743, 0.03953738058251994, 0.027808685653976033, 0.019185377484453574, 0.05371526801692588, 0.05920790042728186, 0.009016251191496849, 0.07870734802314214, 0.02468377913880561, 0.0554167929637645, 0.01739701023325324, 0.035172649792262485, 0.024067092587106993, 0.03948797644781215, 0.017937427752518227, 0.02051676666763212, 0.011949967742631478, 0.09063252633703606, 0.016832743904420307, 0.033296279941818545, 0.023120422581476823, 0.023549697761024748, 0.07634758643273797, 0.04957512553249087, 0.010258683585561812, 0.03049129420625312, 0.015452091382550341, 0.012470124206239623, 0.029009872448763678, 0.07154869501079832, 0.01275809616449156, 0.020530011671196138, 0.03125755701746259, 0.047879344384585104, 0.01729524864016899, 0.021203415268766027, 0.041100036552441974, 0.015444761508011391, 0.04673210112378001, 0.014446215803868004, 0.04077658908707755, 0.02839151330824409, 0.024275976199922816, 0.015563667984679341, 0.029307332022913864, 0.02708335716410407, 0.03352714130388839, 0.03873138276061841, 0.0736752034031919, 0.005234102086563195, 0.08578056669128792, 0.055217340987707884, 0.07738199271261692, 0.006542978750076145, 0.08132117348057882, 0.04339548659377864, 0.04747398756444454, 0.012814626613232707, 0.08255852279918534, 0.06207529442118747, 0.0519968068360218, 0.021376341614606123, 0.05405936669558287, 0.048920875282159874, 0.007864432060159743, 0.053005730733275414, 0.06163165465529476, 0.05839992806847606, 0.007763898615459246, 0.049674639478325844, 0.037206894385495355, 0.01834169213127877, 0.020453542470932007, 0.04259035390402589, 0.016437597339972854, 0.012138400309985238, 0.017691889677995017, 0.06660876329988241, 0.06326699190373931, 0.012282849389261432, 0.026194903766736388, 0.012149485875852406, 0.011932321591302752, 0.018184818227642348, 0.024364067008718848, 0.04398900456726551, 0.01963724957646004, 0.009935868854102279, 0.03625134405280862, 0.015070369633446847, 0.023750757865075554, 0.010290414427540131, 0.044529172724911144, 0.02550934930332005, 0.07355265319347382, 0.06580819375813007, 0.019954211943383728, 0.0708100146480969, 0.00934640852002693, 0.04441213221954448, 0.03278194361233285, 0.08221322311354534, 0.03247972411502685, 0.04694145631843379, 0.03558571816288999, 0.031379459226237874, 0.05813954025506973, 0.06580413611871855, 0.005547201468808842, 0.06863267719745636, 0.01116212158064757, 0.03999238241729992, 0.0587862723373941, 0.02944145125469991, 0.01935044300210263, 0.00957623341985579, 0.030865865892597606, 0.002350601155610223, 0.05111663495855672, 0.020278399011918476, 0.05262134064521108, 0.06897220933543784, 0.06388781751905169, 0.017755066377243826, 0.04144513267757637, 0.06232648129974093, 0.011454321660234459, 0.1224280327026333, 0.018986322451382875, 0.03299873894346612, 0.019998089410364628, 0.05362829339823552, 0.035443500615656376, 0.03245575486549309, 0.01304584929519998, 0.025943029871476547, 0.02448237807090793, 0.04939385150958385, 0.020690407171579342, 0.01011000553678189, 0.06999817463968482, 0.05120153326009001, 0.05936253855803183, 0.022642382786476185, 0.033507056667336395, 0.04029603362349527, 0.06964413542300463, 0.05265699426776596, 0.026501530348988514, 0.032238477774496586, 0.06322650371917657, 0.05765005187796695, 0.043232641581978114, 0.02197015644716365, 0.015935228671878576, 0.05062548756333334, 0.02160913510514157, 0.05365161803950157, 0.039408346970698664, 0.0338687667224024, 0.020063958197299923, 0.04031638967405472, 0.053939747757145336, 0.023244016038786088, 0.011321355089811342, 0.02255018175180469, 0.07895803957113198, 0.0027144411745082054, 0.03242738192368831, 0.04390329202370984, 0.030796838525150503, 0.057167701689260345, 0.047974549633051665, 0.021594402413549166, 0.00971037894487381, 0.02615429853488292, 0.08948039423142161, 0.04767516641212361, 0.039923049709094424, 0.049798092139618735, 0.026415894140622447, 0.0650215477549604, 0.04483229128111686, 0.01293208441763584, 0.05910914644066777, 0.03206045732700399, 0.014094016265257128, 0.03450833008225475, 0.012386017246171832, 0.04900446401110717, 0.01787799147755972, 0.010019184472704572, 0.028993010853550265, 0.047119826211461, 0.02267343594160463, 0.07293369354946272, 0.05652360910815852, 0.013744162761473229, 0.024073762586340308, 0.04802160942927003, 0.03436007696603026, 0.02487730241513678, 0.004012832351561103, 0.013411919785929578, 0.04360477054225547, 0.01709939120337367, 0.03231430406283055, 0.05203302703531725, 0.051080014423600266, 0.033662780454116206, 0.01738599082455039, 0.06279864667781762, 0.11270081251859665, 0.036158259226275344, 0.018542217889002392, 0.02902282907494477, 0.015227543788829019, 0.028403024654835463, 0.04271323998857822, 0.012984613206104507, 0.021265323107529963, 0.0210238291017179, 0.07461388874799013, 0.019694840236167823, 0.07863827315824372, 0.025852935688037957, 0.00792786490637809, 0.03537875819685204, 0.031722933652677705, 0.04576053057930299, 0.0436293538659811, 0.02160377467849425, 0.041975044778415134, 0.03009335377386638, 0.05029725981876254, 0.028769745691014186, 0.030021459595965486, 0.03928441594221762, 0.023767124129725353, 0.060924336181155274, 0.021667036194620386, 0.022973865802798952, 0.012538529017807117, 0.026290656932230507, 0.03344952707578029, 0.02501463281389858, 0.011965574048060392, 0.0625435717936073, 0.06066544793014016, 0.044165535630392175, 0.007628555476133312, 0.0308856994711927, 0.03625692500333701, 0.10715686929013048, 0.02544896986468562, 0.025302650573264276, 0.019594347503568445, 0.04332745328013386, 0.022558819502592087, 0.021943622335259403, 0.03750629456979888, 0.03694450828645911, 0.03708193537646106, 0.043325923183666806, 0.034090786773179255, 0.023844153121379868, 0.06157011152910335, 0.008234754420949944, 0.005261694289012147, 0.022187621831627827, 0.013869538221375217, 0.023257980289469873, 0.03668833417551858, 0.07288770923124892, 0.05946052580007485, 0.011949603878227728, 0.0998100381610649, 0.19575048610568047, 0.104614622491811, 0.20113297871180943, 0.1087500084457653, 0.13428075026188577, 0.1630228151168142, 0.12471698916384152, 0.16883799593363488, 0.15714321418532304, 0.14599107046212467, 0.04480337551129716, 0.17151610579873833, 0.09513171562658888, 0.1396882672395025, 0.18498141611261026, 0.13901003077626228, 0.1633009330502578, 0.07251252686338765, 0.11157408476408039, 0.08944859129509755, 0.19989856066448347, 0.26563842594623566, 0.13074358792177268, 0.10340913717768022, 0.11150781903415918, 0.11715920828282833, 0.2189456086073603, 0.11709040483193738, 0.1785113268664905, 0.07719654230667011, 0.11729138690446105, 0.19983219993965967, 0.13524341503424303, 0.13804256197597298, 0.18016725086740085, 0.14508914814463683, 0.2303599789738655, 0.0945814847946167, 0.13447846179561956, 0.15881342813372612, 0.13351030088961124, 0.14346176332661084, 0.1379243747464248, 0.09411063577447619, 0.1792755201458931, 0.1315274587167161, 0.15511237244520867, 0.1484334979738508, 0.16918501231287206, 0.05883555433579853, 0.14515735448471137, 0.08325362085763897, 0.13239575283867971, 0.06341363010661942, 0.10904673859477043, 0.11948585057897226, 0.12833591497370175, 0.19737556390464306, 0.16192343910889967, 0.13333260613892758, 0.22139715562973702, 0.10245025184537683, 0.1005355210176536, 0.06754499913326331, 0.14781276056809084, 0.13841206500572817, 0.10203949388648782, 0.16421781027955668, 0.10245703041021313, 0.21978441359741346, 0.14707023969718389, 0.1289592036711318, 0.16858859360218048, 0.0941753408738545, 0.0848024245351553, 0.19700606087488787, 0.1873149387538433, 0.08018602510648114, 0.13526062268231595, 0.09225425217300653, 0.22543760096388205, 0.08914299269339868, 0.17301279120147228, 0.16303221961217268, 0.14498340524733067, 0.1419096009007522, 0.09226962099117891, 0.14988759851881436, 0.14639250534985745, 0.28068382718733376, 0.1553678001676287, 0.07191266798015152, 0.1897246337362698, 0.10931885149329901, 0.09616452734917402, 0.10977055904056345, 0.08100382265235696, 0.13959515866424355, 0.13158536489520753, 0.15126091268445763, 0.15162102478955472, 0.11385234072804451, 0.07044236401894263, 0.074260324505823, 0.12155547738075256, 0.07595700810530356, 0.10657880495169333, 0.10433174802788667, 0.07843592044498239, 0.11650096146123749, 0.1220312797065292, 0.2155392678188426, 0.07488057336636952, 0.11032755486667156, 0.1336533496422427, 0.10947320463934115, 0.0907643928325602, 0.05528053295399461, 0.11623900623193809, 0.12617609729724272, 0.0692135031734194, 0.1225991320929357, 0.07771383704883711, 0.17558540244187626, 0.07358611854059355, 0.18783447944692203, 0.23131579054253443, 0.15635869199676172, 0.11593959586960928, 0.17583418052111352, 0.16583774478307792, 0.15084020740219525, 0.23339585321290152, 0.1666910568518298, 0.09963127132505178, 0.14116199101720536, 0.09893089426415307, 0.13646751934928553, 0.11336774458842618, 0.12829219017710003, 0.11798911089343683, 0.09615011526537792, 0.15180956252983638, 0.20244736889643328, 0.1199179823909487, 0.13519118140850747, 0.09860211012086698, 0.12981525702135904, 0.09196935567472662, 0.0950565543025732, 0.20118963638586657, 0.10893535028610911, 0.1456624288111925, 0.17773175798356533, 0.0593619007351143, 0.10301707285855498, 0.16233802400529385, 0.1049334118142724, 0.1396015640348196, 0.1546023990958929, 0.1463741577629532, 0.1302774886467627, 0.16513362899422646, 0.09731911575155598, 0.1341620066336223, 0.10443088877946138, 0.0898432611886944, 0.11724546365439892, 0.19230819653187478, 0.10879419464617968, 0.07771636119910649, 0.0825019194079297, 0.15749135693269117, 0.15316727039005074, 0.07680348054106746], [0.08669063821434975, 0.02470927848480642, 0.057974391616880894, 0.01938942144624889, 0.03531258406915835, 0.06587865283446652, 0.006120990612544119, 0.01626787367942078, 0.0986087801201003, 0.09527669141867331, 0.031057657208293676, 0.048817815990852456, 0.0453960012112345, 0.02390244267215686, 0.052333665546029806, 0.00614735297027177, 0.05255106138065457, 0.010467136328640794, 0.026300833261172687, 0.0807525339935507, 0.01263015584221908, 0.04759653777416263, 0.030079586298338006, 0.04370879674596446, 0.052834651699023585, 0.007307950224328254, 0.04503281534250293, 0.012502357164131743, 0.0336198597215116, 0.05205653148836323, 0.04703544359654188, 0.05771603262318032, 0.07251885759511165, 0.010049956035800278, 0.06969870999455452, 0.005097610950802586, 0.032185385801962445, 0.03628880257851311, 0.06950339368943657, 0.025551857825900828, 0.044694416358002594, 0.005115325803801949, 0.0528681815069701, 0.02460132017066436, 0.02691283113589244, 0.010644953215627797, 0.04729268979281187, 0.03492989371131573, 0.05052651983818837, 0.01319556889523353, 0.01824304840660521, 0.027293794622112597, 0.02288233142878328, 0.01301327537346099, 0.02620775861266468, 0.04032274415450437, 0.038022096534924846, 0.03900360422474997, 0.06260052802307264, 0.022017194190993905, 0.046428534734461985, 0.023765227624348233, 0.027558275698018924, 0.04937513412109443, 0.04165883728169969, 0.02700746471860579, 0.014439795166254044, 0.030849737115204334, 0.02068779311542, 0.014875898104427117, 0.06267539079168014, 0.01596126745321921, 0.06949175681386675, 0.018089355135868703, 0.022733314960662807, 0.06724222323724202, 0.004715002865330982, 0.02956397771569235, 0.02459940839824932, 0.06449734552630357, 0.04618180922365614, 0.027973601893920983, 0.029821325692215135, 0.014127990513640856, 0.06051395141652652, 0.009640662864382778, 0.05243749497458339, 0.03847311197647026, 0.008293931156263819, 0.02510094246827066, 0.0537198277722512, 0.08802885176347834, 0.042015919727938514, 0.03284970211929508, 0.013433516707404383, 0.042441652954689095, 0.03338159214971321, 0.01566403349196272, 0.024439799998487746, 0.015039404687870826, 0.03704816468858293, 0.03240726675306048, 0.0199433316343597, 0.037223864546311755, 0.01936321981650378, 0.06616501496838671, 0.02164874119418008, 0.045525279095662494, 0.016042513540014625, 0.012085533950344791, 0.022772580085854446, 0.02887275069952011, 0.033966248455856524, 0.02622514607251755, 0.023698441118800213, 0.016560619131528904, 0.03098241446007575, 0.051615609255220206, 0.04417662289259689, 0.045688728003629615, 0.02171633854907538, 0.060584702262920995, 0.032002629180039675, 0.0519407768068569, 0.055718018407268186, 0.024848055859495486, 0.03139890943254743, 0.0120203038344958, 0.041569002637905736, 0.005099621110795332, 0.03558753324406488, 0.03321682349113481, 0.001191707342513837, 0.06662437639066152, 0.035145525354892015, 0.03214155922510794, 0.04936270675222788, 0.028180960499282395, 0.020007125800475478, 0.028601245089833225, 0.041936415779803476, 0.07025299168058804, 0.03813461121171713, 0.02739319491333195, 0.01444773402597223, 0.05280147133661168, 0.016064452273505073, 0.043837650546005795, 0.030363017160977637, 0.04492698762831943, 0.0506567815983934, 0.09277006770883288, 0.031468153931200504, 0.025334092189690897, 0.007364015028412853, 0.011322574756507362, 0.03126358240842819, 0.042786362314862866, 0.032505756111017296, 0.0038425743446818417, 0.05105134292638727, 0.030702284670301845, 0.04250416638595717, 0.03773830604872533, 0.007486935039716107, 0.04744175036570855, 0.028806529074375118, 0.04793694522231817, 0.041708482296339104, 0.051381334862006564, 0.06021114159375429, 0.07087851275822946, 0.031064778433314393, 0.03054461009534342, 0.05646178438993437, 0.01311084786097386, 0.01996821690616863, 0.012045742112344928, 0.03913516877219081, 0.035659440992666144, 0.07400989080114023, 0.014564318216538854, 0.05567615279661758, 0.05113780864381364, 0.047216503880918026, 0.09685431926378182, 0.05530626639457686, 0.06445161226604666, 0.041314297555280585, 0.0270594964801733, 0.03217700928715723, 0.006012670978504632, 0.03737384453415871, 0.054409789320613654, 0.015329283329525163, 0.07848360110074282, 0.03504994012681501, 0.02111741265148989, 0.011270281758957675, 0.020902284820164953, 0.045770745924008746, 0.004538853478152305, 0.021869962269972478, 0.059065530209669044, 0.03447908183027591, 0.012386940901965966, 0.04010312951036862, 0.022632062268842543, 0.022143963192190443, 0.014532221813819237, 0.009529402629206223, 0.01343241408799908, 0.027479903207027485, 0.016501530605767454, 0.045712731179914305, 0.0329803201103849, 0.005962732497469655, 0.07406686060130596, 0.010484416919228221, 0.022032437480187843, 0.06435916186975581, 0.009647790874753679, 0.031327432553683005, 0.07211413181253842, 0.03479465828942401, 0.032730805820652416, 0.021807655791885087, 0.05035572578864438, 0.048111138732305596, 0.022571438557601402, 0.014971761531861765, 0.04645817653675165, 0.034018987590180974, 0.05627306005252259, 0.06113946570881775, 0.050789706608546634, 0.030002528468945196, 0.07496547166790281, 0.02206947361784322, 0.030710311739572456, 0.014310149176578437, 0.04864556309101837, 0.05020074499770999, 0.0951763903722167, 0.012152098235674202, 0.03674276964738965, 0.09116073192230292, 0.04382994917354413, 0.006870439325991485, 0.07270987198821136, 0.019918632959680896, 0.04893755367291825, 0.046659521625510285, 0.010138523515446909, 0.014324417071683066, 0.05786711523043258, 0.01014598909698959, 0.04453869935657297, 0.03079336442585502, 0.056702966269637854, 0.06890463403293065, 0.05223127121904066, 0.030729741589831452, 0.026492935006639788, 0.011659944912285676, 0.027109043107235005, 0.021955491609073112, 0.03933529249791588, 0.0963655501337988, 0.06469105370342731, 0.07778328510799579, 0.049561344486262114, 0.006845995526029063, 0.019554807571694255, 0.05518657620996237, 0.011788319496970092, 0.029690405753042017, 0.07239208011222736, 0.06053597666323185, 0.019177565850051384, 0.012029147690295108, 0.034820629217262776, 0.030852176448596374, 0.03727526357397437, 0.02891953568905592, 0.02120584442413279, 0.014476378381784474, 0.023812295902254324, 0.04091814845534308, 0.10562500863202981, 0.02483205939643085, 0.03852466706718717, 0.05020198332411902, 0.046917534566351345, 0.03170485069443073, 0.0650007099445377, 0.017090760237936462, 0.03029620521036642, 0.039312398726386685, 0.06624849513173103, 0.02189807397579508, 0.00976004940457642, 0.03223856259137392, 0.021958380471915007, 0.014107945741021206, 0.0343241587148181, 0.031870199500450065, 0.02653297026907759, 0.015631943874593292, 0.06677089245723826, 0.03417973592877388, 0.05930990459663527, 0.01487573016701, 0.056560083758085966, 0.00871698756236583, 0.07240098927702222, 0.017400723516142795, 0.06571172643452883, 0.02012918746498014, 0.05800081377050706, 0.016919133286657076, 0.012465633152584945, 0.03455294715240598, 0.04295127346579518, 0.029645619049136127, 0.0015769210024570513, 0.03242706301222954, 0.03052210308877485, 0.02196666708083025, 0.032875696795859506, 0.03610197474647846, 0.04920819415045636, 0.004718350163394851, 0.02524522615463606, 0.04766655580273696, 0.040921622554638555, 0.08461051447583096, 0.09846806552793298, 0.0161793299484998, 0.010868944410633827, 0.023985422415924922, 0.028608247571225678, 0.018428003481988395, 0.02472425714534308, 0.05127024510875344, 0.03494335584608572, 0.0442808390861111, 0.0739439439826778, 0.04292472917586565, 0.02472647595485406, 0.02497832610138825, 0.08200812911880867, 0.21304090188017913, 0.07849373162857123, 0.11934531240590981, 0.10894269882036106, 0.18167319148778915, 0.12968367551054272, 0.2333322066281523, 0.1005609185834016, 0.17332038469612598, 0.2965613023511001, 0.22735666084502423, 0.122613042060818, 0.09316684106098753, 0.08426899423024484, 0.11508506243782383, 0.17620786332658359, 0.07917624286242894, 0.08768208644219808, 0.07533045565443379, 0.19105772434600762, 0.10387483611702919, 0.15911059933049337, 0.13081900030374527, 0.09118324571422168, 0.12639504697706017, 0.10464239493012428, 0.09395259818328278, 0.12256673883114542, 0.145692610048822, 0.1476187538355589, 0.10084540117532015, 0.14799121527799539, 0.13295584278447287, 0.17918884408261093, 0.12910721930009977, 0.0632296521216631, 0.10995676262038094, 0.16253612908933843, 0.1375496605677264, 0.13942202366888523, 0.08520050745989595, 0.23935067653656006, 0.11195931623556785, 0.2197209841438702, 0.12415525716330324, 0.10232418682426214, 0.12729741712766035, 0.10286856868437358, 0.10907759158206837, 0.05541349867624896, 0.09286610077002219, 0.10927239220057215, 0.10543530381151608, 0.12455078879637377, 0.11234937887638807, 0.15038527681359223, 0.12839815020561218, 0.1239896539066519, 0.17208625163350785, 0.11356745101511478, 0.21072234772145748, 0.09590955424521651, 0.12185228216860976, 0.14366984287542955, 0.09525039818670068, 0.2113274788217885, 0.06962930943284716, 0.1666106233107192, 0.10345022925840956, 0.18575232688869747, 0.18901821092835494, 0.10713566507079772, 0.15962659807077476, 0.11508978504155364, 0.12846563729856694, 0.18797125853598118, 0.10610199839408908, 0.11261805838772229, 0.08926415869167872, 0.13969927307750496, 0.12576760564531597, 0.10316647948431117, 0.12694208190909453, 0.09620411308216197, 0.13107244670391083, 0.07544949783810548, 0.1635888490293707, 0.10343317767339093, 0.1298632294471775, 0.10611546052885906, 0.09224556013941765, 0.15307044344288961, 0.1857851001300982, 0.0783023236851607, 0.09892886544444732, 0.24250116891094617, 0.0666033485904336, 0.1464282777160406, 0.12536025393222058, 0.08668586132781846, 0.15130933294338839, 0.2188549834702696, 0.13724438766283648, 0.10959205004785742, 0.20009929846440042, 0.15436883377177374, 0.12039955226438386, 0.17384927560176167, 0.18895813343780382, 0.10147002658673696, 0.17638420100722993, 0.07940489559301309, 0.12194891912596566, 0.1504166658435549, 0.14021977729031018, 0.1957676259002515, 0.13587661034294538, 0.19185953560684407, 0.1073866416034954, 0.11976833827793598, 0.08961976532425199, 0.1513179096260241, 0.0644597275448697, 0.14023203163274697, 0.132226824760437, 0.10984676530850784, 0.18692146986722946, 0.09624504909983703, 0.12040021722870213, 0.12643105004514965, 0.10297797567078046, 0.1611164031284196, 0.09961813488709075, 0.23178989653076443, 0.11108712053724698, 0.09507828099387032, 0.11662247351237706, 0.12335686571896076, 0.14464478913162435, 0.12757938914000988, 0.10468101714338575, 0.13172458671033382, 0.06252324966979877, 0.12732909114233085, 0.10136543719896249, 0.08584769416068282, 0.08827067485877446, 0.15862083275403294, 0.1492979515876089, 0.13246370133544716, 0.13236642655517372, 0.20972880960575171, 0.09421627010617938, 0.11595061527831213, 0.10351285125528063, 0.05671249290129968, 0.1187893208116293, 0.1032371964039547, 0.064667718884136, 0.2080935537815094, 0.12615241642509187, 0.31279242996658596, 0.07031033467501402, 0.07065446728042193, 0.12848692972745213, 0.22990527908716882, 0.15538559135581764, 0.10584938659199647, 0.09892664663493633, 0.13181228057614394, 0.08323053031095437, 0.22862178938729422, 0.104136587785823, 0.12274458285953317, 0.14900928921997547, 0.13689494212823256], [0.05747859964945486, 0.05458402693537729, 0.03406724839338234, 0.0568096760793456, 0.013410364244399326, 0.04690907662734389, 0.04923190216400793, 0.09092072730085679, 0.014750258864036627, 0.011645824598547603, 0.044351423691426, 0.043754513042845895, 0.018428927985951304, 0.05340873642957636, 0.016807471867650747, 0.03674367209896445, 0.0410623167907553, 0.007950914740961577, 0.08025327471217938, 0.02750787411683372, 0.020308943265782933, 0.028030405453007137, 0.06932362262159586, 0.030018409581056664, 0.036782396092478714, 0.026589551607945135, 0.037218921418700895, 0.009881724304120456, 0.035380474890449216, 0.05680978125227349, 0.07177221801664148, 0.020391497228826796, 0.06215126320187535, 0.037692840809800794, 0.03604107962122985, 0.0635365399398974, 0.054998014720955064, 0.06859727124018328, 0.027658727718517184, 0.030172732193022966, 0.025507754746026227, 0.005635544607814933, 0.05040058713140232, 0.03378769535837429, 0.01766067197812455, 0.024181836251435534, 0.057343835809401104, 0.02404205464491887, 0.00433212548627385, 0.006970003737868475, 0.01680192314753575, 0.011012605541119618, 0.028289770374872854, 0.05545766791328788, 0.09507454905126776, 0.030405228824487755, 0.019802695073719536, 0.03388720591153417, 0.027203571517020464, 0.016938222173069204, 0.04454067389347723, 0.005998629968546863, 0.027302091409053122, 0.024144705118877546, 0.018881451471575668, 0.013750948111659713, 0.056942129507660866, 0.03401414963549801, 0.0767002889354314, 0.03840323644024985, 0.022861118727762784, 0.014490537711286118, 0.0718805461323687, 0.053424125603799305, 0.031092523730226924, 0.08054677503449575, 0.009291962870130581, 0.025018098431506326, 0.029098390734621456, 0.03973211334752185, 0.016837534361651967, 0.06171801859246833, 0.030560786370187998, 0.01258457949318524, 0.03743265994957515, 0.038032552759562216, 0.038661347768668614, 0.008282065275125206, 0.022034819138103297, 0.06924871235553708, 0.07192767717476402, 0.059361317194998264, 0.031939118302294185, 0.0395360947586596, 0.03888224484398961, 0.02071004736769412, 0.07640361306922776, 0.030858944835407392, 0.02944544782595975, 0.02073365529733045, 0.05282134562730789, 0.06606244761496782, 0.007965679662967367, 0.019647347873875072, 0.025974098293642913, 0.05116096704400011, 0.0516120978364987, 0.09089872919555221, 0.06191767752170563, 0.0071152445826945555, 0.01992756756953895, 0.01665721707312124, 0.07843440052654062, 0.014751449692994356, 0.05376436681087528, 0.03208772086405328, 0.037443655609552345, 0.022686957448188747, 0.019727944263390133, 0.05057841419641461, 0.03797795104661158, 0.05732721170144422, 0.06331674887665681, 0.05736503324338368, 0.05707933607378176, 0.08183564551706825, 0.051353084056505134, 0.01627105431232069, 0.059679740108549595, 0.02026969680030431, 0.021303149738482068, 0.03626684857798474, 0.0027218348737473464, 0.038026771641203334, 0.011267440393567085, 0.01062244112004659, 0.0493066733303879, 0.0644322604473148, 0.002493337570090911, 0.04319933569058776, 0.027725839920874153, 0.015119100322148629, 0.03356325633025595, 0.03405036644211837, 0.01336951389177037, 0.024506756137790423, 0.07368015670882803, 0.013582662945347173, 0.05377577976988895, 0.007811176391052348, 0.02624794315280659, 0.015316496337098735, 0.04609634434538228, 0.04856317536905408, 0.039061283094010184, 0.06664805047746215, 0.017360252294955508, 0.028935471083968878, 0.04289526379268084, 0.002731206714608041, 0.03518708562478423, 0.06434945203363895, 0.06854056606867484, 0.03392491888787065, 0.012679755055744733, 0.036153448412993124, 0.07327071510787521, 0.015284908835643103, 0.021003591794786707, 0.03306534054822155, 0.015187008106814963, 0.03894979979044624, 0.028956064621784856, 0.05743676118020501, 0.009973374029089297, 0.0031205199983170523, 0.061858427843877246, 0.04363191872835159, 0.017714557836630514, 0.020856025695268596, 0.033754481069211445, 0.015621886289279376, 0.022236527243096913, 0.06347627924489123, 0.026168764901480505, 0.01850611304066011, 0.021755262710420147, 0.030899161605962684, 0.022507081207420145, 0.040755646103726964, 0.05633459978603891, 0.04549122681575162, 0.02542122796044818, 0.046794964000582695, 0.02241558924184314, 0.03548180391745908, 0.0409305351121085, 0.07547314478350536, 0.0625673680167113, 0.05360442592895456, 0.05855882739914315, 0.03706913820600935, 0.05901283518012081, 0.030992416066250632, 0.04399932847757425, 0.026550308535141603, 0.07725984283855983, 0.021541388472542167, 0.1133759141500507, 0.02710542651558561, 0.06013808372829642, 0.09146109223365784, 0.03774132213688322, 0.04030742622645838, 0.05264661607465573, 0.025307927879371812, 0.04654955145503793, 0.03645331339378442, 0.03588245509724532, 0.0430099972789841, 0.013115808800128954, 0.060333664662071636, 0.006686619948595762, 0.0093971162901393, 0.022344509305964624, 0.051564651275319714, 0.048996579434190474, 0.052655562558876615, 0.06728441454470158, 0.013726844003291001, 0.05773481447249651, 0.02468838299890714, 0.03198914329654404, 0.03126703275899802, 0.02049785589666239, 0.07579364401421376, 0.02845364506356418, 0.0440829884526985, 0.036572895012795925, 0.04300406009757093, 0.03258569771423936, 0.04663610538201673, 0.048910843141909154, 0.03687460221616285, 0.005534551455639303, 0.027139551738010984, 0.026802418221320425, 0.06439020484685898, 0.02663296427843826, 0.023306534559066807, 0.04809890813859446, 0.010620201106316276, 0.06790610868483782, 0.041349628873701604, 0.017775503852005516, 0.07078464422374964, 0.027716888347640634, 0.03280107490718365, 0.04625649557315877, 0.03375815872901252, 0.05096887717289584, 0.023549010744318366, 0.04109010958511915, 0.028749236970075538, 0.0305557143209236, 0.012068443349562585, 0.07155659994376556, 0.011588747929116445, 0.045387495774775743, 0.042068753857165575, 0.0168629183566996, 0.04232591184388314, 0.016381546954757402, 0.0026266139341584805, 0.009326049076792384, 0.026769529628966535, 0.08602187409996986, 0.05753520304071052, 0.06959082971193961, 0.025547881610691547, 0.021664847919185246, 0.05171512320105519, 0.02290615818596312, 0.04394547315314412, 0.039062480708318095, 0.07522938107805592, 0.049308949815375466, 0.05554801145834582, 0.023592477697612982, 0.01940601332379239, 0.0026676960489047425, 0.03733473038300872, 0.054371370667857785, 0.03201014056269612, 0.02734664062570248, 0.03333893604576588, 0.03210419908698116, 0.056460800514157326, 0.030527602615100995, 0.023444869189656208, 0.06832143318440233, 0.08538686031741755, 0.026327911897429397, 0.03942798038146325, 0.045903738787663836, 0.027131570469854132, 0.00511654674275113, 0.03630659715937717, 0.01764793587582452, 0.030830463327999626, 0.014828826433845928, 0.017669475969991515, 0.05340050579980016, 0.04024180510480489, 0.06398062075355224, 0.028636121789791753, 0.02138522363800023, 0.027689175281141485, 0.034517324063926935, 0.053817136479275565, 0.047288174142262766, 0.012472426136290389, 0.028572916252804652, 0.03173805819824338, 0.07856180226164204, 0.013188686005638113, 0.043012345010148625, 0.04822253043364201, 0.052359032577701976, 0.0487196489370295, 0.06611054217708962, 0.019251741601952484, 0.0054707339648822585, 0.012666256449717497, 0.016515839212973202, 0.022807224387569085, 0.015530000773391553, 0.017272570303508213, 0.01267612658973251, 0.03553212746711714, 0.030797398316540887, 0.0667345297655889, 0.017074232821219733, 0.016899289530036703, 0.00352681298474116, 0.10329688712954521, 0.04025053106514471, 0.060467661757554324, 0.020181117446294854, 0.046300054128680906, 0.008362390250632805, 0.013632006011903286, 0.14012550163481916, 0.07505020712103162, 0.13236627727746964, 0.1042153589161379, 0.1676557979413441, 0.1560896257204669, 0.1238469308508294, 0.23073526312197956, 0.08382633155477898, 0.17326185426541738, 0.13591116134609493, 0.12493694307548658, 0.1332916769066027, 0.1122795779790197, 0.17377218045294285, 0.16883957013487816, 0.10621964958097253, 0.20988096429833344, 0.10604140521692378, 0.19534716489059584, 0.10187458273555551, 0.12276388039546353, 0.15371077693998814, 0.1302049939653703, 0.12864748468356474, 0.0977928281894752, 0.1418324786105326, 0.15992030873894691, 0.14761439764073916, 0.10158904162900788, 0.14869803163622106, 0.1058448471927217, 0.13078894120241913, 0.09000065417162009, 0.1283295096031257, 0.2670655750802585, 0.11952169079865728, 0.1375785797302212, 0.12643365561962128, 0.06742614015404667, 0.13110606132873467, 0.09505205561539956, 0.12010168896189757, 0.09753602982631751, 0.07317335211804935, 0.12938720999019487, 0.12002083472907543, 0.09345014978732381, 0.07724934590182134, 0.10672313613551003, 0.12720854261091777, 0.1890514048614672, 0.19240761548280716, 0.1350640510874135, 0.21095059333103044, 0.1739852268780981, 0.21401112553264412, 0.09202407952398062, 0.1315976328083447, 0.1640515691999878, 0.08362976674522672, 0.1389312528605972, 0.1189923384892089, 0.08359899518213101, 0.1382802663637059, 0.10994556679257325, 0.13609775847622327, 0.11834247836044856, 0.10029848159423896, 0.16661502021764005, 0.14191299357584544, 0.1162230335175991, 0.1287438366562128, 0.15006416690136704, 0.16008744548474038, 0.1078958482082401, 0.12927203545612947, 0.09540866647980042, 0.1229572764464787, 0.12508001896951879, 0.08224942295679025, 0.09820416968848024, 0.09160639372255121, 0.17102449360702718, 0.12181862683168479, 0.1613740021628993, 0.13999273947307042, 0.11211176269820758, 0.0954101863982422, 0.1318958896611418, 0.24074897436158998, 0.1875300614961556, 0.10453408717044763, 0.14884549086647375, 0.13371452635952405, 0.13766697927245072, 0.11786130203732423, 0.08899717551789113, 0.07846637309661933, 0.09475882670709065, 0.13269676454365253, 0.13916249759495258, 0.19003587774932384, 0.10941702872514725, 0.10192849234278713, 0.11050235227282558, 0.102700882325215, 0.11079042431499277, 0.27699205385787146, 0.1426590835409505, 0.1364562285265752, 0.10904016359043972, 0.13189863094261714, 0.060416744489754946, 0.11226771040154354, 0.094877529623253, 0.1725719469998564, 0.1276010208364044, 0.12053122877010278, 0.1288648330207382, 0.08454491371022803, 0.1582832887236561, 0.150699058547616, 0.16381739319435187, 0.21452941772128853, 0.1296514179557562, 0.1259150377341679, 0.11749326464320932, 0.13039604228522095, 0.23971963673830032, 0.13073917744415148, 0.19872617428856237, 0.08280633735869612, 0.08358523449195282, 0.0796718651961003, 0.07683372963219881, 0.13661932120365755, 0.1824632098100015, 0.11249472786273275, 0.10550637356936932, 0.11403110756405763, 0.06399886656020369, 0.145756867315088, 0.09389608978692975, 0.10156455330018486, 0.06717523147485085, 0.10754383102591548, 0.06873327001397099, 0.17081211214619024, 0.056794632957982163, 0.09883317843611751, 0.08466225955635309, 0.15315036129738602, 0.1573541300105197, 0.13310168710138115, 0.16486769754971775, 0.08783806128693478, 0.1145430893770286, 0.09377746829496962, 0.1201834117195436, 0.1541151295283011, 0.1664186521832432, 0.18328521427299294, 0.12939981717084134, 0.10627058720482246, 0.13469457519905909, 0.15396378907774175, 0.06864294343228851, 0.09023115251745496, 0.3173143230378628, 0.1551484162253993, 0.09813212962555033, 0.11137804921184268, 0.1766954721616847, 0.09416874551347323, 0.04925258730405143], [0.041495734426592074, 0.021364762414512888, 0.0551301797718874, 0.03767713950946927, 0.0251207014080137, 0.08214531532887902, 0.045663978438824415, 0.03458503846611295, 0.013964399113319814, 0.02949139821742262, 0.030266295386744396, 0.03899835914905582, 0.017935163141893487, 0.01573252651308264, 0.01476367180501776, 0.04735741864091583, 0.014044772434447492, 0.06645640504679509, 0.027661097502069812, 0.06292830114918095, 0.03398755445544209, 0.035878451740635295, 0.011499835244779075, 0.03691420491252627, 0.024190148305413977, 0.010570565421533371, 0.07282386587134429, 0.027196998209027306, 0.04834712642644133, 0.04267799687970962, 0.020948681348402585, 0.05288738065532275, 0.011583743733353913, 0.025718076853081584, 0.03731953798394118, 0.03273279392825706, 0.021619852565761124, 0.014003258813837809, 0.04207514565704124, 0.041424111662698646, 0.009334739414043725, 0.02975167067987578, 0.03717949174876724, 0.008094747201539576, 0.032069264711546044, 0.025691554615540162, 0.023528237394722443, 0.031789833812841346, 0.03680784794102822, 0.049769020306744745, 0.0586749247408339, 0.03178469051739999, 0.025946595572999546, 0.042190276086330414, 0.03092680512262242, 0.03355818088831646, 0.035930515732616186, 0.04762383184528776, 0.034576417678701024, 0.07178679973419223, 0.018121017276176384, 0.0864094193758709, 0.04099090098004256, 0.031929839335914166, 0.03310089578319873, 0.008285770924495799, 0.07373249211481639, 0.04964350829167025, 0.01640296321628349, 0.02264804007219417, 0.02064847879643951, 0.018706572641219412, 0.04609384394383856, 0.02390300585622234, 0.020192616918523396, 0.0032890600393459734, 0.049218772511397085, 0.0436938655828791, 0.051753338293305466, 0.0063923762063495815, 0.03946352543841515, 0.022319766526509608, 0.02882372654442276, 0.012821463701714362, 0.003383935774244102, 0.03695989067533186, 0.06442312058061361, 0.05080002373350518, 0.08090631717017718, 0.03582432160952261, 0.08019057129110609, 0.02991929597088269, 0.022528336316879307, 0.018417140136339834, 0.02440417182099606, 0.012778002685601158, 0.09172516449221543, 0.05168797162228397, 0.020017166422413926, 0.03699925249176366, 0.04423637807901416, 0.015141444480312722, 0.01461214984634093, 0.02773812140471169, 0.011389434204569884, 0.07450939435511827, 0.11270832390125309, 0.044633433023201566, 0.02106971333601645, 0.02936609315552882, 0.025113354570099285, 0.023277647626985396, 0.013198590920572835, 0.04544432647526264, 0.07154522769685302, 0.009577951809790517, 0.05049589416012168, 0.019163336970710328, 0.04961596316258822, 0.014645294585664357, 0.06533916321183954, 0.10468098321663481, 0.06305518719766821, 0.0331927829954241, 0.04546307779050299, 0.021267560576753955, 0.013490815597054149, 0.04504695940496666, 0.03193541689376746, 0.05312375172174402, 0.04299216877136912, 0.03512650941099439, 0.058334286590772014, 0.033763017039746046, 0.019347861176356673, 0.018927373025300245, 0.011746549729390867, 0.016995539722431983, 0.017628684141007916, 0.012820099846326878, 0.036142585067344565, 0.008597451744468083, 0.04291192861273885, 0.05030786532110401, 0.012655801073248898, 0.010587365948595107, 0.02611764576951308, 0.03565499658829399, 0.03856599324249795, 0.022761594603902528, 0.008012481615878642, 0.045826433292989216, 0.00914313639181533, 0.09916483278253249, 0.06754273282630102, 0.05481162115133234, 0.010023889264890125, 0.04834726552612015, 0.11480693093367986, 0.042722976966095824, 0.03245236897575004, 0.06744918320327997, 0.0451210384656276, 0.0731290437813316, 0.03272135043516755, 0.013550955003925731, 0.011744409799575806, 0.017817293127466525, 0.051883257393326075, 0.027475672541186213, 0.0648215359875134, 0.007292403290713472, 0.027061715289684277, 0.04949296172708273, 0.017377387000513927, 0.04987287348402398, 0.04792246189234512, 0.021687234485788003, 0.005691650124000651, 0.026611239283478687, 0.014281319919973612, 0.04761397951681699, 0.029311847673462968, 0.012482168202820634, 0.02748849685303867, 0.02539298733297203, 0.057412978527801375, 0.015547230473852583, 0.018714574265426824, 0.015330380859917827, 0.0028997344571897493, 0.011740161322190293, 0.016130948705332618, 0.05397537423829947, 0.009891082998365164, 0.00998442227553044, 0.037257255254579444, 0.04929138593641775, 0.03227974966700588, 0.01721848936618439, 0.016295159268858175, 0.04226307271580611, 0.022610756269256984, 0.05019460764846631, 0.005140029567493392, 0.05488413958145039, 0.02587184645900769, 0.02564372298573809, 0.03916985887501921, 0.02696515297118042, 0.05286510095798543, 0.044561389567596574, 0.021207254080634032, 0.028952159652752534, 0.06100947875529528, 0.024112454349441186, 0.018227879756263325, 0.014695083788995231, 0.06139124969818762, 0.013426254686367298, 0.05940068579678025, 0.04741024259211762, 0.005753874753801418, 0.02622366008082671, 0.05881284376872437, 0.05497076475460615, 0.03999990737065673, 0.06533038296869823, 0.028411224750535827, 0.0316543066208916, 0.03033710051594036, 0.05152699936713491, 0.015934280419190015, 0.00965523355573948, 0.01800515572540462, 0.036956362293234894, 0.03126699883224709, 0.016830453848732368, 0.044605931998895745, 0.043349719406770806, 0.06344779434480838, 0.017079542357740656, 0.03066843595089657, 0.07994899246841669, 0.020701262035540173, 0.011416178662329912, 0.03542579424434474, 0.03824254238445844, 0.022439763748220036, 0.03477718601269381, 0.011036871649724032, 0.11063586082309484, 0.028608183110398904, 0.011773275527437883, 0.010278038796968758, 0.03969531300078545, 0.019879199897072146, 0.01996212196536362, 0.03381472819351724, 0.045618608194802485, 0.01686077248970313, 0.015951515208663683, 0.01874093195822622, 0.011632330233364232, 0.03711967888687338, 0.026255434179412465, 0.03494427865371108, 0.023490738156916838, 0.020882424100169113, 0.08739356656691857, 0.027794409277183667, 0.03716647405443447, 0.01611633475736848, 0.024397384774472033, 0.027658732807529823, 0.006731932093056717, 0.023584067256056836, 0.028665685560554266, 0.014736957881333572, 0.01432567066513002, 0.01637782179750502, 0.03865418583154678, 0.03784408626545753, 0.05703210325113364, 0.06990107627851622, 0.12268059700727463, 0.027931821100147705, 0.0037071544460819234, 0.010491080133111348, 0.029632034778062786, 0.00669040617399982, 0.046945256114538224, 0.03759383237255471, 0.026057115356837, 0.0588790484304939, 0.026369304229904498, 0.05740907695144415, 0.02365039405412972, 0.03956054916073169, 0.013847680063918233, 0.023507536987641027, 0.09737876576504537, 0.012944097031972237, 0.04072437242471746, 0.026306297164410353, 0.041035307704338005, 0.05341919604688883, 0.018049469151135002, 0.008388161010641073, 0.0348242831283382, 0.010319275066389568, 0.04803549564842667, 0.028394298694495643, 0.03709136362054518, 0.024876023376626626, 0.00700874681518014, 0.01652997818642429, 0.04350492411426135, 0.04347255799387183, 0.04911920767543571, 0.0573058853458081, 0.030479229853621552, 0.07679961289146117, 0.03329006456104772, 0.03290651585640652, 0.027450354703302895, 0.02628090638401253, 0.0844558152769293, 0.056136369173015864, 0.046217347495257854, 0.04372121054413063, 0.0391098220965692, 0.014253783272579312, 0.013719168924061316, 0.006395572106287415, 0.03513592069170304, 0.021266837936959097, 0.02247391950472125, 0.04647805422012295, 0.09490103407629899, 0.03432369731100542, 0.009064768141667758, 0.054457870312035084, 0.0243294006546161, 0.029862512767847096, 0.043221683241426945, 0.02056842014592673, 0.047000875630016835, 0.013106289801986089, 0.009080639923922718, 0.03607744909822941, 0.047180958823966127, 0.08422212781650679, 0.10597199786986623, 0.11475874137665544, 0.08581350278109312, 0.12745576005961212, 0.1549642618213381, 0.1262168093983616, 0.22182001865335874, 0.10134451117898736, 0.10300720017403364, 0.13344099532280648, 0.07621732806520802, 0.17530724379633153, 0.12995613446193083, 0.08545157220214605, 0.17542878298887185, 0.22229227902633802, 0.14067567139863968, 0.16287935924317154, 0.10519784369638988, 0.11604970853243556, 0.12234887480735779, 0.08402957993426494, 0.15541118569672108, 0.1715677830257586, 0.12212905660271645, 0.13536690840763704, 0.11085052216159445, 0.0989652213507465, 0.09738539505217757, 0.08216214978269168, 0.15231317122067722, 0.08427221048623323, 0.09518698908920799, 0.09819998991276536, 0.18608448335102626, 0.08505079549338136, 0.14005572109350137, 0.15002209773021086, 0.0934478495536106, 0.13801582769623824, 0.07988222462258168, 0.1286283228546381, 0.1108550683462194, 0.11961815133690834, 0.08525654088173594, 0.07285617092358214, 0.12512382519032272, 0.07542286533862352, 0.13217273194875034, 0.14458429094936165, 0.1269970161042043, 0.08107492633696113, 0.13969217560120992, 0.0884929968576346, 0.13732336913900717, 0.09012846302773271, 0.08749333835606064, 0.09533047888960157, 0.16185456780450685, 0.10915889364800282, 0.1879038800086294, 0.13227368438882486, 0.07665471852357898, 0.12079063270773206, 0.11454885692468711, 0.12582192915890897, 0.15901476304445947, 0.065430399030447, 0.14482468233576842, 0.1264172215014696, 0.12239657581916877, 0.10342982571039881, 0.05644788799275245, 0.09092632521476064, 0.2189096055392708, 0.1463822459003755, 0.07919832239193575, 0.14041581962789806, 0.11954716300325734, 0.13549836778215, 0.10086687680866037, 0.13413348102143832, 0.09530354783471141, 0.108578257661845, 0.15478862981711114, 0.15133450659258024, 0.11516765372029372, 0.1327673593269927, 0.09818300618124859, 0.21177707612514496, 0.18840313250465052, 0.08524142990687064, 0.2186072910470622, 0.14994519257119723, 0.06384138536772557, 0.15488232193248613, 0.08305742924234696, 0.08830955491534301, 0.14882684472416127, 0.09788440327559199, 0.1326230756406273, 0.0902760104675378, 0.15121550512100967, 0.053607499692589045, 0.11552191685353007, 0.31944747428808895, 0.09960078474666391, 0.19022448334310735, 0.16694721739206994, 0.16208974804197038, 0.16160948095577105, 0.10332547380988087, 0.20468348105038914, 0.1907640408192362, 0.1634986310132912, 0.22922267285840853, 0.09176125576985733, 0.1421178432979754, 0.12224115058779716, 0.20097943980778965, 0.18218100709574564, 0.11780301587922232, 0.10624538641422987, 0.10579747187771968, 0.14493778055267675, 0.10799967085144349, 0.17180531099438667, 0.07419469659881932, 0.1444137750991753, 0.1598903989153249, 0.1658149595771517, 0.19882125061537537, 0.24833027326634952, 0.0962341179006866, 0.08578328083136252, 0.150413503870368, 0.10858824569731951, 0.19651964626141957, 0.06724015370543514, 0.12389252840408257, 0.11392339691519737, 0.19159610117120401, 0.11817163681345326, 0.14383354623402866, 0.07308937662414142, 0.14166869382773126, 0.09893033108008759, 0.06492640357464552, 0.1479210276156664, 0.10066928741122995, 0.11422024241515569, 0.15369871258735657, 0.11790741527719156, 0.20395469372825964, 0.17404138243624143, 0.08166943157890014, 0.10581018083861896, 0.19043132795819215, 0.09651408144938094, 0.161810001624482, 0.0715981534283076, 0.11543701855199677, 0.23978708311915398, 0.21287601787064755, 0.12304931293640818, 0.1601866880165679, 0.09541766385414771, 0.11066271045378276, 0.11108384321310691, 0.20591010951570102, 0.1342656867844718, 0.09848950723452227, 0.13636569838438714, 0.08113366032817534, 0.1340069749525615], [0.10665979489151921, 0.03227381927094289, 0.04873846471309662, 0.026127450600532547, 0.016380622450794493, 0.030273609994245426, 0.024032614526471922, 0.038745197733598094, 0.027778923411720564, 0.10300807548420769, 0.014209801480839295, 0.01824988973593073, 0.014750828833452292, 0.0133438958021413, 0.03684231412730046, 0.019354505730526786, 0.04853945378480213, 0.007317538772310529, 0.05386131589433976, 0.02754802642656224, 0.04852194079597082, 0.01395780629744487, 0.060600729260061464, 0.053606414036559205, 0.12358733692339488, 0.0042210488796367174, 0.02572617007951651, 0.04366943832220776, 0.06292437243142299, 0.028067762198458825, 0.06461064730371747, 0.04720925373424377, 0.07639069376247269, 0.05177366720246417, 0.039984094112047126, 0.01436254904339356, 0.017872899072244763, 0.0520571964526815, 0.023525575841111795, 0.007975124870426953, 0.031343954881387096, 0.030365524347871542, 0.024561200091349225, 0.031952834887696166, 0.05208785945017423, 0.028774078137108257, 0.012650566175580025, 0.06995920637356383, 0.06381668669304677, 0.02778271472613726, 0.02022450297538723, 0.017392972949892282, 0.06742117327771016, 0.05644580149757011, 0.08684521527694804, 0.022672960967091576, 0.03493181396541851, 0.021113180289311067, 0.0391383850281792, 0.03569257046495165, 0.021373907370226722, 0.05171192730111735, 0.07021963489907128, 0.02689249035237091, 0.04114448059616344, 0.006208374896751983, 0.008941589438888644, 0.026201046204992702, 0.048553010914474726, 0.018834618984588554, 0.03808263882196375, 0.021631503012031317, 0.02940804019038166, 0.007804780350332814, 0.009033220504144472, 0.01776423677802086, 0.027728935736896734, 0.017860885609739592, 0.046313546797526736, 0.012310847440468413, 0.08101731871387788, 0.027727023964481692, 0.022331552679783533, 0.06023204047232866, 0.06609470516975437, 0.02557181184446173, 0.02713885284694178, 0.0607721068497215, 0.0636632020718285, 0.014089023095688649, 0.03685271946181144, 0.04913970621834908, 0.0342237016053072, 0.029252218016024147, 0.0339460790024272, 0.04747877123632601, 0.05120893607714346, 0.04397267562204173, 0.040025644203914065, 0.025717316893860698, 0.017697126272001436, 0.009233417172384049, 0.03200890562896218, 0.0257438968068787, 0.019362634580050195, 0.01426429717269327, 0.037964946922979186, 0.04923240767259683, 0.02377527842431196, 0.04927973888282265, 0.022573996634621705, 0.01820269592904619, 0.02686616319364735, 0.021005746143470918, 0.061263447627425194, 0.04117059401635613, 0.014912316775215524, 0.028311478406456963, 0.03053853042157633, 0.032075042437229834, 0.018918869285179035, 0.05467434333903449, 0.01660929893010429, 0.053889987391552756, 0.030895687506667206, 0.04093509486743382, 0.04928078382675137, 0.03635363320686987, 0.01916782039084605, 0.04451926950631397, 0.06464079461459603, 0.02765716878431184, 0.03428872900881937, 0.03996176352458341, 0.05974232139331954, 0.04222044036058443, 0.05352566158398986, 0.030872803913163285, 0.027260656668139354, 0.021766928423728262, 0.025963686173781753, 0.02047813088367028, 0.05434286880439945, 0.01537607001539852, 0.03177027164825371, 0.042026810214987824, 0.030653121415525675, 0.008797778182529976, 0.05231994556795273, 0.0455257235360997, 0.066715903979327, 0.05175031881247248, 0.003344029645502035, 0.03474594286776014, 0.03638073389551469, 0.0322784333090697, 0.037469568861914535, 0.024272804048710635, 0.027186114507328187, 0.041153705279741964, 0.019730990885623863, 0.04563676579190152, 0.031026943320674554, 0.04523513752168842, 0.11898971934403692, 0.05990620795637369, 0.058331273895289214, 0.02050345720324133, 0.054510779080114195, 0.007839448400773108, 0.015133989076795322, 0.017963687057739923, 0.02872271982154676, 0.0385349434800446, 0.033662105311772654, 0.06710645516536065, 0.13577838561364583, 0.02483606444937842, 0.04502453382260033, 0.03937041007780603, 0.05673779207946999, 0.033311747147568634, 0.028778461473328725, 0.021325103739010434, 0.03026146421741162, 0.04683952678793243, 0.037809935597968955, 0.007469078542531601, 0.08420674542763404, 0.08997894105102335, 0.018788064696959088, 0.015315749948578221, 0.0036572342006755726, 0.02441934895302568, 0.0408782268475209, 0.056915636107857735, 0.0028269978356547654, 0.026416184214342917, 0.010198662074149718, 0.008349128283693321, 0.024320908788857714, 0.028313525885875736, 0.038775389149252854, 0.019270335157800998, 0.020673499775252173, 0.07740674567009721, 0.03949444288653987, 0.04213080249194588, 0.07699878327548504, 0.03092471184208989, 0.04109336994588375, 0.0789742429873773, 0.05063601503414767, 0.010390906311970736, 0.04359148143391524, 0.05278982428301658, 0.014256326082561697, 0.0388055907429329, 0.08928218058177403, 0.01288489400342639, 0.018133853462391665, 0.012393990880809724, 0.007197478786110878, 0.04684675318588104, 0.014719490693616015, 0.06153367419860192, 0.03171797695436648, 0.0396804802252778, 0.04361676364871008, 0.0727893216535449, 0.010919497814029455, 0.033190224918403795, 0.0363873563972967, 0.037594945169985294, 0.03709408115329487, 0.05710655211337975, 0.027951432458524193, 0.04407658986747265, 0.0491113807739956, 0.02795010931523783, 0.04890116383986814, 0.048545621668121645, 0.0416696768786226, 0.02975415751071913, 0.09314755709575755, 0.011695294890419712, 0.026319830545357296, 0.002049547466283132, 0.07125860771962575, 0.0163917639958007, 0.015997557202354074, 0.02741308107839099, 0.0718371198911752, 0.030081859390650476, 0.02951002400368452, 0.03585252491757274, 0.09705829367573772, 0.01156473796748157, 0.04489051976374217, 0.04608509423477309, 0.06107015335666282, 0.043679453499083004, 0.011653964474265064, 0.11992537842265197, 0.026823508786037564, 0.02507456611575825, 0.009296534499818725, 0.015037314800013388, 0.025478265614115765, 0.019957616492839794, 0.058112900970237594, 0.025972602123926793, 0.027581985407908047, 0.045155467332473824, 0.023806496124182428, 0.02053576904082937, 0.04575662221759558, 0.027241805268983756, 0.03734956994386656, 0.03934605745598674, 0.016716600761615803, 0.0660060817109687, 0.01974350816038038, 0.01697860348836652, 0.05060129100456834, 0.055965873678880076, 0.07062216222818408, 0.04024426818692258, 0.01409865405210959, 0.03049936198762485, 0.05356257728167942, 0.06217612472495862, 0.01997641021651881, 0.03894556233925479, 0.04302318799974663, 0.030791559522705417, 0.02979439463732498, 0.056138262285717895, 0.07241223938763142, 0.03806221152522734, 0.03757760181490864, 0.028516221259321486, 0.02863317694781082, 0.013339271585989212, 0.03725145717284509, 0.08894114888140134, 0.009596248506568372, 0.05636495405009814, 0.02894968639260956, 0.02697126826803599, 0.06202021773372378, 0.016050962997334342, 0.06904836132058076, 0.04248769834105458, 0.03406475138451372, 0.03796959149518183, 0.019619458388271074, 0.07576982064970902, 0.011270576921690787, 0.03204481370214905, 0.019963236459131752, 0.10840544836329562, 0.06092619536710637, 0.02630193418424044, 0.06123399242226567, 0.04665223076673491, 0.034455848791237385, 0.035520066507160664, 0.009297859339442636, 0.017078181895028268, 0.07469355554452964, 0.061929565455232344, 0.06643093962754522, 0.015473773969071252, 0.007989503027472113, 0.015470338885539343, 0.07940381672233343, 0.10101154047463622, 0.03305707259901932, 0.017414261986102377, 0.09065621399453708, 0.04040943718116198, 0.018652858112805655, 0.02377049814510558, 0.029068124680114642, 0.028887593653053045, 0.005840663623530418, 0.04449805510895593, 0.05892202683857509, 0.014505097376448768, 0.03867178363725543, 0.04039439745247364, 0.28113898847784313, 0.09961519683046, 0.11468942223915032, 0.17777612060308456, 0.11082333326339722, 0.10174214627061572, 0.09041484551770346, 0.19511798290269716, 0.09126116867576327, 0.13292853853532247, 0.1659756638109684, 0.06603702969316926, 0.132857387353267, 0.16337235564632074, 0.17244861647486687, 0.08884568578962769, 0.13308523941252912, 0.0736008563211986, 0.12803008567009652, 0.16164598613977432, 0.11692033681486334, 0.08121357818267175, 0.13783146973167146, 0.12366861184792859, 0.176223523914814, 0.10504530902419772, 0.10094836207904986, 0.15218385601682322, 0.1357241299535547, 0.10531889434371676, 0.1323824535523142, 0.10557316855660506, 0.12593273392745427, 0.09079081498618637, 0.14047968334385327, 0.10879598597862891, 0.15008278590227875, 0.0763727193698287, 0.14880450735134737, 0.10212331331734147, 0.09626812607582126, 0.18926526552864484, 0.12540137315435068, 0.14014595268028124, 0.14865731953510217, 0.16820185578295163, 0.10808395847146, 0.14650936265076908, 0.128791836223432, 0.1473079983677183, 0.11227146270019667, 0.16578139923512936, 0.09768203699163028, 0.10722824438874211, 0.18233427458575793, 0.08837704879364797, 0.0898561669247491, 0.08494390587189368, 0.14463424469743455, 0.18860944786242076, 0.0789489879139832, 0.16351919062435627, 0.15118121196116718, 0.06611970239984137, 0.12748211435973644, 0.14242334690477165, 0.22756936800267014, 0.09871288774801151, 0.17741846479475498, 0.17057253500180586, 0.17936158552765846, 0.11760679712252957, 0.1014052332778062, 0.16262518002518586, 0.07669168511139494, 0.06328495951103312, 0.24532797294003622, 0.06382975527750594, 0.11006932479462453, 0.16634406761399337, 0.13705764125500405, 0.11283374431410007, 0.1271532012947968, 0.13674562371202878, 0.1649089524788516, 0.1330294774046966, 0.11505140710089888, 0.21622684092393943, 0.17424525506794453, 0.09885118675551244, 0.08114183667515006, 0.13349573952811106, 0.0887104809018118, 0.17517270387283393, 0.1195120420306921, 0.07539978836263929, 0.13753238506615162, 0.2283989042043686, 0.11255939903536014, 0.10807134450546332, 0.13242985600871698, 0.08363940194249153, 0.1372189833117383, 0.09042894547539097, 0.0644120808158602, 0.12344905148659434, 0.13913277776113578, 0.12252977224332945, 0.15507391308035168, 0.11777921287076813, 0.09480027841137988, 0.11604630228664194, 0.11005535375859056, 0.08192615530320577, 0.1472864616662264, 0.16045545573745454, 0.1580320272062506, 0.2534399133707796, 0.14122292346188, 0.12465678953698703, 0.1255934392767293, 0.1998194841934102, 0.13060904799827508, 0.21631015145352908, 0.14975375070103578, 0.12460440663354737, 0.19002860385392392, 0.09687598488692727, 0.1538791621902159, 0.17556457141680376, 0.1584219948521682, 0.12005119238580976, 0.09191938835595335, 0.16678993297474726, 0.29402151863489834, 0.07304197416773864, 0.14859201732490743, 0.13115262240171432, 0.13691134910498345, 0.1812827895794596, 0.08012083824723959, 0.26196747007114546, 0.09517351338373763, 0.1140233858355454, 0.14388710978840077, 0.21779356471129827, 0.18804084908749374, 0.15465330279299191, 0.1607911405818803, 0.11000228553478207, 0.12812250213963644, 0.1114467101703797, 0.08739597536623478, 0.10788430632757288, 0.12981308570929936, 0.17258456775120326, 0.10951557236590556, 0.0965592854523233, 0.08695319055446557, 0.20406899973750114, 0.2763720356992313, 0.24893017964703695, 0.15987073497048446, 0.12101157728050436, 0.19499321388346808, 0.15421536272125586, 0.14618974551558495, 0.1275503071291106, 0.07932767830789089, 0.0908279987052083, 0.07015042432716914, 0.11346508722220149, 0.1521246741924967, 0.15076925978064537, 0.13069295563868114, 0.12256105270768915], [0.0755521534010768, 0.04273329409105437, 0.03985883654760463, 0.012573797571738916, 0.046797861345112324, 0.05853286664932966, 0.056784923121865304, 0.08183292459164347, 0.031936254884515486, 0.03947538283786603, 0.030452047740774493, 0.032961355056613684, 0.08762750508529799, 0.055814808035003285, 0.04742113307916692, 0.032927289206002436, 0.06744883715042047, 0.011952306143939495, 0.016358894063159823, 0.032342283454324515, 0.011811057205445, 0.026073871779122522, 0.022966032116008655, 0.07628897457782711, 0.03975276116813932, 0.02941642688321216, 0.029806055261620452, 0.028182003746873567, 0.027292289970708743, 0.009630178650175887, 0.043242300527968576, 0.0385321343450674, 0.013425449774201428, 0.021428054464714866, 0.052923980834228654, 0.06345327012240887, 0.026659859710239937, 0.050979024664099724, 0.0316516467636185, 0.028581309730985334, 0.011770399387127586, 0.007019980810582638, 0.0387861100025475, 0.022465461565713798, 0.011757048362466906, 0.03740324206384165, 0.048923172123197994, 0.057853938080370426, 0.04084507701918483, 0.015068590175360441, 0.019919956102967262, 0.021721875394827554, 0.06025287149740117, 0.013513821326861424, 0.03621216883350696, 0.029546271344380717, 0.02306594300482954, 0.04000741196796298, 0.02485731107714985, 0.03639379230194858, 0.021237374250111834, 0.028548044551696097, 0.11792661781821932, 0.01388469584552305, 0.013171638661463345, 0.015697973813595514, 0.04057282502097743, 0.032647386725459776, 0.027456015381695967, 0.011128665563384337, 0.016662112703280788, 0.04135124378704599, 0.03737771896911519, 0.010233288564320122, 0.06104901020548173, 0.037136611728263755, 0.03693334977807743, 0.026382669673434327, 0.06475989108106919, 0.04672859988308378, 0.02452622670015054, 0.025682623398357203, 0.00780627821638648, 0.058129613287746906, 0.044926614434059174, 0.07778300690863814, 0.07866061731640782, 0.02751795545087329, 0.07477879311357226, 0.055232743732631207, 0.03123175572337849, 0.04603063840685146, 0.052272488828748465, 0.06671135779470205, 0.05106218591598528, 0.058728481509855816, 0.04773461625778249, 0.03320646904675024, 0.01343602643880461, 0.009047133016533085, 0.021904710048277463, 0.032026411832443306, 0.0486277244053781, 0.012786522540929062, 0.03267835845638599, 0.012963810170601522, 0.037436079766069136, 0.03050905146769115, 0.036514578320618184, 0.04176910261490515, 0.01129217299499682, 0.05510398153481739, 0.041508887827928574, 0.062475867569446564, 0.020436504456613745, 0.023431250991831933, 0.012294296275026031, 0.050174098927527666, 0.08279611862131528, 0.016368963522836566, 0.013744153431616724, 0.003623312114671405, 0.037090909002082686, 0.033970967666911225, 0.03606562562552946, 0.03223756514489651, 0.02435411968534546, 0.032679413578339984, 0.016291359472753744, 0.02338897486749504, 0.0743803573506219, 0.04406643559091857, 0.06161416880786419, 0.03381204119484339, 0.0390609234704503, 0.04043453958417688, 0.03352443394916398, 0.016906397184357047, 0.0204879594634154, 0.02759188862650522, 0.07214226387441158, 0.01565996906720102, 0.05806869441377265, 0.03313388954848051, 0.02767689379730395, 0.018045425082423856, 0.024943778490913764, 0.027602811343967915, 0.051769178693315814, 0.030000896592225348, 0.016253610873328786, 0.09641597885638475, 0.06632851476648025, 0.04989762983417936, 0.02619498858361372, 0.01693495672329196, 0.013689580556404377, 0.044913199796740494, 0.042673664433615546, 0.045344093282307894, 0.0243741330757205, 0.05830945220908948, 0.06568953155406884, 0.02143430377223662, 0.05643543687516025, 0.03469392637323056, 0.0020329755207058042, 0.03288495879886406, 0.026767733207504665, 0.009791895597507911, 0.022640469317723597, 0.08828599617949554, 0.025395385954262953, 0.018593893419685106, 0.004009173775557429, 0.02205986895465425, 0.048802721979362626, 0.010112672179405178, 0.048103688417800834, 0.03394087463883417, 0.025219128001481295, 0.10835881943681411, 0.04056822794622608, 0.028107217313455682, 0.031375832456563196, 0.028469595725515058, 0.03971446125901171, 0.08563808112272195, 0.035156208888760636, 0.035795147996395826, 0.04748352437413164, 0.0319715895956116, 0.10344439385724918, 0.01227341266348958, 0.029215454988713776, 0.04214967594348958, 0.013777037783126746, 0.01575240589279149, 0.12344305323702948, 0.0655745334391083, 0.028187486309824244, 0.007153478334657848, 0.016420308267697692, 0.016361949167081287, 0.01698278496041894, 0.018912650511733124, 0.014496108483789223, 0.03723677367504154, 0.051338906067290475, 0.0007108661520760506, 0.024561542751533643, 0.07502806652337313, 0.012476643231431288, 0.028485358093998263, 0.03333136020228267, 0.09859218993889433, 0.037550850571798425, 0.018657843648855175, 0.01843527568105076, 0.027054568619600365, 0.04581613313140614, 0.037138654118669887, 0.033448183576443365, 0.01714849508633571, 0.044810795291726074, 0.023207855211304765, 0.029098668933979104, 0.03251617501622864, 0.028563362479742085, 0.0014633701814870748, 0.01937750806765897, 0.023358330529715334, 0.023942282855776802, 0.04954002152330109, 0.04127877624705434, 0.020940170822931186, 0.004531896373789225, 0.011279992443243307, 0.05016551885221686, 0.018493507556351166, 0.052969038952142, 0.006806316918560437, 0.05309890037668603, 0.03554986437250461, 0.05121453059837222, 0.018763958044084053, 0.013222603426714028, 0.022722904537139193, 0.020631690143740604, 0.011861745467675584, 0.02312712141844843, 0.017064070062977926, 0.050049146703843556, 0.027931351214647293, 0.012259126956840711, 0.011497797943385584, 0.05681277019903064, 0.027684389912922467, 0.012645697686821222, 0.012178496640574719, 0.02319017089238124, 0.030434582249394486, 0.006907366473959493, 0.014409993908235004, 0.03876323997974396, 0.03909713349172047, 0.036769978901637454, 0.029483415252928222, 0.06015819550624915, 0.035366944902177365, 0.007332787150517106, 0.0302844156644174, 0.03800287024517145, 0.05018044662262712, 0.0296801225548344, 0.031851115703050575, 0.028148068514253412, 0.04289606785667794, 0.044889274651982954, 0.027191264588119726, 0.016078279120847583, 0.033474073080079894, 0.04132938817409532, 0.04243365302681923, 0.05470766619380031, 0.031846067402511835, 0.05674263681950314, 0.014665251996900355, 0.03009769639798573, 0.03515251426558409, 0.01051248367210584, 0.035592337271996906, 0.05539159556584699, 0.013018863957508333, 0.054228216742298434, 0.03806784336588212, 0.040913293537284644, 0.013508777267166545, 0.015558797799582993, 0.023973412346094847, 0.045629820985985656, 0.02415153627017779, 0.03793073179466384, 0.1416722900633301, 0.04821576204683099, 0.015172897971102169, 0.043401033617556095, 0.020689484363953983, 0.03498725706179227, 0.0721630881141339, 0.015023886591994336, 0.028735988573836427, 0.018070854878585254, 0.0913613543712667, 0.025347983497860174, 0.06978354722793613, 0.02672151818738452, 0.028937455798898424, 0.01066868073706116, 0.03032589451010738, 0.014501248386555483, 0.05648584184902055, 0.0554449555597135, 0.07817743931497846, 0.00876198970114014, 0.02490496289517198, 0.010881500701153917, 0.09520561487546988, 0.017232843774503896, 0.030347997788339853, 0.051532980653324297, 0.018779026610510688, 0.06985733791121415, 0.046377932985446284, 0.030306905707610503, 0.014773218792730143, 0.04603136443932142, 0.021453674250681485, 0.032918386826557774, 0.020949658438829438, 0.050533383219902, 0.0825128573924303, 0.0009431224337147016, 0.024783349063779627, 0.012963007802941968, 0.03754739682855351, 0.05406601973144071, 0.037729206894125254, 0.035758890477674346, 0.04488556645810604, 0.019510332993896942, 0.09110936682139124, 0.2215857476528202, 0.07464609201997519, 0.10376114757465464, 0.08141137792595796, 0.12810492808265345, 0.15330837853252888, 0.12821824343076774, 0.2002070362546614, 0.07397718541324139, 0.12609451024660043, 0.1371571687715394, 0.1058469642219799, 0.25628777912684847, 0.19888101597981794, 0.21148450539580413, 0.12877397718174116, 0.11572850362530776, 0.09752441330679826, 0.05403298864673291, 0.16395485081842967, 0.09260934990431581, 0.12489741162530013, 0.28076356862272533, 0.2786605443273272, 0.15267724597028323, 0.13326103426516056, 0.09008899264569793, 0.12698415108025074, 0.06878933057721172, 0.06659950808222805, 0.07754550608141081, 0.18377990701368876, 0.19871090725064278, 0.20539659421358789, 0.13934739838753427, 0.22418461819844587, 0.10804508520024163, 0.14346563097621712, 0.11866859586111136, 0.2434164583683014, 0.0973615309755717, 0.09426788626504795, 0.16022664015846594, 0.08381873874792031, 0.1398866708789553, 0.18755450232752732, 0.08850077286894832, 0.09966719296893903, 0.09087588292147432, 0.10114917451781885, 0.15864855769489491, 0.10191897928182568, 0.18200145315911087, 0.08573890464114291, 0.09390793700835534, 0.08072748248066221, 0.08939050191215106, 0.17819907862160886, 0.17063448524900846, 0.13347374142280646, 0.10743411869875022, 0.14902060718408652, 0.1516581949378763, 0.13901532334940775, 0.0878135526020612, 0.07115125669432537, 0.19148871621915273, 0.08811875765344926, 0.07599477536444153, 0.1144514192960092, 0.08244214725813695, 0.11262304562010936, 0.1367308045072215, 0.11342200024851731, 0.18724499536412104, 0.11362453616623368, 0.14665745970393929, 0.12564149312675, 0.12154760637453624, 0.14913354255259037, 0.11825615513537611, 0.1317719348839351, 0.11188530163573367, 0.13705758697220258, 0.1041085778602532, 0.13668859962906155, 0.18310503608414105, 0.06001557423067944, 0.11783114794109549, 0.10152916091361217, 0.13738210313022137, 0.11897818424871989, 0.12047553461577211, 0.1511752815651042, 0.14453205732362612, 0.22799143035496983, 0.1436820157936641, 0.12170569146318094, 0.0865154065457838, 0.12582142704299518, 0.09663040270762784, 0.17397912006293023, 0.20091183057853154, 0.10480481585753815, 0.12587119080126286, 0.09526508846985442, 0.21727863805634634, 0.12822687439620495, 0.09961802632148777, 0.11984372351850782, 0.13051926424460752, 0.1994831208139658, 0.0902237497004015, 0.2926887401512691, 0.10601728329701082, 0.18301416667444365, 0.15700199747724192, 0.10758690442889929, 0.16542546690574714, 0.1137121757492423, 0.1328912598213979, 0.08857025485485792, 0.07839105570954935, 0.06161480663078172, 0.090200808431421, 0.22059002465435437, 0.10109315466667924, 0.25707960235221045, 0.12319584935903549, 0.26003478520682877, 0.15101315240774835, 0.15431689870144638, 0.08245478158018418, 0.10723260736891202, 0.12481838943702833, 0.13744760890092167, 0.12400437811655657, 0.20177783125213214, 0.09107832384428807, 0.20708975621632167, 0.09312788636556693, 0.21165469554918154, 0.10552811383136682, 0.10150592787457363, 0.10441030881234578, 0.20000876832221234, 0.08339399618229695, 0.2174945343285799, 0.1088945839021887, 0.08823770484221832, 0.09481328592768737, 0.1455292459577322, 0.2252529173025063, 0.1309275251946279, 0.11252872246716704, 0.17889168645654405, 0.11762142633753163, 0.10797681100666523, 0.13425571231969766, 0.16578678680317743, 0.1120445334485599, 0.1308033668569156, 0.19370618223079614, 0.10723132493772677, 0.13033090292343072, 0.17783390464527266, 0.08884991984814405, 0.161401862810765, 0.09342474543622561, 0.10315841848828963, 0.1290126722306013, 0.19205603934824467, 0.2120052267398153, 0.1698475746171815, 0.10546510506953512, 0.15115269991968358], [0.013080544487041022, 0.022620603508715118, 0.07239554742617266, 0.03994150925427675, 0.014309304400480219, 0.08196432289800473, 0.033066358350749524, 0.03173932705872825, 0.040286313609353135, 0.09696040142859731, 0.0372656589107854, 0.06643500405230693, 0.06303597108594008, 0.013917459757067263, 0.003861404115533722, 0.02895145058365805, 0.06650905936424222, 0.04647258183519755, 0.07140867252435003, 0.04775341846314924, 0.03454277251980134, 0.04418091123391475, 0.01914354071154126, 0.07203043451798813, 0.03152464197150298, 0.03892790346539446, 0.030348292951072966, 0.03833835492176669, 0.0225382293574512, 0.009883816736484212, 0.05234392160283668, 0.08557421062141657, 0.03152190747537783, 0.06496797062988792, 0.058591838127800396, 0.04731595336592623, 0.05251986234049712, 0.009499671769195368, 0.03212002930896623, 0.04275615732850773, 0.037212753535381386, 0.013265651384634631, 0.026308860330443298, 0.06572230479546956, 0.02215022098139993, 0.09314311269138541, 0.018895665083878806, 0.026601485342585614, 0.04509509128651448, 0.03788911045661994, 0.0920991390677435, 0.026426370721310377, 0.010602739855780132, 0.033838426029043536, 0.03963625331276229, 0.022854598006233573, 0.028076885101784552, 0.030771122047943727, 0.033434921609503884, 0.04035839099170906, 0.08697187062352896, 0.05120351458234446, 0.0689569151561175, 0.042847233691385815, 0.02200663279342864, 0.01956076341282044, 0.042859131802937815, 0.046228682422744374, 0.048003512900322676, 0.017082275157528262, 0.0464893246867827, 0.009298151109500654, 0.027195303567818234, 0.025418138929775784, 0.014501852282722081, 0.05177374184131622, 0.040397810483617444, 0.0068687328104195845, 0.02779455346587513, 0.11293576883950404, 0.05201730877161026, 0.08399479822920901, 0.031126111213650023, 0.026643159267093455, 0.01713961984829179, 0.007506554031611553, 0.07213769733373608, 0.01743010917146291, 0.04146759897204382, 0.023371075113703097, 0.01487111103987055, 0.03132036221878869, 0.017786090694633976, 0.112905458680221, 0.021119994477235844, 0.0410214554119323, 0.02874458221984761, 0.030038755453590835, 0.05119499557518533, 0.05448850277545197, 0.018573829139183675, 0.05188327435670154, 0.07095315161028079, 0.017416472313925624, 0.009738924064939576, 0.05403185549325176, 0.05176510409052883, 0.030605121848306487, 0.05394256707014782, 0.026897212956100702, 0.023335579250540053, 0.013424478620955986, 0.10313956878547158, 0.0642856222444347, 0.021752484109518782, 0.058700566579188616, 0.046418862217771154, 0.08608830267829554, 0.00392668045658086, 0.023605919476332407, 0.01982872706970998, 0.028652779824499573, 0.013480049790814519, 0.09757960534521512, 0.011879224529755967, 0.07597775092082364, 0.051087213680148125, 0.010333168070896395, 0.033544657685394795, 0.03084058707047786, 0.036195317416318824, 0.029787127527275255, 0.022257531294599175, 0.027832449646666646, 0.04958793627364295, 0.023483116512319872, 0.04380381539730089, 0.03219293789672, 0.03936712257564068, 0.022625370217221122, 0.051842755638062954, 0.09000458967472826, 0.014051921649037727, 0.008346408206437315, 0.03586610918864608, 0.028267857086445605, 0.036229630932211876, 0.05205467230241213, 0.09158376457967929, 0.06052951700985432, 0.045587015604334216, 0.045732581721884866, 0.03600722411647439, 0.03793648237894688, 0.02631303501714553, 0.0595921819497432, 0.006352315498848579, 0.025586831217099513, 0.032528012059628963, 0.030595836096576283, 0.020806677539699843, 0.06245211884379387, 0.01843252422155014, 0.03477093331249697, 0.015237329960135477, 0.05395692826381751, 0.04225991752796939, 0.012026738042810133, 0.03322148841938802, 0.021488415243636285, 0.01994992190572832, 0.022453775496355126, 0.0279395309542971, 0.13408571215612547, 0.05274623180074351, 0.005808783927932382, 0.0024231891355676843, 0.05872719907867057, 0.03768980097291725, 0.0533757358789444, 0.0465015756365444, 0.010815618343518248, 0.0021381925533725215, 0.023141543680269803, 0.016850292516340102, 0.0403482299298048, 0.04838068337578859, 0.051805941720626185, 0.007837039601456906, 0.037168336633060656, 0.016024031942444186, 0.03580377896183303, 0.01188965530933014, 0.025584685350103036, 0.03112834020118628, 0.03667208326182195, 0.033643062226474285, 0.025716499259163226, 0.011379767625060464, 0.0499697547139866, 0.09439359166260276, 0.0257105383290244, 0.02663284044579736, 0.0467015331211899, 0.05412125587463379, 0.045749714731105735, 0.01654082626503493, 0.029582518685076917, 0.03142612886482051, 0.10583354958466121, 0.018729574978351593, 0.036501485987433364, 0.083928939620299, 0.04757216479629278, 0.014329076910923635, 0.012319807495389665, 0.03143765717478735, 0.02425161000740315, 0.06217491014727524, 0.07013421412557364, 0.028338370445583547, 0.033101194338606935, 0.01659402680317206, 0.007334438535118741, 0.025377296210665787, 0.020903041386710744, 0.05004032235592604, 0.04669011337682605, 0.037459713140768666, 0.02727481090862836, 0.00904310421485986, 0.014227871716554676, 0.03411475941538811, 0.03368093805121524, 0.03858461563608476, 0.07164833787828684, 0.05386703255187188, 0.03628627842824374, 0.0856668238661119, 0.01146674987726978, 0.049022326445473094, 0.036389351290251525, 0.05223766980426652, 0.038315037065850835, 0.0133969479107431, 0.03425797101642404, 0.04350890711482082, 0.051663520612886975, 0.010314667813612946, 0.06198005524596997, 0.017468164807983806, 0.02865663729608059, 0.004467387201397547, 0.02101465530826577, 0.02723782735743693, 0.03410118192966495, 0.050952707683401446, 0.026491063946325864, 0.06276592771921839, 0.0013508216839649581, 0.08290013125432388, 0.04276356353823628, 0.033904966565647295, 0.07844919258994715, 0.053781482856720686, 0.03548129840887018, 0.02943605350862656, 0.06523953391505138, 0.04460514150559902, 0.06918508612683841, 0.04030368749850562, 0.05484744780031698, 0.015949990201209272, 0.03807836744402136, 0.02918531446318541, 0.04111149700890694, 0.061408267356455326, 0.10737236522670303, 0.053276710478322845, 0.020181965615068163, 0.03163053753918835, 0.04701720457524061, 0.040414383701447926, 0.026802296085017066, 0.08323208415614707, 0.04813999682664871, 0.022608707093500664, 0.02691316701072667, 0.009751222512152578, 0.021888771260689412, 0.030367566738277674, 0.03242106815533979, 0.02861301088705659, 0.06608213191585881, 0.03476657711767724, 0.024942933714815547, 0.013452243425750306, 0.05086974999202149, 0.03776255689029183, 0.04594997755650963, 0.021578188819278563, 0.09705277718603611, 0.005004533757788262, 0.01168807697415884, 0.03177389841792839, 0.02472089839700077, 0.07703038265130349, 0.01726145589990275, 0.04110073883618627, 0.07017880066164903, 0.032676831752594025, 0.025324699568695257, 0.021607265741165196, 0.08323509006627969, 0.04445860169029661, 0.028090028325095773, 0.037435126424367936, 0.07294891308993101, 0.02894255838223866, 0.01856231439991721, 0.014841742347925901, 0.07297631233398404, 0.01777978371163564, 0.007715761644898781, 0.02381601936316916, 0.0277711999868708, 0.040341515825795274, 0.011671995694216872, 0.014261060560654317, 0.015444756418998753, 0.03909361528764878, 0.08255636505782604, 0.05831669896308865, 0.026635004972506846, 0.01759057761436062, 0.08230370575828211, 0.04590174389470901, 0.08348078759653227, 0.019643291930801103, 0.04241881685863648, 0.02930553051243935, 0.06279793421604804, 0.006898296581182096, 0.009545300704693156, 0.03662750690377184, 0.05053405836224556, 0.015212242824158497, 0.01299032477462398, 0.06544392223336867, 0.008249038431261266, 0.01366397094846304, 0.034981326665729284, 0.085612649630223, 0.0879643095125045, 0.1277496200054884, 0.18650925984340055, 0.11951244915170328, 0.11443106324544974, 0.10637962099696908, 0.10568114383412258, 0.06444910847182785, 0.2423281424811908, 0.1177664292710168, 0.14435662887990475, 0.13284486159682274, 0.09564464060323578, 0.04933742114475795, 0.17967460730246135, 0.12589869861091885, 0.14779929843332085, 0.15456279979220458, 0.16308905370533466, 0.07490069192967244, 0.11354676926774637, 0.056720923698906384, 0.11022263978208814, 0.2240635132683175, 0.10739372550909008, 0.10921666411949055, 0.2521760197622435, 0.13114825263619423, 0.12672340364328452, 0.11759998463094234, 0.15003636053630284, 0.17329579458705016, 0.1957510696457965, 0.1155202883694853, 0.1515633493129696, 0.22680662678820745, 0.1016792935718383, 0.07163109630346298, 0.13655857874878816, 0.10320719158543007, 0.10001839590924126, 0.14616670246635163, 0.11893763499600546, 0.10548894879009042, 0.1797985349382673, 0.07894365462873663, 0.1524766031652689, 0.16669529091034616, 0.09730868666831936, 0.1648428360266345, 0.09102485528481857, 0.10273449016468865, 0.10309169135455575, 0.09828469143914324, 0.14719594509473868, 0.07888630484896046, 0.09151224020336356, 0.1069906349959118, 0.13013367993491037, 0.17168464032667025, 0.1261887994727918, 0.17080270765083178, 0.08601458663386957, 0.17483294781829628, 0.07257914543151855, 0.09644473517047507, 0.1524289564362594, 0.1481259451912982, 0.11422145020748888, 0.15494758343057974, 0.11480098696691649, 0.0799038020361747, 0.17006106887544903, 0.08457687270960637, 0.10308916041893618, 0.10722491956715073, 0.07631745269255978, 0.10179710760712624, 0.22487365693918296, 0.12202387010412556, 0.12698233260640077, 0.18637697265616485, 0.08570869626211268, 0.16046066688639776, 0.12284548101680619, 0.17684088221618108, 0.1415656107876982, 0.1037238688607301, 0.18111037383122103, 0.10754149686545134, 0.15352276845702104, 0.07697020338049956, 0.16904907460723603, 0.14470406595085347, 0.15626470132597856, 0.08576033277703182, 0.14959487851176942, 0.10761036138449397, 0.10140236307467733, 0.10366253608039447, 0.1819963234343699, 0.215957462521536, 0.11261562923235552, 0.10822154501719133, 0.16280435398221016, 0.16126787928598268, 0.15605611966124602, 0.14235888607800007, 0.2093082671718938, 0.13536255221281732, 0.1024128645658493, 0.22774262513433183, 0.14990281127393246, 0.18857150418417795, 0.24416740664413997, 0.1887317741555827, 0.1662090527159827, 0.10892182708318744, 0.10059407858976296, 0.06311481006975685, 0.14717944312308515, 0.12835594532745226, 0.12728098300950869, 0.1374258550682238, 0.23248360359242984, 0.15696760932249681, 0.10312046802469663, 0.0924136129074863, 0.1549965872296265, 0.19655133384679044, 0.1431593131273985, 0.08456915098109416, 0.18234956876507827, 0.11863803464387145, 0.09181490074843168, 0.16818147259099142, 0.1684259758996112, 0.10987729259899684, 0.11308828994099583, 0.07011312525719404, 0.17633468152156898, 0.1267408827053649, 0.16233259572514466, 0.16291032758142265, 0.1736924797296524, 0.08016259529228721, 0.1359945668705872, 0.18528227853987897, 0.1433495743466275, 0.17777394929102489, 0.10455993935465813, 0.08908325447035687, 0.07569687813520432, 0.1158275833087308, 0.17501988421593392, 0.0815574461594224, 0.1774674007402999, 0.09922254218586854, 0.11532282110835824, 0.08517754583486489, 0.0964814710563847, 0.12097693128245217, 0.09933761493968112, 0.0889582343931709, 0.19586874118873052, 0.13488175586930343, 0.09318663392748151, 0.10453589885894742, 0.12860233496342385, 0.06489030551165342, 0.07450739946216345, 0.17404453083872795, 0.1273525548832757, 0.11966068191187722, 0.1184918646301542], [0.0388530814088881, 0.027514403320050666, 0.03894334013706871, 0.005938643232054476, 0.04960898782259651, 0.043986500773046694, 0.030254302280289785, 0.05608286329412034, 0.014210401136162025, 0.0570771104789206, 0.009460994424963636, 0.053081329712378125, 0.03447109886578151, 0.019953938833038722, 0.03088125167414546, 0.031616865058562586, 0.028345510330317274, 0.07720424367913178, 0.018001629039645195, 0.033035848023636, 0.02904597729710596, 0.07562658869262252, 0.007282851213988448, 0.007685828920719879, 0.04218683252111077, 0.10486941917666368, 0.03515740650306855, 0.04270525363140872, 0.04814063464956624, 0.045980491276298247, 0.02833933735798512, 0.03277344496122428, 0.07822001060204846, 0.05685724816950304, 0.024224985989608934, 0.08369565249553748, 0.029909358825534582, 0.053715162843997986, 0.010520494626169758, 0.011153119117287653, 0.05883753565805299, 0.037646615611655374, 0.05963849875011614, 0.022398344274344187, 0.031464825716934035, 0.016263225714543035, 0.03603944095915981, 0.048665030260703394, 0.058204571051256995, 0.03583285079470702, 0.007871219106683773, 0.05559307975428445, 0.035141935904643366, 0.028025345278105566, 0.04917302568043981, 0.010059891484810837, 0.005462012245386306, 0.029759110816355263, 0.034602517528193336, 0.06250754836946726, 0.016823763493448496, 0.022580276476219296, 0.02872615660141621, 0.03313521947711706, 0.011996895224521202, 0.041809051364128075, 0.01882598971548889, 0.008176921184972992, 0.02168875779690487, 0.019705157361126373, 0.04183930724060961, 0.022070072424997176, 0.0252706322020718, 0.016802465975550667, 0.03686760652012058, 0.0165397117712668, 0.01621843222528696, 0.049571339307086806, 0.022628220064299445, 0.028922996217651025, 0.013252850821507829, 0.020131842233240604, 0.05659821403345891, 0.05542311351746321, 0.052372779697179794, 0.024162236767421876, 0.05872590307678495, 0.038399182193513424, 0.029701672827026675, 0.04092952748760581, 0.019734709257526056, 0.025363949426848973, 0.0757784176883953, 0.004387352299610419, 0.025120170454361608, 0.013524866180627473, 0.022230951381581168, 0.045701314828225544, 0.010848964947009725, 0.052148981884654076, 0.0019997667446399903, 0.019809414266741703, 0.025097020535862873, 0.0052736420184373856, 0.02206904105176883, 0.026311029946165423, 0.041131666462336264, 0.04141903622075915, 0.06311032495328359, 0.018356876048658575, 0.031226992407547574, 0.05576707309644137, 0.043293892938111506, 0.05477484116064651, 0.03946287743747234, 0.068619201491986, 0.03488932749522584, 0.06036804603146655, 0.03573340130969882, 0.07080116655145373, 0.05969512928277254, 0.03472915251872369, 0.05336620246193238, 0.054088207826550515, 0.044213409668632915, 0.05327195394784212, 0.064143292738923, 0.045519311380173476, 0.005503458012494126, 0.024964456845607077, 0.05488426850310393, 0.002979556256572583, 0.02584562956222466, 0.05932739722941603, 0.043211600211049826, 0.020401227420994213, 0.02728681080043316, 0.03659381424742086, 0.020985802302935293, 0.007161368000587183, 0.008265094266140034, 0.05380199497033443, 0.028879743002887284, 0.07441019932074205, 0.02483914839103818, 0.0427828305400908, 0.05612044734880328, 0.04047697516424315, 0.045911012683063745, 0.010726408800110221, 0.004670422690521393, 0.029220174199768474, 0.01402553851117513, 0.041933515042598755, 0.058786978013813496, 0.019619765425367013, 0.0269019321671554, 0.015145622559690049, 0.06970099665756736, 0.039840885903686285, 0.028784782027027438, 0.10434996669313737, 0.020162907262731875, 0.048052581160196235, 0.0610410442043628, 0.03309729954759989, 0.03910152022061603, 0.02332606110056596, 0.04791991738602519, 0.02280678503614451, 0.018059479238997613, 0.08671485512916531, 0.021424381893926432, 0.02555082305999739, 0.025478011163483773, 0.03318881356556501, 0.03154474017875535, 0.029540727713278363, 0.04740907551188554, 0.03023585969848292, 0.020631951379722784, 0.053421998396515846, 0.04233153011383755, 0.032809285180909295, 0.0029457961708041175, 0.014168405755689102, 0.0027409757104968385, 0.06092262627290828, 0.026263668201863766, 0.03136908442580274, 0.01962769919607256, 0.021771230335746492, 0.03567473177931138, 0.01974128426185676, 0.043205445898430686, 0.017597649645592486, 0.048881588104580126, 0.08644293222044196, 0.05371625189270292, 0.036374779750726054, 0.03450563629823072, 0.017145726663459624, 0.07672862455781017, 0.010838044774053352, 0.05147742899134755, 0.012599648907780647, 0.02264870164383735, 0.096134217189891, 0.09390877160642828, 0.02099210928593363, 0.021745958298976933, 0.0406741506553122, 0.03875801186742527, 0.044171951178993495, 0.055302028943385394, 0.01789378607645631, 0.026585504146558896, 0.04565170034766197, 0.053931459451892545, 0.04261305429307478, 0.022282087476924062, 0.036938438790717294, 0.049468500539660454, 0.04472014979858484, 0.062267034846757136, 0.025857429286198955, 0.025179883232340217, 0.059554272198251317, 0.029630531822996478, 0.012298085044936409, 0.0668008972757629, 0.03847541221018348, 0.029065698917422975, 0.047326297632285526, 0.02699204331396946, 0.011288915178738534, 0.013741575846714633, 0.09061352057116372, 0.019674280625102774, 0.02550062334298023, 0.020342544319906404, 0.032891577907970974, 0.016282921889796853, 0.07595660776964255, 0.005923987299736057, 0.07166112826338836, 0.04263227379747799, 0.08083027375063725, 0.036884712387940714, 0.027539990875603895, 0.047065007367304394, 0.025588661565312316, 0.03070319051455174, 0.027393203395019685, 0.05016355449333787, 0.04859561612829566, 0.007621818471566907, 0.02724693838639983, 0.03549486232389297, 0.023154841270297766, 0.03155276046267577, 0.01343589073180088, 0.06481266074946948, 0.00902772437049342, 0.016775090480223298, 0.025866567456562604, 0.012908919232099183, 0.059108053999287744, 0.028525544330477715, 0.05546285531350544, 0.024192901461252143, 0.06210557065371956, 0.010811681992241313, 0.016982883347996643, 0.012953115610538848, 0.12543071300855704, 0.038376868569425175, 0.024634643025430183, 0.026091206652511443, 0.004808942221903375, 0.053940456826239824, 0.01950784107404096, 0.046509901261223216, 0.024742207789261426, 0.03766711076189365, 0.0658496522477695, 0.02190906454675964, 0.04479021193193538, 0.03530587335782392, 0.08749588964773075, 0.006629659902370934, 0.010263211110473743, 0.010661383092935597, 0.04299928999638983, 0.019799431320279837, 0.025529065834624425, 0.043045681435614824, 0.04874883612085666, 0.029099988684590374, 0.04156412397112165, 0.056303991071347675, 0.07862148620188236, 0.04185401787981391, 0.01018833731567221, 0.0073436725485537735, 0.03711074258067778, 0.042632993044597764, 0.010863171773962677, 0.025880743749439716, 0.076226678277765, 0.03292451060510107, 0.06783480143972806, 0.02091706670554621, 0.006409597425122878, 0.07289967858897788, 0.10285800389413323, 0.02126854275619345, 0.0741255267390183, 0.011215321270615926, 0.03252996284780758, 0.033009286770331006, 0.022787148232704828, 0.043852103341903, 0.0392295054958335, 0.04592106178668993, 0.04265891647498522, 0.10528712533414364, 0.05426702216001494, 0.04203873546794057, 0.07097606573786054, 0.02976715484900134, 0.03320963441261223, 0.03700072491275413, 0.05418679557208504, 0.046072157964642556, 0.016146078339910934, 0.0293692144166146, 0.006983643988080854, 0.04488079296424985, 0.0794880229181477, 0.021137403989476816, 0.0047914207513843265, 0.025092031607138257, 0.03182237295966063, 0.02905613835901022, 0.022236707054876854, 0.058732518793216774, 0.03511287085711956, 0.006508422233829541, 0.008727381870682751, 0.03121497555236731, 0.028905048966407776, 0.13281432752098354, 0.12551729407693657, 0.1454527886318309, 0.1038561017651643, 0.11534595915249415, 0.14231923249151024, 0.1243721983794655, 0.17665410866694792, 0.11378166452050209, 0.16343476729733603, 0.08080997876822948, 0.13823253821049417, 0.13924426106469973, 0.11366292089223862, 0.18774747768683092, 0.1642644799181393, 0.11874907011432306, 0.1692858561873436, 0.13056507892906666, 0.06299656855740718, 0.08767167092966181, 0.17426239486251557, 0.10867728306246655, 0.11293089017271996, 0.24470583775213786, 0.12932927667030267, 0.09427013221595969, 0.11374232984547104, 0.11334019606666905, 0.14184195095939295, 0.1038400408412729, 0.1444348639675549, 0.17565465372587952, 0.1291981837046998, 0.15035700904471533, 0.17032865594540322, 0.16869325084345682, 0.12796776901398385, 0.09764448686369828, 0.07302421012095042, 0.07436751268271889, 0.11408149557454245, 0.2698487900197506, 0.1738351077905723, 0.10394764970988035, 0.08640682058674948, 0.1187649206923587, 0.11220570587153945, 0.1174217334815434, 0.13740169922155993, 0.07022992827530418, 0.13610420455890043, 0.06110365263053349, 0.08472308343542473, 0.11324934701302222, 0.19068218235458645, 0.14831368226025785, 0.14664878802640097, 0.11337092691766364, 0.11283095553517342, 0.05801097143973623, 0.17247271803872927, 0.2859247773885727, 0.17191296736044542, 0.06359931121447257, 0.153868685609528, 0.0939249275252223, 0.12355844490230083, 0.13715332826333387, 0.1448363938501903, 0.09771559733365263, 0.15178746942962917, 0.11244676222226449, 0.10246359184384346, 0.14489687846175262, 0.09232203782136951, 0.13288556012724126, 0.0907545065773385, 0.21114362297313555, 0.1670274202312742, 0.0415695692146463, 0.21181143713848932, 0.08782372384199075, 0.12788619553404196, 0.1711455171129533, 0.130787299147674, 0.14447858876415662, 0.11434247371341501, 0.13854005028094563, 0.13311513566545077, 0.1485833456473691, 0.11793695869190352, 0.18511913157999516, 0.20403049966054304, 0.09012108056672982, 0.08001558389514685, 0.10529765619763307, 0.14192437939345837, 0.13564357427614077, 0.16387263951557024, 0.06530645782394068, 0.11510028876364231, 0.1997327809887273, 0.08418303741408245, 0.18116426308240208, 0.1233949043921062, 0.11544647733015673, 0.2501765399106911, 0.1257445625960827, 0.142046949959227, 0.11387447454035282, 0.15390508222792829, 0.15121983417442866, 0.23610413074493408, 0.10597033545907054, 0.07460816191243273, 0.1648073350744588, 0.13303837978414126, 0.11916109014834676, 0.13159263879060745, 0.10744739762906517, 0.24240242849503243, 0.11232502625456878, 0.13599006139806338, 0.19376585260033607, 0.2025975694081613, 0.14013538110469068, 0.10583120185349669, 0.14444300638777868, 0.1412903562720333, 0.16464790648647717, 0.09646126428352934, 0.13198494059698923, 0.19077139613883837, 0.2056798825838736, 0.11021311315042631, 0.10077583097985812, 0.08339198771864176, 0.13717342647058622, 0.11074351040380341, 0.11154265502201659, 0.1502146523978029, 0.07730315372880016, 0.11933156528643199, 0.10468820961458342, 0.062483908209417544, 0.1757937398340021, 0.18335830606520176, 0.2541538950588022, 0.1415479417358126, 0.15462772202278885, 0.141180243609207, 0.10199652226375681, 0.12282204441726208, 0.20965759057019437, 0.1677607265966279, 0.10416133395795311, 0.07339405920356512, 0.15418915769883565, 0.05454311127375279, 0.11519152458224978, 0.144946886492627, 0.17376448586583138, 0.1375110112130642, 0.14614349656871387, 0.15494799055159092, 0.15711523140115397, 0.2003044874540397, 0.1362051841403757, 0.10727676642792565, 0.12507315219513007, 0.18174222564058645, 0.060957021213003566, 0.07642036609883819, 0.1627032794058323, 0.1307473877178771], [0.010777443115200316, 0.017940435358988385, 0.017042268732828752, 0.05017898777233703, 0.020473927359229753, 0.05107635711984975, 0.04865820419841579, 0.12848208498741898, 0.013112263454656516, 0.04111318316842828, 0.01629958501351731, 0.08443214119012867, 0.02048800865720425, 0.029133925613548075, 0.03054219451067703, 0.02384229902444141, 0.026748213451355696, 0.05090768009956394, 0.030894608635987555, 0.03665703674778342, 0.0114446245466492, 0.05579717630254371, 0.06999764538237027, 0.022391192515247633, 0.05247455316462687, 0.02339090869229819, 0.025082915489162718, 0.05628626434398549, 0.049975345842540264, 0.013301595080909985, 0.024858367895441394, 0.042888369876891375, 0.05073012105588402, 0.038855408784002066, 0.05795465303318841, 0.05598486587405205, 0.047128033092511554, 0.025040924349533658, 0.09181774381015982, 0.05933028778859547, 0.051192390000713725, 0.021406677218952348, 0.04539157377023782, 0.014898243958928754, 0.026742244039529135, 0.018229800010366098, 0.035450964500861507, 0.007633987148957593, 0.012849460056583797, 0.030322820746472905, 0.013918868565399731, 0.004040269339124539, 0.029970097887728895, 0.029431666779731, 0.05710691852228982, 0.024709110547389303, 0.05705762295318501, 0.015465402543278677, 0.03390753482069288, 0.027942986393879567, 0.05797791999897786, 0.037773566120969396, 0.06247612541275365, 0.01912611593226237, 0.01558279588685504, 0.016758746267961602, 0.013801029933217381, 0.01821828187842454, 0.007039023471796619, 0.012601319800264068, 0.03860218969306775, 0.05814114838306393, 0.02570930339529046, 0.05742420149700982, 0.030848838056304624, 0.01399518339894712, 0.05468658071809581, 0.007595954412993575, 0.04225159190329058, 0.02954192872026137, 0.013877205667085946, 0.03919995190309627, 0.0887207267805934, 0.01287181269643562, 0.03320492537958281, 0.07344859984836408, 0.036256419494748116, 0.028500564063766172, 0.03379074198060802, 0.08423628205699579, 0.041615526391459365, 0.060498759017458985, 0.006260325234117252, 0.021430872081379806, 0.06316795971776758, 0.011533328581468334, 0.03082456685868757, 0.01748289749957621, 0.029389468686921254, 0.04348061898989337, 0.04483720048197678, 0.06293476758790867, 0.049425566236355474, 0.030634254749332155, 0.018627972840996723, 0.06816092572574105, 0.04624449568135398, 0.030173305555113723, 0.06830725180251257, 0.0686894841492176, 0.04919650299208505, 0.023282789226089205, 0.014891641813197305, 0.02680329353149448, 0.0007526723909125264, 0.08550354119922433, 0.0319141583916332, 0.01785812566855124, 0.0631132765806147, 0.02511212811805308, 0.05867626824017082, 0.01354754451728825, 0.03850529489240476, 0.03363317936392767, 0.028518487566283772, 0.03750268815617476, 0.010356247591386949, 0.02177673495108528, 0.07510397423590932, 0.012023745703377893, 0.05327828467956611, 0.016324236190744808, 0.054623358217733245, 0.02483618488934423, 0.04977997186194573, 0.040497653518936465, 0.02312447004286306, 0.05271759423028145, 0.023547197359481027, 0.004089926652211163, 0.017171019056279744, 0.0732272956520319, 0.020122449612244964, 0.06376473126666886, 0.029661707114428282, 0.022600006578224044, 0.017441427135573964, 0.011002089944668114, 0.01093900908849069, 0.029859455967588083, 0.06522906411971365, 0.006913111121061125, 0.07532656764877693, 0.03513679939455219, 0.03501765543062772, 0.02335384880591716, 0.012110514217056334, 0.008571122041238206, 0.053317310621163676, 0.02163738082163036, 0.05734181377504553, 0.029476972562926154, 0.019612479655604278, 0.0507374119146594, 0.005823742656502873, 0.03420358304200428, 0.025980066009131924, 0.06177037435450724, 0.0873328105413488, 0.04378666542470455, 0.03443678534988846, 0.016761180512341003, 0.0371489373168775, 0.05600794963538647, 0.025506278932360665, 0.023573088559455106, 0.013438497154441262, 0.009388531973984624, 0.014193019613490572, 0.04101835111422198, 0.039906140616429706, 0.07967560392405305, 0.008594728274536985, 0.05659982216145311, 0.07982275781354733, 0.012644869025929697, 0.0009507072889911276, 0.018968124142182723, 0.014166011375242045, 0.02036238638018923, 0.03260353979255472, 0.038898604323289225, 0.055214128124394586, 0.08522359800658055, 0.010128400621137448, 0.004225866478269121, 0.03271624445915222, 0.02969423947589738, 0.04023710964247584, 0.06734923499503306, 0.04242989394281592, 0.034767371003649065, 0.02512394480540284, 0.020007950220523135, 0.013631468272901006, 0.022275363194889257, 0.04141381150111556, 0.04339487591226186, 0.011955263708452029, 0.06260932862226452, 0.039571721239813736, 0.022165289547826563, 0.026933704569403614, 0.016648906715480343, 0.0238826430203127, 0.08423308615705796, 0.02977298346481153, 0.006399538991640189, 0.06298996641167573, 0.06983128895184823, 0.0486646265323673, 0.020007342931681445, 0.019473298552579114, 0.04026887186669877, 0.010011392346184169, 0.015332016129312771, 0.04641407515321459, 0.026470029360747764, 0.008153809434069055, 0.060556359855192046, 0.13758503938359873, 0.012333535955154469, 0.05194401341889586, 0.04236628467749272, 0.012970285939185746, 0.04329904641157814, 0.03858966054394841, 0.03684492987979736, 0.021981644045029367, 0.09608037543616124, 0.04722895160583513, 0.03845007910526224, 0.006123524516754384, 0.027732576077271785, 0.007157274738087186, 0.02795183957953538, 0.10309119602399212, 0.06305296160280704, 0.024786977529791848, 0.030066392184900384, 0.04150004990931068, 0.021434666788471595, 0.06412583403289318, 0.02978947865111487, 0.13930728339723178, 0.03220756032637187, 0.009001449798233807, 0.0356630236575646, 0.08345033494489533, 0.007086095990546579, 0.05479214380362204, 0.0286842943834407, 0.05397147944729243, 0.05486454349011183, 0.012081477159102048, 0.07509962482643978, 0.03196538100019097, 0.018087054902155484, 0.03598817424582584, 0.02889875216143472, 0.027485570670770745, 0.0386178299252476, 0.03420373910505857, 0.014685379041891013, 0.03475411921473486, 0.025952505613011972, 0.08996162483734743, 0.025392734578677585, 0.007842664656761502, 0.023562423685299497, 0.030201437616986886, 0.04429694072210363, 0.03944148662100945, 0.009974092428040291, 0.0030767379503231496, 0.04402458694364343, 0.029505145336900438, 0.0402751347449209, 0.03932730953342148, 0.0393309634444969, 0.02814372249745897, 0.09533640250031437, 0.057504865740026744, 0.028639002170945917, 0.030525505941893374, 0.006736719581697668, 0.033453625427292924, 0.02352987605679248, 0.02713802842689412, 0.011669839649195117, 0.04551202730674829, 0.04324969316699675, 0.06269498009766851, 0.032506254834256, 0.01707363062139068, 0.015026558323630264, 0.04316110363496201, 0.05568689061328769, 0.046930908491568904, 0.024880537330838184, 0.05577010954064982, 0.1130420206380742, 0.020594233314373663, 0.08882988949439355, 0.05025466139029179, 0.006895410262846521, 0.03148011989625437, 0.04893721440540893, 0.038226403429039886, 0.02461218521265047, 0.013904345371494336, 0.04709764150902629, 0.046068867069802115, 0.03374656256554382, 0.02057891368999013, 0.004982319793530873, 0.007638050725550524, 0.015911500302276442, 0.03507899838898863, 0.057427159909691126, 0.01623466278293303, 0.007561355064223919, 0.020292526111006737, 0.019123656242819767, 0.07469711785337754, 0.009748054601784264, 0.014742864528670907, 0.008077972967709814, 0.012333134771324694, 0.039680246130696366, 0.025344370298885872, 0.05451583077332803, 0.016455593785004954, 0.07792272405432803, 0.0505831842975957, 0.04651249326499445, 0.059826819359191825, 0.031624756420829465, 0.02095571266753333, 0.02807402507668095, 0.02063589875719377, 0.0231280153883355, 0.07708072316433702, 0.07393806108406611, 0.07401715112583977, 0.1042026567405888, 0.15896950475871563, 0.12654455538306916, 0.15778972235109123, 0.20778292044997215, 0.13817395349698408, 0.10627605619707278, 0.06082075781055859, 0.16875577106007508, 0.08464447515351431, 0.13378498543586048, 0.07988446378814322, 0.11515005252190999, 0.14460890819983824, 0.12910405732691288, 0.1499905322811433, 0.19040190667978354, 0.07669466388012681, 0.11050824195678745, 0.14798014158649103, 0.15583791636994906, 0.20143469609320164, 0.06918289445872818, 0.16217233932444028, 0.07003577226506812, 0.1755273469856807, 0.1203058058662074, 0.09175601069416318, 0.13222928105720452, 0.09259887332362787, 0.11991017923823424, 0.08763726241886616, 0.11205460969358683, 0.08479752551232066, 0.08333913662603923, 0.17549819712127956, 0.13575372765106813, 0.10307622754148074, 0.08173545982156481, 0.16048787614064558, 0.17422150634229183, 0.11305648021932159, 0.0997441727668047, 0.14519300471459115, 0.09207184838929347, 0.15451978067202227, 0.07939455471932888, 0.24331937357783318, 0.07017968954252345, 0.09048406966030598, 0.1124530318858368, 0.17847444170287677, 0.10173629051340477, 0.1897331289947033, 0.15290104039013386, 0.08423762555633273, 0.11228022258728743, 0.07724713387766055, 0.06647601470883403, 0.2796799753393446, 0.15218287892639637, 0.08225337881594896, 0.11308322128440652, 0.13599322337125028, 0.1219045157943453, 0.11428829947752611, 0.2075314825134618, 0.1635180235441242, 0.11841381953230926, 0.14014464989304543, 0.15827102081051894, 0.09950778473700796, 0.14219864324799605, 0.11389834540230886, 0.11377319640346936, 0.1886551539812769, 0.04780480731278658, 0.09715170759175505, 0.12656244156616075, 0.22581068665853568, 0.06514612678438425, 0.08325784134545497, 0.19908844413501875, 0.12775291768567903, 0.20070217682846955, 0.08932333373065506, 0.17196315181042465, 0.14147270577294485, 0.21788063432489121, 0.1348720392478364, 0.1349376400134393, 0.11247332008289439, 0.10944733209908009, 0.10264005844614335, 0.20390612419162477, 0.15213835345847265, 0.1116194584007774, 0.17910210016582692, 0.12527317074792726, 0.2168809486819165, 0.1546599795775754, 0.11784340228353228, 0.10737280627446515, 0.13261015633387224, 0.1364655787391322, 0.1904355213046074, 0.09932714514434338, 0.08945201111159154, 0.1051674046154533, 0.122086105336036, 0.15514853836170264, 0.11745650161589895, 0.1742862250123705, 0.1300482116639614, 0.0769266550030027, 0.11728848277458123, 0.09553705887602908, 0.14371795100825174, 0.13178520702889987, 0.15662712045013905, 0.0987780610365527, 0.13603396261376993, 0.12626738739865168, 0.1259971811835255, 0.06752027331718377, 0.10335474581058536, 0.14491297331239494, 0.09066357609948941, 0.0902168218578611, 0.12687656256769383, 0.06955249248338596, 0.14970898096050533, 0.15022151917219162, 0.07068493350275926, 0.12171899074954645, 0.09336655427302633, 0.0975033040823681, 0.2252410157982792, 0.18904219035591396, 0.07570359563188893, 0.11801847788904395, 0.09491154458373785, 0.162761158442923, 0.1222901815282447, 0.13550315823938164, 0.08178458575691495, 0.11703674628266267, 0.1440939408327852, 0.1005902448669076, 0.22208573296666145, 0.15993564363036836, 0.17940346470900945, 0.06203492158757789, 0.0843316705099174, 0.09464506352586405, 0.1687076629272529, 0.07593572924711875, 0.13216655728008064, 0.10376974461334092, 0.10986940123672996, 0.13064384327403136, 0.12234181804316384, 0.12666020489164762, 0.18328130591128552, 0.18300978333822318, 0.18163969899926866, 0.16881111237619603, 0.15584288324628556, 0.11963801884225436, 0.07537800060319048, 0.1482810175844601, 0.164168046521289, 0.08965274891150848], [0.010689421008074922, 0.04574693273752928, 0.046070346276142767, 0.016532246189724122, 0.04966109591935362, 0.01504992028432233, 0.005760758915649993, 0.039954248749251874, 0.026824777646522437, 0.03364407324365207, 0.06365003170711653, 0.018904075525434952, 0.04290055975850139, 0.015579182687880737, 0.056210906244814396, 0.032767826691269875, 0.020171658668134893, 0.007373200696227806, 0.006116700998973101, 0.010510286066814192, 0.01757691870443523, 0.022911255680290715, 0.03336920888562288, 0.043277075447674306, 0.02606247239080923, 0.019556337668161308, 0.023989624244027903, 0.06844361019986016, 0.032379178795963526, 0.00866095329235707, 0.03551379684358835, 0.03527814502428685, 0.08738081010856799, 0.00588926114973479, 0.04696331871673465, 0.027048125929598297, 0.009838225968581225, 0.04188965453899332, 0.040833195871008296, 0.034277438186109066, 0.05337508448532649, 0.041693439174975665, 0.03637447780264275, 0.04138922817738993, 0.014126028699268187, 0.042160959980849705, 0.038567574229091406, 0.07210182318730013, 0.008966244008791233, 0.012220407204170312, 0.01785442086734942, 0.0014090394584595092, 0.016016747869018997, 0.05900969356298447, 0.04928379991490926, 0.05676715907507709, 0.012551772325033588, 0.009574313165753015, 0.03608901472762227, 0.012207219027914107, 0.05571736362097519, 0.008856160183703261, 0.021339227445423603, 0.034308036722775014, 0.11810652459306376, 0.03265085403940507, 0.012200335290149918, 0.10117450423006501, 0.02300349233805069, 0.08245045931211539, 0.04706257142658744, 0.024204563781885163, 0.016779383910553794, 0.09276233919497047, 0.00591396406525746, 0.0916622778666871, 0.09385096042283944, 0.04095422276960952, 0.04353650652670434, 0.08261380983250481, 0.02408186429446297, 0.007035010785330087, 0.026446911672662412, 0.06503130508852856, 0.03231135243549943, 0.10118878739220755, 0.06573023008448736, 0.028123251095946347, 0.04735779183517609, 0.07297299429774284, 0.06797854908342872, 0.03208656396184649, 0.04653991286509803, 0.05118874966033867, 0.07727746439299413, 0.009292073980239885, 0.027403529001665965, 0.00898136940252568, 0.08149657478289944, 0.02788246446289122, 0.0175553701285805, 0.03718866214954427, 0.01643446590086179, 0.006263045311373259, 0.05012389412149787, 0.032888935014073334, 0.08232427894004754, 0.03750888318089502, 0.04699993246634092, 0.0005991881937786404, 0.037247508099036555, 0.02574868726411036, 0.04207769694871136, 0.09587959692414318, 0.028032286691346338, 0.007390071621297726, 0.023161034598680477, 0.033239951357245445, 0.05361667348604117, 0.029660322902990238, 0.015649528109601567, 0.021815886421661292, 0.012772380174802882, 0.07922141972397055, 0.05038189688431365, 0.05571979616901704, 0.036547619583351273, 0.0393360354937613, 0.03821935345019613, 0.017888953210785985, 0.03703990691740598, 0.012672531202302446, 0.03312727722472378, 0.01892825512082449, 0.01829819634024586, 0.053945657797157764, 0.12142042177064077, 0.08655515512717621, 0.035989219189754555, 0.06529708046998296, 0.04091704922861286, 0.05550546731267657, 0.05294662354780095, 0.038318277070564885, 0.013972035176785929, 0.03551574084641678, 0.03291218162381223, 0.0361808714057718, 0.03689776400902441, 0.03011299396998116, 0.028966581914573908, 0.03804176387244037, 0.07540556948099818, 0.004594728716516069, 0.021210019110835025, 0.03091403848624655, 0.03012850528050746, 0.05677853471466473, 0.019396527404231683, 0.03777868906036019, 0.06526118596749646, 0.0520172375254333, 0.021928017726168036, 0.027492780105343888, 0.03944389881300075, 0.008674159280157514, 0.010658075234719684, 0.04194110784945743, 0.060001175717583725, 0.00812795979436487, 0.01277148281224072, 0.020209045947662423, 0.029651844607932226, 0.0031151748387076494, 0.04149354615115693, 0.04801854584366083, 0.017841711906450133, 0.010298360072608505, 0.08641758215214525, 0.0388599074711757, 0.02052713298637952, 0.00790813734887966, 0.04954378739265459, 0.08937997104866163, 0.01360966609458306, 0.030990027622984986, 0.018516016259257282, 0.036378331881548674, 0.0049446381994390064, 0.0063461047830060124, 0.04793684344206538, 0.0007176999008931619, 0.025480179082868353, 0.04896956356242299, 0.068459358997643, 0.05263211578130722, 0.022835705894976854, 0.023600654044587697, 0.06580992402242762, 0.03891464828380516, 0.03490690155220883, 0.020930079310866337, 0.03266773599066904, 0.042074406053870916, 0.04312160950420158, 0.01866685798657792, 0.03964199032634497, 0.016261885607881204, 0.008971824111150844, 0.019357399682381322, 0.04001269097040806, 0.04899079831583159, 0.009484633736844574, 0.012975804125224906, 0.07695074299616472, 0.026796484432582344, 0.035997877296592505, 0.028759496419557502, 0.00853945905276175, 0.11532981001905032, 0.041990291460284164, 0.016868558679042116, 0.028502270579338074, 0.04522638102727277, 0.02831827732734382, 0.013780029274390211, 0.034997509725924046, 0.030575727711298635, 0.027204915016357387, 0.03387683789644923, 0.03902837075293064, 0.019444594824952737, 0.02823934334862445, 0.04015712732715266, 0.04037847562826105, 0.06249337377292769, 0.07754098025283643, 0.023148408758320978, 0.024006848855476295, 0.031253238142068894, 0.06587262744350092, 0.03454427547486765, 0.024814451412696923, 0.09442230047924177, 0.07951918803155422, 0.08206564174698931, 0.004712857846503279, 0.02442201050663633, 0.03404551152405994, 0.09574998995023114, 0.061400179219033034, 0.05076948626499091, 0.021690411726012826, 0.043554318070943863, 0.036744723828243356, 0.07645758374461106, 0.03657603323725717, 0.0639949446277959, 0.03279423866687076, 0.03953651884304626, 0.015941274418894733, 0.01213323581032455, 0.06942304157252822, 0.0881975084277136, 0.02709180492508624, 0.056119551682578664, 0.03904026886448264, 0.018767483033505932, 0.06239162066153117, 0.03198522814948644, 0.007748584928257125, 0.008004663196126265, 0.015102427020402891, 0.020508843074951853, 0.052563183408762724, 0.030832210555672646, 0.034741735950644524, 0.025492643771160926, 0.06760323100856372, 0.027292240776919892, 0.06117983175707715, 0.01316080754622817, 0.010723165402721082, 0.01651974248566798, 0.032682894462985654, 0.023747041189510907, 0.013988069807445365, 0.05995201585548265, 0.03256375049906118, 0.05993430609149592, 0.027903974022982374, 0.010442269716544874, 0.054292385799012015, 0.026778474416849867, 0.03767643044037478, 0.04814220545813441, 0.033047522218631845, 0.030715047914002622, 0.013663477314236974, 0.014553434514839734, 0.0897506954414504, 0.10894366912543774, 0.026354702156303183, 0.054104540164449384, 0.015125356415020568, 0.006910921573372824, 0.04231365750144635, 0.021249206204499518, 0.04359894531912037, 0.010758576449006796, 0.027965121902525425, 0.039797985527132235, 0.038118044779236825, 0.06849080231040716, 0.038110285731298585, 0.018168121177170957, 0.008940664086756962, 0.1201341093650886, 0.02979151764884591, 0.03589003433340362, 0.05950847786984273, 0.028846267477742264, 0.015629728457757404, 0.04240302734875253, 0.0263927221697356, 0.009793647066024798, 0.022127876823235835, 0.06057276004659278, 0.0287587941358132, 0.01520725728810898, 0.02388849199217345, 0.047439158361937316, 0.023586779699793885, 0.026419505643259202, 0.027868406913642372, 0.027767551164808016, 0.04094478774017521, 0.03783777928245919, 0.03126559765743358, 0.03544504767549889, 0.0021798172840915087, 0.04718487057834864, 0.04884141543880105, 0.03921458790344851, 0.09438971722764627, 0.017380140156352093, 0.04912109061011246, 0.010351499542593956, 0.02298073427352522, 0.014502951509452291, 0.01927761753488864, 0.020928369402619343, 0.07259139977395535, 0.13998241217008658, 0.13478361256420612, 0.17564815336040088, 0.11487866565585136, 0.08228085948420422, 0.10231689935816185, 0.11314447264053992, 0.18897002137133054, 0.10310284647026233, 0.11404371474470411, 0.1348224383379732, 0.1534981783479452, 0.09924673195928335, 0.14295731325234684, 0.11326079389878682, 0.09657733448381935, 0.17633553647569247, 0.13533285952040128, 0.11051863032792296, 0.15115785678582533, 0.1102267788457019, 0.1347502829240901, 0.21705541360591138, 0.08547558555645601, 0.0910547176109893, 0.11988282070628234, 0.0909700228699616, 0.10897117014974356, 0.2642848300082343, 0.17890896195811884, 0.13498501532844134, 0.13325480531368936, 0.0935948880921517, 0.14515921367066248, 0.1720195109290736, 0.10581907643271343, 0.09825998597911426, 0.13764473689453943, 0.11290006432682276, 0.14962484261819295, 0.09489622326301676, 0.07958751650793211, 0.22746956907212734, 0.09872839227318764, 0.07796051166951656, 0.14188790135085583, 0.1093774904896106, 0.10839398790683065, 0.11210098077676126, 0.14929887439523423, 0.058966179112238545, 0.09636018970715148, 0.19686192646622658, 0.20266967053924287, 0.17296416738203593, 0.08861674807433571, 0.1657041140965053, 0.0909139962334718, 0.15135696610169752, 0.21830828780574457, 0.07287303251879555, 0.11206129326352052, 0.15254700795880385, 0.20392677879759244, 0.10625605977007321, 0.06735647496368204, 0.1385724028306348, 0.12302150657134396, 0.24750612463269914, 0.12530424765178136, 0.12920161709189415, 0.10583625015403543, 0.12448564943458353, 0.126306077465415, 0.155693062714168, 0.16692664421030454, 0.14177768012242659, 0.13027210107871465, 0.11347303965262004, 0.12220284050064427, 0.1651081975017275, 0.15330407662051065, 0.09727119760853903, 0.1313562507608107, 0.15149097676788056, 0.1582070892410619, 0.15147717536560126, 0.13918099445956095, 0.15822705174131052, 0.14973256683775357, 0.09840794732528073, 0.17866091669670173, 0.113913341026221, 0.13081985525786877, 0.12475495998348508, 0.08827799625162568, 0.1186085862240621, 0.16784673769559177, 0.07110104510294539, 0.16510597190686635, 0.15875594264694623, 0.09437519657824721, 0.15841267178101198, 0.19225987126784666, 0.12817333798323358, 0.180137965295996, 0.14270952583423682, 0.0687825113002743, 0.06223968988550561, 0.10584669280797243, 0.21857514205787862, 0.11503124104014464, 0.17680451273918152, 0.13606615231505462, 0.09107646465833698, 0.1871337020503623, 0.10064970489059176, 0.0751632306990879, 0.12004847824573517, 0.150962818680065, 0.1627292265849454, 0.11039000722978796, 0.13893088645168714, 0.1862843661968197, 0.1836734041571617, 0.15322433518511908, 0.2454711166875703, 0.0806335596633809, 0.11570497203086104, 0.13420366868376732, 0.09209901014608995, 0.15604755654931068, 0.1411520844059331, 0.09518060407468251, 0.14375402192984307, 0.18723352812230587, 0.23027779481240682, 0.12483613991311618, 0.16318639633910997, 0.14719133105661186, 0.31904021756989615, 0.11111538830612387, 0.10394836217164993, 0.14156714427684033, 0.07050453139735119, 0.12110126603926931, 0.12147792082812105, 0.11798444257250854, 0.16808361427060195, 0.11250212389443602, 0.08973918748753411, 0.15107078717223235, 0.10546690318733454, 0.15772264237914765, 0.13245341474456446, 0.10680488603455679, 0.23770571766155107, 0.11903725750744343, 0.09864576027861663, 0.1760617068835667, 0.11813556589186192, 0.09660860816282885, 0.09658540905054126, 0.10688046805028405, 0.1207728958023446, 0.22026139657412255, 0.07411163712718657, 0.14445273657994612, 0.09797534732414143, 0.14526574366859027, 0.08577550482004881, 0.1225938123783895, 0.15261555356638773, 0.07559423614293337, 0.07113615929016046], [0.024769277943830405, 0.007047278274382863, 0.04512727420244898, 0.04605685021462185, 0.029889796660946946, 0.03052198773782168, 0.07126704190990754, 0.04608709930575319, 0.029270694524581944, 0.051097578302557976, 0.04319803968870214, 0.010342413958694254, 0.05453740479424596, 0.029572187989417995, 0.03324016509577632, 0.02994524993534599, 0.01067050769259887, 0.032138875619109185, 0.018425995018333197, 0.044725228633199415, 0.06717369798570871, 0.06978174911013671, 0.010142919574198979, 0.011279249447397888, 0.04472050602946963, 0.04583652310871652, 0.028712511262191192, 0.07086636698139565, 0.010416586317920258, 0.03757781555343952, 0.04009486156116639, 0.023333932106782283, 0.05649568060679095, 0.05711022977318082, 0.0341195837993707, 0.03959034024072545, 0.028489768571619476, 0.05920433811843395, 0.016592579827244793, 0.04182863049209118, 0.04952805895092232, 0.0775180525545563, 0.06513845255332333, 0.042291387982134304, 0.06677899416536093, 0.009584486950188875, 0.022732963818790655, 0.06303975052599396, 0.05229532492480107, 0.10333858310644116, 0.04269804758951068, 0.06980624422430992, 0.03343935922852584, 0.0490676050872675, 0.05485936966059463, 0.02494945443634476, 0.05321022422452058, 0.052609934471547604, 0.008990496546695275, 0.00721736834384501, 0.02246179917295064, 0.07128194253891706, 0.006009589157266808, 0.034553147320236476, 0.06587887675102268, 0.008235634820136641, 0.03806642862036824, 0.04075320677033492, 0.028067168480317508, 0.04382491783638086, 0.030375220613288026, 0.029834818361060958, 0.03519335189568145, 0.03161528407196913, 0.02798404454785798, 0.027310006520045654, 0.053410225813942294, 0.004138679817385439, 0.031639891144420416, 0.05295680157308068, 0.05967051203229597, 0.039061038821403465, 0.0380014860337334, 0.04498571822685855, 0.04674681176298431, 0.039096940109240155, 0.02566223681372191, 0.024675163440406322, 0.006286722366764609, 0.05039648538721459, 0.06417634417968136, 0.03269742189773491, 0.05807995130973203, 0.07001534157565661, 0.03284676066998925, 0.05250609486496874, 0.07066697946616582, 0.04774918779730797, 0.01684958005457052, 0.03757449073184814, 0.02078608569822141, 0.07823157962411642, 0.03143503124426518, 0.010120195436424442, 0.010870335407422056, 0.028424274675281982, 0.01340157721590783, 0.033504155930131674, 0.02767042226956359, 0.016205031158668653, 0.05959345081022807, 0.06447678591523852, 0.05249840706320746, 0.01633528952619859, 0.0192333346432341, 0.03453870809503964, 0.010501286996129369, 0.046959179653120894, 0.02363486069121531, 0.04514805433739509, 0.021259194239974022, 0.061638256801026206, 0.026467601901718547, 0.04152934905141592, 0.0679119440859982, 0.049344898600663455, 0.020224441907235553, 0.015312715200707316, 0.023581554980150292, 0.02050815605824547, 0.02455016371927091, 0.08489017946911709, 0.03860394370609096, 0.027347010427287648, 0.05076404780681644, 0.026924060890451074, 0.007986513232546193, 0.05257078978632178, 0.025689366340105022, 0.02435125796390431, 0.03577515156939626, 0.020743378704147677, 0.046621829005224366, 0.01896886883436569, 0.07457500869142157, 0.03772847407630511, 0.004722585070079991, 0.06097601340817554, 0.016814119814495956, 0.036899080366960595, 0.03831203794106841, 0.05102248822471925, 0.008420238753647676, 0.023594884800591638, 0.09969213591622454, 0.02292192733979651, 0.018131705899057642, 0.05047484261116811, 0.044748149546129365, 0.016827459812962582, 0.0721445641081248, 0.04366738575377634, 0.029123231901654174, 0.023724223753171306, 0.020935648387031894, 0.014280315688146012, 0.042027878907642195, 0.011767839613769735, 0.04499946873901146, 0.05298117794362562, 0.05500087135338357, 0.04657885059714317, 0.02141356434939163, 0.02952111465856433, 0.022887654536004578, 0.032548826121326, 0.04049581129636083, 0.020061199952449118, 0.053269059995987585, 0.04398915045229452, 0.015969925560057163, 0.043701081802802424, 0.027350224986938492, 0.09337072726339102, 0.030615001318178008, 0.08385751023888588, 0.024818071397021413, 0.0009724587892248694, 0.03686221555939742, 0.015342813317797013, 0.04051369069410222, 0.024508842632972767, 0.031443441685821326, 0.03545345472437995, 0.028421740346987332, 0.060917435480015616, 0.027434911246278455, 0.07268798244850976, 0.045469289778598716, 0.05316338495218328, 0.0031601487758702463, 0.011115184768901339, 0.021659894613549113, 0.014163676366609122, 0.014796955644020011, 0.02767834925491895, 0.010066195075134081, 0.03130378560828311, 0.06697628500738315, 0.026739753816010695, 0.037523946658309014, 0.056225274223834276, 0.04575427109375596, 0.1378842054733208, 0.02913902819688831, 0.07396533140646559, 0.05453120298417551, 0.022900466973494207, 0.045297796837985516, 0.03851197846233845, 0.06646063910531146, 0.045947399123438766, 0.016997566845800196, 0.05104711565322109, 0.04358704720756837, 0.046166481117584875, 0.05353434683222856, 0.018535863408552747, 0.018250841381294385, 0.03719417524657079, 0.014640692421900374, 0.0046894899486298, 0.022809188746448075, 0.027240992723298923, 0.022499987123800174, 0.048194194811263254, 0.03698424668982625, 0.05125890000324164, 0.04113332548045686, 0.06899558486683027, 0.021060232505468384, 0.0572909236486469, 0.017739453286464726, 0.06993333383330277, 0.004880368210641401, 0.06265491939016751, 0.02925699150988034, 0.04149685740204794, 0.0635430606614266, 0.021134774666279554, 0.014397736173123121, 0.020399693931852068, 0.04431014840624162, 0.03723986440205148, 0.03060778170557959, 0.03285344423992293, 0.052937582068677456, 0.035205256792583635, 0.03153822624257632, 0.07711464312991925, 0.012966877997054585, 0.03124875302559563, 0.03318072542814272, 0.04791640257462859, 0.0182910988639508, 0.04183384842638459, 0.04238419460930994, 0.021155894068734984, 0.033465859413679154, 0.04768758699563997, 0.032084979582577944, 0.02688233777215438, 0.04892214074996965, 0.02481819353332477, 0.09455449267157487, 0.04804038449323603, 0.03739077737554908, 0.04501467810145446, 0.04868434476000922, 0.04122856465567436, 0.026466193941554854, 0.09637853050870554, 0.011303839556473707, 0.007094178190787456, 0.002081736743483426, 0.016541496318365847, 0.06896226201206446, 0.03071221163762467, 0.04216147227478879, 0.05495084635913372, 0.0033042091818060726, 0.04820238812161343, 0.021328287764585445, 0.06078930092709405, 0.038293150918824334, 0.01699037437460252, 0.05571003205009869, 0.043578792829066515, 0.04626419694562044, 0.012478013024000185, 0.015892128127494028, 0.036788312917841334, 0.055785603887800655, 0.0443485636663224, 0.05048307663361941, 0.01992062445996063, 0.023521504630999904, 0.009775547992571123, 0.04840082908049226, 0.02667972382291087, 0.08067516743072442, 0.02726302814802953, 0.03987033771617072, 0.08428941813430615, 0.03776007345212357, 0.017318831124742116, 0.03426289718065943, 0.012175338908231683, 0.0571267588862351, 0.07657925864415509, 0.010507856063278658, 0.02181045983784965, 0.010061247706679361, 0.07187107378350836, 0.030777724193675176, 0.11475785928113119, 0.030543012145374502, 0.02312498233680214, 0.044741750960903506, 0.01490934648817139, 0.03472993622667023, 0.025014782091602683, 0.040621367416211536, 0.010669814738711076, 0.021731508895754814, 0.02326776985345142, 0.09129894272025142, 0.03201022198689835, 0.0569501972890326, 0.009813798707909882, 0.017647898556398492, 0.021854886918195655, 0.010711120557971299, 0.03248563076236418, 0.07328507969421999, 0.04171623116625207, 0.04615915633205857, 0.03201075802956309, 0.031997991393187215, 0.06458653895450489, 0.0442818467106138, 0.03432474225493414, 0.09696980592395578, 0.12127860795174326, 0.17842908842223032, 0.11338629573583603, 0.07124353745686156, 0.12554049997457437, 0.11905475014022418, 0.31618697781647953, 0.12943655305675097, 0.21277841739356518, 0.17755320827875817, 0.12361198131527219, 0.16534227851246083, 0.11553767243666307, 0.09300080354192428, 0.11755039729177952, 0.11734694535178797, 0.10252284152167183, 0.06743129023483821, 0.2242253710116659, 0.10704110443059887, 0.09767000656574965, 0.10781293801431145, 0.10239196568727493, 0.15099333918520383, 0.07745957640664917, 0.1297073835240943, 0.209524149873427, 0.05900134758225509, 0.1556537076830864, 0.214132284745574, 0.08455438605908837, 0.17503202999276773, 0.20465099279369625, 0.0556906971947423, 0.17002784780093602, 0.1450707327042307, 0.19001307897269726, 0.07576923032424279, 0.10063541494309902, 0.15013746225408145, 0.1552431397140026, 0.14775793493858405, 0.09528885755155768, 0.1475601012685469, 0.22944270819425583, 0.06680132475282465, 0.18358885869383812, 0.10315589433802025, 0.2146946002862283, 0.1492041101945298, 0.11625527750168528, 0.09885242168924638, 0.11960053656782423, 0.15984306431242398, 0.10859997078244175, 0.1285034588405064, 0.16206642000802926, 0.0793070372726236, 0.09240061217652899, 0.14414651372603007, 0.14088398164936475, 0.0631309999153018, 0.17565877921879292, 0.12153087370097637, 0.13868718381438935, 0.11689966863819531, 0.16490983457437583, 0.10836625618061849, 0.18836144331310475, 0.13901776607547486, 0.08751725671546799, 0.18116469734481402, 0.07007705433560268, 0.1493816828089101, 0.0472755533909159, 0.16224157703774317, 0.12234803342393466, 0.11973452009260654, 0.1451584537114416, 0.10035894584975072, 0.11693842655846051, 0.15869311030421937, 0.11797764365162168, 0.10360168505992208, 0.09957386047712394, 0.13176390102931432, 0.1274186170526913, 0.0941051532115255, 0.07940045797399112, 0.09075126317994935, 0.05356345259185348, 0.1438688707670995, 0.12275211459824018, 0.17109222497258866, 0.18127244870577539, 0.19130790020738328, 0.16076289995440415, 0.18664431545351232, 0.07173681205936841, 0.1312847738819463, 0.19878260126071318, 0.08389520964452199, 0.07026779731469494, 0.06981914317501442, 0.14208844916096755, 0.15258367599121161, 0.19217073890779698, 0.1288092067199094, 0.1256832501717976, 0.16617433886442864, 0.16974567222808087, 0.1567833734942334, 0.18317104397075518, 0.10661622615797178, 0.12253982813230582, 0.10396086757204362, 0.17927243959690842, 0.08382673189043999, 0.1346374696918896, 0.09863615900810276, 0.14312333720070974, 0.1239674115287406, 0.22488604698862347, 0.15197192238909857, 0.08805697704000132, 0.15710508051727498, 0.19098346547356673, 0.20368479963924202, 0.06490705854126386, 0.09018702738519226, 0.17529507087809698, 0.10776173576180424, 0.09628755253340517, 0.17342497408390045, 0.17073835538966314, 0.11424509036753859, 0.19055240574691976, 0.1168535825397287, 0.10709403694740363, 0.12630524965269224, 0.08360026404261589, 0.14655753863709314, 0.19719188447509492, 0.2058873243097748, 0.09032661560922861, 0.11954045907727309, 0.23449749552777835, 0.14019593356975488, 0.21396350594503538, 0.1537049686802285, 0.19804028395031179, 0.12724580775414193, 0.11607068883521215, 0.1415542656821864, 0.11259476428053208, 0.1087911683799965, 0.11953935985054288, 0.14675614583705152, 0.08712969786886658, 0.1519259719976357, 0.14386638732893126, 0.15435925285731042, 0.0790099339293582, 0.10710759407707623, 0.08607343597603695, 0.1004382258813296, 0.08643825711416346, 0.18969937866287573, 0.2405404741210597, 0.1147408416228635, 0.10859114982719932, 0.17088425398937293, 0.08853847905993462, 0.10306757621999298, 0.14907280009772095], [0.026774082598941665, 0.01977873091319842, 0.06836483228419508, 0.03233825295631375, 0.005658457887225917, 0.00915589539467224, 0.037553208480988226, 0.045898646382348876, 0.016366785425426703, 0.06112382547663791, 0.04431683876152549, 0.017254741795893227, 0.02790102918100144, 0.004074530692638031, 0.04341049918106624, 0.008573284023441374, 0.006336359747885061, 0.017533438180440238, 0.056597104628703425, 0.024145363297845637, 0.03883045565869127, 0.011581303551793098, 0.03509164967441133, 0.050282823986240795, 0.07986783289483615, 0.024468597024679184, 0.02075820808698024, 0.045240097612674744, 0.03767653222062758, 0.020903499397848333, 0.011461971294400948, 0.029995739726083617, 0.03972715664921062, 0.010341894031236214, 0.03868782759777137, 0.00797510621071394, 0.034052703995257616, 0.05741764006337949, 0.019535016401537826, 0.034035194399101396, 0.0660087890656931, 0.041916717908212116, 0.04701975925958582, 0.04273931269666978, 0.01924060344962137, 0.0331922299893839, 0.0343712999352387, 0.05922915892941611, 0.05553664599678346, 0.05767418736858027, 0.01941477321088314, 0.03869246877729893, 0.04309674458844321, 0.09386663458177022, 0.014733794211809124, 0.019253283572782363, 0.026790930623454706, 0.0420007171508457, 0.021268725960648487, 0.04548921495942133, 0.014261394739151001, 0.06503021943249873, 0.013149140136582511, 0.05407380252810461, 0.040288613843066354, 0.02321149724801736, 0.009586749864476067, 0.011329327028111687, 0.06786216675703015, 0.014614826666989496, 0.027893551725095937, 0.05839083569922617, 0.02392547045435224, 0.005702706852129528, 0.03283054368304355, 0.0434537931079311, 0.09169860663158552, 0.03204811816768987, 0.02982479639883552, 0.002737242283598919, 0.016697885069463934, 0.036744628833340745, 0.048405758637402735, 0.03734836893688355, 0.0770271663953151, 0.05438663770577737, 0.02922494090827448, 0.007111068199654775, 0.021476808902142302, 0.03607316075691155, 0.034454318694770336, 0.026226727059111, 0.10589840396174363, 0.05047902577955808, 0.012393426848575473, 0.03869226182411824, 0.021081258609358753, 0.00786888409805085, 0.0439695815023567, 0.011518500046804547, 0.0570576297385352, 0.025642430376527563, 0.06186836159655026, 0.05389411288446613, 0.03969194746709295, 0.021195400073858242, 0.041753211324768405, 0.02274629194289446, 0.06245068034955433, 0.04899769901697125, 0.04543150894876037, 0.03740308939346245, 0.038659949986530204, 0.02170074581434684, 0.0659210409170815, 0.00396584252926654, 0.04533033937747989, 0.019022854776786904, 0.023152186502037302, 0.05370570745851312, 0.09986969495990447, 0.060610330530575345, 0.01510021329990455, 0.013886525345567082, 0.03960258440513696, 0.030411542592836276, 0.04561236906530602, 0.02000315297794129, 0.038730724581650326, 0.02285734437672155, 0.04228806316054293, 0.03580539048250232, 0.016087731113657355, 0.031196261556552987, 0.011189854155028505, 0.16594010857599123, 0.026109247202319757, 0.003846707471114184, 0.024210653633677533, 0.024693008911396776, 0.041771250178239176, 0.03462283286665167, 0.04897646426356264, 0.027370411403743283, 0.056016173479812484, 0.06444545116807733, 0.017354306631854603, 0.03355821481506739, 0.024612436270607368, 0.007570477967549647, 0.03726381329553468, 0.061819995620421, 0.041868996540350575, 0.02934358614896025, 0.01797542571356254, 0.010318920531842326, 0.062079080646591525, 0.037664053961634636, 0.014544893455292498, 0.04145429968567831, 0.06095047335007361, 0.038807232797678025, 0.03358600760943123, 0.047368312520640235, 0.12161216219621045, 0.021528039992387806, 0.0631725669705442, 0.011629725507061397, 0.04693259804376534, 0.009242013362901551, 0.009339162614196539, 0.09475334414413997, 0.037984027327703576, 0.04426992145766105, 0.03357310865872672, 0.06765543070754834, 0.03513226678062763, 0.012227830377274325, 0.027560599680457796, 0.02559226967527398, 0.03232785779982805, 0.026602805093196884, 0.01225551969504782, 0.02450883754396013, 0.06388523908598082, 0.015542881064383047, 0.05034080141090921, 0.09219057166150638, 0.004237594107897686, 0.019182220600279312, 0.08763019886932202, 0.060365169042987485, 0.018783457444182465, 0.017476956925487945, 0.01831290528311261, 0.02997104444407991, 0.01431424922442862, 0.046444046044988294, 0.015609165454017264, 0.05886205791362694, 0.05054115244586553, 0.01887742436623999, 0.0061827512940258855, 0.005736834619061223, 0.03083130471142275, 0.002685846436569201, 0.048745942169002125, 0.05690314767083951, 0.02104620379395783, 0.010016171777221774, 0.014820073332105364, 0.023027811033119048, 0.06913606875709125, 0.009390191840273994, 0.03958972955920866, 0.021613158817802156, 0.052786601241678, 0.0386678311707718, 0.03414499154314399, 0.025354003799813132, 0.0049506360249194714, 0.0328663126565516, 0.02635111949140472, 0.024853155050160627, 0.06878121529838868, 0.010920739533113582, 0.04777149124337094, 0.015714516497350166, 0.07040238473564386, 0.038071144438747845, 0.002893711398688278, 0.007539866708352098, 0.034728212747722864, 0.011963271269840854, 0.013897509131181453, 0.08138937982065336, 0.03491126453237874, 0.042752438956605535, 0.050371087821466584, 0.00426247768336907, 0.031648925838193724, 0.06274457422218152, 0.029397607714469944, 0.019864378995927315, 0.09429349417665175, 0.06541013797479016, 0.008665221277624369, 0.06098433903285435, 0.015770030839900886, 0.04583305240209613, 0.007865423569455743, 0.040293892845511436, 0.013294260117358394, 0.032542719306158166, 0.0038732297086556044, 0.051772995452795706, 0.010809837225159364, 0.02819658546442432, 0.04687395904745374, 0.004123967481843595, 0.004921919998845884, 0.04330591657864196, 0.02448483436767544, 0.029362239076622894, 0.018221428584573523, 0.01080599332427872, 0.030341321003756354, 0.011359629553875752, 0.0403547574366842, 0.03877271572127938, 0.04619465728423425, 0.026645276296351637, 0.044373618571885994, 0.021996892423235943, 0.07565805914678744, 0.03173806159091847, 0.028434705454856157, 0.04648850026673504, 0.055918522112603695, 0.0772336038893887, 0.06983709042625767, 0.04073236556723714, 0.014497703041083046, 0.022600527353850857, 0.058361828327178955, 0.025072946113401225, 0.05168225157207676, 0.050182176886924675, 0.052187129123402495, 0.033379135852945704, 0.04744189285806247, 0.03836532329608287, 0.044225813288773806, 0.028199023101478815, 0.035687749473644156, 0.059411399864724705, 0.08223115679408823, 0.06045791120933635, 0.12049674562045506, 0.02146610331588558, 0.03710650173681123, 0.04449739692998784, 0.04020587667556746, 0.057099027160022936, 0.05426479995782886, 0.03302094739462648, 0.009225187390776617, 0.03365185943299106, 0.030572002554046254, 0.06803352399063961, 0.02977592491411737, 0.03141380327620676, 0.04387079019631658, 0.06927398778498173, 0.013726251981487232, 0.04828198027930089, 0.01031845573535455, 0.03236384729721716, 0.051676484024418254, 0.06326771115085908, 0.07260860742202827, 0.0255997149007661, 0.02750752636763666, 0.03693983318018062, 0.011101832896071886, 0.04658960198451366, 0.066383557527193, 0.03411824369270887, 0.00417520832602999, 0.017702759808993766, 0.02873215824365616, 0.05976174785090344, 0.02098545285740069, 0.008115344980199422, 0.06253447263900723, 0.02790339557187898, 0.017248558645535792, 0.030228341530476297, 0.04642143386549183, 0.03215385767232094, 0.07277490278439862, 0.03957007918506861, 0.06475601664611272, 0.030382063638951098, 0.03296446613967419, 0.04002705555675285, 0.02343618224507996, 0.042773731385490725, 0.04402029520965048, 0.05151618691161275, 0.023891085692282234, 0.01877724375974919, 0.1539133603551558, 0.15295003061848028, 0.11890465819409915, 0.14608100349349634, 0.10961598197796515, 0.12055621242948941, 0.091665840175535, 0.14671649225056171, 0.20250401299979004, 0.16033828631043434, 0.11656219246132032, 0.15181739282395157, 0.07220042789621012, 0.11533567256161145, 0.1445137775902237, 0.07656998307045017, 0.08111544166292463, 0.10136741173586675, 0.12755070067942142, 0.17169130354055337, 0.0718609636117305, 0.11314705785896097, 0.1544208095542022, 0.1340329899851765, 0.22465862919177326, 0.1263406284685646, 0.12745224524821552, 0.1786191732223545, 0.07958819504295077, 0.12962754709380014, 0.09691914649946348, 0.20385152926402433, 0.15740477586431162, 0.05955727132303374, 0.07421655221176998, 0.08668267221323081, 0.10864902207893984, 0.12359258878443923, 0.1680277029850653, 0.16671879536339215, 0.11848617850669793, 0.11665064628635134, 0.1347384357026645, 0.10394881679011242, 0.08826536871492863, 0.16263530376766408, 0.0984783521188157, 0.08734175363289458, 0.1730610757533993, 0.1561576420707362, 0.1906028344695057, 0.21810186388237135, 0.19580170192888804, 0.16996610111423902, 0.07947357012225048, 0.08007857230092798, 0.08277369303894894, 0.1327590269169637, 0.1605436245777777, 0.20209803192743234, 0.09476905222982168, 0.14173863721745356, 0.138382331601211, 0.2028451668364661, 0.1830478220113686, 0.13243038526603154, 0.1199079943554742, 0.10931819331433092, 0.26135912271482603, 0.13377885147929192, 0.060005884750613143, 0.16737824997731618, 0.08392336884779589, 0.12711637041398458, 0.15513994810836657, 0.20897152381283896, 0.1575006257210459, 0.121962503397039, 0.08144212234765291, 0.10165773651429585, 0.10662100304450307, 0.10167826219860997, 0.11745362462741987, 0.17980910651385784, 0.17095491662621498, 0.18656945947025502, 0.1464770779545818, 0.0736181250374232, 0.10211483162960835, 0.1422691023243325, 0.10620644528950964, 0.07289332750120334, 0.22346431256404944, 0.1251420777823244, 0.07508533487894706, 0.11419667010860783, 0.10212842268603188, 0.04108959050582988, 0.15645843664450304, 0.08275116567632981, 0.1333398800343275, 0.11673497461846896, 0.16348389323268617, 0.2133520237569298, 0.15319118196410791, 0.1043446334078908, 0.10357752921325819, 0.09811128502977745, 0.16511258083794797, 0.10026745218783617, 0.14376738906971046, 0.11842354972447668, 0.13525223598948546, 0.12508662790060043, 0.13293350541165896, 0.08660276792943478, 0.13692516407796315, 0.07192650330918175, 0.16961270650582655, 0.1277487650513649, 0.16261745829667362, 0.11123070533254317, 0.13078075807009423, 0.06365415720002991, 0.08022901029991251, 0.12603209859558515, 0.11421462414520127, 0.12696470426661627, 0.1501252350530454, 0.12150944556508746, 0.08859342682574477, 0.19079750616635593, 0.0923194797443492, 0.09701366642756121, 0.096098668740264, 0.28006755454199656, 0.09483583364635706, 0.11909080749111516, 0.08819768484681845, 0.09913281950035266, 0.14003554146204675, 0.18337631438459667, 0.17201781459152699, 0.09675287827849388, 0.2294620600129877, 0.1835868638008833, 0.1110553786690746, 0.08084264344402722, 0.08429284473615033, 0.10792851966938802, 0.11508097765701157, 0.18418922647833824, 0.1959700464670147, 0.0967375026749713, 0.1679084708115884, 0.11291682414178338, 0.10890624791915927, 0.13110988826623984, 0.10729491045432431, 0.13835524448326655, 0.14342159405350685, 0.21126565071088926, 0.06882723354335342, 0.15241824915366514, 0.2205702250025102, 0.09620070005101816, 0.1889399622700044, 0.16710159767951283, 0.09902851509728602, 0.08645026039864336, 0.03813704715243407, 0.2353094033896923, 0.123500525153109, 0.11531750139381204, 0.11645445467105933, 0.12993566984576838], [0.010916272228184556, 0.04780646972358227, 0.01467567599112434, 0.065414534881711, 0.007693397978852902, 0.00859305398937847, 0.07667551562190056, 0.042831142233418565, 0.11332944807197366, 0.012786763420860683, 0.00866363350568073, 0.03542788413220218, 0.076906326093844, 0.03403053625619837, 0.022533006334145154, 0.07937558288020746, 0.026898003449397426, 0.06357206803347383, 0.08837575279176235, 0.033672710814114125, 0.028243345008896928, 0.0680331779377801, 0.058964937393154414, 0.032833396922796965, 0.02567074733919331, 0.01949347648769617, 0.02939111752701657, 0.01177005163793053, 0.039859755962554894, 0.04498666139053447, 0.0073561168807957855, 0.010292261739128401, 0.04696281999349594, 0.0348096233792603, 0.06353917944111995, 0.051959887745657136, 0.07094306857990366, 0.007067440094293228, 0.031366930077118535, 0.034830451011657715, 0.040141178361539326, 0.04192088750590171, 0.017155816479186927, 0.027601389813103845, 0.06608958901571375, 0.10162079706788063, 0.056123840023896525, 0.020264268520155122, 0.01082778871724648, 0.046754370643092055, 0.006337105288236801, 0.02448321775799351, 0.047590129010911496, 0.037533100095710585, 0.041347522022468705, 0.018063302783827697, 0.050380499102175236, 0.04124097506116543, 0.04290637480361121, 0.022119150862896016, 0.01820857373864523, 0.03556013060733676, 0.03474276393119778, 0.00713210363340165, 0.0265432314148971, 0.04596675094217062, 0.07090892469776527, 0.08344183968646185, 0.0027983944039858344, 0.03991543993886028, 0.025529615447989533, 0.055676990787365606, 0.04714792434658323, 0.02606916444243065, 0.05712641283337559, 0.024832933010267358, 0.09092969074845314, 0.011216959932685962, 0.06725655389683587, 0.019418410158583095, 0.031933673058769534, 0.07266711749668632, 0.019842808367684484, 0.07397861033678055, 0.06805163409028735, 0.04369383844147835, 0.0055010445482496706, 0.031323391877646954, 0.0808688620371478, 0.021622958559808985, 0.06560167483985424, 0.08433494104870728, 0.015513812624184149, 0.06109546949820859, 0.04883013140144093, 0.05717237001018865, 0.06939154397696257, 0.012329609781902815, 0.08462588329400335, 0.05854333644466741, 0.03184329897963575, 0.01533550549564617, 0.08052928918706519, 0.03995543618553451, 0.05160027775647385, 0.061147723479994705, 0.006412792052807552, 0.007128146077905382, 0.04122602354202952, 0.022785794555342624, 0.049842634570917914, 0.08381494573716607, 0.035760176301534684, 0.03870715906045266, 0.01891535277744489, 0.04324208000408752, 0.02954152159925018, 0.038202997363571606, 0.04647561149405582, 0.051169258741928, 0.03208101015271885, 0.06785399719540562, 0.02836906397715211, 0.003715135290154389, 0.028478650775338923, 0.014212991443595715, 0.007659349939785898, 0.04038728301280311, 0.03157510801351496, 0.006940132930010025, 0.07583227979817561, 0.03318108165902751, 0.07129691102142845, 0.037762227800807784, 0.055114430974104574, 0.06827152693378073, 0.07859161030501127, 0.015006346461762275, 0.026091842779091427, 0.028050875158182213, 0.05111351709014603, 0.03927688420351062, 0.02485571991253112, 0.034569123427250555, 0.0035519151757138646, 0.04856871560748134, 0.016123941134927527, 0.05401443410664797, 0.031012198754719326, 0.01860905358833926, 0.023264499314661537, 0.04698550681184445, 0.03698586838852082, 0.03452278966350215, 0.05045089032500982, 0.01761487595337842, 0.069217017984816, 0.022037611309705035, 0.06941440382174083, 0.019929277477785945, 0.0443127200539623, 0.029625262998576676, 0.06817949722920146, 0.0317371421759682, 0.06324026440935475, 0.008925782117460455, 0.04223739016535027, 0.0387569431747709, 0.02569980390502938, 0.008396380614223225, 0.05313675584537642, 0.02909545267799071, 0.025938587163441947, 0.01196931192784437, 0.02423062631195145, 0.014271024847403169, 0.05828258900770119, 0.0343658784404397, 0.02367741840758494, 0.025914607735882913, 0.009319970251194068, 0.01602141449360975, 0.042481313326529095, 0.014458751738337534, 0.06691421262387719, 0.007962587239619876, 0.014469235104375651, 0.05156220854925258, 0.039589960261115005, 0.047028078098914454, 0.02586920865412269, 0.057883528992533684, 0.058168296569160054, 0.030226821612034525, 0.06020829853202615, 0.03056103064279471, 0.017682546250788227, 0.03339472858767424, 0.1578254947172744, 0.04142605566552707, 0.012689099331120295, 0.01281669020785817, 0.04417249061433332, 0.046215603660259924, 0.06554831484598772, 0.030774989697550024, 0.03776529138641698, 0.017456120811402798, 0.012177902074264628, 0.07040267650570188, 0.041445716217692406, 0.04028396248551352, 0.025740063084023337, 0.04011586221999355, 0.02328450252701129, 0.0144796031194606, 0.014085773761118097, 0.0735819251941783, 0.05634802799405796, 0.05281532023634229, 0.04769399236621601, 0.08349058564220156, 0.024519532952191572, 0.03757555603182741, 0.011926661761078452, 0.05908680906785386, 0.007003650593105704, 0.07266468155596938, 0.05113207163023097, 0.0862666963200484, 0.004425890544163329, 0.08803461252578668, 0.004901061408288244, 0.05091490989018764, 0.03329210355877876, 0.030705382182661976, 0.011917600774073174, 0.025829337936426913, 0.020956496375479867, 0.05849189670490367, 0.04846108638282333, 0.022994700220546553, 0.04638551561427968, 0.03748181302632604, 0.021495487274868146, 0.023323072153808813, 0.012272640829905868, 0.0320469985849091, 0.026886717715699757, 0.03548221782382045, 0.07943724135735206, 0.009319234040698834, 0.023736613802611828, 0.020926254069698707, 0.051872967409768274, 0.02996136514203889, 0.028617590998432467, 0.0844299630927188, 0.06268263754567929, 0.049853508094591756, 0.03927353563319359, 0.02388454631104001, 0.025954829595450844, 0.05018448390598808, 0.016032021692288772, 0.06153393204190901, 0.038242393106754334, 0.08978050348481961, 0.053033119799303155, 0.02643751905166677, 0.020524903998843262, 0.036354671365448406, 0.07212226066206183, 0.03878838988021016, 0.09749526344239712, 0.021063243504613638, 0.023811556299083998, 0.04896255090300526, 0.03956254066101142, 0.020757497321548204, 0.04209082320864711, 0.053336523340216706, 0.05142157198861241, 0.04176731467513101, 0.01655564207716712, 0.038582295046320984, 0.04086230502330831, 0.041983651995126686, 0.007234625185706786, 0.05693989712744951, 0.04400047520175576, 0.014234087097325494, 0.10441669382687126, 0.020871592984933938, 0.01631396317056247, 0.02186142121042524, 0.042186052205839326, 0.01942594868264028, 0.0138300373052646, 0.018926611369741813, 0.01911698454724891, 0.04407038127205201, 0.02616224587628884, 0.01580786255986563, 0.020785741341699446, 0.04380608509693827, 0.03116405149921775, 0.03318972619516509, 0.06516431830823421, 0.02980988219912563, 0.021601230172174316, 0.01676251892266529, 0.04432349179738334, 0.046097596242491684, 0.06415862763034445, 0.0289112609545035, 0.03518635280696409, 0.02381893027839916, 0.02304639441094228, 0.011256515131598073, 0.0606576447774257, 0.022702663837532912, 0.03678972087800503, 0.038319450936147144, 0.024794870588396276, 0.04987249011173844, 0.048480105719396045, 0.050079738455159326, 0.02431543979660741, 0.04296575679576822, 0.06357984404478755, 0.03455625840329698, 0.020390715217217803, 0.02738903379733009, 0.02898578784827675, 0.0066642176908706975, 0.04104930588177272, 0.03380428893225534, 0.07532430134181466, 0.03866745797651155, 0.03623148672548788, 0.024032836746690527, 0.018678355762468915, 0.03235884988680482, 0.022625173442065716, 0.030165288663868393, 0.026528405424739634, 0.06612880833979164, 0.022210922724168216, 0.029162468189107518, 0.07165390186543975, 0.037226595649761815, 0.164632435888052, 0.11373144614377192, 0.07784149662724563, 0.10736697765865497, 0.0751480111586196, 0.08929373603314161, 0.19195888670427458, 0.07001217960246972, 0.1793699993618897, 0.09859846638781683, 0.08097773298088994, 0.15268358348735742, 0.17663661603416714, 0.1229085847735405, 0.10081337432243995, 0.16379316949418612, 0.17781258507498673, 0.13470910941915853, 0.21192539030952112, 0.11207664851099253, 0.1146386271076543, 0.10787091204630476, 0.30000389048031395, 0.10865498640175376, 0.11026348080486059, 0.13417412526905537, 0.16827443188854627, 0.12410522199102811, 0.18539441323706082, 0.17952036272202218, 0.06880875024944544, 0.08560737062777792, 0.12362696336848394, 0.12481475248932838, 0.12096972524055413, 0.19951442841972622, 0.16233977462564195, 0.11007599479385785, 0.1009563212948186, 0.14516137141202176, 0.12347365516637053, 0.17570736232612813, 0.13201016852898256, 0.13072386969413075, 0.13668805680104665, 0.2512279434927872, 0.1279732244355338, 0.11106012162885495, 0.05535330922741975, 0.11024738595421825, 0.09304509830794164, 0.12838706294340746, 0.10750097475413765, 0.1505423848118101, 0.08316297536449772, 0.17793868402285234, 0.10472839245838778, 0.1322178409567901, 0.20320685314280645, 0.12808690619255814, 0.12685947705592426, 0.12087593813027654, 0.10850499623588153, 0.10213237175984041, 0.12520937488547393, 0.13940523671252386, 0.10992352118981735, 0.09929436511759247, 0.1110799755635006, 0.1276802872972829, 0.1121669818780252, 0.09754451151405062, 0.1454623695462942, 0.09433265921792813, 0.1561695978577648, 0.12518239633313247, 0.12601472809910774, 0.07514845899173192, 0.07607843194689069, 0.1297857000359467, 0.09351955034903117, 0.25221325776406694, 0.09827327848012958, 0.11239518677549702, 0.15446712635457516, 0.12566112993018969, 0.09311392890023333, 0.28201858699321747, 0.13231020314352854, 0.09348938946745225, 0.13557141886225768, 0.19211953665528977, 0.14226110918181284, 0.13542930648795196, 0.12585348103727612, 0.16586544258253916, 0.18019102673445428, 0.13712150497095926, 0.11549181704010282, 0.150333491020969, 0.10075873189738818, 0.1279541847429105, 0.19936703704297543, 0.08141156791576318, 0.13383172292794498, 0.13011336459645204, 0.0984047514253429, 0.12463302724063396, 0.13298349987183297, 0.11598528841776506, 0.1716633750391858, 0.2095607364816325, 0.1822315715253353, 0.14996643071728094, 0.11545438904847417, 0.13035272460963043, 0.16946998345000402, 0.13964181473212584, 0.09674525154488427, 0.1024252681859902, 0.10423317046037742, 0.10710318359945502, 0.09268284203218562, 0.08192375328923975, 0.16348837156380924, 0.1403681728988886, 0.11209422256797552, 0.06710737797298602, 0.09656966703810863, 0.13967164313154562, 0.13429867715707847, 0.08743329479226045, 0.14648684885885033, 0.17071893571742944, 0.16533203263367924, 0.18935434360589298, 0.14701898316187517, 0.09364607677395854, 0.09803222212940454, 0.09109574862356697, 0.12414939462074212, 0.1361735508378063, 0.11273329398993935, 0.14975677696721895, 0.13496832336698258, 0.10443426788385425, 0.11988839826413564, 0.15049981352474007, 0.09275286006075995, 0.0641865697024124, 0.13131879562778132, 0.16844430991581508, 0.07014374754258565, 0.08972747597311224, 0.19704348886651651, 0.12171870576483862, 0.14740929007530212, 0.11863774965916361, 0.13085025362670422, 0.16154622792133264, 0.17763026271547588, 0.13201303194676126, 0.17458617820271424, 0.14468224426465376, 0.14885013204600128, 0.08504210345979248, 0.11824494573686804, 0.06724872360272066, 0.1143687330186367, 0.13941327056714467, 0.14995800331234932, 0.14462560016129697, 0.11478192013289247, 0.11975153775087424, 0.17523575334676675, 0.07464071123727731], [0.02317760103116078, 0.018664466150637184, 0.04666944180748292, 0.032044871377625635, 0.055739056385521374, 0.04925836842241032, 0.024564309478072182, 0.04971002847222345, 0.01233627469212349, 0.07739000621118716, 0.008656465631377484, 0.02578057671364929, 0.046656522500727854, 0.03913363867572375, 0.012130933032105011, 0.019420530580516373, 0.019857110189540044, 0.030685565567442348, 0.030565573434744562, 0.09584020118096045, 0.0205908508173057, 0.018579874886199832, 0.03692741259666426, 0.03782157586621387, 0.03034918861729758, 0.02816156287943678, 0.02698735972600324, 0.05682676498379026, 0.0379406892960625, 0.017698376472773295, 0.05298129668725388, 0.035021082032471895, 0.021993016291941916, 0.009594539446490151, 0.031027065456977913, 0.022630710287817886, 0.02150785018290792, 0.037619246901678186, 0.040920930448919535, 0.02252695380177881, 0.01562538244096296, 0.03576110928718533, 0.009610952360422483, 0.03643458582726972, 0.0592733451298305, 0.05446254202563848, 0.060750224095370085, 0.015810620804716433, 0.018866613607055376, 0.04053990250187261, 0.03263820614665747, 0.052142980242414136, 0.01413065121908273, 0.0489669987000525, 0.033872529199080806, 0.008043301524594426, 0.039187337937099595, 0.033449082635343075, 0.017161054769530892, 0.03016801637464336, 0.060951966127114635, 0.02047825980532382, 0.061904615722596645, 0.007750957256316074, 0.03802977415866085, 0.03725640708580613, 0.019174955186567137, 0.027244996079908948, 0.05893227271735668, 0.030682349311453954, 0.01535244851506182, 0.035360434358673434, 0.005477171989956072, 0.02750672908898975, 0.051521381097180505, 0.054882161651871035, 0.12721052393317223, 0.02320601129239159, 0.11184830112116677, 0.031484669473554404, 0.10780117221708808, 0.0131661645802004, 0.049312759789505174, 0.03942562586494854, 0.036320826038718224, 0.07149143344057457, 0.009041135615137006, 0.018197747712422694, 0.07078610985938992, 0.02906579730500068, 0.04282978177070618, 0.07248934132180043, 0.052236848776893954, 0.0690785086314593, 0.020251907308452895, 0.03845769566084657, 0.029269157642764703, 0.023206657596996853, 0.029029146235968386, 0.044052522230361185, 0.03298839806978192, 0.04262576664664915, 0.03554982366040349, 0.03048404066690377, 0.052924428667340956, 0.005738552160827177, 0.04721342333193336, 0.025910414389467666, 0.06088707782328129, 0.02072591151643012, 0.02764805605901139, 0.05644047839034881, 0.024159344511904886, 0.06647150245096002, 0.029515815300068686, 0.03776961365448577, 0.057518321089446545, 0.03098777149404798, 0.019971012470445464, 0.040108720638922284, 0.09007743040898017, 0.02746406789602978, 0.06257907953113317, 0.023966801718675664, 0.018312099522777965, 0.04168495748724256, 0.12823104060121945, 0.01541114688318755, 0.02428707024747772, 0.04370723272274647, 0.028625923408461467, 0.017563744947048168, 0.05686729048777904, 0.021832829441076944, 0.02570070296392909, 0.035858455313635726, 0.0407792726930763, 0.013807483649413501, 0.013715325023180671, 0.04740727400141103, 0.034737529033528905, 0.02044898271560669, 0.013779634875910622, 0.0226434565681432, 0.013440157020730632, 0.05816092767885753, 0.04532065668276378, 0.030562628592763628, 0.041253158157425265, 0.03394023681591664, 0.012572285286816103, 0.042847081021006615, 0.023957763632227267, 0.03475254840616669, 0.019795807943280255, 0.05056756781414151, 0.024616797554439733, 0.03210062660010798, 0.009949954392920648, 0.037340616674295495, 0.05341706205425518, 0.057908112316259315, 0.03836803404348237, 0.01625428262299725, 0.042845208264355145, 0.0277698429168335, 0.03318782290443778, 0.02011531312018633, 0.039605529247117896, 0.08011270939771618, 0.078539132406669, 0.03251334891787597, 0.030133397517991916, 0.04694910001541887, 0.021695127544392432, 0.04698326086093273, 0.035391416267624924, 0.038835256293948205, 0.073555170558393, 0.0157913351431489, 0.04276436760223337, 0.012178551771544983, 0.03650439011731318, 0.05268301947840622, 0.05250676322196211, 0.011659650597721338, 0.037678883344467194, 0.0984509325187121, 0.018767873191141655, 0.014719662023708224, 0.04014033358544111, 0.027157040978116647, 0.038335393116410287, 0.03208733409909265, 0.04449213489091822, 0.04238906988341894, 0.06310600947056498, 0.019516526322279657, 0.04958823143637606, 0.0547342308397804, 0.0369252819967057, 0.02928918121116502, 0.01942444233489888, 0.018438481759013872, 0.03169778035953641, 0.03154384111985564, 0.03954843391797372, 0.03266227039109383, 0.05322979995980859, 0.03101101131843669, 0.02164796257524618, 0.031563393106417995, 0.009239148248785307, 0.014432962318616254, 0.016223219289843525, 0.03622898632394416, 0.03674561610179288, 0.040661102426903586, 0.01595966950325029, 0.010098221079845513, 0.050644947947668176, 0.0652924935732569, 0.01929486759140023, 0.043189652995871644, 0.04987793874793819, 0.030381110297249894, 0.05696087743022612, 0.036512128809200864, 0.03842584861974631, 0.05438972843278732, 0.04418410713385258, 0.020263932645320892, 0.06631252848144088, 0.053404037574572225, 0.06334962389831032, 0.03864528005942702, 0.020020038321880356, 0.026817218766414692, 0.06335723706121955, 0.026250384182536175, 0.08168749418109655, 0.07427825818636588, 0.015346777658643467, 0.03499084651204092, 0.03698700832735215, 0.030616280356688157, 0.04059666195618255, 0.009485699036823851, 0.05963741309408631, 0.03645036515912839, 0.0270506585615554, 0.02400200072276805, 0.0258248511236161, 0.04215133496161018, 0.08390415273606777, 0.012740604379879577, 0.019408705411478877, 0.007890527668808187, 0.02982604151059474, 0.015576712820412857, 0.032873688332204304, 0.031245258570249592, 0.03438289270603231, 0.031062909069338014, 0.012982873611950448, 0.023910965071991086, 0.03130719863942691, 0.02271533208633108, 0.07434419143412795, 0.06773233586656195, 0.014471823715471795, 0.03150205693340727, 0.0747092839862619, 0.0308259578554758, 0.022185743985963718, 0.034546748735010624, 0.029258745522903543, 0.03465983338121857, 0.05614066429968391, 0.007986475913120168, 0.016178361339760677, 0.12900628043072565, 0.00552843658286812, 0.04231931309082678, 0.03345532515751464, 0.020349511178210378, 0.012943702633492649, 0.04808936454355717, 0.037685736548155546, 0.048259296853627474, 0.02565828095456319, 0.03350255798016276, 0.05396314025191324, 0.020344057452997992, 0.020008009592337266, 0.02084228875381606, 0.020114118898553506, 0.07442575134336948, 0.07210046611726284, 0.00665212789317593, 0.03042218541460378, 0.0063624672308963326, 0.0572387103789619, 0.005741152646286147, 0.042245132249913046, 0.0722783033603004, 0.04015514600489821, 0.01133467473222741, 0.025007509892540317, 0.027504303326298083, 0.023965502324114953, 0.042000411810087304, 0.03207235543855599, 0.02599544670166714, 0.07853630970099143, 0.01395002774162484, 0.029854363562273126, 0.04013394857091563, 0.040667073535067697, 0.012694115401245654, 0.022342611104249954, 0.01305449043866247, 0.027117367035576274, 0.07918740476348571, 0.06394289420651537, 0.03526874392160347, 0.02314886507312102, 0.08879835797207696, 0.017996443335765173, 0.041313432423131805, 0.010535233254943575, 0.04257115814834833, 0.03600181958505085, 0.04610247151660068, 0.012027468316123953, 0.01010548903806401, 0.07135848807437079, 0.02340037255947079, 0.05066684427271996, 0.015661100524344614, 0.04557525659246104, 0.039413025469652245, 0.042058406198131185, 0.017757636328626956, 0.07490491241748844, 0.04844762424805334, 0.03699924570641347, 0.030819586411650692, 0.060747604950198104, 0.04370908512334738, 0.06020394912255662, 0.018011362624487708, 0.12602626319442475, 0.12195269178066935, 0.1514002023530858, 0.07797172106802464, 0.10459167443748031, 0.13060535676777363, 0.06155787754271712, 0.10163763830704348, 0.13691190550369875, 0.1816748742546354, 0.07996683115405695, 0.13103250813271317, 0.1007542060688138, 0.14360341429710388, 0.1500258839556149, 0.09669115873319761, 0.10020733398518392, 0.10281839101974453, 0.17612201507602418, 0.2805442932460989, 0.1365219107163804, 0.07129976765385695, 0.11544795653649739, 0.1341954448393413, 0.06152864625411374, 0.08445922152272292, 0.08641336166432925, 0.13668051149163926, 0.10818135538803679, 0.10417916585824319, 0.20114866644144058, 0.09793312887528113, 0.16133133588092669, 0.10276792158505746, 0.10192100131618125, 0.12307216599583626, 0.11629839161677019, 0.17364215957266943, 0.10884124426437275, 0.14901352327849182, 0.12283139462981905, 0.1374030698622976, 0.13221249410084315, 0.08958340941795281, 0.13926532279167855, 0.12130667216011456, 0.08417695774031536, 0.12237237926040377, 0.12238495929964952, 0.11952862542654787, 0.15519177461309092, 0.17607332340308599, 0.10115325251328093, 0.12100453408701078, 0.22536699260984147, 0.10797013422208172, 0.08413760270923376, 0.10865810766283955, 0.16156719465340885, 0.0998927651505385, 0.19384271704724856, 0.10129261003541094, 0.2198437854115452, 0.0825643174882446, 0.2236099668911525, 0.2409144283405372, 0.08785486181399652, 0.13087442304406846, 0.12828517412500723, 0.13275505070175442, 0.16100802751524107, 0.10668205084013087, 0.11151577146457774, 0.11092664700533662, 0.17629111957337174, 0.13491104144070828, 0.23875014590365545, 0.10543315964085714, 0.19052789706204618, 0.0544676513943289, 0.21985157499355928, 0.11267965579671518, 0.20229103442813667, 0.08148363512009382, 0.13445461807506426, 0.11151727781231914, 0.09861574867474181, 0.09992812361036028, 0.11607476004532405, 0.1061761894130281, 0.1717841135604041, 0.10661607688026768, 0.19118105487099715, 0.1642119205955948, 0.12670810946396419, 0.08111578771578414, 0.1905919507678066, 0.09114702551492623, 0.1339798199811152, 0.11118371678250176, 0.14132017110075268, 0.07965032170925822, 0.10149020621819155, 0.11381280249250786, 0.12428096256085805, 0.18947481071310385, 0.14745872813676084, 0.14321096321301802, 0.10222910371209894, 0.10059888261769499, 0.0842274950285043, 0.11701826298875467, 0.10192414971866778, 0.14394743155155862, 0.10254965044025864, 0.09778674173035792, 0.06148294013525758, 0.06714331997292382, 0.10616990617875542, 0.09547046744929892, 0.18844904218401226, 0.13355375427220548, 0.17145677469670773, 0.10056971918259348, 0.09803026116320065, 0.07871589756437711, 0.24493778816291265, 0.0826314449576395, 0.12411746276276452, 0.1990867613681725, 0.08849054056086711, 0.12066737003624439, 0.13574193471244403, 0.06135241035372019, 0.08247418768171753, 0.14354237328682626, 0.17420101458472864, 0.11837054256881986, 0.10951536880539996, 0.09992082935890981, 0.09282631147652864, 0.10222172125109605, 0.13566574880055018, 0.1230221443942615, 0.07254913382764373, 0.1272297129034996, 0.12172707888696875, 0.20172170283538954, 0.20429584756493568, 0.08635797285075698, 0.11149575468152761, 0.1191931034305266, 0.0960286914237908, 0.12974034675530025, 0.09837779322905199, 0.17359620918120655, 0.08649374770798854, 0.08300875114010912, 0.13341837296528475, 0.08251621614077262, 0.14365395158529282, 0.1327953285404614, 0.20251457100468023, 0.09899154850947005, 0.1711378496672426, 0.1352651281548398, 0.0969813953020743, 0.09866428428462573, 0.19425557846469538, 0.184253402320402, 0.07745102008006402, 0.1771013718098402, 0.1596490168677909, 0.09051509906670877, 0.12296665380043642, 0.1559865969632353], [0.05815410840192011, 0.014424375457955258, 0.003263847162348351, 0.023436952382326126, 0.04417152709460684, 0.03438775101676583, 0.001011446987312021, 0.043964970856904984, 0.04522977370236601, 0.011300676735118032, 0.04400133354855435, 0.0026064213681300835, 0.005504938915172326, 0.06426283025315829, 0.0445487722089248, 0.0067015930960354, 0.06878972412752253, 0.03065965910043035, 0.055718238931149244, 0.01755053556657263, 0.010213460922906441, 0.014634217501484921, 0.01719816045702568, 0.01713536543372486, 0.030122764874249697, 0.020240999858028123, 0.013044044392050376, 0.04659229916121278, 0.02329231076873839, 0.047729520459792445, 0.015377376195309418, 0.026794854252200042, 0.03229388355144432, 0.062396065065903325, 0.033968928669180186, 0.03628570845882807, 0.03584250634802239, 0.07146848538624388, 0.010836127064456897, 0.05298832291737199, 0.019930481877444044, 0.017406406246923974, 0.02245608251541853, 0.040123991069516966, 0.03215576774839844, 0.01633405119978956, 0.08434446089501892, 0.007737627435874726, 0.03404045304549592, 0.013817453025174993, 0.018511015456169844, 0.014873295922630599, 0.00877904552700264, 0.07452612024332796, 0.07854825191731964, 0.05485306607027139, 0.019439644911991696, 0.03249270788260868, 0.11636891854660851, 0.02252266206778586, 0.006861525920352766, 0.051987761964223216, 0.011758341819846203, 0.01520452618465892, 0.1311349669205291, 0.018794069731874124, 0.10419062631470816, 0.029906966989593844, 0.08062247918652636, 0.04868880273508174, 0.047581918737185855, 0.05006547564906733, 0.06341890232371432, 0.03657813330313989, 0.04387808444776705, 0.020665535470470786, 0.09063716751656362, 0.03538430182795439, 0.045535643718072345, 0.014013717582981502, 0.05949948049549546, 0.04323662458253758, 0.038527445668088536, 0.05214926686936191, 0.004727568909791964, 0.030464515821742158, 0.048523131624928544, 0.04795470926910639, 0.012705189092749996, 0.01906737176302288, 0.015588168187865188, 0.13763487099536828, 0.023630833585879633, 0.05448432299973709, 0.01101834764371493, 0.03791045716830662, 0.0448623910945441, 0.0218998720935945, 0.022089461563155055, 0.04362783734021442, 0.0792740061879158, 0.07557832449674606, 0.012940447361740683, 0.03390857297927141, 0.03467618946784309, 0.01766010031237134, 0.044122302771678994, 0.05775028507092169, 0.01886490369880838, 0.011769582600598889, 0.07757666440946714, 0.04892162845603057, 0.021966902871749232, 0.012806513030747218, 0.022544502413698604, 0.004483446853035795, 0.020477057102003267, 0.03640320358265724, 0.06795930583029985, 0.03797168477571436, 0.015362852153235247, 0.038905616982706955, 0.06138908517147813, 0.019880353406603848, 0.04848485207185149, 0.024607252263064896, 0.009141852264292538, 0.06602652597108058, 0.03800476675054856, 0.04796089072312627, 0.008028487408799785, 0.03909184431125011, 0.029661849606782198, 0.014629633997433951, 0.05860312216516052, 0.029878220853528807, 0.023256363679787943, 0.00919544041555907, 0.0814094983839563, 0.07329584804496594, 0.02982278454250523, 0.06114215949284179, 0.048441826166318994, 0.04530244819553835, 0.03759882978296705, 0.033291713401143036, 0.05386374844238162, 0.01404589371356581, 0.04218081391549536, 0.02585778890975884, 0.03909956603976233, 0.01946874218992889, 0.0384461334241288, 0.05637905400778566, 0.055452086962759495, 0.1315244867333344, 0.049856140810464106, 0.02258869879213827, 0.02177213448365884, 0.03428185544908047, 0.06047834189874785, 0.030514364396887164, 0.061680644883641174, 0.05127744097262621, 0.04603028556864176, 0.05687218611793859, 0.0009308104158013261, 0.04463464420820985, 0.07040933293423482, 0.019023170295570577, 0.05985210835933685, 0.024913551452170526, 0.044258437252470424, 0.01103912353781717, 0.03427593183836766, 0.04169927118346095, 0.01084100064222834, 0.011812310798891952, 0.031474986778838296, 0.008314907218196561, 0.012031652332682694, 0.04089467114369784, 0.015962429444438646, 0.05947489717176982, 0.05879630108496972, 0.09204360097646713, 0.020037692106728042, 0.0032146086325935486, 0.03548758503581796, 0.016672083775379827, 0.033614434834037504, 0.11289582348295621, 0.042847678131823025, 0.06299299946320908, 0.0024411393554016414, 0.05147633654996753, 0.03263443009927869, 0.01465321478566953, 0.02929013455286622, 0.010000686759927442, 0.07345152433429446, 0.010229194453651351, 0.07083161241774048, 0.04863995839176433, 0.024266668395804505, 0.01879384581531797, 0.014008232475524502, 0.020319457165896893, 0.01925430816066052, 0.028176807864968265, 0.04168369201943278, 0.022019241670412675, 0.006461901872951005, 0.01698333118110895, 0.034987406339496374, 0.01816345964159284, 0.02947918458708695, 0.05227970504867179, 0.03578744323125907, 0.021191257617569396, 0.043406346546752114, 0.04378695719476257, 0.007193607743829489, 0.013355734541879168, 0.06190680060535669, 0.06580142876399414, 0.028944719516273056, 0.020291191093357544, 0.03052552290526884, 0.07056194903062922, 0.059743122064641545, 0.014787781850567885, 0.055699100850948265, 0.005444083653856069, 0.07852269828851734, 0.020259067549237182, 0.01880434275205646, 0.04445626752983246, 0.07876838224806956, 0.03493728295766881, 0.10100668216390268, 0.007839143060014715, 0.03660145455173083, 0.0157965819151806, 0.028963206202856133, 0.050060108437069824, 0.01448802713171712, 0.02305268951957779, 0.004977012377431882, 0.029066139965185096, 0.027137156509395157, 0.043307063302823474, 0.04183253885379859, 0.043190721688526015, 0.07279628342283623, 0.01946417734559093, 0.0448308663575777, 0.04106450506619044, 0.04748243871810181, 0.0186943030317447, 0.059461665738906176, 0.02083796139673463, 0.02543201157823205, 0.013047015527263284, 0.04492694013086813, 0.054029412767184634, 0.010973045253194869, 0.03654190292581916, 0.026754981838166714, 0.03298242696161781, 0.03127645421773195, 0.08294216649872915, 0.020946662706722106, 0.00045118009230853725, 0.029891757627150843, 0.09060317969747952, 0.11432443825261933, 0.06286877327199493, 0.01741882004509015, 0.04109443524586303, 0.022124658870909895, 0.03190822121022003, 0.006197863541144345, 0.025251587420435886, 0.031971766014716456, 0.060871037255440436, 0.008835078100673854, 0.0869790223826255, 0.016229884200064198, 0.05650194348501308, 0.061872079968452454, 0.016186927844371115, 0.013436398784896093, 0.0012815547088393942, 0.029824402848524705, 0.029395572109413997, 0.06848287702138935, 0.009298753309329706, 0.008567821816541255, 0.06257084211600678, 0.047231876091765504, 0.04904808024210589, 0.033418494276702404, 0.038702619661177905, 0.018523707453693663, 0.017132927796670368, 0.0461064748732107, 0.028581418296588317, 0.006083897223496544, 0.02350201371258923, 0.015997711569070816, 0.03498251749468701, 0.030678217033190385, 0.03240947199187108, 0.022190571762621403, 0.08659113783921514, 0.006242536590434611, 0.01730786430250321, 0.016185608093759844, 0.03842547542548605, 0.037731656405542574, 0.0600162459803479, 0.047110523496355326, 0.052078980819455216, 0.05713777829493795, 0.03752175159752369, 0.05391914064862898, 0.02764020540884563, 0.02751311919252787, 0.04146535302113209, 0.021968566978882467, 0.06756817788950034, 0.038918916269072464, 0.0029735618237672107, 0.01140755957125553, 0.012536585863147463, 0.043762499400015385, 0.008812986696804208, 0.04186434518279774, 0.04747514446665134, 0.04395470801474793, 0.01905800967610308, 0.060248746004487784, 0.05069165151300175, 0.0021740669118506567, 0.020983892226857797, 0.0312608648756785, 0.050488701688924005, 0.016764929418319037, 0.0007452863782028933, 0.08711235451378993, 0.038418812211602926, 0.13601694495550223, 0.09198276352669511, 0.16486468485423497, 0.07443259776170764, 0.10918408086789505, 0.059452274814248085, 0.13470547247145856, 0.14010112865694932, 0.09169866091438703, 0.1315613854676485, 0.16542591473885945, 0.06435647487108197, 0.11592878002141203, 0.1250716729887894, 0.10903777514717408, 0.13790125027298927, 0.14844683797231742, 0.10166450150843177, 0.17288853786885738, 0.08228346505867583, 0.19629784673452377, 0.09623774127768618, 0.08502359980983393, 0.07974638191184827, 0.22035749070346355, 0.08387275692075491, 0.19023970966892584, 0.18563922867178917, 0.10991566375430141, 0.08124181202479772, 0.07890282717666455, 0.12939702160656452, 0.0928099655679294, 0.12739140779844352, 0.15063904891056673, 0.08936741136546646, 0.10051718021609954, 0.17123331954436644, 0.13404725279126847, 0.07157875411212444, 0.07550440489181451, 0.15516691309000763, 0.11012047276433025, 0.133679703942367, 0.14082417557282106, 0.13461597370249884, 0.19057551664965494, 0.13649414506341728, 0.12875260332865374, 0.0713822775121246, 0.1625627005206687, 0.09504953146513019, 0.0697970704308578, 0.16439701137798174, 0.3163899140698569, 0.15525451196091516, 0.07723245037985699, 0.1387862227857113, 0.13203749991953373, 0.06955851787435156, 0.09723248718572514, 0.10889891295560769, 0.10907252292547907, 0.04954313939171178, 0.2954495091523443, 0.08626343935195889, 0.1369406482470887, 0.15671246658478463, 0.16799535043537617, 0.12702185048588685, 0.05622258383248534, 0.12397076349173274, 0.1326589701431138, 0.16626256198755332, 0.1511966282767909, 0.047335447677012, 0.15942306470658096, 0.15896670919443878, 0.27975257858633995, 0.07328027566628796, 0.13752751318471773, 0.13466581888496876, 0.11485712895435946, 0.1017167487048677, 0.1402712238154241, 0.13700616758848938, 0.13875771074422769, 0.10595526519630637, 0.11872806267014571, 0.12920358484344824, 0.057576837949454784, 0.232766254139798, 0.09737217719001429, 0.1280671608235155, 0.07863986093018736, 0.14153024554252625, 0.11282189030732427, 0.12938080461961882, 0.11454380862414837, 0.18394095051501477, 0.14503657525139196, 0.20530736685863563, 0.11519094104213373, 0.09004152912114348, 0.1853120390857969, 0.09179930122835295, 0.12149436851697308, 0.08472657789077077, 0.15589845526431287, 0.09609224979898759, 0.18451659248343535, 0.16953192012650625, 0.10708226436483008, 0.11137822563094751, 0.11338476903204407, 0.14952110818454198, 0.06199948170355388, 0.13929063214787415, 0.18419578112661839, 0.11139252914914063, 0.08965241642934935, 0.11158759439630167, 0.11931324484092848, 0.14457145306680882, 0.09805645261492048, 0.10361315908708743, 0.09924403138990913, 0.1253310362143176, 0.12647892747606548, 0.12156857310661248, 0.10051240332956825, 0.1362702827900648, 0.0897718250219311, 0.11578213503318173, 0.10929850222808973, 0.16590128280222416, 0.08568005529897553, 0.16085832911942685, 0.2865201240139348, 0.1374493595212698, 0.11397458559700421, 0.12427413649857044, 0.14307248778641224, 0.09007086218999964, 0.09410400648734399, 0.2027152816631964, 0.0819798545645816, 0.16767728036003454, 0.16819497543786252, 0.10823741595127753, 0.10461254617465393, 0.13756510402475083, 0.19916179377053464, 0.21888291197163717, 0.10839365542467151, 0.221289526405079, 0.09619924120072808, 0.08751697851611034, 0.14101521032197134, 0.18166722037962504, 0.10578404366970062, 0.10234275154237236, 0.0992613679596356, 0.14098007577870572, 0.11729344965091773, 0.10181436275265046, 0.10974476113915443, 0.138916691499097, 0.1720144897699356, 0.1050243287214211, 0.15835043654910155, 0.21153143287769385, 0.09810079487838916, 0.1475365696741002, 0.18268670567444392, 0.13331823476723262], [0.030277053559465066, 0.018871466828776256, 0.022043626522645354, 0.02187143129828785, 0.014341987735990967, 0.004100297635886818, 0.08465331646480731, 0.02800607488357595, 0.04722869036985295, 0.05473830204989229, 0.0416876512712666, 0.00888889525750918, 0.03985537601900952, 0.0047070996287012735, 0.037847906417612515, 0.0034576832009146786, 0.03011315342571054, 0.022277261396603923, 0.003933986582394157, 0.06241226169679846, 0.04330046454976712, 0.010737541863428695, 0.03566067931907518, 0.030682115216872523, 0.048087658027985265, 0.02576571679674089, 0.04445882899952786, 0.0326086695172957, 0.05843965629381793, 0.01718976188983236, 0.026821093201371174, 0.02047622759294297, 0.0651752155806337, 0.00940520188305527, 0.046680267833705456, 0.039349677440311225, 0.049502807270203314, 0.02704847707147045, 0.05145698473123567, 0.05909955874085426, 0.045630136504769325, 0.027649894888911928, 0.03627621914659228, 0.02840736218994217, 0.02743470768577286, 0.06154961298618998, 0.0050731747843591225, 0.021279991338295594, 0.05559464377750244, 0.03162869531661272, 0.026688670307131748, 0.036812197350497754, 0.03196505869605711, 0.013834594516083598, 0.03376579564064741, 0.001410215550484801, 0.015134039966921722, 0.04735176644421049, 0.014214880315453877, 0.06421347361590181, 0.015488313278183341, 0.04880405190799918, 0.018514406434925537, 0.017613976894478713, 0.02423549140803516, 0.046347286951329024, 0.07752195413091353, 0.015468696830794215, 0.030391498668385402, 0.08585495448538236, 0.030403790330248218, 0.02198041250397052, 0.06556468789598771, 0.0472280118348343, 0.029584713745862246, 0.06050896418413945, 0.03461692961198943, 0.02970598152439509, 0.011980811400072915, 0.022000351255493503, 0.06795294117182493, 0.03904220947463598, 0.06976682812507663, 0.053205230206783326, 0.05147742220599737, 0.018929727541814958, 0.04664608323946595, 0.054312646854668856, 0.02145932475104928, 0.03741719274382506, 0.04646581344838653, 0.007580101290451629, 0.022271663482700075, 0.01221373550859945, 0.05124741240537592, 0.010106156546888607, 0.02705897909722158, 0.026181797862851193, 0.030693565495312214, 0.03610895347914525, 0.027998502432767833, 0.047180453315377235, 0.05309466292549457, 0.02935734683913844, 0.0548739954829216, 0.014236611247594868, 0.017861577715458613, 0.010473344924061425, 0.03276387761746134, 0.013744446049843515, 0.07348980049469642, 0.0791251559608749, 0.03337502393073269, 0.022260808618739247, 0.046485219549919875, 0.08705840419445719, 0.013690314222393292, 0.06587551800268036, 0.08942514791020326, 0.010240693077711123, 0.03611415445006319, 0.0172460192282285, 0.03416065213137439, 0.030208134757620946, 0.015661249802048718, 0.05432926417727556, 0.05206212600959199, 0.07191646777625595, 0.011575575019898159, 0.007793841517663428, 0.04535063775256276, 0.04529211749987943, 0.028245882729866674, 0.015267443344263094, 0.08206285975341286, 0.03321277602974858, 0.04589811712503433, 0.024727039138919542, 0.046224027672516446, 0.05872757227293082, 0.018497207268540348, 0.028334567256804024, 0.0355078460914748, 0.03896636961560164, 0.02461137605964073, 0.018906011046575646, 0.042527053372136185, 0.041067612756575854, 0.017115177320582525, 0.050819735175796917, 0.03484714975846665, 0.007516159542969295, 0.026565594232774208, 0.06220571563712188, 0.03137438717697348, 0.04258135313700352, 0.07171748059668712, 0.06673845848334686, 0.024304266021187817, 0.022782931137563925, 0.08134251340691533, 0.00687709405818688, 0.010837294992857745, 0.0646997932344675, 0.025877802300133874, 0.017937234370037913, 0.03034568398392626, 0.02525870525278151, 0.008985479628401143, 0.03670090064406395, 0.015097142928945166, 0.05098502630633967, 0.026595164788886905, 0.04199307006118553, 0.005662041824377541, 0.02089678359750126, 0.0532663933533643, 0.05629345681518316, 0.030934058661971773, 0.022928551537916064, 0.007716057655800666, 0.017686746382553662, 0.03660019926194634, 0.02852751886738198, 0.057764683584017415, 0.07671305217913219, 0.04040247880454574, 0.0709867323083537, 0.015545629131208574, 0.006685601721983403, 0.027557273162528872, 0.03248706925660372, 0.028453958886010305, 0.012210906017571688, 0.03378403126927359, 0.02655901583576841, 0.0378158863500825, 0.03754304741908397, 0.060621383866029124, 0.015347240758793694, 0.03903531216617141, 0.013280202568109547, 0.03788022164787565, 0.0044880206031458715, 0.01846317364834249, 0.09664341022393533, 0.04746035918859499, 0.08028760179877281, 0.027727549829121147, 0.0287728024912732, 0.0372383512689599, 0.020644305806074823, 0.019788561189281087, 0.051180620810815265, 0.027847195908959423, 0.035524873927767785, 0.02194473852536508, 0.03071898002443569, 0.03108331261734877, 0.01541035299721573, 0.022252913863797272, 0.040174630137958696, 0.04761025435956461, 0.027052229370123575, 0.042514015321752856, 0.005212395751316632, 0.015784690588978783, 0.013561670768207737, 0.003232065006159246, 0.039283812046051025, 0.02265983640349337, 0.03849669785371848, 0.030720191209443977, 0.04863724425168974, 0.03983964757727725, 0.01927258280505027, 0.017902732560677186, 0.025217652187815735, 0.015890397863196473, 0.144449276051351, 0.011782050681566554, 0.021931166128654565, 0.07346885411867074, 0.02178222090671105, 0.06558222124086958, 0.09073398089302437, 0.06174089879329715, 0.033911273548645635, 0.009561580456128078, 0.020782894887296215, 0.01706315064802766, 0.025670279150030444, 0.03903453524357506, 0.02277003727587206, 0.006643655535299331, 0.005383576141736869, 0.0818737723997661, 0.03234303662819522, 0.07492963823356799, 0.03185181798679488, 0.032507601726268015, 0.036122337582388094, 0.051712626192186556, 0.03564128339556711, 0.019038849543513994, 0.05461666446977428, 0.010379138818409826, 0.08768138755112886, 0.027918973039569597, 0.030615880021027157, 0.0400760288217238, 0.06963890391801085, 0.039542574768087695, 0.011307630870890404, 0.04932678510834064, 0.08933014622224228, 0.05344660207629204, 0.09008715381579739, 0.03654788081933345, 0.038276068799729855, 0.008978227785389339, 0.016984925738402774, 0.03579996559502823, 0.011814901954494417, 0.05983671918511391, 0.05889111278312547, 0.007409565932383495, 0.05500965838187507, 0.013716179977304168, 0.022202705665092384, 0.0375199365163488, 0.02488336173285331, 0.055994996401880465, 0.0189470522371786, 0.036518829342510016, 0.012102800122063075, 0.06615174282342196, 0.03290984407067299, 0.050560371950268745, 0.0163136985419052, 0.01044224766415677, 0.03783218815390553, 0.060535352411014695, 0.010461833577470055, 0.038520185343388996, 0.053829485816614966, 0.09338186880839722, 0.030888091307133436, 0.02264495613053441, 0.03494046528690627, 0.0599439548594611, 0.0333129685106022, 0.066532557031938, 0.012720725848339498, 0.07016921296183552, 0.03879929054528475, 0.02048130303488246, 0.04096596821078232, 0.05028506315180233, 0.02982875904334443, 0.03447160098169531, 0.04393299489415117, 0.03316643887332507, 0.03367865478087749, 0.03536344366148114, 0.07989827197577272, 0.02730489375868014, 0.02668323354529483, 0.023756601747923663, 0.07364522572606802, 0.024558484254937087, 0.039163650279598575, 0.05267016463247793, 0.011117291620134242, 0.048020686621644666, 0.04003407160884567, 0.05993668096406119, 0.028192308997469287, 0.05344406435532229, 0.05882415494748524, 0.01959905823293541, 0.009189603318061148, 0.0385945358180574, 0.018431920325383544, 0.05525793773787362, 0.041068796800183396, 0.042243741253124814, 0.060829300566443374, 0.008774869992131633, 0.0329236454729523, 0.04940490145236254, 0.04375259618141821, 0.09410667991531746, 0.15338892063924245, 0.152575140020677, 0.08971204608678818, 0.13924544171563216, 0.08242975042334624, 0.16799981519579887, 0.10332568415573665, 0.13160762084381922, 0.17350524477660656, 0.09736856738371508, 0.13859666724290165, 0.09168681369296142, 0.11681235475199563, 0.1601223764675004, 0.07701917325279542, 0.11446500356708254, 0.16416280823094503, 0.06940071777041469, 0.11432804805891854, 0.15783727408519813, 0.10088623541274241, 0.1350400580891541, 0.14997287679995808, 0.1458225223634924, 0.07191217264958791, 0.12293864387486662, 0.1174404067652566, 0.13291609420308045, 0.13473477161356381, 0.09679451318723814, 0.16301415700997623, 0.16101013097379888, 0.11991198414138385, 0.08116981945931911, 0.15227781954620564, 0.1684904231556824, 0.16398045873003347, 0.07153878161417586, 0.11119100424860205, 0.12531874115977967, 0.09144616446324758, 0.09121789171227387, 0.062124969969902716, 0.051817405569766245, 0.1776684642370258, 0.10579968390188046, 0.08467462924974305, 0.1406938697078398, 0.13739993503051146, 0.12496724644941942, 0.13380994195384638, 0.09300097996102911, 0.10743053603385176, 0.08403478429785796, 0.10202791807906968, 0.15818794098283562, 0.1713798695376941, 0.12221242141510759, 0.0940207095284547, 0.07304377228553806, 0.13891551084816456, 0.10970058850944042, 0.19868231378495693, 0.0758991019268121, 0.1661556384393147, 0.14183948109192507, 0.04656070317806942, 0.20776613349361078, 0.21313361690512725, 0.10089063231966325, 0.07834904760654483, 0.11242554443223135, 0.14371871096747263, 0.09839631723506109, 0.24886802583932877, 0.22489319874772004, 0.17505586014262267, 0.0839440505951643, 0.11559129027383667, 0.145605649000832, 0.14967156653957708, 0.19772481944944176, 0.09215703167553459, 0.18147720343300275, 0.11300750356167555, 0.12616015172430448, 0.22428398286657675, 0.14459026205752576, 0.10943912182535444, 0.19818668466593536, 0.1468909028917551, 0.06789434288761445, 0.1111431336030364, 0.16902991277830942, 0.13897815320108617, 0.18225869935538086, 0.0764037419908813, 0.07864140799002987, 0.13472619493092808, 0.06873805368585245, 0.16048569125788553, 0.14343194849789143, 0.14741927811077662, 0.1714933341635125, 0.1461818337972675, 0.10592393723449536, 0.09007911317582641, 0.10227381916982786, 0.14449548428612097, 0.23837730448160852, 0.17993261345795222, 0.10611307887094361, 0.135355590443526, 0.16863755668912614, 0.1394829832549606, 0.13401146685438498, 0.0963653533586434, 0.20463932199137552, 0.1278886246894087, 0.12227669225207397, 0.12983207111912115, 0.06379656134439365, 0.1701093262859753, 0.07761308138391801, 0.10266283686671938, 0.10091980932546513, 0.1320893128535577, 0.11380107740738563, 0.1116144440269896, 0.16110793501138687, 0.2001508264137166, 0.07230432517826557, 0.11457187283251967, 0.16766749588506563, 0.12974561218704495, 0.14460208213755063, 0.16193995465125355, 0.22762261943093368, 0.270218374473708, 0.06608517175274235, 0.10707165207713842, 0.15644487951483044, 0.06160247764949288, 0.10809396007763487, 0.07256205991974898, 0.09569555787103516, 0.14695999132735388, 0.20060426422527858, 0.12197473059807505, 0.1115946104483945, 0.07332170022917645, 0.09215896550033774, 0.18678954908890383, 0.12115226473127093, 0.1320310402661562, 0.22051075819347585, 0.08840617151664835, 0.11322012250976903, 0.14566040677683695, 0.11564327962696552, 0.14076051541737147, 0.15061919497592108, 0.18830294002379688, 0.13190517202019691, 0.06918749492615461, 0.0758533686665552, 0.09166130077626024, 0.1433911956846714, 0.18803307307618006, 0.06940737419894763, 0.1624065831835781, 0.1499130842941148, 0.05683606769889593, 0.13411454989441804, 0.08669309451111726], [0.03356234709333096, 0.04377261635714343, 0.0349016462984894, 0.039462955468999486, 0.04466378389458571, 0.010178781846272094, 0.04014440140287791, 0.07921216450631618, 0.0408233537205628, 0.024754915053823164, 0.019332041132396886, 0.013628577713721564, 0.042685861100575755, 0.03736572586266058, 0.05531645120520677, 0.06077655803944383, 0.05718879734299012, 0.041919221702430925, 0.009608574943350894, 0.02606701009374644, 0.009075374492178006, 0.02682578527102513, 0.07454766373017005, 0.015931033629125783, 0.011566573404707015, 0.024671049821855764, 0.024333641498482654, 0.030507782607206275, 0.0481988902735923, 0.02433559567933636, 0.02835584950766393, 0.03343708274353828, 0.06445121193038565, 0.015488661027380397, 0.008079661671737475, 0.11501610970922879, 0.02310063480399549, 0.030592585913836956, 0.03319021134770342, 0.029805020495717014, 0.07757846252726656, 0.01946708995715848, 0.004474610206671059, 0.0196309934835881, 0.017590947415945784, 0.08153831147189651, 0.04593339416065386, 0.036176165765417476, 0.03231075871735811, 0.01191554226846035, 0.025105821135054742, 0.04200848637680922, 0.020663408263187324, 0.013486966607160866, 0.03343560692987271, 0.016121025130684887, 0.06868172170860426, 0.06792288885584899, 0.0723267507606319, 0.04540170090539115, 0.009854482819459267, 0.02943186355488641, 0.0558897556204881, 0.015161763211446149, 0.06467364928019897, 0.029276689381471703, 0.03979188549731459, 0.06344822860722031, 0.012274254046912705, 0.05420431534626654, 0.011990898671293897, 0.028059282207063267, 0.05419612203591636, 0.011669239993872387, 0.043401705367224555, 0.03167623687269432, 0.06995638366788626, 0.020053854810872247, 0.1085283581965736, 0.019451805955863426, 0.041994729079306126, 0.025683951630656208, 0.06929956855518477, 0.014287116305370415, 0.03809964630220618, 0.05941830735121455, 0.0557022458607597, 0.012209989147127738, 0.014300027130437749, 0.05791023613086768, 0.01486917382239231, 0.06395365577191114, 0.007162093184888363, 0.005982212813770664, 0.03985728270241192, 0.016389139761616076, 0.05634430283680558, 0.03642803117898958, 0.02002500180554177, 0.03090716153383255, 0.02044409217445978, 0.03395885920950344, 0.03917653226692762, 0.04684065994141357, 0.038314738510442634, 0.002556426695913875, 0.037339469950113974, 0.017343003934781467, 0.021684001266424145, 0.027601947908156683, 0.04137793396200452, 0.03273719422785299, 0.09763159469834395, 0.05838808084705046, 0.045888858514704874, 0.01972314532447074, 0.027037583191746047, 0.030379413959703276, 0.047956330967800956, 0.034518504714859385, 0.017153602758688585, 0.006147421247858022, 0.08731771313718387, 0.03526560230446713, 0.09777572910700526, 0.026449391718155572, 0.011673985498159059, 0.04643083157550011, 0.02209820957588298, 0.044980571538742097, 0.06916728136794907, 0.05275789921038917, 0.04080194594072444, 0.029646053311548064, 0.03168969222211412, 0.006691411253996193, 0.021845490904524922, 0.044459022382008176, 0.027305626576500278, 0.01618787270438458, 0.048045466720525704, 0.06406194996088743, 0.0716907734583531, 0.03044339981196182, 0.05457270897126623, 0.03352431181286063, 0.047367172581808906, 0.025969268820647682, 0.051810023108763356, 0.03549647723723735, 0.04656393300475819, 0.04056363087147474, 0.05282322516930955, 0.07800586495016303, 0.03092417579942516, 0.012199420964212289, 0.013260655670559831, 0.018632671696000865, 0.035280740420733175, 0.030833374243229628, 0.06005880369671753, 0.02873155434748956, 0.030092858443302766, 0.037115583928035836, 0.020984004185135876, 0.06776478341115372, 0.05582072825304099, 0.0724119001201221, 0.04259784832330687, 0.016620442171448042, 0.025770352887255803, 0.02065649738402239, 0.0035463749372866005, 0.023984238372317383, 0.03149194336895432, 0.04215160637561764, 0.0034057992327559206, 0.05035418890682714, 0.011852872774137982, 0.03835633270708578, 0.0334962577825146, 0.08617495160017695, 0.038705822346465926, 0.0740716103464365, 0.009341606188432446, 0.00594792262251888, 0.03363250422158411, 0.022493479972971336, 0.0070752848072775775, 0.07444971041487795, 0.010966137766705027, 0.019342704310214946, 0.06695796456187963, 0.09402613102325372, 0.02121201909280249, 0.03630485671705433, 0.011609342315101197, 0.019324670545756817, 0.03827110192339335, 0.012288632203957863, 0.014718103089502879, 0.08133899859551873, 0.03558344167790242, 0.05366956529074481, 0.041068311647645066, 0.06965723793421473, 0.02501660735080285, 0.04059495883328574, 0.05498148900057588, 0.049460907732801776, 0.03581517156479614, 0.039024469176573415, 0.07237926258572511, 0.07385570728885275, 0.02892578160390258, 0.04255145349140678, 0.032927536871284246, 0.03627183581037181, 0.06988028596554484, 0.03147931583225727, 0.0640878157157983, 0.005112654920334795, 0.01623305635127638, 0.031061684313629354, 0.01720938172989658, 0.06045506136225803, 0.025024544514183487, 0.032122882548719645, 0.021608108820925866, 0.012367258297412522, 0.017633754493934766, 0.01122098958252796, 0.044505681842565536, 0.024630707522322024, 0.08538709780467407, 0.04591191852731364, 0.02673605240748397, 0.04697085724079183, 0.04978053165333612, 0.01268974902840065, 0.02241953831565167, 0.05046278504388673, 0.023900924450052635, 0.03779268723779491, 0.018043075654921786, 0.04451469618028828, 0.019199575829718794, 0.04281921698046582, 0.010632905826371695, 0.0073957713154543725, 0.030894150624849966, 0.026311416711126055, 0.049688223749399185, 0.02758448580945177, 0.02368890430911311, 0.012138381650272225, 0.049795079444135935, 0.04982856175463114, 0.028954147760357176, 0.011407501895778945, 0.03412300022318959, 0.1078584473580122, 0.03845193150586315, 0.01894511332336281, 0.023522841344986643, 0.12526990020913736, 0.04193497050021376, 0.0426988380828074, 0.07062909685607467, 0.04999625489913991, 0.05404048985136407, 0.03250630911705749, 0.016908777145934955, 0.03894522985709565, 0.005309444494611982, 0.015539030378152217, 0.017113119663138474, 0.022670231559979062, 0.022104843952027813, 0.050414731193866046, 0.04994835371949843, 0.04340060614049435, 0.020741734953065003, 0.038141725651387653, 0.05550419845219169, 0.06984445931656019, 0.05900515416370971, 0.038516161630728414, 0.0315292051195034, 0.037315829790064266, 0.04948284476995468, 0.03652460367551871, 0.04002368323771017, 0.05031446407416037, 0.0588811586744019, 0.05319083847903779, 0.017962630239448378, 0.010791721188330224, 0.02686385956725904, 0.013722345316117364, 0.08667847208146538, 0.034938507713377476, 0.014990187150293162, 0.04364676168188453, 0.08755026744412524, 0.01582454943231174, 0.045198907144367695, 0.015033358940854669, 0.044868043291249445, 0.03144909727520176, 0.013211809630904878, 0.024858077821720923, 0.06657787638583354, 0.03297313442453742, 0.03566219923751695, 0.0016194997110038198, 0.015861195412331393, 0.08364434167742729, 0.033776614881519756, 0.02393022189582033, 0.03781515692493745, 0.011174422572366893, 0.04158810339868069, 0.03311505002368774, 0.005127497873867729, 0.08492075425705739, 0.01983400946483016, 0.022956454594220434, 0.08894228882023267, 0.14046965459627764, 0.04085122115377869, 0.025729764618777802, 0.03229148832282849, 0.03166953294671007, 0.005432400553088103, 0.021498525415414145, 0.013434439515029746, 0.05240164796954819, 0.01083749091984438, 0.049497049900570085, 0.11967259698680469, 0.0625314735142248, 0.057335829096181054, 0.045530066160219054, 0.01500144404625254, 0.030618933428611075, 0.016066140129363964, 0.011803176021203399, 0.029539034768406833, 0.010915051713319761, 0.04350740076707942, 0.05693688443196671, 0.064514390325972, 0.13215986692479678, 0.09665261794413839, 0.09967094526759215, 0.18450394459068775, 0.13246959101940903, 0.2310523289654936, 0.2283516510256699, 0.08569607551076583, 0.18874387922031538, 0.1991250714553254, 0.0698493311979941, 0.06900313696158783, 0.1722358414637191, 0.09289501993251698, 0.18648042210510798, 0.2925780846604279, 0.20340419826763018, 0.17904314904340676, 0.15702803965125764, 0.09256721966500793, 0.12547198150839123, 0.17385568097233772, 0.15418181594993385, 0.1498444436916283, 0.12280505390039512, 0.08058794175407716, 0.11645030203674521, 0.16450962104967662, 0.16533400038523333, 0.12878866067954473, 0.11598199073757444, 0.11944463636193957, 0.13279208514307225, 0.09741084690072707, 0.133415943809918, 0.13491980811314924, 0.2170637460159404, 0.13514042698911258, 0.1295780683202403, 0.17095053328999452, 0.1820101384073496, 0.11339337964143072, 0.1341093930282763, 0.18745002150535583, 0.10044087216790233, 0.09996824538601295, 0.11317197366484574, 0.11532286182045937, 0.14768132833497866, 0.11277803658906903, 0.14364564631666454, 0.0838656323030591, 0.08553678262978792, 0.13489681934671743, 0.08426962526781218, 0.12730287254921027, 0.11944697052240372, 0.1782617209745305, 0.0968558391822236, 0.07671579346060753, 0.0785347151436976, 0.15715537353285722, 0.07607700702335153, 0.10190192091145686, 0.180741495053683, 0.08529385352241141, 0.3067058894251074, 0.11178624230836119, 0.11299244008426156, 0.14833497468914303, 0.08419053522603852, 0.1262529617441552, 0.09245514603597776, 0.0724920215351241, 0.06760361098817416, 0.1485403265271868, 0.10435359685548715, 0.16569381393492222, 0.15204704978636333, 0.09224108180829457, 0.10327206631856305, 0.2124436960688659, 0.08565418954406466, 0.11650355346500874, 0.18742201157978602, 0.1351036639618022, 0.07096893433481455, 0.08904400800487824, 0.20859580540231296, 0.12018265176032271, 0.13173439832670347, 0.15573553900633538, 0.0885264350633536, 0.14748472959867545, 0.09776046206908566, 0.11095735750028066, 0.1251293077532734, 0.08494895417243242, 0.15143406125051634, 0.08007833481367145, 0.10275681396680218, 0.18218340910971165, 0.13319822906383447, 0.21369061273123535, 0.1058646332738655, 0.11923186135079179, 0.19853908861322062, 0.18646624072321824, 0.27029621601104736, 0.12263111823371478, 0.1410130254392113, 0.1697920568819557, 0.11854431538709573, 0.12269917529608522, 0.1265631201011794, 0.15243571464504513, 0.19113226820315632, 0.17366980308932917, 0.16688505001366138, 0.14727864494281157, 0.1667471309857709, 0.1709026965711798, 0.15539046323725156, 0.16980629254664692, 0.20375192032328673, 0.09317340249461786, 0.1712082408900772, 0.14544066999639782, 0.08486189812953983, 0.14976695499249867, 0.1965558257486139, 0.13877998026353972, 0.11189068241843156, 0.09390223052884851, 0.10590437506990773, 0.08835411431001765, 0.13933464192918368, 0.1360174742128168, 0.18987011164426804, 0.16840647480317525, 0.19850543327629566, 0.21609340022717202, 0.17477247677743435, 0.15746542332427843, 0.10354768724313804, 0.10848626188401665, 0.11677606669919831, 0.20139365829527378, 0.09901182992117745, 0.14777188561856747, 0.07702596538833209, 0.2232402874422925, 0.2850740301821913, 0.08228224369564227, 0.0840490742453507, 0.0845146578337465, 0.09684085034366165, 0.11447439449174063, 0.11212158109992743, 0.17634804866143636, 0.24225176657949174, 0.0814094441011548, 0.14890186355582305, 0.17955286454941544, 0.22038065588900022, 0.19449777475425176, 0.13303345361990587, 0.12393391904022012, 0.09098334929772786, 0.1370879989117384, 0.07566226606390306, 0.08567802647926978, 0.11089197386588369, 0.09385043116552488, 0.23076118315969193], [0.02831511365781937, 0.01408411983201014, 0.026599229213648608, 0.0703264566670571, 0.06214388074087245, 0.041439728146152835, 0.032144412464861355, 0.014362637252945985, 0.010320722042316837, 0.032390754603381665, 0.04912799131125212, 0.017218530078285506, 0.05791021577481713, 0.029604564287832806, 0.0660263088398746, 0.021321490540036132, 0.0342559829088194, 0.025535031853775893, 0.0625305167798485, 0.01124901307879814, 0.023211407342127392, 0.05668599271614637, 0.07174120896628924, 0.008845698021884476, 0.023378082684108188, 0.023952564357646873, 0.04150541712130819, 0.031470155609505515, 0.03691757383889385, 0.010140900084349726, 0.02328396987702165, 0.06627759749868087, 0.031099095341882536, 0.02553733378382666, 0.023793558157714348, 0.01992607648883547, 0.027476953276033913, 0.028621584177017212, 0.043320980056055954, 0.04667319071346095, 0.07955153379589319, 0.045211609319916794, 0.02105571176590664, 0.07411119607942444, 0.035967068414070776, 0.019614352412255745, 0.0511714673734137, 0.026806370687804053, 0.04982871442501034, 0.03338674223050475, 0.020445003107722317, 0.0308244515077344, 0.011732166483333068, 0.02896746401009815, 0.060391041583248546, 0.08507943645651851, 0.05570894300139376, 0.024887556775606105, 0.04631592845544219, 0.06136208626308611, 0.026449062628671527, 0.020490542985498905, 0.02531987179203757, 0.028997814881482294, 0.027007647923060825, 0.021271869274122373, 0.03896564019045659, 0.05031050142965146, 0.026132064638659358, 0.0889781154692173, 0.023196023256917084, 0.010389851190016737, 0.03323744756302663, 0.027853228085275208, 0.02338898165284523, 0.010431842329645795, 0.06673362052866391, 0.08194005848573786, 0.04666901772309627, 0.06857242328780037, 0.01564643398991653, 0.02037342275226755, 0.026132507382759025, 0.029510302203042165, 0.032059629514281235, 0.03659758690212454, 0.01882021368614265, 0.014991030230053833, 0.030818619499249116, 0.03278110222890973, 0.030355580417173247, 0.040523749975753684, 0.03908864501863718, 0.024408930047814335, 0.01456091197074524, 0.021393771482897655, 0.02941641670518688, 0.01457190593438489, 0.006172320938536099, 0.013066305429674685, 0.06074235987450395, 0.021511785686016083, 0.04883279125871403, 0.09492322217140879, 0.005686818106499101, 0.02398135799116322, 0.010576921598320561, 0.05275612144864031, 0.06542691814580134, 0.041113298519381454, 0.02709113317541778, 0.018676410063302944, 0.02790326834656298, 0.011506435694172978, 0.04700509272515774, 0.028402761722515737, 0.06801062343376023, 0.02407230543238776, 0.053719804023525546, 0.05338515394500323, 0.010142188452716385, 0.07816106626497847, 0.05122481379657984, 0.010091485771616655, 0.020933242980390787, 0.023774513376078436, 0.030224602802523544, 0.0814459899972592, 0.02531778020784259, 0.016227382102182934, 0.020786855835467577, 0.01592717955021986, 0.018862301517011862, 0.02130121930635401, 0.01174018083007208, 0.043432239443063736, 0.03762309419523392, 0.003812597939811115, 0.005015489977917501, 0.06665997912308999, 0.04247662804222532, 0.05920970533043146, 0.015557189671588796, 0.028245426415066634, 0.0387127637597067, 0.07017658185213804, 0.025653400591441562, 0.07265040517917701, 0.052738808627639494, 0.0517400661483407, 0.025909786744575416, 0.03070241359195539, 0.053970539676291604, 0.013472567245896374, 0.020241829367088418, 0.016156568491299237, 0.01726936931455774, 0.030534415106688226, 0.032105016721678634, 0.04198548403967704, 0.061027561713542254, 0.02248924591445497, 0.08768505842557975, 0.026870948561866368, 0.041899954700576406, 0.17356623150408268, 0.026667150569015315, 0.0828683486740504, 0.07632516085037164, 0.002325033744065357, 0.023535959123234664, 0.015509195193382246, 0.015501861926168203, 0.056442639524383206, 0.005463261173905006, 0.07882203401199409, 0.04351464752107859, 0.018862522040892924, 0.05528076704857605, 0.017720340651326945, 0.04088012335289802, 0.056251441926828454, 0.005407407139760575, 0.017432070137666802, 0.03859098707990987, 0.03134319492216621, 0.04271217808127403, 0.04707631515339017, 0.03138148465326854, 0.021262235773195113, 0.028154746995174458, 0.054110209324530194, 0.017436619714966843, 0.040757573143179925, 0.059810880571603775, 0.027959393370630484, 0.10445579101464578, 0.046083665918558836, 0.011293259499195431, 0.024794658546202948, 0.009678330887774271, 0.050345832748072486, 0.03622134601963418, 0.028262500052473376, 0.03247592092624732, 0.05842753765838487, 0.01958703459240496, 0.03791647238124694, 0.061079869978129864, 0.013358667509497275, 0.03795534225979021, 0.04475448027785335, 0.038462750746735504, 0.045503260634307346, 0.06026526154684169, 0.017407491902953813, 0.05999842086540801, 0.0562347499653697, 0.050944154749491384, 0.02194111345202795, 0.020530233891414743, 0.043007069400378635, 0.009749046111080264, 0.013597644998558929, 0.01826866140722164, 0.04921248588444931, 0.05015868600457907, 0.02499037009796926, 0.04061696033126541, 0.021099631641326205, 0.012597951722065253, 0.05289718548634222, 0.025504178866477947, 0.0654612791591457, 0.03126159090814846, 0.053159266244620085, 0.007582650037615427, 0.01606877793424896, 0.05170058558828064, 0.03644958823653204, 0.028087502478488853, 0.019901182735338807, 0.006931297979982836, 0.033708832625831874, 0.01687070963505123, 0.020577249582856894, 0.011405057473374265, 0.020908798756343976, 0.03860145348257252, 0.03507381098877106, 0.03923222302858319, 0.043206623156688044, 0.11793619873268263, 0.02851737816152828, 0.052758082414844205, 0.028635263442993164, 0.042780516735677204, 0.00755947467405349, 0.016471512216542448, 0.021792846765103083, 0.04657019588298031, 0.09482024091162852, 0.07413394057324954, 0.05245474333475743, 0.038611743466130326, 0.030706362665763924, 0.042695811816624234, 0.06950473040342331, 0.04693041316100529, 0.025773840557251657, 0.059844386630824635, 0.023195860408512608, 0.04645606629284365, 0.031948454944150786, 0.01755746340911303, 0.023894327393333827, 0.0072513375032160965, 0.023654299023162042, 0.030212015977927616, 0.024379953209842955, 0.051204376321818144, 0.038591387415570874, 0.0393681675195694, 0.02142052781502051, 0.032864171878567765, 0.014154115808196366, 0.04255965697978224, 0.008060743267248784, 0.010722244291433265, 0.009282738186552056, 0.025249263437997018, 0.03555601868512375, 0.07499367836862803, 0.02686948631890118, 0.05616852494754961, 0.05714296230248042, 0.06981098718409028, 0.036688320604818206, 0.029170519007103782, 0.009039365486907107, 0.018133448037718023, 0.02075114962644875, 0.04118475164952023, 0.04878136508965066, 0.05253791476466826, 0.010010306690154331, 0.019700533144974282, 0.023130010281290327, 0.03436959681234189, 0.06462184991687536, 0.016392284771427512, 0.03045327588915825, 0.014195125616554703, 0.03098902339115739, 0.01861499246608998, 0.033176755998283625, 0.056898838973471096, 0.03378261313108461, 0.041527018283626864, 0.02487287836681519, 0.05472680766667638, 0.07486740300165755, 0.018137244441147362, 0.06043093265699489, 0.017645316730652536, 0.02686975773290864, 0.018210317573643157, 0.020368756127676794, 0.048055030671613555, 0.061900313810578415, 0.0556282991144274, 0.02033698372542858, 0.039586384381566725, 0.03446535845952375, 0.02084785613364407, 0.05669048461796982, 0.0029104366507713814, 0.06722814363560506, 0.03798212403697627, 0.0728655754189406, 0.04143885283597878, 0.0037646903989038295, 0.044498903277729235, 0.031218140918229307, 0.05518461524375847, 0.02016316680237651, 0.045157184026071, 0.01773903259475316, 0.08813859123204436, 0.03969420359602996, 0.056408210657536983, 0.014230165164917707, 0.2209345033126218, 0.15521449196551526, 0.11643485857972077, 0.0967208853523646, 0.11279584134795836, 0.15359493744160446, 0.09604016545095614, 0.14432800827281816, 0.10485370430563178, 0.11547112172203404, 0.13284549941974028, 0.12094442945505891, 0.16870760864445142, 0.10444365202316216, 0.15139584615826607, 0.1474282754851239, 0.13676390344543116, 0.1929828774716173, 0.20419511225606712, 0.08486019500664302, 0.13622072259230272, 0.07994589834873166, 0.13402207914207662, 0.10828599227326256, 0.13223404437303543, 0.14350513528500283, 0.18085804022848606, 0.23859386571816035, 0.12499362789094448, 0.10556522969688688, 0.07237963577998535, 0.14363956664289745, 0.12482958526483603, 0.09100994108510868, 0.11058609706482717, 0.09621421646858964, 0.10194266693932669, 0.14464974243726048, 0.1538096937750067, 0.15898033417761326, 0.16291639368448937, 0.20943209981279715, 0.12829581355409964, 0.10464993345418147, 0.0828914460060852, 0.14078768395951816, 0.09766092098184995, 0.08689751675618546, 0.08923205041459628, 0.1435418033174106, 0.07666195849222796, 0.11917628933276449, 0.14264074952474662, 0.0820084141035165, 0.16781275666185788, 0.1392216251364776, 0.11314487297620092, 0.11820618781660285, 0.09986865680132594, 0.10654721914657525, 0.08030130142079932, 0.07652655682925667, 0.1785796960549695, 0.1484753635845014, 0.11982652944113527, 0.07605760770716838, 0.16035976872912475, 0.1541698058801038, 0.08555673834468637, 0.10143140437347548, 0.11713460460305214, 0.06681396586022206, 0.12075529460396085, 0.1629187007035528, 0.09646241779306106, 0.0956925248195018, 0.18549744199429238, 0.12614127488008567, 0.1856580376625061, 0.10331579790051494, 0.11733881650226456, 0.13651781236486776, 0.09455814997532538, 0.15994131618312427, 0.10180023565356221, 0.1382392964192799, 0.10708896829081432, 0.14621247643870966, 0.11102454603782722, 0.15039860324135848, 0.15384607682270662, 0.31291679186480387, 0.1439527648368052, 0.18487282336822577, 0.13408592928733143, 0.10054374486207962, 0.16308211907744408, 0.11431917282087461, 0.06603015613343034, 0.07107372049774442, 0.1160874350794724, 0.12355498437370573, 0.11332520044275693, 0.19678783044219017, 0.13071669079363346, 0.0788974328232663, 0.10862848282392536, 0.10526313233588423, 0.07242853101342916, 0.08711096351700169, 0.1893809964614255, 0.10332704122577395, 0.11448975652456284, 0.06509909073689155, 0.17433270466114792, 0.08819746093026229, 0.1864568633692605, 0.0935721503836768, 0.12413081633193151, 0.19640035980514117, 0.11976369709840842, 0.17872440043304647, 0.19257594645023346, 0.103377218890403, 0.15585832670331, 0.09946323891303369, 0.10910509260637419, 0.1556552547429289, 0.08983875571617059, 0.07173684598611933, 0.22016657809061663, 0.09126849685396467, 0.1726365571043321, 0.1736146110509123, 0.17058009388191359, 0.11866691309426512, 0.07580801538590874, 0.1746384525405509, 0.05879455046462161, 0.1573343032172748, 0.0955310741971646, 0.11395494879356452, 0.08236376967813287, 0.11366271733173303, 0.15701517462730408, 0.15583346518022673, 0.08106412405946425, 0.12313677610031196, 0.11644008329936437, 0.09632234102381126, 0.10230343043804169, 0.1639525166579655, 0.18085988584373677, 0.09914290931607996, 0.0967222967052034, 0.09041914064437151, 0.13209100919110434, 0.11496231545295034, 0.08732949929045779, 0.12310344646019594, 0.1421276820557458, 0.12398033083549567, 0.18085759239537375, 0.15616294821458204, 0.160506739414164, 0.3167605570384434, 0.06592760235071182, 0.18749598546751908, 0.18001311485256466, 0.12418641549135957, 0.12783332408538886, 0.13143019750714302, 0.1280719648514475, 0.16493689455091953, 0.10362837862755571, 0.24871853100402014], [0.0049311518918589824, 0.01655941133919571, 0.00877713121008128, 0.019345253905547515, 0.009721374604851007, 0.033619357605597804, 0.09459265348102365, 0.019279171380081346, 0.047615333194179196, 0.024202865748000995, 0.006499452000883008, 0.014269116467663219, 0.06526591535657644, 0.04833127924108079, 0.010078010066146297, 0.013970858766697347, 0.05739239177533558, 0.0775654414402587, 0.01589148012655122, 0.055064619718385596, 0.02817590710973101, 0.052419615576842, 0.0368423480540514, 0.015107085163305913, 0.02435644536412188, 0.03190127301162907, 0.041397597906844955, 0.07619735199425902, 0.04634477637176003, 0.039542856360120435, 0.008381491011407758, 0.0038892914807157858, 0.02745013587575938, 0.018128189391323497, 0.02983608382887074, 0.11145823169499636, 0.04124110737549407, 0.05728420615196228, 0.03572117750133787, 0.035740763414651155, 0.03949504678270646, 0.0028348646010272205, 0.036284663514899354, 0.01924028284182506, 0.06172525856111731, 0.03785463409232242, 0.03970743502889361, 0.015104993579110928, 0.06469828010137592, 0.05867844633758068, 0.04211261436077101, 0.026723443530499935, 0.05057255504652858, 0.006839541809832943, 0.04474128277174064, 0.05923884840948241, 0.009867184146839594, 0.04799275133492691, 0.04639235185459256, 0.05345731953691159, 0.03350673097052744, 0.03407657824988876, 0.04700555073629532, 0.015256759810394474, 0.010810279969259031, 0.0372556708753109, 0.07711479240762335, 0.06556852161884308, 0.037522711724575074, 0.045904356254530806, 0.08287159207143954, 0.050002605986914465, 0.05562332884541579, 0.024330286142815436, 0.01842944197622793, 0.030516060734433786, 0.027504603578043834, 0.0559770084385361, 0.06306336354464293, 0.034029185971511264, 0.029542926166738783, 0.045146249434245486, 0.018760545012940253, 0.06076182025883879, 0.018506598193198442, 0.015523590313802873, 0.017549017344468405, 0.01661135319487325, 0.019968924278925573, 0.08444299096507685, 0.028766390335346972, 0.018393734070871557, 0.06548484468034335, 0.0450600924502526, 0.055999060826642175, 0.019722454915089265, 0.022314440026613216, 0.011692736813399409, 0.0490720732403653, 0.011594102418582355, 0.024530667711847594, 0.00966920968078609, 0.00921891603086676, 0.021193886940766658, 0.03945257727588926, 0.059568724994148524, 0.061721879456724436, 0.013791885825672319, 0.06379371149731533, 0.02138882496261171, 0.021481465348707776, 0.020708922695900713, 0.017371960416702286, 0.06802845533405032, 0.02337858988903463, 0.061978487830076895, 0.06492425940398659, 0.019637973912592446, 0.03118664671533874, 0.0805115115695766, 0.0593478414895279, 0.08841280758913074, 0.0345154818413513, 0.04436238881732736, 0.045454545212643485, 0.019075071439146996, 0.00730685014942927, 0.03390044073707291, 0.04467525113640087, 0.0687127782564078, 0.022402340845604028, 0.018792281792099987, 0.003397575388329902, 0.05072183275063123, 0.0628213979569929, 0.00912920946055757, 0.04266682819330266, 0.05702847308878388, 0.032615475223532746, 0.006594290840439498, 0.021578806286145533, 0.02176795301160642, 0.061811486791287146, 0.03421810029872826, 0.026489516886483346, 0.03605011770767825, 0.035373882922743044, 0.022355423541739583, 0.041226328882787905, 0.04118277371994086, 0.030604463669338396, 0.018483012315950224, 0.01784273479799075, 0.024125775688194802, 0.04283468418621591, 0.02193873349045004, 0.045213085133582354, 0.04691368727279561, 0.033539175122444115, 0.030045717222882167, 0.026418369097102965, 0.017860634551782693, 0.02042292188187795, 0.07834699164543833, 0.07173466788870947, 0.01205004147985684, 0.061982742244643826, 0.04084732297009655, 0.06584120448678732, 0.020390414965472052, 0.030794110814375535, 0.045359862436141284, 0.049095621798187494, 0.054257234292370934, 0.0685731153935194, 0.06019024271517992, 0.04098825469346983, 0.02329189346970192, 0.032025434742016454, 0.02347669587470591, 0.021707502326795032, 0.029673021685864245, 0.0207225086633116, 0.035172405519655774, 0.05527503342766847, 0.08869995682367257, 0.013237724579604608, 0.03999001433008483, 0.018624763370358517, 0.06477517847503934, 0.031331083072083335, 0.014974869222247174, 0.020698127203754017, 0.061673649187598906, 0.013470760646409221, 0.06826081286583628, 0.08580414578318596, 0.020097873073869517, 0.05243223972086396, 0.07562560481684548, 0.05822555813938379, 0.02239611867948302, 0.028351143867309605, 0.03857192363856094, 0.04807625524699688, 0.013170094146127147, 0.03385206458291837, 0.009828019105563206, 0.047010846702115874, 0.03989224421924778, 0.019598203278811913, 0.08239114856613533, 0.041741258930414915, 0.031227179004677703, 0.022059896096054996, 0.02968965597184641, 0.07315166613885335, 0.061997737868555954, 0.07376737560012511, 0.025858482711815407, 0.02674481229457472, 0.0696788424892085, 0.04036320519766637, 0.017453803614314114, 0.026712464833898202, 0.014235025171988776, 0.07724021282047033, 0.020864680409431458, 0.03760660579428077, 0.03593035288421171, 0.03250398852729371, 0.04799964864339147, 0.06375843446169581, 0.043713712732174566, 0.03691414384437459, 0.06617268919944763, 0.05168799197833453, 0.03155181390632476, 0.02318497670681349, 0.04586316578622375, 0.006760617585054466, 0.016397942057145492, 0.03233264147170952, 0.013409954578881817, 0.005860653689264187, 0.04275811490203653, 0.0445332100082721, 0.011910608470706003, 0.043139665321047814, 0.019848998303392103, 0.05681316035666636, 0.0652933960248317, 0.03083769990397351, 0.042463895332600386, 0.023993279851440872, 0.03135133734238999, 0.03247334588585155, 0.07190829142928123, 0.039770114701241255, 0.07753971139235155, 0.07897621752428156, 0.01136757095810026, 0.004707720912327724, 0.0430766701299165, 0.03313718383599605, 0.034321322438440154, 0.027069915385384644, 0.034431421530566046, 0.08107351498412234, 0.0325105703169746, 0.026198231981002858, 0.011998005477445466, 0.02620819117873907, 0.023629084661869065, 0.022855091640459638, 0.07935148131634508, 0.04084229502560837, 0.05043801173035588, 0.021796872174101214, 0.03507186698594263, 0.05658044320132051, 0.018111906247213483, 0.012932159904656666, 0.050725910746093304, 0.04866052478817957, 0.021412543154188564, 0.04851494849260364, 0.03642841115860002, 0.06361547391861677, 0.05313124953370009, 0.09112520382872649, 0.03268798008295042, 0.01119990665132978, 0.01579040555017335, 0.015159154244299446, 0.04273036281977381, 0.06957280103649412, 0.12056044648800578, 0.026186349136488776, 0.037555098201015165, 0.027569291714046682, 0.02402465870337827, 0.033676327405763526, 0.06327795024429049, 0.07435181138238736, 0.02887908821659429, 0.04110958014747926, 0.02084212760174913, 0.03738699793549521, 0.04206891670557005, 0.029678622992443185, 0.0942241343270455, 0.028384773759171367, 0.01813231997324952, 0.041103514044412544, 0.025864280793549757, 0.07415376058114426, 0.009529019256920686, 0.03213020733424595, 0.02701154780308051, 0.028869330883026123, 0.022452645735549073, 0.03158482463498201, 0.08783918765506574, 0.025539001283634986, 0.0329037643969059, 0.04421595756762794, 0.04392685415223241, 0.02337379943180297, 0.01835556817241013, 0.03417806673262801, 0.02434970242237406, 0.035251936609191556, 0.033421951412622414, 0.0549022598591234, 0.028219567445505942, 0.058543234664414606, 0.03744821875755276, 0.056273779299642356, 0.0391198101320437, 0.05004432571253606, 0.041171258980674405, 0.017090890855927552, 0.026113394747621248, 0.04064216451453311, 0.07717036442565066, 0.041639902762004306, 0.03998235706239939, 0.025612442521378398, 0.1025227600974696, 0.02891328638153417, 0.06795648312462227, 0.13262635975011758, 0.09474900830537081, 0.09419157143150057, 0.08582775880183492, 0.12808698761676038, 0.09920075442641973, 0.13387913895504816, 0.14631812434111321, 0.17347476498356887, 0.21885159079517635, 0.1055661253631115, 0.12695733537631376, 0.21162441931664944, 0.12498533619301659, 0.1176364083907434, 0.12771500114883694, 0.12229176930018834, 0.1862196203853403, 0.11593176557549409, 0.2007069672857012, 0.17788829601236752, 0.09754772098468882, 0.128075438950743, 0.09308851097843476, 0.21084801240691117, 0.07070061444704022, 0.12922385946980544, 0.28072250368339674, 0.16130780428647995, 0.12700963685555117, 0.15674937888979912, 0.09511809064341442, 0.08231674720134054, 0.1375536232122353, 0.10020064362990004, 0.22395972455186502, 0.11020039740417685, 0.12980353193623678, 0.1504084284284285, 0.11971914448908397, 0.17428405370031083, 0.23022826175604547, 0.18826868757605553, 0.12766754440963268, 0.11763805044548852, 0.08763332013040781, 0.10455075877585582, 0.1473731105881078, 0.13224342172699316, 0.14603588091475622, 0.18721501768699714, 0.13743706446673187, 0.08394728042185307, 0.14455101559204714, 0.1574566430811371, 0.13426358332591398, 0.13256079969661577, 0.11708290023463112, 0.12347187740462166, 0.14280317723751068, 0.23278595879673958, 0.06842138817799942, 0.0739912378734776, 0.16618674248456955, 0.13261114699499948, 0.0757677714739527, 0.1176240047706025, 0.23378991921033176, 0.07483944057353906, 0.21722264534660748, 0.3030186215681689, 0.15358456942651952, 0.17202290360416683, 0.1191733716321843, 0.12537800440830843, 0.18931699703846658, 0.16617899361465657, 0.10253166247691427, 0.11492787301540375, 0.15601870524031775, 0.08800654831741538, 0.09603043525878872, 0.07985814341476985, 0.1953346934169531, 0.17374403482036932, 0.07884204400969402, 0.06563227676919528, 0.0807992714856352, 0.15419724583625793, 0.14987017373953546, 0.07603102949048791, 0.1466982260878597, 0.16983932363135473, 0.16405759459095343, 0.11447925280247416, 0.14374395247016633, 0.12160051853529044, 0.12986496649682522, 0.0939509289871369, 0.13505605794489384, 0.11305738945624658, 0.1022689337176936, 0.0789310678041407, 0.1267314510686057, 0.11275541423154728, 0.19554704773638928, 0.07521221414208412, 0.15476243836539133, 0.17537566726761206, 0.11411991422729832, 0.15054146200418472, 0.10011725846145834, 0.16237271071544715, 0.17104035775576318, 0.20437161278511795, 0.1280144250818661, 0.2632946845676218, 0.08538255162004914, 0.08920000320566551, 0.15090591673340115, 0.1530577412673405, 0.323301336062806, 0.16674224553363665, 0.17820929735898972, 0.07773916676108326, 0.14381226737584385, 0.18479405902326107, 0.22528446918087347, 0.11188125756702252, 0.2043718434870243, 0.09884739374475819, 0.09966577483075005, 0.12316433819276945, 0.10964022603418146, 0.11540993143405233, 0.14452200143464974, 0.08653721466128315, 0.10283454015318837, 0.14687104895710945, 0.11883285561842577, 0.15721199049481324, 0.1057816416557346, 0.12270776554942131, 0.10116845848304884, 0.14350361536656106, 0.12475240869181496, 0.14164238023970807, 0.1142120999949319, 0.1513492308024849, 0.12043570461017744, 0.15291771878089222, 0.1599979874278818, 0.0778523056900927, 0.15475701008524212, 0.250090773084334, 0.07229936508727924, 0.12305183708667755, 0.125086139355387, 0.13885254279843398, 0.08955018834343978, 0.18798486994845526, 0.09930161187159163, 0.17838916342173303, 0.16468023189476558, 0.1512534487992525, 0.11701500602066517, 0.11641911656728812, 0.09868335111864976, 0.13272972777485847, 0.14682516641914845, 0.0974201699718833, 0.10953835757183177, 0.07843964560223476, 0.1997028575944049, 0.15158294540430817, 0.13477380094783648], [0.06984760771904673, 0.024221968205113496, 0.0043977894404503915, 0.015294545729245459, 0.020447715551459363, 0.05663892274190273, 0.048083786985703876, 0.0057517407611677685, 0.03327613423711487, 0.03907007012250168, 0.03337931227205055, 0.022102195969117538, 0.02137859943988068, 0.02602698331299637, 0.016199533328680054, 0.06845024627234254, 0.02147332123214645, 0.054560929603342495, 0.031333739536681345, 0.014951956791004964, 0.051849588485700746, 0.015010329462321741, 0.03666451420368893, 0.013309194673118847, 0.051275971944310834, 0.022575496197012917, 0.03984780017552631, 0.047156470495143106, 0.04895902930625847, 0.00986640976874956, 0.024983455826129233, 0.045536301897040436, 0.08772944140114955, 0.08255360342030015, 0.022022259454908114, 0.03941754451287644, 0.018927598638193946, 0.026654760519574796, 0.060555722032274516, 0.031914012506604195, 0.016956301738641093, 0.049736637222979746, 0.04229443460436804, 0.032228672943477116, 0.03916240516783936, 0.03859709050240261, 0.00921254713154797, 0.07514333605234112, 0.023234754035781537, 0.022546405704425912, 0.020785249403810928, 0.050420268039618216, 0.01689528956610177, 0.01664804497600666, 0.0292131818964013, 0.03478900270004358, 0.010772105589109873, 0.029691959598234723, 0.008083536954862731, 0.07290090673736163, 0.025858645560219884, 0.06640204760645117, 0.011913237793903266, 0.021580582351556847, 0.03089262392105801, 0.009758473506995609, 0.05840153619647026, 0.05656609557835119, 0.029743721642132317, 0.05886205791362694, 0.10786838111068521, 0.0214493740350008, 0.03325290459075144, 0.014377804206950324, 0.0705981624445745, 0.016116789375830973, 0.06166332866996527, 0.030016143274094378, 0.05275178560987115, 0.048406376104269705, 0.031926548441073725, 0.016690755362755487, 0.02896465148244585, 0.07019971989627395, 0.0034223745710083415, 0.05807626686458077, 0.013282480749434658, 0.021091609661068236, 0.0024197250022552907, 0.02876219359625663, 0.07528278856937375, 0.02178699948957988, 0.013708241965754755, 0.02794598551866199, 0.012587012889395868, 0.05215049162507057, 0.027804772203255976, 0.05685256627787437, 0.023144457988174896, 0.07780683027314288, 0.06377089236463819, 0.01881784899160266, 0.03338146322805967, 0.03530915407463908, 0.022347717080265284, 0.009576349618977733, 0.08016012542481933, 0.004521606390231422, 0.05125017065022673, 0.04710834200627037, 0.025436844443902373, 0.042445283117038865, 0.027215530696724142, 0.053416997593428404, 0.026579203948910748, 0.0811599399894476, 0.05429879795493824, 0.04667086333834699, 0.02596991173257785, 0.024138688209599683, 0.03511096417371716, 0.06552248980317797, 0.045276802964508533, 0.03736082683982594, 0.012346821670819606, 0.042780034975813966, 0.021005527315927402, 0.02882708190008998, 0.07492900719600064, 0.05902792579893555, 0.03217671073174902, 0.04018820762368185, 0.0615268617070147, 0.020066808044378246, 0.041008970367589166, 0.010982467560097575, 0.020860278413497975, 0.02784133845541094, 0.015783062104934027, 0.03822113121194499, 0.029759392408388, 0.05777599476277828, 0.023119767795183828, 0.015898670901411345, 0.0674092582027827, 0.03241871703150017, 0.0656475302364145, 0.025616323741685067, 0.011839648974793298, 0.05636132388774838, 0.05288777420563357, 0.013611797542710389, 0.10330394389373915, 0.052317747114492316, 0.040844062609331946, 0.042349925198193104, 0.03678085581798639, 0.030985264307154075, 0.010008952164623355, 0.016477060936657444, 0.03862285786973579, 0.03993065269397838, 0.03586547136572855, 0.010944126938868846, 0.02409257666606988, 0.04852831902514611, 0.04212420713156462, 0.11382410688591854, 0.06752101970570427, 0.010248013622393566, 0.08035337219813041, 0.027351212255390625, 0.055087791689272435, 0.035884694262806854, 0.03233638698501246, 0.04343651760635631, 0.02275840888198997, 0.048655469702290635, 0.015775691518293958, 0.061731976057801924, 0.05379582369433982, 0.025878625023843985, 0.03760858033118503, 0.026130539631204944, 0.014092844944181187, 0.029155994965029613, 0.018567888565095406, 0.025192129093089273, 0.03979150212502905, 0.10444425591932875, 0.04300319157274706, 0.018810154404491186, 0.00814336508379451, 0.01974725367368332, 0.04782353487930127, 0.04863385496927159, 0.03516579658857413, 0.028835132718086243, 0.018878913750605922, 0.016458116238936782, 0.019843235844746232, 0.003152242146565446, 0.04579961419637714, 0.03386617132595607, 0.009202422540900963, 0.03656778225143041, 0.016368081427312324, 0.013530323298514953, 0.05906428849058492, 0.005079005096506859, 0.027998359940413917, 0.03804326004215649, 0.04861812313486423, 0.012283689924515784, 0.04144971618162734, 0.04310480558446475, 0.029841973512832607, 0.01134909869038633, 0.027119465405121446, 0.0601890484935471, 0.05176156892308167, 0.027329631449122514, 0.041705221935574494, 0.056745693619762144, 0.03413673037929194, 0.03215891954356006, 0.016847980408264056, 0.013878773931147797, 0.02083288425845759, 0.009493045026569493, 0.030630180146545172, 0.014292045862280896, 0.07707674694912774, 0.04243415514273303, 0.014564844081178308, 0.019940534373745322, 0.011892972497402557, 0.016560505476913283, 0.05929330084472895, 0.07755902928433248, 0.038714629731007984, 0.022846067124711614, 0.05226196475060923, 0.07566766041730132, 0.027179965283721685, 0.014591356140694447, 0.00989901168005807, 0.025790775094979575, 0.03825793834403157, 0.031806817544358115, 0.051747424860617945, 0.04308020529736366, 0.009802518911393625, 0.024035623829279627, 0.035605877438294034, 0.010101956415123172, 0.02913577462147389, 0.041642202995717525, 0.016731816909408996, 0.09696078819355794, 0.04059062638719167, 0.014169030856075031, 0.0471299160271883, 0.03214857866987586, 0.10121434102100985, 0.020809547742828727, 0.07368458075714962, 0.015337429142424037, 0.02588300496738936, 0.04391182799424444, 0.027614816324785352, 0.028562263253011873, 0.033177783978836875, 0.03333873248526028, 0.04727809111188565, 0.05619370538209166, 0.014250141235866716, 0.0606314872524568, 0.03250885362337742, 0.00984512158070824, 0.03090302925556898, 0.05266245986734118, 0.03372086305171251, 0.03423487368438925, 0.03340933744662574, 0.06345709027456385, 0.038227784247802835, 0.013020731625147164, 0.036864580253937414, 0.036372157212878974, 0.028635673956679444, 0.059276683522122245, 0.01706582577233868, 0.04242152421336089, 0.016352397090356265, 0.026543665677309036, 0.024456351163930128, 0.036053608770349195, 0.015634598642853752, 0.0393208736287696, 0.06113450561783143, 0.003952229420454907, 0.057140485649662356, 0.007260844626996134, 0.03942287440544792, 0.03566801767530186, 0.06089007694806371, 0.01705749166597213, 0.04618606363822307, 0.04706126863935164, 0.011720611031965485, 0.02790542269524719, 0.029268038059983934, 0.06789898406714201, 0.07046620773949794, 0.030281206193779196, 0.03221971628123096, 0.00650584846568693, 0.05409342236816883, 0.051338027364441326, 0.04597109356628997, 0.07099855917372874, 0.0979443382737892, 0.008183675152914864, 0.08691767603158951, 0.05866851258490767, 0.03568227369604366, 0.03809256239661148, 0.019550147732453685, 0.004651465694353516, 0.0409685907486294, 0.009778408017674727, 0.07248668824987752, 0.011219149056289877, 0.038759626780769656, 0.03878722958532827, 0.043466529210231135, 0.045981186774692366, 0.056360638567379544, 0.023010026630280272, 0.05882732370602233, 0.0036555310777787653, 0.032065281710986576, 0.05057135403954557, 0.023308687211413468, 0.007628274732269347, 0.02267830103768834, 0.02301508341250675, 0.0217759207090629, 0.09733771439641714, 0.03128394524433783, 0.039982950780540705, 0.11687894617872578, 0.09338526148349047, 0.06462904917342321, 0.12834781647792884, 0.08686847545738731, 0.2088418286293745, 0.10736815152423722, 0.11551948769816331, 0.09262905456125736, 0.10086316522210836, 0.1973189605133874, 0.1686612239905766, 0.057557472560022555, 0.1154559361083167, 0.09757297605808292, 0.1659319254436663, 0.09730545005628041, 0.1525771077722311, 0.09573240232254777, 0.10901171940245799, 0.20762957153575762, 0.07950517628341913, 0.1596699021756649, 0.15877906712038176, 0.12938841778252805, 0.06996663633201804, 0.10364995604114872, 0.13519370555877686, 0.1205498884831156, 0.11637545962418828, 0.08262940256723336, 0.17367057661925042, 0.17498614745480673, 0.18428776333374636, 0.10972188772367579, 0.11876355005162102, 0.10254156908818654, 0.11025949780430112, 0.16130964990173066, 0.1089289313448327, 0.10024365596473217, 0.1312569539461817, 0.13112841227224895, 0.12769472652247973, 0.12342949610735689, 0.09510270825454167, 0.09041027897702796, 0.20007637755147048, 0.07250756677240133, 0.11791964247822762, 0.1255334432103804, 0.13877916602151735, 0.11000446363219193, 0.13263234442898206, 0.15256106720439025, 0.11077962882284607, 0.11868083663284779, 0.1601144511784826, 0.14559229543166502, 0.13461889140307903, 0.10416140181145497, 0.12678367112364086, 0.08852599401559148, 0.10631247995687382, 0.12382856969322477, 0.12738626450300217, 0.18486411097858632, 0.12659461769674504, 0.12438272924295493, 0.1173582768865994, 0.10961117116468293, 0.14417664068085806, 0.1479873340576887, 0.057838650686400275, 0.11781191825866699, 0.08099365141242743, 0.1033220472080367, 0.100114517179983, 0.16345182566770486, 0.07662484941205808, 0.0843819703108498, 0.09510274896664278, 0.14733914312507423, 0.18480013869702816, 0.10443149946097817, 0.11934905791921274, 0.09466723805027348, 0.08732911252549716, 0.1328130111630474, 0.16781378803508623, 0.2219613439270428, 0.1130034119955131, 0.114205626770854, 0.09670506191572972, 0.10540631679551941, 0.13834313941853388, 0.10133095404931478, 0.1426963893962758, 0.1972212107586009, 0.1763449545417513, 0.11496026627719402, 0.1843037496187857, 0.06391362220581089, 0.08079176010297877, 0.13196284749678203, 0.10940714246992554, 0.18555058485695294, 0.08762441096561295, 0.169814190694264, 0.1655160513307367, 0.20752499571868352, 0.10762307713074343, 0.13831765364323342, 0.11601058420326028, 0.08650183584541082, 0.1494511105120182, 0.10777076027755227, 0.1561919759426798, 0.09432227763214282, 0.12872210996491568, 0.09750023031873362, 0.1198404665504183, 0.1169265793370349, 0.08349238376000098, 0.09654796070286206, 0.09475679788738489, 0.21905768902174064, 0.13633447220282896, 0.15088155732623168, 0.2050098292529583, 0.11659691988357476, 0.08361524609582764, 0.11035073362290859, 0.1715954536838191, 0.06229244598320552, 0.1750643825424569, 0.19898282337401593, 0.2275224540914808, 0.13076394397233213, 0.1277491043188742, 0.20033979841641017, 0.11551878202174391, 0.13644535839557648, 0.05540366670382874, 0.16411601645605906, 0.15915494837931224, 0.14180319303912775, 0.15605711032237324, 0.18595565669238567, 0.1502234869237457, 0.11666428484022617, 0.1627225498003619, 0.19932107308081218, 0.11416192911565304, 0.1661039883536952, 0.13077359274029732, 0.23065354036433355, 0.10063021736485617, 0.11551125028303691, 0.08587463200092316, 0.19974960865718977, 0.14878917245992593, 0.14511372468301229, 0.1189099100551435, 0.10743010855679001, 0.12454905174672604, 0.07488477349813495, 0.2842074323977743, 0.11399519949087075, 0.20080319712204592, 0.13709133730403014, 0.09504859508680445, 0.1622870388839926, 0.24078393248575075, 0.08973400347999164, 0.12340120119707924], [0.06785642635077238, 0.0338215780045305, 0.04759849874036653, 0.04757397987746766, 0.01849176881036588, 0.032068216374942234, 0.044933935826910396, 0.027997642389631698, 0.040088256022759845, 0.0318785149471036, 0.07904058335615055, 0.07983522250183991, 0.024391975154035857, 0.007602738066842514, 0.046936526761523316, 0.05526754579373768, 0.024628056146736656, 0.08999344134437186, 0.021220626309514046, 0.02614945379484977, 0.03721605460824711, 0.017206299484574368, 0.025178960424714854, 0.049121792893856764, 0.04489012960610645, 0.017961824479113733, 0.022344780719972084, 0.06334994280976908, 0.05174002882891467, 0.041063748499644656, 0.026569204039073417, 0.007652838548113192, 0.05459149082058242, 0.03125831697668348, 0.037752969190478325, 0.035342103735144646, 0.032204445850636275, 0.049120296724140644, 0.03315923961677721, 0.015078854713855045, 0.013993065521520163, 0.014322120230644941, 0.05198575350056801, 0.0153598886515413, 0.051118002206619294, 0.028340438281052878, 0.028729288040527275, 0.03528426880283015, 0.04535116361720221, 0.020303632032924464, 0.072744897965874, 0.011395856538521392, 0.01444126249823187, 0.03856287198141217, 0.05681202041783503, 0.04897966355617557, 0.05079169810882636, 0.022688512989719, 0.044742344679044824, 0.006150386021805129, 0.038292401137628725, 0.09778181556612253, 0.04977156820573977, 0.05949853054646935, 0.05909792347145932, 0.0956121523465429, 0.023279637430927584, 0.015452975174412131, 0.050627194078905244, 0.0646123436412641, 0.053789072270904265, 0.01297748349939606, 0.04955096968582698, 0.06346576195210218, 0.019137047131412795, 0.07563005600656782, 0.03449464063825352, 0.011759340962661164, 0.014462062989228537, 0.0462512606754899, 0.0456610234188182, 0.025360750134236047, 0.04013699858582445, 0.0024772800388745964, 0.00856166665575334, 0.04337988707369991, 0.050197046981858354, 0.05351225033934627, 0.012599519986127104, 0.018196427961811423, 0.04291288873979023, 0.01151715315479253, 0.09084214616034712, 0.06635856708245617, 0.05748444862131562, 0.021233369197164263, 0.04336183464952877, 0.009361054698404456, 0.0957843984610268, 0.08528942947408982, 0.048678614531776736, 0.08782862965017557, 0.07573867589235306, 0.01264566121556397, 0.0021200385609907763, 0.08233734752450671, 0.04302262481568115, 0.03707847145519086, 0.03620602809158819, 0.024913466635293195, 0.010420691454783082, 0.03923132396968348, 0.021472225398091332, 0.0030696205420619144, 0.032389088799910884, 0.025092973074476634, 0.04777041237269129, 0.04470986999305231, 0.004917381871824286, 0.029771293912615095, 0.011114488422338451, 0.06189077360821622, 0.07258953380265407, 0.009773556492291391, 0.054201278902058087, 0.030926350504159927, 0.06408552226743527, 0.01891676752295877, 0.050776987469622066, 0.061847177733268054, 0.05482745137331741, 0.028819417847054343, 0.05836851189711264, 0.04742640529626182, 0.05406661005690694, 0.022484979625525217, 0.021966529677488973, 0.025382734668840255, 0.054447169814790995, 0.029446485984538282, 0.024419157266882912, 0.040341054421982596, 0.03465812347297158, 0.013865045471382993, 0.06096094993076154, 0.07507662927465779, 0.04241907809461866, 0.05685224397374051, 0.0822287547801222, 0.05652252005945359, 0.019586563010567, 0.012962589655736727, 0.040173544481928856, 0.01990460085549525, 0.04149837392781462, 0.01193279741398458, 0.04662067888836775, 0.03995620971545577, 0.02490125470129507, 0.008479272996607636, 0.01988661289215088, 0.01762222109495529, 0.053183269420904775, 0.009078449103981256, 0.05161249138680952, 0.007466696036447371, 0.04777852425883923, 0.02847105118313006, 0.04221773300586002, 0.006258926603810063, 0.035774618919406614, 0.020638188812881708, 0.019543033292783157, 0.01408764736593834, 0.01705842634796032, 0.001263819181726181, 0.04718667208882315, 0.03550771038447108, 0.033228294125625064, 0.04900184825861028, 0.07416715486241238, 0.03812960023060441, 0.02517566952987441, 0.07018684808697019, 0.05034906936011144, 0.04648979966129575, 0.04417963898075478, 0.015179322001391223, 0.01283222102626626, 0.03980318310537508, 0.07280992876206126, 0.029244000956948315, 0.018910865964634076, 0.02793381599310253, 0.024853981166545833, 0.03747004383642759, 0.04428063552560551, 0.02742189185560814, 0.04700020048767328, 0.013655640234771584, 0.034456089671169005, 0.02315630012058786, 0.06875754799693823, 0.014721668791025877, 0.042989427489893775, 0.06289665427591119, 0.005677316071731704, 0.016642553931368247, 0.06824492836104971, 0.040209384701613865, 0.0363865014431732, 0.03153820249385067, 0.03768400628385799, 0.023820745359574045, 0.07120190933346748, 0.047860060419355116, 0.05225745588541031, 0.01584278845361301, 0.020053210202604532, 0.008904136002196797, 0.025058652773233395, 0.017247839398416023, 0.03833661787211895, 0.04645299252920917, 0.014107176451943815, 0.03782675987375634, 0.05179120733269623, 0.0055038799764588475, 0.07210765180311032, 0.06320907215454749, 0.06499526809368815, 0.009895513832036937, 0.024990387061344724, 0.03924425006178873, 0.07839982916734048, 0.023847625524337803, 0.03960029434944902, 0.04099221733797874, 0.04127809771203569, 0.033829184382089546, 0.037552760647875924, 0.07173806056380272, 0.036336652868028195, 0.10211582907608577, 0.043975057279957194, 0.04570141660847834, 0.04803268312077437, 0.030760180670768023, 0.07850572134235076, 0.014877445164269634, 0.06565072613635234, 0.10306311145957027, 0.05297821613826922, 0.022635017288848758, 0.043885090321834595, 0.03605435176619461, 0.00770052259654871, 0.008522640714155776, 0.005272290037412728, 0.04131953584562455, 0.05028660003361957, 0.04934521411944713, 0.029344736265816858, 0.048469198268971274, 0.047997989625270875, 0.06013630596654756, 0.016240342121039118, 0.08999549730547837, 0.011043548434307533, 0.012960465841128357, 0.04008987772145441, 0.01567240322141775, 0.03483257482626608, 0.016623955286507095, 0.028033677688134567, 0.041170919713165076, 0.030845852502222573, 0.02766292615394507, 0.029858641725565706, 0.01424383934188102, 0.04620583275599139, 0.04396178174231734, 0.022684012606207813, 0.00771145718837423, 0.037217852726046524, 0.055833362575088225, 0.06350874036018338, 0.0293609803941633, 0.04103487004925098, 0.07351296568023306, 0.045616345280515294, 0.029027232767215798, 0.00853410710780216, 0.009875899929154133, 0.026630290850464786, 0.02196626165615661, 0.021205717198816792, 0.04349331438009228, 0.06291796706084694, 0.027864208478214483, 0.019455731280946305, 0.007428905028583748, 0.056525620964488814, 0.04660673499373453, 0.05665159099070089, 0.009533888593848263, 0.030411328854305402, 0.0168129425562386, 0.054320368583181074, 0.021495061494143944, 0.05803254206797906, 0.028904601133295467, 0.03424869205004402, 0.03651083280731525, 0.0689120911327856, 0.0383137512419905, 0.03762769466266036, 0.02548210951499641, 0.049289696384221315, 0.038945674297532866, 0.045302865494574816, 0.05645685822569898, 0.03094874894512551, 0.04989092251552003, 0.08528770599514246, 0.037514372529195886, 0.0192687015847436, 0.014954090783638614, 0.04013593667852027, 0.030236165039241314, 0.05276641482487321, 0.017065484808491807, 0.05624337075278163, 0.06400039326399565, 0.012848859553092291, 0.018496379455817596, 0.015323261331234659, 0.0865509957075119, 0.03989637989018645, 0.042729972662138085, 0.05407662523378219, 0.05590890048603926, 0.026939246504168426, 0.021775310027546117, 0.08535315748304129, 0.015520959294268062, 0.007005206134635955, 0.01004559051112405, 0.018953613670808927, 0.015171279665082693, 0.029816793078290563, 0.0450161640931453, 0.11385349423757621, 0.14645807897405966, 0.08485130619789873, 0.08433026594242879, 0.1475841078375067, 0.12990419939160347, 0.12065687988485609, 0.30594815579908236, 0.12451014454875674, 0.1359790148479598, 0.1474998202174902, 0.18382629166756356, 0.11954329535365105, 0.10419080273381301, 0.17004223274333136, 0.11355665552296809, 0.08899506527398314, 0.20184036503945077, 0.07339059188961983, 0.11204236213650022, 0.1490142018135105, 0.10990048492593424, 0.19675656354853086, 0.09753515451614346, 0.13477602654269763, 0.10686547242637191, 0.1803398294640439, 0.1681540190641369, 0.1451933846942016, 0.17176670235182556, 0.12186620570719242, 0.08390796610287257, 0.18123287654348783, 0.1085056137027485, 0.1601394484085696, 0.13725569205624716, 0.14010301498430117, 0.12198178736226899, 0.154114980250597, 0.19206000199275358, 0.15159437193402223, 0.11627663778407232, 0.16330824765775884, 0.051797653415373394, 0.11324917059391737, 0.13349899649620056, 0.15748644433915615, 0.2720393181911537, 0.18162413340594086, 0.1512423615370478, 0.1517266591212579, 0.05577017739415169, 0.2387639880180359, 0.19784185316945824, 0.1493507008999586, 0.13487482124141284, 0.10294877152357783, 0.08877179332609687, 0.1374192868492433, 0.10962365620902606, 0.20531728704060825, 0.18918135788823875, 0.10360842969800745, 0.1299602056720427, 0.11117508581706456, 0.1872451582125255, 0.07725513380553041, 0.1368027835019997, 0.09187761774020535, 0.1454515808394977, 0.14430592874331133, 0.18238762100892408, 0.11380562359201056, 0.09441041933106524, 0.10272390501839773, 0.24836422715868267, 0.16680365295282432, 0.13998177434716905, 0.10932768601924181, 0.12100743821689061, 0.163626154884696, 0.04633315645956567, 0.10357711530689682, 0.09818730130791664, 0.12487028379525457, 0.09623428753444127, 0.1717426957828658, 0.11265810552452292, 0.11815695331564971, 0.1564701617296253, 0.23857766230191502, 0.18444286286830902, 0.1741192646856819, 0.08385983082864966, 0.17024569825402328, 0.1248223249401365, 0.10779943516744034, 0.11364752493266549, 0.10451586850519691, 0.16126036111797604, 0.133738139378173, 0.12881379361663545, 0.16113225370645523, 0.13560523704758712, 0.08178957298930202, 0.20545675312834127, 0.21670663303562573, 0.11308351305446454, 0.144535327862416, 0.15976682411772863, 0.0940886444545218, 0.11022133020950214, 0.08617534515048776, 0.08774010118629251, 0.13032974941389902, 0.07935419545641967, 0.17490487253027304, 0.08078575506806374, 0.13518928151045526, 0.061929178690271716, 0.039769873821309636, 0.13122153441820825, 0.10793968835579497, 0.0853897440912468, 0.13521874350096497, 0.0900064285046288, 0.13841909462852137, 0.13362197418298039, 0.14647044188209943, 0.12759076138692244, 0.1229312749845641, 0.12474079217229571, 0.13952972074704512, 0.1528145136045558, 0.12039637672049658, 0.03780433429139001, 0.1586372261600835, 0.07267387570547205, 0.12417416114892278, 0.16159631737640925, 0.11370442687932934, 0.10962775456053869, 0.21423979183392866, 0.12572610644357546, 0.15063659261379922, 0.2000028650675501, 0.09248502871819905, 0.15062664529042585, 0.19192908544625553, 0.08579216964010682, 0.17946103161999158, 0.06663272915674107, 0.16142757928797177, 0.12443627922662667, 0.1350401123719556, 0.0723433680832386, 0.11029284101511751, 0.12491664130772863, 0.10929582201476608, 0.092499508655497, 0.11701989147279944, 0.13454479537904263, 0.09441006649285555, 0.10291642575923886, 0.09425328419144664, 0.1280604297561305, 0.15822542325726577, 0.12433443112032753, 0.18047488507415566, 0.14147723838686943, 0.13646727507667883, 0.17266235500574112, 0.04635096121845501, 0.09585470147430897, 0.07010813802480698, 0.1881753211574895], [0.025277173279651573, 0.022110109383772527, 0.03872908591958029, 0.06125266570597887, 0.01588885928504169, 0.06098629999905825, 0.027418370258861353, 0.024134108098223805, 0.04881976677903107, 0.06017337433461632, 0.0540582471128021, 0.01750051396499787, 0.010782995227990406, 0.011393127131408878, 0.04854133671947888, 0.04970501749111073, 0.06436558081103222, 0.05399907207382577, 0.041904409282973835, 0.015162772532286388, 0.022966242461864437, 0.10551362710871867, 0.025593528357733573, 0.0963561592091407, 0.03774786999981318, 0.024189822608605027, 0.030514035307403122, 0.09943360050341912, 0.0378317979962698, 0.01787785068154335, 0.08182488395167248, 0.024998449753703814, 0.05674022802018693, 0.09895031393638679, 0.07823529799601861, 0.0015680284829743738, 0.026452255135934268, 0.012137495313904114, 0.035601185368640084, 0.048323523585817645, 0.06789553710924727, 0.04296159398342882, 0.06216114267174687, 0.018260386672669222, 0.04494604428431817, 0.030863813324166194, 0.041396362973111014, 0.014033100783957966, 0.0023921749962028116, 0.06408898279603038, 0.05486668426809566, 0.01019427619342293, 0.02726691954636148, 0.050240076280065944, 0.027257121500692198, 0.103814792553229, 0.03170387360400387, 0.024005283135920763, 0.012989513077107924, 0.06511141971818038, 0.023482129243867736, 0.040894800065351386, 0.0279088577787791, 0.03643192596999662, 0.021511692387451018, 0.08703388193888323, 0.053041299538952966, 0.026091445836105516, 0.05279636536059635, 0.016528269974514842, 0.03204150584393314, 0.06239385982709272, 0.019793726537110548, 0.02999559384105461, 0.013148513339859034, 0.05491645820438862, 0.029575597627886703, 0.0222443897676255, 0.02008080791815051, 0.04181551101750561, 0.0322450493861522, 0.024581411953217218, 0.03087435775835599, 0.05492304677941969, 0.037281071833734, 0.05372888621475015, 0.03691110061481595, 0.012419643745358502, 0.0414278978881027, 0.025527912325092723, 0.02650344551407865, 0.0892647761585457, 0.017592564025627713, 0.12326933470155511, 0.026173127881650413, 0.03034003857257111, 0.040203457698225975, 0.012748013982283217, 0.03093747847846576, 0.05154626976166453, 0.05789067396628005, 0.012356077736642743, 0.01999644565928195, 0.014729492299790894, 0.020598621739606773, 0.02864367388454931, 0.0006857445592426562, 0.07068326430661337, 0.09270130497004304, 0.04456443279715521, 0.04025906025032912, 0.015303368380825435, 0.028537618861134564, 0.026741545148459927, 0.04598174656608275, 0.04841892221676452, 0.01399293914437294, 0.019443578718762313, 0.043578216074300666, 0.02616422889488084, 0.017052071867510676, 0.012185749331755298, 0.033356557600200176, 0.026510410676045076, 0.016122010702799474, 0.04191334219649434, 0.047218281642666886, 0.03988739947921463, 0.03221004715721522, 0.08335631713271141, 0.02362121026297765, 0.03956391469442418, 0.03968397807329893, 0.04202371948797788, 0.04290450543963483, 0.01660225404027317, 0.04478534344317658, 0.04850346428741302, 0.026923085496361767, 0.01972792560367712, 0.01977563340083829, 0.04545322206935712, 0.016617990963693176, 0.04412870474957994, 0.005940380705786603, 0.036000438766287904, 0.028776266412543397, 0.051242336963436434, 0.0810709772631526, 0.021426704180027758, 0.0595708488087569, 0.015313212227608477, 0.015267869124987295, 0.05912980783198561, 0.06662449174161468, 0.03296598945079105, 0.021594631419117962, 0.03521002010841455, 0.021526023047044873, 0.01926384157767253, 0.01891609577329031, 0.053907629302037616, 0.04899429616385272, 0.057972783488886695, 0.009931423601561358, 0.05320018869159477, 0.0416097350950752, 0.050904891320637295, 0.056082978645073514, 0.05776184730763946, 0.08209648116358689, 0.018587396446881548, 0.03694488148071936, 0.04009219152586801, 0.021873192096661245, 0.05874572308467967, 0.041909233666956425, 0.017174885009548495, 0.010831468921553875, 0.05865973234176636, 0.05332917819863983, 0.04843259469739028, 0.03053180274686643, 0.04532920622399875, 0.0316670596865671, 0.015001131920143962, 0.009752683058780218, 0.04888198504756604, 0.04625082980575306, 0.0537880510757012, 0.004802389694045165, 0.016955553653783033, 0.013954065024985798, 0.013455765022497092, 0.08606956832643066, 0.03085658692621759, 0.0048731231529797825, 0.022259010500939827, 0.024091065229315842, 0.05274834883000169, 0.036154422110744884, 0.023349272087216377, 0.04685113312942641, 0.08020689684365477, 0.12619817682674953, 0.032990708481520414, 0.040674513671547174, 0.04384403895320637, 0.03577549083690558, 0.050827772423092804, 0.08856566795813185, 0.03191099302577121, 0.04179160962147372, 0.018621508098606552, 0.011728614352510443, 0.03933028830215335, 0.1068039293001805, 0.0414010380793895, 0.036416852314557345, 0.015318720235622354, 0.03662237717903086, 0.047169579791703393, 0.01658170630357095, 0.028034386757229055, 0.03220425586083105, 0.016792823992935673, 0.08677688001521996, 0.044955781261835775, 0.025680116211463298, 0.011004789665873562, 0.027636000188067555, 0.022144087024831345, 0.019547433592379093, 0.0326407981504287, 0.009206817751484258, 0.10623873677104712, 0.014398623357660003, 0.03740695704306875, 0.017411756495546018, 0.05936387527201857, 0.019553330061691146, 0.08546113954590899, 0.06953203465257372, 0.03754685739321368, 0.09412934977029051, 0.024063096015847156, 0.08996210659721068, 0.08313639036246709, 0.013421800103969872, 0.04157064129997577, 0.03286365958462868, 0.05177025756399546, 0.07612033826964242, 0.027946706462119306, 0.030871419701725245, 0.018766738341322968, 0.00537213434498491, 0.07391680936728205, 0.003763049192327474, 0.022346563570733582, 0.043309848689075024, 0.05162999759029065, 0.030407644409154142, 0.025440155694793378, 0.03632302788485374, 0.0194893696544958, 0.06207418840910707, 0.04736819377701197, 0.042820540123752186, 0.04107895107673747, 0.04310855109776769, 0.033416363676743846, 0.06845800192760569, 0.036384472623467445, 0.026382564500506436, 0.016152556653001478, 0.029221504128405025, 0.0077077812249107015, 0.03093977871217898, 0.03202398267707654, 0.0643547988895859, 0.009806244068646004, 0.019095213751175573, 0.0839863708242774, 0.01825317893443363, 0.022397748859865323, 0.06757704634219408, 0.04334190268335598, 0.08108895844114677, 0.026032197854614685, 0.004672459143746112, 0.023428633542997495, 0.10307124709444386, 0.033059871555971246, 0.03577988774382642, 0.030074907799384425, 0.021985504909285476, 0.01781618711538613, 0.03327023437512772, 0.012079592528087752, 0.04137907050816076, 0.04545771397118058, 0.05151407666770475, 0.003951645880338869, 0.026964655944279263, 0.025957670960841433, 0.11520346679857799, 0.0349738356391234, 0.05157758754545024, 0.06397589136447225, 0.009570288604923656, 0.012958940833673945, 0.04940511179821832, 0.018386114122612134, 0.0138010452002553, 0.040173581801354885, 0.0657977375334927, 0.020496580250827328, 0.016721426841935942, 0.05681947412501488, 0.043162922108811994, 0.0027484603758369175, 0.021700649123106684, 0.029008416991148676, 0.0733054628861802, 0.02614875660011811, 0.07661091908812523, 0.027912549009280543, 0.007050111158085721, 0.03235060568632824, 0.04747353973133223, 0.06345588926758085, 0.09550885896065406, 0.04975164641759225, 0.01472957372399313, 0.02354692424913602, 0.06349066418728658, 0.02325369364448956, 0.07403940707445145, 0.04015299844156418, 0.005477798786679549, 0.05479925824329257, 0.022660119691863656, 0.06054284343762057, 0.011141290555575063, 0.06310545307184968, 0.08106942341795989, 0.03208507118480546, 0.027565680211409926, 0.04580256921638336, 0.040595603441553454, 0.05153759129877601, 0.12483117303677968, 0.10131636554641382, 0.10588039564234869, 0.11640348312045846, 0.08610791912568466, 0.13080386897282942, 0.15919053075569017, 0.10868663327502352, 0.11397762543388776, 0.14665437915495463, 0.09769275784492493, 0.1308145626847233, 0.09668612400335924, 0.1337513029575348, 0.17986313147204264, 0.07698395728532757, 0.10467339719512633, 0.15999071353248187, 0.16900749398129328, 0.15293343365192413, 0.13037655475948537, 0.3297672319625105, 0.08609407701130424, 0.1830381325313023, 0.09126986749470234, 0.09263823514005967, 0.11215320083179645, 0.15510072878428868, 0.20287150756589004, 0.05920876895210572, 0.2025877306503909, 0.15924853192908422, 0.09803182857909373, 0.17799059195177896, 0.15259199483054026, 0.19554077807281697, 0.1763737651386431, 0.09831892353083406, 0.13622320603047097, 0.12692112874771866, 0.23922104920659745, 0.10157701798847743, 0.15066123700567655, 0.07289845044059412, 0.10008226641054664, 0.1742577129708869, 0.13142415854547704, 0.15156208723783493, 0.14521151514989988, 0.08628918297056641, 0.2712588400713035, 0.0905544473124402, 0.11971748886363846, 0.18049914948642254, 0.14018179289996624, 0.1722978867058243, 0.0836415257570999, 0.15337108873895236, 0.0771655807537692, 0.15021438098379544, 0.06554057954677514, 0.07853048787053142, 0.1266191942351205, 0.11354194488376379, 0.070805142766663, 0.11722607112356595, 0.1376068882111992, 0.102764338920159, 0.15352280916912214, 0.10637505445629358, 0.15402986481785774, 0.22616328059562615, 0.10544594324060849, 0.06258484707879168, 0.12245864820267473, 0.11472493676202637, 0.1287410275212356, 0.08232339684452329, 0.06663322448730469, 0.15723293008548872, 0.09287025340433631, 0.12640530642654213, 0.13779689158712113, 0.20039896667003632, 0.12220064204718385, 0.18699604086577892, 0.14768373034894466, 0.11580175826592104, 0.14436213858425617, 0.07497049282704081, 0.07271188723721675, 0.1487336547247001, 0.12179153971374035, 0.3179030471614429, 0.11904487067035266, 0.11605462112597056, 0.1162893535303218, 0.13292198388704232, 0.1067036757511752, 0.1226273455790111, 0.10808330029249191, 0.06855663377791643, 0.06210074626973697, 0.10293796246073075, 0.1492632513067552, 0.062135724749948294, 0.12197113436247621, 0.12709575652011804, 0.1825203967413732, 0.14962583327932016, 0.10289042429732424, 0.3040432637291295, 0.12245483483586993, 0.11875961454851286, 0.10038275564355509, 0.12935103050300054, 0.142568865524871, 0.16599139225270065, 0.16394733265042305, 0.08238226654274122, 0.1285243441483804, 0.11178160112883363, 0.15726749465933867, 0.11527461798063346, 0.12575201291058744, 0.07146273140928575, 0.15526821836829185, 0.10534640215337276, 0.09334705317659037, 0.1735969012869256, 0.24438529780932836, 0.11834141984581947, 0.22183592351419584, 0.1934132586632456, 0.06619274669459888, 0.0826579485354679, 0.09723762369581632, 0.1054492477061493, 0.11742461047002248, 0.08717620465904474, 0.11771220075232641, 0.14312253652938775, 0.12762115975575788, 0.10577873752585479, 0.1340130546263286, 0.17366218992641994, 0.08238044128354106, 0.15587420442274638, 0.171390563249588, 0.05356040596961975, 0.24803535480584415, 0.08029670773872308, 0.09253754054329225, 0.16342446713575295, 0.1190916895866394, 0.22843331950051443, 0.1577054483017751, 0.1469029536736863, 0.11466570065489837, 0.0764254822528788, 0.11683511281652109, 0.09790157699691397, 0.19959110287683351, 0.16628458723425865, 0.13820465042122773, 0.1594188306480646, 0.16961388715675899, 0.15163451406572545, 0.13810483791998454, 0.1535326750682933, 0.18917537320937428, 0.13594603804605349, 0.0860554955101439, 0.21120997012725898, 0.07338838665080921, 0.1445606236479112], [0.018869468543146337, 0.03735168018777456, 0.03343854159382837, 0.07231358718127012, 0.02971182031823056, 0.031067828448223214, 0.025003007812691585, 0.03599584847688675, 0.040957316889294555, 0.01653620713789548, 0.09465474622058016, 0.021085082154188837, 0.020076049691332237, 0.06169149465858936, 0.051643805777920146, 0.025820722238027623, 0.03702636675110885, 0.03308362367429903, 0.04064712460551943, 0.00475931544289259, 0.07640187601958003, 0.056194441592586894, 0.09122854471206665, 0.02617359098180064, 0.014003800793683954, 0.021334828842165213, 0.01974263454654387, 0.09682798531970807, 0.06428564260048525, 0.050002042802848985, 0.022114160237833858, 0.016522358238164867, 0.045181920020175834, 0.023218357237055898, 0.027626225891123925, 0.01801398516233478, 0.06059374713471957, 0.022638102926846062, 0.004652503004763275, 0.03570670095671501, 0.005748946893228484, 0.04405261043991361, 0.009746365049587829, 0.056201851194990535, 0.08057952791984592, 0.06726065224834851, 0.08114704103874308, 0.04236312609698091, 0.03305445006117225, 0.025323449367923394, 0.040998643064605336, 0.03283436044252344, 0.04136506893805095, 0.01451824908144772, 0.05607264116406441, 0.024682547597746764, 0.015801426655213748, 0.019667617411219647, 0.05777307027684791, 0.032206766440400054, 0.021730623407555476, 0.02692488022148609, 0.056794171554169486, 0.024471808191654936, 0.0548470881767571, 0.031383652572653124, 0.01593831939888852, 0.06888495651738984, 0.005330161865068865, 0.05524231446906924, 0.08437804837844201, 0.04708725313789078, 0.03917662386915513, 0.05834884795227221, 0.05024988450376051, 0.04162172480885472, 0.011184314764770014, 0.03999536118603178, 0.05441277148202062, 0.02702071820385754, 0.04419091623276472, 0.02234604618778186, 0.049623640786324225, 0.01837508114320891, 0.02219290253041046, 0.021523079901401485, 0.046573541060622246, 0.03775487926655582, 0.02438356980149235, 0.05238780924784286, 0.08202634778405939, 0.027049111501712884, 0.03359430270003421, 0.007270632494640137, 0.03111865750647017, 0.025270364180739437, 0.05037555258188929, 0.03896729920857719, 0.046519214154354165, 0.0628296285867691, 0.013779200613498688, 0.041945942411465306, 0.04328519751184753, 0.028990595268883874, 0.018571016611531377, 0.07665593988661255, 0.03822457477716463, 0.02553077065385878, 0.024392991260226284, 0.06109520486955132, 0.04550235139738236, 0.00676518030897049, 0.05191870067002518, 0.023837654452238764, 0.012809547778618122, 0.001591035909119195, 0.020857521864984716, 0.012052076236744012, 0.040284308538373025, 0.01571673869953624, 0.021976604226178358, 0.01154072122049651, 0.01557458730946694, 0.052533348223992755, 0.032068277443093915, 0.009833382076716848, 0.03205951416332807, 0.05657292503331389, 0.017008635448291898, 0.04016013662996037, 0.030932219832071235, 0.04339193446295602, 0.013233364992109793, 0.06058534687118871, 0.035655396923954995, 0.029307898599654436, 0.02789270185998508, 0.027879483997821808, 0.07596965599805117, 0.015939381306192706, 0.0687514343964202, 0.03878168595422592, 0.025050496782309244, 0.013610578724183142, 0.03706083972273128, 0.023380623797753027, 0.07249418606183358, 0.03858857149524348, 0.025253997916089635, 0.023608491124053086, 0.06223292489136968, 0.029346917755901814, 0.03910665333803211, 0.019516845233738422, 0.015011598322806614, 0.011924887392004686, 0.02985159174672195, 0.03303240106574126, 0.041803178643541675, 0.03354377558987055, 0.03908540501392313, 0.030521794355341365, 0.029194735921919346, 0.03340121198977743, 0.01219704863615334, 0.014660346188715525, 0.02676399956856455, 0.015581233559974601, 0.01635921636729368, 0.012597602276530648, 0.00927441001736692, 0.03780635293307049, 0.06711157131940126, 0.007363238105816501, 0.044898892885872295, 0.024381647851052027, 0.009740055522083171, 0.06434939775083746, 0.014319036288985183, 0.04152572906709143, 0.08203495839344603, 0.0038961976949524668, 0.06582395612661328, 0.03921772952058485, 0.09619306653205838, 0.044101593882909844, 0.05659632770610707, 0.03550288600048848, 0.03658177364351494, 0.018640815812562193, 0.007621861728174346, 0.015539386609037007, 0.041625738343490024, 0.008568655566445418, 0.08253204636275768, 0.039947911232177696, 0.04592994041740894, 0.023937507665583065, 0.022490287465708594, 0.027099701376365762, 0.05586042933698211, 0.043761230539530516, 0.04054407549223729, 0.05431466888902443, 0.054865900560149124, 0.039776099380105734, 0.06117383350751229, 0.039733877538570335, 0.030011267999985387, 0.020204414946160147, 0.032730300312063525, 0.020723093899765184, 0.04534086345561913, 0.04680922341399959, 0.011729577024068152, 0.03275124329541411, 0.022326780882264887, 0.019403706304728985, 0.06589807929205042, 0.06891388246523482, 0.0461867489585919, 0.058042998292616436, 0.04003954738644617, 0.032228503309722455, 0.05855510224189077, 0.02780848548614553, 0.0413319089316896, 0.06358063114540917, 0.013984406566513436, 0.12524349162621157, 0.025027611492467777, 0.03480365227109619, 0.03788612490253789, 0.029789858630725315, 0.10348393209278584, 0.008335957070812583, 0.05235762122486319, 0.008368316405851926, 0.04357956296631268, 0.015515446197241545, 0.052108554768243005, 0.006677369395869651, 0.033559476890202077, 0.006682516083986099, 0.04152000901688423, 0.03956263565591403, 0.06426038074174098, 0.04348913121170231, 0.0460157615265676, 0.028183537236015712, 0.025695093175662414, 0.04966052255726286, 0.02743616483972541, 0.02501239364833704, 0.07258728785174233, 0.05017504548387868, 0.05543022795713373, 0.038199553798351965, 0.025171927409246564, 0.020734930943165506, 0.03499621033136334, 0.006101766019128263, 0.015696939047692076, 0.016597141278907657, 0.010078817522818488, 0.040014584083110094, 0.029088775893407207, 0.009697222150862217, 0.03155131518308606, 0.035854126260216744, 0.016135318470852714, 0.014806531469470688, 0.06627294274845294, 0.05745418595948389, 0.014975033766989197, 0.02851193631067872, 0.020719317852386405, 0.013469256843174142, 0.030865801431770836, 0.07026454713195562, 0.03366288901971919, 0.018572346540167928, 0.02734737513986017, 0.034937513659575155, 0.03423800851617541, 0.03967493320150035, 0.02688249383520867, 0.04570197639986873, 0.09552814971123423, 0.011592541788039463, 0.12802047761423246, 0.03673718869686127, 0.03724176769277879, 0.026580640746812736, 0.011337632296739944, 0.02272851941441851, 0.0389642322302929, 0.05837195885500737, 0.06112609178360019, 0.058784603141248226, 0.03554404932739479, 0.0442525238197829, 0.04326032581073897, 0.027016811538487673, 0.055530471328113756, 0.016947599527026926, 0.018813116209847585, 0.032060026457267146, 0.022624074215335504, 0.014073116538513984, 0.05655842813264046, 0.033281341993383, 0.004722822981420904, 0.03827461673478995, 0.07449194243443863, 0.01954783732071519, 0.028787268857870783, 0.03791740536689758, 0.059894557510103495, 0.03588590544781514, 0.034786190172391276, 0.021755554480478168, 0.019261112170560018, 0.01082567508066339, 0.0228703722490796, 0.04172750502558691, 0.06845969826515232, 0.026476237956168394, 0.04684780830783503, 0.012995006666252655, 0.015174448423619782, 0.016932067860450064, 0.018058741332164834, 0.028889663184859922, 0.007848047983965703, 0.03488707136628883, 0.04594852209889463, 0.05049909006005951, 0.022021033002861908, 0.03146414718191538, 0.021736960924629654, 0.027553461492061615, 0.05398592206516436, 0.026509793209178106, 0.013792860371592854, 0.026414403059918965, 0.01585078498880778, 0.041331881790288856, 0.014522427160825049, 0.023926700299073542, 0.05448485564972673, 0.02119514562322625, 0.10576725671333925, 0.12843926942774228, 0.1482871515410287, 0.15124407144529478, 0.1864963405366455, 0.10662641775395189, 0.17206592272434915, 0.1135135210518326, 0.16207777868424142, 0.09872784944517271, 0.23166214195745333, 0.18235921753304346, 0.15723526424595288, 0.15464536393327372, 0.15990855651242392, 0.0645919061665024, 0.15619839488395623, 0.19017562882176467, 0.12180065922439098, 0.10687159281224012, 0.14313587652785437, 0.10686526208051614, 0.22186587404991898, 0.06263676179306847, 0.14622087670224054, 0.1305013916322163, 0.19696776435843535, 0.18575474247336388, 0.20178198388644628, 0.22074095798390253, 0.13491306347506388, 0.08116281019257647, 0.0780601952491062, 0.0958978088040437, 0.10807861161551305, 0.18826224149337836, 0.21747177626405442, 0.17409592308104038, 0.1020522096327373, 0.18333214175488266, 0.09529663356287138, 0.08361609426460095, 0.15823708048888616, 0.1884038517517703, 0.16393187562269823, 0.16218414583376475, 0.2845240911202771, 0.14089562531028474, 0.10884144782487835, 0.08086939807981253, 0.18891849342201436, 0.2211192548274994, 0.12873774341174535, 0.21484899414437159, 0.18950505980423518, 0.12194202521017619, 0.10449811802910906, 0.13738568579511984, 0.14482842784907135, 0.1445189615977662, 0.11544830937470708, 0.15861537733248302, 0.13878093021256582, 0.12133549632770674, 0.15025324746966362, 0.10335093244378056, 0.1003520315779107, 0.1626657157071999, 0.07409298419952393, 0.21358700043388776, 0.21116323263517447, 0.13801000586577825, 0.14421716279217175, 0.15918474963733129, 0.06783134769648314, 0.1264461406639644, 0.12732457209910664, 0.1392703710922173, 0.29467812340174404, 0.10862757358700037, 0.1336103305220604, 0.09923463367990085, 0.1459015038396631, 0.09070921436484371, 0.07005812999393259, 0.08204347400793008, 0.23725470900535583, 0.15953141317835876, 0.088607771056039, 0.09308450762182474, 0.13047487448368753, 0.1589922085404396, 0.1129043594534908, 0.10801700063581977, 0.14183496204870089, 0.11703249865344592, 0.17362037859857082, 0.1231086440384388, 0.22510807721742562, 0.1579951284719365, 0.1245239188096353, 0.07603894120880536, 0.12500128176595482, 0.11975533754697867, 0.19306518376937934, 0.15305752413613455, 0.09462535886892251, 0.09357804006763867, 0.1182696172701461, 0.11752753066165106, 0.09404432254710368, 0.0862827572439398, 0.16272349974938802, 0.07546367243464504, 0.19387316969888552, 0.15624104759522847, 0.10226351222289459, 0.23452327985848698, 0.11081411875784397, 0.06402663221316678, 0.13874602637120656, 0.11065420162464891, 0.09846948366612196, 0.20913969193186077, 0.2028830155198063, 0.11400273122957774, 0.14027112882052148, 0.20750997295337065, 0.17186769550400122, 0.1396276197795357, 0.098181092712496, 0.16363800210612162, 0.0952630867915494, 0.07771637476980686, 0.10285006503441504, 0.11584791221788951, 0.07738459828708853, 0.08449810836464167, 0.17881201287465437, 0.1127353703070964, 0.1297875049390963, 0.11004527072821345, 0.12190937410507884, 0.12249045792434897, 0.1728545975472246, 0.1415645522730691, 0.1043020078380193, 0.08673787782234804, 0.11413150360541684, 0.0965514008754066, 0.1209958895508732, 0.0874131355168564, 0.11508156119712762, 0.130903369347964, 0.10752160221870456, 0.07690169848501682, 0.16246170736849308, 0.08126200522695269, 0.1232489107974938, 0.08730786759406328, 0.13835159396486624, 0.0737057306936809, 0.13615419901907444, 0.08158033314560141, 0.11653688310512475, 0.148207477959139, 0.11820458647395883, 0.055924116633832455, 0.20878468241010392, 0.1035001083676304, 0.09024214478475706, 0.09654958240155663, 0.12150196810918194, 0.16194698427404675, 0.13977080423917088, 0.10724885828260865], [0.029688309079834392, 0.025283308932557702, 0.030004370691520826, 0.032541762571781874, 0.016174983931705356, 0.08470243561480727, 0.0394226844156427, 0.032616703371916494, 0.07259535563311406, 0.007194495776535145, 0.013843585953249462, 0.050145396896238835, 0.027461957652121782, 0.019231053069233894, 0.04033848616693701, 0.032827089939798625, 0.024253499727430086, 0.015888565818646123, 0.04776493998776589, 0.02616336545906961, 0.006969853611995599, 0.0781244593007224, 0.01874229750995125, 0.05829119283173766, 0.051754909101873636, 0.02486653915340347, 0.03669572002919657, 0.00873745302669704, 0.027716091068993722, 0.03963544246341501, 0.052134149109146426, 0.03822968753853014, 0.015164567257410713, 0.03753084057409849, 0.07245774873133216, 0.022770571622199247, 0.020611819245719483, 0.03177502139338425, 0.014260745041870644, 0.01927592628635466, 0.015519883816263505, 0.04552799662841218, 0.09289765264838934, 0.01779746124520898, 0.013074613242809261, 0.009670135032917773, 0.036306071294737716, 0.05931476969271898, 0.01176931627560407, 0.012102163995483091, 0.01006260562488543, 0.06650325788983277, 0.0789590777297105, 0.0055192127474583685, 0.05463538185826369, 0.02720460289024881, 0.012606544519907661, 0.017694893891790082, 0.009300235908345451, 0.029530675216977085, 0.07529682745890957, 0.02195375455942537, 0.06533322603042636, 0.04407893081328698, 0.05038848885201982, 0.04256314804245319, 0.0686845172728811, 0.07766242445047412, 0.048142599008445225, 0.025268135193203176, 0.014951076391818268, 0.0057098268048970825, 0.04609615096290197, 0.023207441304943392, 0.04808851298210876, 0.027891914759363447, 0.05041812726163438, 0.07298794242420367, 0.06995408343417303, 0.021180624973827174, 0.002081033611570352, 0.02245001301967672, 0.045272708005670986, 0.04076069101159062, 0.030246390561972345, 0.01820197159291378, 0.02448445269172745, 0.05315460470904197, 0.007528347728241767, 0.029426730437470332, 0.050776780516441376, 0.06489979821656432, 0.026269296649843454, 0.011772536772436329, 0.0903737602223243, 0.02046936421122934, 0.056436257902532816, 0.04488155631614583, 0.02497063490695187, 0.05047061533800193, 0.025024315508614694, 0.05611307167315057, 0.02320005205859031, 0.02279934998867767, 0.04273963160812855, 0.05422227616821017, 0.04365239352253931, 0.02184961809377585, 0.04442464440528836, 0.003100235405976751, 0.010840850516355463, 0.022178792394697666, 0.07634342701307364, 0.05535877143431987, 0.020925996226391623, 0.027955052442848682, 0.006338866086610193, 0.047993144885237725, 0.0049086550633156934, 0.05143681188513126, 0.028839349813227142, 0.02531250290173505, 0.028197420062497258, 0.0342460932609226, 0.030476461430745463, 0.03104011368538652, 0.05498006068436163, 0.047803748798157485, 0.06314807185637099, 0.02808017090761236, 0.019214113442493335, 0.04199175709592445, 0.0460070253882025, 0.009088069034208144, 0.07456710375845432, 0.01986494048365525, 0.0651154298601406, 0.02678894590852516, 0.07052540313452482, 0.033321853926671405, 0.07741194324834005, 0.006807831747989569, 0.03443596771519099, 0.03261779581329652, 0.0465650797289397, 0.05955646386636155, 0.018730828571798544, 0.06425919330545835, 0.007429692977374154, 0.03566101519390941, 0.02760677907748946, 0.032084158555205376, 0.03275738064465778, 0.0704813322850636, 0.02510491868347994, 0.08363271158720766, 0.07375510768698794, 0.04512536073369639, 0.017426009123612727, 0.06322549948734896, 0.023805724290598716, 0.024334664390023266, 0.014073937565886548, 0.026833903942523257, 0.10754139508519854, 0.03951693632240806, 0.06995260422783238, 0.042974703279989104, 0.047805173721696646, 0.013257594629456955, 0.06337273480104548, 0.05500371441511171, 0.030079983241323913, 0.06186640063034637, 0.03179670397990516, 0.02004502198126699, 0.042442619867090664, 0.013151746559222894, 0.031442281390939436, 0.03675225217427526, 0.029564160920147384, 0.006051657904338623, 0.07749131148947136, 0.07394431039158787, 0.01862291945144534, 0.03492578857445291, 0.043878766375460794, 0.05022052429350359, 0.03096645531643714, 0.018621616664209535, 0.06086133420467377, 0.0199963710204299, 0.03546856230657015, 0.045106958863990645, 0.08127079225544419, 0.0040554053349686515, 0.01134619371233774, 0.046476313777800114, 0.0242063771667225, 0.013508734010559107, 0.024883153083335077, 0.0543976672925055, 0.030646498913743665, 0.01686134754813143, 0.01951173077603536, 0.0775854785793594, 0.040503149652587514, 0.026513743979324187, 0.01272377247057323, 0.044163873219596486, 0.05933616390185697, 0.02984307273956282, 0.04771762574091554, 0.013678021712361701, 0.04463771118649414, 0.01801242453179189, 0.01749481087816613, 0.03699915749686105, 0.05777220853737422, 0.04351460002362728, 0.03481949945645673, 0.004343363722520215, 0.07281232399067708, 0.04739817145413586, 0.04609469550528696, 0.04966301617345639, 0.028760497258710008, 0.04385847139305302, 0.016262304603255222, 0.018604929791763425, 0.019445359873186265, 0.013743580917694738, 0.02427731121757201, 0.011714054687347795, 0.010383763034561915, 0.04547075880691409, 0.04447013678561364, 0.03409332110147391, 0.034485368457223685, 0.01182345997741712, 0.05349650154156344, 0.03894609159656933, 0.01976578955405525, 0.05987002168382917, 0.03315271550257291, 0.04856695480910795, 0.04229653127757566, 0.019190573366358876, 0.020454531435721686, 0.015337815907384669, 0.016605862150234834, 0.018693646549114158, 0.023139986442402005, 0.08569044367011104, 0.03139884497172066, 0.047205314838460515, 0.04947850553851042, 0.047712509586874924, 0.07319739939911024, 0.027271598045315062, 0.006391029314337564, 0.006230398447119764, 0.07642624221209969, 0.023374593317774788, 0.027447995097775544, 0.013296839398598033, 0.07376962155103683, 0.0461944808651294, 0.0707306464069656, 0.05169655169759478, 0.09977120560194765, 0.03910406133426087, 0.032738697182919295, 0.04395961382293275, 0.023059413801612597, 0.03692751098424196, 0.027037824071677666, 0.006807695192817066, 0.006852953902645302, 0.008875854662619531, 0.02571268249968333, 0.06503464348082032, 0.010423813564037638, 0.024919697283101932, 0.014237450934680445, 0.03053966018238238, 0.03946339312408652, 0.05663409496524504, 0.08714207434760672, 0.030075589727078165, 0.005225652205159089, 0.006209660720612321, 0.046693363559565375, 0.07892693552587714, 0.02237795599337135, 0.08343906447823558, 0.022404179675504565, 0.07258185957159315, 0.01858182737071599, 0.023926291481724808, 0.026063330737607818, 0.03943812447999205, 0.03668589144945145, 0.025439558583976965, 0.018324046828118817, 0.01512175509040909, 0.018686131773782626, 0.024628749948793223, 0.036072933447680304, 0.0196484878127064, 0.013021596757295941, 0.04194115873958383, 0.04941869946196675, 0.03957670507952571, 0.0455301950818726, 0.0984198081174067, 0.04842767871118017, 0.024133901145043116, 0.02096898990151073, 0.0454772829211184, 0.008494752076720553, 0.11079931312373706, 0.07452143156634909, 0.03667297214269638, 0.050185023341327906, 0.053707210413579426, 0.08036699718130486, 0.007598544720427266, 0.05481233361310192, 0.038664818475289006, 0.055424867530486414, 0.058908388284700255, 0.03171499479295952, 0.015621319712538804, 0.02562076984239476, 0.01816809912478285, 0.036431542597711086, 0.03720991725900343, 0.035573552030005624, 0.05936283032808985, 0.03775276902264782, 0.04895758063399366, 0.03390387412426727, 0.04551957600883075, 0.06144587855253901, 0.034392507547246556, 0.08228179586252996, 0.029221327709300176, 0.049099401238241365, 0.08227276456143175, 0.03201562651832189, 0.03684703673103026, 0.1812324287103755, 0.07417826248066765, 0.12020350992679596, 0.09105046319642238, 0.061840914855045934, 0.18066381636474813, 0.1818259840032884, 0.10239438805729151, 0.22646710143557616, 0.10681365949234792, 0.16704446503094264, 0.20252390764653683, 0.09755434348647084, 0.06739285801138196, 0.11815414418067251, 0.10418154751615864, 0.07066882508141653, 0.1424002360020365, 0.14600367764277117, 0.10706643414284502, 0.048457581749452014, 0.15566657270703996, 0.08188820483961276, 0.06951456916119371, 0.10658863692411355, 0.1676060613244772, 0.12400469024266515, 0.06738973675029618, 0.09516315215400287, 0.18790781551173755, 0.10636472036795956, 0.09957853558340243, 0.09326100136552538, 0.12558122564639362, 0.15865562802978925, 0.10079094195472342, 0.1865489405712911, 0.10784631515187876, 0.08245400805026293, 0.0775476706081203, 0.14230522752872535, 0.08386699615844659, 0.20431213240538323, 0.20836287790111133, 0.09859275990831, 0.14922423554318293, 0.19070682674646378, 0.15110448322125844, 0.09991776238062552, 0.15242340601980686, 0.08505085656153304, 0.1825127021542617, 0.1689335336642606, 0.09976412848170314, 0.20634705892630986, 0.11818855947681836, 0.1242840431098427, 0.15345427713223866, 0.1101877223700285, 0.15923473052680492, 0.1635497382708958, 0.12536218097167356, 0.16488026401826314, 0.14560834957020624, 0.12679474481514522, 0.09500995930284262, 0.15707095020583697, 0.22002300008067063, 0.14741581758218153, 0.1534097245229142, 0.13987436225371702, 0.1148865773741688, 0.16635497845709324, 0.07537466221089874, 0.08972058884267296, 0.11712027394345828, 0.15170820296875068, 0.17071113256471498, 0.13874502213937895, 0.12199310532638005, 0.06294060298906905, 0.09401602085147585, 0.11859797393637043, 0.174116686252611, 0.0832131462437766, 0.08966942051691668, 0.13543412408658437, 0.12774713656732015, 0.11362682282924652, 0.12606530609939778, 0.08398098325622932, 0.11407544304217611, 0.19138271547853947, 0.16560613363981247, 0.20368892513215542, 0.10315333626099996, 0.2093069101018565, 0.15310033969581127, 0.09701956289687327, 0.1648722437343427, 0.09897821529635362, 0.17341840586491994, 0.1068894247125302, 0.08901845437607595, 0.08908482188624994, 0.135657701375229, 0.14397381299308368, 0.06742605194449425, 0.08476629254541226, 0.1842405101550477, 0.140720400427069, 0.07210446947387286, 0.1386314489479576, 0.07820723378764731, 0.054248647431709936, 0.11799713117735726, 0.0908049081585237, 0.19460043710257324, 0.10198831877538136, 0.1899685670754739, 0.11026846803724766, 0.12711588186877115, 0.08612092664199215, 0.13989124420498097, 0.08716093083577496, 0.0924436855795128, 0.12377793741013322, 0.13503401912748814, 0.13984732941857406, 0.10418992742363896, 0.11541831812688283, 0.0745657127616661, 0.07934105901845864, 0.10986172022031886, 0.1331827448947089, 0.198736094470535, 0.2514395107116018, 0.10136821919253894, 0.11265885191304342, 0.17508304225546972, 0.16425412547375473, 0.09149180272860186, 0.14897677382188185, 0.0954656091385654, 0.12439146877399512, 0.22210626543632575, 0.19719820842146873, 0.2213995847851038, 0.20052942181272165, 0.10336119189326252, 0.20431937915938242, 0.10886160710028239, 0.11964747762041432, 0.1961852234921285, 0.1327047576861722, 0.15079961743737968, 0.2180638794920274, 0.13751097050096306, 0.10393475075917584, 0.11494472782526698, 0.0948719045679484, 0.16687643261892454, 0.13362248986959457, 0.06469796797526733, 0.1661918450679098, 0.14392330284629548, 0.08913528453558683, 0.11869417663131442, 0.11707895116082259, 0.11268548441252538, 0.14520667040986673, 0.1202508309589965, 0.09392418792205197, 0.23405970473374638, 0.0858770204441888, 0.0691571304840701], [0.015291521159399833, 0.08720849614058222, 0.02691665298438498, 0.04753528641802924, 0.042500278380300315, 0.014229814023045557, 0.028825935175908462, 0.019266576073797684, 0.015677456610969136, 0.012572586386730629, 0.0055796689453667826, 0.1333147878093379, 0.1037474615233285, 0.06852088176778384, 0.016450543788128665, 0.05251531276319708, 0.01430854104858424, 0.03182701753186328, 0.05014825692134244, 0.017323379005704607, 0.018623082299849818, 0.025852881405236464, 0.032213497507785044, 0.03509584302082658, 0.03576096000948122, 0.04301147309264966, 0.018649319552683404, 0.0479306043125689, 0.02805718214118055, 0.04385483105267797, 0.046805888414382935, 0.016361016181430647, 0.04858431852023516, 0.008764428186363407, 0.038370279994394095, 0.03340041131845542, 0.03749923441292984, 0.044910363520362546, 0.016379470637600337, 0.03168034200955715, 0.011719594077606286, 0.061361719854176044, 0.019829232578298876, 0.020897847201142992, 0.06278627019907747, 0.057238459321005006, 0.01528824383525976, 0.03193890456376331, 0.004708286640899522, 0.009986476540299398, 0.0920660604855844, 0.011840063729323447, 0.01660659327171743, 0.06388107966631651, 0.03660176667783942, 0.05145081684791616, 0.018918183964810202, 0.06729096240763154, 0.01382089828673218, 0.04321430417309914, 0.025098827135350023, 0.10929324358169522, 0.03791182780904429, 0.04068233718031219, 0.13664050506693975, 0.05010129890537687, 0.030869733542203903, 0.037863906273352246, 0.053325086632477384, 0.04177878191694617, 0.07148213072546891, 0.044584659926061115, 0.039745609409042766, 0.04393832478672266, 0.08783717919141054, 0.06977609691343137, 0.027465682809374163, 0.016842603018241267, 0.022484318053882037, 0.058195946871169975, 0.023638814854036485, 0.06808933349592344, 0.0478216112325234, 0.016261926319982325, 0.027301918382623365, 0.05125306460208126, 0.056059053500315974, 0.04507283873057791, 0.04061559308320284, 0.03842011499883873, 0.008423377826277698, 0.034060649640325985, 0.0829656913078257, 0.018116123342354382, 0.027032870766041533, 0.039064740229930194, 0.05318603105843067, 0.015365289790289742, 0.010977013834885188, 0.009218056835899395, 0.09250269777008466, 0.01981394688066627, 0.006879712779274476, 0.01432513801514038, 0.030643051955848932, 0.06079636447663818, 0.009725506883114576, 0.03838999822203602, 0.030135443301073143, 0.0512584691335048, 0.018969735662852014, 0.040097348392009735, 0.03331793538693871, 0.0335683012381196, 0.05456823403281825, 0.07510662052248206, 0.017789707286283374, 0.020259523864037225, 0.015928777500188777, 0.006373040502824421, 0.012694011924655309, 0.061743355090064664, 0.02431193346689854, 0.0018083331441240652, 0.018117855302989483, 0.060977655462920666, 0.05373789715979781, 0.03563828766345978, 0.06410431090210165, 0.045826399366238287, 0.05843821779957839, 0.026100399105676582, 0.03895791846194437, 0.047957732142614465, 0.026721606396936944, 0.07876693018312965, 0.06906752993485757, 0.06962821020611695, 0.006452729351752038, 0.009838717058300972, 0.02018980947988374, 0.030357789048658948, 0.015158653824723192, 0.013752550302472497, 0.06370495233152594, 0.04662254825234413, 0.04086457811562078, 0.009736299830754953, 0.032451856681810956, 0.05855280879352774, 0.046620139453027926, 0.07019260206392833, 0.039637573063373566, 0.05159632528999022, 0.04884284036234021, 0.033096498876277886, 0.011116419702635279, 0.003099131938402674, 0.015275791021330016, 0.02763896538609905, 0.03575014076860888, 0.015116153783830149, 0.023997390077316334, 0.021426498923184614, 0.02526680696090417, 0.021714102776188935, 0.04906895537195461, 0.051387828442135026, 0.011996656889095902, 0.007729239894875458, 0.024751400242426565, 0.04244478439380016, 0.03310241230896541, 0.030629023244338374, 0.02177349664270878, 0.028622506984642575, 0.0592537626091923, 0.02858226646536163, 0.026232157035597732, 0.03004988682057176, 0.019520519500864402, 0.017816565398659025, 0.01900622557981738, 0.024394982760506015, 0.04611196082883647, 0.025304056837090423, 0.022376008597867827, 0.1616214367427996, 0.03625703356893999, 0.05745326315185853, 0.03774262492411903, 0.023163601157388518, 0.011662034800143113, 0.046013471470879655, 0.03205559901627047, 0.045998991533581696, 0.008759347655411278, 0.02783125881770892, 0.08771663065999746, 0.0774807534845812, 0.0361779604905418, 0.06911429456834282, 0.018641933699005415, 0.011271214744608318, 0.03237303466136966, 0.030205705602254187, 0.03728998778387904, 0.0314169482860182, 0.011662145910252417, 0.01922254084742495, 0.0512852780520916, 0.02947472661201443, 0.04439321805589965, 0.029748386570385525, 0.0568250890022942, 0.07112353853881359, 0.018395155601735626, 0.010374965828045138, 0.014051275344432464, 0.04159473268581288, 0.03836715534063322, 0.03668814418571336, 0.003606947122274765, 0.035990976595452855, 0.0321372607057648, 0.02672741804937167, 0.06253171100148133, 0.020908428954758813, 0.04473326588049531, 0.019076733849942684, 0.010668193040016507, 0.04705961640658123, 0.060479882173240185, 0.03692075956080641, 0.012435426469892263, 0.036617138888686895, 0.04063000516699893, 0.01357379534082221, 0.03965032612904906, 0.05511777615174651, 0.02553892325210784, 0.023163592675700784, 0.05913560252104487, 0.02173182102186339, 0.009086259042045899, 0.03436388694015997, 0.02732200132283781, 0.00037516654421259385, 0.03650058014318347, 0.04038102013458099, 0.036313531787267754, 0.019619380356743932, 0.035411863920411894, 0.015825609643278376, 0.04668854596093297, 0.03565216709726623, 0.02629845160325723, 0.047310915243412764, 0.05436068034863897, 0.07502271288207599, 0.049462912803781886, 0.026478536493544067, 0.027663083913336908, 0.012670794152654707, 0.04287623427808285, 0.03823550258363996, 0.006923867597444249, 0.029316770445023264, 0.010680505057929881, 0.013242068900061505, 0.02708963700570166, 0.005815145617816597, 0.054161716917795796, 0.021363252674096396, 0.057785969227552414, 0.02085780176067991, 0.036065656159605296, 0.010490111524372228, 0.06185878746743713, 0.04108693064855678, 0.040326611804110665, 0.01140919144797538, 0.023571724704067622, 0.014788518061063119, 0.019222566292488148, 0.03271123008536441, 0.0310390687414578, 0.013432067186970795, 0.06496662034520082, 0.0070480853069706684, 0.05261082674509712, 0.04001686396077275, 0.015843629837036133, 0.016536376771650145, 0.06023436784744263, 0.019831682089716196, 0.0376040782513363, 0.030523687468043396, 0.0572944384600435, 0.014556002769885319, 0.04606895867202963, 0.07446290113564048, 0.01873698118808014, 0.024741378280201128, 0.05447750372279968, 0.06648896115698985, 0.02203934496667768, 0.04846470297447272, 0.02175920669521604, 0.04192025986100946, 0.02409421363180237, 0.029075252690485547, 0.04518964174868805, 0.035173844013895304, 0.05157844589224883, 0.02255495694199843, 0.02384495040002678, 0.016243275088657225, 0.019313087952988486, 0.05809635828648295, 0.03608218527265957, 0.058976540341973305, 0.01933204452507198, 0.019515489860038673, 0.021963430468791297, 0.015330253634601831, 0.055395232513546944, 0.01971867377869785, 0.05855978413351944, 0.0192657652244504, 0.05829106391008411, 0.005575772882106581, 0.03159021220303007, 0.008132080198265612, 0.07156253712517874, 0.02279992843978107, 0.045817096651132615, 0.0380554058189903, 0.0390375784731337, 0.03156994775469814, 0.04658441458429609, 0.07383347848164183, 0.04804790944659284, 0.03336118520902736, 0.03783137730455824, 0.022796043826799308, 0.018069714939753925, 0.07803396308528525, 0.0699741341439741, 0.04871264984831214, 0.022224603686481714, 0.01701807217406375, 0.09259216261229344, 0.30367932468652725, 0.09940787724086217, 0.1213665460901601, 0.08700594665216548, 0.15178577309208258, 0.0963411567998784, 0.12940358982554503, 0.19196112586983613, 0.10024567121373755, 0.04077866201155952, 0.26501566650612013, 0.16595393711967127, 0.18897300692541258, 0.10847578530332871, 0.12356098262327057, 0.09845442697405815, 0.24406139233282634, 0.16133635704006466, 0.13486386968621186, 0.11872154873396669, 0.14386327963854584, 0.1915424969047308, 0.10921278289918389, 0.10242123768797942, 0.14411954874438898, 0.15933218172618321, 0.07496397889086179, 0.08657758749489274, 0.11648337383355413, 0.13350989376860006, 0.14575806153672083, 0.16089688347918646, 0.07930373959243298, 0.12861582423959458, 0.1798736894769328, 0.07273303717374802, 0.18181444890797138, 0.11310100568724529, 0.17641033817614826, 0.06288865434804133, 0.09887619077094964, 0.0953792112746409, 0.14985547667103155, 0.17507831965173992, 0.1456735703561987, 0.07617970329842397, 0.14984151242034777, 0.06037722661026886, 0.10214589496276208, 0.2730326120342527, 0.053651387337595224, 0.17843765153416566, 0.08566820807754993, 0.09679891009415899, 0.17971424731825078, 0.13311191940946238, 0.11500123622162, 0.06236681342124939, 0.11355487097586904, 0.08461911829986743, 0.17575890384614468, 0.11834660385336195, 0.17178624416036264, 0.20522909105888434, 0.14623276463576726, 0.12479489855468273, 0.14698306151798793, 0.14021037279495172, 0.09982907785368816, 0.15987582398312433, 0.16035158559679985, 0.1341564833585705, 0.0778658085369638, 0.23215397128037044, 0.12448011258883135, 0.08493976680827992, 0.07992193249187299, 0.16723722325904028, 0.17491515912115574, 0.1211575980165175, 0.28549067782504217, 0.262818841529744, 0.13850746702935013, 0.13162140867539815, 0.0765054611755269, 0.12762045407933847, 0.1404569795621293, 0.1493297613092831, 0.10643402593476431, 0.15027396992913314, 0.2149757851979562, 0.10852929457489933, 0.09945734922907182, 0.06476057640143804, 0.099729557122503, 0.1222559426512037, 0.13560879257108482, 0.11208728115473475, 0.11526670626231603, 0.15664037902440342, 0.23663574936134474, 0.11202757685844388, 0.10439830552786589, 0.1343089501772608, 0.11865275885377612, 0.0563022234876241, 0.07806404932801213, 0.191859169197934, 0.18380225795720304, 0.14141166476266726, 0.15528294257819653, 0.13830814058227198, 0.09095977699118, 0.11467058610703264, 0.13109673825757845, 0.06874173134565353, 0.12826678582600184, 0.13728803103523596, 0.10476027003356389, 0.11553969447101865, 0.15853115756596836, 0.24131973087787628, 0.13240115397742816, 0.11005055651600872, 0.15943155996501446, 0.0979353001873408, 0.09444867513541665, 0.2123535866183894, 0.14306826729859623, 0.08694649341383151, 0.14343829958566598, 0.1654844723109688, 0.13797860326511519, 0.17332144321075507, 0.22094607912003994, 0.1742067142788853, 0.16577191331556865, 0.12665546871721745, 0.10352080368569919, 0.07363359563584838, 0.1377528410937105, 0.15650511985378607, 0.17232915359948361, 0.08098015535090651, 0.11735918612352439, 0.16179789655974933, 0.15153475584728376, 0.16262553286339554, 0.11346708211515631, 0.14136365162474768, 0.15481768468660967, 0.18182401625173433, 0.1633954258369548, 0.22999842837452888, 0.10153206504349198, 0.15559213741549424, 0.11389055582029478, 0.15008195808955602, 0.0760935361364058, 0.1915652278278555, 0.14337860207472528, 0.18420252576470375, 0.13519328486706528, 0.09826872551015445, 0.1332414246031216, 0.2660414214645113, 0.09589284871305738, 0.05652837920933962, 0.08799949155322143, 0.07088362891227007, 0.1640521798815046, 0.20825482798474176, 0.12190124525555543, 0.15286855213344097, 0.0885738307344062], [0.018598751730418632, 0.034629903201545985, 0.025507418871191994, 0.059464997345847745, 0.03495106739657266, 0.03222183331048914, 0.052579312186155996, 0.027157363282250505, 0.07686454869274582, 0.01609642314724624, 0.017593488529590622, 0.016103495178478103, 0.08823160481240068, 0.03844312751399619, 0.03279550752735563, 0.012125899150435413, 0.03881754313728639, 0.11281340861959116, 0.04276784170152886, 0.04420862260407635, 0.018100708723068237, 0.02582842530682683, 0.01984323075573359, 0.054389005792992454, 0.009117710836497801, 0.043259053557579, 0.05973933583923748, 0.009709150796490056, 0.02692590480936425, 0.006125713640358299, 0.01669302675873041, 0.030859314636992555, 0.08505167080355541, 0.03534018348104187, 0.03004918114415237, 0.0196624961681664, 0.04155834624543786, 0.010528054354446275, 0.011011061873952193, 0.016722034130777632, 0.04098295194229909, 0.07247626595199108, 0.05177266636331167, 0.04050061193161777, 0.027672278062839593, 0.016798408336139152, 0.08009190551404442, 0.005479327610893441, 0.006308935058768839, 0.06641681252845696, 0.020842390534068857, 0.03248580039611884, 0.025328696139955094, 0.017749795856486474, 0.024033542423109924, 0.025258963096088598, 0.04865935770794749, 0.03276982497689979, 0.022749401329617416, 0.043275521602481604, 0.040043771266937256, 0.03137086558022669, 0.02784831718807774, 0.019686935303200568, 0.04074563431952681, 0.07213355148477213, 0.02534785118353154, 0.028467855283192227, 0.04132862142952425, 0.031835550109722784, 0.018477568768763115, 0.0329529649711081, 0.028324949022914683, 0.039290448118533404, 0.018777628828372275, 0.00434553376232673, 0.045486253154064925, 0.0410544898893152, 0.058904629200696945, 0.12327725999057293, 0.010659105759779257, 0.04893347567745617, 0.003590134296765817, 0.06547700760087796, 0.0407829876723034, 0.02366371200020824, 0.029002805506544452, 0.032612930717212815, 0.0020584256729177597, 0.018610500564266528, 0.025347723958215544, 0.040600522820438655, 0.07839098107069731, 0.005111475117571119, 0.06837454890566212, 0.021252239256032875, 0.03777890958424125, 0.09726686176976987, 0.03116501501894423, 0.029171462170779705, 0.0181164405574756, 0.07111311624092714, 0.02653204576511468, 0.06084740388074091, 0.028635151484715085, 0.02385537269791322, 0.07121482864022255, 0.03980269456016166, 0.036415844690054655, 0.023244716626192843, 0.01923196400249643, 0.039654797674821954, 0.03540401666292122, 0.07152008118906192, 0.007767513510771096, 0.03226560899721725, 0.019406556151807308, 0.040997197785015614, 0.05598723396126713, 0.04669747548177838, 0.027893599222547243, 0.0787073615938425, 0.03813956451735326, 0.0017692999930919281, 0.02133201461817537, 0.01464442945351558, 0.035749333311936686, 0.025586532661691308, 0.05656544079205819, 0.0431742129315223, 0.05442497154165592, 0.025048914099378244, 0.014642663566129548, 0.02812934434041381, 0.05733095721474715, 0.04500349923702223, 0.048799271628792794, 0.026010762933375578, 0.03310119094593184, 0.045610153648470125, 0.007032225823162922, 0.020617859903723, 0.039095369300671985, 0.020730226999148726, 0.028589099312999418, 0.04192702824782048, 0.0948686950973102, 0.019672553753480315, 0.010900963629995073, 0.012351368703613324, 0.018663767259567976, 0.052004704983638864, 0.03339493554085493, 0.00718872992521418, 0.037347965208547454, 0.022696738530482565, 0.00986878973032747, 0.04401649541354605, 0.036470544790582995, 0.04846790905243584, 0.041041370414729626, 0.13074774055608682, 0.04059798509946891, 0.038254240328179936, 0.01511018437200359, 0.03552527765610388, 0.03315749578177929, 0.044318935434733114, 0.02248804660380951, 0.09987150664840426, 0.03767305472865701, 0.022495834489486048, 0.05466409067490271, 0.045038189339850626, 0.03656716478456344, 0.03704149808202471, 0.02057923429778644, 0.043686045466789176, 0.03962950188932674, 0.08035494639937367, 0.05837025573211057, 0.01897332680943821, 0.03575833407895906, 0.011931233390766596, 0.03657582628407648, 0.030864464717784097, 0.016973565365853052, 0.034325346151100736, 0.07762025349906512, 0.02161984408407339, 0.020062528184748123, 0.03913223410823515, 0.02259740948544017, 0.06336157289998871, 0.028379392976473485, 0.028594235823090588, 0.011203607211687734, 0.020991303525598984, 0.018599121532003795, 0.027777578216046095, 0.0312725153219487, 0.0167300815560988, 0.043726095996264897, 0.06631574473742928, 0.06509235288415637, 0.010455514720108892, 0.01921125511372728, 0.029569463671318123, 0.04206481496138232, 0.0496193354816309, 0.043549480116260905, 0.046573127154260874, 0.04315223178959318, 0.02226004865951836, 0.05345538571210844, 0.0087532993638888, 0.03974883923573153, 0.007575332037439304, 0.028250123573733226, 0.03639802975314004, 0.008925499677258943, 0.026694110461643765, 0.031353776675782034, 0.024292668161381568, 0.015207233539383327, 0.014812840148806572, 0.04862678124170218, 0.023370515322312713, 0.03205818084201642, 0.02811277112258332, 0.014740350556426814, 0.02161924697325698, 0.05688238789194396, 0.019294745455096875, 0.0106068848565753, 0.03130640475345509, 0.02197380018021379, 0.013797965499439409, 0.03275125686611448, 0.058025261387228966, 0.07187851052731276, 0.028001252195930908, 0.01692316378466785, 0.04888090956956148, 0.039315611589699984, 0.028644179393138205, 0.06119148898869753, 0.039375292137265205, 0.02336972313267844, 0.03415032482839056, 0.07067658073667969, 0.012249166062766952, 0.024763875108744417, 0.014344993646123579, 0.02870270303849663, 0.028434025223499963, 0.0238145435495036, 0.01678154504458819, 0.017626170168763826, 0.01027669699396938, 0.03915643745235034, 0.035801244633538384, 0.038962732667901685, 0.025010240995990377, 0.040091021052960835, 0.02850479133693235, 0.0575100090354681, 0.013981970625796487, 0.023140551322805028, 0.0824993070481079, 0.04635221650823951, 0.017341282152171646, 0.01628594645964248, 0.013757254246489277, 0.06237628577010972, 0.005752345505503139, 0.03022851116423096, 0.03972560619669301, 0.039600362202950885, 0.09359252000493662, 0.02605536812916398, 0.010699211420225245, 0.027306481530623775, 0.056870795121150355, 0.02271796140952834, 0.05735690439386027, 0.05205344754670348, 0.03506154986098409, 0.02951045148074627, 0.03557207282366497, 0.01986445363477937, 0.05626995236213718, 0.02560670890047082, 0.030909570333148752, 0.016159174065770845, 0.022572157804721167, 0.007909829445582415, 0.03622262845081942, 0.04994716628321579, 0.011632250505499542, 0.02986728965437838, 0.06459678483328649, 0.012089511013722845, 0.09001856749611241, 0.07417377057884421, 0.05755728257021733, 0.021531972102820873, 0.019393663986452987, 0.061167407780885696, 0.04893164024023073, 0.021810186727504646, 0.05483126134744712, 0.03617942273350699, 0.0827992195263505, 0.04298443686483162, 0.03304993101794805, 0.03101891285872885, 0.025579891500196288, 0.031371065748057196, 0.018188857207340852, 0.03832217864692211, 0.1056874677804964, 0.07945060849721942, 0.06801717808204037, 0.020353704524625624, 0.009936859515229506, 0.019236710354951874, 0.06680999643036298, 0.06650058446185929, 0.01623253387931202, 0.028439344938046167, 0.037141714311603985, 0.03928360848554543, 0.018120995223788277, 0.035199363715946674, 0.0559963873986687, 0.013307075947523117, 0.07636515370437078, 0.011833161331846245, 0.04960801751751985, 0.045727893044906, 0.07864106193717037, 0.03419054838429604, 0.050923109985888004, 0.04706016941262143, 0.03689095151743718, 0.03742172535774963, 0.06627152461026396, 0.021918570822370902, 0.014321355182411415, 0.02713379097570266, 0.04445846937596798, 0.0760203900613955, 0.12780576199293137, 0.08790121254112039, 0.22298035424734863, 0.15038360761744635, 0.13480276082243237, 0.14055519072072847, 0.08310764083372695, 0.16550709466849053, 0.11659297080976622, 0.06588083093187638, 0.08003263548016548, 0.19980645632105215, 0.10377046386046068, 0.1274214940411704, 0.14637597623680318, 0.1525591808770384, 0.19049232825636864, 0.15157337806054524, 0.08469286827104432, 0.10471835692546197, 0.1463189385831356, 0.10188193805515766, 0.13236451308642114, 0.15913138964346477, 0.1483717512871538, 0.11404784023761749, 0.1169414935367448, 0.14087905548512936, 0.08691587791379009, 0.08663134782442025, 0.1682295264410121, 0.1294718233070203, 0.06487132010183164, 0.12887274473905563, 0.09615231371883835, 0.12268827802368573, 0.1171249829764877, 0.10031032881566457, 0.2204577238964183, 0.11603429221681186, 0.11198073758610658, 0.14029307264302457, 0.10909391713461705, 0.10337254378412451, 0.07940349102552448, 0.10641037898936442, 0.12624418150101388, 0.09813242818095855, 0.1243687921336719, 0.07370170019567013, 0.14650204804326805, 0.11422759773475782, 0.09419675543904305, 0.0991482629573771, 0.16361820245427744, 0.18498189108712332, 0.06869067837085042, 0.07143229232834918, 0.07737177397523608, 0.11699208510773522, 0.06632073875516653, 0.1175105944275856, 0.13340299736176217, 0.1867152223629611, 0.14984106458723545, 0.09395757863031966, 0.14082864033324377, 0.07842661772987672, 0.10470475229833807, 0.15768549937222684, 0.10863254046333687, 0.10881957185587712, 0.0717110548700605, 0.1179397813975811, 0.07167911622673273, 0.08817093021103314, 0.09756809739129883, 0.1579293512872287, 0.22878284645932062, 0.11781299034399645, 0.1434376753334488, 0.11317897614623819, 0.10007074488592999, 0.11241050131086792, 0.09306563756295613, 0.1806736144104174, 0.14479219407907554, 0.13033055008522101, 0.15190058121723787, 0.2224028395222766, 0.20979951295469487, 0.12601308604436262, 0.1186606977134943, 0.1957750762147563, 0.06936669602457966, 0.07978853250720672, 0.17016572611672537, 0.14868748720203126, 0.1706042904406786, 0.07939895162624971, 0.09061746964497225, 0.09748940089983599, 0.2827018174741949, 0.12003828664975506, 0.09018514105784041, 0.12905848691506044, 0.102552683491792, 0.1550253571144172, 0.287106703966856, 0.08023412645395313, 0.16881219803222589, 0.0834971945732832, 0.14656580319362028, 0.10309541651180812, 0.15140388001288685, 0.09239526532058205, 0.1102974143411432, 0.14122137640203747, 0.0894258739426732, 0.1256630298282419, 0.19257665212665284, 0.11252177426857607, 0.14541420713067055, 0.10174774418451957, 0.12359845132700034, 0.07680677822125809, 0.18657430421028817, 0.16703207498150213, 0.11149646035794701, 0.10713900346308947, 0.12201072009546415, 0.15167827957442828, 0.1372020470776728, 0.10905418212392501, 0.19901062973908015, 0.10681199029620204, 0.1358730276780469, 0.1059091112443379, 0.07307428600532667, 0.16143863940877573, 0.0858081423544458, 0.0715631070945944, 0.07866287683801991, 0.11316671501845121, 0.1618939092648881, 0.18438506525542053, 0.10684681949870926, 0.07948166504502296, 0.10305504367819854, 0.08863367752305099, 0.19731737274144376, 0.1815477575042418, 0.05870676838925906, 0.11116545061979975, 0.1356499796467168, 0.13782627215342863, 0.17027279894266809, 0.09480823084179844, 0.15481113003832953, 0.14487443252333573, 0.26993455684610773, 0.12156144848891667, 0.1139812623815877, 0.08360890179340329, 0.1911828462034464, 0.0944781167698758, 0.15574497064309462, 0.12158485794706003, 0.14070579835346766, 0.12194532289036683, 0.11920508635895592, 0.10061399359256029, 0.18089629603283747, 0.09336825061057295, 0.11549777457756655], [0.009916461056231387, 0.012127506430260837, 0.023808440127010857, 0.04954113432073167, 0.015702075557783246, 0.05258294913385596, 0.024419969812567745, 0.034166294150054455, 0.008943418938932675, 0.04449762423921909, 0.10234907548874617, 0.01604966021009854, 0.01763035503349134, 0.09844768912132297, 0.027135906308623295, 0.02920722435893757, 0.04953733452462724, 0.02506015233562461, 0.04013284934418542, 0.02018653045940612, 0.0593215889696564, 0.028784296874489104, 0.019540612619104128, 0.04202532083062189, 0.0036311729428624468, 0.03461195595030274, 0.027427932513611655, 0.06346006225794554, 0.034705858411533494, 0.03784272241007004, 0.04314469665821109, 0.02218065158064876, 0.0865304089550461, 0.027639358936409866, 0.014280313991808465, 0.014078397237296616, 0.05928670548434768, 0.00949011036261384, 0.008513309161311813, 0.09199391185705151, 0.021541247676525797, 0.009967832094324487, 0.016193794618759836, 0.048111138732305596, 0.04186834175405758, 0.01644960740980293, 0.008473435899109712, 0.05584641419617193, 0.01319355279805937, 0.012306309737531202, 0.0234996439290366, 0.03666805615648627, 0.031809663998761346, 0.02395550750329026, 0.012401061215704041, 0.048098341561853886, 0.00839520844497851, 0.052381780464202166, 0.05289841363472598, 0.01700469315983355, 0.04437136922829917, 0.03735641296952963, 0.0511578627462898, 0.0060579763376154006, 0.03063362031908972, 0.017958670987614563, 0.00582348057235192, 0.014433493272268345, 0.06501563092959778, 0.03858658338763884, 0.057312351784535816, 0.020824570508141602, 0.04337981243484786, 0.01408413509904806, 0.05129620925124202, 0.011369162970887763, 0.031225435169679776, 0.014718416911949004, 0.06086474723581757, 0.058099133494709215, 0.02516950843190508, 0.04563081164711288, 0.030391566521887268, 0.02289473674526172, 0.016402171026649218, 0.04420974218685712, 0.03508173967046397, 0.04604274347158415, 0.02927108128954257, 0.04121910587751439, 0.04093446382986648, 0.02561681398323604, 0.05586050397583416, 0.023473727283999324, 0.029084568976291587, 0.04037118816216077, 0.05834936363888638, 0.011422802860449468, 0.04744301922619343, 0.009746089394736503, 0.029356926147426878, 0.0498247178537505, 0.006026310380548239, 0.05965136377406972, 0.07304210308939219, 0.046461484394967556, 0.020406933900501047, 0.033808641734399965, 0.01979303273505398, 0.041708875846649916, 0.005081726446016026, 0.05785190926066466, 0.03697303729131818, 0.04579077288508415, 0.021462508776624287, 0.007722672524063715, 0.04295222002214619, 0.03053515131718346, 0.06137222357626472, 0.06983343312250716, 0.03495468398822205, 0.028667378505425792, 0.019888407617275203, 0.04935752274468541, 0.040309529685016186, 0.07902381675583975, 0.02944857587239572, 0.03398660450641598, 0.0705215015581676, 0.03543426236137748, 0.022397918493619988, 0.06115971997912441, 0.04268424279455628, 0.029883401468396187, 0.045830134701515944, 0.019144302367099693, 0.026751485686483126, 0.010975096125288733, 0.025987884428884302, 0.02255490605187203, 0.04480062744447163, 0.04261081852018833, 0.045624874465699704, 0.044501023699662516, 0.019016992234225785, 0.035349845819707425, 0.008105615636200776, 0.019298792916483114, 0.06442456586020333, 0.017974658968991468, 0.02886002477524536, 0.01472963479214481, 0.03288611909374595, 0.010850653651037385, 0.05483498311202441, 0.04082023585215211, 0.0394358887071056, 0.04835488208170448, 0.011011675948144069, 0.017729970759579113, 0.012711225509909647, 0.027282938061814224, 0.02683699975854584, 0.014376498027039426, 0.012512794729056103, 0.030567839741706848, 0.02833754432919834, 0.045359675839011154, 0.0632951646777136, 0.0523023409768939, 0.038998538960835764, 0.03875432402959891, 0.024899264897352884, 0.016016688497204865, 0.03520285477861762, 0.04440280914838825, 0.028956125689936534, 0.057484835386276245, 0.02194996833402131, 0.03230203954236848, 0.05672773958316871, 0.005120466130652598, 0.01683830449889813, 0.029852721507527998, 0.08517318964004517, 0.054041931738278697, 0.051275334121393304, 0.038530475326946804, 0.0261083973372089, 0.019387484228770648, 0.05156226622472916, 0.006854596381474818, 0.0710537444267954, 0.07610270992985793, 0.03796499781310558, 0.02098435702334557, 0.04489198539938245, 0.0506596450161721, 0.02068837495919849, 0.06615931527423007, 0.011897123435379138, 0.025157754509044544, 0.041193291012729914, 0.03894536895677447, 0.023633847977699976, 0.039629915795688114, 0.05350756166236741, 0.009289733882594322, 0.06221621257386037, 0.03053410298057965, 0.007626603839785925, 0.040497616199510436, 0.04311914981475898, 0.032681924157908986, 0.006269995206301766, 0.03022305913535612, 0.03395289149401443, 0.024395104896809374, 0.04924534394272736, 0.05201298989621656, 0.07197323401591607, 0.017946369147726467, 0.054883243915225775, 0.06425189905400787, 0.020628487458452582, 0.03299546840467623, 0.042878846637904644, 0.062198638516877375, 0.07311481490199055, 0.03607084355982287, 0.026221682151247348, 0.024314013176730702, 0.018027574522420764, 0.03755388023065669, 0.027013714026127542, 0.012943393900059164, 0.05539799415107284, 0.008923699863121977, 0.041369123184787374, 0.024442481908148954, 0.010365974390879273, 0.055150091382009644, 0.060516285576990674, 0.014443540679556983, 0.07526195075895105, 0.05426616720589144, 0.03114633834255593, 0.008311646857431956, 0.04426094443936433, 0.002109473558708227, 0.02772073564119637, 0.06787887907453946, 0.02484706519836826, 0.01983368207168366, 0.056660876742431095, 0.08122784777411393, 0.019328066613525152, 0.024376095738261938, 0.023506308839257275, 0.03038641983377082, 0.03564505944294589, 0.048585763799824884, 0.030941634505454983, 0.023365558624001484, 0.016198785243821994, 0.07588236246790205, 0.059031671312238486, 0.04000000236555934, 0.07292259271655764, 0.041340974159538746, 0.057937838935426304, 0.027845275654856647, 0.00867360966679241, 0.11643013597599097, 0.003039748886034691, 0.02002587541937828, 0.03535902979118483, 0.06489942502230406, 0.014678086486778088, 0.051625671929546764, 0.03971940099394747, 0.01194439866646592, 0.047226810827851295, 0.03138825982542975, 0.046870746184140444, 0.021883968929094926, 0.0565483213535377, 0.023666549972923737, 0.018401571150336946, 0.02910070793171014, 0.048348273150622845, 0.06507197647754635, 0.022690292447805405, 0.013517647416197827, 0.06743321048894099, 0.04312149076057332, 0.04046453422467623, 0.015352299237357718, 0.07984814180859498, 0.007965058803425303, 0.06454208134008305, 0.03932459539334689, 0.046960248345775266, 0.035968975097473176, 0.03201440176261323, 0.034510640493993244, 0.04540316993370652, 0.04005128264959369, 0.09617119734840733, 0.03350185230374336, 0.029340400427047695, 0.052403310380343876, 0.08712595914091383, 0.031477972332920344, 0.031737040395715406, 0.05152784414323313, 0.03645358141511679, 0.09097854526979582, 0.02747456992178091, 0.07562994744096484, 0.05528217500873974, 0.011006328244028347, 0.022772013509113873, 0.08138509826468569, 0.05841554794460535, 0.026562908930437903, 0.07614087073930673, 0.01693355045946581, 0.08781198518616812, 0.03911732330120035, 0.011280947481282055, 0.022679055907896588, 0.03639409425003188, 0.04053140724343913, 0.09639922582677432, 0.011221579059825411, 0.042107084300369024, 0.031141914294234345, 0.05370495767731752, 0.007833790266886353, 0.04941590050501483, 0.026921124530157874, 0.09372703278703348, 0.07828363683074713, 0.02998320379161409, 0.0522099177220038, 0.05974988027342728, 0.03609155584126711, 0.016109152464196086, 0.05500534289915647, 0.053276052299354754, 0.04964954725333622, 0.103764180626188, 0.08344545627811126, 0.2536489564393248, 0.15366422943770885, 0.11680115892418794, 0.11260342238737003, 0.10252906368779284, 0.10511121513055903, 0.19017854652234487, 0.10375090848122324, 0.24764533287712506, 0.12807026851390088, 0.13297991720693453, 0.266706250075783, 0.09238231208707605, 0.17748304775782994, 0.15460737954292977, 0.16164385553981575, 0.19480390261326516, 0.11524288968316146, 0.16215165757707187, 0.17878099025360175, 0.10951485990413598, 0.17275205733520643, 0.1583738052951438, 0.10856797107096229, 0.0928633323471461, 0.2584921765540327, 0.12781049816736154, 0.11775538272091321, 0.13638722151517868, 0.1343107550804104, 0.15295271761715412, 0.11448014846869878, 0.09548601947192635, 0.09804503287055663, 0.1721557064780167, 0.12305630184710026, 0.06330971246851341, 0.14581372854965075, 0.09505889524838754, 0.12619525912616933, 0.09172315602856022, 0.09004809734012399, 0.14725564260567936, 0.15807537202324184, 0.1686198197837387, 0.24220475767339977, 0.1083909005724958, 0.11852921119758061, 0.16970950631158693, 0.12374804115721158, 0.11736960842141084, 0.11802150415522711, 0.07436874761645283, 0.16900748041059288, 0.08943108509161643, 0.16802257326032433, 0.12656742201319762, 0.13815909358007566, 0.16434515773185662, 0.09319217077323369, 0.13619370332786015, 0.11911619827151299, 0.09949324373155832, 0.15698154643177986, 0.16677944282335894, 0.07696420513093472, 0.12744509348911898, 0.1263824397964137, 0.1627266210104738, 0.07777164823242597, 0.14012145756610803, 0.08023878120418106, 0.11010551785251924, 0.07656932489148208, 0.09773960390261241, 0.07957319263368845, 0.20212271703141077, 0.24004210372056278, 0.09684738463589124, 0.10586666209357125, 0.10878041359995093, 0.11364642570593528, 0.11669209120529038, 0.10948039711053882, 0.17967763356864452, 0.09727557415940932, 0.10636547354183026, 0.2396911382675171, 0.10897373501211405, 0.15160962540124143, 0.13587230843092712, 0.17685986762600286, 0.14286805875599384, 0.09902853545333658, 0.15204931609332561, 0.26462472176977564, 0.1371246533734458, 0.08322296464549643, 0.09751110044973237, 0.1799093804189137, 0.07041844565953527, 0.1419783772102424, 0.13734557080481732, 0.11956325785389968, 0.13957056855516775, 0.0797034917133195, 0.11959033140114375, 0.09898101086063044, 0.08300149081540958, 0.11508580882634435, 0.18610061891376972, 0.11744135671428271, 0.11167057244373219, 0.14970474690198898, 0.11215080560318061, 0.14646620782358305, 0.17263351726744855, 0.16999605164996215, 0.15825936357889855, 0.09496908435331923, 0.1437979909990515, 0.16283634012298925, 0.17867040261626244, 0.18382827298981802, 0.07334122168166296, 0.1411467646913869, 0.1902698909065553, 0.10586723206298691, 0.09034294794712748, 0.22701963250126156, 0.11889040895870753, 0.09154041976268802, 0.12547188651348862, 0.17623066210321017, 0.16236350978059427, 0.09277058339544705, 0.1196723391434976, 0.13563207989292486, 0.14585397924695695, 0.1662792268076113, 0.1279699131846428, 0.28128400498202866, 0.08318753154682261, 0.1631687544286251, 0.15346777997910976, 0.1584213027464492, 0.1544360223093203, 0.12740279361605644, 0.18744208264563764, 0.07956940640828439, 0.14842513842242105, 0.1675250306725502, 0.08745193414922271, 0.10247737289007221, 0.09349836648574897, 0.14009648747742176, 0.14899227156170777, 0.11900364288261958, 0.11474196799099445, 0.16634131276181766, 0.13951492868363857, 0.08328716084361076, 0.20477809597338947, 0.08798246032425336, 0.12022485663848263, 0.1595933905669621, 0.1759271669600691, 0.17595159422074044, 0.1877940251891102, 0.19523614299084457, 0.12221356135393892, 0.1375993700431926, 0.12008165860814707, 0.15383006339626654], [0.061701815176223, 0.002914955481953387, 0.09754837237830673, 0.021652149136311243, 0.010748031166648226, 0.07275997501398836, 0.020601938079510416, 0.029864938530538763, 0.058806485895599635, 0.02785400500787156, 0.015334575902670622, 0.03463436117661851, 0.023541509539687207, 0.03509264712088874, 0.09504721087536641, 0.04828577668273023, 0.04353612315441881, 0.03372166033035942, 0.02628289788429226, 0.10486209778381245, 0.07406113376574856, 0.023063118602814417, 0.043622008724404235, 0.0733771026134491, 0.029994151954139982, 0.04879701549985579, 0.051728381775319576, 0.08980254230222531, 0.04559127341157623, 0.025903038713814955, 0.050101811199315956, 0.05583511658811143, 0.021754155002002205, 0.07700481545180082, 0.05496158756847892, 0.012919852127587157, 0.022722860432362983, 0.03199240704998374, 0.08414723112114839, 0.04434676554852298, 0.026316588844305704, 0.040887387070272646, 0.03603646558310304, 0.021560708060860634, 0.04301359012190785, 0.05215129229639258, 0.06590917333960533, 0.03307547786140016, 0.07992974242993764, 0.05445058963128498, 0.05301550163754395, 0.047761079123509784, 0.04704986585836325, 0.013541670948533075, 0.04133493859054787, 0.024406568745949438, 0.06278734228440694, 0.027273525084768022, 0.043115200740950446, 0.025295643002859185, 0.017748209780880382, 0.013288881879166832, 0.014573032302515847, 0.03094036564497011, 0.04810994451067277, 0.035607804477746995, 0.023612192532579814, 0.015606434350567204, 0.03158295187833054, 0.03172350022941828, 0.0634269497490355, 0.057245285383292606, 0.07172403524496726, 0.07449734357318707, 0.021583997079038193, 0.0770450932905078, 0.022683288270075406, 0.039680392015725374, 0.05691334944484489, 0.03349729933376823, 0.02271947284628238, 0.028581163845956326, 0.02618446959448712, 0.009337786036277456, 0.03406103301261153, 0.01355522298919303, 0.05033549187438829, 0.017472042635615383, 0.035058160578565936, 0.08810093932385955, 0.05271287162655166, 0.023300831472235065, 0.06103496453059571, 0.030186981428414583, 0.09000448110912528, 0.01294625986234418, 0.023113964624436836, 0.07350407008613859, 0.022615141301815, 0.012131763389334083, 0.06659876169370753, 0.010615171465490545, 0.04243425353031073, 0.05240998037957719, 0.045476207443113835, 0.01981184002943337, 0.049774088963334046, 0.028899451052503924, 0.01625201801237251, 0.07509655106280531, 0.06681032212717192, 0.021391963187072958, 0.024197856463225823, 0.014135118524011756, 0.07900882791727781, 0.0844577762431332, 0.02224294957704842, 0.04650566041735666, 0.05761877141360726, 0.022531740866335373, 0.014744360698387027, 0.009334806419376816, 0.014345030965549605, 0.02079675905406475, 0.015109797607042959, 0.03587668415691171, 0.025138691067695618, 0.022981740201690366, 0.011799882581856633, 0.03301397205463477, 0.011808848573959299, 0.052434960646288734, 0.0037261814161735985, 0.06104224521134581, 0.033643567735063176, 0.03420208687228816, 0.025308384194171855, 0.04763643563325916, 0.11134586629590817, 0.03601566509210637, 0.016792455887688056, 0.004909865400155208, 0.026750544219144752, 0.03115495912996786, 0.01479926096674587, 0.051289104989596775, 0.027523317573858157, 0.08002238960138389, 0.05227187475455659, 0.011206524912267923, 0.03062360853488956, 0.016212484865848507, 0.026634909977604235, 0.03645212935017688, 0.03887066225122128, 0.05838006056313004, 0.03418680965634329, 0.08800424808370215, 0.03632155546386327, 0.08730993034051997, 0.06463620771786996, 0.023703391031761254, 0.0176277121395937, 0.04646463958280427, 0.032909664258893044, 0.055454743427357504, 0.023443091427907348, 0.023751373635604978, 0.007356099069251546, 0.08152429293841124, 0.06379034596362285, 0.05874266289174557, 0.030904019916696206, 0.016132772268195237, 0.021419733929048692, 0.03441949967028839, 0.014665803306603005, 0.054948444345167706, 0.04764606404517378, 0.01122289541776159, 0.01502351339773408, 0.020827086176723242, 0.037793413270264864, 0.013357354544236191, 0.045489808677562645, 0.03449290698128087, 0.012409916097697402, 0.10641011436070714, 0.020161728308136975, 0.008059395527067994, 0.02404919283331505, 0.01523518918215164, 0.08521920109965972, 0.03614610666409135, 0.018849533184298446, 0.05174007293369089, 0.014744277577847242, 0.018230700765603354, 0.053591469302773476, 0.02437673186484192, 0.06024428124406508, 0.035336824732699564, 0.038195292598434856, 0.01961555002656366, 0.01555069100244769, 0.03651421191170812, 0.018223046890593002, 0.027289903223780648, 0.03776971882741366, 0.015530516460005726, 0.0475965547375381, 0.05803098143743617, 0.017315633528466736, 0.048114707826503685, 0.10066204065723078, 0.05974732219640698, 0.036779800696032386, 0.06612865906208754, 0.04800909724352615, 0.056507510864841085, 0.008149653407079833, 0.02303893561474979, 0.042055339219846895, 0.012343321278292154, 0.025066036930573837, 0.04800551457862769, 0.10109055587755782, 0.040094651215310605, 0.02963778536234583, 0.04642741854435631, 0.013871552622211831, 0.07960908713617496, 0.062004102527030876, 0.04978994632671986, 0.012998263634342169, 0.0299941926662411, 0.04408680860485349, 0.003821960026730916, 0.09086500600512538, 0.03496407152020505, 0.07874461995171649, 0.043645801554833136, 0.018772768821301203, 0.023277396569028497, 0.042225783823856285, 0.10744937895131962, 0.05258241987654141, 0.033009151063327274, 0.05389819087992821, 0.05703479703515768, 0.019990912206204872, 0.02260112955367991, 0.01792787228311811, 0.04831048892810941, 0.06773023919335433, 0.01532903905691845, 0.023496559987376844, 0.07017554369355951, 0.021635153530431644, 0.02776712199140872, 0.03519842394494584, 0.04615895277155297, 0.002089095243718475, 0.005166080223196852, 0.059157607411699634, 0.03257406423134463, 0.056728675961494446, 0.042561451704906564, 0.03352060361898371, 0.02840188980501677, 0.043474987149238586, 0.0887486892087119, 0.024236787409920777, 0.010408304798017656, 0.03395414678379893, 0.019266655801662376, 0.024406280368566513, 0.020061929377594163, 0.05451327269630773, 0.04315367028383272, 0.031447278801351786, 0.020061155847672905, 0.03620248953146594, 0.029741523188671896, 0.03784991827394281, 0.051995222456753254, 0.04471113885353718, 0.03117579354771546, 0.015545722429773636, 0.03485765348055533, 0.03431957521076713, 0.020947246246838143, 0.008816541372133153, 0.05571323473538671, 0.023656590775187527, 0.029850763933999196, 0.06446837208100728, 0.053776970598846674, 0.05385605385527015, 0.024824899155646563, 0.026366461168176362, 0.023856940113806298, 0.02703284192830324, 0.044904409375573905, 0.03274742653593421, 0.041672526725700924, 0.04272621018545968, 0.03395339360992823, 0.06635310487555605, 0.027874057414010167, 0.022464414925447533, 0.051679310122770925, 0.08982256587062563, 0.026623705668108802, 0.01598490761326892, 0.08208686632237264, 0.03381403948047331, 0.014039378929218011, 0.04004747946081417, 0.040178796342973194, 0.03504496307245322, 0.02190351582664464, 0.017546342220157385, 0.02806723633381937, 0.04657689302361437, 0.03976303758099675, 0.01827757735736668, 0.0521827050750809, 0.013431230892560311, 0.01443821587599814, 0.005545958053387169, 0.03850885720125266, 0.023772599907325845, 0.07214346488139459, 0.016952077858150005, 0.012510473291123552, 0.07369672653398343, 0.07136692905000278, 0.08792925639344112, 0.027933229060311402, 0.006733900268695184, 0.029718198547405855, 0.02092134826151388, 0.023994633528803076, 0.041096314787864685, 0.015053260372951627, 0.04519941604563168, 0.009264209091530314, 0.027946070335539322, 0.044041078737271686, 0.029107296506741216, 0.01388302240853331, 0.10318774477179561, 0.10700989860509123, 0.1603657262665885, 0.14138830958732537, 0.09641675238630601, 0.12222224660217762, 0.08599548587309462, 0.09300376873995576, 0.09258506513599839, 0.08649992237665824, 0.17803673233304704, 0.17275337369314261, 0.16290902479418687, 0.1130988954433373, 0.2811200166387217, 0.08410113823733159, 0.15708472446671554, 0.1283863301255873, 0.13363574844385895, 0.23937200967754635, 0.1330551260284015, 0.07993738273424761, 0.13388055030788693, 0.14212821131306036, 0.1703208392219884, 0.2318849457161767, 0.11486532565738473, 0.20196836388536862, 0.11870192550122738, 0.12177221503640924, 0.09570466381098543, 0.18167403287121228, 0.15204490561570438, 0.09529864881187677, 0.09503047141645636, 0.11256952277783837, 0.11837848142853805, 0.11558066441544465, 0.21559025294014386, 0.14546941273978778, 0.06494827275829655, 0.14036236463912896, 0.13716738750892027, 0.15261544500078472, 0.17739301973155566, 0.1184744941336768, 0.14113516174256802, 0.1301516882543053, 0.13684648115720066, 0.114511958190373, 0.16134455374308995, 0.09444882441312075, 0.20429976949734346, 0.11544222970094, 0.10316760585244213, 0.17332919208066805, 0.15806684962340764, 0.11589965729841165, 0.14837804809212685, 0.11009171645023993, 0.1671455396073205, 0.1876431054302624, 0.12200438257838998, 0.15143277203398092, 0.1762272829988173, 0.15212616696953773, 0.16809886773782118, 0.18475300765463284, 0.08955388635929142, 0.16802922290350708, 0.20188370985644205, 0.12243673152157239, 0.14877093343862466, 0.3076520657965115, 0.06681290734559298, 0.18731236032077245, 0.09417430950062615, 0.1472538241318294, 0.15735198583986076, 0.13108608525778565, 0.13780246914497443, 0.24274109889354023, 0.10774447383092982, 0.09721687409494605, 0.15956232723380837, 0.1017698644261275, 0.1263401127819504, 0.08103680623961346, 0.13046845554241113, 0.18741146714559623, 0.13735906008098805, 0.11077980524195091, 0.15934470748262747, 0.08245842531323433, 0.13835614014949116, 0.15564104621963842, 0.0949001180540238, 0.1322609686425754, 0.1514351333358458, 0.046185242610850503, 0.11173813417553902, 0.12825788344655717, 0.1340298280119896, 0.10701159494263784, 0.08231301525873796, 0.08774725294538907, 0.12078987274851118, 0.10779742670378514, 0.09748360621077673, 0.2725910757269178, 0.15906633170587675, 0.08693691928471838, 0.10041340507034745, 0.129135717770883, 0.14795027247497014, 0.15998171615813458, 0.127810661015766, 0.08947611946080412, 0.12195556876914841, 0.19019407140357153, 0.12525607166545732, 0.23907711835844175, 0.15265930550439016, 0.12389370905501501, 0.16803135350346565, 0.07136990781873465, 0.13806468221758092, 0.15006513042109354, 0.10285457729228906, 0.08418360738349812, 0.09325859256620918, 0.16390450352004596, 0.11904915901167051, 0.14265854071293557, 0.1207799661372389, 0.10084435623139143, 0.11586107579725129, 0.13595367835036345, 0.28589180058666636, 0.12470482981630734, 0.1562304760196379, 0.08363528323492833, 0.09963739171092, 0.06810390164277383, 0.09733067120292357, 0.15626436205846922, 0.11798360118908541, 0.24287965574434825, 0.10293955701802458, 0.09638083752776895, 0.09798952870603118, 0.17049301069762024, 0.12822783791593143, 0.08944179915956088, 0.1025373214589698, 0.11897845566272736, 0.12068913743964263, 0.223012313246727, 0.1215512433222362, 0.13677147589623928, 0.2685754783451557, 0.1386210402207715, 0.11794506040002618, 0.10639205175851073, 0.07215391432068177, 0.16383546936724866, 0.11479450017213821, 0.1141342855989933, 0.14351576114339487, 0.16291502304375172, 0.11921016180089541, 0.08377525143857513, 0.09616181320909943, 0.11689757875033788, 0.08877555919545037, 0.1366042848676443]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.00847005594654807, 0.04632970950167094, 0.03570783750287124, 0.05146227730438113, 0.04348807608974831, 0.06111395279211657, 0.025682984718254635, 0.015074369597381778, 0.031389861168073754, 0.04241531561794026, 0.04393802283863936, 0.042250160194401226, 0.0308753077073821, 0.03660464027364339, 0.019210040536043898, 0.04873830186469214, 0.01943319713297699, 0.02454533933528832, 0.021551831126479164, 0.02196010055818728, 0.04026089568755456, 0.045120241186980686, 0.049667382546301396, 0.019549525176574076, 0.03125901247507759, 0.025579129844637852, 0.03334368239822132, 0.06813539923833949, 0.005320518186116325, 0.05340537428855896, 0.08024953598422663, 0.04063451403219785, 0.04125597747042775, 0.038959760684520006, 0.055733875770653994, 0.041824579638029845, 0.03190698627648609, 0.013456032195660685, 0.04771342221647501, 0.020916942872905304, 0.04792760518778648, 0.029339487797447612, 0.02352272599403347, 0.02912631245063884, 0.06000131820993764, 0.0261292317549565, 0.017434137973136137, 0.028865643045199767, 0.01867416750506631, 0.03906864519896252, 0.019304597783567648, 0.02949026845661657, 0.022353148753089563, 0.08585346170834132, 0.03806689341685601, 0.06578670455408947, 0.0810070185522948, 0.015053126362285443, 0.015697671865512217, 0.03062556610841836, 0.04993761929550341, 0.046344314967947345, 0.05001686200765627, 0.061089281258838515, 0.026890719375972236, 0.07660313629146133, 0.03784266134191837, 0.029654460360429118, 0.03528576836522136, 0.03449962447796549, 0.017000152064221244, 0.0013188050091100323, 0.005008612601419112, 0.043634707507278235, 0.022810298151203563, 0.011131981055119207, 0.008701701016564454, 0.022590210228892307, 0.06440538367522614, 0.033849832202707014, 0.023503221504922425, 0.01772719724769039, 0.021060220631105558, 0.009953325863794556, 0.01274869590997696, 0.023358394990542104, 0.01728403415264828, 0.019782715610095432, 0.03344503856663193, 0.04704373190179467, 0.021376953992460455, 0.07934088259935379, 0.005348514540985758, 0.019994096231779883, 0.04579626562606011, 0.0219808993528464, 0.054694502614438534, 0.07394130448145525, 0.02315540615070079, 0.018196528045726672, 0.02132966010166066, 0.008227496640756726, 0.009860021361548985, 0.04984820195074592, 0.035448457313967605, 0.020644227774547677, 0.024357563250565102, 0.0514367915290807, 0.025953789740534763, 0.030132596846669912, 0.019756342650258114, 0.03623253845476678, 0.03765120929373162, 0.04401584741260324, 0.05858723087502377, 0.048894100290324004, 0.009063074348627456, 0.024573802182983075, 0.027255650776039277, 0.039554191287606955, 0.04453122529334255, 0.048371078712599616, 0.03343647884737168, 0.01378802496141621, 0.05020258043493543, 0.04170164944870131, 0.04326379991003445, 0.01415211073721626, 0.045253722595849206, 0.01642831158824265, 0.01878495022122349, 0.00906661375691848, 0.016331878191392337, 0.030014121239738803, 0.06154318725956338, 0.03212551187191691, 0.017065737562786256, 0.01166282274893352, 0.027526767924427986, 0.032617327624133656, 0.061257218675954, 0.010435818544855075, 0.015754950399111425, 0.031688196052398, 0.026799090007053952, 0.0254656737005072, 0.0586328012868762, 0.058711490992988856, 0.032860168521957736, 0.046009675067450316, 0.008854188191305314, 0.03483333478548697, 0.013792088538009142, 0.023206710183460797, 0.06058817636221647, 0.013158439459013087, 0.02530049452824252, 0.022969541838392615, 0.02491562776932759, 0.010035035898908973, 0.009812028579679983, 0.022080238575914075, 0.02606858259865216, 0.07923062744417361, 0.027984796025391136, 0.01798871991091541, 0.0707759725462113, 0.09106155045862709, 0.04456723853945732, 0.054861527401953936, 0.016635563324338624, 0.02208371097887201, 0.030218251714748994, 0.009810657938942313, 0.11666186925555978, 0.026901428354904056, 0.025202454699735557, 0.06726403813809156, 0.02904810450438942, 0.03869361889415553, 0.030175222416541407, 0.08053564706018992, 0.02240414235607854, 0.029208561072924306, 0.023563273550410355, 0.03363809535013778, 0.021361975331923792, 0.009521473947513317, 0.0419489042168217, 0.1192583649286202, 0.07580425630190543, 0.020099835736410956, 0.015552619738238198, 0.011831258041118937, 0.025556356513074467, 0.04916690190189651, 0.020719942104603564, 0.01644432162200766, 0.049288736257169924, 0.06809128767677716, 0.005726660834625363, 0.08418837069932904, 0.09918480206813131, 0.010960857067922396, 0.03187875921971031, 0.05497748903664095, 0.043274812533387115, 0.017666805934693133, 0.03664905717596412, 0.03286979354119726, 0.06866870740694658, 0.007965930720924266, 0.04427728356261339, 0.030955513939261436, 0.03528574122382062, 0.06299457366445235, 0.04110215697437525, 0.02097220785383667, 0.016336490533181598, 0.004188388444682849, 0.05480901896953583, 0.0674782855702298, 0.03991368253316198, 0.030763576738536358, 0.020039739586146813, 0.07129192378904138, 0.022944334262449826, 0.0316191686849509, 0.047049499449453185, 0.10072019110832896, 0.027837816858664155, 0.022714178576799374, 0.07091169990599155, 0.03322263514356954, 0.04927825967648199, 0.012583876361272164, 0.008471618273428507, 0.01831503927574626, 0.025058947935966507, 0.029043103701301982, 0.03932424934048738, 0.009379393803620977, 0.04987225601715701, 0.06686161258923155, 0.028845168251012052, 0.03291480076898422, 0.035516700973468165, 0.08241045288741589, 0.007359245775400528, 0.04500729903312666, 0.018852310088862265, 0.03679336800373026, 0.061185137900922976, 0.027789910590010028, 0.010237967063273703, 0.03478977622996483, 0.027471993185047592, 0.015063160198873706, 0.005874396567898137, 0.055841576241488965, 0.033164538975272856, 0.001968818762439436, 0.03466428117826581, 0.02817732185524489, 0.041140612946557145, 0.07679041874195848, 0.036245305091142654, 0.048724897405398745, 0.014046666395318295, 0.04844811957861696, 0.01066875537591321, 0.048706315723913055, 0.009460541502838688, 0.04584739663239036, 0.017656851825969558, 0.021776670490258505, 0.07567123629684959, 0.04379650418247495, 0.05031426390632987, 0.007568922426019396, 0.015151171279805047, 0.016776763069044267, 0.029263644545738186, 0.042723652108439376, 0.050185807049274445, 0.033072312495538166, 0.07362613853599344, 0.010951270216277667, 0.023657956326912557, 0.022449738212994168, 0.015306867925184113, 0.02177141693287662, 0.005644070824408638, 0.02649772716020899, 0.027091209510607377, 0.04416590882465243, 0.026497082551941276, 0.011693657924687224, 0.06785304046102933, 0.0345286352426878, 0.031257411132433584, 0.005816699463009302, 0.054733060366873226, 0.03480387958032744, 0.011221348357919072, 0.03345111824039902, 0.026635596994310617, 0.020049522364778177, 0.01831159062151398, 0.047625623177737, 0.058537412833954604, 0.043769121901797395, 0.008683350036985107, 0.0831449127623013, 0.07160772077207055, 0.03363924885966948, 0.061918552831879685, 0.03060664515942335, 0.050930366917912445, 0.06009572957243238, 0.050976300345999856, 0.027716927363404205, 0.08520396120314087, 0.05175556728084173, 0.04537258157506585, 0.024133360013365746, 0.018522740541292087, 0.031996620752449544, 0.022503680050639168, 0.04093707958236337, 0.07032794944409813, 0.026077864957707267, 0.013693800196051598, 0.014288832998967596, 0.057735588002417765, 0.035707291282181225, 0.05350622834105577, 0.04888941500602024, 0.07805880425231797, 0.05579928654645171, 0.03612143852348838, 0.014002654917671211, 0.019695416990933672, 0.05516304122284055, 0.049574664128678184, 0.045379343176526685, 0.04103694975908313, 0.04531758970447949, 0.01934824454864221, 0.01894881812456463, 0.031625448526548486, 0.08744360173919372, 0.14182835311761924, 0.1855860043849264, 0.08845664773668561, 0.0866514528170228, 0.12414932676724025, 0.13488509426159517, 0.09181023242750339, 0.0945470966398716, 0.10125396068074874, 0.08329408190080098, 0.10824131074228457, 0.10469010951263563, 0.09472924258027758, 0.22361618227192334, 0.13229218125343323, 0.11455661936530045, 0.10820330599589006, 0.06609508514936481, 0.09926239254751376, 0.1337086773876633, 0.09867757000029087, 0.07747365600828614, 0.15210252680948802, 0.17946329792695387, 0.11866854157830987, 0.15504104484404835, 0.17056421616247722, 0.1480583223913397, 0.12935226543673448, 0.28741964431745665, 0.16045361012220383, 0.18679288748119557, 0.10317036070461784, 0.13080378754862718, 0.11009208285915, 0.09482596774718591, 0.13077638830457414, 0.05144644029704588, 0.09144429849194628, 0.1448355388960668, 0.11767672694155148, 0.14633563054459436, 0.11820130236446857, 0.1418617641819375, 0.1261970368879182, 0.2523147937442575, 0.18274045921862125, 0.1705213598906994, 0.09132546665413038, 0.09538978963558163, 0.12362978607416153, 0.08312695194035769, 0.14941185047583921, 0.15776271665734903, 0.14795016390936716, 0.11897027253040246, 0.11634237425667898, 0.14302469177969865, 0.13690341024526528, 0.0891695369833282, 0.1160666990493025, 0.1148163489997387, 0.1192875826465232, 0.1137100247932332, 0.13696883459176334, 0.12882002256810665, 0.09313982179654495, 0.0756018968032939, 0.09121751851801362, 0.16362889616617135, 0.0505938305120383, 0.14691659222756112, 0.14629080652126245, 0.14808470383286476, 0.07500637375882693, 0.12696056520300253, 0.08394346705504827, 0.132872342265078, 0.1744280116898673, 0.13878771556275232, 0.09998537839523383, 0.11496720090508461, 0.0967554227848138, 0.13138654056404317, 0.13535987878484385, 0.07957841056798186, 0.07217978686094284, 0.14293132536113262, 0.10155505380992379, 0.19250145687588624, 0.07818837051412889, 0.12959613092243671, 0.09080610238015652, 0.2015402354300022, 0.08431515496756349, 0.10465451356555734, 0.0656476795141186, 0.13404751063457557, 0.0842198140120932, 0.08143989675279174, 0.1193476737077747, 0.09575157772217478, 0.11901486585182802, 0.14078833535313606, 0.18689575339002268, 0.12242230586707592, 0.08396379596420697, 0.1575059454355921, 0.08693537222487585, 0.1019942220300436, 0.20343889854848385, 0.17850342871887342, 0.14271730184555054, 0.13869335848305905, 0.11409689831946578, 0.0788056677473443, 0.16143786587885448, 0.11575917340815067, 0.13484530496810163, 0.17016633679824217, 0.12798665942890303, 0.15101711505225726, 0.1883985727493252, 0.12179092903222356, 0.10299151922975268, 0.10422659545604672, 0.13425747651074613, 0.08857444141592298, 0.07738480863294431, 0.14887274083282265, 0.09878967077072177, 0.10958839274410691, 0.17272384384913103, 0.15759178011545114, 0.19069620088807174, 0.15759273006447724, 0.13172481741224015, 0.17808693035372666, 0.14686609565147332, 0.1301414423755237, 0.18852179470871175, 0.15402017533779144, 0.07189626778875079, 0.11795527913740703, 0.1201039416981595, 0.08034621365368366, 0.22125527395733766, 0.140629218891263, 0.11820065097085067, 0.10291918061141457, 0.14807962839092526, 0.13304600651775086, 0.08006065219108548, 0.1596566028892994, 0.18746546496238026, 0.09833437377320868, 0.07391609012016229, 0.1603335772774049, 0.1241999047675303, 0.14654985762068204, 0.2616489657333919, 0.1557073119495596, 0.1979872632239546, 0.17183599434792995, 0.1585503736776965, 0.14193800437663281, 0.1468611287751368, 0.14946831816009112, 0.22777573764324188, 0.11735729979617254, 0.08822806964495353, 0.1506340548928295, 0.11266661435365677, 0.08061687448727232, 0.13291164301335812, 0.18004887364804745], [0.03882817238835352, 0.05325838324746915, 0.018396716232278516, 0.019149203086271882, 0.02264797391502985, 0.03132871837754335, 0.06510191344256912, 0.0030459265232950982, 0.04589407305632319, 0.04182311739506466, 0.017213379997493963, 0.015077635047159024, 0.044724763836711645, 0.05506415152922273, 0.024448754964396358, 0.01445244305900165, 0.011738071434332855, 0.03697103222033807, 0.04493430223582046, 0.033398443566901345, 0.0516715375041323, 0.015357176207804253, 0.01740447411845837, 0.012833351635241082, 0.04253730603626796, 0.01879604596511594, 0.0851433544552752, 0.016331934170531373, 0.022457680465387445, 0.03342914388382009, 0.0491661046232496, 0.04400948275412832, 0.09602186536150319, 0.0698676041460463, 0.02211172429711691, 0.026509526884183288, 0.07051724035825048, 0.08286642163459744, 0.023307618518759097, 0.043829121360821385, 0.07613629741328103, 0.029913484318447963, 0.03985163389838167, 0.09721249075872557, 0.02536710461468569, 0.03510875214955636, 0.029221158075545515, 0.04380114196932741, 0.036140335723757744, 0.06052514724433422, 0.03498148272878357, 0.043896672914602926, 0.10945958644151688, 0.019154792518488, 0.02656432197961424, 0.04373989061319402, 0.02625335955859295, 0.0065990083551566514, 0.052390981399055035, 0.045417086686939, 0.009316011847529029, 0.01000375289004296, 0.006498493570169168, 0.035564089859170575, 0.05369401630014181, 0.013125181913242807, 0.04372375505045056, 0.07631778517471892, 0.03270754903288824, 0.06458417086728982, 0.026534137349309664, 0.0515894076254751, 0.07378494287175791, 0.04465836239978671, 0.026939222755442773, 0.02857902306797249, 0.07769881428352424, 0.06732528949422495, 0.030199446116707156, 0.018869762009541904, 0.0623205712597285, 0.02581298184980239, 0.028854545604969774, 0.01226759677021099, 0.015070384900484766, 0.09685932006686926, 0.02244574503440942, 0.030806918162852526, 0.02775965810620359, 0.03512933211667197, 0.04677231450166021, 0.039864180010876486, 0.020928818932069198, 0.044375962910375426, 0.026292711196999465, 0.02977140587089317, 0.04362559478197779, 0.08395502929176603, 0.024167541214930158, 0.04094522539526224, 0.004706408795235413, 0.03680579537259681, 0.031092459269400154, 0.0811833765889917, 0.009978764141643686, 0.024686284629361968, 0.0370546039859099, 0.018216750085619942, 0.053674963036818166, 0.039947385367538245, 0.04404544850279178, 0.027571710691388165, 0.04504494754863637, 0.05093755938911012, 0.05345419827582581, 0.051964430537606986, 0.06215538190943854, 0.0285676202869841, 0.04180184192955494, 0.031126016218747412, 0.020609408750065734, 0.008728456500518535, 0.0869507613990988, 0.046793562825769186, 0.01982788398994931, 0.007560299094101148, 0.05044942129669445, 0.08665580222649233, 0.04275601144347872, 0.03374249135543193, 0.09389691759965249, 0.042323475903166194, 0.04567938118374773, 0.031015703388090645, 0.02668293159721153, 0.027163780527189374, 0.05776841552661998, 0.04773564763101084, 0.06694870934422527, 0.058353875896760395, 0.03640157509861248, 0.013925299381038972, 0.06316903858844723, 0.0549357455622937, 0.050265463667788675, 0.029192802097116197, 0.02058635213013206, 0.032828100956976414, 0.03851904540455767, 0.021154112914311032, 0.028724528117371455, 0.04718367974939091, 0.03839316698057311, 0.015560297361974205, 0.053761703560927084, 0.02474571411897029, 0.11206860787102155, 0.033222947269678116, 0.097821638786367, 0.0324067544591214, 0.024147426044302325, 0.026134931449113146, 0.012150473144304539, 0.05026061214240534, 0.03578442714310118, 0.017588041589728425, 0.025228018506563137, 0.039470663626811335, 0.09942298821572747, 0.02579001852843378, 0.02670510103260832, 0.010182181306715523, 0.00420482553142522, 0.02899688868118184, 0.08098546149475233, 0.08150305479232754, 0.011170845844649842, 0.026498544794906462, 0.05669730728758233, 0.05594051682523318, 0.060822549143007824, 0.024998872141752924, 0.09378845377692155, 0.028724450085844313, 0.027649294385420423, 0.012811495174121643, 0.03927796307419028, 0.06860944415841784, 0.04045018660170691, 0.029040864535740445, 0.05124748365155288, 0.04725601836772902, 0.06965187072221722, 0.03914931962000472, 0.05154664634859987, 0.0426926634141377, 0.02082485379651189, 0.007904659008740314, 0.04269329784438014, 0.04809237723903997, 0.020752426968621354, 0.08636844264609472, 0.026287199796310494, 0.010566312703303993, 0.055691826955548356, 0.0194343472498336, 0.05856571452958243, 0.02076293238704758, 0.03476398511390601, 0.033151653595268726, 0.0219142298945891, 0.036304741366101165, 0.1098065756793533, 0.013139459986372717, 0.027424404131514684, 0.07440276936228786, 0.08291199204644986, 0.012316756632312067, 0.0419564868456551, 0.02940197747999004, 0.03671901074371167, 0.036054904772234816, 0.0448028530393328, 0.013003023557497986, 0.025171242088877728, 0.00869390889004405, 0.031133066197591167, 0.034598721124764, 0.021362635207229426, 0.034551464553390226, 0.024593700222404938, 0.04543329010318432, 0.01492887981502073, 0.011010586051270366, 0.01999650163842099, 0.0257885528927935, 0.022257526205586534, 0.08707111315535647, 0.05489135580137372, 0.02052091251659606, 0.08823868871799537, 0.039071742711322646, 0.07475734462163278, 0.03903816879859992, 0.03541500214487314, 0.06035030912607908, 0.017562392966023514, 0.03849581236551915, 0.04438442763473306, 0.08367341011762619, 0.018447809919182743, 0.04965340133224215, 0.0294259433368487, 0.013790454116782971, 0.021043470994170223, 0.06868092103728227, 0.07303306500294379, 0.04750533248963101, 0.018587196279051046, 0.04930218482123954, 0.07220782392791339, 0.0729065453633666, 0.03895073277609689, 0.04097231251320668, 0.038123937855873785, 0.04653229291683861, 0.01083786750677973, 0.06115223573786872, 0.05499514112515109, 0.06476915986942393, 0.07993299261267696, 0.008266444550827146, 0.05353053007274866, 0.06962027134639875, 0.0451389619681452, 0.030326193065515587, 0.01392862165812403, 0.08266362787357398, 0.07227536530366965, 0.05156759611730065, 0.016523830659155334, 0.07008679809847049, 0.06111170005585466, 0.006808987802027592, 0.02717558534017631, 0.11151140848440783, 0.034970514210207124, 0.03217562507571919, 0.02814794977062515, 0.05856135154941252, 0.06201960705220699, 0.0006928602711663448, 0.03296244749799371, 0.008003943949006498, 0.05753056864653315, 0.04615626238020403, 0.0739162326125162, 0.08105157116161925, 0.05200450142313327, 0.010990791488438845, 0.015963849278965166, 0.030452845019421408, 0.027412801182695797, 0.05915800774736064, 0.026430362203557576, 0.012213784702388304, 0.07437287310936622, 0.04404560795852116, 0.057195888033935, 0.04625468049198389, 0.026353942197082297, 0.019329908836100782, 0.012172161668006862, 0.02049873459951154, 0.017731602636298964, 0.07004444394260645, 0.024197332294923917, 0.02911210053467325, 0.039510673444185934, 0.07595639742378678, 0.007184024284859853, 0.04063017480075359, 0.05305469721289618, 0.035436104583953104, 0.040674778300204446, 0.0282763421668538, 0.05730180735034602, 0.056502652554107566, 0.08515541880790677, 0.021757052346531833, 0.025530193899092928, 0.027144939306059053, 0.027483102499640415, 0.06467723873044763, 0.04587519621210439, 0.017314895621633956, 0.05038026161491871, 0.01763136774700667, 0.015103672132162111, 0.05847071284162147, 0.008388236497661896, 0.09938997748707022, 0.05683814401605299, 0.011720365063021225, 0.0798967249159302, 0.007438905786589852, 0.027978745189362338, 0.013922502120424594, 0.03790794998141272, 0.008631424296514263, 0.05168954921620233, 0.010143771135647382, 0.06476310733705759, 0.14858250426394598, 0.14103388360568456, 0.12163262681237288, 0.15922601813716547, 0.09973419830203056, 0.17637524434498378, 0.10760237502732448, 0.15245645067521504, 0.1163793679858957, 0.12638328117983683, 0.13881013435976847, 0.11459900066256523, 0.17568577134183475, 0.24498827116830008, 0.18698810200606072, 0.09032736878309931, 0.0901978025212884, 0.10793314049286501, 0.07598999169256006, 0.11586927250027657, 0.16667144718979085, 0.07819321525416204, 0.1309381239116192, 0.1259513936404671, 0.1320263176624264, 0.1953810237880264, 0.11627043597400188, 0.08483345394155808, 0.10506569221615791, 0.15046153057898792, 0.0873896446345108, 0.15547384162034306, 0.13521053322723933, 0.07938980497419834, 0.10632336365857295, 0.19098130773220742, 0.15223712101578712, 0.08361660995121513, 0.2852988424045699, 0.14005094420697006, 0.1365458494318383, 0.1318974910037858, 0.20214742927678994, 0.21205291418092592, 0.08703257236629725, 0.10122808135513749, 0.162430521899036, 0.11963283483471189, 0.11255962973726646, 0.1348007930708783, 0.20010668092540332, 0.20674497900264605, 0.1382272592080491, 0.07775540410407952, 0.19122684241405555, 0.11586320639720984, 0.12824858751680168, 0.13258897247059004, 0.103551724526499, 0.07781622119780097, 0.15346161888114043, 0.1262323342795883, 0.11314652860164642, 0.16642650961875916, 0.11012816735144172, 0.11782616749405861, 0.14636676173124993, 0.14502516229237827, 0.21885450849575655, 0.163908398311053, 0.119927671871015, 0.18468541199607508, 0.21189012005925179, 0.06925981318844215, 0.10251187639577047, 0.13584355211683682, 0.15748021538768495, 0.08455374145082065, 0.20021968414740904, 0.10836748432900224, 0.12061759270727634, 0.17845299999628747, 0.08739733243627207, 0.18378853797912598, 0.16887436541063444, 0.1155257166496345, 0.1455434001982212, 0.1416984408029488, 0.07823156605341605, 0.08135290856340102, 0.14909429608711175, 0.10909031411366803, 0.19286317032362732, 0.18743229817066873, 0.16304678097367287, 0.15013845291520866, 0.17657100169786386, 0.06305712780782155, 0.11944475849824292, 0.06118802846010242, 0.14613044155495508, 0.09971296015594687, 0.14006840969835008, 0.06391033809632063, 0.21079820793654236, 0.189747527507799, 0.07491707176502262, 0.10586682494197573, 0.2712766176887921, 0.15633273124694824, 0.10226438074771847, 0.17125383844333036, 0.2333612750683512, 0.15077197392071995, 0.13187813918505395, 0.1700481902807951, 0.10277330236775534, 0.10797286871820688, 0.1389059027923005, 0.10623365454375744, 0.11633645743131638, 0.1706510686448642, 0.07845429517328739, 0.11642126073794705, 0.0997593312391213, 0.09364992406751428, 0.15215838381222316, 0.16786908863910607, 0.07080415889088597, 0.13679282260792597, 0.11568230896123818, 0.13258511839168413, 0.08633448196841137, 0.1053148095629045, 0.10267213279647486, 0.1543701637004103, 0.1354843085365636, 0.17240379245153495, 0.24636124606643403, 0.08372734008090836, 0.10227206176412956, 0.11881730359579835, 0.13931873706834658, 0.17181966879538127, 0.12535671197942325, 0.11674105429223605, 0.08954814595303365, 0.10342983928109918, 0.08366776470627103, 0.09758200057383094, 0.09662826532231909, 0.12225229213280336, 0.07251997039254222, 0.15036635925727232, 0.11614072721983705, 0.1467287873050996, 0.1677991316786834, 0.23491066907133373, 0.09987512324005365, 0.06141446916652577, 0.0700756429827639, 0.08992904158575193, 0.16017903414155754, 0.10963776295206376, 0.25659127426998957, 0.203062094481928, 0.1483975084764617, 0.16758468747138977, 0.08025503890322787, 0.08639934313084398, 0.13658308743366174, 0.14766071444111212, 0.09229070307420832, 0.17206257076135703, 0.1565465104899236], [0.03041934235287564, 0.02322660991922021, 0.014694164374044963, 0.01803899765945971, 0.06530260374503476, 0.04895066296947854, 0.030003247716064965, 0.025599063507148197, 0.0283362110078867, 0.0049586236543421236, 0.013758714793116918, 0.015425219699474317, 0.021919422383819307, 0.022361070649432283, 0.05759386917842286, 0.008995231872956668, 0.017159511102363467, 0.011351157195999153, 0.03240712426070656, 0.00792291244891073, 0.026265720770295178, 0.02158396993763745, 0.015282016580126115, 0.038043721445969174, 0.018423835580636348, 0.024958141380921006, 0.012054155098407396, 0.0042745178631906, 0.009304059453175535, 0.03467312927490898, 0.051222225185483694, 0.017101747416225926, 0.054398118518292904, 0.04028727373640452, 0.006816660760835345, 0.021904689692226902, 0.013438182483826364, 0.02643251315956669, 0.01696790468745998, 0.04682795437318938, 0.0461563302337059, 0.04659301840833255, 0.03288046011169042, 0.04237887828743883, 0.025176341279542873, 0.07648465729185513, 0.0611769954806992, 0.05578907120174595, 0.04435191223663943, 0.0076412551071760905, 0.05202119338459202, 0.007072030383694384, 0.03290026654888477, 0.04861903237178922, 0.03513118451727288, 0.05396011737840516, 0.06453582524721112, 0.014610931875982454, 0.03266776652474489, 0.025212249352729747, 0.058522335785840235, 0.022977989599374787, 0.03399361377315862, 0.02218893649322646, 0.03802910240899239, 0.023329041565635374, 0.028753949395780052, 0.05872681909906013, 0.059057001024484634, 0.047672353884471316, 0.03827459977141448, 0.07367928139865398, 0.02506371634081006, 0.009969949123582669, 0.004020840337034315, 0.01155368039118392, 0.050488572767270465, 0.014325216046667524, 0.059329364980970106, 0.004744990720480148, 0.08498904202133417, 0.031016174969928603, 0.024933763314038515, 0.01384113050465073, 0.02019018437048154, 0.046523254830390215, 0.014170460868626833, 0.03472238073923758, 0.048552746285817454, 0.04673961250643645, 0.019815643218212893, 0.0027130894055257416, 0.023102604251887118, 0.02348891120137913, 0.02603705277267311, 0.033830531274101565, 0.019904938426667025, 0.026208464289084077, 0.030849340172218423, 0.11897684074938297, 0.053434982164097686, 0.005239927309698292, 0.04074930858665279, 0.04662299947813153, 0.03737847214298589, 0.003998096267293606, 0.04513793059491685, 0.04635198241365807, 0.08988117772553648, 0.03253288394106286, 0.003800721456562834, 0.03870624643085258, 0.08297483795987708, 0.03905323227601392, 0.07192773145756551, 0.0804211985585945, 0.03895954355331404, 0.008813314938119479, 0.044845105414944034, 0.02587187529674598, 0.03200701590893524, 0.020246609646294798, 0.05408124266458409, 0.014917953704882945, 0.048823614072586806, 0.007679319225384721, 0.06674734729209117, 0.07361890535269465, 0.030688713969928876, 0.017363415964479958, 0.04729408757495029, 0.06076631216066224, 0.0038294858282565004, 0.042067573206233125, 0.025319386639499238, 0.06354833966387169, 0.04828751373237797, 0.07545712457171508, 0.010782019833901098, 0.027794592481638705, 0.024104642715038996, 0.022163499911714877, 0.053828135531927855, 0.03363968312208142, 0.03998905420303345, 0.038487035515052934, 0.004698485202555145, 0.041812667955777476, 0.028462532175970928, 0.026915733569434712, 0.016578169439786246, 0.02839416468382946, 0.04390367878867047, 0.013551903256614293, 0.08122598180281264, 0.02166713967121073, 0.08931711156453405, 0.019346760253288915, 0.038328760436603, 0.030308557940380912, 0.031248532501714568, 0.0038022082964224474, 0.04079039727470704, 0.020577001917575086, 0.015498794947883912, 0.0401159402515207, 0.03893535038722413, 0.023984503000974655, 0.06596267582582575, 0.020243327233142087, 0.040714475991470475, 0.0270935826868351, 0.11847121002418654, 0.007119202986359596, 0.0673329026571342, 0.023119528611589755, 0.003805563652089664, 0.06023500567036016, 0.005197168153245002, 0.04713567339682153, 0.04803883404071842, 0.03263915948835867, 0.033651740689362795, 0.0089290984573641, 0.0499346642754972, 0.03218420854370509, 0.01499184956108885, 0.06140183484447854, 0.020526045634012138, 0.049218158437205214, 0.05317633140033909, 0.01830007927492261, 0.025886290773217167, 0.0053287606902553564, 0.029692098697913543, 0.018496167413624268, 0.027087236688073193, 0.04029666466106262, 0.049019859970680306, 0.024997852642887404, 0.07406439751918827, 0.05887610358851297, 0.033673518270786316, 0.0918447087918009, 0.033315977813409905, 0.051076173915394714, 0.052350276083286316, 0.038278969536934576, 0.055998551925378184, 0.019394549474652325, 0.012572227611339517, 0.030204226395913532, 0.038298613125724454, 0.01090581261087209, 0.03089138898732407, 0.07396229835493223, 0.04009393536086593, 0.036751828089888604, 0.03361229744872876, 0.06200807874224015, 0.06981488197509732, 0.06339731812477112, 0.056375471342887194, 0.06530902268631117, 0.03271217324904033, 0.05273904272222093, 0.03299371099897793, 0.021916826987372975, 0.031590592182640514, 0.06606182336275067, 0.013823881296307912, 0.01757046753274543, 0.028563281055539846, 0.07610813821000711, 0.018784475246710435, 0.014824183557980826, 0.03755358506792358, 0.021172767538311224, 0.03374325131465282, 0.007955251427899514, 0.012374203951497163, 0.05201911706743496, 0.00521274477276685, 0.07439951239419834, 0.05142204696312547, 0.012569278528514718, 0.04598416893609932, 0.04608753017549004, 0.016390846277187978, 0.0663042842809643, 0.007046615430486521, 0.04099495183410389, 0.033647007907607725, 0.04679822775402239, 0.02577799149522824, 0.033466914535633156, 0.03700199716591409, 0.023178076005673835, 0.021886571110891442, 0.03338546997734478, 0.026691342038767676, 0.015244037278794816, 0.042191606014966965, 0.028891817533544133, 0.008519196300767362, 0.05378166606117572, 0.06804056718413319, 0.05741755185382707, 0.02673304480101381, 0.06061750943107264, 0.031880204499300034, 0.02720032472695623, 0.004783938630550567, 0.056278064248285124, 0.0210866818004953, 0.05070664713691388, 0.02193507788303707, 0.07278511473642928, 0.07133932624544416, 0.06910910377545015, 0.016616113118029067, 0.011154893486361419, 0.02377257785493774, 0.03507973120680877, 0.09581020993313619, 0.01665955632259803, 0.030479162000119686, 0.05345848661714366, 0.04198699378009353, 0.010812166296610875, 0.043297058303973505, 0.039521356978054555, 0.04661147116816469, 0.013891251341971968, 0.018145056075549552, 0.04143047632117357, 0.01090128593412893, 0.009309670089610984, 0.029976252200348035, 0.03731911050687943, 0.03169877441333873, 0.014533339700262462, 0.0544410969263741, 0.07787646832210676, 0.03898781132219093, 0.03516029706224799, 0.06882430905742304, 0.057709267629044395, 0.03673674086374896, 0.016262021314884936, 0.026944803705971156, 0.03872846166736313, 0.09147819131612778, 0.03189746643017445, 0.04578258975275925, 0.025621299099709307, 0.060926880687475204, 0.011521421988228602, 0.04950091755017638, 0.03771237922566278, 0.025726293912157416, 0.009069912285277886, 0.009716276262354637, 0.021979342114978602, 0.026468310970813036, 0.014615576448185104, 0.03447702247649431, 0.05382077003430043, 0.009263092901424637, 0.07838689628988504, 0.025770037368472134, 0.02858878718689084, 0.07575749845377036, 0.027711027501417056, 0.06816085108688899, 0.02316193705025528, 0.02883403349135603, 0.023846483889168928, 0.06185103181217398, 0.025792094845590845, 0.024680642610681907, 0.013671512017026544, 0.026869718717145066, 0.0726590972127659, 0.057247660255857875, 0.044449651813400645, 0.05386115983128548, 0.02684760356454977, 0.002299853945649894, 0.02137256895990244, 0.03927454325769629, 0.0075970892628122655, 0.07200466375797987, 0.08359498504017081, 0.046214263553598096, 0.13222830396677765, 0.2060765405850751, 0.06594276082302843, 0.08838960169149296, 0.053317137594733915, 0.09650870745203324, 0.13325009628065995, 0.09457086572157485, 0.13153946878654615, 0.13118254579603672, 0.12373330337660653, 0.12987595876412733, 0.12002710439264774, 0.14386123046278954, 0.051266190862017016, 0.11623916908034257, 0.12299982059214797, 0.06948692564453397, 0.14903938903340272, 0.09712015571338789, 0.06625590473413467, 0.12961469564054692, 0.13005053225372518, 0.13037033937871456, 0.15135683039469378, 0.08549210109880992, 0.09690256310360772, 0.12281653471291065, 0.12657096396599496, 0.13964615735624517, 0.14650997333228588, 0.14652741168226513, 0.07931801596922533, 0.09064191047634397, 0.058360573037394455, 0.11244498446051564, 0.17394938665841306, 0.14885005062179907, 0.11192576946424586, 0.17894822199429783, 0.20096783685897077, 0.1277088943336691, 0.2087634578347206, 0.12760722264647484, 0.22354793521974767, 0.13233661172645433, 0.11351782974920102, 0.16204987732427462, 0.12403377225356442, 0.12936438407216752, 0.13651144770639284, 0.16246714921934263, 0.12519997039011546, 0.10014723613858223, 0.2009942318711962, 0.08073307360921587, 0.09410338223512683, 0.07856853332902704, 0.08747347085071461, 0.1387566386588982, 0.08848290704190731, 0.11519384517201356, 0.1096011966999088, 0.08640493425939764, 0.14369409371699604, 0.24243754946759768, 0.16258034243115357, 0.0832954254001379, 0.17417254325534615, 0.11217759416571685, 0.09016788591231618, 0.11396013280110699, 0.2124806490859815, 0.09006067059401955, 0.13293206691741943, 0.09308641430522714, 0.10486861171999148, 0.15831000943269047, 0.20587513782083988, 0.17583107283072813, 0.07967763274375882, 0.10812354420444795, 0.09311979822814465, 0.08363344440502779, 0.12322216294705868, 0.1218956812684025, 0.1023294251146061, 0.13737519564373152, 0.14533819763788156, 0.13448083666818483, 0.1445731222629547, 0.09891119639256171, 0.18281949497759342, 0.135824783838221, 0.149008325700249, 0.06594505427139145, 0.16625919645386084, 0.1195434717727559, 0.2113970693733011, 0.11422717704304627, 0.2820885575243405, 0.13755084121865885, 0.09599677313651357, 0.0994849248922297, 0.1483719548476594, 0.23410885781049728, 0.1550251535539116, 0.12064510051693235, 0.18176693788596562, 0.13985848453428062, 0.10838250030896493, 0.1086194243814264, 0.14948448086423533, 0.1098173168886985, 0.0593288696504065, 0.13072510462786469, 0.09186055258448635, 0.07042493245431355, 0.1066454845879759, 0.13460400434476988, 0.20352482822324547, 0.13289541245571204, 0.07112581163112607, 0.14931066733385834, 0.20507758775992052, 0.11472120481942381, 0.13648201285728387, 0.14761617540248803, 0.17262860467391355, 0.11138767762375729, 0.1288196425884962, 0.0906159361558301, 0.24272703964795384, 0.12018081971577235, 0.18995601417762892, 0.14059381293398993, 0.14952869420605047, 0.1576731228934867, 0.08024682862950222, 0.21619747392833233, 0.11311221508575336, 0.11748327660773482, 0.2457512430846691, 0.09331177614097085, 0.08679737855813333, 0.12675830748464378, 0.06814429483243398, 0.07978340278246573, 0.12984279197241577, 0.1098618491419724, 0.10800406097301415, 0.1563193505363805, 0.10248964080320937, 0.2812472826668194, 0.08117658445345503, 0.11764009962124483, 0.06550230338637318, 0.11950009981436388, 0.07980432201709066, 0.16026812578950608, 0.12661770145807946, 0.10998335440776177, 0.2339248933962413, 0.14476882533303329, 0.18117281262363705, 0.17403644270130567, 0.2141743946288313, 0.10937825044883148, 0.11924807833773748, 0.1778672614267894, 0.08033599491630282, 0.1343116643173354, 0.08726967285786356], [0.018089558696374297, 0.021800889101411616, 0.007581242925620505, 0.02790133621809738, 0.013373753039299377, 0.02050577100765492, 0.07222167282764401, 0.030083168963236467, 0.053719858306327035, 0.011231992027855344, 0.0248480236290821, 0.02955146213727338, 0.021849833528644273, 0.046590918342449834, 0.016154032466667037, 0.016974649325545346, 0.04598658112809062, 0.022533172575224723, 0.032692098790513616, 0.026967923090394055, 0.04491781383486731, 0.037920234857925346, 0.04155992044668112, 0.040684929184083424, 0.02117755969188043, 0.02955361987863268, 0.019861603787701045, 0.09029249886849097, 0.04668328392186335, 0.0262716087579195, 0.059839460466589244, 0.04172226334256785, 0.04460537899285555, 0.015314438679654683, 0.016985543205269744, 0.035228228595639975, 0.019106243337903703, 0.028391382690253, 0.03809558866279466, 0.006395420284076993, 0.07887751103511878, 0.07931510505399533, 0.033591727659638436, 0.023817481606134346, 0.03941103057669742, 0.028491529369992868, 0.02539344025509698, 0.01499412434973887, 0.04797007130192859, 0.06154809306774821, 0.04576345506523337, 0.04394799730341349, 0.02973659023908632, 0.04273149258057986, 0.03430469833048327, 0.07316355407238007, 0.04074602786983762, 0.04337273870727845, 0.03925387168835316, 0.018111885891162922, 0.041152826576892815, 0.007086257990782282, 0.07843841745385102, 0.017289688045691167, 0.04805123766085931, 0.06468297235135521, 0.03278010817510741, 0.010921637743844517, 0.046695948777986426, 0.020471133491290466, 0.03077441294278417, 0.048429822881839106, 0.014833014691248536, 0.0327489396690258, 0.028134194169459597, 0.025664881403957094, 0.032285378114985566, 0.04051798242809517, 0.03769028273278049, 0.04048281056540353, 0.03393411982272353, 0.07975210196205548, 0.0614902615281088, 0.07026654881026063, 0.0348286020037319, 0.007143839744717947, 0.017857319908216596, 0.03148150410769241, 0.026251128874719143, 0.0216896975679057, 0.013367373961955309, 0.06485287073467459, 0.04319604140307222, 0.0320397687942854, 0.021924167039937208, 0.07287875935435295, 0.022754697295437967, 0.01923919209678258, 0.00814418271849198, 0.0341654188398804, 0.05310689351920571, 0.01089658962363111, 0.01851989408688886, 0.03815220562475068, 0.031193476170301437, 0.015151785353996923, 0.05214800140155213, 0.023705838846841028, 0.04886924894526601, 0.003612801607232541, 0.03873729619330593, 0.014128832745232751, 0.024984568623559814, 0.03958776859300477, 0.05252984359062143, 0.05145834519394806, 0.034559138784451146, 0.04586348469768252, 0.07053443443562303, 0.02792980076212968, 0.08266126657170908, 0.03450131742283702, 0.02913625298866204, 0.014563419157639146, 0.04380452446639538, 0.04006149120894926, 0.01595903337667031, 0.037617299506174665, 0.04172315222344228, 0.04917264570082937, 0.048420649088386974, 0.05245557114748018, 0.016258691404280916, 0.010677316791511007, 0.021130279371781007, 0.021688454152484025, 0.031934986024030616, 0.016644321515091827, 0.0326261417940259, 0.006914363866339305, 0.009814847044513693, 0.06269279521490846, 0.03300317656248808, 0.05117423240361469, 0.018577477961246456, 0.03482641372829676, 0.03458823436605079, 0.04245266897071685, 0.037102583197078536, 0.012574130902066827, 0.011555502257708992, 0.033196735461907725, 0.05420525172459228, 0.06061427281903369, 0.024302922521850893, 0.045831579981105666, 0.02803713652039213, 0.03792564617469907, 0.032032321872455735, 0.03670773688437683, 0.07538413455975906, 0.03839064283030374, 0.07536165469459125, 0.05675798528162496, 0.02438085396508021, 0.03920978048284139, 0.03524942263694746, 0.035570264527840276, 0.019842713372781873, 0.019182624328615408, 0.06157430487551859, 0.04026159118594868, 0.07284523293908153, 0.018850669730454683, 0.04234416104320969, 0.01613624636749072, 0.006644897678467844, 0.017956399591639638, 0.08256540314427444, 0.030012686138174365, 0.08190197231514112, 0.024119293982429162, 0.06154690563146557, 0.04200561617368034, 0.014801188006198831, 0.027557776974780217, 0.00579965890418472, 0.011905932516258742, 0.11228911139603172, 0.007255145781008261, 0.00943892083263823, 0.04227153744016375, 0.03574614080467394, 0.06740048474499158, 0.04699766955205372, 0.02380083883846445, 0.04355788037979177, 0.01879991022204714, 0.06390825499381338, 0.027203585087720836, 0.04163983490850244, 0.01074278015377266, 0.010770539021385568, 0.04287061261545334, 0.016239509219303727, 0.041163886697696786, 0.006296936439217201, 0.03700593266902225, 0.0840340107679367, 0.06087701514895473, 0.0020096432459208047, 0.04203526136864509, 0.03179463444809828, 0.012849585585562246, 0.036048648679362874, 0.028734624718448946, 0.03480922643627439, 0.10747156704642943, 0.013946843716049833, 0.014618499237777931, 0.04988331613796098, 0.028136526633586203, 0.02652723664817001, 0.044614237267524004, 0.021486125187948346, 0.04996978185538735, 0.0018573354588755006, 0.0682970534211823, 0.01516652652727706, 0.014506756394569362, 0.033569162977593284, 0.08627388200589589, 0.09145873093179294, 0.021069815116269246, 0.00796741756078388, 0.006901135402066367, 0.02499178484348314, 0.012166587502828665, 0.02985044162986534, 0.0491940670513681, 0.026800046741430248, 0.09705806297383138, 0.040241096035710404, 0.029624425007828643, 0.029700858585004295, 0.05883412262690919, 0.03281142595889313, 0.02879325353673526, 0.020778465749961988, 0.03040631448051759, 0.024785618763417006, 0.0041222393379679746, 0.03778023272752762, 0.06691130849399737, 0.07075282771672521, 0.035046971536108425, 0.03641272342896887, 0.04975356327901993, 0.04059625483517136, 0.035858468884336095, 0.0054317618820018, 0.012173669712085809, 0.03047675998615367, 0.10564506612718105, 0.0072891514116366, 0.02433468135339873, 0.06260728623185839, 0.00846610008738935, 0.03680798704070704, 0.01974712305569223, 0.02103022768694375, 0.04975676935698305, 0.016359309665858746, 0.018678798506568586, 0.055625842817659886, 0.028254225317920958, 0.046362442030970535, 0.023060550347768834, 0.04631156208259719, 0.08516865702612059, 0.037496187790696106, 0.07156061008572578, 0.015888204498748695, 0.011826146976090968, 0.07032701985112258, 0.08168146200478077, 0.04257309536582657, 0.02938430503542934, 0.014464037526132805, 0.05810184084943362, 0.010227375979801374, 0.030632650014013052, 0.0644350288701909, 0.09105178633970873, 0.0842229284878288, 0.027135982643812895, 0.1423087151987212, 0.07587225908147437, 0.023453727464324663, 0.0312618216100548, 0.041721031801509004, 0.051471990533173084, 0.04282642302236386, 0.0386743586776512, 0.034917554552001615, 0.01774960077766861, 0.0559070752268391, 0.050246305231537135, 0.01574547805025109, 0.031053514752004827, 0.012370410092574145, 0.007155573311527925, 0.010105853750636535, 0.03338344455031412, 0.013552714954130352, 0.021189255939264382, 0.0249527487238603, 0.019675590197688768, 0.049355432856827974, 0.029387816454150846, 0.00040407672141944725, 0.024500535668006966, 0.03800229349040559, 0.03510428060378347, 0.04604861619217055, 0.010503873910887964, 0.021897746582648585, 0.07576850429177284, 0.04449309501796961, 0.012185959677611078, 0.06329989406679358, 0.02628628716671041, 0.033110622582691054, 0.02551731021542634, 0.030049187929502556, 0.040525765224759064, 0.04704042404357876, 0.01782246695698372, 0.030449252176497663, 0.03132552247760551, 0.06807204442364828, 0.008302277136993195, 0.04926535054775221, 0.0592151607519814, 0.04535183536687067, 0.036477133365614076, 0.029845773308937038, 0.023807729361578822, 0.004473524974725608, 0.007127437856979668, 0.020144613958629112, 0.04004722161750708, 0.10758098760353667, 0.06995453126728535, 0.18011021321373327, 0.09426939261278935, 0.15481108932622842, 0.08287014000649963, 0.14314590527543, 0.15611246520919458, 0.14192960411310196, 0.17284260104809487, 0.14619536378553935, 0.1030463787860104, 0.11707991468054907, 0.1542940999248198, 0.11612700724175998, 0.07380192660327468, 0.14360004876341137, 0.12144087281610284, 0.135018222832254, 0.08595678902098111, 0.11877633365137236, 0.10908498082842145, 0.11488188191183976, 0.14919644274881907, 0.1130165145067232, 0.12467764770346028, 0.08855386823415756, 0.17546478605696134, 0.1819268414484603, 0.14414257822292192, 0.16545532244656766, 0.13515459480030195, 0.2453387752175331, 0.18147763769541467, 0.13699403538235597, 0.08155449453209128, 0.05548730293022735, 0.10841542282806975, 0.10651706505034651, 0.07799236888864211, 0.17307148448058537, 0.1960530448704958, 0.06762193143367767, 0.1272452242140259, 0.0769686766767076, 0.16510781752211706, 0.12517510886703218, 0.13384404512388365, 0.06414631221975599, 0.14220925553568772, 0.21254695552800382, 0.1660555409533637, 0.11557584681681224, 0.09271928614803723, 0.22884277467216763, 0.15182898220207008, 0.21527542626219137, 0.19601976951318129, 0.09004701846944434, 0.06116782847259726, 0.10132905415126256, 0.1019727803234543, 0.15444512824927056, 0.11095488084746258, 0.12855566532484122, 0.13399504630693368, 0.11028799627508436, 0.18529768128480228, 0.14514359379453318, 0.09174302353390626, 0.24243594812495367, 0.15347547456622124, 0.16345443124217646, 0.09573321656457015, 0.1058144216824855, 0.12285270062940461, 0.11087239813059568, 0.15155790746212006, 0.10766412849937167, 0.07015549976910863, 0.1335955113172531, 0.17145069502294064, 0.11952787903802735, 0.24165213161281177, 0.06183722362454448, 0.0785643399826118, 0.13201046708439076, 0.1606325398066214, 0.0782891668911491, 0.13702376878687314, 0.18108794146350451, 0.1216006949543953, 0.13291027237262043, 0.05542232980951667, 0.15869026045714105, 0.16741635650396347, 0.12284092126148087, 0.07852218260190316, 0.08605969564190932, 0.12685395378087247, 0.1718965739543949, 0.16966977130089486, 0.09198316386235611, 0.10872205280299697, 0.12414411561829702, 0.12822304745869978, 0.12505111337772437, 0.1207098870405129, 0.15211159203733715, 0.16671247141701834, 0.11440612029816423, 0.18532964028418064, 0.17796924524009228, 0.1596595070191792, 0.10792118470583643, 0.13102633346404347, 0.12459950761071273, 0.10939524096569844, 0.16972978093794414, 0.12443832840238299, 0.24541010281869344, 0.1583295240998268, 0.09324354265949555, 0.06843542028218508, 0.12582078922007764, 0.19101693082068646, 0.14877910300024919, 0.10863129195890256, 0.0917189016139933, 0.06362396239170007, 0.11396271123417787, 0.17078765774411814, 0.14951630415660994, 0.15030223769801004, 0.09637491391705615, 0.0674563485330769, 0.10758781366582428, 0.14183553201811655, 0.05895456937806947, 0.09499779316995825, 0.0604541181985821, 0.08286142083150999, 0.15797938645950385, 0.10079696734568902, 0.16076690331101418, 0.11975779384374619, 0.12558206702981675, 0.11799315496214799, 0.1338139995932579, 0.07513366692832538, 0.0998464822769165, 0.12228123843669891, 0.16213416494429111, 0.1493427620402404, 0.14171241862433298, 0.08677813530500446, 0.12761505294059003, 0.09881524475557463, 0.14868281888110296, 0.08489423710852861, 0.2474691037620817, 0.11848121163036142, 0.21866987911718233, 0.15471135824918747, 0.1403769531420299, 0.0811342845803925, 0.10249571369162627, 0.11017955959375415, 0.06937181217862026, 0.14993569308093616, 0.17011186400694506, 0.21248729872916425, 0.11856684274971485, 0.10251218173652887, 0.12919518457991735, 0.1467084583959409], [0.03505263730351414, 0.04384878191298672, 0.01378133290979479, 0.06638749981565134, 0.057430131893072806, 0.03582942758553794, 0.01765941668834005, 0.07755448309970753, 0.034435628447681665, 0.031952400625284226, 0.029563628270157745, 0.050289843431008716, 0.04527941532433033, 0.05912534985691309, 0.02539271761530212, 0.04395828728697129, 0.044696699628340344, 0.02820988305445228, 0.053286125151706595, 0.014421671495905944, 0.03689681066732321, 0.048096825036087205, 0.03717687260359526, 0.005298815667629242, 0.020535404328256845, 0.035593310969748666, 0.011159179283172956, 0.04835965218288558, 0.030874235622052635, 0.03127313618149076, 0.057637112215161324, 0.10440971848687955, 0.06962094988141741, 0.047482842446437905, 0.03354721236974001, 0.02585180423089436, 0.025584381705682193, 0.021133921408493603, 0.03396418231672474, 0.020421669984768544, 0.05067692730309708, 0.007886162144131958, 0.020398901742217795, 0.022874742014599696, 0.03724055311509541, 0.027443932369351387, 0.01803220891659813, 0.02273957444620984, 0.03997190083776202, 0.00804439905498709, 0.049923916280801804, 0.0729648315214685, 0.1113181481403964, 0.015963959540905695, 0.06751527251409632, 0.047262895320143015, 0.08002502231725625, 0.041449397270168574, 0.038408165997160335, 0.04055625519582203, 0.030589695354657512, 0.03552793751337698, 0.047378639823624065, 0.03592695342376828, 0.021268444368615746, 0.03293246303551963, 0.009129541942716708, 0.022891174436413815, 0.03703584927799446, 0.07333784936262028, 0.07974738614367587, 0.054813785678041835, 0.025991981084059392, 0.01590453683664756, 0.023727702941479425, 0.09681199903466872, 0.05716393581990685, 0.02523636957630515, 0.03840282592656357, 0.023950815433636308, 0.03516369991536651, 0.08461675699800253, 0.04582437393920762, 0.022836319969168732, 0.07708752208522388, 0.01926878809795848, 0.04845732729882002, 0.022303284910906638, 0.006602184747212699, 0.018065667478367686, 0.015754241330016936, 0.045262251781033616, 0.027608604336689626, 0.06762603657054049, 0.02563989265555782, 0.037253625092229674, 0.027419274406773702, 0.013033080114317792, 0.09510753942387444, 0.04491220235026308, 0.02728309582120606, 0.08733848987945489, 0.02404867545036333, 0.04898379922711423, 0.042067722483937225, 0.025953808400247778, 0.025469621077978184, 0.048317175890718184, 0.04100530627848847, 0.008733482748669173, 0.021158669276961257, 0.013324218286600496, 0.030119803068893294, 0.014102939000752355, 0.10759295017591544, 0.02834691489780588, 0.0019080186320934445, 0.023513397833864604, 0.05236829797338162, 0.062150170760495324, 0.009863606570953769, 0.016481529089755247, 0.006841582927985915, 0.03313718722867114, 0.0348766456757273, 0.011953217925370803, 0.007125549833290279, 0.018798850011080503, 0.035340570246002505, 0.04361525730096868, 0.06576684383409363, 0.01657697861082852, 0.0261351808107325, 0.10823263227939606, 0.05109042315078633, 0.016566834512299726, 0.038551051901387315, 0.03098562393071396, 0.043501531439168115, 0.05146723400269236, 0.009077521207343255, 0.018744484089048843, 0.03280474238895944, 0.011425764665805867, 0.029980235200907503, 0.011588087205642035, 0.05220718661855374, 0.00914228058952306, 0.03093851663704429, 0.040072819351085594, 0.028064501837694218, 0.08648998862398521, 0.021399018254929354, 0.04543936638427632, 0.04021646182185837, 0.020014476031064987, 0.02365233805695815, 0.04126115808529513, 0.07241838691490037, 0.00905811256130359, 0.05021707394293376, 0.038796735860939534, 0.049451123257832866, 0.08253940846771002, 0.00581059095150392, 0.01824745549155133, 0.03632327555013554, 0.036200331790106635, 0.0463715988610472, 0.008457170566543937, 0.05656382927138891, 0.023168797039293816, 0.09092367214283772, 0.05914985854178667, 0.015376736676054341, 0.06459937005170754, 0.02607178019492754, 0.020036470743694475, 0.024184772611728737, 0.061125087551772594, 0.030350287844027792, 0.011286687039371048, 0.05611393341262426, 0.023724807293287346, 0.07087674856718097, 0.026852855425594107, 0.04208456711577518, 0.08195338491350412, 0.016285133913957646, 0.036973176390997, 0.03964404968012657, 0.06390516765947853, 0.043739361355879476, 0.007072338693043483, 0.03459321142041257, 0.035972978454083204, 0.041199187482041974, 0.010120840892860932, 0.03759194943787796, 0.05588048004678317, 0.020932937639632394, 0.1058217091485858, 0.026636270440316627, 0.038371572603604624, 0.05941269586661032, 0.023006561012672525, 0.04792116249778441, 0.028196202092138783, 0.05378209014556237, 0.04267281287216714, 0.010395151396681155, 0.06098154346857752, 0.04689187576462116, 0.07547591320638146, 0.03338030293317778, 0.003932470056627477, 0.08834793964134795, 0.01677017449401319, 0.059943011695785184, 0.006385387295657503, 0.02798548134575997, 0.030071152108056203, 0.021123242963637625, 0.04720199001686914, 0.03317038794713361, 0.02245400450192392, 0.005190121567076338, 0.01283881044946611, 0.061844226105936935, 0.01747959981938558, 0.016669664798038344, 0.027591595160109655, 0.032485322028930695, 0.04272175221038716, 0.05600705396916185, 0.015896521641739776, 0.048613064656300206, 0.012630953969034766, 0.01358100731990167, 0.015694218122267296, 0.02394079007873578, 0.03655501900772963, 0.020561052951961756, 0.05472980679145881, 0.030998750190649713, 0.05718166593994413, 0.041511191454316886, 0.03331063435013805, 0.054085385120872936, 0.06725449115037918, 0.07466920292271034, 0.11694513048444476, 0.04612007271498442, 0.009844454920052417, 0.04021100640030844, 0.05542283192543047, 0.020648144617942826, 0.02262935321778059, 0.03325710132984178, 0.030699539996151413, 0.10011978261172771, 0.05763830643679414, 0.0783764197091971, 0.01925508338691933, 0.006765364361594298, 0.01440038245969585, 0.01682152772056205, 0.025578269801501716, 0.02715808422570782, 0.04810431606269308, 0.0047131364699453115, 0.03821754515437143, 0.010518148591342782, 0.01813077800241964, 0.013073022926359304, 0.010276050689364118, 0.012160004864979004, 0.01344252934878958, 0.05625012217621718, 0.061192846058734825, 0.024792259924912026, 0.03670641374109047, 0.04952923281650458, 0.021265865935544883, 0.020477367531774298, 0.04520952621740954, 0.04964619189766901, 0.028433311065392833, 0.03795306577480265, 0.031747869814613035, 0.02659057958849839, 0.08764925891799585, 0.018434220559096763, 0.03186904938359346, 0.03940213158992784, 0.01108873462570565, 0.052230361982115676, 0.072382024223251, 0.015206069851826345, 0.03849325089582375, 0.061997086474938054, 0.03765901244644608, 0.05262563916455422, 0.019044695122699653, 0.024633016237722974, 0.04399770338620458, 0.04072493900145803, 0.01993131817185453, 0.046308807230421474, 0.05594717664644122, 0.06126397688473974, 0.037083892949989865, 0.011495451060389834, 0.002149806316343269, 0.022275524346956184, 0.008135727323990847, 0.042892977129668, 0.03334146019603525, 0.1261581839727504, 0.028835919818707874, 0.009099867061844893, 0.005823553090782038, 0.03474730333047254, 0.025648338720202446, 0.02934457341741238, 0.031122321595570872, 0.0033191045097607586, 0.0820090179996831, 0.02088088552201433, 0.01883159950375557, 0.03531512857547828, 0.012283279410829502, 0.01837027202626424, 0.019351621956697533, 0.038267502295119424, 0.009104029026015528, 0.03787259491426604, 0.02070414920204452, 0.04547816501664264, 0.06920887556459222, 0.019554958545735905, 0.028610306925007274, 0.04805337843884315, 0.012451854650862515, 0.03450004177700196, 0.019041641715115736, 0.028708836995065212, 0.029948673144515072, 0.04633434050317321, 0.02865319373086095, 0.0550840427832944, 0.030198533487107073, 0.10258560601089682, 0.10148412654442446, 0.08159863323505435, 0.13256784289010934, 0.16743197638009275, 0.055234870939914665, 0.13009758187191828, 0.17165209778717586, 0.132653555433665, 0.0793340972491673, 0.22226113426898206, 0.17760252420391354, 0.12502946811062948, 0.1448574284357684, 0.10584788024425507, 0.17900159555886472, 0.1362200304865837, 0.1496929268219641, 0.1268439928867987, 0.13227766060403415, 0.08794271174286093, 0.18580346128770284, 0.10708696661250931, 0.14873704739979335, 0.07471845099436385, 0.1713007523545197, 0.07616313347326857, 0.1675027340118374, 0.1326298474201134, 0.10139426136655466, 0.160014950803348, 0.12369863023715359, 0.1559198834002018, 0.19243844811405453, 0.1143493540585041, 0.11668001328195844, 0.15807769261300564, 0.1109857949029122, 0.18929332973701612, 0.05713564090962921, 0.1221539316965001, 0.13261114699499948, 0.11810330833707537, 0.09547960731600012, 0.0654623783858759, 0.12083692236670426, 0.14551525456564768, 0.12227875499853066, 0.18515406256275518, 0.08901569273855005, 0.2506449462047645, 0.1809035156454359, 0.17512616994125502, 0.09809926817459719, 0.15115217066236905, 0.20297611052436487, 0.12372316606342793, 0.16159485174076899, 0.17593210669500486, 0.0909031532438738, 0.10345003926860434, 0.0861637761284198, 0.07013375950711113, 0.16039533753480228, 0.08274435318474259, 0.12012296782008239, 0.07400278653949499, 0.21094065957835742, 0.1453117754842554, 0.16400931003902638, 0.16863363475671836, 0.1165341418236494, 0.09842883263315473, 0.11026681241180215, 0.15398438940090792, 0.22895899415016174, 0.0922440266502755, 0.07533371940787349, 0.1285251991025039, 0.2239668627402612, 0.12575026229023933, 0.15633057350558893, 0.10157336068472692, 0.14839782060257026, 0.2482535716678415, 0.182831450764622, 0.18019996982600006, 0.11536859508071627, 0.05350624530443123, 0.07820711165134396, 0.11523621289857797, 0.12220521537320954, 0.11256310383656196, 0.12239091683711324, 0.0880800811573863, 0.15842690744570323, 0.1066446364192026, 0.09298726676830224, 0.16037591786256858, 0.150088797722544, 0.10035988222807646, 0.13592736476234027, 0.14119800765599522, 0.09566578375441687, 0.09708990662225656, 0.1058659360611013, 0.10648826123880488, 0.1210954984916108, 0.18142020649143628, 0.08725192238177572, 0.1608142243432147, 0.08828700041132313, 0.15730228993509496, 0.14575431602341787, 0.2882484612720353, 0.10353636927902699, 0.1057398235425353, 0.06599581547613655, 0.12586364549185547, 0.11844676919281483, 0.1894550382026604, 0.1543109140225819, 0.056880430318415165, 0.07047366483935288, 0.17573488370648452, 0.14863363866295132, 0.10627554051045861, 0.111119032039174, 0.14761337983821118, 0.12703069858253002, 0.08568992119814668, 0.09173122380993196, 0.14409672282636166, 0.186856031950031, 0.22448056803217956, 0.0648256546950766, 0.0838045845074313, 0.13703610455351217, 0.11077022432748761, 0.1020671713298985, 0.08919420851660625, 0.21009679271706513, 0.1920969821512699, 0.09560724653835807, 0.08342227752187423, 0.11310785889093365, 0.12907812371850014, 0.11947344695883137, 0.08002117502370051, 0.10542895272374153, 0.13240105898252555, 0.19452586610402378, 0.06805070449731179, 0.12385575180607182, 0.15152185011122907, 0.09245739877223969, 0.09074371108519179, 0.15874946942286833, 0.09832527461860861, 0.07649457747382776, 0.14288329865251267, 0.16726448679608957, 0.14491404539772443, 0.2706226727792195, 0.16045390867761203, 0.10471870976367167, 0.17440665140748024, 0.10003687241779906, 0.1528683892850365, 0.11477297704134669, 0.08708182722330093, 0.09400048918489899, 0.170772879251412, 0.10232631063887052, 0.13005015227411473, 0.06910345836409501], [0.05669090870235648, 0.06358033937535115, 0.10928382551563637, 0.05630610131525567, 0.028239596102918898, 0.028641187053705965, 0.038924246161643944, 0.004786667189494307, 0.027747359658990587, 0.01981282899422305, 0.006237597703667623, 0.01526038149105651, 0.07474971110267298, 0.020422679305608784, 0.036501133149223666, 0.00301089884929492, 0.031007333658635616, 0.014619751134887338, 0.0929149417206645, 0.05076178149985416, 0.02910827359716807, 0.023153155110776424, 0.02783018333970436, 0.02007191571673112, 0.006427021356232996, 0.023926401743665338, 0.04911731117005859, 0.0625719820548381, 0.0437104320153594, 0.03086775221994945, 0.03898078169939773, 0.0429888134157019, 0.06833855262292282, 0.006889347976539284, 0.05173083807208708, 0.0239547848634954, 0.050943954581660886, 0.03348222907100405, 0.006180980317627213, 0.025820138697911586, 0.009117773600987025, 0.016837644623592496, 0.034379245580307076, 0.019557877942653637, 0.06161553944860186, 0.02061066573618778, 0.021906430134549737, 0.026592652512980357, 0.04846324412418263, 0.013788394763001373, 0.03583958186209202, 0.04541751416400075, 0.009849837399087846, 0.021793774661741087, 0.027734274111155952, 0.011002113693393767, 0.033689284031944614, 0.041025061825556416, 0.03691562644339033, 0.015016480382265789, 0.014174309010351343, 0.01915771361174328, 0.042344113545758386, 0.14215843326279096, 0.03943457913451961, 0.0067953390701274785, 0.029045003599354198, 0.03157928439655474, 0.09003468270280532, 0.06327551430357353, 0.043461341810013564, 0.0295157067344657, 0.015611599698396665, 0.022213234832244258, 0.029004586660968404, 0.024155006976798177, 0.03929342010191508, 0.08383007706808192, 0.030560654055859362, 0.010691333628658737, 0.01538733030403299, 0.027586268660213267, 0.02469083420666201, 0.039831138748143396, 0.08513981928782803, 0.03132235711174352, 0.027333904523402452, 0.020709502843341658, 0.0133731516876391, 0.013203764750090028, 0.012154110940173268, 0.04836104317967381, 0.07349988352507353, 0.04288753867149353, 0.03789891528763941, 0.03737201248960836, 0.06455664948693343, 0.05449294378714902, 0.03345504017280681, 0.015416961928297366, 0.04168437055445143, 0.012202387010412557, 0.01996718892561538, 0.018302023277751038, 0.030643146950751543, 0.013441023001048182, 0.01839959152442004, 0.03175726752462132, 0.06319208842303072, 0.011454614278461252, 0.050539812339203696, 0.0311864160134324, 0.0504458318464458, 0.016204975179529617, 0.02747710594641311, 0.02745418842615826, 0.05067979750622596, 0.013194856433463948, 0.018319212266110947, 0.01980110560543835, 0.06736378278583288, 0.029280994686165025, 0.03422373213938304, 0.022827823014397706, 0.04033659305423498, 0.031933896975325685, 0.020135747202272927, 0.09782030207238027, 0.05950505126799856, 0.027193600444921424, 0.011473469918460717, 0.03328173215101872, 0.017332761448674967, 0.06013608883534159, 0.056555961657847674, 0.029490485587822537, 0.027146377800298587, 0.023040338485900844, 0.01911977332617555, 0.01086266541720501, 0.05042428496692862, 0.060736022357429774, 0.04209575615823269, 0.0612151970022491, 0.07562626299581357, 0.03183178424036928, 0.025961652265063355, 0.03245240629517606, 0.010996169726630407, 0.04127848108432122, 0.030117940490267107, 0.03285922535828181, 0.08230877441487142, 0.042193176823535135, 0.031736965756863356, 0.02683939498716167, 0.06663169099816255, 0.03418415319174528, 0.07516828578497682, 0.028625217732042074, 0.051520929871393104, 0.07137200449194227, 0.09998546660478626, 0.0263570532801428, 0.051646238325962, 0.015216809364834001, 0.04822903758447085, 0.09030938760510512, 0.023018118160377656, 0.03360991579081331, 0.013073988990592105, 0.054268362266676765, 0.036040625002767356, 0.028416653030685017, 0.04450142403532352, 0.04997982417366334, 0.03470161756766694, 0.026087878438244973, 0.019297622443575944, 0.026818265406680957, 0.04319426024864827, 0.018747311883739064, 0.04937602300196886, 0.008126879227347672, 0.014712230368916477, 0.021641121245920658, 0.016497372882440686, 0.059506577971790514, 0.05550810002854892, 0.03463136205183608, 0.011950961796433797, 0.018706730400611247, 0.012672106269747019, 0.039062518027744124, 0.08747457007744483, 0.06500469973044735, 0.017280113916578035, 0.028134628431871533, 0.018865573752139295, 0.04692156845703721, 0.03513232106342912, 0.0374775653971093, 0.06918139489633696, 0.06417344683515173, 0.04930264622505222, 0.01947067431839449, 0.006718642560632101, 0.009025032282806933, 0.04702226644647973, 0.003964807339278715, 0.06710595304944686, 0.023708240860807042, 0.02816995805395501, 0.04314088329140629, 0.04776315204799175, 0.009833404129104955, 0.010658070145707046, 0.02551668257053409, 0.03344644313412053, 0.037307690762515576, 0.05127994476684502, 0.07112491596490145, 0.049729210657200644, 0.013280452777897673, 0.012022182528328682, 0.00839583863437708, 0.025195927192856158, 0.033290644708488665, 0.03489666585145252, 0.07157317655427115, 0.046542562544345856, 0.02682158344292215, 0.022432101391521946, 0.06689494901469775, 0.031092157321316854, 0.047884005920163224, 0.006697130880119013, 0.03692134988627263, 0.023815681791997383, 0.09914094156452588, 0.03540662902274302, 0.030206553771027496, 0.04736503180382507, 0.025530136223616343, 0.03269556610445891, 0.02640406897158495, 0.014922072412446141, 0.044625911462519846, 0.015988469922116826, 0.054560498733605654, 0.040205591690859625, 0.05282968821536217, 0.028606110185916935, 0.05222687431211982, 0.015011057191129242, 0.03220895810851029, 0.050248177988188605, 0.050030463242105076, 0.07778661671493735, 0.032204184614654095, 0.02240681748038956, 0.04337761737406254, 0.012296555796638131, 0.05577856408698218, 0.028555935913962976, 0.054261461565537114, 0.016292648689289178, 0.022765954191397344, 0.03468134294130972, 0.012490638864359685, 0.06727908804480519, 0.09627143054136209, 0.08053660379456622, 0.04767277457618287, 0.04175439876105104, 0.024815294492457594, 0.025196680366726856, 0.021346735435404947, 0.01133083676852818, 0.04106754829574909, 0.04252774208518011, 0.03860904968210629, 0.015615837149588125, 0.07643393679921116, 0.04219380786110248, 0.04321495217404195, 0.032581969164311886, 0.007893078112309533, 0.06597782072744199, 0.02760751698432224, 0.023278080193059783, 0.03448047282706414, 0.013624270712690694, 0.04117659905127116, 0.056318450652595074, 0.0492130422831646, 0.0356291410114084, 0.08733285125344992, 0.029085542674043348, 0.0398752638804061, 0.0219229914780174, 0.049882834378097735, 0.024599567853978703, 0.041793862357735634, 0.051772449232105694, 0.06440566865993397, 0.02992826959650431, 0.02516931844209986, 0.04263109314654555, 0.014259484663073505, 0.0510009277745017, 0.024155470076948404, 0.04837316181510687, 0.01849271367037935, 0.021815503049375753, 0.020440273718642335, 0.05067906468840582, 0.03521901069741164, 0.02708557597361505, 0.061978806741535664, 0.0516230934964759, 0.04609009503786053, 0.032542101839291196, 0.02549133589491248, 0.010575929240855788, 0.03709987923502922, 0.06309732422232628, 0.030971744496907507, 0.0348821689507791, 0.021287139704717056, 0.009451656086769487, 0.03098204805116568, 0.046852846430348496, 0.03646428530503597, 0.01879416303043919, 0.046786173579416106, 0.03745521106091993, 0.04635339715917196, 0.01362603490373918, 0.04583689630297678, 0.03511951371495213, 0.019098480897290365, 0.006165274776451821, 0.05724244232156447, 0.031657665369233916, 0.06751996797642537, 0.047518194120909484, 0.0394869993573853, 0.04596558046926345, 0.04265796313328402, 0.028395654068195393, 0.022450242025245513, 0.08193870141570057, 0.14620841879929813, 0.19877528665321215, 0.2107967965837036, 0.07325617410242558, 0.08950357298765864, 0.11251597279416663, 0.1258132303399699, 0.08822273635970694, 0.12404434382915497, 0.10190509645534412, 0.10335531578000103, 0.16232089778142317, 0.10591937069381986, 0.07924786223364727, 0.06616766125495945, 0.1078308852655547, 0.17089999600180558, 0.19879743403622083, 0.0934688773538385, 0.08817641277398382, 0.05322369314464075, 0.08860577616308417, 0.15739520852054867, 0.10326874149697167, 0.08606811626149075, 0.14320556207426957, 0.20058344677090645, 0.12318229222936289, 0.10055467606123004, 0.10713686607778072, 0.07158215357256786, 0.12981681765190192, 0.1301255782267877, 0.12701480729239328, 0.10933779619101967, 0.14731520440961632, 0.14665978029370308, 0.0935731546155044, 0.12657006829977036, 0.0724704305508307, 0.08825385397566216, 0.1078296299757702, 0.16568390732364996, 0.11852466501295567, 0.08156849949487618, 0.14030535412686213, 0.1766238867172173, 0.18815477511712483, 0.12977086726043904, 0.09719712872590337, 0.10876623221806117, 0.06772325028266225, 0.1235121281019279, 0.11829504876264504, 0.15973741641002043, 0.13590467455131666, 0.19308164502893174, 0.11027112789452076, 0.10301649610378913, 0.11965982695775372, 0.05670248790244971, 0.10582138345177684, 0.16658278980425426, 0.10287756605872087, 0.12595030798443727, 0.15574349143675395, 0.08962665245469127, 0.24113541362541063, 0.10237242387873785, 0.0803425292085324, 0.15259644602026257, 0.15050704670803888, 0.16320426895150117, 0.09584266426307814, 0.07944724296352693, 0.12350196364734854, 0.15654623907591614, 0.1245157899601119, 0.04815090088439839, 0.12788449919649533, 0.19241628716034548, 0.16175377821283682, 0.1817097645252943, 0.18422797082790307, 0.1037099181807467, 0.10458069574087858, 0.10429351936493601, 0.14229760079511575, 0.18138684970991953, 0.11723282933235168, 0.1521122298602547, 0.10829203123492853, 0.07808900584599801, 0.09573402402124234, 0.16624109313956328, 0.15446194234703267, 0.13260764575430325, 0.09232399200222322, 0.11102373179580484, 0.12213014225874629, 0.11615025385149888, 0.04820664253618036, 0.16750095625008854, 0.1823213417083025, 0.09838831730719123, 0.10783988263990198, 0.1022087883736406, 0.15367144905030727, 0.12681119250399725, 0.17147182460342134, 0.11933754996529647, 0.11707329217876707, 0.0820145887721862, 0.07327477274728672, 0.061307036717023165, 0.175394476258329, 0.12233538553118706, 0.10724739264696836, 0.1320251641528947, 0.21118703564362867, 0.1502657596554075, 0.12751819885202817, 0.11697764588253838, 0.12494353843586785, 0.14389192738703319, 0.07457212491759233, 0.22295022729252065, 0.15607404655643872, 0.16843035923583166, 0.07400037774017879, 0.09956125329647746, 0.0849912336894444, 0.2562374861112663, 0.11017211606459958, 0.14571080835802214, 0.15317360790712492, 0.1821882945618459, 0.11181790275233132, 0.08009890799543687, 0.14920162675636156, 0.17623353909168923, 0.18695592587547644, 0.13268546015024185, 0.19127805823726313, 0.14808857148247107, 0.1324868800916842, 0.1599210144153663, 0.13729225152305194, 0.1621105247842414, 0.1426435179476227, 0.183634591954095, 0.21478276912655148, 0.17866285730685505, 0.10874602544520583, 0.10679970202701432, 0.1387711457375969, 0.10149869469127484, 0.17915421165525913, 0.11045077004070793, 0.10401745060724871, 0.1089956924053175, 0.16458206144826754, 0.11814463111971106, 0.17860752956143447, 0.10948733852377959, 0.13945048142756733, 0.12175517023674079, 0.15156991753195012, 0.12363188953271934, 0.12476440519094467, 0.11637332902422973, 0.06937520485371351, 0.11656493374279567, 0.16970638505050115, 0.1426817194691726], [0.060318356912050924, 0.004160741959432406, 0.028658896817692688, 0.029712821157383065, 0.034929917460041385, 0.015425340139440127, 0.021608741554830755, 0.00835378557842757, 0.023589744897825376, 0.0082210208721725, 0.08038193173706532, 0.037576278671622276, 0.0759872096989836, 0.028114740570474948, 0.01894519983657769, 0.012439166894182563, 0.032049583803330145, 0.046023293265274594, 0.04874190488564117, 0.05804107803851366, 0.07987114414572716, 0.017565599043986628, 0.015450990459482585, 0.008001225568088037, 0.05342338260795389, 0.034331466536968946, 0.048544251027383974, 0.07075558935425111, 0.08731485650475536, 0.10129936824419669, 0.029681751038879156, 0.03140909085050225, 0.04469073869820152, 0.007406432796934885, 0.010354837086716933, 0.02342909325047263, 0.07932845183781215, 0.03515836663011994, 0.0012507760423302117, 0.06485211756080389, 0.028079168372122303, 0.028176511005897607, 0.052494997424738746, 0.04389514281813588, 0.047817970892148356, 0.04688074779031532, 0.059221837536564896, 0.03299572964065841, 0.049884968370731385, 0.027842010205079402, 0.029506743286869357, 0.021151154501629726, 0.027217713883146644, 0.030057642475834916, 0.0030729867118809906, 0.03166251350194216, 0.035760386647390466, 0.023698376657973443, 0.05972452341978039, 0.022458087586398636, 0.03772764287090727, 0.03564307472801634, 0.017457671263920407, 0.02530150724175785, 0.038109909144363234, 0.0059364621660539085, 0.0227754129695573, 0.01613686213802014, 0.06850563508591481, 0.018128532051507915, 0.021332209696993232, 0.019745808394093598, 0.036291682959667275, 0.021214471996894906, 0.04057115243215646, 0.06644671556672879, 0.03343268244394234, 0.05946882428335292, 0.014946441997640898, 0.02587389393842646, 0.025009533623233438, 0.04677463509142399, 0.07427505550107785, 0.027343738192160214, 0.11813499592244625, 0.02103867375158838, 0.03243719693273306, 0.024012682560299124, 0.054149201339376826, 0.07825625115739447, 0.0990441417587655, 0.04389750072732568, 0.059957925895495076, 0.04533363027232034, 0.0007509408013512646, 0.016900371793391447, 0.09164234929318939, 0.013768264325335622, 0.06115599482187203, 0.04830117942765355, 0.015195952894698297, 0.04196664112220917, 0.03804368751921824, 0.03395809925028256, 0.06047715446246522, 0.030291553852813582, 0.013457820135434824, 0.06444595328399114, 0.0036949353026492254, 0.038659481797367334, 0.015664072507726293, 0.07120408743087735, 0.030669884623161385, 0.020317262105111564, 0.05565337098336645, 0.06077098048159054, 0.023273145547136664, 0.05274768725835851, 0.024550606463370577, 0.03425480565056205, 0.028238476520138125, 0.04489540182320135, 0.05748637566076858, 0.029772298144442693, 0.055022187530994415, 0.045128078266446076, 0.02928480805296983, 0.04130095416413886, 0.05518732599115797, 0.03989693628890174, 0.027464033969278847, 0.08552414830774069, 0.06294127473873751, 0.014834325960172074, 0.0263780149232064, 0.02031851569855852, 0.010342677739182753, 0.03728216088243893, 0.09103410371712276, 0.024286142350839715, 0.029921104266707386, 0.04512412240728736, 0.05793506372720003, 0.0020130700598071727, 0.03946880444086023, 0.03971010506419199, 0.014111208646292133, 0.04622613113107426, 0.012089169201707202, 0.029832490985946994, 0.03525312743814928, 0.061540561329041205, 0.05901114562792437, 0.04111470647954515, 0.02590544581679361, 0.03328513161146215, 0.010371869163853782, 0.029567825009248087, 0.008704440601702248, 0.01491543633996376, 0.025755157095513175, 0.0696483626961708, 0.03125115843223674, 0.03129255246104939, 0.05963934013353927, 0.04120460897684097, 0.028114017930680087, 0.07385366489844662, 0.03207090337361608, 0.007306536326983145, 0.011299865037601973, 0.007434348575770855, 0.013096485819135393, 0.01152398091341768, 0.03911467022927744, 0.012881631946324237, 0.042000618763267994, 0.023117045173421502, 0.03236530954018235, 0.03395558188536337, 0.028698801462139403, 0.07719130401632615, 0.050614210311323404, 0.05087851666446243, 0.024568299263981835, 0.01794010796584189, 0.020806489246232168, 0.0331997617280909, 0.07314582395234279, 0.016096139858875955, 0.18498453737369605, 0.03129339384447251, 0.0508113077708653, 0.026630385845367397, 0.02107660216279328, 0.021348871124376143, 0.023280241327094178, 0.07892533418323312, 0.05599248921498656, 0.0318459316955081, 0.004609025449358991, 0.05744209446545158, 0.030391532595136335, 0.062007691977279525, 0.043376433330454996, 0.022573966100545864, 0.025688811637727276, 0.03639132921983089, 0.03168623508619411, 0.030558465780424218, 0.0679298641958407, 0.02117261995694467, 0.03443561826965638, 0.034654354210942984, 0.04978724915002074, 0.03752967010119131, 0.005211363105835127, 0.04433136619627476, 0.08059542599533286, 0.05680888219337378, 0.042060479122613154, 0.009632394915180547, 0.00859185298239546, 0.09403721150010824, 0.012534377231661762, 0.0646768044680357, 0.029663186320768933, 0.031224624320332493, 0.04883526112618191, 0.04185312221358929, 0.06360309743987662, 0.055289065531854115, 0.02631834116099136, 0.004971006070263684, 0.0149206118658185, 0.014198616679225649, 0.03852202417328954, 0.10061013272830419, 0.016404193061004792, 0.054719045226063044, 0.030170683017266647, 0.003468989714747295, 0.03920696795518909, 0.016469269658305814, 0.018545043987355063, 0.03865030800391521, 0.028629590890237262, 0.028830969905746833, 0.06929702404886484, 0.04663764565650906, 0.0029904895761449423, 0.015942338022536466, 0.02396261685394815, 0.04709769918450287, 0.008023437411923493, 0.05255389765703252, 0.015108240369175161, 0.013380249163934162, 0.05544279103300401, 0.028870114590972662, 0.03491181753841894, 0.023948355744193708, 0.02383093356287905, 0.02996602328494191, 0.048689667867230516, 0.028051445127597878, 0.02520343179016241, 0.0282396944904966, 0.04288717904793365, 0.01366356891646449, 0.02224680026327925, 0.07190861712609019, 0.06970941727714879, 0.03776097251102328, 0.0416950778370457, 0.052206918597221375, 0.04761215425761683, 0.04748973975490246, 0.014120260303440903, 0.023272962342681627, 0.031124625221959183, 0.041825909566666396, 0.06039499744240727, 0.06885953181024108, 0.07439409089939934, 0.06275606182004724, 0.058153965909566195, 0.030703784232693057, 0.0520235139743558, 0.006969835376366973, 0.01988134576406862, 0.03635717176699212, 0.07538576982915401, 0.022793197372396077, 0.031535535851227384, 0.03730296476611069, 0.05553158412554434, 0.036880505470825095, 0.04344588817496385, 0.037942660440291674, 0.032125372772238085, 0.012846325224797641, 0.036291028173374276, 0.03811878438240715, 0.05964396095701626, 0.026049497104915123, 0.014546888348247324, 0.058602687902748585, 0.05792806803115776, 0.06517966677035604, 0.02220698043570987, 0.022870290824877362, 0.033570574330432076, 0.02367398502039058, 0.030911361665597985, 0.026439966866746545, 0.0277471781508731, 0.05524865198614342, 0.047828220163605044, 0.02585862181149423, 0.017381254650120224, 0.05036481815789427, 0.018154240047026957, 0.03326454146632126, 0.03916422024901424, 0.07400216907262802, 0.08792655582406692, 0.020745444843279462, 0.006565817390635077, 0.01962840317615441, 0.019828031571315866, 0.07932404814554112, 0.008739355469255574, 0.11916444211133889, 0.02909052651375532, 0.03268228378146887, 0.014760939005230154, 0.013686281179876199, 0.00972104212269187, 0.08330619375088386, 0.022010944883472154, 0.019208110103915845, 0.03351313294842839, 0.04813516226464084, 0.04431971235732947, 0.0389193980289357, 0.03228572077516999, 0.02781455158921225, 0.03986200869881681, 0.012417804067289191, 0.042572786632393084, 0.05477357230016163, 0.20081272375370773, 0.10908883490732738, 0.1301355662622622, 0.07605175873530762, 0.08002004187021937, 0.13406327978840896, 0.18139581994286605, 0.13505740144423076, 0.14224793203175068, 0.09886171761900187, 0.15549521547343048, 0.058448986150324345, 0.14050801896623202, 0.16040293712701115, 0.18350941581385477, 0.13308814354240894, 0.0864484758515443, 0.11056456714868546, 0.0889747499355248, 0.11358649749308825, 0.15054474611367497, 0.17405892935182365, 0.13162777333387307, 0.10514452441462449, 0.13728766462632588, 0.135654498689941, 0.17129334275211605, 0.17842123098671436, 0.11928466494594302, 0.10905028733291797, 0.09328149990843874, 0.10709827779127018, 0.13134547562471457, 0.1110146122851542, 0.14991829544305801, 0.10924765281379223, 0.19474894127675466, 0.09101552542831216, 0.1268003766558, 0.11240083218685218, 0.08966310335589306, 0.15886281191238336, 0.1274367067962885, 0.192184784582683, 0.132198516279459, 0.13978478206055506, 0.12096956239214965, 0.13974222434418543, 0.095294618313866, 0.17575343485389436, 0.09012476501188108, 0.19821446388959885, 0.12414788827300072, 0.09063602757773229, 0.1969866683440549, 0.1369626870644944, 0.1679268998226949, 0.11087115641151156, 0.14666028240961687, 0.06202378682792187, 0.12440536517117705, 0.19257970553423676, 0.1507779314581837, 0.11082414072006941, 0.19962034773613724, 0.07678236453128712, 0.14492803678980895, 0.06613893208226987, 0.15552200403596672, 0.09170866930591208, 0.0748779202944466, 0.07998505660465785, 0.1907241836722408, 0.11859200282820634, 0.1383169615375144, 0.17316523087876184, 0.09072100730346781, 0.09767297176378113, 0.06209003220179251, 0.10090874241931097, 0.06437725839870316, 0.06676268218351261, 0.14838137291371822, 0.09972984210721084, 0.1979523186704942, 0.15628960356116295, 0.07217680130686079, 0.14717568403908185, 0.13644185715488025, 0.2067747666899647, 0.22880312108567782, 0.14053011206643923, 0.11821289174258709, 0.08719549540962492, 0.09568852824824196, 0.11537281556853227, 0.18664373191339628, 0.06195621831076486, 0.12042030186525413, 0.09112305287271738, 0.1491904037871531, 0.13409636515591825, 0.16420698086065905, 0.10112012643367052, 0.16005957126617432, 0.09489487976367984, 0.14851085096597672, 0.18726186374468462, 0.10409499358917985, 0.11033372274999108, 0.1317917073943785, 0.18202693893441133, 0.1272736955434084, 0.12567988463810512, 0.08982657601258584, 0.17640689121825354, 0.13603039351957186, 0.09979707135685853, 0.11407654226890632, 0.10922585148364305, 0.09492604487708636, 0.18684636961136544, 0.13473405236644403, 0.1067395702536617, 0.16411821490951947, 0.16604655714971678, 0.10137004445173911, 0.18140128893511637, 0.19583021397037165, 0.12849219515919685, 0.1767567303031683, 0.23881892221314566, 0.11543977340417248, 0.13695938938430377, 0.11339335250002996, 0.1345545527126108, 0.1477852120463337, 0.16588936772729668, 0.08998411148786545, 0.08672860224864312, 0.06021119587655578, 0.1040978841483593, 0.16694124628390583, 0.09036801303071634, 0.13135352305003575, 0.16724636991109165, 0.09234936242657048, 0.16392200972352708, 0.132371312007308, 0.15722557476588658, 0.21698731583143982, 0.1268102154135704, 0.1591322310268879, 0.09289810048150164, 0.10924196669033595, 0.13245277692164692, 0.12372178185198988, 0.16389235774321215, 0.0542286340413349, 0.10654208942183427, 0.13918164585317883, 0.10818566408540521, 0.13155306662831986, 0.15408720102693352, 0.07118925465536968, 0.0932922207617334, 0.1004015782049724, 0.14433841700000422, 0.11749808224184172, 0.08776633335011345, 0.09704745068613972, 0.13605936696486814, 0.10947636661252805, 0.08391764879758869, 0.21176289474325521, 0.13954278933150427], [0.014289562424112643, 0.03294694297281759, 0.034045925430421314, 0.024914928878258382, 0.014412745367735624, 0.08984623317207609, 0.06391939653881959, 0.06588338900889669, 0.026189237999330674, 0.05956503376364708, 0.01711155055090785, 0.01663789409212768, 0.0411629265706454, 0.03894866324429001, 0.07577513357890503, 0.04293605392532689, 0.007597524373392973, 0.03790234188948359, 0.0142763055461858, 0.023856132657134106, 0.015341235723878657, 0.03298257963199701, 0.05807864173714604, 0.03277309212301459, 0.021834831119381955, 0.00850598607212305, 0.02011156251787075, 0.015079344955406018, 0.015919963330296532, 0.06126545609108039, 0.05660076193245394, 0.0478329597307103, 0.020031822778816735, 0.048766949613179476, 0.009182175055944493, 0.05045790298442755, 0.06094963875200067, 0.08769208126302276, 0.03795632952824235, 0.03336758040157812, 0.02606003305741719, 0.008708124198684735, 0.03133640617930463, 0.011085688003471919, 0.03382867208815046, 0.01845786241548402, 0.03176071108984096, 0.026110081800392697, 0.06071455350943974, 0.014368625324485558, 0.04028770121346627, 0.03810720857498901, 0.038689822490726195, 0.03671640516924007, 0.06782887104366507, 0.03654974000528455, 0.016581916649426733, 0.06674487063927309, 0.021331995958462358, 0.028694207780063152, 0.0149161691577839, 0.018595786532387137, 0.03046914343056934, 0.0799391469252961, 0.019342414236494472, 0.0481114847851651, 0.02753519363302205, 0.05343919586656349, 0.0322757734517966, 0.04152874176257423, 0.04146807055388178, 0.02042128491614546, 0.04535655797060047, 0.017955105286091566, 0.05214790979932461, 0.01715906326925116, 0.030360079104346887, 0.03466886807499187, 0.08185036294162273, 0.009615281413841461, 0.03238135350069829, 0.07107963732310704, 0.030053690009351288, 0.02229372944150652, 0.02772783481382898, 0.017557049502751658, 0.054729528592101166, 0.03798343700223735, 0.040867299041045566, 0.018434454653678194, 0.07098407923643078, 0.05415766267105937, 0.03107661547671471, 0.03747259173542261, 0.03210614987515977, 0.06726781757814543, 0.04739318422174879, 0.09336985195321695, 0.03310325708506363, 0.018492082632812004, 0.04525634174102119, 0.010984564233305199, 0.07205790840089321, 0.01502868892358882, 0.010509076578143452, 0.016213731673945273, 0.0045446994814223474, 0.03712515466447387, 0.040795645743076286, 0.05613292221512113, 0.012594637078499156, 0.010855505176420723, 0.06614541887704815, 0.029412827254938226, 0.034600984039051194, 0.031345264453973086, 0.034818566470806084, 0.011901610248189951, 0.025400705668809156, 0.038628672914845605, 0.04205018574638026, 0.045796876307576895, 0.03441837330215743, 0.019549475982785225, 0.006223842102502073, 0.048846233037433455, 0.06227103141801698, 0.018718314689717123, 0.019797609453754764, 0.007363247435673007, 0.017665733849363666, 0.07859570187117372, 0.021727400366216898, 0.05607952829450369, 0.038131666369736195, 0.045051393631313524, 0.024555547894643884, 0.05977598351559468, 0.04241728336949434, 0.056205966509878635, 0.02961628258760486, 0.04021788674539753, 0.010941492526658943, 0.09436356648802757, 0.04428364143573812, 0.06140773131379059, 0.02807923961829926, 0.03853484848514199, 0.03638199597064938, 0.011829368321092, 0.017974209439541613, 0.02183855458029679, 0.045862351544201374, 0.026155796400936585, 0.06694026836859328, 0.02220906693089221, 0.05318176646583846, 0.023609493659543138, 0.02131508686579764, 0.04452334410910096, 0.016868193966469595, 0.017712754629818455, 0.05028299701267055, 0.04497936035373381, 0.025374546447502713, 0.030970875972083638, 0.03389645434383835, 0.021974777270640646, 0.026575278623827865, 0.030872210195021968, 0.01080221897323749, 0.01286639120163662, 0.0537984428395118, 0.03861714121220367, 0.06231660861521959, 0.015788242719801407, 0.04211088070379836, 0.0489050959503012, 0.02603915792756847, 0.04676318820565939, 0.03137359329100166, 0.035424396462206326, 0.026090750337711403, 0.046365661679634025, 0.05420411517843604, 0.06480092209364686, 0.028348797832482626, 0.01088099179988993, 0.05959944227444274, 0.0777051110884973, 0.05506867057244692, 0.02766787606690611, 0.04658799385651946, 0.02089112970445837, 0.027433711935632994, 0.018593055428937078, 0.03499948426282831, 0.03496521824438657, 0.04807520012504288, 0.06040550794984613, 0.008873969183436461, 0.07391940137105328, 0.027000679368419305, 0.06164388864168099, 0.01385204219591937, 0.0687509865633079, 0.03754970384761691, 0.049861138220876455, 0.0085799981274509, 0.05033254024705716, 0.029184825917971984, 0.0748069319607956, 0.03911977959796786, 0.05165137144337807, 0.02339812830489661, 0.020949919674811617, 0.019284689566120505, 0.02148161462641188, 0.0655658006934183, 0.07157188055238553, 0.06888124493083783, 0.021744592747251903, 0.019828314859686152, 0.02977871708571911, 0.033438344818672965, 0.028069636651447842, 0.028159440761165958, 0.04191117088443466, 0.02197107925478901, 0.029988357265080725, 0.029529538670820848, 0.023492337803223302, 0.022016476640211682, 0.06073748120771987, 0.04539963476625936, 0.028738329519650767, 0.02386515717288213, 0.02141250583476254, 0.014344583132437297, 0.031019126597259725, 0.07779406702944211, 0.06557604657219988, 0.03164673077740839, 0.0291803000893976, 0.028874962723680904, 0.039358003064990044, 0.030746362305113246, 0.038729618569569926, 0.013610818755945988, 0.029512171567018543, 0.07759624693010535, 0.026756774866953492, 0.04295667460454362, 0.02489534975029528, 0.08829026416476284, 0.027686673183260218, 0.08862655290535518, 0.1105868366679975, 0.0179519992920437, 0.01934027685118573, 0.02128067665866443, 0.0481254931406251, 0.005508568653437708, 0.02816691143172128, 0.03143046809626477, 0.047595648893288205, 0.03234733175486326, 0.07477582791554076, 0.009271406651740628, 0.05964970136327403, 0.04165934279028859, 0.017804614700643078, 0.07286543971193687, 0.010828811608787094, 0.026029013829039674, 0.09487056106861148, 0.03223372802936605, 0.04787946991356356, 0.025959243465747153, 0.01611266557925514, 0.0398283771106175, 0.07391034971390452, 0.029068063611962965, 0.012328001653908618, 0.03729520911084754, 0.02008969842323235, 0.06252000627240964, 0.06535952604774918, 0.02715534294423248, 0.0067780215841984105, 0.05379890424332448, 0.026227863605267236, 0.06853047625294753, 0.01887908168802304, 0.02533982920327357, 0.06283712639872517, 0.030131378876311437, 0.0726581404783896, 0.029785030854067633, 0.020343728363513947, 0.002449433597835845, 0.06689980732543127, 0.07156322923089777, 0.01168859435711056, 0.05284640731822167, 0.03758464161572712, 0.08655603722270046, 0.01677590811492077, 0.013009607891685196, 0.024670191475057175, 0.040330906930778704, 0.030772333232952014, 0.055962823663971255, 0.049355639810008664, 0.031418223931853256, 0.08328660444489547, 0.03356969902025802, 0.017795420551140393, 0.1028235275298357, 0.025371683029724017, 0.0644938103588564, 0.03052372478746942, 0.03892631908612592, 0.04083554699484791, 0.043331178437386236, 0.025905635806598833, 0.03869410404669387, 0.033447230234742165, 0.011621265023547624, 0.01573385644171919, 0.012852377757163984, 0.05078838685793536, 0.08346677584839718, 0.04393464373424649, 0.025603075345445956, 0.048670153200094185, 0.04396508281518306, 0.06867208651133946, 0.062215479756040235, 0.03251633447195802, 0.04007203903581415, 0.03482315336753215, 0.00926951693171369, 0.07828734841729913, 0.05393186318022864, 0.05161627421953848, 0.004908430722675153, 0.030497909922684942, 0.011386803185035075, 0.019753360488851155, 0.07643184012600354, 0.06265348089592797, 0.14664513750800065, 0.18160123963441166, 0.08385673670896462, 0.10610199839408908, 0.15589358338287898, 0.26234131572502, 0.18859490007162094, 0.1433039360812732, 0.11774101134921823, 0.127549302897283, 0.13261888229421206, 0.09537461759256464, 0.1292798521795443, 0.1555747397776161, 0.12505445177001612, 0.10836361667939595, 0.1500808588628258, 0.1637615497623171, 0.08716552451785121, 0.14339946024119854, 0.25920238558735165, 0.15695116163364478, 0.15638515486248902, 0.2654761475111757, 0.11189933373991932, 0.21533144611333097, 0.14337485656142235, 0.14676521106490067, 0.08166992690946374, 0.2267165851912328, 0.21478431618639401, 0.0984355229884386, 0.10285664003874574, 0.09439438554857459, 0.0735804256317871, 0.1295436801654952, 0.1258662917784282, 0.18505870125123433, 0.18634664214083127, 0.10177907214633056, 0.1371165516653231, 0.07009865210524627, 0.16873161521341118, 0.16962572080748423, 0.1708117728786809, 0.12085440142878465, 0.09617185552737542, 0.18305844786976064, 0.1572848515851157, 0.07899852097034454, 0.0942091726298843, 0.17706117539533547, 0.16805048819099153, 0.11995819237615381, 0.19463935787124292, 0.16679947317710944, 0.11818755524499075, 0.1897518972733191, 0.14037626103631087, 0.12351888631071363, 0.059688941043402464, 0.09664813961301531, 0.0875754885907684, 0.13761257433465549, 0.15604545309075288, 0.1936728661613805, 0.12303236313164234, 0.17079592230064528, 0.10121582022735051, 0.20854663875486168, 0.11394695565104485, 0.16985438710876874, 0.09924129689378397, 0.10434730683586427, 0.15202731798802102, 0.06155430166316884, 0.11435778146343571, 0.10007472788648945, 0.18534764860357555, 0.15661724098026752, 0.12109176654900823, 0.14607755653560162, 0.08000293600239924, 0.10459216976804392, 0.08442999023411955, 0.10293826101613895, 0.09506902577621595, 0.11659153231552669, 0.10850300812827689, 0.09207300189882517, 0.14325015539569513, 0.10465952115399496, 0.07260645646601915, 0.18361935205757618, 0.07141527467008148, 0.14505188300141267, 0.2113515803856509, 0.13234418417726243, 0.09747700406504528, 0.1602260430476495, 0.15973433586103575, 0.10598158556967974, 0.17100032418966293, 0.10875972506723233, 0.1396134112562452, 0.10221190963472639, 0.1118618921775903, 0.07898190364773784, 0.11967946376119341, 0.16083377972245216, 0.14598300946610315, 0.10571597982198, 0.12338703338588987, 0.13859556801617146, 0.16832705906459264, 0.08679687644221953, 0.1168114183736699, 0.07742817380598613, 0.12844404631427356, 0.1007834712841681, 0.21528325655630656, 0.16564004682004452, 0.09645534067281655, 0.2927362376025745, 0.120746785774827, 0.10892416802900177, 0.20577882656029292, 0.10200815235397645, 0.1337386957768883, 0.06290977035782166, 0.14381958198334488, 0.14570822992495128, 0.11689894939107554, 0.10722926897662026, 0.13103101535567216, 0.12235513090022973, 0.1104939045118434, 0.1313375774770975, 0.16107308545282908, 0.17323817339326653, 0.07203573387648378, 0.07770216624651637, 0.19168920974646295, 0.20958544872701168, 0.15582164510020188, 0.21354799824101584, 0.1325052005371877, 0.15318584867886134, 0.1060882309185607, 0.12388408742845058, 0.10020385310053825, 0.08889605344406196, 0.1567576298756259, 0.10611502626644713, 0.09852475034339087, 0.13239841269595282, 0.15695866623095103, 0.14104161890489714, 0.0724073742915477, 0.1380014291831425, 0.127750515671713, 0.14830239143754753, 0.20983413181134633, 0.17832889594137669, 0.11067406912999493, 0.19159086288086005, 0.10342107260865824, 0.21223389304109982, 0.17648881753640516, 0.09238378450806652, 0.09538707549550704, 0.1835627622370209, 0.17055018405829156, 0.09510220613862787, 0.14499902512345994, 0.13336296379566193], [0.024611844248803597, 0.08875594274806124, 0.022954507198716913, 0.05435741659519928, 0.08884544151702098, 0.006949592980423144, 0.009532731691641467, 0.0167973040203963, 0.08043282864881413, 0.05282033121745501, 0.03538407112604805, 0.03896772329296384, 0.06028370412864855, 0.06844698930425303, 0.0640287763838257, 0.053268201649188995, 0.07906275788055998, 0.038478038140705655, 0.031385745853185654, 0.04714244856898274, 0.044934902739311965, 0.02975265116297773, 0.0465204524807632, 0.04069591805871044, 0.014852675243413873, 0.05836279863225562, 0.020769641402044466, 0.04029303449871285, 0.044078954562012634, 0.05593213352507778, 0.014166011375242045, 0.034908872696438005, 0.07165213088904109, 0.025291846599429846, 0.06727904054735388, 0.04267515042530639, 0.02737239611867283, 0.049088626102145226, 0.009799205115996301, 0.009993124487144607, 0.04207360538254891, 0.02089388625297163, 0.08076196563030992, 0.043306968307920864, 0.012137321439305586, 0.0839547918045095, 0.02104281451153968, 0.02899262069591454, 0.06466796315674271, 0.025602101647694196, 0.021359244228473732, 0.01631375282470669, 0.06442707643977233, 0.0432622698135674, 0.030989427119493484, 0.03805400803685188, 0.02672514326072165, 0.05786282688911472, 0.010504226749097663, 0.03200157405808568, 0.04581639776006341, 0.015661346493288875, 0.024929471580045562, 0.047591716782855134, 0.03752818750217557, 0.062257677848849974, 0.042557696013578346, 0.004691536155795413, 0.04818377251337681, 0.017797276344416395, 0.012538920023611613, 0.054378963474716456, 0.012944163189136555, 0.04783768911979028, 0.02913323011515396, 0.03271364906270589, 0.01423354257297303, 0.011595844557242734, 0.020013040929500545, 0.023365772362532358, 0.029058296100369523, 0.016689284638102566, 0.03689848664881928, 0.019769012595393827, 0.03323511679523757, 0.046697309240698814, 0.05410333237211619, 0.036080007175249715, 0.013875633162180228, 0.03492702350818685, 0.01183606291721974, 0.07075230524476085, 0.02240555201257978, 0.09877867171806948, 0.02349791705741414, 0.054217926758740626, 0.05537926997723324, 0.01424702167111848, 0.043705556741250415, 0.0067004383142505375, 0.04162202336426292, 0.03658927824082119, 0.04311124827446682, 0.009913007312986468, 0.05880533917141812, 0.03427250523652349, 0.025875552956547056, 0.044210980513266156, 0.03479456668719649, 0.09422439895570278, 0.017854834773710797, 0.008149535511620343, 0.0670880600810051, 0.06817208084144763, 0.007776454057810562, 0.00795079769367086, 0.0072569413543013585, 0.03899926160063062, 0.0270168234128505, 0.03700579356934343, 0.027672537602484226, 0.03145883086004427, 0.032416650892368386, 0.026464288954489996, 0.10555606947413512, 0.036311699742717404, 0.014346391428261995, 0.04523472022265196, 0.050366789302123446, 0.015187805385461875, 0.051913903427443335, 0.020106463327205608, 0.030269671098462174, 0.020126595461208905, 0.10145728369908673, 0.05998368987015315, 0.031770169868000915, 0.03749582477446113, 0.01384427466629339, 0.008895304020760315, 0.0288088971615902, 0.05173503481117742, 0.026561171880790165, 0.05908366745071752, 0.008737870325733508, 0.02236644464677998, 0.11163383655782257, 0.005757204240321049, 0.031097127590328455, 0.011573870200663805, 0.0774833115616015, 0.033310407040906806, 0.015203454099329454, 0.0415982882093106, 0.05604763036327703, 0.048564437444188764, 0.028392529414434518, 0.028810763132891486, 0.03168741234445146, 0.00378821902475985, 0.03963488606469972, 0.031624098241861374, 0.015707357952903424, 0.03476813096286995, 0.06120739384953465, 0.02694846100972167, 0.020098595713664378, 0.04556320581052985, 0.03808390428977353, 0.06504659926784889, 0.014919373539409466, 0.0076585925250713316, 0.03733327831806881, 0.02904696456555809, 0.017334730896566595, 0.026804424988638078, 0.017831946091194237, 0.042865398073835034, 0.03614958415606192, 0.05430760873215539, 0.014279119770175644, 0.022928731349696006, 0.03748779770519052, 0.01450664782896638, 0.03445548577500241, 0.05087370924385531, 0.054541533679834435, 0.03067684978512781, 0.03622049106551068, 0.04208047215693763, 0.026053744734131863, 0.06122377368488482, 0.07377717364579439, 0.04680569163922753, 0.019244006302739893, 0.012827556946181824, 0.0635858897918037, 0.004807668696490249, 0.08171615550028426, 0.058515957556664944, 0.0802886128159506, 0.10000669796551977, 0.014622775704732962, 0.021154579407136356, 0.04387709039396473, 0.02232635340520314, 0.028332441745858108, 0.0675057458824345, 0.052972957491874695, 0.022842662575255548, 0.05815124498414142, 0.09220497695995228, 0.07442896759935788, 0.026960425278437988, 0.027186024601438215, 0.08214448751615626, 0.032228153864187856, 0.015038446257156985, 0.03051521595833557, 0.028062678274831603, 0.024734728637018373, 0.03658498311415315, 0.01977797773932772, 0.004311763074448598, 0.022540778952783773, 0.028778607358357737, 0.05169859408800091, 0.06417103125048534, 0.05158686990450535, 0.04729532929403441, 0.05633753105731947, 0.031032748187759092, 0.02569331880658865, 0.00898138721406992, 0.018816541115354215, 0.047498350364289114, 0.0704781703118767, 0.02302657440304756, 0.03346226317808032, 0.022558388632855246, 0.02031707720431898, 0.0046959042249779615, 0.04013194349993553, 0.04500746866688132, 0.046932279132306576, 0.025133125384205153, 0.006612269473927361, 0.08068571186491422, 0.04698060439633472, 0.06535593659750052, 0.04852753192452448, 0.013895801767440779, 0.006631625957587468, 0.02056911734065839, 0.05151596978040678, 0.020277693335499083, 0.01570337325600641, 0.06253205705434084, 0.016283809074333737, 0.07247110908584935, 0.03440983733162284, 0.021085509631250585, 0.022163175911243473, 0.015234805809866105, 0.025119938056117723, 0.03395000772018518, 0.027235769699992876, 0.0104224514049877, 0.046705556833850484, 0.07701985857316426, 0.02866386708670429, 0.02322241826914251, 0.05640519456937909, 0.029643929496939694, 0.06594624849302427, 0.029011066670396497, 0.010065201869500535, 0.00628584493616862, 0.04189385127808366, 0.025162202306091785, 0.10256993863731623, 0.037672542434717925, 0.025755854290244833, 0.045675445680639574, 0.03218369624976601, 0.014161473672304834, 0.04586581207279648, 0.0541122143955103, 0.02119433816655406, 0.07251910865306854, 0.0809431616216898, 0.026721752281965952, 0.014254460111260414, 0.06439519207924604, 0.012190703485560204, 0.009667319960759153, 0.02083191734605602, 0.02343628741800785, 0.0398269216530025, 0.030786619787769656, 0.013618280096644802, 0.022643402285341705, 0.08575668904398169, 0.015831825024049197, 0.026472782516585927, 0.04472621590165155, 0.07419494087142603, 0.024898250487500002, 0.03797741839662194, 0.025591392668762376, 0.07452848154519286, 0.012573833194827395, 0.03969427484220692, 0.03379866726962583, 0.08299527543463878, 0.053330514912626574, 0.029467829303549867, 0.04098486880372677, 0.010717932201389755, 0.0052054564584977925, 0.022208437589662414, 0.04286565252446702, 0.13107159174978733, 0.023168221980865513, 0.04705181325386677, 0.06676114190902029, 0.053848057320075374, 0.01766433097821261, 0.008881124335208108, 0.09284177528960363, 0.03255969625232475, 0.02024439592579646, 0.015015506684514028, 0.012877793982625008, 0.019884039548092654, 0.03940899157896638, 0.017247919126280715, 0.00890760077163577, 0.015219060404758369, 0.061539441746260436, 0.05786837052021708, 0.012934290504615222, 0.00566405664929854, 0.02025907433458737, 0.021778896085119674, 0.06613317131996155, 0.01901574881880411, 0.03844865418172308, 0.05890899896621704, 0.01645622991158494, 0.03101760328614286, 0.07732229520167623, 0.1181767393967935, 0.15481597477836267, 0.1376672506864582, 0.1421100672866617, 0.10642816339220319, 0.12900873672749313, 0.09041020433817591, 0.06449146262769188, 0.17919805858816418, 0.15667495716895374, 0.2689697343323912, 0.09034728378589664, 0.13631298978413853, 0.20952756968992098, 0.1331426841872079, 0.11723162154001848, 0.14660232194832393, 0.12468389022563185, 0.1453934982419014, 0.1123299795602049, 0.1295807688896145, 0.06508965231478214, 0.14298521461231367, 0.061872846713023524, 0.14612839237919875, 0.20736984190131935, 0.18557020808969224, 0.17408475439463342, 0.17994355144245283, 0.0865578285551497, 0.10878597758710384, 0.14101356826722622, 0.2146783425871815, 0.1514484461929117, 0.13655613602272101, 0.13465132537697042, 0.14647802790360792, 0.13350800744124822, 0.1441290346639497, 0.19703261873551778, 0.1292786986700126, 0.11727160082331725, 0.19441462707306656, 0.12068128000412669, 0.08205231531922307, 0.17543818748423032, 0.07980886141636542, 0.10416388524962322, 0.12990642498646462, 0.10442627474133458, 0.0737912261060306, 0.16342692343252047, 0.15966338823948587, 0.13156408603702271, 0.15886703240019934, 0.14789016784301826, 0.07428067377103226, 0.1032710892281362, 0.09363462988819395, 0.17963856352227076, 0.14221772365272045, 0.13111629363681587, 0.06439120229333639, 0.14762743908379758, 0.1234961553875889, 0.11375465204140969, 0.08758725438799177, 0.07566046116075345, 0.1445184051990509, 0.10299313414309706, 0.10386661227260317, 0.1216789029006447, 0.11727731408817427, 0.1519756271903004, 0.1346518410635846, 0.07937815452792815, 0.10803301406225987, 0.06588210657771144, 0.11178870539047889, 0.11386219305651528, 0.05440122281600322, 0.1455852250967707, 0.12156674106206213, 0.12104004860988685, 0.11900343932211399, 0.13842999190092087, 0.1279973124286958, 0.08112364515130009, 0.10102986770548991, 0.1022826876225216, 0.09081408195197582, 0.20689446026725428, 0.09083377303821699, 0.2314955751810755, 0.11292865100715842, 0.1090393222070166, 0.15618406422436237, 0.058006886658923965, 0.13159126814986977, 0.18669319711625576, 0.07630164282662527, 0.1706277813230242, 0.1263665213648762, 0.13749456352421216, 0.29263405022876604, 0.10382289426135165, 0.08410713648689644, 0.08149934320577554, 0.0830673019268683, 0.13025654905608722, 0.1271688618830272, 0.10281786854778018, 0.13096658167030129, 0.1516012522791113, 0.17200638806181295, 0.060505625791847706, 0.1103332070633769, 0.12789129811738217, 0.14930925598101957, 0.09956033727420227, 0.09233021416834422, 0.12320338109774248, 0.1124383212466325, 0.1165854526417596, 0.22097271840487206, 0.11660120822489262, 0.12101408786007337, 0.06950592462505613, 0.09210350204791341, 0.15371359964566572, 0.148188193993909, 0.10367430187761784, 0.11422381150935378, 0.12598302694303648, 0.24475911632180214, 0.15923631829874857, 0.09082561026194266, 0.10232074665171759, 0.16227686085871287, 0.0757678664688553, 0.15443678226854118, 0.14133466460875102, 0.11224983778915235, 0.07324974159044878, 0.09601498501641409, 0.11679798338030066, 0.2711307869425842, 0.07684393479887928, 0.14973910791533335, 0.17150193798754895, 0.22409632722181932, 0.07146540483725922, 0.08993095505450453, 0.20708660781383514, 0.16042463667690754, 0.1139873420553548, 0.06266483278678996, 0.09237153016562973, 0.08941777223455054, 0.11067723110318184, 0.12478634901344776, 0.1237682072179658, 0.0975926603589739, 0.11658313205199582, 0.12150567291038376, 0.11975791598004953, 0.10327587968536786, 0.12719027644821576, 0.10185733437538147, 0.12869587780109473, 0.061614793060081344, 0.14121183619967528, 0.1349304746836424, 0.13563820027879306, 0.10112723748066596, 0.14812889003327914], [0.034520631922142844, 0.008681300013060016, 0.03177356593576925, 0.026571894430422356, 0.04155267708535705, 0.027445092664233277, 0.013094430706197662, 0.03273181005248001, 0.024673545134386847, 0.04558314795472792, 0.0492316714621016, 0.009143333166970738, 0.08143086545169353, 0.04194754036143422, 0.016090782824903727, 0.02133900352886745, 0.06826744893831865, 0.07696308554815394, 0.054189845586993864, 0.05285733851737209, 0.021269874381167547, 0.034586351431374035, 0.10416720328586442, 0.032641229020165544, 0.03046683980418103, 0.07269201294652053, 0.01827898362119283, 0.06264554203620978, 0.04649574702073421, 0.07652054500899144, 0.041043222815330536, 0.020252248272299767, 0.014278829696455171, 0.06769346938069377, 0.024023610366774455, 0.030876600316592624, 0.04440136047612343, 0.024238122427569966, 0.04097100972597088, 0.0161970498905118, 0.09496038553438016, 0.04851004607709391, 0.06375731487891503, 0.010818849018375789, 0.010378936106073005, 0.04821449318634612, 0.012057648705584663, 0.003020250970231635, 0.0329097863951964, 0.03622652663450156, 0.009523662222948457, 0.023811403628704802, 0.016524778911843896, 0.07174009616885867, 0.00989070301875472, 0.016136728127353957, 0.07478205686701195, 0.025100562488660216, 0.038788433984986374, 0.020490882253008227, 0.030840641353279352, 0.02672912286860602, 0.044723644253930876, 0.06928833201527596, 0.007544872600452176, 0.02262037111047123, 0.03725862589531711, 0.043109233025461435, 0.013520734750532677, 0.03408523974940181, 0.008857383243074375, 0.09491925274154969, 0.005089850206526795, 0.036647123351160965, 0.02133427922880011, 0.05656511170257415, 0.03008850903383323, 0.055193419235625436, 0.04231691786221095, 0.06916656890617949, 0.022098413136388575, 0.08493216721607105, 0.0414598263534052, 0.024716833972239068, 0.03784049002985869, 0.051388500191803486, 0.011095432614508485, 0.08527978749147483, 0.07744202270571675, 0.011166885744647255, 0.06965715651001249, 0.13835989923349448, 0.04400740643697126, 0.027167449705302715, 0.04435969164062824, 0.027073138426723223, 0.0067386576473446825, 0.030536335360791002, 0.015941242188481346, 0.08534608714814697, 0.019917224999517202, 0.028446554372619306, 0.050181165869746885, 0.025675989022212367, 0.0705256134803806, 0.04365021203245435, 0.032653619069606066, 0.029845590104482005, 0.054613818015371046, 0.03729937870853713, 0.033752818658415756, 0.09738019068858453, 0.02995109890720674, 0.013900546423558677, 0.014484486875257321, 0.00479761407976704, 0.01043460566350924, 0.05123009619170001, 0.0782728549093008, 0.04936771094799042, 0.06416885993842568, 0.0062693913101351684, 0.0467687555854874, 0.04741163358890584, 0.037360796305750094, 0.015891441110787646, 0.010579418607189186, 0.024543188379279206, 0.031009677997125045, 0.023893058532848954, 0.0544499823424433, 0.06238785479217768, 0.0184781285601535, 0.025467773766389916, 0.03845980251207948, 0.010783988433623952, 0.01840844301373831, 0.0499000725602465, 0.01568748026953212, 0.03636387908565147, 0.018377103177564483, 0.05629843047686985, 0.03362114215269685, 0.02078304416500032, 0.04768505945269551, 0.052854186722210476, 0.03054002659129245, 0.05657001072540879, 0.0549154641505863, 0.02991604239546827, 0.010482769775470453, 0.007995636984040695, 0.012707915955356188, 0.027095161977091005, 0.012064445930133973, 0.05833214242011309, 0.03434173955715128, 0.05772484679307256, 0.027736070532617823, 0.0631658901859607, 0.037966307385691574, 0.026032041791560392, 0.021945876767858863, 0.11098807478057486, 0.021128991851583123, 0.06737382510410887, 0.033862815970288854, 0.012922996289229818, 0.043183539395353625, 0.039837988559156656, 0.0184255149548075, 0.03830090318141239, 0.030262997706553767, 0.04365802536319409, 0.032217022497206926, 0.02442695024157209, 0.0532346141657659, 0.02106747925946755, 0.030340506761733974, 0.03819618487198438, 0.012395530307133282, 0.023469935969582627, 0.0324257805810443, 0.01245327278905149, 0.07359510234424047, 0.04406600472118173, 0.0287045757951481, 0.010359458758362701, 0.03752803822447147, 0.03088289372889059, 0.025871932972222567, 0.028833806182124784, 0.03655642357521823, 0.054441727963941436, 0.04745323117822409, 0.031366044588919194, 0.02260265456113432, 0.07390166446566582, 0.01013866176695696, 0.03179665308977876, 0.011372215530302907, 0.04359313027401056, 0.04667101940140128, 0.06367037418697562, 0.031391754280775785, 0.037945004778781107, 0.0005726502121043657, 0.032545674326164384, 0.04699814113389168, 0.008297205935897571, 0.03285300319216081, 0.06407949009111949, 0.03646934378359999, 0.018969040164457898, 0.036357178552342315, 0.03505495110792773, 0.03973279527521559, 0.019791171852765337, 0.04006137585799609, 0.05149345938116312, 0.08051139621862344, 0.060906097159854004, 0.07021946526531662, 0.02936091593333653, 0.06353917944111995, 0.0674794390797615, 0.00840941527193146, 0.0432719592936337, 0.027834286780229638, 0.0692021105704563, 0.052872741262295415, 0.016767495977027074, 0.03158383736652987, 0.0303698126891894, 0.061601961962878704, 0.00947803583195699, 0.048940820819033046, 0.02487530412950686, 0.04274184363228934, 0.05257301877385803, 0.03724286013415881, 0.04251417817015733, 0.022584430806870972, 0.01358547801750579, 0.027614297245496085, 0.0465802415939314, 0.017803678322317343, 0.06839005343083825, 0.05897971588586058, 0.02397836056271834, 0.04674070155514138, 0.05417200011600341, 0.022980705435786928, 0.021770660366330827, 0.06740392491753612, 0.09722448725785528, 0.058863333559462, 0.06154218302773578, 0.03138262459209987, 0.029948394945157424, 0.0316274502048535, 0.09224798250943422, 0.016879890213853548, 0.051026376230376105, 0.039765174966305494, 0.06807904011969056, 0.015019418438896537, 0.02593428864409881, 0.10578593678240265, 0.03265035192349127, 0.0573922832097326, 0.025307780298005258, 0.02283365841555808, 0.054556332528591156, 0.018240230789940273, 0.031677943388266225, 0.01365402277692088, 0.04166046576574445, 0.04086384529780064, 0.04812266704227243, 0.02449987918537642, 0.058121715140129836, 0.01734055103068905, 0.0657715325110725, 0.10177389492413827, 0.06954392258610044, 0.05646875972992607, 0.06194754663322653, 0.046564713320029635, 0.015228307140725, 0.04026393213176301, 0.04344285512343049, 0.015263414542589868, 0.047189413370298486, 0.05189465678163937, 0.01639955866682742, 0.0413238784697439, 0.0242522630973586, 0.01691772193381829, 0.025406858285090754, 0.04446737854076283, 0.007612492855904358, 0.07137773811284985, 0.0404308144269245, 0.05739719580326762, 0.011277634534053504, 0.0753157382298793, 0.04311575374699064, 0.03753367006512625, 0.04898976694260325, 0.0697242229112557, 0.08096204525125877, 0.016716921369412115, 0.04830631593774472, 0.040688172581472566, 0.03899989942354815, 0.023855340467499833, 0.06871260862265315, 0.030925502335386615, 0.013684803669873093, 0.026715058534006988, 0.03329453949949571, 0.04588252778298088, 0.012027968735700207, 0.023713843863723532, 0.04757916049233504, 0.019974082841404846, 0.007182224470722888, 0.08553171397319861, 0.03297393848853452, 0.028074233726199185, 0.0022238408481436117, 0.021991279242294173, 0.06084333945597921, 0.051658614804702144, 0.060474250332585404, 0.027944238290988972, 0.03201540938711592, 0.0007116575465520977, 0.08056641862328563, 0.05815281918538468, 0.036151711363345385, 0.045552498527935574, 0.017735809553414583, 0.06190419503088508, 0.017013205381642495, 0.04261447921661394, 0.02606058436711984, 0.06855769229254552, 0.0700886979965227, 0.054891793456460745, 0.0276116306028728, 0.16327983061117785, 0.12946217453905515, 0.10716052659388099, 0.09429713790970189, 0.18819026249860013, 0.24276118353009224, 0.14112231028931482, 0.12172170488962106, 0.14907947688230447, 0.1318313202687672, 0.13554669304617814, 0.11022890944566045, 0.2363082340785435, 0.10903604488287653, 0.16694807234619344, 0.11587083313081946, 0.20035617825176033, 0.1321786352034126, 0.11373466239976031, 0.1339197289198637, 0.12328984002981867, 0.11161010818822042, 0.27724457745041164, 0.10559884432171072, 0.087951919463064, 0.11545877238469464, 0.09254873637109995, 0.11914108693599701, 0.14307076430746488, 0.18345540442637034, 0.11211623424398047, 0.11086634559822933, 0.08254978326814515, 0.10320902362998043, 0.17032292910984584, 0.0980846593156457, 0.09855053467409951, 0.11589182700429644, 0.1839269319815295, 0.07547043742878096, 0.19914602461670125, 0.10955175863845007, 0.14952585792967252, 0.09073092070009027, 0.10598392651549407, 0.1231367082468101, 0.218715422387634, 0.09726888380412545, 0.17108742094465665, 0.2626101512994085, 0.06817639632416622, 0.13829056652528898, 0.0702915663963982, 0.1586179421948535, 0.11803217072572027, 0.09544017764606647, 0.1065564743642296, 0.1224024383617299, 0.11697170191577502, 0.09915456654770033, 0.08641330738152776, 0.11233593709766865, 0.169865895062685, 0.1485174327556576, 0.12447401934436389, 0.11097102998090641, 0.13116330254290784, 0.12738806940615177, 0.16929927761001246, 0.08191315457224846, 0.11951847454266888, 0.27289875064577374, 0.07743390064154353, 0.1638434353683676, 0.16991679875978402, 0.1419705469161272, 0.1205049558941807, 0.17877481558493205, 0.11811135576239654, 0.1519925905657666, 0.20893682353198528, 0.11662540478365761, 0.11339669767767191, 0.06910138204693794, 0.15104465000331402, 0.19388801604509354, 0.0879308780921357, 0.11971204701278891, 0.1711394510098866, 0.10387413722595998, 0.1480577252805233, 0.22782915191990988, 0.18678083669926437, 0.13696662256760256, 0.13967888988554478, 0.10647477874798433, 0.14388457206743105, 0.15343093552759715, 0.13161040283739567, 0.17189470119774342, 0.13444644851343973, 0.11183566679911953, 0.09303340714957033, 0.10028955885874373, 0.12941246506358894, 0.19117513804563455, 0.10723255308611052, 0.15373035946062633, 0.17330241708883218, 0.1769614578889949, 0.13571932592562266, 0.18169878582869256, 0.1551120603191001, 0.0821617901591318, 0.1141351405531168, 0.1056927874950426, 0.08432122107063021, 0.15874499109174522, 0.21797451643007143, 0.16310335722352776, 0.1228113371346678, 0.11162298678287438, 0.12931061695728982, 0.1059890358841845, 0.09865720037903104, 0.1369112676807812, 0.13011640443333558, 0.13386039781783307, 0.11063217637794358, 0.12749477582318441, 0.12108461478991167, 0.16161192368183816, 0.14276509785226413, 0.2368237307029111, 0.19564927582229885, 0.11719181867582457, 0.05108192449967776, 0.17179207956152304, 0.06963502948305436, 0.19567560298102243, 0.09508545989436762, 0.1815089995839766, 0.1456046583397048, 0.08847960936171667, 0.15315667167305946, 0.09763665656958308, 0.2207387052476406, 0.12860203640801565, 0.10518097531582628, 0.19129878069673265, 0.04900695084195052, 0.07991230407995836, 0.10340512703572001, 0.12582350336015224, 0.12905292292790754, 0.13753178795533522, 0.07657942149255957, 0.15506619135183947, 0.11991958373359271, 0.18317477591335773, 0.1535577265811818, 0.18319315064166272, 0.13628177717328072, 0.1730041873774358, 0.11274507335786309, 0.14211115294269153, 0.17308098397084645, 0.1310475987515279, 0.1692543314503772, 0.11127965484878846, 0.14798965464745248, 0.13047119682388647, 0.1596061470253127, 0.16102400022958005, 0.17460892269653933, 0.10077146121433803], [0.021487416100821326, 0.042210163947726996, 0.03251536077420626, 0.06924401689320803, 0.023575302279953445, 0.05775116716644593, 0.017170679788770418, 0.06379369792661496, 0.06126370547073228, 0.030028272087552717, 0.037683337926864624, 0.05187980365008116, 0.026909017769087638, 0.02495024662597903, 0.05112619212429438, 0.0032390609142437044, 0.1320572860006775, 0.01882431373399283, 0.006913212053145149, 0.028895763214677572, 0.017549892654642463, 0.0601694184754576, 0.018118796770327857, 0.04005138442984649, 0.05741195393992322, 0.023148038956735815, 0.05654770049399563, 0.04648360463657549, 0.05154198142034667, 0.025855376717767546, 0.0474878636055759, 0.033208056818693876, 0.056190658759857924, 0.03918227606586047, 0.012444949708878994, 0.054750573355704546, 0.04120007975559149, 0.048603724621768506, 0.013237476066154028, 0.010863891869251217, 0.019821631289752464, 0.01864924152115626, 0.042917272076010704, 0.02682962577923068, 0.01825715006063027, 0.022864777727850845, 0.026571397403521196, 0.024642303685790727, 0.03195435480613794, 0.025468755945829407, 0.03468555664377553, 0.08921860863587686, 0.04543617387701358, 0.015806076316429035, 0.05444452692089336, 0.022937016262273704, 0.0528538203133004, 0.048139983255948336, 0.0078675032792879, 0.03443228666271482, 0.04104246624878474, 0.02292515886282282, 0.05306373190666948, 0.0320329902294491, 0.02508732257410884, 0.014407437527552247, 0.022131462880809392, 0.01688466710038483, 0.003475630664200123, 0.01008288364391774, 0.06598817517182656, 0.03685729618051222, 0.03800078035731401, 0.0879329340532422, 0.01843696692958474, 0.03436284878158143, 0.030786436583314623, 0.02738737308287195, 0.041518763905125, 0.00382431030240176, 0.004890928335953504, 0.07092329606946025, 0.021400851995817254, 0.008311962376215627, 0.025057904688375335, 0.045863715399588854, 0.05079987784847617, 0.025017250262733017, 0.1143055749791009, 0.014096569253264793, 0.036873808330191035, 0.06017809693834611, 0.030657609924674034, 0.028661234370831932, 0.02946650276758841, 0.014231174485757947, 0.040148028172552586, 0.055578905157744884, 0.046785837704581876, 0.02701151217999203, 0.04616519868639963, 0.005963210864657802, 0.009722161705472639, 0.016883349046111107, 0.029628601390868425, 0.03782834764569998, 0.08124614107821669, 0.07593046381537404, 0.008022527326829731, 0.018533266315768872, 0.027185001709897603, 0.012735043785401752, 0.0627469423093966, 0.06335231089698416, 0.09182060044258833, 0.07695725014699356, 0.03291033261588641, 0.02239872425395463, 0.040448588651738, 0.006146689702291042, 0.030175765244556323, 0.007589644885488919, 0.026985773650397147, 0.0520595102570951, 0.02243365184403956, 0.03801465979112046, 0.03464206594175526, 0.0055937841700922164, 0.028704385805342878, 0.020892571591373, 0.07851035573652812, 0.03918031509965658, 0.015433940570801497, 0.021187752984198074, 0.017403783709076897, 0.05696415475436619, 0.026268290721678307, 0.02764410019985267, 0.11387135327926703, 0.08193124431584563, 0.10537353676876851, 0.02005022295218493, 0.052042071907115836, 0.0926244133817298, 0.06564985082617827, 0.017480069704885994, 0.01762523379043809, 0.13384370585637434, 0.024690596719405482, 0.03486675942050559, 0.01767996951405491, 0.0250498148546155, 0.04790408377136503, 0.02817974761793656, 0.018837991303631237, 0.058320335910788605, 0.03118512679689697, 0.03297050849401525, 0.07008398217814309, 0.04275089189676302, 0.007339132301110242, 0.037941859768969674, 0.0011475011041121824, 0.02760595635377935, 0.023356654548219273, 0.029201165041221038, 0.0687834612493004, 0.029535645485988686, 0.02487419981376401, 0.024104668160102198, 0.0049900033544482926, 0.016561502923390696, 0.013952980217124735, 0.039886459708213806, 0.07888783155275242, 0.018155522478212203, 0.11707886973662035, 0.06148254658494677, 0.03748089361137577, 0.023720608857859458, 0.008571937131429357, 0.03567469106721027, 0.031245390884578228, 0.05356958654842206, 0.03043416834303311, 0.05112875698666487, 0.09235173051378556, 0.03662808705121279, 0.05444384499319962, 0.055065664662314315, 0.011122262737314616, 0.017971843048664074, 0.05680746066250971, 0.02882734313607216, 0.014273788181266614, 0.06516097313059227, 0.04716648567201836, 0.039324293445263586, 0.007759087802177029, 0.027576545253396034, 0.042346037192536254, 0.03732995010380234, 0.0759737068521125, 0.041494133083948066, 0.019416895329153964, 0.035578888707927296, 0.04947059042751789, 0.05239306789423738, 0.030513326238308634, 0.026988983121035353, 0.025957815149532895, 0.09283065410064799, 0.03676976177043148, 0.08378178573080472, 0.018746100698730776, 0.028178799365248, 0.0669880033071552, 0.05222888616845012, 0.052619305040155134, 0.04072110188592758, 0.04886647034436464, 0.03310489574713366, 0.05375423967572195, 0.05278573271685413, 0.038196914297129424, 0.01480723375321499, 0.06694348462458168, 0.03941389399447611, 0.03248889451580388, 0.019760211996201957, 0.10463436107550349, 0.007189525507523545, 0.03288668227781143, 0.013012083696334489, 0.04316447934667979, 0.0273073738041733, 0.04519477825877922, 0.03620476262377841, 0.03514543714533959, 0.04751996509730816, 0.018167525762692094, 0.023288280270727615, 0.06259104888886213, 0.03131633511345301, 0.024366640352777073, 0.02621325644265328, 0.052809345735503097, 0.01051137681185667, 0.026904195081442595, 0.017216769279912114, 0.019736000170399035, 0.021202210869107927, 0.02725938950399203, 0.11305167619138956, 0.023164464593199745, 0.018589382858148644, 0.00364220719451883, 0.0498155338822731, 0.03245833669123905, 0.011950633555118526, 0.022139588337657706, 0.04647447834057467, 0.08272665020610605, 0.009904500180190163, 0.04104621854743787, 0.034024639786886315, 0.03691393010584371, 0.034357915831995864, 0.1209304787750755, 0.006317404872139117, 0.023638399251337563, 0.0053489492274820805, 0.04387952972735677, 0.022477235844624893, 0.08894308270620448, 0.038987553478883843, 0.02032392531899469, 0.03301820272047605, 0.051018535758235624, 0.021312328620946834, 0.012442379757495863, 0.01885967728282724, 0.030059796824519123, 0.04249417156513248, 0.054989278582589965, 0.017971432534977794, 0.0185916372907481, 0.032968408428132534, 0.020912549358659556, 0.05563820233302457, 0.0248762371151575, 0.031522144962634356, 0.011401155048848262, 0.02502693635012422, 0.029505077483398572, 0.0151556122915021, 0.07645538529115063, 0.03298458131030202, 0.04954452360314982, 0.04647026803078396, 0.06120934124503817, 0.03344025828742555, 0.03552464322586145, 0.027400243195838163, 0.06453243935746805, 0.06301355907427413, 0.057584342546761036, 0.021983516801680838, 0.0325518897069352, 0.04368470875280244, 0.03987723502463528, 0.04903618213055389, 0.02574591205588409, 0.047010995979819975, 0.028048557961093526, 0.04663992892684681, 0.03637960074203355, 0.024834525871223638, 0.02653629000165633, 0.05221653004576053, 0.045581516078008075, 0.07818832301667758, 0.013504334559131945, 0.03901971603876778, 0.04701976604493601, 0.058472836656229835, 0.036480811025415144, 0.010607598166513656, 0.02648325909727386, 0.06653817530189242, 0.008695289708807, 0.023760545732719556, 0.03927171715934362, 0.013486038710522865, 0.022075661857213293, 0.02280649496242404, 0.024198804715914384, 0.060040367900260856, 0.03112720704770514, 0.02687966264784336, 0.034101354956094704, 0.014312729305986847, 0.017471038403787782, 0.006200974624204848, 0.03392362967133522, 0.029671332133667808, 0.01137461160708751, 0.03267519987587418, 0.04027087015232869, 0.022874697909823487, 0.07703734442059483, 0.041085054499230216, 0.19065923430025578, 0.09969841915049724, 0.17142024237130368, 0.19505175788487705, 0.2170201162142413, 0.1533368227205106, 0.08085718444947686, 0.15195651964417525, 0.12324988788792066, 0.2508338503539562, 0.1371985322662762, 0.14270579389163426, 0.1261529185410057, 0.1483094889138426, 0.10708423890173435, 0.12226352867271219, 0.18916324100324086, 0.08710080584777252, 0.09928272145667247, 0.14936374234301703, 0.11337026195334536, 0.2140564788132906, 0.08295756924365248, 0.1043358463793993, 0.16857139952480793, 0.17918034882417747, 0.14463701312031063, 0.1489516951675926, 0.1582780640040125, 0.14837483183613845, 0.18124457448720932, 0.14900276171309607, 0.20591392288250582, 0.11261677595653705, 0.12021414935588837, 0.16486419630902155, 0.1285815853625536, 0.1638731552021844, 0.119921049369233, 0.09142278893185513, 0.13728058072073118, 0.1785443579511983, 0.1016967183511172, 0.08612921155456986, 0.09907956807208912, 0.13711699949843542, 0.09743802222822394, 0.11394416008676801, 0.09119621930377823, 0.06924939089055572, 0.1277464580323015, 0.27308705768414904, 0.11052776340927396, 0.14218030923179217, 0.21591898958597863, 0.08018184533076626, 0.12087075412273407, 0.14959590988499777, 0.09361453168094158, 0.15072302440447466, 0.1068698489772422, 0.1100188825013382, 0.2158092569027628, 0.12763345481029578, 0.07774734310805798, 0.08873694376753909, 0.13300686861787522, 0.09433037255491529, 0.10743835954261677, 0.11244172070707593, 0.1281130433614765, 0.11534815760595457, 0.15838276195738996, 0.18532151143465722, 0.09714918344148568, 0.14352269577128546, 0.08638604384447847, 0.1724664212337562, 0.09768589785588638, 0.1385426287140165, 0.0818647343133177, 0.110220997727343, 0.14557294361293316, 0.132848254271916, 0.12056438199111394, 0.14959014233733925, 0.13984371961227485, 0.08767904660531453, 0.19261664498065198, 0.12566279912633554, 0.1357576631541763, 0.09365569161517279, 0.17826712211327894, 0.09855180353458438, 0.09565662353166512, 0.15909189890537942, 0.12838296459189483, 0.15494961903563567, 0.17062575928866863, 0.07998104646269764, 0.08375138057661907, 0.14010347638811382, 0.09390632209501096, 0.06520387011447124, 0.11129949521273375, 0.15996480706546987, 0.10085445283246891, 0.1676538980432919, 0.21798417876873696, 0.06637659575790167, 0.0695427351498178, 0.10718606665198292, 0.11996804470462458, 0.09796513537211077, 0.15622263215482235, 0.12806631944009236, 0.1021348959101098, 0.05759723471211536, 0.0889159141640578, 0.07834520709833928, 0.14306710021836416, 0.08899077014731509, 0.17967072608215467, 0.11769941715257508, 0.10307183063455991, 0.11268433090299368, 0.14513774482267244, 0.09353938392762627, 0.11048253226493086, 0.09122331999242306, 0.1485512237995863, 0.12591315140681608, 0.16579564847052097, 0.12495322791593415, 0.10383007994719914, 0.11319361214659043, 0.14209220824497087, 0.12982156739703246, 0.15317203370588167, 0.18448068441024848, 0.22601124803934777, 0.1656224320509604, 0.15171470333422932, 0.2760970933096749, 0.19095196787800106, 0.14013006139014447, 0.06540527287870646, 0.17867657728493214, 0.12967765011957713, 0.1478107249630349, 0.12033137306571007, 0.08602920906352145, 0.09552641944693667, 0.11937070318630763, 0.10527925432792731, 0.14934767463377543, 0.13388154096901417, 0.07637585420161486, 0.1662808010088546, 0.0716390215924808, 0.09060528994138752, 0.2443995741861207, 0.1533378405230386, 0.09450299186365944, 0.09807772468775511, 0.13117229991725513, 0.07669817869152341, 0.12880155284489903, 0.12547268718481064, 0.13704742251762322, 0.16673761792480946, 0.11383744009903499, 0.10440772359392472, 0.11565670104963438, 0.2141915751355035, 0.15494489643190587], [0.029971146224332706, 0.05483614679958139, 0.049157320987433195, 0.016947058395349553, 0.0650120550500495, 0.03209873688008104, 0.030508406859423434, 0.02812250131475074, 0.027652351185679436, 0.027804013940372636, 0.07665085087397269, 0.030083620189023868, 0.02947689113872392, 0.06190678703465632, 0.012275171765525426, 0.05165198551756995, 0.012964059532220875, 0.041155343941812, 0.0344529785881085, 0.06375269405543804, 0.06150589497493846, 0.07981962976711136, 0.09379965639007942, 0.03412871688072171, 0.03288240072184375, 0.007285572139413229, 0.06577233996774469, 0.01716463064907917, 0.015289894371692623, 0.005823483540942627, 0.0071076072469752815, 0.023808806535920927, 0.027853448609156266, 0.020926476289917315, 0.05809704360685178, 0.028346719818988016, 0.051966937724500895, 0.09692849671202046, 0.02213586657308042, 0.008903700891616089, 0.021741915926603333, 0.010661651114267963, 0.05386303937328713, 0.04451019749311464, 0.023888575112713233, 0.029487418609538248, 0.04653994679184897, 0.030230875858770948, 0.03298318013548851, 0.0404126907565764, 0.01864063600078225, 0.019821571917938333, 0.05519269998850567, 0.032899248746356795, 0.03594026628083416, 0.022745710099115968, 0.02315819662596498, 0.009492630272039344, 0.053750745220375915, 0.052715243106441836, 0.04401732661894389, 0.03363901815776314, 0.046636902660663636, 0.06886548934770481, 0.035324465217334886, 0.05734800879976579, 0.043753783617700846, 0.03566633151578052, 0.00912331129490797, 0.032641456329396794, 0.041349801900131364, 0.11498037805514676, 0.048728863442582745, 0.033501814984317334, 0.055622792802751064, 0.03367089573293924, 0.03995881528992738, 0.017966803229813064, 0.030883772431739738, 0.04169136964316879, 0.02163252590357193, 0.09202004224061966, 0.04209736089355179, 0.02533076227908688, 0.03431192472843187, 0.04462364515555756, 0.07934779008584363, 0.03395011289311307, 0.02568964284312512, 0.03618255077994295, 0.024258469996441687, 0.023735209235123227, 0.04902999049850872, 0.0349474813389991, 0.023438333201089075, 0.0866828825590866, 0.030637162271887064, 0.026425181588690196, 0.024349117185920477, 0.0426452745284353, 0.019987660327128003, 0.035796192940324545, 0.05350974315245237, 0.01729089074901172, 0.01674296354342784, 0.035304200769002946, 0.01596392731049231, 0.04058857721143535, 0.05283026497012802, 0.031430064367928674, 0.0890159709379077, 0.032741876119481664, 0.01616263289802841, 0.03645671285422785, 0.049644431099295616, 0.05574886460921594, 0.0303044969082943, 0.014549799263477325, 0.0361080238861697, 0.04465644893103412, 0.037413518476699076, 0.07474610808172397, 0.021713716011228304, 0.06666130226637636, 0.05143062364576118, 0.03785437624901533, 0.026098704464467506, 0.05713873502931424, 0.043153751708034954, 0.031000103868011917, 0.05069298483431339, 0.030215103312262466, 0.07536751723715238, 0.08192416719560112, 0.03205806209838816, 0.02984536618792585, 0.05166417879185506, 0.02659238958066063, 0.03763248172721692, 0.04110412133325424, 0.06229721608438662, 0.0232982784842274, 0.028265933439667736, 0.05288094814334597, 0.04902043333277106, 0.016466107685118914, 0.06744524770017181, 0.03211198866899524, 0.04959249942164336, 0.03398624488285609, 0.057149014834846766, 0.06105817721358367, 0.012879620089993944, 0.01249030723036932, 0.045876573638192246, 0.020465918949672153, 0.01728255664264517, 0.06780132930725813, 0.013821061135136654, 0.040438553118812184, 0.013481173614439155, 0.06165050435811281, 0.042330583557486534, 0.062076732915427, 0.046679592691361904, 0.02623088817511286, 0.044687868495072634, 0.052133324689098766, 0.03342654848737376, 0.02616250202325838, 0.009469817924712385, 0.029862858820706606, 0.09673587419092655, 0.02553254841560764, 0.02045609036992703, 0.051505140361509154, 0.029274535032787492, 0.020345918335286633, 0.0496645700186491, 0.035995129229766984, 0.016490348348660127, 0.06149714865854808, 0.03291111971650805, 0.06539721188268491, 0.04123482074854629, 0.021738887964082614, 0.04561830624671919, 0.07977540285459586, 0.014376645608405982, 0.006482289729839457, 0.0831202140876225, 0.025039752180288945, 0.07557031099817582, 0.02090613211372069, 0.04982087056019476, 0.044370164828641076, 0.06998884478317839, 0.10044792893209628, 0.04986164712214044, 0.03613161654876811, 0.035575404430606535, 0.05154997456286635, 0.001270685638051613, 0.023654841851176958, 0.03945836517959833, 0.054814287793955634, 0.04098325728305748, 0.030141200670706372, 0.0379012799821794, 0.010254010175620871, 0.027184718421527317, 0.05391928992633309, 0.02571723038064582, 0.03746923977243049, 0.01094971806742251, 0.021646856563165784, 0.016266540358109132, 0.07554193466369595, 0.045259761557515175, 0.07533367869577237, 0.06559149002922432, 0.06535299854086978, 0.04551078898033925, 0.05795754359236785, 0.018459753831848502, 0.03393201297149062, 0.055219363022063456, 0.03658596359725509, 0.03447597074721541, 0.04065676319545933, 0.045582204791052, 0.012747926620899566, 0.033410616485135894, 0.03497548108654363, 0.05524897089760218, 0.03356755145692399, 0.056244948346699984, 0.04842333608706083, 0.018925768289981142, 0.06037240901163646, 0.04319858251671706, 0.0207519265490451, 0.06780854213450636, 0.05635441979393363, 0.049289170519581864, 0.016037232841231992, 0.012156451885987605, 0.030150398212884153, 0.018133044309381927, 0.03414021126393761, 0.053842971700110605, 0.04574691238147872, 0.04608178298388209, 0.012388569386010724, 0.06288361283285276, 0.047035134863108397, 0.0961117712514741, 0.11803738187466349, 0.034292830753007104, 0.06306802508022104, 0.03447060692789299, 0.021649677572505813, 0.06755882089159318, 0.027947681856208613, 0.011035643501340278, 0.02719416532532445, 0.033134123643061945, 0.05020495191482561, 0.03455096243747643, 0.08008497767150402, 0.043343900968985896, 0.12191831719662462, 0.04749360401183367, 0.012686637097171374, 0.04548472984294806, 0.06759504109088864, 0.042868071501808505, 0.047976307038749964, 0.16457077062555722, 0.034511875427727184, 0.020750209855447923, 0.051968454250267575, 0.03210157315645899, 0.045675143732556274, 0.037969812019062896, 0.04795067198574543, 0.04158010686348591, 0.010764479703669037, 0.00920807134493121, 0.02291926578618586, 0.03076906269416213, 0.0186618470054652, 0.012518349386352514, 0.07417647114821843, 0.02851528488099575, 0.07997396934245314, 0.020966894924640656, 0.012185478765916611, 0.10331180811460529, 0.006084906120252396, 0.01955139454055045, 0.0032508248030873282, 0.05714761705270835, 0.015910319651343992, 0.020010024841342653, 0.029015992834631885, 0.038208011737359424, 0.03603599400126508, 0.01809350777018283, 0.026105562757168497, 0.01644072199373373, 0.030164783155279498, 0.025393070453511815, 0.06064735818654299, 0.0298269168207688, 0.008535378512793353, 0.05540060651089464, 0.012524979521653481, 0.043857307705496035, 0.05717805613364492, 0.007537275552749634, 0.019591955667627708, 0.04586709789665682, 0.04428493743762374, 0.030328812210687568, 0.017560063894572, 0.04005410535527127, 0.0365125630716128, 0.012181158194185367, 0.033446314212466986, 0.0510368222769882, 0.07658151816576719, 0.05294647427009685, 0.04531585265483175, 0.07016467356256076, 0.023821685130574873, 0.04000240098685026, 0.034980597240584235, 0.00043848263469824033, 0.07572541053273849, 0.033935514212186844, 0.018184070142784288, 0.04811652969302876, 0.0179920125020934, 0.05240397195198706, 0.03781675826758146, 0.05502590251022151, 0.05824668771986451, 0.06307118026805775, 0.019549189301739846, 0.046827927231788635, 0.05955921871853726, 0.08323899164263691, 0.0969369648290532, 0.06931381779057638, 0.19358291955930845, 0.10165760759264231, 0.14230507825102123, 0.11678703182509967, 0.0983446060812899, 0.07265444924788815, 0.09913975412824325, 0.13220652299267904, 0.19437060372105666, 0.10419112843062196, 0.09036902404789414, 0.15611602073269232, 0.10265563082482133, 0.11862147838941642, 0.11249862265373979, 0.1355246677994728, 0.12849847839346953, 0.1514558693660157, 0.20865128242543765, 0.14686510499034608, 0.07140570732631854, 0.1478741815579789, 0.09387427488608019, 0.15282348383750233, 0.0722311655325549, 0.08408515873764243, 0.13077891245484352, 0.08977615407535008, 0.11143307840185505, 0.10532845490212951, 0.10543917824647256, 0.17482240338410648, 0.20988898458225386, 0.11417007153587681, 0.20152765539075645, 0.10138162704450743, 0.08294398497257914, 0.09639998578599521, 0.10571977283273425, 0.1384423276675599, 0.14237016333001, 0.11175424938223191, 0.11600305246455328, 0.11481853388249874, 0.13045170929815086, 0.08909537989114012, 0.17658029762761934, 0.20005029466535362, 0.10323764423706702, 0.15353138585175785, 0.1036783391609788, 0.08218932511018855, 0.09109309555164405, 0.1690637988171407, 0.0828286883022104, 0.10205814681415047, 0.10388320923915931, 0.10263524763286114, 0.14879057024206432, 0.11961946769484452, 0.15082308117832455, 0.12596632141087735, 0.0763862697141511, 0.1449733493583543, 0.19021064122872694, 0.18886402063071728, 0.14240745561463491, 0.11937903559633664, 0.18824181758931705, 0.14445728276457104, 0.13649969547986984, 0.17475144219185623, 0.1687665461961712, 0.19174915153001035, 0.23520200486694062, 0.13007079330938204, 0.14541827834078244, 0.14184234450970376, 0.28413605051381247, 0.08874552723552499, 0.10072495442415987, 0.13423197716474533, 0.07906878327152558, 0.19149105037961686, 0.10578689351677895, 0.08679084426590375, 0.22972248175314494, 0.10223949886858463, 0.08608155125485999, 0.1403860862233809, 0.17602689803711005, 0.05551854607516101, 0.22601511568895408, 0.1313780860177108, 0.09120162722787686, 0.18015439941414765, 0.1346731742045709, 0.16331500586654457, 0.0922979973256588, 0.2849577564213957, 0.1072254352537649, 0.12883556102003368, 0.1548735009772437, 0.07931484721068825, 0.23457199867282594, 0.09868557671351091, 0.0957606565207243, 0.11971028282174043, 0.07838853155927998, 0.10824588406831026, 0.22219794908804552, 0.11891349272004195, 0.11687107517250947, 0.08578897374016897, 0.15652629014636787, 0.09791195179734911, 0.1552283883626972, 0.06896596002791609, 0.1465658981885229, 0.18178079357104643, 0.1065411666142089, 0.1058990689260619, 0.12147067407412188, 0.14301109393792494, 0.06700487168771879, 0.10809547321072646, 0.13842649066022464, 0.14518000398363384, 0.16513939654188498, 0.09146854933351278, 0.14331225492060184, 0.09880107015903507, 0.1264671752495425, 0.15811047942510673, 0.21754892569567474, 0.14200498935367378, 0.06185921494449888, 0.14868154323526792, 0.2999662182160786, 0.09641579565192972, 0.18568318417029722, 0.15700787359050342, 0.08165978959628514, 0.11343342677823134, 0.11338878595935446, 0.10465682058462075, 0.12986339229558194, 0.12165021444005625, 0.15305206871458463, 0.11297205010695116, 0.13174142794949667, 0.08740121365657874, 0.1465054000062602, 0.12384041691465036, 0.19759454072586127, 0.10486861171999148, 0.11214927211403847, 0.1371261054383857, 0.2442383271242891, 0.15203813383621828, 0.1619043451334749, 0.12273196210818631, 0.11895976880831377, 0.112573621129351, 0.10222502571663686, 0.08360222500881978, 0.13457630654530867, 0.11989576715443816, 0.20649795154375689, 0.1792132713432823, 0.08009468072227069, 0.20441305770405702, 0.17018311018390314], [0.03070037459422435, 0.013686427064905209, 0.047226359602063894, 0.03583440463989973, 0.03162741627810257, 0.047593443654477596, 0.0761410810851625, 0.03427839492048536, 0.035040610270308595, 0.06805088770176683, 0.011355219924423312, 0.04936453879677823, 0.06964855947132621, 0.05806004987763507, 0.023351302603259683, 0.06243837172431605, 0.04060214451913323, 0.04225808209074395, 0.06238734589091369, 0.046391249235187254, 0.02186601489250149, 0.030087192675897052, 0.05877059817846332, 0.03124560123043401, 0.037094179540872574, 0.04452780886952366, 0.01948585993211184, 0.02748020176243569, 0.06920183237109866, 0.059129570344729085, 0.027202745400635258, 0.036714176181703806, 0.003095338715606236, 0.01115298001760883, 0.050946505873331, 0.0447614827592458, 0.02838695016024368, 0.041449512621121745, 0.030166506634226868, 0.019379501264276247, 0.010429994169888752, 0.09676429123750754, 0.04153882818562644, 0.03155511497919049, 0.04935149056836963, 0.00896704213560692, 0.03309841573770557, 0.024569127076704587, 0.012765409923823816, 0.029500066502285854, 0.021037050356556262, 0.03581019790310945, 0.030856614067618336, 0.040722536987492015, 0.036473574449441264, 0.012064268662860351, 0.06515577555234943, 0.01969847209485514, 0.02482863618726177, 0.05911231519920485, 0.027366163774526546, 0.022363187678690468, 0.04559101556826915, 0.022201063610347252, 0.033740825551961146, 0.05549568283770766, 0.04140211695006915, 0.04787801445594855, 0.05963633422340665, 0.03137477394193411, 0.007318295338856322, 0.03483081402789269, 0.012084391467007143, 0.011888557778937476, 0.06400749752564089, 0.025003470912841812, 0.03291127238688724, 0.029045743202524524, 0.018227040069177747, 0.0421563459427229, 0.05483469473464148, 0.013148679580938603, 0.029646066882248436, 0.01060506553455655, 0.07956956247133867, 0.019998823924522315, 0.026564282963850668, 0.006299811307274337, 0.010465950588695705, 0.10600012314638921, 0.04607923169221197, 0.026071683503687382, 0.014029164432681032, 0.02682817880330341, 0.052114128933421204, 0.016901620297825763, 0.025954205343233686, 0.043404751989458285, 0.027865787768470388, 0.05913184343704155, 0.010890465845087809, 0.04283694370782801, 0.010781457498004394, 0.04391166514583996, 0.039334953230406554, 0.01731885826614286, 0.008323857943261308, 0.09366072634501116, 0.06711619214287826, 0.019820403141368712, 0.029766489884683063, 0.008136671335835542, 0.01268702810297587, 0.02466583188756236, 0.03739729470440319, 0.014433657817010368, 0.02819750487937459, 0.05863788351416588, 0.047416949910776954, 0.01587116139541779, 0.08277374732175044, 0.0524006403450455, 0.06272431995187487, 0.03525998742718782, 0.10896732285618782, 0.035287478273468356, 0.08383753416793686, 0.014159935094150049, 0.03766914975962468, 0.043255922118467946, 0.027516822297392145, 0.05920565447637013, 0.06530944337802273, 0.055855306397591314, 0.011290294301163937, 0.025130758993327618, 0.03906832628750375, 0.05181480338796973, 0.02114114611010466, 0.003254697541706264, 0.012292012156519507, 0.016675030313698307, 0.055365994439593384, 0.02093901900973703, 0.09009862784296274, 0.044268689916602204, 0.022471783815750053, 0.016164515832705156, 0.08196046881909881, 0.03989172853263361, 0.04417662289259689, 0.04386924992182425, 0.028359883398349797, 0.033552274240979126, 0.043394787702709436, 0.012786274027478482, 0.042009283655456135, 0.03748828964307904, 0.04443431692197919, 0.019574127160012722, 0.028604312068117515, 0.07060724802847419, 0.024398823268711567, 0.08712063264101744, 0.04464060174567359, 0.03916166217199393, 0.021317989299339906, 0.04691383655049971, 0.03848135617694684, 0.0436831718709852, 0.02134105100828622, 0.056673768907785416, 0.006309339211189321, 0.02120970019937626, 0.0309803822476949, 0.032087578371699364, 0.025715712158541595, 0.030032937015805925, 0.006687073294805097, 0.05039076872968248, 0.0056607034140532565, 0.037818634416908026, 0.031832829184298, 0.01487120773111071, 0.04926604265347123, 0.04735399543174675, 0.03850567147934011, 0.03335254745823996, 0.009619121073878236, 0.01687796995975077, 0.022569940691547732, 0.07124900644911186, 0.02824163849332503, 0.047660225071012974, 0.02355104634937431, 0.042951249717069526, 0.023057140709300126, 0.004201319625800741, 0.012762516820138054, 0.030150116620851413, 0.030923605830009495, 0.07263386928077255, 0.03965041094592639, 0.03377054877845304, 0.02526282056766961, 0.04904121007504208, 0.08197801573468105, 0.02159422090543168, 0.03789318845208202, 0.013577841105870903, 0.05061196096773658, 0.0703756572412593, 0.031050563124673705, 0.04377573422555413, 0.06631816032209567, 0.045537720035229406, 0.02387977620985891, 0.027696644255359257, 0.04459652750353728, 0.04665410691606147, 0.008792444049114627, 0.03581743787175842, 0.059340214755918295, 0.03657122242397495, 0.020242523169144988, 0.022176481982959167, 0.028468265796878507, 0.031527135587696514, 0.03243920200371316, 0.04011128210861768, 0.02923741577459233, 0.02688228857836553, 0.031777168956718276, 0.023328929607357298, 0.0825438867988331, 0.026698091765865684, 0.06248356215655804, 0.027757781956877028, 0.07098836757774864, 0.040888808601136716, 0.02950979330177818, 0.07098889683506318, 0.020847430352919867, 0.031307795750243325, 0.035420430425022326, 0.04128455397273813, 0.01641652713130627, 0.013250367383339574, 0.06026648969522544, 0.04333322082779237, 0.05484271501856191, 0.04303993085133178, 0.025200668456298963, 0.028262343989419084, 0.030055488127150705, 0.04593246117500322, 0.046043496645454846, 0.05446085247344204, 0.037649611343762705, 0.041045353415289094, 0.03355963973860655, 0.01976471746872578, 0.03739554747673018, 0.012714447703079453, 0.0076485010130064824, 0.04875019319089396, 0.08067528956702777, 0.030398365442774126, 0.02721446200406977, 0.050538031184779744, 0.03437229738171611, 0.05035898954208408, 0.030743973861847605, 0.050371162460318634, 0.050023219880781004, 0.04645118423338447, 0.00898843040756349, 0.020247800475252525, 0.019327427094270076, 0.031317553083811484, 0.04796524013259581, 0.050379111498062096, 0.08830862532236747, 0.034493568552924056, 0.01675093632989696, 0.024259835548166717, 0.051604888401925564, 0.024395730845364075, 0.02880513807758689, 0.014157020786244954, 0.017710140573659112, 0.04447128690247025, 0.0507978015313191, 0.03551659580054028, 0.06271896631057773, 0.045990815186606984, 0.07682939379342965, 0.039687520026096275, 0.05761586728372744, 0.02255280259331422, 0.028287843335419893, 0.034262076153286865, 0.06906448331262384, 0.02405541330309851, 0.060622829145618846, 0.03807174154956426, 0.04304006316566041, 0.026593001958514963, 0.029213426169008017, 0.043642001758728705, 0.07720300874539784, 0.057478932131614, 0.04026386427826115, 0.009053082072309085, 0.019341036810406616, 0.02766591849337731, 0.010917229810729623, 0.04614148728017296, 0.028474623670003245, 0.0618484601644533, 0.031556621326931884, 0.021174027917108366, 0.04195456659155233, 0.07353297567793302, 0.049799534026533365, 0.029603926464915276, 0.014356048677914908, 0.07611448929778167, 0.02187860002075987, 0.028237624958689724, 0.01655642069610102, 0.02433200114007507, 0.02567451829755945, 0.06080464938921588, 0.020916554411607127, 0.06422787212899753, 0.049133992953492064, 0.04989493265748024, 0.042218862766666074, 0.03520504644672785, 0.006690601676902068, 0.018991866082485234, 0.056551062635013034, 0.06460981270564453, 0.05732193269899913, 0.004202849722267794, 0.07715263430561338, 0.017858268160905157, 0.008734343639974083, 0.05221193975635937, 0.03473736618512443, 0.011481956695206463, 0.10939507133194379, 0.14056236962122576, 0.12504690646060876, 0.11809222107487065, 0.11693458605025496, 0.14758698482598576, 0.11277516638594014, 0.08699983305164746, 0.23508255556225777, 0.18851536219673498, 0.1369648583765541, 0.07489320090306656, 0.1520128651921238, 0.14261276674057755, 0.1918581106833049, 0.15637682245246, 0.1115335151553154, 0.1263907179236412, 0.16200491759393895, 0.1316712809992688, 0.10917352964835507, 0.07010108126061303, 0.12834689367030347, 0.0830497821526868, 0.10606232445154871, 0.1294281663639205, 0.19925442737128052, 0.16468323101954802, 0.1285511598523174, 0.22599208621042116, 0.11647728058908667, 0.23575986921787262, 0.14268748701683112, 0.10445254761725664, 0.12705583151962074, 0.11446394505245344, 0.16621883719095162, 0.13923401518591813, 0.13272887282073498, 0.13746480297829422, 0.08481690447245326, 0.2821294596152646, 0.10984304015125547, 0.1255599467882088, 0.0873227614377226, 0.07901790671582733, 0.1681794369859355, 0.11690449980752808, 0.13827335887721606, 0.0926012753375939, 0.1421822091298444, 0.11705859511026315, 0.12322495851133551, 0.24452380037733487, 0.11040783913007804, 0.10996620104249034, 0.14611191754894598, 0.09943908985172, 0.1502204199454614, 0.16361273346202715, 0.12022026974175658, 0.11846787163189479, 0.1435964253864118, 0.12192050207938467, 0.1344206913241318, 0.15058990940451622, 0.17077609550740036, 0.14325923419424466, 0.13476211657481535, 0.16505516320466995, 0.1223826522805861, 0.12545474671891757, 0.2264208389180047, 0.11329195222684316, 0.16005517435925348, 0.14865434755172047, 0.10698134585150651, 0.0919014411047101, 0.21568443360073225, 0.11652510373720101, 0.09751649480313063, 0.14021367047514233, 0.14961503100182327, 0.08761763240077666, 0.25916286770786556, 0.18654862844518252, 0.1346398309937545, 0.13372596645993845, 0.17242925108543464, 0.14951890973108156, 0.22410436107644013, 0.15340798747326645, 0.10655706468969584, 0.17425926003072942, 0.18869001711053507, 0.1094761901934232, 0.0876404515334538, 0.13341674448124, 0.14081093056925706, 0.1637356568660055, 0.10758864826389722, 0.10338397031383854, 0.11464685095208031, 0.12752955752824033, 0.19865399173327855, 0.10235356739056961, 0.1597814533327307, 0.1817728682820286, 0.12964782172015735, 0.09427971991577319, 0.11994029262236186, 0.1281658605273281, 0.0899740420281887, 0.1585247657660927, 0.1157228582139526, 0.20021303450422628, 0.12058334025953497, 0.18473035815571034, 0.09011728077062539, 0.09979746490716934, 0.2021791711449623, 0.1332778347922223, 0.1344716085919312, 0.17653134811137403, 0.2283005437680653, 0.1623504954789366, 0.13686588725873403, 0.10639140036489282, 0.15712021184819086, 0.15678485270057405, 0.10484923275985888, 0.12337621753769261, 0.1725307870656252, 0.10902498476207256, 0.11381832576755967, 0.14393650713775838, 0.13625600641327246, 0.14723311524306024, 0.10974056779273919, 0.07068698946386576, 0.1584929424737181, 0.07952635336135115, 0.17643709959728376, 0.14949806513530867, 0.2487460252429758, 0.11555061888481889, 0.07079341768154077, 0.19798038287886552, 0.1825710425951651, 0.11953011820358889, 0.09975328549210515, 0.1792708518249648, 0.12170680426061153, 0.11577616392501763, 0.12539852330727236, 0.22458443817283424, 0.09328812919557095, 0.1194870448006051, 0.11601040778415543, 0.12487881976578917, 0.10444946028292179, 0.1328045159046139, 0.06811359790819031, 0.18459345693034784, 0.08223959098437003, 0.1783812109913145, 0.11645571674619402, 0.18757768108376435, 0.11119331805301563, 0.12724727338978223, 0.1447045137839658, 0.08741238912833588, 0.0931188143523676, 0.09494712017476559, 0.11756774064685617, 0.0993746290249484], [0.0697998320683837, 0.030463118039603745, 0.0011216711843319768, 0.03327408166868346, 0.028095429463844215, 0.015115688987342375, 0.05631488834374717, 0.03590031413893614, 0.047535316952105076, 0.01329526350101722, 0.018899027224896208, 0.03160884138196707, 0.024600577174818943, 0.040322191148464165, 0.0663815490635378, 0.0373177704002176, 0.07247249329728739, 0.014328493370807596, 0.03554518587355103, 0.03328956923048411, 0.04570217996037432, 0.06304362496095044, 0.05107521378834333, 0.02597391339285033, 0.06342338744018759, 0.010482652728179736, 0.02225924120284617, 0.0525516008159944, 0.010937562960732197, 0.029948459405984198, 0.013532867804834885, 0.07746470613139016, 0.019508897892332504, 0.01729152348291661, 0.045033402275294065, 0.018909035616421273, 0.014335080249501126, 0.01744836854881474, 0.09365744902087109, 0.014663413166999817, 0.007181783422960767, 0.06039058696478605, 0.06450326235166617, 0.019909728883898685, 0.057157455810478756, 0.019519321886556487, 0.09398329510752644, 0.06199194996484688, 0.07180859427899122, 0.05836152977177075, 0.08268777014953749, 0.04306468041613698, 0.026239162909665277, 0.04416931846312114, 0.043557893950492144, 0.015725569832803946, 0.007394221711105534, 0.04451561898791364, 0.06597223638423852, 0.010170798033608921, 0.03952940779605082, 0.026323976394321238, 0.06444916275462934, 0.04352254566869565, 0.019884595946807946, 0.030080017168074846, 0.03671573002689651, 0.04073304410225578, 0.04373823498774852, 0.01890375491763864, 0.03408004217115896, 0.023544496790106808, 0.03944635171709316, 0.08303141420973198, 0.02538376264939351, 0.06417958079172031, 0.03165800802941833, 0.016216447510357414, 0.03563965491152235, 0.10971713797854525, 0.04032407747581601, 0.04239448798554284, 0.03186899510079196, 0.004227706156338432, 0.02827525820716151, 0.06462069640734366, 0.04763996062268104, 0.044390510701175244, 0.08484968449920416, 0.028094394697940776, 0.012084276964222746, 0.08320619804518563, 0.021914092491247823, 0.02037458474348698, 0.009361658594571054, 0.028258254119594182, 0.04207139675106321, 0.03076430277100631, 0.041475252847054174, 0.021880845971671597, 0.05852346893932138, 0.04006153192105038, 0.05425136835713472, 0.009935728058085909, 0.01702529687567481, 0.01919112976507417, 0.02517012250609696, 0.035806313290127685, 0.0006371135303717372, 0.011270735529251397, 0.030450280157050917, 0.035446828829922845, 0.009306008545016604, 0.04442546882533601, 0.07219384610652924, 0.023237213725224137, 0.061553338143442354, 0.021354165393859148, 0.07420120374964816, 0.006708343671302178, 0.013300203235952981, 0.07333321496844292, 0.035089067848665376, 0.016229259947847043, 0.025954468275553415, 0.022651224097769176, 0.015560478870091694, 0.014108839710908276, 0.040108649392745326, 0.06559714222592966, 0.005632235477345863, 0.01347718806937337, 0.028846969761486565, 0.02794641299572374, 0.0359863829133766, 0.03880234734554376, 0.03488112061417528, 0.04115155432373285, 0.03556324847574745, 0.061168920913977284, 0.04760527730520282, 0.03217959111290319, 0.020209622702428272, 0.09039669470595461, 0.020521930319124033, 0.04683486185967922, 0.026571041172636405, 0.039674332698008845, 0.06334614979901484, 0.05123774667403527, 0.012337925228556352, 0.04841011143954737, 0.0070301406002337375, 0.03887016013530748, 0.004599766414945147, 0.04324726401162999, 0.05744763809655394, 0.0523828695129071, 0.015562151458912661, 0.019846733692767363, 0.019125254192788686, 0.034349088091403246, 0.04116878232785633, 0.026254876084359627, 0.031598469974207025, 0.019657890611727322, 0.043781583197414875, 0.03331750451720186, 0.026213731417166333, 0.05236747694600906, 0.028895339130290916, 0.02844567227709506, 0.030762321448751857, 0.06361463932054383, 0.0247334343314703, 0.05794523496712957, 0.04960142894248877, 0.012165806339388447, 0.01755288669041225, 0.02101595131015139, 0.01630605145224503, 0.048266075418463776, 0.012109113890411598, 0.025667537868555104, 0.07409497909247875, 0.012114436997632896, 0.026025531248056462, 0.03743361668395145, 0.07951928981180702, 0.02897259034216404, 0.05492358960743461, 0.021627536974847317, 0.0117088554127674, 0.040519878933472295, 0.026202540678371276, 0.01449293633257704, 0.10483213367738894, 0.07549498682575566, 0.03129657956638506, 0.0321464989600437, 0.04510428882869227, 0.020835155654432516, 0.014874698793781655, 0.03311678707333548, 0.024174290942028165, 0.013601743350071567, 0.0433017266249018, 0.020849750942683647, 0.03852194953443749, 0.025688896454604607, 0.06179346490119185, 0.020558805304712484, 0.02024591584423823, 0.034440883701401095, 0.011752529319242706, 0.02099589890401278, 0.04013955666284476, 0.011759336721817297, 0.015242305318159717, 0.032017913181334734, 0.0306005451296057, 0.046251976529934576, 0.01309308551052319, 0.0686791432755334, 0.06630487460643053, 0.039833422018481154, 0.03021481493487954, 0.03396168191518102, 0.03544346668890544, 0.0371824230200478, 0.040182015991636684, 0.028848801806036915, 0.06095034442842007, 0.01826389809139073, 0.10237352310546807, 0.06323747563042811, 0.035456647231642685, 0.03221667644434741, 0.08854225849998848, 0.06719150952994823, 0.02004217043785112, 0.07145328620182616, 0.04102329084915774, 0.020279969820486646, 0.04096882823588593, 0.014014469908683427, 0.007364546830233718, 0.013286981981114616, 0.04005560491766248, 0.07725503202527761, 0.038446740712970495, 0.05792417324015072, 0.053599085858357806, 0.008473297647599663, 0.10827856231480837, 0.02289336101551141, 0.03823591309732624, 0.036440780851989985, 0.03183141443878412, 0.05906309426895209, 0.012788654837225164, 0.048407013927187235, 0.0477348639230643, 0.04663036158308387, 0.061190437259418626, 0.06304232895906482, 0.010130509168707898, 0.005779720576746123, 0.024005885335749814, 0.040873019091252766, 0.022913164060030664, 0.04334768380171486, 0.05787062325647899, 0.005261941530209566, 0.007572708651423454, 0.06589246102209602, 0.02298450014287872, 0.04627028001206262, 0.06390853997852121, 0.07841149996966124, 0.0456240229042513, 0.04433196330709117, 0.022300691210797856, 0.037156028007822375, 0.017576447122597268, 0.014311199209519794, 0.014395900735897678, 0.05308966212240713, 0.024291031195649078, 0.014517331362834998, 0.021465853954266225, 0.010211930826439388, 0.08333982873175826, 0.03375094250908919, 0.02236684667877853, 0.04602240438440016, 0.012492484479610409, 0.023437685200146267, 0.038289374871445556, 0.019692573929205537, 0.02358502907944577, 0.008128637481214744, 0.03362235673038023, 0.028112211331192936, 0.02560318391104894, 0.06548510252365045, 0.04282764099272234, 0.01983019270535026, 0.03460043103301099, 0.07059834564902953, 0.021026058089254156, 0.06710548486028399, 0.03596246116129415, 0.03481595411098429, 0.021882282769573585, 0.028729990324271575, 0.03534098415236388, 0.012839186188232685, 0.009438277072539287, 0.0549371501297823, 0.014434609462374022, 0.05168315063097647, 0.012091102178341575, 0.023301959536703568, 0.055420996488205025, 0.03048738245187061, 0.06650090337331806, 0.05616495246067643, 0.02394982986152172, 0.012448272834132825, 0.015045674351443137, 0.046654992404260805, 0.025438917368384342, 0.06277879274317197, 0.02182902116328478, 0.033181736445320506, 0.009181904490105808, 0.014488720933773687, 0.06850492940949542, 0.018387747695669532, 0.023073322073157345, 0.010360735252366533, 0.016231909627094865, 0.03914199144180332, 0.028179206486259187, 0.04528693688501205, 0.01613469421863556, 0.05040763032489589, 0.03732829447835684, 0.04186435875349811, 0.01146858701083277, 0.08545610481607062, 0.1723037628190858, 0.16161173369203294, 0.05225047376006842, 0.1331609096378088, 0.14103342220187187, 0.16731473909957068, 0.20544886855142458, 0.08649152211312737, 0.15970652949597153, 0.10434361560536282, 0.08979150253747191, 0.153236630239657, 0.1420439372637442, 0.21927992281104836, 0.13041802681982517, 0.12596792275352137, 0.14192000962793827, 0.09267809907240526, 0.10417546784239155, 0.07573930014457021, 0.22449664931212152, 0.18400336216603005, 0.08324836221124444, 0.09289965432669435, 0.13810734849955353, 0.10088308701025588, 0.11183239626032965, 0.09908960360501494, 0.1121074879275901, 0.05856424889394215, 0.13002058171800204, 0.21030219883791038, 0.091725076282663, 0.14789704818810734, 0.18060466168182238, 0.10171501165521996, 0.13286980454410824, 0.09447095144007887, 0.1654383862125022, 0.09322699319039073, 0.12186449579894543, 0.17248521665377275, 0.14766074158251286, 0.12770798509674414, 0.15367381035217217, 0.12971142759280546, 0.20209672914019652, 0.13795709370502404, 0.22139563571129525, 0.11069454731685774, 0.12995194111551556, 0.06735158951154777, 0.12349680678120681, 0.12187132186123303, 0.09291627164930105, 0.15212349354156426, 0.09951881093106099, 0.1270533073693514, 0.2971092058079583, 0.10137723692293678, 0.06578558497130871, 0.0790628528754626, 0.10041984436767441, 0.12107088124113423, 0.09744101456765618, 0.08574637531169824, 0.12634380401245185, 0.26665910546268734, 0.15284882033509867, 0.05861461654837642, 0.12333288629140172, 0.11992583982646465, 0.11765316820570401, 0.15708833427301475, 0.1080052348385964, 0.17012250343603746, 0.13668926459337982, 0.0832517955984388, 0.16947917081415653, 0.26288965344429016, 0.08428668363818101, 0.1035840567201376, 0.14632678244795116, 0.10229134572935955, 0.07625470855938536, 0.11442878336778708, 0.2061296155942338, 0.14221215966556752, 0.13078812696039677, 0.1520882775740964, 0.10535865649580956, 0.10642457394195454, 0.11897081535841737, 0.20565803375627312, 0.09572854145829167, 0.11492068054420607, 0.11448067772601332, 0.1314729723547186, 0.061937388963997364, 0.12419767917266913, 0.11827383775796209, 0.08057859832687037, 0.14032736580286706, 0.08830646758100816, 0.08947011442588908, 0.18211000519139425, 0.12554231844842434, 0.09619997401854821, 0.13190901252840245, 0.15300094788627966, 0.16015231343252317, 0.14231464559478418, 0.13520524065409387, 0.0951851299032569, 0.1191018811826195, 0.1381579264998436, 0.15275465324521065, 0.13736408124012606, 0.1859674360603094, 0.12738942647618906, 0.13136366036321434, 0.1318612029509885, 0.08382852322288922, 0.10986161844006606, 0.13942943327128887, 0.11218228284269571, 0.11135029034422976, 0.11016334260680846, 0.07920601019369704, 0.2293671736759799, 0.2223723597292389, 0.07965748025370495, 0.13221686386636325, 0.11858954653143883, 0.10918198419468743, 0.15401420422962733, 0.1608564563627754, 0.09725668374449015, 0.11710549545075212, 0.09121035318821669, 0.11752075888216496, 0.1022181792982987, 0.10025373899510928, 0.21348427023206437, 0.14223871752619743, 0.15545964666775294, 0.10380841432405369, 0.09997883731765406, 0.13270644045301846, 0.08705531686012234, 0.18225925575409616, 0.1434370782226324, 0.11895349914474146, 0.14461048240108149, 0.09423000365495682, 0.12827046348580293, 0.07577843804444585, 0.15805398459945405, 0.11028818626488958, 0.1000006590038538, 0.171620193070599, 0.11413438059389591, 0.08265078320567097, 0.09376045742205211, 0.14122706252549375, 0.15574365428515843, 0.1109744022999491, 0.18573038306619438, 0.11399970496339457, 0.1363390048167535, 0.11111789210034267, 0.10170287944908653, 0.08557844467993293, 0.15094095628176415, 0.06222029735467263, 0.2205126988036292], [0.05209331147904907, 0.02580244080828769, 0.03637653037107416, 0.06074613931455782, 0.05524011601560882, 0.11407496806766305, 0.013976750995165535, 0.0387818929074066, 0.05039207830226847, 0.00912486938094454, 0.007583044436095017, 0.03495684851493154, 0.027891392287399088, 0.011491006656017686, 0.04925315048811691, 0.021470618966434683, 0.04549621404813869, 0.04697857896930405, 0.026391100471041033, 0.017239288160843507, 0.029725184065422842, 0.012411257052528006, 0.018096774916297624, 0.02997207242463316, 0.08659068322075264, 0.02100100996904075, 0.03260124634419169, 0.12449988509927477, 0.048314020702881474, 0.006890617261108543, 0.05299368334401931, 0.012820267783743995, 0.00985823935895626, 0.036450022498943975, 0.026921029535255263, 0.001719923529890366, 0.1250901019998959, 0.027673657185264995, 0.0038376994946572396, 0.04116780863010457, 0.05350509858024972, 0.026889620149242024, 0.026679601686607515, 0.015598712622054985, 0.021835095748039227, 0.014477084058203867, 0.009901088845383908, 0.01923939904996327, 0.04644983394869736, 0.09945938483412776, 0.03577496497226613, 0.022724831576592157, 0.04734819056466222, 0.007180802939858819, 0.04712044707100306, 0.03399850940331817, 0.025748337818575755, 0.03161565726622939, 0.04074203469125288, 0.08498088603041001, 0.04065983356641872, 0.05137748756845083, 0.04055412798853857, 0.037922314567757506, 0.08082230774951832, 0.04625570847253714, 0.014467828840549504, 0.04822522761034114, 0.03088863074247326, 0.03023799369111657, 0.021192614687606692, 0.030385466492069618, 0.09915487188845873, 0.04483854058863861, 0.03605394125250833, 0.024322318445358957, 0.07685996858136994, 0.030644052795001438, 0.048862280390624485, 0.03591952007263899, 0.02183799139623131, 0.03460682622556176, 0.06920363048889808, 0.029764651054782525, 0.016258040010663014, 0.017121122983683432, 0.03413954290694424, 0.03236479385356818, 0.026281786783199226, 0.04326640887718115, 0.064257653030966, 0.034679497326059, 0.02815436871190156, 0.04874236968212894, 0.017127126322260926, 0.01811175188049674, 0.03716331547392266, 0.016154480299779346, 0.0299961502397699, 0.027588643532778536, 0.033119996543973684, 0.04533436648281557, 0.016944403627089093, 0.04898807739040681, 0.019083936499165635, 0.020059639321906225, 0.021899373370355794, 0.033183900972029994, 0.011625553364865482, 0.014847072240497385, 0.027173052708219205, 0.028980685264936516, 0.007672201393039099, 0.023945090294416462, 0.03196633434189217, 0.05299132204215441, 0.027816790754773786, 0.012247936218045652, 0.043444605743778605, 0.07177580746689013, 0.027409501806167618, 0.03366631901423846, 0.047306596368019066, 0.031127414000885825, 0.00401148630771786, 0.06869232721094574, 0.034582463425717185, 0.056038734769182544, 0.019189187458583286, 0.05861927129860435, 0.0074744321838287366, 0.0251630725272532, 0.014747765247843094, 0.03142644438360419, 0.08182590853955064, 0.02843293617479503, 0.035078754116381915, 0.04178951973361628, 0.023973673582077026, 0.006706715187257422, 0.010421529445531113, 0.03510497610217758, 0.03891419366534267, 0.029814523378653184, 0.031753508440618, 0.02168558055668005, 0.020410745570968305, 0.019577046556930457, 0.05271503615326115, 0.041114798081772666, 0.04145814697923405, 0.03431433013507298, 0.01936168802369918, 0.01882779970765114, 0.011106066954588252, 0.021572886068107824, 0.050139636133930514, 0.027790614570091878, 0.01500401399763567, 0.08259911276400089, 0.036093825540904484, 0.007836335621375059, 0.01379376367133643, 0.03184145336438503, 0.027512645914352367, 0.05622056179812976, 0.043514888401010206, 0.07590624011520829, 0.035191336646676064, 0.032258850788431506, 0.05532002029940486, 0.05705153649406774, 0.05069751405556287, 0.04517306513818247, 0.015333454623552305, 0.08512774814984628, 0.05319050938955375, 0.02860042066978557, 0.012047541926481893, 0.05400572171700852, 0.034143430912601094, 0.03358644865719335, 0.026411782218409435, 0.06397152838430234, 0.06869838652866227, 0.015162662270345857, 0.03992139747632401, 0.04758325545117259, 0.03469066261979086, 0.04390590099085655, 0.036320249283952374, 0.019466840595539128, 0.03574377271745886, 0.027335314179903696, 0.032015165114509206, 0.03891765758661287, 0.06988341401198081, 0.06543795791055475, 0.036389429321778674, 0.025600064346300702, 0.012957851784969015, 0.03331731113472155, 0.04349792841821909, 0.028653546569070647, 0.07896939824734416, 0.006421855160234762, 0.02443959643798215, 0.06367561926266976, 0.020869140080841522, 0.08289390230285269, 0.02894351172393986, 0.03217524170343365, 0.03580840996333531, 0.03203626076823898, 0.0024641516585169093, 0.0573451928794384, 0.048369579150208404, 0.03978381432326777, 0.054770871730787415, 0.019460681193907346, 0.04760027650211539, 0.02260656631551683, 0.019828223257458637, 0.0247317023708352, 0.019915771238239746, 0.030867925246379206, 0.02804660886925246, 0.011924617674334772, 0.11782148560242993, 0.023050845600664616, 0.03609910115067448, 0.01758743090821164, 0.020772131625562906, 0.008521538942919245, 0.03258599287697247, 0.0090354282874614, 0.06626315827348403, 0.051794213242828846, 0.08361796702125243, 0.008878786782068866, 0.028069889405742288, 0.09498228864478213, 0.010677624676775719, 0.02163339782107089, 0.023773368348234465, 0.027879234636202455, 0.03005643468350172, 0.07096974179148674, 0.015308106251593148, 0.04586606991610356, 0.029063157803778137, 0.02607201598584652, 0.02512594309103276, 0.009336482400872877, 0.07887498009949923, 0.01341268907500697, 0.05386151945484536, 0.06615757143923215, 0.018904852448031306, 0.05241209401616028, 0.034823733514973094, 0.033412173723003695, 0.041434869835419316, 0.0355338034486132, 0.08603286636727196, 0.05584127768608076, 0.01936864131130278, 0.04148028418421745, 0.04089713761849063, 0.01721231300117714, 0.020607595365228396, 0.05823144103799548, 0.020751553354784846, 0.015908350203452364, 0.02846424208421792, 0.017806679143437316, 0.06870890382145133, 0.020716130434136306, 0.04973056433456285, 0.062250308958547454, 0.02735666258792792, 0.028148460368226682, 0.022663483529218605, 0.02281814201601914, 0.011249454974729036, 0.0178206433941211, 0.08345545788428613, 0.019247624590726833, 0.024142632194395577, 0.020384593135012046, 0.03318527500544276, 0.028883305311735188, 0.03322594300178545, 0.021912560698443224, 0.03139024793303438, 0.023253686859139373, 0.04006154888442584, 0.013045056257396936, 0.08366776470627103, 0.02691972505168191, 0.01962777892393725, 0.03458348801359534, 0.01537439742657755, 0.036413992289453745, 0.01597756925704224, 0.014296006810452257, 0.017350062395312955, 0.06026516655193908, 0.01894276219952319, 0.02939985366538167, 0.1256368248058217, 0.023483442209128822, 0.031079058202781847, 0.037349410488137176, 0.021029764586793523, 0.034839651946510584, 0.04903460453663554, 0.03234195097216538, 0.025045791141954914, 0.03690507183117526, 0.049905117468110154, 0.06741421829376902, 0.008997572818771005, 0.025088620272332003, 0.05129929319290178, 0.05472043961552637, 0.06447650093053069, 0.015217813596661602, 0.02251412609725126, 0.02311268219325159, 0.0655973254303847, 0.05121771971295987, 0.016426806936838796, 0.028633662100349153, 0.034951338810580115, 0.014179618546872266, 0.021158691329349364, 0.03655761440417596, 0.02266731046672378, 0.08681207562663726, 0.024191478234050528, 0.02584478648246399, 0.01900818824235882, 0.062476708952869685, 0.01970303863553064, 0.016714120716122643, 0.03631130958508168, 0.01363560394383967, 0.033257908786513975, 0.024920659106490866, 0.0417679762467742, 0.0061956061399541795, 0.09440275188535452, 0.14635019190609455, 0.10362252965569496, 0.14887203515640327, 0.09965723207486527, 0.23298718514186995, 0.06508993729948997, 0.1962049552904708, 0.20441393979958125, 0.0667898982231106, 0.13491721610937799, 0.07650628220289946, 0.1515278619314943, 0.08223178104630538, 0.1454964591456311, 0.08107978464769465, 0.1508437900670937, 0.09536512488765375, 0.10892655647226743, 0.10939799581787416, 0.20229237792747362, 0.08782744899924312, 0.14955095015466213, 0.09964349174073764, 0.16578876812543186, 0.11748639786882059, 0.13672936601298197, 0.21162208515618527, 0.16082810716969625, 0.0798254312415208, 0.15798082495374338, 0.15461005297090324, 0.12418241213474955, 0.2042932284197637, 0.060958106869033406, 0.1213997807353735, 0.20701954141259193, 0.10075377859175205, 0.09058915437864405, 0.11737985430019242, 0.13867221533187798, 0.08267384661095482, 0.1415202710777521, 0.06706438599420445, 0.10878772142210177, 0.1219690309039184, 0.12691324417080196, 0.12164845024900776, 0.14575266039797238, 0.2022851583148752, 0.07165685349277087, 0.09380112881106989, 0.1294315590390137, 0.09839253779500723, 0.13454788949872765, 0.06887207113738571, 0.14873626029917172, 0.060462783090770245, 0.19043519560779842, 0.15718440126095498, 0.13470587959246977, 0.16774757658796652, 0.19067660479673318, 0.12615815683134965, 0.18184510512011393, 0.11059358809143305, 0.07348044349678926, 0.09895884990692139, 0.10579285105424267, 0.12066769573305335, 0.1722817782844816, 0.1525649077125958, 0.1934796736708709, 0.09853287919291429, 0.10677718144974538, 0.1497771737298795, 0.20269744976290635, 0.13573755137622356, 0.1260296151574169, 0.12441175697105271, 0.1187310346535274, 0.1976736986211368, 0.1517232528754643, 0.14436289854347706, 0.22110676978315624, 0.14211333782545157, 0.1276864212538515, 0.11873072252741881, 0.10257833211549691, 0.1536438191043479, 0.15040019101330213, 0.19368954455213888, 0.16219333319791726, 0.143949263596109, 0.179755407252482, 0.21220692805945873, 0.09024475714457886, 0.03846981768895473, 0.08577142682458673, 0.09185446612536907, 0.08355436793395452, 0.16775247561080114, 0.1713475441294057, 0.115078154951334, 0.08113093261740037, 0.08714062228266682, 0.1214710676244327, 0.11421481413500649, 0.08535333390214614, 0.07941483613103628, 0.15839095866041525, 0.10119918933404343, 0.11846483179501124, 0.10313717355685574, 0.0820154030142086, 0.15803904325834342, 0.0939009345269629, 0.12696916902703898, 0.1416176679943289, 0.1332766812826906, 0.14827336370944977, 0.11676325595804624, 0.24881577864289284, 0.08721042318003518, 0.12957311501460417, 0.10038663686386176, 0.03480760134490473, 0.12347170098551682, 0.11432036704250745, 0.18713438058538095, 0.19926293620041438, 0.22949104702898435, 0.1011800275051168, 0.15011291285710676, 0.2354046968477113, 0.10317899845540524, 0.10131213148789746, 0.08390504840229239, 0.07697708372558866, 0.0744653031496065, 0.12490780678178583, 0.08345299480216843, 0.09325804973819427, 0.09062594454735518, 0.09756724243717534, 0.09841884459768023, 0.12036866535033498, 0.16876574552484921, 0.08120523220194237, 0.07390879586871181, 0.12113804263728005, 0.12843236194125243, 0.1646606900862285, 0.09425070575837578, 0.1320895706968648, 0.08225807427827801, 0.16119588672050408, 0.10184835057173457, 0.14549704268574715, 0.10470714074160371, 0.1586032858384507, 0.10383138951978513, 0.1558366950069155, 0.14521545065300806, 0.10943697086934533, 0.16289843964789594, 0.11025226462100234, 0.20553995509232792, 0.10381988156586885, 0.11950255611113139, 0.12953541560896806, 0.16727785393595695, 0.10101519099303655, 0.1832711821688073, 0.11265829551432814, 0.17994307646793978], [0.08093667482691151, 0.014827150452349867, 0.0481456761647548, 0.032442950909691196, 0.012310291889921894, 0.038860474047916274, 0.06768397667578288, 0.03021787852048874, 0.030644826324922696, 0.0541438918028559, 0.036699472327849696, 0.02534617011302284, 0.030729419285697595, 0.039242207671382597, 0.042680666915008, 0.028792303587709154, 0.006742859051363277, 0.038233850350869555, 0.0328149034508637, 0.05702721101364919, 0.0031945848521510406, 0.024695278611034155, 0.017313837107004862, 0.04597152443602681, 0.062156230078211853, 0.037846376321145465, 0.02641952769564731, 0.03072382476446884, 0.06202940509787627, 0.03782537905499339, 0.03716424506689821, 0.050868413278034756, 0.036736079292105775, 0.006103419948236218, 0.034220960323831866, 0.01816895916791899, 0.03158551674070103, 0.02279019315860101, 0.015434690351997103, 0.020297803417114273, 0.04232915863394737, 0.007261414596411798, 0.06683380622416735, 0.034174361931426187, 0.02164800837635994, 0.06691881309130362, 0.04047001678762691, 0.040757481540952406, 0.021411413393382515, 0.001068325715355708, 0.06461314431258611, 0.037270479902092896, 0.019425583970067755, 0.07850241687680994, 0.09939702068056379, 0.023168479824172597, 0.04497880734769361, 0.036010976415127516, 0.034425674338958094, 0.03638565666707499, 0.021922996567030038, 0.02366265857459179, 0.02780030235382063, 0.024478420515411665, 0.05391545281080263, 0.05843975807407072, 0.027214679135275737, 0.032159438622849326, 0.039464879115777354, 0.04970636099044766, 0.007129889064734536, 0.05061405085559402, 0.03776089787217123, 0.05065404710226825, 0.05520950730091759, 0.028702153425131525, 0.0475108048745564, 0.07338109918470893, 0.05201198227171387, 0.07099790778011084, 0.06857172439673118, 0.03826889668458274, 0.052490661585969586, 0.03939572282667671, 0.065878015011549, 0.055318249323006184, 0.01170237285883299, 0.04349523124151996, 0.04271984213430967, 0.008360789756157568, 0.016357301202203547, 0.030368811850036894, 0.04908876859449914, 0.05083850345441273, 0.05467984286536064, 0.06719216092356614, 0.03462862416303583, 0.02364802427057709, 0.020602173870429397, 0.0872090050418462, 0.07958331637616668, 0.0342727495091302, 0.04200862208381295, 0.054669956610138924, 0.03154334578929203, 0.027795644210917608, 0.06024481050137963, 0.020522719116083214, 0.045170435814985206, 0.052157870693398375, 0.03763064968266657, 0.029108344843345027, 0.034660959749349525, 0.010987215608890568, 0.07191551104187965, 0.036931052937039306, 0.009340001453113343, 0.02029869908333889, 0.022589655526514565, 0.03307036849270974, 0.05762539391538926, 0.03230429906398058, 0.034892275729881864, 0.018379949631967714, 0.004814395523031375, 0.023312176577746868, 0.07113341122333493, 0.026164661460955228, 0.0632253298535943, 0.03251899093655603, 0.03900858127911176, 0.06115091259458235, 0.002783750982156822, 0.040651857387274504, 0.008094031347094901, 0.08275118603238038, 0.010694448952563107, 0.04124630156106182, 0.07305919538651194, 0.01041868468746543, 0.023233563206823807, 0.016309858033699647, 0.059279635149453364, 0.05174225103110075, 0.016972471228135482, 0.06257845527891602, 0.03458510971228991, 0.051260423314358504, 0.026017668723527874, 0.016354113783953444, 0.015376392319532377, 0.051479342460100136, 0.04788654024845787, 0.031488564264561446, 0.02661663872588958, 0.029135398034538542, 0.0048349907571849015, 0.028120521688833833, 0.03088112614516701, 0.06206124196095126, 0.06747571392250912, 0.0530199935393674, 0.045148135761597326, 0.034349552887891016, 0.05811725037970713, 0.018899364796067988, 0.030079891639096395, 0.021503320961658443, 0.02454736645865653, 0.050347610509821346, 0.027844439360446165, 0.06411134052489485, 0.023176615459046195, 0.10331966555012123, 0.01141319056374154, 0.03418528295255133, 0.0761112594710929, 0.005147822118098182, 0.09246826211788825, 0.017250395779098784, 0.06614793624196734, 0.03343803269256439, 0.030224097293934653, 0.06456074105309588, 0.06424152425357274, 0.10006752184459142, 0.04996989720634051, 0.03458653463582907, 0.04528093185009701, 0.02064577822706529, 0.049290520804268975, 0.13343279861978122, 0.033954000898769925, 0.03653508364888174, 0.03447619805644665, 0.04848162903051291, 0.07745879609137774, 0.023119964570339237, 0.03410984682185309, 0.013814119721895881, 0.05745172966271639, 0.07078730408102274, 0.0656479305720755, 0.04184784321114421, 0.02514223302049296, 0.038907771331391165, 0.01726729978275086, 0.03166886119704161, 0.05286538255001817, 0.0817149341372507, 0.04539850161277822, 0.05146513393680964, 0.017023927931274687, 0.03671483775334699, 0.026203840072931986, 0.03775655524805188, 0.014458639780059457, 0.015999618252473216, 0.0025044229239158866, 0.04378747966672693, 0.02382774614462895, 0.04318037063681653, 0.011927386945379632, 0.03406552152175989, 0.04460847989789077, 0.03552973223850131, 0.05776372006429093, 0.022531742562672923, 0.010015522079941417, 0.050561009773186276, 0.06281986446785075, 0.03444326196664146, 0.026309411640145948, 0.012088729850282627, 0.022672033070453575, 0.0627287779269474, 0.02597855626871543, 0.02953023077653987, 0.05030118175117033, 0.03784235260848488, 0.048475389901016436, 0.11472398681300026, 0.04549155929791076, 0.035960954813552756, 0.034662645908870866, 0.03299877287021705, 0.012666411664603012, 0.07669048410441194, 0.036170903726347854, 0.029048901783036332, 0.05433426498036299, 0.012267671409063041, 0.05322656674044473, 0.0659949333806123, 0.07083417049476079, 0.06629593830023493, 0.06851692590862513, 0.05125727491187198, 0.004187463092551167, 0.05456658858539803, 0.03667730798146554, 0.040680406748184135, 0.0005858290585040647, 0.024603929137811065, 0.0176114731002599, 0.029055561604244367, 0.019679035459245955, 0.05878775832908494, 0.03274932982666152, 0.03867384299103703, 0.03350082093051501, 0.020348866569942663, 0.07794804698122398, 0.0439517597800919, 0.024644203583842943, 0.09290346090814897, 0.13049923389085702, 0.015481639886274934, 0.02173328326482858, 0.08695621003529855, 0.03269275018413152, 0.00821385978321944, 0.037941727454641035, 0.03541618958115578, 0.0484660702225353, 0.005720478956521089, 0.03966756431119783, 0.06562921657626118, 0.02776620936180864, 0.021934921819982783, 0.05988003007535424, 0.028372385406068394, 0.008946190754483854, 0.061485661060682366, 0.027634183410555124, 0.036561112252197096, 0.04273024746882064, 0.02882434401128973, 0.04655489491830979, 0.05930123970444713, 0.001916419531750892, 0.03698553251368659, 0.0509045384824276, 0.03814941006047385, 0.07508018479815551, 0.008516740003999854, 0.031389711890369654, 0.04518380295485258, 0.027399067633918354, 0.04073982945244227, 0.0386392139563603, 0.07210672221013478, 0.01813794163587902, 0.03821562829294375, 0.04179557905133281, 0.04589618330023118, 0.0331880637843694, 0.011724101246467658, 0.031906959135085344, 0.04633323109841772, 0.02701796674435692, 0.12892871030739375, 0.02459124562197498, 0.029504460016531602, 0.007833920884877443, 0.019914307298937013, 0.06812059360423259, 0.07570437594716038, 0.013991443822825593, 0.008244500728324056, 0.055340756329574754, 0.053167313669941256, 0.04142352133723242, 0.004614155174099973, 0.014918433768408639, 0.06160972440349204, 0.019513333815016916, 0.02405787299254111, 0.09684304879712206, 0.02580385046478893, 0.04026929595108543, 0.041323437421981773, 0.018978478586567298, 0.06995594262012414, 0.04552278547946896, 0.08486604397850377, 0.06559974101505109, 0.05111838557890483, 0.03934948405783091, 0.04666338927511658, 0.04568554228171706, 0.021673553523474505, 0.2666739246674946, 0.07476725801825523, 0.24498919397592545, 0.14154704606958798, 0.10051821837467806, 0.18991025377597126, 0.11380830380533423, 0.10161476489156485, 0.15633818666849816, 0.18375222278492792, 0.2974457863186087, 0.11040838195809297, 0.12314148513334137, 0.09147627784737519, 0.16342757482613834, 0.22808495962194034, 0.05446430282401187, 0.11945941485464573, 0.09551472828856536, 0.11450017882244927, 0.0780261599325708, 0.11158258002251387, 0.10185462702065706, 0.10809509323111602, 0.20427770353853703, 0.1462639229638236, 0.19235291198960372, 0.19860607359026158, 0.1299897219453539, 0.10289537081761019, 0.11744120743657861, 0.12708188726433686, 0.09998045223099844, 0.17135473660060338, 0.14265493090663636, 0.16505384684673377, 0.10423566746924605, 0.10703885169433695, 0.07601584387677056, 0.12598848236458643, 0.10646544889147792, 0.04180381307378411, 0.18516490555235318, 0.18192562008542673, 0.16460395098796912, 0.254889969847032, 0.14416644908487797, 0.1355152768748147, 0.11403607444039413, 0.069117721170187, 0.18733438556747778, 0.16746287686484201, 0.09599408613783972, 0.18878923250096186, 0.21756654046475887, 0.07821429733719144, 0.09861487336456776, 0.15586247933762415, 0.06888394550021205, 0.17699477395841054, 0.08289237559906074, 0.09963750706187316, 0.10440928422446762, 0.0872327537674989, 0.12174941625978265, 0.16451812987881048, 0.09669582026877574, 0.11625620030931064, 0.1013139228203467, 0.14546863920986652, 0.10069711413234472, 0.32905474305152893, 0.12367872201970645, 0.10196312477013894, 0.16908571549824306, 0.09246009934161391, 0.1710037032940558, 0.1330701895058155, 0.18881237054509775, 0.11395494879356452, 0.1332584965441908, 0.1599928577031408, 0.12280273331063134, 0.15717419609427452, 0.1767042116927249, 0.15156865545681544, 0.08594018526907478, 0.10032573834593807, 0.19814734320555413, 0.259246788918972, 0.08157920677747045, 0.11745184686567102, 0.09865573474339076, 0.19669119348483427, 0.13388781063258648, 0.17054789060992853, 0.10387820843607187, 0.14990965090692043, 0.197365955848779, 0.20761559371437344, 0.22069014928170613, 0.05559223497818623, 0.15579355375042983, 0.20333232783845492, 0.09732273234320538, 0.09819517231413297, 0.11046260369143315, 0.16278152806418283, 0.1269925513437816, 0.12479731413934912, 0.14211582126361982, 0.2086843813636473, 0.10218199981110436, 0.1313029993325472, 0.17478156914668425, 0.20649233327380248, 0.07119433688265936, 0.12176899878042084, 0.10785229304539305, 0.12369350051241261, 0.16458800541503088, 0.09833013292934213, 0.09916714658694607, 0.09430171123572759, 0.1266388310385602, 0.20043895952403545, 0.1392282069261585, 0.1655766580786024, 0.23315823024937085, 0.09597624066684927, 0.12173203219260488, 0.09620006901345082, 0.11461557048772063, 0.16059030778706074, 0.15496046202523367, 0.20707842468151025, 0.11378735064395837, 0.12340130976268224, 0.24718056353075163, 0.1719008215836116, 0.05462236077125583, 0.06679176419441189, 0.1531633348869426, 0.1292731346828597, 0.06835507495062691, 0.10708408962403025, 0.07111268197851521, 0.07517429081989185, 0.12091527959065777, 0.13678237316863878, 0.11799421347677708, 0.15010391548275948, 0.10403809842786618, 0.11785344460180827, 0.10537312286240713, 0.12951845223350184, 0.1240446288138628, 0.11948912111776215, 0.16922761074134282, 0.1180267831576722, 0.1871394288859197, 0.22012722305953503, 0.12317847886255809, 0.09344767313450575, 0.15400507114827633, 0.10771578537034136, 0.12886581011116505, 0.17155224457383156, 0.13032209553888865, 0.18718083309275763, 0.12412713867213045, 0.1496951931289264, 0.1271490893725838, 0.17677050456404686, 0.13617218019706862, 0.13764758674161776], [0.04046362159507615, 0.046208665639694245, 0.01604712418546634, 0.049932991686676226, 0.016217724852530018, 0.04266514542645641, 0.04646312305703759, 0.013118702751983489, 0.019189971166529825, 0.07995705346443824, 0.04296533949673176, 0.04833307057353003, 0.049672247642385106, 0.04817078196044479, 0.04121354528303657, 0.009232655516825616, 0.0567286997102201, 0.007057241288878555, 0.03961497784725257, 0.005666317019079412, 0.053403379395604134, 0.04296218430889504, 0.044670213013887405, 0.018379647683884417, 0.048638767562806606, 0.0840034902627979, 0.00040056888090995405, 0.026911036410768117, 0.03313301084563136, 0.024198814893939664, 0.08870400089238371, 0.07832518352993897, 0.056940141400056224, 0.022859497029068213, 0.0023108869250531173, 0.03368871745520404, 0.033599398498024256, 0.04202600275831563, 0.0648301737383008, 0.00769508329020547, 0.0034935545908021076, 0.0667953740007111, 0.0399729627450662, 0.034754689184150526, 0.026487956255940453, 0.028996444240744625, 0.006044215223352824, 0.03578089536832912, 0.015602096815460494, 0.05628088016861251, 0.06903401030493633, 0.021709449722298553, 0.030191476722913127, 0.027628047757648995, 0.07997546211949416, 0.007424196843723101, 0.05922322853335312, 0.03558302777154105, 0.062412505969405174, 0.04549482644402555, 0.0458210185835404, 0.0076477190013974905, 0.03048087190836668, 0.0539574371650815, 0.03759422931554062, 0.011158218307952796, 0.0771278745627829, 0.031562344769814184, 0.03517016296141914, 0.011937239273850406, 0.015880072256550193, 0.022064662804561, 0.06885012052953243, 0.008758212805592587, 0.01922195900364646, 0.07953452970832586, 0.07296829205006361, 0.06696549630058662, 0.060655568460268636, 0.024006818321400454, 0.05531625782272645, 0.015545115140931947, 0.07364178555352346, 0.07108355925551482, 0.011771129660441406, 0.0436622390656599, 0.034696243570319245, 0.015314928921205657, 0.03560493766729321, 0.023920126991080384, 0.02746328418808324, 0.0416243439540267, 0.05422454247517245, 0.10246194978909832, 0.04954484590728368, 0.02760295044364674, 0.027911554955478226, 0.008835452143102884, 0.04689128204647984, 0.04722808986636145, 0.04474738619423338, 0.0418130547207381, 0.014023972791619599, 0.015521529263683727, 0.01582331789125289, 0.03525295780439462, 0.01596158806101552, 0.04798036467816148, 0.031979864330164025, 0.040971722187740464, 0.039201512533639155, 0.008516716255274202, 0.006787683498779578, 0.022163331974297762, 0.018506635512624468, 0.04230661091527768, 0.01615519615422402, 0.009163478871674409, 0.04995635364736829, 0.046293957491538355, 0.04569997132888862, 0.01631469089936997, 0.009775581919322056, 0.020679537040580596, 0.09694086640541043, 0.05848132512931313, 0.04594084447515862, 0.014975931129551359, 0.06399917190096208, 0.0276756622562451, 0.025405465591964976, 0.030901119179491485, 0.05170825642666646, 0.020052892987483313, 0.03884287963488272, 0.08634296365614448, 0.037474410209272585, 0.02861660372998033, 0.052599664844040356, 0.029514264847551073, 0.03380812604778579, 0.06828021218201943, 0.02850317981626306, 0.03327619191259146, 0.01583584025502205, 0.05773936065712145, 0.06464795994439296, 0.02159419037135584, 0.0001733460966144256, 0.07932042476854154, 0.05320287569026862, 0.04200581294883575, 0.04373951063358358, 0.06942140630313329, 0.04839484100895269, 0.023751672191013182, 0.03353327186778188, 0.045923287381551096, 0.0581247956891145, 0.02786792685011668, 0.0206930398874517, 0.061713479193193574, 0.055128412188163826, 0.017172043644157902, 0.05819497656609331, 0.018440203541623693, 0.05228523171639868, 0.007753744338905173, 0.026755307534975663, 0.0888711376381772, 0.010766611999965139, 0.015595297894573637, 0.019348066433199813, 0.02313144877552986, 0.033907568747443814, 0.010062091634608805, 0.01973393403126725, 0.05598054699865835, 0.015304204675235918, 0.00944936094206891, 0.03615970789854016, 0.06408472159611327, 0.020485233448977982, 0.007731004085923944, 0.03450514775301729, 0.029479832588029758, 0.03140089754015207, 0.04591323149257472, 0.01026086846832186, 0.08692894649824925, 0.07946634372430188, 0.0445674997754395, 0.05348856946719544, 0.027900815442470566, 0.04904047047187175, 0.005493467008428914, 0.02442623608346496, 0.04125597068507757, 0.0209370275094573, 0.028872601421816007, 0.05354509821959904, 0.03147208604163357, 0.07333765258746487, 0.04412808049736278, 0.029164761637470553, 0.05249273790312665, 0.05830314861876624, 0.03900794006351914, 0.027514357518936907, 0.03310176770069769, 0.011445040149348122, 0.01335681850157146, 0.02973360807767936, 0.06612211798450776, 0.021689181881291524, 0.017481777916795442, 0.04609279560723475, 0.01760610588826239, 0.023815045665417398, 0.013135252221088325, 0.044534655287861824, 0.006732179334254137, 0.021723050956747363, 0.04313617765105196, 0.08274400713188307, 0.03059414993705494, 0.06113793221967561, 0.035431354838822565, 0.029408352316490242, 0.01615168812817761, 0.06453047160591398, 0.025918046212089912, 0.02792381269059011, 0.06776426772453956, 0.0627447913533875, 0.03986013594216534, 0.030887137965432236, 0.022765155216412883, 0.017920328670048287, 0.010299455058494849, 0.044973596198750396, 0.0511994298015322, 0.060272752573447566, 0.04681069922766515, 0.06918055351291384, 0.030947724357247353, 0.06430015646453414, 0.09066279578421797, 0.02219658697556172, 0.04150050113509808, 0.04248816992289253, 0.04616735303508384, 0.02704354072920978, 0.09963175308491502, 0.02035663918858128, 0.08690455316432885, 0.05199565671916519, 0.014798059959762862, 0.030945349484682083, 0.06807708593883685, 0.040906545506524186, 0.028817677404731512, 0.008386591898410447, 0.02512850795340325, 0.02989762356238706, 0.013738100899250379, 0.008802170848606952, 0.042605420774114985, 0.02489961264654994, 0.0354022219377969, 0.02521429513581097, 0.03358238423243165, 0.030332483085138456, 0.039927687495946884, 0.04002451444310801, 0.030128332254077708, 0.019917705063042895, 0.04423823047961507, 0.05149484359260116, 0.028991134704223702, 0.015516998346096702, 0.007675041062092143, 0.07032210725758757, 0.07358392687248332, 0.03574726378012981, 0.032617303875408, 0.005705137703833836, 0.03304539840402348, 0.025421114305832555, 0.043994344637862275, 0.06146358831652573, 0.020550053899309466, 0.008664396009407938, 0.014680990616657903, 0.07289786690047809, 0.08090679214469024, 0.03631550293149693, 0.03245241308052625, 0.025288688018918037, 0.05841896776109934, 0.06000653614423104, 0.02447172167844006, 0.04765436592112694, 0.008841975409138416, 0.05104168398039682, 0.05853295485888209, 0.017796926898881793, 0.03126308029251439, 0.03494210394897631, 0.04215935185285551, 0.029775677248835564, 0.03877965034916997, 0.07589321902820043, 0.039846999504204304, 0.02371108901154782, 0.03806578740477562, 0.022273230898593153, 0.013479937832536442, 0.0700351819396019, 0.07124132543270077, 0.047585827098893266, 0.04291634248303516, 0.07971301155963115, 0.013967983474555825, 0.024029991988624846, 0.05804682523012161, 0.007777113933116198, 0.046265859356416125, 0.015195145438026105, 0.06087540702096053, 0.015208599091108357, 0.0011041374153657152, 0.012486560868897607, 0.07436530744390828, 0.036450809599565606, 0.016044547448733022, 0.07382499679390873, 0.013030064874328673, 0.056596768753869195, 0.009370287863670715, 0.051527084184012244, 0.029979095262076174, 0.02107288039821599, 0.06618452285017286, 0.033709416165947914, 0.06544158128755433, 0.02415167197718152, 0.05009313612910254, 0.04305437007652862, 0.03174312685483268, 0.01814239621827645, 0.022678521561569402, 0.09606744934405599, 0.11502677627972194, 0.09693545169596161, 0.08097691873886756, 0.08578165234731776, 0.2184007449873856, 0.17922418218638214, 0.09346004961324589, 0.11927812386836324, 0.11202177538403443, 0.09910233970731497, 0.22172045042472227, 0.14977538239743027, 0.10947266181132623, 0.14207357567335877, 0.08169014046766929, 0.10410911390291792, 0.11345828830131463, 0.10783518039222274, 0.10694300183760268, 0.11218511911907367, 0.19406055392963545, 0.09222530586911099, 0.09880477496023689, 0.14577792904206685, 0.15190637590629713, 0.18956325096743448, 0.12717373376446112, 0.12946898703064236, 0.13444258086383343, 0.1300504236881222, 0.14915568993559905, 0.1362674736550876, 0.09347996461604323, 0.1482399526451315, 0.07198497945708887, 0.15087844963584626, 0.20202378662569181, 0.14633370350514138, 0.12037496215530805, 0.07511627607579742, 0.09215359150299005, 0.10178829343723399, 0.14039645423846586, 0.12075988150068692, 0.14682687632739544, 0.09044124052992888, 0.10534712140049253, 0.1785407888570002, 0.119370716757008, 0.19386341236531734, 0.1235748790204525, 0.15531844353037222, 0.1392304596624204, 0.1770708920168025, 0.06313052494078875, 0.16584009251424245, 0.15225971623190812, 0.2731208758694785, 0.1582028144704444, 0.14977603379104817, 0.1339183175670249, 0.06867711445582764, 0.14708230404981545, 0.1275839488953352, 0.09962022477494818, 0.17679103703371116, 0.10526854025998286, 0.12840432487428188, 0.13096373182322296, 0.1235050984791347, 0.1436327677220106, 0.1567673600677933, 0.07285879685410432, 0.1765747336404664, 0.18260958338422434, 0.16438667050429753, 0.21635815102074826, 0.14816004836133548, 0.07741598053170101, 0.16013957054487296, 0.11545611252742154, 0.14557035160916193, 0.14023694422628197, 0.10336868970521859, 0.19780361093580723, 0.1138508343803031, 0.11198932105409247, 0.1260730821107115, 0.11470292508602142, 0.13120074410523686, 0.09832982758858375, 0.13605293445289135, 0.24342375940510205, 0.10077035520225763, 0.08057583668934447, 0.07526999818427221, 0.13248852214642934, 0.10702440568378993, 0.18646386585065297, 0.10278642523501601, 0.1728524398058653, 0.12375688925385475, 0.09846849300499473, 0.10704419855028391, 0.09307764084743601, 0.1523297003337315, 0.16813587503773825, 0.09164471059505429, 0.11370889163975205, 0.08524330944887229, 0.16076912890587533, 0.12403237447142601, 0.1757042682064431, 0.14702667774898664, 0.19817661520625862, 0.09101223453347172, 0.07556550018489361, 0.1426071213292224, 0.20680231521172182, 0.12698776088654995, 0.11732261308601924, 0.15247498825192451, 0.20032405640397752, 0.1890249012836388, 0.09019297135195561, 0.15179025142320565, 0.15322377878640378, 0.10948800348809787, 0.12820592123482907, 0.09477091820112296, 0.09995762631297112, 0.1426863470779998, 0.14027999048786505, 0.08934385941496917, 0.2005967324865716, 0.12080831533031804, 0.13411288069827215, 0.14409643784165382, 0.10082041073058333, 0.17181831172534398, 0.1310046881969486, 0.14986189561230795, 0.1006601271884782, 0.15117581082241877, 0.11549130135348865, 0.21650479600897857, 0.06901522845562015, 0.18895807915500232, 0.16185417425419601, 0.14407534897327423, 0.1354837114257472, 0.1068934416398406, 0.1477870305201837, 0.09340658783912659, 0.07926211825438909, 0.06665955164602824, 0.17524956831974642, 0.1298628630382674, 0.1089246633595654, 0.10386709403246641, 0.1221932867275817, 0.14255259425512382, 0.08004466590604611, 0.09456066055489437, 0.11746241844126157, 0.1123684389250619, 0.1801314920719181, 0.09803091934216873, 0.17864186343337807, 0.15219419689050742, 0.09780337940901518, 0.14424468417252811, 0.14228411151894502, 0.1331123129597732, 0.1063084766002638], [0.017587583578590835, 0.004128257519498999, 0.028511172958782742, 0.042948030068406036, 0.010869064850599637, 0.07383639618222203, 0.02465139944771571, 0.0478227172446038, 0.076073057949543, 0.03282179058130298, 0.027636505696656447, 0.015495485393330455, 0.02561567913341735, 0.022497593591521894, 0.024567551179123775, 0.0465673392505518, 0.06447682662733964, 0.012866590521298349, 0.02639446939740862, 0.01774686119253082, 0.02186276131708707, 0.00145983586220869, 0.0206062382951911, 0.03249332534947565, 0.006349720102402249, 0.031097795947321823, 0.028425730132896985, 0.01602850348821708, 0.05768322545502867, 0.04514627657564623, 0.03953866979905537, 0.012448507776883031, 0.047888270512755425, 0.025962095009163022, 0.00800045034182923, 0.024677192260112082, 0.03753334776099239, 0.02033164874384446, 0.031942595794264755, 0.03828501867662583, 0.03191965791795935, 0.030727461712168794, 0.02045149159883814, 0.012188689084723592, 0.039579599031380246, 0.03023583594975727, 0.027331868918346505, 0.031951990111597946, 0.04215315682813525, 0.018546282313764095, 0.041951811739376614, 0.04037700659994568, 0.006705195692900036, 0.0709437064028212, 0.018538645402129208, 0.026532474938513975, 0.04485820114080395, 0.04628808477095195, 0.02789743973075279, 0.04895762473876987, 0.045706519191818576, 0.008925779572954136, 0.03517492627725005, 0.054645281684185774, 0.04409932079059737, 0.04346260388514825, 0.011752599717250891, 0.02547734959184059, 0.04770023149571248, 0.014430178628702248, 0.021994129089372497, 0.054749840537884405, 0.07888902577438525, 0.03791225867878113, 0.018073458756719316, 0.05043714999088219, 0.038701293125216446, 0.03948627671759043, 0.029369913307683806, 0.029489617062998668, 0.019529135199263692, 0.016830435189019357, 0.016574049035885503, 0.024754501147461788, 0.029219722973981073, 0.06900890450924635, 0.00959024262348456, 0.04704720939376524, 0.09252173746270792, 0.0440812853298017, 0.01775111730343529, 0.0690504512084382, 0.028359157365879843, 0.02279252223005252, 0.056617735485945425, 0.04060584253498486, 0.02048286366542535, 0.013422962095189308, 0.0963162002818925, 0.05638581560924649, 0.027704596685777818, 0.029970365909061263, 0.05432319128885865, 0.04349700900326882, 0.05315974461180823, 0.03684479417279363, 0.04241375498739736, 0.020897156791761518, 0.01626344963109919, 0.018547101644799113, 0.02093775863093989, 0.012240819233868803, 0.009113319866758372, 0.0886622845594372, 0.09228150892470564, 0.020111257177112356, 0.008787110763868051, 0.025364855271098868, 0.04160244084362473, 0.034995640361947675, 0.016026123526639173, 0.031571070730154, 0.07016514175172363, 0.05299476560737405, 0.09711601664977414, 0.04563770217022725, 0.03064979998660939, 0.0796655887471778, 0.04524066418941532, 0.05560476751998067, 0.024782762130988494, 0.07018931116908789, 0.022547484575105563, 0.020244777601744448, 0.07537236197718553, 0.020229118709851588, 0.036151409415262084, 0.04570712308798518, 0.034173028610114536, 0.011162215727381408, 0.011089662522343653, 0.04658275556617549, 0.03426734158503158, 0.035964167676866055, 0.02397905266843736, 0.025457331112452915, 0.03182105320904936, 0.051683537395937104, 0.018147900833615234, 0.05915019780929599, 0.07879887561180762, 0.024780146378491606, 0.010460685156950993, 0.027818522715408887, 0.03349999311779227, 0.06478802314294235, 0.03325387489582811, 0.0038502523925022353, 0.039581638029111285, 0.05938208715191909, 0.03084054635837674, 0.015053904981219342, 0.0636398061843855, 0.0495815851858684, 0.007702672704389053, 0.020590316470978514, 0.06967530732176133, 0.02434411638283304, 0.03898855431803635, 0.015805533488414118, 0.024491921665945222, 0.045034314904894145, 0.01205844004705016, 0.057281519153288434, 0.08016480053109781, 0.03461778795878802, 0.05631540063768625, 0.007604827954699951, 0.054154470163796625, 0.009117548836262097, 0.02395013689861766, 0.03216268880558865, 0.030173858561153923, 0.047281656813408644, 0.025912373659334013, 0.007147645478003791, 0.014231864895139421, 0.030222499343965734, 0.028793999925255775, 0.026537353605298058, 0.028232542731400048, 0.028602113614657095, 0.035380580063377104, 0.008197010910537626, 0.05211429517450077, 0.11374840273388795, 0.03597817263965096, 0.021088627499661276, 0.03264302374528987, 0.017698340849684815, 0.03778451767617038, 0.04518734151497483, 0.05491911806166172, 0.029446404560336044, 0.020901745384825126, 0.03961383790842124, 0.01421523145732603, 0.0280402391217649, 0.054271690480943234, 0.02996482906330909, 0.06354588336710419, 0.03551819375050919, 0.012972937314771116, 0.05130622103544218, 0.04061803241659488, 0.022096584484513317, 0.07205900762762342, 0.035077088312911134, 0.04830356787091919, 0.04730814342786159, 0.017824636572705846, 0.0316873410982745, 0.02589865368125694, 0.023119523522577116, 0.0668499960697123, 0.03762970991166575, 0.0251879238723112, 0.02112104111750211, 0.040777162449168305, 0.008487836108542979, 0.021797040111518333, 0.018634720871757184, 0.022210888797417283, 0.09690498547362429, 0.0467853220179677, 0.01581216786455895, 0.08237173567925181, 0.0008604095450469426, 0.024523117313427583, 0.03511429578065872, 0.03969389146992138, 0.010834235648092414, 0.08038543297776155, 0.07171188946813345, 0.05719946391348328, 0.08461183761911732, 0.04481341443689806, 0.013633775291964412, 0.018856481382889406, 0.06128815308745418, 0.053959181000079424, 0.03203395714185067, 0.06184322865945952, 0.032678850394274504, 0.04928560481805887, 0.03675638784521392, 0.051048245414027145, 0.005498423706740141, 0.014237415311591966, 0.02973669541201421, 0.0662338455606784, 0.0033689346372349454, 0.024946974390851598, 0.06004110750343118, 0.046396711442087374, 0.004613829477291022, 0.031001169167991196, 0.08643958704280001, 0.0360397496925933, 0.041627685738993545, 0.0550825398282281, 0.028148212702944875, 0.01049260514056576, 0.00684027759624379, 0.01614575264310198, 0.01282798866408744, 0.047719715628772974, 0.011644900094584694, 0.012881560700147279, 0.018499719544446895, 0.03947015133287225, 0.022558174894324372, 0.18655746297112533, 0.054409158283046315, 0.0838522787338921, 0.010259016915889723, 0.02620401988471193, 0.04602777498907276, 0.04424586060589977, 0.035444172365324836, 0.018110177679253475, 0.062344937452248166, 0.01628053853554385, 0.01541097555309534, 0.04113598194505487, 0.04135186464658805, 0.020053344213270714, 0.021404029236042073, 0.034386631433985064, 0.0700114332139492, 0.048102979348706346, 0.06283512472042016, 0.053109970675515275, 0.018592315825766752, 0.04834278380232198, 0.0779253499848502, 0.03981163086635726, 0.04053584825513618, 0.05817710395370211, 0.03465486650488206, 0.05567042935373528, 0.05154145894838231, 0.018888501450419426, 0.025796523982925073, 0.024025072609739642, 0.021363966832203523, 0.07563056490783181, 0.04118178305881364, 0.09778409544378519, 0.043004711491188834, 0.02666834139797304, 0.013635021251892405, 0.05347285459616354, 0.05350147520325013, 0.15830870664545468, 0.020653433798413192, 0.09048138944698231, 0.05803035718521901, 0.02662237573947225, 0.01762893859163991, 0.055523044762334654, 0.02921424380370549, 0.024988405739090273, 0.038122875948569605, 0.05008652041267071, 0.01954641070083848, 0.06586002704820462, 0.027169568430898444, 0.07204743860555546, 0.05088403654683914, 0.06867075658270291, 0.006264826041712824, 0.05348008099411215, 0.049785461210246594, 0.025564117257350256, 0.05919907268668924, 0.027529342964823757, 0.027936501295438836, 0.01931367488577962, 0.056012061557599475, 0.06438986557934966, 0.020479615179023573, 0.14106415983821663, 0.0854585746835385, 0.16077880481524126, 0.15970898579273904, 0.0916650870016643, 0.19703309371003083, 0.10890063643455505, 0.13164476385074003, 0.19266611018351146, 0.09792753096137728, 0.12511024091924938, 0.10780214252216475, 0.07774640672973224, 0.0970136732129114, 0.11070588563701936, 0.13414877520075866, 0.14741807031844342, 0.14972534722515515, 0.1115191098568695, 0.15115597045847348, 0.13591095778558934, 0.10366231894918851, 0.16586935094424657, 0.10625985278082745, 0.08413448144814797, 0.16571562205042156, 0.09358122239687613, 0.0833536640607885, 0.11954818080578532, 0.079219981229731, 0.10424997777278934, 0.100647167169622, 0.12492931634187698, 0.08780785290790455, 0.1413863961185728, 0.14639015761869295, 0.11228448378720454, 0.2098681806985821, 0.08126065494226557, 0.09370620176196098, 0.137089111709169, 0.18522148180220807, 0.10391284764877387, 0.11722600327006408, 0.14018138577895506, 0.07865227812102862, 0.0779357383559857, 0.10672868655196258, 0.10969631373882294, 0.12200381260897432, 0.15973719927881444, 0.0942101836470621, 0.08375851876501526, 0.13241701812616416, 0.06531788435365472, 0.06653871812990733, 0.30383221219692913, 0.23651201171534403, 0.20070011408201285, 0.14799467580659048, 0.22864735658679688, 0.11766141919153077, 0.11756077887756483, 0.1396379199411188, 0.11611476647002356, 0.0913988027189459, 0.17080413257437094, 0.09152276428150279, 0.15909571227218422, 0.15976632200181484, 0.15957015752792358, 0.1262487412563392, 0.11221635887133223, 0.10450923921806471, 0.14482055684285505, 0.12000962533056736, 0.15148392000368663, 0.12349059140043599, 0.1421805535043989, 0.08126552682369947, 0.11089508155626909, 0.1102167908102274, 0.12512140960565635, 0.1092223638136472, 0.13083348024104322, 0.19767863835607255, 0.03547869283439858, 0.25460680361304966, 0.1455629420067583, 0.0908528466575912, 0.10298481530376843, 0.21398850317512239, 0.19591291381844453, 0.16065579998706067, 0.06860136959169592, 0.14994509757629462, 0.0994734780064651, 0.11351736156003815, 0.16693873570433684, 0.10118717247886316, 0.10852357452469212, 0.12912089856607573, 0.10206893552094698, 0.09148308355361223, 0.06828649541629211, 0.1751945119883333, 0.20754315331578255, 0.17501839143889292, 0.12796717190316745, 0.1556178131805999, 0.09400490644787039, 0.09916409996471234, 0.2991892956197262, 0.1659189789955105, 0.21194531209766865, 0.09407014758991343, 0.1595008655318192, 0.10854948099170413, 0.2024138221251113, 0.15745884153459752, 0.10247900815946714, 0.1087968477181026, 0.10368930428688015, 0.15520214262817586, 0.16021654355738843, 0.1270693072250911, 0.11619252658316068, 0.20122273532407625, 0.1330929339996406, 0.1520840706569808, 0.10530269771282162, 0.14081520533987454, 0.11970653730843749, 0.12171215111655848, 0.16470809254263127, 0.13570107333362103, 0.17247075028717518, 0.11646130787474768, 0.12908196422670568, 0.13660545194787638, 0.16418705907251152, 0.17247075028717518, 0.11460381826119763, 0.19960774055549077, 0.0879594919138721, 0.07923465115683419, 0.19514182662325247, 0.1150193666773183, 0.20130741649440356, 0.0856730935296842, 0.17941210924514703, 0.1114530341167535, 0.16563258293483937, 0.08228894762162652, 0.09051974703158651, 0.14379218273929187, 0.09508588737142937, 0.14483929798007011, 0.17902883195451327, 0.10876741286899362, 0.08072798459657601, 0.12748085228460176, 0.2030416570071663, 0.15306063182651997, 0.1202396894139903, 0.08884481726480381, 0.1312925906053611, 0.1597254741936922, 0.1282450184226036, 0.1266708036086389, 0.07306580431759357, 0.14174907308604034, 0.13152327894100121, 0.19118739238807134, 0.15360690679933342, 0.09935999980994634], [0.018935702042654157, 0.037998076395264695, 0.059152742315615923, 0.018985325004905462, 0.036504183164132495, 0.03425918559410742, 0.023403887370867387, 0.01765395617777748, 0.007273043838462659, 0.03533754058714424, 0.035938726006341834, 0.017846239431362067, 0.060903294810226986, 0.06802534085831471, 0.020359850355557034, 0.07076892935271774, 0.0169861929025501, 0.011168145275275623, 0.0393777518267078, 0.11242589727044106, 0.08075839653611183, 0.03371668327599764, 0.023239356199545518, 0.01671161183289119, 0.026254682701879313, 0.009218310438362616, 0.048469235588397296, 0.02466862914817674, 0.02824518723147256, 0.024627542156460028, 0.01635069227112191, 0.03610712482726999, 0.05915783132825579, 0.015639246607731496, 0.028122599702328444, 0.043968750296958854, 0.0706313903044377, 0.03179736555154834, 0.03142105003020593, 0.10733148349182946, 0.033511304296553135, 0.028028773576287285, 0.016491369543863193, 0.05840188903467996, 0.06782798216279064, 0.043947196632091484, 0.05092806668419923, 0.04294613017035382, 0.02946760199431862, 0.0028877447434102316, 0.03963025506319744, 0.02075961943981903, 0.06253802137715475, 0.040129022406680245, 0.038901874862079105, 0.04921516949044807, 0.06701805562313114, 0.023220482748001814, 0.0374899690172502, 0.004833135387993285, 0.050617277289607694, 0.03131424861827067, 0.028744242952338288, 0.02616582514851221, 0.09989868197590113, 0.0532745255955628, 0.03020846384710499, 0.0486511202928211, 0.022713752796075175, 0.03148816053622535, 0.0494828820893807, 0.03196452943874257, 0.04912105329068644, 0.0033169011793298914, 0.02793342074645417, 0.024001707256372486, 0.02400894383234637, 0.0638885639075722, 0.0552179347058492, 0.00912068281987948, 0.028476235190672532, 0.03749764324831111, 0.03698675387672015, 0.04558331758848258, 0.01852215191216341, 0.027365812632654394, 0.048031926554228575, 0.0667741426399776, 0.00019452756116931726, 0.06135037474866424, 0.04016841814986297, 0.04908360494300723, 0.06018390519810574, 0.02897885661306126, 0.06359883623995952, 0.019343581316726546, 0.045249193374599726, 0.07108200541032211, 0.09067748606737171, 0.033947208763233254, 0.06152262764849833, 0.04844056409118431, 0.02164608472958207, 0.013319390509942812, 0.08887064909296376, 0.020203788997605443, 0.03354407075260367, 0.034412490403545756, 0.04956423504544156, 0.04721327744690435, 0.045539107639342546, 0.05110898447622146, 0.022540068187351738, 0.05693953750388963, 0.02646793608021523, 0.012138217105530202, 0.043503679002502134, 0.06048155136938606, 0.03723464307508298, 0.03147728701255151, 0.01765444641932845, 0.04910484648176602, 0.04798088036477566, 0.020205400518274734, 0.030143232883087227, 0.047252815682440996, 0.020123962745336548, 0.010689234410944794, 0.03133962582796812, 0.009750448134062546, 0.03695363797513502, 0.028128145029768348, 0.03110359063638108, 0.04803890867957047, 0.05996178675975118, 0.043813793254750114, 0.040656023592289, 0.01300238149373659, 0.011640616842279477, 0.024120854612972056, 0.04876880540645548, 0.023445184708439877, 0.019856202648952603, 0.04735890123993158, 0.03269842952223761, 0.04045006446540356, 0.05009297328069806, 0.052038797975650856, 0.020825795263850262, 0.048278886159615855, 0.04870437511375972, 0.06839411785559994, 0.037509653318141184, 0.015078851321179951, 0.037488516952310286, 0.009923846061740602, 0.006762394074550164, 0.022161376097106507, 0.05656161046187792, 0.012436242408252187, 0.04833077033981681, 0.020209682074242404, 0.0342492552341095, 0.05637235347447651, 0.06130709778517485, 0.038651905953884125, 0.06548884803695337, 0.054122833468552144, 0.034280915678079636, 0.024996548159314052, 0.03121261764317751, 0.03392903759543385, 0.0385484497195908, 0.0021547757371860954, 0.04638849438301154, 0.019753881264477968, 0.0106284724481936, 0.05112803773954511, 0.01372546742537192, 0.019746246049180627, 0.042794101006750546, 0.03140116895415953, 0.006057628588418343, 0.023557434756574885, 0.06513809292976346, 0.05749006010591984, 0.06087168864905834, 0.049752033182552884, 0.03357983972611172, 0.10774631944618054, 0.02519139627526913, 0.05126839270815253, 0.013063322420098951, 0.05710846558213234, 0.01226905731683863, 0.037940492520907095, 0.10757006997508661, 0.06387045380792447, 0.10839683096855879, 0.002815706376817876, 0.02634653089834111, 0.020126498769968748, 0.03840011178648897, 0.024037767999938557, 0.03696636050673468, 0.08568488646830831, 0.005377893835040075, 0.044185515094016276, 0.025395029723378162, 0.013912356325558253, 0.03593521458762033, 0.03740687222619142, 0.005047633878088423, 0.028826386401695863, 0.03283179558015295, 0.03099843467186604, 0.03734294744208455, 0.057601421273180416, 0.05280297429167798, 0.05807601580662387, 0.08654007807906185, 0.06683645929609026, 0.036652792511241775, 0.031011099527989115, 0.044917036912270954, 0.02923991617613605, 0.04281565127894282, 0.029875981687967266, 0.010966068216865616, 0.03814527438953519, 0.009635321097448468, 0.019042756208883863, 0.0458551081828773, 0.02144911788803126, 0.05121731259194868, 0.018451831935505782, 0.04790304561278649, 0.03896431365449514, 0.015480625476422054, 0.02652987275671746, 0.03625899114246879, 0.02744602904255901, 0.05719520949891635, 0.062276629331920824, 0.03480798132451517, 0.02923539713291185, 0.022909801919013262, 0.0470153521746397, 0.012425668288155325, 0.00867826780969543, 0.03968873799645475, 0.012355557809184705, 0.017578257114759514, 0.030280581941562038, 0.03078221609549863, 0.040190022704856734, 0.051463067797677856, 0.007146847351188106, 0.013694723003676959, 0.03791463015867131, 0.01780802264277424, 0.02235536416992545, 0.05086273054725357, 0.08334292963679348, 0.06478163812841688, 0.054632939132196565, 0.01893915917857417, 0.028508960934621946, 0.036280551592686346, 0.04956238264484065, 0.057348870539239476, 0.05266971679936562, 0.026161092366757135, 0.032412321838949404, 0.0323882270604372, 0.00976614434538143, 0.06625002183552299, 0.06270287824528557, 0.01855752055001046, 0.038268194400838444, 0.05977229907044342, 0.022583935476307358, 0.033392251934856176, 0.02384917936953051, 0.0434334608060973, 0.017236121098643968, 0.12004261570317404, 0.06584942833121334, 0.019291693743850504, 0.003222350717156327, 0.037827292523745976, 0.005542574708150434, 0.03495506736050759, 0.013029103050939739, 0.01777550045933042, 0.027825937406825166, 0.025437321114752973, 0.05607529762866242, 0.012715015127988798, 0.03361068253538438, 0.01695088702919228, 0.11870371683367661, 0.018431394460744092, 0.03468565842402833, 0.009852668586453157, 0.01190252966314022, 0.039657087730509896, 0.015874374258731092, 0.01249230551599924, 0.02713279692190034, 0.02107633074878582, 0.08189693079995257, 0.041811863891780376, 0.046587892076266665, 0.030999829061329365, 0.04368732789797442, 0.03699736955708691, 0.011473417331996773, 0.018822505438168134, 0.03399170369708112, 0.026267228814374124, 0.05012359556608966, 0.04496843593993357, 0.04672988909961922, 0.012831284647940524, 0.06256849438484226, 0.008680492556387824, 0.04240057444466012, 0.06561420738164868, 0.0347119787974017, 0.018402273434081247, 0.0271843503162797, 0.0292965704575181, 0.03742570157295891, 0.0879240520298481, 0.05016701502193298, 0.024417540657200983, 0.037445229810795615, 0.07212143284933907, 0.03489151916333607, 0.026675471104681492, 0.06251408944704703, 0.01813899166882038, 0.030910628847777843, 0.055492120528859754, 0.014917436321931226, 0.014791781814502818, 0.030566940682807138, 0.010738958305280124, 0.06453430532876935, 0.04498200324763145, 0.02235454653522798, 0.11496773016239915, 0.05388753448746034, 0.15308689113174165, 0.0860694461901273, 0.09951074993503944, 0.11517287843993732, 0.09620332598154034, 0.12223341528858457, 0.1463831551373005, 0.183380982705525, 0.18360978471381323, 0.14331268918301376, 0.16782518742339952, 0.1509948998157467, 0.11250826463635479, 0.16029722137110575, 0.1262793160442795, 0.14701081360025064, 0.08180259407630988, 0.17312726005911827, 0.22380397362368448, 0.10484283417463303, 0.16036895609327725, 0.0746428214811853, 0.11222633333610636, 0.06500586681067944, 0.10821845768285648, 0.1379543931356498, 0.19390009396842547, 0.17796016644154275, 0.09660450302596603, 0.1771475529032094, 0.13877418557448046, 0.15460070275834628, 0.17639167846313544, 0.13846382365695067, 0.13234464558107512, 0.144729008898139, 0.12070071324706078, 0.20660015248826571, 0.10902259631880692, 0.11912151798605919, 0.1013569962233305, 0.13967679999768734, 0.17728423699736595, 0.15438255374985083, 0.14217516593635082, 0.08151205216667481, 0.17355795337685517, 0.12206243803458554, 0.09690835100731679, 0.12798129900225572, 0.13530748231070383, 0.16626428546650068, 0.1084299570481692, 0.08186476824006864, 0.14308358861931733, 0.08123867040766136, 0.09648316060858113, 0.12742975859769753, 0.12255913923893656, 0.13063806215567247, 0.08767770989132778, 0.17224251824830258, 0.11043152000222888, 0.12289893600557532, 0.10872119106352329, 0.15137467586568423, 0.08925256252821002, 0.07974939460733108, 0.17196948932749884, 0.11147109671894993, 0.1048391836562327, 0.10200109558978251, 0.14975579987679208, 0.1395127573715789, 0.14377942628094129, 0.20531447790563107, 0.12121550419500896, 0.18151170015335083, 0.11587806631411825, 0.1840878262051514, 0.10178062599152327, 0.09232980704733304, 0.08599311778587954, 0.12015385473413126, 0.08163910784891673, 0.12542491831949779, 0.10074492370975868, 0.19564072628106388, 0.1725999569254262, 0.12798186897167138, 0.16763329772012575, 0.19650041657899106, 0.13789455991770538, 0.1465660338955266, 0.20170714147388935, 0.16819778457283974, 0.2770733152117048, 0.15283197909593582, 0.12920287916702883, 0.20855330196874483, 0.10556854094777789, 0.13778347016445228, 0.10236978437751532, 0.13966795190104417, 0.12840812467038631, 0.09648662792252642, 0.10170569536941391, 0.07890830295426504, 0.20882474311760493, 0.1368331140173333, 0.12849078380635806, 0.15313202728118214, 0.07524185933704887, 0.10748074083988156, 0.1498572544327804, 0.18696435328040803, 0.11978085046367985, 0.1466839632817677, 0.10243303741195373, 0.11950266467673437, 0.1392401491424867, 0.10924605147114821, 0.08784664475492068, 0.18241620090390953, 0.10950310767761298, 0.12716291791626386, 0.09746586930538927, 0.1155881690127509, 0.08692717552185059, 0.09361787685858351, 0.06803802946316344, 0.09479940988655601, 0.19683207092540606, 0.13563077710568905, 0.14041724455143723, 0.11104813870042562, 0.07285857293754816, 0.14971812761255673, 0.13811915500887803, 0.11549793742597103, 0.11815016796546322, 0.15204490561570438, 0.12255623510905675, 0.1448474404002939, 0.1580259475324835, 0.09840292616614274, 0.15750365198722907, 0.11850128269621304, 0.14870390774948256, 0.10666606455509152, 0.18665887681501253, 0.1368660365364381, 0.10491317111466612, 0.11109461156385285, 0.09367807648543801, 0.06537732402128832, 0.1389011394764696, 0.09840589136417423, 0.1356721134590251, 0.15075179428926536, 0.12653106610689843, 0.1587704090135438, 0.15467089042067528, 0.14416233716266497, 0.11728452013007232, 0.14879948619220937, 0.10055287794343062, 0.06047784656818424, 0.11035522552473204, 0.12470176283802305, 0.1372346846120698, 0.07299707550555468, 0.12666264761771473, 0.07814157195389271], [0.03798623595918928, 0.052128815823899846, 0.06145302352628537, 0.04900402635602014, 0.0474307309570057, 0.03649979982791202, 0.05012750392779708, 0.0326000860493098, 0.03162987257487007, 0.036166303258921416, 0.03428313448759062, 0.009281078320262688, 0.04077493006895695, 0.04182047450116702, 0.016763273792873536, 0.03129437093489936, 0.030957529188266823, 0.04964755575305649, 0.027119495939197283, 0.01978324486740998, 0.042537736906004806, 0.03266798026327576, 0.04054935788735747, 0.03183826764247247, 0.018944236316851208, 0.029985775439334766, 0.03174329309591225, 0.04031538883490222, 0.07336695172957011, 0.06579794787934848, 0.03260086975725634, 0.05372855033991592, 0.06572754308581352, 0.03008866848956261, 0.024102849686252217, 0.01221497553134603, 0.018055136614878262, 0.0021383944175405695, 0.008108809839801064, 0.005320139478759042, 0.009607462145920311, 0.014969038910099437, 0.09656667469867639, 0.046540856028773954, 0.06668615700410944, 0.023544293229601214, 0.01726823446473905, 0.043414017385137935, 0.03097954425694687, 0.017667413223534822, 0.06814961454698018, 0.02957161802000233, 0.042972233412521224, 0.034663504255669456, 0.030730219957019602, 0.026931012481717125, 0.03543513427887644, 0.025999830037887608, 0.00852796042870198, 0.06492976232298783, 0.04742270049506, 0.05424629630787032, 0.04632513617564525, 0.006113692120249782, 0.03982759679534605, 0.03094576678371855, 0.070009024414633, 0.030211578322840587, 0.04499509218814118, 0.01139814913871565, 0.05728924088180065, 0.04526339850521513, 0.02010545739904046, 0.014421607035079172, 0.029134790745696852, 0.009820420361523117, 0.018288934337241308, 0.037853222739483626, 0.021599031718713895, 0.039480577023433785, 0.025584787130355835, 0.10222601637776409, 0.0456758833357266, 0.010432548854233963, 0.03295178771285074, 0.026248350273817778, 0.020152759771527987, 0.044762439493622096, 0.029046191035636833, 0.025907057337462902, 0.03472311355705772, 0.040357047492372136, 0.02072539074080331, 0.03786490032715457, 0.015190992803711976, 0.05883476044982672, 0.018139280046203306, 0.039068353428904495, 0.03783753840252757, 0.000895186691195704, 0.021907174826732705, 0.01491252881740885, 0.05046251702255436, 0.007595571040708039, 0.027400316138352667, 0.025174307370824472, 0.05817329737224749, 0.004863148264121264, 0.025115768458428125, 0.03142139947574053, 0.09141440223902464, 0.02590595811073269, 0.01613055685135935, 0.01971757285563009, 0.04599825532308646, 0.0518076380581728, 0.01517780208294945, 0.07150699903390237, 0.0629326980561018, 0.025083193688520362, 0.03077083027788571, 0.022178083325603178, 0.1325063133346183, 0.05711791757494211, 0.07193447609565087, 0.04483234217124326, 0.014157229435763188, 0.04450202114613993, 0.025175035099631975, 0.0009693094325484708, 0.09889579364763838, 0.019821361572082554, 0.014853755810431071, 0.01947070485247033, 0.035481101633714776, 0.032174441032111645, 0.0066588538715482825, 0.014828246286404985, 0.024751953248466765, 0.05552619655749627, 0.012919088775691177, 0.04430592452575054, 0.035034249004508765, 0.04831666359677911, 0.050638403477413316, 0.013649575828042413, 0.023676146154424975, 0.026378337227340256, 0.045029476950211186, 0.046703911386430264, 0.021779296420780674, 0.016593149796660458, 0.021953143877908587, 0.06999913137406111, 0.04281158685418112, 0.022454150386952927, 0.04408983147836157, 0.05343598300325019, 0.012790279928594828, 0.03648849543450134, 0.06654484530112573, 0.03344193087624652, 0.03794919473252126, 0.07333057546722037, 0.055134807380714586, 0.028556482134652988, 0.032517840819699426, 0.06480335803436381, 0.06047938684267657, 0.017682929623073766, 0.02780672808044723, 0.04392275919339486, 0.034672301462186236, 0.016824647285310284, 0.028778430939252888, 0.02444604760967195, 0.04436051606067589, 0.08708998999957528, 0.032914698988731415, 0.03726650368688362, 0.047150441711502414, 0.011237190454266965, 0.06374574585684709, 0.02061344772976424, 0.0841143357434443, 0.020419513939746788, 0.01428760145790875, 0.03662497936082738, 0.026527550470616137, 0.05083248145612223, 0.05998027005365916, 0.014560632075050046, 0.026360288195844208, 0.037106155683951716, 0.008105825982056558, 0.014730756071263125, 0.026248908368870616, 0.05551390828830855, 0.010197057338830615, 0.05467245022633246, 0.030921648256480694, 0.029253307064729075, 0.021311514378924454, 0.027960809812481915, 0.03124696508582149, 0.01912954931945673, 0.031250174556459696, 0.020951315760612488, 0.02473022655716964, 0.054232332057186534, 0.011348651705442794, 0.08051223081669637, 0.013819670986517199, 0.05764863373977797, 0.04198244759546859, 0.02946823642456106, 0.054387811571359634, 0.020229069516062737, 0.04049531935847231, 0.06212102768144437, 0.03470390083800469, 0.004612436784165246, 0.030834744883967296, 0.03793736108179603, 0.07337565733385937, 0.043976906287883005, 0.002326193402820666, 0.05016298113124711, 0.026166846343715276, 0.137041302131755, 0.029432762613786117, 0.022445105515154343, 0.08289072675896542, 0.03439406478511436, 0.01932342882667269, 0.04149705417720335, 0.020184628865016357, 0.009482844100732888, 0.12334873686943736, 0.03479787115273731, 0.017717338133869425, 0.022831081678824763, 0.023522815899923444, 0.03831546454291258, 0.017049440847975866, 0.04500943302576031, 0.02965126446049128, 0.030187212130320922, 0.0809011874454362, 0.02705204446933099, 0.010664824113648916, 0.02697180600703827, 0.06321109418890306, 0.03239923968378987, 0.028002407401800156, 0.05684263252520135, 0.020525246659027677, 0.0290334074358855, 0.03189229599333235, 0.005356378761851894, 0.04735655690144215, 0.06731480612818684, 0.02526906139350363, 0.082172931704138, 0.020241391712001393, 0.030418063314365487, 0.06168719274657113, 0.014252806182152458, 0.023555556910910776, 0.03420021750831178, 0.033147982720817835, 0.04709456774539181, 0.03487346334648984, 0.0734121421618121, 0.009825261708881174, 0.05189401895872184, 0.003859116180267717, 0.023423346058864678, 0.0498676928691566, 0.048744836156921725, 0.06222920651946749, 0.07756155343460185, 0.033313372238938294, 0.025796691920342188, 0.03434074889602406, 0.051228922326117754, 0.03543238281937582, 0.02294039536666657, 0.016797059747789587, 0.07583241550517933, 0.06753624603152275, 0.05518375689695988, 0.026462112553417683, 0.03013607094596539, 0.04854454279744199, 0.008826524318595017, 0.024899532918685248, 0.03695901197248271, 0.048863254088376246, 0.10207007545977831, 0.047330202601317845, 0.02722324224721108, 0.03200873260253242, 0.041387457200991254, 0.04547980028603758, 0.07605466286518744, 0.047724353415625434, 0.00924900481809995, 0.04343806466619883, 0.044283973917897256, 0.01656283624470234, 0.011830943370504039, 0.01432206085883081, 0.009290968816328262, 0.023538306854399185, 0.0169723626625325, 0.08536592072674207, 0.07270469476601907, 0.044142054926071844, 0.05657462137086051, 0.03704626139785562, 0.02218321305034416, 0.021062643001122133, 0.03819440711023552, 0.010758986962693078, 0.01927949029154011, 0.029204747706119503, 0.018172806461474726, 0.029671830856906514, 0.04752864695287176, 0.08184826626841511, 0.034132727022681913, 0.05680923842425857, 0.015236892305048448, 0.009570610909057515, 0.035375328202332766, 0.07513238449714013, 0.014249138700376664, 0.02537488571501204, 0.04166870318087084, 0.025709223667425767, 0.033871294265346866, 0.06425983112837587, 0.049790553615561554, 0.05565108432035361, 0.050050581805408, 0.030190964428974048, 0.03139618172177246, 0.03080245679510491, 0.01051952941010573, 0.04999522352591157, 0.016095914245982255, 0.1288262243781771, 0.19929633369403227, 0.1631395367107221, 0.1186914760619402, 0.10307468726698842, 0.1370433105954102, 0.138419881729143, 0.12724982468145235, 0.2039115253303732, 0.12828644977084228, 0.09104206971824169, 0.11421777254768781, 0.09314078531627144, 0.2058107177061694, 0.15697698667645454, 0.07683218257235629, 0.15100623135055813, 0.125541287075196, 0.0878867936719741, 0.2274308247225625, 0.19739767057555063, 0.17626329963760717, 0.08397261691944939, 0.14242716027157648, 0.08181475342384406, 0.13616698261882576, 0.14027374796569347, 0.19423537169184002, 0.10860132785247904, 0.09398540535143443, 0.0781056299539549, 0.11984269214527947, 0.11844921191888196, 0.13423116292272294, 0.21387275867164135, 0.17625432940466063, 0.09000756844346013, 0.3033245051545756, 0.08265404017376048, 0.06099853398544448, 0.21239824779331684, 0.07214619937751975, 0.12107880653015204, 0.15978401819510119, 0.16763264632650784, 0.09458550850727729, 0.15620766367231095, 0.11785048618912697, 0.13502485890473637, 0.09731374853955847, 0.1762609247650419, 0.08635047503880092, 0.16627488418349198, 0.17979841280196393, 0.09612089754747492, 0.07913466902183634, 0.1383855478571994, 0.11679024808108807, 0.09140881789582116, 0.2023222470389945, 0.09605436040354626, 0.10658272009875093, 0.2858856666300978, 0.12630146342728818, 0.15676110397492135, 0.059901329289589605, 0.21643990091979504, 0.14808076832975658, 0.10189428739249706, 0.08079272362270526, 0.07734208806817021, 0.13444001600146294, 0.21357534320226737, 0.10215375918362822, 0.08338909037411213, 0.07183079594480139, 0.09394311226372208, 0.12069117304469858, 0.12026541946189744, 0.14502809356365884, 0.09734207737658705, 0.1802927934165512, 0.11248001722352845, 0.0660633093544415, 0.08968022957976375, 0.15588426031172276, 0.08367742704493658, 0.15888069809547492, 0.11841691365199429, 0.1427145198519741, 0.09973020851612091, 0.09060662665537425, 0.10057636204042605, 0.10920996697885649, 0.1196252488132034, 0.12291826068290643, 0.07474093085953168, 0.1720429068165166, 0.13614535092243127, 0.09439857889498983, 0.1125970102314438, 0.0608044865408114, 0.12880315418754304, 0.10956386370318276, 0.20022508528615746, 0.13579785956868104, 0.11802393331059388, 0.06560668921364204, 0.08706433459052018, 0.09900137369654008, 0.20854027409638676, 0.09140602233154432, 0.1200866661965847, 0.1730417917881693, 0.14920949776257786, 0.10497173547212567, 0.11232725184942995, 0.16291560658386775, 0.14788213398839745, 0.08697062890444483, 0.08094622859997408, 0.13402990943619184, 0.2920530614043985, 0.22749896320913518, 0.1698856811438288, 0.11264448054134846, 0.10415972582995892, 0.12625570302563055, 0.20030124405665056, 0.11342269913958651, 0.19787643131400856, 0.11870484320180756, 0.08334658694054399, 0.12631096291754926, 0.09428176230617932, 0.13109614114676202, 0.07268389088234731, 0.12829981691070966, 0.15361533420426504, 0.11825616870607648, 0.17882654709475382, 0.14726051448711328, 0.11763239146343299, 0.2155657306845699, 0.17890860911990913, 0.10581871002380337, 0.1282414493284055, 0.11490458569356374, 0.11429272352584771, 0.09732399441834007, 0.1258197035640478, 0.08930913877806493, 0.08672747588051216, 0.14052481949329376, 0.17211768137557165, 0.17296599942658628, 0.18014034016856126, 0.16820968607706682, 0.09010905692619936, 0.15139725751110486, 0.11884131016475813, 0.11935422835605485, 0.15916617134852068, 0.13975815634642327, 0.13617908768355846, 0.15770451192344936, 0.15375790798238345, 0.16375054392431462, 0.17861312068998814, 0.08118304410683257, 0.07195447930800063, 0.12591814542455332, 0.16190046391316823, 0.06496018783322402, 0.06513837791447129, 0.09369026975972311], [0.016927474178373814, 0.07282714998083455, 0.022403708093666604, 0.047495446234409294, 0.02030018168235464, 0.03463256984416928, 0.025726249807381203, 0.025295030625004853, 0.038539621978998184, 0.040889069837118895, 0.016888665367982218, 0.00456878196148734, 0.06076013749199254, 0.028514253507767404, 0.017764197762257287, 0.05622135229142649, 0.021443621754380207, 0.033150846138596535, 0.0448405524449689, 0.034434091565864425, 0.052742611816419024, 0.02552911333207573, 0.023560440666707497, 0.014314683486840554, 0.021009583259001374, 0.031173316894897392, 0.12504636363259383, 0.0339844331943563, 0.015599143491791827, 0.010864720530142742, 0.038479381640042574, 0.025964824416275536, 0.05181659811309405, 0.0593769099297268, 0.03174189531377383, 0.03242957019912345, 0.06838288810104132, 0.046267613369439325, 0.009096880659594067, 0.021821743875209774, 0.028698770928063562, 0.03522133467985051, 0.024048580455460718, 0.050126598083547184, 0.01994147414474615, 0.05430464692679899, 0.008776794487078275, 0.05902061119143452, 0.027207610496718968, 0.05306632730311581, 0.012406629443700825, 0.008008641955841864, 0.028080915599795322, 0.04151127287851913, 0.0403375871080373, 0.008196320501156151, 0.02793446060137025, 0.03362003614061645, 0.03466277483052441, 0.015145563187875917, 0.10432644866939102, 0.04479523648374847, 0.014270242835794176, 0.028919301594474485, 0.021864199811326604, 0.0019065521482843906, 0.04264749673062137, 0.0761234595307282, 0.06774047150143556, 0.03758619546091982, 0.05064652893426163, 0.014456476949687515, 0.0968170744766082, 0.06456460870270218, 0.03292880912444421, 0.029836755578539202, 0.08086927594350916, 0.052641611878893206, 0.0440072809079928, 0.017160993701379215, 0.035947088950446675, 0.01953176791513605, 0.012202096088523311, 0.010659221110732427, 0.02719913559433605, 0.033293457236140966, 0.022394120393853103, 0.05798602170710053, 0.021220933346609985, 0.03269842952223761, 0.01940006426801639, 0.03258888343615191, 0.018851285500984107, 0.03693376029176371, 0.014266339563099402, 0.10636322759091854, 0.05158362989979131, 0.012667583833847727, 0.0323096086005015, 0.05711620088134493, 0.029531194296266352, 0.006841961635343198, 0.05416349807221975, 0.0773032351530024, 0.02314723319640117, 0.030949430872819254, 0.026093038697061793, 0.03090884769335389, 0.022304996515491178, 0.03170282526740006, 0.078833928730871, 0.02574373735114932, 0.022813970721991997, 0.029828219608004605, 0.058754835809980116, 0.06396327061312539, 0.045380615429686647, 0.035069217306694815, 0.013605128391645849, 0.008609506767243147, 0.03613392696050661, 0.030973627431584255, 0.06161356491169759, 0.061722300148436, 0.07642331772616931, 0.026596012957660214, 0.09362985300166266, 0.03004092676565051, 0.04730275585981352, 0.04642398854983704, 0.04735089113403644, 0.03549085557460785, 0.04521601640486291, 0.04466197220608592, 0.022084967964994054, 0.03744273619460208, 0.024686337215825915, 0.11731166153081826, 0.05310066117505942, 0.002758379073514204, 0.02745487374652709, 0.02574542011799557, 0.00968406196417553, 0.04390183656609484, 0.010068530931935778, 0.029755402622478347, 0.03585988362984998, 0.023802962653072815, 0.03370656631886959, 0.029447493609040976, 0.041924049479088614, 0.05274541077337094, 0.027549771957897713, 0.06863053981214762, 0.03896893447797213, 0.029307447373867035, 0.03109700884670019, 0.015876730471583347, 0.03799735714814492, 0.07969785308731453, 0.014640817950878824, 0.03221882061500635, 0.08476528152823448, 0.04857952127765332, 0.05547433612602098, 0.03974091733938881, 0.012740046284826738, 0.03186404858050602, 0.05987848301551171, 0.03650999142389212, 0.02666578332095274, 0.056533125561795065, 0.04984316722090755, 0.027018419666481868, 0.008607933414168656, 0.008423186988303704, 0.03346334204875997, 0.02309364080429077, 0.007269876776263118, 0.07024882547557354, 0.03686554716633899, 0.026862052967771888, 0.01717534302068608, 0.08359852699296814, 0.02260616428351828, 0.033142652828246355, 0.03806477299492274, 0.0453398219043655, 0.02933539283861007, 0.025724646768399646, 0.04018142566617046, 0.008363140031828411, 0.016780815619443144, 0.07901577611586877, 0.04780448840132781, 0.03208582435867616, 0.04398270097694226, 0.060996980140251775, 0.01576167468114623, 0.02415495439033423, 0.02794597703697426, 0.013625690547217215, 0.04458219684394343, 0.03189969541771071, 0.01656949776224792, 0.014716362647180046, 0.048972097890717645, 0.108086469051029, 0.07041719036975078, 0.031209282643560852, 0.042685223277658224, 0.0260079911178244, 0.02411098192845072, 0.020193707663565874, 0.02858224950198616, 0.02952510105179889, 0.029809658282569478, 0.04911871573754719, 0.024987523643566028, 0.029316573669867854, 0.016874633263796568, 0.03240108869171568, 0.043089477478393486, 0.024192524874316793, 0.0680035123867648, 0.07750214769371919, 0.03183013200759888, 0.014883512963673897, 0.01454084599390626, 0.08981736829238278, 0.054577597816075595, 0.034409342001059225, 0.03390357217618397, 0.017450745117717555, 0.01570831299094217, 0.03948718934719052, 0.04229875687243683, 0.01946008069041584, 0.016778661270758936, 0.062349049374461174, 0.0588222686201334, 0.028430754684710076, 0.040965625550597906, 0.060018478360559256, 0.017289978119411638, 0.02993489888363651, 0.05198434893307941, 0.009282795862028641, 0.04593193870303886, 0.021895590537626828, 0.07956082294029848, 0.03958295438704746, 0.09493367161069598, 0.08590128485645566, 0.03129511732341988, 0.029733611470354453, 0.03737541534272688, 0.03330077862899218, 0.06875494242246662, 0.01995375732492123, 0.016795124226648892, 0.059336604949619086, 0.08279795066586562, 0.060928074909108024, 0.03417715410302792, 0.04297383814784033, 0.008177869437661554, 0.0457711666157203, 0.024494094674342444, 0.029249168001115322, 0.02397800942084619, 0.032012807205319405, 0.09303092371140208, 0.03238474617579153, 0.025718577272657837, 0.12124853527971677, 0.03000390250235796, 0.014085930672341158, 0.07774300048393862, 0.06690779368260077, 0.03528490323307259, 0.016138198852006878, 0.04273651034704276, 0.018221469296674644, 0.03786740412137338, 0.05232453925002899, 0.041081892526043315, 0.017804462030263882, 0.026042323293430463, 0.020826746909213916, 0.029047602388475622, 0.04351985527734671, 0.05862971395254135, 0.03223672036879829, 0.021780209050380757, 0.02109615584569318, 0.08266047947108746, 0.06790846320135252, 0.0830744333299143, 0.08446467694427286, 0.016794645859460746, 0.02177787319357906, 0.01973778980651072, 0.029494227708450386, 0.012378272617102733, 0.05315413312720401, 0.011052354970680816, 0.06820250635168382, 0.01284024809553687, 0.03012209651725633, 0.025043029504429017, 0.027031895371952226, 0.032655671638037474, 0.06281907058187894, 0.06011054877723966, 0.024932139919006398, 0.04912457488743322, 0.03049760458192655, 0.04472471633926034, 0.055353282086019, 0.03875851059066398, 0.03233744549964156, 0.004529784009459296, 0.08248242509684392, 0.022208951579939042, 0.03371441357636026, 0.04449522901060326, 0.07410737592726946, 0.04925362206995487, 0.01223238673992455, 0.042350434099457095, 0.018729278119280934, 0.037162087325538905, 0.019577633489721587, 0.07358842555965696, 0.03338393309552755, 0.02400849260655897, 0.057689847956810675, 0.02047649900695043, 0.025012057773502808, 0.05473132670990058, 0.003741691878531128, 0.047881088219583035, 0.033779607220951996, 0.01943230994844011, 0.02620972297154367, 0.0334964613430202, 0.0637015053736312, 0.035385987987475734, 0.041360030815537484, 0.06323273945599794, 0.031170534901320934, 0.10897959076932498, 0.15901237460119383, 0.16713012329169682, 0.1563843134790659, 0.07146009190806321, 0.17218714979078087, 0.12524411587842874, 0.14357832207211427, 0.12859705596097878, 0.10011546712900911, 0.097707678829985, 0.122536123331104, 0.07916881290397473, 0.07514210790395737, 0.13835339886801584, 0.12653235532343388, 0.06859268434345722, 0.1941347313778741, 0.13192426599562168, 0.12949880185936177, 0.09339678979345731, 0.0956702349441392, 0.11510244650500161, 0.07771773183984415, 0.11662391200661659, 0.08522996945040566, 0.1776197725640876, 0.16953253080802305, 0.14741028073642934, 0.09404805448970624, 0.15088098735681602, 0.17146320720868452, 0.17722278886607715, 0.0767690245328205, 0.1595198373709406, 0.08537761867046356, 0.1280740275979042, 0.13206764044506208, 0.11263552387910229, 0.1170508326696498, 0.15603954983609064, 0.17029633053711482, 0.09414047095924616, 0.15755190939775535, 0.12104549046073641, 0.10235435449119125, 0.14234925088073525, 0.13734007467116627, 0.12277386843093804, 0.15002908664090292, 0.09609714882182223, 0.11848662633981023, 0.14036024760987076, 0.2023214599383729, 0.10139888219003167, 0.143416396475264, 0.0575506736391357, 0.11160341783293656, 0.09490386356732675, 0.09247261152735778, 0.20407636862780365, 0.16641460811453207, 0.06293210773063557, 0.10239235245223556, 0.12768252646284445, 0.06804167319621358, 0.08745627677334206, 0.13586151972413063, 0.08779551035591535, 0.12283899422202792, 0.16937094447868212, 0.11856545853827681, 0.2054471450724772, 0.14472948387265205, 0.13137048642550195, 0.0932010935087289, 0.1913082937576941, 0.16096247067408903, 0.13479939528873988, 0.07876972574740648, 0.12059425110263483, 0.21267817062991007, 0.13899895708475793, 0.08028581046632358, 0.2218031638434955, 0.1717651960040842, 0.1587898286857775, 0.1468370814940759, 0.1372297177357333, 0.19198838940688542, 0.11183642675834042, 0.08868365841252462, 0.07081848276512963, 0.13631702028214931, 0.10361315230173723, 0.18834971822798252, 0.16239785722323827, 0.19742497482470103, 0.25153884823833195, 0.2052925205124276, 0.07800066058656999, 0.12697110963719233, 0.27206784380333765, 0.13662580799843582, 0.09790258122874157, 0.0802806807415826, 0.11573667318693229, 0.18290402687021665, 0.0855763547920755, 0.10515794583729335, 0.17715494893491268, 0.07732689566910267, 0.084188587830535, 0.10723634609686476, 0.13653392078621046, 0.21647538830127033, 0.09349487203040294, 0.09161494326378618, 0.0479921067266592, 0.07481559006763355, 0.1352984985070569, 0.11804571428469249, 0.22458684018680028, 0.15536013272191795, 0.10756382745291505, 0.06107600232852357, 0.19540693025503839, 0.15064321511558124, 0.0972644393997533, 0.1971506295459611, 0.12865830053176197, 0.1480150997106518, 0.16200746888560907, 0.13511594544563973, 0.1132778726252062, 0.13024254409330233, 0.13380916842392512, 0.22025029574121746, 0.16712317509310587, 0.10812736435660295, 0.12268251047602721, 0.11750850453972816, 0.15859152004122734, 0.14646665565669537, 0.08889307467533009, 0.0788833803630301, 0.09319094262484993, 0.14969733729958534, 0.0705249145893114, 0.13458751594381674, 0.14232749704803738, 0.15420684032142162, 0.11067349237522908, 0.10652011167258024, 0.07532189932784863, 0.09676409446235214, 0.13036512822977134, 0.060963921914143224, 0.15464187626327786, 0.18190915882587433, 0.08295617146151406, 0.14727842781160558, 0.1325362774410418, 0.1105825686827302, 0.11809393098311764, 0.16102363382066998, 0.1692332832940987, 0.12164288626185485, 0.12349430977233819, 0.12555751763284206, 0.13344247452914715, 0.16709435092551367, 0.11887634971312114, 0.10782397099371467, 0.1887904538639954, 0.0947971096528428], [0.021712284302338958, 0.03623833314382604, 0.05878425030303853, 0.017828187007190924, 0.04574530425348452, 0.059394857180970054, 0.008103373077964144, 0.03523854911327362, 0.08634645132614033, 0.03515771523650203, 0.05879680320088353, 0.03521196071856788, 0.024973226910723106, 0.04141233229477491, 0.05072977500302451, 0.017189078265801072, 0.0819456631849919, 0.052965323972914896, 0.031411771063825915, 0.0394254494458437, 0.032171282451599836, 0.024456751499591128, 0.05679777118244341, 0.1133781261742115, 0.039506283322615285, 0.01103841362055391, 0.010149013666835214, 0.0026099592921257552, 0.05719242071998971, 0.05013460818944233, 0.03601393822048392, 0.02192028921230563, 0.01649889280088246, 0.024534157078180994, 0.035008922684937716, 0.016707657670070018, 0.05155122306730066, 0.05726368046764817, 0.008181821904145181, 0.030608897895685265, 0.030763271397777965, 0.09272916561790875, 0.03518173198348709, 0.04609076678752899, 0.0331355010691498, 0.11251487356743642, 0.05837469335113253, 0.021169820999992744, 0.02858984230884484, 0.09395326314760105, 0.04631381142618401, 0.012066524791797357, 0.051113493341420374, 0.01885372992338879, 0.07486493313418967, 0.018068183146949326, 0.014325487460674984, 0.04478747743581023, 0.09692460192101342, 0.013947471360942083, 0.09643024166247674, 0.047872501358922036, 0.02180984745999532, 0.02190127835742065, 0.04221631147499595, 0.092699120087283, 0.014952479262969323, 0.03353474089609725, 0.024447587884164283, 0.01977983522894127, 0.048934249207377434, 0.0713179184656058, 0.05020201725086995, 0.08218851086816617, 0.023102845131818737, 0.0444816515248801, 0.06744498985686473, 0.020668071495102983, 0.02407206115978105, 0.012822868269202965, 0.04372245904856494, 0.027345202131462947, 0.03388707359720554, 0.07222220887030874, 0.017489365634641478, 0.04384292276310069, 0.05683480901643634, 0.03366039540352566, 0.07399920387459652, 0.014741772087290883, 0.022488723442490612, 0.06724969390779734, 0.013567030346686286, 0.02278453587288303, 0.06974184446569, 0.07427154068968125, 0.037432469959769926, 0.03023671804528151, 0.020584688022998825, 0.015369534026831388, 0.015548412821122577, 0.03536091611853667, 0.035427782351949384, 0.03100261784025601, 0.042097075908843956, 0.008363480995675283, 0.02433646420416023, 0.03324654671762671, 0.02488835744692811, 0.029492694219308238, 0.02609518456405827, 0.016936966883284704, 0.043795764579304626, 0.04638207544173513, 0.0799763984978199, 0.03396021288686565, 0.02201824083126017, 0.09142035977648837, 0.033835230129105706, 0.04129301191174558, 0.03219051552670343, 0.04573051219007798, 0.0662699504090207, 0.015908340025427084, 0.03823599452152848, 0.01710234791971743, 0.031194636465183327, 0.06869592344654457, 0.017985150816717317, 0.009068810514041355, 0.009495827020145953, 0.016126356719593917, 0.011390815023332834, 0.06651692358510834, 0.02543831686489284, 0.0072506530310160345, 0.027098005038819144, 0.02700032483387206, 0.08987869428736822, 0.009304173955959933, 0.05998107072498117, 0.047326314595660994, 0.0038740647308129284, 0.04292659853984203, 0.02687059063464403, 0.02110196410545281, 0.03118831930415971, 0.04945429880172014, 0.00539320328139833, 0.028153905611751334, 0.004361646848597697, 0.02193126281989472, 0.029352040695292608, 0.051950571459851096, 0.04643036338633724, 0.011165050307421811, 0.07267591809587819, 0.03401956095227173, 0.09188645226614815, 0.018266737760443772, 0.024931924484137977, 0.022773765825799534, 0.03161306865513325, 0.05494247662967869, 0.020581741484680345, 0.031896224711090326, 0.02416660144392933, 0.025422451019819294, 0.01785424105556948, 0.04949576746938484, 0.029929131335977997, 0.02860323998278805, 0.05343004921451211, 0.01872160897723266, 0.057337382941373756, 0.026463883529816355, 0.03724479056628687, 0.03136751700990966, 0.055874936415680816, 0.014003942437869097, 0.029482373701674596, 0.04783702076279691, 0.011804738348083836, 0.026168588482375656, 0.07668751890638045, 0.013287327185805355, 0.0339823738405747, 0.039241661450692585, 0.06596457572387797, 0.005240331886203161, 0.048057968728244305, 0.05142227087968162, 0.045608905144035816, 0.0354025747760066, 0.01943209790624678, 0.04112769024712699, 0.037721407134085894, 0.015565690019034913, 0.024886671287406768, 0.02846106654033065, 0.04943678242021373, 0.02574541842165802, 0.048446433419095616, 0.046960709749587944, 0.02566170416373227, 0.017809294895934205, 0.0402277424665434, 0.024922041621591364, 0.026940101458291923, 0.057272732124796936, 0.07092033087142877, 0.04381547262892127, 0.02993957738259009, 0.005317924910091928, 0.020079907162913253, 0.038068084245813746, 0.0511564038959997, 0.058115241916051934, 0.029958461012159075, 0.09906456566282681, 0.027311205830691115, 0.04459220862814358, 0.019077916197212677, 0.049261482898145914, 0.014942898348506008, 0.02850206023348229, 0.03460682622556176, 0.019663624232634902, 0.026827177964150906, 0.06958021742424794, 0.07216955455286161, 0.054304263554513454, 0.025318021087774208, 0.06635289452970028, 0.08231716110770192, 0.008624137678582753, 0.04381569315280233, 0.07062254899314471, 0.017442307534760663, 0.051078005959945064, 0.05412780373756375, 0.028866698167153766, 0.04103980978418674, 0.031215861040566648, 0.07231051341763564, 0.02052518050186336, 0.022075093584135175, 0.06785996830356972, 0.02033390148010637, 0.04321551875078252, 0.01602418122014829, 0.006232238973357848, 0.045104017414684804, 0.04018803459725209, 0.043840938048171144, 0.011749936467302697, 0.03593316201918891, 0.04326715526570167, 0.04887694013970239, 0.080491732273783, 0.011091884724529726, 0.06854065427822725, 0.017599076265469193, 0.023769373473312174, 0.031819482400481186, 0.06964653743697063, 0.021477314410731196, 0.04288290088464107, 0.0549570312058287, 0.04947027151605912, 0.04650642037657755, 0.02798739481451256, 0.033718620493475876, 0.020634601058970605, 0.028241363686642477, 0.08821586958531823, 0.02593161351978779, 0.029143723659217358, 0.012884270599378007, 0.03560763145131724, 0.012058666508112634, 0.02391977415287069, 0.0558588313870132, 0.05724745669535228, 0.020680973838482584, 0.03360406342627747, 0.03904095757752657, 0.07119007568274226, 0.06368305600647416, 0.02281401482676821, 0.028348762209394147, 0.020939397293009927, 0.0038882830080443193, 0.022627909634528414, 0.015066390025562473, 0.026918641091989617, 0.02446218317241541, 0.0033447503769171555, 0.06618746090680361, 0.007981361455417104, 0.02868176344782114, 0.040246673593563695, 0.013560967636294663, 0.018540267100823776, 0.04011441015505365, 0.016014188095661144, 0.0714666736977441, 0.04305941837706736, 0.03033358570454376, 0.07831611830208983, 0.031273634904729466, 0.038144948692726235, 0.028898935365889753, 0.040863814763724804, 0.019122462021186948, 0.04197125855301108, 0.037286045495420694, 0.024134372726881077, 0.03341268601694277, 0.03609228865908725, 0.0015303218679036945, 0.018697819539478848, 0.017800022714904377, 0.07268613004790885, 0.07472514134964772, 0.0018835606253040688, 0.015136659112093704, 0.021210351592994163, 0.05191400181502104, 0.00963001071275877, 0.008526268331999225, 0.019748773592125093, 0.02462639203960342, 0.06962229338075433, 0.063109612491514, 0.010287978486823184, 0.04877301910892129, 0.02046393253840506, 0.027729614271915386, 0.10758395280156817, 0.0072752677369862795, 0.06435868010989257, 0.009315768423091089, 0.03415521367319992, 0.04470996159527983, 0.015447211019428713, 0.06903968285769224, 0.0475498647429049, 0.06313508469611406, 0.04342524713969656, 0.03348791519446032, 0.03294524663527097, 0.11792459578386374, 0.1834376539502825, 0.13353277396942886, 0.10976622320179429, 0.08764849217342478, 0.15267206196274075, 0.14047753917319433, 0.10383275337517262, 0.15937089893434728, 0.16569389535912446, 0.10199038830718823, 0.12266009167901107, 0.11712673359683581, 0.08897614093231303, 0.14247677475214005, 0.1659203903483493, 0.2316084291253771, 0.10625356276120458, 0.19182070983307703, 0.17108776021216596, 0.08481799691383328, 0.1181890887341329, 0.1530960649251938, 0.24056845690522874, 0.17497785575687885, 0.16203143474246773, 0.12037535570561886, 0.2090005108288356, 0.14891798554786614, 0.18006304145923682, 0.1586182000381606, 0.058864989184907505, 0.043530881471399746, 0.1653151913945164, 0.18131565781576292, 0.08652232081762382, 0.12029399935688291, 0.14576948806643486, 0.16785515152982303, 0.09083376625286681, 0.15738162424947533, 0.19426461655114377, 0.11294179423046963, 0.20876138151756354, 0.1370486438806568, 0.19398188457957335, 0.11725884436496667, 0.13996345390166554, 0.06750948461038725, 0.16605954430997372, 0.1362844506012542, 0.1139948737940618, 0.125910274418337, 0.13508279222462857, 0.16321547835000924, 0.14119618918214524, 0.17428736495120184, 0.14748391535665306, 0.18049382977187634, 0.08377589604684285, 0.16448922428701604, 0.2597618241395269, 0.13224686868488789, 0.17371751767184052, 0.15722735252763542, 0.13775224398289407, 0.11696871636169297, 0.11882749519177846, 0.1703314243682793, 0.130630367568561, 0.10739229380020074, 0.12819183484784194, 0.1682179370628936, 0.18080051402960504, 0.08550360226737601, 0.12808539984481676, 0.1342964515622173, 0.13738939059632166, 0.1887517502265317, 0.10715344947363649, 0.126817150041461, 0.1938094688313348, 0.13051218033901282, 0.17526472679206304, 0.0766294091673834, 0.15925372950732708, 0.1422606749194009, 0.08323723423693861, 0.18582167316760334, 0.11266844639820711, 0.10184440149792603, 0.1347775871732405, 0.24466433855039732, 0.1296188754162618, 0.13629933765956334, 0.15678724114383968, 0.09711311930524451, 0.09894061088562012, 0.14293408021330833, 0.2016367366803544, 0.08237129463148968, 0.11676567154271261, 0.12464225531688758, 0.08488657644816808, 0.17110617565257208, 0.12299528797822339, 0.10368996925119843, 0.13401253893971443, 0.09615556390157767, 0.12871866300702095, 0.10059795981006962, 0.11973275590155806, 0.2112881237907069, 0.1321288307330438, 0.15555498083787306, 0.1118935186948095, 0.09922839115772929, 0.1369684139000518, 0.12977830400424345, 0.10917493421584368, 0.1151928680815867, 0.15796873345971107, 0.16855401545763016, 0.1550165768712759, 0.13079175033739635, 0.09698393980839423, 0.0704198841537748, 0.126607496291399, 0.10737457725086383, 0.14880628511309624, 0.15130735162113393, 0.09838975580143076, 0.06716710262532745, 0.12871806589620455, 0.10987134863223348, 0.15408383549324103, 0.08984332225684609, 0.0886802114546299, 0.20802407179559979, 0.13963957556656428, 0.1357593187796218, 0.13364957698753901, 0.13388014318687574, 0.07491143992436783, 0.08795473538339138, 0.15781089264367307, 0.09477013788585152, 0.154634276671069, 0.11322352197021246, 0.19897151898060525, 0.08559375242995364, 0.05813425446727446, 0.09612164393599544, 0.13734019680746964, 0.09084839546786887, 0.06091336426990373, 0.16944808033960207, 0.15435618587902614, 0.12009832342820508, 0.10590341833553144, 0.16834809365017073, 0.20259254824902329, 0.08918934342052255, 0.13946783835334436, 0.17309125699102879, 0.17263015173375607, 0.09190033509262971, 0.11799213715962001, 0.11572287178465299, 0.12105424356247697, 0.15640430312071527, 0.19874510541558266, 0.137827995632376, 0.13047771076006548, 0.09306649251707963, 0.12667559406587056], [0.04161974009392517, 0.018934226228988597, 0.010014015732200017, 0.0034277776181365228, 0.03302630103592362, 0.023008094501814673, 0.03157435483964426, 0.0012160851973541348, 0.03269218360739095, 0.06898037889706236, 0.0052629894427289915, 0.020296688923346143, 0.015439010923728347, 0.007269858116550105, 0.03094772096457226, 0.03633262576269252, 0.04951821340780173, 0.05903716066053935, 0.027933670108073523, 0.004873563776657517, 0.03177588991820812, 0.053895371566925726, 0.04006729607603379, 0.031984013571803055, 0.03343517266746078, 0.06696297215031725, 0.029886024006243263, 0.024526632124824182, 0.03480313319180693, 0.010516783887786525, 0.05029300879687071, 0.02987259240554912, 0.02173249955688204, 0.022173520177602768, 0.01533710174927754, 0.0443475594344948, 0.051778739251728566, 0.029986226665122167, 0.0240983662661165, 0.030011797257299935, 0.03134654009980815, 0.025668479335893477, 0.06962244265845843, 0.02519586103569184, 0.0567909994029573, 0.01781230589507946, 0.08426134035523448, 0.025432951349232878, 0.06302413743521486, 0.03001059964299202, 0.012701093285743679, 0.022892019212512032, 0.0863279476761818, 0.021215260793854083, 0.035715525304632526, 0.013196110875079674, 0.02271926080408905, 0.029455052489148717, 0.06265965556459767, 0.03055685425975493, 0.016498733345153074, 0.06566009670495987, 0.04965005276192512, 0.027277769321309667, 0.04159706684627703, 0.06944360796894346, 0.024072517474581088, 0.013269720050240201, 0.07060133798846177, 0.035107978619635105, 0.056477258381034644, 0.006479126908483782, 0.08938356728426047, 0.03718222963756748, 0.05026130424812436, 0.07197780055659157, 0.07105651963502169, 0.05964592192322016, 0.014707236351179225, 0.0058708117825777405, 0.019168422590675097, 0.04200650505455477, 0.05023208313754626, 0.034629828562693935, 0.05342015278126512, 0.002845748938852921, 0.0330619037683521, 0.08974390330591372, 0.0469558616168797, 0.015789051872811148, 0.028641346509435346, 0.0702481401552047, 0.007954299782535859, 0.024436512496322393, 0.014616444973008973, 0.10061248724481889, 0.02863485292930688, 0.04190209887123533, 0.006925058850486363, 0.03524303422974689, 0.029225324280560017, 0.016232756099530628, 0.044034140716706, 0.030173370015940497, 0.028015128237062266, 0.07575450611433812, 0.018897257944835082, 0.06803454179316759, 0.0130168979022918, 0.04397749322067414, 0.08193555979856423, 0.07019390485116414, 0.03064505024147885, 0.013492533138820102, 0.045072441787592, 0.013074882960479175, 0.021162189177370498, 0.019844494527205825, 0.02232018212920853, 0.05884512167956148, 0.0616382093035749, 0.04013644897245935, 0.013245771156757005, 0.02262592831227396, 0.04091057939721005, 0.04187811605100121, 0.041937070566096475, 0.01807800154866917, 0.03205144977463143, 0.026518405514902303, 0.029771338017391305, 0.034260393386440616, 0.038567703150744946, 0.047476107986377816, 0.050262430616255314, 0.02283720376103052, 0.06274864543229342, 0.08821338614714996, 0.05317118810489774, 0.02261929732880422, 0.034352229708539586, 0.024414848569514494, 0.007726017701705652, 0.012459872390276619, 0.05498611321672797, 0.020240436673962643, 0.08472587221435138, 0.010876958757372839, 0.07081838098487683, 0.08231665899178811, 0.03761481946068151, 0.022630735732881085, 0.02389241392458124, 0.05137352831661701, 0.028216955085684146, 0.03471053012513688, 0.03743697203961866, 0.0633170542174152, 0.07414265974823918, 0.026396862929686904, 0.09818521820540939, 0.06947944818862847, 0.009867502210129584, 0.017079554232103483, 0.015787506509306173, 0.06081935324306999, 0.03288034136806216, 0.09234775429857628, 0.02223350776226393, 0.03494426169033561, 0.027227060703028525, 0.048427386941122155, 0.031530565582215786, 0.02329542694081153, 0.015940299024805427, 0.025894665591684834, 0.02383966970124415, 0.02503895659797958, 0.018761859674538885, 0.03213185956701636, 0.0192524116552834, 0.009933937573805451, 0.03143856301903725, 0.02951417663799865, 0.019423611129501035, 0.022379976331389377, 0.03157204782058086, 0.02245259314908513, 0.05071073531040123, 0.023654645076021552, 0.06706679479352065, 0.02208246077810015, 0.050452763081661293, 0.03134123734863741, 0.017195035803264806, 0.012363310919941535, 0.03844501384134803, 0.0027280606445856392, 0.03500036296567746, 0.06514091563544103, 0.0563991657857384, 0.0245492901054344, 0.031638089633945904, 0.035699454202715836, 0.023242436748530184, 0.03620258791904364, 0.023892232416463748, 0.12267598296914782, 0.015712769269677143, 0.01405974430963397, 0.045975273342004845, 0.03351602350760784, 0.025169924034604003, 0.022572408862678067, 0.029002167683626925, 0.07149455470166036, 0.025751167309603522, 0.010015063220635056, 0.02811013162136078, 0.038856918524418554, 0.06105508987924882, 0.052271552450422726, 0.04290260893425771, 0.043183722599808655, 0.04804299006770764, 0.012463534783039774, 0.033126340846398046, 0.046088792250624726, 0.02108693794746484, 0.0281097431600626, 0.025753761009712304, 0.02732904112365629, 0.023615795553528836, 0.014873967672299062, 0.04665897540482027, 0.03180749947205186, 0.015299107180908322, 0.06089737119951418, 0.04312714634995375, 0.032749848905950785, 0.030040292335408073, 0.020476383655997257, 0.06920052279851266, 0.039554527162441185, 0.016648146756259457, 0.02378777364668037, 0.05500501720234752, 0.017447985176529204, 0.03181406090568219, 0.014750230026298335, 0.039947460006390295, 0.009454372771350401, 0.04543545462989381, 0.007285705301910639, 0.0260880650353751, 0.054137187876871655, 0.034826990483062606, 0.020727694367191622, 0.025200838090053627, 0.01920269539446703, 0.062398236377963, 0.017583663342520595, 0.013292883539439311, 0.026270808086597493, 0.06224448034273727, 0.013259685365483165, 0.04137701115437916, 0.09087446478328534, 0.037107967372451506, 0.003137619504871379, 0.05368048970454505, 0.03072322765365243, 0.021479041282353655, 0.04663567111960479, 0.08179804789168493, 0.055739639925637414, 0.0653279877400824, 0.03483290391575013, 0.023656488994934728, 0.03653717014406409, 0.019636321679822037, 0.06574554461985826, 0.020434652056012834, 0.02621433192065784, 0.013351909300711538, 0.08690773549356631, 0.022723981711481298, 0.035243180114775896, 0.09280299701328788, 0.012243023624510636, 0.024792751862800548, 0.03792865208483168, 0.03987144712092621, 0.04345139448664018, 0.04792345255347235, 0.07371613942086697, 0.02985985969592418, 0.006552740748572562, 0.022604846229244555, 0.02516499108501843, 0.03175347790654216, 0.03514970852328198, 0.003866645374468395, 0.028602832861776863, 0.029104989487677813, 0.040259318093636205, 0.09209694739963327, 0.029256506357342005, 0.012798558903991111, 0.043883237921233685, 0.04022976789357407, 0.04315131237464292, 0.003556228962094922, 0.02486829655910177, 0.09136056727064507, 0.029793498971100365, 0.02530069978508566, 0.0038631055420929833, 0.021112111596656696, 0.03747995723305004, 0.059499548348997316, 0.040007754628147395, 0.09143223413931471, 0.07557005994021893, 0.08508836597736393, 0.054487691926104684, 0.054411553511662145, 0.04025255309950028, 0.007040366971133543, 0.021024704411891953, 0.013458104271973883, 0.01947289821691811, 0.029380932716386657, 0.06463764621210949, 0.028060355988730277, 0.02633152000739106, 0.08564177235322339, 0.01580013913501586, 0.044998983586473126, 0.016429744993469546, 0.026290139549278786, 0.025152891109298383, 0.04706589285550373, 0.03387111106089183, 0.038395385790084086, 0.05595180086259331, 0.03729043900966644, 0.09989811200648546, 0.04979757645300456, 0.03398340521380305, 0.031540383983935626, 0.017209459761423723, 0.09231882156538111, 0.13637263301227773, 0.1072469244578055, 0.06628517673483916, 0.12135886507374899, 0.09590170359505074, 0.10257012184177126, 0.19599060607807978, 0.13352786137589387, 0.118840577346938, 0.18860950214522226, 0.10300452674606017, 0.13009576339806828, 0.072568573855928, 0.2688772907214505, 0.11102201510220766, 0.11928249363388334, 0.13881458554949078, 0.12404918856918812, 0.07862685341387987, 0.09327307250350714, 0.13670079968869686, 0.14834120364061423, 0.12139955003346715, 0.12245613762310573, 0.09539065137505531, 0.19419779442250729, 0.07050630915910006, 0.09896942148251192, 0.07150733830141169, 0.10110003501176834, 0.2781835342092173, 0.14570627574409756, 0.0723798121990902, 0.11271633739982333, 0.12973099654274328, 0.11763825400599412, 0.10659884887614421, 0.15131516834454878, 0.2219264129442828, 0.1458320218537535, 0.0819017823253359, 0.14772142975458077, 0.10793340512152229, 0.14195753261446953, 0.1441627171422754, 0.10482549081955637, 0.09674079356981174, 0.23753687100751059, 0.08206550603998558, 0.11777516880205699, 0.08288644520299775, 0.11623484002692358, 0.09234328275280339, 0.07605323115629808, 0.07086808367499284, 0.12977913181696618, 0.11143003177962132, 0.11955415191394941, 0.05102590125586305, 0.1788476359631334, 0.1433638778648206, 0.12618812093777315, 0.08519910967775754, 0.12074925564229488, 0.1910859921148845, 0.10722736907856804, 0.12498532262231622, 0.15376790958855832, 0.08828928707433598, 0.11365987427000489, 0.15028737778110163, 0.12823228910565376, 0.18998315557837486, 0.10335777207676854, 0.1139728349766561, 0.1108264070270317, 0.13578660945807183, 0.12593224538224085, 0.11804138523127351, 0.17163969416703495, 0.10968076171619551, 0.10600407222019774, 0.15620621160737105, 0.14004642516374588, 0.10751727995063577, 0.06912634535027401, 0.1211891770362854, 0.1785778911518199, 0.08524398119854075, 0.2258955171065671, 0.11048530068780694, 0.05899606179445982, 0.14260991689349922, 0.1623523953769888, 0.29208609248910633, 0.11871449196977274, 0.10763531111712966, 0.13764236202197416, 0.14760255041931356, 0.1228078223232712, 0.19322458521596023, 0.15768883776451859, 0.1632104164787701, 0.12354506419173308, 0.2658884525299072, 0.10560352621333939, 0.14702545638595307, 0.07105210915740047, 0.2519959365682942, 0.12261993597660746, 0.14591673016548157, 0.13853943959942885, 0.09782866162381001, 0.12995800721858228, 0.08619519908513341, 0.06761916301080159, 0.10220410648201193, 0.23332970961928368, 0.23436735251120158, 0.1536067168095282, 0.11080959971461977, 0.11853033756571156, 0.11524856223591737, 0.12404004191713673, 0.12855475608791622, 0.17877360779259885, 0.14966323412954807, 0.09335329569876194, 0.09901976878089563, 0.32127466052770615, 0.07748738955706358, 0.08070654288998672, 0.11696444159107548, 0.06306230503001384, 0.09934202541730233, 0.18385962130767958, 0.15934386609920434, 0.2231546698936394, 0.1370612374906029, 0.11468472677682127, 0.1179246229252645, 0.11962961857872349, 0.09810433004583631, 0.10959168363894735, 0.14222597463854722, 0.10622231622359582, 0.22575313331825392, 0.18791967630386353, 0.14336777265582765, 0.09774495075855937, 0.11320714213486228, 0.1386693519140993, 0.10079116587127958, 0.14437104096370085, 0.17140892440719263, 0.09631013417882578, 0.12353861810905592, 0.147037751440491, 0.10568585286715201, 0.20124185644090176, 0.06066225203020232, 0.060035835286336284, 0.11929945700934955, 0.1089561338137303, 0.07489786922399487, 0.10414213820227555, 0.1628660870982068, 0.10987923999450036, 0.13214036582836083, 0.18087554643196718, 0.13532920900200093, 0.1417799192879881, 0.13659622387162276, 0.11343471599476677, 0.1681674811989069], [0.02733051184830921, 0.05148120164605124, 0.020886262912037115, 0.026971658425671712, 0.004039174353238195, 0.016427175042086413, 0.0389708072346236, 0.08515162579715252, 0.051408778210835795, 0.019238298126895512, 0.043504523778600354, 0.035064352210611105, 0.011377206155365067, 0.021803063806146383, 0.07004189265093633, 0.04281439598915832, 0.01181813093301441, 0.03516502645132797, 0.0452983566293759, 0.012837521232930678, 0.040329563431441784, 0.0835038170750652, 0.06506589680377926, 0.020440278807654977, 0.003731049904932401, 0.028463343025318215, 0.033395295164414814, 0.04628277523443103, 0.03805984343801226, 0.038866197490798574, 0.04331375365810735, 0.020441954789151038, 0.0029311268798275186, 0.07523188487227474, 0.01322220902823444, 0.05329965513997844, 0.020156878479091183, 0.012793960132902222, 0.02445618492285056, 0.02729386417195201, 0.027778507809021642, 0.056141838165266175, 0.03443767762343798, 0.0471142520462828, 0.060358546541205475, 0.025017216335982084, 0.09848095090793711, 0.03278673406956451, 0.02438722880158041, 0.05053001429353442, 0.01737452019006014, 0.08176936621644668, 0.017945682131020085, 0.012969600618816912, 0.021999967883207967, 0.03636955503108246, 0.04015325289219618, 0.009002608396778149, 0.00909488576663924, 0.029069678525307348, 0.021533164628116146, 0.010960954607331326, 0.03194584258432899, 0.018671422830915878, 0.0701172100380063, 0.0091973080831979, 0.05978831249688353, 0.028336212704224244, 0.027336649197552885, 0.04058493008571012, 0.04279331729880401, 0.06919922679662704, 0.037542416381516626, 0.006802955201627421, 0.01726556273310312, 0.022258399819423045, 0.011366322453665947, 0.03149115626833268, 0.008985718811995216, 0.01201064488850534, 0.0524927107617259, 0.05108336977926748, 0.0022715081452458563, 0.011378961016557046, 0.0647746492177248, 0.046910671184637716, 0.0755004897447569, 0.06295981910079718, 0.014629486416067396, 0.016520085145852396, 0.02157345773386104, 0.01574482156762055, 0.026032211425315057, 0.04755354579538107, 0.030610238002347093, 0.042087362680052004, 0.021182007488927672, 0.015619867647598897, 0.017849313194996545, 0.00227557702289362, 0.013401827425695956, 0.0761661800955023, 0.047946000272142034, 0.02831138001887926, 0.03708234249747225, 0.024379300119887506, 0.013532285961056394, 0.04516995405512197, 0.05515196413866111, 0.05061862078894462, 0.031651324459484646, 0.02567902037740818, 0.04750812466123274, 0.020051871792280247, 0.028333988805700625, 0.024582005671358535, 0.01684287273591118, 0.003605186323901372, 0.014177677088550158, 0.03145860015813794, 0.05144790932536125, 0.05382413217531783, 0.05159807251766324, 0.06078849347042186, 0.010896930587477982, 0.02337618957140616, 0.05116645299962588, 0.04399575599070106, 0.03214176617828863, 0.030889862283532108, 0.016222776545743858, 0.05368536837132914, 0.020165550156629512, 0.019973696076444218, 0.007474304110343967, 0.014605983659358961, 0.07585259513663394, 0.014620492434395211, 0.03334091058267014, 0.026742481526785662, 0.0771238576354725, 0.018483539876927222, 0.050636981946549246, 0.01781150183108236, 0.020344291547579423, 0.017330283099519353, 0.007735821684556348, 0.05865921665515218, 0.055485776226435385, 0.042937984357454946, 0.042573091973151476, 0.05259513562279088, 0.03411716142935412, 0.053443996501820426, 0.01160399885182934, 0.054345925604658465, 0.032599943556955883, 0.038352977351418564, 0.025970069491969686, 0.013931760730754052, 0.016958189762330482, 0.022041451817910587, 0.007158433336631528, 0.01738895262990679, 0.05879878452313798, 0.02876300783827901, 0.041295434281762154, 0.0587908388780696, 0.02643201613266553, 0.019540197016405206, 0.05858159903436899, 0.08212685239102159, 0.03290601713316781, 0.039102792473776, 0.027979586572785462, 0.045045581978878806, 0.02463769304033901, 0.012282660247624984, 0.02565902903942125, 0.03866122902504035, 0.03464638142447386, 0.0010581013588567398, 0.01752823551318475, 0.08161924034357071, 0.054972946244691095, 0.09083772889737572, 0.09007501482431378, 0.04363962010081325, 0.06264368285025869, 0.03472700156271458, 0.017174092819914222, 0.04358190730480211, 0.025200929692281143, 0.023374135306637202, 0.057732968857245784, 0.02465651899443141, 0.011892528056965342, 0.05362213569294129, 0.020257213452298726, 0.027856878603675535, 0.020068568842751638, 0.0311760242496218, 0.029300512745976448, 0.024127088653455888, 0.021732874447479844, 0.024053031645183052, 0.015394256450235844, 0.029178179667464325, 0.07316547432648283, 0.04469908807160599, 0.030868457896368842, 0.019189681092809354, 0.03894709922107203, 0.03029355892379369, 0.10750450313623462, 0.041412213551146645, 0.022152098827064037, 0.01626440297280039, 0.006798182980024389, 0.04428100871986576, 0.052630249810005934, 0.002780443972109684, 0.03407507190214736, 0.01646617384228323, 0.014033157611265779, 0.09543289696531636, 0.035668750493122, 0.05911457472081695, 0.00915207015350461, 0.044393472506531646, 0.0666163493213909, 0.006948354229929724, 0.056183177911277325, 0.010307435478482927, 0.05791143035250051, 0.054453866955425055, 0.049463248678616116, 0.0802838427147695, 0.02447618983153786, 0.019819870491379073, 0.04413602953510625, 0.03176797141454049, 0.01939325008009161, 0.007582074131018349, 0.07793624047189951, 0.02036884772990431, 0.05242329662931817, 0.08316953679812805, 0.06495852542242833, 0.0638772730848619, 0.036239635931061845, 0.015030775418771165, 0.02258262251104627, 0.013089304374131774, 0.049164279364049435, 0.015031443775764533, 0.03327520803681441, 0.0058471347271863905, 0.05839397731636252, 0.04901526628860405, 0.05206682825727122, 0.04980677738785744, 0.048815271484532526, 0.017511718274493302, 0.014940167245055948, 0.008814256405457854, 0.033679129755390544, 0.0291250775169049, 0.051891620337430916, 0.0311772795394063, 0.04400513334465878, 0.030118249223700592, 0.02080325093785567, 0.03368372683014188, 0.024096949824265072, 0.050291689046259434, 0.04970134322398475, 0.02842739932904286, 0.02632593736052513, 0.03750647438157882, 0.012886798990491246, 0.04074731369369796, 0.03779421054891177, 0.03655791295958417, 0.04158939261521612, 0.06293688461716686, 0.031834413563566547, 0.03837957592414958, 0.012553682401111084, 0.04807902706254806, 0.030343051268053905, 0.015871158002742698, 0.09332065816436495, 0.03844201132389052, 0.05252465958307896, 0.021959408452468257, 0.06637401053948061, 0.02456167506586228, 0.019709277765027115, 0.053303580465061326, 0.06566908050860677, 0.009813210078781205, 0.035420823975333145, 0.07473282236605883, 0.026596850948408246, 0.028143401889662658, 0.014243193037275757, 0.03270845487713814, 0.03613991163937109, 0.04809544421732426, 0.077743014054639, 0.020721745311415622, 0.02148958232386836, 0.05205546958105905, 0.04924434310357485, 0.05819066786872489, 0.014748187635892203, 0.05519272034455623, 0.0333463049360684, 0.018652727494814565, 0.050049485971352885, 0.04165155999362469, 0.04457756244976606, 0.019318446683298265, 0.05681935877406171, 0.01159847472860877, 0.04999211922820125, 0.009937281055109841, 0.027659224745418345, 0.02183031037982021, 0.016281259479001164, 0.10821144163076367, 0.04069633535774691, 0.03442907379940152, 0.0335143848455378, 0.0071583841428426755, 0.037747374669249566, 0.02020400103979877, 0.010290210867034537, 0.07286367552088839, 0.07764624817562954, 0.01900997618213296, 0.06412796463285174, 0.0535731318938945, 0.02762335229531995, 0.03354304277205041, 0.022328024297686558, 0.010090204188600183, 0.04527801075684173, 0.07088085370404379, 0.06426627721105303, 0.009642427055431264, 0.12685176889811242, 0.14825141988694668, 0.08905699516513518, 0.10672364503677402, 0.10579898501081125, 0.11456686524408204, 0.13070588851613657, 0.1859838023249592, 0.12918689288198948, 0.12240125771079745, 0.10442423913627863, 0.21249928165759358, 0.1578582136758736, 0.11179363155471427, 0.17385173189852918, 0.10701861778008086, 0.0880251537476267, 0.0620540427044034, 0.13794683425554208, 0.06130000030887978, 0.10260488997612681, 0.2042547826256071, 0.13930771765964373, 0.11952033372861998, 0.09231458750686475, 0.12292001130325453, 0.2479068131319114, 0.06474605575203896, 0.09885928167828492, 0.1869787382228034, 0.07517998372869832, 0.07302703282662801, 0.1738596978996481, 0.1275614486741168, 0.1330492092030389, 0.08634128088929824, 0.09745683121894087, 0.064094899621393, 0.1867508590221405, 0.16590238202895435, 0.11795403063297272, 0.129315244566117, 0.11194931462939296, 0.10857154695051056, 0.17475414276123047, 0.0709441542359335, 0.1508384296404464, 0.11740458011627197, 0.1359735865678106, 0.14369980698185308, 0.1356723170195307, 0.21069093155009405, 0.06508773206067936, 0.10983189182089907, 0.3205370929624353, 0.10702500279460635, 0.28193965979984825, 0.09798494859465531, 0.19950140054736817, 0.18146102715815815, 0.10017211801771607, 0.22282285269881996, 0.1466450560837984, 0.09110013195978743, 0.1518332434019872, 0.08207974849002701, 0.09636614724461522, 0.07390804269484111, 0.1702460375215326, 0.1417425320084606, 0.12026681724403586, 0.1914641261100769, 0.15934166764574392, 0.11166918144694396, 0.09330283304942505, 0.21452804708055087, 0.09120033122599125, 0.09918813367507287, 0.12109779193997383, 0.09256257848548037, 0.12191359459289483, 0.12386613339185715, 0.13454799806433065, 0.12890078180602618, 0.2254133772637163, 0.16468495449849538, 0.25437241047620773, 0.18532782181033067, 0.11181030316012246, 0.051393623131194284, 0.11182196717709303, 0.10133036372384854, 0.10318644198455981, 0.1161531579813787, 0.09716727997043303, 0.10817952334348645, 0.12288931437901088, 0.185727275375809, 0.13015884001340183, 0.1026205573497074, 0.13210432204817021, 0.14262476323970727, 0.20228243060410023, 0.11974838934838772, 0.14242949443204062, 0.09878935864461319, 0.16543985184814247, 0.1264492483543498, 0.09287718124687672, 0.1278256294982774, 0.05923849557127271, 0.18838610127568245, 0.12292747518845967, 0.08714589449976172, 0.09712430834770203, 0.11208619549870491, 0.16932949955974305, 0.08674640700753246, 0.17472580713885172, 0.08576251087444169, 0.1478571503290108, 0.08590455539524555, 0.11680552868970803, 0.15044460791562284, 0.13194420135446958, 0.07166496877159391, 0.1334688423999718, 0.2067139699522938, 0.05575179248782141, 0.09539415261575154, 0.06471398140170745, 0.15241181664168835, 0.25027237619672504, 0.11544544595692839, 0.12677656007664545, 0.12715986450867994, 0.14905456107641968, 0.18770061805844307, 0.14244480218206132, 0.16022844506161554, 0.16810696944594383, 0.1256326993129083, 0.09861195566398756, 0.09871093356715781, 0.10624443646520376, 0.06972837554556982, 0.15072930763874734, 0.21920030351196015, 0.1534639937537057, 0.09481834779892649, 0.1522899517523391, 0.1415031584245818, 0.06664450173931462, 0.1342307829431125, 0.14536817531500543, 0.1889063205037798, 0.20169555209577084, 0.11095415481499263, 0.10257827783269541, 0.137878790763872, 0.10005287227353879, 0.10978548002562352, 0.09955285303294659, 0.18854273429938725, 0.11345409495489937, 0.05965593031474522, 0.1597989731069122, 0.1199859037463154, 0.10533355748546974, 0.12671686256570475, 0.16202554505850586, 0.10961653837668044, 0.10595624228673321, 0.21824810174959047, 0.13551199276532444, 0.10861175015036549], [0.07282102280961615, 0.050602332555821965, 0.0667231303772756, 0.02166009308504207, 0.012596645542154354, 0.04253623734361359, 0.028348226166729416, 0.04083035959463034, 0.04089503076725772, 0.023353550250508955, 0.03223824707259025, 0.028578999319246838, 0.003014140126262126, 0.04261167686698692, 0.03375793141978128, 0.026712551347113082, 0.056414795839892964, 0.0252857940670635, 0.006362350607690002, 0.030844627746513913, 0.04179615241342357, 0.04168407878439341, 0.06977958458342723, 0.026400096149050763, 0.03693822505218642, 0.010687058009872479, 0.06348650476762227, 0.031818396744451354, 0.013897504890337586, 0.03813644664894257, 0.047425652122391124, 0.06675340660980769, 0.10911607130297593, 0.06340713652649096, 0.05783604511192866, 0.0242589907720685, 0.040030933384384425, 0.027294846351391504, 0.034475495772702355, 0.03306991387424724, 0.0585992680862546, 0.0554438020501818, 0.030477927066385746, 0.05099353174279843, 0.05501765491706984, 0.048109561138387234, 0.07028724412832942, 0.014224437481191541, 0.03571481962821313, 0.03360593279025384, 0.02760792919434607, 0.06179933422910316, 0.053009082696267536, 0.05212892099682774, 0.020807344200355665, 0.033783054178846736, 0.004903671223603721, 0.017029149258243184, 0.037116689940116236, 0.008904233541605728, 0.030818283624414886, 0.03189993290496724, 0.010139222406516117, 0.02906245891270893, 0.08363156486302614, 0.01901577935287995, 0.02662189058693392, 0.04787249118089676, 0.041125271269785504, 0.015727970150432417, 0.02512758514577789, 0.037440775228398185, 0.06564958619752101, 0.05649424550522651, 0.042682078267846785, 0.024490686732211282, 0.033092892462653775, 0.058058692807597775, 0.028611826843449047, 0.006355946933451507, 0.08645374128328902, 0.014441696760643805, 0.04185454374445336, 0.02830731898679265, 0.05424659486327853, 0.018704397936484644, 0.014726561028510332, 0.05754312832972833, 0.040383802128157446, 0.13960129262081214, 0.03501508039023195, 0.009576382697559893, 0.02136689979982163, 0.06628895617489304, 0.05451037874445319, 0.06212922438446965, 0.05860346821802003, 0.013558513884033476, 0.041131652891635895, 0.020727690974516527, 0.029529742231326442, 0.015405509953520127, 0.014214707289024122, 0.028540122655353377, 0.06899742369673081, 0.013980242906005254, 0.017561317488018955, 0.03870581556111574, 0.05695573413478477, 0.03701272141188383, 0.08138567501945154, 0.0319782663801951, 0.027498118479603102, 0.05267692623393876, 0.05189613938065512, 0.025208018686888472, 0.03828597201832703, 0.030822531253631626, 0.04257398085402591, 0.048974584721560986, 0.08078528009355068, 0.02912735739456756, 0.020921984388093864, 0.04915622515337808, 0.032198702051703415, 0.007336570831414844, 0.05386169248127511, 0.048335350451192687, 0.06696013587393931, 0.010531858391394573, 0.02308959843191717, 0.016071013707135404, 0.018034551558750014, 0.02395219964507435, 0.010571028521683599, 0.035148517694324255, 0.11609525180288724, 0.0485471483719136, 0.01697243730138455, 0.03193933543350015, 0.053645779245666096, 0.032285042240151336, 0.031184590754232237, 0.03194872296548315, 0.06617954918848616, 0.04237974002691252, 0.043819560802408626, 0.04500824898215277, 0.020938177626313906, 0.03739825143877949, 0.009713254237015332, 0.09367992888603892, 0.028719171083399227, 0.0920224781813366, 0.004249751759094319, 0.014363334447677647, 0.06637054322553532, 0.03216995930831347, 0.06362286316496985, 0.01697201152066035, 0.014460809395781584, 0.004389643627551517, 0.00940741051454097, 0.019551352132111788, 0.062366989840354235, 0.014597069405551468, 0.054278072102793624, 0.0173660300206393, 0.008353187619442386, 0.05024991843051144, 0.003525424108374864, 0.008172976352008325, 0.008931718450704855, 0.01269634354061314, 0.01615165589776422, 0.018944916548207402, 0.019470962695777416, 0.1389754390610116, 0.06418114142226321, 0.053244720944868665, 0.03445043068911348, 0.039603300259581635, 0.007568801986053586, 0.023992555515308465, 0.03282964462414384, 0.08890234346368484, 0.03448339731299451, 0.035480636837227006, 0.03839149439175214, 0.011760999132612986, 0.018940499285236, 0.04468297965026327, 0.06654329824128322, 0.051377633453479836, 0.03945727273821831, 0.025166448238970976, 0.03096505074894854, 0.04978182765522173, 0.05144685420340725, 0.03123052418231964, 0.033072780684701035, 0.016188508830964565, 0.044600354441042454, 0.04160314652004412, 0.029114360056285347, 0.0348405985028616, 0.042634974366852214, 0.021106328781960264, 0.040593547480446954, 0.05195922278133886, 0.05218341414417539, 0.023146758221888115, 0.007901665821139301, 0.0482900107412466, 0.025094572720783095, 0.03660982767386096, 0.03012586577928492, 0.027287920205188648, 0.09316511079668999, 0.04745183339608567, 0.0030196894825037035, 0.03615218633785844, 0.07130741474351712, 0.02530919504351914, 0.02155411270047937, 0.03466636088809796, 0.03204561098079596, 0.035791850316205194, 0.06041899722601686, 0.02184169110842049, 0.04529616156859057, 0.027749217148604136, 0.03956030149544988, 0.019800420285069516, 0.03209131031430193, 0.010253086519826735, 0.039684863561498265, 0.034304783147360594, 0.0726095980831555, 0.031893042381852865, 0.03743550640397838, 0.08480425657970564, 0.027804212411865592, 0.017749142766531025, 0.0267110602664096, 0.05847559829375573, 0.02156817533874086, 0.03223066444375685, 0.018924831911655407, 0.05587481088670237, 0.029804745689034462, 0.016824681212061217, 0.027723750033016716, 0.06340874465448515, 0.048945889475622346, 0.042497347109019756, 0.05078597466594406, 0.012198074920369046, 0.030687950618032898, 0.07727024478039571, 0.04691716815744128, 0.03707554357658539, 0.056186282208987644, 0.03449299858350839, 0.06563861428626946, 0.10332121939531394, 0.032757818299744806, 0.069077551897083, 0.0704588388491954, 0.06547785576965127, 0.020590531905846934, 0.03986980506618108, 0.07514575163700751, 0.04951399631266083, 0.003449393835450922, 0.025332998051973324, 0.01631503864856703, 0.05279846203380397, 0.038582834481660805, 0.037763669687722407, 0.0405587827387665, 0.03461578628048301, 0.037462773333702765, 0.037235701589712074, 0.028127098389502083, 0.040210195550961156, 0.10007734703166143, 0.030066504143178463, 0.028012544714978764, 0.050689022189804485, 0.03591514352176871, 0.006813262572645077, 0.05775231389062745, 0.047398229129612446, 0.045275703737778325, 0.04969955528421061, 0.04473975606794868, 0.02695155343306916, 0.0396533184684813, 0.05404548386910132, 0.04979325757761087, 0.03249074691640479, 0.09415006544440985, 0.016286175465211272, 0.02445887022518686, 0.036619944630989006, 0.020001119069222893, 0.007991155260242522, 0.04407144996470638, 0.039461438943232806, 0.032248408134494505, 0.048206995374390056, 0.05088606536654489, 0.01438155650560345, 0.018705856786774736, 0.027154739048065882, 0.054148563516459296, 0.04477150472147124, 0.052672776992299726, 0.025801209267228842, 0.06275702533977372, 0.061655070898788314, 0.025899717284898673, 0.0325973719092352, 0.09214445163628884, 0.04851256683468819, 0.0251732132331069, 0.0496254117627229, 0.08897107906107392, 0.024763026939971105, 0.026650663864399706, 0.03425862241004195, 0.04487014335713216, 0.03516259729596121, 0.019895164129723395, 0.04006545724613326, 0.08712252575371947, 0.057198310403951576, 0.005052796257327178, 0.014122853155380912, 0.04235929576680064, 0.010763898708059319, 0.060896631596343856, 0.025281327610303248, 0.023467174332056726, 0.02386452443897724, 0.0292053516022861, 0.03455424654696669, 0.0265892920683005, 0.0249443399786417, 0.028460510141615356, 0.014837484540683883, 0.17027613733495983, 0.3221262762589114, 0.14706379361450672, 0.12422799611730234, 0.138959154220564, 0.11187779703842742, 0.12005489718701158, 0.08364632978503193, 0.07453572829919201, 0.14958589470812253, 0.11979592751179423, 0.16755313559302262, 0.07301703800580331, 0.14858087577990123, 0.09118932538798877, 0.07718586895082678, 0.20259773225656577, 0.13502107267933233, 0.07163557463458606, 0.12259179034403392, 0.11097373733563082, 0.1441278268716165, 0.1802275183477572, 0.08172057276325566, 0.11556969928954329, 0.21001375360148294, 0.110332155334098, 0.13044571104858602, 0.11776059386985642, 0.16276098202381814, 0.14047688777957643, 0.13517875064696583, 0.222589694495712, 0.10756867897829839, 0.26988575660756653, 0.10275777748652867, 0.08411108556070498, 0.12432863643126828, 0.0691596885610904, 0.14966674894094467, 0.21624539207134927, 0.0994632321276835, 0.1235893860991512, 0.15430506505072117, 0.19432975591293403, 0.12098101606326443, 0.17581030965915748, 0.12932360411754676, 0.1226608787796327, 0.09590676546628986, 0.06478401978633233, 0.2010303299341883, 0.1888768585132701, 0.16363895205514772, 0.12024202357445445, 0.13146442281348364, 0.09647165944001504, 0.08193952244307313, 0.09477827352072511, 0.09948530487184014, 0.12484618223139218, 0.12451775771166597, 0.1747773622295686, 0.10952330766511814, 0.16424142329820565, 0.2302614828305585, 0.11023286530481917, 0.13615274695413454, 0.10307548793831042, 0.15584341250360012, 0.0945626554478492, 0.1451919733413628, 0.13023474094058785, 0.13681309723428317, 0.13618001049118383, 0.07753181324473449, 0.1451578973127263, 0.20841276379568235, 0.1843405533581972, 0.06801533925213984, 0.14145951505218232, 0.07216839425797973, 0.13931398732321604, 0.11731531204921858, 0.11454196300889764, 0.10026736397828374, 0.15875343206737721, 0.2468829309301717, 0.12286650203168392, 0.31359413266181946, 0.11995000924382891, 0.14638794559453214, 0.15635673781590803, 0.16303820429103716, 0.12511280578161987, 0.09960632159241609, 0.13061146358294146, 0.09904988216502325, 0.14779229595192842, 0.08198144233652524, 0.15733557886310987, 0.11521338698055063, 0.1755804627069405, 0.12035417184233665, 0.15275839875851357, 0.08526671212166548, 0.20307415883455956, 0.12058591869260583, 0.1545710779194321, 0.14092710933515004, 0.21814765142542974, 0.11194183717348746, 0.10703401373965399, 0.13183381727763585, 0.1584978550672531, 0.09077151066490582, 0.12759608110146864, 0.153715974518231, 0.09645177836396865, 0.19239698962441512, 0.11844477429986, 0.11225235515407153, 0.15068932835544857, 0.16642636034105504, 0.1943386040095772, 0.12153134867548943, 0.1286254594368594, 0.12122880348137446, 0.15327123552560806, 0.16761235812945025, 0.08080554114920752, 0.08231951562421662, 0.1438615968716996, 0.16226651998502867, 0.12973932895277226, 0.10975269999887262, 0.1858072475131069, 0.13022772488849504, 0.11798548751643725, 0.1228936705738306, 0.18481375010950224, 0.13848466825272354, 0.16971565383885587, 0.05732324905693531, 0.19463984641645635, 0.15455403311976365, 0.13168193399906158, 0.10575818470013992, 0.1937378291040659, 0.122963654675654, 0.1256453064935548, 0.17876793523984297, 0.15671129950455256, 0.18903586640954018, 0.16633608804217406, 0.2137530922357525, 0.13569013534912042, 0.11418562355850424, 0.11696098106248037, 0.08516771386244468, 0.11920125942145075, 0.1865808181464672, 0.10448642687073775, 0.10342090297490358, 0.16457265695290907, 0.1771920919418335, 0.12171494668083531, 0.08409345722092049, 0.16132621972688607, 0.12641655653715134, 0.060264766216278076, 0.0928822091913649, 0.13050524571112224, 0.123204127486263, 0.06084556505084038, 0.09536151508135454], [0.018656579877382944, 0.057077008698667796, 0.03426465458635773, 0.024807291171912636, 0.015259557071008852, 0.03631394908630422, 0.02692774194292724, 0.04210483156410711, 0.011114133887791207, 0.01930160544413541, 0.06310779401766402, 0.032086289155163934, 0.03630608825811318, 0.016002771743972386, 0.06188387969242675, 0.059461272188595364, 0.03801313987267869, 0.08177476735519511, 0.005555266705674252, 0.017934001150674055, 0.03546795501772847, 0.030129791104367802, 0.04074826364272407, 0.08412329919104065, 0.04456088745168277, 0.04330144503286906, 0.02027941002909626, 0.025054535762007748, 0.05757136217185429, 0.04867184953764081, 0.056087904809308906, 0.010587455854485077, 0.006980856905491757, 0.08290364606572048, 0.03591103159955569, 0.021530309692025185, 0.006865416894600327, 0.05335141039852585, 0.0258284897676536, 0.041659468319267035, 0.03461444617382117, 0.043683870762054405, 0.0349881459426667, 0.007491034239397517, 0.030943626005734717, 0.04728670511394739, 0.043208753756646595, 0.05622372037864157, 0.024625747431335703, 0.041514068442795954, 0.031221781258604357, 0.028452408433492695, 0.04532239373241152, 0.04244458083329456, 0.03883526647197349, 0.02206518697286291, 0.04421901097521186, 0.025797543481790593, 0.01189362134651414, 0.04477199326668467, 0.025323500258049796, 0.04049320911456432, 0.06663287843444518, 0.02722573925607971, 0.038282765940363915, 0.01121664441390229, 0.0302813554714833, 0.016576618987268636, 0.052125894730644565, 0.024201661348342896, 0.038118848843233924, 0.015351350984669157, 0.08581916854849883, 0.044055701166923554, 0.0370687107289476, 0.02870793454349041, 0.06492514149951083, 0.03222804529858487, 0.017707423040909425, 0.015720699647707597, 0.04550422754670892, 0.025701254273631742, 0.022720292177317396, 0.03615695983171463, 0.042570622105683596, 0.029745258523949554, 0.02928019401484302, 0.04169715415420277, 0.03401345752977899, 0.07530174683779478, 0.028594693834228174, 0.08960310050419398, 0.016491272852623036, 0.10112729176346745, 0.05834692091281925, 0.03991093446633645, 0.018395498261920044, 0.006539629331590342, 0.043511088604905775, 0.0713173213547894, 0.057952115312218666, 0.03284995996260217, 0.04547244157376034, 0.0291641848827047, 0.008331534718828542, 0.04579327667930296, 0.059152314838554175, 0.04504156165889331, 0.04321689956954547, 0.07577167983566012, 0.015485322635088648, 0.016212491651198695, 0.048257576767355204, 0.04003770177119544, 0.08779610746673175, 0.0483336337575955, 0.043814807664602995, 0.014304359576531818, 0.05955343760017838, 0.03560809285512992, 0.0420420840382576, 0.05201009933703712, 0.05344959441572428, 0.040950375476053784, 0.017948469213609184, 0.061008074187806675, 0.05286996605406914, 0.032024647641394816, 0.011456998480883027, 0.05175841373524495, 0.031877870338835886, 0.035895713671509705, 0.008203303474666817, 0.06322276499122381, 0.02092217268156154, 0.028874626848846674, 0.011166501524192947, 0.040121256573391814, 0.035046113189309835, 0.02882311586290598, 0.06006284776542868, 0.04111461487731763, 0.020199951882074987, 0.06378993205726147, 0.04227252810129097, 0.028942677125866925, 0.016938966865252172, 0.04019308289779084, 0.004891820609503026, 0.02071384716379855, 0.030264588871172497, 0.03499044956905501, 0.010240080699856793, 0.04739819181018642, 0.058397804253867695, 0.0714799254866583, 0.036770782965634546, 0.004840538205046738, 0.07316019532403775, 0.052299318103385825, 0.013591269313889955, 0.050588436158640046, 0.05303066350253565, 0.0649243069014379, 0.011461469178487147, 0.05325540787141238, 0.019801024181236113, 0.04637055391711848, 0.011101191680479263, 0.0178665547698204, 0.010721029713749886, 0.04086835416299956, 0.016983846867723123, 0.015725700450795035, 0.024894845938043933, 0.08918450546583959, 0.030705419502088, 0.030935001825647693, 0.04248269075261695, 0.05039210205099412, 0.005868973800845976, 0.04027539598090308, 0.042295079212635756, 0.02553727780468762, 0.04586374932633979, 0.019441125814669898, 0.025548680585676005, 0.021970219211652875, 0.012258067594042845, 0.03616380625005279, 0.04323919962293335, 0.04222754801490477, 0.008149206422136297, 0.03720398686294045, 0.016005160187238028, 0.031232671745653664, 0.015921021844925623, 0.039797300206763406, 0.04777399503758975, 0.042128074781170914, 0.00982163833188159, 0.08566571785403149, 0.08050514691110168, 0.06389792090547936, 0.05002292811072298, 0.016200164366247397, 0.019201709822352444, 0.022146821520956497, 0.06392888245838028, 0.08040623007608311, 0.06615755108318158, 0.010539825240682279, 0.020140395167150667, 0.010335019623328532, 0.07455733963953597, 0.03907248231449297, 0.025042376414473568, 0.03486977890133858, 0.007573952915013901, 0.03472078278926866, 0.03689198628334062, 0.02772471185640565, 0.03651158258851085, 0.02418886248155364, 0.015980615879275968, 0.05024102283641696, 0.019087317299896052, 0.012299039234806384, 0.017702288227155805, 0.008590950530820658, 0.05748345796018839, 0.03567542049235531, 0.025633648437048708, 0.05302028530942542, 0.05034946969577244, 0.044967068691871, 0.023836906367380704, 0.038649734641824446, 0.059438276636813364, 0.04303859753002014, 0.02187845583206841, 0.03326836840382644, 0.09226487124604837, 0.03307752364448138, 0.0025101546364437255, 0.060547694963003905, 0.012750654331674533, 0.020216394481914382, 0.004775756346394441, 0.026890196904007877, 0.03431918166045632, 0.03222284432766693, 0.03303380224055477, 0.08295330125838518, 0.03382575778024537, 0.04323605461312192, 0.04239565506577492, 0.038056186134261746, 0.028176156471350362, 0.02070243250844734, 0.015426047512197068, 0.022250689965273653, 0.006650410775494362, 0.042560986908418794, 0.06688660981931857, 0.029843585033501898, 0.02758652650352035, 0.02761539477588875, 0.04656456743500062, 0.07692768637623106, 0.041010744736662934, 0.029383880951042687, 0.007772765371815434, 0.0646819749048778, 0.01548597402870655, 0.07458633344088282, 0.03282936981746128, 0.05074677909059184, 0.05528146254697016, 0.014844712634970034, 0.0338673146574625, 0.03556169123787965, 0.04424545009221349, 0.08686433639377356, 0.05771318956145218, 0.09006370364555291, 0.013698956214024552, 0.027476614008524587, 0.06630693056753703, 0.045254089004759274, 0.03455934573763183, 0.007962343815181936, 0.011058062298356422, 0.03364517925573247, 0.040783672992672236, 0.011325077702557402, 0.006320545641106686, 0.07419065931545836, 0.06923613231629133, 0.048161587810942104, 0.010844455233642032, 0.003571633615397981, 0.06846992378788334, 0.003152013140996652, 0.010469864887584533, 0.013392799517272838, 0.07748836664749043, 0.020868086655225073, 0.021042459976992438, 0.052943980653903315, 0.031478538909660916, 0.02345490132990692, 0.0424328659261976, 0.061036097684076855, 0.02345450608325856, 0.0447408010118774, 0.10999214143625327, 0.03733325117666807, 0.04071308499468224, 0.044321632611432245, 0.07975797807531697, 0.04631899543372648, 0.02004671492613852, 0.02758995140902698, 0.05422607935698969, 0.0514172598985689, 0.03200330771505833, 0.0364268674914326, 0.018594074927802597, 0.02525784520964537, 0.020534515447382416, 0.03932759791080441, 0.02292977798996227, 0.022760531000260795, 0.043438970510448725, 0.03566365469513195, 0.02581212011032871, 0.03682539824928556, 0.03796111320012382, 0.035533257227923186, 0.035680092205958705, 0.010071589428532337, 0.02312132842572672, 0.044931533812944374, 0.03239502937399915, 0.00824769408375557, 0.031098080932029655, 0.011554125679789909, 0.04318579891696572, 0.04068218790260809, 0.024406205729714463, 0.058326510579458306, 0.1122108016695295, 0.15312088573617594, 0.08835686916219336, 0.1794212151850973, 0.1743047083062785, 0.11667157230632645, 0.10181686654686928, 0.1388964575848409, 0.11120912791895014, 0.07902043765144688, 0.1833901564989771, 0.040877192081617456, 0.18211649198617252, 0.08502490938241992, 0.15493497624993324, 0.14999016587223324, 0.13327733267630848, 0.15569083711930684, 0.05807450945888247, 0.07679217614765678, 0.152515103242227, 0.13006908340113504, 0.20589279330202512, 0.1410527333085026, 0.09656815390501704, 0.234929125223841, 0.09745546736355339, 0.09353004728576966, 0.16602155991962977, 0.10234881764543907, 0.2030350887881858, 0.11819587408431939, 0.173913872135537, 0.15234856360724994, 0.20193321577140264, 0.1233276751424585, 0.10895254436348166, 0.21868795529007912, 0.14810668836746896, 0.13516546493130072, 0.12915722733097418, 0.11491723358631134, 0.13188694656959601, 0.07464378500091177, 0.13392758635537966, 0.09022370898830039, 0.15008400726531232, 0.1133359077253512, 0.15110046629394802, 0.10822148394903966, 0.1516957857779094, 0.09873716573097877, 0.08351191199783768, 0.118265247504626, 0.11948713979550771, 0.1332431887941701, 0.14803188666701317, 0.2013202000941549, 0.1407833956182003, 0.14672912657260895, 0.11081083464835371, 0.09001685080251523, 0.18713543910001004, 0.10770000943115779, 0.055171417737645764, 0.09097899988825832, 0.181274253608925, 0.19063203861670835, 0.11672866424279553, 0.12116692108767373, 0.11137249879539013, 0.11767980749053614, 0.10649294991578374, 0.22674264093594892, 0.13488425287817205, 0.10851096055869545, 0.10228117448943001, 0.13663427611546858, 0.12428857572376728, 0.1867440872426544, 0.12795755027660302, 0.1429591452968972, 0.07867671216705016, 0.07153456791171006, 0.1078193433848875, 0.11905418017080852, 0.08480538973318678, 0.10269913170486689, 0.242288488894701, 0.16210274877292769, 0.17876535680677208, 0.1610515351806368, 0.09202513125325952, 0.14865144342184067, 0.17266756615468434, 0.19946059345134667, 0.09246453696063586, 0.1487566977739334, 0.13147126244647162, 0.130020798849208, 0.07715696335903235, 0.13241488752620562, 0.1159082611224481, 0.1497719082981348, 0.1257713104465178, 0.11243001597800426, 0.11910363180296761, 0.17557251027652196, 0.12678318257842744, 0.2946710394961493, 0.09500549454241991, 0.07456196724836316, 0.1403405022408281, 0.0829849209902542, 0.19409131870738097, 0.08828269849930491, 0.09634081753236906, 0.13110773052488053, 0.1256862628672804, 0.15544683592660086, 0.12393793596753053, 0.11024746737842049, 0.15731455784823212, 0.12242732702621392, 0.16177889757922717, 0.11476735877139227, 0.14257783575781754, 0.143547421587365, 0.08661511048142399, 0.17008236130433424, 0.21888493400599274, 0.14017897019428865, 0.10621547659060784, 0.1328486885343279, 0.08809775020927191, 0.11276965668158871, 0.15955624756004128, 0.11746840312012605, 0.11230364561613117, 0.12590580965791429, 0.17138970829546452, 0.11527613789907523, 0.07682439977569239, 0.1480386991586004, 0.1276316363364458, 0.15584842009203775, 0.09274200350046158, 0.07819523728851761, 0.144521865727646, 0.10822847285973174, 0.05999121482350996, 0.11085633720670428, 0.15700750718159334, 0.11358624643513135, 0.08357678673097066, 0.11274410305278641, 0.07051382732710668, 0.11629627458751202, 0.1916578614286014, 0.13477450662425586, 0.11876384860702924, 0.12220303049044949, 0.11236617940344981, 0.17978189725961002, 0.13017038867941924, 0.09001934781138386, 0.15081309314285005, 0.11201828771403857, 0.07526692442063775, 0.11585442615406853, 0.102623162924179, 0.13870728202164173, 0.0806335121659296, 0.11942235327192716, 0.13139354304543563, 0.19273361084716661], [0.03203147370368242, 0.030847341886588504, 0.03801053769088217, 0.010312404899325753, 0.058906963361161094, 0.025023216281884482, 0.0480057588512344, 0.01375370635651052, 0.042383115738630295, 0.0059293833494718584, 0.062154655876968584, 0.022706031067562953, 0.014658941621226924, 0.03977928849469338, 0.016906156304425428, 0.010708609130233526, 0.004926702822558582, 0.06588756878461156, 0.01982624702421682, 0.028501568295593773, 0.03218733659014106, 0.04435335751622915, 0.03510189216051783, 0.04641516759459462, 0.017502356187573502, 0.01168363172161792, 0.057674601274941645, 0.03847627055698207, 0.022587696256648217, 0.03767771965691021, 0.06697873451880046, 0.018293227767571807, 0.025109412281640937, 0.06355247194213526, 0.11017452486391578, 0.03171770893303411, 0.03417663163106356, 0.031789175633873255, 0.023444063429321562, 0.014182587137578853, 0.032557294238358736, 0.02354018809273839, 0.024010060022452047, 0.029656590960387672, 0.06370419915765524, 0.04741720775408404, 0.029969656839966774, 0.036674790616546354, 0.009799365419894457, 0.02261659675943, 0.07284517865628004, 0.0021902092599443024, 0.03844115636976702, 0.016406394907140305, 0.01953753037378192, 0.012324452915761088, 0.009462823925007666, 0.012698387627356818, 0.04287715369303312, 0.030489984633667127, 0.015331057698598929, 0.02422314546337085, 0.044992391618766954, 0.019803187011608055, 0.007222445482122046, 0.04120780148410371, 0.032430394619171105, 0.07491458154150418, 0.03599001646840146, 0.04991531924211553, 0.05416269061554756, 0.034082430614424605, 0.013274712371639907, 0.03003075552572097, 0.020147965921621238, 0.03314203196870429, 0.07234443338321787, 0.030814555074487413, 0.005396372888104192, 0.06033219224108117, 0.031126874565546, 0.00879628031647631, 0.0472752548355077, 0.020502356280173575, 0.016828621804182018, 0.03156696220061608, 0.013103044708259404, 0.020484030745657425, 0.08700946824891226, 0.008656939757721764, 0.056666844457920106, 0.025496309556599175, 0.017153149836563637, 0.008744955927665745, 0.04710798238271049, 0.03667072619178465, 0.09664733215634312, 0.06304107366928033, 0.02205486306255417, 0.03206507475780589, 0.032355752374444685, 0.03125463592420731, 0.045110344753733704, 0.010151955116141056, 0.008997775531107826, 0.06877002625593118, 0.0340281104935067, 0.04256677481212786, 0.04200474086350628, 0.04845443334696548, 0.01855489801216338, 0.04163025399403913, 0.022877997286351662, 0.04660191400242703, 0.025538453366607428, 0.028972532666687454, 0.041395786218345165, 0.0042619861695649365, 0.01669024137247886, 0.011111359527733709, 0.02891890804416367, 0.034797877938087494, 0.03036302055365273, 0.010701579507440329, 0.060767852435154576, 0.07047729500170265, 0.040800171571650674, 0.04779143678024411, 0.046127909794449806, 0.002649110338617382, 0.026434031381670917, 0.04396392252030117, 0.06828141997435264, 0.06399956545127289, 0.08744326247168438, 0.10954523791692086, 0.045056177303195, 0.006980584219231137, 0.05148821769814406, 0.04599417732762439, 0.02665607857384852, 0.035479133882160695, 0.030820292088070085, 0.04678982409781643, 0.021472444225634848, 0.03355114448017307, 0.054738359725368876, 0.021869962269972478, 0.033903168447847874, 0.023496743191831877, 0.06311527147356953, 0.04086472400064979, 0.054514351566987376, 0.053177149035036564, 0.06472519080021552, 0.033586190813886266, 0.06464614825589315, 0.059571276285818646, 0.0041329538299968195, 0.04695290320419839, 0.023603285064122508, 0.03751539372439895, 0.029855995438992977, 0.03555470232718757, 0.04135581372039659, 0.043526525276580026, 0.017543660310496176, 0.019730025669559836, 0.044315797210271866, 0.05837561615875789, 0.07207882763551814, 0.06345950585923024, 0.06174623886389392, 0.023238323129979626, 0.05398388985278351, 0.01912547810934484, 0.05406144301273993, 0.09640672363873039, 0.048496889283082316, 0.04561897799638765, 0.01457279481525932, 0.024490674857848456, 0.018320158822461963, 0.010812478422719454, 0.04112980727638517, 0.010296310048683413, 0.07267000127051558, 0.013322199644920017, 0.04436315216922334, 0.0693060824913638, 0.033538001256861856, 0.00956051770065512, 0.02804738070283617, 0.04688660015485116, 0.03076645711969052, 0.01706684018219156, 0.039562177644776444, 0.017126639473385045, 0.035440352213169844, 0.04349470537688051, 0.046287348560456715, 0.019177380949258804, 0.03690263589045831, 0.018741686828434467, 0.02802198483342571, 0.025485315592959523, 0.0542998225428164, 0.016118862300312946, 0.06898685212114028, 0.052010228258690665, 0.07830269687942096, 0.06658615451306105, 0.05893476294087512, 0.013284996418016297, 0.024892374374238507, 0.03605811424287302, 0.0761221499581422, 0.025842525264514343, 0.06137009976165635, 0.07095190989119665, 0.09257190155663661, 0.06102296803146601, 0.07944983496729817, 0.0153036364021578, 0.048717749038977284, 0.0044547075023209405, 0.007108940992371312, 0.015840830880084207, 0.0070124516163819605, 0.02033949939401022, 0.04507372421877725, 0.04528949835470744, 0.015856199698256593, 0.01743318632777248, 0.03026431406448994, 0.02076966515077012, 0.05766321545732873, 0.026745896254267012, 0.027106586810467497, 0.08431516853826386, 0.028598137399447814, 0.007238431767161403, 0.04315717491720404, 0.03541070023285491, 0.01987824825170849, 0.043702767962323766, 0.025842489641425864, 0.013300355058163404, 0.048449222198022265, 0.1124860697558948, 0.023585317456828694, 0.024309210845136216, 0.04331762130771365, 0.038384895638695786, 0.020565507534359182, 0.010708137548395565, 0.040865419499043903, 0.0333645303866693, 0.03835282128836427, 0.039709504560700486, 0.018869582197761962, 0.021964134448873143, 0.03822482583512153, 0.053306420134114366, 0.06619336416146585, 0.02980869815551809, 0.049062773917934725, 0.0600577180406877, 0.02976902082030262, 0.041677707340568304, 0.023259194867153252, 0.05125675583258271, 0.042088790996266265, 0.04660536774567195, 0.027591971747045006, 0.02039881013999028, 0.02498919962506209, 0.03397667414641806, 0.08473978218223367, 0.05191529442423156, 0.0413405941799283, 0.061554613789277415, 0.03420145922739591, 0.01728953028629933, 0.03081850414829595, 0.05544844662238445, 0.02989062786634479, 0.023626826836594512, 0.019214474762390767, 0.03410954826644488, 0.039214740573827706, 0.038282060263944526, 0.01696995895222894, 0.05924931141946997, 0.02785496852759804, 0.052592031325080564, 0.02984412107616663, 0.0030911877776296543, 0.031313481873699596, 0.01916066015006176, 0.0359310110631798, 0.03461278715570058, 0.03010434264849339, 0.010432916111312807, 0.00850211757434798, 0.03820235954065408, 0.01893599720538727, 0.04201904438169939, 0.012029504769348671, 0.04492810042575002, 0.020902563019522598, 0.02862456633842417, 0.05205250099035246, 0.08632794089083161, 0.022347922337108424, 0.013348893212553645, 0.013149710954166949, 0.03161797446331807, 0.019038837669151168, 0.06778108182230166, 0.05485342230115618, 0.02644545112603477, 0.03205391964209931, 0.02416600094043783, 0.016684906390894736, 0.020333292494927133, 0.04270153525950653, 0.03478263464889356, 0.0890906708581107, 0.014214372262358665, 0.027485482461218323, 0.011480914295784064, 0.023176077720043913, 0.05806655702846391, 0.03098265194733228, 0.0482819768866258, 0.036964589530336, 0.0854898551478982, 0.012793940625020435, 0.042708944861910174, 0.04224151226558855, 0.06293880487126963, 0.026737093958737593, 0.030031617265194654, 0.0473036175992872, 0.049583390089018006, 0.0938273813309414, 0.009446321105185364, 0.03305061294564179, 0.00907198605792863, 0.101654649179961, 0.010943109984509647, 0.11437528766691685, 0.16557967077408517, 0.11663497212742056, 0.14850280354065554, 0.1412790383079222, 0.15046971371131285, 0.16036478988826275, 0.08521354890295438, 0.0786412451416254, 0.1227079691099269, 0.20574031291263445, 0.07500080298632383, 0.10953569092920848, 0.11730294914117881, 0.0759842445009521, 0.09123365408075707, 0.13043405381696566, 0.10614170626338039, 0.0598299474056278, 0.10441192372569016, 0.07938719261437654, 0.11123124816055809, 0.06785424146801233, 0.08223019327436175, 0.10115727622594152, 0.12164428404399327, 0.15149442372577532, 0.10790707796279873, 0.14903652561562403, 0.07778617566717522, 0.14606383655752453, 0.0826361064932176, 0.2486753761768341, 0.11214860036437001, 0.33875654531376703, 0.12744455066110405, 0.13428431935608387, 0.22122092651469366, 0.12104132425572191, 0.1483905195657696, 0.1470482958746808, 0.11919061999235835, 0.08606589745197978, 0.15114132767277105, 0.1694146692752838, 0.11204554446573768, 0.12523636700851576, 0.1272863841482571, 0.12529938934104784, 0.09853986131825618, 0.11661533532398087, 0.06235011467444045, 0.0982548426836729, 0.07587852874504668, 0.1008042615971395, 0.1636540155325617, 0.06560871803334781, 0.097022609519107, 0.08973428846469947, 0.0959321426759873, 0.1730047437761511, 0.07640263597880091, 0.21076061709650926, 0.196829994608249, 0.12610770096736296, 0.08638202013181788, 0.08951015477733952, 0.20075317552047117, 0.14939608132200582, 0.12660128091062817, 0.19471147257302487, 0.06582384756101028, 0.11789934071046965, 0.17661910983068602, 0.19997261597641877, 0.08863308719758477, 0.15135267776037964, 0.10495421569794416, 0.07763893356812851, 0.15079774468072824, 0.12439844411398683, 0.14283061719366483, 0.1292534571673189, 0.10841851694775478, 0.11318526616586105, 0.14270719167377266, 0.14636274480393954, 0.15428248340530054, 0.15408553183078766, 0.14894395986838, 0.07867843564599752, 0.08344308140554599, 0.09988457523286343, 0.1571783215871879, 0.13206504844129086, 0.10024778824299574, 0.2602046089512961, 0.16726629169923918, 0.1404945296900613, 0.08919255967651095, 0.13769644126296043, 0.10947415458836726, 0.13711809872516564, 0.1997892486729792, 0.08593871284808431, 0.10129020802144494, 0.13304330594837666, 0.08030068395393235, 0.07979822198727302, 0.13244417309761047, 0.15024159023804323, 0.10829906764307193, 0.17892747239342757, 0.14426836504467896, 0.1256546974182129, 0.131150573225958, 0.10178098561508314, 0.14858990029564925, 0.07411285170486995, 0.09597228480769054, 0.1323801465332508, 0.1165358517318964, 0.1587234679609537, 0.03727097523265651, 0.1304929642272847, 0.14625078652586254, 0.0819814084097743, 0.07421596867165395, 0.09339224360883236, 0.12179551592894963, 0.10711156350693532, 0.10818395417715822, 0.15970893150993756, 0.10934141278266907, 0.19981643078582628, 0.1922240989016635, 0.19047047942876816, 0.15435157184089932, 0.11124252541256802, 0.12073128803500108, 0.06508252091173615, 0.09441823605448008, 0.11561715602874756, 0.10550338801528726, 0.16569416677313192, 0.08325731887349061, 0.15508573316037655, 0.12513762659260205, 0.11843055220586912, 0.09625102699335132, 0.12020630549107279, 0.07341497165283986, 0.1694481074810028, 0.1303154458957059, 0.10402780505163328, 0.07050941684948546, 0.09904996358922549, 0.21648965110736235, 0.09203708704028811, 0.14500205138964312, 0.06322137399443559, 0.15956182511789457, 0.09784874626036201, 0.09045272134244442, 0.0883829045508589, 0.13753500421132359, 0.11390528003019945, 0.12005484290421009, 0.06879603450319596, 0.1901755609682628, 0.2717740109988621, 0.1343714568231787, 0.11510397999414376, 0.1278306913695165, 0.2587989829480648, 0.1342009545436927], [0.054779305921069214, 0.009478273319213517, 0.027894964774272273, 0.020291637230132307, 0.028493313917091916, 0.02879442400964243, 0.0743990306343351, 0.0053957842589755145, 0.05472171186868634, 0.06058405765465327, 0.019403066785473908, 0.029246525107217685, 0.029174695390143564, 0.020165041255365525, 0.04239126494420426, 0.07976710437131779, 0.03724667689363871, 0.03142998633640153, 0.0773083988044943, 0.020433133833908608, 0.03450242682759251, 0.0359762930976493, 0.04750621458515525, 0.0312939027457365, 0.035429953664009056, 0.020992513014269725, 0.02512515429407358, 0.043687857155288966, 0.042375482219670496, 0.036268127616494894, 0.0511385821737349, 0.00903395501830216, 0.055165578943810294, 0.03330967761576176, 0.03856380496706281, 0.04526091506704688, 0.0337238316424191, 0.03013704125104206, 0.024112888611853123, 0.03449471527710557, 0.051765141409954855, 0.04826902026044471, 0.013147118102226938, 0.03615366554419909, 0.09438775626144238, 0.022627307434699366, 0.030868230587137595, 0.08234272830720459, 0.022838489584890858, 0.03712046938017011, 0.022823605919256806, 0.04246667054082666, 0.042181634942867925, 0.030680028721690178, 0.05355252817805324, 0.051750491838902235, 0.04814521815361721, 0.007726886226529521, 0.05822682021451848, 0.019486211073983992, 0.015005316784871476, 0.03360849425994924, 0.049542677987899096, 0.022317505308559964, 0.004373501279457871, 0.05395357630082539, 0.03347118591357555, 0.007145170521523271, 0.025433711308453764, 0.011989608606589692, 0.04074589555550899, 0.06117637122848204, 0.030302081323627914, 0.01430649696184056, 0.02731420156279845, 0.011541012142385756, 0.0266126625106803, 0.028469232709280083, 0.0408045786565968, 0.01790486485697329, 0.03950568960447397, 0.036033815903855224, 0.06738156040332147, 0.06878705748489924, 0.04736151359975338, 0.06565738256488528, 0.03621989734736936, 0.010730449476146271, 0.008818010400448526, 0.04442639163296137, 0.01848156873269805, 0.03234410532084959, 0.05193626794165798, 0.04868339481098311, 0.03442749281280807, 0.056756584106811454, 0.043440242763608694, 0.06138067812259708, 0.02528876774678273, 0.05194686326597418, 0.016900119039097, 0.052841308127556524, 0.03299535305372306, 0.10653467303408043, 0.08807795055742774, 0.010966460070838886, 0.023418959329969118, 0.05456136047307934, 0.021242408979950205, 0.06927461882254907, 0.018359766607838016, 0.027177661657333374, 0.05666608789137431, 0.08115556343857731, 0.01543417975439557, 0.039284314161964824, 0.04824729356914759, 0.03987890422078116, 0.035857966768422296, 0.05286927055567503, 0.03573308579091515, 0.03603666575093355, 0.024334006211055175, 0.045513679539518695, 0.027414383865626793, 0.022795041291309253, 0.020627471352262155, 0.05016648915729352, 0.006530630260905517, 0.03281774651259184, 0.05848117585160902, 0.06270863900759391, 0.07513078315449612, 0.029118404124996493, 0.06337737598057304, 0.05329313441844923, 0.07658519582556826, 0.05363536712580493, 0.02267916447349957, 0.018782646594835178, 0.01002124891549881, 0.020487209682219794, 0.06284708050744874, 0.07541577464767865, 0.02153731556609273, 0.07319630017238003, 0.006041604135784188, 0.028323189920878837, 0.03989780142105051, 0.05493548093363643, 0.046028009083654196, 0.045787488775593896, 0.08926641821329083, 0.08789667314184563, 0.04469259788415261, 0.02932811894321016, 0.01832548532235835, 0.019514349921207343, 0.013862845321585025, 0.015960049482860734, 0.017783873581460545, 0.04711714939081243, 0.04489077760704926, 0.03822337716285672, 0.0500901437896703, 0.0265871597720044, 0.03924797521904111, 0.014292753235037838, 0.038879561237990856, 0.06643364698226963, 0.07517300838870661, 0.08182581354464803, 0.025899873347952962, 0.045854816412819285, 0.040245174031172476, 0.026334234147465656, 0.0704425268673471, 0.05235342448577285, 0.025272211492327706, 0.020465801902381436, 0.0643509312399796, 0.010612699053516346, 0.036443386426461596, 0.0234098550863564, 0.023738401742385964, 0.012327880365774035, 0.04003524547442794, 0.030289087378020798, 0.037882111367902586, 0.03209055035508104, 0.031462074257433414, 0.06536279658653907, 0.031529815801020177, 0.016826869487496357, 0.0523560097041939, 0.03681529486285789, 0.021419686431597387, 0.03153201764715569, 0.03156153731314199, 0.04368367059422391, 0.019862014301387326, 0.043784314300864935, 0.031222802453807423, 0.1048714615670698, 0.037604376806744506, 0.07638444445495095, 0.02639650839513966, 0.006969605098545019, 0.07262519081788403, 0.12260052987507411, 0.07353610372436897, 0.08861938079020806, 0.07913979196122714, 0.018216007089774524, 0.018800261363919293, 0.0038615958016764906, 0.02100864009532545, 0.023858951970136592, 0.039038128086498806, 0.07542490094367947, 0.06486579682677984, 0.02874358816604529, 0.03283897787332535, 0.0037650423889447537, 0.031235877823616778, 0.020912413651655828, 0.02905114773394806, 0.10602581926754542, 0.013799455731974115, 0.003318215628886329, 0.04679083850766931, 0.03137754575748529, 0.05705119722655841, 0.07852815371006727, 0.018648030336147974, 0.02939857801954661, 0.03393377376986401, 0.015910392593858496, 0.021989642276561687, 0.030056906265339682, 0.02193784630591316, 0.05381785911907043, 0.018619294378108213, 0.03640340714316283, 0.06174576388938086, 0.006441814691892692, 0.015369008162191935, 0.05889728066644498, 0.06764236212308918, 0.05519552269418325, 0.01615721988491714, 0.06257224668349538, 0.017019385139324834, 0.02590007521212101, 0.04267281965751733, 0.023595771985128522, 0.05521800255935107, 0.027686551046956862, 0.07309088297188282, 0.01956879048209105, 0.040791133485202274, 0.06246412891362395, 0.011547118109384817, 0.027242382023749605, 0.05026548063116414, 0.02872403957215803, 0.042082931846380234, 0.04070253377514226, 0.02728647831827402, 0.01873881323263049, 0.026995844806411436, 0.025563837361655066, 0.02622057613916695, 0.026124459957437854, 0.10373357869684696, 0.04204313237486141, 0.012358409352600574, 0.03559938385816557, 0.051359635312110186, 0.06899299964840923, 0.024018529835822325, 0.032237524432795386, 0.03315394025828157, 0.021052559970745018, 0.04464464581438473, 0.034420585326318226, 0.06112206128558942, 0.02332755727028208, 0.03406440533165421, 0.0227372843905219, 0.003538506475576599, 0.024200836928295236, 0.06001575743513448, 0.008622180105053952, 0.019484153416539942, 0.05355284369683691, 0.050771036717508516, 0.009153111704758235, 0.0370720762626401, 0.02941433699535472, 0.0724645544375692, 0.03163656632282904, 0.009036558896436222, 0.04431597362937672, 0.04632593345429216, 0.03049248842788594, 0.02083730321776654, 0.03266773259799395, 0.02830027579329908, 0.03203674592077732, 0.023219783856932606, 0.041693870044712505, 0.057288949111742635, 0.039248338235276084, 0.008097798064617174, 0.0329688291198441, 0.02692556893453002, 0.040377135521599224, 0.09819494161222662, 0.010515010366881532, 0.03985456856233733, 0.05270885469924126, 0.014280186766492469, 0.030217624069856744, 0.04091035887332899, 0.061136554793587754, 0.021615377627313137, 0.017266419383564165, 0.07025377878120967, 0.011393258597568741, 0.048781409194426875, 0.013798780589630561, 0.026448937099693075, 0.008291628378044282, 0.008056716161913105, 0.043543810956180096, 0.0011128481086676142, 0.047495656580265076, 0.0460359886554735, 0.058278918133250306, 0.04448372105668698, 0.04058123206985848, 0.015189706979851638, 0.04060953376548631, 0.07488039016191449, 0.02723854830089424, 0.10131115439747061, 0.09787822860692229, 0.012342301779426634, 0.05025447140048657, 0.017446578912703053, 0.016599407585869943, 0.1998785167400326, 0.11343680588262421, 0.07558842109782354, 0.11902311683765479, 0.0922289631728615, 0.08783829198884112, 0.11135792386318956, 0.09131438617727586, 0.20930176680641516, 0.18193218830440724, 0.10514760496360914, 0.1084574241457241, 0.11354676926774637, 0.15184385568967887, 0.17988826440913336, 0.17325337257768425, 0.0977796713954636, 0.10557091582034316, 0.16261022511337483, 0.19967525478984627, 0.10608780344149896, 0.16487149734582218, 0.0926464047016842, 0.1395452863403729, 0.10138109778719288, 0.15271176983203205, 0.11996485559003693, 0.13118166370051249, 0.07592187356203794, 0.14343720035893576, 0.09043302347085305, 0.10812906747949974, 0.12869091092475823, 0.2122481015643903, 0.2482788131705352, 0.13814595714211464, 0.16036941749708994, 0.11510297576231615, 0.0735086841242654, 0.10571009692336832, 0.11126094763832432, 0.12380503809877805, 0.20310465219829762, 0.13239512858646257, 0.18508540838956833, 0.05974840106708663, 0.09382713705833469, 0.14598936055387768, 0.09824944833027464, 0.12812707546566213, 0.10619459806808404, 0.1490886913878577, 0.1469643475221736, 0.14763803780078888, 0.12966958912355558, 0.12580643141908304, 0.13885231209652765, 0.13935297594538756, 0.10030108716871057, 0.1003038352355361, 0.09172796005649225, 0.14368882828525134, 0.10262137159172978, 0.09131217415311507, 0.13184475526213646, 0.1321738176047802, 0.12476375379732677, 0.16223485954105854, 0.161548752071602, 0.08230337327612297, 0.10235473447080169, 0.10171605659914867, 0.11232149108712162, 0.12605298390345915, 0.07623951616031782, 0.11593528038689069, 0.08084076390202556, 0.14661761612764426, 0.12644482430602821, 0.09894232079386711, 0.12876439626727784, 0.14152044749685697, 0.21572093878473553, 0.15896714345685073, 0.08996724989265203, 0.112010043513562, 0.08511077798902988, 0.10860458482056856, 0.09168878822986569, 0.11803185859961168, 0.11708627933902399, 0.14079906977713108, 0.10086954345128366, 0.13048004492052964, 0.11815330279724938, 0.17761817122144358, 0.12728185153433255, 0.0816510704212955, 0.10016844714326517, 0.07840067055076361, 0.08067828190646001, 0.2275356990950448, 0.12562603609902517, 0.21274670266679355, 0.22732247625078472, 0.09069231205752917, 0.11725887150636741, 0.13845846323030336, 0.17167976844523633, 0.12148549327892916, 0.13413141827498162, 0.14140052321766103, 0.14806560985744, 0.16894857000027383, 0.1500765433801072, 0.16868855538112776, 0.14118392126900808, 0.11082049020166908, 0.0829835164227656, 0.12039967440068722, 0.09674557724169322, 0.118660141314779, 0.11625454468386513, 0.17455417849123478, 0.1952354915972267, 0.12936913381729806, 0.11292888170906476, 0.13570089691451617, 0.09502302788730178, 0.1342581007629633, 0.12206425650843553, 0.14734436784471783, 0.17919858784547874, 0.09592315208699022, 0.09638019970485143, 0.1852005422115326, 0.12440611155969755, 0.13025356350200518, 0.13907882065645286, 0.06306050012686423, 0.1096328707145793, 0.13992350175976753, 0.2789628995316369, 0.25737981338586124, 0.11434596138341085, 0.13337167618530138, 0.12682283616491727, 0.08380524268639938, 0.11096106908683266, 0.16387582863015787, 0.09652904993189232, 0.1648562845907041, 0.1311250195971557, 0.1662756305720125, 0.25738442742398804, 0.08109238504299096, 0.10156053637287446, 0.13366487116685935, 0.07868556704904352, 0.14914373414857046, 0.09325435172234263, 0.11649448823715959, 0.16672335511871747, 0.12031400256923266, 0.13605522790125438, 0.0717747218108603, 0.11747870328170912, 0.152734799310565, 0.16521098198635237, 0.115467226931027, 0.16232612250106676, 0.18084646442106792, 0.11768413654395513, 0.12285607973379747, 0.1589365822396108, 0.07759502556707178], [0.08111367747187614, 0.040786946924137216, 0.08910215167062623, 0.03217794905815806, 0.04968613386154175, 0.03713067115417548, 0.03522207089034574, 0.09931649892990078, 0.0324837647910629, 0.0520269270054996, 0.014542574561866266, 0.005428035876580647, 0.03630600683391094, 0.028830949549696276, 0.03544278136853661, 0.08965755293944053, 0.046682306831436496, 0.04087531593229089, 0.004817843329094882, 0.023228503031922237, 0.03520217963627406, 0.04829509636121137, 0.04622859760586705, 0.04576272564008832, 0.005267670062104506, 0.017231517238542438, 0.04720847002629723, 0.022486787921349918, 0.02914319440190281, 0.04065390656303082, 0.06696160150957958, 0.03429091728425451, 0.028325792102675353, 0.04114205144079668, 0.0189390947177474, 0.047034999156104665, 0.06799889834863798, 0.01209577643645129, 0.02670508067655776, 0.020423486762280976, 0.028960047622344325, 0.02440435841812619, 0.029024226857083182, 0.040349994120853286, 0.018409382784739137, 0.042909886222332716, 0.018036203791520426, 0.005637054772315813, 0.0168631694146565, 0.023225817729585936, 0.02693068848124572, 0.03698901339833226, 0.041384970370147905, 0.07293573593986885, 0.047090676347059865, 0.0121652643595423, 0.032696421058582406, 0.030438270087220838, 0.05206289275416306, 0.04119592712127736, 0.039869923809809346, 0.021034935023635626, 0.06231669682477202, 0.006963907948894692, 0.027927045909953967, 0.05455913148554308, 0.033601698731737475, 0.039397330954670906, 0.014556387838508402, 0.012260398361831903, 0.02974723306085382, 0.013849857313159322, 0.05079744190775922, 0.07420923081891877, 0.01908967351274831, 0.028315865135352527, 0.05439775550205793, 0.061647722364536355, 0.04016413998657039, 0.04333410292331662, 0.051103919212307246, 0.030460261407175233, 0.036780530121177435, 0.010050221512626325, 0.06915332390261547, 0.06070723211658852, 0.008428206451104155, 0.05020762873547418, 0.09537208665694509, 0.049278731258319955, 0.026672114052676728, 0.018859429617545435, 0.035503605247608254, 0.0601934182590672, 0.054495678283274174, 0.06514533289841243, 0.004266718527235622, 0.04338942727606211, 0.0005217150797502004, 0.03626835492572614, 0.02771024209713297, 0.03352687667523112, 0.05760490894317627, 0.06031735268022333, 0.054430935864469836, 0.01772095133284373, 0.036129058471747806, 0.050755505050931654, 0.03429342447114842, 0.024964824950854694, 0.027210774166243415, 0.01952794097763087, 0.10866739002189466, 0.039906866648899655, 0.03712444220270429, 0.03739892997379814, 0.0638037673862917, 0.03824648806559188, 0.06408630258270673, 0.04927323173199381, 0.019330461842140982, 0.02178187994286418, 0.07356237660029105, 0.059480800426432064, 0.05265183400894914, 0.00957328942604363, 0.03648796956986189, 0.06488575932702847, 0.045931212670568905, 0.043347025622746775, 0.010925407005873109, 0.0485659268285547, 0.009674946694368762, 0.02916922639789326, 0.06217743429754462, 0.0927988240229232, 0.010297360081624771, 0.02476437043930803, 0.03336966011141028, 0.03226923576689192, 0.08631339988538198, 0.018974585491897802, 0.02616782343414213, 0.017116167981709753, 0.02791445908535804, 0.019771775929257274, 0.025351749367213676, 0.09166305139660835, 0.0240355865098536, 0.017216974536755254, 0.002780057631233441, 0.04310676994334374, 0.024569629192618386, 0.01983935632077711, 0.03212470102256962, 0.037163152625518184, 0.03992141783237457, 0.06040824923132147, 0.037995660810598304, 0.027969985302271586, 0.007356896347898457, 0.029385509435087442, 0.009756655033145632, 0.03642809563981635, 0.017200557381979058, 0.027311007359198163, 0.019652667588421276, 0.026259391734908735, 0.035407541652343104, 0.010069232367511307, 0.04423967915187989, 0.09326516078518969, 0.014143690965803606, 0.023288646679637686, 0.0442848594060966, 0.020369724736415913, 0.031189883327377693, 0.05379567780931081, 0.07012086734175682, 0.05423157549064074, 0.030382986446576457, 0.048399682356310744, 0.03252280091068574, 0.06542846520564385, 0.006853217259049416, 0.05011803836428693, 0.011332065765080708, 0.02817864330219371, 0.029899252046431814, 0.06261092996490852, 0.03037737835464733, 0.01079870670634721, 0.028827641691480364, 0.06760009617677756, 0.03777389521045344, 0.027868350934503332, 0.05272664249475513, 0.03531924049769129, 0.03320364294839757, 0.012176912261306174, 0.032761672378650734, 0.004501210899824011, 0.05360518928085055, 0.027761710674635003, 0.009067791015175837, 0.06877174973487854, 0.07386830768414906, 0.011889769812114537, 0.027171617606654763, 0.006738961291765528, 0.012893760759782578, 0.010009003054749752, 0.06689660464014326, 0.0104978570016101, 0.07332512004567043, 0.06945301924965211, 0.03483311086893082, 0.04633945326453873, 0.038603373736675294, 0.021713005245796273, 0.022465149439605217, 0.03778721146019442, 0.06095425957547767, 0.05304476685289826, 0.024518511756988506, 0.0598206582612225, 0.041159523717526875, 0.06010450303022351, 0.017789115264479603, 0.062512196334345, 0.06286485133958714, 0.027850649652204344, 0.1012774719191449, 0.05724366368459804, 0.014419216895475984, 0.001697373584777649, 0.04013668306704078, 0.06540256552398205, 0.026444350202967013, 0.021944473896707808, 0.037806213833391666, 0.051362797285297086, 0.09565011638083629, 0.026733156759291887, 0.04647995751085026, 0.0600386376359633, 0.009933409164659679, 0.010202829127332993, 0.02930547283696277, 0.043867092180464945, 0.06235961416470153, 0.0515996976090329, 0.02031070406415633, 0.026854570422853743, 0.05277400423905679, 0.013548227293150765, 0.1112762214615941, 0.06309827417135239, 0.03558917190613491, 0.03528648082699094, 0.01641555512989206, 0.10950592359794037, 0.05187675363517233, 0.03267832113695996, 0.019429687410593033, 0.045894215548677106, 0.05798063413905246, 0.04594349754708154, 0.061095937687371454, 0.0082143186425258, 0.00853739376179874, 0.0303836683742702, 0.016532298776188066, 0.028498443641832898, 0.02370200173131057, 0.030683407826083045, 0.06423575670591422, 0.07089605967381171, 0.027157422654064636, 0.04627396445721388, 0.06288050514246736, 0.017302529320919087, 0.09798643458634615, 0.05124966174896274, 0.02101774942795081, 0.03317383490502834, 0.05808898939618042, 0.02223113628237375, 0.058794774381177764, 0.01846535174575235, 0.04585089448041149, 0.061808270535298755, 0.03645872471055814, 0.02009011572226882, 0.01343695433544261, 0.0772466521177973, 0.09135093207338027, 0.04223825529749904, 0.06544660923204251, 0.049336779929165325, 0.11739836473550115, 0.055771422505910904, 0.015369479744029897, 0.04423990985378623, 0.02516076381185225, 0.024874618809138025, 0.0576749269717506, 0.05523387010076216, 0.06463323573448829, 0.05884081298219306, 0.02294184743160648, 0.05919838058097022, 0.027333395622138466, 0.05038646681766425, 0.03022429746176515, 0.02517635654658079, 0.04722575570589729, 0.011858153472920614, 0.025877512226413404, 0.0678018449938723, 0.026581287051417997, 0.038352342921176126, 0.018054698959791234, 0.02212288280549858, 0.03398899294968162, 0.02799986968083041, 0.063712049807821, 0.0488192510924169, 0.066461168362626, 0.01773255767433771, 0.003410266961769334, 0.04726421507075429, 0.017201051016205123, 0.034969805141112635, 0.017208167152213197, 0.024880539027175734, 0.034071652085653374, 0.041789577409092865, 0.02493763605265745, 0.018084895464458635, 0.02967472141608596, 0.037708090884344916, 0.04621071142277547, 0.02449763493080224, 0.02934358614896025, 0.03313306852110794, 0.06870490725019149, 0.02043410753166037, 0.02707601371886475, 0.056827056753848276, 0.022026580026639358, 0.03166562119232757, 0.11995323907051768, 0.21826225599007948, 0.23478389158844948, 0.19264413921960763, 0.14895029738545418, 0.12442079505750112, 0.07546560625944819, 0.21071678373430455, 0.08233846710728747, 0.12418006440358502, 0.0998278089932033, 0.05811036324926785, 0.10991209466010332, 0.17558158907507146, 0.07141365297138691, 0.09875024110078812, 0.12121293933263846, 0.14222004424248422, 0.1564104235065835, 0.1135490695014596, 0.1407658215612173, 0.09992947389504739, 0.14404028228351048, 0.12216815379049097, 0.1831495886934655, 0.11010614889008657, 0.22981747665575572, 0.09513616003096104, 0.07821106751050268, 0.0967440844646522, 0.14482184605939047, 0.07114698192370789, 0.20764219228710445, 0.10979919321835041, 0.11859781108796597, 0.20371770858764648, 0.1273935791105032, 0.09343596840543406, 0.20288153631346567, 0.11400578463716166, 0.1613328286579677, 0.1056955966300198, 0.10636057451899562, 0.17040115062679562, 0.0805207464311804, 0.0986162575760058, 0.2101668989551919, 0.15688120467322214, 0.11895595544150897, 0.1465441986386265, 0.06437655950763396, 0.12492091607834611, 0.15689705525125774, 0.19983718038669654, 0.1220207895551409, 0.133320758917502, 0.14531801800642694, 0.15319665095635823, 0.09835044826780047, 0.09561351620193038, 0.1313562100487096, 0.16690977582974093, 0.11957351730338164, 0.05397039379126259, 0.08553320675023965, 0.13300241742815289, 0.2335373413349901, 0.13465452806225844, 0.1014182407941137, 0.08845762482711247, 0.06540403794497252, 0.08705211417483431, 0.1227514496339219, 0.13625312942479337, 0.12428873857217175, 0.15891887247562408, 0.10862824533666883, 0.14452888177973883, 0.1807529351540974, 0.08427402217473302, 0.22445767426065036, 0.09938990963356835, 0.18260787347597734, 0.11311379607234683, 0.16914841213396617, 0.30144925149423735, 0.15633555395262583, 0.18410911863403662, 0.09739273001572915, 0.16063838877848216, 0.12444144966346876, 0.12687855746064866, 0.12228335546595709, 0.22237634951514856, 0.10337808741522686, 0.1259188646716731, 0.05578110180795193, 0.1407387073018721, 0.09200126717665366, 0.09616264102182218, 0.09370556393904345, 0.11335855722427368, 0.14172071032226086, 0.1371153574436903, 0.10957923252135515, 0.07284091745636292, 0.18908763863146305, 0.1392306089401245, 0.1815724561789206, 0.10660724235432488, 0.14079190444733414, 0.0705090979380267, 0.165100720045822, 0.09565013673688684, 0.22448123299649783, 0.10266145944063153, 0.10065257509372064, 0.1363326401582786, 0.11103871384901659, 0.20281577269945825, 0.15227089848901543, 0.1006662475743464, 0.2524910500007016, 0.15952332504093647, 0.1218352916517428, 0.08552231626319033, 0.08591021437730108, 0.1576404853590897, 0.07997222550745521, 0.09163498040288687, 0.1297306301338332, 0.2070766876318625, 0.11741203043077673, 0.11558693407901696, 0.09647984257233994, 0.2159914028431688, 0.06641604578388588, 0.16845523432961532, 0.17525686935654708, 0.12340907220329557, 0.15672416452850613, 0.08300522954336234, 0.10616718525333063, 0.07435631685491119, 0.0759082417935133, 0.11450258083641529, 0.08484661073556968, 0.1585405892027276, 0.09930650410907609, 0.12195157898323876, 0.07990809716284275, 0.07753815754715886, 0.0930866382217833, 0.05291991980214204, 0.08788858500442334, 0.1256277867193733, 0.12135985573487622, 0.16061092168092728, 0.10481750446238688, 0.13460342080465384, 0.09861825246896062, 0.08309071817036186, 0.05832663271576166, 0.0999884589442185, 0.15525804034301213, 0.12857311724552087, 0.0876720305532217, 0.10747103100376469, 0.09603065917534487, 0.16520136035978794, 0.1507274348820959, 0.13467672972806863, 0.1264233418873378, 0.10591827146708965, 0.12176952803773539, 0.09952161328068801], [0.025246613758749196, 0.029856986100120202, 0.08074969771717276, 0.0983598663338593, 0.07922490060861621, 0.06639085177864347, 0.02644707282472934, 0.03582113588761006, 0.028449846963797296, 0.06869273433195693, 0.016005580878949592, 0.04570669900359852, 0.01747086368102048, 0.009252068403709148, 0.02570068769689117, 0.014272207194673163, 0.04013178404420614, 0.06233245919325522, 0.009765849182648318, 0.034899047509367974, 0.06800030970147677, 0.027226704472143735, 0.03503584695447769, 0.06887032730238778, 0.0795100142381021, 0.0030444984191230363, 0.024385744506227117, 0.010214150484119142, 0.0309409729338118, 0.033249471203557084, 0.01950278429181448, 0.02937472072829093, 0.0802863465089883, 0.03240300216046827, 0.057332931751651425, 0.026687491352536848, 0.07070109620690346, 0.05272728371034775, 0.026779037600915347, 0.04288390511646867, 0.014662897480385644, 0.041276747427348576, 0.04231944201248033, 0.03048479723344956, 0.03795764249350343, 0.05425400785835726, 0.04776560834475926, 0.033467135059514215, 0.05149434147668736, 0.020854366677148, 0.0478068530958678, 0.03545516123995185, 0.0182312300229179, 0.021008044680846587, 0.06787917084459748, 0.016755667415314486, 0.03688077009948237, 0.052977520639875104, 0.06961343171341078, 0.013248179107904434, 0.05141288674037371, 0.03574557762060847, 0.02954842908574002, 0.0238747363910079, 0.059244324187082906, 0.027258373397801603, 0.08385334403387137, 0.025076328610469188, 0.058069352592740736, 0.04744216766474502, 0.026027517659323554, 0.02597629165809069, 0.017060490790754557, 0.020520103363586322, 0.01058078755158931, 0.016954222028808932, 0.014868193339290363, 0.01939932127217097, 0.0108003436720797, 0.07779077613460166, 0.016964498441666365, 0.035720234337661944, 0.05628373340836593, 0.04545331706425973, 0.011090315612299102, 0.010352832015736826, 0.04127580426367266, 0.02567387029661664, 0.027137458457478454, 0.026167635140674453, 0.07164269246693168, 0.01013156004981803, 0.013215574652089604, 0.020708337459447126, 0.031471482145466974, 0.028054527372920086, 0.06052075033741338, 0.027581193218273774, 0.033512654581240246, 0.023725014246468033, 0.022857066177363907, 0.027641321598951305, 0.024003530819235102, 0.05497025924601725, 0.033892715615885596, 0.029583709514034644, 0.060905140425477705, 0.010854653614972318, 0.02640834034952734, 0.1022036654342498, 0.017575953488371203, 0.030824610963463783, 0.016680433148784295, 0.054892655195934434, 0.049862576715115986, 0.025737079226278832, 0.02957479017121451, 0.05994284884738071, 0.010570768133870192, 0.03287379689780729, 0.033116295135446956, 0.03403100783803633, 0.017803040499399816, 0.06422504942331995, 0.03096212287034307, 0.019497198252273456, 0.04157759628391691, 0.0343013701162168, 0.013544146753182369, 0.02159642953691738, 0.054161058738827705, 0.027674501961363212, 0.07679619307496718, 0.05617581919900008, 0.03371973329090646, 0.04013212670439056, 0.04392238599913461, 0.0062048028339631855, 0.01757160577523921, 0.038869491778314114, 0.02071130944282881, 0.032189256844243834, 0.07638808818800108, 0.028042671669806753, 0.035163669381290674, 0.06063137190150363, 0.040034393912979534, 0.02656699880026281, 0.054829612507351806, 0.05011029627972415, 0.05468112190387078, 0.029617185039179664, 0.023276645091495345, 0.03224982288000839, 0.03867067423249994, 0.028189316658037047, 0.0516897629547332, 0.00988338841125369, 0.014247284603438206, 0.015375250684363502, 0.01221626135520637, 0.023619317150275623, 0.03471482525180493, 0.016418469437797154, 0.0181211852135935, 0.035080121364444494, 0.07423007541469165, 0.005966612445523164, 0.02810127504302987, 0.04601130694417017, 0.018453119455703666, 0.038660024625382254, 0.03299840646130698, 0.002444798991616283, 0.020467449046139206, 0.030729992647788355, 0.021039145333426337, 0.019445324250097786, 0.0788081715415631, 0.07447374412523848, 0.015327456373987454, 0.026776910393631885, 0.04690203682652541, 0.04682763206905552, 0.0037134470102111144, 0.048869350725518804, 0.031390794153724394, 0.022545540572277138, 0.0233131892912622, 0.05691102206973093, 0.017076906249193207, 0.06569097004830837, 0.039666024036705494, 0.028624121897986958, 0.02195004466921091, 0.012532874276595456, 0.02356695629922407, 0.027553989053038613, 0.024177498716328825, 0.04725219143022384, 0.047822496720722744, 0.023099021586988653, 0.05349716650588172, 0.12269477838916437, 0.02453013845453305, 0.01809093103344951, 0.06160595174878836, 0.04074992944619485, 0.09929850418120623, 0.028198203770443797, 0.04935945996216365, 0.013684211648069322, 0.01952766447461077, 0.020648751906784515, 0.05504457240125962, 0.02664572073678885, 0.005186168676508325, 0.02780560849766646, 0.016721162213278667, 0.03930014777662499, 0.04138015955686569, 0.05355297940384064, 0.03193918276312096, 0.05931946515504803, 0.04718469755191888, 0.031026000156998634, 0.027226512786000967, 0.06468324376536266, 0.02613877534999379, 0.004480423555443329, 0.01311234403068998, 0.027145799349195192, 0.05332167020865849, 0.10379581392875739, 0.04052110708185604, 0.025076616987852112, 0.04818344342389277, 0.022941879662019864, 0.04464349230485303, 0.03527427737468055, 0.026071812425340925, 0.06503753403999976, 0.0518996134799506, 0.006023466894735715, 0.08687876204827003, 0.014791637625811356, 0.05278624501079321, 0.04207841280315604, 0.05774799162255866, 0.04207659772198115, 0.06568366222615753, 0.043129809599901946, 0.049916065630636046, 0.034112788271158934, 0.028559823919619833, 0.08601921424269676, 0.03971941117197275, 0.02457242475689522, 0.10128330053495509, 0.033998770639300346, 0.04987332131713629, 0.022986849570380788, 0.02476745777364288, 0.026663691736757755, 0.029290942009538412, 0.02029109270577984, 0.045468618028930256, 0.039954591409436295, 0.054004178049841096, 0.01608549534077091, 0.033873336655753, 0.045023767078029256, 0.02881058332111154, 0.033473798273397345, 0.02444761841824012, 0.04808689806876438, 0.014368504884519746, 0.0210154678539506, 0.020993734377303293, 0.040269492726240835, 0.11417777969368867, 0.014442037724490677, 0.07815455232879945, 0.02247049629555217, 0.0254492311006678, 0.05868367784257446, 0.025858686272321, 0.0114005341893062, 0.019067655051393167, 0.016741732002368996, 0.011590559617616236, 0.08838755251573664, 0.021458688624469296, 0.012239464708337826, 0.04763871551092182, 0.01287597805328135, 0.02589994459412992, 0.006759774505293795, 0.014283684614513601, 0.06371933048857109, 0.01499001242752586, 0.08499574594731842, 0.015157447728727545, 0.014514164300635457, 0.011325843598959702, 0.025165138666384985, 0.012224049240882908, 0.007198910495000226, 0.0738063370808959, 0.048240783025643656, 0.02119511508915041, 0.02140928109708641, 0.04614918865263462, 0.06421072554907628, 0.05849808494427374, 0.043802984191903045, 0.0135430017253384, 0.05452187652034419, 0.008350600704683788, 0.04932857983346496, 0.040970823128840754, 0.04030291736125946, 0.0325021904094943, 0.014706861460581422, 0.017525234692064778, 0.049513511160122495, 0.026771760312840343, 0.0430933383426496, 0.01655748769241784, 0.02151702736903514, 0.03339962421783379, 0.0494093899615109, 0.048881625424006155, 0.020238190723050917, 0.02483387278126819, 0.04329385222601039, 0.0067627062006587425, 0.01589684564221118, 0.00849858664774469, 0.06485833294157471, 0.012862876390240021, 0.029724946578166316, 0.05758405077670302, 0.020092020709333674, 0.03358224852542792, 0.022356178411947827, 0.05006470211914607, 0.07713692621993166, 0.011424366035498679, 0.031864757649600506, 0.0873164917741503, 0.046824578661471605, 0.17725094806935104, 0.09704565935369049, 0.11075905564108066, 0.1163546150284154, 0.13367606699466705, 0.12561504383172306, 0.1498305472944464, 0.1270152958376067, 0.18260027388376848, 0.1462765165737697, 0.1379985250532627, 0.054335900249757936, 0.07405356810029064, 0.12357775600893156, 0.09066156763583422, 0.13542967289686203, 0.10524669821773257, 0.1477392345134701, 0.16166493083749497, 0.16074341242866858, 0.17199838134859288, 0.10413607888455902, 0.07506565736340624, 0.11405261712414877, 0.14772178259279045, 0.13199684210121632, 0.1715447806886264, 0.22541961978588784, 0.10867356469056436, 0.10512314377618687, 0.1817326582968235, 0.05882784617798669, 0.15680071684931005, 0.1264758604977812, 0.10789627568530184, 0.09863243385085038, 0.1469281001814774, 0.10216945369860955, 0.2028797585517168, 0.15281901907707962, 0.157393145774092, 0.12346388426210199, 0.09538160650325672, 0.1344421330307211, 0.09160620373274599, 0.16758404964847223, 0.14797917806676456, 0.14784447529486247, 0.1680125987955502, 0.1409379116126469, 0.12634650458182606, 0.1756463348865509, 0.07756219804286957, 0.05850580667278596, 0.19935251639357635, 0.09448394538568598, 0.14860615799469606, 0.13265659527054854, 0.10935672731803996, 0.08699600611414228, 0.176885706239513, 0.10018794823970113, 0.09328283662242548, 0.11380679067224264, 0.15972214937210083, 0.1950835676065513, 0.1195533105305263, 0.0476998209820262, 0.20093262089150293, 0.13867522802736076, 0.10772383279566254, 0.159988135099411, 0.07078008446842432, 0.14467706025711127, 0.2793668992817402, 0.12939324895186083, 0.13468483143619128, 0.0811551631029163, 0.10260705450283629, 0.2682473659515381, 0.09387378634086677, 0.06398182176053524, 0.2901604915303843, 0.10028081932770354, 0.10643122358513729, 0.06643765033887965, 0.09728758422923939, 0.10459986435515539, 0.09903654216655663, 0.08975174038537911, 0.1795249224773475, 0.12356802581676415, 0.09645761376512901, 0.07034844120166131, 0.19094808665769442, 0.06391225156507321, 0.1573636702128819, 0.07514159221734319, 0.12816548054771765, 0.09130985356335129, 0.10777026494698864, 0.09431355845715318, 0.09236355059381042, 0.13089134570743355, 0.37937454719628605, 0.11669821159115859, 0.12430009724838392, 0.06629574152507953, 0.07392985759569065, 0.19935578693236622, 0.14173586879457745, 0.07945470006338187, 0.09673644416034222, 0.10524312912353448, 0.1040388448163867, 0.15905907138117722, 0.08389938942023686, 0.13736121782234736, 0.1535687731312854, 0.08910719997116498, 0.1175710926098483, 0.09126713978392736, 0.09881778247654438, 0.19510727562010288, 0.11800300729061876, 0.1810014961021287, 0.09640800606991563, 0.13332435515310082, 0.09059769034917865, 0.12754677874701364, 0.10040617188704865, 0.11415739650172846, 0.19619202241301537, 0.13149217489574636, 0.10052797570824623, 0.08132915305239813, 0.18477463935102734, 0.1141808738133737, 0.15620442027492182, 0.15323720020907267, 0.1328184665845973, 0.09236590511032514, 0.22061732890350477, 0.09024295902677945, 0.08137996853994471, 0.14755651860364846, 0.17930996258343967, 0.1362173706293106, 0.1651248758924859, 0.09536989498883486, 0.1671981532126665, 0.12427823485008307, 0.1118124880428825, 0.06815766197230134, 0.12347695284656116, 0.11488804300980908, 0.10238397254475526, 0.05869643430092505, 0.10509258255894695, 0.14193397387862206, 0.07199032631303583, 0.0551074420634125, 0.08402455198977675, 0.13274299991982325, 0.12192012209977422, 0.11856100734855447, 0.12259324240897383, 0.09319920039602689, 0.10330945359809057, 0.12933254720909254, 0.14574348660452024, 0.13565828491534504, 0.12160609609314374, 0.09284322056919336, 0.15310196817985602, 0.0982505746984056], [0.027004811646682874, 0.06007245582129274, 0.011679951517310525, 0.03695672530946987, 0.009459625480563512, 0.04891643427046282, 0.08756446918206555, 0.013187004086960639, 0.02425805609008031, 0.05864806832479579, 0.01491942273319832, 0.03799483978322574, 0.02215577139785247, 0.022624927473121455, 0.06823833300066845, 0.06735505004014287, 0.025166248071140478, 0.033234750386327505, 0.027444643134783422, 0.03280535646315132, 0.04175868031701871, 0.006340183716799531, 0.008138117463594037, 0.0433961108459958, 0.002964700580508049, 0.04556161125323602, 0.07653033626931054, 0.028322887972795537, 0.026706680322864225, 0.007848248151796204, 0.00994228949171624, 0.019010574989286915, 0.03378165300403323, 0.015004488972148724, 0.038645598970885785, 0.07345207394765955, 0.02809653038691197, 0.01427630045717316, 0.07932813971170358, 0.06396264636090823, 0.08243507013789245, 0.062323814657117636, 0.027737541257270744, 0.013512190298310347, 0.07775773147919349, 0.04729446416188564, 0.03464288018377764, 0.04673125634768179, 0.054306058279637776, 0.041586583480238914, 0.07138220965862274, 0.031549550992037566, 0.05042472940736583, 0.009317174686917236, 0.0641415896160262, 0.014090063798773502, 0.01965637578229819, 0.029339769389480352, 0.04746569925919175, 0.009855459909886122, 0.024681363554139222, 0.055232567313526354, 0.028547549221132482, 0.009587635352675403, 0.04175935545936227, 0.015297619492879935, 0.0687190547053303, 0.02652319597213396, 0.03392796211742929, 0.04400159139186144, 0.0184567665814289, 0.02926065559898104, 0.032386398408561945, 0.07494340570909636, 0.06908032031995909, 0.04053249289946897, 0.046744976325758865, 0.022773825197613666, 0.035480239894241095, 0.04268115206754633, 0.0752413436504347, 0.029899326685283865, 0.08400378203285591, 0.02025648911616632, 0.059547045800302706, 0.038548938264804225, 0.0033190468342841734, 0.012573838283840035, 0.08394511589514357, 0.019482334942689965, 0.035044837543474774, 0.028515820923660482, 0.029060056898742914, 0.029057407219495093, 0.024035116624353186, 0.026951748511887023, 0.027228958904743195, 0.04961319473971214, 0.047521050753338, 0.03023833635130099, 0.04485316301829048, 0.024082646306071962, 0.002151974235727851, 0.041049353379224024, 0.01622196739273412, 0.014397459670103021, 0.028024115433384265, 0.027064509157623564, 0.04619982772107635, 0.008513074218561607, 0.016652173861595135, 0.025447748501652052, 0.07847147567995957, 0.01955090938801212, 0.02066819872041898, 0.03430530222664986, 0.061096948704549243, 0.006083650830467897, 0.013106435687015099, 0.05095753546005913, 0.039246842065559964, 0.05395693165649261, 0.027262308900909762, 0.0110093137981104, 0.028464900263186012, 0.0927206500034247, 0.0454156821194504, 0.07102892361581326, 0.09954572841525078, 0.020413761659126197, 0.028118928827877556, 0.10084884134786469, 0.024688070872798562, 0.01630179364500301, 0.04460632894188166, 0.020502972050703, 0.13344145672661917, 0.06621562011007752, 0.028810016744370972, 0.073240398163242, 0.01934919280133077, 0.025958748135183538, 0.026781946819807802, 0.040404897781887224, 0.0638457890599966, 0.04250453279486724, 0.05834738231663193, 0.039273932576179504, 0.028684711682477167, 0.039644806246672354, 0.09320643357932568, 0.03021012625790068, 0.016593465315444127, 0.025969789596274495, 0.02747847489081323, 0.03150413664323943, 0.016578822529741695, 0.03695551073178649, 0.004851593660922455, 0.053792346202369244, 0.037744528214846335, 0.08166531965668712, 0.015097767181162323, 0.033050463667937686, 0.029759996304554597, 0.028916838512356793, 0.028273789178846136, 0.06756860536656209, 0.0952391412907413, 0.04080487381932991, 0.01661334639149053, 0.05030368554538914, 0.008354989129916897, 0.011858849819483501, 0.025272638969389454, 0.03501375724694558, 0.041982026903757026, 0.039349643513560295, 0.012276680657773145, 0.02166698021548135, 0.05162889836356044, 0.018949613706873994, 0.04326492627816541, 0.007285443217759686, 0.02063664175303919, 0.012989074573852122, 0.04104648317609515, 0.05199894422133054, 0.033728408361119885, 0.1023098493793181, 0.05801694933325052, 0.08165476843714714, 0.06029769552073308, 0.02954311276386891, 0.029677469482911483, 0.020925858823050345, 0.02854410565591284, 0.06486458903444664, 0.019802776497921774, 0.021016841887363365, 0.0024907801291971865, 0.11107534795467343, 0.017583568347617984, 0.05315186682024172, 0.023270616307854652, 0.02856567289148058, 0.0431355567915099, 0.039097523649356196, 0.04836469030539904, 0.02288688100608332, 0.061148374873612604, 0.06178775163633483, 0.039777931424656084, 0.0729097141219037, 0.048987191902207475, 0.012519627576693892, 0.0028422362478782554, 0.052497185700173886, 0.02736150223894843, 0.022139098096106733, 0.0867819825985602, 0.019702604373118708, 0.05852201687438147, 0.02140883156763656, 0.028843709400721958, 0.043926789691405635, 0.03450260324669736, 0.006689033836924604, 0.06050523224153689, 0.03117941353203995, 0.05089365478072848, 0.01960158916855497, 0.01960733805650047, 0.044789373941187344, 0.011556521756574512, 0.05117264463167105, 0.015274089594770755, 0.0673249705827662, 0.027818505752033422, 0.025415083825854317, 0.024910486170223782, 0.002879018783070413, 0.01914279771569584, 0.023690680374524424, 0.04451746121048927, 0.06315780883388859, 0.01114936257779066, 0.003007772287154304, 0.05872508883476257, 0.04083838666390095, 0.023312897521204183, 0.03046898397483996, 0.0980166836774775, 0.02190489155639495, 0.040352616658700366, 0.05597241136378475, 0.023962699974487935, 0.04455528275242873, 0.019009158547435488, 0.058730910665222576, 0.05439190313752208, 0.020752676330240707, 0.014090930627259825, 0.025984111774180616, 0.012303553189017942, 0.04861395353717463, 0.04905943213296788, 0.10079518279858998, 0.03776667220517993, 0.0578376328838723, 0.008404861453787556, 0.04196403894041266, 0.037453121173062494, 0.010648543514045221, 0.035355121429477415, 0.044393771061939855, 0.024829952545197945, 0.006331807626078704, 0.04793324720646654, 0.02192264372882034, 0.038838869492922506, 0.00596887748023229, 0.03725002207128065, 0.012257165990636816, 0.0681646101708923, 0.010314789949916303, 0.007445574937654393, 0.048462127934076955, 0.013605675460504634, 0.006709191840075488, 0.08880405088088342, 0.070389763984297, 0.04975010614309992, 0.036874144205025265, 0.02255516728785421, 0.0221557069370257, 0.0559560722405357, 0.04793523870674627, 0.03096339851617813, 0.03155723200844867, 0.042881560777979236, 0.04492973908782005, 0.010374745304164077, 0.027794144648526396, 0.0167553841269442, 0.047940707698996575, 0.023026387805917432, 0.05595708665038858, 0.016676378902047873, 0.018708404685769762, 0.0753983770098005, 0.004052600864919701, 0.06856430800897734, 0.0551698401437274, 0.02140168659389019, 0.04295625391283205, 0.017263603463236774, 0.019815241186214343, 0.019277500487597923, 0.011952259494656963, 0.03354126161762646, 0.031228122168353627, 0.024575732615111128, 0.0019424826979437576, 0.018554014220301594, 0.057936251163482666, 0.07638651398675782, 0.04313494610999312, 0.0674885789464627, 0.031195694979812418, 0.032023524665938954, 0.06090339659047978, 0.043223220123244185, 0.024164962781859294, 0.0028251789377204007, 0.03515515037413154, 0.012085420295729168, 0.04629374714568257, 0.010140069727120655, 0.019332144608987228, 0.023654297326824496, 0.01316245214547962, 0.04355804662087134, 0.04922835003318531, 0.04035026553486075, 0.022517040405156355, 0.009339050655918462, 0.048730352826948674, 0.018617450459195033, 0.037406933294343095, 0.02189837422754083, 0.017332486641992415, 0.1631779960755791, 0.18318283690937928, 0.0822857381509883, 0.11259183300925152, 0.11946183043931212, 0.16193763406148978, 0.1754650981830699, 0.11549572540181023, 0.10877548743571554, 0.11775896538581167, 0.09872736768530947, 0.22156711508120808, 0.11268494158451046, 0.16809261164494924, 0.14160875204418386, 0.1686461605131626, 0.13678012043237686, 0.09061924062137093, 0.08139186325882163, 0.09842743485101632, 0.19566322650228227, 0.11293297327522721, 0.16969613917171955, 0.09309186972677708, 0.1134888223771538, 0.21656209150595324, 0.1653117715780224, 0.2378337165074689, 0.07315953035971948, 0.1486880300300462, 0.17898683063685894, 0.1419304862086262, 0.1254985122276204, 0.13847572516117776, 0.20900797471404076, 0.14272658420460566, 0.10284172583903585, 0.14129183547837393, 0.15714568405279092, 0.20778228262705462, 0.22084610377039227, 0.15746642755610601, 0.14063603138285025, 0.11632598085062844, 0.10855679559920516, 0.13350278272160462, 0.0906648924574256, 0.13526921293565206, 0.10601581766137055, 0.12592737350080693, 0.17339775125895227, 0.09451097143547875, 0.17278568553073065, 0.12361352837511472, 0.0909281979714121, 0.09025220745908362, 0.09295657662940876, 0.12707652683768952, 0.10409768737320389, 0.08192099165171385, 0.03653135170627918, 0.2069138663687876, 0.1324911412916013, 0.10294062231800385, 0.15932022593915462, 0.1443859687341111, 0.2216606986309801, 0.14414113972868237, 0.09437496587634087, 0.12299462301390511, 0.08891638913857085, 0.10129879148943083, 0.18831788136490754, 0.19196027091571263, 0.12502018575157436, 0.16934244600789888, 0.15131773320691927, 0.049737275045897276, 0.11766266769596509, 0.21930082168962273, 0.1865493476923023, 0.08310794617448534, 0.17252317390271596, 0.08927331891443048, 0.11701541314167635, 0.08884612005203962, 0.053434008466345925, 0.11493824103048869, 0.09829526980008398, 0.13988577521273068, 0.11944003589451313, 0.1892331979636635, 0.09545211307704449, 0.12401736527681351, 0.10506694072059222, 0.20415734499692917, 0.12387948696102415, 0.18110419916255133, 0.19328265424285615, 0.11855842891548361, 0.10563506452100617, 0.2444384949547904, 0.10132370050996542, 0.0679564220564706, 0.09294986591807433, 0.13194070011377335, 0.0879564860037395, 0.06528245804033109, 0.13015536591410637, 0.06747916088040386, 0.07909039461186954, 0.10504158386694533, 0.1617865650249379, 0.21495382780475275, 0.15830991443778786, 0.20278762706688472, 0.1664993299969605, 0.0870189880952239, 0.16486133289124283, 0.10063416643866471, 0.10429594173495259, 0.16203243897429534, 0.05817050859332085, 0.1291036502059017, 0.1745475831308535, 0.1877341376883643, 0.11068151265914951, 0.13448227516242436, 0.2335950710943767, 0.16538274634097302, 0.08474655396171979, 0.15027988675449575, 0.09784548250692231, 0.16198293305933475, 0.21039853723985807, 0.08498136100492307, 0.217522992087262, 0.13049091505152838, 0.08549556841275521, 0.14875711846564496, 0.059362647123634815, 0.08051128765302044, 0.09604617727122136, 0.11438874980168683, 0.23999664187431335, 0.10467751590268952, 0.1703519161258425, 0.13312525940792902, 0.12459572138530867, 0.14611259608396462, 0.1958373657294682, 0.14882228496883596, 0.06585917209408113, 0.11611000315419265, 0.1090153292087572, 0.15533954596945218, 0.13238746114075184, 0.12038955065820899, 0.1106723795777985, 0.06983684615365096, 0.08573722187429667, 0.1920640053493636, 0.04770859104714223, 0.12935804655509336, 0.08925738691219262, 0.25014825857111384, 0.17309855802782945, 0.10194771523986544, 0.17883033332015785, 0.0913391187787056, 0.1166450415870973, 0.19614504064832414, 0.12713836851928914, 0.11997439579239913, 0.08074959593691997, 0.08984500502369233], [0.03127818448202951, 0.018973370914214423, 0.04452956627522196, 0.014426185450117503, 0.019008033875642077, 0.04983512997361166, 0.07907957876367228, 0.028393665960590755, 0.04184472534273352, 0.01380091967127685, 0.07054065660174404, 0.00649418741730707, 0.01381815446075052, 0.054970306743468554, 0.07408666703850031, 0.03128639814843025, 0.014133283086786312, 0.03748499196288841, 0.011240334615909627, 0.018260622463588203, 0.07681492064148188, 0.034990663307585886, 0.05405525477336986, 0.14751381160957472, 0.033966458801712306, 0.004632750002201647, 0.03971288366509335, 0.005458962654561869, 0.02638125662425799, 0.033027057602469406, 0.004752524579609079, 0.04517098203567522, 0.015267232998407312, 0.03898184021402683, 0.01646977516689471, 0.014932713537876095, 0.05052034177684358, 0.013485173578374088, 0.09182846466345446, 0.02099956977846367, 0.00400132779031992, 0.057931141794792244, 0.025782988905640583, 0.046760450316859145, 0.05977927441043513, 0.02407378294239087, 0.010257580966156508, 0.013798676264871444, 0.054507352478270016, 0.03492490987160376, 0.036314953318131823, 0.04119899749223675, 0.06089619733393192, 0.02097492029757372, 0.019017397658899426, 0.050444230503801785, 0.039979863446205854, 0.011617352420996343, 0.03449259824784739, 0.05469374265521765, 0.052000050233410935, 0.0824552769107478, 0.0243093957459288, 0.012071824150293, 0.024641984774331962, 0.022081787332094142, 0.04725995047816208, 0.029003752062895467, 0.02307784111638154, 0.022486260360372917, 0.04461237468889781, 0.06409627704748086, 0.009043893859987813, 0.011636530365129667, 0.10197793718959604, 0.06258862651884556, 0.021576597654659833, 0.01848003693989345, 0.048234716922576935, 0.03627141511866024, 0.026422341919637153, 0.022194897423365285, 0.0271570392817791, 0.060800137131341865, 0.029460311135543243, 0.06463924076940332, 0.018274337352652634, 0.020566203032753298, 0.05791944385107074, 0.03703593409487179, 0.03846826384376202, 0.07089043461850711, 0.03255589984889541, 0.07329281499343258, 0.018627318054703728, 0.022229875903576612, 0.02049565744320197, 0.05085502238944173, 0.016561504619728242, 0.01267713336606643, 0.009678374992550483, 0.027174939035571048, 0.014149670555655445, 0.017367108891318952, 0.0536295622587204, 0.03507153789645859, 0.04351256102589624, 0.027309789388839687, 0.06099757046571799, 0.06137740079845701, 0.010476640059745737, 0.030879623190100704, 0.025283373393384472, 0.02447117036873741, 0.05864494027835982, 0.05972118502748864, 0.08881555883479969, 0.05954093898513487, 0.011180340245898281, 0.016573572365034903, 0.030434144594307457, 0.033537661989352534, 0.03323559516242572, 0.031595779582858086, 0.08879069731171642, 0.021842571507607187, 0.024822139214458208, 0.059059151980493746, 0.049354106320866516, 0.035700896089630466, 0.08200612065515347, 0.0336067572103015, 0.07804415468126535, 0.05360793734767607, 0.06717027816921473, 0.061612268909811974, 0.05083262734115124, 0.021901000158063004, 0.10492008538650614, 0.03602556152535336, 0.02387967612594366, 0.047016909412507496, 0.06906867665903908, 0.01882598971548889, 0.0508121627249888, 0.06966785022190639, 0.023398727112050568, 0.05266397978578295, 0.017467867948913147, 0.03258905306990657, 0.005238429019560239, 0.022794428913454925, 0.03288973229272025, 0.007890658286799277, 0.018907171341457536, 0.021196456892149787, 0.013517310693194824, 0.03106536197343043, 0.048968654325498004, 0.029618542109216963, 0.07334190021668162, 0.07298216809119497, 0.01750877682518746, 0.042091074266604016, 0.001617317266728995, 0.02557507559790143, 0.050685487022357326, 0.07370596139558724, 0.02670181353044297, 0.015876253800732747, 0.04309003048443368, 0.003300140516200502, 0.020099169075755135, 0.04327779130211898, 0.035880789293774536, 0.03309985423194511, 0.050458920786955526, 0.039617556280323436, 0.07201937439718417, 0.045164386675293954, 0.02961143784757171, 0.04201688664034009, 0.06642295327037573, 0.019037360159148062, 0.03411199099251202, 0.02608916935111795, 0.039084818081132004, 0.02799709956161678, 0.016737898279513632, 0.013673214291754578, 0.06436637469700404, 0.06031417713633605, 0.034490942622401884, 0.11948171151535851, 0.021287034531789165, 0.04767711380762713, 0.042656188764210255, 0.021218297238062536, 0.04920387188238757, 0.07231479497360331, 0.04123515323070543, 0.02267465221562556, 0.018661712994799018, 0.0358414953308446, 0.026432436824377094, 0.040287718176841736, 0.02764714851842395, 0.024447481014898846, 0.09332235450191156, 0.05500137686197247, 0.024675959022715688, 0.02148174015539033, 0.0407076329658074, 0.020605739571952393, 0.10414657582129751, 0.015865531251100556, 0.020830402516626885, 0.056282400087054284, 0.03651357748146568, 0.0386727030522057, 0.019372408876993825, 0.0599452101492456, 0.023419812587755065, 0.07087647036782332, 0.03728956030681729, 0.056804458145052195, 0.00939043187203684, 0.05425634201882141, 0.016259351279586554, 0.02903991797938943, 0.015808274769889455, 0.023369237980140106, 0.020685959374532104, 0.015322301204183271, 0.026469532333846604, 0.056420729628631046, 0.009334808115714362, 0.049453464203647206, 0.019458150258287787, 0.03000265060524855, 0.02302674064412713, 0.04801738554877894, 0.06792689899780921, 0.07075926701405219, 0.030404309409537485, 0.059068128998790465, 0.009247916617563792, 0.056356991441654306, 0.049392752282853634, 0.05449398873107774, 0.009203555694382106, 0.011225258415964032, 0.018112681473472288, 0.03713135986721941, 0.04256248307813491, 0.0505768603512219, 0.023057493547509824, 0.04606151853555015, 0.0066752426126705745, 0.006451044464483857, 0.03713354474997946, 0.06218954614762749, 0.024613688167716776, 0.03732067792277251, 0.01986628907200481, 0.027216407703235745, 0.06906690568264041, 0.010645518944199597, 0.037732019421777556, 0.005112238893551486, 0.024208877568266222, 0.04755676544404455, 0.03440508419381721, 0.014712993720812457, 0.04228106067915048, 0.03133109664278371, 0.05933073562170778, 0.05198377217831356, 0.05609992166448917, 0.03463080565312079, 0.006737482085424874, 0.025597436719440987, 0.05105246590184314, 0.003037909632049767, 0.10255786071398429, 0.06250401998737029, 0.04581170229773436, 0.014951190046433891, 0.05704910733870097, 0.04938918997400573, 0.0809973290722285, 0.07389331169958625, 0.02692743151315621, 0.04766388576743858, 0.03855024105204003, 0.0448454752165292, 0.013185083832857864, 0.037146223176802905, 0.006372308109088668, 0.022287037389885102, 0.02769720065407455, 0.04824497297938381, 0.04685709745224033, 0.03102252266502806, 0.03212403266557625, 0.02192480316651719, 0.049827235218669684, 0.01625788564394627, 0.08585496127073254, 0.04983280599117279, 0.03612463442342622, 0.03665501810610294, 0.025848263974434564, 0.04716137969600303, 0.03224226399990065, 0.06138333119452, 0.09173104060547692, 0.041912114048110585, 0.04003066536305206, 0.011712217553784805, 0.0477180464326271, 0.005750291240734181, 0.04542666420872722, 0.03319671849853226, 0.04371654222320233, 0.03809037412117634, 0.07283729407936335, 0.07698095137519495, 0.058440999793154855, 0.0388184896936374, 0.018593990110925267, 0.05231946720076459, 0.04109421811465706, 0.030219520575233867, 0.0181703603427325, 0.015346122872350472, 0.016637515808854784, 0.06651359197816678, 0.004616082637637321, 0.02186592498661152, 0.02857610197471721, 0.06395470071583986, 0.06336259748786688, 0.0645638487434813, 0.03778091126254626, 0.017183381964319518, 0.025423183837639432, 0.03303250963134425, 0.011956869291939905, 0.05738707884613957, 0.0678875439667276, 0.011180578581323581, 0.10318216721394233, 0.1236651920314346, 0.1516762711107731, 0.1093686559636678, 0.09074361609028918, 0.13469009686793598, 0.14323218778840133, 0.10297205884541784, 0.1341522764414549, 0.07929891520845038, 0.08944905948426042, 0.12710000414933476, 0.07458996360323258, 0.09110382997563907, 0.2044109542454992, 0.09079488619629826, 0.16033511076654705, 0.25527133366891314, 0.23729341264281953, 0.117488704887884, 0.18127364292740822, 0.14094749252711022, 0.12972041139645235, 0.2458535661654813, 0.19196237437427044, 0.1079288317954966, 0.11146170579429183, 0.10348638160420315, 0.08663455050970827, 0.10418601906193153, 0.14630219233887537, 0.11372180416115693, 0.17491118290594646, 0.10860991810581513, 0.07819041290453502, 0.09904029446520976, 0.18334795162081718, 0.16684165091386863, 0.17288306887660707, 0.08310078084468842, 0.06902671605348587, 0.1745483973728759, 0.09423812571913004, 0.13906622704650673, 0.12329064070114068, 0.17444570788315364, 0.10679388019655432, 0.17999718285032681, 0.09906945111496107, 0.10151626874825784, 0.10564028245529958, 0.1404472357992615, 0.12874127179384232, 0.12241994456521102, 0.1502617970108986, 0.10905074195138045, 0.15797440601246698, 0.130445819614189, 0.1425613880689655, 0.11995971229459558, 0.11531515366264752, 0.11840951762029103, 0.12408464880926268, 0.08511339034885168, 0.07870375857289348, 0.12412033975124359, 0.12703238134937628, 0.08549564305160727, 0.06666265933641366, 0.09119982232472726, 0.08399528677442245, 0.2333055537726198, 0.12356064335576125, 0.14783374087086745, 0.21723424829542637, 0.11200892393078123, 0.10775978836630072, 0.0775398403140051, 0.13536320360643522, 0.10800576409591095, 0.08970326584364686, 0.09998083899595908, 0.07296424119600228, 0.14963352786643164, 0.12384078332356044, 0.17820948734879494, 0.09397896605410747, 0.12552743139011519, 0.07863058535648243, 0.10987285497997488, 0.21308415170226777, 0.17471790899123463, 0.13985118349748, 0.10044724361172744, 0.09762746920543057, 0.11685593027089324, 0.06593217567673751, 0.1433165432619197, 0.11928134012435164, 0.08973277533160788, 0.08065363072923251, 0.09331467348550047, 0.1590865384787321, 0.13879511159445557, 0.12079813730503831, 0.136258137013231, 0.1557921559682914, 0.13757909541683538, 0.13013589195907116, 0.17185396195522376, 0.09679435033883367, 0.09022989044232027, 0.20185603919838155, 0.18955999399934495, 0.2037832143583468, 0.16895041561552457, 0.15971571686012404, 0.13626011833548546, 0.11628840358129569, 0.14308223154928001, 0.07345922570675611, 0.1605178809591702, 0.12441187910735607, 0.17914331438285963, 0.18717008509806224, 0.11943326411502701, 0.12243050257010119, 0.09717898469950471, 0.1326944710952895, 0.1069022286683321, 0.1366859126303877, 0.09451870673469134, 0.15258720437330858, 0.14008620088653906, 0.19482337656830037, 0.14022637265069143, 0.11280871315726212, 0.1307114525032895, 0.1281616264688117, 0.09957239484148366, 0.20128855322088512, 0.10991141612508468, 0.13743836725396769, 0.11015617727701153, 0.28229882195591927, 0.17109630975340093, 0.09865615543510232, 0.0812616456033928, 0.09089938058917012, 0.15767354358519825, 0.08987699116447143, 0.16449029637234552, 0.16436190397611686, 0.08107244968414307, 0.09491472691297531, 0.07850155513733625, 0.16362581561718667, 0.14391392549233778, 0.20560802572539874, 0.13744143423225197, 0.17516130448452064, 0.09267558849283627, 0.0926113108705197, 0.12464578369898455, 0.13110745911087307, 0.09367034118622541, 0.21785483642348222, 0.19535540230572224, 0.08847476462168352, 0.11688573152891227, 0.05652282879288707, 0.12764374140117848, 0.10768351424485445, 0.13579851096229895, 0.12374559843114444, 0.059516776353120804], [0.03479566252125161, 0.03743219515308738, 0.02727178973145783, 0.05291600126240935, 0.04939890320279768, 0.010734754780839597, 0.0252840621064284, 0.013124396508958722, 0.06947450845369271, 0.01686692001697208, 0.043933035606252294, 0.013699877325312367, 0.06981686329735176, 0.042931131153766594, 0.051785456748413186, 0.01441103545948863, 0.03053399102230157, 0.03318257782874363, 0.08496410585939884, 0.06655465691749539, 0.022414635900141935, 0.04425134316885045, 0.021993664292884723, 0.024843848942379867, 0.03292350637327347, 0.028562327713838646, 0.05235815726752792, 0.036839030017810206, 0.04508801077359489, 0.05633479995386941, 0.01859157791893397, 0.01713210337662271, 0.09543151275387832, 0.02263971953652799, 0.024938016032267894, 0.038804125107292614, 0.03967911636989031, 0.0407396632113627, 0.028738234524748156, 0.005478191488821591, 0.04222464049234986, 0.04291259357705712, 0.026271500192316513, 0.04500509040164096, 0.045608996746263335, 0.0020481252992924836, 0.021486376245905246, 0.06297203273113285, 0.01983443694189191, 0.047386351374111006, 0.021990425984508226, 0.02494741713495127, 0.009466610150411725, 0.020768403075635433, 0.059166143382234235, 0.025622121823419417, 0.020375380325796347, 0.01748382200353912, 0.05692439938762358, 0.03176123356180532, 0.05129179198827062, 0.02051302624334182, 0.009995030322378235, 0.10331528221390077, 0.08271173600639616, 0.047276381203638654, 0.01835988704780383, 0.013293399226053484, 0.04908033101154225, 0.038297228914286406, 0.022563640493899584, 0.030777663125523498, 0.033226146562291045, 0.029711877993707145, 0.0257533861191145, 0.03192627702706626, 0.014487294313896979, 0.013760778387742383, 0.05670023855886289, 0.026013841786022698, 0.011914029135368764, 0.07369331350283963, 0.081916194409132, 0.026426090825615183, 0.013969887613451906, 0.04996537137776613, 0.03554934190054025, 0.03427543990047915, 0.03052006409104381, 0.025190412399492094, 0.06962303298392467, 0.06232442533863442, 0.09312943342540946, 0.04099760151335171, 0.01415267476945051, 0.005948345858736762, 0.022172694061217562, 0.0026739241522071616, 0.02373027628553765, 0.015146854100748897, 0.011303384089842439, 0.009167823192131306, 0.015090852909322296, 0.02036819463994886, 0.04445452369483454, 0.03332869016698428, 0.023908961697348526, 0.007232269821023303, 0.03220335680193134, 0.049399021946425946, 0.039755424418087514, 0.06692848900066954, 0.075957788420575, 0.05584933528942721, 0.029296760447323322, 0.023887535257797157, 0.08036967060927834, 0.04551364222009267, 0.02403619888770793, 0.025229212728195956, 0.050090058972792964, 0.0339279553320791, 0.05722948230270829, 0.0336161956324109, 0.023583717810522233, 0.030352177564054728, 0.050934655259230306, 0.054374681918748786, 0.003103169221763632, 0.016080141699473773, 0.03980295918881893, 0.0023977408917354687, 0.03663633803703955, 0.008474136486516466, 0.035198613934751065, 0.02564269839785993, 0.02619819635791438, 0.04383310436138085, 0.08687815136675324, 0.010563423840462096, 0.06393731664866209, 0.02752673060500196, 0.03757725915472422, 0.05806367325463465, 0.0034963900190112846, 0.04599504924512335, 0.024951586732640862, 0.043522555846720934, 0.050646986945399215, 0.044679546263068914, 0.019660638678552847, 0.053082038781472614, 0.06888659857213497, 0.07735004049858876, 0.0526507483529193, 0.05195776053837367, 0.0326008867206318, 0.023392739040510993, 0.045311377716383765, 0.021016351645812392, 0.03588941686653665, 0.03530395310372114, 0.049076524430087635, 0.09065420553088188, 0.05834576061793736, 0.013931797202011304, 0.07201828874115433, 0.019982160800801854, 0.011673653015999921, 0.04535235105348485, 0.04209135925131185, 0.031080476340970824, 0.015735583313341652, 0.03178526048681565, 0.012951571943371423, 0.01911102870612272, 0.0565868248231709, 0.025597989725481187, 0.02660969561631126, 0.04285096563398838, 0.009491141735842186, 0.013564691945378269, 0.012593805873101311, 0.01749801356345415, 0.06354335921683482, 0.01201359651583646, 0.07161471646811281, 0.020003617774429064, 0.03298143630049058, 0.059371291659772396, 0.0896625876692789, 0.03811899472826293, 0.024494176098544682, 0.029694358219525645, 0.06068037570055042, 0.031110827212354968, 0.032847764901816845, 0.04133766630132284, 0.02256976087976779, 0.060998384707740376, 0.03254795081115194, 0.04229592398873397, 0.018115957101274813, 0.030621413474104235, 0.00627565842920116, 0.02290020234483693, 0.040671823280198235, 0.05272517685911485, 0.034963725467345545, 0.09700966985630137, 0.04443969770467707, 0.02355626767634281, 0.051866144740155766, 0.03043619716273887, 0.04080508416518569, 0.020826417819729874, 0.007425493693777493, 0.02028164410564516, 0.022126877680420876, 0.02775739349557885, 0.05592986382544041, 0.030071535480341742, 0.031935997041208405, 0.021472893755084703, 0.042746508560542545, 0.06062657465892179, 0.03199796764446156, 0.032102004026195834, 0.019325791824875132, 0.036803037127746005, 0.02550617036675768, 0.012996959150768816, 0.04081733511494739, 0.022229641808995178, 0.023171899640666585, 0.04055224505386182, 0.08168748739574637, 0.012529386606599604, 0.06869766049619232, 0.09438159516347305, 0.03909341172714319, 0.02192121710894363, 0.0027188209060113877, 0.07330633141100407, 0.05109091169599976, 0.038161525303231816, 0.025146387351144637, 0.036463810330522914, 0.04111054366720574, 0.00199358889533739, 0.041219129626240046, 0.04039503866806626, 0.017073028421561633, 0.023391057970002294, 0.08894294021385056, 0.06498993480844156, 0.024922151883531894, 0.05929169950208493, 0.06252137691314731, 0.06071839401764529, 0.011300159352166312, 0.0064779411685386935, 0.05056883328195129, 0.029620289336889982, 0.03458952697526131, 0.007988268941906946, 0.05401166568377188, 0.09457393948520933, 0.01956657336891762, 0.038884290627070835, 0.056174740328320434, 0.06413940473326615, 0.05741257819214037, 0.023189675561817627, 0.04823246757899012, 0.022943759204021523, 0.02852896075429661, 0.029676088664148535, 0.07797782788319246, 0.010300425363571515, 0.03696909839553492, 0.020486480257074748, 0.015635401010513306, 0.007307034202053079, 0.05020417838490435, 0.03153250279969402, 0.016142543172463775, 0.017092315779466714, 0.0631654898502997, 0.05061788118577429, 0.031091624671327214, 0.027281614918527857, 0.08347905733223472, 0.04017890830125127, 0.023774301333885108, 0.08200153375842742, 0.018630281556397676, 0.012128948317175465, 0.07357965210186583, 0.06171874462493828, 0.0417679253566478, 0.020437333965674043, 0.02429327036121062, 0.042536797135003974, 0.02029013597140355, 0.011005630201127912, 0.007840780873915978, 0.05294493738827961, 0.06068053176360471, 0.06605751466538225, 0.02007339153039668, 0.04637595505586692, 0.004177846130914986, 0.028621241516832794, 0.05301092152616807, 0.03017999930307269, 0.028453146340325475, 0.01997139923540609, 0.06246517385755267, 0.07760900338845593, 0.014833476095061218, 0.020756569424910203, 0.03959780073325549, 0.04531483824497887, 0.048955388965883424, 0.022241831690605198, 0.019682015924315368, 0.06665474083274603, 0.02210068792503859, 0.019051078440887586, 0.03680319658347538, 0.05391073699242302, 0.041563106168593676, 0.06257484547261681, 0.054133055598608086, 0.019807962201801792, 0.03779458374317203, 0.032113919101123295, 0.02070246813153582, 0.03357387879597289, 0.0770479974203876, 0.015262754667284233, 0.038155496519591124, 0.026678029181701795, 0.037144516661231, 0.06881729300533022, 0.06309752099748168, 0.026610034883820584, 0.03821518724518163, 0.028417530037196617, 0.016862068491588746, 0.02950491802766919, 0.11449669115245342, 0.08030945741172348, 0.11764795705676079, 0.08565203180270535, 0.1392746865749359, 0.07233893046421663, 0.10947205791515963, 0.07789094825940472, 0.22927793275032723, 0.061640984511801174, 0.14476993813046388, 0.08806855284741946, 0.14512493408152036, 0.21689593073512825, 0.20499910839966365, 0.14495387540331908, 0.11474871262907982, 0.2579351264451231, 0.19950468465685844, 0.13123279809951782, 0.08919513132423162, 0.11347651375191552, 0.08664273364203316, 0.15746946739298956, 0.18761885458869593, 0.08376871036099535, 0.14298144195760998, 0.11534453422895499, 0.1513330680983407, 0.1827945520303079, 0.09748270375920193, 0.09940518345683813, 0.19982251045959337, 0.1448686106928757, 0.10193376455988203, 0.13415690405028208, 0.17429685087076255, 0.11080739447580916, 0.13096690736711025, 0.12248046988887445, 0.07845109927334956, 0.08344702369400434, 0.08256589847483806, 0.08426216816795723, 0.20166440733841487, 0.0770271663953151, 0.12304707377084664, 0.161898672580719, 0.1476546890501465, 0.1739975762154375, 0.15785657162112848, 0.1473671259092433, 0.03570468910038471, 0.1890808261398758, 0.07989618208791528, 0.12527832761406898, 0.2102524350796427, 0.10788427918617215, 0.09918780797826392, 0.15187352124069417, 0.14101221119718893, 0.10307919273951224, 0.13332656717726163, 0.13751445817095892, 0.15838097062494072, 0.10924103031201021, 0.07768772702131953, 0.1669683334018503, 0.1344710114811148, 0.09248653506594044, 0.10676100517490081, 0.11033553443849087, 0.1093199100079281, 0.09663705913616077, 0.1567595297736781, 0.09571011923253536, 0.12625043759388582, 0.09948159328528813, 0.11337076406925917, 0.16493401756244047, 0.10365405439266137, 0.18096739293209144, 0.1716645692608186, 0.1249368887926851, 0.09867862851491996, 0.14239085864807877, 0.14722383288400515, 0.0639957995819194, 0.17624402924307755, 0.11481884600860731, 0.12160658463835716, 0.12709000254315989, 0.15635129596505845, 0.1789710343416248, 0.1788090816033738, 0.10421634279191494, 0.11368725315800735, 0.10863093912069287, 0.09063063322433404, 0.09465758249695812, 0.1443699145955699, 0.18144696791257175, 0.22707021050155163, 0.09143070065017257, 0.15428666318101542, 0.1155555314783539, 0.13459522410162858, 0.07988770040018217, 0.13535602470593794, 0.11715458067400114, 0.11861895423914705, 0.14272427718554223, 0.12945282432649816, 0.0733856317986335, 0.12842871142285212, 0.20592285240335123, 0.13740220133747372, 0.08796569372394256, 0.11720395088195801, 0.18519815376826695, 0.08697305805981159, 0.10012362990528345, 0.17556066305509635, 0.14535909651645593, 0.1511662977614573, 0.13661230515156472, 0.1023094422583069, 0.09554351174405643, 0.07756633032113314, 0.08736979748521533, 0.06955580373427697, 0.1177147656146969, 0.12605086687420095, 0.20551394005971296, 0.10010346384452921, 0.12622121987598284, 0.12274310365319252, 0.11805653013288975, 0.14105520317597048, 0.08449565206787416, 0.13603236127112592, 0.07547902768211705, 0.14616231913013117, 0.15124654131276266, 0.1110438300030572, 0.1137472220829555, 0.127327204814979, 0.10210763915841069, 0.1424518453755549, 0.15682734256344183, 0.15163703821599483, 0.1464575904288462, 0.18711193464696407, 0.15488130412995815, 0.1401768395943301, 0.06642224759395633, 0.10489774122834206, 0.19612222830099718, 0.11604251606123787, 0.13911046752972261, 0.10988282944474902, 0.13586184542093957, 0.22160485519894532, 0.07132907358131238, 0.15561676823667117, 0.10759558967713799, 0.13088141195476055, 0.0876241395516055, 0.211587181314826, 0.1113017750903964, 0.1335621816771371, 0.09176776292068617, 0.10578449828816311, 0.0727616577808346, 0.05087676265143922, 0.11711161583662033], [0.014248002154220427, 0.038682623234178336, 0.02190122237828161, 0.0314845201958503, 0.025093203776382973, 0.050194994413426945, 0.048006074370018074, 0.04829736266817365, 0.028273694183943526, 0.044889780160571845, 0.09045839389520031, 0.0767112879880837, 0.014385354605370333, 0.03595512619774256, 0.0195188638754189, 0.015013830703017967, 0.07198890817484685, 0.023219132463314703, 0.05189969151147774, 0.06760295280920607, 0.022392751449452977, 0.057383570820093155, 0.013873111556417175, 0.04786480677181056, 0.023751297300415378, 0.009769767722381013, 0.03944546962156892, 0.052964014400328906, 0.025858272365959625, 0.06520581750997476, 0.009989255989369537, 0.034338458840336115, 0.009305801591835916, 0.01110599486024252, 0.011672891360441489, 0.02804697018914989, 0.02997104444407991, 0.009249397520241993, 0.04888691799715161, 0.05881139848913465, 0.04433086408036096, 0.02682809907543872, 0.04860504776505487, 0.03143109574115702, 0.011653805018535681, 0.01563325005450419, 0.03150188729965261, 0.04588698236537831, 0.024732436884992888, 0.057874104141124656, 0.020836819761565754, 0.00465804197093738, 0.032829539451215944, 0.003887421268570636, 0.00955120226301785, 0.010731464734167924, 0.05083028978801199, 0.04006308237356799, 0.030086035773690258, 0.03524771951405065, 0.013033348983818931, 0.04731709330475756, 0.04585054503487689, 0.037694394654993496, 0.012873591306353254, 0.015233516593330672, 0.06665195205381938, 0.02575432080110269, 0.047140908294490406, 0.08268483209290675, 0.035384868404694965, 0.015184224416900958, 0.0764538450166583, 0.006071101325297994, 0.04917571946446385, 0.04556165196533714, 0.008422404128525938, 0.04557886300608516, 0.031166534937386, 0.018982441231076206, 0.09275818656065635, 0.017908021741147553, 0.04658765119633504, 0.008742357986713094, 0.06671401086662497, 0.01235246962668108, 0.009022309661044605, 0.03485853218340448, 0.03169201959722808, 0.07130986425493445, 0.03517872607335448, 0.03669802365558488, 0.019459946679749658, 0.002705639091020982, 0.0775710122127618, 0.02526737014496965, 0.0509687991413687, 0.014629179378971457, 0.024207590048068335, 0.018174850548218404, 0.04119136058060186, 0.017845099492530738, 0.029234911980373517, 0.03451907468427505, 0.022380434342526963, 0.04327806271612644, 0.018850143865815232, 0.03700434150440352, 0.05500094599223562, 0.04661042283156088, 0.016537867852353623, 0.009683860100007482, 0.05598114750214985, 0.043690008111298084, 0.01654592206302498, 0.01845738065562078, 0.04430313913949898, 0.02108552150561341, 0.006268424397733594, 0.06394091966961112, 0.006420911148390067, 0.0046705405859808835, 0.019718660207997476, 0.05140376722972308, 0.057850172211016924, 0.011195879545994103, 0.049366917062018595, 0.048146792354860475, 0.02859689568036369, 0.011827950182903026, 0.039130653121641705, 0.040315158132995875, 0.09386774059385061, 0.05363959439897111, 0.04988372665164726, 0.036775760019996336, 0.039669301360845566, 0.03673553307141576, 0.050073543430439064, 0.044081108910696845, 0.037128696617271216, 0.02599878848663398, 0.05518463220713394, 0.03670818471748914, 0.03356671007350087, 0.00219278217991814, 0.049836415797472, 0.03420725052378007, 0.030537668682102646, 0.01448370486364833, 0.029357224702835083, 0.034078257624059916, 0.03250471455976367, 0.026111086032220295, 0.018202812976336906, 0.10518652573227882, 0.04077153400118862, 0.06456326520336525, 0.03231913523216333, 0.035129827447235584, 0.03264182613098195, 0.024778353349704827, 0.04011424730664917, 0.03477950660245759, 0.027918638861072913, 0.025245304186163203, 0.06920307409018278, 0.046080578584223986, 0.003552671318175271, 0.045007828290441206, 0.029847696955714906, 0.027460475053106035, 0.052603261079639196, 0.02010311306055103, 0.03347574906157596, 0.04478579466896398, 0.02199396793730557, 0.03289601213431784, 0.03389074447165642, 0.0686890838135566, 0.011737563381237643, 0.005565561778244695, 0.03319284067090068, 0.02933636653636183, 0.050304018027548275, 0.040719673569713316, 0.09983590391597577, 0.05951766523399523, 0.02687762025743723, 0.02626598539895245, 0.012711760704405606, 0.01263014311968748, 0.06692292501351663, 0.052865050067859035, 0.033707679116300175, 0.0432478611224464, 0.005344192697001355, 0.024168718473187516, 0.040491628127970865, 0.04900998728615897, 0.024363045813515782, 0.02841399486974946, 0.03727299726701208, 0.028716331414346184, 0.03327477377440248, 0.05150114039757422, 0.05286565735670073, 0.04891273286193609, 0.028897344201271023, 0.018339892317141806, 0.02311086541573916, 0.027630722881960015, 0.017488838073664477, 0.05530295853636094, 0.03199111783344831, 0.01605002661900861, 0.012744137850989188, 0.036575510765292814, 0.05604821390339306, 0.058559533075562546, 0.07799832642610584, 0.05740114487707615, 0.010997622639739087, 0.05574593333793538, 0.027634800877422094, 0.04723365046083927, 0.0512190564269466, 0.03807386875684772, 0.06103159899690321, 0.021355944851945554, 0.05910631016428981, 0.029596119919525724, 0.031225089116820266, 0.0033725255717789488, 0.021171880353774344, 0.030044875839459043, 0.008787475476440574, 0.054976708721369505, 0.10045732664210455, 0.017494266353813664, 0.051922883838415146, 0.02368968292804701, 0.030785015052450553, 0.011540499000277902, 0.0029069527975350085, 0.018983397965452502, 0.031530840388898335, 0.02044427877158991, 0.03488151077181101, 0.05124023350487862, 0.05534908873960376, 0.014588173811456986, 0.042764452419110706, 0.03632564363735063, 0.013890638964117637, 0.024936278982620155, 0.07715144008398056, 0.06104400261704411, 0.05101564859173127, 0.04023649217560887, 0.09344561717339925, 0.010839764860325625, 0.027715689036995173, 0.05577307813135641, 0.03530535088585956, 0.0053042180786308435, 0.01623029132107539, 0.03741524534832154, 0.034441385817314894, 0.045568739263606925, 0.04356926619740469, 0.022761977976188064, 0.010979980729254228, 0.04484242520162037, 0.007787882283862148, 0.05154988635331392, 0.0459032536351255, 0.03536408148439867, 0.04740073970918145, 0.039245400178645334, 0.04542168376169034, 0.03887745099408286, 0.02628689954456474, 0.013205422071873077, 0.04404720930116517, 0.07541297229805163, 0.0263661388640425, 0.026320225792005658, 0.010745602011281465, 0.036031288360910754, 0.020777139214000533, 0.018872452400890843, 0.011850773556424039, 0.039090955430375676, 0.06182851802025523, 0.023022511674623405, 0.011287336736651403, 0.029346344393811057, 0.026222216497574533, 0.006607372147430266, 0.06181391594665391, 0.057409389077552726, 0.13869858320270265, 0.0757864990404674, 0.07371628869857107, 0.03828811618898596, 0.07795252531234707, 0.03167366183229855, 0.08141936428312745, 0.034649322873779705, 0.027531230988513147, 0.02495038233298276, 0.037424795728709014, 0.019380262919834683, 0.036581464910081456, 0.016850753920152783, 0.044132368838680644, 0.014259764558768697, 0.011784398412731076, 0.08947234680610043, 0.030549064677740847, 0.05994299812508481, 0.06744426382439477, 0.03313949764040964, 0.029623810933636766, 0.04473137955314346, 0.015686559158244302, 0.026706965307572057, 0.03229833474116666, 0.04823703411966562, 0.027416675617652278, 0.06153275139097657, 0.06348578552050249, 0.027098459657281637, 0.053587367558585744, 0.010880119034222193, 0.035354205407202244, 0.04097090455304299, 0.06917380887482848, 0.008477535098791122, 0.015286689990067055, 0.019734010366456847, 0.01960853227813329, 0.05446732569751995, 0.053680238646588156, 0.04451953413497124, 0.05514484969899058, 0.022022973613015244, 0.028953435298587595, 0.06306815400187459, 0.060040910728275776, 0.02721286066142576, 0.09146399636353765, 0.11007334172193493, 0.1609704095338072, 0.14342464746109077, 0.10789050135229315, 0.13999888700033936, 0.13823806148554596, 0.1750540823808738, 0.19651605002582073, 0.11103373340197972, 0.14301212531115326, 0.20431317734931195, 0.07444519815700394, 0.10130606538483075, 0.10230354578899485, 0.06320478381322962, 0.21185965383691446, 0.1130919201033456, 0.0641990683174559, 0.17493323529405252, 0.102593945206276, 0.10517467851085321, 0.1443804997418608, 0.14033810022686208, 0.13858969190290996, 0.08694893613989864, 0.20466526917048863, 0.13064458966255188, 0.13466406826462063, 0.11544069621179785, 0.11722309914018426, 0.06548112630844116, 0.14180579861359938, 0.1366561927965709, 0.08204992009060723, 0.15518477213169846, 0.10667547583580017, 0.10868465195276908, 0.11799844753529344, 0.12628791986831597, 0.15362066748951161, 0.07997455288256917, 0.18646514149648802, 0.12708012307328836, 0.1709549030555146, 0.09824342293930904, 0.10150670818984509, 0.1551604670073305, 0.11661636669720922, 0.11307784050170865, 0.12190827487834863, 0.10150155810905354, 0.13317001557775907, 0.11358336266130209, 0.16669504663773946, 0.0752304463780352, 0.11690456766102995, 0.15441071295312472, 0.09241974686405488, 0.20992652113948548, 0.13009090508733476, 0.12177016586065292, 0.15058365331164428, 0.0846436812675425, 0.11889518584523882, 0.19966431680534566, 0.13185460759060724, 0.05629812852878656, 0.13008766168994562, 0.17413022981158324, 0.12324703804084233, 0.10040656543735947, 0.1334957666695118, 0.1587633793907506, 0.1592244982187237, 0.1488799061626196, 0.09683873331440346, 0.19382934990738118, 0.0487499183842114, 0.12088623829185963, 0.17991765854614122, 0.07217491497950894, 0.15038917160459928, 0.1287032195499965, 0.18145907297730446, 0.10421335723783288, 0.08987137289451701, 0.10965535736509732, 0.1383441843624626, 0.16303007544151374, 0.08937940786459617, 0.12269519908087594, 0.07123623642006091, 0.19572356183614048, 0.24462777908359254, 0.12616730348340102, 0.06575291351016078, 0.09628154749849013, 0.09450796552534614, 0.12242411077022552, 0.10656749377293245, 0.1448387551520552, 0.12361283626939569, 0.0965003953980548, 0.11237301903643779, 0.20577307258333477, 0.08122090636087315, 0.1005280367763979, 0.1355823025639568, 0.12530499404030188, 0.15623447937624796, 0.1807812029229743, 0.11132548310394798, 0.1748261081853083, 0.13791858005736554, 0.04293582322342055, 0.1574607550033501, 0.0976565240749291, 0.1591038139803069, 0.08915001553084169, 0.07611229762967144, 0.09425422735512257, 0.11909855636102812, 0.23159887535231455, 0.1121424256957003, 0.11738700605928898, 0.18227745406329632, 0.11365466990641185, 0.17932950439197676, 0.09914758442235844, 0.18175758767340863, 0.08825251726167542, 0.16712654062679835, 0.10137595449175153, 0.1298986625458513, 0.09326456367437329, 0.12091152050665446, 0.08835887762584857, 0.10438871782805238, 0.18529850909752504, 0.06643861385860614, 0.07127722672053746, 0.13516421642686638, 0.18743132108024188, 0.0978220459073782, 0.1357138297919716, 0.16357930882700852, 0.13499253349644796, 0.13330773104514393, 0.07381450664252043, 0.0833274522530181, 0.1394492464938334, 0.09744246663259608, 0.2207189327371972, 0.1364779280764716, 0.1416633062596832, 0.16723412913935526, 0.15968127442257746, 0.10874662934137241, 0.11625326903803007, 0.10424083790608815, 0.13532011663275106, 0.12160148205501692, 0.07760365653250899, 0.12734570167958736, 0.12146124243736267, 0.1489190576331956, 0.13635077061397688, 0.09036747698805161, 0.18348657632512705, 0.22468629984983376, 0.16536011041275092, 0.16284351902348654, 0.1015396307089499, 0.09117287091378655, 0.06992806840155806], [0.08218803589365312, 0.04979353238429342, 0.028119911007317047, 0.041757292712905576, 0.014544125014383878, 0.04157580495146768, 0.05023142156590309, 0.017745080038106868, 0.020791418983467987, 0.03089460524331246, 0.03157010721042752, 0.017368935846856663, 0.029190467936652045, 0.016477111826783845, 0.043517429514655044, 0.08358583838811942, 0.017466648282217126, 0.024915442868535007, 0.014480773592367768, 0.061574033461511135, 0.03854838865143912, 0.04676543415657111, 0.018319970528994287, 0.032052321692130396, 0.08468351127313715, 0.029145470886890377, 0.030172501491116624, 0.043911790674818416, 0.01246916747186333, 0.05636618559115699, 0.044813923338162046, 0.010363535057487232, 0.015332655648567846, 0.040502009713756185, 0.040403947832861116, 0.04731240802045379, 0.03242311393842101, 0.03728302262191262, 0.042957251359309466, 0.07519250948514257, 0.04803294435675655, 0.007346404500172606, 0.031584234309515784, 0.05745274746524436, 0.03389014057548983, 0.03561076967577849, 0.06960999154086624, 0.04546468931117228, 0.02147589627254222, 0.0773654839556132, 0.023081159152622734, 0.04712086437003953, 0.06160072024379458, 0.01320652469127838, 0.02411987921888275, 0.02167294453829527, 0.06224136586700167, 0.007602213898540607, 0.034714764183653254, 0.04208413963871343, 0.008495996340310999, 0.055678788905165026, 0.05091376316600612, 0.04219290201685258, 0.05961531999387911, 0.005361286690458655, 0.04185506960909281, 0.08113034907728434, 0.03001193974965385, 0.051122402506215234, 0.023260616398017322, 0.03343010401087148, 0.02531164794761155, 0.05251509563199111, 0.034559657863740406, 0.026528544524418454, 0.050954590618078194, 0.050139690416732004, 0.06270248469497476, 0.04612436444897737, 0.05746323761663266, 0.04733774791072522, 0.008932530148220914, 0.028135020285844803, 0.043040687417877574, 0.024794967279636433, 0.05494796258530446, 0.05152131663635373, 0.018001452620540346, 0.013056520954705775, 0.07061970593141657, 0.040096059175474305, 0.018639317946508527, 0.00668110600340047, 0.060439902889941416, 0.07284772316259996, 0.01332727339052196, 0.048778566132698736, 0.029905470819877725, 0.022989841909813027, 0.030026660566883426, 0.038904965589089055, 0.05921931338629552, 0.045578483026474714, 0.056411521908427985, 0.06173558586410113, 0.014667053507374865, 0.062217481434345245, 0.06274000089615583, 0.05236614701737251, 0.06089163079325642, 0.036392350415033956, 0.04818708376426782, 0.014433304978800672, 0.006569159599686307, 0.06613407377153635, 0.015622746332415512, 0.041620354168117046, 0.009250873333907552, 0.05327494628727436, 0.042869418393820524, 0.03227059283692922, 0.04317499324679375, 0.02462844630437238, 0.056964894357536516, 0.027632804288129722, 0.04564840606014643, 0.04552671419722693, 0.03731610459674682, 0.03672515148563044, 0.0496844510946955, 0.0501283453112202, 0.01292035000265709, 0.03536865820309945, 0.06155504805168935, 0.05496630338685853, 0.043287440070084164, 0.033310868444719484, 0.046247878178421936, 0.033379865278090746, 0.003419844907641943, 0.045205902840409956, 0.018016348160537224, 0.017300089987527047, 0.04666505168591227, 0.007130173201273594, 0.013847221204611872, 0.012988388405314513, 0.038789702845471244, 0.038849176439855776, 0.026003234587343674, 0.05268782350633826, 0.01218587825340884, 0.03756801750777023, 0.0471253494865128, 0.013648930371605923, 0.03104038509939398, 0.0037033067284418003, 0.04712596356070467, 0.032795266647424014, 0.034275735063212256, 0.048068028009895764, 0.05921476041632039, 0.020980048325977156, 0.04800442213724766, 0.039287717015083344, 0.039054307754018476, 0.035028437352074046, 0.014594747119450142, 0.016295525677768246, 0.030382467367287194, 0.02100890811665782, 0.026848775733794485, 0.03206402302852698, 0.06574330545429673, 0.012841875731412853, 0.03378670808992215, 0.04175685166514345, 0.00289067071363596, 0.011838397077683891, 0.01683464040979743, 0.04312813701108098, 0.03552974580920168, 0.018014131047363793, 0.03959131393847721, 0.06232779087232692, 0.07266663573682308, 0.027968977677768896, 0.009522570629737206, 0.0400803951945688, 0.006433358449222786, 0.03474133900765862, 0.04243726961846862, 0.009215091637867903, 0.041671814263931344, 0.05059212738914149, 0.03042755601927638, 0.04113023814612201, 0.020586112946537987, 0.01663713582924434, 0.01994451228529215, 0.05108263356877225, 0.0846217442303896, 0.028868788055011203, 0.010334175695399088, 0.055959570088556836, 0.04086380458569952, 0.021846839492874484, 0.05422054590391261, 0.010590035983893489, 0.0256177622359246, 0.07118115973259721, 0.07760866412094661, 0.02692648665314274, 0.011822462530939706, 0.09678690002432891, 0.018274237268737385, 0.027281765892569507, 0.08351946409259524, 0.048155996682388444, 0.03095709831852998, 0.05812869726547173, 0.05692756136081048, 0.018525639582159262, 0.05236528188522373, 0.07904246289815221, 0.033548382842647176, 0.035866495953606706, 0.043526260647922754, 0.03626954236200877, 0.03038974804803729, 0.011603449238464236, 0.027770969284964458, 0.0389044872219009, 0.02647384103121502, 0.03699378010683826, 0.02955546210120831, 0.05057135403954557, 0.08075769764504262, 0.011272098536470106, 0.02613534196279943, 0.05387357362945165, 0.02557309257930943, 0.0478149887307414, 0.0215800785393055, 0.08083389034228665, 0.0863017358684114, 0.03070276982284018, 0.015139890635120017, 0.014261432058577026, 0.007201858729656253, 0.025587764202750156, 0.020554184481235485, 0.06935232465288468, 0.07284733639763934, 0.0196473597482379, 0.0633298988853182, 0.020572625366704803, 0.029922420624643564, 0.07146974067602839, 0.06604850372033459, 0.03157922672107816, 0.05028049661112683, 0.034753640847546716, 0.015485782342563783, 0.02458773589959102, 0.04629636289817946, 0.05185084377548524, 0.02430024230852723, 0.030112966828580414, 0.04097776114940643, 0.01943377897675548, 0.024233540619856546, 0.04794820211827755, 0.08162242945815835, 0.042121937431927235, 0.05772355079118695, 0.05289888521656394, 0.014873601263388991, 0.011854335865271943, 0.007093474634789995, 0.04824214009568095, 0.055767079881791554, 0.016537676166210855, 0.030051467807165215, 0.07061779246266399, 0.04787645382540567, 0.01639013720809349, 0.03778085358706968, 0.018797107872420123, 0.04042595611619098, 0.031320229904460054, 0.017977771748389517, 0.02753736324874418, 0.02743051264302007, 0.05842061660119465, 0.0869178795920951, 0.01097950236206608, 0.035378727662776194, 0.004178038665226528, 0.007345805693018649, 0.016188267951032946, 0.004947231475463403, 0.059787681459316185, 0.05477081744798592, 0.04442135351044791, 0.027972438206364, 0.03502456970246775, 0.09889079284455095, 0.017752798373943994, 0.032711101163710864, 0.06908743136695453, 0.05924420205077954, 0.06822214315512351, 0.03494381046454821, 0.023598165517406802, 0.05009809961276395, 0.04780793875189764, 0.016193728461595516, 0.039702878666243384, 0.08743137453815766, 0.019062532112002373, 0.03540747719151633, 0.009747879030848188, 0.028274769661948085, 0.06044253560581377, 0.011267593912115055, 0.0247455835009792, 0.04668138402381113, 0.02435143099033407, 0.010326650742042278, 0.03349363863734262, 0.04701217323807733, 0.03804076981863805, 0.013656921817788055, 0.02749121099311326, 0.01862649363465607, 0.0596922862210444, 0.051221309163208516, 0.008111914985680153, 0.0030849374098969357, 0.020073668033416783, 0.1116328119699444, 0.028407296032777855, 0.03946605637403471, 0.025399156912629093, 0.07402775662818126, 0.07137471184666667, 0.02946754771151713, 0.06392205639609269, 0.023364152360175337, 0.02709691259743912, 0.1094083163355078, 0.17072810951088155, 0.09018768556416035, 0.09915806778839656, 0.07405202104044811, 0.2085815290255206, 0.20205385929771832, 0.13195055244224413, 0.06771358115864651, 0.1646102342222418, 0.16757919133773871, 0.12020694331399032, 0.11310104639934641, 0.14393517720912183, 0.11586868896016053, 0.16453275909381254, 0.1462981482701642, 0.07230625900306872, 0.11482352790023599, 0.10813535071377244, 0.11962330820305006, 0.277269004711083, 0.10329735531870808, 0.09260010825736181, 0.15355605738503592, 0.10151371745658772, 0.22688442761344568, 0.051048211487276215, 0.06362179786499057, 0.10674281365105084, 0.11617724597454071, 0.1162126926439149, 0.187639197068555, 0.08987733721733093, 0.12493148765393666, 0.20294109811740263, 0.12066481874457427, 0.20771689899265766, 0.11684765214366571, 0.16576392017304897, 0.12902576795646123, 0.07681171795619385, 0.17171505226620606, 0.14203287714294024, 0.10351911413350276, 0.14280818482594831, 0.15146406606904098, 0.12744465922670706, 0.11397058224039418, 0.18908423238566943, 0.10153835506311484, 0.25292859652212685, 0.17406376052115644, 0.15842574036547116, 0.10838932637125254, 0.08986534071820122, 0.14767349804086344, 0.08750085652406726, 0.08717287305210318, 0.0858971525781921, 0.10771738671298538, 0.12390685906367642, 0.22170298493334226, 0.0936365637129971, 0.16991825082472392, 0.11663042594279562, 0.11347343320293085, 0.20267538380409988, 0.0756879486143589, 0.14974506545279706, 0.23495328107050487, 0.14984592289796897, 0.09676422338400568, 0.13500037736126355, 0.14668120842959198, 0.1314690639930112, 0.18490561018032686, 0.10924979019910097, 0.15954081767371722, 0.12036126931863171, 0.10629415272602014, 0.09881432194794927, 0.14226214055504116, 0.13959209168595926, 0.17089710544262612, 0.0640605589640992, 0.1425449132387127, 0.12530415265687875, 0.15702828392386436, 0.09424107056111097, 0.18516155358936104, 0.10206407721021346, 0.11541982447462422, 0.14932175459606306, 0.2583036252430507, 0.1159435585141182, 0.11406298513923373, 0.09471014860485281, 0.14785814099013805, 0.15206223540008068, 0.11730518830674035, 0.16717911352004322, 0.14747977629303932, 0.15522891762001173, 0.15950695877628668, 0.11648698363985334, 0.11197469183909041, 0.14405915912772926, 0.12909117873225892, 0.13891525300485746, 0.15971967950463295, 0.12188291123935155, 0.1060605263337493, 0.06835187905068908, 0.09146278178585426, 0.1499411349317857, 0.08139471310589995, 0.14744084195366927, 0.08124474329607827, 0.09196261782199144, 0.15609839239290782, 0.14935384930244514, 0.11710020287760667, 0.13870714631463799, 0.19239169705126966, 0.1481712849012443, 0.0835127533812608, 0.1705635647688593, 0.14968132387314523, 0.12116416623549801, 0.14870929531753063, 0.1559727005660534, 0.2374623135796615, 0.1164912719811712, 0.15787987251366886, 0.1247072589716741, 0.18713554766561302, 0.13283329936010496, 0.12136463262140751, 0.09287171225462641, 0.20685856576476777, 0.09768787917814084, 0.06161368704800095, 0.08003767699535404, 0.1608512316431318, 0.08499135582574777, 0.1944103387317487, 0.1032203348087413, 0.1491607925189393, 0.13411199860274792, 0.15233653996671948, 0.1069501671673996, 0.14920197959457124, 0.11776451580226421, 0.11531628003077847, 0.09777769685855933, 0.15515913707869394, 0.08619228816990342, 0.14206000497298582, 0.07949984978352274, 0.2214755399950913, 0.11437608833823885, 0.13131350305463585, 0.15999467617699079, 0.1153850970523698, 0.15433486630874022, 0.16586884882833275, 0.06852409802377224, 0.09510287110294614, 0.11738787458411284, 0.1517573967576027, 0.11623557284474373, 0.05428325950301119, 0.0932648554444313, 0.15227898662643774, 0.08484754032854523], [0.058018991723656654, 0.040988037562263865, 0.035185555528317175, 0.02909629066873874, 0.07100665409650121, 0.03870769849579249, 0.01636721968783864, 0.00848215168142425, 0.07710154740405933, 0.04461181150483234, 0.016208790242671967, 0.07049814638282571, 0.05127922212705016, 0.0073427141178399324, 0.030057259103549377, 0.04931985048045005, 0.012858560907521417, 0.03473276911037309, 0.019309244052107846, 0.05395660935235875, 0.04489152060289468, 0.015395036765507289, 0.035723087577415366, 0.032965813031686206, 0.027838671812787652, 0.009337845408091587, 0.0348086700375591, 0.03057162257443581, 0.024236241189230765, 0.08013999329081603, 0.04378310311585665, 0.05629014217161706, 0.004921728312703115, 0.0066953599037203404, 0.025977250088804534, 0.06630573634590421, 0.018054215503590446, 0.02211887266353837, 0.023876799137464592, 0.04495256839852248, 0.016112663882917592, 0.043957523935075314, 0.00961987255141139, 0.010739736924214023, 0.04138299583324364, 0.029628007672727108, 0.022246140387973616, 0.04033855741311397, 0.028006105417651788, 0.06465515920094081, 0.03834660251491836, 0.014452381990849972, 0.026524778655064956, 0.021386663828577315, 0.02780034306592175, 0.0430068353057972, 0.026382674762446965, 0.04853842241157379, 0.020034808332898786, 0.020329426541658382, 0.04931230517104268, 0.019015463834096278, 0.03373359576133745, 0.04043414264119097, 0.024371388401570063, 0.020622857314135348, 0.015886972957689847, 0.01391881937161088, 0.048570747819862196, 0.01658851370614554, 0.03837812725188477, 0.0227080157824925, 0.019595149871227995, 0.004976198559493891, 0.014307628418984157, 0.07020121945866517, 0.07891113244529281, 0.02629696561156639, 0.033408302680722306, 0.027170530254287378, 0.027733393711969256, 0.048706919620079656, 0.016462190841723765, 0.054705637374094555, 0.046296125410922935, 0.03131243692977088, 0.03506641834974289, 0.018282978496115123, 0.08254968148789235, 0.011271532807898308, 0.015073526517621108, 0.028273263314206685, 0.11146935966930219, 0.06024481728672981, 0.03699298622086644, 0.03495439900351422, 0.026772355727319206, 0.03964214638939925, 0.04541406720610602, 0.03542515302875212, 0.03406417462974787, 0.04110421632815685, 0.013703049476524549, 0.006351374879678977, 0.031155732659889118, 0.02361046226828226, 0.02424547605083457, 0.09446118732116052, 0.0323466600051948, 0.054827342807714424, 0.02106491439709706, 0.01698966700184558, 0.03410162637010217, 0.03449769404583743, 0.03459338105416723, 0.039420000809643946, 0.05456316876890404, 0.021584371969635998, 0.0609523868188262, 0.031227755759443556, 0.006970774299199027, 0.025216488500258753, 0.041470577740775685, 0.024907134207231656, 0.024371921051559702, 0.020799315434747508, 0.014203349460980721, 0.028736344804721217, 0.020240506223802055, 0.02519496197679213, 0.053605494621608935, 0.016772315271997025, 0.04858526507658618, 0.03569312686366694, 0.06154826270150287, 0.04553878194253359, 0.045170937930899005, 0.052450712836746655, 0.055917870718985796, 0.03051946358755231, 0.053781387861818075, 0.019280175611908947, 0.021209366020879576, 0.03814462299591728, 0.03552801215222903, 0.012304671075461166, 0.021130527037062814, 0.0026388848158863504, 0.0354106052379523, 0.023752101364412477, 0.13126899115741253, 0.07084880649511303, 0.04377313882910779, 0.01713297699045922, 0.06157247283096824, 0.022907963089112724, 0.04818685645503657, 0.030706169283283607, 0.030900813838733093, 0.10348602876599346, 0.03485233376600912, 0.03230903523841074, 0.03732651671660798, 0.012268263430866812, 0.03405443425955517, 0.009299813520296343, 0.040886155529213805, 0.014981035409229142, 0.05680946234081473, 0.037286591716110706, 0.06722670514136553, 0.020266692586509243, 0.045789093510912995, 0.05314266927806394, 0.044265399021761756, 0.05901781562715769, 0.04158990830183029, 0.038859408747936995, 0.010498426971025765, 0.03830703713798097, 0.03483282927689808, 0.0852350720337459, 0.024294245755299926, 0.025079884133966904, 0.06527297890612058, 0.026918055855536034, 0.0042783626122400165, 0.02983381412923336, 0.019987572117575576, 0.05193658685311675, 0.02369374904914626, 0.021918282444987978, 0.029628221411257982, 0.04492455847295267, 0.012009546509943902, 0.09787567731525217, 0.03946182231551834, 0.03359925600567034, 0.008279110255118991, 0.05032872688025236, 0.032601385443870506, 0.007987315600205745, 0.027157831471413374, 0.028502284150038446, 0.03795498263623033, 0.06504144918705736, 0.03344045506258096, 0.03537122645814504, 0.017948945884459784, 0.029817315550254922, 0.024637655720912983, 0.05662253951387746, 0.03914738240252648, 0.04201094267357673, 0.041241148087595186, 0.044763820312385044, 0.029941833511527096, 0.017677067080512643, 0.05377631241987858, 0.046345437943403206, 0.02506775701684611, 0.021338854251163344, 0.019985824889902557, 0.05020895187876054, 0.025739925680682063, 0.06428758999598877, 0.025616169374968325, 0.0637800729434405, 0.0011707306444545143, 0.01459131033958069, 0.009650990167366607, 0.013748483333204473, 0.013187958276830614, 0.03961357667243906, 0.030015390100223676, 0.06834912419851337, 0.09734318338866745, 0.018280491665271775, 0.042389717884361744, 0.05330306817112224, 0.07154519377010209, 0.05995315579431398, 0.02471941240530993, 0.02672539771135364, 0.07016378468168633, 0.025065439819757427, 0.012930878321640193, 0.03060048066877893, 0.03832361035581146, 0.01198805306505944, 0.04052918843392815, 0.02525489018963916, 0.04937121558136173, 0.06374641082116536, 0.03777067556178995, 0.018482454220897386, 0.03077890823728272, 0.04881752422079444, 0.037786977365612984, 0.06341338583401271, 0.05944440380803176, 0.02170241331415517, 0.015730314488921846, 0.051800347199397426, 0.06024314130523375, 0.04416535581861224, 0.009576776247870709, 0.04583409056067467, 0.04644802565287266, 0.02076030645652541, 0.07470952825886862, 0.04410115283514772, 0.02209775156474539, 0.08819355256855488, 0.010723178125252681, 0.019883698584245782, 0.01329290135098355, 0.019332991081422994, 0.049511981063655446, 0.02383255017256098, 0.030351326002606323, 0.009713113440998962, 0.006431263472352709, 0.06554458290338516, 0.004880842336985681, 0.015640371279524903, 0.03891389171725937, 0.012757411692291498, 0.040518491329359155, 0.04671004195032375, 0.04561957849987915, 0.03502814218934093, 0.027706119996894683, 0.015790617592366676, 0.013656955744538988, 0.09908800226237093, 0.0031601067915159676, 0.019079892430454493, 0.03319982958159276, 0.020713146576391797, 0.025727749369772415, 0.047486004419624805, 0.04842303753165262, 0.06399941617356879, 0.05741710402071476, 0.03946513356640935, 0.0237797771114856, 0.034169401840439866, 0.02939826589343803, 0.050633029480065615, 0.03994722591180887, 0.0699069591771279, 0.02696808084978589, 0.02593423775397241, 0.02181687199377588, 0.005780795206581908, 0.10525881685316563, 0.014010630248646651, 0.043237547390162945, 0.05919215841484921, 0.01780595989631755, 0.07087372908634798, 0.054394546031419716, 0.04996396341760244, 0.03269946089546595, 0.008055124149125601, 0.044101258008075614, 0.011589826799796095, 0.040249570938093324, 0.037409705109894276, 0.07219826336950064, 0.055472704249301126, 0.04450460297188588, 0.008898030883366508, 0.01343794075572597, 0.041226159249033244, 0.042807234052036486, 0.025839327668238963, 0.08448000505034413, 0.021926324781296507, 0.008337880717590451, 0.009121026328232671, 0.040315833275339434, 0.03522269853523799, 0.013194404359507774, 0.03989249188452959, 0.055414258635469844, 0.02358381959077503, 0.05641074498583164, 0.05265600360663874, 0.030568955931812525, 0.030500223727098534, 0.1266156251409224, 0.14408537772084984, 0.23794404630150112, 0.1557466262685401, 0.18496791326573916, 0.21904175701950276, 0.11444795876741409, 0.0886580233595201, 0.1799114974481719, 0.11308812709259135, 0.08805059881082603, 0.16498268209397793, 0.2181421552917787, 0.10297637432813644, 0.14090129786304065, 0.10322807010795389, 0.10672732269657509, 0.12491034450275557, 0.10441502463072538, 0.11987017281353474, 0.13345223186271532, 0.1341274692011731, 0.07191530069602386, 0.09296445442097527, 0.095257868857256, 0.05962443271917956, 0.12070543585079056, 0.17255680209824018, 0.16248962229916028, 0.12743244559637137, 0.14358514813440187, 0.07460890830095325, 0.13049802609852382, 0.09997152271015303, 0.08584006064172302, 0.14565769263676234, 0.15316328060414108, 0.10053616562592131, 0.0892785843461752, 0.13013339495020254, 0.08797903372240917, 0.11450988187321595, 0.15001422672399453, 0.12478933456752982, 0.13247929407017572, 0.07473692071757146, 0.1263065795813288, 0.13258260781211512, 0.09298869847719159, 0.09831954099770103, 0.08772219464715038, 0.14417860843241215, 0.15969764068722725, 0.10036077789430108, 0.10844326311988489, 0.14547558740845748, 0.11373238252209765, 0.27495772444776123, 0.14838172575192793, 0.16855895519256592, 0.16062990709074906, 0.08447240545813527, 0.15990498741822584, 0.13440435220088276, 0.14329366306109087, 0.09061766642012767, 0.10606045169489724, 0.0956719448523862, 0.12097575063151972, 0.12791253626346588, 0.11752420584005968, 0.13265693453805788, 0.11050074414483138, 0.09547968874020235, 0.06530834415129252, 0.13899214459317072, 0.16952111784900936, 0.20576103537210397, 0.06967823180769171, 0.1404215328927551, 0.13174290715583734, 0.1718908335481371, 0.11147219594568014, 0.1620285984660898, 0.11912478852484908, 0.10749431154025452, 0.16718422967408383, 0.15542620846203395, 0.19454858345644815, 0.15182010696402617, 0.11958406173757144, 0.17851599518741879, 0.1548333317041397, 0.0854878398988928, 0.1057287769924317, 0.1471882505076272, 0.13873489839690073, 0.20276355264442308, 0.11735919969422476, 0.10900823851781231, 0.11926071265978472, 0.08934380513216768, 0.1194271437291588, 0.09942705942583935, 0.1457612370806081, 0.058344071065740924, 0.05692629250032561, 0.14210410974919796, 0.1711730927761112, 0.15167077497712203, 0.09776067920029163, 0.09784880732851368, 0.111718266670193, 0.15507262386381626, 0.17370922597391264, 0.1549337820283004, 0.1467034915196044, 0.11122206079640559, 0.1922944901244981, 0.1663618723728827, 0.08175547660461494, 0.13609921054116317, 0.11218669332031693, 0.0902698357988681, 0.11964468205613749, 0.13045354134270123, 0.10688337218016386, 0.22326654674751417, 0.10664796124079398, 0.14113869012466498, 0.11066925831671272, 0.07420687630240407, 0.16281443701258727, 0.10324097584400858, 0.16349765392286436, 0.14410045476896421, 0.1523443159780332, 0.10035999079367944, 0.09536536237491028, 0.06989278458058834, 0.18232757065977367, 0.1126826142093965, 0.14004654730004923, 0.13963458154882702, 0.12841623994920934, 0.12652121377842768, 0.16594408479120049, 0.20560012757778168, 0.17225907450275763, 0.08181030223412172, 0.13185300624796323, 0.10296657628246716, 0.11550673123981271, 0.09607754594513349, 0.2681161644203322, 0.1352444871195725, 0.15200461420629705, 0.10918805029775415, 0.09263212153954165, 0.16206933770860943, 0.14748684662793363, 0.2147295041275876, 0.18699505020465168, 0.10933837294578552, 0.11699498923761503, 0.06698209326714277, 0.06324740938310112, 0.13506740305040563, 0.22323548341436045, 0.15401891326265676, 0.15643965479518684, 0.08904614539018699, 0.15064447719071591, 0.10980824487549917, 0.13906708200063023, 0.12768251289214405], [0.06462310520665986, 0.04413518136633294, 0.027131724836570874, 0.02452880682955895, 0.05081019836610981, 0.09399115932839257, 0.04891102973903928, 0.027897091981555735, 0.04748353115948183, 0.025472864475367323, 0.025991869125781313, 0.054241817976747236, 0.040017450893563886, 0.040290113405457566, 0.06755552999675274, 0.023027049377560616, 0.013051421764040632, 0.02212594639110778, 0.023247932882181237, 0.08398589584976435, 0.01539747609889933, 0.03238818634833608, 0.005086415547079274, 0.013959576425674771, 0.027696108212694526, 0.05233939916693738, 0.031152828530009304, 0.009384515894843, 0.07109921984374523, 0.013538578525185585, 0.018084223714790175, 0.03663473330172045, 0.020532381454748765, 0.07965043706021138, 0.013634678591707987, 0.036532525571861436, 0.015772103764382855, 0.015153161083747233, 0.0372607395319002, 0.018387474585324526, 0.011298064375296235, 0.05174625099503568, 0.03532849232267056, 0.04168420770604696, 0.04914829647168517, 0.07325198075601033, 0.031341298416789086, 0.11456786947590963, 0.023943716261003698, 0.0272632198341723, 0.06866002894405808, 0.09756070814494576, 0.04180128213816455, 0.07172940924231495, 0.015062851465440221, 0.0390735238657466, 0.07516038085200957, 0.04636180081537791, 0.05687908681907824, 0.01008668852903481, 0.013564793725631066, 0.04827440104314259, 0.018263719975948334, 0.01529149741067418, 0.054398871692163606, 0.012581662640773823, 0.038539343779640536, 0.061788328391100676, 0.014385022123211195, 0.019868706353008747, 0.021582685810114657, 0.03506503074562975, 0.03210205491632223, 0.07534950213240725, 0.06313554609992675, 0.0198379297009004, 0.027526186080649495, 0.016252291122717515, 0.06027483567595482, 0.006530098035000265, 0.010792139335535467, 0.006374486630582916, 0.08195538659180913, 0.007970313208975961, 0.021380833516429578, 0.01967490996633257, 0.035078302890594514, 0.04207857565156051, 0.025974842985825877, 0.03858597270612206, 0.03641167848504015, 0.024329502434868897, 0.03072797739878297, 0.010364797980790692, 0.03270494345841663, 0.04400525887363723, 0.019732654992757098, 0.02671490586362779, 0.03282676085031458, 0.027628792449831963, 0.0745251974357026, 0.054026227045272074, 0.0704716428049973, 0.037197632382490804, 0.01146582791781319, 0.04636990252350058, 0.037031733963106356, 0.029449922764407735, 0.06378126716507332, 0.03454443153792194, 0.020435730926692486, 0.07886554846274, 0.03310214428763304, 0.05284164400239076, 0.08719225201223578, 0.05890647481594767, 0.031037847378424237, 0.03721255336755088, 0.03921367527384843, 0.05322615961943354, 0.0237296995307718, 0.07273560882146869, 0.04336084738107664, 0.026225509088752524, 0.017343277045126473, 0.02389615265253399, 0.01911232979702098, 0.022999770573473403, 0.009085488904799734, 0.046640213911554644, 0.039807586797646115, 0.015109353166605746, 0.09075619612953492, 0.07122110508914505, 0.01979547885379621, 0.013701189442404678, 0.01591717964038253, 0.03704258713072964, 0.07513323266591344, 0.06373740666146789, 0.045481333775179725, 0.0393347293138504, 0.02717891864345542, 0.03417726266863091, 0.054298631713858674, 0.041136497631669044, 0.00199954049561971, 0.13086363433727197, 0.04289981676265597, 0.0389407379552722, 0.020636886025645902, 0.09453018754720688, 0.036835980002901385, 0.048138202101524384, 0.012766747485979326, 0.061229269818535874, 0.018373483193239996, 0.00643409593197118, 0.014992796117439866, 0.027163926412218382, 0.03249283341158714, 0.04340413112991622, 0.0804231595247984, 0.04388899868354201, 0.07309289143553802, 0.012617372242467744, 0.050839080209178586, 0.01942899700121156, 0.0422661396940904, 0.016161671074639474, 0.028473541406648498, 0.07856941542455129, 0.01899147083583687, 0.05741529233221497, 0.03722411221159356, 0.03787168567734105, 0.11427012830972672, 0.019870914984494448, 0.0373042166632201, 0.020906417098428522, 0.04792823622535382, 0.057830793250884326, 0.03064168810046145, 0.02180174575187266, 0.038028586722378216, 0.006355427430077855, 0.07658057500209127, 0.01134348550944456, 0.07216340702559267, 0.03559733468240925, 0.03584272687190345, 0.03300171431952289, 0.005588106104239289, 0.013766815653070807, 0.02555940143897065, 0.04501542109729988, 0.04582161569435682, 0.03298954479396343, 0.035609059767531495, 0.03513391222804785, 0.09950646837907177, 0.02440019730212433, 0.037443899882159064, 0.02567676255213363, 0.08365940515484128, 0.021030991038839732, 0.023094885916049992, 0.018109231122902462, 0.026957431242668202, 0.08403093700430223, 0.024022146427471722, 0.008450771981318082, 0.07564063436750855, 0.028724555258772204, 0.044320974432464154, 0.031440259356583865, 0.09861425589770079, 0.0492216291438256, 0.05146106951204794, 0.013082845568923014, 0.034046264697930644, 0.07621284294873476, 0.025777116185054183, 0.08019127696752548, 0.04712053867323058, 0.02891800898526396, 0.03658095940149256, 0.04330219142138958, 0.06301634785320077, 0.031855047813483646, 0.013915427544686412, 0.014512946330276983, 0.027257248726008192, 0.03326734042327319, 0.03642157152561205, 0.06815977900155953, 0.045249810841466696, 0.06515946678285088, 0.06389409396797419, 0.025239290669560432, 0.08459853833275181, 0.022187518355037485, 0.046539865367646725, 0.01591946291072028, 0.010206265059033675, 0.07582301100982086, 0.019264750814597522, 0.008000797242857516, 0.10204941406846046, 0.030792563754533018, 0.0793088421757732, 0.02022715604731015, 0.00703416728148503, 0.01019972822229777, 0.04545994295871683, 0.06383362292711224, 0.04822353466546961, 0.040194921727691374, 0.052092860253261666, 0.0005372176435360286, 0.014613050601578184, 0.010722768459735172, 0.06429065697427307, 0.0445976199449173, 0.0521460573987237, 0.0474923826488001, 0.04947614423664553, 0.02867734618484974, 0.048939955686884265, 0.03605492512828537, 0.04087783329721008, 0.02374188432336918, 0.03391538207818355, 0.040639701432415416, 0.036133621619748216, 0.07245962148798363, 0.08099287788250617, 0.06346152110823564, 0.039758050348609686, 0.022107134007715752, 0.07389074005186558, 0.046813538896718195, 0.03650100762024522, 0.0304270437253373, 0.04695679120985525, 0.03595576402066009, 0.06990011954413992, 0.049085443772907765, 0.030849825324756757, 0.017989501922524402, 0.01829834052893732, 0.021950163412839174, 0.01976793542105172, 0.0057592682590309, 0.035740498785993884, 0.01582517707720399, 0.028055438306182623, 0.025689077962722098, 0.04541525464238865, 0.03279707494324871, 0.02357371281167226, 0.020787770161405206, 0.04207355109974742, 0.07179393113723823, 0.00917118278864239, 0.022739250445738435, 0.03716724419168063, 0.021299355031390275, 0.03173056038628731, 0.01684823994790869, 0.021783649222925305, 0.055146742811692614, 0.010877731439125325, 0.04490684192361576, 0.05253996733309967, 0.02201563016777592, 0.060213482539568625, 0.017066183699561015, 0.051490358476127894, 0.04114135933507766, 0.03387873100915125, 0.03016112924420408, 0.055884381623140404, 0.05636287773294108, 0.03050686319225601, 0.013150700767125403, 0.05437671073845454, 0.044775362193052254, 0.017189794120245745, 0.038613629793482165, 0.03673955339140125, 0.050662606821528504, 0.041143510291086774, 0.07215351398502078, 0.06840638576873712, 0.06033021091882672, 0.006298269760528845, 0.017756767803803086, 0.0845523097419313, 0.01619581495677786, 0.04653849133423396, 0.05930183681526354, 0.09124626804675375, 0.02798869929808591, 0.09657557707812105, 0.06688316964677402, 0.019093968639416353, 0.011034484054627163, 0.03825824707746506, 0.02309887230928455, 0.07887480368039437, 0.022460486207689558, 0.3406472424311297, 0.15967035000877722, 0.08467852404075009, 0.1131084356456995, 0.1322129690753562, 0.1253466018076454, 0.250753430383546, 0.13076412039143698, 0.12485759519040585, 0.10318570238138948, 0.1942567184035267, 0.12540667929819652, 0.08972495182284287, 0.099001115853233, 0.15277042239904404, 0.12964604395840848, 0.1460244950971433, 0.15741295899663652, 0.07962866965681314, 0.22771681366222246, 0.0832297567810331, 0.14717778749763966, 0.0901005548824157, 0.10312736872583628, 0.1690059604921511, 0.09326647035777569, 0.15759593274976524, 0.07646234027509179, 0.14886455770049775, 0.11484910867043904, 0.10924381230558668, 0.14159011947257177, 0.10329664964228868, 0.2505350506731442, 0.12963885148721083, 0.10762653087398835, 0.11642568478626864, 0.0802848944440484, 0.11160165364188807, 0.07872817904821464, 0.14840554233108247, 0.09628415985831193, 0.1340901090630463, 0.1273903221424137, 0.13819277605840138, 0.18225765441145214, 0.06629104606275048, 0.13758582648422035, 0.11575290374457836, 0.10619462520948478, 0.13133467334721768, 0.2796495498291084, 0.10527920004512582, 0.19079617623771938, 0.09772434365004301, 0.13615924731961318, 0.17329092270561627, 0.0814336881573711, 0.27990932017564774, 0.15524669523750032, 0.11713479459285736, 0.11375858754451786, 0.2058818553175245, 0.17410589754581451, 0.19264010872159684, 0.12532207955207142, 0.1821271042738642, 0.22271906398236752, 0.09444609670234577, 0.15124363718288286, 0.09574798827192613, 0.07846405250685555, 0.18167790052081856, 0.12279826855020863, 0.13038830698600837, 0.11144603163536106, 0.07469005430383341, 0.0753146390031491, 0.0935274213552475, 0.17130567851875508, 0.12036945245095662, 0.09855849388986826, 0.1562384691621576, 0.06663414050957986, 0.08010711148381233, 0.08685803280345031, 0.12549019338829176, 0.140575913180198, 0.09860869869589806, 0.21312497236898967, 0.15592007339000702, 0.09632307384163141, 0.10581301711499691, 0.12311533439372267, 0.12961302644440106, 0.07743602445615189, 0.141050928405353, 0.14843477361968585, 0.1166490585144077, 0.18504632477249416, 0.15284849463828973, 0.1169647401464837, 0.12537877793822969, 0.11614046937652997, 0.1199175345578364, 0.16545230975108488, 0.08450832031667233, 0.1482224871537515, 0.11811320137764726, 0.1263257549809558, 0.12023198125617844, 0.20410961684371742, 0.09860719234815665, 0.10146311231489692, 0.15569965807454927, 0.10872742001499448, 0.13935602935297148, 0.10951545701495238, 0.1364928422761815, 0.14210894091853074, 0.1576741271253143, 0.1349606287798711, 0.1332520233201129, 0.16351765713521413, 0.13707218904580387, 0.06967023187982184, 0.10872681611882788, 0.14299185068479606, 0.06758765184453555, 0.13792893450175012, 0.13818295087133134, 0.13367682695388794, 0.18699965067207813, 0.16060983602489742, 0.13010666067046778, 0.11875679184283529, 0.09279106836766005, 0.18275563126163824, 0.17909481269972666, 0.08917374390044383, 0.13957872454609188, 0.10776615981012583, 0.11180404706725053, 0.16484761291316577, 0.1115531926708562, 0.11690536833235196, 0.05048919362681253, 0.1882247185068471, 0.10214034454630953, 0.07337554876825639, 0.11786666246397154, 0.11392862163484097, 0.13199814488845213, 0.13497167532997473, 0.08997220998363835, 0.1742239762097597, 0.08314225969037839, 0.10580871520297867, 0.1786441704524415, 0.11469353416136333, 0.13124308469040052, 0.13954832617725643, 0.23914888022201403, 0.0736257042735815, 0.12841216873909744, 0.1392235250345298, 0.13823234822068894, 0.13682677650025912, 0.11122510741863932, 0.1358332790966545, 0.15246001976941312, 0.1223739670323474, 0.11391883715987206, 0.10951447313917534, 0.11203834520918982, 0.1403721762554986], [0.06991796501513038, 0.01709457190840372, 0.010589894339708346, 0.05438283112432275, 0.04876956197300127, 0.014370538793238146, 0.014074498205445707, 0.01793054910376668, 0.029620835557579994, 0.021050140993403535, 0.06894247593092066, 0.049673238303512335, 0.025951148542974676, 0.0077770053675132135, 0.026892361430717365, 0.019493824236893227, 0.04311616765335202, 0.0293457201415939, 0.02211992608915482, 0.022760067900110568, 0.06311442330479622, 0.07129254125590835, 0.013347145984880626, 0.04805591615981289, 0.0719024356720703, 0.027294580026396682, 0.028920933471194336, 0.06609546512897525, 0.04811325915423887, 0.024085094121151736, 0.0296170662955514, 0.03897794203034469, 0.027347717800044587, 0.03338118842137711, 0.040362228107239516, 0.12683428983603204, 0.023703849042898843, 0.05914680513420275, 0.04483599268964358, 0.026890383501138006, 0.028921140424375023, 0.023608647187107375, 0.03190262668899127, 0.033310641135488234, 0.06603506194161517, 0.050908294173755815, 0.030402270411806445, 0.033440923251743825, 0.08922869845160417, 0.021207106499267474, 0.009605028749709683, 0.03645680445645537, 0.05095132007928831, 0.022627348146800483, 0.056580324457692246, 0.038318908108132224, 0.028751116512077193, 0.030969702106501375, 0.04245488778022783, 0.04738518090120383, 0.05409478622355631, 0.05084894950102482, 0.04208705394661852, 0.06565045472234488, 0.05879974804286446, 0.009312398648554725, 0.05779400308217321, 0.016858227983383194, 0.04721254123640912, 0.042484977415629795, 0.0380573633925191, 0.044554169954998155, 0.045642051579696793, 0.028154541738331318, 0.0341423215078456, 0.06381965189107827, 0.013991768671465772, 0.030912230190421854, 0.03685993228905967, 0.06298592234296457, 0.035903781452881436, 0.043503794353455305, 0.1030349319002458, 0.05114456345992429, 0.01783017341845802, 0.00485847018925207, 0.03875987105337637, 0.046831743991268535, 0.033111653955919404, 0.07053499761968851, 0.04339554426925523, 0.052964872747127495, 0.028246630814724734, 0.013685950394054609, 0.06443800085357257, 0.010888185119256377, 0.014834083383902907, 0.035687237179705074, 0.03899944480508566, 0.06466631431664739, 0.019046520381899815, 0.04049398942983576, 0.05925126560032368, 0.0042961079993152195, 0.041209854052535126, 0.006908070454041341, 0.08338628123913493, 0.03758305723645857, 0.009286554946031953, 0.032009031157940626, 0.04498355370014906, 0.04667889380029269, 0.0668324762955308, 0.05738232910100903, 0.017643581377342343, 0.002647299498286364, 0.010334031506707626, 0.021884345516030277, 0.026837802126205394, 0.007007548352703452, 0.03003269274319921, 0.03341743576207331, 0.046729699109814, 0.04362612064661724, 0.06834587401577405, 0.04779835783743432, 0.018292732437008193, 0.0467871778112437, 0.026604688027873635, 0.039441198243626525, 0.05535013707620757, 0.015315619330587131, 0.03206840297207236, 0.058449488266238143, 0.02880992174946836, 0.04017480655706354, 0.037991056950496774, 0.06899432957704578, 0.03390811836080892, 0.013619339459442666, 0.018505743239074945, 0.027386143238150647, 0.013879595806689134, 0.07813964491443974, 0.028474321721919944, 0.07410009524651937, 0.027895424481747404, 0.046101918510560475, 0.06267989626420395, 0.02746907718080495, 0.024822463214929615, 0.03509812289848924, 0.06779434039656605, 0.051948135519134145, 0.032533962811742506, 0.039694929628499916, 0.05072452314198017, 0.053786347952804396, 0.07009948670331921, 0.05267769976386002, 0.03812595310487917, 0.05678726067500455, 0.03173718288806932, 0.04760993205543075, 0.034938093807016096, 0.037282866558858326, 0.03331710757421596, 0.032690171751060655, 0.024644732841157486, 0.02254877718431609, 0.0250920112510877, 0.008668725910995687, 0.02388291443432016, 0.013039289557907199, 0.05301891466868775, 0.0353120548118438, 0.034454786883933206, 0.030751600595457212, 0.021512236911803484, 0.026062033039384654, 0.0050671926500009635, 0.018112491483667066, 0.03211191403014319, 0.010099185447740768, 0.031695917780910215, 0.03519548928099019, 0.03848642822621124, 0.06100047459559781, 0.051990431999521594, 0.026057539441223656, 0.02574059403767543, 0.05224456372005599, 0.047791294287890196, 0.033249399957380125, 0.018731888782765185, 0.02639841677487961, 0.026374118435861807, 0.011026665634874786, 0.031160485797694752, 0.01320406500183578, 0.010827343428640493, 0.04503010459510343, 0.07355634442397527, 0.0678636934608221, 0.026652998024863855, 0.02779119980654546, 0.005906307221656399, 0.027944462207545127, 0.0799303666821548, 0.04056466903005328, 0.06049088801124266, 0.05416767784793462, 0.029488619616521255, 0.048066762542085986, 0.02546150071014251, 0.013725786336830683, 0.03722130646929145, 0.01863475819118321, 0.025654118142223785, 0.031540007397000275, 0.021472143973889093, 0.011063507541881075, 0.03247313553999577, 0.02757901342452637, 0.11632938709642206, 0.023911110957020094, 0.03861676123259323, 0.045371614662664275, 0.05790492320167167, 0.03411934631211417, 0.037804507317819765, 0.024472551187500358, 0.05218242687572326, 0.062186221326036115, 0.04091023673702564, 0.04495470239115613, 0.011770829408695655, 0.042413459824664254, 0.036304568339671404, 0.017342666363609687, 0.02155711521793689, 0.013188245806044765, 0.03813409213242786, 0.0671247620401638, 0.07491892416562353, 0.025554091902449727, 0.05052498974172132, 0.06432647683790751, 0.031546107426817925, 0.044264611921140125, 0.04194747929328254, 0.01604693758833621, 0.03450655571318098, 0.03480722136529429, 0.047927442339382, 0.012944429514131375, 0.08706035158996071, 0.04525284728567515, 0.041986220250172276, 0.0730587136266487, 0.014805934358654278, 0.02927978689383183, 0.025828739129272953, 0.03418857724006687, 0.01781804290866213, 0.04581033504967179, 0.03187540725671819, 0.008596820706900741, 0.08674209831016404, 0.027966141401390945, 0.03316840323220406, 0.0239927896098899, 0.047738178566630395, 0.04991588242618101, 0.006499617393793804, 0.08119194648627724, 0.03695870663172432, 0.016046292980068495, 0.05254785869536655, 0.03332984367651599, 0.026009003831339732, 0.044782571627625396, 0.037036039267799685, 0.03189533922289099, 0.031179779940950017, 0.037417321665478606, 0.08126431224601609, 0.039859725428479056, 0.0434775927237102, 0.013376526551188102, 0.01597822573967278, 0.0494066249313099, 0.028341744460963776, 0.08131031013493027, 0.057449999398418834, 0.02471905278175005, 0.038200323935598135, 0.07240629542086806, 0.0274759812746197, 0.04121956728132708, 0.05447585827537945, 0.08621254922556025, 0.07436417429042713, 0.02949183926518474, 0.027105942202199782, 0.011662648874334991, 0.05753362883946725, 0.026136941609105895, 0.034128934011927674, 0.018541111876921992, 0.026069401929687177, 0.022968110129503266, 0.039498626054929833, 0.04699863985713039, 0.043040874015007696, 0.002131827046728826, 0.009571041778794356, 0.041007955957736285, 0.06121700869074889, 0.0756444273782628, 0.03462386763255511, 0.03572260921022721, 0.0394671691714653, 0.019574269652366638, 0.04260570575882282, 0.01424651955520468, 0.01912481484136411, 0.012874011149896043, 0.033460142756147046, 0.020106836521465863, 0.04087886467043843, 0.011314296629279852, 0.03409118710884026, 0.03351993865466543, 0.060475580261221955, 0.04603550350293517, 0.07195405861628906, 0.03772026380257947, 0.037411737322275124, 0.033327407735799036, 0.03575732645445636, 0.032110461965203285, 0.03392596383179937, 0.03854864649474621, 0.03279200628665941, 0.04599474051168986, 0.04104352476341384, 0.004773090127855539, 0.03394641148458634, 0.023451807210221887, 0.011179423375454332, 0.07915243306862456, 0.12598495398248943, 0.11853839856173311, 0.16281434201768466, 0.12235561944544315, 0.13307930901646614, 0.1134689955839089, 0.07731152685093028, 0.11465761251747608, 0.1151175099824156, 0.13138033875397273, 0.18223150367183344, 0.146041621321014, 0.11875095644167491, 0.10710740408727101, 0.1120455376803875, 0.14389393585068838, 0.18266290266598972, 0.0895801999473146, 0.1168163852500064, 0.1415055197264467, 0.17983266524970531, 0.08906370587646961, 0.13514969577746733, 0.08031593742115156, 0.0963174080742257, 0.19313946978322097, 0.1514555572399071, 0.11465154641440936, 0.08949705226612942, 0.13177131063171796, 0.06694515382072755, 0.13834009958165033, 0.15804258521114076, 0.08133149399821248, 0.10665435982601983, 0.18828789011708327, 0.0720575080652322, 0.10674011308167662, 0.1286040177302701, 0.05391866906679102, 0.1364883775157588, 0.1477204662348543, 0.10411405363785368, 0.1431315474744354, 0.14890820107289723, 0.12688038950519903, 0.0694119135982224, 0.09234045326177563, 0.3232035184545176, 0.10755207522639207, 0.1293368898332119, 0.15074898515428814, 0.19146774948707648, 0.1055429805336254, 0.12335253666554179, 0.0835862997919321, 0.10191642120480537, 0.11731377856007644, 0.1714735073702676, 0.08699948699878794, 0.09387939782547099, 0.12366866613073008, 0.13793006086988108, 0.14242027992648737, 0.16347988987607615, 0.11115120816975832, 0.19054445331650122, 0.13572423851915769, 0.17901283209877356, 0.1230879080082689, 0.13876180909574032, 0.11895425910396235, 0.20719377563468047, 0.14251155645719596, 0.10358947142958641, 0.13459576692964348, 0.2213910081024681, 0.15227800953601087, 0.18815740783299717, 0.09583800951285021, 0.1351502114640815, 0.14400630124977656, 0.18331037435148442, 0.1186690301235233, 0.2270427569746971, 0.07112094653504235, 0.04754941690979259, 0.09669489746115037, 0.08782278746366501, 0.1262373011559248, 0.11977795990450041, 0.11825006189090864, 0.19339488393494061, 0.06035644308264766, 0.10259408091327973, 0.11112889115299497, 0.14279028507215635, 0.12399771490267344, 0.09420130840901818, 0.21760090147810324, 0.09521485652242388, 0.10116440762898751, 0.18261666728981904, 0.08173765827502523, 0.1594917867332697, 0.12075715378991195, 0.16717574798635074, 0.1820524518511125, 0.08709697212491717, 0.10970282767500196, 0.23046162351965904, 0.16324693523347378, 0.2505442516079971, 0.17043462954461575, 0.1375584000987666, 0.13156111405364104, 0.10522716997989587, 0.15009795794529573, 0.20597841085067817, 0.057308592700532505, 0.20637918077409267, 0.16002666231776985, 0.10601269640028477, 0.09119030247841563, 0.11377027191753898, 0.24353509343096189, 0.1428987963923386, 0.136933672907097, 0.15113667292254312, 0.10008531981813056, 0.14072805430207933, 0.1037694053458316, 0.09246598224022559, 0.2032401692122221, 0.10025090950408153, 0.09447640007627861, 0.17452702351978847, 0.12820562267942087, 0.1103771354204842, 0.17926956260842936, 0.21054404228925705, 0.12841919836189064, 0.11264397842543465, 0.2222105019858905, 0.09160647514675345, 0.13774380300726208, 0.1537322729293789, 0.13456466288438865, 0.1466478652187756, 0.06099684443324804, 0.18047122098505497, 0.05386869156999247, 0.19653924235275813, 0.14211109865989002, 0.08366053830832243, 0.11139643751084805, 0.2114685598228659, 0.1236818568514926, 0.20443627717239515, 0.11358175453330789, 0.11041415629110166, 0.11372139025479555, 0.18834795403693402, 0.12327773496508598, 0.1535467885966812, 0.08199761861136981, 0.07363538696829762, 0.10337635715092931, 0.12813956051000527, 0.13013103364833764, 0.1300650936152254, 0.06918842451913015, 0.26351333569203106, 0.11987192343388285, 0.14652469754219055, 0.19706354636166776], [0.058302191884389946, 0.02771734126976558, 0.06075447850993701, 0.07465284344341074, 0.061925494245120456, 0.006996385179393525, 0.07430237332092864, 0.02645613974891603, 0.05262085209999766, 0.013287731762310224, 0.027701049643967832, 0.012059272948785551, 0.058372040279209614, 0.0937541334756783, 0.01999968057498336, 0.009596509742550552, 0.0444170889178557, 0.09512621270758764, 0.039504787152899165, 0.02707194081241531, 0.05851125530898571, 0.023672892579010556, 0.019429368499134268, 0.024643469069685255, 0.05037560686469078, 0.061427530965634754, 0.08091339429042169, 0.02011994581802615, 0.1689556131937674, 0.0689640940566148, 0.03338253192071404, 0.02474473533220589, 0.0051165734600674894, 0.028124363893376927, 0.014110445294396153, 0.06580114377928631, 0.04912496843774404, 0.06419759589646544, 0.047830954659730196, 0.04653574326740844, 0.0691340331520353, 0.07327367352055651, 0.045844916586897204, 0.012205112176681203, 0.025094593076833656, 0.024406650170151676, 0.053414809317993264, 0.04039515741169453, 0.021408963881965195, 0.050113729666918516, 0.041377767720924954, 0.03170125445883189, 0.0305671612066882, 0.05626914829814008, 0.07606250673000302, 0.12243606655725411, 0.028670876353446926, 0.055689988125647814, 0.021804941651810492, 0.05596684737663184, 0.00941822212189436, 0.02234987821429968, 0.0861029386786478, 0.021338347046236907, 0.02245626232719847, 0.03655436082876154, 0.021883107189621245, 0.04266420565545559, 0.02138295054568776, 0.00973758565461529, 0.052045037105147324, 0.01931219907211406, 0.09438444501055138, 0.03724850893818906, 0.03980969025620392, 0.028281621169298887, 0.09754633677325078, 0.013793428644670971, 0.05684421011911971, 0.0338999420138342, 0.12426260140325342, 0.09179506716983658, 0.07596847534711872, 0.007609074735747916, 0.026593777184773768, 0.07933557645550796, 0.03930302815777915, 0.11731736122497491, 0.04577705290700708, 0.05099598125421575, 0.029154698963143995, 0.14646862340824945, 0.03368641722149082, 0.06462362767862422, 0.04643039731308818, 0.041632452447499545, 0.027501063321584036, 0.04087061707728675, 0.023172352562791536, 0.09204991135214056, 0.05727640978459801, 0.01764071117421346, 0.04850019374862313, 0.03744600334071687, 0.021849551936611533, 0.050394208902227025, 0.03958475589752197, 0.029316685628145933, 0.028899583366832564, 0.08128294481762818, 0.03663181220846517, 0.016545905099649514, 0.04337773272501571, 0.02643297117070428, 0.03144222032278776, 0.028551169205456972, 0.06575855892151594, 0.013351318975245314, 0.03179913992062211, 0.010516965395904012, 0.04633308182071362, 0.013492651034279593, 0.029036962959383215, 0.03336241675008621, 0.033302118735654015, 0.0207961568542357, 0.04132060793095401, 0.023846504245219485, 0.008636750796410655, 0.007745880118039037, 0.05538973637989589, 0.017391846581761326, 0.018242122206304754, 0.038639074856681485, 0.036371560102062564, 0.061952072461800914, 0.02792644371012492, 0.02805127210116812, 0.04433252649115665, 0.043188292533159256, 0.03881987051240035, 0.06731411402246781, 0.06339096703699656, 0.0467346184886992, 0.038189084003014226, 0.015881872070687156, 0.06554355153015681, 0.03962392433147345, 0.04377410574150937, 0.04280479811131954, 0.07088148474161114, 0.003546990707816024, 0.017068899535973157, 0.007951188699475356, 0.011958960027966117, 0.04383274134514587, 0.02736196873177375, 0.041442350683999915, 0.0521660911451493, 0.028831495770386288, 0.04138252764408078, 0.02073148907428341, 0.014657138414414865, 0.05671686605949487, 0.051669427260224304, 0.03950032239247646, 0.05397343702082123, 0.03208094908456717, 0.042814531696162055, 0.020869328374309198, 0.020711589338524, 0.03589280275627971, 0.010338816874926644, 0.05191033094057015, 0.012239496090582438, 0.04965629189142159, 0.01248996626652245, 0.044426435737737587, 0.06923498559210982, 0.030357826368084977, 0.03745625261217356, 0.01701838769284742, 0.03311582694628409, 0.05176132804315005, 0.031514284134443314, 0.045976596485291205, 0.010260463043648218, 0.030547609220125845, 0.040129734868449826, 0.04687646962702274, 0.033849143489663086, 0.01163612409228725, 0.021889683890289495, 0.040391734202525446, 0.03685611552957978, 0.048564925989402194, 0.027541062960933362, 0.026828869212684885, 0.05641757783346942, 0.04753901496795671, 0.013881766270580036, 0.06170257513544389, 0.066156838621412, 0.047808311946157894, 0.04873181167723877, 0.023798536908413683, 0.00928272631218923, 0.06836230134857552, 0.018976366646321755, 0.04411426213170801, 0.019361028148393546, 0.04988479534430163, 0.060914755266691954, 0.01600320770272187, 0.03791720859174218, 0.021053533668496778, 0.029871835839003325, 0.036073625553399324, 0.05278344266116619, 0.012330952433070965, 0.022616147229980146, 0.059710362393941195, 0.008278801521685506, 0.004221070507940437, 0.031407632000212155, 0.04747409952272262, 0.09757284713642937, 0.04020729820643153, 0.020746503357908556, 0.039486622770449946, 0.028558202220925262, 0.0752352164792163, 0.022492029604368975, 0.03856175918398159, 0.011057737449716245, 0.05768053845635482, 0.07091734531734671, 0.0628652245338474, 0.00946479506923684, 0.046289896459451745, 0.030434280301311185, 0.04940831448350634, 0.011352631313327168, 0.05886431743523904, 0.02829305618070066, 0.06455910578370094, 0.023686190169038515, 0.029244126485926763, 0.04650240684194224, 0.03949285850727132, 0.022478620056062937, 0.023552686707781892, 0.010168191610968538, 0.13815555162727833, 0.02193621442919331, 0.019624062248372605, 0.056731780259204764, 0.016135153926110694, 0.07880071444170815, 0.03777733538299799, 0.023202423538480486, 0.05719525021101747, 0.08747488898890358, 0.08356440346688032, 0.055092093601290665, 0.04685594733538372, 0.06992861801492316, 0.1129833273589611, 0.024746862539489354, 0.05073517953444805, 0.02118752058595419, 0.09176198858767748, 0.02537748111145837, 0.041598892105477195, 0.06288760940411262, 0.08459208546472446, 0.04744330421090126, 0.07791830000600644, 0.022967375615345578, 0.05728328334433692, 0.03599692056221621, 0.050875351298600435, 0.04708912589454225, 0.0547802660481206, 0.055326707262013636, 0.024647538583459597, 0.013585303294738489, 0.046241615300199816, 0.04006319433184607, 0.0270509096195123, 0.03870407172611781, 0.015241104311176708, 0.050076515413820744, 0.07088777476123401, 0.03920652690742697, 0.06852109211363963, 0.011624499091080256, 0.030124708877078125, 0.04073775313528521, 0.052953313903084824, 0.02444085681677929, 0.015338616578706672, 0.009814830081138228, 0.07004569244704076, 0.05058551845805986, 0.033785334056509395, 0.045154079728360684, 0.029350517384175743, 0.01611612780418779, 0.02420663840270468, 0.05502496273922069, 0.023902688641101122, 0.03568855353764125, 0.08401791591729436, 0.03359875388975654, 0.03536096700866308, 0.05132033795650516, 0.050744285474398305, 0.03514340493295874, 0.041230298312647004, 0.045277834337736876, 0.05237278308985489, 0.01613539141336722, 0.005340058298315853, 0.004777445898590875, 0.03570612420194915, 0.04087928875482508, 0.020632845349609852, 0.0135062777137916, 0.035041207381125004, 0.022482311286564385, 0.012154870899394155, 0.014133501066161054, 0.051827899113829644, 0.029223461701933826, 0.038192558102309704, 0.0745991441820349, 0.008042804497693266, 0.027321243059954474, 0.030569888917463164, 0.04093437222763896, 0.022017424892900244, 0.022495924395376017, 0.04452459939888545, 0.017819442387138094, 0.012765612636160637, 0.007628497800656727, 0.017629237147048116, 0.032089155965617726, 0.03086954355239868, 0.020763933226200085, 0.0055732720564784744, 0.12082320238862719, 0.12957377997892244, 0.2038617751428059, 0.1984249318816832, 0.15549142924802645, 0.09176971710153989, 0.11651370434888772, 0.15165305164243492, 0.12329169921576977, 0.07988168857991695, 0.10298349894583225, 0.09181201018925224, 0.1986889634281397, 0.3005091276551996, 0.12042004402194705, 0.09114519347037588, 0.0957593469481383, 0.30238685118300573, 0.11947731460843768, 0.13608133792877197, 0.10236510248588664, 0.06995027685271842, 0.12753909773060254, 0.14783754066697188, 0.1405315777020795, 0.1662291373525347, 0.2904474032776696, 0.11590845111225333, 0.20315722509154252, 0.11577625891992024, 0.16408635090504373, 0.15236695190625532, 0.10438193926321608, 0.2173748950340918, 0.20730904516364845, 0.12824766470917634, 0.14559224114886352, 0.14867003528135164, 0.13530913793614932, 0.11318101175129414, 0.1520433042730604, 0.12210521288216114, 0.11078309613679137, 0.06370033829339913, 0.148246737995318, 0.15221563859709672, 0.15532498460795197, 0.08130442723631859, 0.1079298835247755, 0.15704911494893686, 0.1948593660656895, 0.09667559313986983, 0.11418153877769198, 0.08782524376043252, 0.14708372897335462, 0.24105461367538997, 0.10206169555229799, 0.12556656928999083, 0.17394116281398705, 0.1869448386132717, 0.13539194634982518, 0.14756706303783826, 0.11982895859650203, 0.1788469845695155, 0.16610016141619, 0.14980033891541616, 0.08736427421016352, 0.12100324487047535, 0.07589301546769482, 0.11994756651776177, 0.12507973398481095, 0.06605340952851943, 0.2181940089379038, 0.0929141885467938, 0.1630236700709377, 0.10959338676184416, 0.2563012141202177, 0.1432861177516835, 0.14158526116183826, 0.25858334451913834, 0.2158596177718469, 0.07617884834430047, 0.1754517581846033, 0.11435888069016592, 0.16205332428216934, 0.15252749329166754, 0.15596093476883002, 0.16243725296642098, 0.15788696998996393, 0.1288900338113308, 0.10131023158984524, 0.2513385447008269, 0.14161618878798826, 0.1603482879166092, 0.14920994559569017, 0.1981605746384178, 0.10795844306371041, 0.10597636085003614, 0.11955454546426024, 0.19013811940593378, 0.12014417882476534, 0.12521761230060033, 0.1855460793844291, 0.2065577440496002, 0.05860876079116549, 0.11143523614321436, 0.2297771173928465, 0.14682900692735398, 0.11281075554766826, 0.1424043072121484, 0.08630298437284571, 0.17550057199384483, 0.17585442800606998, 0.16563094088009425, 0.12897684558161668, 0.07785430058304753, 0.1495242565870285, 0.2035903339939458, 0.1875760525997196, 0.14843558786170824, 0.06856825029743568, 0.15324736466365202, 0.12572379942451203, 0.1830058614058154, 0.12101600132882595, 0.07173513607787234, 0.09077798388898373, 0.10433512034692935, 0.17699166626802512, 0.12472642080060073, 0.1333860068448952, 0.15073823715959275, 0.1453530711254903, 0.08426216816795723, 0.1387080962636641, 0.15267500680472168, 0.10849203621702534, 0.25587503984570503, 0.1640429925173521, 0.12531354358153685, 0.12555571272969246, 0.12496593009148325, 0.2223604717957122, 0.07781466735260827, 0.160695399290749, 0.15524746876742157, 0.1592124067246914, 0.075569517112204, 0.08263865778488771, 0.17220462885286125, 0.14187430350908212, 0.10522517508694104, 0.08604612494153635, 0.1188076412571328, 0.0786362239824874, 0.07615476035113845, 0.07360829306500298, 0.15993784208382877, 0.10244962080780949, 0.1826518696865865, 0.11904812763844218, 0.1027936041355133, 0.07372364401817322, 0.10262950722660337, 0.23413814338190214, 0.1847638235028301, 0.12038615798311574, 0.08478493190237454, 0.11540097477180616, 0.10054070502519608, 0.07358707527496985, 0.09121087566018105, 0.1306714867906911, 0.165483278089336, 0.07738167380115815, 0.13082236583743775], [0.01888409606181085, 0.016135352397603647, 0.04115160521385925, 0.1014996717817017, 0.025032142410054803, 0.10896171815693378, 0.025304428335013132, 0.05090871486546738, 0.02890998191599335, 0.007558813102410308, 0.026159060154376284, 0.03689147738207664, 0.055355629817183526, 0.04043417317526681, 0.043655324793819866, 0.011777640203945339, 0.03344833624682256, 0.049435835863862715, 0.02960369915568403, 0.055045325575130324, 0.01685114238145096, 0.036754579549389224, 0.03210626522611294, 0.017698089791727916, 0.023332117025607398, 0.03977172961458564, 0.03095165646768042, 0.041074130085429976, 0.03221871544207845, 0.0540020169158067, 0.08305617395256247, 0.017253101437485645, 0.0321390690015895, 0.05779099038669041, 0.036055349212672026, 0.03393682039209774, 0.08629755609269653, 0.026624138234183192, 0.02635678695514798, 0.06031007199947323, 0.01513943262398243, 0.03607084695249796, 0.09050394395100218, 0.029729781140174185, 0.05527444649487734, 0.01316710265486368, 0.04852426138573459, 0.013975892648366945, 0.08717490187180893, 0.030535073285656314, 0.04121863768835153, 0.03247957483732274, 0.024274305307439396, 0.018239872862717936, 0.02841893969369786, 0.016666075347789695, 0.036382789856621196, 0.028344906434150677, 0.03962600404130561, 0.041539608500897884, 0.017683401204911724, 0.06843127443322114, 0.01647389557079545, 0.002734076281610344, 0.02144939439105136, 0.021171346007447158, 0.07484053980026927, 0.05836575025958674, 0.01197846875792103, 0.03897644586062857, 0.05915799417666026, 0.03631211364907878, 0.09549616357045514, 0.17453384958207607, 0.006244074320420623, 0.04217664431780577, 0.08498678928507225, 0.20944865606725216, 0.29926618720803944, 0.26868901082447594, 0.3898409227175372, 0.902766903596265, 1.0689320415258408, 1.0329121457678931, 1.1832806084837233, 1.1103881427219935, 1.0107230735676629, 2.341351632561002, 2.5189623534679413, 2.445881200688226, 1.6944003020014082, 0.33548141962715555, 0.5146424302033016, 0.7547827043703624, 1.5794932735817773, 1.3622959511620658, 0.6923869582159179, 0.3047431047473635, 0.2806579885738236, 0.42509274397577557, 0.10856025612780026, 0.036118656529911926, 0.0024814112569271985, 0.021524901767926555, 0.03307193251592772, 0.015786702445309077, 0.019879342389426062, 0.05284374746094857, 0.033805177813129764, 0.01575069428820695, 0.03707626282370516, 0.017777491959610155, 0.027958568950582827, 0.03431648448375719, 0.09907373945627894, 0.0692243529483676, 0.04544528999498912, 0.04465998409848128, 0.07914598020059721, 0.0501012378372252, 0.023584328492039015, 0.055269255701984675, 0.021542945710409964, 0.024006275493385534, 0.03818745891164456, 0.03632384551955121, 0.022016820996733646, 0.04556399291115148, 0.013532406401022204, 0.004249607994487243, 0.036571151177797995, 0.03144649509340525, 0.04371695612956371, 0.04018979200295039, 0.01408678901913975, 0.0760529258155397, 0.023551979335024953, 0.015148843904691083, 0.008714887496483113, 0.040236926438020806, 0.07446858047374658, 0.020812065107747912, 0.034861972355949025, 0.00933071824588946, 0.11317881329783372, 0.0268487180583179, 0.030564545454191308, 0.03827216722337263, 0.018863265036738346, 0.029970053782952682, 0.023451440801311816, 0.050822873400258164, 0.011311604541593363, 0.04851721819224102, 0.048430735511439185, 0.056319502381873984, 0.0675617725189243, 0.0041180850073163, 0.10228245692061526, 0.06857154797762632, 0.03336691543725984, 0.013047498135295297, 0.03261851506041629, 0.014182559996178108, 0.06666296467717205, 0.027931488617988567, 0.005066737607454083, 0.013160145974584987, 0.042460824961641004, 0.0679225360176393, 0.02913899766281247, 0.049954745519374094, 0.03956741254244532, 0.026863371022045612, 0.028794770062501942, 0.018869755224191716, 0.022243794353146638, 0.046571457958115, 0.05562228050881198, 0.0431987148310457, 0.043180204395736964, 0.0329318794954036, 0.07232852173703057, 0.0457165513320693, 0.01759353093802929, 0.02929639403841325, 0.0549796196365995, 0.03986987631235804, 0.013462116958440414, 0.028482755912201743, 0.01724534578222249, 0.08520873130432197, 0.07108007158551898, 0.04195236474541681, 0.0312409363021808, 0.0804039773398212, 0.05111046368256211, 0.029032372669982057, 0.023115024835403477, 0.047919778286346366, 0.04151355954153197, 0.019579884529645954, 0.005976827366144529, 0.0702949251447405, 0.035831174813210964, 0.025859688807811056, 0.04968948243185878, 0.04118967781375561, 0.021165700596092, 0.06957224463777882, 0.02475897778224732, 0.047409187470163615, 0.006815869843454233, 0.013469173722634358, 0.05324092793411442, 0.020049724228946224, 0.009316006758516389, 0.04040497920608946, 0.03024650252025042, 0.058867418340274265, 0.03911979656134333, 0.033595317109887085, 0.05466714747516172, 0.012725823342667093, 0.01963983309854354, 0.03873467704813395, 0.039206906887037415, 0.018037418369203806, 0.036235669893877845, 0.03174573921465448, 0.02404179680161178, 0.07149798808885471, 0.02414803163680647, 0.02510958700440824, 0.038470777816006115, 0.016614036800872003, 0.057563423312136104, 0.04086285463667341, 0.04157916369980999, 0.024779262586629817, 0.035893376118370464, 0.031795859203806946, 0.0514799124295158, 0.11898156335311276, 0.010857599305122026, 0.042299927345344, 0.02651534871464329, 0.05141872553420918, 0.09805742970534734, 0.11269720271229744, 0.07404771912842989, 0.11456235977155821, 0.08677646610885859, 0.3167087441044194, 0.31619574448892046, 0.4012720121869019, 0.737030816929681, 1.2520822137594223, 1.3047926596232822, 1.446078849690301, 1.3233405500650406, 1.3945401523794447, 1.0803389208657401, 2.8980519430977956, 2.429141253232956, 2.7921781156744276, 1.731962914977755, 0.4540036554847445, 0.7516861419592584, 1.2232046318905694, 1.959390048469816, 2.1756036579608917, 1.1617967784404755, 0.4893649922949927, 0.8639766307813781, 0.6019754239491054, 0.08628764269607407, 0.053490404904420884, 0.03411228276257004, 0.06456111424735614, 0.028720602792288576, 0.046562243452561755, 0.018273567215406468, 0.04347321617283991, 0.02639915468171239, 0.061752651019820144, 0.03816883312538266, 0.036413429105388265, 0.02359600268703486, 0.027379692066460848, 0.029245215534631695, 0.04010390643296497, 0.08716264074402195, 0.07447001218263592, 0.03725834769595947, 0.04626344716442483, 0.05803967347102506, 0.04991160426288843, 0.0155054530727544, 0.020980066985690167, 0.07845450551914317, 0.0451691839178758, 0.04282698620642934, 0.03694059992475169, 0.0384421673869448, 0.02081776819457965, 0.02821645636244544, 0.02348455161388431, 0.02982059626707009, 0.030703879227595668, 0.0341172224975058, 0.07298369479498693, 0.029885301366448402, 0.03106850359056677, 0.02576924517883786, 0.06256563096706357, 0.035627017196800025, 0.07873971414353166, 0.03861524470682655, 0.026358661408137, 0.04059087744514857, 0.02303192125899451, 0.05747094577444451, 0.014714265973972422, 0.08363209412034069, 0.042425782020602903, 0.03326051436098559, 0.03511408204212785, 0.08282388427427836, 0.10466996380793196, 0.04143979260697961, 0.020703272195532918, 0.049864245911261866, 0.04267718603036233, 0.08924742601811886, 0.02518684839430664, 0.03868135776636856, 0.025471453122528534, 0.01951113705789404, 0.031095251441001892, 0.03696035207914455, 0.04909603909722396, 0.06332240107336215, 0.005309300730004907, 0.06804865532155548, 0.02496837538533977, 0.029748461209237576, 0.02303250988812319, 0.09618867641048771, 0.03626026339562876, 0.033487843948283365, 0.0023505769828001833, 0.14764802583626338, 0.17854927054473332, 0.15932228868561132, 0.15323292543845518, 0.09356440829911403, 0.11823433344917637, 0.10965695870774132, 0.14390942001981394, 0.09830729344061442, 0.10393014350639922, 0.1327121401471751, 0.1280037449406726, 0.22001948526927403, 0.1094045504661543, 0.14464601049465792, 0.14721065573394299, 0.23321354442409106, 0.18669280356594495, 0.10684213082173041, 0.18718319439462253, 0.12003197627408163, 0.081987983414105, 0.18686968407460622, 0.17143789785248892, 0.09249732377273695, 0.14269415023071425, 0.08736023692680256, 0.14234824664890766, 0.07748147951705114, 0.11506518136177744, 0.21654491099928105, 0.10433789555515562, 0.1304763536900282, 0.16732589421527727, 0.11102876652564321, 0.10030864604881831, 0.1470553662095751, 0.07828601848866258, 0.15282433879162582, 0.15161504011069024, 0.2010380516627005, 0.15042080490716866, 0.14830099365540914, 0.11096247365432126, 0.16189888971192495, 0.16709479875862598, 0.146938346060259, 0.0905492225927966, 0.23023268580436707, 0.12891613026814802, 0.12062341453773634, 0.09373830325369324, 0.10538359265774488, 0.07620191853493452, 0.10600285085716418, 0.14866704972726957, 0.08396515981959445, 0.12757624073752336, 0.14200023960854324, 0.10191920998373202, 0.1140310668519565, 0.14126727251069887, 0.2028433619333165, 0.10469019772218806, 0.14948096605283873, 0.11805422311382634, 0.13072385612343038, 0.1454030927270651, 0.12100595901054995, 0.11476036986070019, 0.19376953026013716, 0.14791859846029962, 0.19113142681973322, 0.29074791286672863, 0.21748666332236358, 0.28589676746300285, 0.18900747650435992, 0.5604570603796414, 0.5130105806248528, 0.5502777323126793, 1.263920532805579, 1.8436610698699951, 2.16129384296281, 1.8177926008190428, 2.35304371373994, 2.1836598770959035, 2.327112168073654, 4.749944022723606, 4.357387738568442, 5.033850891249521, 3.0117726751736233, 0.9274326286145619, 1.3297197563307626, 2.192890993186406, 3.049507907458714, 2.9286819909300124, 1.8482497036457062, 0.9492131684507642, 1.2524294065577644, 0.7413153584514345, 0.346486606236015, 0.15910188694085392, 0.0965272585994431, 0.191288059843438, 0.13861767468707903, 0.09066377287464482, 0.07068937112178121, 0.13872823518301758, 0.13839386669652803, 0.17258428276649543, 0.15763740481010505, 0.14024769222097738, 0.08294175937771797, 0.17001092513757093, 0.22833783605269023, 0.17848543397017888, 0.1861850693821907, 0.17980850940304144, 0.1670833993703127, 0.13996004765587194, 0.22404215298593044, 0.1303058514105422, 0.13152901934725897, 0.16983153404934065, 0.12617596159023897, 0.1648462965552296, 0.17954427429607936, 0.16535245653774056, 0.159194126991289, 0.1433545005108629, 0.16911117413214274, 0.15289776985134396, 0.13358283628310474, 0.09056105624352183, 0.10212830054972853, 0.19382755857493195, 0.04322018028636064, 0.15781568310090474, 0.18778779623763903, 0.16448219466422284, 0.2246243224612304, 0.15787912612514837, 0.12725931060101303, 0.07233004165547234, 0.20971017703413963, 0.09629251262439148, 0.10113810082631451, 0.17336112393864564, 0.18968925492039748, 0.12907669879496098, 0.16668720277292387, 0.13019354029425553, 0.19598991397236074, 0.17129791607814177, 0.11945923843554088, 0.13294681826872484, 0.17319138161838055, 0.21729104167648725, 0.30030893268329756, 0.12798709369131497, 0.15393985036228383, 0.09576318067099367, 0.0950211144185492, 0.10332133474626712, 0.206546493938991, 0.10048812534660101, 0.09019230638763734, 0.08075153654707329, 0.2334684564598969, 0.09658189423914466, 0.11738062783011369, 0.12193912108029638, 0.1539803453321968, 0.0995812632941774, 0.07625240832567215, 0.08224303115691457], [0.04662634465577347, 0.027119494242859737, 0.04726758738979697, 0.02255556423084012, 0.037464174508516274, 0.02181933507589357, 0.02537535220783736, 0.015376341429405978, 0.017466873895110827, 0.019084202824160457, 0.03397063857742718, 0.03295500057616404, 0.02061066573618778, 0.06247273273766041, 0.026551090546750596, 0.03609133192471095, 0.03956652366157089, 0.0756109348897423, 0.048290597674037726, 0.03662430761115892, 0.05750084202736616, 0.06751635817012616, 0.006720621338380235, 0.06788410379418305, 0.03346685007480638, 0.018586129282734225, 0.04019314057326742, 0.03934476823945131, 0.05158288351127079, 0.010584572080655821, 0.029475147303725992, 0.04670893933091845, 0.02782237170530217, 0.01585796897831772, 0.028626534089978253, 0.04792898600654943, 0.05130516591348818, 0.04624795281727399, 0.07260111639542238, 0.08366049081087112, 0.044707101570176225, 0.03246451135990875, 0.08135980247919049, 0.06040021537670067, 0.03324344241991639, 0.051489408527101786, 0.01833406200499407, 0.029412291212273494, 0.054390169480549436, 0.03138714024264898, 0.07323982140847615, 0.03954707345526133, 0.0293295540447746, 0.04309540448178138, 0.023109308177871362, 0.03606791907389249, 0.0390503281461341, 0.021735619121630276, 0.037815340129392486, 0.08284238792423691, 0.04006226134619542, 0.00780727735920144, 0.10640807197030101, 0.08124551682599954, 0.07818716950714588, 0.024509487241240482, 0.048434813506901264, 0.03762220870703459, 0.04217747552320361, 0.10174391724701438, 0.24259659807596887, 0.9635111497981208, 1.0830087661743164, 2.900563499757222, 5.769236505031586, 7.002729790551322, 5.527440062591007, 8.90522299494062, 15.504219021115984, 21.38735430581229, 22.055446181978496, 20.59326205934797, 30.373456069401332, 29.690100737980433, 29.006344148090907, 32.0348676272801, 31.409769466945104, 33.71163470404488, 33.74416964394705, 22.38695342200143, 19.764694588524954, 20.055280412946427, 21.32992570740836, 29.96491936274937, 28.743688344955444, 26.73368045261928, 15.998920338494436, 23.136168990816387, 20.004410914012364, 12.14468422957829, 6.730739516871316, 1.2650812076670783, 0.02247649454511702, 0.03312960459983774, 0.04809711002079504, 0.03655570772077356, 0.0533961156782295, 0.0240688466001302, 0.038645344520253797, 0.0948653838464192, 0.048131209798157215, 0.028197742366631116, 0.019850090744772127, 0.08643855566957168, 0.027845677686855197, 0.05843832636518138, 0.012617733562365174, 0.04874880897945591, 0.022059755300038626, 0.007655698573216796, 0.060671405467603884, 0.019007131424067274, 0.04475679068959185, 0.06072477224682059, 0.027146415119724612, 0.009484303799191756, 0.023789313921172704, 0.032104887800025086, 0.029450791289231608, 0.02437713898585311, 0.05878138688525983, 0.04105248821101018, 0.0529539788674031, 0.0493841857782432, 0.04230112495965191, 0.09030706701534134, 0.03085469381351556, 0.028349333875147358, 0.03884717136887567, 0.014980803010985255, 0.03997954114207199, 0.03641389390187604, 0.048950534047825, 0.012555439806809383, 0.02888390581522669, 0.021937839520562972, 0.01914411237729447, 0.05793887030865465, 0.04393424339858549, 0.027032850409990976, 0.010735246718728116, 0.013241396302224269, 0.014709241422159331, 0.027291183958628347, 0.01664088643155992, 0.0415256951403405, 0.02415251505694219, 0.09276790996747357, 0.011676293365391237, 0.011752729487073208, 0.00324914330849424, 0.027682929366294826, 0.03172460963417377, 0.01075407861000193, 0.032017556950449944, 0.02682334933030818, 0.04876070369833282, 0.014254122540088636, 0.022543898517532007, 0.030794372050357715, 0.017921711185148785, 0.06884959805756807, 0.009210570898306156, 0.01889788219705224, 0.006497519872417408, 0.07815434198294367, 0.0769365005461233, 0.07891443012548344, 0.040562155057809184, 0.014151947040643011, 0.029682158159890344, 0.02428225095250777, 0.033473866126899204, 0.03527672349342278, 0.023444853922618285, 0.02752223700684096, 0.03227187866078956, 0.022390278189310005, 0.02727897372096777, 0.03636667464992829, 0.02036263743814613, 0.06757316512188741, 0.05909354692058904, 0.027765020229188458, 0.0191772062264915, 0.050445913270648034, 0.023963945086247156, 0.036067505167531114, 0.007396893442741462, 0.024397272816193954, 0.045713698092315874, 0.05934160575270653, 0.021370168642273972, 0.031793796457350254, 0.06700388781194176, 0.047880955905254395, 0.040190283940838914, 0.042165808113557954, 0.07279392890632153, 0.05238608916157058, 0.05312889840986047, 0.04616760748571583, 0.0302996284195355, 0.03722536410870297, 0.015246932926986898, 0.0314585153412606, 0.0268687484120684, 0.014861596282571554, 0.032333438750356436, 0.0113856233822714, 0.018426581951124326, 0.025125936305682574, 0.11327753335769687, 0.04322666029578873, 0.05248239024409226, 0.026833956528987204, 0.07622407948864357, 0.017603462994364754, 0.08986707776784897, 0.015600917860865593, 0.03888783936521836, 0.05419973184221557, 0.06904513149389199, 0.06625680718570948, 0.10447839301611696, 0.008047262472765786, 0.0020644595455710907, 0.0712729858766709, 0.15246296461139405, 0.05826680628316743, 0.0802178755402565, 0.048958194708185535, 0.055635047145187855, 0.01870117150247097, 0.0835727019501584, 0.18282771882201942, 0.32718141643064363, 1.1024752301829202, 1.2932171779019492, 2.962008808340345, 5.124237835407257, 6.887117411409106, 6.78974883045469, 10.54302109990801, 18.73623960358756, 24.08861936841692, 27.231454610824585, 26.358931098665508, 34.456325258527485, 34.207430362701416, 33.65099777494158, 35.91122245788574, 35.28442198889596, 38.3274758883885, 38.605761664254324, 28.042986835752213, 23.40230236734663, 21.996330908366613, 25.74536521094186, 35.90959657941546, 33.77088199343, 32.17340081078665, 22.42863392829895, 30.380466801779612, 26.0280214037214, 17.28513090951102, 9.472790939467293, 2.2186483996255055, 0.08771042206457683, 0.1067245067762477, 0.020970709987783005, 0.013936021930671163, 0.07836689986288548, 0.08034501943205084, 0.018099936889484525, 0.06429628202957766, 0.006724237505945244, 0.0415019973048142, 0.07829355022736958, 0.09032846122447934, 0.037227206331278594, 0.009759845844070827, 0.032466166985354254, 0.05105258125279631, 0.03448343123974545, 0.03976258974788444, 0.0545050013544304, 0.08206040345664535, 0.025680099248087833, 0.061302022343235354, 0.021021778229624033, 0.03302101185545325, 0.016894295512299453, 0.04380393414092915, 0.026033977312701087, 0.023982740506263714, 0.08228574493633849, 0.013529954345098563, 0.007552150736695954, 0.0772808909948383, 0.04909110614763839, 0.0716996690524476, 0.033573732910943885, 0.05819131926234279, 0.02901168752993856, 0.0171602727579219, 0.01753282410624836, 0.014833465917035937, 0.03199843583362443, 0.03058655034484608, 0.08913164080253669, 0.06603040719138724, 0.04047001339495182, 0.04984501962150846, 0.04744865106684821, 0.042976911911474805, 0.03654238807835749, 0.07250456086226872, 0.013424244526374553, 0.054975080237324746, 0.023200991829591136, 0.06523684013102736, 0.09048700771693673, 0.03364826659006732, 0.043418407506708584, 0.07356376081172909, 0.03535180678591132, 0.029694873906139816, 0.066697420685419, 0.02712469351744013, 0.051818284272615395, 0.024294732604175806, 0.007539475702547601, 0.012252534140965768, 0.08216928118573767, 0.042703408016158004, 0.049281669314950705, 0.034218731336295605, 0.018086688493245413, 0.018676294712349772, 0.021284003176593354, 0.06297710138772215, 0.2659641227551869, 0.16868846038622515, 0.11888850906065532, 0.11929610504635743, 0.10405257157981396, 0.07659117371908256, 0.13745427211480482, 0.12620178663304873, 0.13396357585276875, 0.196187679788896, 0.14258831233850547, 0.12079758090632302, 0.10517729087067501, 0.09840804910553352, 0.08812367024698428, 0.1268517824688128, 0.12264291117233889, 0.15608277251677855, 0.11303754909230129, 0.15460926587028162, 0.12829921979989323, 0.1356028893164226, 0.09361099651349442, 0.20115169270762376, 0.1845770635242973, 0.13251300368990215, 0.16721555085054465, 0.09325245182429041, 0.17117347275572165, 0.15483900425689562, 0.11201030135686908, 0.27389041600482805, 0.1609703145389046, 0.10743641893246345, 0.18836683088115283, 0.10617954816137042, 0.18183893045144423, 0.12720103801361152, 0.15934708235519274, 0.28997378583465305, 0.13764422120792524, 0.1455542838999203, 0.13733210867004736, 0.1005973694846034, 0.10561533272266388, 0.1881774788988488, 0.17395309145961488, 0.1484457523162876, 0.1707286794802972, 0.13292803641940865, 0.15275283477136067, 0.11690687468009335, 0.1778854461652892, 0.17882388723748072, 0.09754611964204482, 0.13888040344629968, 0.10071620810776949, 0.16001887273575577, 0.21535727115614073, 0.17695715597697667, 0.09740009890603167, 0.07623488176614046, 0.32007851185543196, 0.15001818936850342, 0.20253343427819864, 0.09002085415912525, 0.18237049478505338, 0.18281524734837667, 0.2710746313844408, 0.36754257923790384, 0.595237734062331, 1.769207430737359, 2.3625447239194597, 4.922175535133906, 8.305507472583226, 9.69837897164481, 10.703014663287572, 15.991843598229543, 24.26437405177525, 31.33616372517177, 34.76541587284633, 35.91939353942871, 45.178420543670654, 44.607931750161306, 44.278840746198384, 44.6474426814488, 45.42673526491438, 48.117619718824116, 47.80899463381086, 37.395468848092214, 32.9091351372855, 30.032914434160503, 35.865142004830496, 46.53635215759277, 43.59334189551217, 41.09497812816075, 30.73089919771467, 36.73351049423218, 33.21771853310721, 23.559217010225566, 12.245612893785749, 2.8224952774388448, 0.15971806459128857, 0.2147036519433771, 0.10739335910018001, 0.15757629594632558, 0.1405116966260331, 0.18163459641592844, 0.11925292307777063, 0.21608619418527397, 0.10882111213036946, 0.1805199940821954, 0.14510178246668406, 0.1698428520134517, 0.13173046282359532, 0.19349838766668523, 0.10066513477691583, 0.13653287584228174, 0.1362745032778808, 0.10681077571851866, 0.21026641290102685, 0.1043399175895112, 0.1726139754589115, 0.20773260029298918, 0.18006475136748382, 0.1299440022557974, 0.09260077322168009, 0.08905395532825164, 0.12150895701987402, 0.11620497091540269, 0.2153491558773177, 0.19623825778918608, 0.133657108726246, 0.22091437796396868, 0.11303148298923459, 0.1798593181052378, 0.10860008613339492, 0.12568277519728455, 0.12602325049894197, 0.07153435756585427, 0.12488774928663458, 0.1107417665688055, 0.12201609409281186, 0.16018390602299146, 0.23560242195214542, 0.11033740040979215, 0.10496763712061302, 0.13261144555040769, 0.1654002254030534, 0.10225439949759416, 0.17031166542853626, 0.2581419439188072, 0.06401413359812327, 0.1557302057210888, 0.13984893076121807, 0.11158754689885036, 0.09822464108999286, 0.20703668120716298, 0.10012629654790674, 0.11161718530846493, 0.11672669649124146, 0.10451538674533367, 0.1675863295261349, 0.12015978513019425, 0.19420212347592625, 0.11521481190408979, 0.16859810666314193, 0.06481264717876911, 0.1830490840865033, 0.11540230470044271, 0.1281765406685216, 0.24540383315512113, 0.08533071832997458, 0.12207921142024653, 0.10319999232888222, 0.24764468148350716], [0.023264952236786485, 0.06700096332601138, 0.11976589555186884, 0.03206771765170353, 0.04587862959929875, 0.022727662763957466, 0.05925509253782885, 0.00932162078762693, 0.045696344559213946, 0.007823719110872065, 0.03603571919458253, 0.056986912818891663, 0.007785599013524396, 0.04399611222158585, 0.02868864040023514, 0.057399265335074494, 0.03294430007891996, 0.03938343795016408, 0.03441648018945541, 0.057609197284494124, 0.04874032389904771, 0.04995993631226676, 0.023145336691024046, 0.014612428045698574, 0.03156375612265297, 0.011380497050205511, 0.03604708804881998, 0.00875924587515848, 0.03906234839398946, 0.05475899058261088, 0.037430980575404, 0.021264042372682264, 0.03789183138204472, 0.01978497682804508, 0.034916146591837914, 0.024611744164888347, 0.005265186199851866, 0.049458383582532406, 0.055232835334858725, 0.06257814993815762, 0.019319089595228434, 0.057391353616757054, 0.03408459514113409, 0.04676515256453838, 0.02029799171058195, 0.0527547236665019, 0.007064470655417868, 0.03306038384991033, 0.026631734433716962, 0.05784846908812012, 0.02236718594628785, 0.04579543102798717, 0.08183890927050795, 0.03203681377427919, 0.0319627041795424, 0.04256917004074369, 0.01313024717715702, 0.032063266461981196, 0.04975539193089519, 0.04434083854513509, 0.026068387519834296, 0.02283846413982766, 0.14195655552404268, 0.08666477924478905, 0.3103720412722656, 0.3940960429608822, 0.9053918570280075, 2.3354252534253255, 3.0525944275515418, 4.540405460766383, 8.784873247146606, 13.997444834027972, 17.714479207992554, 27.856321743556432, 27.495632069451467, 35.595211437770296, 41.122426986694336, 57.40884467533657, 60.05266203199114, 71.87511920928955, 71.05452305930001, 67.83602714538574, 71.34408228737968, 69.58911323547363, 76.56406239100865, 80.80615302494594, 74.30986527034214, 73.99905845097133, 68.06173937661308, 63.90706402914864, 65.47222219194684, 64.37049497876848, 69.71437535967145, 72.43958391462053, 71.87905883789062, 68.77677849360875, 66.2281723022461, 61.457872663225444, 57.794879640851704, 53.144752570560996, 47.86235679898943, 27.51403089932033, 11.592469198363167, 2.0242456197738647, 0.12998874485492706, 0.08942434045353106, 0.052171434608421156, 0.022905718834538544, 0.011578646239026316, 0.02679465917338218, 0.017301396167437946, 0.03643625841609069, 0.02187045251152345, 0.023816105876384035, 0.07747910464448587, 0.011899604329041072, 0.06665215561432497, 0.014190300384403338, 0.044339294877967665, 0.04403164031516228, 0.0483621491917542, 0.09734704425292355, 0.011037738478210355, 0.04654118172558291, 0.09191140199878386, 0.023030608293733427, 0.012067327159456909, 0.024578952263774614, 0.015074159251525998, 0.037215589811759334, 0.019303841217021857, 0.03205017412879637, 0.011935050150246491, 0.022624566153224026, 0.017679163753720264, 0.040214215870946646, 0.03982968668320349, 0.11567192737545286, 0.04728864911677582, 0.012396581188243414, 0.015805740441594805, 0.014809288017983948, 0.02894413936883211, 0.02720061140800161, 0.008449235099500843, 0.01678278167465968, 0.07865341127450977, 0.013612054537848702, 0.02793588552490941, 0.04193513334861823, 0.01905960592973445, 0.03416026536641376, 0.017628936895302365, 0.026725336643201963, 0.08885223365255765, 0.0316477791140122, 0.03587274865380355, 0.028829487306731086, 0.031326292614851675, 0.07174747862986156, 0.010013660349484001, 0.034446532505431345, 0.061343419764723094, 0.06637329129236084, 0.03568761715931552, 0.009298809288468744, 0.029170875237988572, 0.025977813272870014, 0.05947033063109432, 0.03633167242099132, 0.009275667003488966, 0.04364930958087955, 0.02837212077741112, 0.05631759909114667, 0.014102766822491373, 0.05294472025707364, 0.008355564188345202, 0.03831185134393828, 0.07435605222625391, 0.0036161298214990112, 0.0035509325721899843, 0.022799792732777338, 0.03944901157436626, 0.013235958692218577, 0.026973342888855507, 0.03685981354543141, 0.12245908246508666, 0.03162431537306734, 0.019055948625983934, 0.014721779052966406, 0.016726777090557983, 0.023365706205368042, 0.07575654850474425, 0.03666580681289945, 0.03349943332640188, 0.03129340062982269, 0.038100066993917735, 0.06206530638571296, 0.052864581878696165, 0.0197061225771904, 0.0374221935469125, 0.02660992292554251, 0.02201434943292822, 0.036974116161997826, 0.026617563229852488, 0.04082782865901079, 0.02399004832841456, 0.04459331803289907, 0.03415970218234828, 0.0352260572835803, 0.12211047831390585, 0.034512048454156945, 0.010928200873812395, 0.01611447217874229, 0.02150276117026806, 0.014429688387151276, 0.013100495961095606, 0.04661586468241044, 0.06880367480750595, 0.01812594852942441, 0.01686543402528124, 0.054539304692298174, 0.02580195395941181, 0.05805765464901924, 0.017157835120867406, 0.03601847422708358, 0.01113088776557041, 0.0187956625928304, 0.12477801660341875, 0.02568481506646744, 0.02315995912067592, 0.05208459908940962, 0.03637690017265933, 0.033953922867242775, 0.010983253812550433, 0.028381520183756948, 0.07314621071730341, 0.04004288577873792, 0.10245366487652063, 0.06690899468958378, 0.5626014481697763, 0.6034921939883913, 0.9921515158244542, 1.8150068074464798, 3.4992370094571794, 5.113624027797154, 10.082770688193184, 14.192166362489973, 19.486186470304215, 31.178967680249894, 34.187370913369314, 43.732910360608784, 48.341327394757954, 66.71750613621303, 69.5451728275844, 82.69443021501813, 80.31549208504813, 78.01128183092389, 82.18416840689522, 77.82621656145368, 87.75772149222237, 91.18165479387555, 84.21522412981305, 84.0825343813215, 79.10039111546108, 72.86873940059117, 73.8334550857544, 72.43849999564034, 79.09570802961076, 81.9160304750715, 80.9871049608503, 79.28073160988944, 77.93410124097551, 73.14510399954659, 69.5485566002982, 66.33835683550153, 59.54816722869873, 38.04126569202968, 18.060061761311122, 3.7970806615693227, 0.39141732241426197, 0.11412838234433106, 0.05393884530557053, 0.04283515576805387, 0.04590580492679562, 0.08561750115560633, 0.027392479058887278, 0.04136202231581722, 0.03483405063993164, 0.043198633406843455, 0.026510123994999697, 0.11160949750670365, 0.0470483357618962, 0.07390866016170808, 0.060074450714247565, 0.01756734287898455, 0.044482428447476456, 0.01979643219549741, 0.034346000757068396, 0.020047915933121527, 0.034142538639051576, 0.009516160170148526, 0.026075585080044608, 0.01744773581490985, 0.012037310466569449, 0.03971704308475767, 0.05438182349982006, 0.03163526014291814, 0.008666843824487711, 0.016583065069945793, 0.048690828162112405, 0.047501006828887124, 0.06801590922155551, 0.06872941593506507, 0.02110160787456802, 0.08567947854420968, 0.010709059507852154, 0.03048067174053618, 0.04460189471553479, 0.03791680147073098, 0.020720890357292125, 0.022369141823479106, 0.04159328740622316, 0.024328364192375114, 0.029346198508782045, 0.01770460033523185, 0.0497637209482491, 0.010946166784768658, 0.019522862143016288, 0.015497831428157431, 0.06427199047591005, 0.029857634101063013, 0.040489965717175176, 0.03351514480475869, 0.024915483580636125, 0.029758676553943327, 0.021729108578126346, 0.013503468578814395, 0.043856785233531675, 0.05046363999801023, 0.03623030946723052, 0.009869978014778878, 0.049919078326118846, 0.041497366303311925, 0.06135378099445786, 0.053053343535533974, 0.020307643871222223, 0.024587895355320404, 0.048394484778067896, 0.0387903779878148, 0.04203275078907609, 0.024306120118126273, 0.09075934453202145, 0.19709672672407968, 0.17807175831070968, 0.11451916423227106, 0.13916000058608397, 0.15228267785693916, 0.15493653688047612, 0.0825662784544485, 0.1441229957022837, 0.13851148395666055, 0.14924886636435986, 0.0803318354966385, 0.07844446320086718, 0.0985119870996901, 0.11750785314611026, 0.10627623261617762, 0.12518832672919544, 0.12799227769885743, 0.11904614631618772, 0.14932870279465402, 0.20920089579054288, 0.14737724965172155, 0.1440339447664363, 0.1487659394208874, 0.10063038021326065, 0.10264143587223121, 0.18856737869126455, 0.09662513049053294, 0.09838403575122356, 0.13993537612259388, 0.17155486371900353, 0.22289916074701718, 0.11708157030599457, 0.10864860817257847, 0.1832742491470916, 0.12972099493656838, 0.13104269972869328, 0.16970391518303327, 0.10764842041368995, 0.1042362917214632, 0.10383503325283527, 0.09661246224173478, 0.19940042096589292, 0.1450724426124777, 0.09329388317252908, 0.1476657491709505, 0.07827342487871647, 0.17730809428862163, 0.11139585397073201, 0.12812536555741513, 0.09538696014455386, 0.17214862257242203, 0.25060920097998207, 0.10914290736296348, 0.1154226471803018, 0.12438340777797358, 0.1381006445735693, 0.11728903917329651, 0.15787090228072234, 0.14225642729018415, 0.18737627831952913, 0.10509233828634024, 0.2508419656327793, 0.13490665810448782, 0.989072703889438, 1.5299731365271976, 2.0036342229161943, 4.179752698966435, 6.854217256818499, 10.27336151259286, 17.8290411063603, 21.006961277553014, 28.757423196520122, 42.00088078635079, 44.58464138848441, 54.05625547681536, 61.50546087537493, 81.16617393493652, 80.87653132847377, 96.67472689492362, 95.58936963762555, 91.60667610168457, 93.52827685219901, 91.1761726651873, 98.28967584882463, 103.25863838195801, 96.60523101261684, 97.17933286939348, 91.1527294431414, 87.40643446786063, 90.28177969796317, 86.11043562207902, 91.54380185263497, 93.65997995649064, 94.26475811004639, 92.22853292737688, 92.70470687321254, 85.8287000656128, 82.1841961996896, 79.43637125832694, 71.81769234793526, 45.48439836502075, 21.001988104411534, 4.3239477957998, 0.6207640586154801, 0.24823155999183655, 0.10809582604893617, 0.07143654674291611, 0.11992096794503075, 0.10474579688161612, 0.1204574177307742, 0.1762866819543498, 0.16413278984172003, 0.19533972814679146, 0.1100592010521463, 0.20878447884959833, 0.2181962752448661, 0.11858892227922167, 0.1492499384496893, 0.09838470071554184, 0.1611360399318593, 0.10741174739918538, 0.08412112787898098, 0.06480305269360542, 0.16847145131656102, 0.10029230014021907, 0.0738886162372572, 0.1321320469890322, 0.13295966972197804, 0.12322992538767201, 0.13629029957311495, 0.07695107547832386, 0.09781934533800397, 0.08050053965832506, 0.1741377751209906, 0.17517415593777383, 0.16081374936870166, 0.19679126382938453, 0.15476197696157865, 0.19156437287373201, 0.10733659286051989, 0.07608647258686167, 0.11669574172369071, 0.11369632517120667, 0.09726655642901148, 0.09243709700448172, 0.20155937011752809, 0.07553749704467398, 0.07716424403978245, 0.17073123077196733, 0.14527590812316962, 0.0878660169297031, 0.1063048600086144, 0.08933860076857464, 0.19754544193191187, 0.1248382840837751, 0.09348679067833082, 0.14024800434708595, 0.18327988098774636, 0.14257843286863395, 0.1315516417047807, 0.07444061804562807, 0.19426766995872768, 0.12443604852472033, 0.08603323277618204, 0.10284855868667364, 0.10232278904212372, 0.11364738922566175, 0.13474665954709053, 0.0982036404311657, 0.06772681259151016, 0.1184100875897067, 0.16652389296463557, 0.1264050757246358, 0.13233106131000177, 0.21409906367106096], [0.043889019039592574, 0.011969156712958855, 0.008947501175238617, 0.05107371761862721, 0.03644086906154241, 0.053600320792091746, 0.03389829317373889, 0.05844206509313413, 0.03307789005339146, 0.017016316464703, 0.04899528682497995, 0.0450935781534229, 0.04217956541106105, 0.02869397707815681, 0.06302183720150165, 0.03381884690108044, 0.022927908625985895, 0.03696316460679684, 0.02331108583270439, 0.042398342064448764, 0.0031960761448967135, 0.04499030512358461, 0.046670744594718726, 0.027744648911591088, 0.07122189218976668, 0.05625233420037797, 0.0042840037827513045, 0.08721168525516987, 0.04132595478690096, 0.049387741301740916, 0.03418222615229232, 0.03657717996143869, 0.05644090247473546, 0.05957075381385429, 0.013047912889825446, 0.018194602702611258, 0.03313654601307852, 0.00991464512688773, 0.02932791199002947, 0.014882413736943687, 0.027498203296480433, 0.11276122249130692, 0.048089490072535615, 0.016039112383233647, 0.027099996539098874, 0.027004472379173552, 0.041659522602068524, 0.04169797518157533, 0.04322433631334986, 0.06402599439024925, 0.010386987772238041, 0.029557358606585434, 0.025898012465664318, 0.05311416062925543, 0.046057399827986956, 0.03195144049823284, 0.06314329496983971, 0.011966358604175704, 0.049718846034790785, 0.06252054910042457, 0.036453520346965106, 0.6731773604239736, 4.276782555239541, 8.456330282347542, 11.596308946609497, 15.846709626061575, 22.43480740274702, 27.008431332451956, 30.52370391573225, 35.985870429447715, 48.31606721878052, 54.68971232005528, 59.18283789498465, 70.02334785461426, 74.82020350864956, 76.67965262276786, 76.34818880898612, 68.59770257132394, 74.32392842429024, 72.73845372881208, 75.45673492976597, 70.1393688746861, 55.50308581760952, 63.577983447483604, 52.07431309563773, 57.914597102573936, 65.02000563485282, 61.68846947806222, 57.18252795083182, 64.51740074157715, 61.6193140574864, 65.00021716526577, 70.39673709869385, 69.53832190377372, 69.67586149488176, 62.4502352305821, 65.73110512324742, 61.139124052865164, 64.86034297943115, 70.59551811218262, 63.58729403359549, 68.77759838104248, 62.18724591391427, 34.21908943993704, 18.022558859416417, 4.0473087430000305, 2.1788814706461768, 0.3313569852284023, 0.03257614394117679, 0.025106511544436216, 0.04208610399759241, 0.012214276640276824, 0.07727167648928505, 0.11114781549466507, 0.011959338311239012, 0.03746539926422494, 0.024805048613676002, 0.035727705008217266, 0.006773268870477165, 0.04833135048725775, 0.041609986153032096, 0.006917409640404263, 0.06208556065601962, 0.03411298165363925, 0.041668448730238845, 0.005903210133380655, 0.03484362816171987, 0.009251819890258568, 0.0357802032626101, 0.028619188948401382, 0.04797867512596505, 0.033825313339808157, 0.03639497634555612, 0.036695370583661964, 0.04525840788015297, 0.037913836272699494, 0.06446018216333219, 0.020614307772900377, 0.0204076853780342, 0.042423091629253964, 0.018643733513142382, 0.010451067771230425, 0.03602118158180799, 0.0594018121649112, 0.03313206089660525, 0.01653591706417501, 0.08729593894843544, 0.03864581949476685, 0.0453146720038993, 0.06221163924783468, 0.016606467742738978, 0.021404258241610866, 0.0184946949926338, 0.038012278133205006, 0.03812777157872915, 0.0876823239294546, 0.04711017405082073, 0.01571753088917051, 0.0402411469258368, 0.01119477947109512, 0.04451509990862437, 0.05294596536883286, 0.013269986375235021, 0.05324667851839747, 0.07971168841634478, 0.002170932080064501, 0.01901304316041725, 0.04231759300455451, 0.03875520273244806, 0.03330640707697187, 0.030933984023119723, 0.02602268479365323, 0.038997307419776917, 0.07859044322477919, 0.03930367276604686, 0.07155090024960892, 0.038986844409789355, 0.017318720862801586, 0.06006269170237439, 0.03784418465303523, 0.0300552913519953, 0.010475126078485377, 0.0035258244440358666, 0.06320075331521885, 0.037718435150704215, 0.02578534511849284, 0.03357938171497413, 0.03517393561612282, 0.05026271899363824, 0.004208589280356786, 0.029998379227306162, 0.017914606923503534, 0.038238969897585254, 0.05933309692357268, 0.04734107951766678, 0.016642479292516197, 0.02018992991984955, 0.026377565393756543, 0.020312766810613017, 0.06584777270576783, 0.0216653483387615, 0.011369449651933141, 0.039709314570895264, 0.014868133967476231, 0.048884505805160315, 0.031697064505091736, 0.015830281356881772, 0.012041191686876118, 0.030666108575782607, 0.026577979193202088, 0.044574485293456485, 0.04132712186713304, 0.0543857691809535, 0.023969051062262485, 0.030299004167318344, 0.03589346772059798, 0.014032352699099906, 0.03280141417469297, 0.026380734152293632, 0.015036210484270538, 0.03940628083156688, 0.06054821064961808, 0.026479969898770963, 0.11164086618061576, 0.020930961406390582, 0.03419696732557245, 0.03626636342544641, 0.04327360134837883, 0.015688945905172398, 0.05300550342404416, 0.0796255280396768, 0.012325675975132202, 0.054833351235304556, 0.012256141402758658, 0.042921797904585085, 0.041230501873152595, 0.197483627391713, 0.861064684178148, 4.5476619856698175, 9.390664100646973, 13.061586754662649, 17.240980318614415, 24.326259919575282, 30.739747728620255, 35.11332259859358, 41.25206995010376, 56.44468137196132, 61.791886465890066, 69.0342995779855, 83.45900303976876, 84.59369250706264, 89.86137199401855, 90.8484330858503, 80.47773252214704, 84.69939545222691, 85.24550996507917, 86.01428644997733, 82.04232788085938, 68.06134332929338, 75.4344173158918, 61.452682358878, 68.10127462659563, 76.12725693838937, 70.64281449999127, 68.7651263645717, 76.15334742409843, 72.49101448059082, 75.087938444955, 80.2995251246861, 78.86044897351945, 80.63288579668317, 71.5165296282087, 74.1569493157523, 68.96183681488037, 75.1990748814174, 81.43696607862199, 76.92386790684291, 79.89204107012067, 74.76847417013985, 44.82832860946655, 24.95081959451948, 5.882263285773141, 2.9508762742791856, 0.2970426008105278, 0.029046917068106786, 0.01049478747881949, 0.05522672851969089, 0.01901940442621708, 0.03596801497042179, 0.037446837938789806, 0.011148558513793563, 0.023162337385916283, 0.08195815501468522, 0.06728392599948815, 0.024727132437484603, 0.010300259970660721, 0.025247456838509867, 0.04146742255293897, 0.040737312087523084, 0.08469614559518439, 0.034785725375903506, 0.05137337903891291, 0.03300247767141887, 0.03680161898955703, 0.049634415922420363, 0.034679368404405456, 0.066156438285751, 0.04647722301472511, 0.03418179188988038, 0.021637348591216972, 0.022863381642049978, 0.017185244542945708, 0.06194610135363681, 0.03981757822579571, 0.04412554277639304, 0.10487907472997904, 0.10527714408401932, 0.006598835328726896, 0.016665719116904905, 0.03915307191865785, 0.020583015434177857, 0.028126061927261095, 0.06830081929053579, 0.038712163256215196, 0.025251375378242562, 0.05274055924798761, 0.028914955577680042, 0.02039184158534876, 0.0543558491793062, 0.04535928907405053, 0.045456007455608675, 0.01301479444373399, 0.010294883428806705, 0.03121806967205235, 0.024673811459381665, 0.034924004027353864, 0.05267106029870255, 0.044816807111991305, 0.009228633500502577, 0.05552462914160319, 0.05236085783690214, 0.04494406635473881, 0.007029926861702863, 0.007931596000811883, 0.039107416689928086, 0.023196382880476967, 0.02996635576710105, 0.022637266632435576, 0.03003040947286146, 0.0939405406160014, 0.0588664480351976, 0.046809084314320765, 0.10401478396462542, 0.086387482338718, 0.14316596277058125, 0.16005001749311173, 0.12640519786093915, 0.163098417488592, 0.07212877459824085, 0.2021482978016138, 0.0956455362694604, 0.09165813201772315, 0.11672206888241426, 0.12983350961336068, 0.15656158753803798, 0.09348049387335777, 0.12457430682012013, 0.2128763028553554, 0.06839789729565382, 0.1228679676673242, 0.1381910118673529, 0.08121742547622748, 0.12864131001489504, 0.10516343518559422, 0.11788488791457244, 0.12542396837047168, 0.1471519217427288, 0.11917197385004588, 0.13297850585409574, 0.19811024091073445, 0.12278921689305987, 0.17223086101668222, 0.10682154406926461, 0.09823625760951213, 0.15881475806236267, 0.1372596818421568, 0.058182050473988056, 0.12558246058012756, 0.10876640863716602, 0.16963541028755053, 0.15166774871093885, 0.10070723108947277, 0.17244377173483372, 0.2013189380190202, 0.11229229372526918, 0.06924107883657728, 0.0916624746418425, 0.09640083395476852, 0.16970603221229144, 0.17464061028191022, 0.11890878368701253, 0.10687961988151073, 0.06991912531001226, 0.17355453356036118, 0.13572978893561022, 0.10857162158936262, 0.20149534355316842, 0.17171335592865944, 0.21925337852111884, 0.08600273262709379, 0.11313327002738204, 0.15190652518400125, 0.3893843229327883, 1.720967065010752, 7.02485546043941, 14.6272052356175, 20.02868444578988, 26.23649341719491, 33.39861488342285, 42.472924028124126, 46.65758432660784, 54.127074990953716, 69.70506477355957, 73.94518211909703, 81.78780147007534, 93.31072875431606, 98.13654450007847, 101.10904639107841, 101.69680145808628, 93.59295763288225, 97.42233221871513, 94.22123459407261, 95.77944455827985, 93.19960621425084, 79.5799001966204, 86.62623514447893, 71.12911197117397, 75.99689483642578, 87.67295346941266, 81.9661478315081, 79.34389768327985, 84.76650810241699, 82.16499137878418, 85.39069952283586, 89.65382930210659, 88.71468993595668, 89.84006186894008, 81.91316086905343, 85.03183201381138, 80.93260329110282, 89.32361616407121, 91.58112757546562, 90.13278252737862, 91.41812978472028, 84.73914609636579, 55.121692248753135, 29.748879023960658, 8.221796444484166, 3.6680595619337897, 0.6653051599860191, 0.19718036295047828, 0.151338645656194, 0.22513752563723496, 0.11232846642711333, 0.10429079165416104, 0.2092189041099378, 0.19907931105366775, 0.1255678449358259, 0.1553735134324857, 0.2407808926488672, 0.09374810129936252, 0.08089829010090657, 0.09667611561183419, 0.11135869739311081, 0.12248621029513222, 0.23566859268716403, 0.14185807295143604, 0.12357542184846741, 0.11789149684565407, 0.144344849511981, 0.12030568372990404, 0.10499738409583058, 0.17483340922210897, 0.10071084768112216, 0.1929369406508548, 0.10171798363860164, 0.13389256037771702, 0.123570712815438, 0.13169559969433717, 0.19329910193170818, 0.19459477812051773, 0.18613877972321852, 0.1623546074011496, 0.23330813220569066, 0.19813226615743978, 0.13589248806238174, 0.14434654584952764, 0.10516568113650594, 0.216235485460077, 0.07049512011664254, 0.2221174884055342, 0.16217921966952936, 0.11620559516761984, 0.12715461264763558, 0.11438265655721937, 0.09752567538193294, 0.1097077266978366, 0.19809246329324587, 0.12200761240507875, 0.07746440079063177, 0.1758646196020501, 0.0724191265180707, 0.15749561813260826, 0.13725042662450246, 0.10182164343340055, 0.13300241742815289, 0.14689520480377333, 0.12783484400383063, 0.11914048982518059, 0.1317499503493309, 0.18564606830477715, 0.1477069091051817, 0.15558243436472757, 0.07436065269368035, 0.07341577232416187, 0.11889696360698768, 0.13650881499052048, 0.2697766481765679], [0.11671512068382331, 0.027362516648801308, 0.03929437005094119, 0.0127089770144916, 0.03240443386935762, 0.007435604713724128, 0.02296395749518914, 0.023965900963438407, 0.037834793728377135, 0.0252553465044392, 0.03269840238083686, 0.02370612383154886, 0.030823966355196068, 0.019109956620793258, 0.02707892463409475, 0.05293564824387431, 0.029963315930217505, 0.030901645044130937, 0.027043913923470036, 0.10459364218903439, 0.012021127406374683, 0.06198310186820371, 0.012796948231490595, 0.02086083820488836, 0.020889606393341507, 0.052345770610762496, 0.0031493083307785647, 0.03795662469097546, 0.035896724688687494, 0.033099474252334664, 0.014410049887374043, 0.051173177281660695, 0.04831440068249192, 0.02638142286533756, 0.008480379856856806, 0.0037012388929724693, 0.02149838801207287, 0.022389506355726292, 0.012491627829149365, 0.03575446303667767, 0.03653631858261568, 0.05930739401706627, 0.004161702934652567, 0.014659450522490909, 0.04678861630548324, 0.010775989353922861, 0.08427814766764641, 0.04699818863134299, 0.058960710119988234, 0.0192365729516106, 0.025453660238002027, 0.05642328092030116, 0.026807273139378855, 0.08758630443896566, 0.026363555341959, 0.060239599352436404, 0.02847300875665886, 0.05435800013531532, 0.30679336615971153, 1.0524751245975494, 7.72823463167463, 15.925071409770421, 32.63341324669974, 42.427597454616, 48.007435185568674, 58.088673795972554, 58.23217494147164, 66.93068381718227, 61.10851723807198, 66.52624307359967, 68.79921422685895, 72.20908437456403, 69.92448193686349, 65.97192968641008, 66.87989248548234, 64.76687581198556, 57.08858135768345, 48.457296303340364, 51.6340092250279, 59.413351331438335, 47.746638025556294, 44.3121087210519, 25.48676368168422, 27.32325768470764, 35.584202017102925, 36.483694962092805, 35.60756880896432, 43.01392814091274, 21.987388576780045, 28.466446535927908, 34.781709398542134, 45.26305307660784, 40.652016571589876, 48.43057005746024, 46.91338225773403, 40.09863771711077, 47.412050996507915, 41.94839062009539, 42.25804056440081, 46.9087894984654, 58.955847195216585, 58.945327622549875, 58.38976355961391, 68.30849075317383, 66.10414000919887, 44.11168793269566, 22.798955542700632, 5.753297771726336, 2.012172256197248, 0.1743602803243058, 0.1578414131488119, 0.012907976068423262, 0.011924912837067885, 0.009733177721500397, 0.003209150454495102, 0.053752685830529244, 0.03703200537711382, 0.031679717757339985, 0.08670163726700203, 0.0688342224540455, 0.04215386589722974, 0.019797963988302008, 0.05499712584008064, 0.023284974108849252, 0.04070505453273654, 0.0439156651097749, 0.05700633927647557, 0.009905126976913639, 0.03264930019421237, 0.05686152294012053, 0.02230607538617083, 0.05469541524403861, 0.03988803390945707, 0.11061142677707331, 0.07090016481067453, 0.015486628814999546, 0.012161040479051215, 0.034737288153597286, 0.04098646675369569, 0.06037754552172763, 0.04324025135221226, 0.016883464397064278, 0.0471917644941381, 0.004734500569091844, 0.04163840998496328, 0.056014382147363255, 0.06876844526933772, 0.03997283721608775, 0.02683141711167991, 0.06188596958028419, 0.024571983709133098, 0.03480758438152926, 0.05814560635813645, 0.04240495778088059, 0.04388998934466924, 0.015421798186642783, 0.04504513753844159, 0.04730043527004974, 0.043865019255982976, 0.03522033044802291, 0.030412597714790275, 0.05896094760724476, 0.04984056503911104, 0.036432998055326085, 0.05520942587671535, 0.026042932278609703, 0.060319686840687475, 0.019644679534914236, 0.04983035308708038, 0.04350017097645572, 0.06354062472070966, 0.04580672185069748, 0.0490911502524146, 0.042415386864117215, 0.02105116388494415, 0.006209836715632784, 0.0515239425668759, 0.034843190506632836, 0.02269107785208949, 0.01938508221480463, 0.06605052575469017, 0.03457583413858499, 0.035271278249898126, 0.019806832440995743, 0.039258892847491164, 0.024889468548021147, 0.037455031249139986, 0.0032724244811106473, 0.029067442752420902, 0.008033852924459746, 0.033731583905007155, 0.05043385909604175, 0.046401861522878916, 0.050697215500154665, 0.006284277096191155, 0.03238098709178822, 0.01326596605524953, 0.05517573322036436, 0.01819526088157935, 0.04666301268818123, 0.04012338378067527, 0.03665312160072582, 0.012741815564887864, 0.07732925697096757, 0.02628023293800652, 0.02446004917978176, 0.07983322082353489, 0.042374549234019857, 0.02864866450961147, 0.024510218362723078, 0.034664047083684375, 0.0704561382798212, 0.012571171641216745, 0.02642566165221589, 0.026379758758204322, 0.024531049387795583, 0.02631222756047334, 0.061057362971561294, 0.016040308301204016, 0.058251566386648586, 0.07482181223375456, 0.05405860673636198, 0.035003535116889646, 0.019908393866249492, 0.05878047764833484, 0.03499899911028998, 0.04558282904326916, 0.09416194659258638, 0.08324856577175004, 0.0943194209997143, 0.02697484245124672, 0.03747195730518017, 0.028925611970147917, 0.06661439514053719, 0.2707411178520748, 1.9136300810745783, 10.359403661319188, 20.118415219443186, 40.191555976867676, 50.03015654427664, 53.72117165156773, 63.93221650804792, 67.1450148991176, 74.98050539834159, 71.32813617161342, 75.29482800619942, 78.13152040754045, 81.94087723323277, 81.77944278717041, 73.96882683890206, 80.21102591923305, 77.6505035672869, 68.58186067853654, 62.95718969617571, 63.72197791508266, 69.63590935298375, 63.45726544516427, 53.79641369410923, 38.27787617274693, 37.43951000486101, 43.26118326187134, 43.889870166778564, 45.56954506465367, 53.30783026559012, 32.67563744953701, 41.702313218797954, 45.51024218967983, 55.55109439577375, 52.82619503566197, 58.08503293991089, 60.38798904418945, 49.35431916373116, 57.01449966430664, 51.5951965876988, 53.56275272369385, 54.463871547154014, 68.28320625850132, 66.3308527810233, 67.80855396815709, 78.1965138571603, 77.39183603014264, 53.512611048562185, 31.04417610168457, 7.863599436623709, 2.426641855921064, 0.5403080987078803, 0.21138166662837776, 0.020722924266010523, 0.008921782153525522, 0.03456116421148181, 0.02400362242146262, 0.050069987906941345, 0.006308530906348356, 0.04465813848323055, 0.0644240773149899, 0.06202092341014317, 0.03144213889858552, 0.05136906016351921, 0.018053689638950994, 0.04101009673572012, 0.0695821512490511, 0.07228609972766467, 0.027169802525479878, 0.05067164830065199, 0.007860363394554173, 0.038848558972988806, 0.04466114778603826, 0.04622547973745635, 0.039973013635192595, 0.029963641627026454, 0.059109736766133986, 0.024110919163961495, 0.024414653490696634, 0.04654898487829736, 0.029713648970105817, 0.11579236734126296, 0.018860301535044397, 0.07562595765505518, 0.022237816459632347, 0.0315421549603343, 0.05253483760835869, 0.038001197656350474, 0.06304873432964087, 0.058468494032110484, 0.07893400586077146, 0.00974862287486238, 0.03659471330632057, 0.040623630330498726, 0.06467098942292587, 0.024291367070483308, 0.03190945275127888, 0.03999677253887057, 0.047308655721800666, 0.04075094046337264, 0.018984417464318018, 0.03939855571037956, 0.008298032900451549, 0.01343041834687548, 0.03746137894423945, 0.024516002873757055, 0.01994422051523413, 0.050129162945917675, 0.04856620163523725, 0.01881206956958132, 0.023430665755378347, 0.05266217488263335, 0.01989343047275075, 0.034616078050541024, 0.02978067465924791, 0.032312278635799885, 0.007504398834758571, 0.0313286912361426, 0.235146202147007, 0.12117116871689047, 0.15996718193803514, 0.09935300411390406, 0.2001130591545786, 0.0860696972480842, 0.10940907629472868, 0.08474068463380847, 0.16294782342655317, 0.09971434436738491, 0.09505531258348908, 0.08882204562957798, 0.10393781095210995, 0.11468930010284696, 0.12883147623922142, 0.19973417877086572, 0.11285984755626746, 0.09605076416794743, 0.11566088082534925, 0.14006289999399865, 0.09393804360713277, 0.10137003088103873, 0.11730539186724595, 0.1561763153544494, 0.10302201937884092, 0.14565934826220783, 0.06486620394779102, 0.16945686058274337, 0.18380216296230042, 0.14160523723278726, 0.09745062262352024, 0.09191358009619371, 0.09699415176042489, 0.1199312816773142, 0.07833394341702972, 0.11587285516517502, 0.07026408572814294, 0.13437847287527152, 0.10072500870696136, 0.14751449014459336, 0.10467221654419388, 0.17131625009434565, 0.1240390105439084, 0.21054989126111778, 0.10621843500328915, 0.12430419559989657, 0.17514848017266818, 0.16212755601320947, 0.1396772206893989, 0.130330658650824, 0.16009425797632762, 0.2262866654034172, 0.16104123501905374, 0.19049303393278802, 0.11673626383500439, 0.14629490487277508, 0.15605880665991986, 0.18333858783755982, 0.7171597832015583, 3.9450147577694485, 16.30694787842887, 31.266806806836808, 54.68402521950858, 64.07976845332554, 67.02966785430908, 78.28056621551514, 81.15599482400077, 87.21048137119838, 82.66391372680664, 85.82426711491176, 88.91176169259208, 90.99315016610282, 90.65478679112026, 85.51522513798305, 88.9478645324707, 88.29191289629254, 80.68767929077148, 70.79839161464146, 71.39674268450055, 81.19171551295689, 68.4976624080113, 63.100982666015625, 43.85691138676235, 45.798297132764546, 53.252123083387104, 52.77845743724278, 53.59384591238839, 62.3941285269601, 38.57929597582136, 46.1056159564427, 52.84064381463187, 62.430307797023225, 59.08535466875349, 65.78339726584298, 67.63818413870675, 58.77392945970808, 66.38973876408168, 60.737900325230186, 62.35429450443813, 65.05717849731445, 76.3210699898856, 78.68186637333461, 77.36002717699323, 87.85833835601807, 88.06463732038225, 65.30335317339215, 37.40721130371094, 10.417920521327428, 3.271076623882566, 1.0872008098023278, 0.49852608357157024, 0.25405976868101526, 0.1353827454149723, 0.12010481022298336, 0.12870125179844244, 0.18182434194854327, 0.12456825428775378, 0.08830176533332892, 0.20766911655664444, 0.1402865451361452, 0.1440838035196066, 0.18257400100784643, 0.12026822859687464, 0.17676055724067347, 0.16109828624342168, 0.16056332923471928, 0.17491776469562734, 0.08147694476480995, 0.11338620074093342, 0.168108394369483, 0.06815865941877876, 0.12402687833777495, 0.10593137397829976, 0.1945336014032364, 0.17823223184262002, 0.1301707008055278, 0.06794760788657836, 0.17218450350420816, 0.13692990025239332, 0.17683317405836924, 0.1710948305470603, 0.17406568756060942, 0.13091041254145758, 0.10192368152950491, 0.24687739408441953, 0.1491673607379198, 0.17950384717966827, 0.18831736567829335, 0.12682529246168478, 0.18423304626984255, 0.06297032282288585, 0.12912722251244954, 0.15992697195283004, 0.23360926604696683, 0.1345019391072648, 0.14402968356651918, 0.1259899072881256, 0.15443549305200577, 0.10441345042948212, 0.22928479952471598, 0.12835050347660268, 0.16500131466559, 0.22294554540089198, 0.12976129991667612, 0.10759276018611022, 0.12400523307068007, 0.11867496051958629, 0.10241559906197445, 0.14985348177807672, 0.10237612867993967, 0.1619078463741711, 0.08116549040590014, 0.1129440198253308, 0.10091275934662138, 0.19081683084368706, 0.09906480315008334], [0.011937185839217688, 0.11499567223446709, 0.01985306103181626, 0.007972853474452027, 0.09443004934915475, 0.022309145757130215, 0.040872815530747175, 0.04896375869533845, 0.06979744362511806, 0.09319032515798296, 0.0023221243131307085, 0.04400702306468572, 0.026687640630240952, 0.06319495184080941, 0.014841945908431495, 0.041616293136030436, 0.03020288289657661, 0.05979541675852878, 0.02047815632873348, 0.049415333928274255, 0.021566680865362287, 0.06701436439262969, 0.043151604144700935, 0.07558218536100217, 0.02828429120459727, 0.05987269511180265, 0.020627578221527592, 0.027180728635617664, 0.0463305339217186, 0.023936201485672166, 0.06391156624470438, 0.04594192673851337, 0.07268832171601908, 0.030344662788723196, 0.07401442341506481, 0.005170202747519527, 0.01924051184739385, 0.07100790260093552, 0.06893178221902677, 0.04446748371369072, 0.015929656203037927, 0.0818077102303505, 0.023494344570540955, 0.043614246283790896, 0.005020470849038767, 0.01414002348402781, 0.016129187906959226, 0.012533258497049766, 0.07729057368955441, 0.03144967742264271, 0.027586514629157524, 0.04344975243189505, 0.014339833387306758, 0.005364528391510248, 0.03671857308862465, 0.046626164843993526, 0.12558864881949766, 5.649513397897993, 14.290442551885333, 31.314725058419363, 46.70232030323574, 55.443289620535715, 63.04644625527518, 59.93127005440848, 63.842633383614675, 57.29924031666347, 52.65438345500401, 50.78573145185198, 53.41597202845982, 55.88495881216866, 62.329155921936035, 50.38392407553536, 36.21312863486153, 51.70668738228934, 36.74997425079346, 46.525499071393696, 27.42717320578439, 21.761162178856985, 46.92117118835449, 42.773381505693706, 20.972298451832362, 20.19287732669285, 24.357523339135305, 20.336050169808523, 12.799709149769374, 21.674658843449183, 18.528992210115703, 22.291419165475027, 23.35860688345773, 13.568281531333923, 22.01746906552996, 18.871755531855992, 15.28605774470738, 24.215328454971313, 20.668858460017614, 22.60805378641401, 19.83474632671901, 22.85444733074733, 22.157103538513184, 32.180512292044504, 34.8867244720459, 51.659950324467246, 49.80501059123448, 52.08114317485264, 52.98175825391497, 59.53030341012137, 54.96170997619629, 42.22208711079189, 23.824954339436122, 20.400965452194214, 8.272085768835884, 2.5155679413250516, 0.4609673246741295, 0.12466612617884364, 0.06221815996936389, 0.0480455210033272, 0.1300260778516531, 0.03462825096877558, 0.027982178576556698, 0.06838573116276946, 0.014114452043681272, 0.01256718100713832, 0.06283602038664476, 0.006588958827446082, 0.07776039133646659, 0.02617420844866761, 0.06751844127263341, 0.09297065623104572, 0.0272038056116019, 0.026107264183727757, 0.03732130217498966, 0.025298664180029715, 0.01471403187939099, 0.042153180576860905, 0.027643374167382717, 0.007253753087882484, 0.05082119741876211, 0.04285172559320927, 0.04239533954699125, 0.005609924821848316, 0.04931909052122917, 0.050939856230148246, 0.04190443981704967, 0.050195533848766766, 0.01940214567418609, 0.04918533430567809, 0.049309261941484044, 0.03054317499377898, 0.009934748423152735, 0.014393663266673684, 0.01786494833816375, 0.025046715645917823, 0.07350392080843449, 0.07246650861842291, 0.02057211985811591, 0.0356543926921274, 0.06877787690609694, 0.051876560252692015, 0.07808570816580739, 0.02597740275918373, 0.0065701727372860265, 0.035205297504684756, 0.031828103187893114, 0.007234630274719426, 0.04458788975274988, 0.010563960731295603, 0.0240085774234363, 0.030580080513443266, 0.04526975637833987, 0.06503699799733502, 0.07401409093290567, 0.07319771152521883, 0.08339122097407069, 0.036692921072244644, 0.027046796000961746, 0.05701167256172214, 0.028168338051597987, 0.036777140838759284, 0.008362129014650626, 0.025037304365209172, 0.04279580752232245, 0.016083237515496354, 0.03308457023065005, 0.0461928252396839, 0.024367703956418803, 0.04850771191662975, 0.04919554625770875, 0.037240902560630014, 0.03669034263917378, 0.06504449580929109, 0.014926828942926866, 0.026990458934700916, 0.062861207606537, 0.04145819108401026, 0.07559163056846176, 0.03274606607322182, 0.023148826057357446, 0.028807404384549175, 0.018748272010790448, 0.034963891708425114, 0.034181554402623854, 0.019503432292757288, 0.03984554065391421, 0.030367790654833828, 0.03598606060924275, 0.041064342217785973, 0.01905391302092799, 0.027694842744884745, 0.02298307521933956, 0.011589098222819822, 0.053655221060450585, 0.04162923279883606, 0.06424602294074637, 0.03747957046808941, 0.07505864809666361, 0.04726836770506842, 0.05152440057801349, 0.05200818586828453, 0.04621468085263457, 0.04230852099135518, 0.02828426067052143, 0.03712944979114192, 0.005360386783390173, 0.03435190740440573, 0.09149441508842365, 0.028417470665382485, 0.017671594695587243, 0.07306224879409585, 0.03606834315827914, 0.029452389239200523, 0.0489879823955042, 0.06612551065960101, 0.4166096720312323, 8.086936252457754, 18.382597139903478, 36.08138384137835, 54.59037739889962, 65.2316060747419, 72.42795957837785, 68.28601333073208, 72.7524196079799, 68.4899012701852, 61.60620975494385, 60.06203515189034, 60.43367344992501, 65.29841300419399, 71.74925259181431, 59.82993057795933, 44.566589968545095, 60.9813026700701, 45.0676315171378, 60.029100690569194, 45.10548530306135, 32.27908985955374, 53.89924703325544, 50.70075498308454, 28.646644592285156, 30.779873575483048, 32.49685335159302, 35.96656485966274, 21.71387447629656, 30.86689281463623, 26.232525995799474, 35.08099957874843, 28.864866665431432, 18.56472158432007, 30.38824531010219, 33.1353302683149, 21.572181599480764, 37.06196921212332, 31.206895964486257, 31.337907723018102, 29.4115891456604, 34.97071082251412, 34.17107738767351, 44.379221371241975, 47.82397147587368, 61.01385498046875, 58.3597195489066, 60.39710508074079, 62.17845644269671, 67.85992200034005, 65.78197288513184, 52.1586468560355, 31.38360255105155, 26.5722234249115, 10.588614310537066, 3.50361676301275, 0.7854360938072205, 0.14962895454040595, 0.018212334518986087, 0.03822374017909169, 0.052919682314885516, 0.06846775926117386, 0.06741182306515318, 0.07936474667595965, 0.0429224459055279, 0.004502147278149745, 0.031706848980060647, 0.01137574136789356, 0.08507062228662626, 0.06917117615895611, 0.06745845877698489, 0.015090126876852341, 0.06129685869174344, 0.041578203572758606, 0.015168292414663094, 0.010076893027871847, 0.027678169443139007, 0.07118432170578412, 0.021350857535643235, 0.025960702316037247, 0.032963136211037636, 0.03845213506636875, 0.05622703502220767, 0.025081249685691934, 0.023419084858947566, 0.007551421311550907, 0.03409970611599939, 0.028223207785880992, 0.023904714068131785, 0.037177781840520244, 0.11473328274275575, 0.07300397620669433, 0.03612206277570554, 0.02691369117902858, 0.009836745065903025, 0.014978891238570213, 0.09646691648023469, 0.03925652476027608, 0.03829645538436515, 0.07993406469800643, 0.055157294031232595, 0.0361746458469757, 0.047899737754570584, 0.018865773919969797, 0.04490991907992533, 0.07124486060014792, 0.016645502166024277, 0.029824677655207257, 0.018789340342794145, 0.03726256139842527, 0.037541459647140334, 0.011724038481978434, 0.018931841178398048, 0.05356648225071175, 0.03074074742783393, 0.06061749586037227, 0.029680987686983178, 0.04623648218278374, 0.09039879816451243, 0.05154243264613407, 0.16524448804557323, 0.16634999801005634, 0.13999041888330663, 0.15037868145321096, 0.23141602373548917, 0.12587501773876802, 0.14086329990199634, 0.10838953671710831, 0.1386127078107425, 0.1681363093001502, 0.15714336346302712, 0.19171683969242231, 0.11068694093929869, 0.13028077275625297, 0.10416153073310852, 0.11912805906363896, 0.19052918627858162, 0.18125659812773975, 0.11647016954209123, 0.18008746871990816, 0.10800583873476301, 0.14748346752354077, 0.1534484824431794, 0.1932163613715342, 0.15072506000953062, 0.10756022443196603, 0.16364072981689656, 0.14577030230845722, 0.11663456500640937, 0.10848907101899385, 0.08543605410626956, 0.1706820505538157, 0.08739552753312246, 0.100720374312784, 0.34993836815868107, 0.09711419139057398, 0.08508104458451271, 0.23867257578032358, 0.20567724986800126, 0.13439999600606306, 0.10065226975296225, 0.20752251228051527, 0.16713000115539345, 0.11054031630711895, 0.10483068839779922, 0.0686636862478086, 0.08840395949248757, 0.09756351049457278, 0.15558224437492235, 0.14625400278185094, 0.10354951250233821, 0.1805013750812837, 0.09012599316026483, 0.1484895721077919, 0.14556459763220378, 0.17360945418477058, 1.0532838297741753, 10.829390236309596, 26.469673224857875, 49.2002671786717, 68.0856203351702, 79.17889186314174, 83.42359501974923, 78.29556042807442, 84.16379356384277, 79.1925937107631, 73.03471102033342, 70.90629019056047, 71.40455940791539, 74.62826647077287, 82.48022420065743, 69.98405579158238, 53.451779569898335, 72.65425545828683, 54.669301986694336, 67.22965785435268, 45.81235681261335, 34.765374183654785, 62.62580231257847, 60.42798982347761, 33.3296331678118, 34.92804888316563, 39.884796483176096, 34.570908001491, 25.193832840238297, 35.56478875023978, 31.02932780129569, 35.258894307272776, 37.219877447400776, 23.608217443738663, 33.546427386147634, 33.69607073920113, 29.135382618222916, 37.79525429861886, 34.62869964327131, 37.905008043561665, 34.52334063393729, 38.01395232336861, 36.282343115125386, 49.71662255695888, 52.11034992762974, 70.8863697052002, 67.09148597717285, 71.46805204663957, 69.85723032270158, 79.83787291390556, 76.47249902997697, 61.390732220241, 39.00296238490513, 29.96195595605033, 13.53534620148795, 4.761025096688952, 1.09777455670493, 0.2959719811167036, 0.2078306350324835, 0.1289704673524414, 0.2624496913381985, 0.11010745167732239, 0.24790078774094582, 0.184287641197443, 0.12215398597930159, 0.1449064186641148, 0.11526441281395298, 0.08042180924011127, 0.20406614989042282, 0.09393380276326622, 0.14029289622391972, 0.2083494429077421, 0.17495942674577236, 0.08071502457771983, 0.07613880799285003, 0.14893162410174096, 0.26712990020002636, 0.09948547450559479, 0.12353336624801159, 0.15170641163630144, 0.10595099721103907, 0.13606989782835754, 0.1519499649958951, 0.08677863063556807, 0.1369707209191152, 0.13689271653337137, 0.12544752710631915, 0.1462295348090785, 0.1322254812611001, 0.12717008324606077, 0.19646343642047473, 0.16298286297491618, 0.09586574123906237, 0.10542473223592554, 0.11020754237792321, 0.09275161834167582, 0.20926665940455028, 0.155396665047322, 0.14649116434156895, 0.17251568287611008, 0.15957280381449632, 0.10424089897423983, 0.21771199123135634, 0.10307447013578244, 0.11255369934120349, 0.15317165372627123, 0.1256816488291536, 0.09558187611401081, 0.08057314969067063, 0.09578502949859415, 0.06798211139227663, 0.1602945208017315, 0.17222034372389317, 0.13318201207688876, 0.12551919397498879, 0.13888606242835522, 0.20771791679518564, 0.12022653940532889, 0.1554544490895101, 0.12692548494253839], [0.03601333771699241, 0.012663141125813127, 0.0031305932747532745, 0.11834859874631677, 0.050607031410826106, 0.08859362360090017, 0.008753162808716297, 0.02794759873566883, 0.05079437492947493, 0.01597572533812906, 0.015404860256239772, 0.04410057608038187, 0.029080409556627274, 0.012395939124482018, 0.020882313838228583, 0.02057211646544082, 0.04060999516929899, 0.03813771550942745, 0.030346399838370935, 0.02974778606689402, 0.07781100326350757, 0.052925144521785636, 0.029402164077120166, 0.03821974700050695, 0.008402534078673592, 0.021127244623910104, 0.05044880722250257, 0.022791779234207103, 0.03704447006540639, 0.01895681635609695, 0.047844369297048876, 0.009663794123168503, 0.06186429038643837, 0.024610962153279355, 0.03263679140114358, 0.05692577002836125, 0.033537590743175576, 0.03665912324296577, 0.0249280466565064, 0.026414051918046813, 0.02441393254723932, 0.015972196956032088, 0.014384947484359145, 0.006098163846348013, 0.028005732223391533, 0.0693765212116497, 0.027298328932374716, 0.019409623130091598, 0.11053800250270537, 0.0265985303225794, 0.043993225055081506, 0.0346829612473292, 0.03939999081194401, 0.03488549037969538, 0.48245001477854593, 2.6304068991116116, 20.916521787643433, 51.66462646211897, 58.15676266806466, 66.46633570534843, 68.70859582083565, 69.75700950622559, 59.34432097843715, 58.61667088099888, 43.5124648639134, 47.839980125427246, 36.638323647635325, 37.30550357273647, 39.286170959472656, 29.757310662950786, 22.941808768681117, 34.76407487051827, 26.283320801598684, 37.36749887466431, 32.8537197794233, 22.382008041654313, 19.048713990620204, 37.815397126334055, 44.65394966942923, 29.936994552612305, 44.99680505480085, 25.447660957063945, 17.885873896735056, 17.871795109340123, 19.054802349635533, 17.121671063559397, 19.80782379422869, 26.11596301623753, 20.8070216519492, 26.0619181905474, 20.964686700275966, 25.086603028433665, 21.508134841918945, 16.07134141240801, 20.33390838759286, 18.16027389253889, 16.45571402141026, 16.004977430616105, 17.65291816847665, 16.548175437109812, 15.566933461597987, 25.081760134015763, 39.550098282950266, 50.91820580618722, 60.965426036289756, 59.58117812020438, 55.68133837836129, 60.920860290527344, 53.06982319695609, 54.58891480309622, 45.87631150654384, 32.02005754198347, 18.23168226650783, 9.661933064460754, 3.0610875146729604, 0.5613201569233621, 0.2141756024211645, 0.004397914969428841, 0.010663854656741023, 0.014678325670372163, 0.053449119441211224, 0.04573249351233244, 0.08109456314040081, 0.02450815731260393, 0.0552885227038392, 0.04173007667330759, 0.026595889125019312, 0.03689173522538372, 0.0033122169552370906, 0.019376815961939946, 0.057526904557432444, 0.04850593754755599, 0.017761978952746307, 0.02521270397119224, 0.061525823548436165, 0.07026715949177742, 0.013738831172564199, 0.02909913712314197, 0.09201475645282439, 0.020419215384338583, 0.005178350680840335, 0.0017201057801555309, 0.013903158783380474, 0.037548903176294904, 0.037511695708547316, 0.06144527465637241, 0.045879430270620754, 0.05513363690780742, 0.07672733534127474, 0.03877907698707921, 0.04858976376375981, 0.025061375394995724, 0.03063281625509262, 0.05553034579913531, 0.07634197494813375, 0.0037964386283420026, 0.05486056048955236, 0.03463688871956297, 0.01573170378937253, 0.06359745881387166, 0.036586330006165166, 0.06025699020496436, 0.02693362144886383, 0.018420795743752803, 0.13524832762777805, 0.023450752088267888, 0.027390363725966642, 0.021653256844729185, 0.07338555715978146, 0.03838387105081763, 0.03354754824457424, 0.028700297631855522, 0.03646114368789962, 0.0077338658073650935, 0.02550657748776887, 0.02492173628083297, 0.047757788228669336, 0.049832174953605445, 0.06788981705904007, 0.032886471931955645, 0.05314957337187869, 0.04439766924562199, 0.02089322468132845, 0.020803600383390273, 0.02730000830654587, 0.019995818014389703, 0.02329333026760391, 0.042999198394162316, 0.04357543068804911, 0.021754882730809704, 0.02554012934810349, 0.0063471632976351035, 0.025365062224279557, 0.012594391957723668, 0.013362949065464948, 0.039497279162917814, 0.04502849307443414, 0.012363549255366837, 0.053651784280581136, 0.021970019043822373, 0.03975329381812896, 0.03350852908832686, 0.0599857729726604, 0.03822158243773239, 0.029454251817826713, 0.047823992890438864, 0.03496057367218392, 0.04510363404239927, 0.012678096037624138, 0.058493043429085186, 0.022325420419552496, 0.011272285981769008, 0.07519111848835434, 0.011694908973627856, 0.07065201776900462, 0.07588381453284196, 0.008597646823285945, 0.03526290173509291, 0.024391618923151066, 0.019320602728320018, 0.011538017258447195, 0.012239875222024108, 0.06317238376608916, 0.01564601669088006, 0.049384338448622396, 0.10046440376234905, 0.03117102005385927, 0.011640548140608838, 0.10113142404173102, 0.044412607194057534, 0.8632913646953446, 5.090186885425022, 28.47350764274597, 63.024920736040386, 67.60426998138428, 77.1847310747419, 78.92269788469586, 78.0849883215768, 68.75787939344133, 66.83429145812988, 53.158628123147146, 54.23398692267281, 43.95821612221854, 43.26175996235439, 49.17477076394217, 39.081112248556956, 32.53213977813721, 44.0775271143232, 33.77267810276577, 46.28034578050886, 42.8720737184797, 31.61892761502947, 18.310255970273698, 31.72526284626552, 48.57821580341884, 34.37661552429199, 38.21891375950405, 22.811026300702775, 26.420405285699026, 25.27474982397897, 18.774003062929424, 27.26216217449733, 30.692235946655273, 32.49813529423305, 29.427319867270334, 27.162267923355103, 29.640045915331157, 29.875808715820312, 25.760658196040563, 22.076308148247854, 27.32576424734933, 29.070132085255214, 25.341966697147914, 26.21701066834586, 23.30763837269374, 25.785447631563457, 26.001392432621547, 37.95443752833775, 51.34108359473092, 60.28821291242327, 66.60911423819405, 67.91666793823242, 63.231581006731304, 70.08704199109758, 63.35090936933245, 63.659819330487935, 56.83124440056937, 39.710709367479595, 23.630819933755056, 11.232135619435992, 3.8839913351195197, 0.6924619227647781, 0.30074550211429596, 0.02682485567804958, 0.03890719118395022, 0.022785316188154475, 0.022054550936445594, 0.051573034575475116, 0.04548424129773464, 0.03727056811164532, 0.026112711123589958, 0.018427993303963115, 0.030587042282734598, 0.03438246862164565, 0.04344905014815075, 0.029875153875244514, 0.06490524006741387, 0.051101113470005136, 0.02351225450235818, 0.05032015359029174, 0.0390773881226778, 0.005191002390347421, 0.041352200521422286, 0.0501479753293097, 0.023341292515397072, 0.08929375638919217, 0.02497081471873181, 0.056519151133086, 0.0427585830911994, 0.016242532092811804, 0.06663312270705189, 0.024910224934241602, 0.03598884938816939, 0.039537132917238135, 0.010772715422457882, 0.05675874863352094, 0.02623402639957411, 0.05877449975482055, 0.052977127089564285, 0.016645220573991537, 0.09574768971651793, 0.044081536387758594, 0.057240698486566544, 0.012190585590100713, 0.03283271838777831, 0.045643998975200314, 0.007103438073370073, 0.04237268665539367, 0.007225226627529732, 0.027081421642963375, 0.009870702350911285, 0.035157437037144385, 0.03485561448282429, 0.009952416626869567, 0.06060779959495578, 0.034759170907948694, 0.06885814081345286, 0.03801803889551333, 0.019912929872849157, 0.024554404563137462, 0.027578446847785796, 0.034877985782389126, 0.1961044099714075, 0.14203990676573344, 0.1299153816487108, 0.201183393863695, 0.11338598360972744, 0.16097476572862693, 0.08380326136414494, 0.13081458982612404, 0.0882016271352768, 0.085908646961408, 0.050757734038467915, 0.12361749101962362, 0.08518623108310358, 0.09147879521229438, 0.09788384009152651, 0.1941784561744758, 0.08861212046550852, 0.12372802437416144, 0.09012602708701577, 0.12019360331552369, 0.15099323061960085, 0.15813873362328323, 0.16240072064101696, 0.14397156025682176, 0.12270441358642918, 0.11815096863678523, 0.1751021362308945, 0.09101573577416794, 0.13204397314361163, 0.1276456005871296, 0.17028236628643104, 0.13124092694904121, 0.184505627357534, 0.17640402780047484, 0.0813189750271184, 0.13377351819404534, 0.14210381119378976, 0.17475898750126362, 0.13264805930001394, 0.12913449640784944, 0.06218600419483014, 0.1488314587622881, 0.09536403244627373, 0.07310914234923464, 0.14107428358069488, 0.1911038240151746, 0.1038663951413972, 0.0983433507915054, 0.16292844446642057, 0.2071947120130062, 0.08696085800017629, 0.13156804868153163, 0.21009475711200917, 0.17101563193968364, 1.2030852543456214, 7.525226507868085, 37.720901625497, 71.41990797860282, 78.93535055433, 85.78697613307408, 87.60717487335205, 84.6660440989903, 79.05368532453264, 76.24463285718645, 62.98687934875488, 64.92965820857457, 54.822582721710205, 54.56808410372053, 57.091214724949424, 45.88358974456787, 39.044495241982595, 52.837357316698345, 43.17950371333531, 55.0644599369594, 48.72501734324864, 37.29403904506138, 30.781117303030832, 51.9094740322658, 57.44429438454764, 45.25226947239467, 63.2134462084089, 40.0610305922372, 29.928562913622173, 28.709928785051616, 29.287271976470947, 29.2411150932312, 32.261952127729145, 38.050406047276084, 34.214573110852925, 39.0054463659014, 34.12261022840227, 36.09296996252877, 34.651545320238384, 26.578230142593384, 33.70558629717146, 32.7688753264291, 29.092632089342388, 28.109474148069108, 28.499049220766338, 27.354383877345494, 25.992017575672694, 42.22000959941319, 55.736166613442556, 67.73201261247907, 78.02103015354702, 78.30768503461564, 72.05977453504289, 81.85244056156704, 74.35924611772809, 73.73543684823173, 64.61002717699323, 48.57917812892369, 31.853036744253977, 15.17823212487357, 5.369822783129556, 1.0790262541600635, 0.5643314953361238, 0.19982799302254403, 0.07958681083151273, 0.09579014565263476, 0.1164881100079843, 0.11823707473065172, 0.12491327577403613, 0.11789031619472162, 0.1518985049000808, 0.08689098246395588, 0.08346486916499478, 0.1683574574334281, 0.12615890321987017, 0.15584069836352551, 0.10295769425907306, 0.13908042199909687, 0.13575759530067444, 0.09068533671753747, 0.19087377350245202, 0.1253558841667005, 0.10024098932210888, 0.15855209715664387, 0.19100798772914068, 0.22762085523988518, 0.09937076816069228, 0.17679485040051596, 0.1617940560515438, 0.08193308993109635, 0.09701473851289068, 0.17139390164187976, 0.11696227027901582, 0.1478690111211368, 0.19661052924181732, 0.15177393944135734, 0.08473056089133024, 0.12754996786160128, 0.08697189097957951, 0.13111476014767373, 0.17730566513325485, 0.1169149356761149, 0.14854768184678896, 0.13301141480250017, 0.09248666398759399, 0.1740769919540201, 0.157743866954531, 0.2973523927586419, 0.11237894264715058, 0.12605394742318562, 0.2179455565554755, 0.09668528261993613, 0.14618834773344652, 0.09520193043031863, 0.18730812626225607, 0.1136980215087533, 0.12420082757515566, 0.09748822703425374, 0.17864126632256166, 0.19090434829039232, 0.10692969576588698, 0.16945094375738076], [0.038509766438177655, 0.03321770219398396, 0.039395753360752545, 0.03171797695436648, 0.060035394238574166, 0.004096963060354548, 0.010797844966873527, 0.008525656802313668, 0.034820836170443466, 0.016013490900929486, 0.05465836383934532, 0.06774636118539742, 0.02916002885571548, 0.01404229408529188, 0.03911863287378635, 0.035048172543091435, 0.02423597825691104, 0.03430777209411774, 0.08031236154160329, 0.027099189082426683, 0.03661415333460484, 0.019428364267306666, 0.062396940376077376, 0.016877055633813143, 0.01878965416524027, 0.01269954877040748, 0.027732345375365446, 0.01414169098383614, 0.049026811561946354, 0.005550067431093859, 0.03936691562245999, 0.05610012183231967, 0.05566692811303905, 0.04159237477662308, 0.05942504520394972, 0.0035993797604792883, 0.03188289149797388, 0.022857534366526773, 0.02497313530849559, 0.026852070021310022, 0.03928615977721555, 0.038740509056619236, 0.0523461675537484, 0.04890330461785197, 0.049929117251719744, 0.016173582756891847, 0.10968781169503927, 0.027127331322325126, 0.04852306377142668, 0.03096335780407701, 0.057529998677117486, 0.3132344548191343, 1.6623252459934779, 9.145069599151611, 23.98836554799761, 50.280573095594136, 66.64245169503349, 71.35015501294816, 76.55960164751325, 68.18004635402134, 55.79659857068743, 50.87483862468174, 42.72430985314505, 30.89326470238822, 24.126917839050293, 24.68614533969334, 22.64939383098057, 20.900674683707102, 16.67431477137974, 21.804788180759974, 18.758117743900844, 12.432473404066902, 12.202350803783961, 21.42533663340977, 20.69363226209368, 22.676920856748307, 68.1988342830113, 85.82202979496547, 52.22892441068377, 48.987485545022146, 59.47316837310791, 46.383620330265586, 43.20384325299944, 60.09059224809919, 43.49278061730521, 40.73114265714373, 41.997139181409565, 38.60436160223824, 40.98317119053432, 36.95711047308785, 41.8708313533238, 45.56435128620693, 41.82320492608206, 65.77424648829869, 39.50375032424927, 20.46333769389561, 20.4906701701028, 28.03432243210929, 33.33861371449062, 23.32268295969282, 21.304305962153844, 15.87725043296814, 13.982213514191763, 16.458121572222026, 31.651618889399938, 48.572907379695344, 53.6191269329616, 55.81239530018398, 59.52440438951765, 60.22951453072684, 60.254604475838796, 62.89013263157436, 56.9385905947004, 38.07386663981846, 28.708509615489415, 14.801549434661865, 6.165538302489689, 1.2039503050701958, 0.34627398050257135, 0.17971236099089893, 0.037076856541846476, 0.03841041873342224, 0.006128337874542922, 0.07399222853460483, 0.03474103705957532, 0.05360757772411619, 0.04845356142946652, 0.08313375764659472, 0.04549797484651208, 0.03859863756224513, 0.012536534973021065, 0.03747442038729787, 0.053819307791335244, 0.019000910954283814, 0.044750968859131844, 0.029435758345893452, 0.02343871657337461, 0.04459272770743285, 0.08000926673412323, 0.062282166177673, 0.02946014150178858, 0.03020068783579128, 0.055426451909754954, 0.028416486789605448, 0.033758318184741905, 0.03974096144416502, 0.05081179631607873, 0.027236753575769917, 0.04466815026743071, 0.004666982093892459, 0.022114160237833858, 0.05411104052992804, 0.03997632149340851, 0.012638903854947005, 0.03663313874442663, 0.044529233793062825, 0.027620602532156875, 0.07068446531359639, 0.08176585140505008, 0.03748475108295679, 0.08918220523212637, 0.016283293387719562, 0.02005638405015426, 0.038902868915881426, 0.01251464628148824, 0.010931446815707853, 0.029113908830497946, 0.05536527179979852, 0.013617134220632059, 0.1268844607153109, 0.023764384544587562, 0.027005764988384078, 0.06778958386608533, 0.013579629045645041, 0.031961492994534116, 0.020795508853292892, 0.028255889425054193, 0.003947593329939991, 0.04410337843000889, 0.031062637655330554, 0.06272673553654126, 0.04603065876290202, 0.02881676816780652, 0.03508173967046397, 0.023232747268463885, 0.011926828850326794, 0.04885057226887771, 0.09466503281146288, 0.03324999028284635, 0.020754474448040128, 0.018635363783687353, 0.02425362864908363, 0.06737731277410473, 0.02373495139181614, 0.028138848919687525, 0.025939606662307466, 0.025491615790607672, 0.04488047066011599, 0.020661566040611694, 0.06342158253703799, 0.011407179591645087, 0.044372539701206345, 0.011008564016914793, 0.02495645352506212, 0.04642413104219096, 0.03615851028423224, 0.04641322359176619, 0.025819617922284772, 0.039232267133359394, 0.03004044500578727, 0.027652768484715904, 0.017417968483641744, 0.08711500758571283, 0.026399422703044753, 0.04471373085730842, 0.023913473955222538, 0.043977825702833276, 0.023864612648529664, 0.04590071252148066, 0.02035223040729761, 0.0371309154267822, 0.032532280044896264, 0.04932505823671818, 0.09097822635833706, 0.08262077160179615, 0.026929192311529602, 0.014452838305650013, 0.5041783888425145, 2.9210320242813657, 13.286315815789358, 31.176094600132533, 62.67674650464739, 76.5102972303118, 78.01775060381208, 82.6989118031093, 77.12949289594377, 64.08390957968575, 58.66268880026681, 53.977351733616416, 39.13613503319876, 35.465186323438374, 33.93579748698643, 31.818226269313268, 29.312354973384313, 23.753844738006592, 32.02977112361363, 26.132657800401958, 26.802128893988474, 21.516578640256608, 39.21233592714582, 31.504105159214564, 25.99995415551322, 61.1952029636928, 81.27477427891323, 48.76872846058437, 47.102658135550364, 60.300059591020855, 42.39636182785034, 27.03257805960519, 33.99991546358381, 42.884528364454, 32.80897685459682, 34.998979568481445, 32.71672909600394, 33.90527057647705, 31.46771396909441, 35.16193567003523, 41.2395909854344, 41.33835962840489, 53.57903235299246, 35.07342256818499, 22.88942629950387, 25.523451907294138, 32.54709924970354, 43.294187205178396, 28.753916093281337, 28.77105556215559, 27.550679172788346, 25.77483078411647, 30.52090379170009, 46.45366512026106, 58.24149594988142, 59.14779118129185, 62.889312744140625, 65.56591864994594, 68.82652064732143, 69.68123245239258, 74.6985058103289, 66.7216820035662, 48.2346100125994, 36.512550830841064, 20.37761081968035, 8.769580262047903, 1.7798392602375575, 0.4192174178149019, 0.22267632984689303, 0.11235599459281989, 0.032502943583364995, 0.036622468781258376, 0.05374270458040493, 0.04945931317550795, 0.038889230362006595, 0.03384864815909948, 0.0223337528295815, 0.04573836623291884, 0.03665997480441417, 0.07175786021564688, 0.040206036131296835, 0.025954201950558593, 0.011382745545623558, 0.007821272143961062, 0.03212135923760278, 0.010356215360973562, 0.043702469406915564, 0.046561622593019686, 0.021369303510125195, 0.027753490222884074, 0.014061181107535958, 0.08486228489450046, 0.030844722741416523, 0.049239908877227984, 0.04534474128325071, 0.03949585084670356, 0.026558186326708113, 0.019534458306484988, 0.03951373363712004, 0.018872460882578577, 0.03969949616917542, 0.010896042554772325, 0.04807162085281951, 0.02901632192411593, 0.06072142706917865, 0.03561591975657003, 0.08644105946379048, 0.040930769206689935, 0.028774783813527653, 0.04598841656531606, 0.04736663993181927, 0.07297740477536406, 0.043933524151465723, 0.05330975513373103, 0.03348359292639153, 0.02127433574891516, 0.021163844802816, 0.00200659450326514, 0.03643653661544834, 0.04102250035586102, 0.080185692624322, 0.002061203001565965, 0.040196143090724945, 0.0496997622373913, 0.010708758407937629, 0.1347642064626728, 0.08634077877338443, 0.2104111308498042, 0.09310052783361503, 0.28631265514663284, 0.15172177366912365, 0.09580100899828331, 0.08795915943171297, 0.16468876786530018, 0.05358612583950162, 0.17001773762915814, 0.14025724599403994, 0.2152992428413459, 0.1863342656620911, 0.10665932670235634, 0.1078600554860064, 0.12507582562310354, 0.11239089843417917, 0.18926109932363033, 0.1900088313434805, 0.08176038919814996, 0.15232686405735357, 0.10913823904203517, 0.06494711246341467, 0.06820474551724535, 0.09544647445103951, 0.06616894368614469, 0.1198721541357892, 0.09771226572671107, 0.08677872563047068, 0.13361776726586477, 0.18049004354647227, 0.08573175966739655, 0.18137367255985737, 0.16683630405792169, 0.11761477669434887, 0.20688839416418756, 0.1516472976654768, 0.08796996849456004, 0.16925734414586, 0.17852415117834294, 0.10296387571309294, 0.1630941562886749, 0.14093120768666267, 0.1502040129687105, 0.0927311469401632, 0.1473402694932052, 0.18729707971215248, 0.12937874187316212, 0.08497278432228736, 0.10285296237894467, 0.5903473421931267, 3.9482469729014804, 17.26809913771493, 40.387609822409495, 73.66626753125871, 88.85922636304582, 88.83977140699113, 93.39938776833671, 84.21527276720319, 74.58058098384312, 68.52598326546806, 62.351675033569336, 50.04448025567191, 41.630934374673025, 41.60568462099348, 38.24335752214704, 34.427090712956016, 28.425499064581736, 33.31000798089163, 31.322489670344762, 23.618439980915614, 22.239703723362513, 36.600893701825825, 31.252521310533794, 36.50052349908011, 83.35103498186383, 95.78082030160087, 67.13088921138218, 66.52672249930245, 79.30102034977504, 66.06292329515729, 61.617938314165386, 79.73663071223667, 60.57099764687674, 54.931676387786865, 57.82029267719814, 55.98641293389456, 57.045801298958914, 52.63239588056292, 56.35482726778303, 60.108303206307546, 58.446808270045686, 81.35573468889508, 55.60049261365618, 30.719563211713517, 33.49545887538365, 43.512082712990896, 48.37422711508614, 36.501600469861714, 32.69014181409563, 26.77527584348406, 24.280066558292933, 29.92364706311907, 49.05567864009312, 64.8377126966204, 70.60288320268903, 69.60947840554374, 75.52504267011369, 78.03040327344621, 81.54020241328648, 83.01605537959507, 74.76946081433977, 59.020917075020925, 45.46133729389736, 26.775805643626622, 12.448282292910985, 3.661084004810878, 1.149696056331907, 0.7128115136708532, 0.358016056141683, 0.11325128083782536, 0.13038414078099386, 0.19168760840381893, 0.10539916503642287, 0.11419654797230448, 0.16664643638900348, 0.1722033532070262, 0.2354282827249595, 0.28482804766723085, 0.1365810382579054, 0.1693439930677414, 0.12898532726934978, 0.08062639433358397, 0.10541502239980868, 0.08468611006225858, 0.10842506481068474, 0.16242797060736588, 0.21291850773351534, 0.10067807443972145, 0.2745384983718395, 0.19928217945354326, 0.2068679431187255, 0.1325522501553808, 0.09885530546307564, 0.10759552182363612, 0.1856642123311758, 0.14556976806904587, 0.11282866887216057, 0.1110581878040518, 0.21125649048813752, 0.09785754685955388, 0.12427074382347719, 0.08285994841051952, 0.1037752271762916, 0.16316932439804077, 0.17500171304813453, 0.16359730357570307, 0.22475783101149968, 0.13289078484688485, 0.1726757085749081, 0.14280002883502416, 0.2504839705569403, 0.12356300465762615, 0.13160003482231072, 0.0815714511222073, 0.10392027082187788, 0.2578695256795202, 0.10134503365095172, 0.16584351233073644, 0.16877851555390017, 0.18371731894356863, 0.22332690922277315, 0.09559358084308249, 0.125457637278097, 0.08276384071047817], [0.041829577048442194, 0.1087083803223712, 0.025015572584899406, 0.02749788947403431, 0.018698089257148758, 0.003772686510014215, 0.026888810996232287, 0.043863750395498106, 0.056018626383904896, 0.007051872804627887, 0.027894657737176334, 0.008219179497765643, 0.035181704842086346, 0.08017668167927436, 0.021856883507488028, 0.017536518729424903, 0.037031303093369515, 0.04166281010423388, 0.04228206151830299, 0.026036649044337015, 0.04431419247495277, 0.04719372885301709, 0.042853181050824266, 0.015118240279012492, 0.02092597756667861, 0.043591888554926427, 0.0989894654069628, 0.06804991061133997, 0.06442425373409476, 0.02087479567022196, 0.04896000300401023, 0.05611359414511493, 0.019912744972056577, 0.006695110542100987, 0.008289212793377894, 0.050783738893057616, 0.038978895372045894, 0.03514796468828406, 0.04587842943146825, 0.07964854394750935, 0.01725325919687748, 0.0643412960427148, 0.06909052548663956, 0.026654073502868414, 0.023480985912361314, 0.00585074198897928, 0.04846525598051293, 0.07322316337376833, 0.13161919665123734, 0.2162444285516228, 1.3716616886002677, 17.91814133099147, 30.281031131744385, 50.523780890873496, 63.934842927115305, 76.31282942635673, 58.390889167785645, 53.228488785879954, 38.62607472283499, 40.87963260923113, 37.602816990443635, 30.374189104352677, 25.900970118386404, 19.93740769795009, 12.130281482424055, 15.58772247178214, 11.295518824032374, 13.873268365859985, 20.819147995540074, 14.850808688572474, 15.104676757540021, 23.114600045340403, 31.126387187412806, 22.754335948399135, 36.74482216153826, 44.144639764513286, 41.78197431564331, 48.54994010925293, 60.103369985307964, 36.95995923451015, 25.98743871280125, 30.41850471496582, 47.339966910226, 44.37529911313738, 38.82222236905779, 57.09176710673741, 54.237978662763325, 41.29828936713082, 48.03515154974801, 52.02452230453491, 54.01823493412563, 44.8538111277989, 57.35218906402588, 71.42405605316162, 47.601622172764365, 54.65705231257847, 53.56940909794399, 46.22703225272042, 28.420908042362758, 33.833137852805, 31.82539333615984, 19.07468635695321, 22.46071376119341, 12.890550766672407, 9.291608844484601, 20.478974614824565, 23.96107997213091, 29.515843391418457, 48.11415604182652, 46.58654941831316, 55.8792439188276, 50.18017510005406, 55.904813289642334, 59.2165436063494, 58.745455741882324, 48.66566930498396, 45.98199708121163, 30.99151917866298, 15.062442132404872, 7.632412893431527, 3.218594274350575, 0.30111484229564667, 0.0244899997155049, 0.031373756139406135, 0.06492035782762937, 0.06839201439704214, 0.019421456780816828, 0.00805288752807038, 0.06729941016861371, 0.048689986778689284, 0.03924976655149034, 0.027255454000883868, 0.027584546877603446, 0.0670526134116309, 0.016400852972375493, 0.009446070895397236, 0.06313251983374357, 0.024124208272301724, 0.09691288362124137, 0.044436515375439606, 0.014281338579686624, 0.034951284527778625, 0.05204348325995462, 0.011801684940499919, 0.026927546864109378, 0.08503570487456662, 0.04988495819270611, 0.09074924114559378, 0.052629503421485424, 0.030319370395903076, 0.026629401969590356, 0.042085550991552215, 0.041869535975690396, 0.026916339161938856, 0.03969881424148168, 0.006870055105537176, 0.019814247132412026, 0.043939471510904174, 0.08849378395825624, 0.0987275576751147, 0.014667430094310215, 0.06263011214988572, 0.045362579968890974, 0.012854466796852648, 0.14432751972760471, 0.053159490161176236, 0.0498556420872254, 0.02699228928291372, 0.08145054296723434, 0.025828757788985968, 0.025526555255055428, 0.017218619984175478, 0.011553717710609947, 0.017956209601834416, 0.0527096384071878, 0.045417147755090675, 0.005840945215563157, 0.04059124385405864, 0.012216907659811633, 0.01938756226029779, 0.04083581501618028, 0.06724915786513261, 0.010240734637981015, 0.0978861471105899, 0.03241138546062367, 0.054969580710998604, 0.03569683845021895, 0.012656993598544171, 0.036298061188842566, 0.07888365856238774, 0.08654017307396446, 0.036771122233143876, 0.042039905940847735, 0.02040581262138273, 0.02912380187106984, 0.02191259292885661, 0.01409640725302909, 0.007366755461719419, 0.050402307217674594, 0.04623188850070749, 0.06970204160149608, 0.04106117006657379, 0.16889826341399125, 0.03932044275903276, 0.08460286738617079, 0.02512569203307586, 0.07539864163845778, 0.08680259649242673, 0.021026012288140397, 0.023404028166883757, 0.03291374903970531, 0.04142949923074671, 0.03708129755354353, 0.009163511950256569, 0.023550930998421142, 0.019650492883686508, 0.04180019308945962, 0.05419307202100754, 0.020947846750329648, 0.03266087600163051, 0.025194212195596526, 0.050086320244840214, 0.03287858396236386, 0.03211771211187754, 0.0360800139605999, 0.6640253343752452, 4.080864199570247, 24.973326546805247, 40.62820856911795, 61.79890414646694, 76.13465676988874, 81.20666108812604, 67.02763203212193, 61.22219671521868, 49.19759907041277, 49.51932845796858, 47.87024300439017, 39.033242634364534, 35.31243712561471, 29.994452680860245, 18.74148723057338, 24.60060954093933, 18.61709884234837, 25.44853469303676, 29.569361891065324, 21.725029809134348, 18.63088754245213, 22.83290270396641, 30.522991725376674, 22.916962010519846, 27.99105599948338, 39.65937955038888, 44.92394971847534, 50.88545894622803, 57.00001614434378, 41.151939460209434, 30.893031937735422, 30.9878922189985, 38.233546665736604, 36.35942990439278, 29.296895231519425, 34.61776665278843, 30.229388645717076, 29.571943146841868, 35.422104018075125, 34.999003887176514, 35.241013118198936, 27.282164301191056, 46.45986638750349, 56.99380098070417, 38.79722622462681, 41.706499508449006, 41.6208039011274, 37.28048310961042, 29.71021577290126, 33.6810348374503, 31.302117552076066, 25.832285438265117, 29.458656242915563, 21.506833791732788, 16.560244458062307, 29.154821940830775, 34.761128834315706, 36.90436322348458, 54.38325159890311, 53.23520769391741, 63.14381831032889, 57.875947747911724, 63.24812466757638, 67.03594902583531, 67.72366087777274, 58.81848130907331, 54.82181147166661, 36.959507601601736, 17.908165454864502, 8.657131484576635, 4.223187625408173, 0.28876175944294247, 0.033770949114114046, 0.04438500778217401, 0.027762428225417222, 0.019619622933013097, 0.015497398862083043, 0.006215642006801707, 0.041118835365133624, 0.02311942004598677, 0.01434620313479432, 0.10567017192287104, 0.048765958952052255, 0.02883454578529511, 0.028258567942040305, 0.048471274586128335, 0.039330312050879, 0.06135946711791413, 0.05298845183902553, 0.021244366553479006, 0.047835460132254023, 0.020696887181007435, 0.08809924977166311, 0.053671594110450575, 0.09774915089032479, 0.06296967821461813, 0.04631959254454289, 0.0867815279800977, 0.029454899818769524, 0.06450529117137194, 0.042603826216821156, 0.05813523155770131, 0.04863085584448917, 0.025667290203273296, 0.0349554134133671, 0.06505766617400305, 0.05265816813334823, 0.0256502182622041, 0.04612308880314231, 0.06592035559671265, 0.037947318583194695, 0.04181690201429384, 0.009778123032966895, 0.004699053051548877, 0.07277197151311807, 0.014685407879629304, 0.07270559043224369, 0.031779482761131864, 0.02544447796286217, 0.02680221974982747, 0.029314253080104078, 0.07111135883522884, 0.039764761059944115, 0.054613801051995585, 0.017743180140054653, 0.04835108567827514, 0.11550636483090264, 0.2181154481534447, 0.1546993888914585, 0.11164414350475584, 0.09327549487352371, 0.16523447286869797, 0.18800822512379714, 0.16409245772021158, 0.17699309119156428, 0.09562523450170245, 0.1372323775930064, 0.1483373495617083, 0.15123240064297402, 0.15118028915354184, 0.2088195862514632, 0.17465897143951484, 0.12724541420383112, 0.20462930681450026, 0.06268600307937179, 0.12983705156615802, 0.12663272422339233, 0.09178360671337162, 0.09695190617016383, 0.12934062177581446, 0.1698457154312304, 0.12306304648518562, 0.4433225100593907, 0.13829926534422807, 0.23742217144795827, 0.06861386142138924, 0.07700871024280787, 0.18945042416453362, 0.13970289645450457, 0.12745323590934277, 0.11107953451573849, 0.1285086971308504, 0.14972289092838764, 0.11509913525411061, 0.12250425932662827, 0.12498765678278037, 0.18985945864447526, 0.19709678100688116, 0.12052947814975466, 0.05861986840942076, 0.12294310863528933, 0.1931432152965239, 0.19499710867447512, 0.13460537498550756, 0.2285223975777626, 1.4123541393450327, 7.279623321124485, 34.00112097603934, 50.12675040108817, 73.04851014273507, 85.00850691114152, 90.13445009504045, 75.65615517752511, 72.07603331974575, 54.765058585575645, 58.79264790671212, 54.47666665485927, 46.79004825864519, 39.23322568620954, 35.47504581723894, 23.365667990275792, 29.305709021432058, 21.189189944948467, 23.60904254232134, 32.46987002236502, 24.792800188064575, 24.841114486966813, 33.36777182987758, 44.48929820741926, 34.77018233707973, 53.22709914616176, 62.12040424346924, 56.49735566547939, 58.578323772975374, 71.4024680001395, 48.35747153418404, 37.555697781699045, 39.264704499925884, 64.85857118879045, 60.67118372235979, 46.446195806775776, 69.91430282592773, 66.98816626412528, 52.95017521721976, 61.650643484933035, 65.98959200722831, 66.89604009900773, 61.40245383126395, 71.65093558175224, 82.97768742697579, 65.50253718239921, 71.14982455117362, 75.35162258148193, 61.943690708705354, 39.24487781524658, 48.4531239100865, 45.68539237976074, 28.481324366160802, 33.78058862686157, 20.007105078016007, 18.3157502583095, 33.59567274366106, 41.42631687436785, 43.334156717572895, 64.72049658639091, 62.80787985665457, 71.855865750994, 66.42444501604352, 73.20715141296387, 78.02093982696533, 80.40217086247036, 71.12642996651786, 66.44142641339982, 44.940177236284526, 23.569001810891287, 12.368417961256844, 5.556245991161891, 0.6702910353030477, 0.14494345310543263, 0.15795938324715408, 0.16180008144250937, 0.20083067779030117, 0.10402710616056408, 0.15122033629034246, 0.15983033499547414, 0.11666167926575456, 0.17881281354597636, 0.10742343855755669, 0.08443029557487794, 0.13601929268666677, 0.1965290643274784, 0.053105346459363184, 0.1575095145297902, 0.172990440257958, 0.14991456350045546, 0.10571333353540727, 0.15480530820786953, 0.18580080143042974, 0.2542662061750889, 0.08426151677433934, 0.10909169153975588, 0.1377669003392969, 0.13221539823072298, 0.2520810791424343, 0.09849842318466731, 0.14632414973207883, 0.1106157558304923, 0.2525859091963087, 0.152745642300163, 0.07165209017693996, 0.16110558728022234, 0.20519673850919518, 0.12815412187150546, 0.12375074172658579, 0.1268571971782616, 0.14713531120547227, 0.12899317113416536, 0.1276653188147715, 0.13145347125828266, 0.0776972265115806, 0.21861742836024078, 0.19994916580617428, 0.18823952414095402, 0.11022074666938611, 0.1609484657113041, 0.15302563299025806, 0.08003551925399474, 0.12850364883031162, 0.11223140199269567, 0.10406732971646956, 0.1405889546232564, 0.10167786864829914], [0.10107391141355038, 0.07397482411137649, 0.020532478145988922, 0.01483224455400237, 0.057275812673781595, 0.038723179272242954, 0.10001191589981318, 0.11807270640773432, 0.00494548467187477, 0.0067005888642077994, 0.028964437743914977, 0.043807662690856626, 0.028644155644412552, 0.0969639230253441, 0.032666596051837714, 0.06273079317595277, 0.09645022451877594, 0.017608082121504203, 0.04518840342227902, 0.061217782220670154, 0.1007330697029829, 0.04854031213160072, 0.02766182183820222, 0.06298777474356548, 0.027234823143641864, 0.03527424344792962, 0.032976282827023945, 0.022688484151980708, 0.02500694670847484, 0.04308755722429071, 0.014751827976267253, 0.02931613940745592, 0.07848181655364377, 0.039742749383939166, 0.03847488295286894, 0.08077779585229498, 0.021128750971651504, 0.04434059087985328, 0.03515940818137356, 0.03614146887723889, 0.02160232770256698, 0.07731426813240562, 0.05000119124140058, 0.17194719266678604, 0.0610621805701937, 0.10734818902398859, 0.02584412321448326, 0.525293475815228, 7.919548937252589, 23.162796224866593, 39.856513840811594, 57.75192240306309, 69.11685112544468, 60.62454046521868, 62.408365385872976, 48.919236864362446, 34.74855259486607, 39.79246882029942, 26.92341491154262, 31.28873184749058, 23.616946118218557, 15.176522868020193, 18.55091725076948, 17.247343131474086, 20.0197560106005, 17.108952386038645, 31.329062666211808, 22.473003387451172, 22.471639803477697, 42.33312279837472, 43.13792221886771, 63.23533303397042, 51.16121557780674, 56.35932275227138, 53.6819212777274, 32.81318746294294, 23.245255708694458, 14.096914376531329, 7.7815863745553155, 7.129480132034846, 7.916483044624329, 7.958182658467974, 5.555993684700557, 7.110756473881858, 14.818763596670967, 10.559979047094073, 12.11406351838793, 13.023522785731725, 12.506146022251674, 10.603372284344264, 13.31031402519771, 19.033884797777446, 16.754787070410593, 19.76386775289263, 27.372054883411952, 33.137546743665425, 46.435842990875244, 62.49054173060826, 80.87790707179478, 55.682724543980186, 62.78214372907366, 49.321763379233225, 44.709771496909006, 35.9920334815979, 29.86215203148978, 19.400320632117136, 13.824384314673287, 19.99405983516148, 18.96566390991211, 32.018612316676546, 37.37704222542899, 50.47464323043823, 43.966797147478374, 40.91226829801287, 47.62003142493111, 48.316501481192454, 55.192268575940815, 56.39938606534685, 51.68188231331961, 33.116247040884836, 26.725577116012573, 9.21558860370091, 1.9526789571557726, 0.19106260979814188, 0.05978689435869455, 0.16473899302738054, 0.08511437422462872, 0.03663944912010005, 0.030390738709164516, 0.03044236165338329, 0.037684912128107886, 0.035416919006300826, 0.011804341405097927, 0.10012476984411478, 0.05144758702122739, 0.03992495299982173, 0.03196446837059089, 0.0050134543728615555, 0.07665759551205806, 0.05221936632213848, 0.011781210994480975, 0.0866114463923233, 0.06353917944111995, 0.04784329042636922, 0.014411462936550379, 0.006912511889822781, 0.02349666685664228, 0.01743535594349461, 0.0121018586547247, 0.046610989408301454, 0.00733189402879881, 0.03964008025026747, 0.05873027962765523, 0.015946088624852042, 0.018899895749720078, 0.03470007390049951, 0.061411612534097264, 0.04913420669202294, 0.025758795739550675, 0.055620231333055666, 0.044270389646823914, 0.041763294355145524, 0.014361777209809847, 0.054821113856243234, 0.014793520560488105, 0.030642383598855565, 0.025855922938457558, 0.039040516529764445, 0.04413011610241873, 0.02512340197738792, 0.04710995013426457, 0.03642623984654035, 0.018506813628066863, 0.013726223143748939, 0.05465501526902829, 0.0034975327143911272, 0.06609061360359192, 0.03921001797009792, 0.055401461465018134, 0.06820362593446459, 0.01397460003915642, 0.04187418394056814, 0.08410688542893954, 0.03147827767367874, 0.02378043020144105, 0.02662799570576421, 0.06306727869170052, 0.015846254071220756, 0.041632639044629674, 0.08981858965541635, 0.025548563538385288, 0.022967665689066052, 0.04555326187983155, 0.026335477562887327, 0.03795020574969905, 0.006492617880992059, 0.05904898752591439, 0.01674880742627595, 0.03337474912405014, 0.04443194204941392, 0.028541557756917815, 0.031298455715711625, 0.012383326854822891, 0.03851344070530363, 0.08467875474265643, 0.05672898469492793, 0.017793003270136457, 0.02566895939941917, 0.043252831391457996, 0.01407935906068555, 0.02734823348665876, 0.06789107234882456, 0.05114368136440005, 0.031576868811888356, 0.03054694764848266, 0.008763331504139518, 0.029959166688578467, 0.04025922988408378, 0.07933166130845036, 0.06544359653655972, 0.07272216025739908, 0.08828655936356102, 0.06786501660410847, 0.8634120353630611, 10.732447232518878, 30.14862973349435, 50.407217911311555, 67.80696283067975, 79.12046446119035, 70.41624069213867, 70.2151459285191, 56.673520292554585, 43.168661049434114, 48.563673223767964, 33.29417303630284, 39.6284670148577, 30.830925464630127, 29.178758484976633, 30.07728910446167, 27.297247103282384, 23.01161731992449, 20.57194151197161, 29.80905737195696, 19.830242156982422, 20.791598388126918, 30.09595196587699, 33.16974469593593, 46.29349872044155, 41.61631883893694, 41.03328159877232, 41.34572124481201, 32.57039655957903, 24.11630620275225, 16.083988870893204, 9.861650347709656, 7.468708123479571, 8.183033313070025, 7.137333767754691, 4.420007509844644, 5.134681412151881, 10.04565601689475, 7.287627645901271, 8.441446372440883, 8.132908139910016, 8.60744491645268, 8.661488005093165, 9.537087832178388, 12.63559183052608, 13.847038916179113, 16.063774824142456, 21.19338491984776, 28.464445454733713, 36.99876839773995, 45.183669907706125, 50.29662690843855, 42.43241603033883, 45.00968701498849, 35.178698199135916, 37.846052578517366, 32.25901998792376, 30.579650810786656, 30.140476022447857, 24.45142650604248, 26.86702333177839, 29.80648306437901, 41.251705169677734, 51.98334380558559, 60.326865741184776, 52.794893401009695, 49.98382248197283, 56.14718382699149, 55.19443988800049, 61.46231951032366, 63.970514978681294, 62.82755715506417, 43.1088752746582, 32.13423728942871, 11.366307939801898, 2.8062119569097246, 0.3673816850142819, 0.0979567418939301, 0.09716552935008492, 0.029193484024809938, 0.03830853670037218, 0.02358740395201104, 0.054306356835045984, 0.07461523224732705, 0.03676374316481607, 0.05540871839704258, 0.0412059490835028, 0.018877797560500245, 0.026452341649149145, 0.032527469231614044, 0.036052730067500045, 0.030851463986826793, 0.06736775221569197, 0.020688483524801474, 0.06685755494982004, 0.06963249176208462, 0.029360610592578138, 0.03352334490045905, 0.007236730340602142, 0.007979213892083083, 0.0810063603733267, 0.05205739662051201, 0.06375749129801989, 0.0641623731436474, 0.05269967072776385, 0.029147408104368618, 0.011838817769395453, 0.04881164471485785, 0.053299353191895146, 0.04082323158425944, 0.03759248548054269, 0.02204221347346902, 0.06587566049503428, 0.04495184236605253, 0.03800491602825267, 0.016728449679378952, 0.08255303345088448, 0.048066613264381886, 0.03199174887101565, 0.08210342257682766, 0.06253709178417921, 0.06265814921685628, 0.05118768775303449, 0.033627187899713, 0.027631993438782435, 0.01224340360412108, 0.007263118567477379, 0.05375186480315668, 0.018466372940955416, 0.2642672695219517, 0.17067578089024338, 0.15010719959224972, 0.15734015218913555, 0.13282495337937558, 0.11334259129528489, 0.2657302724463599, 0.30606356103505405, 0.13371631769197329, 0.09533378335514239, 0.14726138301193714, 0.12163592449256352, 0.1138302069157362, 0.1716239114425012, 0.20499194306986673, 0.1255976597645453, 0.17050441008593353, 0.11038548140121357, 0.08089530454682452, 0.10235810678984437, 0.20433236631963933, 0.14079627421285423, 0.1416088877511876, 0.10393033349620444, 0.11552578450313636, 0.13939546580825532, 0.09890960183526788, 0.11669209120529038, 0.202440990667258, 0.1265416241117886, 0.1500829216092825, 0.10751981767160551, 0.21437746658921242, 0.10876560118049383, 0.11086438463202544, 0.12464464376015322, 0.15465398132801056, 0.15622398922485964, 0.10281452337013823, 0.11939551042658941, 0.11289734340139798, 0.12552357731120928, 0.1539297809026071, 0.2588195561298302, 0.12247272101896149, 0.21103117614984512, 0.26460830122232437, 1.2614508824689048, 13.85173329285213, 38.53854826518467, 61.735210009983604, 79.75257682800293, 88.45648097991943, 80.5106600352696, 80.42050021035331, 68.8662018094744, 54.01820019313267, 55.558160713740754, 40.537503310612266, 44.592246191842214, 36.70740263802664, 27.407994440623693, 29.87701075417655, 30.074610573904856, 30.439269406454905, 26.660182407924108, 43.85039050238473, 32.05389526912144, 33.026882784707205, 58.741425786699565, 62.402542795453755, 83.35619054521833, 64.9589935030256, 73.77055304391044, 70.09690148489815, 44.61602292742048, 32.87865686416626, 20.861573696136475, 12.15474087851388, 10.014045187405177, 10.906563878059387, 10.55206765447344, 6.7839362280709405, 9.43807600225721, 19.636477742876323, 14.150791576930455, 15.91974561555045, 16.667045218603953, 16.231134346553258, 13.614363721438817, 17.653712000165665, 23.70563987323216, 20.741785015378678, 23.820526599884033, 35.18534415108817, 45.08276121956961, 58.83227348327637, 78.81917667388916, 100.37198843274797, 72.90338311876569, 77.6132264818464, 62.65292807987758, 58.85996205466134, 48.57184777941023, 40.06558166231428, 32.83490058353969, 28.20092633792332, 31.568400314876012, 34.13901492527553, 48.42459808077131, 53.32865054266793, 63.52734497615269, 59.60677528381348, 58.935843331473215, 64.03329890114921, 63.87140587397984, 73.40339633396694, 70.73365524836949, 72.60582651410783, 55.387610231127056, 39.37423242841448, 16.902709007263184, 4.637390153748648, 0.7885025292634964, 0.17854146739201887, 0.1997882987239531, 0.17688357563955442, 0.17426037282816, 0.12289793177374772, 0.11888247009898935, 0.17174483995352471, 0.21088150489543164, 0.13999316016478197, 0.2488307606961046, 0.14644026064446994, 0.12378230717565332, 0.08054039001997028, 0.12678859728787625, 0.20572438091039658, 0.13715761660465173, 0.1265830418893269, 0.17658781579562596, 0.10938604681619576, 0.18660797311791352, 0.10203000118157693, 0.0928165948550616, 0.16404485170330318, 0.2299547035779272, 0.13094857335090637, 0.10250010381319694, 0.0738538820296526, 0.10306179510163409, 0.1052255414958511, 0.11963755743844168, 0.1734220428126199, 0.24093673857195036, 0.13769413424389704, 0.13223473647875444, 0.11398791202477046, 0.136143668155585, 0.09620632510632277, 0.15657396401677812, 0.10851659239935023, 0.21044408051030977, 0.1311544815876654, 0.13139765496764863, 0.2110189760902098, 0.23251340485044888, 0.17726339240159306, 0.19399765373340674, 0.1835539277110781, 0.18973957507738046, 0.05901516255523477, 0.13622197109673703, 0.10346910610262837, 0.10702547098376922], [0.04055169204782162, 0.07186677865684032, 0.03989989130890795, 0.03045933520687478, 0.05136197965059962, 0.008206161803432872, 0.01855961891955563, 0.05472586450300046, 0.05680588646126645, 0.030854100095374242, 0.09239410502570015, 0.03075941392619695, 0.04537027455600245, 0.07765310816466808, 0.05493583716452122, 0.039431976952723095, 0.08068222419491836, 0.04473160686237471, 0.06007625561739717, 0.024347034083413224, 0.061584883236459324, 0.024613187748140523, 0.03348382023562278, 0.022638158905985098, 0.060854297796530385, 0.0719376787809389, 0.04656277949522648, 0.003990623476316354, 0.05940510984510183, 0.029501701771680797, 0.056970261569534025, 0.055476799208138666, 0.054348582069256475, 0.06999231888247387, 0.03753468786765422, 0.03327166608401707, 0.06461451495332377, 0.0249512169310557, 0.04177682434341737, 0.014087244485771018, 0.06468811564679657, 0.040574541714574607, 0.03264648766656007, 0.05215157728110041, 0.0116521519375965, 0.7269824189799172, 5.352391924176898, 17.144636596952164, 46.631796087537495, 67.8306770324707, 64.88793427603585, 67.84772791181291, 55.685211999075754, 45.5889687538147, 49.470051833561485, 35.169005462101524, 38.07078511374337, 22.919557162693568, 19.978610515594482, 11.941319142069135, 13.83604165485927, 15.74704987662179, 17.84032324382237, 18.71888300350734, 31.211453982761928, 38.94592114857265, 57.863069261823384, 82.74338722229004, 60.11704404013497, 57.888954775674, 55.40470627376011, 42.14587232044765, 41.33141837801252, 31.60586847577776, 15.436840602329799, 10.116517220224653, 3.7858762570789883, 2.435303653989519, 2.0140806223664964, 1.196087658405304, 0.46164423120873316, 0.17998340858944825, 0.8385245108178684, 0.30187553433435305, 0.025060827477968166, 0.05799684434064797, 0.08172279835811683, 0.19876833845462116, 0.15749597097081797, 0.12324006270085062, 0.4873102796929223, 0.34660190290638376, 0.697312308209283, 1.4810370824166705, 3.0435988988195146, 6.666942460196359, 9.780528392110552, 13.489135469709124, 28.81231222833906, 32.22011007581438, 46.13967950003487, 57.64334985188076, 58.90060206821987, 62.99834387642996, 40.11977413722447, 29.83994558879307, 21.547494649887085, 23.023804460253032, 13.198797174862452, 11.300793375287737, 15.958876132965088, 27.041456120354788, 54.248206411089214, 75.27713094438825, 71.34445749010358, 69.15753977639335, 64.75220121656145, 60.02058914729527, 57.021107401166645, 63.3839966910226, 55.94301448549543, 41.491647311619346, 28.83677509852818, 7.863399675914219, 1.9143457455294473, 0.10749032853969506, 0.05424799264541694, 0.015165656306115645, 0.020062531577423215, 0.02736620618296521, 0.028665560031575815, 0.05593439304668989, 0.04879961089630212, 0.06791438002671514, 0.05047463226531233, 0.06999525015375443, 0.06453532313129731, 0.06093650231403964, 0.03438926754253251, 0.08092349089149918, 0.022392987240371958, 0.027215479806597744, 0.02843330428004265, 0.022441137781632797, 0.019839173116322075, 0.04218820655452354, 0.003091089814136337, 0.021742563927546144, 0.04523518501913973, 0.05331637424283794, 0.0459578757041267, 0.03748757378863437, 0.07889992304678474, 0.06466056033968925, 0.022590152553415725, 0.0466394335962832, 0.055459086051476855, 0.023362707080585614, 0.05524311514039125, 0.05492196112338986, 0.01778481844147401, 0.014300330774858594, 0.04143893086750593, 0.0586419886510287, 0.018308940942266157, 0.011707982647099664, 0.018098924175969193, 0.0428047200797924, 0.018330584513023496, 0.02533290644974581, 0.003471464247143428, 0.017270175074892383, 0.029268791233854632, 0.05027019305686865, 0.0599071579053998, 0.02914330975285598, 0.007864513484361981, 0.06367597210087947, 0.05851660895028284, 0.005507103865966201, 0.020478821293051754, 0.06557285067226205, 0.012798143301292189, 0.055049834440329244, 0.06393849729959454, 0.020361570441829305, 0.031780792333717854, 0.06578190731150763, 0.053477909682052474, 0.02670947419080351, 0.04378208192065358, 0.030807522059019123, 0.012578827212564647, 0.01591517965841506, 0.0656314625271729, 0.023864005359687974, 0.052546325206224404, 0.04211096552067569, 0.01881851565225848, 0.022523116686248353, 0.02353341631325228, 0.034917608834803104, 0.04714701171698315, 0.03279104955228312, 0.03176475176587701, 0.03292451399777617, 0.07960547054452555, 0.05081606090867093, 0.06708740868738719, 0.04625672288239002, 0.003525794546086607, 0.02874969837388822, 0.09957215735422713, 0.04705796078113573, 0.07336425116019589, 0.020732347421082, 0.0280478438029864, 0.04954992813457336, 0.033093336903090985, 0.03860540594905615, 0.012119041705903198, 1.2491223897252763, 7.695112568991525, 24.530571699142456, 54.014517647879465, 76.81552464621407, 72.65646498543876, 74.17526476723808, 62.73325620378767, 54.28404521942139, 59.136055673871724, 43.96468489510672, 48.65075152260916, 38.130810601370676, 35.192570277622764, 24.646068130220684, 19.012739692415508, 17.098543984549387, 23.925176892961773, 19.858271190098353, 31.67495788846697, 27.64001042502267, 50.427464962005615, 67.0739973613194, 46.63442598070417, 47.29326111929757, 50.05597257614136, 38.86680548531668, 32.16868298394339, 24.03584258896964, 13.655282531465803, 8.32911137172154, 4.717653572559357, 2.2889263885361806, 2.093421450683049, 1.442860096693039, 0.2940196730196476, 0.20653924718499184, 0.6414111735565322, 0.38469160188521656, 0.07229483925870486, 0.07558061794510909, 0.03408252221665212, 0.12799182986574514, 0.12737953343561717, 0.016456866038164923, 0.08802237853940044, 0.0580351340717503, 0.550730722291129, 0.8299367002078465, 1.951238942997796, 3.521851224558694, 6.362681712423052, 10.62270130429949, 22.727380411965505, 27.86988636425563, 34.88312530517578, 39.066663469587056, 44.889420645577566, 44.05619961874825, 33.37133278165545, 32.13103764397757, 26.933125019073486, 28.124972105026245, 20.00819420814514, 20.972843885421753, 18.65801157270159, 29.85179226739066, 53.81275238309588, 75.47575909750802, 72.97637394496373, 73.78292083740234, 71.33425753457206, 67.02522100721086, 66.37203475407192, 72.49883120400565, 64.93042251041958, 48.62030104228428, 35.83229439599173, 10.77198508807591, 3.0435452674116408, 0.08393924656723227, 0.05504124079431806, 0.01591069284560425, 0.06185981205531529, 0.030053917318582535, 0.05208796801577721, 0.046514980095837793, 0.018954534782096744, 0.03901948872953653, 0.04461152312744941, 0.08217384094106299, 0.04608367270390902, 0.02273253125271627, 0.005654149613941887, 0.019960206800273488, 0.05817006754555872, 0.03371294454804488, 0.036392886457698684, 0.05565797145079289, 0.02447138580360583, 0.0259413216595671, 0.04484080011025071, 0.025635337989245142, 0.04958341723041875, 0.06724138863916908, 0.06899069941469602, 0.03676919858636601, 0.06328052867736135, 0.06915219074913434, 0.0329013522049146, 0.04671515131901417, 0.031202904414385557, 0.04794528441769736, 0.027199332369491458, 0.010031248825336141, 0.04769669972094042, 0.05778827624661582, 0.02804585060636912, 0.1214741753148181, 0.03312472254037857, 0.024327280232682824, 0.07339924999645778, 0.026976626998345767, 0.0483909156838698, 0.05566978474546756, 0.046826654978628666, 0.03124822716095618, 0.0467826112705682, 0.02387338610632079, 0.05253626253189785, 0.01025787612888962, 0.18280196163271153, 0.19827998323099955, 0.11640638725033828, 0.09018708845334393, 0.10454250779002905, 0.16546748179410184, 0.07198677078953811, 0.20537357830575534, 0.27686915759529385, 0.08199200712676559, 0.19797469675540924, 0.1996941723461662, 0.16873020386057241, 0.13214137006018842, 0.15305111876555852, 0.07810838480613061, 0.22294365907354013, 0.11574402850653444, 0.14463093344654354, 0.106839023131345, 0.12863605815385068, 0.0793740086789642, 0.21648747979530267, 0.08445252438208886, 0.21247053891420364, 0.1875154051397528, 0.1199988094823701, 0.15895904174872807, 0.08776788719530616, 0.14975847330476555, 0.17627991017486366, 0.17226162579442772, 0.10298196545669011, 0.1450240494949477, 0.1881008722952434, 0.09161706707839455, 0.20725198036858014, 0.10069462390882628, 0.15070801520986216, 0.13295601920357772, 0.11495159459965569, 0.21891322891627038, 0.12380887860698359, 0.10631281243903296, 0.1663501337170601, 1.9026082839284624, 10.269333294459752, 29.83395971570696, 64.64518506186349, 85.9110084261213, 81.97206769670758, 83.00410447801862, 73.16483688354492, 61.79417242322649, 66.95052092415946, 53.617487158094136, 51.285129751477925, 35.28860133034842, 32.52781105041504, 20.99249860218593, 23.165141241891043, 24.217438970293315, 24.242244039263042, 28.196290152413503, 44.394587312425884, 51.80060965674264, 69.74754605974469, 98.82597950526646, 79.65494074140275, 72.43593611036027, 72.10047708238874, 54.97301122120449, 52.028545311519075, 39.4970383644104, 18.91938717024667, 13.309936216899327, 5.605631615434374, 3.266107793365206, 3.22553574187415, 2.259881832769939, 0.6733524224587849, 0.5188536356602396, 1.5155552987541472, 0.9477359162909644, 0.2941807843744755, 0.30620233501706806, 0.3529238136751311, 0.45770101994276047, 0.3666158089680331, 0.24917483223336084, 0.6463121505720275, 0.5613997897931507, 1.3068911241633552, 2.1556052224976674, 4.045343705586024, 8.88871841771262, 12.01076899256025, 18.276232378823416, 36.139616693769185, 42.303665910448345, 58.84965787615095, 73.0306532723563, 74.28211416516984, 78.76502936226981, 53.31881536756243, 45.08463028499058, 32.91872017724173, 36.6814615385873, 24.220400639942714, 22.3308675629752, 27.3264000075204, 38.215985093797954, 67.6511286326817, 87.14846175057548, 84.48361914498466, 81.48398453848702, 80.39365237099784, 76.41566971370152, 74.03470270974296, 82.90269551958356, 73.5826529094151, 56.95910862513951, 44.85152517046247, 15.315153326307025, 4.668384330613272, 0.6016044552837099, 0.20068175292440824, 0.12476285813110215, 0.18674218734460218, 0.1629152266042573, 0.10331288698528494, 0.217946520075202, 0.11542745120823383, 0.13460084237158298, 0.16045313514769077, 0.19942366757563182, 0.18822526133486203, 0.151093151686447, 0.06811830694121973, 0.12436565730188574, 0.17042865843645164, 0.10501185046242816, 0.10258074770016329, 0.10526645037212543, 0.11435466020234994, 0.13478674739599228, 0.11412363259920053, 0.14693381344633444, 0.10751697460987739, 0.21074502436178072, 0.19949328526854515, 0.1733675157385213, 0.23713897807257517, 0.1509827133268118, 0.1278117195303951, 0.20031771888690336, 0.2084340833659683, 0.09151669817843608, 0.1476330030709505, 0.15022705601794378, 0.08764575767729964, 0.151478111743927, 0.1810367392109973, 0.24938080832362175, 0.09360759026770081, 0.15273797485445226, 0.22832000415240014, 0.11015377526304551, 0.1084449187453304, 0.16225494417761052, 0.17403421710644448, 0.12239112039761883, 0.11651970259845257, 0.1364398758326258, 0.18597199581563473, 0.1009515579789877], [0.029987800866365433, 0.03161543674234833, 0.02227493571782751, 0.07233882868396384, 0.034895698939050944, 0.024959576482485448, 0.03401766783956971, 0.035883815559957705, 0.018431679445451925, 0.0009681641926623083, 0.01945682711500142, 0.033155297328318865, 0.040163776970335414, 0.03470052173361182, 0.07037693288709436, 0.02268884886455323, 0.03118688420259527, 0.015925727485279952, 0.0353857538928943, 0.05128622121576752, 0.005873980117030442, 0.030859243390815597, 0.03293246303551963, 0.03885045547836593, 0.03411302575841546, 0.0398928888275155, 0.043618619441986084, 0.03799415446285691, 0.04349836268063102, 0.029898454767784903, 0.05906171684286424, 0.061065858229994774, 0.016939111053943634, 0.02816365615996931, 0.06857228758079664, 0.009971430874429643, 0.07068228043083634, 0.019868536719254086, 0.06160184661192553, 0.013632554777099617, 0.019557913565742116, 0.02752374335458236, 0.06612261331507138, 1.5654461873429162, 6.006051957607269, 20.36157958848136, 47.24306385857718, 59.383425440107075, 63.66291127886091, 56.06797088895525, 53.4046881539481, 52.277183123997276, 48.46927152361189, 56.698130811963765, 64.54246289389474, 39.80813005992344, 10.220852238791329, 11.621702006884984, 13.364119138036456, 20.011359112603323, 22.9469313280923, 40.019320556095664, 60.36753354753767, 49.978493213653564, 51.972490719386506, 49.10514286586216, 48.04181834629604, 47.372255189078196, 38.28945881979806, 30.223194326673234, 21.624298300061906, 13.97024871621813, 7.6238492386681695, 4.28597719328744, 0.9305554096187864, 0.17474119631307466, 0.1050382861867547, 0.02998474406610642, 0.03406951470034463, 0.07087258236216647, 0.0220088872260281, 0.07663775514811277, 0.09519823919981718, 0.04628563865220972, 0.025454094500413964, 0.0525123882772667, 0.03217399998434952, 0.04523809593436973, 0.020055512132655298, 0.018905047526849166, 0.02565434036244239, 0.06106229592114687, 0.047368108960134644, 0.11489363413836275, 0.04797969292849302, 0.15838130989245006, 0.1810601893812418, 0.48939256795815056, 0.6129922270774841, 2.3010653257369995, 6.827649516718728, 12.38608375617436, 22.843569925853185, 39.46195690972464, 47.72440031596592, 56.97295985903059, 49.29304647445679, 38.77481828417097, 38.162470068250386, 31.006259781973704, 49.03430250712803, 64.0837984085083, 51.168823855263845, 35.75126797812325, 40.037476199013845, 32.199988092694966, 50.87768043790545, 51.082839897700715, 37.991144861493794, 52.75779002053397, 50.080228737422395, 57.97393471854073, 56.78022377831595, 44.76489850452968, 26.913734333855764, 7.899994969367981, 1.6992023757525851, 0.3799361027777195, 0.09733655410153524, 0.004358730420270669, 0.02565006728816245, 0.027435535498495613, 0.06975080791328635, 0.038691345801843066, 0.022272611735388637, 0.04072660480492881, 0.027212928514927626, 0.041833054540412765, 0.007024170340238405, 0.024242410768887827, 0.021390719771651284, 0.03632743836247495, 0.031164957343467643, 0.00558460528762745, 0.04992744466289878, 0.039952867930488925, 0.029364464671484063, 0.0263537895267031, 0.025484828744083643, 0.030776129636381353, 0.08955626123185668, 0.038084691390395164, 0.010818611531119262, 0.0076955794689378566, 0.0385000532093857, 0.00963731768674084, 0.037213815442685566, 0.04323102327595864, 0.01641000301710197, 0.07689004803874663, 0.013307159916231675, 0.04082047673208373, 0.06239892848368202, 0.026196919015741775, 0.006325749580615333, 0.03874636481383017, 0.008417047942722482, 0.017112230782264044, 0.04957869801936405, 0.005193238163233868, 0.04586967293705259, 0.032377621558095725, 0.09577958764774458, 0.024216675631968037, 0.023492217363257493, 0.011925523518584669, 0.051848166954836676, 0.06629032681563071, 0.029997500524457012, 0.045092421251216104, 0.04488863343639033, 0.0467777427818094, 0.009727235451074583, 0.019155562655734162, 0.05365604208782315, 0.012410621774116797, 0.026633715755971413, 0.03508960049865501, 0.03296944319403597, 0.049237897020897696, 0.02611163734192295, 0.026970533753878305, 0.043284281489572356, 0.013285532460681029, 0.018609879704724466, 0.03209284719611917, 0.04025443603417703, 0.039345341601542065, 0.0016666002193232998, 0.0665991281026176, 0.0362583329635007, 0.018882206341783916, 0.017478427650140863, 0.085423080516713, 0.035166013719780106, 0.03803665789642504, 0.00639589101774618, 0.022995979259056703, 0.06389361899346113, 0.042104556757424555, 0.011208172904194465, 0.03165000470887337, 0.06813335684793335, 0.045710173102894, 0.022265979055581347, 0.008768275479919143, 0.05474741477519274, 0.03111982797937734, 0.07466200366616249, 2.286424602781023, 8.92076872076307, 26.42193910053798, 57.280667781829834, 68.9451263972691, 74.40506948743547, 62.680679185049875, 61.729554176330566, 59.61742687225342, 56.85870715550014, 62.07565089634487, 69.59385190691266, 44.13406808035714, 22.743541921888077, 16.67127319744655, 16.150741951806204, 21.060538836887904, 24.47586853163583, 38.61978660311018, 35.64721870422363, 37.0059563091823, 43.66007586887905, 46.14802081244332, 40.62284108570644, 43.76042175292969, 37.37379046848842, 32.62616280147007, 20.04674107687814, 11.904513665607997, 7.1794637356485635, 3.3880827682358876, 0.8330258258751461, 0.3135137941156115, 0.04578006220981479, 0.13456260013793195, 0.03866327820079667, 0.058141636928277354, 0.1277999673038721, 0.0895533367459263, 0.12012568196015698, 0.054472499527037144, 0.01680693412864847, 0.014937843262617077, 0.05607282776119454, 0.10888910812458821, 0.07736432366073132, 0.13721557706594467, 0.2689612390739577, 0.1430569357637848, 0.053466690105519125, 0.0684029795229435, 0.10181183860238109, 0.08668645165328469, 0.06155869857008968, 0.3630822157221181, 0.47553232312202454, 1.5317947587796619, 4.49249632869448, 8.249956624848501, 14.83321932383946, 25.95475959777832, 33.814547947474885, 41.503035409109934, 36.74510703768049, 36.24995756149292, 34.10570873532976, 21.919353553227015, 43.76924596514021, 56.50794472013201, 56.56665699822562, 52.233055114746094, 54.15092468261719, 43.64634622846331, 60.55102852412632, 60.05197416033064, 48.134218965257915, 60.903350830078125, 60.51865686689104, 66.70306083134243, 65.89145565032959, 51.58327347891671, 32.61096361705235, 9.923425044332232, 2.320675313472748, 0.37314057456595556, 0.012629329725833876, 0.0170923480098801, 0.0314258845922138, 0.05530153700549688, 0.07441686931997538, 0.032358456336494, 0.042367119275565655, 0.03463077851172004, 0.07676064462534019, 0.0017659865157578938, 0.01094373847757067, 0.005647077582710023, 0.028938565203653913, 0.07408453643854175, 0.09797270103756871, 0.010519928897597959, 0.05836644236530576, 0.06976844303842102, 0.024958443329004303, 0.030485160249684538, 0.09245393824364458, 0.014921076662306274, 0.012616310335163559, 0.05655943914981825, 0.04795399680733681, 0.020238336608079926, 0.02174072340130806, 0.022671605593391826, 0.04664044800613608, 0.0032141404434306814, 0.013080340078366655, 0.07290841133466788, 0.0400591604411602, 0.02386638192859079, 0.041381754114159515, 0.0915812472147601, 0.005458598790158118, 0.02253115054086915, 0.028209453881052986, 0.05417610864554133, 0.03256056477714862, 0.045223375117140155, 0.021418551581778696, 0.03501072419541223, 0.03845619949113045, 0.043337315786629915, 0.03670039174279996, 0.03919073739754302, 0.11278592116598572, 0.1549270645316158, 0.19024340089942726, 0.23071021160909108, 0.14254724739917687, 0.11879613330321652, 0.16574364554669174, 0.09669142336185489, 0.20080744475126266, 0.09000665242118494, 0.09583152950342212, 0.11533983876662594, 0.11218208606754031, 0.14305996202996799, 0.19028814349855694, 0.17945713682898454, 0.21013845476721013, 0.10815800021269492, 0.08507596914257322, 0.10563353781721421, 0.09603573461728436, 0.13748828028993948, 0.1900767119867461, 0.1759924284581627, 0.11803297139704227, 0.1036881236359477, 0.10724839009344578, 0.11902037555617945, 0.13892686952437672, 0.10136526077985764, 0.11512140477342264, 0.14737046430153505, 0.16969889402389526, 0.11247011739760637, 0.13316222599574498, 0.07491899201912539, 0.16440799007458345, 0.09025574941188097, 0.11545620752232415, 0.09564141077654702, 0.1521895014281784, 0.20957734701888903, 0.2221107573381492, 3.150994815996715, 12.643501486097064, 34.84078645706177, 69.46719319479806, 82.21144008636475, 82.9928206035069, 72.76348808833531, 71.4666415623256, 70.24503013065883, 64.5518707547869, 69.011613709586, 73.85321576254708, 51.17942680631365, 20.27512662751334, 19.31118392944336, 20.634259905133927, 29.474195889064244, 34.331837858472554, 58.031924383980886, 79.47489207131522, 65.08336625780377, 66.72441264561245, 65.16780771527971, 62.76667703901018, 59.39991351536342, 49.51029927389962, 40.25209215709141, 28.597809178488596, 18.03145602771214, 10.126498307500567, 5.869759133883885, 1.5537389069795609, 0.742885488484587, 0.41665155121258324, 0.32661375403404236, 0.13512036949396133, 0.24511475009577616, 0.32931825891137123, 0.26480154799563543, 0.1728439581181322, 0.1672811380454472, 0.34825836973530905, 0.2296374206032072, 0.25243253314069336, 0.3545543061835425, 0.16476242962692464, 0.39404626563191414, 0.5097042151859829, 0.2960104133401598, 0.21069384925067425, 0.1967527773231268, 0.18495050205716065, 0.27153220825961655, 0.5081261598638126, 0.9170588595526559, 1.011250051004546, 2.920773203883852, 9.352432506425039, 15.704674550465175, 28.572814771107264, 49.78608022417341, 59.1977139881679, 70.3693403516497, 60.762100900922505, 53.58629322052002, 52.62251901626587, 42.316711153302876, 61.19582135336739, 70.50942298344204, 61.46187482561384, 47.07270097732544, 52.95625489098685, 44.817260129111155, 65.62049674987793, 68.38733196258545, 56.47281115395682, 70.1664182118007, 69.7687658582415, 76.0296208517892, 74.5788300377982, 61.63578823634556, 43.88802889415196, 15.336941140038626, 3.486819927181516, 0.6149804432477269, 0.19653290483568395, 0.0915165353300316, 0.132077424920031, 0.12302238866686821, 0.1432337484189442, 0.12636414649231092, 0.12071956294987883, 0.13573354801961354, 0.14731091606829846, 0.12473544531634875, 0.21532901695796422, 0.10547296929040126, 0.1376701005335365, 0.1988805274346045, 0.2284920806331294, 0.12828991029943737, 0.20816475924636635, 0.1797371275190796, 0.15812223165162972, 0.10354801972529717, 0.15957855779145444, 0.1110202848379101, 0.11586108936795167, 0.14223467345748628, 0.11020630065883909, 0.0976809241941997, 0.08934559646461691, 0.14285314455628395, 0.1298781165054866, 0.08961231500974723, 0.11051110537456614, 0.14384020944791182, 0.11467069467263562, 0.15673892945051193, 0.17466454899736814, 0.18189110979437828, 0.08508780957864863, 0.07772254265312638, 0.10229802929929324, 0.10394607550863709, 0.10962525076631989, 0.14994188132030623, 0.17159972845443658, 0.15388820027666433, 0.269687325826713, 0.07929669639893941, 0.11837658153048583, 0.11961344230387892], [0.07446989683168274, 0.048237261428896866, 0.0008752015554429298, 0.06778856606355735, 0.03253448189103177, 0.04455219541809388, 0.055739962229771275, 0.030901916458138397, 0.04649340607491987, 0.05674761726654001, 0.02512713731266558, 0.014449562677847487, 0.039600026328116655, 0.030667760808553015, 0.025137096510401795, 0.07406464179179498, 0.03162128232153399, 0.051426043534385305, 0.012325617451486843, 0.00983146860796426, 0.029546349375907863, 0.00803723796603403, 0.03166778911171215, 0.017255620498742377, 0.07482358999550343, 0.02201064972073904, 0.025623563710334044, 0.02599967736750841, 0.06274067943117448, 0.006513119392496134, 0.03697670816576906, 0.024286866686972122, 0.057774373064083714, 0.04014453371720655, 0.03686904162168503, 0.0296259042141693, 0.09237720271838562, 0.030613586572664123, 0.015057506305830819, 0.05404047628066369, 0.05932370599891458, 0.151272678481681, 4.907574330057416, 17.785557542528423, 44.127043451581685, 62.67803886958531, 66.01438317980084, 63.16729627336775, 54.08107096808297, 51.158585684640066, 40.13483435767037, 27.688656500407628, 24.24821080480303, 30.802298886435374, 79.05945927756173, 43.66858393805367, 21.36507316998073, 29.517212186540874, 50.31385496684483, 58.881973947797505, 41.54623235974993, 46.54533270427159, 60.07386098589216, 55.36003630501883, 46.46535199029105, 31.66674164363316, 31.37100546700614, 24.34868175642831, 15.450681413922991, 8.355828932353429, 2.413255499941962, 0.18857397405164583, 0.01649552726718996, 0.08805750629731587, 0.07548044582030602, 0.08138112204947642, 0.06122550394918237, 0.01696200991448547, 0.03241676285064646, 0.034246418957731554, 0.029757343232631683, 0.012522566481493413, 0.09108887506382805, 0.04587635311431118, 0.09497486547167812, 0.025951012835970948, 0.07634979167154857, 0.0868581345837031, 0.0690542102924415, 0.1179010234773159, 0.015330170514062047, 0.09699704910495452, 0.16784563846886158, 0.08366646191903523, 0.059423647421811304, 0.022653716017625163, 0.06670806011451141, 0.09213051452700581, 0.11123618111014366, 0.025028725986235907, 0.10440353024750948, 0.26964693942240303, 1.5625309837715966, 4.3174468874931335, 10.026736072131566, 17.434663091387065, 29.86870765686035, 32.68076522009713, 45.369259766169954, 51.401400906699045, 31.6058406829834, 30.298196656363352, 23.773796490260533, 23.934748036520823, 16.205566712788173, 17.134962967463903, 21.11502139908927, 19.75376854624067, 20.60554994855608, 35.678141662052695, 40.19783020019531, 48.411104679107666, 56.673433440072195, 59.36307416643415, 63.07656669616699, 41.0406744820731, 22.00093756403242, 6.162299573421478, 0.5115491790430886, 0.3924897334405354, 0.14023139380982944, 0.07483931165188551, 0.12965844757854939, 0.03705475326361401, 0.00441221721536879, 0.012577120696992745, 0.033362969756126404, 0.04393787695361035, 0.050636791956744025, 0.021483957268563763, 0.03845964984170028, 0.11134216149470635, 0.013498913064332945, 0.023016094429684535, 0.026146685371973684, 0.01793831493705511, 0.057856177245931964, 0.039039865136146545, 0.021719924606648938, 0.02108105504885316, 0.03939655403207455, 0.03926663493205394, 0.0389066992460617, 0.0617568375808852, 0.038498987909406424, 0.02344564102323992, 0.03793736108179603, 0.03786542958446911, 0.043606795969286134, 0.013692721325371946, 0.07967653351702861, 0.059959344033684046, 0.007570927496999502, 0.031331235742462535, 0.04882585663082344, 0.019481515611654947, 0.04440650716423988, 0.10851415645863328, 0.041878909936973026, 0.03171737984355007, 0.04814993736467191, 0.033596796316227744, 0.006506432853971741, 0.050507968690778525, 0.006288281725054341, 0.04695208217682583, 0.034289872340325794, 0.03598867975441473, 0.03468182470117297, 0.03741663634510977, 0.028895786963403225, 0.08327058423310518, 0.07203420038734164, 0.038486943912825415, 0.021346092523474778, 0.05968979599752596, 0.03656707996768611, 0.0616126556747726, 0.021868035230519514, 0.022149523786668266, 0.03793517619903598, 0.06780310706900698, 0.028694241706814085, 0.011407254230497139, 0.05818042877529349, 0.011113043990917504, 0.021173861676028798, 0.02743901977581637, 0.023567354938547527, 0.02140162043672587, 0.029213612766138146, 0.02375337531390999, 0.02320799939999623, 0.022503240699214593, 0.07063142423118864, 0.015296976580949766, 0.034504591354302, 0.019680004067985073, 0.07956067366259438, 0.03323685045221022, 0.01017695149805929, 0.042227520873504024, 0.056531571716602357, 0.041119775136134455, 0.0797167435022337, 0.01945325971714088, 0.13839580730668136, 0.2513102633612496, 6.042774055685316, 23.54885377202715, 52.911550181252615, 71.90378747667584, 74.4002821786063, 72.23020689828056, 62.76034723009382, 59.43465450831822, 48.474857875279014, 38.88251188823155, 33.946838174547466, 42.798798016139436, 84.34736497061593, 51.811525276729036, 18.25108163697379, 25.479923180171422, 39.37024416242327, 42.367412158421104, 39.13268872669765, 38.522094930921284, 51.79375525883266, 46.79885857445853, 37.21887690680367, 27.865703548703873, 29.54423373086112, 18.532879727227346, 11.582209314618792, 6.078218988009861, 2.685814005987985, 0.5114584181989942, 0.0147688982209989, 0.07748204270111662, 0.04267028193654759, 0.09506876793290887, 0.0473999051111085, 0.03615649503522685, 0.004934253220978592, 0.125473501426833, 0.085736651904881, 0.027115901399935995, 0.033316313688244135, 0.029528575151094368, 0.10753809061965772, 0.01961041521281004, 0.034171685110777617, 0.07773200143128633, 0.08864948060363531, 0.356907601335219, 0.2782803475856781, 0.16385301628283092, 0.19535264745354652, 0.14332737268081733, 0.09070085481341396, 0.08116661677403109, 0.022744626139423678, 0.1289764248899051, 0.13376863274191106, 0.006015257469178843, 0.025442832515441945, 0.14760884722428663, 1.0355519184044428, 2.8405456117221286, 7.519436052867344, 13.41860864843641, 20.89310462134225, 25.95989257948739, 36.62831824166434, 47.685188157217844, 37.94476910999843, 35.64795868737357, 31.369247572762625, 24.480112143925258, 21.931300980704172, 24.457622562135967, 33.89709254673549, 30.708136899130686, 30.056593894958496, 44.578200408390586, 50.86374929973057, 57.57861001150948, 65.16570935930524, 69.49559048243931, 73.32497896466936, 49.28070647375924, 28.535094738006592, 9.491841162954058, 0.9381380655935833, 0.5015323736837932, 0.08014040719717741, 0.04295910715258547, 0.08778417882110391, 0.015625942232353345, 0.030791389888950756, 0.05557043364803706, 0.022580647974142005, 0.022312540128561, 0.05753124039620161, 0.00886397181810545, 0.052816653557653935, 0.007898497062602212, 0.019636050265814577, 0.02179684503270047, 0.011537223372475376, 0.01885033894463309, 0.08817692846059799, 0.03077988532770957, 0.04826227222968425, 0.017539404199591706, 0.040736097509839704, 0.02782358119397291, 0.029947923363319466, 0.044455022418073246, 0.10632440181715147, 0.006401401146181992, 0.01438397548294493, 0.04587687897895064, 0.051359648882810555, 0.07753829325416259, 0.02087031733909888, 0.031282985117286444, 0.016125479713082314, 0.0436062633192965, 0.007445719974514629, 0.03282455221882888, 0.10503092408180237, 0.05532555714515703, 0.02696783488084163, 0.03193358484921711, 0.016362697251939347, 0.040527356389377794, 0.05740621353366545, 0.017401441066925014, 0.010694885759481361, 0.040805070594485314, 0.20189470212374414, 0.07428439214293446, 0.09370742991034474, 0.12143938003906182, 0.07632774606879268, 0.15976708196103573, 0.19002050214580127, 0.1033973985218576, 0.18815933487245015, 0.19466401583382062, 0.1377804438982691, 0.14712288044393063, 0.12525422605020659, 0.10541522596031427, 0.1104884830170444, 0.19198700519544737, 0.10534005106559821, 0.1811243380819048, 0.14144378661045007, 0.07692605110683612, 0.12218823842704296, 0.10403490931327854, 0.12084389770669596, 0.09622969385236502, 0.12670177194689, 0.1519495171627828, 0.09449294954538345, 0.10774133899914366, 0.28647004812955856, 0.08042358700186014, 0.09914545382239989, 0.09723153723669903, 0.127750515671713, 0.09759939821170908, 0.14677661045321397, 0.08203750289976597, 0.20193535994206155, 0.18294243195227214, 0.11888598491038595, 0.11799303282584463, 0.22850991253341946, 0.4810311166303498, 7.928289771080017, 31.74217128753662, 65.10975551605225, 81.67601190294538, 83.40180546896798, 81.53633226667131, 71.99999918256486, 68.75427327837262, 55.46676410947527, 43.38159901755196, 34.539554255349294, 42.67606851032802, 85.30654988970075, 54.05664110183716, 33.2806726864406, 43.087634631565635, 70.2267563683646, 77.15854331425258, 54.184758935655864, 58.62341758183071, 80.22139957972935, 67.25196852002824, 58.793023109436035, 40.57092414583479, 41.53134931836809, 30.580032961709158, 20.925881011145457, 11.862890481948853, 4.811379994664874, 0.6103714534214565, 0.19132840553564684, 0.17617350231323922, 0.14264038311583654, 0.25421379613024847, 0.13592551914708956, 0.13825332852346556, 0.27397078169243677, 0.22197416823889526, 0.11970904788800649, 0.17478498896317823, 0.3948890875492777, 0.1776791172368186, 0.2536887457328183, 0.17933652044406959, 0.23103579985243933, 0.15665948657052858, 0.23780250389661106, 0.33603532133357866, 0.4222405898783888, 0.3686684588236468, 0.8014017513820103, 0.8135719554764884, 0.4259375200739929, 0.1205186623015574, 0.1355498685900654, 0.21368393594665186, 0.39929885949407307, 0.1544226687401533, 0.3392332297350679, 0.5217117880071912, 2.782543786934444, 6.05567729473114, 13.335707085473196, 23.250185455594742, 36.97735057558332, 41.64559507369995, 58.123077801295686, 66.91856615883964, 42.91707720075335, 40.56590059825352, 36.67618785585676, 35.82941089357649, 26.964461394718715, 30.329883916037424, 32.86692830494472, 32.35376214981079, 33.55139882223946, 53.339409828186035, 58.462330545697895, 65.41114752633231, 75.78836550031389, 78.1463200705392, 79.9928594316755, 60.410181590488975, 35.89364004135132, 12.805059262684413, 2.099757556404386, 0.7101121385182653, 0.21991858711200102, 0.14959090229656014, 0.36351764521428515, 0.18212798636938843, 0.15072584711015224, 0.21497833648962633, 0.11388318692999226, 0.08990579497601305, 0.15531530869858606, 0.08109796260084425, 0.10629341990819999, 0.21100792954010622, 0.12277107286666121, 0.10203480520950896, 0.12395042101187365, 0.14190966875425406, 0.18719573372176715, 0.1658410288925682, 0.11343897719468389, 0.22658009108688149, 0.19802128496978963, 0.1105548030297671, 0.12989733261721476, 0.08992703312209674, 0.3244244472256729, 0.11733532883226871, 0.1420646868646145, 0.111397563878979, 0.19814005573945387, 0.1298631615936756, 0.0992871183635933, 0.18835582504315035, 0.090801244069423, 0.11863065218286854, 0.105837471517069, 0.1135336531858359, 0.17710696293839387, 0.17085139932376997, 0.14958193206361362, 0.15590469778648444, 0.12864224639322075, 0.1308565911437784, 0.1978726586593049, 0.1191777413977044, 0.09640472874577556, 0.15720673863376888], [0.02473904242339943, 0.033825869738523445, 0.014487574209592171, 0.10764296499214002, 0.022672906684290086, 0.051867264322936535, 0.012181810435972043, 0.027189946533846, 0.04312340083665081, 0.04083524504676461, 0.0332122128456831, 0.033576365626816235, 0.056862598418125083, 0.06325676638100829, 0.02209544793835708, 0.027801148826256394, 0.020863274145605307, 0.030245165806263685, 0.029450730221079927, 0.028047324723697135, 0.015825531611751233, 0.06719995050558022, 0.02808541089429387, 0.0710977745641555, 0.04331164341419935, 0.050387922275279245, 0.0724849444148796, 0.07241848869515316, 0.021608600758814385, 0.030906856193074157, 0.027158895075055103, 0.026411962030189376, 0.01883465121500194, 0.07372220552393369, 0.025629156535225253, 0.10492393946541206, 0.030406592679875236, 0.019725425202133398, 0.052452365069517067, 0.42519210864390644, 1.2256465979984827, 11.554351380893163, 31.816127913338796, 51.770270347595215, 66.72418335505894, 63.084619658333914, 50.651756286621094, 46.42528520311628, 40.11650153568813, 28.526008231299265, 23.090903214045934, 14.039317284311567, 20.000872543879918, 17.50333387511117, 14.793402671813965, 20.97003333909171, 44.02427959442139, 44.65606539590018, 39.60742786952427, 47.786760398319785, 41.84643622807094, 40.45794643674578, 19.862349782671245, 16.406545094081334, 13.911739672933306, 9.049140163830348, 5.837268923010145, 2.3073907920292447, 1.2093643631253923, 0.35659338533878326, 0.0391807052572923, 0.11913879348763398, 0.059607638977468014, 0.08116042174931083, 0.023060930327379277, 0.05105267624769892, 0.02403799700550735, 0.08139561555747475, 0.0397987590570535, 0.06111391886536564, 0.009088648333480316, 0.04475995944812894, 0.08293940486120326, 0.1366410886070558, 0.05748677599642958, 0.03996511548757553, 0.024988219141960144, 0.07597467715718917, 0.0363285206258297, 0.030874401863132204, 0.10909985431603023, 0.06125400920531579, 0.2881781921855041, 0.385650344725166, 0.3990808054804802, 0.05700315694723811, 0.07320271911365644, 0.04674713745979326, 0.02204128896950611, 0.049932184230004034, 0.07124177326581307, 0.04623228883636849, 0.06483824151967253, 0.10193060937204532, 0.2961849868297577, 0.6003193642411913, 2.094661052737917, 6.96382508959089, 14.043124897139412, 15.956336566380092, 26.53529027530125, 46.968095847538535, 59.22298458644322, 53.97948830468314, 49.84293038504464, 42.85003055844988, 22.98049807548523, 19.895461423056467, 15.550818852015905, 18.639072520392283, 24.35535029002598, 39.221187932150706, 46.636704989842, 52.14101580211094, 60.115890639168875, 59.64663709912981, 59.98153332301548, 49.64691822869437, 26.486037969589233, 18.04071797643389, 5.846605130604335, 0.08095895113157374, 0.007023580014772181, 0.05906593054533005, 0.018025186079155122, 0.014781917611669217, 0.04812968648704035, 0.06048580578395298, 0.03633485475022878, 0.04947602888569236, 0.02269650952491377, 0.0289199462027422, 0.040616648205156834, 0.009358613668674869, 0.029640574141272476, 0.05141727686194437, 0.017033563128539493, 0.020919059902163487, 0.010050566717317062, 0.037841436586209705, 0.0364079397570874, 0.03582176353250231, 0.06455161475709506, 0.028500774409621954, 0.031719792035541365, 0.04019799209865076, 0.06993978670133011, 0.017553519424317137, 0.016282277281529138, 0.036612267007253, 0.03085032744067056, 0.03602898473452244, 0.055262202330465825, 0.019403886116508926, 0.045352401943611245, 0.07256860099732876, 0.06945964175143413, 0.005043693285967622, 0.011717424461884158, 0.04822980093636683, 0.03334552801347204, 0.028384062993739332, 0.011521599255502224, 0.015699067951313088, 0.04175493819639087, 0.03235304501972028, 0.033870100043714046, 0.07983892051769154, 0.0711681590016399, 0.08887717659984316, 0.05270026444590517, 0.021966775646433234, 0.010780127569367843, 0.0770063353702426, 0.04735293352444257, 0.05688566182340894, 0.03642946967322912, 0.040223026648163795, 0.023113482864573598, 0.07593252656183072, 0.053544158448598216, 0.011131032802430647, 0.036231483332812786, 0.016034511915807213, 0.025559404831645743, 0.018746867443301847, 0.026598618532131826, 0.034755656096552096, 0.018465431473617042, 0.030182978071804558, 0.06348951067775488, 0.012657073326408863, 0.021549843018874526, 0.00986060150898993, 0.009007170696609786, 0.061656366900673935, 0.021155529356162463, 0.07081234880856105, 0.02640326490758785, 0.01631898941871311, 0.03956003347411752, 0.03502490557730198, 0.05654602111982448, 0.02940961778430002, 0.03342109645849892, 0.44551702801670345, 1.2912458436829704, 13.782032438686915, 38.41389410836356, 60.37204987662179, 74.43077087402344, 69.72180993216378, 57.520662035260884, 54.993494510650635, 48.602603980473106, 37.79557391575405, 35.062812668936594, 24.166843925203594, 27.84809160232544, 22.810343640191213, 31.17969376700265, 31.140637942722865, 43.73308059147426, 41.04138319832938, 36.45497458321707, 41.230137961251394, 32.56160708836147, 31.18811845779419, 17.589936222348893, 14.729501826422554, 13.499761002404348, 8.600118909563337, 4.857864311763218, 2.641670797552381, 1.1637391256434577, 0.30204891360231806, 0.019970522228894488, 0.1340789675180401, 0.04047979786992073, 0.029749886132776737, 0.057937241824609895, 0.033110327419957945, 0.05503586679697037, 0.10870772214340312, 0.05671953609479325, 0.21621968916484288, 0.14893789376531327, 0.14452836609312467, 0.07370389186378036, 0.20091770669179304, 0.05661912987540875, 0.009020455564106149, 0.08604781449373279, 0.2870951417301382, 0.13183748136673654, 0.29684387147426605, 0.1905111236763852, 0.07196906781090157, 0.31226197843040737, 0.7798472451312202, 0.6385685460908073, 0.3594090885349682, 0.21683559540127004, 0.15195969518806252, 0.0376877653678613, 0.07000087520905904, 0.047926936830793104, 0.0145596770370113, 0.06740325316786766, 0.09514122190220015, 0.16554384412510054, 0.33573334610887934, 1.2873988215412413, 4.347671551363809, 9.238586272512164, 14.949785777500697, 24.782341412135533, 42.72576897484915, 57.70830161230904, 52.36595330919538, 45.66857426507132, 40.24415731430054, 23.142714193889073, 23.721024921962194, 19.204258101327078, 29.135184594563075, 33.614825453077046, 48.337519781930105, 55.78703090122768, 60.63181522914341, 66.48021820613316, 69.47161224910191, 69.17423629760742, 59.81456811087472, 34.933680398123606, 25.007827826908656, 7.737379329545157, 0.3911496267787048, 0.04193938437051006, 0.056553345905350785, 0.015206773831908191, 0.023858356555657725, 0.032705493071781735, 0.04195102463875498, 0.04976911190897226, 0.011041707908069449, 0.03656169579231313, 0.018038263145302023, 0.01523944190038102, 0.04941358330792614, 0.03860243057299938, 0.04667486669495702, 0.05995021095233304, 0.028865313955715725, 0.01012672039879752, 0.043297767373067994, 0.038451829725610356, 0.011204329003313822, 0.03238631359168461, 0.009176583927390831, 0.025690986342462044, 0.020868210487865975, 0.027306598577914492, 0.03221721927236233, 0.03735197874318276, 0.020813362805971077, 0.021635309593485932, 0.018174049876896397, 0.017153860601995672, 0.017469934088044932, 0.03292172861152461, 0.014779479974614722, 0.05724246946296521, 0.029081040594194616, 0.02874405635520816, 0.042371947052223344, 0.02583611141225057, 0.02144699576976044, 0.013465401916099446, 0.05796637133296047, 0.0413458663970232, 0.009407124681664365, 0.15901226603559085, 0.1298724575234311, 0.16693912925464766, 0.23645099784646714, 0.11340211238712072, 0.07439915277063847, 0.1876273634178298, 0.10811330511101655, 0.16240378761930124, 0.15713397253836903, 0.14027552572744234, 0.10721933522394725, 0.12923109265310423, 0.15801019194935048, 0.11714597684996468, 0.09949610714933702, 0.09184970959488835, 0.15960459996547016, 0.09627833802785192, 0.10053648453738008, 0.14832381957343646, 0.08482463298631565, 0.20012553062822136, 0.1286735947110823, 0.0757534611704094, 0.17591021715530328, 0.15096336150807993, 0.2013988151614155, 0.14155719695346697, 0.19468769670597144, 0.0725067253889782, 0.26312195669327465, 0.13483142214162008, 0.09369340459150927, 0.08014766073652677, 0.12164892522352082, 0.19401748052665166, 0.2590890702392374, 0.14367510830717428, 0.8680931127497128, 2.794301224606378, 20.391462053571427, 48.44828448976789, 72.18319538661412, 83.1280881336757, 77.62778295789445, 68.9485171181815, 63.67728015354702, 56.20596906117031, 42.910233225141255, 36.95233358655657, 23.499177626201085, 29.78172663279942, 28.10791427748544, 24.251535517828806, 29.181614194597515, 60.44096211024693, 60.431123461042134, 53.817803723471506, 62.64462498256138, 53.671492031642366, 51.22120632444109, 24.810375656400407, 21.747305733816965, 18.672779968806676, 12.685901999473572, 8.207585641316005, 3.5853071681090762, 1.985207383121763, 0.6461636328271457, 0.14551881008914538, 0.23986647171633585, 0.2237292533474309, 0.21773413861436502, 0.19450259235288414, 0.26987017744353836, 0.1862183040274041, 0.30143141959394726, 0.13134193367191724, 0.18990992807916232, 0.261003488940852, 0.23942298122814723, 0.25234103947877884, 0.39877177349158693, 0.30630015262535637, 0.23320461490324565, 0.22465298378041812, 0.4460600460214274, 0.145296006330422, 0.3164513622011457, 0.6475598950471196, 0.3927041505064283, 0.8873185068368912, 1.8008207572357995, 1.3899045096976417, 0.7247578012091773, 0.2871483117341995, 0.2714573251349585, 0.14441148165081227, 0.1043208371847868, 0.12818871358675615, 0.1410745278533016, 0.15489867462643556, 0.451766064124448, 0.7088642311947686, 0.9477364591189793, 2.491103768348694, 8.800920111792427, 17.813487563814434, 21.48345831462315, 36.493599619184224, 60.145330156598774, 73.06743008749825, 69.65444019862584, 63.20672035217285, 54.27113546643938, 31.62399980000087, 31.26914487566267, 24.397268772125244, 32.230462891714915, 35.79263755253383, 55.62011432647705, 64.87903363364083, 69.87939507620675, 77.68741934640067, 78.28445720672607, 80.25730092184884, 69.61627374376569, 43.96728352137974, 30.170332431793213, 10.674410666738238, 0.9748529983418328, 0.11128583630280835, 0.15881789289414883, 0.09040352076824222, 0.12705804354378156, 0.17197235274527753, 0.16215225468788827, 0.09900554668690477, 0.14408924537045614, 0.20709730152572903, 0.18826590558247908, 0.1688795087060758, 0.15869619085320405, 0.0956827878419842, 0.11850053630769253, 0.16467469504901341, 0.11874665452965669, 0.10150111706129142, 0.14082087789263042, 0.16043933374541147, 0.0819912471675447, 0.19569039504442895, 0.14044780576867716, 0.15909181748117718, 0.08982869982719421, 0.20611466068242276, 0.1300959669585739, 0.07806768627571208, 0.11894005058067185, 0.12921416998973914, 0.16438669764569827, 0.11196863930672407, 0.1978334936180285, 0.12803179557834352, 0.14026241643088205, 0.10914897346603018, 0.1350624090326684, 0.12776065298489162, 0.12574654391833714, 0.09131562789635998, 0.11293404536055666, 0.08272776300353663, 0.1610890988792692, 0.19442643358239106, 0.15669364402336733], [0.08868496119976044, 0.019283705690343465, 0.027352509953613793, 0.03390729733343635, 0.012250473090846623, 0.04271557754171746, 0.047829509380140474, 0.03825415211862751, 0.007586919719220272, 0.04560619439663632, 0.04512202573407974, 0.016131238779053092, 0.02577452757395804, 0.012522295915654727, 0.0313843175369714, 0.083566466213337, 0.02642535970413259, 0.031061148270964622, 0.03307252284139395, 0.06775764522275754, 0.08289936450975281, 0.010412688982406897, 0.07553651316889695, 0.018750414485111833, 0.009991223740923618, 0.026276268597160066, 0.042325324911092005, 0.022094257109399353, 0.008050113168012882, 0.015808179774986844, 0.035371474123426845, 0.015733834389331083, 0.02575881439926369, 0.043343615984278064, 0.05338114380304303, 0.04521193162405065, 0.036289118097296784, 0.04532353367124285, 0.26986922749451225, 4.34722295829228, 20.078072241374425, 43.86371367318289, 54.54216732297625, 60.10414818355015, 53.95504106794085, 55.236427852085654, 42.503690651484895, 32.07732459477016, 29.09221693447658, 21.3620593888419, 18.01886589186532, 20.045094353812082, 22.991648197174072, 34.97475119999477, 28.31515645980835, 32.23938437870571, 36.307620661599294, 37.669891425541465, 29.903844697134836, 16.107338292258127, 11.108019948005676, 2.978877080338342, 2.521834347929273, 1.0041055658033915, 0.5641830318740436, 0.32022564538887566, 0.241421782544681, 0.04078120991055455, 0.04223216205303158, 0.025854733805837374, 0.05978292492883546, 0.03918917676700013, 0.03193482656830123, 0.009648637347189444, 0.048374814047877274, 0.09481475834867784, 0.04980844658400331, 0.19359267689287663, 0.16539396931018147, 0.24431334595595086, 0.16460505021469934, 0.06374293672186987, 0.12523800906326088, 0.10549555093582187, 0.04372532246634364, 0.030421771508242403, 0.12949084942894323, 0.049837884825787375, 0.18976949847170285, 0.36491466739348, 0.43829326278397013, 0.06512345692941121, 0.10049850014703614, 0.1271053102931806, 0.17507219926587173, 0.10605712687330586, 0.08677503439996924, 0.139233173802495, 0.07802257048232214, 0.06448830065450498, 0.07039399125746318, 0.021132007939741015, 0.024986295495182276, 0.021044906095734665, 0.051627748246703825, 0.07948831468820572, 0.023409366541142975, 0.06887944681303841, 0.40773237124085426, 1.8811374817575728, 4.867411570889609, 9.256721939359393, 17.226635762623378, 27.6804906300136, 38.41697563443865, 50.77923836026873, 50.31761046818325, 31.53878014428275, 25.148733820234025, 19.430588722229004, 18.536531005586895, 19.96251153945923, 29.151386056627544, 39.43449068069458, 44.99998732975551, 50.516895226069856, 54.25261851719448, 60.807007108415874, 63.525607926504954, 61.42420169285366, 40.399828229631694, 19.455982651029313, 4.441754068647112, 0.35081872663327623, 0.09422633278050593, 0.00858034672481673, 0.04888092314026185, 0.002508783571621669, 0.06311205521758113, 0.01731466152705252, 0.03903554965342794, 0.039676890775029144, 0.003932061663363129, 0.04483233538589307, 0.035995709377207925, 0.08688500457044158, 0.03160043094041092, 0.012483560047777635, 0.007541546930692026, 0.03408471727743745, 0.04412199403824551, 0.05982389487326145, 0.03799472443227257, 0.024550094169431498, 0.06015136944396155, 0.03112192465258496, 0.01594145253433713, 0.00286201321120773, 0.021601533816595162, 0.0283344281571252, 0.08356810148273196, 0.011688245759744729, 0.03563895262777805, 0.010646634286136498, 0.01631873836075621, 0.04635850992053747, 0.030280856748244593, 0.04818466478692634, 0.07460034518901791, 0.04848323715850711, 0.032448151880609136, 0.011720287879662854, 0.0467207085208169, 0.0017348641288533273, 0.06485055014491081, 0.05446280665429575, 0.053753754523183615, 0.04689899698964187, 0.059916297772100995, 0.003495899565418118, 0.057565798184701374, 0.11321035839085068, 0.04120330618960517, 0.013899699951122915, 0.06805111161832299, 0.06287789956799575, 0.028730472084134817, 0.04799147568909185, 0.009877922811678477, 0.02386799853827272, 0.016912181695391024, 0.04179136534886701, 0.007018934594400759, 0.031044646299311092, 0.03437688088576708, 0.025174005422741175, 0.02704966620409063, 0.027178131542833786, 0.06165750005415507, 0.02986755089036056, 0.023604335097063864, 0.01986947140124227, 0.051944786948817115, 0.05095366441777774, 0.02125968617786254, 0.019899114899869477, 0.022733111400157213, 0.031316117982247045, 0.017534740967676044, 0.016225202308435525, 0.03487341245636344, 0.10630754700728826, 0.02498187653587333, 0.04856788779475859, 0.2566158915204661, 6.148528243814196, 25.123466696058, 52.946888719286235, 63.90152631487165, 67.80894306727818, 62.937026023864746, 61.17213494437081, 52.58785792759487, 43.423538344247, 40.96743699482509, 33.45743138449532, 26.762058632714407, 26.515786681856426, 28.071559565407888, 31.493602957044327, 22.666418654578074, 27.26037301336016, 31.34344891139439, 30.40946510859898, 23.90788456371852, 14.092395441872732, 9.220084956714086, 3.784583023616246, 2.542511969804764, 1.0650251997368676, 0.5528963346566472, 0.2357957772910595, 0.2194398942270449, 0.03963370880644236, 0.021482612072889293, 0.14083847909101418, 0.0841801536402532, 0.15031192717807634, 0.10608405114284583, 0.042193963924156766, 0.3457777542727334, 0.3751315591590745, 0.6442704115595136, 0.8565929755568504, 0.75645890299763, 0.49603244023663656, 0.349823424326522, 0.2096704827355487, 0.10309670572834355, 0.20358519069850445, 0.054357277495520454, 0.058480056268828254, 0.25677048893911497, 0.33558032289147377, 1.0187690875359943, 1.2640338752950941, 1.1502664600099837, 0.721987532717841, 0.7249674956713403, 1.2861045024224689, 0.7195184252091816, 0.39211729913949966, 0.40917485526629854, 0.6208739270056997, 0.2860231106834752, 0.8482297871794019, 0.3189681571509157, 0.10245597868093423, 0.07160647226763622, 0.022366171536434973, 0.03598282738987889, 0.10323136778814451, 0.057692826725542545, 0.05044414568692446, 0.32506240585020607, 1.2580298717532838, 3.705973710332598, 10.434459839548383, 16.01335174696786, 23.31163706098284, 32.35242114748274, 37.51866735730852, 40.26461281095232, 29.44826521192278, 25.530358416693552, 22.847103084836686, 25.36824131011963, 31.43280621937343, 37.23052903584072, 49.12003285544259, 51.03600903919765, 57.59279475893293, 60.79552173614502, 68.07689339773995, 73.67877428872245, 73.16601112910679, 50.33846548625401, 25.128203630447388, 6.610007183892386, 0.5158896861331803, 0.06622916366904974, 0.03546760557219386, 0.07602111609386546, 0.027311041285949092, 0.023685338607590114, 0.03404201367603881, 0.03616466459685138, 0.017953744823379175, 0.027925627771764994, 0.041705961538744826, 0.07819235351468835, 0.03623381410060184, 0.02930710810635771, 0.049116686917841434, 0.050832383068544526, 0.0809055572109563, 0.00612368100389306, 0.060929852670856884, 0.023181100575519458, 0.07327633337782961, 0.024714111350476742, 0.027264030683519583, 0.03963272153799023, 0.03627556096762419, 0.0630580031179956, 0.033992799531136236, 0.04669790295884013, 0.039096831543637175, 0.02034094636993749, 0.047064244015408416, 0.040411031738455803, 0.019577504568068043, 0.03828444531453507, 0.04041492313678775, 0.032041146220373254, 0.023728937875213366, 0.03627375267179949, 0.017216518221955215, 0.030024129631263868, 0.029060107788869312, 0.033312439253287654, 0.018866964748927524, 0.17118525212364538, 0.08819099449153457, 0.18469994621617453, 0.04880473044301782, 0.1305209877235549, 0.18371927312442235, 0.1591835825570992, 0.10591035296342202, 0.10550637356936932, 0.09675285113709313, 0.11199905124625989, 0.1421811506152153, 0.10488563616360937, 0.13278023792164667, 0.10430932244552032, 0.1716838125139475, 0.09968615123736006, 0.12137681911034243, 0.13599572038011892, 0.1724214886448213, 0.17015013338199683, 0.07784696561949593, 0.12497491389513016, 0.11970665944474083, 0.06985287993614163, 0.0776685584070427, 0.17852753028273582, 0.12467930332890578, 0.10567771723227841, 0.09440509961651904, 0.1530702534530844, 0.14918374057326997, 0.09960630123636552, 0.13018383724348886, 0.12206987477838993, 0.20216040286634648, 0.1103363690365638, 0.22354729739683016, 0.5529030114412308, 9.64324848992484, 33.95551300048828, 61.87530653817313, 73.56118992396763, 78.87328229631696, 71.79101821354458, 71.2716542652675, 60.33018003191267, 48.33547353744507, 42.28511422021048, 35.07499633516584, 27.083371128354752, 28.331555945532664, 33.77542264120919, 46.56371763774327, 38.86014911106655, 44.11927536555699, 48.63438156672886, 46.665296827043804, 36.70135423115322, 21.304000241415842, 13.96129596233368, 4.477165128503527, 3.35915589758328, 1.7447189390659332, 1.270707620041711, 0.5998684912919998, 0.5212938104357038, 0.21867879506732735, 0.2583367648933615, 0.23979150716747555, 0.2582010036068303, 0.29127977575574604, 0.22193083699260438, 0.17326110787689686, 0.2621225560350077, 0.3166957976562636, 0.5027420116322381, 0.7878653034567833, 0.8288794883659908, 0.8541507380349296, 0.33546888030001093, 0.35940070184213774, 0.3939236950661455, 0.390176173299551, 0.18229038694075175, 0.14001169774149144, 0.42011492965476854, 0.25432198175362175, 0.8445200462426458, 1.8806752094200678, 0.7820182857768876, 0.5848247185349464, 0.7887467475874084, 1.7772925283227647, 1.2360985342945372, 0.3333533709602696, 0.2344777908708368, 0.4220642793391432, 0.22566375668559754, 0.38957968673535753, 0.13417960783200605, 0.21022792639476912, 0.1908487355602639, 0.21125593408942223, 0.16403107744242462, 0.33333092502185274, 0.2916133707123143, 0.1871489148054804, 0.6665399308715547, 2.838073355810983, 6.4148427077702115, 12.30276356424604, 24.26166078022548, 37.441927977970664, 52.46455519539969, 66.30574893951416, 69.50094754355294, 47.14291252408709, 39.0165148462568, 31.126647744859966, 29.71538175855364, 31.891856329781668, 42.440423829214915, 56.04170669828142, 60.496380942208425, 68.07159192221505, 71.59098652430943, 76.7845356804984, 81.63753972734723, 80.88793332236153, 58.58146435873849, 31.40306098120553, 10.00149152960096, 1.3500017651489802, 0.16174498439899512, 0.1202335554574217, 0.172340118725385, 0.0917280414806945, 0.1422037865434374, 0.12201008227254663, 0.099163468927145, 0.1778290191931384, 0.12231578943984849, 0.2133096560303654, 0.14276878908276558, 0.23327917233109474, 0.12248549104801246, 0.0997576756136758, 0.18039241592798913, 0.14926196209021977, 0.21092364192008972, 0.1015156852081418, 0.2006346354527133, 0.17820518543677671, 0.1309056356549263, 0.07633086054452828, 0.1392494993550437, 0.12155212541776043, 0.10665927241955485, 0.21615492978266307, 0.1987501944282225, 0.1078911798873118, 0.11426719703844615, 0.09935544005462102, 0.12256436395858016, 0.11870653953935419, 0.16533284687570163, 0.14948387018271855, 0.21225169779998915, 0.10129965322890452, 0.10890459229371377, 0.07598511981112616, 0.1549748605383294, 0.14084155963999884, 0.13503448053130082, 0.14352228865027428], [0.03362576297617384, 0.028996698691376617, 0.0740078551960843, 0.016298073576763272, 0.07409152534923383, 0.0436167534706848, 0.04128545303163784, 0.02847422333434224, 0.021405289614839212, 0.031131322362593243, 0.011461192675467049, 0.05331675082977329, 0.021208773999075805, 0.029917820157217126, 0.011687276302836835, 0.02579582848453096, 0.011807410927888538, 0.06496192488287177, 0.02783198654651642, 0.0061798446196397495, 0.04135630226561001, 0.032864904696387906, 0.03200898705316441, 0.04764305813504117, 0.01453142792784742, 0.018189613773886646, 0.04904081991740635, 0.03220823886139052, 0.08894414122083358, 0.00546177348587662, 0.02198988146015576, 0.041893610398152044, 0.011312404364746596, 0.05276239789756281, 0.0162917835571404, 0.032666260177003484, 0.040466240740248134, 1.6290743159396308, 6.1212583013943265, 34.36190618787493, 60.71499211447579, 60.53718771253313, 54.15505191258022, 47.330517360142295, 44.665382930210654, 43.71651608603341, 28.35441725594657, 16.300378356661113, 15.883924177714757, 16.155577898025513, 17.452387945992605, 29.926655633108957, 53.10636029924665, 46.8498409816197, 62.537198884146555, 37.44784436907087, 26.51500848361424, 9.209122436387197, 3.1595339349337985, 0.8718235354338373, 0.0728363102035863, 0.16641497452344212, 0.011035852150858512, 0.08493134618869849, 0.03350723647911634, 0.05963000349168267, 0.04514366760849953, 0.02717802976258099, 0.08982337332729783, 0.04350252888564553, 0.0225717150606215, 0.14472803180771215, 0.1007594782859087, 0.0396972468255886, 0.23643151032073156, 0.3285131635410445, 0.3626757732459477, 0.6517453161733491, 0.5420949799673898, 0.3284523668033736, 0.3510066808334419, 0.050093488967312236, 0.1393412101481642, 0.12378173720623765, 0.12399790489247867, 0.025945818650403192, 0.08688429889402219, 0.4981761766331536, 0.49868230947426384, 0.5940451951963561, 0.1669298740369933, 0.37954048972044674, 0.022145505163020322, 0.31083667491163525, 0.29346558132341927, 0.16303874711905206, 0.5731965282133648, 0.21396269170301302, 0.1317528680499111, 0.8437983563968113, 0.7510908224752971, 0.10769169737717935, 0.10019096093518393, 0.04060726745852402, 0.0779089362227491, 0.05074336266677294, 0.019628856098279357, 0.07390752700822693, 0.050795447014804394, 0.01877454827938761, 0.05933982799095767, 0.05286764207163027, 1.5921430119446345, 9.719123687062945, 15.242982387542725, 22.695660148348125, 30.82119103840419, 47.35362706865583, 48.4178409576416, 37.03086560113089, 19.299272980008805, 15.748585428510394, 19.340998649597168, 21.175528049468994, 28.821546384266444, 36.40601062774658, 46.810614926474436, 55.81403507505144, 61.69698102133614, 60.30682018824986, 64.45103849683488, 53.39540188653128, 36.138414655412944, 16.495721748897008, 2.736813349383218, 0.04109770917732801, 0.1105081130351339, 0.029581972464386905, 0.05059405782126954, 0.034638459528131146, 0.07395602190600974, 0.04640630253457597, 0.08155568196837391, 0.04519432024764163, 0.03556092788598367, 0.018680074152403643, 0.027283197601458857, 0.03328710954104151, 0.009748123303454901, 0.09188932925462723, 0.007750471255608967, 0.05761806573718786, 0.027961975196376443, 0.027166808489710093, 0.02038976696452924, 0.04092859789463026, 0.06279619038105011, 0.05892935501677649, 0.018023898558957235, 0.06669617896633488, 0.030934302934578488, 0.05171729112043977, 0.0068939484439657205, 0.05566861427256039, 0.0688337746209332, 0.02739075557993991, 0.02988797818709697, 0.019406208402610252, 0.026394075847097805, 0.03996961417474917, 0.08839308936148882, 0.03324821252109749, 0.03840820670926145, 0.029627396991210322, 0.09142408493374075, 0.04991865424173219, 0.022944595498432006, 0.027900935882436376, 0.03090311407244631, 0.03788998915946909, 0.04975842158975346, 0.033013663321201286, 0.03367949616430061, 0.028779384280954088, 0.008431801838534219, 0.040958853771111796, 0.019231919897720218, 0.0031671824274651173, 0.020617615631116287, 0.04718068062460848, 0.03202684270218015, 0.0433734172422971, 0.050651529737349064, 0.08752148398863417, 0.036514150843556435, 0.045146449602075985, 0.01982518850958773, 0.010706760122307708, 0.0479890397483749, 0.03427873418799468, 0.027841306224997555, 0.0273152040982885, 0.04744844750634261, 0.018486209912225604, 0.0448128444674824, 0.07648076928619828, 0.017334249136703353, 0.04635986020522458, 0.009017175695459758, 0.037822393500911336, 0.03298793327329414, 0.07582358776458673, 0.06915643159300089, 2.103632479906082, 8.74785237652915, 41.803322655814036, 70.1133895601545, 69.92364815303257, 62.3565457207816, 56.218673842293875, 53.71745783942086, 52.324646268572124, 40.33565466744559, 27.98758884838649, 25.36546724183219, 23.694859743118286, 23.49770634514945, 27.99190194266183, 45.70370783124651, 42.09138454709734, 48.68556547164917, 32.556336879730225, 19.69750029700143, 6.835548749991825, 2.760117390326091, 0.8448199587208884, 0.1340283623763493, 0.06554607568042618, 0.017674812647913183, 0.06413145230284759, 0.08273429051041603, 0.010578057296308023, 0.0826748169160315, 0.32124507640089306, 0.2548505605331489, 0.37421092284577234, 0.5302506898130689, 0.7386898079088756, 0.6843849133167947, 0.4442586712539196, 0.7928379337702478, 1.2772545601640428, 2.215969434806279, 1.4200643599033356, 1.8295996529715401, 1.7376382904393333, 1.1972951250416892, 1.096124142408371, 0.444389709936721, 0.33772452069180353, 0.2998055954064642, 0.20514157361217908, 0.6257067248225212, 1.9847160152026584, 2.8978326405797685, 3.016284227371216, 1.9126755722931452, 2.1604950172560553, 0.8587369833673749, 2.2336599826812744, 1.2027722597122192, 1.5153009295463562, 2.282725989818573, 1.4191099596875054, 0.6363958226782935, 2.618538724524634, 3.081443348101207, 0.387375425015177, 0.11739928754312651, 0.1660473035382373, 0.16121317579277925, 0.04885295392679317, 0.08300664089620113, 0.08339867128857545, 0.045838945478733094, 0.08029362718973841, 0.13774240522512368, 0.08200075344315597, 0.774838136775153, 7.2227983474731445, 12.48990113394601, 23.913960763386317, 28.543670552117483, 41.2831631387983, 38.49952718189785, 32.43957935060774, 19.592804840632848, 16.08310123852321, 28.088747671672277, 32.57798746653965, 37.639750140053884, 46.67238746370588, 55.89818123408726, 67.79276071275983, 69.17806475503104, 67.34945869445801, 73.10177503313336, 65.09598418644497, 44.21108538763863, 22.804630483899796, 4.225699833461216, 0.09892341002289738, 0.045658268566642485, 0.01652167970314622, 0.0131343599475388, 0.04361359489017299, 0.024738993229610578, 0.02476770883159978, 0.03101793916097709, 0.028027156966605356, 0.02878794400021434, 0.02309682482986578, 0.07797235210559197, 0.04462336356352482, 0.01723159696640713, 0.082797563900905, 0.01786468201316893, 0.05042092621858631, 0.02207126495029245, 0.0556890924594232, 0.01476510351390711, 0.020090037690741674, 0.017293618459786688, 0.01987306254782847, 0.022218763196308697, 0.06232670521629708, 0.05240748676338366, 0.023005597492946044, 0.014456495609400528, 0.035599071732056994, 0.034423747299505134, 0.04521963299651231, 0.06557276246270963, 0.014849503092201692, 0.05405624882717218, 0.009214360516385307, 0.050536053255200386, 0.010799775399001581, 0.06536771596542426, 0.07017215101846627, 0.01315832750073501, 0.013564235630578228, 0.09853503693427358, 0.15232607695673192, 0.11128654197922774, 0.10741611716470548, 0.2701604275831154, 0.1679694846804653, 0.12473649026027747, 0.13667922227510385, 0.1344593542494944, 0.13907113964004175, 0.1752026001257556, 0.14702787197061948, 0.1382757473204817, 0.17435437706964357, 0.13714450730809144, 0.16178845135228975, 0.10895050875842571, 0.20891395690185682, 0.11980668907718998, 0.08965207716184002, 0.1450865018580641, 0.09811558694179569, 0.13998347068471567, 0.11188545091343777, 0.07970009225287608, 0.14798525774053164, 0.123535564701472, 0.1772685492677348, 0.1902599978659834, 0.14312290293829782, 0.08885278326592275, 0.190275373469506, 0.09301678304161344, 0.1418945374233382, 0.08554771382893835, 0.1928021835961512, 0.2349279581436089, 3.0273537933826447, 14.522426400865827, 52.525202546800884, 78.63550799233573, 78.92695713043213, 72.96242196219308, 65.61696706499372, 62.08004215785435, 60.230730465480256, 41.85429464067732, 27.68842199870518, 24.94945079939706, 24.528374331338064, 28.13276277269636, 39.46241201673235, 62.78127520424979, 59.49836948939732, 78.5716609954834, 47.935531752450125, 35.672895772116526, 12.474115695272173, 4.203228056430817, 1.2935408119644438, 0.3456421558346067, 0.32460732598389896, 0.12208442256918975, 0.2347273017678942, 0.2131326805268015, 0.17644442777548516, 0.1313721149095467, 0.2553868203290871, 0.226224403030106, 0.34325867944530075, 0.43719026339905603, 0.44588406117899076, 0.32893323100038935, 0.3710741368787629, 0.6341653423649924, 0.733229392341205, 1.857890546321869, 2.5773537116391316, 1.3679645955562592, 2.057563751935959, 1.6679584980010986, 1.0762336211545127, 0.3022321451987539, 0.5051588448030608, 0.7348864291395459, 0.22968950495123863, 0.4321792280035359, 2.0924999458449225, 1.695182842867715, 2.0774890141827718, 1.6781107932329178, 1.0029353371688297, 0.4183874066386904, 0.9308823006493705, 0.8131412757294518, 1.0049364183630263, 1.5334954389504023, 0.8594761522752898, 0.6721417531371117, 1.4037455384220396, 1.0016491604702813, 0.2289946579507419, 0.1923350529479129, 0.15399786510637828, 0.1517871165914195, 0.21140333903687342, 0.2862347864678928, 0.4060190160359655, 0.1445967759937048, 0.17085343492882593, 0.26940692801560673, 0.3686509526201657, 2.654549066509519, 12.47261575290135, 21.09367479596819, 32.84720584324428, 41.844431672777446, 61.506933893476216, 63.59165055411202, 52.04600960867745, 30.981232370649064, 24.627342735018047, 31.781063829149517, 34.31492246900286, 44.384675707135884, 54.30482380730765, 64.65913009643555, 75.57589653560093, 79.9010181427002, 77.31090341295514, 82.5628660746983, 75.35083743504116, 54.27559273583548, 30.094527585165842, 5.825123471873147, 0.24191078916192055, 0.18684391331459793, 0.158177111563938, 0.16436009907296725, 0.1394036082284791, 0.18245765939354897, 0.13199486077896186, 0.16819596609898976, 0.12034828215837479, 0.11761031193392617, 0.1227225304714271, 0.1286401700760637, 0.11484957007425171, 0.09677396714687347, 0.17712403487946304, 0.08945718154843364, 0.15600993856787682, 0.1562443995582206, 0.1948682005916323, 0.090474319112088, 0.14105240761169366, 0.1157220575426306, 0.12813027815095016, 0.10625204284276281, 0.09645090305379458, 0.15023670478590898, 0.1375559845141002, 0.13738956701542648, 0.15090829160596642, 0.1789664745862995, 0.10095106943377427, 0.16556322308523314, 0.13681482071323053, 0.15013770652668817, 0.11208140504147325, 0.12487246867801462, 0.06871898006647825, 0.10612245622490134, 0.2062665575316974, 0.2188329446528639, 0.1074175624442952], [0.04301083526973214, 0.054720809417111535, 0.02012572863272258, 0.08184785914740392, 0.02476192601690335, 0.04619230276771954, 0.026895445372377123, 0.011383317211376769, 0.09300667965518576, 0.049198365570711236, 0.03685645140441401, 0.05787884710090501, 0.03616840332480414, 0.013976526230440607, 0.04168963259352105, 0.05970938530351434, 0.05358124038736735, 0.04153404112106987, 0.016053219126271348, 0.04136078059673309, 0.012019441246853342, 0.0180914399347135, 0.03188183976869498, 0.0595988587343267, 0.09729801331247602, 0.038879350892135074, 0.06530182342976332, 0.07074991680149521, 0.058158885288451395, 0.0789837764043893, 0.09574643442673342, 0.09342734422534704, 0.03039645536669663, 0.046059554176671166, 0.013895365808691298, 0.4434731719749314, 3.0539679995604923, 17.806115525109426, 38.23179571969168, 57.58396012442452, 60.370034899030415, 53.14539180483137, 48.73541184834072, 43.715029171534944, 31.674620900835308, 21.93375369480678, 16.560124601636613, 19.152275153568812, 22.707822969981603, 21.071708066122874, 21.087794882910593, 38.358576025281636, 48.95461014338902, 35.900890486580984, 13.77553847857884, 3.3827658763953616, 1.2683583689587457, 0.16923060986612523, 0.0360384435126824, 0.03643495562885489, 0.1149289043886321, 0.0439840410836041, 0.11051939707249403, 0.009556124186409371, 0.08662582454936844, 0.04523209768480488, 0.016897727203156267, 0.05726922409875052, 0.1908764469304255, 0.49848005175590515, 0.19639414442437036, 0.9742996394634247, 0.8600447103381157, 0.061893765947648456, 0.7299726413828986, 2.295161093984331, 1.720825929726873, 1.5734388956001826, 0.879681296646595, 0.4321246195052351, 0.2872242262320859, 0.08658942793096815, 0.2045589427330664, 0.0733600306723799, 0.04797018326020666, 0.07815373130142689, 0.7873244839055198, 1.6829644356455122, 3.2592041066714694, 2.0676638271127428, 3.6333159634045193, 2.2216333023139407, 1.8213227199656623, 1.648223659821919, 0.30015626230410164, 1.7352381220885684, 2.1656974809510365, 2.147739210299083, 0.6233452058264187, 7.339565430368696, 9.328350918633596, 0.9815773346594402, 0.08545045261936528, 0.145078020170331, 0.057407421325998645, 0.08754227430160556, 0.09711864258029632, 0.04270846988739712, 0.06630815871592079, 0.09631658704685313, 0.04038258415779897, 0.11848700631942068, 0.06926769776535885, 0.07459085248410702, 0.16692300726260456, 1.7541962819440025, 8.305437990597316, 18.35359362193516, 37.1922653062003, 47.32455927985055, 47.22731229237148, 43.03182322638375, 18.771430492401123, 15.421526772635323, 13.98074918133872, 13.565649032592773, 23.153457845960343, 28.247529642922537, 45.08192048754011, 55.73188999720982, 57.08975212914603, 65.81509494781494, 64.4335081917899, 55.77891193117414, 24.384383337838308, 4.078308131013598, 0.4754931852221489, 0.006028878211509436, 0.09461794926651887, 0.015473609424329229, 0.10343946090766362, 0.0067458225530572236, 0.03901540055604918, 0.0234242383324142, 0.028657305653073957, 0.03719357813575438, 0.029100589188081876, 0.01955309766344726, 0.020952437039730803, 0.05775608654533114, 0.04212355573794671, 0.04274724137836269, 0.06610185692885093, 0.04174879066912191, 0.005649714539426246, 0.060679846443235874, 0.018795377608122568, 0.027535539685881565, 0.03832527955195733, 0.031088547515017644, 0.03009745551805411, 0.021911632801805223, 0.02801259051609252, 0.045157845597714186, 0.023921597715733305, 0.11197298193084342, 0.04724856126787407, 0.02973154533122267, 0.017490385133506994, 0.054283232361610444, 0.06742985174059868, 0.047048352725271664, 0.015537556260824203, 0.04119261587038636, 0.007955902821517416, 0.01847105992159673, 0.08147161147956337, 0.023276589112356305, 0.03524758041437183, 0.0525369885643678, 0.02586946140841714, 0.02673877333290875, 0.007436476631223091, 0.009469291211904159, 0.033494768398148675, 0.10173093687210764, 0.04582110679309283, 0.07196578370141131, 0.03607525403744408, 0.010893453943676181, 0.06819542244608913, 0.0811782536496009, 0.06481839437037706, 0.06972142056162868, 0.00936811909611736, 0.0710752404161862, 0.018584502495027015, 0.049465246964246035, 0.012280317605473101, 0.12445462681353092, 0.067691549126591, 0.11526111513376236, 0.02804704991701458, 0.039278309127049785, 0.05497002854411091, 0.02046646686669971, 0.024036253170509423, 0.04613246615710003, 0.06034800210701568, 0.02289434489128845, 0.03152977169624396, 0.40207822035465923, 4.079914901937757, 21.370251314980642, 47.42046179090227, 66.4481453214373, 68.45793955666679, 61.97479084559849, 58.92041833060128, 52.08726453781128, 42.533943108149934, 33.27313041687012, 26.70881632396153, 25.952164445604595, 29.078895500728063, 27.561669485909597, 20.864083732877457, 28.69274067878723, 42.418985162462505, 33.53286450249808, 14.344342333929879, 4.260952387537275, 1.1893439974103654, 0.1613878578479801, 0.05101399635896087, 0.014065460967166083, 0.0462544735388032, 0.008396171116536217, 0.19937585799821786, 0.1103428965434432, 0.12517677806317806, 0.32269857983504024, 0.621549585035869, 0.4987530399646078, 0.9040410295128822, 1.802741174186979, 3.0856756695679257, 3.0241832435131073, 3.425614331449781, 2.0183887226240973, 2.9991380274295807, 5.216311020510537, 4.3820677399635315, 3.962202864033835, 6.41630573783602, 3.5575938437666212, 2.269706585577556, 2.2571941827024733, 0.8405282518693379, 0.23630554707986967, 0.17252136899956635, 0.32651471506272045, 1.3974387454135078, 2.5623670986720493, 2.9000847254480635, 4.5855713571820935, 6.953383684158325, 6.530868938991001, 5.550490277154105, 4.042332095759256, 3.8986759185791016, 4.299019830567496, 5.6720946090562006, 2.726906955242157, 3.7949275885309492, 5.025766662188938, 8.543553624834333, 2.7184412266526903, 0.762590579688549, 1.4956442586013248, 0.3825756854244641, 0.8818565170679773, 0.4775525118623461, 0.21695114991494588, 0.22679069478596958, 0.25446105429104393, 0.054045575471328836, 0.12648130234863075, 0.03162053593301347, 0.0724759538258825, 0.028747235291770527, 1.0725423906530653, 6.283257722854614, 17.931337697165354, 34.35058757237026, 43.087943826402935, 35.40458760942732, 40.19562414714268, 27.575190680367605, 25.278043270111084, 26.513575417654856, 23.92775641168867, 38.832818371909006, 39.03223167146955, 55.586227961948936, 65.39553492409843, 63.6738338470459, 73.83797141483852, 73.22952461242676, 65.505615234375, 33.628638471875874, 8.625097683497838, 0.7836144172719547, 0.03540265280753374, 0.14173445744173868, 0.03607969165646604, 0.017333911565531577, 0.042852811249239106, 0.05514017798538719, 0.016346685521836792, 0.0033558380632062574, 0.04115254159218498, 0.03446098869400365, 0.032232530415058136, 0.03853361355140805, 0.023928191379777024, 0.05843150708824396, 0.054229733268065114, 0.04131190571933985, 0.04708026083452361, 0.03729456789525492, 0.035929277406207154, 0.0471608402606632, 0.03602309844323567, 0.020139144966378808, 0.023748026761625494, 0.007830150774680078, 0.04712250642478466, 0.036864658285464556, 0.05882020587367671, 0.011108985503337212, 0.023755059777093784, 0.021390960651582906, 0.030420712993613312, 0.10951703121619565, 0.03369946884257453, 0.04054616877276983, 0.010845763958059251, 0.03889229394761579, 0.10776042618921824, 0.035248228415314636, 0.04489886235179646, 0.14953820726701192, 0.18722781485744885, 0.12946425085621222, 0.27234525606036186, 0.08411862408476216, 0.11182405706495047, 0.15848649639104093, 0.1320806954588209, 0.23546497789876802, 0.17589642932372435, 0.11040131840854883, 0.2441380667899336, 0.09643655882350036, 0.07802797840642077, 0.15685748308897018, 0.13524808335517133, 0.15640613516526564, 0.16205295787325927, 0.047168684125478776, 0.20743065220969065, 0.1339171640574932, 0.1369293574243784, 0.0708759343251586, 0.1437072708670582, 0.18291899535272801, 0.23572412399309023, 0.1311095489987305, 0.13491081073880196, 0.15034731956464903, 0.13524159656039306, 0.1751309061156852, 0.23416094215852873, 0.13732925882296904, 0.1547155515956027, 0.13528544349329813, 0.6947452202439308, 5.482258532728467, 29.152525561196462, 60.157197679792134, 75.16125583648682, 77.5450577054705, 71.02638980320522, 67.20857007162911, 59.00924410138811, 47.15356758662632, 36.53968702043806, 26.764566932405742, 26.591603687831334, 32.32128626959664, 31.31556579044887, 32.74310098375593, 51.8329187801906, 61.71724891662598, 45.64895255225045, 17.911196606499807, 4.890294594424112, 1.8317614112581526, 0.5537909152252334, 0.22609534566955908, 0.10380285033690077, 0.35690524003335405, 0.14288514426776341, 0.34546646954757826, 0.23634707342301095, 0.2490661580647741, 0.19063370781285421, 0.34030925056764055, 0.20449483474450453, 0.6580895643149103, 1.7279961449759347, 3.0822619327477048, 2.5442696469170705, 3.2216671151774268, 1.4386296208415712, 3.5644716918468475, 5.693411248070853, 6.211770747389112, 4.185531863144465, 5.55510561806815, 4.8045260310173035, 2.588816068002156, 2.0116774141788483, 0.5561759929571832, 0.2977205387183598, 0.3513309662895543, 0.3224562885505812, 3.4775760003498624, 7.183894949299948, 11.113471678325109, 6.341225675174168, 9.049286076000758, 7.814691935266767, 7.043923922947474, 3.4197001116616383, 3.1842816812651495, 2.9956519859177724, 5.808553321020944, 3.0757547276360646, 4.519207375390189, 16.740235805511475, 14.422172580446516, 3.8146926079477583, 0.5106398335524968, 0.9659955650568008, 0.1692323876278741, 0.8003720609205109, 0.28008527787668364, 0.7800400033593178, 0.3000304347702435, 0.7444457933306694, 0.10038352238812617, 0.22813346130507334, 0.10467094089835882, 0.14046554267406464, 0.39895687784467426, 2.8335726601736884, 10.742222479411534, 25.861047506332397, 48.20939152581351, 62.6901148387364, 63.02783203125, 60.636380195617676, 28.993033136640275, 25.01066095488412, 25.4985408782959, 24.33253414290292, 37.02404941831316, 43.13260337284633, 63.50742449079241, 73.84808104378837, 72.22488457815987, 83.56644998277936, 82.2462158203125, 76.97456196376255, 46.70830617632185, 14.15592282158988, 1.8771248970712935, 0.12356988500271525, 0.16303429592932972, 0.06501499989203044, 0.23330541806561605, 0.07619794231972524, 0.20409823102610453, 0.13159185168998583, 0.09329904003867082, 0.16399678428258213, 0.09356940231685128, 0.09286392267261233, 0.08627711183258466, 0.11709894080247198, 0.1219336928001472, 0.14169341964381083, 0.09220569620707206, 0.11305872617023331, 0.14851264229842595, 0.14354379821036542, 0.07703003659844398, 0.21079961928938115, 0.10219360275992326, 0.08948112704924174, 0.0710203672892281, 0.13560727265264305, 0.18505327297108515, 0.2176085824945143, 0.06774929245667798, 0.1920232389654432, 0.11434906907379627, 0.1326606257685593, 0.12885930974568638, 0.17010011178042206, 0.2189017752451556, 0.1398637771074261, 0.13319985754787922, 0.18992368876934052, 0.16772411284702166, 0.1434568643037762], [0.033765405483011685, 0.010773398198320397, 0.028302175691351295, 0.01611242809199861, 0.03485755170030253, 0.02437346980773977, 0.03252164740115404, 0.03956967545673251, 0.05768626529191222, 0.07318304159811564, 0.046177721050168784, 0.028643999581358263, 0.015269093880695956, 0.05416244634294084, 0.04709641336064253, 0.03636549399899585, 0.056709215577159605, 0.012829450058883854, 0.055319094099104404, 0.020127645494150262, 0.04472868237644434, 0.06738215751413788, 0.051494073455355, 0.09835667721927166, 0.049304715756859095, 0.03034410299733281, 0.019151464304221526, 0.07229609454848937, 0.018261745439044068, 0.045235103594937494, 0.03217699571645685, 0.04345186946115323, 0.08597658188747508, 0.014647723741031118, 0.2902872147304671, 3.2638127165181294, 26.884225334439957, 45.856863498687744, 61.93547098977225, 61.6359133039202, 51.303136008126394, 45.13301753997803, 31.727062429700577, 33.62582792554583, 22.04137086868286, 18.24312421253749, 16.24927088192531, 16.643447399139404, 27.3028073992048, 31.13244949068342, 43.47570889336722, 45.28923041479928, 21.262086970465525, 5.478570776326316, 1.5503848812409808, 0.18955893548471586, 0.14079613850585052, 0.03112393311624016, 0.07410356934581484, 0.0020567694113456775, 0.03459916217252612, 0.06097169114010675, 0.025325720763898323, 0.05400947401566165, 0.36717739169086727, 0.11098016984760761, 0.4293826052120754, 0.13817019441298076, 1.1125375245298659, 1.996556396995272, 2.512236931494304, 3.0924171592508043, 3.4473024819578444, 1.4601948750870568, 1.8228638087000166, 4.04363488299506, 2.599039907966341, 2.168131956032344, 6.218949973583221, 3.410612085035869, 1.6222824518169676, 1.5530918559857776, 0.9841411113739014, 0.24158590659499168, 0.09765402706606047, 0.6422045709831374, 1.5428988486528397, 1.5379613935947418, 5.604247621127537, 6.594648625169482, 3.698921723025186, 7.0163408773286005, 4.320930974824088, 7.524351034845624, 3.299901225737163, 7.621263640267508, 5.496682558740888, 3.895934419972556, 1.7032407990523746, 2.451916362558092, 14.622534309114728, 0.8691927194595337, 0.9699380163635526, 1.7430738444839204, 0.725224144756794, 0.18418294324406556, 0.33772093802690506, 0.07289847079664469, 0.681197318647589, 0.14534663861351355, 0.1315155979245901, 0.10251787464533534, 0.05682582860546453, 0.27220775772418293, 0.029739650432020426, 0.19013759014861925, 0.1295586350773062, 1.0118960163422992, 4.239129832812718, 16.62097692489624, 43.068513189043315, 48.73435224805559, 38.717926434108186, 25.301753997802734, 18.24494116646903, 19.516755070005143, 10.89132387297494, 17.778034380504064, 26.83096044404166, 33.144776344299316, 40.11330883843558, 48.8092850957598, 59.55820042746407, 59.63343552180699, 49.96125820704869, 30.371722493852886, 5.785864847046988, 2.760751847709928, 0.263054293181215, 0.08092413549976689, 0.07225553851042475, 0.02593421739792185, 0.0362803717809064, 0.026049403806350062, 0.04211350663432053, 0.010174260258541575, 0.0739549905327814, 0.03866790920229895, 0.04824565490707755, 0.04846769870658006, 0.033112569978194575, 0.09480793907174043, 0.053844060748815536, 0.02530835535643356, 0.03896994549514992, 0.046823455686015744, 0.0029625392344314605, 0.044956154456096034, 0.02960625384002924, 0.05928129077489887, 0.018460269518462673, 0.03568601242399641, 0.06963925675622054, 0.07452133657144648, 0.06221133390707629, 0.09596278531742947, 0.007129927232329334, 0.05288794044671314, 0.04446529543825558, 0.024581398382516842, 0.018735922673451047, 0.010862933438537377, 0.0041963374824263155, 0.05751011760107108, 0.04011712768780334, 0.01739235039401267, 0.026829099914591228, 0.01158495237385588, 0.022547689831948707, 0.04173462625060763, 0.023829094732978513, 0.017464577054072703, 0.028419820092884556, 0.02894218179530331, 0.05514962997819696, 0.04321866715326905, 0.05416607650529061, 0.008988607674837112, 0.011224233828085874, 0.04597885261422821, 0.02963421626814774, 0.020937982547496046, 0.057892824922289164, 0.011408172797278633, 0.015376811314906393, 0.03435831616765686, 0.018138304652114, 0.05700163024344614, 0.010592605935276618, 0.03109019635511296, 0.01244971132837236, 0.026466884350936328, 0.01741661480627954, 0.06337126238005501, 0.0554134783201984, 0.01566300381507192, 0.043893585580268075, 0.044062849533345015, 0.07928421135459628, 0.0515469856161092, 0.28693883440324236, 4.208544731140137, 33.201268672943115, 54.023793492998394, 69.66127027784074, 69.70525237492153, 59.640362875802175, 52.309460980551584, 42.36675555365426, 43.833231925964355, 31.170438766479492, 26.118334089006694, 22.12022250039237, 21.422242947987147, 24.405707359313965, 25.715213503156388, 34.68059573854719, 39.16304888044085, 20.70670529774257, 5.991885449205126, 1.127638348511287, 0.16705616297466414, 0.07685082871466875, 0.028327983770785586, 0.09738309481846434, 0.02483682271226176, 0.053659224417060614, 0.13461879640817642, 0.22839125032935823, 0.7534551641770771, 1.2470639858927046, 1.6543994141476495, 2.4398592838219235, 2.9175440285887038, 4.012870865208762, 4.342782625130244, 6.104289497647967, 7.008736942495618, 5.9780950120517184, 4.851359060832432, 6.489316540105002, 6.798442763941629, 5.913832860333579, 6.064347778047834, 7.688788839748927, 3.5667771909918105, 4.306002335888999, 2.8922964462212155, 0.975446526493345, 0.3145881321813379, 0.23764557231749805, 0.6065758913755417, 1.4745184779167175, 1.088722356728145, 2.1542548835277557, 2.004264337675912, 4.417374576841082, 7.658874239240374, 8.676647237368993, 11.385910545076642, 8.078076430729457, 10.309279356684003, 9.128353970391409, 4.276669647012438, 5.871830565588815, 7.389418755258832, 8.842099479266576, 3.279005821262087, 1.5649480883564268, 2.9616774661200385, 1.2930200227669306, 1.8298239495073045, 0.9079209470323154, 1.9056806904929025, 1.129476472735405, 0.4850209025400025, 0.6879183437143053, 0.4919199209128107, 0.28878301115972654, 0.16231614803629263, 0.05148048918428166, 0.11997214305613722, 0.039785737970045636, 1.2639434401478087, 4.3318474633353095, 16.58875812802996, 39.344344752175466, 46.82749210085188, 27.014549221311295, 20.972095217023575, 21.7554247038705, 22.40286479677473, 19.81183637891497, 26.893940653119767, 40.218369075230186, 42.32485096795218, 48.25573253631592, 57.43659578050886, 65.64917891366142, 68.91868155343192, 61.92970398494175, 47.57693869726998, 18.579743589673722, 5.568341502121516, 0.7363764920404979, 0.08846451195755176, 0.050862367531018596, 0.04068487150860684, 0.044365350622683764, 0.006709452651973281, 0.012191633926704526, 0.048686183589909754, 0.05227024966318693, 0.03259312767269356, 0.0548587318376771, 0.054044357500970364, 0.016965517940531884, 0.020149954029225876, 0.045423380099236965, 0.015284008080405849, 0.06284440029412508, 0.11009635762976748, 0.0303011856574033, 0.016662837039413195, 0.015197087744516986, 0.01741514747430171, 0.057870792890233655, 0.010146984847129455, 0.07607857443924461, 0.02733574335330299, 0.028323220454954674, 0.12386227931295123, 0.08788698366177933, 0.043294903955289295, 0.12265384915683951, 0.06092061780925308, 0.03362472142492022, 0.023548444167577794, 0.012346775869705846, 0.03849279967003635, 0.0461614972778729, 0.03046243611191, 0.12028578908315726, 0.12793068028986454, 0.12030609085091523, 0.08313801206116166, 0.11437559979302542, 0.25066741928458214, 0.12772686194096292, 0.08234901154147727, 0.20032368999506744, 0.2216011503977435, 0.11508685377027307, 0.08428223244845867, 0.08294887042471341, 0.11074285222483532, 0.11514732481113502, 0.06409584278506891, 0.16973735338875226, 0.15836830916149275, 0.1118219807477934, 0.14841117417173727, 0.0710052020315613, 0.12370169721543789, 0.18120101253901208, 0.1412017803106989, 0.18816519741501125, 0.1314138448131936, 0.09961879985140902, 0.12798763651932987, 0.14887614707861627, 0.14827177593750612, 0.18396435997315816, 0.14293345596109117, 0.19157676292317255, 0.1258463157074792, 0.4924292021564075, 6.48294243642262, 42.07738045283726, 64.74144540514264, 78.43050139290946, 77.70713138580322, 69.07908071790422, 60.93247767857143, 47.8640695299421, 47.09325722285679, 32.66213015147618, 28.067988191332134, 24.994155509131296, 24.289934737341746, 39.21661254337856, 41.322913782937185, 55.01992893218994, 56.34305007117135, 27.926561083112443, 7.817889843668256, 2.2173256363187517, 0.47757227080208914, 0.3287640857909407, 0.15514441286878927, 0.3868325155760561, 0.17675161414912768, 0.2414620061005865, 0.18848841078579426, 0.18660548967974527, 0.4401249273547104, 1.7316891125270297, 1.042692278112684, 2.0002120179789404, 3.7739327379635403, 3.6558038081441606, 5.321052074432373, 7.8865441254207065, 10.947152648653303, 7.586459245000567, 7.663145644324167, 6.75672664812633, 12.89697698184422, 12.433018837656293, 9.783737591334752, 13.108771971293859, 7.1916725890977045, 5.80023068189621, 2.809951824801309, 1.532782488635608, 1.1262729189225604, 0.6729763512100492, 2.2560757398605347, 5.617810070514679, 9.966940743582589, 16.326381989887782, 16.114241327558243, 10.737537656511579, 17.41635285105024, 14.422065751893179, 18.513136420931133, 11.565788984298706, 18.38619978087289, 16.102297374180385, 13.737461481775556, 10.02626359462738, 13.485585808753967, 30.587224347250803, 10.042405997003828, 3.0095852954047064, 4.5520428248814175, 2.5309456075940813, 2.1553911311285834, 0.7996814208371299, 1.7435753090041024, 2.2297655173710416, 0.6805172094276973, 1.1017865985631943, 0.6380708813667297, 0.44851303153804367, 0.5288605615496635, 0.12674677238932677, 0.42974803703171865, 0.38530765739934786, 2.399810301406043, 6.343641911234174, 23.381549835205078, 54.28054332733154, 61.867475918361116, 53.3086953163147, 39.07743665150234, 28.89766389983041, 27.779377392360143, 18.346725327628, 27.646534783499582, 41.18859468187605, 48.44149957384382, 55.223893301827566, 66.1565294265747, 75.00783266339982, 77.57766560145787, 72.45572457994733, 70.44536754063198, 34.47699614933559, 9.663838607924324, 0.7973479117665971, 0.25516024391566006, 0.19223034142383508, 0.15525601830865654, 0.07543827486889702, 0.15370785923940794, 0.18393681145140103, 0.09879981486925057, 0.13829697189586504, 0.11528229899704456, 0.20477535469191416, 0.1752552544432027, 0.1271841289209468, 0.10336801795555012, 0.26728539328489986, 0.16539407787578447, 0.2035175407571452, 0.11073684718992029, 0.09125069209507533, 0.0927629227350865, 0.09831195497619254, 0.1040599811822176, 0.13716665469110012, 0.06340750972075121, 0.16440117758299622, 0.14056728221476078, 0.16491229087114334, 0.1898127482937915, 0.15958712090338978, 0.1777838694729975, 0.22421766285385403, 0.10942266056580202, 0.06831597776285239, 0.1485331340559891, 0.11778772169990198, 0.14790820330381393, 0.24553655460476875, 0.11199988584433283], [0.03826043874557529, 0.025773017833541547, 0.00542866055288219, 0.015194147991548692, 0.03746719738202436, 0.05316363940281527, 0.12826481807444776, 0.0802138043301446, 0.013475170275861663, 0.07114184541361672, 0.06718918215483427, 0.037731551232614687, 0.0763349181839398, 0.02449365532291787, 0.08373924837048564, 0.007822077056126935, 0.04338268603065184, 0.054133859662605185, 0.038008332452071567, 0.0369931083571698, 0.04307063456092562, 0.041084752551146915, 0.09409056470862456, 0.05800875263022525, 0.0574287816083857, 0.07315927930176258, 0.011111104228932942, 0.0764589204585978, 0.009980227232777646, 0.02071268856525421, 0.04998493354235377, 0.02943580923601985, 0.03239016427791544, 0.14968603290617466, 2.696346172264644, 26.5032034942082, 57.32716512680054, 64.56471797398159, 62.420927728925435, 50.28739970070975, 40.07291896002633, 38.20461436680385, 33.6433756010873, 24.80389472416469, 18.54817271232605, 13.351424779210772, 31.30351413999285, 38.90197031838553, 47.980055809020996, 62.86850983755929, 40.72757475716727, 14.131234134946551, 2.653419549976076, 0.24238182817186626, 0.00291322182498074, 0.03646750156102436, 0.08190645064626421, 0.09187934121915273, 0.00756914888708187, 0.12275472017271177, 0.28915791532823015, 0.056729554664343596, 0.5748410799673626, 0.09286735605980669, 0.03915082936042121, 1.6329575989927565, 3.1561206323759894, 3.31096818617412, 4.19235325711114, 3.6566745042800903, 5.494265454156058, 5.421445293085916, 7.912701487541199, 4.684073797294071, 4.4235076648848395, 6.282476050513131, 3.3381664752960205, 5.039309569767543, 10.293001464435033, 3.2325375718729834, 4.313013068267277, 5.41019572530474, 3.3338169029780795, 0.493260814675263, 0.703979104757309, 0.2746961627687727, 2.6786832000528062, 5.483527881758554, 8.012884088924952, 7.840340341840472, 4.958971892084394, 5.514945030212402, 5.880673451083047, 5.3439772214208325, 5.551321021148136, 8.250733954565865, 7.282224552971976, 3.562879034451076, 4.762087736810956, 3.055388471909932, 3.860885100705283, 3.422520863158362, 1.972748611654554, 4.798326935086932, 2.5607772639819553, 1.8217542682375227, 2.3916429110935757, 0.3971988750355584, 0.40749233269265717, 0.32580241614154404, 0.7271823968206133, 0.5297902630908149, 0.19701128559453146, 0.08257291452693087, 0.04701753366472466, 0.018852715513535907, 0.03449868470696466, 0.09273895009287766, 0.33228812526379314, 1.1226273945399692, 7.3381723165512085, 28.753278596060618, 62.7804970060076, 59.583450181143625, 33.192315919058665, 26.692012105669292, 26.554104260035924, 24.390549864087784, 14.127339669636317, 16.277918304715836, 29.55487142290388, 32.31811441693987, 41.13940838405064, 47.109279768807546, 54.22043446132115, 55.687629972185405, 45.97738347734724, 28.245280163628713, 10.10737599645342, 0.16678195340292795, 0.034827607949929576, 0.030363448030714477, 0.041808491572737694, 0.05520766507834196, 0.055311667533325296, 0.017879504610651305, 0.014991228701546788, 0.020892281517652527, 0.023077712194727998, 0.036140339116432836, 0.06967801467648574, 0.0916628749775035, 0.08540458365210465, 0.03998903384698289, 0.028902545172188963, 0.024333777205486382, 0.019465558164353882, 0.03196645987087062, 0.04383481087695275, 0.06464008893817663, 0.10130522400140762, 0.045483854532774, 0.024370855751580427, 0.09428616599845034, 0.02130954832370792, 0.04624715553862708, 0.045279571387384615, 0.05480591127915042, 0.053323461541107724, 0.03165984007396868, 0.080821968482009, 0.06781513749488763, 0.11904686556330749, 0.048483413577611954, 0.0331012113019824, 0.04141341455812965, 0.040118447438414605, 0.028930297254451683, 0.05334394990599581, 0.01741473696061543, 0.01388447532164199, 0.02162131480872631, 0.06080772315285035, 0.08545800471412283, 0.01957926367010389, 0.04628453264012933, 0.01716654242149421, 0.025257651827165058, 0.0369942143692502, 0.04722192876839212, 0.019694463649232472, 0.06003835265125547, 0.05120823718607426, 0.05005388627094882, 0.026532374854598726, 0.041687753051519394, 0.022765180661476085, 0.04238045588135719, 0.042415481859019825, 0.049972462068711004, 0.02081007869648082, 0.06779436753796679, 0.015663276925416927, 0.0037341834644653966, 0.025212110253050923, 0.036373398931963105, 0.08173065579363278, 0.045893669327987094, 0.01903192339731114, 0.038893423708421845, 3.436001019818442, 33.5256279536656, 66.19375092642647, 73.94088813236782, 72.36115959712437, 58.85010256086077, 46.956478459494456, 46.77971976143973, 43.062655857631135, 33.98522697176252, 24.59815161568778, 21.524720191955566, 29.78076778139387, 30.958442279270717, 34.40378992898123, 42.23676518031529, 33.818921838487896, 13.777603830610003, 2.481603409562792, 0.42054555511900354, 0.020586898350822072, 0.07713797116386038, 0.06339638853179556, 0.11019164430243628, 0.20633587666920253, 0.5322650702936309, 0.5297196954488754, 1.143490446465356, 3.1525618519101823, 2.0677259266376495, 1.9662935180323464, 4.690810510090419, 6.209756204060145, 6.975363876138415, 5.8414643321718485, 5.375779560634068, 9.292854309082031, 10.543740238462176, 7.624053342001779, 8.959637812205724, 9.80496346950531, 8.833566222872053, 5.99943162713732, 8.249643087387085, 9.88038182258606, 7.345806649753025, 5.603917147432055, 2.5834171005657742, 1.6989606001547404, 0.5525947936943599, 0.3589820185942309, 0.09285884723067284, 1.7308893097298486, 4.425373690468924, 6.469407779829843, 6.849061693464007, 5.209668108395167, 1.8643193670681544, 4.064774777208056, 8.102547117641993, 6.166774647576468, 9.203048842293875, 12.200968112264361, 7.896097898483276, 9.89629146030971, 6.440129808017185, 5.5394565377916605, 4.336184007780893, 1.6006440243550708, 3.5994011546884264, 1.9618531848703111, 2.6679534443787167, 2.8167397805622647, 2.2330455013683865, 1.5855158418416977, 1.225766237292971, 1.7866754191262382, 1.8243563686098372, 0.6304019157375608, 0.28128256648778915, 0.23879444066967281, 0.19439075621111052, 0.1483315277312483, 0.03861616412177682, 0.11940479278564453, 0.9212376581771033, 6.104683807918003, 24.623396158218384, 49.48388222285679, 46.595377104622976, 25.84003094264439, 24.228752374649048, 22.463018826075963, 26.74993576322283, 21.806431429726736, 26.317568472453527, 39.8218423298427, 38.402325357709614, 49.812382629939485, 54.68311153139387, 62.43823569161551, 67.41957991463798, 60.54455280303955, 42.5833170073373, 17.369042566844396, 0.2516041233071259, 0.07081680678363357, 0.03992790123447776, 0.08012313169560262, 0.037212227670741935, 0.025621867372787425, 0.05818464926310948, 0.02702762060133474, 0.04641189366312964, 0.03848731032173548, 0.02141350837025259, 0.03167735645547509, 0.07883179813091244, 0.05455228845988001, 0.029074723433171, 0.02998687805874007, 0.04380935224305306, 0.029098221100866795, 0.06401893084070512, 0.08669746427663735, 0.010451289991449033, 0.03514015135754432, 0.04373632151899593, 0.019605804567358324, 0.07928011978843383, 0.023896586914945925, 0.03595457997705255, 0.028654214926064014, 0.05369565496221185, 0.03955244405993393, 0.021160755772143602, 0.01927680159652872, 0.04899035048271928, 0.004875929743450667, 0.08710078549172197, 0.05065861703561885, 0.052114298567175865, 0.21206961971308502, 0.13879200390407018, 0.16124600331698144, 0.07484295538493566, 0.08449567920927491, 0.09813288279942103, 0.19371831443692955, 0.19770717753895692, 0.10223096968340022, 0.20710351690649986, 0.16249566126082624, 0.20084601268172264, 0.24249508923717908, 0.11475335380860738, 0.20425559686762945, 0.14509486140949385, 0.12659159143056187, 0.15124679915606976, 0.13468645992023603, 0.13705469641302312, 0.1349552683532238, 0.09991347403930766, 0.21021502065871442, 0.16981809905597142, 0.1781427330736603, 0.18624081781932286, 0.12382277500416551, 0.19360300419586046, 0.10376614159239189, 0.11264790714319263, 0.19234201471720422, 0.08158582249390227, 0.12408378028443881, 0.24936178220169886, 5.898767863001142, 42.119444847106934, 74.67926624843052, 81.99692140306745, 79.576815196446, 69.28438608986991, 56.14770146778652, 52.93265186037336, 46.53952401024954, 34.52306965419224, 26.79500699043274, 22.314747742244176, 40.94987194878714, 48.994687352861675, 64.37031432560512, 75.55876227787563, 51.693489279065815, 18.93964638028826, 3.642494316611971, 0.6398946749312537, 0.16761925204523972, 0.18720450039420808, 0.17451580055058002, 0.3454376996627876, 0.2264208389180047, 0.28679932760340826, 0.5639975475413459, 0.7278076804109982, 2.3438073865004947, 1.8111450203827448, 1.718288208757128, 5.953416313443865, 11.041608197348458, 11.256490792546954, 11.743151307106018, 12.703306368419103, 14.362398096493312, 15.08899119922093, 18.597306898662023, 12.034461481230599, 14.988169363566808, 14.75841328075954, 13.823307343891688, 15.412855420793806, 21.292798008237565, 15.190243823187691, 7.7077904258455545, 8.733698895999364, 5.88423353433609, 2.8007304796150754, 1.564506009221077, 1.961841025522777, 1.3594852962664195, 2.1550960498196736, 3.823732214314597, 10.187386240277972, 20.276160172053746, 17.413420711244854, 16.82987972668239, 16.484092201505387, 18.933436427797588, 19.756629467010498, 15.606366225651332, 11.367233787264142, 15.378842251641409, 9.880623272487096, 12.387940662247793, 13.939698355538503, 7.091295003890991, 10.440323250634329, 7.895752225603376, 8.433575800486974, 7.389952029500689, 2.0001232113157, 1.8028253125292915, 1.886104792356491, 2.652593799999782, 1.9460603637354714, 0.5606202344809259, 0.4178784782333033, 0.19168238368417534, 0.18703633227518626, 0.16256588963525637, 0.21058792993426323, 0.5876200656805719, 1.5996375126498086, 10.756230916295733, 38.573296206338064, 80.40332426343645, 77.29758371625627, 48.54034464699881, 39.162430490766255, 37.58146170207432, 35.91784756524222, 23.887951919010707, 27.236460787909373, 44.1634589603969, 48.31765488215855, 58.90668869018555, 63.079929624285015, 71.44448375701904, 76.28800351279122, 72.87980788094657, 59.88057599748884, 25.53866846220834, 0.7470481651169913, 0.1723777638482196, 0.08469064267618315, 0.16901351937225886, 0.15329368146402494, 0.19681749599320547, 0.14132049679756165, 0.10630655634616103, 0.15004754279341015, 0.10241465589829854, 0.07720705281410899, 0.21976077343736375, 0.17481565874602112, 0.19268946535885334, 0.10578201484999486, 0.13694353880626814, 0.16212074352162226, 0.15710001864603587, 0.1385923381894827, 0.14204804918595723, 0.15033923142722674, 0.17964640738708632, 0.1131610017535942, 0.10592768953314849, 0.202524314767548, 0.07308937662414142, 0.1913552890930857, 0.08770805397736174, 0.14039611497095653, 0.12425498824034419, 0.11344226130417415, 0.19435129261442594, 0.2438775636255741, 0.13816635390477522, 0.13689130518053258, 0.12121778407267161, 0.1484481950423547], [0.0708439006869282, 0.12566638179123402, 0.062496522175414224, 0.10295931595776762, 0.10265762571777616, 0.09736446903220244, 0.04398864494370563, 0.04419276184801545, 0.11210347778562989, 0.20168453268706799, 0.1641843042203358, 0.022554943371298056, 0.020498469970854263, 0.02177522860334388, 0.05013666754322393, 0.02603987887102578, 0.08351938945374318, 0.07091110958052532, 0.022866842170645083, 0.08298785226153475, 0.033491246801401885, 0.04021276380600674, 0.07146087222333465, 0.3786913167153086, 0.2765965222248009, 0.13915843995554106, 0.03198306362277695, 0.051808068927909644, 0.0856306172375168, 0.0938928938869919, 0.05600436357781291, 0.06083417244787727, 0.07350118631230933, 3.271545627287456, 26.564378908702306, 57.362920556749614, 58.45060198647635, 58.80806595938546, 42.39420788628714, 50.55148335865566, 42.511622020176475, 22.119301864079066, 18.338073083332606, 18.920634371893748, 24.70897364616394, 20.298397881644114, 39.049640383039204, 60.06038148062569, 46.08984007154192, 31.973612308502197, 10.247297082628522, 0.8248467104775565, 0.12461500535053865, 0.13778317160904408, 0.057562839772020064, 0.06797845408852611, 0.05496420332097581, 0.04279759885477168, 0.08789250015148095, 0.41654670398150173, 0.36240981466003824, 0.7021999859384128, 1.625031007187707, 1.8962697897638594, 1.2958945142371314, 4.0434251342500955, 3.8357512950897217, 3.1581710023539404, 5.960801380021231, 4.554146392004831, 8.819097467831202, 6.204163772719247, 4.557718634605408, 4.203529000282288, 8.846218023981367, 4.106287223952157, 4.066099711826869, 3.020201708589281, 3.1379662922450473, 3.934796128954206, 8.358439717973981, 4.838266917637416, 1.5215122933898653, 0.4794775971344539, 0.24580365312950953, 9.239873426301138, 34.22779205867222, 43.21205949783325, 43.12768752234322, 40.339632511138916, 19.85847442490714, 10.773438130106245, 2.317519962787628, 7.856580018997192, 2.709526904991695, 5.377835358892169, 8.553203804152352, 3.1510447561740875, 7.113603063992091, 5.224548978464944, 3.055367193051747, 2.2097766356808797, 2.1828994836126054, 3.6359997051102773, 1.642551758459636, 2.083158309970583, 1.9894585950034005, 3.254534048693521, 1.9887073210307529, 1.8536271750926971, 0.44053332401173456, 0.5343233112777982, 1.2637786375624793, 0.43211161877427784, 0.3107691742479801, 0.3824249149433204, 0.16867771239152976, 0.05882810402129378, 0.06525144898997885, 0.01551984140782484, 0.40720067120024134, 2.649814520563398, 13.928242513111659, 38.09375933238438, 50.19275828770229, 45.06344175338745, 47.24969591413225, 50.34650455202375, 47.12627158846174, 15.992394242967878, 16.099109888076782, 24.99588908467974, 40.06147527694702, 44.060629095349995, 46.36491577965872, 50.61374616622925, 50.67961508887154, 56.92392642157418, 47.32909645353045, 14.6730911391122, 0.2298338429204055, 0.019642837312338606, 0.0505236937398357, 0.040872140388403616, 0.05772257370076009, 0.053177128678986, 0.02984605490096978, 0.06264220364391804, 0.041067276881741624, 0.11511768640152045, 0.14012129471770354, 0.20706618390977383, 0.06262443281177964, 0.25149080795901163, 0.04825113407735314, 0.13309806372438157, 0.031480333634785244, 0.11455412235643182, 0.12671371416321822, 0.10957171435334853, 0.10217321956796305, 0.04016195510381034, 0.02884744473599962, 0.04656836383842996, 0.06395810017628328, 0.06954673172107764, 0.08925524952688388, 0.06261038035154343, 0.05159727863169142, 0.05557025722893221, 0.04335290173600827, 0.09379255891378437, 0.17710989420967443, 0.2593827673367092, 0.2277368168745722, 0.10631779288606984, 0.12141546846500464, 0.09912911469915084, 0.03917575195165617, 0.08992300940943615, 0.030172827187925577, 0.033090683831168075, 0.0791666687333158, 0.030280846570219313, 0.045157971126692634, 0.14576723533017294, 0.09802249872258731, 0.08316839685929672, 0.054097079671919346, 0.055133253535521884, 0.020865067174392085, 0.01693551821101989, 0.04700197146407195, 0.07161583605089358, 0.03389332629740238, 0.0345767840876111, 0.06210904475301504, 0.019311150735510246, 0.0627386641821691, 0.23084817134908267, 0.14258937085313456, 0.10550359836114304, 0.03126767736726573, 0.08336108044854232, 0.12858761075351918, 0.030512549315712283, 0.016709806929741586, 0.04910253267735243, 0.05328759418002196, 4.3396689636366705, 34.27067634037563, 67.52780505589077, 67.0753036226545, 68.74376760210309, 50.56237465994698, 57.331844738551546, 51.92001792362758, 35.28734023230416, 27.674525601523264, 27.536345039095195, 27.333660875047954, 17.39722967147827, 31.094581808362687, 48.63566698346819, 45.22611992699759, 31.224860531943186, 9.031814830643789, 0.9535870594637734, 0.04734404471569827, 0.08025702022548233, 0.06329871341586113, 0.15865081043115684, 0.3720527472240584, 0.5323660905872072, 0.7569653615355492, 1.6665636471339633, 2.339056772845132, 3.577728420495987, 5.980268495423453, 4.838396762098585, 6.133345127105713, 8.104287641389028, 6.680530096803393, 10.379315461431231, 8.525329368455068, 6.48465473311288, 9.702917882374354, 7.206823570387704, 9.366652863366262, 7.626380120004926, 9.939200060708181, 9.735554439680916, 6.671556498323168, 5.914659695965903, 4.959152110985347, 5.114669297422681, 4.527516552380153, 3.7368588873318265, 2.142382800579071, 0.44302935578993385, 0.17459725189421857, 8.672018000057765, 34.77318048477173, 49.515645912715364, 47.18226364680699, 43.877693448747905, 21.55092532294137, 8.462358713150024, 2.9170094515596117, 3.99475474017007, 5.545218765735626, 5.518790423870087, 6.018102739538465, 4.022937067917415, 4.374356542314802, 6.55539173739297, 3.0692331918648312, 3.157434276172093, 4.846931755542755, 2.6713886771883284, 1.8508665689400263, 2.3662557133606503, 3.6702612723623003, 4.545739071709769, 3.078102784497397, 3.3313120773860385, 2.03322616645268, 1.743565863796643, 2.303297217403139, 2.1793346234730313, 0.9977693515164512, 0.7962842945541654, 0.4238587059080601, 0.17568020735468182, 0.03629788137706263, 0.07171027455478907, 0.2730331005794661, 1.5032521017960139, 12.632580654961721, 34.39986072267805, 41.10825613566807, 35.09615707397461, 34.126650605882915, 42.048941476004465, 40.66000005177089, 18.916316066469463, 24.524875913347515, 35.19474853788103, 47.17821284702846, 47.63901390348162, 53.57571111406599, 60.01043782915388, 61.1634635925293, 68.58764157976422, 59.114085469927105, 20.742981842585973, 0.11894557385572366, 0.1282282043248415, 0.017387198616883585, 0.07312858237751893, 0.09665375788296972, 0.018884939141571522, 0.06124899483152798, 0.030154221757714237, 0.03906430596751826, 0.06323638997439827, 0.06249523974422898, 0.09249125766967024, 0.051408849457012754, 0.049195033963769674, 0.058360349120838304, 0.03871566788958652, 0.029534739641738788, 0.04253921611234546, 0.07469711785337754, 0.07612067075180155, 0.057898829957204204, 0.05900254180388791, 0.03023119816290481, 0.049862050850476534, 0.0238999626266637, 0.0502848799473473, 0.03337362954126937, 0.05748586675950459, 0.03823741265971746, 0.04553051060065627, 0.004945206896601511, 0.059370334925396104, 0.0925569941422769, 0.16756304220429488, 0.08193362597376108, 0.06272384497736182, 0.23149932069437845, 0.2618590130337647, 0.1315736805221864, 0.2986971948828016, 0.1921259013137647, 0.16347250741507324, 0.13096192692007336, 0.09375889000615903, 0.22293481097689696, 0.3066865647477763, 0.2628810496202537, 0.15063809896154062, 0.12899660452135972, 0.11778990658266203, 0.10868881137243339, 0.10783925160233464, 0.25413853302598, 0.14712412894836494, 0.12831277692956583, 0.12120140423732144, 0.12244187481701374, 0.1257704147802932, 0.16583266934113844, 0.44932735498462406, 0.40737950588975635, 0.2914517436708723, 0.10779465828090906, 0.1622030498193843, 0.13923109748533793, 0.1718845638845648, 0.13540188010249818, 0.14453445933759212, 0.18706203518169268, 6.792868571622031, 43.018854413713726, 76.61760520935059, 75.36527579171317, 76.9210260936192, 58.409121240888325, 65.18636635371617, 56.92444406236921, 36.105494090488975, 26.42979403904506, 27.510885102408274, 33.609833172389436, 29.346814564296178, 51.81558649880545, 74.43779550279889, 61.18787261417934, 41.43486315863473, 12.967455165726797, 1.7402081468275614, 0.2637027826692377, 0.18973630453859056, 0.12309562973678112, 0.15570045874587127, 0.22428497352770396, 0.46062154322862625, 0.6796504216534751, 0.9786975234746933, 1.6141716241836548, 3.8890083687646047, 6.728128731250763, 7.749849608966282, 8.814009649412972, 14.443125741822378, 12.561841913631984, 13.081482921327863, 14.222424030303955, 14.075489606176104, 20.230982984815324, 13.637369206973485, 12.641875607626778, 15.018871716090612, 16.577434301376343, 15.460417577198573, 14.272484932626996, 12.307675072125026, 12.283155747822352, 9.333326697349548, 18.344670397894724, 10.491843274661473, 5.345106737954276, 1.6029241191489356, 0.6810748023646218, 6.1036094427108765, 25.07664625985282, 36.16876438685826, 31.737932886396134, 31.2296130997794, 17.689906903675624, 15.545906475612096, 12.798123223440987, 17.224533932549612, 14.497970478875295, 15.456481422696795, 18.46043086051941, 11.586317437035696, 12.955788271767751, 16.639544248580933, 14.302052991730825, 6.749940863677433, 7.88964649609157, 8.46210162980216, 7.928610256740025, 5.157812399523599, 9.251278894288198, 9.726128339767456, 4.7640597224235535, 4.453283301421574, 2.090481059891837, 1.9077760066304887, 2.509479799440929, 1.611818899001394, 1.1908389457634516, 1.024857229420117, 0.37578306134258, 0.22858110442757607, 0.15403874005590165, 0.19087711189474377, 0.5490032806992531, 3.353191737617765, 18.140879733221873, 47.575170380728586, 63.89919172014509, 59.16659300667899, 62.05752999441964, 62.43966702052525, 57.81983757019043, 26.217319863183157, 26.298936877931865, 40.33664131164551, 53.37484564099993, 58.032695634024485, 62.06816073826381, 70.25759942190987, 72.71580954960415, 78.84569794791085, 72.06297765459333, 27.7922454561506, 0.5069955576743398, 0.22813690826296806, 0.16773691001747335, 0.10403511287378413, 0.2668757752648422, 0.0979204945532339, 0.15398965483265264, 0.10126452547098909, 0.14141275041869708, 0.19853208613182816, 0.3017617847238268, 0.21903524308332376, 0.19940496715051786, 0.3695993274450302, 0.18204388873917715, 0.18864564092031547, 0.09925978697304215, 0.1959585520837988, 0.25814351812005043, 0.3275098002382687, 0.20001608292971337, 0.21956755380545342, 0.10901606202657733, 0.23744733152644976, 0.11233842732118708, 0.181577273777553, 0.21408081107905932, 0.1825962026736566, 0.22410555529807294, 0.15146716018872602, 0.16284095416111605, 0.23148745990225247, 0.18782192654907703, 0.2781652409051146, 0.344503004103899, 0.19967004364090307], [0.10398030081497771, 0.165453259700111, 0.07489593539919172, 0.10018475912511349, 0.10435905906238727, 0.063313335845513, 0.035841335875115225, 0.03990693450240152, 0.09229198550539357, 0.19238293037882873, 0.24385424916233334, 0.12426630620445524, 0.025519968376361897, 0.05472882630835686, 0.07494751763130937, 0.026032874693295786, 0.12821386009454727, 0.048956528904714754, 0.06432356592267752, 0.019423997894461666, 0.05422605900093913, 0.05044199133824025, 0.2256037470485483, 0.302872790821961, 0.2984585134046418, 0.14927125801997526, 0.12145822974187986, 0.1616893580981663, 0.13707657238202436, 0.062089258671871254, 0.21447168796190194, 0.07076835259795189, 2.0118878143174306, 19.186807700565883, 44.75159270422799, 58.4406521660941, 55.02371570042202, 44.674575396946494, 48.93919209071568, 44.88746820177351, 19.16294584955488, 16.79070404597691, 21.007822854178293, 22.225722210747854, 29.593256746019634, 43.64866345269339, 50.18578577041626, 36.59636695044381, 16.158949511391775, 3.655594493661608, 0.1282901002892426, 0.19048189238778182, 0.0746504550001451, 0.06619719788432121, 0.08416287135332823, 0.0334098599185901, 0.033031739494098086, 0.184928028977343, 0.8898422228438514, 1.4983319086687905, 0.7389922716787883, 3.761101152215685, 7.061096830027444, 1.7075390198401041, 4.014916675431388, 4.914658452783312, 5.617761867386954, 7.011528815541949, 5.801232091018131, 2.1615320358957564, 6.510967126914433, 10.15248543875558, 6.241389180932726, 7.291172964232309, 9.849631701196943, 8.231944288526263, 2.622555651835033, 5.115379750728607, 7.060457595757075, 6.538819415228708, 5.014257405485425, 0.8860713594726154, 0.5283574685454369, 0.8702233870114598, 9.035133463995797, 44.77735662460327, 59.610770498003276, 56.376071384974885, 63.312284333365305, 61.35466412135533, 55.65017570768084, 27.415218830108643, 3.022733675582068, 1.9224868629659926, 1.6450543041740144, 2.5954348785536627, 8.462095550128392, 5.528607359954289, 8.194683705057416, 5.174372562340327, 0.9793688931635448, 2.511216849088669, 2.2534725538321903, 2.026247135230473, 2.179363936185837, 2.2754798872130255, 1.4292221942118235, 2.7034591734409332, 1.894353824002402, 1.8414228813988822, 1.991921297141484, 1.8115884023053306, 0.7700931142483438, 1.7767081196819032, 1.125828777040754, 0.6665056784238134, 0.08558556251227856, 0.16209297786865914, 0.09899475798010826, 0.045290421162332804, 0.06325181986072234, 0.04333198589405843, 1.0520927565438407, 8.45592554977962, 26.528283017022268, 38.349314076559885, 36.33768204280308, 78.97130053383964, 96.02690465109688, 57.70781871250698, 24.307520627975464, 16.714840139661515, 41.130059582846506, 53.09496177945818, 36.142128467559814, 47.70574787684849, 51.686363901410786, 51.80376066480364, 48.461079597473145, 43.99639647347586, 6.481857214655195, 0.22359982957797392, 0.11904924043587276, 0.12166279447930199, 0.2685182642723833, 0.054011974417205365, 0.08359682387007134, 0.11385980461324964, 0.17669556715658732, 0.14986273699573108, 0.4356055312923023, 0.1109294764963644, 0.41441626687135014, 0.14838199716593536, 0.12316561383860451, 0.06459847438548293, 0.06714783223079783, 0.027304486637668948, 0.10940002463757992, 0.14479892514646053, 0.058192974887788296, 0.11216810824615614, 0.039843820567641935, 0.10702081623354129, 0.11598794827503817, 0.1115787462996585, 0.1270467255796705, 0.03029185240822179, 0.019945392684478844, 0.11160735333604471, 0.021521700778976083, 0.06107973427112613, 0.1986705344170332, 0.11333586022789989, 0.13862123021057673, 0.1674791481345892, 0.1023303275661809, 0.1318909634969064, 0.0481216763811452, 0.05162775503205402, 0.14145282469689846, 0.10118900452341352, 0.02437701684954975, 0.016367764212191105, 0.08596656671059982, 0.0717189869444285, 0.09819684829562902, 0.03548739165333765, 0.030210519808211496, 0.033310291689953635, 0.04049950931221247, 0.0076592379815078205, 0.037042285182646344, 0.03101493664351957, 0.013639745551959744, 0.016087809145184498, 0.05122752793665443, 0.07259470423949616, 0.1306336381073509, 0.26780333263533457, 0.26305418461561203, 0.12602035993976252, 0.11437227497143404, 0.20700564501541002, 0.08420613474611725, 0.09063023967402321, 0.10461737055863653, 0.11743805903409209, 3.234630499567304, 29.20990378516061, 56.2020537512643, 69.69764409746442, 64.12828077588762, 55.86107437951224, 52.56575918197632, 54.02284158979143, 28.367538928985596, 23.050627980913433, 23.43009168761117, 26.455377306256974, 31.456475257873535, 31.68654748371669, 41.75179828916277, 30.93884835924421, 15.70289407457624, 3.84304256098611, 0.20970921351441316, 0.06701811669128281, 0.15042251481541566, 0.07189877836831979, 0.1523652962808098, 0.5187779111521584, 0.8334485803331647, 1.311019656913621, 2.774536205189569, 3.3608028377805437, 5.002866702420371, 5.657463874135699, 7.866092102868216, 7.924727082252502, 7.623154418809073, 5.3458970955439975, 8.96369729723249, 14.335525938442775, 9.525691049439565, 5.2100949883461, 6.234154803412301, 8.482887165887014, 6.346028183187757, 6.524871775082179, 9.032528758049011, 6.493056842258998, 4.051942757197788, 3.230691305228642, 3.8766001888683865, 1.627202427812985, 3.229143811123712, 1.6248081220047814, 1.0553243202822549, 0.5369020700454712, 10.793917076928274, 52.00061355318342, 71.61267185211182, 66.36562156677246, 73.55870246887207, 71.2781160899571, 63.88191155024937, 31.357633658817836, 5.7732564721788675, 1.4486698763711112, 1.5519368265356337, 2.4586365733827864, 3.8042103818484714, 5.883151352405548, 3.654497981071472, 4.349552341869899, 1.9438758066722324, 0.6053507828286716, 1.9953226574829646, 1.6884108462503977, 2.804672062397003, 3.3753779871123175, 3.224378649677549, 3.349344172648021, 3.8073357684271674, 2.5155855289527347, 2.8553170476640974, 4.234610463891711, 3.8675961920193265, 3.773474156856537, 3.414806625672749, 2.318147037710462, 1.0829549176352364, 0.5371095389127731, 0.535200087087495, 0.10091383821730103, 0.16864036582410336, 0.04648128404681172, 0.542794576713017, 6.08541167633874, 25.778648819242203, 38.6075508253915, 34.03938817977905, 64.16791330065045, 79.01610946655273, 46.720882415771484, 23.542676823479788, 24.95298743247986, 48.319065366472515, 57.32994440623692, 44.12782512392317, 53.371326378413606, 55.93758446829659, 63.18150533948626, 61.14906692504883, 56.004467827933176, 11.184675080435616, 0.3433906137943268, 0.10687005932309798, 0.045510164728122096, 0.18199564489935124, 0.03732374829373189, 0.06169545730309827, 0.03862383496016264, 0.20709902500467642, 0.06649909847016845, 0.16577705661101, 0.08301094959356956, 0.26548458848680767, 0.10622065381280013, 0.10278671021972384, 0.049369312290634425, 0.025957163755914996, 0.031141412178320543, 0.12706948364419596, 0.10166994335928134, 0.022608115071696893, 0.04833896704284208, 0.03226522562493171, 0.020270992802189927, 0.07234444016856806, 0.04636370410610523, 0.028106689752478684, 0.0014751044904447294, 0.024943663139960597, 0.062424366761531146, 0.023303903539531996, 0.07826358612094607, 0.16328756591039045, 0.07887327019125223, 0.06337130309215613, 0.014835871323677046, 0.2661539768534047, 0.48920751788786476, 0.2575980845306601, 0.25851131124155863, 0.4484023489058018, 0.2930138941322054, 0.07326265411185366, 0.12146912701427937, 0.23866418908749307, 0.47232659799712046, 0.3739543823259217, 0.28183239698410034, 0.16263706795871258, 0.18929935512798174, 0.1575497652270964, 0.12815622533006327, 0.18419727390365942, 0.19485009727733477, 0.1370633409491607, 0.16865572785692556, 0.26017532337989124, 0.14050655333059175, 0.3814180775412491, 0.45384406404835836, 0.5110987946391106, 0.41452580956476076, 0.27042407914996147, 0.27805816807917183, 0.32883685188634054, 0.20575605492506707, 0.18642125385148184, 0.366075586527586, 5.232798227242061, 36.795231342315674, 68.7562952041626, 77.26417677743095, 72.48597703661237, 63.883183070591514, 63.27107456752232, 56.15994071960449, 30.07694516863142, 25.628526040485927, 30.121378898620605, 31.00576298577445, 41.93961157117571, 57.75961753300258, 65.1934813090733, 47.5111357825143, 21.428465059825353, 5.4670745474951605, 0.27639369453702656, 0.2845903161380972, 0.2595379075833729, 0.18581317790916987, 0.17919144965708256, 0.4064676362488951, 0.6839068446840558, 1.0817061960697174, 2.780465841293335, 6.947963654994965, 7.342818924358912, 12.035187567983355, 18.754544632775442, 11.48192856992994, 11.178211518696376, 14.829738276345388, 16.374216863087245, 15.574708495821271, 15.495108195713588, 11.509789977754865, 17.62094603266035, 23.59698220661708, 17.043566363198416, 17.92780974933079, 20.93224903515407, 19.38111060006278, 11.60003057547978, 15.079063960484095, 12.084411212376185, 16.406258480889456, 11.687264340264456, 6.755693972110748, 2.880041778087616, 2.6555094378335133, 10.833942174911499, 46.31521184103829, 63.06387233734131, 61.616916928972515, 69.51526778084892, 61.96761335645403, 56.27024337223598, 31.961963653564453, 6.034384105886732, 6.852103701659611, 5.801563433238438, 8.544878993715558, 17.521583318710327, 17.420070137296403, 15.78561064175197, 18.980821405138286, 9.15710301058633, 6.195544532367161, 7.421687926564898, 6.571006510938917, 6.462976353509085, 6.55907905953271, 7.538037249020167, 7.677956598145621, 7.011630432946341, 5.3214481217520575, 5.415918001106807, 6.682110811982836, 3.599161441837038, 5.335047917706626, 3.8839405264173235, 2.961629045861108, 1.1253636819975716, 0.48202682605811525, 0.35371338416423115, 0.20865249021777085, 0.18413645002458776, 0.2652025893330574, 1.4174265414476395, 12.318400485174996, 32.68458672932216, 49.758805070604595, 46.74840423039028, 87.03326756613595, 99.51000881195068, 69.89891256604875, 34.21062305995396, 25.339366333825247, 51.277702127184185, 65.55510030473981, 50.678545066288535, 62.287522315979004, 67.82424300057548, 74.24524007524762, 70.373717716762, 66.81603159223283, 14.81450435093471, 0.5919496076447623, 0.21611903528017656, 0.20455500722995826, 0.38279675213353975, 0.16767396910914353, 0.27307986521295136, 0.2858048123972756, 0.47709284509931293, 0.19812605077666895, 0.5110057539173535, 0.5263899341225624, 0.6891974093658584, 0.2389846204646996, 0.345753761274474, 0.20986777357757092, 0.13131595935140336, 0.1665879330996956, 0.3995100738746779, 0.2955975926348141, 0.2538517569856984, 0.20209260364728315, 0.06206544887806688, 0.26083418088299887, 0.25474799317973, 0.22918513630117687, 0.27493107159222874, 0.13365378390465463, 0.09391198786241667, 0.16935931438846247, 0.18111509643495083, 0.2702803654330117, 0.34416069675769123, 0.2603894690317767, 0.4590519017406872, 0.4324807689658233], [0.09763660228678159, 0.10722824438874211, 0.08142416152570929, 0.11828983761370182, 0.17206259790275777, 0.03238955020372357, 0.01375980384182185, 0.01612688258423337, 0.06160192125077758, 0.15062173269689083, 0.13329637236893177, 0.10534316554133381, 0.07151693957192556, 0.06748361885547638, 0.06067001447081566, 0.057681691965886524, 0.0661846517718264, 0.042914524009185176, 0.07398823874869517, 0.015290179356400455, 0.048813907629145045, 0.0974807156515973, 0.15037277819854872, 0.2829185958419527, 0.07985557855239936, 0.027098586882597635, 0.04928692796134523, 0.09595846304936068, 0.12406615194465433, 0.09018928690680436, 0.10196842412863459, 1.8122755140066147, 18.980149166924612, 49.02758707318987, 62.072809083121165, 49.03512934276036, 43.55849667957851, 33.56629923411778, 37.26779917308262, 26.583703586033412, 19.505686589649745, 22.528858218874248, 29.74312244142805, 30.070472921643937, 44.81068018504551, 42.261049134390696, 25.145775624683925, 10.8991562298366, 1.6763636469841003, 0.4681193551846913, 0.03872393923146384, 0.04476201540923544, 0.042784896679222584, 0.06972070131450891, 0.2112846089793103, 0.7770579233765602, 1.5617062108857291, 1.9898107818194797, 1.3486236333847046, 2.016122958489827, 4.9155043959617615, 2.779074464525495, 4.0522892986025125, 4.512890160083771, 7.3664193493979315, 5.553535759449005, 4.613583019801548, 15.549893004553658, 8.587763275418963, 4.803720039980752, 2.970026812383107, 3.5660691261291504, 4.169167552675519, 3.7149277670042853, 3.607981094292232, 5.387551546096802, 2.449747656072889, 2.970036800418581, 3.5147664504391805, 6.287793593747275, 4.4769996745245795, 2.4186542502471378, 5.806821048259735, 12.98167552266802, 29.9995630809239, 42.807493686676025, 42.28568049839565, 47.188204356602256, 48.803049087524414, 54.06516306740897, 53.13804061072213, 52.72923639842442, 17.982931545802526, 6.623855812208993, 5.74255325113024, 2.9073703459330966, 3.386887026684625, 2.897027952330453, 3.6293129324913025, 4.334719240665436, 1.7144569286278315, 3.261510908603668, 8.030117358480181, 1.847708829811641, 1.456258937716484, 2.417040531124387, 2.5987652369907925, 3.423244344336646, 2.775266851697649, 2.043868418250765, 3.409029198544366, 1.4065386056900024, 3.5361345495496477, 2.4737289292471747, 1.5951623299292155, 1.1104599045855659, 0.7153867440564292, 0.2911743585552488, 0.11071465909481049, 0.20084532057600363, 0.06397960973637444, 0.0852147906220385, 0.0990484504561339, 0.76392669656447, 2.6946801245212555, 20.28642613547189, 31.712276663099015, 62.17225864955357, 87.51556287493024, 49.4153938293457, 35.15556069782802, 29.81442485536848, 18.880105529512676, 19.84920379093715, 22.996979202542985, 38.41175406319754, 49.6631874356951, 53.72173792975289, 52.56718008858817, 54.345908505576, 42.174721240997314, 1.5527574739285877, 0.07761914748698473, 0.07673153547304017, 0.10218595567026309, 0.0484388100781611, 0.06507325212338141, 0.0763856251058834, 0.08379054561789546, 0.11841281530048166, 0.1221909797085183, 0.11756179668009281, 0.34168170977916035, 0.20257139152714185, 0.08472439979336091, 0.08693587434078966, 0.0165221919970853, 0.05682910253692951, 0.045730824316186566, 0.09488736159567322, 0.07876232293035303, 0.011794235474163932, 0.05173545889556408, 0.09639774662043367, 0.08923815044441394, 0.1364775752382619, 0.1924274694174528, 0.002771880436089954, 0.08054221527917044, 0.03877703459667308, 0.028942476958036423, 0.05264162884226867, 0.036766949242779186, 0.09837232423680169, 0.10850876889058522, 0.24151810737592833, 0.025249275312359844, 0.08618233406117984, 0.05785132572054863, 0.04326711794627564, 0.140941589272448, 0.03776247546608959, 0.013641365554316767, 0.0368883323722652, 0.13320932989673956, 0.11636384310466902, 0.027604668833581463, 0.016142755214657103, 0.05011405875640256, 0.07179298118821212, 0.03759336079071675, 0.06877518990742308, 0.017047473096421788, 0.056441309595746655, 0.024111119331791997, 0.03150435716712049, 0.037912764187370024, 0.04752358847430774, 0.15516387325312408, 0.17070235232157366, 0.1684168835303613, 0.05496328051335045, 0.0850524782602276, 0.18851084315351077, 0.15097030970667089, 0.07575865874865226, 0.08769707528076001, 2.5685203799179623, 27.49184009007045, 62.90937219347273, 72.16557475498745, 59.820828437805176, 52.17215067999703, 46.74471473693848, 48.31219359806606, 34.02433490753174, 29.99170814241682, 25.545583656855992, 30.165829999106272, 24.214341810771398, 36.79877839769636, 40.53257008961269, 25.881853887013026, 10.247894627707344, 1.8588734992912836, 0.3366063492638724, 0.009209381765685976, 0.12499023521585123, 0.2084763425269297, 0.1843152440020016, 0.7299622733678136, 2.1176433052335466, 2.581040165254048, 3.261244705745152, 4.761214435100555, 5.067858414990561, 5.419796398707798, 7.767313037599836, 6.9851460712296625, 7.445832048143659, 8.62674788066319, 5.4114329389163425, 7.4176154136657715, 17.88694565636771, 16.55632393700736, 6.458173845495496, 5.2184940576553345, 4.932153148310525, 5.357539236545563, 3.3806510184492384, 3.459299849612372, 5.147618957928248, 2.5578234110559737, 2.2380353936127255, 2.050801634788513, 5.024512946605682, 3.5740632457392554, 4.572939097881317, 8.930246063641139, 14.82214389528547, 37.10867152895246, 53.15863159724644, 52.70153740474156, 54.89325284957886, 56.22116824558803, 63.61605262756348, 61.82841314588274, 59.05005781991141, 22.347951446260723, 7.161776227610452, 5.71235681431634, 2.1922797688416074, 4.517296186515263, 2.7675167875630513, 2.3433902774538313, 2.1050514323370795, 1.4476014822721481, 2.264336713722774, 6.321967005729675, 2.5126688054629733, 2.7037631571292877, 3.202830983059747, 3.157292055232184, 4.680843753474099, 3.8666008625711714, 3.2039409577846527, 5.8703818661825995, 4.250484492097582, 6.4234771473067145, 4.358661864485059, 4.789835802146366, 5.195197182042258, 2.662980488368443, 0.9716867910964149, 0.6929662099906376, 0.4363771341741085, 0.17708097504717962, 0.1498051429433482, 0.13987723924219608, 0.6180178916880062, 2.3344989717006683, 18.058677332741873, 28.79022216796875, 59.436238697596956, 84.54890441894531, 44.79586662564959, 31.825810228075298, 29.922837597983225, 23.185336181095668, 31.465289047786168, 29.043510062353953, 45.59560080936977, 58.5610922404698, 60.164854594639365, 60.90974317278181, 62.89912360055106, 51.71546295710972, 3.542076345000948, 0.06466113030910492, 0.008923090029773968, 0.03476113187415259, 0.02471068305229502, 0.041773156861641576, 0.06726894394627639, 0.06407725771090814, 0.10989931106035199, 0.05360100271978548, 0.12531021875994547, 0.09229884549443211, 0.02033681239533637, 0.06720529736152717, 0.07137387724859373, 0.057367665959256034, 0.07063188563500132, 0.04830862295680812, 0.050887378331805976, 0.06542689100440059, 0.00975809692006026, 0.03891788150316902, 0.1500688080808946, 0.09836224799177476, 0.06955782576863255, 0.05824122551296439, 0.017659901840878383, 0.03521106844501836, 0.07472193187900952, 0.04828368000952261, 0.03486789935933692, 0.03342782752588391, 0.01626081352255174, 0.020105340351749743, 0.07967271336487361, 0.28088581349168507, 0.30480601851429256, 0.155998702027968, 0.22718173451721668, 0.4427495279482433, 0.1415952763387135, 0.10929006125245776, 0.12590203700321062, 0.3499714806675911, 0.36986569315195084, 0.3381793020027024, 0.3375747273010867, 0.19237803135599407, 0.14962172135710716, 0.17188102193176746, 0.16292475323591912, 0.23594380649072783, 0.13623983013842786, 0.16837592715663569, 0.11720545722969941, 0.15816358157566615, 0.20099477469921112, 0.25819953797119005, 0.4215951402272497, 0.3916601836681366, 0.10027627992842879, 0.20638186777276651, 0.3567200271146638, 0.39683876293046133, 0.1575679906776973, 0.45144677268607275, 4.583821279661996, 35.701011657714844, 74.10278810773576, 82.74944605146135, 68.98484230041504, 60.55455126081194, 49.76891469955444, 49.832501138959614, 39.075880255017964, 29.575094154902867, 32.90630374635969, 40.4510885647365, 42.644308294568745, 56.405441420418875, 55.7247576713562, 33.76084879466465, 13.678625873156957, 3.1201691329479218, 0.8195009944694382, 0.13149571684854372, 0.1952849839414869, 0.16985241935721465, 0.2852093572063105, 0.4138522685638496, 2.099771018539156, 4.256581102098737, 6.984451251370566, 6.771110721996852, 9.595695887293134, 12.746379120009285, 12.990980897630964, 12.29995128086635, 14.22489845752716, 15.37967950957162, 17.076799597058976, 11.836976306779043, 29.50969770976475, 20.719267640795024, 12.149456773485456, 11.593176177569799, 9.262415988104683, 14.669431175504412, 9.372654369899205, 12.627660461834498, 14.742689507348196, 10.860225473131452, 8.792893205370222, 10.97000093119485, 16.39824025971549, 8.707386936460223, 6.329082829611642, 9.724248852048602, 15.958848340170723, 40.10074302128383, 53.16641010556902, 57.82808855601719, 57.09911135264805, 58.82586029597691, 66.4974775314331, 64.22754968915666, 62.345157623291016, 23.807113102504186, 12.121519804000854, 12.84309457029615, 9.837270855903625, 10.078037227903094, 8.46180546283722, 11.050746815545217, 11.646450621741158, 4.405256484236036, 8.555481944765363, 14.21008837223053, 4.975985424859183, 5.869244967188154, 5.479001130376544, 7.20400390454701, 10.255529829433986, 9.442641837256295, 8.35501946721758, 9.248635973249163, 7.0724862303052625, 11.386611444609505, 8.217148099626813, 7.074632789407458, 6.513933573450361, 3.5493228818689073, 1.3303196898528507, 0.654110309268747, 0.6244120257241386, 0.2420207661177431, 0.33829381157244953, 0.26199659279414583, 1.0782039782830646, 4.1315339377948215, 26.10508040019444, 42.669724805014475, 69.73796449388776, 87.1142349243164, 55.98139633451189, 50.7913247517177, 41.87456601006644, 28.927879878452845, 30.4517240524292, 36.58382545198713, 53.57645109721592, 67.6423739024571, 69.62711293356759, 70.17884159088135, 71.82928194318498, 60.38588374001639, 5.581187418528965, 0.3223988844880036, 0.1733184712273734, 0.35077063207115444, 0.14743227884173393, 0.1448352403406586, 0.20642390980252198, 0.34444627857633997, 0.34053444276962963, 0.22724078063453945, 0.28260494981493267, 0.4754583356635911, 0.366518072783947, 0.165336972368615, 0.2293836756476334, 0.13895546299006256, 0.16666938444333418, 0.29326503351330757, 0.25879654022199766, 0.19686943106353283, 0.10287876706570387, 0.20543155233774865, 0.28916657343506813, 0.2722657860389778, 0.2775106446019241, 0.42492001610142843, 0.2718527482024261, 0.1491595847266061, 0.2375081554055214, 0.13332998699375562, 0.22124428169003554, 0.21157735612775597, 0.24598449628267968, 0.2745701181037085, 0.48098410772425787], [0.05100416099386556, 0.019544682132878473, 0.10838113645357744, 0.04982870085430997, 0.09728977589734963, 0.022689717389377098, 0.03215644967609218, 0.039601281617901156, 0.0841193569025823, 0.08565639478287526, 0.08193058613687754, 0.09401109468724046, 0.126579187810421, 0.07432943329747234, 0.03845948699329581, 0.03639724265251841, 0.03345754396702562, 0.03161689219996333, 0.046016915036099296, 0.03212417855060526, 0.04735337796487978, 0.05915549038244145, 0.08155970568103449, 0.003359002580899479, 0.20041483081877232, 0.01012942096817174, 0.027595671459234188, 0.09475871814148766, 0.04242072354203888, 0.3029266936438424, 6.0393876773970465, 17.623739208493912, 49.25424773352486, 59.634199823652, 49.271743297576904, 44.43753065381731, 44.7804867880685, 35.57536390849522, 44.617971897125244, 32.472128186907085, 13.748756647109985, 26.66627424103873, 28.72964777265276, 48.88481896264212, 45.97154699053083, 22.322326489857264, 4.992096994604383, 0.2996616916997092, 0.0492361871126507, 0.033716788448925526, 0.03889818363157766, 0.08044853673449584, 0.22530055046081543, 0.2091720580522503, 1.4786148752485002, 0.6985122838190624, 1.7298719414642878, 2.1120728041444505, 2.933846022401537, 4.017725918974195, 4.335202140467508, 3.404419720172882, 3.662467564855303, 7.265117219516209, 9.123421617916652, 1.9392244219779968, 7.36991776738848, 18.909084728785924, 13.070468289511544, 3.641923261540277, 2.6095108432429175, 3.1251952861036574, 3.553495926516397, 3.8950615525245667, 3.6991162725857327, 3.6479158656937734, 2.692164659500122, 3.0720068258898596, 7.183197523866381, 10.878775426319667, 15.708952903747559, 21.563218423298427, 38.99014295850481, 46.14891365596226, 36.031422819410054, 36.55585895265852, 35.76944446563721, 50.15223291942051, 48.180549553462434, 45.46712861742292, 39.40956401824951, 51.10350384031023, 28.324843985693796, 18.395232439041138, 17.859757355281285, 15.673848867416382, 14.149668574333191, 13.728446194103785, 11.436899900436401, 10.793899706431798, 14.692612103053502, 18.205174888883317, 17.46335220336914, 12.104500191552297, 12.292231832231794, 10.97046993459974, 11.933033415249415, 12.623977048056465, 9.377060396330696, 3.9956245677811757, 4.022237036909376, 6.369192608765193, 4.885050441537585, 1.5525314403431756, 3.1137001429285323, 3.258104119982038, 1.9612565083163125, 1.135086166007178, 1.5635543231453215, 0.13057822893772805, 0.21606577028121265, 0.08274819369294814, 0.14258942513593606, 0.025654711860365102, 0.39231895974704195, 2.24700899209295, 12.553019438471113, 32.2642172404698, 48.72532306398664, 55.03427348818098, 61.984302929469514, 43.857380390167236, 23.683770418167114, 13.994039348193578, 21.342366456985474, 24.082339933940343, 35.36144277027675, 44.02466869354248, 52.97621359143938, 58.179820265088765, 54.82101590292794, 28.92556960242135, 0.5244463926979474, 0.2328636646270752, 0.12914296452488216, 0.04502504272386432, 0.03413135638194425, 0.05563448735379747, 0.08834002113768033, 0.05975728987583092, 0.05955663350011621, 0.034179688431322575, 0.13159228595239775, 0.1687709702444928, 0.045779105475438495, 0.0661213444545865, 0.017118549639625207, 0.01971226671178426, 0.007277467038615474, 0.02494572927909238, 0.052711575624666045, 0.04152602422982454, 0.05121191484587533, 0.03483271731862, 0.00913742312695831, 0.15526642703584262, 0.08696772477456502, 0.09657759232712643, 0.04796780160229121, 0.06746175645717553, 0.01822517579421401, 0.010784772141570491, 0.030147144637469734, 0.008773261015968663, 0.09842324828995125, 0.1407361424395016, 0.10118894345526185, 0.009582799094329988, 0.09733787724482161, 0.08491018946681704, 0.09873691467302186, 0.05573095128472362, 0.0148695554983403, 0.026031426021030972, 0.06835976362760578, 0.04920333923239793, 0.0953264958890421, 0.13593043174062455, 0.06804174104971544, 0.060506982861885, 0.057328222718622, 0.047889054220701964, 0.039909462045345984, 0.03455850435420871, 0.030524043698928187, 0.029831412115267346, 0.09068575062389884, 0.015745179494842887, 0.09501929594469921, 0.06463790405541658, 0.10311337054840156, 0.08703588361718825, 0.09222900388496262, 0.07245253079703876, 0.03611527742551906, 0.26509578792112215, 6.729007678372519, 26.919407538005284, 64.36011437007359, 70.03889792306083, 60.096880367824006, 53.18127577645438, 51.956805161067415, 37.56765563147408, 49.88045760563442, 32.1775141443525, 19.140412841524395, 31.4473557472229, 23.441396406718663, 36.88380350385393, 40.500604901994976, 22.066545929227555, 4.195179436888013, 0.5576864661914962, 0.05987218621053866, 0.052177734806069305, 0.12506981380283833, 0.2755140688802515, 0.5942809996860368, 1.526911043695041, 1.716778821178845, 2.9663959443569183, 2.9743911496230533, 4.845632008143833, 7.437884177480425, 5.400912497724805, 6.023187952382224, 6.303556016513279, 7.7683709008353095, 6.512007185391017, 9.236081446920123, 5.235907111849103, 5.247379890510014, 7.501329915864127, 9.89602221761431, 3.951605124132974, 2.8701668679714203, 4.132161446980067, 3.2127128413745334, 5.307436645030975, 2.6783114714281897, 3.657189973763057, 1.8894961646624973, 2.9516251598085677, 6.780301017420633, 12.426731586456299, 17.18277178491865, 23.6421628679548, 41.995044299534385, 50.43176589693342, 41.696070262363975, 42.01952975136893, 41.68924018314907, 55.4601320539202, 53.66779906409127, 53.41174404961722, 47.01217869349888, 56.8792599269322, 35.18312420163836, 22.541856561388286, 21.532043593270437, 19.35896669115339, 15.86847312109811, 14.440521035875593, 12.362526757376534, 12.336213060787745, 15.904428311756678, 20.570400748934063, 18.344837154660905, 13.113244874136788, 12.28270845753806, 10.769919736044747, 11.81196539742606, 12.185253024101257, 10.614479848316737, 7.298687441008432, 7.116140893527439, 5.414513162204197, 5.533508011272975, 4.391471258231571, 5.092640033790043, 5.047589651175907, 4.56474369764328, 3.350441553762981, 2.761513978242874, 1.0667728888137, 0.5647256427577564, 0.2594157712800162, 0.16392278325344833, 0.046810997783073356, 0.12936206348240376, 1.7291190390075957, 12.361388989857264, 35.793926443372456, 58.75698280334473, 61.581467219761436, 59.57205513545445, 35.623389857155935, 27.429863895688737, 20.25688760621207, 23.20226546696254, 34.01612213679722, 41.402369907924104, 50.96856982367379, 58.474608012608115, 67.28440965924943, 66.70665999821254, 38.93808010646275, 2.0071415432861874, 0.15876781700977258, 0.10528813635132142, 0.06372102004076753, 0.06849232222884893, 0.0688714672412191, 0.0899427140663777, 0.03653417101928166, 0.020200825495911495, 0.09599941263773612, 0.05832805085395064, 0.09268810067858015, 0.02187743124419025, 0.02677413009639297, 0.07399450162691729, 0.02018711230318461, 0.019222171045839787, 0.028029255336150527, 0.025398948263110857, 0.015267528161140425, 0.01747771688470883, 0.03775224315800837, 0.03187856922990509, 0.2158193127917392, 0.11168746796569654, 0.13160148688725062, 0.04851472457604749, 0.09221723130238907, 0.03585821104102901, 0.031270601853196106, 0.00035319854889946455, 0.06067276932299137, 0.07638608650969607, 0.11022453968014036, 0.26866784053189413, 0.16436894716961042, 0.26226537408573286, 0.26775800649608883, 0.3119075388780662, 0.14095841694091046, 0.12527817833636487, 0.12308452890387603, 0.21802320810300962, 0.3007544587765421, 0.24846923723816872, 0.2495887657361371, 0.24228107929229736, 0.21301115490496159, 0.17618559380727156, 0.17480655280607088, 0.1498098519763776, 0.2282761979315962, 0.09819914174399205, 0.1553009780389922, 0.1847462358751467, 0.21068285698337214, 0.3115127943456173, 0.2345044437263693, 0.3123472567115511, 0.21253548828618868, 0.17426387406885624, 0.25286877687488285, 0.18576519191265106, 0.5862066500953266, 7.614298939704895, 36.56385980333601, 79.14107281821114, 79.69814464024135, 68.35071495601109, 61.12010683332171, 58.33431693485805, 47.43683869498116, 53.878506660461426, 40.346063068934846, 21.48014576094491, 36.24930443082537, 41.28598758152553, 61.571065766470774, 59.69684478214809, 30.105571746826172, 6.846835230078016, 0.7703955780182565, 0.2494813943547862, 0.0867467869871429, 0.21974778627710684, 0.2250138965568372, 0.486119803573404, 1.3647838405200412, 3.160928351538522, 4.705336153507233, 6.806188268320901, 9.803055320467267, 12.497071674891881, 10.285055330821447, 14.329850997243609, 11.221342461449758, 12.539848259517125, 17.432927778788976, 19.13185613495963, 8.702715141432625, 16.104915107999528, 34.55790792192732, 25.58861906187875, 10.649178283555166, 10.784476212092809, 11.196045807429723, 9.574991992541722, 14.606188671929495, 8.920987589018685, 9.04849398136139, 6.939206753458295, 7.909652096884591, 12.166647485324315, 12.286412715911865, 21.464124952043804, 28.524139165878296, 44.55959660666329, 51.24927704674857, 46.81435653141567, 44.166634287152974, 48.80765574319022, 60.10412039075579, 59.105560030256, 57.91211659567696, 52.802807399204795, 60.683259691510884, 40.262135778154644, 27.71653093610491, 25.268750054495676, 20.90733974320548, 20.45918267113822, 18.640585490635463, 14.22808073248182, 13.93340676171439, 19.163067443030222, 23.65498055730547, 21.551305736814225, 16.073795863560267, 14.578480992998395, 17.548330409186228, 19.60973412649972, 21.270730529512676, 18.847297872815812, 11.167277659688677, 11.744265624455043, 13.56146969114031, 14.218366282326834, 7.0520481041499545, 10.559939094952174, 9.069278648921422, 7.892034070832389, 5.462057948112488, 4.8851659553391595, 1.1582602539232798, 0.3996180423668453, 0.29266360721417833, 0.4743940127747399, 0.18903853983751365, 0.5765608134014266, 2.6503384581633975, 16.690000329698833, 41.00750378199986, 57.75324603489467, 61.356060709272114, 68.61605971200126, 57.04832696914673, 32.95024415424892, 22.796671322413854, 32.48255743299212, 38.11454486846924, 49.35076168605259, 60.80333151136126, 68.72866916656494, 75.05838080814907, 76.20741135733468, 47.08582959856306, 3.8106622185025896, 0.5683758897440774, 0.40714565558092936, 0.1558550697352205, 0.14179089798458985, 0.15416614179100308, 0.16934958419629506, 0.1983550020626613, 0.2005171946116856, 0.22564061864146165, 0.2853355918611799, 0.27327908309442656, 0.13930075589035237, 0.16645787150732108, 0.10650158088122096, 0.07811119394110781, 0.20718053063111647, 0.088846934294062, 0.16346847691706248, 0.14554923559938157, 0.19157775358429976, 0.1652035859546491, 0.10268003094409194, 0.26317371534449713, 0.2506003257419382, 0.25102511580501286, 0.19281777633087976, 0.14857859590223857, 0.09690856813852276, 0.10850088431366853, 0.1455153902726514, 0.23783138234700474, 0.2900403636906828, 0.32607402013880865], [0.04022053981732045, 0.07692210203302757, 0.04641505563631654, 0.17705722632152693, 0.03559442037450416, 0.027373383387124965, 0.023899779422208667, 0.09519889737878527, 0.020424867581043924, 0.044270355720072985, 0.09237741306424141, 0.0170876287988254, 0.062696744288717, 0.042727278878114054, 0.052959990687668324, 0.10724725015461445, 0.04739773379904883, 0.024735553057066033, 0.07259775764708008, 0.042199219177876196, 0.027800078437264477, 0.017749909511102096, 0.03833897578130875, 0.053588246261434894, 0.16335539227085455, 0.055357465254408975, 0.03855349123477936, 0.017197565042546818, 0.3056941937123026, 1.4922684111765452, 20.937138829912456, 54.48660952704293, 62.58464118412563, 59.62906510489327, 46.90819542748587, 32.07351350784302, 43.2548326083592, 49.705880641937256, 79.47322450365338, 60.56275708334786, 28.597227266856603, 24.531834534236364, 43.52969639641898, 39.65930312020438, 15.717099666595459, 2.2095527734075273, 0.06894643857542958, 0.02015858329832554, 0.0839144257562501, 0.07100276609084435, 0.026323095995134542, 0.16796884685754776, 0.4908002295664379, 0.1571716855147055, 1.7894885710307529, 2.45012828707695, 2.076757933412279, 2.1373516534055983, 4.331585168838501, 3.4605520452771867, 2.7821794407708302, 6.768947660923004, 8.092359321457998, 4.00923261472157, 4.786431184836796, 1.5418765949351447, 6.32457822561264, 9.405907579830714, 15.728406122752599, 6.195861543927874, 3.2804942556789944, 2.49762139575822, 3.0870112436158315, 2.5084540716239383, 6.196103428091321, 8.072195649147034, 5.64694082736969, 10.124928883143834, 18.64020160266331, 36.65612145832607, 33.341181073869976, 31.89607388632638, 58.55104514530727, 54.95706163133894, 42.98366526194981, 33.09189707892281, 38.13396508353097, 45.442629269191194, 41.43590191432408, 41.9732860156468, 44.987880093710764, 34.49997731617519, 44.00135401317051, 25.325040885380336, 36.13140392303467, 42.875700678144185, 42.732126576559885, 45.933714049203054, 41.83052485329764, 42.72757550648281, 43.374039377485005, 43.065424714769634, 41.281717913491384, 38.18186943871634, 33.41384533473423, 28.982871396201, 26.684277023587907, 24.69230318069458, 18.000149181910924, 16.341813938958303, 17.710803610937937, 8.697281650134496, 5.740675500461033, 3.6624766843659535, 3.3201398083141873, 3.748268263680594, 3.384613662958145, 1.6929095877068383, 1.279418706893921, 0.4095859117805958, 0.19864225307745592, 0.05851651395538023, 0.03225456244711365, 0.10918602147804839, 0.03392274757581098, 0.007094749856540667, 0.22824674951178686, 4.584877405847822, 21.39882230758667, 29.653407301221574, 42.3644174848284, 65.16678633008684, 30.254853793552943, 37.86427422932216, 28.521059376852854, 20.231088944843837, 23.504711866378784, 36.275902135031565, 43.97647598811558, 50.64569745744978, 56.383815152304514, 54.93732874734061, 33.274655546460835, 1.9047522374561854, 0.06420004540788275, 0.063203888147005, 0.043116937790598185, 0.0721732322126627, 0.019300294175211872, 0.02170508334945355, 0.06601102144590446, 0.032302904674517255, 0.034432184882462025, 0.03836836313296642, 0.01249813667631575, 0.050448108331433365, 0.036279618607035706, 0.08066914203975882, 0.05657253148300307, 0.06456422872309174, 0.01847914297000638, 0.05958739149251154, 0.030490127126021043, 0.03408174529405577, 0.053920555394142866, 0.05288972838648728, 0.09398815341825996, 0.047546037805399725, 0.02512129851883011, 0.015074540927473987, 0.032027490703122954, 0.041292258737874885, 0.06815141945012979, 0.01587421989201435, 0.16334684272961958, 0.04806912045127579, 0.0432286857228194, 0.022258971485176256, 0.05764821304806641, 0.08471114121909652, 0.06285875130976949, 0.04572926029296858, 0.030028696171939373, 0.02991138764524034, 0.06598660775593349, 0.0506940331709172, 0.047328560546572716, 0.0273508000453668, 0.019612776514674937, 0.06821288115211896, 0.03804419981315732, 0.04117779327290399, 0.027440057934394906, 0.024572585908962146, 0.01900043258709567, 0.026504549829821502, 0.04545332384960992, 0.05900909645216806, 0.008096426575710731, 0.04214109247550368, 0.22102394779878004, 0.015944441481094276, 0.04975732236302324, 0.03416158850970013, 0.29646614460008486, 2.0412802142756323, 30.653107166290283, 68.82740306854248, 71.79078197479248, 68.10772255488804, 57.416748251233784, 41.23972994940621, 53.461725916181294, 58.67907960074288, 84.02256447928292, 59.410377502441406, 20.96429065295628, 24.32115125656128, 36.76939793995449, 37.78160456248692, 13.99655112198421, 2.270241814000266, 0.10560569752539907, 0.03458493668586016, 0.02615309752789991, 0.4753306625144822, 0.7480096220970154, 1.5401301000799452, 3.914939045906067, 2.9713235199451447, 5.095006763935089, 4.2038759759494235, 4.445332825183868, 4.318825236388615, 6.731609778744834, 6.192493838923318, 7.956436923571995, 7.1049529910087585, 10.312617097582136, 5.8133988210133145, 5.622821893010821, 3.5896107086113522, 4.416662386485508, 3.8152858104024614, 4.028246360165732, 4.495294281414576, 2.280448717730386, 2.246800546135221, 2.240784057549068, 3.319671239171709, 6.078040940420968, 6.737542237554278, 6.116807545934405, 11.347843970571246, 20.54769924708775, 38.244128772190635, 36.43422031402588, 36.90039927618844, 62.14197145189558, 55.915617738451274, 47.47254548754011, 38.26538678577968, 43.52071932383946, 50.78519296646118, 49.71496541159493, 47.66212361199515, 50.469088145664756, 41.83224105834961, 48.098803997039795, 29.79748167310442, 39.38108335222517, 46.84193045752389, 45.44729845864432, 48.61886623927525, 43.98805863516671, 45.69674573625837, 46.875205380576, 48.22563294001988, 44.3081065586635, 40.932494504111155, 36.420643533979145, 35.13243709291731, 32.70863444464547, 27.381108386175974, 22.067344972065516, 16.865477085113525, 15.444575684411184, 9.311403393745422, 6.283265105315617, 5.907460059438433, 5.521216647965567, 4.892796380179269, 4.939660242625645, 5.320797162396567, 4.780561259814671, 2.267241277865001, 1.8492035610335213, 0.6626947543450764, 0.17372040823101997, 0.1766123380511999, 0.03198612381571105, 0.029251661617308855, 0.2770057874066489, 5.186071157455444, 23.1349322114672, 36.612726484026226, 49.44323526109968, 57.441931997026714, 22.270369597843715, 23.51738885470799, 30.04583808353969, 23.984627417155675, 32.503384658268516, 44.09896578107561, 51.77989707674299, 57.85179580960955, 64.40654223305839, 64.05568599700928, 44.02770158222744, 3.654798924922943, 0.11153223272413015, 0.047356604398893457, 0.05969772128654378, 0.03964099966521774, 0.060811115827943595, 0.05446427907528622, 0.06229869529072728, 0.06749663315713406, 0.061518061107822826, 0.03178661416417786, 0.04026374214195779, 0.08745408510523182, 0.01132216424282108, 0.010322228390058237, 0.06455445103347301, 0.045566995428608995, 0.10823814876909767, 0.10730016910071884, 0.039733450061508586, 0.03591525887272187, 0.07362628102834735, 0.0647563762696726, 0.09361263856823955, 0.0437505945031132, 0.04591992524053369, 0.062448631173798015, 0.05097098063145365, 0.008080878793927175, 0.052875177203012366, 0.039852631344859085, 0.12917140871286392, 0.05874463064329965, 0.2444483744246619, 0.14601553843489715, 0.20968667258109364, 0.21390660399837153, 0.10774355102330446, 0.07926733618868248, 0.09286964272281953, 0.17705607281199523, 0.120452098016228, 0.1912570372223854, 0.12307783854859215, 0.13571501044290407, 0.1799136416188308, 0.14696398111326353, 0.19015550347311155, 0.22571600388203347, 0.1917363272181579, 0.07219704200646707, 0.1823160219937563, 0.13477503588157042, 0.20434400998055935, 0.17432927127395356, 0.13626804362450326, 0.1799226389931781, 0.48285708150693346, 0.18406136333942413, 0.281258763479335, 0.18308002528335365, 0.4500378082905497, 3.8779103585651944, 41.457656724112375, 82.61711760929653, 79.97791385650635, 76.41857406071254, 66.51251343318394, 48.16977289744786, 55.82791062763759, 59.45206669398716, 83.37675026484898, 66.8002244404384, 38.69433729989188, 33.4149500983102, 55.952078410557334, 51.5912778036935, 20.28979080063956, 3.2232126551015035, 0.38527609195028034, 0.16209096940500395, 0.2306258018527712, 0.4141740841524941, 0.6503922087805611, 1.3182221161467689, 3.8984635642596652, 3.8755636044910977, 7.267806172370911, 7.649072068078177, 6.2331811870847424, 7.540260672569275, 11.890338471957616, 11.845053587641035, 11.684307881764003, 16.18058099065508, 18.073160852704728, 10.104630589485168, 11.244998472077505, 9.656654170581273, 15.496716703687396, 18.229550906590053, 24.298105818884714, 12.289826886994497, 8.785242370196752, 9.549453888620649, 9.559293406350271, 7.538633925574167, 12.952885661806379, 14.177682842527117, 9.642148068972997, 14.033142941338674, 23.534752402986797, 42.118312290736604, 41.74769537789481, 38.71711002077375, 63.71904577527727, 57.11380679266793, 51.941929067884175, 42.097912379673545, 49.043838909694124, 54.92556197302682, 54.790690490177695, 55.04962205886841, 57.378838879721506, 47.191035747528076, 52.505608626774375, 35.48895263671875, 41.87310341426304, 48.182540212358745, 46.49937731879098, 50.613426549094065, 44.860606466020855, 46.66103410720825, 51.468020234789165, 50.18489292689732, 45.90336431775774, 44.87049722671509, 43.3099422454834, 39.81432090486799, 34.55026837757656, 30.07412420000349, 23.804276500429424, 22.930378981998988, 22.663012300218853, 13.667087520871844, 12.416087814739772, 10.129420025008065, 9.751623885972158, 10.12709845815386, 9.3230459690094, 8.674133726528712, 5.820822102682931, 3.321991503238678, 1.4967562960726875, 0.6797139868140221, 0.13320624934775488, 0.30989587253757883, 0.0910986459680966, 0.12022689224353858, 0.4596277879817145, 7.461043391908918, 30.154580865587505, 42.48519107273647, 53.91397374016898, 73.26903206961495, 40.4271103313991, 53.092245033809114, 41.91978488649641, 30.175741604396276, 35.70377704075405, 51.51337112699236, 60.83851024082729, 64.53071349007743, 72.49767085484096, 71.14789295196533, 51.8459848676409, 5.486667598996844, 0.3551194172884737, 0.18673955462872982, 0.2824618060673986, 0.12848391703196935, 0.24490193437252725, 0.13368826705430234, 0.17275692921664032, 0.21918867342174053, 0.17243060815547193, 0.1405856976551669, 0.15341014521462576, 0.1418642069080046, 0.08247453373457704, 0.19110021420887538, 0.14045574462839536, 0.19106103559689863, 0.1493904630520514, 0.19743228943220206, 0.20574092359415122, 0.1265181875122445, 0.208554726892284, 0.22890818544796535, 0.2016461276050125, 0.18257257608430727, 0.19554349221289158, 0.11515324163649764, 0.16054696297006948, 0.13856295762317522, 0.21757605352572032, 0.416608314961195, 0.37298415867345674, 0.15430809131690434], [0.09412462038121053, 0.04213442926162055, 0.08287238595741135, 0.07213583814778499, 0.03844939039221831, 0.08116235557411398, 0.05038656181256686, 0.01016095927583852, 0.017796032928994725, 0.01622821670025587, 0.057217261887022426, 0.058244027862591405, 0.01953961347628917, 0.0592124941093581, 0.056163405400833914, 0.018810688750818372, 0.02677418098651937, 0.011346192016000194, 0.014529171798910414, 0.03233024963576879, 0.05294217235807862, 0.04475891789687531, 0.03535991867205926, 0.0489790460893086, 0.027552024694159627, 0.03248896236930575, 0.07253432819353682, 0.020639961485617926, 0.5701665707996914, 22.116246393748693, 58.35457788194929, 60.36779063088553, 55.02115181514195, 46.643639292035786, 37.17302227020264, 44.12623746054513, 30.54103967121669, 18.98131820133754, 19.222613504954747, 18.254753759929113, 30.352173737117223, 43.19991752079555, 37.77534770965576, 15.357393162591116, 1.9080904126167297, 0.08422691827373845, 0.055199047683605125, 0.07317954035741941, 0.09521351302308695, 0.121913309608187, 0.6227550432085991, 0.8102496308939797, 1.931969634124211, 2.5957961848803928, 1.7623924421412605, 2.5572152265480588, 1.8674669010298592, 3.1758808749062672, 4.7660225885255, 3.317662341254098, 3.9198036534445624, 3.901433050632477, 7.09903746843338, 4.897330514022282, 3.477623334952763, 3.8221115469932556, 5.741178376334054, 7.92708512714931, 11.212833523750305, 13.817654984337942, 12.88748834814344, 15.001442159925189, 12.741592679704938, 19.216268062591553, 20.753155742372783, 25.82751897403172, 32.20557791846139, 41.374716077532085, 47.90372289930071, 59.00600624084473, 43.16647931507656, 43.35946553094046, 56.92864772251674, 57.75295768465315, 52.180644852774485, 32.389927523476736, 41.268888064793174, 39.78681298664638, 36.04456186294556, 35.11083861759731, 34.90276091439383, 44.3792839050293, 53.64039189474923, 38.922359807150706, 50.33918115070888, 54.180739402770996, 58.503130367824006, 62.05598054613386, 54.851515020642964, 50.856446743011475, 55.18074151447841, 53.922092710222515, 55.6803343636649, 51.044218335832866, 54.37304469517299, 51.98881551197597, 54.78843232563564, 47.622400760650635, 45.55692366191319, 41.361681256975444, 34.724400656563894, 19.57483332497733, 13.680692093712942, 10.10866401876722, 7.046594202518463, 5.687037144388471, 1.8649894339697701, 3.350433085645948, 3.4234944794859206, 1.1214055972439902, 1.866759704692023, 0.28795517129557474, 0.3590861330074923, 0.09713686124554702, 0.030449537161205496, 0.1439511634941612, 0.08407369828117744, 0.227574565580913, 4.0507976072175165, 27.497779062816075, 33.23531484603882, 47.032290254320415, 81.6557092666626, 89.0417069026402, 46.488750049046104, 43.73665196555001, 21.24944646017892, 21.48567305292402, 29.85980006626674, 38.68001706259591, 53.641712052481516, 54.656704902648926, 57.23569556644985, 31.694346836635045, 1.7032209315470286, 0.047110747412911484, 0.052250843561653576, 0.03948550318766918, 0.03541844231741769, 0.031246958300471306, 0.0022462615535394953, 0.07399556692689657, 0.0467221639784319, 0.011697781721263059, 0.07513101385640246, 0.04879835221384253, 0.01391660310660622, 0.09579446792070355, 0.10850195639899798, 0.025971687797989165, 0.03240653732791543, 0.03628496885565775, 0.035843072924762964, 0.021668601914175918, 0.05679167793797595, 0.012252802162298133, 0.052851319911756685, 0.043346482794731855, 0.02402836859359273, 0.05147707276046276, 0.02198108594997653, 0.0218584797611194, 0.057103742978402545, 0.01881702626789255, 0.042931955573814254, 0.023041100141459277, 0.012262646009081175, 0.021143785611327206, 0.05535813361140234, 0.04665304161608219, 0.03585622293342437, 0.06409973757607595, 0.04706048832408019, 0.05494298892361777, 0.08241755714906113, 0.02284196368418634, 0.04826883366331458, 0.02167764169696186, 0.02141268564654248, 0.0028576334797045483, 0.03705234107162271, 0.04517163682196822, 0.026440553799537674, 0.05215230331357036, 0.03800710091101272, 0.02063263500375407, 0.040055587954287014, 0.05891779278005872, 0.05660352696265493, 0.04932412525106754, 0.03456549665757588, 0.031407431832381656, 0.04801599455199071, 0.0820959722623229, 0.8280451074242592, 30.275503839765275, 70.32414926801408, 68.17652361733573, 63.954659189496724, 56.297285761152, 43.68609687260219, 50.47928810119629, 43.81788682937622, 30.573011807032994, 33.83273138318743, 34.4599244253976, 31.520426477704728, 34.558206694466726, 35.33365345001221, 14.863584688731603, 1.5268959530762263, 0.08266440818884543, 0.07234053180686065, 0.0863613790965506, 0.1926778488393341, 0.5869959220290184, 1.7787359080144336, 3.4322474726608823, 3.5123059196131567, 3.96105033159256, 3.9120025634765625, 3.7837618333952765, 3.9140171068055287, 7.082204154559544, 4.955810461725507, 7.853820715631757, 6.177469662257603, 4.4916130389486035, 6.087124841553824, 2.8291242931570326, 4.393909207412174, 5.459916600159236, 7.5225479773112705, 10.766394393784658, 11.857028807912554, 12.697803395135061, 13.964777009827749, 14.068510140691485, 15.02397516795567, 19.286345856530325, 21.636388165610178, 25.181048154830933, 33.59392179761614, 41.893892424447195, 50.90896817616054, 60.433103697640554, 48.890943799700054, 47.459250109536306, 60.053926604134695, 57.08166790008545, 54.67602089473179, 37.27120379039219, 47.16426086425781, 45.720783029283794, 41.93454286030361, 41.4110621043614, 42.76410566057478, 48.594099385397776, 57.672476700374055, 41.417103563036235, 54.55922515051705, 54.683688231876914, 56.50201790673392, 62.743900844029014, 55.18264879499163, 54.10559810910906, 58.330314772469656, 54.974876812526155, 57.663301604134695, 56.310866015298025, 57.58516911097935, 55.558970178876606, 55.64346374784197, 50.86092138290405, 44.054455620901926, 43.07571152278355, 34.97457749502999, 20.733478443963186, 14.710243156978063, 7.869745118277414, 5.950475488390241, 3.4146828608853474, 3.523088438170297, 2.8103053144046237, 4.67769752229963, 2.891717791557312, 3.992396261010851, 1.9756316798073905, 1.0674778052738734, 0.4333684284772192, 0.08977760614028998, 0.03872258894677673, 0.08634643775543996, 0.3012309803494385, 3.111283038343702, 21.08007890837533, 32.4876435143607, 54.110249928065706, 74.50814601353237, 81.66421386173793, 44.693623883383616, 41.297281878335134, 24.745517696653092, 28.04372681890215, 40.57019111088344, 43.762513160705566, 60.598158155168804, 62.51857076372419, 66.3592917578561, 40.30173008782523, 2.4848449613366808, 0.08816639081175838, 0.028652844285326343, 0.012019096890331378, 0.0322056400722691, 0.033737215745661936, 0.04021968825587204, 0.027619959620226706, 0.013112923329962152, 0.012930389776426767, 0.05667765012809208, 0.051097218678998094, 0.09141520291034665, 0.09236688220075198, 0.02293288059133504, 0.025957430080909814, 0.038202362933329174, 0.0477377239481679, 0.09462003236902611, 0.03331933995442731, 0.04080886021256447, 0.047608669980296066, 0.026342759939974973, 0.02724889256725354, 0.02813136637476938, 0.006565308489371091, 0.0063208933903037435, 0.02329918772115239, 0.01737466098607651, 0.06312130364988532, 0.03874814257557903, 0.037892316534583054, 0.1412448130015816, 0.14189118546034607, 0.20811526690210613, 0.13882503498877796, 0.08834034004913908, 0.1741870774754456, 0.12181363281394754, 0.13549607433378696, 0.23158245480486325, 0.14477144447820528, 0.13961144350469112, 0.11699303505676133, 0.17880795523524284, 0.15190587379038334, 0.20773824570434435, 0.14014645479619503, 0.13633496074804238, 0.11166346818208694, 0.13389926430370125, 0.09367600016828094, 0.17619773958410534, 0.23397567495703697, 0.13070983758994512, 0.2602511835949761, 0.08785030884402138, 0.18657792758728775, 0.18548908244286264, 0.24361725045101984, 1.882925122976303, 40.18199178150722, 84.88934530530656, 78.319093976702, 71.86896310533795, 65.07753671918596, 53.41697604315621, 58.08586324964251, 41.70600618634905, 27.7433249269213, 28.189788375582012, 25.6037209715162, 40.7295515196664, 56.80507401057652, 49.9267395564488, 20.85707300049918, 2.4350685008934567, 0.2251698781869241, 0.16218785063496657, 0.3264222985931805, 0.33532323954360826, 0.48597345714058193, 1.4063118121453693, 5.976717097418649, 6.598019804273333, 7.490036487579346, 6.29643063885825, 7.610931668962751, 6.913170550550733, 11.371242897851126, 12.58543712752206, 8.61972325188773, 9.87163838318416, 12.387811252049037, 18.12560064452035, 13.27047392300197, 10.799431341035024, 10.572694250515529, 10.577161073684692, 13.543987154960632, 17.302112306867325, 21.378887925829204, 18.19122985431126, 18.630500180380686, 18.058484520230973, 24.518335921423777, 25.807218074798584, 30.311519827161515, 35.28875419071743, 46.74824789592198, 50.94310467583792, 62.602866309029714, 52.54762090955462, 52.281803676060264, 64.6351866040911, 59.500544275556294, 56.94388859612601, 40.68198067801339, 52.64497559411185, 49.934889793395996, 46.6706087248666, 46.74989461898804, 48.46822234562465, 50.73847327913557, 60.66949531010219, 44.795950004032676, 56.348382813589915, 55.1520801952907, 57.48774494443621, 62.12071691240583, 54.63762514931815, 55.30115032196045, 57.95573043823242, 54.50537313733782, 61.060275895254954, 58.74820722852434, 56.432977131434846, 54.846154485430034, 57.144323280879426, 52.106802872249055, 48.525041239602224, 45.61644887924194, 41.17945780072893, 22.784597090312413, 19.09852041516985, 15.769652366638184, 12.99156367778778, 12.035660914012364, 7.796096818787711, 9.654751232692174, 10.365254044532776, 5.937677340848105, 6.868978270462581, 2.5393598760877336, 1.5976261177233286, 0.4124802436147417, 0.27139297287378994, 0.36152926619563786, 0.14973723515868187, 0.5668181904724666, 5.724707237311772, 36.53398254939488, 44.8697190284729, 57.480324268341064, 88.66745608193534, 96.33657196589878, 56.48874337332589, 54.84376777921404, 31.31119884763445, 34.11737476076399, 44.870761258261545, 53.89908375058855, 71.1961898803711, 71.12977899823869, 73.64087881360734, 48.09429114205496, 3.665620744228363, 0.17610410175153188, 0.14108811212437494, 0.1180342606135777, 0.24392041989735194, 0.1383891576634986, 0.14327178709208965, 0.20700185879000596, 0.09539810847491026, 0.1106288990538035, 0.15366794780961104, 0.21168297688875878, 0.23694347856300219, 0.22088448171104702, 0.20735187429402555, 0.12428195322198526, 0.24774529465607234, 0.1263269084904875, 0.1670472470245191, 0.08175743078546864, 0.11972006729670934, 0.1990986085895981, 0.09887106783155884, 0.24222351238131523, 0.1039872354428683, 0.12623658190880502, 0.07556757650205068, 0.17831594949322088, 0.12770053478223936, 0.29231755435466766, 0.14735318879996026, 0.09972140113157885], [0.005212563688733748, 0.022992087860724757, 0.0872905853071383, 0.0222967777600778, 0.026150169649294445, 0.05589686666748353, 0.07789207462753568, 0.034597974736243486, 0.07919695175119809, 0.023377758683636785, 0.00986914596121226, 0.014858481806835957, 0.0376513721421361, 0.014999579771288803, 0.07564693795783178, 0.028011715205918466, 0.04538024223542639, 0.03599910883765135, 0.006737252655771694, 0.04906671620639307, 0.01332070177886635, 0.017311326527435864, 0.07501898772482361, 0.0671748582805906, 0.032313136982598474, 0.08247373306325503, 0.03428684946681772, 0.7865671845419067, 16.149327993392944, 53.94678313391549, 66.4282317842756, 61.27128573826381, 54.41527584620884, 42.51762873785836, 44.15450273241316, 32.442792892456055, 17.488013097218104, 20.273340940475464, 21.78348674092974, 14.023674283708845, 27.635811976024083, 40.09413528442383, 14.216898475374494, 1.600190437265805, 0.00981448742095381, 0.030811756117535487, 0.040703358195189915, 0.07584577585969653, 0.16172871312924794, 1.021563566156796, 1.6029000175850732, 2.372294566461018, 4.511950416224344, 1.7449221738747187, 4.058560047830854, 3.007631548813411, 4.4911136371748785, 5.183978446892329, 3.468324039663587, 5.480558395385742, 8.69743972165244, 4.849942931107112, 8.224915317126683, 7.584326148033142, 13.349817139761788, 14.467186485018049, 26.570350885391235, 28.502264499664307, 31.566260269709996, 39.17957169669015, 44.71296419416155, 46.349379607609336, 54.19208928516933, 57.77731112071446, 58.67518860953194, 55.71191740036011, 50.873838084084646, 49.10540689740862, 53.001751695360454, 55.8570305279323, 59.883007866995676, 56.58838401521955, 54.87750128337315, 56.67339522497994, 54.08784546170916, 40.06699909482683, 33.931969029562815, 34.767757415771484, 32.94872944695609, 32.8902325630188, 36.150636536734446, 56.97224072047642, 56.796899454934255, 61.619946343558176, 60.32805388314383, 57.9399858202253, 55.04968111855643, 56.21179512568882, 53.00673702784947, 54.28024802889143, 55.36735623223441, 54.3073981148856, 56.06868655341012, 57.92271607262747, 54.532141072409495, 56.657261507851736, 60.64177199772426, 58.88306481497628, 59.30127688816616, 54.287029470716206, 48.73142358234951, 41.98428153991699, 32.57499974114554, 27.686896869114467, 17.630362578800746, 8.14766698224204, 4.881060438496726, 1.433561235666275, 3.778504652636392, 2.9935961876596724, 4.505076476505824, 1.6284673256533486, 1.5036204648869378, 0.17434626179082052, 0.016220690050561513, 0.028131664930177585, 0.01791017100081912, 0.05373498285189271, 0.013713668549566396, 3.3694494366645813, 24.461021968296595, 25.67011274610247, 32.87005499431065, 40.20288154057094, 45.080791405269075, 48.21210132326399, 41.50023528507778, 17.79001133782523, 24.734947749546595, 33.77144479751587, 39.746520383017405, 52.30128295081002, 55.24891723905291, 46.43162196023123, 24.481711966650828, 0.8787093088030815, 0.1344700072492872, 0.028697831157062734, 0.03590811389897551, 0.016585906435336386, 0.024532827149544443, 0.042181485665163825, 0.10106836099709783, 0.03971128910779953, 0.035874729976058006, 0.008962562108146293, 0.03563994328890528, 0.004459691342032913, 0.05028694608647909, 0.06697502971759864, 0.015820278054369346, 0.06605652400425502, 0.025497083086520433, 0.02141745914039867, 0.05890480561980179, 0.03097202948161534, 0.012507166281076414, 0.02142824954353273, 0.03416637557425669, 0.02029840392060578, 0.06228061911783048, 0.04804930383605616, 0.018669926661199758, 0.04207269275294883, 0.01011782480470304, 0.029823228982942443, 0.028735625557601452, 0.023391227603756955, 0.008508628117851913, 0.034042393655649254, 0.07868063409945794, 0.026881462461980324, 0.065647475953613, 0.020394984898822646, 0.10822486983878271, 0.030089374165982008, 0.03894258357052292, 0.053294427027659755, 0.042537957429885864, 0.043205578212759325, 0.03229300145592008, 0.03629491278635604, 0.018077309442950145, 0.07272750032799584, 0.044112314736204486, 0.08935347425618342, 0.014453964673780968, 0.029520734678953886, 0.06446058928434338, 0.12799162630523953, 0.030858171305486133, 0.03556659704606448, 0.03595963167026639, 0.8924823211772102, 20.533392906188965, 61.52980736323765, 72.51115036010742, 69.51080703735352, 64.50846535818917, 50.84317568370274, 53.60549109322684, 46.50317103522164, 25.63138175010681, 25.190561975751603, 25.145629712513514, 17.601020336151123, 27.001552615846904, 36.661586216517854, 15.179350784846715, 1.4827816230910165, 0.01552343085807349, 0.055474743247032166, 0.10808317815618855, 0.3666560325239386, 0.706306805568082, 2.3659080862998962, 3.0059186007295335, 2.7463150109563554, 7.079376237733023, 7.085514536925724, 6.209359288215637, 5.763466026101794, 5.038037180900574, 7.157960798059191, 5.871556546006884, 5.699418834277561, 8.206220320292882, 5.147153862885066, 7.218807910169874, 10.702576058251516, 15.115972791399274, 14.988096407481603, 26.594092879976543, 30.104553835732595, 34.1926828111921, 42.8019038609096, 49.66235017776489, 50.330315249306814, 57.350031648363384, 59.299456460135325, 59.564988817487446, 55.926293645586284, 53.41140011378697, 51.55644995825631, 56.18358196531023, 56.90827213014875, 63.76296533857073, 61.45773369925362, 59.93403543744768, 57.89889069965908, 56.565979548863, 43.938740321568076, 40.426582268306184, 41.226511001586914, 37.94798960004534, 39.16654035023281, 41.706575938633506, 56.72252941131592, 57.86345836094448, 62.261549949645996, 61.987123898097444, 57.2096710886274, 56.25695146833147, 56.39914982659476, 54.06612886701311, 56.63371058872768, 56.335250718253, 55.40312555858067, 59.241084643772666, 59.008021218436106, 55.92673485619681, 57.59915236064366, 61.69197831835066, 61.77166025979178, 62.006377356392996, 56.61579465866089, 50.64791740689959, 43.11977699824742, 33.96871110371181, 25.85003808566502, 17.529417412621633, 9.048221264566694, 5.742155466760908, 2.182900135006223, 3.1554336292403082, 3.7206513455935886, 5.747165986469813, 3.478684889418738, 2.1361491807869504, 1.9769618255751473, 0.3543665962559836, 0.14019644925636904, 0.11927245131560735, 0.024186535106439675, 0.043898135157568116, 3.1279804280826022, 20.270750999450684, 30.012809821537562, 41.633275917598176, 43.512562138693674, 48.37682226725987, 46.53641816547939, 39.826115471976145, 23.439846958432877, 34.32459783554077, 41.5297269139971, 47.52278791155134, 58.59430462973458, 63.61070251464844, 57.40216745649065, 33.85435765130179, 1.0688194589955466, 0.04432199562766722, 0.04410819602864129, 0.03921615531934159, 0.07028184298958097, 0.04691408421578152, 0.015023603303624051, 0.026552325480484536, 0.0018735774668000105, 0.0625525623826044, 0.025135208486712406, 0.037642985449305603, 0.0355552892599787, 0.14777535971786293, 0.02539358614012599, 0.029081566458834068, 0.07535342406481504, 0.019812443925599967, 0.048858151505036015, 0.10784277319908142, 0.021121565285804014, 0.05013084910543902, 0.02841072602729712, 0.053276299964636564, 0.03984600545040198, 0.016803631359445195, 0.057155338781220574, 0.038840779569000006, 0.03591438016987272, 0.019104891356879046, 0.02560903288290969, 0.11009635762976748, 0.12190945552928106, 0.19426654359059675, 0.12128941022924014, 0.1477762825254883, 0.10020550194063357, 0.1176091448536941, 0.09045652792389904, 0.18584508262574673, 0.11969831346401147, 0.10999847216797726, 0.11288109248770134, 0.16241570269422873, 0.08898116887680121, 0.17143265956214496, 0.10554924341184752, 0.11524390748568944, 0.15824690567595617, 0.147613773388522, 0.17115087753960065, 0.14650443648653372, 0.09940137687538352, 0.1324710702257497, 0.231923052242824, 0.13721443712711334, 0.11155856666820389, 0.12749397515186242, 1.4528995922633579, 28.939003944396973, 75.12823799678257, 81.51545987810407, 78.06556810651506, 72.17189761570522, 58.73857702527727, 57.50378833498274, 44.12118264607021, 24.91862337929862, 27.886864287512644, 28.984533752713883, 21.361347198486328, 37.755868434906006, 51.03576585224697, 19.33504925455366, 2.408166378736496, 0.072417063771614, 0.12997216145907128, 0.15910803446812288, 0.4253657864672797, 0.42010865999119623, 3.4941470197268893, 5.645224188055311, 6.347294926643372, 11.617162227630615, 7.942360741751535, 10.597784195627485, 8.072807959147863, 9.97251580442701, 10.906920841761998, 11.248427408082144, 14.571035129683358, 17.550361020224436, 11.998363852500916, 14.56948481287275, 14.285679561751229, 20.30809930392674, 19.488010372434342, 31.153697081974574, 33.104042530059814, 38.08327102661133, 46.19697781971523, 52.93398938860212, 55.470575196402415, 59.31267193385533, 62.45625237056187, 62.938276699611116, 59.61192389896938, 54.42116444451468, 53.414870738983154, 58.833044733319966, 58.67527198791504, 66.28728757585797, 64.02273069109235, 59.98519502367292, 57.59751953397478, 57.51665987287249, 47.02127388545445, 44.56923028400966, 44.96396092006138, 42.19007675988333, 44.25433097566877, 46.5931328364781, 61.02884224482945, 58.496251651218955, 62.28789751870291, 61.993780272347585, 57.976373536246165, 55.21211610521589, 56.422214371817454, 53.83675493512835, 55.74113457543509, 56.48615516935076, 58.80519635336739, 57.63689150129046, 55.823050362723215, 55.279065472739084, 61.28286143711635, 64.93749577658517, 64.69886684417725, 65.11374378204346, 58.76967716217041, 53.49979509626116, 48.03691291809082, 38.86021859305245, 32.5228396143232, 22.050757884979248, 12.031996607780457, 10.343758055141993, 7.009583754198892, 9.484792215483528, 8.855437414986746, 13.216823407581874, 7.345079694475446, 3.5638031448636736, 1.4839574971369334, 0.1275851973997695, 0.1479206069239548, 0.23831441785608018, 0.18683703296950885, 0.22547162270971707, 4.51809913771493, 32.388461453574045, 35.952755314963206, 43.383419445582796, 47.466246945517405, 52.43131501334054, 60.46776131221226, 54.98059170586722, 30.24588019507272, 37.1158698626927, 48.990237031664165, 54.76175471714565, 68.33632523672921, 71.14284855978829, 65.33976868220738, 41.23524488721575, 1.8172320766108376, 0.24914684944919177, 0.0977787689438888, 0.1326364834925958, 0.14921196763004574, 0.17605964413711003, 0.09921915629612547, 0.1122685857117176, 0.08613246852265936, 0.19446981911148342, 0.08894460262464625, 0.1013505162139024, 0.15355528385511466, 0.2466514419232096, 0.0913730998124395, 0.081067862787417, 0.11768733922924314, 0.12738953504179204, 0.14531396036701544, 0.18128402451319353, 0.11764212165560041, 0.11519555508026055, 0.11735314716185842, 0.15046856020178112, 0.14717333630791732, 0.1138870817209993, 0.12648016240979942, 0.13004632533660956, 0.13996015622147492, 0.051924152698900015, 0.20107085204550199], [0.06588763663811342, 0.09581754489668778, 0.05601698432915977, 0.03636940236070326, 0.009977712412364781, 0.003834208007901907, 0.06293586681463889, 0.03058896932218756, 0.012202970550528594, 0.01928629430143961, 0.02936724666506052, 0.07456867795969759, 0.06959532839911324, 0.08567809433277164, 0.017408066961382116, 0.062032723134117465, 0.048029965588024685, 0.015527641167864203, 0.03146021167880722, 0.015088567942646998, 0.05133411900273391, 0.0718083025089332, 0.017870597142193998, 0.017474395455792546, 0.018150937277823687, 0.07920155221862452, 0.06410889779882771, 5.318487754889897, 31.56629501070295, 65.35010065351213, 60.19532939365932, 59.074821199689595, 40.5629962512425, 43.999901839665, 25.598369121551514, 14.012333955083575, 25.947490045002528, 33.76343699863979, 33.36822346278599, 43.18825844355992, 51.55471290860857, 22.906518868037633, 1.8374845555850436, 0.012955242817822312, 0.059753517221127234, 0.0729420395301921, 0.27291848244411604, 0.4966647263084139, 0.9520110126052583, 1.8095102395330156, 2.2807379364967346, 2.672745964356831, 3.805783714566912, 5.279900065490177, 3.3829230793884824, 3.0324602850845883, 2.5709765681198666, 7.218011038643973, 5.685520700045994, 11.851766416004725, 12.275828003883362, 9.264319794518606, 13.857502903257098, 17.579783167157853, 28.427779810769216, 30.496991566249303, 40.55265038354056, 45.2909049306597, 51.82352134159633, 53.63571923119681, 62.7158579145159, 59.09253215789795, 56.5878073147365, 55.3653620992388, 55.06767347880772, 53.5685579436166, 57.39083841868809, 51.93763508115496, 55.82264041900635, 55.71697221483503, 57.819344248090474, 57.43221146719796, 59.85074738093785, 61.23558589390346, 61.97826494489397, 51.77110413142613, 30.92642845426287, 33.3493104662214, 35.16850519180298, 27.13757402556283, 50.83804096494402, 45.840827056339805, 53.493649414607454, 58.11173139299665, 58.959654808044434, 56.155757904052734, 58.80017280578613, 55.23850883756365, 53.670043332236155, 51.87069961002895, 52.606180327279226, 55.23498262677874, 59.734886169433594, 52.29028395244053, 58.441353934151785, 58.64506122044155, 58.65735953194754, 55.88548687526158, 58.27365568705967, 57.18554694311959, 57.519605909075054, 56.12725986753191, 47.035291876111714, 36.59020389829363, 31.283468587057932, 23.019685915538243, 17.622422524860927, 7.518037727900913, 3.672274078641619, 1.34196161372321, 2.667823599917548, 2.436506126608167, 1.3172152787446976, 1.463787636586598, 0.5445590934583119, 0.040826624259352684, 0.11511769997222082, 0.0881319958716631, 0.0410398810303637, 0.09891192921038185, 2.661262112004416, 21.64536871228899, 36.38662167957851, 40.32495444161551, 25.746021815708705, 29.880033220563615, 48.236743109566824, 35.220081669943674, 15.700960738318306, 26.91402963229588, 36.70447397232056, 46.71121399743216, 58.13849932806832, 60.0840539932251, 52.82967608315604, 18.39010293143136, 0.35151669489485876, 0.022447767068764994, 0.08562462577330214, 0.05804307293146849, 0.021894682997039387, 0.05161186374191727, 0.03157168819702097, 0.05624176601746252, 0.0460537119901606, 0.031837365190897665, 0.02114498831464776, 0.039806015989077945, 0.03652040693642838, 0.042828577371048074, 0.026890860171988606, 0.02178491129805999, 0.06695408334157296, 0.0991313877914633, 0.03654707336266126, 0.10735612109835659, 0.045234431845269034, 0.10808623156377248, 0.045027695795787234, 0.05743703259421246, 0.06253815708415848, 0.07504274323582649, 0.057319666392036846, 0.06018419696816376, 0.021487149775826504, 0.016513031774333546, 0.03830217543457236, 0.037522786363427124, 0.04713838075154594, 0.019845819366829734, 0.035099785309284925, 0.01077712420374155, 0.04300654014306409, 0.05512785918212362, 0.05391457410795348, 0.0612956237580095, 0.07496380925710712, 0.06513461204511778, 0.07096399459987879, 0.030134825834206173, 0.049611091281154325, 0.024427747520219003, 0.09184027795812913, 0.03588284525488104, 0.03705438006935375, 0.016340655041858554, 0.020017700768741112, 0.05663331804264869, 0.014281940779515674, 0.035085508932492564, 0.03756531693839601, 0.05391839765278356, 0.13188792366002286, 6.329427633966718, 39.28070967538016, 75.66607025691441, 69.36545767102922, 66.93642997741699, 48.70304019110543, 52.68678985323225, 39.06820249557495, 24.365256684167043, 25.585381201335363, 26.95519597189767, 26.14201181275504, 37.22653382165091, 43.30226796013968, 18.040815251214163, 1.6407137428011214, 0.09366026494119849, 0.0717390715809805, 0.4477878947343145, 0.6380269122975213, 1.3033760956355502, 1.9273623270647866, 3.7202331508908952, 5.708505340984889, 6.325092826570783, 4.90254122870309, 7.459710206304278, 5.860950120857783, 4.179605918271201, 5.268815951687949, 6.0738959056990485, 7.814051832471575, 11.860077330044337, 10.154808742659432, 11.068222403526306, 14.605537278311592, 21.269587550844463, 29.419437135968888, 35.305217947278706, 43.126488958086284, 50.6152469771249, 54.16803114754813, 57.55810240336827, 63.04133932931082, 62.17874826703753, 60.08676379067557, 58.73337977273123, 57.43483093806675, 56.89226000649588, 57.32314211981637, 54.34597451346261, 56.09025723593575, 57.52654715946743, 59.52225739615304, 59.98109558650425, 60.96696853637695, 61.07297025408064, 61.30901445661272, 52.772871085575645, 35.925768511635916, 36.901684692927766, 39.344445501055034, 33.837417943137034, 52.31545032773699, 48.57639537538801, 54.37686620439802, 59.16302858080183, 56.89772129058838, 55.88281181880406, 58.594575609479634, 54.917227608816965, 53.65543474469866, 50.59914105279105, 53.36036212103707, 55.979683603559224, 58.34182793753487, 52.99253143583025, 59.08908585139683, 61.219097818647114, 60.45633847372872, 59.1751948765346, 61.21973705291748, 59.39657143184117, 59.87400300162179, 57.27347639628819, 47.016733237675254, 37.004260948726106, 31.24151188986642, 23.83089852333069, 18.089080912726267, 8.66922048160008, 5.197342004094805, 3.2082486237798418, 3.0263586810656955, 4.249566027096339, 2.4676342734268735, 3.1863526787076677, 2.386557915381023, 0.29527195010866436, 0.2756123478923525, 0.16735029433454784, 0.045627720920102935, 0.07953221590391227, 1.9574703914778573, 17.9346832547869, 32.00527177538191, 35.83151272365025, 25.31213113239833, 27.531755753925868, 47.88824578693935, 38.39302519389561, 19.599323987960815, 35.11780766078404, 41.14072159358433, 54.67408929552351, 63.56575461796352, 69.00176116398403, 63.49584879193987, 29.370890072413854, 0.7837511556489127, 0.03424322645046881, 0.049848564966980896, 0.03481282606454832, 0.03213436336123517, 0.0908122363367251, 0.03209730517119169, 0.0455583576778216, 0.07147723848798446, 0.006400592841341027, 0.09571189699428422, 0.034894223125385385, 0.02118921692350081, 0.03339648260069745, 0.04911319924784558, 0.017145453553114618, 0.08545178254800183, 0.03593235795519181, 0.07278167456388474, 0.024832597135433128, 0.02548901191247361, 0.03865127830899187, 0.06378065648355655, 0.06978464645466634, 0.013781011453829706, 0.047602977071489604, 0.07520810900522129, 0.04112619407741087, 0.009440379682928324, 0.0413946123527629, 0.139683883903282, 0.13182788688157285, 0.12072569690644741, 0.14581934681960515, 0.0734204270743898, 0.14380354141550405, 0.10959222646696226, 0.15758817030915193, 0.11739137582480907, 0.10896002181938716, 0.12726836225816182, 0.15542379287736757, 0.1763864266020911, 0.14113603026739188, 0.10194285692913191, 0.13680358417332172, 0.17205498473984854, 0.07896748477859156, 0.06163119325148208, 0.10896980629435607, 0.10631899389305285, 0.1639219554407256, 0.08967060795319931, 0.12117549777030945, 0.16763294488191605, 0.17096366972795554, 0.25181349207248005, 9.440936923027039, 50.27453858511788, 83.50827966417584, 78.92467812129429, 75.65455709184918, 55.30434649331229, 56.82392447335379, 35.28871944972447, 23.14659649985177, 33.90412412370954, 44.31107691356114, 44.563237462724956, 54.69698013578142, 64.76597949436733, 30.68103892462594, 2.871870913675853, 0.14255540339010103, 0.18307671403246267, 0.5669237705213683, 0.9459459951945713, 1.6194856933185031, 2.4134131371974945, 6.254708009106772, 9.685596891811915, 9.82507676737649, 7.147265783378056, 11.343073163713727, 10.407461745398384, 10.279976197651454, 8.654178500175476, 12.699105313846044, 10.753678321838379, 20.37033952985491, 20.01542901992798, 15.77082313810076, 20.851827110563004, 24.906038454600743, 35.59439502443586, 37.41740083694458, 45.34268985475813, 51.69199889046805, 56.40924208504813, 56.92764023372105, 65.00822843824113, 64.27081612178257, 63.82557555607387, 60.267312731061665, 59.618580273219514, 56.455631732940674, 59.47490542275565, 54.187211649758474, 57.71990162985665, 57.09040525981358, 58.49293736049107, 58.38098798479353, 60.14585127149309, 61.85152285439627, 63.96629742213658, 54.22415522166661, 39.35942929131644, 41.39460529599871, 44.21679333278111, 40.25313091278076, 55.54388563973563, 49.54604080745152, 57.66514982495989, 58.0342172895159, 58.09963110515049, 56.63972772870745, 60.077057157244, 55.69581842422485, 53.64189617974417, 51.24395472662789, 53.43194246292114, 54.83989763259888, 56.49099458966936, 52.77428156988961, 62.44083431788853, 62.46008777618408, 62.29642295837402, 61.5881096976144, 64.79165308816093, 62.061685017177034, 63.27495861053467, 60.62017004830496, 48.695087977818076, 39.27873986107962, 35.52822038105556, 28.732949904033116, 24.179423638752528, 12.051853690828596, 8.625220145498004, 6.001964245523725, 5.7868024195943555, 8.193738750049047, 5.810076713562012, 6.80108915907996, 3.6791167514664784, 0.18883546787713254, 0.20084901180650505, 0.2725021333566734, 0.15549217563654694, 0.3482305226581437, 3.4547357516629353, 28.367231471197947, 49.64264508656093, 54.75511918749128, 36.60921764373779, 42.06699637004307, 59.168934549604145, 45.79917260578701, 24.796441044126237, 38.424354621342246, 50.005410534994944, 61.99873433794294, 73.47533798217773, 76.2602732522147, 72.69460364750454, 35.666180338178364, 1.3371056914329529, 0.2804661802947521, 0.14110757250870976, 0.11505779890077454, 0.09960326818483216, 0.18450399887348923, 0.12353475045944963, 0.11256195032703024, 0.16476580873131752, 0.08539911465985434, 0.2784555181860924, 0.12043337044971329, 0.12119411677122116, 0.14514442160725594, 0.22421599365770817, 0.05890819150954485, 0.16667464987507888, 0.22035246954432555, 0.1764336119272879, 0.17664918250271253, 0.12578239770872252, 0.22640445908265455, 0.14241071258272442, 0.1248249305146081, 0.20726863161793777, 0.13236292531447752, 0.1397554829184498, 0.09687360322901181, 0.09552099116678749, 0.09077332235340561], [0.02922624030283519, 0.05470455511073981, 0.015920694451779127, 0.03994549225483622, 0.022057658626831005, 0.03278571965971163, 0.08066112854118858, 0.021098325461415306, 0.034391849368278465, 0.04557394362719996, 0.010900145147128828, 0.04183001131085413, 0.04355228925123811, 0.012099351467830794, 0.055037542778466425, 0.046662907515253337, 0.0030086794036573595, 0.0646616934931704, 0.026072842102231722, 0.042381117453000376, 0.07120304248694863, 0.06382866283612591, 0.014447956246190836, 0.028729332145303488, 0.03715806361287832, 0.0700719788936632, 1.8548483209950584, 22.795875753675187, 53.57222311837332, 69.62814821515764, 59.12029715946743, 51.69938482557024, 43.88669484002249, 22.49399389539446, 17.045949595315115, 23.4743013381958, 38.91216332571847, 46.66211802618844, 42.095393657684326, 48.90451710564749, 24.035444804600306, 3.3810548824923377, 0.06976035490099873, 0.07928890681692533, 0.031519111911101, 0.1658332393105541, 0.27492816746234894, 0.7958969324827194, 1.8254958731787545, 2.6035696991852353, 1.827604000057493, 1.9805605581828525, 5.689978403704507, 10.034754293305532, 6.823817150933402, 11.174876383372716, 13.303844383784703, 19.21502259799412, 17.480719225747244, 21.389002765927994, 23.555628265653336, 25.36534912245614, 33.663358620234895, 44.810013157980784, 50.185351508004324, 54.30668592453003, 57.08910247257778, 57.00221872329712, 59.7710029057094, 59.61209760393415, 58.07623652049473, 55.55921336582729, 53.24952098301479, 58.66021524156843, 60.58712441580636, 59.22033732278006, 59.01356588091169, 57.894968441554475, 58.351743016924175, 56.600880350385395, 54.94930396761213, 60.00239181518555, 57.7856559072222, 59.988926206316265, 57.992211954934255, 65.76310157775879, 42.85283415658133, 31.49292550768171, 26.440984112875803, 34.114928994859966, 57.5726762499128, 54.670775004795615, 53.69512632914952, 53.15771790913173, 57.308596066066194, 57.70922919682094, 59.93118667602539, 58.5265805380685, 55.244790009089876, 50.617953300476074, 52.07944086619786, 53.713389669145855, 52.83861494064331, 57.302346161433626, 59.46412876674107, 54.15679938452584, 54.767737116132466, 51.48872586659023, 56.27130992071969, 54.0056517464774, 57.28485059738159, 59.0359251839774, 62.50222165243966, 54.79153817040579, 49.12866251809256, 44.80652168818882, 39.575667653764995, 29.849384716578893, 21.39421217782157, 10.370739647320338, 3.763533455984933, 1.3253163354737418, 2.2118220116410936, 3.8893644639423917, 3.182657105582101, 1.149968447429793, 0.13070092163980007, 0.12455969117581844, 0.058903971021728854, 0.027841190874044384, 0.08739332229431186, 1.637777260371617, 12.768661992890493, 35.566296509334016, 49.23404584612165, 44.23963553564889, 40.47076933724539, 35.667490073612754, 29.249136788504465, 14.466583728790283, 25.74792388507298, 38.96939563751221, 41.37269415174212, 49.30791561944144, 57.72631481715611, 59.4949301310948, 24.409410749162944, 0.5622338450380734, 0.054770959940339835, 0.028276360826566815, 0.010367229680663772, 0.04256844400827374, 0.0831676097586751, 0.0419677810610405, 0.04616875420989735, 0.06335841092680182, 0.01960205566138029, 0.010255846461015088, 0.05072539166680404, 0.030080101984952177, 0.012333915934764912, 0.0625508456890072, 0.05232968254547034, 0.009577807621099055, 0.015141714197982634, 0.01637882094031998, 0.03454722710219877, 0.09860532637685537, 0.05662444619727986, 0.023580101218872836, 0.057950710744730065, 0.03523868482027735, 0.03653826258544411, 0.046517473712031326, 0.035227014017956595, 0.05344118397416813, 0.014816602625484978, 0.010940891174998666, 0.027241292975044677, 0.046530454086938074, 0.03727990475350192, 0.05373309313186577, 0.031495716023658, 0.04211848368868232, 0.042165092259113274, 0.03997408911319716, 0.049047842754849365, 0.021187345863186886, 0.04683981177264026, 0.03687656657504184, 0.041055962310305665, 0.07291540703071014, 0.019247989303299358, 0.023301791599286453, 0.06241408017064844, 0.039970978030136654, 0.06521009906594243, 0.06617389699178082, 0.03664163061018501, 0.02779358994614865, 0.009071861377118953, 0.09442187300218002, 2.394707066672189, 27.45096731185913, 64.22169235774449, 77.65690285818917, 65.09371212550572, 59.98381233215332, 50.72713729313442, 33.07996702194214, 24.46715896470206, 21.67428537777492, 28.69939705303737, 39.22377266202654, 36.76515259061541, 41.72896998269217, 21.930147579738072, 2.920714361327035, 0.024809567656900202, 0.04257010302639433, 0.11337051979665246, 0.5925520381757191, 0.8481586224266461, 3.3411581090518405, 3.580553948879242, 4.514390536717006, 6.733253461974008, 6.320935198238917, 9.20768676485334, 8.674480267933436, 6.914369549070086, 10.157457743372236, 13.646467004503522, 15.833836351122175, 16.06888175010681, 17.468257631574357, 20.30769283430917, 27.62090287889753, 31.7053736277989, 44.07701294762747, 50.697746413094656, 54.93760667528425, 57.87380770274571, 60.042753900800435, 61.6908666065761, 60.92908695765904, 58.91016278948103, 60.45608139038086, 56.77954980305263, 61.075138092041016, 62.111121450151714, 58.75334194728306, 59.02953284127371, 58.40402126312256, 56.61372756958008, 55.7036212512425, 56.26400736400059, 60.90638024466378, 58.16318627766201, 61.63528796604702, 58.904242924281526, 66.0502289363316, 45.53512716293335, 35.55199711663382, 31.483291830335343, 38.51675871440342, 57.012119906289236, 54.344894068581716, 56.10276746749878, 54.051860741206575, 58.40925325666155, 58.38091155460903, 60.27977779933384, 60.10079915182931, 56.4496145929609, 51.79385600771223, 53.91955314363752, 53.811310631888254, 53.428110531398225, 57.6416197504316, 59.80829388754708, 57.10434682028634, 56.850278990609304, 53.49900994982038, 57.77988542829241, 57.10680995668684, 60.3727308000837, 61.75803484235491, 61.43782016209194, 55.46122292109898, 50.75175128664289, 46.885697160448345, 40.42497028623308, 32.49433462960379, 21.4544061592647, 11.933840274810791, 4.801039772374289, 1.4772793012005943, 3.9609721643584113, 4.768310282911573, 3.3240733572414944, 3.8029210567474365, 1.3573207152741296, 0.48362740874290466, 0.044957182436649284, 0.037277217754828076, 0.120966373277562, 1.3216908957277025, 11.932977829660688, 32.68484033857073, 43.119811739240376, 40.899368967328755, 37.31443895612444, 35.725966112954275, 28.30444928577968, 21.64934481893267, 36.79395982197353, 49.24865790775844, 47.672726563044954, 56.776061807359966, 65.18679019383022, 71.06384754180908, 32.3568297794887, 0.7842965349555016, 0.0766852865261691, 0.051631565006183724, 0.029874376952648163, 0.037300165809158764, 0.068506442542587, 0.043918725302709, 0.04986785232488598, 0.07654801210654633, 0.04802207083308271, 0.01821175606788269, 0.0036882589421501116, 0.015081979367615921, 0.023174501822463105, 0.023982262139075568, 0.020011531189084053, 0.028760470117309263, 0.08721042318003518, 0.0103860547865874, 0.022078209756208316, 0.06495671373392854, 0.03378833318129182, 0.0440885117277503, 0.03600625041872263, 0.06140866769211633, 0.006721836340148002, 0.07435378591929163, 0.04816298898575561, 0.022460632092718567, 0.11774135061672755, 0.08206847123801708, 0.10893266328743526, 0.1784594189375639, 0.14601336712283747, 0.09540483275694506, 0.17924255691468716, 0.11657235691589968, 0.14024630800953933, 0.09675192154411759, 0.16906656724001679, 0.05508706904947758, 0.10529010410287551, 0.076733930701656, 0.27538460439869333, 0.21768767253628798, 0.11474594420620374, 0.08115999427224908, 0.1576480713805982, 0.10878759250044823, 0.08363488968461752, 0.18229481098907335, 0.1232799334185464, 0.08453431499323674, 0.12189728261104651, 0.08248124444591147, 3.874794525759561, 37.40778105599539, 75.96457181658063, 85.63895865849086, 73.85986518859863, 68.07376670837402, 57.124649456569124, 33.72744532993862, 26.596549068178447, 31.604760238102504, 51.28832244873047, 61.146593366350444, 55.85730150767735, 63.49671036856515, 32.202131611960276, 4.952130522046771, 0.16272899588303907, 0.28603896126151085, 0.11358008533716202, 0.36246146474565777, 0.9856856742075512, 3.6742603949138095, 7.168875983783177, 7.837115509169442, 6.676433265209198, 6.832914514201028, 13.827869704791478, 17.45648217201233, 13.18003443309239, 17.17714548110962, 19.310536009924753, 26.221910885402135, 23.228239570345195, 26.65836545399257, 28.357578686305455, 31.737112998962402, 38.836358479091096, 52.40630497251238, 56.4901955468314, 56.84400129318237, 59.32946572984968, 61.367379324776785, 64.41147545405796, 63.3990603855678, 63.41231060028076, 59.8676176071167, 59.94422844478062, 60.3459107535226, 63.11861719403948, 60.15575245448521, 60.08253928593227, 59.59877095903669, 60.24909455435616, 56.6268561908177, 56.453540325164795, 61.91136074066162, 60.46248068128313, 63.38880484444754, 62.66216918400356, 69.42100157056535, 50.12050397055489, 39.23953117643084, 36.41476535797119, 42.24572140829903, 57.419475419180735, 54.98275259562901, 55.83212471008301, 56.483775411333355, 60.374905586242676, 60.95200906481062, 62.66300296783447, 63.644852910723, 58.026890414101736, 52.42323773247855, 54.09993532725743, 54.87144940240042, 54.93767615727016, 57.47558559690203, 61.795367513384136, 59.90789631434849, 60.6629501070295, 55.32243612834385, 61.90844249725342, 60.09890924181257, 63.41089316776821, 64.64152336120605, 65.5408148084368, 54.82713031768799, 52.418297563280376, 48.766810757773264, 42.06644398825509, 35.37827130726406, 26.536374194281443, 15.66326676096235, 8.796295217105321, 3.6393311492034366, 7.651128734861102, 10.668981518064227, 9.215451376778738, 5.3539674282073975, 0.7007798392857824, 0.21546243051333086, 0.21079324106020586, 0.1756762989929744, 0.28114818941269604, 2.153783925942012, 17.62223318644932, 45.8858757019043, 64.49096979413713, 59.65082686288016, 52.090742111206055, 49.894465173993794, 44.03703301293509, 23.86399453026908, 38.252285957336426, 54.264003140585764, 56.0807659966605, 65.29196507590157, 72.30669961656842, 78.80678108760289, 38.68378298623221, 1.1094725004264285, 0.15566623343953065, 0.09266350378415414, 0.08814388380518981, 0.0988880515630756, 0.21415121587259428, 0.10098351019301585, 0.10044889245182276, 0.18022789832736763, 0.11231926549226046, 0.12098538582878453, 0.11673235547329698, 0.08066325235579695, 0.09740062816334621, 0.1721581627747842, 0.09366344048508576, 0.10669750786785569, 0.1443622742912599, 0.21501317247748375, 0.13298028361584457, 0.22967672135148728, 0.07647749874740839, 0.11233953333326749, 0.07872618415525981, 0.1737261622079781, 0.07823888744626727, 0.10979744938335248, 0.08084041106381587, 0.10803492074566227], [0.06897193792143039, 0.0156365833577833, 0.012350761414771634, 0.010884783962475402, 0.0337674071613167, 0.019047329534909556, 0.012126952576051866, 0.036730654404631684, 0.020743416023573706, 0.025784424007205025, 0.03652592342612999, 0.05516495129891804, 0.07790800662977354, 0.037285651945109875, 0.044574505649507046, 0.06695537255810839, 0.024712757673114538, 0.0487764796375164, 0.04021998681128025, 0.027447182552090714, 0.023971420845815113, 0.040423496426748376, 0.04340918282313006, 0.03591235474284206, 0.029359355302793638, 0.05317944587607469, 14.417722259249006, 59.46566431862967, 63.95800127301897, 57.04672540937151, 47.83077028819493, 39.098989963531494, 27.035749912261963, 18.090062345777238, 22.808788980756486, 52.19257838385445, 41.63460997172764, 27.247706447328838, 49.6896253313337, 28.939158541815623, 3.6322324786867415, 0.0659741498529911, 0.10008770147604601, 0.036562045237847736, 0.07241125551185437, 0.9613715388945171, 1.0823530299322945, 0.9348435338054384, 1.8288297057151794, 2.212408483028412, 5.231808543205261, 6.892433651856013, 5.171327080045428, 10.747759325163704, 16.406696217400686, 19.881789105279104, 30.967982155936106, 31.695774691445486, 36.245733056749614, 39.84340606416975, 34.74344914300101, 44.57091522216797, 47.97635241917202, 55.144975662231445, 56.63543374197823, 59.306863239833284, 56.09593391418457, 59.054650579180034, 57.03850221633911, 56.40421853746687, 55.94177075794765, 55.62887947899954, 56.558558872767854, 57.178657804216655, 54.08539274760655, 53.263733523232595, 55.906366212027415, 55.47308349609375, 52.85211876460484, 56.576721463884624, 57.88383047921317, 59.738582611083984, 59.9913580758231, 58.28656891414097, 54.739746298108784, 55.249747548784526, 57.22940744672503, 34.82199852807181, 19.21838900021144, 46.74432911191668, 56.55577611923218, 53.32588863372803, 56.91628687722342, 54.332699980054585, 55.84818547112601, 55.29770401545933, 53.9061987059457, 55.51957736696516, 55.26970624923706, 53.32663903917585, 52.57009833199637, 51.98158243724278, 52.56778458186558, 55.39007684162685, 57.049952847617014, 55.08345978600638, 51.17191580363682, 46.96484409059797, 50.26655510493687, 52.968087673187256, 57.062094824654714, 56.70319257463728, 56.15376724515642, 54.97061061859131, 52.568868500845774, 54.561545848846436, 53.44031851632254, 53.473329407828196, 49.17380496433803, 38.775249072483604, 21.081789902278356, 6.547084297452654, 0.6339800208806992, 1.9704798076833998, 1.6772083959409168, 2.442467680999211, 1.019132673740387, 0.564320367361818, 0.06998225620814733, 0.08841919260365622, 0.03992492246574589, 0.08883333645228829, 0.5681907853909901, 7.476926973887852, 22.87313277380807, 41.71339212145124, 36.60698727199009, 35.86745228086199, 27.001585619790212, 15.873745066779, 14.310640096664429, 20.25366016796657, 37.07238803591047, 47.84197425842285, 52.12539625167847, 50.951098578316824, 53.68033014025007, 12.955127324376788, 0.2937936937170369, 0.03484924643167427, 0.046917856870485206, 0.06325200985052756, 0.007747649398100163, 0.07042436927024807, 0.0797838641862784, 0.025658338630039777, 0.02388623755957399, 0.020644053051780378, 0.030130941221224408, 0.02039881862167801, 0.033155338040419986, 0.03928625477211816, 0.0728172297988619, 0.011140026784102832, 0.029176032104130303, 0.043266636186412404, 0.0314882385677525, 0.052105789738042016, 0.02379348182252475, 0.03273793722369841, 0.050433665713561435, 0.04707133809902838, 0.007180473002206002, 0.053188524674624205, 0.005522896344440856, 0.051786372770688364, 0.04208018038687961, 0.028366200559373413, 0.06362546195409127, 0.021931250945531895, 0.05162736487441829, 0.048417487115200074, 0.012689714253480946, 0.02733223363091903, 0.04869847525177257, 0.02084910124540329, 0.02301278317879353, 0.02803419337474874, 0.02349184756167233, 0.014511165175853031, 0.013933740356670958, 0.05847629039947476, 0.02213704552767532, 0.018428967001714876, 0.03699997852423361, 0.06215859138007675, 0.05215613025107554, 0.02890382081802402, 0.02891960014988269, 0.02966147641252194, 0.08929919145469155, 0.16378546133637428, 18.658385038375854, 69.10378156389508, 71.2255390712193, 65.69405038016183, 58.996021679469514, 45.88996819087437, 38.605865887233186, 26.157780749457224, 28.589000599724905, 43.768926348005024, 49.933868408203125, 33.12499829701015, 43.934630462101524, 25.93300826208932, 2.6546619747366225, 0.02590780033330832, 0.07821692326771361, 0.13032961370689528, 0.8466665510620389, 2.2263730594090054, 2.3174294190747395, 2.5575630707400183, 5.15382673910686, 5.334326607840402, 9.42462602683476, 6.764092607157571, 5.855128833225795, 9.23004867349352, 12.704959171158926, 19.05008625984192, 26.919228621891566, 30.433797700064524, 33.021556990487234, 36.83468321391514, 37.73593405314854, 45.49003682817732, 50.76440743037632, 56.71355928693499, 59.04490225655692, 62.55659825461251, 57.69513825007847, 61.21101706368582, 58.879305839538574, 58.26737104143415, 58.477019037519185, 57.75216906411307, 57.78110831124442, 59.30922562735421, 54.17190476826259, 54.326071398598806, 55.649769238063264, 56.906892912728445, 54.22290107182094, 58.93926879337856, 60.01668425968715, 61.70532580784389, 60.63135664803641, 58.885857990809846, 55.994278294699534, 58.603580474853516, 57.702816009521484, 38.69905512673514, 24.23085594177246, 46.87991278512137, 56.1471004486084, 54.67554841722761, 56.17348623275757, 54.621727670942036, 58.32422120230538, 56.651411124638145, 55.41982902799334, 57.77626889092581, 57.65412998199463, 54.15579536982945, 52.73510415213448, 52.86646332059588, 52.135342597961426, 56.16793809618269, 59.24150153568813, 57.09628690992083, 52.83946262087141, 49.28154720578875, 52.12915522711617, 55.36773838315691, 60.21375601632254, 58.587071555001394, 57.28814056941441, 55.52070644923619, 53.88239765167236, 53.76947900227138, 53.34760870252337, 55.59554549625942, 52.88586616516113, 39.08075441632952, 22.363008192607335, 8.690167563302175, 1.9841373605387551, 2.3603071868419647, 3.936807632446289, 5.302877758230482, 4.824848643371037, 1.9665623264653342, 0.41436860657164026, 0.22115008745874676, 0.01895795120591564, 0.03554735379293561, 0.4563007950782776, 7.580685291971479, 22.209941114698136, 43.125863620213096, 36.416398184640066, 33.41228199005127, 30.18100139072963, 19.680954899106705, 26.832662752696447, 38.898555278778076, 48.512770720890586, 55.40472364425659, 59.65489155905587, 58.480319431849885, 64.78549698420933, 18.14267757960728, 0.2647895786379065, 0.06846134031989745, 0.05062538917575564, 0.035730697347649505, 0.02050865987049682, 0.04200489014121039, 0.021747508751494542, 0.04508629068732262, 0.052332505251147916, 0.07831892743706703, 0.081221082779978, 0.0359410533814558, 0.09591515215912036, 0.08793824698243823, 0.06433440212692533, 0.023509401262604764, 0.024302861453699212, 0.04198414393301521, 0.03846227237954736, 0.043509853671171834, 0.03846734782148685, 0.010086512958098735, 0.05062050372362137, 0.030709453392773867, 0.032616744084017615, 0.1176636176449912, 0.011785922572016716, 0.06655834136264664, 0.13052410898464067, 0.09852904547005892, 0.1825482438185385, 0.1496348035122667, 0.1289898327418736, 0.09892964575971876, 0.11477323488465377, 0.12001627497375011, 0.09533837025186845, 0.06799743271299771, 0.13843162038496562, 0.0918257369526795, 0.1230464902307306, 0.07978614406394106, 0.13980150116341455, 0.16313668686364377, 0.12165044514196259, 0.09684187493153981, 0.18071064885173524, 0.16401500973318303, 0.12920700465994223, 0.12897803980324948, 0.11350030997501952, 0.16494838893413544, 0.2791444755026272, 0.3600286995725972, 24.909377064023698, 80.48693888528007, 79.67800181252616, 74.09810502188546, 66.30755547114781, 52.81417465209961, 39.82903718948364, 28.43758371898106, 30.502869742257253, 67.12332957131522, 54.29298060280936, 37.51479721069336, 59.923856326511924, 37.70877354485648, 4.946729166167123, 0.14009340692843708, 0.1990503647497722, 0.18476437990154537, 1.065269146646772, 3.6158121483666554, 4.225674646241324, 4.916263486657824, 7.40487676007407, 8.918811065810067, 12.32535650048937, 13.833422183990479, 12.586349947111946, 16.998088666370936, 22.68143892288208, 24.06064592088972, 35.4468708719526, 35.64433520180838, 42.32833548954555, 44.444391999925884, 39.89261668069022, 49.465886388506206, 52.18283700942993, 59.31977299281529, 61.825029373168945, 65.14296095711845, 60.516266686575754, 63.81862040928432, 61.30412292480469, 60.48381859915597, 60.78851795196533, 61.186899866376606, 60.774378367832725, 59.33446148463658, 55.940221309661865, 54.115162304469514, 56.661916800907676, 57.44084460394723, 54.98648030417306, 59.13571521214077, 62.09585625784737, 64.10068253108433, 63.71194471631731, 62.278802326747346, 58.293114117213655, 60.62019089290074, 59.69592067173549, 41.564690249306814, 28.660490615027292, 50.16026503699166, 57.532161303928916, 57.17540257317679, 58.5503294808524, 54.65136521203177, 59.76620864868164, 58.43712248120989, 58.23637165342058, 60.157968929835725, 60.48375606536865, 56.86446373803275, 53.721769196646555, 54.37445865358625, 51.78355530330113, 56.381751537323, 62.40129906790597, 60.24872629983084, 54.63721867970058, 50.87785414287022, 54.809905733381, 57.394111020224436, 62.3103471483503, 60.52792576381138, 58.608930587768555, 55.805863993508474, 52.984106745038716, 54.643909794943674, 56.18312338420323, 56.673982347760884, 55.90653991699219, 43.193549496786936, 27.273913315364293, 11.416839582579476, 6.093435108661652, 8.880938172340393, 10.23610006059919, 9.307882394109454, 5.420238043580737, 1.4794271630900246, 0.19922212910439285, 0.22894512489438057, 0.13405729510954448, 0.3071415089070797, 1.1883669069835117, 11.150325792176382, 31.948848928724015, 55.017625604357036, 51.19287504468645, 48.18981497628348, 38.817945752825054, 25.197661297661917, 23.726725918906077, 33.008789675576345, 51.724151679447715, 62.14285387311663, 68.18211691720145, 67.37292276109967, 75.55953352791923, 23.527837208339147, 0.43336954127464977, 0.15370916202664375, 0.22630847351891653, 0.19170571171811648, 0.07988556980022363, 0.09399627548243318, 0.17803891721580709, 0.14755725142146858, 0.12355474010109901, 0.2102369644812175, 0.13746506082160131, 0.08066620398312807, 0.15221761991935118, 0.1394449852939163, 0.19742627761193685, 0.16581472887524537, 0.149489271321467, 0.12282882976744856, 0.09881099034100771, 0.11137239701513733, 0.12318803263562066, 0.11745055764913559, 0.17790223312165054, 0.06726186682603189, 0.06900793420416967, 0.13521330165011541, 0.1462222066308771, 0.23702191721115792], [0.04191049234941602, 0.028926724767578498, 0.02325803626860891, 0.039798175516937456, 0.027130408478634696, 0.026433218835986087, 0.06296165793069772, 0.032673466218901534, 0.0301516806440694, 0.046007096634379456, 0.042350077868572304, 0.026554875075817108, 0.026585509235571538, 0.039905071923775334, 0.08865670021623373, 0.014259121646838529, 0.030205390083470514, 0.03317456093749829, 0.04474500114364283, 0.021753406917144145, 0.018166365467810204, 0.014636008833934153, 0.13011560376201356, 0.10193323530256748, 0.06654078766171422, 1.4965537126575197, 30.703141144343785, 61.70299816131592, 62.43028000422886, 52.66013308933803, 37.56842688151768, 30.904291493552073, 18.48575530733381, 19.70546293258667, 28.560172523771012, 40.727967330387656, 22.787899221692765, 42.05908237184797, 23.497845309121267, 1.3903998945440565, 0.08192786521145276, 0.032099907352988205, 0.03236487867044551, 0.10689454086657081, 0.4785898561988558, 1.7362010989870345, 0.660907113126346, 2.8518147213118414, 2.321025763239179, 4.25625627381461, 10.618375182151794, 6.773856997489929, 17.257249525615148, 21.04831521851676, 25.05165011542184, 36.846957206726074, 41.02301910945347, 44.90715592248099, 46.864498206547324, 46.779132638658794, 50.61004625047956, 55.67098903656006, 59.86559568132673, 55.99611609322684, 54.56520060130528, 56.11787632533482, 55.51912920815604, 52.036685126168386, 52.58726038251604, 52.16626555579049, 50.81727974755423, 53.15415348325457, 56.486881256103516, 56.49567072732108, 55.79545906611851, 56.93460232870919, 55.31673513139997, 55.50830738885062, 57.45116267885481, 57.33389793123518, 57.121290002550396, 55.30058751787458, 54.123465401785715, 53.11295413970947, 53.31472635269165, 52.64325591496059, 61.02908543178013, 40.708123275211875, 24.125356231416973, 56.42451769965035, 54.28172104699271, 57.30417353766305, 54.87444060189383, 54.2341502053397, 54.3459015573774, 55.18069635118757, 51.86948020117623, 51.59583929606846, 52.463599818093435, 56.769846643720356, 53.224663802555625, 54.975769656045095, 50.09582396915981, 57.09172541754586, 56.845331873212544, 52.62205696105957, 47.293747493198936, 42.532873085566926, 46.6144186428615, 51.84638786315918, 55.79527841295515, 60.24404321398054, 54.48777335030692, 55.45353821345738, 57.11042649405343, 52.75230441774641, 55.29317378997803, 64.07341085161481, 59.554670742579866, 57.7101081439427, 49.99156624930245, 29.56036744798933, 12.245472192764282, 2.9814696269375935, 0.8498844355344772, 3.524984644992011, 5.379134672028678, 3.054392925330571, 0.46522776463202065, 0.06313743921262877, 0.04697445686906576, 0.04042961681261659, 0.04827583275203194, 0.49001839437655037, 5.293531996863229, 19.536453213010514, 45.929263728005544, 38.36093841280256, 21.608680486679077, 36.69832134246826, 18.09175075803484, 11.256259764943804, 24.98152368409293, 39.00259065628052, 48.266304220472065, 53.80760029384068, 52.571362904139924, 46.24533380780901, 3.179924943617412, 0.10568745420979601, 0.04662478741790567, 0.12050236389040947, 0.050979553921414275, 0.007317082457510489, 0.04492294695228338, 0.048093642706849744, 0.05935374474419015, 0.048956834245473146, 0.05728476255067757, 0.008949937115955566, 0.01935726567171514, 0.10081599346761193, 0.012027045928074845, 0.03238745692319103, 0.004696412278073174, 0.010614926344715059, 0.008336113133866872, 0.012647650171337383, 0.0378134775507663, 0.032632767688483, 0.0464847072559808, 0.03325644315087369, 0.013065274904615112, 0.007795438619463572, 0.03879046619736722, 0.046178905093776326, 0.059724190937621255, 0.03490850968020303, 0.022240869867216264, 0.02623735970285322, 0.01768545716601823, 0.05387180604572807, 0.04463263574455466, 0.01724340008305652, 0.0054830756687027, 0.027080405536772947, 0.04741883963080389, 0.01583980968488114, 0.07460658092583929, 0.024213684988873344, 0.031227463989385536, 0.03120045151029314, 0.025897685072517822, 0.050108023187411685, 0.01363882189616561, 0.09181636638407197, 0.03132138680666685, 0.03267617357362594, 0.04356544265257461, 0.0510782400545265, 0.063178890916918, 2.6269951164722443, 39.21397222791399, 70.48682744162423, 69.79284831455776, 60.31860433306013, 45.323915822165354, 41.4428779057094, 27.73211748259408, 25.117029190063477, 23.806567668914795, 42.35194546835763, 25.600380625043595, 36.10016482216971, 23.82537817955017, 1.9843223563262393, 0.14228403009474277, 0.06071403103747538, 0.09697866080594914, 0.7945868713515145, 1.937473258801869, 3.8562371901103427, 3.5046811401844025, 7.124374943120139, 6.104992568492889, 4.495050225939069, 7.110655725002289, 8.664350662912641, 12.192625062806265, 17.60617068835667, 27.875396285738262, 36.65239722388131, 41.52839285986764, 45.361182485307964, 47.45715870176043, 46.80986452102661, 51.04721648352486, 56.8732636315482, 61.397548403058735, 57.633632796151296, 56.62167630876814, 55.96128477369036, 58.17569303512573, 55.088198457445415, 54.129989760262625, 54.14449759892055, 53.013980524880544, 55.54968043736049, 58.45825890132359, 59.12212453569685, 56.42638676507132, 55.54919753755842, 55.16217940194266, 54.347551754542756, 58.98860100337437, 58.478186334882466, 58.30655888148716, 57.71523938860212, 57.30717863355364, 55.39457927431379, 54.150587694985525, 55.27659886223929, 63.7881942476545, 43.164356640407014, 27.1214576789311, 56.49361406053816, 55.5257682119097, 59.2956280027117, 55.09179762431553, 54.461488315037315, 57.99861819403512, 57.772652353559224, 54.13862637111119, 54.096315315791536, 54.425635610307964, 58.60057190486363, 55.38355595724923, 55.29722111565726, 49.637586797986714, 57.754653045109336, 58.6055885042463, 54.46436486925398, 49.406166621616904, 43.88068117414202, 48.41196625573294, 52.99422679628645, 58.472843170166016, 60.11392429896763, 54.65874767303467, 55.177732944488525, 57.34214544296265, 53.38575083868844, 58.43910271780831, 64.76889078957694, 61.08503927503313, 60.666743823460166, 52.480126108442036, 31.333123888288224, 13.900807550975255, 5.561507514544895, 4.012745797634125, 4.519178279808589, 8.566865699631826, 3.843635763440813, 3.3247610117707933, 0.6383256848369325, 0.2406599505671433, 0.03593841048755816, 0.05082578431548817, 0.4696276571069445, 5.115188675267356, 20.581939969744, 44.50674860818045, 35.283622946058, 18.991059575762065, 23.121638570513042, 18.396910429000854, 16.53779309136527, 37.51345273426601, 46.83666024889265, 53.930687631879536, 60.883875029427664, 60.633969170706614, 55.58058949879238, 5.774752940450396, 0.11700952345771448, 0.03931738595877375, 0.04304892483300396, 0.07254920168114559, 0.04904557644788708, 0.02247451661553766, 0.058371572090046744, 0.013131287032073098, 0.04120217303612402, 0.027780428063124418, 0.03085655639214175, 0.05060359463095665, 0.03545224353937166, 0.03121737078098314, 0.011533449021434146, 0.047046266230089326, 0.010135745762714317, 0.06608217941331011, 0.04463237111589738, 0.023418192585398043, 0.007996113654891295, 0.023111835720815828, 0.03442172187247446, 0.033302003384700844, 0.04418890776910952, 0.04927834788603442, 0.08385434826569897, 0.12041266156094414, 0.09699867080364909, 0.13132484816014767, 0.15727991185017995, 0.0593483978882432, 0.1466362215578556, 0.16927288259778703, 0.11305544206074306, 0.1392144462359803, 0.12223045687590327, 0.09994711580553226, 0.1441902249519314, 0.14908293741089956, 0.14447268550949438, 0.11585089777197156, 0.08151581125067812, 0.20354146590190275, 0.11583974265626498, 0.11373082867690495, 0.2531237703348909, 0.15930297757898057, 0.11128841473587922, 0.2813078351318836, 0.16363175958395004, 0.23279325983354024, 4.517059947763171, 50.38697780881609, 77.5943968636649, 79.01916667393276, 68.9297708783831, 51.72765357153756, 44.633751256125315, 27.92566476549421, 28.922809430531093, 38.149185112544465, 51.279821327754426, 30.883835996900284, 55.80602032797677, 31.98993362699236, 2.654843496424811, 0.1895905416458845, 0.10893180154796157, 0.27999394706317354, 0.5574518016406468, 1.4672905057668686, 4.660728718553271, 5.571021769727979, 9.292378357478551, 10.376916595867701, 10.989038126809255, 19.41903386797224, 12.842563901628766, 22.48647247041975, 24.515407255717687, 30.58300679070609, 41.33401700428554, 44.07442126955305, 48.87460511071341, 48.66774334226336, 46.46144362858364, 52.26435327529907, 58.83669253758022, 62.97711712973458, 59.62484060014997, 58.52674034663609, 59.17995439256941, 60.32549694606236, 56.92043147768293, 56.87299265180315, 56.24153341565813, 53.81682055337088, 58.82707623073033, 59.768828119550435, 59.52071489606585, 58.28727068219866, 56.54540940693447, 55.63367026192801, 56.50029475348336, 60.45158590589251, 62.6575277873448, 61.34006595611572, 59.74009731837681, 58.11105394363403, 58.304752349853516, 56.86852843420846, 58.963094166346956, 66.09487806047711, 47.12188032695225, 30.541407925742014, 58.02406249727522, 57.917737688337056, 60.728812081473215, 57.29124641418457, 56.848246642521445, 58.680087089538574, 60.89602048056466, 56.767710072653635, 56.43216071810041, 56.788745743887766, 61.54284913199288, 54.51973853792463, 55.42295571735927, 52.019137450626914, 59.64378833770752, 61.232716287885395, 57.4284907068525, 51.19049181256975, 46.01936796733311, 52.0198392186846, 54.703688621520996, 60.512347902570454, 63.43358598436628, 54.84284019470215, 56.05358811787197, 57.95844023568289, 54.142586844308035, 59.20932442801339, 68.63422230311802, 64.49637549264091, 63.10243483952114, 57.501651763916016, 34.87131684167044, 17.92811025891985, 8.26638216631753, 5.720411513532911, 10.625086273465838, 15.685744183404104, 11.283247436795916, 3.0440633424690793, 0.2303117758461407, 0.34983783641031807, 0.2192711289972067, 0.20256185132477963, 1.055670427424567, 8.018626775060381, 28.047381571360997, 58.86811229160854, 52.4225880759103, 32.757320472172324, 52.49943167822701, 27.38862633705139, 17.861468349184307, 37.71307100568499, 53.21825408935547, 62.591957637241904, 70.79188810076032, 67.9667158126831, 66.30400494166783, 8.768230574471609, 0.37199048485074726, 0.15035600481288774, 0.227017610466906, 0.08237679076514073, 0.14958338412855351, 0.16384943361793244, 0.14388450421392918, 0.1837354086871658, 0.10086794889398984, 0.07079659322542803, 0.1021771618564214, 0.12331130887780871, 0.18702132308057376, 0.10701102497322218, 0.1544642357953957, 0.1156866108732564, 0.05245860759168863, 0.09215781199080603, 0.14305852353572845, 0.12282435143632547, 0.1173800171485969, 0.12234683920230184, 0.15795993964586938, 0.09074578061699867, 0.12373996659048966, 0.1614258558090244, 0.1643320077231952], [0.031305621045508554, 0.04981089948809572, 0.045843047222920826, 0.0475166300976915, 0.053218536278499026, 0.025583760846140127, 0.01301688772426652, 0.012260725754978401, 0.05337633298976081, 0.01180089868804706, 0.05311488326905029, 0.06464591076863663, 0.008003649634442158, 0.05166276743901627, 0.010542988910206726, 0.014131610497965344, 0.036009687198592086, 0.020131263782137206, 0.01659941946023277, 0.04018900490232876, 0.0328066694284124, 0.09296034928411245, 0.03104126380224313, 0.03396502709282296, 0.07786893658339977, 16.05418631008693, 66.85776247297014, 63.72461823054722, 57.46813365391323, 38.62555013384138, 32.960263456617085, 19.0859181199755, 19.126803057534353, 34.73329782485962, 43.90380130495344, 23.229721273694718, 49.782783303942, 32.07587242126465, 2.548149130174092, 0.046593449278069396, 0.07939538253205163, 0.07574319493557725, 0.02334058514264013, 0.37907333193080767, 0.7359061858483723, 2.6837295464106967, 2.3095347455569675, 3.3748438443456377, 4.323567381926945, 3.1467965841293335, 11.290592551231384, 21.682633638381958, 24.902816227504186, 34.44843905312674, 42.30959619794573, 49.80981527056013, 56.79595797402518, 55.81336109978812, 57.7574496950422, 55.384462697165354, 55.354543754032676, 55.68196371623448, 60.315109389168875, 54.927431038447786, 50.48299149104527, 51.84102037974766, 50.078300612313406, 48.8242758342198, 49.18428284781319, 49.300727707999094, 52.008909702301025, 53.81115777151925, 55.76014832087925, 53.98750305175781, 52.60108034951346, 51.06416661398751, 53.64584623064314, 53.60886096954346, 58.04295464924404, 54.35913440159389, 54.8568616594587, 51.91706146512713, 53.766609396253315, 48.374960150037495, 49.172981602805, 51.53384746823992, 60.58597101484026, 39.66667863300869, 30.40011978149414, 62.3782171521868, 51.70382819856916, 54.924283504486084, 51.18510695866176, 56.580932072230745, 52.61631774902344, 55.594982692173545, 46.82536595208304, 47.968632970537456, 50.733838830675396, 56.5089487348284, 55.04413645608084, 55.26836177280971, 48.11591393607003, 52.79923949922834, 55.527112688337056, 53.52496494565691, 45.95523956843785, 41.53020633969988, 44.5647417477199, 53.30550956726074, 54.95257656914847, 55.54441370282854, 51.894403389522004, 51.72360277175903, 54.036307198660715, 53.12626688820975, 58.529616900852744, 57.821849073682515, 56.166631834847585, 56.440773010253906, 57.41843318939209, 55.8883182661874, 34.27645376750401, 16.74493452480861, 5.876073743615832, 2.6583998884473528, 6.169232572828021, 2.672885362591062, 3.953071194035666, 0.4703015238046646, 0.0610387846827507, 0.16553511816476071, 0.026412453968077898, 0.08826003542968205, 0.09473614328141723, 4.077694952487946, 17.94720217159816, 38.099258831569124, 36.63782685143607, 37.35561398097447, 37.324242864336284, 32.82016345432827, 15.707377399717059, 23.788545778819493, 38.94169316973005, 39.72903176716396, 48.445876938956125, 53.37823288781302, 24.810068198612758, 0.5558127867324012, 0.07157130379761968, 0.06834581294762236, 0.054301776723670106, 0.004664905352651009, 0.06950069312006235, 0.03308382723480463, 0.10023533712540354, 0.025799210981598923, 0.02667970346686031, 0.03333823376202157, 0.08600032382777759, 0.06063097156584263, 0.05071663177971329, 0.0441462957699384, 0.07290756995124476, 0.06412935562963996, 0.028221348599929894, 0.10823374507682663, 0.09356616570481233, 0.028126872776608382, 0.049913127574005296, 0.020028806690658842, 0.07587911907051291, 0.03549491660669446, 0.04671073405604277, 0.0793964546173811, 0.0441949942282268, 0.03696235375744956, 0.023590090950684886, 0.041775731902037344, 0.010125342972709664, 0.014468950119667819, 0.018714402935334613, 0.08068898240370409, 0.06684586379144873, 0.008376957549314414, 0.027201388330597962, 0.04213326896673866, 0.032707209765378914, 0.04254008124449423, 0.00811306425436799, 0.03679797525650688, 0.0879563842234867, 0.007291417718598885, 0.027938484314030836, 0.04276328194620354, 0.04279710352420807, 0.010328793216363659, 0.02287528823528971, 0.058168656192719936, 0.10819409827568702, 20.474805695669993, 74.15611553192139, 72.7125299998692, 65.46500301361084, 49.849256719861714, 41.14586673464094, 29.09699903215681, 26.195853403636388, 31.799389702933176, 42.951984950474326, 28.10460867200579, 39.13883440835135, 29.045106410980225, 3.051839679479599, 0.07098791974463634, 0.0036649661072130713, 0.15722182925258363, 0.39701944323522703, 1.2468194961547852, 3.3228033568177904, 3.064784173454557, 6.055393721376147, 7.601126023701259, 9.646147625786917, 3.9402370027133395, 6.664123662880488, 13.172085693904332, 24.813215732574463, 33.00333881378174, 44.50599125453404, 48.938580649239675, 56.88124016353062, 56.873569352286204, 57.669433389391216, 54.299640451158794, 55.80810131345476, 55.39827571596418, 61.17931243351528, 56.68065956660679, 51.888504368918284, 54.54160451889038, 53.28358105250767, 50.35035385404314, 51.554143156324116, 51.84585632596697, 53.65597670418875, 54.04189007622855, 57.9746538570949, 55.14494092123849, 54.16716262272426, 53.441805430821006, 54.24954741341727, 54.77922248840332, 58.63585485730852, 56.28708233152117, 56.397708075387136, 53.23865747451782, 55.20235736029488, 49.747562885284424, 51.595269543784006, 53.11735234941755, 63.11264869144985, 40.20096036366054, 32.59527458463396, 61.494420187813894, 52.317374978746685, 56.30971956253052, 53.381557600838796, 55.84168195724487, 55.51529380253383, 57.77780096871512, 48.54775490079607, 50.19181333269392, 52.88607113701956, 58.48389080592564, 56.19143690381731, 55.591571126665386, 49.11936930247715, 53.14125067847115, 57.89953340802874, 55.8652537209647, 47.15529073987688, 43.911034379686626, 46.34523500714983, 55.3057222366333, 58.136953353881836, 58.80897617340088, 52.76455061776297, 52.884632859911235, 53.66984530857631, 52.36654043197632, 60.90205846514021, 59.27394267490932, 58.83742209843227, 58.66084057944161, 61.238622256687705, 57.201510429382324, 36.88184758595058, 18.230032069342478, 6.417796994958605, 3.8964003835405623, 7.680340698787144, 6.205440938472748, 5.084269625799997, 3.549864189965384, 0.6100979766675404, 0.2451133116015366, 0.06156203696238143, 0.05184565298259258, 0.012230174715763755, 4.085542942796435, 20.682562044688634, 41.94911323274885, 37.221941062382285, 39.82281855174473, 27.50395601136344, 30.239081382751465, 24.82975591932024, 35.689547130039756, 47.970467294965474, 45.53898688725063, 55.77251264027187, 61.67571258544922, 31.458115032741002, 0.5690552932875497, 0.03308744043377893, 0.03463240360308971, 0.03160670738933342, 0.01952662631603224, 0.06430924204843384, 0.012341662260171558, 0.10862623687301363, 0.060118134798748155, 0.04349032204066004, 0.009989624094617153, 0.050878095972750864, 0.018391355805631195, 0.015017659336860691, 0.0411954555394394, 0.029943601095250676, 0.01494157181254455, 0.029909257045281783, 0.06722664407321385, 0.0689113854563662, 0.01948137311930103, 0.042137611590858014, 0.025242854674745883, 0.021015235455706716, 0.08458688788648162, 0.07666662002780608, 0.08048768141972167, 0.1874729695596865, 0.10610375579978738, 0.11545419905866895, 0.0914051877334714, 0.13981823383697442, 0.1013908822621618, 0.07385998884482042, 0.09669938936297383, 0.1041038077590721, 0.047819724905171564, 0.1442630724715335, 0.1225619755153145, 0.04522683225306017, 0.17282438916819437, 0.13540304718273027, 0.11430750201855387, 0.18837671035102435, 0.1518907831715686, 0.15727143016244682, 0.11779719404876232, 0.16102471947669983, 0.1814955917320081, 0.1861190479248762, 0.13171188453478472, 0.3103507895554815, 25.901496444429668, 86.90690762656075, 79.12566866193498, 74.36973094940186, 53.262104170663015, 46.61777114868164, 29.744942869458878, 28.73766425677708, 45.59956475666591, 56.37558501107352, 31.596797602517263, 63.79132093702044, 43.09906094414847, 3.8008248720850264, 0.20310804487339087, 0.20484841934272222, 0.15307188193712915, 0.23751431650349072, 1.0211544909647532, 5.167281925678253, 9.465935673032488, 7.990576897348676, 9.09026481424059, 11.157262699944631, 10.125070452690125, 17.391976833343506, 28.489613567079815, 29.78556203842163, 37.84708438600813, 47.458228724343435, 52.77603251593453, 59.5250575201852, 57.27398361478533, 57.903948988233296, 56.66993849618094, 56.33182873044695, 57.66081414903913, 65.2529787336077, 60.761697905404226, 55.12154286248343, 57.78118126732962, 54.28139795575823, 53.26269129344395, 54.08172409875052, 54.21619258608137, 55.99237796238491, 57.23035587583269, 58.420217514038086, 55.22741256441389, 53.44803449085781, 52.67978259495327, 55.69211156027657, 55.61481285095215, 60.74748189108712, 57.53868566240583, 58.47960376739502, 55.194102900368826, 58.12313338688442, 53.29280478613717, 52.96576697485787, 57.30250597000122, 65.04487323760986, 44.64802285603115, 35.87768350328718, 64.93994154248918, 55.81288514818464, 59.31752177647182, 55.36793293271746, 57.49353626796177, 58.03785467147827, 60.592210497174946, 51.44652598244803, 52.80209868294852, 55.35240718296596, 62.833727155412944, 58.826388359069824, 56.85187707628523, 49.35471521105085, 55.58012396948678, 61.438132831028526, 59.579503604343955, 50.066731861659456, 46.69102600642613, 48.8280382837568, 59.00313663482666, 60.971575192042756, 58.73991802760533, 52.66887392316546, 52.94160461425781, 55.451596191951204, 55.02838488987514, 63.242600849696565, 63.60560253688267, 61.36849798474993, 60.40264974321638, 64.12325028010777, 60.8124475479126, 38.620870522090364, 23.948878935405187, 11.958825128419058, 9.964562722614833, 14.51182518686567, 11.273736221449715, 11.204216020447866, 3.594981666122164, 0.26492297862257275, 0.2605659695608275, 0.21082908127989086, 0.327856857329607, 0.4232386606080191, 6.096916590418134, 26.777577434267315, 52.42353997911726, 49.247337750026155, 51.121763706207275, 52.969741344451904, 46.11720902579171, 23.736977985927037, 35.7005808694022, 53.80292068208967, 54.68023150307791, 64.90445709228516, 70.0506820678711, 38.95443269184658, 1.5329545651163374, 0.254816579499415, 0.19862657891852514, 0.1659044719168118, 0.08960778239582266, 0.18551048343735083, 0.08992207981646061, 0.2555216859493937, 0.2342942607189928, 0.1330002596867936, 0.1746085291462285, 0.16807890523757252, 0.17469083544399056, 0.09599604031869344, 0.14129505173436233, 0.15289306081831455, 0.1955030650964805, 0.11075520156217472, 0.15870407543012074, 0.18023789993354253, 0.10766483417579106, 0.12509441748261452, 0.20215200260281563, 0.16491511357682093, 0.132083355316094, 0.12360052764415741, 0.13442046062222548], [0.04434481815301946, 0.025484014502061263, 0.03496958800990667, 0.050264398367809396, 0.04967114163030471, 0.03901392134970852, 0.03073934625302042, 0.06524823273399047, 0.05996970526341881, 0.006655132531055382, 0.026305996912664602, 0.025788205143596445, 0.022119690298235843, 0.006496210723915803, 0.045871949422040155, 0.04760586084531886, 0.1042213843071035, 0.009165161638520658, 0.038896921556442976, 0.0901727442230497, 0.06166748808962958, 0.023789117146017294, 0.05823964452637093, 0.021858898756493415, 0.29558776744774407, 35.180515153067454, 58.97209208352225, 58.37183720724923, 47.100410393306184, 41.7639993258885, 28.36759451457432, 20.199848106929235, 22.01858425140381, 36.239806243351524, 26.56087006841387, 42.46498223713466, 33.14468601771763, 5.0164569446018765, 0.1757553754640477, 0.03590958292729088, 0.05853830171482904, 0.0488043402853821, 0.3551437631249428, 1.1720676273107529, 2.9634885575090135, 2.4753341802528928, 4.283404622759138, 8.501860959189278, 8.26838411603655, 6.281892401831491, 20.307496547698975, 31.948841980525426, 43.461419922964915, 47.87249769483294, 54.75146790913173, 55.075309549059185, 54.89507327760969, 52.185918535505024, 53.60166958400181, 52.59998600823538, 53.152958393096924, 51.70755590711321, 55.15433488573347, 55.39327996117728, 50.512993812561035, 47.75502102715628, 49.603714329855784, 45.50037922177996, 50.091505663735525, 51.41079487119402, 52.280612060001914, 53.96088450295584, 56.62510177067348, 52.22741665158953, 53.38953760692051, 52.35426296506609, 54.386798654283794, 54.162952014378135, 55.56387560708182, 52.0617299079895, 52.057769434792654, 45.754130908421104, 48.483949593135286, 42.81057173865182, 50.90148149217878, 47.73653187070574, 61.97069140842983, 37.56409467969622, 32.62002406801496, 61.548435483660015, 48.728901386260986, 54.334113938467844, 51.64403894969395, 55.47895472390311, 54.87107767377581, 54.92176130839756, 48.890926429203574, 41.56973116738455, 46.9123990876334, 56.713736465999055, 56.12277480534145, 53.0705110686166, 49.29442916597639, 49.13504096439907, 56.686965056828086, 54.6528069632394, 47.72781188147408, 40.508623123168945, 42.47712768827166, 50.20942006792341, 53.96604701450893, 55.76059995378767, 52.81368480409895, 54.816864354269846, 55.54448318481445, 53.11656025477818, 55.94486270632063, 57.692105361393516, 53.663355691092356, 53.06345864704677, 56.33253744670323, 57.650405747549875, 54.238708223615376, 42.453010490962434, 23.578312397003174, 5.914621480873652, 7.073552344526563, 1.8464451261929102, 4.660262320722852, 3.5503232053347995, 1.1334656072514397, 0.05344527554033058, 0.029071432538330555, 0.1018063628247806, 0.09935337052281414, 0.04217414052358695, 3.4116048089095523, 26.65468638283866, 32.85882323128836, 20.009957313537598, 44.43394190924508, 27.644651821681432, 17.893994603838237, 12.358702642577034, 22.722829341888428, 40.75004175731114, 52.87300157546997, 52.03948177610125, 43.35063089643206, 6.851436674594879, 0.04309598123654723, 0.028159508614667823, 0.06653587506817919, 0.008702092870537723, 0.06613634007849864, 0.017657355638220906, 0.06541718795363392, 0.04624757283766355, 0.05083609126242144, 0.03464293785925422, 0.03244216720174466, 0.06030339521488973, 0.02956676988729409, 0.03630516205781272, 0.038589704648724625, 0.024112797009625604, 0.060673542852912626, 0.005418929512545998, 0.04827223990910819, 0.022514862307746495, 0.03351381148344704, 0.018839012498834302, 0.02136240789799818, 0.013455594540573657, 0.0465343047731689, 0.024400059898783053, 0.022557292798800126, 0.0532156355412943, 0.037338204482304196, 0.04953150251614196, 0.025429663847067525, 0.01569201797246933, 0.08370359135525567, 0.0215190307436777, 0.01244806164010827, 0.05273575522005558, 0.014454466789694769, 0.05188983579033187, 0.0313794490482126, 0.03710309549101761, 0.08668772729911975, 0.04251476510294846, 0.019954076236379997, 0.01046601080867861, 0.039164925925433636, 0.025726590771228075, 0.069186198924269, 0.04004977969452739, 0.016544673558590666, 0.07664904597082309, 0.7510165093200547, 45.25375638689314, 69.67224148341587, 65.42063876560756, 55.97967318126133, 47.46022980553763, 35.00840479987008, 26.93727135658264, 24.639536823545182, 37.15277174540928, 26.097843851361954, 35.107437474387034, 31.266372544424875, 4.291473652635302, 0.1227395481296948, 0.06486872131271021, 0.10961421778691666, 0.21454894595912524, 1.5791637769767215, 5.073510340281895, 6.920415784631457, 10.412566065788269, 9.627899050712585, 7.491442629269191, 6.199929714202881, 7.407300812857492, 16.601153714316233, 29.220218385968888, 42.5857697214399, 48.98776694706508, 55.116078104291645, 57.44372115816389, 56.99796642575945, 53.654944896698, 55.190097263881135, 52.026849951062886, 54.61665896006993, 51.76170669283186, 57.7649051121303, 57.652486733027864, 52.43984392711094, 49.50874982561384, 51.70097943714687, 47.11782257897513, 52.68108885628836, 52.254452092306956, 55.226207051958355, 56.3658401625497, 57.7776654788426, 53.56295769555228, 55.43316609518868, 52.153821332114084, 55.3825033051627, 54.0367796761649, 55.97863095147269, 53.01340382439749, 52.63334430967058, 49.03021001815796, 51.41953223092215, 45.15315689359392, 52.13495002474104, 49.44074433190482, 64.01223891122001, 39.37135240009853, 34.688353402274, 64.27360234941754, 51.57747173309326, 57.13779544830322, 53.82154185431344, 56.08700200489589, 55.470418861934114, 56.341264384133474, 49.70329243796212, 44.12285368783133, 48.701417786734446, 57.541534423828125, 56.93579394476754, 52.56099271774292, 49.76097290856497, 50.443800176892964, 57.34100941249302, 57.48530960083008, 50.04834345408848, 42.7503273827689, 44.828293868473594, 53.53427900586809, 55.98056255068098, 56.67852299554007, 52.44907808303833, 53.323560987200054, 54.64237771715437, 55.83707530157906, 59.801491601126536, 59.08971118927002, 56.4880450793675, 55.53655876432146, 58.74606023515974, 60.65771116529192, 57.97385481425694, 42.763219765254426, 19.55450984409877, 4.367881689752851, 2.3724845562662398, 3.9325740081923346, 5.414035473551069, 6.570545324257441, 3.853029727935791, 0.4815758988261223, 0.05217274418100715, 0.019771221226879528, 0.08635773536350046, 0.05399434607742088, 3.378691626446588, 27.74470588139125, 34.43951409203665, 23.3564008304051, 40.26499496187483, 24.782211133411952, 19.895126172474452, 20.335065262658254, 30.307385648999894, 47.43668930871146, 58.39248030526297, 60.9531763621739, 53.30286577769688, 9.65583688872201, 0.053351563068905046, 0.018881292015846287, 0.04854486510157585, 0.00934990551987929, 0.019200931203418543, 0.0781870134440916, 0.038582668240581236, 0.0184909545683435, 0.029016651013599973, 0.03688739260126438, 0.07946031833333628, 0.030366084139261926, 0.062262210462774546, 0.039341053260224204, 0.03175483836925455, 0.05918519664555788, 0.026207617816648314, 0.02580689369434757, 0.033995588310062885, 0.01067064085509628, 0.026978730456903577, 0.033009510686887164, 0.056091043033770153, 0.01583124996562089, 0.04590331470327718, 0.060733199651752195, 0.18559304757841996, 0.14652393758296967, 0.09984825325331517, 0.11343451243426118, 0.10698761551507882, 0.16220055281051568, 0.12116867170802184, 0.1507905793509313, 0.1239134001412562, 0.11502706126442977, 0.10902514082512685, 0.1113999726782952, 0.09805418630795819, 0.13654472306370735, 0.15590217363621506, 0.1114503810448306, 0.12670631813151495, 0.09177493503583328, 0.11658381058701447, 0.18217958217220648, 0.17139757930168084, 0.1496182336871113, 0.10460456660283463, 0.20034890435636044, 2.173041726861681, 56.44703333718436, 75.53843879699707, 74.42223153795514, 64.84342411586216, 56.610003335135325, 38.121538230351035, 28.69920597757612, 30.45886332648141, 48.49066850117275, 34.8806482723781, 53.51771797452654, 43.2811141695295, 6.542415976524353, 0.29609208181500435, 0.23961272676076206, 0.16277755184897355, 0.3507141236748014, 1.8259681335517337, 6.448055965559823, 9.397468992641993, 9.841235671724592, 10.40753470148359, 18.576898302350724, 16.097318989889963, 12.54000633103507, 27.720487935202463, 36.41802406311035, 48.016380991254536, 51.03626264844622, 57.61545283453805, 59.88325105394636, 59.10380213601248, 55.61720303126744, 55.61074468067714, 53.733626297542024, 54.52190637588501, 54.181260517665315, 58.281479358673096, 61.301795278276714, 55.34081063951765, 52.68709209987095, 53.64256320680891, 49.17158848898751, 54.41996240615845, 55.66420064653669, 56.70720515932356, 57.53192853927612, 59.266758237566265, 53.362877368927, 55.12083762032645, 54.08758837836129, 57.45740910938808, 56.66933052880423, 58.624564034598215, 57.15374503816877, 55.40418863296509, 50.81601864950997, 53.23879643848964, 47.501901626586914, 55.92040852137974, 51.35431643894741, 65.84407588413784, 42.512386322021484, 37.20958716528756, 65.71034390585763, 54.395021847316194, 58.96296215057373, 56.276145866939, 58.42306627546038, 58.610431398664204, 59.08034501756941, 52.23024109431675, 45.89653076444353, 51.256770678928916, 62.18559224264962, 59.89559800284249, 54.176890100751606, 50.71216739927019, 51.82811410086495, 59.84910065787179, 58.588023458208355, 53.58744314738682, 45.70063672746931, 47.048128673008506, 55.089459555489675, 57.70854479925973, 58.55173301696777, 52.52310766492571, 54.726829596928184, 55.56692239216396, 55.9415032523019, 62.054097584315706, 62.064721379961284, 59.67732729230608, 58.030235971723286, 61.35355240958077, 60.0385502406529, 60.121490887233186, 47.790981428963796, 28.778029816491262, 11.12922237600599, 14.3444231067385, 10.996884380068098, 12.33815334524427, 10.129479084696088, 3.1125226403985704, 0.21689570003322192, 0.11273113624858004, 0.18077569321862288, 0.23109247109719686, 0.29654235765337944, 5.239579234804426, 35.85622746603829, 46.21731519699097, 32.34196063450405, 59.7460241317749, 39.707975251334055, 26.704869747161865, 21.26646086147853, 35.71361221585955, 54.786118575504844, 67.4731366293771, 68.17120824541364, 62.607299259730745, 11.956463609422956, 0.15743547278855527, 0.15832112383629593, 0.12697161175310612, 0.13428517431020737, 0.1504837322447981, 0.20053866345967564, 0.1401240359991789, 0.15664876571723393, 0.11497049858527524, 0.08303956341530595, 0.12971373461186886, 0.15343098981039865, 0.07471297521676336, 0.11160657980612346, 0.12858837071274007, 0.10912977771035262, 0.09903566685638257, 0.14721589402428695, 0.1256224127220256, 0.09985363403601305, 0.12016487414283411, 0.14994982018002442, 0.14934349485806056, 0.12938957129205975, 0.15737543601010526, 0.14511440321803093], [0.010078181396238506, 0.021636909239792397, 0.014077385371950055, 0.0075986965426376885, 0.031356897936867814, 0.028886494426322833, 0.04107250499406031, 0.06245973879205329, 0.11081608650939805, 0.034467261750251055, 0.019535796716809273, 0.01939575557064797, 0.06142010100718055, 0.050225111190229654, 0.034825283967490704, 0.024374999904206822, 0.012557330375005091, 0.03177069573264037, 0.02594525377000017, 0.011638745781965554, 0.04717698260875685, 0.03148668811523488, 0.04024937416293791, 0.14483065344393253, 9.579532640320913, 60.5990058353969, 64.18374824523926, 59.96078600202288, 40.29241950171334, 52.53219243458339, 23.026441301618302, 22.06546027319772, 38.29627500261579, 34.04940400804792, 52.95880140577044, 43.20455196925572, 6.508831858634949, 0.20633861795067787, 0.05783604511192866, 0.06038137245923281, 0.004322459330848817, 0.10177165575857673, 1.864590346813202, 3.1253698595932553, 3.7035209962299893, 3.570145547389984, 8.906630005155291, 6.92760934148516, 23.92925374848502, 20.641887290137156, 32.626874991825645, 46.40935298374721, 55.73414816175188, 51.46398680550711, 49.396692752838135, 47.334307602473665, 52.372515882764546, 53.07752180099487, 55.252370493752615, 53.36873122623989, 53.759654249463765, 49.27155917031424, 52.6474734715053, 52.872800077710835, 55.11229828425816, 52.8699825831822, 54.106338092258994, 53.098908356257844, 50.889711243765696, 48.883801051548545, 54.86025585447039, 52.925133909497944, 53.59314414433071, 52.59734916687012, 53.321625913892476, 49.89095980780465, 53.853739806583945, 51.87684529168265, 53.654076371874126, 49.20491552352905, 48.93256350925991, 43.52363756724766, 46.08976364135742, 42.95071343013218, 50.57278653553554, 47.849686758858816, 59.44196401323591, 36.79144804818289, 35.16879006794521, 59.97371659960066, 49.088269165584016, 49.02980702263968, 49.80158165522984, 55.55327960423061, 53.632519585745676, 53.71741962432861, 47.60641295569283, 40.79858187266758, 44.24949155535017, 53.456358432769775, 53.55208376475743, 53.382603304726736, 51.95124660219465, 47.97379200799124, 52.56148951394217, 55.027658803122385, 50.037309714726035, 40.278113160814556, 43.08589063371931, 52.695659228733604, 55.50391265324184, 52.0183800969805, 51.13462482179914, 48.50122281483242, 53.081193923950195, 54.878724166325156, 55.84272418703352, 53.71117319379534, 49.86873599461147, 51.53066866738455, 54.492171560014995, 58.930903162275044, 58.67996897016253, 51.50555092947823, 39.48820720400129, 16.993587970733643, 7.534768990107945, 4.361954876354762, 4.756848360810961, 5.93546998500824, 4.435374753815787, 0.9228777587413788, 0.05244284861588052, 0.07101708317973784, 0.03841888006510479, 0.12177123794598238, 0.1596600634178945, 6.6758452739034375, 42.93106392451695, 39.129148619515554, 29.47716624396188, 40.31307997022356, 35.32651417595999, 16.05182044846671, 12.41538952078138, 22.315355709620885, 41.38544062205723, 50.481007780347554, 52.04623542513166, 21.989389657974243, 0.18710768701774733, 0.07719458812581641, 0.03373301222122141, 0.024409169231408408, 0.04435982734763196, 0.02970434964767524, 0.06282449207667794, 0.06475164688059262, 0.048082060114081414, 0.03232076371620808, 0.03670155882303204, 0.0024235792932034072, 0.032402170955070426, 0.06828201029981885, 0.023649062429155623, 0.010356795508414507, 0.06208008487841912, 0.03770050825551152, 0.05425416052873645, 0.06324124149978161, 0.018560363611738597, 0.038196466464017115, 0.019500618068767444, 0.021666897094941566, 0.032137735680277855, 0.02055289356836251, 0.03506383991667202, 0.0519202477298677, 0.05918117293289729, 0.06516737850116831, 0.061821237339505127, 0.023817291616329124, 0.030893153178372552, 0.04319357492827943, 0.05630506994202733, 0.05623980505125863, 0.01429663275900696, 0.01768107382979776, 0.031626062600740364, 0.026909044910488383, 0.03983611240983009, 0.01324088909729783, 0.02709495502391032, 0.015438103383140904, 0.07379417094801154, 0.031415699781583886, 0.06781804162476744, 0.029645167823348726, 0.06395907726671014, 0.13095852067427977, 11.611832959311348, 69.4184237888881, 70.34487574441093, 67.65533229282924, 46.12345198222569, 56.71888855525425, 28.286564622606548, 23.296201637813024, 33.800502164023264, 35.012243679591585, 41.949252196720664, 34.75387838908604, 5.624399134090968, 0.15815499132233007, 0.0470139476071511, 0.05679530810032572, 0.040540882984974554, 0.7786973725472177, 3.4781744139535085, 5.862290254661015, 7.3625587565558295, 8.434980205127172, 8.352141175951276, 5.182195799691336, 18.05011715207781, 17.61009989465986, 35.39571475982666, 45.68587875366211, 55.480128969464985, 53.88460717882429, 52.04069423675537, 51.26277044841221, 53.29083844593593, 54.160516670772004, 57.071082319532124, 54.23508473805019, 54.10637630735125, 50.64607613427298, 53.88799442563738, 54.90706934247698, 56.14605474472046, 56.27916485922677, 55.280976227351594, 54.83469690595354, 52.11202096939087, 51.289048535483225, 56.184784003666465, 54.482697691236226, 54.30773857661656, 53.07686867032732, 54.530949456351145, 50.64846978868757, 56.44942699159895, 54.60732058116368, 56.4798184122358, 50.80199718475342, 50.11629683630807, 47.407162938799175, 48.47268656321934, 45.510082381112234, 51.53270101547241, 50.102987561907085, 62.612864766802105, 37.52172803878784, 37.82768848964146, 61.243888991219656, 51.882494177137104, 51.59512710571289, 52.67374808447701, 56.62695346559797, 53.149161202566965, 55.09376743861607, 49.717317376817974, 43.57511329650879, 46.037954398563926, 55.45983675548008, 55.411320958818706, 55.16805757795061, 50.48515932900565, 49.22728524889265, 54.26177971703665, 57.57834945406233, 52.567968709128245, 41.090989862169536, 46.08495896203177, 56.989951678684776, 59.4094603402274, 53.692399161202566, 50.18157516207014, 49.467883995601106, 52.71393299102783, 57.84380190713065, 58.27310677937099, 55.86409684589931, 52.095595427921836, 53.66465847832816, 57.19241176332746, 59.87252303532192, 61.25039250510079, 54.795432635716026, 40.89738178253174, 19.010130643844604, 6.323198573929923, 2.8509153638567244, 2.852661098752703, 7.963506715638297, 5.3737867304256985, 3.9462419833455766, 0.2574626760823386, 0.22546240820416383, 0.025126482526372586, 0.03176725556009582, 0.08236263652465173, 6.8060831768172125, 44.688141754695344, 41.468040806906565, 33.616882119859966, 30.400279590061732, 20.318848167146953, 16.701212985174998, 22.949571643556865, 29.12506628036499, 48.33369132450649, 56.35255520684378, 60.59833880833217, 27.247946160180227, 0.233440989362342, 0.016717330186760852, 0.011663618331242884, 0.015376387230519737, 0.051319092844745944, 0.06968080345541239, 0.04806727483602507, 0.06342109399182455, 0.03925693866663745, 0.04229946933420641, 0.004253416272279407, 0.024921632804242626, 0.01647081332547324, 0.005934021560408707, 0.0867046635331852, 0.014766704856551119, 0.01770175388082862, 0.04498586071921246, 0.043681984434702566, 0.004668866724906755, 0.021214943578732864, 0.05041029018216899, 0.019462930537494164, 0.042648765591106245, 0.09698814672550984, 0.06580211408436298, 0.20453256129154138, 0.11383493630481617, 0.18339656186955317, 0.13000110776296683, 0.08236048556864262, 0.13402701887701238, 0.08992180840245315, 0.1343809427427394, 0.1701709915484701, 0.11947613395750523, 0.07754299550184182, 0.06992582923599652, 0.14321886136063508, 0.07614281813481025, 0.1059872309810349, 0.08461459247129303, 0.1955357026308775, 0.06515173826898847, 0.1422433044229235, 0.14257566444575787, 0.23392823178853306, 0.08057127014866897, 0.0997814718367798, 0.16934421019894735, 18.768208265304565, 79.48860781533378, 77.95592553274972, 76.74045630863735, 54.416589055742534, 64.23546368735177, 32.48359271458217, 29.949643748147146, 51.14960513796125, 45.42036376680647, 66.40397562299455, 54.63125365121024, 9.212619985852923, 0.3813060921217714, 0.1414232812821865, 0.16868702189198562, 0.09252268741173403, 0.7800935262015888, 3.971863465649741, 8.74647229058402, 9.931114094597952, 10.14363430227552, 18.38466944013323, 16.718753712517874, 31.952663489750453, 23.771189178739274, 39.01601110185896, 50.382975646427695, 60.95881135123116, 56.66662767955235, 54.04344647271292, 51.7526010785784, 54.574021339416504, 54.249530042920796, 56.93415069580078, 53.94134269441877, 54.79813201086861, 52.01732049669538, 54.66257265635899, 56.20000055858067, 56.96036624908447, 56.51596294130598, 58.15820094517299, 56.901858942849294, 54.30991336277553, 53.797650473458425, 58.2901611328125, 56.23484230041504, 54.69575725282942, 53.28919867106846, 54.428268977573936, 52.10671601976667, 57.22452981131417, 56.798400265829905, 57.24420363562447, 52.65647833687918, 52.3119067464556, 48.944945199149, 50.63172810418265, 47.80354029791695, 53.61053548540388, 53.889488288334434, 64.35889843532017, 40.233530044555664, 40.81994063513619, 63.8894225529262, 54.609154905591694, 53.58841936928885, 54.8871488571167, 57.99061386925833, 55.494654178619385, 57.4755334854126, 52.26776484080723, 45.31046758379255, 48.86584690638951, 58.316543442862375, 57.93659509931292, 56.47572592326573, 51.81726796286446, 50.35507862908499, 55.87287242071969, 59.19370487758091, 54.29544026511056, 43.95530135290963, 47.45316348757063, 58.45514610835484, 61.1188839503697, 54.05986854008266, 49.78158473968506, 48.8282675743103, 53.173994064331055, 58.79173769269671, 60.86231476919991, 59.56850460597447, 55.35903576442173, 56.589551312582834, 59.427414485386436, 63.1188325881958, 62.66419805799212, 57.10224846431187, 44.430165563310894, 21.58455981527056, 11.805852719715663, 11.194728255271912, 15.04542773110526, 15.304902996335711, 9.751059344836644, 4.313966274261475, 0.1613471321761608, 0.3305825324995177, 0.1904838058565344, 0.1929099756692137, 0.2669192829302379, 9.217539310455322, 54.86003698621477, 51.631368909563335, 42.79213121959141, 56.229016235896516, 51.08060605185372, 26.32469211305891, 22.881230899265834, 35.84516593388149, 57.01389169692993, 65.98761177062988, 70.50895050593785, 34.92003066199166, 0.4618970262152808, 0.1160878829125847, 0.17312359597001756, 0.11106810798602444, 0.12938175456864492, 0.10394480664815221, 0.19204564419175896, 0.19973662149693283, 0.14403623821479933, 0.15285739701773438, 0.10740087726818663, 0.07359877321869135, 0.07873185670801572, 0.09598016259925705, 0.154731972143054, 0.13544959468500956, 0.1954878523413624, 0.11727985180914402, 0.10981992246317011, 0.07948612980544567, 0.0694910239960466, 0.1263513086097581, 0.07019671398614134, 0.22840704662459238, 0.14158471833382333, 0.09865982630955321], [0.04586900797273431, 0.010566986997478774, 0.06201035861990281, 0.03882003336080483, 0.04181063235072153, 0.018915636065815176, 0.04085910912337048, 0.02418429254820304, 0.024397469591349363, 0.04024096032870667, 0.04563051987705486, 0.040371975262782404, 0.0041640108018847445, 0.023388596584222147, 0.02073608954170985, 0.026151153525071483, 0.018980965417410647, 0.06543907749333552, 0.05769291493509497, 0.0417315253455724, 0.006623494987642127, 0.019002703983070593, 0.008016118563578596, 1.1571687353508813, 37.85378244944981, 64.46000167301723, 58.48851830618722, 47.20317077636719, 37.465708187648225, 31.566538197653635, 19.452546766826085, 28.841692686080933, 34.28905779974801, 36.25378254481724, 40.00771011625017, 8.612318209239415, 0.32347395537155016, 0.06979241568062987, 0.07046624166624886, 0.041998807074768205, 0.3496458652828421, 0.6153767076986176, 1.4228481990950448, 5.188957699707576, 7.368775657245091, 13.990891814231873, 5.811697815145765, 8.000524112156459, 24.124781267983572, 40.049110957554404, 50.18445519038609, 50.387933186122346, 43.75863259179251, 48.15220090321132, 54.38570083890642, 58.87154470171247, 56.86846590042114, 55.427235807691304, 52.75709172657558, 52.11591196060181, 52.321578638894216, 53.5076778275626, 49.747708797454834, 51.84579379217965, 55.18614373888288, 52.03657742909023, 53.21583959034511, 55.38207251685006, 52.39824506214687, 54.04951919828142, 54.88256304604666, 53.6167437008449, 54.53831802095686, 52.58454711096627, 52.77484784807478, 52.964158466884065, 54.935098375592915, 52.94056238446917, 52.79149225779942, 47.32669932501656, 45.17754507064819, 42.293941906520296, 43.90937376022339, 40.59274843760899, 48.115490095955984, 48.038090637751985, 57.640191895621165, 37.57825510842459, 38.06686632973807, 58.56138406481062, 45.656949928828645, 50.07960687364851, 50.66722297668457, 54.95495980126517, 50.455205644880024, 53.87211084365845, 47.10538877759661, 41.59078073501587, 39.84882913316999, 51.94342640468052, 52.15444319588797, 53.71686724254063, 52.5763795035226, 48.68301200866699, 49.27122218268258, 54.47547851290022, 50.839322907584055, 40.933144160679404, 41.648798193250386, 54.44220011574881, 52.79374694824219, 54.65344967160906, 49.70443541663033, 52.39813041687012, 54.66697086606707, 56.71351064954485, 52.22795166288103, 55.49092647007534, 49.77083935056414, 49.65898377554757, 51.55018615722656, 55.62111139297485, 58.6464786529541, 59.89584813799177, 55.7337521144322, 39.466772011348176, 17.45882545198713, 3.1187473578112463, 2.305944915328707, 6.054810506956918, 5.587729147502354, 3.332626155444554, 1.2604010530880518, 0.03471171756141952, 0.01519478072545358, 0.021845504475225295, 0.03650813563061612, 0.4445995943886893, 10.12114211491176, 39.19062628064837, 27.410429784229823, 49.37892273494175, 91.34502778734479, 44.61113486971174, 12.776747959000723, 33.934411321367534, 38.895296573638916, 44.44470814296177, 49.29637813568115, 32.802598408290315, 2.4604507046086446, 0.16267935426107474, 0.042030362345810444, 0.012172721459397247, 0.028742234488683086, 0.006701901829468885, 0.04318828235513397, 0.0018876829375845513, 0.0029458375190318164, 0.03749254405764597, 0.03600564652255603, 0.025496881222352386, 0.03975624883813517, 0.046253306458571126, 0.050486011297575066, 0.06459193330790315, 0.023760238695623617, 0.06257004823003497, 0.01105178754577147, 0.015284879997904812, 0.0205812122273658, 0.027256419216947894, 0.06804098787584476, 0.07134760437267167, 0.0203119220345148, 0.04913125167201672, 0.03980681326772485, 0.044303977130247016, 0.02498346091514187, 0.04527651119445052, 0.022565438611699, 0.042002379561641386, 0.03610990682084646, 0.029030747578612397, 0.03104578623814242, 0.058085651003888676, 0.023916327194975953, 0.046804914716631174, 0.0403621398976871, 0.05392439250967332, 0.03211261970656259, 0.03240681891994817, 0.026948941073247364, 0.05522743419611028, 0.04793351183512381, 0.03434932557865977, 0.002642830921104178, 0.03353699702503426, 0.013946624888506318, 1.9736662081309726, 44.666001319885254, 72.99242428370884, 65.66807106563023, 55.47838149751936, 45.382440498897004, 42.24294212886265, 23.090086800711497, 25.610075099127634, 34.563317094530376, 35.62374421528408, 35.934745584215435, 10.398654903684344, 0.28541669036660877, 0.034766210708767176, 0.1143787753369127, 0.09193354938179255, 1.6891845933028629, 3.3567172970090593, 5.42658348594393, 7.289622647421701, 5.6437516042164395, 11.42029891695295, 9.894794992038182, 12.24875955922263, 26.88010678972517, 39.68943745749337, 50.25311034066336, 52.913565158843994, 49.89167547225952, 50.720581667763845, 56.5395416532244, 57.48220375605992, 56.99714306422642, 54.428147384098594, 54.96033770697457, 51.5602263041905, 53.399014949798584, 53.49826301847185, 50.93637881960188, 52.33829600470406, 54.76095914840698, 53.597403390066965, 56.05630138942173, 56.41260501316616, 55.258484908512656, 55.321967124938965, 55.49327148709978, 55.551660673958914, 54.67489876065935, 52.794876030513215, 53.15937852859497, 52.55945021765572, 54.275630950927734, 54.57408387320382, 54.34329598290579, 48.273026602608816, 47.83675268718174, 44.42441245487758, 45.16057756968907, 43.76634856632778, 50.38724184036255, 51.00680228642055, 60.417428561619346, 39.89020218167986, 39.769869804382324, 60.7694798878261, 48.736096245901926, 52.043647221156526, 52.52908311571394, 55.78810439790998, 51.88228573117937, 56.57207311902727, 50.36541754858834, 43.66119105475289, 42.368513447897776, 53.10214969090053, 54.70603016444615, 56.44994810649327, 52.579158782958984, 49.368976388658794, 50.750896658216206, 55.77297816957746, 53.28756237030029, 42.53267853600638, 44.61865282058716, 56.30940689359392, 53.37102065767561, 55.26499537059239, 50.87966067450387, 52.29094750540597, 55.99685607637678, 59.489378520420615, 55.71702780042376, 56.711599894932334, 51.98023796081543, 52.82152237210955, 53.92554249082293, 57.36807612010411, 60.39584050859724, 63.42883341653006, 57.35684783118111, 44.290614468710764, 20.053093467439922, 6.347116010529654, 2.5939351533140456, 6.7121917349951605, 8.527049047606331, 8.546433653150286, 2.9913512681211745, 0.6056587834443364, 0.16656004531042917, 0.037723785399326255, 0.029307613614946604, 0.32373304718307083, 13.20201245376042, 46.01711327689034, 32.50060885293143, 46.816076210566926, 79.4837371281215, 38.351096289498464, 15.878113746643066, 38.46653018678938, 45.387182644435335, 51.46023825236729, 56.41716650554112, 41.56996393203735, 3.4774174945695058, 0.08707645322595324, 0.01598893811127969, 0.006698747913885329, 0.0130488772577207, 0.033954974596521685, 0.039809344203344414, 0.04554131627082825, 0.027604176895692945, 0.07577917764761619, 0.005625296608611409, 0.01423140858033938, 0.05241384802918349, 0.04367776055421148, 0.04145358383123364, 0.07668567329112973, 0.029004189717982496, 0.07714660891464778, 0.023706508900171945, 0.008068696545836116, 0.04361187819657581, 0.02878344870571579, 0.07626395020633936, 0.006274339950843049, 0.03702785613547478, 0.0353617066118334, 0.12834365027291433, 0.0818839639957462, 0.17691435398800032, 0.15115200781396457, 0.06518126811300005, 0.11358623286443097, 0.11530660412141255, 0.13052842446735927, 0.13629411293991975, 0.16452355815895967, 0.08790209463664464, 0.12329273058899812, 0.12196994014084339, 0.10040234494954348, 0.09609944905553545, 0.09111471367733819, 0.15818624464528902, 0.16982991913599627, 0.1301603599318436, 0.1421552441482033, 0.06936128810048103, 0.13793268001505307, 0.07374024098472935, 3.032048387186868, 55.44031579153878, 81.06130477360317, 73.10911233084542, 63.096292631966726, 51.96222823006766, 43.56708117893764, 31.96505560193743, 39.20555795942034, 44.82222809110369, 49.670111315590994, 51.14422723225185, 11.974736503192357, 0.7308470287493297, 0.1749154712472643, 0.2897249534726143, 0.13644898177257606, 1.615512300814901, 2.694389602967671, 6.91356051819665, 12.520276921136038, 16.391170467649186, 25.44379254749843, 17.191799231937953, 13.986326847757612, 31.049477577209473, 44.21617841720581, 54.508173261369976, 57.09660652705601, 50.72915227072579, 52.96063920429775, 56.102367946079795, 59.55652591160366, 58.34371089935303, 56.07273040499006, 54.7371198790414, 53.676852566855295, 54.38685423987252, 54.46105752672468, 52.35744176592146, 52.84849527903965, 57.26066391808646, 55.038247857775005, 57.29963983808245, 59.502045086451936, 55.685639313289094, 58.711145537240164, 58.35127053941999, 56.311321122305735, 55.88932228088379, 53.22124876294817, 54.20396375656128, 54.21876689365932, 55.89443268094744, 56.873020444597515, 55.8796260697501, 50.76531417029244, 50.26200403485979, 46.12579352515084, 47.12198454993111, 46.213795934404644, 52.35605212620327, 52.56039864676339, 61.30108656202044, 42.397522177015034, 43.9889167376927, 61.998616218566895, 49.910612787519185, 54.55959340504238, 55.6077812739781, 58.784428187779014, 52.68277726854597, 59.76128237588065, 52.98554502214704, 45.04784999574934, 44.68622752598354, 55.30543041229248, 56.78336436407906, 57.44167838777815, 55.465353625161306, 50.02163110460554, 53.47358649117606, 58.45008087158203, 57.1068377494812, 44.630475180489675, 46.56585768290928, 59.551662172589985, 55.66846684047154, 55.4765749658857, 49.866578578948975, 52.08475971221924, 57.34360456466675, 61.10372992924282, 57.43893037523542, 60.33396680014474, 55.15632207053048, 54.76702145167759, 56.14246252604893, 58.98764215196882, 63.248527663094656, 64.13376290457589, 62.25164876665388, 46.977368218558176, 23.41961554118565, 6.947051269667489, 10.247007863862173, 18.063596657344274, 18.164988245282853, 10.421345114707947, 3.277402090174811, 0.34268512736473766, 0.24880345644695417, 0.23116602429321834, 0.21364578870790346, 1.0484752420868193, 16.956508908952983, 50.69847597394671, 38.751910073416575, 58.402312006269185, 100.19446890694755, 56.25448138373238, 21.762275627681188, 47.267886298043386, 51.813738277980256, 59.72985567365374, 65.52170726231166, 52.993427753448486, 4.324451540197645, 0.22838688056383813, 0.1275096493107932, 0.0882890767284802, 0.118517363976155, 0.1540228080536638, 0.17800448834896088, 0.1494645183639867, 0.143862193982516, 0.12297187852008001, 0.09582057116287095, 0.09651787446013518, 0.19199944952768938, 0.14572534257812159, 0.15648684012038366, 0.13901947598372186, 0.11604665512485163, 0.21563583692269667, 0.09664932026394776, 0.10236669704318047, 0.186634734539049, 0.12948360267494405, 0.18292077311447688, 0.16014670873326914, 0.09291280433535576, 0.08698858294103827], [0.04390358718644295, 0.07383961243821041, 0.016730558226949403, 0.06573529874107667, 0.037383890245109797, 0.0554344620156501, 0.0328040095711393, 0.054848072052534134, 0.04772569352228727, 0.0756547139691455, 0.04007221884759409, 0.017392696446872184, 0.03265764956761684, 0.02785894983181996, 0.0325594723357686, 0.038185620081744025, 0.060597682637827735, 0.039607469857271226, 0.01655634436091142, 0.0579913074948958, 0.06123511879039662, 0.06164743059447833, 0.03997591437239732, 3.9733573283467973, 44.085222244262695, 56.64777026857649, 57.628529344286235, 46.89868334361485, 30.455722740718297, 18.37846643584115, 28.849799496786936, 40.144811970846995, 38.033111980983186, 41.429648535592214, 16.53639129229954, 0.4965940501008715, 0.04156832071021199, 0.039672178349324634, 0.08929146294082914, 0.1186161179627691, 0.9249788288559232, 2.1825446912220547, 5.184221199580601, 3.649269027369363, 7.631911754608154, 8.123174582208906, 16.980320385524205, 25.07314784186227, 46.246511527470176, 49.37809937340872, 45.55841057641165, 45.96922976630074, 57.930786405290874, 60.4716523034232, 57.44026790346418, 51.003324713025776, 54.92687865665981, 54.40372446605137, 55.16033465521676, 49.20963682447161, 50.85979230063302, 52.536986691611155, 51.578315939222065, 52.13658285140991, 51.949328899383545, 52.30329098020281, 50.66799770082746, 53.1160843031747, 50.8408202443804, 52.81782245635986, 55.03731679916382, 52.87319959912981, 53.12767389842442, 50.97996139526367, 52.30888080596924, 50.03958177566528, 52.09394523075649, 51.15145683288574, 50.81624446596418, 44.398499148232595, 44.513877459934776, 42.76706211907523, 43.66377925872803, 41.06773771558489, 47.03886672428676, 49.19736630575997, 58.41199084690639, 38.00593410219465, 38.44412572043282, 58.71938610076904, 48.31198515210833, 45.48054906300136, 48.612671920231406, 53.577962330409456, 50.09510483060564, 54.05100958687918, 49.169698578970774, 43.381894315992085, 37.90791239057268, 43.430927753448486, 49.78082043784005, 53.3853200503758, 52.04041978291103, 52.63839217594692, 46.071208477020264, 53.51711000714983, 51.40184211730957, 40.365872383117676, 41.41669014522007, 54.139414991651265, 53.169602802821565, 52.6257256099156, 47.67926481791905, 48.70349529811314, 54.27822610310146, 54.061793191092356, 52.332004410879954, 51.61235863821847, 48.32135827200753, 46.04503461292812, 47.48947129930769, 52.436091899871826, 53.39304992130825, 57.6980425970895, 58.30707999638149, 57.328374113355366, 40.40318420955113, 21.564213752746582, 3.6573219895362854, 4.8199562430381775, 5.724627767290388, 6.672964377062661, 3.5028240169797624, 0.6847068103296416, 0.1382543056138924, 0.06401042201157127, 0.03150007561115282, 0.02148553146980703, 3.1673634690897803, 22.556016990116664, 49.298163822719026, 78.35090282985142, 72.02894537789481, 81.85228770119804, 28.70307959829058, 26.499133586883545, 32.34028264454433, 38.27087933676583, 47.760854039873394, 54.30914906093052, 6.290232411452702, 0.16875091274934156, 0.0135853601220463, 0.012887039022254092, 0.019927194375278692, 0.05852986073919705, 0.08526371978223324, 0.057978652816798, 0.044286630382495265, 0.01219329294482512, 0.01004726903712643, 0.019121861517695442, 0.0307130021309214, 0.1385002474167517, 0.058645191336316724, 0.06672268254416329, 0.0802740514544504, 0.02529009597908173, 0.0462702392999615, 0.02980946490008916, 0.09440659917891026, 0.021752587586109127, 0.08716080191412143, 0.09390098880976439, 0.04280771581189973, 0.03821566900504487, 0.06438971630164556, 0.044782045762985945, 0.050799063606453795, 0.01271459273993969, 0.012800033021319126, 0.05291605893788593, 0.013152577764620739, 0.03976354987493583, 0.04921848074133907, 0.04622300986998847, 0.04310186752783401, 0.011543090155880367, 0.07027717466865267, 0.048683849429445605, 0.04628432568694864, 0.04635205026715994, 0.04135027348196932, 0.07032343718622412, 0.02430329910878624, 0.05497164685013039, 0.035998664397214136, 0.10545449956719365, 0.07622730931533234, 7.036888003349304, 55.84425973892212, 63.9484474999564, 65.25354153769356, 52.83231292452131, 39.3446261542184, 26.89094771657671, 37.70461852209908, 41.704887526375906, 33.280287061418804, 38.7489675113133, 18.156349897384644, 0.5763196349143982, 0.04786513586129461, 0.054986700149519105, 0.18737329276544706, 0.577700100839138, 2.7401107038770403, 5.235538423061371, 4.940428452832358, 8.214231593268257, 5.092986140932355, 9.862605725015912, 19.36322419984, 26.52427738053458, 44.47779199055263, 50.74189179284232, 50.648025103977744, 50.23411743981497, 58.16216836656843, 58.684040614536826, 58.1822521345956, 55.01038210732596, 55.550222396850586, 55.47630051204136, 54.89728627886091, 51.73099912915911, 51.24542774472918, 53.146288122449604, 53.48418596812657, 51.70243855885097, 52.4431790624346, 52.16811030251639, 51.42312444959368, 54.10600805282593, 52.77166557312012, 53.99525029318673, 55.94814920425415, 53.82777091435024, 52.04208387647356, 51.077962262289866, 52.60957104819161, 50.995646953582764, 54.30111346926008, 53.396023750305176, 53.662084170750205, 46.61268506731306, 46.519141469682964, 44.30605336597988, 44.61896896362305, 42.33994940349034, 49.92878927503313, 50.608222348349436, 59.30161040169852, 39.915709018707275, 39.56925446646554, 59.35308265686035, 50.16219663619995, 46.41623517445156, 50.513653891427175, 55.587951115199495, 50.639527457101, 56.11790759222848, 50.54702608925955, 44.38891063417707, 40.32175132206508, 44.11993197032383, 50.61642469678606, 54.388782364981516, 53.73713861192976, 52.675655364990234, 48.141799449920654, 55.35128852299282, 54.017818042210166, 42.13760049002511, 43.11066443579537, 56.767838614327566, 55.694154330662315, 53.13871806008475, 47.69371359688895, 50.22915295192173, 55.64619786398751, 56.637469564165386, 54.363296372549875, 53.42615113939558, 50.94493900026594, 48.518506458827424, 49.38798318590437, 54.43804161889212, 56.79223026548113, 59.676465715680806, 60.032137053353445, 60.12244973863874, 42.46386357716152, 22.671289341790335, 5.754154571465083, 4.753904930182865, 7.958220873560224, 8.20287823677063, 6.569821843079158, 3.2194597593375613, 0.37409182637929916, 0.20278583573443548, 0.07919575752956526, 0.07080946503473179, 2.8209414865289415, 26.408867801938737, 52.36995199748448, 73.10337311880929, 73.34865842546735, 74.77423422677177, 28.05162344660078, 34.61852748053414, 38.38681697845459, 44.0602399962289, 54.238704749516074, 62.72720432281494, 9.304740939821516, 0.15882941441876547, 0.054088676015713384, 0.025310029641592076, 0.030325857190681354, 0.07106511667370796, 0.0547026009298861, 0.031333702217255316, 0.07438776695302554, 0.03581457784665482, 0.02514847893533962, 0.05491863630179848, 0.028191667781876664, 0.023217641382611225, 0.08964419937027351, 0.052413542688425095, 0.019700144683676105, 0.024932848988100886, 0.0254370055959693, 0.03824639307068927, 0.01969984103925526, 0.017153935240847722, 0.05906714512301343, 0.01674282274741147, 0.07195601958249297, 0.053301351477525065, 0.20901946909725666, 0.12384138043437685, 0.11961741851908819, 0.09329106046685151, 0.09095218418432133, 0.11919633325721536, 0.13006748205849103, 0.09846551423626286, 0.08471895794251136, 0.15870560891926289, 0.18756579315023764, 0.16202853061258793, 0.0995237778073975, 0.1659920843584197, 0.16796800547412463, 0.16290785771395477, 0.12293522405837264, 0.10373793489166669, 0.16603013660226548, 0.18758800838674816, 0.10449211299419403, 0.17015442172331469, 0.2006503774651459, 10.811342290469579, 66.41244547707694, 70.45241301400321, 74.10001577649797, 60.07727949959891, 45.40795775822231, 27.47059076172965, 39.736487184252056, 51.896272454942974, 47.52187769753592, 51.83233513150896, 22.879120383943828, 1.0993182510137558, 0.10199916855032955, 0.18318480466093334, 0.11842194838183266, 0.6629585687603269, 2.5197309979370663, 5.938593200274876, 10.627588493483406, 11.463205780301776, 18.587110417229788, 16.620914391108922, 23.764439003808157, 29.98300552368164, 50.645419529506135, 54.7676294190543, 53.96822527476719, 51.58337770189558, 59.336816923958914, 61.8005439213344, 60.04006494794573, 55.62602724347796, 58.10521745681763, 57.421910762786865, 57.99521010262625, 53.80833680289132, 51.66676998138428, 54.48821803501674, 54.73358672005789, 52.41573020390102, 52.12278720310756, 52.93298189980643, 50.91961281640189, 55.70811326163155, 52.63476521628243, 54.62998560496739, 57.73133489063808, 56.08507735388619, 54.84751285825457, 52.00040858132498, 53.13716861179897, 52.27506044932774, 56.29129988806588, 54.77019330433437, 55.03100436074393, 48.50685780388968, 48.95552383150373, 47.062681674957275, 47.428017956869944, 44.51414496558053, 50.56701258250645, 55.214846747262136, 63.2302052634103, 43.664428915296284, 43.23978975840977, 61.29602827344622, 53.41073308672224, 50.30490568705967, 52.750379766736714, 57.41311434337071, 52.2893077305385, 58.30393246241978, 52.93182155064174, 47.041097096034456, 41.61625977924892, 46.93967424120222, 54.41802733285086, 56.53017895562308, 55.33578361783709, 55.38597393035889, 49.15073347091675, 56.53858280181885, 55.470919132232666, 44.90124647957938, 44.767128876277376, 58.68543720245361, 56.33905833108084, 53.51320859364101, 47.93160949434553, 48.88897051130022, 58.023041112082346, 59.49213695526123, 57.330979687826975, 56.55786057880947, 52.600649561200825, 50.46416187286377, 50.41918270928519, 56.92524657930647, 57.985420090811594, 63.21625328063965, 62.25786740439278, 64.51307896205357, 45.9790996823992, 29.190355028424943, 8.600979617663793, 13.208411744662694, 12.358684403555733, 16.55103635787964, 11.939223391669136, 3.065232983657292, 0.2621369409774031, 0.2841373533010483, 0.18942573906055518, 0.1553561565067087, 4.45280430998121, 32.37746592930385, 59.024912289210725, 78.31586306435722, 73.87283052716936, 89.14453329358781, 41.128968715667725, 36.57440716879708, 44.77933686120169, 51.91097484316145, 61.47265148162842, 69.77485942840576, 11.912857583590917, 0.25519813331110136, 0.1234238642667021, 0.08516012784093618, 0.13737694626407965, 0.1602137479931116, 0.22159654993031705, 0.16639085938887938, 0.20283559949270316, 0.17547819390892982, 0.08016695148710694, 0.17662210895546845, 0.09166587410228592, 0.1830581221729517, 0.1393452813582761, 0.1522597705147096, 0.1967764174831765, 0.1475258216794048, 0.06903204255338226, 0.16574775746890477, 0.23176701632993563, 0.07656556580747877, 0.15327945937003407, 0.1844359960939203, 0.13121108497892106, 0.0800844891262906], [0.03729656618088484, 0.052098213894558806, 0.12790033620383057, 0.017423378104077916, 0.07800724916160107, 0.026099232025444508, 0.07357612371976886, 0.04107772292835372, 0.02166349084914795, 0.0253907193296722, 0.014243369456380606, 0.010890842432023158, 0.05356223462149501, 0.045810888055711985, 0.018751211763758744, 0.014387032283203942, 0.013647129709300185, 0.04762508374239717, 0.027745773583384495, 0.016109713951924017, 0.043718367482402494, 0.03472673354138221, 0.3722001521715096, 19.10926580429077, 62.113358770098, 53.793439865112305, 49.06946039199829, 36.225590229034424, 32.741492475782124, 18.628825664520264, 28.17138433456421, 28.67899193082537, 38.369835581098286, 32.78820521490914, 1.4520328044891357, 0.10827402970088379, 0.06252247613987752, 0.09687925542571715, 0.09248554440481321, 0.6546720276985849, 2.151144261871065, 3.645081869193486, 3.7455154742513384, 8.25535798072815, 3.989169257027762, 24.52046380724226, 43.618508270808626, 47.77079691205706, 52.67154550552368, 45.33073895318167, 50.80391836166382, 57.01269313267299, 56.347979818071636, 53.72936705180577, 54.88093021937779, 54.88589818137032, 54.89659145900181, 53.30681235449654, 53.07636145183018, 53.29060915538243, 53.5782402583531, 49.12715128489903, 51.58700466156006, 50.43394415719168, 52.23975665228707, 51.443374974387034, 52.3982971736363, 49.06521504265921, 50.45605679920742, 51.2627808707101, 51.78346150262015, 51.55909027372088, 51.6772027015686, 50.73784099306379, 52.14970105034964, 49.75464309964861, 53.46891730172293, 52.68877008983067, 48.10207312447684, 43.48667662484305, 43.754144055502756, 39.31298753193447, 42.39684125355312, 41.54514844076974, 46.337536403111045, 48.161421162741526, 58.76862103598458, 36.6666236604963, 39.94782359259469, 56.91967759813581, 46.543015480041504, 45.70687968390328, 47.8789838382176, 54.085048811776296, 49.56564514977591, 53.17052343913487, 51.01180498940604, 44.54649577822004, 37.37248420715332, 39.946176869528635, 43.2113299369812, 50.46873378753662, 50.56384072984968, 51.569936411721365, 50.69624212809971, 52.790648051670615, 51.43380730492728, 39.05138438088553, 42.34439277648926, 52.69217470714024, 52.52938188825335, 51.66461951392037, 48.32081978661673, 53.40137038912092, 55.48125805173601, 53.46106583731515, 48.16531562805176, 47.317809104919434, 44.81742688587734, 43.99781043188912, 45.531135422842844, 47.43798862184797, 48.897297927311485, 54.86374385016305, 53.267867701394216, 55.993722438812256, 50.8364428792681, 38.317369733537944, 13.750961831637792, 3.810526728630066, 5.757922666413443, 9.443618059158325, 4.282629898616245, 1.669071078300476, 0.41446911117860247, 0.0710400923022202, 0.06227226635175092, 0.07700321410915681, 0.04576474088909371, 7.3949755770819525, 35.63489954812186, 62.02056557791573, 82.357435635158, 54.44316938945225, 24.456959009170532, 20.14077799660819, 32.14144951956612, 46.126630783081055, 45.03190735408238, 50.14298834119524, 17.646949665887014, 0.018598151226927127, 0.07001536193170718, 0.04826622469616788, 0.04707034743790116, 0.02416520705446601, 0.016059794130602052, 0.054314197307186465, 0.02543907512777618, 0.037904577662370036, 0.008584699526961361, 0.010930620699322649, 0.025198470002838542, 0.018370562099984715, 0.051806854350226264, 0.03121716043512736, 0.02509404855248119, 0.043560312927833626, 0.035046747619552274, 0.044161888504666943, 0.03508944443560072, 0.045594744118196626, 0.012780146008091313, 0.046280220550085814, 0.029068796429783106, 0.045145927130111625, 0.016656044903876524, 0.012128241792587298, 0.19241992410804543, 0.059466510478939326, 0.05951127343411956, 0.0545905985470329, 0.025069251490224684, 0.05070227397871869, 0.015705062808202844, 0.012107955291867256, 0.016805938378508602, 0.04209658397095544, 0.03867698800084846, 0.03229516598262957, 0.03205900526206408, 0.008310498436912894, 0.03971233405172825, 0.015506872907280922, 0.017317375667127113, 0.03267022282151239, 0.0963620828198535, 0.019397229687975984, 0.435744332415717, 24.199978147234233, 71.05167429787772, 61.85925619942801, 56.89511571611677, 42.43706784929548, 39.32649482999529, 21.825210673468455, 28.789204256875173, 33.23926837103707, 35.37784399305071, 31.42796332495553, 1.7421068506581443, 0.24013574155313627, 0.03437904880515166, 0.22927136453134672, 0.5230304801038334, 3.4026998238904134, 5.927971575941358, 9.100244164466858, 5.858162156173161, 3.2445894394602095, 8.574302009173802, 21.671328919274465, 34.74451569148472, 46.23288263593401, 52.24190711975098, 51.808301312582834, 53.91132647650582, 58.269980090005056, 58.93860176631382, 56.27746255057198, 56.939882959638325, 57.021517344883506, 56.64087070737566, 54.43558543069022, 54.85012885502407, 53.45839772905622, 52.87098659787859, 49.73550776072911, 51.59391811915806, 50.95409672600882, 52.40618685313633, 50.74619272777012, 50.92694664001465, 49.87984616415841, 50.88659150259835, 51.60696683611189, 54.12611613954817, 52.713078362601145, 54.00929260253906, 52.51153891427176, 52.16473695210048, 50.804710456303184, 55.48635802950178, 53.258407729012625, 49.88305275780814, 45.30145924431937, 45.58344146183559, 42.37371070044381, 44.42119196483067, 42.99309744153704, 49.314936774117605, 50.02980218614851, 59.62012277330671, 38.43631247111729, 41.5340313230242, 58.68105288914272, 48.956520898001536, 47.40805230821882, 49.94238689967564, 56.29883173533848, 49.54466506413051, 54.298817089625764, 53.04232222693307, 47.12942954472133, 39.31958832059588, 41.8958101272583, 45.08422381537301, 53.38261720112392, 52.29886497770037, 54.67171648570469, 51.663629395621165, 54.94437074661255, 52.56746843882969, 40.76018960135323, 44.30615064076015, 54.894305501665386, 53.6938339642116, 51.123556341443745, 48.48699985231672, 53.12437697819301, 57.95023093904768, 55.63545594896589, 51.168000493730815, 48.749794619424, 46.45461354936872, 45.615976401737754, 47.68787363597325, 49.625281538282124, 52.358570848192485, 57.097151960645405, 57.40626341956002, 57.55764034816197, 54.04189702442714, 38.66653060913086, 14.706484181540352, 4.273471738610949, 3.8482428533690314, 6.460020329271044, 6.554605288164956, 6.5777254189763745, 2.754525827510016, 0.25820697471499443, 0.02716844036642994, 0.03725144699481981, 0.056911486866218705, 8.392372114317757, 40.68052503040859, 68.88562202453613, 86.96150657108852, 64.86346272059849, 27.011045592171804, 22.06038808822632, 37.203993865421836, 53.19644021987915, 50.759769507816856, 58.341661180768696, 22.137843132019043, 0.0993750768580607, 0.0641264718558107, 0.01650656363926828, 0.03865069816155093, 0.057747659140399525, 0.03049442225268909, 0.03227904059791139, 0.029714324112449373, 0.027799065723749142, 0.01280138160966869, 0.011604427177059864, 0.05238043696486524, 0.02251559173289154, 0.0732893951769386, 0.062031997101647515, 0.03152552745970232, 0.01680258132650384, 0.06313125775860888, 0.09280679002404213, 0.03470626553254468, 0.011205226365875984, 0.015598308893718889, 0.032456365547009876, 0.0247411407929446, 0.05514394724741578, 0.06355310297970261, 0.15467336028814316, 0.2764909421758992, 0.12912881028439316, 0.13488250225782394, 0.17338586332542555, 0.12276933581701346, 0.11051191961658852, 0.09761262285922255, 0.19752885853605612, 0.08164242588515792, 0.14769683964550495, 0.09656575189105102, 0.13343239149877004, 0.1451005203915494, 0.14282881229051522, 0.12297558332128183, 0.20972784608602524, 0.10075025020965508, 0.15617342479526997, 0.13088795303234033, 0.14673922317368643, 0.5844152633632932, 33.59345279421125, 81.4504177910941, 69.15675462995256, 63.822566986083984, 49.45340742383684, 43.49854414803641, 27.876047679356166, 38.15350341796875, 38.40789781297956, 50.997404847826274, 43.40827662604195, 2.46244700891631, 0.25104172634226934, 0.08746259393436567, 0.30017840968711035, 0.40008910851819174, 2.9763418563774655, 8.05922075680324, 14.50028075490679, 14.044842839241028, 17.933531590870448, 11.00964561530522, 28.66829170499529, 44.844504015786306, 49.33454459054129, 57.53310278483799, 54.44629955291748, 55.91749027797154, 58.31008856637137, 62.79916681562151, 59.06334972381592, 58.39011096954346, 58.767314774649485, 59.17746693747384, 57.37663977486746, 58.57182025909424, 56.1391030720302, 55.15276459285191, 50.43636907849993, 52.578943388802664, 51.6949588230678, 54.40661144256592, 51.48712430681501, 52.75721332005092, 50.92960432597569, 50.61615024294172, 52.94281012671334, 55.71589176995413, 53.86696570260184, 54.59229857581002, 53.88811949321202, 53.500802585056846, 52.39435059683663, 57.85469668252127, 56.947136878967285, 53.37455381665911, 48.66597155162266, 48.38662270137242, 44.44840805871146, 45.43606322152274, 45.62404326030186, 50.327702726636616, 52.33150066648211, 62.93264865875244, 40.78223276138306, 42.703913416181294, 60.03518731253487, 50.76406349454607, 50.310801233564106, 52.778075286320274, 58.94145747593471, 51.48163175582886, 54.927371978759766, 55.978756019047324, 49.70275395257132, 41.223947116306846, 44.27270548684256, 47.8032762663705, 55.48781367710659, 54.541830335344585, 55.91054555347988, 54.60081359318325, 56.71519211360386, 56.739677565438406, 43.94926684243338, 46.32076345171247, 58.50710473741804, 56.306585924965994, 52.68932594571795, 47.84455898829869, 54.44166510445731, 60.359049797058105, 58.29198156084333, 52.82600048610142, 51.84703057152884, 48.95636803763253, 48.12433515276228, 49.20999118259975, 51.574153968266074, 54.673248563494, 58.81209591456822, 57.832236630576, 60.047033991132466, 55.36434071404593, 45.395913055964876, 17.04997433934893, 9.37925602708544, 13.973624672208514, 16.773691381726945, 10.962120805467878, 8.504517776625496, 1.6355352721043994, 0.1772748732141086, 0.1846211954419102, 0.20826535884823116, 0.2521428258291313, 10.978617565972463, 48.97782754898071, 68.28442914145333, 85.0090002332415, 60.751261711120605, 34.8850291115897, 28.91941523551941, 45.50842523574829, 59.83243887765067, 59.5432687486921, 67.67931052616665, 29.249703066689626, 0.14686601422727108, 0.11928348429501057, 0.19143498981637613, 0.12777003033884934, 0.15985698785100663, 0.14307460481567041, 0.11215514822729997, 0.1592346355319023, 0.10779691101717097, 0.10740764904767275, 0.19517109862395696, 0.15679078309663705, 0.16730617598763534, 0.20883683461163724, 0.07083735282399825, 0.16667698403554304, 0.1499899351703269, 0.1231949401221105, 0.1445606779307127, 0.15665004136306898, 0.11840422504714557, 0.11749595164188317, 0.1294975940670286, 0.1344685958964484, 0.13751257184360707], [0.0630350618490151, 0.08258362859487534, 0.07643688842654228, 0.0667675608502967, 0.06801627563046557, 0.04172938796026366, 0.07424724913601365, 0.020139284066057632, 0.029199149792215655, 0.04447111726871558, 0.044544890988618135, 0.041969192413879294, 0.03254001873678394, 0.007176614682456213, 0.01197954423592559, 0.048917038166629415, 0.012454127743174987, 0.09003432986459561, 0.04982236672991088, 0.01826412370428443, 0.0897900979699833, 0.06851917185953685, 1.0559024321181434, 43.44833646501814, 57.032057762145996, 55.283411570957725, 45.667490346091135, 43.95192800249372, 19.73966544015067, 24.35430806023734, 43.78794009344918, 37.663460867745535, 47.5857629094805, 7.185433106763022, 0.21397251689008304, 0.033960962668061256, 0.06575358525982924, 0.03534003081066268, 0.8454773777297565, 2.3136815173285346, 4.14731981073107, 7.919967566217695, 3.6744067413466315, 3.9489300676754544, 18.533213240759714, 36.63362666538784, 50.08115979603359, 49.604065213884624, 41.87514965874808, 53.28725664956229, 57.983318260737825, 52.09627635138375, 53.775721958705354, 54.062467166355674, 51.64310441698347, 48.9937423978533, 48.3276811327253, 49.18503672736031, 53.174157346997944, 54.28181832177298, 53.38003594534737, 50.42408813749041, 51.21719721385411, 52.00716917855399, 53.26543583188738, 52.57192570822579, 52.642571517399375, 51.766917841775076, 50.1929806300572, 49.28517763955252, 49.67305040359497, 49.14156879697527, 49.244363921029226, 49.07182625361851, 50.45182187216622, 51.06849186761038, 53.70402002334595, 49.90922662190029, 45.94106524331229, 42.59026868002755, 44.14119693211147, 42.09254142216274, 46.09404025759016, 41.7331006867545, 46.90269592830113, 46.8433062008449, 58.12588487352644, 37.47047117778233, 41.67181062698364, 56.2122745513916, 46.825970445360454, 41.133710861206055, 45.98412670407976, 53.13577202388218, 47.46019853864397, 53.05638885498047, 51.23896939413888, 45.946842670440674, 39.263353075299946, 38.23610012871878, 39.81557852881295, 45.78432777949742, 49.788852555411204, 52.26577418191092, 48.06542485100882, 53.899987016405376, 47.84380510875157, 36.9662994657244, 43.20576095581055, 50.68481234141758, 51.6656756401062, 50.594739368983674, 45.380897998809814, 47.63428912843977, 51.98468828201294, 51.436430249895366, 48.79179647990635, 43.13467393602644, 43.555189337049214, 43.43354722431728, 48.50626720700945, 51.13094227654593, 53.727692535945344, 52.13065603801182, 55.206373419080464, 56.647245679582866, 59.8161175591605, 49.86345188958304, 31.48584529331752, 9.79969847202301, 4.966401253427778, 3.916968354157039, 4.653639384678431, 6.109255288328443, 2.123437885727201, 0.8453837941799844, 0.010985614266246557, 0.06122264053140368, 0.13867520088596003, 0.4426629740212645, 16.59590608733041, 35.44169793810163, 29.318577085222515, 22.1423716204507, 21.262439591544016, 30.325933865138463, 35.350544520786826, 38.252285957336426, 43.663605553763254, 48.20176935195923, 26.319215195519583, 0.5886806973389217, 0.13874981259661062, 0.021783018185357963, 0.016870986138071333, 0.04686003550887108, 0.039812713129712005, 0.015277845286098974, 0.04540181964901941, 0.06231304630637169, 0.11253305152058601, 0.07768835127353668, 0.02226444217376411, 0.007450758945196867, 0.019652864363576685, 0.007214086778861071, 0.09681432640978269, 0.04091896269736545, 0.01630239245215697, 0.007415511595484401, 0.04726294621026941, 0.04110854538157582, 0.02542569102453334, 0.020729368652350137, 0.035167509889496226, 0.00422531898532595, 0.07265195902436972, 0.04655624859567199, 0.03617115817697985, 0.007068682237461741, 0.023482616092743616, 0.036222275612609725, 0.05337403275604759, 0.010278849646316042, 0.016415614501706192, 0.02451765171385237, 0.014527804550847836, 0.00472880681211661, 0.06167545409074851, 0.005284864563561443, 0.03835049391325031, 0.02592964407189616, 0.027298754713098918, 0.04042764227571232, 0.04705906679321613, 0.02843169106303581, 0.047897101646023135, 0.11673922224768571, 2.0380675409521376, 51.67723396846226, 65.27490724836076, 62.63645390101841, 51.35336800983974, 50.38476480756487, 26.346228054591588, 25.0846905367715, 35.60777030672346, 32.285735811506, 47.40862553460257, 8.947577476501465, 0.16844914108514786, 0.05140231516478317, 0.08999665760036026, 0.1778821756264993, 2.345424145460129, 3.9268447841916765, 5.9120493446077615, 7.323225004332406, 5.11223612512861, 9.56035213811057, 20.18790762765067, 36.170341627938406, 50.27331222806658, 49.18399102347237, 48.462406703404014, 52.43738773890904, 58.71561322893415, 55.20713077272688, 55.258227825164795, 55.37505831037249, 52.014336245400564, 51.22932876859392, 49.83859123502459, 52.52590431485857, 55.274580410548616, 55.527095317840576, 54.65973431723458, 52.445951393672395, 51.414588587624685, 52.681992122105186, 54.92510339191982, 53.65123803274972, 54.17349590573992, 51.24404157911028, 50.62795523234776, 49.981741496494834, 50.05345385415213, 49.69174105780465, 50.756760937826975, 49.95805508749825, 51.888042313711985, 50.90430246080671, 55.73727485111782, 52.1189865384783, 48.36694540296282, 44.24602093015398, 46.888820375714985, 44.67204277856009, 47.78938681738717, 44.339734758649556, 48.56300272260393, 50.2822128704616, 59.14468533652169, 40.36503165108817, 44.99303218296596, 59.53692504337856, 48.45440237862723, 43.45625393731253, 48.00174808502197, 55.08300467899868, 49.21673093523298, 54.53296095984322, 52.03000790732247, 49.30074855259487, 41.49698352813721, 40.651578835078645, 41.52239656448364, 48.194734300885884, 52.97018950326102, 54.7390375818525, 50.12468678610665, 55.018018177577424, 50.28046192441668, 39.19176231111799, 45.799426215035574, 53.71480710165841, 52.625885418483186, 50.802396706172395, 46.47655248641968, 49.21718256814139, 54.43277835845947, 54.402963638305664, 50.81885004043579, 44.189813477652415, 45.91003458840506, 45.72665078299386, 50.62521069390433, 53.13367019380842, 54.89289501735142, 54.98543807438442, 58.38073090144566, 59.97457817622593, 60.390545981270925, 51.949474811553955, 30.93391513824463, 9.899030787604195, 3.6036280478749956, 6.357488368238721, 9.423398801258632, 7.219506204128265, 4.95340291091374, 2.1293410318238393, 0.1447936732854162, 0.07728547110621418, 0.1429449367736067, 0.6065287739038467, 19.869377885546, 41.55012682506016, 44.502260071890696, 31.257187025887625, 27.926050390516007, 32.06767007282802, 37.76320225851876, 43.7006116594587, 49.53827619552612, 55.28187949316842, 34.75052240916661, 1.0365850286824363, 0.10375354798244578, 0.038143316816006384, 0.009344151542921151, 0.0031526865870026605, 0.030762999983770505, 0.03572567618851151, 0.06705133098044566, 0.045602489595434496, 0.01948800410277077, 0.06893811973610095, 0.03588607508156981, 0.04537046115313258, 0.023059941362589598, 0.03368105340216841, 0.06790578977337905, 0.07599205443901674, 0.01768591008814318, 0.035021397551255565, 0.03911780845373869, 0.03852549148723483, 0.036123050044157674, 0.0347630860550063, 0.04815301112830639, 0.08948191414986338, 0.18864351032035692, 0.20086358673870564, 0.18428857757576875, 0.12759382836520672, 0.14225226108516964, 0.15673776237027987, 0.20760992116161756, 0.11051854211837053, 0.1219225919672421, 0.17762692432318414, 0.15421937964856625, 0.1673152819275856, 0.20316041420613015, 0.18317697436681815, 0.13738724642566272, 0.1511617244354316, 0.1125843623386962, 0.11919652324702058, 0.14432293283087866, 0.0822667188144156, 0.21371452430529253, 0.20442793119166577, 3.7143936242376054, 61.86369609832764, 72.24834169660295, 70.7144365310669, 60.321265493120464, 58.71741281236921, 30.191406318119594, 33.61745534624372, 59.4162973676409, 48.284379959106445, 60.77150181361607, 10.9862562417984, 0.36817595096571104, 0.12005831700350557, 0.2406406801726137, 0.16466899535485677, 1.793690059866224, 6.668824119227273, 13.405090928077698, 13.68945985180991, 10.508327875818525, 12.613006711006165, 22.678550209317887, 41.28982993534633, 51.00702115467617, 50.90558787754604, 48.60347597939627, 56.02037920270647, 61.02126176016671, 57.868214402879985, 56.40421853746687, 59.087348801749094, 55.77933924538748, 53.98477588381086, 52.16988556725638, 54.79117686407906, 56.97897699901036, 58.338555335998535, 56.249502999441965, 52.62565265383039, 52.49298027583531, 54.94934218270438, 57.09139537811279, 55.101695333208355, 55.55081646783011, 51.526923588344026, 50.19889007295881, 49.77013063430786, 49.107331548418315, 51.36528764452253, 50.88840845652989, 50.81182541166033, 52.009535040174214, 53.01629080091204, 56.91487986700875, 53.34054585865566, 51.23298004695347, 46.58339146205357, 48.320104122161865, 46.62644944872175, 51.352648871285574, 46.192110606602256, 50.24034302575247, 51.69455235345023, 61.678436279296875, 42.751532895224436, 47.30012246540615, 61.168897083827424, 50.69423757280622, 44.464562620435444, 50.10793467930385, 57.386999538966585, 50.03671564374651, 56.99850491115025, 56.19825308663504, 50.3514586176191, 44.010900838034495, 43.891704491206575, 43.597139086042134, 49.801689352308, 55.01254994528634, 57.02743026188442, 51.87412854603359, 57.637464727674214, 52.443568161555696, 40.061624663216726, 47.67112152917044, 55.258217402866904, 53.710294246673584, 51.00307805197579, 46.38201182229178, 51.62940604346139, 56.04883902413504, 56.24827664239066, 53.193039076668875, 46.344964027404785, 48.043305260794504, 48.21809414454869, 52.73343311037336, 56.29472882407052, 58.83967331477574, 57.159828186035156, 60.41897106170654, 61.57682582310268, 64.15622643062046, 54.961998326437815, 36.29853589194161, 15.232059819357735, 13.686182039124624, 10.98010448047093, 11.37262385232108, 17.158376659665787, 6.642426609992981, 2.6579601977552687, 0.16528342238494328, 0.21108270409916127, 0.30369438816394123, 0.9557452350854874, 25.287987879344396, 48.18140070778983, 38.44189534868513, 31.096096515655518, 32.10842820576259, 41.54206691469465, 47.59002215521676, 50.73113250732422, 57.7162503514971, 62.40819862910679, 41.64145047324044, 1.6580661088228226, 0.20443335947181496, 0.11534998965050493, 0.08722759011600699, 0.1207523090498788, 0.2051601383302893, 0.1880016161927155, 0.15245540573128633, 0.1329170712935073, 0.13759524455027922, 0.16610626823135785, 0.11010449326464108, 0.10051113446908337, 0.06968604853110653, 0.15280706329005106, 0.19842115922697953, 0.20445351196186884, 0.1674829207892929, 0.09724501294216939, 0.10377085741077151, 0.113078763309334, 0.16080137288996152, 0.0655606777540275, 0.10505246756864445, 0.2284723488347871], [0.023159099077539783, 0.09877380662198577, 0.08898831385054759, 0.030706837640276978, 0.09072921079184328, 0.02785284471298967, 0.01939754859943475, 0.005439294044793184, 0.0086980640688645, 0.057964288230453215, 0.03570201906508633, 0.030048081917422156, 0.03315911748047386, 0.05099553681377854, 0.03719863322164331, 0.03559318544077022, 0.055112843202160935, 0.04458830026643617, 0.027363381780950085, 0.0635863444102662, 0.05006123480520078, 0.1454805407140936, 5.297344386577606, 47.433427129473, 58.3657158442906, 59.67660467965262, 39.80463859013149, 26.627772535596574, 24.981902360916138, 44.65209450040545, 50.77405153002058, 47.558036123003276, 24.207600321088517, 0.8532156082136291, 0.06339941479797874, 0.05051238934642502, 0.06809244118630886, 0.42225312920553343, 1.428116562111037, 4.928575260298593, 6.646269832338605, 8.004494139126368, 6.414347214358194, 17.613070249557495, 44.62687601361956, 53.53326109477452, 53.61237675803048, 44.6509758404323, 51.20779282706124, 52.858323505946565, 56.0100611277989, 52.89222029277256, 52.308123452322825, 47.400166102818076, 48.97149426596505, 46.41433136803763, 46.18270969390869, 44.826143401009695, 48.11253363745553, 49.951951095036094, 54.189424651009695, 51.29633372170584, 51.44567482812064, 53.17652668271746, 50.98018373761858, 48.23115675789969, 54.411325795309885, 53.27491317476545, 51.90520783833095, 48.438379832676475, 50.81911407198225, 48.44124596459525, 50.69714886801583, 48.6720164843968, 51.6193276814052, 50.574888365609304, 53.94392395019531, 49.836027349744526, 46.82357679094587, 41.72244215011597, 41.97173656736101, 43.0004277910505, 43.424125467027935, 41.92034421648298, 47.59061622619629, 47.35401269367763, 58.11372552599226, 37.96732643672398, 39.89861297607422, 55.13361188343593, 45.14497191565377, 42.817492144448416, 42.692893573216026, 53.3266772542681, 47.92659984316145, 52.67013154711042, 50.238852637154714, 48.36129651750837, 41.35555294581822, 39.07465042386736, 37.123516355242046, 43.97325897216797, 45.826972348349436, 50.67045736312866, 51.51015758514404, 52.99012735911778, 42.10121624810355, 37.419471400124685, 42.14699445452009, 49.845654078892295, 51.92825501305716, 48.123490946633474, 47.7274158341544, 52.84650114604405, 53.30948741095406, 53.09038291658674, 47.31693710599627, 41.854214736393516, 42.07010916301182, 46.884797368730815, 50.42569317136492, 54.29612813677107, 53.97314459936959, 57.67562770843506, 57.95534133911133, 55.32721996307373, 54.45770502090454, 55.25727244785854, 46.895911012377056, 29.1641811643328, 7.096162217003958, 3.073375838143485, 4.7386288813182285, 5.223688270364489, 6.180005320480891, 1.4892398651157106, 0.2043285258114338, 0.057646224940461774, 0.07441505763147559, 0.07969975298536675, 4.762848998819079, 33.92663976124355, 26.016595091138566, 25.902778387069702, 20.627146686826432, 35.92103678839547, 41.020159925733296, 45.59570850644793, 47.28113651275635, 44.96939788545881, 40.32862656457083, 4.96930820601327, 0.10274867833192859, 0.037588739967239757, 0.031050926140908684, 0.038600998864110024, 0.028787292606596435, 0.017397268076560328, 0.027176316461658905, 0.0311604111588427, 0.025657600723206997, 0.024080751497032385, 0.02034976053982973, 0.04500168076317225, 0.009936753494132842, 0.00882967611375664, 0.036829557668949874, 0.02185418293811381, 0.027360647284824933, 0.0170705093603049, 0.013938612238104855, 0.033490442737404785, 0.025719194739524807, 0.035521342152995725, 0.009938773832150867, 0.026960644105981504, 0.017265019905088202, 0.021916653960943222, 0.08923935145139694, 0.02296071918681264, 0.05733297246375254, 0.02744525551263775, 0.042876733001321554, 0.03709172663678016, 0.026081004878506064, 0.07493326839591775, 0.023538432383377637, 0.022643863689154387, 0.05323670066094824, 0.008118952241992312, 0.04165393825886505, 0.06919446348079614, 0.035890088616205115, 0.049667721813810725, 0.019840292699102844, 0.05756098737141915, 0.029805400475327457, 0.027165989158675075, 7.177822657993861, 58.280937399183, 64.59974384307861, 65.94019726344517, 47.01917552947998, 33.93861150741577, 27.592985016959055, 39.66562250682286, 52.10952309199742, 47.25490706307547, 27.016970668520244, 1.126803913286754, 0.08910601253488235, 0.055568391257630925, 0.1766123923340014, 1.428778595158032, 4.124412468501499, 7.477844136101859, 5.46266200712749, 4.412393586976187, 6.2209406324795316, 21.47943009649004, 42.819712093898225, 52.81203808103289, 53.832252502441406, 47.84136976514544, 52.81770086288452, 54.33671603884016, 57.25353159223284, 55.51081568854195, 54.82299266542707, 50.82230676923479, 51.15719951902117, 48.092880657741, 48.50665283203125, 48.32628801890782, 51.559055532727925, 51.337644236428396, 54.34020403453282, 52.67204577582223, 52.18172877175467, 55.233460971287315, 52.30711596352713, 50.55208785193307, 55.498802253178184, 54.5878586769104, 52.623964241572786, 48.929457664489746, 50.9776337487357, 49.750015599387034, 50.9893171446664, 50.28984546661377, 52.62096609388079, 50.360373156411306, 54.665091378348215, 51.771187509809224, 48.0097211429051, 43.62612697056362, 44.414004053388325, 43.94073792866298, 47.683121068137034, 45.04326071058001, 50.05460378101894, 49.37639706475394, 59.34489073072161, 39.33216803414481, 43.314972741263254, 57.73115423747471, 47.465576444353374, 45.05926936013358, 44.738161836351665, 56.4533040864127, 47.65422003609793, 52.96262986319405, 54.28144659314837, 50.07088688441685, 43.597267627716064, 40.4905960219247, 39.549521582467214, 45.311652251652305, 48.993342876434326, 53.22942679268973, 54.29507201058524, 54.21133232116699, 43.15019621167864, 38.924527645111084, 44.02112511226109, 50.76382378169468, 53.734366280691965, 49.44434697287423, 47.93817554201399, 52.69551331656319, 55.10469348090035, 55.17762177331107, 49.86158977236067, 42.44894926888602, 43.798338072640554, 47.67413704735892, 53.24733577455793, 56.65027162006923, 57.893269606998985, 58.99514620644705, 58.98441123962402, 55.809647287641255, 55.59644528797695, 55.79398604801723, 49.820477281297954, 28.891215971538, 6.485639640263148, 3.0761151654379706, 5.338337455477033, 7.260787189006805, 8.250527245657784, 6.744308914457049, 1.9468374763216292, 0.1527724037212985, 0.11114738801760332, 0.047038127202540636, 5.019516323293958, 38.03384154183524, 21.384783472333634, 25.908357790538243, 22.041919776371547, 37.88315595899309, 46.020257336752756, 48.488469396318706, 52.38987248284476, 50.427412850516184, 49.80080345698765, 7.319909845079694, 0.22173060130860123, 0.04880736994424036, 0.04248586629650422, 0.026507550650941472, 0.03492315925125565, 0.01892328994082553, 0.035502539947628975, 0.026670412626117468, 0.050256537539618354, 0.04239852187622871, 0.0635212321898767, 0.03248271984713418, 0.07138349208980799, 0.030742474299456393, 0.08541106366153274, 0.022583163642723645, 0.03225512902385422, 0.020669196166896393, 0.009406232408114841, 0.036926038563251495, 0.037004290614277124, 0.03204417587923152, 0.024726638803258538, 0.023182377917692065, 0.13416254946163722, 0.28353798974837574, 0.18381509583975586, 0.13039222891841615, 0.20052012588296617, 0.08978225410516773, 0.094524806764509, 0.15106567101819174, 0.13801357495997632, 0.15543843566307, 0.09224858640560082, 0.077855264102774, 0.16576663431312355, 0.08380119183233806, 0.15580101763563498, 0.12437989296657698, 0.1608541900558131, 0.14604755171707698, 0.13972158330891812, 0.15995255272303308, 0.13875582441687584, 0.16982454513864859, 10.524821162223816, 68.57477351597377, 73.26550238473075, 74.50861849103654, 53.66017689023699, 37.927568844386506, 36.26567438670567, 54.45376539230347, 59.71915544782366, 64.11891460418701, 30.98091275351388, 1.5882224908896854, 0.22845440836889402, 0.1738473485623087, 0.23284846544265747, 2.0025047063827515, 4.067207080977304, 12.13591386590685, 14.388369594301496, 19.797437974384852, 16.869550466537476, 24.650247471673147, 47.6244226864406, 56.01381662913731, 56.23594011579241, 49.131976808820454, 54.2137885093689, 54.43860442297799, 60.19930376325335, 57.41402803148542, 58.00069570541382, 52.17151491982596, 54.36862564086914, 51.08935383387974, 50.17011758259365, 49.37576477868216, 52.972537994384766, 54.182323592049734, 56.26994112559727, 55.02342735018049, 53.76309013366699, 57.98455156598772, 54.2598237991333, 53.52404430934361, 59.75221497671944, 56.387810366494314, 54.29842104230608, 48.90371806280953, 50.80149344035557, 49.869166782924104, 52.032207012176514, 50.367293562207905, 54.54810108457293, 52.4934458051409, 58.359691756112234, 53.73478317260742, 50.05725451878139, 45.75522872379848, 46.01842648642403, 45.802316665649414, 49.69002832685198, 48.027133328574045, 51.65378379821777, 51.601630619594026, 61.49931866782052, 43.34390851429531, 45.180272238595144, 59.285872731889995, 49.96667432785034, 47.40866722379412, 46.89685596738543, 59.82319777352469, 51.67920725686209, 54.17794622693743, 56.47823422295706, 52.548520701272146, 45.47822141647339, 42.7209677696228, 40.00921440124512, 48.32687166758946, 51.807471002851216, 55.0952821459089, 57.087073598589214, 56.99915109361921, 45.81196076529366, 42.0861108643668, 46.178648471832275, 53.36523280824934, 56.512099742889404, 51.4767610686166, 48.83205434254238, 54.801102365766255, 58.14914049421038, 59.09593677520752, 52.66841186795916, 44.30218321936471, 45.66668782915388, 51.373382295881, 54.40518706185477, 59.465164048331125, 58.96255915505545, 61.055738721575054, 61.63501698630196, 59.20815018245152, 56.57707929611206, 58.38075174604143, 50.30010100773403, 34.47035714558193, 10.450523206165858, 8.417338728904724, 12.22901017325265, 13.420252765927996, 18.037179606301443, 4.8063729490552625, 1.363657146692276, 0.17707925156823226, 0.30108582813824925, 0.15630526414939336, 7.037664898804255, 48.424917697906494, 39.227788720812114, 36.90748643875122, 29.618509973798478, 46.99751452037266, 53.76330900192261, 56.37369510105678, 59.557088715689524, 56.429475239345, 58.020543234688894, 9.478755967957632, 0.4128112329968384, 0.18490930141082831, 0.17610297538340092, 0.1306547134050301, 0.17949939598994596, 0.1498249833072935, 0.11530044302344322, 0.15728923492133617, 0.16047552680330618, 0.14754309718097958, 0.15119037218391895, 0.11046975545052971, 0.16950004255133017, 0.09200269210019282, 0.2161893993616104, 0.18160878494381905, 0.1761559418269566, 0.10355435724237136, 0.10160477685609035, 0.08221612045807497, 0.10735493366207395, 0.1032309267403824, 0.11181191128811666, 0.12380248680710793], [0.012478236940556338, 0.051518670349781, 0.04998899457444038, 0.06604726878660065, 0.042278075125068426, 0.10781296515571219, 0.0385017122275063, 0.006507800102034318, 0.021712394564279487, 0.03335033543407917, 0.03608273149334958, 0.03502238821238279, 0.03101882464917643, 0.052576506443853886, 0.04811996647289821, 0.04431193634601576, 0.07217068092099257, 0.024723561646948968, 0.04347910246412669, 0.004696183272504381, 0.10112449619919062, 0.23135910821812494, 30.234175954546245, 63.974100249154226, 57.75374630519322, 56.5745883669172, 50.238887378147666, 30.47175223486764, 23.16890021732875, 35.93232413700649, 49.104295185634065, 34.98692096982683, 7.431249516350882, 0.014429752847978046, 0.04361175945294755, 0.036783468177808185, 0.11399450738515172, 0.2222037844892059, 5.862405334200178, 3.396111628838948, 2.3516977173941473, 7.51397042615073, 18.541340896061488, 44.198387554713655, 57.231662137167795, 55.47547367640904, 51.56328698566982, 53.76083891732352, 51.57097169331142, 52.9811954498291, 54.11342872892107, 50.47180836541312, 48.428159032549175, 48.679840156010215, 48.156307288578574, 43.18226909637451, 43.77426603862217, 42.87898370197841, 46.55583838054112, 49.31047603062221, 51.32123606545584, 52.11140605381557, 51.455989428928916, 46.66430670874459, 48.46446337018694, 48.74443061011178, 48.028540338788716, 47.67956359045846, 52.48518092291695, 49.80744246074131, 49.37907559531075, 47.89836931228638, 49.368754046303884, 49.17041424342564, 49.61832639149257, 48.836921555655344, 51.239226477486746, 49.06456538609096, 45.99123471123831, 40.20315252031599, 41.8027320589338, 43.95676742281233, 46.14234413419451, 42.499865668160574, 45.27286045891898, 47.26809821810041, 56.63012531825474, 36.08694240025112, 39.62108107975551, 56.42430230549404, 46.25437341417585, 42.67550918034145, 40.356523581913535, 53.16320698601859, 48.69359064102173, 50.5525290625436, 49.92234134674072, 48.305054324013845, 44.66582761492048, 40.257438795907156, 39.01540660858154, 39.250026430402485, 41.38241120747158, 46.095495905194966, 46.53604991095406, 44.727478981018066, 37.52684538705008, 36.6613986151559, 41.249089172908235, 50.61189794540405, 51.44656419754028, 48.872312205178396, 47.31789595740182, 50.19775056838989, 51.73451491764614, 51.2583965573992, 45.93295669555664, 41.43332065854754, 43.42340980257307, 45.98947334289551, 53.20860651561192, 56.00787591934204, 54.503080231802805, 53.801148891448975, 55.26922682353428, 54.45145164217268, 54.81047895976475, 57.178890568869456, 55.16496215547834, 49.11450556346348, 29.033237150737218, 13.566122378621783, 8.616330793925695, 4.319157012871333, 4.212382308074406, 2.9426463501793996, 1.000388496688434, 0.11911625255431448, 0.11775973891573292, 0.017923578852787614, 0.13578897075993673, 15.630775247301374, 50.9784049987793, 41.38349165235247, 34.97678354808262, 37.45600502831595, 35.79930782318115, 23.16545738492693, 40.44334132330758, 49.744561263493125, 51.44853401184082, 13.25909537928445, 0.09437835176608392, 0.05150033633357712, 0.04809337807819247, 0.044494621721761565, 0.03901166522077151, 0.03964618028008512, 0.017800358589738607, 0.019399765712608184, 0.02488543974634792, 0.0382007955174361, 0.08184122307492153, 0.022322445043495724, 0.039420133123972585, 0.027002463915518353, 0.05065672053024173, 0.0182230214455298, 0.021332236838393977, 0.08115690693791423, 0.061543166903512816, 0.024078464834019542, 0.04688799115163939, 0.014895573923630374, 0.03187699502866183, 0.024417991882988384, 0.011012136503787977, 0.01797354108254824, 0.035828742265169106, 0.027541829705504433, 0.027549375014911805, 0.09260052216372319, 0.053815514780581, 0.02194920158945024, 0.01211464055813849, 0.04091753777382629, 0.047940056305378675, 0.028975446974592547, 0.03278654747243438, 0.07270989234426192, 0.010358348505438437, 0.05267531132059438, 0.02319421835376748, 0.07189700060657092, 0.027665470660265003, 0.02263288159987756, 0.10543495775865656, 0.3435032234660217, 36.37744658333914, 71.09526034763881, 65.45606763022286, 63.64102445329939, 53.3843994140625, 34.28835950578962, 28.997957672391617, 38.05456107003348, 51.45502710342407, 38.32506833757673, 7.487866912569318, 0.014031646174511738, 0.07373507054788725, 0.09500943683087826, 0.49598988252026693, 1.8391799160412379, 4.180738040379115, 5.215681340013232, 5.240704842976161, 8.050013525145394, 20.185091870171682, 43.490626675742014, 56.53180830819266, 59.17812006814139, 54.05655424935477, 55.34777273450579, 53.59878608158657, 54.197151047842844, 57.527815205710276, 52.588333879198345, 50.025028773716514, 49.853244985852925, 49.74069111687796, 46.60501078196934, 45.57080616269793, 45.04585933685303, 48.823629651750835, 51.71721042905535, 54.13885566166469, 53.69508463995797, 53.31517103740147, 49.375761304582866, 49.643906184605186, 51.39473411015102, 49.82629292351859, 50.29219743183681, 54.29838282721383, 50.32209553037371, 49.011168479919434, 47.2201486996242, 48.90997838973999, 48.10003382819039, 50.48954711641584, 51.38379417146955, 54.33992610658918, 51.27624995367867, 48.778421197618755, 41.802937030792236, 44.73404155458723, 46.589415550231934, 47.74526228223528, 44.59467111315046, 48.586456366947715, 49.738505908421104, 58.147191524505615, 37.98179258619036, 42.116144452776226, 58.65226650238037, 48.19715574809483, 43.71517160960606, 42.80842474528721, 54.98478146961757, 49.96172373635428, 51.1503346988133, 51.84886142185756, 49.6846330506461, 46.949360030038015, 42.155057838984895, 41.11542667661394, 41.302076135362896, 43.88795593806675, 47.12666763578142, 48.576311997004915, 45.00131443568638, 39.04538113730294, 38.93978936331612, 42.957369804382324, 51.53773151125227, 53.264094829559326, 50.696520056043354, 47.035625389644075, 50.7474399294172, 53.496842111860005, 53.90397528239659, 47.975028787340435, 43.52945668356759, 44.44156755719866, 49.56863634926932, 55.87889303479876, 56.85603209904262, 54.96610818590437, 55.6828669820513, 56.7236967086792, 57.088223525456016, 57.90523787907192, 59.04347092764718, 58.244640009743826, 51.476319858006065, 30.567182268415177, 9.965934991836548, 0.4698529307331358, 3.2460939415863583, 7.0224557263510565, 10.818799444607325, 5.218918766294207, 1.4065736723797662, 0.21476100172315324, 0.013692585618368216, 0.34707020063485416, 18.169730390821183, 46.28412907464163, 37.54552214486258, 29.45419897351946, 39.94381448200771, 43.63737262998308, 28.03771836417062, 46.463343960898264, 55.85177074159895, 59.25657217843192, 19.57438690321786, 0.06466205311673028, 0.057481992324548106, 0.05302084170814071, 0.030662383418530226, 0.030773317108729055, 0.04665166758266943, 0.06577828393450805, 0.029148809279182127, 0.0036727378776829156, 0.0369782450475863, 0.07321699549044881, 0.029148147707538943, 0.028064552727820616, 0.0037094338996601956, 0.03922602800386293, 0.015783825456830006, 0.013698750109012638, 0.03123163358707513, 0.05303773044475487, 0.001958565038096692, 0.009198642252678317, 0.09853811069790806, 0.03869439920942698, 0.056576952138649564, 0.07027203137321131, 0.073500046373478, 0.10262019094079733, 0.09828965831547976, 0.10694350395351648, 0.1527069250919989, 0.1592367525611605, 0.09450328363371746, 0.07017167604395322, 0.11487395662282195, 0.12262286724788801, 0.13157376194638865, 0.14516849602971757, 0.16586450620421342, 0.12537404176379952, 0.11917562436844621, 0.27030555265290396, 0.14299503979938372, 0.16654749241258415, 0.14115055091679096, 0.18669285784874642, 0.5807517713734082, 43.98637022290911, 79.56949179513114, 71.7090711593628, 73.081924029759, 63.53666945866176, 42.03671612058367, 33.09811919076102, 46.10837091718401, 56.3093478339059, 46.36910901750837, 10.802468572344099, 0.1855923826141017, 0.23516036995819636, 0.16992435763989175, 0.5831835865974426, 2.5305758331503188, 12.404816099575587, 11.128358193806239, 10.664427842412676, 16.26888738359724, 25.224126986094884, 49.86242355619158, 58.89320918491909, 60.53156661987305, 58.25025762830462, 54.37043217250279, 55.08254262379238, 56.268676553453716, 60.40437289646694, 55.99809285572597, 52.80338757378714, 53.91382435389927, 53.670463698250906, 48.50616645812988, 47.52946860449654, 46.42347519738333, 51.68633958271572, 53.91602693285261, 55.48683745520455, 55.039637497493196, 55.62138932091849, 51.696591649736675, 51.90459639685494, 54.14160714830671, 52.416411127362935, 52.74317795889718, 56.550544125693186, 50.367446422576904, 48.9713066646031, 49.22720881870815, 50.02313191550118, 49.957440171922954, 51.59448092324393, 53.496772629874094, 56.73278495243618, 54.26545531409127, 50.97919709341866, 44.03820031029837, 45.88328054973057, 47.94225066048758, 50.02044643674578, 46.76699760981968, 49.77099915913173, 52.167231355394634, 60.03551387786865, 40.879997389657156, 44.68858643940517, 61.24622358594622, 50.48049013955252, 46.831449099949424, 44.16004044669015, 57.85966811861311, 53.909617219652446, 52.97763449805123, 54.178078242710654, 51.237982749938965, 49.1971926007952, 43.93666281018938, 43.813224588121685, 43.39331020627703, 45.323029926845, 51.40360695975167, 51.632741178785054, 48.6909989629473, 40.822278703962056, 41.61936214991978, 45.5387784412929, 54.84361144474575, 55.06733996527535, 50.78155211039952, 46.18870946339199, 52.046509878976, 56.66741630009243, 55.737382548195974, 49.587782110486714, 46.1061509677342, 47.09914582116263, 50.41320031029837, 58.21874407359532, 59.87771333966936, 56.80821112224034, 56.500378131866455, 57.4814498765128, 59.43755190713065, 59.31844588688442, 62.578832490103586, 59.08018520900181, 52.20022487640381, 34.61466775621687, 18.278798001153127, 14.942057643617902, 10.804222123963491, 13.639173133032662, 10.539306419236318, 3.444513648748398, 0.6810312675578254, 0.3077032816197191, 0.09453298311148371, 0.4321325176528522, 22.50777564729963, 67.908385685512, 53.092991965157644, 44.81520346232823, 45.204403332301546, 45.981830324445454, 33.24781118120466, 56.426324231284006, 61.66346985953194, 67.65841034480503, 25.362717492239817, 0.18581077589520387, 0.22422082482704095, 0.08723334409296513, 0.10439344043178217, 0.10689382161945105, 0.1869914268276521, 0.14593449421226978, 0.0978662253224424, 0.10778262785502843, 0.12093202583491802, 0.2114007334624018, 0.11482940401349749, 0.10408472056899752, 0.08496187347918749, 0.145605649000832, 0.11137161669986588, 0.16491423148129666, 0.12152932664113385, 0.08078691536294562, 0.150810107588768, 0.12164797527449471, 0.17368372662791184, 0.07400119876755135, 0.14869503251143865], [0.04043862097231405, 0.047035151826483865, 0.01696007269700723, 0.025717949627765586, 0.02004473190754652, 0.032063951782350025, 0.02331307394030903, 0.029167482562895333, 0.045037161359297376, 0.027179025512720858, 0.014063585666008294, 0.028066456018547927, 0.030453839073223726, 0.04593718717140811, 0.018328615065131868, 0.05701872932591608, 0.04400205279567412, 0.03945686900988221, 0.04886459080236299, 0.02907764113375119, 0.11711293219455651, 1.2635751856224877, 41.82789496013096, 53.28132288796561, 56.15818282536098, 44.10053954805647, 31.45003080368042, 25.20183195386614, 25.05617686680385, 35.520205633980886, 41.03420223508562, 24.613606146403722, 1.167358160018921, 0.06260505385164704, 0.05866344392831836, 0.045608267321118286, 0.8015704080462456, 1.2482004506247384, 3.2832060073103224, 6.702175038201468, 3.79763434614454, 15.661024229867117, 41.56315817151751, 56.90751130240304, 56.883550439562114, 54.95002310616629, 58.86131000518799, 56.77652733666556, 51.335660525730674, 52.43782547542027, 53.69566134044102, 51.50618668964931, 43.845089026859824, 43.071264675685335, 43.9950624193464, 44.77941329138619, 44.88595002038138, 41.788793972560335, 41.832581520080566, 46.253414562770296, 51.14731223242623, 52.07049853461129, 50.77991928373064, 45.12926551273891, 42.346723897116526, 42.31539446966988, 50.83739825657436, 49.0749112537929, 50.26441853387015, 52.652229513440815, 49.187690939222065, 50.18981919969831, 51.14022159576416, 48.729808126177105, 50.899956362588064, 51.06311396190098, 51.081443309783936, 48.1522981779916, 44.295999322618755, 37.67979260853359, 42.98312677655901, 42.55253301348005, 46.28045347758702, 42.76877137592861, 49.75084590911865, 47.07529265539986, 58.77007320949009, 34.982592242104666, 37.526352064950125, 56.225611618586946, 44.61343819754464, 43.90547929491316, 37.8491028376988, 51.060320786067415, 50.37537431716919, 49.38530812944685, 50.04151337487357, 52.045370374407085, 45.379904406411306, 44.9246688570295, 38.99287360055106, 39.72549860818045, 38.24255153111049, 39.20162875311715, 39.384665148598806, 38.62795421055385, 37.4226085117885, 37.53386306762695, 39.41804429462978, 46.81729909351894, 51.07407127107893, 51.852300780160085, 46.53413915634155, 49.93600845336914, 52.33409929275513, 52.41975668498448, 46.954032693590435, 42.113511085510254, 40.202009541647776, 48.43158796855381, 52.418005738939556, 52.39546230861119, 53.3015456199646, 52.96784448623657, 53.45729643957955, 53.70700427464077, 53.78713437489101, 53.14454412460327, 54.82764448438372, 56.17969792229788, 49.06119203567505, 32.18617854799543, 7.344960706574576, 3.816756222929273, 6.085858532360621, 15.358001129967825, 6.236721728529249, 0.8942296845572335, 0.05318751026477132, 0.21064928307064942, 0.03812925757041999, 2.1121722502367835, 19.490447453090123, 36.634300640651155, 35.95576041085379, 43.41970293862479, 37.068754128047395, 39.504243646349224, 39.307581833430696, 40.3868350982666, 51.76488201958792, 36.06129312515259, 1.373670912214688, 0.04039598522441728, 0.05678617501897471, 0.04437570845974343, 0.016528763608740907, 0.004245122029845203, 0.06743482540228538, 0.037304097919591835, 0.0015407691867689469, 0.06198095091219459, 0.05310701226283397, 0.01968760196385639, 0.0719323522810425, 0.030613691745592014, 0.009740589020241584, 0.04333498501884086, 0.09210552408226899, 0.01323810710372137, 0.042928556113370826, 0.03084196788924081, 0.007265699545054564, 0.011706358403898776, 0.005809743630899382, 0.04710275087771671, 0.04618684395349451, 0.0375559836892145, 0.03679475900051849, 0.03820014751649328, 0.0192181473331792, 0.025833994382992387, 0.05516541948808091, 0.015893095039895604, 0.010213322671396392, 0.02350034112376826, 0.04199938043685896, 0.00524756803809266, 0.0312369193748704, 0.09016072736786944, 0.058835038649184365, 0.058195390472454686, 0.034324538694428544, 0.05165695917925664, 0.04375142231583595, 0.06205544048654182, 0.08176092524081469, 2.0228653166975294, 51.03545665740967, 60.42810099465506, 63.76270130702427, 52.170629024505615, 40.68593767711094, 33.7637357711792, 23.48967249052865, 31.082408564431326, 43.21990748814174, 26.170374359403336, 1.6333633086511066, 0.060353138617106845, 0.012016114728924419, 0.2683486576591219, 1.161687235747065, 4.702903415475573, 8.24228320802961, 5.350309201649257, 5.776944228581019, 16.630442108426774, 41.23276785441807, 56.6953376361302, 59.563210078648154, 57.361009802137104, 59.253424644470215, 57.10688986097063, 52.26221323013306, 54.75347246442522, 56.37026963915144, 53.46439402444022, 46.84222575596401, 45.56686653409685, 46.82669653211321, 46.84125995635986, 46.39419548852103, 43.4667318207877, 44.30762365886143, 48.80417469569615, 52.42740317753383, 54.115506240299766, 52.2272881099156, 47.52386835643223, 45.16703939437866, 44.28152622495379, 51.34776776177542, 50.48520449229649, 52.22873680932181, 52.48761626652309, 48.50616298403059, 49.7455027444022, 50.59245341164725, 49.72912584032331, 52.342148780822754, 51.80397258486067, 52.6025116784232, 49.71940878459385, 47.19315494809832, 40.03949812480381, 43.561328070504324, 44.75244733265468, 47.86111307144165, 45.005417346954346, 50.915940693446565, 49.96013607297625, 60.75336006709507, 36.932836941310335, 39.50936099461147, 57.775653975350515, 46.82523046221052, 46.40898125512259, 39.55086605889456, 53.28022507258824, 52.32186351503645, 50.014328547886436, 50.54726580211094, 54.1810416494097, 48.391132082257954, 45.74026230403355, 41.483021123068674, 41.332339014325825, 40.535745416368755, 41.76354421888079, 40.34286689758301, 40.741651807512554, 39.276763098580496, 40.26495327268328, 41.61193452562605, 49.461529867989675, 53.889182567596436, 52.59951005663191, 46.535966532570974, 51.32667997905186, 53.636042322431294, 55.26754535947527, 49.521916661943706, 43.78874955858503, 43.32236215046474, 50.305927072252544, 55.80486345291138, 55.77690042768206, 55.80126428604126, 54.255290099552695, 54.468325342450825, 56.83449615750994, 55.354578495025635, 56.06256519045149, 56.55600193568638, 58.41839708600725, 51.71205139160156, 34.20368875776018, 7.850038290023804, 3.30200349007334, 4.519311164106641, 12.818551795823232, 8.828553097588674, 6.289294404642923, 0.25301471618669374, 0.16225877111511572, 0.08873144763388804, 2.3465873173304965, 22.459193842751638, 39.1111284664699, 32.017962660108296, 43.9882983480181, 37.3510559626988, 41.15134538922991, 46.05630806514195, 46.00756992612566, 57.7729754447937, 44.991920471191406, 2.980271496943065, 0.052396609847034724, 0.01864857316416289, 0.06737101596913167, 0.032252642193010876, 0.03260998926790697, 0.013978219175312136, 0.013540358831440764, 0.06394876353442669, 0.02498340493600283, 0.06334476558757679, 0.005258225702813694, 0.050258020138634105, 0.03538097022101283, 0.05126131219523294, 0.07853264561189072, 0.01680442863809211, 0.013651588532541479, 0.014555578685498663, 0.024806161411106586, 0.011243700149602123, 0.020321457147864357, 0.02449206415829914, 0.02631572031948183, 0.09507384337484837, 0.11340920986341578, 0.1307902575603553, 0.14256773915674004, 0.0912558761026178, 0.11202818075461046, 0.10844162106513977, 0.0867691243599568, 0.1187536705817495, 0.13913589902222157, 0.15406525720443043, 0.1107288608327508, 0.09714255415435348, 0.17822959912674768, 0.11051105787711483, 0.11071908992848226, 0.13110397144087724, 0.16917758913976805, 0.16551217011043004, 0.14812897145748138, 0.2641434504517487, 3.6129455821854726, 61.00587150028774, 68.28280326298305, 70.96846961975098, 58.55418573107038, 46.99489852360317, 35.76334047317505, 35.67594950539725, 46.26851299830845, 52.40672186442784, 34.78314420155117, 2.063334013734545, 0.1585622751819236, 0.18579291685351304, 0.2621634581259319, 1.7207007535866328, 6.584808238915034, 10.861637694495064, 12.110407028879438, 10.4561026096344, 20.20374083518982, 45.10865715571812, 60.000752040318076, 61.56705665588379, 60.9655441556658, 62.46544483729771, 59.53004632677351, 53.057576996939524, 55.951404435294016, 58.692975997924805, 56.05267442975725, 48.74520533425467, 49.01384353637695, 50.89619738715035, 50.50918272563389, 48.870328494480674, 46.500072138650076, 45.88244676589966, 52.322864055633545, 55.3362317766462, 55.210368633270264, 55.38561609813145, 50.18172107424055, 47.461633341653005, 47.00140898568289, 54.00081580025809, 53.71067639759609, 55.107149669102256, 53.88491637366158, 49.63962262017386, 51.42168269838606, 52.43362181527274, 51.342257840292795, 54.13820947919573, 53.89869812556675, 56.1683132989066, 51.58444077627999, 48.88992936270577, 41.6394876071385, 47.052613735198975, 46.99489157540457, 50.085974897657124, 45.798887729644775, 54.67126137869698, 51.0150602204459, 62.77236066545759, 39.67985936573574, 42.63112408774239, 59.64690113067627, 48.94912106650216, 48.643817220415386, 42.90427514484951, 55.383708817618235, 54.570522921425955, 50.824839387621196, 52.8622144971575, 57.03568124771118, 51.48705135072981, 49.149128437042236, 43.88771969931466, 43.717544419424875, 42.93099444253104, 42.96237250736782, 42.091686793736045, 42.67593649455479, 41.77465786252703, 42.527477809361045, 43.675730160304475, 51.420591831207275, 57.583619662693565, 54.67396770204817, 47.32991286686489, 51.954783235277446, 55.70182861600603, 57.4827561378479, 52.297249521527974, 45.711590562547954, 43.67265558242798, 51.60619558606829, 57.23498337609427, 56.57541867664882, 57.48399986539568, 56.65945019040789, 56.10973651068551, 58.77689634050642, 57.60213313783918, 58.01503678730556, 60.87378624507359, 60.69266060420445, 53.396649088178364, 37.12828629357474, 11.201417633465358, 8.51132787976946, 16.39854771750314, 33.50238275527954, 10.160678233419146, 3.3712891893727437, 0.13753011875918933, 0.4089657579149519, 0.20566343489502156, 3.068821511098317, 29.636391162872314, 51.893409797123496, 46.7868903023856, 51.084417138780864, 46.08380208696638, 51.05484560557774, 50.64415495736258, 54.46637289864676, 62.128068106515066, 54.00416483197893, 3.963982471397945, 0.20942304815564836, 0.09264814853668213, 0.1629434943731342, 0.08511304429599217, 0.08251227385231427, 0.16624173096248082, 0.053199167496391704, 0.13405832648277283, 0.12962517222123487, 0.16909620564963135, 0.12739851884543896, 0.13554285253797257, 0.11039516409592968, 0.11577072207416807, 0.1481392580483641, 0.11824935621448926, 0.09116307965346745, 0.0786274369539959, 0.10579263392303671, 0.09441126749983855, 0.1145911839391504, 0.06914286089262792, 0.19387585669755936], [0.09570925749306168, 0.07100625376084022, 0.027008697956002185, 0.01915503339841962, 0.06973748148552009, 0.01590648423215108, 0.05686848131673677, 0.0855309675846781, 0.007052699769181865, 0.027763359514730315, 0.02748781831802002, 0.03815148977030601, 0.01668863494082221, 0.036259710389588556, 0.04465858631634286, 0.04221636915047254, 0.06899210398218461, 0.05663497366809419, 0.011483397733952318, 0.019689099829910055, 0.08180937264114618, 6.4449010491371155, 46.53906890324184, 57.41829422542027, 49.26479162488665, 31.80111285618373, 22.51607527051653, 17.902735437665665, 32.61980519975935, 45.06799629756382, 45.58844416482108, 11.700159328324453, 0.037013908848166466, 0.05423041519575885, 0.11377064511179924, 0.16398140867905958, 1.0152219235897064, 1.895009343113218, 3.1112858610493794, 3.133594572544098, 13.02032400880541, 39.38841022763933, 54.14216300419399, 58.38088376181466, 52.194767066410606, 54.073438371930806, 53.27384662628174, 57.667373248508994, 52.216052872794016, 53.10918126787458, 53.33303485597883, 48.55607189450945, 43.27053206307547, 43.414043630872456, 44.41384424482073, 43.25791760853359, 43.5827180998666, 42.65647111620222, 42.92307349613735, 40.84337343488421, 47.68740463256836, 47.546724455697195, 49.20594038282122, 41.06624732698713, 38.997879777635845, 40.56235701697213, 44.27929932730538, 47.2348302432469, 49.42394706181118, 51.44358689444405, 51.009119510650635, 46.511494977133616, 46.86971630368914, 47.385887554713655, 49.69556951522827, 48.54999916894095, 50.89346327100481, 44.223821435655864, 42.00603634970528, 37.89158412388393, 38.35956614358084, 41.44996506827218, 47.07163095474243, 44.292174339294434, 47.236921651022776, 47.6745400428772, 55.84413119724819, 36.69063663482666, 37.14597640718733, 56.03452920913696, 44.18109001432146, 43.828889301845, 36.89354140417916, 45.317870889391216, 49.758600098746165, 49.9487966128758, 48.963489941188264, 53.52493715286255, 48.29600429534912, 45.6674347605024, 41.589755875723704, 39.374305384499685, 38.068860462733674, 39.261112281254356, 40.27900947843279, 41.33860976355416, 40.199435234069824, 38.95468977519444, 38.11220679964338, 44.31732334409441, 49.19832515716553, 47.6853722844805, 47.27663408006941, 46.06812695094517, 52.31304625102452, 50.89287267412458, 48.41780621664864, 39.54351486478533, 39.24753202710833, 44.17728240149361, 51.73464345932007, 52.81345203944615, 52.67606183460781, 54.128249236515586, 54.21485505785261, 53.165006569453645, 52.05193642207554, 52.140897682734895, 52.781243664877756, 51.974800995418, 57.94387681143624, 50.120163508823936, 25.153804268155778, 5.912545272282191, 3.6133529203278676, 12.927199908665248, 10.876636249678475, 8.76603581224169, 0.6678528147084373, 0.03076754616839545, 0.029003212627555643, 0.04139633922438536, 8.267724905695234, 37.44927569798061, 39.308266230991904, 33.57033266339983, 41.1907034601484, 28.59278736795698, 24.25848024232047, 48.5943078313555, 46.250319140298025, 51.97521441323416, 14.484933052744184, 0.16645693512899534, 0.014884459520024913, 0.05974505588944469, 0.025796970119699836, 0.032715033274143934, 0.04627542670017906, 0.03595403375636254, 0.06784711685031652, 0.05661866168624588, 0.015439138149044343, 0.038999193747128756, 0.008271403793644692, 0.03666825632431677, 0.0900577325373888, 0.02366690111479589, 0.02550976999503161, 0.03262453705870679, 0.06479932753635304, 0.11295253543981484, 0.039820322899946144, 0.08209289849868842, 0.04594300900186811, 0.05320332691605602, 0.09126707871577569, 0.025141113437712193, 0.015326221440253513, 0.026689058768429925, 0.08055356038468224, 0.009986771703032511, 0.029373658820986748, 0.004683817819958287, 0.02605132745312793, 0.027662756520190408, 0.031374689125056775, 0.09021425021014043, 0.0189598528003054, 0.05037467727171523, 0.037842447603387494, 0.025746013836136887, 0.02575696539133787, 0.06896175311080047, 0.03859984874725342, 0.041829556692391634, 0.039174985207085095, 9.998073884419032, 56.818251269204275, 64.32472024645124, 56.07602385112217, 36.93256943566458, 30.796215738568986, 24.0993960244315, 30.2564240864345, 45.99056421007429, 49.890004430498394, 12.438553946358816, 0.06376042256930045, 0.03012179456917303, 0.08871099658842597, 0.2965513957398278, 2.6977436287062506, 4.860885909625462, 5.294841732297625, 5.2583606498582025, 14.79499728339059, 39.10583393914359, 56.61089965275356, 59.49351964678083, 55.22115223748343, 55.830328600747244, 57.27274683543614, 58.07816811970302, 53.785498074122835, 53.27990198135376, 57.39668880190168, 50.72412872314453, 46.90947042192732, 43.44601229258946, 46.606584548950195, 45.600638253348215, 46.099070753370015, 44.52368484224592, 44.17487832478115, 43.46494265965053, 49.33950907843453, 49.18175022942679, 50.92682157244001, 43.081402097429546, 41.04422501155308, 43.12948363167899, 45.43162679672241, 49.06144911902291, 51.21719373975481, 53.57028109686715, 50.54073796953474, 46.77117347717285, 48.11172417231968, 49.00169113704136, 53.53026989528111, 50.3638368334089, 50.91991853713989, 46.42302703857422, 44.40018061229161, 39.39768259865897, 41.06452417373657, 43.9453306879316, 49.34596742902483, 46.28502886635916, 49.303308963775635, 49.27851431710379, 57.29535627365112, 38.357905524117605, 39.53905412128994, 56.90825128555298, 46.13820995603289, 44.79198605673653, 38.76567792892456, 47.39508349554879, 52.47959109715053, 50.559265341077534, 49.94989095415388, 53.759404114314485, 50.06240313393729, 47.12491321563721, 42.82791096823556, 40.66491937637329, 39.27067647661482, 40.925900663648335, 41.00581884384155, 42.49011039733887, 41.13929026467459, 41.308190550122944, 39.54975782121931, 45.967037609645296, 50.41791813714163, 51.81287670135498, 47.59791530881609, 45.96441119057791, 53.379490511757986, 52.97564731325422, 50.10045494352068, 41.116944858006065, 41.8285585130964, 46.69809579849243, 53.84993914195469, 54.14594629832676, 56.185395445142476, 55.84078563962664, 54.97332041604178, 54.99018716812134, 54.11326892035348, 53.55498811176845, 54.82541758673531, 52.786086559295654, 58.53680828639439, 52.58679485321045, 29.884066649845668, 6.9545614038194925, 5.859278644834246, 10.930747951780047, 12.357043760163442, 7.625202400343759, 2.2113888348851884, 0.2462106112922941, 0.05620290970961962, 0.13478320544319494, 8.82992970943451, 38.144092082977295, 35.34470803397042, 41.329962730407715, 44.75735970905849, 33.036214215414866, 29.428139754704066, 51.75138166972569, 52.92543615613665, 57.26441594532558, 19.951415266309464, 0.09589347975062472, 0.03190451301634312, 0.04974545478554709, 0.01663869645978723, 0.02779495040886104, 0.06672924397779362, 0.04164438787847757, 0.021502080938911865, 0.052520605336342535, 0.054734519217163324, 0.11812009529343673, 0.06237167173198291, 0.0395698790172381, 0.05475041050730007, 0.05492601876280137, 0.01449885655061475, 0.03791973613468664, 0.020628434871988635, 0.10412117147019931, 0.042027709273887534, 0.02187448300953422, 0.03313053758548839, 0.018323526052492004, 0.17006142171365873, 0.13076479892645562, 0.12927928221012863, 0.1011636680258172, 0.17483412846922874, 0.12487542709069592, 0.15355088694819383, 0.08810074254870415, 0.16354916830148014, 0.1346987278333732, 0.15093453734048776, 0.1748600620776415, 0.11338897594915968, 0.12418883107602596, 0.1347182017884084, 0.12581522523292474, 0.1431095493691308, 0.1911341409598078, 0.06545112827526671, 0.14808321105582373, 0.13662814215889998, 14.248195767402649, 68.94688429151262, 70.07995482853481, 64.14585971832275, 44.18385192326137, 35.34979064123971, 25.740947893687657, 44.574813161577495, 55.31918089730399, 59.01041834694998, 16.220428909574235, 0.2613100510622774, 0.19311202982706682, 0.36561933958104675, 0.3595422442470278, 3.5355081260204315, 8.746888313974653, 6.724175640514918, 10.105830022266932, 17.864900759288243, 43.69355228969029, 57.97133609226772, 64.5076802117484, 57.752825668879915, 58.84456484658377, 59.48892688751221, 61.77388368334089, 54.618253571646555, 54.32265635899135, 59.22965485709054, 54.01857539585659, 49.4629716191973, 47.1420578956604, 47.95017160688128, 47.685601575034006, 46.96879414149693, 47.510691097804475, 46.85409327915737, 45.61683797836304, 52.98549638475691, 51.858182430267334, 55.068785190582275, 46.30624519075666, 43.35183640888759, 44.844907011304585, 49.31260912758963, 51.02371072769165, 53.84863635471889, 55.29420212336949, 50.88546242032732, 46.64972938810076, 48.02643503461565, 49.82994072777884, 54.9308808190482, 53.47113725117275, 54.34732246398926, 48.05551324571882, 47.17519038064139, 41.63539511816842, 42.408917222704204, 46.52619736535208, 51.283052240099224, 48.25736536298479, 51.11568750653948, 51.54856027875628, 59.031005859375, 42.03221368789673, 41.9567597252982, 58.530450684683665, 48.16372101647513, 47.60990789958409, 40.53195864813668, 48.49525778634207, 54.78238391876221, 53.41029535021101, 51.48524134499686, 56.48937218529837, 53.5305096081325, 49.57625504902431, 45.449584415980745, 42.05551099777222, 41.10978473935808, 43.296139648982454, 43.70267527444022, 45.06717293603079, 43.19847924368722, 43.626029695783345, 41.04097672871181, 48.47772748129708, 54.27670097351074, 52.81491810934884, 48.142254556928364, 46.96622678211757, 55.5986304964338, 55.08541917800903, 53.85788440704346, 42.797099181583945, 43.47470487867083, 49.010303429194856, 55.48642403738839, 56.01158625738961, 58.51633194514683, 58.26959446498326, 57.195858069828574, 57.82613958631243, 57.02423409053257, 57.71209532873971, 57.19747700010027, 55.853278500693186, 60.1965731212071, 55.58051654270717, 30.106200558798655, 9.659829497337341, 8.38724868638175, 23.67081376484462, 23.70982789993286, 14.917283841541835, 1.845491485936301, 0.2798182064933436, 0.14251083721007618, 0.2715323439666203, 12.891069275992256, 50.28699670519148, 50.07402747017996, 38.63704592841012, 49.168774468558176, 41.82610927309309, 36.7304185458592, 62.25531046731131, 58.14049693516323, 66.20571572440011, 23.552788189479283, 0.21613415304039205, 0.10223358204322201, 0.2242532723716327, 0.08201315027794667, 0.059487124372805865, 0.09589848733906235, 0.15493737826389925, 0.11642404273152351, 0.1919762979128531, 0.10846875568053552, 0.24044550635984965, 0.14537270792893, 0.10528033319860697, 0.14043013671679155, 0.12973082012363843, 0.10906089283525944, 0.09606381239635603, 0.1984899491071701, 0.18686610140970775, 0.16162640361913613, 0.12007272908730166, 0.14401729351707868, 0.15627097098955087], [0.028732653574219773, 0.0026901778224523044, 0.04587486372994525, 0.02655189630708524, 0.029815697244235446, 0.028027228212782314, 0.05731438738959176, 0.06495808437466621, 0.01832473893383784, 0.02033251048331814, 0.01963299516189311, 0.07971457897552423, 0.022758054347442727, 0.023066519759595394, 0.07580876177442925, 0.05210608150810003, 0.0256227833950626, 0.05469851954174893, 0.015825652051717043, 0.04810437373816967, 0.17268979496189527, 12.49311033317021, 48.84338338034493, 52.05623388290405, 51.1877681187221, 46.364901883261545, 20.053128208432877, 18.607795204435075, 33.91071449007307, 36.00127458572388, 30.80025611604963, 2.5859049899237494, 0.03364548120381577, 0.10002352563398224, 0.11135659393455301, 0.5821497706430299, 1.3405122629233768, 4.696621375424521, 9.752293518611364, 7.004726963383811, 30.177680151803152, 48.365534918648855, 58.370926993233816, 53.80760029384068, 52.310628277914866, 50.43098075049264, 53.61642755780901, 54.89473976407732, 52.89127533776419, 51.30284070968628, 54.838883195604595, 51.317953041621614, 44.54719754627773, 37.760916301182334, 44.89051151275635, 45.14422845840454, 46.50514084952218, 42.81791251046317, 42.101205825805664, 37.970873492104666, 41.11043439592634, 43.38441998617989, 44.2440893309457, 38.1055052621024, 39.831139019557405, 42.046582562582834, 43.27768175942557, 44.59936809539795, 49.27497073582241, 49.37090451376778, 51.973425252096995, 49.044655323028564, 48.08178438459124, 48.21896266937256, 51.53006764820644, 48.253842626299175, 47.34560884748186, 42.25306218011038, 39.99148954663958, 37.52755410330636, 38.65934269768851, 39.94115332194737, 45.73555489948818, 42.44968925203596, 48.26093326296125, 46.1594158581325, 60.035840443202424, 35.209687164851594, 36.80910689490182, 55.33468232836042, 44.82734891346523, 45.59132766723633, 36.63206679480416, 40.191427435193745, 48.98485565185547, 49.815512793404714, 49.11366135733468, 50.604077747889924, 47.59311410358974, 48.51580708367484, 43.070152963910786, 42.73444380078997, 41.47872713633946, 42.32741832733154, 42.83355637959072, 43.206900460379465, 42.048865045819966, 42.07678290775844, 39.46279069355556, 42.99157231194632, 49.24363783427647, 50.79368366513933, 49.61670746122088, 47.149909360068186, 51.97596829278128, 52.020183154514854, 46.589519773210796, 40.763573374067036, 38.37740216936384, 38.45918941497803, 42.17670495169503, 51.13493749073574, 51.69304806845528, 51.63560036250523, 50.314518519810264, 48.44954906191145, 47.56258371898106, 48.70149769101824, 48.989559582301546, 52.27018976211548, 53.45892231804984, 54.977364267621724, 41.92423520769392, 18.438184465680802, 3.7512585946491788, 5.666330209800175, 9.008308206285749, 13.082876903670174, 2.734559093202863, 0.20686999229448183, 0.050657093724501986, 0.02366068403768752, 0.31396428708519253, 17.71052394594465, 37.739428997039795, 15.062157256262642, 25.932226589747838, 29.70683547428676, 23.87757304736546, 34.79835728236607, 46.171144417354036, 46.47948810032436, 39.24496119362967, 1.9212665855884552, 0.10205169394612312, 0.04642474850905793, 0.03321400417813233, 0.013752378124211515, 0.05200765661096998, 0.039523100813052485, 0.043771143936152966, 0.030008472435708557, 0.03191962738388351, 0.032462370581924915, 0.01899867009238473, 0.03307281121877687, 0.03889803096119847, 0.059553071191268306, 0.039152335708162615, 0.037749881856143475, 0.029920401982963085, 0.057380931318870614, 0.062067430200321336, 0.02282530564947852, 0.015087755396962166, 0.011727948540023394, 0.03236258861475757, 0.018645870898451124, 0.085368064897401, 0.0883353663874524, 0.004161928971630654, 0.018713368169431175, 0.01081370487476566, 0.02757557325198182, 0.029736922721245458, 0.009621001464048666, 0.021824257847453867, 0.021533746471894637, 0.051734050935400386, 0.07433731108903885, 0.02651148785038718, 0.01754798597124006, 0.05361135716417006, 0.08960031851061753, 0.02984012450490679, 0.017778857511335185, 0.12234090880623885, 17.392612593514578, 60.118489265441895, 58.02605663027082, 57.43177720478603, 51.763728618621826, 23.24590015411377, 20.284762041909353, 34.59690816061837, 39.734034470149446, 35.20520557676043, 2.726607314177922, 0.025065324468804256, 0.09333921609712498, 0.0808125843427011, 2.6689965426921844, 4.299283862113953, 4.402337372303009, 6.441649726458958, 10.383136970656258, 32.05801902498518, 51.52231693267822, 61.08878435407366, 55.75891848972866, 54.04309906278338, 52.31017664500645, 54.13725062779018, 56.82478952407837, 53.26808656964983, 52.642745222364155, 56.525151933942524, 53.6048310143607, 45.356794697897776, 40.65601178577968, 48.05309179850987, 47.532807213919504, 48.91777079445975, 44.58864007677351, 44.705421924591064, 40.649282455444336, 42.940075738089426, 45.78699936185564, 44.92653792245047, 40.764761516026084, 40.82930333273751, 44.947851521628245, 45.69332027435303, 46.10029016222273, 51.36607279096331, 51.89431306294033, 54.2205491065979, 49.0839056968689, 48.81087623323713, 49.584061350141255, 53.71656847000122, 49.09165988649641, 50.876016344342915, 44.66970123563494, 42.054618154253276, 39.545147691454204, 41.84543916157314, 41.69925948551723, 47.76495695114136, 43.896224294389995, 50.105902331215994, 49.311625957489014, 60.403372355869834, 36.88472066606794, 39.11765282494681, 56.072587966918945, 47.055212361471995, 47.89088610240391, 38.47615344183785, 42.291516985212056, 50.149481432778494, 52.50591434751238, 50.16857508250645, 52.01012216295515, 49.976471287863596, 49.57678311211722, 46.164411612919395, 44.39791897365025, 42.042622089385986, 43.656761578151155, 45.304193360464915, 45.1145909173148, 43.22472606386457, 43.509817600250244, 40.54989889689854, 44.510104588099885, 50.91272367749895, 53.21224389757429, 49.578426361083984, 46.89162049974714, 52.97263526916504, 54.42985316685268, 49.96616016115461, 42.08654512677874, 41.12835380009243, 40.59766428811209, 45.18580647877285, 51.99281072616577, 53.59533282688686, 52.444183077131, 53.474673884255544, 49.534659658159526, 50.566057205200195, 49.00266735894339, 52.10366228648594, 54.26422895703997, 57.07909706660679, 57.11916732788086, 44.63325793402535, 17.12852372441973, 5.137700404439654, 5.355643681117466, 9.136617984090533, 7.8793345008577615, 5.116458892822266, 1.5792462868349892, 0.11226463663790907, 0.03780159640258976, 0.369632249964135, 19.663514920643397, 38.15079362051827, 17.316679205213273, 27.33367998259408, 36.22769900730678, 33.34932088851929, 41.781533105032786, 51.72286626270839, 52.679813861846924, 47.93156433105469, 3.572409574474607, 0.18135512141244753, 0.0489179474035544, 0.03396348003298044, 0.02260178094729781, 0.020756377738767436, 0.05591936010335173, 0.02863516505541546, 0.026303966396621296, 0.038783853873610497, 0.042639951421214004, 0.030529889278113842, 0.023829384806698987, 0.013874639956546682, 0.04531760327517986, 0.025178376884598817, 0.029113332075732093, 0.04904918286151119, 0.019077459882412637, 0.06146351367767368, 0.03184521923373852, 0.05650243542290159, 0.032051795827490945, 0.09072597417980433, 0.10022872819432191, 0.10027745379401104, 0.21299815417400428, 0.13763970216470106, 0.14949966647795268, 0.08235831425658294, 0.166829912258046, 0.079855056080435, 0.10874369807009186, 0.14294085199279444, 0.14118833174662931, 0.07250243026231017, 0.19209185242652893, 0.07490766726966415, 0.15722880459257535, 0.169260546831148, 0.21114202163049153, 0.0582402619932379, 0.10011781486017363, 0.39963405579328537, 23.878914049693517, 69.38118839263916, 65.81371225629533, 66.89047459193638, 59.72793797084263, 30.66229615892683, 27.075990404401505, 44.84878063201904, 46.36897005353655, 42.15075690405709, 4.168226506028857, 0.16324434322970255, 0.24102796081985745, 0.14064557158521243, 2.121432896171297, 5.062710668359484, 12.096812878336225, 18.711952175412858, 12.72179205077035, 34.163712297167095, 52.475846018110005, 63.4086697442191, 58.31279836382185, 57.55896050589425, 54.3207733971732, 57.07502542223249, 58.7685307094029, 56.39962577819824, 53.34045900617327, 58.66560704367501, 55.73355061667306, 48.867073263440815, 41.71167591639927, 50.38524423326765, 49.87596212114607, 51.436979157584055, 46.88472441264561, 48.11408655984061, 41.577509675707134, 44.36060019901821, 47.99462618146624, 47.12091105324881, 41.2976153918675, 43.53254863194057, 47.948934827532085, 47.60799019677298, 48.73014858790806, 53.789878913334434, 55.7247576713562, 56.28618253980364, 49.75696727207729, 49.79502255575997, 50.284960883004324, 55.55254309517996, 51.50456428527832, 53.05245964867728, 46.26782512664795, 44.55312435967581, 41.809350218091694, 43.225723130362375, 43.50133384977068, 50.46718086515154, 45.96158674785069, 53.01932716369629, 51.67415591648647, 63.20350333622524, 39.53933204923357, 42.09832579748971, 58.07859543391636, 49.51463494982038, 50.462768759046284, 41.02183096749442, 44.49762214933123, 53.35381691796439, 54.88840995516096, 52.38422359739031, 53.37305300576346, 52.54459496906826, 52.4864559173584, 46.64816951751709, 46.82318074362618, 45.19479397365025, 44.68224273409162, 47.45278133664812, 47.75591734477452, 46.08844348362514, 46.98295109612601, 43.33435821533203, 45.86443356105259, 53.74885327475411, 56.56732055119106, 51.312140873500276, 47.495120184762136, 55.279124532427105, 56.48080505643572, 53.65147079740252, 43.951886313302175, 43.56365919113159, 42.44748667308262, 46.321715354919434, 54.39067922319685, 55.57832438605172, 55.96857343401228, 53.724993160792756, 52.6383296421596, 52.16062361853463, 54.05748183386666, 53.86740691321236, 55.850773675101145, 58.474969318934846, 58.27372169494629, 45.375249113355366, 21.654514278684342, 8.011342457362584, 11.850619094712393, 18.899499688829692, 23.93561829839434, 9.149096948759896, 0.985499375632831, 0.2091787891196353, 0.18158000148832798, 0.9195205846003124, 25.04766184943063, 52.30771350860596, 22.607445819037302, 33.9073098727635, 40.92941645213536, 36.19241258076259, 46.69798462731497, 59.78624030521938, 57.695965085710796, 57.62465224947248, 4.403567203453608, 0.308854592697961, 0.245494865413223, 0.1385976579040289, 0.11795740973736558, 0.142056083040578, 0.16516215460641043, 0.10196974048657076, 0.11190991888621024, 0.07446126586624555, 0.13495743966528348, 0.14543507886784418, 0.08445941151252814, 0.11483916134706565, 0.14802879254732812, 0.0999774666769164, 0.1393777560442686, 0.13240739649959973, 0.1652663368731737, 0.11615687635328088, 0.15750262061400072, 0.16675397061875888, 0.10478070072297539], [0.008396226247506482, 0.03441009856760502, 0.03226460815806474, 0.06200982936258827, 0.09013556050402777, 0.07293914218566247, 0.01715684954875282, 0.08683043678424188, 0.02074172647137727, 0.031022651586681604, 0.09895407980574028, 0.006173693275611315, 0.0148658405191132, 0.021351161180064082, 0.056571696884930134, 0.050414266397378275, 0.005442807583936623, 0.02241292599189494, 0.018629178936992372, 0.11313841332282339, 0.5959873252681324, 42.33469656535557, 56.664772510528564, 54.51357201167515, 45.70168590545654, 35.59959922518049, 25.560037646974834, 26.371293681008474, 35.16502414430891, 47.26068796430315, 21.74547140938895, 0.2032651121595076, 0.02506338894766356, 0.055759710991489034, 0.1781346042241369, 1.1481824346951075, 4.806759008339473, 3.6239005029201508, 6.409093073436192, 25.207489524568828, 44.44026476996285, 61.38884925842285, 56.907254219055176, 53.154869147709434, 51.22148077828543, 47.33902890341622, 49.05083227157593, 53.58496611458914, 52.87600667136056, 49.96276944024222, 54.39558465140206, 50.432582310267854, 45.708453450884136, 39.29713521684919, 44.29547125952584, 44.999497481754844, 46.534389291490825, 44.470718724387034, 43.59643036978585, 39.41138097218105, 38.396304743630544, 38.45880378995623, 38.86125387464251, 38.468885626111714, 41.8158780506679, 41.47011137008667, 43.70283508300781, 44.763286522456575, 45.88858897345406, 46.72106654303414, 51.96139792033604, 48.576374530792236, 46.01953819819859, 48.613307680402485, 49.98175539289202, 47.101233754839214, 43.82156590053013, 37.38206229891096, 37.771946566445486, 36.72802489144461, 40.487639563424246, 40.26738166809082, 41.70974779129028, 42.16599082946777, 48.34326594216483, 46.376321247645784, 56.67928729738508, 35.69102014814104, 34.745523180280415, 55.045665059770855, 45.3608524458749, 43.81557655334473, 37.772057737622944, 37.83122164862496, 42.041086537497385, 52.216994353703086, 46.024808406829834, 49.23295150484358, 50.21660450526646, 48.746410846710205, 46.02257456098284, 44.88281985691616, 44.70308385576521, 44.87877600533621, 44.615873541150776, 46.601404666900635, 45.50845997674124, 44.48519877025059, 40.568502698625835, 44.432173592703684, 48.50646870476859, 50.56667212077549, 50.258328437805176, 47.073923860277446, 49.182990482875276, 50.92439317703247, 48.22896112714495, 45.89624241420201, 42.252009528023855, 39.802241461617605, 37.19045877456665, 39.94017710004534, 43.99760546003069, 45.05265120097569, 44.559440272195, 43.1796635219029, 45.15591185433524, 42.55725084032331, 46.87129701886858, 49.7640266418457, 54.878776277814595, 53.49367720740182, 53.5033768926348, 23.425222737448557, 10.457721539906093, 7.089329532214573, 8.954431005886622, 6.269269696303776, 4.779070436954498, 0.6727092255439077, 0.1311261731066874, 0.02977817425770419, 0.06596270975257669, 5.034153137888227, 31.40879671914237, 48.17640495300293, 32.59439563751221, 16.524973664964946, 12.133112873349871, 29.941159997667583, 37.67618301936558, 44.59627614702497, 49.49833795002529, 17.675034284591675, 0.086511884949037, 0.07558049580880574, 0.07323503095124449, 0.00430723512545228, 0.011629650868209345, 0.07694101280399732, 0.049971172852175574, 0.10287494691354887, 0.02421303529159299, 0.014917751840714897, 0.04556381309937153, 0.06091556950871434, 0.045430640423936505, 0.03916631352954677, 0.04031431335689766, 0.07280825956591538, 0.06705139883394752, 0.02716314440060939, 0.025280045179118003, 0.03766251029446721, 0.019962803893057362, 0.03450292215815612, 0.026788294514907256, 0.05448374624497124, 0.04193747429443257, 0.07190466805228166, 0.05991593136319092, 0.026381217608494417, 0.012563490624805647, 0.06523492666227476, 0.0478545473223286, 0.03361923886196954, 0.03621274219559772, 0.032608907004552226, 0.02526459493674338, 0.0234221314811813, 0.04849992233461567, 0.056246692181697915, 0.018404434568115642, 0.004778557423768299, 0.00847898461922471, 0.11893900563674313, 0.979988694190979, 50.829435620989116, 64.23686027526855, 62.11057254246303, 50.576646259852815, 42.01999528067452, 28.41000805582319, 20.720903941563197, 38.638984475817, 48.20038666043963, 21.2987665108272, 0.13792505328144344, 0.021888588056234375, 0.0005035476756997273, 0.8013050737125533, 3.8700862526893616, 7.2294147695813855, 6.740043589047023, 8.120197279112679, 22.763999155589513, 44.21004663194929, 62.04509966714041, 59.27021149226597, 56.67689364297049, 52.10252973011562, 49.354235785348074, 52.23436485018049, 56.09001752308437, 54.72578041894095, 51.53010933739798, 56.3928165435791, 51.625528948647634, 47.66768911906651, 40.94526529312134, 45.78106907435826, 48.54398202896118, 48.54398897715977, 46.196484497615266, 45.341522557394846, 41.396120003291536, 41.21928487505232, 41.18687500272478, 40.81064394542149, 39.59308678763253, 42.89726093837193, 44.47000305993216, 46.62626879555838, 48.29567773001534, 48.91817031587873, 48.53632511411394, 53.750896045139854, 49.16881963184902, 46.1390437398638, 48.567581585475374, 51.174097537994385, 49.80175536019461, 46.30794055121285, 41.10944775172642, 40.01580129350935, 39.12604972294399, 42.21860606329781, 40.818075043814524, 43.710526738848, 42.62687179020473, 49.06665331976754, 48.70830692563738, 56.482886041913716, 36.85386371612549, 36.10190534591675, 57.534433364868164, 48.03849015917097, 45.61558035441807, 38.98141254697527, 39.58528396061489, 44.87164715358189, 54.06436749867031, 49.33678885868618, 50.71771553584507, 50.176204204559326, 51.14988654000418, 47.51578065327236, 47.07277045931135, 47.79787751606533, 46.96437161309378, 47.854470593588694, 48.93915040152413, 47.16309009279524, 46.31735536030361, 43.06699848175049, 45.26708650588989, 50.582514013562886, 52.615841797419954, 49.249130385262625, 47.22392504555838, 49.99653421129499, 51.964524609701975, 50.69303900854928, 47.31981366021292, 43.80906956536429, 41.362205845969065, 38.87458051953997, 41.66348321097237, 46.115551880427766, 46.30371257237026, 46.68258047103882, 45.70460762296404, 47.13274730954851, 44.926207883017405, 47.87605169841221, 52.93476758684431, 56.621742316654746, 58.75879628317696, 54.506491797310964, 29.937046664101736, 10.552389877183096, 5.496011623314448, 9.78359775883811, 8.33337322303227, 10.951170444488525, 3.575008200747626, 0.5764907343047005, 0.04012244740234954, 0.04747095112023609, 5.077011798109327, 35.267041070120676, 38.98543207986014, 34.89081696101597, 23.206611565181188, 19.473047426768712, 34.4926678112575, 42.87343209130423, 49.14747129167829, 56.73826360702515, 22.211009400231497, 0.07354396794523511, 0.03853683998542173, 0.051127148858670673, 0.07180064184857265, 0.01768701440388603, 0.045849052257835865, 0.08610751879002367, 0.035877756242241175, 0.050589589668171744, 0.0156760435617928, 0.002105609937903604, 0.06308536843529769, 0.04249050408335669, 0.06810695505035774, 0.04330460700605597, 0.01852513916258301, 0.06389083021453448, 0.015771499868216257, 0.046073952689766884, 0.004923610399211091, 0.025706439977511764, 0.05022465657176716, 0.07301396424216883, 0.14038285639669212, 0.10885830942009177, 0.14581176079809666, 0.19996952185673372, 0.12544561363756657, 0.08823155052959919, 0.21495407207735948, 0.16189557846103395, 0.11307762337050267, 0.20721711723932199, 0.21075905646596635, 0.1183263427977051, 0.08211442162947995, 0.1386856503252472, 0.1300553905644587, 0.12033507786691189, 0.06437321432999202, 0.06463675054588489, 0.3456745898084981, 1.774425310747964, 59.691557203020366, 72.58504445212228, 70.29390375954765, 57.82054281234741, 48.02290882383074, 35.85394498280117, 37.56968450546265, 46.01657131740025, 60.085130964006694, 29.136100019727433, 0.27073826800499645, 0.13099164675389016, 0.15684501161532743, 0.8835797788841384, 4.765930090631757, 13.27085086277553, 11.220160399164472, 13.423330817903791, 29.240812846592494, 47.138281549726216, 64.69442694527763, 61.32784407479422, 59.42332894461495, 54.541118144989014, 52.07172836576189, 55.04368829727173, 57.61838844844273, 56.71532760347639, 52.88172503880092, 58.57408537183489, 54.78563914980207, 49.32655416216169, 43.741640772138325, 49.60481909343174, 50.49789885112217, 52.405262742723735, 48.443611826215474, 47.36678000858852, 43.52861247743879, 42.79264538628714, 42.735468660082134, 43.707097802843364, 42.9734514100211, 45.82308830533709, 46.546833515167236, 48.709133761269705, 50.10060085569109, 50.25090428761074, 50.51351840155465, 57.3040588923863, 50.83117267063686, 45.68004921504429, 50.49042953763689, 54.5227610043117, 51.599136216299875, 48.854698521750315, 42.32111978530884, 41.116903168814524, 41.17206491742815, 45.33947631290981, 44.189129080091206, 45.860962935856406, 46.862406798771445, 51.63419335229056, 50.65516437802996, 57.81697143827166, 39.011394023895264, 39.251989296504426, 61.0316493170602, 50.38064799989973, 46.635370935712544, 41.96502113342285, 42.36245461872646, 46.51951319830758, 55.2341696875436, 50.53235149383545, 52.78339065824236, 53.015661988939556, 53.509119578770225, 48.91868100847517, 48.60890252249581, 49.385047571999685, 47.80508974620274, 50.00034877232143, 50.95000423703875, 50.24979257583618, 47.99770770754133, 45.2613160269601, 48.47216197422573, 53.000775473458425, 54.97596420560564, 52.57756764548165, 47.04515136991228, 51.83786242348807, 56.48827089582171, 53.37865325382778, 50.93867519923619, 46.712051255362375, 43.31715794972011, 40.981698172433035, 44.052471910204204, 48.267631326402935, 49.24877602713448, 48.68417583193098, 48.65653937203543, 50.48700754983084, 46.757454259055, 51.66656500952584, 55.0052786554609, 60.18556717463902, 60.32965196881975, 58.298380851745605, 30.225542817796978, 14.647056238991873, 13.436422961098806, 15.33254987852914, 12.98122649533408, 8.462426458086286, 1.219752462846892, 0.33499246729271753, 0.14053415613515036, 0.15432221841599258, 6.598851416792188, 47.034812450408936, 63.89493942260742, 44.4583683013916, 25.392391511372157, 21.07293094907488, 41.041074003492085, 49.871748038700645, 57.50222846439907, 64.71675845554897, 27.30616511617388, 0.20267321249204023, 0.15565121067421778, 0.19011454709938594, 0.1846354446773018, 0.10408327528940779, 0.22180779145232268, 0.18486208894423076, 0.1275352029395955, 0.17951611509280546, 0.12122188242418425, 0.0721657004739557, 0.14712486176618508, 0.13880527604903492, 0.1164853415851082, 0.14794055585350308, 0.13601955052997383, 0.22152111040694372, 0.09354503612433161, 0.09723400031881672, 0.12694126766707214, 0.0681564270385674, 0.14137663878500462], [0.016413258288853934, 0.037433345269943984, 0.0336091694022928, 0.037273736870182414, 0.025068488138328706, 0.01841347265456404, 0.05538662190416029, 0.06767075202826943, 0.0871605169294136, 0.04518549589972411, 0.03486513772181102, 0.016556676843070557, 0.03292316710576415, 0.011193631050576056, 0.009247424679675272, 0.06207602045365742, 0.042904329020529985, 0.05343635280483535, 0.04515459202229977, 0.0941540077328682, 4.094502210617065, 48.32532221930367, 53.68508618218558, 46.43168796811785, 35.48682648794991, 29.717045852116176, 18.67767150061471, 33.53310421534947, 36.198905672345845, 34.046826226370676, 6.606375881603785, 0.04653780262119003, 0.11220514947282416, 0.06372703864638295, 0.208697504230908, 5.89119302374976, 5.341664774077279, 4.360779762268066, 9.08412608078548, 34.819938387189595, 56.825609411512104, 55.30420058114188, 54.2109432220459, 53.80088138580322, 49.11970281600952, 44.16839912959507, 48.62119388580322, 52.6295679637364, 50.258849552699495, 50.047488825661794, 51.33280481610979, 53.2381398337228, 44.0099697794233, 37.88767228807722, 42.959798199789866, 46.408651215689524, 48.779477323804585, 47.16151285171509, 43.47070966448103, 39.85498523712158, 37.88372571127755, 36.518175397600444, 37.45121771948678, 38.43925155912127, 44.01871408735003, 42.293188026973176, 43.940119538988384, 43.42977435248238, 43.55208349227905, 45.57117441722325, 49.257346630096436, 49.88008935110909, 47.46744898387364, 49.24512127467564, 50.91407857622419, 46.42317989894322, 40.73132678440639, 35.713799817221506, 38.635715348379954, 36.930095876966206, 40.599349226270405, 39.926916463034495, 44.59759977885655, 42.809515612465994, 48.87043966565813, 45.43768909999302, 56.81666013172695, 39.515485831669395, 36.37167610440935, 55.61912420817784, 46.24565689904349, 46.348667417253765, 38.19433798108782, 40.22843701498849, 36.204599721091135, 47.55625738416399, 50.812026909419465, 49.44839429855347, 47.86209971564156, 50.7896398135594, 48.74363504137312, 48.67283984592983, 47.296054295131135, 48.734199387686594, 47.229803221566335, 48.45923137664795, 46.87781095504761, 45.90477480207171, 42.46886280604771, 47.35033362252371, 48.64539793559483, 51.83372477122715, 50.33083636420113, 46.26319762638637, 49.51668119430542, 53.10371650968279, 49.45364366258894, 52.052617345537456, 49.2209415435791, 44.9533371244158, 39.72944865907942, 39.78538513183594, 38.09304019383022, 38.4386887550354, 39.53130340576172, 41.281169005802695, 42.25805098669869, 40.035134656088694, 42.99334410258702, 46.68755538122994, 51.33949245725359, 54.56177861349923, 54.8987523487636, 40.96691240583147, 19.31139758655003, 4.37932493856975, 6.637366584369114, 3.4355309307575226, 6.719553351402283, 8.58025140421731, 0.20984509693724768, 0.034888479326452525, 0.027633850928395987, 0.21727942515696796, 15.086781672069005, 34.603363037109375, 29.39530951636178, 45.849505356379915, 28.882462978363037, 25.508581025259836, 30.67693601335798, 42.44859491075788, 44.45748588017055, 35.708540030888145, 2.033421801669257, 0.14211093581148557, 0.04206016021115439, 0.02800518261002643, 0.05682035282786403, 0.037968387095523734, 0.0446701655164361, 0.030514235475233624, 0.053949980065226555, 0.036367186943867376, 0.02018839812704495, 0.04965668544173241, 0.03710221339549337, 0.02076051849871874, 0.015302084253302642, 0.013094990497588046, 0.0731410945632628, 0.02409072426546897, 0.058006832376122475, 0.026004912265177284, 0.04577509533347828, 0.09277254436165094, 0.02374551957473159, 0.0421054897430752, 0.01753730413370899, 0.03105769113504461, 0.06081005731331451, 0.021393681577007686, 0.04103999298864177, 0.04370424716866442, 0.12579092010855675, 0.03793440606178982, 0.0780833875760436, 0.07138286783759083, 0.016575794567220976, 0.06889108368860823, 0.014707426340984446, 0.048607707622327974, 0.011065005407934743, 0.06535109864281756, 0.07918796794755117, 0.05323749454692006, 5.940161756106785, 56.673742634909495, 61.59518296377999, 52.52820069449288, 42.565731116703574, 38.867878981998985, 26.835501091820852, 31.039437430245535, 35.648153236934114, 38.21661390577044, 6.446788787841797, 0.044999631587415934, 0.07148402383817093, 0.10682021414062806, 2.110317732606615, 6.207262669290815, 6.013159530503409, 3.90837299823761, 11.048167296818324, 35.26438685825893, 57.24786186218262, 59.60412107195173, 56.29388114384243, 56.27452693666731, 50.854080881391255, 46.35559477124895, 51.06016445159912, 56.28674534388951, 52.628056730542866, 52.36138834272112, 53.150050571986604, 55.550093855176655, 46.57968807220459, 40.16161271503994, 44.32994474683489, 48.88233150754656, 50.50116103036063, 50.56037705285208, 46.50776032039097, 42.57072687149048, 39.10026148387364, 38.496358803340364, 39.21605668749128, 40.875547068459646, 45.518058913094656, 45.50272076470511, 45.42108637945992, 45.000452859061106, 46.13160916737148, 47.59684528623308, 50.665141991206575, 51.85920034136091, 49.063828877040315, 51.91935437066214, 52.34133236748831, 46.791250297001426, 43.077886308942524, 37.066541126796174, 38.796003341674805, 37.82143858500889, 43.40094975062779, 42.185081005096436, 46.29869597298758, 45.92286443710327, 51.60354137420654, 47.594548906598774, 57.12149497440883, 41.125685691833496, 38.85619906016758, 55.93700081961495, 48.588909081050325, 48.046751567295615, 39.75990956170218, 40.462282112666536, 38.37869453430176, 50.020262309483115, 52.11063827787127, 51.67046642303467, 50.75605569566999, 52.5049763407026, 49.55847808292934, 50.319767883845735, 50.184632369450156, 50.40517514092581, 50.48700754983084, 50.640687806265696, 48.621607303619385, 48.307642527988975, 45.797386918749126, 48.85933991840908, 50.370104108537944, 52.90426499502999, 50.28211906978062, 48.097390038626536, 49.72164610454014, 56.42097064426967, 51.09346716744559, 52.93664360046387, 50.94987916946411, 47.335930006844656, 42.50073071888515, 42.06350490025112, 39.00995922088623, 41.38617713110787, 42.233193806239534, 44.198172160557334, 44.38110433306013, 43.467534337724956, 44.1354855128697, 48.43553801945278, 55.134515149252756, 55.84413119724819, 56.625765323638916, 41.45065293993269, 19.575842550822667, 5.281189824853625, 6.671721083777292, 7.7529719557080945, 9.44047486782074, 8.726636052131653, 2.690133397068296, 0.28750549256801605, 0.058168038725852966, 0.25522494901503834, 18.460896389825002, 34.52385480063302, 33.64719711031233, 46.47844934463501, 31.661811896732875, 32.72594935553414, 35.463977336883545, 48.741891043526785, 51.751652649470735, 44.5086350440979, 2.9756468193871632, 0.06172068523509162, 0.03699032297091825, 0.028388495523748652, 0.02091322110832802, 0.05709273035504988, 0.06285545362957887, 0.02943218925169536, 0.04045147581824234, 0.05822407893304314, 0.05568463109167559, 0.0872685464897326, 0.06716217646109206, 0.02629108271295471, 0.03333613708881395, 0.03343258744903973, 0.04418262453483684, 0.03743340294542057, 0.05253875275541629, 0.015169657966388124, 0.034980373324028084, 0.06569955351629428, 0.09696099853941373, 0.09719634841063193, 0.12591961106019361, 0.11730837742132799, 0.14531429963452475, 0.07865820173174143, 0.16725797285991056, 0.10464160104415246, 0.28189278660076006, 0.09533848560282163, 0.1512340155563184, 0.17627957090735435, 0.11719533348722116, 0.09834689274430275, 0.17676005512475967, 0.11787241644092969, 0.16219097189605236, 0.11861305098448481, 0.10459009345088686, 0.13689183443784714, 7.912000588008335, 68.9285340990339, 66.57570729936872, 59.965594155447825, 47.49449137278965, 42.93989508492606, 26.275827169418335, 46.18819529669625, 48.20075838906424, 46.4352628162929, 9.548513276236397, 0.14028111685599598, 0.21246854402124882, 0.16274039527135237, 1.3026791044643946, 13.89829056603568, 13.861372181347438, 10.778584139687673, 14.968710933412824, 39.131156648908345, 59.737158230372835, 60.695453780038015, 59.11555848802839, 59.9836733681815, 52.53836243493216, 48.02619879586356, 52.88809653690883, 58.772039549691335, 53.97966200964791, 52.96205316271101, 55.14813014439174, 57.04067005429949, 49.14462947845459, 42.49778815678188, 47.70417063576834, 52.11949723107474, 53.445022446768625, 54.057992526463096, 49.1413950920105, 44.883809975215364, 41.558919770377024, 39.818166732788086, 40.47521618434361, 42.668283053806846, 48.81441286631993, 47.491295201437815, 47.054673876081196, 47.655911922454834, 47.53871318272182, 50.20515387398856, 54.084558963775635, 53.031705379486084, 49.895184312547954, 52.92624909537179, 53.763434069497244, 48.88962364196777, 45.066773414611816, 39.288922446114675, 41.91040481839861, 39.743226936885286, 45.962097440447124, 43.61752162660871, 49.615943159375874, 47.66505227770124, 53.124078205653596, 49.395355224609375, 59.34357752118792, 44.33469384057181, 42.08570786884853, 59.14303166525704, 51.116403170994346, 51.32812867845808, 42.81501858575003, 43.96713760920933, 39.88150303704398, 51.93987240110125, 56.23546763828823, 53.250177587781636, 52.602577686309814, 54.198172433035715, 51.766855307987754, 53.84110450744629, 52.005960191999165, 53.42436892645699, 51.897064549582346, 53.10143402644566, 52.874780314309255, 51.188761711120605, 47.09948975699288, 51.414355822971885, 52.72923987252371, 54.86571019036429, 51.32000970840454, 48.881160736083984, 51.86962958744594, 59.077426774161204, 53.449858392987935, 55.80037839072091, 53.40056439808437, 49.21578598022461, 45.319336959293906, 43.3016391481672, 40.77807079042707, 42.443234375544954, 43.46823263168335, 45.980253083365305, 47.815668378557476, 45.240196977342876, 47.11539765766689, 50.83720718111311, 57.57147421155657, 58.97469070979527, 58.6878273827689, 43.710339137486045, 24.731520550591604, 8.73003111566816, 14.11439517566136, 10.871914948735919, 14.939627511160714, 16.639235053743633, 0.9203597967113767, 0.2816259594900267, 0.17745237797498703, 0.6050631382635662, 21.940875598362513, 47.71346732548305, 37.62253597804478, 52.66810267312186, 36.44478504998343, 37.57292236600603, 41.5017534664699, 57.17006288255964, 57.96764312471662, 51.76355143955776, 3.7885335087776184, 0.2249231764248439, 0.1367892399430275, 0.10956241163824286, 0.19278503023087978, 0.16079232123281273, 0.09502129083765404, 0.155296458995768, 0.11612617942903723, 0.13067136465438775, 0.20126741006970406, 0.1789380439690181, 0.1380154070045267, 0.07915479437048946, 0.16278863911117825, 0.11464420466550759, 0.069620352770601, 0.09414838946291379, 0.1935761749212231, 0.13306538547788346, 0.10210974940231868, 0.22157138985182556], [0.037455594433205466, 0.027239751004214798, 0.03006269416904875, 0.013314318460678416, 0.04199979095054524, 0.08084220918161528, 0.037652620646570406, 0.029909908438899686, 0.05511142506397196, 0.037021033465862274, 0.01958077001784529, 0.01669528628034251, 0.014188074789542173, 0.06667869311890431, 0.019595426374248097, 0.033493085631302426, 0.008846841353390898, 0.04403928401214736, 0.05029916310948985, 0.01928073031428669, 12.842103583472115, 54.21003648212978, 54.4499751499721, 46.73721068246024, 35.64129536492484, 21.139489480427333, 17.423351424080984, 37.3457475389753, 40.15726661682129, 25.340099368776592, 0.9580052452428001, 0.02128111431375146, 0.09547274732696158, 0.318860867193767, 1.8239585842405046, 2.943398709808077, 4.07165219102587, 6.613624155521393, 24.815946374620708, 48.12264674050467, 57.75270407540457, 55.39063964571272, 53.503950119018555, 51.98148168836321, 49.028330530439106, 42.80776119232178, 45.33260454450335, 53.88164724622454, 52.52141925266811, 51.07298387799944, 52.630200249808176, 49.63378265925816, 40.807621479034424, 37.73553105763027, 42.832097257886616, 47.86923898969378, 48.66392183303833, 48.25470767702375, 46.94554546901158, 43.30021129335676, 36.88981022153582, 36.45508575439453, 35.894400869097026, 39.51962348393032, 43.14325148718697, 45.4464681489127, 44.73941946029663, 45.32375601359776, 44.82618509020124, 45.34260647637503, 48.73540142604283, 49.74947016579764, 48.72441632407052, 46.810305731637136, 48.65318686621529, 44.29410593850272, 38.501788820539204, 35.49535887581961, 36.06576429094587, 37.99724537985665, 43.59846271787371, 46.95907013756888, 49.291827065604075, 47.33553743362427, 50.346247468675884, 45.93317208971296, 57.391588824135916, 34.88628326143537, 34.05453872680664, 56.574254853384836, 44.95119707924979, 47.367975098746165, 36.83997426714216, 38.318717684064595, 33.385521003178184, 39.344591413225444, 41.48416757583618, 50.247840132032124, 47.75494112287249, 48.58181497028896, 49.305237088884624, 49.86730466570173, 49.144031933375764, 51.309875760759624, 51.261693477630615, 50.6186967577253, 48.111453192574636, 46.101203850337434, 45.52626126153128, 51.46642909731184, 50.91218866620745, 49.25043317249843, 44.799337250845774, 43.26659938267299, 44.14134284428188, 50.26550940104893, 49.02636766433716, 51.76070267813546, 49.74003103801182, 51.6184834752764, 44.32321541649954, 39.41409771783011, 38.34954684121268, 38.863362652914866, 40.43428782054356, 43.65985005242484, 45.4041953086853, 43.91644355228969, 39.718057087489534, 44.36785759244646, 52.401472500392366, 52.50550440379551, 54.222320897238596, 48.21539824349539, 30.02206482206072, 10.687791160174779, 7.565567748887198, 6.744415308747973, 13.829450419970922, 13.059869681085859, 4.753461982522692, 0.11901246383786201, 0.012930946175142058, 0.06289384514093399, 3.44572936637061, 31.030404772077286, 43.84489100319998, 38.488000120435444, 32.088174206869944, 23.590532541275024, 25.206200633730205, 38.09921366827828, 44.47308458600725, 42.53606925691877, 6.39999875000545, 0.24559553286858968, 0.05796658167881625, 0.07543566929442541, 0.02322810608893633, 0.07621453250093119, 0.019497992138245275, 0.046587644410984855, 0.01270837735916887, 0.02741567138582468, 0.07063088140317372, 0.04493755581123488, 0.04173927082281027, 0.019900293854464377, 0.001277937163000128, 0.05644896347075701, 0.022230545956907526, 0.007096030167303979, 0.06343124487570354, 0.034735992151711664, 0.0360330220178834, 0.01162649059135999, 0.050116230068462234, 0.0398643225032304, 0.029207227751612663, 0.06664656448577132, 0.09068384394049644, 0.02090930087225778, 0.012601441088398653, 0.051250045121248276, 0.01867445757878678, 0.031785582790949514, 0.03411507832684687, 0.03594238331009235, 0.02735497133939394, 0.02020405532260026, 0.01890546312954809, 0.011787927642996823, 0.026981134167207137, 0.023671314985092198, 0.03997504584757345, 0.01605180268441992, 18.129868575504847, 62.27156925201416, 60.59746333530971, 52.972392082214355, 38.75687803540911, 25.777908836092266, 19.131798812321254, 37.49873644965035, 41.01179082053048, 29.308634213038854, 0.739211411348411, 0.06674182401703936, 0.1332980144236769, 0.8540487949337278, 4.9490368366241455, 7.252094992569514, 5.4135304263659885, 4.074771497930799, 23.056613853999547, 49.89339862551008, 60.003100531441824, 56.973651204790386, 55.72681086403983, 54.45006547655378, 51.220421178000315, 44.84218679155622, 47.282738072531565, 55.220273290361675, 54.54308795928955, 52.459010532924104, 54.31609378542219, 52.036771978650776, 44.70351811817714, 39.54923323222569, 43.85323231560843, 48.36744219916207, 51.09918900898525, 49.44489935466221, 48.433554308755056, 44.770533493586946, 39.54037427902222, 38.302080222538535, 38.508073466164724, 42.74381692068917, 45.28312642233712, 47.42574937002999, 45.9173058782305, 46.342424460819785, 45.92781850269863, 47.05289166314261, 49.52170474188668, 50.60810422897339, 49.8859987940107, 49.34733622414725, 51.18864706584385, 44.98589290891375, 40.303553989955354, 36.31388793672834, 38.27419362749372, 39.345116002219065, 45.12462759017944, 46.562998499189106, 51.811771937779014, 49.065388747623985, 52.01119565963745, 48.56644902910505, 58.06869772502354, 36.13462093898228, 35.5858278955732, 57.15261942999703, 47.80001061303275, 47.85676349912371, 39.49918188367571, 40.20783560616629, 36.97071157182966, 41.287026337214876, 43.7147547176906, 51.40879726409912, 49.70859391348702, 51.77783693586077, 50.53857707977295, 50.98917123249599, 51.209314482552664, 52.79997600827898, 51.39773573194231, 51.601731368473594, 50.25987788609096, 48.22349636895316, 47.01103918892996, 51.89338547842843, 52.05032096590315, 49.720096656254356, 46.47671924318586, 44.59824596132551, 44.875218527657644, 50.44989027295794, 50.64247349330357, 54.10158552442278, 52.709371498652864, 53.10073225838797, 46.731971740722656, 40.5478526524135, 39.69850485665457, 39.36972999572754, 42.22604758398873, 45.75651066643851, 47.49487699781145, 46.24768924713135, 41.866992473602295, 44.393593720027376, 55.13775995799473, 55.981476238795686, 57.58086122785296, 50.0464118548802, 32.333459513528005, 9.96534526348114, 7.118061201913016, 7.112295065607343, 12.580838288579669, 10.45467301777431, 7.967111962182181, 1.0483402950423104, 0.06514378583856992, 0.05326859519949981, 3.7729022332600186, 32.18725551877703, 40.95606974193028, 48.36250550406319, 37.77415956769671, 28.382958718708583, 28.961090530667985, 44.24524620601109, 48.75866746902466, 52.60422788347517, 10.051417810576302, 0.2930619886943272, 0.05384732110958014, 0.08260008306907755, 0.03432605182752013, 0.058893704786896706, 0.03528580907732248, 0.05783862354499953, 0.05152825465691941, 0.019532699204449142, 0.01990195456892252, 0.055623149033635855, 0.067323362454772, 0.03280383315203445, 0.017881864216178656, 0.03139543533325195, 0.05991486606321164, 0.030530628881284168, 0.06575497625661747, 0.031190083495208194, 0.027662668310637985, 0.05638952041044831, 0.14507675809519632, 0.0984112721468721, 0.14567376034600393, 0.17479191002036842, 0.15765045982386383, 0.07347470309053149, 0.13897641615143844, 0.194399142903941, 0.14114635757037572, 0.1955409273505211, 0.11349450171525989, 0.09580038474606616, 0.12083637953868934, 0.19195032359233924, 0.12176597251423768, 0.13522284185247763, 0.07191846945456096, 0.12741909202720436, 0.2197690922766924, 0.0885412474828107, 24.57554391452244, 71.47107451302665, 67.98053577968052, 59.99992520468575, 46.17574759892055, 31.482861042022705, 26.64972710609436, 49.02959510258266, 52.3337345123291, 34.08757741110665, 1.5588169544935226, 0.1514722763427666, 0.18517911407564366, 1.0197156710284097, 7.325859240123203, 11.002547161919729, 13.039158838135855, 12.51893331323351, 28.637427806854248, 53.071855545043945, 63.09101894923619, 59.87405858721052, 58.315126010349815, 57.38955995014736, 52.9914926801409, 47.34423657826015, 47.95302731650216, 57.5523909841265, 55.702672822134836, 53.33895124707903, 56.82997982842581, 54.507068497794016, 45.62579768044608, 41.2883951323373, 47.11176722390311, 52.380808557782856, 54.5129188810076, 53.47406244277954, 50.926085063389365, 46.53538983208792, 41.67964472089495, 40.56457001822335, 41.10745014463152, 44.08627142224993, 47.70038039343697, 51.41023901530674, 48.21521064213344, 48.55435568945748, 49.28999968937465, 49.45000628062657, 52.78107343401228, 52.487258434295654, 50.38593210492815, 51.200928006853374, 53.46136460985456, 47.5799993787493, 42.40880952562605, 39.286494050707134, 39.92997714451381, 41.668117659432546, 46.10618570872715, 49.505418164389475, 53.682279109954834, 51.6383900642395, 53.18825871603829, 50.99386821474348, 60.245273045131135, 37.954889161246165, 38.48766313280378, 60.08533246176583, 50.39371756144932, 50.495567730494905, 42.293504170009065, 42.09169374193464, 38.16739286695208, 43.16044133050101, 45.30176496505737, 55.62988696779524, 51.62050887516567, 53.54547602789742, 51.34052079064505, 51.8196234021868, 53.74327039718628, 54.847683089120046, 53.58409411566598, 53.306190490722656, 52.780288287571494, 50.72974634170532, 50.233269759586875, 55.055972712380544, 55.05971084322248, 51.89224597385952, 45.61399963923863, 46.13090739931379, 44.567034653254915, 49.92538813182286, 51.65400266647339, 56.6355379649571, 54.54809413637434, 55.94359466007778, 49.21764809744698, 43.70579848970686, 41.88144472667149, 41.795082092285156, 44.58821971075875, 47.852677958352224, 50.15957369123186, 48.935433115277974, 43.14006921223232, 47.50530276979719, 57.78388064248221, 58.41987010410854, 59.895834241594585, 54.403460434504915, 34.62601069041661, 16.09749616895403, 15.73368501663208, 12.774751220430646, 29.06297891480582, 25.857352801731654, 8.944812961987086, 0.7725829035043716, 0.1561504631702389, 0.28724564079727444, 4.816121705940791, 42.417338439396445, 54.27860825402396, 42.173974309648784, 38.45304373332432, 35.848351682935444, 34.695760181971956, 51.88391855784825, 55.305725710732595, 62.377056803022114, 15.214779649462018, 0.6189021042415074, 0.13857842822160038, 0.22669909255845205, 0.18682203734559671, 0.1219653668148177, 0.2318015130502837, 0.09987219875412327, 0.1271778999694756, 0.1324758335415806, 0.1532723754644394, 0.1604458341108901, 0.1555694200630699, 0.09156479274055787, 0.12209879394088473, 0.15466633066534996, 0.19886190843369278, 0.10634172481617757, 0.1664913368544408, 0.1108818772648062, 0.14497743413916656, 0.13062160089612007], [0.056425540441913266, 0.0093393831380776, 0.01717377221211791, 0.07164511483694826, 0.07383996527642012, 0.10441414253520113, 0.023442706359284263, 0.01759200423423733, 0.039408099305416854, 0.051221943593450954, 0.04138468877811517, 0.05255696802799191, 0.022078230112258877, 0.010652729226941509, 0.05474792367645672, 0.027918101122070636, 0.050830696909023185, 0.039456573847149096, 0.01337850617710501, 0.7021081394382885, 27.288601807185582, 52.622942856379915, 55.58960478646414, 50.653576714651926, 35.409729276384624, 26.958287920270646, 31.401080744607107, 42.81851700374058, 39.56393214634487, 8.893971255847386, 0.06773330617163863, 0.055668437853455544, 0.05371238085042153, 0.22026983754975454, 6.070419200829097, 3.092339426279068, 2.2812727306570326, 6.2767685396330695, 34.30286734444754, 56.69946486609322, 56.10653339113508, 51.91100263595581, 52.892668451581685, 51.59960174560547, 47.346810885838096, 41.600998061043875, 45.14764697211129, 50.93193892070225, 52.09970528738839, 52.85703114100865, 51.61531509671892, 48.65237045288086, 38.10024547576904, 36.54153176716396, 41.87073407854353, 48.29954092843192, 50.80874388558524, 47.88263859067644, 47.988671575273784, 43.59140682220459, 37.50161647796631, 36.37650510243007, 36.139915466308594, 39.437332493918284, 44.64834247316633, 44.60019145693098, 47.772672925676616, 45.541536876133506, 45.09773806163243, 44.36988994053432, 49.215980529785156, 49.90937948226929, 48.800811767578125, 47.308293546949116, 50.297002111162456, 41.36397763660976, 37.93382569721767, 34.95879813602993, 37.18918725422451, 41.44176271983555, 48.208644594464985, 49.909841537475586, 52.53402328491211, 47.56202438899449, 52.788667815072195, 47.63520629065377, 54.4948605128697, 34.56630481992449, 32.44758020128523, 56.1842211995806, 45.312183788844514, 49.40276895250593, 41.10648781912667, 40.92116894040789, 36.72161865234375, 36.23846524102347, 37.29461921964373, 42.2937126159668, 48.139840057918, 48.835660457611084, 47.613524436950684, 50.679806164332796, 48.36209208624703, 49.9112937109811, 47.8128091948373, 51.41484914507185, 49.89241198131016, 47.916684763772146, 47.11559568132673, 50.073395184108186, 48.90594843455723, 45.56750576836722, 46.614901542663574, 49.57658856255667, 49.118538992745535, 49.94291843686785, 48.461378370012554, 51.75071464266096, 49.17278357914516, 52.035080092293875, 48.50958844593593, 41.45775399889265, 36.392336572919575, 39.23919766289847, 41.76058428628104, 46.72158418382917, 47.68134580339704, 45.02645301818848, 42.453903334481375, 40.00996133259365, 48.66033656256539, 53.55869844981602, 53.829608712877544, 50.18041828700474, 47.88833958762032, 27.262690237590245, 11.065993768828255, 6.932159977299826, 8.872678501265389, 4.471696027687617, 12.298916867801122, 1.4964666430439268, 0.04994817730039358, 0.06920173737619605, 0.3969248283122267, 15.644051517759051, 32.20975725991385, 12.78640421799251, 26.631706953048706, 44.13629150390625, 25.67603608540126, 28.572015728269303, 44.471517767224995, 39.90378590992519, 17.324992724827357, 0.2647306275154863, 0.03713358885475567, 0.07951451971062592, 0.09931365586817265, 0.012226959307944136, 0.06338129791298083, 0.08682485922638859, 0.032463564803557735, 0.03556501605947103, 0.015354799638901438, 0.02981389234108584, 0.06153857322143657, 0.024150771221944263, 0.022444104676001837, 0.012774656659790447, 0.01571183798036405, 0.03195958970380681, 0.055263759568333626, 0.05529011386845793, 0.05116029868700674, 0.09864337183535099, 0.030130537492888312, 0.03362612599240882, 0.027776597732944146, 0.017153965774923563, 0.046318164228328636, 0.08023811623986278, 0.02194923042718853, 0.06230387929826975, 0.021355525856571536, 0.027749573379488926, 0.03400914204706039, 0.04359935922548175, 0.0524114799419684, 0.04859503258817962, 0.03462740280000227, 0.01473950917300369, 0.07774889016790049, 0.0176946581008711, 0.025343389815783927, 0.9460078775882721, 35.089017799922395, 62.4535356249128, 61.97589560917446, 56.03466122491019, 42.045689719063894, 34.02850035258702, 35.42684268951416, 44.29639189583914, 43.988930634089876, 10.376566580363683, 0.01584274604517434, 0.12016216000275952, 0.04801786730864218, 1.7322350889444351, 4.6829642568315775, 5.8584874187197, 4.843627887112754, 7.4746818372181485, 37.36337511880057, 58.28191362108503, 59.478059904915945, 54.53532682146345, 55.22887863431658, 53.848476546151296, 49.80043520246233, 42.73717444283621, 46.9613595690046, 53.215037073407856, 55.108831133161274, 53.607057912009104, 53.92105048043387, 51.01386513028826, 40.45044585636684, 38.92410380499703, 44.01928383963448, 49.85471452985491, 51.953042711530415, 50.450352328164236, 50.58532108579363, 46.95924384253365, 39.367103576660156, 38.40259633745466, 38.65168578284127, 41.517529351370676, 47.45188501902989, 47.646900108882356, 49.09257704871041, 46.83884545734951, 47.04452950613839, 46.34331035614014, 51.05803830283028, 51.8052510534014, 50.061329637254985, 48.706295422145296, 50.78122207096645, 42.37974868501936, 39.25288561412266, 36.514541489737375, 39.19876956939697, 42.7686185155596, 50.548356669289724, 51.132790497371126, 52.9475349017552, 50.15327514920916, 54.255891118730815, 48.80322626658848, 55.75649356842041, 34.66466004507882, 35.44809028080532, 57.61830159596035, 47.60224403653826, 50.311450890132356, 43.27810559953962, 43.67912088121687, 37.4888595853533, 38.6293751171657, 38.94676188060215, 45.00955499921526, 49.172272886548726, 50.324457917894634, 48.83298192705427, 51.946928296770366, 49.696403299059185, 50.578310353415354, 48.82650968006679, 51.791761125837056, 53.339941365378245, 49.988988467625205, 48.246477535792756, 52.61658525466919, 49.66471603938511, 45.922197410038535, 47.80636821474348, 51.55265276772635, 49.53731039592198, 49.98676156997681, 48.0044926234654, 51.7411539213998, 51.716366222926546, 53.69696760177612, 50.51300770895821, 41.879641669137136, 39.51032332011631, 40.54809236526489, 44.32262134552002, 49.197234289986746, 50.18516738074166, 48.69509840011597, 43.81223794392177, 42.71711151940482, 50.36452470506941, 54.95207977294922, 54.814581871032715, 54.78829683576311, 49.360582964760916, 24.727245671408518, 8.74180223260607, 2.672066560813359, 6.31327394076756, 9.117391450064522, 5.662325876099723, 2.592021141733442, 0.3746476008423737, 0.020771317383540527, 0.3020668269268104, 17.390623671667917, 35.41836241313389, 13.378278698240008, 26.386036021368845, 44.25034965787615, 32.58620023727417, 35.66541951043265, 50.60179526465279, 48.35378551483154, 31.198321887425013, 0.5558684266039303, 0.10811586997338704, 0.04474891968337553, 0.0408673804652478, 0.030304520657019954, 0.01814125119043248, 0.04446546846468534, 0.0052923895169182545, 0.04295473399439028, 0.014794614698205675, 0.05017638559054051, 0.01139677086445902, 0.0112805488419586, 0.05889799991356475, 0.018404524474005615, 0.022544789094743983, 0.01466946569936616, 0.03526896105280944, 0.008892835849629981, 0.05027784014652882, 0.050805587720658095, 0.08793587889522314, 0.18086470344236918, 0.12613853359861033, 0.13079788429396494, 0.15321469998785428, 0.1802394198519843, 0.09420590887644462, 0.1489578562655619, 0.12419204733201436, 0.16582432336040906, 0.10978615177529198, 0.12579797687275068, 0.17792949665869984, 0.0921399529491152, 0.10490316272314106, 0.060263415931590965, 0.17514320117022308, 0.13953372410365514, 0.12538031142737183, 1.27474821465356, 44.02047198159354, 66.86783736092704, 70.25429207938058, 62.09197221483503, 48.69039446966988, 35.9602871622358, 43.357822281973704, 53.459238461085725, 51.28825296674456, 13.523039204733712, 0.20084051654807158, 0.2253824903496674, 0.13957894167729787, 1.670199292046683, 16.03761833054679, 11.133123789514814, 8.293034587587629, 9.841770683016096, 41.201111861637656, 60.84654235839844, 61.12127413068499, 57.29871572766985, 56.872120652879985, 56.03071812220982, 51.69974960599627, 45.73875107084002, 49.44249875204903, 55.678093569619314, 55.59040035520281, 55.31481742858887, 57.27262871606009, 52.94664553233555, 41.313738686697825, 39.99023192269461, 45.90690789903913, 52.96930013384138, 54.77435874938965, 53.18981163842337, 52.73275913511004, 49.10063695907593, 43.06791911806379, 40.3075978415353, 40.040641103472026, 44.258972372327534, 49.42847033909389, 48.78103024618966, 50.66582638876778, 49.65133033479963, 49.149583544049946, 48.86482204709734, 53.06322935649327, 53.68356105259487, 52.58997712816511, 50.866094316755024, 54.458024638039724, 44.314075061253135, 40.966922828129356, 36.64732503890991, 41.768275942121235, 45.21219226292202, 52.41499022075108, 53.79527766363961, 56.257587228502544, 52.12111268724714, 56.31560468673706, 50.03236607142857, 55.590619223458425, 37.05925594057356, 38.06112016950335, 59.858994892665315, 50.75513505935669, 53.33811746324812, 45.696884700230186, 45.888884271894185, 40.6338609286717, 40.974993160792756, 42.033196857997346, 47.38274002075195, 53.25716052736555, 52.83449813297817, 51.35517801557268, 53.54834910801479, 50.43791157858712, 51.04438509259905, 50.73393957955496, 53.35260098321097, 54.80341958999634, 52.25417069026402, 49.81784391403198, 53.91882010868618, 51.435356753213064, 47.22710384641375, 49.73492063794817, 53.83743238449097, 52.5425591468811, 52.96949815750122, 49.75693253108433, 51.918030738830566, 52.641835008348735, 55.63447972706386, 53.42099905014038, 44.21579279218401, 40.886625971112935, 43.33965621675764, 45.94280229296003, 50.77714000429426, 52.136190278189524, 50.90067202704293, 45.471596309116904, 43.99994700295584, 53.043975898197715, 57.58462367738996, 58.00633416857038, 57.14530645098005, 52.617377349308555, 33.42221791403634, 17.37724665233067, 14.900767973491124, 15.55437980379377, 15.25185523714338, 19.06188256399972, 3.617747438805444, 0.5224244669079781, 0.17186667770147324, 0.7102943116000721, 22.594716719218663, 44.933110918317524, 19.0954875264849, 34.79443155016218, 52.46806056158883, 37.92768348966326, 40.295084135872976, 57.543771743774414, 56.71007129124233, 41.86615521567208, 0.9269809957061494, 0.32515818785343853, 0.13283887691795826, 0.17691523608352455, 0.09963534253516368, 0.12217302567192487, 0.1900938789227179, 0.09040405002555676, 0.16316792661590235, 0.1014658332403217, 0.15057392311947687, 0.09167661531163113, 0.08121699121381555, 0.13544587631310734, 0.10666083983544793, 0.095113890511649, 0.12168336766106741, 0.10912906524858304, 0.15224138221570424, 0.1436311256672655, 0.14752141120178358], [0.013773064960592558, 0.047884701418557336, 0.08372307888099126, 0.06825528959078447, 0.04886399369154658, 0.04720128094777465, 0.05080842738971114, 0.03530787503612893, 0.03803169441276363, 0.013151316537654825, 0.009512921861772026, 0.03767193853855133, 0.033625159080007246, 0.05958493519574404, 0.09653110589299883, 0.028096547350287437, 0.040274374785700014, 0.014339326182380319, 0.08452275954186916, 2.406520741326468, 43.422951221466064, 54.33991568429129, 51.809329645974294, 34.79317045211792, 20.98528810909816, 13.44230808530535, 28.02180698939732, 37.46566302435738, 28.853886774608068, 3.0204535807882036, 0.0710430032174502, 0.06291274234120335, 0.025963720100532686, 0.9430584758520126, 2.9211725081716264, 6.664505813802991, 3.2810414263180325, 17.796539170401438, 49.770683016095845, 59.19643551962716, 57.5143461227417, 53.93680899483817, 53.60084622246878, 50.13097490583147, 48.68263333184378, 41.55944088527134, 42.56982707977295, 48.65583412987845, 53.29504905428205, 51.52735090255737, 52.568618365696494, 42.96017687661307, 39.36620031084333, 37.69602707454136, 41.55905873434884, 46.22547933033535, 49.48731810706002, 46.545426504952566, 50.61471891403198, 46.91701963969639, 40.24613755089896, 35.862800461905344, 35.76267344611031, 38.81227602277483, 47.30997153690883, 46.90154252733503, 46.161951950618196, 44.735247067042756, 45.648841381073, 43.91665199824742, 48.24227040154593, 48.31859636306763, 49.40521124431065, 47.56741966520037, 46.227859088352744, 37.54921163831438, 37.00059229987008, 34.40539148875645, 37.84600394112723, 46.58604914801461, 50.096907888139995, 50.45900978360857, 51.276878765651155, 45.8419874055045, 51.42966617856707, 46.69269009998867, 51.93149982179914, 30.232577868870326, 29.27450466156006, 55.483821937016074, 43.71303851263863, 47.37866490227835, 45.728262765066965, 46.708361761910574, 42.72062383379255, 38.71627276284354, 36.71855797086443, 37.966294629233225, 39.03536530903408, 47.43426786150251, 47.54451840264456, 47.74362250736782, 49.31996726989746, 47.88761350086757, 46.63328995023455, 48.30400167192732, 50.39891481399536, 49.29243155888149, 49.47884825297764, 50.55502693993704, 45.69274009977068, 47.95359012058803, 50.39777530942644, 47.19093499864851, 48.72201919555664, 50.473684379032676, 51.500346728733604, 50.02969101497105, 49.6006258555821, 50.014912196568076, 50.29153387887137, 39.53307172230312, 39.020124435424805, 38.467419556209016, 47.114063603537424, 51.09146956035069, 51.37540422167097, 48.23687859943935, 48.4960811478751, 41.704234395708355, 43.60512951442173, 51.238413538251606, 52.09245831625802, 52.91040372848511, 55.58106197629656, 48.11823116030012, 35.55344581604004, 11.379497357777186, 7.875131709235055, 6.531013982636588, 6.580368774277823, 1.94446553502764, 0.19557782608483518, 0.07475300878286362, 0.0674895763929401, 3.286862279687609, 30.945497785295757, 50.56162078039986, 39.95392411095755, 42.1336156981332, 20.42222693988255, 23.12744379043579, 41.71869707107544, 39.38700669152396, 36.686283588409424, 4.901961922645569, 0.3028113698320729, 0.08875708268689257, 0.034868896805814335, 0.04050332607169237, 0.07603636956108467, 0.014503460410716278, 0.03540266298555902, 0.019682036280365925, 0.03462755547038146, 0.025744604179635644, 0.0872690553909966, 0.05881791242531367, 0.018423155349280153, 0.0724134471799646, 0.035793760392282686, 0.017694868446726884, 0.005696026674870933, 0.021211589919403195, 0.009615468859140362, 0.04092735617554613, 0.04029791655817202, 0.07349672155188662, 0.03520973173103162, 0.06641710429851498, 0.06291430297174624, 0.04096771543845534, 0.019912946836224625, 0.03941413148173264, 0.038510214271289964, 0.015397859471184867, 0.01688675020289208, 0.035942264566464086, 0.019281256178926145, 0.05954723579010793, 0.042674953650150976, 0.012254108342209032, 0.06518248947603361, 0.01655791516947959, 0.048583684089992724, 3.6155782980578284, 53.01095111029488, 60.32504531315395, 56.13361052104405, 40.534494740622385, 27.33076000213623, 18.99738938467843, 25.461335011890956, 37.606291089739116, 35.2994509424482, 2.8087510892323087, 0.03811806174261229, 0.12144326125936848, 0.19236800260841846, 4.049710648400443, 6.227967866829463, 5.244147675377982, 2.672011192355837, 19.078163930347987, 48.69765881129673, 61.52940436771938, 58.61437797546387, 55.65424040385655, 54.79621778215681, 52.76685394559588, 50.28284168243408, 43.39081927708217, 43.81896727425711, 51.058597632816856, 54.76346397399902, 53.787249020167756, 53.70979050227574, 45.17694405147007, 40.814156259809224, 40.80341781888689, 44.42721952710833, 48.29961041041783, 51.605667522975374, 48.94750561032976, 52.87999493735177, 46.306804520743235, 41.38210548673357, 36.372673170907156, 37.81303126471383, 41.48912858963013, 48.04597684315273, 48.75309501375471, 48.502713203430176, 47.076546805245535, 48.65568821770804, 45.96093709128243, 49.476656096322195, 49.808557646615164, 50.67003352301461, 48.6873893737793, 48.77826138905117, 40.72907209396362, 38.54854324885777, 36.50686373029436, 41.161048548562185, 48.145631381443565, 52.561347075871055, 51.66134691238403, 54.38969257899693, 49.26976306097848, 52.88402141843523, 48.547473498753135, 51.613147258758545, 30.667941570281982, 30.955339908599854, 55.43650123051235, 45.819183417728965, 50.928496088300435, 48.02144275392805, 48.44237504686628, 45.10046522957938, 39.63188205446516, 36.51339156287057, 39.58769498552595, 41.61861869267055, 51.11502047947475, 49.498820849827354, 49.42636503492083, 51.88170208249773, 49.33723701749529, 47.47266360691616, 49.66061312811715, 51.35511548178536, 51.08707135064261, 51.31616735458374, 51.72835881369454, 45.54236371176583, 48.76422602789742, 50.51908390862601, 49.27363668169294, 48.33230863298689, 52.23141533987862, 51.982617718832834, 51.71747446060181, 51.33320433752877, 52.660640307835166, 52.28814043317522, 41.95433827808925, 40.4421775000436, 39.98187323978969, 49.39138432911464, 55.20829112189156, 52.99121822629656, 51.11235931941441, 49.14415005275181, 43.17849275044033, 46.362525599343435, 53.88641371045794, 53.617407253810335, 54.65338713782174, 57.81390380859375, 53.83550425938198, 32.710190841129844, 8.980193189212255, 2.2773856478078023, 8.305054971149989, 6.987331713948931, 5.988027027675083, 1.0591529948370797, 0.09793846894587789, 0.10629144537129573, 3.567535847425461, 35.16918611526489, 37.90038749149868, 36.52911533628191, 43.43741389683315, 23.91030601092747, 27.3949978351593, 47.42465155465262, 46.11637871606009, 46.53220408303397, 8.030398760523115, 0.2528047774519239, 0.035568741216723404, 0.026302154708121504, 0.042272517923265696, 0.017209118797576854, 0.036202109551855495, 0.010396436372372721, 0.017446974159351418, 0.022184656633596336, 0.027837258763611317, 0.046203654658581526, 0.038510835130832026, 0.012110230080517275, 0.1048493277547615, 0.015206856952447976, 0.02642994320818356, 0.030861438451600925, 0.026779661853132502, 0.06349833163299731, 0.050211530311831405, 0.1140765015568052, 0.13736831529864243, 0.12089128659239837, 0.1518917738326958, 0.32287049346736496, 0.0902624126257641, 0.1813342496752739, 0.1148713646190507, 0.13768458047083446, 0.1571998582886798, 0.08360609265842608, 0.1255472581833601, 0.12296243331262044, 0.17988048839781964, 0.14406237538371766, 0.06905699907136814, 0.14598078387124197, 0.21966919835124696, 0.18752103698040756, 5.801186493464878, 61.41274411337716, 68.83490017482212, 65.76842389787946, 47.3860890524728, 31.548934936523438, 20.203964914594376, 38.32806995936802, 46.97290400096348, 41.71010562351772, 4.330981109823499, 0.1298424798463072, 0.4313656916575772, 0.15048545572374547, 5.865265820707593, 9.829204865864344, 13.840295689446585, 9.28263177190508, 20.491622073309763, 52.626281465802876, 62.73702212742397, 61.23764950888497, 58.357155663626536, 58.282806464603965, 55.40250022070748, 53.17936502184187, 45.230122089385986, 45.68101501464844, 52.746196951184956, 58.76022066388811, 56.355112143925254, 57.53720917020525, 47.27887487411499, 41.902331011635916, 41.677970205034526, 46.558388369424, 51.24283954075405, 53.71132605416434, 50.436417715890066, 56.89119693211147, 50.13537311553955, 44.59655407496861, 38.23997374943325, 40.59167841502598, 43.92034843989781, 53.03754881450108, 51.682459013802664, 50.607253074645996, 48.40341649736677, 50.24834387642996, 48.23904643739973, 52.03323187146868, 51.67003216062273, 52.34981959206717, 51.38212660380772, 51.325526578085764, 41.945111070360454, 41.392715385981965, 38.99971062796456, 43.11214092799595, 51.7204760823931, 54.05009242466518, 53.48262957164219, 55.30436733790806, 48.81402724129813, 51.072344643729075, 50.70475714547293, 52.17633696964809, 33.02633040291922, 34.67967162813459, 57.89770950589861, 47.99501528058733, 51.91197885785784, 50.92478922435215, 50.735468183244976, 48.01274013519287, 41.90861218316214, 40.10615219388689, 42.35398129054478, 42.82024710518973, 52.467740944453645, 51.380417346954346, 51.18851852416992, 54.41201366697039, 49.16766970498221, 48.67090824672154, 50.194537026541575, 52.961577211107524, 51.75695759909493, 53.872486046382356, 53.39827149254935, 47.27290289742606, 49.36649588176182, 53.71913235528128, 50.37603439603533, 51.89739806311471, 54.08244671140398, 54.030175413404194, 52.75796719959804, 53.130859647478374, 54.3237750189645, 54.816965103149414, 43.891662802015034, 41.85703223092215, 42.24629463468279, 51.87710584912981, 55.173161029815674, 55.26491894040789, 53.739681652614046, 52.284746238163535, 45.67886802128383, 49.052232333592, 56.323105267116, 57.93856143951416, 57.04671498707363, 60.817825453622, 53.093346323285786, 46.17644589287894, 19.538489035197667, 13.785873055458069, 14.21191314288548, 16.560699565070017, 6.874900306974139, 0.47719820801700863, 0.27547417102115496, 0.20842420389609678, 5.161732052053724, 44.058228492736816, 66.21806962149483, 47.97744676045009, 47.18962526321411, 31.281835760389054, 33.74915150233677, 57.042688505990164, 53.7025192124503, 55.436480385916575, 11.027750883783613, 0.32078774379832403, 0.12959224970213004, 0.061710934686873636, 0.08485244613673006, 0.23257737713200705, 0.08750498201698065, 0.1512676708932434, 0.13673982902296952, 0.12701897349740776, 0.12634999225182192, 0.15247432328760624, 0.18698105881256716, 0.081375503779522, 0.18539639455931528, 0.10919659305363894, 0.08286531562251703, 0.13728735250021729, 0.13953468762338161, 0.12637418881058693, 0.16335231172186987], [0.014914949491087879, 0.052122305280395916, 0.025768626015633345, 0.05757146395210709, 0.0263982963349138, 0.02443611216066139, 0.02026870783551463, 0.005924664562501545, 0.025294910185039043, 0.006193854247352907, 0.044526143066052876, 0.012103010467918856, 0.03042121510952711, 0.02358056092634797, 0.10313154850155115, 0.04958710167557001, 0.039970041651810916, 0.012061784376523324, 0.1399235153304679, 10.60122355393001, 53.42592184884207, 52.340074743543354, 48.643549714769634, 31.722678116389684, 23.572269201278687, 29.045417342867168, 51.59220886230469, 43.471849169049946, 18.051682233810425, 0.14293295384517737, 0.03212244150095752, 0.017619523918256164, 0.547854656619685, 1.847729457276208, 2.7752475270203183, 3.2191375366279056, 9.369353107043676, 33.5900342805045, 54.71101202283587, 56.46794046674456, 52.6362556048802, 53.81337424686977, 50.679670674460276, 49.935299737112864, 48.077389648982454, 43.902672222682405, 39.58493307658604, 43.5418244770595, 48.15057849884033, 49.391196727752686, 41.97385924203055, 38.64411572047642, 37.84740400314331, 38.57031890324184, 44.279980250767295, 47.419614110674175, 50.71976178033011, 49.440039089747835, 48.67043924331665, 49.22188997268677, 42.953520502362935, 37.36313888004848, 35.497043813977925, 37.87057277134487, 44.50162778581892, 45.43284273147583, 46.89535168239048, 46.52118076596941, 46.21478605270386, 42.80224779673985, 45.795156547001426, 48.28597457068307, 49.80327354158674, 47.92149986539568, 43.39875064577375, 34.61015837533133, 36.26121016911098, 35.32541983468192, 41.598475864955354, 47.151417119162424, 50.9309800692967, 47.773725577763145, 48.395342690604075, 49.96022292545864, 51.56905051640102, 42.99859346662249, 52.45872218268258, 28.485941444124492, 26.516801118850708, 55.67814220700945, 45.637449809483115, 52.450651850019185, 46.03172186442784, 51.83510398864746, 46.436433587755474, 48.77176134926932, 36.86971255711147, 36.711536816188264, 36.218628134046284, 40.96283728735787, 46.96416664123535, 49.57617514474051, 48.631956645420615, 50.949813161577495, 48.34320688247681, 47.30443729673113, 45.99382291521345, 47.66653919219971, 49.99080542155674, 47.74287557601929, 45.64124700001308, 51.60870735985892, 48.25327287401472, 46.82745041166033, 46.53726584570748, 48.53863539014544, 48.381012031010215, 51.18800435747419, 52.28205728530884, 50.52179370607649, 47.45765202386038, 39.54126017434256, 36.82800946916853, 41.88895225524902, 46.470882756369456, 52.60824394226074, 49.61303186416626, 51.916710581098286, 47.61592503956386, 47.98469025748116, 38.733010973249165, 45.598109109061106, 48.40786681856428, 51.1449567931039, 51.26148503167288, 55.24420288630894, 47.443126814705984, 19.72456874166216, 5.256609703813281, 8.474618809563772, 2.6207347895417894, 3.2317906405244554, 0.9798238916056496, 0.035891391403440914, 0.0463532241327422, 0.48728351827178684, 15.892279386520386, 31.04490566253662, 32.692716121673584, 32.409073284694124, 29.22226115635463, 26.76925870350429, 40.27805062702724, 44.88006142207554, 43.90226575306484, 16.23225995472499, 0.08885608773146357, 0.08124616821961743, 0.07730829023889133, 0.03286394117666142, 0.02587549188839538, 0.04993559726114784, 0.029603414170976197, 0.015779576131275723, 0.04625620041042566, 0.03231289949534195, 0.03265633999503084, 0.033886686832244904, 0.02116254880093038, 0.024645136569493582, 0.004543865731518183, 0.005547310034411826, 0.06432022753038577, 0.02041599912835019, 0.014056585729122162, 0.01826386246830225, 0.04206795318584357, 0.10625422094017267, 0.03544780931302479, 0.07279804761388473, 0.05374149339539664, 0.07657124514558486, 0.028491495443241935, 0.05066886630707553, 0.06037869903125933, 0.020075723994523287, 0.04900045386914696, 0.021399152265595536, 0.01872475229070655, 0.0158481403985726, 0.03126977404047336, 0.06911880682621684, 0.05152040061407855, 0.030306858210159198, 0.13802103884518147, 14.65665170124599, 61.92589637211391, 57.67866407121931, 56.26170751026699, 36.72493641717093, 28.687348876680645, 24.675274882997783, 42.885851996285574, 50.72375699451992, 20.540500913347515, 0.20311227893190725, 0.06089444671358381, 0.017254592518189123, 1.964057283742087, 4.1478873917034695, 5.409346742289407, 2.0936568209103177, 10.727190051759992, 35.43694537026541, 56.55376461574009, 58.35307012285505, 55.19022233145577, 56.09987701688494, 53.70242888586861, 51.78976699284145, 51.44195406777518, 46.04988445554461, 40.37865359442574, 46.99465881075178, 49.596991947719026, 52.085930483681814, 44.48593875340053, 40.15099934169224, 40.345409938267295, 40.634687764304026, 46.71336446489607, 49.73730387006487, 51.54728528431484, 50.58691917146955, 51.59623186928885, 51.58057410376412, 45.570837429591585, 38.74681009565081, 37.654619285038535, 39.68644625799996, 46.474224839891704, 46.91026946476528, 48.82417161124093, 48.10529014042446, 47.92104128428868, 45.05045209612165, 48.256003516060964, 50.308810574667795, 52.60968916756766, 50.75376973833357, 45.64621148790632, 36.245948450905935, 39.00664145605904, 37.500275475638254, 43.74925947189331, 50.066825662340435, 52.064408438546316, 48.26801347732544, 49.64302723748343, 49.68179471152169, 51.98292343957083, 43.59841060638428, 52.892578125, 29.55468382154192, 27.627010345458984, 56.17325346810477, 47.0722701890128, 52.56182302747454, 48.26396267754691, 52.452771050589426, 49.93997587476458, 50.53235149383545, 38.16208791732788, 39.23025185721261, 38.5609701020377, 42.274174281529014, 48.16471113477434, 51.139634472983225, 51.96809250967843, 52.07782541002546, 49.37380191258022, 47.36842325755528, 47.93239116668701, 50.24475165775844, 50.616959708077566, 47.1438262122018, 45.83746760232108, 52.902597427368164, 50.1919071333749, 49.723553385053364, 49.73814112799508, 49.17891536440168, 50.564136028289795, 52.2363555090768, 53.16070563452584, 51.15135260990688, 49.212568964277, 41.0854035105024, 39.10577140535627, 42.182944434029714, 49.892603056771414, 54.6185245513916, 51.721184798649375, 53.56378105708531, 50.65902410234724, 50.36272512163435, 41.865790435246055, 47.30400998251778, 50.040533678872244, 53.78451142992292, 53.392111914498464, 56.603211471012656, 50.77352694102696, 23.58563927241734, 3.5970507093838284, 1.8468296655586787, 4.0059191925185065, 7.137041509151459, 3.5080599188804626, 0.1369339714625052, 0.05987062557999577, 0.26028190766062054, 20.207812479564122, 33.61050019945417, 33.569040298461914, 36.86114195414952, 30.202335834503174, 34.085249764578684, 46.62685939243862, 51.108711515154155, 53.38343014035906, 21.768862519945415, 0.09337399101683072, 0.020304446274946843, 0.038376135751605034, 0.06767589532371078, 0.03898258660254734, 0.04082849023065396, 0.04036565810175879, 0.005918818135147116, 0.061530627576368194, 0.02226292564799743, 0.05645553508241262, 0.031919043843767474, 0.039111966267228127, 0.017584811763039658, 0.03360451125938978, 0.07493035069533757, 0.03046922485477158, 0.006398557236285082, 0.04317549875538264, 0.03536528927673187, 0.10929312823074204, 0.1556614836944001, 0.1181552976902042, 0.15987054498067924, 0.2952583794082914, 0.18105934799781867, 0.06490096529679638, 0.10305696393230132, 0.16379833993102821, 0.127731340272086, 0.23167571265782627, 0.08538882806897163, 0.16377118495958193, 0.1277620100549289, 0.232215337987457, 0.2632720214979989, 0.13202093009437832, 0.11723752479468073, 0.2688205380524908, 19.893753903252737, 71.38922473362514, 63.805391039167134, 63.28208746228899, 43.82207659312657, 33.50377239499773, 39.95307295663016, 64.36035060882568, 53.42218024390084, 26.61735371180943, 0.2790615042405469, 0.11828834483666079, 0.08961410634219646, 1.7579157395022256, 6.320416254656656, 10.474603056907654, 9.767856614930288, 15.8835837159838, 38.48994909014021, 56.781557832445415, 61.287037304469514, 56.296511037009104, 57.95555673326765, 54.7793927192688, 53.98148938587734, 53.68200118201119, 48.73038135256086, 42.70656762804304, 48.03240006310599, 52.755559648786274, 54.130135672433035, 45.75803927012852, 41.2490405355181, 42.534759521484375, 43.58564329147339, 49.837500367845806, 51.007198333740234, 54.9195031438555, 54.110482692718506, 52.9397737639291, 53.54324565614973, 48.16192143304007, 40.97149126870291, 39.349486419132774, 42.43782867704119, 48.87630047116961, 48.68988030297415, 50.85030106135777, 51.23368876320975, 50.047412395477295, 46.973953178950715, 50.139295373644146, 52.16388579777309, 56.01562316077096, 53.30574580601284, 48.07750429425921, 38.77607243401663, 40.44968155452183, 39.59371559960501, 45.94234718595232, 51.83481216430664, 54.527767181396484, 50.59154667173113, 50.764271940503804, 52.818003109523225, 55.04482780184065, 44.16548783438546, 52.442494664873394, 30.426536832536968, 30.492947714669363, 57.13388361249651, 49.25736747469221, 55.05338798250471, 49.40958513532366, 54.867593152182444, 51.88704177311489, 53.18584074292864, 41.107609953199116, 42.09884691238403, 40.01601321356637, 43.48559617996216, 50.73400558744158, 52.431731905256, 54.50496319362095, 54.25291728973389, 51.49691431862967, 48.14081975391933, 48.64758314405169, 50.25435406821114, 53.76680394581386, 48.22603246143886, 46.46898242405483, 55.993652956826345, 53.78270489828927, 52.12595905576433, 51.693676880427766, 51.92193215233939, 54.01648746218, 55.63725553240095, 57.43491779054914, 53.5825411932809, 52.740624495915, 43.69289221082415, 40.805168764931814, 44.08779307774135, 50.738376004355295, 57.65257011141096, 52.53412055969238, 56.712656021118164, 51.65209191186087, 52.53236961364746, 43.99520833151681, 49.78249495370047, 52.812903131757466, 57.484406335013254, 56.625994614192415, 60.28598254067557, 52.865424564906526, 23.7615224974496, 11.688784258706228, 17.584893567221506, 8.151193193026952, 9.865452749388558, 3.936057661260877, 0.1941967359078782, 0.2922690526715347, 0.6937363743782043, 25.178447791508265, 45.89134393419538, 43.2874231338501, 39.06894942692348, 39.674992152622764, 39.73894337245396, 51.69278056280953, 58.17582157679966, 59.62314523969378, 27.792634555271693, 0.25483742409518784, 0.13715543172189168, 0.13102057948708534, 0.15741370538515703, 0.11828184447118215, 0.17705567926168442, 0.14774057801280702, 0.11913343306098666, 0.17455328282501015, 0.12999212395931992, 0.16015136348349707, 0.09946021943220071, 0.14139289648405143, 0.10283322379525218, 0.0635476882702538, 0.27605605551174706, 0.10289075677948338, 0.09838312651429858, 0.13259779342583247, 0.15883063578179904], [0.03380729823506304, 0.019646849150636365, 0.035613287040697675, 0.0477369198841708, 0.012154909915157726, 0.06697030711386885, 0.05619244669963207, 0.003162705368595198, 0.07781267924500362, 0.07766661101153918, 0.0846432741465313, 0.03399021092004009, 0.06542221589812211, 0.0323639796115458, 0.025115213756050383, 0.012099543153973562, 0.019248335356158868, 0.09700878776077713, 0.10192715562880039, 23.941869940076554, 53.45187337057931, 48.65942982264927, 43.805678844451904, 30.397677489689418, 14.089663062776838, 33.02185923712594, 47.56439025061471, 30.48518657684326, 9.106527073042733, 0.025275359894814234, 0.1366862111857959, 0.12724861688911915, 0.7910949672971452, 3.5045725745814185, 6.620581039360591, 1.4136116547243935, 22.790972062519618, 47.74534913471767, 55.59443725858416, 51.83229691641671, 53.7165858404977, 53.895981379917686, 52.86197131020682, 48.92734888621739, 46.35863808223179, 43.31380891799927, 40.191931179591585, 38.47210611615862, 39.94839334487915, 38.689852237701416, 37.16407299041748, 37.07661254065377, 40.989243916102815, 42.985273769923616, 47.36137778418404, 48.47298533575875, 50.15249000276838, 46.88507877077375, 50.26332071849278, 48.2011718068804, 47.722173418317524, 36.377870423453196, 35.85969114303589, 35.71766996383667, 40.80953918184553, 44.36940009253365, 43.16749375207083, 43.70141765049526, 42.87501628058297, 40.86763654436384, 41.391669682094026, 41.01729726791382, 42.4509607723781, 37.85820150375366, 35.66428000586373, 34.87280723026821, 37.120504311152864, 36.30703353881836, 40.58071068355015, 48.31564685276577, 50.96268817356655, 47.95756796428135, 50.959898471832275, 49.55008813313076, 51.546493189675466, 45.90343032564436, 51.511797360011506, 28.56848430633545, 23.905463116509573, 51.24037987845284, 43.118540218898225, 48.22691488265991, 46.17491034099034, 48.74001155580793, 47.19068833759853, 51.27015290941511, 42.751849038260325, 35.646937302180696, 36.17244345801217, 37.516106946127756, 36.22239405768258, 42.9769845690046, 44.966364996773855, 49.11566243852888, 48.229103565216064, 50.52784211294991, 45.56930882590157, 47.079437255859375, 45.77018124716622, 45.81300299508231, 49.436703954424175, 49.66596671513149, 46.72523546218872, 44.308391434805735, 40.21888671602522, 43.66220201764788, 45.9960150718689, 50.16691446304321, 47.88509130477905, 51.110469409397666, 44.28033808299473, 37.341564723423545, 37.619899136679514, 39.20918491908482, 48.939925125667024, 52.54042952401297, 50.23331144877842, 52.439527784075054, 51.54786198479788, 49.368368421282085, 46.20308528627668, 41.25951841899327, 41.41663455963135, 45.43028579439436, 49.01661934171404, 53.141083921704976, 52.58512381144932, 50.86819614682879, 18.210538898195537, 6.271816645349775, 3.7460418002946034, 9.227432676724025, 3.4039689557892934, 0.24706559255719185, 0.011147306616684156, 0.006157562801880496, 7.185962038380759, 35.42763825825283, 35.05282115936279, 13.946865422385079, 20.229499544416154, 18.094622101102555, 32.01922375815255, 45.64211205073765, 40.023781299591064, 30.67428527559553, 1.136811490569796, 0.029176642785647085, 0.03808191618216889, 0.050429455403770716, 0.007291305760320808, 0.03738210569801075, 0.027658661561352865, 0.05275696961741362, 0.05421112444517868, 0.04659585129203541, 0.008678204197037433, 0.04957492197198527, 0.033636198844760656, 0.06077266324843679, 0.02424001893294709, 0.08091575559228659, 0.06755161484969513, 0.044485848263970444, 0.05368611475984965, 0.06126577500253916, 0.01325961496747498, 0.06393039559147187, 0.020345115967627083, 0.01688899445746626, 0.015139865190056818, 0.03912053616451366, 0.027766431582027247, 0.03424139101324337, 0.07901988803808178, 0.050527781913323064, 0.04728779076997723, 0.041458343754389455, 0.009211042480144118, 0.017041551182046533, 0.04681458044797182, 0.06847548777503626, 0.04635137512481638, 0.06950777024030685, 0.16251448382224354, 29.418082237243652, 61.382832118443076, 54.82607419150216, 49.07552964346749, 36.04640313557216, 18.68203149523054, 34.06328650883266, 51.02763645989554, 34.058460984911235, 10.504052128110613, 0.021704949338787367, 0.29613420526896206, 0.33899750666958944, 2.501207534755979, 7.539919342313494, 6.861736944743565, 6.090547263622284, 24.78881365912301, 50.153323786599294, 54.24050433295113, 55.50159542901175, 55.435511112213135, 56.90956449508667, 53.76634883880615, 51.333888735089985, 48.599046502794536, 45.112819126674104, 42.36042921883719, 41.4135981968471, 41.73043257849557, 40.05171305792672, 39.523333821977886, 39.44597257886614, 42.364490440913606, 46.60406582696097, 48.00214760644095, 50.48547199794224, 51.527385643550325, 47.52378845214844, 50.732209478105815, 51.675642830984934, 49.188229424612864, 39.652622427259175, 38.231535162244526, 38.69708183833531, 42.202607836042134, 47.03174482073103, 44.58752836499895, 45.98881673812866, 46.06434713091169, 41.69762665884835, 43.214824880872456, 42.519984177180696, 44.763217040470664, 40.95799786703927, 37.437863281794954, 35.97101518086025, 39.565898486546104, 38.15911408833095, 42.974545751299175, 49.23229142597744, 52.92198984963553, 49.497785568237305, 51.88076407568795, 51.16522816249302, 53.14608315059117, 47.80928298405239, 53.33515058244978, 29.724362305232457, 24.6354113306318, 50.92291668483189, 44.88220146724156, 49.62562200001308, 46.97622871398926, 51.28649854660034, 48.929791178022114, 52.746957778930664, 44.7675700868879, 37.83196857997349, 38.87604658944266, 39.215056146894185, 39.73284632819039, 43.73293467930385, 47.470686844417024, 50.379564080919536, 49.37472602299282, 50.75737585340227, 46.03862142562866, 45.846969263894216, 47.42278596333095, 45.21326575960432, 50.75898436137608, 52.60096917833601, 48.72034467969622, 47.35629170281546, 42.4909337588719, 46.32099969046456, 47.19740377153669, 51.62225982121059, 50.38515738078526, 52.85541568483625, 45.881665093558176, 39.31882749285017, 39.89085183824812, 41.3278226852417, 50.23053911754063, 53.610882895333425, 52.60418619428362, 53.070733410971506, 52.716694899967735, 52.5222704069955, 49.02299083982195, 42.862947259630474, 44.15271357127598, 48.94174902779715, 51.641068594796316, 56.8556673186166, 54.72545732770647, 51.446265425000874, 20.995019061224802, 3.957901929106031, 1.829989186355046, 7.900608147893633, 8.609741296086993, 0.959381639957428, 0.07498903040375028, 0.07380098343959876, 8.183239153453282, 36.00651005336216, 28.616541521889822, 20.834263801574707, 23.82946719442095, 24.52768645967756, 38.33910717282976, 50.40975400379726, 46.73960086277553, 39.60527740206037, 1.7260995038918086, 0.0967246580070683, 0.029025366795914512, 0.06289516149887017, 0.04451184294053486, 0.019105671672150493, 0.03470521380326577, 0.07562802718686205, 0.03487341245636344, 0.06516718172601291, 0.005964231635776481, 0.03335572300212724, 0.006356329457568271, 0.052615807192134004, 0.05571567067610366, 0.038102428295782635, 0.04488029084833605, 0.03472874879038759, 0.043461311275937727, 0.058317866043320725, 0.11754207845245089, 0.12589366388108048, 0.18364528566598892, 0.15229111883257115, 0.08536262304655143, 0.14819962052362307, 0.16699487769177981, 0.07292870631707565, 0.14310755447617599, 0.22408457499529633, 0.28430359438061714, 0.1777943189122847, 0.10181452560105494, 0.13630178038563046, 0.11641303689352103, 0.17474906731929096, 0.13768156777535165, 0.17663371190428734, 0.5610382120524133, 37.86859948294503, 67.72715582166398, 63.80117348262242, 57.63007531847273, 45.18801948002407, 22.800675221851893, 41.64162417820522, 55.89767401559012, 43.44314268657139, 12.726271033287048, 0.11047293777976717, 0.4017244321959359, 0.22552384276475224, 3.377393616097314, 11.712316938808986, 14.293046389307294, 6.775932771818979, 28.600536346435547, 49.91416679109846, 56.582245281764436, 56.35446943555559, 57.737424986703054, 59.28105068206787, 57.731216771262034, 53.740435532161165, 50.090244565691265, 48.39343541009085, 43.43070193699428, 42.198525769369944, 42.86760950088501, 42.057585035051616, 41.0877936908177, 41.20696224485125, 45.57400580814907, 47.815102100372314, 50.48943941933768, 52.74473088128226, 53.62559223175049, 50.26497786385672, 53.005792072841096, 53.44456039156233, 52.01324537822178, 40.20172813960484, 39.259055614471436, 40.592289856501985, 44.14017902101789, 49.02058676310948, 46.34268501826695, 47.72220121111189, 47.465416635785786, 45.416622161865234, 45.09617819104876, 43.89041212626866, 45.89798641204834, 42.91414853504726, 40.045494420187815, 38.84070805140904, 40.635243620191304, 39.67927919115339, 44.60598625455584, 52.024421555655344, 53.38060917173113, 52.62344660077776, 54.62854732785906, 53.204795428684776, 54.85095569065639, 50.36999641145979, 53.577232769557405, 31.793570586613246, 27.487471410206386, 50.68391949789864, 46.53790855407715, 51.31163018090384, 49.41380269186837, 50.31550516401018, 51.081175804138184, 54.13542325156075, 47.22646113804409, 38.727101530347554, 40.936705112457275, 41.43162529809134, 41.42175190789359, 46.27889360700335, 48.67422948564802, 53.39664213997977, 52.69845240456717, 53.81218957901001, 47.648838656289236, 48.360414096287315, 46.99217830385481, 46.80449703761509, 53.15959392275129, 55.23857137135097, 50.752918584006174, 50.51304244995117, 44.764186314174104, 47.8780632019043, 48.98845134462629, 54.89181457247053, 51.32359845297677, 54.84778036390032, 48.065317153930664, 41.835110664367676, 42.09038053240095, 42.614010674612864, 52.91423913410732, 56.05751037597656, 53.97496850149972, 55.81322908401489, 55.61144297463553, 54.5709502356393, 51.58688654218401, 45.16993679319109, 45.06825338091169, 51.76794964926583, 54.3484445980617, 59.21741907937186, 58.08855220249721, 55.43079675946917, 22.59644855771746, 10.249562195369176, 11.09034286226545, 19.7215028490339, 11.455098969595772, 0.6106924276266779, 0.1843049166990178, 0.23733618749039515, 9.956957050732203, 48.109472955976216, 47.418884549822124, 21.760248490742274, 28.05378086226327, 29.31875079018729, 44.10991614205496, 58.075604234422954, 53.7975948878697, 50.19640956606184, 2.973130485841206, 0.2416867640401636, 0.13535082712769508, 0.2469790114888123, 0.13085716111319406, 0.18875438294240407, 0.1510279987539564, 0.13871606226478303, 0.10489015520683356, 0.17223898986620562, 0.04226586149473276, 0.08878020037497793, 0.13305751447166714, 0.21162219372178825, 0.15858849377504416, 0.15264318351234707, 0.17822817420320852, 0.12504233313458307, 0.11772915055709225, 0.19829218329063483], [0.039634373770760636, 0.06262875507984843, 0.07271107299519436, 0.028713298362812827, 0.040088235666709285, 0.00833183666691184, 0.016265578534720198, 0.033828865470630784, 0.013540933889869069, 0.06469011732510158, 0.03391257294320634, 0.030461530267660106, 0.09285196010023355, 0.037280827561127286, 0.04277884753953133, 0.0197087060992739, 0.0064819038130476, 0.025583874500755752, 1.1203169013772691, 34.88116938727242, 54.21938180923462, 49.778075899396626, 32.93394020625523, 19.935656751905167, 18.15642806461879, 34.83989708764212, 42.46159151622227, 31.252160004207067, 2.3064812294074466, 0.05313054724995579, 0.028884859156927893, 0.4515539812190192, 2.7682960714612688, 4.702404882226672, 4.694377975804465, 7.554210049765451, 35.38333306993757, 53.36650432859148, 54.770266260419575, 46.30701296670096, 51.37194749287197, 52.24875456946236, 50.522922788347515, 48.5356685093471, 43.37115240097046, 41.006986141204834, 41.121249267033164, 39.49111155101231, 38.871954100472585, 36.324720178331646, 36.90590919767107, 39.7895644732884, 44.71984985896519, 47.99036693572998, 49.691223417009624, 52.45629726137434, 56.80951043537685, 46.766820430755615, 47.41712665557861, 48.60229131153652, 50.40876735959734, 39.2756861277989, 36.984667028699604, 35.94928468976702, 35.45421164376395, 37.88664395468575, 38.132026536124094, 36.2289114679609, 37.131232329777305, 37.170910017830984, 37.05427060808454, 36.48701272691999, 37.16835308074951, 34.75327042170933, 36.00522116252354, 36.82065480095999, 36.217488629477366, 36.59845488412039, 38.16328648158482, 43.61918919427054, 51.40076862062727, 46.95291403361729, 49.18211153575352, 44.96142830167498, 50.08562053952898, 47.53452689307076, 56.87475054604666, 32.90921156747, 19.113304444721766, 49.88624892915998, 41.52260153634207, 48.79427351270403, 44.09977872031075, 48.729592732020784, 45.03293916157314, 49.610342911311555, 44.3662143434797, 38.84287241527012, 35.32564565113613, 38.934269019535606, 35.79285294669015, 37.96551295689174, 36.009324073791504, 44.92980704988752, 48.42158951078142, 48.42951045717512, 47.86317321232387, 47.28025756563459, 44.49986294337681, 48.25452702386038, 48.16000720432827, 47.68380546569824, 45.18020623070853, 42.14113017490932, 37.90672424861363, 37.36420542853219, 37.62562097821917, 45.596691676548545, 45.24891349247524, 46.322128772735596, 40.377507141658235, 37.73706660951887, 38.43482903071812, 38.826307909829275, 43.47486468723842, 49.304045472826274, 48.84069095339094, 50.91784449986049, 50.8160012790135, 52.50561557497297, 48.65093217577253, 47.8116523197719, 42.92213896342686, 43.624108518872944, 45.07720266069685, 50.107448305402485, 50.032379967825754, 54.05578299931118, 36.028824193137034, 13.262074419430324, 2.056106367281505, 7.038891690117972, 4.91887948342732, 1.1697846012456077, 0.2667914197913238, 0.04410192297239389, 1.529958045908383, 18.532643488475255, 34.51707335880825, 29.143642289297922, 20.054491792406353, 22.021604980741227, 32.351337228502544, 43.52970681871687, 43.74774476460048, 41.211068630218506, 9.118179202079773, 0.29830312888537136, 0.06955159003181116, 0.07339224072971515, 0.026685996879158274, 0.042156115240816555, 0.01530957527990852, 0.08580092274184738, 0.025202897443835224, 0.037768887622015815, 0.03961017381932054, 0.06087127474269696, 0.05926082615873643, 0.032830686175397465, 0.04656624680917178, 0.019859203470072577, 0.033104302028992345, 0.06717117383543934, 0.045697501461420736, 0.07703672695372786, 0.008651823603681155, 0.03623753247250404, 0.02253129642589816, 0.015156799727784736, 0.020592640453417386, 0.03150744450145534, 0.05102066635819418, 0.019821319163643887, 0.023760691617748568, 0.023165582479642968, 0.002004189520708418, 0.03124276834673115, 0.03896546716402684, 0.02200660734836544, 0.06686122582427093, 0.08632547780871391, 0.04277003676231418, 0.011553214746527374, 2.1225022673606873, 42.88033512660435, 60.61889157976423, 57.15061487470354, 39.375180857522146, 26.78857295853751, 22.59170467512948, 31.349577222551616, 46.61135796138218, 32.75437443596976, 2.755067352737699, 0.07141600070255143, 0.0523849729714649, 0.5771214461752346, 4.213413247040339, 7.154765929494586, 6.743117298398699, 9.057279978479658, 34.20998729978289, 53.36285999843052, 55.46052810123989, 49.066813128335134, 52.01593433107649, 53.74818972178868, 53.225737299237935, 50.060061591012136, 45.14761223111834, 42.93604578290667, 42.319942065647666, 41.73938880647932, 41.3313558442252, 37.86849525996617, 38.99368306568691, 42.83129474094936, 45.10286235809326, 48.95363392148699, 51.00741025379726, 52.639406612941194, 57.502252783094136, 47.13016257967268, 49.04239368438721, 50.539594990866526, 50.60082599094936, 41.15709154946463, 38.57613454546247, 37.86686590739659, 36.79210812704903, 39.183823994227815, 40.213276045663015, 38.744628361293245, 39.483392102377756, 39.16675574438912, 38.629684312003, 37.84429121017456, 38.78131137575422, 37.04072856903076, 37.54509483064924, 37.192511967250276, 38.29470123563494, 39.159727641514365, 40.03171614238194, 45.91968216214861, 52.63566500799996, 49.43630790710449, 51.10186753954206, 47.28936665398734, 53.469698974064414, 48.56942285810198, 57.76537411553519, 33.391371386391775, 19.37072651726859, 51.328896454402376, 43.24834646497454, 50.35207353319441, 46.73270130157471, 51.83524295261928, 48.3911702973502, 51.00335250582014, 46.75556434903826, 40.35476916176932, 37.05863755089896, 40.419602802821565, 37.71280697413853, 39.51061167035784, 37.37722635269165, 48.09630264554705, 49.1518486567906, 50.09791885103498, 48.92786652701241, 48.47723763329642, 44.88172204153878, 48.65431942258562, 50.07059506007603, 49.44080686569214, 47.13535635811942, 43.861556257520405, 40.394342626844136, 41.544606481279644, 40.489525999341694, 46.80653633390154, 46.724134172712056, 47.25824567249843, 43.33585555212838, 39.03037997654506, 39.17987741742815, 39.139018535614014, 46.514889172145296, 52.295088631766184, 52.77090127127511, 51.52916785648891, 51.832355976104736, 53.17308732441494, 50.627402850559776, 48.52889748982021, 44.90608589989798, 44.16522032873971, 46.26634863444737, 51.24242959703718, 52.2814701625279, 53.83722046443394, 39.65282392501831, 13.998084936823163, 2.0707067038331712, 3.7839772275515964, 10.36322169644492, 2.7511572539806366, 0.41036828979849815, 0.05693822114595345, 0.9211012997797557, 24.839521612439835, 31.521284580230713, 30.548064299992152, 20.385945183890207, 23.256930419376918, 38.698151860918315, 50.186379841395784, 49.19884974615914, 49.91720315388271, 12.217986856188093, 0.22555151342281274, 0.04249776440805622, 0.03937058988958597, 0.03254384228161403, 0.016940921046105877, 0.022848274059859768, 0.009518732666037977, 0.05701290749545608, 0.06182044345353331, 0.02138035514924143, 0.01796429943559425, 0.04258862024705325, 0.011529846000485122, 0.04395138658583164, 0.04273817954318864, 0.06006991131497281, 0.023205997721691216, 0.01981245749630034, 0.05056741514376231, 0.07034133015466587, 0.1467100190264838, 0.15819505202983106, 0.16599587058382376, 0.14619449526071548, 0.0714733504823276, 0.15532972078238214, 0.14051659564886773, 0.09673480889094727, 0.16383126245013305, 0.08606031310877629, 0.15269319154322147, 0.16779024286993913, 0.10586297764842, 0.16057286943708146, 0.17748859817428247, 0.11636153608560562, 0.11059994596455779, 3.252660857779639, 51.689768518720356, 68.6702904020037, 65.0560667855399, 46.594484261104036, 30.665495804377965, 27.61816876275199, 44.73041112082345, 51.801096030644004, 41.641242027282715, 3.700436430318015, 0.14481849409639835, 0.1423667028014149, 0.48837161702769144, 5.118513822555542, 12.795989257948738, 12.108131493840899, 11.203286698886327, 37.88597345352173, 55.77432612010411, 54.854457582746235, 50.32076842444283, 55.83767632075718, 56.062537397657124, 56.25411312920706, 52.21681022644043, 48.239240986960276, 45.24423735482352, 45.502477577754426, 43.032007353646414, 42.85628046308245, 38.924725668770925, 41.06736946105957, 44.40921327045986, 47.55374213627407, 50.528325012751985, 53.85130098887852, 54.669180393218994, 58.654927662440706, 48.24188477652413, 49.74008314950125, 53.24095038005284, 54.835179805755615, 44.45069054194859, 41.98536545889718, 40.03481156485421, 38.92235285895211, 41.64120381219046, 41.634870529174805, 40.344697747911724, 40.51160042626517, 40.745271818978445, 40.57413421358381, 41.694357531411306, 40.77529845918928, 39.17252969741821, 40.15284061431885, 39.26582315989903, 40.40276384353638, 40.74220418930054, 42.022837093898225, 47.842783723558696, 54.2172452381679, 51.426122597285676, 53.219442231314524, 48.39068044934954, 54.537758690970286, 51.52808741160801, 59.3972384589059, 36.887322766440256, 21.40640800339835, 51.12295184816633, 44.53832122257778, 51.194104875837056, 47.98772662026541, 52.43393448420933, 48.38611200877598, 53.21717711857387, 49.733225277491975, 42.5173716545105, 39.66111660003662, 42.085548060280935, 39.222594942365376, 42.95377063751221, 38.87800598144531, 49.51504141943795, 52.12250580106463, 52.063018798828125, 49.35974570683071, 49.37374285289219, 47.42805617196219, 49.910578046526226, 52.03378077915737, 51.160892486572266, 49.77555022920881, 47.9984198978969, 41.68616560527256, 42.67328923089163, 42.02730131149292, 49.94528429848807, 48.548477513449534, 49.10308619907924, 45.63662992204939, 41.55391706739153, 42.21165091650826, 41.89264522280012, 48.166865076337544, 53.78970520836966, 53.60742964063372, 53.077428000313894, 54.51452044078282, 56.612070424216135, 53.49734933035714, 52.602570738111226, 46.84779473713466, 47.39263078144619, 48.92113372257778, 54.72175741195679, 54.92769506999424, 57.200336183820454, 41.25543287822178, 16.719061170305523, 5.4861816593578885, 14.987024647848946, 12.223654849188668, 1.6087533320699419, 0.47339531779289246, 0.12934459799102374, 1.9829663719449724, 29.26441240310669, 47.75929764338902, 40.348147528512136, 28.915791749954224, 33.51952396120344, 44.67177527291434, 56.27993263517107, 57.180287156786235, 56.47231435775757, 16.631616353988647, 0.3784803737487112, 0.18124540229993208, 0.19108471646904945, 0.11194837146571704, 0.11243357828685216, 0.07871091711734023, 0.1816501212971551, 0.12982137740722724, 0.15914810874632426, 0.11955823669476168, 0.15152864903211594, 0.16750368396086351, 0.11574035084673337, 0.17686961138887064, 0.14591678444828304, 0.17183399945497513, 0.1181574147194624, 0.15635243590388978, 0.11346161312290601], [0.08130180809114661, 0.030701344899301018, 0.047163557793412886, 0.09211537641073976, 0.05571533140859433, 0.059047196193465164, 0.0537412118033639, 0.018187420409438864, 0.04233300253482802, 0.015922456946490065, 0.057190066203475, 0.04020639914753182, 0.023544410276891928, 0.02125645974384887, 0.048266357010496516, 0.02899146718638284, 0.036045635983880074, 0.08980647101998329, 4.092060353074755, 41.85997826712472, 54.201782022203716, 46.90491935185024, 36.25265693664551, 19.78114444868905, 18.457788808005198, 37.45613356998989, 40.70885631016323, 14.321057183401924, 0.707201386136668, 0.1328706866396325, 0.2864047187779631, 1.0312982095139367, 3.5947033039161136, 7.227774994713919, 4.526707087244306, 17.957798174449376, 39.53989832741873, 55.97093234743391, 53.394092151096885, 54.24992609024048, 49.11286578859602, 53.94085284641811, 51.855774879455566, 47.3371250970023, 43.3073262487139, 40.67364978790283, 38.73639474596296, 41.937464577811106, 37.17308480398995, 38.65263768604824, 37.48178979328701, 41.39768334797451, 48.44459499631609, 50.69838912146432, 50.35931355612618, 52.18509864807129, 47.01815414428711, 49.263853618076865, 51.439713273729595, 48.13843304770333, 48.98392806734358, 39.62704610824585, 36.50647463117327, 35.51769733428955, 36.76784154347011, 35.08886841365269, 35.541126659938264, 35.42786060060774, 35.154240540095735, 34.69956432070051, 36.00837564468384, 34.88265282767159, 35.43069893973214, 35.28590542929513, 35.58496979304722, 35.103021894182476, 38.308107784816194, 37.369812624795095, 35.80197940553938, 35.33599499293736, 38.79898064477103, 39.66442394256592, 42.9796005657741, 41.60681022916521, 47.10152210508074, 44.243012360164094, 53.74107129233224, 37.65746457236153, 20.638703278132848, 54.79584257943289, 44.82602875573294, 49.5885603087289, 45.838092940194265, 49.637732710157124, 46.77626650674002, 48.655941826956614, 48.338190283094136, 39.4825895854405, 35.786363329206196, 37.70947183881487, 36.72146231787545, 37.493170942579, 36.099800041743684, 37.14478479112898, 44.29119116919381, 48.404510838644846, 46.842444624219624, 48.49155787059239, 46.944927079336985, 48.7586327280317, 47.81774936403547, 47.022350856236045, 39.81166321890694, 37.36775595801217, 35.779227529253276, 36.22673668180193, 38.126891817365376, 39.601942266736714, 43.35230541229248, 42.03547586713518, 38.88291488374983, 37.73626756668091, 37.36986821038382, 37.61119999204363, 39.17055640901838, 48.57389054979597, 48.606178828648154, 51.8758864402771, 49.6565831729344, 51.240411145346506, 50.229899883270264, 48.98871537617275, 48.806144509996685, 49.17258555548531, 49.85997084208897, 51.23099981035505, 50.45751592091152, 56.28013413293021, 54.72556849888393, 34.90264279501778, 7.994356717382159, 3.1761262331690108, 12.720473630087715, 3.7614442195211137, 0.05880140366830996, 0.02934494661167264, 0.32048430293798447, 7.023090617997306, 32.8744740486145, 34.646949086870464, 16.773154633385793, 20.23264707837786, 24.89887659890311, 35.8569153376988, 37.43232904161726, 45.854487214769634, 23.87030175754002, 0.2751234769821167, 0.03334588085168174, 0.02138645857173417, 0.028623395865517, 0.05116672780630844, 0.04518009476097567, 0.03581527673772403, 0.006720227788069418, 0.014401712388332401, 0.02439935422236366, 0.023359114237661873, 0.0035803044447675347, 0.06483254182551589, 0.023661274363153746, 0.024629211352605904, 0.03741645314065473, 0.042451512068510056, 0.00867138322376247, 0.031747778212385516, 0.07940088545105287, 0.038155632226594856, 0.04253091423639229, 0.09627031095858131, 0.02324668098507183, 0.04034964467531868, 0.0384537160529622, 0.02733110387011298, 0.009544790107091623, 0.04206253169104457, 0.03293908892997673, 0.03355529032913702, 0.07002828802381243, 0.007633100812589484, 0.017528666382921592, 0.05866834973650319, 0.047890309510486465, 0.08811670847769294, 5.78654750755855, 52.2624077796936, 60.32995768955776, 53.86097982951573, 41.82077305657523, 25.99893798146929, 21.36412647792271, 37.467938559395925, 42.56673165730068, 16.28069932120187, 0.7615841222660882, 0.1008674603487764, 0.26359003729053904, 2.4045392019408087, 5.429770103522709, 6.366380759647914, 6.253306644303458, 17.128158943993704, 43.10250377655029, 56.687437534332275, 54.59834350858416, 54.048004490988596, 52.53932476043701, 54.96791124343872, 54.44619532993862, 49.435460226876394, 44.94203935350691, 42.29415382657732, 40.978561060769216, 42.50587933404105, 38.37517874581473, 41.2475049836295, 40.571334089551655, 43.57507160731724, 49.28018535886492, 51.65370389393398, 51.276972566332134, 52.57125520706177, 49.22527027130127, 50.878486428942, 52.80039290019444, 49.05715165819441, 51.888462679726736, 40.82397059031895, 37.97476100921631, 37.144301891326904, 39.11471373694283, 36.87226602009365, 37.651978969573975, 37.54860714503697, 36.57650899887085, 35.58373301369803, 37.19581930977957, 36.63098634992327, 36.921191760471885, 36.75581768580845, 37.251380579812185, 37.51955672672817, 38.55805533272879, 38.370724950517925, 36.977079595838276, 36.76116779872349, 41.07813916887556, 41.598930971963064, 45.16517032895769, 43.221846035548616, 48.69677291597639, 45.59921039853777, 55.23452057157244, 39.26906796864101, 22.120116540363856, 54.984173502240864, 47.5086795943124, 51.370915685381206, 47.94098261424473, 51.509223052433555, 47.49504375457764, 50.836689540318076, 48.35728393282209, 40.828056131090435, 37.45732518604824, 39.3642270224435, 38.18553808757237, 38.79426629202706, 37.52969067437308, 38.39431755883353, 46.80754382269723, 51.17583458764212, 48.93001004627773, 49.71896409988403, 48.357909270695274, 52.422841685158865, 48.73413337979998, 48.5186836378915, 43.04819665636335, 38.959626470293315, 37.832350730895996, 38.1435466493879, 40.239224093300955, 41.87485088620867, 44.86429943357195, 42.76884433201381, 39.77024848120553, 38.615607261657715, 38.02991580963135, 38.492818696158274, 42.149853638240266, 49.31608322688511, 50.31657518659319, 53.737030914851594, 50.436202321733745, 53.268854345594136, 52.588858468191965, 51.54841784068516, 51.19946888514927, 51.552906376974924, 51.769676276615684, 54.127460615975515, 51.52291795185634, 57.93496922084263, 55.90381274904524, 37.49798951830183, 7.038943367344992, 1.368761032819748, 8.085400700569153, 4.529946684837341, 0.3348542632801192, 0.08389244800699608, 0.1645948314773185, 8.888030546052114, 35.10957751955305, 35.55020795549665, 22.116918631962367, 22.113507066454204, 31.534065791538783, 41.49014302662441, 44.40381799425398, 51.72412041255406, 30.888494764055523, 0.5786371305584908, 0.02576509254452373, 0.011008107702114751, 0.025609867480982627, 0.05645738069766334, 0.004287806971530829, 0.04383732484919684, 0.031593119725584984, 0.015310006149645363, 0.025238510354288986, 0.04467674730611699, 0.04092591428863151, 0.10058592938418899, 0.05365242210349866, 0.048554693681320975, 0.07289262182478394, 0.02830272021570376, 0.021353624262181774, 0.04071344122556703, 0.13749312502997263, 0.18730123234646662, 0.19023517705500126, 0.19268699549138546, 0.153250675914543, 0.07170074792312724, 0.17624820901879243, 0.12721729571265833, 0.06834688503295183, 0.08850422661219325, 0.18717161858720438, 0.07924451027065516, 0.12945946039898054, 0.10663455338882548, 0.08677797245659999, 0.17846632642405375, 0.14792687658752712, 0.3119059375354222, 7.9795205763408115, 59.6341928754534, 67.76576001303536, 60.52349976130894, 48.38069936207363, 31.06832456588745, 27.751497745513916, 48.250945227486746, 51.22161974225725, 20.65892253603254, 1.2636771287236894, 0.18431949163121836, 0.4306606666318008, 3.181533668722425, 11.331763233457293, 15.420559235981532, 12.718557664326259, 22.73815185683114, 43.82563059670584, 58.57892826625279, 55.05773755482265, 56.66954592296055, 54.81515162331717, 57.676569189344136, 55.461417470659526, 50.32541676930019, 46.74612174715315, 43.993457385471885, 42.28037902287075, 44.02200753348214, 40.44885124479021, 43.07128552028111, 42.302922453199116, 44.9248251914978, 52.29554026467459, 53.46996300561087, 51.52896983282906, 54.029563971928184, 50.60529020854405, 51.44693940026419, 54.39819369997297, 52.37595176696777, 53.23469352722168, 42.88574429920742, 40.519608225141255, 39.208893094744, 40.414176259722026, 38.98101649965559, 40.00233915873936, 39.561448165348594, 38.43635068620954, 37.197340965270996, 38.77206679752895, 38.8465028490339, 38.73347650255476, 39.40169865744454, 39.22519356863839, 39.2178840637207, 40.65244735990252, 42.16534464699881, 38.77103499003819, 38.94724130630493, 42.84782450539725, 43.75888967514038, 46.660540785108296, 46.072358403887065, 51.01424033301217, 47.19005952562605, 58.65191214425223, 42.700713770730154, 24.96097264971052, 57.12155055999756, 49.053983279636924, 53.52469049181257, 50.383149351392476, 52.72149610519409, 49.73153339113508, 51.962638173784526, 52.90324708393642, 43.326444217136924, 40.06271553039551, 41.253848688943044, 40.06426150458199, 41.04733780452183, 39.46301303591047, 39.756723812648225, 48.506055286952424, 52.81092289515904, 51.55898257664272, 50.5759653363909, 50.12382173538208, 53.89168044498989, 51.733979906354634, 50.79706048965454, 43.56679630279541, 40.21698638371059, 38.947491441454204, 41.23646429606846, 42.194221360342844, 43.17222547531128, 48.29096337727138, 45.098380770002095, 42.82203279222761, 41.681030886513845, 40.27640390396118, 40.73874398640224, 45.41200508390154, 51.93127400534493, 52.46024036407471, 56.00993953432356, 52.75126566205706, 55.80028806413923, 54.920184067317415, 53.72310325077602, 54.74265759331839, 53.91294540677752, 55.38830852508545, 56.53083208629063, 55.84276935032436, 61.05411284310477, 57.977933406829834, 40.5569999558585, 12.633022734097072, 9.01801483971732, 22.198051009859356, 6.143619775772095, 0.281205023505858, 0.22283205363367284, 0.6175983399152756, 11.590399503707886, 49.02468620027815, 48.57788576398577, 25.75880650111607, 32.08565548488072, 34.41993406840733, 49.67652450289045, 52.27360132762364, 57.843475341796875, 35.551701818193706, 1.1916870602539607, 0.08140719815024308, 0.15451942783381256, 0.129496589835201, 0.0813407152891159, 0.09440958473299231, 0.11166511023683207, 0.12872987240552902, 0.10184109024703503, 0.20981859335941927, 0.08855837370668139, 0.1044510073427643, 0.3547660633921623, 0.08836037040288959, 0.14633138291537762, 0.19949352954115185, 0.05362973189247506, 0.03507191787606903, 0.17726647295057774], [0.05170558299869299, 0.06696456670761108, 0.02982444016795073, 0.034053446991103034, 0.01996920078194567, 0.04191505889009152, 0.027086843137762377, 0.03442889738029667, 0.0460680189010288, 0.04266743887481945, 0.009776950015553405, 0.016251860252980675, 0.035293177967625, 0.015895381702908447, 0.06720691227487155, 0.05347139574587345, 0.07515521720051765, 0.1205432116985321, 10.71274561541421, 53.82599912370954, 53.10540492194039, 43.7085291317531, 30.62839937210083, 19.719055346080236, 27.505861554827007, 38.80567176001412, 36.68033593041556, 11.445007579667227, 0.02176552215990211, 0.010782261562001492, 0.05794998471226011, 1.8338458708354404, 4.032421358994075, 5.13840217249734, 4.79910773890359, 26.42981140954154, 46.900448186056956, 57.54024205889021, 53.44108281816755, 52.061260904584614, 51.95670441218785, 52.68796757289341, 49.808182443891255, 48.314392702920095, 44.58119855608259, 39.87911633082798, 37.87516205651419, 36.99369968686785, 35.97452402114868, 39.37009130205427, 40.13012000492641, 45.149710587092805, 50.82262291227068, 49.65049307686942, 51.057294845581055, 46.8167918750218, 47.48802259990147, 51.98182562419346, 48.804223333086284, 47.1807211467198, 44.162003312792095, 35.9641295160566, 35.90533038548061, 35.5144282068525, 35.88238743373326, 34.517677852085654, 37.20005076272147, 35.28079502923148, 35.95231410435268, 36.309635639190674, 35.376013142721995, 37.40629761559622, 35.218216078622, 34.7312376839774, 36.60653911318098, 35.067742415836875, 35.317658696855815, 35.73903220040457, 38.346739768981934, 37.66306134632656, 37.30797018323626, 34.408559867313926, 38.33841930116926, 36.44722039358956, 44.65038176945278, 46.003216879708425, 52.78893184661865, 39.02107981273106, 25.195762702396937, 52.887085574013845, 43.67276675360543, 49.82710933685303, 43.621339661734446, 47.18224627631051, 45.25513560431344, 48.54431554249355, 44.33274834496634, 38.38997146061489, 34.193655558994834, 37.60464089257376, 35.1159907068525, 36.508538246154785, 35.41232442855835, 37.17902898788452, 36.59900726590838, 43.53412239892142, 47.914951188223704, 49.31904663358416, 49.873318331582205, 49.037401403699604, 47.13303913388933, 44.112712791987825, 39.11812877655029, 36.089992659432546, 36.684939111982075, 35.622222559792654, 35.802601269313264, 37.522447177342, 37.85008948189871, 36.92722627094814, 37.78822272164481, 37.29458795275007, 36.51519809450422, 39.4585349219186, 38.13736275264195, 42.8564715385437, 47.331375462668284, 49.89731740951538, 49.8928462437221, 50.408194133213584, 50.76451860155378, 50.64837598800659, 51.38648312432425, 48.994524070194785, 52.81359795161656, 49.458733218056814, 54.59486940928868, 51.38233157566616, 51.813429083142964, 48.56163045338222, 23.049372094018118, 2.6026119334357123, 8.457237022263662, 6.723180745329175, 0.6498447124447141, 0.023707716692505137, 0.02341148696307625, 2.2816544473171234, 20.285915442875453, 36.41834715434483, 17.495174952915736, 16.954681532723562, 20.922236680984497, 35.11647013255528, 41.96486479895455, 44.588386467524934, 40.28163589750017, 6.325299101216452, 0.29826950068984714, 0.03421410372746842, 0.01200637690323804, 0.012653874881964709, 0.03615862224251032, 0.006245337667808468, 0.044080698397010565, 0.05626784890357937, 0.017085391329601407, 0.06509136222302914, 0.003184749275013538, 0.01046900823712349, 0.025645750109106302, 0.0541838541227792, 0.02350322320125997, 0.021187863246138607, 0.022769743809476495, 0.01910672170509185, 0.027021971797304492, 0.028347902166258012, 0.023002466053834984, 0.012255749548785388, 0.0457965709668185, 0.026246618313182677, 0.01874028565362096, 0.07047994807362556, 0.05575718344854457, 0.02445597796966987, 0.04355806019157171, 0.013630084061462964, 0.026107045356184244, 0.03318121736603124, 0.04931270889937878, 0.03460284322500229, 0.0593393598017948, 0.14034348779491015, 15.29086068698338, 61.435937200273784, 57.53831740788051, 50.19825431278774, 35.995962687901084, 26.6667606149401, 24.84223140989031, 39.188944816589355, 40.45998573303223, 12.296109795570374, 0.009620367881975003, 0.05970137180494411, 0.04548224301210471, 2.9483642833573476, 7.99992743560246, 5.620105581624167, 4.374497243336268, 28.277471167700632, 50.309647832598, 58.5273448399135, 54.03920807157244, 53.869870049612864, 53.405094623565674, 55.752578258514404, 52.78559671129499, 48.555356230054585, 46.877098764692036, 41.79903909138271, 39.11101729529244, 38.49570567267281, 37.86004625047956, 41.68502957480294, 42.572943346840994, 47.87769842147827, 52.02244479315621, 50.51438692637852, 49.51757403782436, 48.47737659726824, 46.475864614759175, 53.323852811540874, 50.07941927228655, 49.250235148838584, 46.50486292157854, 38.24729020254952, 37.58575916290283, 37.667893818446565, 37.44017008372715, 37.27846465791975, 38.455663204193115, 38.32734734671456, 36.88849353790283, 37.61331224441528, 36.33914116450718, 38.914570876530235, 36.97447749546596, 36.29759093693325, 39.151598249162944, 36.432073320661274, 37.930612155369346, 36.881764207567485, 38.93986579350063, 39.0962940624782, 38.27004207883562, 36.10174553734915, 39.97091245651245, 38.384857586451936, 45.94509172439575, 46.52044078281948, 54.369761671338765, 39.928375584738596, 27.720903090068273, 54.99114254542759, 46.07205615724836, 49.75352791377476, 44.450072152274, 48.111616475241526, 46.726489612034385, 49.589095320020405, 46.70690264020647, 40.01831306729998, 37.139406885419575, 39.35046264103481, 36.22485719408308, 37.4360602242606, 37.02934741973877, 38.7588860648019, 37.73230709348406, 45.85665505273001, 48.915022781917024, 51.480454036167686, 52.667192459106445, 50.602233001164024, 49.49846996579851, 45.294552734919954, 40.41633020128523, 38.49175214767456, 38.60394818442208, 39.05568878991263, 37.40958063943045, 40.62604073115757, 39.10696302141462, 39.32188817432949, 40.16249861036028, 39.881697586604524, 38.4705045563834, 40.32479115894863, 40.82538454873221, 45.5407760483878, 48.58902372632708, 51.98470217841012, 50.801024436950684, 52.32953085218157, 51.86422388894217, 53.11026518685477, 52.54445253099714, 52.25792966570173, 54.48339598519461, 52.39564643587385, 56.23097562789917, 53.699437686375205, 52.94179221561977, 52.02022136960711, 24.1699914591653, 2.853951075247356, 4.627821615764073, 5.830777568476541, 1.1136743149587085, 0.1179886766310249, 0.026637016828837137, 2.2691479069846014, 26.948721987860544, 33.31286021641323, 23.610847336905344, 19.745663472584315, 23.0963089125497, 39.79872914722988, 49.81769800186157, 50.95615339279175, 48.998331683022634, 8.053003856113978, 0.3191930507974965, 0.033436434742595465, 0.05880808723824365, 0.02938686989779983, 0.026339740459141985, 0.06950827914157084, 0.05381825266938124, 0.029281354309724908, 0.07220207673630544, 0.052257618733814785, 0.0596580473440034, 0.028596580161580017, 0.0433912389645619, 0.04238855080412967, 0.029237514162170034, 0.041538207326084375, 0.04473068066207426, 0.02129735504942281, 0.11191620212048292, 0.21123739651271276, 0.14736114123037883, 0.1236595737614802, 0.1334956038211073, 0.09208140216235604, 0.1803116159779685, 0.13146016161356652, 0.12273539549538068, 0.08903628627636603, 0.15122565600488866, 0.11208328458347491, 0.15851295925676823, 0.08815180909420763, 0.1823388071996825, 0.12124032500599112, 0.17416615145547049, 0.2021370476910046, 20.21626843724932, 69.50718007768903, 65.37025737762451, 57.53052500316075, 42.159893785204204, 30.06569603511265, 37.701627322605674, 48.785685539245605, 48.32159103666033, 16.151926619665964, 0.13856559033904756, 0.11885729644979749, 0.18833469546266965, 2.5796001510960713, 9.983524356569562, 12.213393228394644, 11.54564094543457, 29.35772671018328, 49.513092449733186, 60.168217522757395, 55.65954187938145, 55.4456832749503, 54.513679708753315, 57.36018296650478, 54.53281504767281, 51.546003341674805, 48.73951128550938, 43.61711515699114, 40.3802238873073, 41.131310258592876, 38.61880690710885, 45.143811566489084, 44.69966186795916, 50.069931507110596, 53.705920355660574, 52.47660337175642, 49.75443812779018, 51.515313148498535, 49.46987465449742, 55.615299224853516, 52.947256973811555, 50.932602473667686, 47.787806102207725, 39.62336703709194, 39.57157516479492, 38.8567271232605, 39.60177550997053, 38.453596115112305, 41.14796509061541, 40.336363383701865, 38.264136110033306, 40.29891606739589, 38.2918107850211, 41.570366927555625, 38.18349879128592, 39.59195423126221, 41.892638274601524, 37.94542224066598, 40.013928753989084, 38.69434077399117, 41.08759914125715, 42.263286454336985, 40.95519079480852, 38.3407747404916, 42.682245458875386, 40.237004143851145, 47.6038247517177, 50.523763520377024, 55.920926162174766, 42.54391377312796, 28.808356966291154, 55.161953585488455, 47.64381858280727, 52.40481458391462, 46.508125100817, 50.91859837940761, 48.64061410086495, 52.36916337694441, 48.11743211746216, 42.04471697126116, 38.601474625723704, 41.4686279296875, 37.88552876881191, 39.34451845714024, 38.822733061654226, 41.038277353559224, 40.186504636492046, 47.56602307728359, 52.087472983769004, 53.59262302943638, 55.062139238630024, 52.23708854402815, 52.08738265718733, 49.57988200868879, 43.1801255771092, 39.76605176925659, 40.41623640060425, 40.46610362189156, 38.409117221832275, 42.10404763902937, 41.03997271401541, 41.77322653361729, 41.64288527624947, 42.41449662617275, 40.83962140764509, 43.162223543439595, 41.65828595842634, 48.42778035572597, 52.26541634968349, 53.86973108564104, 50.836894512176514, 53.903930119105745, 54.953309604099815, 55.06125681740897, 55.81482022149222, 54.103534494127544, 57.98608364377703, 53.047491686684744, 59.17044925689697, 55.26969582693917, 54.562428270067485, 52.64811965397426, 28.375640528542654, 6.304571756294795, 18.252648455756052, 13.73705848625728, 1.2869208071913039, 0.19171058359955037, 0.11563969696206705, 3.7662128550665717, 33.03240660258702, 48.91439049584525, 25.47838589123317, 26.233370201928274, 33.08330563136509, 45.456831387111116, 54.976978642599924, 56.08567837306431, 57.89383588518415, 10.888188498360769, 0.45030781094517025, 0.11264692326741559, 0.17207008892936365, 0.11968121438154153, 0.11163397905017648, 0.14107464998960495, 0.12631929532757827, 0.11627654278916971, 0.15147873599614414, 0.1742635890841484, 0.17185964807868004, 0.07657922471740417, 0.09444175407822643, 0.15580576738076551, 0.18542691506445408, 0.14393707710717404, 0.1301182500485863, 0.057754444490586004], [0.05256226738648755, 0.029773190417992215, 0.054990513516323905, 0.028709959970521073, 0.014025412134027906, 0.030494890441851955, 0.02769743644499353, 0.0402850277854928, 0.014467185928619333, 0.05186952045187354, 0.024336365816582526, 0.00935484779932137, 0.044129787012934685, 0.05248717052329864, 0.11274075787514448, 0.05946299566754273, 0.06414963025599718, 0.5067177382963044, 24.085772344044276, 47.89018780844552, 50.64316831316267, 40.50026444026402, 29.99897595814296, 13.524430581501552, 39.26227610451834, 42.92500509534563, 30.616597856794083, 4.173424192837306, 0.04040367302617856, 0.0376274232486529, 0.186615667705025, 1.6722884199448993, 3.7184891530445645, 3.3127267318112508, 8.750591703823634, 42.1060209274292, 55.19349145889282, 59.97029113769531, 55.83112416948591, 55.78306695393154, 50.82486718041556, 53.93962301526751, 48.93845558166504, 47.468373094286235, 41.34940726416451, 38.44904504503523, 36.64829431261335, 38.046396936689106, 36.246841294424875, 37.816039834703716, 40.21931055613926, 48.07025037493025, 50.88812705448696, 52.01297787257603, 50.20411859239851, 43.61186579295567, 48.17048508780343, 48.502789633614675, 46.894076687949045, 44.45263951165335, 38.887080328805105, 36.809732232775005, 37.85837868281773, 35.265401295253206, 35.77816098076956, 35.24990333829607, 36.77947282791138, 37.64138644082205, 35.560901233128135, 35.12400197982788, 35.21412706375122, 36.19764110020229, 36.25368874413626, 35.82304981776646, 36.167961869921, 33.4059556552342, 40.188321590423584, 42.406304700034006, 46.73068632398333, 45.62452963420323, 45.22753735951015, 42.77457659585135, 44.50936113085066, 40.404348032815115, 44.46527133669172, 42.8774550982884, 54.37960726874215, 35.828163691929404, 23.305046694619314, 53.66697570255825, 44.62725121634347, 48.854809692927766, 40.386185441698345, 46.03332689830235, 41.8917350087847, 46.02989796229771, 41.07811485018049, 38.987051010131836, 34.288515840257915, 38.85397563661848, 36.67074741636004, 36.54281370980399, 37.096331528254915, 36.275026662009104, 34.611415999276296, 37.68015391486031, 40.02953093392508, 42.57866171428135, 44.625371728624614, 46.034865924290244, 41.05498429707119, 38.685853549412315, 36.48755816050938, 35.99407972608294, 33.630524907793315, 36.414254665374756, 36.9393995148795, 37.32127250943865, 36.27088553564889, 36.147513321467805, 35.31004694529942, 36.88089568274361, 38.00984246390206, 39.59581742967878, 44.672800132206504, 48.24873570033482, 47.830659117017476, 51.72745902197701, 46.78706053325108, 44.88305262156895, 46.926969460078645, 49.50527572631836, 49.08278008869716, 52.024105412619456, 49.66160672051566, 53.28920561926705, 51.922206606183735, 56.99606956754412, 53.43807077407837, 55.25535127094814, 40.39768818446568, 10.529987147876195, 2.5662858826773505, 4.775088684899466, 1.687588027545384, 0.09286045535866704, 0.14150645610477242, 0.5271060328398431, 14.50661403792245, 32.316523279462544, 32.97562592370169, 20.349192687443324, 22.21490212849208, 37.81544576372419, 46.11085489818028, 42.60838610785348, 39.6127085004534, 17.06423204285758, 0.11835767754486629, 0.003445180769111695, 0.014319326362705656, 0.023367356741800904, 0.008061530367870415, 0.03091058474300163, 0.05514357405315552, 0.03630904667079449, 0.08711447832839829, 0.03985848370939493, 0.014436256606131792, 0.04826860635408333, 0.027379076295931424, 0.025681227312556336, 0.016904731380886266, 0.045568250718393495, 0.015139549671273147, 0.0529968521025564, 0.03264161917780127, 0.02740757307037711, 0.01604951262873198, 0.043922637057091506, 0.034621916844376495, 0.049832904378750494, 0.04452302519764219, 0.008238868887669273, 0.020167857175692916, 0.05814994219690561, 0.013345621825594987, 0.024302403442561626, 0.01414349758332329, 0.024376894713246396, 0.04751918478203671, 0.09604020616305725, 0.03289362708372729, 0.7583698747413499, 32.34778669902256, 54.79047162192208, 55.92276048660278, 47.00814873831612, 34.29528685978481, 16.52465578487941, 36.42033086504255, 48.105331829616, 34.153404644557405, 5.3094503198351175, 0.13800993801227637, 0.16039195843040943, 0.6798358517033714, 5.3600258231163025, 4.660138121673039, 3.6389724484511783, 9.028324229376656, 41.364769731249126, 58.09267595836094, 60.61179052080427, 57.37593105861119, 55.36421912057059, 54.78590318134853, 53.496025698525564, 50.30340140206473, 50.131304945264546, 44.191484519413535, 40.3101304599217, 39.57199900490897, 38.63512127740042, 38.31184591565813, 37.488852637154714, 42.29125642776489, 49.6845566204616, 53.890502725328716, 51.301197460719514, 50.14721632003784, 44.870761258261545, 47.93068538393293, 50.74065153939383, 48.16281427655901, 46.51260321480887, 41.32268449238369, 39.067167213984895, 39.38205262592861, 37.5604955128261, 37.45132194246565, 36.506915841783794, 39.35470799037388, 39.053774561200825, 37.54513999394008, 36.127877712249756, 37.5674923488072, 37.011052812848774, 37.34560857500349, 36.81141717093331, 38.1207982472011, 35.65029328210013, 41.490542548043386, 44.38522808892386, 49.58846998214722, 46.406233242579866, 47.22815997259957, 44.42694854736328, 46.33054651532854, 41.525297437395366, 47.00575508390154, 45.403622082301546, 55.13220834732056, 37.25607408796038, 24.54958544458662, 55.258321625845774, 45.67696074077061, 50.98181309018816, 42.44562455586025, 48.21200057438442, 44.14924989427839, 47.575622013636995, 43.50799369812012, 40.843164988926475, 35.493920598711284, 39.29533910751343, 38.58378798621041, 38.35509845188686, 38.43931061880929, 38.60941641671317, 36.72167771203177, 38.31838764463152, 40.310321535382954, 46.02660799026489, 47.63375064304897, 47.66003220421927, 42.26199756349836, 41.2153765133449, 37.51326860700335, 38.14366824286324, 36.08216551371983, 38.376453740256174, 37.9371851512364, 38.87311097553798, 38.44675561359951, 39.123207909720286, 38.14302206039429, 38.72930758340018, 40.584580830165315, 41.4949893951416, 45.73043755122593, 49.59576906476702, 51.09321008409773, 52.305517877851216, 49.3821189062936, 46.27706970487322, 50.59375967298235, 52.44606603894915, 52.5534018107823, 51.16629818507603, 51.73828084128243, 55.19401257378714, 53.67130095618111, 56.55821146283831, 57.14512579781668, 55.77518422263009, 44.59240252631051, 11.025635157312665, 4.020746214049203, 3.235446261508124, 3.017083704471588, 0.20985064735370024, 0.07765521162322589, 0.6723306572863034, 17.425786767687114, 34.75965234211513, 39.11549193518502, 23.076051439557755, 23.250937598092214, 44.55121013096401, 50.03425250734602, 50.47737039838518, 46.361403465270996, 21.29575620378767, 0.32032959695373264, 0.10258201656064816, 0.06307449830429894, 0.02377922071277031, 0.06677784065582923, 0.05652098317763635, 0.04133586139817323, 0.04517168431941952, 0.05530316888221672, 0.013408972399442323, 0.023783795735133544, 0.0025810905956729713, 0.07507661570395742, 0.05157940601930022, 0.02291632772955511, 0.08169798433248486, 0.043227725595768006, 0.03731707150914839, 0.13450260407158307, 0.12397581179227148, 0.1384054832160473, 0.1496235534016575, 0.1482650177287204, 0.13786872130419525, 0.18795812209802015, 0.1476819525871958, 0.08994752487965993, 0.20855714247695037, 0.13065646402537823, 0.11201564142746584, 0.07781923389328377, 0.12802111543715, 0.15403318963944912, 0.2677421287766525, 0.1636957861483097, 1.0666777853454863, 39.297093527657644, 62.98659447261265, 62.48214135851179, 52.53100776672363, 40.60593959263393, 21.201712335859025, 51.11172008514404, 52.45918076378958, 40.341063840048655, 5.79422049011503, 0.19679939267890795, 0.2842699390436922, 0.9545217007398605, 6.220315728868757, 13.792360067367554, 10.643016968454633, 14.480004174368721, 47.31410918916975, 57.973764487675254, 64.75311837877545, 58.848650387355256, 59.20543343680245, 54.72116681507656, 57.94157695770264, 51.96781458173479, 51.780935832432334, 44.77547713688442, 43.21312257221767, 40.38715818950108, 41.63698625564575, 39.188190937042236, 40.55753149305071, 44.023487499782014, 50.86067819595337, 55.73238679340908, 52.16536923817226, 50.422424043927876, 45.463803904397146, 50.75255380358015, 53.62602996826172, 50.66198403494698, 50.06790610722133, 43.93422746658325, 41.33385719571795, 41.44015768596104, 38.727806772504536, 38.27160889761788, 38.905371461595806, 40.90701198577881, 40.860830783843994, 40.04442092350551, 38.92240497044155, 38.52288007736206, 40.57124376296997, 40.67491436004639, 39.76625326701573, 41.06563588551113, 37.56727695465088, 44.406447887420654, 48.46962935583932, 50.67906270708357, 49.86158629826137, 48.927758829934255, 47.13638816561018, 48.254040649959016, 43.93973738806588, 47.61477163859776, 48.678530420575825, 59.59695053100586, 40.9555208342416, 28.161048889160156, 56.9730293410165, 47.96150411878313, 53.56081070218767, 44.655780519757954, 50.48964091709682, 46.23659297398159, 50.61843272617885, 44.57026556559971, 42.37475640433175, 36.51015370232718, 42.50879757744925, 40.931688513074604, 41.148152691977366, 39.825052397591726, 41.086480481284006, 38.34802171162197, 41.41835771288191, 43.19812141145979, 47.845278126852854, 49.59798901421683, 50.19789300646101, 44.7794827733721, 42.52011619295393, 38.984101499829976, 40.418053354535786, 37.12720584869385, 41.26336077281407, 41.185384614127024, 41.43218810217721, 39.84388896397182, 41.44543831689017, 39.44199126107352, 40.73176799501692, 41.82114825929914, 43.8580960546221, 48.283205713544575, 52.511646611349924, 52.27865961619786, 54.9975974219186, 50.017347540174214, 48.513844217572895, 50.85294485092163, 52.26684767859322, 53.29642479760306, 54.77358749934605, 51.883393968854634, 56.93473434448242, 55.035847255161826, 60.94384493146624, 57.79007148742676, 59.85732037680489, 45.326163564409526, 14.331865974834987, 6.982563078403473, 10.88501056603023, 3.2060857798371996, 0.29155889792101725, 0.3522838465869427, 0.7567168005875179, 22.784034286226543, 45.56036302021572, 44.36135407856533, 29.607768058776855, 31.479633603777202, 48.76259320122855, 58.215766770499094, 56.51869705745152, 55.68626812526158, 26.89629261834281, 0.46379084459372927, 0.23813235333987645, 0.14084373095205852, 0.07591274048068694, 0.11221781093627214, 0.20388257902647766, 0.15589567327073642, 0.11831940816981451, 0.1276504046150616, 0.13991187166954788, 0.11175971158913203, 0.1904374212026596, 0.1323727640722479, 0.12171827150242669, 0.10934061211134706, 0.18521072023681232, 0.10609448022608246, 0.14453680706875666], [0.04274562307234321, 0.030895385558583906, 0.0233778248408011, 0.01916060925993536, 0.038604527246207, 0.02400457576316382, 0.019791687539379512, 0.06523225323430129, 0.007177573113170053, 0.04754206159019044, 0.030442130951476947, 0.031310747377574444, 0.031422006764582226, 0.03215268041406359, 0.008801903675443359, 0.04678105064002531, 0.03400757123849221, 1.5636712482997348, 36.93295506068638, 49.22917168481009, 46.449596949986045, 41.873020035879954, 25.443580627441406, 24.50992512702942, 41.28314924240112, 34.173891408102854, 26.222911425999232, 1.2924447336367197, 0.044001601569886716, 0.050739983562380075, 0.09120987142835345, 4.246696855340685, 6.792294042451041, 2.6268646206174577, 11.620530366897583, 53.710877895355225, 54.3118553842817, 54.62342997959682, 51.91461917332241, 53.54671975544521, 51.11441946029663, 50.47971888950893, 47.160078048706055, 41.562974044254844, 36.92381470543997, 36.8744547026498, 39.522031034742085, 37.78073603766305, 35.899622440338135, 35.87646756853376, 42.48342275619507, 50.011156695229666, 48.32646867207119, 48.160615171704976, 44.89516333171299, 47.14225244522095, 48.758125509534565, 49.546113763536724, 45.346966470990864, 40.274656432015554, 37.038793495723176, 36.87669549669538, 37.09200280053275, 36.15874855858939, 36.96019547326224, 36.05142668315342, 34.951961108616416, 34.55379111426217, 36.18624952861241, 34.807049478803364, 36.010498319353374, 36.19291632516043, 34.34339271272932, 35.575711318424766, 33.73664127077375, 38.32546785899571, 47.10253306797573, 48.23389087404524, 51.43217100415911, 47.478475775037495, 50.642331055232454, 47.596890449523926, 48.12882021495274, 45.320195061819895, 49.237888199942454, 45.214401790073936, 53.87861783163888, 32.1148796081543, 25.698461396353586, 53.89645733152117, 43.165225165230886, 49.20480782645089, 40.911820139203755, 41.91071401323591, 40.37406430925642, 41.796367509024485, 37.427267278943745, 37.23582703726632, 34.89981140409197, 37.508884293692454, 38.27962711879185, 36.98222126279558, 37.26625667299543, 37.38514729908535, 35.408982345036094, 36.71406943457467, 34.29262222562517, 36.51383624758039, 35.205462660108296, 36.911770003182546, 34.055063315800254, 36.108763217926025, 35.09764051437378, 37.25853375026158, 35.88555233819144, 35.853667054857524, 37.18101617268154, 38.15064076014927, 35.60815245764596, 37.315856388636995, 36.357863085610525, 37.67149993351528, 38.00210564477103, 42.24016284942627, 47.9315504346575, 50.618279865809846, 51.102485929216655, 48.9693021093096, 46.258973121643066, 46.87384353365217, 47.4084483555385, 43.8641722542899, 45.78076682771955, 49.96682024002075, 51.597274099077495, 51.091261114392964, 51.43615927015032, 49.37700850622994, 49.46195370810372, 49.75328472682408, 44.9388153893607, 17.60389862741743, 2.444107238735471, 2.54474190729005, 2.867654877049582, 0.30744606256484985, 0.035918892427746735, 0.08378476449953658, 7.74004830632891, 29.265704768044607, 27.524124894823345, 25.5903856413705, 15.845689977918353, 24.430764300482615, 39.73831108638218, 38.2855851990836, 45.76031827926636, 24.345395258494786, 1.1850949568407876, 0.12665290385484695, 0.06308042870036193, 0.02184243919327855, 0.033594438407037935, 0.0379474203634475, 0.012334564783876496, 0.04426032697249736, 0.01636529264838568, 0.0617608545081956, 0.05386498337611556, 0.04006828334448593, 0.010137833954234208, 0.05382601850266967, 0.03958406379180295, 0.00985600273790104, 0.060278716896261485, 0.01642059494874307, 0.07497524257217135, 0.07977338760559048, 0.011282594625039824, 0.039480593986809254, 0.0434734231260206, 0.021994271581726413, 0.08057606060590063, 0.06431842941258635, 0.005293975168439958, 0.03287609713152051, 0.024781255783247094, 0.04582679970189929, 0.04422175564936229, 0.06314702012709209, 0.02705163904465735, 0.05831878885094609, 0.07374706704701696, 2.632867864200047, 46.713670185634065, 56.91559900556292, 52.36610964366368, 46.711158411843435, 33.279894488198416, 25.176385913576397, 41.61877155303955, 38.68644067219326, 29.96850115912301, 1.308026720370565, 0.039463980056877644, 0.1542029862425157, 0.941840586917741, 11.987171173095703, 7.7476279224668225, 3.7016875403267995, 13.985756226948329, 54.377008642469136, 57.03138031278338, 56.27209159306118, 54.27211863654, 56.07299443653652, 54.35656009401594, 52.202837399074006, 49.49204635620117, 44.25554691042219, 38.22236354010445, 39.192717688424246, 40.646777629852295, 39.39616789136614, 37.15263972963606, 37.791283403124126, 44.51207440240042, 50.771928855351035, 49.87811606270926, 50.389656339372905, 48.11699438095093, 47.39910997663225, 50.521130153111045, 51.69564322062901, 48.525110721588135, 41.81775753838675, 39.21138749803816, 39.04347038269043, 40.30706977844238, 37.61236034120832, 39.00032901763916, 37.79873187201363, 37.442219802311485, 36.92547879900251, 37.9128212928772, 36.547218867710654, 38.22421523502895, 37.484127862112864, 36.903786523001536, 36.94476352419172, 36.89146736689976, 39.579089641571045, 49.612434319087434, 49.99777446474348, 52.863607610974995, 49.78580577032906, 52.73915147781372, 50.47210018975394, 49.52894476481846, 46.91397980281285, 51.365701062338694, 46.32992812565395, 55.41310664585659, 34.488644804273335, 26.224341017859324, 54.74806676592146, 45.529050963265554, 51.326162338256836, 42.53267853600638, 44.62094572612217, 43.41806663785662, 43.524943828582764, 39.95464324951172, 38.30048213686262, 37.555079392024446, 38.80641521726336, 38.546688079833984, 38.47155026027134, 38.78214863368443, 38.96159975869315, 36.96870354243687, 37.837794644492014, 36.82517460414341, 37.74775988715035, 37.34917300088065, 37.50603553227016, 35.75282437460763, 37.90473011561802, 37.44821262359619, 37.24688856942313, 37.2714261327471, 37.914843218667166, 39.58098302568708, 39.43874645233154, 37.09362867900303, 39.12252351215908, 38.684088706970215, 39.13085092817034, 38.77511010851179, 42.75164754050118, 50.5588310786656, 51.78222124917166, 53.13965259279524, 48.99138001033238, 46.78632402420044, 47.511590889522004, 47.121188981192454, 45.00183555058071, 48.37539093835013, 50.51514080592564, 52.78705930709839, 51.60650478090559, 54.01868656703404, 50.66860219410488, 52.50867625645229, 52.03199161802019, 47.686279024396626, 18.317784343447002, 4.610528417995997, 4.2234907405717035, 3.693409195968083, 0.7089746966958046, 0.019388054198186313, 0.06756240355649165, 9.365839924131121, 32.82672602789742, 25.967375789369854, 33.32888971056257, 19.074422325406754, 33.12735373633248, 45.96748229435512, 44.42712920052664, 52.134619985307964, 32.928680419921875, 1.6959817771400725, 0.1212161827300276, 0.04022448889112898, 0.023695436905005147, 0.04746702240247812, 0.045316110498138835, 0.011698612926660903, 0.0419048265820103, 0.04027225097109165, 0.026096246471362453, 0.03416742051818541, 0.02405086881481111, 0.06851706161562886, 0.061511492888842306, 0.058638663829437325, 0.042857482962842496, 0.041343013157269785, 0.03733521553554705, 0.1516249060098614, 0.15852468434189046, 0.08792710543743201, 0.17481259176773684, 0.1713880119579179, 0.14457085595599242, 0.19999263275946888, 0.21170900549207414, 0.184471388480493, 0.09191534428724221, 0.09372057991900615, 0.14575320322598728, 0.09143759456596204, 0.12378329783678055, 0.12695201566176756, 0.17596193509442465, 0.19732098254774297, 4.066194815295083, 54.24462808881487, 63.35687787192208, 58.99716118403843, 53.23468657902309, 36.3847838810512, 33.59032610484532, 51.22880070550101, 44.45576620101929, 34.69144535064697, 2.025359719991684, 0.20524700438337667, 0.23500170132943562, 0.46747311843293055, 9.59865060874394, 17.78107942853655, 9.406657116753713, 16.03454201562064, 57.437380926949636, 58.3306691305978, 58.52847739628383, 56.09228958402361, 58.222443989345, 57.158945764814106, 54.70595373426165, 51.48393160956246, 46.10437222889492, 40.015155111040386, 40.50429092134748, 43.13140133449009, 41.080407755715505, 39.28510788508824, 38.92641755512783, 46.7425468989781, 51.98872171129499, 51.86985540390015, 51.35479586465018, 48.83156449454171, 46.93689843586513, 50.70965562547956, 54.80138724190848, 51.14535978862217, 44.61448737553188, 41.72516584396362, 40.452728339603965, 41.20629869188581, 38.91304227284023, 41.828214577266145, 39.07670361655099, 38.72622258322579, 38.79995686667306, 40.086784090314595, 38.21062455858503, 40.12503044945853, 39.094591753823416, 37.30718156269619, 38.36151858738491, 38.13595921652657, 41.97745493480137, 51.31289822714669, 51.22110557556152, 54.948261737823486, 51.55471290860857, 54.683104583195274, 52.89261286599295, 51.885290827069966, 50.39253984178816, 52.60483585085188, 49.450878279549734, 58.89624554770333, 35.7621488571167, 29.35651077542986, 57.07596342904227, 46.358683245522634, 54.32074213027954, 46.262471539633616, 45.90838091714041, 44.742320333208355, 45.85095405578613, 43.398625578199116, 40.49138116836548, 37.74276065826416, 41.340246064322336, 41.205965178353445, 40.4052026612418, 40.80873319080898, 40.0497328213283, 39.24042749404907, 40.3867621421814, 39.101776191166465, 39.880318369184224, 39.42310605730329, 40.20157527923584, 37.853949206215994, 39.68638025011335, 39.088056973048616, 39.58869900022234, 39.899036816188264, 40.55829579489571, 42.28616687229702, 40.47664751325335, 38.9341265814645, 39.975956848689485, 39.94286952699934, 41.37684917449951, 41.04027843475342, 45.50986351285662, 52.4283446584429, 55.281698840005056, 56.05657236916678, 51.05175018310547, 48.33302777154105, 48.724544865744456, 47.398338726588655, 46.511116300310405, 47.4999144417899, 52.2674035344805, 55.2672187941415, 55.33121517726353, 55.933387756347656, 53.7796859060015, 55.18910714558193, 54.50336510794503, 49.57163102286202, 20.42911434173584, 5.960472209112985, 7.483193380492074, 8.972519772393362, 1.517346631203379, 0.1145855113863945, 0.23849914222955704, 10.974135977881295, 42.82167148590088, 37.006661551339285, 36.072900090898784, 24.832943405423844, 34.84576484135219, 50.59508677891323, 52.753235476357595, 59.13721602303641, 40.841598170144216, 2.8145282992294858, 0.39035994772400173, 0.15726905528988155, 0.19774958597762243, 0.1562546861491033, 0.23566897266677447, 0.09181532144014325, 0.12189763544925622, 0.11254880710371903, 0.12148807171200003, 0.17265657388738223, 0.08511894076530423, 0.1624992982085262, 0.14049820734986238, 0.16946063323744706, 0.1624805842127119, 0.16303193462746485, 0.21291337800877436], [0.031492472626268864, 0.058605008492512364, 0.01869862529981349, 0.03251872630789876, 0.029057665062802177, 0.03381592920050025, 0.02089794898139579, 0.03180321452340909, 0.03847367516053574, 0.07956545054912567, 0.044263566977211406, 0.02689187797451658, 0.03535738434376461, 0.049949344380625656, 0.04670428118801542, 0.03249324731794851, 0.04572546049686415, 7.15443936416081, 46.42974942071097, 51.83778599330357, 37.046134267534526, 24.60888831956046, 14.17789910520826, 19.67173637662615, 37.657801559993196, 37.357986790793284, 18.745576245444163, 0.0864148408706699, 0.07624690540667091, 0.06780248960214001, 3.115344260420118, 11.124435067176819, 1.8198235375540597, 2.486941145999091, 27.091450146266393, 54.80393028259277, 53.96596711022513, 51.232545784541536, 50.84750441142491, 49.032051290784565, 48.32819529942104, 40.10121897288731, 37.86618845803397, 35.919403961726594, 41.307957785470144, 38.62004368645804, 41.433800084250315, 37.92835051672799, 36.72054168156215, 33.99265112195696, 40.03729207175118, 45.92367737633841, 49.7634916305542, 49.4027863230024, 48.055009501320974, 44.83666297367641, 47.26407868521554, 46.66709293637957, 47.390997954777305, 42.65300396510533, 37.85738509041922, 36.98395136424473, 38.040685517447336, 36.03679725102016, 35.75171613693237, 35.17821182523455, 35.339003562927246, 35.022999491010395, 34.64124461582729, 35.16421815327236, 38.02743877683367, 35.25915833881923, 37.098475047520225, 35.08285822187151, 36.46528570992606, 41.91362530844552, 50.542930126190186, 47.910827432359966, 46.82698140825544, 45.641052450452534, 48.34487097603934, 46.506235190800254, 51.58114038194929, 46.751899174281526, 51.18506874356951, 44.52604028156826, 55.47341353552682, 25.809047188077653, 25.077507836478098, 55.507550035204204, 43.18479129246303, 49.444576263427734, 38.67058488300869, 41.262818813323975, 35.84157024111067, 37.63748850141253, 34.67744125638689, 37.96574919564383, 35.79330805369786, 37.042163372039795, 36.98178700038365, 37.698000362941194, 36.058246340070454, 36.71379845482962, 35.643275601523264, 36.049901553562705, 34.60386678150722, 35.60504313877651, 35.77223416737148, 36.42956849506923, 34.10156413487026, 34.05788081032889, 34.71139710290091, 34.2807616506304, 34.34084619794573, 36.77900035040719, 37.912168162209646, 37.2948763029916, 40.31757198061262, 40.87149626868111, 37.71486711502075, 36.91486542565482, 38.59578057697841, 43.90265832628523, 49.892894881112234, 45.63182871682303, 45.151847158159526, 47.816404887608115, 52.33875458581107, 50.460083280290874, 51.60877684184483, 49.70083277566092, 52.361485617501394, 51.09200457164219, 49.401949065072195, 48.76689066205706, 47.89662184034075, 49.533217906951904, 54.96966913768223, 48.648868560791016, 51.42569180897304, 21.4128246647971, 6.438500889710017, 1.6911556018250329, 2.1513629129954746, 0.6241374090313911, 0.10188244695642165, 0.12381278696869101, 2.2426023142678395, 22.236736842564174, 41.80513613564627, 22.88163215773446, 13.701925788606916, 39.09443889345442, 34.39529923030308, 42.10329375948225, 37.26532561438424, 35.301604884011404, 8.248583487101964, 0.13255891336926393, 0.047971743890749555, 0.048863708706838746, 0.02235700622467058, 0.025745191112426773, 0.024021712165059786, 0.04810858404796038, 0.045404930732079914, 0.034726214462092946, 0.027065084216051867, 0.030769663197653632, 0.018955289652304988, 0.0530918877172683, 0.031321936420031955, 0.02248867255236421, 0.04600639435063515, 0.016617999445380907, 0.022713035245292952, 0.0299799366454993, 0.01573392259888351, 0.009671768605975168, 0.006160469476266631, 0.047573559185756106, 0.04826090158894658, 0.04636709338852337, 0.03877137900729265, 0.02400518305200551, 0.005014097284791725, 0.07524401707840817, 0.10760745725461415, 0.019671659783593247, 0.028665933225836073, 0.04265187667416675, 0.1352491011576993, 10.84337956564767, 56.431302615574424, 57.689242703574045, 43.54803269250052, 30.55475194113595, 20.650296347481863, 20.69455463545663, 40.26140969140189, 38.889668532780235, 21.365999017442974, 0.02498092658684722, 0.04683725030294486, 0.10136207845062017, 3.286074310541153, 8.309535690716334, 8.405074289866857, 2.910655541079385, 26.976612057004655, 57.24992547716413, 56.05491522380284, 52.91299193246024, 53.831008774893625, 49.844733442579, 50.186209610530305, 43.29986735752651, 40.18375662394932, 38.31723771776472, 41.881236280713765, 39.93324279785156, 43.420866761888774, 37.61050517218453, 38.28167336327689, 36.29570797511509, 41.93618263517107, 47.988150460379465, 50.74886083602905, 50.12946367263794, 47.96405063356672, 44.42211260114397, 49.15912689481463, 48.654500075748985, 48.691401958465576, 43.27278675351824, 39.28363486698696, 38.840148721422466, 39.20804194041661, 36.39845446177891, 37.289112772260395, 35.67805480957031, 37.198445728846956, 36.624826771872385, 36.9709095954895, 36.429106439862935, 39.72658600125994, 37.07947519847325, 38.885906083243235, 35.9075677054269, 37.312889507838655, 44.95457737786429, 51.654145104544504, 48.73025975908552, 48.80119044440133, 47.04278550829206, 49.831281730106895, 48.36268963132586, 53.77247020176479, 48.47062642233712, 53.54322828565325, 47.04399102074759, 57.36056859152657, 27.76152399608067, 26.61866865839277, 56.334208488464355, 44.89171355111258, 49.51484339577811, 39.70713104520525, 45.02760641915457, 38.80741923195975, 40.5567741394043, 36.09054504122053, 40.32607657568795, 37.460316385541645, 38.81032705307007, 38.22622673852103, 38.57506799697876, 37.19491951806204, 38.52692740304129, 37.24027735846383, 37.79502500806536, 36.413886410849436, 38.147503648485454, 36.9261805670602, 38.074266161237446, 36.05765921728951, 35.48104906082153, 36.179096358163015, 36.2892496245248, 36.81259489059448, 39.1578551019941, 38.080773149217876, 39.0723158291408, 41.35622344698225, 42.7479476247515, 40.32794564110892, 37.89059747968401, 40.469845226832796, 45.824071475437705, 52.7027394430978, 48.404132161821636, 46.46549790246146, 47.43076596941267, 52.79018947056362, 51.66835069656372, 53.58690118789673, 50.09441001074654, 51.79320982524327, 53.652471337999614, 51.69320092882429, 50.39123705455235, 49.511626379830496, 51.19689457757132, 55.633666787828716, 52.133661133902415, 53.773741722106934, 23.365789583751134, 6.57988326890128, 2.696098425558635, 5.29817122220993, 2.3029476361615315, 0.1695935446768999, 0.11106485780328512, 2.3724452555179596, 27.658226864678518, 36.968932832990376, 30.388832432883127, 17.13744694846017, 38.35882616043091, 38.90831749779837, 46.546197754996165, 44.15544421332223, 44.967393330165315, 11.742437379700796, 0.11615621138896261, 0.02316156215965748, 0.03454017373067992, 0.031776249541768005, 0.04141526356605547, 0.044682708236255815, 0.02018199784548155, 0.04478775563516787, 0.036195955239236355, 0.018758309240053807, 0.053005062376282046, 0.007124241108873061, 0.035646436869033744, 0.010404203901998699, 0.05172784233997975, 0.030146757872509103, 0.012489160506187804, 0.12263490445911884, 0.09404336581272738, 0.12002352172774927, 0.1070990241797907, 0.13280891281153473, 0.1594811880162784, 0.14321450516581535, 0.19980649703315326, 0.11645727737673692, 0.1711592370910304, 0.08749081420579127, 0.09718264200325523, 0.1710205716746194, 0.10336098833275692, 0.14830726331898145, 0.11725986216749464, 0.22998806035944394, 15.746634721755981, 66.01486955370221, 63.13777337755476, 51.371231828417095, 36.381229877471924, 24.077206952231272, 27.575857707432338, 48.289101260049, 48.246536595480784, 24.955443620681763, 0.33999101764389444, 0.23493040086967604, 0.1742215606250933, 7.269019067287445, 19.033619029181345, 8.731575352805, 7.248573558671134, 31.053636074066162, 59.367722511291504, 59.96990203857422, 54.742619378226145, 57.17627804619925, 52.524525097438264, 53.01967109952654, 44.0159695489066, 41.556543486458914, 39.522031034742085, 44.4995676449367, 43.17887142726353, 45.269275188446045, 41.45833764757429, 40.49585233415876, 37.541985511779785, 43.72502415520804, 51.748591967991416, 53.35771485737392, 52.73948499134609, 49.37961755480085, 44.41773523603167, 49.430249077933176, 51.38092803955078, 51.76793575286865, 46.207323687417166, 41.411683968135286, 41.6314902305603, 41.01909685134888, 38.34631940296718, 38.845738547188894, 38.17924301964896, 39.17081001826695, 39.16601228713989, 38.77746902193342, 36.79562738963536, 41.02842133385794, 39.56356389181954, 40.65581028802054, 38.24233613695417, 39.071113790784565, 47.40133687428066, 53.84214326313564, 51.5088791166033, 50.17603397369385, 46.92919635772705, 52.0669584274292, 48.775523798806326, 56.72823735645839, 50.94431366239275, 53.90866184234619, 47.99151338849749, 57.96808433532715, 28.118070806775773, 28.9027430330004, 57.46733808517456, 47.09815570286342, 53.28193780354091, 42.58375126974923, 45.74792269298008, 40.75762571607317, 42.48566355024065, 38.25464487075806, 42.49560989652361, 39.43525498253958, 41.211495944431846, 41.61014536448887, 41.0296859060015, 40.77539573396955, 40.23116070883614, 40.129915033067974, 38.53583499363491, 38.11235271181379, 38.912729603903635, 39.43098531450544, 40.090918268476216, 36.82658161435808, 36.788491589682444, 37.95846053532192, 38.26041882378714, 39.37711593082973, 41.91092940739223, 40.08749975476946, 41.68584598813738, 45.004903180258616, 44.493296895708355, 43.80030788694109, 40.371653284345356, 43.624459402901785, 48.87470933369228, 55.03844935553414, 51.30878836768014, 48.31693574360439, 48.95594767161778, 55.899456228528706, 53.626394748687744, 55.84589603969029, 51.73954193932669, 55.40699917929513, 55.0533949307033, 55.55953298296247, 53.61367607116699, 52.57427767344883, 52.114299978528706, 59.99552699497768, 52.509589944567, 57.70145763669695, 24.448199067796978, 14.00891717842647, 6.108470576150077, 13.551219361168997, 3.870062802519117, 0.21963451164109365, 0.3235782597746168, 3.3576259911060333, 34.147067887442454, 53.69845104217529, 34.92572818483625, 21.275170428412302, 47.45653336388724, 43.1671324457441, 55.9486460004534, 50.20326396397182, 54.46138756615775, 14.751327855246407, 0.21152893586882524, 0.0950299014470407, 0.09053291061094829, 0.09544127008744649, 0.15914436323302134, 0.14170533471873828, 0.2037480662443808, 0.09768236947378942, 0.0716375152447394, 0.08622945153287478, 0.154083251953125, 0.05003925027059657, 0.14038966888827936, 0.1329864447138139, 0.14761753247252532, 0.09411919888641153, 0.062487708005521975], [0.032017295714467764, 0.02650154391968889, 0.009377828084065445, 0.06232258650873389, 0.032493345705526214, 0.040717726174209795, 0.02557426644489169, 0.03663981552901013, 0.025707503581153493, 0.022158555087766478, 0.03919633531144687, 0.06769595960421221, 0.06338319781103305, 0.08798232461724963, 0.011859827758079129, 0.046892276100282154, 0.16642072850040027, 13.476320385932922, 46.89126961571829, 47.195965494428364, 42.08267150606428, 27.246443612234934, 21.36760926246643, 34.32993057795933, 36.191408566066194, 35.14640992028372, 9.198443055152893, 0.1383826301566192, 0.0920568663360817, 0.2716532860483442, 2.5364959154810225, 17.233832359313965, 8.356861608369009, 2.472005993127823, 32.98373794555664, 57.68038375037057, 52.257075037275044, 47.628918170928955, 41.57288217544556, 38.96151985440935, 37.099607603890554, 36.72871971130371, 41.721917561122346, 45.325149127415244, 47.61846113204956, 48.48749317441668, 49.28026873724801, 47.38905593327114, 42.36402143750872, 37.1155571937561, 35.67058549608503, 41.569560936519075, 46.27836901800973, 47.84818942206246, 49.50537300109863, 46.752295221601216, 44.769230706351145, 47.75938449587141, 45.68568767820086, 43.852224826812744, 44.35821696690151, 44.19070979527065, 45.68737261635916, 41.247921875544954, 37.18475430352347, 35.11419459751674, 36.62982947485787, 34.50310747964041, 34.476311751774375, 35.92061642238072, 36.35530267442976, 34.89714329583304, 36.221115589141846, 34.20690924780709, 37.40274708611624, 43.457869393484934, 50.073231901441304, 43.83841528211321, 47.89761543273926, 45.51212167739868, 47.51071889059884, 44.17940160206386, 47.78813961574009, 46.703466756003245, 51.06377056666783, 43.28553669793265, 50.293614864349365, 25.265213421412877, 28.560080460139684, 54.34961189542498, 43.167976651872905, 47.428497382572715, 38.70298433303833, 39.3385569027492, 35.483015401022776, 35.444254875183105, 33.006792068481445, 35.84969615936279, 35.32852567945208, 36.95742661612374, 33.92015709195818, 36.82791566848755, 35.892024585178916, 36.206357615334646, 36.27053812571934, 36.99275473185948, 34.58487040655953, 35.36637946537563, 36.542931829180034, 34.76818125588553, 35.72381911958967, 34.341940539223806, 34.20830583572388, 36.38099363871983, 36.19798156193325, 37.186765807015554, 38.35884700502668, 45.55247334071568, 47.00608164923531, 47.2384398324149, 44.83388022014073, 40.07679952893938, 39.84081786019461, 41.79916068485805, 48.49801274708339, 46.63144867760794, 43.17263541902815, 48.34362030029297, 48.512874943869456, 48.05095175334385, 47.84061241149902, 49.57967356273106, 48.64861147744315, 48.325652258736746, 45.5499198777335, 41.60609456471035, 46.059476443699424, 45.804658208574565, 47.66601807730538, 49.80528504507882, 51.47711542674473, 35.778977394104004, 8.868229048592703, 2.9131299683025906, 2.2276226494993483, 0.5555226451584271, 0.018684299729232277, 0.043190124577709606, 0.5416084432176181, 10.911022884505135, 35.586439337049214, 35.258908203669954, 21.773444856916154, 38.71734625952584, 37.68181800842285, 41.515323298318044, 43.32701396942139, 43.628002984183176, 29.05563988004412, 0.5225009513752801, 0.09531945269554853, 0.03359894387956176, 0.08119586841868502, 0.0492471284898264, 0.02029238022597773, 0.0336121787051005, 0.049395127155418904, 0.07436679343559913, 0.017258517843272005, 0.045189814775117805, 0.08525587591741766, 0.051076509790228944, 0.04920486932886498, 0.02980456587725452, 0.10448338703385421, 0.033932240280721865, 0.030358097782092433, 0.03708624407382948, 0.010911208660607892, 0.05068751923473818, 0.02660841657780111, 0.04175077199137636, 0.011644801707006991, 0.06410409377089568, 0.047903106680938175, 0.047951035001980405, 0.023434658933963095, 0.009369872260971792, 0.026463496764855723, 0.046363978912787776, 0.044802211823740175, 0.012987871022362794, 0.18001369839268072, 19.199672290257045, 54.113817828042166, 53.21234464645386, 48.36786603927612, 32.82558652332851, 21.262239830834524, 29.080721139907837, 39.31489828654698, 38.45917204448155, 11.08284228188651, 0.24270752498081752, 0.0682528672207679, 0.653646571295602, 4.853278500693185, 9.011748433113098, 11.604518243244716, 3.7895870293889726, 34.962824617113384, 60.19393975394112, 53.984133175441194, 49.76429762159075, 44.10651499884469, 40.883794580187114, 39.240601199013845, 39.683587074279785, 43.938827174050466, 46.74463135855538, 50.44995628084455, 50.43721328462873, 51.801919392177034, 47.97744328635079, 43.55329247883388, 38.36062574386597, 38.23723268508911, 44.215368952069966, 48.79363080433437, 49.869392599378315, 50.62100008555821, 45.288466112954275, 45.72672026497977, 50.444314343588694, 48.31779037203108, 47.40832328796387, 46.157286235264365, 45.99152306147984, 47.18796116965157, 43.373660700661794, 39.50238847732544, 35.569364139011924, 38.59034708568028, 35.858127798352925, 37.32894679478237, 37.10672950744629, 37.89113596507481, 37.27678319386074, 37.67369556427002, 34.952888693128315, 39.28359317779541, 44.34411212376186, 51.61560344696045, 46.531509263174875, 48.985418455941335, 46.46771090371268, 47.784120082855225, 44.87399217060634, 49.05041537966047, 46.07372719900948, 51.577878202710835, 44.00542565754482, 49.36352900096348, 26.34565656525748, 30.048839705330984, 55.968170438494, 45.880737509046284, 49.39011628287179, 40.416448320661274, 40.61822053364345, 37.22644696916853, 37.60619381495884, 35.52856779098511, 38.18049716949463, 36.02152163641793, 39.66449689865112, 36.90338700158255, 39.264687129429404, 36.062165124075754, 37.772776876177105, 37.354102747780935, 38.839804785592214, 37.099162919180735, 36.40426662990025, 37.703617981501985, 37.073607444763184, 36.39036328451974, 36.08239133017403, 36.35352740968977, 38.201056889125276, 38.10747855050223, 38.344783851078574, 40.042148862566265, 47.45497349330357, 49.86084631511143, 49.46243660790579, 47.0701197215489, 42.71565934589931, 41.386653082711355, 44.861346449170796, 49.95102003642491, 47.49105896268572, 44.77131169182913, 49.57038729531424, 50.595771176474436, 49.768049648829866, 50.49442822592599, 51.50606162207467, 50.153598240443635, 49.83853217533657, 47.78259147916521, 42.64461054120745, 47.359442710876465, 48.44522728238787, 49.17556285858154, 51.92105320521763, 53.76081459862845, 36.595095430101665, 8.319024324417114, 1.3171983425106322, 4.220919472830636, 4.470829674175807, 0.1178162337413856, 0.01437249975944204, 0.3143582445170198, 13.222342014312744, 39.290353775024414, 32.26305341720581, 25.245687246322632, 45.506132330213276, 43.838873863220215, 48.31205810819353, 50.08913285391671, 50.56156519481114, 34.83754859651838, 0.798448387001242, 0.13834818771907262, 0.09303867258131504, 0.0321434862645609, 0.02438097949405866, 0.03560837105448757, 0.03837902970345957, 0.041491025393562656, 0.05160951601075275, 0.014814590769154685, 0.026787117256649902, 0.0233057338877448, 0.04521644727459975, 0.03441655143563237, 0.007622397770839078, 0.06773214587675673, 0.050152843818068504, 0.12926542652504786, 0.08397757022508553, 0.10578979764665876, 0.17718023114970752, 0.1344125760453088, 0.15445031225681305, 0.08283641003072262, 0.13474543818405696, 0.09249431786260434, 0.14712039700576238, 0.14737408767853463, 0.1554762843464102, 0.1415108258702925, 0.23763989976474217, 0.1895492867167507, 0.13668714756412165, 0.5643186845949718, 26.216942923409597, 62.84851292201451, 59.595984731401714, 57.16060985837664, 39.37221050262451, 30.518447603498185, 44.697455814906526, 46.72244923455374, 46.85024397713797, 12.594926629747663, 0.6080897844263485, 0.22440670271004948, 0.7220003977417946, 8.913001503263201, 30.43478087016514, 19.171068293707712, 7.234720153467996, 36.181642872946604, 61.77348068782261, 56.20917565482003, 51.36777509961809, 45.916583265577046, 42.303863934108186, 41.10704020091465, 41.124226570129395, 47.13787508010864, 48.97220298222133, 51.8515990121024, 52.927096775599885, 54.069877420152935, 50.648824146815706, 46.838181904384065, 41.32086059025356, 40.629455770765034, 44.67655563354492, 51.364644936152864, 53.287941047123496, 52.38795130593436, 48.22625132969448, 45.86456905092512, 52.36462620326451, 50.929138796670095, 49.446959495544434, 48.604705810546875, 48.8584748676845, 49.01389217376709, 45.746508734566824, 41.19916636603219, 37.7326579775129, 40.79097012111119, 37.91778925486973, 38.41042348316738, 39.79801000867571, 39.10440608433315, 39.28646278381348, 39.066670417785645, 38.185902867998394, 41.623301778520855, 46.78845017296927, 54.19642148699079, 48.561203139168875, 51.073817661830354, 47.43679700578962, 48.552173955099924, 45.849008560180664, 48.767505577632356, 47.67750344957624, 51.646856444222585, 45.22768327168056, 49.33318274361746, 28.964291913168772, 32.91114316667829, 57.35602099554879, 48.52881063733782, 50.17196580341884, 42.74135378428868, 42.52855478014265, 39.1222699029105, 39.05585902077811, 37.2881817136492, 39.86251013619559, 38.235613754817415, 41.250204358782085, 37.89769506454468, 40.86944655009678, 39.58759423664638, 39.913694041115896, 40.69247940608433, 41.43450880050659, 38.28040879113333, 38.438091209956575, 39.244676317487446, 38.86511707305908, 38.14138228552682, 38.48052733285086, 38.36270325524466, 40.36699799128941, 40.3839932850429, 41.18427637645176, 42.39620549338204, 48.914571149008616, 51.0056071962629, 51.870188917432515, 49.46414239065987, 44.98461444037301, 43.83385031563895, 45.48965120315552, 53.405935355595176, 49.598492758614675, 45.25829356057303, 50.436039039066856, 53.79348502840315, 51.767723832811626, 52.06742743083409, 53.146913460322786, 50.382642132895334, 52.923890181950156, 49.001496587480815, 45.12483603613717, 50.84186942236764, 50.92709602628435, 52.29603706087385, 54.7690155846732, 56.65919658115932, 39.33745561327253, 12.061078292982918, 8.202173863138471, 7.141695065157754, 4.869331445012774, 0.30157985591462677, 0.17166821977921895, 0.6489014944859913, 16.387326376778738, 50.08002029146467, 47.64975929260254, 27.046222584588186, 46.752687794821604, 49.23702662331717, 53.553018297467915, 57.25823204857962, 58.4192864554269, 41.31108447483608, 1.699711548430579, 0.2595980257860252, 0.19843505562416144, 0.15219308409307683, 0.11682971167777266, 0.12910697502749308, 0.16579365357756615, 0.05386235744559339, 0.18813615611621312, 0.08647938312164374, 0.1513385506612914, 0.1861494734351124, 0.10983511486223765, 0.15330675004848413, 0.15673223909522804, 0.10701656181897436, 0.12582051780607018], [0.0744975335629923, 0.040991453986082754, 0.06741016743970768, 0.03212934898744736, 0.046721200458705425, 0.02369116891973785, 0.04282112705654331, 0.042515321501663754, 0.0409002656649266, 0.050512029722865136, 0.06985347026160785, 0.04272165382280946, 0.020741207392088006, 0.069937635745321, 0.0247646859580917, 0.06513358745723963, 1.783709081155913, 31.011300700051443, 53.188022477286204, 48.202325207846506, 38.09867170878819, 24.670400721686228, 26.027625356401714, 46.53971855981009, 30.14130285808018, 28.42411984716143, 2.3742235600948334, 0.08228035058294024, 0.03225730372858899, 0.3163916511195046, 1.4911029594285148, 3.153440364769527, 7.971438952854701, 3.788756285394941, 41.101304462977815, 56.27700744356428, 50.983101981026785, 48.399706159319194, 44.48072065625872, 44.126477173396516, 45.49832602909633, 49.82934318270002, 50.945251669202534, 50.26448801585606, 54.171109199523926, 49.627758571079795, 50.234840052468435, 49.33824798039028, 49.39553935187203, 39.22737877709525, 34.65555790492466, 35.182335581098286, 40.51889256068638, 44.8774037361145, 46.39242022378104, 49.080285685403005, 45.4552298273359, 45.34159551348005, 49.077009609767366, 47.034579685756135, 47.324823311397004, 47.858448437282014, 48.157578808920725, 48.61934913907732, 44.10337788718087, 35.67673812593733, 35.741366795131135, 34.63726329803467, 34.87576368876866, 33.43043415887015, 36.687648909432546, 34.10372155053275, 35.78721100943429, 34.567347049713135, 36.676413672310964, 42.0419203213283, 47.72441421236311, 47.60686111450195, 51.11047635759626, 48.72498607635498, 50.891580309186665, 47.68394095557076, 49.849058696201865, 46.361271449497764, 50.2828277860369, 46.08067887169974, 55.61010544640677, 29.093919243131364, 29.630429608481272, 56.024728775024414, 42.93166841779436, 46.80682815824236, 37.75394030979702, 39.742052691323416, 32.87504380089896, 34.56885480880737, 34.07717943191528, 38.68550613948277, 36.650312764304026, 37.528478213718955, 35.69468184879848, 36.35848842348371, 34.87752505711147, 35.428708280835835, 34.5417012487139, 36.30387558255877, 35.21916798182896, 35.833215032305034, 34.88998317718506, 36.410068375723704, 35.17873988832746, 37.583094528743196, 35.4043687411717, 35.570232663835796, 34.36929907117571, 41.94921745572771, 46.621762888772146, 48.521990980420796, 49.17054278509957, 49.24569797515869, 46.787119592939106, 43.995260443006245, 42.14616067068917, 45.074353899274556, 46.22018827710833, 50.19873373849051, 48.05180638177054, 48.08112777982439, 49.072833742414204, 46.07254600524902, 47.181860651288716, 49.465834277016775, 49.111893040793284, 47.30502789361136, 40.16915151051113, 44.45876087461199, 50.286291463034495, 54.7716246332441, 57.50408015932356, 49.975654874529155, 52.189667088644846, 42.53364780970982, 18.834976979664393, 2.299385815858841, 2.9263413165296828, 2.194752241883959, 0.2126732308949743, 0.19626904970833234, 0.027457913583410636, 4.561848904405322, 27.407339572906494, 32.23171009336199, 18.787619795118058, 9.690583092825753, 18.080843823296682, 27.977746725082397, 41.13962377820696, 44.08184889384678, 38.1816714150565, 4.28590988261359, 0.04946868035144039, 0.015416157864300268, 0.02489116318923022, 0.0614156091053571, 0.021703744939129268, 0.04001399715031896, 0.014352935898516859, 0.03065056333850537, 0.06678963359445333, 0.04541028437337705, 0.0330259583757392, 0.05281585627900703, 0.012682279206014105, 0.014433696832773941, 0.04623555937515838, 0.08315458867166724, 0.045594068975853067, 0.033886354350085766, 0.10165097152015992, 0.014521261776930519, 0.0006253754046546029, 0.00482883008329996, 0.08466202206909657, 0.038709768027599366, 0.016496558640418307, 0.022203487676701376, 0.024050731411469833, 0.026544374746403525, 0.039120230823755264, 0.05738788630281176, 0.005380042246542871, 0.06799311723027911, 2.3756770363875797, 39.166151251111714, 59.31586810520717, 52.51713916233608, 44.533019747052876, 30.508709703172954, 26.731967721666607, 44.42253991535732, 35.4550975390843, 33.9998459815979, 2.863041056053979, 0.15772545151412487, 0.015015861219061273, 0.8822746574878693, 6.198543548583984, 8.34443736076355, 9.1990327835083, 5.0459094899041315, 40.72781099591936, 59.118108476911274, 52.25085987363543, 50.521491459437776, 45.00326687949044, 44.79198605673653, 45.366730621882844, 49.98057072503226, 51.83780683789934, 52.44851875305176, 54.74471426010132, 51.389738355364116, 51.83726487840925, 50.904107911246165, 50.98732648577009, 41.082808358328684, 36.914924485342844, 37.331670488630024, 41.868931021009175, 46.656260694776265, 48.77283137185233, 49.84027617318289, 45.49706493105207, 46.06754330226353, 50.55459615162441, 49.671639919281006, 49.50550849097115, 49.32822520392281, 49.5303760937282, 50.076386383601594, 44.05687359401158, 37.060968671526226, 37.06464079448155, 38.09587158475603, 36.04002816336495, 35.23900508880615, 37.48711906160627, 36.529983861105784, 36.17873157773699, 36.30255542482649, 38.04798460006714, 43.65206459590367, 48.67297880990164, 50.0558614049639, 50.557344164167134, 52.10855381829398, 53.2343704359872, 49.89025803974697, 49.988644531794954, 47.854960441589355, 52.89351265771048, 47.33739260264805, 55.629386697496685, 30.104859556470597, 31.274748597826274, 56.85775177819388, 45.59013952527727, 49.61507116045271, 40.225126198359895, 40.17352887562343, 35.16638946533203, 37.58025966371809, 35.46238967350551, 38.966289792742046, 39.239180292402, 39.14517116546631, 37.470485074179514, 37.86022342954363, 37.45655741010393, 37.933005809783936, 36.48129088538033, 37.28178937094552, 37.42514113017491, 37.795768465314595, 36.41364669799805, 37.98218515941075, 37.17100381851196, 38.85804728099278, 36.95998007910592, 36.761341503688264, 36.4880028452192, 41.82432011195591, 48.94232225418091, 51.30386209487915, 50.98411989212036, 51.77797589983259, 47.80203601292202, 46.81601367677961, 44.21080051149641, 48.2448273386274, 49.1868189402989, 51.69626161030361, 49.74440145492554, 49.65293189457485, 51.63654184341431, 48.60193695340838, 49.50494916098458, 50.273378235953196, 51.66915668760027, 49.8369653565543, 41.9849659374782, 46.27207395008632, 52.44659757614136, 55.54750912530081, 58.793544224330354, 52.249039445604595, 52.80329377310616, 41.61370979036604, 20.042898723057338, 2.8179450758865903, 3.5317083299160004, 1.9913432938711983, 0.9333535794700895, 0.6858653138790811, 0.05546443969277399, 5.376034472669874, 32.684784752982004, 37.917056219918386, 21.42374723298209, 15.850948027202062, 24.70022760118757, 32.98500599179949, 45.166354996817454, 51.102572781699045, 45.34730693272182, 6.296442798205784, 0.14931985469801085, 0.04290763009339571, 0.0484522654275809, 0.019273534450413923, 0.054794325293706994, 0.05732085382831948, 0.025527795277802006, 0.030620524593229805, 0.06566190160810947, 0.09071035430367504, 0.07572351063468627, 0.024986259872093797, 0.03098479611799121, 0.05008494281875236, 0.037620963595275364, 0.04430492029392293, 0.14114563832325594, 0.10381843628627913, 0.17453949499343122, 0.19693129988653318, 0.09029587797288384, 0.08681006037763186, 0.12190299587590353, 0.14334550313651562, 0.09118365283523287, 0.1379592243049826, 0.10293338234935488, 0.10233840213290282, 0.08945453526186091, 0.18377499442015374, 0.07867240346968174, 0.21048661108527864, 3.61332534466471, 46.756443296160015, 65.39050442831856, 58.988218852451865, 49.74748992919922, 34.847206592559814, 36.42443725040981, 56.092240946633474, 41.047212736947195, 40.041728496551514, 3.6680413229124884, 0.17159202029662474, 0.1754926602755274, 1.1344743988343646, 7.22440207856042, 10.614194103649684, 16.992278235299246, 7.141404977866581, 43.39950105122158, 61.30738162994385, 55.89754547391619, 53.894299915858674, 49.1226349558149, 47.32582037789481, 50.01544025966099, 53.515928813389365, 55.162690094539094, 53.10475179127285, 57.34409441266741, 55.263491085597444, 53.8148854800633, 53.27101523535592, 53.03480427605765, 43.27869619641985, 37.9852180480957, 38.09729249136788, 44.500047070639475, 49.32149239948818, 50.26088537488665, 51.695264543805806, 46.60743222917829, 47.49454001017979, 53.82334838594709, 50.56742252622332, 51.97932774680001, 51.31294339043753, 52.765266282217844, 52.30439574377877, 47.42000320979527, 38.926733698163716, 38.72427013942173, 39.27136434827532, 38.08927774429321, 37.455838271549766, 38.37462636402675, 37.82614598955427, 38.81540271214077, 38.58154719216483, 39.31651374271938, 46.10627603530884, 50.74100937162127, 50.50124440874372, 53.604949133736746, 53.989521503448486, 54.26920734133039, 51.6008871623448, 52.46840797151838, 49.880273478371755, 54.089429650987896, 50.92739827292306, 57.48737668991089, 32.501842158181326, 33.442284311567036, 59.82014751434326, 48.27597263881138, 51.477223123822895, 42.912067549569265, 42.35710450581142, 36.82670668193272, 38.453373772757395, 37.687633650643484, 40.86225516455514, 40.64223003387451, 40.36401373999459, 39.10086597715105, 40.3670084135873, 38.997108527592246, 39.78028167997088, 38.92852633340018, 40.14413799558367, 38.40982246398926, 40.07912022726876, 38.76816885811942, 40.905448641095845, 38.55235433578491, 41.0399831363133, 39.260924679892405, 38.67058835710798, 38.48946271623884, 43.62701981408255, 51.57987233570644, 53.963125297001426, 54.53403098242623, 53.067867279052734, 50.957230363573345, 48.35085684912545, 46.582599367414204, 50.743333544049946, 50.70342656544277, 53.70232118879046, 49.0831344468253, 51.35942683901106, 53.971668107169016, 51.59746517453875, 52.46925217764718, 53.00197751181466, 54.07050970622471, 52.52071401051113, 44.29037822995867, 49.540687220437185, 54.881486075265066, 57.362319537571494, 59.36294215066092, 53.205139364515034, 53.34483289718628, 44.67455455235073, 23.283463852746145, 7.188319649015154, 9.559166601725988, 9.961145945957728, 0.7909248449972698, 0.4655401621546064, 0.1775325672434909, 6.7567214369773865, 40.42408439091274, 45.55797978809902, 26.209574358803884, 16.452413627079554, 27.589021069662913, 39.2109706061227, 53.748224462781636, 55.83192321232387, 53.34336335318429, 8.271131260054451, 0.21678363318954194, 0.12086206887449537, 0.10560758385275092, 0.1212022320500442, 0.0983203077422721, 0.13511005576167787, 0.12542166135140828, 0.1901255665080888, 0.16678705598626817, 0.1365626771003008, 0.08776107470371894, 0.09892718267760106, 0.1529776877058404, 0.14235949675951684, 0.12115891437445368, 0.10820166394114494], [0.0254864317830652, 0.03698536966528211, 0.024777018332055638, 0.01923989438052688, 0.040902277521256886, 0.03580540744587779, 0.012927382169956607, 0.04209768319768565, 0.009823206595943441, 0.0504657604199435, 0.08625029612864767, 0.020857903540932705, 0.04773745931951063, 0.013707912876270711, 0.06742934962468487, 0.029775002106492008, 4.213720270565577, 36.98791878564017, 49.53802258627755, 37.48930427006313, 35.733084542410715, 28.07330182620457, 31.453970432281494, 30.557892526899064, 30.225608825683594, 20.36976977757045, 0.9154506772756577, 0.0702061727643013, 0.1279376284884555, 0.5777757167816162, 4.175082640988486, 3.997040263244084, 8.535713451249258, 2.9283597682203566, 37.57561479296003, 57.42033699580601, 49.23837457384382, 50.3300963810512, 48.44229514258248, 50.997491700308665, 47.580596923828125, 50.58551910945347, 49.3153258732387, 52.0686468396868, 42.78008304323469, 47.31493602480207, 50.673101152692524, 49.664153235299246, 48.84550258091518, 40.9798777444022, 33.93861150741577, 38.135267870766775, 39.56810106549944, 42.35026747839791, 46.32244144167219, 49.9178250176566, 47.82030977521624, 43.13623033251081, 46.1871600151062, 47.246034213474815, 48.691148349217, 47.338115215301514, 48.00685501098633, 48.23755257470267, 46.52705199377877, 39.708412987845286, 33.59999104908535, 34.39492750167847, 35.472808497292654, 36.28333323342459, 36.975054195949006, 35.57659026554653, 35.1015419278826, 33.55002307891846, 37.31765249797276, 38.58365249633789, 42.90799937929426, 42.51761136736189, 43.805755274636404, 44.39309344972883, 46.930940355573384, 46.430861132485525, 48.77890062332153, 47.242744241442, 49.07069022314889, 44.913440568106516, 52.86879096712385, 34.87204640252249, 35.759845529283794, 52.29050976889474, 43.99811962672642, 46.3388044493539, 38.125613348824636, 39.67675004686628, 37.07268680844988, 39.96393299102783, 41.46486548015049, 44.3725128855024, 42.9682993207659, 42.26189334051949, 37.626673630305696, 36.930359908512656, 34.48874207905361, 35.691853931971956, 35.654500416346956, 35.52730321884155, 35.5818361554827, 35.75383186340332, 36.99215371268136, 35.238946029118125, 38.74512168339321, 36.713801928928916, 35.891020570482524, 38.9374999318804, 42.38535588128226, 45.43238067626953, 46.94219296319144, 49.14775269372122, 45.722061497824534, 48.52008717400687, 50.051560470036094, 46.8685177394322, 46.96842588697161, 47.63962881905692, 47.348996094294954, 47.47850356783186, 47.202003479003906, 48.426581791469026, 50.0345721244812, 45.723364285060335, 43.4301495552063, 42.2500501360212, 43.43041011265346, 36.91962841578892, 43.65113353729248, 46.20337363651821, 54.11734751292637, 43.32873364857265, 35.848719937460764, 54.42269304820469, 49.91588994434902, 54.23123543603079, 30.164895466395787, 7.570244755063738, 3.13899136866842, 4.218669559274401, 0.3247244139867169, 0.07806282117962837, 0.06918235163071326, 1.2838119225842612, 20.998599120548793, 33.64822891780308, 33.19448723111834, 24.86692704473223, 20.717202288763865, 36.35083845683506, 42.3909387588501, 44.28388513837542, 38.40543120247977, 12.557660835129873, 0.09429183176585607, 0.029989500596587147, 0.03149647259020379, 0.039387471840849946, 0.04742898712200778, 0.010521513276866503, 0.06442876599196877, 0.018715025491214225, 0.030704754537769725, 0.04083995068711894, 0.017936023185029626, 0.037520431846912415, 0.011645266503494765, 0.065012509668512, 0.09243597742170095, 0.011198734482085066, 0.03538564871996641, 0.0252865981310606, 0.011065634749164539, 0.006619239300822041, 0.03537535873640861, 0.014848502253049185, 0.018457031210086176, 0.025802970065602233, 0.060483546262340884, 0.01993960647710732, 0.018947077682241797, 0.04709092740501676, 0.0561985060173486, 0.014392547076568007, 0.06213041860610247, 0.030801045442266122, 5.275492736271449, 45.46803535733904, 55.502860001155305, 44.47225080217634, 39.86422981534685, 34.68661982672555, 37.21243592670986, 38.77276161738804, 35.280141898563926, 22.643350635256084, 0.6100457566125053, 0.02247157346989427, 0.10244090841817004, 2.0072813757828305, 7.34039660862514, 6.6354875309126715, 10.148888877459935, 6.53590030329568, 40.83274963923863, 60.97272859300886, 52.0625011580331, 51.01533120019095, 51.317953041621614, 52.54707200186593, 52.07934359141758, 53.40948935917446, 50.9560352734157, 51.09007297243391, 44.566992964063374, 50.2787526675633, 52.43837090900966, 51.57754816327776, 52.08898769106184, 42.88140514918736, 36.18432140350342, 40.66289397648403, 40.29120009286063, 44.85908481052944, 47.23473644256592, 51.08284337180001, 49.14978504180908, 42.50647687911987, 48.412167753492085, 49.46178347723824, 49.7997681753976, 48.65968343189785, 49.04786539077759, 50.423761572156636, 47.60018389565604, 41.06209577832903, 35.422302041734966, 37.11175305502755, 35.64315400804792, 37.650565011160715, 38.6786447933742, 38.27949857711792, 37.10312686647688, 35.30501297542027, 38.50137540272304, 39.642554487500874, 45.255615030016216, 45.345017501286094, 46.151814528873985, 46.78508724485125, 49.34656844820295, 48.42700910568237, 50.43305131367275, 49.03706094196865, 51.00003126689366, 46.19868360246931, 55.25243302753994, 35.50926569529942, 36.306634017399375, 53.33816262653896, 46.348292214529856, 48.16309220450265, 39.467619691576274, 41.2303637777056, 38.99555907930647, 41.30160365785871, 42.800375257219585, 45.626416070120676, 44.84773145403181, 43.96290963036673, 39.10135235105242, 37.47604015895298, 36.68763501303536, 37.3979424067906, 36.56945310320173, 38.0922828401838, 36.73274619238717, 36.81389420373099, 37.35575989314488, 37.914843218667166, 40.136595726013184, 39.09686728886196, 38.35983712332589, 39.22841058458601, 43.661316122327534, 49.142920221601216, 49.27759368079049, 50.964647565569194, 47.40148278645107, 49.65795544215611, 50.93179995673043, 48.07760156903948, 48.43689291817801, 48.9714595249721, 49.846762316567556, 48.839204038892476, 46.97647190093994, 51.326263087136404, 51.822493008204866, 47.09149585451399, 43.57314000810896, 45.04030425207955, 46.369727407182964, 38.985584940229145, 44.65022543498448, 48.622552258627756, 56.49010174615042, 46.60664013453892, 38.51863125392369, 55.41927317210606, 51.37267705372402, 55.55490548270089, 31.74075038092477, 7.9983936207635065, 1.6682312147957938, 2.596690114055361, 2.626662688595908, 0.36492503540856497, 0.0483005992802126, 1.3840486982039042, 25.511501005717687, 34.960055759974885, 38.149869510105674, 23.941187279564993, 22.616718190056936, 39.182802609034944, 47.17051076889038, 49.8115280015128, 47.44853251320975, 17.377435990742274, 0.07206202710845641, 0.007100022073635566, 0.024326829006895423, 0.043101412909371514, 0.048402898612299135, 0.030124505316572528, 0.03636629806299295, 0.03641869792980807, 0.06812986239258732, 0.07069753389805555, 0.015761376125738025, 0.0519729563301163, 0.018759347398632338, 0.026450691112716283, 0.05629388089956982, 0.0198514613855098, 0.15016624570957252, 0.09953182523271867, 0.0862944619730115, 0.07519321516156197, 0.10673451516777277, 0.09618012686925274, 0.14387926592358521, 0.21623023359903268, 0.13332940345363958, 0.1060987753527505, 0.12124754461858954, 0.09086099586316518, 0.14226173343402998, 0.10745178775063582, 0.13366611967129366, 0.17750276598547185, 7.868919151169913, 53.939723764147075, 62.75422586713518, 50.23198781694685, 46.745767389025005, 38.6499730518886, 41.40132767813546, 40.526459148951936, 40.960485322134836, 28.5480374949319, 1.52409984597138, 0.13338792031364782, 0.286906183298145, 2.6228572470801215, 11.624628067016602, 13.961612973894391, 16.78789871079581, 5.702452157224927, 42.38474096570696, 64.24434348515102, 54.08502796718052, 54.57737384523664, 54.105209009987966, 54.542250701359336, 53.23658691133772, 55.17334863117763, 53.6276593208313, 53.24859339850289, 46.746066161564414, 53.289980343409944, 53.37788200378418, 53.99409341812134, 53.22709914616176, 45.870429856436594, 37.97740479878017, 43.28079455239432, 42.25495556422642, 45.93538509096418, 50.14947101048061, 53.133235931396484, 49.850559507097515, 42.467546122414724, 47.66561508178711, 50.18694959368025, 52.51226847512381, 51.08556359154837, 50.9634872164045, 52.695805140904014, 49.20017337799072, 43.725090163094656, 37.408795492989675, 37.615594727652415, 39.14186034883772, 39.030414717538015, 40.53993170601981, 40.96940333502633, 38.49720300946917, 36.626386642456055, 40.22208636147635, 42.09723840441023, 47.0893314906529, 46.36878940037319, 46.934490885053364, 48.12705189841134, 50.848737716674805, 50.22742632457188, 52.15990447998047, 51.19459472383772, 51.98843336105347, 49.62135233197893, 56.940490927015034, 38.18411718096052, 38.90984957558768, 53.84534638268607, 48.275461946214946, 50.69565153121948, 41.677428245544434, 44.64584459577288, 40.88790096555437, 43.47605282919747, 45.305506569998606, 46.88846949168614, 47.60908106395176, 46.75504323414394, 41.30815928322928, 39.89823429925101, 38.34356444222586, 39.40185151781355, 39.454928806849885, 39.290989535195486, 37.79758889334542, 37.95076540538243, 40.76662015914917, 39.05967705590384, 42.55352660587856, 40.73236901419503, 39.75742558070591, 42.541447162628174, 46.10895456586565, 51.724599838256836, 51.544940267290386, 52.54101317269461, 48.55786452974592, 50.53651693889073, 53.328758239746094, 51.37193707057408, 50.2227988243103, 52.511174133845735, 50.79628229141235, 49.76697962624686, 47.125990186418804, 52.0816330228533, 54.70758308683123, 51.01888172967093, 46.01634202684675, 47.10510042735508, 47.3718660899571, 40.932383332933696, 47.76071160180228, 52.65652002607073, 58.111842564174104, 49.814963885716026, 43.93143776484898, 56.615089416503906, 52.24452659061977, 57.7501471383231, 33.76080015727452, 9.659486430031912, 5.891985986913953, 10.241890515599932, 2.2136506906577518, 0.2880444936454296, 0.10032139572181872, 2.2611785403319766, 30.24806887762887, 46.07808371952602, 46.08287450245449, 34.396282400403706, 31.12995856148856, 48.43400594166347, 54.931752817971365, 56.732010228293284, 54.077878270830425, 20.405631167548044, 0.2055414750107697, 0.10084759962878057, 0.09093271701463632, 0.08548999764025211, 0.15853354600923403, 0.20111499753381523, 0.12786640945289815, 0.13774089887738228, 0.16397372766264848, 0.10714291861014706, 0.10454716932560716, 0.1549284623137542, 0.08742492167013032, 0.13425873858588083, 0.14883877336978912, 0.1187897686447416], [0.0432929904865367, 0.015484360811699713, 0.03160392200308187, 0.0212220800707915, 0.01942040505153792, 0.09589126094111375, 0.029103048877524476, 0.01996902097016573, 0.012699842236803045, 0.019295081329931105, 0.012670355649398906, 0.07049691823444196, 0.0798482775155987, 0.03473382762500218, 0.03701291818703924, 0.18711808217423304, 7.8698979786464145, 44.040802410670686, 47.26704904011318, 46.119522775922505, 34.47976500647408, 14.893719026020594, 24.198746579033987, 24.869438818522863, 32.66373865944998, 21.60241494859968, 0.42814986993159565, 0.08086586969771556, 0.7163189968892506, 1.619513920375279, 7.4670900617327005, 10.003474371773855, 8.395428453172956, 3.5871773191860745, 30.152704851967947, 59.18399824414934, 50.392185483660015, 53.78657157080514, 51.60179042816162, 52.78828566414969, 49.789658546447754, 50.50760548455374, 50.97401373726981, 47.56730154582432, 45.580436365945, 49.894944599696565, 46.67315523965018, 46.858995233263286, 45.373737880161826, 40.76650203977312, 34.851785455431255, 41.597131388528005, 45.93068463461739, 47.302957330431255, 45.761155537196565, 48.897839886801584, 45.247346673692974, 43.59937988008772, 43.83176933016096, 43.342894077301025, 44.912057876586914, 43.18047646113804, 43.36636856624058, 47.81447328839983, 46.57863194601876, 41.29333182743618, 33.50949771063668, 34.461640630449565, 34.55951990400042, 35.62256302152361, 35.662605490003315, 33.26642540522984, 33.99301242828369, 34.17443336759295, 35.340487003326416, 37.39064679827009, 36.3229900768825, 36.89874907902309, 36.477726459503174, 35.73263985770089, 38.516974108559744, 37.675217219761436, 41.24620567049299, 38.8531105858939, 43.15274620056152, 44.37116493497576, 53.920883723667686, 36.31903655188424, 36.64138780321394, 50.63166904449463, 43.94354847499302, 44.555247034345356, 38.24129738126482, 43.442812647138325, 42.650377546037944, 47.2803235735212, 46.323164054325645, 46.83022621699742, 47.20382738113403, 48.21300458908081, 44.21023423331124, 37.02203096662249, 34.99221549715315, 36.11779587609427, 34.486775738852366, 36.44620248249599, 34.714909417288645, 36.264712061200825, 35.25014305114746, 39.59891285215105, 42.195249693734304, 41.28128712517874, 38.490365982055664, 43.77991839817592, 45.34347152709961, 48.14905684334891, 49.361851011003765, 46.6695282799857, 45.73925828933716, 47.60479055132185, 49.633400508335654, 47.0829565184457, 49.565589564187185, 48.81656680788313, 45.8652742930821, 45.6223270552499, 44.91133873803275, 48.42656094687325, 48.032191617148264, 43.61390508924212, 40.508056844983784, 36.56825106484549, 40.4699251311166, 36.16836486543928, 45.47663722719465, 48.66624253136771, 54.62386424200875, 32.46369307381766, 30.959831918988908, 55.63266624723162, 49.65499898365566, 55.50362082890102, 46.51363502229963, 19.58437841279166, 4.817444469247546, 1.413868629506656, 2.1066688426903317, 1.8582685717514582, 0.18677456703569206, 0.4725059483732496, 11.816587686538696, 48.477456501552034, 24.071693556649343, 16.291734797613962, 22.1516717842647, 31.685407979147776, 36.77672134126936, 44.2596880367824, 40.01972702571324, 19.11713116509574, 0.13318860743727, 0.13401806221476623, 0.018027694962386574, 0.05936246391917978, 0.01594723026002092, 0.03574531638462629, 0.011341974072690521, 0.05773448199033737, 0.03278170951775142, 0.07324322765426976, 0.01429104502312839, 0.028802841236548762, 0.019511301602636064, 0.05536279175430536, 0.0741505782519068, 0.07870049481945378, 0.05178445251658559, 0.08130001675869737, 0.013732609854611968, 0.016902039293199778, 0.013331118139571376, 0.042012123324509175, 0.036234248363013775, 0.011526259094742792, 0.029055161268583367, 0.02553699621265488, 0.031635138006614785, 0.11776835631046977, 0.10483997075685433, 0.03052915306761861, 0.04138332153005259, 0.24767060152121953, 11.431886775153023, 54.37871789932251, 54.567754064287456, 49.574198382241384, 41.539016655513215, 25.60933337892805, 30.190635068076, 30.11767898287092, 35.049982820238384, 22.45519862856184, 0.20954313528324875, 0.07893346303275653, 0.5314031679715429, 2.183804052216666, 6.876511420522418, 9.464744056974139, 8.757488659449987, 4.190148072583335, 32.59101186479841, 60.62841756003243, 52.90480695452009, 55.41422183173043, 53.18966225215367, 53.537596770695274, 51.9780319077628, 52.5222669328962, 50.91808768681118, 48.67355898448399, 47.989863191332134, 52.381440843854634, 47.536451544080464, 50.16777951376778, 48.000514779772075, 42.19717781884329, 35.91381066186087, 43.414488315582275, 47.784137453351704, 47.50877339499337, 46.909862995147705, 51.25121906825474, 45.65089109965733, 43.60486895697457, 43.19694021769932, 43.3884916305542, 44.82458005632673, 44.362097535814556, 45.98822961534773, 49.11497804096767, 48.59070519038609, 43.862351826259065, 35.54972505569458, 37.0780473436628, 36.03890950339181, 38.03268814086914, 37.12625394548689, 35.436469418661936, 35.058747972760884, 36.443913051060264, 37.389055660792756, 39.250196661267964, 38.2083420753479, 39.49862602778843, 38.84614849090576, 37.91736194065639, 40.48103877476284, 39.497034890311106, 43.17596708025251, 41.35396180834089, 44.470631871904644, 45.09328774043492, 55.374891553606304, 37.915510245731895, 38.81279018947056, 54.608227321079795, 45.54725176947457, 45.702398095812114, 40.866576944078716, 43.290344851357595, 45.53452614375523, 48.68790701457432, 47.883034637996126, 49.32183633531843, 48.38877664293562, 49.226552213941304, 45.61266558510916, 39.79765565054757, 37.20856925419399, 37.76206275394985, 36.66488313674927, 37.19815043040684, 35.32552753176008, 38.74979087284633, 36.51794263294765, 41.85710866110665, 43.7377393586295, 43.96013035093035, 40.89730535234724, 45.13391733169556, 47.681533404758994, 49.534333092825754, 51.81394672393799, 46.42848832266671, 47.15085778917585, 47.54177386420113, 50.87477609089443, 50.14336354391915, 52.0841760635376, 50.96813556126186, 46.242325237819124, 46.64441054207938, 45.650064264025005, 49.981307234082905, 49.60186958312988, 46.38271359034947, 43.99315166473389, 38.74545519692557, 42.489148071834016, 39.868794781821116, 46.92664289474487, 51.28220803397042, 55.05348178318569, 36.189456122262136, 36.01544543675014, 57.041625431605745, 50.37062522343227, 57.72451523372105, 47.28853287015642, 22.039571285247803, 3.2123513179165974, 4.14726596219199, 4.184894365923745, 1.3374540784529276, 0.24977951550057956, 0.19952270654695375, 15.794561658586774, 48.33852727072579, 26.8443409374782, 22.507530723299297, 25.154905557632446, 35.28918150493077, 41.854534353528706, 49.71525028773716, 48.08662380490984, 24.066624845777238, 0.2774621700601918, 0.0332093494279044, 0.021256822760083845, 0.032219417725822756, 0.009757725422137549, 0.04110968192773206, 0.001003281878573554, 0.05640657538814204, 0.008913807670718856, 0.02483260052810822, 0.01832006043488426, 0.008499462806087519, 0.02787535511223333, 0.03123467681663377, 0.012412092498769718, 0.05826771552009242, 0.1360896024852991, 0.14343656253601822, 0.11218613013625145, 0.08814839606306382, 0.08883144333958626, 0.14552187706742967, 0.23751564643212728, 0.18975644345794404, 0.13809110437120709, 0.08982210446681295, 0.09843810820685965, 0.16941142587789468, 0.2343301416507789, 0.13903016969561577, 0.10900199599564075, 0.339473159717662, 16.003266436713083, 63.16684464045933, 60.13213552747454, 57.54060683931623, 46.08368744168963, 23.148576736450195, 31.269461018698557, 33.72012192862374, 42.90981980732509, 27.193149191992624, 0.8987891684685434, 0.22092178756637232, 1.857830400977816, 3.7786145210266113, 14.855210372379847, 15.520905120032173, 19.035125051225933, 7.203762888908386, 34.351133005959646, 63.39985942840576, 54.965753827776226, 57.07768310819353, 55.27812051773071, 56.62017549787249, 52.954563004629954, 52.835703645433696, 52.238012654440745, 50.70204734802246, 51.55356992994036, 54.40575681413923, 50.73770202909197, 51.04140778950283, 49.96323149544852, 43.603628703526084, 38.26693275996617, 45.567964349474224, 50.33802774974278, 50.58168717793056, 49.46944734028408, 53.082222257341655, 46.20853614807129, 42.96905320031302, 43.210371085575645, 43.348966802869526, 44.758474894932334, 43.133572646549766, 46.20398160389492, 50.694838591984336, 50.32686199460711, 45.59508316857474, 37.76192031587873, 39.71095255443028, 38.694764614105225, 40.69271217073713, 39.19320406232561, 36.76131023679461, 37.05708115441458, 37.42923361914498, 38.900302750723704, 41.05069031034197, 40.20495210375105, 41.281221117292134, 39.99648182732718, 38.518794536590576, 43.012055601392476, 41.03945507322039, 46.58171694619315, 41.69906841005598, 46.78308963775635, 48.34176860536848, 58.39724676949637, 39.57410083498274, 41.31789370945522, 55.10838644845145, 48.21950115476336, 48.89632865360805, 41.680527142116, 47.31563431876046, 47.05779014314924, 50.384691851479666, 50.280861445835654, 50.14459337506975, 50.561297689165386, 50.523454325539724, 47.919359820229666, 42.10742793764387, 37.62956755501883, 39.69942896706717, 38.681840964726035, 39.02445316314697, 37.269817624773296, 39.785187108176096, 39.73717505591256, 44.06761203493391, 45.92521292822701, 45.398692335401265, 42.93405164991106, 47.569080284663606, 50.370086738041465, 53.17206941332136, 52.77016476222447, 48.106794425419395, 48.564753668648855, 47.90644659314837, 52.278982707432334, 52.100424425942556, 53.59844214575631, 53.966436113630024, 47.83915328979492, 46.95839616230556, 46.75745078495571, 50.214540890284944, 52.111492906297954, 49.19745315824236, 44.60537133898054, 40.7270883832659, 44.294088568006245, 40.78149972643171, 49.44059841973441, 54.14716918127877, 57.599124567849294, 38.43933146340506, 37.73216812951224, 57.139021805354524, 53.71862513678414, 60.74026271275112, 51.651306765420095, 22.42076335634504, 7.944955893925258, 3.629000263554709, 3.673288949898311, 3.722592064312526, 0.3447048275598458, 0.900979750922748, 17.556916645595006, 62.162684031895225, 33.012281145368306, 27.99680389676775, 30.872923851013184, 43.578410216740195, 49.05667918069022, 58.24515765053885, 53.275910241263254, 32.46893548965454, 0.5372148475476674, 0.14255723543465137, 0.17253397618021282, 0.1450191776135138, 0.1098216934395688, 0.11624539803181376, 0.11921597006065504, 0.16567356644996575, 0.07427878744368042, 0.16467500717512198, 0.11960762047341891, 0.15606350212224893, 0.08660599097077336, 0.12909579277038574, 0.18520151930195944, 0.1944466946380479], [0.02267819077574781, 0.03800111623214824, 0.014002431849283832, 0.07714833917894534, 0.020866626108597432, 0.06121262535452843, 0.019324424576812556, 0.04627808995012726, 0.055046635147716315, 0.030474188338432993, 0.0266052834423525, 0.029377160061682974, 0.021007547653945427, 0.07123012960489307, 0.037111332906144004, 0.31487184124333517, 19.313822507858276, 52.81482778276716, 44.92317846843174, 39.00093698501587, 22.30743476322719, 15.750650780541555, 40.81904084341866, 38.100443499428884, 41.62038006101336, 12.841118676321846, 0.057161676298294745, 0.6296546044094222, 25.337924582617624, 11.049889581544058, 3.3629800123827795, 4.415855526924133, 6.316611681665693, 5.956126110894339, 20.207350424357823, 56.08091538293021, 50.00996855327061, 55.61199535642351, 51.84031861168997, 51.08881187438965, 49.95619991847447, 51.13935307094029, 47.700151102883474, 49.52516841888428, 49.04178919110979, 47.019581999097554, 45.58972610746111, 45.40179123197283, 42.29073531287057, 38.50377600533621, 39.26488515308925, 47.668964113507954, 46.75194781167166, 47.14068215233939, 47.91375609806606, 45.76279183796474, 45.0673223223005, 46.694718973977224, 47.357118538447786, 47.021631717681885, 44.1799053464617, 44.767917496817454, 44.320679324013845, 42.5418883732387, 46.13637910570417, 40.492492880140034, 33.494882174900596, 33.69512578419277, 35.063035011291504, 34.02431753703526, 34.92057262148176, 35.00157124655587, 34.14314562933785, 35.00059502465384, 35.22150605065482, 35.49055767059326, 36.757415771484375, 34.51458590371268, 37.044435432979036, 36.46855136326381, 38.61562115805489, 39.04725020272391, 42.56546361105782, 41.63449532645089, 45.25751883643014, 44.12560517447335, 52.81872224807739, 32.94978557314192, 35.56845045089722, 52.884702341897146, 41.742282731192454, 47.83686038425991, 43.05921997342791, 48.494496958596365, 44.254059995923726, 48.554230621882844, 46.403943811144146, 47.97963891710554, 43.91761432375227, 48.898885590689524, 47.506199087415425, 47.520408153533936, 35.34505196980068, 36.310604912894114, 34.98352330071585, 38.31082105636597, 36.295169489724294, 36.157230377197266, 37.64131695883614, 41.86332035064697, 45.387929575783865, 45.72193990434919, 45.18462528501238, 47.816748823438374, 48.72984981536865, 48.03953586305891, 44.272528307778494, 43.642469133649556, 42.933197021484375, 44.514607020786826, 45.068684169224326, 46.49318994794573, 47.597481046404155, 45.28800753184727, 43.194001129695344, 47.9550700868879, 50.02361134120396, 48.31037317003523, 47.09277432305472, 41.69231128692627, 37.51438726697649, 39.343264307294575, 39.009834153311594, 39.20398071834019, 42.36226354326521, 49.87618793760027, 49.844719546181814, 53.7381843158177, 55.8153760773795, 50.35706581388201, 49.62102229254586, 52.254750864846365, 50.63617147718157, 34.43691546576363, 7.61283460685185, 2.5482735463551114, 5.398053748267038, 1.6926287284919193, 1.7523988698210036, 0.17255245947412082, 6.938821128436497, 29.79141242163522, 50.50872414452689, 22.819173063550675, 12.429597718375069, 24.230744770595006, 34.98275205067226, 40.20055736814226, 42.146990980420796, 26.482529129300797, 0.626168888594423, 0.028966863506606648, 0.06626528208809239, 0.07177556997963361, 0.030646831395902803, 0.03951874801090785, 0.07063398909355913, 0.008558848190919628, 0.03302742401137948, 0.03990717538233314, 0.010119548283650406, 0.06149997136422566, 0.021578611207327673, 0.017830992749493037, 0.00840347639418074, 0.0167164005937853, 0.036747190303036144, 0.05758021705384765, 0.016252408170008233, 0.06511781830340624, 0.04592183531661119, 0.025926037658272044, 0.07566138396837882, 0.014120622471507107, 0.02537632590558912, 0.03327166269134198, 0.03484686477375882, 0.007822374763366367, 0.01938607626860695, 0.028526080373142446, 0.09246177532310997, 0.3536487876304558, 27.137285675321305, 59.99772262573242, 47.848804337637766, 45.63925634111677, 28.531049149377004, 17.080991097858973, 35.827566146850586, 35.73143434524536, 41.62023414884295, 15.123198917933873, 0.16770292898373945, 0.8365288036210197, 29.256168365478516, 12.255199670791626, 6.664434594767434, 8.923382111958094, 11.684912375041417, 4.229811864239829, 23.365933758871897, 57.379353046417236, 51.4298746245248, 56.00369310379028, 53.46334137235369, 52.77443790435791, 50.71134403773716, 51.999442781720845, 50.13726649965559, 51.17743962151663, 50.50583369391305, 49.739252839769634, 47.85988671439034, 47.21856798444475, 46.05416454587664, 40.533070359911235, 41.102857385362896, 49.10843978609358, 48.28056539808001, 48.614627838134766, 49.67629173823765, 45.93994310923985, 46.0739425931658, 47.05146033423287, 48.02029282706124, 47.392457076481406, 46.431965896061485, 43.52859858104161, 45.90921470097133, 46.509083952222554, 48.893921102796284, 42.98325879233224, 36.17985718590872, 34.60228606632778, 36.54282065800258, 36.318640504564556, 36.14833320890154, 35.70749780109951, 35.283442292894634, 36.213045256478445, 36.622613770621165, 38.54649353027344, 37.854737826756065, 35.32561438424246, 38.71465383257185, 38.49240527834211, 39.99038825716291, 40.702860014779226, 44.90717676707676, 42.49165637152535, 47.69155270712716, 45.382218156542095, 54.29880666732788, 34.783665316445486, 35.899400097983225, 55.14790432793753, 46.05877814974104, 48.473530769348145, 44.162218706948416, 50.33015891483852, 46.07616949081421, 49.49256747109549, 48.32042373929705, 49.68740538188389, 45.8731118610927, 49.74707998548235, 48.37060710362026, 47.994959694998606, 37.7886917250497, 37.5137619291033, 36.84681476865496, 38.90055635997227, 37.10520437785557, 37.15300451006208, 38.91558878762381, 44.31673274721418, 47.02812133516584, 47.563250746045796, 47.23081418446132, 49.53269679205758, 50.053731782095774, 50.91508606501988, 46.230509826115195, 44.10970074789864, 43.94972194944109, 44.3350099836077, 47.11550188064575, 47.76406410762242, 49.579756941114155, 45.907491547720774, 43.52782038279942, 49.17565318516323, 50.43128299713135, 50.34438535145351, 49.10917282104492, 43.86220938818795, 38.77285194396973, 40.996053150721956, 39.936108929770334, 39.7539827483041, 43.988663128444124, 51.19016524723598, 51.89449719020298, 56.26369816916329, 55.87616586685181, 53.77954346793038, 52.04943854468209, 55.57266507829939, 52.4997478212629, 36.45137194224766, 8.17896340574537, 4.143092700413295, 5.606263901506152, 2.8275928667613437, 2.713620913880212, 0.22569273013089383, 7.272063246795109, 35.733091490609304, 42.44096578870501, 18.822525807789393, 19.0924129486084, 33.754393918173655, 41.436054774693076, 45.205688749040874, 48.30117375510079, 33.00839710235596, 1.3887493716818946, 0.05784948689064809, 0.06491886505058833, 0.04905913018488458, 0.007810284117502826, 0.058129423297941685, 0.04900484399071761, 0.06798906637621777, 0.03621445210384471, 0.024820682060505663, 0.059010908140667846, 0.05524447560310364, 0.07119837416602032, 0.023339277266391685, 0.05831254632877452, 0.013268198435460883, 0.1451781312269824, 0.19067797543747084, 0.11507975629397801, 0.16615443064698152, 0.10453476570546627, 0.15351728589407035, 0.08978105309818472, 0.08593411238065787, 0.17581305094063282, 0.17415932539318288, 0.20948360062071256, 0.09937519220901386, 0.18622846848198346, 0.12696796123470577, 0.16123263617711409, 0.8640294479472297, 33.949968338012695, 68.04559176308769, 56.3054325239999, 52.3969144821167, 32.221784591674805, 21.914616618837627, 49.64187036241804, 47.043053013937815, 51.10743999481201, 16.565681423459733, 0.2790062443486282, 0.8887322481189455, 33.82417467662266, 17.88696128981454, 12.47357894693102, 11.50407247883933, 18.743913888931274, 12.276352592876979, 23.718401976994105, 59.381306239536826, 51.36609016145979, 59.06470462254116, 56.451612200055806, 54.20528391429356, 51.798653738839285, 54.93031106676374, 52.545303685324534, 54.01758875165667, 53.266415527888704, 51.103524684906006, 50.43468066624233, 50.359334400721956, 48.24864884785244, 43.39043365206037, 44.28437498637608, 52.21769959586007, 50.928846972329275, 50.14661530085972, 51.78132840565273, 46.024627753666465, 45.50031668799264, 47.70218692507063, 50.241426944732666, 48.81196710041591, 45.961816038404194, 45.96563754762922, 47.508248805999756, 46.605983529772075, 51.13715744018555, 43.88933515548706, 39.3407038961138, 36.94381856918335, 37.61712333134243, 37.359206199645996, 37.58834736687796, 38.698916162763325, 36.61440447398594, 37.815584727696006, 37.61429194041661, 39.54875728062221, 41.81690638405936, 37.813997064317974, 41.95641231536865, 40.16412101473127, 42.37282827922276, 45.40284388405936, 47.11128779820034, 45.364441190447124, 49.60710505076817, 48.85329845973423, 54.7145208631243, 36.196049962724956, 39.39916603905814, 57.377345017024446, 47.602813788822715, 49.901479380471365, 47.372331619262695, 51.90603814806257, 47.43632452828543, 52.28603512900216, 51.575373377118794, 50.38783591134207, 46.77230255944388, 53.88899149213518, 51.795985630580354, 51.14898327418736, 39.8522059576852, 40.71951137270246, 39.622804233006065, 41.8965744291033, 40.57139662333897, 39.71007708140782, 41.18500941140311, 47.28946392876761, 50.63590049743652, 49.97490446908133, 50.61136640821184, 52.94181306021554, 51.791167054857524, 52.46037585394723, 47.11908367701939, 43.61233827045986, 44.24707358224051, 44.539679595402305, 47.41701895850045, 48.541181904929026, 50.78129850115095, 44.9260584967477, 42.45854125704084, 49.587945393153596, 53.26827417101179, 53.49848536082676, 52.3288950920105, 46.08012301581246, 41.84215266363961, 43.26439332962036, 44.06376620701381, 42.638520445142476, 46.763328960963655, 52.57828678403582, 54.422043391636436, 58.54104668753487, 58.4155205317906, 56.4027316229684, 54.30021020344326, 57.62849112919399, 54.429460593632285, 37.38584559304373, 8.96450502531869, 4.7671369058745245, 13.884897044726781, 4.645164319447108, 2.590045464890344, 0.410502802580595, 9.413988334792, 43.060950074877056, 60.25151252746582, 33.33730397905622, 22.01263311931065, 35.65051562445504, 46.86488035746983, 53.434266635349815, 54.92344624655587, 41.82451466151646, 2.405487413917269, 0.20732944192630903, 0.19881187326141767, 0.2277003659733704, 0.1451893134840897, 0.13735353680593626, 0.14954108425549098, 0.16370911257607595, 0.13199150881596974, 0.12167989356177193, 0.23035683057137898, 0.13813002513987677, 0.10400096899164574, 0.15624558020915302, 0.11669290544731276, 0.07871466263064317], [0.01896714705175587, 0.0181526115629822, 0.07083497116608278, 0.04461161812235202, 0.010945765600938882, 0.02825961627864412, 0.024569634281631027, 0.017648958767365133, 0.02548715442286006, 0.03661229754132884, 0.02347229727144752, 0.04259249807468482, 0.039636002254805396, 0.021799404806058322, 0.039965193519102674, 0.6644345724156925, 33.86928933007376, 48.64349412918091, 47.07169696262905, 37.18226337432861, 24.02795464651925, 31.449513162885392, 58.84509290967669, 33.56296757289341, 44.10192918777466, 7.290067332131522, 0.0983702139928937, 0.04041758977941104, 8.766160011291504, 10.173466392925807, 5.93647313117981, 9.964744244303022, 6.214042374065944, 2.5076947637966702, 20.98045563697815, 49.097840309143066, 47.41518463407244, 52.54130847113473, 49.651702063424246, 51.118282658713206, 49.893777302333284, 48.626794133867534, 46.45535005841936, 45.78706536974226, 41.11108405249459, 42.34718942642212, 42.077839033944265, 43.81381171090262, 42.79454224450247, 40.79652173178536, 44.51571178436279, 45.88189785821097, 48.31202336720058, 44.76029879706246, 43.52260228565761, 43.24241270337786, 47.96965435573033, 46.73444182532174, 46.142083576747346, 47.68209968294416, 49.88195146833147, 46.87335021155221, 43.79366193498884, 44.929904324667795, 44.91984680720738, 41.98297527858189, 35.36340911047799, 33.866068840026855, 35.091084889003206, 35.747439520699636, 33.776312010628835, 35.23723677226475, 33.75348717825753, 35.98256308691842, 35.08928530556815, 34.66722393035889, 37.144291469029014, 40.48394659587315, 43.804744311741416, 43.70832415989467, 46.03398697716849, 46.603978974478586, 48.640565463474815, 46.98222153527396, 51.0524172101702, 47.28716060093471, 52.91723033360073, 32.47840241023472, 32.08515521458217, 54.83500262669155, 44.70691231318882, 47.768246923174175, 44.420896666390554, 48.85467072895595, 46.484198978969026, 50.197931221553254, 45.032265186309814, 43.84957408905029, 44.199641704559326, 46.371297700064524, 44.72858721869332, 47.41631719044277, 40.42652668271746, 34.042862279074534, 34.42035790852138, 34.052363940647666, 37.457863671439036, 35.55434560775757, 36.867040974753245, 45.561259337833945, 47.48140444074358, 46.36688559395926, 47.794650077819824, 49.01589672906058, 43.16536412920271, 43.7482693535941, 44.951221397944856, 46.49438851220267, 47.938491685049875, 46.77001312800816, 44.23020683016096, 44.26328025545393, 43.72209201540266, 44.189066546303884, 46.08883605684553, 50.26364728382656, 47.828949860164094, 46.86070796421596, 41.14874676295689, 41.41433123179844, 43.31065443583897, 47.49070460455758, 46.10236767360142, 42.303374086107524, 36.63240725653512, 44.57727977207729, 47.93430192129952, 51.355070318494526, 44.73746701649257, 50.345861843654085, 46.590179852076936, 51.49817541667393, 51.41405357633318, 46.59646449770246, 12.732323782784597, 12.311992509024483, 5.647818905966623, 16.03458717891148, 7.55181986945016, 0.22977812162467412, 3.3313911131450107, 30.691617556980678, 27.167387008666992, 35.71797568457467, 32.60580805369786, 15.593477317265101, 32.216913904462544, 40.661775316510884, 47.68534796578543, 33.8781795501709, 2.0408935035978044, 0.02913350152916142, 0.004486093987777297, 0.04176291098285999, 0.011018658921654736, 0.04517010333282607, 0.053435240007404766, 0.030191327445209026, 0.040623084109808714, 0.015014147918139185, 0.03511766131435122, 0.0436966238277299, 0.007373581524007022, 0.07383965315031153, 0.01492430648899504, 0.06112491113266774, 0.019834336857976656, 0.0290818514435419, 0.024443157050492506, 0.026655844479267086, 0.01101386676808553, 0.015414973820692726, 0.015903910888092856, 0.03232517758650439, 0.08176034170069865, 0.009558106356832598, 0.035659424029290676, 0.07357350457459688, 0.09535356943628617, 0.06584680240069117, 0.03640004839482052, 1.3565607560532433, 42.22182655334473, 54.20835849217006, 53.16155678885323, 43.910228388650076, 31.451097352164133, 31.517879962921143, 55.792162145887104, 37.033929756709504, 47.052905559539795, 7.612271802765982, 0.04329058847257069, 0.08064170208360467, 12.212391819272723, 15.35922748701913, 7.380716136523655, 9.010591558047704, 8.048562220164708, 2.434229288782392, 19.688365152903966, 50.78839956011091, 46.04995741162981, 54.45041636058262, 51.379944869450156, 53.64716638837542, 50.93585075650896, 50.277526310511995, 48.401926108769004, 49.676441124507356, 43.73544992719378, 44.70870842252459, 45.788382053375244, 47.200388022831504, 44.59990658078875, 42.92782953807286, 47.04377562659127, 47.03131055831909, 49.38322714396885, 46.245653424944194, 44.64418050221035, 44.9581800188337, 47.060899462018696, 50.06899350030081, 48.307163102286204, 48.179684502737864, 49.798482758658274, 47.30272109167916, 44.33146292822701, 45.666194507053916, 46.60652548926217, 43.82767684119088, 36.445921080453054, 36.63055556161063, 36.668551785605295, 36.671588148389546, 36.167312213352744, 36.9500788961138, 34.90789563315255, 36.789314951215474, 37.302529743739534, 37.66470112119402, 38.64333752223423, 41.01243352890015, 44.854089055742534, 46.01954167229788, 48.12068040030343, 48.79574653080532, 50.52479880196707, 49.29013170514788, 51.58492020198277, 49.17738676071167, 53.456143038613455, 33.32216385432652, 32.00069638660976, 56.48086759022304, 46.58462824140276, 49.96799101148333, 47.152667794908794, 50.29309374945504, 47.48699426651001, 50.715453897203716, 47.72513335091727, 45.267652784075054, 44.25729785646711, 46.59654092788696, 46.887920583997456, 48.850383690425325, 42.11317409787859, 35.25522565841675, 35.828163691929404, 33.91446304321289, 38.889960357121055, 36.6531788962228, 38.09632321766445, 46.09895263399397, 49.88280609675816, 48.386261395045686, 49.058419704437256, 50.2846690586635, 45.52673373903547, 45.53770841870989, 44.54672506877354, 47.68269027982439, 47.98037542615618, 47.05963141577584, 45.8812620980399, 44.64549718584333, 44.386982509068076, 44.69914075306484, 46.591663292476106, 50.95780011585781, 49.71104315349034, 49.81501252310616, 44.30694273539952, 42.71152516773769, 46.265667710985454, 48.74482665743147, 48.149174962724956, 43.36190087454659, 39.272979804447715, 45.861452783857075, 50.289591857365195, 53.80963264192854, 47.234323024749756, 51.03223269326346, 48.425244263240266, 53.03557900020054, 55.077119554792134, 47.13039534432547, 13.76682370049613, 4.344508818217686, 3.4062340685299466, 18.458825826644897, 8.419616869517736, 0.16898773504155024, 3.4399875487600053, 35.832513264247346, 37.49473776136126, 34.22914000919887, 27.902105161121913, 21.482824291501725, 38.374018396650044, 46.35457338605608, 54.27468599591936, 45.91658673967634, 3.5471819681780676, 0.06930701886968953, 0.030266909460936273, 0.06618753554565565, 0.0038857355331336813, 0.029284553602337837, 0.06372695043683052, 0.013232992646018309, 0.020039371480899196, 0.03990107874519058, 0.05756339617073536, 0.03564210781561477, 0.01988566803213741, 0.0328921682334372, 0.012947538052685559, 0.07116697156535727, 0.10992864412920815, 0.12479537352919579, 0.1283648069947958, 0.11791117436119489, 0.08190186374953815, 0.19086054206958838, 0.07073052427066223, 0.1378303026514394, 0.16691728042704718, 0.12186301659260478, 0.13337690090494497, 0.1562911913331066, 0.1668481377086469, 0.13411855325102806, 0.1415503437497786, 2.6756359807082584, 50.92384426934378, 61.97668770381382, 59.39434106009347, 48.03376538412911, 34.59123148236956, 40.150804792131694, 65.97963523864746, 44.51358910969326, 53.789006914411274, 8.945034435817174, 0.17234109581581183, 0.19968349220497267, 14.132402300834656, 13.112250413213458, 13.676407660756793, 18.01315794672285, 14.505876660346985, 7.467046635491507, 23.33442541531154, 50.33887195587158, 47.65584591456822, 56.46355962753296, 53.663369587489534, 55.29308346339634, 52.938613414764404, 52.52488987786429, 50.395280906132285, 50.96511656897408, 45.912105151585166, 45.39155306134905, 47.735482692718506, 48.267811979566304, 46.617371627262656, 45.85655777794974, 49.24189383643014, 49.16590486254011, 50.38707160949707, 47.446138858795166, 45.06743696757725, 44.23710291726248, 50.16427762167794, 52.38470302309309, 50.18789802278791, 50.273472036634175, 53.90616396495274, 49.12238482066563, 45.320434774671284, 47.938516003744944, 48.195557662418906, 46.01814161028181, 39.279379095349995, 39.243363107953755, 38.75083657673427, 39.82543454851423, 36.82936436789376, 39.81336900166103, 36.15990195955549, 39.24404403141567, 38.649385929107666, 38.90117474964687, 41.89920779636928, 43.3088618006025, 48.14420005253383, 48.382891518729075, 49.76086173738752, 50.62304285594395, 52.814240659986226, 49.91535145895821, 55.15212535858154, 51.04747009277344, 55.04682888303484, 35.79277304240635, 34.480487619127544, 57.596664905548096, 48.62811081750052, 51.37890263966152, 48.938195024217876, 52.21899196079799, 49.16794763292585, 53.1014791897365, 48.53195122310093, 45.884937695094514, 44.707040854862754, 47.65050274985177, 48.61426305770874, 50.72859641483852, 44.701280798230854, 36.17627191543579, 37.70836360113961, 36.993831702641074, 40.56080756868635, 38.79907444545201, 39.91662965502058, 48.864394732883994, 51.087429182870046, 50.91895621163504, 51.42315224238804, 52.958328928266255, 46.86000967025757, 44.638312748500276, 44.69009072440011, 48.44527244567871, 49.53330475943429, 48.68356786455427, 47.606930596487864, 45.71974079949515, 45.23307159968785, 44.671695368630544, 47.99672801154, 53.43323482785906, 52.728100367954795, 50.79436111450195, 46.50945220674787, 46.238323075430735, 48.81295027051653, 52.40962968553816, 50.17840330941336, 46.22218588420323, 40.452453885759624, 48.01139913286482, 53.16541303907122, 57.00533846446446, 49.52655111040388, 53.829952648707796, 51.42131444386074, 56.18750422341483, 55.98057644707816, 50.98732648577009, 14.843575613839285, 18.298614263534546, 13.521699939455305, 21.339295353208268, 9.031497819083077, 0.30442704313567703, 4.625701980931418, 41.67358936582293, 41.025277273995535, 50.34132466997419, 42.226044109889436, 23.53479756627764, 43.03891038894653, 54.148280893053325, 59.55676909855434, 53.967791012355256, 5.899737570966993, 0.20492714297558579, 0.11989907840532915, 0.18432672481451715, 0.15797275038702147, 0.12268650026193686, 0.1971770924116884, 0.1355897393077612, 0.1410998643508979, 0.11034576674657208, 0.1926804951259068, 0.1603989609118019, 0.1511420062077897, 0.2190869745931455, 0.076541050337255, 0.19604031555354595], [0.04700348120448845, 0.03592521637412054, 0.053640483279845545, 0.07922223396599293, 0.08117575664073229, 0.01705242640205792, 0.04076512184526239, 0.06419442713792835, 0.016039870646116988, 0.07772014063916036, 0.07488569630576031, 0.044419901445508, 0.08753107847379786, 0.04038207186385989, 0.023734184647245065, 3.0871117753641943, 41.303729806627544, 48.98272602898734, 46.30684273583548, 35.07958214623587, 16.736115523747035, 18.993621723992483, 46.02146632330758, 32.92387574059622, 39.87589236668178, 4.384032343115125, 0.08281065284141473, 0.3258150097514902, 5.987251435007368, 6.940975069999695, 4.949564899717059, 5.82162983076913, 9.862351247242518, 3.9192556142807007, 21.82834083693368, 46.290132318224224, 54.711095401218955, 49.03894737788609, 49.19348921094622, 45.42129829951695, 45.84849091938564, 43.43265438079834, 42.66391263689314, 38.353858198438374, 40.87014831815447, 42.85954959051949, 46.285640307835166, 45.735138007572715, 45.940471172332764, 43.448676926749094, 46.73563344138009, 47.461866106305806, 46.69424649647304, 42.02476174490792, 46.38424914223807, 47.69824034827096, 48.99276270185198, 42.68825217655727, 43.68475239617484, 43.55595016479492, 46.216627325330464, 47.18588365827288, 44.54151739392962, 45.28849737984793, 44.12617492675781, 36.93686689649309, 33.59201799120222, 32.94563055038452, 33.17106485366821, 33.67050831658499, 34.6231758253915, 34.040666648319785, 35.59725420815604, 33.56321423394339, 35.00087990079607, 37.12609066282, 40.924837589263916, 42.48946074077061, 45.28641292027065, 46.09721558434622, 47.500838552202495, 46.12273979187012, 50.19130264009748, 44.51413106918335, 49.5395998273577, 45.32697997774397, 49.74937983921596, 28.159551552363805, 26.838579143796647, 48.64854199545724, 44.48725891113281, 50.66880021776472, 47.14752265385219, 47.91409655979702, 42.85072190420968, 43.64060354232788, 40.4432509967259, 42.851937838963096, 40.252859933035715, 35.94731487546648, 45.2235803604126, 49.93686655589512, 44.66898557118007, 38.76758868353707, 32.622716494968955, 35.23314428329468, 33.18251895904541, 35.298408712659565, 33.485939843314036, 43.53769377299717, 47.69280685697283, 46.94762298039028, 46.641561780657085, 47.608893462589805, 44.62010151999337, 45.25561155591692, 47.07078327451433, 50.35331726074219, 45.60926791599819, 48.86626032420567, 47.16317694527762, 47.647122451237266, 43.99214417593819, 46.81481163842337, 45.95003536769322, 48.75877864020211, 46.707958766392295, 43.67836700166975, 42.41959660393851, 46.43301854814802, 47.2758663041251, 50.6326904296875, 49.1281726700919, 50.673340865543906, 41.574827671051025, 38.220143590654644, 37.265461104256765, 42.91274152483259, 43.61938374383109, 46.917724881853374, 47.786093371255056, 55.00973245075771, 51.18207059587751, 49.32220458984375, 20.5874342577798, 7.34280937058585, 0.6438136217849595, 14.26680999142783, 3.5614509625094275, 0.2474172908280577, 1.2395636226449693, 25.036134787968226, 31.14330952508109, 36.2117737361363, 69.07519667489188, 22.4400463444846, 25.201915332249232, 44.397085189819336, 43.117289543151855, 42.577438831329346, 5.597827919891902, 0.23870753390448435, 0.033561380180929384, 0.024517580467675413, 0.02968838032601135, 0.05952241497912577, 0.04032486457643764, 0.0393542575516871, 0.08215510658919811, 0.028282825568956987, 0.07086353749036789, 0.04704309407887714, 0.0884403900376388, 0.023876770299726298, 0.07022994863135473, 0.004984237927211714, 0.058485803460436206, 0.042208362437252483, 0.03388415250395026, 0.04584360701431121, 0.0476532836577722, 0.041590423988444467, 0.04361425646181617, 0.06058639860046761, 0.03207015698509557, 0.046388524917087386, 0.033377392017947774, 0.02816457557491958, 0.1273995502186673, 0.031752321004335365, 0.045932844547288756, 5.756839615958078, 49.711762292044504, 52.04030861173357, 53.500066076006206, 41.08585514341082, 23.856926475252422, 21.921335526875087, 45.14473220280239, 35.425286293029785, 42.212366580963135, 4.117671413081033, 0.13006840486611637, 0.36581454053521156, 6.829756123679025, 8.88774653843471, 6.6506732531956265, 11.956220422472272, 9.787052750587463, 3.7889347672462463, 22.384396484919957, 47.745859827314106, 55.35117735181536, 51.09104919433594, 51.1240496635437, 48.78424031393868, 47.73054599761963, 46.27553415298462, 44.46400676454817, 40.93833099092756, 42.75585120064871, 44.81631170000349, 48.53793709618704, 48.37632894515991, 46.648353644779746, 46.01071746008736, 47.79735292707171, 50.68201569148472, 46.61833395276751, 43.228026458195274, 46.16455405099051, 48.75593335287911, 50.98975140707833, 44.65732996804373, 46.370439597538535, 45.720355715070454, 47.58882359095982, 47.580468382154194, 45.49514375414167, 47.153105531420024, 46.62904460089547, 37.89182383673531, 34.0557998248509, 34.575639724731445, 35.81022344316755, 36.43313986914498, 36.77443190983364, 35.77314438138689, 36.307467801230295, 34.43911109651838, 37.44174037660871, 38.11744574138096, 43.410680702754426, 44.2929664339338, 47.316968372889924, 46.77056550979614, 49.45972333635603, 47.524427686418804, 51.329876150403706, 46.469989912850515, 50.95070947919573, 47.020738874162944, 50.61461121695382, 29.46453094482422, 27.593712840761455, 49.71482644762312, 47.39964846202305, 51.45069490160261, 49.250829219818115, 48.761088916233604, 45.27028267724173, 43.45265129634312, 40.59012201854161, 42.96404354912894, 40.700362137385774, 39.398290566035676, 47.27857610157558, 51.13328729357038, 46.378843443734304, 40.65982287270682, 33.960814476013184, 36.43691968917847, 34.95156158719744, 36.624955313546316, 36.109628268650596, 44.103805201394216, 49.97328206471035, 49.468794209616526, 48.35406344277518, 48.629014083317344, 44.504097870418, 45.10718413761684, 47.763497829437256, 52.52599116734096, 47.850148814065115, 51.870737825121196, 48.86174399512154, 48.413102286202566, 46.01134974615914, 47.31162173407418, 47.377674783979145, 48.837400981358115, 48.431306566510884, 45.833069392613, 44.2680640901838, 50.352156911577495, 49.6149252482823, 54.21356269291469, 51.647405351911274, 52.66095297677176, 42.4023094858442, 40.2602528163365, 40.69451175417219, 45.120024408612935, 45.52722011293684, 47.788254261016846, 50.10622194835118, 56.689150265284944, 54.52477945600237, 49.579576287950786, 22.638380936213903, 6.715808272361755, 2.985374297414507, 17.42264791897365, 3.0228652570928847, 0.15823557414114475, 0.8423061221837997, 28.831826244081768, 32.826826776777, 41.33047342300415, 62.762056486947195, 26.949105875832693, 28.9646931716374, 47.34079027175903, 49.50819744382586, 50.85090208053589, 9.291799051421028, 0.1220447418412992, 0.060945662536791394, 0.043032884265163114, 0.03810728321384106, 0.013875365140847862, 0.0026339932145284756, 0.03090952962104763, 0.05622148460575512, 0.029511272508118833, 0.03619916470987456, 0.02740701158264918, 0.06698608305305243, 0.01977801675509129, 0.05070650125188487, 0.05388173640572599, 0.2117789081696953, 0.19555310026875564, 0.15792886274201529, 0.19530382007360458, 0.1963462805641549, 0.13436473932649406, 0.15219102134662016, 0.10775919804083449, 0.15440239411379608, 0.2263643712337528, 0.15187457975532326, 0.0709224207592862, 0.28830111558948246, 0.09636536692934376, 0.09519956912845373, 7.862681405884879, 60.28920650482178, 58.73030866895403, 59.50679765428816, 45.22801331111363, 26.682824850082397, 25.92690600667681, 53.33171122414725, 43.11043861934117, 48.84953601019723, 5.103575195584979, 0.3486257285944053, 1.0376375722033637, 8.877167906079974, 10.822865877832685, 12.24885162285396, 16.18976650919233, 20.540455750056676, 8.408123680523463, 26.0539607661111, 50.31314972468785, 57.11896930422102, 52.69991500037057, 52.57257883889334, 50.055284704480854, 49.37500395093645, 48.082969052451, 47.237126622881206, 42.912289891924175, 44.678674834115164, 45.979797976357595, 49.3888795035226, 49.83506849833897, 50.266798291887554, 48.41331420625959, 50.208975383213584, 51.30220147541591, 47.827834674290244, 42.82451677322388, 47.91631303514753, 52.60632276535034, 53.735453673771445, 46.183696338108604, 48.36329412460327, 48.26775639397757, 50.4621399470738, 49.54569687162127, 46.263878549848286, 48.90229715619768, 48.10492188589913, 40.35922295706612, 37.4888595853533, 35.88912718636649, 37.57991920198713, 38.0903616632734, 37.868158272334504, 36.988651820591514, 38.97987699508667, 37.677034173692974, 37.81716891697475, 40.45550414494106, 45.86058078493391, 46.24893297467913, 49.099337645939414, 50.483915601457866, 51.96739074162075, 50.06582164764404, 52.52732522147042, 46.841054984501426, 51.05220181601388, 47.9296362059457, 51.439129625047954, 31.685953412737163, 29.00537313733782, 49.27309124810355, 49.02281713485718, 52.59741864885603, 51.80669627870832, 50.304454054151265, 44.65711109978812, 44.392582757132395, 41.55887460708618, 42.967257090977256, 42.280823707580566, 40.600384507860454, 47.16198532921927, 52.68143279211861, 49.256606646946494, 42.08061831338065, 35.83428505488804, 38.02622979027884, 36.708778381347656, 38.4317683492388, 37.38401474271502, 45.98843111310686, 51.233497687748496, 50.46499913079398, 49.3146345274789, 50.2951260975429, 44.354405879974365, 45.2343361718314, 50.265446867261616, 54.77932323728289, 50.56038052695138, 54.55550439017159, 50.446947710854666, 50.47625868661063, 46.76130356107439, 49.146623611450195, 48.73345940453665, 50.09602894101824, 51.59101377214704, 47.51058687482561, 46.86584963117327, 51.97783041000366, 52.21864455086844, 55.48387404850551, 54.70346280506679, 55.484294414520264, 44.220778124673025, 42.759634494781494, 41.15225212914603, 47.50393050057547, 48.560577801295686, 50.76277807780674, 51.572423866816926, 59.31810542515346, 56.20453078406197, 53.05746929986136, 24.005621399198258, 11.077522567340306, 5.660827236516135, 21.65370307649885, 4.665374892098563, 0.3157624048846108, 1.48498854466847, 32.29284381866455, 41.91811384473528, 49.04504442214966, 79.85543101174491, 32.74810716084072, 35.179076875959126, 56.527500425066265, 55.53175408499581, 59.91779749734061, 13.332910435540335, 0.46261225640773773, 0.16220638821167604, 0.16378430782684258, 0.1579985890005316, 0.14982066782457487, 0.10139035300484725, 0.14688178338110447, 0.17618108833474772, 0.14203586269702229, 0.15573344911847795, 0.10435285046696663, 0.20761178034756864, 0.13392643284584793, 0.17089076792555197, 0.07441171245383364], [0.015079646903489317, 0.028257970831223896, 0.026423047596056546, 0.018549456161313822, 0.04099367958094392, 0.01320568161151771, 0.03762108573157873, 0.04615960416517087, 0.03010147244536451, 0.07470937219581433, 0.07769696188292333, 0.05040016304701567, 0.03193404286035469, 0.16146075965038367, 0.2293259458882468, 8.725361926215035, 44.133467061179026, 44.389324051993235, 38.206990650721956, 20.278882128851755, 15.303365707397461, 27.678696257727488, 48.91958774839129, 40.9732700075422, 36.01523699079241, 0.9922712636845452, 0.06026355842394488, 0.27532530043806347, 6.857132460389819, 3.0213633605412076, 4.539450083460126, 6.950965711048671, 5.621489575931004, 6.549077561923435, 32.905115604400635, 50.688783236912315, 50.884222166878835, 50.455771923065186, 47.80583667755127, 45.29215213230678, 42.10415881020682, 38.425435066223145, 36.5022223336356, 37.67762129647391, 43.605629784720286, 47.97809641701834, 48.80246196474348, 47.86027233941214, 49.51979398727417, 47.23033823285784, 46.279800346919465, 46.14741979326521, 44.897883551461355, 48.13734565462385, 47.06829234531948, 45.463605880737305, 46.34780931472778, 44.1296386037554, 41.0581179346357, 40.43289818082537, 46.456364495413645, 45.755829742976594, 47.15685061046055, 46.34475210734776, 43.085963589804514, 34.33842475073678, 33.00379739488874, 33.97498185294015, 33.94383307865688, 33.694656780787874, 36.336160387311665, 34.18925040108817, 33.8172264780317, 34.618711607796804, 37.32409347806658, 39.784679889678955, 42.23620237622942, 41.01808588845389, 44.191828455243794, 44.81097548348563, 46.34785795211792, 46.24617453983852, 51.184884616306846, 46.73519223076956, 49.93578263691494, 45.32328353609358, 54.3918673651559, 26.661735330309185, 23.02596013886588, 49.808918952941895, 37.05604934692383, 45.14191123417446, 39.43415021896362, 42.92774963378906, 38.224493162972585, 40.97393356050764, 41.85144935335432, 43.14897332872663, 41.446438857487266, 41.457535130637034, 35.954478468213765, 46.75324365070888, 47.6620089667184, 44.00632197516305, 33.57223646981375, 33.752531800951274, 33.401380266462056, 35.08737107685634, 32.75431537628174, 39.21254089900425, 47.99840252740042, 47.07284688949585, 39.52833652496338, 45.22269099099295, 46.262103285108296, 48.73991428102766, 47.560582637786865, 45.647295406886506, 42.11953517368862, 45.74184649331229, 45.90660217830113, 47.210834639413015, 43.937857900347026, 44.93793296813965, 49.66358000891549, 46.94355828421456, 44.03969764709473, 44.57269048690796, 48.166000025612966, 46.99116734095982, 50.42911515917097, 48.73355320521763, 49.27496031352452, 49.105420793805806, 49.571377413613455, 45.172254017421174, 40.82379341125488, 41.954862867082866, 45.56326389312744, 51.93587718691145, 53.03423799787249, 52.55723374230521, 43.89298643384661, 48.663942677634104, 29.582730225154332, 4.764680283410208, 0.6227142768246787, 8.39926906994411, 17.551898309162684, 0.24578123433249338, 0.3723326293485505, 16.084042719432286, 50.92395544052124, 52.68064069747925, 61.139478410993306, 31.929835183279856, 18.229326827185496, 34.84456280299595, 44.362927845546174, 46.369206292288645, 15.781754391533987, 0.0797450112711106, 0.060392161166029315, 0.03497066688058632, 0.036535477199192555, 0.023599816053839665, 0.016330483801929013, 0.011273568412954254, 0.05331703242180603, 0.009271854484852935, 0.04604760178231767, 0.012320162878105683, 0.05403124141905989, 0.04083571323592748, 0.05875334981828928, 0.03857022051566413, 0.03410416409107191, 0.005317551715831671, 0.03319861500390938, 0.020854977358664786, 0.06607223887528692, 0.04780492266373975, 0.02777899635423507, 0.03891529967742307, 0.016021899646148086, 0.09486228972673416, 0.03154394290010844, 0.04015368376193302, 0.028131174688626612, 0.12144730532807962, 0.2190349173865148, 14.269871541431971, 52.74356358391898, 49.80534063066755, 44.568452085767476, 26.895090579986572, 20.90738316944667, 23.912572860717773, 50.6371476990836, 43.174226556505474, 39.463238852364675, 1.1690631828137805, 0.08566936158708163, 0.22087388299405575, 8.344386986323766, 4.210197968142373, 5.431781607014792, 9.817568370274135, 7.0646078416279385, 6.008049998964582, 35.70776183264596, 49.322336605616975, 52.537226404462544, 51.36659390585763, 50.96276807785034, 46.054442473820274, 44.2065030506679, 39.711094992501394, 38.460276808057515, 39.12708500453404, 45.8519024848938, 48.321723052433555, 50.36752980095999, 49.69311680112566, 51.94203329086304, 49.60301603589739, 50.3557699748448, 47.65428604398455, 45.95316205705915, 48.43949849264962, 48.33555344172886, 47.45311485018049, 47.34428868974958, 46.52886894771031, 43.25893899372646, 43.435951301029746, 47.41068914958409, 46.73217671258109, 48.01065567561558, 48.39050327028547, 45.13938903808594, 36.07722534452166, 33.751871722085134, 35.52717815126692, 34.65435586656843, 35.37788568224226, 37.90237120219639, 35.69436917986189, 34.79894093104771, 35.3723931312561, 39.21523332595825, 42.04131930215018, 43.53231239318848, 43.00697994232178, 47.0010997908456, 45.97974239076887, 48.17160374777657, 47.93151569366455, 52.37042447498867, 49.88507120949881, 52.24489484514509, 47.336357321058, 52.22795861107962, 27.428823402949742, 24.64445267404829, 48.863786765507285, 37.64941855839321, 46.6199563571385, 39.459267956869944, 43.81745604106358, 37.6805534362793, 39.73690755026681, 41.95093366077968, 43.62745060239519, 41.00306388310024, 41.80520909173148, 38.277494021824424, 48.915366717747276, 48.920411109924316, 45.26947668620518, 35.20701905659267, 36.06863737106323, 35.757187843322754, 37.13697501591274, 34.97528968538557, 41.827040331704275, 49.878223759787424, 49.21656765256609, 42.50833552224295, 47.043928486960276, 46.99445036479405, 50.547894614083425, 48.92950282778059, 48.272974491119385, 44.42876550129482, 48.24036659513201, 48.21624592372349, 48.16206734521048, 44.885362897600444, 47.494168281555176, 50.702710900987896, 48.21919890812465, 45.159511021205354, 48.163144315992085, 48.80086735316685, 48.997379779815674, 51.61868497303554, 50.248792035239084, 50.32790075029646, 51.91650560923985, 51.935925824301584, 47.483037267412456, 43.00756706510271, 44.85763611112322, 47.76687465395246, 54.10239151545933, 54.112480299813406, 52.505764961242676, 44.45170150484358, 51.96055718830654, 30.788576194218226, 7.02638840675354, 1.8892049917152949, 11.130460023880005, 18.440850836890085, 0.16452484737549508, 0.2839445679315499, 18.571588141577585, 50.2984299659729, 54.80823121752058, 65.11176354544503, 32.140671321323936, 24.458614417484828, 41.73481341770717, 49.12220764160156, 53.78770065307617, 21.730273962020874, 0.10848768680755581, 0.06076682106192623, 0.009098903542118413, 0.04830795120713966, 0.03194238205573388, 0.023126768580238734, 0.020212060339482765, 0.07730631570198707, 0.016134741716086864, 0.021425750838326554, 0.07755016083163874, 0.02952471767951335, 0.04453608360407608, 0.009712395042047968, 0.017847464187070727, 0.08115321570741278, 0.09704161528497934, 0.13222906392599854, 0.13020854948886804, 0.18081542822931493, 0.09448461035000426, 0.0947968518095357, 0.09554184254791055, 0.11061971168965101, 0.15950782730111054, 0.1396939940750599, 0.16813884702111992, 0.14680035917886666, 0.2173123069639717, 0.3392435706087521, 19.138232844216482, 60.794410024370464, 56.38879353659493, 51.5838189125061, 30.67824227469308, 22.08821562358311, 37.8970627784729, 59.91069643838065, 52.01837314878191, 44.18552991322109, 1.38542064172881, 0.153278292289802, 0.40518251806497574, 13.312864882605416, 6.2402965767042975, 13.098535537719727, 15.632152727672032, 13.634750604629517, 10.708386489323207, 36.68926436560494, 50.31056499481201, 53.273610387529644, 53.575766699654714, 52.37312037604195, 48.29572636740548, 46.94650779451643, 42.095914772578645, 39.78284903935024, 41.32120105198452, 47.331726346697124, 50.86180033002581, 52.86495903560093, 50.896826199122835, 54.881281103406636, 51.19738442557198, 51.589710984911235, 49.71908221926008, 46.266327789851594, 50.11665119443621, 50.23702526092529, 48.94952406202044, 49.153679507119314, 48.28062445776803, 45.62930652073452, 43.996292250497, 51.470935004098074, 49.83940764835903, 49.36054127556937, 51.10385472433907, 47.37904705320086, 37.745105675288606, 36.21898596627371, 37.254423890795024, 37.60537392752511, 37.413450786045615, 39.468067850385395, 38.194094794137136, 36.52412305559431, 38.53964608056204, 41.32895871571132, 44.67143481118338, 45.20312486376081, 45.26740959712437, 47.32833562578474, 48.42151655469622, 48.93457848685128, 50.33165625163487, 55.65255199159895, 50.4438488142831, 53.81658084051949, 49.36876446860177, 55.29443488802229, 30.052268641335623, 27.462417943137034, 48.68893187386649, 38.01683929988316, 46.041240896497456, 40.56597008023943, 43.55338280541556, 37.827480043683735, 40.020143917628694, 44.07675239018032, 43.758017676217214, 42.67515482221331, 43.55558885846819, 38.600008555821006, 49.14460168566023, 50.60279927934919, 47.52526841844831, 38.09971393857683, 37.48136942727225, 37.40336547579084, 38.70163985661098, 37.23014688491821, 42.7317270551409, 51.168462548937114, 50.06857313428606, 45.4244110924857, 47.63401814869472, 45.501053197043284, 51.896008423396516, 51.15798813956124, 50.4178694997515, 46.553660120282856, 50.27282238006592, 50.57335628782, 50.25798102787563, 46.094095843178884, 48.58699485233852, 53.03958811078753, 49.40566635131836, 48.416308879852295, 50.50520488194057, 53.11098085130964, 50.78603022439139, 55.11261095319475, 53.09841850825718, 52.58873687471662, 52.704177720206125, 54.260522093091694, 48.481625420706614, 46.187250341687886, 47.50931535448347, 51.10075582776751, 56.440349170139854, 57.92928212029593, 53.66717720031738, 46.4851439339774, 51.00128541673933, 35.458762713841026, 7.081980075154986, 6.094560716833387, 11.972017151968819, 20.173729828425817, 0.4181489422917366, 0.3618361811552729, 22.314871072769165, 61.694507462637766, 61.82409136635916, 69.15386417933873, 42.11774948665074, 26.88596064703805, 48.564204760960166, 55.148689474378315, 63.444744791303364, 27.61142553601946, 0.21824329772165843, 0.1341916314725365, 0.08113761618733406, 0.2024057882704905, 0.11549164062099797, 0.1309883762151003, 0.08424281634922538, 0.19479764652039322, 0.06793322294418301, 0.10908546258828469, 0.09882405214011669, 0.11332463725869145, 0.15372623396771296, 0.19076683638351305, 0.10237690220986094], [0.05104354316634791, 0.05970826572073357, 0.02057594509928354, 0.051191450229712894, 0.061921728375766955, 0.018381581508687565, 0.05452980859471219, 0.03272726386785507, 0.017200689696307694, 0.011099112818815877, 0.05518115810783846, 0.01798884374355631, 0.059756163507699966, 0.024663453622321998, 0.1282905481223549, 17.613714694976807, 47.584995133536204, 41.64751277651106, 32.226373876844136, 24.410147258213588, 17.535688161849976, 31.87635142462594, 30.586998530796595, 43.816243580409456, 22.44932566370283, 0.5800512518201555, 0.03400733035856059, 8.249555366379873, 7.3204231432506015, 6.851571295942579, 5.960328468254634, 10.545076898166112, 12.088884115219116, 18.600268568311417, 53.11335366112845, 50.16106060573033, 52.88464675630842, 47.33671862738473, 53.964487143925254, 49.22760139192854, 48.22936759676252, 36.499714033944265, 36.73136350086757, 39.4476957321167, 48.39861181804112, 47.316516739981516, 49.44854368482317, 48.31250974110195, 47.911709853581016, 45.70290878840855, 45.40083238056728, 43.457647051130024, 46.52716316495623, 45.66973808833531, 46.00896651404244, 44.34910093035017, 45.04819393157959, 40.5666058404105, 35.83516747610909, 40.34590673446655, 45.46785470417568, 47.79794699805123, 48.47054999215262, 45.602413518088206, 42.17659378051758, 32.0822890826634, 33.95704507827759, 30.822896821158274, 34.21493441717965, 33.99302979878017, 35.55522802897862, 33.94527135576521, 35.453593254089355, 36.59925740105765, 39.77253096444266, 39.57746376310076, 44.89722694669451, 41.030394622257774, 43.603194441114155, 41.08143956320626, 42.306608472551616, 40.70097705296108, 47.418019499097554, 45.855070863451274, 51.82641526630947, 44.641349111284526, 54.89526087897164, 32.23346103940691, 22.677966560636246, 48.27298838751656, 37.833531924656455, 41.58754982267107, 40.55596814836775, 42.465395654950825, 43.31171751022339, 45.56081812722342, 45.24374055862427, 45.014342308044434, 46.97512742451259, 47.90897226333618, 45.576746872493196, 43.40741157531738, 46.996145725250244, 45.629765101841514, 35.81309652328491, 33.68882376807076, 33.70146254130772, 34.81802068437849, 32.41524675914219, 34.51934889384678, 44.067695413317, 49.057766573769705, 45.02040808541434, 42.872518403189524, 47.24007960728237, 48.24492113930838, 46.26785639354161, 42.716989925929475, 40.33678374971662, 41.76412786756243, 46.9638991355896, 45.97173111779349, 43.54022639138358, 47.033773694719585, 46.23640537261963, 44.14016859872, 45.91805975777762, 48.31035927363804, 47.147387163979666, 49.97194453648159, 46.21918773651123, 43.26598446709769, 44.098135471343994, 51.48230225699288, 49.13659388678414, 49.15651784624372, 50.20355578831264, 51.342299529484336, 50.497867584228516, 50.07309293746948, 54.02613851002285, 47.43226678030831, 41.03115545000349, 31.510038920811244, 19.526232412883214, 5.8188305752617975, 2.817446542637689, 6.4990010261535645, 24.836464405059814, 4.187532944338662, 0.14812899859888212, 10.08707162312099, 42.35886934825352, 58.91649259839739, 62.14091532570975, 35.63423946925572, 25.400347198758805, 38.60320125307356, 38.87710271562849, 49.96381861822945, 20.29623004368373, 0.16461210697889328, 0.048032374387340884, 0.023375751916319132, 0.05147841286712459, 0.045372286412332735, 0.03123312975679125, 0.06352185644209385, 0.03216138601835285, 0.030263577853994708, 0.02932984920750771, 0.009795973592969989, 0.05302853290257709, 0.028398519182311635, 0.01643552102281579, 0.07786147269819464, 0.01949507274132754, 0.02600399624290211, 0.054246995198939524, 0.039629766517984014, 0.08660571277141571, 0.0053308535467035, 0.014836924749293497, 0.04104868841490575, 0.02959248636450086, 0.0332901290218745, 0.0038412244840791182, 0.06186092485274587, 0.0332801850911762, 0.015328389359638095, 0.07538084366491862, 23.951807601111277, 54.744161878313335, 48.08416761670794, 37.62772280829293, 30.507705688476562, 17.938299792153494, 28.67345769064767, 36.41948665891375, 47.32992328916277, 26.722285406930105, 0.4639049470424652, 0.03382399358919688, 8.735295244625636, 9.768291745867048, 7.545849629810878, 11.401355522019522, 9.258124606949941, 4.385616966656276, 20.33038912500654, 52.09371941430228, 52.360165459769114, 54.06438486916678, 50.878844261169434, 53.61246708461216, 49.56334182194301, 48.652408667973106, 37.563010760716026, 37.76006862095424, 40.2618647984096, 50.227061544145855, 48.10134008952549, 50.46266106196812, 50.27174540928432, 48.73390061514718, 46.037603514535085, 46.289371490478516, 42.17274100439889, 48.198698248182026, 48.557430267333984, 47.0538261958531, 46.15724107197353, 46.77367830276489, 42.35882418496268, 38.02258546011788, 41.65119184766497, 48.05651378631592, 49.78266518456595, 49.29134069170271, 47.15599250793457, 42.79683862413679, 33.373757702963694, 34.04885857445853, 32.77888420649937, 36.19656760351998, 36.16674246106829, 37.67098229272025, 35.32829291479928, 37.083373137882774, 37.83424064091274, 42.53836563655308, 42.299062728881836, 46.35693577357701, 43.04973915645054, 45.17849349975586, 43.14174025399344, 44.960292271205354, 42.421069622039795, 48.09209203720093, 46.40778269086565, 51.87392010007586, 45.96585988998413, 55.3247081892831, 32.5380596433367, 23.849524906703405, 46.7263298034668, 39.25543212890625, 43.28842714854649, 39.68773167473929, 42.16058513096401, 43.5635792868478, 46.89232226780483, 45.307295731135774, 46.98490353993007, 49.51625388009207, 48.500569684164866, 46.01632465635027, 43.71653345652989, 47.28715017863682, 47.7787630217416, 38.15616805212838, 35.61309610094343, 35.42746455328805, 36.321117537362234, 33.75054114205496, 36.53155067988804, 45.47579649516514, 50.69882338387625, 45.97884259905134, 44.3723634992327, 47.90347276415144, 50.322435992104666, 46.09126445225307, 44.58539179393223, 41.92282124928066, 43.633936745779856, 49.07999038696289, 48.12691988263811, 44.65948043550764, 48.76172120230538, 49.06142480032784, 46.350519112178254, 47.78564521244594, 50.64547164099557, 50.16587223325457, 51.4557740347726, 46.84291362762451, 43.589985915592735, 45.91558967317854, 52.8476163319179, 50.49342768532889, 50.79530954360962, 51.3560917036874, 53.18139042173113, 53.20620938709804, 51.89360087258475, 55.33021463666643, 49.51285968508039, 40.24025590079171, 33.14942816325596, 20.424835988453456, 7.247371086052485, 2.082245707511902, 8.51531093461173, 27.647193125316075, 3.1654998319489613, 0.017602984627176608, 10.740929245948792, 46.10147830418178, 56.352822712489534, 66.48112147194999, 40.092109884534565, 29.550261293138774, 42.7853740964617, 44.74783025469099, 56.30966397694179, 28.480504478727067, 0.29825527859585627, 0.036966299438583, 0.09199936727860145, 0.028883186568106924, 0.010256566556303628, 0.012893160256291074, 0.05817932954856327, 0.062242397240230014, 0.030403746225472008, 0.03034991125709244, 0.01950682157517544, 0.03523448808118701, 0.021519163058006337, 0.026017076701724103, 0.026782688119315674, 0.12016624478357178, 0.13121792461190904, 0.15995461546948977, 0.1985777108264821, 0.12587560127888406, 0.10859729056911809, 0.25721267664006775, 0.16565045554723057, 0.09473140710698706, 0.13241913515542234, 0.16165579775614397, 0.15281691561852181, 0.09141257019447428, 0.1142551733979157, 0.20718599962336676, 30.74503183364868, 62.2092091696603, 55.59872082301548, 44.32765531539917, 34.819208826337544, 25.43298636163984, 42.17090667997088, 41.236047404153005, 54.6973101752145, 27.219790322440012, 0.7864189382110323, 0.11961186810263566, 12.578664370945521, 9.355564406939916, 12.119510906083242, 12.443534936223712, 20.512563943862915, 17.76687036241804, 21.64044417653765, 57.101282664707725, 52.00091927392142, 55.3948016166687, 51.431712423052105, 57.2292024748666, 52.179522718702046, 51.88472802298409, 39.309537751334055, 39.06364100319998, 43.72883176803589, 53.380484104156494, 50.171253613063264, 53.39313677379063, 51.30447701045445, 50.40855196544102, 47.41875948224749, 45.95961693355015, 42.86955499649048, 50.04236452920096, 49.84116554260254, 48.99027872085571, 47.080045223236084, 50.10193143572126, 43.98882641111101, 39.86963551385062, 44.71098048346383, 49.81709698268345, 51.2574759210859, 52.0685704095023, 49.0367100579398, 44.935098103114534, 35.46638488769531, 36.41489737374442, 34.01249170303345, 38.63570145198277, 36.90039580208914, 39.15883479799543, 36.88968167986189, 38.69050189426967, 40.6640682220459, 45.35153143746512, 44.61591523034232, 49.71972492762974, 45.32140057427542, 47.75558730534145, 45.465825830187114, 45.69752393450056, 44.50654016222273, 50.46076767785208, 49.42842517580305, 55.69649934768677, 48.420536858694895, 56.87958649226597, 35.73413372039795, 25.959305456706456, 47.647688729422434, 39.036793163844514, 42.674748352595735, 40.89145844323294, 43.026674611227854, 45.82029512950352, 48.94640779495239, 47.075501101357595, 49.65598215375628, 50.89669418334961, 49.613817010607036, 48.46163892745972, 47.273656776973176, 49.81227840696062, 49.87567029680525, 38.89824955804007, 36.87684140886579, 37.21024029595511, 39.19207845415388, 36.40638583047049, 37.99206897190639, 47.731862681252615, 51.36455460957119, 48.47614329201834, 44.85211229324341, 50.71034002304077, 51.723800795418875, 50.13573094776699, 46.335392883845735, 44.67105960845947, 45.425213609422954, 51.991851874760215, 50.03691714150565, 46.13160221917288, 50.55927228927612, 50.36715807233538, 48.129862444741384, 50.63586228234427, 52.88928120476859, 51.663191659109934, 53.48937974657331, 49.34444924763271, 44.229386942727224, 46.02899817058018, 54.650788511548726, 53.04259320667812, 54.30902746745518, 55.14898477281843, 55.900071144104004, 55.799614088875906, 55.15024239676339, 58.909627778189524, 50.42264291218349, 42.660445485796245, 36.66425085067749, 25.010518516813004, 10.849837047713143, 7.882005214691162, 8.085035920143127, 29.232502801077707, 6.669027354036059, 0.2794124154107911, 12.910730072430201, 54.97063146318708, 63.4859892981393, 71.61074720110211, 44.79868412017822, 35.6716833114624, 51.106019088200156, 52.20128795078823, 62.934906823294504, 36.25663478033883, 0.753423137324197, 0.14918766250567778, 0.1981690020433494, 0.09969708243651049, 0.19619678572884627, 0.08128028496035508, 0.175944591739348, 0.13919414446822234, 0.10916584863194398, 0.1894039852278573, 0.0707945576203721, 0.12688405359429972, 0.08630995971283742, 0.1530033363295453, 0.21515030440475258], [0.017812981037423015, 0.0716253626825554, 0.04528189536982349, 0.02739246209551181, 0.02024020257938121, 0.016941545298323035, 0.015088135376572609, 0.04040409711056522, 0.035052827293319364, 0.053915218716221194, 0.03699221608362027, 0.056067772675305605, 0.014811272732913494, 0.008553816005587578, 0.059217508483145914, 28.124034098216466, 48.867278235299246, 37.15919882910592, 35.23722982406616, 11.482327222824097, 29.567868028368267, 36.13229676655361, 33.605400221688406, 44.19833891732352, 17.2198942729405, 0.0426016990095377, 0.6708188812647546, 19.29194610459464, 4.278976014682224, 13.457298823765345, 5.970499762466975, 7.071718454360962, 11.201232637677874, 43.48582547051566, 53.606647968292236, 51.59380347388131, 49.86848585946219, 50.20299645832607, 49.45948709760393, 48.833294595990864, 47.960434096200125, 42.53926542827061, 34.94694798333304, 37.33732284818377, 43.45065368924822, 48.03365421295166, 45.598758765629356, 48.45849139349801, 48.050910064152305, 45.026307106018066, 47.02649198259626, 47.59092889513288, 45.654945373535156, 44.9672543661935, 41.53253746032715, 40.731028011866975, 35.6643043245588, 35.978255203792024, 33.79733378546578, 37.08031245640346, 42.01126834324428, 47.20796850749424, 47.17612143925258, 44.48750557218279, 38.70856373650687, 32.997179235730854, 34.290232045309885, 32.50337771006993, 34.12931176594326, 33.260995388031006, 35.00652183805193, 33.464046069553916, 34.15101793834141, 40.59603493554251, 44.24186590739659, 43.815156187329976, 44.04149375643049, 43.15597711290632, 45.0281205858503, 41.435617038181846, 42.643328598567415, 39.8598906653268, 41.72363724027361, 40.623733929225374, 45.065373352595735, 45.04699536732265, 51.20740720203945, 34.679862703595845, 25.063557590757096, 45.32530198778425, 38.18539564950125, 44.995537008558, 39.81666939599173, 45.41025413785662, 42.1925642149789, 45.560324805123464, 44.83382116045271, 46.7944256237575, 46.273421900612966, 46.91571685246059, 46.21608883993966, 46.4698474747794, 45.292308466775076, 45.076657227107454, 38.0673040662493, 34.25172165461949, 35.02534450803484, 34.399617535727366, 32.72396911893572, 33.88787228720528, 37.91510377611433, 48.392118726457866, 47.57657044274466, 49.2927303314209, 48.01758302961077, 47.61001559666225, 42.74423728670393, 36.16387980324881, 37.76612050192696, 45.0633271081107, 45.609754289899556, 46.39822544370379, 44.31522151402065, 47.03073385783604, 47.775966371808735, 49.19451754433768, 46.65326254708426, 48.13081782204764, 46.25160455703735, 44.95134646551949, 43.806999002184185, 46.384297779628206, 45.217841148376465, 47.00827727999006, 50.13305589130947, 52.9188631602696, 52.592332567487446, 53.80308049065726, 52.069518838609966, 52.0907872744969, 48.83913803100586, 49.82191208430699, 40.44767352512905, 23.451933349881852, 22.665397269385203, 9.615185584340777, 0.8209432342222759, 2.518498344080789, 2.7897462461675917, 3.576838616813932, 0.06505369674414396, 4.539969027042389, 38.00168527875628, 47.76740619114467, 41.864015170506065, 22.492951665605815, 23.007418870925903, 32.849967752184185, 41.80707120895386, 46.13516664505005, 28.714248827525548, 0.40787915193608826, 0.05882405995258263, 0.04000755785299199, 0.029027972370386124, 0.029897599813661406, 0.028971240057476928, 0.03249815312613334, 0.058869216458073685, 0.026062684433002557, 0.026262899760955145, 0.04957612297896828, 0.03686025798586862, 0.043577612178134065, 0.052404189083193026, 0.05941670600857053, 0.005885447782929987, 0.052053271127598624, 0.06496620643883944, 0.024301982750850062, 0.04813190529655133, 0.09342029424650328, 0.02102220231401069, 0.01828090217895806, 0.04492040244596345, 0.04501966872651662, 0.026263513835147023, 0.07496626555387463, 0.028729237150400877, 0.0366212033134486, 0.17408141600234167, 34.733276980263845, 55.73865754263741, 43.78776638848441, 40.6093407358442, 18.739383663449967, 29.195840631212505, 34.906950678144185, 39.91732447487967, 49.49958515167236, 19.608678000313894, 0.11069766179259334, 0.8074180228369576, 20.732457058770315, 5.862549075058528, 16.905821800231934, 11.371565120560781, 6.863815758909498, 8.364320499556404, 46.7291716166905, 54.43774632045201, 53.53263575690133, 51.28110327039446, 52.44754947934832, 49.821533407483784, 50.16950266701834, 50.209843908037456, 44.11186858585903, 36.42632368632725, 39.84798840114048, 45.54368039539882, 51.054755278996055, 47.46220656803676, 50.13208314350673, 50.10878235953194, 44.881958280290874, 46.60390601839338, 48.52076114927019, 47.12272105898176, 46.86239985057286, 43.35092272077288, 42.907676288059776, 38.11457960946219, 37.4132353918893, 34.94899770191738, 40.09051527295794, 45.40436553955078, 49.147582462855745, 47.47590494155884, 47.00450440815517, 40.47103336879185, 32.93577800478254, 35.817036151885986, 35.43571901321411, 35.24038430622646, 35.30515888759068, 36.715851647513254, 35.92344781330654, 37.33587414877755, 40.93894590650286, 45.21491595676967, 44.555031640189036, 46.43189293997628, 45.6893424306597, 46.647780418395996, 43.78021369661604, 42.617252009255544, 41.22624002184187, 44.09392833709717, 42.63422645841326, 46.46180840900966, 46.88366481236049, 53.331040722983225, 36.17171389716012, 27.264680896486553, 46.02669831684658, 38.84686068126133, 45.19244200842721, 41.06154339654105, 47.103877544403076, 44.746054989951, 47.52377455575125, 46.807714053562705, 49.18844829286848, 48.6290522984096, 48.83317995071411, 47.95508050918579, 48.35376814433506, 46.30425453186035, 46.91602952139718, 38.14760787146432, 35.128379344940186, 35.713608741760254, 35.95543384552002, 35.58194037846157, 36.358505793980186, 39.78217158998762, 51.4879789352417, 47.42079183033535, 49.71798440388271, 49.91087334496634, 48.9357179914202, 44.8545754296439, 38.40009151186262, 40.555467878069194, 46.73822859355381, 48.02160603659493, 46.13800498417446, 46.0365890775408, 47.16455268859863, 48.58005360194615, 49.433744021824424, 48.6887651171003, 50.340692383902415, 48.013702460697715, 46.412972995213096, 44.672192164829795, 48.18192529678345, 45.31539385659354, 47.717406954084126, 50.95928355625698, 54.04003838130406, 55.00939198902675, 55.96272305079869, 54.416957310267854, 54.85572215488979, 50.36156129837036, 51.05436617987496, 41.95609964643206, 24.834294830049785, 24.033686910356792, 10.368035061018807, 1.5578228192670005, 2.419683017901012, 3.6920686279024397, 3.5628210604190826, 0.05921166629663535, 5.143363186291285, 44.50824594497681, 51.074026107788086, 51.93372324534825, 29.597168581826345, 26.810548373631068, 39.85396037782942, 47.59344414302281, 53.35863549368722, 37.93577814102173, 1.3251753087554659, 0.09139646855848176, 0.07062189081417662, 0.12106402803744588, 0.005824924155604094, 0.031481161447507996, 0.021387296562482203, 0.03290313335933855, 0.060130456994686804, 0.035943492714847834, 0.06890263913997582, 0.023947231072400297, 0.02732957886265857, 0.060588929536087174, 0.030982482313577617, 0.08631675184837409, 0.15742266204740318, 0.23134214484265872, 0.11230815787400518, 0.1670449400054557, 0.23635811997311457, 0.12325896668647017, 0.2061218667243208, 0.12817271373101644, 0.11753461456724576, 0.13007189253611223, 0.13054865838161536, 0.1013539292450462, 0.0902196377781885, 0.358462287911347, 41.68942778451102, 64.62504918234688, 51.04176214763096, 49.61825343540737, 18.373446362359182, 43.89461578641619, 47.44552046912057, 44.14860371180943, 55.991370473589214, 22.017793893814087, 0.22727854789367744, 0.7873782781617982, 24.443437814712524, 7.901073677199228, 20.803903647831508, 11.61134397983551, 11.12298115662166, 16.12475221497672, 48.493253231048584, 57.491945130484446, 55.1893572807312, 52.70774562018258, 55.26080560684204, 52.935108048575266, 52.784141063690186, 52.0535067149571, 45.71384872709002, 38.051455225263325, 41.36624274935041, 46.892103399549214, 53.99987084524972, 50.61943326677595, 51.80489322117397, 50.476925713675364, 47.52601187569754, 48.347219467163086, 50.29078694752285, 48.797560010637554, 48.974812030792236, 45.285429750170024, 45.012858867645264, 39.79789188929966, 39.151264735630576, 37.02811758858817, 41.12563705444336, 45.93128912789481, 52.110884938921245, 49.44441645486014, 48.27109152930123, 44.24535390308925, 36.44573695319039, 37.351538862500874, 35.88548980440412, 37.881450176239014, 36.33196367536272, 39.403710160936626, 37.23910311290196, 38.581564562661306, 44.49974829810006, 48.28907694135393, 46.996413230895996, 48.261506489345, 47.89749036516462, 48.328917912074495, 45.59874486923218, 46.18761164801461, 43.11991943631853, 46.01928458895002, 43.697613511766704, 47.72500480924334, 49.335559027535574, 54.1114832333156, 39.288116455078125, 29.236407688685826, 46.19436877114432, 39.59762396131243, 46.05892406191145, 43.22801603589739, 49.06978348323277, 46.86170155661446, 48.58046701976231, 49.383425167628694, 51.22271408353533, 50.10250466210501, 50.702728271484375, 50.11751971926008, 48.59316485268729, 49.84101268223354, 49.258597305842805, 40.93249103001186, 37.43084560121809, 38.28723887034825, 37.40688821247646, 35.78045736040388, 37.632461479731965, 40.39979001453945, 54.033913544246126, 50.88036939076015, 53.323091983795166, 51.83698000226702, 51.318321296146934, 45.987051895686555, 38.953623226710725, 42.32838412693569, 49.74124697276524, 49.800011362348286, 47.48544134412493, 47.99389662061419, 50.396347454616, 51.84288249697004, 51.48373358590262, 49.071180071149556, 51.5010415485927, 46.75415733882359, 47.20587362561907, 45.41624001094273, 49.64635195050921, 47.19837304524013, 48.23459611620222, 52.22063173566546, 56.32615900039673, 57.04699986321585, 56.54473890577044, 56.619633538382395, 55.91569764273507, 51.403235231127056, 51.755519321986604, 45.83979524884905, 26.501185042517527, 26.323071445737565, 13.086568134171621, 5.489028683730534, 4.690247271742139, 5.019518060343606, 4.802023376737322, 0.1574086028018168, 5.838688092572348, 51.024245738983154, 56.11524295806885, 52.460393224443706, 32.008683340890066, 34.254181316920686, 45.209034306662424, 54.83658334187099, 59.748289244515554, 46.4797625541687, 2.8113440700939725, 0.22834760695695877, 0.10990610319588866, 0.28027076220938135, 0.08449902438691684, 0.08316218147852592, 0.15716765501669475, 0.16158342521105493, 0.16755415339555058, 0.1009171155414411, 0.21714529235448154, 0.11905852279492787, 0.1539407188871077, 0.12705090535538538, 0.12605796435049602], [0.026595997690622295, 0.04386136195223246, 0.006452231052597719, 0.040772107363279374, 0.0727069339315806, 0.022178310634834424, 0.0069722136416073355, 0.0351239445486239, 0.0856329785393817, 0.046725800926131864, 0.04540876106226018, 0.07148703653365374, 0.01803421738025333, 0.03077197021671704, 1.3566387061561858, 36.30744000843593, 40.577542304992676, 39.53341218403408, 23.15486138207572, 17.131327322551183, 28.239858831678117, 39.84661613191877, 39.23346539906093, 37.793281010219026, 11.203912036759512, 0.18163655059678213, 0.5997854928885187, 0.919162209544863, 3.1540300931249345, 5.611751675605774, 12.036955884524755, 13.36563731942858, 20.385931287493023, 53.933508600507466, 47.903073242732454, 51.62605701174055, 49.26762301581246, 52.33243867329189, 49.67124039786202, 49.89969369343349, 46.90003824234009, 38.19513354982649, 34.391554151262554, 35.38867276055472, 36.687878199986045, 43.85990258625576, 44.92059373855591, 46.623263699667795, 45.36436823436192, 49.342069489615305, 45.273287773132324, 44.770276410239084, 46.837136200496126, 45.240419319697786, 42.132309436798096, 41.35711281640189, 38.01877784729004, 34.5207176889692, 34.625461782727925, 33.25572517939976, 38.186708859034944, 43.41679164341518, 45.18748446873256, 39.271576268332346, 34.411047322409495, 32.343621253967285, 33.7742657661438, 33.83059481212071, 34.79637704576765, 34.625117846897666, 34.06408902576992, 34.0654856136867, 37.51949766704014, 43.83786290032523, 47.15764965329851, 47.21304416656494, 47.91205031531197, 47.02568599155971, 45.41060502188546, 43.45076833452497, 43.32353292192732, 40.203347069876536, 39.41947562353951, 38.89677653993879, 43.30552666527884, 45.35793072836739, 49.78079959324428, 39.30525071280343, 24.364940541131155, 45.51121146338326, 39.391943386622835, 45.84475973674229, 43.01502595629011, 48.593977791922434, 44.77903461456299, 46.66642243521554, 44.89304413114275, 46.13273130144392, 45.23781721932547, 46.99031966073172, 45.32795967374529, 44.2287129674639, 44.81057596206665, 40.7616035597665, 36.03081137793404, 34.22940056664603, 35.287722383226665, 36.70019735608782, 33.83394731794085, 34.17922762462071, 33.77066659927368, 42.4306720324925, 48.3675012588501, 46.778740065438406, 46.98018571308681, 42.87350157329014, 36.76342248916626, 36.49053198950631, 41.50240312303816, 45.11023439679827, 45.84147671290806, 45.99272857393537, 43.86503035681588, 45.71791689736502, 46.31542723519461, 46.516407353537424, 48.16011142730713, 45.54099491664341, 44.52728400911604, 47.78591966629028, 48.426032883780344, 50.212220191955566, 47.90087761197771, 48.16457564490182, 45.30158083779471, 51.39453261239188, 50.767794677189414, 51.474916321890696, 48.14788954598563, 47.65605436052595, 46.051451274326865, 50.1687661579677, 46.197203636169434, 46.32565150942121, 37.574364117213655, 13.595265729086739, 0.19585846816854818, 1.7578368123088564, 0.4076773284801415, 0.4029731809028557, 0.13410047707813127, 1.1957002963338579, 32.00985063825335, 32.13704088756016, 27.788371835436138, 19.302752290453228, 23.23237201145717, 27.78053774152483, 40.511819294520784, 42.85646111624581, 38.236652510506765, 4.185246552739825, 0.18111050953822477, 0.05184016702696681, 0.02868415867643697, 0.06864754389971495, 0.05356429397527661, 0.04716577999559896, 0.02442994088466678, 0.03180515513356243, 0.040777535643428564, 0.04127901712698596, 0.01632790027984551, 0.010089731758593448, 0.03798218171245285, 0.04696326104125806, 0.02120960859714874, 0.02868733082764915, 0.036766894959977696, 0.02470565850048193, 0.021249129869309918, 0.014479084040171333, 0.035783880922411165, 0.03453335106106741, 0.07513669997985874, 0.024951727528657233, 0.07536764615880591, 0.016578987074483718, 0.045575263377811225, 0.1271436203803335, 2.1545254290103912, 42.3496664592198, 48.94334363937378, 45.79501758302961, 31.634460312979563, 20.424476419176372, 28.74235429082598, 45.37327235085623, 44.2496200970241, 44.55395814350673, 12.570756452424185, 0.2806240346814905, 0.2533814236521721, 1.8090222371476037, 1.8939037110124315, 6.143517289842878, 8.768819434302193, 6.297476777008601, 22.692948613848003, 55.35508223942348, 50.1556271144322, 51.82966702325003, 51.10881921223232, 53.771024976457866, 49.589505263737266, 52.3554858480181, 48.60920129503523, 40.50668804986136, 36.01244034085955, 37.0147179876055, 38.029888016836985, 45.832416261945454, 46.81933491570609, 48.422319071633474, 48.43481888089861, 51.05590173176357, 46.16780580793108, 44.90903888429914, 47.278940882001606, 47.677892548697336, 44.7920902797154, 42.628890241895405, 40.27841540745327, 35.42866659164429, 36.977625029427664, 36.91508081981114, 40.60614456449236, 45.637998717171804, 47.55573626926967, 41.12448712757656, 36.19342006955828, 34.63810403006417, 34.720016343253, 34.98631647654942, 37.01780646187918, 35.74534811292376, 35.21174383163452, 34.34774228504726, 39.03314535958426, 45.282789434705464, 48.64899015426636, 48.95855324608939, 49.41070032119751, 48.04162379673549, 47.52082851954869, 44.50467804500035, 43.86091354915074, 42.57193585804531, 41.5154344694955, 40.89621448516846, 44.943495001111714, 46.184279986790244, 52.122881003788535, 40.43785572052002, 25.978171552930558, 46.146061420440674, 41.01782533100673, 47.11065551212856, 45.11137390136719, 49.520825794764924, 45.93520443780081, 48.691881384168354, 47.16685949053083, 47.549142428806846, 47.45030082975115, 49.69680976867676, 45.51988976342337, 46.10071052823748, 46.42848832266671, 42.26002427509853, 37.36895104816982, 35.57904297964913, 36.6032144001552, 38.13042150224958, 34.33392926624843, 36.25628042221069, 35.65939542225429, 44.7505852154323, 50.055215222494944, 47.601365089416504, 47.98605210440499, 44.9698668888637, 38.82972642353603, 39.449210439409526, 42.83205556869507, 47.858861855098176, 48.36106375285557, 46.535205704825266, 45.14065361022949, 47.09569604056222, 47.96703488486153, 46.886864457811626, 49.66738067354475, 46.11689983095442, 45.181971073150635, 48.63529525484358, 51.130671296800884, 51.94865492412022, 49.80528851917812, 48.81016404288155, 47.89220973423549, 51.784427302224294, 52.52055767604283, 53.392316886356895, 50.4079544203622, 46.5077394757952, 47.355968611580984, 49.90004110336304, 49.533252647944856, 50.33752053124564, 41.38916833060128, 13.831343804086957, 1.9761471492903573, 4.450258229460035, 3.027551817042487, 1.2520877506051744, 0.14914350344666413, 1.5479570286614555, 36.814748832157676, 39.03562239238194, 36.59412963049752, 25.17149611881801, 25.126758405140468, 33.06598377227783, 44.87998499189104, 48.38644552230835, 46.653849669865195, 5.552498306546893, 0.2976612890405314, 0.08306807545678956, 0.03352053237280675, 0.016462387616879175, 0.07033795783562319, 0.04855734336056879, 0.03321014670655131, 0.038614756161613126, 0.02628812599661095, 0.04826441640034318, 0.006770119195737476, 0.026817023687596832, 0.044948205418352566, 0.07353678225938763, 0.12418124505451747, 0.15262677653559617, 0.0931159034371376, 0.18228700783635887, 0.15130965864019735, 0.24455788997667177, 0.06851037126034498, 0.10830290136592728, 0.19713378830679826, 0.17156774231365748, 0.33070095043097225, 0.15165651217103004, 0.22640521904187544, 0.3067382691161973, 3.6390067551817213, 50.70650461741856, 56.59068386895316, 54.37332609721592, 34.88083239964077, 27.24397873878479, 38.529529503413606, 51.79023947034563, 48.730683599199565, 49.52712433678763, 13.951616253171649, 0.3605104051530361, 0.7101849317550659, 4.325115527425494, 5.605079667908805, 10.32254694189344, 18.913979734693253, 19.997033664158412, 24.359044994626725, 57.64780017307827, 53.079074723379954, 55.31673860549927, 53.817887101854595, 57.260465894426616, 53.25971051624843, 53.631856032780235, 50.63449696132115, 42.00212451389858, 37.99765879767281, 39.735441480364116, 39.51374183382307, 48.265463488442556, 49.513325214385986, 50.41954401561192, 51.0606404032026, 53.005892821720664, 47.58559962681362, 45.83229814256941, 48.816521644592285, 49.59474420547485, 46.90075738089425, 44.49120896203177, 42.59327030181885, 37.50808872495379, 38.756864139011924, 39.116697447640554, 42.62587819780622, 48.41634362084525, 50.29039437430245, 43.79893214362008, 38.322334221431184, 37.160970619746614, 37.42425870895386, 37.271453925541465, 39.135683400290354, 37.40085717609951, 36.298035621643066, 37.259294578007285, 41.3761682510376, 48.06482383183071, 50.69966064180647, 51.36293567929949, 50.81385775974819, 50.41350255693708, 48.446022851126536, 46.09480108533587, 46.34004817690168, 44.571245261601035, 42.202899660382954, 43.088364192417686, 47.38761418206351, 49.934844630105154, 52.93455219268799, 44.39748123713902, 28.544012750898087, 46.23662076677595, 41.557179246629985, 50.67816986356463, 46.617267404283794, 51.26869378771101, 47.40246248245239, 49.9454927444458, 49.39778014591762, 51.12185403278896, 49.64398261478969, 50.17208392279488, 48.091918332236155, 45.92221130643572, 48.86356789725167, 44.462898526872905, 38.65426009041922, 37.413812092372346, 39.19885989597866, 40.324273518153596, 37.1054892539978, 38.057361194065635, 36.11324828011649, 46.32455369404384, 53.1608168057033, 49.37915897369385, 50.0978285244533, 46.60995789936611, 40.96895170211792, 40.20899942943028, 45.414846897125244, 48.77519028527396, 49.269505977630615, 49.457739625658306, 46.03800998415266, 48.2419090952192, 50.3575313431876, 48.3081636428833, 50.32941893168858, 46.75882305417742, 45.29547684533255, 50.90747431346348, 53.26348338808332, 54.41589770998274, 50.6829571723938, 50.37071555001395, 48.283580916268484, 52.93382263183594, 52.52461889811924, 54.473915168217246, 49.74090998513358, 46.56623635973249, 46.74418319974627, 52.56536660875593, 48.68214348384312, 51.30895512444632, 40.60976110185896, 17.61283574785505, 4.364172654492514, 9.531239186014448, 1.8785725108214786, 0.9875381290912628, 0.17363050234104904, 1.5576422746692384, 44.08147716522217, 43.34247023718697, 39.97664819444929, 28.733295576913015, 35.88860954557146, 38.75810786655971, 54.73914875302996, 54.57052986962454, 57.44364472797939, 6.980263658932277, 0.6163558065891266, 0.23225914420826094, 0.14204381512744085, 0.1328918705029147, 0.18416380855653966, 0.1734550196145262, 0.10795000208807842, 0.17711347687457288, 0.13572345141853603, 0.11488403965319906, 0.06579851784876414, 0.05885732173919678, 0.1253575805042471, 0.14366214828831808], [0.058172639193279405, 0.08804457341986043, 0.011189361368971211, 0.04471440939232707, 0.01011312849420522, 0.03582333094839539, 0.054404703700648885, 0.042958482900368314, 0.018028237790401493, 0.025886789496455873, 0.03817890937040959, 0.01791971968486905, 0.010545586002990603, 0.21023442676024778, 4.889132508209773, 34.93756791523525, 35.80602673121861, 31.076676300593785, 16.238351787839616, 19.86366994040353, 31.7925318309239, 44.59027637754168, 39.666154044015066, 35.00939491816929, 7.380412152835301, 0.18848288751074246, 0.48202829169375555, 3.4883409312793185, 3.8072636808667863, 18.578496388026647, 10.826447674206324, 16.05760482379368, 39.12041473388672, 55.91669123513358, 48.107009819575715, 46.84174633026123, 42.050192151750835, 44.11591591153826, 43.173302446092876, 42.173348971775596, 37.34723097937447, 38.1161082131522, 35.28757299695696, 35.879906926836284, 36.15055315835135, 36.348156452178955, 38.91618633270264, 40.26637417929513, 44.76005213601248, 46.673447063991, 46.412785393851145, 45.43657738821847, 45.49740539278303, 47.389448506491526, 46.46893726076399, 43.81575720650809, 43.275819642203196, 40.447875022888184, 35.37097222464425, 32.8660945211138, 34.489888531821116, 36.79455736705235, 37.21081352233887, 34.3291072164263, 34.11183704648699, 34.12644215992519, 34.10447195598057, 34.79640483856201, 34.431634834834504, 33.60800927025931, 36.99753509249006, 35.03094475609915, 36.11336292539324, 46.15304783412388, 46.41364349637713, 46.17073447363717, 46.784013748168945, 46.62708173479353, 46.740125451769146, 43.96505662373134, 41.64779765265328, 40.15684277670724, 42.81781870978219, 44.76635415213448, 46.72496795654297, 45.41748373849051, 49.04836218697684, 39.57059894289289, 26.805307694843837, 43.81622620991298, 41.653314522334504, 44.86714819499424, 43.49124159131731, 45.395690713609966, 42.43685245513916, 45.37459945678711, 43.28225367409842, 47.59256519590105, 47.19933189664568, 43.76206847599575, 43.93431779316494, 43.92827633449009, 43.247272968292236, 41.27069459642683, 36.74054207120623, 33.85115800585066, 34.8564372743879, 34.49645457948957, 37.49675273895264, 36.1389149257115, 35.69982351575579, 36.37096043995449, 40.22383730752127, 41.046681199754985, 39.2196558543614, 38.668809618268696, 36.54912962232317, 38.77477312088013, 45.41330092293875, 47.52165535518101, 43.7226687158857, 43.3850279535566, 46.7875052179609, 47.021169662475586, 46.243357045309885, 46.207949025290354, 44.41394846779959, 46.41975791113717, 50.40636328288487, 47.99540785380772, 47.096800804138184, 46.52729170663016, 49.74107674189976, 49.261633668627056, 49.02335909434727, 43.95162228175572, 45.497398444584434, 45.274180616651265, 47.164973054613384, 51.02485718045916, 54.21639060974121, 52.97368097305298, 55.908544472285676, 51.69304806845528, 46.977013860430034, 17.483368226460048, 1.3219909710543496, 2.202234366110393, 2.4266509754317145, 1.1407551360981805, 0.2419932447373867, 0.17060156272990362, 26.067501068115234, 41.3008463042123, 27.939663648605347, 21.735773461205618, 21.85335956301008, 37.2571336882455, 43.695959840502056, 46.53778348650251, 43.41309520176479, 7.249887202467237, 0.11022590353552784, 0.09890150691249541, 0.06278552381055695, 0.025488962718684758, 0.06273624181215252, 0.0875355296635202, 0.12025654422385351, 0.042829686775803566, 0.03540594030969909, 0.027635191035057818, 0.013000868360645004, 0.0429473956381636, 0.06207255992506232, 0.01552096099060561, 0.05214522958600095, 0.056669260042586496, 0.010235471750742622, 0.010691591471965824, 0.045643751309918504, 0.03639682874615703, 0.05928206430482013, 0.03374286794236728, 0.07347185324345316, 0.010149560735693999, 0.07742036386792149, 0.04168243672964828, 0.07924315998596804, 0.21896105206438474, 7.385779636246817, 45.467291900089805, 43.81912708282471, 39.75483042853219, 22.342245238167898, 21.233955451420375, 32.0419339452471, 49.48498351233346, 44.45234768731253, 40.41224813461304, 7.396295734814235, 0.1539202407002449, 2.0939579818929945, 5.343364477157593, 5.611267473016467, 22.38461709022522, 7.98922894682203, 9.404201797076635, 41.06555250712803, 56.6579806464059, 50.48936298915318, 48.02239465713501, 44.683024406433105, 46.4753052847726, 46.34151772090367, 44.05791582380022, 38.55259057453701, 37.98049327305385, 36.51127931049892, 38.11030299322945, 38.202686241694856, 38.14457845687866, 40.84535367148263, 42.88349655696324, 45.82597180775234, 48.22105755124773, 47.87885529654366, 44.995811462402344, 46.299102442605154, 48.44196857724871, 48.231917585645405, 47.42529773712158, 45.817939690181184, 41.21171133858817, 37.04763855252947, 34.51076092038836, 36.41205556052071, 38.46342781611851, 39.66563292912075, 36.45852511269705, 35.39497477667672, 36.1160101890564, 35.38540710721697, 35.92663356236049, 35.100388526916504, 35.06908689226423, 38.5812623160226, 36.230245522090364, 38.30590173176357, 48.32597534997122, 48.22548007965088, 48.885600634983604, 48.076500279562815, 48.20323542186192, 49.10483019692557, 46.282930510384695, 43.585605076381135, 41.66989292417254, 44.980674811771934, 45.248520919254844, 48.926799978528706, 46.63157374518258, 50.60385887963431, 42.05065768105643, 29.554426738194056, 43.97460692269461, 42.77145685468401, 45.690857137952534, 44.831382342747276, 46.42306177956717, 43.87373297555106, 47.37657002040318, 46.02008363178798, 48.74673046384539, 49.249258926936555, 45.931032044546946, 45.877812317439485, 46.02843884059361, 45.09650475638253, 42.64123024259295, 38.04449660437447, 35.828611850738525, 37.548270157405305, 37.019095352717805, 38.35688761302403, 37.97484786169869, 35.98587390354702, 37.68386772700718, 41.96501071112496, 44.328850405556814, 41.496062891823904, 39.82885306222098, 37.541909081595286, 40.58612333025251, 46.90693085534232, 48.8567829813276, 45.530631678445, 44.432243074689595, 46.378468241010395, 47.53679895401001, 47.19582305635725, 48.50579472950527, 45.15538726534162, 47.54944120134626, 51.740632806505474, 49.80116823741368, 49.55658122471401, 47.473167351314, 50.328824860709055, 50.867098331451416, 47.98346390042986, 46.123757702963694, 47.44914395468575, 44.48241949081421, 47.72701978683472, 51.26263148444039, 57.24004513876778, 53.96502215521676, 55.43932914733887, 52.58838251658848, 47.48590687343052, 17.32748886517116, 3.13386316384588, 3.537289470434189, 7.52077271257128, 2.902089932135173, 0.05032836047134229, 0.1739477174622672, 31.15537507193429, 47.49508891786848, 30.94626556124006, 21.06390871320452, 28.10363245010376, 43.810233388628276, 51.285942690713064, 51.29524632862636, 52.956921918051584, 9.031721898487636, 0.10651693612869297, 0.03575672934363995, 0.09476747124322824, 0.05929665280772107, 0.04113414990050452, 0.05909645783581904, 0.0725387047444071, 0.04346396095518555, 0.006948548036494425, 0.04143372989658799, 0.019752376613074114, 0.018572400822969418, 0.016606555952291404, 0.07503770850598812, 0.26551949232816696, 0.21378686970898084, 0.2078911874975477, 0.1038111284641283, 0.09928627698017017, 0.21168228478303977, 0.19019536062010697, 0.09950555914214679, 0.21229506975838117, 0.07502974250486918, 0.15671319940260478, 0.1535241933805602, 0.23988794056432589, 0.3915440727557455, 10.211539915629796, 56.35601193564278, 52.16347932815552, 46.55722802025931, 26.24654746055603, 28.49374600819179, 43.51291649682181, 53.89243432453701, 48.99014670508248, 45.216347285679404, 8.977006571633474, 0.37136805110744064, 2.117855442421777, 5.909056408064706, 5.14341138941901, 25.076288427625382, 23.292651108333043, 20.929933547973633, 40.31895119803292, 60.969518525259836, 49.57497658048357, 50.56426109586443, 45.55888305391584, 48.63993665150234, 46.48742989131382, 46.92405469076974, 39.94701760155814, 40.92720692498343, 37.987535272325786, 40.46783719744001, 40.337443828582764, 39.52943434034075, 42.63977459498814, 44.32938889094761, 47.80365146909441, 50.70790467943464, 48.82331698281424, 45.37415129797799, 46.58648688452584, 50.297464166368755, 50.44605834143502, 48.976955550057546, 47.17008692877633, 43.585681506565635, 38.58106081826346, 35.4099029813494, 38.74265159879412, 41.175872530256, 41.621536936078755, 37.224181856427876, 36.90891081946236, 38.50723620823452, 37.64431163242885, 39.08319670813424, 36.85566329956055, 37.40882328578404, 40.115278652736116, 38.963569572993684, 39.416196073804585, 51.10138463973999, 50.55552026203701, 52.09543561935425, 50.199741227286204, 50.69324745450701, 50.96422372545515, 48.82048559188843, 44.752937180655344, 45.87302500861031, 47.31450523648943, 49.09606157030378, 49.08722346169608, 50.224841594696045, 52.51694808687483, 43.82950421742031, 31.293004989624023, 44.38254608426775, 45.12310593468802, 46.398558957236155, 45.65960761478969, 49.57043593270438, 44.45542573928833, 48.1645131111145, 47.4462639263698, 51.9085499218532, 52.004105022975374, 47.69840710503714, 47.33040271486555, 47.08570800508772, 47.75988129207066, 45.54011249542236, 39.22618021283831, 38.138509205409456, 39.15327276502337, 37.83567544392177, 41.55945825576782, 41.071086747305735, 39.09033598218645, 38.844418389456614, 43.95533956800188, 46.301204272678916, 41.941991329193115, 42.48675094332014, 39.800209113529746, 42.41071680613926, 50.46242134911673, 50.658951146262034, 46.366222040993826, 45.54440300805228, 47.91452387401036, 50.313577038901194, 48.758062975747244, 49.524042810712544, 46.40776184626988, 49.189018045152935, 54.03635931015015, 53.667243208204, 50.965599468776155, 50.94820812770298, 52.99547052383423, 52.880165168217246, 49.2659797668457, 46.89293023518154, 48.55975791386196, 44.93213469641549, 48.00880398069109, 54.05377149581909, 60.44677775246756, 56.42976706368582, 58.85589041028704, 55.8136042867388, 50.87470660890852, 21.1377854347229, 5.225617698260716, 5.353992181164878, 8.47816412789481, 2.7107971225466048, 0.4393177149551255, 0.3399795639727797, 33.922991956983296, 52.617995738983154, 37.672104426792686, 30.306214877537318, 32.88382632391793, 47.22408485412598, 57.914631843566895, 57.280772004808696, 62.62826197487967, 12.16713125365121, 0.2758600674569607, 0.1498341163886445, 0.2521251839186464, 0.1351111549884081, 0.17489276746554033, 0.23586805484124593, 0.1753270841602768, 0.10078501834401063, 0.08743246697953769, 0.07043914776295424, 0.0736276652397854, 0.15458812271910055, 0.1879105567932129, 0.1456773430109024], [0.05363408808729478, 0.004915520565451256, 0.05941625139010804, 0.04771938993196402, 0.08734569592135293, 0.02913428862978305, 0.06585406272539071, 0.07644341593342167, 0.03402982718710389, 0.03433599915089352, 0.00916346106013017, 0.03696360904723406, 0.06815995542066437, 0.0990338483825326, 7.908413580485752, 32.0328665460859, 33.508698667798726, 29.307793481009348, 20.56538414955139, 17.060299362455094, 30.421238831111364, 49.57852710996355, 34.16116230828421, 32.18789822714669, 3.09112349152565, 0.12035945084478174, 1.4591334291866846, 2.7411768180983405, 1.227301029222352, 5.354102918079921, 7.3076419319425305, 19.02537499155317, 48.51795060294015, 50.46312659127371, 50.90568167822701, 45.861518791743684, 39.44387074879238, 35.17893443788801, 36.818754468645366, 37.52262435640608, 43.82953201021467, 44.79611676079886, 43.96029363359724, 41.727979864392964, 39.935011114392964, 40.88529191698347, 42.479809692927766, 42.63009228025164, 43.14636428015572, 47.560641697474885, 48.17300033569336, 47.487282616751536, 43.34152528217861, 42.3879406111581, 45.82614551271711, 44.426052229745046, 45.453023774283274, 43.12214285986764, 39.782897676740376, 34.24637848990304, 32.33010005950928, 33.75657912663051, 34.50534132548741, 33.41596106120518, 34.52554668698992, 35.36161994934082, 34.26209531511579, 33.49432979311262, 34.51731654575893, 34.24852548326765, 36.83344643456595, 34.8285367829459, 36.088304247174946, 46.21615137372698, 46.61945956093924, 44.197136878967285, 45.61066450391497, 44.92229952130999, 44.9840064729963, 40.93894938060215, 40.74865559169224, 41.21152721132551, 46.70616613115583, 47.80454083851406, 49.41672788347517, 46.00767067500523, 51.2168185370309, 38.72227253232683, 25.164461067744664, 43.03111798422677, 41.695618629455566, 47.23676184245518, 42.34231526511056, 44.914562702178955, 42.522179807935444, 45.00130748748779, 42.2598922593253, 44.515611035483225, 42.59523664202009, 46.760601793016704, 45.19047566822597, 43.22561543328421, 41.734608445848735, 39.84629651478359, 35.426700251443044, 34.27352510179792, 35.14072629383632, 35.059699875967844, 33.65971776417324, 35.13027967725481, 35.00896412985665, 35.49893372399466, 34.82004608426775, 34.427177565438406, 34.60929332460676, 35.42994506018502, 37.37516968590872, 44.04697241101946, 46.08471924918038, 46.35988528387887, 42.60240718296596, 44.0785311290196, 43.70303658076695, 45.56301028387887, 44.08552796500069, 41.4073726109096, 44.82716826030186, 50.593909059252056, 46.66032191685268, 46.638723441532676, 42.661644050053184, 41.738551548549104, 46.65196670804705, 48.3107761655535, 48.31597341809954, 41.44882556370327, 47.87255675452096, 49.00170155933925, 51.7569853918893, 50.65441744668143, 51.64729765483311, 50.86994014467512, 51.60362127849034, 53.64768055507115, 50.01849051884243, 19.17410465649196, 3.265378449644361, 2.166750784431185, 7.693476268223353, 0.6728702283331326, 0.10179377600018467, 0.028838864660688808, 15.614902087620326, 38.660926886967246, 40.30126108442034, 62.6099465233939, 24.593027319226945, 23.179414578846522, 38.2627603667123, 42.81567171641758, 46.68853507723127, 9.020141857010977, 0.020388986649257795, 0.03338854034830417, 0.03951921280739563, 0.05352203481431518, 0.04855760120387588, 0.07950956640498978, 0.017797429014795592, 0.05654499653194632, 0.03801736036049468, 0.07849028467067651, 0.043021864856460264, 0.08241544011980295, 0.004586581207279648, 0.0509678932971188, 0.07011972740292549, 0.012553006410598755, 0.048143409857792516, 0.04043998482770153, 0.0750529755439077, 0.0398740119832967, 0.02807654074526259, 0.05587421377588596, 0.042834399201508076, 0.04274260359151023, 0.011236390631113733, 0.06713111312793833, 0.07252641647521939, 0.13581892129565987, 10.681127837726049, 41.03923967906407, 41.05363287244524, 37.72065496444702, 26.288137640271867, 22.49264768191746, 35.45976325443813, 55.05910982404436, 40.31736700875418, 36.36480781010219, 3.426303940159934, 0.037778631384883604, 2.008079550095967, 3.4697977091584886, 2.9108516105583737, 9.706282547542028, 7.744780029569354, 19.071363380977086, 49.16929905755179, 52.729899951389854, 51.696164335523335, 47.351587772369385, 40.49183627537319, 38.148243631635395, 37.09257255281721, 39.268915108272004, 45.37788595472063, 46.342726707458496, 46.134847027914866, 43.043576104300364, 41.507544789995464, 42.42104530334473, 43.56533023289272, 44.01790114811489, 45.25320747920445, 48.926112106868196, 50.29779420580183, 48.424292360033306, 43.570701190403526, 44.55117538997105, 46.49010147367205, 46.26277378627232, 46.53908279963902, 44.873144490378245, 41.448172433035715, 35.5369507925851, 34.26280403137207, 34.319188662937705, 34.53781720570156, 35.224257537296836, 36.08961745670864, 35.838401862553184, 36.1590508052281, 35.146611418042866, 35.40863840920584, 35.21713215964181, 38.38486800874983, 36.66052314213344, 37.28589923041207, 47.602393422807964, 48.10188899721418, 47.32944386345999, 47.52837773731777, 47.124190602983745, 45.97218969890049, 42.980093887874055, 43.66660022735596, 43.400560651506694, 48.58930165427071, 49.541194438934326, 51.16875089917864, 47.42701046807425, 52.721867833818706, 39.22377961022513, 27.740905216762, 44.84926005772182, 42.235382488795686, 47.096099036080496, 45.80118758337838, 46.30876043864659, 44.29936572483608, 46.19930894034249, 43.595481940678184, 46.06370789664132, 45.119458130427766, 49.05506719861712, 46.26366662979126, 45.05991901670183, 43.710554531642366, 40.586467266082764, 37.52042872565133, 35.59827559334891, 34.96090344020298, 35.81117187227522, 36.006562164851594, 37.111106872558594, 35.092061110905235, 36.09950474330357, 36.27505098070417, 36.383144106183735, 37.265631335122244, 37.48478446687971, 38.82673522404262, 45.66695533479963, 48.33825281688145, 47.95826973233904, 44.204693044934956, 44.792837211063926, 45.38927405221121, 47.70528929574149, 45.94878469194685, 43.01313952037266, 45.43841518674578, 51.65513522284371, 48.84915385927473, 49.12697063173567, 45.447235924857004, 44.534458024161204, 48.90571566990444, 49.020329679761616, 48.95470741816929, 44.38931710379464, 47.75486469268799, 49.633101735796245, 52.300164290836875, 51.748720509665354, 54.266952650887625, 52.25952427727835, 52.72158990587507, 55.975361824035645, 52.159654344831196, 22.744710956301006, 5.253646731376648, 2.8469507651669637, 10.691257442746844, 1.915369519165584, 0.05188501819169947, 0.09291355072387628, 17.57973105566842, 45.17772224971226, 43.403100218091694, 56.70740665708269, 28.785434859139578, 28.17356606892177, 43.87655047007969, 51.37327807290213, 55.06371995380947, 12.39662069933755, 0.08751813881099224, 0.028846806913082088, 0.015206105474914824, 0.04619104747793504, 0.07982193000082459, 0.04923084704205394, 0.01227090717293322, 0.03217714160148587, 0.01695950442392911, 0.022891223630202667, 0.034875868753130944, 0.058819920888968875, 0.03061537111976317, 0.046189605591020415, 0.23211380200726645, 0.15105735217886312, 0.2036135263208832, 0.11475563368627004, 0.2627009664263044, 0.13184755082641328, 0.179285413186465, 0.2274028690797942, 0.1466003677674702, 0.07575309476149933, 0.11091015181903328, 0.14138282702437469, 0.2870241669671876, 0.23360590051327432, 15.060889210019793, 52.99885082244873, 49.22371734891619, 44.023841857910156, 31.47352613721575, 26.017206532614573, 39.839963231767925, 57.564765725817, 45.37330709184919, 41.43383135114397, 3.7964084233556474, 0.1374472967748131, 3.2995190748146603, 4.806241367544446, 4.012268108980996, 8.257995690618243, 12.35553686959403, 21.433014392852783, 51.05157995223999, 53.59782028198242, 55.316332135881694, 49.510212421417236, 43.383360385894775, 39.073618616376606, 39.66879783357893, 41.34281342370169, 48.41948420660836, 48.88256079810006, 49.40438093457903, 46.31119230815342, 42.97217641557966, 45.72959334509713, 46.78756080354963, 47.55988434382847, 47.581204891204834, 51.81379386356899, 50.91226857049124, 48.587133816310335, 46.7485397202628, 44.571443285260884, 48.26157944543021, 47.35646193368094, 48.10722868783133, 46.82160002844674, 43.01773227964129, 37.693484033857075, 36.23387942995344, 37.06716993876866, 37.74584565843855, 36.661287443978445, 38.22093915939331, 38.330206530434744, 38.631014892033164, 37.29166276114327, 36.23761756079537, 37.80198015485491, 39.653598649161204, 39.31474542617798, 39.46184573854719, 50.867338044302805, 49.75230155672346, 50.23706347601754, 49.55540350505284, 47.95086990083967, 47.35644803728376, 44.44605609348842, 44.644204820905415, 44.55226625714983, 51.44532741819109, 52.557362283979145, 51.857025555201936, 49.69487122126988, 53.70440217426845, 42.64307151521955, 30.014161246163503, 45.419144357953755, 43.43880353655134, 49.00967461722237, 46.5246513911656, 46.960636956351145, 45.729284150259836, 46.83816453388759, 45.29665456499372, 46.82748862675258, 46.29366200310843, 50.18688358579363, 49.50949675696236, 47.16217640468052, 45.71118756702968, 43.145818846566335, 38.68049996239798, 37.98299462454659, 37.53626367024013, 38.024485792432515, 37.57691410609654, 39.085732800619944, 38.4355377469744, 39.38028083528791, 39.31439454214913, 37.3069418498448, 38.594338825770784, 39.45385183606829, 42.18401098251343, 48.428047861371724, 50.75496135439192, 48.877738748277935, 45.68992607934134, 46.819762229919434, 47.17070531845093, 48.564291613442556, 48.80546358653477, 44.43121474129813, 47.10738638469151, 54.27747222355434, 51.61724322182791, 51.47430835451399, 48.272581917899, 45.989511557987754, 51.50937591280256, 50.00609840665545, 51.76104661396572, 47.23393739972796, 49.5986317225865, 51.102492877415244, 54.83382838112967, 55.160768917628694, 56.31572280611311, 53.34713969911848, 55.04848950249808, 58.55679130554199, 55.49697835104806, 25.1519421509334, 7.8194184473582675, 8.58321567944118, 15.58932055745806, 2.217189060790198, 0.2631441583590848, 0.19362448661455087, 20.354179756981985, 51.061821596963064, 50.98387670516968, 73.2959771837507, 35.3708610534668, 33.469715799604145, 51.69866221291678, 55.24118389402117, 63.88579559326172, 15.966416665485927, 0.18044086332832063, 0.1274696293153933, 0.2148082684725523, 0.14241854287683964, 0.17223402298986912, 0.12070208388779845, 0.10388392848627907, 0.11365020514598914, 0.1765341301049505, 0.12395214449082102, 0.144723987739001, 0.20424843153783254, 0.09070268007261412, 0.15720661649746553], [0.042930761352181435, 0.008124384762985366, 0.03140125037836177, 0.027141141206292168, 0.0527921720141811, 0.07576268246131283, 0.02056527852879039, 0.028046795466382588, 0.024969055616695966, 0.0699485262323703, 0.013540811753565711, 0.04068624214934451, 0.02775882350813065, 0.024782877481941665, 14.207517538751874, 38.691231455121724, 34.787000451769146, 34.005560874938965, 17.866563115801128, 20.096735102789744, 40.66015986033848, 47.60281726292202, 32.268629346575054, 33.11674731118338, 1.3114358974354607, 0.004011778501860265, 1.2401631219046456, 3.278351387807301, 4.186043424265725, 7.651659403528486, 14.72138980456761, 33.11580583027431, 54.94646562848772, 50.31289611543928, 52.11152417319161, 45.51248645782471, 40.0588002204895, 37.08837584086827, 37.47037042890276, 44.98906476157052, 49.60126508985247, 47.887571811676025, 46.150803565979004, 45.74379546301705, 44.48269394465855, 45.227050985608784, 46.300036975315635, 44.49771247591291, 44.98410027367728, 47.115588733128135, 46.83904695510864, 43.84809064865112, 42.905001231602256, 41.27297360556466, 43.4027076448713, 42.65670735495431, 44.52294485909598, 43.94590738841465, 42.38864237921578, 35.602586950574604, 32.526803561619346, 33.51020990099226, 33.64832271848406, 34.313855920519146, 33.33272859028408, 33.89836406707764, 33.75694043295724, 34.803311347961426, 32.74510901314871, 32.35876832689558, 33.80406658990042, 33.734740938459126, 35.83701569693429, 43.02925934110369, 47.622185366494314, 44.4873422895159, 46.56705624716622, 45.38890927178519, 44.547294821058, 41.33338124411446, 41.296826771327424, 43.1876539502825, 48.65514278411865, 47.03124107633318, 46.365551539829795, 41.260803835732595, 45.78798600605556, 36.63087517874581, 27.83205168587821, 45.97786290305001, 41.14748566491263, 44.09091281890869, 43.676647322518484, 42.17778539657593, 39.2733028956822, 39.485483510153635, 39.75931896482195, 41.94967951093401, 43.64444589614868, 44.22692380632673, 47.11416435241699, 44.77032504762922, 43.279436179569785, 39.21645968300955, 33.71244069508144, 35.78816638674055, 35.423955712999614, 35.494497299194336, 39.034660066877095, 35.360490867069785, 34.971999713352744, 34.05901684079851, 34.17732034410749, 35.24417107445853, 34.56633608681815, 35.29756450653076, 38.577353954315186, 41.88908774512154, 43.560299737112864, 45.808097566877095, 46.05007553100586, 44.81100675037929, 44.134141036442344, 44.302440302712576, 41.64964587347848, 46.78993361336844, 47.94000291824341, 47.14599405016218, 45.95581974302019, 42.325677803584504, 39.28176580156599, 39.23311798913138, 44.43081521987915, 50.0185877936227, 48.28882680620466, 46.7676750591823, 51.70344952174595, 48.4838627406529, 51.05321625300816, 48.18930080958775, 50.48522881099156, 48.37419237409319, 50.485586643218994, 52.98879677908761, 54.67512110301426, 25.675732101712907, 5.235724287373679, 2.5600240358284543, 10.598162003925868, 3.360154701130731, 0.06469229542251144, 0.04753050274614777, 9.253385935510908, 44.19142893382481, 36.4956945010594, 44.40334899084908, 24.825276068278722, 26.7153354712895, 44.030915124075754, 49.16153791972569, 47.55766439437866, 13.450832656451635, 0.0350981907519911, 0.0330340431204864, 0.103747916141791, 0.009256351656014366, 0.0652016241635595, 0.006967967284643757, 0.06896532220499856, 0.06447793263942003, 0.106595130504242, 0.0394575780789767, 0.018130313205931867, 0.05302359995299152, 0.0289827005139419, 0.0313257803209126, 0.034784429374017885, 0.01553764786305172, 0.04997122034962688, 0.04170236191047089, 0.008346059609071484, 0.1018917089594262, 0.012867717737598079, 0.006969789151168827, 0.03943067755816238, 0.07561000529676676, 0.04492245501439486, 0.09542856791189738, 0.05277174471744469, 0.038980299939534495, 18.257008450371877, 48.07971729551043, 42.53525979178292, 40.81072384970528, 23.26784256526402, 22.53999444416591, 44.784638336726594, 53.707876273563926, 35.749694211142405, 35.9514490536281, 1.4655988365411758, 0.027086195136819567, 2.5172580906323025, 4.598662197589874, 3.585697570017406, 4.279171867030008, 12.831352983202253, 33.48671804155622, 56.43069812229702, 53.00081716264997, 53.348234040396555, 47.07709223883492, 40.53377907616751, 37.717441422598704, 40.15689836229597, 45.7561354637146, 50.948656286512104, 50.191716057913645, 47.75077567781721, 47.39547259466988, 46.28112050465175, 47.3057678767613, 49.04184825079781, 47.325622354234966, 46.67035164151873, 48.93090636389596, 48.251136302948, 45.667403493608745, 42.98409605026245, 42.128314222608296, 46.11787952695574, 43.533417156764436, 45.29075901848929, 45.70899888447353, 44.17723723820278, 38.18617384774344, 34.194419860839844, 34.85516227994646, 35.37862566539219, 36.449978828430176, 35.36595562526158, 35.02835655212402, 35.09358971459525, 35.22429575238909, 33.60475403921944, 33.78760630743844, 36.030265944344656, 35.264921869550435, 37.188370840890066, 44.314908845084055, 48.924114499773296, 45.817581857953755, 47.8652264050075, 48.143282890319824, 47.38381699153355, 43.090841225215364, 41.83682686941964, 43.96044301986694, 49.234570435115266, 48.25153235026768, 49.519154753003804, 42.79841933931623, 46.654999596732004, 36.97743395396641, 28.663645097187587, 45.668303285326274, 42.495606422424316, 46.41078083855765, 43.205493450164795, 43.998484407152446, 40.82911920547485, 41.07911886487688, 40.95784848076956, 43.45506579535348, 45.14262342453003, 45.61904403141567, 46.892513343266074, 46.39481387819563, 43.007285663059776, 39.908677441733225, 35.54076535361153, 37.14370434624808, 36.6236629486084, 37.045283113207134, 39.06663220269339, 36.455679825374055, 36.44270406450544, 34.669836453029085, 35.40584870747158, 35.87355627332415, 37.14536149161202, 36.48715169089181, 40.73900801794869, 43.28432771137783, 46.22864770889282, 47.24600642068045, 48.13609497887747, 46.45256035668509, 46.077315943581716, 46.47177907398769, 44.54801395961216, 47.0182340485709, 49.67768137795584, 49.17944342749459, 48.3987021446228, 44.38245923178536, 41.219986643110005, 40.39095885413033, 46.02846663338797, 50.81770706176758, 50.794482707977295, 49.708701610565186, 52.456842694963726, 51.36898061207363, 52.115568024771555, 50.83920131410871, 52.198922089168, 50.782552650996614, 52.74891022273472, 54.72569009235927, 55.553762504032676, 29.420663493020193, 7.8867195674351285, 2.984486665044512, 10.43072952542986, 3.7550540481294905, 0.2068277738456215, 0.023423281598037908, 10.650506258010864, 46.78420829772949, 43.71189900806972, 47.89798368726458, 30.59694835117885, 32.43971831457955, 49.41715519768851, 53.731173583439414, 54.86763136727469, 17.65303107670375, 0.008951788668387702, 0.03435661304476006, 0.04335583979263902, 0.02454156498424709, 0.06128598856074469, 0.030151650109993558, 0.028340750407161455, 0.020304334316668764, 0.03700208876814161, 0.021464539292667593, 0.015562215919739433, 0.05292067297601274, 0.03100497574944581, 0.06137850681053741, 0.12412285033081259, 0.19341750629246235, 0.09376239803220544, 0.10277777391352824, 0.10534875666988747, 0.1455327607691288, 0.1265234122318881, 0.0826854563451239, 0.107054498711867, 0.17020573254142488, 0.09188911212342125, 0.1729348546692303, 0.12261522694357804, 0.10423630529216357, 22.903524194444927, 59.85915470123291, 52.338573932647705, 47.311010292598176, 26.90792911393302, 30.174886975969585, 50.8249887738909, 54.820505210331504, 44.23825284412929, 40.80347340447562, 1.8672430387565067, 0.10561639802264315, 5.546666596617017, 8.689926981925964, 8.644476209368024, 13.740302426474434, 21.699566398348125, 35.68047973087856, 59.085340772356304, 55.10371378489903, 56.33236026763916, 49.70955276489258, 42.98401962007795, 39.84609849112374, 42.706202847617014, 48.49165167127337, 52.22835118430001, 52.057821546282085, 49.5696507862636, 50.117429392678396, 48.56991965430123, 49.73727607727051, 51.79054866518293, 48.288152830941335, 48.66935879843575, 50.21134124483381, 48.992595945085796, 46.13850178037371, 44.65518297467913, 44.46688331876482, 48.87451825823103, 44.801661423274446, 47.516263553074424, 47.479927948543, 46.79064927782331, 39.60866117477417, 35.46757302965437, 36.70724630355835, 36.504831382206504, 37.96586036682129, 36.38204976490566, 37.23152262823922, 37.80862610680716, 37.616418089185444, 35.623688629695344, 34.490701471056255, 36.875399657658164, 37.22911160332816, 40.35726009096418, 45.936885901859824, 52.232600007738384, 48.82949045726231, 48.49496596200125, 48.57204580307007, 49.70568609237671, 45.504423073359895, 44.76407514299665, 47.0935594694955, 51.46738794871739, 49.72371319362095, 49.63834415163313, 45.69355998720442, 47.153536319732666, 38.396071978977744, 32.46310942513602, 45.89635705947876, 47.014676570892334, 47.53007309777396, 45.50899151393345, 45.571129253932405, 42.384907722473145, 41.64846467971802, 40.597177914210725, 44.21909318651472, 45.67383752550398, 46.413497584206716, 48.49866240365164, 48.411875929151265, 46.61839648655483, 42.036122049604145, 36.54657963344029, 39.15946013586861, 39.244460923331125, 38.06985405513218, 41.47024685995919, 37.68336745670864, 38.62979200908116, 36.468433243887766, 37.2662010874067, 38.41216400691441, 38.1002003124782, 38.26061337334769, 41.523265089307515, 45.669213499341694, 47.702871322631836, 49.31021547317505, 48.76690108435494, 48.33170413970947, 47.572623865945, 49.22096586227417, 45.30701780319214, 48.19700288772583, 50.51756920133318, 52.644819259643555, 50.74447652271816, 46.82713079452515, 43.43792111533028, 42.709940978458945, 48.65332930428641, 53.82608945029122, 53.51062386376517, 50.97602871486119, 55.73073659624372, 53.326976026807515, 56.02266863414219, 52.05492067337036, 54.44503150667463, 53.99901621682303, 54.996892179761616, 57.01663623537336, 59.91287817273821, 30.106252670288086, 9.469249963760376, 7.595662134034293, 18.37417071206229, 6.034399739333561, 0.30176642590335434, 0.1977081817707845, 12.296467627797808, 55.0038230078561, 48.30976520265852, 54.22012874058315, 34.16292020252773, 37.001012665884836, 56.962537561144146, 60.741047859191895, 62.90074947902134, 24.467388255255564, 0.12116244275655065, 0.10760849541319267, 0.1996053656829255, 0.07150474629764046, 0.1371050708528076, 0.11826405328299318, 0.17944661953619548, 0.13800826881613049, 0.15957279024379595, 0.09278643397348267, 0.08269048428961209, 0.13233038277498313, 0.20124001082565102, 0.10107951611280441], [0.01866966881789267, 0.030796807991074662, 0.04565556799726827, 0.023753823147022297, 0.12578824668058328, 0.013474095646025879, 0.03366773036707725, 0.050631624912577014, 0.03707198805308767, 0.04160288189138685, 0.009019361426388579, 0.01920558595364647, 0.12417087703943253, 0.1693931325737919, 15.653669561658587, 34.2103590284075, 35.34506239209856, 25.36185417856489, 16.739426340375626, 30.107965401240758, 47.892407757895334, 44.77750253677368, 32.110144410814556, 30.14546135493687, 0.23061996645161084, 0.10155472811311483, 0.40821350685187746, 1.5536550943340575, 3.496134204523904, 8.584713016237531, 27.72385433741978, 48.37324741908482, 51.8527524130685, 50.896610804966514, 48.91544662203108, 43.170936584472656, 38.84433501107352, 38.37556784493582, 40.15944487707955, 46.48254530770438, 48.16901901790074, 47.333373069763184, 47.33201469693865, 45.85312189374651, 46.99604845046997, 46.56104605538504, 47.20858342306954, 45.95345388139997, 45.71590191977364, 44.864758014678955, 45.22989627293178, 43.69710281917027, 42.4717949458531, 43.77125399453299, 41.39729772295271, 42.07606029510498, 44.22013889040266, 43.38604586465018, 41.741004262651714, 36.48622063228062, 33.07408537183489, 34.93251657485962, 33.19260426930019, 34.42720535823277, 33.33982617514474, 33.08298601422991, 34.00179842540196, 31.47780622754778, 33.618400301252095, 33.7788758959089, 34.527756214141846, 34.28060531616211, 34.50128010341099, 41.640839031764436, 48.00616019112723, 44.99693359647478, 46.05376155035836, 46.9234745161874, 44.908698422568186, 39.60826512745449, 39.36661720275879, 40.82834448133196, 45.80229582105364, 47.837603841509136, 49.77342408043997, 45.9255360194615, 49.30945117133004, 42.155238492148264, 29.53870643888201, 45.503255775996614, 42.00926726205008, 44.348454747881206, 40.25365897587368, 39.9046995980399, 39.99972316196987, 44.399305139269146, 46.47356823512486, 47.22803837912423, 45.58263199669974, 45.58953850609915, 46.275016512189595, 44.72871576036726, 40.96535948344639, 37.766982078552246, 34.00149270466396, 33.74314478465489, 34.55254391261509, 34.38335875102452, 37.90660612923758, 35.74879094532558, 34.96605552945818, 34.95176655905587, 37.03748723438808, 37.431133951459614, 35.52339833123343, 33.827395166669575, 38.48668691090175, 41.04834181921822, 43.26319476536342, 43.32845572062901, 45.405921936035156, 45.52964503424508, 45.227179527282715, 43.34532247270857, 42.241882528577534, 46.710317679813926, 45.30916827065604, 46.05794089181082, 42.27650192805699, 39.86684233801705, 40.1819292477199, 38.498075008392334, 40.42481047766549, 45.398459570748464, 51.34787893295288, 48.63219288417271, 48.100117206573486, 47.17292179380144, 47.360318183898926, 45.31193017959595, 41.22684104101998, 44.99404314586094, 49.42820283344814, 53.09289469037737, 53.29389565331595, 34.69238683155605, 11.705889855112348, 1.0484484263828822, 9.053457600729805, 2.9071360613618578, 0.009484073097285415, 0.009807812332707857, 4.714203791958945, 37.38900007520403, 35.77530527114868, 30.26308740888323, 27.34062818118504, 28.082369225365774, 41.29004880360195, 44.469725131988525, 53.10153477532523, 19.104075499943324, 0.02840054121666721, 0.024830571708402464, 0.026888634577127438, 0.08141312854630606, 0.06339653102414948, 0.02091428471196975, 0.022909941018692086, 0.020091416813167076, 0.04931594890409282, 0.0016093585810657324, 0.07938043440559081, 0.02918177590306316, 0.04368437287796821, 0.10637341240154845, 0.015632525718371783, 0.025292496296710203, 0.021495836720402752, 0.021004920027085712, 0.045420367403754165, 0.028760375122406652, 0.028178270107933452, 0.013025199778244963, 0.05403435928747058, 0.07021690718829632, 0.03969713147463543, 0.022386990687144653, 0.10405273442821843, 0.17753255367279053, 21.039409364972794, 45.379629952566965, 43.444584437779014, 31.79167025429862, 18.80522131919861, 27.915666307721818, 50.99780089514596, 48.28793396268572, 35.3763918195452, 32.63500091007778, 0.30929957596319063, 0.030134486566696848, 1.9014138451644351, 4.58440796818052, 3.417211788041251, 8.571107574871608, 27.220334018979752, 50.3267890385219, 53.13198525565011, 51.56632334845406, 50.54224572862898, 44.77782562800816, 39.489040987832205, 40.482914788382395, 40.98703438895089, 47.591057436806814, 49.35365561076573, 48.57209096636091, 48.286436625889365, 47.29243080956595, 48.00127213341849, 47.106566497257774, 47.57235983439854, 47.85847623007638, 48.283813680921284, 47.590654441288535, 45.81261389596121, 43.902244908469065, 42.068267890385215, 43.59668745313372, 43.33237450463431, 43.9210467338562, 44.79881961005074, 45.5851993560791, 43.960984979357036, 39.366005761282786, 35.12276520047869, 35.6638422693525, 34.013262953077046, 35.5983624458313, 34.29763535090855, 33.92405503136771, 36.23739174434117, 34.024657998766216, 35.487198216574534, 34.93961763381958, 36.68934426988874, 36.8892821584429, 36.844129289899556, 42.56177759170532, 47.90729079927717, 46.14194808687483, 48.46304246357509, 47.35782378060477, 44.45146526609148, 43.19176728384835, 40.89006185531616, 43.43226875577654, 47.12191506794521, 48.71238204411098, 52.46760198048183, 48.02672685895647, 49.584933349064414, 42.42540529796055, 30.966060979025706, 47.24383858272007, 43.53662722451346, 45.71950456074306, 41.77434171949114, 41.99635056086949, 41.05863210133144, 44.619128772190635, 46.22973510197231, 49.220309257507324, 46.92751489366804, 48.44517517089844, 47.64314113344465, 47.17417941774641, 41.91676936830793, 38.97171980994088, 35.81917272295271, 35.820148944854736, 36.442415714263916, 35.545372009277344, 40.22352116448538, 37.96303939819336, 35.63460424968174, 37.268994263240266, 38.04245730808803, 39.58262627465384, 35.88848100389753, 36.44143254416329, 39.15940107618059, 43.12806967326573, 45.29400382723127, 46.2450385093689, 48.113819054194856, 47.56112807137625, 46.80871112006051, 45.15160397120884, 44.1549300466265, 48.8988994870867, 47.00067595073155, 47.52052974700928, 43.96282277788435, 42.06899050303868, 43.00375945227486, 41.0279175894601, 41.59990719386509, 47.11128085000174, 54.210623604910715, 50.904611655644004, 50.84655250821795, 49.68225676672799, 48.9214220728193, 46.83602796282087, 44.54817724227905, 46.585093770708355, 51.57149280820574, 54.02302919115339, 55.672486373356406, 35.9615968976702, 11.197453686169215, 2.26608527132443, 9.036067128181458, 3.865033175264086, 0.19214975860502037, 0.05271799456594246, 5.3057065435818265, 40.492173263004844, 40.04132897513253, 29.598245552607946, 22.80626504761832, 33.286599499838694, 47.97994811194283, 49.11529070990426, 59.9562349319458, 25.157255785805837, 0.04148121038451791, 0.02374786221688347, 0.06001646311155387, 0.04754968493112496, 0.03078412277890103, 0.048091773342873366, 0.02571979015400367, 0.04216295826647963, 0.012548866498816227, 0.02497934390391622, 0.022349869732611945, 0.036996097303926945, 0.019545163892741715, 0.06698769118104662, 0.10318225542349474, 0.1304614394903183, 0.11680869066289493, 0.09842024237981864, 0.1966481607939516, 0.11437821893819741, 0.08813267440668174, 0.13085714754249367, 0.149379932188562, 0.14316289579229696, 0.14906216066862854, 0.09810346830636263, 0.3279864846595696, 0.3318990261426994, 27.02354540143694, 54.80041102000645, 51.59925086157662, 37.7029196875436, 24.831793478557042, 40.728130613054546, 55.860855511256624, 51.28979546683175, 42.340873513902935, 35.7927383014134, 0.7445717294301305, 0.1872021255216428, 0.9996900941644395, 5.739720123154776, 10.363961679594857, 14.638746193477086, 32.72040121895926, 53.12594379697527, 54.89271436418806, 55.11806876318795, 51.887972831726074, 47.167939935411724, 41.215518951416016, 42.98910222734724, 44.166015897478374, 50.00186000551496, 51.004651818956646, 49.56371702466692, 48.931531701769146, 49.22599288395473, 50.84447152273995, 50.26542602266584, 49.14756509235927, 49.15139354978289, 48.45479495184762, 47.53004877907889, 46.27535349982125, 45.183239119393484, 43.88275868552071, 44.943039894104004, 44.55779354912894, 46.301169531685964, 47.38090917042324, 46.64220448902675, 46.04496513094221, 40.58081143242972, 35.99082449504307, 39.14999321528843, 35.70007017680577, 37.98723302568708, 36.701454980032786, 36.38057327270508, 38.836452279772075, 34.69637509754726, 37.03461068017142, 36.61608941214425, 37.62770891189575, 38.023662430899485, 38.41382810047695, 45.564820289611816, 50.74297571182251, 49.190039430345806, 49.41459478650774, 47.94736106055123, 47.717799527304514, 43.110264914376394, 44.05997943878174, 45.608208315713064, 49.467592171260286, 50.95423221588135, 53.72674410683768, 50.932922090802876, 51.46624149594988, 45.2044415473938, 33.61050019945417, 46.98659542628697, 45.796306473868235, 47.78093433380127, 43.31784234728132, 42.07803358350481, 40.66475261960711, 45.59671599524361, 49.720930440085276, 52.60567658288138, 48.431942326681956, 49.38130596705845, 49.193134852818076, 47.819611481257844, 45.10332441329956, 40.948058468954905, 36.83491597856794, 37.53335237503052, 37.79123476573399, 37.495286669049946, 41.75880207334246, 41.14119407108852, 37.06945589610508, 40.16672658920288, 41.76616716384888, 40.392754963466096, 38.22726896830967, 37.731205804007395, 42.55850846426827, 44.82439940316336, 46.47844239643642, 48.432060446058, 48.8154342515128, 50.03482920782906, 49.81918144226074, 46.89988885607038, 45.72657087871006, 51.464302948543, 50.438964230673655, 51.64153412410191, 46.61825404848371, 44.37901292528425, 44.86439323425293, 42.71302945273263, 43.35312877382551, 48.758417333875386, 57.44378021785191, 53.36607354027884, 52.06223365238735, 51.60698768070766, 51.81580536706107, 49.255477564675466, 45.11311442511422, 49.03623063223702, 55.43957233428955, 57.200704438345774, 57.75094270706177, 40.35424109867641, 17.180737699781144, 3.1524752165590013, 17.304908956800187, 7.168214167867388, 0.5150655646409307, 0.13593629428318568, 6.028645328113011, 46.972118854522705, 46.17402444566999, 41.82481690815517, 38.94002907616751, 39.39248882021223, 55.68091106414795, 56.47239078794207, 66.69075557163784, 32.01982477733067, 0.2413961882037776, 0.13243049383163452, 0.10526611110461609, 0.20522457201566013, 0.1553914810397795, 0.18228411727717944, 0.09531476401856967, 0.1231974507016795, 0.18501395865210465, 0.11491276882588863, 0.1946061910795314, 0.13916365110448428, 0.10387290907757622, 0.17677571571299008], [0.05941380187869072, 0.03799575919817601, 0.0674213564821652, 0.03089726510058556, 0.027370504702308347, 0.07600058362420116, 0.03169430286756583, 0.05588626116514206, 0.04356637563822525, 0.03602720358009849, 0.06539824325591326, 0.02974708378314972, 0.04492857200758798, 0.06929569412022829, 19.35224778311593, 31.780987398965017, 39.57884298052107, 34.74609988076346, 18.146884713854107, 24.074754238128662, 52.350260802677695, 37.70069626399449, 33.719277722494944, 25.964007650102886, 0.037928801362535784, 0.17508652992546558, 1.6797594704798289, 1.5460535479443414, 3.710928644452776, 12.34975596836635, 31.364213602883474, 51.33458008084978, 51.27152517863682, 49.362966196877615, 45.512656688690186, 40.60943453652518, 37.70469842638288, 36.53023747035435, 39.580788476126536, 45.755847113473074, 47.0784957749503, 48.76637996946062, 45.69606133869716, 48.28201757158552, 47.39528151920864, 46.82940632956368, 43.41574246542794, 45.94396264212472, 42.88273572921753, 44.03694616045271, 43.106304441179546, 43.085852418627056, 42.09678677150181, 42.96846955163138, 43.05782685961042, 42.56783642087664, 42.93038647515433, 44.1382508959089, 41.9859664780753, 37.131909779139924, 32.5737247467041, 33.46320881162371, 35.29277719770159, 36.24686213902065, 32.42751727785383, 33.65339142935616, 32.747252532414024, 33.40039709636143, 33.7089388029916, 34.34479624884469, 32.1536158152989, 33.316184929439, 32.74410499845232, 39.26027154922485, 48.12571784428188, 44.4975700378418, 44.60439164297921, 46.96459395544869, 44.69017062868391, 41.322545528411865, 38.05225774220058, 38.19014126913888, 44.347374303000315, 46.58074419839041, 46.93736049107143, 46.892739159720286, 46.78194318498884, 46.437284742082866, 31.91838107790266, 42.215177127293174, 44.38103485107422, 44.5576684815543, 40.987169878823416, 42.875613825661794, 45.134292534419465, 47.69821602957589, 46.838157585689, 46.57010303224836, 45.29766205378941, 46.141809122903005, 46.356814180101665, 44.23385463442121, 38.12076350620815, 37.27810682569231, 32.79921810967581, 33.90746968133109, 32.86216531481062, 34.07133599690029, 34.108130182538716, 36.332557746342246, 34.6457644190107, 35.810748032161165, 36.37606389181954, 34.85002408708845, 34.48765468597412, 33.51008483341762, 35.65548358644758, 38.563210896083284, 39.56615904399327, 40.7864259992327, 44.7691125869751, 44.94226516996111, 45.563104084559846, 41.894861698150635, 45.375933510916575, 48.229093142918174, 45.189669677189414, 44.74784067698887, 43.98818717684065, 43.36486428124564, 44.801678793770925, 41.88081244059971, 40.369360378810335, 41.95201063156128, 43.74382945469448, 43.867806162152974, 44.260292530059814, 41.538655349186485, 41.60006352833339, 39.171834877559114, 40.84506532124111, 43.00200155803135, 50.54234300340925, 53.4834703036717, 54.35856812340872, 40.52638619286673, 14.537309442247663, 3.64624091557094, 5.042335510253906, 3.915650801999228, 0.24616590940526553, 0.04926377634650894, 2.7164631613663266, 38.80535214287894, 37.94270549501692, 31.174868243081228, 40.767902101789204, 28.60273371423994, 30.72276633126395, 43.12960522515433, 50.10565219606672, 29.268563951764786, 0.27374211539115223, 0.047914892834212096, 0.03286826344473021, 0.0314901452511549, 0.03934413720188396, 0.03764364362827369, 0.05058958627549665, 0.0334509282505938, 0.04077270447409578, 0.05942784755357674, 0.005154608740537826, 0.04035925612385784, 0.03477160506216543, 0.04487040798578944, 0.04836747908432569, 0.0543331046854811, 0.024695102191929306, 0.009775776998139918, 0.02578397617409272, 0.023096064870644892, 0.04344462270715407, 0.023285167491329566, 0.05371904406430466, 0.006689094480991895, 0.0087646826369954, 0.058223895728588104, 0.06867466494441032, 0.2587097691638129, 25.175133500780376, 42.09751285825457, 44.55779354912894, 39.17216839109148, 21.568422624043055, 29.018564292362758, 54.52504696164812, 41.45347738265991, 37.63413946969168, 28.144868271691458, 0.03020102371062551, 0.09867682361177035, 1.2442338977541243, 5.0700284242630005, 5.373220017978123, 14.483155182429723, 31.891199725014822, 52.9345417703901, 52.28793546131679, 51.88447788783482, 47.455501556396484, 41.70615904671805, 39.86387198311942, 38.250132015773225, 40.2863815171378, 46.65518372399466, 49.72928217479161, 49.122072151729036, 46.163959980010986, 47.75520168031965, 47.61797823224749, 48.676289626530235, 45.2633171081543, 47.40044750486101, 44.46033811569214, 45.936288356781006, 43.10367802211216, 44.12601164409092, 43.61380781446184, 43.635263851710725, 44.541559083121165, 44.597502504076274, 44.994182109832764, 46.36592674255371, 43.08737754821777, 38.14583608082363, 34.5712171963283, 33.73039484024048, 36.01193312236241, 38.00611475535801, 33.86169147491455, 35.13287830352783, 35.06670018604824, 35.550329548971995, 35.03945977347237, 36.49926587513515, 33.257358006068635, 34.16321897506714, 34.11934804916382, 40.39829267774309, 48.82072530473982, 46.00488097327096, 45.02923924582345, 48.54723031180245, 45.82328980309622, 43.30289677211216, 40.714487825121196, 40.90639359610421, 45.65192290714809, 47.66016074589321, 49.36486652919224, 47.664204597473145, 48.553330830165315, 48.16146980013166, 32.751251220703125, 43.35468864440918, 44.8374411719186, 46.15583406175886, 43.1397739137922, 43.56989867346627, 45.97302000863211, 49.10955497196743, 49.06554160799299, 49.54583930969238, 47.539102281842915, 48.645616803850444, 48.409259932381765, 45.869599546704976, 40.99432304927281, 38.19391761507307, 34.881575856889995, 36.17431599753243, 36.10571295874459, 35.95051799501692, 36.135878562927246, 37.24797943660191, 36.75668968473162, 36.07276112692696, 37.95498643602644, 36.222814423697336, 36.5498035975865, 35.985571656908306, 37.868887833186555, 40.3286578314645, 41.56321723120553, 43.11371122087751, 45.573950222560335, 46.62390988213675, 47.12423229217529, 43.82875381197248, 46.683528900146484, 48.71257659367153, 47.387808731624055, 45.98350484030587, 44.45918818882534, 44.97341047014509, 45.841959612710134, 43.750471932547434, 43.7906151499067, 44.494780336107524, 46.07862915311541, 46.356807231903076, 46.5589268548148, 43.909276485443115, 42.63001585006714, 41.108798095158164, 41.37853411265782, 45.25694908414568, 53.291981424604145, 55.08992855889456, 56.480492387499126, 42.07208939961025, 15.647219896316528, 2.7562661341258456, 4.203290590218135, 4.120374262332916, 0.6775538570114544, 0.03798167959653905, 2.9832142761775424, 44.23666518075125, 42.2047061920166, 40.37771558761597, 40.601586546216694, 32.258512769426616, 37.591182231903076, 47.57374947411673, 55.456015246255056, 33.671446323394775, 0.3525969497859478, 0.026130599003019075, 0.03218779120860355, 0.024688832528356994, 0.03161022559340511, 0.011120500242603677, 0.08064588864466973, 0.07128025977207081, 0.017471735598519444, 0.045626954175531864, 0.038928931445947716, 0.07362408936023712, 0.03978896440405931, 0.00868051206426961, 0.21084680461457797, 0.158528633415699, 0.1752452664077282, 0.0949924463140113, 0.1281562660421644, 0.11184026048119579, 0.12879301687436445, 0.11375134079051868, 0.129142448838268, 0.0805542389197009, 0.24288812386138098, 0.12277997524610587, 0.17404839848833425, 0.6373281297939164, 32.83667584827968, 53.11226626804897, 52.96550294331142, 46.323706013815745, 29.048750741141184, 34.707867418016704, 60.89332457951137, 44.86878102166312, 44.73226976394653, 31.77355977467128, 0.1926332148058074, 0.25118063603128704, 2.6721067300864627, 6.420549784387861, 8.182823130062648, 16.851049150739396, 35.70858519417899, 54.722525187901084, 56.1452557018825, 54.767066614968435, 48.59037167685372, 45.24196181978498, 40.93357842309134, 40.97426707404, 43.00906787599836, 49.06227248055594, 51.40322480882917, 50.61623362132481, 47.44014951160976, 50.1381002834865, 49.61100993837629, 48.695782797677175, 45.52603891917637, 47.62531900405884, 45.32260956083025, 45.90313502720424, 44.28648723874773, 45.70101887839181, 44.76476648875645, 45.18471213749477, 46.21546697616577, 46.70144830431257, 47.18128047670637, 49.19902345112392, 45.93284899847848, 40.75375209535871, 36.626456124441965, 36.17225933074951, 38.87309013094221, 40.28364740099226, 35.265144211905344, 37.36236763000488, 36.84867688587734, 37.24642651421683, 36.67151519230434, 38.38331856046404, 34.99267407826015, 36.02582604544503, 35.478787422180176, 41.50327164786202, 50.92162084579468, 48.275461946214946, 46.530814443315776, 49.674221175057546, 49.19193281446184, 45.23290136882237, 42.2682648386274, 43.06831863948277, 47.80023642948696, 48.71857288905552, 50.087930815560476, 49.58281762259347, 50.60782977512905, 52.11277832303728, 36.09599590301514, 43.182064124516074, 47.809244768960134, 48.683415004185264, 44.17226232801165, 44.39178024019514, 47.60415826525007, 50.376923765454976, 50.1696902683803, 52.046252795628135, 48.71214233125959, 49.8869229044233, 50.159730025700156, 48.356703758239746, 42.580197266169954, 41.016324520111084, 37.32546574728829, 38.75616584505354, 37.84313780920846, 37.34495891843523, 36.76335300718035, 39.96943596431187, 37.75907155445644, 38.06462900979178, 39.16403552464077, 37.8010629926409, 38.96153027670724, 37.18061317716326, 38.93259102957589, 42.220384802137104, 42.827883175441194, 46.82111365454537, 48.848250593457905, 48.92605652127947, 49.020857742854524, 46.14266375132969, 49.49714980806623, 51.81143147604806, 49.279428005218506, 49.5841829436166, 46.235175541469026, 46.64120394842965, 48.77722610746111, 45.164753437042236, 45.25495842524937, 45.10688883917672, 48.3902461869376, 48.1628212247576, 48.07054219927107, 45.85847895486014, 44.127119881766184, 42.99423694610596, 44.08010837009975, 47.65383441107613, 56.23790298189436, 56.85514620372227, 58.42291341509138, 43.978716782161165, 18.017385925565446, 8.399665117263794, 12.676648736000061, 9.371673805373055, 1.1180357209273746, 0.11899305773632866, 3.4375904202461243, 50.17040245873587, 49.35788358960833, 41.879356792994905, 52.01981142589024, 38.28079094205584, 41.88279267719814, 55.24877480098179, 64.0698047365461, 42.33536359242031, 0.9787018660988126, 0.09649234118738345, 0.10879967720913035, 0.10111651662737131, 0.15107892959245614, 0.1848565520984786, 0.208982041105628, 0.20604268168764456, 0.11496869368212563, 0.1617309930069106, 0.04259254217946103, 0.16083031919385704, 0.0733715725530471, 0.11751585985933032], [0.02975282758208258, 0.023193131001400094, 0.017432596002306257, 0.05524021440318652, 0.030164169081087624, 0.07970545946487359, 0.005674160883894989, 0.022707776598898426, 0.018473175254517367, 0.0059670212628719, 0.0101743230230308, 0.06256693375429936, 0.0353814893003021, 0.4383230097591877, 19.72432902881077, 32.03280053819929, 39.99021455219814, 28.351247140339442, 20.942542791366577, 33.143907819475444, 54.48626559121268, 30.63501058306013, 38.949697494506836, 21.241231952394756, 0.18828409032097884, 0.5415430867246219, 2.010710963181087, 5.575994942869459, 1.6719818306820733, 6.366341241768428, 37.886810711451936, 52.488192967006135, 46.828603812626426, 45.75618757520403, 41.10158239092146, 39.66428845269339, 37.655519076756065, 37.349589892796104, 39.64576802934919, 43.5973926952907, 47.40582193647112, 49.21511547906058, 44.11653777531215, 43.42024489811489, 46.18140343257359, 43.2086409841265, 44.772927148001536, 45.379028933388845, 41.49642072405134, 45.387519632067, 39.83271278653826, 41.11535372052874, 43.65294006892613, 43.8500257219587, 42.62454066957746, 41.872446809496196, 43.48739576339722, 44.43916348048619, 39.12968710490635, 35.01156275612967, 32.136127199445454, 33.99906778335571, 33.881511211395264, 34.535103934151785, 31.78689684186663, 33.89207247325352, 33.91742297581264, 32.27643912179129, 32.572571345738, 33.35547004427229, 33.44559512819563, 33.339284215654644, 33.97030918938773, 39.37397187096732, 45.466829844883506, 43.55740581239973, 46.295819418770925, 45.81565373284476, 43.1334684235709, 41.5868376323155, 38.26670346941267, 39.44481222970145, 40.31404229572841, 41.13712590081351, 44.56176444462368, 44.893356800079346, 46.51574032647269, 47.2941609110151, 31.804753712245397, 43.43177890777588, 45.223396233149934, 44.02683653150286, 44.9963047845023, 45.68158476693289, 46.40147025244576, 47.29446315765381, 45.26753119059971, 44.26974555424282, 42.46090017046247, 41.10261419841221, 39.54808677945818, 37.843919481549946, 34.32147114617484, 33.00436019897461, 34.29345600945609, 35.07507971354893, 34.1963723046439, 35.008797373090474, 35.52318293707711, 36.019374643053325, 34.9370676449367, 34.885529381888254, 35.00025456292288, 35.121115003313335, 34.580663272312705, 34.74177810123989, 34.19451366152082, 36.720739705221995, 38.40049450738089, 40.22508103506905, 43.12906673976353, 45.54713017599923, 44.62324905395508, 45.18925278527396, 45.53605127334595, 46.63608660016741, 45.59469059535435, 45.94223254067557, 47.3647962978908, 48.66099664143154, 45.65833609444754, 43.36295005253383, 40.43535784312657, 38.1048139163426, 39.06601728711809, 38.11960315704346, 37.311954975128174, 40.07960660117013, 44.104128292628694, 44.15461390359061, 43.11790793282645, 42.14903027670724, 47.209900106702534, 50.994712420872276, 53.09604222433907, 46.80363198689052, 20.69770564351763, 4.6680165103503635, 4.319497040339878, 2.6815128539289748, 0.2970109267958573, 0.010175138961390724, 0.8687619854296956, 30.53715910230364, 43.32493298394339, 25.812026228223527, 26.030185767582484, 17.257534401757376, 25.103125844682964, 45.191507475716726, 51.01384775979178, 30.103640147617885, 0.7414076934967722, 0.08523554700825896, 0.019774028665519187, 0.015898353686290126, 0.04903446543695671, 0.008323529701946037, 0.0502706205339304, 0.06429479603788682, 0.05051276254068528, 0.010211662805107023, 0.006267104223037937, 0.06092610037220376, 0.056613528568829806, 0.04771590565464326, 0.00844639288594148, 0.05320716742426157, 0.029807415724332844, 0.029568849597126245, 0.01171684092176812, 0.07909667106079203, 0.022962693723716905, 0.04942341188767126, 0.0927111165864127, 0.028575732173132043, 0.011571480061060615, 0.014648441291813339, 0.06842934739376817, 0.8096953492079462, 26.361302171434673, 40.601121016911094, 46.34232718603951, 36.15282869338989, 26.39228766305106, 34.60364096505301, 58.38380895342146, 34.41738060542515, 42.28972087587629, 23.241032941000803, 0.16040951891669206, 0.6832404147301401, 5.511439664023263, 7.618507811001368, 6.159704855510166, 9.177011336599078, 38.14086811883109, 55.084623609270366, 49.69364139011928, 48.22085952758789, 43.0140323638916, 42.81147500446865, 39.0661631992885, 39.874811921800884, 39.97347981589181, 47.182760443006245, 48.29619537081037, 50.33841337476458, 44.87189728873116, 43.76404871259417, 46.541285378592356, 44.30290583201817, 44.93143292835781, 43.8484901700701, 42.79095697402954, 45.08442531313215, 41.385923521859304, 43.17624848229544, 44.93641826084682, 45.9970121383667, 44.69728210994175, 44.309051513671875, 44.51880720683506, 45.937504291534424, 40.81576476778303, 36.018440110342844, 34.1308125768389, 36.3835505758013, 35.12950495311192, 36.19508763722011, 33.50306020464216, 34.621386664254324, 34.85412005015782, 33.49399280548096, 34.54293802806309, 34.64887721197945, 33.658171789986746, 34.86570964540754, 34.213527406964985, 41.67728233337402, 48.29459728513445, 44.368562834603445, 47.06516565595354, 47.91019862038748, 44.233872004917686, 42.31571408680507, 40.189634799957275, 40.26654788425991, 42.48795992987496, 42.06900092533657, 46.493023191179546, 45.9494378226144, 47.81453929628645, 48.23373106547764, 34.910414355141775, 44.42211954934256, 47.246419838496614, 44.977707930973594, 46.12605060849871, 47.170222418648855, 47.996363231113975, 49.39074509484427, 47.0641963822501, 45.75124045780727, 45.01368917737688, 41.8437750680106, 40.42319849559239, 39.37603548594883, 35.94693272454398, 35.540028844560894, 35.384389196123394, 36.345342431749614, 36.695656708308626, 36.5450301851545, 37.30317940030779, 37.299830368586946, 36.24887711661202, 36.585850851876394, 37.217278821127756, 35.99735232761928, 35.40837785175869, 36.61788552148001, 36.837021282741, 39.02829204286848, 39.93454211098807, 42.172063555036274, 44.75875629697527, 47.068382671901155, 47.34063393729073, 47.70770379475185, 47.76951149531773, 49.25535944529942, 45.94187470844814, 48.91774647576468, 48.64358445576259, 49.292546204158235, 48.256020886557444, 45.4850514956883, 42.74051652635847, 39.085277693612234, 41.612240246364046, 39.74995626722063, 39.85209478650774, 42.389503955841064, 42.944362776620046, 45.08410917009626, 43.95966134752546, 44.82240874426705, 49.11382464000157, 53.538284642355784, 54.21353142602103, 48.04729005268642, 20.717815467289515, 5.479570014136178, 4.150311878749302, 2.762841518436159, 0.22806943474071367, 0.012203297943675091, 0.9829600261790412, 36.24939475740705, 42.87052427019392, 34.09155872889927, 35.163776942661826, 19.9381320476532, 31.394705772399902, 50.53147602081299, 55.53842782974243, 36.31559371948242, 1.3080799175160271, 0.010664489935152233, 0.01216357820002096, 0.027506425444568907, 0.052589731091367345, 0.02626620083382087, 0.03728171304932662, 0.037386902940592597, 0.040367374795355966, 0.015862345529188002, 0.017919034364500215, 0.04896748045991574, 0.019594529011685933, 0.04867034318989941, 0.11007254783596311, 0.13947040321571486, 0.12048314777868134, 0.1852016957210643, 0.10462808462658099, 0.15642875752278737, 0.08064318807529551, 0.15523881066058362, 0.18038131509508404, 0.16780010876911028, 0.09535044817520039, 0.19405344288264, 0.14080516302159854, 1.2624360067503793, 33.67072023664202, 50.08984851837158, 54.844587666647776, 40.76363590785435, 32.749535015651155, 42.980316230228965, 58.71078423091343, 39.00526918683733, 49.63439410073416, 25.12269718306405, 0.2486414494259017, 0.9142821856907436, 6.860334711415427, 11.52134222643716, 3.625446694237845, 9.817374689238411, 41.98894030707223, 56.07094471795218, 50.50394030979702, 50.342613560812815, 44.75451442173549, 43.89275714329311, 41.797611236572266, 41.49119915281023, 42.81008536475045, 47.19154296602522, 51.227546555655344, 51.97004842758179, 45.52151216779436, 45.13523054122925, 47.80301570892334, 43.780741759708945, 44.83262954439436, 45.132371357509065, 43.06601531164986, 46.47711181640625, 42.14057779312134, 42.7514078276498, 46.420546531677246, 47.665232930864605, 47.151708943503245, 46.386319705418174, 46.53203732626778, 48.58210679462978, 43.70361328125, 38.55916009630476, 37.24775014604841, 38.494653020586284, 37.90886776787894, 37.14752932957241, 34.396212918417795, 36.650757449013845, 36.557578631809776, 35.19125359398978, 36.535813399723594, 37.73419352940151, 35.63262401308332, 36.17705706187657, 39.303002970559255, 42.28130660738264, 50.20939922332764, 47.018362590244834, 48.88885586602347, 48.50390134538923, 47.816338879721506, 44.866369996752056, 42.351243700299946, 42.803856304713655, 46.093505246298655, 44.24059091295515, 48.543624196733745, 48.19129841668265, 49.648408617292134, 50.20666510718209, 36.80707802091326, 46.66266345977783, 48.91952868870327, 46.06356545857021, 47.74815273284912, 49.67364794867379, 49.87559386662075, 50.68290158680507, 49.1398595401219, 48.7601717540196, 45.99200596128191, 44.229807308741975, 42.512532234191895, 41.80368743624006, 37.33167396272932, 37.11904171534947, 37.758866582598, 38.46199301310948, 38.887208870479036, 39.227493422372, 39.46945401600429, 39.58702795846121, 38.05072913851057, 37.939022949763704, 40.8476048878261, 37.93566696984427, 37.89468649455479, 38.1084999356951, 37.68529210771833, 42.02236809049334, 42.63929864338466, 43.52109800066267, 46.990201541355674, 49.55629287447248, 49.590748991285054, 50.69132627759661, 47.96608298165457, 51.67604235240391, 49.14003324508667, 50.220846380506245, 51.52757324491228, 52.297506604875835, 50.94639812197004, 47.12912034988403, 44.2806715965271, 41.65763977595738, 44.18790967123849, 41.6095860345023, 42.02892024176461, 43.949433599199565, 47.03145299639021, 47.9056510244097, 47.348860604422434, 46.94054971422468, 53.24462945120675, 56.06018195833479, 57.9679662159511, 49.140467507498606, 25.242678676332744, 8.793277093342372, 8.94055197920118, 8.06547326701028, 0.8007030231612069, 0.07728376798331738, 1.553023568221501, 40.7506115095956, 52.67110776901245, 37.85559245518276, 36.1212352343968, 26.470077957425797, 34.78067411695208, 58.28043712888445, 62.534377915518625, 45.025414262499126, 2.0295779279300143, 0.18209978645401342, 0.1457584143749305, 0.10138880594500474, 0.09607021776693207, 0.12185184790619782, 0.17151480301150254, 0.16016582985009464, 0.2288155789886202, 0.1331104537738221, 0.061708722662712844, 0.0747763164607542, 0.13236565302525247, 0.11097839887120894], [0.016985061445406506, 0.07436775016997542, 0.023238177244950618, 0.00679490650405309, 0.008325259118074817, 0.07969415507146291, 0.08971912999238287, 0.11636096611618996, 0.017569821228140166, 0.02792423338230167, 0.011639201248596822, 0.12554546685091086, 0.04831088247842022, 2.421770300183977, 28.762106282370432, 36.64114809036255, 42.444481577192036, 25.32005728994097, 23.482427256447927, 35.646020139966694, 37.929608140672954, 26.215674877166748, 44.01176241465977, 13.170216628483363, 0.1293947281582015, 0.41297945539866177, 2.2952121198177338, 5.477694000516619, 5.871061052594866, 9.492082612855093, 44.88369532993862, 47.64544446127755, 49.106386593409944, 44.55345092500959, 44.66764456885201, 42.29810387747628, 41.50435904094151, 38.16790355954851, 40.547612939562114, 43.626140866960796, 49.41444887433733, 48.87896163122994, 44.39401756014143, 42.51662124906267, 40.86540617261614, 39.864935057503835, 40.82728140694754, 41.28863484518868, 44.62523971285139, 41.910272802625386, 41.14673178536551, 40.68357876368931, 40.672948019845144, 42.93035173416138, 43.83736610412598, 44.1998918397086, 40.68602452959333, 40.469775744846885, 37.58748926435198, 32.080499921526226, 32.217855385371614, 34.016810008457725, 33.76102597372872, 33.04916565758841, 33.70682307652065, 35.09479522705078, 32.74291685649327, 33.41840335300991, 33.88992200578962, 32.99442080089024, 33.59547472000122, 32.11147151674543, 34.419701303754536, 42.678246770586284, 46.48388978413173, 43.32129907608032, 44.8000876562936, 45.948308740343364, 44.16181571143014, 42.49143402917044, 42.149655614580425, 43.473801612854004, 42.72076627186367, 44.27670417513166, 43.991237436022075, 45.07281139918736, 46.19610234669277, 48.63853311538696, 32.34932919910976, 42.216455595833914, 43.51625163214547, 45.61780377796718, 46.43357787813459, 45.57783079147339, 46.21348326546805, 46.03264944893973, 40.700414248875205, 38.86450910568237, 37.62671879359654, 35.78370564324515, 34.61828429358346, 35.225619384220664, 34.20518609455654, 34.06846639088222, 34.44366216659546, 33.6249281338283, 34.18400798525129, 35.20526811054775, 33.01282657895769, 35.41113976069859, 34.64852632795061, 34.742521558489116, 34.836256231580464, 35.09005308151245, 34.064564977373394, 32.61471911839077, 33.58725847516741, 35.50975554330008, 39.079541955675396, 37.71945292609078, 41.4297388621739, 44.31061485835484, 45.073596545628135, 44.078687463487896, 45.46639558247158, 46.559180464063374, 46.48695393971035, 48.32331418991089, 48.280940600803916, 47.19360658100673, 48.65296452386038, 45.7822641645159, 41.333950996398926, 39.30970450810024, 35.61477061680385, 36.21552923747471, 37.833320004599436, 45.27840164729527, 48.51930202756609, 49.25987924848284, 48.700226170676096, 48.03740971429007, 46.14174311501639, 51.3418687411717, 50.58260781424386, 55.91542666299002, 30.1747236933027, 6.54878009217126, 1.7640273315565926, 2.775835518326078, 0.8958470406276839, 0.0077377953732918415, 0.35722415149211884, 27.648723466055735, 45.57260227203369, 33.67370448793684, 33.30846548080444, 30.921140875135148, 38.42645297731672, 42.926679611206055, 48.70366900307791, 33.73173236846924, 1.8189451332603181, 0.09256557082491261, 0.038206328970513175, 0.010526843169437987, 0.027190467309472815, 0.03587769856676459, 0.03338807894449149, 0.0493006479394223, 0.05327588266560009, 0.03385078215173312, 0.05350799931745444, 0.013115840182373566, 0.05638234490262611, 0.04255155187898448, 0.024418904512588466, 0.04015603827844773, 0.034574490639248064, 0.03198143853140729, 0.03893598481746657, 0.03504483075812459, 0.06068518651383264, 0.029784813722861663, 0.015670713669221317, 0.03529121021607092, 0.04828154601688896, 0.052604472264647484, 0.016832614982766763, 2.847996251923697, 33.51812389918736, 44.299928528921946, 49.61388301849365, 30.876074859074183, 26.974213191441127, 37.611120087759836, 45.126145771571565, 30.661319937024796, 48.19374418258667, 15.050119502203804, 0.23010305847440446, 0.9245764847312654, 4.987202422959464, 10.912333488464355, 8.589092986924307, 10.805559652192251, 43.94146401541573, 51.5341670853751, 49.066917351314, 46.72466570990426, 45.28915745871407, 44.56162895475115, 42.094156878335134, 41.05678735460554, 42.34688717978341, 45.98812539236886, 50.4769743510655, 49.52132259096418, 45.03870964050293, 44.35598659515381, 42.82371425628662, 40.31542498724801, 41.449860845293315, 41.45349127905709, 43.871707575661794, 42.11524813515799, 41.560910429273335, 41.96773787907192, 42.69429363523211, 44.1393278666905, 45.225293091365266, 45.08611372538975, 42.66612216404506, 41.35346848624093, 38.646419048309326, 34.48793608801705, 33.45841802869524, 34.17289434160505, 34.63536296572004, 33.95466532026018, 35.20770345415388, 36.29074001312256, 33.2389418057033, 34.6755930355617, 35.716259479522705, 34.64308588845389, 34.97517156600952, 34.1264317376273, 35.511013167245046, 43.98815243584769, 48.013111863817485, 45.359598296029226, 47.04180581229073, 46.86947659083775, 45.25879035677229, 42.72376094545637, 43.51550122669765, 44.99562038694109, 44.15675742285592, 45.45517771584647, 46.117969853537424, 46.17844349997384, 47.02273300715855, 48.518346650259836, 35.09937408992222, 43.348980699266704, 45.54596635273525, 47.461021900177, 48.089163371494834, 48.650338104793, 46.65577779497419, 48.15873915808541, 41.661256313323975, 40.14601400920323, 37.58018323353359, 37.48085526057652, 36.58380460739136, 37.02131877626692, 36.26239831107003, 34.5164132799421, 35.30341836384365, 34.53774077551705, 36.23198257173811, 37.20999363490513, 35.1297481400626, 35.361175264631, 38.32699646268572, 36.03798539297921, 35.73756960460118, 35.26158673422677, 35.64276838302612, 34.33508614131382, 35.53938266209194, 37.80242483956473, 40.335696356637136, 40.11208248138428, 43.33574785505022, 45.201033455984934, 46.55207245690482, 45.91844538279942, 46.83072648729597, 49.49817814145769, 48.07873412540981, 49.52982718603951, 49.544109208243235, 49.85348817280361, 49.460199287959504, 47.37938404083252, 44.14090510777065, 40.772077969142366, 37.401694434029714, 37.58774634769985, 39.55817903791155, 45.9064701625279, 50.771320887974326, 51.80564015252249, 50.96507487978254, 49.74731275013515, 47.956529208592, 53.14060797010149, 53.48372738701956, 55.43568134307861, 31.50230210168021, 6.782469723905836, 2.9562064111232758, 4.825106160981314, 1.5487400037901742, 0.05692551897040435, 0.26913437406931606, 30.932702677590505, 48.940355913979666, 35.95563881737845, 37.99120739528111, 32.09648772648403, 42.18345512662615, 49.363678387233186, 54.02443272726876, 39.81040212086269, 2.6615465538842336, 0.0714688314391034, 0.0273790389765054, 0.01843318748953087, 0.009315821009555032, 0.018800999270752072, 0.016534865334896103, 0.04620731874768223, 0.10308002733758517, 0.05319185967424086, 0.05241198205788221, 0.046321807961378775, 0.052211576740124395, 0.009533361881040037, 0.10051669845623629, 0.17268157111746923, 0.15450266801885196, 0.09927801242364304, 0.08053854440471955, 0.0861848107139979, 0.15403812937438488, 0.23399160695927484, 0.11743785547358648, 0.28908949185694965, 0.13738226597862585, 0.15996722265013627, 0.07431757929069654, 4.116572294916425, 40.40521655763899, 52.503972326006206, 57.205481324877056, 36.11911603382656, 33.68500920704433, 42.52063383374895, 44.607355049678254, 36.20796264920916, 54.66206891196114, 17.200811045510427, 0.20736914979560034, 0.7830030843615532, 4.03781750372478, 14.363125920295715, 9.207738876342773, 11.752532243728638, 50.102935450417654, 51.131849016462056, 53.23248747416905, 47.585040296827046, 47.56142336981637, 46.082964829036165, 45.67152030127389, 41.429554734911235, 45.31898954936436, 47.490256445748464, 53.25650044849941, 49.79699584415981, 45.942315919058665, 43.02239452089582, 44.95496647698538, 41.927678040095735, 40.37141704559326, 41.37648091997419, 45.086374282836914, 41.56960262571062, 41.8755179132734, 43.28299018314907, 43.83437837873186, 45.91051401410784, 47.56557839257376, 47.05618510927473, 45.11408717291695, 44.30832890101841, 40.665881701878135, 35.516363280160085, 36.15672663279942, 37.37306090763637, 37.106871945517405, 35.60132932662964, 36.49063621248518, 38.370735372815815, 34.751946789877756, 35.8851979800633, 37.42122234616961, 36.353405816214426, 35.84820229666573, 36.94864756720406, 37.78178521565029, 46.91022082737514, 50.044292654309956, 45.57876532418387, 46.85683781760079, 48.540219579424175, 46.77171891076224, 45.66775090353829, 45.53310523714338, 47.75274549211775, 47.689749649592805, 48.3924800327846, 47.71218190874372, 47.92042636871338, 49.813713209969656, 51.597051756722585, 37.159334318978445, 43.35055446624756, 45.921245506831575, 49.62865488869803, 49.9050646509443, 49.07727016721453, 48.45438848223005, 50.56617879867554, 43.139370918273926, 42.1138584954398, 40.61346796580723, 39.18696805409023, 36.93865953172956, 39.85954672949654, 37.09007120132446, 36.5812337739127, 37.922913551330566, 36.941952977861675, 37.629897594451904, 38.38529879706246, 36.54429715020316, 37.68494469778878, 39.247323581150596, 38.75771876743862, 38.471432140895296, 36.692578656332834, 38.08947924205235, 35.341223512377056, 37.629880223955425, 39.9571932383946, 43.64609261921474, 42.06341804776873, 47.30047334943499, 48.242753301348, 49.086973326546804, 47.23970787865775, 47.78088569641113, 49.99941771371024, 49.75491060529436, 51.16449165344238, 51.142087187085835, 51.92660134179251, 52.546290329524446, 50.30086530957903, 46.10358708245413, 42.87341819490705, 39.70717968259539, 40.091369901384624, 42.45756503513881, 48.79446806226458, 51.7446106501988, 54.99933794566563, 53.90849508558001, 52.16294779096331, 50.509366852896555, 55.46515907560076, 54.89651155471802, 60.52269377027239, 32.847730432237896, 9.656626377786909, 6.399862391608102, 9.32699167728424, 3.0571483203342984, 0.19281823773469242, 0.6140865683555603, 36.45083345685686, 55.32133483886719, 45.80977555683681, 42.18555000850132, 41.918631485530305, 49.15308196204049, 56.37932661601475, 61.66529723576137, 47.590518951416016, 4.17914342880249, 0.1816706130547183, 0.26315075371946606, 0.07561248873493501, 0.08669237526399748, 0.08863359609884874, 0.15614799330277102, 0.1647094360419682, 0.2125173578304904, 0.13472603208252362, 0.15895271780235426, 0.09705414782677378, 0.23370320243494852, 0.11478832550346851], [0.08105131331831217, 0.026077720769015805, 0.011636470145146762, 0.012341905684609498, 0.030347780657133887, 0.06476033212883131, 0.025212615761639814, 0.06078267842531204, 0.1268656381538936, 0.027162280964798162, 0.027923926345205734, 0.018494688207283616, 0.004544800413506371, 2.3921575120517184, 28.342839820044382, 41.03945507322039, 37.097540514809744, 23.35979676246643, 19.32664019720895, 22.478749547685894, 31.72730561665126, 26.52186288152422, 45.02585199901036, 10.166131700788226, 0.13298842603606836, 1.8957215334687914, 10.787659355572291, 9.53194877079555, 13.47275596005576, 11.220433984483991, 42.45359761374337, 51.12780516488211, 47.437717642102925, 48.934001786368235, 44.9967668397086, 47.25360427583967, 44.52506405966622, 41.66416066033499, 39.522329807281494, 42.502902030944824, 47.49695103509085, 47.3995338167463, 45.123772961752756, 47.33575977597918, 40.632335799080984, 44.453122411455425, 44.253740378788535, 45.544246673583984, 45.34630986622402, 47.2866290637425, 44.24049711227417, 44.17856781823294, 43.585323674338206, 42.769084044865195, 44.08005278451102, 42.63032157080514, 38.001726967947825, 36.47444690976824, 34.45014830998012, 31.978378772735596, 33.80830846514021, 33.21990374156407, 35.39023610523769, 35.05599301201956, 33.14705535343715, 35.94458075932094, 33.21149294716971, 32.77110569817679, 33.902845655168804, 33.63811928885323, 32.438266141074045, 32.81881897790091, 36.37939207894461, 44.5320018359593, 45.09919718333653, 41.92202915464129, 44.97893081392561, 46.7839720589774, 44.504486969539094, 44.10486132758004, 46.03143351418631, 47.9274787902832, 45.243917737688335, 46.378655842372346, 46.191829204559326, 46.414852482931956, 46.00933476856777, 47.83124623979841, 30.18777241025652, 43.42310060773577, 45.56307281766619, 45.970490864345, 46.63564191545759, 48.18438843318394, 44.35978378568377, 45.82458216803414, 43.28385870797293, 40.37646491186959, 39.298663820539204, 39.83604097366333, 39.84918349129813, 38.747143609183176, 36.01356247493199, 35.25696618216378, 32.97258956091744, 33.21439382008144, 34.36115230832781, 35.38454900469099, 33.96480969020298, 35.007869788578574, 36.10628965922764, 35.29391322817121, 34.51233121326992, 36.61506802695138, 32.81357308796474, 34.074417522975374, 32.35779210499355, 35.24514382226126, 36.0990183694022, 37.75507634026663, 38.991654191698345, 44.441984449114116, 45.256959506443565, 45.937462602342876, 43.97474936076573, 47.95901666368757, 46.07614517211914, 46.03349365506853, 42.39075115748814, 46.73975372314453, 48.15438263756888, 45.54755054201399, 43.48004804338728, 39.68678671973092, 37.66416958400181, 37.07463230405535, 36.33516332081386, 46.721156869615825, 50.09363528660366, 51.359166281563894, 49.96444048200335, 49.89801222937447, 47.38822562353951, 48.32840721947806, 49.047983510153635, 51.39419909885952, 43.5320657321385, 18.68946259362357, 3.6393124759197235, 2.3531852832862308, 0.9915203154087067, 0.09619185873972518, 0.1502603449459587, 22.405086483274186, 48.75003433227539, 36.08569867270333, 27.930175883429392, 22.732106924057007, 31.57545621054513, 49.731384004865376, 48.1024934904916, 39.301519530160085, 5.061731840882983, 0.20008517136531218, 0.00606752120490585, 0.057761141631220064, 0.05291669676080346, 0.009232291652421867, 0.05704057136816638, 0.04012226080521941, 0.0217977339135749, 0.05617253848218492, 0.08831480677638735, 0.02407687027672572, 0.03107531268947891, 0.059568765706249645, 0.054675982001104524, 0.07358546036162547, 0.012231645440416676, 0.06382185712988887, 0.004180913533283663, 0.017485180769913962, 0.040574653672852685, 0.09165319228278739, 0.05046309038464512, 0.037693665229848454, 0.014064298975946648, 0.026828487536736896, 0.033752574385809045, 3.7010817442621504, 36.04503434044974, 47.32687302998134, 43.60625512259347, 28.142269645418438, 24.149645396641322, 30.556440353393555, 39.40122965403965, 32.48196336201259, 50.09768956048148, 11.354713133403234, 0.1486547411020313, 0.4762626439332962, 5.478565565177372, 11.218054226466588, 12.56901158605303, 12.207480311393738, 44.341947759900776, 53.15039798191616, 48.861361844199045, 50.28008324759347, 46.090649536677766, 48.25788647787911, 45.84745216369629, 43.8245848928179, 41.93425103596279, 44.3394707271031, 48.62127726418631, 49.19558409282139, 45.77733094351632, 46.906020641326904, 43.317998681749614, 44.39149536405291, 44.09640884399414, 46.005078996930806, 46.46157564435686, 49.19778667177473, 45.122664724077495, 45.70495155879429, 43.69880165372576, 43.962555272238596, 46.12644665581839, 44.034740107400076, 41.06466313770839, 38.197016511644634, 37.03859199796404, 32.73355415889195, 34.12949936730521, 34.692647389003206, 35.5118156841823, 35.66866431917463, 34.81469249725342, 37.011316844395225, 33.61579820087978, 34.74664184025356, 33.96409402574812, 34.598363808223176, 34.77728687013899, 34.17995718547276, 38.034904616219656, 46.54237624577114, 47.55446822302682, 41.67951617922102, 46.83519070489066, 48.31983314241682, 46.31702879496983, 47.56864602225167, 47.7242648260934, 50.13518898827689, 46.21478605270386, 47.71815735953194, 46.14888933726719, 47.876749992370605, 47.07656764984131, 48.84513085229056, 31.93361152921404, 45.52591732570103, 45.883301394326345, 47.23649433680943, 47.74387264251709, 48.044542040143696, 46.41854545048305, 46.44781821114676, 44.12312119347708, 41.81712872641427, 40.70499311174665, 39.657843998500276, 41.5470244543893, 39.33062205995832, 36.441383906773154, 34.98342602593558, 34.84741851261684, 35.306114264896934, 34.86358002253941, 36.83338042667934, 35.37699631282261, 37.11365686144148, 37.45813465118408, 36.851244245256694, 37.3628123147147, 38.53255544389997, 34.68449020385742, 35.85000535420009, 34.90579380307879, 36.33669539860317, 38.26330232620239, 39.310267312186106, 41.71633815765381, 46.48513003758022, 46.85323517663138, 47.63001946040562, 44.6638890675136, 48.48487717764718, 47.29433461597988, 47.72386877877371, 44.09484549931118, 47.782695702144075, 50.8156920841762, 47.734659331185476, 43.70180674961635, 41.95526933670044, 40.35269512448992, 38.38664674758911, 39.019943782261436, 49.87661177771432, 51.952862058367046, 52.162412779671804, 51.65223782403128, 51.87879426138741, 49.29543318067278, 51.046094349452424, 51.29332167761666, 54.01136663981846, 46.431701864515034, 17.57398315838405, 1.5341822249548775, 2.6295576989650726, 1.062404534646443, 0.08022893566106047, 0.12681861567710126, 26.043376922607422, 51.53383009774344, 38.35113797869001, 34.684458936963765, 27.851699454443796, 36.836625235421316, 55.5060943875994, 52.9391553742545, 47.05767897197178, 6.573673750673022, 0.18877552609358514, 0.04890404761369739, 0.05672629091090389, 0.030955866777471135, 0.07366017385252885, 0.05954013831381287, 0.050903374794870615, 0.023311464115977287, 0.03646107244172266, 0.042448719896908314, 0.04444668661536915, 0.025890724999564033, 0.02764609000379486, 0.15726525549377712, 0.0960754289158753, 0.06700237467885017, 0.15386816992291383, 0.09609613101929426, 0.18721782682197435, 0.1474434339574405, 0.1753324717283249, 0.1584569936884301, 0.14116113606308187, 0.15243601320045336, 0.10774038905011755, 0.17079634299235685, 4.931056201457977, 43.48125008174351, 56.14108330862862, 51.25885166440691, 34.46741458347866, 28.2286513873509, 30.650327886853898, 37.811450549534385, 36.781605924878804, 55.71932765415737, 12.5569486447743, 0.2176277714648417, 2.8727023090635027, 20.515384912490845, 16.391179152897426, 22.41258011545454, 14.351052556719099, 47.368728978293284, 56.53622388839722, 49.99587065832955, 53.024253436497276, 49.114182472229004, 50.58738122667585, 48.182171957833425, 46.19751977920532, 43.86581202915737, 46.36382838657924, 51.77096169335501, 49.73335034506661, 47.32999277114868, 48.13581010273525, 42.869673115866526, 47.47329241888863, 45.46990442276001, 48.0543772152492, 48.07398155757359, 50.86197403499058, 45.8652777671814, 47.929066453661235, 46.76983594894409, 47.29527957098824, 48.39744104657854, 47.30069916588919, 43.21600260053362, 40.22095727920532, 39.41944088254656, 34.9624285697937, 36.53068215506417, 37.323113782065256, 37.42053100040981, 36.95463344029018, 37.23785938535418, 37.645006452287944, 36.497389861515586, 37.14923163822719, 35.74053648539952, 35.66679525375366, 36.49743849890572, 35.8618346623012, 39.45605788912092, 49.054292474474224, 49.31602416719709, 43.94360753468105, 47.60109410967146, 50.5130945614406, 47.912602697099956, 49.28502477918352, 50.196819509778706, 52.48313120433262, 49.07302829197475, 49.67738607951573, 49.497115067073274, 50.04965318952288, 48.03749656677246, 50.694803850991384, 34.65155226843697, 47.075851985386436, 47.364313398088726, 49.45824684415545, 49.5611948285784, 52.22575603212629, 47.39366258893694, 48.76294755935669, 47.28644493647984, 44.260660784585134, 43.418045793260845, 43.16507577896118, 43.66880628040859, 42.1638160433088, 39.35235949925014, 37.44201830455235, 35.49215228216988, 35.980384826660156, 36.70537723813738, 38.86859812055315, 37.273256983075825, 38.692808696201865, 39.463350023542134, 39.50135666983468, 38.49645607812064, 40.392129625592915, 37.087722710200715, 37.73576382228306, 35.76667560849871, 38.409725189208984, 40.11258275168282, 41.75326088496617, 42.8341052872794, 48.16885920933315, 47.91440575463431, 50.19121578761509, 46.18404722213745, 50.465416022709434, 48.694393157958984, 48.461611134665354, 44.74926505770002, 49.99658979688372, 52.48088346208845, 49.5124705859593, 47.43063742773873, 44.277176652635845, 42.750365597861155, 40.22567163194929, 40.41480507169451, 51.933928217206685, 53.871867656707764, 55.03936651774815, 54.588292939322336, 53.69368805204119, 51.69846766335623, 53.876283236912315, 53.709891251155305, 55.65833289282662, 49.0472400529044, 23.273178781781876, 9.575272526059832, 5.931530790669577, 3.1679647053991045, 0.4214036576449871, 0.2356593103281089, 30.000983987535747, 60.54100922175816, 48.138676234654014, 37.821792943137034, 34.34718642915998, 42.06691299165998, 62.43016883305141, 61.75941058567592, 54.576449734824045, 8.747674328940255, 0.33817346660154207, 0.10400384598012481, 0.15278301600899014, 0.10897188939686332, 0.11944401210972241, 0.1885363832116127, 0.21868678820984705, 0.07023450160132987, 0.2265212892421654, 0.19194338896444865, 0.15524451035474027, 0.2025833066020693, 0.06939861431185688], [0.021014446658747535, 0.041642297990620136, 0.043131753602730374, 0.02447266484211598, 0.05638760694169572, 0.011374917796014674, 0.004995588121736156, 0.057646469213068485, 0.029355979591075863, 0.03166352791179504, 0.01822512660042516, 0.017378978165132657, 0.07874234685940401, 2.647831895521709, 33.618820667266846, 42.43844011851719, 38.0487836429051, 28.242075307028635, 15.275685821260724, 18.2385835647583, 30.656855719430105, 29.60998453412737, 44.24672269821167, 7.170109289033072, 0.20020049517708166, 0.5857942636523927, 4.845719729151044, 8.720801302364894, 8.405814273016793, 12.16680816241673, 44.536424364362446, 51.275412695748464, 49.92692368371146, 50.79459040505545, 47.85614858354841, 47.15307426452637, 47.24590914590018, 43.95441198348999, 38.93276820863996, 42.680254799979075, 46.33345433643886, 47.89746257237026, 45.52264125006539, 43.19693674360003, 46.427164690835134, 46.82761369432722, 44.41200644629342, 44.265257017953054, 46.071997097560335, 45.361088684626985, 45.18864481789725, 45.47437906265259, 45.32577793938773, 43.482591084071565, 42.524365016392295, 39.836353642599924, 35.768200738089426, 32.81394134249006, 31.444454874311173, 31.43266030720302, 32.52021666935512, 32.9157498223441, 32.8848546573094, 32.390149865831646, 33.63388436181204, 33.084097726004465, 32.83400079182216, 34.11614840371268, 34.07370185852051, 32.77279758453369, 33.11994348253523, 33.65102904183524, 38.69438246318272, 45.22721079417637, 45.00795691353934, 45.8153931753976, 44.36578355516706, 46.335795879364014, 46.453929151807515, 48.30080202647618, 45.99835661479405, 45.87053407941546, 45.694022042410715, 46.519374234335764, 45.60980292728969, 46.31847054617745, 45.1192045211792, 48.56299230030605, 31.0582948412214, 42.704281670706614, 47.08829620906285, 44.197275842939106, 46.05231632505144, 46.33306871141706, 45.44466856547764, 48.59733377184187, 45.63514300755092, 45.43393012455532, 43.83371482576643, 41.61800377709525, 43.185409682137625, 41.060212816510884, 38.96344103131975, 36.74249104091099, 33.79697247913906, 33.297758306775776, 32.77238416671753, 33.400855677468435, 32.82146971566336, 34.814758505140034, 36.07464408874512, 34.32449013846261, 35.791404247283936, 35.12671177727835, 34.89987393787929, 33.84890331540789, 33.641252926417756, 33.914337975638254, 33.73810734067644, 34.7693589755467, 38.879902839660645, 40.95419372831072, 43.46867731639317, 46.10650185176304, 45.478662627083914, 48.65307222093855, 47.46902275085449, 47.577612672533306, 44.014784881046836, 46.03384453909737, 49.65636083057949, 48.19070781980242, 48.78671039853777, 50.58758967263358, 43.084511416299, 38.28807265417916, 37.70915569577898, 43.65940536771502, 51.20188685825893, 51.678300516945974, 50.38545615332467, 52.678545815604075, 50.72201994487217, 50.162714276994976, 49.85638209751674, 53.8345627784729, 51.004832472120015, 35.1154522214617, 10.942310622760228, 2.6335446621690477, 0.7610119272555623, 0.04784952277051551, 0.045807213788586, 17.607304981776647, 49.63316079548427, 35.70311001368931, 29.49873345238822, 38.3054118837629, 31.370015348706925, 44.920402663094656, 44.35913412911551, 40.34775495529175, 8.278036032404218, 0.10284490138292313, 0.0832290511046137, 0.031216556538960764, 0.047687054345650334, 0.06969538517296314, 0.09741478918918542, 0.0334171405993402, 0.041866730233388286, 0.022465809314910854, 0.029254657349416187, 0.06448644825390407, 0.018804269809541956, 0.013197635882534087, 0.012195579607837966, 0.06441023520060948, 0.06188293652875083, 0.02462408332420247, 0.042717965984983106, 0.053076932805457284, 0.009990867510038828, 0.042146839667111635, 0.01754809114416795, 0.024388918353776847, 0.04573151642190559, 0.044001096061297824, 0.0740157329876508, 4.174105550561633, 40.45522969109671, 49.53797047478812, 43.20839779717581, 31.606191567012242, 20.361459732055664, 23.261297362191335, 32.525636264256065, 32.371205602373394, 48.89400795527867, 8.347966177122933, 0.22194953741771833, 0.9244704161371503, 6.123996325901576, 11.915716767311096, 12.341684767178126, 11.202707392828804, 45.52848468508039, 53.15010615757534, 51.30401495524815, 51.22979777199881, 50.6448324067252, 49.37707104001726, 49.915268080575125, 43.82548815863473, 41.11494377681187, 43.51614393506731, 47.55595166342599, 49.137514523097444, 46.1056889125279, 43.115146023886545, 46.18982464926583, 48.62207978112357, 47.01256084442139, 45.9361389705113, 47.288011755262104, 47.05538606643677, 46.59346982410976, 47.0050950050354, 46.704102516174316, 44.653095041002544, 45.110435894557405, 41.060556752341135, 37.671840395246235, 33.65717472348894, 33.40742519923619, 32.614708696092876, 34.215087277548655, 34.74732971191406, 35.26464741570609, 34.91468054907662, 34.4157304082598, 34.685039111546104, 34.31247670309884, 34.365366390773225, 34.71195643288748, 33.68683658327375, 33.93492201396397, 35.14263704844883, 40.96552276611328, 47.460459096091135, 45.92652266366141, 45.997060775756836, 46.094818455832346, 47.886303765433176, 48.97264419283186, 49.162211894989014, 47.01353359222412, 47.08893544333321, 46.33716467448643, 48.870828764779226, 46.72660773141043, 47.93611192703247, 47.02192006792341, 50.25610154015677, 32.98594747270857, 44.1981964792524, 48.63880409513201, 46.27438770021711, 48.52903992789132, 47.51992177963257, 47.40074627740042, 50.32658406666347, 48.37148257664272, 46.57695048195975, 44.918488434382844, 43.628635270254954, 44.4101026398795, 41.64258302961077, 40.63388524736677, 37.34592471803938, 34.34860733577183, 34.668422494615825, 34.96644810267857, 34.31945964268276, 35.05045529774257, 36.57975728171212, 37.57489912850516, 36.058948108128135, 37.28001063210623, 37.31760038648333, 36.37689420155117, 36.674346583230154, 34.94424165998186, 36.37456655502319, 35.88993665150234, 36.83597557885306, 39.97792666299002, 42.171601499829976, 46.1991491317749, 47.095515387398855, 46.971382345472065, 48.832530294145855, 48.404920782361714, 47.88547345570156, 45.29641832624163, 46.196981293814524, 50.34476750237601, 49.66697767802647, 51.210037095206125, 51.55491093226841, 45.26576287405831, 40.50415195737566, 39.75200598580496, 45.33715214048113, 52.66892256055559, 51.72583661760603, 52.562076636723106, 54.07185418265206, 53.33360113416399, 52.6460143498012, 51.312432697841096, 57.11838565553938, 55.10300506864275, 40.89977543694632, 11.105822580201284, 1.8819912416594369, 1.107371864574296, 0.03299873215811593, 0.04130190750584006, 18.76389169692993, 56.00259876251221, 38.941780022212434, 32.94443198612758, 40.793464524405344, 35.89992816107613, 50.26126057761056, 49.48040117536272, 47.74784006391253, 10.31967386177608, 0.18150400556623936, 0.04730742418074182, 0.12743921737585748, 0.04400275168674333, 0.031023679567234855, 0.11244056041219405, 0.05785000936261245, 0.12197930392410074, 0.032427911181002855, 0.041090703303260465, 0.020384540548548102, 0.0435960683306413, 0.023521531772400652, 0.09511435191546168, 0.10948479401745967, 0.12474813392119748, 0.11484016557889325, 0.1623422173517091, 0.11209938621946744, 0.08324122402284827, 0.1183373893478087, 0.1762118259710925, 0.16399459939982208, 0.08825882763734885, 0.09419753575431448, 0.20185521138565882, 6.991338653223855, 48.63077197756086, 56.16934858049665, 51.80835689817156, 37.61551134926932, 24.415884733200073, 22.754289048058645, 38.76829392569405, 39.09894132614136, 54.87213032586234, 9.513821789196559, 0.3208577957536493, 1.3084555545023508, 10.044095277786255, 14.903726169041224, 14.93857833317348, 14.54330313205719, 45.627246379852295, 54.371602943965364, 55.04146487372262, 53.8846731867109, 53.447909423283164, 51.63602420261928, 50.87967804500035, 46.23102746691023, 42.19454445157732, 45.99812732424055, 50.28950847898211, 50.296203068324495, 47.2321343421936, 43.76444475991385, 46.83687216894967, 50.2754487991333, 49.68177039282662, 47.770074299403596, 51.03471320016043, 50.16305473872593, 48.732132298605784, 50.56135674885341, 48.431779044015066, 47.55548613412039, 47.22500549043928, 44.11041988645281, 38.356797286442344, 35.41253982271467, 34.90846538543701, 33.87194701603481, 35.334466389247346, 36.43453645706177, 37.08877188818795, 36.32738133839199, 36.934629576546804, 36.99875797544207, 35.6471665927342, 36.84154456002371, 36.0824990272522, 35.77845975330898, 35.667052337101524, 37.42682606833321, 42.07840878622872, 49.46462181636265, 46.06502110617501, 45.0992180279323, 46.48297957011631, 49.75379889351981, 50.139896392822266, 51.47142832619803, 46.91523742675781, 48.529696532658164, 49.44209575653076, 51.01722111020769, 47.890399728502544, 50.59297105244228, 48.83794641494751, 51.609725270952495, 37.71893528529576, 45.58449411392212, 50.0621634210859, 47.39814417702811, 50.78396660940987, 49.5483615057809, 50.10464123317173, 51.92778600965227, 49.66581732886178, 49.68426479612078, 47.57551779065813, 44.81250408717564, 46.05560629708426, 43.49285704748971, 42.05497946058001, 40.16022654942104, 36.41127041407994, 36.730428968157085, 35.838471344539094, 38.15467071533203, 35.78849990027291, 38.13167912619454, 39.6333898135594, 37.86284984861101, 39.68916647774832, 39.21707112448556, 39.27787133625576, 38.337873867579866, 37.331343923296245, 39.23122807911464, 37.867730958121165, 39.967295919145855, 42.54820081165859, 44.55717863355364, 47.77229424885341, 49.8055282320295, 49.46465308325631, 51.65508311135428, 51.89923933574131, 50.287840911320274, 46.774838651929585, 47.874081884111675, 52.46961348397391, 50.86003201348441, 54.275328704289024, 54.53097724914551, 48.53039830071585, 43.41246291569301, 41.83993966238839, 47.86921467099871, 54.66111700875418, 54.99747930254255, 54.366912909916465, 57.059256485530305, 55.714547293526785, 55.805572169167654, 54.45152112415859, 59.58421448298863, 57.13831656319754, 42.87365443365914, 16.106770277023315, 8.365555541855947, 2.8189966423170905, 0.11331219971179962, 0.11556022694068295, 22.66596007347107, 61.55676637377058, 48.45531606674194, 42.68657766069685, 47.09336839403425, 41.93282665525164, 58.5253507069179, 58.39817087990897, 57.540634632110596, 14.239833610398428, 0.22616584545799664, 0.1749272234737873, 0.27583132471357075, 0.11099629862500088, 0.22116657585969993, 0.2264228066695588, 0.1211048351334674, 0.15790875096406254, 0.09027585440448352, 0.07721499167382717, 0.12286268866487912, 0.12336331180163793, 0.10773973087114946], [0.04907443793490529, 0.024019824141370397, 0.028067343203084807, 0.0783109614359481, 0.021809146872588565, 0.061149446958942075, 0.045613695601267476, 0.04930976405739784, 0.035640062032533545, 0.01494902721606195, 0.04598729698253529, 0.032365367215658934, 0.046213157541517697, 5.87608677148819, 34.642206941332134, 45.97896071842739, 39.92373071398054, 28.724233388900757, 19.028124741145543, 27.362850257328578, 38.001966680799214, 37.972648756844656, 40.60089520045689, 6.830832660198212, 0.3821654160107885, 20.302516426358903, 24.9769343989236, 11.313818642071315, 13.24320832320622, 12.709617938314166, 39.821449756622314, 46.78072725023542, 50.683443546295166, 46.513430050441194, 47.19826534816197, 44.1084292275565, 48.139089652470176, 43.86544377463204, 39.71666744777134, 40.10340418134417, 47.46966545922415, 48.0487630707877, 47.30144609723772, 42.8371763910566, 44.74141011919294, 44.15906075068882, 42.82406166621617, 42.26541607720511, 41.83776487622942, 42.760193824768066, 44.527151993342805, 45.295369148254395, 43.898086411612375, 39.79122509275164, 38.58638661248343, 34.03375666482108, 33.60703304835728, 33.02563558306013, 33.4154121535165, 33.920924867902485, 32.297297613961355, 33.92110552106585, 32.26503365380423, 31.607768808092388, 33.71759973253523, 32.662095410483225, 32.603251116616384, 32.02511930465698, 32.39103923525129, 32.8770101411002, 32.85290336608887, 34.83482837677002, 42.10864039829799, 46.83046245574951, 48.14273745673043, 39.23831524167742, 43.81647287096296, 45.92733212879726, 47.501953738076345, 47.02829851422991, 45.70377036503383, 46.44602905000959, 45.90769304547991, 46.47881759916033, 44.261091572897776, 46.46261787414551, 46.232232979365754, 47.23964187077114, 30.63477087020874, 41.497066906520296, 46.060970306396484, 45.85272932052612, 46.44250978742327, 45.533546447753906, 46.97738558905465, 45.35696840286255, 47.445503098624094, 45.392946175166536, 47.34774889264788, 45.93831723076956, 44.669920103890554, 41.60769612448556, 39.71175159726824, 37.65482078279768, 35.76083217348371, 32.59288787841797, 33.32683651787894, 32.23850195748465, 33.52311965397426, 34.654522623334614, 34.48991632461548, 35.756732736315044, 35.23910583768572, 33.60008832386562, 33.3737507547651, 34.086424010140554, 34.96822336741856, 34.432451248168945, 33.42827674320766, 34.477583272116526, 36.203637395586284, 39.79285791942051, 41.47296707970755, 46.0375896181379, 47.47168738501412, 44.195438044411794, 45.37936244692121, 46.26853036880493, 46.3301226752145, 43.29645579201834, 46.826536723545615, 50.708679403577534, 44.4687489100865, 46.939368520464214, 47.905512060437886, 43.2874196597508, 40.50985642841884, 41.50741972242083, 46.433383328574045, 50.077338286808555, 50.68178987503052, 51.1087532043457, 52.52943399974278, 51.062995842524934, 51.70455428532192, 54.54086453574044, 53.051104749952046, 41.27737876347133, 15.841081585202899, 3.1224503133978163, 0.4907583775264876, 0.11183862521180085, 0.027248207246884704, 13.074204683303833, 49.97565140042986, 40.86899144308907, 37.15411969593593, 24.698669467653545, 26.361830234527588, 43.59635393960135, 42.16307953425816, 44.98984643391201, 7.3929215158735, 0.10003844661904232, 0.1143420801631042, 0.01746251091494092, 0.04994329184825931, 0.018966999470389316, 0.01639656293472009, 0.005757488800944495, 0.007043651504708188, 0.05708240305206605, 0.01445986792844321, 0.010269809015361326, 0.05849549972585269, 0.07882898899593524, 0.0398745649893369, 0.019610230312017456, 0.049795472994446754, 0.010993137523265821, 0.027032799519864575, 0.06706595341009752, 0.0330276648913111, 0.03743532998487353, 0.038440586400351355, 0.05796829837241343, 0.018590817959713082, 0.055148015064852576, 0.04721789487770625, 7.292601687567575, 41.68809373038155, 52.207166126796174, 45.99246801648821, 33.35197162628174, 17.793527126312256, 23.534623861312866, 34.71158817836216, 37.649001666477744, 47.870885712759836, 7.027220453534808, 0.21109968104532786, 17.43799475261143, 15.555166687284197, 8.328328830855233, 9.511435951505389, 13.594322511128016, 42.722840309143066, 47.525664465767996, 52.304770946502686, 48.17571708134243, 48.07472154072353, 45.81328092302595, 49.36143411908831, 44.79151010513306, 41.299699851444785, 43.770677294049946, 48.62350763593401, 48.763833454677034, 48.22572674070086, 43.686708314078196, 46.944600514003206, 45.12371390206473, 43.87207235608782, 43.445383480616975, 44.39439623696463, 45.10202162606375, 47.31974417822701, 46.56439161300659, 45.78801727294922, 43.05439444950649, 40.21619776317051, 36.48050226484026, 35.24966015134539, 34.67152486528669, 34.1561735016959, 34.650801862989155, 34.944425787244526, 35.20276328495571, 34.83538770675659, 34.0049181665693, 34.56122916085379, 32.87482493264334, 34.87261962890625, 33.469927719661165, 34.12849187850952, 33.669438294001985, 34.88967398234776, 36.55269404820034, 44.291660172598704, 47.757202761513845, 47.721548080444336, 39.4315550667899, 44.78620515550886, 46.571357182094026, 48.01892403193882, 46.47736889975411, 45.25763348170689, 48.66183737346104, 46.59670073645455, 48.358433859688894, 46.79030186789376, 47.003889492579866, 48.064983640398296, 49.05237477166312, 33.120360374450684, 42.68633794784546, 48.54535429818289, 45.20383358001709, 46.33519833428519, 48.550905908857075, 49.011425563267295, 47.78198003768921, 49.293946266174316, 47.42797974177769, 49.54477276120867, 46.55690492902483, 46.74895313807896, 43.45801183155605, 41.626654284340994, 40.83214862006051, 36.86816658292498, 34.11400488444737, 35.4330335344587, 33.82804829733712, 34.96825116021292, 35.93484285899571, 36.139470781598774, 37.13788522992815, 36.95027691977364, 35.75269930703299, 36.052580084119526, 35.88047667912075, 35.887324128832134, 36.86934082848685, 35.78328875132969, 36.367726053510395, 37.811151776994976, 42.49587392807007, 43.835007190704346, 48.07184846060616, 48.31118263517107, 46.871832030160085, 46.97975492477417, 47.448668003082275, 48.65077236720494, 44.29818800517491, 49.25544629778181, 51.939337389809744, 47.120716503688264, 48.42125947134835, 49.179610184260774, 45.37327929905483, 41.53664384569441, 43.2999507359096, 48.328042439052034, 53.69892699377877, 51.811191763196675, 52.33205999646868, 53.17273991448538, 53.46488734654018, 53.1535142489842, 56.793116160801475, 53.32339423043387, 42.64817149298531, 19.415537187031337, 5.0585673706872125, 1.0927295131342751, 0.13658261245914868, 0.01529494097589382, 14.978822299412318, 55.18918704986572, 42.69578054973057, 39.04673951012747, 28.850789615086146, 31.697866099221365, 50.007074628557476, 49.581737177712576, 52.217612743377686, 10.633510095732552, 0.1066577389304127, 0.12057708416666303, 0.026110478743378605, 0.030057181072022234, 0.05344529589638114, 0.0898882480604308, 0.012574956170283258, 0.02801970495576305, 0.06478736496397428, 0.030372967877026116, 0.04973167373931833, 0.026049495408577577, 0.04308932141533919, 0.11735157296061516, 0.1108672684058547, 0.11146717478654214, 0.15540066840393202, 0.08225339917199952, 0.2513691873422691, 0.20033724712474005, 0.12220342404076032, 0.08431663417390414, 0.16526511551014014, 0.16195583237068994, 0.15474699490836688, 0.25611624547413414, 9.938334141458784, 50.377806186676025, 57.71898794174194, 52.407739775521414, 39.22596134458269, 27.765378509249004, 36.53066825866699, 47.42079530443464, 48.52383920124599, 51.765451771872385, 8.162377187183925, 0.5199452085154397, 23.228130136217388, 30.97276599066598, 24.314216954367502, 21.781060082571848, 14.444496273994446, 45.9177679334368, 50.645867688315256, 52.233416421072825, 48.11536155428205, 50.527671882084434, 46.75037751879011, 51.782301153455464, 47.50887761797224, 43.327535084315706, 46.9857303755624, 51.175435066223145, 51.4169613974435, 49.45545366832188, 44.265788555145264, 47.50741502216884, 47.04443917955671, 46.45208787918091, 47.15707990101406, 45.33276782717024, 45.73992531640189, 49.63206992830549, 49.21683863231114, 47.65379619598389, 44.01952007838658, 43.28238916397095, 37.63888161523001, 36.017884254455566, 37.235833985464915, 35.71369559424264, 37.28609030587332, 35.82257386616298, 37.060086250305176, 35.941561767033164, 34.66262422289167, 36.052156244005474, 34.12968349456787, 36.2647294316973, 35.68903991154262, 35.41166434969221, 36.37864862169538, 36.19245426995413, 39.18837506430489, 46.43479381288801, 49.13567672457014, 49.11434228079659, 40.43098047801426, 47.15950829642159, 47.94932740075247, 49.27859074728829, 48.48982082094465, 47.16318736757551, 50.122866358075825, 48.57761825834002, 48.82282018661499, 47.60041666030884, 49.082453523363384, 49.30150590624128, 50.62669760840279, 34.897139821733745, 43.79208469390869, 49.09540843963623, 47.58853871481759, 49.06803601128714, 50.69426189150129, 49.97703061785017, 48.78326061793736, 48.735759258270264, 49.171887261526926, 49.30280521937779, 48.014484133039204, 49.132216521671836, 45.446138109479634, 43.78372253690447, 42.76315723146711, 38.53634916033064, 35.51324353899275, 37.984644821711946, 34.5878963470459, 36.923929350716726, 37.38639102663313, 37.20976781845093, 39.10780722754342, 38.31962789808001, 37.3193096433367, 38.131418568747385, 37.360644476754324, 38.538131373269216, 39.71959611347744, 37.17921311514718, 39.693311078207834, 40.542433057512554, 44.19946799959455, 45.80168437957764, 48.757687773023335, 51.60822098595755, 48.59409243719918, 47.89621884482247, 49.50340666089739, 50.42800692149571, 45.042649269104004, 48.85221454075405, 51.90931074959891, 50.05580581937517, 49.63054827281407, 51.94283580780029, 47.41639362062727, 45.38425745282854, 45.751164027622764, 50.5185558455331, 55.028120858328684, 54.02591964176723, 54.11848701749529, 55.606912749154226, 53.76114811216082, 55.060499463762554, 57.77043240410941, 55.62885168620518, 48.061443533216206, 22.67228988238743, 6.286748758384159, 2.7864777701241628, 0.3872944079339504, 0.13359519919114454, 16.971880061285837, 61.22683116367885, 52.70724534988403, 48.86242839268276, 35.896672930036274, 36.99083008084978, 55.694070952279226, 57.70460169655936, 60.61063017163958, 14.245241914476667, 0.1787861335490431, 0.27431194909981316, 0.1176814359745809, 0.11884015665522643, 0.1225956172815391, 0.27492792318974224, 0.11486600419240338, 0.10158955053027187, 0.18588455979313168, 0.09878485995743956, 0.17313922941684723, 0.21621556367192948, 0.11103127710521221], [0.04315573303028941, 0.05298124240445239, 0.08671358626868043, 0.0075774651819041795, 0.07626825211835758, 0.05917575143809829, 0.04823281363184963, 0.042852360023451705, 0.06293073030454771, 0.03813619898366077, 0.03840901077325855, 0.05095159149329577, 0.04275640838646463, 6.920889564922877, 35.51219088690621, 39.42679555075509, 40.74944073813302, 29.347332205091202, 22.577453919819423, 17.450329542160034, 25.468613249914988, 37.873560496738975, 39.09366416931152, 5.141406399863107, 0.3327383468193667, 9.07882113116128, 31.72978264944894, 6.819162292139871, 10.00311393397195, 9.690072400229317, 24.2652964251382, 23.85626813343593, 44.3127965927124, 44.9907670702253, 47.69388730185372, 47.22943149294172, 47.7551634652274, 41.412833895002095, 37.12397493634905, 38.986192907605854, 44.89770637239729, 44.516347544533865, 48.294962065560476, 43.62873601913452, 46.300620623997276, 45.92963893072945, 44.556966713496614, 39.58254984446934, 36.30388947895595, 35.346007347106934, 36.40680619648525, 36.69250570024763, 35.38935368401663, 34.20615536825997, 32.19606236049107, 32.89068419592721, 32.984985147203716, 31.563199588230678, 32.202583244868684, 32.5199248450143, 33.22584097726004, 32.68029274259295, 32.9925343649728, 31.81672545841762, 33.14162881033761, 33.230760301862446, 33.60496595927647, 33.03834383828299, 33.3639155796596, 33.52501998628889, 32.764713355473106, 33.147861344473704, 42.80944265638079, 44.89775848388672, 36.794255120413645, 41.61520365306309, 44.301026344299316, 42.94130556924002, 44.969109535217285, 45.62069770268032, 44.985271045139854, 46.809798513139995, 46.15347514833723, 45.057424613407676, 43.122844627925325, 45.41478783743722, 44.92653444835118, 47.762837750571116, 30.720292772565568, 40.36664710726057, 46.49835245949881, 43.79666008268084, 46.80219718388149, 43.86598573412214, 46.24582018171038, 41.451524938855854, 44.1957437651498, 45.9047018459865, 43.18971756526402, 45.25012247903006, 47.33177498408726, 42.10941512244088, 40.4963595526559, 38.15092216219221, 34.149718625204905, 33.477723598480225, 34.05408361979893, 33.53121083123343, 35.194724219185964, 34.43484837668282, 34.2363418170384, 34.61596359525408, 36.79070111683437, 35.03450223377773, 33.66274717875889, 33.91337217603411, 35.606728076934814, 32.95549004418509, 33.9278244291033, 33.73701299939837, 34.60434968130929, 36.19138077327183, 37.8027583530971, 41.34664535522461, 43.85907922472273, 44.77563694545201, 43.791365555354524, 46.00721904209682, 46.10849251065935, 44.882156303950715, 42.45882960728237, 41.52488054547991, 47.74966744014195, 48.165235723767964, 48.01691600254604, 47.57966586521694, 42.12263754435948, 39.61612006596157, 42.764275891440256, 49.61732932499477, 51.62866953441075, 53.16117116383144, 51.4541585786002, 52.23239156178066, 52.967340741838726, 54.90212917327881, 51.24141863414219, 46.99778202601841, 17.2349180153438, 3.4286105249609267, 0.7398603079574448, 0.06009615704949413, 0.028054795394252454, 6.255163550376892, 51.11241143090384, 40.558948925563264, 34.710903780800955, 35.4477984564645, 24.02811098098755, 37.34706769670759, 45.86155005863735, 41.01722431182861, 7.174687283379691, 0.023215987453503267, 0.03605160369936909, 0.13350479118525982, 0.0344802896226091, 0.04766971777592387, 0.023806082217821052, 0.014423569697620613, 0.024750034690701535, 0.015378516134140747, 0.021283346693962812, 0.026688487102676715, 0.019475695477532487, 0.05248352000489831, 0.03769460839352437, 0.008751501246089382, 0.09573121488626514, 0.07278981019875833, 0.08144634962081909, 0.053433652235461135, 0.06654874009213277, 0.03804339574916022, 0.05563589531396117, 0.023002379540620104, 0.03235814081771033, 0.0542199012956449, 0.038092216343751976, 8.37593788760049, 40.82117394038609, 47.88220085416521, 45.496106079646516, 34.940110955919536, 24.54314967564174, 23.844704593930924, 33.53954866954258, 42.72621018545968, 43.520597730364116, 6.332962095737457, 0.4637160428932735, 12.554203237806048, 35.749006339481895, 6.26137523991721, 7.636724250657218, 11.35235161440713, 27.19871817316328, 27.187196322849818, 45.34445469720023, 45.02576862062727, 48.7806897844587, 47.45043979372297, 49.4635135786874, 43.402488776615684, 39.25999362128121, 40.74581377846854, 46.84993130820138, 45.939752033778596, 49.321547985076904, 43.82365036010742, 46.70433875492641, 46.774494716099326, 46.53677947180611, 41.195709637233186, 38.384496280125205, 37.178973402295796, 39.02742351804461, 38.67527491705758, 38.49078287397112, 35.625095639910015, 34.87352984292166, 35.71285833631243, 33.859026840754915, 33.65314824240548, 34.11806958062308, 34.25173902511597, 35.60650226048061, 34.448168073381694, 34.29856293542044, 33.23905297688076, 34.61471291950771, 34.24282101222447, 33.91174977166312, 35.19682952335903, 33.85165132795061, 34.99485233851841, 33.91229173115322, 34.56365755626133, 44.80734504972185, 45.87440422603062, 39.189028194972444, 42.14248507363455, 45.01085083825247, 44.03967680249895, 45.54758875710623, 45.36824185507638, 45.962879112788606, 48.26697819573538, 46.60813052313668, 47.33744818823678, 45.42704793385097, 46.23283747264317, 45.964463302067344, 50.49709980828421, 32.26419986997332, 40.416351045881, 48.57690954208374, 45.32745245524815, 46.571749755314414, 45.428232601710725, 47.13696486609322, 43.3878767149789, 46.64774567740304, 47.61949641363961, 46.661798409053254, 45.63175228663853, 47.07457004274641, 43.4280755179269, 42.0732775415693, 40.09954793112618, 35.84134095055716, 34.473730495997835, 35.95479808534895, 35.94050216674805, 35.90435068947928, 35.58096763065883, 35.40014771052769, 36.286508560180664, 37.969181605747764, 37.284283774239675, 35.99516364506313, 35.09154347011021, 37.309123584202354, 34.89986004148211, 35.77635792323521, 35.557197843279155, 35.76557431902204, 37.72545269557408, 39.91923870359148, 42.49806261062622, 44.84569215774536, 46.462187085832866, 46.209251812526155, 48.79556587764195, 47.107084138052805, 45.66376611164638, 42.986166613442556, 42.845601081848145, 47.55235249655587, 48.43980073928833, 51.59345258985247, 48.741352558135986, 44.62134524754116, 40.63111291612898, 44.90467194148472, 50.93814018794468, 54.08978748321533, 53.93077448436192, 52.35066727229527, 54.01722744532994, 54.48622737612043, 56.28557109832764, 51.79291452680315, 46.77409519468035, 17.82271303449358, 3.086747646331787, 0.7868502693516868, 0.19490857342524187, 0.021205399983695576, 7.4806902919496805, 56.86302546092442, 45.09746708188738, 42.56710686002459, 42.25960043498448, 27.96364188194275, 44.38719095502581, 49.47333485739571, 50.92814520427159, 10.388909186635699, 0.020006079160209213, 0.010711964485900742, 0.08638918546161481, 0.053777102913175306, 0.05977902335247823, 0.038910933304578066, 0.0774746738108141, 0.06611622151519571, 0.031062898891312734, 0.06446970200964383, 0.030492786983294145, 0.006257457575494689, 0.030513987809951817, 0.11504384822079114, 0.11581596678921155, 0.2341281282050269, 0.1610106195190123, 0.23244300005691393, 0.29180433760796276, 0.09824433217623404, 0.07489683106541634, 0.10442132143569843, 0.15799922682344913, 0.1274842992424965, 0.2317991517484188, 0.12819122416632517, 10.818456377301898, 48.4731034551348, 53.21551997320992, 52.37419734682356, 38.9193686076573, 31.872172083173478, 23.98330725942339, 35.271918705531526, 47.08362007141113, 48.85279124123709, 7.363100716045924, 0.563762611576489, 11.91101370538984, 35.386122771671836, 10.859377792903356, 14.693233966827393, 11.922029205730983, 28.050412722996303, 30.05546133858817, 50.464286940438406, 44.88792678288051, 49.88697154181344, 48.69108928952898, 52.149447441101074, 44.688579491206575, 41.53328091757638, 42.915034430367605, 48.3072395324707, 48.08568579810006, 52.244134017399375, 45.44340399333409, 49.33505528313773, 48.91881997244698, 49.56899765559605, 43.25704908370972, 39.999823910849436, 39.38436985015869, 39.50617871965681, 40.12088932309832, 38.68767397744315, 37.41185964856829, 36.425059114183696, 36.26086623328072, 36.043464047568186, 34.27426855904715, 34.71162986755371, 35.95916155406407, 37.754666396549766, 35.345896175929475, 36.083562101636616, 34.296509742736816, 37.014009271349224, 36.62733507156372, 36.48072460719517, 36.52404662540981, 36.615839276994976, 35.86033385140555, 36.21678686141968, 36.00145871298653, 46.33923176356724, 46.342955998011995, 42.03917925698416, 43.95660414014544, 45.68248803274972, 45.85642228807722, 45.87177085876465, 46.71383694240025, 47.07146419797625, 49.129600524902344, 49.292435032980784, 48.949840205056326, 46.27772978373936, 48.055937085832866, 47.71470757893154, 52.11053058079311, 35.307291984558105, 41.49414866311209, 48.132975237710134, 46.8863468170166, 46.67486102240426, 46.842736448560444, 49.44778285707746, 46.72135141917637, 46.61781283787319, 49.72538423538208, 47.27595663070679, 48.04126943860735, 49.71763699395316, 46.3560985156468, 43.92136287689209, 42.279562609536306, 38.38501392092024, 37.13055835451399, 37.97344779968262, 37.70174196788243, 38.887910638536724, 36.63615928377424, 36.428574902670725, 37.700727530888145, 41.71890204293387, 39.33531904220581, 37.317579541887554, 37.65281970160348, 40.95296042306082, 36.653199740818565, 38.47363124574934, 38.634791237967356, 38.59414427621024, 41.20942538125174, 42.36047785622733, 44.1505492074149, 47.73326621736799, 49.02985913412911, 47.88529627663748, 50.910691329411094, 49.62765087400164, 47.028732776641846, 45.63048076629639, 43.38619177682059, 46.87556668690273, 49.85524606704712, 52.24543333053589, 52.22026348114014, 47.00689806256975, 42.49314676012312, 46.53307260785784, 53.46113184520176, 56.34042712620327, 55.90187420163836, 55.27926002229963, 56.20582662309919, 54.70275061471121, 57.79298278263637, 52.36912863595145, 49.86771808351789, 19.68961582865034, 6.656399003096989, 3.2515880124909535, 0.43830686062574387, 0.2633716304387365, 8.376837679318019, 59.50262873513358, 51.815642084394185, 42.61763416017805, 46.75997298104422, 36.31782756532942, 48.98551573072161, 58.720588139125276, 57.887207303728374, 14.795997823987689, 0.16020264716020652, 0.13731458889586584, 0.2561463995703629, 0.20023239989365849, 0.1825704454843487, 0.11405177574072566, 0.26515316484229906, 0.19588433392345905, 0.14796089833336218, 0.055533857217856815, 0.09806726846311774, 0.07953178164150033, 0.10429745486804418], [0.015600169776007533, 0.03165735663580043, 0.0217119365531419, 0.027463190889518176, 0.030570764227637222, 0.08380548695900611, 0.01688820226783199, 0.052791978631700785, 0.06292029443596091, 0.04399545404261776, 0.0667643920917596, 0.04360153053754142, 0.01674413062365992, 5.312910088471003, 35.66500956671578, 44.700585978371755, 37.402785301208496, 30.262965815407888, 19.351999385016306, 17.198945454188756, 29.794160434177943, 33.75246926716396, 38.50965418134417, 3.0888957253524234, 0.13187085171895369, 0.16344468747930868, 3.125411331653595, 4.830344234194074, 3.927503994532994, 13.03403627872467, 20.50485144342695, 16.825811556407384, 37.382333278656006, 47.898994650159565, 47.297614165714805, 47.00122833251953, 44.38134057181222, 36.73871469497681, 38.48422724860055, 42.76989351000105, 44.993403911590576, 46.08025503158569, 45.872788769858225, 45.956104619162424, 41.96055691582816, 45.40113810130528, 44.428289549691335, 43.48917102813721, 37.02353525161743, 34.2130514553615, 31.259559835706437, 31.52219479424613, 31.02380050931658, 32.57866839000157, 32.3552177974156, 30.80606828417097, 33.16321686335972, 32.519292558942524, 32.38776315961565, 31.652713230678014, 32.14294685636248, 32.595886026109966, 32.28532934188843, 31.20961618423462, 32.54015799931118, 33.796559061322895, 33.14106600625174, 33.342459542410715, 33.95624256134033, 34.18232652119228, 33.0802275793893, 32.82547882625035, 39.60223061697823, 44.50703001022339, 41.15543787819998, 46.01208625520979, 44.487147739955354, 46.85089363370623, 43.5338305745806, 47.06374822344099, 47.17247363499233, 45.99833229609898, 46.92053542818342, 45.44457129069737, 46.05122198377337, 44.43983745574951, 46.21646056856428, 46.47020878110613, 34.558463777814595, 42.199599266052246, 49.122621059417725, 47.017702511378694, 45.74548734937395, 45.08888258252825, 44.72258744921003, 40.355752331869944, 42.32985714503697, 45.164322648729595, 45.04273612158639, 46.20202568599156, 45.82514844621931, 43.491130420139854, 40.232699734824045, 35.75566618783133, 33.24876308441162, 33.028435707092285, 34.19465609959194, 33.92881454740252, 35.9747428894043, 33.74635485240391, 34.458784920828684, 34.716597829546245, 34.8643547466823, 35.67961120605469, 33.899597372327534, 35.892198290143696, 33.217708110809326, 34.84949949809483, 34.49077442714146, 33.44435487474714, 33.459484577178955, 33.34335238592965, 35.30758033479963, 36.76671246119908, 38.71256242479597, 40.78637388774327, 42.65621403285435, 47.33337654386248, 44.123861176627024, 47.20073890686035, 47.82423898151943, 44.97974375316075, 41.30998318535941, 47.752828870500835, 46.929432596479145, 51.21338612692696, 46.67235619681222, 42.50380529676165, 39.819518157414024, 44.608341693878174, 48.39025313513619, 53.875477245875764, 47.51266091210501, 49.88779490334647, 49.554760796683176, 50.19460998262678, 51.04086930411202, 45.64302226475307, 28.505170583724976, 5.928339830466679, 0.6314005564366068, 0.06239435515765633, 0.03288724206920181, 2.966912065233503, 41.51809562955584, 45.907904965536936, 27.916835342134746, 29.426340171269008, 27.113192796707153, 30.164218017033168, 42.265558515276226, 41.419872420174734, 14.312210389545985, 0.06491027479725224, 0.02247017399141831, 0.006733010115567595, 0.061933704518846104, 0.07176866249314376, 0.05541546642780304, 0.043664413770394664, 0.03126443736255169, 0.04085005746622171, 0.020712831057608128, 0.07814952438431126, 0.03585868262286697, 0.04596793498577816, 0.030158489742981534, 0.03216977949653353, 0.031830668050263605, 0.04308355047500559, 0.06454363518527576, 0.022355326850499426, 0.024097932003704563, 0.036349670562360964, 0.016053546519417847, 0.0512749880685338, 0.004604930066437061, 0.08375662565231323, 0.03909890786079424, 8.114579660551888, 43.77863992963518, 50.68567739214216, 45.24385520390102, 35.44159024102347, 20.947377000536235, 17.743017196655273, 30.40483066013881, 36.74798011779785, 43.91003731318882, 3.419642354760851, 0.12608570286205836, 0.08333682282162563, 5.446816640240805, 5.757367244788578, 5.811758177621024, 13.704011985233851, 21.42196502004351, 17.499609640666417, 39.88560247421265, 48.53195817129952, 48.68190029689244, 49.284461975097656, 46.593403816223145, 38.29666410173689, 40.886282035282676, 42.96862588609968, 46.89363200323922, 48.30111122131348, 47.37618439538138, 46.097587312970845, 42.93433652605329, 46.771645954677034, 45.866337367466514, 44.581570284707205, 39.02833373206002, 35.28014537266323, 33.29349211284092, 33.173493249075754, 32.33209071840559, 32.9685491834368, 33.76938118253435, 32.458933557782856, 35.30382830756051, 33.81680958611624, 33.60115834644863, 33.1640749658857, 33.16315432957241, 34.299636432102744, 33.18332495008196, 32.4615078653608, 33.42088385990688, 35.644508906773154, 34.54693671635219, 35.58797141483852, 35.30822304316929, 34.768188204084126, 35.44518593379429, 33.77145521981375, 41.607960156032014, 46.4941349029541, 42.82208490371704, 47.28082036972046, 45.37578412464687, 47.73361710139683, 44.694436822618755, 48.22838790076119, 47.60923739842006, 47.78365455354963, 48.15803391592843, 46.08974279676165, 48.27316209248134, 46.04233523777553, 47.13661745616368, 46.11157751083374, 36.499474321092876, 42.8491724559239, 49.80919688088553, 47.29071113041469, 46.43238626207624, 45.487306186131065, 45.333535603114534, 40.41415888922555, 42.163228920527864, 45.88406222207205, 45.890933990478516, 48.74286726542881, 47.12578868865967, 43.598167419433594, 42.013241631644114, 37.65475824901036, 36.001152992248535, 33.79865741729736, 36.26960359300886, 35.86609043393816, 37.82410669326782, 36.15751872743879, 36.885269573756624, 35.70554883139474, 36.586031505039756, 36.79323026112148, 36.31925194604056, 36.64936433519636, 35.31702641078404, 36.18438393729073, 35.27250235421317, 35.88790430341448, 34.88777017593384, 34.95052283150809, 37.39711904525757, 39.29595749718802, 41.690001010894775, 43.08510201317923, 43.8279686655317, 47.73544100352696, 47.05227674756731, 48.207880292619976, 47.56144074031285, 44.93941988263811, 43.59949105126517, 48.86655909674508, 48.82044390269688, 53.376607009342735, 47.942966324942454, 43.72513880048479, 41.055797236306326, 47.1903270312718, 51.72316156114851, 55.739373207092285, 51.01849610464913, 51.98717226300921, 50.091703687395366, 52.38247265134539, 49.72958442143032, 45.466194084712434, 27.123910393033707, 6.340634644031525, 1.1201297342777252, 0.04289672942832112, 0.030821001157164574, 3.3819996203695024, 45.453315598624094, 49.16910450799124, 29.181093079703196, 36.78018501826695, 30.520820413316997, 33.49736615589687, 48.63000420161656, 49.47113922664097, 17.46100718634469, 0.03526524268090725, 0.07415481231042317, 0.020783198531717062, 0.01061498317202287, 0.01529172811258052, 0.02979114106191056, 0.053392699254410605, 0.01838523881243808, 0.03875157596277339, 0.016581845403249775, 0.04308273284030812, 0.06194870014275823, 0.025255550064944794, 0.1303240225783416, 0.1443629799676793, 0.16075354974184716, 0.11242894389267478, 0.14301669863717897, 0.18542695577655519, 0.13769201721463883, 0.1559140615697418, 0.07975698062883955, 0.11455429877553668, 0.15535467730036803, 0.21342385347400392, 0.07912977678435189, 11.143331561769758, 52.221555846078054, 56.79566614968436, 50.95899520601545, 39.949974060058594, 27.253534248897008, 23.234234128679546, 39.891484124319895, 44.15155322211129, 48.14517280033657, 4.093426976885114, 0.24302274520908082, 0.6942340391022819, 4.941554061004093, 9.650225349834987, 7.246000553880419, 14.726696491241455, 22.82345836503165, 18.966395207813807, 42.15703460148403, 52.284961632319856, 50.475108759743826, 51.30323328290667, 49.26453801563808, 39.55542755126953, 41.31820290429251, 46.09433903012957, 49.481627532414024, 49.28353786468506, 48.12913288388933, 46.914424487522666, 44.04866777147566, 47.248702321733745, 47.50038691929409, 47.64953000204903, 40.918705804007395, 38.312610217503135, 35.561366762433735, 36.00034352711269, 35.14441578728812, 36.978295530591694, 34.89145272118704, 34.431343010493684, 36.653432505471365, 35.84820924486433, 36.11853585924421, 34.70381314413888, 34.86390658787319, 35.890172890254426, 34.247663906642366, 33.324296951293945, 36.195768560682026, 37.687404360089985, 37.28903981617519, 37.127101625714985, 37.071877343314036, 37.70328794206892, 37.5665717124939, 37.12844957624163, 42.255869252341135, 48.30983468464443, 44.15885925292969, 48.25542334147862, 47.05376713616507, 48.76743956974575, 45.67048849378313, 50.758233955928254, 49.371533325740266, 49.562528882707866, 51.16789279665266, 46.45117766516549, 50.77749783652169, 48.50787918908255, 48.83755036762783, 48.647531032562256, 40.01421363013131, 44.56713540213448, 49.56947013310024, 48.84764610018049, 48.52075072697231, 45.74947214126587, 46.97052424294608, 42.58052730560303, 44.38605839865548, 47.32286391939436, 48.05199745723179, 50.941940852573936, 50.18508052825928, 45.66761193956648, 44.00564799989973, 39.011598995753694, 37.15527309690203, 35.737833636147634, 39.78276218686785, 36.65295655386788, 40.3282722064427, 36.98600803102766, 37.12350593294416, 36.89503526687622, 37.73191104616438, 38.54481554031372, 37.13223287037441, 39.006617137363975, 36.791354247501914, 37.66892910003662, 38.31199530192784, 37.45460149220058, 36.43669734682356, 36.812528882707866, 38.20190804345267, 42.06103481565203, 43.24904475893293, 45.18141174316406, 46.812174797058105, 50.68229709352766, 47.99985122680664, 49.35181781223842, 49.06604535239083, 47.93259961264474, 43.9931447165353, 48.670348916734966, 50.77197054454258, 56.512297766549246, 50.32243251800537, 45.74856192725045, 44.48421212605068, 49.27817732947213, 53.0646641595023, 58.86440890175955, 52.93574033464704, 53.70667423520769, 50.6139372416905, 52.62985978807722, 51.69170011792864, 48.83840847015381, 30.31135654449463, 8.935034240995135, 1.4965499128614153, 0.28471375522868975, 0.09118422958999872, 4.371355354785919, 50.48287337166922, 58.020828110831125, 38.03130892344883, 36.79163564954485, 39.69596529006958, 40.289226804460796, 56.062363692692344, 57.92903198514666, 24.04445661817278, 0.192680685115712, 0.12889878691307136, 0.06423775838421923, 0.13944208116403647, 0.15495450448776993, 0.07235195155122451, 0.1516880640493972, 0.10735679284802505, 0.1576045501445021, 0.06358857679047755, 0.18707454736743653, 0.18782553635537624, 0.1288206468203238], [0.09984749329409429, 0.026621251067678844, 0.03689564358709114, 0.013749520643614233, 0.009688694662015353, 0.036963395308703184, 0.02216743371848549, 0.020419785353754247, 0.033424984464155774, 0.01711381007251995, 0.016218328748696616, 0.0525344270946724, 0.029444260389677117, 3.5934971400669644, 32.364080224718364, 41.767080851963584, 38.17950357709612, 30.433505875723704, 23.16594202177865, 27.20298957824707, 38.6894805090768, 38.8180638722011, 33.95825406483242, 2.1447286861283437, 0.07529178594372102, 1.9295151829719543, 6.981800947870527, 3.913933728422437, 5.782788966383253, 10.652133005005972, 37.87612438201904, 43.58880819593157, 46.89820739201137, 48.56823124204363, 47.55983918053763, 44.548128604888916, 42.66127232142857, 42.529930523463655, 45.04923268726894, 45.69870512826102, 45.692007064819336, 45.89052404676165, 46.85418013163975, 44.26858173097883, 42.29261132649013, 43.145613874707905, 43.963111128125874, 45.127260957445415, 38.84338310786656, 35.80086074556623, 33.238132340567454, 31.95044354030064, 32.647552830832346, 34.135551248277935, 34.60944618497576, 31.846689564841135, 31.606195041111537, 32.07274573189871, 32.02004017148699, 31.58057008470808, 31.964788096291677, 32.40634611674717, 33.786626611437114, 33.52311617987496, 32.863002572740825, 31.003230367388042, 32.08939708982195, 32.06609630584717, 32.89637129647391, 33.89672776630947, 32.07158885683332, 31.610770429883683, 34.14524745941162, 40.97033439363752, 41.589147908346995, 42.68590715953282, 44.4164845602853, 42.84104653767177, 42.61187062944685, 44.99720457621983, 45.27071693965367, 48.240251949855256, 46.05751357759748, 47.92918457303728, 46.89078671591622, 47.07848882675171, 44.26548630850655, 46.993633951459614, 33.99983555930001, 41.17581694466727, 48.85261058807373, 44.16490418570382, 44.852598667144775, 42.848689556121826, 47.79362521852766, 45.009885038648335, 47.44287667955671, 47.779155594961985, 46.42585148130144, 44.41680070332119, 44.71072687421526, 38.20356866291591, 37.11691556658064, 36.99660403387887, 34.47540501185826, 33.273359707423616, 33.84592948641096, 33.95200416019985, 33.455986159188406, 34.19316918509347, 34.19583034515381, 33.464980602264404, 35.02147783551897, 33.82371609551566, 34.95972919464111, 35.116226945604595, 36.19494867324829, 37.30086217607771, 35.0824100630624, 34.409383228846956, 33.04975972856794, 33.77596460069929, 34.1237393106733, 32.84001793180193, 37.29919113431658, 39.76111160005842, 42.136415822165354, 43.21589837755476, 44.50191266196114, 47.73895679201399, 45.50815078190395, 48.307507038116455, 48.82630123410906, 45.656237738473074, 49.306036131722585, 51.07311936787197, 50.394784109933035, 46.97842781884329, 40.19221258163452, 40.548891408102854, 47.089890820639475, 49.781143529074534, 50.47277069091797, 49.59014449800764, 50.51529366629464, 50.21594442640032, 53.41673285620553, 52.4434882572719, 29.21618495668684, 9.301336322511945, 0.7772320626037461, 0.05871474796107837, 0.058504510670900345, 1.1601654716900416, 40.32264763968331, 46.138543469565256, 42.31860801151821, 30.423014095851354, 45.9987005506243, 44.10887738636562, 38.942148276737754, 48.732038497924805, 16.431452648980276, 0.0518832472153008, 0.026708040785576617, 0.014529095463720816, 0.0660948883742094, 0.005557743782576705, 0.10696666913905314, 0.038613952097616026, 0.015694406415734972, 0.007465389856536473, 0.07160784969372408, 0.024028565368748138, 0.028667358149375235, 0.022182086682213203, 0.07157509680837393, 0.04341247371797051, 0.04686632213581886, 0.04533108576600041, 0.07388005312532187, 0.014203213753976991, 0.037619884724595716, 0.04877744994259306, 0.06225053287510361, 0.007557030251648809, 0.01989921328744718, 0.06017782552433865, 0.02909738989546895, 5.14905549798693, 39.90865659713745, 48.93654482705252, 43.278039591653005, 32.62030547005789, 26.734123400279454, 26.526931592396327, 34.602240903036936, 39.95402485983712, 40.91432843889509, 2.2271510405199866, 0.02227535640953907, 0.5400539466312954, 5.8210387996264865, 8.650329198156085, 6.436705214636667, 10.123153618403844, 41.559288024902344, 45.5110308102199, 48.31220402036394, 50.859080110277446, 49.23158270972115, 46.886520521981375, 43.28829860687256, 43.50004495893206, 46.49656677246094, 46.85846022197178, 46.46209328515189, 46.82866287231445, 47.934281076703755, 45.957056522369385, 43.671391010284424, 44.831399713243755, 45.190135206495015, 47.777147565569194, 40.6531526020595, 37.28355768748692, 34.423832007816856, 33.616305419376914, 35.18989174706595, 35.187529359545024, 36.389581612178254, 33.17612314224243, 33.08339595794678, 34.652865477970664, 35.095757552555625, 33.602680001940044, 34.2404898915972, 33.673676695142476, 35.44005816323416, 34.90064171382359, 34.147703647613525, 34.16610942568098, 34.88780491692679, 33.31877313341413, 33.75792012895857, 34.479605197906494, 34.28133487701416, 34.71154301507132, 36.19681773866926, 43.36292920793806, 43.40387494223458, 43.350387709481375, 45.978873865945, 44.818872111184255, 44.65163591929844, 45.97470147269112, 46.2942248071943, 49.08916548320225, 47.39066791534424, 49.65835843767439, 47.607917240687776, 46.44533423015049, 46.004467555454795, 48.76613678250994, 36.35880109242031, 41.49707385471889, 51.390381063733784, 46.35167251314436, 45.88262741906302, 44.53995057514736, 47.87819521767752, 45.61650793892996, 48.42749547958374, 48.31436491012573, 47.41991983141218, 46.29388434546334, 44.85109438214983, 39.62988792146955, 39.27938951764788, 38.22694935117449, 36.737325055258616, 34.64564977373396, 35.359000478472026, 36.38072960717337, 36.26177644729614, 36.016432080950054, 35.23787253243582, 35.729464530944824, 35.457449504307334, 35.19066299710955, 35.89659302575247, 36.677091121673584, 37.75077887943813, 38.56693513052804, 37.05554212842669, 36.254182066236226, 34.721451146262034, 34.51822328567505, 36.21363932745797, 34.95898921149117, 39.14235367093767, 42.05213417325701, 43.408776896340505, 44.819824014391216, 47.8021228654044, 50.488546575818745, 47.53810521534511, 48.7321948323931, 46.90590599605015, 47.52188811983381, 49.61865643092564, 52.54426145553589, 52.307821205684114, 48.56185279573713, 41.61439766202654, 42.80507223946707, 48.89163861955915, 52.99969155447823, 52.64208514349801, 50.91027791159493, 51.78448288781302, 50.7666551726205, 54.554733140128, 51.40130363191877, 29.379950523376465, 9.93218845980508, 0.3197190782853535, 0.1326831259897777, 0.06672621771161046, 1.6859278423445565, 42.844280924115864, 51.57371275765555, 43.99311692374093, 28.899482590811594, 47.51681246076311, 47.82148054667881, 46.21431704929897, 55.89588138035366, 21.865604025977, 0.06317751349083015, 0.10218463252697672, 0.07380312761025769, 0.009147144837437995, 0.019613514421507716, 0.08021458464541606, 0.02773012317317937, 0.02255347603932023, 0.05494906859738486, 0.05357837357691356, 0.046357844956219196, 0.012169614617180611, 0.0215123539590942, 0.19407344609498978, 0.1442993198122297, 0.11635069309600762, 0.08718990428107125, 0.07963634388787405, 0.07858422784400837, 0.10769739028598581, 0.11875596403011254, 0.11521971092692443, 0.14173239469528198, 0.0992144269070455, 0.16396701016596385, 0.12269005578543458, 7.592454671859741, 47.127355507441926, 54.53468063899449, 51.356473854609895, 40.12270975112915, 32.928524085453574, 34.70054054260254, 51.21523434775216, 48.072425161089214, 45.70918648583548, 3.2130580799920216, 0.3344399226563317, 4.187021817479815, 12.161964399474007, 10.5927380664008, 12.627634406089783, 13.440532820565359, 43.60774551119123, 46.738478728703086, 50.368328843797954, 51.7910280908857, 52.556160245622905, 48.35618264334542, 46.41602325439453, 44.60430826459612, 49.24708066667829, 50.82236235482352, 48.44967065538679, 47.724497590746196, 50.11318056924002, 46.60761635644095, 44.551540170397075, 45.66135508673531, 47.11893081665039, 49.78696264539446, 43.1439984185355, 38.92631680624825, 35.8638322693961, 35.33428921018328, 36.43997342245919, 36.16883039474487, 38.615760122026714, 34.32440676007952, 34.166755608149934, 35.57647214617048, 36.88158355440412, 35.44053411483765, 35.55372026988438, 36.124688489096506, 36.4767085484096, 36.70711428778512, 36.268234797886436, 35.30675349916731, 36.36531155450003, 34.23063734599522, 36.33526406969343, 36.79107979365757, 35.50716386522566, 34.8240829876491, 38.128142493111746, 44.35792861665998, 45.35161134174892, 44.1321816444397, 46.961227553231375, 46.275916303907124, 44.9077604157584, 46.81912299564907, 47.76570388248989, 50.16084173747471, 49.09023897988455, 50.20861060278756, 49.35304069519043, 48.13721016475132, 46.961647919246126, 51.20127889088222, 38.137258529663086, 42.66744579587664, 50.59024388449532, 48.11917264120919, 46.071406500680105, 44.77880184991019, 48.81562532697405, 48.08646052224295, 52.037800312042236, 51.06815835407802, 50.07701519557408, 49.28740106310163, 48.04960380281721, 42.077324867248535, 42.20176362991333, 41.13528115408761, 38.69285038539341, 35.96738127299717, 37.225766045706614, 37.21583359582083, 37.11585596629551, 39.21007776260376, 36.68421997342791, 36.82420533043997, 39.30252354485648, 36.82786355699812, 38.329007966177805, 38.823417459215435, 38.64844444819859, 40.9282283101763, 38.68968200683594, 38.19530725479126, 36.68694019317627, 36.74669470105852, 37.86669567653111, 37.506535802568706, 41.50093010493687, 43.84534611020769, 46.088089125497, 47.759238583701, 50.09963853018624, 53.534675053187776, 49.228577613830566, 49.54637084688459, 50.828553199768066, 48.98187140056065, 50.31760351998465, 54.22412395477295, 55.2297819001334, 52.07912124906267, 43.78863491330828, 45.49197884968349, 51.63398838043213, 54.514270305633545, 54.90381758553641, 54.65884494781494, 53.0087902205331, 51.44195406777518, 53.365562847682405, 49.23256240572248, 30.57262965611049, 11.592476146561758, 1.7906472917113985, 0.32527798999633106, 0.15947053501648562, 2.164626155580793, 47.66687617983137, 56.350439480372835, 57.20718363353184, 39.81794786453247, 54.96252291543143, 55.043281827654155, 52.28602123260498, 65.16019248962402, 28.338247060775757, 0.38458618468471933, 0.17653630141701016, 0.11765375174582005, 0.11373508987682206, 0.05200737501893725, 0.3112778312393597, 0.1212534885853529, 0.13586702942848206, 0.1532327083072492, 0.14082151571554796, 0.11563386156090669, 0.12149305215903691, 0.05516428294192467], [0.014520305042554225, 0.06007581456963505, 0.0276349722075143, 0.03814972557925752, 0.044589677692524025, 0.05304802042831268, 0.02805839162985129, 0.06604659703693219, 0.021477887772821953, 0.08284628271524395, 0.016010875148432593, 0.006258400739170611, 0.035387860744127204, 3.290997109242848, 33.586233615875244, 44.91616078785488, 40.18387474332537, 33.21400819505964, 15.408273083823067, 21.928846529551915, 34.63025951385498, 33.863598755427766, 35.164027077811106, 1.0898535017456328, 0.06451030554515974, 0.2543200547141688, 2.790650163378034, 5.886572905949183, 5.690508638109479, 8.33705403123583, 36.4214460509164, 48.44971234457833, 50.9305979183742, 51.102496351514546, 47.66314499718802, 44.56410946164812, 46.26073101588658, 47.1336783681597, 47.168867519923616, 45.79646628243582, 47.188916546957834, 46.03701639175415, 44.87401301520211, 40.96824993406023, 42.37498916898455, 42.45731837408883, 43.141761098589214, 45.06984799248831, 43.05028459003994, 36.59415047509329, 32.970390456063406, 33.87268352508545, 32.151142256600515, 31.20361988885062, 33.268798215048655, 33.40480572836739, 32.363729340689524, 31.562084402356827, 32.619777406964985, 32.885229860033306, 32.94642264502389, 33.56946413857596, 33.391277585710796, 32.610505035945344, 32.19133063725063, 32.16509076527187, 32.00822475978306, 32.73883826392037, 33.235311371939524, 35.70966216496059, 32.236139569963726, 32.95080001013619, 32.60312604904175, 37.88489300864083, 42.00834315163748, 43.00054243632725, 43.164606775556294, 43.531169414520264, 41.68195499692644, 43.57411275591169, 42.451235226222444, 43.928106103624614, 42.79680388314383, 43.84314700535366, 44.875399180821006, 46.43277883529663, 46.80236046654837, 46.781835487910676, 36.005405289786204, 41.65376615524292, 47.681175572531565, 43.158210958753315, 44.94841085161482, 45.57191092627389, 46.929807799203054, 45.63839129039219, 45.447569438389365, 42.829130377088276, 44.04167788369315, 40.73575973510742, 37.6098416192191, 34.10347488948277, 34.250279903411865, 32.73496464320591, 34.57079683031355, 32.956188338143484, 34.50200619016375, 33.415589332580566, 33.75708634512765, 32.654146671295166, 33.29209205082485, 34.0615633555821, 34.65075322559902, 34.41871118545532, 34.73724092755999, 35.49196120670864, 35.54369054521833, 36.28009189878191, 35.48620115007673, 34.43524442400251, 34.339640685490195, 33.7583509172712, 34.727496079036165, 35.27090426853725, 36.003921849387034, 37.18559503555298, 35.85890947069441, 35.96771478652954, 38.66134030478341, 41.528510979243684, 44.88137810570853, 44.70959779194423, 48.544120992933, 47.992816175733296, 51.58937399727957, 47.51014219011579, 48.519392354147776, 49.225774015699116, 40.17203153882708, 38.54626076562064, 43.78166239602225, 47.63599491119385, 50.32901593617031, 50.54892642157418, 48.969715527125764, 49.964551653180806, 45.5739780153547, 51.06170000348772, 38.469073227473665, 9.153104322297231, 1.2033530856881822, 0.1152492950537375, 0.10513533705047198, 0.47041877465588705, 33.85097387858799, 46.04801886422293, 35.41465207508632, 20.160863501685007, 27.992874690464564, 37.25369780404227, 39.66471924100603, 54.30864184243338, 16.18040554864066, 0.20996815604822977, 0.037385511943804364, 0.018089875911495516, 0.03203064928363476, 0.043891302309930325, 0.008835586153769066, 0.04965961332033787, 0.032636279107204506, 0.017925936761977415, 0.0312736213340291, 0.026501107960939407, 0.03384258544870785, 0.030721572028206925, 0.029153582773038318, 0.027709787478670478, 0.038381336722522974, 0.037016918150974173, 0.02277930097521416, 0.041858872797872336, 0.05340805110920753, 0.02251255528868309, 0.04774761020338961, 0.08249928669205733, 0.03064828346084271, 0.028377479507720897, 0.07028206012078694, 4.19523024559021, 40.47311782836914, 49.85386684962681, 46.442805085863384, 37.337680680411204, 21.638519525527954, 18.17984175682068, 37.818079130990164, 40.44987610408238, 38.51804413114275, 1.362782542194639, 0.031260162591934204, 0.18833510258368083, 2.882906172956739, 5.980210738522666, 4.674960366317204, 9.018396990639822, 36.949748856680735, 52.24196965353829, 52.03486122403826, 52.45007514953613, 48.559490408216206, 47.81378889083862, 49.839960030147004, 50.214551312582834, 47.92103781018938, 49.02680540084839, 48.6754732131958, 48.07357161385672, 45.93330757958548, 42.0545243535723, 42.17623594829014, 43.115719250270296, 44.65116344179426, 45.85732902799334, 43.692256450653076, 38.26742260796683, 33.77251829419817, 34.74748257228306, 33.87714426858084, 32.794677461896626, 34.53064319065639, 35.36750507354736, 33.81335285731724, 32.984717641557964, 34.18890993935721, 33.72431516647339, 34.71519429343087, 34.740110533578054, 34.576692376817974, 34.24816765104021, 34.15297385624477, 34.48834950583321, 33.64171150752476, 33.854201316833496, 34.84124503816877, 36.232680865696494, 33.96015092304775, 34.2440299987793, 34.08698681422642, 39.24472842897688, 42.83565820966448, 44.43189566476004, 44.68638733455113, 43.687941619328086, 42.67335523877825, 44.58892147881644, 43.93097570964268, 46.02742092950003, 44.47607231140137, 45.84815393175398, 44.4453786441258, 48.307566097804475, 48.21421357563564, 48.43201528276716, 37.8480223928179, 42.76912225995745, 47.90990679604666, 42.69919906343733, 45.95962735584804, 45.24009622846331, 48.01328556878226, 48.35400785718645, 46.064281123025076, 45.120830399649485, 46.813519273485454, 44.17872762680054, 38.267634528023855, 36.08408669063023, 35.08180209568569, 35.04240928377424, 35.429000105176655, 35.92506674357823, 35.61328022820609, 35.31422976085118, 36.48973642076765, 34.48796040671212, 34.45762457166399, 36.41809354509626, 36.8859817641122, 35.86868211201259, 36.23161084311349, 36.9161821092878, 38.16642011914934, 37.61025851113455, 37.060676847185405, 35.68973125730242, 36.49740375791277, 35.967332635607036, 36.557297229766846, 37.2024096761431, 38.197395188467844, 39.135287352970664, 38.14648573739188, 39.36823960712978, 42.050956453595845, 42.80383546011788, 46.94978387015206, 47.68018198013306, 50.73974827357701, 49.85540934971401, 51.199069363730295, 48.954547609601704, 51.19246162687029, 50.204156807490754, 42.0149439402989, 41.19360433306013, 45.657398087637766, 49.9178215435573, 54.134433133261545, 51.199489729745046, 50.77900559561593, 50.37953281402588, 47.967705386025564, 51.39552967888968, 36.152623721531455, 8.703264049121312, 1.6054977753332682, 0.28049372881650925, 0.09926365462264844, 0.40535481167691095, 36.795960903167725, 49.438701561519075, 40.83599444798061, 28.616541521889822, 38.01407739094326, 44.274449484688894, 45.36602537972586, 62.46784891401018, 21.09708115032741, 0.4047989015068327, 0.03089482237451843, 0.0499669421863343, 0.045865024972174845, 0.03037231309073312, 0.0876056087602462, 0.02592592909266906, 0.030552654127989496, 0.08566447613494736, 0.007765058910341135, 0.01372517819982022, 0.011915702572358506, 0.024917522578367164, 0.11206344421952963, 0.12054907424109322, 0.12823048420250416, 0.12001205448593412, 0.11371963284909725, 0.13317404607576983, 0.13659272263092653, 0.1377246683197362, 0.10937693409089531, 0.2167223071945565, 0.22192945278116635, 0.07669948826410941, 0.17071656084486417, 5.699269013745444, 47.92226069314139, 58.587175777980256, 51.84641913005284, 44.55841193880354, 24.684821707861765, 30.999606881822857, 45.50563553401402, 42.654751437050955, 44.490260532924104, 1.6920661415372575, 0.16750919366521494, 0.41477089641349657, 9.76517026765006, 13.313463296209063, 13.342943634305682, 11.816372292382376, 38.65392310278756, 50.998672894069124, 54.077596868787495, 55.008294173649375, 51.595147950308665, 49.58898762294224, 50.16740083694458, 50.8579614503043, 50.078265871320454, 49.48313181740897, 50.861616202763145, 48.79812976292202, 48.17899315697806, 43.43294620513916, 42.20166288103376, 43.19959790366036, 45.21913698741368, 48.41313007899693, 46.48863192967006, 40.448132106236045, 35.94710642950875, 37.19816085270473, 36.40888718196324, 33.534775257110596, 37.44543334415981, 36.91551855632237, 35.84891101292202, 34.51476308277675, 36.93589762278965, 35.32392597198486, 36.49422148295811, 38.010995864868164, 36.88211161749703, 36.014493533543174, 36.75443499428885, 35.66595452172415, 35.7924291065761, 35.446860449654714, 36.40798044204712, 38.65480204990932, 36.028139795575825, 36.67576054164341, 36.241977555411204, 41.69986745289394, 45.31123883383614, 45.022704465048655, 46.13722331183297, 44.82200574874878, 43.241002219063894, 46.2179023197719, 44.193989345005576, 45.920224121638704, 43.61265788759504, 45.3697635105678, 46.16937610081264, 49.749706404549734, 49.48083543777466, 49.661700521196636, 41.35775899887085, 43.92293316977364, 49.37931530816214, 45.104648045131135, 47.42811175755092, 46.78093569619315, 49.432264055524556, 50.5812702860151, 48.594853264944895, 46.20912674495152, 48.039567129952566, 44.51591328212193, 40.05714654922485, 37.05220004490444, 37.06263623918806, 35.69693653924124, 37.85292434692383, 37.22774975640433, 37.47679056440081, 36.64754738126482, 37.14233207702637, 36.339565004621235, 36.22817843300955, 38.46139546803066, 38.535282611846924, 37.006456579480854, 37.86314167295183, 38.87850277764456, 39.146637235369, 39.716333934238975, 38.64024557386126, 38.99423892157418, 38.670306955065044, 37.885549613407676, 38.50505099977766, 38.99549307141985, 40.21003818511963, 41.412076541355674, 39.311629159109934, 41.10812064579555, 43.22123111997332, 45.39472838810512, 48.42933675221035, 50.6198536327907, 53.10954257420131, 51.243016719818115, 54.43965360096523, 52.16658864702497, 54.09377922330584, 52.9016489982605, 43.852773734501426, 43.55979251861572, 47.84491334642683, 51.92624698366438, 55.50649043491909, 53.43926586423601, 52.86453519548689, 51.22201926367623, 49.18268476213728, 53.56568486349923, 36.009178161621094, 10.696084703717913, 3.150793969631195, 0.407309888196843, 0.3633622064122132, 0.8227734331573758, 42.73299857548305, 55.43934651783535, 46.06776564461844, 31.56476640701294, 38.829945291791645, 50.244376455034526, 51.51740108217512, 69.83844239371163, 28.182409388678415, 1.1258068467889513, 0.2496917402105672, 0.11298163102141448, 0.12211739937109606, 0.07332414295524359, 0.22456495064709867, 0.14069832089756215, 0.09887661824801139, 0.24685825939689363, 0.07210628116237265, 0.12303418160549232, 0.1707613712974957, 0.07604053576609918], [0.02023268780404968, 0.053538950692330084, 0.04681484507662909, 0.03732094933677997, 0.023333219645012702, 0.04010379447468689, 0.03898008959367871, 0.011849712497288627, 0.02269994460844568, 0.0720899895365749, 0.081750021183065, 0.050594773675714216, 0.0438255488739482, 1.9982404666287559, 31.78614296231951, 48.31778689793178, 35.892264298030305, 35.31020327976772, 21.484952177320206, 25.273912566048757, 29.42850453513009, 36.72294575827462, 34.029493944985525, 1.553899041243962, 0.0783791881320732, 0.6330987938812801, 1.7449446469545364, 6.501628748008183, 3.4142716143812453, 3.138670231614794, 26.8423068523407, 48.31919043404715, 50.65472664151873, 49.376310212271555, 48.919990743909565, 48.78983013970511, 48.00350250516619, 47.0721173286438, 42.81864207131522, 45.40979903084891, 43.09810209274292, 41.1959285054888, 42.08566270555769, 44.20905303955078, 46.04964821679251, 46.44200604302542, 44.51049368722098, 44.54909093039376, 42.55493361609322, 36.588456426348, 33.58834934234619, 32.13191311700003, 31.780066762651714, 32.16779708862305, 30.825040340423584, 31.21879128047398, 30.615135260990687, 30.616851466042654, 31.701632022857666, 31.568212713514054, 33.649090494428364, 32.83077335357666, 33.77872998373849, 33.13554566247122, 31.994213717324392, 32.321668420519146, 32.65775278636387, 31.23470960344587, 31.970791339874268, 32.72412197930472, 31.111038616725377, 33.30187164034162, 31.156042098999023, 33.76023735318865, 36.8145751271929, 42.16408702305385, 45.763111455099924, 45.29724863597325, 44.62543078831264, 45.52473613194057, 45.41010127748762, 46.41932364872524, 44.7800247328622, 42.08760125296456, 42.801629407065256, 44.94185522624424, 42.926714352199006, 46.43327215739659, 36.17105034419468, 38.30745465414864, 47.29091262817383, 41.85920354298183, 44.94633681433541, 44.112723214285715, 45.385984080178396, 44.464510508946006, 39.94322041102818, 38.38134527206421, 36.44343709945679, 34.63407754898071, 34.15158074242728, 33.337741715567454, 33.19802039010184, 32.26763228007725, 33.47311346871512, 32.58204868861607, 34.0362024307251, 33.443208421979634, 34.40617663519723, 33.53068971633911, 34.455783299037385, 34.24304682867867, 33.39689867837088, 33.44216619219099, 35.30607952390398, 34.52022089276995, 35.93736852918352, 33.88449893678938, 34.92128481183733, 33.231788635253906, 35.57723992211478, 35.74933637891497, 34.48104347501482, 37.077467169080464, 36.42496531350272, 35.86018099103655, 35.38012300218855, 35.64203882217407, 35.97605609893799, 37.03016035897391, 40.06561640330723, 40.58227750233242, 43.9909907749721, 46.35790157318115, 48.795854227883474, 47.79225294930594, 50.97436809539795, 49.48063394001552, 45.7122471673148, 40.17675631386893, 42.39888749803816, 46.24628571101597, 51.01035976409912, 49.593097482408794, 49.826404094696045, 50.8805569921221, 53.16497530255999, 45.158249923161094, 29.59559828894479, 8.95264184474945, 0.11125810457659618, 0.11243423646582024, 0.059291448444128036, 0.21589384307818754, 31.18704843521118, 50.053165503910606, 43.30865682874407, 23.23635506629944, 23.08204426084246, 43.74666084562029, 38.14665944235665, 51.320374488830566, 23.39443700654166, 0.21366317277508123, 0.04044190508180431, 0.05960080612983022, 0.03420459745185716, 0.03787003344457064, 0.05597338506153651, 0.013616968827721263, 0.01931891487246113, 0.023574403221053735, 0.033931629599205086, 0.01423357819606151, 0.07084619413529124, 0.037458739443016906, 0.09448019987238304, 0.014822326068367277, 0.03551803429477981, 0.06506182559366737, 0.010899488664498287, 0.02945015685898917, 0.013095873441281063, 0.021549154305830598, 0.03738028043881059, 0.06964346367333617, 0.042549200755144866, 0.005052141046949795, 0.029426794898297106, 2.9753341504505704, 37.719654423849924, 53.650682176862446, 41.1701055254255, 40.591209411621094, 21.73830607959202, 26.501494237354823, 34.31285537992205, 38.16581562587193, 37.722440651484895, 1.7415020316839218, 0.025654951043959175, 0.23297483580453054, 4.689542029585157, 6.612484650952475, 7.566694225583758, 7.0450382402965, 29.616005148206437, 49.2390068599156, 49.92848355429513, 50.70223147528512, 50.5197822025844, 49.55946820122855, 48.739268098558696, 48.47282205309187, 43.23756980895996, 44.832198756081716, 44.08765063967024, 41.857584612710134, 42.79121058327811, 45.02721037183489, 46.652977670942036, 45.870634828295024, 47.35767439433506, 45.84909888676235, 44.63060024806431, 38.69596317836216, 34.90866688319615, 34.03427083151681, 33.01790223802839, 32.33478661945888, 31.52558204105922, 32.002860750470845, 31.667474678584508, 33.6771125793457, 33.69726235525948, 32.785544054848806, 36.23056166512625, 36.6228152683803, 35.70336709703718, 34.73064013889858, 34.23408365249634, 32.6658022744315, 34.422821044921875, 33.64886120387486, 33.39476558140346, 34.229278973170686, 33.24177319662911, 34.40637813295637, 32.18123837879726, 34.857917240687776, 39.03662988117763, 43.46633577346802, 47.696051665714805, 46.736849376133506, 46.04077189309256, 47.54509162902832, 46.17349985667637, 47.44043091365269, 44.89375284739903, 43.07891811643328, 43.66827474321638, 46.91124221256801, 45.114278248378206, 48.42248582839966, 39.00985847200666, 39.80485051018851, 48.28540481839861, 42.13827099118914, 45.00985377175467, 47.23078639166695, 47.19613225119454, 45.868303707667756, 42.89604500361851, 40.66124030521938, 38.68009001868111, 36.96215486526489, 36.542038985661094, 35.19156626292637, 35.17829520361764, 34.03015749795096, 34.27439362662179, 35.47464976991926, 34.74656193596976, 34.60845954077584, 36.75581073760986, 35.296775885990684, 37.03620181764875, 36.217002255576, 35.400915486471995, 36.359586238861084, 36.864185265132356, 36.39814179284232, 37.34673765727452, 35.5789908681597, 35.64528363091605, 35.00427756990705, 36.05601944242205, 37.04153803416661, 36.3375118119376, 37.65433440889631, 37.8926020349775, 36.305845396859304, 37.84683425085885, 37.79362842014858, 36.51543780735561, 38.7511179787772, 42.40873656954084, 43.356981549944194, 44.849287850516184, 49.10254771368844, 50.297464166368755, 49.08669887270246, 52.651156016758506, 51.64753041948591, 47.602671350751606, 40.152795451028005, 45.354647704533164, 48.14147635868618, 53.99391276495797, 52.42755256380354, 50.62524890899658, 52.908958503178184, 53.67066519601004, 48.161403792245046, 32.56605393545968, 9.35026901108878, 0.7990219933646066, 0.46164363409791676, 0.06003654096275568, 0.22481849204216683, 34.61214556012835, 54.503146239689414, 43.45526729311262, 23.981709173747472, 25.47870203426906, 47.40150710514614, 43.447700704847065, 57.456064632960725, 28.18978316443307, 0.8870430216193199, 0.0373615969770721, 0.06575600084449564, 0.041122709800090106, 0.022529606873701726, 0.021172582637518644, 0.01210148970130831, 0.04883776152772563, 0.03637089513774429, 0.01814807894905763, 0.037667361819850545, 0.03420214794043984, 0.03509221285847681, 0.280030967933791, 0.0881095974306975, 0.10580732420619045, 0.09660987702331372, 0.13404791775558675, 0.18046989105641842, 0.10669070894696883, 0.13253682026905672, 0.23583296101008142, 0.2215781616313117, 0.1701064628681966, 0.07004252368850367, 0.09090003198278801, 4.231515909944262, 46.0827077456883, 61.47763334001814, 47.02154833929879, 45.3360195841108, 29.774305956704275, 34.69144187654768, 41.9244783946446, 44.94713238307408, 45.234204156058176, 2.6870323291846683, 0.20630375482141972, 1.1351658531597681, 9.143716437476021, 14.394648160253253, 6.527382680347987, 4.773359017712729, 31.537692751203263, 50.98590905325753, 52.16320487431118, 52.519345215388704, 51.74008389881679, 51.790131773267476, 50.22442817687988, 48.99410717827933, 42.568169934409006, 46.98357990809849, 43.404938016619, 43.297557081495015, 43.008039542606895, 44.96460015433175, 47.92334808622088, 49.08714355741228, 49.3364622933524, 48.22572674070086, 46.39087077549526, 40.28483206885201, 37.076841831207275, 35.27218273707798, 34.49559300286429, 34.687929562159944, 33.41460963657924, 34.54513018471854, 33.015623228890554, 34.48639358792986, 35.315813950129915, 33.6601242337908, 37.20429263796125, 38.16894578933716, 38.14044427871704, 36.6046005657741, 35.399035998753135, 34.6940405028207, 36.52969203676496, 34.29296268735613, 35.39477327891758, 36.07659305844988, 34.50299630846296, 36.978851386478965, 33.899100576128276, 37.76331690379551, 39.42577069146292, 46.524620124271934, 50.1102796963283, 48.83836678096226, 47.062664304460796, 48.00890472957066, 48.429590361458914, 50.24459184919085, 48.17528976712908, 45.028467995779856, 45.73770536695208, 47.85694415228707, 47.15320628029959, 49.55271455219814, 41.832758699144634, 42.77910334723336, 47.72275011880057, 43.96919775009155, 45.82375880650112, 47.072405678885325, 49.00109011786324, 48.39168446404593, 44.15457568849836, 41.41161101205008, 40.51356329236712, 38.55404622214181, 38.144081660679404, 36.67413466317313, 36.372905935559956, 35.149053709847585, 36.32500505447388, 36.32166644505092, 37.47178438731602, 36.356456075395855, 37.844801902770996, 36.717043263571604, 38.517825262887136, 37.63054377692086, 36.82875987461635, 37.59558391571045, 39.55859592982701, 38.668076583317344, 39.07443502971104, 36.602436201913015, 37.188079016549246, 37.0527663230896, 38.526065826416016, 39.02076366969517, 38.04760592324393, 39.29396683829171, 40.42661353519985, 40.06415033340454, 40.003749643053325, 39.455297061375205, 38.352270535060335, 41.22296742030552, 44.344337940216064, 45.363447598048616, 48.93752452305385, 52.56155204772949, 51.92969676426479, 52.28903675079346, 55.65276043755667, 54.521413053785054, 50.601559025900706, 42.3534289087568, 46.100321429116384, 50.01350518635341, 55.81387526648385, 53.94605704716274, 52.13240350995745, 53.720344815935405, 55.53278936658587, 54.239691393715994, 35.73256342751639, 10.797918370791844, 1.1280487264905656, 0.392976704452719, 0.14158024000270025, 0.5036091251032693, 37.952419076647075, 59.99809088025774, 54.312650953020366, 32.86844301223755, 32.16251993179321, 54.88904571533203, 53.17361191340855, 63.44692652566092, 34.42305728367397, 1.9304764228207725, 0.21940539750669683, 0.15809876791068486, 0.16241193003952503, 0.16487296298146248, 0.15622146507459028, 0.1122232595724719, 0.0674597615642207, 0.10929103155753442, 0.08046309809599604, 0.1354804951697588, 0.11636731720396451, 0.1776298148823636], [0.025763815202351128, 0.03246385318094066, 0.06510110598589693, 0.0138694720642109, 0.05967245264244931, 0.033927918012653074, 0.03255631036258169, 0.052236387373081276, 0.026429539479847466, 0.06693869416735002, 0.03533317082162414, 0.018201910524762104, 0.03588272990392787, 2.042523507561002, 33.202623571668354, 44.67668417521885, 40.210712160382954, 29.591460636683873, 17.992160490580968, 19.081714459827968, 31.324386528560094, 35.75119849613735, 33.19791964122227, 1.9242247811385562, 0.004699296475986817, 0.22178193926811218, 1.3047976536410195, 3.600439258984157, 5.212302344185965, 6.424216261931828, 19.67571595736912, 46.61454023633684, 44.489371163504465, 47.81994846888951, 47.05915199007307, 48.54456220354353, 48.57565886633736, 47.91926949364798, 45.972002097538535, 47.902103969029014, 45.054568903786794, 47.05808891568865, 45.75335965837751, 45.97559431621006, 44.28610856192452, 45.08740609032767, 42.370552744184224, 41.026632172720774, 37.776643548692974, 32.70465660095215, 31.228855746132986, 31.499317850385392, 30.614430018833705, 32.18360424041748, 33.040025302342, 33.29357896532331, 33.61288343157087, 32.00917318889073, 31.26214109148298, 33.670553479875835, 33.277973311288015, 32.880640574863975, 33.70290776661464, 33.355338028499055, 31.260129587990896, 33.91105147770473, 32.720130239214214, 32.16355173928397, 31.046333517347062, 33.2125803402492, 32.12330429894583, 31.747170516422816, 31.386166436331614, 32.60841710226876, 33.877095631190706, 39.915802819388254, 42.120577403477256, 44.73478153773716, 42.95657423564366, 42.78671857288906, 41.67746646063668, 43.93559973580496, 44.705929143088206, 46.48558861868722, 43.78658866882324, 44.555709089551655, 42.34602907725743, 41.96445485523769, 35.70323160716465, 36.52671820776803, 44.23411866596767, 42.61260713849749, 43.80785363061087, 44.627525670187815, 42.42604800633022, 41.09746905735561, 39.97852073396955, 37.12505885532924, 37.56589773723057, 35.92380564553397, 36.89204406738281, 32.12126152856009, 32.0052752494812, 32.91518701825823, 32.41853673117501, 33.295260429382324, 33.50899396623884, 32.893831729888916, 32.75737258366176, 32.799478667122976, 33.57053763525826, 33.83843585423061, 34.75830439158848, 34.6818915775844, 34.73812682288033, 33.57582868848528, 33.586525440216064, 35.2332797731672, 36.17381572723389, 33.82520301001412, 34.38154179709298, 34.70355258669172, 35.76912832260132, 36.10767582484654, 34.29041617257254, 34.83336230686733, 35.2767060143607, 35.51045036315918, 35.7775947025844, 34.65335532597133, 36.45130940846035, 38.24545587812151, 40.96446663992745, 44.64970779418945, 45.671051297869, 48.74916928155081, 51.03287887573242, 48.47310692923409, 46.89168650763375, 39.587021010262625, 40.16196359906878, 47.438565322331016, 50.376013551439556, 51.657987458365305, 50.18848514556885, 49.647046770368306, 53.82352556501116, 54.050839356013704, 40.029159205300466, 6.953491381236485, 1.2730602366583688, 0.216103551111051, 0.08488566721124308, 0.0645504883889641, 27.793515239443096, 51.3544727734157, 34.84510823658535, 26.972745384488785, 27.427989619118826, 40.86345720291138, 43.7245169367109, 51.05975103378296, 27.86974913733346, 0.9294446749346597, 0.007261910775144185, 0.059540029748209884, 0.04869710121835981, 0.032970036912177286, 0.04606443962880543, 0.023245293380958692, 0.0471283587893205, 0.03269749992926206, 0.03207856064130153, 0.03268697585112282, 0.008484978627945696, 0.06948226410895586, 0.052773651400847096, 0.010602662672421761, 0.026523920308266367, 0.021230302218879973, 0.058051446053598604, 0.014965988895190614, 0.009703611406231565, 0.05160817251141582, 0.07919617143592664, 0.033022752297776084, 0.03926340171269008, 0.04415796996493425, 0.03589177816840155, 3.238191234213965, 40.030597482408794, 49.1185633114406, 46.38993624278477, 34.66157157080514, 24.19122862815857, 24.215748820986065, 31.649016789027623, 40.590285301208496, 37.050918102264404, 2.4395922124385834, 0.04464353980230434, 0.5164641610213688, 4.879056751728058, 6.242179104260035, 8.260464038167681, 6.864345124789646, 22.993583270481654, 45.16939830780029, 48.19120461600167, 48.101308822631836, 48.722092151641846, 47.790550640651155, 50.1509370803833, 48.729825496673584, 46.28111355645316, 49.13526678085327, 45.99008478437151, 47.11610637392317, 45.899320466177805, 46.274029867989675, 46.9013340813773, 46.92460707255772, 44.05469880785261, 44.60310622623989, 38.936360427311485, 34.21818617412022, 33.33191565104893, 33.15832880565098, 31.561212403433665, 33.9345919745309, 33.94004283632551, 34.35696601867676, 34.15455804552351, 33.011103425707134, 32.80906023297991, 34.69798013142177, 34.47147927965437, 35.33392442975725, 34.79870121819632, 34.95059926169259, 32.88537924630301, 35.230156557900564, 33.400348458971294, 33.08285747255598, 32.85769067491804, 34.40729182107108, 34.392155170440674, 33.61805983952114, 33.039128984723774, 33.51723452976772, 35.8869628225054, 41.782432896750315, 44.51416233607701, 45.17776393890381, 46.17525775091988, 46.09780618122646, 44.108488287244526, 46.18448495864868, 46.27064956937517, 47.6892980166844, 46.34307411738804, 44.64525747299194, 44.054848194122314, 43.05390807560512, 36.86394555228097, 38.04998220716204, 45.712757859911235, 42.81014095033918, 43.85616445541382, 46.548580987112864, 44.29394612993513, 44.03330183029175, 41.712836265563965, 38.594092164720806, 37.978283745901926, 38.13708482469831, 36.544484751565115, 34.505084242139546, 34.51507922581264, 33.93260131563459, 34.6832013130188, 35.185531752450125, 35.160278524671284, 34.07104764665876, 34.51386676515852, 34.39836685998099, 34.57677575520107, 36.28880146571568, 35.761023248944966, 36.314113753182546, 36.063269887651714, 35.76498372214181, 36.243804931640625, 36.9726779120309, 36.48136731556484, 35.97296067646572, 35.244459424700054, 36.8933607510158, 37.711337430136545, 39.475999219076975, 36.68486615589687, 35.50074372972761, 36.63646500451224, 35.798109258924214, 37.317169598170686, 37.28662184306553, 38.423590319497244, 39.90848289217268, 44.01237733023507, 47.37902968270438, 49.12730414526803, 51.06903730119978, 52.63527243477957, 50.51321268081665, 47.44739648274013, 42.4467362676348, 42.077092102595735, 48.77582951954433, 52.54752363477434, 52.5806839125497, 51.284160477774485, 50.35312271118164, 55.46882425035749, 54.74508598872593, 40.34388828277588, 9.165581549916949, 1.5983170292207172, 0.6113393700548581, 0.07159637566655874, 0.12973979035658495, 31.0348516191755, 55.4774295943124, 41.20212629863194, 34.02284104483468, 31.506953920636857, 47.283929688589915, 48.1183180127825, 56.27912664413452, 33.27857780456543, 1.3150920612471444, 0.009887823485769331, 0.02923176357788699, 0.03272518076534782, 0.03790821800274508, 0.05577426556763904, 0.024896547364603196, 0.05164880318833249, 0.040431221547935686, 0.03992855941344585, 0.01333000958298466, 0.018912051704579165, 0.027172297838010957, 0.12662132483507904, 0.1483144557901791, 0.1898524561630828, 0.07663975682641778, 0.22507809954030172, 0.103144277818501, 0.12136330269277096, 0.14951669770692075, 0.12900250777602196, 0.12979237682053021, 0.14989333892507212, 0.14993950644774096, 0.1535389447318656, 4.308760336467198, 48.661472593035015, 55.066641671316965, 54.05952113015311, 39.736084188733784, 26.432804346084595, 29.02339502743312, 41.08023057665144, 47.974059513636995, 44.31911250523159, 2.67037576011249, 0.09017796215734311, 0.7559886510883058, 4.298617269311633, 9.23033354963575, 12.074608172689166, 9.912096006529671, 21.474479504993983, 48.35792664119175, 46.64013739994594, 48.96210030147007, 49.54425859451294, 50.26994929994856, 51.37655067443848, 51.31140089035034, 47.1754127229963, 51.42231151035854, 46.92481204441616, 48.94328110558646, 48.08556420462472, 48.318335805620464, 48.380497864314485, 49.22185870579311, 45.08820513316563, 45.535509313855854, 42.83540112631661, 36.37569216319493, 35.99082449504307, 34.948719773973735, 32.786211081913535, 36.45739950452532, 35.04888153076172, 37.26937641416277, 37.033408641815186, 35.920039721897666, 35.08805200031826, 38.159690788814, 36.72069454193115, 36.80851629802159, 36.47751106534685, 36.9218726839338, 34.67430067062378, 37.09236063276018, 36.24619163785662, 35.01361247471401, 33.45989452089582, 36.29224082401821, 35.24582127162388, 35.7677595274789, 34.89550699506487, 35.44074603489467, 37.39139025551932, 43.756978920527864, 45.660378864833284, 48.377378123147146, 47.96782003130232, 47.06175756454468, 46.3553272656032, 47.76889310564314, 47.56514065606253, 48.90446499415806, 47.85873678752354, 47.60755940846035, 46.761939321245464, 44.74012817655291, 38.78442416872297, 40.2212039402553, 44.77274649483817, 43.38832139968872, 46.24989530018398, 47.71752854755947, 46.01392752783639, 44.73902688707624, 43.534250940595356, 40.352382455553325, 40.816025325230186, 38.83261340005057, 38.87803724833897, 34.80827236175537, 36.17166873386928, 35.52529866354806, 36.66042934145246, 36.91146428244454, 37.3111628804888, 34.92911890574864, 36.95956318719046, 35.24236454282488, 36.50832980019705, 37.64478063583374, 37.27397264753069, 37.98082678658621, 38.005465098789756, 36.830020972660606, 36.20459624699184, 39.26774781090872, 39.02246945244925, 38.04442712238857, 36.723835127694265, 38.43168844495501, 38.968398571014404, 41.09875099999564, 39.50333343233381, 37.91991192953927, 39.7588186945234, 39.39416333607265, 38.814499446323936, 37.75324201583862, 41.01481328691755, 42.870812620435444, 45.460784912109375, 48.87749208722796, 50.739842074257986, 53.228308132716585, 56.13446862357003, 51.96549735750471, 49.94239384787423, 43.895925521850586, 43.78845773424421, 50.551240171704976, 56.0905316897801, 56.3115747315543, 53.402127742767334, 51.191822392599924, 57.89361354282924, 56.24499361855643, 42.932682854788645, 8.715241874967303, 3.5273780822753906, 1.0178069791623523, 0.16454662834959372, 0.29972151134695324, 35.39363724844796, 61.88044820513044, 46.80188798904419, 38.160187585013254, 37.08969599860055, 53.58068602425711, 55.329564980098176, 65.67367826189313, 40.3244229044233, 2.3975158759525845, 0.17949850032372133, 0.1412988786718675, 0.11484070840690817, 0.11316954450947897, 0.0835176252626947, 0.1945067856992994, 0.11706300558788435, 0.16618537184383186, 0.21278289572468825, 0.23950131131070002, 0.13198907966060297, 0.1607948453830821], [0.03160381343747888, 0.03690172665353332, 0.058098441388990195, 0.06649684573390655, 0.01650514719741685, 0.03103044456137078, 0.04276910377666354, 0.04934089524405343, 0.017823734121131043, 0.04477972856589726, 0.025738670390897563, 0.09321644197085074, 0.056342582750533304, 3.580239760024207, 27.527376651763916, 44.58924457005092, 36.64508424486433, 21.875229018075125, 10.648091759000506, 27.078809635979788, 41.13320016860962, 33.94862386158535, 35.34586838313511, 2.1926115453243256, 0.0860010227188468, 0.19117356384439127, 6.3746960163116455, 6.839821023600442, 10.153221079281398, 5.694660186767578, 23.06062991278512, 42.03889438084194, 46.86234426498413, 48.049308504377095, 48.84057978221348, 47.32891927446638, 48.007049560546875, 47.35931069510323, 46.65105996813093, 46.890713759831016, 46.75809349332537, 46.50165980202811, 46.27448150089809, 44.1201091493879, 43.52992568697248, 40.98406750815255, 36.55163792201451, 35.941777161189485, 31.952201434544154, 30.85002953665597, 32.459593636649, 32.84446477890015, 34.764766216278076, 36.558481897626606, 37.86973551341465, 38.26194742747715, 37.53719472885132, 36.353259904044016, 34.10876941680908, 35.12971339906965, 36.251187392643516, 33.39621775490897, 33.853197302137104, 33.28643274307251, 32.00967345918928, 31.429676055908203, 31.992789336613246, 31.27291774749756, 32.30703204018729, 33.65953016281128, 31.858911446162633, 32.725285802568706, 30.85510172162737, 31.835551602499827, 31.681631633213588, 33.278796672821045, 35.57406806945801, 36.98393051964896, 36.22341544287545, 38.91958747591291, 38.511109828948975, 41.94847052437918, 42.47101674761091, 43.41077102933611, 42.25442055293492, 45.03044475827898, 41.997497013636995, 41.32391084943499, 35.680354663303916, 36.97470678601946, 41.84563718523298, 43.75871249607631, 45.28758021763393, 44.31102480207171, 45.563045024871826, 44.54293482644217, 45.75576720918928, 43.28060695103237, 44.159922327314106, 41.7746787071228, 43.24948596954346, 40.20817954199654, 35.229263714381624, 33.39720787320818, 31.77403572627476, 33.90406158992222, 33.67952707835606, 34.48084545135498, 34.179422174181255, 34.842207363673616, 33.32607569013323, 33.72325904028756, 33.02139718191964, 34.89466973713466, 34.02062456948416, 33.845898219517295, 35.824821608407156, 33.67744261877877, 33.69636256354195, 34.12004634312221, 32.740050724574495, 33.87582063674927, 33.95431096213204, 35.98079129627773, 34.87344299043928, 34.75723089490618, 35.25692449297224, 35.52590315682547, 35.57313701084682, 35.162310872759136, 36.97279603140694, 35.79493740626744, 34.81594317299979, 37.63276720046997, 42.29500845500401, 47.2671845299857, 50.185771874019075, 50.09755059650966, 46.483761242457796, 38.258226667131694, 40.061721937997, 46.923144476754324, 51.33745663506644, 51.10981975282942, 53.049260003226145, 54.592183930533274, 53.133958544049946, 52.39856120518276, 36.28599091938564, 7.3463659797395975, 0.6821591556072235, 1.1422036183731896, 0.11140710408134119, 0.031499505641737154, 25.4993451322828, 50.68685163770403, 39.101477418627056, 24.45549988746643, 20.743555068969727, 43.37916714804513, 37.78724997384207, 47.492417335510254, 26.66911084311349, 1.9806154923779624, 0.11960154079965182, 0.04940935264208487, 0.04010189457663468, 0.042071142300431214, 0.011092468264645763, 0.07862244972160884, 0.01642367210505264, 0.06198405860258, 0.00788235810718366, 0.059652442644749365, 0.02337622519449464, 0.05762791806565864, 0.02254740145456578, 0.010742960813721376, 0.04070846077853015, 0.02729854775991823, 0.023444105837760226, 0.04729791111978037, 0.028707544385854687, 0.05056627181225589, 0.032023656980267594, 0.061509511566587856, 0.016347051930746863, 0.06272408246461834, 0.029135937469878366, 4.4542239138058255, 34.817777497427805, 52.015427112579346, 43.29827969414847, 28.93811457497733, 18.002268382481166, 22.44521233013698, 39.9273680959429, 38.730832712990896, 40.26777424131121, 2.983250971351351, 0.016833203611895442, 0.3783448024519852, 5.2565306680543085, 5.960278528077262, 10.364968299865723, 6.701390760285514, 24.15095165797642, 42.59969738551548, 46.02911628995623, 47.60738570349557, 49.97933741978237, 48.62892375673567, 50.476015499659944, 48.44327136448452, 48.22901323863438, 47.15161166872297, 49.49069493157523, 46.44228744506836, 47.797453675951274, 46.580935273851665, 45.25804689952305, 42.43847485951015, 39.02414744240897, 37.39338091441563, 34.08243574414934, 31.890369415283203, 33.88779933112008, 34.16127347946167, 34.89243936538696, 38.29653556006295, 39.851462500435964, 39.800688539232524, 39.055633204323904, 37.38437604904175, 36.289364269801546, 35.76674509048462, 37.781052180698936, 36.738832814352854, 35.40295825685774, 34.5026593208313, 34.81971604483468, 34.48183904375349, 32.923886162894114, 33.26267685209002, 34.42060456957136, 33.66476215635027, 33.65304054532732, 35.13998283658709, 32.97367000579834, 32.768864904131206, 33.275673457554404, 34.705716950552805, 38.118015493665425, 38.98335804258074, 38.389676162174766, 41.40891511099679, 40.28154557091849, 43.55625935963222, 43.905100618089946, 44.605433872767854, 46.069391523088726, 47.107521874564036, 44.40180996486119, 43.13296467917306, 36.35182162693569, 38.627106530325754, 42.899383613041465, 45.333813531058176, 46.57673161370413, 45.75904328482491, 46.31517710004534, 45.03038569859096, 46.69526440756661, 43.70239039829799, 44.91171394075666, 43.78909696851458, 43.996281828199116, 40.93696914400373, 37.57737963540213, 34.689569337027415, 34.23362507138933, 35.24656472887312, 34.03390257699149, 34.5716792515346, 36.62336070196969, 36.49379416874477, 34.052680083683555, 35.11955860682896, 35.39477675301688, 36.01399326324463, 35.72808531352452, 36.33443375996181, 36.848433698926655, 36.01533079147339, 36.46955190386091, 36.26318693161011, 35.61736576897757, 35.565292494637625, 36.57538686479841, 37.84499645233154, 37.07967322213309, 36.92857422147478, 36.26241568156651, 37.80040986197335, 38.335233552115305, 36.509490149361746, 37.0949592590332, 36.639702865055625, 37.752839020320344, 39.243106024605886, 45.436403683253694, 48.34565959657942, 51.97138595581055, 52.210786138262065, 49.11286926269531, 39.69612509863717, 43.382304259708945, 50.16831105095999, 54.801064150674, 53.89960486548287, 53.80936861038208, 55.1839029448373, 56.686409200940815, 55.22261830738613, 38.04253026417324, 7.315491659300668, 1.3663672698395593, 1.443568270121302, 0.08352582196571998, 0.07770097202488355, 28.49670594079154, 56.100672585623606, 43.758955683027, 27.56087739127023, 27.60327008792332, 49.775491169520784, 45.2656968661717, 53.756746428353445, 32.87981373923165, 2.4931100606918335, 0.11587343870529107, 0.03017347858154348, 0.017274643227990185, 0.01854310168086418, 0.04943470610305667, 0.08817918798221008, 0.027595997156043137, 0.0046223391545936465, 0.031278988546026606, 0.006619672715065202, 0.017795345912288343, 0.05869477189012936, 0.12868295849433967, 0.0865257406341178, 0.11767839613769736, 0.12425333261489868, 0.09215424968195812, 0.17555523477494717, 0.1264272095369441, 0.16794033481606416, 0.09057295774774891, 0.14178460117961678, 0.11119636467524938, 0.1675926534725087, 0.16072805039584637, 5.392364910670689, 41.53459760120937, 57.05691841670445, 49.911477838243755, 32.25450365883963, 17.163961274283274, 35.75451626096453, 51.698815073285786, 44.41356979097639, 44.35496520996094, 3.4717347366469244, 0.2846895179578236, 1.089624428323337, 14.715697492871966, 12.487153121403285, 15.787696838378906, 9.374985490526472, 27.692158392497472, 44.137719358716694, 48.298707144601, 49.956793989454, 52.99147183554513, 51.66374751499721, 53.91815308162144, 51.63892160143171, 51.37201002665928, 50.89374814714704, 50.453249726976665, 49.46857534136091, 50.32898814337594, 48.23513112749372, 48.397632122039795, 44.71570873260498, 40.824884278433665, 39.17623656136649, 36.782161780766074, 33.05611038208008, 36.46836723600115, 36.03234345572335, 36.13089323043823, 40.24682542255947, 41.18645116261074, 42.102724007197786, 42.185758454459055, 39.45009633472988, 37.981618881225586, 39.322468348911826, 40.460899421146934, 38.25803211757115, 38.010738781520296, 35.92158917018345, 36.95098911012922, 34.65123265130179, 35.62977177756173, 34.37102222442627, 36.0052559035165, 35.241537707192556, 35.44732597896031, 36.48940290723528, 33.84545700890677, 33.40860986709595, 34.052013056618826, 36.9027373450143, 39.37633078438895, 39.818079880305696, 40.45276655469622, 42.852469376155305, 42.422560010637554, 45.52892242159162, 46.64700222015381, 47.37118516649519, 46.726197787693565, 48.314767905644004, 45.8147018296378, 44.63889292308262, 40.208002362932476, 39.76868513652256, 44.85767780031477, 46.94125843048096, 46.080967221941265, 47.694999013628276, 49.67942190170288, 47.82114355904715, 50.474928106580464, 47.237904821123394, 48.38096339362008, 46.44910710198538, 46.16926492963518, 44.14704384122576, 39.59884337016514, 36.92956781387329, 35.56294747761318, 38.71600178309849, 37.23005655833653, 38.13238089425223, 37.95017828260149, 38.26343781607491, 36.127644947596956, 37.108741010938374, 36.39227056503296, 38.68732309341431, 37.55418307440621, 38.70964070728847, 39.88732215336391, 38.42282601765224, 38.554150445120676, 38.655097348349436, 35.94695009504046, 36.963169302259175, 37.029771259852815, 40.737288338797434, 37.955024651118684, 38.072410992213655, 38.094492367335725, 40.26608582905361, 39.9821720123291, 38.396071978977744, 40.74404198782784, 40.43513202667236, 38.487656184605186, 41.59694726126534, 47.494321141924175, 50.96808344977242, 54.1583696774074, 55.640114716121126, 50.34151921953474, 41.791521140507285, 44.76962675367083, 53.70283188138689, 56.752795764378135, 56.534111636025564, 56.91649879728045, 57.421695368630544, 58.033887250082834, 56.73805863516671, 38.95220232009888, 9.525516475949969, 1.8472658821514674, 2.6464118574346815, 0.34102410078048706, 0.2381592776094164, 31.03864186150687, 61.47809192112514, 51.11808116095406, 36.22813326971871, 30.59833104269845, 54.561493737357004, 51.70787899834769, 62.31352942330496, 40.3533239364624, 3.624158237661634, 0.25306186079978943, 0.0761971620044538, 0.11475932491677147, 0.15690986599240983, 0.10665078394647155, 0.1874011941254139, 0.1699798618044172, 0.11875813534217221, 0.10533458885869809, 0.09177309620593276, 0.11972111224063806, 0.13003544163491043], [0.011014877785263317, 0.06623917206057481, 0.04420256328635982, 0.07407665186162506, 0.013850677492363113, 0.03310853608750871, 0.006110200633494449, 0.09787222357200724, 0.0635246859331216, 0.03840549596186195, 0.022380770217361193, 0.025018826160313826, 0.10383045992680959, 3.7745915140424455, 30.500962461744034, 40.99019234521048, 38.35788467952183, 15.688655478613716, 23.734004156930105, 62.55454853602818, 54.83375195094517, 32.90125240598406, 36.37645993913923, 2.890226100172315, 0.11898298827665192, 0.5610725187829563, 5.603807279041835, 4.536496664796557, 8.765852553503853, 3.924277424812317, 22.209466900144303, 45.624939577920095, 48.76773139408657, 48.42058549608503, 46.735692501068115, 43.456135817936485, 41.68660681588309, 39.47938299179077, 39.65701716286795, 42.00575147356306, 41.358860288347515, 42.53257083892822, 41.700496264866416, 40.60967772347586, 36.647137437547954, 35.44063833781651, 31.40675742285592, 31.057905742100306, 31.397033418927872, 32.44048261642456, 33.34367200306484, 38.1151111466544, 39.2969754082816, 39.03854063579014, 39.70946911403111, 38.72163329805647, 38.90770605632237, 39.96872724805559, 37.870260102408274, 38.20643479483468, 36.66873591286795, 37.15167393003191, 34.31305340358189, 32.377945355006624, 31.360069002423966, 32.22243424824306, 32.52973917552403, 33.200942107609336, 32.381547995976035, 32.58785390853882, 31.573906762259348, 31.965660095214844, 32.38054745537894, 31.749463421957834, 32.60028076171875, 33.21850020544869, 32.412755829947336, 32.85482106889997, 32.710201263427734, 34.916118826184956, 36.10984713690621, 38.33594921657017, 40.43762295586722, 42.654563835689, 43.95911243983677, 44.79188183375767, 43.49075174331665, 41.19813108444214, 34.326463426862446, 35.97931827817644, 42.78835834775652, 37.40382753099714, 42.090752261025564, 43.706204959324424, 46.12516123907906, 45.8371445110866, 45.97989525113787, 43.84794821058001, 43.66711439405169, 43.84422745023455, 45.666083335876465, 44.46360724312918, 41.296656540461946, 35.34401668821062, 32.239988871983115, 31.68588740485055, 32.57292570386614, 33.84600939069475, 33.594158036368235, 32.93960993630545, 33.75622476850237, 33.28003692626953, 34.158806868961875, 33.76381567546299, 33.57944522585188, 34.39270755222866, 35.15871865408761, 37.29577956880842, 38.559868812561035, 34.11699260984148, 32.859090736934114, 33.26298952102661, 33.67552491596767, 34.275807585035054, 35.1098450251988, 34.45438323702131, 34.15812941959926, 34.17444726399013, 35.80827794756208, 36.70846571241106, 37.60675661904471, 36.202532632010325, 37.46873412813459, 36.781255040849956, 38.19563382012503, 41.205666405814036, 43.32847656522478, 41.52602352414812, 39.7999381337847, 36.29837260927473, 45.357600688934326, 48.98883349554879, 53.49213123321533, 51.03122867856707, 52.37710516793387, 51.12960474831717, 54.08546570369175, 53.53086396626064, 40.94193710599627, 7.422770977020264, 0.6602284695420946, 0.302143039980105, 0.04649792851081916, 0.0948160814919642, 22.851829596928187, 50.819642135075156, 41.39418492998396, 35.297130244118826, 27.007845946720668, 40.08412293025425, 40.428437437329976, 47.737865924835205, 30.24454266684396, 1.427876197866031, 0.10772138328424521, 0.047050842948790104, 0.04648770638076322, 0.0026186159146683557, 0.033584921953401396, 0.020665379407416497, 0.016851717439879264, 0.03185958042740822, 0.028617014243666614, 0.0055245757186120105, 0.03160248690151742, 0.05730384295540197, 0.029492158176643506, 0.020132371490555148, 0.026346211986882345, 0.019514490717223713, 0.02462921304894345, 0.0019809185261172907, 0.05000102160764592, 0.05565386970660516, 0.008314962349166828, 0.025100262236914465, 0.033968267097537, 0.09351990997259106, 0.09924995500062193, 5.242067124162402, 37.12043482916695, 48.542227608816965, 44.6189272744315, 21.87026800428118, 21.75237270763942, 54.86786413192749, 60.8309644971575, 39.21232203074864, 40.45904425212315, 3.286540925502777, 0.05940714545015778, 0.29925744767699924, 4.963465639523097, 6.348569052559989, 6.10499951669148, 5.795872858592442, 23.411194324493408, 45.69443893432617, 50.695481300354004, 48.667851039341514, 47.73806742259434, 47.322287218911306, 43.49281883239746, 41.58428764343262, 41.075210503169465, 43.79473543167114, 43.13723087310791, 44.86516101019723, 43.648333413260325, 43.42217302322388, 39.2859069279262, 36.964875085013254, 34.27263225827898, 33.75893109185355, 32.71894557135445, 32.85683952059065, 34.68639748437064, 39.28319713047573, 41.06089721407209, 40.87130866731916, 41.53707810810634, 40.37820543561663, 40.57593379701887, 40.38824210848127, 38.60702971049717, 39.45820140838623, 39.27801724842617, 38.458765574863975, 37.68520872933524, 32.83384793145316, 34.29081221989223, 34.1182849747794, 34.497389112200054, 34.00720064980643, 33.329320498875205, 34.69228260857718, 33.10376112801688, 34.166224070957725, 34.25580719539097, 34.02537366322109, 34.19869647707258, 36.255870478493826, 34.66594198771885, 35.12789297103882, 33.974863733564106, 37.02154459272112, 37.46539204461234, 40.41412762233189, 42.05526781082153, 44.322583130427766, 44.92043740408761, 46.243502957480295, 43.846179894038606, 43.83655663899013, 36.08305140904018, 37.294129371643066, 41.34721858160836, 39.25375066484724, 44.188253607068745, 44.71737977436611, 47.643589292253765, 46.68027366910662, 47.06227173124041, 45.70584440231323, 46.263875075748985, 45.76301418031965, 47.58305311203003, 46.61765650340489, 42.52196788787842, 37.37317902701241, 34.874123913901194, 33.5903400012425, 34.14363547733852, 35.34699051720755, 35.774426324026926, 34.12726552145821, 34.54225015640259, 35.07978016989571, 35.607766832624165, 35.82658992494856, 34.95608139038086, 35.1338996887207, 37.78718744005476, 39.68384068352835, 41.49186270577567, 36.84903471810477, 35.15524108069283, 34.61449752535139, 35.584931577954976, 36.57228796822684, 36.78025450025286, 36.04668453761509, 35.396215030125205, 35.5849107333592, 37.31527621405465, 38.88413429260254, 39.13004841123308, 37.95116492680141, 39.54141650881086, 37.369006633758545, 40.398098128182546, 44.088095324380056, 45.85280575071062, 44.98426008224487, 42.82427358627319, 36.83358192443848, 46.77209758758545, 51.75845146179199, 55.230365548815044, 53.24458081381661, 54.40185192653111, 53.22678995132446, 55.25405543191092, 54.622710841042654, 41.126404830387656, 8.191761987549917, 0.9420774770634515, 1.3110061947788512, 0.04864859274987664, 0.13704573975077697, 24.973267487117223, 55.954722200121196, 43.019660404750276, 35.81814438956124, 28.871149574007305, 45.2196546282087, 44.1908209664481, 55.78245551245553, 34.865727015904014, 2.285984912088939, 0.05587010524634804, 0.022772213676944375, 0.06691321517739977, 0.02659339890150087, 0.06826842602874551, 0.060160991070525985, 0.036926876553999524, 0.01388324547692069, 0.026594827217715125, 0.008643201968100454, 0.06337885518691369, 0.1593111471406051, 0.08590228908828326, 0.1864681134798697, 0.09922234541071312, 0.1687014475464821, 0.10841129054980618, 0.14260770486933844, 0.11032100021839142, 0.1575701077069555, 0.08262678342206137, 0.1213204599916935, 0.09841408128184931, 0.11213804914483003, 0.13362881381596836, 6.208135102476392, 46.40545851843697, 55.94492524010794, 50.78708635057722, 24.51182198524475, 32.78204216275896, 67.77417428152901, 62.15438788277762, 42.20904186793736, 45.98549549920218, 4.631883706365313, 0.1626313818352563, 1.122823029756546, 9.204996074948992, 9.546161311013357, 18.3548720904759, 8.329973816871643, 25.619178976331437, 49.17815106255667, 51.360625403267996, 51.009866441999165, 50.43466329574585, 48.291203090122764, 45.60805892944336, 42.55161585126604, 42.758897985730854, 46.0639580317906, 44.165268966129844, 45.3542412349156, 44.34987218039376, 44.642043931143625, 40.910916873386924, 39.052728857312886, 35.84122977937971, 35.63001149041312, 34.64437477929251, 35.09586524963379, 37.23206458772932, 42.857145513807026, 42.87266084126064, 42.16614368983677, 43.911823000226704, 42.98517649514334, 43.35476507459368, 43.32545062473842, 40.90568140574864, 42.79910373687744, 41.89345816203526, 41.04929372242519, 39.48156125204903, 34.64118555613926, 35.565129211970735, 36.36772952760969, 36.10673781803676, 36.81836884362357, 35.16942235401699, 37.1174054145813, 36.699815205165315, 35.26828132356916, 36.88123961857387, 35.55360215050833, 35.256910596575054, 37.510041168757844, 37.03680978502546, 37.49899353299822, 35.94489690235683, 39.2191138948713, 38.750794887542725, 42.80692393439156, 44.708604199545725, 46.35080051422119, 46.18574258259365, 48.92564310346331, 47.77435438973563, 45.13584893090384, 38.68561036246163, 39.348322595868794, 41.89610195159912, 40.57609707968575, 44.49194547108242, 45.08632911954607, 48.89919478552682, 48.35161420277187, 49.01093918936593, 46.82806880133492, 46.98074156897408, 46.63558980396816, 49.899558203560964, 50.631116662706646, 44.16149956839425, 39.75937802450997, 36.099185126168386, 35.71367127554757, 34.43183980669294, 37.638395241328645, 37.99997254780361, 34.98459332329886, 36.58099406106131, 36.672675541469026, 38.15717206682478, 37.41146012714931, 37.19686848776681, 37.3981682232448, 38.86852863856724, 40.866722856249126, 43.58445514951433, 38.264007568359375, 36.79195874077933, 35.873382568359375, 36.50872584751674, 37.97936071668352, 38.2146440914699, 38.26124218532017, 38.73489393506731, 37.604019028799875, 38.88297741753714, 40.028676305498394, 42.09893723896572, 41.036769594464985, 42.11428580965315, 40.001682553972515, 42.40421329225813, 45.55450221470424, 47.567492621285574, 47.09052658081055, 44.53112636293684, 39.351171357291086, 49.46414239065987, 53.329915114811485, 58.550947870527, 54.486262117113384, 56.304056780678884, 54.02706609453474, 57.209966387067524, 56.29695572171892, 43.703095640454976, 9.899919288499014, 3.3781909218856265, 2.551073887518474, 0.2091228642633983, 0.2911452358322484, 27.731149945940288, 62.48426750728062, 52.07928800582886, 46.52140310832432, 36.30520963668823, 51.69374983651297, 53.270490646362305, 64.29994297027588, 43.486398696899414, 3.989932256085532, 0.2484898375613349, 0.14621334496353353, 0.1824928346489157, 0.16206925628440721, 0.14915725056614193, 0.15966456889041833, 0.10933470885668482, 0.11979379691183567, 0.1208017063992364, 0.14723882850791725, 0.14561626128852367, 0.1780265135956662], [0.03995246080947774, 0.006067554707572396, 0.06521215502704893, 0.13846724347344466, 0.023216223244422247, 0.005807330590739314, 0.0571265078282782, 0.06382436770945787, 0.05091982587639775, 0.0252059966525329, 0.031045694635914903, 0.054087013604917696, 0.015947467747277448, 5.069235461098807, 32.90796089172363, 37.84993314743042, 38.403489180973594, 22.075208595820836, 38.38670580727713, 46.88076741354806, 35.68955755233765, 30.824241297585623, 45.561877727508545, 4.334776563303811, 0.10880461015871593, 0.34834128671458786, 4.534844296319144, 6.580889454909733, 6.605922511645725, 7.420291338648115, 33.059435095105854, 44.94977617263794, 47.462540081569124, 48.588909081050325, 46.145891189575195, 44.03678982598441, 40.89847264971052, 34.79908684321812, 32.565442493983674, 32.60101727076939, 34.166397775922505, 35.7255596433367, 34.94406795501709, 33.42442396708897, 32.91332837513515, 32.217469760349815, 33.22106409072876, 33.83183853966849, 32.993611335754395, 33.16212599618094, 38.71923616954258, 43.7936932018825, 42.26644441059658, 40.60387945175171, 35.991658278873985, 36.18550954546247, 36.36923033850533, 38.3936505317688, 37.01806354522705, 40.0363575390407, 37.29060663495745, 36.522181034088135, 35.77500302450997, 33.07361289433071, 31.74553074155535, 31.80658803667341, 33.496650491442, 32.181137629917686, 31.971225602286204, 33.668194566454204, 31.986654077257427, 33.18271003450666, 33.254787172589985, 31.33753946849278, 31.835120814187185, 32.02941676548549, 31.578735760280065, 32.57913391930716, 32.89241429737636, 35.026334626334055, 35.11385760988508, 40.22079747063773, 38.83584083829607, 41.462405817849294, 41.03853096280779, 44.5985621043614, 44.40725040435791, 41.91116912024361, 36.90409571783883, 35.54983622687203, 40.65214858736311, 40.32316528047834, 39.470200947352815, 38.300110408238, 39.80272436141968, 39.99283054896763, 41.94535078321184, 43.007303033556255, 43.58891936710903, 41.879151821136475, 43.647749764578684, 45.82419654301235, 41.27558960233416, 35.7726788520813, 33.61018058231899, 32.206151144845144, 33.615860734667095, 32.07291943686349, 32.9873058455331, 32.59526763643537, 33.34711830956595, 33.27464859826224, 34.92697538648333, 33.38717467444283, 33.34450231279646, 34.494012287684846, 37.15346656526838, 38.776965277535574, 39.23814501081194, 37.25264515195574, 33.422346455710276, 32.778672286442344, 33.72450276783535, 33.75054461615426, 32.7124524797712, 33.69472973687308, 35.10441500799996, 35.04704373223441, 36.388424737112864, 37.571098463875906, 39.08992951256888, 40.65262801306588, 38.92246403012957, 39.03994069780622, 36.741834436144146, 35.59694153921944, 35.754502364567344, 35.7935026032584, 37.43100888388497, 34.94468981879098, 47.15530811037336, 50.639041083199636, 52.95533078057425, 51.22608395985195, 56.21739884785244, 52.79133244923183, 56.411503723689485, 53.698864459991455, 44.18288612365723, 8.21739215510232, 0.701567754149437, 0.7276693678327969, 0.11143153134201254, 0.05464820956279125, 19.863162721906388, 50.678253241947715, 42.087031500680105, 34.446299007960725, 32.41629941122872, 46.7296267236982, 47.706223828451975, 49.33321748461042, 32.84682369232178, 1.703860491514206, 0.07242120283522777, 0.01790280719952924, 0.07323992997407913, 0.0277740125145231, 0.055602962616831064, 0.020082326140254736, 0.025104723604662076, 0.06851149084312574, 0.04007882438600063, 0.0037478830864919083, 0.05197506318134921, 0.061584476115448136, 0.025162894411810806, 0.020267428797004477, 0.04547515232115984, 0.07186417308236871, 0.059712818690708706, 0.012755355731184994, 0.057046399983976565, 0.03359527639778597, 0.048965550027787685, 0.009774581080169549, 0.08640137195054974, 0.08214081664170537, 0.032614124938845634, 6.022025866167886, 40.652478626796174, 44.265541894095286, 45.200185775756836, 24.555222170693533, 34.99071816035679, 56.13212360654558, 49.259215695517405, 36.86082581111363, 47.51515531539917, 4.625341543129512, 0.10811654850840569, 0.09655582492372819, 3.2745290100574493, 5.403070781912122, 3.1201113760471344, 7.114002585411072, 31.443447385515483, 45.86534030096871, 47.473097869328086, 50.531010491507395, 47.88058887209211, 46.273387159620015, 42.2979336466108, 36.64603962217058, 34.164775371551514, 34.50674138750349, 36.80032784598214, 36.81587444032942, 37.50980493000576, 36.00537749699184, 34.75280836650303, 33.0512501171657, 34.65024948120117, 34.92659670966012, 34.46290520259312, 34.32323946271624, 38.96117244447981, 44.72987610953194, 43.626012325286865, 42.040134634290425, 38.270524978637695, 37.84355122702462, 37.475585051945274, 39.74356392451695, 39.14279835564749, 41.4254344531468, 40.12602751595633, 39.81103440693447, 37.118635245731895, 34.83487354006086, 32.93524994168963, 34.33121599469866, 34.65678426197597, 33.76597309112549, 32.8076045853751, 35.134698731558665, 33.619633606501985, 34.799142428806846, 33.60923562731062, 33.89895813805716, 32.46817118780953, 33.64305945805141, 32.38441065379551, 34.017574310302734, 34.30426740646362, 36.99500247410366, 37.87069089072091, 40.291773319244385, 41.1701784815107, 41.83104944229126, 43.742908818381174, 46.840617247990195, 46.504814284188406, 43.63967595781599, 36.822047914777485, 36.79201085226876, 40.31911448069981, 40.05999878474644, 40.665301527295796, 39.68820762634277, 40.730892521994456, 41.326196806771414, 40.97387450081961, 44.528249808720176, 43.25734438214983, 42.913193157741, 45.319420337677, 47.81869084494454, 42.389719349997385, 36.955898012433735, 35.95880719593593, 32.550316265651155, 33.98879139763968, 34.71321405683245, 34.4221123286656, 33.438362053462434, 35.00158166885376, 35.535255432128906, 35.21031597682408, 35.52093866893223, 34.54366758891514, 35.87894460133144, 38.89543901171003, 41.58976977212088, 40.552132742745535, 38.55185406548636, 35.444855894361226, 35.21329327992031, 34.923456123897004, 35.79195315497262, 34.94779218946184, 34.97060659953526, 37.018470014844624, 36.1100868497576, 38.55002668925694, 39.41165542602539, 41.695781912122456, 43.13596282686506, 40.43331159864153, 40.12594066347395, 38.28908361707415, 36.67650399889265, 37.99048130852835, 37.51744100025722, 38.94479554040091, 36.9642219543457, 48.458633831569124, 53.05419669832502, 54.78304399762835, 54.47399159840175, 56.63612508773804, 54.5030072757176, 57.50100905554635, 56.14007234573364, 44.39566775730678, 9.798160314559937, 1.3732292673417499, 1.186088657804898, 0.06950283729072128, 0.04520988923364452, 22.874336549213954, 57.0316686630249, 46.33646985462734, 37.8977506501334, 34.40158387592861, 53.68126467296055, 54.75281585965838, 57.813469546181814, 38.11360338756016, 2.654724725655147, 0.11198873072862625, 0.023740035315443362, 0.0720001854268568, 0.019137530587613583, 0.12388738510864121, 0.03813163583566036, 0.025215903263805167, 0.06320631051702158, 0.03373599098995328, 0.05924588481762579, 0.05609872065750616, 0.029221714474260807, 0.1302877345255443, 0.1099738006346992, 0.13158525632960455, 0.14422227894621237, 0.12323543509202343, 0.12343489724610533, 0.1931688232081277, 0.1882869673094579, 0.09095664215939385, 0.11437388988477842, 0.14680848802839006, 0.2012001265372549, 0.1391842242862497, 7.6152881894792825, 47.782508100782124, 52.652149609157014, 50.334379945482524, 33.692627906799316, 49.26763343811035, 53.348584924425396, 43.0059620312282, 40.8971802847726, 55.13780859538487, 5.958681310926165, 0.2582407114761216, 1.158660535301481, 11.678832701274327, 13.424999254090444, 11.733279653957911, 10.695290003504072, 36.22758436203003, 46.18402985164097, 49.10662283216204, 52.40685388020107, 50.772074767521445, 47.9420074735369, 45.32373169490269, 39.43296902520316, 37.01446090425764, 35.886219365256174, 37.30964469909668, 38.06538636343819, 38.10852425439017, 36.81063549859183, 36.26558058602469, 34.95380932944161, 36.742348602839876, 36.228095054626465, 36.057825974055696, 35.38931546892439, 42.97532742364066, 45.83467790058681, 45.44138206754412, 43.91501569747925, 39.99042994635445, 40.11809267316546, 38.69003636496407, 42.970779827662874, 40.401457582201274, 43.01714515686035, 41.71935020174299, 40.31995521272932, 39.432461806706016, 37.77630656106131, 35.192434787750244, 36.284872259412495, 36.42026833125523, 35.99945068359375, 35.052786418369834, 37.81806870869228, 35.12870243617466, 35.86652817044939, 36.528569902692524, 34.88746792929513, 33.46970190320696, 35.13969448634556, 34.41056442260742, 36.595018999917166, 36.58076824460711, 38.835517747061594, 39.11340747560774, 42.60164288112095, 43.35507774353027, 44.22822659356253, 45.3761419568743, 48.18713991982596, 48.91876786095755, 45.83243015834263, 40.35425499507359, 38.33947542735508, 41.09118441173008, 43.14804227011544, 41.14345570972988, 41.426897048950195, 43.28885098866054, 42.535402229854036, 42.601191248212544, 45.09082807813372, 44.49388401848929, 44.35318647112165, 46.62396546772548, 48.802441120147705, 43.751715660095215, 39.09188543047224, 38.500715323856895, 35.143356187003, 35.90122052601406, 36.403088910239084, 37.683819089617046, 36.33959627151489, 36.7324161529541, 37.035173484257285, 38.39768396105085, 36.97138902119228, 36.43537024089268, 37.392432485307964, 41.46734946114676, 43.563016482761924, 43.78991338184902, 41.52702406474522, 37.14886685780117, 35.170662607465474, 36.800341742379324, 36.272462776729036, 37.06000287192208, 36.34827109745571, 39.029532296316965, 37.22713484082903, 40.28147956303188, 41.04837656021118, 42.40302515029907, 46.296187673296245, 42.66342626299177, 43.69280535834176, 40.98715945652553, 38.50582572392055, 39.32983691351754, 38.996636050088064, 41.714166845594136, 38.51560878753662, 51.51124497822353, 56.579896790640696, 57.3981340272086, 55.378518513270784, 59.49047633579799, 56.461308411189485, 61.26765183040074, 60.11480672018868, 47.07364593233381, 11.021379385675703, 2.4779727586678097, 2.9389043109757558, 0.3303639627993107, 0.12486284705145018, 24.967530012130737, 63.488879748753135, 54.40061167308262, 44.06564916883196, 41.5208158493042, 56.268367358616416, 59.67762606484549, 64.10573387145996, 44.96243231637137, 4.275456317833491, 0.3272179758974484, 0.09665314720145293, 0.19165985632155622, 0.1394308174827269, 0.24164143790091785, 0.09448807087859937, 0.1456450040319136, 0.22049789316952229, 0.10767795704305172, 0.09029380165572677, 0.09620236246181385, 0.12583649052040918], [0.02702958496021373, 0.032263271444078, 0.07290621966655765, 0.05947642387556178, 0.030240809611443962, 0.0559644555406911, 0.014502412074112465, 0.0545291504157441, 0.028827777398484092, 0.08359885947512728, 0.06878732889890671, 0.07382515285696302, 0.045360445976257324, 5.329138474805014, 31.07447372164045, 34.71743508747646, 38.89216641017369, 25.820139987128123, 24.52828574180603, 31.869556086403982, 32.99425751822335, 32.35581534249442, 46.16247306551252, 4.673431328364781, 0.05101086152717471, 0.1762839135314737, 2.167271682194301, 5.016278462750571, 3.130468317440578, 19.994131054197037, 37.05677195957729, 45.702234813145225, 48.282187802451, 45.465544428144185, 46.82334402629307, 44.3184037889753, 43.468375069754465, 42.77803332465035, 40.02978801727295, 37.136436530521934, 33.353041648864746, 32.482060636792866, 32.736475876399446, 33.81035123552595, 33.42669602802822, 33.791841234479634, 33.08159637451172, 34.10059486116682, 32.16015059607369, 36.99935552052089, 42.14352035522461, 44.245319162096294, 42.70980201448713, 40.237938676561626, 36.24788005011422, 31.652112211499894, 34.48895747320992, 36.65595817565918, 37.74915994916643, 38.07841076169695, 39.046895844595774, 36.24554892948696, 33.60149185998099, 33.00240428107125, 31.648499148232595, 32.83243744713919, 34.130312306540354, 33.0430269241333, 30.855198996407644, 32.006838594164165, 31.407330649239675, 32.8305127961295, 31.16349404198783, 33.42256532396589, 31.308384827205114, 33.15458025251116, 30.482570580073766, 31.773657049451554, 32.86539970125471, 36.19689416885376, 37.49011720929827, 38.94694600786482, 41.27020474842617, 43.79880012784685, 40.44786460059029, 43.656772000449045, 42.3588102885655, 43.43174416678292, 36.58241149357387, 33.08308676310948, 39.159838812691824, 36.242168630872456, 40.12979343959263, 41.65610074996948, 43.41697229657854, 44.34201029368809, 44.003619125911165, 44.52378559112549, 44.513165269579204, 45.85599149976458, 44.470333099365234, 43.80371250425066, 40.15432752881731, 35.002401556287495, 31.140498978751047, 31.376918384007045, 33.37002999441964, 33.08753708430699, 32.99127326692854, 32.741697447640554, 33.94274568557739, 32.64738259996687, 33.75161811283657, 33.981471470424104, 33.929148060934885, 34.60945313317435, 38.58753306525094, 40.98475885391235, 39.806316580091206, 36.04639618737357, 33.692867619650706, 33.84995596749442, 32.04053388323103, 33.854534830365864, 35.79662234442574, 34.60273422513689, 32.58415051868984, 34.15715319769723, 35.52998522349766, 38.00378016063145, 41.837132590157644, 42.80646882738386, 46.6766745022365, 42.524708952222554, 42.19185897282192, 37.513754980904714, 38.25474214553833, 37.711250577654155, 37.383747237069265, 35.556836536952424, 41.77294513157436, 52.26523917061942, 54.31048311505999, 52.35553795950753, 53.19365746634347, 51.47281796591622, 52.06284856796265, 52.50275639125279, 49.52980286734444, 14.032712153026036, 0.38295900342719896, 0.5707039705344609, 0.06237633326756103, 0.014808032728199447, 19.578432491847447, 52.47777761731829, 44.32544926234654, 25.935935190745763, 21.476048060825892, 35.190343379974365, 40.63078982489449, 47.224605969020296, 34.67057296207973, 2.013794877699443, 0.031218643034143106, 0.03364540317228862, 0.033270519359835556, 0.028838589854006256, 0.04768734611570835, 0.024896155510629927, 0.06375489250889846, 0.036740717078958235, 0.00964168321141707, 0.01730573200620711, 0.030677684383200746, 0.052511865805302343, 0.02978919366640704, 0.012922163387494428, 0.022673408800203885, 0.026078811514058282, 0.04124767220179949, 0.054530046081968715, 0.03580828443435686, 0.042002396525016854, 0.04506768864978637, 0.05549797967874578, 0.016137447374473726, 0.0719612714435373, 0.1928242359842573, 6.9982868518148145, 37.352198941367014, 42.54353857040405, 44.8704069001334, 30.853996958051408, 30.759459768022808, 35.67930548531668, 37.32787677219936, 36.44848149163382, 50.265992300851, 5.546775596482413, 0.08551633836967604, 0.20443563934947762, 2.4935955660683766, 4.988077027457101, 3.0325731933116913, 17.22221323422023, 42.116616930280415, 46.68125336510794, 48.68171616962978, 47.6942138671875, 49.29393236977713, 46.200292110443115, 45.56653996876308, 45.35801410675049, 42.05789075578962, 38.22610861914498, 34.58266435350691, 33.49776220321655, 34.37717138017927, 34.70952456338065, 34.78599296297346, 35.9300069127764, 35.17001295089722, 34.918071269989014, 32.42962953022548, 37.47911473682949, 44.62397166660854, 45.49740539278303, 44.87467656816755, 42.81337881088257, 36.18474524361746, 33.39751359394619, 36.270989758627756, 38.58475725991385, 38.18161235536848, 39.17214754649571, 39.50923940113613, 37.77725499016898, 35.45994390760149, 34.12292289733887, 33.25859478541783, 34.44722311837332, 34.92462689535958, 34.54481404168265, 32.19026408876692, 33.34602744238717, 33.25667708260672, 34.11384160178048, 33.666575636182515, 33.961971351078574, 32.46046216147286, 34.61550154004778, 32.11089481626238, 32.38504293986729, 33.63167830875942, 35.813485622406006, 38.32419981275286, 39.689659799848286, 41.303173950740266, 46.261641229902, 42.4368211882455, 44.31065654754639, 45.52641412190029, 45.073898792266846, 37.05856112071446, 35.24045031411307, 39.02192749295916, 38.74786969593593, 42.22149998801095, 42.08742754799979, 45.497117042541504, 45.992909227098735, 46.28682844979422, 45.600877966199604, 44.72761099679129, 47.425026757376536, 47.16439288003104, 46.93487998417446, 42.299809660230366, 36.29924808229719, 33.46814203262329, 33.209422383989605, 35.1734106200082, 33.832401343754356, 34.827466760362896, 35.24130146844046, 35.87888206754412, 35.56143971851894, 35.797157355717246, 35.79115411213466, 35.82568318503243, 37.78914335795811, 39.79374728884016, 41.32308053970337, 41.851386819567, 38.09913723809378, 36.12869759968349, 35.28829560961042, 34.49237598691668, 35.13565410886492, 36.499113014766145, 35.41433940614973, 35.30702795301165, 35.611161027635845, 37.20114510399954, 40.31953832081386, 42.777772767203196, 45.28056253705706, 47.748534883771626, 45.95874840872628, 45.288396630968364, 38.64952836717878, 39.734642437526155, 38.12218441282, 39.01562895093645, 38.19474792480469, 44.27203845977783, 55.40427895954677, 55.71917131968907, 53.2425971031189, 54.78755685261318, 52.03957557678223, 55.003281048366, 54.40044491631644, 53.03624950136457, 14.271887387548174, 2.09361361180033, 0.6270717744316373, 0.07162088435143232, 0.027651877907503928, 21.352627209254674, 56.52184459141323, 49.73062317711966, 32.07680000577654, 23.902464968817576, 39.776241302490234, 45.85638059888567, 54.23327473231724, 39.738818304879324, 2.820785803454263, 0.1334561945072242, 0.019285176414996386, 0.0998496917475547, 0.027912192778395753, 0.015476949512958527, 0.020927390615854944, 0.07275339322430746, 0.0660240086061614, 0.06865941147719111, 0.05223508458584547, 0.04188770375081471, 0.07260613755456038, 0.13489515015057155, 0.16047839022108487, 0.150532084650227, 0.17662884002285345, 0.12515233723180635, 0.14815033173986844, 0.17693207732268743, 0.19829382534537995, 0.11377722690148012, 0.11607124523392745, 0.1553205062768289, 0.1832196677901915, 0.18452960678509303, 7.684196080480303, 47.28908177784511, 51.304946013859336, 52.09413283211844, 36.77765934807913, 35.037687982831685, 38.874844551086426, 42.78270598820278, 41.7224178314209, 56.54424558367048, 6.88760769367218, 0.16934104822576046, 0.5366553004298891, 7.77800110408238, 12.73812552860805, 7.924846938678196, 22.763537100383214, 42.11723184585571, 49.18598515646798, 50.08333110809326, 47.77984346662249, 49.841050897325786, 48.822240012032644, 48.43478066580636, 47.550573757716585, 45.702158382960725, 39.814272267477854, 36.2481301852635, 35.89258738926479, 35.94929163796561, 36.72006572995867, 35.621392250061035, 38.23401914324079, 37.17754554748535, 37.197188104902, 34.86917332240513, 39.577588830675396, 44.94668075016567, 47.32086631229946, 47.08191776275635, 45.55667700086321, 39.4772047315325, 35.35764905384609, 38.938007150377544, 40.45957578931536, 41.235008648463655, 41.837869099208284, 41.489177227020264, 38.35849959509713, 36.755838530404226, 35.993034022195, 34.76916790008545, 36.25347682407924, 36.35621983664376, 36.591461522238596, 33.80244071143014, 35.0681106703622, 35.212122508457725, 36.175462450299946, 34.872143677302766, 37.023434502737864, 34.44566672188895, 37.5822433744158, 35.04076256070818, 34.42620481763567, 36.54868146351406, 39.528916699545725, 40.79494101660592, 42.00005047661917, 44.78540958677019, 50.92282288415091, 43.67890896115984, 47.73351635251726, 46.822412967681885, 46.1188314301627, 39.04909494944981, 35.65936762945992, 38.31845365251814, 40.4112753868103, 42.23920399802071, 43.91249350139073, 48.5436554636274, 47.16990280151367, 48.35312196186611, 48.980975082942415, 47.104537623269216, 50.33223990031651, 48.17967755453927, 48.75534275599888, 44.20405728476388, 37.451860427856445, 35.76566464560372, 33.55312544958932, 35.791393824986045, 36.08041456767491, 35.1965446472168, 36.67207799639021, 38.016929626464844, 36.56908484867641, 38.74445465632847, 37.29416411263602, 36.4518826348441, 39.62617410932268, 42.43049485342843, 45.17046138218471, 44.08058084760393, 40.845471790858674, 36.47983523777553, 37.246263231549946, 36.12848220552717, 38.144804273332866, 40.04359408787319, 37.955403327941895, 36.11583648409162, 37.16335385186331, 39.35573632376534, 41.7001245362418, 45.60585982458932, 47.05648735591343, 50.36897502626692, 47.292142459324424, 48.375901630946565, 41.40876572472708, 42.596577644348145, 40.405977385384695, 40.31837797164917, 40.601096698216026, 44.416043349674766, 57.41638347080776, 57.610015869140625, 55.5160858971732, 57.85216753823416, 55.614458492824006, 58.20463228225708, 55.509394781930105, 53.900852067129954, 16.142956495285034, 2.677708715200424, 1.801532621894564, 0.47558557455028805, 0.12527017162314483, 24.741525956562587, 61.335952622549875, 54.79789924621582, 39.22049311229161, 31.15623664855957, 46.08343383244106, 55.991047382354736, 62.18943459647042, 48.552903515951975, 5.747624133314405, 0.1977191333259855, 0.2327795805675643, 0.2501961902848312, 0.1616627188133342, 0.10070831674550261, 0.10305576971066849, 0.16483059525489807, 0.1374893659459693, 0.10102740462337222, 0.14593034157795565, 0.07614180033228227, 0.13428266373063835], [0.02365379860358579, 0.04263355622866324, 0.04494900608967457, 0.02678095955135567, 0.03340727809284415, 0.008904702578937369, 0.03611036143930895, 0.03788287811247366, 0.021706876378240328, 0.010073628426263375, 0.018921715739582266, 0.09163542823599917, 0.06587516516447067, 3.403959619147437, 30.577806064060756, 37.34007086072649, 40.49546670913696, 23.19574110848563, 17.567069700786046, 24.028277737753733, 49.87991564614432, 32.66644845690046, 45.64627749579293, 5.714870759419032, 0.04105109042887177, 0.08310002088546753, 0.781170659831592, 2.7474970732416426, 2.8246906910623824, 18.84181227002825, 35.69526897157942, 51.082704407828196, 46.88734040941511, 50.501605715070454, 47.95625128064837, 49.05402496882847, 46.7564571925572, 45.72266251700265, 44.311743940625874, 44.49275146211897, 43.35231930868966, 39.56747572762625, 30.788228784288677, 32.40577289036342, 33.053706305367605, 32.525507722582134, 32.50265857151577, 33.50480072838919, 33.69416693278721, 40.15603331157139, 43.108798844473704, 41.68589809962681, 42.57465607779366, 41.44060237067086, 36.79639516557966, 32.07239832196917, 32.92780842099871, 33.11975588117327, 33.006371702466694, 36.41749947411673, 35.763243198394775, 34.40474878038679, 32.99682140350342, 32.641434941973, 31.60664667401995, 32.67836809158325, 31.761598450796946, 32.09814487184797, 32.40991749082293, 32.17786155428205, 31.726642063685826, 32.905021803719656, 31.34846203667777, 32.16380187443325, 31.542803151266916, 31.65273060117449, 35.16925212315151, 38.83823101861136, 39.542927742004395, 40.2501814024789, 40.250699043273926, 41.28938177653721, 40.92436163766043, 43.38039003099714, 42.9918189729963, 44.00748232432774, 42.82250526973179, 41.95788880756923, 34.769445828029085, 32.16870730263846, 41.35831832885742, 41.333082471575054, 45.40899998801095, 44.610853467668804, 44.91982248851231, 43.79971381596157, 45.14028882980347, 43.71842336654663, 42.660438537597656, 44.26979071753365, 44.083822182246614, 41.99079547609602, 36.6123617036002, 33.58522960117885, 32.1818984576634, 34.05177681786673, 33.82620702471052, 32.847567149571006, 34.659813676561626, 31.936995301927837, 33.34114980697632, 33.26341336114066, 33.547070094517295, 33.89300700596401, 33.84319537026541, 36.810402733939036, 40.7347765650068, 41.277406556265696, 38.3898846081325, 34.70120756966727, 32.783122607639854, 34.98690012523106, 39.20513064520699, 41.14714867728097, 43.03276470729283, 42.94632911682129, 40.89170510428292, 33.341472898210796, 33.04335348946707, 36.4378924369812, 42.02518905912127, 46.24462856565203, 47.66258914130074, 49.736449241638184, 47.62033714566912, 44.65998765400478, 38.80232620239258, 34.398571831839426, 36.93981293269566, 37.18886763708932, 37.28792463030134, 40.37652397155762, 48.1513705934797, 48.577117988041465, 51.191676480429514, 50.114281858716694, 54.999959809439524, 54.64622007097517, 47.60834802900042, 14.982822724751063, 1.2617163253682, 0.5953661671706608, 0.05911118204572371, 0.016708287011299814, 19.183385712759836, 51.888031891414094, 41.30250692367554, 33.69896466391427, 28.283853088106426, 37.489033290318076, 40.49470935549055, 50.35148293631417, 30.079623699188232, 1.365367272070476, 0.12911351610507282, 0.031026054439800124, 0.01975940284319222, 0.026441993990114758, 0.024018292348565798, 0.043729410639831, 0.012598684539885392, 0.07956582374338593, 0.03583922563120723, 0.0692650175520352, 0.03340194480759757, 0.0021026971142938627, 0.017499095826808895, 0.038562203624418805, 0.022012403733762245, 0.03166873227538807, 0.006346941501500883, 0.058426872694066594, 0.03907660102205617, 0.041934057870613675, 0.018076094865266765, 0.026908420658271228, 0.0641468550477709, 0.08795317475284849, 0.027013712329789996, 3.910147394452776, 37.16617482049124, 45.149821758270264, 46.565055165972026, 27.39226371901376, 23.486926215035574, 35.3332712990897, 46.23044729232788, 37.09597717012678, 49.96057728358677, 6.496665562902178, 0.04653811474729862, 0.13228120255683148, 1.726543320076806, 4.9718542865344455, 4.432621530124119, 21.838622433798655, 37.59304434912545, 49.13581568854195, 46.756151471819194, 48.346472535814556, 47.932342529296875, 48.94816221509661, 47.91680288314819, 47.759106567927766, 46.172447204589844, 46.94762992858887, 44.896393162863596, 39.81330646787371, 32.452989373888286, 34.290833064488, 34.31976536342076, 33.990504128592356, 34.4659936768668, 33.62798534120832, 36.33595541545323, 41.94926609311785, 43.790424074445454, 43.54968636376517, 44.12092208862305, 42.345615659441265, 38.11306142807007, 33.652932848249165, 34.76603773662022, 35.55175392968314, 35.67450080599104, 36.769995485033306, 36.30381999697004, 35.97795990535191, 34.87493685313633, 34.61514023372105, 33.20999561037336, 34.25210727964129, 32.6609593800136, 33.75271245411464, 33.52067041397095, 33.61625678198678, 33.630841050829204, 33.33576495306832, 32.6302170753479, 33.46378551210676, 32.988858767918174, 33.03884063448225, 36.394118785858154, 39.497701917375835, 40.159097467150005, 42.34530993870327, 42.07667521068028, 43.284352030072895, 42.353908334459575, 44.990291118621826, 44.75375011989048, 46.10789149148123, 43.81454127175467, 42.948906898498535, 36.41873277936663, 33.32304627554757, 40.95786932536534, 40.722367082323345, 46.42941590717861, 46.04657016481672, 46.26385423115322, 45.14419024331229, 45.893556935446604, 46.01375034877232, 44.73147072110857, 46.26421553747994, 46.52674279894148, 43.40850939069475, 37.773249353681294, 34.726957593645366, 34.28198800768171, 34.59856183188302, 34.87029545647757, 34.9874837739127, 34.71097673688616, 33.70988028390067, 34.62224129268101, 35.16548619951521, 34.86945819854736, 36.45075355257307, 35.64405032566616, 38.824532645089285, 41.92184502737862, 43.67158555984497, 40.695244789123535, 37.363972663879395, 34.381402833121165, 36.37274612699236, 39.69742093767439, 42.30713306154524, 44.15388781683785, 44.206107003348215, 41.15065751756941, 34.33431141717093, 34.92628404072353, 38.07627419063023, 43.797952447618755, 48.322376183101106, 49.63247987202236, 51.14909097126552, 49.07769053322928, 45.72989559173584, 40.28204584121704, 36.419306005750386, 39.1055977003915, 37.62903254372733, 40.150495597294395, 42.983877182006836, 51.94658088684082, 50.461601461683, 53.17317417689732, 52.413642270224436, 55.555503027779714, 55.65508113588606, 50.054204259599956, 15.992507151194982, 1.6053835643189294, 1.2820767185517719, 0.09326850596283164, 0.040773532286818535, 21.726521934781754, 56.50159406661987, 44.88108280726841, 33.78474364961897, 31.287401267460414, 40.68141439982823, 47.49132994243077, 58.1429739679609, 37.18587991169521, 2.8063320304666246, 0.12437508893864495, 0.023575027473270893, 0.052280532861394544, 0.031373169206615, 0.04336681848924075, 0.05510606124464955, 0.0621132313140801, 0.041297439352742264, 0.035305381419935396, 0.021319471898355653, 0.0146918115538678, 0.04648559274418013, 0.11462042879845415, 0.12971829436719418, 0.15147691752229417, 0.13255533070436545, 0.08754802149321352, 0.1236671055001872, 0.14301965704986028, 0.105957653639572, 0.09099784280572619, 0.09067562688142061, 0.15457635692187718, 0.17838022033018724, 0.09876764552401644, 4.9925868426050455, 46.927879674094065, 54.29172992706299, 53.49285037176949, 31.95829153060913, 26.317721332822526, 30.393452984946116, 57.193141324179514, 41.812685353415354, 55.31807960782732, 8.247071385383606, 0.15456982941499778, 0.5970816665462085, 5.066336759499141, 9.067998443331037, 6.772902488708496, 21.759518929890223, 38.14779199872698, 51.03375434875488, 47.344014235905235, 50.31788839612688, 49.32030078342983, 50.52252326692854, 50.600958006722585, 49.874054840632844, 47.13225051334926, 49.76868193490164, 48.68785490308489, 42.85810089111328, 34.25061689104353, 35.47708511352539, 36.04893227985927, 36.07655831745693, 35.27248845781599, 36.131178106580464, 38.592007705143516, 43.63718155452183, 44.442241532461985, 43.952487332480295, 46.31822041102818, 46.47123711449759, 41.05506420135498, 36.137824058532715, 37.197862080165315, 37.19538157326834, 36.874312264578684, 37.962785788944785, 38.57115963527134, 37.46941157749721, 36.56950868879046, 36.642985888889854, 34.793090547834126, 36.97645078386579, 34.53381504331316, 36.626275471278596, 35.87976796286446, 34.86099181856428, 35.174289567129954, 36.38875477654593, 34.15153210503714, 35.26203489303589, 34.3329565184457, 34.93474694660732, 39.765325682503835, 42.306340966905864, 44.24922404970442, 43.8385021345956, 44.4392329624721, 45.01737519672939, 44.35111590794155, 47.58361939021519, 46.85170309884207, 47.96688897269112, 45.965425627572195, 43.497185775211875, 37.388412952423096, 35.905830655779155, 40.56475067138672, 43.79807751519339, 47.83491836275373, 47.59820018495832, 48.69145059585571, 48.45422519956316, 47.96843147277832, 48.428023542676655, 45.79513570240566, 48.78379562922886, 49.27356719970703, 46.17118610654558, 39.43963929585048, 35.620867661067415, 36.35717521395002, 37.04702016285488, 36.68351125717163, 35.67668948854719, 37.33680868148804, 35.54842921665737, 36.675229004451204, 36.98385756356375, 37.84981850215367, 37.59299571173531, 35.932678495134624, 40.94873939241682, 44.13681261880057, 46.332582337515696, 42.45072453362601, 38.854976177215576, 36.34319543838501, 39.61238540921892, 42.386648246220176, 45.61897802352905, 46.4211927141462, 48.30871949877058, 44.77492822919573, 36.396383898598806, 36.252180985042024, 40.36702230998448, 46.3275831086295, 49.398485388074604, 52.80470773151943, 53.5312044279916, 52.377469948359895, 48.9228811945234, 42.57403768811907, 38.762766633714946, 41.568918228149414, 41.21428912026541, 43.423395906175884, 44.68580715996878, 52.88416038240705, 53.02045972006661, 56.133891923086985, 55.46046209335327, 57.814636843545095, 58.592595372881206, 50.80579437528338, 17.713301488331386, 4.2960229856627326, 2.595581659248897, 0.17988329753279686, 0.28132352286151474, 23.745466947555542, 62.80092470986502, 54.336240087236675, 44.97707564490182, 41.0066248348781, 49.622804505484446, 54.02290759767805, 65.57738317762102, 44.308982031685964, 4.879283002444676, 0.40697482760463444, 0.10815911979547568, 0.14922301418014935, 0.07151185734463589, 0.1509471173797335, 0.10335823348058121, 0.15853597516460077, 0.1681158582546881, 0.11896523780056409, 0.23370423380817684, 0.13368609574224266, 0.17431021801062993], [0.04904972568952611, 0.040597435486103804, 0.04092905929844294, 0.010509152913333049, 0.026908892240109186, 0.039494890719652176, 0.030661742202937603, 0.057125815722559176, 0.05139028473890253, 0.052817382982798984, 0.0691583857738546, 0.049170433676668575, 0.014754908525251915, 2.0336200424603055, 26.378217560904368, 42.190208775656565, 42.31053767885481, 34.26469741548811, 19.891674654824392, 14.470014401844569, 43.39627013887678, 41.079740728650776, 42.16355895996094, 7.8290199892861505, 0.0892385643507753, 0.04710049135610461, 0.9042720028332302, 3.294247563396181, 3.337482729128429, 19.96543151991708, 43.84408153806414, 50.49974707194737, 50.55879633767264, 48.851808071136475, 47.33575977597918, 47.04161473682949, 48.365371635981965, 47.596067087990896, 46.57699564525059, 46.82049526487078, 45.820736340114046, 44.08541679382324, 38.151502336774556, 32.07256507873535, 33.19114862169538, 33.957600934164866, 32.89610379082816, 32.86614315850394, 33.500301769801546, 42.52961785452706, 44.39654670442854, 42.289724349975586, 42.0216246332441, 39.8287627356393, 37.86871412822178, 36.42033781324114, 35.08416795730591, 32.81976740700858, 32.26698957170759, 31.9563946723938, 32.26057638440813, 33.091118880680625, 31.154520443507604, 32.583459172930034, 30.729881286621094, 31.898620401109966, 32.76098217282976, 31.997819832393102, 30.705354145595006, 32.51180240086147, 31.298118863786968, 32.8527261870248, 32.19145223072597, 32.225248268672395, 32.242538860866, 37.94877127238682, 42.47075271606445, 44.67327955790928, 44.85961634772164, 44.39852694102696, 42.0483751978193, 42.43815524237496, 42.90085315704346, 45.83367041179112, 46.17188787460327, 44.24289076668875, 42.7407979284014, 42.71912997109549, 37.83919470650809, 32.91692754200527, 42.30373191833496, 43.55445977619716, 44.84941986628941, 43.25016341890608, 44.44640697751726, 43.374629974365234, 44.11822618756975, 40.28320271628243, 40.63783182416643, 39.52351100104195, 39.87843540736607, 34.99802419117519, 33.745493275778635, 31.233146258762904, 32.705990655081614, 32.7106146812439, 32.93151181084769, 32.94264282499041, 33.03639486857823, 33.74486446380615, 34.813841342926025, 32.41714709145682, 34.217873505183626, 35.07435710089547, 32.89697231565203, 38.081679889133994, 40.91606896264212, 39.90570708683559, 38.881421021052766, 34.70837116241455, 36.122756889888215, 40.940210478646414, 45.54966279438564, 49.7139891896929, 46.78796032496861, 44.70212153026036, 45.203871795109336, 43.010742391858784, 32.01996374130249, 33.676042556762695, 37.86942284447806, 43.25658702850342, 48.83552149363926, 47.380461011614116, 51.12453951154436, 47.575847830091206, 43.185916900634766, 36.692936488560264, 37.641455922807964, 44.2815922328404, 45.892132554735454, 41.05053397587368, 40.5714487348284, 41.078271184648784, 45.728200231279644, 49.12393774305071, 52.71381834575108, 54.99477992738996, 50.82584340231759, 12.521342601094927, 1.5155264203037535, 0.5634603649377823, 0.05132942014772977, 0.07875380053051881, 18.84719017573765, 53.22503553118025, 40.40667567934309, 36.20799739020211, 24.610642739704677, 30.674188000815256, 40.675536223820274, 50.18894025257656, 28.49355319568089, 0.5390065599765096, 0.14026912035686628, 0.023947560161884342, 0.06993059933717762, 0.03840636109401073, 0.024754116078838706, 0.053504643961787224, 0.05553685973531433, 0.026141613322709287, 0.045711570885032415, 0.04596413518967373, 0.04468677605369261, 0.03679858933069876, 0.013872690864705613, 0.036777463142893145, 0.019405650307557414, 0.05812743519033704, 0.01841052950892065, 0.08229400270751544, 0.015814169542863965, 0.03579778749761837, 0.0454062911947923, 0.044432512018829584, 0.06803314401102917, 0.05221478960343769, 0.026463612115808895, 2.6435396458421434, 32.32515641621181, 49.178772926330566, 48.118293694087434, 39.50919076374599, 22.39091215814863, 18.236441782542638, 46.79681232997349, 41.39386183874947, 46.24719245093209, 8.56680577141898, 0.20488343174968446, 0.04107151094025799, 1.5291533576590675, 3.49402260354587, 4.822068495409829, 19.04485947745187, 44.45756925855364, 50.82767077854702, 51.526048115321565, 51.00150775909424, 47.56388650621687, 48.28501919337681, 49.27948359080723, 49.19722734178816, 47.40639863695417, 48.12675312587193, 47.034280913216726, 45.35202823366438, 38.49866560527256, 33.12267759868077, 35.22476128169468, 35.23237998144967, 34.83777093887329, 33.93846559524536, 35.97938428606306, 44.32109274183001, 45.892664091927664, 43.48627710342407, 43.82527623857771, 41.483201776232036, 39.24491603033883, 38.29843241827828, 36.79220887592861, 33.339131355285645, 34.23207562310355, 33.09107024329049, 32.977446351732524, 33.96803365434919, 31.67356824874878, 35.06075600215367, 32.381891931806294, 34.459806306021555, 34.191657951899934, 32.64780991418021, 33.400410992758616, 33.12631150654384, 33.39053760256086, 34.671173981257844, 33.44389281954084, 33.590788160051616, 34.048969745635986, 38.587609495435444, 43.95465169634138, 45.449525356292725, 45.30546835490635, 44.80687952041626, 43.40926327024187, 43.902964047023225, 43.25207069941929, 46.70271635055542, 46.3857638495309, 45.34889112200056, 44.611735888889854, 43.79858820778983, 37.873921803065706, 34.78369310923985, 43.038441385541645, 44.117798873356406, 45.637852805001394, 45.01400184631348, 45.79997859682356, 44.539165428706575, 45.47196108954293, 42.82316534859793, 42.60905313491821, 41.813088348933626, 41.78273514338902, 38.690519264766145, 34.683548722948345, 33.360559599740164, 34.477743080684114, 34.37436778204781, 35.53790616989136, 34.78754241125924, 34.5959597315107, 35.39893872397286, 34.155033997126985, 35.395933628082275, 35.22039086478097, 35.42591510500227, 34.69248063223702, 39.820824418749126, 42.35887977055141, 42.14497947692871, 40.389350346156526, 36.47971017020089, 37.496116978781565, 43.738072872161865, 46.695969649723594, 52.015906538282124, 48.275256974356516, 46.75072145462036, 47.768153122493196, 44.662287507738384, 33.126054423195974, 36.06800855909075, 38.633752482278005, 44.07634939466204, 50.04773548671177, 48.612981115068706, 51.88895600182669, 49.307227747780935, 44.134127140045166, 38.25093105861119, 39.27318825040545, 46.394973686763215, 47.278364181518555, 42.735993249075754, 42.58776038033621, 44.945166042872835, 47.28366565704346, 51.38699729101998, 55.57682357515608, 57.95844718388149, 51.64506033488682, 14.137250406401497, 0.541539124080113, 0.7159104102424213, 0.05216199618631175, 0.059763396690998755, 20.40470358303615, 56.710554191044395, 45.910434109824045, 41.83399895259312, 34.66425704956055, 39.283614022391184, 46.576863629477366, 56.392038345336914, 34.869572843824116, 1.7143770243440355, 0.09834501998765127, 0.0741160883169089, 0.025791845483971492, 0.02399626201284783, 0.020683458972988383, 0.03840203204059175, 0.005048039726846452, 0.024708701730040566, 0.014313660595299942, 0.049853918608278036, 0.0431645743415824, 0.03762620188561933, 0.14392472776983464, 0.12448829572115626, 0.12316379536475454, 0.147717290690967, 0.1361122384135212, 0.11992558198315756, 0.11858829802700452, 0.20120475414608205, 0.19809436319129808, 0.1239450741559267, 0.16206669142203672, 0.1273826411260026, 0.10081236330526215, 3.022761902638844, 39.16921540669033, 56.62018244607108, 54.813004629952566, 45.81832531520298, 26.977298191615514, 20.219777277537755, 50.36086995261056, 50.707161222185405, 51.354938302721294, 10.919138380459376, 0.32364730749811443, 0.37169081664511133, 4.396559945174626, 7.396316579410008, 5.2872534309114725, 22.535735198429652, 45.13184676851545, 52.443300655909944, 54.21056801932198, 53.39684363773891, 50.02008860451834, 51.17007105691092, 51.14696134839739, 50.23115055901663, 48.297053473336355, 50.50792162758963, 49.783690043858115, 48.521841594151084, 42.21704966681344, 34.61325032370431, 36.61373049872262, 37.621486800057546, 36.414417948041645, 36.58950907843453, 37.27373988287789, 47.61799212864467, 47.5835360118321, 43.345374584198, 45.52112654277256, 44.06545114517212, 41.092403820582796, 40.59562151772635, 39.246621813092915, 34.78321368353707, 35.99517059326172, 35.788746561322895, 35.13496971130371, 36.0559847014291, 33.69418430328369, 36.16862889698574, 33.781936577388215, 36.82416711534773, 36.307030064719065, 35.13352101189749, 33.49809571674892, 36.23202773502895, 33.479095867701936, 35.46909121104649, 34.7736633845738, 35.03347390038626, 37.43968023572649, 41.50840636662075, 45.34823799133301, 47.95672723225185, 48.8242688860212, 48.662931714739116, 45.73952579498291, 46.85511119025094, 45.33102035522461, 51.11784839630127, 49.296621322631836, 49.7733268056597, 46.78252683367048, 44.85865749631609, 39.09053747994559, 37.524844305855886, 43.628002984183176, 46.492748737335205, 48.1781975882394, 47.68500402995518, 47.35183095932007, 47.472979749952046, 48.81868600845337, 44.166575227464946, 45.464470931461875, 44.391682965414866, 43.956697940826416, 39.26580926350185, 36.53918327604021, 34.60546139308384, 36.56988736561367, 36.29051767076765, 36.97973033360073, 36.94003527505057, 36.91413239070347, 37.86750166756766, 36.18421023232596, 37.002655914851594, 36.76497541155134, 37.86569166183472, 36.52071149008614, 41.81839329855782, 44.15219593048096, 44.348197664533345, 42.6815367426191, 38.1900509425572, 39.651583671569824, 46.97841044834682, 49.4574373790196, 54.63826090948922, 52.453823702675955, 48.25855350494385, 51.120047501155305, 48.90942253385271, 34.83172253199986, 38.144675731658936, 41.04662561416626, 47.34400033950806, 53.23706981113979, 50.08135781969343, 54.80336747850691, 52.34740856715611, 46.67368330274309, 39.931290354047505, 41.50223984037127, 49.36145148958479, 51.449513707842144, 46.244041442871094, 45.23314108167376, 46.8433062008449, 49.29775387900216, 54.092841216496055, 60.186602456229075, 60.180529730660574, 53.87992409297398, 14.986317668642316, 4.302668937614985, 2.490976312330791, 0.18669188075831958, 0.13709470283772263, 23.298034225191387, 62.898797035217285, 51.94491331917899, 49.81648901530674, 37.53876154763358, 45.03053855895996, 54.463635308401926, 63.705524580819265, 42.685149805886404, 3.01192792398589, 0.24893107531326158, 0.1108993970389877, 0.15194400745843137, 0.12943611879433903, 0.07992902318281786, 0.14069663813071592, 0.11724053749016353, 0.19356641758765492, 0.0848676385357976, 0.12650685597743305, 0.06946848306272711, 0.06650854367762804], [0.06156824555780206, 0.11739280074834824, 0.026585980817409496, 0.017218469010133828, 0.028325044017817293, 0.03291151326681886, 0.061003867270691056, 0.05334188376686402, 0.031623226324362416, 0.0198169205603855, 0.004351071456247675, 0.06303230699683939, 0.07301449349948338, 0.2152779639831611, 17.037926162992203, 41.923981598445344, 43.52493340628487, 34.96301916667393, 22.320073536464147, 21.96210755620684, 29.745193004608154, 40.65912805284773, 44.84774882452828, 8.802431344985962, 0.10754927287676505, 0.05625175405293703, 1.3274228338684355, 2.615741423198155, 5.842835732868739, 25.54970567567008, 43.61334228515625, 53.25940479551043, 48.758809907095774, 47.176663398742676, 45.40766245978219, 45.86185925347464, 46.185336112976074, 47.10718488693237, 48.09478793825422, 47.93727227619716, 46.55448348181588, 44.962814467293875, 41.175490379333496, 33.136025088174, 34.69744512013027, 34.10993671417236, 32.90385103225708, 31.801463740212576, 36.005446978977744, 41.77453279495239, 43.10266358511788, 42.646510873522075, 42.69034011023385, 43.15482023784092, 39.48494849886213, 39.594129017421174, 37.03614970615932, 35.71593986238752, 31.658091136387416, 31.44803319658552, 30.840910026005336, 32.532025132860454, 31.551842757633754, 33.92110204696655, 30.605265344892228, 34.18157264164516, 30.76243359701974, 31.235918590000697, 32.24709687914167, 35.62777417046683, 32.9261999130249, 30.96007510593959, 31.800918306623185, 30.902366842542374, 32.45945119857788, 41.64604670660836, 44.78498574665615, 43.22726910454886, 45.529377528599326, 43.333687714168, 43.88864728382656, 44.015385900224956, 46.00375189099993, 43.60636281967163, 45.517176491873606, 45.07644878114973, 45.004979610443115, 45.72037655966622, 40.896228381565635, 38.24535512924194, 43.816716057913645, 44.876111371176584, 42.21557664871216, 42.03670917238508, 41.453428745269775, 41.55002607618059, 38.516279288700645, 38.78767939976284, 37.83183309010097, 35.53020756585257, 33.60698093686785, 32.05155720029558, 33.08147825513567, 33.0771495274135, 32.71876491819109, 33.44605370930263, 32.97978442055838, 34.741079807281494, 32.53969941820417, 32.92377151761736, 33.5207051549639, 32.649394103458945, 33.200136116572786, 33.93678413118635, 33.11585099356515, 37.30929034096854, 41.97685391562325, 40.88422884259905, 39.354548181806294, 37.058297089168, 40.35666601998465, 42.950029032570974, 43.688403674534385, 45.31029387882778, 42.45698833465576, 41.682135650089805, 44.84049143110003, 47.92799643107823, 38.21088511603219, 32.11004366193499, 34.14312825884138, 36.66411188670567, 46.26643896102905, 48.75841038567679, 49.363567216055735, 48.37629073006766, 47.46492678778512, 39.883844579969136, 41.427258355276926, 52.39963470186506, 52.712939398629324, 51.59338310786656, 50.470887729099815, 47.904824188777376, 48.43487794058663, 51.068999086107524, 55.094055788857595, 54.127408504486084, 44.24504470825195, 10.848245041710989, 0.3222964528415884, 0.9222661001341683, 0.3568569283400263, 0.13723339539553436, 19.034746374402726, 50.56811039788382, 39.21598025730678, 30.029224940708705, 29.599451065063477, 32.46521472930908, 39.63604402542114, 54.09384870529175, 21.899761370250157, 0.7642159696136201, 0.042148556360708814, 0.010123950279583889, 0.023779261424871426, 0.050080685011510334, 0.012187806989199348, 0.04442848152081881, 0.04685123151700411, 0.022687279752322605, 0.03200391161122492, 0.018090600247627923, 0.03947721488241639, 0.030345266684889793, 0.014537996146827936, 0.06758940246488367, 0.020526026974299123, 0.005098715690629823, 0.09757493702428681, 0.05171522498130798, 0.01719999928692622, 0.0427306172704058, 0.01880883295754237, 0.021202090429142118, 0.04357821946697576, 0.023276198954720582, 0.010124387934670916, 0.5078177249857357, 21.627880096435547, 47.64880044119698, 50.279972076416016, 39.21646663120815, 21.98171537263053, 20.33464663369315, 38.06257929120745, 45.942211696079795, 47.74351133619036, 10.258081555366516, 0.1589328231556075, 0.03268836684791105, 1.7561810782977512, 5.803077706268855, 4.837737117494855, 25.411318404333933, 44.79917744227818, 54.877334526606965, 50.41696623393467, 47.83587721415928, 46.870296478271484, 47.77275630405971, 47.249543053763254, 48.99134179524013, 49.478268078395296, 49.33074392591204, 47.623661858694895, 46.9115548815046, 40.87706524985177, 34.94516577039446, 35.55775022506714, 35.60548782348633, 33.930329254695344, 34.03851270675659, 37.94063145773751, 43.95116370064871, 43.97535037994385, 43.38260303224836, 43.59431116921561, 44.5932606288365, 42.04753793988909, 42.12882491520473, 38.695150239127024, 37.50947489057268, 34.155704498291016, 33.75323356900896, 32.50461448941912, 34.25810357502529, 34.31248712539673, 35.43186971119472, 33.746427808489116, 36.42074080875942, 32.72980213165283, 33.24510138375418, 33.625859192439485, 37.359487601688926, 34.23283645084926, 31.83215045928955, 32.752897943769185, 32.5980087007795, 33.89996215275356, 42.119121755872456, 46.173089912959504, 46.81945998328072, 47.50640753337315, 45.78335850579398, 44.903688771384104, 47.06529419762747, 46.273001534598215, 44.819094453539165, 47.11714860371181, 47.102727617536274, 47.00711693082537, 45.69261155809675, 41.34038850239345, 38.16713578360421, 44.706773349217, 47.44662870679583, 43.85818985530308, 45.05503095899309, 42.70245082037789, 43.219205720084055, 40.900105476379395, 41.122159481048584, 39.463221481868196, 37.96293864931379, 35.51040172576904, 32.972019808632986, 34.561250005449565, 34.87524952207293, 34.37354094641549, 34.728996889931814, 34.62197726113455, 35.82351187297276, 33.270795822143555, 34.681895051683696, 35.22080775669643, 34.32192972728184, 35.41106333051409, 35.3419565473284, 34.995171955653596, 38.34310586111886, 42.94292449951172, 41.43783698763166, 42.16052259717669, 39.24380431856428, 42.9693728174482, 43.3042551449367, 45.41045910971505, 46.645369393484934, 45.82852527073452, 43.068228312901084, 46.09751088278634, 49.73891237803868, 39.67591626303536, 34.100574016571045, 35.720306805201936, 40.41952289853777, 47.50399650846209, 52.381294931684224, 50.63294403893607, 50.68762288774763, 50.31457757949829, 41.44965934753418, 44.18480035236904, 54.13626398359026, 55.639173235212056, 52.13957405090332, 51.997948919023784, 49.84408726011004, 51.389825207846506, 52.44619805472237, 55.580183029174805, 55.919460092272075, 46.7124924659729, 11.230220522199359, 0.979468013559069, 0.9913551871265683, 0.09367088401424033, 0.04245765281042882, 20.293709584644862, 56.217346736363, 43.69309023448399, 33.148375511169434, 32.39358575003487, 39.73481614249093, 45.798741817474365, 61.72642053876604, 28.156807013920375, 1.2597295748335975, 0.050914862392736335, 0.10672303435525723, 0.061373282090893815, 0.052281150328261514, 0.03952301599617515, 0.03415055213762181, 0.05526150343939662, 0.07368758666728224, 0.006513932362265352, 0.0034852005524693853, 0.0638636141749365, 0.027930209579478418, 0.1759692361312253, 0.18435565754771233, 0.12898487943623746, 0.13942783192864486, 0.2221069982541459, 0.1588832629578454, 0.11087720215852771, 0.1671214380434581, 0.08866865600326232, 0.11458420859915869, 0.14071905692773207, 0.12049282368804727, 0.16593751657221997, 0.6598573380282947, 24.51820043155125, 55.70026527132307, 56.70802852085659, 45.05355446679251, 29.637805121285574, 30.60830170767648, 39.18036726542881, 49.87994343893868, 54.37377078192574, 12.272154143878392, 0.2050253405634846, 0.17915373668074608, 3.9760345561163764, 7.021854272910526, 9.257996065276009, 27.558634860174998, 47.15856334141323, 56.9209178515843, 52.758380617414204, 50.980333123888286, 48.67960391725813, 50.7441395350865, 50.66098696844918, 52.06790338243757, 52.71502733230591, 52.77316985811506, 50.27566071919033, 49.546596663338796, 44.30313859667097, 36.542452403477256, 38.106377261025564, 37.30901936122349, 37.58049937656948, 34.69014603751046, 39.89757422038487, 46.64428200040545, 45.13393817629133, 44.38978263310024, 44.602074418749126, 47.64609064374651, 42.77589675358364, 43.59760114124843, 42.39986024584089, 40.296147210257395, 36.48175294058663, 36.22234889439174, 34.6423875944955, 36.362751143319265, 35.02606017248971, 37.72173193522862, 34.93986429486956, 37.62942164284842, 33.83016402380807, 34.55241537094116, 35.1337433542524, 38.839144706726074, 34.889361313411165, 33.78490693228585, 34.858594690050396, 33.84652355739048, 35.02496235711234, 45.20045328140259, 49.61037070410592, 48.39958109174456, 47.60902200426374, 45.62135778154646, 48.85961437225342, 47.503530979156494, 49.797120911734446, 47.21815456662859, 48.60866975784302, 48.140951769692556, 48.28181954792568, 48.076420375279014, 43.77890396118164, 40.422955308641704, 44.848877906799316, 48.752129214150564, 44.84441021510533, 46.21288572038923, 44.72621440887451, 45.64364412852696, 42.85553700583321, 42.96241767065865, 42.02458456584385, 38.60636615753174, 37.451148237500874, 33.59398085730416, 37.54522337232317, 37.15242086138044, 35.673277923039024, 36.56949826649257, 37.0747504234314, 37.31503650120327, 36.016063826424734, 35.691718442099436, 37.32110922677176, 36.64332635062081, 36.84572737557547, 36.73048802784511, 37.73544420514788, 40.96638781683785, 45.09855100086757, 44.28987101146153, 44.38941437857491, 41.61629452024187, 45.410466057913645, 47.35237291881016, 47.7457069669451, 50.149672508239746, 48.93024281093052, 45.83130802427019, 48.44625561577933, 51.38793877192906, 41.08788054330008, 35.46519674573626, 38.827148641858784, 41.22487122671944, 49.31269250597273, 54.31586796896798, 51.8618997165135, 53.394126892089844, 53.59224782671247, 44.58633327484131, 46.15695966993059, 57.067427567073274, 57.38668687002999, 56.32774666377476, 55.73320320674351, 53.05999149594988, 53.91843448366438, 54.765958377293174, 60.25302028656006, 58.07968282699585, 47.95165504728045, 13.108975206102643, 0.8823790975979396, 2.892192006111145, 0.9287033889974866, 0.14182641250746592, 23.092595100402832, 62.308505875723704, 50.40658215114048, 44.54019028799874, 39.06531204496111, 42.895079204014365, 52.35469722747803, 70.71682671138218, 34.80423893247332, 2.837321864707129, 0.15301278153700487, 0.25639145927769796, 0.20100644550153188, 0.2714248097368649, 0.16049718564110144, 0.11732565292290278, 0.23501654767564364, 0.10269906385136501, 0.09516177472791501, 0.07957269730312483, 0.20929564642054693, 0.11453897745481559], [0.018046936519177895, 0.06645698858691113, 0.12297581402318818, 0.009058203315362334, 0.02464072948454746, 0.01058737188577652, 0.03956063737028411, 0.06967278995684215, 0.045491287883903296, 0.05677340498992375, 0.07066557489867721, 0.01756217922749264, 0.1273021533020905, 0.04966447841642158, 10.927446688924517, 37.520873410361155, 46.5682235445295, 40.93853596278599, 28.766129289354595, 25.22939545767648, 20.885989665985107, 28.72239211627415, 46.63552727018084, 12.893063408987862, 0.03758704362969313, 0.03285407188481518, 0.9573496175663812, 3.1375092310564856, 3.428305455616542, 24.384793281555176, 44.89010851723807, 50.24658945628575, 45.231956413814, 42.77765464782715, 39.224575178963796, 39.04128170013428, 39.5634422983442, 43.084883144923616, 42.754336493355886, 44.179634366716655, 42.2977043560573, 40.71450866971697, 38.22583416530064, 34.58568334579468, 32.03155333655221, 32.648879936763215, 32.45995494297573, 32.86187696456909, 34.57637275968279, 40.536544459206716, 43.6790201323373, 42.468737738473074, 41.851845400674, 42.81528956549508, 40.31929860796247, 40.36058132989066, 39.688603673662456, 38.4852660042899, 32.94851752689907, 32.39777898788452, 32.35595778056553, 31.374507359095983, 32.7594118799482, 32.70493105479649, 32.33002362932478, 32.87032944815499, 30.246019159044536, 33.514528206416536, 32.33298703602382, 33.413383279527935, 31.792142731802805, 34.09615496226719, 33.700437682015554, 31.018738746643066, 32.62128169195992, 44.717581272125244, 43.82470996039254, 44.11032261167254, 37.15801068714687, 36.87818935939244, 43.534608772822786, 41.92667749949864, 44.61724233627319, 44.030727522713796, 44.24064302444458, 46.30192688533238, 48.048905508858816, 46.56062568937029, 44.75346524374825, 38.69158928734915, 44.83596120561872, 43.5065449987139, 43.723398276737754, 41.63675001689366, 40.918705804007395, 40.34374931880406, 39.27865300859724, 38.52074350629534, 34.56812872205462, 35.86277266911098, 33.80241639273507, 34.02977187292916, 33.551245961870464, 33.325849873679026, 33.78719983782087, 33.64426497050694, 33.11288758686611, 32.704097270965576, 33.741428579602925, 32.63195412499564, 33.198663098471506, 33.134055273873464, 34.156586919512065, 35.40192992346627, 34.48792566571917, 36.069582326071604, 41.01174565723964, 40.19189296449934, 42.154415130615234, 40.83948939187186, 42.81057868685041, 41.775092124938965, 42.48790781838553, 46.048800536564414, 46.32749278204781, 48.945396832057405, 47.35299825668335, 45.4071170261928, 46.37480306625366, 33.74111591066633, 33.48756572178432, 35.39152152197701, 38.78174563816616, 47.17117779595511, 49.05149929864066, 49.34420953478132, 49.251367705208914, 42.13295909336635, 40.15369176864624, 52.401069504874094, 50.61368015834263, 53.89536646434239, 48.76990270614624, 48.128295625959126, 54.44960689544678, 51.396134172167095, 53.0588241985866, 54.25318826947893, 38.76051541737148, 5.2477689896311075, 0.393183630492006, 0.28655980474182535, 0.04969086325062173, 0.056123517719762664, 18.236160380499705, 51.45437049865723, 44.2547721862793, 36.652480602264404, 30.137651579720632, 32.6280631337847, 34.14452484675816, 47.60188273021153, 22.662267105919973, 1.1164258016007287, 0.07494856257523809, 0.033045235555619, 0.08589465556932346, 0.051852166918771606, 0.01846356550231576, 0.013876029256997364, 0.0650753623672894, 0.06177654902317694, 0.06808427162468433, 0.08491557024951492, 0.03943890818793859, 0.06035282649099827, 0.013987786519075078, 0.0703200309404305, 0.03972321096807718, 0.032913148536213806, 0.03710353314610464, 0.04844896435471518, 0.009584755819690014, 0.06316122865038258, 0.05960453807243279, 0.014769719248371465, 0.05343379472781505, 0.02319378748403064, 0.044544816349766085, 0.030458015456263508, 14.86954276902335, 44.59115185056414, 52.78499221801758, 43.30572121483939, 30.571667330605642, 19.147892577307566, 29.19590663909912, 38.02289465495518, 49.86682176589966, 13.342038631439209, 0.03783330434401121, 0.0017220576285451117, 1.7247957395655769, 4.505808208669935, 3.949439023222242, 23.97200080326625, 46.15970073427473, 51.80807202202933, 47.67575250353132, 45.743962219783235, 41.2677902494158, 42.16680029460362, 41.26345109939575, 45.983331135341096, 45.60859741483416, 46.52765301295689, 44.34555040087019, 41.87548317228045, 40.111658641270225, 36.252535343170166, 33.935286794389995, 34.04367174421038, 34.10097006389073, 34.419194085257395, 36.853877612522666, 41.24625083378383, 43.44766248975481, 44.29409204210554, 41.544120107378276, 44.78966883250645, 41.93907655988421, 43.41831677300589, 42.112826687949045, 39.355996881212505, 34.06406470707485, 33.264723096575054, 34.0451204436166, 33.41419621876308, 33.72428042548043, 34.5558443069458, 33.78658144814627, 34.34987538201468, 31.927528381347656, 33.45061867577689, 33.527597767966135, 35.39199052538191, 33.08512258529663, 34.04805258342198, 35.05480834415981, 32.06838921138218, 34.59685952322823, 47.40599911553519, 46.74266849245344, 46.60990578787667, 38.483379568372456, 37.55661841801235, 44.13330725261143, 43.54255403791155, 46.063756534031455, 45.05973836353847, 46.690021991729736, 46.883623123168945, 49.2385378565107, 47.79840905325753, 47.51980366025652, 39.5980339050293, 47.76613467080252, 45.98681565693447, 43.84432125091553, 42.11624520165579, 42.12626797812325, 42.119719300951274, 41.244597162519185, 40.387745312282014, 36.54371002742222, 35.8974997656686, 35.85321889604841, 34.65554748262678, 34.10759517124721, 34.42480475561959, 34.3789883341108, 34.2852988243103, 34.4182665007455, 34.62239762714931, 34.413559096200125, 34.55144957133702, 37.041357381003245, 34.4713785307748, 35.6595378603254, 36.76567717960903, 35.59553452900478, 38.4672771181379, 42.582163606371196, 42.95424311501639, 42.81738792146955, 43.22713361467634, 45.344367844717844, 44.83389064243862, 44.086875915527344, 48.61716045652117, 49.7320545060294, 50.78285142353603, 46.10288184029715, 46.48549134390694, 47.26684406825474, 35.101253577641074, 33.92692811148507, 36.249429498400005, 42.539939403533936, 50.37977947507586, 50.98300470624651, 51.112810952322825, 51.59094429016113, 44.87306111199515, 41.28515379769461, 52.51341492789132, 53.55178499221802, 55.62606545857021, 52.555260453905376, 50.74412563868931, 56.07212938581194, 54.35517392839704, 54.45397731236049, 55.25650119781494, 39.929369177137104, 6.671991194997515, 0.6269848133836473, 0.7185783556529454, 0.1290989276021719, 0.02364959677548281, 20.440978390829905, 56.76820339475359, 46.08372565678188, 43.906069891793386, 38.47829696110317, 33.817448820386616, 39.0549453326634, 55.503822326660156, 27.449836492538452, 1.8304340881960732, 0.12385835738054343, 0.053631652146577835, 0.08077574667653867, 0.027577496898759688, 0.0289695980027318, 0.03640744781919888, 0.0726735975061144, 0.07386252656579018, 0.050708048311727386, 0.05316169200731175, 0.04943206660183413, 0.07933983765542507, 0.0659722974523902, 0.163829077567373, 0.2102494766669614, 0.06191832212997334, 0.08693821528660399, 0.13909308346254484, 0.0982536891741412, 0.1842966385717903, 0.15795745620770113, 0.14741674038980687, 0.18880231465612138, 0.1743383907846042, 0.2234092155205352, 0.20729007332452706, 16.692889043263026, 50.59653895241873, 59.04199096134731, 52.18969488143921, 38.98430299758911, 33.576217787606375, 31.00277873447963, 38.17403881890433, 56.50949764251709, 16.343040296009608, 0.12139329394059521, 0.26648640472974094, 2.7569755017757416, 6.621914659227643, 5.355730967862265, 28.497800282069615, 47.054465430123464, 54.37141534260341, 49.38946315220424, 47.53293922969273, 43.7236762046814, 43.52604859215872, 45.15649897711617, 47.48842559541975, 47.10898447036743, 48.45405844279698, 46.645258222307476, 44.53999573843819, 42.1903338432312, 37.45441389083862, 35.610261235918315, 35.46667671203613, 35.18940189906529, 36.34431062425886, 37.98530837467739, 43.977295875549316, 45.43929065976824, 46.106418473379954, 45.14397137505667, 46.48248972211565, 43.46172564370291, 43.72279378346035, 43.489424637385774, 42.132472719464985, 36.00695126397269, 34.759287561689106, 35.27887037822178, 35.761964729854036, 36.37114804131644, 35.78555733816964, 35.53398043768746, 36.8397866657802, 33.86223690850394, 36.81320285797119, 35.285280091421946, 37.097283431461875, 35.231025082724436, 36.404186725616455, 37.682797704424175, 34.33842127663748, 35.523231574467246, 49.27877834865025, 47.29270873750959, 48.03301845278059, 38.94976002829415, 37.389674050467356, 45.13704054696219, 43.54053211212158, 47.30304765701294, 47.34871816635132, 48.07982151848929, 48.17666203635079, 52.60085800715855, 50.65791586467198, 49.99764939716884, 41.79072904586792, 48.33342381886074, 48.394904954092844, 46.53785296848842, 44.1510842187064, 44.47710064479283, 44.41981622150966, 44.0324124608721, 42.638801847185405, 37.80704886572701, 38.775731972285676, 37.99060637610299, 37.06295933042254, 36.96171365465437, 37.752693108149934, 36.31836952481951, 36.07687793459211, 36.25657572065081, 36.78858191626412, 36.932854311806814, 37.2353823525565, 38.29915850503104, 35.898514202662874, 37.270717416490825, 38.72851548876081, 37.189030919756206, 39.2674594606672, 45.13032511302403, 44.620622634887695, 45.837269578661235, 44.819917815072195, 46.86833013807024, 46.83615303039551, 45.871374811444966, 49.936824866703574, 51.963701248168945, 52.07216610227312, 45.798071316310335, 48.447197096688406, 50.95202963692801, 38.00405808857509, 35.81942980630057, 38.460249015263145, 43.83662264687674, 51.83772693361555, 52.95556354522705, 52.56020409720284, 55.774041243961875, 46.59581484113421, 43.380125999450684, 54.60511105401175, 56.811435086386545, 57.00616530009678, 54.65635401862008, 51.30493559156145, 60.003982952662874, 56.90404762540545, 58.54394408634731, 56.708900519779746, 42.04023885726929, 6.103139136518751, 2.1286299271242957, 1.0936422241585595, 0.23864757855023655, 0.13635796308517456, 22.547474179949077, 61.901132992335725, 53.59413773672921, 48.97667762211391, 40.3179715020316, 43.127416542598176, 45.50407566343035, 64.99272700718471, 36.72008310045515, 3.893495602267129, 0.22622875922492572, 0.10865108482539654, 0.19539971064243997, 0.18763602152466774, 0.1603468358516693, 0.2020284549466201, 0.16860151290893555, 0.3298845099551337, 0.13428734562226705, 0.13077357916959695, 0.21381186693906784, 0.17654513594295296], [0.05557307993460979, 0.048883111415697, 0.03331332813416209, 0.03211325074412993, 0.025273225902180587, 0.0618775761021035, 0.042190951228673966, 0.043883651827595065, 0.043865599403423924, 0.06861419390354838, 0.01563804390441094, 0.026345826918259263, 0.018820284932319607, 0.08591928639050041, 7.058946362563542, 32.426259653908865, 44.409314019339426, 39.38337278366089, 27.881866795676096, 28.98355405671256, 29.872831412724086, 37.26421390260969, 45.31892006737845, 20.97355260167803, 0.028158911503851414, 0.05101169612524765, 2.523398778268269, 11.74681908743722, 0.6604032058800969, 20.98317411967686, 43.19151367459978, 51.40511471884591, 44.539200169699534, 43.37351131439209, 36.98521941048758, 36.8669992855617, 34.66076905386788, 38.19275031770979, 36.953959465026855, 39.200513567243306, 40.72563968385969, 37.424581800188335, 34.7976450920105, 33.517227581569124, 33.27664620535714, 34.2391072000776, 34.67967162813459, 35.3673209462847, 33.36042410986764, 37.03189393452236, 39.10376337596348, 43.4940173966544, 41.74613203321184, 43.19417136056082, 42.17321000780378, 42.30616726194109, 41.99919932229178, 38.45188685825893, 33.77407816478184, 30.95558656964983, 31.620536123003276, 32.12203972680228, 32.34651517868042, 32.64309903553554, 31.353805201394216, 32.345452104296, 31.218284061976842, 33.55879865373884, 31.908115114484513, 32.364973068237305, 31.7513324873788, 33.31061942236764, 32.063539368765696, 31.908622332981654, 32.93522562299456, 42.669193267822266, 45.32430492128645, 45.49646391187395, 44.841012545994346, 45.14193902696882, 42.202642577035085, 42.589803150721956, 40.796646799360005, 39.928090708596365, 44.35623673030308, 46.608675956726074, 44.73023394175938, 47.303172724587576, 46.33026163918631, 40.67178767068045, 45.93603822163173, 44.74250446047102, 42.023386001586914, 41.34035723549979, 43.19510241917202, 41.08914164134434, 39.57172455106463, 39.03160285949707, 37.26467943191528, 36.82701587677002, 32.36027956008911, 32.58359118870327, 31.948411192212784, 32.12308890478951, 32.90978479385376, 34.42616660254342, 33.585257393973215, 33.26372603007725, 33.64962897981916, 33.354858602796284, 33.07877887998308, 35.10854223796299, 32.7450395311628, 34.03986413138253, 33.24570935113089, 36.082822118486675, 41.003772599356516, 42.73908519744873, 42.092888832092285, 42.568777901785715, 40.463935783931184, 41.293276241847444, 40.2089056287493, 42.02937534877232, 44.24398510796683, 45.088021005902974, 43.07612494059971, 44.238047872270855, 48.853121280670166, 42.12063646316528, 32.5873293195452, 32.873018401009695, 34.6900418145316, 45.36757482801165, 48.34500299181257, 49.121714319501606, 48.82708638054984, 45.41197729110718, 42.75639316013881, 45.49755825315203, 50.38376426696777, 52.47598498208182, 52.50291272572109, 49.463972159794395, 54.435206753867014, 53.27216863632202, 56.34499556677682, 50.985485213143484, 23.669130563735962, 1.6505706310272217, 0.7568603243146623, 0.5179047722901616, 0.007840987827096666, 0.002909906333245869, 18.719678572246007, 52.18830871582031, 42.224251474652974, 26.61066780771528, 19.478665045329503, 40.0810136113848, 41.30731507710048, 43.87610231127058, 25.415014845984324, 1.7207169298614775, 0.08513869291969708, 0.019895113239596997, 0.063092839105853, 0.04548557801172137, 0.023530469774933796, 0.08756425205085959, 0.03307375777512789, 0.052307921927422285, 0.03197834101904716, 0.044820637442171574, 0.03705282622416105, 0.05529465326773269, 0.04524926122810159, 0.03943673348320382, 0.019803784122424464, 0.006336187145539692, 0.0045580318463700155, 0.07469413229929549, 0.05455106370417135, 0.05220747160326157, 0.059882228528814654, 0.05728928837925196, 0.023467069159128835, 0.024310573004186153, 0.03659817044224058, 0.03129086969420314, 9.835025719233922, 39.36757952826363, 49.259823662894114, 45.38254819597517, 33.342174666268484, 30.159802436828613, 29.94133022853306, 37.91941513334002, 52.16224602290562, 22.15111940247672, 0.024337213985355835, 0.0405958341434598, 1.7343977157558714, 9.895202330180577, 3.7969777413776944, 23.36371033532279, 46.6400158064706, 52.238544191632954, 46.29922751017979, 44.26810230527605, 39.64123085566929, 38.56993327822004, 37.03010824748448, 40.545264448438374, 38.97810173034668, 41.283382007053916, 43.87706116267613, 40.272651876722065, 36.48084620067051, 34.81299713679722, 34.71063280105591, 35.28293854849679, 37.23095635005406, 37.239950793130056, 35.749881812504356, 39.746888637542725, 41.36829594203404, 43.676973887852256, 42.749121870313374, 43.48274394444057, 43.87218700136457, 44.39894035884312, 44.38618694032942, 40.09710911342076, 34.02096503121512, 32.96543639046805, 33.594679151262554, 34.193655558994834, 34.120115825108115, 34.1318096433367, 33.793067591530935, 33.687875338963096, 32.342884744916645, 35.224431242261616, 34.501599720546174, 32.79885332924979, 33.80942365101406, 34.86519547871181, 32.61661945070539, 32.89617327281407, 34.66904435838972, 44.419844014304026, 46.71213115964617, 47.92768723624093, 43.87217657906668, 45.96249348776681, 43.54998861040388, 43.97363764899117, 41.45513800212315, 41.05644689287458, 43.619192668369834, 49.21330547332764, 47.69416175569807, 47.96926525660923, 46.75637034007481, 43.3142466545105, 46.67853661945888, 46.513131277901785, 43.95645475387573, 42.93221385138375, 44.90900761740548, 43.35841982705252, 40.08461625235421, 41.70951850073678, 39.622661794934956, 38.37446655545916, 33.640377453395296, 34.52476501464844, 34.25621019090925, 34.29762145451137, 33.48031875065395, 35.73622512817383, 34.65548842293875, 34.15097624914986, 34.74264662606375, 34.36014134543282, 34.295995576041086, 36.059028012411936, 33.82879522868565, 35.57393952778408, 33.94406584330967, 37.448198727199006, 42.942688260759624, 43.38206107275826, 43.55111421857561, 43.65255444390433, 42.69467231205532, 43.573087896619526, 41.531985078539165, 44.51118850708008, 45.8415253502982, 47.52955198287964, 45.91703142438616, 45.160000869206016, 50.99404191970825, 42.86932570593697, 34.125698702675955, 34.04999460492815, 36.622134344918386, 46.35639033998762, 50.298666204724995, 51.174010685511995, 50.756604603358674, 47.47769062859671, 43.98744024549212, 47.416640281677246, 52.53399896621704, 53.17782252175467, 53.839384828295024, 51.51439251218523, 56.01109640938895, 55.10763604300362, 57.80782413482666, 52.516350541796, 25.96590277126857, 2.3539556648050035, 2.150110283068248, 1.1520492157765796, 0.11173135561070272, 0.06904962339571544, 20.58781467165266, 55.787472111838206, 46.97980356216431, 35.21626363481794, 23.02757212093898, 42.258106572287424, 45.91885185241699, 52.448636872427805, 31.30260740007673, 2.1982180901936124, 0.10121822224131652, 0.02347505890897342, 0.045179090529148064, 0.017924055523638214, 0.10314203186758927, 0.05806051128144775, 0.04281434849170702, 0.03574311453849077, 0.023371852036299448, 0.09019023685583047, 0.023191841784864664, 0.037580946992550573, 0.11923663823732308, 0.11791064510388033, 0.05526319299159305, 0.11634417915982859, 0.0852891377040318, 0.17597919702529907, 0.18242457402603968, 0.13133886669363293, 0.18904480950108596, 0.2066898276763303, 0.13234881178608962, 0.18176802354199545, 0.15956323647073337, 0.13919394090771675, 10.933868561472211, 45.72894368852888, 57.94081265585763, 49.320887906210764, 39.32014765058245, 34.89047997338431, 40.80943843296596, 48.06466749736241, 55.887748513902935, 27.02869575364249, 0.17007767941270555, 0.1850786908928837, 4.730863835130419, 18.35074312346322, 3.2466404608317783, 24.5413361958095, 48.19382756096976, 56.77079507282802, 49.214660372052876, 48.05931043624878, 40.3467161996024, 40.82634687423706, 39.24819210597447, 42.77041115079607, 40.18278040204729, 43.470303194863455, 45.47356264931815, 41.79861525126866, 38.06581367765154, 36.99601343699864, 36.52553006580898, 36.39998653956822, 38.27970354897635, 37.84759507860456, 37.070855958121165, 40.84842130116054, 43.211416789463584, 47.04573849269322, 44.189281940460205, 46.70730563572475, 46.36375890459333, 45.26546062741961, 47.4308945110866, 41.510410921914236, 36.77598830631801, 35.22093282427107, 35.42708240236555, 35.42666203635079, 36.300210407802034, 35.81478493554251, 33.99540955679757, 35.00138711929321, 34.389257771628245, 36.47752843584333, 35.738038608006065, 35.356797899518696, 34.1347348349435, 36.82691512789045, 34.67177847453526, 34.61238179888044, 35.75929314749581, 46.82497337886265, 48.89081178392683, 48.62659958430699, 46.52538790021624, 47.185949666159495, 45.06023863383702, 44.50446612494332, 41.616346631731304, 41.499408449445454, 45.93505505153111, 51.33645609446934, 49.16793373652867, 49.48149899074009, 48.8401073047093, 44.58763606207711, 47.846066747392925, 48.86179610661098, 46.034695693424766, 44.807904379708425, 47.72184337888445, 45.28817081451416, 42.772891657693044, 45.02976730891636, 40.96561656679426, 39.676982811519075, 35.156470911843435, 37.12806395121983, 35.46052755628313, 35.99921097074236, 36.5504150390625, 37.1149457522801, 37.4648813520159, 35.93774720600673, 35.8991881779262, 35.77651078360421, 36.49687916891915, 38.535789830344065, 35.4590163230896, 36.45052426201956, 35.8791252544948, 39.4433913230896, 47.21943303516933, 45.80211169379098, 46.60393728528704, 47.1122327532087, 44.72527640206473, 46.90351928983416, 42.986131872449604, 45.651599815913606, 49.6965457371303, 49.69633034297398, 46.3863787651062, 45.41921383993966, 52.91628190449306, 45.552855491638184, 36.20428357805525, 36.79917444501604, 38.34994288853237, 49.370588370731895, 53.11897822788784, 52.93049791881016, 54.50512647628784, 49.54354293005807, 47.03910296303885, 49.71813031605312, 53.554157802036826, 55.5636602129255, 56.171631063733784, 52.05927719388689, 57.85126774651663, 56.492102827344624, 60.601340430123464, 55.22496679850987, 27.138395650046213, 2.5043437778949738, 3.096752400909151, 1.4718525409698486, 0.2431788896875722, 0.24072959540145739, 23.011427981512888, 62.734777859279085, 52.52381290708269, 38.035297189440044, 30.960564953940256, 53.77382857458932, 53.09444761276245, 58.36015033721924, 37.78596108300345, 3.863168018204825, 0.18795569294265338, 0.08799856874559607, 0.10093224008700677, 0.1450623052992991, 0.21392641722091607, 0.18247786616640432, 0.1434911438929183, 0.10996051491903407, 0.15879575908184052, 0.24103879023875507, 0.128998979393925, 0.1948619716401611], [0.02718023839406669, 0.0502203173403229, 0.03092652353058968, 0.060948247755212445, 0.016523252208051935, 0.028075483926971043, 0.06261481797056538, 0.020695803221315145, 0.038833631202578545, 0.04214999146227326, 0.02313119262856032, 0.04600680825699653, 0.025831329436706643, 0.03928918265072363, 2.3797150254249573, 28.38548960004534, 49.85835886001587, 40.42455686841692, 28.661086423056467, 17.357242788587296, 24.60216246332441, 36.4097626549857, 44.04754563740322, 28.062662397112163, 0.4846093846218926, 0.04345512303656765, 2.1165947786399295, 8.34667728628431, 1.9421168267726898, 12.277109946523394, 41.01746055058071, 49.809346267155235, 47.84448255811419, 46.738572529384065, 45.65425402777535, 43.82567228589739, 39.13627747126988, 35.9981062071664, 35.56264175687517, 36.58021933691842, 34.708235672542024, 35.87694352013724, 33.62478916985648, 33.31944710867745, 35.16574675696236, 34.841786997658865, 36.82591806139265, 35.71641928809029, 36.2585802759443, 36.5331209727696, 39.75919737134661, 43.26372282845633, 43.59828206471035, 40.098050594329834, 42.46824441637312, 43.60960068021502, 41.687530926295686, 38.52874435697283, 32.7846268926348, 32.43052584784371, 32.846632616860525, 31.68917042868478, 32.47364289419991, 32.87451226370675, 31.86738477434431, 32.469453130449565, 31.98364203316825, 32.587558610098704, 33.10730818339756, 33.516845430646626, 32.660532065800254, 31.9029769216265, 32.797283036368235, 30.71505730492728, 33.34927225112915, 40.92763423919678, 43.377218178340364, 46.17666128703526, 45.696884700230186, 44.187291281563894, 45.13281256811959, 44.84808233806065, 44.91896438598633, 44.26046623502459, 44.92433186939785, 46.54868868419102, 46.21515430722918, 45.60124969482422, 45.79693875994001, 42.49247973305838, 45.15197222573416, 44.36979613985334, 41.60678938456944, 39.48216227122715, 42.52649116516113, 40.63184595108032, 40.29959004265921, 38.73610986982073, 37.30606290272304, 35.567821638924734, 34.38121523175921, 33.279595715659006, 32.59388494491577, 33.421067987169536, 32.81881202970232, 34.148447104862754, 32.16328770773751, 33.74757773535592, 32.920071601867676, 31.942095279693604, 32.68670245579311, 33.486308097839355, 33.73915304456438, 32.780808857509065, 34.07359068734305, 33.90209524972098, 35.02232551574707, 40.051633153642925, 39.53702524730137, 39.73133162089756, 38.729880809783936, 36.27482169015067, 36.495048318590435, 38.073595660073416, 41.439886706215994, 43.094332695007324, 45.59302650179182, 46.737304483141216, 43.80639450890677, 46.992355482918875, 36.19653633662632, 33.00281422478812, 34.58877876826695, 35.62667982918875, 45.6881925037929, 50.218709809439524, 51.14773259844099, 49.76712553841727, 46.17491034099034, 43.6020827293396, 46.951760632651194, 48.450660773685996, 51.12810046332223, 53.50834138052804, 53.10841696602957, 54.2074864932469, 52.363253934042795, 44.455884320395334, 13.77544902052198, 0.9497012794017792, 0.7382969632744789, 0.9077921339443752, 0.04835278880117195, 0.0724502984168274, 18.900489807128906, 55.27747433526175, 41.00953265598842, 35.28975125721523, 36.24065392357962, 35.63761976787022, 37.07437869480678, 44.0978228024074, 23.77226267542158, 1.7934942075184412, 0.06483054693256106, 0.029503900225141218, 0.06795686310423271, 0.04478826792910695, 0.015689851749422293, 0.08785912979926382, 0.03801981665726219, 0.02552583600793566, 0.024235828979206935, 0.01792852028406092, 0.014428970836369055, 0.04628335877454706, 0.04398969667298453, 0.05552857821541173, 0.07873281344239201, 0.07489692606031895, 0.08672227151691914, 0.01430961991926389, 0.021086420564513122, 0.050574068179620166, 0.013319641567899712, 0.021220717911741564, 0.03513425149555717, 0.05215404714856829, 0.03384665326614465, 0.004685849608254752, 3.7264973861830573, 35.66043070384434, 54.37690094539097, 45.506507532937185, 33.597802366529194, 22.774739333561488, 32.74796124867031, 42.448355197906494, 48.39054148537772, 30.65621301106044, 0.48064630585057394, 0.12555563130549022, 1.648864522576332, 12.786858456475393, 3.6673664791243414, 15.3422269821167, 42.56819772720337, 53.197944504874094, 49.20180967875889, 47.53493683678763, 46.47165053231375, 45.337061813899446, 39.648978097098215, 37.51404333114624, 37.44079542160034, 37.95136295046125, 36.66419873918806, 37.81968763896397, 34.82291916438511, 35.65980189187186, 36.510261399405344, 37.14654963357108, 38.0160367829459, 37.878396442958284, 36.793421336582725, 37.402493476867676, 41.308979170663015, 44.053475924900596, 45.11447279793875, 40.89724281855992, 42.31629078728812, 44.396525859832764, 43.88625015531267, 41.10320826939174, 35.2663288797651, 33.27362373897007, 34.343024458204, 34.436231068202424, 33.98787423542568, 33.70906734466553, 32.975063119615825, 34.27440404891968, 32.47556407111031, 34.23761681147984, 34.626233032771516, 35.914637497493196, 34.051995686122346, 33.34324468885149, 34.94622189658028, 32.653861795152935, 33.81186594281878, 43.46432774407523, 44.50775957107544, 48.01077726909092, 47.71336657660348, 46.6533910887582, 46.530095304761616, 47.91059814180647, 45.14125462940761, 44.88958740234375, 47.71340479169573, 49.063321658543174, 48.15266643251692, 48.07325199672154, 46.433320794786724, 43.23430415562221, 48.87900332042149, 44.987279074532644, 43.948634556361604, 41.345071588243755, 43.52087913240705, 42.5093777520316, 41.738329206194194, 40.497311455862864, 39.16698850904192, 37.58061749594552, 35.277303559439524, 35.26286172866821, 34.68295465196882, 35.042909554072786, 33.382436003003804, 34.29048218045916, 34.04585000446865, 34.12903731209891, 34.11646454674857, 33.88190031051636, 34.8094813483102, 35.57639571598598, 35.21841410228184, 35.13410466057913, 35.183645316532676, 35.77942207881382, 37.880859579358784, 41.18396718161446, 42.14856127330235, 42.07141195024763, 40.36835289001465, 38.15322201592581, 37.54622391292027, 41.035800320761545, 44.469638279506135, 44.57543502535139, 48.603597572871614, 47.57443734577724, 47.18091222218105, 49.43013790675572, 37.97133207321167, 35.476942675454275, 36.33823789869036, 37.851121289389475, 48.175508635384695, 50.92991699491228, 53.077702454158235, 50.764768736703054, 48.036909443991526, 44.784200600215364, 48.33185352597918, 50.46366507666451, 53.19553695406233, 54.614744731358115, 54.98379829951695, 54.012346335819785, 53.80756207874843, 44.380861146109446, 16.100131273269653, 1.0706149169376917, 2.787551701068878, 1.7228744540895735, 0.0715663708480341, 0.016840677675125853, 20.168595109667095, 58.820378167288645, 47.50236020769392, 38.80827733448574, 33.03313268933977, 40.83615773064749, 41.68834039143154, 51.01317378452846, 30.204277856009348, 2.831844512905393, 0.0656277034431696, 0.0459417604974338, 0.05697663979870932, 0.02787900054162102, 0.04378991900011897, 0.03305201751313039, 0.040273757318833044, 0.05434205795505217, 0.019940878730267286, 0.03090713099975671, 0.04699327603780797, 0.021350716739626865, 0.11622144574565546, 0.11202526305403028, 0.1040869868759598, 0.13885395415127277, 0.2006523045045989, 0.11168007193399326, 0.13360000321907656, 0.14013117418757506, 0.08768807112106256, 0.09275631380400487, 0.11341571022889443, 0.11511392731751714, 0.145822725923998, 0.15219848523182528, 4.369431572301047, 39.71677514484951, 63.90775884900774, 51.15890877587454, 38.950503485543386, 25.13482526370457, 32.827406951359336, 46.661353724343435, 54.381886277879985, 34.93757833753313, 0.959588348865509, 0.24695811261023792, 4.023429087230137, 12.23438721043723, 5.70375885282244, 15.707631008965627, 43.50514841079712, 55.2333220073155, 50.502165045057026, 49.34984104973929, 49.94561433792114, 47.95766176496233, 42.218581744602744, 40.20803362982613, 39.428612504686626, 41.9211745262146, 38.02443020684378, 40.04642200469971, 37.59474318368094, 37.11282655170986, 39.512991428375244, 37.78340762002127, 39.633688586098806, 39.625309058598106, 39.61511952536446, 40.679663453783306, 43.51197154181344, 47.677322796412874, 46.01159988130842, 40.16360684803554, 45.584052903311594, 46.049849714551655, 46.37319803237915, 42.64433608736311, 37.031616006578716, 35.73184428896223, 36.351929324013845, 36.294380869184224, 35.83390985216413, 35.30439111164638, 35.53490454810006, 36.289586612156455, 35.174866267613, 35.42794745309012, 36.348173822675435, 37.34843301773071, 36.08888094765799, 34.867366790771484, 36.35165139607021, 33.36235918317522, 35.6402496610369, 45.204191412244526, 46.418701784951345, 48.050989968436106, 49.012756143297466, 47.254354681287495, 49.10032081604004, 48.58231176648821, 48.357919692993164, 45.77614974975586, 48.81272792816162, 51.491696221487864, 49.27863938467843, 49.609630720955984, 48.73497411182949, 45.796226569584434, 48.79285955429077, 46.41480384554182, 45.845061983381, 43.60222864151001, 47.31174680164882, 44.180037362234934, 44.81582532610212, 42.38039486748831, 42.25069979258946, 40.03224767957415, 37.921822684151785, 37.204167570386616, 36.738148416791645, 36.7018267086574, 34.39478158950806, 38.20806762150356, 35.95326253346035, 35.843866620744976, 36.524744919368196, 35.51502922603062, 36.4396642276219, 37.150200911930625, 37.886331285749165, 36.764096464429585, 37.397997992379324, 37.399363313402446, 37.82092094421387, 44.33280740465437, 44.39965602329799, 43.49083859579903, 42.272093296051025, 40.134247234889436, 39.89287028993879, 42.07311773300171, 46.312995365687776, 46.41936533791678, 49.8524945804051, 49.28572307314192, 46.712805134909495, 52.31080893107823, 41.21235752105713, 36.976871149880544, 39.17026458467756, 39.71591704232352, 49.73695298603603, 54.541409969329834, 55.41133485521589, 53.80657543454851, 51.20077862058367, 45.94535575594221, 51.33132832390921, 53.96015494210379, 54.84761013303484, 57.95275313513619, 57.46629932948521, 56.33557380948748, 55.09847831726074, 46.18502344403948, 16.348944527762278, 1.6008885140929903, 2.583464869431087, 2.9853067696094513, 0.5395160583513123, 0.10974757705948182, 22.728415693555558, 65.06032603127616, 52.10034104755947, 49.49034057344709, 48.00792850766863, 45.98453664779663, 48.67561565126692, 59.902608735220774, 37.051758834293906, 3.687555338655199, 0.13562163045363768, 0.13646039473158972, 0.20430032589605876, 0.17043247180325644, 0.09043267063264336, 0.16946257384760038, 0.09213046024420432, 0.15049629871334347, 0.09851045361054794, 0.08098084067127534, 0.14436074080211775, 0.11219733953475952], [0.03181246295571327, 0.06533374171704054, 0.013216216715851, 0.016937197585191046, 0.07080468814820051, 0.017379632951425653, 0.049932112983827076, 0.05479937359424574, 0.005934574566448906, 0.04807615685941918, 0.010128291207365692, 0.031026356387883425, 0.11594760258282934, 0.0211984585704548, 0.5205966564161437, 22.613322257995605, 48.381765910557334, 47.45958014896938, 33.98330579485212, 25.4625301020486, 20.855454070227488, 31.633953094482422, 43.01631484712873, 37.05612577710833, 1.4854398518800735, 0.048233783936926296, 0.7324815381850515, 10.355175682476588, 2.963039747306279, 6.370775929519108, 34.80829668045044, 48.080787318093435, 53.647114276885986, 47.33928598676409, 47.06142405101231, 44.59048482349941, 42.51021500996181, 36.62113727842058, 33.25034727369036, 33.69980887004307, 33.220490864345, 33.95681578772408, 34.02411951337542, 37.033029964991975, 40.426512786320274, 39.689649377550396, 36.75101300648281, 36.68670742852347, 36.45297350202288, 37.59596259253365, 40.87277473722185, 44.347235339028494, 42.321460247039795, 39.67362335750035, 40.7961083139692, 44.986250741141184, 41.00614193507603, 38.18955414635794, 33.393421104976106, 31.43501922062465, 31.279494217463903, 30.641729491097585, 31.821325165884836, 32.09014054707119, 32.74121454783848, 32.91525650024414, 32.25597320284162, 34.62920338766915, 33.37873956135341, 32.86641066414969, 31.819841725485666, 33.00292887006487, 34.067524909973145, 31.611030987330846, 33.061467443193706, 40.426790714263916, 45.982024874006, 47.089984621320454, 43.64198623384748, 43.48342834200178, 43.04993718011038, 45.97916221618652, 46.26790503093174, 46.88846949168614, 46.86893115724836, 45.14378377369472, 41.61036075864519, 45.21377992630005, 45.04390341894967, 43.57425519398281, 46.472605909620015, 43.95703492845808, 42.13304247174944, 40.63972520828247, 40.01574223382132, 39.62253325326102, 39.76251861027309, 37.69519329071045, 36.62883588245937, 34.74149669919695, 32.36960056849888, 32.870412826538086, 33.72101477214268, 32.00774185998099, 33.069569042750764, 30.869355951036724, 32.31515448434012, 33.568397590092246, 33.804122175489155, 33.47439193725586, 33.12247610092163, 33.239118984767366, 33.21622119631086, 34.439996991838726, 34.57987117767334, 31.92141396658761, 34.88435861042568, 35.17954240526472, 36.606577328273225, 36.47201156616211, 33.8133875983102, 32.63954850605556, 34.91679627554757, 34.137121541159495, 38.53559875488281, 41.48466437203543, 41.575633662087576, 45.82913671221052, 45.84866462435041, 46.66097157342093, 42.748830045972554, 32.720192773001536, 34.00958040782383, 34.46201235907418, 39.31199393953596, 48.12122583389282, 49.974386828286306, 48.28952510016305, 49.559020042419434, 47.03590331758772, 45.50277287619454, 44.95448705128261, 47.66153301511492, 48.93122945513044, 49.98452077593122, 52.87396042687552, 53.39378295625959, 37.43499020167759, 9.28363926070077, 0.24702577612229756, 3.662375501223973, 1.9504885375499725, 0.027863702969625592, 0.025226654651175653, 18.144449370247976, 52.215184347970144, 44.4725078855242, 41.55629335130964, 23.205892426627024, 39.488749163491384, 38.66491862705776, 54.21644619532994, 26.229041474206106, 0.9824510706322533, 0.028776442831648246, 0.012701726867817342, 0.01807458173217518, 0.04133729649973767, 0.021196655363642743, 0.04781934153288603, 0.014732674629028355, 0.033109441931758604, 0.030159171670675278, 0.053283054780747206, 0.05289407440328172, 0.11674698468829904, 0.06715553360325949, 0.06605868853096451, 0.02211803976180298, 0.02189141754726214, 0.07761122219796691, 0.03778801891686661, 0.04665597288736275, 0.06137614550867251, 0.02998912740232689, 0.018740448502025435, 0.018425116315484047, 0.03138499267931495, 0.05151180696806737, 0.06636503352118389, 1.1256187025989806, 27.863537447793142, 54.773000376565115, 51.136066573006765, 40.56112371172224, 24.64089345932007, 26.142109087535314, 40.80933420998709, 48.598445483616416, 38.92686223983765, 1.534873896411487, 0.02994553492005382, 0.665239369230611, 8.258401291710989, 2.924094442810331, 10.331309488841466, 35.68807411193848, 51.55808278492519, 53.18485757282802, 49.42532280513218, 48.71990346908569, 47.279187543051584, 43.55753435407366, 38.62732539858137, 34.41080413545881, 35.34520483016968, 35.28111812046596, 36.61809744153704, 34.84685570853097, 38.7138408933367, 40.229774543217246, 41.601348945072715, 39.37469795772007, 39.018974508558, 37.440917015075684, 40.94065516335623, 41.346402168273926, 44.8913904598781, 42.19064998626709, 39.733158997126985, 40.911295550210134, 46.318647725241526, 43.01229184014456, 39.9724097933088, 34.81667620795113, 32.760794571467805, 32.281056199754985, 32.18378489358084, 34.43147850036621, 35.13954510007586, 34.57372202192034, 35.03852524076189, 33.754025663648335, 35.79313434873308, 33.79467609950474, 35.64914335523333, 33.797809737069265, 33.44288880484444, 34.23298236301967, 33.404406206948416, 34.14778355189732, 41.35650832312447, 46.51692846843174, 48.05074330738613, 44.61444916043963, 45.09972524642944, 44.259760992867605, 48.439495018550325, 47.183486529758994, 48.83736971446446, 47.62839010783604, 47.942743982587544, 44.25528982707432, 46.95825025013515, 46.46476486751011, 44.83770867756435, 47.101390089307515, 45.92248228618077, 44.76028490066528, 42.91523592812674, 41.42559773581368, 42.809720584324424, 41.644698756081716, 40.30980736868722, 38.41391495295933, 34.993351527622764, 34.570897579193115, 35.738472870418, 34.13172279085432, 34.322919845581055, 33.00087915148054, 33.83127573558262, 34.57956198283604, 34.778502804892405, 34.21822091511318, 35.375644888196675, 33.60846785136631, 34.5542323248727, 34.90115588051932, 35.709134101867676, 34.796630655016216, 33.97750057492937, 36.65294613157, 38.452248164585654, 39.09908029011318, 38.82479320253645, 36.2478209904262, 34.71142142159598, 37.191938740866526, 37.117384569985525, 41.61245216642107, 44.0535488809858, 44.56554079055786, 47.0416043145316, 46.713774408612935, 50.54341997419085, 44.32944447653634, 34.1806172643389, 35.82721873692104, 36.3311368397304, 40.99090453556606, 50.472312109810964, 51.265407289777485, 51.943308285304475, 50.94936500276838, 49.136545249394004, 47.109912054879324, 47.15790326254708, 50.638645035879954, 49.52228839056832, 53.46673904146467, 52.78864002227783, 54.255762577056885, 38.315577098301475, 11.223387837409973, 1.780977787716048, 5.172074445656367, 1.4291475010769707, 0.08452518869723592, 0.05547460075467825, 19.397213050297328, 57.91084507533482, 47.282498359680176, 41.28630372456142, 30.77234172821045, 44.21366316931588, 43.76553562709263, 59.3495112827846, 31.00872639247349, 1.9707418850490024, 0.08883386570960283, 0.022547243695173944, 0.049919784002538235, 0.0477074002181845, 0.06777855767203228, 0.027681560421894704, 0.02127027471682855, 0.0284801673011056, 0.03894056832151754, 0.05392699808414493, 0.06318653800657817, 0.08797047739582402, 0.13514080696872302, 0.2652329062776906, 0.08884377910622529, 0.07500936609825917, 0.10818768611976079, 0.1651031356304884, 0.1328918162201132, 0.17959531370018209, 0.09953054958688361, 0.15552314397479805, 0.12368305107312542, 0.10659228065716368, 0.1681092493236065, 0.10573157255670854, 1.1680951033319746, 31.493745395115443, 60.505427496773855, 58.614683696201865, 46.153006144932334, 33.22582360676357, 30.187942641122, 41.22162641797747, 54.2739633832659, 43.73279571533203, 2.1776173327650343, 0.07067575292395693, 1.9139242938586642, 21.590768030711583, 8.811483979225159, 8.884108287947518, 39.312428201947895, 52.12092161178589, 55.322849546160015, 50.86376667022705, 50.87922988619123, 48.260162012917654, 47.66276284626552, 39.945068631853374, 36.78076866694859, 37.3942494392395, 38.0951281275068, 37.45803737640381, 37.622445651463096, 40.61120980126517, 43.70201866967337, 43.42514337812151, 41.91916649682181, 40.75671550205776, 39.88289267676217, 42.71932104655674, 44.953854765210835, 47.789143630436485, 44.24794905526297, 41.5857641356332, 41.689879417419434, 48.780564716884065, 45.0796206338065, 42.12192187990461, 37.022517340523855, 34.71537842069353, 34.63501902988979, 32.833434513636995, 35.7047358921596, 35.098818234034944, 35.8895788192749, 36.71756437846592, 35.26804855891636, 38.681472710200715, 35.48259503500802, 37.436355522700715, 36.05720411028181, 35.06940998349871, 35.90105029514858, 35.58473702839443, 36.32853821345738, 43.69617523465838, 49.68100609098162, 50.98736470086234, 47.026578835078645, 46.41934101922171, 45.882443291800364, 50.494317054748535, 49.95675230026245, 50.29913520812988, 49.43123919623238, 49.64755746296474, 45.90522296088082, 49.65420341491699, 48.867448466164724, 47.43270799091884, 48.450685092381065, 46.950843470437185, 46.056777068546836, 47.32240533828735, 43.01935468401228, 43.51898227419172, 43.67484426498413, 41.71796751022339, 40.51901068006243, 36.96205064228603, 35.49619613374983, 37.868967737470356, 36.29678841999599, 34.76644768033709, 35.5600848197937, 34.62856067929949, 35.385195187159944, 36.47467620032174, 37.33140298298427, 38.02679259436471, 34.90028388159615, 36.844865798950195, 36.81858423777989, 38.66274731499808, 37.48968642098563, 34.56670781544277, 38.22224194662911, 39.12512213843209, 41.397071906498496, 41.643020766122, 37.48605598722185, 36.05561644690377, 39.15645851407732, 38.52462754930769, 43.913528782980784, 44.392204080309185, 46.126040186200825, 48.68026399612427, 47.44976929255894, 51.52904278891427, 47.23096009663173, 35.724698066711426, 38.13476760046822, 37.551091126033235, 42.60516561780657, 52.864087036677766, 54.12896490097046, 53.56043897356306, 53.126555238451274, 51.259883471897666, 50.043952192579, 49.91332605906895, 52.25480645043509, 54.372051102774485, 55.16201959337507, 56.81758771623884, 54.36675657544817, 39.8731096131461, 11.459501521927969, 2.131273716688156, 8.521780576024737, 5.401425361633301, 0.21748241569314683, 0.14574219738798483, 21.311160360063823, 60.56408418927874, 57.13333470480782, 51.38566671098982, 35.45387813023159, 50.457099028996055, 52.763081073760986, 66.29071998596191, 38.806078229631694, 2.9384911102907996, 0.11995589892779078, 0.08317484972732407, 0.13958727408732685, 0.14721208065748215, 0.1344009730964899, 0.1424382339630808, 0.1116981345361897, 0.1169274342911584, 0.1453376276684659, 0.13484659418463707, 0.12983350961336068, 0.1789904133017574], [0.017960798194898025, 0.023578094451555183, 0.0553616687788495, 0.044606810701744895, 0.022781886193635206, 0.04085473257250019, 0.07462704554200172, 0.01742486409576876, 0.029107476318521158, 0.03638920879789761, 0.022602980257943273, 0.03265366317438228, 0.06549369956233672, 0.04446615717772927, 0.11602040939033031, 13.1093556199755, 44.992997441973, 43.569030148642405, 31.418162890842982, 18.856420857565745, 26.643605743135723, 37.10331794193813, 39.94078506742205, 43.348379680088584, 4.075820675918034, 0.1011159195165549, 0.8306276659880365, 3.774066056524004, 1.276451391833169, 2.4430912818227495, 19.36517490659441, 42.2149269921439, 43.13837732587542, 47.96395683288574, 47.794135911124094, 46.490348134722026, 40.91712161472866, 36.673943587711875, 32.58647469111851, 32.464162077222554, 34.02582877022879, 35.420714378356934, 37.36249964577811, 39.86060980388096, 42.76145144871303, 43.913924830300466, 39.00697496959141, 39.264850412096294, 39.532095500401084, 41.20145232336861, 42.71972404207502, 43.28922619138445, 38.70901884351458, 42.07941280092512, 42.82875517436436, 43.37705489567348, 40.66262994493757, 37.19342565536499, 31.940069879804337, 32.5255320412772, 32.51046487263271, 32.83525841576712, 32.473688057490754, 33.07122618811471, 31.81402955736433, 33.88726084572928, 32.01950863429478, 32.30815764835903, 32.37574625015259, 32.211751392909456, 32.422410351889475, 33.040268489292686, 33.54738276345389, 31.511838504246303, 33.365037713732036, 43.6169935635158, 44.65392882483346, 49.22938013076782, 44.64889138085501, 42.40529373713902, 42.44376591273716, 40.826402459825786, 43.56745638166155, 43.65250928061349, 44.19672346115112, 40.96608904429844, 42.408712250845774, 45.05180352074759, 45.68521172659737, 44.172654901232036, 44.60035126549857, 44.631065777369905, 42.64308193751744, 39.560711656297954, 40.65420178004673, 38.472109590257915, 36.54564510072981, 35.091599055698936, 35.27148791721889, 34.029031889779226, 32.81829786300659, 33.596499579293386, 32.94259071350098, 33.80778387614659, 33.18799761363438, 33.03105865206037, 33.51366662979126, 33.540580477033345, 34.72167001451765, 33.601575238364084, 33.260703563690186, 34.03144291469029, 34.91465275628226, 35.0958548273359, 33.356025900159565, 33.67516360964094, 36.57111719676426, 34.19525711877005, 32.528210571834016, 33.650608675820486, 33.60965599332537, 32.537951946258545, 32.061017172677175, 35.12102467673165, 36.89810984475272, 42.06887238366263, 42.99356991904122, 44.15826865604946, 43.55074596405029, 45.81495891298567, 45.7256988797869, 41.797343730926514, 33.64096805027553, 33.33625132696969, 34.45806230817522, 38.27309928621565, 46.94881459644863, 50.18547657557896, 49.21957969665527, 48.58464636121477, 48.60941668919155, 46.400410652160645, 46.12073176247733, 46.020625591278076, 47.78093433380127, 48.913619245801655, 54.34776714869908, 30.85160330363682, 6.344152169568198, 0.5546233962689127, 3.3218807663236345, 0.9844827673264912, 0.05038203259131738, 0.15230747152652058, 15.163397720881871, 54.043877261025564, 48.40568855830601, 45.797275747571675, 30.98225028174264, 40.14481544494629, 36.9156505720956, 51.141486167907715, 21.375637905938284, 1.6121708686862672, 0.06572199266936098, 0.055057922577751536, 0.025072116604340926, 0.03684762705649648, 0.014204735368756312, 0.021441248578152487, 0.08801221408482109, 0.04070198755445225, 0.015093975866745626, 0.06415024093751397, 0.039070653662617714, 0.022895964893645475, 0.008569456237767423, 0.025242696915354048, 0.039452869045947275, 0.04515170824847051, 0.0165501544252038, 0.055490264735583744, 0.05336575123614498, 0.07023642864078283, 0.04778957759429302, 0.04476874308394534, 0.04204290506563016, 0.02635299224805619, 0.05802797552730356, 0.059647502909813604, 0.24000983259507588, 16.565240212849208, 50.16522257668631, 48.02876615524292, 38.233015128544395, 22.506342581340245, 24.447888135910034, 41.636791706085205, 46.031172956739155, 45.50159863063267, 4.4129429289272855, 0.17158657844577516, 1.5803829686982291, 6.092538791043418, 3.8751771109444753, 4.42770437683378, 21.21639735358102, 46.61852502822876, 44.23698827198574, 50.96786805561611, 49.37995106833321, 49.58114310673305, 43.23967511313302, 38.46061379568917, 34.30649777821132, 34.19671276637486, 35.71062101636614, 37.93064342226301, 38.53802367619106, 41.88100004196167, 44.34028714043753, 45.67133617401123, 40.9338424546378, 40.36901991707938, 39.5380813734872, 43.83029631205967, 43.81725454330444, 44.931745597294395, 39.740405968257356, 42.17035429818289, 44.501513140542166, 45.835049629211426, 41.50929921013968, 39.87288727079119, 33.57605797903878, 32.705167293548584, 32.40361547470093, 32.87869855335781, 32.75007002694266, 34.47242423466274, 33.7309124810355, 35.96699912207467, 32.81658165795462, 34.060100759778706, 34.276835918426514, 34.17071955544608, 33.31516007014683, 34.39529923030308, 34.548222133091514, 32.425710746220176, 34.693651403699604, 44.253010817936485, 46.14267069952828, 49.175211974552695, 44.442825181143625, 43.599574429648264, 43.35051277705601, 42.05131081172398, 44.31902912684849, 46.03173576082502, 46.453901359013145, 43.27372823442732, 44.66008840288435, 48.28108998707363, 46.94591719763619, 45.29898221152169, 45.889450550079346, 45.7455290385655, 43.483098302568706, 42.306181158338276, 41.367924213409424, 40.5957396371024, 38.89252771650042, 38.641426767621724, 36.251816204616, 34.46287740979876, 33.962648800441194, 36.247147015162874, 34.63147892270769, 34.70156192779541, 33.72898088182722, 33.97150775364467, 35.68673658370972, 34.564533029283794, 35.48535346984863, 34.88616861615862, 36.04017060143607, 34.82962417602539, 36.53289515631539, 36.360736165727886, 35.66787569863455, 35.352378845214844, 38.029380798339844, 36.41000236783709, 35.39497825077602, 35.45023380007063, 34.87132726396833, 34.26150471823556, 33.99398865018572, 37.47143350328718, 38.2980363709586, 42.241340569087434, 44.033256667000906, 44.64600787843977, 44.01582016263689, 46.92179652622768, 47.368096692221506, 43.62605054037911, 35.523050921303884, 34.51540231704712, 36.40123374121529, 41.33332913262503, 51.08524744851248, 51.272744587489534, 51.37087399618966, 51.64823913574219, 48.76314558301653, 49.42270680836269, 48.52266148158482, 47.40164259501866, 50.976793016706196, 52.19184187480381, 55.945477621895925, 32.494734151022776, 7.264362471444266, 2.792789774281638, 6.985405325889587, 1.6465648859739304, 0.02984667236783675, 0.07159712884042944, 17.283518927437918, 58.484703745160786, 53.301910400390625, 50.90317685263497, 31.69038983753749, 46.51546239852905, 42.78642674854824, 58.19303573880877, 26.68783971241542, 1.9676236638001032, 0.08815934083291463, 0.0892299876681396, 0.0079877269620608, 0.03943037900275417, 0.028457889300105826, 0.04399439552798867, 0.017596825225544826, 0.08577039545135838, 0.007830802168297981, 0.04188977667529668, 0.032013071833976676, 0.030163460011993135, 0.0814864035429699, 0.05007815746856587, 0.13075832570237772, 0.1348434050700494, 0.157159987570984, 0.1636774249907051, 0.19578513210373266, 0.13318172709218093, 0.15489064077181475, 0.10882191958704165, 0.19430508437965596, 0.1280090646552188, 0.1281456130423716, 0.2194197824490922, 0.28331203758716583, 18.491845403398784, 57.94389418193272, 53.64607204709734, 43.399987425122944, 28.04377371924264, 35.38064064298357, 46.32103443145752, 51.728577681950156, 50.11923939841134, 5.949756784098489, 0.25978972549949375, 2.6148778923920224, 9.977335248674665, 5.900269542421613, 4.98038797719138, 22.202331100191387, 46.880440848214285, 46.07139260428292, 51.16962289810181, 52.44546849387032, 51.06787347793579, 44.25500495093209, 40.090477057865684, 36.431302070617676, 36.964180265154155, 37.05767869949341, 40.532066345214844, 42.053819111415315, 43.651797090257915, 45.7855715070452, 47.033756324223106, 41.93795095171247, 42.18280547005789, 41.78848477772304, 44.519835540226524, 44.590592520577566, 46.04989487784249, 39.13575635637556, 43.51666504996163, 46.718780585697715, 47.576678139822825, 44.26311002458845, 41.689914158412385, 35.61886657987322, 35.026487486703054, 35.51699209213257, 36.31287349973406, 34.5724470274789, 35.73260511670794, 35.37166009630476, 37.47732904979161, 34.19708449499947, 35.81492042541504, 35.49750934328352, 35.85865933554513, 36.042946406773154, 36.2279109273638, 36.414845262254985, 34.48726211275373, 35.938674790518625, 47.130569049290244, 48.91592952183315, 50.773499148232595, 45.537944657461985, 46.07729162488665, 44.9200622013637, 44.126227038247244, 46.29452357973371, 46.884866850716726, 48.76521267209734, 45.521932533809114, 47.145080362047466, 48.73674937656948, 48.42850644247872, 46.768578324999126, 48.20448957170759, 47.80864722388131, 46.09274789265224, 43.588794299534385, 44.126845427921836, 41.5139753477914, 40.76485879080636, 40.115733759743826, 38.5597437449864, 36.83302954265049, 35.3156715120588, 38.00610433306013, 35.715057441166465, 35.73839296613421, 35.45755025318691, 36.6328067779541, 37.8457989692688, 36.14217363085066, 38.1994240624564, 36.986629894801546, 36.322816371917725, 37.45953123910086, 39.02817044939314, 38.70944268362862, 37.10924822943551, 36.9496237891061, 39.341985838753835, 37.61840179988316, 37.011928285871235, 36.37055049623762, 36.96622650963919, 36.46500778198242, 35.09228345326015, 38.84860815320696, 40.27134908948626, 45.59527424403599, 47.475713866097585, 47.60410615376064, 44.23965638024466, 48.44302470343453, 50.91759089061192, 46.888459069388254, 37.30406876972744, 36.15296418326241, 38.83764042173113, 42.986715521131245, 53.098043305533274, 54.55165161405291, 54.153144632067, 52.641963550022666, 52.464562143598286, 51.951847621372764, 50.53561019897461, 50.75516632625035, 53.49071727480207, 54.1489166532244, 58.61396108354841, 33.7187705039978, 7.625861610685076, 2.996198288031987, 10.862216132027761, 3.4336019371237074, 0.11952082227383341, 0.2624073778944356, 18.145913703101023, 64.60070964268276, 59.336295809064595, 56.78953089032854, 42.21754993711199, 51.62051929746355, 50.23387425286429, 64.51806082044328, 34.54591185706002, 2.787767095225198, 0.1769617564444031, 0.2787219653172152, 0.09726851739521537, 0.10838084468351943, 0.11649675454412188, 0.10988816951534577, 0.18453595787286758, 0.2507838287523815, 0.19012456227626118, 0.07788149626659495, 0.09880001842975616, 0.12826101827834333], [0.01909146993421018, 0.03058766314227666, 0.04611589293926954, 0.08236115053296089, 0.01577289086500449, 0.05749656047139849, 0.021545761630737355, 0.06794169784656592, 0.07340243232569524, 0.05789843640689339, 0.05447739854987178, 0.02792164816388062, 0.020038730265306573, 0.03194490959867835, 0.05545857375753777, 6.129432857036591, 39.446938378470286, 44.25675937107631, 31.653050218309673, 23.859889881951467, 25.31517791748047, 29.76154211589268, 41.17805773871285, 45.63514995574951, 10.663753867149353, 0.23737513540046556, 0.37270031390445574, 1.5047049266951424, 3.752467146941594, 1.5175158849784305, 7.193162543433053, 36.890887192317415, 43.292877469744, 47.52163103648594, 45.89546421595982, 44.82767200469971, 37.00541434969221, 32.953944069998606, 31.280077866145543, 37.87510299682617, 39.19638981137957, 36.54686450958252, 38.08224616731916, 41.73356621606009, 42.932818344661165, 42.170486313956125, 42.33159419468471, 43.12095819200788, 43.11383976255144, 43.65324231556484, 43.45301260266985, 40.492013454437256, 41.703053201947895, 42.70985760007586, 45.18293339865548, 42.57581990105765, 39.43669673374721, 34.19404465811593, 29.733311585017614, 29.56144789287022, 31.486665180751256, 31.269791058131627, 31.91710260936192, 32.992840085710796, 33.83193928854806, 33.90796300343105, 33.561161041259766, 32.415736607142854, 35.46128143583025, 33.255207538604736, 32.309835638318745, 31.878901413508824, 32.19509308678763, 33.29180370058332, 33.45548241479056, 43.59039238521031, 44.06385653359549, 43.75707966940743, 52.731890610286165, 48.0584523337228, 42.87910876955305, 42.4431266784668, 38.57848303658621, 40.935829639434814, 39.04644421168736, 41.052767821720664, 43.49245752607073, 47.654240880693706, 45.06877449580601, 42.23707437515259, 47.90362909861973, 44.01048394611904, 42.485743454524446, 39.08612189974104, 38.20029953547886, 36.1711163520813, 35.15205185753958, 32.371764932359966, 31.730953420911515, 32.34479897362845, 32.956789357321604, 33.10361521584647, 32.392842292785645, 34.04086814607893, 34.28855405535017, 32.309825216020855, 33.70699330738613, 33.38815437044416, 34.78371742793492, 33.679808480399, 33.676786014011924, 33.94209255490984, 34.82894672666277, 33.929808139801025, 35.27997166769845, 35.36900588444301, 34.30062655040196, 33.09841101510184, 32.0910507610866, 31.628717626844132, 32.97292307444981, 33.21784707478115, 35.40499060494559, 36.752861227308, 40.579109123774934, 42.79215553828648, 44.94267511367798, 43.126850264413015, 42.51004477909633, 42.57430519376482, 47.17550652367728, 45.31312526975359, 39.21624428885323, 34.998086724962505, 33.31805746895926, 34.511702401297434, 37.071505614689414, 44.93121406010219, 49.13397789001465, 49.92776788984026, 48.88243920462472, 46.62003973552159, 41.90588501521519, 42.28413105010986, 49.13643407821655, 51.13148423603603, 54.52357046944754, 30.74941267286028, 4.314122174467359, 2.221109147582735, 4.796945546354566, 0.3628911945436682, 0.05722099382962499, 0.029735399410128593, 15.754348959241595, 53.51197876249041, 39.11052049909319, 37.83369868142264, 31.568706035614014, 46.39136062349592, 44.585204192570274, 51.226139545440674, 25.160408530916484, 0.8393617144652775, 0.028832968191376755, 0.02221175392956606, 0.0309250578949494, 0.03400472139141389, 0.04248377980132188, 0.04254994714366538, 0.04961932191093053, 0.09894684662244149, 0.045786738994398286, 0.047312431769179444, 0.019999417642663633, 0.022707829185362374, 0.03662674694455095, 0.06597582583448716, 0.06379475644124405, 0.025209065327154737, 0.02848886272736958, 0.07797952422073909, 0.05064560951931136, 0.058153857343963215, 0.0104641584080777, 0.02178185449780098, 0.04973554817427482, 0.013491857996476548, 0.019735777950180427, 0.04562374470489366, 0.03302647066967828, 8.37111931187766, 46.24661227634975, 49.63587406703404, 36.319960662296836, 26.177894047328405, 25.147297280175344, 34.88755825587681, 45.63042170660836, 48.84773990086147, 10.150883878980364, 0.10396425346178667, 0.3269120923110417, 0.6971426201718194, 3.536057250840323, 3.2320700883865356, 9.069804106439863, 39.01519468852452, 44.45679800851004, 48.179753984723774, 47.51252542223249, 46.02808795656477, 39.82843617030552, 35.65368400301252, 33.37424407686506, 38.08528600420271, 40.36359337397984, 38.54231766292027, 41.090868268694194, 44.27858713694981, 45.41696262359619, 44.81652709415981, 43.853597096034456, 43.84559971945626, 44.728660174778526, 45.95724759783064, 44.01791157041277, 41.5872996875218, 40.705750465393066, 43.63475315911429, 46.47248779024397, 43.859377997262136, 42.2150868007115, 35.62279578617641, 32.24488040379116, 32.74334764480591, 33.48991073880877, 32.5067024230957, 33.858512674059185, 33.52753176007952, 34.899060998644146, 34.185501847948345, 34.87726102556501, 34.57948555265154, 35.99521575655256, 34.126136439187185, 33.83584417615618, 34.41043588093349, 35.1787885257176, 34.41240569523403, 34.879380226135254, 45.67893402917044, 45.28744125366211, 44.93104730333601, 50.1173494883946, 47.524788992745535, 45.552688734872, 43.006653376988, 42.68703276770455, 43.11074086597988, 40.37891067777361, 43.259901319231304, 47.016410146440776, 49.31562464577811, 46.46268735613142, 42.95653602055141, 48.84597505841936, 44.404526710510254, 43.24438599177769, 40.3560163634164, 40.00370447976248, 37.04802417755127, 37.66462469100952, 35.01074286869594, 34.18389681407383, 33.92133828571865, 34.38034323283604, 34.63046448571341, 34.41641827992031, 35.401266370500835, 34.75568839481899, 34.264179774693076, 35.240002155303955, 34.96421078273228, 35.58152001244681, 35.36708470753261, 36.38798005240304, 35.14634043829781, 35.48506164550781, 35.33804471152169, 36.17705011367798, 37.499528544289724, 35.9271616254534, 34.43344831466675, 34.404519489833284, 34.076349122183665, 33.717252322605674, 34.065450872693745, 35.8832003729684, 38.71813488006592, 42.773482254573274, 45.577038696834016, 46.45512771606445, 45.37949793679373, 41.02867146900722, 42.79302058901106, 48.7392646244594, 46.777110712868826, 40.84143141337803, 37.66501031603132, 35.121055943625315, 36.56115000588553, 40.53436967304775, 48.147879123687744, 51.0213657106672, 52.3886148588998, 49.7911558832441, 48.565337317330496, 44.176469462258474, 44.281929220472065, 50.42287220273699, 51.909394127982004, 54.71726540156773, 31.875118119376047, 6.023887549127851, 3.9841331158365523, 5.2443113923072815, 2.1726443767547607, 0.06376528766538415, 0.06788281457764761, 17.092924628938945, 57.29259436471121, 47.54845803124564, 42.84138005120413, 35.29318019321987, 48.30669409888131, 50.38212101800101, 58.1455135345459, 28.658833469663346, 1.3097695239952631, 0.010988813558859485, 0.04556109556662185, 0.018627582683361003, 0.02211876240159784, 0.03851929306983948, 0.03191191583339657, 0.03783297525452716, 0.04157557764223643, 0.05303728600431766, 0.0204245283135346, 0.04216741284887705, 0.03617550419377429, 0.07370089273899794, 0.1413751324372632, 0.1455306030277695, 0.17425814723329885, 0.13040077845965112, 0.20140079648366996, 0.12765283377042838, 0.21848059498838016, 0.17756646685302258, 0.16615717192845686, 0.15324417554906436, 0.16699379203575, 0.09703202079981565, 0.18065598607063293, 0.09832319151610136, 9.230113812855311, 51.76902314594814, 55.920078481946675, 43.853117670331685, 33.373483249119346, 34.66700506210327, 40.04270124435425, 51.699621064322336, 53.488737038203645, 12.865585889135088, 0.305397483919348, 0.9749676436185837, 4.86603365625654, 7.40901962348393, 4.113525075571878, 9.232707227979388, 40.03356088910784, 48.13705383028303, 52.0064674104963, 49.289895466395784, 49.09205593381609, 40.650970867701936, 37.27018935339791, 34.64571925571987, 40.77462100982666, 42.92193399156843, 40.449917793273926, 43.097435065678184, 45.77659443446568, 46.30264949798584, 46.95279938834054, 43.9628575188773, 46.07416493552071, 46.50764567511422, 46.297577313014436, 45.563232626233784, 42.6795460837228, 41.5098237991333, 45.29649475642613, 47.15344599315098, 46.36857053211757, 44.141860485076904, 37.78508908408028, 32.41510432107108, 34.396091324942454, 35.36365229742867, 34.67716332844326, 35.671950817108154, 35.53398738588606, 37.53484623772757, 36.73943383353097, 36.36196599687849, 37.1396917615618, 38.610496861594065, 36.61113882064819, 34.94906023570469, 34.241806575230186, 36.46726942062378, 37.613048212868826, 36.875771386282786, 48.072133336748394, 46.06531640461513, 48.43619115012032, 51.27270637239729, 49.388657161167686, 47.66785934993199, 44.838653632572715, 43.49362482343401, 45.12686491012573, 41.67292928695679, 45.40762424468994, 47.63829129082816, 51.12587356567383, 48.42465366636004, 44.79769400187901, 51.595655168805806, 47.80556569780622, 46.52811506816319, 42.76947661808559, 42.446847438812256, 39.535354205540244, 39.129225049700054, 35.28248691558838, 35.594971724918906, 35.62474822998047, 35.37244176864624, 36.854805197034565, 35.68850837435041, 36.57493870598929, 37.160706588200156, 35.90860993521554, 36.90674645560128, 36.936936378479004, 37.77684852055141, 37.90035969870431, 37.94697168895176, 38.68887254170009, 37.31213215419224, 37.200075081416536, 38.9080673626491, 40.0901643889291, 37.096143926892964, 35.71506438936506, 35.80093717575073, 34.361002922058105, 35.95681653703962, 35.94856555121285, 38.3801258632115, 41.085594585963655, 45.27574396133423, 48.098074436187744, 48.908918789454866, 46.509375776563374, 42.697517599378315, 44.02131271362305, 50.88946805681501, 49.99141338893345, 44.7237616947719, 39.94776105880737, 36.252174036843435, 37.97404187066214, 41.40609761646816, 50.441055638449534, 53.48079872131348, 54.85870293208531, 52.84668527330671, 50.550493240356445, 45.947547912597656, 47.130277224949424, 53.66674293790545, 56.23968866893223, 57.71613918031965, 33.13472230093819, 6.841915036950793, 7.486705694879804, 11.863870177950178, 3.1805446360792433, 0.18259262000875814, 0.23664649735604013, 19.996008804866246, 64.07306344168526, 51.93193755831037, 50.78852115358625, 42.922646181924, 57.54379258837019, 57.52804797036307, 65.29961504255022, 36.812563623700825, 1.8205798055444444, 0.10066970131759133, 0.15231146131243023, 0.1582457385957241, 0.0832934712192842, 0.07964994851499796, 0.08921180971499, 0.16367262096277305, 0.21401549529816422, 0.09876603739602224, 0.10138352694255964, 0.11747263717864241, 0.048973217473498414], [0.0404746918939054, 0.05636123228552086, 0.00927117170899042, 0.03544758878914373, 0.018818106834909747, 0.00870964496529528, 0.011996198029789542, 0.03752276261470147, 0.0652961033795561, 0.015259687688999941, 0.01760847736815257, 0.007044657008788947, 0.0755431628120797, 0.04991751430290086, 0.0021761888180792865, 3.8602154680660794, 36.00019761494228, 43.80944129398891, 36.397377490997314, 19.126961129052297, 17.25985857418605, 36.36689574377877, 37.05315542221069, 47.76869855608259, 14.580110345567975, 0.028965940698981285, 0.12656398862600327, 1.4138521275350024, 3.319044598511287, 1.7783405120883669, 1.3616035197462355, 24.399822235107422, 52.3646296773638, 47.0779572895595, 44.334450653621126, 40.93503059659685, 34.72030816759382, 32.00731801986694, 38.11913067953927, 42.40383114133562, 39.94717741012573, 41.72638872691563, 42.56037752968924, 45.18082462038313, 41.11833102362496, 41.17801604952131, 41.840290546417236, 43.833162443978445, 42.490082604544504, 43.83470841816494, 39.09282691138131, 42.81794030325753, 40.561238356998985, 41.67131035668509, 43.04171051297869, 40.02494164875576, 37.281025069100515, 31.83786187853132, 31.679310934884207, 30.987305096217565, 31.583728040967667, 32.851287909916465, 32.849800995418, 33.543005398341585, 31.97054120472499, 32.34009156908308, 32.73563167027065, 33.963628496442524, 35.172257219042095, 33.99332162312099, 33.24815859113421, 32.77471876144409, 32.49446317127773, 33.070625168936594, 33.14014536993844, 42.98232078552246, 45.29146078654698, 42.848481110164094, 36.4755516733442, 44.801011766706196, 46.779990741184776, 44.448963914598735, 42.838552134377615, 42.527932916368755, 38.607915605817524, 41.08464615685599, 44.419114453451975, 47.3387370790754, 45.71329287120274, 40.250431537628174, 45.42075286592756, 43.67244366237095, 42.12959616524832, 38.031437465122764, 36.308374541146414, 35.142074244362966, 34.00523778370449, 34.020138195582796, 32.21624340329851, 33.099084990365164, 33.394852433885845, 34.5157219341823, 33.84965024675642, 34.43376793180193, 35.031024660382954, 33.78449004037039, 34.65795850753784, 34.05024821417672, 32.71674299240112, 33.81339802060808, 34.073166847229004, 34.732418877737864, 32.91206727709089, 33.540990420750205, 34.73202977861677, 34.01371111188616, 32.758803912571494, 33.570499420166016, 33.08630377905709, 33.14890010016305, 32.45888144629342, 32.31428943361555, 34.44063970020839, 37.44698626654488, 42.844555377960205, 45.06874322891235, 46.741317067827495, 46.76617077418736, 45.40952457700457, 44.43667949948992, 44.049404280526296, 47.02286849703108, 46.395797048296245, 42.022229126521516, 33.934251512799946, 33.36523226329258, 34.10566357203892, 33.728657790592735, 38.109490053994314, 42.38432059969221, 44.36304249082293, 39.65561710085188, 40.00255455289568, 40.234131063733784, 49.84456321171352, 50.419311250959126, 53.490435872759136, 33.18915101460048, 4.760893080915723, 3.5695149983678545, 5.106651076248713, 1.2154218895094735, 0.05404542958629983, 0.056906750691788535, 15.494785104479108, 51.7991818019322, 43.28648860113961, 41.88431085859026, 33.766383034842356, 40.49550839832851, 35.735151631491526, 48.544086251940044, 19.016286747796194, 0.8355615383812359, 0.08946590750877347, 0.059193712260041914, 0.03602817727785025, 0.017584424998079027, 0.055117728654295206, 0.016956344147079756, 0.022381687935973917, 0.008980042866564222, 0.03975457624931421, 0.031075478930558478, 0.021846805566123555, 0.03174384270927735, 0.02949802071920463, 0.08518551183598382, 0.01412939338479191, 0.03455438903932061, 0.03059321016605411, 0.035428118226783614, 0.02388770828422691, 0.03356358541973999, 0.07978013902902603, 0.06774241889693908, 0.03514349992786135, 0.055106990837625096, 0.04189572064206004, 0.03501554179404463, 0.04938307298081262, 4.770275320325579, 40.245244707380024, 50.600502899714876, 40.600214276994976, 25.103643485477992, 21.241381338664464, 37.7846166065761, 43.87031446184431, 49.942261832101, 16.301179136548722, 0.06211981988911118, 0.1812801297221865, 1.7323676475456782, 4.5206747480801175, 3.3898050529616217, 3.2203623737607683, 25.273955992289952, 53.25005946840559, 48.78419862474714, 46.406472955431255, 42.43785646983555, 35.66228239876883, 32.48348501750401, 38.81964806147984, 43.78049509865897, 41.36430072784424, 43.031194414411274, 43.59594399588448, 46.26420511518206, 42.02601589475359, 43.25857768739973, 43.61863333838326, 44.3712100982666, 44.628091948372976, 42.951283182416645, 39.86461544036865, 41.472842012132915, 41.37459448405674, 44.29805251530239, 45.27170010975429, 42.38253491265433, 38.805470262254985, 34.01873813356672, 33.6237782069615, 32.412026269095286, 33.27690328870501, 33.16679171153477, 34.74390425000872, 34.259917054857524, 33.518686703273225, 33.36695541654314, 34.577484471457346, 35.63511494227818, 35.955565861293245, 34.575115135737825, 34.52825995853969, 34.572756222316194, 34.6801996912275, 34.16881922313145, 33.978410788944785, 44.90422378267561, 46.65925884246826, 43.83364534378052, 37.90022073473249, 46.357123374938965, 48.2938677242824, 46.67074768883841, 43.581832204546245, 42.93551424571446, 40.05647257396153, 42.790609564099995, 45.62490483692714, 48.75226470402309, 46.55928816114153, 41.66362912314278, 48.126662799290244, 45.98323038646153, 43.63918610981533, 39.929713112967356, 38.89410148348127, 36.781126499176025, 35.27817208426339, 35.11981569017683, 34.73950604030064, 33.68960196631295, 34.587350913456504, 34.83478668757847, 35.49611970356533, 35.52460731778826, 36.20179264886038, 35.82196937288557, 36.04298462186541, 36.455294200352256, 33.76810271399361, 34.19625765936715, 34.557647364480154, 36.02440513883318, 34.9560466493879, 36.70170858928135, 35.911302362169536, 34.33451291493007, 35.490422180720735, 35.001939501081196, 33.639898027692524, 33.608068329947336, 33.997257777622764, 35.30070161819458, 35.975889342171804, 40.114618573869976, 44.96120595932007, 47.14885670798165, 48.336998667035786, 46.257531370435444, 45.688008376530235, 44.84857913425991, 45.19152137211391, 49.18800360815865, 46.80258628300258, 42.238015856061665, 35.57996709006173, 35.57946334566389, 36.412917137145996, 37.62362337112427, 41.49100807734898, 44.363650458199636, 46.546232495989116, 42.710052149636404, 41.50333418164934, 42.133938789367676, 53.211354528154644, 52.367342948913574, 54.156684739249094, 33.785153593335835, 4.554105571338108, 4.020654584680285, 4.343699353081839, 1.6081523128918238, 0.0548352375626564, 0.04904495898102011, 17.125537736075266, 57.5364796093532, 45.704989773886545, 44.07729434967041, 36.66510200500488, 48.0655950818743, 45.26823990685599, 54.7529513495309, 24.09542339188712, 1.0372916821922575, 0.03579978917592338, 0.03451809759384819, 0.015166283951007893, 0.07783922353493315, 0.06479681017143385, 0.04918858448841742, 0.018374204136697308, 0.004829801660629788, 0.043400429721389494, 0.09916917540665184, 0.05084342961864812, 0.023036969559533254, 0.12307800139699664, 0.15982048266700336, 0.0983829636658941, 0.12562007856156143, 0.14822431919830187, 0.1568005540009056, 0.08545202003525836, 0.08975507877767086, 0.14932167317186082, 0.23362356956515992, 0.08399220622543778, 0.18824237398803234, 0.19805374608508178, 0.15095520551715577, 0.0648404196170824, 5.652723899909428, 46.40660497120449, 56.16000325339181, 47.572158336639404, 28.080823251179286, 25.80069719042097, 46.38047627040318, 47.28478084291731, 56.58362102508545, 19.57997325488499, 0.14665706615362847, 0.4335322268307209, 4.349374728543418, 9.914606043270656, 7.2675516945975165, 2.3793706553322926, 28.386495351791382, 56.26611614227295, 51.25868143354143, 50.396611486162456, 44.389178139822825, 37.87636062077114, 34.50532395499093, 40.55564505713326, 46.87794644492013, 43.65829365594046, 46.78226627622332, 46.92297077178955, 48.50606223515102, 43.18536799294608, 43.75455747331892, 46.37076963697161, 46.14595372336251, 45.94930580684117, 45.388641766139436, 38.728379998888286, 42.03567736489432, 41.93322270257132, 45.957442147391184, 46.32357747214181, 43.15682131903512, 40.236806120191304, 34.9407571383885, 35.249177251543315, 34.25660276412964, 34.40954998561314, 35.361460140773225, 35.48477676936558, 36.97621801921299, 35.51130151748657, 35.465467725481304, 37.3378370148795, 37.74658216748919, 37.83641195297241, 37.11335114070347, 36.831236907414024, 36.61358111245291, 35.60153429848807, 36.30075931549072, 35.01061085292271, 47.02980279922485, 47.786683968135286, 47.90548774174282, 40.05136217389788, 45.37741347721645, 49.616217613220215, 48.96034935542515, 45.489116191864014, 45.86477402278355, 41.44384717941284, 45.4873582976205, 47.985937459128245, 50.697770731789724, 50.037803036826, 43.542995248522075, 48.98257664271763, 48.96405969347273, 44.691942419324604, 42.08014930997576, 41.84998328345162, 39.382160323006765, 38.28890643801008, 37.88727624075753, 36.93930571419852, 35.01217072350638, 36.78895711898804, 37.45550128391811, 37.48197044645037, 36.9577636037554, 38.245177950177876, 37.97334705080305, 38.79092420850481, 38.074717794145855, 36.54223700932094, 36.59973335266113, 36.94188002177647, 37.766551290239605, 35.806641646793906, 37.87206315994263, 39.45836121695382, 36.32491820199149, 36.98360048021589, 36.83166422162737, 36.10413571766445, 36.45523166656494, 35.70042453493391, 36.99113927568708, 39.310215200696675, 41.36230312074934, 47.389618737357004, 49.72863599232265, 49.26839426585606, 49.26579563958304, 46.76308229991368, 45.05638933181763, 44.61404616492135, 50.14875187192644, 50.18815163203648, 45.250066893441335, 38.136219773973735, 37.16487898145403, 38.43820932933262, 40.05601051875523, 43.11088330405099, 46.576116698128835, 50.08086449759347, 43.97903292519705, 44.35540642057146, 44.50814867019653, 55.95588949748448, 55.60284457887922, 58.453951018197195, 36.303736618586946, 7.427872691835676, 6.690511618341718, 13.263152258736746, 4.393659506525312, 0.35033658679042545, 0.1841210608503648, 18.70832347869873, 62.2978959764753, 53.511426380702424, 56.061053957257954, 45.411296367645264, 50.32792854309082, 49.54990400586809, 62.622939654758994, 30.166396277291433, 1.6142419746943881, 0.18604022929711, 0.251069112015622, 0.12824378348886967, 0.15013491096241133, 0.13864858874252864, 0.1256611706422908, 0.11998153398079531, 0.08968594284462077, 0.16956353985837527, 0.18430710158177785, 0.05975026025303772, 0.11817687510379724], [0.039235822656857114, 0.002627897637596886, 0.019003752319674407, 0.061338649663541994, 0.06069562916776963, 0.048339462373405695, 0.029167370604617254, 0.03077012799414141, 0.02668869575219495, 0.04873873951977917, 0.04397397840927754, 0.026994850752609115, 0.016609034301447015, 0.024634814355522394, 0.0487590582509126, 1.4180831462144852, 27.30717781611851, 45.25906481061663, 37.445249216897146, 27.911219460623606, 17.90981912612915, 18.181611810411724, 36.63494334902082, 48.15630381447928, 23.46388598850795, 0.1985118386468717, 0.027268944973392144, 0.3472062333353928, 2.9436716437339783, 2.7104903161525726, 0.8557418212294579, 16.68266303198678, 52.249716894967214, 44.00752401351929, 44.902264390672954, 37.00275318963187, 35.38286754063198, 39.157146385737825, 45.80173996516636, 43.23997041157314, 45.10855640683855, 42.74686023167202, 44.131757804325645, 41.93514040538243, 43.66375494003296, 40.73830277579171, 40.742812156677246, 41.282242502485005, 43.10855565752302, 39.014909812382285, 40.2347320829119, 38.09877940586635, 41.9281644139971, 44.68185363497053, 41.54918187005179, 39.33767795562744, 34.233308928353445, 31.437016827719553, 33.073136942727224, 32.44977583203997, 33.09927953992571, 33.06610883985247, 33.233417987823486, 32.02361501966204, 31.736373015812465, 32.3895696912493, 33.273609842572895, 32.8311311858041, 33.4427672113691, 32.768006801605225, 34.80760186059134, 31.89397553035191, 33.420216832842144, 32.35365445273263, 32.09707484926496, 38.66405357633318, 43.98380633762905, 45.77234213692801, 43.51821449824742, 38.63334948675973, 44.2894332749503, 45.58309057780674, 45.53898688725063, 46.231625011989046, 44.40158414840698, 41.97343192781721, 43.921265602111816, 47.12465960638863, 45.64365802492414, 43.28719731739589, 45.250522000449045, 43.849980558667866, 42.21389865875244, 39.24282809666225, 36.65346029826573, 34.336329868861604, 33.56845317568098, 32.733463832310264, 32.83164535249983, 32.437519209725515, 32.3056389263698, 33.283608300345286, 36.03090517861502, 32.76964657647269, 32.97083861487252, 33.31083134242466, 32.59460408346993, 32.60734013148716, 34.05028642926897, 33.88425922393799, 33.4479193006243, 33.92842197418213, 34.87284891945975, 33.94491352353777, 33.662750652858186, 32.80642339161464, 33.69459424700056, 33.70175436564854, 33.70274100984846, 32.06994908196585, 31.477055822099956, 31.804753712245397, 33.574237551007954, 37.291829517909456, 42.286232880183626, 43.72696965081351, 45.56130797522408, 45.60426868711199, 46.29882104056222, 47.4956864629473, 46.40670224598476, 44.84978117261614, 47.163037981305806, 44.43886818204607, 40.087520599365234, 36.32863548823765, 36.559458119528635, 37.115584986550466, 34.168384960719514, 34.98575714656285, 35.01064211981637, 35.36991957255772, 38.823195116860525, 41.78612586430141, 49.9262045451573, 50.59840454374041, 55.20894772665841, 33.2506217275347, 5.590911856719425, 2.730562141963414, 1.6776174711329597, 1.115574213010924, 0.13014668066586765, 0.0450837360029774, 16.611747980117798, 49.168114389692036, 41.551339285714285, 33.73387936183384, 33.01692254202706, 38.162091391427175, 36.63343211582729, 50.752404417310444, 17.36174522127424, 0.7211312758071082, 0.064625547932727, 0.01685558508948556, 0.07495991446610008, 0.05866626663399594, 0.060219589354736466, 0.08774098328181676, 0.008998413354025354, 0.024242605847705687, 0.049595393373497894, 0.0446761875147266, 0.06876420442547117, 0.05153700775865998, 0.04118144039862922, 0.03708123309271676, 0.05727339708911521, 0.06464370552982603, 0.05229932488873601, 0.054945088989500485, 0.0590032474803073, 0.03515608335978218, 0.04002304541479264, 0.03755370720422693, 0.05089855719623821, 0.01805174393978502, 0.018564239743032625, 0.05577365488612226, 0.014374579469274198, 2.1315803059509824, 34.93478863579886, 50.93777540751866, 43.088544845581055, 28.49156427383423, 15.244941779545375, 30.373483862195695, 44.5302335194179, 52.98047283717564, 24.884747437068395, 0.1944388507732323, 0.05785830784589052, 0.3947462966399533, 4.845769669328417, 4.487225251538413, 2.06011808344296, 18.123698575156077, 55.059505871364046, 45.45799173627581, 47.268435205732075, 38.29675095421927, 36.727840764181956, 40.715474469321116, 47.096158095768516, 45.52857848576137, 47.46897063936506, 45.21231038229806, 46.648086139133994, 43.38718884331839, 43.96024152210781, 41.997927801949636, 42.768371854509624, 41.95564453942435, 43.28646428244454, 39.49244213104248, 41.09307779584612, 38.62728023529053, 44.17948498044695, 47.01497186933245, 43.795576163700645, 41.72040980202811, 36.24271753856114, 32.10976573399135, 34.395594528743196, 32.47033902576992, 34.41344097682408, 34.16699532100132, 34.62423195157732, 33.371881689344136, 33.3888943535941, 33.59557546888079, 34.309079033987864, 34.863128389631, 34.98460374559675, 34.61595664705549, 35.5899064881461, 33.54557623182024, 35.02221087047032, 33.679464544568745, 33.72950547082083, 40.14347791671753, 48.20436103003365, 46.273807525634766, 43.536922522953574, 39.57503536769322, 45.22709614889962, 46.422783851623535, 47.838642597198486, 47.86307941164289, 44.222973755427766, 42.79369803837368, 46.63667024884905, 47.228052275521414, 47.5738502229963, 45.04089484895979, 46.40546546663557, 45.064421449388774, 42.812611034938264, 40.78708955219814, 38.479829038892476, 35.774888379233225, 35.638953821999685, 35.12139640535627, 32.94831950323922, 34.89962380273001, 34.700606550489155, 35.854629380362375, 37.766850062779014, 34.99137823922293, 34.8616623197283, 34.783432551792686, 33.676789488111226, 34.835929666246685, 35.16145971843174, 35.3082959992545, 35.23249462672642, 34.97488668986729, 36.383050305502756, 35.73819146837507, 35.6703006199428, 34.730317047664094, 35.27865498406546, 35.01889657974243, 35.49786022731236, 34.04778855187552, 32.91811915806362, 33.58885308674404, 36.112998144967214, 39.169469015938894, 43.55432776042393, 46.46277073451451, 46.92441599709647, 48.13553217479161, 47.96062517166138, 48.859207902635845, 46.58846712112427, 44.763356004442485, 49.54826075690133, 47.657371044158936, 43.02120290483747, 37.67338636943272, 37.37362718582153, 38.863532883780344, 36.864126205444336, 35.70991577420916, 38.19649887084961, 37.15299756186349, 38.98081847599575, 43.964688369206016, 52.97392763410296, 52.4866817338126, 56.40591042382376, 34.92948368617466, 4.829341522284916, 4.27268876348223, 7.253488540649414, 2.7018799781799316, 0.0710483840001481, 0.023989117039101462, 17.746934243610927, 53.942398820604595, 46.46241985048567, 40.59632675988333, 37.479875564575195, 41.58139371871948, 41.071385519845144, 58.143192836216514, 22.54768088885716, 1.0014683987413133, 0.07951219912086215, 0.03276075974905065, 0.04405227117240429, 0.025743884932515875, 0.042565305783812485, 0.11831022080566202, 0.047169040356363566, 0.03639123422492828, 0.037533154378512075, 0.026348257769963572, 0.017527122715754167, 0.0496271691684212, 0.19567560298102243, 0.12338678911328316, 0.0960113141419632, 0.13400887485061372, 0.14862730114587716, 0.09241443393485886, 0.1346279023481267, 0.14048766291567258, 0.10847244691103697, 0.12027113272675446, 0.16806274253342832, 0.08920809134308781, 0.1149756418807166, 0.08767619675823621, 0.18618909988020146, 2.328822727714266, 38.819766180855886, 59.25648880004883, 48.79565620422363, 39.04057993207659, 26.346804755074636, 27.688871894563945, 47.472010476248606, 57.86240570885794, 28.99393813950675, 0.43747169258339064, 0.15573785959609918, 2.0644400800977434, 8.81021853855678, 6.78936059985842, 3.1558859135423387, 19.830306427819387, 58.07335301807949, 48.48835475104195, 49.22216442653111, 40.60582842145647, 40.94432381221226, 43.069062096732004, 49.44451720373971, 47.000210421425955, 49.449026584625244, 46.867183685302734, 47.97411857332502, 45.82566261291504, 45.478954451424734, 43.598619052342, 42.95138045719692, 43.69397265570504, 44.61050258363996, 38.83353751046317, 42.09179449081421, 41.87919351032802, 46.251357895987375, 48.98660659790039, 45.62122229167393, 42.375030858176096, 38.29337065560477, 34.59753002439226, 36.16637420654297, 33.64358752114432, 36.950777190072195, 35.40923942838396, 36.23621055058071, 34.796467372349326, 35.144224711826865, 36.25472402572632, 36.37139122826712, 36.89841556549072, 36.391589641571045, 36.766865321568076, 39.285062721797395, 35.17392478670393, 37.35629490443638, 35.94502544403076, 34.80566678728376, 41.24468401500157, 48.33827018737793, 48.74654286248343, 46.15194654464722, 42.03057738712856, 45.18504565102713, 48.75697905676705, 49.94976936067854, 51.10808965138027, 46.550099168504985, 45.38137742451259, 48.171874727521626, 49.485094683510916, 49.52388300214495, 47.916340827941895, 48.431907585689, 46.056655475071494, 45.01564162118094, 44.18552643912179, 41.214806761060444, 38.062329156058176, 37.34264516830444, 36.64266627175467, 35.237823895045686, 36.71883589880807, 36.80563626970564, 36.6175137928554, 40.936256953648154, 35.7544606753758, 37.10428721564156, 37.08736835207258, 35.05119180679321, 36.58212661743164, 36.77005454472133, 37.52182183946882, 37.34908962249756, 36.74301562990461, 38.83249875477382, 37.36224256243025, 37.07006386348179, 36.678633621760774, 37.30382905687605, 36.47861582892281, 36.72062505994524, 35.49741901670183, 35.11238806588309, 35.76373652049473, 37.445874554770334, 40.93467276436942, 46.43690259116036, 47.27520969935826, 50.144284180232454, 48.78164863586426, 49.82388537270682, 51.747834614345, 48.45490264892578, 46.337244578770225, 51.167639187404085, 50.35333463123867, 44.16766956874302, 40.094705036708284, 38.87124538421631, 42.025592054639546, 39.83625636781965, 38.059362275259836, 39.32727302823748, 38.936061654772075, 42.328550883701865, 45.81807518005371, 55.114455699920654, 54.563727583204, 58.1908609526498, 37.512848240988596, 7.631059731755938, 8.134341205869402, 9.402420452662877, 5.964167347976139, 0.1911373979278973, 0.16817102315170424, 20.10761945588248, 60.181175913129536, 53.27339151927403, 46.98421566826956, 42.78192778996059, 49.669701371874126, 49.46688345500401, 65.26282433101109, 28.64315833364214, 1.3637118637561798, 0.14096877138529504, 0.1742461235927684, 0.21689489936189993, 0.13321390322276525, 0.08892586827278137, 0.18483793309756688, 0.12368923931249551, 0.07813446090689727, 0.1642847138323954, 0.1539116504469088, 0.15700910852423736, 0.27433759772351807], [0.0713055691282664, 0.02445992873981595, 0.08507754334381648, 0.06268719051565443, 0.05803831640098776, 0.02792127157694527, 0.03166749734165413, 0.04774526586490018, 0.0380668527047549, 0.03948549300964389, 0.04999111499637365, 0.07131526539368288, 0.0944250485460673, 0.023361346617873226, 0.061875262297689915, 0.6911882853933743, 14.290794304439, 41.91527550561087, 43.19766283035278, 38.77467237200056, 24.69344789641244, 23.08652584893363, 39.00895868028913, 44.56314713614327, 35.160414014543804, 0.9906866401433945, 0.10280586526330028, 0.2885402041886534, 2.963337868452072, 2.005513710635049, 1.7557298796517509, 15.460846628461566, 50.67672463825771, 46.600522245679585, 43.623618670872276, 37.56736728123256, 40.23879330498831, 43.40084205354963, 46.91257626669747, 45.1271984236581, 43.607575280325754, 44.485890116010395, 44.385978494371685, 44.39840882165091, 43.897836276463096, 43.64513029370989, 42.80153213228498, 41.24045256205967, 41.31555911472866, 40.77585431507656, 42.087229524339946, 43.61309562410627, 42.81126308441162, 40.174275806971956, 39.673133509499685, 33.0746933392116, 30.220036370413645, 32.20229489462716, 33.983601093292236, 32.81040818350655, 32.55401965550014, 32.32069567271641, 32.72680050986153, 33.362018721444265, 32.39014639173235, 32.96927874428885, 32.49208688735962, 32.329384395054404, 33.75926807948521, 34.523330211639404, 33.380549567086355, 32.899841921670095, 33.104209286826, 30.661295618329728, 33.482021059308735, 36.22192505427769, 39.97301776068551, 42.56452907834734, 45.53705876214163, 45.787027154650005, 40.59177221570696, 45.359306471688406, 46.161455154418945, 45.78908382143293, 48.179642813546316, 43.124543462480815, 44.45900406156267, 47.21932186399187, 46.888604981558665, 42.9961268561227, 45.63656391416277, 45.23603848048619, 43.466512952532085, 38.98843022755214, 36.44640398025513, 35.10148286819458, 35.69607496261597, 35.88084493364607, 34.741069384983604, 32.5701915877206, 32.92301763807024, 33.9894688470023, 33.94039372035435, 34.545488016945974, 33.31848478317261, 33.12392132622855, 34.17743498938424, 33.92833512169974, 33.21658250263759, 33.490834849221365, 33.825748443603516, 34.04444299425398, 33.9867833682469, 34.51807737350464, 34.05901684079851, 33.372454915727886, 34.75906869343349, 34.76875448226929, 33.52809803826468, 33.08079038347517, 32.18431295667376, 32.017900126320974, 32.38062388556344, 34.29877832957676, 37.37256758553641, 42.243254797799246, 42.79971170425415, 43.029540743146626, 42.09768656321934, 46.376074586595806, 45.54670980998448, 45.50958558491298, 44.968911511557444, 48.39319569723946, 45.510811941964285, 42.35776458467756, 44.22441898073469, 45.385337897709434, 38.016005516052246, 35.041290623801096, 34.60875136511666, 35.473322663988384, 37.30370051520211, 44.982144355773926, 47.94532176426479, 52.818836893354145, 51.950496196746826, 34.49841397149222, 3.3188038000038693, 3.1993948817253113, 3.2299940969262804, 1.1654426285198756, 0.047681700704353194, 0.08027911332568952, 16.55204037257603, 51.43351548058646, 38.56364515849522, 34.7089513369969, 42.29006133760725, 44.00560631070818, 44.307251930236816, 45.424966948372976, 11.726134300231934, 0.5835697001644543, 0.03171121535290565, 0.02098222472704947, 0.07282788958400488, 0.011573362147568591, 0.022108060208016207, 0.04355171928182244, 0.06725276088608162, 0.012053080468571611, 0.08149505486445767, 0.0637433302721807, 0.044801462042544565, 0.07225588456328426, 0.024738212914339135, 0.03956821660644241, 0.06848591685827289, 0.0144714454321989, 0.054698858809258254, 0.0186936007480004, 0.017931302277637378, 0.06772670402590718, 0.0364432812535337, 0.06627246777393989, 0.02189473558350333, 0.06962947906660182, 0.026970613481742994, 0.029445010170872723, 0.06495494275752987, 0.9782343826123646, 19.501079933983938, 50.14986705780029, 47.10224124363491, 41.71751587731497, 26.791684014456614, 21.510273150035314, 42.46482937676566, 49.27144105093819, 35.91806990759713, 1.0061781917299544, 0.14970229060522147, 0.26031580727015224, 3.332738629409245, 3.7392625297818864, 2.751112524952207, 15.916966336114065, 54.61744063241141, 47.219186374119346, 46.0497385433742, 38.68632255281721, 41.96323892048427, 45.50657006672451, 48.725555828639436, 45.19011436189924, 46.033531870160786, 45.155578340802876, 45.01442221232823, 44.78244618007115, 45.30169895717076, 44.61784335545131, 43.839370659419465, 41.025259903499055, 41.49344342095511, 42.63159309114729, 43.24297898156302, 45.301132678985596, 44.762713296072825, 42.40286534173148, 41.552471842084614, 35.859823158809114, 32.683874538966585, 33.80850996289934, 34.66968706675938, 33.317977564675466, 34.86780105318342, 33.27013226917812, 33.963294982910156, 34.420538561684744, 33.9212201663426, 33.66115256718227, 34.47731924057007, 33.045715876988, 35.840298720768516, 34.03893654687064, 35.25061552865164, 34.5802845954895, 34.3578588621957, 32.27293028150286, 34.9928651537214, 36.786681583949495, 42.959033897944856, 44.90029110227312, 47.8757529258728, 47.16168655667986, 40.376385007585796, 47.26262651171003, 47.65265669141497, 46.8565216745649, 49.05861077989851, 44.48320811135428, 45.39273425510952, 47.808362347739084, 47.54202052525112, 44.34112092426845, 46.578843866075786, 46.74056666237967, 46.10142271859305, 39.715781552451, 38.58872468130929, 38.37756197793143, 37.99404573440552, 37.95047358104161, 36.084090164729524, 34.13916431154524, 34.11046477726528, 35.40433400017874, 34.62822716576712, 35.761888299669536, 35.91044078554426, 34.407753876277376, 34.88597059249878, 34.54342440196446, 34.54044362476894, 34.53690004348755, 35.55835124424526, 35.01242085865566, 35.5535500390189, 36.44585507256644, 35.961972100394114, 33.90843200683594, 35.21013879776001, 35.74192612511771, 34.972232478005544, 33.86204930714199, 33.906090463910786, 33.884512833186555, 34.69921691077096, 35.971817697797505, 40.82298047201974, 45.47684914725167, 45.193821225847515, 45.57126126970564, 45.06384127480643, 48.657348837171284, 48.640815598624094, 46.78618853432791, 46.52546780450003, 50.258026191166465, 47.28174795423235, 44.328756604875835, 44.995047160557334, 47.047888960157124, 39.94032996041434, 36.66730110985892, 36.32770095552717, 37.62345314025879, 39.671358244759695, 46.6317127091544, 50.66416229520525, 54.27284124919346, 53.565598011016846, 35.0029330934797, 5.0647430164473395, 1.2475299494607108, 6.041267165115901, 2.019646563700267, 0.08760628729526486, 0.03939099004492164, 18.281735352107457, 56.16147627149309, 44.32262134552002, 41.01681089401245, 43.34605898175921, 46.87315913609096, 50.325635637555806, 52.67424488067627, 16.473626477377756, 0.7167628130742482, 0.04271976410278252, 0.011837993349347795, 0.0732935613819531, 0.05670158205819981, 0.04358657901840551, 0.030048095488122532, 0.06568217623446669, 0.08719899665032114, 0.04031967717622008, 0.02675346191972494, 0.040166491110410006, 0.057778111792036464, 0.15995502259050096, 0.08563601159091506, 0.2817650320274489, 0.1847816011203187, 0.13825193074132713, 0.07866488530167512, 0.13837177359632083, 0.11207803950778075, 0.09597963334194251, 0.11628646297114235, 0.11679798338030066, 0.19436620681413583, 0.16653214395046234, 0.24335954285093717, 0.1513484844139644, 1.1326063105038233, 25.17254877090454, 56.97916807447161, 54.0641382081168, 48.90831777027675, 33.98684242793492, 31.922105312347412, 50.05199473244803, 53.67412887300764, 42.34979847499302, 1.5421761274337769, 0.31725529049124035, 2.9136304557323456, 9.78737497329712, 7.209565503256662, 4.314771831035614, 18.343145268304006, 56.080286570957725, 50.46075030735561, 49.04964412961687, 41.35884986604963, 44.834519454411094, 48.64536666870117, 51.58477428981236, 48.61657680783953, 47.83621767589024, 47.244158199855256, 46.51858213969639, 46.51160267421177, 45.805575370788574, 46.77257701328823, 45.28550965445382, 42.72008534840175, 43.08210039138794, 45.379695960453574, 45.9394463130406, 49.08062614713396, 46.57933023997715, 44.04991149902344, 43.539135524204795, 37.557976790836875, 33.80346209662301, 35.972279753003804, 36.66829817635672, 34.769129684993196, 38.25440863200596, 36.18326527731759, 36.28208950587681, 37.671454770224436, 35.952942916325156, 35.3428042275565, 36.352759633745464, 35.196124281202046, 38.41744811194283, 36.46574081693377, 37.21496854509626, 36.14238207680838, 35.829942430768696, 33.166298389434814, 36.45117391858782, 39.291889326913015, 45.13746786117554, 46.620071002415244, 49.55040775026594, 49.0772145816258, 43.288937841142925, 47.766231945582796, 49.76373134340559, 48.47711603982108, 52.94012812205723, 46.03472696031843, 48.53642586299351, 50.174161434173584, 48.43404068265642, 47.24238988331386, 49.73092194965908, 48.943433965955464, 49.29661784853254, 41.88590199606759, 39.16113117762974, 39.16438640866961, 39.1828373500279, 40.31795760563442, 38.890269551958355, 36.13452019010271, 35.30636092594692, 37.290165424346924, 35.404903752463206, 38.8071482522147, 37.11848585946219, 36.135746547154014, 36.965132168361116, 37.46266140256609, 35.69154473713466, 35.94701262882778, 37.844065393720356, 36.95869813646589, 37.18933316639492, 38.00706665856497, 37.50941930498396, 35.70598309380667, 38.006889479500906, 37.66311693191528, 37.46738617760794, 36.83566985811506, 35.34775481905256, 35.77738973072597, 35.95526014055525, 38.28932332992554, 40.53437662124634, 47.44713939939226, 46.44668565477644, 48.38896771839687, 46.17213453565325, 51.738833223070415, 50.717416763305664, 48.09220320837838, 47.563275064740864, 52.95295797075544, 49.87668125970023, 46.231555530003135, 48.74489613941738, 49.640296595437185, 42.68890183312552, 38.82537685121809, 38.54708065305437, 39.699074608939036, 41.847287382398335, 49.605680670057026, 52.56248658043997, 57.260722977774485, 55.23921755381993, 37.7873854637146, 5.430493150438581, 7.006946912833622, 12.097541570663452, 3.0461187064647675, 0.22499077208340168, 0.3245610498956272, 19.993946926934377, 61.499290875026155, 50.62249394825527, 49.21357992717198, 53.02587931496756, 53.86202205930437, 57.30754688807896, 62.32413237435477, 22.60623856953212, 0.9638145906584603, 0.10180615247892481, 0.11431499304515974, 0.21116976014205388, 0.13823910642947468, 0.13743402462984833, 0.06852730749441044, 0.14011801060821327, 0.16465770453214645, 0.11502130728747163, 0.15088779984840325, 0.12561788010810102, 0.1838826643569129], [0.04305570000516517, 0.02698996869314994, 0.029954172670841217, 0.02823017125150987, 0.02604887624537306, 0.052921867197645564, 0.07204429020306893, 0.08771255944988557, 0.04772423127932208, 0.05603721485074077, 0.041721876577607224, 0.02286671833800418, 0.04390202655590006, 0.03790451998689345, 0.04633931416485991, 0.10472595651767083, 13.342625754220144, 43.68617330278669, 42.859202180589946, 33.31658097675869, 22.12868366922651, 28.887780087334768, 38.6084749358041, 43.52795934677124, 42.51527329853603, 3.6894969258989607, 0.0967438876894968, 0.06891727514032807, 1.9163605059896196, 3.7314931409699574, 1.44548499584198, 12.057908177375793, 45.552984033312114, 46.45341498511178, 43.808930601392476, 42.779040813446045, 46.35395152228219, 45.63325309753418, 45.93669830049787, 45.75930036817278, 46.90373815808977, 46.77036401203701, 45.70630298342024, 43.63304737636021, 44.13550983156477, 42.679292474474224, 44.9744005884443, 43.90067114148821, 42.38797882625035, 42.837419578007285, 42.76891381399972, 41.57021059308733, 38.805185386112754, 37.814420904432026, 33.14518281391689, 32.34095661980765, 31.410245418548584, 31.904724393572124, 31.69937038421631, 31.634696551731654, 32.46959209442139, 33.903807980673655, 33.864602770124165, 33.49962084633963, 33.206250531332834, 32.32398564474923, 33.92320735113961, 32.71971334729876, 34.146671840122764, 33.419539383479524, 31.4170720236642, 32.284467765263145, 32.82031284059797, 31.176309994288854, 33.428141253335134, 32.890958649771555, 33.520917075020925, 40.81727947507586, 43.559452056884766, 42.753759792872835, 45.65962151118687, 42.017751012529644, 43.89581782477242, 44.0736118044172, 47.36137778418404, 48.39551292146955, 43.43804618290493, 46.75047826766968, 47.899276052202495, 42.93419756208147, 46.218385219573975, 45.940954072134836, 43.24194022587368, 38.95392894744873, 36.89504221507481, 36.671747956957134, 38.018319266183035, 37.77505588531494, 37.89200448989868, 33.514965942927766, 33.66325439725603, 34.13412339346749, 32.56664105824062, 34.86175264630999, 33.7482829775129, 34.02649579729353, 34.46665028163365, 34.786778109414236, 32.04948663711548, 32.58338621684483, 33.994732107434956, 33.98409788949149, 36.547906739371165, 37.94859756742205, 36.96766826084682, 37.87025315420968, 36.56771952765328, 35.49105446679251, 33.686683722904746, 32.61372900009155, 32.52378109523228, 33.871564865112305, 33.69311775479998, 31.916376522609166, 31.730407987322124, 33.63027129854475, 35.85161733627319, 39.15021208354405, 42.074965953826904, 41.99319607870919, 44.27892065048218, 45.701783180236816, 47.919384138924734, 47.59327391215733, 48.36430508749825, 45.957494258880615, 45.70404829297747, 46.60871764591762, 46.296198095594136, 36.761609009334016, 35.674771785736084, 35.921550955091206, 37.37346042905535, 44.080539158412385, 50.59578159877232, 54.36456789289202, 52.59919738769531, 30.411132676260813, 3.2497313235487257, 0.31736353039741516, 7.05277636221477, 1.294073109115873, 0.02436816705656903, 0.008880412721607302, 18.884402990341187, 49.269658837999614, 41.45931734357561, 30.660361085619243, 40.925369126456125, 37.035559109279085, 42.24219172341483, 51.06564310618809, 12.561628256525312, 0.17703137413731643, 0.04569725040346384, 0.04036090157127806, 0.017920751058097397, 0.08241845281528574, 0.015267100684078676, 0.05260740353592804, 0.007390671276620456, 0.030999567825347185, 0.06533900714878525, 0.024834871924083148, 0.013171782850154808, 0.08634060913962976, 0.057986103131302764, 0.045811990675117285, 0.03076436723183308, 0.045261223800480366, 0.05635434176240649, 0.023078955610149672, 0.02571480461795415, 0.02799700795938926, 0.041325313571308336, 0.03935176732816866, 0.02265883217166577, 0.04750474216416478, 0.1051828752138785, 0.03458385442250541, 0.04834062606096268, 0.10114688785480601, 16.5769670350211, 49.916873114449636, 49.53894322259085, 41.06953729901995, 26.050583941595896, 31.400622163500103, 43.926546233040945, 48.470237323216026, 44.60578128269741, 3.76956753219877, 0.016785780799442103, 0.06007234047033957, 2.406061508825847, 3.0626973254340033, 2.3415205606392453, 13.751423018319265, 45.894140584128245, 48.19091279166085, 46.518533502306255, 43.74990218026297, 48.367893832070486, 47.68333298819405, 46.583672864096506, 45.788083280835835, 48.36029250281197, 47.72317048481533, 47.09783608572823, 45.68198776245117, 45.96751356124878, 44.92778164999825, 45.0028395652771, 46.20639610290527, 44.550418036324636, 45.444817951747346, 45.77200862339565, 43.55527966363089, 42.80732692990984, 39.979979855673655, 35.693337372371126, 33.735202993665425, 33.15336431775774, 33.44328137806484, 33.24080739702497, 32.772755895342144, 33.79052802494594, 35.8757449558803, 35.207682609558105, 35.68409974234444, 36.442363602774485, 34.89189740589687, 34.84619562966483, 34.511837891169954, 34.81128093174526, 34.59981598172869, 33.06910351344517, 33.996368408203125, 34.6509234564645, 32.33595391682216, 34.31885167530605, 35.11174535751343, 35.47279460089547, 41.548073632376536, 45.27917289733887, 46.65863697869437, 46.66372653416225, 43.20123073032924, 46.21539749417986, 47.16393429892403, 46.343265192849294, 48.7284323828561, 45.5584522656032, 47.6702356338501, 48.23637138094221, 43.27464887074062, 47.39593117577689, 47.56507464817592, 45.9452862739563, 40.683839321136475, 39.03933620452881, 37.632117543901714, 39.70772164208548, 38.9131430217198, 39.2490154675075, 35.73888976233346, 33.913497243608745, 35.945129667009624, 35.325298241206575, 35.63657406398228, 34.97339282717024, 34.7967209815979, 35.58831187656948, 35.55052409853254, 33.11140762056623, 35.087054933820454, 35.20743942260742, 35.721071107046946, 36.56109094619751, 39.303586619240896, 37.186887400490896, 38.51848186765398, 38.09246001924787, 37.45180484226772, 34.20930985042027, 33.19409465789795, 33.884537151881624, 35.113207953316824, 33.93325444630214, 34.10578169141497, 32.96945939745222, 36.343928473336355, 38.649281706128804, 41.798236574445454, 44.80313444137573, 45.63464273725237, 46.03571707861764, 48.59932443073818, 48.29725497109549, 49.45102071762085, 49.546388217381065, 47.520571436200825, 48.683477537972585, 48.192323275974815, 48.585737228393555, 38.74991594042097, 38.31525748116629, 37.142484937395366, 39.17419031688145, 46.95592955180577, 52.82975251334054, 56.08142954962594, 53.6707763671875, 33.77407121658325, 4.157195806503296, 2.0384872555732727, 8.232497538839068, 2.789509356021881, 0.11977462151220866, 0.13558465029512132, 19.723399707249232, 55.667025089263916, 45.53144461768014, 38.15716859272548, 46.73949663979666, 43.28080497469221, 48.08693299974714, 55.60883392606463, 16.03312979425703, 0.1808487714401313, 0.029545294253953865, 0.050512759148010185, 0.05021260578983596, 0.07093021034130029, 0.04983912993754659, 0.011599739348249776, 0.08679927167083536, 0.03131932066753507, 0.019939906728853072, 0.03203513440010803, 0.012764398058477257, 0.022506407761414136, 0.17081889749637671, 0.10680124230150666, 0.15964223151760443, 0.09276602364012174, 0.20789683290890285, 0.08948730850326163, 0.13070058237229074, 0.1163374480924436, 0.14572732390037604, 0.19246624090841838, 0.14829506325934613, 0.22139364081834043, 0.24305868042366846, 0.06551597586699895, 0.19881633802184037, 0.20730196125805378, 18.195982422147477, 57.85507883344378, 53.81786625725882, 47.25032820020403, 31.17170681272234, 38.39397709710257, 48.801555224827354, 53.50946004050118, 51.0636385508946, 4.676069906779698, 0.2049898938941104, 0.6822562675390924, 8.042272363390241, 10.325347934450422, 3.5187935829162598, 14.256932258605957, 49.95692947932652, 49.12023087910244, 49.17601449148995, 46.268558161599294, 50.358545780181885, 50.33548123495919, 49.575803416115896, 47.47625929968697, 50.640917096819194, 49.57843330928257, 49.356751033238, 46.83406509671892, 47.14427784511021, 45.816251277923584, 47.44091381345476, 49.40642023086548, 46.609544481549946, 46.137032236371724, 48.14479064941406, 46.04867894308907, 43.619133608681814, 40.79743194580078, 37.373550755637034, 36.257277488708496, 34.72926786967686, 35.50701795305525, 35.82064921515328, 35.675852230616975, 35.609000137874055, 38.713441371917725, 37.698121956416536, 37.62746572494507, 37.75836978639875, 37.55244255065918, 37.63523381096976, 36.94905056272234, 37.11188159670149, 38.36318615504673, 33.96690457207816, 35.562395095825195, 36.38265773228237, 33.70731292452131, 36.97697189876011, 36.06469079426357, 36.25332396371024, 42.5567193031311, 48.241016251700266, 47.06245238440377, 48.39487368719918, 44.23749549048287, 45.8608934538705, 46.76281826836722, 47.612992899758474, 50.15521022251674, 47.60262966156006, 49.767834254673545, 50.47980226789202, 45.156940187726704, 50.04972961970738, 48.86243881498064, 47.75878695079258, 42.61565392357962, 41.385683809007915, 40.70945038114275, 42.789939062935964, 40.8062561580113, 42.17094489506313, 36.72417906352452, 36.65920645850045, 37.37693452835083, 36.32289627620152, 37.783004624503, 36.33800860813686, 37.47951078414917, 37.498413358415874, 38.07743106569563, 35.1305193901062, 35.54805748803275, 37.69076728820801, 38.11551761627197, 40.42382035936628, 41.810371603284565, 41.222574847085134, 41.33248840059553, 40.613506180899485, 41.335913862500874, 36.12964950289045, 34.693495069231304, 36.10525090353829, 37.35894564219883, 36.01066507611956, 34.89344685418265, 35.49774905613491, 38.332350049700054, 40.45360033852713, 43.9326502255031, 47.12053237642561, 46.332811628069194, 47.917369161333355, 50.066474778311594, 51.4609226499285, 50.64040987832205, 51.411072799137656, 48.93646492276873, 50.34819991247994, 50.96314328057425, 49.9845346723284, 40.776142665318076, 39.980417592184885, 39.440181255340576, 41.574699129377095, 48.76251677104405, 55.83463995797293, 57.919950689588276, 54.607800006866455, 35.12450919832502, 4.680966215474265, 5.212943749768393, 15.696150847843715, 4.617819683892386, 0.34816199062126024, 0.28531469298260553, 23.879944120134624, 60.71561745234898, 54.91977412360055, 43.677967480250764, 50.59933907645089, 50.700053215026855, 56.11517347608294, 64.29542664119175, 21.00417331286839, 0.488852291234902, 0.1844551172107458, 0.11947245629770414, 0.175472779199481, 0.2056582508874791, 0.1690685621329716, 0.18542506944920334, 0.10260666095252548, 0.13061826250382833, 0.09648851424987827, 0.19602468210671628, 0.1414487806281873, 0.20350776985287666], [0.06112951160009418, 0.00542209275798606, 0.060833772112216265, 0.0711557146693979, 0.034168088875178776, 0.04553316027990409, 0.015614078047552278, 0.02575032422984285, 0.05456734515194382, 0.027125573916626827, 0.018000821582973003, 0.026342422368803194, 0.022144365224188993, 0.053275556968791146, 0.03648839704692364, 0.08716535488409655, 5.950704778943743, 41.51843956538609, 41.61863258906773, 38.27493708474295, 28.494216748646327, 21.90250243459429, 34.7393844468253, 39.70807947431292, 45.96370594842093, 8.660414508410863, 0.11727474922580378, 0.05706286124352898, 0.9721280017069408, 2.28515134538923, 2.225612231663295, 8.262181111744471, 36.85115739277431, 49.050665514809744, 47.352814129420686, 46.86042308807373, 44.48668915884835, 43.68161875861031, 46.11380788258144, 46.575258595602854, 44.36194120134626, 44.62168223517281, 43.5199202810015, 42.30914109093802, 42.70755427224295, 43.59292500359671, 43.78109611783709, 44.50541802815029, 44.11958108629499, 42.30813012804304, 41.06724786758423, 37.700282846178325, 34.20531463623047, 31.426393032073975, 31.506488391331263, 30.69821834564209, 31.593834195818218, 31.85585423878261, 33.76512541089739, 34.920336382729666, 34.41299629211426, 34.30554240090506, 34.96309559685843, 37.49526235035488, 35.387984888894216, 37.78453322819301, 36.089176246098106, 33.60767575672695, 33.66142702102661, 34.001854010990684, 32.49067292894636, 33.584767545972554, 33.471491064344136, 32.33096858433315, 30.68824073246547, 32.393203599112375, 33.57048552376883, 34.40052774974278, 41.59787137167794, 43.619192668369834, 43.797226360866, 43.05789981569563, 34.116360323769705, 43.58715452466692, 53.85441378184727, 46.10849598475865, 44.663583346775596, 44.451878683907644, 46.56808805465698, 40.969907079424175, 45.07054628644671, 46.44429200036185, 44.41332312992641, 39.27579729897635, 36.87561852591378, 37.74376119886126, 37.86424643652779, 39.354152134486604, 39.95223569869995, 37.905591692243306, 33.34633663722447, 34.157521452222554, 33.58537551334926, 34.050015449523926, 33.70803206307547, 33.97795568193708, 34.272986616407124, 32.86251619883946, 34.396438734872, 34.308068071092876, 33.81556585856846, 36.98047031675066, 40.15412950515747, 41.78028242928641, 41.01248216629028, 41.06140790666853, 38.75493253980364, 36.50797891616821, 34.91022327968052, 34.23640782492501, 33.83342967714582, 34.38296965190342, 32.93123040880476, 33.50832346507481, 33.34878587722778, 34.54276432309832, 34.168173040662495, 32.94352872031075, 36.11853585924421, 39.830840247017996, 44.00546734673636, 44.9011561529977, 43.95206349236624, 46.83313056400844, 46.368237018585205, 48.272237982068745, 35.232883725847515, 47.998447690691265, 49.56843137741089, 44.10905456542969, 39.02340745925903, 36.68427555901663, 38.57294184820992, 42.81126308441162, 49.64610876355852, 51.539107254573274, 50.11658518654959, 26.826774154390606, 3.475283746208463, 0.5140343542609895, 5.579296205724988, 1.8920192292758395, 0.04968165892309376, 0.3143490435821669, 22.60678574017116, 52.198282854897634, 35.70195313862392, 33.28345543997628, 36.55600486482893, 36.1688859803336, 45.80534608023507, 46.34716313225882, 12.963175943919591, 0.11155893986246415, 0.02508326493469732, 0.06021998969039746, 0.04229690786451101, 0.007953226000868847, 0.03891546591850264, 0.04181171122140118, 0.011833443772047758, 0.020959856820159724, 0.017125089020867432, 0.053280605269329886, 0.015567479655146599, 0.012043288360083742, 0.023384013080171177, 0.01695711089165083, 0.037331242713012865, 0.0427047650861953, 0.027446168142237833, 0.04488877932141934, 0.028967260449592556, 0.014585405388580901, 0.07117038459650107, 0.01519509285156216, 0.07023479337138788, 0.05677453814340489, 0.015573481297386544, 0.05564261281064578, 0.024604772217571735, 0.013423400598445108, 8.664823140416827, 48.99149465560913, 46.65963404519217, 42.582841055733816, 30.29382971354893, 26.3334572655814, 40.28040606634957, 45.071300165993826, 50.3619886125837, 8.754312464169093, 0.10848148499748536, 0.07929077957357679, 1.896205084664481, 2.9907980178083693, 2.8120182624885013, 8.462214538029261, 40.95484685897827, 51.41416474751064, 47.417745045253206, 48.50340454918997, 46.38271359034947, 43.95177861622402, 46.985084193093435, 48.26641886574881, 47.4083753994533, 45.76187814985003, 45.574836117880686, 45.50053555624825, 44.230717522757395, 45.46565212522234, 45.439603328704834, 45.41273464475359, 45.919463293892996, 44.71719912120274, 42.75171702248709, 39.93630347933088, 36.05111748831612, 33.23005158560616, 32.449369362422395, 32.70732123511178, 32.49055133547102, 33.5376101221357, 34.66435432434082, 36.34782641274588, 35.55253907612392, 35.12723984037127, 36.24206093379429, 38.576752935137065, 37.737730162484304, 39.131886209760395, 36.670695304870605, 35.87667948859078, 35.23244251523699, 34.702277592250276, 34.2913680757795, 35.08354261943272, 35.508782795497346, 35.19008977072579, 33.19204146521432, 32.09662669045584, 34.865410872868125, 36.22213350023542, 43.530415534973145, 45.434347016470774, 45.9978563444955, 41.98479918071202, 35.409962041037424, 41.637066159929546, 53.558052267347065, 50.143822125026155, 46.05741630281721, 45.47495576313564, 47.841546944209504, 42.264144556862966, 45.64517968041556, 46.90668766839163, 44.413076468876426, 41.22797359739031, 38.41352585383824, 39.04800060817173, 38.86611066545759, 40.64175755637032, 41.72018051147461, 39.44536113739014, 33.8780197416033, 35.62639147894723, 35.244195393153596, 36.518911906651084, 35.71608577455793, 35.31053679330008, 34.80874483925955, 34.71442304338728, 36.0703570502145, 36.12624141148159, 35.292078903743196, 37.86974940981184, 42.717007296425955, 43.73685693740845, 42.41917276382446, 41.79973043714251, 40.49652630942208, 37.707477705819265, 35.670373576028005, 36.07555430276053, 35.09909963607788, 35.83713729040963, 35.3784623827253, 35.03116709845406, 36.07909440994263, 35.09734869003296, 34.660911491939, 35.51675932747977, 37.70670645577567, 44.251906054360525, 44.648877484457834, 48.16373143877302, 47.516187122889924, 49.60901233128139, 49.20330354145595, 48.932525294167654, 37.41728271756853, 47.029861858912874, 51.781582014901296, 45.03466926302229, 39.837003299168174, 38.03442866461617, 40.07174818856375, 44.91030693054199, 51.72438097000122, 53.57921300615583, 50.7642684664045, 28.589254208973475, 2.966965045247759, 2.3219470509460995, 5.362291804381779, 2.0109057298728397, 0.1153827900333064, 0.1138592753559351, 24.54252781186785, 56.34780958720616, 46.44346863882882, 40.37242453438895, 39.46955476488386, 43.945316791534424, 49.84842988422939, 55.32823787416731, 15.451093094689504, 0.13703206048480102, 0.022561321600473354, 0.0305044068954885, 0.03667415279362883, 0.03161659025188003, 0.03856594913772174, 0.07009048932897192, 0.07831439482314245, 0.013839494387087013, 0.017391897471887723, 0.04868589860520192, 0.029945395820375, 0.020949926460161805, 0.15458536786692484, 0.12177241859691483, 0.11620753577777318, 0.14059620137725556, 0.0798741364851594, 0.16188438263322624, 0.17949527049703257, 0.08533771402601685, 0.22234953381121159, 0.09632798643516642, 0.18438259538795265, 0.10332318036151783, 0.07822472642042808, 0.16575931970562252, 0.12982399655239923, 0.2070712186396122, 9.521370138440814, 54.47955363137381, 52.55081360680716, 48.88627461024693, 36.10429205213274, 30.183971745627268, 44.112275055476594, 49.099879605429514, 54.21320138658796, 11.001996517181396, 0.14275907246129854, 0.3775082773395947, 4.470840096473694, 6.743601935250418, 4.388500469071524, 9.555299060685293, 40.865048340388704, 53.75421033586775, 50.692952156066895, 51.361431394304546, 48.769673415592735, 45.49127360752651, 50.19808408192226, 50.27363184520176, 48.711499622889924, 48.78864894594465, 49.00498110907418, 47.01409987040928, 45.662842001233784, 47.590956687927246, 47.17629861831665, 45.05844599860055, 48.33130461829049, 47.16786003112793, 45.518027646201, 41.26588991710118, 36.40895318984985, 34.031998770577566, 33.54303319113595, 34.27259404318673, 36.055269036974224, 35.73319223948887, 37.701630796704976, 38.682605266571045, 38.06935378483364, 37.878604888916016, 38.53766236986433, 42.18815558297293, 39.491896697453086, 41.63698625564575, 39.73263093403408, 38.32740988050188, 37.238998889923096, 36.995342935834614, 36.32979931150164, 37.449577944619314, 38.08148186547415, 37.225064277648926, 34.318170751844136, 34.36491475786482, 36.761556897844585, 37.21833494731358, 44.75305182593209, 46.781321321214946, 48.1775027683803, 43.88058042526245, 36.86839239937918, 42.62410640716553, 56.33613313947405, 51.80003990445818, 48.093530314309255, 47.00379221779959, 49.55491713115147, 43.65751198359898, 48.65267269951956, 50.00836699349539, 47.30668156487601, 42.64210224151611, 39.45328903198242, 40.88544477735247, 40.84424543380737, 42.173751967293875, 44.59561259405953, 41.950454235076904, 35.38032102584839, 37.09251001902989, 36.63561037608555, 36.99692365101406, 37.44115672792707, 36.6327338218689, 37.65869787761143, 35.97694894245693, 37.82420744214739, 38.65041773659842, 37.79083524431501, 40.08353928157261, 45.18212740761893, 47.28497191837856, 44.58143826893398, 43.44327122824532, 41.74865075520107, 40.461698463984895, 38.60217639378139, 37.079054832458496, 38.06859990528652, 38.70190736225673, 36.29164675303868, 37.313928263528005, 37.95169298989432, 38.4395294870649, 37.507710048130576, 36.687148639133994, 40.49629701886858, 45.07069219861712, 48.82515825544085, 51.06235313415527, 48.58288499287197, 51.05652012143816, 49.49497502190726, 50.59109851292202, 38.72823061261858, 50.814048835209434, 54.25765248707363, 48.227911949157715, 43.53340673446655, 40.383948121752056, 41.04529850823538, 47.05999967030117, 54.31787599836077, 56.44121422086443, 52.289943490709575, 30.41299131938389, 4.6448312401771545, 2.522477490561349, 13.959608418600899, 5.236654477460044, 0.2108684770230736, 0.4455646068922111, 27.490460872650146, 63.20025852748326, 50.19181333269392, 47.6916743006025, 45.71281691959926, 46.87673051016671, 57.60751799174717, 61.85069601876395, 19.266055379595073, 0.3713808075657913, 0.10802947210946254, 0.12066038112555232, 0.16019918663161142, 0.08728112652897835, 0.19053047549511704, 0.15242024404661997, 0.16077727132609912, 0.14152536009039196, 0.08952220555927072, 0.16677738007690224, 0.08711747745318071, 0.16036746331623622], [0.05176947046337383, 0.05172596958332828, 0.04872662766969629, 0.0062129062384233946, 0.006490706108577017, 0.014300880388223698, 0.0125919916400952, 0.026479065750858614, 0.03592814086005092, 0.062056383650217734, 0.048398450815251896, 0.10973072903496878, 0.009550073350380574, 0.06988935797874417, 0.06186292653105088, 0.029785974017743553, 3.7303644929613387, 35.68673310961042, 47.6475636618478, 36.802916049957275, 29.344049181256974, 25.921677487237112, 34.28421490533011, 40.703638213021414, 47.88403517859322, 15.52664954321725, 0.03673329729852932, 0.0431293312327138, 0.8515385953443391, 1.799414072717939, 1.325728776199477, 3.0561123873506273, 23.861031123570033, 44.478479862213135, 48.87777696337019, 47.34110294069563, 43.79155315671648, 45.78304583685738, 46.463969298771445, 45.27572659083775, 42.53907435280936, 42.34081098011562, 41.42375993728638, 42.60663168770926, 43.81925909859793, 42.976560728890554, 45.30321019036429, 41.677258014678955, 40.185636111668174, 39.09509549822126, 36.95690202713013, 33.85707787105015, 30.170829227992467, 32.09992013658796, 31.767309870038712, 31.450353894914898, 32.26604461669922, 32.09878758021763, 34.29787506375994, 34.5499244417463, 33.43473856789725, 34.49899762017386, 36.2644237109593, 37.07673760822841, 37.914704254695344, 36.88201086861746, 37.080854415893555, 35.674910749707905, 33.426716872623985, 34.49680198941912, 31.595960344587052, 33.762318338666645, 31.940055983407156, 32.251634052821565, 31.12816940035139, 32.48357881818499, 31.372089385986328, 34.453785691942485, 38.98071077891758, 42.1562042917524, 45.6908849307469, 46.02457216807774, 43.85492420196533, 41.75045381273542, 42.00731829234532, 46.335076740809846, 44.884101799556184, 46.937989303043906, 47.08048643384661, 42.19504819597517, 46.686454091753276, 45.19360930579049, 44.572325706481934, 40.08130196162632, 37.39662919725691, 38.65081378391811, 40.209958280835835, 40.30117423193795, 41.58562517166138, 39.38738189424787, 33.64835051127842, 33.44868360246931, 34.4121173449925, 32.99462577274868, 33.523230825151714, 35.66811541148594, 33.67927346910749, 32.05673360824585, 34.94159092221941, 36.18216051374163, 40.23500306265694, 43.34623963492257, 42.72009229660034, 43.95972735541207, 41.92137949807303, 43.66367850984846, 43.205476079668315, 41.63120188031878, 40.336227893829346, 39.74617297308785, 38.01843738555908, 38.73888914925711, 36.5253563608442, 34.981796673366, 33.52888665880476, 34.34977810723441, 33.69666828427996, 33.69919395446777, 33.69711296898978, 34.15196289334978, 39.37427064350673, 41.51764052254813, 41.15620912824358, 42.90113803318569, 46.197804655347554, 47.193870612553184, 47.262713364192415, 48.09329407555716, 50.65741212027413, 46.07873337609427, 44.10971464429583, 40.61684826442173, 36.376411301749094, 42.16869020462036, 48.187650612422395, 53.918886116572786, 47.462748527526855, 19.83722335951669, 1.0235766981329237, 2.381528070994786, 4.668319625513894, 1.0445852279663086, 0.1692553356822048, 0.544037327170372, 23.57805357660566, 49.85605205808367, 34.107984270368306, 37.365292821611675, 32.08492244992937, 29.06497825895037, 45.84118141446795, 42.78989737374442, 7.539380856922694, 0.07548478844442538, 0.04099698065380965, 0.03424590327111738, 0.03641831116484744, 0.016790769728166715, 0.028048569835456352, 0.012620676708008562, 0.03660532220133713, 0.0645102309063077, 0.02541766395526273, 0.07560018689504691, 0.01161643470238362, 0.022409350112346665, 0.04230726909424577, 0.002948409378794687, 0.023130875413439105, 0.0371104304545692, 0.035344610922038555, 0.03198703983798623, 0.005030667109947119, 0.04419672788519945, 0.0004066298419534827, 0.00878071048230465, 0.03918580784063254, 0.04872383549809456, 0.029269961706761802, 0.025265320969213332, 0.03232068568468094, 0.061336125513272624, 4.325083826269422, 41.36207035609654, 53.2072377204895, 43.07188653945923, 31.424579552241735, 25.232527358191355, 39.332501547677175, 46.862733364105225, 51.33298199517386, 16.13231532914298, 0.012142476609109767, 0.14598946911948069, 0.49780585936137606, 3.4516880980559757, 2.7679447531700134, 4.916666916438511, 25.128679582050868, 48.431424685886924, 51.535400390625, 49.52539076123919, 44.57379872458321, 46.523970467703684, 48.285641057150706, 47.16012668609619, 44.57267311641148, 43.63850171225411, 43.28023174830845, 44.330396379743306, 46.291813782283235, 44.472323758261545, 47.1104679107666, 44.212252685001914, 41.78734874725342, 41.386232716696604, 38.4751216343471, 35.79723378590175, 33.037173066820415, 33.069364070892334, 32.79321139199393, 32.57196685246059, 34.32612991333008, 34.30432994025094, 36.43434190750122, 36.309739862169536, 35.32006277356829, 36.9244122505188, 37.233579295022146, 40.00119965417044, 38.72873783111572, 38.561918531145366, 37.35101427350725, 37.03696264539446, 34.422949586595806, 35.53746495928083, 32.81606749125889, 35.884075845990864, 34.017060143607004, 33.646849700382774, 33.38126870564052, 34.46285309110369, 33.00165734972273, 36.21294103349958, 39.916737352098735, 44.19071674346924, 47.34971175874983, 48.57019758224487, 44.245159353528706, 41.73066881724766, 44.39181498118809, 45.914370264325825, 46.570440019880024, 46.95908055986677, 48.30042682375227, 43.192517689296174, 47.84716803686959, 45.69027001517159, 46.377950600215364, 41.49625744138445, 38.9485684122358, 40.46142053604126, 41.05741616657802, 43.12441144670759, 44.07594639914376, 41.21531397955758, 34.652928011757986, 34.46589640208653, 35.58570630209786, 34.918543747493196, 35.12242126464844, 35.86634404318673, 35.87080826078142, 34.67896638597761, 36.26613991601126, 37.976362568991526, 40.20822817938668, 44.05299302509853, 44.76410640989031, 46.43061099733625, 45.767089298793245, 44.878084659576416, 45.08287933894566, 42.8080530166626, 41.842441013881135, 41.59357043675014, 39.80848094395229, 40.23825134549822, 37.69927535738264, 35.1625714302063, 35.213769231523784, 35.7667555127825, 35.79326636450631, 35.05461726869856, 34.995422090802876, 37.96274757385254, 41.663038526262554, 46.00236919948033, 43.56429147720337, 45.06108283996582, 47.58326850618635, 49.62011555262974, 48.346559388296946, 49.239785058157786, 51.88770532608032, 49.20884472983224, 46.010564599718364, 41.890651089804514, 38.89064475468227, 44.25565113340105, 50.02677624566214, 53.721397468021934, 49.20153522491455, 20.321455478668213, 2.784355095454625, 3.2303139311926703, 4.841019707066672, 1.3339619572673524, 0.1251162120274135, 0.4914560743740627, 27.073329244341167, 55.25447579792568, 43.433884211948936, 40.16338797977993, 35.9075642313276, 35.721060684749055, 50.058515616825645, 50.42338636943272, 10.50970275061471, 0.12263320812157222, 0.033613070978650024, 0.011372120535400296, 0.07672110638980355, 0.005103441262950322, 0.06327345155711685, 0.012335743738471397, 0.012592775348041738, 0.026611475074397664, 0.022160414273717573, 0.05633743606241686, 0.03896642729107823, 0.04781670542433858, 0.13775442886565412, 0.1489345689437219, 0.15610413279916557, 0.14634306728839874, 0.14690454144562992, 0.10576370797519173, 0.10097903864724295, 0.11843011794345719, 0.14925162121653557, 0.1593976467847824, 0.12008047795721463, 0.25231102108955383, 0.05464273039251566, 0.12341505688216005, 0.13569810135023935, 0.13224543019064836, 5.200734462056841, 47.50519159861973, 60.986145564488, 49.77275357927595, 38.898864473615376, 34.17399215698242, 44.21205813544137, 51.00805296216692, 56.34019088745117, 19.306200334003993, 0.1222678441554308, 0.2527964179004942, 2.5185335193361555, 6.840352126530238, 4.248906816755023, 4.221552193164825, 25.503548792430333, 48.363700594220845, 52.58917113712856, 50.667302880968364, 44.49264029094151, 46.95496722630092, 49.83948060444423, 48.4840156010219, 46.20493698120117, 45.44072893687657, 44.6403728893825, 46.376835414341514, 49.016365732465474, 47.71720545632498, 47.13198300770351, 45.869530064719065, 44.5758831841605, 42.97288860593523, 40.24392802374703, 37.5472730909075, 34.48797082901001, 35.18144621167864, 35.925323826926096, 34.32868685041155, 35.50745916366577, 37.602191652570454, 38.56305456161499, 38.133468287331716, 36.84386873245239, 38.42839847292219, 39.57721362795149, 42.138524600437705, 40.70552812303816, 40.56432335717337, 39.45486627306257, 38.917093072618755, 36.40776852199009, 37.909593854631694, 34.47779866627285, 37.659903390066965, 36.322799001421245, 35.87482779366629, 35.51124593189785, 35.283880029405864, 34.468467235565186, 38.11719560623169, 43.02914122172764, 45.60213906424386, 49.07908017294747, 50.18554605756487, 43.18426670346941, 43.25668430328369, 48.71997989927019, 49.49513830457415, 47.18721423830305, 50.25089386531285, 50.251602581569124, 45.72576836177281, 49.563317503247944, 48.33362879071917, 49.43462296894619, 44.0904472896031, 41.96893644332886, 43.158124106270925, 44.788206236703054, 44.28839451926095, 46.375077520098, 43.492214339120046, 37.04837506158011, 35.613742283412385, 37.580506324768066, 36.37636266435896, 36.733121395111084, 38.64547756740025, 38.059747900281636, 36.15315178462437, 37.454542432512554, 40.15053728648594, 43.59693758828299, 47.46369695663452, 47.157538482121055, 47.42123304094587, 46.46889904567173, 46.97778163637434, 47.540943554469514, 46.08917304447719, 43.757315908159526, 43.710203647613525, 41.12363249914986, 42.96894202913557, 40.78851045880999, 38.16794524874006, 36.96340206691197, 38.15038367680141, 37.729729311806814, 36.14347294398716, 37.1740506035941, 39.11692326409476, 42.29022809437343, 46.27810846056257, 45.83681099755423, 47.28964458193098, 49.791065556662424, 52.35053178242275, 49.61862863813128, 50.991797651563374, 51.24130746296474, 52.11690902709961, 48.50383186340332, 43.95886925288609, 41.46934012004307, 45.528887680598665, 51.97700010027204, 58.00121334620884, 50.43463202885219, 22.09276669366019, 2.3497146580900465, 7.641812937600272, 10.209912300109863, 4.207048262868609, 0.36608353895800455, 0.840186704482351, 28.86971824509757, 62.050289971487864, 47.33554438182286, 50.290345736912315, 41.11187267303467, 41.211891991751536, 59.28808225904192, 57.94958823067801, 12.674664156777517, 0.2804902547172138, 0.12018765934876033, 0.1763225764568363, 0.1823527714503663, 0.04943997832015157, 0.09227295938347067, 0.16776156798005104, 0.13518077268132142, 0.17479299567639828, 0.12167323034788881, 0.30002354085445404, 0.11060101804988724, 0.20500056046460355], [0.039956067223101854, 0.037832045661551614, 0.03782064627323832, 0.033989376321967156, 0.05459768584530268, 0.04880065244755574, 0.08453284257224628, 0.06131638014422996, 0.03195827334587063, 0.05715977640024253, 0.07768264479402985, 0.09346042280750615, 0.04741956227059875, 0.01041990689866777, 0.06206476355769804, 0.02097218919412366, 1.5842202199356896, 28.6070659160614, 43.58634505953108, 41.66203103746687, 27.575261899403163, 21.618083136422293, 29.764227594648087, 33.388199533735005, 47.1450560433524, 21.094492946352275, 0.34902147735868183, 0.01983727321826986, 0.5911187008023262, 1.8331401944160461, 2.3810521193913052, 1.085476896592549, 10.728531922612872, 34.25726284299578, 44.49019105093819, 45.69147900172642, 47.51660401480538, 47.93262045724051, 46.584562233516145, 46.14587034497942, 42.94858728136335, 40.57184478214809, 38.50408520017351, 41.16753816604614, 40.69557135445731, 40.70188726697649, 41.540434088025776, 42.81005409785679, 38.336320945194785, 34.63704442977905, 31.57896852493286, 30.825120244707378, 30.945522103990825, 31.22708395549229, 31.738902160099574, 32.361849852970664, 31.825438499450684, 31.835565498897008, 31.80912412915911, 34.10298156738281, 31.862514087132045, 35.017715385981965, 34.660192353384836, 37.16912085669381, 36.26015404292515, 37.245387758527485, 37.109401089804514, 36.671588148389546, 34.35394007819039, 33.20770270483834, 31.199933869498118, 31.05326087134225, 32.669432708195274, 32.561360427311485, 33.386792523520334, 30.90462848118373, 32.394256251198904, 32.971804414476665, 37.69160107203892, 42.184848240443635, 44.26032032285418, 43.833033902304514, 46.06278726032802, 44.285246985299246, 45.27041121891567, 45.813096795763286, 44.808616570064, 44.129847049713135, 46.79528372628348, 41.49089690617153, 43.91168056215559, 46.08444479533604, 42.46150466373989, 40.116480691092356, 38.40486492429461, 38.94736984797886, 38.06763063158308, 42.62127849033901, 42.038015433720176, 40.53896938051496, 33.187024865831646, 32.638683455330984, 32.17483213969639, 34.18844788415091, 34.58775738307408, 34.9552788734436, 33.50880636487688, 33.73924684524536, 36.03011308397566, 39.95554304122925, 44.344782624925884, 43.82747881753104, 44.16376468113491, 43.15800598689488, 43.786557401929585, 44.5536003112793, 44.83655527659825, 44.626111711774556, 43.91344540459769, 43.44553286688668, 41.96086611066546, 44.50785684585571, 43.21073586600167, 41.87752594266619, 38.12839610236031, 35.23136554445539, 31.727232660566056, 31.174454825265066, 32.398974078042166, 33.217183521815706, 33.8773318699428, 35.2132203238351, 40.5745267868042, 41.331223828451975, 42.37139695031302, 46.618896756853374, 46.222828592572895, 48.96108933857509, 41.14396987642561, 51.82327120644705, 46.12166282108852, 42.50964873177664, 41.41115590504238, 40.003242424556184, 47.14355523245675, 51.10019997188023, 48.01707233701433, 14.32717854636056, 0.7422563508152962, 2.2122651764324734, 2.2678551077842712, 1.7728998554604394, 0.07702518507306065, 0.29833217018416947, 22.346890108925955, 52.01289102009365, 38.78307621819632, 44.38394614628383, 31.825688634599956, 32.12132058824812, 48.77017368589129, 38.61224780763899, 4.9433189034461975, 0.01847667819155114, 0.044043002384049554, 0.04928591015881725, 0.05841431301087141, 0.05733818361269576, 0.02383899286256305, 0.09120825651500906, 0.07232739536889962, 0.016425074976203696, 0.026714907559965338, 0.05410619918256998, 0.017148562939837575, 0.019006576721689532, 0.05272656785590308, 0.03015362803957292, 0.01875564768644316, 0.05136203393340111, 0.025324697872357707, 0.022793183801695704, 0.04498835772808109, 0.01900037830429418, 0.04120332654565573, 0.07697295823267528, 0.04321611925427403, 0.03338640635567052, 0.028638751112989018, 0.03180892778826611, 0.042928756281201325, 0.0776128846087626, 2.231518200465611, 34.06530843462263, 49.77075249808175, 45.74870089122227, 32.362013135637554, 23.319526740482875, 34.887381076812744, 40.63003247124808, 50.683665888650076, 23.100750548498972, 0.29342571060572353, 0.019610031840524504, 0.2503080671387059, 2.960207053593227, 3.0834049114159177, 2.772316472870963, 12.337772931371417, 37.37959916251046, 48.101875100817, 47.434750761304585, 48.34311655589512, 50.04647438866751, 48.19637754985264, 48.37828138896397, 44.55185978753226, 42.60372734069824, 40.967214652470176, 42.706202847617014, 42.39074420928955, 42.92997653143746, 42.99726636069161, 43.59125396183559, 40.76607125146048, 37.01693098885672, 32.337301867348806, 32.07044587816511, 31.961633614131383, 33.4470021384103, 34.06406818117414, 33.634985651288716, 32.82519047600882, 34.05826990944998, 33.85967649732317, 35.727449553353445, 34.8396122114999, 37.52808564049857, 37.363715580531526, 38.17325019836426, 38.92173446927752, 39.04357460566929, 39.43088109152657, 38.35906934738159, 37.51071514402117, 35.08461264201573, 32.36095700945173, 32.96075330461775, 32.703590052468435, 34.28569834572928, 34.04045125416347, 33.47300229753767, 32.93447521754673, 34.093577180589946, 38.94858578273228, 43.66588108880179, 45.46277904510498, 45.59120259966169, 48.40970114299229, 43.99884223937988, 44.90083653586251, 47.105402673993794, 46.40201916013445, 46.82483788899013, 47.076915059770855, 44.32667909349714, 45.88949223927089, 48.61579860959734, 43.77992534637451, 41.19913509913853, 39.943209988730295, 39.858143193381174, 40.15489380700247, 43.96310070582798, 44.77847181047712, 42.07204423631941, 34.00773913519723, 34.455567904881065, 34.04587779726301, 35.130686146872385, 35.9008001599993, 35.88784524372646, 34.3150440624782, 34.56716987064907, 36.708271162850515, 41.34260497774397, 44.56275803702218, 45.84315470286778, 46.2134485244751, 44.98244660241263, 45.648650305611746, 45.84854997907366, 46.47615296500069, 46.435610226222444, 46.169310092926025, 45.37810134887695, 44.2207989692688, 46.315104143960134, 44.30938155310494, 43.1237096786499, 40.373518875667024, 35.52230746405465, 32.37752846309117, 33.03752047674996, 34.08690690994263, 34.88982336861746, 35.362755979810444, 38.463233266557964, 41.61288642883301, 43.110410826546804, 45.131256171635215, 47.92493574959891, 49.23720727648054, 50.88258239201137, 45.47120720999581, 53.17239597865513, 48.52885927472796, 44.8676449911935, 44.600024700164795, 43.017294543130056, 48.63490615572248, 53.49618550709316, 49.15511778422764, 15.834430422101702, 1.6414943294865745, 4.115249531609671, 4.2191285746438165, 0.7144164932625634, 0.03336120895775301, 0.29393268483025686, 26.093803473881312, 56.519284180232454, 41.14375448226929, 44.66839150020054, 35.59895304271153, 38.06283637455532, 54.1867287499564, 46.1408155305045, 7.061157192502703, 0.02021710355100887, 0.06728014655943428, 0.08132422688816275, 0.06581493839621544, 0.04270381513716919, 0.038707898663622994, 0.040629937313497066, 0.0625974949715393, 0.042971174897892137, 0.07621850193079029, 0.005336961634124496, 0.01873232134883957, 0.0461249988792198, 0.1377383747271129, 0.25811594245689257, 0.0856058167825852, 0.1250140517950058, 0.09159323692853961, 0.1408374612884862, 0.24616626224347524, 0.15394485795072146, 0.11448464037052222, 0.23176384078604834, 0.1451238484254905, 0.1608493724571807, 0.10101397641535316, 0.16107710238013948, 0.1912658717483282, 0.2043906253363405, 2.6809376733643666, 38.10506752559117, 57.04042339324951, 53.28512702669416, 38.926997729710166, 30.386136531829834, 39.35906798498971, 45.18338850566319, 57.01063299179077, 25.821981259754725, 0.5818128372941698, 0.1316246927848884, 2.1524446606636047, 7.6670670339039395, 6.470862124647413, 2.118363095181329, 12.702532512801033, 36.91328123637608, 47.991322313036235, 46.58104297092983, 49.50156886237008, 50.58640847887312, 51.12232998439244, 51.793449538094656, 47.75953388214111, 44.52613755634853, 42.53440516335623, 45.76156895501273, 44.294300488063264, 43.74502454485212, 44.6944055557251, 46.25455754143851, 43.48042324611119, 37.94031878880092, 35.233915533338276, 34.80177927017212, 34.06775420052664, 34.8976331438337, 35.06198583330427, 35.54372876031058, 35.435910088675364, 35.92091172082083, 36.48811749049595, 38.59080219268799, 36.06772715704781, 39.08529506410871, 39.02216025761196, 39.75922516414097, 41.81135477338518, 41.46836389814104, 41.06970058168684, 41.45865726470947, 39.378088678632466, 37.48072324480329, 33.7022442136492, 34.33011817932129, 34.65232004438128, 35.935381344386506, 36.689431122371126, 33.69573722566877, 35.65630694798061, 36.290111201150076, 40.18804713657924, 44.783877508980886, 48.26642581394741, 45.839559010096956, 49.559381348746165, 45.37843486240932, 45.05489546912057, 49.38645110811506, 47.134352343423025, 48.40027938570295, 49.070596422467915, 46.065233026232036, 47.639156341552734, 50.332837445395334, 46.05207313810076, 44.61044004985264, 42.87280327933175, 42.103866985866, 42.523750100817, 46.88011428288051, 46.439720085689, 45.1863032749721, 34.951342718941824, 35.671624251774375, 36.419896602630615, 36.45965419496809, 37.65277106421334, 38.689400604793, 35.29854072843279, 36.68336534500122, 39.50786018371582, 43.96942704064505, 47.258711201804026, 47.58632223946707, 49.13737208502633, 46.78184591020857, 48.65274912970406, 47.902423586164204, 48.429583413260325, 48.34835549763271, 48.43501343045916, 47.96260888235909, 45.81641108649117, 49.42343289511544, 46.77828843252999, 45.76825312205723, 42.75888408933367, 39.94437033789498, 33.893931116376606, 34.66058840070452, 35.47114787782942, 36.68449790137154, 36.844480173928396, 38.93948711667742, 44.06822695050921, 45.897586890629356, 46.813595703669954, 51.98932620457241, 50.50551755087716, 53.95450953074864, 45.51514761788504, 52.30400317055838, 51.23715591430664, 46.733753953661235, 46.64838491167341, 45.3837502343314, 52.74271590369088, 54.577109813690186, 51.38793877192906, 16.72937055996486, 2.4156124591827393, 6.317796349525452, 10.324660062789917, 4.712240925856999, 0.20709183253347874, 0.5299979490893227, 29.248174462999614, 63.854862213134766, 49.91915212358747, 58.018458775111604, 42.25363540649414, 45.85442120688302, 60.34677927834647, 54.01063707896641, 9.439214638301305, 0.17811237541692598, 0.1508435865065881, 0.14708470606378146, 0.18818756192922592, 0.21022019109555654, 0.10515878043536629, 0.17707347044987337, 0.15991678035684995, 0.11127576005778142, 0.1753774043172598, 0.10277162638625928, 0.10752139865819897, 0.13564190507999488], [0.025629539907510792, 0.08148109061377388, 0.0022446865041274577, 0.026406084220590334, 0.03423878883144685, 0.07184468555663313, 0.09000108164868184, 0.011048701907774168, 0.06151909248105117, 0.02856586966663599, 0.09085743355431727, 0.029155051801353693, 0.011308109238078552, 0.016926171391138008, 0.057459017128816674, 0.029251030579741513, 0.44175430706569124, 17.13332145554679, 47.024206025259836, 43.50049311774117, 27.50768198285784, 19.290832655770437, 37.717417103903635, 34.41210344859532, 45.228732449667795, 28.096932649612427, 0.9574920556374958, 0.057537028299910684, 0.08273380875055279, 1.8146615688289915, 1.4581732749938965, 2.0126175923006873, 1.4614339343139102, 16.602232422147477, 34.75641795567104, 47.85030514853341, 47.5005258832659, 47.092315741947715, 43.56179707390921, 42.58834750311715, 40.6802088873727, 39.23894057955061, 37.19402667454311, 36.38307115009853, 36.85186958312988, 38.980679512023926, 38.414710521698, 35.97915152141026, 33.00821644919259, 29.793764386858257, 30.96871519088745, 31.171696390424454, 30.90738344192505, 31.46969073159354, 30.253627436501638, 32.17232036590576, 31.724491596221924, 32.98669787815639, 32.8618700163705, 32.43667500359671, 33.32345969336373, 34.54481404168265, 35.51922941207886, 36.04918588910784, 34.95870086124965, 37.608907086508616, 39.31090307235718, 36.66710656029837, 35.86361340114048, 32.3551413672311, 33.4799713407244, 32.938223770686555, 30.6033650125776, 31.68361186981201, 32.82792459215437, 32.26638160433088, 31.710254737309047, 34.54660667691912, 35.8651385307312, 40.016648973737446, 43.93917805807931, 44.193270206451416, 44.934132303510395, 44.95425081253052, 43.87025192805699, 43.16994646617344, 44.43657875061035, 45.54859972000122, 44.41575847353254, 44.18822928837368, 46.78796032496861, 44.256905283246724, 43.346753801618306, 39.143795422145296, 38.3486887386867, 39.415132999420166, 43.10647814614432, 45.18437167576381, 45.04253114972796, 43.58802304949079, 34.24017374856131, 32.20645339148385, 34.080643108912874, 33.739764486040386, 35.08707925251552, 32.66660131726946, 34.68732506888253, 33.33663347789219, 38.64499119349888, 43.141076701028005, 47.03693512507847, 46.17764098303658, 44.717358929770334, 41.26345804759434, 42.543274538857595, 44.292209080287385, 46.79433529717581, 45.805036885397776, 46.48113829748971, 44.539620535714285, 46.472004890441895, 45.19759062358311, 46.049599579402376, 45.07076515470232, 43.111515590122764, 41.29014607838222, 38.726295539310996, 35.81063338688442, 31.358057498931885, 32.66580574853079, 32.78751386914934, 34.201451437813894, 33.54306445802961, 38.720104694366455, 39.31209816251482, 43.46701669692993, 43.91792351858956, 49.812632765088765, 44.41727318082537, 43.46793385914394, 55.5455254146031, 45.78206614085606, 42.711271558489116, 43.93661069869995, 46.2434195790972, 50.93622595923287, 43.2456088747297, 8.62780053274972, 1.781892561486789, 1.4216348699160983, 2.3559854073183875, 0.595378435083798, 0.025441672220560055, 0.548710045005594, 25.11957917894636, 48.118637629917686, 36.96522944314139, 42.22380331584385, 29.280907426561626, 29.259847436632427, 44.29831654684884, 32.613326004573274, 4.1259141479219705, 0.08147524164191314, 0.017934947707025067, 0.011420355045369692, 0.1336670560496194, 0.04460573861641543, 0.00157102474518719, 0.06279329982187067, 0.0614737934832062, 0.029692658489303927, 0.02237463795713016, 0.03364548459649086, 0.07956888393632003, 0.033013507258147, 0.042130938198949607, 0.04381998149412019, 0.008001891380575086, 0.02996079177994813, 0.02030838347439255, 0.014702064217999578, 0.028013326726587753, 0.04401051073468157, 0.04634734123413052, 0.02915878374395626, 0.06893795688769647, 0.03380102857149073, 0.026701626933312843, 0.027451905155820504, 0.020513350243813226, 0.0748315356405718, 0.7996882061873163, 22.62290903500148, 51.58561849594116, 49.51686184746878, 31.183369364057267, 23.20479461124965, 39.41020672661917, 36.68673522131783, 49.95438643864223, 28.856214421136038, 0.9719756841659546, 0.023906758154875467, 0.1806798026497875, 1.4409333829368864, 3.294617772102356, 2.608487069606781, 2.884858399629593, 19.995279244014196, 37.397535937173025, 50.07013300486973, 48.65678950718471, 49.219760349818635, 47.854213510240825, 44.77799933297293, 43.87887116840908, 41.335674149649485, 38.77438402175903, 39.49823692866734, 38.66089562007359, 40.904118061065674, 41.92786564145769, 38.014365741184776, 34.150635787418906, 31.64681421007429, 32.1076534816197, 32.44419642857143, 32.22803102220808, 32.624561241694856, 32.24021468843733, 33.8636508669172, 33.31709166935512, 35.02011946269444, 33.59752443858555, 35.12943547112601, 35.71283401761736, 36.13599668230329, 36.59683247974941, 37.17962653296334, 36.497810227530344, 38.939466272081646, 39.73383297239031, 37.796685627528596, 36.55654335021973, 34.14212771824428, 33.77329649244036, 34.75518812452044, 31.93830851146153, 34.00429630279541, 33.10368469783238, 33.9631803376334, 32.08620439256941, 35.03524569102696, 38.86650323867798, 42.155898571014404, 44.14207240513393, 46.42497600827898, 46.28964941842215, 46.41473436355591, 45.88139063971383, 45.28013174874442, 46.28027629852295, 46.890140533447266, 44.82356909343174, 45.08732966014317, 47.48752580370222, 48.467527525765554, 46.42064380645752, 40.81015757152012, 40.192455768585205, 41.36353990009853, 44.378064496176584, 45.878979614802766, 44.9036922454834, 45.010697977883474, 36.39175639833723, 32.453604289463584, 34.53515257154192, 35.934224469321116, 37.3824896131243, 34.230196135384695, 35.32127523422241, 34.235598359789165, 40.118777070726665, 44.80888754980904, 48.93057632446289, 47.427392618996755, 46.28420550482613, 43.79757029669625, 45.45326696123396, 45.05186605453491, 48.3212297303336, 48.25326592581612, 47.37318277359009, 47.240649359566824, 48.743965080806184, 46.38293593270438, 48.78331272942679, 46.4909074647086, 45.385779108319966, 42.461278847285676, 40.26807648794991, 36.02896315710885, 34.18524476460048, 35.059758935655864, 33.32486322947911, 36.38594423021589, 36.19520575659615, 40.911090578351704, 42.18557432719639, 44.97389336994716, 45.74824925831386, 51.34713200160435, 43.52571855272566, 46.22208513532366, 55.93291527884347, 48.41319956098284, 45.39444351196289, 45.572543212345664, 49.86541822978428, 52.38772201538086, 45.133271149226594, 8.958274228232247, 2.58038312622479, 4.149192784513746, 7.649877190589905, 1.1766252113240105, 0.10720288753509521, 0.4587845046605383, 26.66927065168108, 54.7385060446603, 41.68331684385027, 50.60537706102644, 34.35370036533901, 33.650900500161306, 51.31928014755249, 39.145528997693745, 5.428182440144675, 0.042180701957217286, 0.06148560677788087, 0.03474271982642157, 0.0348537010140717, 0.02611409024601536, 0.007380658644251525, 0.058456897868641784, 0.09010855481028557, 0.027332108101940582, 0.06343963156853404, 0.0420927400700748, 0.07485832420310803, 0.03428006072395614, 0.11173765920102596, 0.16617794867072785, 0.060154219291039875, 0.12584774063101836, 0.16180073283612728, 0.1613180094531604, 0.1474707924893924, 0.1363068422568696, 0.15022014853145393, 0.1267687433532306, 0.14360391641301767, 0.1342161265867097, 0.11294734464692217, 0.14148961486560957, 0.12848266852753504, 0.11095207171248538, 1.0726000389882495, 24.987617254257202, 59.71237400599888, 55.141577993120464, 37.72905533654349, 29.749935150146484, 46.64340305328369, 44.07073872429984, 55.186640535082134, 34.358241013118196, 1.8082175488982881, 0.13983010819980077, 0.48115808410303934, 7.72820770740509, 6.457373934132712, 4.049136119229453, 2.283688098192215, 19.63133086477007, 36.43052387237549, 50.31335817064558, 50.56161730630057, 51.75164222717285, 48.706476075308665, 47.46697303227016, 44.88256972176688, 43.292498792920796, 39.87950890404837, 40.947749274117605, 39.72992461068289, 42.839368547712056, 43.5370580128261, 39.99302509852818, 35.64047547749111, 32.46479436329433, 34.03893307277134, 34.9114704813276, 34.25512974602835, 36.09190341404506, 33.54644823074341, 36.11379023960659, 36.1201617377145, 37.61011259896414, 36.14340346200125, 37.84547240393502, 37.96986252920968, 39.34195804595947, 37.66474628448486, 39.48308290754046, 39.03870391845703, 42.86124842507498, 42.44154248918806, 40.29206166948591, 38.63380459376744, 36.79991095406668, 35.74400363649641, 35.815045492989675, 32.95576102393014, 34.495589528764995, 35.24974005562918, 35.24448721749442, 33.59421362195696, 38.348414284842356, 38.47497224807739, 44.59378521783011, 47.923285552433555, 47.82099764687674, 47.354134287152974, 47.220179966517854, 48.14866427012852, 46.311494554792134, 46.93227788380214, 48.308691705976216, 45.30278287615095, 48.10337938581194, 47.758317947387695, 50.45419815608433, 47.89622231892177, 43.113336018153596, 43.11272457667759, 43.28268098831177, 46.93585620607649, 48.932938711983816, 49.2589099747794, 47.90871865408761, 38.18567705154419, 35.22437218257359, 36.96516343525478, 37.376166752406526, 38.43760136195591, 34.48296465192522, 37.531608377184185, 36.3671041897365, 41.9130277633667, 47.98411008289882, 50.769719328199116, 51.62929139818464, 48.60763100215367, 45.89351872035435, 47.90693644114903, 48.24885729381016, 50.02661643709455, 49.61675957271031, 48.873073032924104, 48.69006095613752, 51.18655913216727, 48.5983099937439, 50.42505393709455, 48.62461934770857, 47.64757408414568, 44.2450829233442, 43.28548111234392, 39.11233745302473, 35.076583998543875, 37.010014057159424, 35.702238014766145, 37.8049122946603, 37.31220858437674, 42.37724733352661, 43.47697693961007, 47.82058770315987, 47.699998242514475, 52.951561382838655, 47.03071648733956, 48.17781891141619, 56.18106671742031, 50.86031688962664, 46.971424034663606, 48.26981653485979, 52.652639457157676, 54.94718129294259, 46.086379868643625, 10.58379226071494, 4.847593137196132, 9.928105524608068, 7.258290614400591, 1.7535332718065806, 0.22635514315749916, 0.7319525522845132, 31.22178942816598, 61.63763645717076, 48.59019797188895, 51.17435114724295, 37.59497594833374, 41.32171869277954, 58.64945943014962, 47.75275591441563, 7.979188799858093, 0.28116493565695627, 0.13645279513938086, 0.18357329310051032, 0.21172280689435347, 0.1431294847279787, 0.06837774480559997, 0.14164421228425844, 0.1946750216718231, 0.13582406459110125, 0.1015700019363846, 0.1691668275743723, 0.24409301206469536, 0.1208484438913209], [0.005073727790399322, 0.022941772792754427, 0.04299394314044288, 0.0256208003764706, 0.047542594240180085, 0.04856459011456796, 0.023364618853000656, 0.04383562172630003, 0.04795261598857386, 0.053535062686673233, 0.034743401754115305, 0.05349799092592938, 0.04200175870209932, 0.02930749487131834, 0.02777116436378232, 0.059269199280866554, 0.07030814979225397, 9.866935321262904, 35.94598429543631, 44.50854819161551, 34.65915012359619, 21.449700491768972, 24.857760633741105, 38.8763245173863, 44.162673813956125, 38.636410168239046, 5.195000461169651, 0.10541876112776143, 0.024853613061298217, 1.19324106829507, 1.8807264523846763, 2.7249386608600616, 1.037681215575763, 5.705328277179173, 29.408657005855016, 49.28324604034424, 48.48590898513794, 45.68744557244437, 43.75117370060512, 42.081226280757356, 39.360745974949424, 36.2935505594526, 34.75340243748256, 34.73213052749634, 34.117305278778076, 32.766137736184255, 32.39287008558001, 30.799929550715856, 31.107880660465785, 31.828193460191997, 30.058417797088623, 29.886328288487025, 28.74669517789568, 30.910100187574113, 31.137830870492117, 31.483076436179026, 32.52528190612793, 33.33271816798619, 32.06212888445173, 32.930007525852744, 32.70028965813773, 32.725518567221506, 33.16179248264858, 33.32467910221645, 34.478524753025596, 37.60690253121512, 37.82722296033587, 35.22808599472046, 34.48472602026803, 33.0313435282026, 31.494957855769567, 32.28333520889282, 33.386688300541465, 32.36899954932076, 31.69771671295166, 31.42265142713274, 32.49739531108311, 32.788236481802805, 35.99297843660627, 37.41627870287214, 40.83572694233486, 43.31663336072649, 45.0820768220084, 48.563544682094026, 46.977545397622244, 43.20681708199637, 44.142951352255686, 44.88311168125698, 45.285551343645366, 38.69139126368931, 44.300682408469065, 47.09120403017317, 42.05100161688668, 39.87634399959019, 37.99042572293963, 40.304043837956016, 41.33014685767037, 44.23602942058018, 44.37626838684082, 43.80745758329119, 34.17688955579485, 30.998488221849712, 32.83257293701172, 33.07600654874529, 33.677303654806956, 33.46402175085885, 34.7868059022086, 36.64182553972517, 42.739311013902935, 45.99059895106724, 46.68050643375942, 45.278141089848106, 42.12256111417498, 40.694713251931326, 39.202038696834016, 42.865459033421104, 43.773512159075054, 45.46830633708409, 44.95563350405012, 44.34604024887085, 46.44016477039882, 46.206055641174316, 46.599792684827534, 46.04359980991909, 44.81097895758492, 44.297131878989084, 43.753987721034456, 41.208119119916645, 38.55194786616734, 34.854759284428184, 32.85808324813843, 34.030154023851665, 33.979286261967246, 33.32938303266253, 37.40826742989676, 38.55385514668056, 45.53657933643886, 44.28748777934483, 50.44923366819109, 43.022592544555664, 43.535508564540315, 54.47796596799578, 52.63308375222342, 47.83040203366961, 50.790779318128315, 53.869105747767854, 37.049556255340576, 4.435906725270407, 1.4947318732738495, 3.7765569857188632, 3.797867979322161, 0.0734101811956082, 0.06789561174809933, 0.2555817498692444, 24.473594733646937, 50.057581084115164, 38.794794355119976, 27.624903304236277, 20.63546715463911, 40.37185478210449, 42.77560840334211, 34.322471686771934, 2.1829874217510223, 0.07682944129088096, 0.02682318478556616, 0.06245674645262105, 0.027769943000748754, 0.041606115110750706, 0.0681092417133706, 0.051028564505811246, 0.03522236266040376, 0.018878023173393946, 0.09565532074442931, 0.036801052412816455, 0.015495003633467215, 0.018516399631542817, 0.04481097849618111, 0.04161079360970429, 0.03705592034384608, 0.020494609106598154, 0.023219040861087184, 0.051716690616948266, 0.05118632050497191, 0.023340120346152356, 0.005418074558422501, 0.005428496856308941, 0.03536197463316577, 0.06483741370694977, 0.03633905148931912, 0.048347336772297106, 0.045357694516756704, 0.035099388366299014, 0.24155830379043305, 12.975874645369393, 45.08105196271624, 49.43416438783918, 38.744558879307334, 22.725758007594518, 32.17568676812308, 42.980205059051514, 48.65037979398455, 40.74965960638863, 4.474595163549695, 0.12495271222931997, 0.1050310597888061, 1.4782001546451022, 2.0177609963076453, 4.206796390669687, 2.1630078767027174, 8.275948098727635, 29.98575006212507, 49.46592460359846, 49.6939332144601, 48.061071804591585, 46.411413124629426, 43.78680753707886, 41.15441649300711, 38.08857945033482, 35.16035148075649, 35.89409167425973, 36.565899099622456, 35.14488826479231, 34.918818201337544, 32.91686848231724, 32.959068366459434, 33.971327100481304, 32.46956777572632, 30.70708077294486, 30.213473796844482, 31.99393231528146, 33.56073720114571, 32.615615436008994, 34.30046326773507, 34.93004649026053, 33.7502111026219, 34.10521193913051, 33.96808923993792, 35.027422019413535, 35.00640719277518, 35.27919346945626, 36.59949711390904, 39.19781766619001, 39.50060279028756, 37.577699252537315, 37.4558938571385, 34.16721418925694, 33.80916656766619, 34.018665177481516, 34.582817213875906, 33.07878582818167, 34.00936501366751, 32.95468405314854, 33.4927317074367, 34.920791489737375, 38.10571370806013, 40.2889975139073, 41.35433006286621, 44.91257899148123, 45.858895846775596, 49.4090188571385, 46.865366731371196, 44.96400955745152, 46.33662618909563, 45.15983411243984, 45.927773339407786, 42.409202098846436, 46.90823711667742, 47.80991874422346, 44.359224455697195, 40.97137662342617, 40.120844159807476, 41.18613154547555, 42.514418670109336, 46.7184088570731, 46.193458557128906, 44.99473796572004, 36.50839580808367, 33.13988133839199, 33.93992819104876, 34.44996765681675, 36.16500541142055, 34.68802683694022, 36.19036633627755, 36.58483641488211, 44.60585423878261, 47.21947125026158, 48.063910143715994, 47.528117179870605, 43.76302037920271, 42.3298328263419, 42.85011741093227, 43.554279123033794, 47.2445889881679, 47.91962732587542, 47.226749488285606, 46.074501923152376, 47.959774017333984, 47.74938603809902, 47.879133224487305, 47.70749534879412, 47.132927962711875, 45.58718654087612, 45.43071658270699, 42.56350769315447, 39.04809440885271, 35.595169748578755, 34.382483278002056, 34.29851082393101, 35.282459122794016, 35.57098306928362, 38.552528040749685, 40.83850622177124, 48.52471814836775, 45.934759753090994, 52.42398466382708, 44.39230830328805, 47.12491321563721, 55.599964550563264, 52.215820108141216, 49.86659247534615, 52.392297404153005, 54.96009799412319, 39.41721051079886, 6.287329801491328, 2.510654479265213, 4.14782008102962, 8.807472263063703, 2.6198002568313052, 0.05169557460716792, 0.30974901041814257, 27.88010369028364, 54.9849134853908, 44.62686906542097, 34.84805427278791, 25.07757384436471, 42.35944257463728, 51.250777857644216, 40.13046394075666, 3.438321066754205, 0.06085792795888015, 0.018680082634091377, 0.0491465729927378, 0.020344099861436656, 0.03170155640691519, 0.062483317883951325, 0.005191431987831103, 0.04940708972779768, 0.003622000845747867, 0.053375169302203825, 0.01407648970572544, 0.08064898276435477, 0.025335037049704363, 0.1704823441271271, 0.11914067981498581, 0.19230996072292328, 0.0889566805479782, 0.13185087564800466, 0.23478353875023977, 0.0997402983318482, 0.16825695282646588, 0.12161790260246821, 0.13889036434037344, 0.08112074102142028, 0.17062365583011083, 0.12604395938771112, 0.14944311736949853, 0.11885182745754719, 0.1275938826480082, 0.23162536535944256, 14.28952625819615, 49.574361664908274, 56.91189214161464, 47.604821818215505, 30.65784236363002, 33.1098164830889, 48.47446877615792, 53.72728259222848, 45.76599843161446, 6.142270088195801, 0.2679345884493419, 0.4236607908138207, 6.6209306206021985, 6.973024070262909, 7.892490914889744, 3.0503542848995755, 8.293716379574366, 32.46134805679321, 52.1529597554888, 52.759846687316895, 48.50599275316511, 48.40607418332781, 46.68891027995518, 43.979762486049104, 40.031198501586914, 36.178279944828574, 37.95327717917306, 38.90160206386021, 36.217794350215364, 37.27063751220703, 34.26136228016445, 34.79913895470755, 35.221478257860454, 34.27237170083182, 32.94297286442348, 32.60340745108468, 34.20261526107788, 35.33216306141445, 34.89340169089181, 36.24964141845703, 37.305857930864605, 35.59091050284249, 36.50127737862723, 36.71045289720808, 36.504310267312185, 36.73186377116612, 37.518771580287385, 39.2005934715271, 41.740576948438374, 40.6622200012207, 38.464202540261404, 40.08311891555786, 36.262464318956646, 34.08119896480015, 35.40017550332205, 36.922077655792236, 35.83718245370047, 35.36641073226929, 33.43786873136248, 35.087398869650706, 36.468071937561035, 40.50452716009957, 41.564964703151155, 44.08100468771798, 47.323923519679475, 48.37499836512974, 51.63208457401821, 48.04979487827846, 46.069916112082346, 46.494968686785015, 48.04590041296822, 47.13984489440918, 44.58382150105068, 50.36893333707537, 48.82275765282767, 46.5137357711792, 42.147133418491904, 41.29000016621181, 43.89158289773123, 43.7513439314706, 46.90884855815342, 47.905612809317454, 46.851456437792095, 38.349227224077495, 32.891094139644075, 35.192486899239675, 35.76109620503017, 37.11940649577549, 36.32786076409476, 37.921155657087056, 39.518411023276194, 46.68090942927769, 50.07871055603027, 49.933336871010916, 50.222903047289165, 47.1734151159014, 44.62665367126465, 43.60682487487793, 46.78140469959804, 48.60497679029192, 50.13527584075928, 48.1024934904916, 47.941465514046804, 50.49221175057547, 50.238390581948416, 50.91089630126953, 49.2515344619751, 49.01200573784964, 47.59323917116438, 47.018466813223704, 45.697999886104036, 42.550837653023855, 38.69953107833862, 35.96510573795864, 36.916015352521626, 37.26524918419974, 37.107076917375835, 40.598918437957764, 42.40774645124163, 50.757883071899414, 48.953321252550396, 54.45248344966343, 48.49596997669765, 47.98306785311018, 54.202028683253694, 55.51893465859549, 51.59846918923514, 57.45953178405762, 57.03166171482631, 42.044258390154155, 6.5502409509250095, 3.314368026597159, 9.238075579915728, 12.61304145199912, 1.8784127022538866, 0.2847791388630867, 0.44393088455711094, 29.464006355830602, 61.341156823294504, 49.79263237544468, 38.01898281914847, 30.08846528189523, 52.68345471790859, 57.077863761356895, 48.874181270599365, 4.087157096181597, 0.15474771415548666, 0.13039589300751686, 0.11176621873996087, 0.08824395414974008, 0.09192601085773536, 0.1826882255928857, 0.18304917908140592, 0.08002309527780328, 0.12286984042397567, 0.3200846186705998, 0.26082234723227365, 0.16196552185075624, 0.11867036005215985], [0.03982020415631788, 0.04364631724144731, 0.021260512294247746, 0.06418046967259475, 0.020230635235618268, 0.0475021230189928, 0.018796950113028288, 0.037687287000673156, 0.04432428568335516, 0.03163223387673497, 0.05789678756679807, 0.01500936594259526, 0.036078151381973705, 0.005310010223183781, 0.10369005746075086, 0.08500470939491477, 0.04501886126984443, 4.4400200588362555, 30.18037257875715, 44.98473950794765, 35.225476946149556, 30.365420477730886, 31.594925062997, 42.65952484948294, 39.01770993641445, 43.3014862877982, 8.249352131571088, 0.01888817236093538, 0.04514986263321979, 0.28027092505778584, 1.4718750140496661, 2.4103324796472276, 1.6922345267874854, 2.78534933924675, 23.125225578035625, 47.357358251299175, 47.09023128237043, 45.740317889622276, 42.14923177446638, 38.96403857639858, 37.80422442299979, 34.428744384220664, 33.332134519304546, 32.7596481187003, 32.59706374577114, 33.178509848458425, 32.95368351255144, 32.16510466166905, 31.7458746773856, 29.99005447115217, 30.691582815987722, 31.48727662222726, 30.864738873073033, 31.220180920192174, 31.36313315800258, 31.676976340157644, 32.918577739170615, 32.58277824946812, 31.526985577174596, 32.66848775318691, 30.55997003827776, 32.38654375076294, 33.671394211905344, 33.066018513270784, 33.56654936926705, 32.625700746263774, 33.05273355756487, 36.77758639199393, 34.09101676940918, 33.06688008989607, 32.3616691998073, 33.477869510650635, 31.426108155931743, 31.85567011151995, 30.977720056261333, 32.25157151903425, 31.842697824750626, 32.727943488529746, 35.70364849908011, 35.84586770193917, 40.743771008082796, 40.30661119733538, 44.06837633677891, 44.758606910705566, 45.661434991019114, 43.60435479027884, 43.62191983631679, 44.1839839390346, 45.92313541684832, 38.72165066855294, 40.586356094905305, 47.9384708404541, 41.59830910818917, 39.70768690109253, 37.98826830727713, 42.09692920957293, 42.4471218926566, 44.02960538864136, 45.225077697208945, 42.541422843933105, 34.489141600472585, 32.78734711238316, 32.9617851121085, 33.15228387287685, 34.039707796914236, 34.753086294446675, 34.514481680733816, 37.550594329833984, 43.15204095840454, 46.25202144895281, 44.524570737566265, 43.610601220812114, 39.29149675369263, 36.99034023284912, 36.41094732284546, 37.19532251358032, 41.267175333840505, 42.57088668005807, 42.21302318572998, 44.229953220912385, 43.451397146497456, 42.970713819776265, 45.18179736818586, 45.07151903424944, 46.410700934273855, 45.144607135227744, 44.802630696977886, 44.50662006650652, 41.895247323172434, 40.74626193727766, 36.891196387154714, 35.64213957105364, 34.05569560187203, 35.34618105207171, 35.62583909715925, 38.05606882912772, 39.6672796521868, 43.68709741319929, 45.36911385399954, 50.07885299410139, 45.60378926140921, 41.66182606560843, 47.82701131275722, 44.29940741402762, 55.07021999359131, 48.87229483468192, 26.91748809814453, 1.2050609311887195, 1.327171721628734, 2.2103140354156494, 13.296943954059056, 3.874977784497397, 0.0325376336861934, 0.3238464710967881, 21.069151129041398, 45.76878465924944, 38.89317042487008, 32.939946923937114, 23.767284291131155, 38.32696519579206, 42.92765583310808, 27.553618260792323, 0.7424131738288062, 0.035839832920048914, 0.021503090259752104, 0.05658226506784558, 0.05184755966599498, 0.019497737687613283, 0.03079547466976302, 0.02229463528575642, 0.005303585344725954, 0.011152017346051122, 0.034829796225364716, 0.04986803213666592, 0.025709776673465967, 0.009887822637600558, 0.09259119909256697, 0.05066125653684139, 0.05222697609237262, 0.02577136560077114, 0.02420286405166345, 0.03509637227814112, 0.01386104041843542, 0.03714400436729193, 0.045364374694015296, 0.02515976975804993, 0.04667404906025954, 0.015185109905100294, 0.025539516970249157, 0.044050785180713446, 0.0070741020359231955, 0.10070482229015656, 0.04192791034334472, 6.3072715657097955, 36.4084529195513, 50.04683569499424, 38.06268004008702, 30.58520242146083, 32.12011507579258, 47.13492556980678, 44.58636106763567, 47.05686255863735, 9.915337341172354, 0.02760603777798159, 0.04041865847206541, 1.17511918927942, 3.260437411921365, 7.275238139288766, 3.1480507339750017, 4.090206052575793, 25.166717495237076, 48.47968339920044, 49.19477810178484, 46.90265423910958, 46.13828986031668, 40.87789555958339, 40.21910905838013, 35.01844842093331, 34.97350399834769, 34.75141872678484, 34.60623959132603, 33.533882413591655, 34.49630519321987, 34.087966510227744, 33.28744718006679, 30.934557846614293, 31.13773012161255, 34.08442987714495, 32.68314150401524, 33.266706807272776, 34.00669690540859, 33.06537233080183, 34.9784129006522, 34.41408021109444, 33.81275878633772, 34.658003670828684, 33.87646334511893, 34.723594665527344, 34.78289754050118, 34.685508114951, 35.35444940839495, 34.87582969665527, 36.236808095659526, 37.856884820120676, 35.75796604156494, 35.16042096274239, 33.076103823525564, 34.90958057131086, 32.840851715632844, 33.540646484919954, 32.36488274165562, 34.457499504089355, 33.32187897818429, 34.793962546757285, 37.98607962472098, 38.700837339673726, 41.86241708483015, 43.306579317365376, 46.07555457523891, 46.31668485913958, 48.54270356042044, 45.24026645932879, 45.08298356192452, 44.607751096997944, 45.63693216868809, 39.41911779131208, 42.64003167833601, 49.41075243268694, 42.94290018081665, 41.348632540021626, 39.55302694865635, 43.30365759985787, 43.722501959119526, 46.06569160733904, 46.30535929543631, 43.42195415496826, 35.13768993105207, 35.26757608141218, 34.651024205344065, 35.2481141771589, 35.523704051971436, 35.793342794690815, 35.42928498131888, 38.91970559528896, 45.19799361910139, 47.36104427065168, 48.03538431440081, 46.1933091708592, 41.677643639700754, 39.29595749718802, 38.365930693490164, 38.64388990402222, 42.89119168690273, 42.63157572065081, 45.10892118726458, 46.31861298424857, 44.84376403263637, 46.62899596350533, 45.44060386930193, 46.30321230207171, 47.90584209987095, 46.40918622698103, 46.89267315183367, 45.73187582833426, 43.37489400591169, 41.140443665640696, 38.68008654458182, 36.51592765535627, 35.519955498831614, 37.079430035182405, 38.476285457611084, 40.384830542973106, 42.05876970291138, 46.74084459032331, 48.089764390672954, 51.6251711164202, 46.1577274458749, 44.32708903721401, 49.31906747817993, 47.12886674063546, 57.1640179497855, 50.21582978112357, 29.686644009181432, 1.894360989332199, 2.720635554620198, 5.243077652794974, 5.992475177560534, 1.7769682428666522, 0.005753494774190975, 0.27105810227138655, 25.049933910369873, 52.218623706272666, 42.93835258483887, 30.554272515433176, 27.096626554216655, 44.668926511492046, 48.21515505654471, 34.4258713041033, 1.580597494329725, 0.026093449210748076, 0.030183486973068545, 0.03841609128617814, 0.03416293200903705, 0.022923730546608567, 0.04951517357091818, 0.035586908991847715, 0.007202463473991624, 0.07672880097691502, 0.03226751568061965, 0.0268395306941654, 0.017366946042914475, 0.01402207204539861, 0.1565674500805991, 0.23296465777925082, 0.18041312481675828, 0.18401918560266495, 0.1136668903220977, 0.1286517730248826, 0.05969958047249487, 0.1283263476299388, 0.09082736766764096, 0.05783405021897384, 0.13727059268525668, 0.12276920011000973, 0.08034896850585938, 0.1722966924841915, 0.11197709385305643, 0.27883777767419815, 0.1499430484005383, 6.06503130708422, 42.688766343253, 56.68077768598284, 44.680905205862864, 41.09861203602382, 41.521145888737266, 51.70270259039742, 48.36348172596523, 52.4425676209586, 10.779903428895132, 0.11540032337818827, 0.344805223601205, 1.7127114108630588, 6.828870228358677, 6.750963985919952, 4.202872395515442, 4.712206184864044, 25.516766003199987, 51.02788312094552, 51.46408060618809, 49.75058535167149, 47.83891705104283, 44.33848755700247, 41.944725445338655, 36.14461939675467, 37.261035101754324, 35.467183930533274, 35.72582367488316, 36.64003637858799, 35.383763858250205, 36.0725804737636, 35.82005861827305, 34.09191656112671, 33.76938118253435, 35.38060590199062, 35.531558990478516, 33.88201495579311, 36.375956194741384, 34.73863751547677, 37.038157735552105, 36.00861188343593, 35.94383035387312, 36.42410373687744, 35.84911945887974, 36.1470547403608, 36.518689564296174, 36.64611605235508, 37.84027862548828, 35.82965408052717, 35.82998759405953, 41.30935089928763, 38.62451137815203, 35.97661542892456, 35.16855730329241, 36.46770715713501, 34.20078788484846, 35.00026151112148, 34.8516708101545, 36.01220757620675, 33.825130053928916, 36.510897159576416, 39.02449485233852, 39.52641534805298, 44.274338313511436, 46.19045693533761, 46.80165522439139, 48.27179677145821, 50.285089424678254, 47.15017686571394, 46.32098926816668, 46.37618923187256, 47.21028920582363, 42.43754380089896, 44.069109371730256, 51.501670360565186, 45.68974542617798, 42.932297229766846, 42.19313744136265, 45.74888849258423, 46.078514507838655, 47.4996851512364, 48.39070129394531, 46.00721556799752, 38.31888444083077, 36.07533890860421, 36.55941295623779, 37.039015838078086, 37.60627024514334, 37.746985163007466, 37.261403356279644, 41.07660361698696, 48.660538060324534, 49.10981552941458, 47.92170136315482, 47.98599999291556, 42.749403272356304, 41.56971379688808, 39.281897817339214, 39.1520915712629, 44.87641709191458, 43.963823318481445, 47.50249917166573, 48.197659492492676, 47.59661946977888, 47.29956660951887, 48.884693895067485, 49.59058223451887, 50.7668080329895, 49.6385942867824, 49.73461839130947, 49.10738018580845, 45.708126885550364, 44.26677172524588, 40.795229366847444, 38.4145507131304, 37.927895409720286, 38.884797845567974, 40.53652014051165, 42.063998222351074, 44.32035970687866, 48.39330339431763, 50.98002392905099, 53.27424962180001, 49.41303491592407, 47.06303950718471, 49.30777318137032, 47.85575253622872, 61.3245575768607, 52.24914714268276, 31.567594323839458, 1.8614006893975394, 4.8946172424725125, 9.936079451016017, 24.336571046284266, 8.185750927243914, 0.1935663361634527, 0.615484241928373, 27.843629121780396, 60.288268498011995, 51.76633766719273, 45.36060231072562, 34.381590434483115, 51.53837769372122, 56.13628210340227, 40.438477584293906, 2.4507195353507996, 0.1605566388794354, 0.13635640245463165, 0.1522211618721485, 0.16033891056265148, 0.13215065241924354, 0.13975313518728527, 0.10884015860834292, 0.0735632044130138, 0.14859751345855848, 0.11409102220620428, 0.1224486737379006, 0.11877387735460486, 0.09688648182366576], [0.010534011043741234, 0.034270920857254944, 0.023294889201809253, 0.03346489589395268, 0.010574786757518138, 0.035000654735735486, 0.029953059873410633, 0.054954612228487215, 0.048451203520276716, 0.020621462924672023, 0.02429313974321953, 0.04913370118343404, 0.015924604509824088, 0.035673737725509067, 0.06897720335317509, 0.027509802852624228, 0.011133458565122314, 0.969654877270971, 30.22046368462699, 45.78554718835013, 42.804259300231934, 22.135644027165004, 23.59907708849226, 40.82896981920515, 37.79170376913888, 44.28908586502075, 15.829429456165858, 0.4643158678497587, 0.05614360235631466, 0.6466662915689605, 0.9692396138395581, 4.681405689035143, 1.6500994563102722, 2.8510682242257253, 17.90686093057905, 47.313848631722585, 47.24341126850673, 45.161869934626985, 44.06707354954311, 38.911784648895264, 35.253353118896484, 34.66172095707485, 33.287474972861155, 35.28170871734619, 33.762780393872944, 33.05061783109392, 31.362476553235734, 30.115031719207764, 30.93599612372262, 30.357523850032262, 30.753324508666992, 30.401714393070765, 31.083134651184082, 31.882111481257848, 31.302027225494385, 31.43311194011143, 31.718787125178746, 32.94471338817051, 32.353852476392476, 31.999782698495046, 32.36062349591936, 33.932080200740266, 32.56351089477539, 33.14780575888497, 31.79847948891776, 33.40521567208426, 34.5818201473781, 34.86722782679966, 33.51943016052246, 31.607320649283274, 32.29199613843645, 34.25833286557879, 32.70778676441738, 31.817649568830216, 31.93542848314558, 31.408685547964915, 32.66790063040597, 32.54064784731184, 33.921522412981304, 37.23593473434448, 39.29580116271973, 41.584541252681184, 42.06281008039202, 44.15515933718, 45.84943240029471, 45.87793043681553, 44.84721728733608, 44.228917939322336, 43.946998255593435, 40.50398520060948, 46.639102118355886, 46.14967795780727, 43.460648672921316, 39.25954893657139, 40.51769747052874, 40.06597076143537, 43.659144810267854, 46.748709951128276, 43.938920974731445, 43.859464849744526, 35.20532717023577, 32.163353715624126, 33.33069971629551, 32.35041659218924, 33.78842966897147, 35.36548662185669, 33.28411899294172, 38.72209187916347, 42.89662517820086, 45.705639430454795, 43.53399733134678, 40.40699529647827, 36.901271275111604, 34.1706292288644, 34.25068984712873, 35.20608799798148, 36.73029695238386, 37.408760751996724, 37.43557037625994, 36.49244621821812, 38.21305642809187, 40.22395542689732, 42.201975549970356, 43.854722704206196, 41.86879205703735, 43.7211331639971, 44.51591675622122, 45.15976810455322, 42.950022084372385, 42.63222885131836, 41.59069388253348, 40.7972617149353, 37.04362596784319, 36.58878299168178, 36.65931762967791, 37.29069001334054, 38.190269810812815, 42.71003130504063, 45.56461879185268, 47.48908914838518, 51.00943565368652, 46.92586817060198, 42.127445697784424, 49.700683389391216, 50.95339148385184, 43.09508310045515, 13.187513300350734, 1.6562030145100184, 2.5983502992561887, 2.440082060439246, 2.6936587393283844, 2.049787197794233, 0.058189215803784985, 1.3387377581426074, 26.06942571912493, 44.95536252430507, 42.45356287275042, 30.344846861703054, 27.161220482417516, 40.28104877471924, 45.33490787233625, 17.526916061128887, 0.3043190746435097, 0.08146395081920282, 0.058891289202230315, 0.013527995075232216, 0.0323713077897472, 0.08446820532636982, 0.017635924109656895, 0.02579903625883162, 0.06327833700925112, 0.04489534414772477, 0.030447939211236577, 0.04310335012684975, 0.04866300144099763, 0.04632873580391918, 0.03430801636672445, 0.04095912518511925, 0.025415329794798578, 0.029035107166107212, 0.06721926839756114, 0.09130382817238569, 0.02534821250342897, 0.0787580142329846, 0.03262889325352652, 0.024216215924492905, 0.015811060156141008, 0.03286151880664485, 0.018642658035137823, 0.03217078033568604, 0.027470520764057125, 0.055862526010189734, 0.030868478252419403, 1.8160757443734576, 35.52539593832833, 51.0821659224374, 47.30489240373884, 28.90448703084673, 29.346595696040563, 46.270017283303396, 41.63809101922171, 48.57089935030256, 14.2481757913317, 0.13800712887729916, 0.016091103432700038, 0.594600073993206, 3.0887356996536255, 7.6825840984072, 3.8908418246677945, 3.8284582921436856, 19.103988647460938, 47.989203112465994, 49.87081698008946, 46.428245135716026, 44.4217860358102, 42.51968540464129, 37.66967255728585, 35.66595104762486, 34.189233030591694, 36.12025553839547, 36.36574234281267, 33.98460858208792, 31.923421995980398, 32.419339248112266, 32.08106619971139, 31.73812743595668, 33.230544907706125, 32.86210625512259, 32.92969833101545, 34.108557496752056, 33.351863929203574, 33.2845185143607, 32.43090105056763, 33.660829475947786, 33.696810722351074, 33.3953527041844, 34.08535051345825, 34.44212314060756, 33.28209359305245, 35.4491741997855, 34.11057594844273, 33.025392396109446, 36.319797379629954, 36.933121817452566, 34.86076600211007, 33.16304663249424, 33.435447284153526, 35.534227098737446, 34.01410021100725, 33.596892152513774, 33.533951895577566, 33.41954633167812, 33.72411019461495, 34.48958281108311, 34.546742166791645, 38.99108443941389, 42.008294514247346, 42.49290009907314, 42.78582572937012, 46.402682713099885, 46.38797337668282, 47.15146575655256, 47.13303565979004, 46.959229946136475, 43.90502766200474, 41.62184265681675, 48.012562956128804, 48.66633633204869, 44.64185632978167, 41.155715806143625, 42.684173583984375, 42.18972934995379, 43.33142260142735, 48.228922912052695, 46.00893872124808, 44.99965034212385, 36.06011887959072, 33.8536558832441, 34.95588336672102, 34.58416863850185, 34.88811411176409, 36.639199120657786, 34.977353300367085, 39.933503355298726, 44.62093530382429, 47.47077717099871, 44.95081145422799, 42.96628781727382, 38.91439369746617, 36.89450372968401, 35.49063410077776, 36.761556897844585, 37.308678899492534, 40.96499122892107, 39.68267338616507, 38.51046364648001, 41.09760454722813, 43.452057225363596, 45.04787431444441, 43.93609305790493, 44.43487296785627, 45.220637798309326, 46.52597849709647, 46.46879134859358, 46.682611737932476, 44.21869019099644, 43.199705600738525, 41.40673337663923, 39.55148097446987, 37.80566964830671, 38.02537516185215, 39.35918263026646, 39.82511493137905, 45.83592510223389, 48.92082452774048, 50.04867696762085, 52.414173807416645, 45.507897172655376, 43.75777448926653, 51.15375321252005, 53.12205975396292, 46.865530014038086, 15.956305299486433, 1.7412843576499393, 2.9494816405432562, 5.264856781278338, 3.522089634622846, 1.2885675302573611, 0.06104179059288331, 1.0472101271152496, 27.388737508228846, 50.0383380481175, 46.524484634399414, 37.47338942119053, 30.09680312020438, 45.623146942683626, 52.35305397851126, 23.455958093915665, 0.38789968831198557, 0.018345569958910346, 0.05931480361946991, 0.01445897904756878, 0.0399891288418855, 0.008735811820120683, 0.031033419937427555, 0.017408726836687753, 0.06544579499002014, 0.010759965749457479, 0.020679240181509937, 0.05052925772698862, 0.05970439128577709, 0.030106707343033383, 0.11038980366928236, 0.13359171152114868, 0.11686971810247217, 0.0908812094213707, 0.1520980213369642, 0.10086703287171465, 0.14194230628865107, 0.1264711378940514, 0.1483999104904277, 0.14113801158964634, 0.13362159420336994, 0.08568407222628593, 0.06700185220688581, 0.09467035252600908, 0.14332393929362297, 0.14730581348495825, 0.15440974943339825, 2.000489511660167, 40.35552304131644, 57.01187324523926, 53.960776805877686, 32.6458991595677, 32.0275615964617, 48.89829151970999, 46.928821155003135, 52.55704961504255, 20.570520605359757, 0.8435113632253238, 0.19178971435342515, 2.1058276763984134, 7.956292748451233, 14.77925613948277, 3.968141402517046, 4.575852564402989, 21.309386832373484, 50.00179747172764, 52.0974714415414, 48.97358567374093, 47.06607934406826, 43.77718775612967, 38.9278176171439, 37.4644262450082, 36.76887335096087, 38.42930521283831, 37.876899106161936, 36.155006953648154, 34.061650208064485, 33.394859382084434, 33.80859681538173, 33.6416072845459, 34.9910204069955, 34.47930295126778, 35.11558771133423, 35.43443012237549, 34.0712456703186, 34.872400760650635, 34.539703641619, 35.6800663130624, 35.05365146909441, 35.715126923152376, 35.52418000357491, 37.00517463684082, 34.79424047470093, 37.489804540361675, 34.599590165274485, 35.699295452662874, 38.49799163000924, 39.59993076324463, 37.11288908549717, 35.29418420791626, 34.540301186697825, 37.46207080568586, 36.66972950526646, 34.766996588025776, 34.87750768661499, 35.01598875863211, 35.600349630628315, 35.885430744716096, 36.87044211796352, 41.15649053028652, 44.25913565499442, 43.857790333884104, 45.80927528653826, 47.89307131086077, 46.56443330219814, 47.81898614338466, 48.38989530290876, 48.46726696831839, 45.67872905731201, 43.38830055509295, 48.673840386526926, 49.57500089917864, 48.213935647692, 43.138425963265554, 46.04552446092878, 43.6569630759103, 45.43600068773542, 49.90490484237671, 47.961643082754954, 46.285021918160574, 39.32050895690918, 35.43614980152675, 36.41650588171822, 36.37383699417114, 36.70452955790928, 39.36082240513393, 36.68139205660139, 42.31354277474539, 45.31614426204136, 50.00661257335118, 47.169993128095356, 43.43428373336792, 41.056200231824604, 37.97272171292986, 37.5324386869158, 38.822628838675364, 38.90749066216605, 42.807476316179546, 40.97840472630092, 39.595320633479524, 42.50127962657383, 44.927284853799, 47.400148732321604, 47.16185678754534, 45.741071769169395, 46.19851337160383, 47.280882903507774, 50.34007746832711, 48.87561954770769, 46.53373268672398, 45.29649823052542, 44.65400872911726, 41.762863295418875, 40.29724155153547, 40.12078162602016, 41.29937328611101, 42.27852037974766, 48.046821049281526, 50.651124000549316, 52.14776597704206, 53.671165466308594, 47.04721845899309, 45.822758265904014, 51.25291095461164, 53.93034022194998, 47.16710615158081, 17.24717116355896, 3.557480935539518, 7.466860771179199, 9.050634026527405, 9.791813135147095, 5.291108378342219, 0.21702436384345802, 1.615933318223272, 31.972653457096644, 55.572234289986746, 55.111985615321565, 42.17147295815604, 38.47209916796003, 52.914947850363596, 60.21898800986153, 28.839476210730417, 0.7969734147191048, 0.1848505131368126, 0.18266115204564162, 0.060551772958465984, 0.09997913587306227, 0.10751926127289023, 0.157686123624444, 0.13833024725317955, 0.1629504154303244, 0.08322314106460128, 0.14978465118578502, 0.08507172829870667, 0.14712579814451082, 0.16469585177089485], [0.06139430310577154, 0.10426377917506865, 0.00291060607248385, 0.044164246413856745, 0.03679354103016002, 0.023928079421498945, 0.029823978764138052, 0.04768753271283848, 0.06470995768904686, 0.048002481527094326, 0.039958048545356305, 0.0319071796589664, 0.022978113432015692, 0.033088044329945526, 0.06164864517216172, 0.007620890574928905, 0.02057341925267662, 0.3334518128207752, 18.084917204720632, 45.617609228406636, 40.66589559827532, 21.04380410058158, 27.03609905924116, 42.26746926988874, 38.10779121943882, 46.51569863728115, 33.50572483880179, 1.9831583159310477, 0.05696277054292815, 0.6847438312002591, 2.245405695268086, 7.546550529343741, 4.784549525805882, 1.7595977463892527, 12.955421754292079, 47.40326847348894, 48.44404261452811, 46.503560134342735, 40.33333049501692, 38.55249677385603, 36.482743058885845, 35.770000321524485, 34.38934809820992, 35.78645712988717, 33.82652316774641, 31.8011371748788, 32.65568222318377, 32.01135492324829, 31.64768968309675, 30.17942762374878, 29.219412394932338, 32.65013756070818, 31.16381365912301, 32.15437664304461, 31.34672498703003, 31.305734089442662, 32.69094780513218, 34.39241572788784, 33.14624241420201, 33.787672315325054, 32.426207542419434, 32.71843140465872, 32.09803717476981, 34.50324296951294, 31.743713787623815, 33.73779814583914, 32.99559852055141, 34.03360033035278, 33.25250816345215, 32.21596894945417, 32.61402082443237, 32.97204065322876, 31.912787778036936, 31.95694705418178, 30.97304391860962, 31.708701814923966, 32.85385526929583, 33.71729053769793, 37.2163199697222, 40.840448243277415, 41.230113642556326, 44.362285137176514, 46.75186790738787, 43.74102585656302, 45.239331926618306, 46.83573613848005, 44.47610010419573, 44.847203390938894, 45.72437524795532, 40.9240003313337, 46.177762576511924, 46.610065596444265, 40.53332049506051, 40.14221681867327, 39.18665885925293, 41.261324950626914, 43.340465681893484, 45.48749378749302, 44.95676953451974, 43.899663652692524, 37.74945524760655, 33.3701411655971, 32.58380658285958, 32.614013876233784, 32.68227992738996, 33.554344858442036, 34.76431458336966, 36.3063838822501, 42.04736770902361, 43.97899471010481, 42.451082365853445, 38.13490309034075, 35.778317315237864, 32.9190536907741, 33.790125029427664, 33.25191061837332, 34.87414823259626, 33.84346982410976, 33.8020133972168, 32.4085556438991, 33.558725697653635, 34.26325566428048, 35.34300225121634, 38.24298579352242, 40.518166473933626, 41.04346070970808, 42.5840813091823, 43.78424712589809, 43.555060795375276, 42.20127725601196, 42.670985903058735, 40.99350316183907, 40.96956661769322, 39.03824186325073, 37.606805256434846, 37.294435092381065, 38.26028333391462, 39.51970338821411, 41.13276938029698, 46.51292978014265, 49.10929788861956, 50.605331897735596, 49.56012480599539, 48.29597997665405, 49.52149977002825, 34.955852099827354, 9.58944685118539, 0.4424232340284756, 2.355208946125848, 4.651418566703796, 2.248252719640732, 0.3783430925437382, 0.022915030031331947, 1.1618903619902474, 31.757693563188823, 40.46782330104283, 37.04553672245571, 19.74377703666687, 27.058361087526592, 45.42524835041591, 41.378377778189524, 11.927519151142665, 0.3921850712171623, 0.1358553993382624, 0.046309557011617083, 0.0296193767072899, 0.036479857683713944, 0.07748870591499976, 0.015224037459120154, 0.027888691718024865, 0.032761601132473776, 0.0434996824312423, 0.10589310460324798, 0.04213397464315806, 0.05421367573684879, 0.030757391891841377, 0.04274074440555913, 0.052477077314896245, 0.04236398105110441, 0.0429980482773057, 0.030343974075679268, 0.003116152565261083, 0.07992770003953151, 0.025515568076765964, 0.03153697434546692, 0.03173042807195868, 0.014008319836908152, 0.047339630845401964, 0.06270110048353672, 0.04257165687158704, 0.06477603342916284, 0.029080514729555165, 0.04408432516668524, 0.4191575167434556, 23.44967692238944, 50.95905079160418, 46.24583060400826, 23.236785854612076, 26.213123151234218, 47.252176421029226, 43.3233140536717, 50.687007972172324, 34.05558443069458, 1.9850249929087502, 0.06831274115081344, 0.6328272170254162, 3.6549543908664157, 6.012218918119158, 7.1858647636004855, 4.108821579388209, 15.480562141963414, 49.7159103666033, 49.4582815851484, 48.81731721333095, 42.82222734178816, 40.5040407861982, 37.70603595461164, 37.77887739453997, 36.8446295601981, 38.13029990877424, 35.90986408506121, 34.34616504396711, 34.270078795296804, 33.97754921231951, 34.51650013242449, 32.210646629333496, 30.498078959328787, 34.58863633019583, 34.55682747704642, 34.026895318712505, 32.31898641586304, 33.763259819575715, 33.14484235218593, 34.657757009778706, 34.45251069750105, 35.17666932514736, 33.90702152252197, 35.430389744894846, 34.14321858542306, 36.38879646573748, 34.77683523723057, 35.16407571520124, 34.18897942134312, 35.72216197422573, 35.167737415858674, 33.350540297372, 34.048163754599436, 35.220484665461946, 34.05044971193586, 32.47173908778599, 32.444696698869976, 34.052919796534944, 34.14294065747942, 35.84542301722935, 37.67894492830549, 41.487092767442974, 43.52293579918997, 47.09012358529227, 48.400300230298726, 42.940537793295725, 46.83083071027483, 48.82806955065046, 46.30231251035418, 47.84838397162301, 45.531479358673096, 42.93162325450352, 47.41826616014753, 46.71550798416138, 43.13177653721401, 43.3160080228533, 40.620384897504536, 43.809889452798025, 44.3319354057312, 47.180769784109934, 47.78850787026541, 46.8184038570949, 38.919021197727744, 33.15134934016636, 34.87068108149937, 34.566676548549104, 34.23875284194946, 34.811412947518484, 35.77827215194702, 38.47239446640015, 44.49405424935477, 45.7252368245806, 43.71302809034075, 39.73938110896519, 36.592145919799805, 35.05255365371704, 35.630678517477854, 35.59108073370797, 36.268193108694895, 34.54383781978062, 35.683863503592356, 35.62816326958792, 36.53675488063267, 35.52139030184065, 37.73151847294399, 40.32065003258841, 43.33139133453369, 42.13761786052159, 44.500054018838064, 45.67882980619158, 45.43543093545096, 44.579788071768625, 45.26327541896275, 43.96412556512015, 40.88027879170009, 40.907335077013286, 40.299593516758506, 37.78963320595877, 39.407524721963064, 40.59330081939697, 44.62039681843349, 47.2000093460083, 50.41601085662842, 50.83174589702061, 49.65241772787911, 49.066351073128835, 49.19613994870867, 37.47807250704084, 10.843304003987994, 0.7212473324366978, 3.564863396542413, 5.280444196292332, 3.281473300286702, 0.582927480340004, 0.04791903529050095, 1.1999700729336058, 33.32284130368914, 46.49191147940499, 42.85646111624581, 23.96544517789568, 32.63069997514997, 49.97756215504238, 49.68145077569144, 15.593451261520386, 0.34902587426560266, 0.1828225619558777, 0.043726004394037385, 0.02138746789257441, 0.09836041594722442, 0.043273462248700004, 0.016608101315796375, 0.0815119096743209, 0.05039572203531861, 0.03536986938810774, 0.09000034204551152, 0.06474920415452548, 0.00772174632376326, 0.017867095901497772, 0.17662280106118747, 0.19771575422159263, 0.10935259503977639, 0.1441145682973521, 0.10723498224147729, 0.1091233655544264, 0.11579163452344281, 0.13892973294215544, 0.11863879460309233, 0.18596831815583365, 0.1832394945834364, 0.12871282760586056, 0.21426101640931197, 0.15696915638233933, 0.22378675240491117, 0.11333955824375153, 0.17466243196810993, 0.6059717780777386, 26.236073051180156, 57.701256138937815, 52.02733979906355, 29.065987484795706, 35.74281202043806, 52.26925870350429, 48.41778884615217, 53.952414648873464, 41.77604055404663, 2.6264574996062686, 0.31649663405758993, 3.0404960938862393, 7.907951525279453, 16.881678547177994, 9.723289132118225, 3.843572361128671, 15.68976719038827, 51.8011029788426, 52.52113785062517, 52.06885528564453, 44.33029910496303, 43.144422258649556, 39.56178862707955, 39.1740721975054, 38.46107585089547, 39.79055806568691, 37.95871761866978, 35.777170862470356, 36.89403472627912, 35.34647635051182, 36.05962208339146, 34.43153061185564, 32.17392539978027, 38.28272948946272, 35.65495204925537, 34.71928678240095, 33.62960079738072, 36.83823721749442, 35.855004583086284, 36.772062574114116, 36.97001675197056, 37.60225766045706, 36.424868038722444, 36.43221575873238, 35.236059052603586, 38.91758292061942, 36.03821120943342, 36.71271106175014, 36.47809818812779, 37.68269348144531, 36.964187213352744, 37.2153229032244, 35.63699442999703, 38.25520420074463, 36.297038555145264, 35.30709048679897, 34.09078400475638, 35.29903057643345, 36.84600182941982, 37.73616681780134, 40.51373699733189, 43.91104827608381, 44.76754576819283, 47.94251469203404, 48.02123083387102, 46.078601360321045, 49.23581416266305, 49.81960875647408, 47.31682940891811, 48.761613505227224, 48.53249665669033, 44.58699682780674, 47.697135584695, 48.73109354291643, 43.686645780290874, 44.885227407727925, 41.22392279761178, 45.83169712339129, 46.76813364028931, 48.36480188369751, 50.42637756892613, 49.23059606552124, 41.30739498138428, 35.470237663814, 36.4393515586853, 36.216029507773264, 35.945206097194124, 35.69541488374983, 38.022307532174246, 39.33239385059902, 46.338394505637034, 47.652990204947336, 45.25336728777204, 41.02086864198957, 38.688796111515586, 36.230975082942415, 36.56718799046108, 37.63404219491141, 38.971726758139475, 37.53142772402082, 37.90364967073713, 35.67028324944632, 38.290299551827566, 36.55150590624128, 38.707618781498496, 42.55169228145054, 45.148518971034456, 44.56618697302682, 46.520781244550435, 47.043695722307476, 47.314741475241526, 46.01377466746739, 48.02036925724575, 46.105886936187744, 44.13416535513741, 43.60539354596819, 42.677795137677876, 40.678016730717246, 43.394859654562815, 42.37343624659947, 45.61476741518293, 49.36897986275809, 52.564539773123606, 51.49287394114903, 49.787560190473286, 49.05171121869768, 50.47855159214565, 39.48300300325666, 12.234636477061681, 1.7630003009523665, 7.900824410574777, 14.303701451846532, 9.189462508474078, 2.122403255530766, 0.2818989205573286, 1.4645061237471444, 37.70072405678885, 51.1179005077907, 49.774285657065256, 29.364341395241873, 37.05305119923183, 57.496385029384065, 56.49782466888428, 19.124136686325073, 0.685312280697482, 0.33131703308650423, 0.15635483791785582, 0.1361283604055643, 0.1806762878383909, 0.2140182772917407, 0.16163492601897034, 0.18467185486640247, 0.09000442004097359, 0.15770152636936732, 0.16355318522879056, 0.16121145231383188, 0.22292409012360231, 0.0774359701733504], [0.0440690852701664, 0.06365759737257447, 0.04160194212038602, 0.038292943965643644, 0.021799185978514806, 0.044918611113514216, 0.030318691860884428, 0.02217160670885018, 0.03364198335579463, 0.019062033388763666, 0.055554270943892856, 0.021512910357809494, 0.04370990275804486, 0.018047433546079055, 0.011028293270750769, 0.01542562003513532, 0.09608881641179323, 0.09160275677485125, 12.0492376940591, 43.538784640175955, 45.56951379776001, 33.99890797478812, 30.026852130889893, 33.667166233062744, 35.688904421670095, 43.552034854888916, 38.31439243044172, 5.209889582225254, 0.10571268214178936, 0.1670713485883815, 1.7968942650726862, 3.219884467976434, 3.6977800471442084, 2.17502869452749, 10.64329663344792, 43.53562668391636, 46.84696442740304, 45.286485876355854, 42.963063853127615, 40.95941529955183, 36.20143829073225, 39.51689631598336, 34.39142213548933, 37.69357783453805, 35.180240699223106, 34.78978667940412, 34.23044627053397, 32.07795340674264, 29.980834211621964, 31.380107607160294, 31.41990688868931, 31.720743043082102, 30.52357189995902, 31.03471612930298, 31.640130043029785, 31.018155097961426, 33.248919418879915, 33.40020602090018, 32.44170202527727, 33.23141343252999, 32.711847986493794, 32.817964349474224, 34.437777042388916, 32.10124724251883, 32.09486879621233, 32.42418214253017, 32.56334066390991, 33.715306827000205, 32.79030704498291, 31.543341636657715, 32.36053316933768, 31.834599699292863, 31.057391575404576, 31.871029104505265, 31.31126138142177, 31.468916007450648, 34.51554822921753, 40.45300279344831, 42.86964879717146, 44.482627936771934, 42.45875665119716, 42.679129191807334, 44.0952137538365, 52.141439642224995, 49.39688730239868, 43.40418413707188, 45.475532463618684, 43.99157789775303, 44.438083035605295, 40.13348988124302, 45.09247132710048, 46.577231884002686, 42.00000878742763, 40.13894074303763, 42.00142969403948, 42.87649277278355, 43.399643489292686, 47.93875224249703, 44.56355707986014, 45.58325038637434, 40.19402258736746, 30.970511300223215, 33.26112392970494, 32.75785895756313, 32.9359586579459, 32.47570998328072, 34.98117480959211, 37.24851097379412, 41.40811259405953, 41.55315276554653, 41.61660024097988, 39.091649191720144, 33.629274232046946, 34.67107670647757, 35.407106331416536, 33.80244071143014, 33.72219596590315, 33.53294440678188, 33.91580751964024, 34.066017150878906, 34.60043784550258, 33.021807125636506, 32.72163799830845, 33.221564361027305, 34.67000320979527, 37.84302316393171, 39.137149470193044, 39.72208704267229, 41.36708000728062, 41.45587451117379, 41.4207444190979, 42.51282753263201, 41.30964272362845, 39.25575522014073, 38.98564747401646, 37.917004108428955, 36.30609553200858, 37.22874334880284, 40.41980430058071, 45.420061520167756, 47.852153369358604, 50.31797177450997, 47.221656458718435, 49.80165808541434, 44.13452318736485, 24.39427583558219, 5.3853919591222486, 0.45731040090322495, 1.4960477969476154, 1.9490055314132144, 1.8347951684679304, 0.3897112411047731, 0.05398367950692773, 2.418380447796413, 34.798301696777344, 41.32421657017299, 37.1974903515407, 33.12717655726841, 28.190771545682633, 45.14427362169538, 37.78062834058489, 6.0928566711289545, 0.22574967278965882, 0.013651831108810646, 0.09475195993270193, 0.05259061997224178, 0.07346173628632512, 0.01790051205482866, 0.015742607847122208, 0.0062700418555842975, 0.036334162644509754, 0.0470206243917346, 0.090314368052142, 0.03138700792832034, 0.12277814320155553, 0.04493783740326762, 0.012221603970309454, 0.03691808952550803, 0.023332659853622317, 0.05210987791152937, 0.006625957645675433, 0.03663293179124594, 0.07675779477826186, 0.026296595809981227, 0.05663931289953845, 0.013727023815070944, 0.03545143608269947, 0.05479463402714048, 0.020534656243398786, 0.006615074368060699, 0.023602872854098678, 0.011775390012189746, 0.010606969673452633, 0.06802786500858408, 15.521655525479998, 49.3798051561628, 50.22757223674229, 35.87537670135498, 30.880407060895646, 41.59062787464687, 41.35057456152779, 49.48162405831473, 40.54883234841483, 5.338636228016444, 0.16909920477441379, 0.4664096640689032, 3.062006196805409, 3.8199563026428223, 6.7526267766952515, 3.848486908844539, 10.961499810218811, 44.52218055725098, 48.908036368233816, 48.00558696474348, 44.15017747879028, 42.77788046428135, 37.58920199530465, 40.277821336473735, 35.84414802278791, 39.697299344199045, 37.45753363200596, 35.2757819039481, 34.627758162362234, 34.28224856512887, 33.2487804549081, 32.20950365066528, 32.88851983206612, 34.221879141671316, 32.180699893406455, 32.806517192295615, 33.225038460322786, 32.99224254063198, 34.46452760696411, 33.83204698562622, 32.96042673928397, 35.90010534014021, 33.20878314971924, 34.82370778492519, 36.21565777914864, 33.526621546064106, 32.86092506136213, 34.624106884002686, 34.85811526434762, 35.65128340039934, 34.10382924761091, 33.6763448034014, 33.280064719063894, 33.79986987795149, 32.66723707744053, 32.79142917905535, 32.88927023751395, 32.900074686322895, 35.35574524743216, 42.43029335566929, 44.56052419117519, 46.52185126713344, 44.69306455339704, 44.97646072932652, 49.004762240818565, 55.601979528154644, 48.95468657357352, 44.52291011810303, 47.67302186148507, 46.499196665627615, 46.355476651872905, 44.01104327610561, 46.24545192718506, 47.483044215611045, 44.794560364314485, 41.63215378352574, 42.47266347067696, 43.40879079273769, 46.02885225840977, 48.00630610329764, 44.75471939359392, 47.98626749856131, 41.54895952769688, 33.19973659515381, 34.14483751569475, 33.782329150608604, 35.227832385471885, 34.05509458269392, 36.89846420288086, 37.968281814030235, 42.58845867429461, 44.22459615979876, 42.97289555413382, 40.04054730279105, 34.9468229157584, 38.76121023723057, 35.89414031164986, 34.963126863752095, 35.62383106776646, 34.8030229977199, 35.277053424290244, 34.84877341134207, 35.66508947099958, 35.375558035714285, 34.74116318566458, 34.62721272877285, 36.47185870579311, 39.18890312739781, 40.255448137010845, 43.16499934877668, 44.11061791011265, 44.57486874716622, 44.19249548230852, 44.888684136526926, 43.35930572237287, 41.09549576895577, 40.74772105898176, 38.42098127092634, 39.24602426801409, 40.086527006966726, 43.61909886768886, 45.6860350881304, 50.545459270477295, 51.051711968013215, 46.09583289282662, 49.242064067295615, 46.22577115467617, 28.23461467879159, 7.816668697765895, 1.6225244445460183, 4.269062672342573, 3.745050379208156, 2.7679575639111653, 1.3708093400512422, 0.06097384888146605, 2.3349382281303406, 38.46287543433053, 44.72476918356759, 44.94956772668021, 31.41741943359375, 28.176044838769094, 50.96637071881975, 44.21702609743391, 8.475668856075831, 0.30490589886903763, 0.02019770084215062, 0.06267481403691427, 0.051479250857872624, 0.050962397163467746, 0.04516604908608964, 0.03163385896810463, 0.018016836705750654, 0.08524870380227055, 0.023160802200436592, 0.07146490272134542, 0.0107781903518896, 0.04377700987138918, 0.04491842451638409, 0.12630816735327244, 0.11694909312895366, 0.10093066588576351, 0.1897741396512304, 0.07631924402500902, 0.1643219246928181, 0.15756732571337903, 0.10440090431698731, 0.1401994755225522, 0.07000949938914605, 0.12263209532414164, 0.11178756545164756, 0.1608118223292487, 0.07815850140260798, 0.11439567085887704, 0.11723999466214861, 0.1679635135723012, 0.18958655185997486, 18.742329699652537, 54.89049441473824, 57.23850263868059, 43.951097692762104, 39.66314894812447, 44.7644989831107, 46.46273946762085, 52.943115847451345, 45.80351870400565, 6.646465250423976, 0.2818444477660315, 0.32062646959509167, 5.172581664153507, 10.324515887669154, 11.785081948552813, 6.175377820219312, 12.767252377101354, 47.13124302455357, 51.254714012145996, 50.338531494140625, 46.20742791039603, 45.71909809112549, 40.63300977434431, 44.51654209409441, 37.736152921404155, 41.8899701663426, 38.995625087193076, 37.43040439060756, 37.816286495753694, 37.098554951804026, 33.06246450969151, 35.148977279663086, 35.06888886860439, 35.75028828212193, 33.624153409685405, 35.47960730961391, 34.68051583426339, 34.68938520976475, 35.39605869565691, 36.68709652764456, 35.33882985796247, 37.70102630342756, 35.66310576030186, 35.97977685928345, 38.41136148997715, 34.60335956301008, 34.68607439313616, 36.29087550299508, 37.81218358448574, 37.48866850989205, 35.37119804109846, 35.818269457135884, 34.28326995032174, 35.69970539637974, 34.312063285282676, 34.861398288181846, 33.66155208860125, 34.29731920787266, 38.17737742832729, 46.31275217873709, 46.72682312556675, 49.3828832081386, 44.869267395564485, 49.107658113752095, 50.308272089277, 52.70362533841814, 49.86806549344744, 46.595126969473704, 47.77195726122175, 47.88773856844221, 47.11630092348371, 45.937848227364675, 47.5643242427281, 49.381847926548545, 47.84268644877842, 42.79460825238909, 47.018508502415244, 45.82016658782959, 47.15276159558977, 50.57722296033587, 47.25328813280378, 49.66461181640625, 45.3929739679609, 34.936570848737446, 36.76027495520455, 35.48577036176409, 37.08947365624564, 35.42740896769932, 38.88258137021746, 40.64719452176775, 45.73340095792498, 44.30783557891846, 45.30726099014282, 42.430630343300955, 36.96147394180298, 40.19878557750157, 37.53148678370884, 36.51980127607073, 37.247013636997764, 36.82535525730678, 37.70923212596348, 37.87220559801374, 36.76171670641218, 36.88784040723528, 35.25966208321707, 36.926395961216514, 38.03271245956421, 40.75471789496285, 42.07543495723179, 45.21336998258318, 47.30367299488613, 47.34584161213466, 45.01207719530378, 47.13564470836094, 46.61673934119088, 43.63954741614205, 42.31884772436959, 41.26858581815447, 41.76587186540876, 41.87893990107945, 44.51311663218907, 49.721288272312705, 52.58678443091256, 52.81179141998291, 47.523983001708984, 50.11736338479178, 46.94581992285592, 29.613726139068604, 8.10690711225782, 2.01962919320379, 6.473264030047825, 8.258095570972987, 6.941874427454812, 2.6111523551600317, 0.24802547533597263, 3.1628050165516988, 44.06036158970424, 52.620156628744944, 49.7101537840707, 44.71158845084054, 37.53869901384626, 59.19206510271345, 51.01322937011719, 11.598182354654584, 0.5065090752073697, 0.06165480627013104, 0.24818259690489086, 0.11474850906857423, 0.17692825038518223, 0.15057453380099364, 0.07288637251726218, 0.11909012895609651, 0.17622209899127483, 0.11385999460305486, 0.2942052116351468, 0.08761543394731623, 0.1820116854671921, 0.10304780370954957], [0.027555614144408276, 0.020986485926966583, 0.038922488755945645, 0.01302681553975812, 0.00541986504270296, 0.055014048503445726, 0.025677130657381246, 0.01649974605866841, 0.04654824188245194, 0.0460572234088821, 0.03923890320584178, 0.047469054614858966, 0.027809291246480176, 0.07523632249129669, 0.06871075622205224, 0.032170305361172984, 0.0405287575641913, 0.06093879576240267, 4.8205850550106595, 36.34974758965628, 45.070219721112935, 34.773434094020296, 19.001798016684397, 27.551910740988596, 41.811705657414024, 41.55313539505005, 47.91763319287981, 11.858604311943054, 0.06574423504727227, 1.0855476813656944, 3.9550457852227345, 2.532589290823255, 7.600686550140381, 4.279596141406468, 7.679571185793195, 40.475504534585134, 48.83597312654768, 46.93217018672398, 45.13375057492937, 38.88171979359218, 36.40053544725691, 37.108390126909526, 36.97028078351702, 37.22131225040981, 35.90023388181414, 36.4743982723781, 32.73801490238735, 33.92665713174002, 32.08610016959054, 32.95583050591605, 32.84777212142944, 30.89070429120745, 31.144442081451416, 33.47730670656477, 31.042446000235422, 33.15207890101841, 32.53548533575875, 33.48575919015067, 31.921882969992502, 32.60172251292637, 32.099065508161274, 33.416624614170615, 33.27570819854736, 32.4697380065918, 32.622751235961914, 31.587181295667374, 32.60411616734096, 34.12939861842564, 33.43882063456944, 32.551202160971506, 34.22775731767927, 33.160090173993794, 32.8102205821446, 31.46848521913801, 31.441456726619176, 33.189279556274414, 39.51392943518502, 46.17141192299979, 43.786230836595806, 45.150405406951904, 46.55630390984671, 43.70627096721104, 40.80140631539481, 37.898455892290386, 50.19930349077497, 49.99629102434431, 45.389326163700645, 46.205923625401084, 43.76004655020577, 41.482454844883506, 45.30859157017299, 46.27783400671822, 42.72519227436611, 39.17492682593209, 40.463706493377686, 43.30369928904942, 42.807921000889365, 46.06698397227696, 46.4127402305603, 46.78938470567976, 42.05607380185808, 33.34203917639596, 32.63707842145647, 32.69858734948294, 32.90747799192156, 34.18731880187988, 33.25539861406599, 34.87985617773873, 38.160264015197754, 40.84461716243199, 40.04981967381069, 37.34820720127651, 34.70969132014683, 35.21322727203369, 33.14492225646973, 32.57836961746216, 31.991646357945033, 34.05081101826259, 34.60730961390904, 32.68892240524292, 34.0235914502825, 32.63424703053066, 33.026736872536794, 33.52905688967024, 31.813133239746094, 33.102989877973286, 35.08864607129778, 35.791883672986714, 36.35048409870693, 37.27241972514561, 38.710200037275044, 38.29624720982143, 39.848478249141145, 36.904873916081016, 36.90490518297468, 35.364041396549766, 35.0023946080889, 38.21473094395229, 40.6517699105399, 45.548148087092805, 46.43626683098929, 49.16263573510306, 51.86918142863682, 47.71452692576817, 40.92085974557059, 15.548103843416486, 2.603150635957718, 0.3964127243629524, 3.7542845351355414, 1.7428614901644843, 1.6648616641759872, 0.20662544827376092, 0.08607769039060388, 2.61812378679003, 37.852938243321006, 39.57550089699881, 26.353801591055735, 22.650383949279785, 37.882249219076975, 41.47786208561489, 32.7623405456543, 3.5529952219554355, 0.1058068967291287, 0.039138768400464735, 0.09586775648806777, 0.027318364375137856, 0.021850574828152145, 0.015511390254167574, 0.0318599909410945, 0.05241877080074378, 0.02421585630093302, 0.01672307907470635, 0.014239133701526692, 0.041291715909859965, 0.042032628652772734, 0.033032462133892944, 0.04407133800642831, 0.05250503295766456, 0.03868750190096242, 0.006538718398327806, 0.027048232798863734, 0.0517056779935956, 0.010909558972343802, 0.028120782924816012, 0.04020735588190811, 0.07209413538553885, 0.013293432304635644, 0.061462271958589554, 0.05147337813728622, 0.017365721287205815, 0.02711842724654291, 0.06747345440089703, 0.02929324224325163, 0.08956382689731461, 8.10007095336914, 42.93234934125628, 51.68440450940813, 38.26619625091553, 24.994264943259104, 33.54358557292393, 45.02403504507882, 46.61628770828247, 51.51262419564383, 11.579991102218628, 0.0732485812955669, 0.6031750195792743, 3.1925129081521715, 4.91392628635679, 4.053795754909515, 3.05249975834574, 8.96083116531372, 42.168325424194336, 49.79299715587071, 47.94072205679757, 47.09773186274937, 41.678373200552805, 37.92398009981428, 39.43263898577009, 37.73013578142439, 38.23674978528704, 38.19583879198347, 37.663968086242676, 35.67848212378365, 35.89821890422276, 33.91300739560808, 35.59807409558977, 33.5339275768825, 32.99442080089024, 33.04653923852103, 33.62125253677368, 32.149787357875276, 34.056223664964946, 34.0268987928118, 34.414827142442974, 33.529449462890625, 33.52606916427612, 34.18823248999459, 34.293059962136404, 34.12385743004935, 34.649891648973735, 34.58747598103115, 33.93317801611764, 34.42521469933646, 35.767617089407786, 36.134395122528076, 34.13913304465157, 34.74238954271589, 34.95106479099819, 34.839164052690776, 32.3548321723938, 33.11179671968733, 34.69517305919102, 40.00687633241926, 47.2224520274571, 46.10562637874058, 47.22293840135847, 48.70562144688198, 44.918248721531455, 42.42553036553519, 43.65267603737967, 55.88361780984061, 49.894155979156494, 45.04460171290806, 47.29736055646624, 46.465692452022004, 43.49748454775129, 46.220021520342144, 47.810710838862825, 42.48766810553414, 40.76807233265468, 41.60883910315377, 44.677611759730745, 44.74466535023281, 48.28020061765398, 47.797290393284385, 45.971651213509695, 43.52769531522478, 34.162864616939, 33.98281594685146, 33.620971134730745, 34.2142847606114, 35.78914955684117, 34.823700836726594, 37.25958987644741, 40.23823397500174, 43.26544598170689, 41.433893884931294, 38.943385056086946, 36.17763376235962, 36.278980187007356, 35.275955608912874, 35.07206072126116, 33.86235850197928, 35.293503284454346, 35.47892986025129, 33.58158874511719, 34.15309544972011, 34.51130287987845, 34.13771908623831, 34.50719996861049, 33.91501195090157, 36.2728761945452, 36.68743004117693, 37.290818555014475, 38.61628123692104, 38.930933884211946, 40.646836689540315, 42.137857573372976, 43.244295665196006, 38.34809814180647, 38.882612637111116, 38.328208923339844, 36.34184748785836, 39.758148193359375, 41.69530248641968, 47.688954080854145, 47.78639561789376, 52.601695265088765, 50.17512723377773, 48.96478578022548, 41.031999656132285, 20.075904403414043, 3.1507501091275896, 2.5361999656472887, 4.304164103099278, 2.9293368586472104, 3.6732390097209384, 1.0850544678313392, 0.04810805479064584, 2.671098155634744, 41.49462114061628, 45.283647537231445, 33.97544043404715, 29.69480119432722, 42.456046853746685, 48.92596966879708, 38.74094581604004, 5.194090681416648, 0.15874614460127695, 0.08538603929004498, 0.04747129038774541, 0.041824284475296736, 0.006934031203854829, 0.05782482214272022, 0.023148705617391636, 0.04732735614691462, 0.03795302167002644, 0.08298153510051114, 0.0012652857715563315, 0.012743378739937075, 0.023551721491717865, 0.0602570241317153, 0.10876950954220124, 0.1328904048672744, 0.2003349129642759, 0.1547535224152463, 0.13173684105277061, 0.19092574928488049, 0.09867981595120259, 0.14123714555587086, 0.10102532152086496, 0.16277133646820272, 0.09775116613933019, 0.12824865537030355, 0.14047432291720593, 0.18389261168028626, 0.19193333307547228, 0.11580019763537816, 0.11356541541005884, 0.3449854153607573, 9.219155635152545, 49.15373509270804, 57.13100011008126, 45.25726522718157, 29.214955125536235, 36.35768938064575, 50.592262336185996, 50.95774800436837, 55.86218956538609, 14.992379971912928, 0.1727528308651277, 2.1813689257417406, 11.75255743094853, 9.346424051693507, 14.087272013936724, 7.0898697546550205, 10.279615759849548, 42.61109243120466, 51.982857431684224, 51.79595783778599, 50.144860880715505, 43.75506469181606, 39.78113630839756, 41.381393296378, 40.13646371023995, 41.12449754987444, 40.99974264417376, 40.37551300866263, 37.28667395455496, 37.934280804225374, 35.93710102353777, 37.30002491814749, 36.28754384177071, 34.529694761548726, 35.03740658078875, 37.01969984599522, 34.23430252075195, 37.54433747700283, 35.887299810137065, 36.73862436839512, 35.664439814431326, 35.65954828262329, 34.82137319019863, 36.05198948723929, 36.60368340356009, 36.28788777760097, 35.45012610299246, 35.190496240343364, 35.24840600149972, 38.15087005070278, 38.135636125292095, 35.972106048039024, 37.07363871165684, 36.608300481523784, 37.21851212637765, 33.7281505720956, 35.36230434690203, 37.90179797581264, 43.202304227011545, 49.22489159447806, 47.84167201178414, 49.65154225485665, 50.10768454415457, 46.196706839970176, 47.3781681060791, 44.42879329408918, 51.486627510615754, 48.21147945949009, 47.54304191044399, 49.26359306062971, 47.8493150302342, 47.12574699946812, 48.53253139768328, 49.35493755340576, 44.32428543908255, 40.9031731060573, 43.468451499938965, 46.42090088980538, 44.9152193069458, 51.05353239604405, 50.49562679018293, 49.516160079411094, 44.430578981127056, 36.41877099445888, 35.35536309650966, 35.31138447352818, 36.19498688834054, 37.99099547522408, 36.202754974365234, 38.686927046094624, 41.56709780011858, 44.79719720567976, 43.85703992843628, 40.51570681163243, 38.244087082999094, 38.516161169324604, 36.225402627672466, 36.43337263379778, 35.38144315992083, 37.18246487208775, 38.35623795645577, 35.60986171449934, 36.102853775024414, 35.60372298104422, 35.76385811397007, 37.28852564947945, 34.96346385138375, 36.5888420513698, 38.36016021456037, 39.433542251586914, 40.80045788628714, 40.88337421417236, 42.46851192201887, 43.423851013183594, 44.37148107801165, 40.44872270311628, 41.00069454738072, 39.77495241165161, 37.99261440549578, 41.9832740511213, 43.36816120147705, 48.79911988122122, 51.188984053475515, 52.495690073285786, 52.894940512520925, 48.66531842095511, 42.94525214603969, 19.956655945096696, 4.005673834255763, 2.708188291106905, 9.99186827455248, 9.968247873442513, 7.58512692792075, 1.7808097281626292, 0.10962915234267712, 3.262580279793058, 46.97251837594168, 48.84853546960013, 36.864209583827424, 32.78061430794852, 51.7958779335022, 55.212428774152485, 44.49881029129028, 6.713484968457903, 0.26572362280317713, 0.09202852392835276, 0.18111703704510415, 0.14133277828139917, 0.0636578823572823, 0.18320414290896483, 0.12672885906483444, 0.12432269246450492, 0.13308632506855897, 0.16650991514325142, 0.08709281270525285, 0.10657237243971654, 0.17807004840246268, 0.15408071423215525], [0.03580848460218736, 0.07286483581577029, 0.0714730451415692, 0.020495959391285266, 0.03876562163765941, 0.020532237266057303, 0.032445475059960566, 0.03714109345206192, 0.026380265963130763, 0.054116305961672745, 0.016261247784963677, 0.024243891671566025, 0.04111728151994092, 0.009152858950463789, 0.035514268425426314, 0.035121050596769364, 0.021882694979597415, 0.022896869041557823, 1.0200958677700587, 27.704838854925974, 51.51432303019932, 34.02373388835362, 23.638886792319163, 30.996671267918178, 39.253198283059255, 41.0197743007115, 45.92017895834786, 16.890841484069824, 0.029179998141314303, 0.12881730842803205, 1.139642990061215, 1.8457529119082858, 2.5171312860080173, 1.8633959080491747, 5.891926492963519, 35.6422507422311, 47.43036297389439, 46.538547788347515, 43.14827503476824, 44.049487658909385, 37.830651896340505, 38.068631172180176, 37.29936136518206, 39.807351861681255, 37.45433051245553, 35.98583916255406, 35.11532020568848, 34.92655849456787, 35.68807758603777, 33.62668602807181, 34.66389226913452, 33.52823005403791, 32.843683106558665, 33.292369978768484, 34.47401884623936, 32.64841440745762, 32.76757253919329, 34.31459590366909, 32.24128818511963, 32.229622159685405, 33.97297729764666, 33.400452681950156, 32.55785158702305, 32.736750330243794, 32.88271461214338, 31.72803865160261, 33.39556809834072, 32.376524448394775, 33.36891828264509, 33.691467557634624, 33.40725496837071, 34.10950592585972, 32.407798290252686, 32.25747748783657, 30.592703001839773, 32.644009249550955, 41.46023103169033, 45.64528390339443, 44.17048358917236, 45.96033954620361, 43.919076919555664, 45.685420172555105, 44.68787424904959, 40.10757310049874, 32.03384971618652, 43.08992058890206, 51.20120940889631, 44.09641579219273, 44.26529523304531, 40.10636758804321, 46.682021141052246, 46.99381113052368, 42.400103432791575, 41.26697383608137, 41.70131615230015, 43.080596106392996, 47.8524625641959, 49.43380308151245, 45.251988070351736, 44.703604970659526, 43.83925254004342, 33.382547174181255, 31.843375274113246, 33.194664410182405, 32.36751610892159, 34.23687335423061, 34.05240910393851, 34.097992760794504, 36.249627522059846, 38.20998532431466, 37.39126518794468, 35.94044310706002, 32.61410072871617, 32.58098561423165, 33.219507694244385, 33.50908081872122, 35.1535005569458, 33.791000502450125, 33.82881607328142, 33.23296635491507, 34.462446621486116, 34.1571809904916, 34.275557449885774, 32.681793553488596, 33.415391308920725, 32.982490743909565, 32.830693449292866, 33.51846783501761, 31.89635876246861, 32.69458518709455, 33.7668068749564, 35.52697317940848, 34.80564594268799, 34.13522120884487, 33.90980775015694, 34.44512823649815, 36.90976892198835, 38.233386857169016, 41.88848672594343, 44.223592145102366, 45.72727959496634, 47.29588406426566, 46.047987597329275, 50.49912173407418, 34.053875173841206, 11.970412118094307, 1.4892090324844633, 2.273554584809712, 3.0618774380002702, 1.8387738806860787, 1.2541901235069548, 0.5943376709307943, 0.12683073431253433, 2.9960393479892184, 38.53434460503714, 42.73414850234985, 38.70911611829485, 22.901952164513723, 29.75028603417533, 43.65038660594395, 29.141604730061122, 1.8088145511490958, 0.03749727683940104, 0.03903144790924021, 0.017650373512879014, 0.037836422212421894, 0.01964819773898593, 0.05379516890804682, 0.0331154198252729, 0.05405725984434996, 0.03421041928231716, 0.03896847307415945, 0.04404014235894595, 0.10685217992535659, 0.06914009925510202, 0.030617606892649616, 0.03720502502151898, 0.2056316523147481, 0.032139761107308526, 0.008502729104033538, 0.03680992086551019, 0.0811955291511757, 0.01716324474130358, 0.047829288856259415, 0.034041233360767365, 0.043074492032506635, 0.05342887195625475, 0.05187813784661038, 0.049701919978750606, 0.04612200653978756, 0.01744882995262742, 0.029979444707610776, 0.020938810360218798, 0.03963461804336735, 2.1315236347062245, 34.25698144095284, 54.6954619543893, 39.08267559323992, 25.88935967854091, 30.914567879268102, 44.99539457048689, 45.856099196842735, 49.0632243837629, 18.29559006009783, 0.13458816733743462, 0.07057930595640625, 1.919384058032717, 4.766587998185839, 6.155773043632507, 3.769626157624381, 6.8309125644820075, 37.15641607557024, 49.863337244306294, 48.184840066092356, 45.73050355911255, 45.330176149095806, 39.936529295785085, 39.78269965308053, 40.97694213049752, 40.893185070582796, 39.5148674419948, 38.85690082822527, 37.164375237056184, 36.35894700459072, 36.549511773245676, 36.23496682303292, 36.773914269038606, 34.271398953029085, 34.287126200539724, 35.25120612553188, 36.38160855429513, 34.03299583707537, 34.32428864070347, 34.92286900111607, 34.79824611118862, 34.25968429020473, 34.61876719338553, 34.62285968235561, 34.60976580211094, 34.17557634626116, 34.457353591918945, 33.73347636631557, 35.51774944577898, 34.94345998764038, 35.46246610369001, 34.10657378605434, 35.11513955252511, 35.22905874252319, 34.278229032244, 32.570049149649485, 32.988355023520334, 34.57188074929373, 44.5022531236921, 45.66611807686942, 45.22762768609183, 47.02363279887608, 47.55834184374128, 47.39031703131539, 45.224066734313965, 39.12962109701974, 36.21989618028913, 49.95711708068848, 51.911245822906494, 44.29968534197126, 46.11612858091082, 42.51878908702305, 48.13099847521101, 48.99234233583723, 43.755412101745605, 42.05150188718523, 43.2422320502145, 45.161904675619944, 49.16502938951765, 48.21385226930891, 45.506969588143484, 47.90436908176967, 45.611536502838135, 35.20212752478463, 32.83354221071516, 34.8459107535226, 34.08919634137835, 34.00935459136963, 36.20073652267456, 36.73138434546334, 38.130466665540425, 39.62310300554548, 39.17298827852522, 37.706157548086985, 34.199429512023926, 34.87969289507185, 34.16283335004534, 34.540978636060444, 36.23414693559919, 34.63233355113438, 35.632120268685476, 35.21477672031948, 37.44747264044625, 35.5835280418396, 35.819120611463276, 33.92151893888201, 34.27682202202933, 33.86093759536743, 34.083748953683035, 33.901028701237266, 34.86661638532366, 34.71471834182739, 35.52732753753662, 37.635497842516216, 37.59737655094692, 36.27349805831909, 36.296482699257986, 36.54867451531546, 38.38059834071568, 39.42414133889334, 42.42541572025844, 46.81904656546456, 46.69088704245431, 47.987677982875276, 47.6451734815325, 51.19147150857108, 36.80673061098371, 14.35145902633667, 2.4174548174653734, 3.963614216872624, 3.7574381487710133, 4.62084345306669, 4.05026650428772, 0.9998948488916669, 0.07456426069672618, 2.8954689502716064, 41.79760776247297, 46.139537061963765, 37.733957290649414, 25.633353301456996, 37.33523838860648, 50.06417492457798, 35.640419891902376, 2.5872257990496497, 0.08123862969556025, 0.1299029780285699, 0.03746605744319303, 0.0592592383867928, 0.08021402146135058, 0.05021400357197438, 0.018198550080082247, 0.029184415404285704, 0.024837809980713894, 0.07053790853491851, 0.029164317197033336, 0.07725668765072312, 0.038019718269684484, 0.0094092527371166, 0.12887715521667684, 0.21105359494686127, 0.13540968325521263, 0.12298192083835602, 0.114547106304339, 0.1558525591556515, 0.11976137650864464, 0.146931506427271, 0.1142610495111772, 0.14978798957807676, 0.11489382412816797, 0.12957023802612508, 0.08647030432309423, 0.15329699271491595, 0.09650759465460267, 0.15672932139464787, 0.05412879439869097, 0.18982527405023575, 2.8414879611560275, 39.18056181498936, 63.235604013715474, 46.07274055480957, 32.19575316565377, 40.237285545894075, 49.38946315220424, 51.14565508706229, 53.71490785053798, 23.351806334086827, 0.23426131105848721, 0.3513977069939886, 4.742920696735382, 5.914704859256744, 8.573404823030744, 5.366730400494166, 7.942002040999276, 39.418287481580464, 52.02550547463553, 51.12143019267491, 48.28225033623831, 47.50031048910958, 42.36512620108468, 41.63815007890974, 43.660475390298025, 43.268058504377095, 42.57690034593855, 41.352325507572715, 39.51407534735543, 37.7463424546378, 39.98181765420096, 38.52964414869036, 38.47661549704415, 35.78602286747524, 37.44092743737357, 37.06500904900687, 37.95659146990095, 36.824875831604004, 35.94323628289359, 37.19769879749843, 35.945695945194785, 35.337999548230854, 36.77703053610665, 36.994005407605854, 37.381673199789866, 35.19251469203404, 36.45492247172764, 34.588966369628906, 37.49962929316929, 36.68689502988543, 36.67404433659145, 37.727036884852815, 37.49621772766113, 38.08787768227713, 35.72896426064627, 34.54180547169277, 33.820037024361746, 35.95005941390991, 45.653993470328196, 47.99054411479405, 45.51872246606009, 48.399699211120605, 47.778759547642295, 47.639277935028076, 45.79703950881958, 41.639897550855366, 40.1500370161874, 46.59940358570644, 47.63885062081473, 46.58693504333496, 47.631270136152, 45.73069116047451, 48.66371686117989, 52.10759496688843, 46.17116526194981, 44.424131052834646, 44.922424588884624, 46.58764028549194, 50.22789532797677, 48.116664341517854, 48.362929344177246, 50.12559005192348, 49.88551936830793, 36.60364171436855, 35.315626348767964, 37.01168509892055, 34.66717529296875, 37.15571778161185, 37.003489698682515, 37.4960891859872, 39.80885962077549, 41.95584256308419, 40.71107278551374, 40.59052848815918, 35.91182347706386, 35.58344118935721, 35.58830145427159, 36.7557030405317, 38.39204549789429, 35.86281088420323, 36.78442689350673, 36.8765287399292, 37.73368631090437, 37.22211824144636, 37.94473784310477, 35.45837361471993, 35.734258787972585, 35.324467931474956, 36.594581263405935, 36.97382436479841, 36.36501973015921, 35.2441919190543, 37.211112294878276, 39.39473308835711, 38.86429371152605, 37.78465134756905, 37.87693037305559, 38.452925613948274, 40.78533860615322, 41.68110384259905, 45.10300132206508, 49.28736284800938, 49.39276007243565, 48.940210001809255, 48.51836749485561, 52.40338325500488, 39.408674648829866, 15.672777107783727, 2.9328941191945757, 6.80794312272753, 8.654241033962794, 6.426916071346827, 6.653271879468646, 2.449840371097837, 0.3655336813202926, 3.8838271839278082, 47.73528119495937, 52.383191789899556, 48.87164517811367, 34.4840589932033, 41.471264771052766, 58.49853066035679, 40.760835783822195, 3.345051488706044, 0.14909896440804005, 0.21517246535846166, 0.13693996971207006, 0.1350820865482092, 0.20257205649146012, 0.12852350276495728, 0.13301594741642475, 0.10264130016522748, 0.12214507002915655, 0.11735690624586173, 0.25105391283120426, 0.14499299973249435, 0.2429350513432707, 0.11358567646571568], [0.022413360254306878, 0.0484497548480119, 0.08785051240452699, 0.04077407172215836, 0.07219482998230628, 0.005625494656019977, 0.0428390064542847, 0.012359422066115906, 0.02477563581695514, 0.055953022225626876, 0.019409565454615012, 0.024120052245312502, 0.059476702074919424, 0.010669481408383166, 0.023383962190044776, 0.03748091396742633, 0.04176078038290143, 0.05746346153318882, 0.5219659943665776, 18.78691281591143, 45.74620301382882, 39.15475273132324, 27.917045525142125, 34.13724660873413, 33.182675293513704, 38.05115645272391, 47.458426748003276, 26.234238726752146, 0.7579290983932359, 0.162059023976326, 0.9430773662669318, 5.670093093599592, 3.8172430310930525, 1.9997710244996207, 4.3000351360866, 29.13493272236415, 47.21832479749407, 47.97255870274135, 45.164770807538716, 43.02324220112392, 40.95144918986729, 38.809844153267996, 38.36893578938076, 38.85374287196568, 37.64202567509243, 38.37554700034005, 35.781044483184814, 37.812044620513916, 36.878429072243826, 37.03081348964146, 35.61359984534127, 36.82603965486799, 35.91935532433646, 33.15982961654663, 35.26789917264666, 33.99738284519741, 33.25132696969168, 34.41100910731724, 33.54400593893868, 33.79126453399658, 32.442782470158164, 33.29290846415928, 33.764753682272776, 32.73011132649013, 32.357625348227366, 31.850007329668315, 33.21124628611973, 33.20967946733747, 32.502321583884104, 31.533617632729666, 32.98956748417446, 33.94539989743914, 34.20317111696516, 31.952997003282817, 30.59267520904541, 32.387182985033306, 42.7365734236581, 45.64876842498779, 46.15660183770316, 44.609748704092844, 46.08144664764404, 45.36892277853829, 46.87314871379307, 45.389902864183696, 44.59755114146641, 32.02132906232561, 40.179410525730674, 51.684355872017996, 39.73202991485596, 40.38297537394932, 46.17457682745797, 47.53830671310425, 42.01128223964146, 42.67761448451451, 41.73336124420166, 44.04691335133144, 44.670118127550396, 49.57253428867885, 54.25333070755005, 43.18226214817592, 45.75687892096383, 35.6735280581883, 31.11159447261265, 33.41910512106759, 32.70536879130772, 34.354568890162874, 33.85749128886631, 32.771720613752095, 35.23518705368042, 34.94332102366856, 35.7059622492109, 36.044725145612446, 31.98508378437587, 33.142723151615684, 33.69708170209612, 32.222642694200786, 33.834246090480256, 33.62041180474417, 34.19602142061506, 33.90671927588326, 32.99215221405029, 34.11593648365566, 32.70187732151577, 32.60896600995745, 33.21020405633109, 33.767376627240864, 33.24667515073504, 32.54448325293404, 32.07578556878226, 30.464084897722515, 31.771774087633403, 31.339342526027135, 32.74207959856306, 34.968536036355154, 36.36977229799543, 38.032312938145225, 39.113337993621826, 41.16448790686471, 44.97262532370431, 45.249868869781494, 47.417477539607454, 48.36091089248657, 48.435815947396414, 44.656510080610005, 29.64668491908482, 8.317415816443306, 1.2402229415518897, 2.6127573890345435, 1.8212784251996448, 1.7160141936370303, 2.75161474943161, 0.7014826387166977, 0.04339604299249394, 3.5233196829046523, 35.30133390426636, 38.17374004636492, 33.07924093518938, 32.054214886256624, 37.8231964792524, 46.72228595188686, 20.127922092165264, 0.2109784675495965, 0.0646151527762413, 0.04219188082164951, 0.036431461173508844, 0.057298245041498115, 0.003976958205125162, 0.062008777633309364, 0.038229863957634995, 0.047038951622588296, 0.03975172979491098, 0.06643180815236908, 0.040826027148536274, 0.0195236339766, 0.09120364926223244, 0.014146936059530293, 0.05619177834263869, 0.05277887612049069, 0.07955019029655627, 0.048735669148819785, 0.07000764698854514, 0.02503379464282521, 0.02651752172304051, 0.0460103366390935, 0.039000371005386114, 0.0438714823020356, 0.018756902976227657, 0.06944332298423563, 0.05082573342536177, 0.036303801595100334, 0.03487954641293202, 0.027224214248625294, 0.045721596239932945, 0.02143897209316492, 0.7426770968096597, 24.167642968041555, 52.21409348079136, 45.19608286448887, 29.286782128470286, 36.2853238923209, 39.67787218093872, 44.33547551291329, 54.72310536248343, 26.95476692063468, 0.44579560735395973, 0.07545983871178967, 1.3189578652381897, 5.661864255155836, 3.435600195612226, 1.750978397471564, 6.65757064308439, 32.22796848842076, 49.27553701400757, 50.685885838099885, 47.40512711661202, 43.92067847933088, 41.99966485159737, 39.617336000714985, 39.49421044758388, 39.9489665712629, 39.04373788833618, 38.921098709106445, 37.78347710200718, 38.572927951812744, 38.556241852896555, 38.22857870374407, 37.854275771549766, 38.15696709496634, 36.886530671800884, 35.782340322222026, 37.74007517950875, 34.949695995875764, 34.90829168047224, 36.79361936024257, 34.5735239982605, 34.8103220803397, 34.78889036178589, 35.33627986907959, 35.220707007816856, 34.58037839617048, 34.92942115238735, 34.24278279713222, 34.555111271994456, 34.261195523398264, 34.23223543167114, 33.34254986899239, 34.441299779074534, 36.07477263041905, 35.56063372748238, 33.004186494009836, 33.22799491882324, 33.705377851213726, 44.45914997373308, 48.20236342293875, 46.03392096928188, 46.310448850904194, 48.18677861349923, 47.5876076562064, 48.37243447984968, 47.63043635232108, 44.06643084117344, 33.9906222479684, 46.619490827832905, 50.11986126218523, 40.143953868321006, 42.95180082321167, 47.204060145786826, 49.677142892565044, 44.504118715013774, 42.94450868879046, 42.69211190087454, 45.34566715785435, 47.46960987363543, 51.19937855856759, 51.214254651750835, 45.09461832046509, 46.98876673834664, 36.48698493412563, 33.503261702401296, 34.47294882365635, 33.62547704151699, 34.36114536012922, 35.73368903568813, 35.878128187997, 36.551978383745464, 35.735526834215435, 39.14833606992449, 38.33116538184029, 33.52349138259888, 35.70423214776175, 36.22538178307669, 34.0428136416844, 35.6877440725054, 34.95365299497332, 35.61504854474749, 36.14679765701294, 34.46739026478359, 35.650588580540244, 34.477659702301025, 34.557039397103445, 33.84130893434797, 33.906097412109375, 34.966083322252544, 35.21793467657906, 34.35357877186367, 33.34357820238386, 34.13464798246111, 33.09197350910732, 34.12368719918387, 35.44805901391165, 37.88471235547747, 39.376309939793174, 41.4780010495867, 43.14271647589547, 45.75939416885376, 46.23624903815133, 47.54281609398978, 49.36512361254011, 48.2325325012207, 46.85482284000942, 31.196699483054026, 9.765892011778694, 2.1924723642213, 3.6314562346254076, 4.451420315674373, 4.29652065038681, 4.809650327478137, 0.5078278758696148, 0.06126883519547326, 3.9217152765819003, 39.579433577401296, 44.29418931688581, 37.60773284094674, 34.360367161887034, 41.05991056987217, 51.50080530984061, 25.173837661743164, 0.6541232828583036, 0.02249790232495538, 0.011957282350132508, 0.01600225266468312, 0.054544539589967043, 0.016896253085828254, 0.019067324265571575, 0.020667966322175095, 0.015545082910518562, 0.02384033296922488, 0.037308569465364726, 0.026451132160478404, 0.01955221387158547, 0.023435729322955012, 0.011390373127401938, 0.16122894494661263, 0.19625535687165602, 0.2347948838557516, 0.14149523313556397, 0.24762809808765138, 0.13671912013420037, 0.14738014021090098, 0.12990470150751726, 0.1170570073383195, 0.1847825917814459, 0.07755113113671541, 0.07272261487586157, 0.11269909582499947, 0.11717010555522782, 0.1416182651051453, 0.05375370363305722, 0.14033928087779454, 0.10977479309907981, 1.0348806572811944, 26.987732648849487, 58.15892703192574, 50.65861415863037, 38.762971605573384, 44.81690577098301, 43.09872395651681, 48.66882378714425, 56.11833838054112, 31.839838641030447, 1.079857649547713, 0.33289522411567823, 3.447570638997214, 11.181721227509634, 8.007105793271746, 5.730379138674055, 7.106680486883436, 34.37824835096087, 50.672903129032676, 52.86741522380284, 49.136017186301096, 47.431783880506245, 43.951518058776855, 42.01347092219761, 41.09260879244123, 41.85473585128784, 41.24317625590733, 41.48219428743635, 39.967879567827495, 42.28146641595023, 40.62960863113403, 40.20692886625017, 39.9279135295323, 40.74912806919643, 38.65423229762486, 37.69541563306536, 39.10598679951259, 37.54712717873709, 37.09221819468907, 38.5472161429269, 36.05226741518293, 37.492309365953716, 36.61513403483799, 37.83677673339844, 36.97014529364449, 37.36312845775059, 37.00862441744123, 35.86882107598441, 35.980297974177766, 36.93335805620466, 36.142479351588655, 36.02630547114781, 35.78042956760952, 38.98449059895107, 37.12730312347412, 34.30672706876482, 33.67607034955706, 36.08981895446777, 46.64451476505825, 49.535851274217876, 48.44611317770821, 48.09033761705671, 48.83264146532331, 49.25409139905657, 51.3837559563773, 47.90375764029366, 45.76292037963867, 40.198837688991, 46.59674937384469, 47.92032561983381, 42.390963077545166, 42.8269555909293, 49.77722821916853, 49.286518641880576, 46.208678586142405, 45.47172137669155, 46.132237979343955, 46.471928460257395, 49.41442455564226, 53.350815296173096, 51.291105202266145, 45.29761689049857, 48.449708870479036, 38.12730176108224, 35.04828398568289, 36.914090701511924, 35.52748734610421, 38.07431827272688, 37.318753787449424, 36.139745235443115, 38.922050612313406, 37.746811458042686, 40.83197144099644, 41.67766448429653, 35.55538783754621, 36.67690004621233, 38.57584619522095, 35.26552636282784, 38.55123567581177, 36.09270593098232, 37.23832491465977, 37.329183033534456, 35.99858215876988, 36.91143648965018, 35.2879238809858, 36.65093810217721, 36.77172906058175, 36.22292212077549, 36.44407285962786, 36.596502440316335, 35.35238231931414, 33.969603947230745, 35.49603632518223, 33.55615486417498, 35.21794162477766, 37.87117379052298, 39.42837279183524, 42.39547940662929, 44.34571715763637, 46.255294050489155, 49.53025797435215, 49.01577166148594, 50.96988650730678, 51.363505431583945, 48.53707551956177, 46.81975875582014, 34.94172988619123, 11.433497888701302, 3.283710403101785, 7.844030703817095, 8.656831843512398, 8.960004329681396, 9.793270519801549, 2.0885008232934132, 0.20508354529738426, 4.896636128425598, 43.2278597014291, 47.874675955091206, 45.06852436065674, 43.67756448473249, 48.012219020298545, 57.537306444985525, 29.94787543160575, 0.9689385614224842, 0.14458844358367579, 0.10820532803024564, 0.1006320086973054, 0.12824132719210216, 0.07019344344735146, 0.17403684982231685, 0.0604977954977325, 0.12555823687996182, 0.11763126509530203, 0.14256612424339565, 0.100393449355449, 0.1422331535390445, 0.12579925251858576, 0.10034110037876026], [0.028436529017718773, 0.06450162029692105, 0.04549178321446691, 0.07869313271450144, 0.061380712049348016, 0.08205720755670752, 0.031810820900968144, 0.049635956196912696, 0.0945740480508123, 0.039383631332644393, 0.04146237425240023, 0.032914420789373774, 0.08782130147197417, 0.038463704088436704, 0.039342966728976796, 0.012901444320699998, 0.011876994694050933, 0.038800461018191915, 0.20623805906091416, 12.12776449748448, 43.612591879708425, 41.90734413691929, 30.397608007703507, 23.105390208108084, 25.580335072108678, 36.38695171901158, 37.412387711661204, 36.62270757130214, 2.918178051710129, 0.061676512605377605, 0.5757387003728321, 2.869433615888868, 4.50746795960835, 1.9253345387322562, 3.30500967161996, 19.814139706747874, 44.23042222431728, 48.890766620635986, 46.34619038445609, 45.477557863507954, 41.57967751366751, 39.6707433291844, 39.69760159083775, 39.12368733542306, 39.23558112553188, 39.20797940662929, 39.19130720411028, 38.11623675482613, 38.75933422361101, 40.46099322182791, 39.464670181274414, 38.95973416737148, 38.99841478892735, 37.96284832273211, 38.04956878934588, 40.009992599487305, 37.989498138427734, 34.34864902496338, 32.743385859898154, 33.681760924203054, 32.59668159484863, 34.10950245176043, 32.26794147491455, 33.56986018589565, 32.67129135131836, 32.350051811763215, 34.4910523550851, 34.086073126111714, 34.289064747946604, 32.57995728084019, 33.45123706545149, 32.22397674833025, 32.93485042027065, 33.61559670312064, 32.19651746749878, 31.0298558643886, 35.59170259748186, 43.58015768868582, 45.1614009312221, 44.0703079359872, 43.364374433244976, 45.85564408983503, 44.075661523001536, 46.376745087759836, 44.63777773720877, 43.72865111487252, 32.03705978393555, 44.57191228866577, 48.104345185416086, 37.492326736450195, 46.73627267565046, 45.958942958286826, 44.53802939823696, 40.82524905885969, 44.93437201636178, 43.158346448625835, 45.52498974118914, 38.01359101704189, 48.27601432800293, 50.39671918324062, 42.4362792287554, 39.83872297831944, 30.394067900521414, 32.31537682669503, 32.65042591094971, 33.383919443402974, 32.34159237997872, 33.49423599243164, 33.20330102103097, 33.773876667022705, 33.81904343196324, 34.95488282612392, 33.016213825770784, 32.65390348434448, 31.19005353110177, 33.90313400541033, 32.905775683266775, 32.53727102279663, 33.47600391932896, 35.927258900233674, 38.07609006336757, 38.286825452532085, 37.61288145610264, 37.86610507965088, 35.26555068152291, 35.639537470681326, 33.396106583731516, 32.32125847680228, 33.60820034572056, 33.707194805145264, 31.40416921888079, 32.38574470792498, 33.614815030779155, 33.94330848966326, 37.76442166737148, 40.528946604047505, 43.14373786108834, 43.94752631868635, 45.65536226545061, 48.35862840924944, 46.87284646715437, 48.20100505011422, 43.86986977713448, 43.289281776973176, 25.239770855222428, 6.771453355039869, 1.3414877248661858, 3.1022790414946417, 2.4826886313302174, 6.280587877546038, 3.2811793046338216, 0.22734226233192853, 0.03536089576248612, 6.013105247701917, 33.61704887662615, 37.34600462232317, 34.53907830374581, 24.736337389264786, 40.71098245893206, 41.52097913197109, 13.20614402634757, 0.1357724687882832, 0.06913180077182395, 0.04213921293350203, 0.016526751752410616, 0.056276137208832164, 0.028033311279224496, 0.0169830054843, 0.019049151401434625, 0.030602506095809594, 0.05201071680390409, 0.01831406048898186, 0.0675053930442248, 0.02998936488958342, 0.043939963448792696, 0.07904188614338636, 0.016634728726265684, 0.04557308188772627, 0.026135710068047047, 0.009748898529713708, 0.0035596477183779435, 0.09127150954944746, 0.028516787836062055, 0.015230030619672366, 0.03806601471400686, 0.054161601566842625, 0.02806592167222074, 0.027324830813865577, 0.0777143934475524, 0.036832030929092846, 0.03316605889371463, 0.041754632855632474, 0.0691975372444306, 0.0452574409677514, 0.2814210961971964, 16.503032990864344, 49.78889077050345, 47.27956274577549, 36.64013365336827, 31.867426463535853, 36.20358528409685, 41.69806786945888, 42.87842437199184, 37.75194270270211, 2.170337357691356, 0.07829657649355275, 0.3659983149596623, 5.114298437322889, 5.49365314415523, 3.2585338226386478, 4.508059425013406, 23.468261616570608, 47.39752926145281, 50.638252462659565, 48.72892223085676, 47.62382861546108, 43.376019614083425, 42.233047894069124, 42.527161666325156, 41.43487705503191, 41.83849096298218, 40.20630005427769, 39.99325091498238, 39.951064927237375, 39.93586574281965, 41.50258725030081, 40.23651082175118, 40.32694162641253, 39.582622800554546, 39.81633240836007, 39.649106638772146, 41.42629255567278, 39.43569271905081, 36.71655688967024, 34.574371678488596, 35.19489445005144, 34.25763457162039, 36.483351026262554, 33.04613276890346, 34.65780912126814, 33.60954829624721, 34.55672672816685, 35.57413060324532, 35.40537275586809, 34.8248542376927, 33.80142627443586, 34.42465884344918, 34.60568026133946, 33.574974060058594, 35.02266945157732, 33.62847866330828, 31.837066309792654, 39.57072401046753, 45.386241163526265, 46.39936147417341, 46.64595651626587, 44.980744293757844, 46.84140934262957, 45.661170959472656, 46.64993435995919, 47.09364284787859, 44.33492660522461, 34.08372116088867, 49.520982129233225, 45.667789118630544, 39.09301798684256, 47.151563031332834, 46.6342488016401, 46.30724573135376, 43.46492528915405, 43.83889818191528, 45.332319668361116, 46.767866134643555, 40.81616428920201, 50.328515665871755, 48.92648730959211, 43.75252512523106, 40.41348838806152, 32.509533814021516, 34.804784366062705, 33.80876357214791, 34.42109441757202, 34.72144767216274, 35.856025968279155, 35.11526462009975, 36.332276344299316, 35.199303082057405, 36.4429611478533, 34.97421618870327, 33.846054553985596, 33.86202846254621, 34.594545773097444, 34.45925392423357, 33.52784790311541, 34.947826930454795, 37.657082421439036, 38.85213088989258, 39.5838873726981, 38.70888335364205, 39.04891082218715, 36.77321597508022, 37.00730773380825, 35.164471762520925, 34.49493987219674, 34.975928919655935, 34.958582741873606, 33.24568503243582, 33.79277924128941, 34.770425524030415, 36.8361805507115, 38.84192746026175, 42.145667348589214, 45.621819836752756, 45.32092114857265, 48.571278027125764, 49.74685069492885, 46.97405392783028, 47.210403851100374, 44.563862800598145, 43.346527985164094, 29.38871567589896, 7.569023609161377, 1.6893454875264848, 3.775651114327567, 4.888768596308572, 8.213179809706551, 3.455835086958749, 0.34007404318877626, 0.04458999999665788, 6.271995561463492, 36.69370426450457, 42.31812858581543, 36.04514898572649, 31.257687296186173, 44.93259327752249, 49.49341862542288, 16.701569080352783, 0.11296187208167144, 0.024144800113780156, 0.021127794237275208, 0.032717282617730756, 0.032180819261286936, 0.06229177423353706, 0.02658238627814821, 0.054019645255591185, 0.07257291648004736, 0.058497643896511624, 0.009408515678452594, 0.07740130381924765, 0.004575621170390929, 0.05947327547307525, 0.0782423819016133, 0.16667460916297777, 0.1726937983185053, 0.1409384680113622, 0.14101972936519555, 0.11847230925091676, 0.2140934318304062, 0.09553374083978788, 0.10041792411357164, 0.1474841596292598, 0.2699637881347111, 0.12558141563619885, 0.0799549635765808, 0.13945124138678822, 0.14995129938636506, 0.11752447725406714, 0.09083205634461981, 0.1455444994249514, 0.12601548805832863, 0.41243635596973555, 19.300388165882655, 55.86320400238037, 54.56045845576695, 41.55679014750889, 32.51299054282052, 36.086233683994834, 47.143468379974365, 47.02226400375366, 43.66492918559483, 3.4019726514816284, 0.205182869253414, 2.384818043027605, 9.867236699376788, 12.422527057783944, 4.7340951817376276, 5.579427352973393, 24.668726205825806, 49.13213314328875, 52.682388169424875, 49.993671553475515, 50.467708928244456, 47.274136202675955, 44.34742294039045, 44.45882340839931, 43.09154299327305, 44.405291012355256, 42.89627429417202, 42.45227745601109, 42.04356009619576, 42.23684508459908, 44.72159733091082, 43.04956545148577, 42.53949819292341, 43.506558895111084, 41.104163646698, 42.40055853979928, 43.82249695914132, 42.392307553972515, 38.96505648749215, 36.8097357068743, 36.724793979099815, 36.29457194464547, 38.9591018812997, 35.821621962956016, 37.15870203290667, 36.87125505719866, 36.20906741278512, 39.813466276441304, 37.23413167681013, 37.404883657182964, 34.68056099755423, 36.229449953351704, 37.35479061944144, 34.616842542375835, 36.711255414145334, 36.24591718401228, 33.733254023960654, 39.843291418892996, 48.401335511888774, 48.403385230473106, 48.17002650669643, 45.954228605542866, 48.863144057137625, 47.83856964111328, 48.53712068285261, 49.001461846487864, 46.77977534702846, 38.31725508826119, 48.661628927503315, 44.70819078172956, 42.47987570081438, 47.96562440054757, 49.43541506358555, 46.731534004211426, 45.072293758392334, 47.30825880595616, 48.96959393365042, 47.498028005872456, 44.51384619304112, 50.546786376408164, 50.268479755946565, 46.22339834485735, 42.0527560370309, 33.97836215155465, 35.156554290226524, 35.97555930273873, 35.53252479008266, 35.77706663949149, 36.51553160803658, 36.27657263619559, 37.15825734819685, 37.30515616280692, 38.26199606486729, 37.00127322333199, 35.17871904373169, 33.63954019546509, 37.607406275612966, 35.697721685682026, 36.354229177747456, 36.5554906981332, 40.180233887263704, 40.76302099227905, 43.261739117758616, 41.368962969098774, 43.35864911760603, 39.87769889831543, 39.21730736323765, 37.8657819884164, 35.752199036734446, 36.67822715214321, 36.961227280753, 34.15731995446341, 36.605694907052175, 37.07754012516567, 38.34024320329939, 41.110281535557334, 42.60702426092965, 47.615066937037874, 49.23500122342791, 50.517975670950754, 53.47323908124651, 48.43925183159964, 49.389275550842285, 43.86956753049578, 47.196316378457205, 30.619912147521973, 9.944498930658613, 3.9097926020622253, 8.90180708680834, 7.53770112991333, 11.647715193884713, 8.63943268571581, 2.106209393058504, 0.2905539061341967, 8.035554323877607, 42.824471609933035, 47.930862562997, 45.05416938236782, 36.40371077401297, 51.57230574744088, 53.895105906895225, 19.192852633340017, 0.2248537622924362, 0.19427422460700783, 0.15406197309494019, 0.1453416310250759, 0.120162322851164, 0.12097693128245217, 0.10902311879077128, 0.06931028262312923, 0.17037677764892578, 0.10912675144416945, 0.12627877321626457, 0.2571152661527906, 0.09322359372994729, 0.21021126157471112, 0.15205093100667], [0.034339374862611294, 0.04769456572830677, 0.026583130970331173, 0.026889309719470993, 0.02262299195198076, 0.018212807797161595, 0.01085610143906836, 0.0466591145044991, 0.029064033113952194, 0.0707875754950302, 0.007177650296528424, 0.021558443450235894, 0.056152233321751864, 0.01807156564401729, 0.05067615377317582, 0.055262283754668066, 0.03457450760262353, 0.02099498118540006, 0.04906377475708723, 4.521474659442902, 32.13466460364205, 45.73236567633492, 31.706575666155132, 19.184179544448853, 29.211345536368235, 34.943376609257285, 43.34651061466762, 40.78922264916556, 4.350549408367701, 0.026590408258406178, 0.5642332434654236, 1.986441774027688, 2.5328335634299686, 0.8102648843611989, 2.0639055030686513, 14.793218544551305, 37.44350869315011, 50.047575678144185, 48.30051367623465, 45.208280427115305, 44.57437889916556, 42.75261681420462, 40.885879039764404, 41.32472031457083, 41.12473031452724, 41.59849670955113, 41.228567668369834, 39.780014174325125, 42.395781653267996, 42.649408272334504, 42.330805574144634, 43.17277785709926, 42.06908777781895, 40.05359949384417, 40.72858224596296, 40.54807152066912, 43.29516690117972, 41.490149974823, 38.71970517294747, 34.27321590696062, 33.53437920979091, 33.29303700583321, 33.52568006515503, 32.50230768748692, 33.39760739462716, 33.569332122802734, 34.0759391784668, 33.42922864641462, 33.889762197222026, 32.72311449050903, 32.67316736493792, 32.03084462029593, 34.566145011356895, 34.038669041224885, 29.75109202521188, 31.702340739113943, 33.324776376996724, 35.88150153841291, 39.269387585776194, 39.52837821415493, 40.54025132315499, 40.57593379701887, 40.554825169699534, 44.0784512247358, 45.09255470548357, 44.9064576285226, 45.44422388076782, 36.155274459293906, 49.4094739641462, 42.267410210200715, 45.23340858731951, 48.353580542973106, 44.24717433112008, 42.17997407913208, 43.42651217324393, 44.0041298185076, 47.7077385357448, 46.27761513846261, 40.36471550805228, 48.685801710401265, 45.42998354775565, 37.86113016945975, 31.847912447793142, 32.04473059517996, 33.72199099404471, 32.980020659310476, 34.33374861308506, 34.77087715693882, 33.7015563419887, 36.00020456314087, 33.87770012446812, 32.83901391710554, 34.69734437125069, 33.97127151489258, 33.70645482199532, 33.47219978060041, 33.37872566495623, 33.56579548971993, 37.52585874285017, 42.8057462147304, 42.64698682512556, 44.7191515650068, 43.843213013240266, 41.473502090999055, 42.49284103938511, 41.41432080950056, 40.71761104038784, 37.910417216164724, 33.92712613514492, 32.63094663619995, 32.05206094469343, 31.809509754180908, 34.114473887852256, 35.631383759634836, 41.330393518720356, 43.583607469286235, 44.81125341142927, 46.4062054497855, 48.17236457552229, 44.84282602582659, 46.56206744057791, 44.34733608790806, 48.00784165518624, 44.32303128923689, 25.99417325428554, 4.532932238919394, 0.8780497727649552, 2.294068924018315, 3.2060636324541907, 3.16513700570379, 2.6744662949017117, 0.4478525184094906, 0.04951529909989663, 8.682553206171308, 38.588637828826904, 35.5467095375061, 24.671125071389334, 25.713995831353323, 42.99190929957798, 30.80106905528477, 6.719286280018943, 0.08810416915054832, 0.01866892582204725, 0.04093951891575541, 0.025124694586598446, 0.10047208477876016, 0.06456430336194378, 0.015928195656410286, 0.03497447006936584, 0.07864483459187405, 0.04476059387837138, 0.008696612852093364, 0.061096989416650364, 0.06696160829492978, 0.04016121889331511, 0.03498436989528792, 0.05471772886812687, 0.07035309595188924, 0.022943567517878752, 0.0380362270266882, 0.03775163586916668, 0.0337630407884717, 0.025241943741483346, 0.03008587292528578, 0.02518706043649997, 0.06530769954302482, 0.04164248119507517, 0.014809398279924477, 0.027082907634654214, 0.03252210541229163, 0.06276284038488354, 0.04127222499144929, 0.027336359123832414, 0.02102487743832171, 0.03276303962671331, 7.205829109464373, 40.16186285018921, 50.368818691798616, 37.75926610401699, 21.917248249053955, 31.345213753836497, 41.439271790640696, 45.565205914633616, 44.936522483825684, 4.912831945078714, 0.07420869477625404, 0.9389195208038602, 4.2382065909249445, 5.561387658119202, 1.888950731073107, 3.1632151773997714, 18.246690375464304, 39.742111751011436, 52.32763746806553, 49.66282612936837, 47.73962034497942, 45.900126457214355, 44.9604103905814, 42.6034528868539, 42.92007187434605, 42.68769632066999, 43.547351769038606, 42.12847055707659, 42.32438543864659, 42.394906180245535, 44.16645015989031, 45.03730957848685, 45.096511704581125, 44.5761194229126, 42.40991081510271, 42.217932088034495, 42.73904698235648, 43.76066146578108, 42.73761912754604, 38.835416998182026, 34.240048680986675, 34.66957589558193, 34.28989158357893, 35.579647472926546, 33.97999497822353, 33.946553298405235, 34.38926471982683, 35.56429542813982, 35.88178294045584, 34.54311520712716, 33.918017046792166, 33.32080200740269, 33.34069469996861, 35.50705964224679, 35.13634198052542, 31.75297573634556, 33.18511758531843, 34.79495613915579, 39.258016858782085, 41.759225913456504, 42.35146256855556, 42.4641032900129, 42.8376419203622, 42.58632557732718, 47.785620893750874, 46.39288922718593, 46.26014736720494, 45.786221163613455, 37.85873304094587, 52.551803725106375, 42.53736162185669, 46.817368575504844, 49.46953419276646, 45.90666471208845, 43.48361941746303, 44.584624017987935, 44.78667068481445, 48.99120283126831, 46.23202453340803, 42.075619084494456, 50.47375038691929, 47.62288018635341, 40.05587155478341, 33.83535432815552, 34.55857147489275, 34.77051585061209, 34.54194443566458, 35.19274745668684, 35.23411355699812, 35.08219814300537, 37.061944893428254, 35.88772712435041, 34.738328320639475, 35.83342000416347, 35.82242447989327, 34.69418294089181, 34.389900479997905, 36.071197782244, 34.713203634534565, 39.11329977852957, 45.15226752417428, 45.298937048230854, 47.57942615236555, 46.211798327309744, 43.08974340983799, 43.0497738974435, 43.697175775255474, 42.920606885637554, 37.967760699135916, 35.57394300188337, 33.58831112725394, 34.17402342387608, 33.71855163574219, 35.54472235270909, 38.54613222394671, 42.90464687347412, 45.67970527921404, 45.39529814038958, 49.77567877088274, 49.415070738111226, 47.94809409550258, 47.77838781901768, 45.348578453063965, 49.47355372565133, 47.128057275499614, 27.64551513535636, 6.039164900779724, 0.8537978455424309, 2.6087554437773566, 4.303430199623108, 5.160195631640298, 5.970227479934692, 0.508076762514455, 0.056170421452926736, 9.290620463235037, 43.34210198266165, 43.369596004486084, 32.55139323643276, 28.040370838982717, 48.26340682165963, 39.26888384137835, 9.692240238189697, 0.06578876051519598, 0.015855142879965048, 0.017870578482480984, 0.0364256596990994, 0.04739705865670528, 0.08729303481855563, 0.018289796076714993, 0.048332537923540385, 0.04833135387993284, 0.05725365850542273, 0.016747550440153906, 0.008932214629437243, 0.016055510878296833, 0.04167709665905152, 0.008871197367885282, 0.1755651142448187, 0.0998266012008701, 0.08410315348633698, 0.10930135886051826, 0.11109345126897097, 0.17868189699947834, 0.07308808740760599, 0.14358742801206453, 0.08212429431400128, 0.18122733969773563, 0.12844582407602242, 0.12227068043180875, 0.09865527333957808, 0.16785110746111187, 0.1888118548584836, 0.23079432281000273, 0.1243716012686491, 0.11193889233150653, 0.1682524202125413, 8.211683341435023, 44.629599707467214, 58.409600666591096, 43.14580842426845, 28.918534551348003, 39.077398436410085, 45.669039794376914, 52.25841951370239, 49.493849413735525, 5.937178373336792, 0.15528429964823381, 2.228378700358527, 9.506284730775015, 6.066717982292175, 2.2146672989640916, 4.370915012700217, 19.31516351018633, 42.44516944885254, 52.31432124546596, 53.54394742420742, 49.28075163705008, 48.70358215059553, 45.62392166682652, 45.09811673845564, 44.54707942690168, 44.20804207665579, 46.67382574081421, 44.93293373925345, 43.10576248168945, 45.90096371514456, 46.325884274074006, 45.94109998430525, 47.17791754858834, 46.98929827553885, 44.00208704812186, 44.380336557115825, 44.51712574277605, 47.82598645346505, 45.00034516198294, 42.936695439474924, 37.76891367776053, 36.14903845105852, 36.901031562260215, 37.96715273175921, 34.428452559879844, 36.18571104322161, 36.79853868484497, 38.82935469491141, 38.053126267024446, 36.759097235543386, 35.951862471444265, 35.20849207469395, 36.36451598576137, 37.36155469076974, 36.53961753845215, 33.54644128254482, 35.25243943078177, 35.78198248999459, 38.95235865456717, 43.51837778091431, 43.399963106427876, 43.40841906411307, 44.37888090951102, 44.66038370132446, 49.29520736421858, 47.138965947287424, 50.07701172147478, 48.819102900368826, 42.458767073495046, 49.20125034877232, 44.47707980019705, 48.95412029538836, 51.17908981868199, 46.73191268103463, 43.67337472098214, 47.53489862169538, 45.734700271061485, 52.308637619018555, 46.66708598818098, 45.00673403058733, 51.33312790734427, 48.54968997410366, 41.002098083496094, 34.39365250723702, 34.62303686141968, 36.57072809764317, 36.578940868377686, 38.027897357940674, 36.90464809962681, 36.30619280678885, 39.57937799181257, 37.03530202593122, 36.40463488442557, 38.84395980834961, 37.325125285557334, 36.47794532775879, 37.19119528361729, 38.49567093167986, 36.206357615334646, 41.64598764692034, 47.67631183351789, 45.528821672712056, 49.24279710224697, 48.76128693989345, 45.34674065453665, 46.89976726259504, 46.710505281175884, 46.64471973691668, 41.72991841179984, 39.302857058388845, 35.400144236428396, 35.479447501046316, 34.618763719286235, 37.72900322505406, 39.5662910597665, 44.599062374659944, 48.800526891435894, 49.53010163988386, 50.07835619790213, 52.908652782440186, 50.295671531132285, 49.90907028743199, 46.494607380458284, 50.05354070663452, 47.33421727589199, 30.749808720179967, 6.816148945263453, 3.3728067193712508, 6.255987780434745, 10.798644457544599, 11.516785076686315, 8.723685673304967, 0.9138272958142417, 0.18459216771381243, 10.476106473377772, 49.16008922031948, 46.56612171445574, 36.17576469693865, 35.31756142207554, 54.59406341825213, 45.512500354221885, 12.4799165725708, 0.2077295333147049, 0.06900233629026584, 0.24134594947099686, 0.14740516458238873, 0.16009378300181457, 0.20368238405457564, 0.0987220818975142, 0.10670008630092655, 0.13697225440825733, 0.12548426299222878, 0.055700803973845074, 0.1245354674756527, 0.10302953076149736, 0.08934825632189002, 0.1227238332586629], [0.04449041819732104, 0.04490386315488389, 0.05525164771825075, 0.03755318133958748, 0.010305206490946668, 0.0028994948495112893, 0.03629018339727606, 0.052382788088704856, 0.03530946959342275, 0.025323138938152363, 0.02581166718820376, 0.022496177149670463, 0.060897941168929846, 0.03833145422062703, 0.043567135597446134, 0.004535628316391791, 0.024868888580905538, 0.020720925980380604, 0.07637169478195054, 1.587196545941489, 21.052454607827322, 42.346560614449636, 34.939971991947715, 25.774931532996042, 27.510612385613577, 33.82065193993704, 38.58724471500942, 40.426196643284385, 11.746750473976135, 0.055925799400678704, 0.22504626267722674, 2.6737174093723297, 6.760264149733952, 4.411076034818377, 1.310545442359788, 12.7357223204204, 30.89485236576625, 45.38209656306675, 48.068756512233186, 47.945762974875315, 45.08679117475237, 43.91709320885794, 43.35327468599592, 42.66481590270996, 43.32329320907593, 44.110861097063335, 43.54618099757603, 42.373314653124126, 42.468254838671, 44.443037101200645, 41.09905324663435, 43.639853136880056, 43.45195995058332, 44.00646093913487, 42.91012552806309, 42.81963218961443, 43.476837975638254, 42.76336567742484, 41.08768946783883, 34.73365913118635, 32.823814732687815, 32.38685989379883, 32.37999159949166, 32.73266478947231, 33.166333130427766, 34.95579304013933, 35.57809107644217, 32.71320635931832, 33.74019180025373, 33.08133929116385, 33.051118101392476, 32.1388578414917, 33.74402373177664, 34.92418221064976, 32.00693586894444, 30.84511021205357, 33.654614312308176, 32.846639565059114, 35.0339081627982, 35.20744637080601, 34.83185107367379, 35.218959535871235, 36.87151561464582, 37.89251865659441, 43.73024920054844, 43.2038745198931, 48.671481473105295, 40.52016060692923, 39.621004649571006, 43.255263396671836, 42.920308113098145, 47.212411880493164, 43.14480440957205, 43.05861895424979, 42.54443488802229, 46.144466808864046, 44.12290927342006, 45.7990266936166, 39.83802121026175, 44.6955554825919, 45.422000067574636, 39.505556855882915, 32.39249835695539, 32.08590909412929, 32.5586575780596, 32.86267253330776, 33.24595948628017, 33.91923992974417, 33.92485407420567, 33.85032074792044, 32.8719414302281, 32.75513178961617, 32.99662685394287, 33.76651157651629, 32.2459990637643, 33.80091905593872, 33.95216049466814, 34.83066293171474, 42.13933059147426, 45.72183568137032, 45.416319915226524, 47.27100951331002, 45.10941103526524, 46.54175090789795, 43.74209587914603, 44.234028339385986, 43.24750573294503, 43.73046806880406, 41.7609212739127, 39.214430809020996, 32.88314192635672, 32.029065881456646, 32.79775551387242, 34.08006640842983, 41.56666701180594, 43.763746465955464, 45.57036147798811, 46.88185133252825, 48.22089079448155, 48.18897771835327, 45.790070465632844, 46.46391371318272, 49.13352973120553, 44.694884981427876, 25.93284671647208, 4.697831230504172, 0.7698748973863465, 1.1641201909099306, 3.7670283998761858, 7.8236551114491055, 3.014955601521901, 0.3238499994788851, 0.13978619341339382, 11.101670163018362, 38.000809805733816, 31.635766574314662, 25.899917466299875, 31.610402175358363, 41.209720679691856, 29.202219077519008, 3.1113130024501254, 0.07114976391728435, 0.010059104384189206, 0.037303874003035684, 0.017020955947893004, 0.02343479124829173, 0.029505457463009015, 0.03251337945195181, 0.05842614666159664, 0.02693950604381306, 0.06520289980939456, 0.01823648527663733, 0.04920065901907427, 0.005660155497025698, 0.05200148533497538, 0.013009740206013833, 0.026188408490270376, 0.022981936976845776, 0.031257580766188245, 0.05204450784783278, 0.03176886368809002, 0.02713829305555139, 0.03965499784265246, 0.05137023063642638, 0.03272532665037683, 0.10016540730638163, 0.06137935497931071, 0.014455101219937205, 0.04149888961442879, 0.020458112404282604, 0.020608012664264867, 0.023663253989070654, 0.016394030302762985, 0.03612502458106194, 0.012033701508439012, 2.5385999168668474, 27.193500076021465, 49.11974450520107, 38.891315255846294, 27.87189613069807, 32.43580995287214, 39.30904442923409, 44.1990441594805, 44.25903838021414, 10.066359911646162, 0.043256909386920075, 0.49098902515002657, 2.6975403938974654, 7.189933368137904, 2.9126837636743272, 1.9681849479675293, 14.471393619264875, 35.54595913205828, 46.139981746673584, 48.96206556047712, 48.94198179244995, 47.04109362193516, 45.74718965802874, 45.57207768304007, 45.764209270477295, 44.652890069144114, 46.210196767534526, 45.762638977595735, 44.90179886136736, 43.26171479906355, 46.00724336079189, 43.39234788077218, 45.904114723205566, 45.56311798095703, 46.409269605364116, 44.05130808694022, 44.16574491773333, 44.46059519904, 44.89693859645298, 42.020231519426616, 37.23719583238874, 34.20731571742466, 33.550731795174734, 34.5351699420384, 33.8540484564645, 36.46951368876866, 35.44346278054373, 37.1018761907305, 35.50484316689627, 35.28708662305559, 34.373478412628174, 34.29411956242153, 33.33798142841884, 36.08556318283081, 35.824863297598704, 33.14339017868042, 33.452074323381694, 34.69522517068045, 34.8702780859811, 36.311838218144004, 35.851686818259104, 36.75840241568429, 37.41349247523716, 38.551114082336426, 39.86314937046596, 46.775634220668245, 44.912460872105186, 49.328100136348176, 42.81348303386143, 42.666070052555625, 44.40134790965489, 44.34285797391619, 49.34475844247, 45.812804971422466, 43.985432216099326, 43.52713598523821, 48.117532866341726, 47.57571234021868, 47.57260996954781, 40.96301794052124, 46.123483249119346, 47.448143414088655, 41.078639439174104, 33.33576842716762, 34.03253378186907, 34.444471631731304, 33.46774251120431, 35.05264745439802, 34.74109370367867, 34.74786124910627, 35.79553147724697, 35.203711714063374, 34.22775731767927, 35.24361869267055, 34.96811219624111, 34.15534666606358, 35.17605788367135, 35.41834504263741, 36.396700041634695, 45.00938476834978, 47.52858965737479, 49.027128492082866, 49.47480092729841, 46.76457616261074, 48.153048583439414, 46.50264644622803, 45.94033915655953, 44.40914726257324, 45.17801059995379, 44.19186667033604, 40.168884004865376, 34.064815112522666, 34.175538131168906, 35.26255600793021, 36.406055791037424, 43.88055610656738, 46.167302063533235, 48.12781620025635, 48.104119368961875, 49.418207849775044, 49.47635037558419, 48.49910708836147, 47.79978479657854, 50.28104209899902, 45.84099381310599, 27.75811764172145, 5.515693698610578, 2.3502396813460757, 4.8866515670503885, 8.163438524518694, 6.194207438400813, 4.498390572411673, 0.32251195556351114, 0.07617334542529923, 11.955747076443263, 44.56256348746163, 36.908955982753206, 27.666792256491526, 35.81686244692121, 45.729360580444336, 35.460426807403564, 4.741022101470402, 0.040976997797510455, 0.04371690184676221, 0.0417956367268094, 0.004561152683371412, 0.03992579438324485, 0.03425998965810452, 0.03147331079734223, 0.04114830753366862, 0.017138627490827014, 0.023003680631518364, 0.02964476409501263, 0.03003762908545988, 0.032577514581914456, 0.035893759490656, 0.06044584007135459, 0.11531128601304122, 0.12110319307872228, 0.0835557250039918, 0.19574541066374096, 0.09275883116892406, 0.0827955079397985, 0.10505149726356779, 0.09627251619739191, 0.13778971268662385, 0.23941975140145846, 0.2007988952100277, 0.11292692074286086, 0.13296777143010072, 0.18452462633805616, 0.16998956485518388, 0.10568722350788967, 0.09619776199438743, 0.1290460154414177, 0.13366784315024102, 2.9323604106903076, 32.60821213041033, 55.743625504629954, 46.6271025793893, 35.71505396706717, 36.485709939684185, 45.16881118501936, 47.734082630702424, 49.59855876650129, 14.755135468074254, 0.11664356238075665, 1.2472567984036036, 6.954476722649165, 17.539692061288015, 9.996771097183228, 2.942751224551882, 16.182231187820435, 37.901346342904226, 46.1923885345459, 50.13411896569388, 52.91086230959211, 49.25235782350813, 47.68386105128697, 48.519948210035054, 46.651723521096365, 47.15321322849819, 47.945179326193674, 47.398870263780864, 46.81325871603829, 45.59824112483433, 47.441643374306814, 44.6601231438773, 47.46483646120344, 47.743653774261475, 49.71316582815987, 45.80945246560233, 47.30083465576172, 46.02283164433071, 47.39716100692749, 43.94824545724051, 38.96480982644217, 35.284189224243164, 35.879135676792686, 36.45367874417986, 36.637302262442454, 38.01638419287545, 38.95684371675764, 38.95537417275565, 37.54245798928397, 36.99572161265782, 36.30535207475935, 35.86787959507534, 34.79455314363752, 37.06518275397164, 38.533406598227366, 34.79579339708601, 35.0632677759443, 35.81840147290911, 35.80948346001761, 37.862009116581504, 37.507616247449604, 38.57859420776367, 40.19495364597866, 39.84158216203962, 41.47427681514195, 47.2184602873666, 46.433980873652864, 50.93753569466727, 46.518901756831575, 43.603340353284565, 45.2589293207441, 46.81873737062727, 49.421584674290244, 47.16891963141305, 45.03191082818167, 45.52359662737165, 49.28200231279646, 48.19981690815517, 47.69091347285679, 43.2372328213283, 48.85046706880842, 49.654529980250764, 43.08998312268938, 35.1738726752145, 34.446830545152935, 35.49027279445103, 34.89957863943917, 37.12405831473214, 36.32217713764736, 36.48689808164324, 38.34317881720406, 36.30032157897949, 35.24160024097988, 36.55547680173601, 37.18725912911551, 34.99282693862915, 37.38627290725708, 37.32858201435634, 37.44210515703474, 46.82412917273385, 48.97350924355643, 50.67238201413836, 54.03514684949602, 47.850096702575684, 50.74627958025251, 48.03122581754412, 48.57056583677019, 45.28312642233712, 47.744150570460725, 46.87270402908325, 43.01430681773594, 36.152623721531455, 35.32503420966012, 36.748848642621724, 37.465200969151084, 45.263633251190186, 48.09160566329956, 49.752725396837505, 50.49012034279959, 51.74156733921596, 50.49499797821045, 48.53180183683123, 49.88040896824428, 52.673254762377056, 47.16846799850464, 30.53172561100551, 7.3054046119962415, 2.8110038254942213, 6.076470647539411, 11.04087950502123, 20.257818664823258, 8.189906818526131, 1.4259467699698039, 0.24756466863410814, 13.536356295858111, 50.08550589425223, 42.95817232131958, 36.1187755720956, 43.40459060668945, 52.430241516658235, 41.565864494868684, 5.669734392847333, 0.16442386779401982, 0.1943439780069249, 0.09295566060713359, 0.1501387378999165, 0.17331798268215998, 0.06811825944376843, 0.08181384418691907, 0.14232752418943814, 0.10271826639239277, 0.13496647775173187, 0.11821788576032434, 0.1382179632782936, 0.11862097627350263, 0.0971546456483858, 0.11803614694092955], [0.0025352589478383637, 0.010257841353969914, 0.04015316128996866, 0.07034996790545327, 0.031012208932744603, 0.06900049067501511, 0.03074883556525622, 0.022891330499468104, 0.04088133114523121, 0.04420743177511862, 0.03638438441391502, 0.049939709183360846, 0.03761983383446932, 0.020744143752381206, 0.07111628499946424, 0.038973429772470675, 0.04323691295992051, 0.04270238682095494, 0.009235027844884565, 0.3621208944490978, 13.535895109176636, 41.45493303026472, 41.276583194732666, 24.54991374697004, 19.596271991729736, 30.218476499829972, 36.889414174216135, 46.300783906664165, 21.568907260894775, 0.35193092695304323, 0.4207140217934336, 2.9494015191282545, 2.952249846288136, 1.1963160804339816, 1.7654390100921904, 10.300506387438093, 29.980094228472026, 46.95198992320469, 46.042036465236116, 46.232611656188965, 45.515898023332866, 46.399861744471956, 45.67761387143816, 44.109078884124756, 44.139192376817974, 45.66750771658761, 44.07300731113979, 44.825851576668875, 44.931540625435964, 43.98051636559622, 42.63102681296212, 45.23336342402867, 44.4753531728472, 44.63542577198574, 46.75451169695173, 44.78467655181885, 45.465217862810405, 43.17894785744803, 43.43939413343157, 37.908822604588096, 32.149641445704866, 32.806451184409006, 32.05609089987618, 32.37930372783116, 33.9242183140346, 34.19694900512695, 34.205585615975515, 34.69305385862078, 31.313130446842738, 33.395839078085764, 32.661442279815674, 33.959838254111155, 31.928268364497594, 33.536557470049175, 32.68658433641706, 34.824510301862446, 33.02451344898769, 34.78991174697876, 33.68903568812779, 36.260261740003315, 36.05772869927542, 36.88301488331386, 37.22137131009783, 37.43926681791033, 40.26423066002982, 42.311437470572336, 46.39318452562605, 44.662228448050364, 39.76471771512713, 39.4603727204459, 41.900135380881174, 47.43324300221035, 45.34131063733782, 44.08280774525234, 43.78906570162092, 46.00125053950718, 45.71882363728115, 45.14812292371477, 39.009372098105295, 41.403707436152864, 45.92865228652954, 39.63383797236851, 32.083946228027344, 32.429320335388184, 33.022741658346995, 34.413559096200125, 33.23214994158064, 35.495560373578755, 34.24773686272757, 34.73145307813372, 33.409172671181814, 35.33165584291731, 32.870718547276084, 35.805192947387695, 32.432408809661865, 33.0763817514692, 31.71856825692313, 36.26990931374686, 43.68910891669137, 46.97556863512312, 41.02900498253958, 41.06972142628261, 45.77678203582764, 44.41971894672939, 44.24325207301548, 45.787534373147146, 44.366909163338796, 44.90887907573155, 42.954899719783235, 44.68585927145821, 41.69719239643642, 35.361751965114046, 33.256836891174316, 33.48292432512556, 35.902287074497764, 44.38052763257708, 44.94345678601946, 49.07954222815377, 46.327187061309814, 46.53265919004168, 45.9747223172869, 48.29042836597988, 50.443595205034526, 44.133706774030415, 23.15379309654236, 5.017069688865116, 0.5805403941443988, 2.2251688497407094, 5.6429621151515414, 3.4516635622297014, 5.040152907371521, 0.3660990095564297, 0.08067972718604974, 11.544094971248082, 37.215090138571604, 35.854111739567344, 36.39727674211775, 34.52306270599365, 45.19064589909145, 24.203044039862498, 0.9419634831803185, 0.03179637149774602, 0.017695016028093438, 0.02864114973427994, 0.015636149095371366, 0.04808680985921195, 0.033697779290378094, 0.048141296221209426, 0.06148605461099318, 0.022798603600157157, 0.011563745610016798, 0.023992265441587994, 0.04287878217707787, 0.011411606184472995, 0.05445638771301933, 0.03901311728571143, 0.02222002187876829, 0.04448353106688176, 0.05837223705436502, 0.04131070810503193, 0.030356947665235827, 0.029036104612584625, 0.03501893107646278, 0.032573721571160216, 0.029050516696380715, 0.06104571931064129, 0.010183335664415998, 0.007705300331248769, 0.0054317648505925065, 0.03014719552759613, 0.034170334826090505, 0.0926024763445769, 0.05228209688461252, 0.06578344758599997, 0.029326758480497768, 0.6223025417753628, 17.72548168046134, 46.65594802583967, 45.6688209261213, 28.12039497920445, 20.341005972453527, 38.01466451372419, 42.59960011073521, 48.67575461523873, 22.783829314368113, 0.1522927473166159, 0.255629654441561, 3.1150952109268735, 4.727069250174931, 2.2967048968587602, 1.8734975031444003, 10.990157655307225, 34.98072665078299, 45.026109082358225, 47.4727018220084, 48.22372565950666, 47.41923195975167, 48.85348606109619, 47.0281526020595, 44.44262020928519, 46.96031733921596, 47.120469842638286, 45.10785811288016, 46.59980310712542, 46.92425618852888, 45.85281269890921, 44.27172926494053, 44.947782039642334, 45.319097246442524, 46.22310652051653, 46.70653438568115, 47.11988271985735, 47.240565981183735, 45.608930928366526, 45.24901424135481, 39.58360249655587, 35.082861695970806, 34.55513211659023, 33.178655760628835, 33.765361649649485, 35.09204374040876, 35.95070559637887, 37.174015862601145, 36.765691076006206, 32.87240695953369, 34.54292413166591, 33.54987021854946, 34.83266053880964, 34.09165252958025, 33.345426423209055, 33.85971818651472, 35.231744221278596, 35.52995048250471, 36.04090016228812, 35.85013389587402, 37.523006507328574, 38.02151196343558, 37.918126242501394, 38.729658467429026, 39.244030135018484, 41.971910272325786, 44.303287982940674, 47.899053709847585, 44.13170569283621, 42.25782517024449, 41.49931117466518, 42.8766873223441, 48.99960667746407, 45.577063015529085, 45.110633918217246, 45.729308468954905, 48.19984817504883, 46.746952056884766, 47.59110607419695, 40.13857248851231, 43.97439500263759, 47.24169158935547, 41.06171015330723, 33.18721941539219, 34.18658576692854, 33.12646436691284, 35.41523919786726, 34.97943775994437, 36.7968989099775, 34.73775509425572, 34.91288791384016, 35.21564177104405, 36.55394124984741, 34.676301751817974, 37.532612391880576, 33.92700801576887, 35.06067262377058, 33.898704528808594, 37.40825005940029, 45.54148823874337, 47.53009046827044, 43.090542452675955, 43.60394484656197, 45.801323073250906, 47.25647735595703, 46.646449838365825, 47.619201115199495, 45.72575099127633, 45.63862752914429, 44.45212881905692, 46.86706556592669, 43.84246955599104, 35.65447957175118, 34.99908031736101, 34.69478048597063, 38.2715220451355, 45.07694557734898, 46.8541384424482, 50.67138147354126, 48.47930472237723, 48.052626269204275, 48.5627977507455, 49.9265901701791, 51.04641744068691, 45.98290034702846, 25.42400928906032, 5.748236009052821, 2.3922836652823856, 5.909231850079127, 9.46345603466034, 6.482552468776703, 4.984914294310978, 0.13077473267912865, 0.006410627526098064, 13.2177266733987, 41.98542104448591, 38.63987731933594, 37.93957185745239, 39.287154129573274, 48.93411643164498, 30.255906445639475, 1.6788390512977327, 0.026594121541295732, 0.020316145915005888, 0.024212494159915617, 0.0560949344321021, 0.04695242822968534, 0.0351873502534415, 0.04733894891770823, 0.04893717369330781, 0.045356106744813066, 0.021852064212518077, 0.06298928787665707, 0.04108862020075321, 0.044024464807340076, 0.07093869202903338, 0.017662602410252606, 0.13367312215268612, 0.07586514803447894, 0.11234628475670304, 0.23103191863213265, 0.14529701056224958, 0.12846257032028266, 0.13858809056026594, 0.10406184715351888, 0.08414605047021594, 0.11772328801453114, 0.07782021098371063, 0.1687273947255952, 0.0904479105291622, 0.10838055291346141, 0.14824145899287292, 0.1320683325507811, 0.11432076059281826, 0.10497239365109376, 0.12522427551448345, 0.7364708898322923, 20.799804210662842, 55.05877978461129, 52.15802846636091, 33.46140922818865, 28.704358066831315, 41.385916573660715, 47.18413618632725, 55.99576868329729, 25.87568736076355, 0.605107595877988, 1.364217453769275, 9.98239266872406, 10.188737664903913, 3.3580928231988634, 3.3417265585490634, 12.751101289476667, 35.33806555611746, 51.240692547389436, 48.79357521874564, 47.17725052152361, 48.61830690928868, 50.890173298971995, 49.31037875584194, 46.96988500867571, 48.68895271846226, 49.44035523278372, 47.44604853221348, 47.707106249673025, 48.34976250784737, 47.23797082901001, 45.30763271876744, 47.81574133464268, 47.13773264203753, 48.08875690187727, 49.34974030085972, 47.27615812846592, 48.80432060786656, 47.079711709703716, 47.057699816567556, 41.372298104422434, 36.045485973358154, 35.99304791859218, 34.35013941356114, 34.93760960442679, 38.22032076971871, 38.36553117207119, 37.61042874200003, 38.93154532568795, 34.529924052102224, 37.01321717670986, 35.7729845728193, 36.98064749581473, 35.22994116374424, 35.26184034347534, 36.02472823006766, 37.26022911071777, 37.02956281389509, 38.29948507036482, 37.196885858263286, 39.560412883758545, 39.14268718447004, 39.89281470435006, 41.450017179761616, 41.51914133344378, 43.89824969427926, 46.82251371656145, 50.82119853155953, 46.832206453595845, 44.449325220925466, 43.12995263508388, 44.84085273742676, 48.96399368558611, 48.02696309770857, 46.14548124585833, 47.206641401563374, 49.164192131587434, 47.676732199532644, 48.936899185180664, 41.39389657974243, 44.1872878074646, 48.71813862664359, 42.50778661455427, 35.031142779758994, 35.903902530670166, 34.79067604882376, 37.86217587334769, 36.614543437957764, 38.28470972606114, 36.22072301592146, 37.14108140127999, 38.01144749777657, 38.8590339251927, 35.73699985231672, 39.44830369949341, 35.54830067498343, 36.15534394127982, 36.12840230124337, 40.22876010622297, 48.19636712755476, 49.93291303089687, 46.214542865753174, 46.73068284988403, 46.73191268103463, 50.147320543016704, 48.80604028701782, 49.31366177967617, 47.51377957207816, 48.418143204280305, 46.466223989214214, 48.42518867765154, 46.82364627293178, 39.36856269836426, 36.55959013530186, 36.7748418535505, 39.70969493048531, 48.51569243839809, 49.020051751817974, 52.684840883527485, 51.52130249568394, 49.63970252445766, 50.028151988983154, 50.57339102881295, 54.123746803828645, 47.37980440684727, 27.56071237155369, 7.006797092301505, 2.832279860973358, 7.646603720528739, 14.1762159040996, 9.049734234809875, 11.097573331424169, 1.5850961272205626, 0.23687440369810375, 14.94208196231297, 48.24613012586321, 47.0517486844744, 44.96597242355347, 45.83398655482701, 56.46794741494315, 35.92986100060599, 2.2159527157034193, 0.11603450934801783, 0.06535145826637745, 0.08230186692838158, 0.12210167092936379, 0.1272183135151863, 0.15289867908826896, 0.16663015154855593, 0.11703559277313096, 0.16303310170769691, 0.13684257279549325, 0.12806481309235096, 0.1704541306410517, 0.1092707094337259, 0.0838655305228063, 0.1196833856936012], [0.015799170526276742, 0.034837969179664335, 0.031129168013909032, 0.04530240409076214, 0.026416832215285728, 0.08706185115235192, 0.013842643637742316, 0.010213992724727308, 0.03058510845793145, 0.02345838051821504, 0.0360603839425104, 0.031959060446492264, 0.01741443161985704, 0.05250237310039146, 0.03848126796739442, 0.035652947412537675, 0.031351568044296334, 0.010842229638780867, 0.03905344940721989, 0.023254926881885955, 7.181050096239362, 32.92254516056606, 39.648668902260916, 27.232962369918823, 24.395861761910574, 27.196696247373307, 34.53221000943865, 42.81443493706839, 30.41255705697196, 1.4057360887527466, 0.02661949026930545, 1.0041917668921607, 4.339271179267338, 1.4024967082909174, 0.5884288251399994, 9.407879131180898, 29.41054344177246, 42.33090284892491, 46.219337122780935, 45.81958293914795, 44.214545590536936, 45.02675526482718, 46.57143708637783, 44.36414725439889, 45.75304698944092, 45.681424958365305, 45.681508336748394, 45.344934122903005, 44.531122888837544, 43.15134613854544, 39.999163831983296, 45.552924973624094, 43.464894022260395, 43.50505461011614, 43.0656852722168, 42.104325566973, 41.522208963121685, 45.3561554636274, 41.52256332124983, 38.15944760186331, 33.875320366450715, 33.19135706765311, 32.125715323856895, 32.7661794253758, 33.10187816619873, 35.119218145098, 35.75713225773403, 35.33072131020682, 35.71531105041504, 34.887811865125386, 34.578623976026265, 32.551295961652485, 33.25883797236851, 33.819891112191335, 32.36931916645595, 34.973031520843506, 33.95698601858956, 35.42645011629377, 39.86303472518921, 40.648003986903596, 42.33980349131993, 39.41029010500227, 37.466403007507324, 38.83528845650809, 37.755722522735596, 41.159189905439106, 44.95314952305385, 45.853709016527446, 41.54138946533203, 38.94360392434256, 41.768446172986714, 47.520269189562114, 45.25240496226719, 46.04668828419277, 44.676722390311106, 45.46659360613142, 44.821015630449565, 43.71424055099487, 42.95701892035348, 41.145244870867046, 44.37029641015189, 39.024428844451904, 31.575025422232493, 32.537496839250835, 32.42802102225167, 32.61718920298985, 32.850415910993306, 35.84741367612566, 32.888137681143625, 32.91762931006295, 32.938550336020334, 33.267012528010774, 32.709231989724294, 32.96880279268537, 32.45884323120117, 32.98244905471802, 33.06918689182827, 33.41645090920584, 42.90217331477574, 45.27282224382673, 41.51560470036098, 43.71772159848894, 42.65077359335763, 42.38581446238926, 44.658351353236604, 46.13165085656302, 45.99992343357631, 45.23839044570923, 45.48924125943865, 44.580507210322786, 43.679367542266846, 42.17800426483154, 35.94955914361136, 32.62268870217459, 33.57856627873012, 40.50795957020351, 44.91474682944161, 46.56446804319109, 47.99098879950387, 48.22125557490757, 46.98345831462315, 47.541193689618794, 49.072371687207905, 42.21979767935616, 22.799058028629847, 4.94183155468532, 3.7095702716282437, 6.685886723654611, 8.49879332951137, 5.176389711243766, 1.7330257722309657, 0.14604536683431693, 0.9032905697822571, 19.378769057137625, 37.00391353879656, 25.755250760487147, 35.61569472721645, 36.568942410605295, 44.28811659131731, 19.29800145966666, 0.48821099421807695, 0.018065131435702955, 0.040818129000919204, 0.024859002325683832, 0.03552874157737408, 0.012815416258360659, 0.09417876747569867, 0.06499642160321985, 0.045822151737021546, 0.008510919869877398, 0.03177468212587493, 0.09253412751214844, 0.03714687117774572, 0.016904079987268363, 0.04080637677439621, 0.031595623519803794, 0.05504320176052196, 0.048443793917873075, 0.010755813963312124, 0.05484952411747404, 0.015556511136570146, 0.06657707571451153, 0.024370302745540227, 0.0736253989328231, 0.05288723137761865, 0.034597302986575026, 0.02955735182123525, 0.07651456711547715, 0.0032076712481544484, 0.05886219362063067, 0.04138496019212263, 0.046051598353577514, 0.032339403073170354, 0.008966212626546621, 0.10815878731331655, 0.06314685049333743, 9.38654555593218, 40.398039068494526, 46.36023269380842, 29.91466304234096, 29.067212104797363, 34.989074911390034, 40.48238672528948, 48.73336212975638, 30.015689849853516, 1.5348554402589798, 0.10165980604610272, 2.0440660076481953, 4.153364309242793, 1.5257783787591117, 1.0971845026527132, 9.133509533745901, 31.777961458478654, 45.53016267504011, 48.2652758870806, 47.68904440743582, 45.78808675493513, 46.45319264275687, 48.723575592041016, 45.814271041325156, 47.17237983431135, 45.72272505078997, 46.601279599326, 46.00573560169765, 45.613440309252056, 44.35450662885393, 40.920411586761475, 46.145762647901265, 43.761866978236604, 45.26684331893921, 42.96578407287598, 43.79506547110421, 43.450195108141216, 47.47002329145159, 43.96365308761597, 40.285693645477295, 35.817814350128174, 35.516679423195974, 33.50827830178397, 34.12405892780849, 36.44215863091605, 37.38581085205078, 38.40222460883004, 36.87467009680611, 36.528243337358745, 35.804977553231375, 35.564469133104595, 34.238412380218506, 35.311002322605674, 34.433882577078684, 33.95702075958252, 37.49527972085135, 34.94015959330967, 36.02867828096662, 40.369721685137065, 43.08711004257202, 42.305625302451, 40.531913484845845, 40.129161153520855, 38.979296820504324, 39.124844210488455, 42.81452178955078, 46.558433532714844, 48.450035435812815, 43.410611220768516, 42.41649770736694, 43.50226143428257, 49.226142270224436, 46.10563332693917, 46.285306794302805, 46.716345242091585, 47.914110456194194, 45.29925319126674, 44.34499454498291, 41.64861059188843, 43.92879744938442, 46.0270630972726, 40.79570879255022, 33.14636400767735, 33.721601894923616, 33.79745537894112, 33.622138432094026, 33.795513357434956, 35.23903635569981, 34.8861060823713, 34.4169602394104, 35.47733524867466, 35.309518882206504, 34.44157770701817, 35.6927433013916, 33.37803431919643, 35.77809149878365, 33.667381627219065, 36.41820819037301, 45.63719967433384, 45.98500912530081, 43.72884913853237, 45.279694012233186, 42.44986295700073, 44.180259704589844, 45.170523915972026, 46.13562522615705, 46.20867511204311, 47.324371678488596, 47.00090176718575, 45.8551299231393, 46.262530599321636, 43.1565329687936, 37.504194259643555, 35.08879198346819, 34.88078376225063, 42.60408517292568, 47.70718962805611, 49.74870933805193, 51.152728353227886, 48.267693860190256, 49.694773946489605, 48.078883511679514, 50.768312317984446, 43.916325432913645, 25.603670597076416, 5.366131552628108, 3.270536618573325, 6.547211102076939, 7.610248139926365, 9.10208717414311, 3.1270487180777957, 0.2951345331966877, 0.6545077679412705, 18.699865783963883, 40.655139786856516, 35.559733935764854, 37.78832694462368, 39.43212134497506, 49.869826861790244, 24.802105563027517, 0.6677329039999417, 0.012539062515965529, 0.02550020095493112, 0.05230837993855987, 0.042535060085356236, 0.0662990663466709, 0.009813042989532863, 0.033479911873915365, 0.022507001479555453, 0.0109319760730224, 0.05206799873017839, 0.08854721180562462, 0.03969416966927903, 0.06616166979074478, 0.017008716872494136, 0.055679759210241694, 0.17905047722160816, 0.11266796463834387, 0.12211730437619345, 0.14696664097053663, 0.06950022493089948, 0.14363865740597248, 0.15526760768677506, 0.0858024630163397, 0.11680718431515352, 0.08561262927417244, 0.12695363057511194, 0.1056619616491454, 0.08460479442562376, 0.1670840507639306, 0.08658516673105103, 0.12342826117362295, 0.1635992577565568, 0.10653607081621885, 0.2109211449112211, 0.23890216488923344, 11.093529479844229, 44.01301309040615, 53.75711120877947, 39.02207687922886, 34.68251691545759, 37.3289224760873, 45.74133927481515, 51.135038239615305, 37.09006077902657, 2.017938175371715, 0.3573098640356745, 3.045632766825812, 12.662335446902684, 6.005887806415558, 1.6475443648440498, 13.207874127796718, 31.97237205505371, 47.33717026029314, 51.37750257764544, 48.3368353843689, 46.869122232709614, 49.670361450740266, 49.7145346232823, 47.27097824641636, 48.95364086968558, 48.38905804497855, 48.26002999714443, 47.55331482206072, 46.65547207423619, 44.69576045445034, 40.58803755896432, 48.20866543906075, 44.36266033990042, 45.379560470581055, 44.81854901994978, 44.57378135408674, 45.64657279423305, 50.28884840011597, 45.355241775512695, 41.03884710584368, 36.68386214120047, 37.63940967832293, 34.67735092980521, 36.53024789265224, 38.133586406707764, 39.39280148914882, 41.239785534994944, 38.71585587092808, 37.89786876950945, 38.57489081791469, 37.94444601876395, 36.35750872748238, 37.23750850132534, 36.56453030450003, 35.47441700526646, 38.76562581743513, 36.74358190808977, 38.850251402173726, 43.26066562107631, 43.33627939224243, 45.523204054151265, 42.225915568215505, 41.76178285053798, 41.46718617847988, 40.36303404399327, 43.58572319575718, 49.27172245298113, 49.9408027103969, 45.5327786718096, 44.54349763052804, 45.343520164489746, 49.6261431149074, 48.335661138807026, 49.19118935721261, 48.48252521242414, 49.688308647700715, 46.63729558672224, 46.22621236528669, 44.187145369393484, 44.970516545431956, 46.74603489467076, 43.231347697121755, 33.67385387420654, 35.888936110905235, 35.66678830555507, 34.55208533150809, 35.34150838851929, 37.01819208690098, 36.70164952959333, 35.531086512974326, 36.38440520422799, 36.6480268069676, 35.73817409787859, 37.14349937438965, 34.860842432294575, 36.56340817042759, 36.08174862180437, 37.38420581817627, 48.12929269245693, 48.44947263172695, 45.371226106371196, 44.57113061632429, 41.89259658540998, 44.27935838699341, 46.89043583188738, 48.95987687792097, 48.79093142918178, 48.11934287207467, 48.361984389168875, 46.67185592651367, 48.14200789587838, 45.327296120779856, 39.807136467524934, 37.32658093316214, 37.416966574532644, 44.74831315449306, 49.44477776118687, 51.578767572130474, 53.82333101545061, 50.51135056359427, 50.749642508370535, 50.39691720690046, 52.42256375721523, 46.585093770708355, 27.943521635872976, 7.2110094257763455, 6.631354221275874, 13.725256970950536, 15.737454414367676, 13.605579461370196, 6.691646346024104, 0.6281600903187479, 1.2364751483712877, 23.765062604631694, 48.393265179225374, 35.80835437774658, 45.26181977135794, 47.66415248598371, 55.219700063977925, 30.07159158161708, 1.0152642641748701, 0.19574531566883835, 0.11180943463529859, 0.16333339416554996, 0.06976248550095729, 0.14252520858177117, 0.13670500660581247, 0.12919945935053484, 0.11510734552783625, 0.072591169072049, 0.1577604639210871, 0.26107706927827423, 0.09912104691777911, 0.11132046873016016, 0.09224351774901152, 0.11870651239795343], [0.058865267384265146, 0.010012176054130708, 0.05273604020476341, 0.05551211356318422, 0.015299492249531406, 0.08825648669153452, 0.015018587233498693, 0.08276838010975293, 0.03176740144512483, 0.02343188033306173, 0.04004735393183572, 0.013352355437486299, 0.01879185431503824, 0.023367516197530285, 0.039504183256732564, 0.0900632015296391, 0.04828937291832907, 0.02667641426835741, 0.04360052291303873, 0.04165526479482651, 2.791568628379277, 20.850536482674734, 41.51945400238037, 31.270736013139995, 15.247993775776454, 27.527878659112112, 40.163196904318674, 42.11510917118618, 38.40596968787057, 2.5744306913443973, 0.16720168159476348, 1.724286784018789, 1.9149289599486758, 1.096344530582428, 1.3618289019380296, 3.945066434996469, 28.22420801435198, 40.737194538116455, 43.925413676670615, 43.17629017148699, 42.325326919555664, 41.88172960281372, 45.14285618918282, 44.57079362869263, 45.707723890032085, 46.123507567814414, 42.11789887292044, 44.21943017414638, 45.97760929380144, 42.40073224476406, 42.197865690503804, 44.47658995219639, 41.406368596213206, 40.428993293217246, 43.23141023090908, 43.19618286405291, 42.919991970062256, 44.2384751864842, 42.48056009837559, 35.66956411089216, 32.478259972163606, 33.33441005434309, 33.47900901521955, 31.507138047899517, 33.21988289696829, 35.318318775721956, 37.38326433726719, 35.262528215135845, 34.791561944144114, 34.16085658754621, 32.524771213531494, 32.60384518759591, 33.21193068368094, 32.55362360818045, 31.85215084893363, 31.988846233912877, 33.49466678074428, 38.573417799813406, 45.05699035099575, 45.20963879993984, 45.196635246276855, 43.15311098098755, 43.042290687561035, 40.27176250730242, 41.15898840767996, 39.89388820103237, 44.38367516653878, 44.46856130872454, 45.36059536252703, 38.80551889964512, 42.19203267778669, 45.89867080960955, 44.71025092261178, 45.07873126438686, 45.82752125603812, 46.298727239881245, 46.117883001055034, 44.40707669939314, 43.97555535180228, 41.9934218951634, 43.374484062194824, 40.00434718813215, 32.63584859030587, 31.9616197177342, 32.08544703892299, 32.87206997190203, 33.04907533100673, 34.43181201389858, 32.49039152690342, 32.946884700230186, 33.91747856140137, 34.1624025617327, 32.90350014822823, 33.597732884543284, 33.45913021905081, 32.524934496198384, 34.0299004146031, 34.237220764160156, 38.09873424257551, 45.16478817803519, 45.85956982203892, 45.70585829871041, 44.85725743430001, 47.11275039400373, 44.564265796116416, 46.14278187070574, 44.319133349827354, 43.51026228496006, 43.657800333840505, 47.06857374736241, 44.97645378112793, 44.61240986415318, 42.69636072431292, 37.667987619127544, 32.96988671166556, 33.30185774394444, 40.26070097514561, 46.732795102255686, 45.86801883152553, 47.03496878487723, 44.90005833762032, 46.844338008335654, 49.05147497994559, 40.02388204847063, 19.987142903464182, 3.384929805994034, 2.1856368567262376, 4.040471715586526, 5.3741002678871155, 3.319873605455671, 2.063292541674205, 0.13205014781228133, 0.18672970230025904, 17.87032209123884, 35.980607169015066, 22.31072994640895, 37.59938110624041, 41.3578736441476, 41.18148667471749, 12.872825043542043, 0.42553805293781416, 0.020150722470134497, 0.11505600756832532, 0.04097757115960121, 0.0018364367923433228, 0.049446610999958854, 0.03343212604522705, 0.07574540017438786, 0.03476889770744102, 0.037816310434469154, 0.047725177835673094, 0.04204042162746191, 0.056126157220985205, 0.07729090617171355, 0.031247921820197786, 0.02666860941930541, 0.03693989424833229, 0.03172877583918827, 0.036863816902041435, 0.07659108550953013, 0.03716039098799229, 0.004969305915957583, 0.01371018257590809, 0.11875941098800727, 0.016461683636797324, 0.037447903238769085, 0.031116428518933908, 0.03278356870370252, 0.0583454892039299, 0.05927818308451346, 0.004538509545714727, 0.04148551568921123, 0.021686111510332142, 0.018560975989592925, 0.03844788743715201, 0.08598029347402708, 3.7050951974732533, 27.162488528660365, 46.43385928017752, 37.9291912487575, 21.08470640863691, 29.82449279512678, 42.69390453611101, 47.23898179190499, 40.021849700382774, 2.554286560841969, 0.13982075798724378, 1.2649354040622711, 3.990786450249808, 2.029501497745514, 1.8087398580142429, 6.356381867613111, 29.406774044036865, 43.28744050434658, 45.31871509552002, 43.880729811532156, 43.06632798058646, 44.598464829581125, 45.708488191877095, 45.72873871667044, 46.81858798435756, 45.841626099177766, 41.718033518110005, 45.514508383614675, 46.32100316456386, 43.64257683072771, 42.594270842415945, 44.20952204295567, 41.67945711953299, 42.72393117632185, 43.629201548440115, 44.31728860310146, 43.812856333596365, 45.52258219037737, 45.05399220330374, 37.94226081030709, 35.26088496616909, 34.46220343453543, 34.81854179927281, 33.12133659635271, 35.15974003928048, 37.3030925478254, 38.5518227985927, 37.19568034580776, 36.196512017931255, 35.01263277871268, 34.44860233579363, 34.073423930576865, 34.42758403505598, 34.19432953425816, 32.83639792033604, 33.7127811568124, 34.72000592095511, 40.549002579280305, 46.481232098170686, 48.06787061691284, 45.75891126905169, 43.71335812977382, 43.33944429670061, 41.098507813044954, 41.372857434409006, 41.461446966443745, 46.016619954790386, 47.383813517434255, 46.72352620533535, 38.92115082059588, 42.55325215203421, 46.57718324661255, 46.88336256572178, 47.31699616568429, 47.36060653414045, 48.26462275641305, 46.709845202309744, 46.704050404684885, 43.687754017966135, 43.492513111659456, 47.56553670338222, 42.20736387797764, 34.638496603284565, 32.57929025377546, 34.17343977519444, 34.18809700012207, 33.39705153873989, 36.82311446326119, 34.40306036812918, 33.93711764471871, 35.10631186621529, 36.52086782455444, 33.858606474740164, 34.32919406890869, 34.5630704334804, 34.151108264923096, 35.558090686798096, 36.48954881940569, 40.83002247129168, 46.6162633895874, 47.02509192058018, 48.93040261949812, 47.15496417454311, 47.722979409354075, 46.93646764755249, 47.683833258492605, 44.06834854398455, 43.822111334119526, 44.7231502532959, 48.179813044411794, 46.746830463409424, 46.5339480808803, 44.84570605414254, 38.563579150608604, 34.262790134974885, 35.82977219990322, 43.336546897888184, 47.96079887662615, 47.174655369349885, 48.744892665318076, 46.270316055842805, 49.48886408124651, 49.895194734845845, 42.350298745291575, 21.400774751390728, 4.716636964253016, 2.9380529395171573, 6.07715938772474, 8.335892813546316, 7.828085456575666, 3.3464708753994534, 0.06655511832130806, 0.3879263683089188, 21.269219296319143, 43.434724943978445, 26.787469932011195, 43.24287475858416, 45.26234088625227, 45.62833377293178, 16.551515783582413, 0.2718775283013071, 0.05078916038785662, 0.08019305472927434, 0.058690673538616726, 0.01864557234304292, 0.046970032820744176, 0.023987856660304323, 0.04816970308976514, 0.05739332815366132, 0.019617205652009164, 0.010755399208781975, 0.013526610863794173, 0.015488784860021301, 0.043044297224176784, 0.07573125950459923, 0.0264914473186114, 0.11646703471030508, 0.07966955139168672, 0.14899788983166218, 0.18880610088152544, 0.09683772908257586, 0.1465741763157504, 0.14489835766809328, 0.17415298787610872, 0.13469122323606694, 0.10966647855405297, 0.13741392642259598, 0.09109310233699423, 0.26900067552924156, 0.10066744179597922, 0.0884093131337847, 0.1434261809502329, 0.1652224627988679, 0.1113360139674374, 0.16863258981278964, 0.20148057863116264, 3.814420325415475, 31.42400632585798, 53.2483606338501, 43.9493293762207, 24.591849599565776, 37.8295818737575, 50.31945868900844, 51.75803109577724, 46.633508818490164, 3.3654188300882066, 0.28666785465819494, 5.341680407524109, 8.01382383278438, 4.543657651969364, 2.344285075153623, 6.091249900204795, 32.82281766619001, 44.96877602168492, 47.39468744822911, 45.63040433611189, 43.45091772079468, 42.915864740099224, 46.37629345485142, 46.649718965802876, 47.8269487789699, 47.735260350363596, 42.19331462042672, 45.85233327320644, 47.143030643463135, 43.11791835512434, 43.080443246024, 46.02809837886265, 42.16608810424805, 43.83443743841988, 45.37840012141636, 45.748266628810335, 47.279316084725515, 46.504685742514475, 46.190359660557334, 39.00820132664272, 36.61731576919556, 36.02067743028913, 36.72452647345406, 34.24941485268729, 36.27699300221035, 39.31027773448399, 41.42539971215384, 40.52550377164568, 38.587439264569966, 37.969928537096294, 34.70870467594692, 34.81106206348964, 36.551964487348286, 35.884923526218955, 34.29027026040213, 35.390677315848215, 37.345278535570415, 42.11003351211548, 47.45904861177717, 50.372626304626465, 48.012364932468955, 46.91703006199428, 47.32999971934727, 43.8864620753697, 44.69291516712734, 44.11740630013602, 47.417519228799, 49.587900229862754, 49.03505638667515, 41.99791043145316, 45.418560709272114, 47.02556439808437, 48.05036810466221, 48.39490842819214, 49.15763650621687, 49.27362278529576, 49.60522208895002, 48.81675788334438, 46.11397811344692, 44.6921751839774, 47.93815469741821, 43.40746021270752, 34.97915288380214, 33.70123325075422, 36.57944113867623, 36.901340757097515, 35.65657445362636, 38.844300270080566, 36.02450588771275, 35.37146207264492, 37.45275674547468, 39.37285668509347, 35.83513968331473, 36.21878099441528, 36.1695008959089, 36.072900090898784, 36.74920647484915, 38.79110138756888, 42.1439893586295, 48.25227233341762, 49.239826747349326, 52.23762355531965, 47.46981831959316, 48.80335480826241, 48.631699562072754, 50.135915075029644, 45.79329095567976, 44.42557627814156, 43.99337748118809, 49.6352139881679, 48.649615492139546, 48.54001113346645, 46.95726013183594, 41.96098075594221, 36.675864764622276, 36.66911806379046, 45.2065885407584, 50.94931983947754, 49.51532629558018, 51.11157764707293, 47.84678588594709, 50.243448870522634, 50.96555430548531, 43.00075435638428, 23.157345363071986, 4.869690145765032, 5.158363912786756, 11.284907187734332, 14.579274824687413, 12.589394126619611, 5.2146521380969455, 0.3191444676901613, 0.5468069442680904, 22.340296268463135, 46.08429888316563, 33.479867117745535, 45.825624397822786, 52.21130377905709, 53.15584189551217, 21.00976661273411, 0.5480283073016575, 0.1304662028061492, 0.2187418716826609, 0.2069202581686633, 0.06240718625485897, 0.150316717635308, 0.05623288738674351, 0.13145020071949276, 0.13216610944696836, 0.1419416820364339, 0.1499345667128052, 0.12538151921970503, 0.13539878598281316, 0.14628289480294498, 0.15601548898432935, 0.1877001973667315], [0.047771202865988016, 0.0437463808006474, 0.039491226630551476, 0.007968217383937111, 0.037953398256961784, 0.01340689862679158, 0.02735506124528391, 0.04683005783174719, 0.0359185599455876, 0.05770846695772239, 0.03911464987322688, 0.036321239945079596, 0.0594024635585291, 0.03445360284032566, 0.04453056711437447, 0.021073095833084414, 0.020591352933219502, 0.06227871243442808, 0.044061621384961266, 0.02950747949736459, 0.6375156768730709, 9.198173812457494, 38.02221373149327, 36.89909996305193, 30.20046329498291, 27.23435548373631, 28.366465432303293, 38.41799007143293, 41.2113013948713, 5.531400101525443, 0.10787005030683108, 0.1575383794094835, 1.8560835804258073, 1.7733473628759384, 0.8006170934864453, 5.009401917457581, 23.770690645490372, 45.91609689167568, 45.88251972198486, 45.992857115609304, 46.291907582964214, 45.92255524226597, 46.32649918964931, 46.33130039487566, 47.48751538140433, 45.72230468477522, 46.64723151070731, 43.170008999960764, 45.944244044167654, 45.47578954696655, 42.47172893796648, 43.19604042598179, 41.36916446685791, 43.87558467047555, 44.28037282398769, 44.19323893955776, 45.12131677355085, 42.83888564790998, 39.023813928876606, 34.01454489571707, 33.0381875038147, 33.62403529030936, 31.545009204319545, 33.204878262111116, 34.10630628040859, 37.39402709688459, 38.14292825971331, 36.23077705928257, 33.659912313733784, 33.68199021475655, 33.45775447572981, 32.36270448139736, 32.676252365112305, 32.107570103236604, 31.002281938280376, 33.26356274741036, 32.68861321040562, 41.60200902393886, 46.26421553747994, 46.1056889125279, 46.18943555014474, 44.35032728740147, 44.526860169001985, 43.37700278418404, 42.06637103216988, 42.363041741507395, 41.961619990212576, 44.69398518971035, 46.4987485068185, 41.66621037891933, 39.852098260607036, 45.460190841129844, 45.50100108555385, 45.57380083629063, 44.904324531555176, 47.2739451272147, 44.33955410548619, 45.45006384168352, 44.81767007282802, 42.44432871682303, 40.886282035282676, 39.03074475697109, 33.4197929927281, 31.82129737309047, 32.58605432510376, 33.02925212042672, 32.183281149183, 34.31822286333357, 32.22052696772984, 32.0228020804269, 34.26365171160017, 32.64181709289551, 32.965613569532124, 32.67146853038243, 32.68748760223389, 31.857903957366943, 32.28241457257952, 34.37302677971976, 34.020086084093364, 39.40511022295271, 41.97245223181588, 44.27002348218645, 44.5123245375497, 41.69210284096854, 42.57366943359375, 45.412738118852886, 44.95540073939732, 44.6551273890904, 43.22268329347883, 43.65957907267979, 46.44421557017735, 45.96412631443569, 44.484979901994976, 42.557646887642996, 35.515102182115825, 32.62486696243286, 35.36549704415457, 39.34667934690203, 42.87838615689959, 43.79359245300293, 47.12971789496285, 47.12579911095755, 46.912089892796104, 37.28775439943586, 14.402879170009069, 2.2294100735868727, 1.436166918703488, 4.37596982717514, 4.415230189050947, 5.888778959001813, 4.505228468350001, 0.25115045479365755, 0.8502841198018619, 13.069074307169233, 30.557513850075857, 28.901461090360367, 33.44617182867867, 38.84069068091256, 29.274191992623464, 10.054966603006635, 0.1066398663180215, 0.04536645779652255, 0.024190921835335236, 0.02241710407127227, 0.047497451305389404, 0.036587076394685676, 0.042630183909620555, 0.06010702718049288, 0.01612360356375575, 0.0265769172858979, 0.03711435917232718, 0.04192458552175334, 0.012813262757845223, 0.024312600127554367, 0.036396835531507216, 0.017608323001435826, 0.053919897215174775, 0.06696414601589952, 0.05647784870650087, 0.028657034239066497, 0.05186109643961702, 0.01386765274219215, 0.07475671358406544, 0.050666138596300564, 0.029178067709186246, 0.027216877588736157, 0.08898510437990938, 0.07679388605590377, 0.031436893822891374, 0.010794380197434552, 0.014086409039529306, 0.04646463958280427, 0.01013513168852244, 0.06875062693974801, 0.012272814704504396, 0.051398749463260174, 1.1818112816129411, 15.35065862110683, 44.46722378049578, 40.42200687953404, 27.09156652859279, 30.81156430925642, 37.148915495191304, 42.880279541015625, 45.34914820534842, 5.837181202002934, 0.035275356245360205, 1.2130441942385264, 4.845758812768119, 3.0682005158492496, 1.8786739110946655, 5.719290682247706, 27.009176526750835, 44.89940173285348, 44.99137503760201, 45.84030246734619, 46.071545464651926, 45.951775891440256, 45.97200557163784, 47.34072078977312, 46.78683819089617, 45.973297936575754, 47.03539262499128, 44.299935477120535, 46.671935830797466, 45.19226482936314, 44.45240674700056, 42.81777702059065, 42.34372922352382, 44.28199870245797, 45.493156569344656, 44.5881085395813, 46.962704045431956, 44.460310322897776, 40.551170417240684, 36.229269300188335, 34.87755979810442, 34.68758910042899, 32.75430495398385, 34.48773806435721, 36.0562105178833, 39.42157745361328, 39.04162911006382, 37.40942430496216, 35.08381012507847, 33.88897010258266, 35.795528003147666, 34.34643949781145, 34.30061960220337, 34.33765697479248, 33.10785709108625, 33.993015902382986, 34.349614824567524, 43.02098403658186, 47.384688990456716, 47.73723016466413, 48.50558975764683, 46.05847937720162, 46.90902573721749, 43.75538083485195, 43.706816400800435, 44.88622794832502, 43.693687779562815, 45.4935873576573, 48.01525885718209, 42.446864809308735, 41.22410692487444, 46.399038382938926, 46.20448882239205, 47.5997565814427, 44.95633527210781, 48.22779730388096, 44.814574650355745, 47.24487386431013, 46.198516845703125, 44.27847596577236, 44.03803007943289, 40.75140013013567, 35.59133781705584, 33.04367658070156, 34.00413996832711, 33.96589708328247, 34.220326219286235, 35.03821952002389, 35.19538082395281, 34.501651832035606, 35.62958070210048, 34.43979549407959, 34.68362862723214, 34.01490272794451, 34.61778402328491, 34.54060343333653, 34.1175137247358, 34.22615228380476, 35.958970478602815, 41.440977573394775, 44.09058277947562, 46.50136450358799, 45.853125367845806, 42.91809858594622, 44.448081493377686, 47.51384210586548, 47.36501864024571, 44.18616567339216, 43.44077335085188, 44.82707098552159, 47.49238954271589, 47.59527151925223, 46.205016885484966, 43.29542051042829, 36.80578218187605, 34.01573998587472, 36.83314766202654, 41.902407441820415, 45.524155957358225, 46.02987016950335, 47.69861902509417, 48.43677479880196, 47.13394239970616, 39.20424822398594, 16.96357696396964, 2.862687566450664, 2.289444463593619, 5.72619936295918, 8.97261357307434, 6.102832981518336, 3.9969755581447055, 0.18351872531431063, 0.4461061049784933, 16.200357300894602, 36.72559649603707, 30.409479004996165, 39.94351570946829, 44.95747825077602, 39.61594288689749, 12.563862102372305, 0.2483517692557403, 0.008237421063573232, 0.0029857201110904236, 0.009295588791636484, 0.04776554388393249, 0.018246001730273877, 0.016003826865926385, 0.04400938775922571, 0.05076683658574309, 0.020355214265042117, 0.02255121142869549, 0.019590703770518303, 0.04505544448537486, 0.00413293601845258, 0.022059790923127105, 0.06083409780902522, 0.12020049723131315, 0.12159343462969575, 0.1644088178873062, 0.1326333758022104, 0.12171866505273751, 0.08872019752327885, 0.1037480179220438, 0.15180414782038756, 0.08141635158764464, 0.1432574157203947, 0.23820921778678894, 0.17849542200565338, 0.13119192314999445, 0.07989992760121822, 0.1333062925509044, 0.10428501732115235, 0.09384671957897288, 0.2266445926257542, 0.11169991908328873, 0.15505705827048846, 1.426241091319493, 17.890115771974834, 50.02713060379028, 48.34717082977295, 38.51499039786202, 38.96131488255092, 38.53086355754307, 48.46048552649361, 50.07825892312186, 7.756468636648996, 0.23877609308276856, 2.6226142772606442, 10.164812411580767, 4.128580084868839, 3.005400742803301, 7.972878098487854, 28.00810514177595, 48.713191509246826, 46.08277027947562, 47.114338057381765, 46.69761984688895, 47.392714159829275, 45.27185297012329, 47.4962214742388, 49.07403925486973, 48.144613470349995, 49.20369611467634, 46.284473010471885, 47.51064246041434, 47.34092228753226, 43.56466320582798, 44.284576484135215, 43.40303768430437, 45.48302609579903, 48.49418428965977, 47.46545832497733, 49.53857844216483, 47.52310405458723, 42.36237471444266, 37.793076038360596, 36.24598666599819, 36.10833937781197, 33.90112597601754, 36.431739807128906, 37.15497432436262, 41.63322033200945, 41.376515660967144, 39.58499561037336, 36.5786212512425, 35.76139497756958, 37.85326133455549, 36.42672668184553, 35.40354537963867, 35.24783277511597, 33.85188756670271, 35.74852691377912, 35.67465019226074, 44.60613216672625, 50.35005508150373, 49.871577807835166, 50.645506381988525, 47.28905398505074, 48.62110355922154, 47.02089173453194, 45.802959374019075, 46.63616303035191, 45.752400806971956, 48.132384640829905, 49.738783836364746, 45.64646509715489, 41.49232128688267, 47.214232308524, 47.35644456318447, 49.25181933811733, 44.976766450064524, 49.95705107280186, 46.12800652640206, 48.642076696668354, 46.88686793191092, 45.402663230895996, 45.72269030979702, 42.199390820094514, 37.9431779725211, 33.77204581669399, 37.25572320393154, 35.8420809337071, 35.113989625658306, 37.69572482790266, 35.85442788260323, 35.44739546094622, 38.00471469334194, 36.311230250767295, 36.76997464043753, 35.90358986173357, 36.04134832109724, 35.758862359183176, 35.49500451769148, 36.84167310169765, 38.04479537691389, 44.46756771632603, 46.39829839978899, 47.51624270847866, 49.09544665472848, 44.51296377182007, 46.35461507524763, 49.56501981190273, 49.58420031411307, 45.67270844323294, 45.08817734037127, 44.23391369410923, 48.79972784859793, 50.19470030920846, 49.12900645392281, 46.128287928445, 39.590168544224326, 35.81536858422415, 39.111726011548726, 43.832776818956646, 47.265826157161165, 47.26050383704049, 50.9795549256461, 50.157294682094026, 48.852023465292795, 41.795095988682334, 17.73728666986738, 3.4075572660991122, 6.059428019183023, 10.917856437819344, 13.185882210731506, 14.721818855830602, 11.196102261543274, 0.5446014340434755, 1.122810653277806, 18.873591593333654, 41.15420109885079, 38.51578596660069, 44.69451672690255, 51.6934232711792, 45.717903000967844, 15.45769909449986, 0.2817340094063963, 0.10527892863111836, 0.20149576424488, 0.08655986416020564, 0.15225461364856788, 0.10620711025382791, 0.144128573260137, 0.14057150270257676, 0.10348662587680987, 0.10568794954035964, 0.12778974856649125, 0.06726131721266679, 0.11013476271182299, 0.08980876446834632, 0.08780900641743626, 0.14531744803701127], [0.03737268763195191, 0.0295246430406613, 0.032388417050242424, 0.07603035774081945, 0.024699042784050107, 0.06623823568224907, 0.02551211602985859, 0.04362088574894837, 0.05992033505546195, 0.05286485668537872, 0.049703826662153006, 0.07037367591900484, 0.01885847288316914, 0.02877588982560805, 0.03299105453437992, 0.018952773983723352, 0.04698154416733554, 0.00947833014652133, 0.001991490737834413, 0.018728971082184995, 0.2729336273457323, 6.7128248895917615, 37.337288107190815, 42.43415655408587, 29.54787458692278, 19.820393085479736, 36.06399597440447, 34.645913805280415, 41.15914821624756, 8.1951961347035, 0.05987648812255689, 0.9169958915029253, 2.7092101105621884, 2.6763653244291032, 7.867354069437299, 11.24161730493818, 21.44395433153425, 44.79536288125174, 45.793013027736116, 46.11853960582188, 44.675975458962576, 43.50252546582903, 44.71280091149466, 48.0454557282584, 48.78745385578701, 47.5009115082877, 44.300390584128245, 46.138783182416645, 44.69352313450405, 44.94085121154785, 43.78857585362026, 42.99018267222813, 46.49469770703997, 44.727058615003315, 43.32743086133684, 44.29411288670131, 41.13633728027344, 38.4771157673427, 34.204984596797395, 32.14005987984793, 32.12483637673514, 34.49988004139492, 33.120843274252756, 33.07240738187517, 36.3505778993879, 38.14073610305786, 36.71182516642979, 35.9883439881461, 35.87155171803066, 34.46457624435425, 32.8049191066197, 32.558188574654714, 32.22273996898106, 31.86727360316685, 31.539759840284074, 32.98517622266497, 32.194370474134175, 39.48695305415562, 44.32197168895176, 46.26888472693307, 45.087746552058626, 43.41267483575003, 47.197594846997944, 44.450172901153564, 44.223248209272114, 41.23754474094936, 44.58598933901106, 43.501243523189, 47.7729925428118, 41.56461729322161, 37.95354468481881, 43.52582972390311, 43.464077608925955, 46.1053797176906, 46.807432651519775, 46.031308446611675, 44.34268079485212, 45.83538661684309, 45.14140401567732, 42.38121822902134, 40.474611691066194, 39.04654843466622, 34.24576357432774, 31.566367966788157, 33.2053542137146, 34.434577396937776, 33.57252829415457, 33.09787947790963, 33.11538893835885, 34.49429368972778, 33.070069313049316, 33.72392954145159, 33.78368057523455, 34.18870496749878, 32.64799056734358, 32.64944274084908, 33.01832955224173, 33.22952699661255, 33.40362106050764, 32.91565602166312, 35.79597963605608, 37.55446100234985, 39.90212181636265, 41.71976361955915, 41.8536936214992, 42.746669156210764, 41.80702951976231, 41.541160174778526, 45.558782305036274, 43.23316465105329, 43.90696620941162, 45.961267130715505, 44.35050099236624, 45.04697799682617, 42.08566965375628, 37.66227967398507, 34.65542588915144, 38.858276571546284, 38.582815238407676, 43.18631642205374, 43.409419604710166, 48.64267771584647, 45.99208239146641, 34.42805651256016, 11.093082189559937, 1.4363592969519752, 1.723692930170468, 2.870415700333459, 8.622017894472394, 2.8932177339281355, 2.0098003149032593, 0.04748388399769153, 1.7598352879285812, 25.338919912065776, 35.26536308016096, 19.56795460837228, 31.589140687670024, 37.841327803475515, 21.01188060215541, 4.703097530773707, 0.03234323340335062, 0.02262932268370475, 0.07323630659707955, 0.03080995460706098, 0.05986759252846241, 0.016592778298737745, 0.021452844741621187, 0.04611002021868314, 0.019574737841529504, 0.06438958059464182, 0.005639205728324929, 0.06233536332313504, 0.09121970340077366, 0.06333049599613462, 0.03579061198979616, 0.047180544917604754, 0.032313045380370956, 0.029032298031130006, 0.03868061816319823, 0.0368255814537406, 0.03139834964115705, 0.027621245444087044, 0.023100012248115878, 0.024141426098399928, 0.038298185648662705, 0.005674933141563088, 0.011678788677922316, 0.051735184088881524, 0.0260528219265065, 0.01764741170752261, 0.018992042501590083, 0.038414805462317805, 0.027314588327759078, 0.048361575829663446, 0.005843080480449966, 0.033687601265098364, 0.24338163595114434, 8.97902762889862, 44.27712801524571, 45.61712632860456, 36.04047284807478, 25.492035627365112, 39.012345927102224, 41.0163905279977, 47.00854131153652, 8.335680024964468, 0.06597062825624432, 0.46036375420434134, 5.260724340166364, 4.539672860077449, 7.451570391654968, 13.486722707748413, 23.148746967315674, 45.94192681993757, 46.954334940229145, 47.09043278012957, 44.88180889402117, 44.51091405323574, 44.16674893242972, 48.49063376017979, 49.61890309197562, 49.67189700262887, 46.70258086068289, 46.90664597920009, 46.57523775100708, 46.99051421029227, 45.95990875789097, 43.3971734046936, 46.63485329491751, 45.77594477789742, 45.537402697971885, 47.24802834647042, 43.548578126089915, 41.39177737917219, 37.046460832868306, 33.4121048109872, 33.54275526319231, 35.362359932490754, 35.020161151885986, 34.924355915614534, 37.948875495365684, 39.78351954051426, 39.25804465157645, 38.56421491077968, 36.740152972085134, 36.09038870675223, 34.08081333977835, 33.86947693143572, 34.32887445177351, 34.181291239602224, 32.68248837334769, 33.8780961717878, 33.48871912275042, 41.20697614124843, 44.55664014816284, 48.21969223022461, 46.95391457421439, 45.18381929397583, 47.30477428436279, 46.25260509763445, 44.0578602382115, 44.03832885197231, 45.23250184740339, 45.65180478777204, 48.50029870441982, 43.69441386631557, 39.909921169281006, 44.93729373386928, 45.086075510297505, 48.94631052017212, 46.85882500239781, 47.43405246734619, 45.970365796770366, 47.852806500026155, 46.83504131862095, 44.00063834871565, 41.5552476474217, 40.083931854793, 35.257365703582764, 33.372566086905344, 33.79908125741141, 35.373157433101106, 35.10397727148873, 34.74362284796578, 34.86154767445156, 35.61864423751831, 34.131965977805, 35.18503148215157, 35.5736893926348, 35.58249276024954, 34.00235775538853, 35.41094521113804, 34.625135217394146, 34.14440325328282, 34.95910733086722, 33.66341767992292, 36.72070149012974, 40.3490195274353, 42.15623555864607, 43.782072339739116, 44.41512271336147, 44.48125566755022, 44.64296456745693, 44.68328496388027, 45.996320792606895, 44.27440084729876, 45.403288568769185, 49.16986880983625, 47.926905563899446, 47.6677759715489, 44.04884147644043, 38.73342439106533, 36.2991612298148, 39.69861602783203, 41.44666467394148, 44.912471294403076, 45.03778900418963, 50.0242714200701, 48.905455112457275, 37.046457358769004, 12.955591985157557, 1.376429672752108, 2.8542604872158597, 6.865772979600089, 8.921631165913173, 5.594556186880384, 2.406002014875412, 0.023377385489376526, 1.9107852280139923, 23.383474486214773, 36.535601479666575, 26.04523730278015, 35.27794279370989, 44.50673123768398, 28.21825167110988, 7.167284846305847, 0.053827202546277216, 0.0416635022099529, 0.060625821485051086, 0.03507957175107939, 0.06899603269994259, 0.04978148838771241, 0.016557160299271345, 0.02659588403600667, 0.02067821898630687, 0.03398842637294105, 0.05819655076733657, 0.025637134410707012, 0.05627534671553543, 0.03413803655920284, 0.0844699288053172, 0.06867471922721181, 0.16181332644607338, 0.13254205855940068, 0.11223601603082248, 0.1805484246994768, 0.10116378337677036, 0.13008809595235757, 0.11148686587278332, 0.10309496867869582, 0.10230625314371926, 0.11792926410479204, 0.23078436191592896, 0.14518216172499315, 0.11686314988349165, 0.0698193060234189, 0.10165606053279978, 0.14710422073091778, 0.11137032748333045, 0.1786069595920188, 0.13224920284535202, 0.12513773515820503, 0.44792683156473295, 11.050567030906677, 50.135324478149414, 53.21950476510184, 40.94049188068935, 30.560477256774902, 46.187851360866, 44.58701419830322, 49.72794812066214, 10.599635890551976, 0.23808249458670616, 2.61990339415414, 8.776113305773054, 6.156571217945643, 13.672454135758535, 16.11101736341204, 26.715700251715525, 48.40566771371024, 46.5427896635873, 47.336082867213655, 46.013514110020225, 43.60270459311349, 45.12003135681152, 50.30370364870344, 51.70299094063895, 52.04389040810721, 47.767739704677034, 49.46488584790911, 47.98269959858486, 48.69642898014614, 46.58620548248291, 45.20186723981585, 50.199372972760884, 48.7686311858041, 48.340573515210835, 48.42926379612514, 44.53373541150774, 41.558756487710134, 38.57952526637486, 35.469963209969656, 34.902799129486084, 37.92071097237723, 38.00332852772304, 37.510343415396555, 40.597719873700825, 42.0194776398795, 39.68030057634626, 41.01817968913487, 39.68982655661446, 38.38068519319807, 34.7526798248291, 34.5978079523359, 35.35796519688198, 35.71725307192121, 33.82919822420393, 35.66596494402204, 36.196015221732004, 44.19315208707537, 47.17916475023542, 50.971946648189, 49.877237115587505, 44.736379623413086, 51.572740009852815, 49.04607622964041, 47.34663370677403, 45.423851762499126, 47.50735248838152, 46.91616153717041, 50.43352031707764, 45.219383648463655, 41.0112384387425, 45.62119102478027, 44.45863928113665, 50.52472931998116, 48.6933787209647, 48.27638258252825, 47.56757599966866, 49.47723627090454, 47.137902872903005, 45.08442531313215, 43.01254544939314, 42.01643085479736, 36.814509119306294, 35.11861712591988, 34.89822374071394, 37.886320863451274, 36.58697993414742, 35.33369861330305, 36.06083801814488, 37.871392658778596, 35.64811502184187, 36.71866566794259, 37.26361983163016, 37.46062558037894, 35.6739901133946, 35.84372418267386, 36.515826906476704, 35.768336227961946, 35.83578586578369, 35.509255273001536, 37.85097885131836, 42.14316599709647, 43.21150016784668, 46.29419354030064, 45.656453132629395, 46.345794337136404, 46.5059676851545, 44.5945634160723, 48.54032727650234, 44.33978339603969, 46.33387122835432, 48.95271328517369, 50.24044377463204, 50.01959180831909, 46.52393225261143, 42.218463625226704, 38.839985438755576, 41.415467262268066, 42.907728399549214, 47.24342169080462, 46.47712571280343, 52.12065063204084, 48.95722961425781, 40.60461596080235, 14.344400525093079, 2.9953060959066664, 4.214643946715763, 10.156616142817906, 17.310667276382446, 10.296701380184718, 5.999479396002633, 0.10288724196808678, 2.434431003672736, 31.353270190102712, 44.78557981763567, 30.447336265019008, 41.88593326296125, 48.299127510615754, 37.886887141636436, 8.378579940114703, 0.10974640319389956, 0.1819153470652444, 0.2423880435526371, 0.09239488534097161, 0.19102774666888372, 0.08225799285407577, 0.09040342577333961, 0.1640776385154043, 0.09507872204163245, 0.06999233923852444, 0.2102664943252291, 0.18654746136495046, 0.14143169511641773, 0.11465088145009109, 0.25734319963625496, 0.13427510485053062], [0.02631502821376281, 0.014520768142704452, 0.03570297919213772, 0.04805657094610589, 0.018328852552388395, 0.06854857278189488, 0.016352025592433553, 0.0595725519316537, 0.032723189265068085, 0.010347689568464245, 0.023218983185610602, 0.031336039770394564, 0.033911100522215874, 0.05424151602866394, 0.0648853929181184, 0.04359930155000516, 0.020337002385141592, 0.0704649660204138, 0.029797716066241264, 0.029435575141438415, 0.08640092411743742, 5.98102411202022, 29.425502913338796, 41.16391468048096, 30.50294269834246, 20.379245383398874, 24.11987931387765, 26.730209827423096, 39.64475359235491, 17.78277826309204, 0.11397652620715754, 0.6554277528609548, 3.996378447328295, 10.1959342615945, 9.085075378417969, 11.524853672300067, 27.49514048440116, 45.08213240759713, 47.84655659539359, 51.4119656426566, 46.162184715270996, 46.708775179726736, 44.66778005872454, 46.151018960135325, 45.10103498186384, 46.00448145185198, 44.4039534841265, 44.95608861105782, 44.10107108524868, 45.44753817149571, 45.8045539855957, 44.748452118464876, 44.90265348979405, 43.70502723966326, 41.22710854666573, 39.41593551635742, 34.85907064165388, 33.48392833982195, 32.43670974458967, 33.1812231200082, 34.02380337033953, 33.46552603585379, 31.80332933153425, 32.833246912275044, 34.9983229637146, 35.77921710695539, 38.360820293426514, 36.677949224199565, 36.746010303497314, 33.45955753326416, 32.41718530654907, 33.285307134900776, 32.25035558428083, 32.60678774969918, 33.81553111757551, 32.08126769747053, 31.92529453550066, 33.39067309243338, 42.6300436428615, 45.72347893033709, 44.36386932645525, 45.231414454323904, 42.1231621333531, 42.91055979047503, 45.06576592581612, 43.0025053024292, 44.03987830025809, 44.38580478940691, 46.059393065316335, 40.8758111000061, 38.33147457667759, 43.1979546546936, 42.0121750831604, 43.2635178565979, 43.44754089627947, 45.195151805877686, 45.36316967010498, 44.06990146636963, 45.008408546447754, 42.41513238634382, 39.61513342176165, 39.091041224343435, 33.51791892732893, 32.12896013259888, 30.976306097848074, 31.96827609198434, 32.72601188932146, 35.38574062074934, 33.910314968654085, 35.837443011147634, 33.42764098303658, 32.92486238479614, 32.89566258021763, 33.231726101466585, 32.499980040958945, 33.78613676343645, 33.035099029541016, 33.0598589352199, 32.43821750368391, 31.668489115578787, 32.267156328473774, 33.302507400512695, 32.800652912684846, 32.84353024618966, 35.46325472423008, 40.05273791721889, 42.358358655657085, 42.82206058502197, 43.99492692947388, 45.92556381225586, 44.932912894657676, 42.24766342980521, 46.413282190050396, 46.23052372251238, 43.91686044420515, 41.25713866097586, 41.419917583465576, 42.69317150115967, 44.525772775922505, 43.63189050129482, 46.397572313036235, 46.62710952758789, 41.56311648232596, 22.449018205915177, 11.83062652179173, 0.5799372036542211, 2.395134163754327, 5.63068334545408, 8.707316585949489, 3.3301552023206438, 2.005531732525144, 0.07082874221461159, 1.2593835762568881, 25.906087466648646, 33.01523412976946, 23.167663437979563, 35.99901294708252, 37.248775005340576, 21.175990104675293, 1.6987788613353456, 0.05107891519687005, 0.07930923572608403, 0.02917194732331804, 0.023100694175809622, 0.09560998103448323, 0.013152601513346391, 0.019569562315674763, 0.04843406033303056, 0.008739381762487548, 0.08858409696923834, 0.08658189619226114, 0.0054783628189138, 0.01038035424426198, 0.047220992390066385, 0.008906420968872095, 0.02926115771489484, 0.07461016359073774, 0.01966873529766287, 0.013794633892497845, 0.07383361418864556, 0.04768576852178999, 0.03789342933201364, 0.014540306558566434, 0.05173148946570499, 0.03335219122735517, 0.10159106366336346, 0.016930765073214258, 0.018702318226652484, 0.009725079406052828, 0.036030460548188, 0.019750790537468026, 0.07664943273578372, 0.16900639475456306, 0.016881442362708703, 0.034231060317584446, 0.029641971923410892, 0.19214587738471373, 7.876748902457101, 36.100289889744346, 48.239848954336985, 33.16907072067261, 22.557847840445383, 34.330243246895925, 32.33022165298462, 44.19066463197981, 17.88017463684082, 0.09087386088711874, 0.5032464074237006, 5.391403453690665, 10.060493894985743, 12.191644498280116, 13.861979280199323, 30.31651210784912, 46.08226306097848, 47.86496932165963, 49.604141644069124, 46.679971422467915, 45.68833146776472, 44.685046332223074, 48.27308218819754, 47.28906788144793, 47.31877837862287, 46.74092449460711, 46.614495073046, 44.93782179696219, 45.63601500647408, 48.16945675441197, 46.752507141658235, 46.99557597296578, 45.45002562659127, 43.483268533434185, 42.45917354311262, 37.29703719275338, 35.7585323197501, 33.41530793053763, 34.27376134055001, 35.39205305916922, 34.748232977730886, 34.38512706756592, 34.70600530079433, 37.228552273341585, 38.101266860961914, 39.86298956189837, 38.43678147452218, 38.96078334535871, 35.22177703039986, 34.04029491969517, 34.45916707175118, 33.81446804319109, 33.4762019429888, 36.42388139452253, 33.075349943978445, 34.57258946555001, 35.73068393979754, 44.91399294989449, 47.55224132537842, 44.84056438718523, 45.895478112357004, 44.66701923097883, 44.29981388364519, 47.11324371610369, 45.83673109327044, 44.06802545275007, 45.79388502665928, 46.34734378542219, 41.91528592790876, 38.77629477637154, 44.02550595147269, 43.60650178364345, 43.01595006670271, 44.314460686274934, 47.09871155875069, 46.8448417527335, 46.30938925061907, 47.61702285494123, 43.67406954084124, 41.830170495169504, 40.74519886289324, 35.34796673910958, 34.149572713034495, 32.49893781117031, 33.43596145084926, 35.18589653287615, 36.284201758248464, 35.51314279011318, 36.06724425724575, 34.132712909153526, 34.66564668927874, 36.16317803519112, 35.381345885140554, 34.05967344556536, 34.9243072782244, 34.943633692605154, 35.31762742996216, 34.41143642153059, 32.44638858522688, 33.89529991149902, 35.2351245198931, 34.99330636433193, 35.886340958731516, 39.02313647951399, 41.63592318126133, 43.9706985609872, 45.1221262386867, 45.943114961896626, 46.61183043888637, 45.31523404802595, 44.14990302494594, 47.4273544039045, 48.353615283966064, 45.95825161252703, 43.87927416392735, 41.60353762762887, 44.03982271466936, 45.43176576069423, 45.51379271915981, 47.058898380824495, 49.76477357319423, 42.79722077505929, 27.310542481286184, 14.506720866475787, 1.6318541382040297, 3.872093413557325, 10.262357303074428, 5.442561302866254, 5.0391658289091925, 2.53625533410481, 0.08053327218762465, 1.6773461656911033, 29.248344693865093, 39.12454196384975, 24.70998808315822, 37.98275143759591, 42.40408475058419, 28.226424489702495, 2.41481927888734, 0.040173300209322145, 0.035652445296623876, 0.05319246017773237, 0.025887547759339213, 0.12922394089400768, 0.019585726716156517, 0.02920392667874694, 0.04910970139982445, 0.018886387813836336, 0.03235825277598841, 0.1083322615761842, 0.04599703735272799, 0.06768608013434069, 0.054918212217411826, 0.033974275525127134, 0.03890357119962573, 0.154300328876291, 0.1231568335954632, 0.09235117411507027, 0.15947470122150012, 0.09217293653637171, 0.1278121673635074, 0.11978522022919995, 0.1970319537711995, 0.14032755579267228, 0.14564619825354644, 0.1265300211629697, 0.1077890128695539, 0.08847521245479584, 0.06312283035367727, 0.09627394112093107, 0.16759770177304745, 0.4200443891542298, 0.16073617924536976, 0.1008013913940106, 0.06813063592250858, 0.3075440430215427, 9.746243374688284, 41.310761383601594, 53.951893533979145, 40.33138152531215, 30.34191472189767, 34.29302522114345, 36.012204102107454, 50.0768449647086, 23.694791998182023, 0.30267761700919693, 1.6897419691085815, 9.929118224552699, 18.42083133969988, 15.527476378849574, 18.209764174052648, 34.31148658479963, 48.979800837380544, 48.96808964865548, 52.53605215890067, 47.796477454049246, 47.08128547668457, 44.875426973615376, 49.511685439518516, 49.34503289631435, 50.48664971760341, 49.05401454653059, 48.1227023260934, 46.62228052956717, 48.758191517421174, 50.44241748537336, 48.20982231412615, 48.80942753383091, 46.94094576154436, 45.05605581828526, 43.56900235584804, 38.69819355010986, 38.626634052821565, 35.071303367614746, 36.310309614454, 36.29394660677229, 37.68202992847988, 35.820600577763145, 36.660474504743306, 39.239246300288606, 39.9780968938555, 42.8818359375, 41.370574951171875, 40.15297263009207, 36.77048533303397, 35.7397061756679, 36.59519965308053, 33.916405064719065, 35.80241019385201, 37.108928612300325, 34.58617319379534, 35.106357029506135, 36.72974804469517, 46.452171257564, 49.6288285936628, 46.758235931396484, 48.36164392743792, 45.78684997558594, 46.827370507376536, 49.623033796037944, 48.25701100485665, 46.93049914496285, 47.04738868985857, 48.8096707207816, 44.07712064470564, 39.97246190479824, 43.42192983627319, 45.075972829546245, 44.090624468667166, 45.19245590482439, 48.02369049617222, 48.64881297520229, 46.579896518162315, 48.7869223185948, 45.64232397079468, 44.47862924848284, 41.88636405127389, 37.49776717594692, 34.71546874727522, 33.94086272375924, 34.78810868944441, 37.23169980730329, 38.964368615831646, 36.881892749241416, 39.48093938827515, 35.509425503867014, 36.370956965855186, 38.33482708249773, 37.026377064841135, 35.80269506999424, 37.00425052642822, 36.48280211857387, 37.3304580279759, 36.461005619594026, 35.36047697067261, 35.92341307231358, 37.6520345551627, 36.473321301596506, 35.884075845990864, 40.31226008278983, 43.667798791612896, 45.508366176060264, 47.35014254706246, 47.719036306653706, 48.74004282270159, 45.88309989656721, 44.21800579343523, 49.66540738514492, 50.21383217402867, 48.861205509730745, 45.721675872802734, 44.92976883479527, 47.00176681791033, 48.52634055273873, 48.32196623938424, 50.711646284375874, 50.054221630096436, 45.564757755824495, 28.922243152345928, 16.936119420187815, 1.421945041843823, 6.286341854504176, 13.886674915041242, 17.32329215322222, 11.264427372387477, 4.960170456341334, 0.23380620405077934, 1.740844992654664, 32.775785309927805, 44.36903531210763, 34.336194378989084, 44.802304131644114, 48.42672422954014, 35.76786722455706, 3.4150615377085547, 0.18406267969736032, 0.11839765682816505, 0.11270862245666129, 0.16285345277615956, 0.2595711557992867, 0.08584663564605371, 0.1361335308424064, 0.1493191354508911, 0.11031743112419333, 0.22238347413284437, 0.15558438854558126, 0.10515411889978818, 0.14286497820700916, 0.18033965304493904, 0.09721795296562569, 0.12881250440010003], [0.031226931339395896, 0.0024881455049450907, 0.02976562814520938, 0.04563441127538681, 0.023152982084346668, 0.018304671260661314, 0.0644183097673314, 0.015146825263010604, 0.031971894936369996, 0.029939852189272642, 0.045671744272112846, 0.018974342915628637, 0.0415977827007217, 0.026087584971849407, 0.027534208060907464, 0.04665881934176598, 0.05182687113327639, 0.027971286393169845, 0.013703384503190006, 0.02786962149132575, 0.023828672344929407, 2.566285014152527, 24.538258143833705, 40.343054498944966, 44.365064416612896, 36.25940016337803, 33.71019990103585, 33.669764859335764, 40.642542702811106, 25.26061545099531, 0.5197187406676156, 0.24878475602184022, 6.767725212233407, 10.143322501863752, 4.352739827973502, 7.920031837054661, 22.74911090305873, 41.493148122514995, 45.0991415977478, 47.90697465624128, 44.852744579315186, 46.57907315662929, 49.7079963684082, 45.75289760317121, 43.75504732131958, 40.45166526521955, 41.50230584825788, 41.94262708936419, 41.51247453689575, 42.98149394989014, 43.886924130576, 41.22174106325422, 41.551356656210764, 36.954188755580354, 33.59397043500628, 31.537255014692033, 32.59748411178589, 33.689615862710134, 33.64641196387154, 32.08491202763149, 32.4752652985709, 32.396462304251536, 32.49166304724557, 32.34010199138096, 34.898314067295615, 34.99789564950125, 35.77328334535871, 34.711032322474885, 34.386794635227744, 33.74162312916347, 33.486735412052695, 33.31411436625889, 32.708401679992676, 32.53755242483956, 33.65954753330776, 32.74421616962978, 31.975248609270366, 33.24002225058419, 40.47416353225708, 43.14196259634835, 44.142461504255024, 40.54098435810634, 43.16542318889073, 45.33879886354719, 41.8812050138201, 45.6522216796875, 45.43426363808768, 45.09189462661743, 48.333378655569895, 41.33695956638881, 37.913734980991904, 41.49043485096523, 40.66406127384731, 43.91847242627825, 41.96924563816616, 43.63285977499825, 45.04807581220354, 45.66247722080776, 43.266627175467356, 40.764188289642334, 39.27498088564192, 39.560697759900776, 33.53143664768764, 32.0254910332816, 32.03458969933646, 33.08973618916103, 32.8511871610369, 33.794481549944194, 33.412490436008994, 38.80148547036307, 32.6831762450082, 34.71938405718122, 33.346076079777305, 34.122724873679026, 33.577204431806294, 33.393987383161274, 32.82377651759556, 33.07891089575631, 32.18414272580828, 33.28387580599104, 32.02930906840733, 33.66932017462594, 30.76186384473528, 33.15727267946516, 34.523639406476704, 34.656495911734446, 38.00381142752511, 42.83575201034546, 42.70532390049526, 46.321691036224365, 44.33932828903198, 41.94842883518764, 44.014510427202495, 45.99094983509609, 45.27887412479946, 44.85768127441406, 45.548981870923726, 45.065904889787944, 45.52841172899519, 46.40324204308646, 48.94467074530465, 47.5992111478533, 41.50264630998884, 15.192147629601614, 4.425569108554295, 3.9570390496935164, 7.614435298102243, 10.597088507243566, 3.040043158190591, 4.924018110547747, 1.6737619808741977, 0.08047390037349292, 1.8233847064631326, 24.81353361266, 29.823096207209996, 25.16685472215925, 42.157545294080464, 37.843196868896484, 15.506011656352452, 0.3625379763543606, 0.06121230644306966, 0.021783608510824184, 0.004950848067112799, 0.025988215214705894, 0.01663326139428786, 0.009306575969925948, 0.0582871012655752, 0.03865058620327285, 0.014210475775014077, 0.04469515935384801, 0.042944030104471106, 0.011419797798485627, 0.05102594875331436, 0.10060944740793534, 0.04781917189913137, 0.04384511782388602, 0.09327380532132727, 0.05485455545463732, 0.021857295717511858, 0.022236164226861935, 0.044867089949548244, 0.03927042455013309, 0.013565797109289892, 0.029652970976063182, 0.046959067694842815, 0.03811642308054226, 0.05211766410086836, 0.029543597916407243, 0.02450560262825872, 0.02763260920931186, 0.037808137480169535, 0.014506942991699492, 0.04777890084577458, 0.04337807199252503, 0.07146218179592065, 0.004777280929764467, 0.03939765325880476, 3.950675368309021, 30.001696177891322, 46.242884567805696, 45.329773153577534, 35.33730820247105, 30.864412307739258, 34.62935624803816, 44.16575534003121, 27.378330843789236, 0.3562120215169021, 0.04043042766196387, 7.187058550970895, 16.45671108790806, 6.868763744831085, 10.986706137657166, 27.894585473196848, 43.70644119807652, 47.28817156382969, 49.3792736189706, 47.769508021218435, 46.3524055480957, 50.13639102663313, 47.330586842128206, 46.48826020104544, 43.98359094347273, 42.24759047372, 43.488233021327424, 43.852242197309224, 46.500447341373985, 46.84078400475638, 43.60831873757498, 43.95143815449306, 39.140693051474436, 35.77616337367466, 34.33589560644967, 33.86387668337141, 34.63038805552891, 34.922736985342844, 34.441504750932964, 33.90496138163975, 34.52000549861363, 34.85939373288836, 33.90655599321638, 36.439028467450825, 37.47347974777222, 38.86178888593401, 36.45234816414969, 37.557035309927805, 35.83590398515974, 34.95598064150129, 34.06522158214024, 34.0991461617606, 33.917287485940115, 35.16283893585205, 34.23238481794085, 33.357954025268555, 34.73196724482945, 41.31287016187395, 46.74925538471767, 45.74738073348999, 42.79072420937674, 44.018300669533865, 45.4012770652771, 44.97367797579084, 45.92365305764334, 46.77036401203701, 45.60347659247262, 49.785482679094585, 42.23349257877895, 38.53923961094448, 40.73595428466797, 41.41853836604527, 43.4304552759443, 41.88129186630249, 44.24395036697388, 46.354729720524375, 46.95047174181257, 45.09788397380284, 42.28221682139805, 42.17455448423113, 40.24031148638044, 36.085017749241416, 33.52091360092163, 33.51658139910017, 33.54215771811349, 33.67371491023472, 34.158449036734446, 35.08396298544747, 39.170268058776855, 34.55909606388637, 35.099624225071494, 35.39578424181257, 34.9797226360866, 35.262837409973145, 35.57509292875017, 34.862617697034565, 33.93941055025373, 32.84297786440168, 34.345654351370676, 34.44039303915841, 34.084280490875244, 32.85361903054373, 33.77872998373849, 36.1693480355399, 37.079054832458496, 40.64552695410592, 44.37468767166138, 44.490774699619834, 47.16772106715611, 45.12836572102138, 41.47260924748012, 45.93364109311785, 47.67427601133074, 46.4357213973999, 45.774774006434846, 48.18646594456264, 46.42778308050973, 47.16136693954468, 48.105964115687776, 51.36343594959804, 47.41450718470982, 42.69524553843907, 18.449282475880214, 8.330527935709272, 6.75757953950337, 9.637814998626709, 7.850787826946803, 1.6798413289444787, 1.4601801101650511, 1.5976142840726035, 0.07727154078228132, 2.1253920665809085, 28.65537326676505, 34.158455984933035, 29.01717291559492, 46.416110106876914, 43.849619252341135, 20.452929292406353, 0.6529402434825897, 0.10007824948323624, 0.03715940711221524, 0.047173077639724524, 0.0813261064301644, 0.07021582831761666, 0.043983440580112595, 0.030670973671866313, 0.017726605225886618, 0.022569818555244377, 0.006345210813118943, 0.022696668980643153, 0.01794328011705407, 0.0372157085553876, 0.07088710979691573, 0.009475127461233308, 0.03442669214148607, 0.18484888465276786, 0.12458187927092824, 0.09108777583709785, 0.12928918882140092, 0.0938696540626032, 0.10139247003410544, 0.21674492955207825, 0.07987170054444245, 0.14610380227012293, 0.1046113655237215, 0.12036344063069139, 0.10703514689313513, 0.13460082880088262, 0.09204527695796319, 0.20597914366849832, 0.11198743472674064, 0.111812942661345, 0.06864321484629597, 0.13340743498078414, 0.0820192638784647, 0.1738525325698512, 4.776653332369668, 36.67639977591378, 52.471711839948384, 53.958271980285645, 45.944605350494385, 43.13950293404715, 44.193207672664094, 49.11662823813302, 32.03743846075875, 0.6709510598863874, 0.8930338344403675, 12.396227257592336, 16.50758753504072, 9.0620698928833, 12.737291744777135, 29.783984797341482, 46.07903562273298, 50.810783181871685, 54.79764911106655, 47.3904698916844, 46.3712351662772, 53.50617354256766, 49.58934545516968, 48.834725924900596, 45.726393699645996, 46.09741013390677, 45.493986879076274, 45.57627786908831, 46.61003085545131, 48.75960200173514, 45.38472645623343, 45.74961805343628, 40.71547099522182, 37.47292389188494, 34.35720920562744, 35.892521381378174, 37.99154090881348, 36.50597436087472, 35.89445645468575, 35.61535079138619, 36.45227868216378, 36.58186953408377, 35.96658223015921, 39.025297369275776, 40.71905973979405, 41.16153839656285, 39.200374603271484, 39.16581078938076, 38.49474682126726, 37.07319055284773, 36.07242413929531, 35.64238970620291, 35.216221945626394, 36.41176373617989, 36.106981004987446, 35.561596052987234, 35.607673031943186, 44.34049211229597, 47.81404250008719, 47.55611842019217, 44.653765542166575, 45.35551275525774, 48.19691603524344, 46.374306270054404, 48.80663088389805, 48.250378949301584, 48.10333769662039, 51.33948203495571, 43.904669829777305, 39.55698047365461, 40.438331672123496, 41.86895186560494, 45.06376831872122, 42.19276918683733, 44.17751864024571, 47.39059495925903, 47.71808787754604, 46.127745968954905, 45.425435951777864, 41.53790494373867, 42.5584146635873, 37.94773599079677, 34.68260029384068, 35.09656006949288, 36.27452291761126, 36.312234265463694, 36.23568248748779, 36.83992215565273, 40.728078501565115, 35.68220288412911, 37.78402253559658, 36.81316811697823, 37.370764528002056, 36.666258880070274, 37.228253500802175, 37.039794036320274, 35.663779735565186, 34.8266190801348, 35.54835278647286, 35.581714562007356, 37.62126793180193, 33.73104797090803, 35.7208696092878, 39.362583773476736, 38.267050879342214, 41.608314514160156, 47.22599560873849, 46.21860408782959, 51.04855053765433, 44.998719283512656, 42.87790673119681, 46.50146177836827, 49.50268752234322, 47.65384135927473, 48.853360993521555, 50.684350286211284, 49.721006870269775, 49.275575229099815, 49.71114042827061, 54.259236676352366, 48.88105651310512, 45.34201240539551, 20.58427456447056, 8.462475964001246, 7.004379553454263, 16.42097302845546, 19.319009338106426, 11.433954732758657, 11.46028927394322, 4.206186251980918, 0.139462002952184, 2.616141161748341, 32.74377843311855, 42.065773487091064, 36.414855684552876, 52.0507413319179, 48.95797307150704, 26.12752308164324, 1.372461817094258, 0.21842114175004618, 0.1160505363451583, 0.1736847580011402, 0.1775431659604822, 0.19465336283402784, 0.09944856220058032, 0.144168742533241, 0.08782349992543459, 0.16303965635597706, 0.0763860729389957, 0.12421287835708686, 0.10267133891050305, 0.10541644732334784, 0.1922185756266117, 0.15420736957873615, 0.12984667319272244], [0.02787726349197328, 0.034577822246189625, 0.031766990931438546, 0.08304385175662381, 0.004289206450006792, 0.03208076588011213, 0.038027202510940175, 0.06396869210792439, 0.03998568527666586, 0.007569218436921281, 0.006649557093624026, 0.06085401959717274, 0.038913582983825884, 0.04832798834624035, 0.011538716149516404, 0.015634888716574227, 0.036077109830720086, 0.014729051252028771, 0.04183245064424617, 0.06350771577230521, 0.04303888251472797, 1.0184988677501678, 19.853971992220195, 41.50408806119646, 46.15974242346627, 57.40184783935547, 63.962489809308735, 50.83963557652065, 37.29746103286743, 23.77106932231358, 1.082176719393049, 0.276258720351117, 3.6435224328722273, 8.735875419207982, 7.136549489838736, 7.421674030167716, 17.020849227905273, 36.59395245143345, 40.13264914921352, 35.28605134146554, 47.46697998046875, 46.84698179789952, 47.44683020455496, 48.149723870413645, 43.998939514160156, 37.910702092306956, 34.9459022794451, 33.70446068899972, 34.43739141736712, 34.32318040302822, 34.20112487248012, 33.965309960501536, 33.384037562779014, 31.956325190407888, 32.71124349321638, 33.977167061397004, 33.11716420309884, 32.53827503749302, 33.257385798863, 33.370113372802734, 35.03429378782, 34.50479589189802, 35.41054221561977, 32.596570423671174, 34.40808391571045, 33.70073645455496, 35.632943630218506, 33.22104672023228, 34.877802985055105, 33.58644206183297, 33.483942236219136, 32.67778444290161, 33.72304017203194, 32.20261798586164, 32.99603278296334, 32.78491871697562, 32.92667586462838, 32.23790441240583, 38.818692684173584, 44.1357912336077, 45.44656889779227, 42.75604575020926, 43.15031433105469, 43.24815886361258, 43.21411269051688, 44.3330888066973, 45.577511174338206, 45.81240545000349, 44.484413623809814, 40.916124548230854, 37.85054111480713, 41.155628953661235, 40.36680691582816, 40.678642068590435, 42.68019226619175, 42.59250947407314, 41.81248385565621, 44.38176441192627, 45.064035824366975, 42.95522975921631, 41.76072672435215, 38.50314719336373, 34.588243756975444, 32.86706032071795, 33.91163165228707, 32.398331369672505, 32.26310205459595, 33.098761899130686, 34.473671436309814, 33.595419134412495, 33.98784644263131, 33.20019865036011, 32.43126930509295, 35.187668323516846, 33.81153242928641, 32.36804069791521, 33.07931389127459, 33.58616413388933, 32.978186334882466, 32.62354680470058, 32.33653061730521, 31.06506586074829, 30.93673610687256, 32.46178579330444, 33.2092729977199, 34.7989478792463, 35.5551689692906, 38.69077287401472, 42.448577540261404, 43.45016731534685, 42.55799429757254, 43.57206998552595, 41.39212131500244, 45.48098332541329, 45.06643295288086, 49.08840812955584, 44.03279113769531, 46.525162083762034, 46.99767085484096, 47.457183020455496, 47.77088029044015, 42.586287362234934, 26.928989103862218, 14.410949502672468, 7.076178763593946, 6.060574037688119, 6.4035844547407965, 3.1435845621994565, 1.1339365648371833, 1.3952294353927885, 0.9870242880923408, 0.03761979990771838, 2.4810935854911804, 29.21284634726388, 33.21112469264439, 29.004080772399902, 38.501761027744834, 34.641522543770925, 10.387840032577515, 0.2699884596679892, 0.04666340623849204, 0.022850616702011654, 0.027238041095967804, 0.05012977023475936, 0.01616866677068174, 0.054153238622737784, 0.02606794816840972, 0.05451583755867822, 0.027037208301148245, 0.031108815356024673, 0.018429235023047243, 0.06297418368714196, 0.03708441202927913, 0.039848349788891416, 0.03405663949836578, 0.07935179344245366, 0.017154908938599483, 0.08199694686170135, 0.05612833531839507, 0.03331309064690556, 0.07221665845385619, 0.034903013546551974, 0.022639738196241002, 0.0760007125458547, 0.0737195320959602, 0.04926697224644678, 0.05475932645744511, 0.010331537890514093, 0.020945957030302713, 0.014177484554238617, 0.005247401372928704, 0.013800275063009133, 0.016814296233600805, 0.04871647339314222, 0.04833552008494735, 0.03436252308477249, 0.08529011479445867, 1.702704267842429, 24.74129319190979, 46.85226590292794, 52.927499771118164, 54.97678756713867, 56.346812520708355, 49.6304475239345, 42.30240133830479, 26.820364441190446, 0.8681834393313953, 0.0995996380224824, 3.8181263208389282, 11.97534360204424, 11.402509791510445, 9.87919281210218, 19.270503963742936, 39.70689133235386, 43.10817698069981, 40.54297501700265, 47.0140894481114, 46.93741955075945, 49.190133231026785, 48.920960017613, 44.643767084394185, 39.56223678588867, 36.3532703263419, 37.37733057567051, 37.51031214850289, 36.53851624897548, 37.55774402618408, 37.58518941061837, 35.6337183543614, 33.552274295261924, 33.80320153917585, 34.24822671072823, 34.301877226148335, 34.548670291900635, 34.20975106103079, 34.789390632084434, 35.82405035836356, 35.38656050818307, 35.74861029216221, 33.91417121887207, 36.02022232328142, 36.57349695478167, 37.2253144127982, 35.53884070260184, 36.33277314049857, 34.85373789923531, 34.62277977807181, 34.5188764163426, 33.95429706573486, 34.47056906563895, 34.83473457608904, 34.72042628696987, 34.564182145254954, 34.39415972573416, 40.867640018463135, 44.156309264046804, 47.45825999123709, 44.91208219528198, 43.636240073612754, 45.77898114068167, 43.743457726069856, 46.15239470345633, 45.860045773642405, 48.50626025881086, 46.140273571014404, 42.59932565689087, 38.1491573197501, 41.44686617170061, 41.55953121185303, 40.273207732609336, 41.84684269768851, 42.4574191229684, 43.11182478496006, 45.13698148727417, 46.154489585331504, 44.58782366343907, 42.08838987350464, 40.230125427246094, 35.73592982973371, 33.5210907799857, 34.843614373888286, 33.268864222935264, 33.70788615090506, 33.662629059382844, 35.09641415732247, 35.839159216199604, 35.97878674098423, 35.6176506451198, 33.71112053734915, 36.505296911512104, 35.512538296835764, 35.32972076960972, 34.40611410140991, 34.940420150756836, 34.96588182449341, 34.44666378838675, 33.80074882507324, 32.313632828848704, 33.26110308510916, 33.74860259464809, 34.443495409829275, 36.65242154257638, 37.915819440569194, 41.02432189668928, 44.29601321901594, 46.73736006872994, 44.12294748851231, 43.721452781132285, 40.986124174935476, 45.52651139668056, 46.25681223188128, 50.59885617664882, 46.02287680762154, 47.73380470275879, 48.9520879473005, 49.51486076627459, 48.72683777127947, 43.26039811543056, 31.38935218538557, 19.883632114955358, 8.877387642860413, 11.411427804401942, 10.582799536841256, 0.6894206745283944, 0.5470173986894744, 0.1682237046105521, 0.2720074270452772, 0.06305262233529772, 2.7801929073674336, 32.56512982504708, 36.66864211218697, 31.174034459250315, 43.9263482093811, 39.612566062382285, 14.754084553037371, 0.3587009965309075, 0.03270702316824879, 0.028737223507570367, 0.05625974041010652, 0.04450185490506036, 0.02190274229672338, 0.06479341071099043, 0.07643910723605327, 0.07319314498454332, 0.04917369743010827, 0.015402741530644042, 0.03323586318375809, 0.03335310724963035, 0.051667842880955765, 0.043168574305517335, 0.01887290701935334, 0.05532526537509901, 0.11801914285336222, 0.21231425872870854, 0.1424348820000887, 0.1363063265702554, 0.21655903809836932, 0.12888798463557447, 0.12819107488862105, 0.14994975232652255, 0.15582051873207092, 0.14194845381592, 0.16026471954371246, 0.10644350506897483, 0.1284101331340415, 0.11988606410367147, 0.06651672002460275, 0.11307423748075962, 0.12454651402575628, 0.08944373298436403, 0.16659412133906568, 0.13116692591990742, 0.12769232450851373, 2.4725620661463057, 28.89115343775068, 54.75332307815552, 58.69463661738804, 64.9809011731829, 65.93416622706822, 57.150573185511995, 46.57766267231533, 30.87981298991612, 1.4608997915472304, 0.7203125283122063, 7.0404181224959235, 18.31887694767543, 14.04107517855508, 11.062342490468707, 23.146490539823258, 42.844690867832725, 45.695651394980295, 40.22163125446865, 47.03869996752058, 47.44705949510847, 50.99662317548479, 51.30788857596261, 47.89114318575178, 42.30439894539969, 38.06312819889614, 39.441602161952424, 38.30427932739258, 37.711754322052, 38.55799627304077, 37.93315519605364, 36.40639277866909, 35.706980160304475, 36.724064418247764, 37.02255208151681, 36.208997930799214, 36.17513935906546, 36.93555021286011, 36.17062650408064, 37.536076068878174, 37.94031184060233, 38.525763579777305, 35.217104366847444, 37.568600586482454, 38.25426271983555, 39.03632416043963, 36.81564514977591, 38.916947160448345, 37.318027700696675, 36.32924345561436, 36.20079558236258, 35.87164204461234, 34.807167598179404, 36.051711559295654, 35.85980231421334, 35.29684884207589, 35.92877013342721, 42.20715890611921, 47.68195029667446, 49.475867475782124, 46.00524227959769, 45.3708370072501, 46.635138171059744, 45.320768288203645, 47.99099574770246, 48.69852386202131, 49.03697061538696, 45.900640623910085, 43.34712553024292, 39.12582738058907, 41.88357087544033, 42.09659569604056, 40.078474044799805, 42.822182178497314, 42.37866824013846, 43.61911276408604, 46.218076024736675, 47.143631662641255, 48.45540639332363, 44.95751299176897, 42.88986110687256, 38.621148450034006, 35.69548783983503, 37.391609123774934, 34.668662207467214, 34.90458481652396, 35.63853693008423, 37.889642102377756, 36.76988083975655, 38.04285682950701, 37.83698170525687, 36.1486736706325, 39.1528628213065, 37.45984738213675, 36.40895666394915, 37.32432624271938, 37.16125896998814, 36.91056101662772, 36.55296502794538, 35.502883774893625, 32.99166236604963, 34.34281948634556, 35.695147378104075, 36.7775342805045, 38.90338775089809, 39.27503647123064, 40.90251302719116, 46.45877204622541, 48.753459794180735, 44.82961402620588, 44.32383728027344, 42.34134946550642, 45.60420615332467, 46.50764567511422, 52.16915600640433, 47.7167329788208, 49.35370772225516, 50.74654361179897, 50.21033028193882, 49.87765053340367, 43.959765570504324, 35.64586727959769, 26.326585497174943, 16.031840903418406, 11.937557561056954, 15.832312958581106, 10.697160805974688, 6.4498103857040405, 4.295931356293814, 3.2921092552798132, 0.27552766672202517, 3.1991829616682868, 37.90031453541347, 43.20098754337856, 39.042702606746126, 49.30341666085379, 47.038171904427664, 18.493323632649012, 0.6004126220941544, 0.16384572881673062, 0.09961791775588479, 0.2385836062686784, 0.1295872963964939, 0.0869577367390905, 0.14605068654886313, 0.10141699907502957, 0.12180550396442413, 0.14482166964028562, 0.14770268861736568, 0.15426267018275602, 0.07114324319575514, 0.11475252599588462, 0.07932434670094933, 0.14349351876548358, 0.14910750037857465], [0.10565054190478154, 0.01730971161409148, 0.0218549649497228, 0.010244707460515201, 0.011470428385239626, 0.06002782178776605, 0.0072281969145738655, 0.031105154659599066, 0.031488079112023115, 0.03724441058667643, 0.014719490693616015, 0.03262973802962473, 0.05186830926686525, 0.05383250190477286, 0.023413468285330703, 0.024650054252041236, 0.0071270052909052795, 0.04821085623864617, 0.039103823847004344, 0.04347745023135628, 0.04651198436373046, 0.08853425178676844, 15.847077880586896, 42.741534437452046, 38.71325029645647, 49.04664945602417, 60.14896406446184, 52.978034019470215, 40.80770833151681, 23.457279988697596, 2.4545864249978746, 0.03153904726994889, 1.3893247693777084, 4.718384870461055, 3.2395784854888916, 6.645165937287467, 15.008996588843209, 35.55109732491629, 42.90298277991158, 50.7849497795105, 46.78342662538801, 48.63947459629604, 47.784787109919954, 47.564629963466096, 43.75506121771676, 40.17653397151402, 34.747048309871126, 36.119456495557515, 33.167757511138916, 35.2845435823713, 32.1669876234872, 31.260049683707102, 32.14055667604719, 32.014745644160676, 32.335620403289795, 33.10478251320975, 32.073329380580354, 33.63518367494856, 34.098868233816965, 34.23924963814871, 35.43864073072161, 34.098121302468435, 33.96480621610369, 33.36286292757307, 34.04566240310669, 34.302957671029226, 33.280940192086355, 33.43159450803484, 33.019670554569785, 33.984372343335835, 32.56600877216884, 32.59874868392944, 32.671510219573975, 31.767323766435894, 34.24078171593802, 32.043830803462434, 32.51744086401803, 32.21743154525757, 35.65670299530029, 41.47880704062325, 43.27423892702375, 45.017882415226524, 44.36296606063843, 44.604030336652485, 43.353886127471924, 42.45429938180106, 43.29558031899588, 44.55247122900826, 43.7481164932251, 40.00114754268101, 39.88696779523577, 41.433577741895405, 41.425799233572825, 46.0921642439706, 45.22771453857422, 44.66071374075753, 42.311357566288535, 43.65838050842285, 43.57673570087978, 44.64255114964077, 43.654857771737234, 38.82558877127511, 35.07407917295183, 32.90241622924805, 32.1327851159232, 31.350640296936035, 32.85085712160383, 33.27055958339146, 33.16772971834455, 34.28841161727905, 35.253780433109824, 35.12684726715088, 35.372994150434224, 33.66511998857771, 33.74493394579206, 32.785484995160786, 32.91316161836897, 32.41406556538173, 32.66825498853411, 34.36220496041434, 33.058979988098145, 32.72363907950265, 32.92732899529593, 33.81369679314749, 35.066147804260254, 37.58374418531145, 38.23410946982247, 39.379752772195, 42.28637184415545, 42.882867744990754, 43.864575249808176, 43.28471333639962, 41.70057616915022, 43.38282190050398, 42.01844583238874, 43.913271699632915, 46.10678672790527, 45.25715058190482, 45.2982873916626, 44.65710762568882, 45.045942715236116, 32.97179399217878, 18.049759319850377, 3.94593973670687, 1.029032553945269, 4.287547920431409, 4.361779000077929, 0.15468355188412325, 0.09873536082782916, 0.11241928155400924, 0.26286620327404564, 0.06570568068751267, 3.141102969646454, 24.36596713747297, 22.59594307626997, 26.792519535337174, 43.645647934504915, 27.95144431931632, 6.028780383723123, 0.15558650557483944, 0.1068237628787756, 0.047335328933383734, 0.03058881325913327, 0.05042375570961407, 0.012782472535036504, 0.03005260435332145, 0.033492281567305326, 0.05105844379535743, 0.02010446334523814, 0.06215021147259644, 0.07327771080391747, 0.06672278432441608, 0.06549308888081994, 0.011979017523117363, 0.01102836282059018, 0.03524135824825082, 0.0492874436479594, 0.00994323265539216, 0.022156281995454004, 0.0594316337789808, 0.01639681399267699, 0.011809572910091706, 0.029063700631793057, 0.02407127066648432, 0.006904724428230631, 0.04536465967872313, 0.02722425156805132, 0.014178519320142056, 0.07596302671091897, 0.02035924476305289, 0.03471269125917128, 0.04407509709043162, 0.019054991891607642, 0.03836136743692415, 0.007561243954114616, 0.042259588438485346, 0.06487222933875662, 0.31210537254810333, 21.011401176452637, 49.18349422727312, 45.27256516047886, 57.367586272103445, 61.9415854045323, 56.22381550925118, 45.38411154065813, 26.35063147544861, 2.338347405195236, 0.023870290290298204, 2.0514651877539496, 6.127839982509613, 5.859143589224134, 9.990531614848546, 18.05107774053301, 40.21609354019165, 43.17876373018537, 48.80058595112392, 46.449016775403706, 50.392915044512065, 49.008399622780935, 48.92819309234619, 46.18956061771938, 41.22074399675642, 36.27941097532, 37.80401597704206, 34.151354925973074, 35.81850222178868, 33.767470427921836, 33.77579436983381, 34.62661518369402, 34.51824413027082, 34.11477613449097, 34.892835412706646, 33.40560129710606, 35.35127755573818, 36.6966746194022, 35.47632081168038, 37.95905808040074, 35.85150963919503, 35.12355729511806, 35.60875695092337, 35.312478814806255, 34.38025638035366, 35.109640053340364, 34.49206331798008, 35.19103125163487, 34.999417304992676, 34.75687653677804, 34.30452101571219, 34.89139018739973, 34.04916082109724, 34.996690137045725, 33.70636796951294, 33.91380296434675, 34.52647427150181, 37.20599494661604, 43.67590733936855, 44.78570141111101, 46.41058281489781, 45.951397214617046, 43.749322005680625, 45.41901581627982, 45.15647118432181, 44.45426886422293, 45.16383280072893, 43.99861642292568, 41.35841907773699, 41.37251697267805, 40.75112567629133, 40.806714739118306, 45.30900846208845, 46.082030296325684, 45.54155772072928, 43.30014181137085, 44.810958112989155, 44.91325296674456, 46.74419709614345, 44.12940583910261, 39.88602631432669, 36.86389691489083, 34.65664529800415, 33.25228582109724, 32.52245051520211, 34.119122232709614, 35.61483662469046, 34.29641246795654, 34.901478971753804, 35.611685616629465, 36.139950207301546, 37.20429958615984, 35.25502068655831, 35.23487785884312, 34.39565706253052, 33.55964285986764, 33.625438826424734, 33.9740994317191, 34.313880239214214, 34.72095087596348, 33.59432479313442, 34.29210458483015, 34.92194141660418, 36.47710459572928, 38.11651120867048, 39.60653502600533, 42.148036684308735, 43.12128823144095, 43.77920968191964, 45.774079186575754, 44.164584568568635, 42.33936922890799, 43.00653525761196, 43.5139239856175, 44.94238676343645, 46.055380480630056, 47.2294453893389, 46.46705777304513, 45.93204648154122, 46.67118195125035, 36.281467642102925, 22.73028302192688, 6.8054647871426175, 3.3200457905020033, 7.330821122441973, 2.930829635688237, 0.6610003166965076, 0.045734729285218885, 0.03305328976629036, 0.11837770789861679, 0.03265964785324676, 3.530146722282682, 29.449738230024064, 28.776881626674108, 32.21289784567696, 47.3869297845023, 34.947931153433665, 8.276233843394689, 0.05097614089027047, 0.06392661615141801, 0.02515424139398549, 0.018571518727445176, 0.021949054008083682, 0.043350927199104, 0.03529864695987531, 0.06579790716724736, 0.03394102391653827, 0.009163921615774078, 0.013986525292109166, 0.06358092970081738, 0.029357007571629117, 0.0037780291251172976, 0.05573026935702988, 0.02470792311110667, 0.06106224163834538, 0.24985979976398603, 0.17392776853271893, 0.07414266653358936, 0.12963799653308733, 0.08473111729004554, 0.09928231433566127, 0.10268913688404219, 0.12351971412343637, 0.04730274568178824, 0.11073255206325225, 0.15409960464707442, 0.12172611536724226, 0.17981270274945668, 0.11241571924516133, 0.14317734858819417, 0.07614872138947248, 0.1320585480758122, 0.07890306466392108, 0.1072954668530396, 0.14705966812159332, 0.12411477576409068, 0.6107865540044648, 24.843033926827566, 55.178042139325825, 50.61312082835606, 55.901519843510215, 63.760123525347026, 58.46346310206822, 49.69395753315517, 30.50773695537022, 3.247758252280099, 0.21710101115916455, 3.2826382092067172, 11.083909698895045, 7.481399008205958, 10.599802647318159, 18.66374557358878, 43.108816214970176, 44.96882813317435, 49.22566631862095, 48.269708837781636, 49.22352627345494, 50.721901825496126, 51.2402617590768, 46.975891726357595, 43.975656100681846, 39.05620295660836, 39.83809764044625, 34.937897954668315, 39.19912392752511, 35.78015858786446, 35.25240816388811, 37.01704216003418, 37.26415831702096, 36.0367625100272, 37.009173325129915, 35.31784977231707, 37.73068468911307, 38.42778008324759, 37.15744093486241, 39.29037114552089, 36.44887406485421, 36.58113997323172, 37.3787271635873, 36.9389374596732, 37.92363268988473, 37.199637344905305, 36.39210728236607, 35.8103415625436, 37.225081648145405, 37.255368845803396, 36.11264378683907, 36.681791578020366, 34.66999626159668, 37.55060127803257, 34.80903318950108, 35.16859204428536, 35.457015241895405, 38.11900561196463, 45.33432422365461, 46.77717672075544, 48.5680227960859, 47.50243316377912, 46.40070595060076, 46.65315137590681, 46.798830781664165, 45.600329058510916, 47.8304819379534, 44.5668922151838, 43.029307978493826, 43.01034981863839, 41.30232974461147, 40.692267486027305, 46.21088811329433, 47.83744403294155, 47.37154994692121, 43.54906102589199, 45.54157509122576, 45.899362155369346, 48.571264130728586, 46.492766107831685, 41.91964244842529, 39.02440105165754, 35.39533608300345, 34.377209595271516, 33.989611285073416, 36.55030039378575, 36.658320563180105, 35.40896150044033, 36.750453676496235, 38.68604809897286, 38.62816265651158, 39.30240889957973, 37.277481487819124, 37.66441624505179, 36.276235648563926, 35.321362086704795, 34.614174434116904, 36.22415542602539, 36.99986621311733, 36.52702740260533, 36.266605445316856, 36.41166993549892, 36.56434965133667, 38.686694281441824, 40.67016874040876, 42.02687052318028, 43.48212208066668, 46.1860795702253, 45.825770309993196, 45.8559741292681, 45.39263350622994, 43.40892628261021, 43.739333970206125, 43.982955183301655, 44.21376044409615, 47.444155148097444, 46.645953042166575, 45.97852645601545, 44.83825063705444, 48.09830025264195, 37.884253774370464, 23.950577769960674, 6.102330539907728, 3.76864298752376, 10.00413271359035, 11.046524916376386, 4.016208171844482, 0.2322093668792929, 0.24532745725342206, 0.4795655352728707, 0.1780017199260848, 4.832235446998051, 32.81029353822981, 32.855053833552766, 37.27778026035854, 54.04027114595686, 41.10949291501726, 11.372914808137075, 0.1775064165038722, 0.2863241902419499, 0.26660585403442383, 0.08986023813486099, 0.15277418148304733, 0.1212715104754482, 0.1624360858861889, 0.146024847935353, 0.13488721129085335, 0.16696886265916483, 0.12954258093876497, 0.16185893757002695, 0.1277895857180868, 0.10440468375704118, 0.1274142472871712, 0.11880462856165, 0.11775030727897372], [0.046839655709585974, 0.03736703543524657, 0.03822152476225581, 0.04117244641695704, 0.05058764227266822, 0.09179371688514948, 0.01244362147657999, 0.04024157440289855, 0.04342639725655317, 0.008922641348492886, 0.035681737653378925, 0.03316864071946059, 0.05205274187028408, 0.021891558343278508, 0.021277874309037412, 0.016038106455068504, 0.02547614519218249, 0.04338583104046328, 0.024172855840463723, 0.04508088954857417, 0.031081161661339656, 0.07226838996367795, 8.361434391566686, 36.31735161372593, 39.996367182050435, 28.224366085869924, 49.826859201703755, 56.5603688785008, 35.63113362448556, 33.17469876153128, 6.395267461027418, 0.011658412271312304, 0.7902177572250366, 3.8009620990071977, 0.890836412353175, 0.7635282608015197, 3.6498991421290805, 16.282316514423915, 36.74459287098476, 43.45402356556484, 49.494672775268555, 49.75468478884016, 47.69464118140084, 45.72102621623448, 45.625460692814414, 40.058973925454275, 34.99029779434204, 36.702740396772114, 36.48760332380022, 33.77811854226248, 31.884241104125977, 31.892144680023193, 31.829263482775005, 31.33361373628889, 32.299534933907644, 32.09787041800362, 32.01102140971592, 33.31642811638968, 32.41434349332537, 33.01462268829346, 33.49013308116368, 33.646637780325754, 33.24058158057076, 33.32938303266253, 34.00869798660278, 34.94433546066284, 32.68508699962071, 34.557828017643516, 34.48223509107317, 33.84739555631365, 34.70236791883196, 33.00049352645874, 33.94703619820731, 33.150126457214355, 31.779135704040527, 32.36151286533901, 32.455973625183105, 32.36022744859968, 33.31217929295131, 37.613399096897666, 42.00634554454258, 42.45832586288452, 44.092278139931814, 46.37816252027239, 45.08198996952602, 45.75869240079607, 42.81890262876238, 43.478140762874055, 43.241294043404714, 41.655673435756135, 38.38847412381853, 41.91311114174979, 45.16817889894758, 46.95030151094709, 45.56148168018886, 45.75927952357701, 44.70805876595633, 45.92640454428536, 44.749181679316926, 45.66493688310896, 42.79573733466012, 39.441824504307334, 33.34410279137747, 31.990294933319092, 32.24424464362008, 31.915101528167725, 33.73017249788557, 32.51736095973423, 32.65830169405256, 32.38565438134329, 33.592896938323975, 34.8529805455889, 34.1322786467416, 32.592807974134175, 32.297012737819124, 32.97852679661342, 31.83633327484131, 31.21772125789097, 32.58242736543928, 31.899113723209926, 33.11940499714443, 33.43905687332153, 33.42609848294939, 36.50509541375296, 35.95371069226946, 37.42342839922224, 40.78797197341919, 40.73947007315499, 41.983784743717735, 43.71024533680507, 43.7305896622794, 43.270254135131836, 41.731151717049734, 41.59445980616978, 43.3978647504534, 41.881066049848286, 40.79660858426775, 42.4882378578186, 41.17956549780709, 46.54364081791469, 37.746512685503276, 28.88070682116917, 7.130987022604261, 2.672748787062509, 2.9199292148862566, 2.2048418947628567, 1.8651485911437442, 0.46916636185986654, 0.16477619031710283, 0.06882401728736502, 0.06279637358550515, 0.04103670548647642, 3.856755265167781, 24.401548862457275, 35.513028144836426, 30.80785049710955, 40.07545852661133, 25.905766112463816, 2.7346837265150885, 0.0646514001169375, 0.04714538662561348, 0.021887193666771054, 0.04253444601116436, 0.043727670197508166, 0.020248609628262262, 0.021439301182648966, 0.007978401346398252, 0.0678470761382154, 0.01921658500629876, 0.06503793437566076, 0.029545660662863935, 0.02644758002965578, 0.03554651240951248, 0.06718884967267513, 0.017556384538433382, 0.06312647408672742, 0.02727814421190747, 0.04153400719431894, 0.04091159380706293, 0.10076727465327297, 0.041070292969899516, 0.0981550912505814, 0.015106545727966087, 0.02884287480264902, 0.06575329348977123, 0.030919364986142943, 0.02004431969752269, 0.03102022243131484, 0.05947153163807733, 0.050238563146974356, 0.03548496249797089, 0.016101010043972304, 0.033081757702997754, 0.008813734781662268, 0.08926738851836749, 0.06514424724238259, 0.05160877301490732, 0.0733058632218412, 11.913925869124276, 44.80609784807478, 43.659943853105815, 36.179791178022114, 58.9612181527274, 58.94885730743408, 40.35992472512381, 34.75614350182669, 6.19309138400214, 0.032668115970279486, 0.36980560209069935, 4.639382549694606, 3.8711389047758917, 2.2815615151609694, 7.535086001668658, 20.598200491496495, 41.97736460821969, 46.42552491596767, 49.80836657115391, 48.88776499884469, 50.592081683022634, 48.0674398286002, 48.23762900488717, 42.363667079380576, 36.997399602617534, 38.165700980595176, 39.18584244591849, 35.263987336839946, 33.8516582761492, 33.24322189603533, 32.67258719035557, 31.279997961861746, 33.85507678985596, 33.97630548477173, 34.00320890971592, 34.85681595121111, 34.43297583716256, 35.88494437081473, 35.820412976401194, 35.01235137666975, 34.7954911504473, 34.848825522831504, 35.52205038070679, 34.558446407318115, 35.699965953826904, 35.375405175345286, 36.01877709797451, 34.7060261453901, 35.95242527553013, 34.01524666377476, 35.1419734954834, 34.61859001432146, 33.503261702401296, 33.49809224264962, 33.52518674305507, 32.91142109462193, 35.19070816040039, 40.258331639426096, 44.219294684273855, 43.827965191432405, 46.150039264133994, 46.76545510973249, 45.11639397484915, 47.22523478099278, 44.27652352196829, 44.99985531398228, 44.35734496797834, 42.36527211325509, 39.2153444971357, 42.89003133773804, 45.84427336284092, 49.09700652531215, 46.90865053449358, 46.789964880262104, 48.38810614177159, 46.29093483516148, 46.42347172328404, 47.24267823355538, 44.375611782073975, 40.207658427102224, 35.09457983289446, 34.57108170645577, 33.54392603465489, 33.417920453207834, 34.978656087602886, 33.873923778533936, 34.61243043627058, 34.28587899889265, 36.589418751852854, 36.74080262865339, 35.52575377055577, 35.27233559744698, 33.89706475394112, 34.11837877546038, 33.21266719273159, 33.60975326810564, 33.575429167066304, 34.311076641082764, 34.553857122148784, 34.980438300541465, 35.16444744382586, 38.870564460754395, 38.581331798008506, 39.20185456957136, 42.17853580202375, 43.34334223611014, 44.133550439562114, 46.30928502764021, 45.51074593407767, 44.09696469988142, 43.96171801430838, 42.07882220404488, 44.81907360894339, 43.45790760857718, 44.6334559576852, 43.973186016082764, 43.063847473689485, 46.566417012895855, 40.483265672411235, 30.781336171286448, 10.811992815562657, 2.3939820655754636, 2.985714324883052, 2.107675680092403, 0.8544187865086964, 0.06276995143187897, 0.06554900016635656, 0.08404742540525538, 0.03481019674135106, 0.07598954385944776, 4.2938838090215405, 26.499064104897634, 32.87844841820853, 32.262834548950195, 44.70667954853603, 30.664658546447754, 4.780446180275508, 0.06900572896535907, 0.07639602026236908, 0.03603365984080093, 0.04584065538698009, 0.024139896001932875, 0.025444157355065857, 0.04574026952364615, 0.022374459841687764, 0.030147500868354524, 0.05619105909551893, 0.007230784677501235, 0.06810081430843898, 0.029607590554015975, 0.01700456254184246, 0.04896990282993231, 0.028103371716237495, 0.06929736331637416, 0.10197972852204527, 0.1724326437605279, 0.12290648131498269, 0.20459662856800215, 0.1675349644252232, 0.156780265803848, 0.09058055733995778, 0.18513955548405647, 0.18630766708936009, 0.08522863952176911, 0.08750726867999349, 0.11316648431654487, 0.19712082828794206, 0.10463370968188558, 0.1318827803645815, 0.1153159679046699, 0.14282607100903988, 0.08149849503700222, 0.18480958390448773, 0.10150487614529473, 0.1351036639618022, 0.21995566226541996, 13.319446563720703, 49.229546887534006, 51.89616128376552, 38.86435971941267, 56.850734097617014, 62.47722898210798, 44.78476340430123, 40.5424747467041, 8.704258510044642, 0.058064731769263744, 1.8095194676092692, 8.186393635613577, 4.389212225164686, 2.1649679200989858, 6.320442744663783, 20.83757288115365, 43.37038115092686, 46.40602132252285, 49.55931534085955, 50.64868170874459, 52.10256099700928, 49.22267859322684, 50.470022678375244, 45.04190581185477, 39.37201942716326, 41.619417735508506, 41.27760805402483, 38.12744767325265, 35.38403136389596, 36.07517910003662, 34.773322922842844, 34.96280377251761, 36.48121445519583, 35.65507711683001, 34.67908450535366, 37.40687779017857, 35.456070286887034, 37.351392950330464, 37.53629841123308, 38.10480349404471, 36.41768707547869, 36.2437423978533, 37.16193641935076, 38.02906118120466, 36.32773222242083, 38.09229326248169, 37.898087637765066, 36.457823344639365, 37.607406275612966, 35.57886580058506, 36.2169188771929, 36.40116078513009, 33.75537708827427, 35.10832684380667, 35.001602513449534, 35.67431320462908, 36.18320621762957, 42.522683552333284, 47.394857679094585, 45.6152537890843, 46.59944180079869, 50.12088959557669, 48.193507943834575, 48.80795798982893, 45.64586407797677, 47.46330438341413, 45.424751554216655, 43.72516311917986, 40.85742269243513, 42.56124605451311, 46.991910798209055, 51.50141675131661, 49.85237298692976, 48.43881409508841, 48.69835015705654, 47.444019658224924, 48.67441708700997, 48.066946506500244, 46.09613513946533, 42.240520681653706, 37.52416685649327, 36.04561798913138, 35.95291512353079, 33.9092241014753, 36.6272725377764, 35.560473918914795, 35.869307449885774, 36.35032776423863, 38.22594881057739, 39.369330474308555, 37.56967060906546, 36.90262964793614, 35.806665965488975, 35.87353890282767, 35.22040128707886, 34.13802480697632, 35.59292548043387, 36.470326628003804, 37.09544563293457, 37.134775911058696, 35.55091667175293, 40.770921094076975, 39.634887150355745, 40.30306414195469, 44.530129296439036, 45.5318615095956, 46.16371331896101, 48.52603483200073, 46.34530448913574, 45.79335348946707, 44.23561947686331, 41.515837465013774, 45.57349511555263, 44.74180269241333, 44.68339613505772, 46.3384188243321, 43.73617948804583, 47.45847885949271, 41.533468518938335, 33.84053768430437, 10.749314853123256, 4.777101056916373, 5.021846575396402, 8.0866505077907, 7.49807642187391, 0.8195398609553064, 0.8934101771031107, 0.27881698736122673, 1.0110813400575092, 0.30864649957844187, 5.986090217317853, 34.25700923374721, 43.08540078571865, 42.13041605268206, 51.77007232393537, 37.17463077817644, 6.763811205114637, 0.14359842027936662, 0.10943211934396199, 0.17024385263877256, 0.13403064225401196, 0.1798920642052378, 0.08863052912056446, 0.1930711820189442, 0.1410849637218884, 0.14370216828371796, 0.1125550496258906, 0.19269853058670247, 0.17288526733006748, 0.07500847043203455, 0.0844750449593578, 0.1540349538304976, 0.108539397961327, 0.14642519716705593], [0.028206707510565008, 0.019933033169114163, 0.028367253984989863, 0.0228433886077255, 0.026403449808380434, 0.04477547415133033, 0.0356884788987892, 0.01526928217416363, 0.01737773135703589, 0.0221215189501111, 0.03283716279215046, 0.009949667711875268, 0.005350344465114176, 0.011841687124355562, 0.04580113072214382, 0.06398243922740221, 0.0380650952990566, 0.04125194018706679, 0.03640576165967754, 0.038300597840653997, 0.0130328129411542, 0.06039348430931568, 1.080934294632503, 29.906227929251536, 43.78132888248989, 31.88535976409912, 22.47485681942531, 40.95571885790144, 48.044326645987375, 33.17987516948155, 10.140049031802587, 0.1904937938920089, 0.22490705443280085, 4.133195860045297, 3.063300515924181, 1.1101533153227396, 1.7555571517774036, 3.821146615913936, 23.217033863067627, 40.74882582255772, 48.27624361855643, 47.29841668265206, 49.73276669638497, 47.17038917541504, 44.229181970868794, 41.85952663421631, 37.265700817108154, 38.182234219142366, 35.37179211207798, 32.738869530814036, 34.11393192836216, 32.409205300467356, 33.041606017521445, 33.06627559661865, 34.44426318577358, 33.19366386958531, 32.780756746019634, 32.9472599029541, 32.78167390823364, 31.709365367889404, 34.15523549488613, 34.36463335582188, 33.55577271325247, 33.93250751495361, 34.74218804495675, 32.80402626310076, 34.62989820752825, 33.422276973724365, 33.40586185455322, 33.58617803028652, 34.05872501645769, 34.96067762374878, 34.25139161518642, 32.595517771584646, 33.66475868225098, 31.275255816323416, 33.03965704781668, 33.63471467154366, 33.00457559313093, 35.17560625076294, 37.265186650412424, 40.39461360658918, 41.552152224949424, 42.28487798145839, 44.63831969669887, 43.90277991976057, 44.72003051212856, 43.2734329359872, 43.739031723567415, 40.7475334576198, 40.88367298671177, 45.202430043901714, 43.82261160441807, 44.59435497011457, 43.404823371342246, 42.67131246839251, 43.49842255456107, 46.11855002811977, 43.61296360833304, 45.20505993706839, 42.70557056154524, 36.26394081115723, 33.2702191216605, 33.884599685668945, 32.58168043409075, 31.834724766867502, 32.662831919533865, 33.828663212912424, 32.82971722739083, 34.2057523727417, 34.079701628003804, 33.86610358101981, 33.26857934679304, 33.426428522382466, 33.244239807128906, 32.72614390509469, 33.303699016571045, 32.72090148925781, 31.48099892480033, 32.43250608444214, 32.150593348911826, 33.602210998535156, 33.58136292866298, 36.03640120370047, 38.10216317858015, 38.52129936218262, 39.74063525881086, 41.256954533713206, 41.61688164302281, 43.73176390784127, 42.67475530079433, 43.87041868482317, 42.200790882110596, 41.51823459352766, 44.08439540863037, 37.79470191683088, 38.87585898808071, 42.87970284053257, 38.42108201980591, 40.907977785382954, 33.49869326182774, 15.878961426871163, 4.097598935876574, 8.430958935192653, 7.698952317237854, 1.38388226713453, 0.21278174221515656, 0.0435313564459128, 0.056703658375356875, 0.020882134026448642, 0.05485792438100491, 0.034841412744883976, 5.280007762568338, 30.062927177974156, 34.50818313871111, 46.64050912857056, 39.7500570161002, 22.50519265447344, 1.5441240114825112, 0.010868925750920815, 0.0322423895288791, 0.013533380946942737, 0.08186878516737904, 0.005308296922261694, 0.02861493792650955, 0.032288611334349425, 0.0584102010886584, 0.05067110207996198, 0.06598613956677062, 0.015468732453882694, 0.03936283423432282, 0.03158669060628329, 0.06878493367029087, 0.013798024023084767, 0.025468481139146855, 0.009216216309661312, 0.040399791805871894, 0.06682259004030909, 0.025449648399704268, 0.017303835500829985, 0.04585674684494734, 0.06384542943643672, 0.049088643065520694, 0.035917487860258134, 0.029115571241293634, 0.03929663975057857, 0.04362693828131471, 0.016975483923618282, 0.06275439262390137, 0.07440122908779553, 0.010784331941977143, 0.022019950739507164, 0.03590933865468417, 0.04546024151412504, 0.06210629668618951, 0.0318707864332412, 0.007836222814928209, 0.06120978907815047, 2.025687588112695, 36.68549844196865, 48.9663074357169, 32.79228728158133, 33.47760895320347, 49.8348913192749, 46.8698969568525, 37.093826702662874, 10.087967072214399, 0.11715403784598623, 0.11126898149294512, 5.110656712736402, 5.92946674142565, 3.0299172444002966, 3.9189442481313432, 7.1274382301739285, 27.8598427431924, 43.67052943365914, 48.783816473824636, 48.891159193856375, 50.452794619968955, 49.615609645843506, 46.87978424344744, 43.93336936405727, 38.94010898045131, 40.15625217982701, 37.139181068965364, 35.444022110530305, 36.39524439402989, 33.855674334934776, 34.98407220840454, 34.43050227846418, 36.09696517671858, 33.97787925175258, 34.61828081948416, 36.10738052640642, 34.59987851551601, 33.70602403368269, 36.16593994413103, 36.91488627025059, 35.48832382474627, 34.9081666128976, 34.66841207231794, 34.473080839429585, 35.58915260859898, 34.38943842479161, 35.55791350773403, 34.840227127075195, 34.22424847739083, 36.460585253579275, 34.31941447939192, 33.74508680616106, 35.041898591177805, 32.505038329533164, 33.83795990262713, 34.99820831843785, 35.38413906097412, 36.91986118044172, 39.38560662950788, 41.65425252914429, 44.66268008095877, 44.46454872403826, 46.9729665347508, 45.886396816798616, 47.07311092104231, 44.57300315584455, 43.59905331475394, 42.90803064618792, 42.6929908479963, 46.49680301121303, 46.22680296216692, 45.38584164210728, 45.354442732674734, 44.81239291599819, 44.50051607404436, 46.77391454151699, 47.05689035143171, 46.302190916878835, 44.53424263000488, 37.93155711037772, 35.09698738370623, 35.2464987209865, 33.71401793616158, 34.330990178244456, 34.14375707081386, 35.58770043509347, 33.441252504076274, 35.72687285287039, 35.23225491387503, 34.6729770387922, 34.26096970694405, 33.5849620955331, 34.77024139676775, 34.084127630506245, 34.53311674935477, 33.47007710593087, 32.378289290836875, 33.954178946358816, 34.76762192589896, 35.23497860772269, 35.17320564814976, 37.13542209352766, 39.213416372026714, 40.218567098890034, 41.06775508608137, 42.58994211469378, 44.24765375682286, 44.780257497514995, 44.8661789212908, 45.095309666224885, 42.64430482046944, 42.44885546820504, 45.52444083350045, 40.46987649372646, 42.43933296203613, 46.34168100357056, 40.52369029181344, 43.52363756724766, 36.89353098188128, 20.17258163860866, 5.210170115743365, 10.300693988800049, 9.050491588456289, 0.058832846981074126, 0.18413016679031508, 0.05519146844744682, 0.11333431316805737, 0.03842016249629004, 0.015570056391879916, 0.05818252544850111, 6.389192129884448, 33.37877082824707, 40.05886275427682, 46.491994857788086, 43.900563444410054, 27.247018575668335, 2.294202459709985, 0.04935935139656067, 0.0341529168321618, 0.023712003337485448, 0.04481801829699959, 0.06251896132848092, 0.03104234267292278, 0.03176569492955293, 0.03163331274741462, 0.04373625705816916, 0.11357072155390467, 0.05803149712405034, 0.050341510480003696, 0.030716825675751482, 0.07396515498736075, 0.006267758161162159, 0.020031581898885112, 0.040565713973981996, 0.17624788332198346, 0.18016008553760393, 0.1350697372108698, 0.09571879769542388, 0.12383914126881532, 0.12755996946777615, 0.08361342762197767, 0.19556937153850282, 0.1148901464683669, 0.08646079126213278, 0.10791435185819864, 0.13287508354655334, 0.1663561048252242, 0.12868632402803215, 0.23508543255073683, 0.1705824551837785, 0.18974530191293784, 0.12973251646118505, 0.13278943885649952, 0.07189632207155228, 0.1380741409957409, 0.09858378289001328, 1.9242562651634216, 41.91142272949219, 55.194717815944124, 42.618968214307515, 33.19157941000802, 48.53564766475132, 54.1150997706822, 42.58733306612287, 12.661043081964765, 0.5302991100719997, 0.7233717984386853, 9.73863683428083, 9.302570496286664, 3.9142338037490845, 3.8357647572244917, 7.50546669960022, 29.559947081974574, 42.641039167131694, 49.39385788781302, 47.96538468769619, 52.570772307259695, 51.37438978467669, 48.4138422693525, 46.220587798527305, 41.25892434801374, 41.1851692199707, 39.168576172419954, 37.697298594883506, 38.62690155846732, 36.20678145544869, 37.320136478969026, 37.504347120012554, 39.19027887071882, 35.85156869888306, 37.51555109024048, 37.40445981706892, 36.96328394753592, 35.40810339791434, 36.987581798008506, 37.816946574619834, 36.83984225136893, 37.06921965735299, 37.109383719308035, 36.0638952255249, 38.13450356892177, 36.12870454788208, 37.84659801210676, 36.23773915427071, 35.881737777165, 37.79524735042027, 36.84845454352242, 35.562839780535015, 37.25316626685006, 32.76955277579171, 36.01224231719971, 37.25712674004691, 37.43371868133545, 38.96560192108154, 40.142786570957725, 43.07178579057966, 44.93874590737479, 46.71455608095442, 48.33465365001133, 47.28410339355469, 49.45702396120344, 46.89454221725464, 44.26546893801008, 43.854858194078716, 45.33253853661673, 48.3449821472168, 46.655034337724956, 47.10248095648629, 47.855474608285085, 45.80120842797415, 46.27784790311541, 48.78025899614607, 48.09150491441999, 49.18874706540789, 45.55822992324829, 39.223331451416016, 35.73417888368879, 37.62402636664254, 35.32934209278652, 35.40810687201363, 35.70976986203875, 36.984347411564414, 35.66879633494786, 37.36403867176601, 35.98739555903843, 37.11391741888863, 36.37828036717006, 35.5688464982169, 36.416311332157676, 35.059897899627686, 36.48509502410889, 35.765515259334016, 35.08215992791312, 36.03888518469674, 36.4932278905596, 37.482397760663716, 37.3551276070731, 39.12998587744576, 41.784277643476216, 42.12834548950195, 43.17426129749843, 43.90530211584908, 44.54566546848842, 46.69607039860317, 45.478117193494526, 47.604582105364116, 44.908483028411865, 43.31489283697945, 45.02820743833269, 40.660309246608186, 43.857463768550325, 47.45531048093523, 43.171013014657156, 45.859830379486084, 39.80127566201346, 21.32241644178118, 6.682316218103681, 13.570663026400975, 16.40040636062622, 5.150320938655308, 1.1666913500853946, 0.17722565228385584, 0.37945583569152014, 0.14344291362379277, 0.1427460310182401, 0.1809884003762688, 8.413381729807172, 40.25073378426688, 43.121413299015586, 50.744438307625906, 50.08054140635899, 30.734446253095353, 3.062715998717717, 0.16068683617881366, 0.11595791631511279, 0.14072449877858162, 0.1578935110675437, 0.17890209518373013, 0.11903564259409904, 0.0868617511753525, 0.09328608001981463, 0.11270731966942549, 0.21085865183600358, 0.10663929634860583, 0.18453597144356795, 0.11159002355166844, 0.18017247558704444, 0.14242672600916453, 0.10436639402593885, 0.0868494561208146], [0.019060562664110745, 0.021961881712611233, 0.04963734719370093, 0.04022638200383101, 0.03100119291671685, 0.07448614774537937, 0.08487939754767077, 0.07962458487600088, 0.031320138302232535, 0.054717369244566987, 0.03640632823641811, 0.08066063999597516, 0.06866390337901455, 0.0194095722399652, 0.028410147576193725, 0.027883412715579783, 0.04828104729365025, 0.047554360037403445, 0.04085078689136675, 0.05156257835083774, 0.04267217165657452, 0.03566018398851156, 0.07046687270381621, 9.061839733804975, 41.192906039101736, 36.79817043031965, 22.28984887259347, 22.239894798823766, 43.510922363826204, 37.60441507611956, 14.001521689551216, 0.5956117968474115, 0.1569870968482324, 3.2409544459411075, 5.560434017862592, 1.5805325720991408, 3.045408470290048, 1.8315759812082564, 8.490381666592189, 28.59790471621922, 47.92460223606655, 49.06216478347778, 49.446111815316335, 47.15728834697178, 47.68149866376604, 43.059699399130686, 40.69396979468209, 38.8820150920323, 35.683491774967735, 34.9153128351484, 34.41061653409685, 33.64604370934622, 35.563430377415244, 34.58002403804234, 34.64617436272757, 32.78079148701259, 34.765666007995605, 33.76921789986746, 32.60036414010184, 33.48433133534023, 33.75769778660366, 33.510626792907715, 35.851214340754915, 34.06572880063738, 33.97605882372175, 33.139544350760325, 34.87825114386422, 33.9989983013698, 33.89119700023106, 32.598276206425254, 34.37172051838466, 32.35956736973354, 34.54318816321236, 33.14730896268572, 32.77428797313145, 34.765075411115376, 35.01973383767264, 33.62152699061802, 34.25157226834978, 32.5701116834368, 35.08939300264631, 37.02567182268415, 39.39285707473755, 39.830409458705354, 41.184689794267925, 42.11628341674805, 43.34043094090053, 43.174108437129426, 44.61790588923863, 39.32996198109218, 40.092547621045796, 46.30289963313511, 44.218412263052805, 41.416606766836985, 41.004964215414866, 40.24917391368321, 40.999568939208984, 43.988270555223735, 41.65613201686314, 42.7033679825919, 37.093906606946675, 33.61017363412039, 32.919908319200786, 34.138809953417095, 31.45055886677333, 32.22860772269112, 32.4173902784075, 33.97017369951521, 32.88502836227417, 32.50494800295149, 33.43105602264404, 34.32282951899937, 33.17618220193045, 31.844827447618755, 33.07940074375698, 32.535961287362234, 32.9654746055603, 32.5107810156686, 33.09761197226388, 32.42270565032959, 32.78571775981358, 31.916654450552805, 33.711527006966726, 37.8615540095738, 37.18750579016549, 38.479373931884766, 38.06518486567906, 41.208452633449006, 41.45340095247541, 43.066307135990684, 43.99155705315726, 45.81947871616909, 43.489410740988596, 43.36502061571394, 43.6066893850054, 44.671250683920725, 41.76159872327532, 40.57915776116507, 38.37709992272513, 36.73405940192086, 20.79138994216919, 5.376913854054042, 0.2436873566891466, 0.8492724512304578, 1.3917419825281416, 0.1939488263534648, 0.07684960735163518, 0.06905668015990939, 0.03692594696102398, 0.03154950010191117, 0.21679964661598206, 0.43216848000884056, 10.373627492359706, 29.924227237701416, 27.65602081162589, 32.4449850491115, 33.75183698109218, 13.050352386065892, 0.16941614848162445, 0.07243780658713408, 0.05186383093574217, 0.03766248993841665, 0.0932201739134533, 0.0036920850314865155, 0.04318377009725996, 0.006172738237572568, 0.007913695398851164, 0.04001884189035211, 0.031353885241385014, 0.048556111819509945, 0.029168208595365286, 0.04723540447386248, 0.06280600878276996, 0.007967853519533361, 0.08055009307073695, 0.006974375623810504, 0.07177951226809196, 0.027580460400453637, 0.03284208895638585, 0.11591613212866442, 0.0042174271989746815, 0.02024022632810686, 0.08626622134553534, 0.024750782775559595, 0.04284044494852424, 0.041598929424903223, 0.0494425703239228, 0.04073140544018575, 0.04156120287786637, 0.03109975012817553, 0.022633387108466456, 0.04383874638006091, 0.03149042345051255, 0.05845606327056885, 0.014439196359100086, 0.07910081012440578, 0.03112959209829569, 0.032987882383167744, 0.022364483680576086, 15.027343307222639, 48.07059778485979, 42.93575395856585, 22.779022897992814, 30.08032546724592, 50.87927852358137, 38.244882651737754, 16.963900055204117, 0.3141662733895438, 0.05794805767280715, 1.9264566728046961, 7.3892658948898315, 3.1980775466987064, 5.172160863876343, 5.56798540694373, 12.371228507586888, 32.38308007376534, 49.58927944728306, 49.51990515845162, 51.181695393153596, 49.371317931583945, 49.303163051605225, 46.271646635872976, 42.161978244781494, 40.91043049948556, 37.26387344087873, 36.66591147014073, 36.07984481539045, 35.05553443091256, 36.77363634109497, 35.589131764003206, 35.59374189376831, 35.620346546173096, 36.7068259375436, 34.628487723214285, 33.58209596361433, 35.18615709032331, 35.38596991130284, 36.324789660317556, 35.47902018683297, 35.99197094781058, 35.3664037840707, 33.797219140189036, 35.3168249130249, 36.017609800611226, 35.577761037009104, 34.23905161448887, 35.601763589041575, 34.007687023707796, 36.183932304382324, 35.016541140420095, 34.41137041364397, 35.98837178094046, 35.70556967599051, 34.922549383980886, 35.343169007982524, 35.08342450005667, 35.57505471365792, 37.650168963841026, 41.39596366882324, 40.773707321711946, 43.23428331102644, 43.62917375564575, 45.23398181370327, 44.401764801570344, 46.50784717287336, 40.75450250080654, 41.886037485940115, 46.9423006602696, 45.61230775288173, 44.00469609669277, 42.16181148801531, 40.96860081808907, 42.832858085632324, 45.22829818725586, 44.073722975594656, 44.23675898143223, 39.733443873269216, 34.9593574660165, 33.23671490805489, 34.37139742715018, 32.525886399405344, 33.291894027165, 34.16654716219221, 34.58095162255423, 34.756028856549946, 32.87755210059029, 34.522670132773264, 35.37497786113194, 33.50458533423287, 33.17189168930054, 34.02714892796108, 33.47519098009382, 34.06716012954712, 33.933914525168284, 35.50465556553432, 33.97815023149763, 35.33662380490984, 34.20438010351998, 36.372440406254356, 39.68681103842599, 39.56023570469448, 40.503005504608154, 40.05333546229771, 43.20814071382795, 43.37875720432827, 43.750572681427, 45.57070541381836, 45.49912854603359, 45.15339313234602, 45.03886250087193, 42.800660133361816, 43.984435149601524, 42.820698738098145, 41.9367801802499, 41.2332820211138, 40.90837730680193, 25.93440658705575, 7.497917481831141, 0.5447314956358501, 2.2164180278778076, 2.203983575105667, 0.29239843572889057, 0.09711164009890386, 0.06732136077646698, 0.05795054789632559, 0.020946672884747386, 0.07864904829433986, 0.28658914459603174, 11.01755005972726, 34.1381915637425, 31.68832274845668, 40.82855640138899, 40.339820112500874, 17.53397716794695, 0.49858080063547405, 0.04321253319670047, 0.045765633162643225, 0.0307546200762902, 0.02845922431775502, 0.03697915428451129, 0.015981808404571245, 0.06087554951331445, 0.035064460776214085, 0.018480622176347033, 0.04529355938679405, 0.027558365603908896, 0.014841550661783134, 0.018106915622151325, 0.008595768129453063, 0.05153688222968152, 0.012596213824248739, 0.04197272079597626, 0.12913659986640724, 0.07005553120481116, 0.17420864131833824, 0.18550524514700684, 0.12935358179467066, 0.1667588832122939, 0.22273638019604342, 0.15133210457861423, 0.08490435406565666, 0.18227292144937174, 0.1977700370230845, 0.1827667320945433, 0.24406595208815166, 0.1700819677540234, 0.0886199711156743, 0.13947899346905096, 0.10421997973961489, 0.08545327532504286, 0.1746759076735803, 0.1615385604756219, 0.16624022461473942, 0.07791460877550499, 0.21323333441146783, 16.338164397648402, 57.20731217520577, 48.773932661329, 30.052442346300396, 32.19762570517403, 52.98607655933925, 46.094182695661274, 19.05475197519575, 0.8680887701255935, 0.20719503770981515, 7.6050474132810315, 15.491826908929006, 7.028767730508532, 8.092233385358538, 5.547263273171016, 14.350146685327802, 33.186913694654194, 51.10667221886771, 49.737529686519075, 51.23175368990217, 50.137565272195, 53.02097388676235, 46.88478694643293, 45.01382466724941, 42.92346954345703, 39.28389195033482, 38.968388148716514, 39.78040674754551, 36.85364484786987, 40.020084857940674, 38.6804895401001, 37.517392362867085, 36.80169316700527, 39.956835406167166, 37.13515111378261, 35.66972391945975, 37.67704807009016, 37.24411971228463, 37.074389117104666, 37.93048708779471, 36.697355542864116, 37.189107349940706, 34.86108561924526, 38.44669655391148, 37.99878440584455, 36.983541420527864, 35.40190213067191, 37.37371056420462, 34.1669397354126, 38.00070210865566, 36.65751109804426, 35.388241972242085, 38.08458423614502, 37.89720174244472, 36.80256169182913, 38.26479271480015, 35.73681919915335, 38.25172315325056, 39.07617555345808, 42.54103027071272, 43.43542671203613, 45.86313772201538, 46.431392669677734, 46.58849491391863, 45.537704944610596, 47.165042536599294, 41.837313243321006, 43.09806040355137, 48.43350567136492, 48.64653049196516, 45.73488787242344, 44.33983550752912, 43.55562359946114, 44.79191657475063, 47.19926936285836, 44.923310484204976, 46.00071900231497, 40.88854367392403, 36.860120568956646, 36.189463070460725, 36.73008155822754, 34.447646958487375, 35.5553982598441, 35.04739809036255, 37.09848199571882, 37.48979411806379, 34.343757493155344, 37.10318940026419, 35.757549149649485, 36.836274351392476, 33.95550952638899, 36.63842439651489, 35.36678940909249, 36.18846252986363, 35.079172202519004, 36.74205330439976, 35.27561862128121, 37.942941733769004, 35.94159650802612, 38.4608986718314, 42.572474343436106, 41.30196149008614, 42.5354334967477, 41.56496817725045, 45.21712895802089, 44.97033936636788, 45.387696811131065, 46.97603069032942, 47.173557553972515, 46.83719873428345, 45.25519118990217, 43.57640566144671, 44.30184275763375, 43.294631889888215, 42.20765222821917, 40.255739961351665, 40.375912530081614, 27.08650824001857, 7.907182012285505, 0.665135960493769, 1.8801675566605158, 3.709727474621364, 1.7113095032317298, 0.27954472973942757, 0.1276830964322601, 0.23802093788981438, 0.2748931279139859, 0.639131675873484, 0.8518625008208411, 14.593277181897845, 39.23294428416661, 37.483735288892476, 42.312920910971506, 44.00715228489467, 19.604241575513566, 0.578872337937355, 0.21372903138399124, 0.1367692503013781, 0.11348565361861672, 0.20044894755950995, 0.07757551768528563, 0.1081144314791475, 0.09973489719309978, 0.15330214958105767, 0.06374348633523498, 0.1517622007855347, 0.2048041517181056, 0.14899107734007494, 0.08625486945467335, 0.14734907687774726, 0.13664536337767327, 0.12842801931713307, 0.1086794679452266], [0.024877458478191068, 0.018218617753258774, 0.055420392592038424, 0.05957515750612531, 0.013224426141407872, 0.05578587190913303, 0.08494446227060896, 0.04906488416184272, 0.04848039070410388, 0.04959499303783689, 0.05175087521118777, 0.028843427808689218, 0.01746873138472438, 0.022599546870748912, 0.02881995728239417, 0.049704461092395444, 0.0234290084335953, 0.0139379243732297, 0.04869845150304692, 0.04764753646616425, 0.022944168021370257, 0.03329901783061879, 0.03565520354147468, 0.7085882031491825, 21.146456786564418, 36.279004505702424, 32.97067880630493, 24.306078876767838, 32.428496973855154, 41.03374365397862, 12.604406578200203, 0.5981487578579358, 0.0710887907605086, 1.3517985258783614, 4.723662895815713, 3.35779253074101, 4.13613668509892, 0.8687120452523232, 2.178651745830263, 14.5678129025868, 36.97316081183297, 49.389428411211284, 49.98556300571987, 51.3963599886213, 44.99234083720616, 44.200617926461355, 41.47548927579607, 38.61030578613281, 36.20625686645508, 36.95266710008894, 36.11859491893223, 37.44797985894339, 36.269016470227925, 36.10561568396432, 35.568405287606375, 33.260557651519775, 33.95017678397042, 34.439635685511995, 33.970667021615164, 32.63092231750488, 33.72988762174334, 34.82091808319092, 34.279375485011506, 34.299570424216135, 34.196083954402376, 35.9526059286935, 35.08233710697719, 33.77268852506365, 33.83053227833339, 33.75892761775425, 33.883946555001394, 34.15112910951887, 33.30975089754377, 32.80746214730399, 32.824843066079275, 32.743403230394634, 34.55389881134033, 33.19932317733765, 34.17460012435913, 32.73763969966343, 34.97448716844831, 35.03246988568987, 36.85014295578003, 38.48904235022408, 40.25007717950003, 40.600950786045615, 43.0001220703125, 43.06625849860055, 46.41508524758475, 40.76805148805891, 39.87595837456839, 46.8472249848502, 42.10369675500052, 42.8476369040353, 35.918789046151296, 36.0209310395377, 34.712474073682515, 35.955645765577046, 34.742090770176475, 34.007704394204275, 33.547810077667236, 34.54347651345389, 32.249952588762554, 32.13917398452759, 31.16000257219587, 32.65501172201974, 32.88841560908726, 32.9391895702907, 32.76017618179321, 33.10243402208601, 32.612110069819856, 34.33125768389021, 33.25934171676636, 32.4169316973005, 31.222272327968053, 31.557561125074113, 30.76705414908273, 32.293413570949006, 32.881380558013916, 31.968887533460343, 31.463100365230016, 33.165603569575715, 32.4677334512983, 33.0750789642334, 33.50540174756731, 34.83680861336844, 35.02316277367728, 36.70919874736241, 39.412114007132395, 41.05144418988909, 41.80562250954764, 43.59657628195626, 43.30043363571167, 42.19974170412336, 41.90461696897234, 42.714881147657124, 43.01220498766218, 44.396320887974326, 39.42151491982596, 28.17867820603507, 11.148605244500295, 1.0074638256004878, 0.0607204499787518, 0.25613858284694807, 0.07947086276752607, 0.11888127587735653, 0.06568712954010282, 0.052683738725525994, 0.060568464919924736, 0.17377906079803193, 0.2516096058700766, 1.2078952533858163, 17.69101514135088, 32.05943298339844, 33.75492892946516, 31.905363627842494, 26.42813515663147, 3.7746171355247498, 0.033021839668176005, 0.017029676819220185, 0.019946914299258163, 0.06435374716030699, 0.032565636826413016, 0.019084258803299496, 0.047261005600116084, 0.02493395669651883, 0.03207631129771471, 0.0334999252642904, 0.028119251132011414, 0.02440935413220099, 0.09493901846664292, 0.03289042100576418, 0.044998433973108015, 0.025598798878490925, 0.029825888840215545, 0.011491840405921851, 0.05893767385610512, 0.03655612501981003, 0.059201101506395, 0.05561242478766611, 0.06171328920338835, 0.020127499609121254, 0.02048476186714002, 0.006077738670033536, 0.03229335768680487, 0.06919883324631623, 0.022795283867578422, 0.045841758006385395, 0.053074673283845186, 0.025775881251320243, 0.07585389113851956, 0.021190472213285308, 0.028450172660606246, 0.04082589822688273, 0.03698851806776864, 0.01887791630412851, 0.035769255100084205, 0.04415068928418415, 0.028223345189222267, 1.2183886617422104, 30.003648621695383, 43.96410124642508, 33.81829650061471, 27.735648904527935, 41.15348196029663, 45.74551166806902, 16.195703744888306, 0.7548418726239885, 0.05254979930551989, 0.8755738256233079, 0.08178584104669945, 1.3214280584028788, 3.9310150061334883, 2.423470654657909, 4.045187371117728, 18.342250687735422, 40.621857915605815, 49.6981577192034, 50.11739812578474, 53.324162006378174, 47.19366216659546, 46.510171345302034, 43.75645433153425, 41.002382959638325, 37.62503385543823, 38.799922125680105, 37.15078803471157, 38.6291493007115, 37.76799998964582, 37.59263093130929, 37.69585336957659, 34.975998401641846, 34.823325634002686, 34.87274122238159, 34.932870932987754, 34.31808042526245, 34.96877227510725, 35.65027938570295, 34.7473783493042, 35.86896351405552, 35.6210344178336, 37.630575043814524, 36.85684796742031, 35.90269007001604, 35.56844350269863, 35.009433133261545, 35.17186117172241, 34.48689038412911, 34.65851436342512, 34.20083999633789, 34.997204303741455, 34.852525438581196, 35.93529101780483, 35.13525111334664, 37.04460913794381, 34.693581921713694, 36.00063187735421, 37.25764785494123, 39.58652768816267, 40.047568457467214, 41.1096944127764, 41.7474695614406, 44.977127756391255, 44.44566004616873, 46.37798534120832, 42.499865668160574, 41.68218081338065, 48.256903307778494, 44.995856625693186, 42.93461792809622, 38.073560919080464, 37.081111499241416, 35.31141921452114, 37.06419610977173, 37.417713505881174, 35.560626779283794, 35.19706923621041, 34.13899755477905, 33.27728891372681, 33.71527208600725, 33.40445831843785, 34.74406405857631, 33.94368369238717, 35.93172311782837, 34.43907288142613, 34.41136346544538, 35.42345196860177, 34.52960443496704, 34.91935321262905, 34.16286809103829, 32.58447708402361, 33.35450424466814, 33.09910930906023, 33.961241790226524, 34.39429521560669, 33.941383838653564, 34.00694356645857, 34.995772974831716, 35.13375377655029, 35.71424102783203, 35.55584989275251, 37.00705759865897, 37.09168665749686, 40.27857174192156, 40.66549955095564, 42.99122837611607, 43.36608369009835, 44.82601833343506, 44.62826912743704, 43.34644113268171, 43.179072925022666, 43.29148088182722, 43.193469592503135, 42.97866255896432, 41.017474446977886, 30.233123302459717, 13.839785865374974, 1.6656993563686098, 0.7831685926233019, 0.5452935940452984, 0.17400316734399113, 0.2081234228930303, 0.016605483866961937, 0.05401173692994884, 0.005182043607679329, 0.2950353313769613, 0.7793952322431973, 1.7477149154458727, 21.375090735299246, 38.8110739844186, 37.33461652483259, 35.949958665030344, 32.522318499428884, 6.190644749573298, 0.05612220475450158, 0.007161104220098683, 0.010292098890723926, 0.03444721443312509, 0.017971476639754007, 0.026914407033473253, 0.026013105575527464, 0.03373336505943111, 0.055181110610387156, 0.032151187637022564, 0.012276011452611004, 0.033335075181509764, 0.031579145296875916, 0.05765485590589898, 0.026042599796450565, 0.03066769634772624, 0.00418962465066995, 0.03459721816969769, 0.2199315471308572, 0.09524258824863605, 0.15996726336223738, 0.1864868953291859, 0.1140042104359184, 0.17959789213325295, 0.12034984278891768, 0.09719360712915659, 0.1230119527982814, 0.25006767575229916, 0.13076813731874737, 0.17707904800772667, 0.08894519295011248, 0.11199160771710531, 0.16805454583040305, 0.20415988271789892, 0.10090475263340132, 0.13994921823697432, 0.135732218090977, 0.1672485140817506, 0.07353618514857121, 0.17318288635994705, 0.16184551614735807, 1.557210617831775, 35.47913135801043, 51.09219912120274, 44.348534652165, 32.56249645778111, 41.58662223815918, 50.99559831619263, 19.294468300683157, 1.211851709655353, 0.3801606707274914, 4.056165959153857, 12.094903860773359, 13.492421099117824, 13.21007149560111, 4.067032941750117, 4.584680684975215, 21.192396538598196, 40.09666095461164, 50.06992455891201, 52.61031103134155, 56.410030705588206, 48.087228298187256, 48.20216539927891, 45.491450786590576, 44.0907495362418, 39.9857816014971, 41.88736459187099, 39.856402669634136, 42.223299571446006, 40.75251184191023, 40.738368783678325, 39.83167403084891, 36.546861035483225, 36.86711393083845, 37.25547306878226, 36.933858326503206, 35.989198616572786, 36.65758058003017, 37.34831837245396, 36.771694319588796, 37.88806138719831, 37.36923592431204, 39.09829861777169, 37.978429658072336, 37.830221108027864, 37.775118419102256, 36.254404408591135, 36.051180022103445, 35.779168469565256, 36.61800364085606, 36.850035258701865, 35.78625910622733, 36.28692545209612, 37.208770751953125, 37.22809369223458, 38.48830236707415, 36.94674028669085, 37.45415333339146, 38.71829121453421, 41.2880095073155, 42.354825496673584, 43.80002301079886, 44.43606110981533, 46.513270241873606, 45.755760260990684, 47.006745202200754, 44.258930683135986, 43.857995305742534, 49.014034611838206, 46.73642553601946, 46.018259729657856, 39.64480570384434, 38.937656266348704, 37.03660133906773, 38.56257166181292, 38.81018114089966, 36.57699537277222, 36.919333117348806, 36.659119606018066, 34.690736634390696, 34.50348963056292, 33.95024626595633, 36.067543029785156, 36.08304793494088, 35.91826098305838, 35.343530314309255, 35.09284973144531, 37.12219272341047, 37.20339632034302, 36.887586797986714, 36.50126000813076, 33.30394567762102, 35.01224020549229, 34.39980513708932, 35.34172378267561, 37.30236646107265, 35.9967165674482, 34.48568139757429, 36.72797277995518, 36.48175641468593, 36.361198220934185, 37.71811192376273, 38.71287161963326, 38.66573504039219, 40.59326260430472, 42.6941442489624, 44.4844205720084, 46.387275082724436, 46.8588284764971, 45.6529894556318, 44.83763919557844, 42.73461750575474, 43.03617627280099, 44.631368024008616, 44.80928707122803, 44.13211563655308, 32.28800092424665, 14.207204001290457, 1.9529818551880973, 0.8814270315425736, 1.2702748775482178, 0.5338777037603515, 0.709369386945452, 0.23382075184157916, 0.291072741150856, 0.144663150289229, 1.1197218533073152, 2.1764658859797885, 3.029687519584383, 26.277725764683314, 39.43540784290859, 43.13443769727434, 44.02572134562901, 37.18351057597569, 6.015282639435359, 0.14827761133866652, 0.11455390522522585, 0.07283884792455605, 0.1528070361486503, 0.09892685019544192, 0.08827520068734884, 0.1881321391889027, 0.09720217024109193, 0.17812598682940006, 0.20682488328644208, 0.09374386724084616, 0.09809216391295195, 0.16127651025141987, 0.1351962297090462, 0.1436364453818117, 0.1267290897667408, 0.127063336116927, 0.09504443566714015], [0.03843431334410395, 0.01791943809283631, 0.08302485277610165, 0.033914449092532904, 0.07699224898325545, 0.044819405901112726, 0.08867432855601821, 0.06685924450201647, 0.009281878143415918, 0.030690562977854694, 0.05778284118111644, 0.06319398832108293, 0.058886539457099776, 0.03105585230514407, 0.06945219822227955, 0.059035918941455226, 0.012583638874015637, 0.02281859324180654, 0.027830261371231506, 0.044098360663545985, 0.06896935270300933, 0.0883018806842821, 0.029803629498928785, 0.10994766346578087, 8.561880367142813, 36.73677962166922, 35.71581826891218, 24.981120688574656, 22.222062247140066, 34.09912184306553, 15.128533397402082, 1.1503272567476546, 0.059590037779084275, 0.7558334022760391, 1.0653370001486369, 1.1199864276817866, 1.3040830748421806, 1.5981260623250688, 0.16320958866604737, 4.95207667350769, 25.70993287222726, 44.63687794549124, 50.39997788837978, 51.271750995091026, 47.42963341304234, 45.90620960508074, 43.62500483649117, 40.37405041285923, 39.77635594776699, 37.69406073434012, 39.425947870527, 39.01473958151681, 38.30963291440691, 37.17567300796509, 35.12209469931466, 35.51419544219971, 35.67914915084839, 34.40100717544556, 32.28251879555838, 34.55527108056204, 32.79374987738473, 33.3274062701634, 33.61983857836042, 34.82597984586443, 36.133801051548545, 36.383811133248464, 36.19348955154419, 35.60698168618338, 35.83429200308663, 35.017826557159424, 36.720201219831196, 35.346479824611116, 34.738130296979634, 34.40418945040022, 33.35787412098476, 33.7934775352478, 33.32402944564819, 32.79270764759609, 32.414906297411235, 31.521128245762416, 32.948145798274446, 34.81813185555594, 34.09970549174717, 35.46743059158325, 38.47890492847988, 40.94438634599958, 42.93378414426531, 42.195180211748394, 46.00673961639404, 39.559940406254356, 39.92761128289359, 45.98187896183559, 44.490802492414204, 42.25306565420968, 37.84108461652483, 34.36560262952532, 33.841534750802175, 31.822898932865687, 30.777549403054373, 30.697669437953405, 32.43158197402954, 32.639284474509104, 30.768464633396693, 32.170340129307334, 31.799535615103586, 33.964837482997346, 33.448294503348215, 31.91781827381679, 31.980775901249476, 32.20890957968575, 33.091900553022114, 33.13841526848929, 32.95286362511771, 32.99854108265468, 31.8092075075422, 31.86186443056379, 31.842871529715403, 30.73227494103568, 33.78458731515067, 32.50123071670532, 31.874847139630997, 32.74665151323591, 32.63469518933977, 31.73252371379307, 32.110974720546174, 33.26439653124128, 34.03584459849766, 35.676804133823936, 36.25330311911446, 37.57480880192348, 41.5592428616115, 43.897947447640554, 44.383098466055735, 43.8140583719526, 42.30422871453421, 42.70999656404768, 42.518525055476594, 37.72650187356131, 31.448602948869976, 16.93247161592756, 3.8387355463845387, 0.17144376039505005, 0.4885320769889014, 0.4778786429337093, 0.10005011063601289, 0.07427278919411556, 0.046794607769697905, 0.032347369074289284, 0.04919485075931464, 0.23577273424182618, 0.9179989291088921, 7.547431213515146, 22.8940920148577, 27.20216621671404, 29.86739444732666, 34.12225587027413, 12.2448433807918, 0.4395116131220545, 0.0012833818764192984, 0.06594777519681624, 0.020126564927133064, 0.0029555766169713543, 0.014840013779965895, 0.043377016870571036, 0.02626444003544748, 0.029910200208957707, 0.017447211646607945, 0.03073420635025416, 0.019776203370253955, 0.030912806945187703, 0.008349563394274031, 0.05268291091280324, 0.04321465361863375, 0.004574880719051829, 0.0206354051229677, 0.013317330307992441, 0.06770678902310984, 0.036556840874254704, 0.08081902364002806, 0.044022554731262584, 0.026714668376371264, 0.06114513826157365, 0.04305544216185808, 0.017807262683553354, 0.021873566987259046, 0.049647552360381396, 0.038116606284997294, 0.02832313733441489, 0.051321657707116435, 0.03780145051756075, 0.025656506585489427, 0.017094760201871395, 0.04016053357294627, 0.030635415044214045, 0.05172777109380279, 0.06295291839965753, 0.05065525828727654, 0.03267547468255673, 0.03106991494340556, 0.10080908598112208, 12.167966774531774, 42.42939703805106, 42.475331578935894, 26.407924583980016, 28.203120231628418, 38.95457860401699, 16.13699320384434, 1.301054528781346, 0.06737102275448185, 0.4979565484183175, 0.8231417419654983, 1.5613775828054972, 1.7229058295488358, 2.1059210428169797, 1.5761438075985228, 9.543761576925005, 29.711827754974365, 45.90607064110892, 52.25155816759382, 53.99136972427368, 47.4877724647522, 47.77235678264073, 45.6195581981114, 42.56813171931675, 40.71018689019339, 38.679627963474815, 40.938480377197266, 39.754719257354736, 40.369336060115266, 38.42197486332485, 35.79266881942749, 37.41498981203352, 36.666491644723074, 35.889109815870015, 34.32175602231707, 36.4741655077253, 36.142402921404155, 34.31828192302159, 35.76460157121931, 37.10141066142491, 35.596694878169465, 37.98642356055123, 38.31019919259207, 36.26404503413609, 36.21540069580078, 37.52623394557408, 37.537225995744976, 36.594890458243235, 36.20406123570034, 35.298304489680696, 33.97283833367484, 34.58004835673741, 34.46873126711164, 34.13644756589617, 34.4156539780753, 34.0355875151498, 35.18901974814278, 35.769218649183, 36.09282405035836, 38.08280897140503, 40.76646729878017, 43.828660011291504, 44.23668255124773, 44.271704946245464, 45.944313526153564, 40.599783488682334, 41.78987441744123, 47.844677107674734, 46.36623246329171, 43.39608253751482, 38.60073116847447, 36.889851910727366, 34.042306423187256, 33.326020104544504, 32.445075375693186, 32.95970760072981, 33.73802743639265, 33.28747149876186, 32.62471062796456, 33.71105800356184, 32.993910108293804, 34.6131773676191, 35.015974862234934, 33.7236133984157, 33.06018202645438, 34.056258405957905, 35.77572911126273, 34.255904470171245, 34.17252261298043, 32.9704703603472, 33.56364154815674, 32.32607357842581, 33.261843068259104, 32.721683161599294, 35.042687211717876, 33.86176790509905, 34.69871664047241, 35.79300928115845, 34.83457824162075, 33.81037555422102, 34.11037792478289, 35.430396693093435, 35.63233913694109, 37.191278662000386, 38.25770902633667, 39.45594324384417, 42.50000810623169, 44.786139147622244, 44.822148186819895, 44.915445123400005, 42.047225270952495, 43.88774054391043, 43.003154958997456, 39.924661772591726, 34.857806069510325, 20.828161546162196, 4.472162859780448, 0.863489062658378, 2.3238827756472995, 0.7280216632144791, 0.24202540729727062, 0.08527220825531653, 0.07791969100279467, 0.002062952349660918, 0.14373225452644484, 1.0229313841887882, 1.3535923553364617, 7.342421139989581, 27.07817040170942, 32.02529648372105, 33.680423395974294, 39.54805898666382, 19.012414864131383, 1.2198781818151474, 0.050468742581350465, 0.0233317896324609, 0.01481623960925, 0.05757391346352441, 0.038415853798921616, 0.02759332542440721, 0.0521890833042562, 0.03227268611746175, 0.02940000972843596, 0.09042294044047594, 0.0016277902426996402, 0.005834680216919098, 0.03304261641044702, 0.008004414682675685, 0.010743391683458217, 0.009222673418532525, 0.016819631215184927, 0.014595050763870989, 0.11684345879725047, 0.09627206836427961, 0.12732763907739095, 0.11986038833856583, 0.1489244316305433, 0.15228940892432416, 0.14017726028604166, 0.15874585961656912, 0.12187011406889983, 0.0949559004179069, 0.1380039533334119, 0.11581728314714772, 0.12053559853562287, 0.07426938294832196, 0.16257773685668195, 0.13474603529487336, 0.1819814635174615, 0.1565306056290865, 0.10356212646833488, 0.23979004153183528, 0.13581134884485177, 0.13965223703001226, 0.11773091474814074, 0.2931571193039417, 12.984988944871084, 50.39491959980556, 48.86073303222656, 34.50126968111311, 30.01407786778041, 41.56733751296997, 23.59561688559396, 1.924921772309712, 0.23728418456656591, 1.8561652217592512, 5.403574960572379, 6.812481599194663, 7.196152874401637, 5.169633890901293, 2.1734204036848883, 8.631340639931814, 32.905716623578755, 47.63993106569563, 52.100757939474924, 54.760531834193635, 49.06661857877459, 48.87642901284354, 48.07033722741263, 45.7174756867545, 43.08017226627895, 40.05584723608834, 43.470650604793, 41.635391644069124, 42.62750407627651, 41.14564439228603, 38.20479849406651, 39.644149099077495, 39.16235753468105, 37.95660884039742, 35.914078167506624, 37.72070360183716, 37.764904567173545, 36.041900702885215, 36.97565521512713, 37.400871072496685, 39.13367884499686, 40.472735677446636, 40.756590434483115, 39.36647476468767, 39.5468430519104, 40.25214079448155, 39.424565179007395, 38.06558438709804, 37.94490112577166, 37.165834358760286, 35.47190523147583, 36.08427776609148, 36.91145386014666, 35.364427021571565, 35.671471391405376, 34.669836453029085, 37.15862907682146, 38.899291787828716, 37.26576335089547, 40.496710436684744, 41.93761396408081, 44.9261349269322, 46.30216659818377, 45.78813886642456, 47.32814107622419, 41.670629433223176, 43.978383268628804, 48.160347666059224, 49.68227066312517, 44.60540607997349, 40.71420989717756, 39.59474045889718, 37.263446126665386, 36.064530985695974, 33.38801540647234, 33.433414936065674, 35.43984276907784, 35.60969843183245, 33.419157232557026, 35.57782704489571, 34.255980900355745, 36.22190420968192, 36.40966190610613, 35.345229148864746, 34.19779668535505, 35.73192419324602, 36.57981286730085, 36.73788091114589, 36.284038475581575, 35.60924679892403, 34.45770795004708, 33.526534693581716, 33.84237895693098, 33.12186813354492, 37.712383134024485, 35.66104561941964, 37.61733872549874, 36.921785831451416, 35.03507546016148, 35.42575182233538, 35.138815539223806, 38.50057635988508, 37.397810391017366, 38.64203126089913, 40.549509797777446, 41.313651834215435, 44.62272793906075, 46.44053302492414, 47.02237517493111, 45.847208976745605, 43.81999908174787, 44.20991809027535, 43.284042835235596, 41.60188395636422, 35.59613902228219, 22.142996958323888, 5.120224382196154, 1.1830196167741502, 1.5816390727247511, 1.9502473047801425, 0.6555640026926994, 0.2573094628751278, 0.15876211731561593, 0.16995376534759998, 0.6533350965806416, 2.6848523318767548, 4.740550058228629, 13.493125472749982, 32.11343090874808, 36.14528642381941, 40.25936344691685, 45.89070817402431, 20.650848729269846, 1.3978993892669678, 0.18374979362956115, 0.13743217901459762, 0.046010533414248905, 0.1540518222110612, 0.06137768578316484, 0.17762718216649123, 0.11236805894545146, 0.1291214685354914, 0.11298643504934651, 0.15949901991656848, 0.16101121662982873, 0.09995502752384969, 0.1256075935172183, 0.09700220597109624, 0.07246494120252983, 0.07445834138031517, 0.08818397165409156, 0.133013409695455], [0.03500044099720461, 0.0072588251371468815, 0.07314684175487075, 0.03376532745148454, 0.04603969006400023, 0.029788735655269453, 0.03801376412489584, 0.028474596528602496, 0.02445712808652648, 0.03838007804006338, 0.03500033582427672, 0.059983683084802966, 0.02174123569524714, 0.09610147108989102, 0.07928953785449266, 0.043725685482578616, 0.050804352786924155, 0.08180209874574627, 0.03317233873531222, 0.052619586632187874, 0.03345791037593569, 0.039958723687699864, 0.08195641796503748, 0.017559217422136238, 1.163629800081253, 24.96778014728001, 37.2241610118321, 30.829987457820348, 22.97024600846427, 30.757826941353933, 24.666544471468242, 1.929992220231465, 0.06998723665518419, 0.4070386370377881, 1.3052846789360046, 0.9591374759163175, 0.8651672697493008, 1.9625275943960463, 2.3436217393193925, 1.9414228754384177, 10.232811825616018, 28.69011425971985, 46.2508020401001, 48.32451275416783, 49.81447751181466, 46.8642133304051, 45.8623560496739, 42.33858060836792, 39.581875869206016, 38.98330593109131, 41.83607646397182, 38.6433618409293, 39.91818952560425, 37.18135316031319, 38.4043299130031, 37.11284392220633, 35.43593093327114, 32.61725868497576, 35.3261250768389, 32.5830249105181, 33.81978341511318, 33.81506906236921, 34.06531538282122, 34.53779288700649, 37.33003418786185, 36.16031885147095, 38.630149841308594, 40.244678429194856, 41.644851616450715, 41.29599298749651, 40.28186171395438, 38.93608944756644, 38.77658660071236, 34.04961245400565, 34.562149797167095, 33.1874452318464, 33.28387580599104, 33.5067184312003, 31.96737630026681, 31.512359619140625, 31.916168076651438, 33.196602957589285, 34.911126545497346, 36.899318831307546, 43.537071909223286, 43.113301277160645, 43.824279172079905, 44.44350610460554, 45.67976781300136, 38.89771454674857, 37.66046272005354, 44.822936807359966, 43.38896410805838, 43.577364512852256, 42.19483975001744, 39.56556844711304, 34.677305766514365, 34.09349032810756, 31.658091136387416, 33.03018317903791, 30.63550737925938, 32.47067601340157, 31.666831970214844, 32.3958751814706, 32.20643254688808, 31.045777661459788, 33.51898547581264, 33.66870525905064, 32.49589450018746, 34.256477696555, 32.62175416946411, 32.97372211728777, 31.457038061959402, 33.22768919808524, 32.92115204674857, 32.82510014942714, 32.99924979891096, 31.710157462528773, 33.04683106286185, 33.33151960372925, 32.77657045636858, 34.94867461068289, 35.07127557482038, 34.75349971226284, 34.53698342187064, 31.452879565102712, 32.41209922518049, 31.676524707249232, 33.274731976645334, 38.300304957798545, 39.404609952654155, 42.30091789790562, 42.391536303928916, 43.0825902393886, 41.65381826673235, 41.63830641337803, 41.30366032464163, 33.22832843235561, 20.77760819026402, 6.475403640951429, 0.5471818755779947, 1.5063393818480628, 2.351201355457306, 0.7370319568685123, 0.09913414264363901, 0.028672467518065656, 0.06538534430520875, 0.06930809774036918, 0.1480729923184429, 0.1911366515393768, 1.9484422930649348, 17.00809407234192, 28.35695161138262, 28.287391458238872, 35.450042724609375, 34.1830004964556, 5.736077964305878, 0.02793892366545541, 0.030727339575865438, 0.010768406725089465, 0.03268675871991685, 0.014018424919673374, 0.085831836797297, 0.029077634348401, 0.03294930088200739, 0.04314452702445643, 0.018006594219644154, 0.03485800292608993, 0.045131036679127386, 0.05571692596588816, 0.01744499453343451, 0.04513972192736609, 0.037972071540674994, 0.05893023032695055, 0.04742674456377115, 0.03778849049870457, 0.04089633694716862, 0.028718685930860893, 0.03327502483235938, 0.031003910449466536, 0.05040760657617024, 0.03458421743874039, 0.03613590489008597, 0.005912642194224256, 0.035613514349928925, 0.011842139198311737, 0.04018044179039342, 0.057756656514746804, 0.012718768274810697, 0.032695956262094636, 0.041326083708554506, 0.04875393191884671, 0.07225889047341687, 0.014302644579272186, 0.04807411786168814, 0.018667477149782435, 0.05049129030002015, 0.029713594687304327, 0.015327554761565157, 0.022792364470660686, 2.3991849635328566, 31.105983802250453, 44.50882959365845, 31.2030188696725, 25.083782059805735, 36.58227252960205, 24.819543804441178, 2.3603163063526154, 0.022526103936667954, 0.07426198691661869, 0.4208401750241007, 0.11073688111667122, 0.2563908078840801, 1.2892127356358936, 2.3859740495681763, 4.08706807238715, 14.736920765468053, 33.99011850357056, 47.98699705941336, 49.82716144834246, 51.609443868909565, 48.438303402491975, 47.505743980407715, 44.62214081627982, 40.8788856778826, 41.76093864440918, 42.92691237585885, 42.1007194519043, 40.20304134913853, 39.267827715192524, 40.199650628226145, 40.55926506859915, 38.52038219996861, 34.951481682913645, 36.149375438690186, 35.299443994249614, 35.00926290239607, 34.84153686250959, 35.91265031269619, 36.58647618974958, 38.371822765895296, 39.201764242989675, 40.19006558826992, 43.01221888405936, 41.331369740622385, 42.24222993850708, 42.42370646340506, 40.075892789023264, 39.73790809086391, 36.39832592010498, 34.79728031158447, 35.64042336600167, 35.12331758226667, 34.79853098733084, 33.04560470581055, 32.985600062779014, 34.747322763715474, 35.15870475769043, 37.35109765189034, 38.753838198525564, 44.47118425369263, 44.50420209339687, 45.37374135426113, 47.51419646399361, 46.244378430502756, 42.3598872593471, 40.78633567265102, 46.904057775224956, 46.55176673616682, 44.18708283560616, 43.46219464710781, 40.5849803515843, 35.992849894932334, 34.22247668675014, 33.23721865245274, 33.60779735020229, 33.302514348711284, 34.42676067352295, 32.20187105451311, 32.60864291872297, 33.1129674911499, 33.36627796718052, 33.88805294036865, 34.371383530753, 32.93436752046858, 35.18107100895473, 34.6752803666251, 33.32903214863369, 33.9134520803179, 34.89184529440743, 33.62429237365723, 33.81196321759905, 34.362364768981934, 33.612695830208914, 35.36759540012905, 36.04947076525007, 35.28891052518572, 37.07799175807408, 37.48828288487026, 35.29532371248518, 35.706500734601704, 32.94815274647304, 34.648046902247835, 33.699899196624756, 36.046430928366526, 38.396579197474885, 42.87327923093523, 44.505147048405235, 43.993843010493684, 43.10737793786185, 43.27992255347115, 41.76156745638166, 42.19861262185233, 35.48065301350185, 25.169102464403423, 7.601071306637355, 2.1329176170485358, 2.0653207642691473, 4.86626946074622, 1.195525505713054, 0.04670765011438301, 0.1289995222219399, 0.021782424467216645, 0.14786502133522714, 0.2951645515859127, 0.1870733124337026, 4.125838586262294, 19.415962764195033, 33.01847546441214, 29.876760619027273, 36.71319743565151, 39.488516398838584, 8.308820026261465, 0.14052768291107245, 0.004083827894646674, 0.035571404466671605, 0.028728399159652845, 0.057525615340897014, 0.06436376233718225, 0.056867181922176054, 0.04468073709202664, 0.04167247922824962, 0.06369691169155495, 0.023937185361449207, 0.05063671053254178, 0.03780790677826319, 0.028184556734881232, 0.07478040802691664, 0.025468279274978807, 0.017167729857776846, 0.05353834679616349, 0.012700849013136966, 0.08762802755726234, 0.09333864612770931, 0.21548772629882607, 0.1269597238195794, 0.08702432816582066, 0.13376186096242496, 0.11832551498498235, 0.13361772655376367, 0.11956295929849148, 0.09600422345101833, 0.0954968896029251, 0.201769566695605, 0.17835615947842598, 0.20940182358026505, 0.30140883794852663, 0.11643282297466483, 0.162240043548601, 0.18388593489570276, 0.1371319136981453, 0.10580087812351328, 0.14552469977310725, 0.08603367382394415, 0.13797204861683504, 0.05494402368952121, 2.467181771993637, 35.72810615812029, 51.614992005484446, 41.69155740737915, 32.94753783089774, 41.17170013700213, 32.98978982652937, 3.495325173650469, 0.21873675552862032, 1.635652522955622, 2.5779812208243778, 2.381972972835813, 1.8328746429511478, 6.036916724273136, 5.407243175165994, 4.821800555501666, 15.767616544451032, 34.47193438666207, 47.927523953574045, 50.507341453007285, 52.42083018166678, 50.604095118386404, 49.48790522984096, 46.39012731824602, 42.65191657202584, 43.09782416479928, 46.455377851213726, 43.11212355749947, 42.59272486822945, 40.87821865081787, 42.079405852726524, 41.849764415196006, 40.491996083940776, 36.24510077067784, 38.69956929343087, 36.253428186689106, 37.39202948978969, 36.60328388214111, 38.42140858513968, 38.40773453031267, 42.01977293831961, 40.809973444257466, 43.762023312704905, 44.95952449526106, 44.86673130307879, 44.65772601536342, 44.11065265110561, 41.586326939719065, 42.89757708140782, 38.666457653045654, 37.97723456791469, 37.749368395124165, 36.62571961539132, 36.47730261938912, 34.689089911324636, 34.74995960508074, 36.133655139378135, 36.625014373234336, 39.573979241507395, 40.339632511138916, 47.6267294883728, 46.542699337005615, 47.013682978493826, 49.63443578992571, 45.90410082680838, 42.198438916887554, 41.572767530168804, 48.17229856763567, 46.90769863128662, 45.417410782405305, 45.862317834581646, 43.35079417909895, 38.4806524004255, 36.316993781498496, 34.85064942496163, 35.81110239028931, 34.323632035936626, 35.67107534408569, 34.00480004719326, 34.27491821561541, 34.41290943963187, 34.341158866882324, 36.66856915610177, 36.75944464547293, 35.46206658227103, 35.992644923073904, 36.20558289119175, 35.99281167984009, 34.466990743364605, 37.51926490238735, 35.35836124420166, 36.75933000019619, 36.37285729816982, 34.39406245095389, 36.417527266911094, 36.818042278289795, 36.17020613806588, 39.18244130270821, 39.327467577798025, 38.05919551849365, 37.47294473648071, 34.35000739778791, 36.59334100995745, 35.08719389779227, 37.145837443215505, 41.907149587358745, 43.74556997844151, 46.00672571999686, 46.139648233141216, 45.0062962940761, 42.78893157414028, 44.084339823041645, 44.420306069510325, 37.07896450587681, 24.065344640186854, 7.415827989578247, 1.522970546569143, 2.3614427830491747, 6.408165054661887, 1.9519226891653878, 0.16312545032373496, 0.2730886861681938, 0.1657479881708111, 0.5194872788020543, 0.6004476345011166, 0.5772502592631749, 7.36349242074149, 25.582558495657786, 38.72218220574515, 37.46136556352888, 43.49988167626517, 45.14484337397984, 10.60817175252097, 0.1979884710162878, 0.13171449010925634, 0.06385622492858342, 0.17135694862476417, 0.16501656813280924, 0.18218480689185007, 0.1382710789995534, 0.13516253366002015, 0.10623708114560161, 0.13951924416635716, 0.08193057256617717, 0.11365037477974381, 0.15528322756290436, 0.05021089927426406, 0.1653055019144501, 0.06233541760593653, 0.12550400836127146, 0.13148190187556402, 0.1582546816872699], [0.03470209254217999, 0.006561792405721332, 0.012609586053128754, 0.05396910796740225, 0.01801024473804448, 0.045289057306945324, 0.025734339641141038, 0.03979558690584131, 0.03896587767771312, 0.03095278962116156, 0.02386332003931914, 0.026187587462897812, 0.03219272415818913, 0.019887320264907818, 0.03279162969972406, 0.05908254108258656, 0.06037101801484823, 0.08012478732104812, 0.019376400359241024, 0.019280787989763275, 0.016788849474063942, 0.04925339136804853, 0.05182980918990714, 0.03457571539495673, 0.07874269969761372, 4.3854228513581415, 34.90266711371285, 38.49711268288748, 25.832695381981985, 25.97516471999032, 30.567237854003906, 5.173725077084132, 0.058284373554800234, 0.1241329876439912, 0.4570506034152848, 1.001952818461827, 0.31433493005377905, 0.3804857161428247, 1.5743309791599, 1.7057793885469437, 2.0726265779563358, 12.024595907756261, 34.71405478886196, 50.40709979193551, 50.72999995095389, 49.205704144069124, 45.00821052278791, 42.75486108234951, 41.119845730917795, 43.97243561063494, 41.21432386125837, 39.59548739024571, 39.260007517678396, 38.03324747085571, 38.282819816044395, 36.48148890904018, 37.59895726612636, 38.12129851749965, 33.55547741481236, 33.89152703966413, 33.066431931086946, 32.38923270361764, 34.650867870875764, 35.48840372903006, 38.5079345021929, 40.409329891204834, 42.10735845565796, 42.775618825639995, 42.49683625357491, 45.0845364843096, 45.51941728591919, 46.625115394592285, 44.48031071254185, 39.12604624884469, 34.59674835205078, 32.946043968200684, 33.46586997168404, 32.16574042184012, 33.68474517549787, 33.99149077279227, 33.13291924340384, 31.97087471825736, 36.49128586905343, 41.70308794294085, 43.081419467926025, 45.13005065917969, 45.46895946775164, 43.36432579585484, 40.76819740022932, 39.60175813947405, 37.80019794191633, 45.4421637398856, 44.095220702035085, 43.34543364388602, 43.3311550957816, 42.46050064904349, 39.68698821749006, 37.44472810200283, 34.48798819950649, 33.20086567742484, 31.95117310115269, 32.1470810345241, 33.260863372257774, 30.751622200012207, 32.45340626580374, 31.531630447932653, 33.961999143872944, 32.4979372705732, 32.71343217577253, 32.40058258601597, 33.40683807645525, 32.96933780397688, 33.57807295663016, 33.53008869716099, 33.50140305927822, 31.81185129710606, 33.419761725834434, 31.72108350481306, 31.32958378110613, 33.08657128470284, 34.47121524810791, 36.283499990190776, 36.88321985517229, 37.47944130216326, 36.77708264759609, 33.20106022698538, 35.126114232199534, 31.75032499858311, 32.54630715506417, 34.722479479653494, 38.12538753237043, 42.272544928959434, 42.02968454360962, 44.39728321347918, 43.196523325783865, 44.27945566177368, 36.42660508837019, 23.914930037089757, 9.804357239178248, 1.2164590167147773, 0.8580023742147854, 0.9088456545557294, 4.197622162955148, 0.1975372859409877, 0.02738397192609097, 0.09688277702246394, 0.036434104067406485, 0.07388757807867867, 0.06448857885386262, 0.4196662823004382, 3.31448267187391, 20.351395266396658, 32.61106784003121, 26.956675938197545, 34.56044054031372, 21.67549783842904, 1.4082710955824171, 0.015255027849759375, 0.044208395294845104, 0.037781423556485345, 0.010051816069920148, 0.03190044180623122, 0.05493312641712172, 0.02165986747214837, 0.027929872008306638, 0.02574688914631094, 0.044630647636950016, 0.07158430452857699, 0.04487777687609196, 0.031491407326289585, 0.04452695730807526, 0.05803087965718337, 0.018857366871088743, 0.0309022150135466, 0.052027496974915266, 0.06021378109497683, 0.04132324064682637, 0.06774079041289431, 0.028047339990735054, 0.04512682297666158, 0.03399361038048353, 0.02589706251663821, 0.020587027272475616, 0.047643692565283606, 0.039638336415269544, 0.03999227045902184, 0.037797884816037755, 0.019901282819254056, 0.01094868839053171, 0.04170362737828067, 0.026342651374371986, 0.07076514991266386, 0.07320046637739454, 0.029768433887511492, 0.040866321950618706, 0.03241035408739533, 0.024352435222161666, 0.03547894389235547, 0.03090716153383255, 0.037610568438789675, 0.09410042382244553, 9.075426067624774, 41.48034259251186, 41.88296638216291, 25.975751842771256, 30.639679772513254, 33.28793355396816, 5.05965085540499, 0.05059967948389905, 0.03945960011333227, 0.20031043142080307, 0.11855650187603065, 0.0652925953535097, 0.27307671681046486, 1.199966924531119, 0.5011303009731429, 2.9288413652351926, 15.012712138039724, 38.19763837541853, 52.46238040924072, 52.56178133828299, 51.095916407448904, 48.82169457844326, 43.006719384874614, 44.33942208971296, 46.538085733141216, 43.32481139046805, 42.69851119177682, 40.54843977519444, 40.025240421295166, 39.204421928950715, 38.10108273369925, 38.74014329910278, 38.16680227007185, 36.32543584278652, 36.28920793533325, 34.40447085244315, 33.14430386679513, 34.867589133126394, 37.12570851189749, 40.32158803939819, 41.99227196829659, 43.904527391706196, 44.17345394407, 45.01240028653826, 46.518686362675254, 47.25078330721174, 46.76955107280186, 44.32014083862305, 39.32474735804966, 36.792427744184224, 34.82138361249651, 35.6257209777832, 34.368843964168, 35.262212072099956, 34.517893246241975, 34.41507380349295, 32.89008665084839, 37.11994498116629, 43.87898928778512, 45.96904911313738, 46.84526211874825, 46.54620122909546, 45.40729767935616, 43.06151287896292, 39.28393016542707, 39.98779310498919, 46.63492277690342, 46.957583223070415, 45.38300677708217, 44.872310706547324, 43.109566620418, 40.77195290156773, 37.832281248910085, 35.815594400678364, 33.69213111060006, 32.25728293827602, 33.69645983832223, 34.714537688664024, 32.91834497451782, 33.41194500241961, 33.359788349696565, 35.5519380569458, 34.47069065911429, 35.1690263066973, 34.40705558231899, 34.68744318825858, 34.19686562674386, 34.45712777546474, 35.47060244424002, 35.36264828273228, 33.746959345681326, 34.59865910666329, 33.745767729622976, 33.94927699225289, 33.827016489846365, 35.42430312292916, 37.30813694000244, 39.252030985695974, 37.957084792000906, 38.78810671397618, 34.42376252583095, 36.32885783059256, 33.604225976126536, 34.200926848820274, 36.933034964970176, 39.0298866544451, 44.06247731617519, 44.51307494299752, 45.715373856680735, 43.61515576498849, 42.887526512145996, 40.167827878679546, 27.0540896824428, 12.723494359425136, 2.4154761007853915, 2.399688707930701, 3.2323645183018277, 7.118242289338793, 1.141367337533406, 0.020259532345724956, 0.08925786867205586, 0.07732262089848518, 0.19695911982229777, 0.05103347031399608, 0.77361910790205, 4.853370130062103, 23.401392153331212, 36.693898814065115, 28.656182731900895, 40.45428821018764, 27.84520809991019, 3.0380038619041443, 0.055327287409454584, 0.021669555255877118, 0.046313672326505184, 0.03307325565921409, 0.05976913031190634, 0.015053385901930076, 0.010723182366096547, 0.050346168622906716, 0.031132299453020096, 0.0375207914704723, 0.011931208793872168, 0.04078482650220394, 0.04874402191489935, 0.02493968013940113, 0.01689744052211089, 0.021002534976495162, 0.052786943901862414, 0.048359648790210485, 0.04754804626905492, 0.15625750885478087, 0.12073561708842005, 0.08029201906174421, 0.09263066268925156, 0.12473862086023603, 0.12567404923694475, 0.09434746485203505, 0.07327632659247943, 0.11634280851909093, 0.15062455540256842, 0.11726504617503711, 0.11271200834640435, 0.07886394033474581, 0.13404419938368456, 0.10729493759572506, 0.137070519849658, 0.16938672720321588, 0.10801289549895696, 0.10015453039003269, 0.12631042008953436, 0.09390954513634954, 0.2034704911389521, 0.17400463297963142, 0.11744674428233079, 0.24285669411931718, 10.164917503084455, 48.95194203513009, 49.703667640686035, 35.451105798993794, 35.65582752227783, 40.10005167552403, 7.4018508195877075, 0.29182420511330875, 0.2946374655834266, 2.0714191113199507, 3.28217984523092, 1.110591920358794, 2.098805001803807, 5.652955796037402, 4.712214870112283, 4.138552486896515, 16.77818512916565, 36.73022747039795, 50.25863068444388, 53.6227399962289, 52.16419499261038, 50.36833579199654, 46.39407736914498, 45.90505967821394, 49.478886468069895, 45.56080770492554, 43.86331067766462, 43.47677891595023, 43.18945353371756, 41.667738982609336, 40.71952179500035, 41.512141023363384, 41.06839779445103, 36.956787381853374, 38.72302641187395, 35.750336919512065, 36.228550161634175, 37.00500440597534, 39.63593980244228, 42.90226016725813, 43.33017539978027, 46.75706515993391, 46.691230978284565, 46.70814984185355, 48.93563461303711, 49.81722552435738, 50.136293751852854, 47.41113730839321, 41.97432477133614, 38.31472246987479, 35.86759124483381, 37.10697616849627, 36.10332972662789, 37.081521442958284, 36.395748138427734, 35.5270357131958, 34.77293382372175, 40.69128779002598, 44.68257277352469, 46.69480930055891, 48.904888834272114, 48.82883732659476, 45.32812295641218, 42.407934052603586, 39.851205417088096, 43.31917987551008, 47.72321564810616, 48.5618006842477, 47.29944501604353, 47.268793037959504, 45.551424162728445, 43.419828006199424, 40.71845524651663, 37.490860666547505, 35.99803672518049, 33.91804831368582, 35.856633935655864, 36.68861470903669, 33.74123403004238, 35.715203353336875, 34.85590921129499, 37.38682528904506, 36.03687368120466, 36.02152511051723, 34.997127873556956, 36.85963766915457, 36.041053022657124, 37.12610455921718, 38.20841155733381, 37.387537479400635, 36.163087708609446, 37.537590776171, 34.789668560028076, 35.21349825177874, 35.418598651885986, 38.01026282991682, 39.55078962871006, 41.0292238507952, 39.49394294193813, 40.669157777513774, 36.16350112642561, 39.56696850912911, 35.02430575234549, 36.49436044692993, 38.47225202832903, 41.048612798963276, 45.79475007738386, 46.449162687574116, 47.394541536058696, 44.710567065647666, 44.59551879337856, 39.766972405569895, 26.945894071034022, 11.508409891809736, 1.727178971682276, 2.2223976041589464, 2.818874397448131, 14.302698305674962, 3.0023719796112607, 0.28356013713138445, 0.3228227517434529, 0.22350606960909708, 0.5885359793901443, 0.24185973618711742, 2.1207378591809953, 6.900665095874241, 27.48410848208836, 45.74714796883719, 34.89851556505476, 47.276477745601106, 30.48926864351545, 3.198414751461574, 0.15076684419597897, 0.10967726047549929, 0.1845285211290632, 0.0814534267410636, 0.09245445393025875, 0.11081758607178926, 0.12057335222406046, 0.13833179431302206, 0.0862850167655519, 0.18155602206076893, 0.09942052513360977, 0.10734177686806236, 0.11660617510122911, 0.201620058289596, 0.11975184987698283, 0.1481611475880657, 0.071037683502904, 0.1120599904762847, 0.13238484199557984], [0.043078960185604434, 0.029451666599405662, 0.009547915609021271, 0.05293925805017352, 0.017285881464236548, 0.05733531340956688, 0.09382434827940804, 0.040541856682726314, 0.03059924573504499, 0.0883944532168763, 0.06016191387815135, 0.021114651013963988, 0.009962444526276417, 0.030049795218344246, 0.045478025916963816, 0.030887097253331115, 0.05142487984682832, 0.053017086016812494, 0.07313473669013806, 0.053692713512906005, 0.08856056537479162, 0.042545065084206204, 0.06331561572317566, 0.05764894586588655, 0.07286229130945035, 0.9813010351998466, 20.333795479365758, 37.807653359004426, 28.281073808670044, 21.552037034715923, 28.136422736304148, 11.255725622177124, 0.35360289152179447, 0.13652253496859754, 0.12258353935820715, 0.10799591176744018, 0.18359366272177013, 0.09295547740267855, 0.8153878780347961, 1.0807612410613467, 0.17896464254174912, 2.448263781411307, 16.314861876623972, 39.144789014543804, 51.244121483394075, 49.73993723733084, 48.521466391427175, 45.760856764657156, 44.829127652304514, 41.828294481549946, 41.299477509089876, 40.62524168831961, 39.75780078342983, 40.875769410814556, 39.64783511843, 42.11211797169277, 39.56002378463745, 38.018336636679514, 36.31430830274309, 34.836256231580464, 33.76486485345023, 33.47394725254604, 32.871826784951345, 35.67242329461234, 38.37602990014212, 41.5146666935512, 41.33732087271554, 43.78204107284546, 42.808094705854145, 45.21203940255301, 46.90907437460763, 48.17676625932966, 44.8734085219247, 43.68085445676531, 36.619542666843955, 32.75729962757656, 33.76262753350394, 33.34441198621477, 32.9477219581604, 32.935044969831196, 33.38429117202759, 35.920606000082834, 38.502938747406006, 45.4018885067531, 47.81592198780605, 46.708980151585166, 46.513721874782014, 41.27370664051601, 44.69539567402431, 51.3184289932251, 36.919941084725515, 45.23677846363613, 44.70766271863665, 45.73133734294346, 42.10529831477574, 41.418156215122764, 40.99953767231533, 41.123187814440044, 39.44430153710501, 38.088009698050364, 35.5516288621085, 33.797861848558696, 32.22403233391898, 32.092204162052695, 31.363101891108922, 32.724049023219514, 32.97159249441964, 32.190931115831646, 31.923547063555034, 33.25279303959438, 32.64885561806815, 32.65473031997681, 36.6939821924482, 39.38792732783726, 39.29548501968384, 37.62497826984951, 33.71155827386038, 31.80461127417428, 32.61642142704555, 32.07719605309622, 32.2781205858503, 34.887339387621196, 37.54513304574149, 36.93519932883126, 37.40305280685425, 36.76129634039742, 36.05161428451538, 34.59664065497262, 33.492592743464876, 33.80940628051758, 36.87280797958374, 39.71386732373919, 41.37580347061157, 42.41117886134556, 43.2269355910165, 38.58340236118862, 28.42184952327183, 11.100525447300502, 3.5784360510962347, 0.5146941617131233, 3.7251676746777127, 4.268619724682399, 4.265670648642948, 0.8896720462611744, 0.037128435381289036, 0.03951885996918593, 0.0350864928082696, 0.05686545505055359, 0.06414836818086249, 0.2956203371286392, 4.437371926648276, 27.86090234347752, 25.627129452569143, 26.305931976863317, 29.5988187789917, 10.843218888555255, 0.05531613907909819, 0.07107296053852354, 0.03454406512901187, 0.05208386966426458, 0.03637529543734022, 0.026507664305557097, 0.011109847242810895, 0.02268106267521424, 0.07437754143029451, 0.0623007919639349, 0.011935307993553579, 0.03314509894698858, 0.08999050328774111, 0.03192603614713464, 0.046046902891248465, 0.054675890398877006, 0.03433658269100955, 0.08900993876159191, 0.02989219528223787, 0.049960455391556025, 0.03094921713428838, 0.054353070578404834, 0.06952382437884808, 0.009488805879040487, 0.027392585928152715, 0.0516983464227191, 0.008140061466422464, 0.03917475111250367, 0.03663739315899355, 0.04643322001876576, 0.02543122787028551, 0.04657414834946394, 0.019697662941845398, 0.028226724293615137, 0.024127298999311667, 0.02264127168538315, 0.028661244548857212, 0.05556128021063549, 0.008745378315714853, 0.04985468535284911, 0.04958050970786384, 0.006156519554289324, 0.0012177920309893253, 0.06705409261797156, 0.01289922890386411, 1.8067649411303657, 26.738328797476633, 43.399806771959575, 30.167476722172328, 26.459858894348145, 32.165823800223215, 10.879917536463056, 0.4783921039530209, 0.13793482418571199, 0.07837399055383035, 0.05086178399090256, 0.12949072729263986, 0.10200825413422925, 0.7449365641389574, 0.5408525552068437, 0.19267721101641655, 4.483213535376957, 20.384539910725184, 40.13887473515102, 53.34454802104405, 51.40030656542097, 51.27797310692923, 47.271228381565635, 47.8342478615897, 43.417069571358816, 43.15630715233939, 42.274921212877544, 41.157386847904746, 43.014119216373985, 41.85651806422642, 43.176363127572195, 41.53536190305437, 39.00999048777989, 37.80213301522391, 37.18220778873989, 35.696415424346924, 35.510804721287315, 35.3018411227635, 37.47350059236799, 39.5590614591326, 43.25033712387085, 43.55038118362427, 44.86786733354841, 45.17372356142317, 45.70339863640921, 47.41369424547468, 50.33664853232247, 45.2895187650408, 45.484863894326345, 37.015322480882915, 34.332685538700645, 34.557244368961875, 35.06927796772548, 34.42212275096348, 34.90620027269636, 35.59337363924299, 36.63428674425398, 40.949232714516775, 47.13163212367466, 47.455477237701416, 47.97110652923584, 48.753671714237754, 41.178908893040244, 42.96372045789446, 48.46782977240426, 38.10943794250488, 45.88186659131731, 45.95873103822981, 47.31481095722744, 43.84337977000645, 43.032059465135845, 43.54068149839129, 42.34767232622419, 40.65095697130476, 37.72521645682198, 35.66670840127127, 34.097530705588206, 34.81321253095354, 33.698697158268516, 33.31158174787249, 35.02021326337542, 34.602376392909456, 33.874497004917686, 34.80599682671683, 35.200119495391846, 33.743339334215435, 34.814372880118235, 38.18726124082293, 41.85052524294172, 40.72246783120291, 39.71712255477905, 34.99102735519409, 33.24814469473702, 33.3702905518668, 33.978918007441926, 33.69746732711792, 37.69477987289429, 38.87371546881539, 38.75696836199079, 39.62583017349243, 38.76565708432879, 37.68861334664481, 35.75929314749581, 34.656933648245676, 35.84066350119454, 38.28420598166329, 41.53528894696917, 43.157446656908306, 45.92070354734148, 44.22426264626639, 39.948028564453125, 30.553977216993058, 13.829373121261597, 4.576053627899714, 2.2801429969923834, 4.220687142440251, 7.229693566049848, 7.484485745429993, 2.6639371684619357, 0.26985956515584675, 0.02143954375891813, 0.055206623527088335, 0.03768730057137353, 0.014760109496169856, 0.7071629539132118, 4.851477180208478, 32.1164116859436, 29.966117927006312, 30.123668330056326, 35.43332883289882, 15.246246303830828, 0.15767500922083855, 0.04893985729930656, 0.018831826812986816, 0.017107175696375113, 0.07956941319363457, 0.028235331510326693, 0.01917765405960381, 0.04397318113063063, 0.06860727963170835, 0.03830776995580111, 0.01710699588459517, 0.046796775689082484, 0.04802712591897164, 0.1059855210727879, 0.019549228317503418, 0.024034773964168768, 0.04459252753960235, 0.04120206447052104, 0.07563684814210449, 0.03504335833713412, 0.10525989572384528, 0.12561129831842013, 0.14506268527890953, 0.21069660410284996, 0.09229315937097583, 0.11260954955858843, 0.14382391103676387, 0.12789920983569963, 0.11310509725340775, 0.20921253945146287, 0.152624550940735, 0.14271325777683938, 0.10856997953461749, 0.11828759844814028, 0.14331787319055625, 0.08986481824623686, 0.1987151141677584, 0.15673886159701006, 0.15013253608984606, 0.09121270770473139, 0.1919685219015394, 0.14750854617783002, 0.13764667750469275, 0.15366142030273164, 0.1361094835613455, 2.244050145149231, 31.42627838679722, 49.6559613091605, 37.2195474079677, 30.0379900932312, 36.46376058033535, 15.571031161717006, 0.9869241906063897, 0.5331196444375175, 0.39165763237646645, 0.568789578974247, 0.49363867725644794, 0.18864926429731504, 3.4743715780121938, 3.3671953976154327, 0.5700695674334253, 5.343654130186353, 20.41026735305786, 41.23553671155657, 53.54258905138288, 53.08470971243722, 51.56843907492501, 49.03727633612496, 50.37809106281826, 44.90885475703648, 46.2385766846793, 45.186410972050254, 44.006794452667236, 45.48512445177351, 43.367667879377095, 46.76538562774658, 43.68091699055263, 40.97646965299334, 39.508412565503804, 38.41264343261719, 36.75924662181309, 36.238041400909424, 36.6080572945731, 39.060434409550254, 41.39067956379482, 45.20988198689052, 45.05284227643694, 47.94365419660296, 46.44335399355207, 48.61664628982544, 50.303380557468955, 52.501338958740234, 46.21701642445156, 48.59081288746425, 39.38970259257725, 36.27115651539394, 37.09170055389404, 37.71999488558088, 35.85037708282471, 36.443614278520855, 36.73063394001552, 38.756214482443674, 42.090856484004426, 49.2265556880406, 51.51134920120239, 50.402117933545796, 49.209907804216655, 41.02486733027867, 41.459369455065044, 48.521250997270855, 41.32852445329939, 46.880604130881174, 47.038164956229075, 48.767085211617605, 45.085755893162315, 42.751022202628, 44.88137115750994, 44.32257270812988, 42.10676091057913, 40.75294610432216, 38.23743070874895, 35.35374764033726, 35.70486095973423, 34.98017079489571, 33.682268142700195, 35.984703132084434, 36.42168576376778, 36.09812899998256, 35.97214426313128, 37.174081870487754, 36.53134223393032, 36.471424443381174, 40.01619734082903, 42.97257246289934, 42.730994020189556, 41.39501176561628, 36.95270878928048, 34.350702217647004, 35.67256573268345, 35.09268644877842, 36.17313132967268, 38.967224325452534, 40.84088945388794, 40.75892850330898, 40.97383281162807, 41.11773695264544, 40.55818114961897, 37.378456183842246, 36.30440711975098, 38.420974322727744, 41.04115390777588, 44.16651269367763, 44.93052618844168, 46.339474950517925, 45.229767731257844, 40.205077171325684, 32.09725897652762, 13.364035759653364, 4.756657719612122, 1.1802978771073478, 7.086117293153491, 9.648719327790396, 8.427900859287806, 5.227047724383218, 0.5526997223496437, 0.34957730610455784, 0.20762372256389686, 0.21264940074511937, 0.18162444553204946, 0.7923771813511848, 7.045570646013532, 36.791937896183555, 33.46357706614903, 35.662747928074424, 41.60842221123831, 16.19179538318089, 0.16316339400197777, 0.22035031180296624, 0.08477991752858673, 0.2587550953030586, 0.2104046983378274, 0.10304256541920559, 0.1475197962884392, 0.18619536954377378, 0.21015522815287113, 0.25687938023890766, 0.10287109961999313, 0.09725466171013457, 0.12570864095219544, 0.20982438804847853, 0.07411118250872407, 0.14095560780593328, 0.07648481335490942, 0.17969299560146673, 0.15869306959211826, 0.1474836982254471], [0.05723579267838171, 0.07676980484809194, 0.028019998422158614, 0.07413506015603032, 0.05156537052243948, 0.05747081006744078, 0.08368474843778781, 0.020624433211716156, 0.05217125140396612, 0.007928086278427924, 0.01669698261788913, 0.013791872254971946, 0.041899394909186025, 0.023497742334646837, 0.04951177750314985, 0.07903442904353142, 0.039455410159592114, 0.03183653059282473, 0.03071821667253971, 0.0280716145810272, 0.053778314098183594, 0.0229773314204067, 0.06231099713061537, 0.04393060984356063, 0.03481061743306262, 0.048309586476534605, 5.754321328231266, 34.91090767724173, 30.92849554334368, 21.127449989318848, 24.61580525125776, 21.15573263168335, 2.812414526939392, 0.4291624070278236, 0.021067692997998426, 0.14204100599246366, 0.11796025958444391, 0.15102955938449927, 0.4691712473120008, 0.2524181753396988, 0.27155915967055727, 1.9523767105170657, 5.680402483258929, 17.77507792200361, 44.46662623541695, 51.10199955531529, 49.69659437452044, 46.97438396726336, 44.49807725633894, 44.37258236748831, 42.212665353502544, 41.97647871289934, 41.98997906276158, 42.228729588644846, 42.46927969796317, 41.13434662137713, 42.32580287115914, 38.838046891348704, 38.31428473336356, 35.109257902417866, 34.96093470709664, 32.75756713322231, 33.83185591016497, 36.06349917820522, 37.75620542253767, 40.67943068913051, 41.08492408479963, 41.696004254477366, 42.24842773165022, 42.152195181165425, 47.063202789851594, 48.80166987010411, 50.852055481501985, 45.51302146911621, 42.04133667264666, 34.58439792905535, 33.66865314756121, 33.52268539156233, 32.95073052815029, 34.05139466694423, 34.60723665782383, 35.2710154397147, 40.168300356183735, 46.3272739137922, 46.98926700864519, 45.77256447928292, 41.47970335824149, 41.533520630427766, 38.92148086002895, 37.960430349622456, 38.89660630907331, 42.68656029020037, 45.06055130277361, 46.35966294152396, 43.84551286697388, 42.378612654549734, 43.32351902553013, 43.29704986299787, 42.24104527064732, 41.886937277657644, 39.18080152784075, 33.92331504821777, 31.28436837877546, 32.597702980041504, 32.11714472089495, 32.581086363111226, 33.0400322505406, 33.45470421654837, 33.7605812890189, 33.93229212079729, 34.33405433382307, 39.64589657102312, 43.11534752164568, 43.96663039071219, 41.51740428379604, 40.08046817779541, 35.5277270589556, 32.957011699676514, 31.30880171912057, 31.726398876735143, 32.86791147504534, 35.67502539498465, 36.38274111066546, 37.18609183175223, 38.56612566539219, 37.71374845504761, 38.0689959526062, 37.093159675598145, 37.182808807918, 36.21991007668631, 38.7840906551906, 40.52600751604353, 41.62133543831961, 42.47054079600743, 43.25532245635986, 34.96087564740862, 15.111722230911255, 2.886353130851473, 1.2050506174564362, 2.9617994938577925, 3.1257934825760976, 6.039662131241389, 7.386596918106079, 1.0186060220003128, 0.13142349358115876, 0.0867660641670227, 0.03621541901624628, 0.07865360804966517, 0.028201131649049263, 0.25870485657027786, 10.704736948013306, 29.12143932070051, 22.973077399390085, 30.00262028830392, 24.16275143623352, 3.0237402958529334, 0.04972845069797976, 0.09687744373721735, 0.018494674636583244, 0.04795621900952288, 0.027326374481033002, 0.049230446706392934, 0.017354130212749754, 0.027869965847847716, 0.03465204719187958, 0.007997033918010337, 0.04073996176677091, 0.039623018487223556, 0.003711655253677496, 0.06605107536805527, 0.08685529152197496, 0.01695549937098154, 0.032905769467886, 0.038559211284986565, 0.016166685448427285, 0.021025444015062282, 0.04152537962155683, 0.040815645562750955, 0.01946481177583337, 0.05645187099331191, 0.022109451204804436, 0.03456702336136784, 0.0520645789136844, 0.012138079702188926, 0.0750678354608161, 0.061215373421353955, 0.08750325175268309, 0.014160348152342652, 0.05786550710243838, 0.006859488618959273, 0.03590178316725152, 0.03954935333292399, 0.033943056128919125, 0.08831119018473796, 0.05017264007723757, 0.0625068291223475, 0.004108350574305015, 0.05308971979788371, 0.044501410464623144, 0.03216616629755922, 0.07202815464032547, 0.18576224707067013, 10.401923162596566, 40.330763135637554, 35.85740518569946, 23.625718218939646, 28.918475491659983, 21.097369500568934, 2.3895723479134694, 1.009407367025103, 0.02224252379632422, 0.16418585128017835, 0.12130929130528655, 0.5001432225108147, 0.05746576176690204, 0.0014715713373984077, 0.48361128675086157, 3.4126724430492947, 7.51054322719574, 21.3888829095023, 44.58759437288557, 50.72143977028983, 50.11347934177944, 49.243710790361675, 47.168877942221506, 46.69160270690918, 44.731060777391704, 43.87242324011666, 44.23031800133841, 43.81834888458252, 42.85870885848999, 42.01625714983259, 42.97610214778355, 40.879636083330425, 40.071974005017964, 37.60564490727016, 35.38106448309762, 35.15704761232649, 35.17489753450666, 36.102621010371614, 39.87743834086827, 41.124973501477925, 42.88948590414864, 44.41224615914481, 45.02660935265677, 44.94041347503662, 48.22357627323696, 49.78967939104353, 50.401833057403564, 45.490026405879426, 43.42113079343523, 36.11598934446062, 35.107413155691965, 34.05511195319039, 34.45063120978219, 33.95944915499006, 37.006755352020264, 39.156402928488596, 41.97004120690482, 48.23830298015049, 48.78173548834664, 47.74915674754551, 42.0622854913984, 41.54972382954189, 39.83704498835972, 42.410609109061106, 39.85638182503836, 44.63970238821847, 46.46096420288086, 46.38948808397566, 46.14418888092041, 45.65339592524937, 43.73710707255772, 44.146595682416645, 44.79034628186907, 43.1036502293178, 40.601346833365305, 34.83226101739066, 32.81647743497576, 34.68978820528303, 33.08842645372663, 33.55195467812674, 35.22557769502912, 35.4490248135158, 34.995720863342285, 35.37499870572771, 35.854636328560964, 40.33591522489275, 45.435729707990376, 45.495755195617676, 43.074540751320974, 43.00763654708862, 36.843983377729145, 34.831472396850586, 33.47555923461914, 33.79249783924648, 34.04722574778965, 37.514887537275044, 38.8172995703561, 39.16675921848842, 40.26196207318987, 39.33099726268223, 39.38087838036673, 37.56713451657976, 37.7388071332659, 37.435730184827534, 39.09388303756714, 43.053942816598074, 43.48321989604405, 42.486969811575754, 44.073372091565815, 35.72897815704346, 17.426476376397268, 5.418303404535566, 2.568769646542413, 3.740099787712097, 8.963361178125654, 10.701091749327523, 8.683674471718923, 3.6343429940087453, 0.35193293541669846, 0.21352469734847546, 0.1142131992216621, 0.05951753631234169, 0.06686511382992778, 0.2727375307253429, 11.150609799793788, 33.88834129061018, 25.68823364802769, 32.931424958365305, 30.075739656175884, 5.439706896032606, 0.012491676174769444, 0.008731375049267496, 0.015565747694511498, 0.02143698907457292, 0.06411922510181155, 0.04628230704526816, 0.013297882646189203, 0.043671714807195325, 0.06369780735777957, 0.027801367653799907, 0.005151387395536793, 0.0526171133720449, 0.0045883564245221865, 0.01601045954573367, 0.03219381659956915, 0.040190083773008416, 0.017893741971680095, 0.03558512444474867, 0.08165663440844842, 0.05297038584415402, 0.12602170343909944, 0.17145571618207864, 0.1453147746090378, 0.155568551538246, 0.10002593443329845, 0.17441387102007866, 0.13629943265446595, 0.10195991529950074, 0.2319728024303913, 0.1292209146278245, 0.17067313460367067, 0.09220682936055319, 0.11739619342344147, 0.1044435298868588, 0.07683592808565923, 0.11612787576658384, 0.2044228964618274, 0.11309614059116159, 0.10653526335954666, 0.29237303137779236, 0.18258747671331677, 0.10346914681472949, 0.18398335895368031, 0.1656314158546073, 0.26935386657714844, 0.23004665864365442, 11.439439467021398, 46.3710823059082, 42.11227083206177, 31.170810495104107, 34.61931610107422, 27.79313482557024, 4.673979801791055, 1.922930896282196, 0.121595918067864, 0.3800720269126551, 0.2104360330849886, 0.80582987091371, 1.2454690486192703, 0.5156794488430023, 0.8105682166559356, 6.5623955215726575, 8.387828860964094, 21.353370666503906, 46.547750677381245, 51.352707930973594, 52.28175156457083, 51.52757324491228, 47.88408381598336, 48.12985897064209, 45.269848414829795, 46.26345123563494, 46.296128613608225, 45.8048597063337, 45.14716059820992, 45.93314777101789, 46.06796366827828, 43.07967547007969, 42.09878437859671, 40.09954793112618, 37.035277707236155, 36.35848842348371, 36.97097560337612, 37.727363450186594, 40.40726280212402, 42.649133818490164, 44.63772562571934, 47.64883170809065, 46.21949345724923, 45.95118876865932, 51.02485370635986, 52.46398196901594, 52.78392219543457, 47.93528856549944, 45.06760719844273, 37.61717196873256, 36.513853618076865, 36.06315524237496, 36.017908573150635, 36.474075181143625, 38.39745119639805, 39.676486015319824, 43.73812845775059, 50.496752398354666, 50.59260974611555, 48.670571259089876, 43.57519320079258, 42.08249085290091, 42.18969113486153, 46.04433284487043, 41.168236460004536, 44.82686253956386, 48.90233884538923, 49.87464196341378, 45.91044800622122, 46.70497451509748, 45.01847996030535, 46.19171108518328, 46.59878519603184, 44.35377011980329, 42.40193428312029, 36.35347529820034, 34.71126856122698, 36.16257701601301, 35.0326818057469, 34.85786860329764, 37.25151259558541, 36.52171203068325, 36.126317841666086, 36.52118744168963, 37.80225460869925, 43.257938453129356, 47.67845187868391, 47.07313871383667, 45.11087015696934, 43.74290534428188, 38.78859656197684, 36.50081532342093, 35.82188252040318, 35.20908614567348, 36.30422646658761, 38.94769641331264, 40.163050992148264, 40.6023508480617, 42.053607191358296, 40.99336419786726, 41.920271260397776, 40.46477999005999, 40.579480852399556, 38.7641840662275, 42.787607942308696, 43.28993143354143, 45.549391814640586, 44.161002772195, 45.644370215279714, 38.31480584825788, 17.560338633401052, 4.343568205833435, 2.6075329950877597, 7.73816100188664, 8.648281216621399, 11.931118318012782, 15.229621001652308, 4.290956011840275, 0.5610821268388203, 0.21849966182240418, 0.12267295670296464, 0.125247983528035, 0.12821573285119875, 0.7801496546183313, 14.282202856881277, 37.92542879922049, 30.965737887791224, 40.99822793688093, 35.09461457388741, 5.687433625970568, 0.18224595646773065, 0.1356890904051917, 0.11143507329480988, 0.1033117063343525, 0.1769765213664089, 0.1962387463343995, 0.11866314043956143, 0.1723157593182155, 0.1893623774605138, 0.15047282140169824, 0.11296162780906473, 0.21111891072775635, 0.10848144428538424, 0.23867124585168703, 0.16820994392037392, 0.10763546039483377, 0.09337497489260775, 0.1405982505530119, 0.19577381413962158, 0.075044398861272], [0.13602032405989511, 0.02997079338612301, 0.032256889822227616, 0.00717833052788462, 0.04332475610343473, 0.05258295252653105, 0.08290483350200312, 0.01775612319553537, 0.04808657576463052, 0.03575429001024791, 0.031535240688494275, 0.016619717835315635, 0.04255133814045361, 0.02233951528822737, 0.0502641473098525, 0.0826944944315723, 0.02505602514637368, 0.03241948716874633, 0.021901841541486125, 0.04818406767610993, 0.044202298657702546, 0.05199847263949258, 0.03640501866383212, 0.05251589630331312, 0.03000119175495846, 0.009096416711275066, 0.35618938558867996, 18.71754026412964, 37.17409924098423, 25.119796310152324, 19.586579254695348, 27.07865677561079, 14.536823068346296, 2.4587434019361223, 0.02766188799536654, 0.3357407828526837, 0.04364556746025171, 0.09027826320379972, 0.1518873226429735, 0.012897942231834998, 0.22697550058364868, 2.0718861605439867, 0.5597410159451621, 4.582746480192457, 23.59534764289856, 42.68236705235073, 52.6864389692034, 49.272969654628206, 49.85252584729876, 46.56875160762242, 45.49216992514474, 44.45687096459525, 46.56238010951451, 43.57743746893746, 43.54579189845494, 42.1580490384783, 41.4911470413208, 40.81850583212716, 40.220196451459614, 35.08560970851353, 33.741650921957834, 34.07467808042254, 34.216629777635845, 35.75428697041103, 37.03222744805472, 37.576611859457834, 40.50952638898577, 39.75631386893136, 39.543657302856445, 44.299198968069895, 46.02318600245884, 45.215336322784424, 45.17328235081264, 47.8606128011431, 44.280306816101074, 37.17261927468436, 33.751357555389404, 33.860065596444265, 33.20865460804531, 32.409643036978586, 33.50684697287423, 35.22166238512312, 42.54851695469448, 44.57084921428135, 46.01644277572632, 44.517299447740825, 44.51713963917324, 46.46790197917393, 43.49293000357491, 41.1963141305106, 37.562729358673096, 41.61338669913155, 42.61630705424717, 43.17633533477783, 44.50748859133039, 45.87014845439366, 45.95591006960188, 44.042824336460654, 44.3353157043457, 41.257920333317344, 40.20256887163435, 36.451959065028596, 30.737086568559917, 31.329604625701904, 31.25074257169451, 32.0581510407584, 32.087111132485525, 32.07435423987252, 32.58251074382237, 40.21891450881958, 41.76832457951137, 43.99408272334507, 42.964898177555625, 44.99591221128191, 44.39982625416347, 40.28448813302176, 36.62686954225813, 31.607487406049454, 31.771829673222133, 32.12368644986834, 32.20551885877337, 34.60515219824654, 37.41327708108084, 38.55384472438267, 37.477506228855674, 37.20712055478777, 38.887997491019114, 38.25885547910418, 38.01714154652187, 38.17003665651594, 39.00618634905134, 40.09433330808367, 41.47446094240461, 44.362062794821604, 36.47539186477661, 19.272612742015294, 4.3438244206564764, 1.6903968368257796, 2.103474191256932, 3.7691480347088406, 5.81071594783238, 10.698261226926531, 10.06724841254098, 4.1409161772046765, 0.11561373621225357, 0.1923261641391686, 0.13117630327386515, 0.0640511205419898, 0.023189762075032507, 2.215307184628078, 18.194796017238072, 28.386028085436138, 21.977551664624894, 32.15940366472517, 14.985598530088152, 0.4872479630368096, 0.04589673291359629, 0.0371984873366143, 0.04062771850398608, 0.05734538286924362, 0.09354539574789149, 0.042459196477596245, 0.01365316951913493, 0.0357640846632421, 0.002000138666647087, 0.046053318439849784, 0.04023395784731422, 0.013565009160499488, 0.023330768437257836, 0.060833663546613286, 0.05200314435309597, 0.03299546840467623, 0.06771222408860922, 0.022190485249406526, 0.03527238086930343, 0.04561876425785678, 0.08784766255744866, 0.03640523918771318, 0.017217955019857203, 0.02154990069435111, 0.03704682118924601, 0.02309344063646027, 0.005091000323383403, 0.0411903359927237, 0.005909792347145932, 0.029817529288785796, 0.05777360631951264, 0.04613238812557288, 0.05542923729600651, 0.029341370732124363, 0.025655878940597177, 0.04266624804586172, 0.015355108372334923, 0.04002485710329243, 0.040941659693739245, 0.03291738938008036, 0.07864552669759307, 0.03906329834301557, 0.04820999110649739, 0.04404245616335954, 0.029656434897333384, 0.024750485916488936, 1.5650709846190043, 26.80302173750741, 41.62750196456909, 28.291204282215663, 27.811855009623937, 32.301397051130024, 15.662964514323644, 2.502679250070027, 0.03886489470356277, 0.573999316564628, 0.06631750892847776, 0.032531754180256806, 0.31032163969108034, 0.1125934479225959, 0.2903110720217228, 3.787380107811519, 1.6874627428395408, 4.555868676730564, 27.218233925955637, 44.61521346228463, 51.5925805909293, 50.51436260768345, 52.01748030526297, 47.410275731767925, 46.92463139125279, 45.25412464141846, 48.754574980054585, 44.93381616047451, 44.99278552191598, 44.53701843534197, 42.50040067945208, 41.99116720472063, 41.2783202443804, 36.83515221732003, 35.694376128060476, 35.67642198290144, 36.12734270095825, 37.475810868399485, 38.18649346487862, 40.19521072932652, 41.14017963409424, 41.73137058530535, 41.78096682684762, 44.92232731410435, 48.013796261378694, 48.60218014035906, 47.91123390197754, 49.669701371874126, 46.03354924065726, 37.44279302869524, 35.33996936253139, 34.79270144871303, 34.95601885659354, 34.621473516736714, 35.65980536597115, 36.20587471553257, 43.193410532815115, 46.5270346232823, 48.43043456758772, 45.78675617490496, 45.78402553285871, 46.17041833060128, 44.13247346878052, 41.06031009129116, 39.016417571476524, 41.5471008845738, 43.134472438267295, 45.60313613074166, 47.23653255190168, 47.451273577553884, 46.40710524150303, 46.81581217902047, 45.014773096357075, 42.9075859614781, 42.84806421824864, 36.32736396789551, 32.170770917619976, 32.28487770898001, 32.83855186189924, 32.83738456453596, 33.00479098728725, 33.452272347041536, 33.93772561209542, 40.92864172799246, 43.30172252655029, 46.46386507579258, 45.20913505554199, 45.30738953181675, 45.089445386614116, 42.531518186841694, 39.17767136437552, 33.98740175792149, 33.368921756744385, 33.447915826525005, 33.782391684395925, 36.85757058007376, 39.011967250279014, 40.26835788999285, 39.15612847464425, 39.21233940124512, 40.541234493255615, 40.69915315083095, 39.024206502096995, 39.894732407161165, 40.00577504294259, 42.1772712298802, 43.23981755120413, 46.27555499758039, 40.0197548185076, 23.2360771383558, 6.782837978431156, 2.870000111205237, 3.4437326278005327, 5.42792101417269, 9.847269313676016, 10.55624178477696, 7.424754687717982, 2.100907700402396, 0.9916829466819763, 0.1943855450621673, 0.6106531268783978, 0.024764653727678314, 0.05671165491055165, 1.8812312824385506, 20.841272796903336, 34.632680961063926, 24.914728913988384, 37.16995464052473, 20.124434096472605, 0.8377591233168329, 0.028275717914636646, 0.01621526007407478, 0.009076698483633143, 0.018244571717722074, 0.10296967718750238, 0.04554132305617843, 0.009723367801468288, 0.0351179225503334, 0.013059273262375166, 0.003328515578427219, 0.040014807999666245, 0.029431754989283423, 0.030633179271327596, 0.014376418299174734, 0.005915134538164628, 0.024286666519141624, 0.017545590742624233, 0.05909178272954055, 0.05859237417046513, 0.05198030486436827, 0.201599172981722, 0.08750314997243029, 0.21472604359899247, 0.06609952276838676, 0.1592377975050892, 0.19668310534741196, 0.11008499216820512, 0.1595111656934023, 0.14361275093896048, 0.21292617517922605, 0.1265513678746564, 0.15492071344384126, 0.07188078361962523, 0.1965989398636988, 0.09913281271500246, 0.20708495218838963, 0.1552767814802272, 0.1007101284340024, 0.08986736953790699, 0.19511575730783598, 0.14209678157099656, 0.10078332879181419, 0.1456645458404507, 0.1441308938499008, 0.18642590860170977, 0.07495634537190199, 1.9568161751542772, 31.306654725755962, 50.994052342006135, 36.14038446971348, 29.957738399505615, 36.48598091942923, 22.75098865372794, 4.6703584875379285, 0.23157450237444469, 1.0538832204682487, 0.2845809794962406, 0.3374259652835982, 0.507575080863067, 0.24212908744812012, 1.0753202587366104, 3.9270032899720326, 1.8981379866600037, 6.68987021275929, 27.695128747395106, 43.84019749505179, 52.93534081322806, 53.16373157501221, 53.994708333696636, 49.406555720738, 50.1749153137207, 48.361873217991416, 51.1458809035165, 47.698865686144146, 45.88058117457798, 45.957115582057405, 44.99851778575352, 44.45318494524275, 43.78675889968872, 38.823188168661936, 36.51186990737915, 38.06497641972133, 37.68156787327358, 40.37995638166155, 41.0069375038147, 41.251045090811594, 42.2917879649571, 43.811748095921104, 42.664802006312776, 48.08979218346732, 50.08658981323242, 49.522378717150005, 48.170432976314, 50.874977588653564, 47.32346841267177, 39.91358286993844, 36.917967796325684, 37.33687816347395, 37.65882641928536, 35.772890772138325, 36.714343888419016, 38.04722029822213, 45.57225833620344, 48.701442105429514, 50.69845860345023, 47.00125959941319, 46.65234538487026, 48.42192302431379, 48.866378443581716, 43.84367854254586, 40.31798192432949, 41.179047857012065, 44.1383238519941, 47.26148700714111, 49.09471361977713, 49.54053088596889, 50.46191413061959, 47.18767629350935, 46.63949121747698, 44.22069822038923, 44.51940475191389, 38.36088630131313, 33.23214299338204, 34.27460554667881, 34.50935043607439, 35.710846832820344, 35.62819801058088, 34.90630449567522, 37.13607175009591, 44.26893956320626, 45.18214130401611, 48.812550749097554, 46.235561166490825, 48.30803162711007, 47.17558642796108, 44.9974547113691, 42.18313898359026, 35.107850892203196, 34.04117039271763, 34.52318777356829, 36.152880804879324, 38.505172593253, 40.4088956287929, 41.423930168151855, 40.540935720716206, 40.490915639059885, 43.35246522086007, 42.15970965794155, 41.98610544204712, 41.78030327388218, 42.48022658484322, 44.81958082744053, 44.00175700868879, 47.32240533828735, 39.82709864207676, 22.42002511024475, 6.429832577705383, 2.671477700982775, 4.482808368546622, 8.316720128059387, 14.263652035168239, 20.34099555015564, 17.763721091406687, 9.783695033618383, 1.3812068849802017, 0.7034945764711925, 0.545443957405431, 0.22806074949247496, 0.18884650085653576, 3.170245017324175, 23.512004000799998, 37.06099646432059, 30.309893948691233, 42.504222188677105, 22.028431585856847, 0.9820093171937125, 0.1226085637296949, 0.09784289050315108, 0.08255449230117456, 0.16035610464002403, 0.18785209421600613, 0.13936349323817662, 0.08466714500848736, 0.10624364936458212, 0.1312363671937159, 0.08996361294495207, 0.1315172128379345, 0.10707737891269581, 0.15552196332386561, 0.1576983236840793, 0.13339785406632082, 0.16512369524155343, 0.13730238883623055, 0.11274513442601476, 0.17543046575571808, 0.14394672587513924], [0.018327919566737752, 0.0115601290183674, 0.049839058691369634, 0.0472543186375073, 0.06301305017301015, 0.09931848025215523, 0.01974869895327304, 0.024098393407517245, 0.05676417012831994, 0.046104931206043274, 0.009961933080506111, 0.004245471899464194, 0.008178233302065303, 0.032722483588648696, 0.05985007953963109, 0.04684895842469164, 0.0204310049302876, 0.02138839748554996, 0.09474848583340645, 0.018407852688272084, 0.05296782098178353, 0.03748897496344788, 0.05859272700867482, 0.07215563779962914, 0.03923555802819984, 0.01173197988620294, 0.14703821284430368, 4.6337215048926215, 32.088278429848806, 28.574551820755005, 19.482905183519634, 27.99074159349714, 17.464024441582815, 1.3183849645512444, 0.2153349066419261, 0.5977124326995441, 0.13706601437713417, 0.05351918496723686, 0.0661757697484323, 0.0784386752971581, 0.31739232742360657, 0.38333844020962715, 1.0460210080657686, 0.8282455738101686, 4.695175715855189, 21.241136414664133, 42.40852117538452, 48.750107288360596, 48.88258164269583, 50.2609235899789, 47.78281382152012, 46.55823203495571, 45.33667618887765, 46.01162767410278, 44.96076822280884, 42.6066004208156, 43.19665534155709, 40.956170490809846, 39.794386523110525, 36.50305264336722, 32.82783773967198, 33.45297758919852, 34.69355412891933, 33.07521445410592, 34.17865439823696, 36.79614850452968, 37.14702558517456, 37.920929840632844, 38.17947925840105, 42.51796572549002, 46.161625385284424, 46.75018296922956, 45.32312025342669, 45.7166280065264, 45.13952452795846, 41.22324882234846, 34.74171904155186, 33.793487957545686, 34.39483370099749, 32.02759633745466, 32.124325684138704, 32.83546686172485, 37.18245097569057, 45.21157734734671, 46.461624281747, 45.723819392068044, 46.81931059701102, 44.920041356767925, 46.815662792750764, 45.17747906276158, 38.28253493990217, 43.04276316506522, 40.46413033349173, 44.89271409170968, 42.937192235674175, 44.36251095363072, 43.772449084690635, 45.82357815333775, 38.2437744140625, 40.19722918101719, 45.64181675229754, 35.179691791534424, 30.24780832018171, 31.09192759650094, 31.751252583095006, 31.940841129847936, 30.94671024594988, 32.80172988346645, 42.50380877086094, 42.786662987300325, 44.905807971954346, 43.333784988948274, 45.407832690647666, 44.06206042425973, 43.6093088558742, 39.551494870867046, 35.793127400534495, 32.20090178080967, 31.215935570853098, 31.04399197442191, 33.05107988630022, 34.99694374629429, 36.8098920413426, 36.90240035738264, 37.0894250188555, 38.08978843688965, 39.349409988948274, 39.114553928375244, 40.68317229407174, 41.79192761012486, 40.63250255584717, 43.18529503686087, 43.99842882156372, 39.72826051712036, 25.257375853402273, 7.58935056413923, 0.6186617399965013, 1.7920806833675929, 3.3803908952644894, 3.0078747357640947, 11.408922978809901, 10.265535235404968, 4.878912142344883, 1.2426224585090364, 0.920491595353399, 0.08231794820832354, 0.2679422151829515, 0.0698889372870326, 0.22274509258568287, 5.264022128922599, 28.58466144970485, 24.530955587114605, 25.74940037727356, 29.026071820940288, 5.8872903074537, 0.07959449184792382, 0.05860549703772579, 0.06345077311354023, 0.028346638394785777, 0.02413015902441527, 0.03059730851756675, 0.01824460055546037, 0.06385157696370568, 0.030958984645881822, 0.02200023251186524, 0.024309071745457392, 0.02116630788493369, 0.018115275173581073, 0.021243574363844733, 0.07908601127564907, 0.05216227777834449, 0.015025730510907514, 0.045678909601909776, 0.013651614825773453, 0.06738324995551791, 0.03937172304306712, 0.020940291262896996, 0.031128815175699334, 0.05042231382269945, 0.04892856986927135, 0.06840511012290205, 0.03995491032089506, 0.02391415418657873, 0.03222623361008508, 0.06500085243689162, 0.005760675371025822, 0.010672720564928437, 0.04719602230138012, 0.009228828579320439, 0.018380511119695644, 0.033304456288793256, 0.03423698053562215, 0.020780484391642467, 0.023382136930844614, 0.07480940182826348, 0.011618348171136208, 0.04391772785623159, 0.022946773595841866, 0.04502867288621409, 0.029089742805808783, 0.028840421898556606, 0.020768235138218318, 0.2443721613713673, 10.199394464492798, 38.862726892743794, 33.16736493791853, 21.482681853430613, 35.045754841395784, 19.123282057898386, 3.000806680747441, 0.4697733521461487, 0.7184991027627672, 0.1332726100725787, 0.06230534493391003, 0.2817368863948754, 0.04890147935865181, 0.22382256548319543, 1.8315012880734034, 2.7582656954016005, 1.6616486651556832, 5.04866054228374, 24.105388845716202, 44.900020122528076, 49.43052700587681, 50.551118578229634, 50.20183263506208, 48.99650083269392, 48.455712114061626, 46.69344745363508, 47.945658751896445, 47.072447368076865, 46.38921710423061, 45.43389885766165, 42.032623631613596, 40.9032495362418, 39.41130454199654, 34.83940723964146, 34.09558173588344, 35.49726963043213, 35.15411894662039, 36.315114293779644, 38.634395190647666, 39.31920269557408, 40.294740200042725, 41.10667889458792, 43.90824120385306, 47.78177159173148, 48.96078014373779, 46.40203653063093, 48.15435831887381, 47.959235531943186, 42.50669574737549, 36.19809620720999, 35.17416797365461, 36.72746556145804, 33.58728279386248, 33.503379821777344, 35.71314321245466, 39.704115527016775, 46.4503299849374, 46.74877943311419, 46.93051651545933, 46.70601674488613, 47.41041122164045, 48.34510374069214, 47.15160819462368, 39.27392823355538, 41.944805349622456, 42.38874660219465, 44.57108545303345, 44.49332816260201, 45.8259266444615, 43.68520055498396, 45.716763496398926, 39.76264367784773, 41.89308295931135, 46.718936920166016, 38.16448157174246, 31.836468764713832, 32.39702163423811, 33.10410506384713, 32.55726446424212, 32.954927240099224, 34.3268803187779, 44.01224184036255, 44.32360451562064, 46.26880134854998, 44.94901534489223, 46.6477039882115, 45.355300835200715, 46.009647437504356, 42.200061321258545, 37.81924990245274, 34.339932509831016, 32.383100918361116, 32.667813777923584, 34.80299173082624, 36.032631805964876, 39.97941705158779, 38.84154183523995, 39.601917948041645, 40.05455487115042, 39.79205540248326, 40.266193526131765, 41.06345762525286, 43.041981492723735, 43.70688935688564, 44.01694924490792, 45.06817347662789, 41.6878262247358, 26.829926899501256, 9.839860796928406, 1.8289743150983537, 3.3017924385411397, 3.7799068859645297, 4.343637253556933, 8.30678767817361, 11.205220903669085, 6.821955902235849, 4.937695205211639, 1.6324610199247087, 0.19813633736755165, 1.4164700784853526, 0.06311493220606021, 0.09389076328703336, 5.100791573524475, 30.32953998020717, 26.574884584971837, 27.719893864222936, 33.69334009715489, 9.032679881368365, 0.0776040025853685, 0.06977591370897633, 0.054963534963982444, 0.07607556174376182, 0.01726846007763275, 0.038907995247947316, 0.048910531015800576, 0.055179831571877, 0.0343317379509764, 0.030082992544131618, 0.03858705157680171, 0.0480251853088183, 0.009875162870490124, 0.045379326213151217, 0.011966112635231443, 0.03440970840996929, 0.02941586369914668, 0.05504475899838975, 0.04843605861866048, 0.0373082301978554, 0.006222759839147329, 0.09485445264726877, 0.11642698757350445, 0.10556912448789392, 0.16638464400810854, 0.20927280693181924, 0.26431064148034367, 0.08809386898896523, 0.09568175646875586, 0.12280698093984808, 0.14674161161695207, 0.09615909906902484, 0.12520736642181873, 0.0484463893143194, 0.21180955081113748, 0.1253518672393901, 0.10849705737616334, 0.06380988777215992, 0.164630725979805, 0.17016488473330224, 0.11859072718237128, 0.21354698043848785, 0.10319109673478774, 0.11877193674445152, 0.1672742034175566, 0.09927083352314574, 0.17429527666951927, 0.42901296647531645, 12.645362734794617, 45.36068221500942, 39.174777439662385, 28.497822863715037, 38.9547175679888, 24.302090610776627, 4.319606908730098, 1.2940677894013268, 1.712596982717514, 0.42379324084946085, 0.19986580099378312, 0.5360131891710418, 0.11809469094233853, 1.00177791927542, 1.665278121829033, 3.034610318286078, 1.960303736584527, 6.2973881874765665, 23.69348921094622, 45.50279024669102, 49.73400694983346, 51.98092235837664, 52.61476830073765, 51.81673642567226, 50.05974892207554, 49.16637734004429, 51.32497419629778, 49.28397907529558, 48.17605406897408, 49.11433185849871, 43.48593316759382, 44.54727745056152, 40.7266263280596, 35.7728317124503, 36.46114458356585, 37.61500413077218, 35.931573731558665, 37.6962320463998, 39.37933588027954, 40.95058066504342, 42.07936763763428, 42.57251255852835, 45.390965938568115, 49.59926053455898, 50.1808351789202, 48.09881789343697, 49.383366107940674, 49.57043593270438, 45.18525062288557, 38.39189263752529, 36.669371673039024, 38.693802288600374, 34.37445116043091, 35.640496322086875, 35.968770912715364, 40.88271066120693, 50.0172815322876, 49.169465814317974, 49.66523715427944, 48.76200260434832, 49.70779487064907, 49.14468853814261, 48.747432231903076, 42.036823817661826, 42.50135258265904, 41.9097238949367, 45.99103668757847, 45.087996687207905, 46.803076131003245, 45.13771104812622, 46.99391882760184, 41.465132985796245, 43.00922073636736, 49.25085006441389, 39.68944093159267, 33.48579045704433, 33.473419189453125, 34.61820438929966, 33.6857213973999, 34.288522788456504, 36.06355823789324, 46.97685752596174, 45.53711782182966, 47.41686609813145, 45.666889326913015, 48.532972608293804, 46.61113214492798, 48.002109391348704, 43.574012007032124, 39.49717385428292, 35.462546007973806, 34.60875483921596, 34.09511273247855, 36.46579987662179, 38.654135022844585, 40.88043165206909, 39.22594049998692, 41.508944852011545, 42.56474447250366, 41.98433365140642, 41.80364227294922, 43.70447138377598, 44.86174249649048, 44.712738377707346, 46.54225812639509, 46.13253327778408, 44.06055266516549, 27.880461522511073, 10.058195778301783, 1.2449274148259843, 3.9765678303582326, 7.986615555627005, 7.332539933068412, 18.992336307253154, 21.05191785948617, 11.177437663078308, 7.785657150404794, 3.614526514496122, 0.33957382717302864, 2.1941425374576022, 0.20525826806468622, 0.48051065312964575, 7.173651567527226, 38.40300280707223, 32.934106963021414, 35.01828861236572, 38.455301897866384, 10.105575544493538, 0.17392809422952787, 0.12683198281696864, 0.1448650958814791, 0.19651203309851034, 0.08019113447517157, 0.09504198615572282, 0.11595782132021018, 0.19774717039295606, 0.07795719363327537, 0.06887540952967745, 0.14314612240663596, 0.11525166992630277, 0.09255181013473443, 0.12376868219247886, 0.16977138870528766, 0.11984464632613318, 0.0799420578405261, 0.15897797287574836, 0.21228115979049886, 0.14874182428632463, 0.10819327046296426], [0.034765983399535925, 0.006049161319554384, 0.03524337010458112, 0.05309984014768686, 0.03629099424662335, 0.0285803733526596, 0.009610759826110942, 0.005664526534798954, 0.04357317116643701, 0.07065510510333947, 0.027539880613663366, 0.056853044645062516, 0.0244447176810354, 0.013223524538001843, 0.02752576199626284, 0.004730634615823094, 0.02010959985532931, 0.02362162247300148, 0.030887721505548273, 0.015720178872080784, 0.05045943986624479, 0.01494171260856092, 0.029507394680487256, 0.048105225299618075, 0.04683966928028634, 0.030587534220623117, 0.013323286149118627, 1.312950930425099, 22.14046607698713, 35.22538661956787, 29.979430675506592, 24.39205936023167, 29.168270179203578, 6.222078399998801, 0.5426775429930005, 1.5313751527241297, 0.013511916339796568, 0.05849142173039062, 0.1308898122182914, 0.02599753319684948, 0.1796899964766843, 2.4054183661937714, 2.9897950887680054, 1.6997655055352618, 0.14155228435993195, 3.7474257946014404, 21.93223030226571, 45.50671597889492, 51.88244553974697, 48.19721828188215, 52.55745955875942, 47.71099376678467, 47.78749343327114, 45.38921846662249, 43.42878770828247, 44.14616142000471, 42.3149984223502, 42.53724350248064, 40.450362477983745, 34.7406907081604, 33.06248535428728, 33.544506209237234, 35.03466551644461, 35.554470675332205, 35.96976103101458, 34.630725043160574, 35.54498985835484, 37.00543519428798, 36.08645255225045, 41.39789179393223, 46.264538628714426, 46.646022524152485, 47.42647893088204, 47.439534596034456, 48.54331152779715, 43.630205563136506, 39.27529008047921, 33.93031188419887, 34.08607660021101, 33.431021281651084, 33.084618840898784, 32.39168889181954, 35.01634659085955, 38.80527918679373, 41.86576959065029, 41.956669398716514, 43.18874134336199, 42.7743820462908, 44.18617956978934, 44.541103976113455, 38.23760788781302, 40.95743158885411, 42.201475279671804, 42.02489723478045, 42.91091414860317, 43.87804085867745, 43.7690931047712, 41.90397426060268, 41.736453192574636, 46.6721373285566, 43.14605508531843, 36.64420182364327, 30.001755237579346, 32.65572043827602, 31.558658940451487, 31.14032874788557, 32.62710428237915, 40.29508066177368, 44.821126801627024, 44.21109580993652, 44.19333274023873, 43.99507284164429, 43.06748832975115, 44.44421829496111, 40.186230182647705, 39.980132716042654, 35.41373838697161, 34.10374239512852, 31.78282172339303, 32.48263038907732, 33.41266761507307, 34.80829668045044, 37.877736364092144, 37.81616837637765, 36.08374970299857, 38.35317727497646, 37.1225575038365, 39.44082048961094, 39.870080198560444, 42.24196590696062, 42.6026816368103, 43.83435753413609, 43.142209257398335, 33.876769065856934, 12.22471010684967, 1.8753281363419123, 1.1978470725672585, 3.3336983493396213, 2.6334934192044392, 4.319219980921064, 6.8892804724829535, 6.968136012554169, 4.338599809578486, 2.224870945726122, 1.3016791066953113, 0.7986996620893478, 1.3932604896170753, 0.12670390254684857, 0.5773701156888689, 10.519762005124774, 26.852352210453578, 28.64794216837202, 28.40622476169041, 20.945733751569474, 1.9422618704182761, 0.06280284680958305, 0.01045465043612889, 0.07550575517650161, 0.0361227854155004, 0.06658797298691102, 0.033337416127324104, 0.026686751749366522, 0.04085405743015664, 0.012178926662142788, 0.011137087879303311, 0.0612913557727422, 0.04014122925166573, 0.05325438328353422, 0.014100656578583377, 0.03319771255233458, 0.005219475416067455, 0.014907884245206202, 0.011344620359263249, 0.0627415750973991, 0.07783387667898621, 0.01890753605403006, 0.033511209301650524, 0.011843075576637472, 0.031597384318177185, 0.02254107581185443, 0.04165778215974569, 0.025874197582847307, 0.07472999287503106, 0.03200228651985526, 0.02582045252035771, 0.021353135716968348, 0.034041664230504205, 0.06647133281720535, 0.013658356919352497, 0.05439733820302146, 0.0034269936981477906, 0.013102945472512926, 0.028595867699810436, 0.05547162198594638, 0.08884837957365171, 0.002896731091563457, 0.036626696054424555, 0.04612205403723887, 0.03463542986927288, 0.03806041680010302, 0.008792380436456628, 0.04076598358473607, 0.05523853502901537, 2.039066561630794, 28.274009227752686, 38.303779057094026, 29.51420361655099, 29.447434902191162, 32.648289339882986, 5.151096097060612, 1.453200318983623, 1.6495987517493111, 0.01206469105090946, 0.08653250562825374, 0.23802517194833073, 0.18702137736337526, 0.09525970090180635, 1.4602345015321458, 5.889175006321498, 3.3786577539784566, 1.4955653314079558, 4.1076990110533576, 23.212870155061992, 46.42506980895996, 50.033179010663716, 50.225724015917095, 51.62079722540719, 50.276122774396626, 48.56146717071533, 47.83128445489066, 45.80137518474034, 44.926961762564524, 44.27242408479963, 43.82575566428048, 40.675247873578755, 36.06825174604143, 33.9992345401219, 36.68536295209612, 36.62828002657209, 36.957749707358225, 36.674989291599815, 36.221501214163645, 37.208909715924946, 38.45379761287144, 37.598804405757356, 43.882136821746826, 47.50904090063912, 49.21778358731951, 49.25577981131417, 47.35576016562325, 48.31885692051479, 43.88396419797625, 40.490040166037424, 35.89328915732247, 34.96907799584525, 34.40777472087315, 34.577842303684776, 34.531998089381624, 37.85129846845354, 42.103873934064595, 43.41126435143607, 43.70458950315203, 45.07001822335379, 44.98413848876953, 45.7858807018825, 46.038128103528706, 39.21295779091971, 40.93384592873709, 41.392645903996055, 41.764405795506065, 43.71912513460432, 44.22053493772234, 43.64649908883231, 42.69193124771118, 42.704642977033345, 47.799968923841206, 44.592444215502056, 38.072490896497456, 31.547392436436244, 34.60873746871948, 33.60598039627075, 33.37417459487915, 34.01561491830008, 42.13912909371512, 45.52843952178955, 46.47537824085781, 46.51627881186349, 45.813628332955496, 43.82795476913452, 46.2076085635594, 42.335255895342144, 42.11072833197457, 37.92756189618792, 33.67376702172415, 32.97436482565743, 34.05699144090925, 35.34897075380598, 36.24218600136893, 38.084031854357036, 38.829636096954346, 38.07781669071743, 39.89351994650704, 39.07778753553118, 40.85381310326712, 41.02167810712542, 42.649033069610596, 42.88058178765433, 43.96364961351667, 46.25984164646694, 36.08974599838257, 16.176603146961757, 3.368309714964458, 2.676379437957491, 5.155804370130811, 4.094586891787393, 6.443320768220084, 7.144697989736285, 11.100362164633614, 6.116401510579245, 5.0976153782435825, 1.3353773270334517, 0.9939509906939098, 0.9044438621827534, 0.1633135402309043, 0.5680477502090591, 11.180480974061147, 32.595927715301514, 29.501933097839355, 32.33765969957624, 27.737684726715088, 2.6162571098123277, 0.015360422997868486, 0.025358261607055153, 0.06197934278420039, 0.0565978204831481, 0.012582272474121834, 0.014446823092709695, 0.025632398236276846, 0.03157700112621699, 0.026201524572180848, 0.03148711219962154, 0.03653172490053943, 0.056283730015690835, 0.012490904341185731, 0.01619254272165043, 0.012824243998953273, 0.049934732128999064, 0.04764662044388907, 0.020851800118439963, 0.051487125256764035, 0.0658012523448893, 0.03319199928747756, 0.12282116232173783, 0.1417974933449711, 0.10752475062119109, 0.16754910509501184, 0.16737635007926396, 0.10938464903405734, 0.13542514028293745, 0.10371459328702518, 0.1112739144425307, 0.13514979077236994, 0.14621909894049168, 0.11360907913850886, 0.13736946880817413, 0.14656721454645905, 0.14205442741513252, 0.12081150444490568, 0.10158349121255533, 0.172658894477146, 0.13410101990614617, 0.13024669672761643, 0.0930767451812114, 0.09204151787395988, 0.18886038368301733, 0.16068166574197157, 0.15567687286862306, 0.07111176595624004, 0.11480986220496041, 2.571642292397363, 33.1245744568961, 46.75611325672695, 41.26224906103951, 33.39438690458025, 40.44289663859776, 9.516403913497925, 2.4485873069081987, 3.687882338251386, 0.1634421090462378, 0.25106873203601154, 0.6127061567136219, 0.40420640472854885, 0.8619929743664605, 9.268343670027596, 8.021023035049438, 3.2276621077741896, 1.354238212108612, 5.8354662997382025, 25.799053941454204, 47.66156080790928, 51.85954080309187, 51.59225402559553, 54.447477272578645, 52.21255098070417, 52.057950087956016, 48.93729523250035, 47.25169352122715, 47.49341787610735, 45.64031246730259, 46.74176870073591, 44.7770231110709, 37.82559013366699, 35.83752638953072, 38.19566856111799, 39.13875797816685, 38.96442420142037, 39.295773369925364, 37.59198474884033, 39.230154582432334, 40.56876673017229, 38.63288048335484, 44.53913416181292, 47.80943584442139, 52.232798031398225, 51.127096448625835, 49.18906320844378, 51.95318167550223, 46.264493465423584, 43.033973693847656, 38.173229353768484, 38.28531769343785, 37.10215411867414, 35.36652537754604, 35.80632897785732, 39.587312834603445, 43.18655266080584, 44.90411955969674, 45.53933777127947, 46.320575850350515, 47.17276198523385, 47.74284430912563, 47.89339092799595, 42.694387435913086, 40.30454063415527, 41.35181828907558, 42.62579134532383, 43.59011793136597, 45.755162715911865, 44.1071993964059, 43.21128477369036, 44.20574222292219, 49.56582580293928, 46.52699293409075, 40.54292637961251, 33.037103584834504, 36.336872577667236, 34.30183206285749, 34.31554085867745, 36.77236482075283, 44.2629189491272, 48.28107261657715, 48.03055184228079, 47.282515730176655, 45.551295621054514, 45.341460023607524, 48.2593560218811, 42.920592989240376, 43.95843846457345, 39.10205411911011, 36.39635957990374, 34.66500398090908, 36.13530533654349, 36.128638539995464, 39.732808113098145, 41.36306047439575, 41.478355407714844, 39.954674516405376, 42.08996711458479, 40.346149921417236, 42.89227213178362, 41.529310022081646, 45.10553394045149, 45.07548298154558, 45.931184904915945, 45.83910737718855, 37.563243525368826, 13.910425594874791, 3.300339396510805, 3.4066196935517445, 7.939318299293518, 7.3773193359375, 11.663401620728628, 13.315243772097997, 12.629594666617256, 11.007180741855077, 8.699958443641663, 1.75580153294972, 2.193109210048403, 4.848004383700235, 0.39767374098300934, 1.332582956978253, 14.091594661985125, 37.45685618264334, 38.320458207811626, 38.444101401737754, 31.551405021122523, 2.922210829598563, 0.1648913784218686, 0.07627244546477284, 0.13752882954265389, 0.1260056085884571, 0.1573998225586755, 0.07861296380204813, 0.13643978083772318, 0.1169908908861024, 0.09353394886212689, 0.143249531143478, 0.19801850297621318, 0.09948550164699554, 0.22838560491800308, 0.10993561946919986, 0.11300247561718736, 0.15059581265917846, 0.1525260412267276, 0.1029461727344564, 0.10230336936989001, 0.13346630467900208, 0.11881213315895625], [0.08288225864193269, 0.02716752264781722, 0.025427777519715682, 0.029338819440454245, 0.017757241081978594, 0.02172016039756792, 0.01019779100481953, 0.02682871654230569, 0.027792212520060793, 0.05111270624079874, 0.049032972659915686, 0.019027775852009654, 0.014718001309250082, 0.06943130612905536, 0.021500452454867106, 0.01915530820510217, 0.03666147097413029, 0.07741474559796707, 0.018197566204305207, 0.006835169499806527, 0.06408017541148833, 0.05983331972467048, 0.02567291016956525, 0.025992216874978373, 0.03609446675649711, 0.006453258184982198, 0.005334416703720177, 0.1633179642792259, 7.01673822743552, 32.220447063446045, 29.877434594290598, 21.576626709529332, 22.157223394938878, 17.310672487531388, 0.605307682284287, 2.1565584284918646, 0.06721761277211563, 0.0894507286804063, 0.2934514677950314, 0.13030471147171088, 0.10547925252467394, 0.18553405574389867, 5.923879521233695, 5.842482677527836, 1.698857462831906, 0.25236812659672325, 2.571404750858034, 20.485142878123693, 45.049475874219624, 47.878302914755686, 49.399506773267476, 48.01305627822876, 46.63277925763811, 46.1803195135934, 45.257390294756206, 45.06483486720494, 42.51799004418509, 40.2419547353472, 35.550902775355745, 34.96403012956892, 34.683850969587056, 35.10450186048235, 33.81933525630406, 34.276297433035715, 34.11500889914376, 34.0756299836295, 35.38915566035679, 33.065111773354666, 36.199023791721885, 40.43408284868513, 47.03579562050955, 46.40519448689052, 46.197926248822895, 46.9446039881025, 46.59665904726301, 44.631896087101524, 40.36740446090698, 36.00644751957485, 34.04909481321062, 32.926432677677695, 34.37057753971645, 32.995025294167654, 32.85861478533064, 33.00740698405674, 35.10114588056292, 35.74324975694929, 39.89583369663784, 42.871740204947336, 45.8602785382952, 44.280907835279194, 38.050013474055696, 40.90796388898577, 42.131510393960134, 43.73568269184658, 45.42807279314314, 44.52919128962925, 44.55442714691162, 41.87747730527605, 43.19834722791399, 43.43350553512573, 42.49321971620832, 34.72896214893886, 30.900230271475657, 32.16854749407087, 31.03362873622349, 33.269972460610525, 35.84583643504551, 45.813319138118196, 43.134559290749685, 42.90424735205514, 44.560211522238596, 44.9129125050136, 43.096389361790244, 42.10537127086094, 39.97457068307059, 39.10998201370239, 34.680668694632395, 33.20301614488874, 31.42062602724348, 32.21305070604597, 32.815376145499094, 32.9973703111921, 35.76484475816999, 35.26502261843, 35.34480530875069, 36.07930980409895, 37.63138450895037, 38.65478120531355, 39.46642460141863, 41.59274360111782, 42.47647455760411, 43.2790436063494, 38.840395382472444, 21.152355807168142, 4.606619187763759, 1.0344466120004654, 1.36851296041693, 4.166796479906354, 3.210410382066454, 3.0493999932493483, 4.9278296317373, 12.348790168762207, 4.1752133539744785, 3.454473457166127, 0.9790429792233876, 0.9185771495103836, 0.08057781801159893, 0.15634826969887528, 1.7584191582032611, 15.837447677339826, 26.9799211365836, 19.653127363749913, 28.427609579903738, 8.699966260365077, 0.37391274741717745, 0.033114218818289895, 0.028184163184570413, 0.020312642977972115, 0.027203700438674008, 0.06623569796127932, 0.02869771241343447, 0.050957342077578814, 0.01581552322022617, 0.033071114881230254, 0.0299668816317405, 0.055166138735200675, 0.05789802250053201, 0.0227192625004266, 0.03764692434508886, 0.0020499745192604935, 0.003983859330349202, 0.014963707321190407, 0.06397279045943703, 0.015675758577084968, 0.006532595043868891, 0.033785910811275244, 0.03215945897889989, 0.03342729826856937, 0.004192698414304427, 0.053931344100939374, 0.01613220399511712, 0.03547207372529166, 0.09779060259461403, 0.03855929610186389, 0.05034600916717734, 0.04159832213606153, 0.07292101851531438, 0.03267946107579129, 0.03091137862897345, 0.03782869030588439, 0.0011359485153142096, 0.025083527867017046, 0.03739033293511186, 0.03313049008803708, 0.009611632591778678, 0.02696382304254387, 0.0635599358273404, 0.03846904755170856, 0.04625150155542152, 0.043668006613318405, 0.004261638420367879, 0.03132419254896896, 0.026093021733686328, 0.25814017972775866, 11.528926185199193, 40.11343738010952, 33.40807832990374, 24.237267392022268, 29.78889717374529, 15.860119649342128, 0.5189399995974132, 4.127548277378082, 0.14842665834086283, 0.14209044405392238, 0.765202885227544, 0.06905213397528444, 0.2609428550515856, 0.11696430588407175, 5.009988171713693, 3.85180641072137, 3.290896143232073, 1.2645313228879655, 3.2280158145087103, 23.59635513169425, 47.294605595724924, 47.566155093056814, 51.34068407331194, 50.26025308881487, 47.98395722252982, 47.34097439902169, 47.35791758128575, 46.57528638839722, 44.017564160483225, 42.38144404547555, 38.37287194388253, 36.22294296537127, 35.866941588265554, 36.41447005953108, 35.379056453704834, 35.04559850692749, 35.5249616759164, 36.60737289701189, 37.034075668879915, 34.165907927921836, 37.14194992610386, 42.35221644810268, 48.375422205243794, 48.043211460113525, 47.65956667491368, 47.10306807926723, 48.974534102848594, 45.7240104675293, 42.91138315200806, 38.20464563369751, 35.97445453916277, 35.87081173488072, 34.935393129076274, 34.810950892312185, 33.28757224764143, 34.778947489602224, 37.25550086157662, 37.63773168836321, 41.447074617658345, 44.39185667037964, 47.62075056348528, 47.49146890640259, 40.66689613887242, 41.21651601791382, 41.30901043755667, 43.67659868512835, 45.71607909883772, 44.220778124673025, 43.43636819294521, 43.869557108197895, 45.001196316310335, 44.44298846381051, 43.27266863414219, 36.66661671229771, 32.7249870300293, 33.22407266071865, 32.33366101128714, 34.130218505859375, 37.30406182152884, 46.23002345221383, 45.412984779902864, 45.207012380872456, 46.31521531513759, 46.660530362810405, 45.47021361759731, 43.320656367710654, 42.22967454365322, 40.63414927891323, 35.803056376320974, 35.094222000667024, 33.80190222603934, 34.192759241376606, 34.94475582667759, 34.94489826474871, 36.867186886923655, 36.407872744968955, 37.50898504257202, 37.39484003611973, 38.83723395211356, 41.24140099116734, 41.90138953072684, 43.84609304155622, 43.81453084945679, 45.005184582301546, 40.93118476867676, 24.946688890457153, 6.937971276896341, 2.3552117688315253, 3.1431833037308285, 5.212008348533085, 5.636761282171522, 6.308804512023926, 7.37723856312888, 11.74331545829773, 8.464995554515294, 6.811382046767643, 1.7045719219105584, 0.7477454819849559, 0.40768699081880705, 0.1153274622878858, 1.8631642290524073, 18.684499842779978, 32.13421297073364, 25.971692357744487, 33.29015697751726, 14.722386871065412, 0.3640760252518313, 0.042737382264541726, 0.043757990534816465, 0.019431312501962696, 0.056626044147248776, 0.035869786848447154, 0.04957591602578759, 0.03960573620029858, 0.036206767694758515, 0.035954532479601245, 0.05416440391646964, 0.017414102530372993, 0.06311635712959937, 0.04194784230951752, 0.03842416924557515, 0.023629474819504788, 0.02839757432229817, 0.026896390232390592, 0.05029905793656196, 0.0329229940793344, 0.00976438948418945, 0.05487562057429126, 0.12858045899442264, 0.09772665066910641, 0.10707245953381062, 0.14555485386933598, 0.12424197393868651, 0.21744979172945023, 0.20409895027322428, 0.11007628656391587, 0.14166908737804207, 0.11687283936355795, 0.12362876827163355, 0.08825586243931736, 0.08136067100401435, 0.15091491410774843, 0.054356324153819253, 0.06824602080242974, 0.1652244712625231, 0.10507101193070412, 0.08423325579081263, 0.09473757499030658, 0.1781429366341659, 0.10597678832709789, 0.12169548629650048, 0.14277295528778008, 0.046333597507327795, 0.0961674993325557, 0.1003715598157474, 0.2772813269070217, 13.11338470663343, 47.75675112860543, 40.0627954346793, 30.47214480808803, 31.715111528124126, 23.44770884513855, 1.361031161887305, 7.2166439805712015, 0.2566155658236572, 0.43352074601820534, 1.3430325048310416, 0.15754569401698454, 0.5798810752374786, 1.8729976671082633, 11.19720789364406, 14.157980356897626, 3.0376069460596358, 1.0184496875320161, 4.3190410648073465, 23.82600178037371, 46.89989927836827, 47.91918611526489, 52.76424837112427, 51.42193978173392, 49.501791204724995, 50.830721037728445, 50.64135830742972, 49.507922989981516, 48.19588770185198, 45.52397183009556, 39.28102929251534, 38.74644878932408, 38.07070173536028, 38.25040299551827, 36.87215832301548, 36.78756400517055, 36.75578989301409, 38.310237407684326, 38.655350957598, 35.96387938090733, 39.14282962254116, 45.26551273890904, 51.39586319242205, 49.54778480529785, 48.631459849221365, 48.13293702261788, 49.212874685014995, 47.8918171610151, 44.3751288822719, 40.45817572729928, 37.30943625313895, 37.21065718787057, 36.962147917066304, 37.41796016693115, 35.644863264901296, 37.0101113319397, 39.56103127343314, 38.19483825138637, 44.08822734015328, 46.09121928896223, 50.10891090120588, 49.17503826958792, 42.937185287475586, 40.43980816432408, 43.22598021371024, 45.29272883278983, 47.53061505726406, 45.92595291137695, 44.79194436754499, 44.58013200759888, 45.274906703404014, 45.91017355237688, 45.43382590157645, 38.65386404309954, 35.14331797191075, 35.462570326668875, 33.958243642534526, 36.32615845543997, 39.90180567332676, 49.948907784053254, 46.849021094185964, 45.39862980161394, 47.20860774176461, 48.132203987666536, 46.74951941626412, 45.13695022038051, 45.01463760648455, 41.92088270187378, 37.05153996603829, 35.295414039066856, 35.67404222488403, 36.037707465035574, 36.83059419904436, 35.32586799349104, 39.444708006722585, 38.21073572976248, 39.097044467926025, 39.86489336831229, 41.103149209703716, 42.193106174468994, 43.2752742086138, 44.29421363558088, 47.07970476150513, 46.79753146852766, 43.7771634374346, 23.781337022781372, 5.519615956715175, 2.1594779746873036, 4.199080416134425, 8.6250308070864, 7.5217602252960205, 10.038197125707354, 12.841630237443106, 21.08689682824271, 13.416247997965131, 11.047395178249904, 3.4504665178912024, 3.117047220468521, 1.6702888586691447, 0.7156137547322682, 2.4771003254822324, 21.407523189272197, 35.80520684378487, 29.709854466574534, 40.00648028509957, 17.467585393360682, 0.3214115346116679, 0.22418696592961038, 0.09634028148970433, 0.0909131887767996, 0.11996496415563992, 0.11946183043931212, 0.1340907197445631, 0.12408718653023243, 0.11021710972168616, 0.08469746873847075, 0.1961573085614613, 0.1321972134922232, 0.16392116834010395, 0.07019700575619936, 0.07865922631961958, 0.15686052292585373, 0.07649591418781451, 0.18118981671120438, 0.18903564927833422, 0.12515283934772015, 0.08010218531957694, 0.1604285178972142], [0.01886811656212168, 0.01926208077929914, 0.0601005403857146, 0.02068048868594425, 0.05107441990237151, 0.048050633764692714, 0.022275096869894435, 0.026283333843041743, 0.10814143038753952, 0.03541437449998089, 0.08619317705077784, 0.07584560622594186, 0.04472264341477837, 0.013616834817055081, 0.022341735794075897, 0.08232881833932229, 0.03660728316754103, 0.03672459847959025, 0.035403653646686246, 0.038603380522025485, 0.07631769696516649, 0.037025559294436655, 0.029442184072520052, 0.04893295320549181, 0.10805250158799545, 0.011712846046845828, 0.02763035986572504, 0.013018938596360385, 1.5413902210337775, 15.150236095700945, 30.913338048117502, 21.60604190826416, 31.524341787610734, 35.73486328125, 2.219172337225505, 0.6984220658029828, 0.09094337679977928, 0.16250628711921827, 0.4099057460469859, 0.07838423643261194, 0.08326848755989756, 0.8429348798734801, 1.6529726449932372, 1.77004360301154, 3.103128024509975, 1.3507871287209647, 0.2175251498286213, 2.9457007348537445, 19.428073474339076, 42.63867677961077, 48.48207705361502, 49.78755324227469, 46.09310572487967, 46.111813749585835, 46.56489188330514, 43.33902045658657, 41.31837313515799, 39.080372265407014, 36.86381353650774, 35.59895304271153, 37.432436738695415, 40.167629855019705, 39.821303844451904, 39.8277587209429, 37.596240520477295, 34.564251627240864, 33.18441234316145, 34.07684244428362, 33.44246843882969, 38.44761719022478, 44.22014583860125, 47.06049994059971, 46.56102868488857, 46.71585191999163, 48.03708662305559, 45.93954358782087, 41.09801796504429, 37.183354241507395, 34.70095048631941, 33.365628310612266, 33.10681138719831, 32.58305617741176, 32.91022253036499, 32.466819763183594, 34.019408634730745, 34.32125227791922, 39.51816783632551, 45.21029887880598, 43.94316632407052, 46.638706071036204, 37.9440221786499, 43.16400923047747, 44.200770786830354, 47.069720200129915, 45.230532033102854, 47.367436613355366, 44.10046659197126, 45.80689900262015, 46.5214204788208, 44.96900183813912, 38.78576169695173, 31.06637212208339, 31.733378342219762, 33.1055120740618, 33.05737148012434, 31.8092839377267, 39.328659193856375, 45.121928215026855, 42.88855137143816, 45.155637400490896, 45.27832521711077, 44.518046379089355, 41.728289059230256, 40.001623494284495, 38.55187838418143, 37.08624274390084, 33.31275251933506, 32.45431995391846, 32.31953879765102, 32.8986051423209, 30.312065260750906, 35.37469298498971, 33.167045320783345, 34.43062039784023, 35.31807558877127, 35.51766259329659, 34.919374057224815, 37.17101076671055, 39.863948413303916, 41.340551785060335, 42.42733689716884, 39.46756758008684, 32.132448128291536, 12.613184758595057, 2.905851947409766, 1.2761190725224358, 2.0705638314996446, 3.0558227343218665, 3.8994706187929427, 5.371225016457694, 6.143195501395634, 10.896724360329763, 5.138086029461451, 5.799441192831312, 1.4695174034152712, 0.32103266779865536, 0.17335876263678074, 0.18304121308028698, 5.662976401192801, 25.31532382965088, 23.344337020601543, 21.651439700807842, 22.80612087249756, 2.9472232588699887, 0.050400831404009035, 0.020546785056857125, 0.02681117471573608, 0.0086380332275959, 0.023521506327337453, 0.026727365462907722, 0.026861542370170355, 0.06348887964018754, 0.030088736343064477, 0.023615178086661866, 0.04969320080376097, 0.024089764138417583, 0.0456815558884825, 0.05337248569620507, 0.02758203969070954, 0.043869399199528356, 0.061831313584532054, 0.03415310003661683, 0.023679216525384357, 0.025067098837878023, 0.043574714833604436, 0.049941860139369965, 0.032936965115368366, 0.041760305408388376, 0.06086437404155731, 0.02942532586998173, 0.03900739045015403, 0.03656882719535913, 0.042622051667422056, 0.025238785160971538, 0.056088630841778855, 0.0705778199647154, 0.022014895653618232, 0.025162253196218183, 0.06960581176515136, 0.02418857240783317, 0.027550443707566177, 0.062202791151191504, 0.01850188576749393, 0.059060875459441116, 0.014849703260032194, 0.04568455840594002, 0.02179962532993938, 0.005004998554276037, 0.029276662240070955, 0.052736586425453424, 0.07502785617751734, 0.049961876922420094, 0.03887011603053127, 0.04539686295070818, 2.31572949886322, 21.953806195940288, 37.24749653679984, 22.50766795022147, 33.71919781821114, 36.39688416889736, 2.126409326280866, 1.2467429574046816, 0.11521524616650172, 0.20396067840712412, 0.6806207267301423, 0.15886015205511025, 0.13753583202404635, 0.6651470884680748, 6.76332265990121, 6.957974706377302, 6.652765529496329, 3.0037145018577576, 0.5826255051153046, 4.226962234292712, 23.47592374256679, 45.63147783279419, 49.31952258518764, 51.293172291346956, 47.391831738608225, 48.99315874917166, 46.1450435093471, 45.8397570337568, 43.83584097453526, 42.12707396915981, 37.01451996394566, 38.852846554347444, 38.562533446720664, 40.86170973096575, 40.58011661257063, 40.26351152147566, 37.04355648585728, 36.083989415849956, 34.77952071598598, 36.289294787815635, 35.25547579356602, 40.57173708506993, 46.01017550059727, 49.614939144679475, 49.33828966958182, 47.97929498127529, 48.26299340384347, 46.87107467651367, 43.12270218985421, 39.02117361341204, 35.801916871752056, 34.432802132197786, 35.13858624867031, 35.94575500488281, 34.752030168260845, 34.09917048045567, 36.17386089052473, 35.870766571589876, 40.239800793784006, 46.04682377406529, 46.46976409639631, 47.95349284580776, 39.83448110307966, 43.27785199029105, 44.02668367113386, 46.27565574645996, 45.15634611674717, 47.600896086011616, 44.301266057150706, 46.34077426365444, 48.530214173453196, 46.28671727861677, 40.30025012152535, 33.20882831301008, 32.37907443727766, 34.747159481048584, 33.62590782982962, 33.66601978029524, 40.04394497190203, 45.83455283301217, 45.0022246497018, 45.810703141348704, 45.75378697259085, 46.2429644720895, 43.44325385774885, 42.35313708441598, 40.220787048339844, 37.97152314867292, 34.67660747255598, 32.97644233703613, 33.5323885508946, 33.99639967509678, 32.018706117357524, 35.632033416203086, 34.761799335479736, 36.913072790418354, 37.128755296979634, 36.46173170634678, 37.0941150529044, 38.195310728890554, 40.80638122558594, 43.01391771861485, 45.24988276617867, 41.94808489935738, 34.929389885493684, 14.872947386332921, 4.047285292829786, 2.314398918833051, 4.100557999951499, 3.7839025344167436, 5.44231333902904, 7.480524403708322, 5.855491442339761, 10.8252751656941, 8.421436429023743, 3.366313410656793, 0.7580768018960953, 0.49528827731098446, 0.07155880518257618, 0.174216200198446, 5.2528190272195, 25.35624177115304, 28.45034408569336, 23.814069986343384, 29.940413066319056, 5.102062225341797, 0.08132812846451998, 0.04012692573347262, 0.056465886134122095, 0.06809033094240086, 0.04354347168867077, 0.029073695452617745, 0.04989621169599039, 0.0108231102182929, 0.0011996173644937308, 0.04567316919565201, 0.034417911898344755, 0.0328508013460253, 0.04859611485153437, 0.04300353762560657, 0.07078223542443343, 0.004654637845565698, 0.04548039739685399, 0.013798055405329381, 0.02864093260307397, 0.031367225239851644, 0.020153652045077512, 0.03908344744039433, 0.11381256500525133, 0.149770496945296, 0.1567797094051327, 0.06646319718233176, 0.11335797368415765, 0.1259716818375247, 0.0910627446802599, 0.09888434676187378, 0.15395442529448441, 0.10541086976549455, 0.18684015423059464, 0.20302461220749787, 0.14971687910812242, 0.10946712496557406, 0.09258401340671948, 0.18557915118123802, 0.1253976547824485, 0.1097975375929049, 0.10742288215884141, 0.10348880397421972, 0.15677284263074398, 0.09665964756693159, 0.10726966216628041, 0.16299062541552953, 0.20828039518424443, 0.09367957604782921, 0.09526144473680428, 0.1404867943908487, 3.0058992760522023, 29.093618733542307, 47.18648815155029, 31.761796474456787, 39.13576677867344, 44.33021572657994, 4.577792848859515, 1.3246848093611854, 0.23777050418513163, 0.47287219443491524, 1.4249117055109568, 0.2718632790659155, 0.3239954502454826, 1.2473181379692895, 8.350756747382027, 8.965917246682302, 8.28142762184143, 4.393288212163108, 0.45522284720625195, 4.496762088366917, 24.982812574931554, 47.213860579899375, 50.17700672149658, 53.867031710488455, 50.170732498168945, 51.72574976512364, 49.73211356571743, 46.927139690944124, 45.65559850420271, 43.200091225760325, 39.93622704914638, 39.87527745110648, 41.86437995093209, 42.47793367930821, 43.90331493105207, 43.884665966033936, 40.89293493543352, 37.45454938071114, 35.93566274642944, 37.53037854603359, 37.627865246364046, 41.75412246159145, 48.319999899183, 50.944848673684255, 50.45380210876465, 49.837086950029644, 52.21404831750052, 48.60955217906407, 45.452405384608674, 40.68294995171683, 37.113559586661204, 35.79053572246006, 35.84594413212368, 37.59410047531128, 35.99511153357369, 36.56344291142055, 38.39366442816598, 37.711764744349885, 43.61990138462612, 48.599122932979036, 48.19242055075509, 49.75766904013497, 41.680224895477295, 42.58138540812901, 45.58583859034947, 47.718133040836875, 47.46772691181728, 49.0609245300293, 46.945733070373535, 48.14262628555298, 49.888729436056956, 47.560068471091135, 40.91540540967669, 34.34870113645281, 33.48065226418631, 36.40948820114136, 35.929197447640554, 34.62028884887695, 42.70932258878435, 47.310659408569336, 46.43708324432373, 48.025424071720664, 46.30041217803955, 47.55274159567696, 45.13383742741176, 44.0693803514753, 42.764505181993755, 39.64258228029524, 36.76057025364467, 35.169606481279644, 35.18183878489903, 36.37073809759957, 33.77399826049805, 39.84515701021467, 36.06680999483381, 38.3259403364999, 40.14706318719046, 37.872455733163015, 38.00642047609602, 38.87591109957014, 42.06836516516549, 45.58762080328805, 47.3888509614127, 42.84114728655134, 35.79782438278198, 14.106168508529663, 5.35172142301287, 4.0213159663336615, 6.17388265473502, 8.101100155285426, 10.330400143350873, 12.560533046722412, 14.520440084593636, 20.671677691595896, 12.958277463912964, 11.768637299537659, 4.103793254920414, 1.7474037664277213, 0.23168130378637994, 0.783425078860351, 7.253452931131635, 30.46229226248605, 31.539738995688303, 31.21940619604928, 34.338122504098074, 6.555076462881906, 0.11582413635083608, 0.13100035914352962, 0.10291107211794172, 0.23403231906039373, 0.05080825436328139, 0.13130913328911575, 0.07367022295615502, 0.11222913568573338, 0.07686796850923981, 0.07821377486522708, 0.13166403424526962, 0.09983481147459575, 0.1274848556412118, 0.1242382555667843, 0.166402489479099, 0.12541402104709828, 0.11153513685400997, 0.11602210572787694, 0.07032473318810974, 0.128033668334995, 0.06455699553979294, 0.10800044438136475], [0.033488756577883444, 0.07147955907774822, 0.06133281426238162, 0.047060793664838584, 0.04903597178469811, 0.03028830706274935, 0.04343282637585487, 0.0335318028394665, 0.03884395172021218, 0.008113512935649072, 0.05844104050525597, 0.0331807864962944, 0.03166253725066781, 0.02542331615196807, 0.03847983965118017, 0.05684678855219057, 0.0010725931705175234, 0.0550832421119724, 0.08843696343579463, 0.06530033065272228, 0.009673758409917355, 0.06978575925209693, 0.029839049026902233, 0.05190983561000653, 0.018334609922021627, 0.05279352229886821, 0.00913592950174851, 0.07605736343456165, 0.04727592319250107, 6.315951602799552, 28.70795202255249, 27.170473745891027, 27.15412289755685, 26.87822209085737, 13.607163650648934, 0.8057354731219155, 0.06466371552752596, 0.09366941159324986, 0.22531374118157796, 0.015480203088372946, 0.11993634354855333, 0.23466677644423076, 8.876304592405047, 1.108990143452372, 6.64025182383401, 2.404485353401729, 0.5738745746867997, 0.07653376287115471, 3.037853389978409, 17.351460150309972, 40.91783727918352, 45.41965157645089, 47.09407711029053, 49.812469482421875, 46.427369662693565, 44.834418705531526, 44.62544468470982, 39.96881062643868, 41.44399309158325, 42.852135862622944, 42.565647738320486, 43.44172177995954, 46.03343806947981, 46.19378512246268, 46.13116448266165, 42.36847175870623, 33.430131912231445, 32.542162554604666, 34.81341750281197, 35.117428983960835, 43.85231167929513, 47.43655381883894, 48.01219470160348, 45.00594541004726, 45.19776432854788, 46.10071400233677, 43.02022320883614, 38.794922896793906, 32.95198815209525, 33.65237004416329, 33.17114128385271, 34.721228803907124, 33.29526390348162, 32.13395936148507, 34.6452328818185, 34.85468632834298, 42.59604958125523, 44.691890307835166, 47.148561409541536, 46.24009486607143, 37.54636982509068, 45.54527153287615, 47.33967855998448, 46.56889404569353, 45.34990208489554, 46.174076557159424, 44.441143717084614, 47.56212166377476, 43.71639796665737, 42.39058787482125, 33.02536807741438, 31.926517418452672, 33.00350557054792, 32.436765330178396, 32.58440065383911, 32.28702817644392, 40.35892071042742, 45.91655199868338, 44.87675060544695, 43.798699378967285, 45.322262150900706, 43.21507849012102, 41.520041125161306, 38.1258669580732, 37.10118137087141, 35.70892913000924, 32.7605687550136, 31.840623787471227, 32.106190885816304, 32.17253923416138, 31.994811262403214, 33.56135906491961, 32.66114003317696, 33.50738198416573, 32.994049072265625, 35.169960839407786, 36.38453722000122, 37.24161836079189, 38.050715242113384, 42.57556976590838, 43.92300959995815, 43.072063718523296, 25.200086218970164, 6.56839485679354, 0.9225391426256725, 1.8380608218056815, 2.6521836391517093, 2.908910457577024, 4.666603854724339, 5.271378534180777, 4.553997005735125, 7.666147266115461, 9.59118390083313, 3.118262938090733, 0.7396521334137235, 0.03296417097694107, 0.11692626721092633, 0.9886491894721985, 7.8117493731634955, 20.230298587254115, 19.284469842910767, 24.766141687120708, 15.935391221727643, 0.5709517715232713, 0.06039636129779475, 0.06667706463485956, 0.04426656270931874, 0.01733400147142155, 0.013851731766148337, 0.03704479576221534, 0.020210905133613517, 0.031061813235282898, 0.0939125781878829, 0.055041956648762734, 0.03438558988273144, 0.02940487482451967, 0.01753768920233207, 0.058269785051899295, 0.03784144337155989, 0.02018115476572088, 0.02403288594047938, 0.014762021268584898, 0.08588513572301183, 0.0771780318713614, 0.03639021302972521, 0.007345009262540511, 0.06738650013825723, 0.03067979123443365, 0.02764320792630315, 0.041802055668085814, 0.09232971205243043, 0.07065424336386578, 0.016351567581295967, 0.03207578882575035, 0.03621704410761595, 0.08858779498508998, 0.048434681192572625, 0.030293033059154238, 0.01872831120687936, 0.09775326281253781, 0.032977857028267214, 0.028948339500597546, 0.01608046400360763, 0.049960024521819184, 0.08674592524766922, 0.06278117440108742, 0.08689874490456921, 0.024218292241649966, 0.008015183881590409, 0.060803706225539954, 0.07325165505920138, 0.058853895137352605, 0.03422303664098893, 0.06476650001215083, 0.15111546191786016, 10.26963380404881, 39.87970692770821, 27.681473800114222, 33.39133317129952, 38.811987672533306, 11.531625560351781, 0.9809290894440242, 0.12763006213520253, 0.10611907033515827, 0.28852394648960655, 0.19287083776933805, 0.3923786979700838, 2.7496814131736755, 8.677375061171395, 9.130492278507777, 7.174283853599003, 5.082427050386157, 1.1997555473021098, 0.6166771607739585, 4.808495623724801, 21.017392260687693, 44.533189977918354, 46.79221262250628, 49.08589288166591, 49.69319323131016, 48.13297871180943, 47.35919257572719, 44.6741897719247, 40.82780947004046, 42.060131549835205, 42.263807569231304, 43.49321835381644, 44.242567675454275, 46.6266370500837, 47.34052971431187, 47.72435515267508, 43.12326499394008, 35.195453780038015, 35.281865051814485, 36.45306035450527, 38.43740333829607, 46.069467953273225, 48.13683148792812, 48.411514622824534, 46.1421982220241, 47.77348239081246, 48.11305127825056, 45.53605474744524, 39.09234401157924, 34.767020906720845, 35.22468137741089, 36.079865659986226, 35.81280469894409, 35.87346594674246, 33.07087530408587, 36.0602821622576, 36.07072877883911, 43.51939221790859, 46.877758843558176, 48.17251743589129, 48.042412417275564, 40.81775195258004, 46.42413180215018, 48.2056360244751, 48.053588594709126, 46.773285729544504, 48.82149655478341, 45.82357120513916, 47.41924933024815, 46.17810651234218, 43.34233474731445, 35.7798285484314, 32.74509859085083, 34.145191873822895, 34.21452099936349, 33.79593372344971, 34.78852905545916, 41.6865234375, 47.36972951889038, 45.385469913482666, 45.122699465070454, 46.39353193555559, 45.02235358101981, 43.36913047518049, 39.97725963592529, 39.21749496459961, 37.63843693052019, 34.07334055219378, 33.27085140773228, 33.66525200435093, 33.8698764528547, 34.64888416017805, 35.23907457079206, 34.65572118759155, 35.81858560017177, 34.335892132350374, 36.17942987169538, 36.87025104250227, 38.28487300872803, 40.05144207818167, 43.890380859375, 44.73797770908901, 43.104219981602256, 27.775863340922765, 8.245757307325091, 1.730699971318245, 3.484171577862331, 4.564438845430102, 4.374348725591387, 6.30675435917718, 7.831489205360413, 7.133208274841309, 8.624248266220093, 4.988178210599082, 2.020003093140466, 0.10191089792975358, 0.0623213719310505, 0.041467544689242325, 1.082217431494168, 10.262907947812762, 25.973288706370763, 22.689365080424718, 27.750071627753123, 20.977339369910105, 1.1005631727831704, 0.05280442974929299, 0.05553931603208184, 0.036141143180429935, 0.03367878370253103, 0.05891952982970646, 0.040717390299375565, 0.006969254380757255, 0.052830495672034364, 0.10673914956195013, 0.04763419986037271, 0.04619089820023094, 0.043061732181480954, 0.03502441703208855, 0.02911561195339475, 0.002466459949833474, 0.034920977761170695, 0.060943362303078175, 0.037522993316607814, 0.024201266101694534, 0.061370900432978354, 0.020242881096367325, 0.021796120696568062, 0.2315610945224762, 0.18645763689918177, 0.14747779497078486, 0.14403820596635342, 0.20795036932187422, 0.1574756827737604, 0.13709368503519467, 0.13655714025454863, 0.1511620365615402, 0.13435848323362215, 0.19415542669594288, 0.1126647958798068, 0.09531690140387841, 0.16549463676554815, 0.12367792134838444, 0.1255942942308528, 0.056477299093135765, 0.10319843848368951, 0.24673408748848097, 0.14005202986299992, 0.130338991060853, 0.1360051248754774, 0.07990102004259825, 0.1262164701308523, 0.12795894805874142, 0.1670823408556836, 0.09190380919192519, 0.2022609074733087, 0.18310082916702541, 13.006788917950221, 49.31519733156477, 37.61678286961147, 35.93003817967006, 35.97041763578142, 18.922717094421387, 1.2479123175144196, 0.2610895000398159, 0.2484769725373813, 1.56414481145995, 0.1422042479472501, 0.6418295311076301, 3.793277825628008, 22.016009943825857, 15.662161997386388, 10.161516359874181, 7.19900814976011, 1.1828696876764297, 0.5452730751463345, 5.300692549773625, 20.32800415584019, 45.15841667992728, 47.85322686604091, 50.031164033072336, 52.812593936920166, 51.125974314553396, 49.939354010990684, 48.50637837818691, 43.10812486921038, 45.00272144590105, 45.352934973580496, 45.8767214502607, 47.46228647232056, 48.85671697344099, 49.1687536239624, 50.40244449887957, 46.75463329042707, 37.644467966897146, 36.36123643602644, 38.35441058022635, 39.78259195600237, 49.40643065316336, 50.121167523520334, 50.2484724181039, 47.754242828914094, 48.257285458701, 50.110748699733186, 46.67108815056937, 42.048778193337576, 35.12470374788557, 36.981116499219624, 38.506899220602854, 37.324312346322195, 37.17467941556658, 34.306608949388774, 37.85748931339809, 37.93888398579189, 46.199013641902376, 48.49533421652657, 49.70391082763672, 49.997659819466726, 42.76764229365757, 45.608312538691926, 49.98883213315691, 50.34364536830357, 48.28598846708025, 49.584335803985596, 47.75379467010498, 50.14175156184605, 47.130030563899446, 45.907679149082725, 37.2834986277989, 35.532879148210796, 35.91704504830496, 34.81766632625035, 35.69593252454485, 36.62997191292899, 43.43718808037894, 49.04169191632952, 46.56335285731724, 45.281305994306294, 48.81803635188511, 46.91020693097796, 45.16048376900809, 42.832986627306255, 40.636153834206716, 38.699051652635845, 35.14634738649641, 34.82834223338536, 35.07009438105992, 35.241982391902376, 37.257984842572895, 37.02417795998709, 36.312713691166465, 36.85955776487078, 35.727209840502056, 38.99981485094343, 39.42710821969168, 41.0703432900565, 41.99097612925938, 45.333511284419465, 47.92195497240339, 44.562198707035606, 28.077244928904943, 8.3125981092453, 2.0261889440672736, 5.809872175965991, 7.822896020753043, 7.648016810417175, 10.589144110679626, 12.669446059635707, 11.8987284217562, 15.143442494528633, 19.978077241352626, 9.936166303498403, 2.0272068551608493, 0.6875442266464233, 0.4092138303177697, 1.4285815485886164, 11.761216623442513, 29.098409516470774, 28.78089942250933, 35.604796477726524, 23.48859899384635, 1.1380908276353563, 0.16291760147682258, 0.0811350377542632, 0.09925601431833846, 0.16379289808017866, 0.154240292097841, 0.15237058885395527, 0.13229142129421234, 0.14096722432545253, 0.24156981174434933, 0.08295767102390528, 0.1257246272372348, 0.11894699877926282, 0.1498614749205964, 0.19036605288939817, 0.12344293110072613, 0.10204460325517825, 0.1159593683800527, 0.07801122537681035, 0.1752949080296925, 0.20029933058789798, 0.10740646161139011, 0.07346192627613034], [0.04039394283401115, 0.044618240624134026, 0.02321326992075358, 0.031039655674248934, 0.02204673082035567, 0.01758652676029929, 0.03423960646614432, 0.04285842612651842, 0.0876520001994712, 0.009896548597940376, 0.018677147970135723, 0.017189826350659132, 0.0738323385428105, 0.016710134322888086, 0.024976421114323393, 0.022355265782347748, 0.043799313317452154, 0.0668639535350459, 0.021421165637938038, 0.0029823429150772946, 0.02654307535184281, 0.040054861921817064, 0.04004123015329242, 0.03074720368853637, 0.04046679374628833, 0.004537838644215039, 0.12994677067867347, 0.014386623465855206, 0.0824515110413943, 0.9167205691337585, 18.05909422465733, 33.35241631099156, 25.610059465680802, 28.396523339407786, 24.468741416931152, 5.590246132441929, 0.15548437248383248, 0.13429020904004574, 0.23399445680635317, 0.18470779008099011, 0.09383142539965254, 1.0720611193350382, 6.033194661140442, 8.681610856737409, 7.081305665629251, 3.6244815460273196, 1.4614669382572174, 0.3651030829974583, 0.09725462099803345, 4.994691712515695, 19.16284336362566, 41.24149131774902, 45.04064818790981, 47.55061544690813, 46.09896305629185, 45.91086489813668, 43.06536912918091, 45.79753630501883, 41.575126443590435, 43.795638697487966, 46.686488832746235, 45.76549468721662, 45.45763390404837, 46.68143401827131, 45.99423285893032, 46.23552989959717, 38.48268822261265, 33.77568319865635, 34.80416250228882, 35.64343541009085, 42.77013669695173, 46.772222655160085, 46.30046428952898, 48.47177634920393, 45.82342529296875, 46.49621936253139, 43.847559111458914, 39.14577218464443, 34.356774943215505, 33.556665556771414, 32.94570698056902, 34.966795512608115, 35.414533955710276, 33.97073997770037, 35.763694831303184, 37.48596913473946, 42.45799234935215, 45.29918023518154, 46.08597339902605, 45.479082993098665, 36.183237484523225, 46.00966133390154, 45.90204068592617, 45.2428685597011, 42.85780211857387, 45.08752768380301, 44.61212498801095, 42.08210870197841, 40.800179958343506, 33.12812498637608, 31.941817351749965, 31.7966034752982, 33.20700788497925, 33.74745266778128, 32.816463538578574, 32.97494847433907, 40.42693315233503, 45.27361781256539, 43.927352224077495, 45.54598024913243, 44.071930340358186, 44.13669102532523, 40.80583579199654, 36.16208716801235, 34.9881716455732, 33.255367347172324, 31.660536902291433, 32.41866527284895, 33.005162715911865, 33.862320286887034, 32.67835766928536, 32.137704440525596, 34.033395358494346, 33.11559043611799, 34.26433610916138, 33.79843854904175, 36.38205671310425, 39.69327981131417, 40.800315448216026, 38.99025412968227, 41.968307631356375, 35.34869977406093, 16.745384420667374, 2.3630808208669936, 0.6513668021985463, 2.6773593510900224, 4.3349811008998325, 2.613162990127291, 4.254042838300977, 6.882688369069781, 3.6693336878504073, 5.166397767407553, 2.2160704008170535, 0.8182263257248061, 0.2815507506685597, 0.1717955536608185, 0.19193350949457713, 4.234196611813136, 22.003815855298722, 38.17884349822998, 24.159451041902813, 24.230208022253855, 8.29362084184374, 0.030256728042981455, 0.061404521843152385, 0.045172359461763074, 0.044062439019658735, 0.03400537957038198, 0.030696276242711713, 0.06653649253504616, 0.057825778877096515, 0.02969544387555548, 0.03738116253433483, 0.016842867646898543, 0.0636514023478542, 0.023695871167417084, 0.06331556822572436, 0.025368185181702887, 0.05512665817514062, 0.0860812459141016, 0.033677949104458094, 0.008757216207283949, 0.017001894202881625, 0.017290892445349267, 0.0524085724194135, 0.027362386030810218, 0.07034580848578896, 0.025084026590255753, 0.029090825069163526, 0.04734675207042268, 0.03829579720539706, 0.013252563292293676, 0.04373368541044848, 0.019935219748211757, 0.019359382700973322, 0.02045931850027825, 0.023208610081513013, 0.040459262007581334, 0.005408779052751405, 0.06091879255005291, 0.0776575661397406, 0.020969037398962036, 0.044852854284857, 0.00833833618422172, 0.02226291546997215, 0.048414929038179774, 0.07745933891939265, 0.052954477590641806, 0.015274505197469677, 0.017671201145276427, 0.054666407871991396, 0.010870080956790065, 0.05546831073505538, 0.053688822114574056, 0.04202049983931439, 2.280955501965114, 26.047987052372523, 37.93332890101841, 27.08491015434265, 29.17897735323225, 28.750975268227712, 4.843734281403678, 0.204602626817567, 0.12269817106425762, 0.1655693163297006, 0.18651052191853523, 0.36081547449742046, 4.688509353569575, 8.040718572480337, 7.640610899244036, 6.653581942830767, 6.446691078799112, 3.4007940632956366, 0.940671769636018, 0.8163611686655453, 6.3185489262853345, 23.801750830241613, 44.12960386276245, 46.859825542994905, 49.73470524379185, 48.682678495134624, 46.71381957190377, 46.68549871444702, 46.63813631875174, 43.48674610682896, 44.91777971812657, 49.657472542354036, 47.54032516479492, 47.49077756064278, 48.61650732585362, 47.667498043605256, 48.28540481839861, 39.87023305892944, 34.56240688051496, 36.73816926138741, 37.292395796094624, 44.357570784432546, 48.540518351963584, 48.337391240256174, 48.18976981299264, 46.11848054613386, 49.1144152368818, 46.0575761113848, 39.41990641185215, 35.37941081183297, 34.364688941410606, 34.85734054020473, 35.894418239593506, 37.34995814732143, 34.89170285633632, 36.79806273324149, 39.55520173481533, 44.609415190560476, 46.10736690248762, 47.584008489336284, 46.271552835192, 38.172749928065706, 46.8335474559239, 47.10488850729806, 46.58634097235543, 44.6430583681379, 46.40954405920846, 46.51200566973005, 45.14865446090698, 43.88843536376953, 36.761195591517854, 33.47119229180472, 32.47251033782959, 35.04112039293562, 34.003014360155376, 34.40461676461356, 35.494420869009836, 42.246280738285606, 47.119705540793284, 45.40395212173462, 46.25373765400478, 46.88031578063965, 45.489880493709016, 42.668102400643484, 39.264499528067454, 37.99968767166138, 33.82794407435826, 33.27935600280762, 34.1856130191258, 33.79844202314104, 35.52317598887852, 34.15195941925049, 33.69187750135149, 35.70131043025425, 34.965784549713135, 35.16904715129307, 35.68410669054304, 38.62043973377773, 40.38304485593523, 41.46806512560163, 41.49548619134085, 43.67530632019043, 37.14543792179653, 18.14942601748875, 3.761747334684644, 1.825973561831883, 2.4818485506943295, 3.942592442035675, 4.4687408719744, 6.202903543199811, 8.47731818471636, 7.94991169657026, 8.268292920930044, 4.2825882094247, 1.6945760697126389, 0.033857282517211776, 0.20437843884740556, 0.15347919293812343, 3.6408623584679196, 16.726031950541906, 31.4187639100211, 24.39578185762678, 28.248839378356934, 12.114089574132647, 0.13202239573001862, 0.050021984947047064, 0.005506969855300018, 0.06612664381308214, 0.03870452634458031, 0.0441735050241862, 0.0485259645086314, 0.049037756331797154, 0.018617348678942238, 0.05357969332752483, 0.05447255041716354, 0.03660378871219499, 0.019535650831780264, 0.09383500806455101, 0.035204245775405846, 0.04010061553812452, 0.016684180358424783, 0.01781289282787059, 0.047869600621717315, 0.01899414765648544, 0.05881778350366013, 0.03269324551469513, 0.018423862722037092, 0.13708094214754446, 0.20957761843289646, 0.1005856172580804, 0.1899324283003807, 0.11555017105170659, 0.14620897519801343, 0.14760264541421617, 0.09649147944790976, 0.17244455883545534, 0.08544533646532468, 0.1312774457037449, 0.1261374479425805, 0.2124691004199641, 0.10859285973544631, 0.16492174964930328, 0.11395218037068844, 0.17621801421046257, 0.0995773006496685, 0.12269955527569566, 0.11262628223214831, 0.10165954141744546, 0.07880776442055192, 0.20612745785287448, 0.08050168638250657, 0.0905972153746656, 0.08596316046480622, 0.2057803057666336, 0.13051006330975465, 0.14845738240650722, 2.823430027280535, 34.591631003788535, 46.85270711353847, 35.99290200642177, 35.74090126582554, 32.568103654044016, 7.482705269541059, 0.5240020336849349, 0.3922858472381319, 1.0087015820401055, 0.5588787336434636, 0.3939105314867837, 5.333903201988765, 15.69248914718628, 15.723837682179042, 14.986717190061297, 7.886062094143458, 4.829862637179239, 1.0595602244138718, 0.7184826007911137, 6.72025294814791, 23.293418884277344, 44.83494676862444, 46.862861905779155, 49.2183290209089, 49.91703987121582, 49.53532668522426, 46.5178873198373, 49.1717517716544, 45.47162062781197, 47.29337229047503, 51.823153087071006, 48.55115256990705, 49.455578735896516, 49.43446316037859, 49.226757185799734, 50.6697347504752, 42.522735663822715, 36.535591057368684, 38.618462971278596, 39.43114512307303, 46.58374582018171, 51.78577872685024, 49.99377925055367, 50.191097668239046, 47.46873787471226, 50.38461889539446, 47.74493571690151, 41.29704563958304, 37.025261878967285, 36.02051067352295, 36.78094932011196, 37.97335747310093, 38.8790933745248, 38.44612332752773, 38.56288433074951, 42.416094711848665, 45.91993924549648, 48.68845592226301, 50.015544482639854, 48.61741406576974, 40.704444204057964, 48.61408240454537, 47.66058111190796, 48.086550848824636, 46.45548207419259, 48.001063687460764, 47.3352803502764, 46.921661036355154, 44.51806027548653, 36.12924303327288, 35.810810565948486, 33.92680651800973, 36.48591143744332, 35.87622785568237, 35.01770843778338, 36.497841494424, 44.19851957048689, 49.78627477373396, 47.12765427998134, 46.46499068396432, 48.00224835532052, 46.86795493534633, 44.668412344796316, 41.59272623062134, 37.641070297786165, 35.4868369102478, 34.452774729047505, 35.987861088344026, 36.641502448490684, 37.01920999799456, 36.08634832927159, 34.895913464682444, 37.635942527226035, 36.31826530184065, 37.78329644884382, 36.037321840013774, 39.616495268685476, 41.62069967814854, 43.477848938533235, 42.52504941395351, 44.85981437138149, 39.05171094621931, 18.666168757847377, 3.56819440637316, 2.424016088247299, 6.9057594282286505, 8.862368243081228, 7.31066700390407, 9.210935916219439, 12.26417326927185, 10.970365711620875, 12.909248369080679, 8.01925732408251, 3.679192747388567, 0.9525006434747151, 0.5637597888708115, 0.6754451873047012, 5.817349306174687, 28.200375693184988, 44.58674669265747, 32.479263986860005, 34.700672558375764, 12.216984578541346, 0.16649341317159788, 0.10686571669897862, 0.17639253341725894, 0.11929601005145482, 0.10986712814441749, 0.10500596077846629, 0.17322847034249986, 0.1540470996073314, 0.07250451336481742, 0.13115239169980797, 0.19761341757008008, 0.15517076716891356, 0.10770950213606868, 0.19709592605275766, 0.10302336287817784, 0.16693822001772268, 0.1751201988330909, 0.1447428645832198, 0.09529797706220831, 0.08373658851321254, 0.09849492872932128, 0.13805120651211056, 0.22522625087627343], [0.08761798523898635, 0.03850646536531193, 0.004503514526212322, 0.029974124993064573, 0.00790783709713391, 0.016844112758657763, 0.014075013043891107, 0.0709253791719675, 0.05813581509781735, 0.07064884222511734, 0.07448236151997532, 0.009613443432109696, 0.011832209686482591, 0.017382258881947825, 0.05897567860249962, 0.06968009099364281, 0.059848702113543234, 0.07076000661722251, 0.022542690725198815, 0.08289753246520247, 0.10380237536238772, 0.07611844515694038, 0.09697304932134491, 0.03197328593315823, 0.024960015833910023, 0.0643616249518735, 0.01880961496915136, 0.015139619221112557, 0.03031022713652679, 0.21120140701532364, 8.975555266652789, 32.253444058554514, 29.047864845820836, 30.360157217298234, 22.738540955952235, 12.05914843082428, 1.6194583347865512, 0.11947135707097394, 0.14357989627335752, 0.22296590145145143, 0.40790070220828056, 4.404623329639435, 5.786306057657514, 4.041925626141684, 5.465162490095411, 5.738855940955026, 1.783422902226448, 1.3003820734364646, 0.35742730487670216, 1.226747127515929, 7.557546053613935, 21.132278987339564, 41.31231778008597, 46.773817266736714, 45.150989055633545, 45.78320564542498, 44.06829990659441, 47.933207580021445, 48.68199062347412, 44.81952176775251, 49.13982827322823, 49.02522121156965, 46.451313155038015, 46.343470164707725, 46.511081559317454, 45.83603627341134, 39.836833068302695, 33.477355343954905, 35.23231744766235, 34.95751966748919, 44.92528377260481, 49.092385973249165, 47.4461110660008, 47.33225788388933, 47.468630177634104, 46.73520612716675, 45.8731882912772, 38.477004596165244, 34.62154994692121, 34.19451366152082, 32.65352828162057, 33.752010686056956, 33.10050589697701, 34.903382778167725, 36.565287658146445, 42.67084346498762, 43.11013289860317, 46.32061059134347, 46.67624371392386, 44.9863931792123, 36.13370030266898, 48.04918343680245, 45.00003249304635, 44.12602206638881, 42.558411189488, 41.36573553085327, 39.53925561904907, 37.28809833526611, 35.176794392721995, 32.73358889988491, 32.24557869774954, 32.57468359810965, 33.680784702301025, 32.55260222298758, 32.074805872780935, 31.212725503104075, 40.623657499040874, 44.90196909223284, 45.428402832576204, 44.18592248644148, 43.8662497656686, 45.113440990448, 42.63838495526995, 40.29254804338728, 34.76990440913609, 32.16750873838152, 31.145435673849924, 32.25854056222098, 36.25585658209664, 36.70460251399449, 36.517602171216694, 33.82097155707223, 34.269634110586985, 34.707790987832205, 34.49465847015381, 35.931684902736116, 36.84729766845703, 39.22711821964809, 40.33124950953892, 41.84701292855399, 41.553826740809846, 28.11457586288452, 7.800629649843488, 1.1568334847688675, 1.263072092618261, 2.2861501489366804, 2.414083638361522, 3.8589204975536893, 6.179967973913465, 7.850377883229937, 8.485017657279968, 8.218452623912267, 2.384733144726072, 1.3052335445369994, 0.22391542978584766, 0.09121881451989923, 0.7794878929853439, 13.83381996835981, 42.770431995391846, 42.83252109800066, 31.341930730002268, 21.66018921988351, 2.2473566191537038, 0.06378095503896475, 0.10747904450233493, 0.07715646124311856, 0.02611667037542377, 0.02463443437591195, 0.05022712643923504, 0.031537523958832026, 0.03882879324789558, 0.020376672935006872, 0.030303787839199816, 0.052764291010264835, 0.04098338959738612, 0.04481494453336511, 0.03640635198514376, 0.03948987295318927, 0.0512800058349967, 0.05194468856123941, 0.039469035142766576, 0.0433651832198458, 0.05524262320250273, 0.029218471076871668, 0.033875782774495225, 0.009385109612984317, 0.024215377933744873, 0.00782810159892376, 0.009794915078340896, 0.014238076883235147, 0.01903156377375126, 0.047444040421396494, 0.017252458525555472, 0.06412016148013727, 0.04192190191575459, 0.031057708098420074, 0.005448685393535665, 0.024000448573912894, 0.021190801302769353, 0.06653731356241874, 0.016579741944691966, 0.02399325949539031, 0.04213522654026747, 0.04519706492179206, 0.04485142596864274, 0.06125274034483092, 0.04832074159224119, 0.06046075427106448, 0.07441551224993807, 0.040195637582136054, 0.01981735143012234, 0.023286499116303663, 0.03644193775419678, 0.013883080932178667, 0.04478298214131168, 0.40510329231619835, 13.95712617465428, 39.06914050238473, 31.229474135807582, 31.14373336519514, 27.158731290272303, 13.467904380389623, 1.4425554616110665, 0.07230532262474298, 0.18084854073822498, 0.23916226093258175, 2.1851222557680945, 5.858432701655796, 6.546560142721448, 7.656839285578046, 7.452834963798523, 7.505468436649867, 5.882584205695561, 2.093199325459344, 1.303491935133934, 1.808606539453779, 9.037504536764962, 25.16890617779323, 44.91830083302089, 48.23775407246181, 46.680023533957346, 46.93160738263811, 45.63205105917794, 48.46650614057268, 50.46073988505772, 45.39391892296927, 49.80876956667219, 50.883141721997944, 47.78739268439156, 47.4909964288984, 47.82693140847342, 47.57461452484131, 41.65555879047939, 35.288493633270264, 37.38921546936035, 36.78215135846819, 45.912869453430176, 49.70199312482561, 49.41561964579991, 47.95468446186611, 47.24822984422956, 47.703263895852224, 47.56346961430141, 40.84702818734305, 36.410360200064524, 36.03696400778634, 34.96961995533535, 34.82280799320766, 34.88968440464565, 36.34629086085728, 38.77718761989048, 44.1263347353254, 44.77345173699515, 48.339552130017964, 48.621822697775706, 46.192343371255056, 37.96773290634155, 47.909343991960796, 45.89582552228655, 45.64964042391096, 45.42334106990269, 43.346614837646484, 41.444528102874756, 39.06142452784947, 36.53333636692592, 33.20342261450631, 33.96117925643921, 33.81115027836391, 35.07365533283779, 33.65960659299578, 33.916610036577495, 33.59192419052124, 41.928355489458355, 45.991040161677766, 47.025036334991455, 45.11844021933419, 44.74814292362758, 46.96888099397932, 43.10075977870396, 40.88191509246826, 35.37933438164847, 34.0401177406311, 32.52196414130074, 33.50523151670183, 37.290884562901084, 37.888370582035606, 37.07502140317644, 34.09395933151245, 34.87632301875523, 35.922356946127756, 36.36474527631487, 37.55015311922346, 37.88784946714129, 39.72721133913313, 42.312910488673616, 42.50712306158883, 42.863899162837434, 29.707651887621196, 10.77905227456774, 1.8836818252290999, 2.1542357759816304, 5.1524922507149835, 4.170906339372907, 4.800002753734589, 6.447352026190076, 7.747440321104867, 6.465678334236145, 6.103007989270346, 2.8744473925658633, 0.8104201874562672, 0.06257036714149372, 0.11470510996878147, 0.7743790671229362, 13.520759327071053, 41.57827050345284, 46.643663610730854, 32.58430337905884, 26.988760982240947, 3.2225187037672316, 0.03458717924409679, 0.03506462023194347, 0.012219193474655705, 0.04722338422600712, 0.047551774818982394, 0.0045490264144193914, 0.02257407466614885, 0.041117393478218994, 0.011501881876029074, 0.02427246647753886, 0.025359505022476827, 0.015543327201157808, 0.03922966155888779, 0.015669639887554303, 0.029249025508761406, 0.04777945385181478, 0.03135296243375965, 0.09969050743217979, 0.06078927378569331, 0.04129213660157152, 0.013974580531274634, 0.03664797830528446, 0.01966905590545918, 0.17849462133433136, 0.08344752580991813, 0.04300014155783823, 0.07976048865488597, 0.11473539977201394, 0.14701849461666175, 0.05482819436916283, 0.2165783763464008, 0.16980338841676712, 0.18078844967697347, 0.09790001636637108, 0.11670241850827422, 0.1295557309474264, 0.09173048420676164, 0.16627092153898307, 0.1740434587533985, 0.20092576768781456, 0.17942751199007034, 0.10756602590637547, 0.15857792219945363, 0.14824114686676435, 0.18035125599375793, 0.1598940494337252, 0.10235669543700558, 0.16589400890682424, 0.12678183907909052, 0.11547110815133367, 0.06576876408819642, 0.1343183953847204, 0.5419172037925039, 15.628199202673775, 47.61196804046631, 38.794655391148154, 41.14972298485892, 30.382335867200577, 17.29250815936497, 1.8931962975433894, 0.4262420194489615, 0.3061034046113491, 1.814963924033301, 2.7003965377807617, 7.893283009529114, 15.62612169129508, 12.814616509846278, 14.250077860695974, 12.53381027494158, 8.116181220327105, 3.895758543695722, 1.4243855965988976, 1.6618752415691103, 10.06094205379486, 24.50965588433402, 44.28376007080078, 49.121738638196675, 47.904567105429514, 48.38652890069144, 47.816206863948274, 50.93253646578108, 53.90130370003836, 48.10543605259487, 52.84192228317261, 52.116089139665874, 48.28830221721104, 48.53403220857893, 50.22584560939244, 49.446421010153635, 43.802378450121196, 36.67422846385411, 38.40315566744123, 38.23360225132534, 48.78803750446865, 49.831017698560444, 51.36260216576712, 49.49556909288679, 48.1354592187064, 49.756814411708284, 50.1764543397086, 42.691041878291536, 37.93620545523507, 36.91767249788557, 36.03883307320731, 36.289614404950825, 36.21950708116804, 38.94153683526175, 41.26716143744332, 46.78876631600516, 47.460389614105225, 50.90362501144409, 49.294047015053884, 47.93230084010533, 41.89993735722133, 49.72839975357056, 47.851993560791016, 48.48301158632551, 47.8155745778765, 45.234263215746196, 42.794979981013704, 40.47767237254551, 38.265775884900776, 35.8233312198094, 35.15487977436611, 34.59771415165493, 37.453274386269705, 35.34498248781477, 34.53525332042149, 34.79788480486189, 43.34545448848179, 46.99380418232509, 48.6733192716326, 45.21775776999337, 47.12398910522461, 49.85069499697004, 47.094184807368684, 43.2230098588126, 37.24051359721592, 34.66870737075806, 33.95123985835484, 35.025966371808735, 40.12157719475882, 39.36204876218523, 39.28431231634957, 37.06917101996285, 36.94311680112566, 38.40833554949079, 38.99717453547886, 38.32846253258841, 39.28539970942906, 42.969727175576345, 43.75386960165841, 44.077874524252756, 44.85451636995588, 30.245001247950963, 11.105186820030212, 2.0937391136373793, 3.383399248123169, 6.9323936104774475, 5.868889306272779, 10.144193632262093, 13.038701125553676, 16.09705148424421, 14.347087740898132, 16.281369822365896, 7.754642997469221, 3.3836474290915897, 0.4085672678692, 0.26722877632294384, 1.6841516005141395, 17.161722217287334, 48.75874737330845, 48.952678544180735, 39.31277561187744, 31.702333790915354, 3.455199978181294, 0.13924955363784516, 0.19227925022797926, 0.13520116944398197, 0.12377170845866203, 0.13644178930137837, 0.10815168983702149, 0.12628677992948464, 0.1648407325680767, 0.12789828702807426, 0.1407492110239608, 0.16358698984341963, 0.1118602908349463, 0.0868945854849049, 0.08253917098045349, 0.05283420725858637, 0.1619780883193016, 0.10174625140747853, 0.18223128654062748, 0.1933789655034031, 0.1173352338373661, 0.1678813701229436, 0.12162733423922743, 0.05017459086541619], [0.07373806288731949, 0.02576324014392282, 0.02372011691997094, 0.07349187002650329, 0.07321146543004683, 0.0587315009906888, 0.008014573200073625, 0.02145784384837108, 0.012287644087336957, 0.02559175398865981, 0.026265663094818592, 0.01771713457336383, 0.022462206293961832, 0.015142967791429587, 0.016569923542972122, 0.0157291338379894, 0.019244761172948138, 0.05962536231215511, 0.05405422340014151, 0.055560513466064415, 0.03616108871730311, 0.051143335311540535, 0.03754777341548886, 0.03495103007714663, 0.020780263867761408, 0.02930879426587905, 0.04332337528467178, 0.03829123066472156, 0.03301836217620543, 0.0308127535640129, 2.7712916135787964, 26.580391032355173, 27.578251361846924, 19.12546031815665, 23.751720326287405, 15.722154481070381, 6.944653272628784, 0.28748163527676035, 0.12511081088866505, 0.19360199996403285, 3.538812211581639, 4.786960116454533, 4.0324365581784924, 5.718862933771951, 3.953786858490535, 7.060798057488032, 5.089337468147278, 1.0067764967679977, 1.5375281082732337, 0.3568362465926579, 1.8506652883120944, 10.10958639213017, 26.014858041490825, 46.24813740594046, 49.62915168489729, 48.639839376722065, 49.211175850459504, 47.277995926993235, 48.39083678381783, 48.106401852199006, 49.18439054489136, 47.997804982321604, 47.572853156498496, 46.4710043498448, 47.36263540812901, 46.00774710518973, 38.75764581135341, 35.876127106802805, 36.3335965020316, 36.651282038007466, 43.79953663689749, 46.223050934927805, 47.49242775780814, 47.214822905404226, 46.40653896331787, 47.10282489231655, 45.68360321862357, 43.08491093771798, 34.68157890864781, 34.4929700578962, 33.61765684400286, 33.700215339660645, 34.14915929521833, 35.82458536965506, 41.14379269736153, 43.11215482439314, 44.869552271706716, 45.660278115953716, 45.48928642272949, 43.92117180143084, 33.27120923995972, 48.24392407281058, 45.95806401116507, 44.30678640093122, 41.67736571175711, 35.90118925912039, 35.44672148568289, 33.452915055411204, 33.23470687866211, 31.552172797066824, 33.96277386801583, 34.9133951323373, 33.21171876362392, 32.05370766775948, 33.24379859651838, 33.11399929864066, 36.96698733738491, 45.38406637736729, 45.2423335484096, 41.79170874186924, 44.2782119342259, 46.48114177158901, 42.201819215502056, 42.267128808157786, 35.75132703781128, 32.48824453353882, 32.75773736408779, 33.99809850965227, 37.72338560649327, 40.99650130953108, 40.05235229219709, 39.22558961595808, 37.39297097069876, 38.21480737413679, 37.41587570735386, 38.57771178654262, 38.88317544119698, 40.935659408569336, 41.325932775224956, 41.937096323285786, 37.32197427749634, 16.20414059502738, 3.8805806381361823, 0.9138844013214111, 1.3274306505918503, 2.674409189394542, 3.201761177607945, 2.7129352135317664, 4.87486047404153, 5.7638616391590665, 5.048250164304461, 5.641080890383039, 2.9331570650850023, 0.6797204464673996, 0.09697472530284099, 0.44159561129552977, 4.633936899048941, 18.32490972110203, 28.199081591197423, 22.23048346383231, 26.16802065713065, 12.50663673877716, 0.7279964217117855, 0.049883156682231596, 0.034684983281684775, 0.07217298794005599, 0.011646105342411568, 0.05742445934031691, 0.04536683099078281, 0.021540708241185973, 0.044225887927625857, 0.008032771509273775, 0.030700184604419128, 0.022124362011839236, 0.023053020305399383, 0.013830199305500303, 0.029285096430352757, 0.008119160891510546, 0.03287813612925155, 0.017459438847643987, 0.023947461774306636, 0.021558718256918446, 0.036730769755584855, 0.04300583785931979, 0.04861198239294546, 0.05439845100045204, 0.034581377769687345, 0.0072551305139703405, 0.05855915988130229, 0.11247767627771411, 0.04503581446728536, 0.06375101128859179, 0.013283348426089754, 0.03171157158379044, 0.03386490585814629, 0.015090099735451596, 0.06483051979116031, 0.0722542560792395, 0.05284165757309113, 0.02770631168303745, 0.04215412713321192, 0.02223067487856107, 0.02374640167025583, 0.035360790589558225, 0.029038635548204184, 0.05711986497044563, 0.049303165304341486, 0.0831909988607679, 0.08637142820017678, 0.023817612224125435, 0.02253392744543297, 0.020101672869973948, 0.031245401062603508, 0.03146968063499246, 0.01627154285753412, 0.04050414709906493, 5.040706591946738, 32.42397369657244, 31.735796315329416, 24.875099863324845, 28.501317807606288, 19.968125683920725, 6.476016819477081, 0.3455298718597208, 0.05090437902669821, 0.26128285537873, 1.2152824912752425, 5.371410880770002, 7.766798870904105, 9.602764810834612, 6.019080264227731, 7.893619128635951, 6.125499742371695, 3.287487183298383, 2.768008589744568, 1.7515747483287538, 2.9888364544936588, 12.639258742332458, 29.664368084498815, 48.22092553547451, 49.64845725468227, 49.782019002096995, 49.63937595912388, 49.00452600206648, 51.460234778267996, 50.10892479760306, 49.915097849709646, 48.961363792419434, 48.03137520381382, 48.761898381369456, 49.275078432900564, 46.48530721664429, 40.14588199343, 38.25385972431728, 37.27792269842965, 38.554080963134766, 45.051577704293386, 48.24637678691319, 48.52020181928362, 47.63340670721871, 46.45432867322649, 48.390197549547466, 47.0243866784232, 43.84292466299874, 36.41090563365391, 35.907039642333984, 34.44575357437134, 35.7998046193804, 35.76436185836792, 37.659892967769075, 42.03357553482056, 45.9020927974156, 46.599973337990896, 46.770301478249685, 47.84332568304879, 45.24158314296177, 36.2630375453404, 48.549790722983225, 47.12287391935076, 46.26998601640974, 43.48928567341396, 39.21159594399588, 36.79247638157436, 36.315989766802105, 33.852134227752686, 33.052875995635986, 34.337139333997456, 35.45638295582363, 34.43557793753487, 33.60848869596209, 34.38353245598929, 34.65252501623971, 39.587813104902, 46.51205430712019, 46.14024230412075, 42.45295490537371, 44.09436954770769, 48.14717040743147, 43.81125477382115, 43.013108253479004, 35.969149589538574, 33.70381450653076, 33.07983848026821, 35.07551745006016, 38.44089133398873, 41.48325041362217, 40.86703552518572, 39.66288144247872, 38.20845672062465, 38.40470511572701, 38.981176308223176, 39.065385001046316, 40.90485804421561, 42.56328535079956, 42.25419126238142, 43.38098757607596, 39.136711733681814, 19.5175975390843, 5.541997407163892, 2.137988499232701, 3.0873853606837134, 3.665031450135367, 4.811272731849125, 5.795519803251539, 6.706844227654593, 5.655788924012866, 5.990937888622284, 3.6363521090575626, 1.0780038918767656, 0.31351444550922936, 0.11099262775055, 0.4272885104375226, 4.714003162724631, 21.79424602644784, 36.382904393332346, 28.884055852890015, 31.235307148524694, 17.20274611881801, 0.8629542142152786, 0.07866481066282306, 0.049752243528408666, 0.029163217970303128, 0.02872354763426951, 0.049607050605118275, 0.04862306286979999, 0.03479193736399923, 0.04081868879230959, 0.07670166636151926, 0.04468050978279539, 0.01294879419063883, 0.04227616504899093, 0.04156236995809844, 0.02273140488458531, 0.030691672382610183, 0.04204249794461897, 0.003111180387869743, 0.01875475880556873, 0.017095262317785194, 0.02722650091163814, 0.07280757424554654, 0.03825157368555665, 0.05615211797079869, 0.15245364154023783, 0.08916141491915498, 0.10764566556151424, 0.22702926769852638, 0.1302995274641684, 0.20738927514425345, 0.09574851074389049, 0.08636745877031769, 0.10242679488978215, 0.10872115035142217, 0.18737179998840603, 0.1379478791994708, 0.15228559555751936, 0.11372941732406616, 0.0907441589183041, 0.12946833563702448, 0.2422152885368892, 0.15097626724413463, 0.11195837985724211, 0.19588841870427132, 0.12576607215617383, 0.11961952197764601, 0.18307542481592723, 0.08371661244226353, 0.12559166151498044, 0.06873968216989722, 0.13334180707378046, 0.1355317381343671, 0.19264652766287327, 0.1376752302582775, 6.447657746928079, 39.38488054275513, 38.248356751033235, 29.41734572819301, 34.7526798248291, 23.648404087339127, 9.698638660567147, 0.7531308787209647, 0.24248550832271576, 0.6260247134736606, 8.498551879610334, 15.135139397212438, 10.949578438486371, 17.20944765635899, 10.155837944575719, 16.58550637108939, 9.952161056654793, 3.9749258841787065, 4.320267421858651, 1.6348761703286852, 2.0576267199856892, 12.270287684031896, 29.58089590072632, 47.80151489802769, 49.731981549944194, 50.57015664236886, 49.15392616816929, 51.92964812687465, 51.59154530933925, 51.919847692762104, 51.83627128601074, 50.425852979932515, 48.839245728084016, 49.885039942605154, 49.18290363039289, 49.19013670512608, 41.48669672012329, 39.76045152119228, 40.523301192692344, 40.70578868048531, 47.087274823869976, 51.080456665584016, 50.6296193259103, 49.771634919302805, 48.597563062395366, 50.73469345910208, 48.95348800931658, 47.16923924854824, 37.41249540873936, 37.98747968673706, 36.07165288925171, 36.53633451461792, 37.7796243258885, 38.95921305247715, 44.2944290297372, 47.63879156112671, 48.36508328574044, 48.20281158174787, 49.205603395189556, 46.7437732560294, 38.89013753618513, 50.91775417327881, 47.732300417763845, 49.66385098866054, 46.427946363176616, 39.77307987213135, 38.54841818128313, 37.226735319410054, 35.417858668736045, 34.804433482033865, 35.536540848868235, 37.442282336098806, 36.26099477495466, 35.19572128568377, 36.316806180136545, 37.01845611844744, 40.87264272144863, 48.726688385009766, 47.69781303405762, 42.76983445031302, 43.718135016305105, 50.0354962348938, 44.80260985238211, 45.42339318139212, 38.195678983415874, 35.70718513216291, 34.82240847178868, 36.133512701307026, 39.88742985044207, 43.940043108803884, 42.3518898827689, 41.64443472453526, 40.28440475463867, 41.25804887499128, 41.961258683885845, 40.94094698769705, 43.648170130593435, 44.58851848329817, 44.558134010859895, 46.29151153564453, 40.02988181795393, 18.561148473194667, 5.625702789851597, 2.857204569237573, 4.637757974011557, 7.029225877353123, 7.930075458117893, 7.3381766591753275, 13.225141269820076, 15.467265026909963, 13.445648431777954, 11.854722005980355, 4.689716603074755, 2.0562307834625244, 0.33542852103710175, 0.9628500938415527, 6.130698297704969, 24.387174776622228, 37.86893647057669, 31.79163898740496, 36.326384271894185, 19.73178791999817, 0.9769952148199081, 0.13060480036905833, 0.13800387190920965, 0.21146063453384809, 0.0823698832786509, 0.13352278593395436, 0.175512731341379, 0.17668785899877548, 0.12226115380014692, 0.1768299170902797, 0.11671237940234797, 0.10870935062744788, 0.17464797917221273, 0.09516782047493116, 0.0672000590711832, 0.09493871991123472, 0.09693278505333833, 0.09223131768937622, 0.054664311198783774, 0.09341981927199022, 0.13961288199893065, 0.1776515415736607, 0.13625536859035492, 0.17348506514515194], [0.025716229541493312, 0.02235165936872363, 0.06111807828502996, 0.03484625069956694, 0.020353930137519325, 0.02274617489560374, 0.010818136556606208, 0.047834954623665125, 0.004357387345018131, 0.019870606251060963, 0.01872739688094173, 0.036322753078171184, 0.021700318337285092, 0.017228984606585333, 0.026558944589591453, 0.05794261582195759, 0.026548607108582343, 0.02757021621800959, 0.02476547984406352, 0.06336977638836418, 0.04049559755782996, 0.026176627426009094, 0.04451958841777273, 0.012306036627186196, 0.03990723305780973, 0.04558731076706733, 0.03982389199414423, 0.024115431421835507, 0.13493617437779903, 0.015874905212383186, 1.0912635517971856, 15.379919222423009, 30.294389043535503, 20.34110845838274, 20.853364399501256, 19.415787322180613, 15.116855212620326, 3.279295474290848, 0.02751482231542468, 0.21653779995228561, 0.6305763806615556, 4.184051028319767, 6.073568471840449, 6.209125220775604, 4.3633575439453125, 5.291081888335092, 6.936917322022574, 2.189954945019313, 2.2121959115777696, 1.2042446264198847, 0.9555975858654294, 4.2096651281629285, 15.187221356800624, 32.905185086386545, 48.50633668899536, 48.256448200770784, 47.16084235055106, 50.06571395056588, 48.83438893726894, 47.14987809317452, 50.644620486668174, 47.986743450164795, 49.30893700463431, 48.43378012520926, 47.80987358093262, 42.709239210401265, 38.44327456610543, 38.46170466286795, 36.294064726148335, 37.28028161185128, 47.2903185571943, 48.63685859952654, 47.7135784966605, 45.7234719821385, 44.57388210296631, 47.802265303475515, 45.56633847100394, 43.650306701660156, 35.528967312404085, 35.377263818468364, 33.27481882912772, 33.74804326466152, 33.29096296855381, 36.968561104365754, 42.12874501092093, 43.228036880493164, 45.11768633978707, 47.388496603284565, 45.67819404602051, 44.62480197634016, 32.40701314381191, 47.768118381500244, 44.71271405901228, 43.387466771262034, 41.58155352728707, 36.04332855769566, 33.38300575528826, 33.65614986419678, 32.208562169756206, 33.92907510484968, 33.940431935446604, 32.49047490528652, 33.040424823760986, 33.715393679482595, 32.59559767586844, 32.64208459854126, 35.60871178763253, 44.296197346278596, 44.58275147846767, 44.190379755837576, 43.612515449523926, 44.878185408455984, 44.58146606172834, 41.13408258983067, 40.10658993039812, 35.09443392072405, 30.822031770433696, 35.881168024880544, 41.88456446783883, 42.85340390886579, 43.01786776951381, 40.6428518976484, 38.9523412840707, 39.7051751273019, 40.04536240441458, 40.43263067517962, 40.83679001671927, 40.25611168997628, 40.12980038779122, 40.54498304639544, 25.426378624779836, 8.822500348091125, 1.7455541342496872, 0.8814125380345753, 1.9008647203445435, 2.3676835681710924, 5.121571029935565, 4.526122570037842, 3.955478310585022, 2.8398321185793196, 3.696059933730534, 2.6881475150585175, 0.19665867808674062, 0.13745952397584915, 0.13398337550461292, 1.8795087805816104, 11.640653218541827, 32.42687804358346, 27.237827845982142, 28.96320973123823, 25.2407922404153, 4.431915853704725, 0.05026081909558602, 0.027666488462792974, 0.03801788283245904, 0.033947564994118044, 0.03814061963930726, 0.026502152904868126, 0.016629293660766313, 0.04430525956143226, 0.04201560760182994, 0.0901546748355031, 0.042785388617111106, 0.03538613047982965, 0.0310591024878834, 0.024552441900596023, 0.061063619064433236, 0.06298191898635455, 0.019628886632355194, 0.039026416572076936, 0.01754934643395245, 0.020898166112601757, 0.10717597683625561, 0.03292084990867546, 0.0223409062850156, 0.006766617955041251, 0.03402601382029908, 0.060236498447401185, 0.0517842455634049, 0.057803875766694546, 0.03604661307430693, 0.03958647259111915, 0.02234945073723793, 0.027515397373852984, 0.018042266501912048, 0.03233157277905515, 0.018453645320343118, 0.028131744658042277, 0.028989546932280064, 0.03803156888378518, 0.024467139870726635, 0.04364755556785634, 0.023431057609351616, 0.03135449253022671, 0.010559849657251366, 0.019056270930117795, 0.05666234577074647, 0.00866519583256117, 0.05700714673314776, 0.013162237558779972, 0.04748694758330073, 0.056350219662168195, 0.05276355140709451, 0.0263015796496932, 0.024584524732615267, 0.0333915869705379, 1.7363086874995912, 22.60662940570286, 33.834649085998535, 25.118041890008108, 25.126245975494385, 25.988447938646587, 15.331785576684133, 2.6321506798267365, 0.07662636933049985, 0.09078593631940228, 0.42249178354229244, 4.242246099880763, 6.226022371223994, 7.844482336725507, 7.782475743974958, 6.332835725375584, 7.386540463992527, 4.350733969892774, 4.532022459166391, 1.8925145055566515, 1.775120456303869, 6.106744817325047, 18.024518251419067, 36.77707569939749, 50.40402173995972, 48.105988434382844, 48.909245354788645, 49.328176566532676, 49.93129062652588, 49.05772835867745, 50.84568050929478, 49.710476875305176, 50.212741306849885, 48.88418320247105, 50.34998559951782, 43.21449484143938, 40.04299306869507, 38.17005055291312, 37.53603785378592, 39.148707798549104, 49.23664099829537, 48.76645639964512, 48.62484516416277, 45.74609531675066, 45.334942613329204, 48.83827992847988, 46.435054370335166, 44.214861733572825, 36.412614890507285, 36.63698264530727, 34.559509481702534, 35.2093050139291, 35.79335669108799, 37.13238573074341, 43.58171755926949, 45.09916591644287, 47.42395673479353, 49.08040727887835, 46.921456064496724, 44.32672425678798, 35.71269505364554, 47.766162463596885, 46.56692770549229, 46.12830182484218, 43.95031254632132, 38.21134717123849, 35.03365107945034, 34.620754378182546, 34.17709800175258, 34.66699811390468, 35.92699486868722, 34.40768092019217, 35.26310838971819, 35.24584559031895, 34.17101485388619, 33.88127844674246, 37.08310563223702, 46.33928387505667, 46.26427459716797, 45.99498673847744, 44.02907732554844, 45.48556566238403, 45.70054292678833, 42.39925922666277, 42.00344467163086, 35.085477692740305, 32.90641144343785, 37.25232206072126, 43.027008124760215, 43.53615127290998, 43.83937760761806, 42.41321120943342, 40.667048999241416, 41.007031304495676, 41.613741057259695, 41.24620567049299, 43.020963191986084, 41.83585064751761, 40.78503635951451, 42.61964566367013, 29.377553394862584, 10.793215308870588, 3.3344804559435164, 2.1675834826060703, 4.238905319145747, 3.973480658871787, 5.0811841913631985, 6.746536680630275, 6.138026910168784, 5.669765225478581, 2.0909174936158315, 1.130097250853266, 0.26970792614987915, 0.053898723529917855, 0.1299900205007621, 1.853808696780886, 11.719365886279515, 31.052788393838064, 28.739804301943096, 30.083827359335764, 29.331761292048864, 7.2069034746715, 0.07802143054349081, 0.011503410276158579, 0.010190738481469452, 0.04290711779945663, 0.048667177824037414, 0.04126189768846546, 0.027473470695050697, 0.003560071802764599, 0.018634400263960873, 0.03159581690228411, 0.042528040640588315, 0.01241758099890181, 0.05196130249117102, 0.04872874469895448, 0.005743271795966263, 0.05405910885227578, 0.05178937868082097, 0.0352799770688372, 0.028959423370127167, 0.09887340199202299, 0.11210015296403851, 0.05597987864166498, 0.006811245203217757, 0.07420916975076709, 0.1518746611795255, 0.15233207520629677, 0.14320801837103708, 0.22041603470487253, 0.10178475826978683, 0.14169103120054516, 0.08479814297918763, 0.13526902294584683, 0.039139942266047, 0.07094744513077395, 0.11308566401047365, 0.08553495058523757, 0.1266421287187508, 0.09211836196482182, 0.09790545143187046, 0.12413000208990914, 0.134721024494086, 0.09665396144347531, 0.10192597497786794, 0.17866052314639091, 0.14131756552628108, 0.03484179611716952, 0.1179586039589984, 0.1123534772279007, 0.14149649521069868, 0.1263642143458128, 0.10013503607894693, 0.1250596357775586, 0.3645376461957182, 0.13986864898885998, 2.204778926713126, 26.100548437663488, 44.04901170730591, 31.057891845703125, 30.710033757346018, 27.57051627976554, 21.39946675300598, 4.458788011755262, 0.22161487037582056, 0.5066460307155336, 2.8988151592867712, 8.671835609844752, 17.6530328137534, 15.879862955638341, 15.384425129209246, 13.022326827049255, 13.919534683227539, 7.6944325140544345, 6.658331905092512, 2.8523421330111365, 1.8307202671255385, 5.317071190902165, 16.608706406184606, 36.40395048686436, 50.557326793670654, 48.700618743896484, 48.163443088531494, 50.5991028376988, 51.01639427457537, 50.371862002781455, 52.65151384898594, 51.96469136646816, 52.744796889168875, 51.99879659925188, 52.17355421611241, 44.84286076681954, 41.349754674094065, 40.20449699674334, 39.137819971357075, 40.42432062966483, 51.85833529063633, 52.03310680389404, 51.22494445528303, 46.34352922439575, 44.83130938666207, 50.26747226715088, 48.59901523590088, 46.313679763248985, 38.73263924462454, 38.116907255990164, 36.252816745213096, 37.433774266924175, 37.44752127783639, 39.36942080089024, 44.634918553488596, 46.402707031794954, 49.91324268068586, 50.67886815752302, 48.00627136230469, 45.98360906328474, 39.17277635846819, 50.349283831460134, 48.27565649577549, 47.58084011077881, 45.531034673963276, 39.95379556928362, 36.82214866365705, 37.42032602855137, 36.183247906821116, 36.77648857661656, 37.477440220969065, 36.00590903418404, 35.465092522757395, 37.137416226523264, 35.05670172827584, 35.732782295772004, 38.076322828020366, 48.25115367344448, 48.448989731924875, 47.771144321986604, 43.463115283421104, 46.31066424506051, 48.792904717581614, 43.5883252961295, 43.03417866570609, 37.75308568137032, 33.85672351292202, 39.189090728759766, 45.17643335887364, 45.92041172300066, 46.01212099620274, 43.53185728618077, 42.00185006005423, 43.8140583719526, 43.79089307785034, 44.57387168066842, 43.271008014678955, 43.68033334187099, 43.53123194830758, 43.22129017966134, 29.104781014578684, 10.87471854686737, 2.8927908539772034, 2.9705537898199896, 5.507862210273743, 6.944367962224143, 9.953634074756078, 12.466193011828832, 9.653725504875183, 9.935756359781537, 7.1356236423764905, 5.148824904646192, 1.3592312527554375, 0.37864474207162857, 0.38155907711812426, 2.776215063674109, 15.45988951410566, 39.91519832611084, 35.13567842755999, 37.086624894823345, 33.83679607936314, 7.246991540704455, 0.21806792356073856, 0.09102076371865613, 0.07453175208398274, 0.1477317027747631, 0.14960646788988793, 0.11842922227723257, 0.12029648279505116, 0.11787435705108301, 0.16440112330019474, 0.18119711774800504, 0.15104406646319798, 0.11028011169816766, 0.08241065644792148, 0.14504843604351791, 0.16841174023491995, 0.14120411447116307, 0.1719856248902423, 0.1642055016543184, 0.08329063494290624, 0.2204252899225269, 0.22622483729251794, 0.12227578301514898, 0.07311216861541782, 0.21175830784652913], [0.01945431314275733, 0.039102870505303144, 0.02143995087992932, 0.026166344227801477, 0.0477183449880353, 0.006701227111209716, 0.025669849976631146, 0.03807224027280297, 0.01545013380902154, 0.02616717543319932, 0.017494427505880594, 0.018693387009469525, 0.045354274700262716, 0.016696658617417728, 0.0744625890095319, 0.02453459642960557, 0.049836704174854925, 0.0602625949042184, 0.01949341711588204, 0.013257462315128317, 0.039233508852443526, 0.045988837257027626, 0.04785220298383917, 0.0360433662842427, 0.004942873160221747, 0.03742151840456894, 0.045222330173211436, 0.019754817642803704, 0.03351325847740684, 0.0215391883227442, 0.1360870919057301, 5.609990307262965, 27.750184535980225, 26.945668254579815, 23.007017612457275, 32.53197649547032, 25.55444782120841, 9.466692158154078, 0.654768488236836, 0.054755808253373416, 0.1675453595817089, 3.3817774951457977, 4.468858991350446, 5.706128188541957, 5.208938981805529, 3.8758649826049805, 4.237349356923785, 3.764794554029192, 2.8147819084780554, 2.055258469922202, 1.9001104065350123, 4.374852469989231, 10.854442834854126, 22.205593279429845, 41.2123783656529, 49.317903654915945, 48.42230517523629, 49.29920257840838, 50.52131428037371, 47.750591550554546, 48.92127963474819, 48.20438534872872, 47.13448435919625, 45.85430308750698, 43.81676122120449, 37.361752714429585, 36.54525600160871, 39.315617425101145, 36.228445938655305, 38.579434939793174, 43.47644887651716, 46.09213645117623, 48.783899852207725, 47.179835251399446, 47.43874250139509, 48.24071053096226, 47.016205174582346, 46.242832456316265, 38.37761756352016, 35.20369781766619, 33.96846096856253, 33.89185013089861, 35.05285242625645, 36.973080907549175, 40.24361188071114, 43.99832459858486, 46.839304038456504, 46.22125135149275, 47.447278363364084, 42.9223369870867, 32.30889415740967, 46.59646449770246, 47.03004598617554, 42.59821047101702, 41.77810069492885, 37.982028824942454, 35.46725688661848, 33.336094992501394, 34.04320968900408, 33.42767224993025, 31.97707598549979, 33.36792469024658, 33.04101889474051, 33.322598116738455, 32.80331754684448, 33.41499178750174, 33.94337797164917, 41.5482508114406, 44.79546710423061, 44.86953142711094, 45.69064174379621, 45.80455051149641, 43.85462542942592, 42.84970399311611, 42.69548872538975, 38.23249053955078, 32.73980753762381, 36.3251405443464, 42.88766895021711, 41.40465586526053, 42.89125769478934, 42.920325483594624, 41.950728688921245, 40.8015661239624, 42.099423612867085, 41.54014573778425, 43.02532318660191, 42.3807874407087, 42.670232023511616, 25.810235330036708, 11.541862862450735, 2.7208107795034135, 1.0996676151241576, 2.010229583297457, 3.644190762724195, 2.55183493239539, 3.3684760374682288, 4.140018556799207, 4.305011783327375, 3.4174564949103763, 1.1127779973404748, 0.970449468919209, 0.26654524728655815, 0.021214056394195983, 0.8442912442343575, 8.378321988242012, 23.622560262680054, 28.758041586194718, 23.37758067675999, 28.568941150392803, 12.116849746022906, 0.5296337114913123, 0.018911620834842324, 0.08351022923099143, 0.023967057865645205, 0.03309996279754809, 0.02438364952935704, 0.033684052526950836, 0.016237074974924326, 0.025673486924331104, 0.003920192389549422, 0.07460915257355996, 0.0707276812089341, 0.02046740663770054, 0.03649411370445575, 0.03726965208937015, 0.0027285485536724862, 0.037080785259604454, 0.03267899627930351, 0.010521675277102207, 0.05649491046954479, 0.016699350705104213, 0.04629414748134358, 0.029583370246525322, 0.031712999900004694, 0.0283678120800427, 0.018195549258962274, 0.013073750655166805, 0.019761840480246713, 0.05983498892081635, 0.03660495239975197, 0.034428836312144995, 0.006500845542177558, 0.03718168680955257, 0.05940080114773341, 0.009482825441019875, 0.04028169617855123, 0.0474589444430811, 0.0024224781580934568, 0.01991422417839723, 0.031956085070435486, 0.044175489739115746, 0.06885507383516856, 0.026390956282349567, 0.05614883725398353, 0.05463728514899101, 0.07124267571738788, 0.021443564078903625, 0.02913098077156714, 0.025953788044197217, 0.0396229472410466, 0.029927441783781563, 0.03784057484673602, 0.03950602887198329, 0.07177620101720095, 0.0930826212944729, 0.3415155772651945, 9.319919279643468, 35.03794159208025, 28.709854091916764, 26.814555747168406, 32.50959634780884, 29.400308745247976, 9.492159043039594, 0.5427712351083755, 0.18198465263204916, 0.20139817733849796, 1.5658851180757796, 3.2909128623349324, 6.4289631843566895, 6.14492039169584, 6.766774611813681, 5.379172887120928, 4.890805287020547, 3.4593428415911536, 2.8138467243739536, 2.5448374450206757, 4.795847296714783, 14.401385307312012, 25.426246609006608, 44.460463183266775, 47.655588831220356, 49.28245047160557, 50.41960654939924, 52.69763599123274, 49.13226168496268, 50.701105867113384, 49.662822655269075, 48.59766033717564, 47.47797203063965, 46.154489585331504, 39.69103206907, 39.272191183907644, 40.06905576160976, 37.45731128965105, 39.82282897404262, 45.467507294246126, 47.20116969517299, 49.584248951503206, 46.90154947553362, 45.61332218987601, 49.04902573994228, 48.64246232169015, 47.23979125704084, 39.05526147569929, 37.11152376447405, 35.97958925792149, 36.012933662959504, 36.488197394779746, 37.771515778132844, 42.846493925367085, 44.91950287137713, 48.25492307118007, 47.903924397059846, 48.2526718548366, 44.37394421441214, 35.23239387784685, 48.51920127868652, 48.210058552878245, 45.0592554637364, 43.48591579709734, 39.46898848669869, 36.212385177612305, 34.608994552067344, 34.49015603746687, 35.23267527988979, 34.15357487542288, 33.87433024815151, 34.52456004279, 34.635303906032014, 34.59630019324166, 34.78222703933716, 35.57582596370152, 44.16291700090681, 45.43515995570591, 46.48604025159563, 45.239630699157715, 44.42681653159005, 46.20035811832973, 45.754572119031636, 44.235709803445, 39.94646174567086, 33.835583618709016, 37.01751463753836, 43.96500103814261, 43.84292813709804, 44.47651352201189, 44.451493058885845, 42.73900876726423, 42.54613024847848, 42.55783101490566, 43.44408764157976, 43.0492319379534, 43.45329053061349, 42.90879842213222, 30.19222273145403, 14.026666351727076, 4.573944849627359, 1.979402814592634, 3.0281626071248735, 4.42115135703768, 3.8849949155535017, 5.310890768255506, 6.6404159750257215, 7.341133117675781, 4.933400784220014, 1.667428155030523, 0.4750943151967866, 0.13732529617846012, 0.0632911002529519, 1.1284834231649126, 7.298421672412327, 24.831769159861974, 33.93846559524536, 27.814319883074077, 32.02371576854161, 18.178681407655986, 0.9470249201570238, 0.04010106337123683, 0.03130828768813184, 0.03621168028829353, 0.027162961196154356, 0.014469615083986094, 0.06595099823815481, 0.03301507467404008, 0.016533603259761418, 0.04633810976520181, 0.018707425899005363, 0.00813189275296671, 0.013016013262261237, 0.022015450355995978, 0.036419658056859455, 0.10648605599999428, 0.010921576675692839, 0.04632383678108454, 0.023382270941510797, 0.046602745207824876, 0.010332679525682969, 0.116526012974126, 0.03488753277010151, 0.033921858694936545, 0.030718861280807426, 0.12234116664954595, 0.09231025845344577, 0.1539290209433862, 0.1487020757049322, 0.10667904492999826, 0.09627651276865176, 0.07922399137169123, 0.1806552532528128, 0.07853111890809876, 0.06353878589080912, 0.09243990613945893, 0.10409591639680521, 0.1399313999073846, 0.08024239779583045, 0.17711145484021731, 0.11663371005228587, 0.1818985329674823, 0.18295949032264097, 0.1547400059976748, 0.11194007976778916, 0.14103619062474795, 0.07905753994626658, 0.1181680541485548, 0.12203509307333402, 0.0912190859339067, 0.1009381501270192, 0.12052404986960547, 0.06797176373324224, 0.11821111398083822, 0.18932330741414002, 0.398457584636552, 10.405771596091133, 41.53212751661028, 38.710877486637656, 34.27720069885254, 40.96975769315447, 32.773561886378694, 12.379464728491646, 1.068436113851411, 0.29824683762022425, 0.6678940153547696, 6.822001934051514, 10.82621317250388, 14.117242200034005, 11.707085813794817, 12.315604703766958, 10.950457385608129, 8.499013934816633, 6.930099402155195, 4.9027566228594095, 4.780788379056113, 6.447038488728659, 13.524183920451573, 25.17627821649824, 45.491919789995464, 49.99646472930908, 50.72501809256417, 51.489966120038716, 54.01981912340437, 50.13809680938721, 53.90489591870989, 51.77276822498867, 50.30277953829084, 49.023011684417725, 48.16932821273804, 40.47292675290789, 40.530704498291016, 41.97524888174874, 39.55294009617397, 41.535757950374055, 46.53819343021938, 49.68379579271589, 51.87898881094796, 47.31441143580845, 47.51408876691546, 52.16723830359322, 50.877722127096995, 50.989671502794536, 41.70065259933472, 39.3037360055106, 38.191384996686665, 37.381242411477224, 38.45806728090559, 40.07069901057652, 44.38272673743111, 47.86336776188442, 51.24273531777518, 49.402299949101035, 49.14104768208095, 45.83485855375017, 37.969636712755474, 49.1559932572501, 48.719861779894146, 46.57551220485142, 44.491420882088796, 41.88017668042864, 38.58901650565011, 36.17624412264143, 37.28829288482666, 37.525153500693186, 35.07474272591727, 36.29465184892927, 36.23406703131539, 36.857164110456196, 35.49937146050589, 36.94298825945173, 37.911567143031526, 45.136925901685444, 47.491962228502544, 48.771174226488384, 47.319542680467876, 46.207674571446006, 47.1960141318185, 47.5187475340707, 46.07131617409842, 41.18074321746826, 36.353360652923584, 38.26923608779907, 46.38663584845406, 43.43403359821865, 45.616709436689106, 45.60836465018136, 45.8302275793893, 44.06266491753714, 44.97828115735735, 44.110697814396445, 46.76882151194981, 46.13540635790144, 44.7426746913365, 29.499466487339564, 14.571571009499685, 3.811773496014731, 1.8025643208197184, 4.892128484589713, 8.382205162729536, 5.968446135520935, 10.228446619851248, 11.947767070361547, 10.419118217059545, 8.599867905889239, 4.8931841765131265, 2.928197354078293, 1.1729668762002672, 0.35664327123335426, 1.7701020113059451, 11.049839207104274, 28.6961452960968, 36.956318378448486, 32.10329348700387, 37.976515429360525, 18.821023259844097, 0.9368121538843427, 0.13838908980999673, 0.14927877618798188, 0.0882813957120691, 0.13931225027356828, 0.19576677094612802, 0.19382134319416114, 0.11013430809336049, 0.10880273740206446, 0.14528861029871873, 0.10172294372958796, 0.1970900363687958, 0.07735839326466833, 0.14498105751616613, 0.1077046709667359, 0.20506609337670462, 0.22526096472782747, 0.09059162424611193, 0.11164770581360374, 0.19824011251330376, 0.08589029258915357, 0.186834454536438, 0.10148508327880076, 0.10915085300803185, 0.11749676588390555], [0.01334648356506867, 0.007096893179030823, 0.009385061267364238, 0.010011695990605014, 0.007151396928488144, 0.02367350665320243, 0.043703812906252484, 0.0053788764385639554, 0.04705739759707025, 0.016179346911875263, 0.028254698596096466, 0.052400636952370405, 0.04933330582986985, 0.012129726936109364, 0.026097286326278533, 0.05920815148523875, 0.01585726160556078, 0.05584152874403766, 0.02595962174902005, 0.008108996436931193, 0.11090378037520818, 0.060160373603659015, 0.02386193413154355, 0.03954063755060945, 0.05917636890496526, 0.03177422411473734, 0.06431530815150056, 0.03303168860397168, 0.05749634334019252, 0.025999044633603523, 0.018349943117105534, 1.2524326635258538, 12.248353958129883, 32.7497365134103, 21.86738450186593, 36.10703659057617, 31.0370055607387, 18.911158766065324, 5.70062130689621, 0.47265973154987606, 0.06220237045947995, 1.2839687998805727, 1.5767993267093385, 4.038828032357352, 4.363736655030932, 4.971603282860347, 3.4522899857589175, 1.7379437940461295, 2.378541431256703, 1.0447986679417747, 1.24639250763825, 2.6042697301932742, 8.089466265269689, 16.670307397842407, 29.772874627794536, 46.07201794215611, 52.23914173671177, 50.38799571990967, 50.02864531108311, 47.91278682436262, 47.41568143027169, 44.84241260801043, 44.449408599308555, 40.501744406563894, 37.22747182846069, 37.98922368458339, 36.50484875270298, 34.862659386226106, 35.41137947354998, 38.445293017796104, 48.01846545083182, 46.0637252671378, 49.24242189952305, 46.46014084134783, 44.59907627105713, 49.30513286590576, 47.26015295301165, 46.045687743595664, 43.572347913469585, 37.546494892665315, 34.90135390417916, 34.15293911525181, 34.02735389981951, 36.655582972935264, 40.21131317956107, 43.35671751839774, 46.51913104738508, 47.045641217912944, 47.985277380262104, 47.229914392743794, 35.30592666353498, 42.66819272722517, 48.416736194065635, 43.81142153058733, 43.48049620219639, 38.95290061405727, 36.13402339390346, 32.81599453517369, 32.16200576509748, 33.43726423808506, 34.32799897875105, 32.317311900002615, 34.17050068719046, 33.206799439021516, 33.12368508747646, 32.90960414069039, 34.228000504629954, 36.204589298793245, 46.11420392990112, 43.2732766015189, 45.55278253555298, 44.76559679848807, 44.1995826448713, 44.81754500525338, 43.59721551622663, 42.06966100420271, 34.604467800685335, 33.35820416041783, 43.34908144814627, 43.00265121459961, 43.9782269341605, 41.73172494343349, 43.46790606634957, 42.18551179340908, 43.12074974605015, 44.057745592934744, 44.69742802211216, 42.57427740097046, 31.90203891481672, 15.494932753699166, 4.151460068566458, 1.1260107329913547, 2.121820475373949, 2.2690805963107517, 3.7995060171399797, 3.976813188620976, 3.966841220855713, 5.2430385691779, 7.108953416347504, 4.761292168072291, 0.8597838814769472, 0.1159211125757013, 0.1071864262755428, 0.585772550531796, 5.644558463777814, 15.66189101764134, 25.880257538386754, 24.512372629983084, 26.028149945395334, 23.71061478342329, 4.3698901534080505, 0.011807733232022395, 0.0671121548595173, 0.01421879037349884, 0.01504698392402913, 0.007791205409115979, 0.026548907360328094, 0.042960389583770714, 0.0920271532876151, 0.026670470301594053, 0.06259224989584514, 0.013907225752648498, 0.011279827050332512, 0.1004658422565886, 0.02726104173676244, 0.0028955402626057287, 0.033072946925780604, 0.04492452454620174, 0.013699574529060295, 0.009073164164354759, 0.040360267141035626, 0.06508946232497692, 0.02024499642928796, 0.0535079178932522, 0.02784388465806842, 0.016396781762263606, 0.024033299846840755, 0.05542741882215653, 0.05206040253064462, 0.029932873456605842, 0.02473561412521771, 0.0050498454781648305, 0.012304032404374863, 0.0265730530289667, 0.07793809287250042, 0.0670679279470018, 0.025513788618679558, 0.025551052065566182, 0.030877146537282636, 0.0024738332930220558, 0.0320768168063036, 0.024513904504211884, 0.015028755080753138, 0.029312868868666034, 0.031937846049134216, 0.03758700291759201, 0.012553578924520739, 0.05985878514392035, 0.04604761874569314, 0.01592678260723395, 0.0887344264026199, 0.024061740642147403, 0.025950302070538913, 0.03760355238669685, 0.00628420415367665, 0.05421059179518904, 0.012083640837642764, 2.1655446205820357, 18.46672245434352, 37.44152498245239, 23.91312003135681, 35.868605681828086, 39.675749506269185, 20.13263123376029, 5.406686450753893, 0.2113046936158623, 0.010358160211970764, 0.1128271014562675, 1.8775367949690138, 4.659973101956504, 7.879528181893485, 6.018379364694868, 6.073956702436719, 5.928947797843388, 2.0503044043268477, 2.4718257742268697, 2.405975307737078, 3.156151030744825, 9.371461016791207, 20.84482158933367, 33.06026193073818, 47.73351982661656, 53.46649932861328, 52.276394503457205, 49.35666765485491, 49.93846116747175, 48.86730602809361, 46.918746267046245, 46.60275609152657, 43.200966698782786, 40.55191387448992, 39.09543595995222, 38.17908321108137, 36.55904122761318, 37.92791625431606, 40.855352129255024, 49.21055398668562, 49.22788974217006, 49.68097482408796, 46.2302770614624, 45.33650943211147, 48.301451683044434, 48.248165948050364, 49.04734774998256, 44.68831545966012, 38.386417457035606, 36.0061800139291, 35.117995262145996, 35.377204758780344, 37.82088967732021, 41.354976245335166, 44.993779114314485, 47.16837419782366, 48.12509945460728, 47.463203634534565, 47.98611116409302, 38.00635099411011, 44.4142507144383, 49.76065329142979, 45.51491485323225, 44.63064888545445, 40.49072803769793, 37.76874344689505, 35.69645711353847, 34.794435024261475, 34.669016565595356, 34.38074970245361, 34.390956606183735, 34.44487115315029, 35.44679791586739, 33.96547671726772, 34.626309462956016, 35.564333643232075, 37.79542105538504, 46.96614340373448, 45.8077848979405, 45.73427990504673, 45.58414670399257, 44.46862384251186, 44.93275656018938, 43.84651688167027, 43.6150689125061, 34.85320636204311, 36.288669449942454, 44.95294107709612, 44.35786260877337, 43.69174575805664, 43.78219393321446, 43.97363417489188, 43.62040165492466, 45.25579915727888, 44.573486055646626, 45.383479254586355, 44.976808139256065, 35.352180821555, 19.08395004272461, 5.662381027426038, 2.0285003057547977, 3.850056767463684, 4.522716649941035, 4.785022871834891, 5.631893200533731, 4.746570672307696, 6.679576022284372, 5.461928972176143, 3.128230780363083, 1.0546392713274275, 0.1072763389508639, 0.06618153051074062, 0.48428200504609514, 5.03851009266717, 17.16043332644871, 29.69507564817156, 27.48086541039603, 28.622694151742117, 28.91945345061166, 7.013651924473899, 0.03339405344533069, 0.024220504265810763, 0.03990519406007869, 0.007970805995033255, 0.022970145734559213, 0.05694752386105912, 0.028493242670914957, 0.06920804775186948, 0.039729107437389236, 0.02115576175440635, 0.045812343513326984, 0.018286567946363772, 0.023365743524794067, 0.01671628693916968, 0.006751256770387824, 0.02140910128530647, 0.0662553890475205, 0.07545951301498072, 0.03535735720236387, 0.03524074078138385, 0.06789645313152246, 0.03258292589868818, 0.04264774100322809, 0.014918260741978884, 0.035503737561936886, 0.054646950880331654, 0.10723751996244703, 0.1738724679286991, 0.11516105835991246, 0.13464482501149178, 0.09495075033711535, 0.09792479646525212, 0.049428504292986224, 0.14170716676328862, 0.18242118135094643, 0.08354283283863749, 0.15756085248930113, 0.17255169951489993, 0.17286318780056067, 0.10379698100898947, 0.1407742082540478, 0.0947855067040239, 0.08759492861905269, 0.18026639840432576, 0.09141852094658784, 0.1259333581796714, 0.19804468085723265, 0.0975846807871546, 0.09586022474936076, 0.1850004286638328, 0.166991064324975, 0.08774009440094233, 0.11316377017647028, 0.09685888580445733, 0.10369908876184906, 0.07928292213806085, 2.4150885215827396, 21.679515634264263, 46.056818757738384, 31.332651410784038, 45.3959721156529, 39.99942091533116, 24.986679247447423, 7.3937283754348755, 0.7066379306571824, 0.25947138401014463, 3.4799188460622514, 6.157884861741747, 12.169877529144287, 13.145157081740242, 11.621702006884984, 10.311441114970616, 8.486943176814489, 8.246331402233668, 3.5150969241346632, 3.1295858962195258, 4.2449962837355475, 9.889558655875069, 20.090554680143082, 33.70957803726196, 48.40525082179478, 55.13925382069179, 53.7467896597726, 52.73187671388899, 52.609696115766255, 50.449845109667095, 49.60490942001343, 48.38942977360317, 43.817049571446006, 41.072639669690815, 41.17695992333548, 40.52050454275948, 37.530677318573, 39.42212636130196, 42.64432219096592, 52.5487882069179, 50.02195072174072, 52.02228845868792, 47.971471309661865, 44.257290908268516, 50.533768926348, 51.695306232997346, 51.019364629473, 47.0748028073992, 41.80201986857823, 37.45790883472988, 36.267376695360454, 36.22502395084926, 40.04297917229788, 43.04557718549456, 47.05739756992885, 49.41251032693045, 49.84415326799665, 49.76283849988665, 50.09746721812657, 41.45479754039219, 45.572588375636506, 52.35411357879639, 47.85811144965035, 46.87360382080078, 42.10100085394723, 39.3940486907959, 37.08242470877511, 35.25713293892996, 37.15763895852225, 36.06718519755772, 35.027064187186106, 38.07771594183785, 36.46693243299212, 36.60870000294277, 36.187687805720735, 37.757744448525564, 39.65994930267334, 50.44389050347464, 46.79225083759853, 48.46512344905308, 45.323839391980854, 45.0467209134783, 46.426504611968994, 44.907572814396445, 44.81224005562918, 37.07822799682617, 36.70042664664132, 45.671992778778076, 45.95737961360386, 45.615403175354004, 44.739867619105745, 45.689787115369526, 45.22016879490444, 46.434067726135254, 46.98508766719273, 47.01598630632673, 45.64178548540388, 36.66492830004011, 18.568576097488403, 5.890300180230822, 2.5537563264369965, 5.073859052998679, 6.056741671902793, 8.65897102015359, 10.85790651185172, 8.089903133256094, 11.45291462966374, 17.11474370956421, 10.521017892020089, 2.8671261625630513, 0.32618757975952967, 0.35827254237873213, 0.9898784777947834, 7.4405288355691095, 19.921993119376047, 34.27468545096261, 33.51845741271973, 35.458043575286865, 32.726494789123535, 7.464797156197684, 0.18790785622383865, 0.15909686578171595, 0.16840236288096222, 0.0773192010819912, 0.12649937852152757, 0.08733092421399695, 0.13376929770622933, 0.14227485630129064, 0.13979086173432215, 0.1680623489831175, 0.09584778041711875, 0.1074106346017548, 0.22004845871457032, 0.09744754885988575, 0.13808492970253738, 0.08726862112858466, 0.2536715923675469, 0.1244968588330916, 0.13112781516143254, 0.1210831491542714, 0.14523753018251487, 0.08798847214451858, 0.14636182199631417, 0.11008398115102734, 0.125831862911582], [0.042235476696597676, 0.029332115514469997, 0.04584694540660296, 0.0740817001621638, 0.00982427189592272, 0.04071884236431547, 0.024997833983174393, 0.043394733419907947, 0.017219843043546592, 0.03544957350407328, 0.004243555462120899, 0.07887510223580257, 0.02278944507374295, 0.030377961894763366, 0.06140678136476448, 0.06653636361339263, 0.04740886516602976, 0.0822137048734086, 0.031685254603092156, 0.03593137068673968, 0.008857173745387366, 0.03484260357384171, 0.023367660386221747, 0.09162585410688605, 0.047723294900996346, 0.01021783662560795, 0.013700037629210522, 0.051952087985617776, 0.027953686891123652, 0.08381212303148848, 0.051149906923196146, 0.3066564106515476, 6.612121607576098, 24.232078824724468, 32.86252314703805, 29.222921235220774, 32.614871978759766, 30.801687444959367, 17.93041011265346, 3.8458066412380765, 0.1982491234583514, 0.19075042940676212, 0.9512041530438832, 3.3583401356424605, 3.941122029508863, 4.246423270021166, 3.0969621496541158, 6.190395482948848, 1.0988916967596327, 2.4406066494328633, 1.5236735088484628, 2.6403413031782423, 6.604163748877389, 14.037895509174891, 23.047574247632706, 40.84816074371338, 50.006122725350515, 50.42543608801705, 49.41074201038906, 48.638182231358115, 43.778504439762656, 42.92061383383614, 41.36155618940081, 40.70612914221627, 39.640014920915874, 41.36037846973964, 41.29241813932146, 39.98333930969238, 36.9068854195731, 37.66645206723894, 43.06389263698033, 47.07272182192121, 48.256066049848286, 46.84632171903338, 44.079225948878694, 47.95126942225865, 49.52421651567732, 47.155971663338796, 45.81753322056362, 41.72264017377581, 34.28609439304897, 36.2499679837908, 36.60806424277169, 35.06828784942627, 36.6158184323992, 39.98543766566685, 43.8417260987418, 45.92663383483887, 47.345619269779746, 48.575669288635254, 35.129793303353445, 48.17123896735055, 48.56049789701189, 45.606638022831504, 46.61813245500837, 42.25230482646397, 41.45889697756086, 38.538148743765696, 34.86049849646432, 34.85982799530029, 34.045110021318706, 32.419495582580566, 35.29114089693342, 34.560589926583425, 35.324262959616526, 33.957607882363455, 33.440189429691856, 32.653177397591726, 38.50740991319929, 45.179765020098, 44.264186995370046, 44.71646956035069, 45.82012142453875, 43.50118098940168, 42.82973139626639, 42.08340106691633, 38.737006187438965, 32.708589281354634, 38.43605191367013, 43.93279961177281, 42.995581422533306, 42.3490445954459, 42.704795837402344, 41.0885579926627, 44.912641525268555, 42.76729835782732, 40.42468193599156, 34.87077488218035, 20.021534749439784, 5.983446862016406, 0.7456369208438056, 0.5513193649905068, 2.1006575652531216, 5.060982303959983, 2.9610321521759033, 2.685906938144139, 4.108910168920245, 4.392650714942387, 2.90157858814512, 1.5975962621825082, 0.9947461251701627, 0.17380029894411564, 0.4349602444895676, 4.341852435043879, 12.968907339232308, 24.4350391796657, 27.558082478387014, 24.158721481050762, 30.03543315614973, 11.659930995532445, 0.9997899745191846, 0.02505946871159332, 0.050754090305417776, 0.005453748961112329, 0.0422882768990738, 0.052999484818428755, 0.026037448019321476, 0.035315104826752625, 0.06821673523102488, 0.019415248185396194, 0.02546068816445768, 0.022137479790087258, 0.07107329302068267, 0.021576346596702933, 0.05957352902208056, 0.049527953777994425, 0.06550457647868566, 0.0571131542591112, 0.02071037476084062, 0.03748653223738074, 0.03881609785769667, 0.035609561883445294, 0.02954049701137202, 0.0756038034866963, 0.03920858965388366, 0.011705635764103915, 0.061704597169799466, 0.015854798523443084, 0.025759594714535133, 0.01667652478707688, 0.017071099685771123, 0.04977537817986948, 0.019443349713193517, 0.08559579482035977, 0.0422815017269126, 0.07243166584521532, 0.006688997789751738, 0.006811727387165385, 0.029984601573752503, 0.03638999250584415, 0.0678618885576725, 0.028125792209591185, 0.09581844734826259, 0.06273210274853877, 0.04275660176894494, 0.06015394109168223, 0.013895197871274181, 0.02983362413942814, 0.01582512618707759, 0.04326555731573275, 0.036967307063085694, 0.034102165805441995, 0.005147808971482196, 0.06731192235435758, 0.023843311737956743, 0.08557834968503032, 0.04242952074855566, 0.42556866843785557, 9.930175219263349, 29.58169494356428, 32.752442836761475, 33.093297140938894, 34.53659084865025, 36.394837924412315, 19.371275424957275, 3.065406905753272, 0.15906956153256552, 0.08202930619674069, 0.5211534351110458, 2.5403686676706587, 5.591143752847399, 6.008794324738639, 6.4162696940558295, 4.201437592506409, 4.0290562595639905, 3.6831449695995877, 2.196073051009859, 3.5657655767032077, 7.03024422270911, 15.906764643532888, 25.527537448065623, 40.73178536551339, 52.235775334494456, 51.762578691755024, 50.4894255229405, 48.54055656705584, 46.598573275974815, 44.36899709701538, 43.0238675389971, 42.51616961615426, 40.84543357576643, 41.788432666233604, 42.10366896220616, 39.51165737424578, 38.109378882816856, 39.13938679013933, 45.55257408959525, 48.6923816544669, 49.9496408190046, 48.565396377018516, 43.301996980394634, 49.09818771907261, 50.96919168744768, 48.74274219785418, 47.574319226401194, 43.013545989990234, 35.703346252441406, 36.801491669246126, 37.099958487919395, 36.94921037128994, 38.80597400665283, 42.84746319907052, 46.599104813167024, 50.349301201956614, 48.795385224478586, 48.18236303329468, 37.91745226723807, 49.78494071960449, 51.14151048660278, 47.01240798405239, 46.75485563278198, 45.23209885188511, 43.54022986548287, 39.9425881249564, 35.5768404006958, 36.43848998206002, 35.89609970365252, 33.74761595044817, 36.559364318847656, 35.816476821899414, 36.105014664786204, 35.30470725468227, 34.87915093558175, 33.93408475603376, 41.048018727983745, 46.482680797576904, 44.96983214787075, 45.64307090214321, 44.81163903645107, 43.92575413840157, 45.15477234976632, 43.47711590358189, 41.0009377343314, 34.18968118940081, 41.54130956104824, 45.026074341365266, 44.687627587999614, 43.4898658479963, 43.57621806008475, 42.842609882354736, 45.77897419248308, 44.934052399226594, 43.80177048274449, 38.6448209626334, 22.924264567238943, 8.251962048666817, 1.376555500285966, 1.794551093663488, 5.166148066520691, 5.869820364883967, 4.451969657625471, 3.2716809000287737, 5.5768434916223795, 6.068023809364863, 3.7580035584313527, 0.9902642113821847, 0.18906443273382528, 0.05869581683405808, 0.346605621278286, 4.089170336723328, 14.46327291216169, 27.001437970570155, 32.741638387952534, 28.204506397247314, 33.94155059541975, 16.916224990572246, 1.4935119215931212, 0.00833784933534584, 0.025225479089255844, 0.052644543150173764, 0.014207365540122347, 0.026945587413917695, 0.012927824914056276, 0.029299067466386726, 0.025833015596227984, 0.04760813054495624, 0.036424601184470315, 0.055949819540338855, 0.03087223394374762, 0.05106815702414938, 0.05056888417207769, 0.02226475769254778, 0.03103491271446858, 0.030025646157030548, 0.06459533955369677, 0.015286142073039497, 0.03616599113281284, 0.013329852671761597, 0.048645315425736566, 0.12345856454755579, 0.01331725058012775, 0.0893993703648448, 0.12160336838236876, 0.14089339971542358, 0.10527614663754191, 0.19028135814837047, 0.13114437141588756, 0.14947663699941977, 0.08411374541797809, 0.1483743025788239, 0.15708897209593228, 0.1747682291482176, 0.10269437517438616, 0.15706960670650005, 0.08021784839885575, 0.09410010491098676, 0.16096438414284162, 0.13289081198828562, 0.2615392601915768, 0.16980447407279695, 0.10819241550884076, 0.10900120210966893, 0.06841178012213536, 0.12935848081750528, 0.165986710361072, 0.16646999014275415, 0.12190233091158525, 0.16290427504905633, 0.18029697319226606, 0.1506861528115613, 0.1482139104711158, 0.21563713970993245, 0.13507872101451668, 0.667634055018425, 11.966304864202227, 37.73996748243059, 42.10802895682198, 39.83288301740374, 41.976669788360596, 38.2910395349775, 23.258893285478862, 4.634660814489637, 0.47595567469085964, 0.49066468541111263, 2.756143454994474, 9.164485471589224, 11.856630155018397, 12.304491060120718, 11.156037211418152, 12.885206733431135, 4.744170069694519, 5.990831060068948, 4.290236873286111, 4.590481562273843, 8.073871033532278, 17.045034170150757, 26.911719356264385, 42.7424898147583, 53.70914084570748, 53.67745358603341, 52.659122126443044, 52.8935786655971, 47.430060727255686, 45.34015028817313, 45.38060964856829, 44.863052231924875, 43.22388185773577, 44.699554170881, 44.94693088531494, 43.00307852881295, 40.941214493342805, 40.56044626235962, 46.24091822760445, 50.412071228027344, 52.18244791030884, 48.20127602985927, 44.93057482583182, 49.51670898709978, 51.61937631879534, 50.73471430369786, 48.29708474023001, 45.606332302093506, 38.07439122881208, 39.43909733636038, 40.15159341267177, 38.728567600250244, 40.625272955213276, 45.50458288192749, 48.32095527648926, 51.048529693058555, 50.537201336451936, 49.51046255656651, 40.047707421439036, 50.85795797620501, 50.120173931121826, 48.00915139062064, 50.16668517248971, 48.04943357195173, 45.18775544847761, 43.75389392035348, 37.53787565231323, 38.55531774248396, 36.6963723727635, 35.49894067219326, 38.83298512867519, 38.11735541479928, 37.920287132263184, 38.15265573774065, 36.543824672698975, 35.664422443934846, 40.73557560784476, 49.87989827564785, 46.608231272016255, 46.844786167144775, 46.89274958201817, 44.35011189324515, 45.892493861062185, 44.05992037909371, 41.647742067064556, 35.74738393511091, 41.766465936388286, 48.04081433159964, 45.49402162006923, 45.504562037331716, 45.44377224785941, 44.65349803652082, 47.08807734080723, 44.55498647689819, 44.92656224114554, 40.44620745522635, 23.267945051193237, 7.553102680615016, 1.283037741269384, 2.587391035897391, 6.026586490018027, 10.892564126423427, 7.773329309054783, 6.943168529442378, 9.785469429833547, 11.894464833395821, 10.000802789415632, 4.662509194442204, 1.8145888298749924, 0.42562080706868854, 0.774674148431846, 6.15589941399438, 17.035219839641027, 32.65678698675973, 35.668014662606375, 32.93938064575195, 39.36028739384243, 17.817837136132376, 1.4296948888472147, 0.18954912386834621, 0.16201140438871725, 0.11752188525029592, 0.10559722262301616, 0.1396336315998009, 0.1083576116444809, 0.14990918950310775, 0.146542543013181, 0.16477210553629057, 0.14732967077621392, 0.13362384693963186, 0.18159642203577928, 0.14968473011893885, 0.06657584078077759, 0.11648736361946378, 0.11808844842016697, 0.13151567934879235, 0.10571582375892571, 0.11886679594005857, 0.08853685736124005, 0.11634335134710584, 0.1260497947888715, 0.3313533754221031, 0.0862671984359622, 0.12272118697209017], [0.0558603852322059, 0.033246031031012535, 0.030978210935635225, 0.067128371846463, 0.024667770801378146, 0.06031406857073307, 0.02142905191119228, 0.025589759095704982, 0.033617098083985705, 0.017323993079896485, 0.004955207654607615, 0.03518126718699932, 0.013705489658085363, 0.05337822949513793, 0.03942636886079397, 0.03994769749364682, 0.019892212502392273, 0.028421270461486917, 0.057637899315782955, 0.005264868560646261, 0.021777203140248145, 0.012827641763059157, 0.027675655470894914, 0.08988489609743867, 0.009524847962893546, 0.051020954735577106, 0.07484206650406122, 0.04408060000943286, 0.05204510495864919, 0.02385473996400833, 0.023189678954492723, 0.06328651335622583, 1.5002397320100238, 16.975098814283097, 35.229350566864014, 28.028899363109044, 24.529433931623185, 35.66556542260306, 34.44994681222098, 14.257792966706411, 3.0265128442219327, 0.2117545080504247, 0.37243107120905605, 1.5669822820595332, 5.001680297510965, 4.919525231633868, 4.904833699975695, 3.430373413222177, 1.4283124144588197, 3.2121917264802113, 1.606407555086272, 1.946891541991915, 2.7915692797728946, 9.487010427883693, 16.495692219052994, 31.296357495444163, 44.74168804713658, 51.15307228905814, 50.97763722283499, 50.52369751249041, 47.392543928963796, 42.32003239222935, 42.31867749350411, 42.782223088400706, 45.258196285792756, 46.05581474304199, 46.19389976773943, 46.33605643681118, 42.57573652267456, 35.48573909487043, 43.12967470714024, 47.25372239521572, 49.11407824925014, 49.582438945770264, 45.844394956316265, 41.84314973013741, 49.81806625638689, 50.50104291098458, 47.02580411093575, 45.95008747918265, 37.12038966587612, 33.86018371582031, 36.18736818858555, 37.8106723512922, 35.7222557749067, 37.878851549965994, 44.70783294950213, 46.310629504067556, 48.16702488490513, 48.403343541281565, 39.640598569597515, 35.08654076712472, 44.88622447422573, 50.51474823270525, 44.47807339259556, 44.448543548583984, 43.19217375346592, 43.41532209941319, 40.196246010916575, 33.97298077174595, 33.15735953194754, 33.684727805001394, 33.502987248556956, 36.06702538899013, 35.18635858808245, 34.81165613446917, 33.098348481314524, 32.638391630990164, 34.35671935762678, 37.95584453855242, 43.51572009495327, 43.53268412181309, 45.25630637577602, 46.206809520721436, 45.470859800066265, 43.27680628640311, 40.96054090772356, 36.427529198782786, 36.49503442219326, 40.42629739216396, 42.370604855673655, 41.79837553841727, 42.44645486559187, 41.815575804029194, 39.65062134606497, 38.66890341894967, 37.46872023173741, 24.68192604609898, 7.712219033922468, 2.9973230276788985, 1.005525603890419, 1.1675990670919418, 4.960019767284393, 2.8117370775767734, 4.123740664550236, 2.754960524184363, 5.062618604728153, 5.114749201706477, 2.3000365580831255, 0.8397629729339054, 0.16491600924304553, 0.1627194828220776, 3.1554542567048753, 10.777477639062063, 22.47817632130214, 24.43372597013201, 21.93982642037528, 22.956023045948573, 17.540852410452707, 4.44695349250521, 0.08697442870054926, 0.007814978731663098, 0.031685312278568745, 0.0020771585404872894, 0.01753411501912134, 0.01813309859218342, 0.020412913490352885, 0.03567834497828569, 0.06366766683225121, 0.02390555036254227, 0.057190324046782086, 0.025766159540840557, 0.06921171862632036, 0.010017238773538597, 0.008537140159335519, 0.047923126856663396, 0.021167717541434934, 0.043527363267328055, 0.04119570320472121, 0.021818500477820635, 0.004332166198374969, 0.052363103787813864, 0.04041471279093197, 0.03349683792995555, 0.04935731579150472, 0.036191371735185385, 0.044284777981894355, 0.0414445661008358, 0.036400486049907546, 0.008752954159198063, 0.0254674056611423, 0.0566685543661671, 0.0044919336297815395, 0.022317071046148027, 0.019309469665001546, 0.03367696862135615, 0.015910689452929155, 0.025561221609158174, 0.07812951438661132, 0.01742532380324389, 0.031617736976061545, 0.07869346519666058, 0.05847095711422818, 0.02968184942645686, 0.03803924311484609, 0.05214371306023427, 0.029638630138444047, 0.03704134201897042, 0.11818443398390498, 0.0746272558878575, 0.027336718747392297, 0.029219210680041994, 0.044881305258188925, 0.037828490138053894, 0.04413932042994669, 0.053336614942444224, 0.04287115205079317, 0.037115560179310184, 2.9398540428706577, 21.772581543241227, 39.97931282860892, 30.599734578813823, 28.739793879645212, 39.068393571036204, 34.62089681625366, 13.19273487159184, 2.503580344574792, 0.1575680449604988, 0.07183337437787227, 0.6157302515847343, 2.7730473365102495, 5.577662510531289, 4.907934767859323, 5.323016243321555, 5.366463763373239, 3.168755714382444, 2.670034646987915, 3.104989056076322, 3.6362224817276, 11.38169298853193, 19.449864762169973, 34.88854142597744, 46.42335360390799, 51.45671551568167, 51.791611739567344, 50.60934100832258, 47.24077442714146, 45.58923625946045, 43.00889417103359, 44.125851835523335, 45.32200506755284, 47.06452294758388, 47.14103651046753, 47.8427038192749, 43.95570434842791, 37.90170070103237, 45.93658365522112, 49.524369376046316, 50.614145687648225, 50.71587426321847, 45.59307861328125, 43.684460571834016, 49.77562665939331, 50.711767877851216, 48.08447333744594, 46.17879090990339, 38.67009156090872, 35.109358651297434, 37.75644860948835, 39.62291193008423, 37.53319604056222, 40.20864159720284, 45.23230034964425, 47.63921887534005, 49.36588444028582, 49.665053027016775, 40.422048568725586, 38.011923449380056, 48.36297450746809, 50.08861868722098, 45.07711928231375, 46.25144822256905, 45.80368198667254, 43.04123803547451, 41.50971957615444, 36.066101278577534, 35.75267498833792, 35.20696694510323, 35.589458329336985, 37.37811919621059, 37.8378050667899, 36.523073877607075, 33.83983244214739, 34.413698060171946, 36.12451825823103, 40.17254570552281, 44.4762738091605, 46.34515510286604, 46.672637598855154, 45.45973226002285, 45.539521898542134, 44.711185455322266, 42.5713973726545, 38.421095916203086, 37.915100302015034, 42.92893777574812, 44.36674240657261, 44.539095946720664, 43.6462003162929, 42.944592067173545, 41.97866044725691, 39.813817160470144, 39.37130376270839, 27.953957830156597, 11.447759066309247, 5.195885487965175, 2.281609284026282, 2.307441383600235, 6.303519104208265, 4.278106187071119, 3.4639586167676106, 4.115785845688411, 6.061011339936938, 4.831162818840571, 2.0651861429214478, 0.29911517245428904, 0.10522860168878521, 0.32142651666487965, 2.512071043252945, 11.910972884723119, 22.211780650275095, 29.54420246396746, 26.93005738939558, 27.259488855089458, 24.147960458483013, 6.682705317224775, 0.19126067417008535, 0.037598107143172195, 0.04770621956725206, 0.048898273280688694, 0.037096181219177585, 0.01689513011037239, 0.0436747885708298, 0.04313772810356958, 0.02372940776071378, 0.06103870325854846, 0.04077117098495364, 0.015301448126722659, 0.05790247369025435, 0.0334586092670049, 0.03315012689147677, 0.056762684136629105, 0.06235147174447775, 0.029463920941842452, 0.021816632810181806, 0.04856857650780252, 0.0457302543467709, 0.033510836107390266, 0.03525933264089482, 0.030038002279720137, 0.028700701360191618, 0.03809639611946685, 0.16024946607649326, 0.09028442430176906, 0.08709908236882516, 0.20138592299606117, 0.11171040923467704, 0.12125542919550623, 0.08808807429990598, 0.08748802542686462, 0.08885452031557049, 0.13396786419408663, 0.17051880859902926, 0.09499739283429724, 0.1558233414377485, 0.2140140025211232, 0.12930980271526746, 0.18354738663349832, 0.16171021626463958, 0.15840013245386736, 0.24131715244480542, 0.09893307236156293, 0.14699078324650014, 0.10302858081247125, 0.3529610245355538, 0.18465993979147502, 0.12769395299255848, 0.14246120915881225, 0.1390697147165026, 0.12377800526363508, 0.16590555757284164, 0.18317329670701707, 0.17721024953893252, 0.10641096252948046, 2.9725249069077626, 24.676713160106114, 47.084787368774414, 38.07292863300869, 35.54292624337332, 42.236667905535015, 40.57568366186959, 18.904340846197947, 4.041388009275709, 0.3455523992223399, 0.9958249415670122, 4.172342879431588, 12.137742110661097, 14.295230729239327, 12.638449277196612, 8.22360384464264, 6.965442717075348, 6.668432414531708, 4.634689910071237, 4.061692816870553, 3.830620050430298, 11.23113421031407, 20.133741208485194, 35.848323890141074, 46.92859533854893, 54.70042644228254, 54.555799688611714, 54.77903836114066, 49.678713185446604, 46.983010155814036, 45.821431159973145, 45.557934624808176, 48.22368049621582, 49.09990392412458, 48.95328303745815, 50.7874094418117, 47.699397223336355, 40.386459895542686, 47.25786352157593, 51.06472594397408, 52.62534345899309, 51.53200619561331, 46.14094407217843, 43.79285594395229, 50.270334924970356, 53.19288274220058, 50.09862756729126, 48.305106435503276, 40.87164912905012, 38.08261442184448, 38.33819695881435, 42.76489775521414, 39.546391419001985, 41.79583249773298, 47.34188461303711, 49.55888455254691, 50.828028610774446, 50.71729864392962, 43.2938015801566, 40.22152703148978, 49.43693324497768, 53.93848698479788, 46.64667912891933, 49.035831110818044, 47.76847621372768, 45.88438183920724, 44.71660157612392, 36.83220618111746, 37.40653732844761, 37.29420232772827, 37.97727973120553, 40.50695555550711, 40.29319422585623, 38.96902738298689, 34.90095090866089, 36.24447890690395, 38.27716050829206, 40.3530911718096, 47.20999043328421, 46.642471994672505, 47.968427998679026, 46.762703623090474, 46.119060720716206, 47.053103583199636, 43.77124009813581, 40.33309078216553, 38.70925855636597, 43.640297821589876, 46.17511878694807, 44.58743803841727, 45.63033485412598, 44.26466294697353, 41.32330288205828, 42.59895740236555, 39.26278332301548, 28.096625191824778, 9.498966540609088, 5.893914546285357, 2.7349338616643633, 3.937749547617776, 10.150836110115051, 6.047309058053153, 7.554870128631592, 8.84247989313943, 11.111574820109777, 12.59416319642748, 5.69520822593144, 1.4411591993910926, 0.746399214225156, 0.47974103157009396, 4.41848281451634, 14.4332332440785, 28.277009112494333, 32.767096587589805, 29.768493788582937, 33.31032759802682, 26.771798270089285, 6.608519835131509, 0.21558192053011485, 0.13556820260626928, 0.18658350514514105, 0.11000609211623669, 0.14385384800178663, 0.0744910603389144, 0.1700849804495062, 0.08405371542487826, 0.12573770939239434, 0.19980528924082006, 0.15299748735768454, 0.06139619621847357, 0.13004328549972602, 0.08561500414673771, 0.11208649405411311, 0.11699231580964156, 0.17615731246769428, 0.10427380113729409, 0.13047279816653046, 0.18999311647244863, 0.13962407782673836, 0.134113966354302, 0.13871602155268192, 0.08182890087898288, 0.06919193933052675, 0.136303110314267], [0.010788443864190152, 0.02576317568309605, 0.05722717528364488, 0.006847122742328793, 0.018159371468105485, 0.08721275055514914, 0.043639216372477155, 0.03605255704107029, 0.026167129632085562, 0.04768674561221685, 0.0845205814444593, 0.04904382922021406, 0.009220647991501858, 0.05256276271705117, 0.00698456001035603, 0.035661276429891586, 0.026599044312856028, 0.04765091896323221, 0.012789090795974647, 0.04381225298025778, 0.05117790327806558, 0.023836066680295125, 0.052996994594910314, 0.04086660693532654, 0.033088342885353735, 0.004132036535468484, 0.028019150253385305, 0.08539060583072049, 0.03888996657250183, 0.04320370884878295, 0.006781617395712861, 0.09225790947675705, 0.16314690560102463, 3.895580061844417, 19.983262334551128, 29.737268584115164, 23.87107821873256, 33.35173886162894, 42.4032301221575, 32.372803688049316, 13.19230147770473, 2.6812423084463393, 0.2088540829718113, 0.43992546520062853, 1.653747586267335, 3.9443711808749606, 3.995689272880554, 4.206433347293308, 6.4553967373711725, 2.1020928025245667, 1.4730739040034158, 0.9597389293568475, 2.2780398641313826, 4.058881402015686, 12.182881951332092, 20.474981137684413, 34.267782415662495, 46.64125605991909, 51.133700711386545, 50.35248000281197, 47.622428553445, 48.10262203216553, 46.38375929423741, 49.25462988444737, 46.10558121544974, 47.801452364240376, 52.29176391874041, 49.597325461251394, 47.00274998801095, 40.982650075639995, 40.174953256334575, 48.22496591295515, 49.1433926991054, 48.912795884268625, 46.3445645059858, 48.07145936148507, 44.25492852074759, 48.73041609355381, 48.02709858758109, 46.7198679787772, 37.854001317705425, 35.06126322065081, 33.80992044721331, 37.39358936037336, 37.343777724674766, 39.72920547212873, 44.722069808415, 46.14356354304722, 46.22092131205967, 48.10023880004883, 38.97479786191668, 43.40906524658203, 39.49629838126046, 49.556338037763325, 47.76550585883004, 46.004081930433, 45.948239258357454, 45.68245676585606, 43.318429470062256, 38.20405503681728, 32.4901830809457, 32.2540659223284, 35.17189938681466, 35.89749281747, 36.48652287891933, 36.35923882893154, 34.009900024959016, 33.66762481416975, 32.734485217503135, 35.16623313086373, 39.75306211199079, 43.16316155024937, 45.49003335407802, 45.715589250837056, 46.099775995527, 46.35941628047398, 42.87112181527274, 41.830292088644846, 37.816227436065674, 41.36552708489554, 42.07266610009329, 46.278935296194895, 43.51756484167916, 41.172009331839426, 38.02992275782994, 39.31569732938494, 29.919655323028564, 11.814057673726763, 3.0606723598071506, 2.8930818097931996, 1.337264631475721, 1.1690719766276223, 6.393615526812417, 3.669248572417668, 1.9557984811919076, 1.7560415714979172, 3.900397769042424, 3.7509789296558926, 1.9869196798120226, 0.08800682651677302, 0.05075756101203816, 2.1331286685807362, 9.30955169882093, 21.991210086005076, 24.152796404702322, 19.72842846597944, 22.553604228155955, 20.583034311022075, 7.441099456378391, 0.5855170413851738, 0.03702860591667039, 0.05758203552769763, 0.05920517950185707, 0.04845483707530158, 0.0029872945243758814, 0.05915885591613395, 0.02924031651179705, 0.05603208851867488, 0.02468583170723702, 0.04214368447927492, 0.03597171977162361, 0.02044926430763943, 0.020996287365310957, 0.03522941263924752, 0.04455928950171385, 0.047090805268713405, 0.04432948326159801, 0.035311030223965645, 0.06160273549279996, 0.05697948964578765, 0.0390640854436372, 0.005262039493702884, 0.07042558384793145, 0.024999418362442936, 0.023844075089852725, 0.028991283981927803, 0.03569368326238223, 0.02747525693848729, 0.0629030732171876, 0.03527936977999551, 0.012223058579755681, 0.013120143790729344, 0.01917302984345172, 0.008617488883568772, 0.012614712385194642, 0.04388628115079232, 0.03993282739871314, 0.0239751426103924, 0.04603051287787301, 0.014264867142108935, 0.01361078058835119, 0.04401469051039644, 0.025180984155407975, 0.07567875446485621, 0.0932120450639299, 0.03868817025795579, 0.008946170398433293, 0.038153067364224365, 0.02427417129677321, 0.05001676022740347, 0.04594039664204631, 0.08275174243109566, 0.027905690716579556, 0.03741380685408201, 0.03850014481161322, 0.0022287574704802993, 0.030806029281978096, 0.029973799296255623, 0.34830594861081665, 6.5901075431278775, 28.53964580808367, 33.65816831588745, 24.97815728187561, 35.32949147905622, 47.3102251461574, 36.01665094920567, 12.148311189242772, 2.1805664088044847, 0.07865887348140989, 0.21050638359572205, 0.6008193088429314, 3.57328331044742, 3.4254571284566606, 4.105070420673915, 7.14634644985199, 4.9739739213671, 2.9583575299807956, 3.014032142502921, 2.571793415716716, 5.288546664374215, 13.216128587722778, 24.784328596932546, 36.797875131879536, 47.99545301709856, 52.48677553449358, 51.558968680245535, 48.83871071679251, 49.17843246459961, 46.097695010049, 51.16790669304984, 49.488447189331055, 49.43411227634975, 52.69172307423183, 50.560550757816856, 47.28776856831142, 42.08762904575893, 42.08981078011649, 49.42019156047276, 51.864821434020996, 49.75668934413365, 45.722078868321006, 46.634523255484446, 45.79061589922224, 51.54569067273821, 49.04867833001273, 47.8726818220956, 39.75475399834769, 37.120813505990164, 36.858602387564524, 38.90105315617153, 38.484105655125205, 41.038697719573975, 46.53578240530831, 46.87431253705706, 47.36322947910854, 48.29546580995832, 40.15732567650931, 43.05325494493757, 41.68727036884853, 49.38400534221104, 49.91861711229597, 47.178452559879844, 48.14936603818621, 46.820328508104595, 45.99773127692086, 39.35664653778076, 34.258801868983674, 34.07455996104649, 36.000190666743684, 37.65936490467617, 38.86240380150931, 37.92997292109898, 35.90682077407837, 35.353785855429514, 34.14906549453735, 37.45744677952358, 42.19359254837036, 44.984253134046284, 46.50701338904244, 47.17004871368408, 46.3212810925075, 47.398460320064, 43.9102909224374, 42.02861104692732, 38.857890946524485, 42.84621947152274, 44.014357566833496, 45.25987427575247, 44.109523568834575, 42.82241146905081, 40.20287806647164, 41.20325885500227, 32.467754295894075, 15.141523054667882, 5.430756747722626, 4.776165655681065, 3.5888527035713196, 2.9384746083191464, 5.233383612973349, 3.4670607703072682, 3.361384315150125, 3.7612131919179643, 5.433974197932652, 2.0059431961604526, 0.4778079667261669, 0.09913963199193988, 0.12187140328543526, 1.9992768338748386, 10.224242959703718, 23.295763901301793, 29.89969662257603, 23.158168724605016, 24.364450693130493, 24.221858024597168, 11.734128202710833, 1.2753954827785492, 0.014627628926453846, 0.007519294374755451, 0.03018227239538516, 0.053796017076820135, 0.02670671255327761, 0.01636806276759931, 0.08380675581949097, 0.06154560962957995, 0.028529347519257238, 0.011688826755354447, 0.01216037297022662, 0.033968423160591295, 0.04265231093657868, 0.0019128892412741802, 0.04833879740908742, 0.05534066812002233, 0.02425763539836875, 0.006364136002957821, 0.008243164862506092, 0.004511451265508575, 0.019785411090457013, 0.07554573445980038, 0.05363783360059772, 0.048059203661978245, 0.04186049449656691, 0.02416833340456443, 0.07670402766338416, 0.1185711853738342, 0.21107111472104276, 0.12946245952376298, 0.08491036588592188, 0.13401572805430206, 0.13291555137506553, 0.08570708813411848, 0.06910480186343193, 0.1209252540554319, 0.2375231646001339, 0.08078610112092324, 0.10043161016489778, 0.14015523503933633, 0.08631274170641388, 0.12454354204237461, 0.09885071856634957, 0.10016462699111019, 0.2005310502967664, 0.1723107381590775, 0.16542632185987063, 0.18943715201956884, 0.111789146438241, 0.18715150680925163, 0.12183708298419203, 0.18258740885981492, 0.09145758420761142, 0.12459083593317441, 0.17036564967461995, 0.14452476985752583, 0.11051013506948948, 0.18630913272500038, 0.3586038845990385, 8.110429848943438, 32.80641296931675, 41.03866645268032, 31.806945868900844, 41.86227812085833, 50.18262781415667, 39.90099273409162, 16.07191637584141, 3.931982542787279, 0.3752045966684818, 0.7825757158654076, 4.986584467547281, 8.905558245522634, 12.059136271476746, 12.449421797479902, 9.63557767868042, 6.69282363142286, 3.787727083478655, 3.578408909695489, 4.006391670022692, 4.753320412976401, 13.921840616634913, 26.287163155419485, 37.107667514256065, 49.60825845173427, 55.07902683530535, 52.94782672609602, 51.77636044366019, 52.1901604107448, 48.834013734545024, 54.11232743944441, 51.872485297066824, 51.22579560961042, 54.88966063090733, 52.649905341012136, 51.36844907488142, 45.122261728559224, 44.616488456726074, 51.68590184620449, 53.9190285546439, 50.977605955941335, 46.7812831061227, 48.189436299460276, 46.15245028904506, 50.31650570460728, 51.514069420950754, 50.2525440624782, 41.66583170209612, 38.4389944757734, 37.618912492479595, 38.660659381321494, 40.949910163879395, 43.555165018354145, 48.72998530524117, 49.68486928939819, 50.267906529562815, 48.880097661699565, 43.21516881670271, 44.58514860698155, 42.03867203848702, 51.967626980372835, 51.091167313711985, 48.26079429898943, 49.48605700901577, 49.10328769683838, 46.11017050061907, 40.72215863636562, 35.641990184783936, 35.770274775368826, 37.523975781032014, 40.06701299122402, 40.25197751181466, 39.45823267527989, 38.26158612115042, 37.084988594055176, 36.36513784953526, 38.85461139678955, 43.565983363560264, 46.17745338167463, 49.05908325740269, 48.675692081451416, 46.61209447043282, 49.708340304238455, 46.1615697996957, 44.01363842827933, 41.49930770056588, 43.53874295098441, 45.71114935193743, 46.136260986328125, 46.46953133174351, 43.1215626852853, 42.151670592171804, 42.148644651685444, 32.151357650756836, 14.14458075591496, 4.931156516075134, 5.382325197969164, 4.209205678531101, 4.321269699505397, 12.903932128633771, 8.297723753111702, 6.371302255562373, 5.808096476963588, 10.059007849012103, 9.03725961276463, 4.5948511106627326, 0.5584620588592121, 0.41600029330168453, 2.8092656901904514, 12.917874557631356, 27.368110043661936, 32.05027525765555, 27.557283435549053, 30.499871594565256, 29.7391619682312, 13.841957177434649, 1.1276104471513202, 0.10340360711727824, 0.1254010610282421, 0.16063739811735495, 0.13388042817158358, 0.0882006229034492, 0.15778851455875806, 0.22373094968497753, 0.20249445922672749, 0.12520579222057546, 0.14244575213108743, 0.16661823647362844, 0.0887557595436062, 0.15275613245155129, 0.11238138537321772, 0.1134689413011074, 0.12831782523010457, 0.12568202880876406, 0.14941951792154992, 0.11900125443935394, 0.10342136437871627, 0.13800574466586113, 0.18637717621667044, 0.10250718771879162, 0.08132782990911178, 0.12354594628725733, 0.11187622962253434], [0.01706738131386893, 0.030874317046254873, 0.028507787069039683, 0.06928221162940774, 0.02452239128095763, 0.052597547814782174, 0.07920358103833028, 0.01964166683943144, 0.05169600886957986, 0.025517625734210014, 0.02117956815553563, 0.026906854938715696, 0.027389868395403028, 0.020954450592398643, 0.023360493360087276, 0.04921554607738342, 0.07500777832631554, 0.0506554279210312, 0.017823554309351102, 0.11713058767574173, 0.02289184957875737, 0.05576054558956197, 0.04189201244818313, 0.06800916458347014, 0.044706765695341995, 0.09892047196626663, 0.02034873764828912, 0.02480429713614285, 0.05646670037614448, 0.01753323631627219, 0.062247995154133866, 0.05272867809981108, 0.018600877241364548, 0.716052305485521, 5.371497298989977, 24.259651013783046, 30.84666313443865, 20.14397243091038, 24.960851056235178, 33.63998488017491, 29.49524893079485, 12.414436749049596, 2.091563241822379, 0.10705257167241403, 0.39025474765471047, 2.1702670071806227, 1.6071783708674567, 2.374445468187332, 5.978864090783255, 1.9706341879708427, 2.855553503547396, 2.0654823098863875, 0.5238865198833602, 2.2026165170328955, 4.624921611377171, 13.287104436329432, 22.401174647467478, 36.77342094693865, 46.75446653366089, 51.156758308410645, 49.41736364364624, 48.01588766915457, 48.680844170706614, 50.90513277053833, 50.616605349949424, 50.276702948978965, 50.68313782555716, 51.923002174922395, 46.354448318481445, 44.084655966077534, 41.90647561209542, 48.91756582260132, 47.85650641577584, 48.280158928462434, 44.381382261003765, 47.32092537198748, 46.203206879752024, 47.32162019184658, 48.656883307865684, 48.626425879342214, 37.73894609723772, 35.12085097176688, 34.021923882620676, 36.43647500446865, 37.51912593841553, 43.683199473789756, 45.067826066698345, 48.3521283694676, 46.629385062626426, 49.68498740877424, 37.75005626678467, 49.89379814692906, 49.08891534805298, 41.89232907976423, 51.323125975472585, 45.62522792816162, 47.64758103234427, 45.621156283787315, 44.89257860183716, 40.95466273171561, 36.07448775427682, 33.20323153904506, 34.08683395385742, 33.241127014160156, 34.979041712624685, 34.56885480880737, 36.592882428850444, 34.90906640461513, 36.53464262826102, 36.164303643362864, 37.78237928662981, 42.89665991919381, 45.38931226730347, 45.48977279663086, 48.222492354256765, 43.68178898947579, 41.052305766514365, 40.932348591940745, 42.69584308351789, 42.31842041015625, 42.87660394396101, 43.31076560701643, 42.993625504629954, 42.743007455553325, 37.98630544117519, 28.91980607169015, 13.868066770689827, 5.599882849625178, 3.2546065705163136, 1.5773691875594003, 2.506760231086186, 2.806839248963765, 2.2275857371943335, 2.580115620579038, 1.8820644148758479, 3.3712381635393416, 4.172761508396693, 1.8366737876619612, 0.23051036947539874, 0.18617099656590394, 1.263881340622902, 8.613596677780151, 19.072014774594987, 20.03702575819833, 21.745681592396327, 20.261105162756785, 24.466399874005997, 15.013775212424141, 2.580874277012689, 0.04371330561116338, 0.07766224124601909, 0.01583226607181132, 0.04515423918409007, 0.036594726877020936, 0.022955516519557153, 0.05150869588500687, 0.03622301182310496, 0.03698720510250755, 0.03296160611457058, 0.0407037687088762, 0.03585665041048612, 0.04336976333122168, 0.011884378851391375, 0.028002259820433598, 0.04351474590865629, 0.06651099997439555, 0.021455360410202826, 0.01875926088541746, 0.03438963395144258, 0.02462984747918589, 0.07042754481413535, 0.035574786963739564, 0.07242773712745734, 0.011752661633571344, 0.004895478761422315, 0.04360317937763674, 0.01210767709250961, 0.06919031763183218, 0.06135055116776909, 0.038334209072802744, 0.021547992314611162, 0.05546836841053196, 0.04893236288002559, 0.04578047611617616, 0.033130863282297335, 0.07970627370689597, 0.04950210498645902, 0.048160899097898176, 0.061754659483475347, 0.028299800818786025, 0.011222131217696836, 0.05053183276738439, 0.06979320278125149, 0.04675379049565111, 0.01948187523521483, 0.02299102595342057, 0.060815811290272644, 0.020829841028898954, 0.004864493035711348, 0.03521502430417708, 0.042444760645074506, 0.015094496642372437, 0.021120401598247032, 0.04799037646236164, 0.032548588634069474, 0.008116964982556445, 0.04267939466184803, 0.022688088905332342, 0.05551070221034544, 1.4126491120883395, 8.441937957491193, 30.718642575400217, 31.16677359172276, 23.209248406546457, 32.62144150052752, 42.873821190425325, 33.64826365879604, 11.722624591418676, 1.7895926854440143, 0.07816136482038669, 0.09003467591745512, 1.0158865622111728, 2.1966682076454163, 4.279227452618735, 6.581141761371067, 4.312323893819537, 3.3763424839292253, 1.676038058740752, 1.4539629923445838, 3.385497821228845, 6.5631915245737344, 17.15314814022609, 25.752341202327184, 39.44099072047642, 49.381806237357004, 52.45088808877127, 50.56017555509295, 48.777754170554026, 49.8078419821603, 52.974750995635986, 52.28330796105521, 51.86894518988473, 52.91610819952828, 51.95580462047032, 49.263877936771934, 45.737146036965505, 43.11813027518136, 51.317070620400564, 49.124507495335166, 48.23421743937901, 45.56228767122541, 47.88507740838187, 46.68568631580898, 48.67729016712734, 49.4268479347229, 50.73457186562674, 38.64033242634365, 36.025172914777485, 36.19444840294974, 37.85866008486067, 38.64857298987252, 45.66378000804356, 46.88885511670794, 49.98378079278128, 48.62370218549456, 50.6254677772522, 39.9096918787275, 50.33617605481829, 49.473459924970356, 43.9055209841047, 51.22722346442086, 47.0432962008885, 47.59797784260341, 47.80897378921509, 48.458043234688894, 43.94902712958199, 36.73918717248099, 35.357885292598176, 35.02956206457955, 34.898529461451936, 37.05823108128139, 36.33018493652344, 37.806409631456646, 36.59743697302682, 38.00924491882324, 37.519483770642964, 39.28317281178066, 44.707787786211284, 46.38813318525042, 47.336531026022776, 46.89277390071324, 44.46589320046561, 42.59511852264404, 42.22104140690395, 43.933484009334016, 43.69372599465506, 44.818802629198345, 45.805568422589985, 43.722870213644846, 42.978405475616455, 40.453628131321494, 33.28304549625942, 15.698872804641724, 8.651714495250157, 3.780092316014426, 2.6166659678731645, 3.0222268913473402, 3.8860666751861572, 3.7981094292231967, 2.7682024879114966, 2.69547786457198, 4.379667571612766, 4.843270489147731, 0.778508468398026, 0.19966361112892628, 0.2176274729094335, 1.3172930117164339, 8.376668316977364, 20.706244979585918, 25.613368545259746, 25.502009766442434, 22.645686967032297, 27.33965195928301, 19.87863983426775, 4.0103773304394315, 0.0766837801784277, 0.117818540760449, 0.0373721889087132, 0.04291874788967626, 0.024063908561531986, 0.06443621630647353, 0.09005936780678374, 0.031254551107329984, 0.02749050870936896, 0.040846664791128466, 0.04594689022217478, 0.010232521819749048, 0.03909356779019747, 0.035965249940220795, 0.041648971382528543, 0.011506973433175256, 0.021071241736145954, 0.03510800915371094, 0.04063849364008222, 0.031730041306998046, 0.04284105223736592, 0.027233652670734694, 0.015078722399526408, 0.023063111817464232, 0.08375326690397092, 0.05076652106695941, 0.058765780579830916, 0.08561100079012768, 0.21233682680342877, 0.16399739496409893, 0.15285762771964073, 0.16530357487499714, 0.21980243548750877, 0.1647937779447862, 0.10983884001949004, 0.09856928938201495, 0.14963352786643164, 0.19497691547232016, 0.08235348987260036, 0.13207002888832772, 0.16345610043832234, 0.10353856094713722, 0.12560251807527884, 0.20938187465071678, 0.07323111580418688, 0.07591590923922402, 0.2526294711445059, 0.12793726207954542, 0.19861950858363084, 0.15275355401848043, 0.11767443349318844, 0.20636293664574623, 0.17252043262124062, 0.09198465663939714, 0.18040752011750424, 0.17046904484076159, 0.10214058203356606, 0.16712035238742828, 0.09759293855833155, 0.14552328842026846, 1.2771012655326297, 10.779648082596914, 38.392403330121724, 41.280766010284424, 29.18852765219552, 35.4521723474775, 41.55796439307076, 36.37872505187988, 15.456873995917183, 2.8225777872971127, 0.4009630616222109, 1.2104186436959674, 5.506764394896371, 6.673274440424783, 8.97843703201839, 14.7223573412214, 8.547376871109009, 6.490557662078312, 5.6343129106930325, 1.6050939112901688, 3.5400561562606265, 5.9680883032935, 16.028014183044434, 26.70871557508196, 38.56946080071585, 49.414330754961284, 54.05079766682216, 52.18883677891323, 51.053556714739116, 51.383530139923096, 54.687978744506836, 55.366199357169016, 53.41715669631958, 55.055885859898154, 54.00947672980172, 50.444477626255576, 48.49433020183018, 46.12172188077654, 53.90764740535191, 50.97792557307652, 47.708659172058105, 44.07989992414202, 47.173943178994314, 46.51175900868007, 50.368749209812705, 50.852107592991416, 52.445857592991416, 41.81805631092617, 37.85362958908081, 38.205927576337544, 40.139819690159385, 42.270172119140625, 47.78914015633719, 50.37614904131208, 52.87957457133702, 51.77593660354614, 50.41200174604143, 42.573457513536724, 51.11085850851876, 47.453031471797395, 44.49360956464495, 52.644193921770366, 49.34118706839425, 49.45933771133423, 50.20275674547468, 50.02040127345494, 45.84135511943272, 38.4908002444676, 37.85713495526995, 36.6139806338719, 36.833595820835654, 39.297385351998464, 38.00779969351632, 39.696208477020264, 38.98041895457676, 40.12416887283325, 38.64933034351894, 40.647524561200825, 46.730898244040354, 49.61208690915789, 49.012259347098215, 48.498408794403076, 44.22326210566929, 43.64897264753069, 44.41106843948364, 45.49410152435303, 44.80524321964809, 45.9866350037711, 46.150410992758616, 45.26381737845284, 44.475502559116904, 42.32257890701294, 33.82955258233206, 16.881225177219935, 7.799246958323887, 4.854891351291111, 3.7441049899373735, 5.905662213053022, 6.753984715257372, 8.249484147344317, 6.319775283336639, 5.585162656647818, 8.969156844275338, 11.069889971188136, 5.101431676319667, 1.476651900580951, 0.4843746115054403, 2.0160437055996487, 10.31871587889535, 24.324474232537405, 26.02498504093715, 29.652062824794225, 28.455728939601354, 33.268482072012766, 21.608036041259766, 4.3361779281071255, 0.17884644174150058, 0.1827032754995993, 0.131717570658241, 0.09995540750346013, 0.10607168823480606, 0.18513462931982108, 0.1709588657000235, 0.11625966083790575, 0.15149008110165596, 0.15085703507065773, 0.14366991072893143, 0.13625946694186755, 0.12453681097498961, 0.06836525976125683, 0.11100714161459889, 0.07372268728379693, 0.2274237408169678, 0.1221191907035453, 0.10105008804904562, 0.14305712575359003, 0.08447353182626621, 0.179558414965868, 0.09995394865317003, 0.08849593491426536, 0.13612336638782704, 0.1261247050549303, 0.1178663774792637], [0.022423115891537497, 0.05571225085960967, 0.03501091757789254, 0.05949162305997951, 0.025051445034997802, 0.055999715612935166, 0.02819692133925855, 0.02149325659099434, 0.07859923025327069, 0.007286490706194724, 0.012935713731816836, 0.015122781374624797, 0.050966098571994474, 0.037951345688530376, 0.02549450465344957, 0.09313825438065187, 0.057595171965658665, 0.020872327499091625, 0.061283973311739307, 0.046572865918278694, 0.009542995381967297, 0.03006990360362189, 0.05943247516240392, 0.04290637480361121, 0.025346880878454874, 0.022576838000012294, 0.023814275528171232, 0.012787384280402745, 0.08364316102649484, 0.023695184150710702, 0.03499147754960826, 0.03232932682814343, 0.0381135901968394, 0.06481540881629501, 1.448418221303395, 13.545457567487444, 33.48753098079136, 28.117792878832134, 26.243889774594987, 31.157185077667236, 35.33044685636248, 27.48810022217887, 11.087325607027326, 2.0677743468965804, 0.056500182686639686, 0.7458487323352269, 1.3158752535070692, 1.7724127215998513, 4.024680631501334, 4.95484162228448, 2.769823372364044, 2.1537947825023105, 1.4748344038214003, 1.1524992202009474, 1.4291885388748986, 3.915692925453186, 9.641068492616926, 20.10836638723101, 35.422482694898335, 47.3373578616551, 50.62933792386736, 52.948448589869905, 51.45482907976423, 53.3938524382455, 49.74037844794137, 50.33302852085659, 50.31758614948818, 50.976181575230186, 48.53462627955845, 45.35491173607962, 43.685308252062114, 49.25737789699009, 49.01399639674595, 51.12406703404018, 42.997457436152864, 42.29278155735561, 49.944912569863455, 46.57446302686419, 49.44539267676217, 44.01026855196272, 35.7865127154759, 34.66524716785976, 36.32624530792236, 36.84231233596802, 40.573373385838096, 44.41928121021816, 48.02537196023123, 49.005578654153005, 47.72862829480852, 48.68702111925398, 37.666726521083284, 42.13043689727783, 51.90270301273891, 43.689605712890625, 49.49646888460432, 48.78188140051705, 48.32465519223894, 48.50602054595947, 47.43794693265642, 43.74870361600603, 37.94616222381592, 32.736576625279014, 33.886090074266704, 34.241764886038645, 34.9807961327689, 35.48779923575265, 37.63600506101336, 37.73687205995832, 38.67978082384382, 38.01098196847098, 40.58540071759905, 43.45616013663155, 42.347040040152415, 47.09677995954241, 44.63685015269688, 42.95217950003487, 43.435325963156565, 45.460458346775596, 42.59187718800136, 45.38648087637765, 43.66020441055298, 43.1194087437221, 43.46444238935198, 35.6775997025626, 27.396507331303187, 17.611732721328735, 7.0466688956533154, 3.2445957362651825, 1.173436096736363, 2.845308384725026, 3.3800539076328278, 3.5471511355468204, 2.779933435576303, 1.8820266340460097, 1.7161125540733337, 2.848112634250096, 3.8339881896972656, 0.34898711634533747, 0.09133437581892524, 0.3125624880194664, 7.97796504838126, 18.28976399557931, 25.980533940451487, 20.29586352620806, 16.879409960338048, 22.364239760807582, 21.15952808516366, 7.228610949856894, 0.21563570121569292, 0.019592854726527418, 0.05768013812069382, 0.0078071603119107226, 0.006290590440455292, 0.029240465789501156, 0.038846743891813924, 0.08319643392626729, 0.03278891555964947, 0.06179649116737502, 0.03278463739635689, 0.021044836545895253, 0.027707870617242794, 0.01733024069108069, 0.052496025405291996, 0.05195213209039398, 0.02558034272598369, 0.04552174053554024, 0.04823666771075555, 0.04237928880112512, 0.02283868466370872, 0.05409773445821234, 0.050832060764410665, 0.027646327491051385, 0.010008991180386926, 0.07340083098305122, 0.01896037018325712, 0.056551211912717135, 0.008994298887306025, 0.05014485067554882, 0.033193967039031644, 0.050653494096228054, 0.04414517957983272, 0.03763432055711746, 0.014498971901567919, 0.028491695611072437, 0.10931441387427704, 0.03818146066207971, 0.00704074525440644, 0.017501435076285685, 0.04139235961650099, 0.04770578530484012, 0.0727546824408429, 0.011272165541803198, 0.027781854683001126, 0.038148449933422465, 0.019522295566275716, 0.05268543167039752, 0.02990141318046621, 0.038480731924729686, 0.03484666799860341, 0.04979170033974307, 0.05256865918636322, 0.04343704686367086, 0.10622425683374916, 0.01875946274958551, 0.0200325165808733, 0.07734588786427464, 0.035399813138480694, 0.05737785076988595, 0.011132677401682096, 0.011707815557851322, 2.4446211882999966, 19.587169851575577, 38.23518991470337, 28.012195893696376, 25.671936648232595, 31.893040997641428, 44.01683112553188, 29.804547991071427, 9.672569019453865, 1.7077374777623584, 0.06107669443424259, 0.3376597613096237, 0.5489984495299203, 2.7549290401594977, 5.097555015768323, 5.077048710414341, 3.31822384255273, 2.8301333018711636, 4.345668298857553, 2.61612183707101, 2.8022775394575934, 6.2806417260851175, 13.775526319231306, 23.742105756487163, 38.34421409879412, 50.067718505859375, 52.8300895009722, 52.526738098689485, 52.40309490476336, 53.73016956874302, 50.93023313794817, 51.460731574467246, 52.59894377844674, 54.05385487420218, 50.21841103690011, 47.341005665915354, 45.21372781481062, 51.71156849179949, 50.36512919834682, 51.22399255207607, 42.85778474807739, 42.39383963176182, 49.31081649235317, 49.07818732942854, 50.0989020211356, 46.022272314344136, 37.94290004457746, 36.29532929829189, 37.84692805153983, 39.38779878616333, 41.44639369419643, 46.59164244788033, 49.27848652430943, 48.55930280685425, 49.4711948122297, 48.24642195020403, 39.67495046343122, 42.408437797001426, 51.75219113486153, 44.83535671234131, 49.50595664978027, 50.25347859518868, 48.71079090663365, 49.5395233971732, 48.073300634111675, 45.15549496241978, 38.39812864576067, 34.41447625841413, 36.047896998269216, 35.79868595940726, 36.35782834461757, 38.05563109261649, 38.750520433698384, 39.32133231844221, 39.435206345149446, 39.46131420135498, 42.55206053597586, 45.494844981602256, 44.86927434376308, 48.64853157315935, 44.126751627240864, 43.05572850363595, 43.4920197895595, 46.58714001519339, 43.9333415712629, 46.23019368307931, 44.2685991014753, 44.298323495047434, 44.0696165902274, 39.52748189653669, 31.56406463895525, 21.022422756467545, 8.953915102141243, 4.586686108793531, 2.7238781920501163, 3.3452992354120528, 5.203820330756051, 4.287857549531119, 3.678224342209952, 3.384239763021469, 5.303340247699192, 4.540041983127594, 1.3085186311176844, 0.3936538009771279, 0.11823545981730733, 0.6862578328166689, 5.937819344656808, 20.723275014332362, 29.473292623247417, 19.518139498574392, 20.44082031931196, 24.644120897565568, 24.950371435710363, 9.95433931691306, 0.5969633300389562, 0.06526882627180644, 0.029743395945323364, 0.08735763813768115, 0.02885290015754955, 0.029052250353353362, 0.02288029752006488, 0.021414690717522587, 0.0315248319613082, 0.05802506461207356, 0.02977290882595948, 0.011846760869957507, 0.01656026459698166, 0.050406161296580515, 0.03551119126911674, 0.021166564031903232, 0.04867710139868515, 0.04543453182226845, 0.01725901147749807, 0.022436632309108973, 0.09805616084486246, 0.008869249124212988, 0.0510019795037806, 0.011168062154735838, 0.03075245554958071, 0.042531524917909076, 0.03668518238035696, 0.02561492595954665, 0.23734565983925546, 0.14588986017874309, 0.1687478864831584, 0.1487184962523835, 0.20564476161130837, 0.16122119607669966, 0.149279726137008, 0.10530330839433841, 0.1927751371903079, 0.1463439900960241, 0.111899795143732, 0.13402539039296762, 0.11759224933172975, 0.11508523885692869, 0.13438277478728974, 0.1088188865355083, 0.13570243040365831, 0.1325036534773452, 0.16054320388606616, 0.15995111422879355, 0.07332470613930907, 0.08767707206841026, 0.15136634345565522, 0.13303209654986858, 0.16000992964420999, 0.11035245710185596, 0.1591684647968837, 0.11509695037135056, 0.1299540852861745, 0.2143336467977081, 0.10276017950049468, 0.23705901950597763, 0.12492086179554462, 0.1462304304753031, 2.6111414985997334, 22.245804241725377, 46.53269740513393, 37.868175642830984, 35.25909580503191, 40.16721643720354, 43.12310865947178, 34.39129359381539, 13.317633952413287, 3.0486828088760376, 0.2582594119012356, 2.138288140296936, 5.709886729717255, 7.946299501827784, 12.70818747792925, 10.690069300787789, 6.625406563282013, 6.6361914702824185, 5.684866266591208, 2.4904640998159135, 2.397219708987645, 5.237031417233603, 11.692288756370544, 23.82643777983529, 38.339982645852224, 50.35459920338222, 54.293460028512136, 56.20255054746355, 54.892016070229666, 55.58359112058367, 52.31422744478498, 53.78008195332119, 54.05123887743269, 56.08025530406407, 52.69278614861624, 49.57793651308332, 47.7274922643389, 53.02711609431675, 51.42678267615182, 51.92214754649571, 44.675701005118235, 44.08173772266933, 51.40924889700753, 52.61393451690674, 52.50422593525478, 47.45754432678223, 38.041053771972656, 37.45330565316336, 39.625910077776226, 40.9632750238691, 43.41751078196934, 50.13992765971592, 52.42408193860735, 51.69398954936436, 51.98086329868862, 48.77950859069824, 41.73095369338989, 44.10823120389666, 49.22938360486712, 45.91801112038748, 50.72487565449306, 51.224409443991526, 51.73328856059483, 51.83232470921108, 49.422494888305664, 46.88701384408133, 41.429391452244346, 36.629475116729736, 38.07689952850342, 37.59115791320801, 38.93236868722098, 39.441723755427766, 40.14132744925362, 41.412396158490864, 40.866611685071675, 41.58431543622698, 43.79585061754499, 48.38413177217756, 45.20957626615252, 50.900470529283794, 44.121543952396934, 43.135733536311555, 44.42395734786987, 48.66054153442383, 45.25853327342442, 48.03381402151925, 44.73213079997471, 44.80993325369698, 43.95117064884731, 41.78197431564331, 33.387674944741384, 22.714123249053955, 7.953416194234576, 5.162735198225294, 3.254002945763724, 7.43578929560525, 8.795720253671918, 8.252461450440542, 7.144536009856632, 7.063087923186166, 7.169166939599173, 8.405387827328273, 7.372086473873683, 0.8228346098746572, 0.45750332197972704, 1.0282076724937983, 10.099395990371704, 22.878276177815028, 33.68859447751726, 26.53098586627415, 23.965228046689713, 30.77193178449358, 28.887432677405222, 9.970819575445992, 0.6616393881184714, 0.13410202413797379, 0.21930034671510967, 0.13242125218468054, 0.12981073797813483, 0.08371644280850887, 0.14435487825955662, 0.15320150926709175, 0.1269029032971178, 0.2590948242161955, 0.13873101717659406, 0.16900743969849177, 0.10901913579021182, 0.12796364352107048, 0.1671662349253893, 0.14399294768060955, 0.12024537553744656, 0.09527726138808898, 0.12630219624510833, 0.0687506812225495, 0.116629530276571, 0.11506130014147077, 0.1716814919241837, 0.06407851978604283, 0.14995933324098587, 0.1525881543223347, 0.115279367725764, 0.12747778530631745], [0.050906217856598754, 0.06197456589766911, 0.010893481085076928, 0.022307820917506303, 0.042520970305694, 0.01091287616041622, 0.04163334472104907, 0.08383861303861652, 0.009098783950321376, 0.012468006328812667, 0.046995525381394794, 0.03649635626269238, 0.04829248060871448, 0.04380204781357731, 0.06335792238158838, 0.029886685577886443, 0.0717998208212001, 0.04915014547961099, 0.02050634436974568, 0.07174623012542725, 0.05448441460196461, 0.03805613185146025, 0.023965068061703017, 0.03346620546653867, 0.05382646294310689, 0.03657562272357089, 0.03818316039230142, 0.028572197005684887, 0.08606404505137887, 0.05234970272119556, 0.05176331954342978, 0.021492712066641877, 0.02876663121527859, 0.032621252949216535, 0.05256700695359281, 3.0549112175192152, 16.311976637159074, 32.6496616091047, 25.97816286768232, 15.877768073763166, 29.364508152008057, 36.2971636227199, 26.842692477362498, 12.244725261415754, 1.6411493080002921, 0.09507254058761255, 0.6062442777412278, 2.266742527484894, 3.571861969573157, 1.724434758935656, 2.4568445895399367, 1.108221281852041, 1.5267616574253355, 3.193505632025855, 0.9802064767905644, 0.9521638729742595, 3.29575315117836, 8.191305143492562, 18.433035850524902, 33.6397590637207, 43.820454188755576, 50.194057600838796, 50.575687408447266, 48.16687549863543, 49.16415391649519, 51.270267554691856, 52.171897070748464, 50.72485828399658, 47.99900354657854, 46.66892031260899, 47.396348067692344, 49.32845796857561, 50.24343497412545, 49.55901656832014, 45.19623919895717, 48.35426146643502, 46.94777931485857, 48.462632519858225, 46.688896383558, 39.554135186331614, 35.49642195020403, 36.243134430476594, 36.489430700029644, 40.330394881112234, 42.42971665518624, 47.46024717603411, 46.20611122676304, 50.20833614894322, 47.33592653274536, 49.87676811218262, 36.80447244644165, 45.39885214396885, 51.50366449356079, 47.65865298679897, 50.05536808286394, 47.92699589048113, 47.55124773297991, 46.67264802115304, 45.14088984898159, 42.20507097244263, 35.248815945216585, 33.91390718732561, 33.18371752330235, 33.647641795022146, 34.08618777138846, 36.9028137751988, 39.286469732012065, 38.02081366947719, 42.70505639484951, 43.1894986970084, 44.28456606183733, 42.77957582473755, 48.027484212602886, 46.97202157974243, 45.53211164474487, 44.01668173926217, 44.521020208086284, 44.087657587868826, 45.99252012797764, 46.49039677211216, 42.23212030955723, 38.32466534205845, 34.18466806411743, 30.542175701686315, 23.107794284820557, 11.657898647444588, 2.979041665792465, 1.1172424320663725, 2.126783009086336, 1.9455492368766238, 3.1679432094097137, 2.943751548017774, 1.9188036663191659, 1.4345449485949107, 3.7168975813048224, 3.5173735448292325, 1.3358140864542551, 0.17272434596504482, 0.6735846442835671, 5.649584182671138, 16.862534523010254, 26.664089032581874, 31.133300645010813, 29.251089232308523, 16.872633729662212, 27.093039546694072, 10.741657069751195, 1.7884368960346495, 0.018775147086541568, 0.013669857239749814, 0.04066362657717296, 0.010201333805785646, 0.004552161670289934, 0.02624032998989735, 0.048316225941692076, 0.03802292774032269, 0.06731067384992327, 0.0007095295441104099, 0.04917260498872825, 0.009197042606371855, 0.031212977266737392, 0.017471901839599013, 0.011713667074218392, 0.05268300590770585, 0.015264898837943162, 0.04693730029144457, 0.02796206679860396, 0.019256557504247342, 0.0812707311872925, 0.046380406245589256, 0.05806549172848463, 0.0369352734248553, 0.010855028505570121, 0.07747538627258369, 0.01647113054059446, 0.0491690630359309, 0.03613166404621942, 0.051748775145305057, 0.015415738868926252, 0.07506660731243235, 0.034404531187777004, 0.02271265017666987, 0.10588796130780663, 0.07822557458920137, 0.028774349551115717, 0.021534275729209185, 0.052144737648112435, 0.01970293346260275, 0.005679061603067177, 0.05393390557063477, 0.061286307472203455, 0.022867262862356644, 0.011727935817491795, 0.04258896969258785, 0.07648337486066989, 0.04313775524497032, 0.025911790119217973, 0.010152417368122509, 0.05251071568844574, 0.06841057911515236, 0.05816136872661965, 0.02919027116149664, 0.021066283341497183, 0.01501844304480723, 0.06598060950636864, 0.05304652425859656, 0.032787690803940804, 0.020693898234250288, 0.02298812521621585, 0.03552168142050505, 0.10730742264006819, 4.905664878232138, 22.868595600128174, 38.01433794839041, 29.433830329350062, 19.61749700137547, 30.966411863054546, 42.77310357775007, 29.055414063589915, 10.785698226519994, 1.6387862690857478, 0.11145131742315632, 0.26102897471615244, 0.7099882108824593, 3.4240084290504456, 4.901402592658997, 3.677014921392713, 3.579826993601663, 2.6932826680796484, 4.9188781806400845, 2.947810164519719, 2.1919110800538744, 4.481061765125819, 10.233976517404828, 20.955080815723964, 36.410985537937705, 45.46148668016706, 50.03481183733259, 52.508662360055105, 50.821948937007356, 51.93755865097046, 53.812040192740305, 52.79574108123779, 52.021197591509136, 50.50617068154471, 48.74673393794468, 49.583821637289866, 50.128549984523225, 51.33628238950457, 50.361213888440815, 45.81967673982893, 48.15056460244315, 48.00116096224104, 49.26234238488333, 49.48538303375244, 42.9480105808803, 35.96941362108503, 37.61586570739746, 38.03410904748099, 41.212559018816265, 44.753812653677805, 48.427627495356965, 48.19122198649815, 50.802799701690674, 49.46543822969709, 48.91458851950509, 38.0514725957598, 47.187040533338276, 51.23637771606445, 48.4123866217477, 51.461554936000276, 50.23019518171038, 48.42771087374006, 48.59836905343192, 47.59075171606881, 43.90745953151158, 38.35639081682478, 34.67474882943289, 35.063903536115376, 35.18259266444615, 36.31797347749983, 38.038250173841206, 41.22032363074166, 39.78606258119856, 43.99297101157052, 44.99086781910488, 45.65846463612148, 45.41583701542446, 47.96342529569353, 47.26666341509138, 44.902625696999685, 44.551196234566824, 45.665513583592, 44.65802826200213, 46.68439047677176, 47.80708040509905, 44.06674003601074, 41.76497902188982, 38.166541712624685, 33.19214221409389, 27.095591272626603, 13.312149218150548, 4.665711011205401, 2.855619077171598, 3.550375751086644, 4.288359991141728, 3.474221323217664, 3.681957696165357, 3.2470226117542813, 4.035607976572854, 4.415322686944689, 3.7132532511438643, 0.7336730456777981, 0.1574892806155341, 0.49918409969125477, 4.8808020523616245, 20.172209909984044, 29.813879421779088, 33.0888363974435, 30.91757992335728, 17.07720259257725, 29.50414262499128, 15.103069986615862, 2.722906095641, 0.04358516088021653, 0.006146782152687332, 0.05010195029899478, 0.03555367434663432, 0.029800833934651952, 0.06894542755825178, 0.01626712389822517, 0.02450821329174297, 0.019339983384790163, 0.028044890479317734, 0.00553625839529559, 0.0526951788259404, 0.025963664121393646, 0.013232994342355855, 0.006947765600801046, 0.003826856505059238, 0.039800567352878194, 0.08606808233473982, 0.04539442022464105, 0.06233809103391, 0.04078457544424704, 0.025609925156459212, 0.06309067457914352, 0.030393032157527547, 0.06134932301938534, 0.03412733945463385, 0.025174331119550124, 0.0449497456928449, 0.12596600928476878, 0.1381264424749783, 0.09850759697811944, 0.19050688961786882, 0.12662786591265882, 0.10049416430826698, 0.15792492723890714, 0.19525915889867715, 0.14653106220066547, 0.08085911827428, 0.0752575131399291, 0.2256961092352867, 0.1459017074001687, 0.16441185772418976, 0.16416286251374654, 0.12713560009641306, 0.17580769051398548, 0.06328801970396723, 0.1715465991624764, 0.19824649074247905, 0.16446664264159544, 0.08054627970393215, 0.11075392591633967, 0.2042346301355532, 0.12410980888775416, 0.1303978879004717, 0.08865549242390053, 0.1230304768042905, 0.28347944574696676, 0.10194399008261305, 0.13477648794651031, 0.0703751551253455, 0.15116241654115065, 0.10907280112483672, 0.21649091318249702, 5.0704526986394605, 27.168660266058787, 45.7377644266401, 36.76765741620745, 24.665274688175746, 35.41315821238926, 45.15385171345302, 33.6676595551627, 14.464771117482867, 2.30899669442858, 0.41520640732986586, 1.380322943840708, 5.921967463833945, 8.880040117672511, 6.08507946559361, 9.508172903742109, 5.073832562991551, 4.051569725785937, 6.663622524057116, 2.8413018797125136, 1.6219399273395538, 4.294195175170898, 10.034905416624886, 21.97570170675005, 35.235398973737446, 44.49408551624843, 48.96547017778669, 54.24542365755354, 51.25725705283028, 52.88522693089077, 54.82393414633614, 55.653413568224224, 54.691897528512136, 51.28913191386631, 51.556286675589426, 51.534948757716585, 51.96803344999041, 52.99484518596104, 50.40614094052996, 46.29187631607056, 48.27867201396397, 50.285812037331716, 51.68532861982073, 51.56633724485125, 42.388406140463694, 38.06010225840977, 40.08517905644008, 39.93502153669085, 44.402428354535786, 45.50312376022339, 52.0411319732666, 49.69450296674456, 52.35977636064802, 50.20696040562221, 49.018415451049805, 40.07295717511858, 48.34256417410714, 50.399602685655864, 49.959500312805176, 53.3709477015904, 51.897432804107666, 49.3271621295384, 49.803148474012104, 48.82371303013393, 46.36449888774327, 40.117807797023225, 37.38542522702898, 35.68851184844971, 36.46235704421997, 36.99328279495239, 41.20423855100359, 43.03112840652466, 40.425331592559814, 46.183911732264924, 46.844108717782156, 49.44163022722517, 47.3856235231672, 50.30341877256121, 48.83092178617205, 46.094912256513325, 44.128363609313965, 45.63752971376692, 44.40691689082554, 47.51999820981707, 47.57457978384835, 43.620669160570415, 45.17439406258719, 42.921173163822715, 36.958864893232075, 27.577657290867396, 12.16144241605486, 4.477565084184919, 2.413136512041092, 5.752204733235495, 5.473403922149113, 8.454595838274274, 6.786592611244746, 6.086104324885777, 6.538500666618347, 7.569277218409947, 7.058471279484885, 3.367998783077512, 0.6938288722719465, 1.0716706088611057, 6.788206330367497, 20.850126538957866, 34.04260172162737, 36.811368533543174, 35.42445945739746, 23.81616834231785, 34.64372859682356, 16.559747661863053, 2.358026657785688, 0.13140724945281232, 0.08785378972866706, 0.1273121006254639, 0.13697947402085575, 0.11948781833052635, 0.20334908765341553, 0.11454492142157895, 0.08366306924394198, 0.13962512277066708, 0.07761571409979037, 0.06493847471262727, 0.2083553054503032, 0.11613823021096842, 0.0921540121947016, 0.08067470602691174, 0.1194357339824949, 0.07642835245600768, 0.10670445606644664, 0.1366262694022485, 0.10636393326733794, 0.1826867192451443, 0.14775452869279043, 0.19427235185035638, 0.06217524941478457, 0.15773239971271583, 0.18638082673507078, 0.057852981345994134, 0.13369227041091236], [0.04474279251215713, 0.010257273929060569, 0.011007011868059635, 0.05698480936033385, 0.04484513255634478, 0.022565131574603062, 0.048832933751067946, 0.047095873925302706, 0.04321065026202372, 0.01130580815619656, 0.04061972536146641, 0.007456173654645681, 0.07223693986556359, 0.06789043452590704, 0.011016511358320713, 0.03657231486535498, 0.03156044487176197, 0.07722606536533151, 0.11430223658680916, 0.013678209157660604, 0.01669981550159199, 0.04191502496334059, 0.029467910727752105, 0.023180043757227913, 0.05437045464558261, 0.04147184660126056, 0.06549836788326502, 0.03164125160713281, 0.033979330611016066, 0.09059103392064571, 0.03881313605234027, 0.03319290513172746, 0.03764726361259818, 0.023398613457434943, 0.026749957286353623, 0.04248827848849552, 4.252822995185852, 20.811744689941406, 30.638363088880265, 19.276210171835764, 17.898109674453735, 22.77704439844404, 25.58008667400905, 29.755458968026296, 10.225709898131234, 2.305718013218471, 0.3200395910867623, 0.41983236053160256, 2.3690584429672787, 3.2544945308140347, 2.4246883264609744, 2.542743431670325, 2.5471273107188086, 3.0968314366681233, 2.4403471776417325, 1.9698759657996041, 0.304472559264728, 1.2084988781384058, 5.592828256743295, 18.035088198525564, 30.26107590539115, 43.65453815460205, 46.66952133178711, 53.294732911246165, 51.53444153921944, 50.24287564413888, 47.05115808759417, 49.33789709636143, 47.113532066345215, 49.47252539225987, 48.50743450437273, 50.51075996671404, 48.8697726385934, 48.07372447422573, 49.55914510999407, 50.335265840802876, 47.539102281842915, 50.4776656968253, 44.48453174318586, 38.31409018380301, 36.591159275599885, 38.537780489240376, 39.530587741306846, 42.73263726915632, 44.54343509674072, 47.16969435555594, 46.85264457975115, 50.82672929763794, 49.567476000104634, 51.9404421533857, 38.6593461717878, 40.57926893234253, 51.754028933388845, 50.47668252672468, 47.04025288990566, 46.292876856667654, 46.23201411111014, 43.746879713875906, 43.583975723811555, 38.6102363041469, 35.227102824619834, 35.38616098676409, 34.76887607574463, 35.07361364364624, 36.354621750967844, 40.015026569366455, 40.38609511511666, 42.34801626205444, 42.61814137867519, 44.2874356678554, 45.01615578787667, 47.35799748556954, 46.839950220925466, 43.57756948471069, 45.322776317596436, 46.06028243473598, 46.33110931941441, 43.64745099203927, 41.439699104854036, 38.07021883555821, 37.3524386542184, 36.485564027513774, 37.46346739360264, 26.41834167071751, 16.44738139425005, 4.381243944168091, 1.336557218006679, 1.452024119240897, 2.029633513518742, 3.983672797679901, 2.750478501830782, 1.9275764184338706, 2.664704293012619, 3.1463670986039296, 6.142771227019174, 3.2960892702851976, 0.37867405478443417, 0.39906962322337286, 3.7017631019864763, 13.408352238791329, 23.342478377478464, 21.02633285522461, 28.01944633892604, 41.984625475747244, 25.65031385421753, 20.45301788193839, 3.3508304357528687, 0.17905348991709097, 0.038461054409188886, 0.01175080584029534, 0.043713241150336604, 0.04399930812152369, 0.018221413317535604, 0.0339053160111819, 0.06567538409893002, 0.05029835565281766, 0.05613548707749162, 0.04210894009364503, 0.08036074787378311, 0.05162198069904532, 0.037023822244788916, 0.047817801258393695, 0.0101257263449952, 0.03728971976254668, 0.0229404581311558, 0.06949610622333628, 0.059648608921894004, 0.06723837594368628, 0.026276716430272375, 0.018693387009469525, 0.08909127475427729, 0.029742798834506954, 0.030717287079564164, 0.04520398937165737, 0.04145127681217023, 0.011481974506750703, 0.055677553971431086, 0.00705584350674014, 0.050405119745326896, 0.037314520217478275, 0.028981540219060013, 0.01354780829777675, 0.043974528022642644, 0.018887894161577736, 0.0031468251046525048, 0.0032658098248897916, 0.030804438117359365, 0.012368349890623773, 0.03392029806439366, 0.09310849383473396, 0.035377292561211755, 0.02085590355896524, 0.031235935499093363, 0.06664337537118367, 0.010797031573019922, 0.0389468108436891, 0.02663494729703026, 0.0862726674282125, 0.04220304950805647, 0.04165545817730682, 0.05470218702352472, 0.05700488042618547, 0.018222448083439043, 0.009922876604832709, 0.041379267283316166, 0.017037958339122788, 0.03723831055685878, 0.02239796090205865, 0.06035457032599619, 0.07535737992397376, 0.028856628707477024, 0.388356016682727, 6.808098154408591, 26.141049487250193, 33.823097705841064, 16.836609057017736, 18.289182083947317, 31.159912245614187, 35.827117988041465, 27.795691762651714, 10.074826291629247, 1.7362514734268188, 0.22742351011506148, 0.07563185412436724, 1.5295982595000948, 2.9344450873988013, 3.5186858858381, 5.703378873211997, 5.057668447494507, 6.772477345807212, 5.640033449445452, 3.912795526640756, 1.2975640360798155, 2.969290954726083, 8.177331447601318, 20.70973644937788, 32.9085236958095, 45.479444299425396, 48.48443944113595, 53.24606425421578, 54.15135894502912, 52.26113625935146, 50.50799110957554, 51.49624034336635, 48.967426095690044, 50.87600939614432, 50.00538969039917, 52.130916595458984, 51.97162219456264, 47.37825148446219, 49.500641277858186, 50.09865883418492, 48.54772710800171, 51.00700031008039, 47.45254509789603, 40.03424876076834, 39.21548693520682, 39.85654163360596, 40.88636193956648, 44.04513461249215, 46.39977141789028, 49.20068407058716, 49.6345990725926, 52.60400901521955, 50.9239068031311, 51.04001120158604, 41.02183444159371, 42.33703810828072, 51.762766293116975, 52.40717002323696, 49.11390454428536, 46.77388327462332, 48.07363067354475, 45.51380314145769, 46.28964941842215, 40.813068866729736, 36.977875164576936, 36.36366483143398, 36.30220454079764, 36.84950024741036, 38.02792167663574, 41.913684368133545, 43.394025870731895, 43.53985813685826, 44.312157358442036, 45.666948386601035, 47.029024600982666, 47.49678427832467, 48.43921709060669, 44.61860070909773, 45.86367620740618, 45.98460612978254, 45.9873298236302, 43.15367031097412, 43.314569745744976, 40.49596350533621, 40.18967648914882, 39.59203066144671, 40.479030745370046, 29.8810441834586, 18.744620868137904, 7.239076239722116, 2.1213909898485457, 2.344728022813797, 3.9276724883488248, 3.9710713710103716, 3.955206028052739, 4.484341749123164, 5.4390698330742975, 4.192192580018725, 4.659055505480085, 2.8606102722031728, 0.2729517306600298, 0.3541596702166966, 4.169574022293091, 15.708794832229614, 28.37609042440142, 25.520535400935582, 33.03168051583426, 41.60230432237898, 28.59889657156808, 24.96310227257865, 5.407835509095873, 0.3928658589720726, 0.03210743569902011, 0.06021732983312436, 0.04592947901359626, 0.005156232559654329, 0.01583346538245678, 0.06832924312246696, 0.030966943861650567, 0.01915745067942355, 0.05266861417996032, 0.013521676217871053, 0.028461334561663013, 0.034829606235559495, 0.044799256803733964, 0.016213952197826335, 0.029455079630549465, 0.027712696697562933, 0.03338535801906671, 0.03531271977616208, 0.052041617288653336, 0.04772277242903199, 0.01886508859960096, 0.01875912517841373, 0.03181291418150067, 0.020346354294036115, 0.05614449462986418, 0.01049703682240631, 0.010216206445225647, 0.026175166879381453, 0.12569707871547767, 0.10820293958698, 0.07155547357563462, 0.14468845964542457, 0.11876677987830979, 0.1156097057142428, 0.08604769914277963, 0.07961510574179036, 0.12255926137523991, 0.08754289176847253, 0.14361702570957796, 0.13587431689458235, 0.14486349453883512, 0.1899292663271938, 0.10262682022792952, 0.13297910296491214, 0.14695150963962078, 0.13640144360916956, 0.1939918997564486, 0.1589951126703194, 0.2034009141581399, 0.12731940166226455, 0.16845637426844665, 0.1922204348125628, 0.12262735914971147, 0.16651918393160614, 0.14510795713535377, 0.11394827200898103, 0.14690090449792997, 0.09843016934714147, 0.08852666576525994, 0.11653479321726731, 0.21540174234126294, 0.10803728204752718, 0.16946686218891824, 0.3704427464732102, 7.589919447898865, 31.769429070608957, 41.30739845548357, 27.784878628594534, 24.441278662000382, 30.24041543688093, 34.57855796813965, 37.51444632666451, 13.25432196685246, 2.7098098269530704, 0.7087039340819631, 1.116169152515275, 6.1224216903959, 10.217850617000035, 6.743370039122445, 9.317735808236257, 8.538620403834752, 6.4093232325145175, 7.572041732924325, 4.244589814117976, 0.9786467147724969, 1.7880295578922545, 7.863361460821969, 21.705095427376882, 35.44228853498186, 47.36411884852818, 50.06718349456787, 56.03977162497384, 54.603040490831646, 54.38897691454206, 51.441050801958355, 53.11262757437569, 51.15131439481463, 52.39150530951363, 51.29543045588902, 54.90398781640189, 51.69544172286987, 48.56316600527082, 50.83031456811087, 53.33049528939383, 52.14923204694475, 54.03269760949271, 50.55614907400948, 40.976518290383474, 40.6789026260376, 41.41462305613926, 43.42399345125471, 45.22506380081177, 49.86150639397757, 48.82587391989571, 51.77398763384138, 53.88589606966291, 52.799274240221294, 52.730924810682026, 43.35286821637835, 42.90894086020333, 50.81606033870152, 52.840188707624165, 50.00734560830252, 48.93995291846139, 50.74368095397949, 47.15606198992048, 47.36129787990025, 42.097492013658794, 38.363967827388215, 38.77382121767317, 38.538061891283306, 39.54639489310128, 40.46779203414917, 44.774924755096436, 44.74071182523455, 45.42820480891636, 46.93495294025966, 46.98391342163086, 48.65337099347796, 49.791923659188406, 48.22459765842983, 45.260305064065115, 45.461889675685335, 46.21948650905064, 47.26823023387364, 45.62174688066755, 45.67612000874111, 42.980833871024, 44.16088465281895, 41.89254099982125, 42.08607612337385, 28.320900882993424, 18.79343891143799, 5.691513521330697, 1.8469447450978416, 4.66106527192252, 5.6524281672069, 8.13740188734872, 6.964920733656202, 7.058329709938594, 7.86334148475102, 9.673844013895307, 12.112909248897008, 6.764820430959974, 0.8982099166938237, 0.8779064118862152, 5.136934799807412, 16.144162007740565, 30.258115972791398, 29.01066940171378, 34.96609721864973, 47.83609955651419, 34.46404818126133, 28.134157623563492, 6.224525902952466, 0.4384111650288105, 0.2000121067145041, 0.12343512794801167, 0.12403058313897677, 0.1405736468732357, 0.14858584265623773, 0.1918864327349833, 0.15860608140272753, 0.19971853175333568, 0.12288657309753553, 0.22031573365841592, 0.14333656004496984, 0.23664809869868414, 0.14124916919640132, 0.09948157292923757, 0.06530578607427222, 0.10186106631798403, 0.10428461698549134, 0.11447028256952763, 0.19888059528810637, 0.13858657064182417, 0.1394452838493245, 0.14599507381873472, 0.1346640954060214, 0.16710163839161396, 0.1405512145055192, 0.13788036496511527, 0.09742777634944234, 0.11889262098286833], [0.03358939349917429, 0.06618783410106387, 0.03336920888562288, 0.041397787896650176, 0.014011381726179804, 0.06055521313101053, 0.02874829380639962, 0.009428525676152535, 0.04326038348621555, 0.035823449692023654, 0.017501635244116187, 0.006065465667883733, 0.040340019656079154, 0.033353185281157494, 0.04278492721329842, 0.008883359259925783, 0.017342980186055814, 0.031219440312790017, 0.02884927678054997, 0.003830741118041, 0.04195088553907616, 0.03167269152722188, 0.06622277865452425, 0.059542764244335036, 0.01382988378671663, 0.0371297585245754, 0.026050163765570948, 0.04084596250738416, 0.017275260694857155, 0.00280836208340978, 0.021955808824194328, 0.01961127695228372, 0.020008845886747752, 0.06943497021815606, 0.054236057214438915, 0.019068993461717452, 0.15940562635660172, 7.5661479234695435, 24.813177517482213, 34.59130096435547, 22.134650434766495, 17.576138836996897, 20.85607419695173, 31.869215624673025, 32.637175696236746, 9.45981170449938, 2.302671662398747, 0.2632801910596234, 0.48065298263515743, 2.9616794203008925, 2.665550236191068, 3.06484431879861, 4.764317674296243, 6.669115943568094, 6.926850685051509, 4.422075033187866, 1.078556707927159, 0.7329067896519388, 0.851362556219101, 4.478004557745797, 16.403993368148804, 27.53800913265773, 40.58665486744472, 50.727859905787874, 53.33829811641148, 52.154457092285156, 49.86100264957973, 49.100598743983674, 48.968586444854736, 50.88131781986782, 51.35942336491176, 52.67626680646624, 48.76852001462664, 50.10865729195731, 51.663525172642295, 50.689377307891846, 48.69867672239031, 45.56294775009155, 39.26807090214321, 36.526450702122276, 37.41436447416033, 39.75595603670393, 42.13519641331264, 43.928005354745046, 44.69956111907959, 45.841758114951, 48.34241826193673, 48.85821431023734, 49.77504995891026, 51.58288090569632, 42.21184894016811, 41.73827362060547, 51.0806234223502, 47.70856884547642, 49.237537315913606, 44.938554831913535, 45.38335766111101, 41.5997439111982, 39.47047192709786, 35.280141898563926, 37.07064403806414, 36.49812289646694, 36.079761437007356, 33.84513391767229, 39.26900543485369, 40.03871297836304, 44.0243490764073, 44.92223003932408, 46.66230910164969, 46.11177206039429, 47.15840700694493, 49.29890727996826, 44.266657079969136, 45.721787043980186, 46.600358963012695, 43.4372228213719, 43.15622724805559, 41.89337478365217, 41.241737978799, 38.7303671836853, 42.2914023399353, 40.69527605601719, 28.28069339479719, 15.65005476134164, 4.89579713344574, 1.9219948436532701, 1.1273696486439024, 1.1197044828108378, 2.93461531826428, 3.7506588782582964, 3.117949400629316, 3.049926753555025, 3.1756016441753934, 1.8987843862601688, 3.691578345639365, 2.3866530188492368, 0.3257552986698491, 3.2662304724965776, 12.231759922845022, 21.545043672834122, 23.68424984386989, 20.386243956429617, 20.960311072213308, 42.115029266902376, 23.845184019633702, 9.178182976586477, 0.6775728017091751, 0.009117802438725318, 0.020435430674946735, 0.03426586237869092, 0.02089142656352903, 0.014590038086420723, 0.0424557563050517, 0.022039512904094796, 0.06739409973046609, 0.01696975708806089, 0.07774190125720841, 0.0436057069205812, 0.051454925377454074, 0.03277532450322594, 0.057616423682442734, 0.007250606381733502, 0.021268195006996393, 0.041801180357911756, 0.030479989812842438, 0.02969828015193343, 0.007851409276814332, 0.003771541058085859, 0.006043521421296256, 0.01675435614639095, 0.03980158515540617, 0.05445374142644661, 0.01643325641219105, 0.011635478635850762, 0.02553149838266628, 0.045582282822579145, 0.042081211760107956, 0.03485548556117075, 0.027488632560042397, 0.03436642466112971, 0.006043780536856502, 0.010985952685587108, 0.04032566185508456, 0.03290394420868584, 0.05561851803213358, 0.03250661785049098, 0.022851612452151518, 0.0044782993167505735, 0.06555649119296245, 0.05676011588158352, 0.04004810032035623, 0.06826033789132323, 0.0791745058127812, 0.014358940933431898, 0.027134430494957736, 0.023318905948794315, 0.04112072169248547, 0.0013530038101764927, 0.02515391230450145, 0.060592858253845146, 0.03423433085637433, 0.05611058484230723, 0.0108831283370299, 0.03723927068391016, 0.039297969679215124, 0.028099656737010394, 0.042897984718105624, 0.005172426646043147, 0.013109378832658487, 0.02514756460940199, 0.008003100869245827, 0.10559340247086116, 0.7276333783354078, 11.76860429559435, 32.05359649658203, 35.5807591847011, 19.95894363948277, 17.28120344025748, 28.67497066089085, 42.354054246629985, 29.780847685677664, 10.455011742455618, 1.9289458649499076, 0.22880284967167036, 0.2967091958437647, 0.9604401545865195, 3.770720064640045, 6.0080843056951245, 7.843371493475778, 12.265037451471601, 10.366734879357473, 6.827114939689636, 2.0947059988975525, 1.7040841366563524, 1.5863715559244156, 7.137132704257965, 20.916483572551183, 32.27660240445818, 42.64429439817156, 51.72029195513044, 53.8581553867885, 54.179933411734446, 51.93164920806885, 51.53542470932007, 51.478557177952354, 52.44036504200527, 51.90144191469465, 53.65823139463152, 49.672960077013286, 48.73494284493582, 52.03017118998936, 52.37225532531738, 51.1003771509443, 49.707819189344136, 41.80000836508614, 37.501602581569124, 39.586180278233115, 41.58518048695156, 44.35643127986363, 45.78713832582746, 45.55501290730068, 47.598707403455464, 50.210253851754324, 50.690475123269216, 50.48723684038435, 52.558088370731895, 44.621727398463655, 43.883311067308696, 51.227730682918, 50.15340369088309, 50.491332803453716, 46.78147070748465, 45.379782812935964, 44.85377638680594, 41.63877541678292, 37.910160132816856, 37.97882917949131, 37.94489765167236, 37.67083290645054, 35.737295150756836, 40.61324562345232, 43.111425263541086, 45.372528893607004, 46.5427896635873, 47.2425149508885, 46.38340146200997, 47.26168155670166, 50.05003186634609, 47.27412230627877, 45.52882514681135, 47.35184138161795, 43.90727540424892, 43.98113475527082, 42.56104455675398, 41.78564643859863, 41.35140487125942, 44.80459703717913, 42.69868837084089, 31.36684349605015, 18.564401967184885, 8.047193425042288, 3.78141507932118, 2.215539732149669, 2.4759441018104553, 3.6970279046467374, 4.647628324372428, 4.3383783357484, 3.9655592782156805, 6.61837455204555, 6.184795669146946, 5.146674871444702, 1.0971890624080385, 0.23419231761779102, 2.3166434041091373, 13.060727783611842, 23.1097571509225, 27.297460760389054, 22.9521997996739, 24.557280574526104, 47.01121636799404, 27.02919602394104, 12.80243023804256, 1.122962970818792, 0.02047632767685822, 0.07590208069554397, 0.017591651396027634, 0.031818579948906384, 0.027796217573008368, 0.0080060762453026, 0.02386867707329137, 0.054999385361692736, 0.06047162440206323, 0.015540945543242353, 0.07749499593462263, 0.04643191383885486, 0.04518381991822805, 0.011634891703059631, 0.02634036980037178, 0.06745376331465584, 0.029186634213796685, 0.028424681796293174, 0.016684685867013674, 0.011741563345172575, 0.01961878494226507, 0.04701381190014737, 0.06652679626962968, 0.042574571179492135, 0.051339279261550734, 0.03543432682220425, 0.08871644522462573, 0.11603459077222006, 0.01180500297674111, 0.12764532917312213, 0.17858867985861643, 0.08385769344334092, 0.15123497907604488, 0.11874636954494885, 0.09473355127764599, 0.14056082256138325, 0.04867393942549825, 0.19091619551181793, 0.0998831367386239, 0.0767672196296709, 0.11078828692968402, 0.2407765228833471, 0.15923326489116463, 0.08478249596165759, 0.13778603502682277, 0.08474147173443011, 0.15370884990053518, 0.12178201308207852, 0.08995190143053021, 0.14905012345739774, 0.13324329735977308, 0.1779912704867976, 0.15146660379001073, 0.20189581492117473, 0.0838444959372282, 0.06650313575352941, 0.1414043637258666, 0.09513481653162412, 0.09101238381117582, 0.1736306380480528, 0.09541003033518791, 0.07484159152954817, 0.14068450592458248, 0.09376077633351088, 0.24454513351832116, 0.8268115307603563, 13.23510672364916, 39.321912493024556, 45.96916028431484, 30.22923925944737, 25.28885987826756, 28.3688417162214, 41.47466244016375, 39.02749994822911, 12.352698530469622, 3.502667031117848, 0.6725550623876708, 2.1460668657507216, 7.375839369637625, 9.02852920123509, 12.480765989848546, 9.88785982131958, 14.032814638955251, 12.631415963172913, 11.072518127305166, 4.120646544865199, 1.9996500824178969, 1.396828823855945, 5.538515491144998, 21.275281599589757, 32.95253358568464, 44.70990351268223, 50.252196652548655, 56.90841456821987, 54.82559823989868, 54.75954171589443, 53.654632227761404, 52.50024461746216, 54.277757099696565, 55.211535930633545, 55.23060526166643, 50.17365074157715, 48.132874488830566, 53.218928064618794, 54.50038433074951, 52.03790800912039, 50.337211336408345, 43.272619996752056, 38.54450634547642, 41.849354471479145, 44.470788206372944, 47.27427864074707, 48.296247482299805, 47.71735831669399, 49.26171704701015, 53.24157919202532, 52.065332548958914, 52.7792078426906, 52.1777127129691, 47.61162757873535, 44.41434798921858, 52.11597796848842, 51.99344996043614, 53.00877285003662, 48.52877589634487, 49.28101566859654, 45.8236927986145, 42.193467480795725, 39.941271441323416, 41.052614961351665, 39.74987983703613, 39.036709785461426, 37.8049887248448, 42.94425507954189, 44.751797676086426, 48.26693650654384, 48.666378021240234, 48.91046476364136, 48.55253873552595, 48.7686242376055, 50.81369795118059, 46.65285260336739, 46.55175978796822, 47.54054055895124, 44.785301889692036, 45.90328788757324, 45.766137395586284, 43.5051623071943, 43.50882053375244, 46.699082442692344, 42.71829271316528, 29.40152815410069, 19.25013358252389, 6.804238430091313, 2.9975887962750027, 2.4761503764561246, 3.862263015338353, 7.2683120880808145, 6.543796930994306, 6.763070787702288, 8.536316207477025, 9.648183447974068, 7.462353127343314, 8.425105946404592, 4.296335654599326, 0.5706507191061974, 4.5672537343842645, 14.448315177645002, 25.67801979609898, 31.609304359980992, 28.119401386805944, 29.43351071221488, 49.931585924965994, 33.805682046072825, 13.79771191733224, 1.13467980495521, 0.12844106076019152, 0.12098472086446625, 0.11901741714349814, 0.09510586344237838, 0.1867546181061438, 0.08710069728216954, 0.10515136404761247, 0.17862880841961928, 0.24090205186179706, 0.10049149088029351, 0.1983865267996277, 0.15789287324462617, 0.13503891815032276, 0.10582187199699027, 0.13568013374294552, 0.1815690363624266, 0.10865101018654448, 0.10130240129573004, 0.11734414978751115, 0.15167985377567156, 0.15304149713899406, 0.12858583299177034, 0.0897935652839286, 0.1127887438716633, 0.16521163337997027, 0.14117625382329735, 0.0903915853372642, 0.16664669423231057, 0.1747265128152711], [0.07905128385339465, 0.013654025321427201, 0.02533857730616416, 0.050788997539452145, 0.014909444875749094, 0.02551793786031859, 0.013595930001299297, 0.06682412352945123, 0.041468409821391106, 0.037167515605688095, 0.05281694193503686, 0.057076798352812014, 0.02174074375735862, 0.029954952986112664, 0.08667564259043761, 0.061974260556910715, 0.033892732579261065, 0.031193849364561693, 0.0427464814191418, 0.03709031528394137, 0.03602275578305125, 0.021557666527639543, 0.02807608782313764, 0.0368730721196958, 0.01625244379309671, 0.025985066812219362, 0.017074075061827898, 0.007034544292504766, 0.06101565342396498, 0.03323597853471126, 0.023307976445981433, 0.040381773308451684, 0.062235835806599686, 0.034667151381394694, 0.045345240006489415, 0.023205733093033944, 0.014067358320711978, 0.9231450472559247, 11.115906153406415, 28.560186420168193, 31.796405451638357, 21.324148280279978, 14.237638848168508, 16.14331259046282, 44.15760162898472, 29.88122136252267, 9.742168256214686, 2.746838948556355, 0.31880191607134684, 0.6711185223289898, 2.222893097570964, 3.464832352740424, 3.824948149068015, 14.487238117626735, 9.339699932507106, 4.186990550586155, 0.9940635732242039, 1.8674169608524867, 0.4862361858998026, 0.7012740841933659, 4.65735102551324, 17.299777712140763, 25.6869603906359, 38.159638677324565, 49.239937918526785, 53.09093182427542, 50.8236095564706, 51.20310626711164, 50.764563764844624, 51.84597444534302, 50.060752936771934, 50.436202321733745, 50.50090742111206, 51.04975605010986, 51.99047613143921, 50.445377417973106, 48.0366975239345, 43.687736647469656, 38.82935469491141, 39.86145748410906, 41.33792189189366, 44.54481431416103, 44.72181272506714, 46.82237127849034, 46.471129417419434, 47.30589294433594, 47.71648631777082, 49.721399443490164, 49.571738719940186, 51.28794377190726, 44.280511787959504, 38.98803765433175, 53.0010221345084, 49.510691847120015, 46.846714292253765, 45.34129326684134, 43.32587793895176, 41.395699637276785, 41.046260833740234, 38.0096618107387, 39.176629134586875, 37.24793079921177, 36.885193143572124, 36.706343037741526, 41.80668558393206, 43.2246287890843, 45.81159598486764, 46.606754779815674, 48.972477436065674, 46.77093029022217, 48.92190497262137, 44.6664251599993, 43.00115040370396, 45.0773902620588, 43.43677118846348, 43.80940655299595, 42.50048058373587, 43.59411314555577, 42.756420952933176, 41.74021911621094, 35.26603358132498, 27.630901336669922, 15.543278319495064, 5.253042672361646, 1.6469387859106064, 1.5134663879871368, 2.0036214121750424, 1.3209218169961656, 2.388606982571738, 3.7755477598735263, 3.976672487599509, 2.4841801055840085, 8.28431807245527, 5.04621217080525, 1.3999859115907123, 1.4155310945851463, 1.9844163741384233, 10.061982546533857, 20.559361798422678, 22.09579610824585, 20.320421934127808, 24.69339578492301, 22.117582184927805, 23.971307720456803, 15.254024812153407, 2.887622262750353, 0.025835378594430428, 0.056127765348979404, 0.061897748948207924, 0.016624652481238757, 0.06258737801441125, 0.07820840086787939, 0.015948075036119138, 0.025428559531324675, 0.012946898533430482, 0.0444698043034545, 0.07780964619347028, 0.027572753938979337, 0.05824291506516082, 0.05306700923080955, 0.04214657503845436, 0.02508283406496048, 0.014085780546468283, 0.02929199713149241, 0.04338042990171483, 0.06112887377717665, 0.11491114034184388, 0.03919788237128939, 0.08531538343855313, 0.06311666247035776, 0.02259781151743872, 0.04501988925039768, 0.009825226085792695, 0.040001189801841974, 0.03464836613940341, 0.011488915071822703, 0.017590806619929414, 0.04613933971683894, 0.045342227311006615, 0.031180590790297304, 0.02223711078321295, 0.025386061186769178, 0.016744895671893443, 0.0164462079493595, 0.01908566167445055, 0.05180380433531744, 0.05740636959671974, 0.09192868428570883, 0.05088793812319636, 0.045372646035892625, 0.03286226519516536, 0.03409436604540263, 0.024114157472337996, 0.018674927464287196, 0.06614025522555624, 0.05937752061124359, 0.029662534927151034, 0.020330083024288927, 0.053670542381171665, 0.08196419397635119, 0.008551311363199992, 0.00670800737238356, 0.023884113744965622, 0.007972979003430476, 0.018496138575885977, 0.09228305598454815, 0.06725927482226066, 0.016606842633336782, 0.038286284144435606, 0.03380461802173938, 0.059805459076804776, 0.014339341449418237, 0.03513425488823226, 1.9246375475611006, 15.546752418790545, 35.13518163136074, 31.22810534068516, 20.85645113672529, 16.272625514439174, 27.683909143720353, 45.53952537264143, 26.653413125446864, 10.966917668070112, 2.87702191727502, 0.3491332727883543, 0.47342414196048466, 0.7845012896827289, 4.8771273238318305, 7.885913576398577, 19.023132460457937, 14.244323015213013, 4.960007607936859, 3.5066509544849396, 3.2499124109745026, 1.2870654165744781, 2.080735125711986, 6.78932021345411, 20.07915094920567, 30.144721371786936, 41.23119408743722, 51.21519265856062, 55.01834126881191, 53.802048683166504, 52.93001849310738, 52.00930922372, 52.906054156167166, 52.3228987966265, 51.620477608272004, 50.9900849206107, 51.34487036296299, 52.99795797892979, 52.13676697867257, 50.02682835715157, 45.87694379261562, 40.65562963485718, 41.974738189152305, 43.26650905609131, 45.33875370025635, 46.46556738444737, 47.891636507851736, 46.997622217450825, 47.54317045211792, 48.34967565536499, 51.460147925785606, 50.268729891095845, 52.20817708969116, 44.1943610736302, 40.98645074026925, 52.2187557220459, 50.46451275689261, 48.02704300199236, 46.159627778189524, 44.7661109651838, 42.05002539498465, 42.284381185259136, 39.75332266943795, 40.34496177945818, 39.024182183401926, 36.55615772519793, 37.445798124585835, 42.065301009586875, 44.88425118582589, 46.47026784079415, 48.36716079711914, 49.86298983437674, 48.69952440261841, 49.046361105782644, 46.6274847303118, 43.23021861485073, 44.8991550718035, 43.82787486485073, 43.201539925166536, 43.70242861339024, 44.834960665021626, 43.77110808236258, 44.72308077130999, 38.39793757029942, 30.184534549713135, 17.095700434276036, 7.035077563353947, 2.9566031098365784, 2.5089391427380696, 3.134761001382555, 4.244544650827136, 4.335368897233691, 3.998229273727962, 4.6774217656680515, 4.263911017349788, 4.312197523457663, 2.255238047667912, 0.4332586686526026, 0.11781289534909384, 1.568499703492437, 9.862808091299874, 22.428081546510967, 25.52331641742161, 23.726880516324723, 27.893795115607126, 24.654784645353043, 31.072041852133616, 20.345664739608765, 4.654250826154437, 0.07263458174254213, 0.019558587011748126, 0.03561632348490613, 0.040511047800204585, 0.03214578989094921, 0.09294439692582403, 0.1177457475236484, 0.022877016803249717, 0.09679289827389376, 0.05150133717272963, 0.06119204538741282, 0.04410271346569061, 0.04675157168614013, 0.08286646234669856, 0.06934649603707449, 0.010185710536981267, 0.03970157587900758, 0.0059700979950970835, 0.008715159758659346, 0.055407507212034295, 0.06813366897404194, 0.010179384046101143, 0.09012373363865273, 0.020489781329940473, 0.023155667386682968, 0.027128308412751982, 0.019368895761934773, 0.031768972253693004, 0.039484112190880945, 0.029751514616821493, 0.17158147586243494, 0.10378655871110302, 0.1089553874252098, 0.09587125772876398, 0.13384084243859562, 0.1242274668599878, 0.07962128719581024, 0.23863403499126434, 0.1549407709389925, 0.1119215354057295, 0.20567670703998633, 0.1622800092611994, 0.07854829262942076, 0.134365282154509, 0.09678496619952576, 0.26924668518560274, 0.12456391166363444, 0.18587805942765304, 0.16508948350591318, 0.08267804674272027, 0.15075802324073656, 0.08382108647908483, 0.13925150781869888, 0.20209519565105438, 0.04701478220522404, 0.1246982208852257, 0.11264856532216072, 0.1021323310477393, 0.16416161400931223, 0.17762365378439426, 0.224283155053854, 0.12642106200967515, 0.12991029263607093, 0.08793670670794589, 0.2420121080109051, 0.11462639990661826, 0.12709458943988594, 2.340504820857729, 17.811788729258947, 42.092194012233186, 42.31963634490967, 31.99118082863944, 21.092288630349294, 24.205296993255615, 51.90340825489589, 35.584611960819785, 12.346971477781024, 4.074180466788156, 0.7886648891227586, 1.309851382459913, 6.352262020111084, 9.885872636522565, 11.44449862412044, 26.27815134184701, 15.778153487614222, 10.6199654511043, 6.246077477931976, 5.190520175865718, 1.2608828672340937, 1.4493510169642312, 6.952530358518873, 20.57855098588126, 32.217323848179404, 42.34279121671404, 51.312391008649556, 58.42442812238421, 54.94313744136265, 54.569459847041536, 54.27972343989781, 55.648056507110596, 52.35999870300293, 50.127976758139475, 49.86291340419224, 51.94689702987671, 55.01861572265625, 54.16481065750122, 52.20106560843331, 47.097735336848665, 42.504882267543245, 44.239368030003135, 46.17950310025896, 47.83333069937569, 50.37892484664917, 49.62332909447806, 51.76348890577044, 50.31391750063215, 51.44519887651716, 53.700195040021626, 52.62661497933524, 52.60215384619576, 46.96178340911865, 42.51270246505737, 51.86245904650007, 51.42022010258266, 50.82011808667864, 49.349698611668174, 46.39989995956421, 44.205815179007395, 44.428435461861746, 42.107834407261436, 42.67334829057966, 40.89153834751674, 39.29972342082432, 40.53540842873709, 43.66171564374651, 46.385197571345735, 48.483254773276194, 50.2216488974435, 50.57142121451241, 50.771063804626465, 50.264484541756765, 46.333628041403635, 44.81314679554531, 45.181078229631694, 44.27546044758388, 44.296325887952534, 44.64025477000645, 45.5366210256304, 43.565677642822266, 45.03453377314976, 37.3183890070234, 30.18661900929042, 17.775171722684586, 6.932236407484327, 2.697718007223947, 3.6720243777547563, 5.483002858502524, 5.279570894581931, 7.781705362456186, 7.756069115230015, 8.960470727511815, 7.6761109828948975, 14.401007499013629, 8.999415380614144, 2.9282075592449734, 1.6510317091430937, 2.8268070689269473, 12.539644156183515, 25.278651237487793, 29.599722044808523, 28.8688861983163, 35.53344195229666, 31.37594563620431, 32.76069382258824, 21.6630414554051, 4.776041890893664, 0.14929594312395367, 0.0765856843707817, 0.10269603079983167, 0.08372497877904347, 0.1492129990032741, 0.2335231735238007, 0.21347234158643655, 0.1427868109728609, 0.1400259334061827, 0.11929381159799439, 0.1981886931295906, 0.0979677816586835, 0.16265880822071008, 0.22048998145120485, 0.11433234997093678, 0.06742848788521119, 0.0923282192753894, 0.11449613475373813, 0.07625789088862282, 0.15219913662544318, 0.20474902753319058, 0.1258474692170109, 0.15985572577587195, 0.15803712978959084, 0.10948127242071287, 0.13623023565326417, 0.1965659223496914, 0.16004294715821743, 0.1608436999044248, 0.1427711368139301], [0.07023275098098175, 0.022888222809082696, 0.02997452872140067, 0.02608779531770519, 0.019987441499584487, 0.028201991692185402, 0.09988355064498526, 0.052445084388766966, 0.04550657867054854, 0.091624870231109, 0.0168244148870664, 0.055154688456760984, 0.05710927303880453, 0.03352790804845946, 0.02615733497909137, 0.018432273163593242, 0.05907753349414893, 0.0696725592549358, 0.029912995773234537, 0.03421673644334078, 0.030131646897643805, 0.008117625706030853, 0.026448796303676705, 0.016942439268210104, 0.014550287808690752, 0.029594226806823696, 0.012807944739636565, 0.03340430950213756, 0.03896063260201897, 0.0020767476027166204, 0.09242554833846432, 0.06474855276090757, 0.06097053084522486, 0.05733455345034599, 0.017777466514546956, 0.035528337849037986, 0.04492000550297754, 0.08387149484562022, 1.6540965161153247, 16.304919004440308, 32.43485804966518, 28.659272943224224, 22.688183886664255, 15.959784609930855, 26.23930048942566, 47.752676010131836, 22.604140213557653, 10.185427716800145, 3.087437472173146, 0.892570476446833, 0.828460370855672, 2.7148381514208655, 10.077858311789376, 16.550669840403966, 16.851582424981252, 3.291124565260751, 2.0220806045191626, 1.9959154256752558, 1.4637722202709742, 1.7943948677607944, 0.6971133617418153, 4.779869045530047, 15.608808517456055, 23.341057470866613, 34.34266315187727, 48.93265730994088, 53.80237177440098, 52.957984992435996, 52.36266333716256, 50.442292417798726, 50.78591905321394, 52.58145863669259, 50.67225694656372, 52.080264227730886, 51.52083696637835, 50.30018786021641, 46.36367205211094, 42.090957232883994, 42.43600477491106, 44.34594644818987, 45.55128172465733, 46.437250001089915, 46.6384003502982, 45.293465341840474, 45.13493871688843, 47.43699850354876, 47.41839817592076, 49.52335841315133, 49.31959554127285, 54.46205806732178, 44.4429155077253, 38.81964806147984, 53.295684814453125, 45.207328523908345, 46.83448198863438, 45.3311766896929, 45.37587445122855, 43.361129624503, 42.711726665496826, 41.15685878481184, 42.5761707850865, 40.5770594051906, 38.12321274621146, 40.01584298270089, 44.15047972542899, 44.549980299813406, 48.031805992126465, 47.444370542253765, 47.70380932944161, 45.62471376146589, 49.11267818723406, 43.10209730693272, 46.3360355922154, 44.118622234889436, 46.291824204581125, 43.78990643365042, 44.99809741973877, 43.796854632241384, 40.21877901894705, 30.754203455788748, 20.048587560653687, 10.784003734588623, 4.430525779724121, 1.5560064081634795, 0.8289210689919335, 1.635938701885087, 1.7662881016731262, 3.7749975493976047, 3.3657189054148535, 3.4839789824826375, 2.0067663405622755, 3.3882110927786147, 1.9875200475965227, 3.0556724795273373, 0.6811904247317995, 1.304474019578525, 9.23210620880127, 20.750612701688492, 27.426308155059814, 19.532532691955566, 19.276500259126934, 25.168711628232682, 21.629995822906494, 11.850432361875262, 2.8909256969179427, 0.1652400911386524, 0.05621138121932745, 0.02433297992683947, 0.058367195539176464, 0.03789402983550515, 0.0060087295382150584, 0.012374896905384958, 0.08287146993513618, 0.030442432899560248, 0.0740005202325327, 0.0399414346154247, 0.03319735971412488, 0.01890807718570743, 0.032637490292212794, 0.025740892593083636, 0.0030496035469695926, 0.021594929974526167, 0.029125270899385214, 0.058719104155898094, 0.06043259506779058, 0.036690227288220606, 0.0372737436555326, 0.05310376886544483, 0.08146543002554349, 0.05747676760490451, 0.024372474057599902, 0.011228141341624516, 0.10001093202403613, 0.0377625195708658, 0.019124450128791586, 0.035411171814692874, 0.022071670374966094, 0.011602870787360837, 0.06542040420962231, 0.008121817356108554, 0.03988159800480519, 0.014927968881758196, 0.04042734032762902, 0.0510969133382397, 0.035196405303265364, 0.014206888021102973, 0.019959326401086788, 0.036465510060744624, 0.08796950709074736, 0.04510360011564834, 0.04103538573586515, 0.04882275572578822, 0.0729241194203496, 0.017362257365935614, 0.026253379914643507, 0.024212093824254613, 0.05789332025285278, 0.06207943348480122, 0.05012481014377304, 0.012930743462805237, 0.009139753894747367, 0.0099980727037681, 0.053775199622448, 0.06758854751076017, 0.005685369858318674, 0.043385413741426807, 0.04379318953890886, 0.0767703273200563, 0.06478459654109818, 0.034522335045039654, 0.010274725849740207, 0.05040772192712341, 0.062092461357159276, 0.052685994854463, 3.059355676174164, 21.724845681871685, 37.30159173692976, 30.07609748840332, 15.16748673575265, 14.088628649711609, 38.86067022596087, 49.85660096577236, 21.327346188681467, 12.08490800857544, 3.072011385645185, 0.25677844136953354, 0.20190395734139852, 0.6341061198285648, 5.364655928952353, 10.93452342918941, 8.290968367031642, 4.268445151192801, 3.70124328987939, 3.2972989082336426, 3.3966674847262244, 2.1464542278221677, 1.3769402567829405, 7.901656457356044, 18.28663730621338, 26.713822501046316, 39.448592049734934, 52.243758814675466, 54.98223842893328, 54.64904451370239, 53.209589685712544, 51.49096666063581, 50.829984528677805, 53.357614108494346, 50.2285658291408, 53.93584319523403, 53.481903484889436, 51.24400336401803, 48.93600286756243, 42.77766507012503, 43.89277451378958, 45.67614780153547, 47.50415284293038, 47.39334297180176, 47.698368889944895, 47.50532708849226, 48.35875347682408, 48.25791427067348, 48.83873503548758, 50.158305644989014, 50.901568344661165, 54.30594941547939, 44.8050035067967, 42.11528982434954, 52.06098297664097, 47.686629908425466, 49.65082311630249, 47.80492646353585, 46.2799323626927, 43.75307750701904, 43.99415915352957, 43.64230237688337, 43.087405341012136, 41.4489541053772, 40.46396705082485, 41.031186716897146, 45.034467765263145, 46.343789781842915, 50.18768262863159, 49.20992170061384, 49.4340705871582, 47.443342208862305, 48.99349226270403, 43.22666808537075, 46.039403097970144, 44.97790595463344, 47.39272805622646, 44.084183488573345, 45.09577866962978, 46.18236575807844, 41.730158124651226, 33.56466293334961, 22.51642268044608, 13.87817292554038, 7.177328033106668, 1.9359544260161263, 1.4033591534410204, 2.5931417558874403, 2.6798895810331618, 4.8030343396323065, 3.6285701266356876, 3.8604200056621005, 3.4201018043926785, 3.3527222999504636, 1.8218663079398019, 0.4154906863612788, 0.056359776827905855, 1.1876668759754725, 8.469910536493574, 22.5323166847229, 27.111806631088257, 21.15001426424299, 23.194646767207555, 29.32271821158273, 26.48391703196934, 17.472872972488403, 5.639548812593732, 0.43173790882740704, 0.05944664975894349, 0.05546852447358625, 0.032352234170372994, 0.022621930044676577, 0.06874509687934603, 0.004940185737463513, 0.06653869777385678, 0.05721381492912769, 0.08579233927386147, 0.037120018154382706, 0.04163409110956958, 0.04071261341284428, 0.04592538405475872, 0.035607187010880025, 0.05141505805243339, 0.06795835588127375, 0.016707474465614984, 0.010455197504987674, 0.025373126612976193, 0.04129695759287902, 0.029242382650928836, 0.03996784998370068, 0.06889177579432726, 0.04695662157610059, 0.03756490642470973, 0.016198354374085153, 0.04561991776738848, 0.048640334978699684, 0.017522103252953718, 0.025260013129029955, 0.20205536564545973, 0.18990922240274294, 0.16569969004818372, 0.06923006621322461, 0.22386582887598447, 0.09099607182932751, 0.14771024749747344, 0.17720110288688115, 0.1395151593855449, 0.20909086455191883, 0.1512292522404875, 0.14646832485284123, 0.1696785515440362, 0.1955805266542094, 0.1105639903939196, 0.1411147785506078, 0.17112566317830766, 0.09496564418077469, 0.1222922442747014, 0.11667115161461489, 0.1452333504068, 0.1262298779828208, 0.12380906859678881, 0.0979944955823677, 0.07452911936811038, 0.14522866851517133, 0.14620810667318956, 0.14787958269672735, 0.1086328322333949, 0.138325606073652, 0.235356439437185, 0.12552238308957644, 0.25366966532809393, 0.23323650604912213, 0.15733181977910654, 0.1426103782973119, 0.16991084122232028, 0.23867083873067582, 3.110019551856177, 25.274082796914236, 45.898128850119456, 40.12839685167585, 30.675310134887695, 24.019276346479142, 35.354848929813926, 54.88780893598284, 28.773056643349783, 13.577983822141375, 4.9449756145477295, 1.450340375304222, 1.47320613690785, 7.2060436350958685, 20.123555149350846, 23.89155455998012, 27.56963038444519, 10.520072068486895, 6.548609861305781, 5.659069342272622, 4.0941469839641025, 3.348363390990666, 1.3904976035867418, 5.762151948043278, 17.410401718957083, 28.39641911642892, 40.69055822917393, 52.128585474831716, 58.26926442555019, 55.09749514716012, 55.140455859048025, 50.53895575659615, 50.57563877105713, 53.09369373321533, 51.73063087463379, 54.47730588912964, 55.999750001089915, 52.9407673563276, 50.15285478319441, 45.04748521532331, 45.29617861339024, 47.403827803475515, 51.00325870513916, 50.1347964150565, 51.17760290418352, 49.18298700877598, 49.72389037268502, 51.886774267469136, 52.52581398827689, 52.748733043670654, 54.45152112415859, 57.15442248753139, 47.40880618776594, 44.74398790087019, 53.16467653002058, 50.33834041867937, 51.066786084856304, 49.58377647399902, 48.063955307006836, 47.92845153808594, 46.61359180722918, 45.42728417260306, 46.06773437772478, 45.10194172177996, 41.98833581379482, 44.55103990009853, 47.877083505902974, 48.7358078956604, 51.85729653494698, 50.665579727717805, 51.011930056980674, 48.17560938426426, 50.319264139447895, 44.80839422770909, 47.361165864127024, 44.51110165459769, 48.6255920955113, 45.40479632786342, 45.66691017150879, 45.10977234159197, 41.94173771994454, 32.86338472366333, 22.56516776766096, 13.228062987327576, 6.386766774313791, 2.5563949048519135, 1.7777971412454332, 4.579832145145961, 6.13651567697525, 9.188359481947762, 9.497291156223842, 9.345281073025294, 6.786526169095721, 7.568455593926566, 5.549296924046107, 5.464171937533787, 1.3083310297557285, 2.1911148599215915, 11.235266651426043, 25.996457474572317, 34.72162485122681, 26.476513726370676, 28.05011568750654, 33.879332951136995, 31.822165897914342, 17.91672737257821, 5.785124429634639, 0.5745667346886226, 0.1121235013540302, 0.17528665704386576, 0.2169398455215352, 0.08350275856043611, 0.12529094836541585, 0.09899798102144684, 0.20456157544893877, 0.13157817242400988, 0.20817991771868297, 0.1184481398335525, 0.13997725530394486, 0.10131766833364964, 0.09539809490420989, 0.095527159050107, 0.1074942776135036, 0.16364344395697117, 0.12760054586189135, 0.15549068285950593, 0.11811298424644129, 0.16200060211122036, 0.12814011690872057, 0.1276547336684806, 0.15725291972713812, 0.21857256362480776, 0.11352749887321677, 0.112153621523508, 0.1684821450284549, 0.09493769532335655, 0.10501688519226653, 0.13167957269719668], [0.023486230988055468, 0.07346842664160899, 0.04981971365798797, 0.02378520878430988, 0.03916455273117338, 0.05997727771422692, 0.007208245440519282, 0.0708897425127881, 0.08160053313310657, 0.05246009697605457, 0.05318338137918285, 0.04179117875173688, 0.03375828765066607, 0.011032328009605408, 0.04156697042552488, 0.027379834558814764, 0.04316796023132546, 0.0528221971887563, 0.03388961471085038, 0.00462805326761944, 0.028550127654203346, 0.02256407984532416, 0.08791264585618462, 0.016046057189149514, 0.07130814756133727, 0.05509652104228735, 0.0730695091187954, 0.049558392858930995, 0.03599991290164845, 0.019625451548823288, 0.03973869513720274, 0.09675667128924813, 0.07057131959923676, 0.0426579733113093, 0.030619649283055748, 0.06259610397475106, 0.02385662459502263, 0.03510078275576234, 0.011375071314562644, 2.8929343777043477, 17.08898500033787, 33.80289581843785, 30.102764674595424, 21.866243260247366, 8.65595029081617, 24.258506298065186, 58.50342219216483, 19.017759765897477, 14.271311555589948, 4.4768429057938715, 0.19773832229631289, 1.4408359995910098, 3.244644807917731, 13.344202995300293, 7.09821844952447, 2.3192557096481323, 3.302152007818222, 1.4925923709358488, 2.5036893444401875, 1.0777659160750253, 0.32617726602724617, 0.9788419157266617, 3.842214856828962, 15.02476726259504, 21.843784945351736, 28.280236550739833, 40.47673436573574, 49.13049684252058, 50.64088582992554, 50.54317331314087, 51.457875864846365, 50.78168412617275, 50.870784350803916, 53.922975131443565, 53.22510848726545, 48.85690457480294, 49.611569268362864, 45.841813700539724, 46.54876511437552, 46.95871925354004, 46.99425234113421, 47.256265435900005, 47.087514536721365, 46.96562576293945, 46.01774903706142, 46.35257577896118, 46.658883639744346, 48.93419286182949, 49.22879648208618, 51.76394053867885, 46.014792578560964, 35.93373114722115, 54.11673954554966, 51.24267625808716, 49.4204694884164, 46.133644989558626, 45.926383699689595, 44.572721753801616, 44.363195351191926, 43.63232823780605, 42.42915037700108, 40.38128696169172, 43.12519311904907, 43.26539387021746, 46.935046740940635, 48.47719594410488, 48.46252134868077, 50.00053289958409, 46.85028914042881, 50.94616535731724, 44.15411710739136, 45.41275896344866, 45.75286981037685, 42.93598672321865, 45.447569438389365, 43.16289751870291, 40.03254297801426, 32.26248019082205, 22.00958286012922, 13.05360414300646, 6.483206033706665, 2.300908339875085, 0.5798511654138565, 0.4817668657217707, 0.8339225777557918, 1.5913365866456712, 1.8965399009840829, 4.105388300759452, 2.3251712322235107, 2.049118867942265, 2.8810260338442664, 2.251250650201525, 1.4371279414211, 0.033073418507618565, 1.5081161665064948, 6.810430577823094, 17.520207575389318, 26.691482305526733, 20.105078152247838, 19.241898230143956, 20.401311125074113, 22.30198563848223, 13.181633387293134, 3.967966829027448, 0.1838086633277791, 0.04549360168831689, 0.026016175946486846, 0.013137233543342777, 0.027320841027955924, 0.022305676746847372, 0.05178523961720722, 0.03822464941601668, 0.03634279700262206, 0.00190669739718682, 0.03550814125420792, 0.05568172356912068, 0.03054978053218552, 0.027236519481188486, 0.06042889705193894, 0.07097221165895462, 0.01764228198278163, 0.0315459717198142, 0.015585560917056032, 0.021315850217693617, 0.06653990556618997, 0.04777313669079116, 0.032495635761214156, 0.024733381745006357, 0.011930860196506339, 0.045299496568207226, 0.007952418544196656, 0.029270446859300137, 0.02178518780108009, 0.08157232643238135, 0.07470279719148364, 0.06140956335834094, 0.03267921001783439, 0.03869716763230307, 0.036452977518950186, 0.018214985894571458, 0.05379813410607832, 0.042594211375606914, 0.026583044457116296, 0.05574887139456613, 0.03255567932501435, 0.029855364401425635, 0.018892321602574418, 0.01864881913310715, 0.05139734150309648, 0.03018305271065661, 0.02113081541444574, 0.014387420744502118, 0.08201019186526537, 0.024319984284894805, 0.06887886327292238, 0.02659660667580153, 0.04444638127461076, 0.019571781125185744, 0.024276692054367492, 0.06424692539232117, 0.05078227325741734, 0.013491106518943394, 0.06325031351298094, 0.03681269607373646, 0.06401114125869103, 0.05269498544346009, 0.01635422743856907, 0.014926666094522392, 0.030633447292659963, 0.036578095983713865, 0.04138816287741065, 0.08252315755401339, 0.032494807948491404, 0.05198505460949881, 0.06164687419576304, 5.011155469076974, 23.890494959694998, 37.318430696214946, 30.495046070643834, 21.0989727973938, 14.491706677845546, 35.523127351488384, 51.98373985290527, 18.23652342387608, 17.71956181526184, 4.08624210527965, 0.2024202003542866, 0.3560799243194716, 1.0109607236725944, 1.566368886402675, 6.541216543742588, 3.530878020184381, 3.911223496709551, 4.890552112034388, 4.538775239671979, 2.2801970626626695, 1.200870841741562, 2.024372858660562, 6.243942643914904, 18.35949264253889, 23.99857939992632, 34.187655789511545, 42.27215930393764, 51.124747957502095, 50.738733836582725, 52.652879170009065, 51.749912125723704, 51.956909384046284, 50.50132083892822, 56.14013835362026, 54.19689049039568, 51.53785310472761, 49.5324501310076, 47.64458635875157, 47.30588599613735, 47.299827166966026, 48.66303593771798, 48.549832412174766, 48.15239545277187, 49.47443962097168, 47.294126170022146, 47.20968471254621, 48.71783985410418, 51.58296775817871, 52.08173377173287, 52.9623623575483, 45.93427685328892, 38.211013657706125, 54.5445852960859, 51.28812095097133, 50.095459188733784, 49.37645265034267, 47.55164725439889, 46.86636727196829, 45.886466298784526, 45.574259417397634, 43.33954504558018, 41.800953320094514, 43.42120374952044, 45.06187840870449, 48.76800584793091, 49.70535952704293, 49.80665384020124, 49.940462248665945, 47.502023220062256, 50.42343500682286, 48.56592444011143, 44.67083726610456, 45.91328287124634, 43.627488817487446, 45.96540130887713, 46.08758190699986, 41.919010162353516, 33.661746638161794, 25.35441439492362, 16.554090091160365, 9.85514770235334, 3.9547040207045416, 1.2046479476349694, 0.739565335214138, 2.2030939885548184, 3.3345438582556586, 3.5654811348233904, 4.016552976199558, 3.344389021396637, 4.019000479153224, 2.7039207943848202, 2.7878096529415677, 0.9133050952638898, 0.32635466222252163, 0.7285866386124066, 6.757538718836648, 18.180960416793823, 31.3681150163923, 25.66706074987139, 21.997882093702042, 22.555471556527273, 26.430335998535156, 18.29919270106724, 6.492527042116437, 0.43843608083469526, 0.06500625357564006, 0.010962381227208036, 0.03743925530995641, 0.0736416702025703, 0.016314251547945396, 0.018555941259754554, 0.00850684441892164, 0.04953902746949877, 0.041135513755892, 0.0404961268151445, 0.016530236029731374, 0.00575120302216549, 0.015506520069071224, 0.02773088652507535, 0.078043123308037, 0.020160142232530882, 0.026287193010960306, 0.054958900569805076, 0.039371380382882695, 0.050884535270077844, 0.06682928718094315, 0.07775252033025026, 0.022648684680461884, 0.007499143581039139, 0.05683471741420882, 0.04012764837326748, 0.0075224249656977394, 0.08114714281899588, 0.05555402667128614, 0.04800992166357381, 0.05644919756533844, 0.07918582377689225, 0.1944814356310027, 0.1191247206713472, 0.11151080458824124, 0.11465217066662652, 0.1366634259798697, 0.06887697694557053, 0.1914282723196915, 0.19457701407372952, 0.15396703247513088, 0.09176122862845659, 0.08675704643662487, 0.1189583031726735, 0.13700362986751966, 0.15710892102548055, 0.054439088462718895, 0.18814873615545885, 0.12389385833271913, 0.15846354833671025, 0.0581624475972993, 0.1977711362498147, 0.14225949426846846, 0.15254935568996839, 0.1546444682670491, 0.1982695609331131, 0.09840064628848008, 0.1500795017927885, 0.09722605467374835, 0.09076130549822535, 0.17260235893939221, 0.09236347595495836, 0.16967006985630306, 0.16303162250135625, 0.1153797230550221, 0.19618975610605308, 0.16866691011403287, 0.11231716881905283, 0.1576097612934453, 0.2173442252512489, 5.2933244194303235, 26.114924260548182, 46.601835455213276, 40.652763502938406, 29.38416460582188, 14.77356903893607, 31.53967993600028, 66.29607704707554, 25.519750254494802, 17.686012438365392, 6.990032391888755, 0.6245332935026714, 3.084905288049153, 7.538611343928745, 24.024848801749094, 16.412728990827286, 8.365087406975881, 8.66576201575143, 6.487228606428419, 6.86645781142371, 3.252913598503385, 0.9636838776724679, 1.6021143283162798, 5.509602734020778, 18.06978576523917, 26.246008975165232, 35.76225308009556, 42.58167723246983, 50.17140647343227, 50.46348442350115, 51.9911778994969, 51.991337708064485, 50.616674831935335, 49.688249588012695, 57.76941796711513, 56.04398570741926, 53.113211223057334, 53.60255895342146, 50.114924567086355, 50.275896957942415, 49.73526804787772, 50.614684173039024, 50.68986020769392, 50.67964635576521, 51.06126226697649, 50.22777026040213, 49.86151681627546, 51.03917741775513, 53.162553855351035, 52.9758175441197, 52.95530298777989, 47.49093042101179, 41.009775842939106, 53.20497260774885, 52.79399708339146, 53.05097620827811, 50.37100042615618, 50.022579533713206, 50.045421736580984, 48.18524306161063, 47.086632115500315, 46.0334415435791, 43.705176625932964, 47.02668653215681, 47.51741695404053, 49.89435747691563, 51.53506340299334, 52.60026741027832, 52.00329903193882, 46.75331660679409, 49.635547501700266, 47.35235207421439, 47.744553565979004, 48.007056508745464, 45.164743014744346, 47.02018996647426, 46.761921950748985, 44.00172921589443, 35.377246447971885, 24.58637615612575, 15.024711677006312, 8.416871462549482, 3.4092606604099274, 1.183756342955998, 1.1243356743029185, 2.4153293200901578, 4.281142549855368, 6.532559522560664, 10.132835933140345, 5.161202686173575, 6.583324798515864, 7.792434249605451, 5.798576142106738, 4.306298068591526, 0.49195726748023716, 2.7450120065893446, 8.754894375801086, 22.101722921643937, 34.48616082327706, 28.132708924157278, 28.08093442235674, 29.524580751146587, 31.01593862261091, 19.521349566323416, 5.890224618571145, 0.42589444667100906, 0.18513887694903783, 0.13655306904443673, 0.08756896108388901, 0.2828486253108297, 0.14906296133995056, 0.11203373117106301, 0.13384473722960266, 0.10791255374039922, 0.1466097179800272, 0.25627602690032547, 0.10724250040948391, 0.08899541811219283, 0.1212440976606948, 0.1679369421409709, 0.17854468364800724, 0.12585795936839922, 0.15217078743236406, 0.104386702579047, 0.1278495139309338, 0.1544164397886821, 0.14092303812503815, 0.11424065274851662, 0.1401787937751838, 0.0759577409231237, 0.10045943010066237, 0.09487432693796498, 0.12036580193255629, 0.11156977606671196, 0.12869130447506905, 0.132251930556127, 0.17545644007623196], [0.018629776047808782, 0.06482262842889343, 0.04308664459469063, 0.027645241835021546, 0.07159110344946384, 0.017014945823965327, 0.03167877798633916, 0.018091626531843628, 0.052118094970605204, 0.03950649706114616, 0.047947391268930266, 0.05118963175586291, 0.03203481548864927, 0.017230166953855326, 0.06316579519105808, 0.042485560955745835, 0.013301930107575442, 0.016710460019697036, 0.012479890869664294, 0.0738153208845428, 0.021634269738569856, 0.022529335459694266, 0.101959487822439, 0.03702596980812294, 0.007199843480650867, 0.028667609207332134, 0.08292746943022523, 0.016382398516205803, 0.05322445310386164, 0.0679795126031552, 0.021627401267843585, 0.05593701897721205, 0.03367210691794753, 0.022881581647587673, 0.04014805192127824, 0.01735587404774768, 0.06945643228079591, 0.09703320823609829, 0.009180812048725784, 0.20536002117608274, 3.4367881204400743, 16.07789703777858, 36.66844408852713, 24.706566095352173, 19.507833583014353, 13.647186143057686, 28.489669152668544, 40.600196906498496, 19.666737147739955, 15.727515016283308, 5.971335283347538, 0.13265811518899032, 0.6910210943647793, 0.4697108726416315, 3.243604749441147, 2.0086436569690704, 2.428051905972617, 4.4683235457965305, 3.555848543133054, 2.3565065222127095, 1.4639057559626443, 1.5451387741736002, 0.5902314484119415, 3.6071757546492984, 10.229727693966456, 18.257517405918666, 24.162537779126847, 34.747597217559814, 41.11243895121983, 45.448854855128694, 50.9357465335301, 51.20116424560547, 52.37342957087925, 56.37371941975185, 54.044290678841726, 50.634760992867605, 50.793367522103445, 47.681974615369526, 48.63299192701067, 48.032087394169395, 46.75672122410366, 48.20674078805106, 45.43491676875523, 47.0155485698155, 45.0053721836635, 45.97075489589146, 47.36119713102068, 50.55423484529768, 50.75255727767944, 55.597470147269114, 47.73832450594221, 39.38629797526768, 45.76331295285906, 46.4642402785165, 51.369310651506694, 47.24622528893607, 48.53570672443935, 43.402388027736116, 46.875663961683, 46.00182376589094, 45.41750110898699, 45.31555019106184, 46.040295941489084, 48.042464528764995, 48.64254222597395, 47.952280385153635, 51.746121883392334, 47.44742774963379, 54.228640283857075, 43.73831605911255, 39.88461235591343, 44.6532826423645, 46.33948884691511, 46.21523073741368, 41.913118089948384, 31.69865471976144, 19.287240437098912, 12.898053084100995, 7.443082298551287, 2.408800401857921, 1.5778860683952058, 0.5913449515189443, 1.0750769632203239, 0.5700301581195423, 1.5930029600858688, 3.0936102952275957, 1.6251264363527298, 2.3788855842181613, 1.8454280836241586, 2.0080899723938535, 1.4146790717329298, 1.6874093285628726, 0.5257189444133213, 1.1339492670127322, 6.093930167811258, 15.04565007346017, 24.872023548398698, 23.358664206096105, 19.297572408403667, 24.990229776927404, 25.542988504682267, 13.046642916543142, 2.931297553437097, 0.25736575414027485, 0.04012210134949003, 0.026793899214161292, 0.06005029486758368, 0.018772582224171077, 0.006191296170332602, 0.021504628837906888, 0.025326718210375736, 0.0140901528564947, 0.01524602369006191, 0.050036407208868434, 0.08589869963803462, 0.023358115094846914, 0.0628164785781077, 0.03008260577917099, 0.026789339458835975, 0.0385342920864267, 0.01998980449778693, 0.02455241815187037, 0.007925451866218021, 0.07427926241819348, 0.0253441056702286, 0.03869561378711036, 0.06971872677760464, 0.10800842395318405, 0.018089394151632274, 0.06189061075981174, 0.008937524165958166, 0.030327305862946168, 0.029154322376208644, 0.0365082475888942, 0.018187193100207617, 0.013815462373064032, 0.01044497876760683, 0.06693321838974953, 0.063387635430055, 0.0384366983946945, 0.04113519484443324, 0.08826599975249597, 0.024081134869317924, 0.017626321142805473, 0.07244962666715894, 0.0230660396960697, 0.014480324062917913, 0.030643024814448187, 0.014697916672698088, 0.048935256831880124, 0.04035481511216078, 0.011632243720149356, 0.042087779979088476, 0.0065198699677629125, 0.011978039584521736, 0.02920858821432505, 0.05925745383969375, 0.042732235576425276, 0.05743493592100484, 0.018455312820151448, 0.021228561776557138, 0.03986912653116243, 0.012454913995627846, 0.019926137556987147, 0.018188163405284286, 0.0245696224072682, 0.025817031007526175, 0.049243542432252846, 0.014138082025705703, 0.02699434694035777, 0.05729796684214047, 0.01623230826641832, 0.09219426289200783, 0.02486944497962083, 0.06760118861815759, 0.41741810579385075, 5.936696342059544, 22.703108617237636, 38.85131795065743, 25.85654854774475, 14.354286074638367, 16.178319352013723, 52.08218540464129, 38.07223033905029, 21.144921234675817, 21.882517678397043, 4.8735902564866205, 0.10502539402140038, 0.15865295460181578, 0.6412332888160432, 1.31890184538705, 2.6061400984014784, 4.948499654020582, 4.575832154069628, 4.493405674185071, 2.5359886969838823, 2.656507807118552, 3.8950090067727223, 1.0365468135901859, 5.6637320177895685, 13.499257258006505, 22.375567061560496, 28.53498182977949, 37.46952622277396, 43.066522530147004, 48.039059911455425, 50.46108382088797, 51.53759602137974, 52.16729736328125, 57.85584660938808, 56.73528977802822, 53.32270635877337, 51.809329645974294, 49.76401274544852, 50.05760540281023, 49.37239490236555, 49.153585706438335, 49.77899653570992, 48.305294036865234, 47.89584711619786, 46.34091322762625, 48.342133385794504, 48.51048476355416, 52.34614052091326, 52.72138493401663, 56.90322773797171, 48.134545530591694, 41.56143501826695, 48.0223251751491, 49.94411700112479, 53.08809001105172, 48.424292360033306, 49.532172203063965, 45.27214479446411, 48.98588398524693, 47.50589336667742, 47.92106907708304, 45.30015645708357, 48.53681148801531, 48.50186899730137, 49.03511892046247, 48.97035823549543, 52.063988072531565, 48.715498311179026, 52.48300266265869, 49.6348283631461, 42.06455060413906, 45.3910527910505, 46.322437967572895, 46.65297072274344, 44.00907693590437, 35.32757725034441, 23.607977730887278, 17.54688170978001, 9.761621475219727, 4.283358590943473, 2.5161090322903226, 1.440467853631292, 1.8015808250222887, 1.8270368533475059, 3.5601342788764407, 4.388906504426684, 3.25181382894516, 3.787351880754743, 4.400364952428, 4.939672836235591, 2.2088488340377808, 0.4086985508246081, 0.21937917891357625, 0.7972253412008286, 6.037528600011553, 16.15337531907218, 28.248893226896012, 27.554102897644043, 21.058992862701416, 26.23826347078596, 27.17600277491978, 18.18237611225673, 5.9183752451624185, 0.7073925701635224, 0.08861254794257027, 0.0005546256184710988, 0.11953625216015748, 0.05135378634024944, 0.034544282260217836, 0.07042544814092772, 0.05639627183388386, 0.03023064515686461, 0.0254537755889552, 0.04392941562192781, 0.065954316274396, 0.05827703180589846, 0.054107420545603545, 0.02689503994770348, 0.030342623790992156, 0.022945173949535404, 0.05600763750927789, 0.03186977202338832, 0.025460209797269533, 0.06231985879795892, 0.018120508374912397, 0.0578525945810335, 0.04466731566935778, 0.04700103508574622, 0.04535675474575587, 0.03135674526648862, 0.06151335886014359, 0.029232957799519812, 0.004631615576467344, 0.013470182195305824, 0.053643322948898585, 0.04729807736085994, 0.07243600168398448, 0.16328429537160055, 0.15887038436319145, 0.055633886850305965, 0.12098552153578826, 0.10795677386756454, 0.12925652414560318, 0.0909662570006081, 0.21259758781109536, 0.10463567064808947, 0.08726223611405917, 0.11019699794373342, 0.12964837811887264, 0.10219864427511181, 0.14474745147994586, 0.24588803574442863, 0.10120131993400198, 0.08713289376880441, 0.13449594085769995, 0.13224925712815352, 0.12550989804523333, 0.12241718971303531, 0.21121660619974136, 0.09730616930340018, 0.10405524500778743, 0.11102187939520393, 0.17474597319960594, 0.08612284011074475, 0.14082664544028894, 0.13176767368401798, 0.19974097769175256, 0.2109129482081958, 0.16645426170102187, 0.1350722885025399, 0.14117605026279176, 0.11164760403335094, 0.2426712912108217, 0.2091963088938168, 0.22216854138033731, 0.48570334592035835, 6.119982004165649, 24.577843768256052, 49.12866251809256, 35.931504249572754, 26.455260923930577, 21.675906045096262, 37.896767480032786, 47.79878773008074, 26.72584114755903, 19.00510883331299, 7.791746377944946, 0.30492793768644333, 1.3349508813449313, 2.328114228589194, 7.376438651766096, 6.952004032475608, 7.256250883851733, 10.165869406291417, 7.5744102001190186, 6.21876106943403, 5.699436204774039, 3.8052612968853543, 1.3881088346242905, 4.335401466914585, 11.836828657558986, 21.88776704243251, 31.437016827719553, 39.56411279950823, 42.24347366605486, 47.57418721062796, 51.140225069863455, 51.596544538225444, 53.295375619615825, 58.23836926051548, 57.91117511476789, 54.65750394548689, 54.62490994589669, 51.277854987553184, 52.754993370601106, 51.45874438967024, 51.998112201690674, 51.75830902372088, 50.65371567862374, 50.955677441188264, 50.21205690928868, 49.49055596760341, 52.07847159249442, 53.97056334359305, 55.86937747682844, 58.79572595868792, 49.60349893569946, 45.0175211088998, 52.46935640062605, 53.12114259174892, 55.07710565839495, 50.22049897057669, 52.00050238200596, 48.05453354971749, 52.25292001451765, 50.48109115873064, 49.714506830487935, 49.05926391056606, 51.06424651827131, 52.01459680284773, 49.998962606702534, 52.91312394823347, 53.8551607131958, 50.12651068823678, 53.977994441986084, 50.04697118486677, 45.680480003356934, 46.713972432272776, 48.159704957689556, 46.48853118079049, 43.49122422082083, 33.85655675615583, 21.815967832292827, 15.684300695146833, 9.041439822741918, 3.707725090639932, 2.8845657067639485, 1.5843858910458428, 2.232300741331918, 2.259283636297498, 5.056299652372088, 8.13037552152361, 5.911874771118164, 6.125798949173518, 7.440947464534214, 7.295770934649876, 6.29862322977611, 5.3438621418816705, 1.001644600714956, 1.8789466278893607, 7.7965467146464755, 20.08630759375436, 31.779285090310232, 31.5710996900286, 27.868726015090942, 34.329548427036826, 32.99007817677089, 19.192963804517472, 4.772690253598349, 0.5789944742407117, 0.1606950464525393, 0.08957901251103197, 0.2479726853115218, 0.114400909149221, 0.10161817792270865, 0.07926288499896016, 0.15497682828988346, 0.06789489928632975, 0.10941284216408219, 0.09088994216706071, 0.22653893115265028, 0.12134391016193799, 0.19549414914633545, 0.1017702172643372, 0.07380434897329126, 0.12666510391448224, 0.07865389303437301, 0.1515736494745527, 0.07462993610118117, 0.21652091800102166, 0.08876779675483704, 0.10233308241835662, 0.2211027799972466, 0.2674056025488036, 0.12028426916471549, 0.18863927626184054, 0.09140370852713074, 0.08516380550073725, 0.12543021089264325, 0.06727316443409238, 0.1513389442116022, 0.1309415301574128], [0.08900667500815221, 0.05523016869223543, 0.042268121016344855, 0.03039131885660546, 0.04979920493704932, 0.04633706821394818, 0.01424506918660232, 0.009703439227970583, 0.032661568107349534, 0.045900179871491024, 0.026716948254033923, 0.04098555412409561, 0.028056323794381957, 0.027174525129209672, 0.041367460773991685, 0.020243167777412703, 0.025054410233029296, 0.029840545196618353, 0.06425179048840489, 0.07352724884237562, 0.008531909502510513, 0.015021082546029772, 0.02385801898448595, 0.028069329614351903, 0.030698420413370644, 0.055768959423793216, 0.07601690917674984, 0.06597032291548592, 0.10845552424767188, 0.03711587569809385, 0.031008816257651364, 0.03974185711038964, 0.042097489815205336, 0.03770579743598189, 0.11632965851042952, 0.0756037084917937, 0.06757553320910249, 0.08508010142083679, 0.03645925396787269, 0.01120888112512018, 0.10948120456721101, 3.337795832327434, 20.111388853618077, 31.226357868739537, 32.08730220794678, 17.601152351924352, 13.341894456318446, 30.729617255074636, 48.66754184450422, 18.467726469039917, 13.260894094194684, 7.770951288087027, 0.4092725100261824, 0.17548032450888837, 1.6174845035587038, 2.027293924774442, 3.2016161339623586, 4.312952705792018, 3.5940423565251485, 1.8337145064558302, 2.412880514349256, 2.8727594145706723, 0.5934319081051009, 0.4911578446626663, 1.9362914136477878, 6.978416306631906, 11.697519881384713, 20.280243975775583, 23.050945860998972, 29.592395169394358, 35.128462723323274, 45.39825807298933, 48.12101738793509, 53.86344991411482, 52.81084646497454, 53.114962169102256, 49.490385736737935, 52.43123510905674, 48.76958308901106, 50.154619625636506, 50.23865113939558, 50.28479412623814, 49.361329896109446, 47.95187044143677, 46.89981937408447, 48.737183638981406, 50.31161069869995, 49.42663948876517, 52.66472584860665, 51.28183283124651, 48.729064668927876, 34.18977846418108, 45.900640623910085, 49.536261217934744, 51.227091448647634, 49.9497207232884, 48.292516299656455, 47.419252804347444, 45.84272391455514, 45.06713124683925, 44.35081366130284, 47.78039584841047, 48.95698990140642, 49.94045877456665, 48.80779470716204, 50.799971784864155, 48.89829151970999, 52.64004932131086, 46.30370909827096, 39.710709367479595, 45.84604515348162, 46.98016139439174, 46.70639542170933, 39.152216638837544, 25.549201931272233, 13.794824072292872, 6.700828390462058, 2.391806845154081, 0.693384621824537, 0.4400660847978932, 0.5232800181422914, 0.7312767856887409, 0.7984607091971806, 1.4005786797830035, 3.7755811980792453, 3.5717049837112427, 2.6861957226480757, 2.3792577471051897, 3.048807007925851, 3.971787903990064, 1.1031994713204247, 1.0698549577168055, 1.2341341482741492, 5.379661866596766, 13.816561511584691, 24.127782889774867, 17.341689246041433, 17.787072249821254, 28.555597134998866, 21.772008316857473, 12.981777140072413, 2.112497729914529, 0.09573521824287516, 0.019173920420663695, 0.09510516455130917, 0.029491296437169825, 0.04991336166858673, 0.06691455189138651, 0.07551929873547383, 0.018174954024808745, 0.01722882854353104, 0.030190163757652044, 0.06259686393397194, 0.037752646886344464, 0.0072795094290216055, 0.03598273239497628, 0.03734818912510361, 0.043538033230496306, 0.10293759605182068, 0.0370189096512539, 0.05141982476093939, 0.055945015512406826, 0.03330444611076798, 0.01548995533292847, 0.057527006337685246, 0.11355541380388395, 0.050627533346414566, 0.0210911245085299, 0.05487280465396387, 0.0589249852512564, 0.06146553571202925, 0.028352845293868865, 0.03572279241468225, 0.046449603246791024, 0.02749803875173841, 0.05085414029391749, 0.06496234557458333, 0.042251266206481626, 0.06152391007968357, 0.040369956621101925, 0.02936920423858932, 0.06578171053635222, 0.02828160929493606, 0.034384426195174456, 0.047855364957026074, 0.02695350761392287, 0.06275995661105428, 0.015003584824236376, 0.021281373853396093, 0.03039362926834396, 0.06024687324783631, 0.05294290517589875, 0.030917135998606682, 0.034990680270961354, 0.0155364536414189, 0.05039330645065222, 0.016339857763211642, 0.0036149669821108027, 0.010469678290454405, 0.03414495422371796, 0.07598593405314855, 0.02904865751042962, 0.05007454426959157, 0.054490070191345046, 0.14787529435540947, 0.06763643172702619, 0.05930632193173681, 0.014703472178163273, 0.04253211185070021, 0.029160514008253813, 0.0248196574726275, 0.011117098237653928, 0.022084649053535292, 0.0052030472350972036, 0.0041534345613659495, 0.030314858138029064, 0.3451055974832603, 5.077552889074598, 26.459219660077775, 35.01845536913191, 31.815360137394496, 17.69932344981602, 15.948452098029, 40.6327075277056, 36.060021604810444, 22.33712441580636, 21.414989028658184, 7.586954304150172, 0.3497410501752581, 0.03609724875007357, 0.6675698384642601, 0.846625947526523, 2.482432633638382, 4.55751496553421, 4.37802345412118, 4.7666500977107455, 3.402848775897707, 4.105896387781415, 2.4339350759983063, 1.7477567132030214, 3.615093444074903, 9.41384242262159, 15.301545279366628, 23.079662765775407, 25.99605447905404, 33.12696116311209, 40.01111125946045, 47.03147036688668, 49.445879050663535, 54.81060750143868, 54.8836851801191, 55.03068126950945, 50.543882029397146, 53.31755426951817, 51.31534399305071, 50.83599124635969, 51.81620488848005, 51.276809283665244, 49.376685414995464, 49.18658964974539, 48.382057734898154, 50.13798563820975, 50.715453897203716, 50.554207052503315, 54.73180798121861, 52.50965247835432, 49.3133282661438, 38.04641778128487, 48.5527298109872, 50.3912787437439, 52.32480607713972, 51.63949135371617, 50.92908321108137, 48.9652339390346, 47.01515599659511, 46.446657861982075, 46.934758390699116, 50.35173307146345, 49.83021865572248, 50.33217389242989, 49.490205083574565, 51.595936570848735, 49.095481395721436, 49.58335610798427, 49.868360791887554, 42.149808474949424, 46.576887948172434, 48.19411938531058, 47.351751055036274, 40.73275463921683, 28.994883094515117, 16.95010440690177, 10.294588259288243, 4.197442812579019, 1.5378241666725703, 1.1998460910149982, 1.8886350222996302, 2.4595031440258026, 2.2268772380692616, 3.1092139950820377, 5.107762353760855, 4.088731297424861, 4.327403656073979, 4.4516105226108005, 3.2868251502513885, 3.5289889786924635, 0.9783817061356136, 0.3505687271910054, 0.9102470193590436, 5.4926100458417615, 14.404306156294686, 26.13994472367423, 24.25920111792428, 22.290953636169434, 29.614539078303746, 27.29284541947501, 18.189306940351212, 4.183134734630585, 0.2823205893593175, 0.07749771007469722, 0.08522977267525025, 0.05654186848551035, 0.03427403194031545, 0.01663073894035603, 0.025500516473714794, 0.021216609382203648, 0.040697957056441476, 0.017446473739775162, 0.05320363225681441, 0.05645719410053321, 0.008874550179046179, 0.08564175199717283, 0.04291924322023988, 0.0561233989761344, 0.036739936763686795, 0.0334960101172328, 0.06255934094744069, 0.013464165286027958, 0.006317081719836486, 0.04414230937670384, 0.02946160374475377, 0.024074527634573833, 0.07600491267762013, 0.03890645497345498, 0.021488423725324016, 0.011165758528347527, 0.04685970641938703, 0.06271961770419564, 0.02297728561929294, 0.022904840131689395, 0.027267659149531807, 0.026167418009468486, 0.24276397909436906, 0.11888133016015802, 0.11874486319720745, 0.11027526017278433, 0.11137055139988661, 0.11468326114118099, 0.08513600592102323, 0.0831511892112238, 0.07722905091941357, 0.13945801316627435, 0.18234889023005962, 0.12058852426707745, 0.07623231690376997, 0.16395590933305876, 0.14387066209954874, 0.10126195382326841, 0.12381056137382984, 0.08995490055531263, 0.09941737673112325, 0.16009119099804334, 0.12598323050354207, 0.1361822903688465, 0.10019297618418932, 0.11926128262920038, 0.11787418063197817, 0.15021055404629025, 0.15305194657828125, 0.15835153577583178, 0.24324321480734007, 0.16083278906132492, 0.2340696927692209, 0.12194302944200379, 0.12745926130030835, 0.09950724869434323, 0.1738518268934318, 0.14095980115234852, 0.20210390804069384, 0.1558486915060452, 0.07816472356872899, 0.10195230892194168, 0.3165390560669558, 5.626285135746002, 28.737961292266846, 42.91520466123308, 43.091727120535715, 26.2370788029262, 19.95558418546404, 37.324440887996126, 55.85482447487967, 25.00112976346697, 17.951742819377355, 9.611575995172773, 0.6905636531966073, 0.5113505039896283, 3.743680715560913, 6.199543220656259, 9.504406111580984, 12.587232368332998, 9.863409110477992, 6.044409053666251, 6.487081825733185, 5.749687314033508, 1.16226122209004, 1.2882996989148003, 3.0187840589455197, 8.91128877231053, 13.283792751176016, 25.483534506389073, 28.833003963742936, 31.918850081307546, 37.58488021578108, 45.53056219645909, 47.2860176222665, 56.237927300589426, 55.89436319896153, 56.95595761707851, 51.73651947293963, 56.28073862620762, 52.58384186880929, 54.38401937484741, 54.7839229447501, 53.48748288835798, 52.73729630878994, 51.63456508091518, 50.605356216430664, 52.42223719188145, 54.319057192121235, 53.03002044132778, 57.55898482458932, 53.00238050733294, 50.53628764833723, 40.133132049015586, 50.67009258270264, 53.34117814472744, 53.803000586373464, 53.90768562044416, 51.860781056540354, 51.136375767844065, 49.06241839272635, 48.463653905051096, 47.813611711774556, 51.055818353380474, 51.108659403664724, 51.71952417918614, 51.49457277570452, 54.367506980895996, 48.84973750795637, 52.79909358705793, 50.08399813515799, 46.20276914324079, 46.91998304639544, 47.929511138371055, 46.77633598872593, 40.32100439071655, 27.82382501874651, 16.758391448429652, 9.82161830152784, 4.428298882075718, 1.0645702012947627, 1.11758691072464, 1.7807725987264087, 3.0272810544286455, 2.685103769813265, 4.632592856884003, 8.471966334751674, 7.7307915687561035, 8.111814277512686, 7.852682079587664, 9.398454768317086, 9.696659292493548, 2.7416877278259824, 1.630329117178917, 2.05901158281735, 7.41048048223768, 17.445033277784074, 31.72901487350464, 25.412490912846156, 26.540296452386038, 38.80416052682059, 30.28760760171073, 18.46023804800851, 3.521390906402043, 0.2838763344500746, 0.20295659585722856, 0.14245035259851388, 0.15406771350119794, 0.15447948926261493, 0.13444591925612517, 0.23884508652346476, 0.09268560366971151, 0.13310892028467997, 0.16463478361921652, 0.18234939234597342, 0.19597163423895836, 0.09271138800042016, 0.20547841196613653, 0.1528762602912528, 0.13198046226586613, 0.13760224703167165, 0.1186795202749116, 0.1511829082987138, 0.1252601971583707, 0.07029322202184371, 0.07160048758877174, 0.1012382661657674, 0.13651610245662077, 0.21298382351441042, 0.15644114757222788, 0.12464591940598828, 0.08319329230913095, 0.1847629549780062, 0.10631520088229861, 0.0949073512373226, 0.16639056083347115, 0.07891412478472505, 0.12406893393823079], [0.01724159178723182, 0.014702532407162445, 0.034721440968236754, 0.009369432061378444, 0.02765911617981536, 0.06662981824151107, 0.06971053685992956, 0.03513624978118709, 0.015289141197821923, 0.01163575513887086, 0.0222700197316174, 0.040971365956855674, 0.06845900615943329, 0.039142642835421224, 0.01913957467435726, 0.06731082991297756, 0.037563311867415905, 0.10558154846408538, 0.033501764094190936, 0.01943427261098155, 0.036386545547949414, 0.020755303957100426, 0.042400160538298745, 0.02973264455795288, 0.010894744856549161, 0.0353774180901902, 0.015005944429763725, 0.06129320138799293, 0.011854926190738167, 0.06583308920796428, 0.07816296616303069, 0.049736956134438515, 0.02360439786155309, 0.09044981042721442, 0.06816911564341613, 0.06893627412085022, 0.07760316120194537, 0.06983828464789049, 0.021766680758446455, 0.02467064100450703, 0.024171508948451707, 0.0182164209961359, 3.059554134096418, 16.005401270730154, 28.974144458770752, 26.571882963180542, 21.815484932490758, 15.225940193448748, 23.56228985105242, 40.39927237374442, 25.046725579670497, 12.707662888935634, 6.845865956374577, 1.8795446072305952, 0.03011285826297743, 0.3970037283641951, 2.4862343839236667, 2.603382966348103, 2.842981606721878, 2.522090128489903, 2.882805858339582, 6.2333105972834995, 3.092152259179524, 2.021400115319661, 0.7927176973649434, 1.2775255399090903, 2.613171023981912, 6.024827292987278, 11.365174514906746, 15.38518943105425, 22.523596695491246, 30.094923632485525, 38.328132493155344, 44.56625645501273, 49.30852358681815, 55.22545664651053, 53.25709104537964, 51.841993127550396, 51.20612873349871, 52.17335966655186, 51.067147391183035, 49.7024621282305, 50.07947833197457, 49.78410693577358, 50.1311798776899, 50.34541368484497, 52.24489484514509, 51.577405725206646, 52.40974085671561, 52.74649224962507, 52.347724710192, 38.51607779094151, 51.99824769156319, 51.436096736363, 52.450985363551546, 52.236306871686665, 48.96294103349958, 49.122895513262065, 49.06143869672503, 51.363078117370605, 51.27388061795916, 51.73020356042044, 49.42622259684971, 48.90062264033726, 48.921463762010845, 49.61132608141218, 51.817271436963765, 49.93426445552281, 42.72015135628836, 44.07283708027431, 46.00682994297573, 44.79749945231846, 32.33649935041155, 18.420940773827688, 7.721651213509696, 1.7591841114418847, 0.2702695360141141, 0.3991697207093239, 0.6144143279109682, 0.8563349151185581, 0.9706385901996067, 1.6998130572693688, 1.7912871773753847, 2.567030425582613, 3.759244680404663, 2.3697141792093004, 2.60360226886613, 3.1889054902962277, 2.1514258810452054, 2.9438944203513007, 1.4421818873711993, 1.338788024016789, 3.964725060122354, 11.362900716917855, 20.69993601526533, 16.825128895895823, 15.456559589930944, 22.038247653416224, 21.685680423464092, 12.261827383722578, 1.8162986295563834, 0.09520537738821336, 0.0721960717013904, 0.04002180030303342, 0.01769722635591669, 0.015278649350096072, 0.024197951458128433, 0.05723771293248449, 0.07343956854726587, 0.021159904210695198, 0.055537029369069, 0.023961887428803102, 0.033977308576660495, 0.014568155332069312, 0.03992601490712591, 0.05085336337132113, 0.04008069035730191, 0.06330688297748566, 0.026878320844843984, 0.05317307443224958, 0.062092922760971954, 0.04926751846713679, 0.07108667373125042, 0.0399656345668648, 0.056122493131884506, 0.02307946451141366, 0.030671862552740743, 0.02069250214844942, 0.030362565935190235, 0.04162835070331182, 0.016485055775514672, 0.025962198485753367, 0.0683920890358942, 0.005290602425312889, 0.012792712476636683, 0.02415271522477269, 0.02312222239561379, 0.037012989433216195, 0.027059834051345075, 0.0376238575471299, 0.02714320395274886, 0.036548891836511235, 0.030977478117815087, 0.04388184692444546, 0.030444658494421413, 0.008274041598529687, 0.032829800687198124, 0.060819387169820924, 0.07472832367888518, 0.03731215552293828, 0.07863654967929636, 0.01998889695719949, 0.04248896720153945, 0.037596315810722966, 0.007444282328443868, 0.039560291317424605, 0.07154932604836566, 0.018360892975968972, 0.018255692906677723, 0.030237057312790836, 0.04776850229661379, 0.04236054427123495, 0.01559533182132457, 0.01934948457138879, 0.041791524804596386, 0.047909671507243595, 0.04327914837215628, 0.05661987965660436, 0.05819914277110781, 0.057906035999102254, 0.06085602127547775, 0.015755834190973213, 0.037739462950932126, 0.03453903379184859, 0.03368978614785841, 0.04523817735857197, 0.04508390902940716, 0.19579573082072393, 4.5663200701986035, 21.748212473733084, 34.33979007175991, 27.07497423035758, 17.376774174826487, 17.33300747190203, 34.519282885960166, 27.540110962731497, 21.250782251358032, 19.04352194922311, 9.094678657395498, 2.057796733719962, 0.014230066777340003, 0.45724575008664814, 1.3461120767252786, 2.3904968925884793, 3.3263050317764282, 5.232042610645294, 4.625049718788691, 7.202160894870758, 8.88971027306148, 3.031558104923793, 0.8425349784748895, 2.195233838898795, 4.219310096332005, 9.213006479399544, 13.972834314618792, 16.998012236186437, 23.909328051975795, 32.48544788360596, 39.859522410801475, 47.034895828792024, 52.739849771772114, 56.720778465270996, 54.441911765507285, 53.67841591153826, 52.17768839427403, 53.0472172328404, 52.687873772212434, 51.35403503690447, 51.77284812927246, 52.223716735839844, 50.88337101255144, 52.35566650118147, 53.54140090942383, 52.6798312323434, 53.50885207312447, 52.37950924464634, 52.7191858291626, 41.49205378123692, 52.36622428894043, 51.55327810559954, 52.159789834703716, 53.56280830928257, 50.86885622569493, 50.0105174609593, 50.68942594528198, 51.621148109436035, 52.356573241097585, 52.95113059452602, 52.01126514162336, 50.15219470432827, 49.86644656317574, 50.35383490153721, 50.30964435849871, 53.65200233459473, 46.33444792883736, 46.591896057128906, 48.03791693278721, 45.74602236066546, 35.875904764447895, 21.789069618497575, 9.65574221951621, 3.679529300757817, 1.6602017027991158, 1.1317613444158008, 1.2053017296961375, 1.9801427977425712, 2.423553381647382, 3.52411025762558, 2.393648986305509, 4.318437874317169, 6.00419157743454, 3.37398704460689, 3.847445547580719, 3.816492191382817, 1.6477008078779494, 0.681568015898977, 0.4669205737965447, 1.7851679857288087, 4.729703485965729, 14.132793137005397, 24.71556227547782, 24.40757989883423, 17.29047233717782, 23.76371465410505, 26.559077433177404, 16.817854131971085, 3.9988602570125034, 0.3967268317937851, 0.03142611529412014, 0.021463528275489807, 0.03438561702413218, 0.021183993900194764, 0.03992504120937415, 0.015194558505234974, 0.02465646301529237, 0.05803359379725797, 0.04806860137198653, 0.018231394567659924, 0.045414253803236146, 0.03614797942074282, 0.04710033868572541, 0.028995819988527467, 0.017847976481009806, 0.035755769216588566, 0.03736969189984458, 0.03443418995344213, 0.018927510428641523, 0.03316344314121774, 0.007328170567883977, 0.06645451871944325, 0.05270574700885585, 0.029878614403839623, 0.02233703015372157, 0.08648995469723429, 0.07986621119614158, 0.0351783664497946, 0.05765638939504113, 0.021297517897827283, 0.04453589700694595, 0.0356515326670238, 0.023669946040692072, 0.07478883543184825, 0.07923069529767547, 0.12480313596980912, 0.18367071715848787, 0.13745294218616827, 0.14920324166970594, 0.13489253100539955, 0.13603356906345912, 0.08939140436372586, 0.12654420254485949, 0.09398916443543774, 0.12513964862695762, 0.2671782390347549, 0.15566741409046309, 0.13050101165260586, 0.18680523681853498, 0.1597564968147448, 0.11421691759356431, 0.20593453677637236, 0.08309871131288153, 0.09989828842559031, 0.10238551281924758, 0.08514035533049277, 0.08167380134442023, 0.22810569565211022, 0.10613322457564728, 0.1261963854943003, 0.07931720851255314, 0.12907289899885654, 0.2007958282317434, 0.13319214939006738, 0.16231267393699714, 0.18309548231107847, 0.13322869528617176, 0.18986333986478193, 0.1810379470033305, 0.1476284840277263, 0.1851396911910602, 0.14446340315043926, 0.1063872884426798, 0.08384540517415319, 0.1428481505385467, 0.2894313377993447, 4.868110299110413, 23.75584408215114, 40.70040035247803, 36.62293686185564, 29.811565671648296, 22.644095829554967, 31.31083754130772, 49.45102071762085, 34.45027685165405, 18.14300935609, 9.37573676449912, 2.6112485442842757, 0.5188479902488845, 1.3302071073225565, 5.609876096248627, 7.801467776298523, 9.472840445382253, 10.1396347454616, 8.122107165200369, 11.636087383542742, 5.845557689666748, 3.1822245802198137, 1.6975082095180238, 1.4905222420181548, 3.9029573116983687, 7.274695745536259, 13.93161152090345, 17.70161461830139, 23.65373682975769, 33.68657602582659, 39.84806483132498, 45.50400618144444, 51.38884898594448, 58.698694365365164, 55.25653941290719, 55.63757862363543, 54.659842014312744, 56.370738642556326, 55.04590129852295, 53.797428131103516, 55.462119238717214, 53.23870611190796, 53.06290973935808, 53.27972827638899, 56.65999909809658, 54.765635286058696, 55.78941413334438, 53.662685189928325, 52.62184851510184, 45.52649055208479, 51.74766785757882, 50.15037080219814, 53.65926667622158, 56.297893728528706, 53.484192916325156, 51.45558990750994, 53.84075709751674, 55.58266701017107, 54.79338986533028, 56.259741170065745, 52.32071358816964, 51.09830658776419, 50.08379316329956, 50.578946113586426, 50.758664744240896, 51.850181579589844, 49.722618852342876, 45.7961814062936, 47.59774855204991, 44.91153328759329, 33.78192268099104, 20.570675202778407, 8.472402334213257, 2.3740014348711287, 0.9184248319693974, 1.1204204729625156, 1.248423010110855, 1.9756260343960352, 2.4790927214281897, 4.23783095393862, 4.123253422124045, 5.952105709484645, 8.17868287222726, 7.130436377865927, 8.325102261134557, 8.002097879137311, 5.507542593138559, 5.57717353105545, 2.800535712923322, 2.438020182507379, 5.942223634038653, 15.339081185204641, 27.80286751474653, 26.5191513470241, 22.709018060139247, 31.809818949018204, 30.90005656651088, 18.208742788859777, 3.3063328691891263, 0.4207083492406777, 0.20481549682361738, 0.08680876437574625, 0.10866202959524733, 0.08270096087030002, 0.09108244255185127, 0.18652014354509966, 0.19767553066568716, 0.15784494153090886, 0.10477967613509723, 0.13092669738190515, 0.15395561951611722, 0.06430579509053912, 0.11916068302733557, 0.12333884382886545, 0.14511911225106033, 0.1473212433712823, 0.12158742280943052, 0.10627431236207485, 0.10660661131675754, 0.15264292566904, 0.14216029244874204, 0.12738190830818244, 0.15437115436153753, 0.2588370351919106, 0.08432634401002101, 0.1240167138831956, 0.19405344288264, 0.16097407362290791, 0.10851769162608044, 0.08619141964507954, 0.14882157929241657, 0.1080962603113481, 0.11441214568912983, 0.15835002942809037], [0.060254493196095736, 0.026140844881800667, 0.0661642142970647, 0.016557184047996998, 0.024393568014992133, 0.008495029427909424, 0.04052776011771389, 0.029317964666656086, 0.04243757835190211, 0.036502418973084004, 0.05782474071851798, 0.0193579374213836, 0.009710667322256734, 0.05997727092887674, 0.027045330365321467, 0.04190425321991954, 0.01477810594120196, 0.015501247851976326, 0.050470140363488875, 0.04975819428052221, 0.024847572403294698, 0.023157667368650436, 0.02600202170599784, 0.06034553902489798, 0.042402776290795634, 0.016501357579337697, 0.047378076639558585, 0.01769083285970347, 0.018806824493887167, 0.050228459760546684, 0.031544366984495094, 0.05925807809191091, 0.012061272082584245, 0.01853220780113978, 0.018666106509044766, 0.08897576095270258, 0.022782020204301392, 0.06054185956184353, 0.04174476356378623, 0.019511148932256868, 0.04483460508553045, 0.03244485080774341, 0.157479889690876, 2.0439659101622443, 14.433178527014595, 32.25443765095302, 30.633113724844797, 20.09115743637085, 9.381779091698782, 13.062490889004298, 41.020972864968435, 44.10782820837838, 15.471569435937063, 6.794438864503588, 2.6449399249894276, 0.8257053015487534, 0.26145208201238085, 1.5781306666987283, 2.096480829375131, 3.6283228141920905, 2.7590371625764027, 3.971201649733952, 14.936050925936017, 3.8153123004095892, 0.823270283639431, 0.28482666345579283, 0.22518904001585074, 0.4409031798796994, 1.6238719608102525, 4.6716782110078, 7.484155705996922, 12.998422418321882, 20.204440866197857, 30.13233620779855, 38.449197905404226, 47.113684926714214, 55.493445192064556, 55.00856862749372, 54.21164151600429, 52.45295170375279, 52.17446443012783, 53.50836917332241, 53.3414352280753, 52.701304640088765, 54.19517775944301, 52.30526079450335, 52.1168395451137, 51.601672308785574, 56.946105071476524, 51.78359351839338, 52.66165474482945, 47.883361203329905, 50.56278460366385, 63.31068624768938, 54.94224807194301, 53.62590490068708, 51.880024092538015, 52.36827400752476, 49.329625265938894, 50.0702337537493, 52.22224371773856, 51.975791113717214, 52.91097695486886, 53.74895402363369, 54.07169784818377, 55.13990000316075, 53.21925115585327, 44.91680349622454, 40.85317734309605, 44.910855838230674, 38.54673671722412, 25.369106360844203, 13.371006539889745, 4.366162444864001, 1.0980822316237857, 0.8456048880304609, 1.6532450360911233, 0.6041590582047189, 0.5626304894685745, 2.4803123474121094, 3.4449828692844937, 5.1389215503420145, 1.8567460477352142, 2.8964408295495168, 5.815367332526615, 2.5650797188282013, 3.040844372340611, 2.8435248689992085, 1.0475125908851624, 0.5980727619358471, 1.5146103437457765, 5.3011103102139066, 12.760985970497131, 18.441748891557964, 15.219615595681326, 14.681062459945679, 20.117140225001744, 23.12277112688337, 14.441754341125488, 3.311538806983403, 0.1462054332452161, 0.05017481817464743, 0.016708359953814318, 0.005721411094002957, 0.0057690400114682105, 0.03585112713543432, 0.016778449228565608, 0.030457659225378717, 0.030182696479771818, 0.07535586679088217, 0.02779865181738777, 0.0314195063630385, 0.07838090482567038, 0.04778077360242605, 0.0621442064376814, 0.016048939266641225, 0.05079822222303067, 0.04196171495797379, 0.09921986197254487, 0.06798631830939225, 0.00867870292027614, 0.031377572898886034, 0.036320076257522614, 0.026158142435763563, 0.07950888108462095, 0.052266799312617095, 0.015228626052183765, 0.03600385179743171, 0.014189369943259018, 0.022714816399716904, 0.05391940527728625, 0.07240732000874621, 0.1492847880082471, 0.020636653627402017, 0.03666913841984101, 0.0768970912322402, 0.04214885491611702, 0.038419500924646854, 0.03782964704026069, 0.022356789093464613, 0.03591893992519804, 0.017230930305751305, 0.04135142020615084, 0.024131924911801304, 0.014212378217572612, 0.00932059365524245, 0.023742859717458487, 0.05969962118459599, 0.03604596846603921, 0.011564065369644334, 0.07602140107857329, 0.05945727561733552, 0.02799663306879146, 0.017171726429036686, 0.013172881228716245, 0.025597546981381517, 0.01912540177415524, 0.05730633317892041, 0.02717675411674593, 0.06584091950207949, 0.02584329540176051, 0.06953829753079585, 0.03758064504446728, 0.031893900728651454, 0.05157005241406815, 0.024240271687241535, 0.07928194504763399, 0.0126787296196978, 0.04922713545550193, 0.023825749555336576, 0.027481855691543648, 0.03668464294501713, 0.019780971775097505, 0.01331245418571468, 0.01558516567040767, 0.015434196717771036, 0.034752270206809044, 0.026721547025122812, 0.15389331643070492, 3.824024472917829, 20.82380849974496, 36.342531885419575, 30.94643579210554, 21.5316128049578, 12.954264010701861, 24.229021617344447, 38.192722524915425, 28.576410463878087, 14.838385309491839, 8.8755715574537, 3.833604301725115, 0.2847192920744419, 0.2627106016235692, 1.2028586779321944, 1.6007812512772424, 3.9901559012276784, 4.178855512823377, 10.18242609500885, 16.468661989484513, 4.17037740775517, 1.6401442076478685, 1.1306096804993493, 0.6154652972306524, 1.2712941999946321, 3.11073391352381, 5.699596881866455, 9.420562199183873, 15.972366060529437, 23.841216598238262, 31.513721466064453, 39.82580280303955, 49.608466897692, 57.15500961031233, 55.843853269304546, 56.14128133228847, 55.0557746887207, 54.38529436928885, 54.71695620673043, 54.33363103866577, 53.590663637433735, 55.36832550593785, 55.02501501355852, 55.4276978628976, 54.870500973292756, 57.74422032492501, 53.68996729169573, 53.30351196016584, 46.92783798490252, 49.42027841295515, 59.01725537436349, 56.032566343035015, 54.74114983422415, 52.83887202399117, 54.09858390263149, 51.12875011989048, 51.23869146619524, 53.387112685612266, 52.27813502720424, 54.44765097754342, 54.90344933101109, 53.26317419324602, 53.84743431636265, 52.880946840558735, 49.111774921417236, 43.931941509246826, 45.36029658998762, 41.199680532727925, 30.36053589412144, 15.558199575969152, 6.627468006951468, 2.449128180742264, 1.198511276926313, 1.772887913244111, 2.405219474009105, 2.184239400284631, 2.8634457886219025, 3.7235318081719533, 4.048366171973092, 4.084348721163614, 4.508915356227329, 5.448228861604418, 2.924403637647629, 3.1776168388979773, 1.0418157194341933, 0.30829936106290134, 0.37360851945621626, 1.1554060642208372, 5.15603974035808, 13.232292703219823, 20.224547215870448, 20.87303648676191, 17.09683993884495, 21.12085267475673, 27.15579741341727, 19.002195801053727, 5.797458350658417, 0.2942246177366802, 0.02604144798325641, 0.034845005587807724, 0.03948878051180925, 0.039522408707333465, 0.040353658209953985, 0.017223042336159518, 0.04567363399213978, 0.035270959338439364, 0.03891069242464645, 0.021058470010757446, 0.03588365610422833, 0.024277972789215188, 0.0059549242557425585, 0.05788685381412506, 0.008690388141466039, 0.03895711779062237, 0.06686959894640104, 0.017343521317733184, 0.04068490543535777, 0.020149287368570055, 0.039788106057260714, 0.04535194053979857, 0.0329870002876435, 0.005615822987497917, 0.02192323575062411, 0.0638049276811736, 0.04085739242977329, 0.0211226526381714, 0.04224370393369879, 0.018957460964364663, 0.026745587520833527, 0.06672009054039206, 0.04008222384644406, 0.06822186495576586, 0.05791691291545119, 0.1498823059456689, 0.11626641904669148, 0.12941451423934527, 0.10515113334570612, 0.07012532531682934, 0.06680194221969162, 0.12998168809073313, 0.0948945472815207, 0.10354992640869957, 0.095113490175988, 0.1300613616726228, 0.10959088296762534, 0.09148158399122101, 0.13416263088583946, 0.16663525413189614, 0.11405086650380067, 0.11481615900993347, 0.0862133295408317, 0.16283262175108704, 0.24941063672304153, 0.09206422165568386, 0.15092821339411394, 0.20954736934176513, 0.1768042684665748, 0.07323834898748569, 0.10546925770384924, 0.1669308782688209, 0.10778507058109556, 0.14673583049859318, 0.09907584970018693, 0.17828009570283548, 0.1894529890269041, 0.1310378685593605, 0.16493533392037663, 0.08948090313268559, 0.22103161524449075, 0.1343323460647038, 0.12829033099114895, 0.08541500594999109, 0.15064035169780254, 0.12641689580466065, 0.1083494352975062, 0.2557504879576819, 3.8399532181876044, 22.56748672894069, 44.98034824643816, 42.55465916224888, 30.58965274265834, 16.777797767094203, 20.584813049861364, 47.86649445125035, 50.80163587842669, 19.81712916919163, 9.823566402707781, 3.6305167078971863, 1.2616325127226966, 1.3586752883025577, 2.5936952233314514, 7.622624618666513, 10.250778998647418, 8.15114802973611, 10.954985874039785, 24.901508229119436, 7.658895952360971, 2.4307536695684706, 1.8594562794481004, 0.4997924470475742, 1.2372848306383406, 2.4373386076518466, 5.863756324563708, 9.303373881748744, 15.02143212727138, 21.77393470491682, 32.53665263312203, 40.46553039550781, 51.20855018070766, 59.64091873168945, 58.81143583570208, 57.731192452566965, 57.025015762874055, 55.64251184463501, 56.89067234311785, 56.87351724079677, 55.28340114865984, 57.253166811806814, 58.334045955113, 58.13695682798113, 57.27538020270211, 59.048855781555176, 55.17036437988281, 53.1864070211138, 52.53273786817278, 51.87464966092791, 59.264194352286204, 56.531044006347656, 54.378106457846506, 53.350075313023154, 55.80101762499128, 53.18368680136544, 52.7178760937282, 56.292328221457346, 53.32818501336234, 55.159476552690776, 56.00224093028477, 55.10867132459368, 53.60272223608834, 51.580688749040874, 49.52268443788801, 47.69878230776106, 47.576573916843955, 40.812047481536865, 28.358730350221904, 14.860001155308314, 5.435071579047611, 2.16746558036123, 1.6974186428955622, 4.299117539610181, 2.6454905697277615, 3.3559404015541077, 5.123716286250523, 7.09659561089107, 10.199080058506556, 6.257660124983106, 7.634064827646528, 13.839901379176549, 6.093058603150504, 8.472385832241603, 8.996877551078796, 3.1323810262339453, 1.3344516967024123, 1.8249953857489993, 6.676044600350516, 17.95554174695696, 24.278635229383195, 22.610940762928553, 22.206856114523752, 28.632405996322632, 33.39904219763619, 19.91376645224435, 5.68182121855872, 0.25488367304205894, 0.09699954611382314, 0.13189244270324707, 0.18446518667042255, 0.09116251646940197, 0.10145653052521603, 0.07434661380414452, 0.129475595961724, 0.11118816118687391, 0.09795224999210664, 0.11654471339923994, 0.11881659791937896, 0.13019235964332307, 0.1619936539126294, 0.2667494591857706, 0.12258078450603144, 0.213223916345409, 0.08861950292651143, 0.12855380613889011, 0.139674058716212, 0.1209103941385235, 0.11410391437155859, 0.1045300295310361, 0.1135595121553966, 0.13388821775359766, 0.12886757430221352, 0.11266595617468868, 0.11902983433433942, 0.09290365089795419, 0.10590647852846555, 0.10758149650480066, 0.14669112861156464, 0.21548798414213316, 0.14256438719374792, 0.11124669161758252, 0.1559421800609146], [0.024421696684190204, 0.03953126698200192, 0.025139033727880036, 0.029317021502980163, 0.029412060510367155, 0.04864335785220776, 0.018177800479211977, 0.06012565975210496, 0.040961316853229485, 0.03237726193453584, 0.05034866223910025, 0.021816156139331203, 0.03837369981088808, 0.0656004874035716, 0.0061744791039797875, 0.025568816112354398, 0.012514990638010204, 0.0902515153533646, 0.01804825457345162, 0.042975120579025576, 0.023899745495457734, 0.03212874509128077, 0.02607036375307611, 0.055051537563226054, 0.0425461235988353, 0.08493577023702008, 0.03869923037875976, 0.03235252933310611, 0.013519140193238854, 0.030231092989976917, 0.04404325344200645, 0.04941489288051214, 0.020306819451174567, 0.010850336435916168, 0.017329114322949733, 0.015265860661332096, 0.0009872519128423715, 0.02958403860351869, 0.036378728824534586, 0.04270763528932418, 0.059761361085942814, 0.02896551661459463, 0.04113954086122768, 0.14129944864128316, 1.6593842038086482, 11.526310188429695, 27.818196977887833, 28.997092621667043, 20.629597663879395, 6.873810742582593, 4.472577146121433, 23.22108118874686, 41.572381905147004, 27.124766758510045, 8.070435149329048, 4.567523845604487, 1.2636922193425042, 1.088868920292173, 0.7630003605570111, 2.3209174147674014, 3.440590087856565, 11.149525880813599, 17.29005023411342, 3.1150580814906528, 1.288214040654046, 1.439078648175512, 0.7926773652434349, 0.17504352437598364, 0.1363699460136039, 0.09987217161272254, 1.2059387926544463, 2.553338348865509, 7.623649477958679, 14.221881202289037, 23.856269870485576, 34.089554173605784, 42.34460817064558, 48.219372613089426, 54.719954354422434, 55.10461010251726, 54.533746106284006, 54.38306399754116, 54.4043220111302, 53.005722590855186, 56.13134888240269, 55.75728913715908, 57.27429975782122, 54.13262660162789, 55.454333782196045, 52.120094776153564, 54.870973450796946, 53.52649007524763, 46.91781520843506, 50.99428858075823, 56.240987982068745, 53.57707643508911, 53.11225584575108, 52.61518171855381, 52.00840943200247, 51.47522551672799, 52.68500416619437, 54.05011326926095, 51.82730463572911, 49.819869313921245, 54.864070415496826, 53.41874088559832, 47.40254586083548, 38.139780725751606, 39.552488463265554, 33.43164661952427, 16.185880729130336, 7.717242581503732, 2.4569316591535295, 0.6792671850749424, 0.7632142347948891, 0.7907091794269425, 0.762600839138031, 1.742301834481103, 1.899485502924238, 2.172962908233915, 2.773203888109752, 2.5984523509229933, 2.113397304500852, 5.131303284849439, 2.0903082234518866, 2.026864222117833, 2.0176737095628465, 0.8079597651958466, 0.5313657128385135, 1.7503689101764133, 6.531367472239903, 14.384365694863455, 13.399404696055822, 11.986752544130598, 17.163730246680124, 23.706918341772898, 20.553198746272496, 14.948217221668788, 3.177873270852225, 0.15621716316257203, 0.011443197926772493, 0.02310450923895197, 0.05719697368996484, 0.06806468910404614, 0.06214216404727527, 0.04249598325363227, 0.045261410397610495, 0.04079240234568715, 0.024841501211215342, 0.028729233757725785, 0.024827840604952404, 0.05279350872816784, 0.03158048201086266, 0.01205202958746148, 0.04332498001999088, 0.04276392316179616, 0.004939239605196885, 0.058121321589819024, 0.06326009120259966, 0.037221635558775494, 0.012535976877968227, 0.049323389040572305, 0.05940098435218845, 0.035434869650219164, 0.09275617809700114, 0.09374144487082958, 0.1178514768502542, 0.03953977920381086, 0.04036674375778862, 0.031776062944637876, 0.022345432113589983, 0.007808589476293751, 0.005348897489186908, 0.032713645670030794, 0.01480968835364495, 0.0021746078314858353, 0.025606946387727345, 0.035798998682626655, 0.003530495521512681, 0.02789305809086987, 0.031106908672622273, 0.07675318074013505, 0.06676709266113383, 0.05411897599697113, 0.08691940629588706, 0.017144400127498165, 0.04388617258518934, 0.03614199474187834, 0.1168329007923603, 0.013031704384567482, 0.06998532318643161, 0.03497327245505793, 0.024231549119576812, 0.038322446668254476, 0.023810845533651964, 0.0243814866989851, 0.016724371683916876, 0.004065939591133169, 0.009269991058057972, 0.019512316012488942, 0.07487977269504752, 0.032081766719264646, 0.03963834320061973, 0.0989993109500834, 0.016907185981316224, 0.07232683897018433, 0.014788641893704022, 0.05831070749887398, 0.022091093439874903, 0.04199969256296754, 0.03442561327080641, 0.045909696325127564, 0.044442330420549424, 0.029468202497810125, 0.02367620213356401, 0.07732583036912338, 0.05729065223463944, 0.05480448974828635, 0.07993838696607522, 0.13357089406677655, 2.6622428936617712, 16.70277111870902, 33.54082713808332, 33.06758533205305, 21.848426342010498, 9.375639489718846, 13.505665234157018, 35.34786946432931, 34.547204221997944, 20.5038126877376, 9.080917750086103, 6.443494038922446, 1.1529644238097327, 0.1757005634052413, 0.5546227991580963, 0.8589895612427166, 2.8046086600848605, 9.629802857126508, 9.922976885523115, 5.093081244400569, 3.156525147812707, 2.25565168261528, 1.7362449594906397, 0.5845547158803258, 0.4992571643420628, 0.43821422702499796, 1.3985736902270998, 3.666767631258283, 9.222262348447527, 16.78812105315072, 26.48696208000183, 35.66109773090908, 44.94228254045759, 50.56088774544852, 55.18698794501168, 55.15790278570992, 55.51869147164481, 54.65221984045846, 55.356027194431846, 54.50518206187657, 58.05272729056222, 58.05834143502371, 59.318904467991416, 55.80663871765137, 56.55037042072841, 53.56936740875244, 55.72349657331194, 51.79343911579677, 49.87160907472883, 52.84600782394409, 56.32105902263096, 54.49065685272217, 54.86267382758004, 53.74507345472063, 52.92714888708932, 52.79334395272391, 53.18839768001011, 55.799200671059744, 52.7462351662772, 50.60398047310965, 54.66424022402082, 54.89981542314802, 50.45316287449428, 42.22556121008736, 43.65539278302874, 38.5569748878479, 21.34647979055132, 9.759040219443184, 4.744846650532313, 1.4242596604994364, 1.3545395902224948, 1.6910531158958162, 3.6464037639754157, 3.474826902151108, 3.199830229793276, 4.3815140553883145, 3.960520531449999, 4.789265181337084, 4.042619577475956, 4.797039347035544, 2.1877814616475786, 1.4529973013060433, 1.2715731050286974, 0.09974334495408194, 0.4125513812260968, 2.163383730820247, 7.745570387159075, 15.086140700748988, 21.059526136943273, 18.786945819854736, 18.2269001688276, 24.615791354860576, 25.296992744718278, 19.52371369089399, 5.999511965683528, 0.3010917721050126, 0.04061080601864627, 0.04406457640496748, 0.04320615157485008, 0.08282735837357384, 0.010194909775496593, 0.028188670353431786, 0.01182792049699596, 0.04314714616962841, 0.0055860781327023035, 0.012886976257764866, 0.062172976322472095, 0.00876306857181979, 0.01189921417140535, 0.010215245470005487, 0.020976212906784246, 0.02611000037619046, 0.03821224579587579, 0.02349145570769906, 0.0901569886399167, 0.08048102499118873, 0.04053340892174414, 0.07655067196381943, 0.040152367403996844, 0.02511978877841362, 0.1098957351808037, 0.10614261550030538, 0.03444362837555153, 0.024804275083754743, 0.017050114293981875, 0.0401687031345708, 0.03262309177911707, 0.04872423583375556, 0.038351671171507666, 0.05365267994680575, 0.022936734670240964, 0.03756441109414611, 0.1131512579907264, 0.08962351762290512, 0.13938668556511402, 0.06924114669007914, 0.11215253586747817, 0.16730203692402157, 0.14216544931488379, 0.17182835404361996, 0.12892526334949903, 0.1395365060972316, 0.09952322819403239, 0.12154709068792206, 0.1444593590817281, 0.15043854181255611, 0.15591479438756192, 0.1141556730227811, 0.1033985520313893, 0.14086496909814222, 0.05220214510336518, 0.16638711387557642, 0.12045285797544888, 0.18711467592843942, 0.12206272301929337, 0.10387976228126458, 0.21216481817620142, 0.19026336339967592, 0.09565380761133772, 0.2113279402256012, 0.12331837921270303, 0.2084419136600835, 0.12344318894403321, 0.1000515152035015, 0.22959537857345172, 0.10238233727536031, 0.1187131077583347, 0.07453506333487374, 0.1515193259609597, 0.1621681595487254, 0.23228533565998077, 0.1973451112530061, 0.13033458058323177, 0.1221448393272502, 0.1165996068822486, 0.21328763078366006, 3.027324480669839, 17.114215646471294, 40.04676941462925, 42.94276816504342, 31.73097426550729, 14.50119183744703, 11.17115649155208, 29.924133437020437, 48.42828410012381, 34.07809312002999, 11.512438978467669, 6.117852815559932, 1.5217116198369434, 1.7296923739569527, 2.777744318757738, 5.270077049732208, 8.779574377196175, 19.053310223988124, 27.691828353064402, 8.39579062802451, 4.435620546340942, 5.535245929445539, 2.4293848744460513, 1.2983408229691642, 0.4195029724921499, 0.2793280870786735, 1.7449168541601725, 3.2226518051964894, 9.178150841167994, 15.728724002838135, 25.222037315368652, 35.815260887145996, 44.63999073845999, 49.84725216456822, 56.91452898297991, 57.53067438943045, 57.46752568653652, 55.898090907505576, 57.92520005362374, 55.67462641852242, 59.32036358969552, 58.59479795183454, 59.56812245505196, 56.194209235055105, 59.09579086303711, 55.30951942716326, 55.07088007245745, 54.72187205723354, 50.382899216243196, 52.25043255942208, 57.78444692066738, 55.59494795118059, 56.45452002116612, 55.49829156058175, 55.30273103713989, 54.44465282985142, 54.256644998277935, 56.12037420272827, 53.40646341868809, 48.79557629993984, 53.36814062935965, 52.53877932684762, 51.24121018818447, 47.92530400412423, 45.406081744602744, 36.397728375026155, 19.272263595036097, 8.943035960197449, 3.5909024221556525, 1.13395827795778, 1.773003644176892, 2.7043244412967136, 2.717300853558949, 4.167387511048998, 6.121142787592752, 6.619844964572361, 7.768160717827933, 6.966640412807465, 5.851058057376316, 9.410839932305471, 8.818413070269994, 6.900096646377018, 5.614128828048706, 3.039722238268171, 0.9704926780291966, 2.6811417766979764, 9.208074126924787, 18.122824839183263, 19.0177059173584, 18.24510271208627, 23.816842317581177, 33.60312121255057, 30.595513548169816, 21.938431569508143, 5.62052594763892, 0.3911841506404536, 0.13463580049574375, 0.2124488800764084, 0.1775479699884142, 0.1932451312563249, 0.11119329769696508, 0.18099259372268403, 0.16682951870773519, 0.15655587427318096, 0.11626812895493847, 0.16357667611113616, 0.14355317556432315, 0.12664854766002723, 0.0883972691372037, 0.08696880364524466, 0.08496862490262304, 0.14475965153958115, 0.11652760074606963, 0.1486193894275597, 0.1562453495072467, 0.17152282329542295, 0.14074165214385304, 0.2474146852535861, 0.18513644779367106, 0.15685669598834856, 0.13808103491153034, 0.23962724741016114, 0.20518079293625696, 0.0672922312681164, 0.12568915342645987, 0.11615694420678274, 0.10248914547264576, 0.08590636029839516, 0.16152463693703922, 0.20385633329195635, 0.07569936157337256, 0.11023413416530405], [0.03208162083423563, 0.019879420420953205, 0.043486827585314, 0.05541359706382666, 0.024669178761541843, 0.0661765636344041, 0.0432156307090606, 0.005383990896267018, 0.049598273754652054, 0.04455999178545816, 0.02074598427861929, 0.03479626302474311, 0.05372216871806553, 0.04065799134384308, 0.05942619192813124, 0.05636498797684908, 0.02325374792729105, 0.15275303833186626, 0.03788430303601282, 0.03179716877639294, 0.05271629144304565, 0.03571194603240915, 0.05378902816612806, 0.02225819116990481, 0.06025435070374182, 0.05822456069290638, 0.016601044551602433, 0.06580200551876, 0.03824162296950817, 0.03282945802701371, 0.08087165081607443, 0.033603344179157696, 0.03266662997858865, 0.09180273461554732, 0.04318683707554426, 0.01106099526597453, 0.08083166474742548, 0.0640044305473566, 0.01902876142412424, 0.007767566945403814, 0.01676536537706852, 0.07139496611697332, 0.03432031820661255, 0.06100441688405616, 0.07411118250872407, 1.5521239936351776, 9.462531055722918, 23.84652849606105, 30.22504254749843, 26.584738867623464, 11.912581392696925, 3.8476409656660895, 10.428020596504211, 30.388189724513463, 40.30909865243094, 12.287218706948416, 5.4719026769910535, 1.8194303129400526, 0.16930055325584753, 0.5406683193785804, 1.3765495291778018, 10.014744349888392, 9.20339104107448, 2.90779071194785, 2.712410624538149, 0.9184391626289913, 0.47829575198037283, 0.28447081255061285, 0.6687775222318513, 0.2310185379215649, 0.1401927580258676, 0.21377449323024067, 0.9271789108003888, 2.6304620504379272, 8.24420612198966, 13.768925530569893, 19.353065933500016, 27.37991850716727, 37.33778142929077, 43.55334806442261, 53.19851425715855, 54.87912368774414, 57.1187504359654, 54.42840794154576, 57.86301367623465, 53.049843651907786, 56.63020869663784, 52.97353853498186, 55.53446735654558, 44.54734345844814, 54.9713089125497, 50.08584983008248, 35.58066885811942, 50.81678989955357, 52.77771050589425, 59.468061447143555, 52.55502074105399, 54.60649027143206, 50.60083988734654, 52.60999141420637, 51.72213670185634, 54.58051790509905, 52.6754469190325, 53.589350427900044, 50.52615370069231, 46.7384683064052, 35.93943214416504, 33.39428962979998, 24.583588191441127, 8.235640730176653, 1.6040211745670863, 0.5830134100147656, 0.12589317533586705, 0.7331385229315076, 1.6091515507016863, 1.560390504343169, 2.228320074932916, 3.38406149830137, 1.9450359387057168, 3.064544026340757, 2.955329635313579, 3.740699504102979, 4.423924991062709, 3.7138581786836897, 1.7100406970296587, 0.8360607230237552, 1.3025234213897159, 0.23154931515455246, 2.715897534574781, 7.573850001607623, 15.78926192011152, 12.635254842894417, 11.184315511158534, 9.306940044675555, 22.14449429512024, 27.16565864426749, 12.679784979139056, 5.106440458978925, 0.23013782660876, 0.04547820912141885, 0.012105200439691544, 0.04137732667316284, 0.0382954240111368, 0.028219866000914147, 0.0962442619992154, 0.04842033017692821, 0.0955969938742263, 0.0398739102030439, 0.07718894949981145, 0.023813050772462572, 0.022586576673867445, 0.05393490980246237, 0.02827975689433515, 0.0218487393909267, 0.018929839500093033, 0.016053076633917432, 0.04355130876813616, 0.14451607103858674, 0.04052422155759164, 0.026141879647704105, 0.04602550528943539, 0.04945965922836747, 0.05905981015946184, 0.030219401831605604, 0.08237159997224808, 0.021391194746164337, 0.0031362543772307356, 0.05703782330134085, 0.02640784501896373, 0.04741461235763771, 0.0757456783737455, 0.017633198095219474, 0.02275279739738575, 0.08440527798874037, 0.08016723647181477, 0.030115555439676558, 0.04295842183221664, 0.01324041751545987, 0.027761717459985187, 0.0411306927645845, 0.03271974230717335, 0.02822757585506354, 0.06186855837170567, 0.020189490568424975, 0.023591604083776474, 0.008695045436200286, 0.020625980271558677, 0.02826008277146944, 0.01832200274137514, 0.05270638483177338, 0.038231064964618, 0.015524226440382856, 0.006530535266002906, 0.09895436479044811, 0.0420102064630815, 0.033839976481561146, 0.015112486302054353, 0.02495252650364169, 0.047354453442884345, 0.029858506018561975, 0.06155166894729648, 0.04887217003852129, 0.041995495823877196, 0.0060241318590539905, 0.022162843429084336, 0.020238071979422654, 0.08867272042802402, 0.021599842568061182, 0.017187982431745956, 0.03297344994332109, 0.0077608002549303425, 0.05008299542324884, 0.012941762871508087, 0.08151213359087706, 0.035047795956156085, 0.05441642200042095, 0.029211641621908972, 0.0626613519021443, 0.027009792093719755, 0.06278924218245915, 0.05307218984567693, 2.123692363500595, 15.13731939452035, 29.331910678318568, 35.52292932782854, 23.664800098964147, 8.536147713661194, 6.846496939659119, 22.490761246000016, 38.55037062508719, 29.628967012677872, 11.315223915236336, 9.111783385276794, 1.7118517884186335, 0.05763655581644603, 0.28814681672624176, 1.9488385575158256, 3.3783433479922156, 2.818714806011745, 2.998587165560041, 4.590208845479148, 2.6642704648630957, 2.0169880092144012, 1.4820199268204826, 2.2021446909223283, 1.1880894133022852, 0.24322033460651124, 0.5030708568436759, 1.0492330299956458, 4.179185117994036, 9.337783966745649, 17.325826508658274, 22.951909712382726, 31.407876082829066, 42.26968574523926, 47.674331596919465, 53.17017602920532, 55.38262489863804, 55.140164034707205, 53.670446327754426, 57.6403933933803, 54.9640063558306, 58.34333569662911, 53.88217183521816, 55.71111488342285, 50.87848990304129, 53.10894502912249, 48.092800753457205, 40.942416531699045, 51.88955354690552, 53.18314484187535, 58.43309252602713, 54.336677823747905, 54.504931926727295, 52.406454358782085, 53.03479037966047, 53.61653872898647, 54.91411134174892, 52.06996004922049, 53.165228911808555, 52.56214959280831, 50.86679261071341, 40.88492366245815, 38.30620050430298, 29.59571988242013, 11.702224680355616, 3.9213140181132724, 1.1208890421049935, 0.8548821987850326, 1.6078290045261383, 2.4362837842532565, 2.9796746032578603, 3.5565101419176375, 4.939578601292201, 2.994232382093157, 5.089433874402728, 3.7381655829293385, 2.9179585320608954, 3.3044527300766537, 3.22995588183403, 0.615006607558046, 0.8419793940016201, 0.2459748610854149, 0.41151151273931774, 2.2277616134711673, 8.634198955127172, 19.064191102981567, 18.617376770292008, 15.38887197630746, 9.24719682761601, 23.198994602475846, 31.944812025342667, 18.67221542767116, 8.028586149215698, 0.5998382557715688, 0.05576544121972152, 0.008545024736252214, 0.0848077917471528, 0.03202564848054733, 0.016793516098654697, 0.07795796716319663, 0.03134094897125449, 0.012559967331721314, 0.03923544606992176, 0.1007790540211967, 0.018447267091167823, 0.029249799038682665, 0.0807273874857596, 0.043491370377263854, 0.01867102419159242, 0.018188183761334846, 0.014437847770750523, 0.017148849620882953, 0.06625542975962162, 0.02097999065050057, 0.00983926497532853, 0.03035261861181685, 0.007522514023418937, 0.014753086658726846, 0.004364864800923637, 0.05357795627787709, 0.043419313350958486, 0.014208670871864473, 0.042854843461619954, 0.01937104502160634, 0.03256609144487551, 0.04885395476594567, 0.011271347058936954, 0.04894870539594974, 0.018434488580429127, 0.030795603591416563, 0.013451201874496681, 0.0834039638617209, 0.10615537195865597, 0.13601256161928177, 0.15699325794620173, 0.12076127928282533, 0.11490624131900923, 0.11748836562037468, 0.09228953599397625, 0.14169370462851866, 0.09752428438514471, 0.06552557035216264, 0.11361576949379273, 0.15945460301424774, 0.14559617665197166, 0.17232049549264566, 0.1922281701117754, 0.12201819755136967, 0.24515673784273012, 0.11688584009451525, 0.13265507535210677, 0.15305817552975245, 0.23105933144688606, 0.11825449950993061, 0.13262577621000154, 0.1507378571799823, 0.16741742858929293, 0.11017193964549474, 0.13003504808459962, 0.15481669402548245, 0.17945021577179432, 0.15331836656800338, 0.1206946742853948, 0.19106178198541912, 0.2327286632997649, 0.1323244795203209, 0.09437958669981786, 0.12235029973089695, 0.1107258413519178, 0.10198288370988198, 0.1583342467035566, 0.10701022430190019, 0.25006743147969246, 0.12520227740917886, 0.15181811207107135, 0.19632698302822454, 2.544695875474385, 15.869079351425171, 34.19305106571743, 43.97636134283883, 38.262687410627095, 19.405418872833252, 9.618273190089635, 17.41705983025687, 35.419223989759175, 47.07847145625523, 16.166488306862966, 7.808620078223092, 2.506104494844164, 0.41223181837371414, 2.0366718215601782, 4.122934239251273, 16.745483432497295, 17.890612568174088, 9.493561710630145, 8.165337119783674, 2.636442712375096, 2.3994900328772406, 1.951788284948894, 3.726554274559021, 0.7505575482334409, 0.3288506125765187, 0.48529931902885437, 1.579701828105109, 3.7024366429873874, 9.190796562603541, 16.03627732821873, 21.130772965294973, 30.68486738204956, 39.494905267442974, 45.910896165030344, 53.739313398088726, 56.49108839035034, 56.20083434241158, 53.71860081808907, 57.461254937308176, 55.72381271634783, 58.52072320665632, 55.65504986899239, 56.08065482548305, 48.378125054495676, 53.784393310546875, 49.776272841862266, 44.37326329095023, 55.138843876974924, 54.47950846808297, 60.09316308157784, 54.76753214427403, 56.23139251981463, 53.40256895337786, 54.6042286327907, 52.711723463875906, 55.60341780526297, 51.81340823854719, 54.211592878614155, 50.9313656943185, 52.57828678403582, 44.328850405556814, 40.604664598192485, 26.358842509133474, 11.158798251833234, 2.341426108564649, 0.9046118674533707, 0.8858373463153839, 2.215635269880295, 2.9242119107927596, 3.933067330292293, 5.9749800477709085, 7.252830633095332, 6.193306343896048, 8.836086681910924, 7.416451590401786, 8.303765211786542, 11.078397171837942, 9.740137645176478, 5.748073594910758, 3.9085480059896196, 2.82242015004158, 0.645597517490387, 3.5323866478034427, 10.313353606632777, 20.339592014040264, 19.21205050604684, 17.67264931542533, 14.379990935325623, 30.206852163587296, 38.00940472739083, 21.190400668552943, 7.582151361874171, 0.5947800757629531, 0.19982272759079933, 0.15565905453903334, 0.17219891558800424, 0.13798852344708784, 0.11421508554901395, 0.19764985490058148, 0.13376899915082113, 0.14577977465731756, 0.13598793079810484, 0.19219980734799588, 0.08022798571203436, 0.11604645156434604, 0.10199133147086416, 0.12734680090631756, 0.09758062314774309, 0.1079075393666114, 0.06618343719414302, 0.07838861298348222, 0.26506780513695305, 0.16979665734938212, 0.142405311443976, 0.11595429293811321, 0.11255080199667386, 0.1433370350194829, 0.07751427989985261, 0.1350554201219763, 0.13366101708795342, 0.10879021164562021, 0.1345114657389266, 0.14316200012607233, 0.06671794636973313, 0.2322406880557537, 0.09864101053348609, 0.12471016310155392, 0.14024385171277182, 0.1570826752909592, 0.15016407439751284], [0.030403532486941134, 0.054148125861372264, 0.04759766414229359, 0.007511276635341346, 0.037428144299026044, 0.07693727407604456, 0.11673851657126631, 0.05987849658621209, 0.012325547901647431, 0.08152106311172247, 0.039712154239948304, 0.06582388148776122, 0.09196054150483438, 0.03381357468398554, 0.003920923511032015, 0.0374258067458868, 0.02808537527120539, 0.011037536614042307, 0.047721998899110725, 0.06716247501650027, 0.0468606767244637, 0.045693966293973584, 0.03852243468697582, 0.03999613471595304, 0.05368209783253925, 0.04545122717640229, 0.016707533837429116, 0.035514383776379485, 0.03468052530661225, 0.06766243997429099, 0.03659378371334501, 0.0491569172590971, 0.030490116947995763, 0.05693822114595345, 0.04011909543935742, 0.020653140332017626, 0.04141896836725729, 0.04996959186558213, 0.05259695748931595, 0.01617903817844178, 0.015389009678204144, 0.039271859651697535, 0.028758230951747725, 0.0425366342865995, 0.005353043762235237, 0.06736654442335878, 0.4275360128709248, 5.852027765342167, 21.03377263886588, 30.693333762032644, 34.24439130510603, 26.361237900597708, 11.99296944481986, 5.701297887734004, 21.656004667282104, 42.87112181527274, 25.126836572374614, 11.170946308544703, 4.806314757892063, 0.25300692660467966, 1.8561235325677055, 3.4759316657270705, 2.3418853410652707, 3.532938812460218, 3.5823090204170773, 3.539866600717817, 2.331568568944931, 1.464742362499237, 1.4607953514371599, 1.470755159854889, 0.166506807452866, 0.25684971468789236, 0.28728749283722466, 0.302987951785326, 0.46983566880226135, 2.4403528230530873, 3.7771228296416144, 6.3185780218669345, 10.514074036053248, 20.000488655907766, 30.411045823778423, 47.552599157605854, 54.30521638052804, 57.69616310937064, 57.85854251044137, 54.43235451834542, 54.706738880702424, 56.877307483128135, 50.03210203988211, 42.610779762268066, 46.71574074881417, 34.41193321772984, 33.29093517575945, 46.465480531964985, 47.075553212847026, 53.699437686375205, 52.08821644101824, 50.58195120947701, 51.6631360735212, 57.433976309640066, 55.773697308131624, 55.66989469528198, 52.24024302618844, 49.6235340663365, 42.940176486968994, 33.20026813234602, 27.408682312284196, 18.400914328438894, 3.703962641102927, 0.2780248112976551, 0.42712623200246264, 0.17874083455119813, 1.245978764125279, 1.3938548862934113, 2.920393007142203, 3.367051656757082, 5.952305470194135, 4.352831023080008, 2.224049972636359, 2.4388070659978047, 3.44496528165681, 2.872117357594626, 2.698188530547278, 2.413583368062973, 0.46738078338759287, 0.5694262076701436, 0.7707343569823674, 4.814592233725956, 9.928762997899737, 18.141082968030656, 13.526977964809962, 12.32411972114018, 15.362110989434377, 20.80158121245248, 26.71663304737636, 15.771955694471087, 4.597544406141553, 0.44121042053614346, 0.12863280118576118, 0.03133296939943518, 0.035592920812112946, 0.025442606902548244, 0.09390611853450537, 0.029427266480135064, 0.009107832214795053, 0.04602229242612209, 0.0211340740788728, 0.024773978495172093, 0.02988526065434728, 0.013028154798251177, 0.04549369329054441, 0.013179882013771151, 0.06719988265207835, 0.04620271149490561, 0.025287196938214556, 0.046313523048801084, 0.06707356657300677, 0.0534240272162216, 0.026306578756443093, 0.05172190176589148, 0.07808557924415384, 0.1274851949087211, 0.03214613933648382, 0.04822971272681441, 0.028823563696018288, 0.05727866252085992, 0.017260283730658035, 0.033029958339674134, 0.03352593690423029, 0.02403258908140872, 0.032962966577282975, 0.06384612832750593, 0.09407444271658148, 0.031757674645632505, 0.05057281967518585, 0.02342710005385535, 0.03925983601116708, 0.05418838673670377, 0.032711610064974854, 0.021342940728313158, 0.04581456232283797, 0.02053921090971146, 0.07055699572499309, 0.05454393230112536, 0.017320077932838882, 0.04998027539945074, 0.026901313003950884, 0.02692145531597946, 0.1329119551394667, 0.049285448755004575, 0.01639990641602448, 0.06946371974689619, 0.0418223438651434, 0.06430259919060127, 0.00316944088886625, 0.03931429183908871, 0.03383958971660052, 0.056603615172207355, 0.09271978826395103, 0.012547270245184856, 0.027433934155851603, 0.06201163426573787, 0.049545334452497106, 0.06707703388695206, 0.02506027277559042, 0.018110033490562012, 0.020750581353370632, 0.02334523480385542, 0.027211988743926798, 0.07538460953427212, 0.013940541822064136, 0.017896021849342754, 0.08606154125716005, 0.04939632137705173, 0.03254307892971805, 0.055142026993313005, 0.03613205759653023, 0.05579947314358183, 0.01191626490825521, 0.01098205619824252, 0.043678785142089636, 0.09846651168274027, 0.8872612384813172, 10.253553935459681, 27.179605415889196, 35.05329711096627, 32.290095806121826, 18.94016228403364, 8.782435297966003, 11.118973783084325, 34.51942184993199, 34.55344023023333, 16.382591179439, 10.81650914464678, 4.132776362555368, 0.131206498082195, 0.3592601365276745, 0.3596535511314869, 1.800997284906251, 2.616187410695212, 3.3540114079202925, 3.454093260424478, 3.454044188771929, 4.424953758716583, 3.8614487733159746, 3.322577106101172, 0.8047302099210876, 0.8696093942437852, 0.7541734884892191, 0.865603432059288, 1.1092820763587952, 3.513366171291896, 5.583905032702854, 9.306432826178414, 15.395742007664271, 24.80794726099287, 36.06462478637695, 49.97688817977905, 55.91520779473441, 58.07838698795864, 59.87560108729771, 56.554393427712576, 55.58827420643398, 56.42678281239101, 51.58109521865845, 44.802964210510254, 50.703826086861746, 35.69188172476632, 36.532978534698486, 52.2352021081107, 50.820861543927876, 53.6698522567749, 51.51010547365461, 51.58134535380772, 51.91989633015224, 55.807854652404785, 56.440359592437744, 56.93937226704189, 54.95415728432791, 52.964415550231934, 47.38348695210048, 35.85502542768206, 34.185373306274414, 22.899784326553345, 6.187562354973384, 1.009138124329703, 1.2683189596448625, 1.0606259043727602, 2.1114776475088934, 3.166005096265248, 4.880532375403813, 4.661973748888288, 5.511543018477304, 5.242652944156101, 5.084846760545458, 5.246157007558005, 3.759371050766536, 2.9838628470897675, 2.6090700668948035, 1.322516645703997, 0.2107639962009021, 0.24786547677857534, 1.0789394016776765, 4.014537130083356, 11.014267035893031, 21.48638698032924, 17.182530335017614, 15.381477355957031, 13.59614988735744, 19.216966356549943, 30.127757344927105, 21.988317898341588, 7.776084269796099, 0.9737548572676522, 0.06538010601486478, 0.04037577845156193, 0.04210126246990902, 0.044087154657713006, 0.021921963497464145, 0.013863012410833367, 0.025189496377216916, 0.03531674688149776, 0.020147572371310422, 0.047819222789257765, 0.01322427686370377, 0.007991642957287175, 0.02378591106805418, 0.05762298511607306, 0.016656492736988833, 0.035369224779840024, 0.010140490418832217, 0.027424960530229976, 0.028259312634223273, 0.07482624306742634, 0.020594888100666658, 0.051105846251760206, 0.07493890023657254, 0.10370450347129788, 0.040271497797220945, 0.05307056814698236, 0.0524652029520699, 0.04451384461883988, 0.03578862727486661, 0.045422406401485205, 0.007644807237998715, 0.020933139503800442, 0.01517185811618609, 0.02247850640144731, 0.030903500837406943, 0.01825384559508945, 0.015002120884933641, 0.01934520131908357, 0.13340698714767182, 0.19631984483982834, 0.08350039047322103, 0.08984492359949009, 0.13179481508476393, 0.13885275992963994, 0.22411065788141318, 0.13771113833146437, 0.11490914544888906, 0.21772364846297673, 0.1521404433463301, 0.1573365559535367, 0.30526462676269667, 0.08112378764365401, 0.10016343276947737, 0.16663897250379833, 0.0646911622690303, 0.1743704719202859, 0.21638929577810423, 0.15197699783103807, 0.14888233531798634, 0.21049586630293302, 0.15190393318023, 0.11364041388567005, 0.22898011015994207, 0.18189405463635921, 0.22215441428124905, 0.13839088114244597, 0.1238542590290308, 0.1305614284106663, 0.12567806616425514, 0.12685446946748666, 0.14909082198781626, 0.1852799036673137, 0.08933247359735624, 0.11443931423127651, 0.13827244964029106, 0.13896813802421093, 0.1910310714904751, 0.17206375141228947, 0.10970238662723984, 0.12740854759301457, 0.08669471620981183, 0.10966637677380017, 0.19021283968218736, 0.15806904807686806, 0.9468644601958138, 10.046414239065987, 30.849504947662354, 43.48835808890206, 46.95294877461025, 34.460174560546875, 19.445992878505162, 12.433579904692513, 31.974268913269043, 47.51809092930385, 30.254923275538854, 13.633010080882482, 6.568568127495902, 0.5302701773388045, 3.861244235719953, 8.32467234134674, 6.6867504715919495, 10.112457735197884, 9.018216337476458, 10.043970210211617, 6.305775531700679, 6.38160730259759, 7.4072174344744, 3.8318702919142584, 0.528723443193095, 1.0046692384140832, 0.7275225328547614, 0.8624998671667916, 1.076077720948628, 3.2001544066837857, 4.819805553981236, 7.950516189847674, 13.102504696164813, 22.493528366088867, 33.041196073804585, 52.48693534306118, 56.960307189396445, 57.91757787976946, 58.170704228537424, 54.85476677758353, 55.920512744358604, 58.33838857923235, 52.26815046582903, 45.3439370564052, 51.53245782852173, 38.38691077913557, 40.67389644895281, 52.79515743255615, 52.1335951260158, 55.75627817426409, 53.21747241701399, 51.7841910634722, 53.72083813803536, 58.45913437434605, 56.39135047367641, 57.28352696555001, 54.56447104045323, 52.71367590767996, 49.60396099090576, 40.08606147766113, 34.33584002086094, 19.812724011284963, 4.723727600915091, 0.5553599053195545, 0.9402332731655666, 1.1049495488405228, 2.9293904900550842, 5.23054483958653, 7.160720101424626, 8.473424587930952, 12.620783482279096, 10.764139703341893, 7.250324070453644, 8.915515882628304, 8.85540701661791, 8.329851354871478, 5.998844938618796, 6.553501393113818, 2.3405302252088274, 1.4546700801168169, 1.815747550555638, 6.123371422290802, 12.042308603014265, 23.759299073900493, 19.64063102858407, 19.405698537826538, 21.897682121821813, 29.446649755750382, 36.460234369550435, 23.52428146771022, 8.267547726631165, 0.8839354940823146, 0.14130016788840294, 0.14561269219432557, 0.11949032891009535, 0.08315125027937548, 0.3146789473082338, 0.11512854296181883, 0.14306264902864183, 0.15732780285179615, 0.09157840415303196, 0.09584695938974619, 0.13721101731061935, 0.12249830178916454, 0.1424164529889822, 0.10740383568086795, 0.11562196005667959, 0.15039807398404392, 0.07627432500677449, 0.06971101183444262, 0.15564817083733423, 0.18509528785943985, 0.0849649268867714, 0.14448869893593447, 0.14401299160506043, 0.18234517185815743, 0.14056045615247317, 0.14191089011728764, 0.1923533733934164, 0.15237381868064404, 0.1257959684090955, 0.1516472026705742, 0.10382056688623768, 0.13020574035389082, 0.13578534738293715, 0.18137569459421293, 0.20055321125047548, 0.09727242575692278, 0.13934207867298806, 0.07100513417805944], [0.06306201325995581, 0.01847946866681533, 0.055430889528776915, 0.01606974484665053, 0.0407382586438741, 0.053229379268097024, 0.012300274168540324, 0.03702585106449468, 0.014209729386493564, 0.03631826117634773, 0.05675438565335103, 0.04613406749974404, 0.027231111557089856, 0.06173714649464403, 0.0018947941966221801, 0.07114529237151146, 0.0361434705555439, 0.043709577061235905, 0.02615611022338271, 0.02879505165453468, 0.043650663258241754, 0.05399404412933758, 0.041948948321597915, 0.0435868809664888, 0.045656813109027486, 0.025532606091084223, 0.11504490673542023, 0.002111258105807272, 0.04356857069901057, 0.044794418849051, 0.024485516295369183, 0.03589999522747738, 0.049196564060236724, 0.004848301917913237, 0.02084284515253135, 0.013696721289306879, 0.012320163726274456, 0.027670865013663257, 0.018891468344788467, 0.0581889036776764, 0.039729178683566194, 0.06916675889598471, 0.043646666686981916, 0.02611549650984151, 0.018231007802699293, 0.03507477111582245, 0.07010267581790686, 0.20895712529974325, 4.836410445826394, 13.768737929207937, 27.392298460006714, 34.86709928512573, 32.70073781694685, 24.378291504723684, 8.705708946500506, 22.29246834346226, 38.08608852113996, 15.786807468959264, 10.955856135913304, 5.7157197424343655, 0.9191681806530271, 0.06209700075643403, 0.8872020159448896, 0.1831022405198642, 1.974680210862841, 2.7385456221444264, 2.275016312088285, 3.0957227647304535, 2.0757693350315094, 3.4885899807725633, 1.0311725991112846, 0.34928879301462856, 0.6346864029765129, 0.5084815493651799, 0.10110369231551886, 0.2549770666020257, 0.08896353375166655, 0.26105513902647154, 0.3777381107211113, 2.633775472640991, 8.788378613335745, 18.277100903647288, 30.760585376194545, 44.81725318091256, 49.500745500837056, 53.84106281825474, 55.14493744713919, 60.192140170506065, 59.830500330243794, 50.56873573575701, 29.15276527404785, 37.65773902620588, 44.68442446844918, 45.2899808202471, 47.17448513848441, 51.124136516026084, 54.96528482437134, 54.94438464300973, 54.46221440179007, 54.66375732421875, 57.4587779045105, 50.12704917362758, 47.10033048902239, 37.155724729810444, 31.274171897343226, 20.30973039354597, 10.300881590162005, 1.18764386006764, 0.31874988600611687, 0.32255397045186585, 1.2370500032390868, 1.7575066643101829, 1.765975541302136, 3.4326576335089545, 2.8870850801467896, 2.588740289211273, 3.378123176949365, 3.7762951254844666, 3.297448511634554, 4.354110794407981, 2.3532028709139143, 0.9761788014854703, 1.4177008867263794, 0.7308641821146011, 0.17125709541141987, 2.1097733846732547, 6.158359944820404, 12.64880383014679, 13.255259105137416, 10.683237484523229, 13.01932954788208, 11.547344122614179, 16.619820049830846, 24.882400682994298, 18.118501322610037, 5.6655789358275275, 0.6009686408298356, 0.0240062195142465, 0.03545686775552375, 0.04420223419687577, 0.033037927733468156, 0.026857355809105293, 0.08658810478768178, 0.04709059153018253, 0.0340806766014014, 0.07236094892557178, 0.0051818705812495735, 0.02969023951196245, 0.024786254889996986, 0.02354152819940022, 0.025213184034717933, 0.041737930716148446, 0.021660264415134276, 0.0340040666051209, 0.06680931110999414, 0.053075867505478005, 0.05724601820111275, 0.043952584200139554, 0.028399584482290914, 0.044926563543932777, 0.03965382397707019, 0.09306829742022923, 0.025967492755236368, 0.014110214592489814, 0.045264701292450936, 0.026981782168149948, 0.03106099899326052, 0.009226245057236935, 0.04431318824312516, 0.07608171605638095, 0.03429665769051228, 0.03161973526169147, 0.01467427481631083, 0.02172790587480579, 0.03537552497748818, 0.029339274058916738, 0.04024183903155582, 0.07568962459585496, 0.023639054037630558, 0.006388980138581246, 0.04451156474117722, 0.052900805470666716, 0.02045016167020159, 0.06009574992848294, 0.022648250418049947, 0.006737802269136799, 0.05831231562686818, 0.017413027052368437, 0.029359989733036076, 0.0584316360098975, 0.06059821868049247, 0.04607500441904579, 0.03273280071360724, 0.06166647028710161, 0.032811432744243314, 0.0024533623155938195, 0.024264078088370816, 0.07995494322053023, 0.019666584341653755, 0.023026911974219338, 0.06671793279903275, 0.05161969403603247, 0.060963731924338, 0.03453164115282042, 0.016071810985782316, 0.02698504931426474, 0.04150044685229659, 0.053885322463299544, 0.04575254761480859, 0.011558775341005197, 0.02571583938385759, 0.02248109331620591, 0.05334668779479606, 0.012164065897065614, 0.009431026925865029, 0.05582045344635844, 0.0422312494234315, 0.05193139945289918, 0.06748050437974078, 0.01528613019867667, 0.059120159064020426, 0.012126626879242914, 0.01453599107584783, 0.4354815493736948, 7.545659422874451, 20.226223468780518, 32.07653597423008, 36.80940566744123, 27.92713257244655, 15.410942929131643, 11.091016837528773, 31.018384388514928, 38.49629626955305, 22.07480733735221, 18.680212804249354, 6.689781188964844, 0.9077256917953491, 0.18958210067025252, 0.1408947839268616, 0.5354955483760152, 1.1818335375615527, 4.300908872059413, 4.755415294851575, 4.89474925824574, 4.535451395171029, 3.5101906274046217, 2.5330999834196906, 1.4847159364393778, 1.3806408239262444, 1.1707887245076043, 0.8511056357196399, 0.5472991264292172, 0.6547633313706943, 0.8563700903739248, 1.8855465480259486, 4.574772988046918, 11.706972905567714, 24.1622667993818, 35.82656560625349, 48.04356929234096, 53.01177447182791, 57.45228828702654, 58.03008311135428, 62.20557526179722, 59.419757570539204, 53.95766053880964, 33.14653076444353, 37.37609379632132, 45.98283086504255, 50.02882596424648, 50.218108790261404, 54.33732400621687, 54.6921511377607, 55.92824608939034, 52.875534193856375, 54.510282039642334, 56.72943939481463, 51.840530531747, 48.05931738444737, 42.14353077752249, 36.18955339704241, 27.762710400990077, 13.79516887664795, 2.5286214351654053, 0.5714953594974109, 1.1737584280116218, 1.922063674245562, 3.062178816114153, 4.498880420412336, 4.353334767477853, 4.308592276913779, 5.920530489512852, 4.904669548783984, 4.587840378284454, 3.7325935619218007, 3.845473561968122, 2.962762687887464, 1.0461821194205965, 0.7169687077403069, 0.356003711266177, 0.21440774282174452, 1.951588089976992, 6.146315676825387, 15.726271288735525, 19.847230502537318, 14.902744735990252, 13.04498837675367, 12.363498636654445, 17.769133738109044, 27.61681386402675, 24.063982793263026, 8.67434390953609, 1.1677468248776026, 0.052667857613414526, 0.03584514584924493, 0.026972135096522312, 0.021665299144972647, 0.04630380303465894, 0.0571594914155347, 0.021805409840973358, 0.03415029090163963, 0.04618577186816505, 0.059733988983290534, 0.031124974667493786, 0.06898548148040261, 0.03637374159214752, 0.02853246538766793, 0.06315682495811156, 0.052245547595833025, 0.01453061368582504, 0.01686310156115464, 0.04142896318808198, 0.014848383509420922, 0.02115760397698198, 0.011237466957287064, 0.03312851555113282, 0.034418675250240734, 0.02434483732629035, 0.06615822283285004, 0.05788325757852622, 0.06438740928258214, 0.03936121253562825, 0.02694303951492267, 0.017298168037086725, 0.046768904863191504, 0.033704445896936316, 0.049745258010391674, 0.02891669262732778, 0.026809661582644497, 0.013878652643013214, 0.014949089980551174, 0.03767936510433044, 0.18204596505633422, 0.12947774013238295, 0.1536195818334818, 0.07596147965107646, 0.1569963792072875, 0.11158041549580437, 0.10135677230677434, 0.08940638641693763, 0.19810648182673113, 0.1451787826206003, 0.13588610983320645, 0.11094053661716835, 0.14128443944667066, 0.1157237131680761, 0.09345515059041125, 0.1214791014790535, 0.16391153314283916, 0.14133019984832831, 0.1232837467853512, 0.12297124069716249, 0.0892350020419274, 0.18443489686719008, 0.11035427557570593, 0.1771915762552193, 0.1854301177497421, 0.1681974045932293, 0.25581245177558487, 0.11801642871328763, 0.15051590837538242, 0.11900045376803194, 0.14637532484318527, 0.16183408961764403, 0.08924610287483249, 0.11866890798721995, 0.133357399808509, 0.09769266285002232, 0.14810708191777977, 0.10950301946806056, 0.08869583811610937, 0.10463488354746785, 0.16468808933028153, 0.25535617768764496, 0.20694943517446518, 0.14259097219577857, 0.1239185705780983, 0.10754315927624702, 0.17977714751447949, 0.4861338628189904, 7.803340315818787, 22.022261585508073, 38.510793685913086, 46.496941975184846, 40.74057136263166, 34.02501583099365, 15.42207568032401, 31.227532114301408, 45.864899090358186, 21.107126508440288, 15.724947656903948, 7.60148298740387, 1.4946350327559879, 0.23104125527398928, 2.356517595904214, 1.0850934428828103, 5.106702753475734, 8.929209913526263, 9.992040242467608, 9.659742644854955, 8.544641017913818, 9.394245028495789, 2.7114404823098863, 1.922329659972872, 1.3318993193762643, 1.4714737555810382, 0.8723913878202438, 0.7353530441011701, 0.6149593815207481, 0.5915019373808588, 0.9698736369609833, 3.4619894538606917, 11.962954095431737, 21.285634415490286, 34.08340501785278, 49.18230955941336, 53.24172510419573, 56.91936492919922, 58.19507850919451, 61.579994201660156, 59.87754658290318, 53.427978515625, 36.53624766213553, 42.620451654706685, 49.05756507601057, 53.23076432091849, 54.64501108442034, 56.12690550940377, 57.258871282849995, 56.29384987694876, 56.14820868628365, 55.96721158708845, 59.13607651846749, 52.607986858912874, 51.819244725363596, 44.885199614933555, 38.49531657355172, 25.15360450744629, 11.772304211344037, 1.7271559557744434, 0.7356030164020402, 0.8638320756810052, 2.920500704220363, 3.6384013933794837, 4.36985628093992, 7.332675422940936, 8.548942821366445, 7.648993900844029, 6.265887226377215, 9.241557495934622, 7.519979749407087, 9.373489890779767, 7.106250132833209, 3.8806318811007907, 3.8675358295440674, 2.070844365017755, 0.48815122885363443, 3.0373526854174475, 8.659062215260096, 17.335456711905344, 18.696181501661027, 16.590804372514995, 19.911192144666398, 17.788199595042638, 25.226256608963013, 35.22272545950753, 26.87401843070984, 8.972363437925067, 1.2201391735247202, 0.12776355711477144, 0.13195100027535642, 0.18241187185049057, 0.0949081994060959, 0.2143582911895854, 0.18072256392666272, 0.14028016690696987, 0.1138349702315671, 0.1673587624515806, 0.09798785272453513, 0.08983540375317846, 0.0917574627591031, 0.1234520777527775, 0.12008828110992908, 0.16929701130305017, 0.06609524799776928, 0.23001547317419732, 0.17005199007689953, 0.15182435459324292, 0.11874651882265295, 0.1747001449444464, 0.13886437644915922, 0.1438232460724456, 0.11863350202994687, 0.19738017794276985, 0.2138859222510031, 0.14118449123842375, 0.15303412824869156, 0.09407313314399549, 0.12238396863852229, 0.16048190503248147, 0.14774524633373531, 0.121858986094594, 0.09903717320412397, 0.08413458322840077, 0.08797277762953724, 0.06023240688123873, 0.18352096447987215, 0.11494729268763747], [0.04231334198266268, 0.012025255443794387, 0.06918482149818114, 0.01802018697240523, 0.024910223237904053, 0.010711013688705862, 0.12766465385045322, 0.038186868586178334, 0.014790512954017945, 0.0165223667198526, 0.03061091314469065, 0.0302778915502131, 0.03276059350797108, 0.05342973369572844, 0.034055452062083144, 0.04344992545832481, 0.04874465295246669, 0.02819709266935076, 0.015302795018734676, 0.08688818011432886, 0.03663010908556836, 0.022721739153244665, 0.05282068405566471, 0.037919729349336455, 0.06325168415371861, 0.032338093500584364, 0.051743122948599715, 0.023657213331067135, 0.02131795197991388, 0.04619288291516049, 0.05994386664990868, 0.06583487375506333, 0.04368049844301172, 0.008306872515406991, 0.09169158379414252, 0.02274889242835343, 0.027762317963476692, 0.07498913896935326, 0.013958691785644208, 0.058703314646014144, 0.033261291283581934, 0.029619777042950903, 0.09181641388152327, 0.02073137372333024, 0.05200824693643621, 0.028161540827048675, 0.023845998736630594, 0.029541514813899994, 0.11141677999070712, 2.326391292469842, 12.046177881104605, 26.127910443714686, 35.477981431143625, 28.979412930352346, 22.091443061828613, 15.636729853493826, 9.039675848824636, 10.758906841278076, 17.09855614389692, 14.511358789035253, 8.697175690105983, 3.2798445991107394, 0.3876029242362295, 0.7489417663642338, 1.0451555230787821, 2.3093545266560147, 2.088049407516207, 3.9296509878976003, 2.519377725464957, 2.340706101485661, 2.7092127161366597, 1.19375664634364, 1.9097269305161066, 0.8817969688347408, 1.3536534777709415, 0.4551638960838318, 0.636285411460059, 0.18875362298318318, 0.9937447160482407, 0.3661757382963385, 0.7201206386089325, 4.22430237701961, 12.375214168003627, 23.068359783717565, 32.125718797956196, 37.60848672049386, 43.47431925364903, 47.8048917225429, 47.162600244794575, 37.85730171203613, 25.376342909676687, 30.742426259177073, 54.978076457977295, 50.736239433288574, 52.189743518829346, 58.100624697549, 53.569162436894004, 51.76539271218436, 51.587504931858604, 49.31639589582171, 45.59696960449219, 41.21692943572998, 29.596199308122905, 17.80898686817714, 9.344343066215515, 2.5546268054417203, 0.12383751278477055, 0.22357912068920477, 0.7364758838500295, 2.2843807467392514, 2.1862192026206424, 3.4373815400259833, 5.406714677810669, 2.517668468611581, 3.177459201642445, 5.066125707966941, 5.158642274992807, 2.112495558602469, 4.129696139267512, 3.543796024152211, 1.1878263588462556, 0.42198318083371433, 1.0448748809950692, 0.9356064242976052, 4.25652551651001, 9.530187402452741, 17.01138925552368, 18.345109871455602, 11.278471418789454, 12.095064537865774, 14.487159950392586, 20.315751007625035, 27.14523788860866, 19.07783215386527, 5.435035101005009, 0.6522181736571449, 0.04832577971475465, 0.032944015094212124, 0.007132042565249971, 0.03693326835387519, 0.02710098889656365, 0.023697477599073733, 0.01961370780398803, 0.055753431149891446, 0.03700577321329287, 0.02715513768738934, 0.042015044417764456, 0.04595768910699657, 0.10304667055606842, 0.02347653472263898, 0.044958882166871, 0.009080368509915258, 0.02076106471940875, 0.04484104438285742, 0.005632219362139169, 0.02300428452768496, 0.03482101598222341, 0.02193345279166741, 0.014343585685959883, 0.030611242234174694, 0.08618608635983296, 0.021711057850292752, 0.04982371022924781, 0.07806974902216877, 0.04693266250459211, 0.0633567145892552, 0.023319538682699203, 0.04424871723832829, 0.06995993240603379, 0.04137310618534684, 0.06253773639244692, 0.0178797845063465, 0.06753404079271214, 0.03517538768106273, 0.038998186122626066, 0.06813006595309291, 0.003688426031398454, 0.05704359763434955, 0.014979968412912317, 0.03087488023032035, 0.03408756712451577, 0.04084457829594612, 0.07069842956428017, 0.03019610433174031, 0.03288133881453957, 0.012144513910503259, 0.010825519017609102, 0.018063738742577176, 0.022932161344215274, 0.016381976128156697, 0.05844241114599364, 0.06037430212433849, 0.01576679083518684, 0.03848945788506951, 0.03551590708749635, 0.03732619780514922, 0.059831528392221243, 0.05459623038768768, 0.027013099951935664, 0.029217799327203205, 0.016031801168407713, 0.04693653015419841, 0.03698077937588096, 0.023458282130637338, 0.02451355505867728, 0.015494189391444837, 0.025217318009319048, 0.05054294377831476, 0.059378714832876406, 0.016249726260347024, 0.037073619929807525, 0.07065981413636889, 0.014344411802345088, 0.040874891847904236, 0.02093574168559696, 0.030536623738173927, 0.03462770814076066, 0.04430151065545423, 0.06784579370703016, 0.0212694214590426, 0.013327320887973266, 0.0715959956869483, 0.01883442560210824, 0.023657961415925195, 0.21421395322041853, 4.306027523108891, 17.933571543012345, 32.95469100134713, 39.785965306418284, 34.221827030181885, 20.627391610826763, 18.005893605096, 19.158589329038346, 13.18784247125898, 19.761015517371042, 19.05498821394784, 9.848299384117126, 1.9588328897953033, 0.5431857385805675, 0.3071248440870217, 0.6361473160130637, 0.23465825404439652, 2.963313115494592, 2.185648364680154, 5.955729629312243, 6.211676512445722, 3.8760135003498624, 2.455946534872055, 3.208374994141715, 2.036957783358438, 2.5128815940448215, 1.5355047711304255, 1.1226980707475116, 0.967597667660032, 1.424863936645644, 1.132188007235527, 2.4273679426738193, 6.029508641787937, 15.415544373648506, 27.293814693178447, 37.451148237500874, 42.527564661843435, 46.71823515210833, 50.725407191685264, 50.6418342590332, 44.12002924510411, 27.126106023788452, 34.424106461661204, 57.325834546770366, 55.63777664729527, 55.651836327144075, 60.46401623317173, 55.98587097440447, 53.23843513216291, 53.48424155371529, 52.4622414452689, 51.02324519838606, 46.41152776990618, 36.45125034877232, 25.175341946738108, 14.029337065560476, 4.499470583030155, 0.4221663852887494, 0.728457336979253, 1.7260590089218957, 3.467970550060272, 2.8716943860054016, 3.107463700430734, 5.65738136427743, 4.575155138969421, 3.931062774998801, 4.593535729816981, 4.118447440011161, 3.9070055059024265, 2.02271397624697, 2.892773049218314, 1.5635182793651308, 0.11111245024949312, 0.24153827343668255, 0.8919960558414459, 4.61708447762898, 11.242127997534615, 21.187937532152446, 21.52060338429042, 13.158872825758797, 11.26046689919063, 14.646674088069371, 19.09359587941851, 28.685257468904766, 23.726644277572632, 8.496937291962759, 0.9972586589200156, 0.08934246163283076, 0.02327130502089858, 0.04963234639061349, 0.048195847044033666, 0.034196468602333746, 0.007670906239322254, 0.01791134656273893, 0.02428212881620441, 0.03110429970547557, 0.043895644934049675, 0.009598795557394624, 0.02001315458411617, 0.024583171055253063, 0.018177062572379197, 0.024757072795182467, 0.016521891745339547, 0.03205687466210552, 0.015926809748634696, 0.03919664404488035, 0.023538817452000718, 0.0987294100757156, 0.008160614292137325, 0.028455872354762893, 0.01095313364307263, 0.016969638344432627, 0.018815675983205438, 0.02943511034495064, 0.04111555464831846, 0.02998609435079353, 0.040505826473236084, 0.015340679325163364, 0.02495713036374322, 0.014394063602334686, 0.02452033701618867, 0.012472164900308209, 0.04403025610372424, 0.03904428918446813, 0.01891802959809346, 0.023085858007626872, 0.03177021736545222, 0.1910004967025348, 0.20570405200123787, 0.11196062580815383, 0.10919295610593897, 0.11568690942866461, 0.0978438268814768, 0.17596977895924024, 0.11265436679657016, 0.06140211982918637, 0.08928025354232107, 0.22471026570669242, 0.23373324796557426, 0.13011761222566876, 0.0917042927550418, 0.1371708751789161, 0.1255801942731653, 0.19390845351985522, 0.09514784440398216, 0.08172458290521588, 0.1847681796976498, 0.1497601560716118, 0.17151614651083946, 0.1312378328293562, 0.11199105131839003, 0.14634430222213268, 0.11769306606480054, 0.24880272362913403, 0.1221981586090156, 0.07112517380820853, 0.08240974721099649, 0.26735346391797066, 0.217873821833304, 0.2357248296695096, 0.09343612446848835, 0.2543040955705302, 0.15725882298180036, 0.07211675774306059, 0.1583624059068305, 0.15603889844247273, 0.15249094739556313, 0.13706885065351213, 0.2227494487805026, 0.2140559631266764, 0.12363111600279808, 0.09414659813046455, 0.10156385440911565, 0.05973866408956902, 0.1369173066424472, 0.2879594867782933, 4.20149621793202, 17.72529581614903, 36.56963723046439, 47.76044757025582, 41.842757156917024, 31.495326110294886, 25.984416246414185, 18.78586711202349, 18.01633674757821, 24.348341294697352, 19.371921607426234, 12.063135828290667, 4.30535398210798, 0.6159312065158571, 1.7184454117502486, 4.6150529980659485, 6.661999251161303, 7.885871018682208, 9.76802510874612, 11.994722996439252, 6.657917184489114, 9.436811430113655, 4.315583033221109, 5.4918891702379495, 3.8658309153148105, 3.604153939655849, 1.5666110962629318, 1.4469643107482364, 0.8754610802446092, 2.232522649424417, 1.1419969094651086, 1.4410195840256554, 5.389645559447152, 13.00348504952022, 24.29170479093279, 33.571708406720845, 38.60753345489502, 44.77407012666975, 50.32038974761963, 50.80497448784964, 49.022573947906494, 33.4884272984096, 38.83043513979231, 58.96216310773577, 58.21999822344099, 60.17804227556501, 62.21321133204869, 60.080142157418386, 56.25671175548008, 55.78306000573294, 54.75757884979248, 52.889117922101704, 49.74529777254377, 36.39867680413382, 22.762536559786113, 11.616695829800197, 3.413282798869269, 0.30257654243281906, 0.47559279416288647, 1.898822384221213, 5.640691356999533, 5.244268834590912, 7.006617741925376, 11.605206983430044, 7.360587205205645, 8.266693098204476, 11.993761539459229, 11.85107159614563, 7.4333904300417215, 10.860444341387067, 8.7888936485563, 3.659374747957502, 2.023421606847218, 1.547358397926603, 1.2694478247846877, 5.075377234390803, 12.350632309913635, 22.16161118234907, 24.72262164524623, 17.58857958657401, 18.946697064808436, 21.888310738972255, 28.180587223597936, 36.116461821964805, 26.16633571897234, 8.225511125155858, 1.0074201822280884, 0.11822549892323357, 0.10868224993880306, 0.13832317691828522, 0.22106987104884215, 0.16247378529182502, 0.08672378465001072, 0.11494395429534571, 0.10617862535374505, 0.2632722929120064, 0.10674540565482207, 0.20213309861719608, 0.09601632173040084, 0.22738944765712532, 0.11826703883707523, 0.09115307126194239, 0.08778184466063976, 0.16702212765812874, 0.20530022867023945, 0.09431928529271058, 0.12210688207830701, 0.1706493587366172, 0.07313225325196981, 0.11029316671192646, 0.1522750918354307, 0.17252120615116187, 0.10084211028047971, 0.10437518105443035, 0.15660417239580834, 0.09632396272250585, 0.07959730098290102, 0.14207941107451916, 0.1739728639700583, 0.13068021275103092, 0.09570183431995766, 0.11728039463715893, 0.08188531428043332, 0.09861920241798673, 0.13214048796466418, 0.0697420412408454, 0.06901867541351489], [0.05310647622016924, 0.03717276068138225, 0.04796627829117434, 0.045986051870776076, 0.029299620472426926, 0.05566955743623631, 0.014262341295502015, 0.060224915854632854, 0.0047203276688898245, 0.009392534482425876, 0.0842707719919937, 0.02829610789194703, 0.018460137204134038, 0.03494008191462074, 0.028504655629928623, 0.01784518770208316, 0.06241712000753198, 0.03990415929417525, 0.014339975879660674, 0.030133740178176334, 0.035090431704052856, 0.045594214860882075, 0.0027653414789321168, 0.0264815067805882, 0.002252842707093805, 0.019575757340395024, 0.0631245266912239, 0.030373524275741408, 0.03496798327458756, 0.031563077587634325, 0.06586794555187225, 0.01547896136928882, 0.05177462732951556, 0.06869394890964031, 0.08632055164447852, 0.04715290140094502, 0.007217925590729075, 0.011538472725078464, 0.022563343634828925, 0.06573265923985414, 0.04797790838139398, 0.07435423375240394, 0.021994756734264747, 0.04663027337353144, 0.02744753030128777, 0.05618827370926738, 0.04113798701603498, 0.08891005162149668, 0.03477561181145055, 0.11746784672141075, 0.7423274612852505, 6.812623168740954, 20.142231907163346, 28.957053627286637, 29.983655180249894, 23.083784784589493, 20.432854209627422, 24.63886979648045, 24.30902143887111, 23.77923345565796, 18.268624101366314, 12.148629937853132, 6.201480899538312, 1.5847819383655275, 0.7441553803426879, 0.8596983860645975, 3.3227492911475043, 4.243572771549225, 3.4983265783105577, 4.441841355391911, 2.3001887670585086, 1.437449078474726, 1.8826068086283547, 2.1774894424847195, 1.9146851216043745, 1.3505736887454987, 0.7986065128019878, 0.8762848217572484, 0.4997572717922074, 0.47185341481651577, 0.16944977667714867, 0.3090153783559799, 1.112302697130612, 4.782411217689514, 10.988491824695043, 16.08602121898106, 20.43899815423148, 21.219381604875835, 21.46695113182068, 24.970917258943828, 24.79822846821376, 23.04221544946943, 37.423775809151785, 47.72354221343994, 43.72471843447004, 39.52649872643607, 35.664818491254536, 34.46405512945992, 22.722101518086024, 17.84421249798366, 10.302246042660304, 7.360754830496652, 2.8403736438070024, 0.8591989300080708, 0.13787268394870417, 0.046676844624536376, 0.44094421767762726, 1.5606235946927751, 1.0081554970570972, 1.9520108444350106, 2.133631761584963, 2.2370105343205586, 4.301544632230486, 3.8747211354119435, 2.122719181435449, 3.5526593199798038, 2.969192160027368, 3.7252597383090427, 0.8529895203454154, 1.3872739651373454, 1.1954713314771652, 0.6567741291863578, 2.0927010093416487, 6.558971796716962, 10.809624348367963, 15.327819892338344, 14.431186999593463, 17.342997244426183, 14.791201829910278, 15.964903695242745, 28.087179115840367, 22.47935230391366, 16.56625986099243, 5.880863223757062, 0.4119960410254342, 0.04908343191657748, 0.00795959574835641, 0.019215857277491262, 0.03756117108943207, 0.05453747943309801, 0.07922327890992165, 0.05896442849189043, 0.04657083370589784, 0.07845766749233007, 0.040086797172469754, 0.04651770780661276, 0.07633557636290789, 0.028063867407451783, 0.06215330559228148, 0.031012001979563917, 0.04675914413694825, 0.02788073928760631, 0.07868272398731538, 0.018067072045856288, 0.05776453430631331, 0.01940290054439434, 0.016259675280057957, 0.06656041089445353, 0.05179226924000042, 0.013909251179679163, 0.037660288092281134, 0.027608276943543127, 0.005215374944132886, 0.020250953966751695, 0.009322029604975666, 0.07115124990897519, 0.01784627166177545, 0.06903823757810251, 0.04110719170421362, 0.037645048195762296, 0.023541314460869347, 0.023506553111863986, 0.03337820625997015, 0.03020542740289654, 0.04029243399522134, 0.07225926366767713, 0.08688797655382327, 0.021133383669491326, 0.04977003810927272, 0.0679790647700429, 0.029050818644464016, 0.06005326685096536, 0.07386902014591865, 0.0748248045731868, 0.01965317818602281, 0.04254605235265834, 0.06995351346475737, 0.03074289159849286, 0.006076482956164649, 0.044001129988048754, 0.023879577738365958, 0.0514274989920003, 0.06003690737166575, 0.025719047158158252, 0.04840424211163606, 0.020448015803205113, 0.03590390358918479, 0.06292309000023774, 0.009184220839025719, 0.05140137878645744, 0.059296815656125546, 0.04356783109584025, 0.023119786454896842, 0.08213291170873813, 0.025000953547922627, 0.03506546500804169, 0.011521321056144578, 0.025664196083588258, 0.006309745908116123, 0.023229140854839767, 0.043784219305962324, 0.0571198310436947, 0.03184060858828681, 0.04791422786989382, 0.02315575389989785, 0.03417479280116303, 0.06852116675249167, 0.01765626489317843, 0.04408166191673704, 0.07648629256125007, 0.012288685638590582, 0.04640902006732566, 0.029546413836734634, 0.046244081774992604, 0.01653453454907451, 0.11018950013177735, 2.056713031870978, 10.80330583027431, 26.487880979265483, 33.56046969549996, 33.593094961983816, 25.950354439871653, 19.255204030445643, 19.453213793890818, 21.730110679353984, 24.17681459018162, 27.00235860688346, 14.118446843964712, 5.840920635632106, 2.0665375675473894, 0.2486225590109825, 0.5340183504990169, 1.3221913831574577, 0.6593484367643083, 3.6943819437708174, 4.940645584038325, 3.901330998965672, 4.245835712977818, 4.984538657324655, 3.9979908636638095, 3.334923186472484, 3.4094200347151076, 2.4008744614464894, 2.4507523221629004, 3.5300687721797397, 1.7983633748122623, 2.281803833586829, 1.4124775784356254, 2.4422694402081624, 7.885042446000235, 14.155667475291661, 19.57111951283046, 24.922762768609182, 26.269579001835414, 26.638278211866105, 30.35929216657366, 29.951290471213206, 24.05698422023228, 42.87121909005301, 52.81919819968087, 49.27153485161917, 47.31032589503697, 42.28319304330008, 41.4838410105024, 30.251744474683488, 24.1776796409062, 16.724173307418823, 12.546114666121346, 5.559189856052399, 1.7086329268557685, 0.2666807100176811, 0.3548052284334387, 1.2555694494928633, 1.9936179603849138, 2.769328313214438, 4.3891583766256055, 4.132275657994406, 4.240172062601362, 5.486069619655609, 3.807858620371137, 4.018208384513855, 3.267181941441127, 3.855487218924931, 3.0170687224183763, 1.1212163673979896, 0.8628987371921539, 0.15494926619742597, 0.4397906538631235, 2.4962163397244046, 6.931820818356105, 12.727962919643947, 20.84459056173052, 20.14617153576442, 19.226810216903687, 13.108742441449847, 16.12976881435939, 27.46581040109907, 27.351385729653494, 22.408661331449235, 8.550451448985509, 1.0243859461375644, 0.021519308943035345, 0.011972606215359909, 0.006065876605654401, 0.021162467376728143, 0.04981785107936178, 0.08264572811978203, 0.05284932841147695, 0.03477914019354752, 0.008391243255963283, 0.0442224036503051, 0.042360574805310795, 0.08453767374157906, 0.0349140974160816, 0.03180961989398513, 0.018341437680646777, 0.03298192484570401, 0.012986223030436252, 0.011283203610219061, 0.026797056098335555, 0.047109268206570826, 0.039615273009985685, 0.04022347108860101, 0.010023242112116089, 0.046019646139549356, 0.032840114419481585, 0.005404294784446912, 0.026588762810985957, 0.016507484750556092, 0.026959353193108524, 0.01620980804519994, 0.009140775089950433, 0.027130494991849576, 0.03825441674728479, 0.05389482195356062, 0.01980982138775289, 0.03590575259711061, 0.01593975110777787, 0.033951680309006145, 0.04423898704616087, 0.020983176372413124, 0.04775917583278247, 0.1956853060317891, 0.09483045286365918, 0.11278785499078886, 0.12647934816777706, 0.12763135135173798, 0.23028786427208356, 0.1500140367341893, 0.2236481819834028, 0.09319213006113257, 0.15079888461955956, 0.217237437410014, 0.09520467849714415, 0.1044047244691423, 0.15641306979315622, 0.0968117004792605, 0.14662845911724226, 0.21644124441913196, 0.1966684761324099, 0.09419705399445125, 0.09461146247174058, 0.0697482701923166, 0.22970576265028544, 0.07760587534201996, 0.1773596629500389, 0.17201362124511174, 0.1187749087278332, 0.091947574700628, 0.14015934696154936, 0.1181760880031756, 0.15161468727248056, 0.13026678136416844, 0.13585814061973775, 0.0882212028705648, 0.10897209295736891, 0.16029133168714388, 0.07491770958794014, 0.0903161254578403, 0.12286247153367315, 0.11479095821934086, 0.18302956941936696, 0.17088756524026394, 0.1344857628324202, 0.12805238233080932, 0.23963864679847444, 0.09937057138553687, 0.12042353169194289, 0.17823995357113226, 0.13990736619702407, 0.0844092338478991, 0.26571447615112576, 1.428953385778836, 11.24479263169425, 28.32124481882368, 42.73638582229614, 42.705945764269146, 35.09336042404175, 29.248438494546072, 33.60354157856533, 34.884841510227744, 31.126602581569127, 24.82104114123753, 15.948391301291329, 8.57444531576974, 2.3778557309082577, 1.2171659959214074, 1.4635117713894163, 6.70878494637353, 11.956969959395272, 8.499532444136483, 12.93729477269309, 7.505960021700178, 9.77522691658565, 6.414497034890311, 6.547097759587424, 5.14778528043202, 5.120852325643812, 3.765257477760315, 2.9384127259254456, 2.44263139792851, 2.684410035610199, 1.5133162417582102, 0.9741195291280746, 1.718596643635205, 6.525683845792498, 12.764488731111799, 18.159763199942454, 22.38123505456107, 25.506331545966013, 26.87480878829956, 32.333226748875205, 34.14462212153843, 29.136353628976003, 45.01663868767874, 56.73125287464687, 49.740513937813894, 46.48493896211897, 42.096877098083496, 42.12073373794556, 27.65545105934143, 20.99259761401585, 12.43813271181924, 9.279205441474915, 3.844145153250013, 1.3357192001172473, 0.2003311538802726, 0.20176086787666592, 0.9867395205157143, 3.6052782450403487, 3.5800966705594743, 6.097978362015315, 6.983463738645826, 7.500164355550494, 10.220008901187352, 7.064817156110491, 6.622811845370701, 9.584290419306074, 9.207785776683263, 8.88382601737976, 5.141479790210724, 4.444090400423322, 2.6920350321701596, 1.2530740691082818, 3.18672245315143, 8.151617901665823, 14.710413387843541, 21.241405657359532, 21.78581265040806, 24.42082142829895, 21.099281992231095, 21.970094510487147, 37.57407924107143, 32.61701897212437, 23.48966554233006, 8.353649803570338, 0.9143820660454887, 0.19918618031910487, 0.13522879938994134, 0.13246740613664898, 0.10629224604261772, 0.12587325354771955, 0.15081411094537803, 0.1420977043786219, 0.14547459674733026, 0.18841641822031566, 0.2069793449980872, 0.18161243546221936, 0.14875376650265285, 0.13743748515844345, 0.09334557397024972, 0.07459334270762545, 0.15677808092108794, 0.13550842367112637, 0.15002729530845368, 0.09593333011226994, 0.17608519776591233, 0.11850608672414507, 0.1268500318484647, 0.13890616063560757, 0.18577205868703978, 0.11002452791269336, 0.10821644921920129, 0.08109429172639336, 0.07868053910455533, 0.1564550439694098, 0.11132525240204164, 0.116573496854731, 0.12983653587954386, 0.10050549584307841, 0.11661498248577118, 0.18829584254750184, 0.19033474528363772, 0.16437972230570658, 0.17596103942820004, 0.14841395616531372, 0.14344771765172482, 0.14848814718425274], [0.025673078106982366, 0.005809488332098616, 0.023563081864267588, 0.003291895891639537, 0.02292600872793368, 0.05749066400208643, 0.024345663442675556, 0.027146501632939492, 0.04457045140277062, 0.016109208443335125, 0.009569134247223181, 0.021449832046138387, 0.006483518726391984, 0.06928928196430206, 0.00842509197536856, 0.009015386059348072, 0.03346181534496801, 0.05729367850082261, 0.0539517646123256, 0.029348973717008318, 0.03659398388117552, 0.02193361394373434, 0.013268810813315213, 0.0170059467532805, 0.037595148730490885, 0.015193428744428923, 0.05426693395046251, 0.04337969708389469, 0.056857628149113486, 0.021807029843330383, 0.05661680589296988, 0.0814483038016728, 0.01877128452594791, 0.05995142553001642, 0.03018189241577472, 0.04079918769587364, 0.017700008349493146, 0.031082091254315207, 0.060932553240231106, 0.018882757651486566, 0.042116285235221894, 0.07123984622636012, 0.017578504780041318, 0.029104365235460655, 0.023737660442878093, 0.028787733654358556, 0.024731848255864212, 0.03614800316946847, 0.026699160458520055, 0.06723127846739121, 0.02065023111312517, 0.27175723761320114, 5.19320912872042, 14.674206324986049, 26.1331650188991, 29.149610791887554, 26.390884126935685, 22.41801186970302, 13.953723294394356, 14.534272210938589, 18.076061725616455, 21.839688982282365, 14.864013739994594, 10.369547162737165, 4.11875706911087, 1.0889682578189033, 0.40672564240438597, 0.16007162204810552, 4.176631220749446, 6.442671545914241, 4.5818736127444675, 3.1822803829397475, 3.809304714202881, 1.5834124918494905, 3.0537606392587935, 2.148941465786525, 1.7954171214784895, 2.469679215124675, 2.8381619453430176, 2.271938694374902, 3.0983402814183916, 1.1648534429924828, 0.9228730904204505, 0.6094164560948099, 1.3486087598970957, 1.707186615892819, 2.5439148545265198, 2.745276906660625, 3.528103083372116, 7.38589688709804, 12.054977774620056, 16.08535419191633, 19.336253029959543, 20.866885593959264, 14.887406587600708, 8.706675614629473, 7.1725216167313715, 4.825039718832288, 2.936506313937051, 0.39811647151197704, 0.027385688619688153, 0.1158356171633516, 0.02656151962998722, 0.11628993707043783, 0.8761583428297723, 1.5264888320650374, 1.7798237353563309, 2.2013161182403564, 3.7017348749297003, 3.125891843012401, 2.6331562144415717, 2.127786155257906, 2.6228668008531844, 1.6480882785149982, 3.676821674619402, 0.34106500287141117, 1.762489065527916, 1.905622933592115, 0.882422958101545, 0.9162745816367013, 2.0961301624774933, 5.107613401753562, 8.117416262626648, 14.610453128814697, 13.444160648754664, 14.52020297731672, 14.105035083634512, 12.833548613956996, 20.112566573279246, 26.938523769378662, 25.700320039476665, 12.370967081614904, 3.4203352204390933, 0.31965516028659685, 0.028205318210114325, 0.0376566409665559, 0.024303575611806343, 0.04112097275044237, 0.03376872351925288, 0.015572010572733623, 0.01662641667228724, 0.031231260392814875, 0.09862932616046496, 0.01628789215880845, 0.016799575416371226, 0.04609758606446641, 0.049471214679735045, 0.03977201799196856, 0.08810124466461794, 0.03347451412784202, 0.01683945461575474, 0.056535877021295686, 0.049902630637266805, 0.033555921366704364, 0.057684989646077156, 0.06697383549596582, 0.036375078306134255, 0.020688970373677354, 0.06528125703334808, 0.050577823870948384, 0.020032078925786272, 0.04046172848237412, 0.02193594301518585, 0.04843841992052538, 0.016029684139149528, 0.024696879953678166, 0.032742086465337446, 0.03655962626050625, 0.023056116121421968, 0.03467399440705776, 0.018336397861795764, 0.06755179805415017, 0.06753065490296908, 0.017585463156657558, 0.049981015002621074, 0.010484814710382904, 0.041426320294184346, 0.09449887315609626, 0.05419968095208917, 0.01861310444240059, 0.04512198502197862, 0.03572732163593173, 0.024567235660340105, 0.05906341318041086, 0.046776572308902226, 0.05208123355571713, 0.021845545187326412, 0.027626290351950696, 0.01265827433339187, 0.013528436122994338, 0.030631713635687317, 0.050808882008173635, 0.01220799086149782, 0.05229197635448404, 0.024120790152145282, 0.030955625897539512, 0.061069155910185406, 0.02180224277877382, 0.008054230179238533, 0.04236792673223785, 0.028848856088838408, 0.023444541796509708, 0.01795569052254515, 0.030194099260760204, 0.0269389835718487, 0.04104622872546315, 0.10507107978420598, 0.02046229217999748, 0.1182465199381113, 0.06288526167294808, 0.017167473710807304, 0.10572397974984986, 0.05939924730254071, 0.009326864166983535, 0.015672973190833415, 0.01745141008203583, 0.04240055408860956, 0.02204258836406682, 0.016585395837734853, 0.023803800643820847, 0.010798408999107778, 0.056441513156252246, 0.06614457070827484, 0.029918172995426824, 0.03419928791533623, 0.04322030920801418, 0.03786009969189763, 0.9674811767680305, 8.112950307982308, 21.97485055242266, 32.00584500176566, 34.637475218091694, 30.707028661455425, 28.01520620073591, 16.69108772277832, 14.742203133446829, 19.079619577952794, 29.8167907169887, 19.541047709328787, 9.689558233533587, 5.63168214900153, 1.5204095925603593, 0.32152729268584934, 0.11825730864490781, 0.6334374642797879, 1.27112711753164, 2.1847292482852936, 2.6011836443628584, 1.3069409557751246, 5.03828775031226, 3.8960238780294145, 6.914550636495862, 4.3540756191526135, 7.913102746009827, 7.491109115736825, 1.4533942171505518, 3.4728918288435255, 2.170398154429027, 1.6417400134461266, 1.0961067719118935, 2.376503872019904, 3.0490345614297047, 5.271078893116542, 4.000158701624189, 5.5319807103702, 11.416855216026306, 17.36178343636649, 19.571503400802612, 24.483186721801758, 27.376677172524587, 20.082654578345164, 13.128109676497322, 10.77188607624599, 8.12093552521297, 4.95350843667984, 1.0219957658222742, 0.1411311990980591, 0.1038098663889936, 0.055999993812292814, 0.46365008928946083, 1.4480637546096529, 3.405243081705911, 4.696974865027836, 3.3487752888883864, 4.384884800229754, 2.790900081396103, 5.406513614313943, 4.2241968512535095, 5.129099403108869, 3.200831421783992, 2.315191230603627, 1.466326226081167, 1.1532854522977556, 1.393167448895318, 0.6508252226880619, 0.3650311311440808, 1.4017213327544076, 5.517743851457324, 12.434994731630598, 20.07087390763419, 21.313076325825282, 16.966660227094376, 14.478228909628731, 14.654393536703926, 19.123278583799088, 27.214963061468943, 31.002709252493723, 16.510757650647843, 5.294007079941886, 0.851870208978653, 0.02234278243434216, 0.05392813802297626, 0.01812672714835831, 0.09319101726370198, 0.05369350739887782, 0.04781375379700746, 0.03475624642201832, 0.04626436997205019, 0.015121536262865578, 0.014314194941627128, 0.0168292833758252, 0.02593875510085906, 0.06621467016105141, 0.05438912792929581, 0.0411333594072078, 0.07038360967167787, 0.0130246043637661, 0.00564411111242537, 0.06276366819760629, 0.005181856162380427, 0.01792495627887547, 0.09667562028127057, 0.025585214607417583, 0.034353878548634906, 0.01908291530396257, 0.05961164911942823, 0.1309129095503262, 0.06380325848502771, 0.07579303333269698, 0.020041154331660697, 0.04384069377556443, 0.03282086777367762, 0.01781038903365178, 0.017365203904254094, 0.043550358819110055, 0.02843112957530788, 0.04447330893682582, 0.06330387028200285, 0.15344447908656939, 0.018532552157661746, 0.014227363663459463, 0.009547200602745371, 0.09202035436672823, 0.10823235408003841, 0.11736283664192472, 0.09026355256459542, 0.16873745061457157, 0.12287254099334989, 0.08800138466592346, 0.1475468562649829, 0.11023777111300401, 0.11426920550210135, 0.16904885747603007, 0.22389249530221733, 0.09601771951253925, 0.15256040224007197, 0.19749844659652027, 0.1003497177734971, 0.12609611158924444, 0.22133755311369896, 0.12776621697204454, 0.18369762785732746, 0.2744220889040402, 0.14182633108326367, 0.1604678322161947, 0.1449990929769618, 0.08370199001261167, 0.08017144338893038, 0.11497691752655165, 0.0738424826413393, 0.12276483034448964, 0.17203684071344988, 0.16659167861299856, 0.1796063466795853, 0.3016490936279297, 0.22848738517080033, 0.09724743531218596, 0.17056269624403544, 0.17771794301058563, 0.07661058660596609, 0.14014298069689954, 0.11868260082389627, 0.14010427705943584, 0.1439172231725284, 0.10382023440407855, 0.13807703155492032, 0.11394050956836768, 0.0645151977826442, 0.16855719100151742, 0.08592347973691565, 0.08642929366656713, 0.10618534963577986, 0.09832510498485394, 0.7934831934315818, 8.011700289590017, 22.50725974355425, 37.84804323741368, 43.44204139709473, 39.45066261291504, 35.53219127655029, 22.284384114401682, 22.57310434750148, 26.90122757639204, 29.286660534994944, 20.086448294775828, 14.032290918486458, 5.877011750425611, 1.94100598352296, 0.7969169606055532, 0.5222397425345012, 7.108851364680699, 12.462150028773717, 12.693024771554128, 10.37316804272788, 11.332345145089285, 5.829793964113508, 8.055200355393545, 8.400455474853516, 5.218637364251273, 7.697346414838519, 7.560481667518616, 5.554839849472046, 8.432576996939522, 3.752980010850089, 2.7357546176229204, 1.162614494562149, 2.465089278561728, 2.387817059244428, 4.033090557370867, 3.679068548338754, 4.998319974967411, 10.51444229057857, 16.84372227532523, 19.527823550360544, 24.80906765801566, 27.338012184415543, 19.186922345842632, 11.07753038406372, 9.154821395874023, 5.99286948783057, 4.411220209939139, 0.844842540366309, 0.11798674959157195, 0.23506922913449152, 0.11487934419087001, 0.43206957674452234, 1.494548723101616, 3.247216075658798, 4.7267188004084995, 5.848060778209141, 8.931017313684736, 9.357317958559308, 8.101728098733084, 5.688612648418971, 9.8580607346126, 7.035317276205335, 7.669163652828761, 5.717752524784633, 4.611768671444484, 3.9330104419163296, 1.5498537783111845, 1.3947685744081224, 3.0072235592773984, 6.87062759910311, 11.156865784100123, 19.550174168178014, 20.09379948888506, 20.044436011995586, 21.382832765579224, 20.691368886402675, 27.939575059073313, 36.85017074857439, 36.19173860549927, 18.76204173905509, 5.130786078316825, 0.6498247906565666, 0.11044660383569342, 0.22751332101012978, 0.07065625182752099, 0.1453950045896428, 0.120431212708354, 0.13885717040726117, 0.06543337779917888, 0.14804001551653656, 0.16401028712945326, 0.0803412264212966, 0.06367392292512314, 0.24671913257666997, 0.16661512878324303, 0.14344976682748112, 0.19154431537858077, 0.17182365858129092, 0.08478910489273922, 0.13094949615853174, 0.1327351424843073, 0.07367597014776298, 0.12759678677788802, 0.17618553952447005, 0.18852575735322066, 0.09026845837278025, 0.11006671922015292, 0.17182872045253003, 0.22748349261071, 0.1164912719811712, 0.17164808085986547, 0.10141274466046266, 0.151777019990342, 0.07145740490938936, 0.09811754790799958, 0.15243378760559217, 0.09300675429403782, 0.10254295329962458, 0.12175447813102178, 0.20126409881881305, 0.2039867341518402, 0.09360083205891506, 0.1315093282610178, 0.15427318747554505], [0.06804544585091726, 0.03363156784325838, 0.0393684694676527, 0.0237159931233951, 0.014499273849651217, 0.08780036866664886, 0.01073930096546454, 0.05654022982344031, 0.01994110773583608, 0.03467623017994421, 0.014014116222304958, 0.022299256109233414, 0.04880917824006506, 0.00890028361962842, 0.01784166949801147, 0.04656574808593307, 0.009720092173665762, 0.03400573580126677, 0.03556594565244658, 0.02001215374496366, 0.021955734185342277, 0.03799948435542839, 0.027571590251422355, 0.03129478823393583, 0.037021348984645944, 0.0426512965267258, 0.05252027963953359, 0.016694115807435343, 0.03496900786246572, 0.024116340658760498, 0.05709364637732506, 0.059065252010311396, 0.06875167866902691, 0.05308118382734912, 0.07606237780834947, 0.03433553096173065, 0.011968448492033141, 0.0387124143141721, 0.03419552543865783, 0.05839611470167126, 0.02286617211731417, 0.03630481261227812, 0.10479668022266456, 0.06592335472149508, 0.049841416600559435, 0.02825751112374876, 0.009907779200667781, 0.05688397905656269, 0.05606033593150122, 0.029917223046400716, 0.06192434073558875, 0.13720648469669477, 0.149076694888728, 1.6429513884442193, 8.500296745981489, 24.96539691516331, 31.352460724966868, 28.313101530075073, 21.07875006539481, 20.13262254851205, 19.37729777608599, 16.429875407900127, 18.79572660582406, 18.23689862659999, 13.322213683809553, 7.859942947115217, 3.541651636362076, 1.0710188895463943, 0.38804413484675543, 0.14209927857986518, 1.6120278877871377, 3.532118707895279, 2.562676076378141, 7.16564724275044, 5.12787652015686, 5.342287506375994, 3.9573056868144443, 8.676996384348188, 12.961594360215322, 1.2801882198878696, 3.642428308725357, 2.4128227574484686, 1.7535884231328964, 1.2180658962045396, 0.3163466235356671, 0.2083315160125494, 0.15666842966207437, 0.051843220434550724, 0.09866943436541728, 2.7901138492992947, 2.94547860963004, 1.8073478298527854, 2.721069165638515, 1.9457361868449619, 0.41873905062675476, 0.3164959283811705, 0.1813150742756469, 0.4021481637443815, 0.23684359820825712, 0.14039193519524165, 0.17577996557312353, 0.11812529287167958, 0.12833786915455545, 0.17336501872965268, 0.6429212668112346, 5.7203932745116095, 4.921953192778996, 1.7907435894012451, 2.2510220110416412, 2.1055723301001956, 3.552624578986849, 4.4830658861569, 3.373434228556497, 2.752744265965053, 1.8572645570550645, 0.6320000014134816, 0.872874667601926, 0.544468169765813, 1.5737872826201575, 4.049981193883078, 13.605212943894522, 16.225794655936106, 11.10820494379316, 12.294988530022756, 7.929182614598956, 16.118335553577968, 18.32186119897025, 19.128844090870448, 27.578534500939504, 18.977180549076625, 11.36125659942627, 1.9942337444850375, 0.2588050626218319, 0.01359166286420077, 0.05018827013139214, 0.021179322186591368, 0.02669980506678777, 0.01518781217081206, 0.03750553461057799, 0.050243458777133904, 0.026507421729287932, 0.04382521299911397, 0.03227758853297148, 0.03592958274696555, 0.013656373900760497, 0.00299019314115867, 0.04039571041773472, 0.03623456048912235, 0.025192770308681896, 0.05487907092486109, 0.04275218450597354, 0.01776616721014891, 0.04272305499762297, 0.035727386096758504, 0.021388080270428742, 0.020319155217813592, 0.05060028338006564, 0.03050292090379766, 0.04473232610949448, 0.028863400486963134, 0.038706511059509854, 0.04971835070422717, 0.02223387247483645, 0.02530782949179411, 0.06778838285910231, 0.014309387521020003, 0.0360631421873612, 0.005288063856174371, 0.03544142429849931, 0.03510089810671551, 0.028367248895977224, 0.03309548107374992, 0.06797001311289412, 0.013945348394502486, 0.04954306475285973, 0.05107577357973371, 0.05313933088577219, 0.037102376243897846, 0.06763433505381856, 0.02119392595653023, 0.07067658752202988, 0.042591592230434926, 0.07048018556088209, 0.0317885004915297, 0.021647908292444687, 0.05045306502974459, 0.025536655248808007, 0.0403503401737128, 0.014605428956981217, 0.028910290649426833, 0.0326599769427308, 0.032321594921605926, 0.022942929694961225, 0.04798640703250255, 0.055106519255787134, 0.01832128519059292, 0.03422457691548126, 0.015397896790610892, 0.061284516139754226, 0.04902115257989083, 0.06052950343915394, 0.040794933281306706, 0.021904275785865526, 0.0174966581897544, 0.04934953299484082, 0.021362696275381104, 0.008384105915735875, 0.007714295161089727, 0.022237902972847223, 0.042406253782766204, 0.04418693323220525, 0.048385032785258124, 0.03152075396584613, 0.036752767860889435, 0.03411237775747265, 0.0827287808060646, 0.01541493141225406, 0.035959102412951846, 0.008253393777912217, 0.08681986520865134, 0.01358177321630397, 0.03276357227670295, 0.03662447724491358, 0.06577813465680395, 0.011255076637358537, 0.02176724394251193, 0.010884973952280623, 0.04044754031513419, 0.37487352586218287, 3.4863309477056776, 13.420997091702052, 30.659753118242534, 35.232859407152446, 31.987001487186976, 23.02458439554487, 18.33880090713501, 16.872256789888652, 18.879193578447612, 21.61396632875715, 22.63353283064706, 16.05178223337446, 11.59414197717394, 4.447567539555686, 1.515929850084441, 0.20791230350732803, 0.20715708046087197, 0.6010591302599225, 0.8517738027232034, 1.0625596748931068, 0.9926372383322034, 0.8388516189796584, 5.331303707190922, 4.907205641269684, 8.491960644721985, 6.709435905729022, 3.295552087681634, 4.115827100617545, 4.158127299376896, 4.5683194143431525, 2.7155811744076863, 1.4662107122795922, 0.21857811404126032, 0.5765568507569176, 0.1865826230496168, 0.4353878301169191, 6.047172265393393, 5.247142348970685, 3.8649233068738664, 4.871084996632167, 3.4102127807480946, 1.2995959499052592, 0.6656324852790151, 0.6691838832838195, 0.7445063729371343, 0.9490317553281784, 0.4311556714986052, 0.41176577338150566, 0.32156914472579956, 1.0085811827863966, 2.5494959950447083, 2.849753494773592, 4.428094778742109, 5.253360118184771, 4.146118640899658, 7.0567046999931335, 4.5702245235443115, 2.800069966486522, 4.722167296069009, 3.105878208364759, 1.3806854443890708, 1.0452478038413184, 0.4544124864041805, 0.2872800018106188, 0.18385101748364313, 1.3338474205562045, 4.576552161148616, 10.003233790397644, 21.81463204111372, 18.520298276628765, 15.910042456218175, 10.952917916434151, 12.822353328977313, 17.34222773143223, 19.98143322127206, 29.33668409075056, 25.52703891481672, 15.728425230298724, 4.39762692792075, 0.6729812909449849, 0.07523565752697842, 0.02263478997961751, 0.012204186824549521, 0.018868233609412397, 0.013757338215197836, 0.024598950387111733, 0.08805881586990186, 0.034137391950935125, 0.03545914424051132, 0.044421611353755, 0.08285856419908148, 0.04811424642269101, 0.00969628237986139, 0.04049321250723941, 0.04446706302197916, 0.04293472399669034, 0.02124972189111369, 0.019821612630039454, 0.019253894254299145, 0.018252754850046973, 0.09072926507464477, 0.05507920143593635, 0.027870593492739966, 0.01504402551134782, 0.027201698760368993, 0.05217330736507263, 0.05409668951428362, 0.05536368402785488, 0.024295852186956575, 0.05268084477367146, 0.03939638779099498, 0.005755813667617206, 0.005657765781506896, 0.07795633867915187, 0.03454010248450296, 0.03307512163051537, 0.031237092401300157, 0.012389934937735754, 0.03250850757051792, 0.02271874002846224, 0.02735701372980007, 0.011964020202867687, 0.0733001906690853, 0.1769001590354102, 0.13521791568824224, 0.11663143017462321, 0.12889722628252848, 0.11888276865439755, 0.12421127701444284, 0.14460970887116023, 0.20867884451789515, 0.15600912432585443, 0.17304652796259948, 0.13387612625956535, 0.17095593442874296, 0.09737751726061106, 0.15352755891425268, 0.11911713464983872, 0.16072680189141206, 0.1639274787157774, 0.09136606340429612, 0.11059328275067465, 0.1491679578487362, 0.16556998129401887, 0.11551530792244843, 0.17758740644369805, 0.18569831550121307, 0.09804843911635024, 0.1339027519736971, 0.15243385545909405, 0.09789589765880789, 0.17146402145070688, 0.14758277790887014, 0.20673024122204098, 0.11948720764900957, 0.18831576433564934, 0.15288985813302652, 0.16264250980956213, 0.14075320080987044, 0.16907161554055555, 0.20500972068735532, 0.12542860954999924, 0.2675894041146551, 0.08125127758830786, 0.11637798377445766, 0.1405254030334098, 0.15088489571852343, 0.09184017617787633, 0.1485847570002079, 0.11033143608697824, 0.1281922691102539, 0.18338320830038615, 0.14091987615185125, 0.135067525186709, 0.18466775651488984, 0.3045759137187685, 3.120774929012571, 14.571397304534912, 35.693149771009175, 43.504689829690115, 40.936180523463655, 32.388381549290244, 29.1560309273856, 27.442940405436925, 23.706536190850393, 25.95113958631243, 26.52041939326695, 19.026061126164027, 11.458783251898629, 5.026901824133737, 1.9881479910441806, 0.6856421029993466, 0.9064875553761209, 4.015092985970633, 7.77802802835192, 10.630065526281085, 16.26954572541373, 10.937601481165204, 15.284166097640991, 9.382029226848058, 21.15937348774501, 25.93832537106105, 6.750548831054142, 8.505355034555707, 9.089445795331683, 4.203788689204624, 2.6787687497479573, 1.482911358986582, 0.8176622188517025, 0.9512575673205512, 0.28956937896353857, 0.3698200413158962, 5.134406524045127, 5.207332210881369, 3.286241284438542, 4.15831446647644, 2.9733608620507375, 1.0046757523502623, 0.6045872409428868, 0.3798582340989794, 0.7685115305440766, 0.8001004840646471, 0.4632702182446207, 0.4878243921058518, 0.19469562199498924, 0.6569831179721015, 1.6900225026266915, 2.8487635936055864, 9.952900171279907, 10.360981770924159, 6.187198877334595, 6.5971291320664545, 6.5057781253542215, 9.365365709577288, 11.758027400289263, 10.33660922731672, 7.645200184413365, 6.296132300581251, 3.481365157025201, 2.3420629543917517, 1.398545463170324, 2.327854105404445, 5.632500733648028, 16.085533108030045, 21.487622022628784, 15.5484390939985, 17.93607463155474, 13.404349207878113, 22.657029901232036, 24.870281287602015, 28.2510541166578, 37.646052156175884, 29.213475159236364, 16.861127512795584, 4.12464132479259, 0.5070291587284633, 0.20096027797886304, 0.15663314584110463, 0.15302723433290208, 0.1107376953586936, 0.0669029082304665, 0.1420472078025341, 0.155683821067214, 0.12520299665629864, 0.1372796714838062, 0.09967934553112302, 0.14250411971339158, 0.20417833887040615, 0.10734890827110835, 0.14678995045168058, 0.1297222570117031, 0.12536292736019405, 0.1500069121164935, 0.11427578729178224, 0.07215593635503735, 0.13632400919284138, 0.18001004787428038, 0.1049830602215869, 0.08992797628577266, 0.15479853642838343, 0.060406939658735476, 0.13385338176574024, 0.09817646510366883, 0.19389353932014533, 0.12653772932078156, 0.12156091923160212, 0.07924956535654408, 0.10518605075776577, 0.1937239191361836, 0.16211929145668233, 0.10982025494532925, 0.1201251255614417, 0.07799401772873742, 0.08347594964184932, 0.14263165715549672, 0.1343698419098343, 0.06978600352470364, 0.14524778963199683, 0.12903685521866592], [0.05248623075229781, 0.05645382856684072, 0.04988874102543507, 0.012138854928447731, 0.014116720046981104, 0.07696191846792187, 0.047526804730296135, 0.02912962030885475, 0.031321434304118156, 0.024653670843690634, 0.03915193537250161, 0.07605625742248126, 0.009274724687981819, 0.034087777470371554, 0.05207019718363881, 0.043434519320726395, 0.0530321427088763, 0.07626888315592494, 0.07257240757878337, 0.07140063866972923, 0.011934635395716344, 0.029218393045344522, 0.006239844502748123, 0.02022835535795561, 0.015411581145599484, 0.043625096058739085, 0.02227332250082067, 0.017451506773275987, 0.02849078637414745, 0.11924768478742667, 0.02457781062860574, 0.07693200185894966, 0.019903291282909255, 0.05945084310535874, 0.024181712418794632, 0.008065684698522091, 0.05172923333676798, 0.015471497484083687, 0.03554626813690577, 0.0399321488636945, 0.01341974753553846, 0.001447499035358695, 0.03309754042753151, 0.030299635204885687, 0.07758277122463499, 0.05283039728445666, 0.031448679976165295, 0.07474386891616241, 0.011137922477376248, 0.01834989561965423, 0.026608321582898498, 0.0068986120999657684, 0.037724362154092105, 0.07337753009051085, 0.6540814851011548, 4.933924070426396, 16.606538568224224, 31.384356430598668, 35.254305022103445, 30.17013440813337, 24.322221279144287, 19.90602442196437, 16.921142578125, 16.18116463933672, 21.129266943250382, 19.12532135418483, 12.677859459604536, 8.04750348840441, 3.3648199822221483, 1.2176845052412577, 0.1633679587393999, 0.22848760230200632, 0.4768891760281154, 1.6999489814043045, 1.539134987762996, 5.888281728540148, 7.213832565716334, 7.4922764131001065, 4.079540567738669, 1.4828694526638304, 2.6085459121635983, 1.7258063767637526, 4.483864060470036, 2.9417591520718167, 2.5438017291682105, 0.19559294384505066, 0.5958177457962717, 0.25572964336190906, 0.2294361942580768, 1.7265965172222681, 0.0780954383579748, 0.03507809933008892, 0.06536534109285899, 0.10377423651516438, 0.07993514356868607, 0.11181267124733754, 0.16297139573310102, 0.0550210408068129, 0.23545515271169798, 0.06583095182265554, 0.6904005876609257, 0.3452666274138859, 1.859952641384942, 4.543781851019178, 2.041685381105968, 1.8537583223411014, 3.62259749855314, 3.178849927016667, 7.29566844872066, 2.654710177864347, 2.661404550075531, 2.5104966248784746, 2.2282093380178725, 0.36960988544992035, 0.4544286083962236, 0.3185252637735435, 2.14749059506825, 5.733718616621835, 10.919924395424978, 15.561807428087507, 42.96820552008492, 18.191356658935547, 15.86197829246521, 15.784432922090803, 20.64626291819981, 21.463958195277623, 26.947612013135636, 29.145313331059047, 14.575951848711286, 6.016024359634944, 1.7717649106468474, 0.19564607313701085, 0.03999913384073547, 0.03329821715929678, 0.014549554990870612, 0.031157222044255053, 0.06947228964418173, 0.013681404209429664, 0.0297899163062019, 0.048364303540438414, 0.010076370555907488, 0.05310797917523554, 0.03123688544811947, 0.0015784504627975235, 0.010489628068171442, 0.09707295003214053, 0.012963060389405914, 0.012687428438636874, 0.09854794267032828, 0.05358074844947883, 0.0593725469495569, 0.0183670540739383, 0.024142393010801504, 0.02794084731223328, 0.018685958747352873, 0.03033754156370248, 0.07703646232507058, 0.026790896696703773, 0.08854986487754754, 0.05907746564064707, 0.01974784060647445, 0.06451477030558245, 0.050671044404485395, 0.03221552632749081, 0.031182256593768085, 0.015149474942258425, 0.018242259609646032, 0.016997269986729537, 0.014385327463969588, 0.02648047880003495, 0.034419031481125524, 0.016512836695515683, 0.014787103315549237, 0.03054087815274085, 0.035607319325208664, 0.03187056930203523, 0.024382317904382944, 0.07040539743112666, 0.011636817894343818, 0.004885764684461589, 0.011094543733634055, 0.03635947878605553, 0.0376367632831846, 0.02675238304904529, 0.027592940355784128, 0.015395767886989882, 0.007648785997714315, 0.04619333753362298, 0.031850630550512245, 0.046549951790698936, 0.06139012333005667, 0.030802215915173292, 0.05484198559341686, 0.024582020938396454, 0.02702517108991742, 0.041521410191697736, 0.0816403292119503, 0.06470689071076256, 0.05556929710188082, 0.014578667535845722, 0.019787648559681008, 0.04099999674196754, 0.03026186116039753, 0.05126782613141196, 0.017995108318115984, 0.07443288953176566, 0.02216161019168794, 0.05232962826266885, 0.025995628209784627, 0.040781878267547915, 0.008283982136552888, 0.045560973430318494, 0.033834141080400774, 0.05345775379932352, 0.01793128192158682, 0.05632231490952628, 0.0743531480963741, 0.021728314692154527, 0.014884434074961712, 0.06939731152462107, 0.013026011475761021, 0.05485870808895145, 0.028961187561175654, 0.04933072739679899, 0.07270109853042023, 0.07958655298820563, 0.03990137730059879, 0.018436322321317027, 0.016387496010533402, 0.18244586645492486, 1.8454519680568149, 9.067630188805715, 23.94653739248003, 35.8546849659511, 39.215785707746235, 31.434084687914165, 23.395835331508092, 11.799664480345589, 12.950002159391131, 21.252161468778336, 26.10522631236485, 20.323145627975464, 17.94776323863438, 10.483072910990034, 4.8090362804276605, 0.997176257627351, 0.2966228047651904, 0.040198724916470904, 0.16461297550371715, 0.4526885189116001, 0.7644063393984522, 0.6410313567944935, 0.973087721637317, 2.3667605434145247, 3.8828201293945312, 2.3492851725646426, 4.362852931022644, 5.423626593181065, 8.388771210397993, 3.6743468131337846, 3.671231414590563, 1.6625349947384425, 1.0923623442649841, 1.250160928283419, 1.0756271736962455, 2.4771090107304707, 0.40571769220488413, 0.10029515677264758, 0.15284146501549653, 0.19718925175922258, 0.3585577985005719, 0.5742637823734964, 0.5802867848958287, 0.6720965898462704, 1.107753146971975, 1.3370629165853773, 1.1784734321492059, 1.789969082389559, 2.7008672782352994, 4.454928721700396, 4.577537068298884, 4.050940479551043, 5.680877132075174, 2.9220121545451025, 4.290464861052377, 4.470549574920109, 2.0987409480980466, 1.7158201869044984, 0.8911862107259887, 0.1719768310764006, 0.24394093879631587, 0.1224729245794671, 1.4391561640160424, 5.0436574050358365, 14.084165300641741, 18.270861421312603, 41.437135219573975, 25.314128739493235, 13.6949246100017, 10.712539775030953, 11.44141970361982, 20.31575969287327, 28.25461333138602, 32.807580266680034, 21.682221957615443, 9.125322818756104, 3.30184411576816, 0.23166966012545995, 0.023625605473560945, 0.01706633297726512, 0.03446008624242885, 0.04142254424680557, 0.03639055568990963, 0.06803368005369391, 0.052387429268232415, 0.023399441270157695, 0.032633117134017606, 0.036129937174596956, 0.010967382878464247, 0.02453326141195638, 0.006952380487096629, 0.04008387607921447, 0.004078093425570322, 0.008387270433429097, 0.055818251600222926, 0.0057837379281409085, 0.0812442751069154, 0.045245264656841755, 0.02296100417152047, 0.029418903536030223, 0.012032500501456005, 0.03236582861947162, 0.023508542915806174, 0.03869886736252478, 0.047021923786295314, 0.02189061857227768, 0.061199604267520566, 0.019457614215623056, 0.03240898683933275, 0.05603573564440012, 0.024010261886620095, 0.014437001298314758, 0.03363504872790404, 0.048179362035755596, 0.052577856728541, 0.059119765513709614, 0.05736387294850179, 0.05707817577889987, 0.04804488318040967, 0.06997190854911294, 0.015320469159632921, 0.05333949193092329, 0.12019870589886393, 0.12423000458095755, 0.16463983191975526, 0.09707673625754458, 0.12275930706943784, 0.14177911861666612, 0.12519218080810138, 0.0950470683830125, 0.12077441572078637, 0.12955649090664728, 0.12585900431232794, 0.10677035538745777, 0.074851009595607, 0.13248031187270368, 0.26778797060251236, 0.1981719197439296, 0.17512824625841208, 0.2720535402851445, 0.1340094991028309, 0.20794457463281496, 0.16753223671444825, 0.15814976660268648, 0.07407405307250363, 0.09655303614480154, 0.08081499992736749, 0.12628200304295334, 0.18862387351691723, 0.1834237982652017, 0.11386972479522228, 0.2580737647201334, 0.05771339990730796, 0.19442021820162023, 0.17449019263897622, 0.13799929858318397, 0.11132224649190903, 0.1439987016575677, 0.08445136408720698, 0.1673076416232756, 0.11720623075962067, 0.1352175764207329, 0.13418542966246605, 0.07988112539585147, 0.0948609123006463, 0.11362640892288514, 0.22558850715202944, 0.2486925566835063, 0.08105813259524958, 0.14561687197004045, 0.1897510966019971, 0.21752486484391348, 0.1822026116507394, 0.05650663894734212, 0.10923818725028209, 0.23220345005393028, 1.5888575996671404, 8.401508126940046, 25.200454473495483, 42.257258892059326, 48.37246574674334, 41.537474155426025, 33.120155402592246, 27.363145555768693, 23.072202137538365, 25.00750994682312, 29.523767811911448, 26.719421012060984, 18.398930617741176, 11.095890998840332, 4.332804577691214, 1.9824307092598505, 0.5227179740156446, 0.4237409665116242, 0.6990535376327378, 4.035514610154288, 4.249444433620997, 12.725354739597865, 11.80869540146419, 15.47743718964713, 8.51928356715611, 4.60616842338017, 7.432348200253077, 5.30621028797967, 9.709691507475716, 7.76588865688869, 7.436108044215611, 1.8795737028121948, 2.053963282278606, 1.4430454181773322, 1.1069647435631071, 3.602815108639853, 0.6258132819618497, 0.16145875118672848, 0.21905391636703694, 0.22680642322770186, 0.2988384115908827, 0.437402644859893, 0.7939156645110675, 0.54754046776465, 1.8057941475084849, 1.3672050705977847, 1.8205242199557168, 2.0590888815266744, 3.687970059258597, 9.065107124192373, 7.783937471253531, 7.8618528332029065, 11.179200768470764, 9.823838250977651, 14.963320868355886, 6.904683760234287, 7.359344346182687, 6.570542284420558, 5.256014330046518, 2.0592769171510423, 1.3142267933913638, 0.6718677878379822, 2.9822063531194414, 7.862788234438215, 13.218368513243538, 19.300294365201676, 50.763875893184114, 23.208327770233154, 21.924618550709315, 20.98388978413173, 28.615132774625504, 29.085063764027186, 36.568247590746196, 39.13548885072981, 25.28621087755476, 10.105942930494036, 2.713063972336905, 0.27639814572674887, 0.10045698737459523, 0.10934306840811457, 0.053321364867900095, 0.09123609002147402, 0.20069499792797224, 0.1672869734466076, 0.17147037253848144, 0.0885339193046093, 0.11321635664041553, 0.20641652734151908, 0.09451032682721104, 0.0995739826134273, 0.08886799602104084, 0.1349623386881181, 0.12343625431614262, 0.06305826774665288, 0.17633781635335513, 0.10143519059887954, 0.17466931231319904, 0.1846072854740279, 0.10138221058462348, 0.1832854449748993, 0.13466724380850792, 0.13795815221965313, 0.1590073805834566, 0.09829408914915153, 0.19267791669283593, 0.1308100572121995, 0.14042552267866476, 0.14390651588993414, 0.11408218768026147, 0.183870952842491, 0.08107702979551894, 0.1713365518621036, 0.20767138286360673, 0.20440100692212582, 0.07177239443574633, 0.1491403550441776, 0.13158125297299453, 0.10216063952871732, 0.11499686645609991, 0.15734537690877914, 0.06819328506078039, 0.16125850193202496], [0.031139783694275787, 0.028940614379410232, 0.07843801033283983, 0.04707998263516596, 0.02698051500400262, 0.008268820271561188, 0.00593515980290249, 0.04443149421630161, 0.01887070178054273, 0.013041927362792194, 0.051040635643793006, 0.05358178660805736, 0.044766405530806096, 0.018418626128030673, 0.05383817785020385, 0.05848263470189912, 0.04695885395631194, 0.016019207558461597, 0.04883296428514378, 0.013667815697512456, 0.018732480804568956, 0.06373779342642852, 0.020021509046533277, 0.05349043543849673, 0.057895355857908726, 0.011309311941399105, 0.048082195821085146, 0.017037196683564355, 0.07156227928187166, 0.02552634660553719, 0.010437638715042599, 0.025246746073077832, 0.021518135077453086, 0.0012770275019907526, 0.07389844142432724, 0.07581297547689506, 0.00853182892647705, 0.03308131665523563, 0.0292933067040784, 0.02359238439904792, 0.031890463948782, 0.025718687534598366, 0.01902303798124194, 0.06185543550444501, 0.011983169309262718, 0.04605869243719748, 0.06406885744737727, 0.028860991687646935, 0.020850056283442036, 0.04176672774233988, 0.01746000033537192, 0.02723164251074195, 0.008528079172330243, 0.038926475149180205, 0.032809709265295944, 0.5164971106818744, 2.1693253091403415, 11.747097883905683, 22.943108081817627, 30.404149736676896, 35.19064910071236, 27.08402078492301, 20.364886931010656, 15.232441970280238, 16.76728687967573, 19.02691228049142, 16.927927494049072, 15.102522815976824, 12.00748770577567, 8.888786162648882, 3.4876165815762112, 2.0501309164932797, 0.5069097908479827, 0.024640184960194995, 0.049067191180906126, 0.6223972652639661, 0.682389531816755, 1.0749784942184175, 2.6286455307688033, 1.6568844807999474, 3.0954559104783193, 7.150668229375567, 8.06158835547311, 2.435947013752801, 2.812486397368567, 0.3332768864929676, 0.8036568218043872, 0.8477861338428089, 1.0383472655500685, 1.8403320142201014, 0.5462009853550366, 0.17847513380859578, 0.07682388408907823, 0.07324841166181223, 0.6814741609351975, 0.6474085003137589, 1.7097569065434592, 1.4941629895142146, 0.6682028844952583, 1.926077127456665, 0.5315244900328773, 2.441745068345751, 1.8740922255175454, 4.883161400045667, 4.737650488104139, 3.5462702342442105, 3.3600641574178423, 1.3146396683795112, 6.672472792012351, 7.229282319545746, 0.3687327025192124, 1.5022584008319038, 0.7548530548810959, 1.2453991323709488, 2.3040313380105153, 7.618881276675633, 12.643757700920105, 23.612778936113628, 16.176471131188528, 28.143226759774343, 45.14542007446289, 14.774281229291644, 17.368144512176514, 17.420137882232666, 26.39404903139387, 26.0076162815094, 23.988153627940587, 10.335873586790902, 3.6278896374361853, 0.5699653987373624, 0.016268306245495166, 0.03720003778913191, 0.024882861313277056, 0.01450377592949995, 0.012771921315496522, 0.036436869097607474, 0.05059927236288786, 0.04720492468082479, 0.034656315177146874, 0.025054427196404765, 0.021058610806773816, 0.07621477677353791, 0.05258545292807477, 0.029404223430901766, 0.0406330314331821, 0.05407944793945976, 0.052481881342828274, 0.03334609119753752, 0.013723407223421549, 0.030347743337707858, 0.08077886793762445, 0.018991699841405665, 0.026632611440228562, 0.05177139750282679, 0.0484711931619261, 0.05682346730359963, 0.028606975318065712, 0.0793917795111026, 0.020810614739145552, 0.0655927588897092, 0.04176643257960677, 0.04421631379851273, 0.08117571592863117, 0.023254141477601867, 0.03325105219015053, 0.03829270647838712, 0.009782468201592565, 0.05424844726387944, 0.046469134877302816, 0.03388373859758888, 0.04609478371483939, 0.025764463203293935, 0.022759367312703813, 0.03608411570478763, 0.014259172536964928, 0.09869899813617979, 0.025141683407127857, 0.002606755546626768, 0.12347741425037384, 0.012725337341959988, 0.03010610005419169, 0.004729609179776162, 0.0243311835053776, 0.046824229215937, 0.04686188790947199, 0.019385009272290126, 0.03247848578861781, 0.027630347991362214, 0.04740732828421252, 0.038679088066731176, 0.049811581415789466, 0.028835516090371778, 0.03940175500299249, 0.025691873526998928, 0.041054554350141964, 0.028594106901437044, 0.13420320727995463, 0.06299279590270349, 0.028650513517537286, 0.06401247118732759, 0.06497266609221697, 0.0635629485228232, 0.05645918220813785, 0.029793213986392533, 0.0872905853071383, 0.03643037212480392, 0.037877032533288, 0.06509127401347671, 0.0285983952427549, 0.0206528519546347, 0.054545177412884574, 0.06349297799170017, 0.06303642570440258, 0.02709586256449776, 0.0043956681703483415, 0.02694996566112552, 0.03774892172909208, 0.06348168716898986, 0.03865357854270509, 0.02407625280985875, 0.02877949963190726, 0.026431271440482566, 0.042569668763982396, 0.023229642970753566, 0.06311169559402124, 0.027490678343123624, 0.03553532675973006, 0.04708825736971838, 0.05971207230218819, 0.023872656681175743, 0.04918675922921725, 0.7617808431386948, 4.469274580478668, 17.170709712164744, 30.152621473584855, 36.89116512026106, 37.17416524887085, 26.221596479415894, 15.899034772600446, 12.817355837140765, 15.41316635268075, 23.472315890448435, 22.845904520579747, 20.242888723100933, 19.877752201897756, 12.641775727272034, 5.483435818127223, 2.6341528466769626, 0.6606882448707307, 0.021388275349246602, 0.028007664351857135, 0.3370201742010457, 0.1084770473784634, 0.41604711221797125, 0.9706008093697684, 0.8019759005733899, 0.7646395925964627, 2.4501936435699463, 3.3109002241066525, 2.6258714624813626, 2.4967096618243625, 2.894808437143053, 2.4573452941008975, 2.352530198437827, 2.0935753967080797, 3.3935266818319048, 1.903725641114371, 0.49557890743017197, 0.6372210841093744, 0.8025537409952709, 1.6985460966825485, 1.4930430267538344, 1.750605366059712, 2.4166140854358673, 2.465432562998363, 1.0333423912525177, 2.990921131202153, 2.666327565908432, 4.099473212446485, 2.5033028508935655, 2.6634188762732913, 1.0272876875741142, 2.268905588558742, 1.5634055882692337, 2.4879544973373413, 1.0328813131366457, 0.32695804270250456, 0.32164280648742405, 0.1761877651193312, 0.5128438238586698, 2.253034600189754, 6.706685287611825, 13.977289846965245, 21.680337258747645, 19.722536393574305, 29.33774369103568, 55.77060188565935, 15.878824199948992, 10.141291890825544, 14.307418738092695, 24.621221372059413, 29.535142013004847, 28.709141901561193, 17.086593082972936, 5.742951469761985, 1.2496326480593, 0.05561541712709835, 0.06591026578098536, 0.04406377912632056, 0.08278442746294395, 0.05796229333749839, 0.019034189704273428, 0.025608825929729, 0.1001985537420426, 0.038080053603542705, 0.036891874325062544, 0.05264471617660352, 0.04193092643150261, 0.02938178088515997, 0.0020845768366208567, 0.015298141964844294, 0.09237482784582035, 0.04960615493889366, 0.05313832665394459, 0.0429640638508967, 0.020566808625257442, 0.09510652840669666, 0.03734227908509118, 0.021622039144858718, 0.027520130155608058, 0.007710325731230634, 0.05587969294616154, 0.019274433509313633, 0.028684752394578288, 0.025350234537784542, 0.0382193195234452, 0.058571895983602316, 0.02424185097749744, 0.025896462013146708, 0.021084571556587304, 0.0355770804121026, 0.03688428830355406, 0.0600611785692828, 0.0233662286773324, 0.03559539407225592, 0.014252195500635674, 0.11755134724080563, 0.0413284992932209, 0.021206416089886, 0.060672531835734844, 0.012144382444343396, 0.00949852928585772, 0.08637920421149049, 0.16253251928303922, 0.19446318303900106, 0.09825441520661116, 0.11315007055444376, 0.10374507308006287, 0.11093245526509625, 0.19709090489361966, 0.11029303779027291, 0.1342011173920972, 0.11353015194513968, 0.17982054661427224, 0.271445844322443, 0.14671396810029233, 0.12801131739148072, 0.11035601941070386, 0.1556204187550715, 0.1412813046148845, 0.21779763592141016, 0.10455624133880649, 0.2600755515907492, 0.16613672088299478, 0.1320825003619705, 0.14763503867600644, 0.13596343568393163, 0.10689176565834455, 0.15823602197425707, 0.12796185218862124, 0.19023031874426774, 0.06208743341267109, 0.08276882115751505, 0.11582625338009425, 0.1587325603302036, 0.14125482817845686, 0.19988055234508856, 0.209734495729208, 0.16884674903537544, 0.08867766016295978, 0.10998311692050525, 0.1894138375563281, 0.0819365301036409, 0.14064871998769896, 0.10337648607258286, 0.21911526950342314, 0.08032068038093192, 0.112911389076284, 0.11702184565365314, 0.09000329367284264, 0.11772290803492069, 0.09898668341338634, 0.14125879082296575, 0.1617266232413905, 0.1666515525430441, 0.13943450871322835, 0.1617246147777353, 0.794390259044511, 3.963562539645604, 16.401309626443044, 34.68970135280064, 43.7082234110151, 47.598620550973074, 35.47201292855399, 28.229064805167063, 21.78890459878104, 24.985638754708425, 27.918575865881785, 26.200750146593364, 24.009774684906006, 17.485193865639822, 12.242432355880737, 5.878652393817902, 3.0150711153234755, 1.0642523212092263, 0.21496552574847425, 0.10783515325082199, 1.394217495407377, 2.1091161285127913, 3.1402654945850372, 6.129169259752546, 6.286791316100529, 8.11229978288923, 12.9530611038208, 17.92271671976362, 8.157493472099304, 5.548310714108603, 5.4140254855155945, 3.4659705545221056, 3.7017887234687805, 4.397969560963767, 5.316368554319654, 1.8727299443313052, 0.7977681692157472, 0.6589275279215404, 0.46384252182074953, 2.2677673867770602, 2.0495309829711914, 4.766018680163792, 4.715473140989031, 4.745876286711011, 6.085970137800489, 4.877428701945713, 7.8997222525732855, 6.5350465433938165, 10.745297057288033, 9.432741522789001, 12.402281744139534, 8.893602132797241, 5.317231867994581, 11.096559762954712, 12.757354668208531, 2.3496084809303284, 3.526799861873899, 1.3120878338813782, 1.8933843331677573, 3.3595636699880873, 9.702623452459063, 15.33174215044294, 27.98797447340829, 21.20276325089591, 34.094185147966655, 51.08828381129673, 20.885077714920044, 22.100319385528564, 24.15586403438023, 35.28782660620553, 34.74327196393694, 33.511877468654085, 19.133587973458425, 6.634768392358508, 1.3080716665302003, 0.07548831682652235, 0.2116299561624016, 0.06866335376564946, 0.13044701383582183, 0.1695474042956318, 0.11304188493107047, 0.17783353823636258, 0.15933822068784917, 0.12661505517150673, 0.12379996265683856, 0.16507024025278433, 0.21097510201590403, 0.0942780575049775, 0.16763502119907311, 0.10090873563396079, 0.1341814398765564, 0.12251381309969084, 0.1435574231935399, 0.10463776053594691, 0.09162366243877582, 0.1447336772190673, 0.19026917165943555, 0.1252760070243052, 0.11563208379915782, 0.14714757911860943, 0.18802862188645772, 0.09757376994405474, 0.13952930005533354, 0.1150866909218686, 0.13814553645040306, 0.09888314575489078, 0.07919230378632035, 0.20671143223132404, 0.09360983621861253, 0.11696866207889148, 0.08627611438610724, 0.18862679121749742, 0.16506078147462436, 0.21706869932157652, 0.1424047957573618, 0.21529203679944786, 0.17708020151725837, 0.09181993547827005, 0.21269630108560833, 0.09635580637093101, 0.1875382446284805], [0.009124824427999556, 0.005541784638938094, 0.10268161871603557, 0.03873522326882396, 0.03324358491227031, 0.0295305666513741, 0.05809988666857992, 0.0593499517334359, 0.025765404670632312, 0.015805038157850504, 0.047146139799484184, 0.07719149400613137, 0.07517021282442979, 0.02596975736586111, 0.009928388853690453, 0.10850733718169586, 0.07527249519314085, 0.022892405977472663, 0.06434170994907618, 0.06726291855531079, 0.022099877075691308, 0.021583274439243332, 0.059092434123158455, 0.05400087019162519, 0.03962497266807726, 0.06713922162141119, 0.08604574496192591, 0.07506701443344355, 0.06711770527596984, 0.07011491658964328, 0.05615057430363127, 0.09637519890176398, 0.034469992853701115, 0.09027962027383701, 0.05002949972237859, 0.03268989355170301, 0.11011533625423908, 0.021282306839046732, 0.03669491596519947, 0.05778328222887857, 0.055773817734526734, 0.02228287627388324, 0.016929460589640906, 0.034449809829571416, 0.011618424506325806, 0.064138671915446, 0.026977570162021687, 0.008409467010226632, 0.013518267427571118, 0.050051392654755285, 0.0634240795459066, 0.05900115080709968, 0.01971976791641542, 0.0472104445632015, 0.016939287473048483, 0.026307951093518307, 0.03425391337701252, 0.7642696553042957, 5.69416686466762, 15.446502072470528, 31.751690319606237, 37.4634986604963, 34.49000665119716, 28.6236286844526, 25.364852326256887, 14.964521169662476, 19.594065938677105, 14.126675248146057, 13.920818362917219, 13.522903714861188, 18.570813417434692, 11.268946307046072, 6.549126199313572, 4.197211350713458, 2.2724695801734924, 0.7747708803841046, 0.41281872402344433, 0.6358562516314643, 1.0058478266000748, 0.9807715607540948, 0.5050110327345985, 4.234736399991172, 3.4540672046797614, 1.3208912014961243, 1.5451184724058424, 3.357480513198035, 1.5177047891276223, 2.0402505780969347, 1.9887396735804421, 2.523647827761514, 0.8303597260798726, 0.5119425122226987, 1.0174652146441596, 1.0898875913449695, 2.541688825402941, 1.2698273701327187, 0.4669028233204569, 1.7196590666260039, 1.5874630744968141, 0.8186789357236454, 2.6818561383656094, 1.7202223049742835, 3.4007497685296193, 1.3269357000078474, 1.3320498998676027, 1.2355605917317527, 3.740788962159838, 1.1705629080533981, 0.29017273230212076, 1.3524190868650163, 0.7500317650181907, 1.6187561324664523, 4.715772347790854, 10.152736442429678, 14.594630343573433, 20.437764848981583, 22.591202667781285, 42.279826641082764, 47.47256980623518, 27.097811222076416, 31.309760570526123, 22.480861800057546, 25.49638867378235, 27.23288767678397, 28.878882919039043, 21.29209450313023, 10.421805432864598, 2.2310300895145962, 0.15499531158379146, 0.033007078138845306, 0.016954661380233507, 0.02441422431729734, 0.03367427144465702, 0.04259083227121404, 0.019098075472616723, 0.013783473687778627, 0.0678144928866199, 0.04289479560351797, 0.04868453135713935, 0.07110256502138716, 0.007078421759485666, 0.009052867485609437, 0.054314007317381244, 0.062312666326761246, 0.03069989283436111, 0.01041132936786328, 0.03871824632265738, 0.06779664741562945, 0.060810966550239494, 0.06782053184828588, 0.037528625157262595, 0.039279523704733164, 0.04445324465632439, 0.038263821242643256, 0.11418832412787847, 0.08186566390629325, 0.033612959020371945, 0.04889192897826433, 0.027131000500438467, 0.04691241501963564, 0.02926466574094125, 0.039446772408804724, 0.05260167670037065, 0.036844285271529637, 0.039175996224262884, 0.0426974844054452, 0.01114601655197995, 0.04381708075691547, 0.05510430044627615, 0.010691499869738306, 0.04699813774121659, 0.04544572765007615, 0.14581914325909956, 0.06754539268357412, 0.028914104016231637, 0.022544247963066612, 0.04850952360512955, 0.020628670662907616, 0.0993297439334648, 0.010465259331145456, 0.019142787537670562, 0.024722530273720622, 0.05415050073393753, 0.029371887844588076, 0.04831578489392996, 0.021015973362539495, 0.004463609457681221, 0.03815812584278839, 0.012606015262593116, 0.015835341531783342, 0.030131572258791754, 0.007537071992244039, 0.07943435079817261, 0.027582645283213685, 0.05234217776783875, 0.028646642475255897, 0.060864509748561044, 0.021371749628867422, 0.08617681078612804, 0.02054894110187888, 0.007562992878125182, 0.057459315684224875, 0.05711050118718829, 0.0618372643366456, 0.04521438113546797, 0.05537550410787974, 0.045848319440015724, 0.11327194901449339, 0.04183572118303605, 0.024658183101564646, 0.051832353696227074, 0.03006722339029823, 0.08535270964992897, 0.025198283405708413, 0.06319436830069337, 0.015993514829980474, 0.006466140596395624, 0.04283478596646871, 0.11944047015692506, 0.038584276368575435, 0.051572807266243866, 0.07495846918651036, 0.05555834893935493, 0.03988663273464356, 0.041021109359072785, 0.023454655360962664, 0.011441453243605793, 0.04909143862979753, 0.03844837598236544, 0.01744804285200579, 0.04081202557842646, 0.04832396124090467, 0.19335318117269448, 1.859567016363144, 9.310658199446541, 21.753498315811157, 38.346843991960796, 39.61172880445208, 34.960535185677664, 23.829738174165996, 19.996531656810216, 12.750382150922503, 16.93190881184169, 18.63660590989249, 17.141200712748937, 16.220305579049246, 20.51276023047311, 16.501497438975743, 9.749938079289027, 5.43381004674094, 1.580250627228192, 0.4415597032223429, 0.2900665822838034, 0.10605609550007752, 0.3389883057347366, 0.21202404930123261, 0.31212825274893213, 0.6540868590985025, 0.9582680825676236, 0.7863618327038628, 1.1047730211700713, 0.7355672983186585, 0.5656864483441625, 1.2344441030706679, 1.53003762449537, 2.0177392831870486, 1.0983650450195586, 0.5177803018263408, 0.5103465435760361, 1.5998347763504301, 2.3290782911436896, 2.2648599999291554, 0.8567806854844093, 1.0601700374058314, 1.2620763289076942, 0.8131332961576325, 1.211844218628747, 2.3054498561791013, 3.056847159351621, 1.2025214731693268, 1.3846410321337836, 0.8678924835153988, 0.34453579091600006, 0.5108442083001137, 0.08298908040991851, 0.5300013689058167, 0.18520126145865234, 1.7294524439743586, 3.3369457636560713, 10.08291573183877, 15.236458029065814, 25.251685278756277, 26.791034357888357, 47.24745512008667, 36.454300607953755, 25.508443798337662, 36.02890757152012, 17.385860681533813, 20.57951852253505, 26.33142144339425, 32.856724875313894, 25.18966392108372, 14.846929856709071, 3.6108302899769376, 0.5044457859226635, 0.03357692202553153, 0.04532946745998093, 0.042964711851839504, 0.07267756015062332, 0.03416791245607393, 0.05195028308246817, 0.03216249203043325, 0.0033812593776799205, 0.03599066446934428, 0.047904266975820065, 0.10558409975575549, 0.06449965933071715, 0.0136889919272757, 0.045095077715814114, 0.05128484718235476, 0.030180786403694322, 0.03492712189576455, 0.06970663528357234, 0.035418900328555276, 0.03586070126454745, 0.037628149281122854, 0.04524116969800421, 0.03547388202111636, 0.0571963901498488, 0.0653105154633522, 0.04134952709344881, 0.015446876840932029, 0.016594204918614457, 0.008635825444278973, 0.027294854833079234, 0.05101542467517512, 0.008905611815862358, 0.031030990782060792, 0.037812232439007075, 0.026195707830733488, 0.04997400573587843, 0.017770324933475683, 0.016821083280124834, 0.004113213549966791, 0.018210851919970343, 0.04312757721969059, 0.03840676821502192, 0.029361516436828033, 0.12216112416769777, 0.11168101509766919, 0.02571830416231283, 0.038038971700838635, 0.08943850147937026, 0.0873334619349667, 0.2145427848611559, 0.12566651749823773, 0.15136255723025116, 0.15846205555966922, 0.1730166995631797, 0.2337606336389269, 0.2197037222129958, 0.09965865021305424, 0.19391202261405333, 0.15033490237380776, 0.16754279471933842, 0.07011089287698269, 0.08905892220458814, 0.13467706899557794, 0.16669419168361596, 0.09340478972132717, 0.11134925897100142, 0.12082423376185553, 0.15454232160534176, 0.10527392104268074, 0.1394037167940821, 0.09060638916811772, 0.12078896351158619, 0.1929757392832211, 0.23842474765011243, 0.11114471458962985, 0.15079272352159023, 0.19916836198951515, 0.18028277823967592, 0.2700634242168495, 0.08409775234758854, 0.2052628413907119, 0.16166377732796328, 0.10541439136224133, 0.17812133207917213, 0.11855112787868295, 0.13974001232002461, 0.09051447481449161, 0.11093626184655087, 0.07804429717361927, 0.165291890501976, 0.12004971317946911, 0.11541683892054216, 0.2166944465466908, 0.15075125146125043, 0.06758459843695164, 0.1240393090993166, 0.12725256596292767, 0.10919459816068411, 0.1739289898957525, 0.15360609255731106, 0.13850378936954907, 0.1712435789938484, 0.16348405608109065, 0.3128259495965072, 1.521881090743201, 9.309046217373439, 24.237430674689158, 43.89474432809012, 48.83311741692679, 44.49274103982108, 37.86604254586356, 35.05047961643764, 21.318806852613175, 27.408055237361364, 23.11547030721392, 23.303801230021886, 22.715983629226685, 26.40555351121085, 16.994284527642385, 9.78700932434627, 6.058987677097321, 3.254851060254233, 1.1373628952673502, 0.8302533317889486, 1.1079970938818795, 2.1696796672684804, 3.3115518348557607, 2.677264464753015, 7.842925940241132, 6.45016040120806, 5.56721111706325, 6.812466834272657, 8.865249139922005, 5.720832313810076, 6.9629470109939575, 6.704846186297281, 8.69292860371726, 4.1190202321325025, 1.9604500830173492, 3.1122030232633864, 4.789791941642761, 8.519541519028799, 7.262878596782684, 3.9839016539709906, 4.73405088697161, 5.886522097246988, 5.12361249753407, 6.697438103812082, 5.292633507932935, 8.704698852130345, 5.379836005823953, 5.7548719729696, 3.8578409211976186, 6.612007396561759, 3.0199978223868778, 1.225189971072333, 1.7694976265941347, 1.375460399048669, 2.851352883236749, 6.344823104994638, 12.772246394838605, 18.50657732146127, 26.385098014559063, 29.380756514413015, 48.75203888756888, 52.75307566779, 32.51340396063668, 37.30636167526245, 28.833422592708043, 32.295067242213655, 36.67488506862095, 38.66161823272705, 28.542572736740112, 15.54618787765503, 3.7698975716318404, 0.4263878230537687, 0.09282171779445239, 0.1487211561096566, 0.1763145426022155, 0.20318030885287694, 0.16084121646625654, 0.24520347533481462, 0.24933184523667606, 0.1524471411747592, 0.14538504369556904, 0.08810368739068508, 0.1801923702337912, 0.1668924189039639, 0.08018987240003687, 0.10635613689997367, 0.14283608618591512, 0.10161944678319351, 0.09753837755748204, 0.13137605041265488, 0.16580541937478951, 0.12185515915708882, 0.10804331422384296, 0.15660797219191278, 0.12134340804602418, 0.13479317990796907, 0.11679368146828242, 0.22707843434597763, 0.13784061638372286, 0.09211713381643806, 0.17242006372128213, 0.11663421216819968, 0.13110982041273797, 0.17440993551697048, 0.06160172447562218, 0.16495018026658467, 0.10429427253880671, 0.09420687239617109, 0.07445517262177807, 0.1508425958454609, 0.0885483721005065, 0.2023412324488163, 0.24259382965309279, 0.1372728861336197, 0.1926452655877386, 0.31080725363322664, 0.3677199211503778, 0.20842832938901015, 0.1037560517766646], [0.05552881230999317, 0.030240962281823158, 0.011814926551388842, 0.04289564037961619, 0.04878052031355245, 0.0165886358424489, 0.053889553129140816, 0.05377746932208538, 0.04088928018297468, 0.027401427239445702, 0.003974259332088488, 0.04060012927012784, 0.029914834603135074, 0.02618713114809777, 0.02983726787247828, 0.08002204354852438, 0.021039448977847184, 0.04745368579668658, 0.03326847357675433, 0.01882686502566295, 0.05871054104396275, 0.04005755909851619, 0.007532552949019841, 0.05400465302435415, 0.11182292391146932, 0.015284676437399216, 0.025211280743990625, 0.001986957487783262, 0.024053728839914714, 0.031679758469441106, 0.033910296458218775, 0.015232797346210905, 0.026038917047636848, 0.04616406214024339, 0.08551202967230763, 0.014092430189651037, 0.03980484890884586, 0.07686327304691076, 0.023892576772985712, 0.023732232162728906, 0.03265622125140258, 0.030707790981978178, 0.045002345727490525, 0.026944523810275962, 0.041478920328829966, 0.07122702191450767, 0.033609742764383554, 0.03686059046802776, 0.04254597771380629, 0.04102706350386143, 0.030107579260532345, 0.0657824704955731, 0.013208356735828732, 0.026497408248750225, 0.04537995385804346, 0.019537966332531402, 0.023477812064811587, 0.022044042125344276, 0.23966008850506373, 2.8546556660107205, 9.27787138734545, 24.585396460124425, 29.284999915531703, 34.2875257219587, 33.44733912604195, 27.942498513630458, 23.685530049460276, 18.969160590853008, 22.445022991725377, 22.490921054567607, 15.989222390311104, 13.695597716740199, 15.810818706239973, 13.499350190162659, 10.97039176736559, 8.986517786979675, 5.795554544244494, 2.6190850266388486, 1.683379807642528, 0.8169116505554744, 0.42967795793499264, 0.3155032316488879, 0.35557932832411354, 0.42585704582078115, 0.9791193008422852, 0.44117035982864244, 0.5396937802433968, 1.0362248080117362, 1.5064690091780253, 1.7102157047816684, 1.9416324070521762, 0.5619094510163579, 0.6802950842039925, 0.9333647617271968, 1.1065327610288347, 1.334859686238425, 0.8017794511147908, 0.806721357362611, 1.0824727777923857, 0.12010969567511763, 1.2908963710069656, 1.6855851007359368, 2.297005840710231, 1.0460036375692912, 0.31422017621142523, 0.1754822786897421, 0.42872057216508047, 0.7206725318517003, 1.3992967371429716, 3.7616079364504134, 7.958945223263331, 12.578303933143616, 19.60550614765712, 28.43106630870274, 24.223629815237864, 20.415118932724, 22.39099727358137, 12.075682537896292, 28.80608490535191, 28.501864978245326, 25.90467003413609, 32.75464194161551, 33.75413336072649, 25.25984420095171, 11.529198033469063, 4.481006179537092, 0.788110607436725, 0.13414726885301725, 0.036055722406932285, 0.025336383941716382, 0.03003703197464347, 0.04954567372000643, 0.030749605702502385, 0.024965517056573714, 0.036292710940220525, 0.02208596032245883, 0.043525700856532366, 0.04786788732079523, 0.036825445746736865, 0.0278257966108088, 0.024091804832486168, 0.038197535156671486, 0.010475612079192485, 0.04793290115360703, 0.041205005919826884, 0.00910764985850879, 0.0661983038964016, 0.05978589691221714, 0.0062775468769749355, 0.017486587033740113, 0.026405838251646076, 0.02071837299237294, 0.06416189138378416, 0.0455643321786608, 0.02027466706931591, 0.042598289371068986, 0.026987186699573482, 0.07771925175828592, 0.02639080530830792, 0.031528713181614876, 0.11062334863735096, 0.024600636546633074, 0.036113662512174675, 0.048979707660951784, 0.021939841198867986, 0.017262538163257495, 0.02518166438676417, 0.012674356461502612, 0.04393183799194438, 0.020146540998082076, 0.02920156198420695, 0.034541778465999026, 0.022284837240087133, 0.018854228646627495, 0.030720876529812813, 0.04669804545119405, 0.01340279688260385, 0.019701686654505984, 0.022293432582435862, 0.040674442425370216, 0.04498231876641512, 0.028903708859745945, 0.060574917787952084, 0.035331854463687966, 0.00802458668061133, 0.06043826083519629, 0.0549977975897491, 0.03048867845375623, 0.011762925323897173, 0.03283762758863824, 0.03522133128717542, 0.053052854990320544, 0.013060390300649618, 0.022501976927742362, 0.03061253484338522, 0.030342779854046445, 0.02204453236689525, 0.031813294161111116, 0.05930562982601779, 0.021137227570371966, 0.014464190196512001, 0.02212280477397144, 0.005956532807821142, 0.07997923477419785, 0.01826771315453308, 0.0917769909969398, 0.035003792960196733, 0.029526366519608667, 0.043277397751808167, 0.03611135549311127, 0.023668680572882295, 0.01087234980825867, 0.03703647353021162, 0.06263535044022969, 0.02061084724430527, 0.019071174951802407, 0.014551169904214995, 0.07552200609019824, 0.02401579703603472, 0.036436495903347216, 0.008065623630370413, 0.015666683171210543, 0.0425895973374801, 0.0412064511994166, 0.018405810297865952, 0.06446727963962726, 0.02467825586375381, 0.06891646089830569, 0.06357175590736525, 0.061320430998291285, 0.06136944836803845, 0.04792133552421417, 0.012235208597433354, 0.0268579054224704, 0.7629742505294936, 5.320648210389273, 15.649417264120919, 32.44425548825945, 38.36445420128958, 38.402915954589844, 36.20191076823643, 23.87277705328805, 16.803080524717057, 11.738011377198355, 16.0514052936009, 20.86443635395595, 27.099572590419225, 19.242910930088588, 23.157753569739207, 20.70482407297407, 16.189149856567383, 10.681629845074244, 5.2888849547931125, 4.021703328405108, 1.1397402648414885, 0.48441912340266363, 0.48572712178741184, 0.1354904424931322, 0.08416055076356445, 0.278229294610875, 0.3115375473030976, 0.42862622865608757, 0.29256293975881165, 0.1356270315923861, 0.37116383920822826, 0.3550256980316979, 0.4444817192852497, 0.41504108905792236, 0.35470415385706083, 0.6874516201870782, 0.6544547879270145, 0.2146200428583792, 0.6025562499250684, 0.5854800747973579, 0.17466817237436771, 0.35053371478404316, 0.43500953327332226, 0.30830563072647366, 0.2853623261409146, 0.27752616948315073, 0.1466146848563637, 0.11359433457255363, 0.2017269004136324, 1.1886306128331592, 2.2346077603953223, 4.57728476183755, 9.332634483064924, 14.75037942613874, 22.789518151964458, 32.32939829145159, 29.336395740509033, 25.575900384357997, 24.28438660076686, 20.55410201208932, 33.60544885907854, 27.658146960394724, 27.446270329611643, 30.102368627275737, 36.24957888466971, 31.73709215436663, 18.501416546957834, 7.776057345526559, 1.5902816546814782, 0.09724199346133641, 0.05147049097078187, 0.021981136840102927, 0.0514498906476157, 0.016108977741428783, 0.009905030285673482, 0.019054672980148877, 0.012574622839955347, 0.04284019049789224, 0.049987020037536106, 0.027839346955131208, 0.017476644799379364, 0.00914829156161951, 0.03606259596667119, 0.058229337579437664, 0.021350842268605317, 0.08434952276625804, 0.04124538214611156, 0.022067704337782094, 0.011522122575635356, 0.03654281555541924, 0.02849316463938781, 0.005953526897688529, 0.042833235513951094, 0.002630359023377033, 0.04933862893709114, 0.009776915240633701, 0.02320146680410419, 0.03259325320167201, 0.047574410747204504, 0.07903814741543361, 0.010580243027236844, 0.05074058406587158, 0.01615877033743475, 0.022425054805353284, 0.04119386776749577, 0.06859803798475436, 0.027538620234866227, 0.04759751147191439, 0.00793366807712508, 0.0564824525666024, 0.03561173998085516, 0.0418148630165628, 0.06839896259563309, 0.036542360936956744, 0.039290302233504396, 0.02345787500962615, 0.043261306293840916, 0.014800553575956395, 0.10880052537790366, 0.11039903853088617, 0.08429956223283495, 0.12101837620139122, 0.18352328506963594, 0.11701754374163491, 0.11564864005361285, 0.1606170284960951, 0.09823386916624648, 0.17100808663027628, 0.15301902405917645, 0.10295060356812817, 0.09038032844130482, 0.09460677379476172, 0.15877101969506058, 0.21616056162331784, 0.11356928305966513, 0.10433189730559077, 0.12616411436881336, 0.1255639772862196, 0.13652733899652958, 0.08029480105532066, 0.1544114729123456, 0.17218271217175893, 0.21643512403326376, 0.09312246487076793, 0.09632774216255971, 0.1756886483303138, 0.10767851344176702, 0.13378214915948256, 0.1279880843524422, 0.12725339377565043, 0.13721554992454393, 0.11164007229464394, 0.21759004491780484, 0.11114023625850677, 0.1931488471371787, 0.1820813167308058, 0.11067218958799328, 0.12066297312932354, 0.10754169364060674, 0.15652592373745783, 0.12366378067859582, 0.12354534917644092, 0.08620948224727597, 0.12192462757229805, 0.24724404726709637, 0.1144520706896271, 0.12171477026173047, 0.19930662028491497, 0.10171355280492987, 0.16976009788257734, 0.1238046038363661, 0.13647268978612764, 0.15093373666916574, 0.1273568839366947, 0.1297342942229339, 0.08148573179330144, 0.5905180616038186, 5.011625341006687, 15.88524259839739, 35.277286188943044, 45.43719230379377, 47.602070331573486, 45.417223181043354, 37.337576457432334, 32.97893326623099, 25.171815735953196, 30.923034259251185, 32.80999823978969, 28.240353890827723, 23.684329748153687, 25.084871189934866, 19.991619280406407, 16.862039463860647, 12.437431812286377, 6.966108875615256, 4.178216712815421, 2.7369568731103624, 1.17122374687876, 0.66472156558718, 0.7541231683322361, 0.9403352162667683, 1.361800457750048, 2.577698733125414, 1.405272513628006, 2.0905978764806474, 2.7406118427004134, 3.512206473520824, 4.221531782831464, 4.776882188660758, 2.095891969544547, 2.421280017920903, 4.588983791215079, 3.97075001682554, 5.66693730865206, 4.7397505811282565, 2.785880442176546, 3.2687016427516937, 2.2853747734001706, 3.577267668076924, 5.057542511395045, 4.947020556245532, 2.458757732595716, 1.7010921772037233, 0.9706855991056987, 0.9263667315244675, 1.8416921240942818, 2.255747437477112, 5.428204587527683, 10.734706265585762, 16.34479645320347, 25.291812862668717, 36.1516683442252, 31.5737886428833, 27.413733652659825, 29.805131639753068, 19.603234086717876, 35.01084361757551, 35.537944384983604, 34.2881441116333, 40.895783696855815, 44.3847382409232, 35.69746807643345, 19.230167933872767, 7.4384209258215765, 1.3285016502652849, 0.22525686637631484, 0.10941312036343984, 0.1007062607843961, 0.16712529212236404, 0.09161072277597018, 0.08477339002170733, 0.14759925273912294, 0.11297903901764325, 0.08821804089737789, 0.19536578389150755, 0.15723949830446923, 0.10601090506783553, 0.08761480290974889, 0.21258815617433616, 0.16035329550504684, 0.1048049447791917, 0.1173640037221568, 0.11035421450755425, 0.13412181021911757, 0.2479523021195616, 0.16859031708112784, 0.12112504190632276, 0.07767185608723334, 0.23699957983834402, 0.11089305952191353, 0.14249831145363195, 0.10685036145150661, 0.09328456010137286, 0.10165452025830746, 0.1333674014146839, 0.16114654365394795, 0.19778075787637914, 0.099983383502279, 0.1651101109704801, 0.11158782509820801, 0.19369258438902243, 0.16237701262746537, 0.14986698462494782, 0.16256966228996003, 0.08513844186174017, 0.11631007598979132, 0.11265058735651629, 0.1738207092774766, 0.11893401161900588, 0.10976528682346855, 0.13455506839922496, 0.2447940744459629, 0.1815469161208187, 0.11108237757746663], [0.014031434132318412, 0.053103069974375625, 0.02018755504728428, 0.03101067544360246, 0.048770223544644456, 0.042052608116396835, 0.07882765906729869, 0.04104884108528495, 0.031189717086298124, 0.06528444614793573, 0.014923059680898274, 0.05057927932856338, 0.025175525341182947, 0.034630917611398866, 0.016693834215402603, 0.04308278712310961, 0.008375541955631758, 0.09399784289832626, 0.037296036923570294, 0.01109052510998611, 0.07604721933603287, 0.06725371083510773, 0.01875295559875667, 0.06212913617491722, 0.06260686554014683, 0.03535355401358434, 0.01954157104981797, 0.006514203776272812, 0.011107226401301367, 0.009436829248443246, 0.010960219245004867, 0.0342189315041261, 0.029299230314791203, 0.011021906559887742, 0.03288618355457272, 0.015117113910881537, 0.06271245237439871, 0.034414431013699086, 0.09778273837374789, 0.019711486396512816, 0.018696806825963513, 0.04387071216478944, 0.016064284336087958, 0.10144734994641372, 0.015444612230307289, 0.05043253256008029, 0.05397660917203341, 0.03110340064657586, 0.05802945473364421, 0.022758793950613056, 0.013143280986696482, 0.03438770351931453, 0.0322964043090386, 0.05884028372487851, 0.074147965892085, 0.014969732712156006, 0.04667355712237103, 0.03376818408391305, 0.04215987093214478, 0.0822688222729734, 0.9499255759375436, 4.575178154877253, 12.899763209479195, 26.58583320890154, 34.404752254486084, 38.080335412706646, 40.15694005148751, 33.1875181879316, 28.997882979256765, 22.978401456560405, 19.60539845057896, 17.919131449290685, 18.575585092817033, 16.89892397608076, 12.1180066210883, 13.471105762890407, 22.074786492756434, 15.91203658921378, 12.602083274296351, 9.202017903327942, 6.567638371671949, 3.556500153882163, 2.371038028172084, 1.6843804568052292, 0.5116724010024751, 0.7897663957306317, 0.3354021667369774, 0.20552942422883852, 0.09580133469509226, 0.14839749490576132, 0.13506736233830452, 0.2484421229788235, 0.18980845995247364, 0.4700861839311463, 0.36805471032857895, 0.2757917254098824, 0.3762897370117051, 0.6535157497440065, 0.1744170601346663, 0.10179586588804211, 0.04381720628589392, 0.517240893627916, 0.9150090324027198, 0.8734360603349549, 2.1675474388258795, 3.375780765499387, 5.2306859748704095, 7.030539086886814, 10.134662440844945, 15.269455024174281, 17.85648649079459, 18.34866213798523, 16.02862909861973, 16.84063901220049, 17.916124616350444, 16.547265223094396, 17.22340832437788, 19.29725452831813, 21.639954328536987, 30.890499319349015, 32.522832666124614, 32.53755589893886, 15.773689270019531, 3.625481218099594, 0.866699293255806, 0.32996948968086925, 0.05351179572088378, 0.01636977437218385, 0.028673342828239714, 0.023000703559124043, 0.06428432624254908, 0.06408332381397486, 0.052151268547666926, 0.04976204496675304, 0.05504957659702216, 0.028854277583637407, 0.020616233116015792, 0.03424567596188613, 0.026389271819165776, 0.046749597149235864, 0.015226597232478005, 0.01776263034636421, 0.07649502530694008, 0.037274449331951995, 0.05202254366927913, 0.028373884968459606, 0.012820858957378991, 0.021232465049251914, 0.027748957608959506, 0.03720045169549329, 0.021530609943770936, 0.01726568995841912, 0.05142315976055605, 0.03732175679345216, 0.011594958220874625, 0.01660868655224996, 0.01201072461637003, 0.0253910212777555, 0.05201903564323272, 0.044554560112633874, 0.032912402147693295, 0.035514064864920716, 0.03472384298220277, 0.04628271416627935, 0.030602234681802135, 0.01860360155946442, 0.06381920405796596, 0.011627481252487217, 0.027958375568102514, 0.05081900914332696, 0.008233093706491803, 0.06789561174809933, 0.021571225353649685, 0.03908878072564091, 0.06300959642976522, 0.044499096660209556, 0.04158481589651533, 0.02515559846402279, 0.018038899271882007, 0.010768609437426286, 0.04071134115968432, 0.009530539175362458, 0.02604731052581753, 0.016860507861045853, 0.034119078290781805, 0.027049622099314417, 0.04583919653669, 0.04772623974297728, 0.034300128397132666, 0.06324336531438998, 0.04423988610506058, 0.0811599399894476, 0.05992849783173629, 0.10700381214597396, 0.0343767723201641, 0.058298575292740545, 0.06452957593968936, 0.02578674120429371, 0.04392382110069905, 0.05228269738810403, 0.04842704088826265, 0.045098144694098403, 0.017572872939386537, 0.019832852562623363, 0.023629405269665376, 0.040788236140672646, 0.04013592989317008, 0.0316901061284755, 0.02073780623530703, 0.0161837726565344, 0.05925143523407834, 0.02600573329254985, 0.045023054616259675, 0.007787840723592255, 0.007677980815060437, 0.05221035876976592, 0.028842352330684662, 0.017349841871431897, 0.056373157538473606, 0.024593437290085212, 0.04034871508234313, 0.02448319231293031, 0.0374459897700165, 0.039888983858483176, 0.05525951533179198, 0.033575056054230244, 0.047567588077591996, 0.020577057896714126, 0.052017729463321824, 0.03775828890502453, 0.02894599176943302, 0.04005263971963099, 0.02194366983271071, 0.021648965110736232, 0.01482144058016794, 0.2210978674037116, 1.6340398894889014, 7.792816400527954, 18.163897378104075, 32.782163756234304, 39.51120226723807, 40.94843714577811, 37.58368512562343, 27.621653284345353, 20.753979103905813, 21.714708260127477, 13.76707123007093, 15.815329824175153, 18.10622385569981, 21.513045481273107, 23.09845069476536, 22.87871217727661, 24.33533947808402, 18.17581180163792, 19.09154268673488, 12.180633340563093, 6.757843571049826, 3.1843444321836745, 2.4520818165370395, 1.3996829049927848, 0.8427248054317066, 0.7182070070079395, 0.19106156485421316, 0.17090173305145331, 0.023395388719758818, 0.10598911730838673, 0.10856579975890261, 0.13030743918248586, 0.2910394657935415, 0.2143825963139534, 0.24744562645043644, 0.20800550707748958, 0.06098824060921158, 0.10500581150076219, 0.14841570678566182, 0.0723671643063426, 0.2539339954299586, 0.4344564729503223, 0.571440859564713, 0.7675391627209527, 1.5072106208120073, 3.2184509677546362, 6.481815091201237, 12.61293375492096, 16.221745593207224, 22.164802142551967, 23.66739525113787, 26.102700642177037, 23.03452726772853, 24.877653326307023, 21.2515743459974, 16.655438252857753, 18.309373549052648, 14.301909685134888, 19.033655507223948, 32.51661055428641, 34.030970437186106, 35.62182303837368, 24.877913883754186, 8.781078662191119, 2.437068279300417, 0.4528120665677956, 0.04333888320252299, 0.038756970316171646, 0.07634363735892943, 0.06752163038722106, 0.05953592461134706, 0.04212806460314563, 0.0849136703514627, 0.04142998099060995, 0.03306717937812209, 0.029632720098431622, 0.017082100434760963, 0.04063544701784849, 0.020589734627200023, 0.048732076305896044, 0.03686083474063447, 0.028841144538351467, 0.08519391888486487, 0.048613654981766424, 0.02572169853374362, 0.028197060438937376, 0.05469908272581441, 0.039077707034136565, 0.040534060315362046, 0.05122711742296815, 0.06317258732659475, 0.046501908118703535, 0.007486481269422386, 0.025461339558075582, 0.010918536838809294, 0.018877336156687567, 0.016989271755197217, 0.04316248445372496, 0.03248548148466008, 0.037725074615861685, 0.040251942417983494, 0.04853180330246687, 0.048598506687475104, 0.0734263981825539, 0.07402876764535904, 0.047633436508476734, 0.05320344565968428, 0.06490981339343957, 0.06949068472853728, 0.04619144781359604, 0.03499448685241597, 0.054224871564656496, 0.03051611501723528, 0.03130930209798472, 0.014912886744631189, 0.06956902159644024, 0.07112640874194247, 0.1346078584236758, 0.1454399778906788, 0.17307782199765953, 0.10774420920227255, 0.1066979014181665, 0.10922868776002101, 0.1126607246696949, 0.06599038719598736, 0.15889132395386696, 0.1219648646989039, 0.16563250151063713, 0.17940141553325312, 0.09560962141092334, 0.12725382803806237, 0.14428293997687952, 0.12770094190325054, 0.21138372937483446, 0.11101499905011483, 0.15860013743596418, 0.14999834900455816, 0.24356006351964815, 0.08966876912329878, 0.24135680603129522, 0.18927673277045998, 0.14500806320990833, 0.1547938816781555, 0.07837750536522695, 0.11533426120877266, 0.11082220689526626, 0.174237777612039, 0.1638667769730091, 0.07190136358674083, 0.07438193833721535, 0.17003068407731398, 0.0913474986861859, 0.12139242541577135, 0.07529051708323614, 0.14404439420572349, 0.19222299967493328, 0.11344868024545056, 0.13734652075384343, 0.236234898013728, 0.27279406626309666, 0.18407652181174072, 0.15755417570471764, 0.17298567694212708, 0.12414103506931237, 0.1387564350983926, 0.10363738278725318, 0.07117887306958437, 0.12064013364059584, 0.15399136474089964, 0.16824442707002163, 0.22178678400814533, 0.25144398904272486, 0.13044368901423045, 0.13033349492720195, 0.18264583072492055, 0.26334310482655254, 1.5421395408255714, 7.095859970365252, 18.98940416744777, 37.18087373461042, 46.94741106033325, 51.929297242845806, 50.980802127293174, 43.62032175064087, 38.90251922607422, 33.23216731207711, 27.893730844770158, 26.48757873262678, 26.89825027329581, 26.676131997789653, 21.679077897753032, 22.292244264057704, 31.02354690006801, 21.198314666748047, 17.93600688661848, 12.552328092711312, 8.832327706473214, 4.520821963037763, 3.3403260622705733, 2.3819241183144704, 0.9714640144790921, 1.7844068322862898, 0.8627706297806331, 0.5451264572995049, 0.3173709399998188, 0.7506435321910041, 0.5809478951351983, 0.9080232158303261, 0.952854567340442, 1.1462350934743881, 1.4383605952773775, 0.9020611728940691, 0.9309888035058975, 1.5661056148154395, 0.5174311005643436, 0.5918306740266936, 0.66101350741727, 0.9153025937931878, 1.5223540025097984, 1.3509939461946487, 2.5602320475237708, 4.391600668430328, 7.374558295522418, 11.189630883080618, 15.356436048235212, 22.321732418877737, 25.87444363321577, 27.927467823028564, 23.055203369685582, 24.797151497432164, 25.271449429648264, 24.340055567877634, 25.67002068247114, 25.286304678235734, 29.890511104038783, 38.81218917029244, 41.47425249644688, 41.01386833190918, 27.01040288380214, 8.607789720807757, 2.234204113483429, 0.48243242715086254, 0.06442310700991324, 0.09554049904857363, 0.10387075133621693, 0.14654763202582086, 0.1761672326496669, 0.20470721620534146, 0.1669122999800103, 0.08620798268488475, 0.09339596876608473, 0.1573035791516304, 0.17740790678986482, 0.11729182116687298, 0.1518224546951907, 0.220358562788793, 0.11423590300338608, 0.08524421190044709, 0.19323430183742726, 0.1759003648268325, 0.24017650793705667, 0.1105117296267833, 0.10853656168494906, 0.1367191065635, 0.10250971865441118, 0.14877205980675562, 0.12693259598953383, 0.19014064355620316, 0.1114019336444991, 0.13183788848774775, 0.08514600752719811, 0.09007185285112687, 0.08170729383294072, 0.14770456137401716, 0.07629468105733395, 0.16893400863877364, 0.210825810741101, 0.17517699221415178, 0.21370193069534643, 0.12129430925207478, 0.1451082014079605, 0.12282683487449374, 0.20808872261217662, 0.13059067326997006, 0.13546297539557728, 0.1444818593029465, 0.14773103781044483, 0.1595840132130044, 0.19524634815752506, 0.11528900292302881, 0.13477954135409423, 0.1515727402376277], [0.013566891247007464, 0.06474882417491504, 0.008383062668144703, 0.016060311513553773, 0.07158299495599099, 0.00885667756665498, 0.02035199461637863, 0.02542034925759903, 0.03510492181937609, 0.015729418822697232, 0.09661322898630585, 0.019963093966777836, 0.04660427191161683, 0.02027050086430141, 0.02913962530770472, 0.027058232708701065, 0.07568505126982927, 0.02582789944218738, 0.02360435206043933, 0.05278139687808497, 0.019754782019715224, 0.09165098704397678, 0.006221833638846874, 0.02047469071112573, 0.017976798050637757, 0.017095694883859584, 0.05520425204719816, 0.023789810948073864, 0.00816268043126911, 0.024673772443618094, 0.010670845263770648, 0.08574617175119263, 0.045412866199123006, 0.05960322171449661, 0.04468709496515138, 0.030036109167018106, 0.041070611881358285, 0.034572889296604056, 0.04553683454703007, 0.06050797352301223, 0.020724725776485035, 0.012294621971834983, 0.034712223070008416, 0.07087545935064554, 0.026303058856033852, 0.02671860048680433, 0.07242336736193725, 0.041626600082963705, 0.039082592486270835, 0.01741587689944676, 0.05117286854822721, 0.013934692850203385, 0.024934903252869844, 0.030362294521182775, 0.03619184670969844, 0.0694958008825779, 0.03916430506589157, 0.05281032282592995, 0.08964508146579776, 0.03429869329556823, 0.042985804112894196, 0.0651822452034269, 1.1794504140104567, 4.4550720282963345, 15.573198999677386, 23.426586321422032, 31.064263343811035, 38.11555583136422, 38.69878762108939, 33.24129377092634, 38.75337266921997, 23.716786520821707, 26.917632273265294, 23.090291772569927, 15.793545484542847, 15.721223422459193, 29.013617174965994, 36.428025994982036, 14.740056140082222, 18.5907530103411, 18.65393124307905, 16.77407874379839, 12.729592272213527, 11.503305571419851, 10.530325872557503, 7.838265436036246, 6.736662856170109, 5.544798833983285, 4.606508885111127, 4.1455197930336, 3.2583963785852705, 2.547208083527429, 1.9028599389961787, 2.029770089047296, 1.6461956543581826, 2.241779604128429, 1.8512044250965118, 1.6626612565347125, 2.0497637476239885, 2.665307483502797, 3.3918124309607913, 5.2012859753199985, 7.283210328647068, 10.180945260184151, 12.289554170199803, 15.451864344733101, 17.001043387821742, 13.175320080348424, 16.813989196504863, 14.239061491830007, 17.822824205671036, 19.959461280277797, 19.04559772355216, 19.760397127696447, 19.844491175242833, 20.925924437386648, 25.16939776284354, 33.32293163027082, 30.273996080671036, 28.94725145612444, 24.7876706804548, 14.744881664003644, 2.3911802044936588, 0.4069667123258114, 0.07553479647529976, 0.01920199819973537, 0.068822524510324, 0.07930654872741018, 0.00443650410410815, 0.012171977615383054, 0.03527111200881856, 0.01602347893640399, 0.041563669352659156, 0.011693269463389047, 0.015976727873619114, 0.03707457666418382, 0.07643485960683652, 0.010338430109966015, 0.03173199888052685, 0.025792586783479367, 0.042007841768541505, 0.047119218922619305, 0.041672302809144766, 0.05401187602962766, 0.07877687750650303, 0.0540912273073835, 0.1085564224049449, 0.06618370860815048, 0.09250396663056952, 0.02637778252496251, 0.02662527817301452, 0.02315165724472276, 0.08034214244357177, 0.08697498509926455, 0.05526403098234108, 0.01982819102704525, 0.04621327289247087, 0.01587574659580631, 0.020091734028288295, 0.02786214742809534, 0.04651120065578392, 0.05500297820461648, 0.047411358782223294, 0.032573229633271694, 0.05663752495976431, 0.033231252538306374, 0.012479815382643469, 0.014138440801096814, 0.06104791097875152, 0.03344738969047155, 0.04447674232402018, 0.013894476079648095, 0.023793510660263043, 0.025518397567793727, 0.02745776600204408, 0.046419574679540734, 0.016455020422914197, 0.11053205175059182, 0.03933287691324949, 0.05747623834758997, 0.01351883654881801, 0.06344112434557506, 0.06073227684412684, 0.02818530481973929, 0.04628616451684918, 0.03820190152951649, 0.008056508360563644, 0.0156759672266032, 0.03650418994948268, 0.04178826444383178, 0.022073863739413873, 0.03889486559533647, 0.0401985247486404, 0.039154222035514455, 0.061329503011490615, 0.04886014639799084, 0.05457046302035451, 0.07325341925024986, 0.028095383662730455, 0.0406018052516239, 0.04001613114295261, 0.012794707369591509, 0.015680605013455664, 0.010257702254291092, 0.06180623493024281, 0.014390894843797599, 0.04310452059975692, 0.08112961625946419, 0.06821297614702157, 0.028938266648245708, 0.06956222267555338, 0.03444429333986981, 0.018899849948606322, 0.03898234572261572, 0.04603905902643289, 0.025271996057459285, 0.007928385682004904, 0.038427246401884725, 0.02905851662425058, 0.05641662109909313, 0.07239745410957507, 0.05926105686064277, 0.03468876611441374, 0.019942113664001226, 0.03710230839039598, 0.06747289800218173, 0.015239338423790676, 0.023385475323136364, 0.08480505725102765, 0.053442500332104306, 0.044363182703299184, 0.05142997225214328, 0.05285900432084288, 0.011915249650233557, 0.03331997777734484, 0.06195597403815814, 0.040625740574406724, 0.21899413743189403, 2.5534410519259314, 9.024724193981715, 21.842787878853933, 31.929004873548234, 38.46557133538382, 45.341008390699116, 42.71629510607038, 34.026902266911094, 34.354638372148784, 16.42441586085728, 17.18995795931135, 15.518294334411621, 12.21201661654881, 16.49899956158229, 36.55757168361119, 32.547675950186594, 21.305664334978374, 29.418613774435862, 27.491996424538748, 24.208338567188807, 18.929771253040858, 16.89301974432809, 11.832327961921692, 9.081764561789376, 8.28032546383994, 5.219834625720978, 4.929947529520307, 4.301336620535169, 3.4238536145005907, 2.3292889084134782, 2.5186713976519446, 2.713706463575363, 1.8135311837707246, 2.7070774478571753, 2.779248603752681, 2.5159283791269575, 3.1264077467577795, 2.5171034932136536, 5.713340852941785, 7.3197839089802335, 8.87711579459054, 14.903769595282418, 18.44781640597752, 22.14689142363412, 23.819984640393937, 18.86948868206569, 19.431419031960623, 16.814727442605154, 19.381145341055735, 17.767198664801462, 16.21089424405779, 16.579440593719482, 17.408284255436488, 20.695548227855138, 25.320911918367656, 34.02520343235561, 34.999115058353965, 32.78297322137015, 30.08540460041591, 19.539458308901104, 4.591976727758135, 0.8899272297109876, 0.07554622979036399, 0.05980748789651053, 0.05230118068201201, 0.036348964885941575, 0.027877190549458777, 0.023615656453850012, 0.04312931426933833, 0.05739986923124109, 0.007673519447312823, 0.02378327156683164, 0.10185374492513281, 0.0415123415711735, 0.045083987060934305, 0.03384687039735062, 0.03552258726475494, 0.040667629933782985, 0.04589874137725149, 0.12048302564237799, 0.057234863085406165, 0.006938298340953354, 0.016991466815982546, 0.04523779059361134, 0.07899817491748504, 0.024815148607428585, 0.009428177926955479, 0.03371435250820858, 0.0037859650162447777, 0.03024121673245515, 0.014402462169528008, 0.025187676207029393, 0.03241620645193117, 0.034096255765429566, 0.019432679750025272, 0.03302444184997252, 0.01612320662076984, 0.014844461577013135, 0.028293965417625647, 0.011296182288788259, 0.0338290079629847, 0.04973919190732496, 0.014812979248485394, 0.0019367266005636857, 0.016220155704234327, 0.0005726590118553888, 0.010277760597611112, 0.031027007781501328, 0.07252195850014687, 0.09577468183955976, 0.0437344792964203, 0.03669203219137021, 0.010005598505293685, 0.014044860643999917, 0.07215705593781811, 0.1682480097349201, 0.11222773790359497, 0.16110038970197949, 0.2017169123781579, 0.1327904566590275, 0.11131592933088541, 0.07997231371700764, 0.12312604167631694, 0.16232913519654954, 0.18828483670949936, 0.05452604951070888, 0.12819570249744824, 0.09155937803110906, 0.1499626173504761, 0.22253653806235107, 0.12470341846346855, 0.10228371899574995, 0.1526884146566902, 0.11571042745241097, 0.16538309917918273, 0.1539214892046792, 0.1649139193551881, 0.13674437520759447, 0.06575988206480231, 0.10195758113903658, 0.10535337749336447, 0.0915652270029698, 0.14160869776138238, 0.1584404238632747, 0.10235339097146477, 0.28518400713801384, 0.209854677851711, 0.14385094387190683, 0.13550504456673348, 0.14873894729784556, 0.10063772874751262, 0.14058586050357136, 0.10583739009286676, 0.14367637038230896, 0.1357487200626305, 0.16456220751362188, 0.16036705619522504, 0.16029006961200917, 0.22230913383620127, 0.1645363960415125, 0.11958632804453373, 0.14594746780182632, 0.14340317861310073, 0.14976745710841247, 0.18967474784169877, 0.09891196992248297, 0.11051236066435065, 0.2017810067960194, 0.11534210507358823, 0.21205991666231835, 0.11274362129292317, 0.15460397329713615, 0.3362138846090862, 0.1247043955538954, 0.11338656714984349, 0.16852409206330776, 2.2402544745377133, 7.891881210463388, 22.178045409066335, 35.336498737335205, 47.482978207724436, 55.29978500093733, 52.23002917425973, 44.661662169865195, 50.037935052599224, 32.595163413456504, 36.55966656548636, 31.3461309160505, 21.527117320469447, 21.86980073792594, 40.76949323926653, 47.03902653285435, 21.063135726111277, 27.310196808406285, 26.57428182874407, 23.778260707855225, 17.79494629587446, 16.640411036355154, 13.528562154088702, 10.794356550489153, 9.147887962205068, 7.844883595194135, 6.791405541556222, 5.8793797833578925, 4.250169217586517, 3.425896167755127, 2.7049013589109694, 2.9225875522409166, 2.493969900267465, 3.27878760440009, 2.5679126296724593, 2.4006501649107252, 3.514403841325215, 4.342619776725769, 5.011021716254098, 8.176809464182172, 10.144771201269966, 14.667119162423269, 17.465163946151733, 22.651019709450857, 26.901024341583252, 21.101701702390397, 23.37873407772609, 20.98445779936654, 26.01414932523455, 26.953144516263688, 25.98549321719578, 28.54032325744629, 27.906977585383824, 30.117203031267437, 35.37667669568743, 42.69416856765747, 42.007085527692524, 39.20410231181553, 32.477933406829834, 19.68711621420724, 4.596060965742383, 0.7686718819396836, 0.18124135823122092, 0.1538508537092379, 0.18171021235840662, 0.19277121525790009, 0.13077338917979173, 0.09529265734766211, 0.08825069200247526, 0.15253436006605625, 0.12354929825024945, 0.08485511956470353, 0.25533052906394005, 0.12218266086918966, 0.1946367115846702, 0.2632960687790598, 0.13565477010394844, 0.12381474114954472, 0.13593987694808415, 0.17905004295919622, 0.10484089356447969, 0.06890453903802804, 0.08682806869702679, 0.10021774949772017, 0.12869720772973128, 0.13352240595434392, 0.13946504278906754, 0.1374593882688454, 0.09076778550765344, 0.13054930977523327, 0.10494857028658901, 0.270509058875697, 0.17562037413673742, 0.11750971233206135, 0.0695229083565729, 0.11988153148974691, 0.08579349956874337, 0.09223005561424152, 0.14598249377948896, 0.06563347777617828, 0.2277779903795038, 0.14857049419411592, 0.11455283313989639, 0.059691580544625006, 0.08242734840938024, 0.05528754900608744, 0.08679811816130366, 0.11902690306305885, 0.15128676486866816, 0.16125067163790974, 0.1095862350027476, 0.06238005163946322, 0.08415736843432699, 0.08584470860660076], [0.03645506401413253, 0.02599576222045081, 0.01744428546434002, 0.030259957869670222, 0.06866468369428601, 0.03551349489550505, 0.04883530523095812, 0.0165031404300992, 0.10817805092249598, 0.04899404849857092, 0.025144590929682766, 0.06699513471020119, 0.029299912242484943, 0.0767417134983199, 0.04314925302086132, 0.036993922599192174, 0.0651287359318563, 0.011901595829320806, 0.040266388428530524, 0.06787258905491658, 0.043160676157900264, 0.05244043642388923, 0.03448272556332605, 0.002537001298540937, 0.044936571935457845, 0.029495123374675, 0.01608181937730738, 0.03372064931318164, 0.06783549354544707, 0.08270556812307664, 0.03838362677821091, 0.014564090907307608, 0.051746183141533814, 0.006810745207725891, 0.004134394868742675, 0.003519599309324154, 0.007383311716174441, 0.05479888504903231, 0.037756260085318766, 0.08730455634317227, 0.07344330048986844, 0.04920901178515383, 0.06627220314528261, 0.0989763086129512, 0.04473553218745759, 0.07004565852028982, 0.03352325329823153, 0.0035303470919773516, 0.014900705344708902, 0.02083742365773235, 0.02146419832882072, 0.06631958524563483, 0.061930413624005656, 0.020026023000744835, 0.03193439569856439, 0.051891566054629426, 0.03975356183946133, 0.03935621173254081, 0.047640489879995584, 0.010751080333388277, 0.007876656716689467, 0.08136263197021824, 0.019907199644616673, 0.1667076266769852, 1.1004965135029383, 4.2670676708221436, 9.908964106014796, 19.568303755351476, 31.595435755593435, 39.81773941857474, 34.26662901469639, 38.14671502794538, 38.18744189398629, 32.48490939821516, 30.459464345659526, 25.987760066986084, 28.741626467023575, 70.60347379956926, 39.650239195142476, 18.26772952079773, 21.79653024673462, 16.792076315198624, 13.655408467565264, 17.47263673373631, 20.18463155201503, 26.04967893872942, 20.302561589649745, 22.52363317353385, 16.60131525993347, 15.244479724339076, 14.393321054322378, 13.281448602676392, 13.441268461091177, 12.231163246291024, 14.4506219795772, 12.426979116031102, 12.407540661948067, 12.306265456335884, 16.04241779872349, 17.801276104790823, 13.459358964647565, 16.89965353693281, 19.70358518191746, 12.697387371744428, 16.922589540481567, 13.953830122947693, 19.41198318345206, 21.591063329151698, 19.826326847076416, 24.927800212587627, 21.893252645220073, 28.7210111618042, 26.979587623051234, 31.240254265921457, 33.57340029307774, 31.391113553728374, 26.330512966428483, 20.66764078821455, 19.52304666382926, 13.518448182514735, 6.0377769981111795, 1.8566720059939792, 0.06570376043340989, 0.07499300661895957, 0.004899812055685158, 0.0660443850127714, 0.11098918757800545, 0.061510576866567135, 0.08743626677564212, 0.08801493501024586, 0.00860086053476802, 0.04676555968554957, 0.049745414073445966, 0.032379551990223784, 0.04972097324207425, 0.033291489484586885, 0.040133751795760224, 0.05613991451848831, 0.030289684488837208, 0.0603691249021462, 0.00815991879374321, 0.03490156826696225, 0.035742615815252066, 0.01862720270375056, 0.022312538432223455, 0.008403020927549472, 0.009957700718327292, 0.06605446125779833, 0.012315011949145367, 0.09608711328889642, 0.04827679966443351, 0.021991348792133585, 0.02643226210160979, 0.060861666686832905, 0.042818324706916294, 0.0411787907193814, 0.023937560252047012, 0.029154156135129075, 0.05434320467923369, 0.03122963530144521, 0.03480235626921058, 0.05993640276470354, 0.028465219174644778, 0.04984527746481555, 0.019214958218591552, 0.04715685386742864, 0.03957687471328037, 0.05003659041332347, 0.05288958928680845, 0.07018673273601703, 0.017732159035014253, 0.011976913216390779, 0.054459797351488044, 0.07112139436815466, 0.03724297548511198, 0.04638471833563276, 0.041142356781555076, 0.0354158265649208, 0.020926698510135924, 0.02881546877324581, 0.06710890467677798, 0.008890958852134645, 0.029247329171214784, 0.030145322770944664, 0.03937093594244548, 0.004428496966803712, 0.03127859838839088, 0.10603208214576755, 0.028733905471329178, 0.06327296301190342, 0.0219574305228889, 0.049570036519851, 0.09352231198655707, 0.02450446268942739, 0.03141826803662947, 0.05241537134030035, 0.04558050166815519, 0.011322659573384693, 0.04373040469363332, 0.012192060555597501, 0.03302747829418097, 0.053127853465931754, 0.019670847237908413, 0.04537013206364853, 0.019305483271766986, 0.05727176181972027, 0.06723407403166805, 0.021777610261259333, 0.0604584879641022, 0.03018295093040381, 0.012587996765172907, 0.01962302069711898, 0.05404844906713281, 0.03533651599926608, 0.01672774739563465, 0.09068222224180188, 0.03939124110287853, 0.014409442598532354, 0.022324290658746446, 0.06546441399093185, 0.016550609043666294, 0.05808903689363173, 0.022274923843464682, 0.046622758598199913, 0.017648293803046857, 0.03472585483853306, 0.04154433110462768, 0.028878402896225452, 0.056457886206252236, 0.01360298930999956, 0.03232405461104853, 0.015746419517589465, 0.032166098444057364, 0.034769986756145954, 0.011828956959236945, 0.052543434647044966, 0.01847912261395582, 0.04233051909665976, 0.06217993809176343, 0.18740537390112877, 2.1942867125783647, 6.858529048306601, 15.364537647792272, 27.420153788157872, 39.09133652278355, 45.61209583282471, 40.758365699223106, 39.9222229548863, 38.078653948647634, 27.95562539781843, 19.185946123940603, 17.754391397748673, 30.691544600895472, 65.78608621869768, 23.61969586781093, 17.28925119127546, 24.341896840504237, 23.18488802228655, 21.804053408758982, 25.70176179068429, 26.600526911871775, 27.719101769583567, 25.895463671003068, 27.023903233664377, 25.87319643156869, 23.745256764548166, 21.410571711403982, 22.821318319865636, 16.44027165004185, 16.97819597380502, 19.613882201058523, 19.804268053599767, 18.065415348325455, 19.499342884336198, 16.841790676116943, 18.81439815248762, 20.503001485552105, 25.74909118243626, 28.087663752692087, 19.936436687197002, 21.348110880170548, 20.97817141669137, 20.162406001772197, 14.927059956959315, 14.693126269749232, 15.992896250316075, 18.880711759839738, 25.432805708476476, 23.908421312059673, 31.751124041421072, 31.628967761993408, 33.75649574824742, 31.6222870690482, 27.707220349993023, 24.804917846407207, 18.961901460375103, 9.719643064907618, 3.7086409500667026, 0.26994685190064566, 0.03693444900480764, 0.07344057956444365, 0.04458684141614607, 0.06236101873219013, 0.07011444161513022, 0.0755754950057183, 0.012711649594296302, 0.03189342236146331, 0.08876084177089588, 0.028057394183373878, 0.011940475037720586, 0.06585199997893401, 0.01470524993991213, 0.03663974767550826, 0.02747373023469533, 0.04149740023006286, 0.014881843767528023, 0.03479203575157693, 0.01905691044937287, 0.026445949849273478, 0.016719416681943194, 0.030137109104543924, 0.013771568790876439, 0.017421941306175928, 0.09279338217207364, 0.019114986261618987, 0.039093740816627226, 0.03813730160306607, 0.03160935028323105, 0.03300754293533308, 0.052658724532063515, 0.04478572003011193, 0.026495240329365646, 0.06099856112684522, 0.046265106182545424, 0.01584133129966046, 0.01982869653563414, 0.04862060996570757, 0.010149767688874687, 0.012494123141680444, 0.01677350270827966, 0.01661570938969297, 0.040481904721153636, 0.049402387480118444, 0.0502733821714563, 0.029232713526913097, 0.030769547846700464, 0.022270493009792905, 0.03791166156796472, 0.07243682949670724, 0.035549891513905356, 0.06787858730448143, 0.019972907279485037, 0.1553993656166962, 0.13206736903105462, 0.14204065315425396, 0.11874103625970227, 0.13946216580058846, 0.18441258663577692, 0.1325991912079709, 0.08687804958650044, 0.19963933314595902, 0.22485540434718132, 0.10814950495426144, 0.280877589647259, 0.07546720760209219, 0.15047499271375792, 0.11791269427963666, 0.16139093839696475, 0.17796233775360243, 0.10659595831696476, 0.10591937747917005, 0.16189477778971195, 0.1373485970710005, 0.11122700053134135, 0.18644519256693975, 0.09493103889482361, 0.1394804319632905, 0.10345075173037392, 0.12303245812654495, 0.15095730897571358, 0.1361991044666086, 0.1892481664461749, 0.09651443428759064, 0.1056971504752125, 0.12480365165642329, 0.08440517620848757, 0.09346247198326246, 0.11005615442991257, 0.13009927820946487, 0.17597651002662523, 0.11129997697259698, 0.17253652747188294, 0.1886811690138919, 0.13724022145782197, 0.16316844230251654, 0.26313696588788715, 0.09450335827256952, 0.2650636253612382, 0.09338399262300559, 0.10698232294193336, 0.07826537745339529, 0.15387538953551225, 0.11563163596604552, 0.16261654905974865, 0.16385444120637008, 0.13348775995629175, 0.07124759509627308, 0.16262072883546352, 0.20163043987538132, 0.14021007423954351, 0.11742116351212774, 0.1172705694500889, 0.07778369222900697, 0.13887109394584382, 0.19708422810903617, 0.2877799735537597, 1.8152802842003959, 6.527687532561166, 15.616288253239222, 28.45667389460972, 45.30779252733503, 56.36664962768555, 50.38592515672956, 51.31215129579817, 50.67010300500052, 44.86275693348476, 39.7988611630031, 34.32902383804321, 35.25304044995989, 78.52617808750698, 49.33427013669695, 25.91305477278573, 32.4447522844587, 25.466794558933803, 21.767681326184952, 26.613007613590785, 30.312113898141043, 36.94426325389317, 27.753721169063024, 32.08448818751744, 24.01067795072283, 21.887129545211792, 20.93748450279236, 21.704810551234655, 19.593280792236328, 18.431277956281388, 20.275246483939036, 17.90281707899911, 18.35930504117693, 19.709746497017996, 20.793754066739762, 25.228950772966655, 20.752235106059484, 24.91061384337289, 28.218824897493633, 19.494901248386928, 25.820205995014735, 22.585253272737774, 26.625813143593923, 27.153136253356934, 26.18128650529044, 32.29329545157296, 30.53243432726179, 38.87547336305891, 35.907553809029714, 42.140077522822786, 44.61628001076834, 43.24337155478341, 36.97785084588187, 31.808290345328196, 27.771932397569927, 19.07503550393241, 9.074182340076991, 3.0594116960253035, 0.24024987114327295, 0.14147067016788892, 0.12565857863851956, 0.18440050871244498, 0.2123720156294959, 0.19230458672557557, 0.13910026236304215, 0.17804693749972753, 0.12996027352554457, 0.13349933576370987, 0.13410158987556184, 0.12258792269442763, 0.16927544746015752, 0.16398970037698746, 0.15534638560244016, 0.10393249123756375, 0.13230272568762302, 0.1642146890184709, 0.09255831728556327, 0.10277158567415816, 0.10116688428180558, 0.07635810372552701, 0.16411430654781206, 0.0948918399267963, 0.08902183348046881, 0.20700677138354096, 0.09596915676125459, 0.13997065994356359, 0.12709646219653742, 0.09195974761886255, 0.13774445440087998, 0.22060784298394406, 0.11735419210578714, 0.0986911067739129, 0.29655199285064426, 0.10613915497171027, 0.10849200229027442, 0.1373360441731555, 0.13542001055819647, 0.16232300123998097, 0.1048066004046372, 0.11628665296094758, 0.09957911233816828, 0.09697157011500426, 0.12947322108915874, 0.18409875061895165, 0.13185363050018037, 0.12526768818497658, 0.08000528373356376, 0.27829188268099514, 0.19963492266833782, 0.2054077900413956, 0.15454556500273092, 0.15295744022088392], [0.07765699617032494, 0.09570460952818394, 0.032022686675190926, 0.02228952761340354, 0.03558157570660114, 0.06584049881036792, 0.04058549326977559, 0.057882443336503844, 0.011878417073083776, 0.04266072477080992, 0.020159489142575433, 0.024320628893162523, 0.04700900447954025, 0.020485014621434466, 0.0441907771330859, 0.03800968952210886, 0.05845055356621742, 0.03936965011858514, 0.06451003413115229, 0.04227575792797974, 0.022364946780726314, 0.05518297997436353, 0.032517837427024326, 0.013245687188048447, 0.03327724364187036, 0.017522983652140414, 0.0780807277187705, 0.05674240951027189, 0.025302048373435224, 0.0814059292897582, 0.0480423590301403, 0.02235616823392255, 0.021054829670382396, 0.030693148196275746, 0.036477353889495134, 0.027325921558908055, 0.05962486019624131, 0.015750466978975704, 0.07815413163708788, 0.0029302384230374756, 0.009200084987761719, 0.030162927362003496, 0.06244641236428704, 0.0424261891416141, 0.010933960787951946, 0.06329612819744007, 0.03493475202204926, 0.0025953756661952604, 0.06241006324333804, 0.028509673396391527, 0.026254653864141022, 0.02481484496300774, 0.04020348144695163, 0.017326272957559143, 0.06608716664569718, 0.0092972249092002, 0.05178533800478492, 0.06728576482938868, 0.006314665711085711, 0.039229461391057284, 0.005979358725848475, 0.028965102708233253, 0.03090555340583835, 0.030970930254885128, 0.05043027303846819, 0.025904253291498338, 0.4402403325906822, 1.4321170960153853, 4.361534510340009, 13.795350398336138, 22.76895669528416, 32.29549108232771, 35.2833936555045, 40.265311104910715, 40.27504205703735, 33.52855314527239, 30.201265811920166, 59.79987267085484, 72.34559563228062, 23.57465069634574, 31.664222921643937, 26.81992323057992, 21.029377903257096, 22.66877235685076, 25.838974816458567, 26.42191651889256, 25.65250253677368, 19.69633994783674, 17.99792402131217, 17.842671734946116, 18.415366581508092, 13.951611042022705, 19.839080265590123, 20.788949387414114, 15.348508153642927, 15.102366481508527, 21.806447063173565, 14.726496730531965, 36.36358840124947, 46.70037133353097, 19.507993391581945, 16.758243799209595, 18.89773484638759, 22.572723933628627, 21.922978775841848, 23.048505306243896, 33.67855085645403, 31.474530151912145, 33.18670524869646, 35.14248766217913, 35.22972576958792, 35.04800605773926, 31.555570466177805, 29.150524480002268, 23.77939326422555, 18.827790805271693, 11.2551862682615, 9.128465141568865, 4.123855744089399, 1.7258594653436115, 0.21341188411627496, 0.008798572916670569, 0.04237799619191459, 0.030616497487894127, 0.016259517520666122, 0.0902946430391499, 0.03339873194428427, 0.06136451541845288, 0.01651068913218166, 0.009347849558772785, 0.02731533471627959, 0.036783559780035696, 0.13598406314849854, 0.06463877936559063, 0.009940357363250638, 0.04062908575204866, 0.034980000129767826, 0.05468019570357033, 0.046334476210176945, 0.05080381674425943, 0.01805202892449285, 0.037460235612733025, 0.061156144099576135, 0.014319838656644737, 0.054493211808481386, 0.04465774832559483, 0.045526028876858096, 0.032022198129977496, 0.04786141748939242, 0.02973687183111906, 0.019402461192969764, 0.010626789681347353, 0.06587578263133764, 0.05365118377708963, 0.06703020818531513, 0.03984044146324907, 0.04644074157944747, 0.026670655202386633, 0.025981065151946883, 0.049497606299285374, 0.00810357409396342, 0.017725229496136308, 0.04956027579360774, 0.04816077696159482, 0.024577266104253273, 0.08652354218065739, 0.06325331942311355, 0.04093263178531613, 0.012209906874756728, 0.05538789076464517, 0.045503688111369095, 0.03911794076806732, 0.050871500612369606, 0.03511537465133837, 0.022118991407166635, 0.0059343391996143115, 0.05045182331066046, 0.036495199360485585, 0.03506967192515731, 0.02415315287985972, 0.03354453215641635, 0.04960585977616055, 0.02855043638763683, 0.004621025341163788, 0.019599081981661062, 0.04749590424554689, 0.03858510418129819, 0.02402334743445473, 0.012622325548103877, 0.016582367875214134, 0.027744391068284, 0.038567553873040845, 0.011888458543190998, 0.032468918444854875, 0.041887961594121795, 0.01838758315092751, 0.011043664633429475, 0.013918300292321613, 0.02478287917827921, 0.05161798752046057, 0.01631938636169902, 0.021196860620485883, 0.041876867546566894, 0.06354616156646184, 0.035137070808559656, 0.02020837759066905, 0.054592138821525235, 0.026582974907276884, 0.010573263446401273, 0.03896947391331196, 0.04585753733824406, 0.0431082966471357, 0.04338340188509651, 0.06393379505191531, 0.05329674083207335, 0.031632783490100076, 0.018674338835158517, 0.04426448639216168, 0.03525893230523382, 0.06951885071716138, 0.01224068013418998, 0.04324511644829597, 0.004745224390977195, 0.026725170402122394, 0.05596580582537821, 0.0389277338316398, 0.033902401703276804, 0.05532335190634642, 0.029662748665681908, 0.044782347711069245, 0.013188885325299842, 0.034558796124266725, 0.0257214067636856, 0.051527776289731264, 0.012917075223023338, 0.043395028582641056, 0.04897952784917184, 0.052523729990103414, 0.04605085875040718, 0.07857763248362712, 0.10133728478103876, 0.29233663475939203, 0.9031276670949799, 3.214135919298444, 9.04232919216156, 21.565801416124614, 30.907908030918666, 40.44553347996303, 43.53934049606323, 46.65687908445086, 43.093346050807405, 33.01202058792114, 28.74909578050886, 65.45758928571428, 64.90970993041992, 17.092879465648107, 25.42248589651925, 22.23507969720023, 16.382985489709036, 19.130860805511475, 27.62685748508998, 34.279038497379844, 28.261003937040055, 28.260220527648926, 22.50285632269723, 24.01343812261309, 24.4840760912214, 21.40877386501857, 25.593126705714635, 25.948113645826066, 23.131690876824514, 21.051914385386876, 26.45302881513323, 20.485332216535294, 36.27144486563546, 49.57348619188581, 21.91068741253444, 17.745721782956803, 21.11297341755458, 16.277220010757446, 18.69925955363682, 17.322064059121267, 28.669033425194876, 24.36273101397923, 29.127591950552805, 34.06146955490112, 33.86661774771554, 36.922546659197124, 36.42353398459298, 33.757051604134695, 31.402341842651367, 24.88257438795907, 17.014060837881907, 13.443222641944885, 7.817110776901245, 3.133627793618611, 0.6487915175301688, 0.08693971484899521, 0.04784976704312222, 0.044664540461131504, 0.021687882486730814, 0.03745491250551172, 0.02109700401446649, 0.06559338314192635, 0.014464448039819087, 0.0071638242973546895, 0.033383607398718596, 0.06681592004107577, 0.046077864444149394, 0.04857441869431308, 0.045601699102137766, 0.01716827947114195, 0.03260829293036035, 0.04666740280975189, 0.05678390531933733, 0.04859174169333918, 0.009488764318770595, 0.0420585486904851, 0.014287472536255206, 0.09757688441979033, 0.05933311049427305, 0.022663751550550972, 0.06364095290856701, 0.03347908406119261, 0.025245319453201125, 0.04838442210374134, 0.0023964769082210425, 0.049370808460350545, 0.0877162099682859, 0.018778751803828136, 0.0757101367094687, 0.004278131486249289, 0.03414299665018916, 0.04583746627239244, 0.03805851350937571, 0.06434433587959834, 0.05521837914628642, 0.04070902396259563, 0.02212385819958789, 0.0409716000514371, 0.035812372607844215, 0.020527233070294772, 0.048166771818484576, 0.042981234179543595, 0.057150080134826045, 0.040934714887823374, 0.04231718249086823, 0.010423645626620522, 0.018323424272239208, 0.0650209438587938, 0.022955009314630712, 0.0605411742414747, 0.10384680583540883, 0.23102241914187158, 0.08983853179961443, 0.11922918792281832, 0.1470029018819332, 0.1560455480856555, 0.1423039925949914, 0.11736656858452729, 0.14582089387944766, 0.12813215090760163, 0.16245166505021708, 0.14173521740095957, 0.0955602987004178, 0.09953509577150856, 0.11535845776753766, 0.09998609085700341, 0.10436425664063011, 0.09224838284509522, 0.23515724869711058, 0.10338279644825629, 0.10448869996305023, 0.13054835982620716, 0.09511326625943184, 0.09670827817171812, 0.1311291858021702, 0.05913991800376347, 0.159036394740854, 0.13247777415173395, 0.08927171078643628, 0.17390947522861616, 0.15258149110845157, 0.1445860279990094, 0.1168440423373665, 0.1484616978892258, 0.08607348347348825, 0.13641650708658354, 0.09520198471312012, 0.27697544332061497, 0.1134262750191348, 0.3027315469724791, 0.13648191786238126, 0.09616713292364563, 0.09329692300941263, 0.14091667346656322, 0.11175232912812914, 0.16918351953583105, 0.08886754818792854, 0.09339256252029113, 0.17842625214585237, 0.08734079689851829, 0.11090141907334328, 0.1492843944579363, 0.12045497500470706, 0.13351878257734434, 0.13220625157867158, 0.17204528168908187, 0.13672967813909054, 0.21564270369708538, 0.15988571702369622, 0.12103167548775673, 0.11867618188261986, 0.1458634923079184, 0.08446995594671794, 0.15547274239361286, 0.19605763176722185, 0.22977595031261444, 0.7894923218658992, 3.308931278330939, 8.92763180392129, 22.075038364955358, 33.77982085091727, 46.29651771272932, 52.90888902119228, 58.18807125091553, 55.0005156653268, 46.07710402352469, 39.07173565455845, 68.75153568812779, 81.59086172921317, 32.392011983054026, 39.86491421290806, 35.64550944737026, 30.75048269544329, 31.010077817099436, 37.95071676799229, 38.260509150368826, 34.04614182880947, 31.561941964285715, 27.2098057610648, 25.98756899152483, 27.805162157331193, 23.761095183236257, 31.02726071221488, 30.555259159633092, 23.80020659310477, 23.820156608309063, 30.73238263811384, 22.541479621614727, 48.93492589678083, 62.347540855407715, 27.805737120764597, 25.410159792218888, 27.834782327924454, 31.037332126072474, 30.214978081839426, 30.902926172528947, 42.35743107114519, 41.63671875, 45.550524371010916, 47.02720764705113, 46.3108275277274, 47.3200672694615, 43.490901129586355, 39.971833092825754, 33.51400361742292, 25.33874099595206, 17.40256241389683, 12.661309719085693, 6.6713932156562805, 2.5647985339164734, 0.5079249878014837, 0.14496359202478612, 0.15011657694620745, 0.08366117613123995, 0.12710524243967875, 0.20885560289025307, 0.04885302856564522, 0.1701261403837374, 0.072606632885124, 0.12738103978335857, 0.08552814487900053, 0.14000246966523783, 0.20018338252391132, 0.1926843627755131, 0.10954212344118527, 0.13068340186561855, 0.10045105697853224, 0.09342127812228032, 0.21847789441900595, 0.14874637047094957, 0.19087044868086064, 0.12196886805551392, 0.11193164557750736, 0.22143906195248875, 0.1626283284276724, 0.08190082559095961, 0.18650214879640512, 0.08653008325823716, 0.12623778970113822, 0.07895246201327868, 0.11182711047253438, 0.07964784505644015, 0.17018121028585093, 0.1453903362687145, 0.24137993050473078, 0.15095650830439158, 0.092302007467619, 0.19494936695056303, 0.13895968347787857, 0.13623153844049998, 0.09026265011302062, 0.09768834736730371, 0.11320498439350299, 0.1631704643368721, 0.08944960231227533, 0.18603432604244777, 0.1391901546823127, 0.15852494218519755, 0.22272331161158426, 0.09781707903104168, 0.12949770263263158, 0.07999746022479874, 0.2537216411105224, 0.19352943742913858, 0.07936169326837574, 0.13540570704000338], [0.0567551049004708, 0.02282274417978312, 0.02626930852420628, 0.06406167176152978, 0.07994548444237028, 0.06757288692252976, 0.03836871257850102, 0.008583997243217059, 0.002267681631825066, 0.05053500831127167, 0.06846739963761397, 0.03638967698706048, 0.02828196552582085, 0.03767188764842493, 0.003672208196283983, 0.01461452302256865, 0.02206176715636892, 0.02715002153334873, 0.006089688943965095, 0.03705258195155433, 0.020519058419657604, 0.05961789164159979, 0.00298326593474485, 0.021509091901992048, 0.03533224122864859, 0.025052785141659633, 0.02857659730528082, 0.00996507384947368, 0.019894210788022195, 0.024777707045099566, 0.015879834769293666, 0.04412444354966283, 0.026911107656945075, 0.07057242561131716, 0.026263858191668987, 0.03389608793492828, 0.04990441179169076, 0.02397749203789447, 0.08825789804437331, 0.0334401327584471, 0.08675451550100531, 0.004892055128168846, 0.04098316228815487, 0.025897461155961667, 0.035917789808341434, 0.016089759933363115, 0.040211634045200687, 0.06745174128030028, 0.04017293380041208, 0.013594079297035933, 0.03702822932973504, 0.01889407561559762, 0.04754332366532513, 0.07339871395379305, 0.021129327726417353, 0.011982143873215785, 0.03840203543326684, 0.04214840369032962, 0.01847582493376519, 0.0694906304457358, 0.07045492370213781, 0.010210962217700268, 0.05090809739860041, 0.04239728354981967, 0.019463015354371498, 0.011141934315674007, 0.03450545648645077, 0.0392998899333179, 0.18326431539441856, 0.33699135003345354, 1.1829711965152194, 5.041479579039982, 14.543784294809614, 27.001992089407786, 34.90047148295811, 42.44574267523629, 43.537978649139404, 43.59312302725655, 53.43401650020054, 42.256202765873496, 36.686558042253765, 44.206756659916465, 29.536920751844132, 30.763844081333705, 29.40753834588187, 21.98805386679513, 19.89298960140773, 20.28585638318743, 21.524475267955236, 21.292914390563965, 23.21141103335789, 23.33766848700387, 21.596524613244192, 21.381562982286724, 28.72076276370457, 28.857859407152446, 22.49514729636056, 24.726828779493058, 57.4316451890128, 71.25522177559989, 24.596086263656616, 27.775330066680908, 30.000827653067454, 29.421844686780656, 33.11125128609793, 40.02725887298584, 40.94509506225586, 40.87298665727888, 35.499468735286165, 33.192753655569895, 28.574982609067643, 18.993498393467494, 14.87732822554452, 8.109391961778913, 3.8702595233917236, 1.9641070067882538, 0.8799656842436109, 0.23633095143096788, 0.07061675430408546, 0.013314256544357963, 0.07119703745203358, 0.07601895835250616, 0.00733451487030834, 0.05311959230207971, 0.0055904339034376395, 0.020515044885022298, 0.04620882848809872, 0.04434771889022418, 0.02527593495324254, 0.04280829595934067, 0.09666638541966677, 0.06017515888171537, 0.13051478591348442, 0.014935873814725449, 0.06940938266260283, 0.037789114750921726, 0.016365616648857082, 0.048014342319220304, 0.028944936647479023, 0.03429828617455704, 0.09215211229664938, 0.061520212063831944, 0.023756622103974223, 0.025390912712152516, 0.026132110439773117, 0.06266400497406721, 0.024540667621684924, 0.033710053988865445, 0.013438807584212294, 0.043273716699332, 0.04063302464783192, 0.01831020980275103, 0.024293557042255998, 0.03145007436562862, 0.032880239587809355, 0.07472968074892249, 0.018229786439665725, 0.05904640230749335, 0.0112596762566162, 0.06789277547172137, 0.03321222641638347, 0.047513746323862245, 0.005582218540699354, 0.0010706975133091743, 0.06225010539804186, 0.006352297263219953, 0.04436190027211394, 0.031224064528942108, 0.008390244961317097, 0.050500202857490094, 0.04435052802520139, 0.016319985168852975, 0.06224216653832367, 0.06504387155707393, 0.015194076745371734, 0.019181078965110437, 0.01574126604412283, 0.022540144522541335, 0.03527627905298557, 0.045237519179603884, 0.029612954373338392, 0.02576547422047172, 0.033299628512135575, 0.012551952984982302, 0.005829659905949873, 0.04534145038841026, 0.060835624512817175, 0.04137207820479359, 0.024276016912023936, 0.023010747573737587, 0.04779248172417283, 0.0371265490539372, 0.0071566411560135225, 0.05220988718792796, 0.0027002404967788607, 0.05221300166366356, 0.06033504208815949, 0.027289557170921137, 0.022897998802363873, 0.03857173704143081, 0.05647313628079636, 0.0060024725971743464, 0.05722278516207423, 0.058308271558157036, 0.008714739915116556, 0.03411053214222193, 0.03574033593758941, 0.00466957749033879, 0.0765835198440722, 0.009795965959451028, 0.032950881868600845, 0.06526353369866099, 0.02826007259344416, 0.04516989637964538, 0.03669714495273573, 0.03051355354753988, 0.059131402389279435, 0.009828941913188567, 0.07331578340381384, 0.01997321770925607, 0.030133197350161414, 0.01884209644049406, 0.031115756769265448, 0.02264723600819707, 0.019818830636462996, 0.0054755210294388235, 0.008334576252049633, 0.0479740339464375, 0.012867665999302906, 0.042808750577803166, 0.01658691405983908, 0.016320717986673117, 0.048255707403378825, 0.010990667655797941, 0.04063517899651613, 0.03959468625751989, 0.037401789998901744, 0.011516692599148622, 0.018976151211453334, 0.08012923851077046, 0.030086771984185492, 0.030742874635117393, 0.016807787386434417, 0.03914948586108429, 0.1902097455625023, 0.9500505349465779, 3.1262755138533453, 9.167838845934186, 20.097527197429113, 35.08012063162667, 43.5933974811009, 48.18648678915841, 45.40591498783657, 48.21888971328735, 64.34981713976178, 40.77027838570731, 36.780841623033794, 39.2066627229963, 25.429385457720073, 29.261914525713237, 29.965447425842285, 24.205283096858434, 20.377506596701487, 19.67089738164629, 17.441911799567087, 14.117648669651576, 18.445504392896378, 17.983921664101736, 22.6583639553615, 19.26452156475612, 21.318548032215663, 16.85384406362261, 18.36542293003627, 16.85113947732108, 55.78987618855068, 75.32422583443778, 18.41366079875401, 18.500714778900146, 21.29466012545994, 25.94962661606925, 30.618668419974192, 36.82175261633736, 42.74548101425171, 43.27887337548392, 42.291086196899414, 38.97482565471104, 35.5125070299421, 26.492737770080566, 21.343855108533585, 13.665234088897705, 6.760565962110247, 4.122981573854174, 2.260777933256967, 0.7204099659408841, 0.241672189107963, 0.05847126924033676, 0.06673725747636386, 0.02397107648929315, 0.04695860968370523, 0.014907709522438901, 0.004664363796889249, 0.03734251317967262, 0.03975680523685046, 0.04271907538973859, 0.03559815910245691, 0.033699689366455586, 0.027557346105043377, 0.04532615960176502, 0.03976604009845427, 0.02251931349746883, 0.03750457109085151, 0.01869007066956588, 0.03598221331568701, 0.013274284046409386, 0.06124342405902488, 0.005241032897694302, 0.037989414895751646, 0.05775584905807461, 0.009867754964424031, 0.01115071031797145, 0.002301846506140594, 0.0687526421887534, 0.04904645515073623, 0.02753548201040498, 0.015752862207591534, 0.023509587859734893, 0.045113411732017994, 0.024646561493032744, 0.014791199970724327, 0.028523820851530348, 0.02711986574078245, 0.01465854637457856, 0.05161157536453434, 0.03287204288478408, 0.04392726466591869, 0.026217305600377064, 0.01689694688788482, 0.022671768441796303, 0.05156086504991565, 0.03442675320963774, 0.04928683635911771, 0.02800061267667583, 0.03685956248747451, 0.013410649229107159, 0.052752094343304634, 0.014950117961104428, 0.05235185706987977, 0.07026000094733068, 0.053441713231482675, 0.031037219733531986, 0.04355057595031602, 0.04080203075760177, 0.1392360372202737, 0.0846170691241111, 0.12283941491373948, 0.1291036502059017, 0.17799569453511918, 0.10859195049852133, 0.10974895448556968, 0.05208594598142164, 0.08165774042052881, 0.12306331789919309, 0.1964613465326173, 0.19338371524853365, 0.09269759338349104, 0.0913241570815444, 0.0901279134143676, 0.11542855043496404, 0.14086434484592505, 0.12446171071912561, 0.08821394933121544, 0.17950493283569813, 0.10087028983980417, 0.14684139697679452, 0.07755676976272038, 0.13325050340167113, 0.13075242244771548, 0.15376763817455086, 0.11653939368469374, 0.10982172736631972, 0.10089048304195915, 0.09384459576436452, 0.1473061391817672, 0.09277448497180428, 0.0918346732588751, 0.1489694049315793, 0.14304147873606, 0.14181855507194996, 0.15189817920327187, 0.18930326348968915, 0.18143913761845656, 0.1761101678545986, 0.14772052051765577, 0.11338822277528898, 0.1590154551501785, 0.20696760634226458, 0.2005958775324481, 0.10753138669367347, 0.10932319411741835, 0.13967726140150002, 0.1247077068047864, 0.09028576101575579, 0.16734737663396768, 0.07836373788969857, 0.07830884440668992, 0.14749711964811596, 0.10181425418704748, 0.15434135310351849, 0.13209300408405916, 0.09351704655481236, 0.12743028785501206, 0.12393447543893542, 0.15204726691756928, 0.09496678411960602, 0.09764266160449811, 0.1860046876328332, 0.16862019976334913, 0.1041284589362996, 0.06976825983396598, 0.07226321274148566, 0.35094919534666197, 0.9777899150337491, 2.942718003477369, 8.83319102014814, 22.415086678096227, 41.230405466897146, 52.82395771571568, 59.04193537575858, 58.25964117050171, 58.27275242124285, 65.4883142198835, 53.75583274023873, 49.70716953277588, 55.6826376914978, 39.91033111299787, 42.998332909175325, 41.53380550657, 33.79770203999111, 29.18670722416469, 28.830561671938213, 29.47087812423706, 29.0760588986533, 33.072744369506836, 31.499745164598735, 32.677513463156565, 29.339661393846782, 39.38699974332537, 38.58835295268467, 30.510109765189036, 33.78215544564383, 66.36214051927838, 80.05260004316057, 33.53276375361851, 36.45331048965454, 38.468166487557546, 38.77543319974627, 45.15656845910208, 49.23718990598406, 53.51695367268154, 53.96569613048008, 49.52629402705601, 44.74036094120571, 38.30808694022042, 27.8761362688882, 21.134577104023524, 11.60259359223502, 5.645631526197706, 2.8852774628571103, 1.9165485416139876, 0.4131508262029716, 0.2374129162303039, 0.11996333567159516, 0.19557498980845722, 0.12342881757233824, 0.0974010895671589, 0.15806819312274456, 0.07411477195897273, 0.09212005151701824, 0.14802417850920133, 0.15317622705229691, 0.13495222851634026, 0.15857761007334503, 0.2268369844449418, 0.160480724381549, 0.26671127123492105, 0.08239625793482576, 0.19524674170783587, 0.08609815500676632, 0.09292644967458077, 0.09941265412739345, 0.09077137495790209, 0.13943706000489847, 0.15368681108312948, 0.1006309094705752, 0.08029341684388262, 0.0805357624111431, 0.13653356794800076, 0.18687945497887476, 0.13890711058463368, 0.11868435144424438, 0.08568256587854453, 0.14405667568956101, 0.12272360255675656, 0.13644195214978286, 0.09722913522273302, 0.10145254073930637, 0.11908512136765889, 0.13085801606731756, 0.10634618957660028, 0.17794274166226387, 0.0913451916671225, 0.1573870661003249, 0.11399620372269835, 0.19698970818093844, 0.07296443797115769, 0.10578027780034713, 0.11136071942746639, 0.06610935474080698, 0.11010771630597965, 0.13709976470896176, 0.16592949628829956, 0.16434986676488603, 0.10462071573627846, 0.16967270257217543, 0.13429793076855795, 0.19426145457795688, 0.14710272795387677, 0.08662069482462746], [0.021537006832659245, 0.04129139021305101, 0.01167790827873562, 0.06666266612176384, 0.038288058513509374, 0.025918217542182122, 0.059130201382296424, 0.02336335677786597, 0.06815981971366064, 0.09829113073647022, 0.020626847100045, 0.06338688904153449, 0.05299760866910219, 0.03771567690585341, 0.0367593598285956, 0.021443326591647098, 0.008980561945853489, 0.012328545330092311, 0.044230993903641186, 0.033164091142160554, 0.030950981325336864, 0.120927113241383, 0.021961589942553213, 0.026750752868662988, 0.004978972071382616, 0.0876890482114894, 0.042977193503507545, 0.0073396395060366815, 0.06467953896416084, 0.04425225919112563, 0.008443648211791046, 0.042180549286838086, 0.056455314558531554, 0.04979624991704311, 0.026780886608841162, 0.045915253526930294, 0.05301099277234503, 0.04404172673821449, 0.023744600159781318, 0.025667149407256926, 0.06644220330885478, 0.009718869962463421, 0.030473458913287947, 0.049596818297037056, 0.016166429301457744, 0.0682675303625209, 0.06851700733282737, 0.01395026353254382, 0.03135160197104726, 0.019690394135458127, 0.02701343921944499, 0.04291424920250263, 0.05821455230138131, 0.0210617320678596, 0.14003027603030205, 0.04350592495341386, 0.04285816489053624, 0.014764397837487715, 0.06808532335396324, 0.05460653054927077, 0.013529547224087375, 0.016160376769091402, 0.02259110419877938, 0.021448597112404447, 0.053992873656430414, 0.030175622752202407, 0.028018660011834333, 0.031214185059070587, 0.05327488861179777, 0.04244911005454404, 0.052295236715248654, 0.07006120375756707, 0.3905615811901433, 1.9322262832096644, 5.252865927559989, 14.722838503973824, 26.0238333770207, 35.455246925354004, 36.42102221080235, 38.13231488636562, 45.19355024610247, 45.816810607910156, 47.95225954055786, 41.70271968841553, 45.66757025037493, 40.972429275512695, 38.326940877096995, 40.685604163578574, 41.62773820332119, 42.14500379562378, 43.12564822605678, 39.842613969530376, 37.608684744153706, 40.91161516734532, 41.23896564756121, 38.318710735866, 39.19492721557617, 36.01046705245972, 51.77731582096645, 48.252428667885916, 37.1163284437997, 40.195189884730745, 43.88241127559117, 43.48780918121338, 41.27974115099226, 32.47709614889962, 26.814201389040264, 19.631299597876414, 12.207016519137792, 9.394439578056335, 3.904797281537737, 1.4334935992956161, 0.6295979874474662, 0.08757820273084299, 0.06419513281434774, 0.023373843536579182, 0.03332462913489767, 0.04714476576607142, 0.02658281205887241, 0.03576537048710244, 0.029235631227493286, 0.025467383608754193, 0.04672513256913849, 0.058984506343092234, 0.052086424348609786, 0.06901818686830145, 0.007455688502107347, 0.011838229140266776, 0.005417547421529889, 0.010372080357878335, 0.034460059101028104, 0.025758846629677073, 0.017682800701420223, 0.02866154649694051, 0.05002079751076443, 0.020017543009349277, 0.04598617061440434, 0.035096847252654176, 0.04511388670653105, 0.041773940569588115, 0.059784668763833385, 0.07093669713607856, 0.03397789890212672, 0.06803169873143945, 0.011396819210079099, 0.023454472156507627, 0.03765025595203042, 0.07099026069045067, 0.015399221630234803, 0.010975538869388402, 0.010621625181686665, 0.028851743255342756, 0.04567311830552561, 0.052382638811000755, 0.032562834476786, 0.0363290193490684, 0.015480966440268924, 0.044834784897310395, 0.006537827397031444, 0.0588749297229307, 0.05367599441004651, 0.03413651664076107, 0.03823450852983764, 0.10302686411887407, 0.036512915909822495, 0.021925247606954405, 0.03503339405038527, 0.018925710614504557, 0.013968777360527642, 0.048725382557937076, 0.04104618462068694, 0.0030983484424983282, 0.011401780997402966, 0.044293497156883986, 0.01250659631166075, 0.04078808007761836, 0.032719650704945834, 0.050645416136831045, 0.09635362827352115, 0.02601564838550985, 0.01060708163173071, 0.0632646441725748, 0.017041549485708987, 0.03891127935743757, 0.02040410610581083, 0.02489794514674161, 0.04195335540654404, 0.03423457173630595, 0.01804779147330139, 0.06252378571246352, 0.04318683707554426, 0.0476371175609529, 0.03890968819281884, 0.031298160552978516, 0.0667057598807982, 0.016288971029488102, 0.028916068375110626, 0.049348844281796894, 0.049960119516721795, 0.07394722809216805, 0.03032362141779491, 0.09867862851491996, 0.041658925491252115, 0.03691749580736671, 0.0109441125199997, 0.018058894002544026, 0.018784134282863567, 0.02849511882024152, 0.02395263560382383, 0.008404817349011344, 0.04516276836927448, 0.01830514284249927, 0.03336314617523125, 0.04328258515202573, 0.020274282000692825, 0.01875433132850698, 0.05857259487467153, 0.025120784528553486, 0.05337399882929666, 0.047787643769489865, 0.02095869991795293, 0.05026756373367139, 0.06830134854785033, 0.04367215246228235, 0.039974231605551074, 0.031415136597518406, 0.05417816121397274, 0.02891425329393574, 0.0725786229595542, 0.04084892770541566, 0.08942130061664752, 0.009690557240641542, 0.09211175981909037, 0.03347145393490791, 0.14222123846411705, 0.049730669507490735, 0.018992892366700938, 0.05287794901856354, 0.0385871533570545, 0.028530450138662542, 0.0137395589013717, 0.040686164117817364, 0.003168035897293261, 0.03295197091730578, 0.04677123563098056, 0.08718501882893698, 0.060064740878130705, 0.1101733102862324, 1.0455632954835892, 3.7658055169241766, 9.102972200938634, 21.72486478941781, 35.18737302507673, 43.552847794124055, 44.241153717041016, 46.38886622020176, 51.70930685315813, 52.56323003768921, 52.391251700265066, 46.23397350311279, 46.9047977583749, 41.685119901384624, 35.73196588243757, 37.52112007141113, 37.875936780657085, 36.8031279700143, 38.29583726610456, 33.802405970437185, 37.16776248386928, 38.16389792306082, 42.002273900168284, 35.20189823423113, 33.86988340105329, 34.33043779645647, 58.8767489024571, 57.256262234279085, 35.57717044012887, 42.053909437997, 43.939942359924316, 44.71515982491629, 48.972220352717805, 41.277243273598806, 35.128507886614116, 28.494501624788555, 18.867647409439087, 14.623447997229439, 7.360819969858442, 3.581903636455536, 1.5614695378712244, 0.4194811236645494, 0.12947472743690014, 0.010230163910559245, 0.019272555663649524, 0.06181597190776041, 0.09345882146486215, 0.02956625759335501, 0.00921017480348902, 0.03267880628949829, 0.040217394807509015, 0.01956759286778314, 0.051416055498910804, 0.021628792264631817, 0.03353235245283161, 0.05027490208989807, 0.05694845345403467, 0.02307385641948453, 0.032750259419637065, 0.012150635992709016, 0.0179528033560408, 0.01672700439978923, 0.015738080322210277, 0.06588068165417228, 0.0747013519118939, 0.01985217723995447, 0.04464037443644234, 0.03290369315072894, 0.03382651095411607, 0.09991818307233707, 0.041579886339604855, 0.0162262201109635, 0.041650657542049885, 0.06008971096681697, 0.061572086066007614, 0.03202874938558255, 0.04733515251427889, 0.025383905141747425, 0.010498951987496443, 0.13917097928268568, 0.04399504352893148, 0.04431766318157315, 0.07521847023495606, 0.05898077440048967, 0.051140923119549236, 0.023003750181357776, 0.01016141559063856, 0.027978865629328147, 0.05092914216220379, 0.053431854117661715, 0.06660513992288283, 0.038850804923900535, 0.005207632859570107, 0.022134579052882533, 0.042626553747270785, 0.03832324733957648, 0.013992119813337922, 0.05109308300805943, 0.03384961507150105, 0.04332380276173353, 0.05020442944286125, 0.008894773915276995, 0.03780364557834608, 0.059776010656995435, 0.09103768638202123, 0.15302789929722035, 0.19716650726539747, 0.12307965702244214, 0.10666041235838618, 0.09462887368031911, 0.1257034840860537, 0.11126432674271719, 0.09699202794581652, 0.14854902534612588, 0.1373272503593138, 0.1275523155927658, 0.12746447244925158, 0.11292829816894871, 0.16351412875311716, 0.10669701253729207, 0.16512385808995791, 0.12672606350055762, 0.07841458730399609, 0.11348493437149695, 0.10863422323018312, 0.16963925079575606, 0.1005855697606291, 0.16973790978746756, 0.13730147959930555, 0.18783624363797052, 0.11094134407384054, 0.10835550140057292, 0.11188150862497942, 0.09377764471407447, 0.11085083428770304, 0.16924065218440124, 0.16237215431673185, 0.10426292422094516, 0.12553843722811767, 0.13526006628360066, 0.10248758484210287, 0.2887175189597266, 0.15136714412697724, 0.13063168392649718, 0.22994468840105192, 0.04448823670723608, 0.12009583999003683, 0.15473004510360105, 0.08793235051312617, 0.154513293877244, 0.10567398528967585, 0.17625664999442442, 0.1551476562661784, 0.07271377356456858, 0.15013260394334793, 0.18447096778878144, 0.12674810231796332, 0.09300203847565822, 0.2039489397513015, 0.09699744944061552, 0.15526585706642695, 0.0789842310228518, 0.2019307323332344, 0.1223195485238518, 0.08314159472606011, 0.15099483196224484, 0.08747082456414189, 0.08559235464781523, 0.10984670424035617, 0.18647188613457338, 0.1612724254706076, 0.16787024214863777, 0.17475355922111444, 0.13797485775181226, 0.18009672393756254, 0.20431644788810185, 0.8730986384408814, 3.434728196689061, 9.593698280198232, 21.963650056294032, 38.1205689566476, 48.03025654384068, 51.3623103414263, 53.37943492616926, 58.70908887045724, 58.701105390276226, 64.52961567470005, 56.69352763039725, 60.16878032684326, 55.40015867778233, 50.975691727229524, 54.202553272247314, 54.83037860052926, 54.56314393452236, 55.02643244607108, 51.63741731643677, 49.355350971221924, 53.85597365243094, 54.528222288404194, 52.15648249217442, 51.17755079269409, 49.85069499697004, 64.07482828412736, 61.30606147221157, 50.18001529148647, 55.36546632221767, 56.85960347311837, 57.4658476965768, 56.78650842394148, 46.987793990543906, 39.75709554127285, 30.451411383492605, 20.776213339396886, 13.686434779848371, 5.767783897263663, 2.5595163830689023, 1.0398681610822678, 0.3332153026546751, 0.15003082369055065, 0.16132662684789725, 0.20275462312357767, 0.12942432585571492, 0.19192088874323027, 0.12332178545849663, 0.1393092240073851, 0.1211218527917351, 0.24690472547497067, 0.10498265310057572, 0.17216524668037891, 0.10709629646901574, 0.18942606475736412, 0.20878476383430616, 0.16223077476024628, 0.05936907285026141, 0.10239826927759818, 0.25654529673712595, 0.08645167853683233, 0.1085398525797895, 0.1778081745973655, 0.14492479339241982, 0.17278236070913927, 0.11595262374196734, 0.11600402955498014, 0.2325850852898189, 0.09939900878816843, 0.1736980030047042, 0.0951873826395188, 0.1406524655010019, 0.2174380530736276, 0.17308505518095835, 0.12477451536272254, 0.2376415825315884, 0.15909013471433095, 0.08932071458548307, 0.07189496500151497, 0.3159355398799692, 0.10206945120756115, 0.10617359740925686, 0.1269521377980709, 0.11595870341573443, 0.09172883536666632, 0.09726555898253407, 0.055416521549757035, 0.12613349886877195, 0.18031817062624864, 0.12593164827142442, 0.13163245522550174, 0.12362401852650301, 0.14963044731744699, 0.13343981467187405, 0.13984795367079123, 0.08612178838146584, 0.14868057971554144, 0.17823463385658606, 0.10593041045857327, 0.1692785280091422, 0.08199890104255506, 0.0999475975653955, 0.09772586356848478, 0.10058286919125489], [0.047594318964651654, 0.10009888373315334, 0.03478951160130756, 0.03374996881133743, 0.03537456824311188, 0.06587417450334344, 0.04107427257778389, 0.03170475909220321, 0.046796857113284726, 0.03761257350976978, 0.03899111918040684, 0.013915627712516912, 0.057892288879624436, 0.06967926318092005, 0.01476284399229501, 0.009874248544552496, 0.005612359066227717, 0.026561171880790165, 0.03000444533037288, 0.04011379268818668, 0.05712188021945102, 0.0574211005919746, 0.098361528744655, 0.03439276199787855, 0.05277827222432409, 0.0507359530643693, 0.010802381821641964, 0.05574015900492668, 0.06537350386913333, 0.0473130051312702, 0.01688296058481293, 0.04744705990222948, 0.03784020843782595, 0.0495794274445091, 0.019862719977806722, 0.02316060203260609, 0.01093032892926463, 0.014534267596900463, 0.07717581306185041, 0.07419891708663531, 0.07616281456180982, 0.028679700701364448, 0.05890542987201895, 0.024919617555237243, 0.06750920641102962, 0.03934094808729632, 0.0077932452550157905, 0.019035020909671272, 0.025042196602693627, 0.01690364063584379, 0.010865683201700449, 0.045606435276567936, 0.019887327050258006, 0.025076476191835742, 0.04899542253198368, 0.008124414448892432, 0.039902113511094024, 0.03620009430285011, 0.049728331954351494, 0.019535584674615945, 0.021781525408316935, 0.04412724929196494, 0.021215737464704683, 0.06502027210912534, 0.05722548573144844, 0.021447284147143364, 0.07618435126330171, 0.04229640235592212, 0.024742061904232417, 0.012366718013903924, 0.04596945151154484, 0.027010046544351747, 0.05601401573845318, 0.0547547633094447, 0.031202368371720825, 0.04622078427512731, 1.1599588713475635, 4.479261313165937, 8.54614269733429, 11.826731187956673, 14.219162719590322, 18.42577498299735, 19.706251553126744, 25.82343864440918, 27.017745392663137, 35.53677361352103, 35.97733804157802, 37.2654333114624, 40.339966024671284, 39.92505087171282, 32.563292026519775, 41.22736215591431, 41.129173687526155, 43.0473871912275, 43.169470514569966, 44.522118023463655, 40.680670942579, 42.44441556930542, 40.726355348314556, 37.02007852281843, 38.81355449131557, 32.86883905955723, 31.1335403578622, 27.07066113608224, 13.186735102108546, 7.568063889231, 3.09830966591835, 0.8556561629687036, 0.17444587073155812, 0.1286026742309332, 0.055618677487862964, 0.021664635876991918, 0.044891350969140015, 0.03462353854307106, 0.06964712776243687, 0.04773568155776177, 0.04911011191351073, 0.04210726750482406, 0.03308383062747972, 0.016420109796204736, 0.057828079110809734, 0.03958496285070266, 0.024078799012516226, 0.05041996269885983, 0.021520925552717278, 0.05645893454285605, 0.05239063873887062, 0.007980380972315158, 0.008810693248441177, 0.020123552231650268, 0.05793365237436124, 0.034300932461129766, 0.08126009854355029, 0.022085164740149463, 0.011694175307638943, 0.030082914512604475, 0.030775976966002157, 0.013336652440817227, 0.0419420781545341, 0.026911533437669277, 0.02500003413297236, 0.06445999895887715, 0.015291580531213964, 0.02277168272329228, 0.07543140809450831, 0.055394916994763274, 0.03145886478679521, 0.02942531229928136, 0.023430633524964963, 0.01248265929254038, 0.02509065587738795, 0.031051418078797202, 0.010002503537439873, 0.00968669043920402, 0.03630750300362706, 0.0686326025586043, 0.025777083954640796, 0.05604147944333298, 0.01902793870041413, 0.026501211437529752, 0.03596127372501152, 0.09869498799421958, 0.015001640821407949, 0.026436275636245097, 0.04585091144378696, 0.011410321208781429, 0.055171119182237556, 0.03011627807947142, 0.018254018621519208, 0.01748699076207621, 0.03227680482502494, 0.05528798666117447, 0.01951855853466051, 0.04142422701365181, 0.06842046537037406, 0.0929616317152977, 0.02497710134567959, 0.013055904336007578, 0.017419836151280572, 0.03188441141641565, 0.03349198979724731, 0.04205541046602385, 0.040673821565828154, 0.03015009287212576, 0.013693639043984669, 0.08092489545898778, 0.06250168582690613, 0.03823325324005314, 0.023469349036791494, 0.09375481879604713, 0.049124934510993104, 0.033601135547671995, 0.0074361466935702735, 0.03454152401536703, 0.01794201973825693, 0.029109030163713863, 0.029650633422923938, 0.025588622549548745, 0.017446877468111258, 0.054378590280456204, 0.04639425853799496, 0.04327372009200709, 0.027392071937876086, 0.04751254192420414, 0.03359778358467987, 0.05914115293749741, 0.025698251756174222, 0.04244964270453368, 0.01853888458572328, 0.033014392746346335, 0.03314398954223309, 0.018558887798073034, 0.028828208268220936, 0.02463390681493495, 0.05623787122645548, 0.06411976792982646, 0.05251405747341258, 0.03976972454360553, 0.03335581121167966, 0.024339502344706228, 0.027756865934601853, 0.025737827311136892, 0.02184462746871369, 0.043378943910024, 0.03004161887136953, 0.05134790004896266, 0.006424516289761024, 0.035869206701006205, 0.005374415918985116, 0.06158776022493839, 0.0545966748281249, 0.03297087151025023, 0.05937618389725685, 0.025810756254941225, 0.04189466552010604, 0.033039383191083155, 0.03754779716421451, 0.03775481480572905, 0.048833958338946104, 0.04155417325507317, 0.11647102449621473, 0.02062142899792109, 0.013923284132033587, 0.03132209248308625, 0.032579794459577115, 0.0348374874198011, 0.034132560781602345, 0.01294038544542023, 0.05883913021534681, 0.05451703856566122, 0.04872247842805726, 0.32557323415364536, 2.711193386997495, 7.083962917327881, 13.199330449104309, 18.897217205592565, 22.34751718384879, 27.640814679009573, 29.436217035566056, 35.06946904318673, 37.56384801864624, 43.62766252245222, 44.805771282741, 46.00488792146955, 49.55680704116821, 50.31730474744524, 45.521255084446494, 49.89230081013271, 48.25157751355852, 50.08418921061924, 48.7332683290754, 49.04615265982491, 49.615481104169575, 48.82356364386422, 48.45278344835554, 46.3694737979344, 45.93154968534197, 40.71752418790545, 39.70153079714094, 35.84476293836321, 19.47722155707223, 12.619650057383947, 5.576866507530212, 2.2114049025944302, 0.8054062479308673, 0.40437063734446255, 0.07294081138180834, 0.02410296503720539, 0.030932043412966386, 0.02359561083306159, 0.04366345364334328, 0.03787382984799998, 0.05990932921745947, 0.03997806193573134, 0.011505797871255448, 0.04197454605517643, 0.013206103999566818, 0.0964708316272923, 0.021663231309503317, 0.02634953341579863, 0.010005835144381438, 0.031338587669389587, 0.016580613862190927, 0.012819992128892668, 0.033824953716248274, 0.06921764223703317, 0.06419969256967306, 0.018731108467493738, 0.017488117130207162, 0.0113574226187276, 0.04043660572330866, 0.044570987445435355, 0.03438100977135556, 0.019199163619694964, 0.029935991325016533, 0.02523261897398957, 0.03945942708690252, 0.054212165996432304, 0.06318463132317577, 0.007067225083509194, 0.07605124983404364, 0.029056603155497993, 0.03815989003383687, 0.02668713342531451, 0.006037878554447421, 0.02106006456805127, 0.024296215203191553, 0.04698799703536289, 0.03939557354897261, 0.011193473291184221, 0.059496779926121235, 0.06766520161181688, 0.023569853643753698, 0.05935538001358509, 0.010679030940601868, 0.06153700580554349, 0.030583429083760296, 0.026033651615892137, 0.06774239854088851, 0.016701159000928913, 0.054224922454782894, 0.025238130374678543, 0.019906081758173447, 0.06835128872522286, 0.023743190503280078, 0.04512785095721483, 0.05983333329537085, 0.028305001789703965, 0.011517403364580656, 0.03270357281767896, 0.07327541735555444, 0.034040710888803005, 0.1537101933998721, 0.19009556168956415, 0.0728733107181532, 0.08731736708432436, 0.12073149159550667, 0.14701401628553867, 0.1696660936410938, 0.12383916841021606, 0.18483660316893033, 0.17976877439234937, 0.19875707477331161, 0.11763638124934264, 0.11190191217299018, 0.13842848555317946, 0.18183780408331326, 0.20306381796087536, 0.10166414867022208, 0.15843137220612594, 0.06433546064155442, 0.10253035968967847, 0.13494504961584294, 0.1940271971481187, 0.16116466053894588, 0.23516232413905008, 0.13535109854170255, 0.13286394200154714, 0.1009803685758795, 0.14700736664235592, 0.09685368822621447, 0.07955989334732294, 0.08892609897468771, 0.1569768645401512, 0.09255748947284051, 0.12211197109094687, 0.09304794815501996, 0.09303196186998061, 0.07614358487938132, 0.07182700971939734, 0.21286692550139769, 0.1634976810642651, 0.13626828789710999, 0.12749712355434895, 0.15857778649244988, 0.08055317361972161, 0.12877464214605944, 0.17288553874407495, 0.10876271062131439, 0.1406461958374296, 0.10422603905733142, 0.1306230393903596, 0.1291092141930546, 0.11270574546818223, 0.1403185719890254, 0.13519240277154104, 0.1757531227277858, 0.11960002088121005, 0.13193223199674062, 0.12438723471547876, 0.10125328893108027, 0.08036802176918302, 0.10246279117252145, 0.0618948991011296, 0.17016830454979623, 0.06307422010494129, 0.18225187329309328, 0.07691433280706406, 0.16699542051979474, 0.075845938708101, 0.09946670622697898, 0.14655983208545617, 0.23100922842110905, 0.1956077359084572, 0.2065463310905865, 0.15260503627359867, 0.0945390152877995, 0.30834731991801945, 2.5784510927540913, 6.672869273594447, 11.993559173175267, 17.97730871609279, 21.34744906425476, 28.212800809315272, 30.764028208596365, 38.042175906045095, 39.63790266854422, 47.28852244785854, 51.24139084134783, 53.29810973576137, 55.696447236197336, 54.476770877838135, 51.240181854793, 55.520286083221436, 57.32453523363386, 57.173022815159385, 58.92692879268101, 58.693233081272666, 57.482005732400076, 59.093428475516184, 55.67202431815011, 55.7794052532741, 55.20889561516898, 47.69305004392351, 42.82723004477364, 35.70364849908011, 19.028444358280726, 11.209042412894112, 5.119294192109789, 1.7897860407829285, 0.6076490080782345, 0.2614211408155305, 0.1261821769710098, 0.13450689241290092, 0.18433942699006625, 0.09693733802331345, 0.21798804641834327, 0.16584645717271737, 0.22199471427925996, 0.13939812566552842, 0.11434026168925421, 0.18331007579607622, 0.12276951223611832, 0.1700794164623533, 0.11138181508119617, 0.10537517882351365, 0.08943117330116884, 0.1105192613654903, 0.11598649621009827, 0.0812869006767869, 0.08108867345643894, 0.21985917458576815, 0.15160568989813328, 0.0985046046386872, 0.1400697667683874, 0.08982173127255269, 0.18860399244087084, 0.12805014316524777, 0.11713867581316403, 0.14264894622777188, 0.15125332666294916, 0.10355853023273603, 0.10292792014245476, 0.1258763340967042, 0.09493861813098192, 0.11133226845413446, 0.10118774244827883, 0.14017891591148718, 0.09345625660249166, 0.13204078402902397, 0.1112521809658834, 0.08817728808415787, 0.10178760133151497, 0.14107299436415943, 0.13593868272645132, 0.16820835614843027, 0.11908470067594733, 0.20789839353944572, 0.14425727778247424, 0.19126066059938499, 0.09462408322308745, 0.1370531086410795, 0.12436035115803991, 0.13258680115853036, 0.12336508956338678, 0.11986228823661804, 0.13871094611074242, 0.10837300760405404, 0.15044029243290424, 0.09782891946711711, 0.12374519131013326, 0.1584823980395283, 0.15967037715017796, 0.15074726167534078, 0.08882576400148016, 0.2701929701226098, 0.23979587693299564, 0.27822370348232134], [0.022850060303296362, 0.05566746076302869, 0.06364619798426117, 0.03979381253676755, 0.04745312600529619, 0.02755298312487347, 0.03381174603211028, 0.015492143608363611, 0.0350964842364192, 0.047563320092324696, 0.1023262699267694, 0.0721585690709097, 0.06788948457688093, 0.022372185053037744, 0.01109567773528397, 0.06469773048801081, 0.06512618464018617, 0.02957300901679056, 0.006769092063352997, 0.026009103915254985, 0.03586197351770742, 0.03903186181560159, 0.040848503621029, 0.05095200539965715, 0.02539549282352839, 0.0328595374843904, 0.03468936322523015, 0.07403142071728196, 0.03209937131032348, 0.016129815551851476, 0.057047716341912746, 0.07839828889284815, 0.028387720297489847, 0.025570945015975406, 0.02516012259625963, 0.02706726740247437, 0.012511455470563045, 0.025185879785567522, 0.019297658066664423, 0.014342004699366433, 0.019182938151061535, 0.05143436576638903, 0.03393294595714126, 0.014943989093548484, 0.06345012171992234, 0.030162594879844358, 0.03913330280088952, 0.10344064155859606, 0.033970160210239034, 0.03258867648297122, 0.03569735074415803, 0.0630828510703785, 0.037015815531568866, 0.06837483389036995, 0.021660576541242853, 0.025682024591203247, 0.04012285452336073, 0.022243327860321318, 0.028012325887435248, 0.02178588160313666, 0.06731950159051589, 0.07966444880834647, 0.03892998656790171, 0.05028687823297722, 0.04174957776974354, 0.04374028416350484, 0.08330533879676036, 0.04360344400629401, 0.02939603351322668, 0.014585995714047124, 0.01351845741737634, 0.04789707789729748, 0.03756278600277645, 0.09828260833663599, 0.04677742047767554, 0.03599195368587971, 0.041016020346432924, 0.08225244922297341, 0.008129851210729351, 0.20863950305751391, 0.6706422450287002, 0.8042393305471965, 2.4082612650735036, 2.6259242253644124, 3.0723583613123213, 3.7208858472960333, 6.424448592322213, 7.396182826587132, 8.672827465193611, 9.86555176121848, 3.139256485870906, 8.217806441443306, 14.747780799865723, 13.137488876070295, 16.0026376247406, 16.0520566872188, 16.768466336386545, 17.707167966025217, 20.528810569218226, 15.049002579280309, 15.0923958165305, 8.457147564206805, 3.4832109894071306, 1.6141417686428343, 0.3235363805932658, 0.016332741627203565, 0.004072707129775414, 0.03572178818285465, 0.08994048168616635, 0.02035995722482247, 0.03305615996941924, 0.04445809618170772, 0.01134810718109033, 0.08306400424667768, 0.07737542449363641, 0.03753676079213619, 0.039593980581100495, 0.0192007768367018, 0.06910324801823922, 0.0021214885055087507, 0.028342682535627058, 0.011907255659545106, 0.09787401490445648, 0.019230383015902977, 0.06701057816722564, 0.03667615447193384, 0.012705660674587956, 0.07314752707523958, 0.051240935788622925, 0.01720645045861602, 0.04544299993930118, 0.05791873138930116, 0.01673408491270883, 0.016404501794438277, 0.017791836189904382, 0.03493253321253827, 0.06292081012257508, 0.056817234959453344, 0.07999313117137977, 0.02922418773440378, 0.012920744401136679, 0.04132717275725944, 0.031721135534878285, 0.029982572754046748, 0.07276709284633398, 0.04087797918223909, 0.02080519833335919, 0.033330400075231276, 0.0529686861139323, 0.04416176297568849, 0.039668473548122814, 0.0333091551437974, 0.01021247195811676, 0.06431777123361826, 0.014024778551954244, 0.09299028624913522, 0.07512195541390351, 0.012211579463577696, 0.003659640031401068, 0.04807038252641048, 0.0024775149816248032, 0.054428018163889647, 0.02151973981277219, 0.005415734036692551, 0.05188040754624775, 0.01050230479865734, 0.049675541929900646, 0.08579519590628998, 0.011357839917764068, 0.10554289232407298, 0.02974701253697276, 0.022663098460595523, 0.06487261610371725, 0.015891522534989884, 0.030656300352088044, 0.08056170280490603, 0.036463901932750425, 0.02270211252783026, 0.0163342055665063, 0.04691515630111098, 0.0262564468929278, 0.012247935369876879, 0.02059145810614739, 0.06995996633278471, 0.04435718784640942, 0.026707961057711924, 0.04776422752599631, 0.06347984833908932, 0.038450184278190136, 0.05448449941884194, 0.013380259341959442, 0.041237796124603064, 0.012183410082278507, 0.01797410935562636, 0.051976213298205814, 0.04892050548057471, 0.011223544266873171, 0.01140187429596803, 0.01952048557411347, 0.011908841735151197, 0.026323918718844652, 0.023379860445857048, 0.040579369491232295, 0.062287655525973866, 0.04171992578942861, 0.05029574329299586, 0.06212507175015552, 0.060161140348230085, 0.04707653906994632, 0.07158784648137433, 0.019600827512996535, 0.03996636059933475, 0.053249511402100325, 0.017941163087795888, 0.01694330100768379, 0.03937597745763404, 0.040835438429244926, 0.03699326102754899, 0.006640006713236549, 0.041337700228073766, 0.011574105143414011, 0.031903664847569804, 0.03227356142763581, 0.07520326426518814, 0.051626760978251696, 0.02681032824330032, 0.03300424525514245, 0.026583080080204775, 0.008073967066593468, 0.10684736232672419, 0.03410134817074452, 0.029016973317733834, 0.012221365634884154, 0.04185456070782883, 0.04580709504495774, 0.01190839390203889, 0.06222353396671159, 0.023982681134449582, 0.026985429293875183, 0.03142940279628549, 0.011996210752321141, 0.022474669285916855, 0.04631879187322088, 0.10375455899962358, 0.06923451740294695, 0.052836483743573935, 0.04508490986855967, 0.015813109331897328, 0.03946693507688386, 0.09279193689248391, 0.05275542934292129, 0.02772174496203661, 0.07017628329672984, 0.08409286011010408, 0.13595540182931082, 0.8925972378679684, 1.6453541623694556, 2.414800388472421, 4.513416051864624, 4.501577189990452, 5.874355801514216, 7.823955621038165, 11.191702314785548, 13.249101264136177, 14.435656428337097, 16.70283191544669, 6.857046476432255, 14.699155569076538, 22.699966294424875, 19.712960038866314, 24.951813186917985, 24.443675790514263, 24.350568192345754, 26.760300738470896, 27.35758352279663, 21.57349828311375, 20.69818159512111, 13.189179130962916, 6.8656127367700845, 2.886440851858684, 0.8657711116330964, 0.1305283566138574, 0.08369216482554163, 0.0867606426722237, 0.018071345120136226, 0.011724538053385913, 0.027813683064388375, 0.014178280984716756, 0.012662207291993712, 0.10786711225020033, 0.008189083077013493, 0.005205066300862069, 0.03578123802851353, 0.05074814633865442, 0.022486872738227248, 0.07738598928387676, 0.012508550492514457, 0.034940319401877265, 0.05548906033592565, 0.040035689914865155, 0.04586471963141646, 0.04107680690607854, 0.0237325375034873, 0.03965346096083522, 0.02777465881912836, 0.018327156214841774, 0.018038256359951835, 0.07316030388964073, 0.03635663911700249, 0.009516441762181265, 0.02568782097660005, 0.02322988385068519, 0.05539101202573095, 0.027549846596749764, 0.07579255157283374, 0.02434152607539935, 0.011641462466546466, 0.04019392767388906, 0.03510311691622649, 0.04457535381828036, 0.05879559540855033, 0.037742380651512315, 0.0249008119571954, 0.027483323023521473, 0.056172497770083804, 0.017036716620038663, 0.07869866277490344, 0.02548785331392927, 0.010367937901589488, 0.058590548911264966, 0.013212656103340643, 0.06365387900067226, 0.10222617244081837, 0.02075149567930826, 0.015437063528224826, 0.005492131566695336, 0.030801320248948674, 0.03704909088888338, 0.03959011971684439, 0.0453911327224757, 0.036641403300953765, 0.04868022265977093, 0.04655709337177021, 0.0024115779171032564, 0.035238535542573245, 0.054538802576384375, 0.04638345965317317, 0.021061297805447663, 0.03988080411883337, 0.06797853551272835, 0.07161878089287452, 0.08219925207751137, 0.11485932740781989, 0.1268665881029197, 0.12493828657482352, 0.08948111347854137, 0.11942810724888529, 0.1546063753111022, 0.12521150548543247, 0.09581941086798906, 0.1210795800600733, 0.0738015126969133, 0.15450292586215905, 0.16809152598891938, 0.14260063453444413, 0.14283116002167973, 0.13616800042135374, 0.17548230583114283, 0.12459295296243258, 0.16227171756327152, 0.0723112937329071, 0.10474521334150008, 0.12555968894490174, 0.19699436293116637, 0.08463001557226692, 0.1215216727661235, 0.15442158308412346, 0.1648842538041728, 0.13437889356698307, 0.14678604208997317, 0.09679524600505829, 0.10017964975642306, 0.20106809719332627, 0.13342086997415337, 0.15506750770977565, 0.09038995685321943, 0.1431288333343608, 0.09178956425083534, 0.24715860613754817, 0.10142440189208303, 0.10306879758302655, 0.09855683826442276, 0.17734839926872933, 0.1639949522380318, 0.10267634649894067, 0.0980543830831136, 0.19649120207343782, 0.10237705827291523, 0.11697654665580817, 0.24838813873273985, 0.09082830404596669, 0.09578411347631897, 0.09258015254246336, 0.24684992698686464, 0.10600646066346339, 0.1451963023947818, 0.12891851871141366, 0.12338486207383019, 0.09590956781591688, 0.16770594167922223, 0.14161712516631397, 0.09033489373645612, 0.1628718003630638, 0.14675829000771046, 0.14558895703937325, 0.14773403693522724, 0.05753700115850993, 0.11035675222852401, 0.21377788590533392, 0.18789933382400445, 0.1267934013158083, 0.10118371873561825, 0.1420743084911789, 0.12007224054208823, 0.13738759926387242, 0.30402868879692896, 0.1587508807757071, 0.17745743984622614, 0.11701108408825737, 0.18942748968090328, 0.16611523846430437, 0.5763620297823633, 1.1575427438531602, 1.6442047783306666, 3.332973348242896, 3.516900415931429, 5.007312246731349, 6.04490020445415, 9.59420723574502, 11.57226036276136, 12.811585358210973, 16.319152389253887, 6.870139053889683, 13.862640227590289, 21.89539095333644, 18.940089327948435, 22.00694601876395, 22.16882167543684, 26.368311166763306, 26.90311574935913, 28.807941811425344, 22.591517073767527, 19.483044147491455, 12.407478128160749, 5.7534098114286145, 2.1341637330395833, 0.5606927020209176, 0.12536309020859854, 0.10973338889224188, 0.20035137422382832, 0.131953022309712, 0.09673948399722576, 0.09517267200031451, 0.14427449900124753, 0.08997393346258573, 0.21037767907338484, 0.08023844872202192, 0.08145850896835327, 0.07442292185234171, 0.19027825045798505, 0.19061156042984553, 0.17565465372587952, 0.14758834189602307, 0.13074159302881785, 0.23091871184962137, 0.11954941573951926, 0.18389190600386687, 0.14305316310908112, 0.09007402416318655, 0.14640817950878823, 0.18754797482064792, 0.10771334264427423, 0.17208094548966202, 0.14433259516954422, 0.09983654852424349, 0.16534352701689514, 0.13675382041505404, 0.16095909156969615, 0.1447509527206421, 0.1507168904479061, 0.1439440388764654, 0.13044153127287114, 0.04756548801170928, 0.14682637421148165, 0.11647593708974974, 0.13740054571202823, 0.20446189865469933, 0.14094091073742934, 0.08556222090763704, 0.12371616358203547, 0.13437505305877753, 0.0892609085089394, 0.10517536383122206, 0.10118326411715575, 0.08454383483954839, 0.16784805405352796, 0.10882433517170803, 0.11984540628535406, 0.21105282141694, 0.07156508163149868, 0.0950377792386072, 0.13677796269101755, 0.10919965324657303, 0.10662100304450307, 0.18464571769748414, 0.11524602451494761, 0.18278756311961583, 0.12411117952849184, 0.10944599538509335, 0.16299023186521872, 0.061520117068929334, 0.18773530476859637, 0.10466982131557805, 0.1533055558268513, 0.14144168315189226, 0.17969273775815964, 0.10871608169483286, 0.18849047353225096], [0.014334769819730094, 0.030337229437593902, 0.012452559479113137, 0.050170936954340765, 0.05519385349803737, 0.013587956366661404, 0.013136789951074337, 0.032447164612157006, 0.030533305701932738, 0.05424107498090182, 0.024851831906874264, 0.020609049126505852, 0.03788814015154328, 0.05416823085397482, 0.05849779995956591, 0.032972096265958886, 0.034696352135922225, 0.04654937842860818, 0.06488234629588467, 0.025920684016974907, 0.030972348393074105, 0.06073092655943973, 0.05722653067537716, 0.01557992398738861, 0.019070041798321263, 0.04524206875690392, 0.047472549070205004, 0.02285998727061919, 0.05387575172686151, 0.07964458808835063, 0.053543483306254656, 0.014353441407105752, 0.012034240943778838, 0.05756210016884974, 0.07175159055207457, 0.059685371949204376, 0.036143721613500795, 0.06520507790680442, 0.002012597841842632, 0.006952844859500016, 0.05706976194466863, 0.10798485164663621, 0.03295907857162612, 0.021362146662016, 0.02589938141006444, 0.04212714858087046, 0.009096652502194047, 0.021943089685269764, 0.03581190102600625, 0.03238539756940944, 0.04133346277688231, 0.022534105560875366, 0.016868814826011658, 0.01722854864783585, 0.022031862421759536, 0.05124135987300958, 0.05064858489536813, 0.027895395644009113, 0.09341097117534705, 0.038662307895720005, 0.030313246617359773, 0.07191475108265877, 0.11319959682545491, 0.05727598230753626, 0.08048692146050078, 0.05550774379766413, 0.015635828487575054, 0.012477245431260338, 0.019794493281681622, 0.033616626502147744, 0.07979443576186895, 0.06427034163581473, 0.039838582277297974, 0.01863019334684525, 0.1136097169614264, 0.026730237362374152, 0.03445300572950925, 0.04736470610701612, 0.07035519941044704, 0.014934135068740164, 0.07201034988143615, 0.025443137856200337, 0.025220172945410013, 0.02141968982427248, 0.027093886331255947, 0.07158321208719697, 0.09692997591836111, 0.16235850219215664, 0.06805043986865453, 0.09353465453854629, 0.16407132813973085, 0.12655416343893322, 0.19025691731699876, 0.16893820198518888, 0.288432561393295, 0.5484677808625358, 0.8007180594972202, 0.7374826669692993, 0.3540104739367962, 0.15251393616199493, 0.3419787181275231, 0.024567530823073218, 0.036720347457698414, 0.02887565822207502, 0.010692013860014933, 0.04150918638333678, 0.0412453108999346, 0.03107096328000937, 0.04426615898098264, 0.028791675942816904, 0.053865383711776564, 0.020730800361239483, 0.06205697397568396, 0.008366422444981123, 0.0044859366524698475, 0.020579210549060787, 0.006092844131801809, 0.02946823642456106, 0.008367826164300953, 0.024140208128041456, 0.023294656803565364, 0.016079619227509414, 0.030226339852171283, 0.02369907554904265, 0.038354249604578526, 0.06086100172251463, 0.025527338963001966, 0.012595521718529719, 0.009460614445353193, 0.012340907389963312, 0.026954477918999534, 0.03373376200241702, 0.0520416851421552, 0.07346062348889452, 0.07413574547639915, 0.027108471441481794, 0.06244806120438235, 0.03253097725766046, 0.026266570635406033, 0.013873457609276687, 0.016999931540340185, 0.014787780154230339, 0.02938918030953833, 0.040559518949261734, 0.006454987177026591, 0.016910458216443658, 0.0037371579923533966, 0.016048995245780264, 0.04878125313137259, 0.06633092356579644, 0.0678148932222809, 0.017139663953068, 0.03242112243814128, 0.0024330847206458983, 0.024487538329724754, 0.029708264794732844, 0.039155813200133185, 0.03707044438592025, 0.05524532716455204, 0.03498627318601523, 0.022909907091941153, 0.03211002770279135, 0.016411020819629942, 0.013856051489710808, 0.038922600714223723, 0.026251956687441895, 0.022340134451431886, 0.06544954728867326, 0.044951143474983316, 0.03161971490564091, 0.0338040548376739, 0.029801369977316687, 0.017184331913345625, 0.051307869875537496, 0.026127616841612116, 0.019079498880143677, 0.024103365372866392, 0.009264418589217322, 0.045549489225127866, 0.02502262426008071, 0.028553045354783535, 0.0269175707029977, 0.04901209074471678, 0.026079868332349827, 0.0750752722046205, 0.020651464350521564, 0.019942887193922485, 0.024223964794405868, 0.02022700846594359, 0.04028959771884339, 0.01848869165405631, 0.036273908734853776, 0.029446112790278027, 0.10930596611329488, 0.031826406850346496, 0.02329377131536603, 0.034714536874422004, 0.03371351451746055, 0.024762143148109317, 0.017473521841956035, 0.03781705343031457, 0.016108188944469606, 0.03683753384809409, 0.033431929270071645, 0.01911302699175264, 0.03164639150989907, 0.06038049714905875, 0.05387006899608033, 0.024992341242198433, 0.06825022771954536, 0.04041377641260624, 0.01558775597784136, 0.030742810174290622, 0.006409890467434057, 0.021925354476219842, 0.033489957584866455, 0.010730634376938854, 0.049236560306910954, 0.01950292508783085, 0.014806443259918263, 0.07966335636696645, 0.01662233698048762, 0.042674895974674394, 0.04878360086253711, 0.03483574019212808, 0.03880081385640161, 0.027436112253261462, 0.03372456785291433, 0.0025424855578291628, 0.0040659518895803815, 0.01779577338935009, 0.028800937945821455, 0.053397041878529956, 0.05773142858275345, 0.0036044000714485136, 0.05229334020987153, 0.027832388578514968, 0.03282401956883924, 0.016157694859430194, 0.04059369336547596, 0.04845059283875993, 0.013974002928340008, 0.08435117839170353, 0.02126442744130535, 0.01851328176313213, 0.021536538643496375, 0.03516332332843116, 0.029818591196089983, 0.05766054881470544, 0.011903703528722482, 0.02749191497319511, 0.07682156349931445, 0.07171627280435391, 0.046150033428732834, 0.05405903760609882, 0.031596546327429156, 0.03530514732535396, 0.002635907743492031, 0.04815628845244646, 0.07163107594741241, 0.032796993519046476, 0.12342376927179949, 0.2590422241815499, 0.2631706212248121, 0.19641270914248057, 0.5347463371498244, 0.42548854702285355, 0.3457453745816435, 0.7629301728946822, 0.6865842895848411, 1.0980971051113946, 1.3947950644152505, 1.6919875400406974, 1.8564357672418867, 0.9962063325302941, 0.7108060898525375, 0.4506530767040593, 0.06862872133829764, 0.006456160194440079, 0.006977047355446432, 0.03753964117329035, 0.03531872481107712, 0.08105288073420525, 0.01953943196817168, 0.04648822885272758, 0.031891376578382084, 0.04080093492354665, 0.033184274166290245, 0.0854195657053164, 0.039062351786664555, 0.025744273393814052, 0.058587570142533095, 0.02428289216810039, 0.047853346315345595, 0.008887899507369314, 0.00860063492187432, 0.020982548727520874, 0.023672241185392653, 0.027263160462358167, 0.036372815391847065, 0.065449174094413, 0.00771776247503502, 0.014721097125272666, 0.015853504217895012, 0.023908496900860752, 0.011167693201319447, 0.02175732545687684, 0.023248898098245263, 0.023487616895831058, 0.04154959314369729, 0.13620309425251825, 0.06381758235927139, 0.030827677941748073, 0.0337256874356951, 0.02844591485336423, 0.07226541798029627, 0.039402375862534554, 0.028391944177980934, 0.04786790767684579, 0.06515103937791926, 0.035169918688812425, 0.02822920773178339, 0.0497788319231144, 0.028994968427079063, 0.07638599830014364, 0.05240850117323654, 0.047897437520857365, 0.01260038257376956, 0.04955433521951948, 0.017224901522110616, 0.024871685841519917, 0.018556774161489945, 0.01307404921057501, 0.05249635110210095, 0.017689526679792573, 0.06354429559516055, 0.03392035234719515, 0.025264793408236334, 0.0315962749134217, 0.008149618632160127, 0.010098355090511697, 0.03708569446046438, 0.03517609675015722, 0.1386276220104524, 0.022281166365636245, 0.01835285742501063, 0.013131406623870134, 0.06927814041929585, 0.017654286963599067, 0.03900316317698785, 0.04744145520297544, 0.023082388997344033, 0.18487525252359255, 0.06526685173490218, 0.10408907676381723, 0.10274970970515694, 0.15268918818661145, 0.08303624537906476, 0.14147932827472687, 0.10074149710791451, 0.1750455599810396, 0.12279795642410006, 0.10869556958121912, 0.07938612052904707, 0.11309401677655322, 0.11684910420860563, 0.1084433649001377, 0.13998104152934893, 0.1591898522206715, 0.19889894287501061, 0.14902475981840066, 0.07851967202233416, 0.15839074152920926, 0.1657858504248517, 0.22842186582939966, 0.12456547229417733, 0.16177257363285336, 0.09518756584397384, 0.12037916907242366, 0.07397445091711623, 0.12533638307026454, 0.11022360330181462, 0.13524186797440052, 0.1316316681248801, 0.08195149858615228, 0.14342229972992623, 0.16123571672609874, 0.10521807082529579, 0.08995654939540795, 0.12804795828248772, 0.12060140286173139, 0.11256929207593203, 0.1490433109658105, 0.16962265382919992, 0.12480724789202213, 0.13603362334626062, 0.14800584449299745, 0.07251684234610625, 0.13699142980788434, 0.09001850642796073, 0.18137379469616072, 0.15449428132602147, 0.15499459233667168, 0.09867792283850056, 0.054257325894598446, 0.08967134755636964, 0.06994609029165336, 0.11269618490976946, 0.2645605323570115, 0.15563816923115933, 0.11506002449563571, 0.13535481691360474, 0.15330387306000504, 0.11217416077852249, 0.1643289000328098, 0.1449558702962739, 0.20691444990890367, 0.11287407643560853, 0.19618822261691093, 0.11729811797184603, 0.08876432944089174, 0.2052206772246531, 0.1478914434888533, 0.12880233994552068, 0.16752200440636703, 0.11739711623106684, 0.20717149254466805, 0.16994959914258548, 0.28569757672292845, 0.09579236446214573, 0.22998854890465736, 0.12689238600432873, 0.13175563647278718, 0.18133541675550596, 0.10873437499893562, 0.10112594826413052, 0.10288664485727038, 0.20613294041582517, 0.2442898415029049, 0.24778158270886966, 0.2725820376404694, 0.3768727885825293, 0.30873071934495655, 0.32313392790300505, 0.40451646809067043, 0.44479208120277947, 0.7829018469367708, 1.0565026913370406, 1.142916894384793, 1.6338111417634147, 0.9429338425397873, 0.5459551385470799, 0.3883151417332036, 0.10570865842912879, 0.1077649180910417, 0.1538428334253175, 0.14168246808860982, 0.12438308208116464, 0.10326327929007155, 0.1566463229911668, 0.19730769683207783, 0.10730961430817842, 0.19289054242627962, 0.09664992416011435, 0.1631276894892965, 0.1165455412119627, 0.11393330352646963, 0.12887112982571125, 0.16259776721043245, 0.19148463143834046, 0.12695114713694367, 0.08853554100330387, 0.09612551158560173, 0.08545955855931554, 0.12095529958605766, 0.08442816497491938, 0.11524077265390328, 0.14022334638450826, 0.064567003931318, 0.09051295489604984, 0.07102012301662139, 0.07884354357208524, 0.17626339463250978, 0.06176723952272108, 0.09217450395226479, 0.14268839625375612, 0.17443871897246155, 0.24510625483734266, 0.1192019379564694, 0.12792274143014634, 0.10549256538173982, 0.15459937282970973, 0.07063322913433824, 0.12541753585849488, 0.14272141376776354, 0.12324235614921365, 0.08962638104068381, 0.17782076820731163, 0.1352989056280681, 0.06619310631815876, 0.12338459065982274, 0.12274934617536408, 0.1572281124868563, 0.20484258394156182, 0.15926037915050983, 0.07276500295847654, 0.15767571489725793, 0.22286322553242954, 0.06050553758229528, 0.16875250052128518, 0.1705567929893732, 0.16580825565116747, 0.24026447321687425, 0.12336236185261182, 0.13299067877233028, 0.08325645713401691, 0.11851037506546293, 0.080816146651549, 0.14669107432876313, 0.1658596478934799, 0.07596929637449128, 0.09001909675342695, 0.20888862040426048, 0.2364739051886967, 0.0874611215133752, 0.10032579941408974, 0.13548417282955988, 0.14082376845180988], [0.0634996887030346, 0.016768208438796655, 0.04190752715138452, 0.023979027223374163, 0.012266212558772947, 0.06195696469928537, 0.026224291118394052, 0.02330209863638239, 0.038018391733723025, 0.034662605196769745, 0.031090033506708484, 0.11066385039261409, 0.023944947802062546, 0.02406562355879162, 0.031619596162012646, 0.06274639948138169, 0.07074315859270947, 0.01665792614221573, 0.03781209673200335, 0.011736133368685842, 0.026494046107732823, 0.02606201946868428, 0.02089530269482306, 0.006367224185461444, 0.019393881117658954, 0.033291899998273165, 0.03845085942053369, 0.025175320084339807, 0.023382413433864713, 0.08274124549435717, 0.029051039168345075, 0.018140757556206415, 0.04744405059942177, 0.06339186948857137, 0.013747580033460898, 0.010383093829399772, 0.04441256648195641, 0.03866392620173948, 0.03357228763135416, 0.08729467687330075, 0.0393640963094575, 0.06889038479753903, 0.010863837586449725, 0.03605979361704417, 0.027798331209591458, 0.0900667163410357, 0.02829951074506555, 0.05652689661032387, 0.09964994460876499, 0.09733675766204085, 0.010488676422807788, 0.07828752483640398, 0.013258255352931363, 0.06464738997497729, 0.026499526974345957, 0.048896987456828356, 0.034571291346635134, 0.021192268634747182, 0.059738799796572754, 0.03677696441965444, 0.009374292916618288, 0.01946423841374261, 0.02168646943755448, 0.020213948363172154, 0.04680594948253461, 0.03399720661608236, 0.03505986709413784, 0.04114207858219743, 0.053935595122831206, 0.02700609407786812, 0.06507684157363006, 0.06305520076836858, 0.04959362918244941, 0.020885630178132226, 0.03254364889913371, 0.021688298089429736, 0.02123830553942493, 0.022562493769718066, 0.08016628652278866, 0.03924170894814389, 0.024042236153036356, 0.0352452869660088, 0.009899984529641057, 0.0441075887397996, 0.015282618779955166, 0.10852752359850065, 0.06876847241073847, 0.06110681460372039, 0.07803798001259565, 0.04160324151494673, 0.08606145304760762, 0.0384475413842925, 0.06183310491698129, 0.024231628847441504, 0.01768473452622337, 0.02446663605847529, 0.10226811269032103, 0.09039769893778221, 0.018586750142276287, 0.03302031974973423, 0.04574641365824001, 0.02033572504296899, 0.033937278403235335, 0.006058165055167462, 0.03032036784238049, 0.04009698876844985, 0.010511453147046268, 0.06036879241998706, 0.03274862075756703, 0.018957815498911908, 0.08187517018190452, 0.024720296197171723, 0.02966848567926458, 0.100783322006464, 0.026622630190104246, 0.03964166123686092, 0.014707541691937616, 0.06081878327365432, 0.0844873467992459, 0.09031357416617018, 0.011986096339699413, 0.0784395302512816, 0.13417517021298409, 0.039800031310213466, 0.035526973993650506, 0.08758684726698057, 0.05584944724770529, 0.02656724307286952, 0.021538618353328536, 0.06910436760102, 0.01566913946797805, 0.04575205906959517, 0.07436849655849592, 0.060698906491909704, 0.010691529555645372, 0.03613813387762223, 0.0369735258365316, 0.035018089693039656, 0.023264283879793117, 0.014732211528878127, 0.029441044133688723, 0.03831270629806178, 0.023036869475618005, 0.016255846646215235, 0.02687326236627996, 0.012053486741414028, 0.04410131907622729, 0.06984975188970566, 0.027732233417087367, 0.06880623966987644, 0.0423340135520058, 0.06665282057864325, 0.043598453381231854, 0.04170783429539629, 0.041397767540599616, 0.08508947198944432, 0.027234382095879743, 0.04551436485988753, 0.02640688998092498, 0.020383992631520544, 0.023680660108636533, 0.06648475423987422, 0.03733469645625778, 0.051895905286073685, 0.02179146764267768, 0.06453314503388745, 0.034872842486947775, 0.05882073513099125, 0.01733006936098848, 0.05989393325788634, 0.05822434356170041, 0.013919018691272607, 0.014869860839098692, 0.05425545313794698, 0.027199334065829004, 0.03679504059255123, 0.06818831139909369, 0.03106340439990163, 0.04245105066469737, 0.0573409248941711, 0.028962571772613695, 0.04280756992687072, 0.025646652560681105, 0.03532303011577044, 0.020974038202049475, 0.02184834923329098, 0.049512785127652545, 0.03993261705285736, 0.01655573028671954, 0.02133762779911714, 0.09650982703481402, 0.010823653894476593, 0.03081488755664655, 0.04125234730807798, 0.06813121946262461, 0.031866453987147124, 0.03005625826439687, 0.03660230950585433, 0.025301972038245628, 0.006918555092332619, 0.01225026953034103, 0.035966135428420136, 0.04244249773078731, 0.0474900722370616, 0.030800370299922566, 0.06102724280208349, 0.040759500182632885, 0.014510308525391986, 0.04277653373511774, 0.0055150414534312275, 0.045012618747672865, 0.04046009660565427, 0.034788531118205616, 0.023068862401747277, 0.02070754357347531, 0.025554051190348606, 0.04853451744254146, 0.03779516049793788, 0.016976873224068965, 0.032040813738214116, 0.035319990278886895, 0.13110657701534884, 0.022323983621650507, 0.0673054898423808, 0.022180281779063598, 0.046251484592046054, 0.03409567561798862, 0.06864119959729058, 0.018695541358153735, 0.019187716733930365, 0.014485424949920602, 0.046344169082918336, 0.054793989418872764, 0.028180984248008047, 0.01809111763057964, 0.037821667468441386, 0.025803821627050638, 0.0631128219621522, 0.005215520829161895, 0.05990145821124315, 0.03135084201182638, 0.015834702012528266, 0.08774913248739072, 0.017828728138868297, 0.0336669025543545, 0.06587806929435049, 0.03693109364914043, 0.0134450297503333, 0.10829034846808229, 0.030143334663340023, 0.03370267492053764, 0.020766576120097722, 0.02424374917921211, 0.01987519145144948, 0.018803989913846766, 0.06746595658894096, 0.044399436829345565, 0.024447231653279493, 0.05133239891646164, 0.05413999022649867, 0.028723615487771373, 0.007591342071204313, 0.024985135200300386, 0.023476553382351995, 0.019741431843223314, 0.038880063353904655, 0.03129188410405602, 0.04805564474580543, 0.014116021155911897, 0.042970442080071995, 0.05518584339214223, 0.035432983322867324, 0.03131727149177875, 0.07734906340816192, 0.027183008513280323, 0.021560039703867266, 0.031208122348678962, 0.04615442694297858, 0.02667962373899562, 0.046897890977561474, 0.04168632812798023, 0.02103375267636563, 0.022934851735564213, 0.04202483228540846, 0.018540297634899616, 0.03713356510603002, 0.023107664426788688, 0.013712459060895656, 0.01769506691821984, 0.05323384402851973, 0.021287277108058333, 0.03121861250006727, 0.02164273615926504, 0.03259368746408394, 0.03220631521461265, 0.06809626133846385, 0.013100831835929836, 0.04714153593938265, 0.04618577865351524, 0.020478778884613087, 0.027860076199950914, 0.038878587540239096, 0.01857740162605686, 0.043277750590017865, 0.0336746819583433, 0.023440211046753184, 0.047950553242117167, 0.007731240725011698, 0.02737775315264506, 0.026803763416994895, 0.00812059429673744, 0.06455915328115225, 0.0425626391411892, 0.015133285096713474, 0.014684547836493169, 0.031103974008666616, 0.015284583138834153, 0.01393046133619334, 0.0440592431197209, 0.023561838448845913, 0.02570191414893738, 0.049682910820203166, 0.017675162093447785, 0.07633675022849015, 0.01862905001533883, 0.040508035104721785, 0.040840571546661, 0.06246017983981541, 0.05088337158252086, 0.054256277557994635, 0.03392903081008366, 0.0744629961305431, 0.04608585758666907, 0.05065415566787124, 0.03300242678129247, 0.031578358196254284, 0.02906467772221991, 0.08067652450076171, 0.03169060145903911, 0.035663200076669455, 0.025392424148906554, 0.0687191022027816, 0.07425268420151301, 0.057286044981862815, 0.04816356574052146, 0.02951054647564888, 0.07837783784738608, 0.015463989494102342, 0.032023846970072815, 0.06560198696596281, 0.04371983311804278, 0.0479019904908325, 0.17974655915583881, 0.10003083345613309, 0.101182836640094, 0.06533770436154944, 0.05120225589988487, 0.1674266702362469, 0.0869211433455348, 0.15628592590136187, 0.1498350663376706, 0.1472236971770014, 0.16830478954528058, 0.22775880140917643, 0.07436262044523444, 0.0902676305600575, 0.19324328564107418, 0.12159058478261743, 0.1657559270305293, 0.15949078250144208, 0.12405864734734807, 0.12814608801688465, 0.10486180601375443, 0.10282250972730772, 0.08724677908633437, 0.14747797138988972, 0.0729828534115638, 0.11826399900019169, 0.17403423067714485, 0.1014272720952119, 0.24046035270605767, 0.2870765227292265, 0.14315312488802842, 0.10063169657119683, 0.10478705181074993, 0.085216446247484, 0.12472281099430152, 0.06639779319188424, 0.14671623440725462, 0.10362121329775878, 0.10038510337471962, 0.2118759522480624, 0.15055064936833723, 0.24415611582142965, 0.17300527303346566, 0.149614474603108, 0.10341383264000927, 0.2667451708444527, 0.11517171135970525, 0.18165591598621436, 0.21788678185216018, 0.1996929102710315, 0.09228064039988176, 0.12947764513748033, 0.10969737903880221, 0.1444772316941193, 0.10330154866512332, 0.1281950103917292, 0.08801581032041993, 0.0849431459126728, 0.1316126420029572, 0.13316431588360242, 0.10551593412778207, 0.263314850628376, 0.1034712977707386, 0.11396311835518905, 0.16242924625320093, 0.17414838740868227, 0.15964706268693718, 0.10731091709541422, 0.13574249111115932, 0.15923262706824712, 0.1400442538516862, 0.14293611581836427, 0.18544466554054193, 0.1476625329149621, 0.18072827719151974, 0.10146551432886294, 0.1565848205770765, 0.10673702574734177, 0.14776170759328774, 0.15219385762299809, 0.14552892026092323, 0.09675928364906992, 0.11754791385361127, 0.13214583482061112, 0.10172575964991536, 0.26087310165166855, 0.19881422099258217, 0.09836774412542582, 0.14552858099341393, 0.10132469117109265, 0.209086467644998, 0.12495674272733075, 0.18331972456404141, 0.15216743546937192, 0.1602697271321501, 0.11230099932955843, 0.2228530610778502, 0.12741301235343727, 0.09556530628885541, 0.07910811116120645, 0.13868978938886098, 0.15334539940314634, 0.0900618444596018, 0.1414586872394596, 0.1535076778382063, 0.11104813870042562, 0.21027298112000736, 0.16415666070367607, 0.11570442920284611, 0.14418870503348963, 0.12269221352679388, 0.07551456256104366, 0.11798341119928019, 0.20803790033927985, 0.19108501502445766, 0.15660974995366164, 0.06548137736639806, 0.11945083817201001, 0.18198173493146896, 0.1464346152331148, 0.08560403902083635, 0.14847098024828093, 0.15731411001511983, 0.15876313511814388, 0.13349884721849645, 0.15859925534043992, 0.23927717762334005, 0.10723357767398868, 0.1058480159512588, 0.14633729974074022, 0.11308040536407914, 0.09912972538066761, 0.1324076543429068, 0.20061664070401872, 0.12185377494565078, 0.18115971689777716, 0.15538302649344715, 0.2055775187909603, 0.045999693817326, 0.08638267152543579, 0.1731495295784303, 0.08038544654846191, 0.11957788706890174, 0.13862018526664802, 0.06651959022773163, 0.10733993125281163, 0.16769935988954135, 0.1374964362808636, 0.09194931175027575, 0.13831670369420732, 0.10255681577005557, 0.1358445156365633, 0.16972002360437596, 0.1623913161456585, 0.15709856658109597, 0.19459993498665945, 0.22561153663056238, 0.23784101754426956, 0.12618509467158998, 0.09806343474026237, 0.10509956468428884, 0.15595435297914914, 0.12973039943192685, 0.1156470522816692, 0.09326359336929661, 0.18633516132831573, 0.22929872306329863, 0.15182060907993997, 0.15972699411213398, 0.21131248319787638, 0.20690637534218176, 0.07198983098247222, 0.17737480785165513, 0.15319281044815267, 0.163866627695305, 0.18175195583275386], [0.026513835581551706, 0.057798277852790694, 0.064679362545056, 0.04909914678760937, 0.05021727750343936, 0.07401665579527617, 0.014553363268662776, 0.03236575398061957, 0.05317429579528315, 0.015656576392107775, 0.05596776679158211, 0.04630441710885082, 0.015287377006773437, 0.03268789526607309, 0.023078322876244783, 0.07877005144421544, 0.0034296459219019327, 0.05020787300808089, 0.055331874306180646, 0.04114680118592722, 0.0470712804235518, 0.04023265166740332, 0.030464373329388242, 0.012601792230270803, 0.027551537845283747, 0.047341764838035615, 0.032822156990213056, 0.10326941324664013, 0.0518013650019254, 0.05396566100950752, 0.04197990648182375, 0.029416542234165326, 0.04167167516425252, 0.02116393979771861, 0.02843671222217381, 0.018033202970400453, 0.05644801012905581, 0.017980151709967425, 0.06137261034122535, 0.03879068672124829, 0.019311091363696114, 0.026304426104096428, 0.05510454811155796, 0.023372420309377567, 0.02448109903239778, 0.008278531804015594, 0.036965023792747936, 0.025571411508800726, 0.019971353434292332, 0.03855164222685354, 0.03505886286231024, 0.0006998392688858855, 0.10919521562755108, 0.007707433475713644, 0.02829466770136995, 0.07369541017604725, 0.05607316702870386, 0.05480543291196227, 0.08183725364506245, 0.013407068260546242, 0.0425653498885887, 0.03387525351718068, 0.028848343794899325, 0.02872024316872869, 0.004420120451998497, 0.011641098602142717, 0.08079826046845742, 0.04991272723834429, 0.04208532368232097, 0.03909120648833258, 0.025480374161686217, 0.023574328582201685, 0.034647660462984016, 0.05725675941045795, 0.059795857806290896, 0.012358578986355236, 0.006770204860783581, 0.04716377831729395, 0.03527287959254213, 0.05241853670616235, 0.04144972635965262, 0.050643506060753546, 0.03171792606424008, 0.050277734973600934, 0.06521828219826732, 0.07045928668230772, 0.03938838107777493, 0.009275050384790769, 0.01170232196870659, 0.0546549100961004, 0.005137074123402792, 0.024419493141717145, 0.029827683565339873, 0.08179793254073177, 0.03513010225391813, 0.04210189011480127, 0.024133044494582073, 0.03782273955377085, 0.027351670266528214, 0.03128835232928395, 0.010138678730332425, 0.024353049296353544, 0.05624432748715792, 0.03655842525352325, 0.05264247361836689, 0.007959097873286476, 0.03257161471992731, 0.054123400045292716, 0.05486574449709483, 0.009341674041934311, 0.06478420299078737, 0.08296537918171712, 0.03663877737043159, 0.039376320117818456, 0.009111745665515108, 0.026066872690405165, 0.012853058836688953, 0.012107821281201072, 0.06211489372487579, 0.013167794760582703, 0.03497936569952539, 0.0048590202267015615, 0.05296632141939231, 0.05383837462535926, 0.002100993991397055, 0.07717944322420017, 0.022904327837750316, 0.07003330918295042, 0.031947783194482327, 0.02900391151862485, 0.03178588134635772, 0.019766368005158644, 0.03495459577866963, 0.008151096142163234, 0.04274886307705726, 0.06948873054768358, 0.04191689432731696, 0.021348974600966488, 0.028627762238362005, 0.03406823905450957, 0.04456129457269396, 0.02753695103872035, 0.04437600362247654, 0.0343049290323896, 0.01055256134298231, 0.01307459203858993, 0.038422442373952696, 0.048799200382615836, 0.02033370640128851, 0.06048995163291693, 0.06690693194312708, 0.06895383460713284, 0.008285508840344846, 0.012934565311297774, 0.0241778362875006, 0.01885902588920934, 0.03236872935667634, 0.05586519604548812, 0.054724171558128934, 0.017883178877777288, 0.01787065142499549, 0.07109904342464038, 0.04959755790020738, 0.025101636270327226, 0.023359645191313963, 0.013463059273947562, 0.021643681019278507, 0.06712631588535649, 0.007145725223901016, 0.009225755663854735, 0.026619142520108392, 0.08259059714951686, 0.0337312616008733, 0.02601540750557823, 0.05675777154309409, 0.06971928317631994, 0.03522723793451275, 0.0991299832239747, 0.02033015257412834, 0.056392180267721415, 0.010965058047856604, 0.04139887694535511, 0.06357087381184101, 0.003155642243135454, 0.029164150955953767, 0.008191354472988417, 0.05308795899951032, 0.04580534103193453, 0.012121083248140556, 0.048441324050405195, 0.05246272969192692, 0.044841549891446314, 0.0669573742364134, 0.11132819724402257, 0.014079267458458031, 0.023961373438526477, 0.04898322925769857, 0.07384662170495306, 0.0826943451538682, 0.07250986700611455, 0.037829650432935784, 0.07896875363907643, 0.05341534196798291, 0.042328659910708666, 0.05251827456855348, 0.04399425982098494, 0.022209889654602324, 0.04077349157471742, 0.0930976779865367, 0.04263461135061724, 0.050072590088737864, 0.040613374273691855, 0.0410056421533227, 0.05737572695527758, 0.06418490050626652, 0.008645559877290257, 0.024002987991220186, 0.01480100310540625, 0.016858706350571344, 0.018964636472186873, 0.010875742483351911, 0.024994578711422424, 0.05031256417610815, 0.10221785360148974, 0.005264403340074101, 0.011614922417460807, 0.004190486390143633, 0.015373932630089777, 0.005255057792445379, 0.076584822631308, 0.04208679271063634, 0.03292028672460999, 0.03464181827647345, 0.038453885686716864, 0.010120662777418537, 0.015746958952929293, 0.027249376023454324, 0.04242849276800241, 0.06390925922564097, 0.02665631945378014, 0.03469858790880867, 0.02343456563539803, 0.027855433324085813, 0.02442997650775526, 0.042278349931750975, 0.05097218842378684, 0.058414937263088565, 0.027385069456483637, 0.04315896285697818, 0.02488362805784813, 0.056956609444958825, 0.029410472738423517, 0.01706547463046653, 0.0986713817609208, 0.026524624288348213, 0.004378594532941601, 0.023548206680321267, 0.044021679421088526, 0.06811925689024584, 0.0760655737082873, 0.01303524464102728, 0.06049242828573499, 0.0736282148531505, 0.017187480315832154, 0.013064909343873816, 0.060184414099369726, 0.027737057801069956, 0.019174254599160383, 0.0594231520912477, 0.006798831829135972, 0.06760313601366111, 0.03971481070454631, 0.03636483921270285, 0.008275866857729852, 0.030926954400326525, 0.006365771272352764, 0.030921448088650192, 0.0436185108763831, 0.031431431615991254, 0.056947625641311915, 0.029334385214107375, 0.033754352147557905, 0.05506441955055509, 0.052489497898412604, 0.014664130717782038, 0.021710197807156613, 0.02964545280805656, 0.019600116747564504, 0.019831347911219512, 0.06308901895369802, 0.003438861487666145, 0.024377015153212205, 0.1271019854715892, 0.036946391221135855, 0.0713420200294682, 0.017306130645530562, 0.018238960233117853, 0.003602469215236072, 0.03143875640151756, 0.05984036970351424, 0.01976150121273739, 0.008341407403349876, 0.04600573277899197, 0.05388305615633726, 0.02697768551297486, 0.036102018851254664, 0.027795053885451386, 0.04341283334153039, 0.04512468219867774, 0.04012416070327163, 0.030702841069017137, 0.06009335469986711, 0.02350014095593776, 0.02265473721282823, 0.02368172540861581, 0.014435104792937636, 0.018267504505014846, 0.008722876398158925, 0.03645643126219511, 0.06490193560187306, 0.017301304565210427, 0.008483501117942589, 0.028300643898546696, 0.013846563025643783, 0.023456943720313053, 0.04811145085841417, 0.03899800631084612, 0.028907026895987134, 0.012540165135370833, 0.003308568133174309, 0.06824092500443969, 0.016259690547095876, 0.022698665569935526, 0.048117720521986485, 0.009117557317949831, 0.06962652065392051, 0.021596968972257206, 0.02368464141285845, 0.03102539965350713, 0.037849012429692915, 0.03031218471005559, 0.025908701088545576, 0.015721293365848914, 0.01625849971813815, 0.011470503024091678, 0.02585101543393518, 0.024011798768437335, 0.0457198625829603, 0.052443269307592084, 0.014483426664290684, 0.05153118592819997, 0.05220687449244516, 0.089224762948496, 0.12003160986517157, 0.10686927900782653, 0.1155502117638077, 0.15156842475490911, 0.1481056162821395, 0.18909777594464167, 0.11976945107536656, 0.1380611266940832, 0.061926559545099735, 0.13414489398045198, 0.13995746922280106, 0.08291015321654932, 0.12169961178941385, 0.09678954631090164, 0.13587496828820023, 0.13760425549532684, 0.19642009160348348, 0.16361035858946188, 0.25539648266775267, 0.11599162593483925, 0.18609223222093924, 0.12954769709280559, 0.1303248775324651, 0.1622415498963424, 0.1710702675793852, 0.0939422505242484, 0.16045892983675003, 0.14630403795412608, 0.21004014861370834, 0.09785410668700933, 0.26622101611324717, 0.2625364623963833, 0.13958515705806868, 0.1915666934634958, 0.09832230263522693, 0.19464455544948578, 0.1796186960169247, 0.22245106979140214, 0.16698807877089294, 0.06864296378833906, 0.07497605681419373, 0.11370241841567413, 0.11423367740852491, 0.15866846591234207, 0.12441228622836725, 0.12850051399852547, 0.12870278528758458, 0.10791347654802458, 0.13210360280105046, 0.14777481688984803, 0.0945429779323084, 0.2250045192028795, 0.13194162292139872, 0.17673466434436186, 0.10960806347429752, 0.10772072510527712, 0.06758161966821977, 0.22990707041961805, 0.11431337813181536, 0.07259399177772657, 0.10904738320303814, 0.14946825030658925, 0.162386240703719, 0.0986489901053054, 0.1585381736180612, 0.1592245932136263, 0.24182542945657456, 0.12962255307606288, 0.1335252286600215, 0.13287520568285668, 0.08576124879930701, 0.11439819500914641, 0.05888186435082129, 0.16406756905572756, 0.04267311142757535, 0.06579503696411848, 0.21306486773703778, 0.07053603577826704, 0.15146040197994026, 0.08855776981051479, 0.11742380979870047, 0.15916826123637812, 0.14882258352424416, 0.15004444867372513, 0.13950218579598836, 0.0965019560285977, 0.13533423016113894, 0.11102232044296605, 0.19058718745197567, 0.05171736915196691, 0.08209544979035854, 0.10006743363503899, 0.15606966322021826, 0.2100788793925728, 0.2300257869064808, 0.10945453814097814, 0.10546412119375807, 0.07024332934192248, 0.12840873535190309, 0.11697996647230216, 0.12058897210018975, 0.14894507266581059, 0.13960792869329453, 0.1927034838923386, 0.0592086807425533, 0.09880915151110717, 0.1794743716184582, 0.20200908955718788, 0.16170477441379003, 0.12975653660084518, 0.11706992664507457, 0.05994814820587635, 0.09780222589948348, 0.13969075067767076, 0.1569618417748383, 0.23632894296731266, 0.12751450762152672, 0.19202864010419163, 0.09176238892333848, 0.15204197434442385, 0.10519594379833766, 0.20136969243841513, 0.1719370282122067, 0.11922939148332391, 0.16446877324155398, 0.11044359114021063, 0.16031974873372487, 0.14107097232980387, 0.1662636205021824, 0.13779401459864207, 0.15077053542648042, 0.12999338603445462, 0.131528910781656, 0.12862049256052288, 0.18938710327659333, 0.064983291950609, 0.06389006346996341, 0.09633850372795548, 0.13099380449524947, 0.08832794999969856, 0.17036769885037625, 0.2024348567106894, 0.23981270460145815, 0.09250070287712983, 0.12393200557146754, 0.08731721102127007, 0.11870883298771721, 0.09492007376892225, 0.1821236844573702, 0.22635160120470182, 0.11096473996128355, 0.07078254755054202, 0.09981152415275574, 0.10263867423470531, 0.13440983476383345, 0.09252540155180863, 0.12476881566856589, 0.11576248465904168, 0.10398670618555375, 0.14403541040207657, 0.27807819843292236, 0.12328742444515228, 0.13104446391974175, 0.18129821946578367, 0.14428929106465407, 0.0650642683197345, 0.13723708662603581, 0.08556811737694911, 0.15397896112075873, 0.0955899642514331, 0.15312564905200685, 0.1670972550553935, 0.09651662595570087, 0.17125986383429595, 0.13661780128521578], [0.05439726356416941, 0.021086432438875948, 0.03463305499670761, 0.008631166453207178, 0.024185695419354097, 0.004970422106063259, 0.028807370457798243, 0.08976195233740977, 0.14992731995880604, 0.006309770929094936, 0.04247802243168865, 0.021935995601649796, 0.02846382139250636, 0.008518656865427536, 0.02587222813495568, 0.04124240337737969, 0.024410582280584743, 0.03787899349949189, 0.06434099070195641, 0.01317913901792573, 0.005404636596462556, 0.07067136958773647, 0.03503118881157466, 0.08240505853401763, 0.03883687459996768, 0.08593632440481867, 0.005091944759312485, 0.1186481990984508, 0.018612795708967105, 0.02753364826951708, 0.03755424324689167, 0.05120285640337637, 0.029292421215879064, 0.05125506628038628, 0.07389862462878227, 0.029995722762708153, 0.041508741942899566, 0.006276648666244, 0.01228992990218103, 0.00989814824424684, 0.03487646247127226, 0.01820137448209737, 0.04599612133045282, 0.030214316211640835, 0.07848769945225545, 0.021180619884814535, 0.0524242872904454, 0.022499042263786708, 0.025240474713167975, 0.02301499181027923, 0.013095287356658705, 0.10249101822929722, 0.018765282883707966, 0.047123167996427844, 0.029593612732631818, 0.03399432284225311, 0.04603602258222444, 0.020815883563565354, 0.03485302926440324, 0.03863585860069309, 0.0346959144808352, 0.009002749192794519, 0.03951414415080633, 0.06029357681316989, 0.055288543059889755, 0.050405530259013176, 0.015987229899370244, 0.05162484411682401, 0.03291743348485657, 0.054589736807559214, 0.05624665825494698, 0.11157552325831992, 0.03355879835518343, 0.060571362264454365, 0.048099087950374396, 0.027688956453597972, 0.022515998853902732, 0.08761733384536845, 0.05853383695440633, 0.02799455844797194, 0.028826077668262378, 0.03806120390072465, 0.023702210380828807, 0.004502584085068, 0.006987428517147366, 0.031031221483967135, 0.02509662359287696, 0.017889289085620215, 0.02263071876950562, 0.05192675827337163, 0.04993853871045368, 0.0282141917518207, 0.002955461266018184, 0.05158267316541501, 0.06096263269760779, 0.05929944158664771, 0.03960232995450497, 0.07269859473620142, 0.05082391834418688, 0.03499192877539566, 0.06086761743894645, 0.027246502427650348, 0.014501513015212757, 0.04266134223767689, 0.02719120860898069, 0.07364918837057692, 0.04095102686967168, 0.05931517681373017, 0.038774235639721155, 0.08523296857518808, 0.0429650171925979, 0.014493278992761458, 0.04107039475015231, 0.0368466669294451, 0.030168701695012193, 0.013348415693534272, 0.033899056525634866, 0.050503310547875505, 0.03214960325775402, 0.02286360725494368, 0.027513814690921987, 0.065535225905478, 0.03384285347004022, 0.05192857335454651, 0.01541347595463906, 0.032555720037115474, 0.021339753310063055, 0.03205876098945737, 0.03197502298280597, 0.02579469363471227, 0.025075063142659407, 0.057741572681282244, 0.010975970587294017, 0.012290320907985526, 0.04125422006472945, 0.02699592792695122, 0.040855624846049717, 0.034115543123334646, 0.011065629660151899, 0.02621550069722746, 0.012900935419436012, 0.009340206709956484, 0.04702479738209929, 0.0208983459243817, 0.011941908442947482, 0.012928549250188683, 0.07034945221883909, 0.05281277573002236, 0.057554466649889946, 0.08942562288471631, 0.019907805237120817, 0.007570417747566742, 0.010911619174294174, 0.03238417959905096, 0.042844000472021956, 0.04508011941132801, 0.053227360626416545, 0.05760359258524009, 0.027270715949790816, 0.011169721172856433, 0.0272007420259927, 0.07617636490613222, 0.014935441248651062, 0.04513182377974902, 0.0691228916070291, 0.05218311558876719, 0.0647902623085039, 0.03299543787060039, 0.026796520055670823, 0.04593238314347608, 0.029653853071587424, 0.022762795610885535, 0.03628754050337842, 0.036489462346902916, 0.02578038502750652, 0.005978676374070346, 0.07897255343518086, 0.03056986516873751, 0.049323819910309145, 0.021349498769268394, 0.0018413353910935776, 0.013975896041042038, 0.011026842053979635, 0.03821510582097939, 0.08372091435428176, 0.03005141013168863, 0.017339585814625025, 0.007927305114987706, 0.019575107643114667, 0.03476993925869465, 0.09616327884473971, 0.016779809691277996, 0.03066050387652857, 0.037693125794508626, 0.017237680032849312, 0.022152058114962916, 0.0270718712625759, 0.0391480236181191, 0.03391644059281264, 0.0796927505039743, 0.07486025802791119, 0.03747638474617686, 0.018736674150984203, 0.01726267047758613, 0.04462847632489034, 0.07814178908509867, 0.026846667186224034, 0.04525866572346006, 0.028669275010802915, 0.03764399985915848, 0.0275631832025413, 0.04586888922910605, 0.011135834285856357, 0.03005662128063185, 0.0455968645401299, 0.022382929655058042, 0.06378434771405798, 0.029745716535087143, 0.034230497133518965, 0.042897068695830445, 0.04672256092141781, 0.026035649901522056, 0.019014452816918492, 0.0437482874840498, 0.03822534830708589, 0.06077896683876004, 0.014687516427199756, 0.011892890225031545, 0.012236172965328609, 0.016722062968515923, 0.023489430280668393, 0.05591453232669404, 0.01691011555625924, 0.0021083923555644496, 0.017447109866355146, 0.032637324051133225, 0.047137108498385975, 0.027521968985508596, 0.02325940182033394, 0.02707401373689728, 0.03898860520816275, 0.01791403695408787, 0.054630879778414965, 0.051541173963674476, 0.022130026082907404, 0.029615553162459816, 0.042542445939034224, 0.025389070489576886, 0.12917989040059702, 0.056322494721306224, 0.0378491176026208, 0.015066330653748341, 0.0396716931967863, 0.06503523380628654, 0.021512321728680815, 0.014317726716399193, 0.04232635967699545, 0.03423857170024088, 0.0373106423898467, 0.013058602360875478, 0.009113020463181394, 0.04041778655456645, 0.030949576757848263, 0.00953090812877885, 0.033905492430286746, 0.0274968631898186, 0.04045988625979849, 0.033861811738461256, 0.06685606217277901, 0.02751484267147524, 0.029554420549954687, 0.01019603614362755, 0.02894509271053331, 0.02649064834362694, 0.039443349199635644, 0.045800353799547465, 0.015804120439237783, 0.02780804274204586, 0.03035437941019024, 0.0523482777976564, 0.03580972971394658, 0.015142246847972274, 0.05254458476390157, 0.04812258901074529, 0.05916285927274397, 0.04061897897294589, 0.0317962798955185, 0.023005480445655327, 0.02427324848914785, 0.03235490759834647, 0.015683234336652925, 0.036842429478253634, 0.017790994806481258, 0.04324101470410824, 0.03084530628153256, 0.023093291358756166, 0.01517746620811522, 0.04858477992404785, 0.022445477013077055, 0.04811179691127368, 0.03782896850524204, 0.01363456408892359, 0.01768548261108143, 0.01994871750607022, 0.023972584533372095, 0.03895228662128959, 0.005210790167828756, 0.014097960250053023, 0.018054980551823974, 0.01723147483010377, 0.012068551915165569, 0.04934994350852711, 0.03095607033797673, 0.015165878526334251, 0.025435197300144603, 0.045441921068621535, 0.004497231716024024, 0.05097206968015858, 0.02870906769697155, 0.03407768765464425, 0.055584703239479234, 0.013034060597419739, 0.010630249361773687, 0.06124941552323954, 0.030294430841292654, 0.026713306217321327, 0.013148879748769104, 0.0315440616437367, 0.04222852510533162, 0.02450913270669324, 0.07197910334382739, 0.012085147185384162, 0.09942606876471213, 0.059965213361595354, 0.02149700719330992, 0.011093709135561116, 0.02620177563013775, 0.02561004220374993, 0.06478542435382094, 0.00785457294633878, 0.06451482458838395, 0.056929834453122954, 0.13362671035741056, 0.0580241418044482, 0.047829417777912955, 0.020543889408665042, 0.03712855751759239, 0.05156833911314607, 0.03775615491239088, 0.043854579994721074, 0.02408171332042132, 0.03841728890048606, 0.108205049830888, 0.14522820711135864, 0.17216242397470133, 0.12633582444063254, 0.05015069964740958, 0.06381319223770074, 0.09505721926689148, 0.10645800536232335, 0.27353030389973093, 0.119213785177895, 0.1803829978619303, 0.1127345221383231, 0.08457396857972656, 0.12868754539106572, 0.11901597864925861, 0.17041766616914952, 0.08326610590198211, 0.18167916259595326, 0.1582938874406474, 0.09796253658298935, 0.1239116902330092, 0.10419614958975996, 0.14966144279709884, 0.13560177651899202, 0.2288240199642522, 0.1833321281841823, 0.0769922761246562, 0.24322264162557466, 0.113639538575496, 0.18241138330527715, 0.073487893811294, 0.16310125376496995, 0.09498607487018619, 0.12002821719007832, 0.14671160679842743, 0.10663062467106751, 0.10667458016957555, 0.13895205674426897, 0.13518535957804748, 0.05171899763601167, 0.16173297432916506, 0.10021057738257305, 0.10987295676022768, 0.11356093029358558, 0.15804510936141014, 0.21798867067056044, 0.1502195649913379, 0.14567198258425507, 0.1664455628820828, 0.20789265313318797, 0.07152775542012282, 0.17143576725253037, 0.08748353352504117, 0.129903235871877, 0.15326867066323757, 0.14544217634413922, 0.16388592523123535, 0.10461607455675091, 0.16687213070690632, 0.12259846712861742, 0.21058014035224915, 0.13488183729350567, 0.07432818479303803, 0.15124635132295744, 0.1226039496915681, 0.20262556576303073, 0.12773918413690158, 0.16498839535883494, 0.1671743502042123, 0.12155988785837378, 0.1325789980058159, 0.12776681408286095, 0.20855780744126864, 0.11726626753807068, 0.1355574546115739, 0.08654857333749533, 0.11774007497089249, 0.19490929267236165, 0.10548799884106431, 0.10113571916839906, 0.11894182834242072, 0.12496937704937798, 0.09248762072197028, 0.09286019073000976, 0.04621924739331007, 0.13219600569988998, 0.11420868017843791, 0.13049580050366266, 0.09854827515248742, 0.17226188363773481, 0.13858680134373053, 0.06079000660351344, 0.12324382178485394, 0.1916085590741464, 0.12562203274241515, 0.14718518352934293, 0.17343114875257015, 0.11354478794549193, 0.13602440884070738, 0.19661415261881693, 0.17664779829127447, 0.15490389934607915, 0.1098525667829173, 0.17262818398220198, 0.1237984291676964, 0.14931418214525494, 0.134150607245309, 0.13737748909209455, 0.1795393345611436, 0.0922749542764255, 0.10148821132523672, 0.07939172522830111, 0.10354428099734442, 0.12438865963901792, 0.09615141126726355, 0.0834458362577217, 0.12026315315493516, 0.13392399011978082, 0.11900447069534234, 0.10319942914481674, 0.08929816686681338, 0.13985876951898846, 0.1790678205766848, 0.2212713009544781, 0.14947449282876082, 0.11994538163500172, 0.11870837158390454, 0.09323114582470485, 0.08299231023660728, 0.08483943183507238, 0.11256233030664069, 0.10942578861223799, 0.1369349349822317, 0.1272688236619745, 0.11153801384248904, 0.13224899928484643, 0.14173196043287004, 0.10026675329676696, 0.12394130150122301, 0.17548556279923233, 0.12641445307859353, 0.1125176419903125, 0.06644421855786017, 0.09369664120354823, 0.11218919711453573, 0.09412706310727767, 0.10078907598342214, 0.17569062965256826, 0.14928595508847917, 0.0953279547393322, 0.06553496127682072, 0.09158360851662499, 0.0988847470975348, 0.15312684327363968, 0.13986022158392838, 0.10547178863946881, 0.19076648354530334, 0.14701027077223572, 0.1337378408227648, 0.13396844773420266, 0.1355916392058134, 0.1864203717559576, 0.15163502975233964, 0.08144522325268813, 0.10036956492279257, 0.16930501801627024, 0.18489913695624896, 0.1703254668308156, 0.09872284864208528, 0.09207642171531916, 0.09714332768427474, 0.10503124977861132, 0.2536142425877707, 0.09148452883320195, 0.205740733604346, 0.11563714567039694], [0.03718602264832173, 0.02062540521313037, 0.019321834269378866, 0.03115215678034084, 0.032472355224724324, 0.04157093307003379, 0.04091446401019182, 0.08186711597123317, 0.018570139605019773, 0.02292396973020264, 0.009061046377090471, 0.021669538292501653, 0.013519514235667884, 0.028902188941304172, 0.02976126516503947, 0.035266318158911805, 0.06649763961987835, 0.03877875468294535, 0.06077659196619477, 0.035413472048406086, 0.045375787653028965, 0.011329883426826979, 0.006678098396930311, 0.033648599072226455, 0.025947033228086572, 0.027376263768279126, 0.018688428614820753, 0.02235984759006117, 0.009834183596207626, 0.02705353724637202, 0.016349379305860827, 0.02311204606667161, 0.0020602536886664374, 0.04527348153559225, 0.06257709142352853, 0.03594881242939404, 0.06889716336237532, 0.016061739829768027, 0.04534637315997055, 0.001812429163172575, 0.07173278834670782, 0.007815511381652738, 0.0072172529928918394, 0.017320245870255997, 0.026771875663793514, 0.02810644039085933, 0.016147677986217395, 0.026409025669896176, 0.015088137072910155, 0.086933994798788, 0.024500866453828554, 0.07841580866702966, 0.031005929091147015, 0.024642990702497106, 0.06212771125137806, 0.016774985307295407, 0.05275483562477997, 0.04239141422190836, 0.05253741264875446, 0.04515210858413151, 0.06291421476219382, 0.012937662823657905, 0.04312643728085926, 0.00989378017506429, 0.01789254435737218, 0.01302469426965607, 0.02435657937478806, 0.06398484802671842, 0.0007475270280597865, 0.03042790207213589, 0.09639502569500889, 0.024308946216478944, 0.022709727387077043, 0.04444508866540023, 0.038147398204143555, 0.031779988269720755, 0.07653699269784348, 0.020464789188866104, 0.017111877944054346, 0.01975152505162571, 0.05323117060054626, 0.09512851294130087, 0.05243237542786768, 0.011972585011140575, 0.04284189022811396, 0.011224080309537905, 0.04524822985487325, 0.037537361295627694, 0.03512987833736198, 0.031118548940867186, 0.013640452076547911, 0.015710694648857628, 0.009084292986829366, 0.03794435338516321, 0.025465034181252122, 0.042108790815940926, 0.04277419957465359, 0.04611734500420945, 0.046348321717232466, 0.035296831878700426, 0.02757876236656947, 0.033895969191300016, 0.0211710237033133, 0.05456273111381701, 0.012944288718115007, 0.023638925115977014, 0.055430183852357526, 0.049249432116214714, 0.028074769768863916, 0.046588502757783444, 0.011526003795942026, 0.09649312828800508, 0.002109661216049322, 0.023391558389578546, 0.005536334730485188, 0.047927483051483116, 0.03436833134453211, 0.027868564673034207, 0.05430612613313964, 0.10480833745428494, 0.04872322481657777, 0.02118812278578324, 0.03653622358771307, 0.012535900542778628, 0.02914839537282075, 0.023807364649006298, 0.05221652665308543, 0.015886387721236263, 0.04246547971186893, 0.056849689289395294, 0.04892265982925892, 0.05977751021938665, 0.02454187032500548, 0.019775755537141646, 0.02676747875687267, 0.05935086775571108, 0.08391288548175778, 0.04971673918355789, 0.07205748092383146, 0.04629613898162331, 0.007444158495802964, 0.005886384585340108, 0.03873993230185338, 0.004842033950678472, 0.06497532594949007, 0.0325663967856339, 0.108675152462508, 0.030680870105113302, 0.019623268362400786, 0.06740542447992734, 0.025859458105904714, 0.05542776487501604, 0.09914127404668502, 0.023713770921209028, 0.08037224225699902, 0.02135682525113225, 0.03141296189278364, 0.07320822881800787, 0.013726683699392846, 0.05483799580750721, 0.01994634941885514, 0.09199480073792593, 0.026117016428283284, 0.013298483997849482, 0.04265240593148129, 0.042616871052554677, 0.035724654993308444, 0.039564868036125383, 0.017927122501922504, 0.03386542833011065, 0.03986972024930375, 0.024761727545410395, 0.002925938843483371, 0.062202797936541696, 0.060951409728399346, 0.02194002440332302, 0.05506719136610627, 0.02770397243356066, 0.05175639848623957, 0.041670094177659066, 0.037107349905584536, 0.024212222745908157, 0.03052880022940891, 0.12476566726607935, 0.02812786174139806, 0.024881198902481368, 0.03435850615746208, 0.03442096191325358, 0.05190981186128088, 0.045549696178308556, 0.06969980922128473, 0.002454283002797248, 0.04128823841788939, 0.0667682122439146, 0.048762905544468334, 0.04098580178937741, 0.035900806076824665, 0.025285151155133332, 0.03728470878143396, 0.02470155166728156, 0.010785337870142289, 0.058649907154696326, 0.04748618083872965, 0.0459666593399431, 0.018504521876041378, 0.04005420374284897, 0.00924042474278914, 0.03149326990491577, 0.008454619274873818, 0.04118308923872454, 0.027147242932447364, 0.026668080161990862, 0.05116728759769883, 0.021478384799723114, 0.028313008502924016, 0.026117496491808976, 0.0408962487376162, 0.035387996451130936, 0.027162484525303756, 0.009400005152981197, 0.03794252134061285, 0.04947315189721329, 0.02508635226903217, 0.03543492393302066, 0.001996694253258673, 0.041104260432933054, 0.07126528450420924, 0.04529518447816372, 0.041961596214345524, 0.01347500573111964, 0.061051439360848496, 0.017339495908735052, 0.014554101175495555, 0.025899218561659967, 0.01555841273095991, 0.051199104104723246, 0.010537703122411455, 0.03684282302856445, 0.033288269835923395, 0.016387831885367632, 0.012394185111458813, 0.05237589417291539, 0.005208590018030788, 0.052677007658141, 0.07907347194850445, 0.059218784128980975, 0.05068833686943565, 0.04958334598424179, 0.026064879493787885, 0.04717234482190438, 0.02692276319222791, 0.020867667659851055, 0.03196556081197091, 0.02793828584253788, 0.017366208136081696, 0.02522741461039654, 0.07489978947809764, 0.07326352263667754, 0.01024002387254898, 0.020520588516124656, 0.018641689426398704, 0.03803218635065215, 0.04529336600431374, 0.07600880068327699, 0.03519013224701796, 0.01077180533736412, 0.0010425465796808048, 0.010830778512172401, 0.02254933019035629, 0.022241380464817797, 0.02658770768903196, 0.05190126232004591, 0.023644714716023633, 0.03060996998101473, 0.043542555666395595, 0.007649517119196909, 0.05539777362719178, 0.04325034116793956, 0.02719058096408844, 0.031306445465556214, 0.02785810505572174, 0.005441543388380004, 0.006843355176637748, 0.08991650225860731, 0.014709828354950463, 0.024292021856776307, 0.03320450129519616, 0.1063702232869608, 0.0096078056542735, 0.02943630117390837, 0.017200647287869027, 0.03378519834950566, 0.06378350633063487, 0.024458807460697632, 0.038892799456204684, 0.06008469659302916, 0.011251554192442979, 0.0244498626728143, 0.03313987422734499, 0.042898717535925765, 0.02034129581547209, 0.04960650099175317, 0.046352362393268516, 0.025308592843690088, 0.026664509371455227, 0.03293395581256066, 0.0797092185488769, 0.1088386590459517, 0.028745779834155525, 0.021432302093931606, 0.055498719281916103, 0.03613706857764295, 0.06822146462010485, 0.0227910769504628, 0.007978643074498644, 0.02378750223267291, 0.06654217865850244, 0.01963478819067989, 0.01937387281629656, 0.009537200692908039, 0.028041470662823746, 0.04901570055101599, 0.02773627918213606, 0.05166176659986377, 0.012917344092524477, 0.05787238744752748, 0.03559974008905036, 0.026544800527127724, 0.04190866369754076, 0.008381117817147501, 0.02957508194127253, 0.002106962979139228, 0.015543676646692412, 0.05020384929542031, 0.04540908336639404, 0.0581582813922848, 0.04545758504952703, 0.0250741895288229, 0.02396773300798876, 0.0695431897682803, 0.03141600172966719, 0.04533085506409407, 0.03570437358160104, 0.020598178995507102, 0.0022615835103871568, 0.01774741928758366, 0.024674160904916267, 0.05441189277917147, 0.019215002323367765, 0.08248757517763547, 0.060443885890500884, 0.032656048224972825, 0.24402239013995441, 0.10717582077320133, 0.15092549925403936, 0.11887520977428981, 0.12782358032252106, 0.08753820309149367, 0.18590567580291203, 0.19770525049950394, 0.09205658813672406, 0.09935085994324513, 0.11403565374868256, 0.10663251778376953, 0.11182458632226501, 0.14541384072176047, 0.10476760499711547, 0.08778309995042426, 0.18679002406341688, 0.11976703549070017, 0.14995119082076208, 0.2013962095869439, 0.12100150782082762, 0.13620761329574244, 0.0940705139988235, 0.1111885683078851, 0.0873119252334748, 0.1366015300154686, 0.10206522393439497, 0.1322570467101676, 0.10497590167714016, 0.12101925829691546, 0.06759038634066071, 0.2092289057161127, 0.08989016831453357, 0.14655395597219467, 0.13178851827979088, 0.16986060248953955, 0.1714359029595341, 0.05164552586419242, 0.13017445988953114, 0.07742727813976151, 0.14769016286092146, 0.10356247252119438, 0.11917324949588094, 0.10765468329191208, 0.12877404503524303, 0.09943427903843777, 0.09834265868578639, 0.10388044760163341, 0.10571988139833723, 0.18198951094278268, 0.1372848419206483, 0.23830198709453854, 0.12883205977933748, 0.10098617005028895, 0.13168044122202055, 0.08617760467209987, 0.1024279280432633, 0.1348714285663196, 0.07816982615206923, 0.19062286482325622, 0.19144391933722155, 0.09037018434277602, 0.2258047562624727, 0.09939647785254888, 0.11675102875701018, 0.10733017391924347, 0.12472032755613327, 0.17318714755986417, 0.1921420233058078, 0.07262276166251727, 0.14565698696034296, 0.1432888318917581, 0.15216861612030438, 0.13728124568504946, 0.16906527802348137, 0.14592261984944344, 0.12118194385298661, 0.07356242409774236, 0.08459217367427689, 0.11536776726799351, 0.08777997868933848, 0.22085240057536534, 0.09446066484919616, 0.08626474213919469, 0.14118588902056217, 0.12826628371008805, 0.17128385683255537, 0.14546711929142475, 0.10201890713402204, 0.09504490385630301, 0.10105582845530339, 0.13966831830995424, 0.1354199019925935, 0.14995281930480683, 0.10941468777933291, 0.17285029563520635, 0.12364779439355646, 0.1988708515252386, 0.10198783701551811, 0.1411127293748515, 0.09323328999536377, 0.1549231018871069, 0.100420556829444, 0.11291458497622184, 0.07490152652774539, 0.15343260472374304, 0.11391547162617956, 0.22143820699836525, 0.07600100431591272, 0.11883765964635781, 0.1439710445702076, 0.2907779855387551, 0.11654182284006051, 0.09511861311537878, 0.1036290843039751, 0.1410430031163352, 0.23056959201182636, 0.07792570960841008, 0.10992702243051358, 0.18755496373134, 0.10616540749158178, 0.09094184331063714, 0.10357296267258269, 0.1971493810415268, 0.08787586925817387, 0.13889108358749322, 0.10651213210076094, 0.12754417317254202, 0.1293555088341236, 0.09909710820232119, 0.24789383954235486, 0.2552946209907532, 0.09065030395452466, 0.14423913375607558, 0.13487321989876883, 0.19804613292217255, 0.19642417638429574, 0.0978491533813732, 0.143894831516913, 0.14219052796917303, 0.13910873048007488, 0.06971937817122255, 0.09895559293883187, 0.09567997192165681, 0.11215310583689383, 0.10233488732150622, 0.1599779570741313, 0.1521701631801469, 0.128440097240465, 0.1808772970523153, 0.11565400048026017, 0.1255925300398043, 0.12876489838319166, 0.07583355544401066, 0.11889891778784138, 0.06221786819930587, 0.08501514526350157, 0.24485972949436732, 0.2291886375418731, 0.12556293234229088, 0.15389881256435597, 0.16936509550682136, 0.08869695769889013, 0.14573773262756212, 0.12486005148717336, 0.12727183635745729, 0.1452714026506458, 0.11801083758473396, 0.12010177038609982, 0.11095946774418865, 0.09420800554965224, 0.284171144344977, 0.058511960985405106, 0.26134069370371954, 0.17337668953197344, 0.08478356126163687], [0.024633805034682155, 0.025636030094964162, 0.061099472854818614, 0.019401416249041046, 0.006813564520728375, 0.015346925240010023, 0.017819291413096443, 0.016891321832580224, 0.04150012794083782, 0.020693492809576646, 0.03118590371949332, 0.04132662992924452, 0.011735440414798046, 0.02722767647355795, 0.0662997652377401, 0.04409990093803831, 0.032997890774692805, 0.06606983007597071, 0.03555567263226424, 0.02047208513665412, 0.08905172973339047, 0.036088349763303995, 0.02630193588057799, 0.0395756058527955, 0.029842828466956104, 0.023444077000021935, 0.01580458862840065, 0.042403502323265584, 0.008215267743383135, 0.04889804257878235, 0.02637653232419065, 0.03498228340010558, 0.02901481218369944, 0.052937246193843226, 0.05937932551439319, 0.012208827155908304, 0.05537227088851588, 0.04518433560484222, 0.05453012411349586, 0.013836535126236933, 0.024607747593628507, 0.031885927942182334, 0.056180077006242106, 0.06526991192783628, 0.026616189196439724, 0.012430950683275504, 0.03441864810883999, 0.031194259878247976, 0.020831707000200237, 0.0008205481041971195, 0.04164202318393758, 0.021882128402856842, 0.033949169729437144, 0.031619236538452763, 0.021732703117387633, 0.021344930532255342, 0.020787685344527875, 0.035140806143837314, 0.057209831928568225, 0.06580340330089841, 0.04489291159968291, 0.001209894731541031, 0.028328372232083763, 0.05927027136619602, 0.008676859001362962, 0.01418609346728772, 0.026360730939943875, 0.043695511030299325, 0.017359154764562845, 0.017908832590494837, 0.058309947539653094, 0.06393310294619628, 0.04981873996023621, 0.04555095486076815, 0.01178403285198978, 0.04806407554341214, 0.03378427893455539, 0.04820584525753345, 0.07716426439583302, 0.03134364275527852, 0.01616971001827291, 0.017856699048674533, 0.07932022799338613, 0.022195945759969096, 0.05748231802135706, 0.07617109947438751, 0.0204986531753093, 0.04118563374504447, 0.035314209160528014, 0.03729134485391634, 0.02442901298802878, 0.0528352963072913, 0.05512055475264788, 0.06820013826446873, 0.025714322858090912, 0.06001636811665126, 0.04124901570113642, 0.08647921348788909, 0.01828917012816029, 0.054372337580259354, 0.02440390210332615, 0.006641201358953757, 0.0415207757614553, 0.032069922890514135, 0.02013577943268631, 0.01477703555221004, 0.03472270643604653, 0.03941703221893736, 0.03353935493422406, 0.012546120128328246, 0.019988360914534757, 0.002258627430169976, 0.062315692592944415, 0.05232177421982799, 0.059500369376369884, 0.07250163637633834, 0.04127897980755993, 0.06697903985955886, 0.01752579617979271, 0.013697379468274968, 0.034386519475706985, 0.08476669966642346, 0.05107723243002381, 0.004466685341737632, 0.011487944766746035, 0.016491623994495188, 0.01724214479327202, 0.13314737964953693, 0.022115724261051843, 0.05532055973474469, 0.09106222899364573, 0.025415628350206783, 0.017438070083569204, 0.037347758255366764, 0.021957890230364034, 0.01138688121656222, 0.007345904080596353, 0.030844454720084156, 0.03612135031393596, 0.10679437552711793, 0.011118542669074876, 0.0856693276603307, 0.01123606154162969, 0.0031888896108804537, 0.023901372283164943, 0.019132774057132856, 0.010821327367531402, 0.04795121142108526, 0.04224210598372987, 0.0192858973584537, 0.03745928566370692, 0.06768906568842274, 0.06027681699820927, 0.06170587281563452, 0.05562645349917667, 0.04649340946759496, 0.05035074194893241, 0.034723649599722455, 0.00729807753980692, 0.054562520767961226, 0.01645228762312659, 0.0542476092731314, 0.01988455862738192, 0.007959876492220377, 0.01086305472667196, 0.07441694395882742, 0.010654955669971449, 0.028954680410346816, 0.03509453684091568, 0.019023657144446458, 0.1030818729528359, 0.030952850689313242, 0.10354274072285209, 0.024039499960573654, 0.06709481150444065, 0.0356311969725149, 0.0698226240596601, 0.022094862701903497, 0.09783114506197826, 0.021933786970164095, 0.09476125586245741, 0.010899370769038796, 0.00903953512066177, 0.019362217281013727, 0.05089373620493071, 0.04748326992349965, 0.04832293665302651, 0.030855799825595956, 0.016731345327571034, 0.06432782033724443, 0.06226964042122875, 0.03503650852612086, 0.022764310440314666, 0.10053402824061257, 0.027019020169973373, 0.011694949685728975, 0.02595215616747737, 0.08895775941865784, 0.02999563455315573, 0.002262005050267492, 0.020522708938057934, 0.058188130147755146, 0.040985377704990764, 0.054619056305715015, 0.025420396755050336, 0.01704851464767541, 0.0067344193479844505, 0.021562273780416166, 0.032406784993197234, 0.05174663097464612, 0.05750692170113325, 0.01731653937271663, 0.038661988984261236, 0.05452547275594302, 0.02673301426693797, 0.045629614032804966, 0.014913426179971014, 0.04233891596751554, 0.01984655388098742, 0.00502082920034549, 0.040795459145946164, 0.010312265799646931, 0.03493850092802729, 0.044681005113359006, 0.061340352786438804, 0.005601809967109668, 0.029064704863620654, 0.02443832757749728, 0.03274295159748622, 0.017050903090941052, 0.056919568218290806, 0.055849267435925345, 0.061650361865758896, 0.049511455199015994, 0.027923637967822806, 0.02245801973289677, 0.04649089888802596, 0.013138914613851478, 0.03348294831812382, 0.017929225960480313, 0.07249477638729981, 0.025553408278418437, 0.01936161338484713, 0.06554492895624467, 0.029490136142287935, 0.020781551387959292, 0.029687128428901945, 0.020569000293367674, 0.048242876306176186, 0.05024519582678165, 0.06328671013138124, 0.03469198576307722, 0.015942377038300037, 0.03332980974976506, 0.036160223585154326, 0.07433159782418183, 0.019045361783355474, 0.062440156271415095, 0.053425998360450776, 0.045539904917989454, 0.013974750165029295, 0.04485161935112306, 0.008538409867989165, 0.036565916280129125, 0.0527973424510232, 0.0632993308827281, 0.013990957822118486, 0.017245812275047814, 0.08489010483026505, 0.043289723340421915, 0.041034635954669545, 0.08209867283169713, 0.013841209384346647, 0.05202706271250333, 0.00945288932416588, 0.03934710579259055, 0.04447099852508732, 0.024836520764178464, 0.06790444627404213, 0.012452736746386757, 0.057754987318600924, 0.03082196128421596, 0.04875660873949528, 0.0506198862567544, 0.025101079871611934, 0.01600935183731573, 0.04300896929843085, 0.01949166988820902, 0.07803804108074733, 0.023243977023022513, 0.07256218884140253, 0.018053016192944984, 0.02707598148845136, 0.018579291346083795, 0.009617232202020074, 0.013667583299268569, 0.02199746748166425, 0.06882424798927136, 0.014266302243673375, 0.017967688718012402, 0.02299652887242181, 0.017219001660123467, 0.021493375334622603, 0.03135506928499256, 0.023200959599177753, 0.02899030689150095, 0.01737370085902512, 0.0327308126060026, 0.019543581209810715, 0.030162004554378133, 0.030727946864707128, 0.03860198613256216, 0.036645613610744476, 0.02817026848372604, 0.026395953692761914, 0.05871138921273606, 0.03890602071104305, 0.0812191285991243, 0.011745668482035398, 0.026863822247833014, 0.031997468921222856, 0.007926829292305877, 0.04589577617921999, 0.04447495438424604, 0.006282950984314084, 0.02683118640977357, 0.02028065514085548, 0.03195725215066757, 0.0033641641119694604, 0.01446111304020243, 0.038936242660773654, 0.01707112682717187, 0.08507654589733907, 0.052586368950349946, 0.011810611068670238, 0.02003977520923529, 0.06619026325643063, 0.016637956856616905, 0.013280792045406997, 0.05567563371732831, 0.03499534859188965, 0.030875887854823043, 0.026080553652718663, 0.03821849510339754, 0.01599445629731885, 0.06595943242843662, 0.030345605952399116, 0.08649669933531966, 0.08332678728869983, 0.010417489617663835, 0.05098980658554605, 0.02263503085954913, 0.1291185644056116, 0.12125394998916558, 0.19690380564757756, 0.12652768700250558, 0.26221874515925137, 0.10974617927734341, 0.1273843917463507, 0.15248466416129045, 0.1775238819952522, 0.09731911575155598, 0.19914814164595945, 0.12601144398961747, 0.17651472400341714, 0.11697124051196234, 0.1439948340079614, 0.12072701326438359, 0.09838650561869144, 0.17491913533636502, 0.12343923987022468, 0.14084112537758692, 0.1572703037943159, 0.16382229221718653, 0.0733583750469344, 0.09245999756136111, 0.11884491997105734, 0.1025161850931389, 0.09783630871347018, 0.12221400918705122, 0.07568466450486865, 0.15713663239564213, 0.1018375890063388, 0.1263980868139437, 0.1908952287797417, 0.16285200071121964, 0.17157820532364504, 0.09650399163365364, 0.10978550716702427, 0.15809602662920952, 0.13020411186984607, 0.11861328168639115, 0.0866570710869772, 0.06637580865728003, 0.12950584505285534, 0.1124781851789781, 0.08054028823971748, 0.09480078052729368, 0.18473157951874392, 0.1474987617028611, 0.18134225638849394, 0.06518682531480278, 0.12145221792161465, 0.10375533931489501, 0.12726723589003086, 0.11106595024466515, 0.13899994774588517, 0.14783389014857157, 0.18259184647883686, 0.1047462107879775, 0.14169464100684437, 0.09636147213833672, 0.14189718370991095, 0.0772159348375031, 0.12113547777490956, 0.13122044876217842, 0.18877509183117322, 0.1036333047917911, 0.09664001754884209, 0.14273522874074324, 0.0648834387372647, 0.14147079230419227, 0.14509882405400276, 0.12607515842786857, 0.11827701330184937, 0.16843398261283124, 0.13260276030216897, 0.13724577187427453, 0.12254319366599832, 0.10599823003368718, 0.15765937577400888, 0.19895731045731477, 0.122535322659782, 0.0988230479082891, 0.17579710536769458, 0.16926259600690433, 0.16773947487984384, 0.10967757260160786, 0.12487611919641495, 0.16101427003741264, 0.12231485306152276, 0.09817716399473803, 0.11641538462468556, 0.14804591877119883, 0.11463751431022372, 0.1937476542911359, 0.06400671042501926, 0.22202082430677755, 0.17600850973810467, 0.17817558773926326, 0.10328438172915153, 0.13728249418948377, 0.10662675702146121, 0.08937611696975571, 0.16083035990595818, 0.09112354820328099, 0.18579580741269247, 0.1043830859873976, 0.1258683545248849, 0.19563858211040497, 0.0898708300665021, 0.08529367710330657, 0.14841800023402485, 0.09088718052953482, 0.12781446081187042, 0.22104139971945966, 0.1991984618029424, 0.18548366773341382, 0.11381964212549583, 0.1004081532093031, 0.07505242593054261, 0.05374962903027024, 0.0881864143801587, 0.25086286451135364, 0.18773808676217282, 0.1166769734450749, 0.10929078049957752, 0.10216986081962075, 0.08257870243063994, 0.1645765517439161, 0.0767624970259411, 0.14744681306183338, 0.188830718132002, 0.1403949750321252, 0.06270952110311814, 0.08829489177359001, 0.12336469601307597, 0.09486074266689164, 0.12818278319069318, 0.13421152611928328, 0.13741645057286533, 0.1677599394960063, 0.12260848230549268, 0.21588314936629363, 0.052490284999034235, 0.19085011977170194, 0.1600561107375792, 0.057178965370569906, 0.14201507238405092, 0.1616199439657586, 0.08473609095173222, 0.10809594139988933, 0.12492158104266439, 0.12741017607705935, 0.18428707122802734, 0.12001423936869417, 0.18834769619362696, 0.16338494925626687, 0.17849763402981417, 0.12949641341609613, 0.14546656289270946, 0.09454785659909248, 0.15493295421557768, 0.1249065175652504, 0.22675945503371103, 0.1331353560090065, 0.09114627234105553, 0.23114949518016406, 0.16682410399828637, 0.1284755981926407, 0.10801885982177087, 0.11613702241863523, 0.13970977679959365, 0.1783540424491678, 0.14120085750307354, 0.11794396117329597, 0.08911189543349401, 0.16863307835800306], [0.044281154604894776, 0.02752281885061945, 0.03038470653284873, 0.03170161747506686, 0.0320959955986057, 0.058777207109544954, 0.04232016804495028, 0.040495332929172685, 0.06394598832620041, 0.02258490408504648, 0.09912695695779153, 0.05626982344048364, 0.030574540275016, 0.015122642274945974, 0.05578668275848031, 0.03760476017903004, 0.06992842802511794, 0.055967705723430426, 0.029842021010283912, 0.014267413344766413, 0.018822669982910156, 0.011338801921478339, 0.0028245527771235046, 0.01118356328723686, 0.07562261247741324, 0.012920519636411752, 0.06274331214704684, 0.052554823857332976, 0.060664715112320015, 0.061266182123550346, 0.024599284565608417, 0.05373504052736929, 0.039442372109208784, 0.02686722170827644, 0.009466650014344071, 0.0565406369444515, 0.0519180865958333, 0.005647301499266177, 0.057464296131261756, 0.024547941517084837, 0.06885577951158796, 0.014504490087607076, 0.03422871597909501, 0.0648946820625237, 0.015352838672697544, 0.04109152772330812, 0.02856782724016479, 0.021085813275671432, 0.04728210464652095, 0.03920463379472494, 0.013550237453143512, 0.01877970344919179, 0.049693892909479995, 0.0190843063007508, 0.023394823839355792, 0.022868373963449682, 0.05251141118683985, 0.07651646022817918, 0.054665281503860436, 0.046091221405991485, 0.05990837248308318, 0.014541656843253543, 0.026028878122035946, 0.04528781898053629, 0.07546630515051739, 0.04639220257688846, 0.03227749353806887, 0.049705451753522666, 0.051567623258701394, 0.03405252418347767, 0.03478956249143396, 0.05449718802369066, 0.07214256242981978, 0.053298243787139654, 0.032264163717627525, 0.046366428424205096, 0.03861524809950164, 0.04362492642498442, 0.022024459604706084, 0.039576118146734576, 0.0676749860867858, 0.008829009453100818, 0.03916437631206853, 0.0503288558019059, 0.026280465336250405, 0.007437635229767433, 0.03158229369936245, 0.006716109080506223, 0.02151840988413564, 0.04566886728363378, 0.03237965716315167, 0.026347436742591004, 0.04323963388534529, 0.031163909006863832, 0.04025064980877297, 0.024669187243229578, 0.03529710668538298, 0.026836562103458812, 0.037477236307625256, 0.030116471461951733, 0.040285021000142605, 0.06868890060910157, 0.027502500119486024, 0.055027181548731666, 0.03202467478279557, 0.045219039278370995, 0.062471362096922736, 0.03661892004311085, 0.04647890917424645, 0.010604579533849443, 0.03868899807067854, 0.06868234596082143, 0.0356458092241415, 0.0451437829594527, 0.006306663662793913, 0.04829464513542397, 0.04408849476437483, 0.03499235285978232, 0.029277802178902284, 0.024880935970161642, 0.023650938578482186, 0.04577375861949154, 0.04799903456919959, 0.0036479454803546624, 0.07979031026895557, 0.023317786366013542, 0.029983400566769496, 0.019899498272155012, 0.014600504489083375, 0.013050640600600412, 0.044336655376745124, 0.036940158876989565, 0.04874724495623793, 0.027073738930214728, 0.03333068505993911, 0.05774812732956239, 0.03887505915814212, 0.030151321020509516, 0.012188262455830616, 0.04294955677219799, 0.12087327827300344, 0.021993579476007392, 0.016673149075359106, 0.021337503966476237, 0.06174564853842769, 0.034288437238761356, 0.005855300896135824, 0.026925816599811827, 0.07772467325308494, 0.035389818317656, 0.01713464449026755, 0.020146919281354973, 0.02863591822928616, 0.05391265046117561, 0.020924785041383336, 0.06616071984171867, 0.03820462245494127, 0.04375423484348825, 0.009806353482417762, 0.004344094844002808, 0.05610259848513773, 0.007996077183634043, 0.06244095015738692, 0.04231319270495858, 0.04274363835741367, 0.0662500150501728, 0.03136282154758062, 0.034173065929540565, 0.06263467869056122, 0.049908879944788556, 0.020341906496988874, 0.031836133649838824, 0.0808746838676078, 0.03885504576776709, 0.036007682127611976, 0.02629263655814741, 0.01543930608646146, 0.04275336854958108, 0.030607927590608597, 0.05182170408910938, 0.023398637206160595, 0.08551025869590895, 0.05770442967436143, 0.08921274609331574, 0.019949458805578094, 0.0194839227146336, 0.055289425155414004, 0.025279281827222024, 0.058136493632836, 0.058835656116051335, 0.026594241981261542, 0.04182739895103233, 0.03128533963380115, 0.021936250052281787, 0.023054190778306553, 0.046294479963502715, 0.030061533874166862, 0.029543516492205005, 0.012801148363256028, 0.03739621244104845, 0.05798822694591113, 0.045496224226163964, 0.054729810184133906, 0.025110552220472267, 0.01278138009365648, 0.03840061390240278, 0.0655885858993445, 0.03104375402576157, 0.03185607918671199, 0.038284394424408674, 0.04431262505905969, 0.015926901350862215, 0.051687425401593955, 0.04483449991260256, 0.03263157346685018, 0.015732355182990432, 0.041749621874519756, 0.02681456569449178, 0.053249022856886895, 0.03142178624070116, 0.027091828673811894, 0.029183034585522752, 0.0314609241405768, 0.018364935348342572, 0.06641071249863931, 0.030067240353673697, 0.01784015806125743, 0.046366574309234104, 0.016477050758632164, 0.023573777272499034, 0.0773211552628449, 0.011510278746884848, 0.053336594586393664, 0.03873830721048372, 0.038856100889721086, 0.1097476381276335, 0.04111251141875982, 0.05027191314314093, 0.05449757818132639, 0.02588008896314672, 0.050711152609437704, 0.07277929290596928, 0.036000951060226986, 0.08713321946561337, 0.03174599366528647, 0.033764431785259924, 0.024986570301864828, 0.0429257062662925, 0.040467085516346354, 0.03432936307841113, 0.04843280504324606, 0.0794070465490222, 0.06865088907735688, 0.033625284608985694, 0.03678308480552264, 0.043917266452418904, 0.05682962161621877, 0.03349249869851129, 0.0483979961967894, 0.049125721611614735, 0.018354706432936446, 0.02166262232432408, 0.009729673936297851, 0.07170371990650892, 0.03655176203964012, 0.03168689326516219, 0.027158165649910058, 0.017375554955963577, 0.015404839900189211, 0.05228825458990676, 0.04214547920439925, 0.08549680334648915, 0.01309856552896755, 0.05723908357322216, 0.013249162983681475, 0.021939042223883525, 0.022965119486408572, 0.13091197317200048, 0.025215553818270564, 0.049510759700621874, 0.03870015997173531, 0.03331757237070373, 0.017831550844545876, 0.021992965401815515, 0.013600971516487854, 0.05774731308754001, 0.052344959761415205, 0.06753169306154762, 0.07259032090327569, 0.05680544880617942, 0.043334788243685446, 0.014140970040378826, 0.07278729961918932, 0.060204939783683846, 0.04449315947879638, 0.058871177424277575, 0.0765970226909433, 0.0789657070168427, 0.01837342042875077, 0.03487501719168254, 0.01657030521892011, 0.04642964413921748, 0.028506413035626923, 0.045963202204023085, 0.06496350586946521, 0.011957079637795687, 0.01757760063212897, 0.009822841883370919, 0.05462130904197693, 0.013066000088916292, 0.008828101912513375, 0.040007048951728005, 0.020993111821423684, 0.02802713491421725, 0.01781894705657448, 0.043236105503248315, 0.042463837657123804, 0.02034119742789439, 0.02469066796558244, 0.04153205640614033, 0.03261428439457502, 0.012731768157599228, 0.018439575896731446, 0.05446404837337988, 0.04136759987367051, 0.02655700906845076, 0.02321781780171607, 0.04525963602853673, 0.028903552796691656, 0.037107797738696845, 0.0039099643223120695, 0.04448879989130156, 0.039243232259260755, 0.015781967967216457, 0.037387384700455835, 0.014194470830261707, 0.013814514120375472, 0.03836965574217694, 0.05640809191390872, 0.06393830052443913, 0.02707194081241531, 0.015996133975152458, 0.11471228886927877, 0.07791684115571634, 0.04168894388047712, 0.08702105762703077, 0.02965220423149211, 0.09027135571730988, 0.05552694633869188, 0.029365099101726497, 0.029262056773794547, 0.031190175097435713, 0.08698838616588286, 0.08164030207054955, 0.08754152791308505, 0.09308583755046129, 0.20815462193318776, 0.18774240224489144, 0.1434211597910949, 0.20917965764445917, 0.15596966072916985, 0.1610617267766169, 0.13649094237812928, 0.13989959018571035, 0.16078268603554793, 0.1179365651415927, 0.13425730009164127, 0.11834378114768437, 0.12647428629653795, 0.09252291811364037, 0.11694009575460639, 0.12523173939968857, 0.16008836829236575, 0.1294325768415417, 0.0933316300756165, 0.1003651273037706, 0.19713016492979868, 0.13520172584269727, 0.17238023371568748, 0.11913658146347318, 0.09433996704007898, 0.13537274380879744, 0.14506709575653076, 0.11047032541994538, 0.11569955732141222, 0.09335438814014196, 0.11413883178361825, 0.105357326567173, 0.10160869878849813, 0.12870169963155473, 0.14193533094865934, 0.07937035816056387, 0.19378999487629958, 0.11719527920441968, 0.16417450617466653, 0.1756993963250092, 0.1258888869945492, 0.14027412794530392, 0.10324087406375579, 0.15276013580816133, 0.09609466538365398, 0.0699173000508121, 0.15072382507579668, 0.1381775497325829, 0.09252610722822802, 0.1244141725557191, 0.12764952251953737, 0.14039007600929054, 0.20763877247061047, 0.15114214191479342, 0.19891016584421906, 0.194986224972776, 0.1436074719365154, 0.08605572621205024, 0.1570477850203003, 0.10419443289616279, 0.15853659941681794, 0.15485599477376255, 0.09432995186320373, 0.17859163827129773, 0.12911662379545824, 0.08593196820999895, 0.13037063793412276, 0.18377279596669333, 0.1277564867798771, 0.10707023393894945, 0.12207347101398877, 0.23945441097021103, 0.16826468812567846, 0.13249127699860505, 0.12972092708306654, 0.14758067445031234, 0.14139297790825367, 0.08872274881494896, 0.09952365567109414, 0.2034349494746753, 0.10169879466827426, 0.1381369869091681, 0.08077789763254778, 0.1364555907036577, 0.07143193949013948, 0.07237390894442797, 0.15026639747832501, 0.17424251378646918, 0.08759709314576217, 0.20262984053364821, 0.12207794934511185, 0.1871319514300142, 0.100371254474989, 0.11261063521461827, 0.12081830336579255, 0.06292569557470934, 0.1689297202974558, 0.17501691223255225, 0.14594087244144507, 0.14330498102520192, 0.11691876261362008, 0.08499229898942368, 0.10912168278758015, 0.13458535820245743, 0.08178510822887931, 0.10247962562633411, 0.11459256815058844, 0.1903160312878234, 0.11541180419070379, 0.22847468299525125, 0.12688038950519903, 0.10399702670318739, 0.15475608727761678, 0.11026963511747973, 0.21458474546670914, 0.1721549058066947, 0.13741695268877915, 0.15223927875714643, 0.12109221438212053, 0.0861423412071807, 0.13960346393287182, 0.0869331873421158, 0.11745510383376054, 0.1401797980070114, 0.13193870522081852, 0.07167912301208292, 0.1371278560587338, 0.12705804354378156, 0.13412934195782455, 0.08633220209074871, 0.12343586076583181, 0.1824943817087582, 0.09613613744399377, 0.1203653405287436, 0.08595874320183482, 0.20677102117666177, 0.15501573548785277, 0.11614144646695682, 0.13569202167647226, 0.12172767599778515, 0.11620552731411797, 0.0946117542417986, 0.07555578356342656, 0.07919896021485329, 0.2614816932805947, 0.09296615754387208, 0.11697767302393913, 0.14832280177090848, 0.10831415147653647, 0.1557974349707365, 0.10645557620695659, 0.2375364638864994, 0.09804704133421183, 0.16643455704408033, 0.058897239954343865, 0.06365028276507344, 0.10179649692560945, 0.06255679644112076, 0.18475963015641483, 0.11720713999654565, 0.1067791288452489, 0.12072060789380755, 0.1443534397653171, 0.11245859587298972, 0.11932678839990071, 0.15715014881321362, 0.05311455757224134, 0.1741612795740366, 0.1545350748513426, 0.08315513149968215, 0.08397028275898524, 0.13341130263039044], [0.008497259263614458, 0.004517405410297215, 0.042431006740246496, 0.010242153624338763, 0.029101379681378603, 0.04452658072113991, 0.03980916439156447, 0.017401687035869275, 0.029735969379544258, 0.017756214797762886, 0.014889696114031332, 0.018848515381770473, 0.020776704951588596, 0.023564252337174754, 0.022348343028819988, 0.04727291388969336, 0.03476345585659146, 0.027543110440352132, 0.05525638728535601, 0.030421954712697437, 0.044459320937416384, 0.05938824824988842, 0.049871055010174, 0.045678159820714166, 0.03310213750228286, 0.013129261605042433, 0.012523861635210258, 0.07665284576692752, 0.015314448857679963, 0.013805280106940439, 0.02165201342930751, 0.007322520067516182, 0.03479639533907175, 0.048940909028585465, 0.09781453452472176, 0.009816433968288558, 0.03033645251499755, 0.03779142516266022, 0.07182434986212424, 0.03733289833845837, 0.026116432888167243, 0.054674546899540086, 0.04084567413000124, 0.03174701825316463, 0.03078060457482934, 0.029433376687977995, 0.015899977081322243, 0.021896489596526538, 0.01059692565883909, 0.07849760606352772, 0.06038815780941929, 0.07827383878507785, 0.0509832044398146, 0.0027055398552745047, 0.048450714975063286, 0.011818651708641222, 0.05429881152563861, 0.050571052091462274, 0.046700450857835155, 0.07659276827637639, 0.006370043074379542, 0.03669688032407846, 0.009514073674966182, 0.043787289676921706, 0.03756551371355142, 0.016602433852053115, 0.04829716928569334, 0.015493392112797924, 0.03846115279676659, 0.021815268954794322, 0.0192734716859247, 0.020120620960369706, 0.034446814097464085, 0.029572425476674522, 0.05965301261416503, 0.0407470931698169, 0.015895261262942637, 0.05862039766673531, 0.04273410833307675, 0.027425237033250074, 0.03441987964989884, 0.009812472171948423, 0.025202062845762287, 0.015538289078644343, 0.0462442344453718, 0.024274390124316727, 0.03192584615732942, 0.03179745376110077, 0.024149955283584337, 0.01995529929575111, 0.08114154490509204, 0.034224604056882005, 0.020416121264653544, 0.02207282218816025, 0.03287529306752341, 0.0035853446877029327, 0.05680843436026147, 0.03618730052507349, 0.03480649533282433, 0.039243568134094985, 0.01670292828099004, 0.062338871349181445, 0.027371264661529233, 0.02775042494093733, 0.02872239412473781, 0.012850963011650103, 0.010322513374766069, 0.05797061896217721, 0.0457694634928235, 0.02267458945113633, 0.027741863525339534, 0.02888346476746457, 0.02624565309711865, 0.018442320570881878, 0.018288143843944584, 0.004041636163102729, 0.04192326916381717, 0.021064198542652384, 0.016948909099612917, 0.035956476482429674, 0.03620445728302002, 0.00932916100802166, 0.027152113117543713, 0.05314442668376224, 0.0276882880966046, 0.01458963266174708, 0.025146573948274766, 0.022730850182207565, 0.046462732899401865, 0.13635762381766522, 0.034129045970205746, 0.08662101373608623, 0.06480298484010355, 0.03640470653772354, 0.014749271595584494, 0.07377286494842597, 0.04662433619211827, 0.051421877329370806, 0.053449509598846943, 0.11058305044259344, 0.01811805377448244, 0.08754440490156412, 0.017909636654491936, 0.02230284725581961, 0.029329655825027397, 0.03686373887051429, 0.025545335408034067, 0.042289125067847114, 0.0920079711026379, 0.060603633389941285, 0.02800361010512071, 0.09250639578593628, 0.04295669835326927, 0.03161572511973126, 0.07914270966180734, 0.02730927030955042, 0.026894200260617902, 0.029426686332694123, 0.03574170997100217, 0.0081838201897751, 0.024432772072032094, 0.044797126203775406, 0.0374274657640074, 0.04023368304063167, 0.05740045277135713, 0.055972964369824955, 0.05301083670929074, 0.08872603970978941, 0.03367156408993261, 0.02611533196509949, 0.03836827492341399, 0.06060336197593382, 0.014872466413570302, 0.005980030899601323, 0.046521066554955075, 0.08089258362139974, 0.019019962521269917, 0.03897085473207491, 0.014799172757193446, 0.007113615674565413, 0.05062181668888245, 0.058579624497464726, 0.013401919876092246, 0.02531435021332332, 0.0314357742401106, 0.01893089122937194, 0.028223384204985838, 0.050318291011665545, 0.03386939775996974, 0.07027548511645623, 0.01606588567873197, 0.06969410952712808, 0.11916909686156682, 0.020680286821776202, 0.03313808628757085, 0.045050630279417546, 0.023302895915029303, 0.10859858657100371, 0.021754017598660927, 0.0035730258844393703, 0.040380504447966814, 0.0315781512430736, 0.04216170636937022, 0.07112469204834529, 0.021187398449650834, 0.01128063365883593, 0.025553476131920303, 0.038258148689887354, 0.024463033037526265, 0.0427019016684166, 0.021132579605494226, 0.04652323108166456, 0.06736554697688137, 0.02928961208090186, 0.037622897420078516, 0.03461793723649212, 0.04674945126420685, 0.04237386730632611, 0.02626765120242323, 0.06238360716296094, 0.028249054881078855, 0.01186131120526365, 0.02027603771005358, 0.03400141353319798, 0.029549341715340103, 0.03857564540313823, 0.04614121247349041, 0.08774801968996014, 0.05069161080090063, 0.014289640455639787, 0.004657259959328387, 0.006635853230753648, 0.033875392616859505, 0.022267056229923452, 0.015481706043439252, 0.03706555214843579, 0.011448770395613142, 0.04240245398666177, 0.020244224595704248, 0.03136168500142438, 0.031271500912095816, 0.015278664617133992, 0.016416966482730846, 0.01118016297862466, 0.015419092528255922, 0.07104434671678714, 0.020828957237037163, 0.04210894009364503, 0.03678716280098472, 0.05340742685699037, 0.046402906466807635, 0.07689434995076486, 0.041885383161050935, 0.08055766552154507, 0.046223647692906, 0.01637586422397622, 0.05849626647042377, 0.023605846533817903, 0.08204076665320567, 0.030344466013567786, 0.01430915851545121, 0.04975071343194161, 0.0954545150910105, 0.02511234694559659, 0.0280157151698534, 0.0922631545524512, 0.041086737266076465, 0.021100289820294296, 0.03319958870166114, 0.010962432117334433, 0.024577566355999027, 0.08711761994553463, 0.04938597032534225, 0.01419225032441318, 0.0009173663046177742, 0.06546926551631518, 0.04705612873658538, 0.017235184720318233, 0.027305036251034056, 0.0075623185839504, 0.021938660547935536, 0.020050261967948506, 0.028222022045935904, 0.048156013645763905, 0.08259506190993957, 0.019681564698527967, 0.055455584810780625, 0.07613841444253922, 0.04347363007920129, 0.011971961607092192, 0.02868581090920738, 0.023643824138811657, 0.05223365966230631, 0.007038834754244557, 0.060269631312361786, 0.03660372764404331, 0.020572515104764273, 0.020804694521107843, 0.02714397748267012, 0.055944754276424646, 0.004970855520306421, 0.019851491919585636, 0.04420875831108008, 0.0431667320829417, 0.01074846797356648, 0.08798343062933002, 0.04493355584729995, 0.05197385538901601, 0.017902880142043744, 0.012591841514222324, 0.013723471684248319, 0.02725038873696966, 0.029437468254140446, 0.02568736975081265, 0.059237138501235416, 0.02456142400790538, 0.021426144388637373, 0.05187264849830951, 0.013992742369217532, 0.055463126727512906, 0.05329221500349896, 0.013971426191606691, 0.016281169573111192, 0.023121798311227133, 0.06353248230048589, 0.03062418189698032, 0.024753417187769498, 0.04138530624498214, 0.033346525459949455, 0.05810286543731179, 0.048885815377746306, 0.011609226964148027, 0.0364561327067869, 0.04404810157471469, 0.008221731637604535, 0.006032954510633967, 0.04925296389098678, 0.06901358640087502, 0.03818169475666114, 0.037558151608599086, 0.02933456502588732, 0.016844360423939567, 0.007915820061628307, 0.10665956418961287, 0.0293972277348595, 0.01745117429111685, 0.02102854322375996, 0.014813891878085477, 0.008643017915476645, 0.08630664846194641, 0.049624370211469274, 0.07502166115279708, 0.08098223166806356, 0.2220531768564667, 0.07724513898470572, 0.13793002015777997, 0.0787563653928893, 0.15563654074711458, 0.10543121224535362, 0.1607072465121746, 0.11701069053794656, 0.12739239845957073, 0.11083846459431307, 0.1731751374900341, 0.17842925127063478, 0.10816040901201111, 0.12116567258323942, 0.20868945680558681, 0.16932746395468712, 0.11231597459742002, 0.14086168498865195, 0.18056507594883442, 0.15290055184492043, 0.12485387681850366, 0.19172906689345837, 0.09805899712124042, 0.14407557967518056, 0.10941071834947382, 0.193925837587033, 0.17958725270416054, 0.11729849795145647, 0.07473430157239948, 0.10982676209615809, 0.07328521540122372, 0.14987595485789434, 0.10633222532591649, 0.22372556211692946, 0.14275063148566655, 0.21005937829613686, 0.11817554517516068, 0.07011149677314929, 0.09885797210569892, 0.13454866302864893, 0.1150423554437501, 0.11189686387245144, 0.15637720243207046, 0.08310945252222673, 0.11375670121716601, 0.16577707018171037, 0.1327824770872082, 0.10626987474305288, 0.13825450917439802, 0.207087476338659, 0.17426943805600914, 0.09401126432099513, 0.13353794440627098, 0.13138496636279992, 0.11127208239798035, 0.18122021508003983, 0.10196385080260889, 0.09296038321086339, 0.11109522903071982, 0.08854866387056452, 0.12057660919214998, 0.11374484721039023, 0.14446964567261084, 0.1539833037448781, 0.08778553589114121, 0.11178880717073168, 0.10608960834464856, 0.08410707541874476, 0.2641924135386944, 0.09810533427766391, 0.13664036935993604, 0.16473118987466606, 0.17468683208738053, 0.10302696589912687, 0.16317746681826456, 0.08977419310914618, 0.1508753690868616, 0.13127862635467732, 0.10968032745378357, 0.11396250767367226, 0.13534545313034738, 0.2015895377844572, 0.10644681631986584, 0.07559058562453304, 0.12400603374200207, 0.3071358634957245, 0.09151558538100549, 0.10432566156876938, 0.1963183656334877, 0.1986188300486122, 0.1390310110790389, 0.2639491180224078, 0.07056817798210041, 0.11063027647989136, 0.12082306668162346, 0.13092509603926114, 0.18219421138720854, 0.1342155294758933, 0.16891286548759255, 0.1174245968993221, 0.16043652461043426, 0.07282584719359875, 0.1566200501152447, 0.12376226325120245, 0.09916351642459631, 0.09877592365124396, 0.17229671962559223, 0.22902565343039377, 0.1291266389723335, 0.10226760378905705, 0.1488794990416084, 0.1641929487564734, 0.06514581465827567, 0.11120832046227795, 0.09280550759285688, 0.12580839917063713, 0.13530087337962218, 0.13709874690643378, 0.12843641958066396, 0.08354545876915966, 0.09405456842588526, 0.1489473661141736, 0.24425235922847474, 0.15562545348490986, 0.11227428540587425, 0.08890890489731516, 0.09968980854111058, 0.15401777332382544, 0.2654440120926925, 0.12238482359264578, 0.1678091332848583, 0.2063333253775324, 0.1408698409795761, 0.09489425551146269, 0.15957075463874, 0.13008444543395722, 0.22091167739459447, 0.15385515562125615, 0.14831875770219735, 0.05463120886789901, 0.16228090492742403, 0.1415148563683033, 0.12739816600722925, 0.1187072859278747, 0.09630296206367867, 0.09712358910058226, 0.11024708739881005, 0.19589246277298245, 0.1823858975299767, 0.11842061845319611, 0.1961925516703299, 0.12706938864929335, 0.15607103386095592, 0.162816391193441, 0.08529469490583454, 0.11181365512311459, 0.10497148441416876, 0.14591062335031374, 0.13712907742176736, 0.12956787672426018, 0.19529109075665474, 0.1447962788598878, 0.09792146485831056, 0.15580329751329763, 0.12005325513226645, 0.10529945431543247, 0.202700530311891, 0.10134365622486387, 0.12607589124568871, 0.15297991330070154, 0.10580563465399401, 0.06937098436589752, 0.2009714330945696, 0.15506688345755848, 0.1561893160854067], [0.03807817066886595, 0.04702605267188378, 0.03553946243066873, 0.041841685505849976, 0.044238291547766755, 0.019960698738162006, 0.04771282171298351, 0.03098847038511719, 0.01877466871935342, 0.04862083388226373, 0.027783523879147003, 0.06108115240931511, 0.04992590778108154, 0.04204981933747019, 0.05476427297773106, 0.06300034121211086, 0.03498606284015945, 0.04913901750530515, 0.048305881675332785, 0.05540403650541391, 0.020855028248791183, 0.018532662419602275, 0.013141601612525327, 0.034386967308819294, 0.02860760296295796, 0.020321564017129794, 0.03797731322369405, 0.047223312979830165, 0.015193610252546412, 0.042847718843924146, 0.06490865988390786, 0.04106435578848634, 0.08265796889151845, 0.024213983544281552, 0.033484871964901686, 0.05411106767132878, 0.10501202009618282, 0.04111425864643284, 0.044562325945922306, 0.015338421499888812, 0.007787971341583345, 0.03444706854809608, 0.03944181910316859, 0.03699241964412587, 0.024888885007905107, 0.036090761955295286, 0.044714884366840124, 0.10941081334437643, 0.04112372760261808, 0.05410898456882153, 0.045567405942295275, 0.0535608843368079, 0.028169444063678384, 0.07054565740483147, 0.02234025319506015, 0.045811519093279324, 0.01942993507587484, 0.009286897606216371, 0.018707814360303537, 0.07100501204175608, 0.019584373038794314, 0.0052068427903577685, 0.05913730564394167, 0.03048044103862984, 0.09640826391322271, 0.007044246071018279, 0.01711458869145385, 0.025431672310722724, 0.034281197270112376, 0.05469765440960016, 0.028587012817817073, 0.02351367942589734, 0.020655571183721935, 0.03237212881711977, 0.021404056377442818, 0.04685942482735429, 0.03078506254990186, 0.011034572264179587, 0.05387344131512301, 0.025980959979018996, 0.003261245828720608, 0.0301709578239492, 0.05904829542019537, 0.05777224924947534, 0.05083668837323785, 0.0468113268725574, 0.016172514064237475, 0.034708589514983554, 0.0291783425158688, 0.010790516788672124, 0.05657140172219702, 0.04946379829198122, 0.010498342154148434, 0.07289196364581585, 0.01961996389685997, 0.07314245841865029, 0.016797341339822327, 0.07107923698744603, 0.022134400937440138, 0.037466820795089006, 0.021205062412523797, 0.05501088992293392, 0.057326831721833775, 0.011497294131134237, 0.02508090532916997, 0.039729032798537185, 0.04560486786067486, 0.027294888759830167, 0.019896314246580005, 0.02542240352236799, 0.06504556110927037, 0.050820949753480296, 0.02161889074237219, 0.032548554707318544, 0.015850520360150507, 0.02705092658288777, 0.03182460194719689, 0.03690715154100742, 0.048955704484667094, 0.018194312628890787, 0.011663078895903059, 0.025867941489975368, 0.007776504099768187, 0.015540801354550889, 0.02995128889701196, 0.04595925313021455, 0.011139245620662612, 0.02804451558871993, 0.027481908278007592, 0.03695903232853327, 0.05390493891068867, 0.01563389296643436, 0.032057295353817086, 0.09052037128380366, 0.034609998376773934, 0.03170889476314187, 0.0631109695615513, 0.01243177764782948, 0.03701166968260493, 0.03935594031853335, 0.0019779611736469504, 0.020420675930966223, 0.01224254016830985, 0.011714413462738906, 0.03940500857840691, 0.036675262198384316, 0.053596514210637124, 0.03213547955134085, 0.068784065145467, 0.026389441452920437, 0.033659750795257945, 0.02197051776706108, 0.02237537586396294, 0.053416570116366656, 0.03232554738808956, 0.045929363662643094, 0.02135486258859081, 0.035840640376721106, 0.029043890801923614, 0.047779711695121865, 0.04223044875210949, 0.061956394729869704, 0.06331006530672312, 0.02203095657750964, 0.04413894384301134, 0.020635858045092652, 0.02139298607861357, 0.042850690827305825, 0.03219250702698316, 0.03389360449676003, 0.028683066235056946, 0.05995070628289666, 0.029651512125773088, 0.09281082730740309, 0.03963737628821816, 0.07598765074674572, 0.049978226223694425, 0.06126006852303233, 0.026775524485856295, 0.002643691812409088, 0.08155764971992799, 0.024072198563122323, 0.03566567333681243, 0.02611212758347392, 0.07803869925971542, 0.063111722735422, 0.023153002440397228, 0.03737917442673019, 0.050959421787410975, 0.03149597386696509, 0.01820387827631618, 0.05470800546130963, 0.024429737324161187, 0.07643660344183445, 0.0187903683233474, 0.05965996081275599, 0.016444784722157886, 0.013968007223281478, 0.08442260777311665, 0.018428179901093245, 0.04652122940335955, 0.06510572002402373, 0.04106864073712911, 0.0227804086836321, 0.026588331941249113, 0.025800846250993863, 0.08562778096113886, 0.02824587933719158, 0.03231546435771244, 0.01514569210952946, 0.022089064620169144, 0.07416182836251599, 0.07747408348534789, 0.07415011006274394, 0.02579564697641347, 0.02347630062805755, 0.05835480548973594, 0.02549643169290253, 0.01809159430143024, 0.03346637849296842, 0.02609362393351538, 0.057647100250635824, 0.041535493186009784, 0.047507927886077335, 0.04116200376302004, 0.03262094421578305, 0.018927590156506215, 0.025279385303812366, 0.019317476378221596, 0.03566791589504906, 0.02180343700040664, 0.04421031215627279, 0.02459151025063225, 0.0013869005571385579, 0.029517050233802626, 0.026742461170735102, 0.03262236913932221, 0.018910099220063006, 0.07370775951338665, 0.012852800145213093, 0.0019366324538298482, 0.022106509755498598, 0.059550357051193714, 0.025984211858095865, 0.04861420798780663, 0.006661931027857853, 0.006233836075157991, 0.01357653662229755, 0.03302121880863394, 0.04706366386796747, 0.03466858648295913, 0.0313490235379764, 0.0352042186340051, 0.02015439504092293, 0.08955322139497314, 0.037736657208630016, 0.04649262236697333, 0.018891721099082912, 0.06816229636647872, 0.004516625519110156, 0.03381386645404356, 0.01050888149932559, 0.0417296695522964, 0.02343022640395377, 0.01935820883539106, 0.013072534381145877, 0.06512261554598808, 0.06950732919254474, 0.01030289607920817, 0.017693392633061324, 0.02309738122858107, 0.031170840242079327, 0.010836464635628675, 0.058020844124257565, 0.05777205925967012, 0.012168964071731483, 0.020284295481230532, 0.025017788001735295, 0.05872857650475843, 0.054931474184351306, 0.028964196863983358, 0.017589866848928586, 0.05121056116851313, 0.03853568308321493, 0.01869107999040612, 0.02005725766399077, 0.047012101991900375, 0.016810835705005696, 0.03763111787182944, 0.06616855692118406, 0.030598153293664967, 0.041858143372727294, 0.05970342776605061, 0.08090105852378265, 0.05394740502483078, 0.050571537244000604, 0.025102250344519104, 0.019525608513504267, 0.02133963456643479, 0.01219181967566588, 0.022898721442158734, 0.05817728715815714, 0.026093615451827645, 0.0338472809110369, 0.010813888927389468, 0.04388188085119639, 0.03707441720845444, 0.019481717475822995, 0.021363697114533613, 0.02487298014706799, 0.028224188268982937, 0.03318825377417462, 0.013721773650364151, 0.04074929840862751, 0.09765147577439036, 0.03771062521263957, 0.03408019144886306, 0.05416102820475187, 0.05736074490206582, 0.021944328011678796, 0.06624451213117157, 0.04525339011369007, 0.06101824542773621, 0.033381734642067125, 0.026186829200014472, 0.032731084020010064, 0.07892569380679301, 0.052166661114564965, 0.03247380728966423, 0.04254121100530028, 0.013292174470344824, 0.013778254057147672, 0.057318485741104395, 0.019317910640633533, 0.017785383321877037, 0.017598128012780632, 0.022222953150048852, 0.03475637534367187, 0.03745402701731239, 0.012956135939540607, 0.022564246086403728, 0.03268279946808304, 0.013159060318555151, 0.0868552779512746, 0.08773323441190378, 0.0728886184681739, 0.007789706694893539, 0.06142544107777732, 0.014959011858861362, 0.021837546955794096, 0.029624540358781815, 0.09355245251208544, 0.14829570108226367, 0.1475037285791976, 0.19094207483742917, 0.07888108691466705, 0.16344277401055607, 0.0928594172000885, 0.1203500327787229, 0.13550387748650142, 0.12373809383383819, 0.2771439642778465, 0.10432090503828866, 0.14441304228135518, 0.17579851672053337, 0.1020216823422483, 0.22407441054071697, 0.16008002231163637, 0.10878563831959452, 0.18558502729449952, 0.13289288830544266, 0.1454454604536295, 0.15298498874264105, 0.08357348905078002, 0.24624005971210344, 0.0970543920993805, 0.13468692132404872, 0.12883397324809007, 0.1724279754395996, 0.18286319263279438, 0.09108252397605351, 0.16934445447155408, 0.1733119980032955, 0.2050114305956023, 0.10199737043253013, 0.15340562617140158, 0.09172926962907825, 0.12745177027370247, 0.18495750453855309, 0.17021373925464495, 0.17178918900234358, 0.15757204831710883, 0.2239150633769376, 0.10351925662585668, 0.1703992642994438, 0.12060468697122165, 0.08487875972475324, 0.12202254017548901, 0.1722200180270842, 0.19806285202503204, 0.19260113367012568, 0.12801477792007582, 0.10528221952595881, 0.11364973017147609, 0.07466345573110239, 0.1016799992482577, 0.1938271785953215, 0.09146747046283313, 0.12173425778746605, 0.0862730677638735, 0.256468052310603, 0.1386901829391718, 0.10973541092659746, 0.058838662026183944, 0.18186658753880433, 0.076169952750206, 0.13655766951186316, 0.1253951306321791, 0.10466108178453785, 0.09441766608506441, 0.15870529679315432, 0.11363232574824776, 0.10387132809098278, 0.06396354881248303, 0.07847024753157582, 0.09702965271260057, 0.15457904392055102, 0.056185067631304264, 0.14120946132711001, 0.17406452048037732, 0.14739527154181684, 0.08132207593215363, 0.1394864030714546, 0.11176768437560115, 0.10200683599604027, 0.12878442662102835, 0.187112260343773, 0.12218697635190827, 0.15742914884218148, 0.16663021940205777, 0.10345649213663169, 0.12532803708953516, 0.1969143772231681, 0.1649746618100575, 0.11139731960637228, 0.18970241849975927, 0.1059613720114742, 0.11117379660052912, 0.0672861108822482, 0.163904978494559, 0.19149045326880046, 0.08105469920805522, 0.16183157903807505, 0.1995849824909653, 0.15124443785420486, 0.10963700299284287, 0.1171145471079009, 0.06749494360493762, 0.15906540889825138, 0.09094824189586298, 0.08566746168902942, 0.08892724569886923, 0.0962439091610057, 0.17096292333943502, 0.1413282049553735, 0.17984588311186858, 0.12264342685895306, 0.1295804160514048, 0.22358137342546666, 0.18659394101372787, 0.17376341378050192, 0.07579052275312798, 0.1393846363893577, 0.07717159257403441, 0.09853706575397934, 0.12246615279998098, 0.06391782912292651, 0.19296910321073873, 0.09682588186115026, 0.08163426989423377, 0.0969775819352695, 0.19217095603900297, 0.2191108725965023, 0.0701018480051841, 0.16568928132099764, 0.18213445959346636, 0.1073520431028945, 0.07789955208344118, 0.2773580827883312, 0.12248922299061503, 0.11898503745240824, 0.08712669874408416, 0.11405486986041069, 0.13819414669913904, 0.18495544179209641, 0.07242291274347476, 0.2327453824026244, 0.2043157693530832, 0.12762774154543877, 0.10481103802365915, 0.15269695062722477, 0.09867436731500284, 0.1638880151190928, 0.12737091604088033, 0.09586674547088997, 0.10637141750859362, 0.12451215301241193, 0.13534220973295824, 0.09892041768346514, 0.14035310942147458, 0.13426555107746804, 0.15157537295350007, 0.1320708974131516, 0.10008503483342272, 0.12338194437325001, 0.059125024160104137, 0.1085669125563332, 0.19842532543199404, 0.15022888806249413, 0.16847264553819383, 0.1304406084652458, 0.2075607002313648, 0.08893411925860814, 0.1866077288453068, 0.15600749584180967, 0.1715890211718423, 0.12404901215008327, 0.1770712991378137], [0.02474335960245558, 0.05184520175680518, 0.007979143494074898, 0.013213439811287182, 0.03367420019848006, 0.058522247576287816, 0.03741889925939696, 0.011182743956201842, 0.04860133957117796, 0.01181241257914475, 0.009365993585171444, 0.0496627142253731, 0.021317293800945793, 0.019297978674460734, 0.0279741956120623, 0.020306855074263046, 0.02339285608780171, 0.019564853282645345, 0.0506371040828526, 0.07229061877088887, 0.017911539945219244, 0.011787820773731385, 0.017835849363889014, 0.004851376529716487, 0.05206886386232717, 0.04725198447704315, 0.008169612514653375, 0.0028701717466382043, 0.08984661993703671, 0.1779617135013853, 0.02744431743797447, 0.04480003033365522, 0.05493664462119341, 0.007554674886965326, 0.03189169888251594, 0.027943569933995605, 0.015724750501768928, 0.02881156380421349, 0.04453536096428122, 0.08132662890212876, 0.019880960695445538, 0.057964871770569255, 0.042293542330818515, 0.0339439212610679, 0.043335778904812675, 0.06503117616687502, 0.003335373447043821, 0.060624023367251666, 0.010911455477720924, 0.0447947207971343, 0.059885974042117596, 0.05441618112048932, 0.022008902493066022, 0.023793978849425912, 0.03807665753577437, 0.03944565621869905, 0.0008559513049216808, 0.017548445678715194, 0.028528631664812565, 0.02548476597959442, 0.013730586123918849, 0.03008461424282619, 0.017953780446467654, 0.043124137047146044, 0.05831583043826478, 0.04820595043046134, 0.012473004587393786, 0.05428392786000456, 0.06909697156931673, 0.03751531230019672, 0.04064874291153891, 0.023094556826565946, 0.005802510023516203, 0.04275879343705518, 0.03974165354988404, 0.03293854270928672, 0.04122918212254133, 0.06116191164723464, 0.011060932501485305, 0.04603912348725966, 0.012921851261385849, 0.015048491968108075, 0.04394926955657346, 0.05433529635359134, 0.0439607944738652, 0.02922806895471045, 0.012116307209778045, 0.0469417039837156, 0.03263215022161603, 0.04334543106545295, 0.019983645096155148, 0.013440957692052637, 0.05805739002036197, 0.054501686710864305, 0.06194751949182578, 0.03548868086987308, 0.07401746325194836, 0.0016171060727044407, 0.023778114700689912, 0.05417321469368679, 0.04333393668223705, 0.0072925983695313334, 0.03422774228134325, 0.08031109946646861, 0.025504667411691377, 0.0018647194041737489, 0.03411123103329113, 0.06210430179323469, 0.035984374449721405, 0.021492606893713986, 0.056321449777377505, 0.02466761304198631, 0.0262499702761748, 0.02010234970865505, 0.05303629534319043, 0.048792693231787, 0.02553413449121373, 0.02611008858574288, 0.0255419563036412, 0.018147860121514117, 0.011472308775410056, 0.024503164991204227, 0.019055853631081324, 0.018981626989053826, 0.020140130538493395, 0.04982596975085991, 0.053037760978830714, 0.015478591567703655, 0.007937547601094204, 0.02845780617956604, 0.05068523596440043, 0.0520457020694656, 0.03725443933425205, 0.08701687106596571, 0.027755001659638116, 0.012527069409510918, 0.028655358257570436, 0.04492937946426017, 0.035054493096790144, 0.02569482515433005, 0.043262222316116095, 0.006974941352382302, 0.0474349005546953, 0.0171284426801971, 0.045679862943610976, 0.02301663556136191, 0.03741921138550554, 0.0788486868675266, 0.005147950191582952, 0.04581324935757688, 0.04222339877326574, 0.009707255139281707, 0.03594696681414332, 0.03517814253323844, 0.04542413327310767, 0.0700221744232944, 0.046418662049940655, 0.054927002638578415, 0.05884022265672684, 0.023906240771923746, 0.040323076636663506, 0.027189685297863822, 0.019922212231904268, 0.04313076972695334, 0.025564926410359994, 0.007191505981609225, 0.010411501546124262, 0.03420385106333664, 0.07309432314442736, 0.08353729599288531, 0.0055047523180421975, 0.06773946048425776, 0.01517027712959264, 0.025221943921808685, 0.03093884911920343, 0.04418479245422142, 0.03983175621501037, 0.06348421131925923, 0.03858526363702757, 0.05286155900518809, 0.04722901267398681, 0.03717351724792804, 0.0447463242869292, 0.017483036599255035, 0.006935865368827113, 0.02658433367365173, 0.029381546790578535, 0.014688669936731458, 0.00997920349306826, 0.038260601593979766, 0.004418119197777871, 0.03538824750908783, 0.01702022991542305, 0.021608349700857486, 0.04668554344347545, 0.03680157827745591, 0.04862708318978548, 0.04384802873911602, 0.012555594173526126, 0.024571498556594764, 0.04494823595242841, 0.03323401417583227, 0.03938206052407622, 0.01594733712928636, 0.06388133750962359, 0.021837608023945774, 0.01505522642816816, 0.03744038167808737, 0.06548606604337692, 0.017556077501337444, 0.025768349512613246, 0.08177320672465221, 0.032128219226641316, 0.024773454326870184, 0.04045327054336667, 0.026516166349340762, 0.053582994400390556, 0.05938671476074627, 0.04136834626219102, 0.05449589202180505, 0.03051332284563354, 0.07291761905487094, 0.011168171568507594, 0.12667457626334258, 0.025957521683137332, 0.010238010319881141, 0.060306387554321966, 0.04375349524031792, 0.04522112238087824, 0.023874990841639892, 0.03745385059820754, 0.03101889250267829, 0.013131852760644895, 0.028979097492992878, 0.03776977650289025, 0.02734391630760261, 0.03320349367069347, 0.024160143486889343, 0.030947826137500148, 0.03479143524808543, 0.03546165142740522, 0.013043115647243602, 0.027559795616460697, 0.04025760818538921, 0.022788895460377847, 0.03975951259157487, 0.05375327276332038, 0.019186111998611262, 0.013180561396958572, 0.043911712643291266, 0.052837834028261046, 0.034750699398240874, 0.08969257213175297, 0.044429407721119266, 0.0671600526464837, 0.0433763315502022, 0.03650291769632271, 0.013543741328508725, 0.03818083640986255, 0.02674349763297609, 0.00971619738265872, 0.0017456035358398886, 0.029081081306295734, 0.023961083364806006, 0.0223469316759812, 0.015286968189424701, 0.030489716612334763, 0.00583882352137672, 0.05031353108850973, 0.04306347601647888, 0.04120778112805315, 0.04782229655289224, 0.016892312493707453, 0.04325936229101249, 0.01055760625084596, 0.0707852141931653, 0.03587830924828138, 0.01673040216389511, 0.05936018404151712, 0.051732439414731095, 0.014241564553231001, 0.01558699262594538, 0.01745560851746372, 0.04144089522638491, 0.020322956710255573, 0.05699227324553898, 0.01472736000349479, 0.012214470022757138, 0.02698722910801215, 0.035882472060620785, 0.022836316576493636, 0.026459059145833765, 0.02339655749632844, 0.03722124540113977, 0.06497150579733507, 0.03737755612071071, 0.03642955788278154, 0.016698656903047646, 0.04102779632168157, 0.05258329857939056, 0.06549485307186842, 0.033999252399163585, 0.05673265217670372, 0.07365799575511899, 0.04060486205188291, 0.04593581313799534, 0.043308820708521774, 0.03217155386560729, 0.04679596144706011, 0.07606425056500093, 0.08103979179369551, 0.010404806949996522, 0.05318217358684965, 0.012844785798474081, 0.06679841383759465, 0.017369953649384633, 0.066635782564325, 0.04105126345530152, 0.06321780490023748, 0.07926204361553703, 0.05013816710561514, 0.03167744127235242, 0.10904274880886078, 0.028665861979659115, 0.06183407522205796, 0.047667017206549644, 0.03198733160804425, 0.011144918173418512, 0.016739267223913754, 0.024910438672772477, 0.015549554456291454, 0.07402250476713691, 0.02653622384449201, 0.0520430456048676, 0.017247647712273256, 0.05791754395301853, 0.04350632528907486, 0.04286087563793574, 0.012995874342907752, 0.023534914179305946, 0.019916439595233117, 0.05971360579133034, 0.05917639604636601, 0.031264749488660266, 0.037261384140167914, 0.039555239624210765, 0.014159617879028832, 0.11664515015270029, 0.006644034242656614, 0.03058047406375408, 0.02115369731161211, 0.04443805904260703, 0.17880857948745998, 0.13788674319429056, 0.10397536108004195, 0.09352584036865405, 0.16835635820669786, 0.12358709265078817, 0.11575462722352572, 0.08409609672214303, 0.12643977600548947, 0.08863496673958642, 0.10905414141182389, 0.15128513638462338, 0.07377322457198586, 0.1184913625142404, 0.11738758959940501, 0.11176657157817058, 0.17100495179849012, 0.08252806336219821, 0.2602911628782749, 0.15655176235096796, 0.22018378573868955, 0.06395585422537156, 0.07176405524036714, 0.23540108704141208, 0.10513416318488972, 0.1228617929986545, 0.10905562061816454, 0.09382710313158375, 0.2359253503382206, 0.2263461457831519, 0.10094165136771542, 0.1438288236302989, 0.19861610233783722, 0.08959950426859514, 0.16268417185970716, 0.12264003418385983, 0.13572590771530355, 0.1508974621870688, 0.14583495312503406, 0.09281610630984817, 0.06548609997012786, 0.12519550562969275, 0.10638387541153602, 0.09855910457138504, 0.07718695460685662, 0.19174628811223166, 0.11105339734682015, 0.21141397846596582, 0.13446190554116452, 0.2137148500021015, 0.16179503314197063, 0.13702490872570447, 0.09341999569109508, 0.20742508822253772, 0.1205199650887932, 0.11628503804760319, 0.16613602877727576, 0.13652724400162697, 0.09262762285236802, 0.15578475993658814, 0.18197902079139436, 0.10952818633190223, 0.0607435405254364, 0.10748570771621806, 0.08383087773940393, 0.16557146050035954, 0.08913934217499835, 0.19511019332068308, 0.2855660766363144, 0.13629673208509172, 0.11530682125261851, 0.06647275774074451, 0.12523667913462433, 0.1276950929313898, 0.09346805632646595, 0.12081363504486424, 0.09380235017410346, 0.17446948375020707, 0.14107318435396465, 0.10742310607539755, 0.11857338382729463, 0.14485774056187697, 0.20941261228706154, 0.10816057864576578, 0.1571096402726003, 0.11197427793272904, 0.11813856501664434, 0.15000617929867335, 0.1611820174647229, 0.10325921486530985, 0.09898010840905563, 0.10462404734322003, 0.10359143918114048, 0.12461105627673012, 0.13108204118907452, 0.1496638583817652, 0.11264804963554655, 0.11615139379033021, 0.0851773354890091, 0.1335600239357778, 0.12086130891527448, 0.10387939587235451, 0.1575244694416012, 0.12224006493176733, 0.15403071977198124, 0.15163521974214486, 0.11162855755537748, 0.08887317324323313, 0.056905234166021855, 0.2229333453412567, 0.11680765928966658, 0.09305088621165071, 0.08812234031834773, 0.09745561664125749, 0.11440179124474525, 0.08449003379791975, 0.07089131671403136, 0.14067567139863968, 0.13084626384079456, 0.10249275527894497, 0.11220435558685235, 0.11160892075193779, 0.11162313606057848, 0.15074135842067854, 0.141459175784673, 0.10210452468267509, 0.11376408367816891, 0.11587179665054594, 0.11501161780740533, 0.20600543011512074, 0.20330847054719925, 0.19451661088636943, 0.13626116327941418, 0.1400622757417815, 0.09883982129395008, 0.06795011168079716, 0.13473574870399066, 0.11102215759456158, 0.14902058004268579, 0.07511968232159104, 0.14028882501380785, 0.12858383809881552, 0.1682383066841534, 0.17343888405178273, 0.11789996496268682, 0.07078910898417234, 0.16359981415527208, 0.13777425565889903, 0.10005901980080775, 0.12334410926061017, 0.10548214308385338, 0.06892169240329947, 0.14406905216830118, 0.08740968855896167, 0.1527452894619533, 0.1616541828427996, 0.13191053244684423, 0.18897804165525095, 0.20805480943194457, 0.19203562901488372, 0.15736661505486282, 0.07824974400656563, 0.09695061016827822, 0.11823754970516477, 0.06517347174563579, 0.11618148003305707, 0.15167730248400144, 0.07565606425383262, 0.17505098826118878, 0.2401890472642013, 0.05489990873528378, 0.16391917344714912, 0.07921565217631203, 0.09674913276519094, 0.09217810697321381, 0.12787761885140622], [0.06664015911519527, 0.052832141119454584, 0.042472427910459895, 0.05406594169991357, 0.06232648129974093, 0.032838282374931235, 0.019877266072268997, 0.014350471120061619, 0.007892287619012808, 0.03466628624924591, 0.061171037943235466, 0.04585787999842848, 0.055784952494182756, 0.04814405785873532, 0.10048011863338095, 0.056779301459235806, 0.014829956194651979, 0.06297400726803712, 0.07179425683404718, 0.031261716437126906, 0.06675578148237296, 0.06895777689559118, 0.021000168585617627, 0.02202618817266609, 0.019277787168643305, 0.007949971577285655, 0.05287526201988969, 0.020807082964373485, 0.02180352181728397, 0.06732603588274547, 0.018023406621068716, 0.017670570107709085, 0.05924243785973106, 0.07949372939765453, 0.0741267277460013, 0.025393562391400337, 0.027884114999324083, 0.07208908029964992, 0.05391347827389836, 0.07586419130010263, 0.008148433740383812, 0.04596426071865218, 0.05467973429975765, 0.0405154548851507, 0.05281008194599833, 0.03932447325704353, 0.042374997067132165, 0.044951184187084436, 0.052063527184405496, 0.01874037386317338, 0.029067846480756998, 0.0681490038654634, 0.028026571730151772, 0.01566073750810964, 0.061014153861573765, 0.03362654668412038, 0.06701101921498775, 0.02951557102746197, 0.03209617541038564, 0.015880403042371784, 0.012937583095793213, 0.012215962799798166, 0.04280309159574764, 0.06267901416867971, 0.054709006300462146, 0.03361420073945608, 0.04881141401295151, 0.06928128203643219, 0.017082933336496353, 0.07914931180753879, 0.011924818690334047, 0.01651109625319285, 0.02567217904808266, 0.11082808979387794, 0.051711092703044415, 0.02013832563534379, 0.04518062401829021, 0.04749660313661609, 0.0737030233389565, 0.0330146641603538, 0.05086725637582796, 0.08158578856715135, 0.014877831929230263, 0.026862670434638858, 0.01800880115479231, 0.018887356422575455, 0.03564362094870635, 0.026186545911644186, 0.06478603503533772, 0.038384664936789444, 0.036259540755833895, 0.012160244048573077, 0.016193932022101114, 0.029423948443893875, 0.03415973950177431, 0.009995619799675686, 0.048155375822846375, 0.0018588583459079797, 0.06307390797883272, 0.02002484574248748, 0.02756868612154254, 0.02430165875037866, 0.019378539440887313, 0.033017795599464855, 0.031933133623429706, 0.07140238929007735, 0.05119667834203158, 0.061804077188883505, 0.005512873534046645, 0.07316081279090472, 0.026435853248195987, 0.039713243288653235, 0.02188528698336865, 0.024948828487790058, 0.05521234018462045, 0.019760771787592342, 0.03103479736351541, 0.06511970463075809, 0.071918652659016, 0.014759778710348266, 0.04595929044964058, 0.06029117479920387, 0.061805841379931996, 0.06272861507854291, 0.07442729161786181, 0.06279709283262491, 0.03185881368283715, 0.05915380083024502, 0.04376855193238173, 0.011896971613168716, 0.044591733653630526, 0.04853501616578017, 0.05581029238445418, 0.035951149982533286, 0.05684236789654408, 0.02153558699813272, 0.05354875213067446, 0.03351155874718513, 0.036195694003254175, 0.08759876912725822, 0.015508815213771803, 0.053350870963186026, 0.05916769044207675, 0.04496630533997502, 0.11632908854101386, 0.018990459818659083, 0.010222293752511697, 0.015585879828514797, 0.06787972045796258, 0.06309290017400469, 0.09980490843632392, 0.01776841146472309, 0.04581361237381186, 0.05125893732266767, 0.030351119049425637, 0.04693665907585195, 0.01839784768942211, 0.06591283742870603, 0.052415676681058745, 0.030204609768199067, 0.017561117320188453, 0.06678420531430415, 0.0030583555884991904, 0.02161617490596005, 0.039625634239720445, 0.022572687062035714, 0.019902999512851238, 0.019092251945819174, 0.06284033586936337, 0.014226896322465368, 0.030161522794514894, 0.038110282338623486, 0.06258666555264167, 0.04068014890487705, 0.06471237327371325, 0.059557149186730385, 0.062237742490002086, 0.006046171948712851, 0.046598361871604405, 0.10700784264398472, 0.034099207392760685, 0.038909884967974255, 0.03698605837832604, 0.03795320487448147, 0.02025258753980909, 0.01992166940388935, 0.09071261382528714, 0.010163304462496723, 0.041495836206844876, 0.033369951881468296, 0.024857947203729833, 0.016885177697986364, 0.049560299542333396, 0.023309771171105758, 0.03326136252975889, 0.05688904432047691, 0.02421003786314811, 0.053960232729358334, 0.024274765014914528, 0.022988964903301427, 0.018608931452035904, 0.028435158376981105, 0.05278699479198881, 0.049897317708070786, 0.032612106297165155, 0.03677408064582518, 0.038829573563167026, 0.0288712511371289, 0.06029447926474469, 0.033559361539248905, 0.0409941443774317, 0.0435775952147586, 0.027029666384415965, 0.0611847239945616, 0.08409397290753466, 0.038377506392342706, 0.014449248855401362, 0.02400766988284886, 0.008898629690520465, 0.044880691183997054, 0.04082120615722878, 0.11403167753347329, 0.049546026558216126, 0.0761522294155189, 0.06726443847375256, 0.06642252579331398, 0.0586169371381402, 0.04545323903273259, 0.062119860601212294, 0.025822664544518505, 0.036015929720763645, 0.05242319145639028, 0.04143606744972723, 0.039435807282903364, 0.012690875396531607, 0.04733371402003935, 0.05648928880691528, 0.04071244038641453, 0.031993835366197994, 0.08313048032245465, 0.07598737254738808, 0.07587717167500939, 0.04596229975244828, 0.05876508168876171, 0.03205749552164759, 0.025630023363711577, 0.009230037219822407, 0.027007401954116564, 0.04231842760262745, 0.030355889150606732, 0.04117192394499268, 0.00859372828355325, 0.04182727342205388, 0.051649804027484994, 0.03301287282790456, 0.03995944632749472, 0.034068619034120014, 0.11195522466940538, 0.06724794328744922, 0.03550498267369611, 0.033875111024826765, 0.06872439477592707, 0.05382832891440817, 0.04648879203679306, 0.02821316377126745, 0.029673062397965362, 0.03602728500430073, 0.05396448035857507, 0.01152293851399528, 0.0007355859249530892, 0.0693346488156489, 0.013027673038387937, 0.031287249709878645, 0.016505206569230983, 0.023275715498519794, 0.02678643023994352, 0.023070887828777944, 0.06561731507203408, 0.033626621322972436, 0.03759587137028575, 0.008059433694662792, 0.025765881341482912, 0.06489641232682125, 0.08521336569849934, 0.06342591837580715, 0.04068759582670672, 0.02002895936103804, 0.014775437602241124, 0.011385959257105631, 0.012720041376139437, 0.03722448879852891, 0.02786951801473541, 0.0211325931761946, 0.016861381474882364, 0.009548918992680098, 0.07219455856829882, 0.04658077424392104, 0.00914403545071504, 0.04531448879944427, 0.08897482457437686, 0.034066990550075255, 0.009432271189455475, 0.03544380595641477, 0.06276174794350352, 0.031937432142772844, 0.01551487113881324, 0.011445486286122884, 0.03274062082969716, 0.0313670488207468, 0.007477216721911515, 0.019407263524564247, 0.006283472184025283, 0.04609998807843242, 0.08593905890094382, 0.011987209137129997, 0.03601487459880965, 0.016393248291153992, 0.03723107737355998, 0.04167055897414684, 0.021098262696926082, 0.05505532039595502, 0.03039689302178366, 0.01765070260236306, 0.04642183420115283, 0.03633653073172484, 0.1414831687829324, 0.07768602389842272, 0.07736631855368614, 0.09686788996415478, 0.02732613529743893, 0.09758453829480068, 0.011386104293965867, 0.10629584227821656, 0.0125803191414369, 0.07582869034792696, 0.0047969906757186565, 0.03709497681951948, 0.031234619141157185, 0.03386115695216826, 0.02508827930848513, 0.015296591512326683, 0.022924685584647313, 0.0070677789377181655, 0.016849668264122944, 0.004477254372821855, 0.013706794989827489, 0.042641464554305585, 0.03570992399805358, 0.05205786141699978, 0.028704613114574125, 0.10425079201481172, 0.03286377493558185, 0.22200732145990643, 0.16060598194599152, 0.20295200896050247, 0.17866797346089566, 0.13645443719412598, 0.0961692024554525, 0.12186674853520733, 0.131703307852149, 0.1913919299840927, 0.11157107885394778, 0.16418680122920445, 0.14753521260406288, 0.1386170775762626, 0.06886789814702102, 0.1685558067900794, 0.1927097671266113, 0.11686351629240171, 0.11460092770201818, 0.14947181940078735, 0.16218523148979458, 0.08875996646072183, 0.14741448765354498, 0.10828232139881168, 0.11349450171525989, 0.17289499752223492, 0.1854704905833517, 0.1657304683966296, 0.13463874533772469, 0.10009577604276793, 0.10344607662409544, 0.1713031679391861, 0.09721073335302727, 0.11262797856969492, 0.16250593428100857, 0.14474240317940712, 0.09772094418959958, 0.1583931842552764, 0.2737176338476794, 0.20451987268669264, 0.20759238781673567, 0.11088529029595, 0.10267498264355318, 0.13660144859126636, 0.2795633487403393, 0.10505868973476545, 0.187049821551357, 0.12700407286839827, 0.17893961817026138, 0.12167107260652951, 0.1545327135494777, 0.2001378663948604, 0.14018597267568111, 0.18497007100709847, 0.11877599438386303, 0.16729431519550936, 0.150390908654247, 0.1985783079372985, 0.10317097138613462, 0.13633593783846923, 0.11825458093413285, 0.13554840295442513, 0.08177239926798002, 0.12409660459629127, 0.10039453501147882, 0.18290862733764307, 0.1606584462736334, 0.1554373228656394, 0.08940979944808142, 0.13975048890071257, 0.19299309620899813, 0.0957459933789713, 0.10112406193677868, 0.16139734376754078, 0.20467689926070826, 0.13032822949545725, 0.10125161973493439, 0.1793860535004309, 0.10726211685687304, 0.12459658991013255, 0.07852419106555836, 0.12054323883993284, 0.18750613635139807, 0.09205324974443231, 0.19583752857787268, 0.13967105959142956, 0.11006409328963075, 0.15676125325262547, 0.17405397604618753, 0.11541263200342655, 0.09856496032859598, 0.09833877746547971, 0.10442223067262343, 0.0992004219442606, 0.09472728839942388, 0.1636237393000296, 0.06288424387042012, 0.16979824512132577, 0.07581995760223695, 0.09216197819582053, 0.06918205986065523, 0.0820974786100643, 0.14311192424169608, 0.12130617004420076, 0.14836595659809454, 0.07835063537848846, 0.1954780678663935, 0.11464458464511804, 0.14132733643054962, 0.16001077102763311, 0.11577134632638522, 0.09745909752590315, 0.12756775904979023, 0.08430101429777485, 0.08978764167321579, 0.17500521428883076, 0.12065757199057511, 0.07996396095092807, 0.19227011714662823, 0.12900523548679693, 0.11279521031039101, 0.13025672547519207, 0.15462019028408186, 0.14936888563845838, 0.11678980024797575, 0.1180891812379871, 0.13903333166880266, 0.10744523988770587, 0.12534099710839136, 0.11613111916397299, 0.08660462033003569, 0.16738734234656605, 0.13182959678981984, 0.1653976198285818, 0.102996078985078, 0.08088302984833717, 0.09962585661560297, 0.11018361723316566, 0.1511019997830902, 0.05479267306093659, 0.19549340275781496, 0.08636255974748305, 0.10239446269614355, 0.13467584763254437, 0.2053712848573923, 0.19846069067716599, 0.10001912194171123, 0.07724954267697674, 0.13302609830030374, 0.15088765057069914, 0.22163984046450683, 0.2921999506652355, 0.08973745722323656, 0.11096600203641824, 0.13864602388015815, 0.12360423244535923, 0.14710565922515734, 0.14145203759627684, 0.11148082691111735, 0.29022685225520817, 0.08591995135481868, 0.13875384309462138, 0.15401056728192739, 0.14083674204136643, 0.0921067725867033, 0.08763002923556737, 0.10004139146102325, 0.09869012968348605, 0.09724816813000611, 0.1330133689833539, 0.06581213604658842, 0.1605429324720587, 0.11706824387822833, 0.12986071886760847, 0.06091692657875163, 0.1485198347696236, 0.12156511257801737], [0.028171968213947754, 0.021117136148469787, 0.05146210427795138, 0.04694495416645493, 0.06232655593859298, 0.019125274548839246, 0.029438367313040153, 0.05197079519608191, 0.043747520739478726, 0.04979924225647535, 0.04877941769414714, 0.022742193591381823, 0.020925090382141725, 0.03545271512120962, 0.06720174183802945, 0.019445987518078515, 0.055977924460811276, 0.02105694161062794, 0.03744862587856395, 0.03858467670423644, 0.005034899896210325, 0.022302854041169797, 0.021413890046200583, 0.04492492148918765, 0.06761728346879993, 0.030722196280424083, 0.01502033106849662, 0.044020888927791796, 0.04465789421062384, 0.017683116220203892, 0.02199054303179894, 0.01889090346438544, 0.09634511265903711, 0.06312108651867934, 0.045997271447309425, 0.04266804616366114, 0.08567825718117611, 0.0924249580129981, 0.04355528498334544, 0.021777696774474213, 0.019402866617643406, 0.03332022204995155, 0.01976740446739963, 0.03447479009628296, 0.02125317563435861, 0.03728040347674063, 0.0012437185359885916, 0.0365580486665879, 0.01204904997056084, 0.027603876643947194, 0.015826082921453884, 0.05495456473103591, 0.01880768284068576, 0.007176730881578156, 0.05906054297728198, 0.04076830078182476, 0.026002771487193446, 0.06032892848764147, 0.011381182370574346, 0.041052240545728376, 0.0709919502426471, 0.0489032401570252, 0.05794870906642505, 0.018917033847953593, 0.0569311168843082, 0.03310445469937154, 0.02844967563370509, 0.03946109628304839, 0.020123733739767755, 0.01715394202619791, 0.0207737397535571, 0.05817413875567062, 0.02247934608853289, 0.03200620845226305, 0.034493917998458655, 0.010684572875366678, 0.06683210988662072, 0.024259145138785243, 0.021650410390325954, 0.027051747610260333, 0.017684147593432238, 0.014017741295642086, 0.03768403342525874, 0.05383100234238165, 0.017216063603492718, 0.08603645581752062, 0.054841320629098585, 0.030267686383532624, 0.06641829173479762, 0.05984130608183997, 0.020630575649972473, 0.03260526327150209, 0.0342448379711381, 0.009024507266336253, 0.024895846777196442, 0.03049519917528544, 0.009960629445101534, 0.050348638490374596, 0.01612690633295902, 0.010756614634634128, 0.05663512633847339, 0.029382605305207626, 0.03488090009029422, 0.02532248754453446, 0.09503292771322386, 0.06538744097841637, 0.058941819705069065, 0.03748159250244498, 0.04159276154158371, 0.011303969326296022, 0.04224721874509539, 0.025766797363758087, 0.0863269909418055, 0.04436538454943469, 0.019281559823346988, 0.026488468549879532, 0.038315430616161654, 0.038226013271404166, 0.02336880880674081, 0.05029634040381227, 0.037129592283495834, 0.03111859643831849, 0.07403956313750573, 0.03700572571584156, 0.007822685193137398, 0.06368184142879077, 0.03343343561781304, 0.017440975909786563, 0.033801004822765074, 0.031842830790472884, 0.021926837075235586, 0.06869572667138917, 0.018539474911189506, 0.06987348704465798, 0.029964896916810955, 0.04082682442718318, 0.048505510070494244, 0.07186095004103013, 0.029172038925545554, 0.027829097683674524, 0.026808209517704587, 0.01449801177451653, 0.04657066746481827, 0.023282918147742748, 0.04221123603305646, 0.04818767748240914, 0.03387440874108246, 0.015171079497252191, 0.055343884376010725, 0.02693961969842868, 0.036694498666163, 0.030826799238898923, 0.05476738066811647, 0.035079188378793855, 0.040494189597666264, 0.04835512974698629, 0.007433117882880781, 0.05060760477291686, 0.005567219948196518, 0.02311683482756572, 0.015405732173738735, 0.02170419955759176, 0.06068279128521681, 0.03526825537639005, 0.05917453007506473, 0.0321129148692957, 0.05190229708594935, 0.0425610852959965, 0.03146044238071356, 0.023207561744909202, 0.0019522824399505875, 0.048521482784833224, 0.03388154353680355, 0.04844064890806164, 0.01675985736905464, 0.03823765693232417, 0.012295313229385232, 0.025690921881635274, 0.04963952189843569, 0.035498163396758695, 0.014043710527143307, 0.013815449650532432, 0.06716316712221929, 0.04621389375201293, 0.011981908082296806, 0.033358067340616665, 0.05659190026511039, 0.03655150080365794, 0.038256557525268624, 0.03952241549268365, 0.023576576229450957, 0.05148592424978103, 0.03282710690317409, 0.047297242762787, 0.03724674813981567, 0.00918914021791092, 0.041944778723908324, 0.060547694963003905, 0.03409388767821448, 0.004232950383863811, 0.0450404115420367, 0.009611263638362288, 0.03879968409559556, 0.01648570886547012, 0.03132563782855868, 0.07807785073029143, 0.06671087603483881, 0.035140626332057376, 0.11989601142704487, 0.01946029782162181, 0.004227287585048803, 0.0544688591866621, 0.0378634279061641, 0.06378080576126065, 0.04137982368203146, 0.04874054103025368, 0.04661275699202504, 0.02844119055329689, 0.008589015009679964, 0.013278859916941395, 0.044936398909028084, 0.014215244179857629, 0.019770508765109947, 0.04574384540319443, 0.008034172684087284, 0.04012926667928696, 0.029271457876477922, 0.043785474595746825, 0.009963438580078738, 0.026727684374366487, 0.0641460068789976, 0.012407898304185696, 0.023152851466355578, 0.03652107190074665, 0.004874298290815204, 0.031006370138909136, 0.1353979581700904, 0.06150280764060361, 0.02222045274850513, 0.05033610934125526, 0.05054333054327539, 0.005900945522755916, 0.0902314849996141, 0.027469229851184145, 0.05267616966739297, 0.04140446128855858, 0.027269654042486633, 0.07261708910976138, 0.01061177030870957, 0.056749758044523854, 0.04519927355327776, 0.03327379668397563, 0.02514521178922483, 0.04581462339098964, 0.04124272568151355, 0.06338169824864183, 0.058562410064041615, 0.0319683801249734, 0.028744035999157598, 0.03798846494672554, 0.03068623731711081, 0.03887174790725112, 0.04816081767369594, 0.02214087076884295, 0.016812250450519577, 0.05905867700598069, 0.010911927059558886, 0.031419869379273484, 0.018855270197881118, 0.03105346386187843, 0.06692331177847725, 0.019342532980122736, 0.0138461270668943, 0.05592764840860452, 0.024101911611588936, 0.013218915588887674, 0.004706295564704175, 0.030357395498348132, 0.027338918897190263, 0.015338614882369126, 0.08991541660257749, 0.020562021560700874, 0.04116223446492638, 0.012726163458345192, 0.0040623136696272665, 0.024613803518669944, 0.08656852905239378, 0.012938913872598537, 0.030496848015380756, 0.041813298993344815, 0.029734310361423662, 0.0317205282460366, 0.01017258597338306, 0.009578805067576468, 0.029933982861361334, 0.03429506991856864, 0.013522175789278532, 0.01996628308136548, 0.10303828386323792, 0.05659975430795124, 0.012443840304123504, 0.010278162629609662, 0.07337050725306783, 0.051068523433059454, 0.03869803276445184, 0.05536826413923076, 0.03845187722306166, 0.04436169331893325, 0.06240752552236829, 0.04150043667427131, 0.0055887413826504985, 0.029510217386164835, 0.06855667449001755, 0.014685854016404067, 0.010629972858753587, 0.03936183339517031, 0.031307344524455924, 0.01849566020869783, 0.03707713134852903, 0.04134419380820223, 0.00982214808131435, 0.06666310038417578, 0.055404850747436285, 0.06638229545205832, 0.038944530966026444, 0.05404162300484521, 0.00845131735383932, 0.035633693981383524, 0.061916890421083996, 0.017086992672245418, 0.044905590026506355, 0.028522948934031383, 0.03324310315240707, 0.10310738586953708, 0.021124332012342553, 0.0459173603781632, 0.03980200245444264, 0.06826157282505717, 0.023204873049897805, 0.014511747019631522, 0.013988917976218675, 0.024101536720991135, 0.06197042004870517, 0.052321987958358865, 0.03054161775591118, 0.01027978178379791, 0.012841209918925805, 0.03785312095923083, 0.022570848232135177, 0.013177862523921897, 0.05138300405815244, 0.020776632009074092, 0.08860432409814425, 0.07004198086048875, 0.14628161915710994, 0.14970098781798566, 0.09710867490087237, 0.13023905642330647, 0.08449168942336525, 0.07291029087666955, 0.11080979648977518, 0.1462330496204751, 0.12280479605708804, 0.09007839392870665, 0.13756430335342884, 0.1043188219357814, 0.17174459568091802, 0.14308639775429452, 0.21479985463832105, 0.13556840616677487, 0.09091814208243575, 0.10562568038169827, 0.07930479132171188, 0.10208093880542687, 0.09355353138276509, 0.2067787293344736, 0.1461930839078767, 0.11320513367120709, 0.16264446399041585, 0.1616412771067449, 0.12029120379260608, 0.27435670526964323, 0.1269843274993556, 0.11656132393649646, 0.21411201011921677, 0.12297364271112851, 0.10054616044674601, 0.12266687702919755, 0.1343831004840987, 0.17392820279513085, 0.09068049197750432, 0.13801942393183708, 0.14378983500812734, 0.1679210237094334, 0.0827933909105403, 0.1230620558240584, 0.14107007666357926, 0.08585646761847393, 0.13240807503461838, 0.14669980028910296, 0.11239715452705111, 0.09825620653906039, 0.0784455556422472, 0.09723839044038739, 0.09356139560363122, 0.08844256813504867, 0.19994296399610384, 0.15012395940721035, 0.11920743409012045, 0.16107839159667492, 0.10943087762487785, 0.13996053620108537, 0.22741330494838102, 0.09911078068294696, 0.16968237848154136, 0.0981650317886046, 0.12308594025671482, 0.17470061991895947, 0.16010306536086968, 0.14924594866377966, 0.1075523534257497, 0.11692168031420026, 0.10632368935538189, 0.14691448876900332, 0.15930745591010365, 0.13956731158707822, 0.1384611502289772, 0.13137738034129143, 0.14146273130817072, 0.1512238918138402, 0.0870361075337444, 0.1658696766410555, 0.16176680608519486, 0.22708987444639206, 0.07775743292378527, 0.10024099610745907, 0.0865752397637282, 0.27750725192683084, 0.1270150379942996, 0.10544605180621147, 0.10494273488542863, 0.11562865041196346, 0.09185059169041258, 0.14238952871944222, 0.09598844751183476, 0.19489980675280094, 0.23356149718165398, 0.11678737109260899, 0.10962993944329874, 0.14775910201881612, 0.09836942689227206, 0.13241791379238876, 0.1262945830821991, 0.10368838147925478, 0.13385156329189027, 0.084470430921231, 0.18627979287079402, 0.10023707417505127, 0.14406628374542507, 0.07789561658033303, 0.08175853001219885, 0.08223286670233522, 0.20394513995519706, 0.07544522985283818, 0.24289330786892346, 0.1606772688350507, 0.11759193720562117, 0.14807707709925516, 0.20440068122531685, 0.26125888952187126, 0.08778082685811178, 0.2068052464830024, 0.10176166093775205, 0.11454023952995028, 0.14886009294007504, 0.12385910376906395, 0.12043475466115133, 0.1586200049413102, 0.11333674232342414, 0.21081572771072388, 0.10385029350540467, 0.21177212281950883, 0.13549942629677908, 0.15104812410260948, 0.1339428262518985, 0.12698887368398054, 0.18179367216570036, 0.14308919331857137, 0.12077411716537816, 0.15523464445556912, 0.048568291523094685, 0.09161321978483881, 0.19697966586266244, 0.07959230017981359, 0.10620760558439152, 0.17010164526956423, 0.10287791211158037, 0.1319561300000974, 0.14893474536282675, 0.13856598388935837, 0.12640869910163538, 0.12844320493085043, 0.0966562752478889, 0.16681571730545589, 0.1550861538520881, 0.18721219498131955, 0.14977330608027323, 0.11553833740098135, 0.08321261020111186, 0.14745803603104182, 0.09375215893877403, 0.09946227539330721, 0.10348796259079661, 0.13686462518359932, 0.08626009417431695, 0.10741290769406728, 0.18039187309997423, 0.0978609531053475, 0.13893174140581063, 0.13529773854783603, 0.1276064898286547, 0.13606632873415947, 0.06975787146283047, 0.09809356848044054, 0.08037875619317804, 0.10285745428076812, 0.14167286003274576, 0.14917676523327827], [0.005819109534578664, 0.03699911678475993, 0.025680550473875234, 0.01161631935143045, 0.03288461613867964, 0.039210421698434014, 0.02761587992842708, 0.0513934127853385, 0.028547260843749558, 0.006566028160575245, 0.05980467876153333, 0.021545673421184932, 0.043988916357713084, 0.06149397311466081, 0.012739190482534468, 0.03139473644218274, 0.04971505641671164, 0.029302636560584818, 0.022442852778892432, 0.009096988377028277, 0.03709681564942002, 0.04377914047134774, 0.012771392906350749, 0.0052383077314256555, 0.059612035884388855, 0.01955801364965737, 0.013576601931293095, 0.04806674557871052, 0.066538779198059, 0.023673313270722116, 0.015068188143361892, 0.054373050042028935, 0.020002939239410416, 0.03384621900373271, 0.01803499599918723, 0.01754108357376286, 0.011799357565385955, 0.020080466954303638, 0.02645100323882486, 0.08975284639745951, 0.022692758922598193, 0.013053358981518872, 0.028310195975271717, 0.029860382167888538, 0.06755439005792141, 0.029078760716531957, 0.012239155974904341, 0.022031855636409352, 0.041246271026985984, 0.016690129414200783, 0.047063283888357024, 0.003998579299410007, 0.041607478966138194, 0.06117943820676633, 0.025113975429641347, 0.03437515062146953, 0.051709895088736496, 0.017551510960661938, 0.03921928336577756, 0.005724384773722184, 0.06349553606872048, 0.01928316455866609, 0.047838825665946515, 0.016270374080964496, 0.054030461103788445, 0.012265783385373652, 0.018287222732656767, 0.03084279570196356, 0.040261377447417805, 0.045420516681458266, 0.026511194383991615, 0.013005689351952501, 0.06554543785750866, 0.004877037451868611, 0.08628827373364142, 0.01018549595028162, 0.05598885905263679, 0.03402822245178478, 0.023331138238843, 0.03168530549321856, 0.045442687813192606, 0.0745948761967676, 0.04220055928453803, 0.004397394193802029, 0.006788459573207157, 0.012587975560953575, 0.023965670261532068, 0.015954090249059454, 0.012745526303271098, 0.09754568537963287, 0.010397142896960889, 0.04387918706717236, 0.05687930055760911, 0.045765616199267764, 0.03074210449787123, 0.03590282132583005, 0.013303040360499705, 0.01706580541628812, 0.050401564221829176, 0.012618464683847768, 0.0415894027932414, 0.015094913941408907, 0.057769094061638625, 0.021874432119407823, 0.013373256012398218, 0.04390440482114043, 0.024546877913443104, 0.043306147280548296, 0.034083044688616476, 0.03620855902720775, 0.057951606410954676, 0.007694971331927393, 0.040362224714564424, 0.0636580316349864, 0.04124002850481442, 0.015789112940962826, 0.013159912728172327, 0.029444728578839983, 0.02992661057838372, 0.021896214789843986, 0.005571618975539292, 0.0065673016859883705, 0.010287282140260296, 0.059463667417211194, 0.0284983418615801, 0.009767751625206853, 0.015100116608664393, 0.06549212536109345, 0.03871761867776513, 0.06828884993280683, 0.048518025648913214, 0.011215453584944564, 0.04214570990630558, 0.01240220369904169, 0.03488103240462286, 0.032314955456448455, 0.020069394959136844, 0.036888339157615385, 0.01807642904376345, 0.03362677060067654, 0.032250301247196536, 0.033085275907069445, 0.010237442046803023, 0.003201568037703899, 0.008095269673503935, 0.049955067823507955, 0.06598856872213738, 0.04451103548386267, 0.025399487698450685, 0.04146227925749762, 0.061146977091474194, 0.049407642733837874, 0.03313681064173579, 0.04450785315462521, 0.028769467491656542, 0.09546932072511741, 0.036773310508579016, 0.04004286881536245, 0.03241597914269992, 0.02636559264335249, 0.03220812351043735, 0.03254527059782829, 0.02136309491470456, 0.01928985830662506, 0.01916479242832533, 0.041019121251468144, 0.010458831060012537, 0.024396127788349986, 0.011764479169089879, 0.02492545634907271, 0.07113335015518324, 0.052087971408452304, 0.045481038612446616, 0.016988530455689346, 0.054297244109745534, 0.059394293996904574, 0.031243267069969858, 0.01648042816668749, 0.07536352745124272, 0.047823395779622455, 0.02350312820635736, 0.06891716657472508, 0.08467540277966432, 0.04366225263636027, 0.03806125818352614, 0.08013530461383717, 0.052736155555716584, 0.02566714771091938, 0.030966394248285463, 0.08030878566205502, 0.027125609539715306, 0.026277281310675398, 0.06459136333848749, 0.05745405703783035, 0.031303717754781246, 0.019329403327511888, 0.02565497818535992, 0.035144643259367774, 0.0319291709789208, 0.028262379612507563, 0.01720571255178324, 0.034933266030358415, 0.028914029377379587, 0.057547097759587426, 0.04070418600791267, 0.018143934796431234, 0.05844462995550462, 0.010347287536465695, 0.044865950010716915, 0.044576731244368215, 0.012016836520550507, 0.019733067202780927, 0.03791234349565847, 0.0670895596433963, 0.020945470181426833, 0.05993528996727296, 0.025224464679402963, 0.038697310124656985, 0.03988337576655405, 0.06731697065489632, 0.026880507423941578, 0.09485726178224597, 0.045790399690823894, 0.014224948078793074, 0.0540500130903508, 0.023589212247835736, 0.0673938486725092, 0.019901041939322437, 0.041772820986807346, 0.050486102899802585, 0.05291217093222907, 0.09484631022704498, 0.08467758087707417, 0.005929974947191242, 0.02394546688135181, 0.04017871831144605, 0.02795364617902253, 0.020608677628583143, 0.04705596249550581, 0.012747212462792439, 0.018053294392302632, 0.03635171973811729, 0.03532627351315958, 0.035649765083300214, 0.012480506640193718, 0.0453790310504181, 0.02250066735515637, 0.04074180059667144, 0.044087751768529415, 0.022784278029575944, 0.07203824445605278, 0.023504005212868963, 0.017078443131010448, 0.10016776182289634, 0.016416683194360564, 0.03871367299663169, 0.051342254637607505, 0.014051902989324714, 0.011115900623346013, 0.05928997602313757, 0.011586130480282009, 0.012111717768545662, 0.05640469245346529, 0.018861901181350862, 0.06295995480780091, 0.041146112472883294, 0.05004386430872338, 0.025834075807194625, 0.04786096287092992, 0.03509536126096334, 0.11539911558585507, 0.036685212914432795, 0.048175287432968616, 0.015338258651484336, 0.019523820573730127, 0.01674564545308905, 0.03346097735421998, 0.029469946332808052, 0.04503759901438441, 0.023182276137439266, 0.058294008752065044, 0.048136895921613486, 0.017467693226145845, 0.03207451657259038, 0.053300001192837954, 0.04624093337250607, 0.0675542950630188, 0.03435191758243101, 0.04335455057610359, 0.06931678298860788, 0.04249135564480509, 0.030129512905010154, 0.015768824743905237, 0.05794807802885771, 0.02701550705491432, 0.05706659997148173, 0.04302312693159495, 0.022969954048416445, 0.06193766037800482, 0.04807849780523351, 0.0519443933985063, 0.02764314685815147, 0.02732964332348534, 0.038735620211809874, 0.03595226617263896, 0.025845851782443266, 0.04401906366859164, 0.05841683716114078, 0.047981307841837406, 0.027772847130628567, 0.024991347188396112, 0.047362548365656815, 0.012406757517185594, 0.02143147088853376, 0.02152853362661387, 0.060457524444375715, 0.03897662567240851, 0.009447576394969863, 0.047857838217169046, 0.01749041736392038, 0.046807289589196444, 0.03814872134742992, 0.040752582518117766, 0.05740946371640478, 0.019601193921906606, 0.0357939571674381, 0.06186274332659585, 0.024908855989841477, 0.024962623104719178, 0.05181563459336758, 0.018709944960262095, 0.08725081636969532, 0.04630191331463201, 0.06843995968145983, 0.03133108646475843, 0.04683744029275008, 0.04729409436030047, 0.027419600103582655, 0.03936448307441814, 0.031956946809909174, 0.028650398166584115, 0.04560058291203209, 0.026092349984017865, 0.051363862585276365, 0.028687564922230582, 0.021933052456006408, 0.03101872286892363, 0.05600694540355887, 0.05149701829733593, 0.0387861608926739, 0.0446321098799152, 0.0383149556416486, 0.1174151109797614, 0.09186884428241424, 0.12877703058932508, 0.061479934225124974, 0.11390868627599307, 0.1349967811256647, 0.12007168414337294, 0.13410875520535878, 0.10626946083669152, 0.1702674656574215, 0.14661205214049133, 0.18047219807548182, 0.08724268073482172, 0.2114390299788543, 0.10664792731404305, 0.13672017864882946, 0.07320520933717489, 0.19272037941430295, 0.20644603004412992, 0.11290566224072661, 0.10196954371141535, 0.07071650573717696, 0.09403330992375102, 0.0919520462464009, 0.13783479455326283, 0.11568849720060825, 0.10051230833466564, 0.18370608240365982, 0.1625062735485179, 0.10409175019179072, 0.10027820018253156, 0.07050101658595459, 0.11994421455476965, 0.1761171839066914, 0.10684356931596994, 0.1360916516610554, 0.15058452183646814, 0.0919584719730275, 0.08802191035023757, 0.138019057522927, 0.18597601274294512, 0.09185649494507483, 0.0943871455799256, 0.12201936463160173, 0.13288938706474646, 0.1487266251019069, 0.15605263199125016, 0.08867858297058515, 0.20461375479187283, 0.06591528015477316, 0.1166720472808395, 0.0857993553259543, 0.06326155683823995, 0.16272659386907304, 0.1018444150686264, 0.14268804341554642, 0.1457692166524274, 0.1623298680143697, 0.10370252214904342, 0.10568203271499702, 0.18742050523204462, 0.08010840748569795, 0.11397223786583968, 0.07494988571852446, 0.13449891284108162, 0.11617921372609478, 0.15442151523062161, 0.12567073798605374, 0.11505579043711935, 0.14267338705914362, 0.09175265873117106, 0.11126389248030526, 0.14121976148869309, 0.06915111187845469, 0.17682075686752796, 0.11334368373666491, 0.17989521260772431, 0.13130792549678258, 0.08348472988499062, 0.15842568608266966, 0.1170386326100145, 0.17256788936044487, 0.18628057997141564, 0.08285070676356554, 0.16216950304806232, 0.038360200356692076, 0.18665168434381485, 0.07526532986334392, 0.13579711318016052, 0.18028292751738004, 0.11073732894978353, 0.12319367804697581, 0.11396702671689646, 0.12246480930064406, 0.20981654418366297, 0.09272581365491663, 0.09052736019449574, 0.07970124576240778, 0.06845733017793723, 0.1351111549884081, 0.17641697424863065, 0.09382078597056014, 0.10764788437102522, 0.06630376180899994, 0.13248789789421217, 0.11673530031527792, 0.18868367959346088, 0.08385466039180756, 0.11325537240398781, 0.10869786981493235, 0.23112471508128302, 0.11590125864105565, 0.12609415740839072, 0.1733412021504981, 0.12984081065016134, 0.08153156683381114, 0.0578272920101881, 0.12817685279463018, 0.1797923602695976, 0.12616142737013952, 0.12406438775360584, 0.12430745256798607, 0.20170042397720472, 0.1762534880212375, 0.19062928376453264, 0.0919601343838232, 0.13368374801107816, 0.2387759302343641, 0.1561229417898825, 0.14047508287642682, 0.16970899062497274, 0.20062555665416376, 0.1268042443054063, 0.11380693994994674, 0.16855742170342378, 0.1475131195038557, 0.07599119269954306, 0.07407080288976431, 0.13497761929673807, 0.11180860003722565, 0.12676255511386053, 0.10689384876085178, 0.14618998978819164, 0.17747877298721246, 0.12241439414875847, 0.14638820343783923, 0.16928848890321596, 0.1974003847156252, 0.06258391748581614, 0.10153899967138257, 0.1703975543911968, 0.07203946581908635, 0.17795264827353613, 0.1379790510982275, 0.07925983837672643, 0.28250656223722864, 0.1315374874642917, 0.18649017943867616, 0.11687765696219035, 0.10770325961389712, 0.17120630027992384, 0.14439833164215088, 0.0732822162764413, 0.10795813093760184, 0.08103645340140377, 0.1481709184923342, 0.1057921860899244, 0.0888118404628975, 0.1254427773611886, 0.1785928053515298, 0.20641157403588295, 0.16187966002949647, 0.11092665379068681, 0.16341055716787065, 0.0816396235355309, 0.13276054683540547], [0.05148913711309433, 0.03267549503860729, 0.05377254994320018, 0.031025175736950975, 0.025120022872995054, 0.010265463846735656, 0.035047361693744145, 0.01982439123094082, 0.017237456116293157, 0.02551419913236584, 0.0437940173516316, 0.027830266460244144, 0.05574829463980027, 0.05209131319341915, 0.01718044390768877, 0.011465487802135093, 0.03661883522623351, 0.06028516297893865, 0.03057349533108728, 0.10035621135362557, 0.026477684932095662, 0.004211587981054825, 0.07384980403419052, 0.053495012157197507, 0.08091174545032637, 0.025376716063224843, 0.08050661933209215, 0.07641557564160653, 0.011696414473200483, 0.0426910552861435, 0.02480708761140704, 0.014368470957768815, 0.005309914380112397, 0.02109745524025389, 0.011945779485228871, 0.01731698042047875, 0.01610854347901685, 0.04750688633482371, 0.020904101597677385, 0.015744809693257724, 0.05628565026979361, 0.026046574315322295, 0.1125575602054596, 0.05377423610272152, 0.03149834195418017, 0.07156647941363709, 0.018982437838401114, 0.034258076189351935, 0.025757776240685155, 0.019334914728200862, 0.018163152604496906, 0.05980320634054286, 0.0580251935337271, 0.007557087927125394, 0.026163772580080798, 0.02589849422552756, 0.027188910071605017, 0.038191533514431546, 0.013790042754927916, 0.04542111039959958, 0.056962913035282066, 0.01243117290349411, 0.024758012566183294, 0.022485529238890325, 0.04118397472692387, 0.054663781941469224, 0.07052699090646845, 0.020274248073941896, 0.02367606133754764, 0.023211590546582426, 0.040145761865590296, 0.015661943604105284, 0.00571761341832046, 0.01881455470408712, 0.02435833338781127, 0.05587399325200489, 0.027570886271340505, 0.03499895500551377, 0.019125077773683836, 0.05168767985222595, 0.054297345889998336, 0.03125136538541742, 0.03574011880638344, 0.03949420879195843, 0.06071700980620725, 0.006578186235856265, 0.07500790724796907, 0.06276299644793783, 0.016345915384590626, 0.04031791298517159, 0.0524908040783235, 0.05031865742057562, 0.05938628049833434, 0.038725370940353186, 0.022814971561144506, 0.03557911601715854, 0.03153659775853157, 0.02319959913646536, 0.03790947329252958, 0.0639082957059145, 0.0374244530685246, 0.042561753652989864, 0.05479269002431205, 0.013207929258766984, 0.05117017476420317, 0.0508128175112818, 0.04620772926136851, 0.01668878591486386, 0.028022576855229478, 0.04965012740077717, 0.015369749461699809, 0.0046216529860560384, 0.021796541388279626, 0.029049529427928582, 0.015175963253048914, 0.03553746075236371, 0.03697106275441391, 0.023141815094277263, 0.07661287326897893, 0.021998960258705274, 0.025308977912313173, 0.029339877955083336, 0.06313564788017954, 0.017965011897363832, 0.02921153644898108, 0.03532605298927852, 0.0628995109083397, 0.031039492825844457, 0.01957444437513394, 0.04348423558154276, 0.05977600387164524, 0.05191463963793857, 0.01806368276343814, 0.017129019434962953, 0.08713031533573355, 0.07897418870457582, 0.011580306105315685, 0.03959582619635122, 0.017964715038293173, 0.056145597249269485, 0.06859563597078834, 0.008776606193610599, 0.03731952441324081, 0.03620797209441662, 0.015412763492869479, 0.04299527646175452, 0.01974605436303786, 0.011444236085351025, 0.03028935200667807, 0.060172458312341144, 0.0287718966470233, 0.057775153379355154, 0.04089183486731989, 0.03581941580133779, 0.021982056255053197, 0.028084108107058064, 0.0937871713457363, 0.01935845141166023, 0.010189290657373411, 0.04962529980444482, 0.00547265973208206, 0.01877492486632296, 0.03375712057043399, 0.05869264129017081, 0.02360092885127025, 0.017321833642199636, 0.03689644765108824, 0.002197345752002937, 0.06550667315189328, 0.04860364659024136, 0.018085976031475832, 0.04716178681701422, 0.042067647845085175, 0.02238852926529944, 0.028037499536627104, 0.031681997635002644, 0.03631142493603485, 0.028361493222681538, 0.030257796735635827, 0.05942203250846692, 0.02594438354883875, 0.025216084771922657, 0.017698586818629077, 0.03624371053384883, 0.06806528621486255, 0.04987333488783666, 0.04190124052443674, 0.010801046803992773, 0.07732570144746985, 0.017657711869105697, 0.03016788066763963, 0.06801876585398402, 0.04291423563180225, 0.027494652861995355, 0.019836016232147813, 0.10470575653016567, 0.023102811205067804, 0.016691260871344378, 0.038726307318678925, 0.06490260056619133, 0.031224281660148075, 0.022615178621241024, 0.08063484887991633, 0.09543152632457869, 0.024422987597063184, 0.02962838765233755, 0.029276954010128975, 0.0335754801386169, 0.05183529175285782, 0.022071982501074672, 0.029549972752907445, 0.01747168131571795, 0.033496841322630644, 0.033934642294687886, 0.010612160466345293, 0.058162576518952847, 0.04241526472781386, 0.029767036105373075, 0.049242137864764245, 0.046311056574008296, 0.027978119240807633, 0.02871670460860644, 0.034054569966558895, 0.010395587355430638, 0.03289407830951469, 0.02336385041209204, 0.06813311936067683, 0.06610702736569302, 0.053238732873329093, 0.018250444438308477, 0.03311934515035578, 0.05000048217230609, 0.01964418081167553, 0.035338680525975566, 0.006847304250446281, 0.04587912153718727, 0.05038931666474257, 0.027316757943481207, 0.016680221106590967, 0.026965638123718754, 0.0635013986112816, 0.03442723836217608, 0.026866633079147766, 0.020807880243020396, 0.004433699209974813, 0.026966896806178347, 0.07012324899967227, 0.028205565875396132, 0.04295620641538075, 0.030062704347074032, 0.03448335999356849, 0.05149517946743539, 0.01666530521054353, 0.005522542658062386, 0.011598376341031065, 0.020926304959825108, 0.022674687838714038, 0.04829732874142272, 0.031456123505319865, 0.016165898347805654, 0.07964300710175719, 0.013218465211269046, 0.07414028487567391, 0.031008042727730105, 0.012384916323104074, 0.013665305966112231, 0.03901509182261569, 0.0238831451362265, 0.02198125558373119, 0.05279410923165934, 0.010228820411222321, 0.011189926249374236, 0.03609787978764091, 0.03210684198087879, 0.017346145551917807, 0.03442273967500244, 0.03409753819661481, 0.02766611866120781, 0.051001457031816244, 0.026217753433489373, 0.02197659065547798, 0.0254055792465806, 0.010305164082508003, 0.05537756685433643, 0.0006801662062311412, 0.032352892349341085, 0.05743324636880841, 0.031129161228558848, 0.0224607898521104, 0.03172791749238968, 0.021712969622707794, 0.007250962612618293, 0.01869046252353915, 0.03529974279393043, 0.08085183080817972, 0.008321932600145894, 0.05271025926672986, 0.04213500601638641, 0.0638626574405602, 0.061324508993753364, 0.02290855341457895, 0.06460302735545806, 0.018030359908672314, 0.031245777649538856, 0.036202842369675636, 0.027801847717325603, 0.03528816359383719, 0.03632436799151557, 0.06912593822926283, 0.03534011223486491, 0.03790982952341437, 0.05512050725519657, 0.02468780624414129, 0.06761380258415427, 0.02571288266751383, 0.015659448291574205, 0.022822757750483494, 0.022965094041345373, 0.007684931558157716, 0.004687268170528114, 0.042848763787852864, 0.05213609650464995, 0.026967478649956838, 0.025526005641690323, 0.08778423988925559, 0.020572194496967962, 0.02082400902041367, 0.022961524947147285, 0.058386316656001976, 0.05007363503266658, 0.043104313646576235, 0.041478380893490145, 0.04303837700613907, 0.01728455662461264, 0.014622548395501716, 0.0290097096003592, 0.015974980645946095, 0.03274892609832542, 0.03142811018707497, 0.06725781597197056, 0.025613802984090786, 0.031139407107340436, 0.018815263773181608, 0.09265648773206131, 0.014312578331945198, 0.0524094748709883, 0.03109485449801598, 0.01732374880728977, 0.05375062647674765, 0.02519419014320842, 0.04666907200589776, 0.019519696777154292, 0.14583149259643896, 0.13588475276316914, 0.08918597110147987, 0.15878495680434362, 0.1689668090215751, 0.12072628044656344, 0.1374676256839718, 0.15599662571081094, 0.11235904121505362, 0.1080646337941289, 0.09237265653376069, 0.07867319735565356, 0.13668925102267945, 0.17771689806665691, 0.15338365520749772, 0.16180299914308957, 0.10233300777950458, 0.07826851228518145, 0.11431822287184851, 0.23655123103942188, 0.15968572561229977, 0.1452360645468746, 0.12304727733135223, 0.14172098173626832, 0.1750261267381055, 0.0901429768917816, 0.1137628826711859, 0.2056097492043461, 0.14431841378765448, 0.09549667925706931, 0.07517524755426816, 0.10425256977656058, 0.11177531789456095, 0.11917687287288052, 0.14977342821657658, 0.1592586421008621, 0.1167437412909099, 0.15964479637997492, 0.13250742613204888, 0.11629480895187173, 0.14317719931049006, 0.11358129991484539, 0.20476464740931988, 0.2185340906892504, 0.07117732600974185, 0.1562743636646441, 0.0938183975272945, 0.09735477955213614, 0.20352390541562013, 0.10563480667769909, 0.1457673031836748, 0.13262526052338736, 0.2324143387377262, 0.06574814340897969, 0.20505906375391142, 0.19636370534343378, 0.07892362427498613, 0.13995989837816783, 0.1065285662189126, 0.19726788039718354, 0.0825222483170884, 0.08799476894949164, 0.13194630481302738, 0.1750397245798792, 0.14954550830381258, 0.1105874337788139, 0.12385638962898936, 0.08538776955434255, 0.08645112213811704, 0.13215385510453156, 0.13501383949603352, 0.11938052837337766, 0.1436205812330757, 0.06826922670006752, 0.08301753138325044, 0.21718121399836882, 0.12128102353640965, 0.17662121328924382, 0.1290637252054044, 0.14568061354969228, 0.11281262830431972, 0.13785711835537637, 0.09473330021968909, 0.1256272710327591, 0.19415037839540414, 0.1319895682058164, 0.2244546344237668, 0.12931470173810208, 0.08004277957869427, 0.11193657852709293, 0.14203274143593653, 0.1379683573863336, 0.10069648988012757, 0.12325334841651575, 0.13456272227423532, 0.03922320869086044, 0.10749157025877919, 0.06421364324965648, 0.08080059462892157, 0.15865680868072168, 0.1379684116691351, 0.1522610733019454, 0.12353857739695481, 0.15253901481628418, 0.15308557477380547, 0.11967664105551583, 0.17301948155675614, 0.15021200611123017, 0.16713473732982362, 0.14351957451019967, 0.15579493796186789, 0.12149478920868464, 0.10266931687614747, 0.11809850430914334, 0.09693327359855175, 0.10293629326458488, 0.10924941021949053, 0.1252584465380226, 0.1271027997136116, 0.09598015581390687, 0.17351048306695052, 0.10939017230910913, 0.10980764776468277, 0.11371391958424024, 0.112907168588468, 0.10629145215664591, 0.17719315045646258, 0.07279123512229749, 0.07966132754726069, 0.19217892204012188, 0.16305066219397954, 0.12611091722335133, 0.14371059568864958, 0.10623447557113, 0.10870831246886935, 0.13633086239652975, 0.12947717016296728, 0.13465227532599652, 0.14192497650427477, 0.12283755572778837, 0.18115108593233994, 0.08316794224083424, 0.06780286958175046, 0.12836564837821893, 0.17102548426815442, 0.13160783797502518, 0.058177877483623366, 0.10057672844933611, 0.16187815368175507, 0.0817353648266622, 0.08862259026084628, 0.20560072468859808, 0.10030702435012374, 0.10546427047146217, 0.11567808847342219, 0.15865302245531762, 0.17263301515153476, 0.09257237653114966, 0.07780794307057347, 0.20361127358462128, 0.10094704572111368, 0.07862479745277337, 0.18912243390721933, 0.15932463641677583, 0.054617709413702996, 0.05604326059775693, 0.11821700366480009, 0.18057454829769476, 0.13132567597287043, 0.10684100445359945, 0.0827952975939427, 0.10052205209753343, 0.14478657580912113, 0.07640714823667492, 0.06852822351668562, 0.10583703725465707], [0.035033444940511665, 0.025750531183023537, 0.019105510520083562, 0.025373235178579177, 0.020968891513933028, 0.040985394668366225, 0.005587096783399049, 0.03581282044095652, 0.01092425943352282, 0.077771030765559, 0.08327695567693029, 0.18091457576623984, 0.03338947333395481, 0.02801987967853035, 0.044265619545642815, 0.017535867335807, 0.048695805216474194, 0.09024474357387849, 0.006671957230927157, 0.014813561092263885, 0.07321523808475051, 0.023229895725048015, 0.0105603348097897, 0.036786572475518496, 0.02624396015224712, 0.060647554961698394, 0.016687252425721714, 0.08540072957319872, 0.03887534414284995, 0.040734041548733196, 0.009992831868917813, 0.051969031005033424, 0.03811205331502216, 0.03450101547475372, 0.04661891130464418, 0.056880464245166094, 0.02562767223987196, 0.0702238418161869, 0.037486179399171045, 0.10378481487610511, 0.007580346411227116, 0.02605685920986746, 0.10762757581791707, 0.053878143562802246, 0.028329179688755955, 0.014170013035514524, 0.04800142640514033, 0.013046426898134606, 0.04055972590244242, 0.021165062773174474, 0.025342159971062626, 0.01726517596814249, 0.052046258468180895, 0.048306801090283055, 0.028983742065195526, 0.016951501103384153, 0.048601013874369006, 0.030792475544980595, 0.0574339520452278, 0.04377462821347373, 0.015729281419355954, 0.03936923621222377, 0.010343834641389549, 0.030755858402699232, 0.021916304515408616, 0.019996041930945854, 0.06298997319702591, 0.03488910697134478, 0.02251135597803763, 0.04668285983747669, 0.04641823457287891, 0.035287865038428984, 0.05018233973532915, 0.03827960735985211, 0.005700347246602178, 0.005495209995258067, 0.043411717151424715, 0.03961823481534209, 0.02848424868924277, 0.036126737881984027, 0.042940450832247734, 0.03171772250373449, 0.03294960283009069, 0.039937940160078664, 0.04121929925999471, 0.02051151141391269, 0.07828031200915575, 0.05454582880650248, 0.07571708490805966, 0.04331566034150975, 0.05626310255112393, 0.04443263076245785, 0.028313861760709966, 0.005546177729099456, 0.029855350830725262, 0.01840898414541568, 0.007614496230546917, 0.010498049535921641, 0.07381287137312548, 0.05017322361735361, 0.012345889533337737, 0.027104776818305254, 0.051393606167818816, 0.006414909082065735, 0.08614763378032617, 0.05073093869058149, 0.012062514649837144, 0.04794434803937163, 0.02157276902081711, 0.029313727215464627, 0.06923625445259468, 0.06488486366080386, 0.06345253730458872, 0.030259347188153436, 0.0762548917638404, 0.03540488179507, 0.052704637604100366, 0.049572445319167206, 0.035262128205171654, 0.005060441226565412, 0.05188049575580018, 0.040101277109767706, 0.019549827124657373, 0.02572639569241021, 0.012539090505535049, 0.0212782814300486, 0.03478941999908004, 0.022399019416687743, 0.03133180910455329, 0.08107006802622761, 0.030082731308149438, 0.013544960147035974, 0.026853101394538368, 0.07864081766456366, 0.05143119361517685, 0.023766867982755815, 0.05127619246819189, 0.01438153106054025, 0.022259716177359223, 0.0482146560347506, 0.08347714386348214, 0.08989683831376688, 0.05711058261139052, 0.021972477036927427, 0.01965812809898385, 0.021308038583291427, 0.018670338871223584, 0.022035412856244614, 0.08519338284220014, 0.05973193980753422, 0.06450031750968524, 0.058354473007576804, 0.022284416548375572, 0.036039987179849825, 0.039021958597004414, 0.0466551925720913, 0.02188481709786824, 0.05923495361847537, 0.015229228252012814, 0.03191908794854369, 0.0372697776183486, 0.03350959099563105, 0.07085418727781091, 0.0033478813919438316, 0.04811589526278632, 0.023059812440936054, 0.039508464812700234, 0.04542019098464932, 0.07136321746345077, 0.06348757685295173, 0.05105724957372461, 0.05439251381903887, 0.038648747373372316, 0.0317528061568737, 0.007688776307207133, 0.060613451791661124, 0.031073287262448242, 0.04880778045792665, 0.02504485985264182, 0.004066018470829087, 0.03599348378234676, 0.03202130585642798, 0.0330772658011743, 0.03165808945362057, 0.0032884090698124574, 0.03806320557902966, 0.04289030370169452, 0.07771201857498714, 0.005639838462229818, 0.017236748743536215, 0.05198528870408024, 0.03180526030649032, 0.046304766554385424, 0.03756750860650625, 0.01797303218128426, 0.04162103948848588, 0.034151644579001834, 0.0672110513384853, 0.034861110616475344, 0.055528018424021344, 0.0388199994340539, 0.04201529886839645, 0.042862626258283854, 0.06088977839265551, 0.036645613610744476, 0.07866015591259513, 0.04551732327256884, 0.03760376273255263, 0.05624281774674143, 0.005937303973561419, 0.04527866893580981, 0.04091531217896512, 0.034458454365709, 0.06490094494074583, 0.04340163751372269, 0.031270961476755996, 0.005998834377221231, 0.012420858323041881, 0.01715690383155431, 0.017212611556585346, 0.008289781914624785, 0.04990820140976991, 0.01160260446236602, 0.013079452045660998, 0.03715977352112532, 0.036236792869333706, 0.026997093310845748, 0.04856368087764297, 0.04960376649562802, 0.050119337758847644, 0.047552304076296945, 0.07694619681153979, 0.05781397236777203, 0.05009608097108347, 0.053569243888237646, 0.049044962373695204, 0.008827473419452352, 0.016039044529731785, 0.0074366352387837, 0.039382420147636106, 0.06514455936849117, 0.023028146907953278, 0.09276311272489172, 0.038352040973092826, 0.018545724218711257, 0.05571217282808252, 0.005815115507825145, 0.03928429041323917, 0.028426303494987742, 0.032399996250335655, 0.032345523459038565, 0.012584235136663275, 0.059870707004198005, 0.057341664497341426, 0.04171227869976844, 0.010549509631735938, 0.05628670539174761, 0.0075754143098103145, 0.025767791417560408, 0.017036893039143512, 0.02781719109043479, 0.007086574357734727, 0.022149157377758195, 0.018497767059930732, 0.04124834734414305, 0.04547148144670895, 0.013905134168453515, 0.04996520174401147, 0.033088699116238525, 0.014993332160104598, 0.041829689006720266, 0.00922807286094342, 0.0488462092887078, 0.044054829249424596, 0.0537071255967021, 0.050361747786934884, 0.0502058577590755, 0.02690003396544073, 0.08525062405637332, 0.016323628901903118, 0.05104105633550456, 0.04535276495984622, 0.01797607371450535, 0.06404096287276063, 0.008564007601567676, 0.008902097852634532, 0.027124986983835697, 0.04847240434693439, 0.06564964726567268, 0.02492475406532841, 0.03546062344685197, 0.004493378061202488, 0.05111406331083604, 0.03834481457514422, 0.028157961554825306, 0.0139981299372656, 0.08267103747597762, 0.017495358795193688, 0.03722058722217168, 0.024759864966784204, 0.03734326635354331, 0.01523709756189159, 0.043567773420363665, 0.011602045519144406, 0.0324960123481495, 0.07415212531174932, 0.040152459006224356, 0.07448310790849583, 0.03868609733347382, 0.023184494946950247, 0.01645104929671756, 0.023073998911838447, 0.024775340654222027, 0.028637628137533153, 0.05726566178990262, 0.019409624826429144, 0.027020791146372045, 0.019693116757220457, 0.03708558589486139, 0.03459431403981788, 0.0569723853841424, 0.017200830492324064, 0.028902053234300444, 0.04474832596523421, 0.02930218194212232, 0.013329080838177885, 0.0675223157075899, 0.03703484504616686, 0.052196665933089595, 0.01960209128446877, 0.03649020195007324, 0.08635881423418011, 0.015908903209492564, 0.013911616722387927, 0.12269910744258336, 0.011381935544445046, 0.05161819786631635, 0.029203115829399655, 0.030357405676373413, 0.021377522265538573, 0.020073335551257645, 0.05235312932303973, 0.04469030104311449, 0.06323993192719561, 0.023706329088392, 0.05645160636465464, 0.03673478329022016, 0.06921175933842148, 0.08601881390703575, 0.01840524881013802, 0.034942117519676685, 0.03625177152987037, 0.1348764497254576, 0.16588919130819185, 0.2080147351537432, 0.06974527106753417, 0.13870534141148838, 0.13808243269366877, 0.10039350363825049, 0.09827578905969858, 0.07359173002519778, 0.1230769157409668, 0.14474610798060894, 0.28893196316702024, 0.11393791756459645, 0.12033235015613691, 0.2135923065777336, 0.11107032001018524, 0.1395973435470036, 0.1941858793475798, 0.07035992201417685, 0.1281749393258776, 0.15895573049783707, 0.16247014834412507, 0.15257420364235127, 0.1752580092953784, 0.06763322225638799, 0.14572048426738807, 0.15186571808797972, 0.3355680549783366, 0.17297697812318802, 0.1874330174177885, 0.16184200133596147, 0.11157418654433318, 0.14613771545035498, 0.08346868931714978, 0.12075239047408104, 0.1919546662164586, 0.0939985214333449, 0.10419142698603016, 0.13775335678032466, 0.18976750357874803, 0.0845075264307005, 0.11150908789464406, 0.194960318505764, 0.11414165448929582, 0.09793601943446056, 0.10950548255017825, 0.11947491259447166, 0.12483183800109796, 0.17896629816719464, 0.08828483588461365, 0.10567636016224112, 0.12652688633118356, 0.12136795744299889, 0.1121505613305739, 0.08834629080125264, 0.14259781182876655, 0.10954922770283052, 0.15940771624445915, 0.11063566404793944, 0.16107828303107194, 0.0936396239059312, 0.08865663914808206, 0.2818907509957041, 0.10632913799158164, 0.11598539698336806, 0.1639154279338462, 0.24741674800004276, 0.16478566266596317, 0.11491181887686253, 0.08722366139824901, 0.086441805852311, 0.06472561149192707, 0.11763130580740315, 0.11231744701841048, 0.09415001794695854, 0.07155720383993217, 0.10588695707597903, 0.16532881637769087, 0.11100611702672072, 0.08425701130181551, 0.10739603252815348, 0.11096213438681193, 0.100387118623725, 0.111805010586977, 0.10521507848586355, 0.08282397248383079, 0.1793344034148114, 0.1449012075151716, 0.1326428074389696, 0.1645863497895854, 0.1996494433177369, 0.14151024233017648, 0.14087037023689064, 0.07056645450315305, 0.13720248134008475, 0.0847854543743389, 0.11030039310987506, 0.0951346265418189, 0.09794123736875397, 0.18132513016462326, 0.09570667227464062, 0.13780882023274899, 0.17823961430362292, 0.06525866181722709, 0.22304835702691758, 0.15263966870095047, 0.2519836143723556, 0.19414766425532953, 0.0780117003513234, 0.12761936842330865, 0.12024563338075366, 0.11338141028370176, 0.22833601757884026, 0.11701032412903649, 0.11911640183201858, 0.0754165481775999, 0.168910042781915, 0.0886129822049822, 0.16683090291917324, 0.1121567834966949, 0.18979091303689138, 0.1280342247337103, 0.17302554765982286, 0.08715988589184624, 0.16150263883173466, 0.07979026955685445, 0.1081250709082399, 0.07612256386450358, 0.1076316809547799, 0.20309163789663995, 0.15399924931781633, 0.20091012067028455, 0.0604559773845332, 0.12092709967068263, 0.10239334311336279, 0.11011546517589263, 0.15941146175776208, 0.1619222584579672, 0.19647613859602384, 0.1423908450773784, 0.118013931704419, 0.1373320815286466, 0.10313247809452669, 0.1346114275178739, 0.11607105524412223, 0.10571885681045906, 0.15355065624628747, 0.1592601348779031, 0.1741351152637175, 0.15478200731532915, 0.19061932287045888, 0.12420259176620416, 0.09375281711774212, 0.19426874204405717, 0.14667602442204952, 0.22278450189956597, 0.08611695042678288, 0.2175380012818745, 0.25452567796622005, 0.14752876652138575, 0.215488160561238, 0.12016552553645202, 0.18192405945488385, 0.1530177891254425, 0.12434135217751775, 0.11298002967877047, 0.19781691022217274, 0.0785223183089069, 0.07609416717397315, 0.11770172417163849, 0.09466051376823868, 0.15034370975834982, 0.20899365762514727, 0.16309985598283155, 0.07385128324053117, 0.11461557048772063], [0.01806439013619508, 0.054247035911040645, 0.024427476106211543, 0.03278206914131131, 0.041501576613102636, 0.04027481244078704, 0.0010111627447518653, 0.014543393892901284, 0.10487824691725628, 0.038954257765518766, 0.021504474471190145, 0.034209245416734896, 0.04994115446295057, 0.05776270904711314, 0.051352239280406914, 0.020394708395802548, 0.015945958006860952, 0.05524084883342896, 0.01285327851240124, 0.013941425613925924, 0.07101510864283357, 0.04114561374964459, 0.043002523215753694, 0.057625495695642064, 0.046497887798718045, 0.020635905542543957, 0.02239208309245961, 0.07145802237625633, 0.02230441806438778, 0.010498217473338758, 0.035393417945929935, 0.0341151156462729, 0.05321049903120313, 0.02294168288686446, 0.024142286141536067, 0.02650054986588657, 0.028420132218993137, 0.03558401843266828, 0.015884080702172856, 0.04028707696124911, 0.03987943687077079, 0.11295719697539296, 0.06345555678542171, 0.04558709363586136, 0.0347716220255409, 0.01615180347913078, 0.01502508929531489, 0.01301345179256584, 0.014277723684374775, 0.04501822005425181, 0.10005125057484422, 0.02063343228240098, 0.0650531267747283, 0.06132281944155693, 0.10415589889245373, 0.07471133316201822, 0.01658343317519341, 0.04338297440803476, 0.036017989074545245, 0.005857588407317442, 0.0063861010296802434, 0.02483354029910905, 0.005516520659771881, 0.020124130682753663, 0.03522094452221479, 0.03365470928006938, 0.03239944324429546, 0.031005796776818376, 0.032969025894999504, 0.059694274328649044, 0.08569162432104349, 0.03265834167333586, 0.03822718035163624, 0.057118351837354045, 0.05103970265814236, 0.023050653914521848, 0.04530489431428058, 0.027742625180897967, 0.07386110164225101, 0.06976294011941978, 0.059456726003970416, 0.04986503640455859, 0.053103704404618056, 0.08089877186076981, 0.02766881414156939, 0.0285865989114557, 0.025982761489493505, 0.033582075498998165, 0.03477510630286165, 0.11464291544897215, 0.032701096164860895, 0.0790787645216499, 0.013224478727871818, 0.1114032839291862, 0.011363498051650822, 0.03713721223175526, 0.03570492658764124, 0.04452144421104874, 0.027710974914953113, 0.038196137374533076, 0.07835029611097914, 0.0420353529708726, 0.017401193401643207, 0.03130482715953674, 0.028605828593884195, 0.015601175704172679, 0.048049982371074815, 0.05802712057318006, 0.04087183504764523, 0.06619143712201289, 0.020317833770864775, 0.029439676885626147, 0.023625094875959412, 0.05027283595076629, 0.07838582420455557, 0.007845051403689598, 0.03716673529041665, 0.07875261309423617, 0.06786157643156392, 0.017230212754969085, 0.0329483441476311, 0.02491217741875776, 0.044208826164581945, 0.03938903586406793, 0.08588979047323976, 0.10669919742005211, 0.03639610271368708, 0.052570504801613946, 0.022257003733622174, 0.011110916783634042, 0.02774311711878649, 0.011641887399101896, 0.05073194292240909, 0.004377474526076445, 0.038888144705976756, 0.030585878595177616, 0.014826938410156539, 0.07157844198601586, 0.020761042667020644, 0.10958550218492746, 0.04674277108694826, 0.032018551004252264, 0.06687647929149014, 0.04507767668526087, 0.041972710617950985, 0.09396638601486172, 0.03559239494747349, 0.02006820073750402, 0.052083845915538926, 0.03533576282539538, 0.03520054775955422, 0.05006422035928283, 0.017853425117209554, 0.08872716607792036, 0.04262542737913983, 0.01744397503456899, 0.02402929649023073, 0.028547919022717645, 0.03001871831449015, 0.04699182736554316, 0.009336282233042377, 0.01701931728582297, 0.03213696554303169, 0.042320500527109416, 0.06204820730324302, 0.01649221431996141, 0.025478774515379752, 0.016799512651882002, 0.042986038207475624, 0.028662357346287796, 0.04662472974242909, 0.08020983490028552, 0.010230705890405391, 0.019354003614612987, 0.01986387009466333, 0.006984006156147058, 0.04470138491264411, 0.008442130837855595, 0.046166576112487485, 0.008391890408737319, 0.047477661831570525, 0.025800305119316493, 0.020031318966565386, 0.06939041082348142, 0.05610119052497404, 0.07289932575076818, 0.011457235119970781, 0.05072853667661548, 0.04148726970223444, 0.028941286129078696, 0.056028278544545174, 0.006716462342800307, 0.008916631224565208, 0.00768911133387259, 0.02256997292196112, 0.01426653633825481, 0.051535783002951314, 0.025549644105402485, 0.02246722575676228, 0.06911041334803615, 0.03106432720752699, 0.09412040667874472, 0.04763632028230599, 0.05349981279245444, 0.10702450746404273, 0.011894513620063663, 0.01102928732455309, 0.019114434951916337, 0.019445575308054686, 0.026742508668186407, 0.04406387072854808, 0.022414807230234146, 0.03296926338225603, 0.11491622935448374, 0.07113064958580903, 0.0689985907769629, 0.03130833179290805, 0.006050617625338158, 0.03977109857701829, 0.03239350945555738, 0.021690060584140674, 0.01784738615554358, 0.02664071993370141, 0.06333867912845952, 0.00029130043757114824, 0.02711079203124557, 0.08539268893322774, 0.01714417621094201, 0.04712549537154181, 0.01884312442104731, 0.04311503789254597, 0.08304934789027486, 0.031928193888493946, 0.04260288305314524, 0.02550814999267459, 0.05492099421098828, 0.040927234039242776, 0.03259314463606902, 0.005600736185442656, 0.019901057206360356, 0.019653025515643612, 0.06179773288645914, 0.03687761491164565, 0.020261707050459724, 0.03675448455448661, 0.05637767318902271, 0.033952165461544476, 0.03603193296917847, 0.012588308891281486, 0.030397004980061735, 0.02153557851644499, 0.04012852368344154, 0.034776873886585236, 0.0062430013869223845, 0.018191525546301688, 0.056061374090079746, 0.0389963608634259, 0.029977361605103527, 0.026182338994528567, 0.03409122782094138, 0.029708193548555886, 0.03338140555258308, 0.042058239957051616, 0.037434078087764125, 0.060830033384263515, 0.06420662719756365, 0.021895965428224633, 0.12290984684867517, 0.05993032309093645, 0.01596846670976707, 0.03809541902904, 0.021995275813554014, 0.03057464544794389, 0.05223108122923544, 0.016234223431508456, 0.023945504200777838, 0.052268787420221736, 0.05208661433841501, 0.046077939083001444, 0.010493402419212674, 0.03373569243454507, 0.009529686765745282, 0.09883593328829322, 0.03999531029590538, 0.03810311700882656, 0.07007050647267274, 0.02047747779371483, 0.02667736930639616, 0.01922716336723949, 0.05391716271904962, 0.0724181222862431, 0.019680591000776206, 0.011794111641523029, 0.027203766595838324, 0.047625351763729534, 0.03924997689734612, 0.01155446664363678, 0.038586634277765236, 0.028392967069521546, 0.041704478939729075, 0.006288211327046156, 0.04156749629016433, 0.03487260499969125, 0.015363732552421945, 0.02335665963723191, 0.028574059584311078, 0.029022493200110536, 0.03378254867025784, 0.03177942508565528, 0.03525760916194745, 0.02891000227204391, 0.03568032969321523, 0.009431540067972881, 0.03708835771041257, 0.018838283073689257, 0.06010384485125542, 0.014791680034250021, 0.07926025906843798, 0.0067562473954499835, 0.011276835559069045, 0.04065005926947508, 0.017450246394478848, 0.08350250750247921, 0.06149167288094759, 0.03421449388510414, 0.03276727029255458, 0.035781336416091235, 0.03118518107969846, 0.04365551478362509, 0.03048657838787351, 0.022437685734725425, 0.01646725949831307, 0.08411962831658976, 0.1053959352097341, 0.026482629756044065, 0.04116173913436277, 0.04305495361664465, 0.01141850434110633, 0.0398351522827787, 0.058210352169615884, 0.05212439177557826, 0.022339174324380498, 0.0283884208848966, 0.04946013759555561, 0.04874318392415132, 0.01767820871568152, 0.02163630025461316, 0.017703679223944033, 0.03509543589981539, 0.026385064902050153, 0.02007848223937409, 0.001462767451552541, 0.14699819284890378, 0.14750033590410436, 0.15037809791309492, 0.09899741105203118, 0.1130292166822723, 0.10944429904754673, 0.07979229159121003, 0.09850708807685546, 0.1779759627367769, 0.17184558883309364, 0.08320074940898589, 0.12982956053955214, 0.1363689824938774, 0.14298202549772604, 0.10191714723727532, 0.07363181787409953, 0.1107277480353202, 0.1379607849355255, 0.05339762881132109, 0.08580619495894228, 0.14546380804053374, 0.09998110362461635, 0.14698808267712593, 0.1321631781756878, 0.1185854481799262, 0.14615056690360817, 0.10733731889298984, 0.2255346586129495, 0.1491264043641942, 0.0664341626688838, 0.1016129803444658, 0.13784372407410825, 0.1251301219952958, 0.13368821277150086, 0.08220877192382302, 0.1007019453016775, 0.10167252857770238, 0.13995575931455406, 0.16148556689066546, 0.16844523272344045, 0.1327242994947093, 0.17853629695517675, 0.1862500323248761, 0.17528930333043846, 0.15546151942440442, 0.10654856943126235, 0.10205949031348739, 0.1702863560723407, 0.10006520125482764, 0.11230464306260858, 0.1912611084324973, 0.07702538863356624, 0.13589113099234446, 0.1795804537832737, 0.18917763951633657, 0.22030307219496795, 0.09068748088819639, 0.1851511855742761, 0.13849667832255363, 0.13415534341973917, 0.12206181378236838, 0.1150804619703974, 0.05814002201493297, 0.1534935643098184, 0.15717095269688539, 0.24917808920145035, 0.14814365495528492, 0.10989614908716508, 0.14555074194712297, 0.224838400259614, 0.14280053095093795, 0.08486930773194347, 0.10934741103223392, 0.10981977318546601, 0.16557450033724308, 0.16562515976173536, 0.11041802394070796, 0.06970289655561958, 0.12438803538680077, 0.18828183758471692, 0.11887162710939135, 0.11128536811364548, 0.12524501154465334, 0.20247881220919745, 0.06841821263411216, 0.10601245212767806, 0.1271988802722522, 0.1998156165438039, 0.26774961980325834, 0.18961316400340625, 0.08553311854068722, 0.18954848604542868, 0.11955071852675506, 0.18146774465484278, 0.09450869155781609, 0.06886163526879889, 0.06660180153059107, 0.12165173435849802, 0.0926943432007517, 0.12660911120474339, 0.19293338512735708, 0.1111042806878686, 0.08775848948529788, 0.12777267662542208, 0.10738691301750285, 0.0725975947986756, 0.2345008882028716, 0.14862460057650292, 0.11770738315369401, 0.20616834637309822, 0.11574679692941052, 0.1789257489144802, 0.08360309353364365, 0.26762034531150547, 0.16291484662464686, 0.1359244334910597, 0.14171663911214896, 0.10751352765198265, 0.14545658842793532, 0.14508734324148723, 0.11251014417835645, 0.12951561595712388, 0.08708019195390598, 0.20371279599411146, 0.10434823642883982, 0.254881420305797, 0.16807408763894013, 0.09074502065777779, 0.08819283332143511, 0.08655394733484302, 0.12584037174071583, 0.11842084915510245, 0.10544025033180203, 0.10508294057633195, 0.09472873367901359, 0.12907014414668083, 0.11636361240276269, 0.1623008402862719, 0.12297816175435271, 0.16071997582912445, 0.08244653059435741, 0.1901506587330784, 0.1866805220821074, 0.12923524528741837, 0.11162006908229419, 0.1679180652967521, 0.14991932681628636, 0.18015847062425955, 0.21514117132340158, 0.09439939992236239, 0.09523038818900074, 0.11452466036592211, 0.1315694193222693, 0.15717059985867568, 0.08316157079700913, 0.10444565370146718, 0.14047470289681638, 0.1936061933104481, 0.09804254943238837, 0.1044323815565024, 0.14761765460882867, 0.06680676660367421, 0.11833325028419495, 0.11553788956786905, 0.2218696874167238, 0.24248805961438588, 0.11627218659435, 0.13774165883660316, 0.08362608230007545, 0.07346775489194052, 0.11226926424673625, 0.11452954581805638, 0.14556039071508817, 0.07666533081127064, 0.18752235333834374, 0.07081285770982504], [0.053682274251644096, 0.02393489869843636, 0.018753705379952277, 0.017185426051063196, 0.030058670456388166, 0.005003808573487082, 0.05011208761217339, 0.050655723083764315, 0.059686382966382165, 0.024822493749005452, 0.05650868133774825, 0.03466763992660812, 0.027291821781545877, 0.07631416179771934, 0.020984947348811796, 0.09634321954633508, 0.03609550830775073, 0.019851999124512076, 0.018759825765820484, 0.06374537944793701, 0.011254309892787464, 0.05924350994506052, 0.0351038666974221, 0.07438204011746816, 0.05140957209680762, 0.03853089262598327, 0.0549359457301242, 0.05705336853861809, 0.02290422096848488, 0.033931548175002844, 0.060966147509004386, 0.045136234257370234, 0.03705683975879635, 0.013694922323338687, 0.03249578503891826, 0.0314794481465859, 0.06321291944810323, 0.062051376061780114, 0.03692961444279977, 0.040306048800370524, 0.0038019521494529075, 0.008624615197602128, 0.06863479422671454, 0.03067260215591107, 0.020564214925148656, 0.030629094490515332, 0.05308616766706109, 0.013338771166412957, 0.013529207108409276, 0.016867383117122308, 0.06542260944843292, 0.04628923488780856, 0.03217426800568189, 0.13330593971269472, 0.013530046795494854, 0.046128727429147275, 0.03826386534741946, 0.06003493283476148, 0.04215943327705775, 0.011978246537702424, 0.04004611221275159, 0.036960250298891745, 0.028757155473743166, 0.038015755625175576, 0.043314232025295496, 0.034278819004872015, 0.0380347715690732, 0.021984151231923273, 0.02695880357974342, 0.03250046353787184, 0.028270686577473367, 0.022329732509596006, 0.03010430872174246, 0.021509750080960136, 0.029677761252969503, 0.08456557510154587, 0.03056456581024187, 0.012242787833591657, 0.03521884784900716, 0.09856073984077998, 0.01904293262798871, 0.0997319184243679, 0.010002704553439148, 0.005306111191332872, 0.03790125623345375, 0.00494488501655204, 0.039134897358183346, 0.021042680500873497, 0.04956128681078553, 0.005522653768171689, 0.045807427527116876, 0.011128652840852737, 0.04324782380302038, 0.023561070007937293, 0.018284266016313007, 0.04444257130048104, 0.04021911150110619, 0.025313254379268204, 0.0315538020139294, 0.039970024688435454, 0.008375374866383416, 0.044758900933499844, 0.001635895873602879, 0.02449738048017025, 0.019129276209111725, 0.020711070259234736, 0.08980233874171972, 0.03674006229266524, 0.012894497818446584, 0.040725023818335364, 0.039249909043844254, 0.05893126170017889, 0.017201492063967243, 0.028874148481658528, 0.03815296558397157, 0.02380925097635814, 0.05768703203648329, 0.04109453363344073, 0.025361331978014538, 0.007530475783694003, 0.04906642443633505, 0.03401793246822698, 0.028414145843791108, 0.05042035285649555, 0.034254893860114474, 0.04484776187954204, 0.011191603079039072, 0.04993723253054278, 0.027328215007271086, 0.009367190351310586, 0.029211750187511955, 0.04433424657742892, 0.017122663258175765, 0.03520846626322184, 0.054057809457715066, 0.07836002630314656, 0.03230315573247416, 0.03277813024552805, 0.0773111672273704, 0.049654361459293535, 0.03562235566122191, 0.03182714306084173, 0.06469246505626611, 0.03751604851069195, 0.04330958406041775, 0.03086574375629425, 0.03172750019335321, 0.018317120681915964, 0.03493073170206376, 0.07296593074819871, 0.006513822948493595, 0.016250884858891368, 0.04147244371207697, 0.038951580944870196, 0.062027864823383946, 0.01720956663068916, 0.013508673790576202, 0.03814328628193055, 0.09136551379093102, 0.06701796062822853, 0.046654656529426575, 0.0260939886460879, 0.06953806682888951, 0.01927316464882876, 0.03455400227435997, 0.0291669465202306, 0.009006966287935418, 0.011392718314060142, 0.028656779788434505, 0.058159333121563704, 0.08412983348327023, 0.019469681960929717, 0.022443329449743032, 0.04803250330899443, 0.030839440346296345, 0.08145529949771506, 0.055985551194420884, 0.026996784577412263, 0.05939271979566131, 0.027496963273733854, 0.0022812296436833484, 0.04466616215982607, 0.042719631788453886, 0.04128089666898761, 0.05274967197328806, 0.030569949985614846, 0.041217555424996784, 0.024623698255579387, 0.02075327344105712, 0.0021458546980284154, 0.03672516166365572, 0.015460795290502054, 0.020811812353453467, 0.04543592281905668, 0.018354962579905987, 0.026131725371150032, 0.026336978821616088, 0.05202069466135331, 0.024432370040033544, 0.03331801002579076, 0.042217644796307595, 0.01738940385569419, 0.05899931876254933, 0.052480028942227364, 0.05036896061418312, 0.012289943472881402, 0.03128827090508171, 0.01363386943869825, 0.032313625527811904, 0.05182950384914875, 0.01620748406276107, 0.02862974695329155, 0.05492749796914203, 0.0028689071269971983, 0.023880101906667863, 0.07501981553754636, 0.04439737408288887, 0.016090689526338662, 0.055489613341965845, 0.04355812804507358, 0.023516690425042595, 0.05227298076663699, 0.032845820898988416, 0.026485520315223506, 0.023486648287091936, 0.014361332769372633, 0.050217481063944955, 0.07657552670155253, 0.044201304603900225, 0.15468119058225835, 0.014932235170687948, 0.040104361051427465, 0.006916156471041697, 0.025781818432733417, 0.045596294570714235, 0.03429064926292215, 0.01410223332433296, 0.01505950459146074, 0.059944843740335534, 0.0423082088652466, 0.061003433008279116, 0.004890593733372433, 0.04788868102644171, 0.021078909181856682, 0.09313278538840157, 0.0518095990243767, 0.00778408333592649, 0.06742917999093022, 0.02929731345336352, 0.03283680656126567, 0.02709404069797269, 0.037605998505439074, 0.04577575011977127, 0.029079259439770664, 0.043853175427232466, 0.03921485592478088, 0.07017278205603361, 0.027002501234944378, 0.059319186955690384, 0.011370129883289337, 0.019923033259276832, 0.04423677841467517, 0.03148196890418019, 0.06766659260860511, 0.02408308905017163, 0.007634712333258773, 0.041862279043665955, 0.04577606563855495, 0.00897652211798621, 0.02005076238752476, 0.061697465766753466, 0.07648534939757415, 0.009915748594461806, 0.06915172934532166, 0.026899776122133647, 0.01799783602889095, 0.01238357791277979, 0.049906148841338496, 0.03622612290616546, 0.01111404991908265, 0.004414915240236691, 0.01333083994021373, 0.10544698818453721, 0.03875832399353385, 0.033241074332701306, 0.041864508031202216, 0.022223694449556724, 0.06710902681308133, 0.014707421251971806, 0.01085411587597004, 0.009751236931021725, 0.02618523803539574, 0.009339916636236012, 0.033420367033353875, 0.049823309893586805, 0.02018927174088146, 0.052199020449604304, 0.03541097164686237, 0.08293052283780915, 0.03641603467985988, 0.018513303815520236, 0.06399866299969809, 0.032125182782432864, 0.02155984123237431, 0.01940159097180835, 0.020483282660799365, 0.0723360399050372, 0.03172346969534244, 0.03658223844000271, 0.029315298024032797, 0.04602283186146191, 0.0024210839806723273, 0.020741583979023353, 0.01752995390311948, 0.06766140181571245, 0.029810550556119, 0.014643387902261955, 0.04523250480581607, 0.06259400051619325, 0.023179631547204087, 0.013051936602486032, 0.0644452136808208, 0.039654668753168414, 0.01074011011847428, 0.018276797042095234, 0.0376635722017714, 0.02499794085243983, 0.03711523108982614, 0.09609862802816288, 0.06765952227371079, 0.0355341053966965, 0.027683160068201165, 0.05991643347910472, 0.05395146944959249, 0.03435349517634936, 0.008455479318009955, 0.05736991191016776, 0.048584138708455224, 0.02578031038865447, 0.018669655247192298, 0.027617966423609426, 0.04777833426903401, 0.0061702531030667675, 0.04792584438941308, 0.015501933172345161, 0.04214772515531097, 0.021491656944687878, 0.04310466648478593, 0.011434373578854969, 0.04692862182855606, 0.04697012442297169, 0.08303743960069758, 0.24234106178794587, 0.15973951986857823, 0.1542024841266019, 0.10956870165786572, 0.09834677739334957, 0.15782090782054833, 0.10320819581725768, 0.13105096428522042, 0.15969647360699518, 0.07044645558510508, 0.14911447571856634, 0.0800411103825484, 0.1201905363372394, 0.15142405964434147, 0.11735335072236401, 0.1761628221720457, 0.09883743285068444, 0.13329238258302212, 0.146450777937259, 0.09727419673332147, 0.10927841759153775, 0.11224831108536039, 0.16052974175129617, 0.10905078266348157, 0.13750029035976954, 0.07268079676266227, 0.08632027344512087, 0.16014182328113488, 0.08415762627763407, 0.11736857704818249, 0.12458755182368414, 0.08376263068722826, 0.14527613882507595, 0.17807322394634995, 0.11890198476612568, 0.0705003651923367, 0.10816843608128172, 0.10927337607634918, 0.08343211627964463, 0.19435910933784076, 0.12454422057739326, 0.1051464243126767, 0.134040467441082, 0.08116152097604104, 0.11469565119062151, 0.18053783955318586, 0.09247072520000593, 0.1271478815802506, 0.05683662409761122, 0.06224135908165148, 0.14578791707754135, 0.13279923690216883, 0.13179758350764, 0.321017007210425, 0.18012499170643942, 0.11075466551950999, 0.1607456515942301, 0.20039432549050876, 0.11307739945394651, 0.15682370561574185, 0.11679452285170555, 0.05965268013200589, 0.13015884001340183, 0.1442743632942438, 0.1258911533015115, 0.1297176294028759, 0.14660628459283284, 0.10126017606151955, 0.16561377394412244, 0.14010537628616604, 0.08209513766424996, 0.09502165046121393, 0.09818644635379314, 0.15507691220513412, 0.09666038717010192, 0.11966444099588053, 0.2100973084036793, 0.14690249226987362, 0.0792874615373356, 0.1582775076052972, 0.15996849829597132, 0.19516306476933615, 0.16344881297222205, 0.15358805709651538, 0.14311159854488714, 0.12010996708912508, 0.13727549170809134, 0.1256020838128669, 0.16149681700127466, 0.04861423173653228, 0.09308196990085499, 0.07814693238054003, 0.19357690773904324, 0.09631905012897082, 0.15847207073654446, 0.1938334618295942, 0.07815109858555452, 0.17150389216840267, 0.11694918812385627, 0.08099961573524134, 0.06312657586698021, 0.2158899482871805, 0.06811743841639586, 0.13013414133872303, 0.06969759719712393, 0.1410776898264885, 0.23575004403080257, 0.0779487933697445, 0.11247408682746546, 0.15955828316509724, 0.11181444900908641, 0.13550461030432157, 0.0773538877921445, 0.11992110365203448, 0.11886868226741042, 0.07727098438356604, 0.154486369607704, 0.0913094464423401, 0.16243502737155982, 0.10271084321928875, 0.12608752133590834, 0.12839163626943315, 0.24974936140435083, 0.13946682055081638, 0.10638253869754927, 0.1628186982125044, 0.048537180692489655, 0.11739672268075602, 0.06992673847292151, 0.14515624168728078, 0.11779396422207355, 0.15775366500020027, 0.09372256802661078, 0.08137098473629781, 0.14728582384330885, 0.18330392826880726, 0.12367906128721577, 0.09574861930949347, 0.1574765241571835, 0.11879702896944114, 0.09660320023873023, 0.1060049475303718, 0.2027609334992511, 0.0882465054414102, 0.1376964141215597, 0.19052383942263468, 0.11506682341652257, 0.049944832122751644, 0.10245954777513232, 0.14427206984588078, 0.0914053370111755, 0.11021867713757924, 0.1518370703394924, 0.23936845415404864, 0.11101664110485997, 0.10046124178916216, 0.23546937480568886, 0.13539010073457444, 0.16481986083090305, 0.10033277475408145, 0.13142843331609452, 0.1065960940239685, 0.13066238085074083, 0.14300228655338287, 0.12657557800412178, 0.14214453686560902, 0.08946020102926663, 0.09267788872654949, 0.06332240785871233, 0.12532297521829605, 0.10954859666526318, 0.0901894158284579, 0.0809323118467416, 0.1741887331008911, 0.17638595162757806, 0.23457110300660133], [0.04529844144625323, 0.09602203499525785, 0.016505662884031023, 0.015648464505959834, 0.04676275733592255, 0.06009043021393674, 0.040097850507923534, 0.04414867064250367, 0.0167192894566272, 0.04723731794261506, 0.06171164036329303, 0.019553672721875564, 0.029354025410222154, 0.020011968844171082, 0.022882076978151287, 0.026479588222822974, 0.010332796572973686, 0.01682727660850755, 0.03316442023164459, 0.04983886191621423, 0.023272355053839937, 0.008551932222742056, 0.03903316460283739, 0.020093009674123356, 0.03893568965473345, 0.04280400083267263, 0.02184611006772944, 0.047118340219770155, 0.04883557325229049, 0.05168327955263002, 0.03766850515135697, 0.031982683643166504, 0.06085750726716859, 0.013870409290705408, 0.056552803077335866, 0.024022794428414533, 0.003770037678935166, 0.019847061085913862, 0.07557535929871456, 0.017359792587480376, 0.047535985309098444, 0.03099334565922618, 0.052087228412606885, 0.0700227308220097, 0.0032195685115376754, 0.051781823193388324, 0.05005035449617675, 0.05295702888231192, 0.02925215694787247, 0.016815770350928818, 0.05357000384745853, 0.05102921589942915, 0.07704873702355794, 0.038484660642487664, 0.01261813220168863, 0.018437290930056145, 0.11197457648813725, 0.02158941009214946, 0.024005366256460547, 0.04987051557483418, 0.038313527325434346, 0.03309682118041175, 0.041026591922023466, 0.017061288069401468, 0.03275352317307677, 0.04568810375141246, 0.03155924725745406, 0.04432189724008952, 0.03697451310498374, 0.07918176613748074, 0.013558200061587351, 0.016860076991309012, 0.10372165683656931, 0.034048622607120445, 0.02471169237313526, 0.05301021245707359, 0.04907584250239389, 0.04205682181886264, 0.016597237970147814, 0.0492470843850502, 0.022749475968469466, 0.07045590757791485, 0.08801120985299349, 0.003323060368919479, 0.11560817222510066, 0.005418122479958194, 0.021016670557271157, 0.042391122451850345, 0.047359070873686245, 0.023769846751487682, 0.055665801744908094, 0.014783839562109538, 0.03898793345849429, 0.007279767272328692, 0.0321633164504809, 0.020705165308234946, 0.04268728941679001, 0.07089032605290413, 0.07054451746600014, 0.07450412892337356, 0.028235511322106634, 0.012399995915724762, 0.041080409927027564, 0.05524730170145631, 0.03641330357640982, 0.01535490820450442, 0.021123046188482215, 0.01331076632985579, 0.05664433745135154, 0.045585516041943004, 0.057311557898564, 0.03669131633692554, 0.03862456438530769, 0.062400909805936475, 0.0665904428543789, 0.01892693367387567, 0.04036760549726231, 0.030613535682537725, 0.011966384897407676, 0.019240474527967826, 0.06976477216397013, 0.006499477021861821, 0.011622085202751415, 0.0483581356571189, 0.037738675850310495, 0.08626786340028048, 0.03382640238851309, 0.0327138967279877, 0.0520034293378038, 0.05414854655308383, 0.05236242864547031, 0.036397042484687905, 0.04980018881282636, 0.041459599044173956, 0.10462407448462077, 0.01876953729827489, 0.021041306467460733, 0.021041068980204206, 0.05067506811714598, 0.05685411673039198, 0.015340547010834728, 0.05848678055086306, 0.010328218157935356, 0.02203693786369903, 0.02708793049012976, 0.04901620605960488, 0.05007301078044942, 0.02711860366564776, 0.03600548367415156, 0.07337282105748143, 0.023028774552845528, 0.034778838245464225, 0.03631479386240244, 0.032155825423875024, 0.06147985280092273, 0.03024601736771209, 0.036861727014184, 0.021263765869662166, 0.006032172074940587, 0.06312192790210247, 0.04814648701410208, 0.0355034288285034, 0.005344646891379463, 0.060753216434802325, 0.08897323680243321, 0.03432692713769419, 0.03204059660700815, 0.010660213468197201, 0.016309552692941258, 0.021501091974122182, 0.0040070334216579795, 0.04793068573677114, 0.015215817007369228, 0.04130252497270703, 0.01528519212401339, 0.02444559977655964, 0.03579362129260387, 0.05136801861226559, 0.03854041247229491, 0.04398067215723651, 0.015328832103737762, 0.026117040177008936, 0.04930527215557439, 0.01798167671742184, 0.030866201767431836, 0.05718873627483845, 0.0187743769492954, 0.025794627477547953, 0.04000093535120998, 0.06649599756513323, 0.03406975218760116, 0.08454547010894332, 0.01677176565863192, 0.024539054404678087, 0.041189626923629215, 0.02172452168140028, 0.07071818850402321, 0.012604265490413775, 0.09514984608228717, 0.010617610798882586, 0.011613005556033125, 0.023818533335413252, 0.045522900830422125, 0.007424004309411559, 0.05018078589013644, 0.05556473056120532, 0.02586612810513803, 0.0379528893556978, 0.05137533661244171, 0.056336078992379565, 0.03399428552282708, 0.02057621142427836, 0.009427605413033493, 0.07358963335199015, 0.020300363190472126, 0.028727506886103323, 0.038884477224200964, 0.026749450081427182, 0.006025720479166401, 0.08380689831184489, 0.017194464137511592, 0.08259997450347457, 0.045673871479396305, 0.025094825475077544, 0.058422930405608246, 0.03594415428649102, 0.023399861961869255, 0.042608521679150205, 0.07184823429478066, 0.016222369424732666, 0.013230717009199517, 0.07549451863659279, 0.045734050750200234, 0.050982264668813775, 0.01871756830119661, 0.08252870797046594, 0.021545052561642866, 0.03502828807436994, 0.028734312592340366, 0.019019526562520435, 0.020218046714684794, 0.02988715037437422, 0.03952843409829906, 0.015063674189150333, 0.009924643340387514, 0.06423214689961501, 0.032212062406220605, 0.055454777354108434, 0.06840920847441469, 0.02172107811618064, 0.023965370009786317, 0.0522849704804165, 0.039485286056463204, 0.038301849737763405, 0.035555798161242685, 0.03585029253736138, 0.022942912731585757, 0.029864816394235407, 0.025098872936463783, 0.014440105596025075, 0.03155384272603052, 0.04423416266217828, 0.028714533296546767, 0.01740125277345734, 0.032164880473698886, 0.010868233645201793, 0.06560303190989153, 0.03554200015163847, 0.12118898704648018, 0.013350844848901033, 0.08297780994325876, 0.060121425693588595, 0.02444772019849292, 0.07968977173524243, 0.024472060945949385, 0.07032921151923281, 0.021439292700961232, 0.03016082729612078, 0.034689115559948344, 0.07524804079106875, 0.015383683178307754, 0.016945306078663895, 0.058200248783188205, 0.009794064365061266, 0.046951227222702334, 0.03787218440057976, 0.06133830361068249, 0.0928263793300305, 0.017497940620939647, 0.04477563360705972, 0.045289783339415274, 0.025976425668756877, 0.024621264011199986, 0.04238759406975337, 0.024560197555859174, 0.04795889922284654, 0.027099782800568, 0.006856693054682442, 0.024906735567908202, 0.009965137462131679, 0.05033991592270987, 0.03943869105673262, 0.07151007958288703, 0.021606381949303404, 0.04242396693942802, 0.023442529940179417, 0.10171537127877985, 0.018903396990416304, 0.04113151039928198, 0.08381221802639109, 0.0721781990889992, 0.0720833195373416, 0.009496957629120775, 0.014927487121894956, 0.036787186549710374, 0.077239072881639, 0.029491544102451632, 0.017732932564935515, 0.07009206353021519, 0.036892814096063375, 0.02772220127683665, 0.05958202428051403, 0.04866501669000302, 0.018768044521233866, 0.05614044038312776, 0.03524028616292136, 0.03109618442665253, 0.027893527976370285, 0.02854137115978769, 0.05778934833194528, 0.04567218192719987, 0.05525735419775758, 0.05423670182270663, 0.01999398088082671, 0.011931621852064771, 0.04714077598016177, 0.047801187328462086, 0.05820265079715422, 0.029432844037988355, 0.05085587055821504, 0.04387737877134766, 0.02193759015894362, 0.024498839330460345, 0.03948241585333433, 0.013790334524985935, 0.015367052285000682, 0.0066709695383906364, 0.04075636195817164, 0.03627479761572821, 0.026458370432789837, 0.04352952100868736, 0.08620597422122955, 0.12822284389819416, 0.18271633051335812, 0.23550026171973773, 0.09922941574560744, 0.14429235804293836, 0.15463378812585557, 0.1502374511744295, 0.09575065491454941, 0.14677278351570877, 0.13433983709130967, 0.18276032672396728, 0.10475294864071266, 0.08257361341800008, 0.12721346877515316, 0.11363994569650718, 0.1606637659881796, 0.07722502042140279, 0.11137966412518706, 0.14235362064625534, 0.16401633966181958, 0.1775449572929314, 0.07654449729514973, 0.1446660544191088, 0.0937699976244143, 0.13660250710589544, 0.08883422533316271, 0.1462405135056802, 0.0674092039199812, 0.16553419535713537, 0.19120876624115876, 0.08815464537058558, 0.07690300127225262, 0.09711723801280771, 0.08713602860059057, 0.2050565124622413, 0.1881761218288115, 0.09242951098297324, 0.15222274964409216, 0.14561973538781914, 0.17589034964995726, 0.11458780483475753, 0.1462325339338609, 0.16896291423056806, 0.17267710635704653, 0.09201893622853927, 0.19432090781629086, 0.17587519117764064, 0.1528821906873158, 0.12950760924390384, 0.14270128841911042, 0.11141435762069055, 0.1572176901889699, 0.24400029703974724, 0.07444795979452984, 0.18798799120954104, 0.115645953054939, 0.28363081333892687, 0.1045077396556735, 0.1148118299565145, 0.10223445056804589, 0.14283200140510285, 0.12952151921178612, 0.09594563873750822, 0.1235312492187534, 0.13479298991816385, 0.16731811820396356, 0.169499418299113, 0.11876872048846313, 0.13080761448613235, 0.24434824979731015, 0.15102261118590832, 0.1978579887322017, 0.17394452834767954, 0.062078877086085935, 0.07190638474587883, 0.11156837149922337, 0.15634395421615668, 0.1607447966401066, 0.10499688876526696, 0.13531970951173986, 0.08720565307885408, 0.2106882988342217, 0.12972775314535412, 0.1004774859175086, 0.29529597024832455, 0.18097591533192567, 0.12884663471153804, 0.10056465731135436, 0.201661028234022, 0.15763895186994756, 0.19469110295176506, 0.075451336668006, 0.16845064743288926, 0.11622869249965463, 0.1893560399434396, 0.12236737167196614, 0.13813584697033676, 0.11361977285040276, 0.1725966999573367, 0.1262204870581627, 0.0947346572897264, 0.126307787373662, 0.10789756490183727, 0.11013839287417275, 0.0789117906242609, 0.11470593778150422, 0.1164628549345902, 0.12149393425456115, 0.10074259633464472, 0.15921195889157908, 0.12247498732592378, 0.24220597903643334, 0.05898897788886513, 0.18994183279573917, 0.12738120263176306, 0.11886390538087913, 0.1558808676366295, 0.08231735788285732, 0.0806335121659296, 0.16198967769742012, 0.11218055257839815, 0.08207176891820771, 0.08639371807553939, 0.14743257739714213, 0.09179873125893728, 0.14438571089080401, 0.1241745004164321, 0.10215358276452337, 0.1359631506992238, 0.1681685939963375, 0.2174831349402666, 0.158530343323946, 0.10990088526159525, 0.10769411974719592, 0.2505143960671765, 0.11037395309124674, 0.127510042861104, 0.10190552393240587, 0.1593329823975052, 0.15517183925424302, 0.14870302565395832, 0.1274612019104617, 0.09795891320598976, 0.10940542577632836, 0.15161680430173874, 0.1062058142519423, 0.13999733994049685, 0.09102100120591265, 0.15278605584587368, 0.1384006520467145, 0.10792850609868765, 0.10951357068760054, 0.09903143958321639, 0.09653801337948867, 0.16147148050367832, 0.14791186739291462, 0.17557749072355883, 0.14194624179175921, 0.09456182084977627, 0.1325705163180828, 0.14948482013174466, 0.15955778104918344, 0.17004373909107276, 0.2016978726855346, 0.16720465357814515, 0.06945702260626213, 0.06153655797243118, 0.10374258964189462, 0.13873341919056006, 0.12417401187121868, 0.10064648863460336, 0.09961462007569415, 0.1430987742330347, 0.09747306856193713, 0.09146694120551858, 0.12153787618236882], [0.015370171849748917, 0.032966070874993286, 0.02650251761744065, 0.06076297376837049, 0.0018788002780638635, 0.0649212399231536, 0.051017972574170144, 0.03995912402336087, 0.03524800789143358, 0.03625420068523713, 0.047415328212082386, 0.05333039616899831, 0.002298119228466281, 0.031165805512240956, 0.02312889409118465, 0.07258095033466816, 0.028117183296542083, 0.02664704218373767, 0.025378799165732095, 0.05170114877234612, 0.03783180478161999, 0.06794236959623438, 0.039733280427753925, 0.043706364197922606, 0.03552167463515486, 0.02036156874549176, 0.012613155995495617, 0.043210083685283146, 0.030619466078600714, 0.022502285661175847, 0.07712007819541863, 0.065352788195014, 0.03284425348309534, 0.043647616636008024, 0.07941415759601764, 0.013901853451638349, 0.07000898370253188, 0.06286217791161366, 0.05721980639334236, 0.02125300600060395, 0.02342618233524263, 0.03386047841714961, 0.04482756189203688, 0.041693832725286484, 0.023046743856476884, 0.05460647287379418, 0.0500465173806463, 0.060472194371478896, 0.04065417119168809, 0.0017714414072023438, 0.04675447242334485, 0.05629040340759924, 0.027107723356623734, 0.0657349866149681, 0.013476872550589698, 0.021924791292154362, 0.051600661128759384, 0.03614743998540299, 0.040481955611280034, 0.03963413628350411, 0.0508154230857534, 0.07354938944003411, 0.04483082903815167, 0.028359706979244947, 0.03809028591162392, 0.02735696453601122, 0.028268961402188455, 0.012737076845951378, 0.0753465708611267, 0.09153688459524087, 0.015621180612859982, 0.019149577976869683, 0.010246808374566692, 0.06009859299021108, 0.007921405253000557, 0.08443605633718626, 0.07206999310957533, 0.06445087944822651, 0.009634992007964423, 0.10937958037746803, 0.01699588747162904, 0.031284148804843426, 0.03975085448473692, 0.006314542726613581, 0.031231877859681845, 0.056094428923513205, 0.037208614471767626, 0.0677223206896867, 0.07491715318922486, 0.03292698386524405, 0.011758955894038081, 0.04369956866971084, 0.02663682005368173, 0.010082971005301391, 0.03086062420957855, 0.0721669082662889, 0.06673835670309407, 0.04352501214348844, 0.008984960549111878, 0.057836180818932395, 0.0075174496076735, 0.023468081872644167, 0.007098586972071124, 0.015441733545490673, 0.046281852426805666, 0.021493777366621152, 0.038168276726667366, 0.0030819645783464822, 0.03125558926590851, 0.059464976989797184, 0.04119995761928814, 0.025270925668467368, 0.036033401997493844, 0.02383453997650317, 0.03147058987191745, 0.01086054160259664, 0.02423579165978091, 0.03464203201500433, 0.06509786937385798, 0.026221948476242166, 0.08028477909309523, 0.07966201286762953, 0.053267960769257376, 0.058122855078961165, 0.10861844729099955, 0.041940646445644755, 0.05399009505552905, 0.09093775852982487, 0.023845725626285588, 0.10349251556077174, 0.048482012402798445, 0.03505383152514696, 0.018008477154320905, 0.020332298441124812, 0.07110781688243151, 0.04770454697843109, 0.02560546718138669, 0.02741210738063923, 0.03539104646603976, 0.0172127591379519, 0.00780093136043953, 0.007212568556756845, 0.07949617212372166, 0.020559904531442692, 0.027974219360787953, 0.04554521445451038, 0.018915966851636767, 0.057694719838244576, 0.08703639930380241, 0.07156418596527406, 0.01592434836285455, 0.030656201964510337, 0.021683107296537076, 0.03110129040266786, 0.04005434962787798, 0.044416010047176054, 0.035039843525737524, 0.04503883734079344, 0.1140850375273398, 0.032745675915586095, 0.062237477861344814, 0.06554980083767857, 0.0782541816255876, 0.05269253932471786, 0.02155306775655065, 0.012882336774574859, 0.014739804335736802, 0.016173077248302952, 0.018753763055428863, 0.03869538987055421, 0.02692425257659384, 0.016990449013454572, 0.030590431565152745, 0.029253799002617598, 0.06467115905668054, 0.01300527120474726, 0.028268206531980207, 0.03454722370952368, 0.051434257200786045, 0.021019854582846165, 0.0379754811791437, 0.028524960790361677, 0.06347411471818175, 0.03373371450496571, 0.031531237331884246, 0.03859715835590448, 0.013634137460030615, 0.042486344663692374, 0.020942396417792355, 0.03298588749021292, 0.03985180013946124, 0.04299259964110596, 0.012182713735715618, 0.018410750032801713, 0.018803165493799106, 0.05117673280515841, 0.008792034383597118, 0.04127433184268219, 0.00987348604082529, 0.036259221844375134, 0.03564318668629442, 0.031120808462479284, 0.02952463286263602, 0.03283161237569792, 0.01659745510135378, 0.050563405001802106, 0.051068618427962065, 0.04713350208476186, 0.018621616664209535, 0.024537319051367894, 0.0866716324484774, 0.02437386166171304, 0.022206671702276384, 0.07134569768926927, 0.04316543608105608, 0.028204615926370025, 0.05365279869043401, 0.021874647554276243, 0.02746825784976993, 0.01795371259296579, 0.0026023351030224668, 0.03288271624062743, 0.03778139302240951, 0.05418346396514347, 0.08604597566383225, 0.005272040675793375, 0.019257427725408758, 0.02022728666530124, 0.007461197358289999, 0.036375546495297124, 0.04062655142375401, 0.05873173847794533, 0.018190290612567748, 0.026463233832535998, 0.032977799352790625, 0.030650746542960405, 0.08608522891466107, 0.07034506888261863, 0.04305345744692853, 0.012576517648994923, 0.029996574324156557, 0.015242161129468253, 0.040560438364212, 0.011704105667636862, 0.11806190413023744, 0.01807106183176594, 0.032115903816052845, 0.047256981887455494, 0.012227705696464648, 0.013724625193780022, 0.08414805214852095, 0.020595858405743326, 0.04739633262423532, 0.020872899164844836, 0.026133321624781405, 0.02720479288005403, 0.047774320734398704, 0.03870177488507969, 0.02421395301020571, 0.024546241786863123, 0.02040701193202819, 0.016434257251343558, 0.055375534641955576, 0.04464302072301507, 0.049369203725031445, 0.007818190746807625, 0.010933763164627765, 0.025089387016903077, 0.02630779503046402, 0.0024561693301490906, 0.03628793405368924, 0.04380661096157772, 0.09256114677659102, 0.017459449025669267, 0.012536434889105814, 0.05014246901763337, 0.030430561929408993, 0.0021513928160337465, 0.015084837696381977, 0.021594517764502337, 0.03638915451509612, 0.03041247897116201, 0.07166364562830754, 0.013491813891700335, 0.04335249122232199, 0.01147759795588042, 0.025197550587888275, 0.05994376486965588, 0.03591251080589635, 0.02191852841393224, 0.02317528722674719, 0.04113689118197986, 0.06178712738411767, 0.029289639222302606, 0.02750705648213625, 0.024026609491556883, 0.025011262191193442, 0.07093449868261814, 0.06538098132503883, 0.054002532602420876, 0.02606836716378374, 0.03141842409968376, 0.02345474696319018, 0.016636365691998174, 0.04081480757200292, 0.005931974080989936, 0.06219940526144845, 0.02149369254974382, 0.026038299580769877, 0.04488616356892245, 0.03062091475086553, 0.0958450391356434, 0.023645854654854963, 0.013612584643332022, 0.009578766899981668, 0.026335638714954257, 0.03535301457824452, 0.006913137838377484, 0.014754423372713583, 0.0368757828670953, 0.016331579635984132, 0.044021055168871365, 0.026875126641243696, 0.03181846459795322, 0.04638115263410977, 0.03248342891622867, 0.013905293624182897, 0.007284818117373756, 0.029097956472209523, 0.02838906379682677, 0.008682532402287637, 0.023973702419815317, 0.010885543921696288, 0.08480013787214245, 0.047327993969832144, 0.0200950198341161, 0.04449268111160823, 0.008585270344545799, 0.10195553874863045, 0.031796059371637445, 0.007817850631129528, 0.03881269839725324, 0.05010625221101301, 0.02535027524988566, 0.03467252537874239, 0.0045380676497838324, 0.022018395197976912, 0.08648775624377386, 0.03172578349975603, 0.024286038874249374, 0.04882912038426314, 0.02342700845162783, 0.07836010094199862, 0.09068681592387812, 0.09738323052546807, 0.0879523130133748, 0.12556515793715203, 0.16906940351639474, 0.23660787514277867, 0.17858956195414066, 0.09778319299221039, 0.08252053840884141, 0.129033910376685, 0.13443724757858685, 0.08846060359584433, 0.11239874908434493, 0.1281292467777218, 0.1265152155288628, 0.10952724995357649, 0.10549211076327733, 0.10721747603799615, 0.1549767061535801, 0.1463359969535044, 0.1395853063357728, 0.19896169379353523, 0.08062511190239872, 0.13619550823100976, 0.09111738710531167, 0.0772993675033961, 0.10174197663686105, 0.15795885398983955, 0.14553422640476907, 0.09853545084063496, 0.17503709186400684, 0.11472621240786143, 0.13106423643018517, 0.1651542836001941, 0.13734189314501627, 0.17017112725547381, 0.15670644119381905, 0.17949266492256097, 0.1402361299842596, 0.08328343568635838, 0.08946935446666819, 0.05439057320888553, 0.1092650843784213, 0.08757916625056948, 0.09385663976094552, 0.08506290734346424, 0.18935139876391205, 0.20738688670098782, 0.1153598419789757, 0.17214968108705112, 0.1109142094584448, 0.10471897439232894, 0.13375754547970636, 0.10676707127796752, 0.10356276429125241, 0.0944583849715335, 0.0963598300835916, 0.0961879843047687, 0.15931578832013266, 0.13676258708749497, 0.16536769643425941, 0.11495510941105229, 0.09874744553651128, 0.10845249119613852, 0.10942798706569842, 0.08554988514099802, 0.05794465821236372, 0.22943687279309544, 0.21878867702824728, 0.11941347803388323, 0.08901399640100342, 0.0730482709727117, 0.1560024611119713, 0.09445983703647341, 0.13664022008223192, 0.15755588561296463, 0.10961484882448401, 0.09226509516260453, 0.1461192185857466, 0.10749024711549282, 0.127634554037026, 0.1397513709962368, 0.049634042728160105, 0.12990014175219194, 0.13923212885856628, 0.16502252567027295, 0.18441572146756308, 0.19547342668686593, 0.10181651370865957, 0.11905675860387938, 0.08223163855395146, 0.15444919945938246, 0.1316385077578681, 0.14528147211032255, 0.1671560840415103, 0.19059041727866444, 0.08999671188316175, 0.0980595535199557, 0.21285518684557506, 0.06039297540805169, 0.08282927862767663, 0.11714756462190833, 0.0879233463534287, 0.09292362018355302, 0.14478109324617044, 0.1431363107902663, 0.043301207545612536, 0.09653905832341739, 0.20431549793907575, 0.09612669902188437, 0.15955038501748017, 0.11811193930251257, 0.09339862183800765, 0.06544466862188918, 0.16519734343247755, 0.09623112556125436, 0.17051753295319422, 0.16988068712609156, 0.10705466156027146, 0.1969166435301304, 0.15515255528901303, 0.15997544649456227, 0.1596672830304929, 0.2282498979142734, 0.08247938525996037, 0.10367819666862488, 0.2748888667140688, 0.09094058802085263, 0.16816790189061845, 0.16526245565286704, 0.15350226312875748, 0.09561042886759553, 0.11014589068612882, 0.1598642481757062, 0.2126850781163999, 0.185196009597608, 0.0921735472178885, 0.12785058601626328, 0.08151915642832007, 0.1339626530451434, 0.08016197782542024, 0.16841320587056025, 0.08057502923267228, 0.08257028181105852, 0.13725916615554265, 0.1549093819090298, 0.06797327686633382, 0.11111356983227388, 0.1664923546569688, 0.0903152230062655, 0.18108293387506688, 0.07395074968891484, 0.08854567831648247, 0.11378232269947018, 0.18418446316250733, 0.10483272400285516, 0.15934169478714466, 0.19842213631740638, 0.11662241922957556, 0.15921475445585592, 0.17277454398572445, 0.21186976400869234, 0.21681545648191655, 0.11115802066134554, 0.18975891332541192, 0.16778861438589437, 0.1873882476772581, 0.09677777372832809, 0.12858258959438118, 0.11431259103119373, 0.14755079176809105, 0.12932827243847506, 0.1075133987303291, 0.10343778492616755, 0.07136954819517476], [0.029663213462169682, 0.010788314094367837, 0.02665369352325797, 0.01880564893196736, 0.04258108511567116, 0.03831572238621967, 0.02978481711553676, 0.010301098809577525, 0.03987806962270822, 0.018236071370275955, 0.015309105394408107, 0.03186690182025943, 0.023687720265505568, 0.03698965122124978, 0.05242744247828211, 0.05247175760035004, 0.10012002009898424, 0.027468802374122397, 0.07472252220447574, 0.03253690765372344, 0.018706632013033544, 0.0304998878522643, 0.029861413541116884, 0.02925132234979953, 0.03873707566942487, 0.06130572035908699, 0.019018230560634817, 0.02280708189521517, 0.009940415038727224, 0.06439285113343171, 0.05445854884705373, 0.07455780782869884, 0.040951437383357964, 0.11612897499331407, 0.048215860434408696, 0.06057356071791478, 0.050796217152050564, 0.02825714641117624, 0.07338903125907693, 0.02745155062127326, 0.023256557062268257, 0.08607769717595407, 0.0032878560637722588, 0.0146600323662694, 0.027251347167683498, 0.00961293453084571, 0.0563679396041802, 0.06285145027296883, 0.07482122869363853, 0.0600226242095232, 0.050479829843555174, 0.02990903312872563, 0.021494700174246515, 0.05499168398923107, 0.08740789722651243, 0.03459966089576483, 0.047891826036253145, 0.02575623257351773, 0.0490466213918158, 0.0033094568020065446, 0.04013938024373991, 0.013671178686698633, 0.016000819259456227, 0.04403601008068238, 0.015401213130514537, 0.017838181828015616, 0.029815778668437685, 0.04337554784225566, 0.060554880648851395, 0.01904142797658486, 0.03302510002894061, 0.010723430879547127, 0.04109748526077185, 0.02402194625964122, 0.08430543156074626, 0.06751557785485472, 0.04880689496972731, 0.1198707427829504, 0.05592165015903967, 0.08294210543057748, 0.022124562179669738, 0.04825760390875595, 0.016487737685175877, 0.05352863356737154, 0.0353061820912574, 0.03963980205090983, 0.07218674184488398, 0.02181922990296568, 0.024063286005652378, 0.03184150764718652, 0.0075144750797855, 0.030185905950410024, 0.027807432060529078, 0.007034498491391007, 0.07000668346881866, 0.01376672150633697, 0.014142155780323913, 0.03317083578024592, 0.008946860807814767, 0.06397915511791195, 0.039529591000505855, 0.028202833075608526, 0.028376129223033786, 0.03931451575564487, 0.06889997249735252, 0.042411247800503454, 0.060066966472991874, 0.06973974100713219, 0.054222249026809416, 0.03370574529149702, 0.0533210629198168, 0.033053361012467315, 0.023581882373296788, 0.021931995637714863, 0.028081215851541077, 0.07300403048949582, 0.0701459324253457, 0.02607111183793417, 0.03300571767613292, 0.051683835951345306, 0.02696158048430724, 0.024739357942183102, 0.04545013812769737, 0.048476811431880505, 0.07044166512787342, 0.044333625717886856, 0.02909969012918217, 0.04620779711487038, 0.01835821445898286, 0.044647088540451865, 0.01995285656968398, 0.030424058171255246, 0.07425531691738538, 0.06833136693707534, 0.0431261183694005, 0.04414861975237727, 0.026834060005577545, 0.058949175024671216, 0.008729897539264389, 0.039255632486726554, 0.039439400125827105, 0.03922745632007718, 0.026453841211540357, 0.01305528771730938, 0.015783730461927395, 0.0360625416838697, 0.02544061031325587, 0.033207697195133994, 0.006848230450746736, 0.07904780975409917, 0.04215510083096368, 0.03927235837493624, 0.012283621222845145, 0.013853944638477904, 0.07774122272218977, 0.046544526903224845, 0.026379707868077924, 0.02410880383104086, 0.07451554866773741, 0.039926995390227864, 0.009513485045837504, 0.007784302163470004, 0.014349495725972312, 0.01263585129553186, 0.05286823578977159, 0.0067449832900560325, 0.024452186655253172, 0.03784974864018815, 0.015358421319563473, 0.06851579275514398, 0.04449024856356638, 0.028593825309404304, 0.020281274304059998, 0.04341128967436297, 0.019980907207354903, 0.08244061376899481, 0.06456054427794047, 0.046996224272464, 0.04427181796303817, 0.002705778826826385, 0.017858146024601798, 0.022493556308160936, 0.033986886098448715, 0.025101705820166638, 0.050653032692415376, 0.060932288611573834, 0.029001238090651374, 0.05693552057657923, 0.058439276314207485, 0.06486853132290499, 0.04400675504335335, 0.036778362201792855, 0.04170830248455916, 0.009216340990470988, 0.0541008658973234, 0.028516129657093967, 0.011498736866217638, 0.03087664781404393, 0.0503804142852979, 0.03879171470180154, 0.014924737358731883, 0.03238453582993575, 0.04511814790644816, 0.053033085872552226, 0.028499698931617395, 0.05092624142499907, 0.028403275712792362, 0.02353989632268037, 0.013542046687299652, 0.07758185520235981, 0.015761147120169232, 0.10245967669678585, 0.02252266546046095, 0.021523220697417855, 0.040880299772002866, 0.0512498313827174, 0.05871959270111152, 0.014693326383296932, 0.023453417034553628, 0.008864652049461645, 0.0243245796633086, 0.06815996220601456, 0.06701557897031307, 0.04422662413812109, 0.004507329589354673, 0.029347694678498164, 0.025737549111779248, 0.029232469254306385, 0.05389936474551048, 0.01151843388964023, 0.03716365474143198, 0.03385222403864775, 0.025306701427325606, 0.016131418590833033, 0.031704731950802464, 0.04744140092017395, 0.0378982672866966, 0.024943142364333783, 0.02014874623689268, 0.07805155071296863, 0.03737117789153542, 0.029158770173255886, 0.013948398409411311, 0.03995149728975125, 0.030365049373358488, 0.05237741409135716, 0.0063353355840912885, 0.020711879412244474, 0.0398877692807998, 0.06556430791637727, 0.05373584459136639, 0.04431220097467303, 0.037695911180760176, 0.03506138701257961, 0.04604513191484979, 0.02226140403321811, 0.07959205590720687, 0.006505625821383936, 0.018467594303988984, 0.10264002451939241, 0.04316314941804324, 0.031790712515690496, 0.03254995248945696, 0.03916492253275854, 0.01655861914956144, 0.027825542160176804, 0.002740047813858837, 0.018957308293985467, 0.045529394410550594, 0.026855839283338616, 0.022899413547877754, 0.024982470254014646, 0.01819853820571942, 0.010048938233272305, 0.022285149366195713, 0.014895137964880891, 0.04378454839544637, 0.011638311519553619, 0.04082480239282761, 0.052677204433296404, 0.06793052237480879, 0.06633577509117977, 0.034532720023500066, 0.01574809380274798, 0.07601517891245228, 0.031702431717089245, 0.03528913050623877, 0.028290588009570326, 0.03196795604058674, 0.030441499913909605, 0.03889779686661703, 0.03562091038163219, 0.005620721162163785, 0.009088315003152405, 0.016632209665008953, 0.056046822906604836, 0.024081730283796787, 0.03081981711355703, 0.05437453603371978, 0.01912570372223854, 0.027660707344434092, 0.002724313434945153, 0.07203569316438266, 0.04242106959489839, 0.022301590269697563, 0.03434186169345464, 0.02699996860298727, 0.06897025515458413, 0.02870264197034495, 0.05091403458001358, 0.020999266134042825, 0.047456705277519565, 0.013565015097680901, 0.020301808470061848, 0.03608845493623188, 0.008441756795426565, 0.04177060556997146, 0.040578619710036685, 0.016696977528876493, 0.02845537193518664, 0.04065927377502833, 0.007492425236185747, 0.022843269864097238, 0.02761806990019977, 0.02871921518817544, 0.016769272042438388, 0.0837661319279245, 0.04902181075885892, 0.05370364471205643, 0.027546065460358347, 0.02069865306839347, 0.019786741019093564, 0.06655546437416758, 0.021358187410182188, 0.019973867406536425, 0.007012084783387503, 0.037338316440582275, 0.009602591960823961, 0.09676214706684862, 0.016609329464180127, 0.08146329942558493, 0.0638821381809456, 0.040263860885586054, 0.02681896599408771, 0.019242379515032684, 0.03758892317169479, 0.04146301546799285, 0.08270799049309321, 0.036930808664432595, 0.053706589554037364, 0.018707363134516135, 0.025946234253102114, 0.15220915180231842, 0.25514083781412666, 0.11808565285589014, 0.1661807442350047, 0.08777474039899451, 0.0999702334936176, 0.13289225048252515, 0.1510651417608772, 0.11051296456051724, 0.15519862781677926, 0.11030720560146229, 0.08683603469814573, 0.12082496657967567, 0.1440897203449692, 0.20622842386364937, 0.16937106661498547, 0.20942436451358454, 0.1120531711993473, 0.15557330128337654, 0.09606512196894203, 0.06100657462541546, 0.12013041813458715, 0.13357554881700448, 0.16929308937064239, 0.17012928878622396, 0.14191961607762746, 0.1444216189639909, 0.12284428679517337, 0.1265781292957919, 0.08170080703816243, 0.09179972192006451, 0.21798865709986004, 0.1759234078760658, 0.2022148213748421, 0.08939216432294675, 0.16582144637192997, 0.15579484296696527, 0.10537378104137522, 0.10524898488074541, 0.09835523193968193, 0.08324784652463027, 0.14634431579283305, 0.10825135984591075, 0.06237382947334221, 0.0696381711001907, 0.13231690706951277, 0.14894341704036507, 0.11117855991636004, 0.1347537570233856, 0.17963042110204697, 0.13231618782239302, 0.14872363954782486, 0.1243172777550561, 0.08347026351839304, 0.16043053993156978, 0.08008830927844558, 0.16002682516617434, 0.12721040179686888, 0.18482073902019433, 0.22643514243619783, 0.11043786430465323, 0.11880028593753066, 0.1321491596422025, 0.27412201357739313, 0.10803408614758934, 0.11745206399687699, 0.17229961018477166, 0.14291071146726608, 0.21529390955609934, 0.11730797030031681, 0.13733375072479248, 0.07914014479943685, 0.18452341854572296, 0.13916472318981374, 0.1987708354634898, 0.12213227285870484, 0.08177897427231073, 0.16645233466156892, 0.12908895313739777, 0.19749423967940466, 0.1690860547657524, 0.14448886178433895, 0.14283246280891554, 0.16469338190342697, 0.10727813028331314, 0.08171301388314792, 0.1669435261615685, 0.13775934145918914, 0.18446910860283033, 0.14904192675437244, 0.07408484856465034, 0.11387935999248709, 0.09476338646241597, 0.07278821564146451, 0.09454898296722344, 0.12219813146761485, 0.0891860593110323, 0.12834777576582773, 0.06524130489145007, 0.1387063863554171, 0.07483969163149595, 0.08618126197585038, 0.1260188535920211, 0.11222674724246774, 0.11720053106546402, 0.14968950700547012, 0.07675864973238536, 0.11957353087408201, 0.16733628937176295, 0.11259827909192868, 0.11353249289095402, 0.1370441791202341, 0.11604456523699419, 0.14447254980249064, 0.12319792567619256, 0.15092862051512512, 0.18009979091584682, 0.11885595295046057, 0.05684427118727139, 0.0792175317183137, 0.11485475408179419, 0.09373060866658177, 0.22577255299048765, 0.08795337152800389, 0.0691911658006055, 0.10862091715846743, 0.18601692840456963, 0.13799354460622582, 0.10129826901746647, 0.10775338299572468, 0.15418679639697075, 0.13568097512636865, 0.2132143082895449, 0.17628776761037962, 0.0909462266468576, 0.12334239935236317, 0.1425787042826414, 0.1188108032303197, 0.11158217290150267, 0.13116316683590412, 0.08261618470507008, 0.1655129436403513, 0.1598502839250224, 0.16408709729356424, 0.13203551859727927, 0.1199983616492578, 0.10598197233464036, 0.14003404868500574, 0.06340993887611798, 0.08732018979000193, 0.11287460569292307, 0.1347275927130665, 0.11499921418726444, 0.0917954064373459, 0.20091759812619003, 0.10182467648493392, 0.16341465551938328, 0.07898375604833875, 0.08547729546470301, 0.09653329077575888, 0.1526926215738058, 0.10984841414860316, 0.16988489404320717, 0.12920196993010385, 0.1543709643717323, 0.12781207236860478, 0.09000244550406933, 0.14923019308064664, 0.11231082451662847, 0.1286896759910243, 0.08573687582143716, 0.15232211431222303, 0.126326053536364, 0.15711369791201182, 0.12900731180395397, 0.17432289304477827], [0.016104869211890867, 0.050796451246632, 0.013832751445339193, 0.020308044206883227, 0.039633902188922675, 0.029996299517474005, 0.07343439811042377, 0.022581429985751, 0.030135056536112512, 0.03925203964380281, 0.014499796321615577, 0.019606028483914476, 0.04822821994977338, 0.04864264199776309, 0.037405959596591334, 0.017023376621572033, 0.04467650303351028, 0.0373225405013987, 0.014719960579116429, 0.0300770282213177, 0.025146663854164735, 0.012184679790932153, 0.025486961040379744, 0.0279159094539604, 0.031996345945766995, 0.04709589767402836, 0.029523971290992837, 0.032170159476143975, 0.016145248830850636, 0.04506132399131145, 0.055948309799922366, 0.04077284357377461, 0.03074251501155751, 0.037703503987618854, 0.02051125017793051, 0.0755538565239736, 0.07661526849759476, 0.07261830368744475, 0.02657150596912418, 0.08633695862122945, 0.033021856631551466, 0.05226640576230628, 0.0912364021475826, 0.03566338328112449, 0.02324836714459317, 0.0297571328867759, 0.014571944950148463, 0.02431973492327545, 0.027679708021293794, 0.031139166227408817, 0.02125479563671563, 0.026290159905329347, 0.037892672765467844, 0.03050839328872306, 0.038157162323061905, 0.033248144667595625, 0.03285728135545339, 0.018809637021539465, 0.04075509988303695, 0.06602088734507561, 0.057457164728215764, 0.043562440135117085, 0.020657654286229184, 0.04520148218476346, 0.049807055587215085, 0.028221599657886794, 0.05078531987965107, 0.08696819296372788, 0.009068366073604141, 0.0980535824117916, 0.008949222957848437, 0.027232619601168802, 0.02238354372924992, 0.006532886389842523, 0.014810826596138733, 0.05323815272588815, 0.04457153366612537, 0.015180248201691678, 0.07488587272486516, 0.0027054155985492146, 0.013036795093544891, 0.033776462211140564, 0.06489903825734343, 0.037325875501015356, 0.05969325652612107, 0.03559258154460362, 0.036688432563096285, 0.06055803583668811, 0.02583588071034423, 0.04585302508037005, 0.017483743972011974, 0.049084229195224385, 0.03235261414998344, 0.013568589280891632, 0.05123739383582558, 0.03830092693013804, 0.06269025749393872, 0.01403735435035612, 0.0415102313272655, 0.03616580453568271, 0.11755153723061085, 0.02579851378686726, 0.03704321477562189, 0.03825850831344724, 0.08450504977788244, 0.09740500471421651, 0.053935666369008164, 0.006892483656494213, 0.05487367657146283, 0.04065272930477347, 0.016694711221914207, 0.06980633243386235, 0.04334237765786903, 0.0850861200264522, 0.030465964494006972, 0.018465478971068348, 0.05664227809756994, 0.05766394827514887, 0.0839079050347209, 0.02850089654592531, 0.014382670999371579, 0.051458541969103475, 0.016479296709543893, 0.02634613904436784, 0.05372928994308625, 0.03209095747609224, 0.008488770790531166, 0.009339586698583193, 0.049300993992281814, 0.05278801598719188, 0.00805217761080712, 0.007630913385323116, 0.0042745157427686665, 0.007585958744000111, 0.008882842725142837, 0.08528919877218348, 0.041302843884165795, 0.015332043270713516, 0.013253742246888578, 0.05330767881657396, 0.08115189256412642, 0.04145889676042965, 0.04726247123575636, 0.05206425321687545, 0.012660183561300593, 0.01796816029985036, 0.05748550035059452, 0.028767045121639967, 0.04593651542173965, 0.11428710525589329, 0.03282287623733282, 0.04662213095330766, 0.04881722905806132, 0.020466410887560675, 0.04374368362394827, 0.020332281477749348, 0.051271463079111915, 0.10301878955215216, 0.050187958005283556, 0.03495632604296718, 0.002328247031463044, 0.012096251410964345, 0.026566449186897705, 0.03867041978186794, 0.022383104377825345, 0.031467068275170665, 0.03616578757230725, 0.023294341284781694, 0.009524578245223632, 0.04885381905894194, 0.056910849043301175, 0.027623238640704324, 0.020564381166228225, 0.07995336223393679, 0.09547749028674193, 0.08274865509676081, 0.02106088729176138, 0.04297816041590912, 0.05839478477303471, 0.039223642953272374, 0.010187432319591088, 0.015115658453266536, 0.03135613797764693, 0.023138846503570676, 0.03760093663419996, 0.05949794700635331, 0.020914255874231458, 0.003610912735374378, 0.015264339046552777, 0.08635357594383614, 0.043422112307910404, 0.03167290187307766, 0.0568694176950625, 0.06107539843235697, 0.03521899034136108, 0.05450195812487176, 0.04147980581702931, 0.04723753168114594, 0.02973334344902209, 0.021300547556685548, 0.013543353715379323, 0.01907073729671538, 0.09623189230582543, 0.015665429577763592, 0.015868594836709753, 0.025169186127771224, 0.032132158122424564, 0.01667989880245711, 0.026852288848853538, 0.031208509113639593, 0.04222244882423963, 0.04011992664475526, 0.015118370897003582, 0.019969404342451265, 0.02845569932833314, 0.024399472965991924, 0.022200695505099635, 0.034841562022588084, 0.02910080971196294, 0.04632015572860837, 0.01042249720610146, 0.00824570597615093, 0.06026413517871073, 0.0677351721429399, 0.06931600267333643, 0.024298449279740453, 0.017512289940246513, 0.030917047789054256, 0.01752663417054074, 0.02600008957753224, 0.04826108479340162, 0.04549721488729119, 0.01662987211186971, 0.025124945644555346, 0.015816734405234456, 0.023692843204896365, 0.024927904164152484, 0.023696760048291514, 0.011050631491733449, 0.05026412695380194, 0.07451332985822644, 0.054432706840868504, 0.07144802755543164, 0.056589976618332524, 0.021752913282918077, 0.04966755896540625, 0.05207882136372583, 0.06295660284480878, 0.043088001664727926, 0.02953998471743294, 0.016099147465346113, 0.02463170836147453, 0.03729523964492338, 0.058194542303681374, 0.06452355733407394, 0.03189718144546662, 0.028631884338600293, 0.036670811008661985, 0.026115077514467493, 0.033874622479613335, 0.038294701371341944, 0.02357872379278498, 0.005366530493899647, 0.021563303457306962, 0.03590412750574095, 0.008816834838528718, 0.018686272569798996, 0.03876387780266149, 0.04105514806828328, 0.02291296558853771, 0.021159203623288443, 0.04755315224507025, 0.06723076956612722, 0.018272612177367722, 0.03684492648712226, 0.02042640615919871, 0.015101643312456352, 0.024866215152932063, 0.024814400522570525, 0.007233722734131983, 0.01396054248990757, 0.06002173532864877, 0.034632132189082246, 0.03005016501992941, 0.097378752194345, 0.012935086086924587, 0.012835843555097069, 0.03049681748130492, 0.050527388363012245, 0.015885105290051018, 0.006459683911608798, 0.03617101568462593, 0.04974033184615629, 0.08031057699450425, 0.06171847999628101, 0.0142294408287853, 0.049134328828326294, 0.029417712707072496, 0.03912090935877391, 0.010870658559724689, 0.02708848688884505, 0.06239867742572512, 0.03487781275595937, 0.017042560502886772, 0.019097985566726754, 0.05910622195473739, 0.03502081740381462, 0.024298739353460923, 0.04479243752679654, 0.04320641959618245, 0.02327009553222784, 0.0560167671979538, 0.02412027107285602, 0.08553596160241536, 0.03951493803677814, 0.012639724034150797, 0.010107988591438957, 0.028290382752727185, 0.02534120493302388, 0.03058746297444616, 0.01827449511204447, 0.010786569411201137, 0.03676366174061384, 0.021179011756820337, 0.06190196943602391, 0.07803029221083436, 0.031696311331221035, 0.055301567539572716, 0.011907511806514646, 0.03877962999311941, 0.009293386097332197, 0.023720725905150175, 0.07595182409776108, 0.049337492390934906, 0.037308440543711185, 0.03386485496801989, 0.06665880525750773, 0.0331833445733147, 0.049447940928595405, 0.00680633430602029, 0.04387177746476872, 0.012864407334875847, 0.02676442195661366, 0.05115191538685134, 0.03246209577524236, 0.07639022557330982, 0.05316490147794996, 0.017264772239806395, 0.003393136285012588, 0.11260555298732859, 0.02977324470079371, 0.042124407299395115, 0.09648556940789733, 0.10132756815957171, 0.15812926127442292, 0.10025373899510928, 0.07433817961386271, 0.08939631695726089, 0.2405590388391699, 0.08835053843046937, 0.12088219422314848, 0.2297658265701362, 0.07098239646958453, 0.12612610283706868, 0.06455995395247426, 0.17011597592915806, 0.07902729764048542, 0.10867373432431902, 0.1427607959402459, 0.13177960232964583, 0.18945031559893064, 0.15987110137939453, 0.06943151647491114, 0.08179943888847317, 0.11551125028303691, 0.1585188489407301, 0.13203151524066925, 0.09439060610852071, 0.0937034333390849, 0.08879067017031567, 0.11006500252655574, 0.11112249256776911, 0.10150984980698143, 0.23561417417866842, 0.1186429743788072, 0.13542264327406883, 0.1305697743913957, 0.1369458186839308, 0.15130211333078997, 0.19271405546792916, 0.12163956144026347, 0.12709012467946323, 0.10765260018940483, 0.10551970678248576, 0.12314930185675621, 0.11008653922804765, 0.10962495899626187, 0.12173002372894969, 0.14957193045743875, 0.25901915399091585, 0.16577337895120892, 0.09973660031599657, 0.08366761542856693, 0.08226534817367792, 0.11821943282016686, 0.06049371750227042, 0.1718194516641753, 0.20037930272519588, 0.08591303708297865, 0.11558245574789387, 0.14655101113021374, 0.13559629395604134, 0.09530552237161569, 0.08350058046302625, 0.12955377676657268, 0.17005326572273458, 0.11872913475547518, 0.2094099252883877, 0.13692648043589933, 0.14229673227029188, 0.0731131796325956, 0.1305374489831073, 0.10535841222320284, 0.1399640238710812, 0.13074284153325216, 0.08933695871382952, 0.08199284172483853, 0.07921367763940777, 0.09926511347293854, 0.13231261872819491, 0.2871530343379293, 0.11277531566364424, 0.12405544466206006, 0.13464190731091158, 0.10404834430664778, 0.11124848973538194, 0.1734194372381483, 0.09611266013234854, 0.09780789166688919, 0.13007353459085735, 0.10984160165701594, 0.12973938323557377, 0.08399572103683438, 0.18173364895795072, 0.16596704641623156, 0.11783099866339139, 0.10422160822365965, 0.10012865106442145, 0.16638589251254285, 0.1873847328658615, 0.15641169915241854, 0.10258495461727891, 0.16225491703620978, 0.1246923990547657, 0.13762117815869196, 0.0720454640686512, 0.10579662370894637, 0.22279088012874126, 0.22407441054071697, 0.12101684271224908, 0.21609939847673687, 0.13828357761459692, 0.12864289778683866, 0.15445620194077492, 0.12177144150648798, 0.1995571625552007, 0.12958199025264808, 0.17153286561369896, 0.15643092883484705, 0.21496658426310333, 0.12307156888501984, 0.10958757171673433, 0.07971357474369661, 0.22079315089753696, 0.08219789500747408, 0.1553087676210063, 0.15458563928093227, 0.15431897501860345, 0.18072489808712686, 0.14697786393974507, 0.13500892690249852, 0.13691185122089727, 0.07674252774034228, 0.04839012858324817, 0.12455716702554907, 0.165900658550007, 0.10858973847436053, 0.17577638290822506, 0.12717652932873794, 0.2633263042994908, 0.22649060588862213, 0.09658395020025116, 0.15294211890016282, 0.12061478357229914, 0.09656375699809619, 0.12343526365501539, 0.11671741413218634, 0.14240046670394285, 0.10999777327690806, 0.07807280921510287, 0.1462540706353528, 0.28521999663540293, 0.12122807066355433, 0.1452167805816446, 0.16467559071523802, 0.10318992286920547, 0.18308571140680993, 0.12255307313586984, 0.1381687152066401, 0.15060395507940225, 0.11485797033778258, 0.18039586288588388, 0.15278492947774275, 0.11091510512466941, 0.11014414685113089, 0.16102892639381544, 0.09021590583558593, 0.11761728727391788, 0.09811135966862951, 0.10111774477575507, 0.11350005891706262, 0.20277424635631697, 0.1708725153335503, 0.11298135282205683, 0.0633335697597691, 0.19429040088185243, 0.29525848797389437, 0.16345444481287683], [0.01936730629365359, 0.0445973722796355, 0.0792077404579946, 0.02445897539811475, 0.03158315883151122, 0.0453727071040443, 0.01568752607064588, 0.013354771022152687, 0.13093387628240244, 0.041145905519702604, 0.06538523573960577, 0.011708706135063298, 0.046030702867678235, 0.002774731131337051, 0.0222766710711377, 0.06359908051256623, 0.05395298597535916, 0.0075764736726081795, 0.03327907568642071, 0.06310837755778007, 0.09627303866935627, 0.03588686218219144, 0.02274508075788617, 0.03129958886919277, 0.03109856947724308, 0.013318845985590346, 0.01441425850082721, 0.06474080389099461, 0.07262901775538921, 0.04567499106217708, 0.019642231719834462, 0.05390511193711843, 0.04178274795413017, 0.00537821020199252, 0.05037324217015079, 0.01607637752645782, 0.02722185125042285, 0.042067216975348334, 0.0474111043315913, 0.05113071795286877, 0.02717668965591916, 0.08865354502839701, 0.029160537756979465, 0.019455027300864458, 0.031892628475491486, 0.013921962685084768, 0.031310672738722393, 0.011856411334260233, 0.08462479085262332, 0.04104060706283365, 0.038550268193440776, 0.050956202138747485, 0.05297204486227461, 0.02189495780372194, 0.026560625660100153, 0.02292605283270989, 0.05493221378752163, 0.036626736766525676, 0.04210892652294465, 0.04608143014567239, 0.07531332943056311, 0.03377613651433161, 0.033871969407690425, 0.049514074344187975, 0.0467801990785769, 0.04286751849576831, 0.042690298719597716, 0.03974213870242238, 0.006858169292432389, 0.03447615734434553, 0.02063309640756675, 0.02983734929668052, 0.006665763902544443, 0.01619542988815478, 0.06448514546666827, 0.03453030104615858, 0.05712038744240999, 0.034380850315626175, 0.012539885239675641, 0.05420598454241242, 0.055375948548316956, 0.08242396251963717, 0.03769219620153308, 0.018487585641975914, 0.03172909475064703, 0.02160867370132889, 0.07240428017186266, 0.019207114353775978, 0.009253430562759084, 0.06075149295585496, 0.0350412582712514, 0.05598648418007152, 0.009556713663706822, 0.060752734674939086, 0.03791210261572685, 0.03636439137959054, 0.023108112259900997, 0.028753532096743584, 0.014393196773848363, 0.08306491348360266, 0.023647279578394124, 0.03508105095742004, 0.06360889891428606, 0.018214334500953555, 0.08300619984843902, 0.02475852146744728, 0.0034136303750398967, 0.029595614410936832, 0.03822003537788987, 0.016511369363537858, 0.017638860469950095, 0.008781835154098059, 0.1007811099823032, 0.04364886853311743, 0.04364844784140587, 0.02007483341731131, 0.04104715492576361, 0.03955274600801723, 0.020974882978147695, 0.017645331997690455, 0.023508408905139992, 0.026507313163684945, 0.05663775566167065, 0.034027425173137865, 0.08427253618304219, 0.0612171036856515, 0.027954066870734096, 0.013276328133153064, 0.05012579062687499, 0.049183359768773825, 0.04163105805803623, 0.049652132471757274, 0.027140533917450478, 0.03403570669304047, 0.05133075686171651, 0.027809586409213286, 0.009927641617001166, 0.03266691496329648, 0.056987883123968325, 0.037303857039660215, 0.07169924157538585, 0.05414464836940169, 0.037436609023383687, 0.021622863564906374, 0.027408117594729577, 0.03729445932965193, 0.13452063953237875, 0.045726200100034475, 0.03847867935629828, 0.024727483579356755, 0.028255690953561237, 0.09565824523035969, 0.01579192716495267, 0.006091007846407592, 0.030863769219389985, 0.02774643854770277, 0.045636049937456846, 0.013810035789252391, 0.01061364815437368, 0.0072112038532005885, 0.05449991912714072, 0.024637251992576888, 0.03538532980850764, 0.01986914231175823, 0.05675695051572152, 0.04491323033081634, 0.047718239815107415, 0.014075214908059155, 0.039473744175795994, 0.04139679045017276, 0.0736037197389773, 0.009063299113352383, 0.022433427927483405, 0.02233765270960118, 0.015760745088170682, 0.011944169660897126, 0.007832440830368017, 0.04115640924179128, 0.013614392939156719, 0.025900729998414005, 0.05567911799464907, 0.01967501513926046, 0.03205197224659579, 0.040263565722852945, 0.05463254897456084, 0.03196892295298832, 0.03869560360908508, 0.0519254181667098, 0.03243676606299622, 0.03871924376913479, 0.028586883896163533, 0.03629309091983097, 0.034888163807668855, 0.010033690703234502, 0.021748757255928855, 0.09695470851979085, 0.026764213307095424, 0.027778797882742116, 0.059728771048997126, 0.01279532483645848, 0.06679187276001487, 0.031297583798212666, 0.01785640388594142, 0.023059780210522667, 0.0392544552284692, 0.006658021817981664, 0.0031217479346586125, 0.014960619986855557, 0.060999015745307715, 0.010997621791570314, 0.008548476783159589, 0.01372864721010306, 0.008906930718304855, 0.008918291090854576, 0.008140468587433653, 0.017295084095426967, 0.047987757317189655, 0.07995961154145853, 0.03158755573843207, 0.043429616905216656, 0.029647739471069405, 0.04537457986069577, 0.03714425203257373, 0.052685424885047336, 0.018447034692923938, 0.052950922067144086, 0.0372035593858787, 0.056864579740379534, 0.04553146733503256, 0.013963422871061733, 0.032522906083613634, 0.09118136617222003, 0.03763811356787171, 0.03944921513487186, 0.03155526764956968, 0.04172673149566565, 0.04721077365268554, 0.020582277527345077, 0.04015355144760438, 0.027314869919791818, 0.08323847595602274, 0.05655189723308597, 0.039351682511291335, 0.04643180527325187, 0.024879215883889368, 0.06675584255052464, 0.024230436322146227, 0.023199000329311405, 0.0023474470279844744, 0.011052544112317264, 0.011391769213202809, 0.024546886395130838, 0.018196538223751953, 0.02825371641665697, 0.009221986401826143, 0.03294983013932194, 0.03342801073033895, 0.024927458027377725, 0.011899208234223937, 0.025203151894467216, 0.012078499238538955, 0.012473880745736616, 0.018634763280195848, 0.03758036005975945, 0.014401452848687768, 0.025470357288473418, 0.019475734493296062, 0.017895594372281005, 0.05470225487702659, 0.02428647822567395, 0.011107762443966098, 0.025840253868539418, 0.009514245853227164, 0.038336404133588076, 0.04810684360563755, 0.07993630386356797, 0.03030107369912522, 0.0161380614486656, 0.04531187304694738, 0.052673598019672294, 0.04775053808199508, 0.06530546716281346, 0.017731595850948776, 0.03931817984474557, 0.02910313369440181, 0.014316437499863761, 0.04006710947890367, 0.05105605874476688, 0.046214731742760966, 0.017283196161900247, 0.06987310706504754, 0.03950322652235627, 0.06286732799240521, 0.0326142911799252, 0.021353122146267976, 0.03820058177890522, 0.08361223340034485, 0.09252829889633826, 0.04148812804903303, 0.03839792351105383, 0.04662325392876353, 0.03526733596143978, 0.023289652607802833, 0.01562996255233884, 0.026720973663032055, 0.03867036210639136, 0.05739031545817852, 0.028178488935476968, 0.0283848076859223, 0.05702483614108392, 0.028197365779695765, 0.04581753430621965, 0.029724719268935065, 0.05032377018194113, 0.05269823223352432, 0.07851153638746057, 0.018562760536691973, 0.04544191089059625, 0.03628719784319401, 0.02317941950501076, 0.01846470883382218, 0.08504280235086169, 0.07894096763006278, 0.05379826642040696, 0.02865910037819828, 0.02078815014101565, 0.06862194955881153, 0.037240963628781695, 0.05336641620046326, 0.04302350691120539, 0.013300893645334457, 0.029722134050514017, 0.10131905254508768, 0.028058037095304047, 0.006073685695550272, 0.06921244465879031, 0.02381614998116025, 0.010029393032060137, 0.04224029768790517, 0.02208368553380881, 0.013212572982800859, 0.060350539827985425, 0.021394685808835284, 0.016124745198924626, 0.03567518979044897, 0.02141678739073021, 0.06843667557196957, 0.04802688164636493, 0.04511221072503498, 0.06937158147671393, 0.05183416199205177, 0.03880919037120683, 0.24402369292719023, 0.17543275920408113, 0.227340606706483, 0.08623017756534473, 0.1336090141641242, 0.1085039037945015, 0.11783862539700099, 0.20903662246252808, 0.18450625160975115, 0.12421769595571927, 0.1529272182711533, 0.10383286872612578, 0.09325211934213128, 0.12313119854245867, 0.13373134045728616, 0.15968715053583893, 0.12962834776512214, 0.08719805348664522, 0.1355973660413708, 0.177890060203416, 0.17777291791779654, 0.1327006457639592, 0.16407349945179053, 0.15546104444989137, 0.13004648818501405, 0.09403086719768387, 0.12342523490743977, 0.17209543899766036, 0.15367832939539636, 0.11808851627366883, 0.07463029572474104, 0.1660758698625224, 0.12409945444336959, 0.06854226919157164, 0.15399440457778318, 0.11846890300512314, 0.11919033500765051, 0.1305840236267873, 0.06845344217228037, 0.09380152236138072, 0.12504439588103974, 0.23142777596201214, 0.08532767170774085, 0.1281100306659937, 0.11129291342305285, 0.11554335856011935, 0.14005296624132565, 0.1661866610603673, 0.14279309420713357, 0.1097932696076376, 0.0886122358164617, 0.18480045082313673, 0.2267423423805407, 0.05052102031186223, 0.13775677659681865, 0.17154612418796333, 0.16558420338800975, 0.14983765834144183, 0.12947011339877332, 0.0731863732050572, 0.16962486585336073, 0.17373488816831792, 0.109136814118496, 0.14239206644041197, 0.12040134359683309, 0.16802266825522694, 0.12427987690482821, 0.15682195499539375, 0.13950823832835468, 0.09820571674832276, 0.08832997881940433, 0.1633845285645553, 0.07915474687303815, 0.07658213563263416, 0.11149451296244349, 0.1352742612361908, 0.12677554227411747, 0.24490491992660932, 0.09830207550632102, 0.14775290020874568, 0.09971455471324069, 0.1637284101120063, 0.11222397881959166, 0.15004728495010308, 0.1258635369262525, 0.08010991383343935, 0.21130430006555148, 0.1476581088666405, 0.17921971742595943, 0.11454593922410693, 0.22083874845079013, 0.19742595191512788, 0.1799426693469286, 0.1519105149699109, 0.09735703907374825, 0.08919217291155032, 0.1451048223035676, 0.19539027900568076, 0.11840394006243773, 0.2510867267847061, 0.16733993989016327, 0.09330618501241718, 0.1584586086017745, 0.11554829829505511, 0.19836009107530117, 0.08658853226474353, 0.09776351547666959, 0.0812788193247148, 0.12016340850719384, 0.1009133971695389, 0.08187250353928123, 0.16698619244354113, 0.2631080874374935, 0.095001932233572, 0.16989785406206334, 0.09915124851145915, 0.0819461653009057, 0.16684519286666596, 0.1354948122586523, 0.14466028687145027, 0.15668258390256337, 0.19588871725967952, 0.11925596291465418, 0.08922403691602604, 0.18052516451903752, 0.12847687383847578, 0.1096146045518773, 0.05541894052709852, 0.12519277791891778, 0.12366690193968159, 0.1302214145128216, 0.13359032730971063, 0.09357751759567431, 0.13723944792790072, 0.16315768073712075, 0.14042648619839124, 0.14507046129022325, 0.1636152576122965, 0.14708462463957922, 0.14094343488769873, 0.08205770967262131, 0.172505274148924, 0.09826286296759333, 0.13488601706922054, 0.1454752752823489, 0.14514424518815108, 0.25009449145623613, 0.15024122382913316, 0.18362465820142201, 0.10867099982819386, 0.23599912066544804, 0.21254657554839337, 0.10456886887550354, 0.16210848917918547, 0.14606473222374916, 0.09491796352501426, 0.1477211583405733, 0.19927554338106088, 0.08287671501083033, 0.1832587785486664, 0.20123443326779775, 0.11428201624325343, 0.14797159204525606, 0.08615175248788935, 0.11668267313923154, 0.174135970217841, 0.07082509169621126, 0.0981801427634699, 0.23833281972578593, 0.14738255579556736, 0.17274356207677297, 0.08588276085044656, 0.24312398263386317, 0.10674079161669527, 0.10149552593273775, 0.08192703061337982], [0.06571360597653048, 0.04405521601438522, 0.03485466453379818, 0.017077033474509205, 0.009144010853820612, 0.009718785993754864, 0.03411224205046892, 0.012771333534536617, 0.033653219895703454, 0.0369625844593559, 0.08072352662150349, 0.07928825542330742, 0.008419881674594112, 0.03597669004063521, 0.044102883099445274, 0.02901597587125642, 0.037464758048632314, 0.04599861494664635, 0.05553784021841628, 0.008321671364163714, 0.006594886254918362, 0.03368888030360852, 0.03999114069821579, 0.0203403865785471, 0.03613430694011705, 0.01498056891640382, 0.035971075163355896, 0.05444263380819133, 0.016846842165770273, 0.028088511799329093, 0.020780682863135422, 0.06862664502114058, 0.013936928623089833, 0.037086115152175934, 0.013928731920064559, 0.04714401598487582, 0.022111232359228388, 0.019591872547087923, 0.02247580752841064, 0.028425380687362382, 0.019501640960308056, 0.044449801091104746, 0.044085845085127015, 0.030245722204978977, 0.04037758335471153, 0.049809691695762534, 0.001781797972008852, 0.053377859693552764, 0.06859549347843442, 0.05892425921878644, 0.04866741191861885, 0.07631600741297007, 0.02708259890122073, 0.08859961506511484, 0.03236775565892458, 0.02522951806895435, 0.01900854956225625, 0.02046065521426499, 0.04976816535262125, 0.03304955103833761, 0.02299783505233271, 0.01675712626560458, 0.07001104644898858, 0.04542916121759585, 0.05057880774672542, 0.05127730865829757, 0.05450917095212, 0.04696617874183825, 0.06537916285118886, 0.037053871168089766, 0.058236971098397455, 0.04436051945335098, 0.05313484916197402, 0.027477865905633996, 0.017219424048172574, 0.05399620865604707, 0.031472771362002404, 0.01600866990962199, 0.024693014000409415, 0.04342776111194065, 0.04676990570234401, 0.019665493596611277, 0.025592507162530507, 0.03151710684012089, 0.030738314879792075, 0.012566567781115217, 0.07852165334458862, 0.05333847752107041, 0.009731527185067534, 0.028329571542729224, 0.05058263807690569, 0.014819912180038435, 0.07459799745785338, 0.04213347591991935, 0.02004212633307491, 0.03434080317882555, 0.0399682435340115, 0.007872031652368605, 0.038901783259851594, 0.08040279668888875, 0.08913155259298426, 0.04046292270400694, 0.012111044322539653, 0.0070724468345620805, 0.06416246813855, 0.080156074570758, 0.03297617086874587, 0.0259543257831995, 0.02567384994056608, 0.047006673711751185, 0.08343639105026211, 0.04558422004005738, 0.04314858805654304, 0.07705636375716754, 0.013254792279829937, 0.08324868112270321, 0.024833177282874073, 0.03550841606089047, 0.024178933817893267, 0.04670768404113395, 0.011653889835413014, 0.024420707719400525, 0.03066663783309715, 0.022452945987294828, 0.032265544536390474, 0.06051359857831683, 0.004848800217067557, 0.035035470367542336, 0.10994788059698683, 0.04519379777567727, 0.07589052524417639, 0.019055317588416592, 0.04588587296062282, 0.061586206379745684, 0.01682943943887949, 0.05038170689450843, 0.030722806961940866, 0.02576652086073799, 0.030863128003797362, 0.015498291135632565, 0.015005301517833556, 0.029094699504120008, 0.016704851927767907, 0.022100043316770877, 0.011126160072827978, 0.04523732579712357, 0.04427448121298637, 0.022700494221810783, 0.025680099248087833, 0.051267612392881086, 0.02835265191138855, 0.027164927251370888, 0.11954163972820554, 0.023917246609926224, 0.041227343292640786, 0.07132151470120464, 0.025865712502439107, 0.041614457698804994, 0.028979871022914137, 0.08809865266084671, 0.03315032705930727, 0.02034353667737118, 0.04209021591980543, 0.05931790452450514, 0.04787903225847653, 0.047707498605762205, 0.04839082747431738, 0.023232557278658663, 0.04594944490651999, 0.009687590346272503, 0.03687330621427723, 0.11230388988873788, 0.05250140958066497, 0.04612215921016676, 0.05753375097577061, 0.009597977922697152, 0.01278051156883261, 0.041874116087066274, 0.04138411541602441, 0.07886111762906824, 0.03390568920544215, 0.02861377763162766, 0.017840938376528875, 0.019665977052812065, 0.07217847728835684, 0.07910243182310037, 0.07375710936529295, 0.06804465196494545, 0.0072872981628669155, 0.03830802101375801, 0.03639201454019972, 0.044307546224445105, 0.015142535225355198, 0.04192573903128505, 0.045764472867761335, 0.038756793897066794, 0.019750766788742373, 0.05737527233681508, 0.044252584887934585, 0.02943702381370323, 0.02230475563555956, 0.010512297074975712, 0.03163370290505035, 0.040173337528748174, 0.032597572077065706, 0.038879819081297944, 0.045731289112674336, 0.07746098097413778, 0.0275422470045409, 0.04669437457674316, 0.04219109032835279, 0.03451755476583328, 0.022268128315252916, 0.007510935671494475, 0.046574494402323446, 0.038751579355448484, 0.01846621178888849, 0.026558447562690293, 0.009451142096492861, 0.036709175378616364, 0.029034001154026816, 0.0023220314386500312, 0.005151587139282907, 0.03434608557394572, 0.07772402864481721, 0.014045853849633463, 0.029847110022923777, 0.024176453772400106, 0.016262984834611416, 0.09566146827169827, 0.04409900866448879, 0.031715018541685173, 0.06202010238277061, 0.09356387904179947, 0.038053621271891255, 0.04164580262399145, 0.02286601096524724, 0.037720043278698406, 0.03832937790346997, 0.036901899679963074, 0.029086950634207045, 0.04293346192155566, 0.05135788808443716, 0.002603029541205615, 0.06386580584304673, 0.023067617289988056, 0.0130134085359584, 0.04650735675490328, 0.07713426636265856, 0.03156591386401227, 0.0277037519096796, 0.027198355279064605, 0.020697021191673617, 0.02726110619758921, 0.07044774480164051, 0.030696289813412086, 0.1103786960510271, 0.010826306118230735, 0.02301051008648106, 0.06750756435628448, 0.04177398806703942, 0.03157532853739602, 0.024408792644473057, 0.052182057074138095, 0.02634359453804791, 0.03663959839780416, 0.051355764269828796, 0.03925377669345055, 0.05902588340852942, 0.09790790772863797, 0.033290013670921326, 0.0406519082774009, 0.03295075973229749, 0.04161588940769434, 0.029704105375068526, 0.040030170032488446, 0.013472912450587111, 0.08204090236020939, 0.010705137575444366, 0.009355748554558625, 0.029556259379855225, 0.06718570127018861, 0.02941373988453831, 0.015250678440289838, 0.03518476164234536, 0.01884601328388921, 0.027771837809788327, 0.04227094372202243, 0.05543366473700319, 0.02347384942030268, 0.010853358461255474, 0.01761559859317328, 0.03648652429027217, 0.010333840668733631, 0.049643603286572864, 0.028645750201706375, 0.035475510505161116, 0.00872875505592674, 0.028522921792630638, 0.0534393892490438, 0.052968228102794716, 0.04263259270893676, 0.029219702617930512, 0.022479357962895716, 0.017704878534589494, 0.04497099740962897, 0.15160190367272922, 0.03539200998576624, 0.03899012512660452, 0.020596655684390237, 0.06508619857153722, 0.004679670698741185, 0.07546004905764546, 0.027744460618123412, 0.007708762556181422, 0.05244902667722531, 0.007831872557289898, 0.05762997402676514, 0.009016306322467114, 0.03683647872614009, 0.003770560150899525, 0.08020849818629877, 0.04503660496058209, 0.020620860724842975, 0.021723088276173388, 0.03434759870703731, 0.06255173456988164, 0.039216874566461356, 0.06221636863691466, 0.02068569474587483, 0.009002408228947647, 0.040737647962357314, 0.026589858645041074, 0.011303573231478887, 0.04415654164871999, 0.06278431601822376, 0.03134679455044014, 0.015539564724479402, 0.026417946709053855, 0.006919520308396646, 0.013618352190990533, 0.052776005917361805, 0.05438362840296967, 0.022607480641454458, 0.052041186418916495, 0.016347784748567, 0.031952085106500556, 0.03687396439324532, 0.07568938710859843, 0.052970952420894585, 0.00340904517465138, 0.007005965669772455, 0.10637726648045437, 0.10879606061748096, 0.0981752165992345, 0.08785841055214405, 0.123856267492686, 0.10667186602950096, 0.07842329290828534, 0.115444740280509, 0.19927706329950265, 0.11536786226289612, 0.17926500285310404, 0.1705842600869281, 0.07891298484589372, 0.11261595492916447, 0.1228295625852687, 0.07851603507463421, 0.13731529457228525, 0.13663518535239355, 0.16280649815286907, 0.1911138120506491, 0.08653258705245596, 0.11741994214909417, 0.2631443754902908, 0.15893666366381304, 0.14730088732072286, 0.06741887304399695, 0.18341337596731527, 0.11839676116194044, 0.09217363542744092, 0.14674884480025085, 0.09116559701838664, 0.2060251347720623, 0.08679254060345036, 0.13000306194382055, 0.08683321877781834, 0.14039178591753754, 0.09731024729886226, 0.09431741932140929, 0.1258375218936375, 0.12015063847814288, 0.17048341621245655, 0.08414443555687155, 0.12030294244842869, 0.09508313930460385, 0.10453289973416499, 0.10924152564257383, 0.08026588189282588, 0.12177093939057418, 0.1935061365365982, 0.11937401443719864, 0.1828936588551317, 0.11110726624195065, 0.11264780536293983, 0.163829986804298, 0.1369145382195711, 0.11458202371639864, 0.11630368418991566, 0.20885193880115235, 0.13986566343477794, 0.12668657276247228, 0.11314724784876619, 0.08556187485477754, 0.13492647132703237, 0.10836645974112408, 0.13433968781360558, 0.16781823922480854, 0.20626615041068622, 0.1692226031529052, 0.10898258310875722, 0.10176598999117102, 0.11791411920317582, 0.12738789298704692, 0.16622243342655046, 0.11661434466285364, 0.15663355296211584, 0.15109971990542753, 0.09958200289734773, 0.0963302595274789, 0.15447741294545786, 0.06527183218193905, 0.2548575901559421, 0.09754530540002243, 0.10726777583892856, 0.1130542139123593, 0.12165172078779765, 0.09579154343477317, 0.2509343278195177, 0.11747377711747374, 0.10302698625517742, 0.14406337961554527, 0.12603228858539037, 0.17195342161825725, 0.14896179176867008, 0.2034340538084507, 0.09842307187084641, 0.1629853192716837, 0.15164642914065293, 0.09523223380425147, 0.12513415249330656, 0.2260979376733303, 0.2096292142357145, 0.1483270629708256, 0.08470096997916698, 0.1078059830303703, 0.1634476866040911, 0.1469071063080004, 0.11085278168320656, 0.05396355076559952, 0.19928844911711557, 0.17692161431269987, 0.173117244882243, 0.11515459870653492, 0.15823292785457202, 0.17871832075927938, 0.16075717311884674, 0.14145348966121674, 0.0988577346184424, 0.13354574755898543, 0.1526393565748419, 0.1189270227083138, 0.2252474890223571, 0.15015248501939432, 0.08800600548940045, 0.12626864947378635, 0.14570737497082778, 0.21078455581196717, 0.13878854337547505, 0.09983627711023603, 0.13730048893817834, 0.13772138421024593, 0.25946204736828804, 0.1348755947713341, 0.1848556971443551, 0.12991170398890972, 0.21271737638328755, 0.20284961802618845, 0.1791671309620142, 0.08395813019680125, 0.13511905313602515, 0.12556677285049642, 0.06939381706927504, 0.08659776712634734, 0.24239178906594003, 0.09154683870396443, 0.13970570558948175, 0.10971757224095718, 0.15582401997276715, 0.07201536425522395, 0.2079989659999098, 0.12080699897238187, 0.14488484125052178, 0.12305202707648277, 0.24703416281512805, 0.14443770024393285, 0.08723536612732069, 0.14438272533672197, 0.1305737913187061, 0.09806257978613887, 0.0671977995495711, 0.12120851528431688, 0.18255565342094215, 0.11348168418875762, 0.11231119771088872, 0.15671516715415887, 0.10179314496261732, 0.14180415655885423, 0.15539914848549025, 0.10430520373795714, 0.13492576565061296, 0.07350848734910999, 0.11222775825964552, 0.21453314966389112, 0.3478555642068386, 0.20034627164048807, 0.1098166722804308, 0.0743505832340036], [0.03682807846260922, 0.022402535924421887, 0.031694981402584484, 0.014269258960017135, 0.011125431495851703, 0.04744230676442385, 0.01498119656129607, 0.055876412229346376, 0.01858525736523526, 0.05041845974379352, 0.03796942525410226, 0.09322284055607659, 0.019997572027412907, 0.029116110676633458, 0.032753010879137685, 0.03031006089544722, 0.02663076582497784, 0.04639425175264478, 0.06711520826710121, 0.04509003620062556, 0.018295521215934838, 0.03488448275519269, 0.013118613694262291, 0.015850771418107406, 0.05374013293268425, 0.03324835501345141, 0.0040387608709612065, 0.03556089735190783, 0.03221018625689404, 0.005975335013187889, 0.022474927129223943, 0.021971659402229955, 0.04596703592687845, 0.04020730159910662, 0.012465466911505376, 0.017154478068862642, 0.012856555836541312, 0.04908489415954266, 0.016520387093935694, 0.05125454380842192, 0.049441189505159855, 0.031026678692017282, 0.030808244698813984, 0.03136968153661915, 0.018081250035070946, 0.026379382171268975, 0.036187802640987296, 0.05168257048353553, 0.10095716267824173, 0.03567883352349911, 0.021663100691512227, 0.03944259602576494, 0.007734978604795677, 0.03059368853324226, 0.025760960266260163, 0.039841798533286364, 0.035990976595452855, 0.05458045105582901, 0.052611359395086765, 0.07226178103259631, 0.03374403502259936, 0.01962576706760696, 0.02459223458676466, 0.01750554021314851, 0.04887098599491375, 0.014228289863759918, 0.008358056956369962, 0.04337396007031202, 0.05770748308194535, 0.03025754228500383, 0.048255330816443474, 0.08008068933018617, 0.07710383406707219, 0.04866112529167107, 0.012073405985055225, 0.03038234862365893, 0.043111533259174654, 0.02742097752967051, 0.05492626303540809, 0.022690278877105032, 0.11971599608659744, 0.06388122215867043, 0.04564256726631096, 0.05190942170364516, 0.041836457393531284, 0.017583230776446204, 0.025424698667068566, 0.011361349640148026, 0.04665008320340088, 0.023525414689044868, 0.03498938087640064, 0.047758928167500665, 0.02594843440290008, 0.012492602375069899, 0.04066369103799973, 0.021979360774691616, 0.06691822276583739, 0.009580205394221204, 0.02047845658047923, 0.023602662508242896, 0.02984809729137591, 0.04476390852193747, 0.05903646855482033, 0.01711318751664034, 0.02867275589544858, 0.08470002681549106, 0.061453932763210366, 0.018808491993695498, 0.023386197962931225, 0.028058964991942048, 0.010132894219298447, 0.007915955768632037, 0.023618893065888966, 0.023911105868007456, 0.015154107640098249, 0.1267891265451908, 0.019813453246440207, 0.014698863229049104, 0.031701624260417054, 0.0581392552703619, 0.05898248430873666, 0.043472181406936476, 0.08366665190884046, 0.011840998411311634, 0.04092056064733437, 0.0349702767229506, 0.03270013264513441, 0.028756344624395882, 0.005982166588572519, 0.011132132029160857, 0.042102724712874205, 0.02642490338933255, 0.030517197280590023, 0.04494844629828419, 0.11754855167652879, 0.10965519451669284, 0.056397062327180586, 0.06332983781716653, 0.09838590172252484, 0.042577315853642564, 0.015788592165336013, 0.022009564064709202, 0.050258800453905544, 0.02694124648613589, 0.01543419502143349, 0.0700522470953209, 0.05757900247616427, 0.02056751599801438, 0.029251383417951207, 0.012514637799800506, 0.03426713463185089, 0.020665945984157066, 0.05288624071649142, 0.053531195037066936, 0.008806098718196154, 0.021751931103478585, 0.027770389137523513, 0.026449006649532487, 0.04106189949171884, 0.07179884373077325, 0.029108626435377767, 0.006087953590654901, 0.033203527597444396, 0.006101331332631941, 0.029770248968686377, 0.008696124306879938, 0.004084155287793172, 0.005921595039710934, 0.045732391732079644, 0.04022113692813686, 0.07502164079674653, 0.0878430213779211, 0.03904512717521616, 0.015775403140911033, 0.05310106829607061, 0.022889673177685057, 0.1095924571688686, 0.03724057347114597, 0.03891268731760127, 0.019932079827412963, 0.053858089460326095, 0.06323668174445629, 0.037830060946622064, 0.029880415914314132, 0.03249988339043089, 0.0117460942627596, 0.022813946973266344, 0.09322532399424485, 0.004587663470634392, 0.0395716364229364, 0.05943719098078353, 0.01737388745615525, 0.019513747721378292, 0.020471028318362575, 0.03740899604079979, 0.017373984147395407, 0.017732545799974884, 0.06464337304766689, 0.019741677812167575, 0.02815426353897367, 0.04949236800894141, 0.036436889453658035, 0.07066201937517949, 0.020505411384095038, 0.03409970611599939, 0.01300661894492805, 0.05537243373692036, 0.008256648201495409, 0.04863864542650325, 0.020025607398045913, 0.07646492549351283, 0.0313060994126967, 0.032328102072434764, 0.06849443925810711, 0.022925167344510555, 0.004584957388163145, 0.01644797044407044, 0.01859152363613248, 0.034165469730006795, 0.041655203726674826, 0.03208079641418798, 0.0323265787613179, 0.0730992764500635, 0.047535469622484276, 0.03045759137187685, 0.04644632592265095, 0.0025121745503773646, 0.03561371451775942, 0.023406367416360548, 0.047308655721800666, 0.0304836233678673, 0.042898490226694515, 0.03079295051949365, 0.07056618308914558, 0.03098134576742138, 0.03961569709437234, 0.03778683826593416, 0.05111414134236319, 0.014898837677070072, 0.0212245906503605, 0.04132451629266143, 0.031230727742825235, 0.015281173500365444, 0.02213137297491942, 0.09239584886069808, 0.021684669623417512, 0.023212920475218977, 0.02504072418170316, 0.04674771082188402, 0.010648161838097232, 0.02327493518324835, 0.026287243901086704, 0.041317452743117294, 0.0394389014025884, 0.06845862617982285, 0.02323499321937561, 0.023958850984594653, 0.052336932692144594, 0.017305944048400437, 0.019621039374864528, 0.04447215881996921, 0.03410063910165003, 0.02593801380135119, 0.05116113667775478, 0.0213016773174916, 0.02422069595195353, 0.01648932376078197, 0.046154637288834365, 0.016125327042703117, 0.032143649112965376, 0.034948387183249, 0.035260387762848816, 0.012628294959930437, 0.0561103982451771, 0.0641583494309868, 0.04229272808879614, 0.01771665450983814, 0.023144066134201627, 0.11052717986915793, 0.00688639550103939, 0.039894893898495605, 0.05974442485187735, 0.0409958475003285, 0.004615842605874474, 0.032756525690534284, 0.05002690771860736, 0.02474389225244522, 0.10267910813646657, 0.026617283334157298, 0.027829908533021808, 0.020387380217601146, 0.051133740826376846, 0.02296630522635366, 0.05153244800333466, 0.016488797896142517, 0.03428091907075473, 0.017424965876021555, 0.056903911022735496, 0.03597730750750218, 0.037191854656807015, 0.043439343704708984, 0.03285658585705927, 0.037595691558505805, 0.03581655238355909, 0.03825739212334156, 0.023398481143106307, 0.03259841685316392, 0.05060885327735117, 0.052140673223350725, 0.03770432162231632, 0.03906090650707483, 0.1021588414109179, 0.027578552020713687, 0.0534493331797421, 0.034009990215833695, 0.03038824848564608, 0.0018233501842977212, 0.048901326688272614, 0.04747027597789254, 0.027533582112352763, 0.06466988341084548, 0.034997713286429644, 0.07510693943394081, 0.004295806051231921, 0.022358772112056613, 0.032520154624113014, 0.017681608176124946, 0.016067078204027245, 0.02249277090387685, 0.11579675067748342, 0.04567134054377675, 0.021315032582996146, 0.030096956794815402, 0.08118472687367882, 0.010022171723124172, 0.024913285127175704, 0.06719539075025491, 0.04429262863206012, 0.01946199924818107, 0.013951149020743157, 0.005764608329627663, 0.008225359255447984, 0.03127953815939171, 0.04339388185845954, 0.024036594134356295, 0.01282573168698166, 0.09791792969086341, 0.06354147967483316, 0.00842051356033023, 0.03376105946621724, 0.019297876894207935, 0.006471285588174526, 0.18060458025762013, 0.0888580826244184, 0.16376118335340703, 0.050509376650942225, 0.08560423579599176, 0.18530399166047573, 0.08773957192897797, 0.19902809523046017, 0.15539092464106424, 0.10291941131332091, 0.12527200366769517, 0.1956303854073797, 0.08345587857599769, 0.12637496234050818, 0.16010976928685391, 0.08261569615985666, 0.13797837256320886, 0.16329266849373067, 0.1339845968676465, 0.12164193631282874, 0.11139256986124174, 0.141790721565485, 0.1054064796439239, 0.11263736949435302, 0.21643125638365746, 0.11487870636795249, 0.13463889461542877, 0.130262981568064, 0.171975935410176, 0.16289401559957437, 0.06540850270539522, 0.12433990011257784, 0.19277391582727432, 0.1213566530495882, 0.2026426919869014, 0.10310670054916825, 0.1557985477681671, 0.19028753281704017, 0.08812829107046127, 0.13636508770287037, 0.06296260109437363, 0.09989938765232052, 0.0681305273569056, 0.13851620656039032, 0.07405783608555794, 0.14394174542810234, 0.11279592955751078, 0.1704900251435382, 0.19240677409938403, 0.1729815514492137, 0.06818124106419937, 0.14833387546241283, 0.0880009096914104, 0.11849531158804893, 0.11464769233550344, 0.1607154703566006, 0.1485182877097811, 0.11270518906946693, 0.13321508387369768, 0.19423632164086613, 0.12411666209144251, 0.145133945026568, 0.1176967980074031, 0.09496686554380826, 0.21071116546435015, 0.10098926416997399, 0.13973161205649376, 0.12315909990242549, 0.2029704244009086, 0.08743635498519454, 0.12772751333458082, 0.14233186681355747, 0.1595754772424698, 0.08009974259350981, 0.11189081134008509, 0.1419566369482449, 0.1485519159053053, 0.08844766393303871, 0.19673894877944673, 0.07937563716300897, 0.22655782156756946, 0.14150485476212843, 0.10974760420088257, 0.14129615096109255, 0.13114366573946817, 0.14935496209987573, 0.06527308747172356, 0.07713693979063205, 0.1292369823370661, 0.1857967030789171, 0.08669468906841107, 0.14726434142461844, 0.20737676295850957, 0.09186942782253027, 0.17902303726545402, 0.16153652487056597, 0.12940213776060513, 0.12005590141883918, 0.1385950387588569, 0.1699165544871773, 0.06621876851256404, 0.12185473846537725, 0.19235878810286522, 0.06811508389988116, 0.15577403908329351, 0.12309526332787105, 0.10550454831016914, 0.07862257864326239, 0.129629216289946, 0.14489113805549486, 0.08228123946381466, 0.14806273286896093, 0.09166795041944299, 0.09964304390762534, 0.13330199063888618, 0.1865739513720785, 0.132792220850076, 0.13450553534286364, 0.1138642422322716, 0.21147625440997736, 0.16372729731457575, 0.2413259462586471, 0.20225923827716283, 0.09229393968624727, 0.12878758859421524, 0.1736674282167639, 0.24271610166345323, 0.07241931650787592, 0.09437909136925425, 0.14536923382963451, 0.11415441094764642, 0.14245553660605634, 0.12451209872961044, 0.16199095334325517, 0.22531591249363764, 0.22298219986259937, 0.12823516609413282, 0.1739583568913596, 0.20794548386973993, 0.08233987167477608, 0.1123719537364585, 0.11430740702365126, 0.08365566642688853, 0.08428223244845867, 0.15164868187691483, 0.14303177568529332, 0.14427033279623303, 0.0924221488780209, 0.08095061193619456, 0.10286988504230976, 0.0939997835084796, 0.12157496490648814, 0.11671232511954648, 0.19198560741330895, 0.1154952911393983, 0.10960368692342724, 0.09414695096867425, 0.1700124450560127, 0.12175720584179674, 0.14338876652930463, 0.16153910330363683, 0.14904359595051833, 0.09256649363253798, 0.10409084774021592, 0.14676006776945932, 0.06711254840982811, 0.11478704985763345, 0.11821591800877027, 0.17606995786939347, 0.11874714307487011, 0.17804000287183694, 0.17617002821394376, 0.1521359107324055, 0.05238835886120796, 0.14640146201210363, 0.1399600612265723], [0.04069216236738222, 0.029224408258284842, 0.01819112690697823, 0.04120618657075933, 0.02161791704462043, 0.03422968289149659, 0.06397899905485765, 0.05216855422726699, 0.054853629254336865, 0.03497445989134056, 0.0838044827271785, 0.018371048948860595, 0.02772395868253495, 0.044517047304127894, 0.05589929921552539, 0.04434121852474553, 0.04457256164667862, 0.06987037256892238, 0.06418648149285998, 0.016029772348701954, 0.11632330742265497, 0.022496267055560435, 0.04111261319901262, 0.04063304839655757, 0.02457246886167143, 0.011911320932475584, 0.015278746041336229, 0.01905719204140561, 0.02721332206523844, 0.060975721638117514, 0.01936287376364427, 0.07414619491568633, 0.0031959616421123166, 0.005177345176759575, 0.09284176850425345, 0.0157194443579231, 0.04722729937306472, 0.030571751496089355, 0.07081764138170651, 0.04772614474807467, 0.090935180096754, 0.007704962760076991, 0.012385812837497463, 0.06350082185651575, 0.02538235129655472, 0.010515999331671213, 0.04265543559033956, 0.04455606306770018, 0.010446955000848641, 0.059943819152457375, 0.017198715159403424, 0.028145739442801902, 0.08304288823689733, 0.05312898322673781, 0.027434892586565444, 0.02016617780152176, 0.04819228134251066, 0.012814738571510782, 0.06594324258289166, 0.056979340368083546, 0.042660399074000974, 0.038775545212307146, 0.02646219906663256, 0.017265031779451028, 0.026998185752225772, 0.06796549406966992, 0.08490044570394925, 0.01670202922209033, 0.01913519642714943, 0.01735575869679451, 0.033095209659742456, 0.004051311224299882, 0.004707942284377558, 0.020423237400661622, 0.025398778629356196, 0.050602855027786324, 0.025143045566177795, 0.010041623625771275, 0.01777831807599536, 0.013394653614211296, 0.08550532574632339, 0.04511589177751115, 0.023607714201456735, 0.04149037739261985, 0.025417441735044122, 0.04139577943299498, 0.04426530741953424, 0.029473908977316957, 0.04198499549446361, 0.017450665389852862, 0.0577856231746929, 0.0160139353413667, 0.029238766059279442, 0.019922766934282014, 0.04445433709770441, 0.026401080024827803, 0.05584206817937749, 0.0013658058575986484, 0.04231184920562165, 0.007774161457616303, 0.020079528879640356, 0.01598945719056896, 0.04458293305443866, 0.054649308789521456, 0.027646863533716117, 0.03460570664278098, 0.023654008949441568, 0.03787922080872314, 0.019928463235763565, 0.016397791083103845, 0.029521484460149492, 0.03489780918295894, 0.029187149900410856, 0.036089584697037935, 0.0678502923942038, 0.03317670510815723, 0.04578320721962622, 0.036526819092354605, 0.03486977890133858, 0.019445716104071056, 0.018799879687971303, 0.0368889871585582, 0.051047482062131166, 0.033634417690336704, 0.00912959877002452, 0.019135169285748686, 0.0454821514098772, 0.02226666098327509, 0.057112774279500754, 0.07131783025605337, 0.03802501084282994, 0.014026273025332816, 0.09587661137006112, 0.03155955599088754, 0.07153326512447425, 0.040323205558317046, 0.015839287212916782, 0.03092268980773432, 0.02144253270567528, 0.09488404355943203, 0.033227920931364806, 0.04547243818108525, 0.018040168132366877, 0.059168294338243346, 0.016464794719857827, 0.07008100340941123, 0.016691673081368208, 0.047632727439382246, 0.010965143712902707, 0.005782423266542277, 0.0534520914245929, 0.03301275747695139, 0.02595569472759962, 0.05805166318480458, 0.010011154858927642, 0.05257651662187917, 0.024919916110645448, 0.13281523675790854, 0.03490083544914212, 0.07471158421997513, 0.036047810688614845, 0.020008077445839132, 0.02104146931586521, 0.02175384117955608, 0.04102929588407278, 0.07599119269954306, 0.010251574234903922, 0.039060869187648804, 0.02292456684101905, 0.055033132300845215, 0.06790331990591117, 0.014631298104567187, 0.02486808960592108, 0.013878998695872724, 0.026196969905868173, 0.016950620704197457, 0.04607051930257252, 0.024328701763546894, 0.08008769181157861, 0.1008536114490458, 0.021446325716429522, 0.06046729534864426, 0.034502243623137474, 0.05917406188590186, 0.04033017072028347, 0.029183054941573312, 0.11587404938680784, 0.026596464183447615, 0.05483038603727307, 0.04813094516949994, 0.044066523800471, 0.02781968131395323, 0.010006816475652158, 0.032314687435116084, 0.05256424531606691, 0.036213987307356935, 0.03239662732396807, 0.04523475414940289, 0.003954045349798564, 0.06244957433747394, 0.044213898213846345, 0.004592501001232969, 0.023132936463558247, 0.027197283193735138, 0.05355037722204413, 0.054607684058802466, 0.048087864981165955, 0.2010400736970561, 0.03679724583136184, 0.029229816182383468, 0.133682105956333, 0.04331195893298302, 0.04551916888781956, 0.04825137495728476, 0.040513626233275445, 0.015246281533368995, 0.0785948062049491, 0.016403387300670147, 0.00692062420005511, 0.061901508032211235, 0.02125168455365513, 0.0780449824939881, 0.03930627494784338, 0.019133669723357474, 0.026389069954997728, 0.09298842706318412, 0.06634061983121292, 0.013317428695570146, 0.033674780345921, 0.06459506813968931, 0.0500519863728966, 0.10008889569767884, 0.05943958620939936, 0.010379038734494575, 0.0918062087148428, 0.041185002707477124, 0.06829129265887396, 0.04447535132723195, 0.009398895748225706, 0.011634500697255135, 0.030525421125016043, 0.019800189583163177, 0.1013614134863019, 0.0024833840974939187, 0.005424833615377013, 0.028094236938548938, 0.02099489636852273, 0.05959864838847092, 0.013429580356127449, 0.04117057026763048, 0.017854478542826006, 0.05679385603538581, 0.016078614995681813, 0.03264816704073122, 0.02437602958109762, 0.0158911883564932, 0.011472032272389956, 0.007628136480759297, 0.04938984136762364, 0.019132724863344004, 0.07471853920391627, 0.04246895041848932, 0.04004341842872756, 0.03911859216168523, 0.0437276532341327, 0.0195303362062467, 0.021074670034327676, 0.006255488975771836, 0.05841884562479598, 0.03807006896074329, 0.017135343381336758, 0.03837661072611809, 0.03915626442592059, 0.0201328244126801, 0.06048355304769107, 0.03459790349006653, 0.02760745761250811, 0.027232517820916007, 0.05632396374962159, 0.008496837723734123, 0.03390329058415123, 0.0403852813344981, 0.03238936360659344, 0.02511230284082038, 0.013797901886781412, 0.031925500104469914, 0.009914699409689223, 0.024774909784485186, 0.06371580889182431, 0.022953540286315337, 0.014413286499412996, 0.018602108782423393, 0.018434765083449225, 0.03492775971868208, 0.020025797387851135, 0.060051780859274526, 0.009237812382967343, 0.025993178698367307, 0.045855240497205935, 0.030642984102347066, 0.07407050433435611, 0.0413911993216191, 0.010802232543937862, 0.041174247927431545, 0.058294877276888916, 0.10929192722375904, 0.017643510131165385, 0.05824708127017532, 0.046177877113223076, 0.02221977082081139, 0.031182232845042433, 0.025709113405485238, 0.06389490142464638, 0.026637094860364283, 0.01867283757642976, 0.08310656874839749, 0.04609744696478758, 0.04064994391852191, 0.059660306865615506, 0.03634923969262412, 0.040540234984031746, 0.03935296833515167, 0.027584173683343188, 0.003695641827237393, 0.05490457366353699, 0.014260755219895924, 0.02269964266036238, 0.039764109666326215, 0.03939439629071525, 0.01810169599152037, 0.014701568887435963, 0.10204539035579988, 0.014675728577588285, 0.05369034203301583, 0.029879435431212187, 0.028615955729037523, 0.014066212444699236, 0.010287740999566657, 0.05112818701724921, 0.035120307600923946, 0.030504671524145772, 0.0602306155487895, 0.016100994776934385, 0.03631834938590016, 0.0468440085117306, 0.07696883273976189, 0.0319707380341632, 0.07025025718446289, 0.05622466354231749, 0.034727802234036584, 0.025417073629796505, 0.051947368774563074, 0.12374995462596416, 0.09029575583658048, 0.10749987552740745, 0.21044478618672915, 0.14929173620683805, 0.10113526454993657, 0.13579741173556872, 0.1821201696459736, 0.16977756337395736, 0.1575375787381615, 0.18544751538762025, 0.10910391874079194, 0.1399880847228425, 0.16334042378834315, 0.14014051082943166, 0.09633880906871387, 0.10284355109823601, 0.09524965179818017, 0.22916453597801073, 0.11385600481714521, 0.17070566357246467, 0.06814758572727442, 0.08777947657342468, 0.16419848560222558, 0.07339291926473379, 0.09883671360356466, 0.07447918597608805, 0.14279309420713357, 0.17994788049587182, 0.1808197029999324, 0.11800055099385125, 0.33169676842434065, 0.1009805246389338, 0.1695740707218647, 0.3041226794677121, 0.19632942575429166, 0.17102175232555183, 0.09495542544339385, 0.14066849249814237, 0.14064888283610344, 0.25043552315660883, 0.09709330608269998, 0.07582338420408112, 0.2156590156789337, 0.060586649658424516, 0.12366230147225515, 0.07224365057689802, 0.07591008062341384, 0.13984080191169465, 0.1936227631356035, 0.10519168938377074, 0.14493130732859882, 0.16182278522423335, 0.12355050604258265, 0.07765195465513638, 0.17426428118986742, 0.15351922650422367, 0.11139461903699807, 0.25376343886767116, 0.12140671536326408, 0.2265379269208227, 0.12005629496914999, 0.06488220380353076, 0.1249773973332984, 0.11344454796718699, 0.22256540294204438, 0.18789294202412876, 0.146113410325987, 0.04971685114183596, 0.13313682164464677, 0.08669366448053292, 0.10852867710803236, 0.1408186387270689, 0.10676760053528206, 0.0935558316164783, 0.08132511576903717, 0.23598419289503778, 0.13992529309221677, 0.07214485587818281, 0.1143408180879695, 0.11299685056188277, 0.075921038963965, 0.13295369861381395, 0.11840345151722431, 0.14162568827824934, 0.12558497115969658, 0.13194516487419605, 0.07844303827732801, 0.19831807618694647, 0.07810591493866273, 0.09655226261488029, 0.09504981644983802, 0.139082973290767, 0.10754389887941734, 0.15546314790844917, 0.08466353520218815, 0.1321471511785473, 0.10600918158888817, 0.11000452470034361, 0.1284773623836892, 0.12162457938705172, 0.18661387637257576, 0.14156595005520753, 0.15160669412996086, 0.16092439128884248, 0.0874908956299935, 0.15997708854930742, 0.13473444591675485, 0.07130739438746657, 0.11796082955385957, 0.11368574681026594, 0.06953569874167442, 0.20630033500492573, 0.16195894006107533, 0.1144265713436263, 0.12310507494424071, 0.09053042717278004, 0.16283024687852177, 0.08366976638457604, 0.18404780620975153, 0.10516677357788597, 0.13617250589387758, 0.14964351590190614, 0.05580890817301614, 0.12043626100889274, 0.13448527428720677, 0.12881044165364333, 0.1556272991001606, 0.18696891303573335, 0.17009802189256462, 0.0959963049473507, 0.12160521399761949, 0.15723176300525665, 0.10435254512620823, 0.16158826995108808, 0.1556608730128833, 0.33469830879143303, 0.14754292076187475, 0.07972308780465807, 0.14659381311919006, 0.13972501669611248, 0.13059193534510477, 0.15073343313166074, 0.16437182415808949, 0.08053467675511326, 0.0780686769368393, 0.1249604339578322, 0.12088485408042159, 0.07950542734137603, 0.04609363359798278, 0.12673519658190863, 0.10708349251321383, 0.11486886761018208, 0.13330260132040295, 0.08731462580284902, 0.17981340842587606, 0.08728415958051171, 0.1947243647383792, 0.1388601152492421, 0.09807141431208168, 0.0913717970252037, 0.10298757015594415, 0.10620082023420505, 0.12093320648585047, 0.1540949091847454, 0.2929906068103654, 0.12171379317130361, 0.10954036603548697, 0.12438753327088696, 0.22129339405468532, 0.2641152505363737, 0.16025846345084055, 0.19060554860958032, 0.045870809483208826, 0.09306029749235936, 0.07230319881013461], [0.038573935494891236, 0.04115923873281904, 0.018407913756423762, 0.02116888462166701, 0.021518199538279856, 0.023941921535879374, 0.044263265029128106, 0.028646557658378567, 0.010665268554086131, 0.04747713596693107, 0.019608781639752642, 0.03396002628973552, 0.05416470586455294, 0.02610594782579158, 0.02877304676387991, 0.014539326075464487, 0.030331957220499004, 0.02005151895407055, 0.02088976415273334, 0.02006614308005997, 0.025750376816306795, 0.049587651288935115, 0.03295073937624693, 0.051106273728821955, 0.009335135508860861, 0.05672619591600128, 0.0637918251699635, 0.026505355590156147, 0.04163909869800721, 0.01553955115377903, 0.04661644822252648, 0.030965780174093585, 0.054232182779482434, 0.04198580973648599, 0.06562542356550694, 0.026228818643305982, 0.02534171722696296, 0.042613064471100054, 0.023537845450586507, 0.032657863306147714, 0.04945006474320378, 0.00449577159348077, 0.03390031520809446, 0.05269919236057571, 0.07168577944061585, 0.026016711989151578, 0.020617676699267964, 0.03267455187493137, 0.04610488031591688, 0.031102362487997328, 0.011769535103147584, 0.03273048012384346, 0.009842183524077492, 0.017207977162407975, 0.029084097394453626, 0.033192508188741546, 0.06211260027651276, 0.039716839524252076, 0.016971015770520483, 0.015647019226370112, 0.04525198893887656, 0.049190318145390065, 0.06137425239597048, 0.04106618104768651, 0.01215206939793591, 0.025444705272093415, 0.03671920412619199, 0.015582987572997808, 0.05730970549796309, 0.02623959208306457, 0.025709461154682294, 0.031707910887364826, 0.08813236228057317, 0.042710909220789156, 0.007558013279257076, 0.026396391347848942, 0.057978076062032154, 0.02002964468140687, 0.02337384014390409, 0.0806574033839362, 0.04133312350937298, 0.07742626712258373, 0.05065635751400675, 0.024433971382677555, 0.08043987862765789, 0.034044510684907436, 0.024222807892199074, 0.008059349725954235, 0.029953704481678348, 0.03339289654312389, 0.03841172830600824, 0.03066020192844527, 0.0887801121654255, 0.027632807680804814, 0.03783774535570826, 0.032349638773926666, 0.05760487501642533, 0.0392555578478745, 0.027268473391554186, 0.02120961368616138, 0.02100466557645372, 0.04233611022521343, 0.03415488458371588, 0.05801367200911045, 0.08039485782917057, 0.020876709138974547, 0.010136357292399874, 0.012620703001240534, 0.04804307149190988, 0.07707881648093462, 0.03480680745893291, 0.03738292333270822, 0.047634260928524394, 0.03567880638209837, 0.03641754102760127, 0.029995478490101438, 0.01514710855138089, 0.020404779551816837, 0.023258836939930916, 0.031686486144151, 0.01857392074141119, 0.10554075493876423, 0.06008095107972622, 0.030593026961599077, 0.044010076472269635, 0.06714527415377752, 0.05126777524128556, 0.03060332712318216, 0.041502719944609065, 0.02274517066377614, 0.009525579084376139, 0.0007850577011205522, 0.008816636367035764, 0.021358397756037966, 0.02770818104701383, 0.024702337071565644, 0.022051032732373903, 0.012936527973839214, 0.04808248759114316, 0.026963860361969898, 0.04358358667897327, 0.02050777098962239, 0.03624078265524336, 0.02141673310792872, 0.057536410833043714, 0.017445416921483617, 0.017441488203725646, 0.06654717946158988, 0.04399476872224893, 0.05136694652693612, 0.020110770328236476, 0.021448205258431177, 0.09821742147739444, 0.07349482843918459, 0.04534194232629878, 0.01219269328950239, 0.030187327481274093, 0.038080630358308554, 0.01798469280557973, 0.033721670508384705, 0.07922252573605094, 0.015410522630970393, 0.08736432849296502, 0.052092039225889106, 0.005386884848121554, 0.028964162937232425, 0.03387481586209365, 0.032331189406769614, 0.027031754575935856, 0.03015818100954805, 0.05071075566645179, 0.011611778255818146, 0.07846466997372252, 0.060652610047587326, 0.08748117900852646, 0.03168859978073409, 0.03267055530367153, 0.01650439402354615, 0.05089187023362943, 0.028629553570811237, 0.034117782288896184, 0.04098181539614286, 0.004372538183815777, 0.01577041930119906, 0.019761382469109127, 0.037564472162297795, 0.029829278122633696, 0.018445635214447975, 0.028965218059186424, 0.07341824897697993, 0.0826529273763299, 0.02012384739438338, 0.01253734836687467, 0.06834931418831859, 0.031600939841674905, 0.056422972186867676, 0.044361069066716094, 0.04609549617660897, 0.0468864814112229, 0.0242627311963588, 0.0407801785373262, 0.09622755646705627, 0.07963360260639872, 0.031877252871968915, 0.0588954146951437, 0.05210572188454015, 0.04867508614967976, 0.04767661169171333, 0.03274104830675891, 0.029163194221577475, 0.04479929073048489, 0.0609522850385734, 0.03027422067576221, 0.1461884155869484, 0.009640294759135162, 0.008442687236570885, 0.050576571973838975, 0.029935689376933233, 0.03116381061928613, 0.035791181959211826, 0.05995661632290908, 0.0038882656205844668, 0.0274122736217188, 0.029075147517557656, 0.002656030123554436, 0.026415432736809765, 0.05379951831751636, 0.10238142125308514, 0.03343230585700699, 0.04319292014198644, 0.04165408414389406, 0.01949744252488017, 0.013124847734746124, 0.03360242476420743, 0.027991652621754577, 0.01784193412666874, 0.025022347757060612, 0.02526977555161076, 0.011788891162723303, 0.0158683963652168, 0.056517040889178, 0.0313336615051542, 0.03706689564777272, 0.0159330828048821, 0.048056601480181725, 0.004670049920345524, 0.012384718699779893, 0.02658011148949819, 0.026792810165456364, 0.0344082495596792, 0.026067963435447643, 0.03932373026119811, 0.02144757252452629, 0.01516779199508684, 0.0487743693936084, 0.07181240764579602, 0.030365900934806893, 0.0714553218068821, 0.05351084916453276, 0.017394095925348144, 0.06516022674207177, 0.037715181575289795, 0.04108962443258081, 0.007963163146216954, 0.06487526917564017, 0.02252474008128047, 0.04102545537586723, 0.0383634030419801, 0.02858565914045487, 0.042970459043447456, 0.06650674555982862, 0.023084422906062434, 0.0045034593952420566, 0.10123079549521208, 0.017196073961843337, 0.08052407125277178, 0.00729000721392887, 0.012368019104802182, 0.0009429629779853192, 0.008479975280351937, 0.06210352147796324, 0.030270614262138094, 0.050803419801273515, 0.020610738678702285, 0.049139733359749825, 0.041836759341614585, 0.08850168210587331, 0.06003670381116016, 0.05398323506649051, 0.060995215949203284, 0.027438415879649774, 0.0024471940081899186, 0.04091280159939613, 0.02363815837140594, 0.08309699461928435, 0.042073116837335486, 0.013621201189900083, 0.031923328792410235, 0.09025486731635672, 0.016029984390895282, 0.044510540153299055, 0.0892865639179945, 0.047756906133145094, 0.020158189748014723, 0.04091598392863359, 0.04429963111345257, 0.0742411966036473, 0.040170267157788785, 0.04833963539983545, 0.01434661025580551, 0.0466279867105186, 0.04302602427612458, 0.026445892173796892, 0.07846262758331639, 0.022615709574893117, 0.05464798564623509, 0.06545494842742171, 0.030393992284578935, 0.030823335317628722, 0.009814049765866781, 0.03920915623062423, 0.025228931136163216, 0.036666373389640024, 0.046969751228711436, 0.023229424143210053, 0.0027355243177485783, 0.047429635122950585, 0.021253732033073902, 0.06547403561749629, 0.012799243376191174, 0.004108713166455605, 0.048182374731238396, 0.027532296288492422, 0.004005421900988689, 0.008462002584045487, 0.029491462678249394, 0.01646809240004846, 0.020937225980950252, 0.0364525195078126, 0.02837626832271261, 0.05988007757280554, 0.01696902766291584, 0.022198680256094252, 0.02517803931342704, 0.01734075798386974, 0.045712134069097896, 0.03275157238489815, 0.037948444951325655, 0.01160874605245356, 0.010179850538926465, 0.05420319915616086, 0.018763060681521893, 0.21447550132870674, 0.13213911732392652, 0.14630285730319365, 0.10844003329319613, 0.13330735106553349, 0.1886403076350689, 0.2518011698765414, 0.09270977308707577, 0.1806493771395513, 0.11851156928709575, 0.07551569571452481, 0.16028396279684134, 0.09076679484652621, 0.11765263894838945, 0.18854444420763425, 0.10309563364301409, 0.06442887455757175, 0.1176051279263837, 0.12651137502065726, 0.09861832710781268, 0.07018789303089891, 0.18585116229951382, 0.14520036003419332, 0.07694106030144862, 0.11975395333554063, 0.1687800490430423, 0.2094677636133773, 0.09793395668800388, 0.19076566930328095, 0.11487730858581406, 0.1370075246585267, 0.10079780194376196, 0.11372044030576944, 0.1299077956272023, 0.16977224365941115, 0.16381011929895195, 0.11221826555473463, 0.17249037351991447, 0.15524525674326078, 0.13762352588985646, 0.10069731090750013, 0.11873251385986805, 0.10652834908770663, 0.1261011463190828, 0.08667186315038375, 0.11611323298088141, 0.07591613315578018, 0.09394738703433957, 0.08653880243322679, 0.06012267419802291, 0.16982245525079115, 0.17770604150635855, 0.08244023378938437, 0.166450774031026, 0.12081619990723473, 0.11162206397524901, 0.162478005779641, 0.16562623184706482, 0.15874444826373033, 0.07828970293381385, 0.1133732542927776, 0.13080420824033873, 0.15309628205639975, 0.13943260881517613, 0.08349918268088784, 0.1304610866521086, 0.1745772622525692, 0.1945039222815207, 0.22438041626342706, 0.12977843971124717, 0.1653538950319801, 0.11256651686770575, 0.16436688442315373, 0.13409146613308362, 0.10760859040809528, 0.09446823730000428, 0.2139730325766972, 0.17610264968659195, 0.1353756207972765, 0.17818432727030345, 0.12718289398721286, 0.21120015851088933, 0.15076054739100592, 0.07401036577565329, 0.1516362511153732, 0.1402965738837208, 0.13678449019789696, 0.07354174235037395, 0.10071063733526639, 0.07862865831702948, 0.08428906529609646, 0.1534798986145428, 0.25243296740310533, 0.1601704710296222, 0.18069178557821683, 0.09123677534184285, 0.1568419717784439, 0.14087840409151145, 0.17035840292062077, 0.13330203135098728, 0.08722899468349558, 0.16206783136086805, 0.11086680021669183, 0.12415734705116067, 0.20273308642208576, 0.11499283595808915, 0.08531634017292943, 0.10244145124618496, 0.17943237030080386, 0.12169190363160201, 0.24361725045101984, 0.16421352193823882, 0.14917897725743906, 0.12638998510582106, 0.10271239027913127, 0.09230163427335875, 0.08382032651986394, 0.10843193158507347, 0.25654176835502895, 0.131902919283935, 0.07187414076179266, 0.16012932466609137, 0.15977645931499346, 0.07984736149332353, 0.12845847196877003, 0.12084745323019368, 0.14234699814447335, 0.07898446851010833, 0.09848443857793297, 0.10420056006738118, 0.11617978369551045, 0.11034141055175237, 0.11266608509634223, 0.11233208301876273, 0.16212883165904454, 0.14158446049051626, 0.10512760853660957, 0.18913638458720275, 0.21386403271130153, 0.13489589653909206, 0.14291328990033694, 0.12273559905588627, 0.15599672070571355, 0.0722791583144239, 0.0814047282827752, 0.07188467841063227, 0.09082912507333926, 0.1829588117876223, 0.11823338350015027, 0.10975327675363847, 0.10384943855128118, 0.07729612410600696, 0.18877141417137214, 0.10971088867102351, 0.16133375146559306, 0.1851655569459711, 0.21316895500889846, 0.1286831484841449, 0.10410933781947408, 0.10873978292303425, 0.18091164449495928, 0.11871211709720747, 0.12038059399596282, 0.07910822651215962, 0.13408868413950714, 0.10250931153339998, 0.07928100188395806, 0.09630754217505455, 0.09706487546541862, 0.15932553208300046, 0.09767073938356978, 0.06778375525027514, 0.1069226118602923, 0.10530170026634421, 0.1891726997814008, 0.09710805064865521], [0.012410659093542822, 0.06773283119712557, 0.02152795687184802, 0.03188436391896435, 0.045313867939902205, 0.05654794476660235, 0.03853935056499072, 0.026435286671455418, 0.05131586980340736, 0.010269621570062424, 0.03419268576960478, 0.007892323242101287, 0.015786587094355906, 0.03069109223516924, 0.03250789688900113, 0.02390249356228326, 0.053463076906544824, 0.033634210737156015, 0.014779617377955998, 0.032547770999372005, 0.024781874946451614, 0.058714374766818116, 0.02229847918663706, 0.05199295275711587, 0.015236010209524205, 0.024506801938904182, 0.056073682715318034, 0.08586379579667534, 0.022338594176939557, 0.03820177600053804, 0.04102449185614075, 0.03497229875730617, 0.02931313349732331, 0.02578581161131816, 0.006444902450311929, 0.008746145060285926, 0.027656278207099864, 0.023600776180891053, 0.017067739241091267, 0.03157911815547517, 0.01709845652138548, 0.013563591022310513, 0.03912203233422978, 0.06833338897143092, 0.044068539049476385, 0.013383201639434057, 0.005744004613786403, 0.03906818040247474, 0.02909896070403712, 0.006810168452960039, 0.03496899089909025, 0.019487980354045118, 0.022200010184730803, 0.0411877779157034, 0.028238115200240697, 0.024504798564261625, 0.03902404848486185, 0.0010265758797426575, 0.04075958839218531, 0.06689851132354566, 0.04894735171858754, 0.0770874135196209, 0.09739197005650826, 0.06997650901653937, 0.03455822615485106, 0.05788866550262485, 0.022967075363599827, 0.08658940757491759, 0.03370953490957618, 0.027176657425505773, 0.03629330126568675, 0.06442289666405746, 0.03674351942858525, 0.026613934763840268, 0.021393220173195004, 0.006788969746724303, 0.02651742333546281, 0.02139822776163263, 0.027900079231975333, 0.03487501719168254, 0.03367948937895043, 0.01155197387561202, 0.09133286268583365, 0.06244707054325512, 0.03233036159404686, 0.0333684964238533, 0.06302676336573702, 0.02097669636298503, 0.03374146676755377, 0.026358176255598664, 0.04198370288525309, 0.05432341181273971, 0.11115460763020174, 0.06407032308301755, 0.03554759128019214, 0.007610510685481131, 0.05976991741252797, 0.06522100990904228, 0.049854790525777, 0.029164273092257123, 0.07439979737890617, 0.06875174652252879, 0.022992284635880163, 0.03984992399013468, 0.03924731704007302, 0.03132819590557899, 0.0380689086658614, 0.0228820701928011, 0.03161613902609263, 0.034111034258135726, 0.0036168418591842055, 0.0032544229470659047, 0.02387180851240243, 0.007023714025438364, 0.023068909899198582, 0.018805335109521235, 0.03529781236180237, 0.02490249472404165, 0.013872021659543472, 0.0735808259674481, 0.060690302667873244, 0.09126553844128336, 0.050065685994923115, 0.02599479361171169, 0.05194852228409477, 0.016503642546012998, 0.014668907604313322, 0.08262343145906925, 0.02469358905883772, 0.024083664108599936, 0.05556545998635037, 0.022601039647789936, 0.023231276543810964, 0.0480413039081863, 0.08518214630229132, 0.020277942697118436, 0.05655184634295957, 0.006282414093480578, 0.018794682109728456, 0.0695293815806508, 0.09272789675742388, 0.11880822479724884, 0.033231700371418676, 0.049663810059428215, 0.016802959609776735, 0.004535786499868014, 0.005321565674551363, 0.13287988757448538, 0.017780984718618647, 0.027641111253095523, 0.03571563387023551, 0.05628281060074057, 0.03302623318242175, 0.053720211144536734, 0.036865536988313706, 0.08072224419031825, 0.017354688307802593, 0.02274542341807059, 0.03192466211372188, 0.012677926403869475, 0.06734259892255068, 0.02808869500378413, 0.04220188582049949, 0.07194354132350002, 0.04758909763768315, 0.030568725229906182, 0.10979504058403627, 0.03323405488793339, 0.05446351911606533, 0.0957962456824524, 0.011983509424940815, 0.02547195184576724, 0.06789135054818221, 0.027259511640295386, 0.014781546113746507, 0.024365608979548727, 0.017842926484133517, 0.057468889813338, 0.05694967481706824, 0.049129165176834376, 0.023265413640599166, 0.01870074402540922, 0.016071112094713107, 0.0032405759557150304, 0.049535865496311865, 0.04430003823446376, 0.03483894966276629, 0.024312656106693403, 0.06846605613827705, 0.020081779919564724, 0.0077409064563523445, 0.068557054469628, 0.015371554364849414, 0.026662792677858045, 0.028862844088247845, 0.029110977559217384, 0.039936277749282975, 0.04179034415366394, 0.016655408777296543, 0.02205506831939731, 0.03645028034225106, 0.029308712841676812, 0.04740760987624526, 0.03979063360020518, 0.017416402764086212, 0.06284463099603142, 0.0205370328123016, 0.015131724466170584, 0.04373831980462585, 0.021478802098759582, 0.003954152219064001, 0.03427708874057446, 0.09083118781979595, 0.06924387440085411, 0.1590681637504271, 0.032188564738524814, 0.03175164586199181, 0.025682967754879167, 0.04067924306062715, 0.06127061295722212, 0.020509815076366067, 0.048136712717158456, 0.030179853418043683, 0.033034263644367456, 0.022407969293583716, 0.019289517342778187, 0.04169460625520774, 0.007292036033634628, 0.048881666136107275, 0.01005903398618102, 0.04270751315302082, 0.020858470117673278, 0.03309269229482327, 0.04357235353173954, 0.016620969732425044, 0.020924713795206377, 0.027887855423614383, 0.019245510954143744, 0.049570311326533556, 0.04422306861462338, 0.044754602414156706, 0.01384435354598931, 0.009621277118899992, 0.03288809363065021, 0.05454882453860981, 0.020519207697361708, 0.024981647530304532, 0.05584450751276953, 0.07108765082167727, 0.04586217851777162, 0.02164593036286533, 0.019838694749133925, 0.0421714060274618, 0.051316568694476566, 0.012849114003724285, 0.005854871298652142, 0.039545360154339244, 0.010505797557665833, 0.03314804718164461, 0.013545364723540843, 0.06265069211700133, 0.028112364001572132, 0.02150898503272661, 0.052591098339429924, 0.013668925102267946, 0.08873187511094979, 0.02679350057483784, 0.020399665094113777, 0.05047051016507404, 0.03595240187964269, 0.03653094797794308, 0.03376313578337431, 0.008191107655875385, 0.018535564853144542, 0.09220430521028382, 0.06048992449151618, 0.013610216556116939, 0.027497114247775505, 0.023106027461056198, 0.06227278882371528, 0.0390364724610533, 0.02595301790695105, 0.026768304873257875, 0.07972721329757146, 0.02801278729124793, 0.02993090231237667, 0.023218148587537662, 0.022309658051069294, 0.039872593845107725, 0.03665156097018293, 0.043134053836443594, 0.029915156907268932, 0.030886466215763773, 0.046782282181084156, 0.0169711328178112, 0.050199801834034066, 0.012267677346244454, 0.04932304298771279, 0.07769540803773062, 0.009481960308871098, 0.05787239423287766, 0.028813562089843408, 0.0656659524621708, 0.014919302293232508, 0.01304841585390802, 0.03584193637860673, 0.08260132478816168, 0.04062426136806607, 0.04196696003366794, 0.0773579047194549, 0.024447521726999964, 0.04319083703947919, 0.027195074562249438, 0.016793066569204842, 0.042146948232714615, 0.02709749953023025, 0.06647010466882161, 0.08369700956557478, 0.027092264632561376, 0.014115859155676194, 0.06436416945819344, 0.021179697077189173, 0.024915415727134262, 0.048345396162143776, 0.03613691929993885, 0.08055854083171912, 0.01919279047953231, 0.07712089243744101, 0.03434885399682181, 0.03710684778967074, 0.051108580747885365, 0.040151953497635465, 0.03770906458209668, 0.03537634600486074, 0.012473047844001224, 0.035068691442055364, 0.035621198759015114, 0.03700527449005416, 0.013002844593886818, 0.02428279208418514, 0.05209716555795499, 0.040643721752400906, 0.07984907140157052, 0.04785749216430953, 0.01853316114284098, 0.0749088004231453, 0.025159959747855152, 0.04370870514373694, 0.042235978812511475, 0.0461126495418804, 0.046478040649422576, 0.06509529094078711, 0.03942524927801319, 0.16303063184022903, 0.1403085296707494, 0.07099034211465291, 0.05572032881900668, 0.09614211533750806, 0.14810839827571595, 0.0702181149806295, 0.15923490694590978, 0.1183624408606972, 0.103612270206213, 0.13815131756876195, 0.11238528694957495, 0.0798059572864856, 0.09632852247783116, 0.1287514633898224, 0.13310480836246694, 0.09967362548091582, 0.16136192423956736, 0.19905169467840875, 0.08888789066778761, 0.12407794488327843, 0.06521649765116827, 0.13359414067651543, 0.12079064627843243, 0.08373106523816075, 0.09879062750509807, 0.09768436436674424, 0.19990322898541177, 0.15682488626667432, 0.10633883425699812, 0.062256130789007456, 0.11237455931093011, 0.1515483401183571, 0.08388456343007938, 0.1390585188886949, 0.17539149070424692, 0.16855979657598905, 0.24670135495918138, 0.1026272341342909, 0.11691965827984468, 0.07192560085760695, 0.11608041902737957, 0.1658551695623568, 0.11239829446588244, 0.1223778889647552, 0.15725118267749036, 0.1594907282186406, 0.04903014316888792, 0.13134277505534037, 0.07276657037436962, 0.056129526147352796, 0.16844261357826845, 0.10296799442065613, 0.09480742338512625, 0.07477829099765845, 0.21187190817935125, 0.09958662372082472, 0.143223624676466, 0.09984373421009098, 0.08744271285831928, 0.15441436347152504, 0.1571047276790653, 0.149958464716162, 0.1737749217344182, 0.12713241098182543, 0.08679904096892901, 0.1720299603683608, 0.18672605178185872, 0.12094749643334321, 0.10699905561549322, 0.11269984221351997, 0.1597631193165268, 0.11641640242721353, 0.10711851170552628, 0.0953414575862033, 0.13518882010664257, 0.1602538629834141, 0.10759506720517363, 0.09402252121695451, 0.12363769779247896, 0.117300045011299, 0.2956860193184444, 0.14059814198740891, 0.13016330477382454, 0.09321968536823988, 0.13813581982893602, 0.18875540074493202, 0.14009192772209644, 0.1331342432115759, 0.21923383671258176, 0.18066969247800962, 0.14135156013071537, 0.11907478049397469, 0.10290901615683522, 0.1637030600437096, 0.1411309955375535, 0.13004893091108116, 0.21706716583243438, 0.11887306560363088, 0.15940972470811435, 0.09749006586415426, 0.1276688471968685, 0.14496372773178987, 0.12202194306467261, 0.09866732412150928, 0.14518507942557335, 0.15595382372183458, 0.15634517557919025, 0.16411546005734376, 0.06776899711361953, 0.07149053777434997, 0.1690843855696065, 0.10216735702540193, 0.08757577357547623, 0.08072816780103104, 0.1230878537254674, 0.15095892388905796, 0.11511057535452501, 0.15908165302659782, 0.1166502663067409, 0.17854226806334086, 0.19170614598052843, 0.13464508285479887, 0.15734795534185, 0.1267092086906944, 0.14431545537497315, 0.12333710677921772, 0.0968250608337777, 0.10347679390438966, 0.1137758834021432, 0.14280342151011738, 0.11074076912232808, 0.13260798502181256, 0.1678338726716382, 0.15217910627169268, 0.12589028477668762, 0.06378361489623785, 0.16771658110831464, 0.11890741304627486, 0.2552437580057553, 0.3034672146396977, 0.09872748982161283, 0.21193034361515725, 0.16517298402530806, 0.07175265585205384, 0.09506167045661382, 0.1296374537050724, 0.13684285778020108, 0.20465779171458312, 0.11790281480976514, 0.216819147712418, 0.2090997262192624, 0.13375534702624592, 0.12857809769255774, 0.1480709702840873, 0.08154029279415097, 0.1176250090024301, 0.11803229286202363, 0.08899662590452603, 0.16769047108079704, 0.15938878511743887, 0.14307833675827297, 0.17570413249943936, 0.0793279768632991, 0.1410471150385482, 0.17615170776844025, 0.09514316929770367, 0.1306517549923488, 0.19003823905118875, 0.07850344825003829, 0.11337158509663173, 0.19225575934563363, 0.1476143840700388, 0.07263709232211113, 0.21113923963691505], [0.046093986436192474, 0.01463157291124974, 0.02680630961965237, 0.02145365559096847, 0.05786348506808281, 0.013241233453819794, 0.009668301292029875, 0.04911109918196287, 0.02185543822789831, 0.05196373164653778, 0.02155930518970958, 0.09869712537952832, 0.033714186267129014, 0.0181032871561391, 0.03844687641997423, 0.029942355983491455, 0.00849930928753955, 0.030383342677461248, 0.025153822398611476, 0.035786428821406195, 0.031558063213846514, 0.02173530021017151, 0.03223726998216339, 0.028657091914543083, 0.03014754836580583, 0.01545190648175776, 0.017441939429513047, 0.05315287783741951, 0.0028527104961020605, 0.01716351954798613, 0.017148752929642797, 0.035472830291837454, 0.05469007856611695, 0.012235943111591041, 0.028395708350996886, 0.034479943569749594, 0.02660001631427024, 0.019153209835557, 0.04174692130514553, 0.014447386276775172, 0.0401388340230499, 0.015395657625049353, 0.031136774391468083, 0.014654023938679268, 0.02976718538307718, 0.030138181189873388, 0.01529309366430555, 0.0649091959265726, 0.02775015013425478, 0.028843024080353122, 0.039647805371454785, 0.03808421641588211, 0.03736938995176128, 0.052182786499283144, 0.03571600367182067, 0.027779529004224708, 0.040158630282218964, 0.025667972130967037, 0.03714101881320987, 0.008548238447734287, 0.051590520422905684, 0.0027846296850059715, 0.01332222084913935, 0.04568295367062092, 0.06472330447286367, 0.028579569288662503, 0.026861009720180715, 0.0016336118611174502, 0.03172450106857078, 0.012201227563699442, 0.019655505561136773, 0.06393819195883614, 0.03626746265217662, 0.03255778956892235, 0.026851947885006666, 0.03431917487510613, 0.02911483163812331, 0.019831984037799493, 0.01183146923514349, 0.05100400832348636, 0.04550329116838319, 0.018241604823353033, 0.029508595687470267, 0.08507375711841242, 0.021347760023283105, 0.04238929379997509, 0.019865686872175763, 0.0377954047705446, 0.03230286056974104, 0.03561664918171508, 0.015848379582166672, 0.03914467165512698, 0.012488960338357304, 0.042640158374394686, 0.03794018378747361, 0.07469371839293412, 0.02142558798992208, 0.03312567248940468, 0.07234774463410888, 0.032288390810468366, 0.010858918207564523, 0.00286003719000811, 0.011245028381901128, 0.04121731793774026, 0.041424729129565616, 0.019193289202771018, 0.027689010736399462, 0.025270862903978144, 0.03545679650934679, 0.02049415109546057, 0.06664700553353343, 0.01654298061371914, 0.026475963149485842, 0.016231415992868797, 0.053921468023742945, 0.021345420773806315, 0.009710831018829984, 0.05858636913555009, 0.03837447673348444, 0.017521353471758108, 0.015136462336938297, 0.03648169990628958, 0.05842731374182871, 0.0793308334957276, 0.03179008487079825, 0.03138442270989929, 0.04800545351047601, 0.04671765172055789, 0.0277419568239046, 0.02386399857433779, 0.08757312728890351, 0.024600901175290346, 0.022819203923323324, 0.02345155275958989, 0.050410805868783166, 0.04248948967350381, 0.03513754239039762, 0.04695903716076698, 0.06066313412572656, 0.03231355767431004, 0.06008192138480289, 0.02743410039693117, 0.05467017713401999, 0.03374551083626492, 0.06673170705991131, 0.029931336574788605, 0.02108936201381896, 0.01457602294561054, 0.06889795724834714, 0.10974228448633637, 0.025778013547616344, 0.0754637945709484, 0.015801620037694062, 0.01116350748842316, 0.032483866571315696, 0.020958515017160347, 0.015292944386601448, 0.04398556100204587, 0.013047563444290842, 0.027870725807068602, 0.016615962143987417, 0.05057753549356546, 0.07003323454409838, 0.025599664010639702, 0.017584771050938537, 0.08109484812510864, 0.05208849048774157, 0.05528012244030833, 0.0253275646828115, 0.027143780707514713, 0.016140475336994444, 0.043288301809557846, 0.03622890489974192, 0.03497710957058838, 0.030041527269142013, 0.014778160224003451, 0.055914050566830804, 0.01741357666573354, 0.04810097427772624, 0.03410118532234004, 0.06653994627829109, 0.006767578506177025, 0.04553778110338109, 0.03357500516410385, 0.02622354812254863, 0.016051234411341802, 0.012604560653146888, 0.057305003250283856, 0.054018522280135324, 0.05736765917390585, 0.033424105761306624, 0.02096129022538662, 0.029292597634983913, 0.03468087135947176, 0.044813828343259435, 0.02205457807784634, 0.011167756813977445, 0.017459074135071466, 0.07182646010603223, 0.006870702682395599, 0.016462701439325298, 0.008934548789901393, 0.0252579079741346, 0.03532282994793994, 0.012224430068662124, 0.030582862507019724, 0.03231218024822218, 0.028484934009611607, 0.007008656485205782, 0.058342802205256054, 0.04734984279743262, 0.02459042120192732, 0.02666333380953542, 0.050715155966047726, 0.017478140969095484, 0.036459148794944794, 0.019861201755702496, 0.05126796183841569, 0.023766491395820464, 0.005029867710878274, 0.0247933031725032, 0.03633316519803234, 0.008463469916023314, 0.0652280802439366, 0.021275840400319015, 0.02293500949495605, 0.03400646861908691, 0.07253939685012613, 0.00583178414464263, 0.027389859913715293, 0.026384043706847087, 0.05105316818558744, 0.011114097416533955, 0.020274634838902524, 0.028622052366180078, 0.016799953699644123, 0.02572481470581676, 0.009477268239217145, 0.051963212567248514, 0.039429340844175646, 0.012785869450973613, 0.017930917209014297, 0.028353647661528418, 0.017796945558594804, 0.013748076212193285, 0.020557884193424667, 0.015393488009327223, 0.04377628044624414, 0.024168014493105665, 0.012157952296547592, 0.004901659791357815, 0.06428805818515164, 0.0149337907122182, 0.03198413231543132, 0.05115532502532005, 0.03217195759394339, 0.14495463536253997, 0.016538936545007994, 0.04017054196447134, 0.0667231846600771, 0.08860528083252055, 0.010699515912814863, 0.024265243472265344, 0.04741531464138201, 0.044304587811763795, 0.02615810341999999, 0.03775422108758773, 0.01997764006124011, 0.049298527517489026, 0.02820396453275212, 0.05175400325762374, 0.027436178410425782, 0.06816678148295198, 0.06857193474258695, 0.03881723101117781, 0.06175745504775217, 0.033253661157297235, 0.023755504217531, 0.07063788388456617, 0.026305301414270486, 0.01902284799143672, 0.025273456604086926, 0.041635485499032905, 0.031262276228517294, 0.007761684046792132, 0.061183041227715354, 0.027338299733985747, 0.01155361084134451, 0.011455183399708142, 0.0076608774917466295, 0.03406743159783738, 0.007023888748205666, 0.020257028551506143, 0.04199490549841097, 0.08398348026509796, 0.0193628093028175, 0.02083998003841511, 0.008240961320033031, 0.028008897589253526, 0.027464135749531642, 0.04864187525319202, 0.022352378615843396, 0.029677503409662416, 0.016782657842018774, 0.01369201225627746, 0.02173482014664582, 0.012555891032596784, 0.034138847408550124, 0.04843931897942509, 0.0361981910121228, 0.014767595433763095, 0.03579335666394659, 0.03279080188700131, 0.05218178226745554, 0.01642540915470038, 0.03226741390036685, 0.02151506131381861, 0.045215429472071786, 0.05049830635211297, 0.07274676393717527, 0.08339631677206073, 0.04425932274066976, 0.008441984104657812, 0.043296047286795716, 0.02290098774912102, 0.0454854626607682, 0.03782405930438212, 0.05877610109746456, 0.02181751829838114, 0.02697136835195124, 0.03831750014796853, 0.006222523624143962, 0.06845458889646189, 0.008040649300840284, 0.0348318114743701, 0.01301624990134899, 0.04005721643833177, 0.050124277493783405, 0.04636224186314004, 0.02682795319040971, 0.032013424672186375, 0.10510557650455407, 0.03421640056850655, 0.04997552226164511, 0.030862700526735613, 0.062190129687743526, 0.025240216869860888, 0.01897315717568355, 0.03573588474786707, 0.05657716587718044, 0.031083658670208285, 0.02633799662414406, 0.10506928166640656, 0.09499678893813066, 0.10667148604989052, 0.1390686969139746, 0.14324659987219743, 0.06949105113744736, 0.07508475133883101, 0.12804091508899415, 0.12749492510088853, 0.09597152484846966, 0.07819244172424078, 0.1292134914547205, 0.1749865681465183, 0.12977762546922478, 0.06098389798509223, 0.09549677425197192, 0.10184937515961272, 0.21420021967164107, 0.07553696100200925, 0.18747573798256262, 0.08220945045884166, 0.10398541018366814, 0.161792427567499, 0.15818239056638309, 0.10800838324108294, 0.15186053408043726, 0.12414240571005003, 0.22004722378083638, 0.08573304209858179, 0.10654222512883799, 0.10456417341317449, 0.14272116949515684, 0.13052284690950597, 0.12427438077117715, 0.2177042830735445, 0.14325400947460107, 0.13007699511945248, 0.1148887351155281, 0.12231625084366117, 0.15358268309916767, 0.09173505074743714, 0.22352033241518907, 0.11885504371353559, 0.08890308985220534, 0.13957074497427258, 0.12967347034386226, 0.10921753942966461, 0.15470906480082444, 0.2000951322593859, 0.14166790672710963, 0.1106662591919303, 0.13410981371998787, 0.175464446789452, 0.10762681585869618, 0.10653952455946378, 0.08853313220398766, 0.09443465660193137, 0.14865482252623352, 0.0782785274620567, 0.12624644780797617, 0.1121304766940219, 0.17139391521258013, 0.12499906974179403, 0.12059354542621545, 0.10840647295117378, 0.11635187374694006, 0.13198196861360753, 0.05910140435610499, 0.10855915011571986, 0.11046372327421393, 0.13173590467444488, 0.1350941373301404, 0.08539142007274286, 0.14488855962242397, 0.09988019189664296, 0.1456064089600529, 0.10858722110944134, 0.07583726703056268, 0.18096644298306533, 0.1223902383020946, 0.23168808913656644, 0.16833653141345295, 0.17487011796661786, 0.15837860932307585, 0.10947642768067972, 0.10444106001939092, 0.09070466139486857, 0.1365085028644119, 0.2100594054375376, 0.10371244911636625, 0.11488887082253184, 0.09254395948456866, 0.1406482450131859, 0.07848604382680995, 0.1500101148017815, 0.1475641317665577, 0.12070796000105993, 0.11413130004491125, 0.19601796461003168, 0.07975601710911308, 0.13439806896661008, 0.11514900757798127, 0.1273997537791729, 0.08929435350000858, 0.09397428416247879, 0.11074373432035957, 0.15716329882187502, 0.20630313056920255, 0.14025055563875607, 0.07500022623155798, 0.11380928089576108, 0.14090645472918237, 0.1201061944344214, 0.09592480092708554, 0.10406566052032368, 0.06751755917710917, 0.07527710923126765, 0.15073854928570135, 0.19138689525425434, 0.07618705183267593, 0.1272001966301884, 0.13360262236424855, 0.11403718723782472, 0.17802390802119458, 0.11724819136517388, 0.12465940868215901, 0.13925492763519287, 0.1484205379549946, 0.07256167315478836, 0.14940454943903855, 0.1589234322309494, 0.0775260389117258, 0.12620086382542337, 0.08895258898181574, 0.1623893076820033, 0.1479877954615014, 0.12001297729355948, 0.13711664666022572, 0.11088439462972538, 0.13378791670714105, 0.16702020061867578, 0.13434982512678417, 0.08494227060249873, 0.11692421803517, 0.18581529493842805, 0.137904697230884, 0.06134510931691953, 0.10423834089721952, 0.09233099448361567, 0.19506607497377054, 0.12115691948149886, 0.13252415880560875, 0.08431632204779557, 0.13299983899508203, 0.07557872483240706, 0.06159353455794709, 0.14119570063693182, 0.08986486574368817, 0.09238995917673622, 0.08622790447303227, 0.14064310171774455, 0.14422610588371754, 0.12638580533010618, 0.0882392790434616, 0.10321477082158838, 0.218724555468985, 0.14944798925093242, 0.11280714574136905, 0.16708506856645855, 0.12418034938829285, 0.09439396485686302, 0.09869481836046491, 0.12270448143993105, 0.07940298212426049, 0.07662913096802575, 0.13717913973544324], [0.025824174284934998, 0.043648308741727045, 0.0702335855790547, 0.036084217485040426, 0.0547055661279176, 0.05527900964287775, 0.020450821545507227, 0.04734312190807291, 0.1106061070625271, 0.05558882194704243, 0.0019583595692113575, 0.022856173903814385, 0.011980500970301884, 0.08924125134944916, 0.056709086655506065, 0.04231833600039993, 0.06568440182932786, 0.023408509890681932, 0.04752615672935333, 0.02493034689021962, 0.018594953630651747, 0.023945349834061096, 0.014570654037275484, 0.03502984191956265, 0.027169191843963096, 0.03166706307924219, 0.12777400655405863, 0.03886570894558515, 0.03891094008992825, 0.04946306208148599, 0.06479942931660584, 0.022659488654296314, 0.055575515875326734, 0.016994582988055687, 0.04240879150373595, 0.046132340628121576, 0.03796517083953534, 0.021853477261694412, 0.05758745702249663, 0.05288399137290461, 0.015162677537383778, 0.03113734096820865, 0.1144452446273395, 0.06419885797160012, 0.04353362614555018, 0.0348971272552652, 0.04987216441492949, 0.00947396971085774, 0.050953247118741274, 0.04947032240618553, 0.021040870508711253, 0.07783049078924315, 0.015796632805306996, 0.02093049491356526, 0.03702369671581047, 0.012662532988802662, 0.04582732217386365, 0.026147022943145463, 0.03860324481502175, 0.026756849505805542, 0.04696513040523444, 0.024804139376751015, 0.05672259968040245, 0.021533122219677483, 0.02013295503067119, 0.008110911602021327, 0.019791619685877646, 0.07304081387285676, 0.03646472974547318, 0.04271589984585132, 0.059319112316838334, 0.02390735865836697, 0.045428258766021044, 0.01496661314740777, 0.03243725121553455, 0.044515330610530715, 0.031995019409805536, 0.03638277289324573, 0.03929317582930837, 0.01514671160839498, 0.027029138823438967, 0.017413318822426454, 0.04481328890791961, 0.0099924001510122, 0.0758262611925602, 0.048214065709284375, 0.02114746157479073, 0.04016811280910458, 0.04113132380215185, 0.01992629192370389, 0.04987166229901569, 0.04274416761472821, 0.028209306299686432, 0.15629784097628935, 0.12293439624564988, 0.06457592666681324, 0.055676183330693414, 0.013877562746139509, 0.0008064633605369766, 0.0675037917015808, 0.04646865651011467, 0.029732939720685993, 0.0640753171007548, 0.018554068503103087, 0.04626766425956573, 0.01809622360659497, 0.015538843781022089, 0.03248565451108983, 0.054084937287760634, 0.04381431233403938, 0.004065890397344316, 0.01758269134110638, 0.01326694229750761, 0.02897864965988057, 0.03032178937324456, 0.006373512932831156, 0.012787156971171498, 0.02416149207523891, 0.020278751850128174, 0.020470746726329838, 0.08854929490813188, 0.05801283062568732, 0.04250272110636745, 0.05883165275944131, 0.02610816663530256, 0.06047543098351785, 0.02060108651806201, 0.059844461269676685, 0.06686668803117105, 0.01287359554719712, 0.011869456169993749, 0.022868704749271274, 0.024461821852517978, 0.075675144658557, 0.06265017643038716, 0.05717734367187534, 0.0268457053628351, 0.027022629976272583, 0.03546813143683331, 0.0382813681582255, 0.04044666161228504, 0.04739716382963317, 0.05097156756424478, 0.02812355474036719, 0.0414207189876054, 0.053746612942112346, 0.03747490893251129, 0.043529290306781016, 0.01118768793198147, 0.04515504664076226, 0.02414687303826213, 0.06036156602203846, 0.017092795842992406, 0.013053945914310004, 0.045565163384058645, 0.05495654944596546, 0.004606617498211563, 0.017557763660858785, 0.004129538678431085, 0.03360996328826461, 0.08094079353447471, 0.056283736801041026, 0.04124266461336187, 0.024559569910966923, 0.0441824922205082, 0.043910705018788576, 0.028320574168381945, 0.020931733239974295, 0.020253286430878297, 0.09044364932924509, 0.027292454515450766, 0.025102489528113177, 0.12434270924755506, 0.019321785075590014, 0.03400083677843213, 0.0555135825914996, 0.0804476003561701, 0.04633124638348818, 0.01315722064048584, 0.02739154776957418, 0.07283624913543463, 0.06255982949265412, 0.030383325714085783, 0.03610150655731559, 0.06284233754766838, 0.021947205000157868, 0.016215273644775152, 0.044142882738794596, 0.023868005323622907, 0.07419813677136387, 0.02370203735439905, 0.013381207594648004, 0.05513627640902996, 0.05099594393478973, 0.040525656659156084, 0.024515570307682668, 0.02648109626690192, 0.024667465460619757, 0.025641271777983223, 0.029445977083274295, 0.019786303364006535, 0.022383737111730233, 0.03916603533018913, 0.012014571061756994, 0.025708779226988554, 0.030899602653724805, 0.05962038865046842, 0.026786725402676632, 0.032084046596927304, 0.012794355379550584, 0.013825247696201717, 0.0030594357314320014, 0.03211960183190448, 0.011873205924140555, 0.04977127304300666, 0.026122763619891236, 0.056392516142555645, 0.029680234513112476, 0.05519034207931586, 0.04017899990347879, 0.03926191232832415, 0.05940757292721953, 0.03394854547721999, 0.030247862982962812, 0.018170704699254463, 0.027023741077365618, 0.05567668205393212, 0.02793435542844236, 0.05687612501372184, 0.045954428746231964, 0.07651181226330143, 0.04835977092651384, 0.016914210515096784, 0.05038065177255443, 0.05389762091051255, 0.05677281127178243, 0.015110408288559743, 0.02247735798092825, 0.024311265109905174, 0.02672926366462239, 0.04301840093519006, 0.06465156975069217, 0.019023365374388437, 0.01130232133436948, 0.0058754894333625475, 0.01615733523587031, 0.026640865818730423, 0.06336343887129, 0.08198028882699353, 0.03835453798196145, 0.06049149190740926, 0.014381056086027195, 0.03117736435628363, 0.006980749188057546, 0.015235587821475096, 0.010739786118002874, 0.06162062846124172, 0.03942553765539612, 0.14536046715719358, 0.0366155307606927, 0.06595477767820869, 0.012238203481371914, 0.038605718075164726, 0.007179355115762779, 0.06756868000541415, 0.048327303025871515, 0.009884053375571966, 0.009237454455745007, 0.03593569974015866, 0.10618184160973344, 0.008598215096364064, 0.03607169172859617, 0.01735757208163185, 0.05243272487340229, 0.018141675274819136, 0.0813843925882663, 0.043253316543996334, 0.09161693137139082, 0.06340216965015445, 0.008643686272470015, 0.013997360648188208, 0.027969454348619496, 0.03414200598906193, 0.04423279880679079, 0.018140601493152123, 0.0178869125167174, 0.004348732206770884, 0.037796894154910526, 0.06020192030285086, 0.006759580698729093, 0.06347642852259533, 0.02594293826924903, 0.012641666340641677, 0.009345079439559152, 0.043736755781407864, 0.03060326266235539, 0.024718143544825058, 0.021401052163647752, 0.018084449327683876, 0.04774893334667597, 0.02107517554291657, 0.01324606207864625, 0.011474956758320332, 0.022260689875110984, 0.029627732866044556, 0.01615772539350603, 0.0338534046895802, 0.020940287870221903, 0.030340968165546656, 0.014712103143600481, 0.10342212433793715, 0.0305374413728714, 0.02881219144910574, 0.02076115462529872, 0.033193162975034544, 0.04523453023284674, 0.035449654928275516, 0.05529479236741151, 0.024558414705097675, 0.02137405495159328, 0.05190409181107368, 0.012461469492076762, 0.019589840334707072, 0.03401522511350257, 0.006049668100396437, 0.05037792406177946, 0.02966660274458783, 0.022365852624976208, 0.037960923210318596, 0.03863556683063507, 0.029694476963153908, 0.09876588811831814, 0.0443187963350543, 0.02550297785949494, 0.04432098800316453, 0.02556010372271495, 0.029613948427140713, 0.06391823624393769, 0.015386483831597226, 0.01940208121335932, 0.003755563678818622, 0.05996721503990037, 0.017254219323928868, 0.034260613910321674, 0.05628287845424243, 0.0240438205323049, 0.024154240232227103, 0.018556986203683273, 0.05158872230510626, 0.051605563544269116, 0.016109483250017678, 0.034584800978856425, 0.10780168790370226, 0.12259712362928049, 0.0821705704022731, 0.09047066859368767, 0.1690306184547288, 0.2135191469320229, 0.13918194440858705, 0.10082680931580917, 0.14838236357484544, 0.1354771839188678, 0.12821794487535954, 0.12102546010698591, 0.09413611476442643, 0.1662830537451165, 0.10718109977564641, 0.11929900917623724, 0.08826372666018349, 0.08296245469578675, 0.08708885006074395, 0.1933299752750567, 0.11250417985554252, 0.1121933293927993, 0.0758181798404881, 0.0863829632954938, 0.09862694450254951, 0.14371487045926706, 0.17863266249852522, 0.0940835690125823, 0.07364758702793292, 0.11190150505197899, 0.24910051907811845, 0.08837232618991818, 0.16478125218834194, 0.08048196815486465, 0.09492096264979669, 0.10026657009231192, 0.06359162341271128, 0.09469197065170322, 0.10261545476636716, 0.08267906454524823, 0.08079740551433393, 0.15082821090306553, 0.33524260244199205, 0.12314661485808236, 0.1992540881037712, 0.16181781834789685, 0.11872186086007527, 0.08311617680426155, 0.10140095172183854, 0.10315581291381802, 0.08345742563584022, 0.13162219577601977, 0.09845278491931302, 0.09893115210746016, 0.14639661727207048, 0.11738927236625127, 0.10546680140708174, 0.16060330851801805, 0.2128237978156124, 0.17857695477349417, 0.10069649666547775, 0.12144216203263827, 0.17689148735787186, 0.13690657221845218, 0.14068119467369147, 0.17779300255434854, 0.08905287645757198, 0.10619477448718888, 0.0747370021417737, 0.1342366183442729, 0.16432994497673853, 0.12487672987793173, 0.1576410010457039, 0.14759739355317184, 0.12120109211121287, 0.14684122055768967, 0.1351485422679356, 0.06515817078096525, 0.13288429805210658, 0.10845314937510661, 0.09601073060184717, 0.11978551878460816, 0.22406860228095735, 0.09987346761460815, 0.19430080960903848, 0.12200795167258807, 0.23374098326478684, 0.15043371064322336, 0.19195776033614362, 0.11405553482472897, 0.09785840181367737, 0.06121727331940617, 0.09698372946253844, 0.234531612268516, 0.19439832866191864, 0.13947105460933276, 0.15966148834143365, 0.16959830799273082, 0.12782450313014643, 0.17854689567216805, 0.13624501414597034, 0.1635156079594578, 0.20783020077007158, 0.06521284034741776, 0.13221397330718382, 0.14103866049221583, 0.11273619133446898, 0.12306795907872063, 0.11373667086341552, 0.09857468373541321, 0.10294388607144356, 0.11057411413639784, 0.08557386456855706, 0.07852884581578629, 0.1351408205394234, 0.12156822026840278, 0.08093908362622772, 0.11848427860864572, 0.09141017496585846, 0.08217620224292789, 0.1408235648913043, 0.13505384592073305, 0.09282768211726632, 0.12223022617399693, 0.07268119709832327, 0.19355306401848793, 0.136015845728772, 0.09513069782406092, 0.21328703367284366, 0.13729090802371502, 0.14446503163448401, 0.2211055348494223, 0.11165220450077738, 0.21239378303289413, 0.21468009320752962, 0.1054159112806831, 0.12711333057710103, 0.09956583340785333, 0.1720537498061146, 0.1565500253013202, 0.08686277576323066, 0.17750016041100025, 0.24406836767281803, 0.11747411638498306, 0.13963175884314946, 0.10906140173652343, 0.11421104148030281, 0.10639952242906604, 0.10952004391167845, 0.23721312837941305, 0.13158322072454862, 0.16033962980977126, 0.06363953477037804, 0.17915935495070048, 0.11659922690263816, 0.17402961663901806, 0.08658617774822883, 0.09835662293647017, 0.11801519377955369, 0.16280942942414964, 0.20239703516874993, 0.12222357653081417, 0.1684274279645511, 0.1379047515136855, 0.10827058274298906, 0.09358311550957815, 0.10129098155136619, 0.16652676995311463, 0.12879517461572373, 0.1151281086994069, 0.07685410603880882, 0.10001100666288819, 0.22649194938795908, 0.1528079453855753, 0.09454248938709497, 0.21709152523960384], [0.04710042689527784, 0.055215583582009585, 0.003907658575501825, 0.030212029548627988, 0.03816388660509672, 0.014522211725956627, 0.11001829896122217, 0.017991732606398206, 0.04437997644501073, 0.07098596556378262, 0.03383887725483094, 0.05688774831859129, 0.04583011773814048, 0.055761980691126416, 0.06629728858492204, 0.0357736214729292, 0.06350865215063095, 0.08432271384767123, 0.03478453454694577, 0.031057779344597032, 0.034579074143299034, 0.06352351206753935, 0.03942181249814374, 0.02275025119472827, 0.022572607334171022, 0.07591140376670019, 0.03970096519749079, 0.03397703037730285, 0.04568830731191805, 0.011112675037501114, 0.06073820724018982, 0.036106476826327186, 0.019201407874269143, 0.005211399153007993, 0.026663433893450668, 0.06211836782417127, 0.01696248658533607, 0.014068435495054083, 0.10719263487096344, 0.06104354799858161, 0.03645293341417398, 0.026142999230484878, 0.04352032346650958, 0.04495575072775994, 0.034171267811741145, 0.01727130144302334, 0.02148099715954491, 0.009357332085658396, 0.02134673882808004, 0.05609126355765121, 0.03024413443303534, 0.03560867639524596, 0.06417563850326197, 0.03242466439093862, 0.0332793335297278, 0.08869876938738994, 0.05247631057032517, 0.01172535992892725, 0.04797912635175245, 0.045123084248708825, 0.036177468552653275, 0.011809231946244836, 0.024940901502434696, 0.03498857681240354, 0.013593190416161503, 0.02928206677149449, 0.019582971863980805, 0.03375825033124004, 0.04007019002788833, 0.014791834400966763, 0.02770387743865805, 0.04063311964273453, 0.010279739375359245, 0.07003517515425171, 0.06803868085678134, 0.02088243597453194, 0.01984117309828954, 0.038283420726656914, 0.01653167452397091, 0.03875067351119859, 0.08612509284700666, 0.03696806362963148, 0.03695609766457762, 0.0258424726780504, 0.07789325527846813, 0.06767819555742399, 0.013776284609256046, 0.0725907212389367, 0.03326394096282976, 0.019300399348139763, 0.032393020910343955, 0.04437990180615868, 0.03375115624762007, 0.01885914972185024, 0.03192889956491334, 0.03868689461212073, 0.02136055889007236, 0.0531401315570942, 0.04639463512493031, 0.02135302545502782, 0.049397576666836224, 0.002463940040407968, 0.035864328034222126, 0.00842393422499299, 0.01585198599579079, 0.03023619218064206, 0.017187164797048484, 0.015008561878598161, 0.014198034835447158, 0.03219371481931635, 0.024739064475787536, 0.01637691256058003, 0.07294075031365667, 0.03580185531505516, 0.017516237317717502, 0.03819877687575562, 0.0346167939049857, 0.08279833064547606, 0.022092835578535284, 0.03362486052459904, 0.06126794631459883, 0.014046577337597097, 0.01736363479202347, 0.08022181104336466, 0.028478287759103944, 0.0061134393659553355, 0.022680275574592606, 0.03736807020115001, 0.05148356634059122, 0.01576630737898605, 0.06509254287396159, 0.03837463618921382, 0.017470861984682933, 0.018290028474958878, 0.027064110518300107, 0.027336387961570705, 0.03773148337911282, 0.07014532174382891, 0.018806731195322106, 0.02202550963764744, 0.019017426496637718, 0.013281844622854675, 0.012169884334850525, 0.032306327883686335, 0.01912465538563473, 0.03260431671515107, 0.01866778079420328, 0.04490522361759629, 0.04981499783960836, 0.10689031359340463, 0.04556283600894468, 0.06369226372667722, 0.047723193120743544, 0.015679680509492755, 0.030761948254491602, 0.045057117074195824, 0.01815797538230462, 0.05962338098990066, 0.04962749147255506, 0.04286643283973847, 0.06220429749893291, 0.03384938436959471, 0.03917938889935613, 0.02411899881969605, 0.03660446385453854, 0.05764984153211117, 0.08461799871708665, 0.028114425051691275, 0.0622518424476896, 0.020003524475864003, 0.03810095587479217, 0.13166198506951332, 0.03245085244998336, 0.013495972463195878, 0.03729253907554916, 0.043231583067349026, 0.02167225582525134, 0.050102465985608954, 0.05417013414470213, 0.04176534353090184, 0.02270185638086072, 0.03150647758905377, 0.01864210842177272, 0.039200243673154285, 0.010029363346153071, 0.05445586184837988, 0.015426648015688573, 0.03337967868096062, 0.03522161287920816, 0.029186328873038292, 0.06660835617887122, 0.016549905063584447, 0.08892607183328696, 0.03294570803908365, 0.03897615748324564, 0.017412143260506645, 0.01874853833578527, 0.0530459983939571, 0.01783150843610721, 0.023617999096001898, 0.031166572256812027, 0.02657495462335646, 0.045875338704458306, 0.055266022482620816, 0.03647399514115282, 0.061577738262712955, 0.019559316436893175, 0.009107533659386848, 0.05094003264925309, 0.023530557984486222, 0.06365510036370584, 0.031061755559806312, 0.05884963393743549, 0.02654238324612379, 0.023949631390028765, 0.09259912438158478, 0.04928821039253047, 0.025658930651843548, 0.021317728063357726, 0.009155111686725701, 0.031588315697652955, 0.04617471174736108, 0.07608313419456993, 0.041124809865972826, 0.017089287816945995, 0.022004517460508004, 0.02751677479994084, 0.024458822727735554, 0.06310796365141869, 0.012905730965680309, 0.061755962270711146, 0.04120038170367479, 0.02526690874115697, 0.061479540674814155, 0.015925895422697067, 0.016873827503461922, 0.022293707389118414, 0.01262868766207248, 0.0538748560606369, 0.023360623978078365, 0.018281316085319434, 0.0417494013506387, 0.06490553183747189, 0.03548141375982335, 0.04910838843456336, 0.04980393771880439, 0.027501114211710434, 0.037496415099927356, 0.036047753013138256, 0.051482144809727154, 0.0371655546394842, 0.023220608276980262, 0.027098169583561163, 0.016178834617936184, 0.012361519587492304, 0.014794495954577411, 0.028692928741553, 0.017891635120447193, 0.047621110919862986, 0.023156357796064446, 0.05305666157177516, 0.07135548216423818, 0.014561369981882828, 0.022765884641557932, 0.10111807047256402, 0.04109288818602051, 0.029871143733284304, 0.042238842230290174, 0.014954811727095927, 0.02136286930181086, 0.029663396666624715, 0.06781527320189135, 0.06138875947466918, 0.033375539617346864, 0.042086619684206586, 0.027169481917683567, 0.04724902267168675, 0.02540328579821757, 0.015207430314538735, 0.049527767180864296, 0.003854441922158003, 0.05282915895804763, 0.027517969021573663, 0.014548701733084661, 0.019739543819533925, 0.024393810591261302, 0.00746662648660796, 0.0023021624490086523, 0.030371848294245343, 0.022298657302079455, 0.024961581553465555, 0.03194402071780392, 0.05988888495734759, 0.04198881225394351, 0.03358705933871014, 0.03657997891839061, 0.04165264564965453, 0.00935580623003521, 0.019662614911794662, 0.06777837446757726, 0.04698063153773546, 0.029562474760626043, 0.06155894962804658, 0.025903279593746577, 0.017114756628870964, 0.043581072706729174, 0.026421115467590944, 0.02992242740999375, 0.10341069102287292, 0.04083351817514215, 0.03265674711604204, 0.09970294497907162, 0.027843815108229007, 0.03570583921724132, 0.01052216551865318, 0.03774096590599843, 0.0719534954322236, 0.017520627439288155, 0.03382516745477915, 0.013298548458676254, 0.03645367980269449, 0.031154935381242206, 0.046569235755928924, 0.070134227696274, 0.0138823871301221, 0.032760454408292256, 0.07674339626516614, 0.023433398555165956, 0.049633014747606854, 0.046238263337207694, 0.015002100528883082, 0.03256650535123689, 0.01636173712488796, 0.018692426882418137, 0.039522055869123766, 0.03189164799238954, 0.08735999265419585, 0.06051144762230771, 0.053276791902525086, 0.014801734226888843, 0.036132613995245526, 0.01607453021486955, 0.032389265219015737, 0.01824379649146327, 0.02903409275625433, 0.06703746851001467, 0.022097268108544604, 0.01289087359327823, 0.041624109859445264, 0.016187022839273726, 0.04340060614049435, 0.02778764597938529, 0.1319440927888666, 0.08584943121033055, 0.12322810691382204, 0.08662595347102199, 0.12829502645347798, 0.12721527367830276, 0.11739027659807887, 0.1332277860492468, 0.13954820404095308, 0.1946345538433109, 0.05271358408832124, 0.2159630943621908, 0.16903106628784112, 0.0835724441068513, 0.15970437175461225, 0.16869065883968556, 0.2406348447714533, 0.18921911157667637, 0.1015420937910676, 0.1557109896093607, 0.13429997994431428, 0.17535991168447904, 0.10956828775150435, 0.10661269099052463, 0.04416496566097651, 0.14004873218280928, 0.11382325871714524, 0.14620748242097242, 0.2154713464634759, 0.1296853039945875, 0.21949951031378337, 0.16147150764507906, 0.10139857684927327, 0.0790210822597146, 0.20147312831665787, 0.1591580424989973, 0.13216730366860116, 0.09866976006222622, 0.13086534424551896, 0.15963940881192684, 0.10775139488812004, 0.11366873593734843, 0.14935494852917536, 0.13514360253299984, 0.10576139417077814, 0.18039922841957637, 0.1754688165549721, 0.1181233251201255, 0.1234557961246797, 0.1530227152896779, 0.10168314765074424, 0.12891406752169132, 0.16525782804403985, 0.1110173739226801, 0.11251285153308085, 0.18676886734153542, 0.13225811879549706, 0.20401737679328236, 0.17826457082160882, 0.1068873687514237, 0.1601751393505505, 0.08264711233122007, 0.11355779546179942, 0.13014948980084487, 0.0834641567032252, 0.09253711985158068, 0.15710042576704705, 0.27033462109310286, 0.08475261327943631, 0.06853025233639137, 0.08073673091296639, 0.15524297686559813, 0.060550897648291926, 0.13655811734497547, 0.14639477165681974, 0.13726508298090526, 0.11869025469890662, 0.09646769001015595, 0.09511838919882264, 0.19770715039755615, 0.1796932127326727, 0.14503295187439236, 0.11441142644201006, 0.1148713646190507, 0.18166594473379, 0.15326195316655294, 0.076303488441876, 0.19477847112076624, 0.14198725244828633, 0.09687886866075651, 0.13192076475492545, 0.13983784349901335, 0.12250937548066888, 0.14813710030700478, 0.05591137035350714, 0.12677715718746185, 0.1371548074696745, 0.21163204605025904, 0.09441221744886466, 0.07271255898688521, 0.12765244022011757, 0.07336887876902308, 0.11025747576994555, 0.17426658820893082, 0.04101716707061444, 0.12936407194605895, 0.16229877753981523, 0.1729411921863045, 0.04672230647078582, 0.17503657617739268, 0.06695555576256343, 0.05256476439535618, 0.17121468697275433, 0.13573696783610753, 0.0904431879254324, 0.14119574134903295, 0.21910222806036472, 0.20514649977641447, 0.1157135758548975, 0.1532320569136313, 0.09868772766952004, 0.07544892786868981, 0.16414414851793221, 0.12820463201829366, 0.13546494314713137, 0.06826117248939616, 0.10827502036201102, 0.08108982018062047, 0.1456496316407408, 0.10048532299697399, 0.12276743591896125, 0.20009184814989567, 0.20949575996824674, 0.10973459668457508, 0.11413215499903474, 0.1594137687768255, 0.18239793474120752, 0.10964284517935344, 0.08151509878890854, 0.1950480259422745, 0.14220662281981536, 0.07510923966765404, 0.12446724756487779, 0.07766078239572899, 0.0747929269980107, 0.10311720427125692, 0.13723164477518626, 0.14949726446398667, 0.14665357848363264, 0.1646192315965891, 0.11444753807570253, 0.11418365580695015, 0.10866578189390046, 0.14399091207555362, 0.14614770348582948, 0.1914932352623769, 0.11243722201990229, 0.10110046248883009, 0.1387775239667722, 0.09311520454606839, 0.17064122988709382, 0.19405151584318706, 0.15042054706386157, 0.07729733189834015, 0.1733090803027153, 0.1232251620718411, 0.1672800795308181, 0.10701384089354958, 0.2358514985867909, 0.1778951763574566, 0.170037890119212, 0.2388153938310487, 0.08512512221932411, 0.056815345239426406, 0.11574697334851537, 0.0797726751438209], [0.04283722869253584, 0.06408594295914684, 0.007982684598703469, 0.028009299621252075, 0.06542536430060863, 0.012646269352574433, 0.040704613484974415, 0.052592275597687276, 0.06249107353921447, 0.018645015944327627, 0.022830654201763015, 0.04859834723174572, 0.0620173950280462, 0.04226756461762956, 0.022087207130555595, 0.029596907020147358, 0.0732008395716548, 0.007880081622196096, 0.08566248802734272, 0.025696073658764362, 0.0260588473174721, 0.033785408695361445, 0.004752896501616175, 0.007682653376832604, 0.04736175108700991, 0.01978515663982502, 0.041849166354430575, 0.029304000415972302, 0.08292362892201968, 0.02336970447296543, 0.07067715070609536, 0.02211990742944181, 0.031325040717742274, 0.01663121730754418, 0.05551416952429073, 0.02421201579272747, 0.04530089435034564, 0.050927829196942706, 0.0392097228073648, 0.03336483912010278, 0.012199598231485911, 0.037863085245979686, 0.03894241054409316, 0.014511353469320705, 0.05831127068293946, 0.03361119482932346, 0.06053352036646434, 0.04671909360747252, 0.02248565646420632, 0.033435277840388675, 0.0115199919756768, 0.018935233853491287, 0.025638929135831337, 0.06183851284107991, 0.044284065520124774, 0.021779555960425308, 0.03641261486336589, 0.07316134204821927, 0.04350375024867909, 0.01689633451003049, 0.045832197447972636, 0.020507472434214184, 0.008494362767253603, 0.03845065925270319, 0.02647191229542451, 0.034106277727655, 0.030503687648368732, 0.061463601887226105, 0.04475795776982393, 0.023162089720634476, 0.04498356727084943, 0.028043097450530956, 0.004741925862617791, 0.01879296202345618, 0.03440670928518687, 0.020720142272434065, 0.04408263222181371, 0.023893901612609625, 0.014757917828059621, 0.015359220294547933, 0.03485525146658931, 0.02431131260735648, 0.061136649788490365, 0.041856905046318255, 0.060986164292054515, 0.040686130191066434, 0.025754644801574092, 0.0417801763064095, 0.05014122390587415, 0.03247898790453162, 0.01663819434387343, 0.04441390658861824, 0.06165888426559312, 0.06896194310060569, 0.026901542009519677, 0.03157806981887136, 0.03207243686275823, 0.014762581059975284, 0.016419999534264207, 0.01973812228866986, 0.03378729841538838, 0.051609268345470936, 0.034783625310020785, 0.06594634348792688, 0.033419576540057144, 0.042002935960356674, 0.0390063522915755, 0.011633713596633502, 0.05201986345595547, 0.050952107179909945, 0.03511728472741587, 0.04606512834184936, 0.05040024107854281, 0.027322055605639304, 0.014507080395040768, 0.020710649567523172, 0.09854423786912646, 0.0409355562712465, 0.01831951760686934, 0.025417268708614365, 0.029101338969277482, 0.03350899388481464, 0.0639154203236103, 0.042508122245115895, 0.051834938914648125, 0.027651803268651878, 0.005635947487982256, 0.004614554661592203, 0.0433605657890439, 0.0395492481599961, 0.05011588740827782, 0.06006940919905901, 0.05820901545562914, 0.02848671855671065, 0.03808879652725799, 0.0313882835741554, 0.04478494989286576, 0.042564915626176765, 0.017624277056061795, 0.02696417079174093, 0.03174822265282273, 0.01574254168995789, 0.0612724789285234, 0.04990105643602354, 0.04875307357204812, 0.09849970561585256, 0.07358699385076761, 0.04305214448166745, 0.042705972878528495, 0.017005970502006154, 0.017409524115334665, 0.05295801954343915, 0.02162615954875946, 0.013746740346375321, 0.02450536683733974, 0.0055439398357910764, 0.01485115023595946, 0.04992053039105875, 0.021117244714072773, 0.030762579292058945, 0.03139894335929837, 0.06548565892236573, 0.0035796882501537247, 0.012051303554991526, 0.031972376696233235, 0.02023722550698689, 0.0041907972439990514, 0.027743856721956815, 0.060759689658880234, 0.050243614840188196, 0.048040890001824925, 0.02383632961261485, 0.021274293340476494, 0.06237928489489215, 0.02575494166064475, 0.027865394218159572, 0.028369306553421274, 0.033968267097537, 0.022327213448339274, 0.05129136451120887, 0.015216666872480085, 0.050321887247264385, 0.03954423717888338, 0.028736348197396313, 0.05500789079815149, 0.0556065588524299, 0.024841292561697106, 0.05001723859459162, 0.024077594612858126, 0.03239310572722128, 0.047241290765149255, 0.03749122769970979, 0.024912788100274544, 0.043435357311474423, 0.019369631972430006, 0.029181361996701786, 0.0359336709204529, 0.046210724993475845, 0.006952130701392889, 0.011488144934576536, 0.017552711967644945, 0.00850388006905892, 0.023301861149125865, 0.009896204241418412, 0.04098458042634385, 0.014698515479852046, 0.01567595704857792, 0.0038950106827542186, 0.07210404199681111, 0.039870911078261476, 0.015629304373370748, 0.04595322434657386, 0.028323612308927944, 0.02679527155123651, 0.022821120784751008, 0.04715089972264, 0.05207549314945936, 0.04303467899028744, 0.02530405344441533, 0.043141297197767665, 0.01088717664658491, 0.0225703104931329, 0.04247712337278894, 0.07588368561118841, 0.038904799348009486, 0.035173341897981505, 0.016035599268174598, 0.026253396878018975, 0.011855337552593222, 0.03138628868120057, 0.10218441539577075, 0.010880513432701784, 0.07129731135708944, 0.016592327072950344, 0.027418134467942373, 0.026853221834504178, 0.05368114109816296, 0.04003062804362603, 0.061518040751772265, 0.03030868007668427, 0.034213377694998465, 0.019328276959380934, 0.04312151790197406, 0.03447815562997546, 0.04097349316413913, 0.060794023530823846, 0.02670304337516427, 0.029472599404730966, 0.0243336686398834, 0.04178179121975388, 0.016613110600571548, 0.028540970824126686, 0.041738677104668956, 0.06551193179828779, 0.019768999024693455, 0.012212201171288533, 0.06895287787275654, 0.02871632802167109, 0.03864447260275483, 0.03351851373112627, 0.03885380744135805, 0.04107767203822732, 0.030407440848648548, 0.040450973702328544, 0.04266855167225003, 0.007166516385041177, 0.018520835554227233, 0.04143034400684493, 0.055542535680745325, 0.017076928301581314, 0.03257571646411504, 0.0239324695430696, 0.024260023841634393, 0.05500098670433674, 0.01619133323297969, 0.0770033701722111, 0.0496684376682554, 0.06675502152315207, 0.03827688643442733, 0.03107002011633345, 0.022990476340055466, 0.004190328630751797, 0.043199250873710425, 0.041746626142412424, 0.03141281600775463, 0.024352324960221137, 0.016880478842982223, 0.049933456483164, 0.023077854687081914, 0.054032964898007255, 0.029932941310107708, 0.02089961987387921, 0.03164999792352319, 0.018532423236008202, 0.018678415134283047, 0.014292868585991008, 0.024892812029325535, 0.02723290628221418, 0.07696763173277889, 0.013936449407732912, 0.020195655059069395, 0.02944186855373638, 0.037208088607128174, 0.0927154863519328, 0.07410743021007095, 0.034813596201794486, 0.022176805983430574, 0.07704191774662052, 0.10418627690523863, 0.018506425166768686, 0.01769718394747802, 0.007181419558557016, 0.03728941102911319, 0.02465878869406879, 0.051816397945263555, 0.04707585035690239, 0.020570214871051054, 0.04946111807865756, 0.009808184678799339, 0.01668822781981102, 0.011220647770512317, 0.014258756934266006, 0.0019058765818564488, 0.010750201630539127, 0.060212437595639906, 0.008076828788034618, 0.020093253946730068, 0.016306989526908313, 0.03417483690593924, 0.03982894029468298, 0.05043074462030615, 0.021462318786819066, 0.0298985565480377, 0.06156344831522022, 0.030912118232143775, 0.03932128753513098, 0.006513399712275714, 0.04877014551311731, 0.04526164109951683, 0.07177530535097633, 0.026428053488156626, 0.042226927155362706, 0.030250461772084236, 0.011312629977640296, 0.05950195036296334, 0.07297680766454764, 0.00560566786277507, 0.04716830075319324, 0.025601781039897884, 0.038971112575381994, 0.06979566586336919, 0.03825672376634819, 0.07252408910010542, 0.2175994087010622, 0.08681447764060327, 0.12917106944535459, 0.23609164570059094, 0.13417953997850418, 0.10841999615409545, 0.14500475195901735, 0.10404945710407836, 0.07760948514831917, 0.10446680363799844, 0.18149974436632224, 0.1263788707022156, 0.13228558589305195, 0.15162759300853523, 0.1263028204973255, 0.3023574841873986, 0.12719593543027127, 0.16960811960910047, 0.10405544178294283, 0.08437030629387923, 0.13432398651327404, 0.07534253357776574, 0.10735431619520698, 0.10978496433900935, 0.1203216700149434, 0.11965294661266462, 0.15041568875312805, 0.15636835433542728, 0.0648464382226978, 0.09311234791363988, 0.08053188797618661, 0.1455648419048105, 0.15680519518043312, 0.10414458771369287, 0.088213569351605, 0.10762568270521504, 0.15370568792734826, 0.08245263062417507, 0.14517133230609552, 0.06730163576347487, 0.10214435468826975, 0.12973908468016557, 0.12393275195998804, 0.11575149239173957, 0.10806545482150146, 0.14962344483605453, 0.1324364242276975, 0.13038188804473194, 0.09847229958644935, 0.0908109810469406, 0.10484830316688333, 0.1551112596477781, 0.16609336249530315, 0.17822176883263247, 0.16476377312626156, 0.13666950565363678, 0.17077064008585044, 0.10935302251683814, 0.07534921036234923, 0.26389043831399506, 0.16426514488245758, 0.10494946595281363, 0.18232035104717526, 0.09870855869459254, 0.10421972189630781, 0.1374824991715806, 0.1329782208693879, 0.10057058770741735, 0.20978480231549057, 0.1425638986485345, 0.05838756516043629, 0.11828990546720368, 0.0972323107666203, 0.10242021988545146, 0.10722949289317642, 0.1463653775198119, 0.20286857629460947, 0.11098396285836186, 0.07445236348680087, 0.19275415688753128, 0.06762589407818657, 0.1310376649988549, 0.2215267015354974, 0.18820779584348202, 0.16596088531826222, 0.0859434897346156, 0.13024685957602092, 0.10024821572005749, 0.12557654375476496, 0.05950709365840469, 0.17092595675161906, 0.20989552565983363, 0.1621119768491813, 0.0709733719538365, 0.11010582319327764, 0.15934245474636555, 0.15738538333347865, 0.06392023113689252, 0.14938738250306674, 0.11903393268585205, 0.15191405692270823, 0.1022146644869021, 0.12360356748104095, 0.053992561530321836, 0.09997127843754632, 0.10627249388822488, 0.10793149843811989, 0.12138770281204156, 0.16694640315004758, 0.12501112052372523, 0.09939107671380043, 0.17495900605406078, 0.1217749427471842, 0.07408864836075477, 0.07401566513414894, 0.18286738597920962, 0.1303360326481717, 0.14364219935876982, 0.08737702388316393, 0.1175024655780622, 0.12698534530188355, 0.13924940436014108, 0.18013978376984596, 0.23122304837618554, 0.1448877453804016, 0.14254698955586978, 0.21606362611055374, 0.2181444623108421, 0.10209664010575839, 0.13960449530610017, 0.13992438385529177, 0.17428439296782017, 0.1378614745501961, 0.09986659405486924, 0.1818263911242996, 0.12717424945107528, 0.15406204094844206, 0.10288306219237191, 0.11480014558349337, 0.09277721268257924, 0.09755504237754004, 0.08939189969428948, 0.10883296613714524, 0.08450352985944067, 0.15041684226265975, 0.12439746702355997, 0.12377491114395005, 0.15214450098574162, 0.10063143194253955, 0.08459517279905931, 0.11885070108941623, 0.05544433809284653, 0.15824048673467977, 0.1357852252466338, 0.06220605490463121, 0.08375302941671439, 0.13077930600515433, 0.11877228958266121, 0.11621546106679098, 0.13700695468911103, 0.18882727117410728, 0.12699268705078534, 0.12812246142753533, 0.14369762209909304, 0.06606440858117171, 0.0846228977399213, 0.061007063170628886, 0.1670874027269227, 0.17413136975041457, 0.10837747914982693, 0.09410768414714507, 0.10415925085544586, 0.13806888913469656, 0.1754328134868826, 0.09748579109353678], [0.03874220878684095, 0.041183713490941694, 0.018275007405983548, 0.03022882329033954, 0.025818944476278763, 0.024510730656662157, 0.012462208247078317, 0.047286131751856635, 0.012280730663665702, 0.0217015193442681, 0.01593038223550788, 0.05672981250765068, 0.007823056691060109, 0.11894283257424831, 0.010695331048087349, 0.025263466872274876, 0.03962891156386052, 0.024403294814484458, 0.04792591902826514, 0.07941033065851245, 0.03589885189597096, 0.08530811632850341, 0.039500916110617776, 0.019685705458479266, 0.025523427208619456, 0.04281987515943391, 0.0816494622933013, 0.05343240373102682, 0.03884065743269665, 0.01164094593176352, 0.025798196571746042, 0.020829133656142012, 0.08594458217599563, 0.01446461767357375, 0.029589171720934764, 0.04150117627744164, 0.02514872151160879, 0.036901787721685, 0.026927745335602334, 0.02077502727375499, 0.038465705766741715, 0.014079916307569613, 0.022813780732186775, 0.04934365688157933, 0.045064024560685666, 0.06469291288937841, 0.01435268484055996, 0.07962923962622881, 0.011351685605144926, 0.03947787645405956, 0.01914073496923915, 0.04787548691300409, 0.01251528664891209, 0.03664578663717423, 0.06528188807091542, 0.01719396371793534, 0.04269343015870877, 0.03731572800981147, 0.02168795034023268, 0.02140755931447659, 0.046504398342221975, 0.04864864024732794, 0.01366176740598998, 0.035033539935414276, 0.034113965529416285, 0.04416294701929603, 0.026649907297853912, 0.018551898887380958, 0.05570268012317164, 0.08540030888148717, 0.0476893274379628, 0.022618932616231695, 0.01665055894825075, 0.02303397043475083, 0.0553299370887024, 0.0694578436336347, 0.015958914633042047, 0.014875747130385466, 0.0515841862985066, 0.028387235144951513, 0.03697831629376326, 0.058484453175749095, 0.03323702347863998, 0.036973739575062475, 0.049387330788054636, 0.03694611302177821, 0.059905950113066604, 0.03781841728570206, 0.0097630468330213, 0.035650572539972405, 0.09415759039776665, 0.06138622175369944, 0.028851295422230448, 0.013065214684632207, 0.04356619243377021, 0.030319624846535068, 0.029663834321711744, 0.030597858130931854, 0.036506351083517075, 0.03065666336832302, 0.03828208740534527, 0.018689646585179225, 0.08185794896313123, 0.03941523070846285, 0.01235500056230064, 0.04411353609923806, 0.035270338478897295, 0.021959223551675677, 0.004927348703079457, 0.032630002658282004, 0.05525040939184172, 0.04683274822309613, 0.01969348995148071, 0.03773484552013023, 0.03913103649392724, 0.013496942768272544, 0.10126903094351292, 0.10799492110631295, 0.032248062081635, 0.031407842346067937, 0.06081526167690754, 0.060583114490977356, 0.015824988783736314, 0.046106841282120774, 0.010845496784895658, 0.01995771996943014, 0.03513114719784685, 0.02968292829713651, 0.02075960417278111, 0.04187845531851053, 0.02024755111363317, 0.03780347594459142, 0.015843402527804886, 0.04916380099686129, 0.04886351193168333, 0.017210039908864667, 0.04329074792830007, 0.010241795697116425, 0.08081602451524564, 0.024594229479719485, 0.019016082997300794, 0.03589876368641853, 0.009903942085137325, 0.09747186755495411, 0.042866178389106474, 0.07184170000255108, 0.041912263325814686, 0.011256456607952714, 0.014583661553582974, 0.01857269598570253, 0.021456379909068346, 0.025271678842338066, 0.09830478964639561, 0.01905310895693089, 0.06395341828465462, 0.06346314959228039, 0.0600094199180603, 0.01839056870500956, 0.04225456727934735, 0.00850883761553892, 0.03605762569765959, 0.10208440611937217, 0.012431440924826478, 0.03144730255007744, 0.02886513075126069, 0.03448272217065096, 0.030437001226735965, 0.015578434603022677, 0.05954908140535865, 0.025141790276393294, 0.027873165140460645, 0.006830164455875222, 0.04850426156605993, 0.024773601908236742, 0.02936157750497971, 0.01860250742174685, 0.026891523439969336, 0.025440905475988984, 0.022443066517423307, 0.04644624110577362, 0.04019074873732669, 0.05704093099172626, 0.005023406785247582, 0.0807962655755026, 0.04031132101746542, 0.05476523310478244, 0.05167386827192136, 0.01883540438887264, 0.012080628142159964, 0.06273533936057772, 0.03526957512700132, 0.021567439128245627, 0.026561794436669776, 0.0073556741366961175, 0.044750789047351906, 0.02271172228003187, 0.053939432238361666, 0.033350226868476184, 0.07755453738250903, 0.07437902742198535, 0.031125310542328016, 0.08751748741737433, 0.021966439771599004, 0.021890606697914854, 0.13686078467539378, 0.03563791786187461, 0.034686910321137736, 0.023121472614418184, 0.04110218411577599, 0.010904072168549257, 0.04764277654300843, 0.03267910145223141, 0.02069382868441088, 0.024153356440365314, 0.027478727645107677, 0.027141300662021552, 0.01951390378443258, 0.04960042131798608, 0.027509945344978144, 0.04686774705935802, 0.00930279483353453, 0.036694491880812814, 0.07278601718800408, 0.06261954735964537, 0.02127154018463833, 0.04100103150787098, 0.027185385082183138, 0.012140274762974253, 0.02947447894673262, 0.09334275804992233, 0.05654524080455303, 0.03360344935208559, 0.0560660661597337, 0.03603218063446028, 0.026441167873729552, 0.03791133247848068, 0.01828049505794687, 0.012857814519000905, 0.07697639840521983, 0.021563527373863117, 0.004282868084763842, 0.05027566544179406, 0.015014239520366703, 0.01966407206574721, 0.034186422891382656, 0.0832579227696572, 0.04419289755501917, 0.026416867838374207, 0.019077531128589596, 0.021082027050267373, 0.07634144569081919, 0.012216656601854732, 0.03621143940836191, 0.025604215284277285, 0.021809559082612395, 0.04824988218024373, 0.050941745950175185, 0.043680875029947074, 0.03940810948344214, 0.05223985807970166, 0.023407242726534605, 0.06207676684217794, 0.05464658447142158, 0.019743023007842045, 0.02627610065974295, 0.025171091114836078, 0.04815970826894045, 0.04176632740667888, 0.043534508241074424, 0.04304575946714197, 0.009723703676302518, 0.026440745485680442, 0.10015887301415205, 0.041423151535647254, 0.026302860384540896, 0.03858622037140386, 0.007204192890120404, 0.0333887744428856, 0.0375606520101428, 0.0622676048161728, 0.017554184388635413, 0.030362820385822227, 0.030334427087966884, 0.06056134030222893, 0.027886284615046213, 0.025364724653107778, 0.02701971397202994, 0.013199582429868835, 0.050990139067705186, 0.009668625292501279, 0.010869712851542448, 0.01916413933836988, 0.009806287325253444, 0.05170119287712233, 0.0252461591402867, 0.029088256814117943, 0.023844731572483267, 0.029022354100431715, 0.019404766515695622, 0.03421981020697525, 0.02223091066948005, 0.045161750566746504, 0.016960350896364877, 0.023716893878632357, 0.013957509438374212, 0.04176006792113185, 0.034928757165159495, 0.02446628491660314, 0.027456726147128, 0.016129052199955498, 0.06088392263544457, 0.010090512922033668, 0.018820422335660884, 0.05596615866358791, 0.0757938747161201, 0.04782016595293369, 0.05217896295445306, 0.06532148737460375, 0.006982030346989632, 0.04839353482904179, 0.010230287743200148, 0.057050464408738275, 0.014838850092408913, 0.022889803795676147, 0.0802953370979854, 0.005930058067731027, 0.02208598067850939, 0.0703965425491333, 0.023807381612381766, 0.048784286182905943, 0.04223113746515342, 0.0325219663126128, 0.026912590255960822, 0.019540358168472136, 0.09429626259952784, 0.05181064736098051, 0.03511073686448591, 0.07866210330809865, 0.030555907703403915, 0.04691431152501276, 0.013513564331723111, 0.07433337558593069, 0.030217037137065614, 0.028646326956472228, 0.04713716617386256, 0.028733165868158852, 0.04131073185375758, 0.016818435297214558, 0.053222570169184885, 0.06476605217903852, 0.08780992243971143, 0.006856284661418093, 0.0681269650480577, 0.10795637353190354, 0.10135211077119623, 0.10268110302942139, 0.10954515649271862, 0.14001880878848688, 0.07141790738595383, 0.16203456957425388, 0.09994828288576432, 0.08954332835440125, 0.11985084813620363, 0.1560159639588424, 0.056467423015939336, 0.2371106967329979, 0.12910042037921293, 0.08255386126360723, 0.16480481092418942, 0.056320679640131335, 0.14485001883336476, 0.11865973419376782, 0.1679659698690687, 0.27088214457035065, 0.14809173345565796, 0.10152789205312729, 0.08335462079516479, 0.16302706274603093, 0.10417371043669325, 0.12414313852787018, 0.20863093994557858, 0.13564923325819628, 0.11702127568423748, 0.07659931613930634, 0.19635378516146115, 0.14649419060775212, 0.1321395651570388, 0.08151275105774403, 0.08887195866554976, 0.08597673795052937, 0.07981568747865302, 0.06775474787822791, 0.09776561214987721, 0.18498189108712332, 0.07869994520608868, 0.13883711291210993, 0.08383006349738155, 0.19039674981364182, 0.13630994994725498, 0.17098165090594972, 0.146207794547081, 0.1001525219263775, 0.12206322513520718, 0.207153443513172, 0.07348606176674366, 0.16623675051544393, 0.12375080958008766, 0.10106650181114674, 0.14294110983610153, 0.10900728178343602, 0.10762306356004306, 0.1317303678286927, 0.12662098556756973, 0.07014448714575597, 0.10785689351281949, 0.16729204888854707, 0.10234255476721696, 0.11838205052273613, 0.09655896654086453, 0.05806649596031223, 0.19372370200497763, 0.1563334097819669, 0.1836354469082185, 0.09625908120402268, 0.116470888789211, 0.1498637276568583, 0.10883247759193182, 0.1252576322960002, 0.10883914759116513, 0.13651523393179688, 0.16623167507350445, 0.10181069187819958, 0.12438758755368845, 0.2853124402463436, 0.11442388434495245, 0.12413453470383372, 0.09479948452540807, 0.1336987300642899, 0.09553027352584259, 0.11697461961635522, 0.08149432204663754, 0.09292509938989367, 0.21134115808776446, 0.11910687520035676, 0.10235992526369435, 0.04939366151977863, 0.07844275329262018, 0.09247676416167191, 0.22834931686520576, 0.1432566557611738, 0.0936271252908877, 0.1775692217051983, 0.11471573582717351, 0.2083635021533285, 0.1980694066733122, 0.11906412749418191, 0.13268077825861319, 0.07813627259539706, 0.09763231394546372, 0.09550940857401916, 0.10292093801711287, 0.12741810136607715, 0.1039844738053424, 0.13415313139557838, 0.13805044655288967, 0.11906210545982633, 0.19757778091090067, 0.18184776497738703, 0.22911114884274347, 0.18055782919483526, 0.12838216392057283, 0.09222700220665761, 0.11755383067897388, 0.17020106422049658, 0.07641668843903712, 0.12472947420818464, 0.09388887017433133, 0.12130967128489699, 0.10953560271965605, 0.11108750730220761, 0.07778810270662818, 0.07775499019771814, 0.10219288351280348, 0.06636733375489712, 0.12392513879707881, 0.10538869524108511, 0.23244739696383476, 0.1286239938012191, 0.09193109308502503, 0.1703328357211181, 0.23085088548915728, 0.12615248427859374, 0.11793237179517746, 0.08259665646723338, 0.09609956440648862, 0.1839785956378494, 0.11047530586698226, 0.17919081183416502, 0.145826145740492, 0.09008682811898844, 0.09005665366670915, 0.11197506503335067, 0.10619725792535714, 0.23287965091211454, 0.23473004304936954, 0.09495110317532506, 0.14880206462528023, 0.12418564196143832, 0.12115796442542758, 0.09167191984930209, 0.13495604188314506, 0.12606650032103062, 0.09741085368607726, 0.19506631924637727, 0.13700980453618936, 0.0890705930069089, 0.14703073538839817, 0.19521120004355907, 0.12159917503595352, 0.05679149812619601, 0.11160683086408035, 0.1024958019011787, 0.14780104905366898, 0.09175710992089339, 0.1308646114276988, 0.1309030165097543, 0.1254956488098417, 0.17271697707474232], [0.0717314380620207, 0.03296680369281343, 0.051553353667259216, 0.035324404149183204, 0.019437273432101523, 0.008205736022708672, 0.013249357214330562, 0.024214619670861533, 0.01416437525767833, 0.04576538549736142, 0.07958964032254048, 0.005161807148916913, 0.07091050568435874, 0.03727573176313724, 0.012931035232863255, 0.03788289846852422, 0.06278785118567091, 0.028312077213610922, 0.04693192629409688, 0.08107384068093129, 0.020867825419242893, 0.03306047545213785, 0.02050121803767979, 0.03889029226931078, 0.022644727124965618, 0.06044064927846193, 0.009654940089343913, 0.03959185676649213, 0.024937574984505773, 0.03284378529393247, 0.028940566881958927, 0.02062219743882971, 0.08932398512427296, 0.023073269486693398, 0.033551073233996115, 0.07646030467003584, 0.024048093606584837, 0.0709584102566753, 0.016280625048758726, 0.0334834063292614, 0.014651604961337788, 0.022229428070464304, 0.01449158604788993, 0.022967292494805794, 0.022533031779208353, 0.019601738446259072, 0.027588195699666227, 0.06521083188376256, 0.022167939227074385, 0.020929583980302726, 0.05509625980630517, 0.01897533018408077, 0.07315255501972777, 0.03464685639898692, 0.04661753727123141, 0.03315854072570801, 0.060482182406953404, 0.0367080049057092, 0.004033789329696447, 0.038091690479112525, 0.0204731504366334, 0.0281603991918798, 0.03408580971881747, 0.010849982749537697, 0.21310032797711237, 0.01799692339929087, 0.022826888332409517, 0.05545579515663641, 0.034596495529902835, 0.03651789974953447, 0.03070976212620735, 0.006705489583379988, 0.07751954533159733, 0.029468572299395288, 0.03346924530342221, 0.04606820549815893, 0.046742957684078386, 0.05645808976675783, 0.0041078870500704, 0.04156438859977892, 0.03104808647185564, 0.02091010832892997, 0.020844483814601387, 0.08092737889715604, 0.01710897890318717, 0.010957466937335474, 0.048409595752933195, 0.030192508096141473, 0.05874534310506923, 0.041892660449125936, 0.02840292457092021, 0.05638203277651753, 0.07430551493806498, 0.04520473236750279, 0.035451955161988735, 0.048651035475943766, 0.04302020923101476, 0.0416812221519649, 0.019016198348253965, 0.012117558258718677, 0.008071409837741936, 0.0009151218380014013, 0.016575519760538424, 0.09713898506015539, 0.06026072893291712, 0.021717013691418936, 0.05852197616228035, 0.024254459854481474, 0.03128325992396899, 0.09087016287126712, 0.018017849419265985, 0.01686489289360387, 0.05703301927340882, 0.02231516775542072, 0.01573335432580539, 0.07955076705132212, 0.012974631107811416, 0.01597744203172624, 0.03501835432169693, 0.02769281222884144, 0.058796782844832966, 0.07785432093909808, 0.01776203832456044, 0.018302968137764504, 0.0064165795504647705, 0.035606664538915665, 0.022656615058492337, 0.06261850920106683, 0.08453116659075022, 0.05176370291571532, 0.05192502800907407, 0.03624968842736312, 0.029875991865992546, 0.015300642366388013, 0.03214252274483442, 0.01126599935482123, 0.05186213459819555, 0.03651925342689667, 0.06621310274515833, 0.06828426303608076, 0.041481074677514176, 0.03147359238937497, 0.017691256944090128, 0.02495805486770613, 0.040322530415973494, 0.022078425191076737, 0.06863337608852557, 0.01848141266964376, 0.025413869248170937, 0.033897129486181905, 0.04030714124175055, 0.044161006409142695, 0.03363194103751864, 0.0743493347295693, 0.011203095765917428, 0.030406514648348093, 0.008144628007097967, 0.03690707690215536, 0.02534938806534878, 0.028593404617692744, 0.010595259007199534, 0.030906506747539555, 0.06804907601326704, 0.03204913597021784, 0.06645626933979136, 0.031233519914426973, 0.010307264148390718, 0.04853863615010466, 0.048300137876399925, 0.04929225106856652, 0.021012232938249196, 0.03953815750511629, 0.06549016439488956, 0.03434825349333031, 0.046551108692905734, 0.03780576939295445, 0.03313648833760193, 0.017801389962966954, 0.038513243930148225, 0.0467342656504895, 0.037923865020275116, 0.002386496930349884, 0.046069216515336714, 0.0035550701515083866, 0.019393092320699776, 0.034660562806363614, 0.022881245772753443, 0.012740522955677338, 0.016877009832699384, 0.022349328600934575, 0.0398686413786241, 0.07217243154134069, 0.03848556987941265, 0.04021472477221063, 0.05355353580255594, 0.10095048589365822, 0.0421909851554249, 0.016480960816677128, 0.09724634287080594, 0.04332860339699047, 0.021393020005364503, 0.03992176388523408, 0.05364827286185963, 0.04200631845742464, 0.06556906444685799, 0.018855136187214936, 0.020438472208167826, 0.01615301127146397, 0.03395980237317937, 0.00843014451675117, 0.02595272274421794, 0.005608995652957154, 0.016184101746018444, 0.06315955945423671, 0.049636794187660725, 0.018760095483490398, 0.012489892475839173, 0.05550415774009057, 0.025491916042353426, 0.0579141444925751, 0.03525842001129474, 0.04741191518093858, 0.03254818829840847, 0.03795041948822992, 0.02971393395481365, 0.052928075793066194, 0.014493811642751098, 0.03006012930667826, 0.03341003633769495, 0.042559226110045395, 0.03694900018828256, 0.011833648180722125, 0.012104480344403003, 0.01356655452400446, 0.014533589061881815, 0.07202223102961268, 0.07995538426829235, 0.034761586492615085, 0.012068512051233223, 0.03379877922790391, 0.0611605274357966, 0.027179157827049494, 0.06614533745284591, 0.03772482695057988, 0.045166541023978164, 0.029978029962096895, 0.03292192199400493, 0.011089509003795683, 0.061067303509584496, 0.019121987046673894, 0.03148393326305917, 0.051380099928272624, 0.017070205715884055, 0.012672731370132948, 0.010497428676379579, 0.0807859789846199, 0.03657861167032804, 0.01774264918640256, 0.02940273404653583, 0.03148718683847359, 0.0326949689936425, 0.030432020779699087, 0.06764046222503696, 0.03184275615162083, 0.052669815186943324, 0.062295580814991675, 0.02910026688394802, 0.06240620916443212, 0.045928729232400656, 0.04714611265808344, 0.03342943565387811, 0.027441418397107294, 0.10390247284833874, 0.024282898953450576, 0.0017739763716235757, 0.02725240568231259, 0.013870904621269022, 0.021813972952908704, 0.007683267451024481, 0.03899288337145533, 0.06340040545910597, 0.022800822409668138, 0.015848527163533226, 0.014115848977650915, 0.018848125224134753, 0.034838959840791564, 0.04619677092081734, 0.018735064326652458, 0.01895467727445066, 0.025777833735836402, 0.02926650457084179, 0.03046843775414995, 0.033782263685550006, 0.06658811547926494, 0.049190752407802005, 0.031672124950481315, 0.03234637162781187, 0.021432083266388093, 0.04038354428485036, 0.028489768571619476, 0.012384400636489903, 0.050484209787100554, 0.05152670759707689, 0.06626850512943097, 0.01525312286269452, 0.03610515368304082, 0.06787662633827754, 0.051112916586654525, 0.025801095612613217, 0.038192503819508214, 0.03497069062931197, 0.03603993968239852, 0.060878392575042586, 0.057908899416880946, 0.04456798492797783, 0.08117064048669168, 0.048378613843981705, 0.017861306301451156, 0.04205633666632431, 0.037858684946383746, 0.02365137792990676, 0.03121226480496781, 0.021839730142216598, 0.024261830441121544, 0.042066131319318495, 0.010944815651912774, 0.020399227439026748, 0.0486697935765343, 0.01793317503428885, 0.016615344677120447, 0.015949939311082875, 0.06855480851871626, 0.02906949192817722, 0.05825247562357357, 0.021690250573945895, 0.003957364658292915, 0.05130707598956568, 0.015050084829064352, 0.07908491883426905, 0.0556542496862156, 0.021069877880758474, 0.013428621077244835, 0.03561032862801637, 0.032293798734566996, 0.10435621600065913, 0.014868278156167694, 0.040897429388548644, 0.040498868096619844, 0.04463556023048503, 0.032922261261514256, 0.0249925583734044, 0.07011216173746757, 0.25900338483708246, 0.10533703158476523, 0.13403398064630373, 0.09665348646896225, 0.11813264819128172, 0.07946966854589325, 0.11027993527906281, 0.15575753711163998, 0.10620162769087724, 0.09780025814792939, 0.20672132527189596, 0.08274083837334599, 0.16105104663542338, 0.0916237167215773, 0.0846120547503233, 0.1635772596512522, 0.1343912836164236, 0.1587334559964282, 0.13534630808447087, 0.24975044706038066, 0.09280313272029161, 0.060072659381798336, 0.14534528154347623, 0.16209366997437819, 0.1354476133627551, 0.19348618760704994, 0.13879114894994668, 0.13526417820581368, 0.14722852834633418, 0.10444294634674277, 0.08667639576430831, 0.1038023346502866, 0.1821668121431555, 0.10913975896047694, 0.12034231105021068, 0.15134263544210366, 0.06428204636488642, 0.16284056061080524, 0.11830663814076356, 0.1122499124280044, 0.1691430245659181, 0.15315178622092518, 0.12928897169019493, 0.15674226784280368, 0.14947542920708656, 0.09443192210580621, 0.07981222695005791, 0.13601971337837832, 0.06630830799362489, 0.09686165422733341, 0.13047221462641442, 0.16825569075133118, 0.17263822630047798, 0.11017957316445452, 0.14753306843340397, 0.13491926528513432, 0.10222838446497917, 0.12118967915219919, 0.10633281565138272, 0.13933158852159977, 0.16654940588133677, 0.12352278110172067, 0.08758787185485874, 0.12459688846554075, 0.42412623869521276, 0.1158626771398953, 0.10291040715362344, 0.12664026953279972, 0.13899565940456732, 0.10703798316951309, 0.08086046177361693, 0.18522374810917036, 0.1567828713783196, 0.1287513276828187, 0.10504203848540783, 0.08134816560362067, 0.11664053611457348, 0.1309825543846403, 0.11139523650386504, 0.11695438570209912, 0.11270733324012586, 0.07416409466947828, 0.12144316626446587, 0.17375954613089561, 0.06883576272853784, 0.12626945014510835, 0.1517889214945691, 0.14027365297079086, 0.15274471949253762, 0.1073962768007602, 0.13120178904916557, 0.09939864916460854, 0.10012933638479028, 0.14890061505138874, 0.1620716175862721, 0.08306160901806184, 0.19425506277808122, 0.15448324834661825, 0.1059307429407324, 0.14078308349209173, 0.05931052206350224, 0.10545508989265986, 0.07721159899873392, 0.21081750547247274, 0.11375011942748513, 0.11369388923048973, 0.10428553300776652, 0.0829022889956832, 0.09861578260149274, 0.1592192734990801, 0.10081568812685353, 0.07059219133641038, 0.10418471627469574, 0.08929218897329909, 0.08979625228260245, 0.13628321566752025, 0.10271834103124482, 0.12633499662790978, 0.12121308861034256, 0.1061786999925971, 0.1604582920138325, 0.1401223260909319, 0.051443912754101415, 0.08405315902616296, 0.11453527265361377, 0.15490958546953543, 0.179095952638558, 0.2124980195824589, 0.1212186933095966, 0.1551271780793156, 0.19836382301790373, 0.15242766721972398, 0.10500416266066687, 0.1449179130473307, 0.16938291383641108, 0.1071202080430729, 0.1492900127278907, 0.13560808689466544, 0.1599716602691582, 0.15759682841598988, 0.16372523456811905, 0.0893910311694656, 0.08532191094543252, 0.15330418518611363, 0.12131698589239802, 0.07400921905147177, 0.14891687275043555, 0.1333560970212732, 0.13723306969872542, 0.11044316366314888, 0.15560160976435455, 0.1805383280983993, 0.09203518035688571, 0.10253365058451891, 0.0665446553113205, 0.11272155533411674, 0.15169118531048298, 0.20036517562610762, 0.08095287145780665, 0.11751083870019231, 0.16593968788427965, 0.07370195125362702, 0.20418505636709078, 0.16637709869870118, 0.11370426403092486, 0.06376587120550019, 0.08789171305085931, 0.09078524421368327, 0.1085923169074314, 0.1067956443876028, 0.16562681538718088, 0.12359997124544211, 0.16039636890803063, 0.1341159748179572, 0.0768314701105867, 0.1291009360658271], [0.022095831310642616, 0.04432041124839868, 0.027660432537751536, 0.018824010089571987, 0.041101661643811634, 0.01544767411957894, 0.036201322451233864, 0.03467631499682154, 0.0312864218971559, 0.014020212859447514, 0.036310888893370113, 0.02915252765108432, 0.015764522831887007, 0.01763158996722528, 0.03508014511317015, 0.04381352523341775, 0.07551437257123844, 0.018805540366364375, 0.05356116932151573, 0.02651079065565552, 0.05335388026599373, 0.06644237972795963, 0.025130513024383357, 0.050228028890809844, 0.06200792946453605, 0.03438530150534851, 0.0705666309222579, 0.04078666193942938, 0.030660432630351613, 0.06750079936214856, 0.04956401112888541, 0.009553656015279037, 0.047429519771997414, 0.037348301083381684, 0.015328148479706474, 0.02230262164292591, 0.017149406019598246, 0.02907991422606366, 0.0024846851883921772, 0.007498817884230188, 0.020632612951365963, 0.055422156783086915, 0.017778949113562703, 0.04058280287842665, 0.017486096792189137, 0.005683422462815153, 0.05623241580490555, 0.048041711029197486, 0.016405646822282245, 0.04039132708151426, 0.036307299443121464, 0.04965418843286378, 0.02182339780431773, 0.014687236531504562, 0.02617952646687627, 0.06254455566938434, 0.032645405403205326, 0.040274771728685925, 0.04139468699161496, 0.03299915624250259, 0.014699568905468498, 0.028216821075017964, 0.02799510975767459, 0.017482454755476544, 0.025320351855563264, 0.07737322604017598, 0.026149201040555323, 0.0867736909006323, 0.051376418875796456, 0.045123515118445666, 0.008823909414266902, 0.03154027881100774, 0.04938426041709525, 0.04934644566050597, 0.10847252154988901, 0.01973366940260998, 0.02359580421554191, 0.054722604142235856, 0.01853381423279643, 0.07028096089405672, 0.06513803864696197, 0.03298441167654736, 0.0071302215468936735, 0.05308248322190983, 0.030031763150223663, 0.0324484232946166, 0.052780341756130965, 0.013232038456148334, 0.03561150249359863, 0.041740434510367255, 0.0900383060798049, 0.03494501147153122, 0.02320572461134621, 0.07983552105724812, 0.014741359877267053, 0.021356550444449698, 0.06448051785784108, 0.03286588178681476, 0.015480610209384134, 0.024790750184495534, 0.08598320438925709, 0.015484650885420186, 0.06529187610638992, 0.03659587360120245, 0.003209659779843475, 0.02277862244019551, 0.03541225068537252, 0.03337409433775714, 0.03422197812635984, 0.03499603730493358, 0.06914152417864118, 0.06028811460626977, 0.032092786127967496, 0.015771294611373117, 0.032470166949289184, 0.05599078269941466, 0.051585957274905274, 0.009288766122023975, 0.022095274911927323, 0.037823760748973916, 0.015417324944532343, 0.047615333194179196, 0.030944840583418096, 0.013268144152659391, 0.03383236671132701, 0.04577497998252511, 0.048933747091463635, 0.05145847411560161, 0.03925105916070087, 0.02705906900311155, 0.03363185282796621, 0.021035929077437947, 0.015870257247505442, 0.019922844965809157, 0.027193829450490217, 0.06204138124095542, 0.031204505757029568, 0.010797819521810328, 0.02182568277099303, 0.07578685187867709, 0.022225326326276575, 0.031437864127968035, 0.06431352360440151, 0.03443416959739157, 0.023109521916402236, 0.011711497458496263, 0.014889131233628308, 0.029753048105963638, 0.012170846158239459, 0.02482339450424271, 0.057921642304531167, 0.02356693763951106, 0.056937230484826226, 0.032759572312768014, 0.02647928797107722, 0.0588835674737181, 0.030103185746286596, 0.02794421454226332, 0.04109492039840136, 0.0225813282054982, 0.02540073959556009, 0.030149658609713827, 0.07054935542068311, 0.040154053563518186, 0.033509204230670414, 0.022515992068552544, 0.03773162926414183, 0.00539557688171044, 0.039670366660824845, 0.0767483360001019, 0.025494760800419108, 0.05095868557691574, 0.02439473339888666, 0.07874056231230497, 0.050698168841855865, 0.023502202006056905, 0.01608721542704318, 0.041875988843717744, 0.016330634775970663, 0.0727213460153767, 0.05209921134103622, 0.023997776842276965, 0.04565174784511328, 0.028755876435233012, 0.05175416949870331, 0.035595010699970384, 0.04501565519188132, 0.022686355248359696, 0.03000459460807698, 0.0473026167601347, 0.015414799097925425, 0.0324748793749937, 0.024321580538526177, 0.010723473287985792, 0.03241944984932031, 0.026257060967119675, 0.024297865739624416, 0.013081642017433686, 0.06122074741870165, 0.009134849782900085, 0.02392105828039348, 0.030925658398440907, 0.03640799403988889, 0.027787946231131042, 0.04231876347746168, 0.02833916772423046, 0.05459096156326788, 0.11123565185282912, 0.013560532525713955, 0.039571551606059074, 0.032697055488824844, 0.025051127819876586, 0.011159717022175235, 0.03875599322574479, 0.031874124825532944, 0.05118463095277548, 0.035278182343712876, 0.03342869605070778, 0.04526418560583677, 0.04328573355451226, 0.01838662302387612, 0.0232294003944844, 0.03753834517140474, 0.08088187633880548, 0.04236191151929753, 0.029691606760025024, 0.028363150544464588, 0.07312366299863372, 0.025946692264239703, 0.021268900683415786, 0.041150248143821955, 0.03370844925354634, 0.057706743478775024, 0.01521672963696931, 0.008959534145625574, 0.06414017147783722, 0.03331006777339748, 0.002450442494591698, 0.02468383511794465, 0.012643574720381625, 0.0409900256698685, 0.04812677896448544, 0.01921111431771091, 0.06284357926675252, 0.008392652064295751, 0.01138548004174871, 0.03441349124269826, 0.02871746796050242, 0.014061030981663083, 0.06948847948972668, 0.05355212784239224, 0.034211511723697186, 0.04733132557677371, 0.009080936782993376, 0.032175689536545954, 0.05349529714190534, 0.009357193834148347, 0.023371115825804215, 0.00595608030978058, 0.05403190977605326, 0.03355226067027875, 0.00977975151701165, 0.06023136193731001, 0.03655765850895217, 0.02003649279608258, 0.009277078356327755, 0.02643779555468687, 0.02822716534137726, 0.028492876262004887, 0.017095413291826844, 0.013262793904037347, 0.012002758615251099, 0.031747123426092524, 0.03591564563768251, 0.017607323858620863, 0.04533267693061914, 0.0826948947672333, 0.047796586861035655, 0.024782953817131262, 0.07387535766299282, 0.030302362915660654, 0.022393109376675317, 0.01564221010942544, 0.06421351432800293, 0.016180113656446338, 0.023180203212957298, 0.1051675606785076, 0.04064189988587584, 0.04222373804077506, 0.046896116608487706, 0.033351275205079994, 0.049065128434449434, 0.020113642227702906, 0.08069157440747533, 0.013398472918197513, 0.03715493556644235, 0.030118965078145266, 0.06412460588450943, 0.0055541140443113235, 0.044675261314426146, 0.020499000924506357, 0.03480806953406759, 0.040853602811694145, 0.05890268859054361, 0.04346835786210639, 0.027357894128986766, 0.019567925349942276, 0.054085256199219396, 0.027277207833581736, 0.027429681437622224, 0.04016747837886214, 0.033648487113948376, 0.047515731038791795, 0.04123967905927982, 0.03410959915657129, 0.023734778365386382, 0.040586697669433694, 0.043611623745943816, 0.021245009465409175, 0.058553819810705524, 0.04865621609081115, 0.011658547978316034, 0.05793348952595677, 0.05672708140420062, 0.03853131331769483, 0.009496944058420402, 0.03369385735797031, 0.023825970079217638, 0.02814812449339245, 0.024132922358278717, 0.04188507782029254, 0.007151116184624178, 0.04206642648205161, 0.048254251945763826, 0.02327037712426058, 0.029368593557072536, 0.043351497168519666, 0.060950378355170996, 0.014858407167983907, 0.040934433295790634, 0.030456844983356338, 0.08548524110977139, 0.030237844413412467, 0.011889696869600033, 0.0033585396927914447, 0.02069802881617631, 0.013850659680818873, 0.049492595318172655, 0.013696745886201305, 0.06228063947388104, 0.02960137856592025, 0.023135163754756962, 0.13386962589408669, 0.11659324222377368, 0.1968870186912162, 0.14542726214442933, 0.10473010915198497, 0.08142747277660028, 0.15735569064106258, 0.06757715490779706, 0.15228239287223133, 0.13640102291745798, 0.14647770220679895, 0.07335422919797045, 0.1478130862648998, 0.12082778928535325, 0.10325403085776738, 0.10903960040637425, 0.18715894355305604, 0.09694018787039177, 0.10733277949371509, 0.0976900097780994, 0.13129123353532382, 0.15826838809464658, 0.15564143976994924, 0.09208446914064032, 0.12746582951928886, 0.15603280519800528, 0.14054866321384907, 0.13450230551617487, 0.1833753508648702, 0.15338225742535933, 0.16237831541470119, 0.13047089826847824, 0.08714542631059885, 0.10903730695801121, 0.0659156194222825, 0.10576400653059993, 0.08250681164541415, 0.18411401765687124, 0.09984418204320328, 0.12791484328252928, 0.06326102758092539, 0.1854674643171685, 0.13127368661974156, 0.13193584180303983, 0.06829792194600616, 0.061924143960433345, 0.1955145187675953, 0.09122528774397713, 0.11256288670535598, 0.19815099372395448, 0.10033200800951038, 0.19042466474430902, 0.16760562706206525, 0.22022627560155733, 0.12927455960639886, 0.11187177843281201, 0.1149741355329752, 0.09869213814714126, 0.1087252487029348, 0.12929996395749704, 0.09063568152487278, 0.0896194057006921, 0.13345528527029923, 0.07475113602621214, 0.08707097744835274, 0.21851331394697937, 0.1301942052585738, 0.17766104106392178, 0.1234711581575019, 0.1394631021789142, 0.09310039891196148, 0.09750578752053635, 0.07021021004766226, 0.1786574154560055, 0.2026193639529603, 0.09353747724422387, 0.12151876863624368, 0.15216797829738685, 0.13272098824381828, 0.12670308830482618, 0.11038526427000761, 0.06019985077104398, 0.0978030130001051, 0.12512104319674627, 0.12159135831253869, 0.12922837851302965, 0.16431450151971408, 0.13162786832877568, 0.09994237963110209, 0.08830838104976074, 0.2541521308677537, 0.08441067912748881, 0.15024043672851153, 0.11187992763838597, 0.09986193930464131, 0.11353674730552094, 0.19767899119428226, 0.11919570900499821, 0.19808936917356082, 0.11603464505502156, 0.30254904819386347, 0.19005901579345974, 0.11901987344026566, 0.14595282822847366, 0.11503190600446292, 0.1040107806080154, 0.11034157340015684, 0.12489548458584718, 0.09944130187588078, 0.10241789929568768, 0.21241213061979838, 0.11899358699364321, 0.20290573287223065, 0.11140116689992802, 0.12123795013342585, 0.13314450266105787, 0.13441163966698305, 0.16535542852112226, 0.11246481125376054, 0.11245501320809126, 0.12910876635994228, 0.12938495725393295, 0.15819240574325832, 0.10506958022181477, 0.11655620778245585, 0.14445733704737254, 0.12422609621925013, 0.12585186612393173, 0.16428392673177378, 0.07115683425217867, 0.11339325071977717, 0.12395651425634112, 0.1445264933364732, 0.1929327201630388, 0.1936318962169545, 0.13858581068260328, 0.14869390614330769, 0.09854111660804067, 0.09817997312971524, 0.11160951107740402, 0.07513572967478208, 0.1668203313435827, 0.10158845808889184, 0.1524825199906315, 0.09110133975212063, 0.13266027293034963, 0.09616743826440402, 0.1144390699586698, 0.114112952458007, 0.12290420143732003, 0.16227743082812854, 0.19296401419809886, 0.1506064792296716, 0.2121161265032632, 0.1316638578261648, 0.18158954169069016, 0.12011231482028961, 0.17573947060321057, 0.08238927580948387, 0.12743863383574144, 0.12051209408257689, 0.14811466793928826, 0.16695073220346654, 0.12717646147523606, 0.13580286715711865, 0.17199337376015528, 0.0934872045846922, 0.09033182675817183, 0.14174444547721318, 0.16420847363770008, 0.09689995074378592, 0.0868864498500313, 0.09933620358684234, 0.13483998525355542, 0.07585841696709394, 0.1333619188517332], [0.04253840187032308, 0.010152169702840703, 0.0017729318517792437, 0.04182955329971654, 0.059260256189320765, 0.011086845753847488, 0.00976951836076166, 0.07857394803847585, 0.005913769410523985, 0.027270129016999687, 0.02815130173361727, 0.007967002806253731, 0.01524438163531678, 0.021978259851623858, 0.01719267450139991, 0.0345196514390409, 0.031138535189841474, 0.036780153534242084, 0.05771198855446918, 0.009057589241170456, 0.04341478073703391, 0.03212092497519084, 0.040746814970459254, 0.050864274214420996, 0.05141192661332233, 0.04668777243101171, 0.034525405415999036, 0.01053946731345994, 0.030668391846120358, 0.05654476583003998, 0.02763557949635599, 0.027982853718900254, 0.02215200213582388, 0.017216949091692055, 0.010283449265573705, 0.0030019192864918815, 0.03310353867709637, 0.01735656106445406, 0.06035786122083664, 0.051809792406857014, 0.02480295024413083, 0.08263817602502448, 0.03436761888276253, 0.06707468615578753, 0.05411191923277719, 0.02619498349460108, 0.0174001925624907, 0.03600909687312586, 0.07246564687894923, 0.10382560840142624, 0.04111445542158825, 0.027624765344496285, 0.04324825806543231, 0.054199294187128544, 0.036080024138625176, 0.058492948434182575, 0.04477614590099879, 0.034653383905866315, 0.012179610286174076, 0.05938184966466256, 0.036341297440230846, 0.04209732357412577, 0.023927422938868403, 0.015599101083353162, 0.029843442541147982, 0.044382062940193076, 0.017776238366163204, 0.024253665968509655, 0.06866693643054791, 0.010662831765200411, 0.04687611000346286, 0.06642675306648016, 0.04158951135884438, 0.003967408672906458, 0.09814322367310524, 0.06155071899827037, 0.009923181097422327, 0.022866389248520136, 0.029684753556336676, 0.03865937323176435, 0.04817048340503659, 0.049200960967157564, 0.009072874090634286, 0.02667064163168626, 0.013030772247085614, 0.020777585350775292, 0.07797123252281121, 0.006099794026730316, 0.03804917008216892, 0.01638423395343125, 0.012385119035440897, 0.01124754998766418, 0.003909069504256227, 0.026729993089767437, 0.023293281073815057, 0.06320692798388855, 0.018365620668711405, 0.023012369272432158, 0.016257205412590077, 0.0027656071678003563, 0.04865347480933581, 0.020831072569957802, 0.058839842677116394, 0.03763637651822396, 0.06907897682062217, 0.03359342738986015, 0.026167243286701183, 0.02895969817680972, 0.041531544112201245, 0.03746503624798996, 0.06723969908697264, 0.08104712675724711, 0.04819287166797689, 0.02259921099591468, 0.04373670828395656, 0.007045352083098675, 0.03105185234120914, 0.03523031169814723, 0.05361860731084432, 0.034285933444542546, 0.023582572782678262, 0.03794042466740523, 0.017741848515080552, 0.050106842536479235, 0.01648301168877099, 0.06475269860987153, 0.02224260352418891, 0.045943989484970055, 0.04085671728742974, 0.023113565985113382, 0.09031774715653487, 0.0487666883771973, 0.0508038778124111, 0.010693219107841807, 0.009642512720477368, 0.0496789787097701, 0.09315211685108286, 0.06413322327924625, 0.051633512401687245, 0.02630692650564015, 0.030596826757703508, 0.053587160605405054, 0.038986433896103075, 0.04751265388248222, 0.0269194044438856, 0.0627404690853187, 0.05307376743959529, 0.018497534661686847, 0.09538155900580542, 0.011924616826166, 0.03298454738355108, 0.0060022325654114994, 0.02102593256027571, 0.05414654487477882, 0.0553890307034765, 0.007898713345639408, 0.05714986978897026, 0.0035987075867264396, 0.037666839347886186, 0.122425074289952, 0.027449545550293157, 0.056598224211484194, 0.023768498163138117, 0.02214954075004373, 0.0010683259273979015, 0.019578325595440607, 0.04114590212702751, 0.04138255478548152, 0.0514022982014077, 0.037922965961375406, 0.012543378846852906, 0.06998575744884354, 0.08536661283246108, 0.015735188066693287, 0.03824772299932582, 0.04069978231564164, 0.051624983216502836, 0.04573384040434446, 0.055971668367939334, 0.06118640676140785, 0.026943953840860298, 0.02285524600717638, 0.04397627864299076, 0.0508817430984761, 0.04046985733189753, 0.08488757389464549, 0.013129248882510831, 0.017243927644033517, 0.03236354195645877, 0.03178164050249117, 0.008255167298817208, 0.0040120240467201385, 0.013658256835437246, 0.011899430454442543, 0.03662954590150288, 0.01866817773718919, 0.01644169060247285, 0.03823549919096487, 0.023762381169945, 0.030475687900824205, 0.061296390502580574, 0.039041133996631415, 0.07256779354065657, 0.032920066200728924, 0.019003938916804533, 0.048805337731859515, 0.053000156568097215, 0.017784842190199664, 0.05101013210202966, 0.03345913852431944, 0.03958553960546851, 0.014151816422651921, 0.040557310317776034, 0.09232906744416271, 0.04635378731680768, 0.02932818340403693, 0.049863346852362156, 0.07653219545526163, 0.10537118225225381, 0.031217604875564575, 0.06298188505960362, 0.01833895084980343, 0.04419219187859978, 0.03276011174810784, 0.050382724697036405, 0.09810691526425735, 0.03739207677010979, 0.008578242418090147, 0.03294175896527512, 0.018795099408764924, 0.02197813941165805, 0.05917009924139295, 0.061027622781693935, 0.0331852546493922, 0.07884491421282291, 0.042504397087863514, 0.05030803156218358, 0.012329363812958556, 0.03574864799156785, 0.023615831176617315, 0.0836743600666523, 0.04039579523461206, 0.03197126050612756, 0.016088489376540695, 0.008739813480393162, 0.06218025700322219, 0.027229657795812403, 0.0342367057289396, 0.01632648383799408, 0.009057369565458169, 0.07343067973852158, 0.008808006249767329, 0.02791780256666243, 0.009372211510448583, 0.053755457646080425, 0.022669354553467462, 0.0045314252160356516, 0.03253739959161196, 0.02744433100867484, 0.023822541781035916, 0.034662696798997264, 0.024460463086143136, 0.020792467320071797, 0.039719825078334124, 0.05330566356756857, 0.023878771978031312, 0.012396050234591323, 0.013497729020725404, 0.02916791003995708, 0.03260885611442583, 0.04096213788060205, 0.014438500860705972, 0.05609077501243778, 0.037516974710992405, 0.010289886018394359, 0.029761645144649913, 0.060457259815718443, 0.09650304846997772, 0.029622837235885005, 0.06355796807578631, 0.0313353205232748, 0.0035786157407398734, 0.05578838588137712, 0.04478459705465606, 0.05247221561148763, 0.08467071410268545, 0.004131720592600426, 0.033552722074091434, 0.014023125471015061, 0.037445399444550276, 0.07276881632528134, 0.08039110553051744, 0.02903966692143253, 0.033846412386213026, 0.03320880999256458, 0.07977758773735591, 0.02911615138873458, 0.03981727288503732, 0.003279127134841734, 0.04494610195979476, 0.01811313778827233, 0.014179900987073779, 0.022309181380218694, 0.013056400514739965, 0.03744685829484037, 0.05608427125428404, 0.06597233816449131, 0.03750842856243253, 0.041881525689469914, 0.01929992437362671, 0.07089026498475245, 0.025468971380697827, 0.07057537045329809, 0.024558891375948275, 0.02822865472574319, 0.07617799339017697, 0.05672582611441612, 0.019658450403117707, 0.016475142378892218, 0.015294457519693034, 0.03439105548230665, 0.03440527757629752, 0.028200878894754818, 0.04161547889400806, 0.03994078661448189, 0.03786146015461002, 0.008880982691022967, 0.01922201837546059, 0.02787505486048758, 0.0831158986049039, 0.10792750865221024, 0.0017188924747253104, 0.02595699072948524, 0.041573565785906146, 0.032403853721916676, 0.04942744238568204, 0.03466839310047882, 0.046127417856561284, 0.04772004811093211, 0.0548920682631433, 0.05395771875711424, 0.02738964956785951, 0.007055193809459784, 0.01934092994114118, 0.02913350492183651, 0.014212535976964449, 0.015207068994641304, 0.025733270948486667, 0.013854226230510643, 0.048839138953813484, 0.052588516513683965, 0.014272519320781742, 0.15810028782912663, 0.10599316816244807, 0.11111549008637667, 0.09048066341451236, 0.11917030465390001, 0.1252893063106707, 0.14446697224463734, 0.1593876044665064, 0.15405555415366376, 0.1850051512675626, 0.09900397927101169, 0.1427395170820611, 0.10297910882426159, 0.07801151714686837, 0.09764114168605634, 0.14295691970203603, 0.11690848959343773, 0.07807624938764743, 0.099052019550332, 0.14547691733709403, 0.10064429696649313, 0.12384186897959028, 0.11849371024540492, 0.10720852616110019, 0.20921753346920013, 0.11881644864167486, 0.10150878450700215, 0.060322034571852, 0.14158441977841513, 0.11089378555438348, 0.18348295294812747, 0.0739958519116044, 0.14083527640572616, 0.08286992287529366, 0.14058778754302434, 0.07809824749295201, 0.1331777237355709, 0.26616458914109636, 0.1572549824735948, 0.11022993403353862, 0.12703827103333815, 0.25692465209535187, 0.14075431360730103, 0.09423097396003348, 0.19079492773328507, 0.1340758055448532, 0.10704613237508706, 0.15831383637019567, 0.1426476841526372, 0.15051023582262651, 0.10682249401829072, 0.1385968436620065, 0.19616983431790555, 0.09807107504457235, 0.10022194284413542, 0.20566495481346334, 0.15948037377425603, 0.07891987876168319, 0.18129862658679485, 0.14849259837397508, 0.1441827474960259, 0.14739190600812435, 0.15748200672013418, 0.10581199931246893, 0.13468112663498946, 0.1553119160234928, 0.13901693826275213, 0.07369923711355243, 0.158906061734472, 0.16113717987069062, 0.16496864998979227, 0.16167608595320157, 0.1403729769268206, 0.06864508760294744, 0.17184056767395564, 0.2607098732675825, 0.11679232439824513, 0.17365340968327864, 0.09334775206765958, 0.11853295671088354, 0.14006163791886397, 0.09299304110131093, 0.10644363399062838, 0.12295001612177917, 0.10710029982562576, 0.17624301144054957, 0.1113054391794971, 0.2054629006556102, 0.11827535767640386, 0.11531036320541586, 0.1445353685745171, 0.06423330040914671, 0.07400244727198567, 0.07357015261160475, 0.12572895629065378, 0.0883026881409543, 0.0745852409995028, 0.09618700042899166, 0.10499551812452929, 0.06616669773523297, 0.12804505415260792, 0.11056781733142478, 0.20160381416124956, 0.1948404756507703, 0.15329113017235482, 0.11909178458154202, 0.15624962427786418, 0.15375475957989693, 0.13566412031650543, 0.22350845805236272, 0.10148316981004817, 0.14463636172669275, 0.11362932662346534, 0.08684955111571721, 0.16997717480574334, 0.18254361620971135, 0.1698322668671608, 0.1501633415796927, 0.1382675641881568, 0.21448939772588865, 0.11263618884342057, 0.12747102709753172, 0.09137653998498406, 0.09460519280816827, 0.12561801581510476, 0.14450187608599663, 0.12787535254444393, 0.11127626895904541, 0.09630805107631854, 0.14424601410116467, 0.11125807064984526, 0.1069812440712537, 0.1268189549446106, 0.07550438453576394, 0.06185123537267957, 0.08980856769319091, 0.22615881583520345, 0.23404238852007048, 0.09397273031728608, 0.16771630969430718, 0.1956717081900154, 0.1213282902858087, 0.1215767969510385, 0.0977853439482195, 0.1000032713636756, 0.23287376122815268, 0.1335462632455996, 0.10900926310569048, 0.19243776957903588, 0.12456254102289677, 0.08362745972616331, 0.08936666497694594, 0.18890439346432686, 0.212975002559168, 0.17453542378331932, 0.12059590672808033, 0.10195497556456498, 0.09722533542662859, 0.15501433770571435, 0.15550232652042592, 0.10419977975210973, 0.09231128982667412, 0.12872785037117346, 0.1230561797107969, 0.12753566434340818, 0.14225146041384765, 0.09592724365315267, 0.07355989994747297, 0.2220333364925214, 0.23552870590771946, 0.09178765078208276, 0.1506936845502683, 0.1688061183584588, 0.08995519232537065, 0.19083013013005257, 0.11576070689729281], [0.03618626915184515, 0.03790969381641064, 0.02758045700777854, 0.020422187367720262, 0.04901846218854189, 0.024030575528740883, 0.02638488169759512, 0.06514777562447957, 0.05594460839139564, 0.09335955857698407, 0.02033597440458834, 0.0681111958942243, 0.0208598390620734, 0.015102364255913665, 0.04584760697824614, 0.011380628516365374, 0.0388524809053966, 0.03995215207604425, 0.03461562003940344, 0.02800937426010413, 0.025235462035717707, 0.0740101622151477, 0.028333944700924412, 0.026628925298739756, 0.07878919970244169, 0.013065207899282021, 0.03463824578960027, 0.06545042259884731, 0.0352395635231265, 0.06083311393324818, 0.046813674603721926, 0.05353592103347182, 0.09425166249275208, 0.07972836002175297, 0.051986092768077335, 0.049259409973663945, 0.014106464838343007, 0.033363607579043934, 0.03248510829039982, 0.007926989596204033, 0.026598800040249313, 0.11974311034594264, 0.024789942727823342, 0.022721050440200737, 0.04913159093952604, 0.048295405094644854, 0.036092424366090975, 0.04425664931269629, 0.024671207581247603, 0.053975309777472696, 0.03820399481004902, 0.05931343297873225, 0.03474640766424792, 0.03436553578025528, 0.009493045874738266, 0.03489621801834021, 0.04326338600367308, 0.006453951562954379, 0.020357785912762796, 0.011426268478057213, 0.008047966452847635, 0.046762014340077124, 0.07075947735990797, 0.02129396915967975, 0.0164366711396724, 0.015118835693491357, 0.01313680861078735, 0.028938337894422666, 0.04127935639449528, 0.0036658308152774616, 0.05844127120716231, 0.0330240991897881, 0.04457467528326171, 0.06503431778401136, 0.018085132951715162, 0.049567352913852246, 0.013230510904187602, 0.023435252652104412, 0.05254991804914815, 0.03274213396278875, 0.037794275009738545, 0.018914105969348123, 0.04564083021666322, 0.04940836537363274, 0.042635574870343716, 0.03897886483797005, 0.01603748389918889, 0.03605569865820663, 0.028665624492402588, 0.019914473540016582, 0.04778901780290263, 0.07382410112768412, 0.016342439588957598, 0.0386620093403118, 0.025082701750631844, 0.05850168117987258, 0.024823134964598075, 0.024503071692639163, 0.018746953956516724, 0.010177876850190972, 0.003982891569778855, 0.01386065365347479, 0.020021841528692415, 0.03153320508343833, 0.07813042362353631, 0.01792764836656196, 0.06756154860236815, 0.04592949936964682, 0.006604489221769784, 0.08573631263737168, 0.04466715621362839, 0.06774228997528553, 0.03517017313944442, 0.021154036579121436, 0.06707328158829894, 0.08921935502439737, 0.016073977208829353, 0.03519909569461431, 0.05847245667661939, 0.024284442620618, 0.025114428351766298, 0.035655885469168425, 0.053515951747873, 0.04490886056529624, 0.08339685960007565, 0.02933140644537551, 0.019397229687975984, 0.031389077460127215, 0.014353840046429207, 0.005489268573001027, 0.04133648904306548, 0.1057203970849514, 0.026203304030267254, 0.022303362942433784, 0.08870474049555403, 0.05981987116060086, 0.0064561843672501186, 0.041975441721401045, 0.03128223194341574, 0.023313131615785614, 0.013095758090327893, 0.01707019384152123, 0.03671495310430016, 0.05792690095092569, 0.0076274469195465955, 0.020094229340819374, 0.01959532798667039, 0.016484977743987526, 0.020004416749413525, 0.010236716862501842, 0.05866508598306349, 0.01987054687924683, 0.020707455363922884, 0.017887869251093695, 0.04510135416473661, 0.03486975854528802, 0.02354179961340768, 0.012364197256309646, 0.049224502739629576, 0.02713166885743184, 0.0642045440950564, 0.015557057357260158, 0.01905532437376678, 0.039766559177743535, 0.042626424825617244, 0.03733985671507461, 0.03814163404916014, 0.029374870005995035, 0.008292401059796768, 0.023679991751643162, 0.03195798157581261, 0.06315277410405022, 0.05393212102353573, 0.019954379880800843, 0.026154661551117897, 0.00760670834487038, 0.02076804854108819, 0.0070749561418779194, 0.05361764379111784, 0.017925278583009328, 0.03059659944847226, 0.05011457444301673, 0.07255323217915637, 0.014125611400231719, 0.014365442995248097, 0.05439476316262569, 0.03956819285771676, 0.006433383046117212, 0.040052527761352916, 0.014315285686669605, 0.0421288856305182, 0.030456902658832923, 0.01792416748191629, 0.09012806269207171, 0.01943518184790654, 0.018373690146420683, 0.01741877763665148, 0.06200066913983651, 0.030178347070302283, 0.008680626567054008, 0.02621612834211971, 0.06282203577991043, 0.01144745318950819, 0.03140491107478738, 0.08180236337440354, 0.0338021447615964, 0.006453378200863621, 0.05020418517025454, 0.022624248938102807, 0.03477046851600919, 0.021692087707508887, 0.06198180586631809, 0.011994563608563371, 0.06684777726020132, 0.03823120067162173, 0.010934264432372791, 0.039665369250412495, 0.019443180079438856, 0.03609580347048385, 0.005360599673752273, 0.006089466299662101, 0.009708181339582162, 0.05329342279583216, 0.06358331814408302, 0.0436676096703325, 0.02917953334482653, 0.05576845730787941, 0.05407986184582114, 0.014594942198268004, 0.02244287313494299, 0.050189718803656955, 0.00979567673389933, 0.03064893146178552, 0.042322519168789895, 0.04732690492112722, 0.030445713616375412, 0.03465568074690444, 0.053933793612356694, 0.07689012267759868, 0.07124422956258059, 0.02618394372984767, 0.014204607295271541, 0.03410245079014983, 0.05792534710573299, 0.02374262223020196, 0.03529381239786744, 0.03978129695834858, 0.06718986068985291, 0.017617925968287245, 0.015311639722702759, 0.01441551887962435, 0.058423412165471485, 0.020261116724993502, 0.056717320677957365, 0.022979825036600232, 0.025176443059795668, 0.031348046447549544, 0.007388739996323628, 0.011193432579083102, 0.016422725548701625, 0.0877499942268644, 0.05110969354531594, 0.02727727229440851, 0.008482211053238382, 0.01876130836483623, 0.05248759460768529, 0.05353702026020203, 0.11794649889426571, 0.022519781686631695, 0.04930334850879652, 0.023179509410900728, 0.02772992130901132, 0.03504661191254854, 0.06566880230924912, 0.013134246292923177, 0.028243935334363153, 0.010573988630702453, 0.03140326562736716, 0.029301418590226343, 0.03747303956853492, 0.06550326012074947, 0.041020135661321025, 0.035434910362320285, 0.02866808757452028, 0.04436602915770241, 0.040661400982311795, 0.030875562158014094, 0.050671756866254976, 0.006276717791999025, 0.01662677290317203, 0.0874210133084229, 0.06833450855421168, 0.041947207879275084, 0.026372233804847513, 0.022573738791314617, 0.05030800781345793, 0.00937363219314388, 0.026431478393663253, 0.028870236727276018, 0.03653752298227378, 0.04094904215474214, 0.050058666550155194, 0.0514944703983409, 0.01305702731146344, 0.02674366726673075, 0.055309292660760026, 0.026428857552153722, 0.007408229218396757, 0.040999908532415114, 0.02984851459041238, 0.03320288298917668, 0.052881419725183926, 0.00879345421812364, 0.035576863280896626, 0.044178203879190345, 0.028003988388393606, 0.05940117434199367, 0.02526732604019344, 0.049039065904383145, 0.02259811176918447, 0.02273279588137354, 0.043880486461733065, 0.009303415693076593, 0.04069441510364413, 0.026923523151448796, 0.041142465347158055, 0.03511713884238686, 0.06356009867574487, 0.01439877093902656, 0.061881491249161105, 0.04238599272710936, 0.042422681115567684, 0.016112063379426087, 0.04193687379094107, 0.035968398342707326, 0.034944265083010705, 0.018801302915172916, 0.07018316364181892, 0.04914805219907846, 0.05339782897915159, 0.08671583900494234, 0.05631356520046081, 0.02804476155766419, 0.05745229284678187, 0.03798476353819881, 0.02215308609551617, 0.03438473832128303, 0.021908223163336515, 0.06016301989023175, 0.03702888750870313, 0.03592416125216654, 0.004199681387815092, 0.1095423134309905, 0.13449466521186487, 0.12313406196023736, 0.0987875469561134, 0.1470974353807313, 0.10380157469106571, 0.1858907751739025, 0.20638937237007277, 0.13419045082160405, 0.20021918203149522, 0.11317958004240479, 0.08529515630964722, 0.1852182112634182, 0.09810681348400456, 0.20765589869448117, 0.050304733881992955, 0.11342659393059355, 0.16077803128532, 0.1036886257518615, 0.10564620606601238, 0.10555886503841196, 0.21642934291490487, 0.08318965536143098, 0.09844156873545476, 0.09512672839420182, 0.12323350805257048, 0.06739378760435752, 0.11810355260968208, 0.143825444525906, 0.1282496324607304, 0.10043307580053806, 0.0844623970666102, 0.13902653274791582, 0.14949379036469118, 0.12200242839753628, 0.09315624912934643, 0.1588795988687447, 0.17680972388812474, 0.15642088651657104, 0.11873302954648222, 0.08846640507025377, 0.2913871742784977, 0.12133042088576726, 0.1466240214982203, 0.16873278229364327, 0.11083411518484354, 0.1415174619427749, 0.19807034305163793, 0.10231793751674038, 0.12036550337714808, 0.0924967470179711, 0.12006715152944837, 0.16267479450574943, 0.06891882898552076, 0.11180086473801307, 0.09493954093860728, 0.13959480582603387, 0.1553927973977157, 0.08744625481111662, 0.08336910073246274, 0.10494618184332337, 0.1384803799114057, 0.12669628938393934, 0.1384296254920108, 0.08818384951778821, 0.10444402521742241, 0.055377329367079904, 0.1419546827673912, 0.12572525148945196, 0.14512740394898824, 0.1175864546426705, 0.120926312570061, 0.11533985233732633, 0.09598999457167727, 0.13394855308745587, 0.14338791157518113, 0.08602529391646385, 0.11378405296376773, 0.1727484610996076, 0.10110367195946829, 0.1454105566122702, 0.10940012641783271, 0.062222475452082496, 0.13177809598190443, 0.1413458197244576, 0.15342575152005467, 0.09471347342644419, 0.10105881400938545, 0.14856963923999242, 0.1934114130479949, 0.16657269320317677, 0.2601513575230326, 0.07296331838837691, 0.06760561266647917, 0.12811000352459295, 0.1968833953142166, 0.11679621918925218, 0.11433712685746805, 0.09501773531415633, 0.12497800801481519, 0.0541045842692256, 0.12130984770400183, 0.07228413876146078, 0.11846257905874934, 0.22252657716827734, 0.10853580851107836, 0.11792817844876222, 0.14634777632142815, 0.10154243305857692, 0.18238888308405876, 0.15874170698225498, 0.11641572389219489, 0.176205040620906, 0.09271780015634638, 0.19577764107712678, 0.21952420898846217, 0.08727531826921872, 0.08985875892852034, 0.12796166219881602, 0.17178228151585373, 0.1833266999040331, 0.11244440092039959, 0.09412740916013718, 0.1240907149123294, 0.12701184887971195, 0.10317272879183292, 0.17721566424838134, 0.14163733193916933, 0.14435125488255704, 0.10770494916609355, 0.13149862097842352, 0.1420318457697119, 0.09236013077731643, 0.08513136474149567, 0.15176757478288241, 0.16688340795891626, 0.16830393459115708, 0.08979638120425598, 0.15971962522183145, 0.10043590529156582, 0.12184067921979086, 0.12380775223885264, 0.09789425560406276, 0.11169246198343379, 0.1131398586024131, 0.08355446292885713, 0.08591686402048383, 0.11939722033483641, 0.10000103898346424, 0.098850406440241, 0.21923345673297132, 0.1194081718900374, 0.09872544064585652, 0.1425927092454263, 0.11101568437048367, 0.13646160252392292, 0.06158664742750781, 0.10363710458789553, 0.21952205124710286, 0.09887291344680957, 0.14844199323228427, 0.2720698522669928, 0.15215241270405905, 0.09508268468614135, 0.15467425595436776, 0.11935156849878174, 0.1261319653796298, 0.17727897156562122, 0.07428734377026558, 0.22164098040333816, 0.10050354844757489, 0.1551943937582629, 0.143813909430589, 0.1099206916987896, 0.16580164672008582, 0.060690153390169144], [0.04920555464923382, 0.03644228719973138, 0.1053946799199496, 0.04939317975991538, 0.021758156662274684, 0.07404014667762177, 0.011232777432139431, 0.03849997857053365, 0.038581043149211576, 0.028636176072593247, 0.017161458497866988, 0.03867031800161515, 0.014932979862870914, 0.017547595813604336, 0.06079010159841605, 0.03060273340504084, 0.05611015057989529, 0.04277598072907754, 0.07197207372103419, 0.02464187451239143, 0.011254297170255865, 0.07783697079867125, 0.03545168714065637, 0.009305729497490185, 0.03890741849318147, 0.03635475278965064, 0.04557213193870016, 0.021194523067346642, 0.03428520741207259, 0.011109198393699313, 0.04853473457374743, 0.02209246238427503, 0.015016974016491855, 0.07321897681270327, 0.02747265645302832, 0.020581193567652787, 0.04035867936909199, 0.027304761444351504, 0.07032041092004095, 0.040086366302732906, 0.06662009483469383, 0.048807003535330296, 0.007508576914135898, 0.062057849285858016, 0.03018164475049291, 0.017947951830657463, 0.029876517730631998, 0.016270462290516922, 0.011722420175958956, 0.05669725639745593, 0.01734531095384487, 0.012947965529747307, 0.024921212112531066, 0.06448690287236657, 0.07882683125457593, 0.024140208128041456, 0.025930210648636733, 0.062379753084055016, 0.059746379032731056, 0.02684441444996212, 0.051818586220698695, 0.04098163219168782, 0.02989417321181723, 0.0795899320925985, 0.008710845972278287, 0.043731090014002154, 0.0952153993504388, 0.02411250863224268, 0.036950431897171905, 0.08119384638432946, 0.03204198421112128, 0.044962966947683265, 0.0401117231563798, 0.022987251602379338, 0.03129930727716003, 0.029649649547146897, 0.05362295672031386, 0.0272600578609854, 0.007537432463972696, 0.03325459075027278, 0.030019332388682023, 0.08026538656226226, 0.0422130239728306, 0.026424016204795668, 0.01628106609652085, 0.04562522051855922, 0.06514922768941947, 0.05544908444530197, 0.033160203136503696, 0.02362292865291238, 0.03909392402108226, 0.03373772803960102, 0.026236124769119278, 0.06484029069542885, 0.03794543564851795, 0.011903133559306818, 0.04277115295241986, 0.021105809702671, 0.02768341451883316, 0.11427597728158746, 0.0278155286796391, 0.02959736842396004, 0.032393828367016146, 0.017330176230253916, 0.009011659205758145, 0.008008578343183866, 0.04653190275920289, 0.08152045921555587, 0.05705579090863466, 0.028197386135746325, 0.05558671170313444, 0.0008154117001270476, 0.056585094558873346, 0.14922590473932879, 0.02118071827239224, 0.05601803266576358, 0.05197446946320789, 0.03961072682536074, 0.009376202144527009, 0.010676791775040329, 0.028058093074443083, 0.0549138051324657, 0.029085820873400996, 0.041507693606295755, 0.014894179534167051, 0.015531189906011735, 0.0398923358214753, 0.03517185590629067, 0.02016807091422379, 0.034843787617449246, 0.019346934976056218, 0.05763877462595701, 0.014382542077718037, 0.015432831166046006, 0.023536356066220572, 0.018910509733749286, 0.010614891569795353, 0.020727969173874174, 0.02048977624092783, 0.022722402421225394, 0.05158484787014978, 0.028144049890605465, 0.012054313705968005, 0.024662398500368, 0.03949114181367414, 0.03511441791696208, 0.03625268076679536, 0.013643096666783094, 0.020554652670398355, 0.04822178065244641, 0.01709220721386373, 0.06451019019420658, 0.03039618056001408, 0.023809595332880105, 0.0019058259037722433, 0.024866028555801938, 0.03801373019814491, 0.03794934061755027, 0.05914804006793669, 0.02776240447669157, 0.0602697263072644, 0.018942541675642133, 0.010307905363983341, 0.019520443165674806, 0.0232346726115793, 0.025624813911105906, 0.034350859067801914, 0.030335787550679276, 0.034747018345764706, 0.0015290342416847125, 0.032469457880194695, 0.049415313572223694, 0.03918657119252852, 0.03194652111934764, 0.0575394303138767, 0.03069537039846182, 0.06908105992312942, 0.06150074489414692, 0.12000830897263118, 0.04845742229372263, 0.006497094515777592, 0.043926715052553585, 0.02027327098351504, 0.04825784818136266, 0.012158244914774383, 0.05425766855478287, 0.06125088794423001, 0.050770079983132224, 0.037917500361800194, 0.0573470995628408, 0.00937870254607073, 0.05870611699564116, 0.01718127341674907, 0.038016987166234424, 0.028633061596857648, 0.03421095871765699, 0.013652005831577947, 0.0617242068318384, 0.06091158650815487, 0.010294888517819345, 0.034175851315792115, 0.02850743762350508, 0.04394406519298043, 0.04217130085453391, 0.020869496311726313, 0.03174205476950322, 0.007881805101143462, 0.032527079073978324, 0.034498878089444976, 0.019692599374268736, 0.049583027072783024, 0.03703913338748472, 0.059067721877779276, 0.021832103408606987, 0.026734563023118035, 0.063293760110225, 0.022552385294277753, 0.030731251330247948, 0.0443365671671927, 0.056646437517234256, 0.039651900330292325, 0.04549722506531647, 0.026212024901594435, 0.03619853027963212, 0.06152796093374491, 0.03242208595786776, 0.027308518832017268, 0.02706276871530073, 0.04209712001362017, 0.08649112177746636, 0.0405692762828299, 0.0368794978463224, 0.00413727228130613, 0.05891289375722408, 0.03538356561745916, 0.004258185101207346, 0.024047206422047954, 0.01517696409220142, 0.04375494730525783, 0.03285321353801659, 0.03932587443185704, 0.03465512434818915, 0.05253239827496665, 0.10466674755194358, 0.02373754169924983, 0.04104510914268238, 0.043943308626434634, 0.024919380067980716, 0.011376291829427438, 0.04649784030126674, 0.07645755660321031, 0.02598614229022392, 0.06387618742883205, 0.030095073860138655, 0.022782084665128162, 0.026446921850687692, 0.007765327779842275, 0.03829056230772819, 0.03179378627932497, 0.07647534779139928, 0.05768037560795035, 0.017313238299850906, 0.029559285646038394, 0.039823389878230434, 0.09041766143803086, 0.12163676587598664, 0.06636310648173094, 0.013267204381658562, 0.0678108830803207, 0.0384904655095722, 0.03820287861994334, 0.05770727952143975, 0.09030580494020667, 0.03170645882242492, 0.01735190801056368, 0.04240373641784702, 0.03661544594381537, 0.008845982158423533, 0.04141236622152584, 0.024272035607802014, 0.015272593425054635, 0.03457672301945942, 0.026182786827640872, 0.043014906479844024, 0.013980690739117563, 0.024129996176010797, 0.03484335335503731, 0.010694793309085071, 0.0441633643183325, 0.08339293766766787, 0.0623557125883443, 0.011936953440973801, 0.06115066832197564, 0.06621092464774847, 0.013412589839260494, 0.03383061609097889, 0.01115705122772072, 0.023689453922478215, 0.020594879618978927, 0.028258500088538443, 0.06198137838925634, 0.027199093185897385, 0.018903894017317464, 0.02905851323157549, 0.0532916925315346, 0.02329886032800589, 0.019331859624279395, 0.04306585428171924, 0.0489536451308855, 0.007958439694318389, 0.039378189481794834, 0.04891083635655897, 0.021343846572563052, 0.018319565104320645, 0.0430947938002646, 0.03809532064146229, 0.039939436329794784, 0.019759625063410828, 0.02775953257722514, 0.01769364538735577, 0.06321635283529758, 0.03358293723847185, 0.08538943196513823, 0.017314820982781903, 0.03039141385150807, 0.03149591279881341, 0.0317663123964199, 0.06858490833214351, 0.02601703768596053, 0.022159925728504146, 0.06433849369308778, 0.01503085345029831, 0.024331302249005864, 0.04105174521516476, 0.03162701254976647, 0.02686993924102613, 0.020768832249034728, 0.0645836755367262, 0.030268327599125247, 0.04154058898399983, 0.027584428133975183, 0.01347615839248257, 0.022936156219137565, 0.032435951820973835, 0.08159553911536932, 0.06178235049758639, 0.02365239233975964, 0.022886735121054307, 0.02083289952549551, 0.01201695271967245, 0.04953406398583736, 0.0424848247452506, 0.15553530332233223, 0.13523616828024387, 0.16316002846828528, 0.13539844671530382, 0.09891098604670592, 0.12932295272392885, 0.14559695018189295, 0.11278575831758124, 0.12402979603835515, 0.1567574670272214, 0.07233972435018846, 0.14468737398939474, 0.15987355767616204, 0.1633839857365404, 0.1577080131641456, 0.1341411756085498, 0.12577375317258493, 0.08998510214899268, 0.2084264973444598, 0.10190808200942618, 0.0739251689187118, 0.12072864174842834, 0.2181257347443274, 0.12146319661821638, 0.06961459879364286, 0.1465940981038979, 0.19892499861972673, 0.07620339774127517, 0.11879599759621279, 0.09485392338995423, 0.07821303526205675, 0.14698209799826145, 0.11436614101486546, 0.15211570395955018, 0.1264187821320125, 0.20286556359912666, 0.2171061137425048, 0.12585820364100592, 0.19360194568123135, 0.18116380167858942, 0.20654437690973282, 0.13879623796258653, 0.11212273460945912, 0.12614458613097668, 0.10463842550026518, 0.14301021184240068, 0.14515659452549048, 0.14412638837737696, 0.09671518565820796, 0.10027771842266832, 0.12049780413508415, 0.09611533356032201, 0.12232747381286961, 0.19499317317136697, 0.2042384977851595, 0.1775733336274113, 0.06970350045178618, 0.19854364836854593, 0.18110599049500056, 0.054270550542111905, 0.0861727667174169, 0.15024293373738015, 0.16494988171117647, 0.13569423370063305, 0.10881763803107397, 0.11181175522506237, 0.2264460397085973, 0.17432080315692083, 0.08582111594400235, 0.11756921985319682, 0.08685481654746191, 0.13309811800718307, 0.13964211328753404, 0.12833316012152604, 0.1515855509787798, 0.09007949994078704, 0.13355855830013752, 0.11032074237508432, 0.05309410991945437, 0.11562901682087354, 0.10571321139910392, 0.2193501918975796, 0.1085613349984799, 0.16490802967122623, 0.14067900979093143, 0.1687175016850233, 0.16478944889136724, 0.11958514739360128, 0.0837424306997231, 0.23937678656407765, 0.2126990287963833, 0.12054352382464067, 0.10899758551801954, 0.16943969364677156, 0.09769720903464726, 0.12021252087184361, 0.1487427878060511, 0.06824015147451844, 0.10389941944075481, 0.1601981416876827, 0.08066492155194283, 0.1351396670298917, 0.14913127624562808, 0.07114646623709373, 0.09898658841848373, 0.08718372282705136, 0.16633173184735434, 0.0875149496964046, 0.11666048504412174, 0.15709953010082245, 0.10510938987135887, 0.030450049455144575, 0.1627044871981655, 0.23480498045682907, 0.14328452997973987, 0.10453040951064654, 0.1832249467926366, 0.13455457985401154, 0.20302240018333706, 0.1474004691200597, 0.17768527833478792, 0.11374015853341136, 0.11661880942327635, 0.11005313494907958, 0.22273728943296842, 0.07548829647047178, 0.08048235491982528, 0.11646920602236475, 0.1197245999106339, 0.13781872684402124, 0.16492730006575584, 0.17859404028526374, 0.17440256662666798, 0.07077798100986651, 0.09889069106429815, 0.10145201148199183, 0.04462504633037107, 0.0977953862664955, 0.1106961283034512, 0.13842313869723252, 0.2759003181542669, 0.09764941981328384, 0.07934231430824314, 0.10668532137892076, 0.1568273561341422, 0.07813653722405434, 0.13906014737273964, 0.11773445670093809, 0.08627254529190914, 0.11741498884345804, 0.13163691998592444, 0.16343244670757226, 0.19156800982143196, 0.1011731471600277, 0.14464417845010757, 0.11640289958034243, 0.15010080779237406, 0.16586196848324367, 0.08344217216862099, 0.20289046583431108, 0.11981422081589699, 0.11887116570557867, 0.16205928181963308, 0.0964804125417556, 0.10036075075290032, 0.1270474312560899, 0.13401845576507704, 0.17553217815501349, 0.14427201556307928, 0.08167257998138666, 0.23312329926661082, 0.18853951804339886, 0.1323188612503665, 0.09608201070555619, 0.10132182096796376, 0.1754178042922701], [0.010072621649929454, 0.01918740800049688, 0.07698810313429151, 0.021731860037626963, 0.06901991034724883, 0.04215620005769389, 0.029949053124125515, 0.0726876092542495, 0.03999670468536871, 0.04488717797877533, 0.035886400778378756, 0.03361503194485392, 0.004564615332388452, 0.022301055923370377, 0.0045692726271227, 0.043877592509878535, 0.020290302212483118, 0.06663024571857282, 0.07414249011448451, 0.00939839193597436, 0.024766886107889668, 0.0313648876867124, 0.02872526432786669, 0.03805789943518383, 0.05300537110971553, 0.011583595303818583, 0.04866709639983518, 0.02617901756561228, 0.02603541750327817, 0.034955752680876424, 0.10263331380805799, 0.009448245600132006, 0.06617005648357527, 0.07434006594121456, 0.04990551441109606, 0.0478645387504782, 0.019727148681080768, 0.028476506604679992, 0.11270470730960369, 0.031016992604626075, 0.10542081708886794, 0.05449515241863472, 0.04954291208248053, 0.03554299420544079, 0.015188477135130336, 0.0514434683136642, 0.03724303316058857, 0.0077801512254934225, 0.04854368784331849, 0.012396099428380174, 0.0370051048562995, 0.018040973892701522, 0.04769125108474067, 0.022939730402348295, 0.017561773802818995, 0.04899736314213701, 0.05816299721066441, 0.05929150951227971, 0.035271410564226766, 0.01003438959430371, 0.012009536331918622, 0.041421509480902126, 0.06654713196413857, 0.07485867704131774, 0.033608300877468925, 0.012576073208557708, 0.06273864382611853, 0.06708244859640088, 0.02073531092277595, 0.055913131151880534, 0.03745558764785528, 0.03315311244555882, 0.06726603303104639, 0.047331630917532105, 0.05677751012678657, 0.014183194426420544, 0.058987675101629326, 0.09693200473806687, 0.04130709490605763, 0.07403805678976433, 0.05886142009070941, 0.019676624963592206, 0.029363938806844608, 0.03324213624000549, 0.05115595945556249, 0.009839359122062368, 0.05668795707502535, 0.02057766348921827, 0.027304568061871187, 0.050188110675662756, 0.040120133597935946, 0.06736067509544746, 0.02904596711908068, 0.010174897233290332, 0.07117816739316497, 0.08700129868728773, 0.0720577659085393, 0.06370788360280649, 0.017181721249861375, 0.007236205324131463, 0.09680863350097622, 0.07445001575563635, 0.022484358765983155, 0.014722557671900307, 0.06265890917607717, 0.06520305587244885, 0.02521991340576538, 0.04819239669346383, 0.07969999725797347, 0.008798924058542719, 0.02795567499872829, 0.03327067203021475, 0.05287246984828796, 0.02618205570615828, 0.03197048019085612, 0.057605146430432796, 0.0391317591337221, 0.015957328557435955, 0.0035267752412307474, 0.043671134659754376, 0.010397600908098477, 0.042463203226881366, 0.030748299522591487, 0.05647675287244575, 0.037653407747192044, 0.044454998669347594, 0.01632035497043814, 0.034340871032327414, 0.05242249595799616, 0.06287116171526057, 0.10532719282699482, 0.02133899335084217, 0.06091815472713538, 0.07233898474701814, 0.05387742770835757, 0.0253471438107746, 0.015193818902064646, 0.009766650702139097, 0.061677035077341964, 0.03402900276705623, 0.04986194567754865, 0.021232570222179805, 0.04935311565973929, 0.07012159337422677, 0.059494907169469764, 0.04780160802017365, 0.015568877437285014, 0.009261067474393972, 0.07318065994020019, 0.04777368291148117, 0.03912130969443491, 0.05511239876172372, 0.04353477626240679, 0.043117521330714226, 0.006699034170846322, 0.008917214764681245, 0.1102617708966136, 0.02899227464305503, 0.09550523558365447, 0.01548433706297406, 0.0408507631426411, 0.028137846384197474, 0.04769823321008256, 0.06801817552851779, 0.015938914813367382, 0.0427820773662201, 0.016872629889154007, 0.07332524896732398, 0.01051334965242339, 0.044093288614281585, 0.05505811596023185, 0.04030718195385166, 0.015964578704110215, 0.017198694803352867, 0.05344287691903966, 0.06823109981736966, 0.029433848269815956, 0.011262744931238038, 0.040371693670749664, 0.048906429271612845, 0.02401356804849846, 0.02551294214624379, 0.027704588204090084, 0.04513807987262096, 0.026365078653075864, 0.024213552674544708, 0.03499031046937619, 0.04144198088241475, 0.010488744276309652, 0.004375994895651404, 0.07989048917910882, 0.039721959070967774, 0.021334621888984526, 0.05487019907949226, 0.007872353956502463, 0.018203159029196416, 0.04584442125633359, 0.02408196946739086, 0.013263494491444101, 0.04847592255100608, 0.011440012204859937, 0.04613601150257247, 0.06847146406237568, 0.03930014777662499, 0.009914124351260918, 0.013475544318290693, 0.027862792036363056, 0.0256395754404366, 0.02419449432220842, 0.0341548744056906, 0.03573068038427404, 0.02198243623466364, 0.034841002231197696, 0.021319432882592082, 0.07818457750337464, 0.02671596098558179, 0.041479446193469424, 0.034506440362227817, 0.0321568907238543, 0.039415644614824226, 0.009263595017338437, 0.04003580187314323, 0.029973141117287532, 0.05557333438524178, 0.026520950021222234, 0.019689600249486308, 0.049903343099036386, 0.06134824414870568, 0.047965884740863524, 0.02437059112292315, 0.011356467580688851, 0.029408430348017385, 0.08458285738847085, 0.04121696509953056, 0.08855652809143066, 0.014680308688964163, 0.03778539977169462, 0.045594757688896995, 0.04150319491912212, 0.056960178539156914, 0.019810898562094996, 0.061279983525829654, 0.02280146362526076, 0.03671401672597442, 0.026044979758028473, 0.046167736407369375, 0.03554391022771597, 0.07614684184747082, 0.02204179617443255, 0.04478266662252801, 0.023993519035034945, 0.021725101828841225, 0.014218801399692893, 0.0294246880470642, 0.04984952509403229, 0.04120082275143691, 0.033541611063161066, 0.016159806799675738, 0.017294965351798704, 0.028961818598742996, 0.010609316556448383, 0.0282280219918383, 0.01800338814168104, 0.009472605855470257, 0.021918550466320345, 0.013024142959953418, 0.04128717651058521, 0.008410715514660945, 0.0050328011025807685, 0.016895744184564267, 0.040793247121785364, 0.027197887089901736, 0.01515202793026609, 0.04454780190384813, 0.03547244013420173, 0.01402723484872175, 0.07062800441469465, 0.03402958291449717, 0.03917546018159815, 0.027222039543890526, 0.043545381764748266, 0.049065840896219015, 0.02147880888410977, 0.04583813123671072, 0.04855896845193846, 0.0037181984516792, 0.05019705715988364, 0.04107563304049628, 0.030641399723078524, 0.020940398132162433, 0.03343344579583832, 0.029248971225959913, 0.03217364036078964, 0.023295640679342405, 0.018289256641375165, 0.05496611339705331, 0.026050309650599957, 0.02808636423599507, 0.02191039447539619, 0.0342577437071928, 0.007030291574275387, 0.02337237959727645, 0.046246249694377184, 0.02833271655254066, 0.03688531628410731, 0.05275105957740119, 0.020460511025573527, 0.02703318458848766, 0.02247145302992846, 0.03828619593488319, 0.03375086787023714, 0.014362415032727378, 0.009239629160479775, 0.015900730255192945, 0.025411967653781176, 0.01822670080166842, 0.039321056833224635, 0.03685930464416742, 0.08717500365206174, 0.016684551856347492, 0.03159496194816061, 0.039816977722304206, 0.03351138232808028, 0.030468108664665903, 0.06186030060052872, 0.010202802834101021, 0.012744857946277728, 0.041098933933036666, 0.08310903861586537, 0.0056434075564279085, 0.009664828040903168, 0.01126156936931823, 0.06606592849961349, 0.012379322650044091, 0.04236702088798795, 0.004841296892014465, 0.036514391723488054, 0.034456768206187656, 0.029145932290703058, 0.0421462527343205, 0.012522920167871883, 0.023108022354011024, 0.013914698967710137, 0.04930365724223001, 0.0062219812202134305, 0.08339335835937943, 0.053556948833699734, 0.0039949143621405316, 0.0428751011246017, 0.017154606990516186, 0.06275271664240531, 0.023355338190283095, 0.09881655432816062, 0.08222072092550141, 0.1456096659281424, 0.1453383740569864, 0.11663456500640937, 0.07996541980121817, 0.11412751381950718, 0.12370162936193602, 0.1286736489938838, 0.11731251648494176, 0.09632617474666663, 0.08546199450003249, 0.05049366856526051, 0.10251946920262915, 0.1329624517155545, 0.12225541339388915, 0.10300222651234694, 0.18662661926022597, 0.10430621475513492, 0.10276677486087595, 0.08868810960224696, 0.0945203895015376, 0.1472627536526748, 0.09549782598125083, 0.1683034731873444, 0.13862920978239604, 0.14222988300025463, 0.13600530129458221, 0.12959049908178194, 0.14894419057028635, 0.16112732754221984, 0.10176529110010181, 0.2069216695215021, 0.17780442908406258, 0.11746118350752763, 0.09046569493200098, 0.07692040569548096, 0.10897868153239999, 0.17533750645816326, 0.19241187668272428, 0.18321258388459682, 0.12915958863283905, 0.11422732632075037, 0.16589649234499249, 0.055424287383045466, 0.13136015912251814, 0.11984426634652273, 0.13666893568422112, 0.1036015289968678, 0.07404898120356457, 0.13449447522205965, 0.09412738201873642, 0.19252942608935492, 0.11761313463960375, 0.09196926067982401, 0.10657442840082304, 0.22031662932464055, 0.2335810118487903, 0.1233453441943441, 0.07292570719229323, 0.17057277927441256, 0.1630969654236521, 0.17900635887469563, 0.14764688589743205, 0.12853324652782508, 0.14944736499871525, 0.08111797938389437, 0.1670384124985763, 0.11333838437816926, 0.21936305692153318, 0.09039543941617012, 0.24242872851235525, 0.17726991990847246, 0.08182348616953407, 0.11098683984684092, 0.05892763153782912, 0.06676140653767756, 0.19008914274828775, 0.1430433786341122, 0.21479481990848268, 0.15806767743613037, 0.1528761110135487, 0.14831278659403324, 0.15602918182100567, 0.07496027408965997, 0.09941709174641541, 0.15377886114375933, 0.0891513658155288, 0.07802741522235529, 0.08572544250637293, 0.126838727455054, 0.08663723750838212, 0.08528704103082418, 0.11963302482451711, 0.11380452436528035, 0.22112494095095567, 0.11660898423620633, 0.16874803576086247, 0.08173508662730455, 0.09261051698454789, 0.17303014812724932, 0.21584899191345486, 0.09130864577101809, 0.15385911826576504, 0.1524824792785304, 0.2545413656958512, 0.1149318628013134, 0.08883655270827667, 0.15936267508992127, 0.16354359074362687, 0.12121801477457796, 0.04970140429213643, 0.14623743295669556, 0.08768952997135264, 0.10581654549709388, 0.15442228876054287, 0.1743158498512847, 0.0954071262053081, 0.10741904843598604, 0.13474950939416885, 0.10879614882703338, 0.08560367261192628, 0.13360384372728212, 0.12287134677171707, 0.1835996474006346, 0.10561737511307001, 0.09908091835677624, 0.08008818035679204, 0.11049949564039707, 0.17950813552098616, 0.16459339298307896, 0.1095263407166515, 0.21615244634449482, 0.11073017719068698, 0.15644766150840692, 0.05508518611480083, 0.09099003965301172, 0.11682956240006856, 0.11797757579811982, 0.2034491579979658, 0.13764337982450212, 0.0942699218701039, 0.15494868265730993, 0.1428663217063461, 0.20974554227931158, 0.1965556221881083, 0.1551003080925771, 0.1517056381063802, 0.2544420553105218, 0.13889647115554127, 0.1571912273232426, 0.11144934288625206, 0.14637345208653382, 0.15525170282593795, 0.0970987682896001, 0.1407150128590209, 0.12785992265811988, 0.09918973501771688, 0.19221833135400498, 0.16635505988129548, 0.06290866434574127, 0.09882160941404955, 0.09908128476568631, 0.1620242287005697, 0.09451558547360556, 0.10638640634715557, 0.07969289299632822, 0.16644165452037538, 0.16669937569115842, 0.2698861908699785, 0.1284356867628438, 0.07327872182109527, 0.09577023743518762, 0.10437665347542081, 0.11044517212680408, 0.19357693488044397]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.033391539473086596, 0.011967592689740871, 0.021053727050977092, 0.11088869654174362, 0.006337189681029746, 0.010490915588369327, 0.046658134021397145, 0.05776313652417489, 0.014202515711076558, 0.05486929323524237, 0.0443304399959743, 0.05067952269954341, 0.022644613470349993, 0.07200086396187544, 0.10302846546151809, 0.017323792912065983, 0.03937415559110897, 0.02768258161709777, 0.05374435342050024, 0.04880796026970659, 0.04771409735881856, 0.08544064778834581, 0.05794665989066873, 0.060997706172721725, 0.011518203187733889, 0.0956986994881715, 0.036554038524627686, 0.07601156910615307, 0.013053589683425213, 0.0402671042829752, 0.05430598024811063, 0.03291299586583461, 0.019825130834111145, 0.05790894691433225, 0.04132927282314215, 0.04005269739510758, 0.02360877610876092, 0.04391073555286441, 0.040421454036342244, 0.04088294945125069, 0.03653838472174747, 0.025213479197451046, 0.030824441329709122, 0.039058762336415906, 0.02953215442331774, 0.06977044471672603, 0.11414953906621252, 0.06400426091360194, 0.0194189852170114, 0.06277695391327143, 0.02400307620077261, 0.013881862961820193, 0.01893070972125445, 0.0256401793366032, 0.02478857887243586, 0.02097311369808657, 0.04786228940689138, 0.01575204118021897, 0.033006796546812565, 0.0792888186073729, 0.04779255975569997, 0.04168000757428152, 0.02278454096189567, 0.06016075358326946, 0.06588315830699035, 0.05331735811861498, 0.05591934313997626, 0.020765359846076796, 0.03809590418157833, 0.08008159178176097, 0.013094005773642232, 0.06255710856722933, 0.03664623447028654, 0.038715213271124024, 0.09103793743997812, 0.03369953669607639, 0.010846410262664514, 0.045942500100604126, 0.016209584128643786, 0.07797470662210669, 0.021905877128509537, 0.04739034794537084, 0.007258751346463603, 0.017263822290780287, 0.04913781989099724, 0.010290254971810749, 0.049962979541825395, 0.019848621716456752, 0.02318106495243098, 0.056531011925211976, 0.037494667872254334, 0.03858077512787921, 0.013801858594108905, 0.02862471222345318, 0.05112509289756417, 0.023610533514459218, 0.05121001494782312, 0.0292854255198368, 0.046403693567429266, 0.0258576345430421, 0.012516698001750877, 0.07753124327531882, 0.03182513798986163, 0.06625869351306132, 0.03425972502944725, 0.029883788233356814, 0.02954758091696671, 0.017204158706590533, 0.009377685591711529, 0.0908258952466505, 0.025787265372595618, 0.03796886885538697, 0.03718889285145061, 0.03146312598671232, 0.03753468786765422, 0.060446898585983684, 0.028273383754172494, 0.03989471069404057, 0.05267469385372741, 0.05762806734336274, 0.09151088313332625, 0.0860675870041762, 0.021581060718744993, 0.0262244929825621, 0.020757527855624045, 0.0019182806260817284, 0.03899287997878023, 0.029058129859289954, 0.007704777011115636, 0.05553924139322979, 0.020621775050780604, 0.06084498151072434, 0.05317257231633578, 0.015451115988461035, 0.013617656692596418, 0.02876669228343027, 0.019504368671083024, 0.03359328829018133, 0.031046115327626467, 0.015031766079898392, 0.06053079265568938, 0.05145175661891699, 0.03731276620445507, 0.09278640683208193, 0.027900069053950052, 0.00821619903269623, 0.02215712337887713, 0.020789953347827708, 0.05145673706595387, 0.024320642463862896, 0.037236268166452646, 0.03484499201710735, 0.05352243175730109, 0.02529625198803842, 0.02847083405192409, 0.04887869754540069, 0.02223162991659982, 0.01843819677430604, 0.03867657409448709, 0.03913167431684477, 0.0267695974824684, 0.02478073161494519, 0.06645536010286637, 0.023890722676047256, 0.07371513518903937, 0.06879523383187396, 0.04531990350889308, 0.034220865328929255, 0.08124544218714748, 0.04070775170943566, 0.02982077268617494, 0.029312136050845896, 0.02330680936574936, 0.105982759435262, 0.08486225775309972, 0.051694875716098716, 0.03239121261451926, 0.04739185090043715, 0.023312982338081514, 0.019835885614156723, 0.028795848933181593, 0.022336923284456134, 0.0689487863065941, 0.043300274559961896, 0.019955604636509503, 0.0699974282511643, 0.043538759262966256, 0.05687726495255317, 0.028366444831980125, 0.014289628581276961, 0.046084436055805, 0.02138523042335042, 0.07118266608033862, 0.03209774282627872, 0.05540362259905253, 0.08225631687257971, 0.010381517083650189, 0.05649571453354188, 0.04710209609142371, 0.04112093882369144, 0.024270086515960947, 0.0001867969003797043, 0.015849677280389836, 0.03060731690909181, 0.04755251781482782, 0.030597837774881294, 0.025502791262364814, 0.03468959731981158, 0.07470961646842104, 0.02257697201067848, 0.04210017681387918, 0.0314069093604173, 0.0315424060182912, 0.07072882793311562, 0.0467571594220187, 0.036087413384978256, 0.032603366766124964, 0.011438179312140813, 0.04094349513096469, 0.016515905370137522, 0.07880386962954487, 0.026880312345123718, 0.08360027761331626, 0.032606769619243484, 0.006842756793568177, 0.06902343194399561, 0.039291218255779574, 0.014566095978287714, 0.029825135666344847, 0.015021428598889282, 0.04839500385735716, 0.03402111479746444, 0.02130457805469632, 0.010794344574346073, 0.04499263928404876, 0.03384144211720143, 0.01598305012365537, 0.03560689524082201, 0.051964505176459036, 0.03201711251001273, 0.06255968700030021, 0.049626826508236785, 0.040725322373743565, 0.00501552432875282, 0.01104169518553785, 0.021813671004825404, 0.05351212141769273, 0.036950835625508, 0.028345449262165597, 0.026696685502039533, 0.010340733736354326, 0.027805640728079846, 0.019807129300066402, 0.005377306902248944, 0.05876903076257024, 0.0665633896631854, 0.021170658990740776, 0.014774133118667772, 0.0699104264910732, 0.022458886561383094, 0.04368852890495743, 0.01848525317784931, 0.009215349481174988, 0.05060838508818831, 0.045689701701381376, 0.054287764975535016, 0.007799863515953932, 0.0301590088222708, 0.017077581391536763, 0.015133846584441406, 0.017335404342572604, 0.005852233493767146, 0.040011439073298655, 0.03523888838078294, 0.018163500353693962, 0.02796328646529998, 0.035561864264309406, 0.04112664530319827, 0.039115253769393475, 0.006731150929616498, 0.031526538476880105, 0.050454201575900824, 0.023126091741557633, 0.006990642652713827, 0.05278703211141484, 0.03742662777325936, 0.03987903992778488, 0.0593012057776962, 0.00710182316002569, 0.03141338936984539, 0.016864463720204573, 0.05491152525480304, 0.049800785923642774, 0.016834477561392953, 0.013049480305718524, 0.021252084889316132, 0.037099624784397225, 0.03714765149301716, 0.0429668729858739, 0.013613115596984113, 0.022560436112274016, 0.027268814355401055, 0.018035781403471316, 0.04186568868213466, 0.03134261477472527, 0.03255728066765836, 0.03266500488721898, 0.037740562177662335, 0.06011061663074153, 0.03473746457270213, 0.04687127883413008, 0.050623390890125713, 0.06810784393123218, 0.019682653747232895, 0.040087448566087654, 0.08687516581267118, 0.12716639201555932, 0.029024457558989525, 0.01684191430519734, 0.02431842195801437, 0.00814427771339459, 0.03704295353963971, 0.0652733656710812, 0.01881983540286975, 0.07511752458023173, 0.01969877743561353, 0.042854154748576026, 0.04240834706329873, 0.07519911163087402, 0.07287182472646236, 0.019584094839436666, 0.06665493082255125, 0.05387806213860001, 0.025851936545222998, 0.01353170326910913, 0.04926046848829303, 0.01729113671795598, 0.024697709462738464, 0.0025710533664096147, 0.009937381987193865, 0.0525226341560483, 0.04309018315481288, 0.017986704661910023, 0.027505984396806786, 0.05923787810440574, 0.05612918687984347, 0.02788347378373146, 0.02256967267021537, 0.029103171013827835, 0.006981455712645713, 0.06525742688349315, 0.06081391139222043, 0.08815325437379734, 0.24305661767721176, 0.07394854445010424, 0.1992151401937008, 0.08190311225397245, 0.07616227173379489, 0.13850981476051466, 0.11457378630127225, 0.13213356690747396, 0.17503439129463264, 0.14264376222022943, 0.12986303945737226, 0.0948867644848568, 0.0971489188128284, 0.28770560611571583, 0.08257048537156411, 0.1134571483624833, 0.1327715798148087, 0.20046284395669187, 0.16193804118250096, 0.15573404622929438, 0.15907163784972259, 0.18883924053183623, 0.15307348327977316, 0.0835715891527278, 0.22160539802696022, 0.08314739620046956, 0.13405566662549973, 0.1943458914756775, 0.13236665725708008, 0.10791636032185384, 0.1867133088942085, 0.14604767385338033, 0.17517722291605814, 0.11286940132933003, 0.19619770853647164, 0.1397028693131038, 0.1971814621772085, 0.199353887034314, 0.12654535605439118, 0.1642015797219106, 0.14616192557982036, 0.07672133709170989, 0.09397807038788285, 0.16549870797566005, 0.11901930347084999, 0.20139141912971223, 0.18394807513271058, 0.1353591459670237, 0.17715066059359483, 0.15015431706394466, 0.08345125096717051, 0.193494886425989, 0.12097055305327688, 0.20656143528010162, 0.13169682105737074, 0.24593756880078996, 0.07338394224643707, 0.13617304872189248, 0.10651811677962542, 0.1538843461977584, 0.1117905985031809, 0.11394232804221766, 0.11687278508075646, 0.14499582243817194, 0.12201850967747824, 0.115564922403012, 0.10784621337162596, 0.12011076776044709, 0.1443641741893121, 0.14353058034820215, 0.12419127380209309, 0.13491743324058397, 0.13812314479478768, 0.1509847760732685, 0.12559377854423864, 0.09607149341276713, 0.08813642670533486, 0.0833341833204031, 0.1592103982610362, 0.09879882420812335, 0.1433597252305065, 0.1411999754075493, 0.12446599906044346, 0.17244329676032066, 0.10521150260631527, 0.2343745178409985, 0.1159608747277941, 0.06246571668556758, 0.09783485664853028, 0.10694498315985713, 0.09563670852886778, 0.22697878469313892, 0.08947411099714891, 0.17537140606769494, 0.06522016174026898, 0.18734497071376868, 0.07644965167024306, 0.16902170250458376, 0.10789000602172953, 0.09133115277758666, 0.12871611171535083, 0.22290152204888208, 0.13889073074928351, 0.10411764308810234, 0.1914822565657752, 0.10581414348312787, 0.14503391539411886, 0.11652276957673685, 0.2543685563973018, 0.13953662823353494, 0.16774547312940868, 0.10383021565420286, 0.09491434014801468, 0.09055507835000753, 0.1655498966574669, 0.16218957411391394, 0.07480124583733933, 0.15959222348673002, 0.15048233446265968, 0.17469018405037268, 0.18867430223950318, 0.1048007242913757, 0.12657956779003143, 0.17205487617424556, 0.15399405173957348, 0.139127946591803, 0.14036066830158234, 0.10816272281642471, 0.12096151496682848, 0.13807498237916402, 0.0804962513170072, 0.1360052062996796, 0.08685592255954232, 0.10745893950973238, 0.20070266537368298, 0.22601934974747045, 0.10525712730096919, 0.1774415485560894, 0.16138384092066968, 0.14870199428072997, 0.10598379759384052, 0.12360145045178277, 0.1088366573676467, 0.14681441842445306, 0.12189551841999803, 0.18483322406453745, 0.10389503610453435, 0.2173596415668726, 0.10398600729448454, 0.12877196871808597, 0.15925801784864493, 0.24699980180178369, 0.12117028662136622, 0.07012628205120564, 0.09904829439307962, 0.13265860373420374, 0.10170284552233559, 0.1369605836059366, 0.13867047828223023, 0.0914469040664179, 0.09743533522955009, 0.15217772206025465, 0.08885597238051039, 0.1963048627866166, 0.19720480378184999, 0.1198896196271692, 0.16898355526583536, 0.14294515390481266, 0.12663199140557221, 0.16518749110400677, 0.12055238549198423, 0.09960362780839205, 0.27607508163367, 0.3045649214514664, 0.14257200035665715], [0.010940686766324299, 0.04501873913354107, 0.05201537494680711, 0.019604086177423596, 0.04969225424740996, 0.040125239573951275, 0.008781004796868988, 0.03848789386185152, 0.06669220275112561, 0.01902426952230079, 0.08495956646012408, 0.01936215621286205, 0.02940761610599501, 0.06306520915989365, 0.013054274155625274, 0.054727411562842984, 0.030498812374259745, 0.02728864284498351, 0.030124518887272904, 0.029920537689966813, 0.034646836042936356, 0.031268851232848, 0.01977072928899101, 0.01724859087594918, 0.0656935213399785, 0.07297825972948756, 0.02493545625891004, 0.07618952170014381, 0.024784796039706895, 0.054917665996721814, 0.033506700436451604, 0.010355271349128867, 0.0047076988599396175, 0.03785766714385577, 0.04473453134830509, 0.047099341239248, 0.04895332621942673, 0.021792646597272584, 0.010405241212408458, 0.024819270707666874, 0.06098935340664216, 0.06882515044084617, 0.05322610194395695, 0.07006773126444646, 0.07754925838006393, 0.029378164293510572, 0.03437773583989058, 0.029995230824819634, 0.034745070950261185, 0.09189212481890406, 0.05945893802813121, 0.022729296337014863, 0.023050786228850484, 0.01529433368705213, 0.042933621377285035, 0.004468692533139671, 0.08081632307065384, 0.03729223712746586, 0.11912405570702893, 0.013273809071896332, 0.04397649238152163, 0.049283481003450494, 0.021467238165704266, 0.03215805101873619, 0.03433188722868051, 0.08575204107910395, 0.04260531899386218, 0.021780058076339107, 0.017519412861604775, 0.015522772679105401, 0.0997276029416493, 0.03004426176526717, 0.014210236591420003, 0.03972645436546632, 0.03567002953163215, 0.024496705337826694, 0.06502614822238684, 0.015280003027458276, 0.04326621888737593, 0.005661527410016528, 0.06544137772704874, 0.07216759358665772, 0.06282404424356562, 0.009986021921836903, 0.01960593179267432, 0.06910224378641162, 0.005797915917355567, 0.007194277797160404, 0.07033506727644376, 0.056695207221699614, 0.009370123318928694, 0.00854692972331707, 0.037066902433122904, 0.015833326282777956, 0.020850743300148418, 0.0460977421275207, 0.0325706172734499, 0.04727098345756531, 0.07073492796293326, 0.06402693076857499, 0.02685531002602407, 0.015373023393164788, 0.013795740752747017, 0.037836612202227116, 0.04147147001432521, 0.0026209884547694984, 0.06319780847323792, 0.01367114221544138, 0.04398409536640559, 0.02530788886360824, 0.010582382108883133, 0.06582508928009442, 0.0032680112469409195, 0.07033105713448354, 0.09947959839233331, 0.03746349258082254, 0.04791464516893029, 0.024546241786863123, 0.05628743820956775, 0.012836898677051067, 0.0439802718215755, 0.059326501563191414, 0.06208000345421689, 0.04782565530123455, 0.021796743252447674, 0.01889889660690512, 0.03129192142348204, 0.04403749267969813, 0.0309927315850343, 0.04804337004731808, 0.009102866186627319, 0.004490397172048688, 0.04993766000760453, 0.0748318409813302, 0.025724451689581786, 0.02424264486346926, 0.039886510598340204, 0.019330509339592288, 0.07822896047894444, 0.021160989866725037, 0.010173431597650051, 0.03584259455757482, 0.016721470946712152, 0.02249210254688348, 0.025552853576040695, 0.06332299818417855, 0.04326961495514427, 0.0183849012412663, 0.028116874563108598, 0.03127867302724293, 0.026892656593450477, 0.07766365259885788, 0.03536423076210277, 0.014551434532872267, 0.03551639224003468, 0.03052414208650589, 0.10790043510496616, 0.010146648124126452, 0.04729143450302737, 0.0302833639351385, 0.07291502026574952, 0.015655863930338194, 0.023513486043417027, 0.01895875866258783, 0.03097077758450593, 0.03140618672062244, 0.04498055796804173, 0.022634416785357252, 0.036348401701876094, 0.029779297233160053, 0.01892316441184708, 0.006366172032098153, 0.00862483402514564, 0.002714423999090546, 0.062073584512940476, 0.07352974585124425, 0.012060631715160395, 0.026164739492482374, 0.02543141955642828, 0.018041479401290417, 0.02562169434635767, 0.031220386869141033, 0.05526008190853255, 0.0613724339221205, 0.08516420583639826, 0.005873908870853484, 0.059672540852001736, 0.03970251225733331, 0.019378008487235223, 0.12617567660553114, 0.04512833610975316, 0.026275781748284186, 0.012819212661789996, 0.02228795680483537, 0.03986578813887068, 0.004314798670488277, 0.04991999774106911, 0.045012506789394786, 0.012253897148184478, 0.019846401210608225, 0.055943007048751624, 0.04549136930810554, 0.044546010571398904, 0.0677551075017878, 0.04517678690275975, 0.03156751859933138, 0.014823540646050657, 0.022880952306357876, 0.0017417424595415859, 0.019167557458526323, 0.08200871265892472, 0.03684111312031746, 0.05296789562063558, 0.045784564289663515, 0.03759645151772669, 0.05788157481167998, 0.027194618247449398, 0.04879009783534067, 0.028437507804483175, 0.030288391879626682, 0.03431342089814799, 0.03620784995811326, 0.036091101222804615, 0.11396309121378831, 0.031624776776880026, 0.07771618478000164, 0.023456000556637133, 0.022041024340848838, 0.03213133030970182, 0.020099255588970015, 0.08269707286464316, 0.06405705093805279, 0.027622595728774155, 0.09033313633075782, 0.007605128206445703, 0.022382561549810425, 0.06627685111016035, 0.010330388621826257, 0.11340332017945391, 0.01927680498920381, 0.020038463940311755, 0.04135859232129795, 0.03869858237781695, 0.03331760290477957, 0.03431061176317079, 0.041669978826705895, 0.06307590965713773, 0.09661207547677414, 0.03546478965186647, 0.008931826168139066, 0.041181189340672324, 0.005572615997932319, 0.06576687097549438, 0.07793630832540137, 0.03931128932163119, 0.0017639357496851257, 0.03489184146746993, 0.05885244985776288, 0.022389752324670553, 0.03185164835304022, 0.01409994496498257, 0.024549693833770495, 0.06490553862282208, 0.021236473494874578, 0.0358614306896925, 0.00971604386411075, 0.04610394054491605, 0.02217651082069746, 0.018078038868095194, 0.048462820039795976, 0.02257018835682954, 0.03156759323818343, 0.07009398378431797, 0.0157050356668021, 0.11749520525336266, 0.06919328282986369, 0.020942559266196828, 0.03390961792320013, 0.027693762177867547, 0.025426808910976564, 0.07856765801885299, 0.01726217514702252, 0.054942775185086896, 0.015293363381975462, 0.04700919107667037, 0.0432442954209234, 0.06662531955433743, 0.03735556819343141, 0.10503726838422672, 0.04856444422953895, 0.046509429679385254, 0.018890710081905127, 0.03068032388442329, 0.02533108288688319, 0.007929829265257078, 0.021896208004493798, 0.03128595031531794, 0.026991973764130046, 0.019896862163607563, 0.015802229022873298, 0.02635669196024537, 0.0656571654336793, 0.016723839033927237, 0.012425278978688377, 0.03774532888616834, 0.08942193843956504, 0.00715860297038619, 0.0244899742704417, 0.05896837078034878, 0.050522658973932266, 0.01584327021347625, 0.0707471144518682, 0.03787556350497263, 0.013654384944987084, 0.035565830301493406, 0.021951454325712154, 0.052735670403178246, 0.0322070955298841, 0.018778475300808038, 0.005040661082603037, 0.011272629490122199, 0.029449125485760824, 0.07520216503845793, 0.01671166272301759, 0.029569653661123345, 0.02086607988790742, 0.026567020852650915, 0.01143903681077063, 0.03288133202918938, 0.06976674670087439, 0.011329427112026938, 0.05587876335318599, 0.01654246831978006, 0.033263143684182844, 0.05254170099007232, 0.05085337354934641, 0.05198701896837779, 0.01499978672446949, 0.029700387003166333, 0.018810446174549203, 0.03131476430488484, 0.04530743542792542, 0.04763511927532298, 0.020223507225247364, 0.02947987330013088, 0.007729129632934928, 0.07029133569449186, 0.0015926230449362525, 0.004889974146083529, 0.050831853811229975, 0.009955085813999176, 0.05187411413394979, 0.07762403972446918, 0.13150768620627268, 0.09388992868896041, 0.03893375243725521, 0.13253352258886608, 0.14477966832263128, 0.09823317706052746, 0.20284133989896092, 0.13214089508567536, 0.0826215451317174, 0.18976041967315332, 0.09396299333976847, 0.06758962638143982, 0.26632727469716755, 0.11628999135323934, 0.09573671780526638, 0.09355529557381358, 0.1918323670646974, 0.10921572774116482, 0.06039885152131319, 0.1737760752439499, 0.11814696528017521, 0.1070640796263303, 0.12423160592360155, 0.1952736931187766, 0.22488857113889285, 0.15236799685018404, 0.20302165379481657, 0.058676675361182005, 0.13040562319968427, 0.08909628912806511, 0.07847637470279421, 0.12390087438481194, 0.10786684083619288, 0.14504093144621166, 0.09423037006386689, 0.09774971407439027, 0.09989606961607933, 0.11081096357000725, 0.1393572235746043, 0.1381612377507346, 0.1765347272157669, 0.14560980163514614, 0.13316076036010469, 0.13166575772421701, 0.11015501019677945, 0.1548445818147489, 0.14233323745429516, 0.11728134458618504, 0.19846934878400393, 0.1258966630058629, 0.05235715642837541, 0.09279750766498701, 0.09826481036309685, 0.16257699046816143, 0.15528492390045098, 0.15364436193236283, 0.18290321262819426, 0.17506199409919126, 0.120109709245818, 0.1766575149127415, 0.11888014950922557, 0.17496938763984612, 0.08582777915788548, 0.16398344428411551, 0.14703847068761075, 0.14881384399320396, 0.14780719658093794, 0.1046264222157853, 0.12291733787528106, 0.16603077442518302, 0.17781363001891545, 0.09490323931510959, 0.1237981306122882, 0.17703492966081413, 0.1329401143427406, 0.1035000676555293, 0.13886616778160843, 0.1736621085022177, 0.08814086432435683, 0.15585740389568464, 0.13983785706971372, 0.13719014557344572, 0.09313639519470078, 0.06532268159623657, 0.1416170708835125, 0.16573786442833288, 0.13938501636896813, 0.18875603856784956, 0.13622214751584188, 0.12445230622376714, 0.08223150284694773, 0.11099298737410988, 0.24305946752429008, 0.23327575251460075, 0.14240409008094243, 0.1291339128677334, 0.08144695351698569, 0.18295837752521038, 0.15416550396808557, 0.12716975754925183, 0.08768007797854287, 0.11235232371836901, 0.11206216857369457, 0.19762160070240498, 0.06670458601521594, 0.12782980927399226, 0.14369725569018296, 0.19591796211898327, 0.08878885848181588, 0.12798303605190345, 0.16638578394693987, 0.13406182772346906, 0.15834222627537592, 0.22501808990325245, 0.12882287241518497, 0.2004850184811013, 0.07447238705520119, 0.1118904585018754, 0.10649963348571743, 0.18570121963109287, 0.1457403517727341, 0.1032651113346219, 0.15756448943700108, 0.08700460993817874, 0.1900743506848812, 0.14986959019941942, 0.18230247843478406, 0.12966477152492317, 0.2100952456572226, 0.05111354762422187, 0.08535752724856138, 0.12233244068920612, 0.1657794179128749, 0.14909667095967702, 0.15919032719518456, 0.13803511166146823, 0.06488734031362192, 0.13555194490722247, 0.11892884118216378, 0.1981321983039379, 0.26375994245920864, 0.14298849872180394, 0.08921945680465017, 0.09853128463562046, 0.13303793195102895, 0.14983303073261464, 0.13676452769764832, 0.15293648705950805, 0.10407610995961086, 0.09924373283450093, 0.09167870519948856, 0.150169719808868, 0.1532743839280946, 0.05448342394083738, 0.11824413149484567, 0.23139941319823265, 0.1348689586988517, 0.13906972828720296, 0.1131012092477509, 0.1361414697021246, 0.09387863108089992, 0.08506720247013227, 0.10413660814187356, 0.14036879715110573, 0.15093780787927763, 0.1274027529039553, 0.08618105841534478, 0.12804381921887398, 0.10438479589564459, 0.12185053154826164, 0.13176322249429567, 0.07324146346322127, 0.08367166628262826, 0.11191644639308963, 0.2067361580474036], [0.017829094547778368, 0.04783851353983794, 0.05626894813030958, 0.023885124762143408, 0.03124963172844478, 0.014418935303443244, 0.05475316196680069, 0.01966918313077518, 0.03679366995181356, 0.03168045396783522, 0.057307262771895955, 0.03949514856295926, 0.023037332575768232, 0.08948544253196035, 0.025238710522119488, 0.032188154224838526, 0.04801311756351164, 0.03913933497720531, 0.050588765248124085, 0.023688157920592597, 0.0295156558443393, 0.010691594016472144, 0.021953825805602328, 0.016835748118215373, 0.03826421818562916, 0.020847672929189036, 0.046216353441455534, 0.013733616630945886, 0.01761510835162231, 0.0470262969444905, 0.03265597697879587, 0.01123337454295584, 0.02721529490580516, 0.04092221288010478, 0.04044015785413129, 0.06764462843005146, 0.0395789679938129, 0.030564487778714726, 0.03188734608037131, 0.01988040599306779, 0.022065249737352133, 0.03862915467470884, 0.05342682956584862, 0.06710998354745762, 0.014588507989953672, 0.05241693875619343, 0.03849305072799325, 0.02933206801701869, 0.02499832252838782, 0.07476626057177782, 0.0731498815917543, 0.03945645849619593, 0.007316721137613058, 0.011236545845999249, 0.005664424754546157, 0.018679605963240777, 0.032552011843238554, 0.03357703059113451, 0.033108790538140705, 0.04370399611070752, 0.03361192425446851, 0.013721001816780438, 0.05041094836113708, 0.030419871610190188, 0.039005063075040064, 0.06777146698108741, 0.043810427721057615, 0.03199976576226098, 0.07725976819970778, 0.013414493978156574, 0.04606612239565168, 0.038082818633743694, 0.010608587979472109, 0.04450345624770437, 0.043441626975046735, 0.01826782850548625, 0.04499863074826343, 0.025785550375335982, 0.008478481655142136, 0.04320734240380781, 0.022025723376178315, 0.011267713503912091, 0.01868105463550559, 0.048643364637557945, 0.02334067165585501, 0.026694692305422256, 0.03677558020821639, 0.10113176330924034, 0.010773522879130073, 0.023536912464935864, 0.056288333875792365, 0.02825624226326389, 0.036627109960785935, 0.04128145985305309, 0.06367371936461755, 0.034116890015346665, 0.09274011038775955, 0.023147918516770005, 0.052052019230489216, 0.0526692248614771, 0.016436808543013673, 0.008088916041223066, 0.03634264772491796, 0.03142477518745831, 0.025307595397212675, 0.14007375655429705, 0.027071425125801137, 0.009900712258448558, 0.027511570436347808, 0.02502163190261594, 0.05405657113130603, 0.04488261483077492, 0.04985290080575006, 0.012983820168301463, 0.032283546070435216, 0.0490651962879513, 0.03392961095752461, 0.028603518182145696, 0.025795368777055825, 0.004582591421369995, 0.016772500172789608, 0.04852517062265958, 0.01564028815898512, 0.018172619864344597, 0.011282622614609343, 0.029038923925587108, 0.028224946531866277, 0.016036644212103317, 0.024965947926310555, 0.05809993416603122, 0.034529262887580056, 0.03454346123284527, 0.04112363939306565, 0.038562057739389796, 0.05667646947715964, 0.04980956955945917, 0.012264326231421104, 0.04623230579974396, 0.0048892727105080015, 0.014957144191222531, 0.024175625959677354, 0.046008928678929806, 0.05624150138880525, 0.010575952141412666, 0.0516168679376798, 0.019278696405568292, 0.026923853937270384, 0.013900928099506667, 0.049274656655532975, 0.016794640770448104, 0.01907459646463394, 0.04627603738169585, 0.01445579162931868, 0.025544960517436266, 0.0655468220689467, 0.004743893190087485, 0.07329322889979396, 0.038511859718710184, 0.007835159211286476, 0.030605111670281206, 0.029357906630528823, 0.027589729188808372, 0.0625197755705033, 0.057522066602749486, 0.01067075111703681, 0.05448759014585188, 0.04248197829084737, 0.007196524596240903, 0.012610898170221065, 0.017568204618458236, 0.08262903615832329, 0.031908831891736815, 0.06711400726011821, 0.014533192118895906, 0.050081960657345395, 0.02606907792921577, 0.03459902646552239, 0.020429169493062154, 0.051122585710670264, 0.021937568106555512, 0.06100586894899607, 0.03385622060990759, 0.06975475698709488, 0.020024820297424282, 0.01804639708383807, 0.037004609525735886, 0.051703927373247485, 0.00993965847218143, 0.07000813553375856, 0.06112649890461138, 0.033609685088906965, 0.0147589831280389, 0.03743400005623698, 0.0203154877360378, 0.039320425795657296, 0.06412418519279786, 0.002395645490781005, 0.07102320356560604, 0.03296888340264559, 0.06216914259961673, 0.06727522039519888, 0.02724669241745557, 0.044380169827491045, 0.02573999183784638, 0.023661104729399085, 0.016108041363103048, 0.03169795338596616, 0.02298073427352522, 0.009760629552017366, 0.012167765609254795, 0.01711786601559392, 0.003676004599713321, 0.039331967676324506, 0.04761952314791935, 0.005758613048653517, 0.025545001229537383, 0.007356124514314745, 0.030346705179129328, 0.04455064157290118, 0.05306217806147678, 0.008950044833389776, 0.01978282587203596, 0.04020015323268516, 0.021433321592797126, 0.08428607974201441, 0.03836361338783588, 0.03109952960429447, 0.04324844466256244, 0.038178509034748585, 0.04679601912253669, 0.03828279986711485, 0.014744465871314918, 0.03114495413111789, 0.03462758261178221, 0.030699760520032475, 0.055016168925379, 0.018876347191897885, 0.035159611741879156, 0.05306179808186633, 0.04684890414189015, 0.05475116368117077, 0.036684035656175444, 0.030762955878994296, 0.07929625535117728, 0.04361025649788124, 0.044138974377087185, 0.015599189292905586, 0.04124461879421558, 0.023523898163278188, 0.014357797601925475, 0.014491221335317408, 0.01170445341683392, 0.026280964059489112, 0.0145098759593176, 0.003562223182858101, 0.04538783164960997, 0.04827100158269916, 0.04832994931244424, 0.044887832765068324, 0.042956314980983734, 0.07264936702059847, 0.014225122801560377, 0.023280488992375985, 0.042692015413194895, 0.056318939197808504, 0.07853023002722434, 0.039707570735897334, 0.04200499192146318, 0.039332188200205564, 0.0676976695124592, 0.022325596838657345, 0.03299431150246944, 0.04590749787166715, 0.016305539158305953, 0.056440970328237326, 0.03459622411589537, 0.05778276654226439, 0.032194491741912704, 0.06287813705525228, 0.025059270240100365, 0.03629715195191758, 0.009408013562538793, 0.05359305368204202, 0.010102913997668241, 0.060167654284409115, 0.06360020009534699, 0.04554356561441507, 0.02429707015731505, 0.04156433092430234, 0.01303359495276319, 0.03233253290610654, 0.028356516168319752, 0.07282791672540562, 0.03571663810206311, 0.019222523884049485, 0.06838037752147232, 0.028086723859554956, 0.032288105825760534, 0.05993518140166998, 0.05920264178088733, 0.03251140830772264, 0.02499568641984037, 0.0445876827995692, 0.02806936014842774, 0.03869926430551069, 0.012231978770744587, 0.05963728417243276, 0.05564118449443153, 0.04383347416296601, 0.0017965412657109223, 0.02053284794757409, 0.0349687160924077, 0.04084971480603729, 0.02923434540363295, 0.023621016880497336, 0.07929304588053908, 0.03514504020235368, 0.05357069256050246, 0.017082650048126067, 0.012291870512334364, 0.06683275449488844, 0.020919456845149398, 0.026931445047791516, 0.011898419437264758, 0.012778208790613073, 0.03619444549881986, 0.023474368499591947, 0.014869428273024303, 0.08126568288675376, 0.004835890240168997, 0.06814761286867516, 0.045389840113265176, 0.014178690650234265, 0.05832750802593572, 0.026836775841989687, 0.05451684518318091, 0.01218631845300219, 0.05575486285878079, 0.023598727005134736, 0.03666127080629979, 0.03150412307253905, 0.005579826280674232, 0.03776601741888693, 0.045499277633747885, 0.030476505535521677, 0.06584028167916195, 0.04543597710185817, 0.018902918623228158, 0.034600906007524045, 0.043966175256563086, 0.02446971321478486, 0.03188119516042726, 0.16145318719957555, 0.12714621238410473, 0.18367881886661053, 0.10770439276737825, 0.11933575863284723, 0.12346666625567845, 0.16177766264549323, 0.1459282516900982, 0.12495856120118073, 0.12096152853752885, 0.12654682169003145, 0.07328703387507371, 0.11444559746554919, 0.1412941696388381, 0.07391393237880298, 0.1278120180858033, 0.1339802678142275, 0.1319578941911459, 0.18688925302454404, 0.1769404233034168, 0.10227303885455642, 0.12425475753843784, 0.16872823610901833, 0.12977438207183564, 0.14949259614305838, 0.06916189379990101, 0.16289059578308038, 0.2511698066123894, 0.07720936661852257, 0.09889044679169144, 0.13578932359814644, 0.11656333240015165, 0.1627396760242326, 0.1510627804590123, 0.10373369404780013, 0.19141694078488009, 0.11533804743417672, 0.19234151260129043, 0.07285159759755645, 0.105308933449643, 0.09226019613976989, 0.15772637432175024, 0.07462381571531296, 0.21098412653165205, 0.13581061602703162, 0.12801058457366057, 0.08258774730243854, 0.15070079559726374, 0.17919461163026945, 0.17671529895492963, 0.09399535946015801, 0.0896619837731123, 0.10845328508211033, 0.17117553550217832, 0.18114027008414268, 0.20276294196290628, 0.0963815160627876, 0.09582707831369978, 0.07293153580810342, 0.16337496122079237, 0.11543046390371663, 0.12153303144233567, 0.16926525586417743, 0.12736698053777218, 0.21749404578336648, 0.07944231679929153, 0.13261718595666544, 0.12731819386993135, 0.15017342461006983, 0.1073257363002215, 0.18324047167386326, 0.20029379374214581, 0.12461139554423944, 0.10281735964651618, 0.06628009450754949, 0.08618871229035513, 0.25733513864023344, 0.07737385029239313, 0.09933740459382534, 0.11101832387170621, 0.12691329845360347, 0.1550228465348482, 0.15306604653596878, 0.23392285779118538, 0.08445409179798194, 0.14949999217476162, 0.10519023053348064, 0.17148683379803384, 0.12995133043399879, 0.108228445718331, 0.174001525289246, 0.13439203000494412, 0.14707496230091366, 0.14705755109233515, 0.16292951655175003, 0.1251015556710107, 0.24368317691343172, 0.12786170041986875, 0.18155366075890406, 0.1478485736463751, 0.1926425921597651, 0.09395276781703744, 0.15161638361002716, 0.09653003380766936, 0.08842388128063508, 0.17976588383316994, 0.07674471262310233, 0.06020498049578496, 0.12281163569007601, 0.09043094715369598, 0.12170327587851457, 0.10244776840720858, 0.17420687712728977, 0.1038937536733491, 0.16228288624967846, 0.1505835854581424, 0.14181771368852683, 0.11739722479666982, 0.1456853768655232, 0.10946251092744724, 0.13032409043184348, 0.1844532580247947, 0.17518551461398602, 0.11943658893661839, 0.0765191133001021, 0.06936514896473714, 0.15909706934222154, 0.12833531786288532, 0.1600812165332692, 0.19428700820675918, 0.14880397809403284, 0.12358038872480392, 0.12386621481605939, 0.1340134074645383, 0.19645133135574205, 0.10339154276464667, 0.1339155627148492, 0.08106276020407677, 0.08896813421909298, 0.14860340314252035, 0.11789683013090066, 0.14793664749179566, 0.13229040349168436, 0.07010297437331506, 0.15130178763398103, 0.14829077491802828, 0.14148406444915704, 0.09534925395356757, 0.12118771140064512, 0.09164507021861416, 0.0818767850952489, 0.0904097565050636, 0.14214362762868404, 0.07094127046210424, 0.15258728579751082, 0.1108581285391535, 0.09076798228280884, 0.15723808695163044, 0.10568026173859835, 0.18451610393822193, 0.13722110034099647, 0.15754034716103757, 0.21065248575593742, 0.1380484245185341, 0.10121681088847773, 0.122238924992936, 0.18310825234012945, 0.16932472267321177, 0.09636885459933962, 0.1434208612356867, 0.1865075770765543, 0.06352357992104121, 0.1363311338105372, 0.1265588996133634, 0.17486885589148315, 0.1482123498405729], [0.00610931175262002, 0.015047346940264106, 0.0300797898588436, 0.04380905708031995, 0.018835436619286026, 0.0946719470833029, 0.03693296979846699, 0.0019440454489085823, 0.045369575664933236, 0.04947757933820997, 0.04374387361375349, 0.07406345435551234, 0.06057594237583024, 0.025540527987426946, 0.061291192924337726, 0.08675774532769408, 0.01771863074307995, 0.08716125653258391, 0.04472787491977215, 0.0660555265577776, 0.02205196741436209, 0.016518982526447092, 0.007634767464229039, 0.08706918611590352, 0.020062550237136226, 0.031119668523647954, 0.022505269518920352, 0.03870253823697567, 0.055181090254336596, 0.049122077878564596, 0.05059870578614729, 0.0952000373176166, 0.02974953668724213, 0.051617889132882865, 0.051378403590726, 0.03565898298152855, 0.010950843587384691, 0.03386890582208123, 0.07628937491348811, 0.035972008149006536, 0.02343881156827722, 0.03843380105016487, 0.011070560065231152, 0.01958042396498578, 0.03492115757295063, 0.03169925956587706, 0.028490131587854454, 0.03914852234135781, 0.008977661208648766, 0.01959880717497851, 0.034453976034585915, 0.01961953641979822, 0.011492013432351606, 0.07489161991647311, 0.016573073641796197, 0.07830437964626721, 0.036945342884532044, 0.057923901826143265, 0.03572000363575561, 0.03519404060872538, 0.021648038910435777, 0.048111885120826106, 0.016295886997665678, 0.025460679682769945, 0.0699031458103231, 0.04654764477163553, 0.0176538442194994, 0.0342130587835397, 0.008989260764792562, 0.08036450695778642, 0.05033849099917071, 0.028051229692729454, 0.03203904954716563, 0.01053112218089934, 0.04153051952432309, 0.027348516775029044, 0.03173110321430223, 0.019130687561950514, 0.03821571650249617, 0.03772758858810578, 0.02674332121387124, 0.06465144082903862, 0.05579034684758101, 0.04246807171564017, 0.008612796813914818, 0.02983432642317244, 0.09375870001635381, 0.08118550040360008, 0.04171756448756371, 0.05749685224145651, 0.018141266457470398, 0.011146913066373339, 0.09326067566871643, 0.01298342746615942, 0.05386685274009194, 0.07117621999766145, 0.02962326132027166, 0.021476754619340812, 0.028893547797841684, 0.02759773250935333, 0.05234758569193738, 0.015446895500645041, 0.05539176859227674, 0.02779552885996444, 0.024272135691717267, 0.014680985527645265, 0.06475484956588064, 0.008926620108208485, 0.022435439783813696, 0.03656712407246232, 0.02683480130508542, 0.02589343235428844, 0.010551629205500441, 0.09473277774772473, 0.010597236936778894, 0.0626036153574075, 0.01789786576825593, 0.03276859682851604, 0.02495414650599871, 0.038782598583825996, 0.013339928068619753, 0.009956779607039477, 0.026627866784110665, 0.05533275640170489, 0.026352698781660626, 0.06308434384741954, 0.01878372037650219, 0.0252504016804908, 0.024791946102465903, 0.0383678203049515, 0.018917820948575224, 0.028593302837439945, 0.045465639260198386, 0.03313820503119912, 0.06216292721884591, 0.04381436661684087, 0.04075006854587367, 0.032927536871284246, 0.02539399835014982, 0.028325644521308795, 0.05030457103358848, 0.09352890734693833, 0.04279117652082017, 0.021573349168258052, 0.0299951460079423, 0.021536594622635415, 0.12834255104618414, 0.02408961994972612, 0.015958231009010757, 0.03670676318662507, 0.017024329963273237, 0.031108292884060314, 0.005758359870274684, 0.05890547736947026, 0.03671833220869303, 0.01884056125501437, 0.016973875795624087, 0.0681256554754717, 0.03608724714389869, 0.044831880767430575, 0.04376478945570333, 0.025532831703977923, 0.025354212449331368, 0.0186901368267302, 0.04510360690099852, 0.05496824738968696, 0.04335615531142269, 0.007040077321497458, 0.05916631980133908, 0.013714815273747911, 0.020805742857711654, 0.006449630567138749, 0.00590500613075814, 0.018747719004750252, 0.00952323729039303, 0.07267549061881644, 0.028217650584078262, 0.02143871085718274, 0.022347540661160434, 0.01821179169097117, 0.060814189591578076, 0.02485413383692503, 0.0232837459604655, 0.015696903424603597, 0.0075239304652703655, 0.14236799201795033, 0.032894492215876064, 0.02268410420843533, 0.046087089127727916, 0.011194186601122575, 0.03912777274048754, 0.01293077738955617, 0.03283550716670496, 0.031387879845819304, 0.017200216418132186, 0.030105184031916515, 0.051398881777588806, 0.001463724928076512, 0.015723320489217128, 0.0035846742102876306, 0.03685005960453834, 0.020327087292181592, 0.027109239882390414, 0.015294881604079689, 0.016109244066423604, 0.005036503359276269, 0.012915122738507177, 0.09449054753141743, 0.008574155940940338, 0.025437923314582025, 0.028732314306710447, 0.0678598733086671, 0.023930795257911086, 0.04091358191466757, 0.019193014396088462, 0.060290726966091564, 0.07025752429451261, 0.03142886675362076, 0.027505735035187433, 0.0443084011785686, 0.03686692798510194, 0.05282170864354287, 0.01145863883929061, 0.05119055795616337, 0.0442236555474145, 0.04906511825642415, 0.033348004666290114, 0.01855763590096363, 0.014541127585938998, 0.05070927306743605, 0.025541571235018115, 0.02833661643256034, 0.025903953039752584, 0.04831182224942105, 0.01819698605686426, 0.00674347354963954, 0.056873322664094825, 0.05802189585353647, 0.010682857029938271, 0.01341030911342906, 0.008708954555913806, 0.008102623296768537, 0.00849323724729142, 0.03904610426564302, 0.05516224055151854, 0.03583857423758932, 0.025118104315229824, 0.04017114925331303, 0.038883245683142116, 0.03509122219734958, 0.007077378935978881, 0.04813076875039509, 0.04640710659857307, 0.028353578111689006, 0.006052123124910784, 0.02482434784594391, 0.04529063490086368, 0.0269467154783862, 0.017849537111552696, 0.03633834242022463, 0.018700849198337113, 0.04818892937951854, 0.0647050179541111, 0.013785742539247232, 0.056436105232153616, 0.04905804452885475, 0.06065833688314472, 0.020477440474288802, 0.032684444915503263, 0.009672092606446572, 0.03377187192173941, 0.03193018538877368, 0.02876153202461345, 0.01024647249973246, 0.04959693704066532, 0.0073830207942851955, 0.02273265678169472, 0.031893415576113124, 0.07088253647089005, 0.008551838076008218, 0.055750808612044365, 0.009831689980014094, 0.11319488100707531, 0.029598725493997335, 0.013834557196657573, 0.024282742890396287, 0.07579053632382836, 0.030262590585542575, 0.07155307834701878, 0.04798752661528332, 0.08474580078784909, 0.0328143029473722, 0.007222743189361478, 0.019188115373253822, 0.022916295499141728, 0.0774262806932841, 0.059261307918599675, 0.04963639385199972, 0.041341832506337335, 0.013112514512613416, 0.015008438045957258, 0.026745231289948736, 0.02646682328278465, 0.01077162382924663, 0.04535380990377494, 0.018111351544835737, 0.01803043794019946, 0.008690426309060837, 0.03251032604436789, 0.023987916032118455, 0.051891973175640614, 0.035864192327218394, 0.04998025504340019, 0.07546933141670056, 0.04293116847319262, 0.026787653299314634, 0.031287609333438535, 0.02417309841673289, 0.03617046607126083, 0.036103335209190845, 0.03671730422813978, 0.060302574187517166, 0.03099113702774048, 0.03851576129506741, 0.03896024922973343, 0.0380674532082464, 0.034483892643558126, 0.002897342833291207, 0.01727509106110249, 0.021708740653204064, 0.02260511594691447, 0.06350932390029941, 0.012339250068180263, 0.05533429328352213, 0.09200363526386873, 0.02403076721488365, 0.017121029685118368, 0.046195814186441045, 0.012645330429742379, 0.04421709750645927, 0.026799437756251012, 0.013149927237204142, 0.026470107392274907, 0.012349936994723976, 0.060359082583870204, 0.019423083568524038, 0.05475705675780773, 0.014312249242461153, 0.05463515115635736, 0.08577929783080306, 0.017058182075353603, 0.0228341757985098, 0.10611978958227805, 0.13379215076565742, 0.11335213828299727, 0.1211605564291988, 0.13821131363511086, 0.12042358597474438, 0.15234688084040368, 0.11530528776347637, 0.12831136557672704, 0.17495759470122202, 0.12927575382803166, 0.17596513777971268, 0.11753796653023788, 0.07782767486891576, 0.20483663997479848, 0.1053684274000781, 0.1427551640995911, 0.12548758781382016, 0.1509112093065466, 0.20485957445842878, 0.2739897535315582, 0.0920597297538604, 0.09677484245704752, 0.1583958848246506, 0.11284939133163009, 0.14945556170174054, 0.13609566858836583, 0.130252939249788, 0.09242586724992309, 0.11838807591370173, 0.0969045851379633, 0.17700394775186265, 0.12030393310955592, 0.12735312485269137, 0.13682650508625166, 0.12315885562981878, 0.08113376889377832, 0.1418028673423188, 0.1413682656628745, 0.13418157558356011, 0.2200738630656685, 0.11509247204022748, 0.08434249314346484, 0.1513093872261899, 0.06494205059217555, 0.10991733973579747, 0.12099397608212062, 0.15314741645540508, 0.1116793526868735, 0.10381853128118174, 0.13823958140398773, 0.1398142304803644, 0.08458701680813517, 0.15941429803414003, 0.08157238071518284, 0.16216236485966615, 0.06662232721490519, 0.17028782170798096, 0.15452902231897625, 0.1155412279601608, 0.1662469013993229, 0.2195946273526975, 0.08727892129016773, 0.09489021144275155, 0.11677753233483859, 0.16074434880699429, 0.116146074075784, 0.13750882633030415, 0.10943792081837143, 0.20960379631391593, 0.12207496379102979, 0.0776692640834621, 0.08596751665962593, 0.15219411546630518, 0.12499681700553213, 0.13696001363652094, 0.09464247152209282, 0.11073957490069525, 0.08159331352050815, 0.16112846748105117, 0.15777377677815302, 0.1404055737491165, 0.06912254555416958, 0.10475258901715279, 0.07396232549633298, 0.11980430063392435, 0.16998780066413538, 0.14231341066105024, 0.23992463573813438, 0.1279816654111658, 0.10166186200720922, 0.10675263883812086, 0.17397495385791573, 0.07838948829365627, 0.1320609636604786, 0.1398872679897717, 0.05697760331843581, 0.05487128134284701, 0.10325733532330819, 0.09057004004716873, 0.1268482676574162, 0.0775508868641087, 0.14859304869813578, 0.0818578607535788, 0.10851399361022881, 0.07600810857755796, 0.2780955960708005, 0.10235503981156008, 0.1038591144606471, 0.10081514529883862, 0.16707524337938853, 0.14471019990742207, 0.12862141536814825, 0.30310571832316263, 0.10833716059901885, 0.1776779094444854, 0.06427719483950309, 0.11192115542611905, 0.13097739751849855, 0.1352577456938369, 0.16158463300338813, 0.149276306320514, 0.18883492504911764, 0.1426020594579833, 0.08267974308026688, 0.15351705519216402, 0.06540231446602515, 0.11446963117590972, 0.09595190840108053, 0.18137194908091, 0.07533228769898415, 0.10677663862173047, 0.16034637444785663, 0.17332250172538416, 0.17501573158161982, 0.08524379799408571, 0.14437796202089104, 0.1771988637213196, 0.12843465538961546, 0.11626004081751619, 0.15666821253086838, 0.15402731352618762, 0.1265282705426216, 0.09699225186237267, 0.16197500777031693, 0.15097077111048357, 0.27884917706251144, 0.11141281734619822, 0.11011167216513838, 0.20293109651122773, 0.07854158191808633, 0.057657352914767604, 0.09444574386413608, 0.15993363516671316, 0.10028562335563557, 0.14463139485035623, 0.16487197232033524, 0.20160460126187119, 0.10622085058795554, 0.09305457065680198, 0.11245726594435317, 0.18684623390436172, 0.10162630677223206, 0.15554594275142464, 0.11616466593529497, 0.18253341104303086, 0.12710051983594894, 0.09815490804612637, 0.2013212043259825, 0.19095104507037572, 0.11132404460970845, 0.15155443336282456, 0.11727074586919375, 0.17644070940358297, 0.14409077885959828, 0.11216112612081425], [0.03247386157246573, 0.004808910839658762, 0.02877060403781278, 0.027646398737228343, 0.08916305018854992, 0.07698441868914024, 0.023510110331699252, 0.045944606951837025, 0.04408701216535909, 0.09790488824780498, 0.01875615998038224, 0.0168105337569224, 0.012611056777781673, 0.05876907826002155, 0.0023002067838595913, 0.06398959098649876, 0.014046679117849894, 0.05441201491547482, 0.03913018832515393, 0.08739690495921032, 0.051426304770367484, 0.02595571508365018, 0.04384842568210193, 0.027750720103670443, 0.04702305354710136, 0.03380800051880734, 0.018477171825777208, 0.06825089946921382, 0.050293446451957734, 0.04285665175744465, 0.02329128448452268, 0.03228986323145883, 0.09435303562453815, 0.08690299253378596, 0.02775832817756704, 0.03272537414782813, 0.014557168153779847, 0.05131177484456982, 0.040937656337129216, 0.03881062886544636, 0.021129592355074625, 0.029895991685667207, 0.01113563496619463, 0.0635872400764908, 0.0262945245818368, 0.004122195657276149, 0.03931187286174723, 0.03779340648491468, 0.02786320255004934, 0.036010023073426316, 0.04211348967094507, 0.08568885589816741, 0.014972209364974072, 0.012850805252258266, 0.06134986584740026, 0.05948115326464176, 0.04358386827100601, 0.06121152612779822, 0.015578763692506721, 0.0025740251377491014, 0.024456351163930128, 0.00596910690988547, 0.054759645368903875, 0.11426540570599691, 0.016825680354876176, 0.03342611422496183, 0.05389207049406, 0.029896958598068783, 0.05921432615390845, 0.0659124506637454, 0.023087559434186136, 0.053609989916107485, 0.022488714960802878, 0.02685769507661462, 0.009539005596057644, 0.056204935136650286, 0.026477500031303083, 0.02534251450560987, 0.03511407525677766, 0.04444852205259459, 0.023028062091075947, 0.023936995371643986, 0.02227335303489651, 0.05184751556121877, 0.08275902989719595, 0.028518311147178923, 0.033271828932421546, 0.07227065627064024, 0.02939065612320389, 0.03799279060746942, 0.037837772497109005, 0.15072934835084847, 0.03036658964785082, 0.02041844863976751, 0.07118908502161503, 0.03724804753437638, 0.00250602320634893, 0.021785812053297247, 0.005256892805586436, 0.038957697938063314, 0.06327273230999708, 0.06379062416298048, 0.08354406098702125, 0.04575291063104357, 0.03423850045406392, 0.019278981390276125, 0.051704059687576125, 0.028172792633995414, 0.01731465813437743, 0.026893601453463947, 0.021980083414486477, 0.05195597938394972, 0.05346549249121121, 0.012711050787142344, 0.03210409391405327, 0.025210814251165305, 0.012346616413976465, 0.018256666604429483, 0.08330921323171683, 0.017827579718349234, 0.03193508101893323, 0.02374655264429748, 0.07759541911738259, 0.08261377590575389, 0.037894450527216704, 0.029822004227233783, 0.01644445563267384, 0.027664130553603172, 0.025260013129029955, 0.04027516527899674, 0.014475392809669887, 0.07447694681052651, 0.02610407506914011, 0.06983036614422287, 0.08732076654476778, 0.03904093382880092, 0.02530491179121392, 0.04291934160781758, 0.04499840343903218, 0.02049996274789529, 0.07872099336236715, 0.02813708981765168, 0.04228758818602987, 0.023114968856264437, 0.06727879627474717, 0.04934521072677203, 0.04251888381051166, 0.013317745910691363, 0.019471125544181893, 0.047229633533528874, 0.018561836032729064, 0.05160216408382569, 0.04809979362679379, 0.033180908632597754, 0.019699713813939264, 0.03442633251792618, 0.026738186400117617, 0.022726466845987097, 0.02986092838857855, 0.03190543582396848, 0.05525269605485456, 0.019905862930629934, 0.06098149597112622, 0.028570649945842366, 0.047196707621748955, 0.019660874469471828, 0.011807997012510896, 0.07288698319877897, 0.02719824671346162, 0.04301316603752119, 0.020008644022579705, 0.04058829222672752, 0.019794561135183488, 0.027998476987704635, 0.017286787308486443, 0.017264868931046555, 0.045201465221388, 0.07899183061506067, 0.06727617712957518, 0.015499432770801442, 0.016215336409264376, 0.04646869382954069, 0.014143270274092044, 0.1336702180228063, 0.0508621164730617, 0.10637396201491356, 0.030131490834589516, 0.034745763055980206, 0.03463919573862638, 0.046026495950562615, 0.03891128275011267, 0.012594732073401766, 0.03884553949215582, 0.018038617679849267, 0.008603472046421042, 0.045302733180246184, 0.046739232526826005, 0.04755575781954186, 0.06993566120841674, 0.022267626199339117, 0.03907123041738357, 0.016451176522033553, 0.008448783025544668, 0.04327169466497643, 0.0852582643606833, 0.07706409227102995, 0.013705130882694252, 0.03286062992577042, 0.04279760564012187, 0.04907089937478304, 0.04503326317561524, 0.0361533602034407, 0.04245651626427259, 0.035641819438231845, 0.002728580147959292, 0.02346679095977119, 0.05181790429300495, 0.05367424378969839, 0.0638124051370791, 0.024167315602036457, 0.035976272741598744, 0.02797027537599206, 0.02391046634875238, 0.06104063708335161, 0.033931772091559, 0.014255369348185403, 0.05201088643765875, 0.09628500124173504, 0.0660028654549803, 0.04189635846497757, 0.03799443605488964, 0.058982172182628086, 0.028226396900468638, 0.04070844381515469, 0.048998944128730466, 0.020603822710524713, 0.03304145272289004, 0.03832809886495982, 0.0440539200124996, 0.04722434435305851, 0.02510418925833489, 0.04543697454833558, 0.0676880343151944, 0.024468939684863602, 0.01786394410633615, 0.059162214664476256, 0.03127485287508794, 0.014498573262244463, 0.042529516454253874, 0.046352769514279704, 0.0039554617916499925, 0.04654907648052488, 0.02615390159189701, 0.038148392257945876, 0.05379321472719312, 0.037569635813789706, 0.035265816042998006, 0.051826664180095704, 0.022818659398970858, 0.03811023484117218, 0.03448657285688179, 0.010785911232233047, 0.050557956365602355, 0.011433108959213963, 0.021948813128152063, 0.08624584493892533, 0.015809409619708146, 0.07164154574275017, 0.03620049124583602, 0.010999319825454481, 0.07469069212675095, 0.035361876245588064, 0.01175380835775286, 0.044008916177387745, 0.026549509560157145, 0.01805486689720835, 0.07263003555791718, 0.00966165928236608, 0.051583541690238884, 0.09672839673502104, 0.045800784669284306, 0.03080485202372074, 0.07162688260099717, 0.031149055875305618, 0.05086894592802439, 0.015989543703783835, 0.062294990489525456, 0.008977612014859915, 0.023044474156839505, 0.033074164896139076, 0.034779805157865794, 0.007219314043010984, 0.05045393016189337, 0.02864969927551491, 0.05469984947038548, 0.06355880945920944, 0.011469986489308732, 0.04245623806491494, 0.05104679674176233, 0.018555846264851943, 0.013928318861871958, 0.009823465287419302, 0.034663243019687276, 0.046036405954509974, 0.019112940478537763, 0.0371621416083404, 0.01752993693974401, 0.03746598280434098, 0.008620838302054575, 0.07398179266601801, 0.0432173881147589, 0.026621851571170346, 0.06955933890172414, 0.02916743845811912, 0.050050890538841486, 0.052727195500795326, 0.04135296048064317, 0.04873300929154668, 0.029542247631720135, 0.07205984901104655, 0.02261474944784173, 0.006494894365979624, 0.0360507962426969, 0.019699121792135493, 0.03207889651613576, 0.0021677927953922854, 0.007590532918194575, 0.07054299754755837, 0.048808876291981766, 0.01749919930339924, 0.021422845012109195, 0.056092332250305584, 0.043017922568001916, 0.025762826237561445, 0.022574261263278977, 0.05405364325270057, 0.0071488151027421865, 0.037339866893099885, 0.003940546743771327, 0.07046178369117634, 0.03901743616110512, 0.04087443383676665, 0.011469842300617268, 0.0700786081807954, 0.016274679385657822, 0.051656857399003844, 0.020990497765264342, 0.05290360103494354, 0.03048336213188512, 0.02962686773389578, 0.015725846335824047, 0.030488003311412673, 0.17644814614738735, 0.13657314011028834, 0.1934206818363496, 0.11169814810689006, 0.10177130292036704, 0.17814984412065574, 0.0764029413195593, 0.25657300810728756, 0.15288582763501576, 0.28927152923175264, 0.07848090731671878, 0.1129160506118621, 0.18023034105343477, 0.09713047623102154, 0.1079207436580743, 0.17864347834672245, 0.08840186281927995, 0.1881635282188654, 0.10723004929189171, 0.2175095435231924, 0.23217967418687685, 0.12560466224593775, 0.15995514472680433, 0.11182262535606112, 0.1174207292497158, 0.10240058308201176, 0.12496688004050936, 0.142605614981481, 0.17936325472380432, 0.15379582451922552, 0.07667613987411771, 0.14357380302889006, 0.12459141947329044, 0.1538409199565649, 0.11737158974366528, 0.0773231094436986, 0.10925611414547477, 0.10269769999597754, 0.1157926387552704, 0.1131934289421354, 0.10153283857341323, 0.13477737004203455, 0.12883216834494046, 0.14134649825947626, 0.18431187846830913, 0.17642610732998165, 0.14855781915996755, 0.0951966717839241, 0.06770233104803733, 0.11636476591229439, 0.17912436968513898, 0.18651799937444075, 0.10871187477771725, 0.11572880218071596, 0.19260725405599388, 0.10016526481402771, 0.12399371154606342, 0.1315747390368155, 0.09161475327398096, 0.1289157231471368, 0.1542757794793163, 0.11769033835402556, 0.14469460717269353, 0.16598082067711012, 0.12155429672982011, 0.22925725100295885, 0.1658407710492611, 0.12657473662069865, 0.13100170264286654, 0.1477125680872372, 0.08877899258264474, 0.17237925662526063, 0.12738938576408795, 0.15776495582291059, 0.04685607286436217, 0.2307267678635461, 0.14753670538110392, 0.09113161598465272, 0.1833309746746506, 0.10815362366182463, 0.22617754340171814, 0.2178446448275021, 0.2277322028364454, 0.09125799991722618, 0.16990499225045952, 0.11395760865083762, 0.16660558858088084, 0.1250312187309776, 0.08724709799779312, 0.1718289511544364, 0.0705499118193984, 0.24223173622574123, 0.13956967288894312, 0.09562515986285039, 0.15213956125080585, 0.14618347585201263, 0.0962104709552867, 0.11040462965943984, 0.07740096455173832, 0.16546487621963024, 0.139992943033576, 0.14942935667932034, 0.1233763261032956, 0.21754798931734903, 0.1593400663030999, 0.11679184942373208, 0.1488542439682143, 0.11363818829080888, 0.1275949275919369, 0.07457382125513894, 0.10430931566017014, 0.13313076911228044, 0.12401166558265686, 0.12427598211382117, 0.10821300226130656, 0.061445383221975396, 0.0725660700617092, 0.09201757915850196, 0.18731020257941314, 0.14868266960339888, 0.14322426249938353, 0.11837071898792471, 0.12686916653599056, 0.16361729321735247, 0.114718192123941, 0.12611227429338864, 0.1202432042253869, 0.12287307025066443, 0.1024910317999976, 0.09954689549548285, 0.11908057518303394, 0.1731872289840664, 0.0743483304977417, 0.2013676975454603, 0.18592430837452412, 0.14096350595355034, 0.20803590544632503, 0.09073946345597506, 0.08852477265255791, 0.1327352374792099, 0.1305755012269531, 0.11399255320429802, 0.08304811295654092, 0.1306547269757305, 0.1258336678147316, 0.14197788866502897, 0.2256231124379805, 0.1653782408684492, 0.12433642601328236, 0.09887491512511458, 0.0909125441685319, 0.10457629204860755, 0.18631511740386486, 0.16092760754483088, 0.11754372050719601, 0.1682321455861841, 0.1030981849346842, 0.08609282172151975, 0.10102483297565154, 0.18608845956623554, 0.09533855345632349, 0.12233599621270384, 0.09785038152975695, 0.24457469050373348, 0.1807537901082209, 0.14748809513236794, 0.10898162637438093, 0.16573789156973362, 0.09966835326382092, 0.09758326264896564, 0.07738795703543083, 0.19430805636303766, 0.05930457131138869, 0.05255037945296083, 0.12365744316152164, 0.10677750036120415], [0.00808211203132357, 0.052496025405291996, 0.019007592827879956, 0.04127276781946421, 0.09631311294755765, 0.06485062478376286, 0.027916654146143367, 0.03647317750645535, 0.014065653501477624, 0.04580219941479819, 0.09371650870889425, 0.006580812166378434, 0.03443513650979314, 0.027592183789238334, 0.060215843841433525, 0.05504779204992311, 0.004515967764226454, 0.05866182901497398, 0.004585156283740486, 0.04718839217509542, 0.0871122188067862, 0.03667519095220736, 0.06365334295800754, 0.030873641903911318, 0.0839502727612853, 0.045883263993476114, 0.027372608160866157, 0.04313412168994546, 0.0253730468851115, 0.03552252958927836, 0.044194627819316726, 0.03844577380056892, 0.06546017993241549, 0.029474082003746713, 0.05466737478439297, 0.014697660525728549, 0.021627352074054734, 0.04067077833626952, 0.07068383427602903, 0.014532644201868346, 0.0072566037831295815, 0.03985153211812888, 0.006402395199984312, 0.016934468178078532, 0.04300079295145614, 0.009703540160054607, 0.028967077245137522, 0.06225247348525694, 0.004601770637756479, 0.031410088296979666, 0.04514779310141291, 0.003444655328556629, 0.028030413934694867, 0.04994381092754858, 0.06058948593480246, 0.03235636644863656, 0.011335121717170944, 0.026090998002993207, 0.05092639070270317, 0.06065840473664658, 0.01660724975434797, 0.026262563886120915, 0.017559354825477515, 0.013470913316788418, 0.020235356143010513, 0.05362529766612819, 0.0290781364643148, 0.008453045921799327, 0.07207061736179249, 0.044686131445424895, 0.016195270432425395, 0.08136051494096007, 0.02389673619265003, 0.023887872828968933, 0.048445795596178086, 0.02204176564035671, 0.01439964964187571, 0.05200624865080629, 0.014027074544823595, 0.08915302822632448, 0.034952404110559394, 0.017283143575436304, 0.023374907140220915, 0.032375378999859095, 0.008941629302820988, 0.014238051438171948, 0.015417046745174696, 0.09918660697128091, 0.031531033771378655, 0.04096250428951212, 0.019344577066866413, 0.036878293446664295, 0.018028777225741317, 0.03317996546892183, 0.05256068979256919, 0.0365101542722966, 0.03638191115377205, 0.03857798295627747, 0.06197202139134918, 0.044563089297818284, 0.042695587900068076, 0.025968081384365047, 0.016753138176032474, 0.05526532359155161, 0.0467280909818198, 0.02005699642800859, 0.05664756388536521, 0.02979060501924583, 0.030275072237210612, 0.019909286139799014, 0.04006304166146687, 0.028395102758492743, 0.0670663673164589, 0.06126505575541939, 0.04211627505719662, 0.04411782104788082, 0.04253313643857837, 0.03186925294409905, 0.05173040720235024, 0.026949960572112883, 0.024003549478948116, 0.04462782832394753, 0.04175026309011238, 0.03809769551402756, 0.1388711617993457, 0.013955810556321271, 0.05325671744399837, 0.01898288567151342, 0.02814788700613592, 0.054430443926581314, 0.06647918346737113, 0.01591456219154809, 0.02893476201487439, 0.010873347254736083, 0.04288627320368375, 0.01568145996757916, 0.016113244030358534, 0.016769579079534327, 0.016172313896406974, 0.08665449943925653, 0.048541129766298194, 0.05869648179837635, 0.023800302795799713, 0.03059414993705494, 0.04048763155671103, 0.02703391231729516, 0.024598622993965234, 0.07723837399056979, 0.01193488815001079, 0.04275486132662211, 0.006817381704292659, 0.031688474251755645, 0.03043651268152254, 0.03657538862898946, 0.011826806851396603, 0.027176811792222515, 0.034700039973748584, 0.02015332974094365, 0.03920880678508963, 0.0759676814611469, 0.08410197962075472, 0.03858288537178721, 0.04923786987949695, 0.0584432864561677, 0.03630868365455951, 0.01289778107976807, 0.025429243155355965, 0.014164248880531107, 0.04881707299500704, 0.010386692609504929, 0.01619540953210422, 0.031740032735147646, 0.05980754896466221, 0.020049639412068894, 0.031020710976528268, 0.017304597156388418, 0.006586684886964836, 0.04310572839209011, 0.032896181768072505, 0.0957699388797794, 0.11121510581246444, 0.0269731970038265, 0.05062929414478796, 0.030707936867007186, 0.0368980727424579, 0.06269520401422467, 0.09009948279708624, 0.023239066125825047, 0.03335368061172111, 0.0734226865960019, 0.04956393988270845, 0.028958490384476523, 0.04710677798305239, 0.04541634369109358, 0.018005549275715436, 0.0215889894004379, 0.07382720203271934, 0.03190524583416326, 0.034666798543184996, 0.019562125571870377, 0.046062448128525696, 0.027201405293973427, 0.021696242038160563, 0.06880202596741063, 0.02816143226144569, 0.060690377306725295, 0.02831573791003653, 0.02844127028116158, 0.0317744446386184, 0.04664252771596823, 0.05877188739499875, 0.03576399306101458, 0.04008235955344779, 0.052001339449946365, 0.03993496139134679, 0.03129904943385294, 0.06474480724760465, 0.031699286707277806, 0.04012709875990238, 0.041203489394060204, 0.019615066570362875, 0.01806976752621787, 0.003856878286959337, 0.05601388681679964, 0.021596276866538183, 0.02784409330758665, 0.04578842515391963, 0.0281140874805195, 0.019173243581982594, 0.04927799504782472, 0.04045829509517976, 0.04257136849420411, 0.01762169523031584, 0.0921905105933547, 0.04375989382554378, 0.021186316186296086, 0.024341958641473736, 0.029036155502711023, 0.013231344654091766, 0.02225476287172309, 0.029972879881305352, 0.041330928448587656, 0.004718431587597089, 0.03405443765223026, 0.03236288717016578, 0.06325331942311355, 0.08148323478443281, 0.025609392506469573, 0.013549670028234167, 0.05207299614059074, 0.01786192716099322, 0.044332336501351426, 0.022584132251462767, 0.03580480694238629, 0.011085191824739533, 0.012035845679097941, 0.03158922154190285, 0.028113955166190863, 0.02113413005801184, 0.0654395388971482, 0.07114816935999052, 0.015489831500287567, 0.03433340714712228, 0.05103783668684108, 0.006248561557315822, 0.06275239773094654, 0.0249467742230211, 0.03785738894449813, 0.039517370584819994, 0.04953611655426877, 0.025546176791457192, 0.024089726818991557, 0.029712912759610584, 0.025326908200180957, 0.052286086670522175, 0.030148891865142753, 0.02210198562326176, 0.02487369769785021, 0.009868171415291727, 0.015325108642822929, 0.01925367712309318, 0.057528044496263774, 0.02412923112777727, 0.04150155625705208, 0.030028655459838252, 0.023108102081875716, 0.04977386843945299, 0.03748713952622243, 0.05689791616584573, 0.05358279083988496, 0.053293378691055944, 0.017729592476306216, 0.06386176855968577, 0.028685274866542647, 0.057370732937540324, 0.017012431851721237, 0.015657835074567368, 0.041205446967589, 0.0332658306828567, 0.013441439451915877, 0.03792226028495601, 0.019055195452113236, 0.024403644260019064, 0.03684579501194613, 0.025988484932375804, 0.01315197641296046, 0.022342346475592682, 0.03450672873961074, 0.06353366295141832, 0.030162476136216095, 0.09726680748696838, 0.025474499744762267, 0.01346033750035401, 0.07057699215199266, 0.01794038277252444, 0.016290847178814665, 0.0543637303635478, 0.045819156004914215, 0.019374342701796974, 0.05928230857742684, 0.043574283963867595, 0.029256933834403753, 0.034472208270537, 0.025497398605304103, 0.04618921543338469, 0.023474896060568944, 0.025153557769954205, 0.03667181524048958, 0.026479386358654926, 0.048545743804425, 0.046490722468921115, 0.04840697321508612, 0.0633039992036564, 0.024931839667260647, 0.05567375078265156, 0.06184114555695227, 0.051505140361509154, 0.03737470627363239, 0.031072734256408045, 0.008415863050946167, 0.06253652860011373, 0.023681532026135495, 0.06680691588137831, 0.033110419022185464, 0.05870408817593541, 0.008659747196361423, 0.05248170153104833, 0.06944436792816434, 0.058541029425604005, 0.008312947948330214, 0.013925095820533378, 0.03955671204520123, 0.1123156760420118, 0.13368278449135168, 0.11644065326878003, 0.17896108701825142, 0.24382436648011208, 0.21394224065755094, 0.18406105121331556, 0.10597907499011074, 0.09013651045305388, 0.12999034619757108, 0.14914293347724847, 0.12130462298435823, 0.11937660644096987, 0.1413177012332848, 0.10898968737040247, 0.1077982477311577, 0.09032479035002844, 0.1622410477804286, 0.12322992538767201, 0.15268209071031638, 0.19398245454898902, 0.1337140920971121, 0.08236927259713411, 0.08821601207767214, 0.20695886681122438, 0.09975031350872346, 0.13939645646938256, 0.25469159334897995, 0.12430943389024053, 0.19770598331732409, 0.10968653604920421, 0.09648706218493835, 0.11227582568036658, 0.1393699393208538, 0.16900126502982207, 0.09107415085392338, 0.1620041983468192, 0.13328969558434828, 0.19017062123332704, 0.09981910338891403, 0.13108783587813377, 0.13574834008302006, 0.12229797111025878, 0.11738577112555504, 0.1623750991587128, 0.10581552769456591, 0.10891769480492387, 0.20636163385851042, 0.09669592204902853, 0.12241108289786748, 0.10967605946851627, 0.17142381146550179, 0.07076967574123826, 0.12176951446703502, 0.11449107288249902, 0.08286067444298949, 0.0882711566186377, 0.18862901681235858, 0.18286836306963647, 0.11982578305261475, 0.1514340748212167, 0.09889917953738145, 0.1487424485385418, 0.09012247834886823, 0.13680306848670754, 0.09883284595395837, 0.09224955671067749, 0.07728697745395557, 0.1284503431192466, 0.19388161067451748, 0.09402107593736478, 0.14155166010771478, 0.07835226386253323, 0.17130057593541487, 0.12033937977893011, 0.12833465289856705, 0.07239938793437821, 0.16965009378535406, 0.13553149386176042, 0.19051054013626917, 0.07538737117179803, 0.1702132099973304, 0.1476032832371337, 0.16763590329459735, 0.08467863260635308, 0.0562086942206536, 0.1586045886256865, 0.2036437482706138, 0.11014730203896761, 0.13090972043573856, 0.060648043506911824, 0.12929003020482405, 0.12853422361825192, 0.08394031865256173, 0.08190425897815398, 0.1206442727042096, 0.0891082449150937, 0.11826356473777976, 0.0702566761257393, 0.16307309456169605, 0.1267791385097163, 0.07691465171852283, 0.19171882101467677, 0.08716179257524864, 0.136069477136646, 0.0953427128759878, 0.2144714029771941, 0.056711051014385054, 0.09380254694925887, 0.13061845249363355, 0.1730197529707636, 0.1551386724625315, 0.1474703989390816, 0.11158628482371569, 0.16151414678565093, 0.11125219453658376, 0.14288111376975263, 0.15159791388681956, 0.16423058030860765, 0.039639910616512807, 0.08321090707821505, 0.14375780815524714, 0.08170164163623538, 0.12085536494851112, 0.2524870330733912, 0.10356375495237963, 0.06954355617719037, 0.11266882637781755, 0.11497332129095282, 0.11985870557171957, 0.12512344521071228, 0.17479220857577665, 0.12173220861170973, 0.10169788543134928, 0.20320468183074678, 0.13258137287838118, 0.11122784870011465, 0.07978385061557804, 0.1016690069809556, 0.12163308821618557, 0.1235542922679867, 0.1380722682390894, 0.06680137903562613, 0.08882520760276488, 0.11105634218880109, 0.15094603172370366, 0.08726339640894107, 0.14613235502370767, 0.15380410264645303, 0.18760368254567894, 0.12191839862082686, 0.14775566863162176, 0.09592410203601633, 0.07347859788153853, 0.10525693052581378, 0.20482666551002435, 0.12766962072678975, 0.08831862692854234, 0.10668074805289507, 0.15474323582436356, 0.1378204096108675, 0.09155027887650899, 0.2702376991510391, 0.12361008141721998, 0.20890263893774577, 0.06578667062733855, 0.18034770047026022, 0.2162601298519543, 0.09812870980905634, 0.04836444603279233, 0.07395214068570308, 0.14319603544260773, 0.1809156071394682, 0.12678946581270012, 0.13392641927514756, 0.14300276152789593], [0.02476782418255295, 0.018617206186588322, 0.05018103355541825, 0.08780970530850546, 0.0191495711915195, 0.0743561607918569, 0.03196707733773759, 0.07696707533406359, 0.06490786599793605, 0.057988688349723816, 0.028594914358109236, 0.015081161732918449, 0.07060675948326077, 0.0029702183424628204, 0.03876705334654876, 0.020072355068155696, 0.022317498523209776, 0.0184264207990574, 0.12478957884013653, 0.043125901238194535, 0.019906098721548915, 0.020242146582209637, 0.060033535052623065, 0.004788711700322372, 0.023075990412118177, 0.029393600965184823, 0.06679961484457765, 0.017366331968722597, 0.017035905770691376, 0.06179643688457353, 0.08551133078123842, 0.06438084106360163, 0.014064744264552636, 0.04528468754142523, 0.023154649584154998, 0.05778852730457272, 0.07695245968976192, 0.041035216102110486, 0.0156249363041882, 0.03042578504287771, 0.036736231962484975, 0.018603584596088955, 0.0093500386823767, 0.02237272957739021, 0.033712798663015874, 0.01543047495319375, 0.052577683702111244, 0.02856808847614697, 0.023183136180575405, 0.043496649379708936, 0.010990490388524319, 0.02704285710517849, 0.017890895517276864, 0.022852106086377586, 0.022870703034901192, 0.0310418812691101, 0.052273404851023636, 0.04212186618575028, 0.021539322333410382, 0.046090173069387674, 0.03726511947544558, 0.02212044347210654, 0.02532976652894701, 0.08854173602802412, 0.06043768408043044, 0.05083055441666927, 0.08216533889727932, 0.014060439808028085, 0.027236463502049446, 0.02133015203954918, 0.05158888854618583, 0.030351007091147558, 0.025556207235370363, 0.08685516938567162, 0.03008843439498118, 0.07644624542444944, 0.04489684371011598, 0.04251854454300233, 0.047342830138014894, 0.08657939239804234, 0.020868676980691295, 0.01862158443379615, 0.025931774671854715, 0.03992814889975956, 0.02449064262743507, 0.02407869214325079, 0.06118694280407258, 0.040205517052007575, 0.04043733175577862, 0.02683027378017349, 0.03403364394658378, 0.004431729337998799, 0.04457283645336117, 0.01992026822907584, 0.0333971068529146, 0.0665792945240225, 0.027502333878406456, 0.008678727517170566, 0.038063761977744956, 0.09227587708405086, 0.07809554692357779, 0.008190815037648593, 0.056996303743549755, 0.05465207721239754, 0.011155136910799359, 0.06382160607193198, 0.012454439869283565, 0.050253358603055985, 0.011150804464705288, 0.055454336306346316, 0.021714920410886407, 0.019981889386794398, 0.015814669962440218, 0.04664888558909297, 0.057809690811804364, 0.022021173798878278, 0.004902898541851235, 0.012245363722156202, 0.027913466727893268, 0.024145035904699137, 0.01172426070219704, 0.035045977482306104, 0.06375749808337007, 0.04960144590586424, 0.0652765751417194, 0.00818212894124112, 0.04165684238874486, 0.03525444379608546, 0.032211370300501585, 0.02462770670120205, 0.02415897979933236, 0.041539024960781844, 0.010426123975776136, 0.010997778702793377, 0.031847166629242044, 0.04368932957627943, 0.10756968999547617, 0.03163443233019539, 0.055899984535894225, 0.03586846370516079, 0.04195301274635962, 0.02224934646593673, 0.06605613723929439, 0.03652022373197334, 0.024333973980641792, 0.022186118876561522, 0.05117190842117582, 0.027903588954359293, 0.05191907725696053, 0.028929835850639, 0.017031488507719975, 0.029552849741386514, 0.02424735389649868, 0.07565569105957236, 0.013178731048745769, 0.03461171846304621, 0.006054294861054846, 0.04131642136988895, 0.0148854196470763, 0.0061989067887355176, 0.02762644811134253, 0.024332932429388165, 0.024252242741308043, 0.03779439375336681, 0.010594900231808424, 0.04378437536901661, 0.010524380087320293, 0.00504439853830263, 0.05653258612645524, 0.03910332512376564, 0.01699371955224446, 0.037899858451315334, 0.04836217633315495, 0.021092800490025963, 0.04027412033506802, 0.017536020006186197, 0.04189805480252419, 0.010495044473957802, 0.005316307028156838, 0.029870756968323673, 0.03040968340688518, 0.029040491341480186, 0.025820712060002343, 0.07420374147061791, 0.005255424625439835, 0.03735364793932863, 0.02390381840190717, 0.021360574157110283, 0.036665535398891995, 0.027132009821278707, 0.03252570843324065, 0.05503968016377517, 0.060319123656622, 0.05661023428131427, 0.03171072680769222, 0.10720560846051999, 0.006701625326448786, 0.04795333184301853, 0.02035914976815028, 0.08100482688418456, 0.04276935822729554, 0.019900851949517216, 0.018493110613365258, 0.01816841633990407, 0.020287672889285853, 0.03113110862406237, 0.03547519498637744, 0.04993161426058837, 0.002164729421825281, 0.027476267955665077, 0.010057173952061151, 0.056808722737644396, 0.038047897829008956, 0.0409995658722307, 0.028484262259943143, 0.01309250621125102, 0.03268359674672995, 0.01541339622677437, 0.046722605026194027, 0.0660659692117146, 0.036843409961355586, 0.021484226986233677, 0.0806672964245081, 0.02861204058197992, 0.015133441159767764, 0.019463883879195367, 0.04247407675055521, 0.04180360612060342, 0.037594799284956286, 0.022641504083627036, 0.09171771417771067, 0.031069772451051643, 0.03293214751673596, 0.03325718953939421, 0.02389370823012931, 0.006927800980130476, 0.03438713354989886, 0.07551627925464086, 0.01338616683746555, 0.08111869184566395, 0.0508611597386854, 0.08225073252937623, 0.05319820058399013, 0.040637659042009285, 0.0220743777296905, 0.06675802743328468, 0.01259820702086602, 0.04916810630155461, 0.11869490944913455, 0.08389793735529695, 0.004868872555172337, 0.03592300774263484, 0.027044146321713924, 0.06305634070719991, 0.0676818121490734, 0.04319153593054839, 0.02204795727240188, 0.022317413706332445, 0.0446844215371779, 0.030572148439075266, 0.03834582559232201, 0.04810193779745272, 0.06686697980122906, 0.03316743292712739, 0.022762458039713756, 0.014318042235182864, 0.05327997083908745, 0.078543352894485, 0.01637330953963101, 0.02773236233874091, 0.039472963860524554, 0.030485441841717278, 0.044170139490493705, 0.008382230614578086, 0.019962142321414182, 0.04697782579543335, 0.08046199208391563, 0.019089753240613, 0.06605611688324384, 0.017609081264319162, 0.03156959491648844, 0.07317276857793331, 0.03465298017753022, 0.057493608844067366, 0.03152954438701272, 0.025884345074051192, 0.05023250722193292, 0.02350936394317874, 0.04059265859957252, 0.04744807431208236, 0.032918570031012805, 0.05409899653334703, 0.02542629831337503, 0.01432476142820503, 0.09840129768209797, 0.04406543814444116, 0.01805141824297607, 0.03434543078765273, 0.004570472361852548, 0.022796276225043193, 0.032457505485841205, 0.053802714217454195, 0.07090460921504668, 0.03590958631996598, 0.031178667143519436, 0.019447743227439265, 0.06848671074424471, 0.03428067819082311, 0.0485821913129517, 0.04070832167885133, 0.024682266005714024, 0.033187066337891986, 0.023760869733190963, 0.028876177301364284, 0.03276881056704691, 0.03794251794793776, 0.015370478886844856, 0.038214094803801606, 0.017026765903990184, 0.06183026185525315, 0.06970290334096976, 0.023356866590412598, 0.05118702618139131, 0.050563303221549304, 0.017829635679455738, 0.06849811691790819, 0.02817374258302152, 0.0713284086169941, 0.03953521605581045, 0.1121288210685764, 0.033023709032152376, 0.07556764435555254, 0.0021923279855400324, 0.06795899370419127, 0.020374257350340486, 0.021635765908285975, 0.032999593897589614, 0.024291378944846134, 0.006472945454463894, 0.018323656670483093, 0.03348562853144748, 0.04110044028077807, 0.024161946693701402, 0.08087172545492649, 0.04012606060132384, 0.017495911801233888, 0.04404170298948884, 0.08676037804356643, 0.04384667506175382, 0.036645722176347456, 0.02361457927950791, 0.06303401690508638, 0.13201835166130746, 0.07986279816499778, 0.10976895091256925, 0.18087121737854822, 0.18867575430444308, 0.21263781136700086, 0.09885924775153399, 0.16792562417685986, 0.0992230578724827, 0.1837038296673979, 0.12207452952861786, 0.12839042847709997, 0.1129513005060809, 0.12458520409251962, 0.13457953637199743, 0.15559721285743372, 0.18939562567642756, 0.13673117091613157, 0.1930039527692965, 0.19911573481346878, 0.08219273135598217, 0.11549700104764529, 0.10930452761905533, 0.16243867788996014, 0.17509208034191812, 0.12534635753503867, 0.13303310078169617, 0.08418700005859137, 0.11235072237572499, 0.10979617373751742, 0.12340479743267808, 0.1439634042658976, 0.05285460402124694, 0.09186450165829488, 0.09838658704289369, 0.15977529223476136, 0.16529457750064985, 0.08368276033018317, 0.11602007012282099, 0.09010396112820931, 0.08973214429404054, 0.1158775913396052, 0.14782052300870419, 0.13808305694588593, 0.07748394938451902, 0.07864218151995114, 0.16033513790794782, 0.1165622603148222, 0.08322626232568707, 0.21433025412261486, 0.09230145106890372, 0.0838535815211279, 0.14521147443779878, 0.10033744986035995, 0.22593245655298233, 0.10385183377989701, 0.1421144370521818, 0.1191723674003567, 0.06725119347018854, 0.10829159018716641, 0.09368942159094981, 0.1489373237958976, 0.1302648407540151, 0.21840820887259074, 0.16724793054163456, 0.2231267685336726, 0.11548934717263494, 0.11278752929397992, 0.11451871639915875, 0.1390585731714964, 0.08762688761843102, 0.11268615616219384, 0.13979472938392842, 0.249826795820679, 0.12170379156512873, 0.1458699791026967, 0.140043263190559, 0.11727252363094262, 0.17107129895261355, 0.18505757488310337, 0.12323140459401266, 0.12844614977283136, 0.09318712925804512, 0.12285968954009668, 0.08057413356644766, 0.12053065880068711, 0.12015747811113085, 0.17125486981655869, 0.14423613463129314, 0.07815652008035354, 0.0990116602874228, 0.1474926955997944, 0.09676479335342135, 0.1048149870974677, 0.0871735108750207, 0.1860650365373918, 0.1276009122708014, 0.23181231532778057, 0.08972196626876082, 0.2245302910783461, 0.17705506858016762, 0.12764907468642506, 0.20432079051222118, 0.1375048772564956, 0.09046600027275936, 0.118049880489707, 0.11900204153997557, 0.07699695801628487, 0.11218682224197046, 0.17086980119347572, 0.09115368872880936, 0.14875097093837603, 0.0930699191189238, 0.15883279352315835, 0.13093277705567224, 0.12220499824200358, 0.07990068756043911, 0.10256052735660758, 0.2027068678289652, 0.21458222131643975, 0.10529194971812622, 0.11325193901679345, 0.11562647909990378, 0.10272918402084283, 0.13730063821588243, 0.0923140582495502, 0.209318608045578, 0.14906004363937037, 0.11115309449711017, 0.10386172003511872, 0.11150477241192545, 0.1435185702783721, 0.07501173418547426, 0.10256356719349112, 0.10849008203617164, 0.11003655155322381, 0.16471449791320733, 0.1264896754707609, 0.10695730535579578, 0.13622582517564297, 0.18532345204481057, 0.1494551274393286, 0.13985978732151644, 0.1639534258948905, 0.11593756026455335, 0.1422502661922148, 0.16821887344121933, 0.12057973045323576, 0.09626075040016856, 0.1405904066881963, 0.0707882743860994, 0.18576354985790594, 0.10009541641920805, 0.1779728957584926, 0.077328435943595, 0.17243001104465552, 0.16042237036994525, 0.11189729813486338, 0.07584465627691575, 0.22146146717880452, 0.08050503156014852, 0.05994590225496462, 0.19144763770912374, 0.09681714233011007, 0.10953504632094077, 0.13498663024178573, 0.15476006349282606, 0.10267862637660333, 0.10227618725704295, 0.1694753710180521, 0.15801453457346984, 0.25746748011027065, 0.16999941718365463, 0.06349976334188666, 0.1069125695420163, 0.14835800416767597], [0.03542673062267048, 0.06173477840742894, 0.07275817011083875, 0.03825830136026655, 0.011676098286573375, 0.04247827688232064, 0.008753744652494788, 0.005450134489884866, 0.0045355591906367666, 0.04576405896139996, 0.01478636880139155, 0.049580502922513654, 0.07201163909797158, 0.03916544161204781, 0.03192031270425234, 0.018157303632636155, 0.024932318034448793, 0.050713079648890665, 0.020067238914115087, 0.031360100622155836, 0.023626272134216766, 0.030919361593467847, 0.008550391948249723, 0.04276047281122633, 0.0120279594058437, 0.031766013841011694, 0.04214417641716344, 0.02324648929892906, 0.07093385407435042, 0.006697930703272245, 0.03543540230020881, 0.0476856633488621, 0.019051746797880957, 0.02026587155913668, 0.006954433479612427, 0.04613795889807599, 0.033352401573210955, 0.01486376759463123, 0.031045128059174334, 0.05185611599258014, 0.05427174137106963, 0.012364333811482149, 0.025624561156811457, 0.04050337356914367, 0.05821799925927605, 0.054132024225379737, 0.03489339191998754, 0.02117261317159448, 0.014672151001702462, 0.013480774126946926, 0.038409604491399865, 0.026442328168611442, 0.0776630419173411, 0.03374018433636852, 0.024415550853258798, 0.006289400883750724, 0.023316461526389633, 0.0038505742725517067, 0.018026499044416205, 0.075783282784479, 0.026991714224485413, 0.05372824499915753, 0.0662113114127091, 0.034821674161191495, 0.035324176839951954, 0.028007598194692816, 0.02091956201807729, 0.04152809376163142, 0.0292604248970747, 0.0195996400767139, 0.07921037317386695, 0.031661719615970335, 0.00761762003613902, 0.001102992917627229, 0.012601150166509407, 0.030402097385376692, 0.029589833292577947, 0.020556321866544228, 0.04430460138246417, 0.06653785639043365, 0.004226613290874022, 0.03222895792818495, 0.01116780431142875, 0.041640296312315125, 0.01879276694463832, 0.010615187580697238, 0.005484062513070447, 0.004678164775084172, 0.030713911367846385, 0.07133967908365385, 0.03635063747476254, 0.015017364174127579, 0.043449202818529944, 0.06267665286681481, 0.005988788666270141, 0.0254324136102306, 0.023967386955129247, 0.04503804345482162, 0.013889167391295944, 0.022145944514444897, 0.056468529028019736, 0.02803590497933328, 0.039925221021154096, 0.020520257730303065, 0.013727252820639737, 0.050660269268389256, 0.01715250183562083, 0.0504996498514499, 0.018892056973917142, 0.05823275739593165, 0.014632478755499636, 0.019698112471295253, 0.023441798818696822, 0.025913137011229992, 0.037455163563468626, 0.02740502856405718, 0.04529556106509907, 0.03409818959023271, 0.0109872877032363, 0.016896755201742053, 0.06242338288575411, 0.04358639581395047, 0.03396802282493029, 0.01671453971149666, 0.018477724831817404, 0.053152735345065594, 0.01293938375809895, 0.02640375854181392, 0.03889270106862698, 0.031665611014302285, 0.01427467875847859, 0.0357810039339321, 0.03758197497310383, 0.06818230636417866, 0.01865442722503628, 0.024826961902103255, 0.05940096399613789, 0.023773565123389875, 0.012095198833516665, 0.035769384021737745, 0.02056707495025226, 0.025423450162634254, 0.040713254628436904, 0.038172242763851366, 0.0477721629930394, 0.015323736305747713, 0.026660624758473465, 0.055523624909775596, 0.015200953697785735, 0.03302545965250049, 0.02697242856291788, 0.022231117622660737, 0.02672430018096098, 0.021842685162222812, 0.02867661675970469, 0.015298255619459918, 0.035239227648292265, 0.03254106028803757, 0.008404417861519116, 0.02328921664905335, 0.03480340799848948, 0.04345036989876202, 0.02617179964935141, 0.0246224107353815, 0.03248725585373385, 0.04303209716454148, 0.06046941237790244, 0.06376595262970243, 0.06265703641942569, 0.011456685506605675, 0.0396564804416682, 0.09347849898040295, 0.01763365271368197, 0.06349517644516059, 0.03862712585500308, 0.019151379487344196, 0.023199979116075804, 0.10166199771421296, 0.049966219546539445, 0.06068029427634818, 0.03979768697172403, 0.015844496665522456, 0.04590473962681634, 0.08323248449180808, 0.034254367995475016, 0.017108195195240632, 0.04079892985256655, 0.02914472110569477, 0.14872423665864126, 0.0042212732202772585, 0.05081560629020844, 0.04320254855390106, 0.005536639223074806, 0.0308391112568123, 0.036603235706154785, 0.020480035870735134, 0.023920227074995637, 0.028223216267568723, 0.06888872917209353, 0.01721623832626002, 0.022098296089097857, 0.034018712783498425, 0.044576992480350394, 0.08472077641636133, 0.05957821091370923, 0.039559164949293645, 0.02212344090055142, 0.02643575146794319, 0.026584128416808586, 0.05314015530581985, 0.027202938783115575, 0.04754540676783238, 0.027688283007591963, 0.0050733295751602524, 0.14545060374907084, 0.011845627716476364, 0.029063497071287463, 0.07841219207538025, 0.05924006298716579, 0.038743345332997184, 0.04515285836532712, 0.015573501653437103, 0.058761404028960636, 0.002587240031321666, 0.01609696088624852, 0.01623858810801591, 0.045033442987395186, 0.02952923672273755, 0.09527018426784448, 0.019139008097616688, 0.06348729865359408, 0.0438531109664057, 0.08771881554275751, 0.020327643690896884, 0.04878105974889227, 0.06687505436795098, 0.04305069241672754, 0.07935982051172427, 0.031130531869296516, 0.028765806795230935, 0.04659639412005033, 0.028883953312677995, 0.028969475866428444, 0.022719835862517357, 0.031752487245414934, 0.035030394925602844, 0.0723312698038561, 0.013164125582469361, 0.006210701423697174, 0.027801048742341142, 0.022351337064589773, 0.003875883204662906, 0.03653050693018096, 0.03610641575817551, 0.021322218268843632, 0.03693213520039405, 0.025291575185422386, 0.06051323216940675, 0.06177821143397263, 0.08951561019888946, 0.035793085249939134, 0.030122564706419195, 0.06166469931070294, 0.017262544948607683, 0.04440128583727138, 0.02779159844586892, 0.02176014646621687, 0.029746252577751875, 0.04446236416697502, 0.05909931446824755, 0.03663413279822894, 0.07033362199685403, 0.03276864093329225, 0.036514245838459046, 0.011885264339590711, 0.022855045839345882, 0.060568444563874176, 0.020341429826138274, 0.01447325203168605, 0.05737199501267501, 0.009792129692089344, 0.016093946494428173, 0.028407294336440306, 0.031293030828237534, 0.041199896551136456, 0.05145503055038197, 0.03759968473709055, 0.029998212986226593, 0.009974195056461861, 0.0355888258532754, 0.006443348605119224, 0.06403790946517672, 0.04942116932943463, 0.04282320337370038, 0.015268130360969474, 0.03707118398909058, 0.01906250836327672, 0.023871113014008318, 0.02046065521426499, 0.047063606192490885, 0.031314285937696695, 0.012262404280980783, 0.020531925139948726, 0.033055997121014764, 0.03656693747533219, 0.042248175479471684, 0.03187160746061376, 0.030915107178900923, 0.05641551508701273, 0.051416747604629824, 0.05878551237817321, 0.03308442434562104, 0.0040652708100554135, 0.03453229593911341, 0.01443942536466888, 0.028450637457094023, 0.04338035526286278, 0.017268502486071417, 0.016708388791552613, 0.03655200291957174, 0.013933339172841182, 0.010790458265026765, 0.024245477747172117, 0.03993638970756105, 0.009104029026015528, 0.044008390312748294, 0.04788589224751506, 0.020854514258514558, 0.04433361553986158, 0.011988220154307783, 0.06723268982023001, 0.011845044176360326, 0.06220523387725864, 0.017707747041380832, 0.04629400838166475, 0.015660973299028616, 0.05092946107366255, 0.06274913397750684, 0.044706524815410376, 0.01154749808899526, 0.048504030864153586, 0.040485158296568055, 0.016582944629979984, 0.05873492080718279, 0.027023488323071172, 0.05264600878581405, 0.02724618690886668, 0.08052089570888452, 0.02836482143694801, 0.03188274561294487, 0.03866099493045892, 0.05919107275881937, 0.1078193433848875, 0.1293936696435724, 0.1467317050056798, 0.17768481693097524, 0.0888634023389646, 0.14567179259444984, 0.13751297896461828, 0.13811608803059372, 0.14801918449146406, 0.08252474532595702, 0.07958138255136353, 0.1454811513956104, 0.20029348161603722, 0.1034676336816379, 0.15380669465022428, 0.13646905283842767, 0.08264925650187901, 0.15870417042502336, 0.0712515034579805, 0.15078743094844477, 0.13433558946209295, 0.04856344339038644, 0.14511178407285893, 0.11407568731478282, 0.10606967977115087, 0.14342200117451803, 0.1455852250967707, 0.17367402357714518, 0.11831777968576976, 0.13916656880506448, 0.1132971973025373, 0.11432153412273952, 0.17402099924428122, 0.09841880388557911, 0.07965720205434731, 0.14944319879370077, 0.08184598639075245, 0.07542678048568112, 0.17189951879637583, 0.0860327510163188, 0.1296420813138996, 0.08976777416786977, 0.13519393626068318, 0.12378078725721155, 0.14601002873054572, 0.13756358410630906, 0.09365307925535099, 0.12425574819956507, 0.08548822666385344, 0.05278529166909201, 0.11452448394681726, 0.12582239056272165, 0.16917438645448002, 0.1270802044974906, 0.10152582930667059, 0.10499002877622843, 0.11801166539745671, 0.08793518000415393, 0.1276968435517379, 0.2026123343301671, 0.10386270391089575, 0.11110971575336796, 0.1244586573115417, 0.09366620890796185, 0.13801041298678943, 0.10744138580879994, 0.17915163322218827, 0.119217096428786, 0.07396210157977683, 0.1123829527891108, 0.15551481156476907, 0.07434051377432686, 0.18414710302438053, 0.10771860129066876, 0.08804867855672326, 0.18044365889259747, 0.09234772715717554, 0.05505648747618709, 0.16615299215274199, 0.1591813705329384, 0.11580080831689493, 0.14241008833050728, 0.1281343765024628, 0.16801941128713743, 0.13643120415508747, 0.08940381476921694, 0.07772462575563363, 0.15895939458693775, 0.07369083685002156, 0.10799372009932995, 0.09979918160076652, 0.16017546504735947, 0.16016200291258947, 0.14746780693531036, 0.14320191155586923, 0.14067909121513367, 0.07489526364952326, 0.1959667352161237, 0.08610662990914923, 0.19099880036498817, 0.10982672138405697, 0.18476074295384542, 0.09289018197783402, 0.19673831095652922, 0.09025449412209646, 0.17189599041427883, 0.14261653939528124, 0.10740216648472206, 0.13235989904829434, 0.10332316679081746, 0.1144341980772359, 0.07086554595402308, 0.09867849959326641, 0.13488474142338547, 0.07525568109537874, 0.10604333904172693, 0.12909552135637828, 0.10656997042575053, 0.13416119239159993, 0.07609999578978334, 0.16012032729174408, 0.19513126861836227, 0.11128659626202923, 0.12031446397304535, 0.08865460354302611, 0.1332048379949161, 0.08475215866097383, 0.1408677782331194, 0.12707808746823243, 0.11349346355668136, 0.13751348108053207, 0.08129017121557679, 0.11625406970935208, 0.175495374415602, 0.14134040501500877, 0.08648931687431675, 0.09414860659411975, 0.1367218071328742, 0.11354401441557066, 0.11941423799310412, 0.08421026702438082, 0.09891363233327866, 0.1402840752686773, 0.07749918928103787, 0.16437122704727308, 0.07382704596966505, 0.09899288522345678, 0.1079265722738845, 0.11318854349000113, 0.11201234374727521, 0.17400174242045197, 0.05702725851110049, 0.25549096188374926, 0.10568813274481467, 0.15041012476597512, 0.13347770406731538, 0.17668978603822844, 0.19468429046017782, 0.13763533239918097, 0.08533438241907529, 0.08797488108809505, 0.11836724488862924, 0.1195993966289929, 0.09150402992963791, 0.12734845653176308, 0.12872915315840924, 0.16476860429559434, 0.20886914644922527, 0.10204149556479283, 0.08351602392005068, 0.11976988533777849, 0.21621609292924404, 0.09897591506264039, 0.1344883819775922, 0.08825287009988513, 0.11963196630988802], [0.07734292266624314, 0.023011856978493075, 0.033708927620734484, 0.05701370816677809, 0.05932959568287645, 0.059382779257638116, 0.06551465272371258, 0.07406915404966899, 0.06885333678552083, 0.0028864044247062077, 0.030477289243468215, 0.1058196938995804, 0.024234159783061062, 0.011646926369784134, 0.018702409828880003, 0.022328814790983285, 0.041722175133015425, 0.045156196757618866, 0.045814216269978454, 0.049637262376823595, 0.04097504700933184, 0.029993663408926556, 0.04601599222847393, 0.029151380926902806, 0.06585650545145784, 0.046674520642097504, 0.055033488531730006, 0.05391041808096426, 0.03557496338284441, 0.05160287315292018, 0.017971503781154752, 0.050257209289286814, 0.011948381667025387, 0.03417518974414893, 0.0581338337755629, 0.06898293697408267, 0.04607657522761396, 0.06497680515583072, 0.021804598991626074, 0.01951667559998376, 0.03806833530377064, 0.060061002150177956, 0.0510481673825, 0.03368950794850077, 0.036333341617137194, 0.03879240680752056, 0.06849161655242954, 0.004294954489783517, 0.04557247120620949, 0.02112157885650439, 0.03448734638680305, 0.06028763284640653, 0.015207019800852453, 0.04403679378862892, 0.07687734586319753, 0.03394224188689675, 0.06954558499689613, 0.05038211062284453, 0.0273412598430046, 0.03107175716598119, 0.046634510824722905, 0.019833600647481422, 0.005160881372700844, 0.018905115380351032, 0.015957097855529616, 0.030303964258304665, 0.041623380434300215, 0.017658775472747426, 0.04261668784809964, 0.07769500091671944, 0.024723870380382453, 0.006021888028564197, 0.035548483553741655, 0.03130040989656534, 0.009356120900650109, 0.07750290086758987, 0.016971431373219405, 0.02391222714712577, 0.03909850073978305, 0.04796992880957467, 0.02242368077194052, 0.06256649949188743, 0.05160809447988868, 0.028144602896645665, 0.014291275725034731, 0.02455045548932893, 0.022788423878539885, 0.06285650535885777, 0.006325469684920141, 0.05100249179771968, 0.04037750532318439, 0.03593503477584038, 0.05633626898218479, 0.029391633213630745, 0.045305857834007056, 0.07947152094649416, 0.011850419870045568, 0.035314809664019516, 0.02360988381717886, 0.026377209162871753, 0.02116451824882201, 0.03371266974136233, 0.061129090908382616, 0.027783647711787905, 0.034981642184512954, 0.049131784322006364, 0.02975007612258196, 0.05999096376555307, 0.05835397767701319, 0.06098353836153235, 0.017504401970654726, 0.0881406811199018, 0.02962350898555347, 0.09584834360118423, 0.07183000205882958, 0.012094631408607321, 0.04582603295732822, 0.011709650995076766, 0.005742971544220511, 0.014601015086684908, 0.021184952330908606, 0.022607562065656697, 0.022421796140926223, 0.08379837591201067, 0.05065958055534533, 0.03818631558013814, 0.028337481564709117, 0.028541137065206255, 0.05701062761779342, 0.0501720260030457, 0.035971390682139566, 0.01667555787467531, 0.019939823608313288, 0.01939425940093185, 0.14526946204049246, 0.012038779494884824, 0.036046066853616915, 0.004791154850473893, 0.03008036661360945, 0.03061594787452902, 0.03719836180763585, 0.03304344083049467, 0.02645693363488785, 0.059732774405607154, 0.01063546135888568, 0.033603476493486335, 0.015435553787808334, 0.06381459680518933, 0.0424543008474367, 0.008145032583602836, 0.026834969242502536, 0.02316234417126647, 0.018927269548709904, 0.02999742588560496, 0.04627274648685541, 0.028516099123018127, 0.05847762032811131, 0.025959419884852, 0.01001739568476166, 0.041546963820500035, 0.038790832606277297, 0.03287903518815126, 0.004177375821330185, 0.06988997544561114, 0.02251099974715284, 0.01970089616120926, 0.024229482980445027, 0.03924695063116295, 0.0544359230968569, 0.043028585745819976, 0.04104773846587964, 0.04081338943381395, 0.04793354915454984, 0.018386326164805462, 0.013739632692054977, 0.0341610490743603, 0.0230140554319535, 0.02965922367626003, 0.04618297630388822, 0.042583738187594075, 0.07877365446516446, 0.017856437812692354, 0.0157926158779966, 0.07207742306802954, 0.06285287519650799, 0.04434617183038166, 0.010902823664114943, 0.051770003113363466, 0.03389444927285824, 0.04475371014060719, 0.03207840457824724, 0.012104944292722004, 0.02486190984823874, 0.07633174264005252, 0.06383863051554986, 0.010036665231122502, 0.043212984422487874, 0.03253768796899489, 0.0462667753786913, 0.031405596395156214, 0.008575139816717377, 0.05780754664114543, 0.0640828013420105, 0.04705538234806486, 0.05731786148888724, 0.02223629314851548, 0.05173751146399549, 0.014118077965187175, 0.053589562619371076, 0.08365141201232161, 0.036522510394986184, 0.039566123325909884, 0.029301455909652368, 0.028295644791796803, 0.03151669293375952, 0.032335908617824316, 0.011983735037834516, 0.09364018708999668, 0.05423142621293664, 0.059626760094293525, 0.02483102463052741, 0.021553247568330595, 0.04585367986666305, 0.023370820663071105, 0.05593160766043833, 0.0641803000388401, 0.03640058443748525, 0.04885726940951177, 0.016415061495665993, 0.05353260299723063, 0.06718162327472653, 0.04132798360660672, 0.08960072563162871, 0.07788279905383076, 0.03586987166532448, 0.019132333009370735, 0.022823836621163145, 0.05147963423015816, 0.026844913173200827, 0.018288128576906662, 0.02089321959231581, 0.029167414709393467, 0.03497705528778689, 0.027978947053530386, 0.03372456446023924, 0.08409427824829306, 0.06910344479339463, 0.02533959341235459, 0.0414351785688528, 0.019807840065498437, 0.017137894673006873, 0.030865852321897234, 0.0017454593471484259, 0.0077995013478877285, 0.04433975628178034, 0.02855202415958047, 0.07747259749365704, 0.03352500731125474, 0.06042704465133803, 0.014287094252982309, 0.02780880779027939, 0.026821937977469394, 0.04193869226479104, 0.017252015781455805, 0.014287258797724332, 0.030814337943281447, 0.06839716447783367, 0.05174767591857484, 0.05689515792099493, 0.0574670849101884, 0.06165365954594953, 0.055173589049705436, 0.02780396305024624, 0.021259046658607464, 0.04842074069061449, 0.04401459890816893, 0.10684412571468524, 0.03603341556819422, 0.030899351595767906, 0.020159382273309996, 0.05754812913281577, 0.04101476166397333, 0.027989661121474843, 0.028033102629706264, 0.07925563824496099, 0.023046469049794332, 0.04844505260033267, 0.040726031442838054, 0.04560653705682073, 0.06662481065307345, 0.0250686662537711, 0.039311594662389586, 0.08379021313573633, 0.03350680900205459, 0.0361248413766069, 0.04617059303979788, 0.039932888466864824, 0.0014156431945074083, 0.03228397015482187, 0.035890309140086174, 0.06583562692893402, 0.019526058042954122, 0.01578371349855193, 0.02541743155701884, 0.00829460799494492, 0.02278570125677756, 0.009502201856646155, 0.05486170382105878, 0.020487301284447312, 0.03495291640449848, 0.03230246362675514, 0.022568707454151342, 0.0356040894985199, 0.04050995196614947, 0.040949510343905, 0.015657410990180712, 0.025137657998129725, 0.0438612432086042, 0.03052018622734717, 0.019063393851476054, 0.026710793941414783, 0.01183511212002486, 0.036681901663541794, 0.07676697535706417, 0.027837575978732536, 0.02946203461449061, 0.023682797493945276, 0.04733521358243056, 0.02648710469449205, 0.019255107135644982, 0.02416680839711002, 0.023525535129010677, 0.061100707788552554, 0.01588199251065297, 0.036613769962319305, 0.04472512346027153, 0.03329797288669007, 0.03380720324016043, 0.025411370542964766, 0.0847810303260173, 0.02569909653227244, 0.034774444731218476, 0.005084162386732974, 0.04895835077123983, 0.03978499836687531, 0.024628488712811043, 0.029823398616697108, 0.010451599573051291, 0.017224511364474893, 0.01391741565229105, 0.08279073783861739, 0.01065908879640379, 0.18483251838811807, 0.14071921977613652, 0.13860133556382997, 0.19946929227028573, 0.14880321813481195, 0.13042642708335603, 0.11822631316525595, 0.10303037893027067, 0.22310029209724494, 0.0840833131223917, 0.1322649312870843, 0.21170236941959175, 0.08938434759953193, 0.14414808792727335, 0.11120112799108028, 0.0687800075060555, 0.09113791278962578, 0.15324845031968184, 0.12217834538647107, 0.12294932401606015, 0.12273466267756053, 0.16396644019654819, 0.21073286501424654, 0.1209975994591202, 0.08981352778417723, 0.19022425264120102, 0.1390604730695486, 0.17759465319769724, 0.16739644828651631, 0.12057356935526643, 0.09550765116832086, 0.14175083727708884, 0.19876406368400368, 0.14719313595976147, 0.16870990209281445, 0.12703220493027143, 0.06803091841616801, 0.09238738074366536, 0.15044140523033483, 0.16659497629318917, 0.07415818462946586, 0.18961591885558196, 0.15084236514355454, 0.17615752959890024, 0.14205031549291952, 0.15631926911217825, 0.14053054632885115, 0.11769086761134011, 0.10803053740944181, 0.12721209813441547, 0.07874768693000078, 0.1656345778277942, 0.1174723386232342, 0.0937936988526157, 0.1614481931818383, 0.10364762188068458, 0.13798009604215622, 0.16927618027797767, 0.12508703502161161, 0.17420936056545802, 0.09241059342665331, 0.14686142733054502, 0.06517781436975513, 0.09390087345881121, 0.15072800485151155, 0.07851324629570756, 0.11821452022663184, 0.10798422739441906, 0.13357283467692987, 0.18485838414302894, 0.11760568432509899, 0.09317917004227638, 0.180526128038764, 0.1217480863311461, 0.20467387299452508, 0.1690793236983674, 0.15089387952217034, 0.08882021358502762, 0.08859398322446005, 0.10748298679079328, 0.16667907392340048, 0.11823335635874953, 0.11669538888548102, 0.04476527237732496, 0.09191976155021361, 0.1073017907994134, 0.055493409745395184, 0.14394350961915084, 0.11230110110981123, 0.18789048572736128, 0.1679867466113397, 0.09167177735694818, 0.14720129195068563, 0.17105272066380295, 0.15456286764570645, 0.19298636514161313, 0.0871962553688458, 0.11568909431142466, 0.0770009138754436, 0.14278743522507803, 0.18338232620486192, 0.12440668152911322, 0.1076236945976104, 0.1393331220107419, 0.13769801546420368, 0.11773884003715855, 0.060209689528814385, 0.174413301050663, 0.19627451870058263, 0.10139502132577555, 0.20038621021168573, 0.2339261690420764, 0.11994017048605851, 0.1740999264376504, 0.08941847112561975, 0.10044175426342658, 0.11523063534072467, 0.12567252931850298, 0.12942367446209702, 0.08969211072794028, 0.16195413603314332, 0.06472067175699131, 0.1335101787533079, 0.1353039267872061, 0.15034379118255206, 0.12792255144034112, 0.08167631870933942, 0.123977358852114, 0.156333559059671, 0.1424176607813154, 0.1845902678157602, 0.1111714013719133, 0.05696055173341717, 0.09640512908143656, 0.25957378851515905, 0.06202394289097615, 0.15508471535784857, 0.11696931347250938, 0.11997416509049279, 0.08291720319539309, 0.13722475085939678, 0.17610186258597033, 0.14670012598591192, 0.13823240250349045, 0.07938181861702885, 0.09638165855514151, 0.17949484980532102, 0.1233930452061551, 0.1397486161440611, 0.08879317396453448, 0.14330031270427362, 0.10614294798246451, 0.086847142316401, 0.09884268471172877, 0.1417348509920495, 0.1250074157225234, 0.174968546256423, 0.10875701092715774, 0.09837162534573249, 0.13867053256503173, 0.12412633800080844, 0.05710269124912364, 0.07799515766756875, 0.20616105890699796, 0.11995386332273483, 0.09890875366649457, 0.11884829907545022, 0.1396748051047325, 0.12990548860813889, 0.10877598955162934, 0.15153020966265882, 0.1261062624731234, 0.19752306384699686, 0.05564710131979414, 0.08391495501356465, 0.05462939039404903], [0.01830958215785878, 0.03427348232695034, 0.013472508722251015, 0.040558507932083945, 0.06425091517823082, 0.04866051461015429, 0.03693799435028008, 0.0323130216316453, 0.08410191855260304, 0.03867874540654676, 0.012515301067781235, 0.01008234844942178, 0.03644994107474174, 0.03975576368559684, 0.04557914799079299, 0.027515348180064132, 0.02683365118822881, 0.024142471042328646, 0.05234425747767091, 0.02244098680759115, 0.020413061071719443, 0.05088150221854448, 0.015526655595749617, 0.06440177386892693, 0.07817861318056073, 0.0056858902098611, 0.04287764223824654, 0.05476854096299835, 0.03765440180099436, 0.031046631014240638, 0.03510504734835454, 0.03265014497031059, 0.019392552885359952, 0.02337661704846791, 0.033045785168984106, 0.02728128243636872, 0.014136688484411155, 0.052797834388911724, 0.07735443740550961, 0.006077015606154288, 0.021952331332223754, 0.020303708368114064, 0.028755825545106615, 0.023598911905927316, 0.05520377028733492, 0.021782002079167535, 0.027436297154054046, 0.008005984643075083, 0.010579599267137902, 0.0019983973761554807, 0.03198140799733145, 0.009413833696661251, 0.008754468140458422, 0.030746915311153446, 0.026204866357147694, 0.017045379815889255, 0.03641658090054989, 0.03892188485977905, 0.048091512106891186, 0.02116936638153025, 0.033948104429457865, 0.032451724367482324, 0.00974057290503489, 0.06487697908388716, 0.015109509229660034, 0.05576114609305348, 0.021670442440414002, 0.06098091921636036, 0.09766529753272023, 0.06325527360396725, 0.043882304935583046, 0.008148591499775648, 0.01739349202918155, 0.018562748662329147, 0.04883656730609281, 0.02911616156675986, 0.04406189958431891, 0.023122651569013084, 0.0025847525643517394, 0.09253902653498308, 0.04244004821936999, 0.03515688403110419, 0.039312205343906365, 0.051871437313301225, 0.01929669624327549, 0.006403632254140186, 0.007159620772914163, 0.016031472078923668, 0.051501791791192124, 0.02779163746163249, 0.007570314270976398, 0.01840416993945837, 0.018596074909770062, 0.041373129934072495, 0.046270605708871565, 0.05963941477239132, 0.014812663729701723, 0.02076935811367418, 0.030290909244545867, 0.02623535632821066, 0.03289175093440073, 0.06560052133032254, 0.05533545357840402, 0.02382592936711652, 0.01098380851492818, 0.10385521288428988, 0.037259070335754325, 0.05582079949921795, 0.029786812008491585, 0.056671217616115294, 0.018317353080159852, 0.01712372007646731, 0.01669170700811914, 0.01172314875293523, 0.02547889156267047, 0.053020699215786796, 0.046811486328286786, 0.0338949717448226, 0.054268497973680496, 0.004147306966063167, 0.10053486283868551, 0.004882278286718896, 0.06205512157508305, 0.021888292893501263, 0.051971222673143656, 0.028680304597531046, 0.02060427563264966, 0.10022593263004508, 0.0774408420547843, 0.055085437172757726, 0.012222222285345197, 0.02872117276170424, 0.06949966853218419, 0.06831605240170445, 0.028598052582570484, 0.05244042963853904, 0.013388952223717101, 0.03874594412211861, 0.012352303385601511, 0.07055356912314892, 0.03778074841414179, 0.02841462760365435, 0.02587079642606633, 0.0029878659780868994, 0.013221474514076752, 0.04746483073436788, 0.032939485872962644, 0.0036360448242963423, 0.02877826809084841, 0.012429787843887295, 0.05558580246620944, 0.01618233585863241, 0.05360413755157164, 0.023160708901871527, 0.03487983139763985, 0.04005207992824061, 0.08025320007332734, 0.04217755016205566, 0.025912578916177154, 0.01740472178374018, 0.060324986199183125, 0.030060248050306524, 0.0644625366798469, 0.050052512237536054, 0.022802942831601416, 0.03643072835568871, 0.08136595679180962, 0.0713383491550173, 0.02820529106871358, 0.06934472506067582, 0.017948459035583904, 0.05691916109727962, 0.038255230989307165, 0.06426126283726522, 0.03498401705707822, 0.03379585134929844, 0.04812484513968229, 0.08006650116294622, 0.033287584515554566, 0.01815758352833135, 0.04919243517464825, 0.05340286031631487, 0.03343352722004056, 0.03146370274147817, 0.019372144248336554, 0.040226415930581946, 0.04003885528072715, 0.011852960135521633, 0.021087920126904334, 0.020422211116445915, 0.025994941193078245, 0.03377131552302411, 0.020362559406618987, 0.01825291769845145, 0.08399908657052688, 0.024860878475010395, 0.04900782275944948, 0.03397088624270899, 0.03822337377018162, 0.041209026239812374, 0.06746401597878762, 0.024872425444690243, 0.036896383190261464, 0.04144017258659005, 0.023910276358947158, 0.015484890069014259, 0.03714081186002918, 0.06646098515817098, 0.016184909202690636, 0.05513618141412735, 0.018332402986873473, 0.0383987445384264, 0.08950436687363045, 0.0631622735943113, 0.027558665855654647, 0.07537246375743832, 0.01649117616138288, 0.01684553937853447, 0.03306894017649548, 0.03327692812308669, 0.06565056328794786, 0.05380442751837628, 0.013409321844976927, 0.034195922381643734, 0.01654320622661284, 0.03265031799674034, 0.028519440907984972, 0.011405210991922234, 0.02583709019901497, 0.030540552455931902, 0.02173445713041084, 0.0374467904413385, 0.018778923133920346, 0.020426864170336297, 0.07615301651614052, 0.015790071371676664, 0.01333927667500185, 0.023176405113190413, 0.04241824010387063, 0.09989119094929524, 0.017117250245064497, 0.0067120989385460106, 0.05364957904177053, 0.009029553022368677, 0.05261507437431386, 0.06066814171416419, 0.022595031220199804, 0.030876946369452134, 0.014894939493387938, 0.02024386327580682, 0.015962765319272876, 0.06675004786146538, 0.019286803202703595, 0.018055608196716224, 0.03219579452914851, 0.04371654561587742, 0.056228001934609244, 0.01721489821959819, 0.01979393688296633, 0.07930302034531321, 0.011940384283661842, 0.06530105668519225, 0.0538290685175785, 0.030678783609930958, 0.03956513266478266, 0.014448281942999788, 0.0349048591618027, 0.04302950516077025, 0.029414795006492307, 0.09574427668537412, 0.028573628714574233, 0.03108544660998242, 0.01937827481223004, 0.04088674924735512, 0.020393505692481995, 0.0697704040046249, 0.035801078392458816, 0.04616278310173324, 0.06752725544252566, 0.059236256405711174, 0.006244759640789458, 0.035812223330140114, 0.08695350268057414, 0.02940300546054329, 0.04061575253893222, 0.022172714417268122, 0.040644315470542224, 0.010001936960699303, 0.013472185569948383, 0.05065491562709212, 0.005486232976961348, 0.03955118537747434, 0.0432873213264559, 0.02614809333213738, 0.022299105135191764, 0.025319641090131233, 0.08493499670709882, 0.0314271398819983, 0.06087351390825851, 0.02430846106394061, 0.03530936102781977, 0.0242756080946752, 0.038325252410556586, 0.01863558600390596, 0.04173384254266109, 0.044261599225657325, 0.05018124050859894, 0.022154429594853094, 0.029561860686434165, 0.010851604448232268, 0.05280889790239079, 0.0323469110631517, 0.03687257678913219, 0.01669813782375838, 0.04549011401832104, 0.04036595665716699, 0.07981749238180262, 0.013019609497860074, 0.013620043439524514, 0.02313718748545008, 0.039426399394869804, 0.05537419792796884, 0.05329930230176874, 0.01864863253597702, 0.018585678056946824, 0.05440856795758009, 0.048429110420069525, 0.04263614144708429, 0.029310161513941627, 0.007686539686151913, 0.019459224039954797, 0.03418216169146555, 0.0657684180353369, 0.026257683522999287, 0.05866843116070543, 0.03882303248558726, 0.021850310199494873, 0.0245884229162974, 0.01610719319432974, 0.028417119523510337, 0.005128398205020598, 0.02421037543431989, 0.04080500274098345, 0.023391972295939922, 0.02216090790794364, 0.0699504871985742, 0.03763998293184808, 0.06808743359787123, 0.036268948643867455, 0.16768591132547173, 0.01820993420135762, 0.0022318681294564158, 0.13511842888380798, 0.10513272469065019, 0.10384948604873248, 0.12672991757946356, 0.1967607976070472, 0.19251947876598152, 0.13006235233375005, 0.11200549732893705, 0.13870211158479961, 0.1928022378789527, 0.16611435636878014, 0.15531469801706926, 0.11425540409982204, 0.19242989857281956, 0.15233033815664904, 0.15511172105159077, 0.1901080874460084, 0.13239580712148122, 0.14157726801931858, 0.1618540385471923, 0.21132640673645905, 0.1402452087828091, 0.1141164672694036, 0.21922620997897216, 0.189316684912358, 0.11883273348212242, 0.12129516420619828, 0.23221360093780927, 0.1483422757259437, 0.12298691485609327, 0.10290381179324218, 0.17527765966951847, 0.03692803345620632, 0.0854631005121129, 0.07963071204721928, 0.10664539637842349, 0.14951208366879395, 0.1194919573941401, 0.11136285681277514, 0.2192318689610277, 0.12349159563226358, 0.133465029033167, 0.15489684258188519, 0.19448049925267696, 0.21682563450719627, 0.10333111243588583, 0.16058333244706902, 0.14122850101973328, 0.17982236508812222, 0.06750400204743658, 0.07136704440095595, 0.07587364329291241, 0.07761660298066479, 0.10041069093027286, 0.12561982071825437, 0.12308967219931738, 0.08525190648755857, 0.09941549718912158, 0.11672805356127874, 0.0888252415295158, 0.07836052841906037, 0.08461468068084546, 0.0714930279978684, 0.25832677685788696, 0.12008714117109776, 0.1393708892698799, 0.15071437986833708, 0.13701273580746992, 0.19697429186531476, 0.20281748260770524, 0.1441690003765481, 0.08577876857348851, 0.1116285982674786, 0.10715984127351216, 0.11469193281871931, 0.1487225131796939, 0.10070142961506333, 0.13667775663946355, 0.12219526804983616, 0.1373788190207311, 0.1662908433271306, 0.11556247967694487, 0.1733920108526945, 0.12030294244842869, 0.09545563467379127, 0.15859922819903918, 0.1783043329737016, 0.0781658702929105, 0.24963164914931568, 0.08569723580564771, 0.08099086941885096, 0.11099849707846131, 0.12713721500975744, 0.20564810000360012, 0.11199063062667847, 0.1590315228594201, 0.0978328346141747, 0.09418335437242474, 0.12834485806524754, 0.1356932430395058, 0.16524735146335193, 0.1528634224087, 0.11140612020556416, 0.09566007727491004, 0.14824710440422806, 0.2324877290853432, 0.1537176708557776, 0.16881172305771283, 0.14748342681143964, 0.18718122664306844, 0.11673186692808356, 0.1381254382431507, 0.08720190756555114, 0.07565942300217492, 0.1359698681959084, 0.12508385947772435, 0.18622898416859762, 0.11542977179799761, 0.1341230044407504, 0.08073851546006543, 0.19657984588827404, 0.13425126112997532, 0.14842642763895647, 0.11418901623359748, 0.18022572701530798, 0.2012056905244078, 0.10060287918895483, 0.16273793897458486, 0.1892464565379279, 0.10212857874908618, 0.09825932101479598, 0.10652276474450316, 0.25701918559415, 0.19709941372275352, 0.12491423929376261, 0.09316161634134394, 0.13719710734273705, 0.09245777196649994, 0.10447912583393709, 0.20024553633161954, 0.19720470878694737, 0.12859025704009192, 0.12414688404117312, 0.0842810110854251, 0.10803278336035353, 0.12645866642040865, 0.14400737333510602, 0.0953261498361826, 0.16362216509878635, 0.12938201241195202, 0.2076341855738844, 0.13419294783047267, 0.12714148978037493, 0.14034875322665485, 0.1647665144077369, 0.11644042256687369, 0.17417171544262341, 0.13807932500328335, 0.08637226279824972, 0.1086265489991222, 0.15349002235702106, 0.09585891517677478, 0.11977749850068774, 0.14952988842768328, 0.1733173177178417, 0.20227886150990212, 0.3212132123964173, 0.11213819163718394, 0.10493929471288409, 0.23559240677527019, 0.08358083758503199, 0.19351474036063465, 0.12523065374365874, 0.20840804119195255, 0.11285211225705487, 0.11011241855365889], [0.005627566308248788, 0.04148104753611343, 0.028633587461497103, 0.053539649583399296, 0.05245151011539357, 0.03714774988059487, 0.030821733974984715, 0.0725687299189823, 0.0312575027346611, 0.09751268143632583, 0.07517914913062539, 0.003749153219229941, 0.09554348460265569, 0.03127737363268222, 0.06361851375550032, 0.00451934347594423, 0.041233480641884465, 0.006596673346523727, 0.022974137216806412, 0.02659962615663452, 0.034890779560165744, 0.021941225410306027, 0.05188224637614829, 0.03289594767349107, 0.032238006192658625, 0.05629270024863737, 0.018693132558837533, 0.03401680949277111, 0.03364843622382198, 0.028111905990434543, 0.054351537089262686, 0.06669424514153174, 0.005057024802746517, 0.05191005952656269, 0.011280188370229942, 0.05511584571961846, 0.0852955159332071, 0.04128009260499051, 0.028858867873038565, 0.09692986056740795, 0.018580005504190922, 0.010099927595417415, 0.050945505034178495, 0.04780842390443597, 0.061859900264867713, 0.07994841571365084, 0.021177731021972637, 0.044215390990887365, 0.02496542884702129, 0.11326548257576567, 0.02795002280202295, 0.008336987595872154, 0.07148247677832842, 0.038113030405449014, 0.02468177067515041, 0.010777838361848677, 0.009806973493791052, 0.029222111417246715, 0.022010849888569543, 0.03843282735241311, 0.003427518926660663, 0.06898762565106153, 0.017443781652088677, 0.02410676992232246, 0.03393876100225108, 0.018233007784666758, 0.025268555884914737, 0.05299315069402967, 0.0389512314993356, 0.042255439196846316, 0.04043515705104385, 0.013704476096401257, 0.010534860060683318, 0.031260518822818995, 0.07142740009086472, 0.022374006919562817, 0.0455124208570591, 0.04661808009924633, 0.04378306579643062, 0.004911978612653911, 0.037086101581475565, 0.02108670215654586, 0.04744596067549927, 0.05029317503795028, 0.03499686172498124, 0.03397289809903928, 0.06270725479615585, 0.024925013604973043, 0.027954348462766836, 0.05475824758676546, 0.034575980023614, 0.052889650354960134, 0.013193782651796937, 0.02834094887865441, 0.060727438889443874, 0.05726656424147742, 0.05152899765276483, 0.03999657915639026, 0.04268631911171334, 0.022606055717915297, 0.05321159486525825, 0.018747149035334587, 0.030832458220954453, 0.07002485463661806, 0.011587387466404055, 0.048288372079176564, 0.09477281131382499, 0.05943518251712833, 0.02927505411207676, 0.0209405423208539, 0.05324785577665482, 0.052345502589430125, 0.047741567849048545, 0.02804306861279266, 0.05754235479980707, 0.011724279361910053, 0.04547607173611011, 0.01595384767279029, 0.009256283802512501, 0.009726938592003924, 0.04856147563883236, 0.054828153657061715, 0.04627864634884255, 0.0032051587602057096, 0.04500899537067328, 0.036442392372659276, 0.0405735408754221, 0.012521565642340906, 0.007968929845706692, 0.014416239823081663, 0.020390856013234173, 0.01889699331617781, 0.04329559945368341, 0.05023333164198058, 0.034557978489569256, 0.016733667613672357, 0.030310766571866612, 0.02235379336135728, 0.05954602121242455, 0.01568591285363904, 0.03245448261233313, 0.007902107717070197, 0.005828287992959044, 0.03375531566728439, 0.035119520500302315, 0.03121012741965907, 0.03322946459853223, 0.02255881780625454, 0.03142820857465267, 0.06432868886206831, 0.03222050677452769, 0.041612306742795875, 0.05459985037201217, 0.048203663767448494, 0.11989279517105647, 0.031053555464105945, 0.013226529599965682, 0.031274571283055205, 0.016285137306632738, 0.05984291420983417, 0.013315751017736537, 0.037649645270513635, 0.03228606004267931, 0.1016619773581624, 0.02803101613452392, 0.06182412111333438, 0.055909582413733006, 0.06288675444998912, 0.03039053175598383, 0.06268223042466811, 0.04833241239456194, 0.0208320513567222, 0.02638418789553855, 0.01458124936159168, 0.03882542432152799, 0.10717480975602355, 0.05670967698097229, 0.023994002491235733, 0.06738393527588674, 0.04248152027970978, 0.05002339629988585, 0.028452552622184157, 0.03441258539844837, 0.04385679880423205, 0.012578376834946019, 0.07737252714910678, 0.027261017988036786, 0.018580380394788723, 0.09322493722928421, 0.05853288022003003, 0.0375371068449957, 0.026695043447294405, 0.06077174044081143, 0.043293180476341925, 0.03840760620576995, 0.023884222310568606, 0.07626576189483915, 0.06075230041252715, 0.04714654352782028, 0.04326838680676051, 0.025387900016669716, 0.028997048136911223, 0.022661905935300247, 0.04364495677873492, 0.017727165017277002, 0.08688337608639683, 0.025806579871901443, 0.036466985874410184, 0.029995587055704424, 0.05268090584182313, 0.018922263656609824, 0.10674037771033389, 0.04533791182828801, 0.006106449607094484, 0.00860593343220119, 0.019815212348476052, 0.048482256675405164, 0.01099426219505923, 0.0044982592724928895, 0.0689905501369919, 0.0229546887068344, 0.03349100931414536, 0.05124634710539665, 0.018987104462991868, 0.008927906780237598, 0.00988465896807611, 0.03418418711849621, 0.019288977907438363, 0.03362501658765333, 0.054836421606263945, 0.049199654787246666, 0.0603497459420136, 0.054202249207134755, 0.05153278727084398, 0.030677809912179197, 0.009883733615944428, 0.02848133777401277, 0.014796272019988723, 0.021309848575453674, 0.026580810380567397, 0.01653772027098707, 0.05708319693803787, 0.01978255106535341, 0.045080933653350384, 0.03482926357537508, 0.03731077131150024, 0.016213399191786135, 0.03583478122683508, 0.0019591914107357816, 0.04704222555405327, 0.0244587480888835, 0.0355950005219451, 0.02432942101066666, 0.03051267145201564, 0.045689250475593975, 0.04032964485564402, 0.028824198126260723, 0.05188851264704551, 0.07021099714828388, 0.049960435035505464, 0.057794613763689995, 0.010909214615821838, 0.061088005613003454, 0.024027717199974825, 0.04547431093773671, 0.014781157652448331, 0.060354312482689104, 0.008132644230499864, 0.05399011541157961, 0.056350514824901304, 0.04248453297519258, 0.023877740604802966, 0.06342701760253736, 0.0370172540258084, 0.017196927219629288, 0.01459683700730758, 0.029876083468220065, 0.01750340622051486, 0.03703225304239562, 0.035417682358196804, 0.04671842185780406, 0.023601040809548328, 0.04925406311771699, 0.07990378168012414, 0.031242001602160077, 0.063164227775165, 0.01902657823770174, 0.026338659892124788, 0.02662735109749649, 0.02836692489550582, 0.006977056685302938, 0.09220366060201611, 0.03668436135298439, 0.03334176214411855, 0.05004629007141505, 0.08227732431675706, 0.02084694859305663, 0.04058920146365251, 0.026546707210530127, 0.022878402711025307, 0.004007800166229052, 0.03345370345882007, 0.06403719700340714, 0.04596755161349263, 0.022467125672847033, 0.028376256448349783, 0.0129839270375669, 0.014698671542906334, 0.024877388928351656, 0.13134002020316465, 0.05640191385256393, 0.00871675431595317, 0.00236658553226984, 0.1074755432616387, 0.057280134941850386, 0.037008592526295354, 0.0641571484240038, 0.014313614794186183, 0.04019975968237434, 0.0017954799945333175, 0.05465090673949037, 0.02631176106764802, 0.018138397950679064, 0.09397905426365988, 0.005127048344417874, 0.024934823525005152, 0.011555123126267322, 0.022704970856596316, 0.09080730338713952, 0.07721733940499169, 0.04258865417380418, 0.027048733218439987, 0.05517198431438633, 0.045033958674009354, 0.015042963604043637, 0.005689888477458486, 0.008976662065833807, 0.029120103855218207, 0.02813209579991443, 0.024539020477927158, 0.02198826485047383, 0.03820417122915387, 0.037831451943410296, 0.09261223367814507, 0.05676689783909491, 0.03872885861034904, 0.03360743913799524, 0.017671221501326988, 0.02364682326359408, 0.03329084487631917, 0.044854649009981325, 0.03455839239593063, 0.12778769939073495, 0.09071317700935261, 0.14302433894148894, 0.1762749297278268, 0.16380444674619607, 0.11195295836244311, 0.11326747068337031, 0.1831955797970295, 0.13491657828646048, 0.17516515856342657, 0.1963044692363058, 0.07552438096276351, 0.2141291227723871, 0.16871964585568222, 0.12579693192882196, 0.12006527877279691, 0.26391318280782017, 0.0984852731760059, 0.11450100663517203, 0.11441262066364288, 0.1331373101898602, 0.2368098343057292, 0.08681650646030903, 0.10133653160716806, 0.10318610271705048, 0.1235096175223589, 0.12409193627536297, 0.12150924200458185, 0.1172609342528241, 0.14276813768914767, 0.10420575764562402, 0.16292254121175834, 0.12482159212231636, 0.2624112048319408, 0.08055864261197192, 0.2404407023319176, 0.2206671740859747, 0.14767322662685597, 0.10580423008650541, 0.12278967829687254, 0.11556163829352174, 0.07889456262013742, 0.1399910431355238, 0.19241255521774292, 0.16082491805510862, 0.16142021039766924, 0.1734912126724209, 0.15771084944052355, 0.09106918397758688, 0.13196771937821591, 0.10239862211580787, 0.08790546695568732, 0.1247035405997719, 0.11122546025684901, 0.11845207533666066, 0.1567512516464506, 0.053498055386756144, 0.14861811378172465, 0.10581132077745029, 0.10174431758267538, 0.1605571409953492, 0.23052638290183886, 0.15960096301777021, 0.11137703819466488, 0.07764792415712561, 0.14515967507447514, 0.10838068183511496, 0.16536296025982924, 0.095209075404065, 0.08017568423279695, 0.14138220277215752, 0.13708561046847276, 0.08662445390863077, 0.10976215199168239, 0.13330456907195704, 0.16640303230711392, 0.09456715413502284, 0.14521247866962636, 0.10205239962254252, 0.13708406340863022, 0.14067031097199234, 0.09309419710189104, 0.20049477581466946, 0.17590853438845702, 0.23887931182980537, 0.06706293392926455, 0.15986120833882264, 0.09909484868070909, 0.1653849719358342, 0.11375822113560778, 0.09013948243643556, 0.19595175316291197, 0.10693679324218205, 0.15745462104678154, 0.1481413615069219, 0.18250484471874578, 0.2031162551471165, 0.18765093572437763, 0.10481333825737238, 0.09455394305820976, 0.12539024518004485, 0.149881545986448, 0.1616150178015232, 0.1618316468915769, 0.09437742895845856, 0.1081077071971127, 0.14264898693987302, 0.15161482297948428, 0.15370956914765493, 0.13537524081766605, 0.11213386936911515, 0.04727886124913182, 0.21453123619513853, 0.12299291310565812, 0.18822250648268632, 0.2578968299286706, 0.13617739134601184, 0.14715369950447763, 0.1062030458290662, 0.1368524386946644, 0.13133294986827032, 0.08703486581466027, 0.07049421766506773, 0.09275406106774296, 0.13347470494253294, 0.10479071589985064, 0.1696591725839036, 0.16591261433703558, 0.08147356566041708, 0.20170723646879196, 0.052149222764585695, 0.10737422441265412, 0.10037008060940675, 0.15671486859875067, 0.12482449625219617, 0.09993632031338555, 0.11027313635817595, 0.131296661815473, 0.1477301014321191, 0.1261198738855975, 0.12339204097432749, 0.11417597479053906, 0.09645732878042118, 0.16083833947777748, 0.16466345850910458, 0.07914707264197723, 0.08429910082902227, 0.10573271249553987, 0.07991188338824681, 0.11515603720077447, 0.17082857340574265, 0.1357111292225974, 0.11811067722737789, 0.2178701034614018, 0.20522777470094816, 0.14329206171844686, 0.08941300891871963, 0.12980936733739717, 0.08958328049629927, 0.12824534411941255, 0.10289848529334579, 0.09022486928318228, 0.12410395991589342, 0.1508134731224605, 0.07682900702846901, 0.176187466563923, 0.1467492790626628, 0.3179250588374478, 0.23263678965823992, 0.08525991998612881, 0.13743836725396769, 0.09454449785075017, 0.17819401675036975, 0.139320718390601, 0.12031956655638558, 0.12771923520735332], [0.04556771806840386, 0.07384624172534261, 0.07318013068288565, 0.07617217834506716, 0.0752444581261703, 0.001997946362410273, 0.04072762600013188, 0.02494865206868521, 0.015903088164382746, 0.034267518004136424, 0.01799907605163753, 0.07051282309527908, 0.03388455623228635, 0.08769223732607705, 0.034086824128670354, 0.032457369778837473, 0.029015623033046722, 0.03891963551619223, 0.07922796080155031, 0.006290738021821848, 0.036536657850125005, 0.022332643424826007, 0.04326992368857775, 0.028151769922780137, 0.009563569411901491, 0.04639433317684701, 0.028381165649209703, 0.0631530862301588, 0.06866346233125244, 0.021649231435731053, 0.017339826694556644, 0.03492678602093032, 0.0218180153252823, 0.005185440523616437, 0.056957505111183436, 0.05510909090350781, 0.009659629614491547, 0.039961566749427996, 0.04253683445443, 0.031278815519596846, 0.05896011979452201, 0.04760436128292765, 0.028070567940760936, 0.0060156684069495115, 0.040004070182996135, 0.044434832608593364, 0.03871527773195079, 0.08522521291992494, 0.03992703949500408, 0.0404573247901031, 0.020689267232748013, 0.05191768965284739, 0.03710166038945317, 0.019166873834495033, 0.025003801698663404, 0.050339603796601295, 0.09298109888498272, 0.04114760185724922, 0.06106448080390692, 0.013142454870311278, 0.08227070181497506, 0.03817145905590483, 0.042742152365722826, 0.027427581371739507, 0.015419177345133253, 0.021180884513471807, 0.020316357957199216, 0.027626604174396822, 0.008800950333742159, 0.04687451883884413, 0.013459183142653533, 0.025108043337240815, 0.03354114965934839, 0.040048093535006046, 0.05804036557674408, 0.07579868552940232, 0.055853233473109345, 0.03494604623743466, 0.03420910292438098, 0.028563732281327248, 0.05363978438877633, 0.0031233219238596833, 0.038596435716109614, 0.014096352122058826, 0.04068183845707348, 0.010615855089521833, 0.10003493180764572, 0.017786472370581966, 0.03363824802051697, 0.0041933761011543015, 0.04720909767118948, 0.013961474627389439, 0.028887074573763778, 0.042602947513972006, 0.0480256399272808, 0.01823418165024902, 0.01978324486740998, 0.06761932585920606, 0.021974064808871065, 0.01771583517880312, 0.04386995220556855, 0.050214916201574464, 0.01870421303569206, 0.02000156181332256, 0.03318187554499932, 0.04299502879647272, 0.042015712774757824, 0.0274255508556962, 0.058526529132255485, 0.032437580305018594, 0.015750131104141474, 0.02960141927802137, 0.019121934460209947, 0.05046788762722697, 0.047125654827271185, 0.013933027046732605, 0.021165512302624326, 0.03256767921681915, 0.08066812423723084, 0.015433111061741198, 0.02273151175385075, 0.013529430176796657, 0.017687823556895767, 0.05489156275455441, 0.018116532159703116, 0.048145859369209835, 0.01045854268262961, 0.030339108979595557, 0.06313901341387204, 0.018330864408718686, 0.016427770456565276, 0.020837817208043168, 0.024374652155009762, 0.04500449329082455, 0.04453962555687342, 0.028967179025390317, 0.044612103274890354, 0.05684165204209941, 0.06576697275574718, 0.025353790061282258, 0.04827922542712518, 0.05307178272466574, 0.008652755741163023, 0.05292576877400279, 0.04057897933359657, 0.012329945656737047, 0.009872500468710703, 0.07937785597251994, 0.016381779353001287, 0.06096721959433385, 0.031542127818933556, 0.0015911209380387195, 0.01069212836279933, 0.02759244672155806, 0.03201948059722781, 0.01591116951645485, 0.07859573579792466, 0.01552355638705194, 0.05075113528541156, 0.013341720249237759, 0.011971841167126383, 0.13372648214655264, 0.07274252309330873, 0.10606754238584212, 0.043334866275212595, 0.07534468453377485, 0.029081522354057858, 0.029377777528549944, 0.02455303561873734, 0.026602560820590173, 0.019339011383375952, 0.030663272299404656, 0.022215377306565642, 0.05082086832927806, 0.010668971658950406, 0.03429638288382973, 0.02986404625698924, 0.12849850553487027, 0.08514781243034772, 0.05504342228440302, 0.07343878823199443, 0.039861051964440515, 0.020364452519321015, 0.044183795007744005, 0.027969527291134, 0.036444316019437144, 0.0720195643869894, 0.061329577650342665, 0.02243643892662866, 0.055234385787376335, 0.015258427310202802, 0.010421137591557843, 0.05821952596306801, 0.021915766776406338, 0.01997488860173949, 0.04143319046124816, 0.021565059166667715, 0.025461592312370027, 0.014577478403225541, 0.03762455643819911, 0.02553038388889815, 0.014655392883079392, 0.0392005897260138, 0.015471283745552813, 0.01806855634120958, 0.049758730323186944, 0.011926129111088812, 0.031575236935168505, 0.10703590006700583, 0.037225153762847185, 0.016598221845924854, 0.03279797060947333, 0.020422382446538125, 0.011631145341587918, 0.05587672435545495, 0.016710767056792974, 0.030085364024021795, 0.07887552971286432, 0.050227340177765915, 0.04645159813974585, 0.05668339053434985, 0.02815534240965332, 0.053312852646091154, 0.05474737406309162, 0.03453352069482207, 0.018819346857656325, 0.040327076600598435, 0.015434378225888525, 0.020106342887239795, 0.02176852128468454, 0.02894474326499871, 0.02366014290601015, 0.031575969752988646, 0.022882996393101554, 0.046368165473852835, 0.04524450809029596, 0.05980392558766263, 0.017572552331590226, 0.047417462204716036, 0.019064267465312566, 0.036587826175881286, 0.017987125353621583, 0.007595374265552631, 0.021158380899578333, 0.03839042230642267, 0.02210445549072964, 0.004445529043940561, 0.05573048648823585, 0.031240613998046944, 0.051423271718834124, 0.01913398863481624, 0.04129357170313597, 0.037662910630128214, 0.05644504153834922, 0.007773755184773887, 0.08011012417929513, 0.017508106771856546, 0.05251609647114362, 0.07177940370248896, 0.025087259809619615, 0.04001877064417515, 0.028658265780125345, 0.08914052961128098, 0.044018476735800505, 0.028772809276623384, 0.03979281509029014, 0.03775529656559229, 0.019257493882573078, 0.011179344495758414, 0.052601744553872516, 0.055913843613650115, 0.04367434073771749, 0.04553855802597744, 0.06704815543655838, 0.05148951709270477, 0.036864546327186484, 0.060342214203306606, 0.03589063144422003, 0.0336662986581879, 0.05113322853243776, 0.055012589653155634, 0.05099365727177688, 0.034046997515750785, 0.01866926339321903, 0.05430988182446786, 0.0933739028072783, 0.016503026775483574, 0.020022070534261208, 0.01389504096005112, 0.05797464267483779, 0.05220137157344392, 0.0071993413647370675, 0.05262543560404863, 0.012479854398407042, 0.0762585558529411, 0.027268492051267197, 0.011023909086361527, 0.03997428249567747, 0.02409850706213287, 0.026727443494434868, 0.03837782530380147, 0.0587453566757696, 0.025031273885230933, 0.04911166236602834, 0.02478306577540934, 0.007631279794233186, 0.05853373517415353, 0.054182398665164194, 0.02073305649017649, 0.0607844561870609, 0.05250116530805826, 0.029881002847105265, 0.023185804519536238, 0.031088618761194602, 0.024394731702549115, 0.027734537043475678, 0.050436993927827904, 0.0775719757324883, 0.027064624508576732, 0.030932233402771608, 0.03299658459478191, 0.05074351194447704, 0.013937318780725556, 0.013102815702690609, 0.02420835000728922, 0.01355264540429094, 0.021138091006183198, 0.037638418908630095, 0.05931130237877369, 0.03626478583152805, 0.02844416762569121, 0.045329525135457516, 0.0655437618760126, 0.042288548313081264, 0.012859345463636731, 0.02944882693035262, 0.04904902001310672, 0.08410563013915505, 0.026789293657722216, 0.05035728302651218, 0.013498824006611747, 0.028710190672427416, 0.00492687669715711, 0.010802104470453091, 0.011931871213684124, 0.01696845260448754, 0.040612502356192896, 0.029660821626228944, 0.012809698752659773, 0.06926342978009156, 0.034156808230493746, 0.06481615520481553, 0.17001754763935292, 0.27701230134282795, 0.21734205393918923, 0.1756027186555522, 0.1458711733243295, 0.09800827662859644, 0.15530099160969257, 0.17577147031469004, 0.11973491364291736, 0.09501064462321145, 0.13644858822226524, 0.16841258161834308, 0.0649535721167922, 0.25379614425557, 0.12201118149927684, 0.09756850451231003, 0.1802583916911057, 0.15248144790530205, 0.18391587186072553, 0.09543865772762469, 0.09670953346150261, 0.08668172904955489, 0.15861882429037774, 0.10313872061669827, 0.10181045439094305, 0.12068429269960948, 0.12120692751237325, 0.16451472363301686, 0.2439384146460465, 0.09103242095027651, 0.08441375967647348, 0.11535741282360894, 0.13475443555840425, 0.09398087273750987, 0.2089445045483964, 0.17080306048904145, 0.09069933489497219, 0.0971438976536904, 0.14187218647982391, 0.07819590903818607, 0.10346171685627528, 0.19966025916593416, 0.11349687658782516, 0.12306394215141024, 0.17715847731700965, 0.12595173290797643, 0.13797362281807832, 0.16293128074279853, 0.1690228424434151, 0.11507269952978406, 0.10714389570057392, 0.1943847443908453, 0.09667024628392287, 0.06593143607356719, 0.14482943208089896, 0.15098440966435842, 0.14985281681375845, 0.14951847546866961, 0.14699809785400117, 0.09448961793844189, 0.1294287634747369, 0.10702717410666601, 0.14283753825085505, 0.12496052895273481, 0.10902197885193995, 0.0945365047082305, 0.11607355225299086, 0.07341024904911007, 0.08949998353740998, 0.1291325015148946, 0.07098532774086509, 0.07507929591728107, 0.10423747237239565, 0.13203338799732073, 0.13055864641708986, 0.12312266257192407, 0.13298497907817364, 0.20287043548056058, 0.1320168317428657, 0.11737762870533125, 0.1617482685084854, 0.11097193921783141, 0.13498220619346413, 0.09576921963265964, 0.16657424026301929, 0.13539531188351767, 0.2077534720301628, 0.20578494694616112, 0.14927314434732708, 0.10602335618542773, 0.12669491874320166, 0.07240845316222735, 0.08004334954810993, 0.25275079320584026, 0.1649738204266344, 0.12788634481174604, 0.10297928524336644, 0.11850354900317532, 0.12306319576288972, 0.10864314596567835, 0.09119219559111766, 0.19273213164082595, 0.07566930925739662, 0.1311974057129451, 0.09283753444573709, 0.1887298742575305, 0.09696204348334245, 0.14315691111343248, 0.09840939260487046, 0.2149630015982049, 0.11395113542675972, 0.15134507816817078, 0.11382434437317507, 0.16864929534494877, 0.09471996022122246, 0.11102050196911607, 0.12740288861095905, 0.06737317371049098, 0.16352373680898122, 0.10379379867975201, 0.08833183122000524, 0.10756064512367759, 0.09943517470466239, 0.13036347260432585, 0.11886003773127284, 0.14961815226290906, 0.07772296334483794, 0.15224852040410042, 0.11307883794818606, 0.07601752664361681, 0.2096289699631078, 0.19256112724542618, 0.13250788753586157, 0.14749300772590296, 0.1437570210546255, 0.11318561900407076, 0.14025744955454553, 0.12398030369409493, 0.12331662859235491, 0.1342986093035766, 0.11779517201440674, 0.1708955040999821, 0.08116618251161915, 0.10019935441336461, 0.12026745506695338, 0.08582768416298286, 0.20954930995191845, 0.18053121705140385, 0.09238873781370265, 0.12435608995812279, 0.07241057019148554, 0.09523447975516319, 0.16212359336870058, 0.1242050752043724, 0.14273596155856336, 0.10630421540034668, 0.18426834366151265, 0.09725732156740767, 0.08936325873115233, 0.16693702579608985, 0.11553315339343888, 0.24626310276133673, 0.1448681221476623, 0.22122886537441186, 0.11707505636981555, 0.13419019297829696, 0.08723290983055319, 0.1955104068453823, 0.07894539846373455, 0.0851264317919101, 0.09260121426944222, 0.050689934819404564, 0.10001377508576427, 0.146333798500044, 0.09836896548845939, 0.124891657648342], [0.03015474762235369, 0.03694086455340896, 0.03991306506629501, 0.002851774965945099, 0.018379152353320802, 0.018603362375870347, 0.01574761713189738, 0.016612649196758866, 0.04136096719386322, 0.019685732599880015, 0.07013688076819692, 0.04378138981493456, 0.06201831105032137, 0.06037428855363812, 0.06340063616101231, 0.045956773084721396, 0.008105714023778481, 0.02648691470468683, 0.02727106709166297, 0.059904959451939375, 0.03629631056849446, 0.020534752934638942, 0.05775044791932617, 0.029523055268717662, 0.02941466269216367, 0.038093315570482185, 0.01773297836604927, 0.018316162251202122, 0.043360660783946514, 0.009148156702784556, 0.009316520748793014, 0.0497012685851327, 0.02379525958427361, 0.0016876831505214795, 0.019266289392752305, 0.016775779193267226, 0.04942799199904714, 0.015002575503396136, 0.0627710913707103, 0.017079264158383012, 0.04945094683872802, 0.036546700168401, 0.026393605961597393, 0.02196412087817277, 0.06052768496530397, 0.05006448159526501, 0.09688998306436197, 0.0637481478708131, 0.019483871824507202, 0.009302997545871352, 0.02464658354542085, 0.02528138189310474, 0.028514043161911622, 0.09216350489961249, 0.025533620500937104, 0.04987313811268125, 0.015317259688994713, 0.05959951691329479, 0.037240604005221806, 0.017210843972861767, 0.007603913628762322, 0.025419558764302304, 0.005715876792757106, 0.04103878180363348, 0.01845641035054411, 0.02021413156762719, 0.020758918852412274, 0.03725679385076676, 0.05245308431663683, 0.06546394580176898, 0.047279112307088714, 0.03181002022964614, 0.019436472760779516, 0.049894403400165696, 0.006301024612704558, 0.019610014877149036, 0.019161396360556995, 0.046726642309554985, 0.0624354336676853, 0.07915135419794492, 0.020260848703661134, 0.00766163575462997, 0.047843935034636936, 0.029648170340806246, 0.036791468105678043, 0.08408074826002121, 0.034540034631001096, 0.025552127543570738, 0.03579370950215629, 0.010533252780857896, 0.08736728012029614, 0.022858589488480772, 0.03459744208625384, 0.03470298820840461, 0.03901182806917599, 0.03637606557458639, 0.03590824621330414, 0.04700599517673254, 0.05476641375571489, 0.008366392759074057, 0.0530728073125439, 0.013804940839431115, 0.0367620230785438, 0.08491882043225424, 0.05187974936727967, 0.058204068935343196, 0.012778448822375919, 0.03297115310228296, 0.048359723429062536, 0.02081443658763809, 0.012571623715172921, 0.029482994561216662, 0.052309920213052204, 0.020349998027086258, 0.062362145100321086, 0.014070837509020098, 0.04907313854034458, 0.0288377654339586, 0.051799149585089514, 0.0328948280907103, 0.06550849162574325, 0.004770736035425216, 0.046792714656995874, 0.016442772865827595, 0.012801162782125175, 0.03333168250641652, 0.011770975293724664, 0.018051650641219955, 0.01534743414127401, 0.02822098897637001, 0.06666352786123753, 0.03083582714732204, 0.027011559677443335, 0.031096411735883782, 0.015886825376323292, 0.03944951708295515, 0.015471271871189986, 0.02911058740158166, 0.032643814238586595, 0.017151443320991736, 0.026408163930422494, 0.049663321514214785, 0.010543165329311575, 0.04036961056824241, 0.023463405070028136, 0.05058121654604163, 0.11313005377139364, 0.016480635119868175, 0.06440557366503136, 0.04493684674214039, 0.06678018160164356, 0.028677749913185835, 0.015046151022293737, 0.03940105611192329, 0.03969060396775603, 0.05178770609200001, 0.04272866987490228, 0.03808061678760818, 0.05092016853658216, 0.01776087294066591, 0.03199010342359543, 0.03154499802206244, 0.034267165165926726, 0.015713910904846022, 0.031365091247217994, 0.03403652772041304, 0.04494604767699327, 0.05088689657194274, 0.02171217404039843, 0.010917748041850115, 0.033024791295507124, 0.057249302310603004, 0.01517734067913677, 0.022606878441625407, 0.034563104821635146, 0.02541312964500061, 0.010261150060354598, 0.04804371949285269, 0.03461326552288873, 0.03253591020724603, 0.03562473053378718, 0.050352339898901324, 0.02033377595112792, 0.0008593512954705927, 0.0017872555139807186, 0.014484403754717537, 0.019342002026470642, 0.029073868479047502, 0.03708074454750333, 0.024597042007371783, 0.04057716764509678, 0.01959514817489045, 0.02211318993275719, 0.07750707385795456, 0.02556919269928975, 0.05507615820637771, 0.03099701992635216, 0.02552953572012484, 0.004234782004329775, 0.07132058510822908, 0.04251986090093851, 0.0037239575176499784, 0.011093923722260764, 0.024267935559951832, 0.03552532854623028, 0.03601205189313207, 0.011457478544408721, 0.06333851628005505, 0.038569779467902014, 0.059920077212154865, 0.018739532479750257, 0.030388740423534597, 0.0223587025622172, 0.02425907219627074, 0.05823515262454748, 0.03429005215210574, 0.04936990261610065, 0.035451785528234074, 0.038514801168016026, 0.039094263288591585, 0.017022055174623216, 0.018216865436573113, 0.007900622573548129, 0.04910528752952814, 0.06154694634356669, 0.04791659256443381, 0.07954904357237474, 0.03221100728426661, 0.09067808317818812, 0.029629018689904894, 0.01021081124365862, 0.057202476608966074, 0.03827743265511734, 0.08214106769966227, 0.005796194558830133, 0.040798173286020756, 0.05714731849730015, 0.0557750899876867, 0.03319943603128195, 0.024226085216339146, 0.03187142086348363, 0.02613700437359512, 0.034761382932109494, 0.02172729010427637, 0.025245796124051725, 0.01594393257983029, 0.01187896159743624, 0.04375121196998017, 0.042069055805248876, 0.012813808130366462, 0.06677264986293656, 0.018360892975968972, 0.04320717616272824, 0.03202282577486975, 0.026694385268326317, 0.08886361268482038, 0.027657070396734134, 0.060572705763791285, 0.02248760894872248, 0.002524439070839435, 0.04498948409621205, 0.026775668674547757, 0.05145661492965051, 0.05252593522891402, 0.018211542329351817, 0.045507840745683224, 0.13600372709333897, 0.028359657785456096, 0.019512546714395285, 0.03475725743919611, 0.013091729288654668, 0.040741468114512305, 0.0205851019293602, 0.013186386620093669, 0.005661912902723998, 0.03427587755556617, 0.0281914252056075, 0.05080597109294363, 0.020996317899386798, 0.02431715140119195, 0.01793215553542333, 0.01834565816846277, 0.02907578194780009, 0.003226168960931578, 0.0756504459838782, 0.02953942831871765, 0.006904079819962914, 0.044637283709432395, 0.03258378763816186, 0.01966067260530378, 0.006109444491033043, 0.027573045709037354, 0.026541160186752677, 0.045563667214342525, 0.024072181599746858, 0.026497850992849896, 0.0490373322474105, 0.03321898462516921, 0.052468541344361644, 0.024947057511391382, 0.016025711316615343, 0.037217147049627135, 0.038434822245367935, 0.019651520864239762, 0.039968525126044235, 0.048440767651689906, 0.059823080631239076, 0.022771299351006746, 0.07403907459229231, 0.05766392791909831, 0.03754838409700564, 0.05453463976404496, 0.04834680751498256, 0.021811623525406634, 0.07412735878356866, 0.050410293574844084, 0.0398422836858247, 0.003850175209143864, 0.054765253460833004, 0.01607218078736748, 0.057368887322289605, 0.016278133128902743, 0.009099770370604736, 0.022789087146520615, 0.0033967868034129162, 0.14036699224795612, 0.0355725579762033, 0.016767297505534122, 0.014158088630730552, 0.023928020049684813, 0.028104945917480757, 0.013825214617619557, 0.049580658985567946, 0.026300237846693823, 0.024689183670229146, 0.015259460379768695, 0.08712447314922299, 0.06591696292161942, 0.03050327713468245, 0.010184099864480751, 0.017406882917774574, 0.030205227235066037, 0.07203232763069016, 0.024264446193618432, 0.024364379134827426, 0.04786588903516531, 0.04006813406678183, 0.02081465711151915, 0.011659634482514645, 0.04081751831940242, 0.04363294331622975, 0.014324534118973782, 0.10254431715501205, 0.12173178791999817, 0.1397311777940818, 0.12734726231013024, 0.08602837446544852, 0.1409517672977277, 0.05111708618434412, 0.07444706412830523, 0.13710517941841058, 0.08050163888505527, 0.12417988798448018, 0.11464884584503514, 0.15467445951487335, 0.16071485967508384, 0.1487595069089106, 0.12845997831651143, 0.07504347605364663, 0.10009391007146665, 0.15066173912159034, 0.14055494644812175, 0.11167532218886272, 0.10970603714564017, 0.10762091260403395, 0.15503130108118057, 0.10059751197695732, 0.11234074791095086, 0.0820000816934875, 0.12280824301498276, 0.11533818314118044, 0.09004082344472408, 0.13953395480556147, 0.1451079435646534, 0.2007250977413995, 0.10999361385724374, 0.15262362813310965, 0.0747565778770617, 0.1258774468941348, 0.10817972011864185, 0.15646249428391457, 0.13513471372425556, 0.1399874740413257, 0.10754489632589476, 0.16943636882518018, 0.2004053448992116, 0.13152150117925235, 0.111772881953844, 0.15637421687798841, 0.2193276916763612, 0.13244238176516124, 0.0910764578729868, 0.20776800625026226, 0.11401449702680111, 0.13925437123647758, 0.2024609124554055, 0.10303980378167969, 0.11226365276213203, 0.17777727411261626, 0.1647878611194236, 0.09635020167167697, 0.10900783818215132, 0.11721649020910263, 0.09317883077476706, 0.17421602377934114, 0.1065468934497663, 0.07431467516081673, 0.09088580310344696, 0.12822200251477106, 0.10506818922502653, 0.16409171133169106, 0.2322127324129854, 0.10809850626225982, 0.09134979891989913, 0.16505596387599195, 0.11656915423061166, 0.11464740735079561, 0.08702244862381901, 0.09036630312246935, 0.19493066652544908, 0.1968880229230438, 0.23334110900759697, 0.061803310444312434, 0.16997009090014867, 0.08722904896629707, 0.10449424359415259, 0.09819343526448522, 0.18406631664506026, 0.19185401233179228, 0.14210045923079762, 0.13958362356892653, 0.10181284961955887, 0.1886041552892753, 0.1521725244820118, 0.11814041063189507, 0.09964032298220055, 0.13662214390933514, 0.167376024382455, 0.1017060074955225, 0.13959802208202227, 0.08887276612222195, 0.18261574448219367, 0.20944364847881453, 0.11248287385595696, 0.13897917100361415, 0.16473241123769963, 0.08753469506544725, 0.16176350840500422, 0.11984577269426414, 0.1130278053294335, 0.180465182023389, 0.14100207388401031, 0.08362072865877833, 0.11880974471569061, 0.1422775297292641, 0.08858915205512728, 0.08488622360995837, 0.18257214182189532, 0.1306978953736169, 0.11092898116580077, 0.11025322814072881, 0.10534992375011955, 0.16676923765667848, 0.0926525793703539, 0.17346898386520998, 0.11841316813869135, 0.11298782604613475, 0.09679479817194597, 0.11912073088543755, 0.09593693991856915, 0.10534208667065416, 0.12074219887810093, 0.1889747439750603, 0.0742184996072735, 0.16945341362484864, 0.14905978579606327, 0.10827770057533469, 0.13128535742206232, 0.09034682916743414, 0.10177679905401808, 0.15517030576510088, 0.1984139938971826, 0.08839080269847598, 0.13011701511485235, 0.09643339006496326, 0.1314714660069772, 0.2833682745695114, 0.16401956948850835, 0.13650235533714294, 0.058201314083167484, 0.14247089863887855, 0.2127025436077799, 0.1980006710759231, 0.09273443783500365, 0.08621721076113836, 0.10606138807322298, 0.18277107471866266, 0.11988174862095288, 0.11155370157212019, 0.10831686561661107, 0.10079021592225347, 0.06494205737752573, 0.09937598609498569, 0.11281492853803293, 0.11239201123160975, 0.0745583303006632, 0.06499507131853274, 0.11025402202670063, 0.20915411758635724, 0.20126373240990297, 0.12706090696156025, 0.1243016171668257, 0.07305452706558363, 0.13593178881066187, 0.10966037173888513, 0.1554134791450841, 0.12959998500134262, 0.09208385845912354], [0.02145073449771319, 0.01873758338790919, 0.018786811103512133, 0.014165992715529032, 0.01582600997893938, 0.05637856206989714, 0.030405900574156215, 0.04742930603346654, 0.06335113024605171, 0.0241380520830197, 0.028397504772458757, 0.056776638209287605, 0.05432411748915911, 0.03184929044385042, 0.09436486927526337, 0.04028278522725616, 0.052495353655623536, 0.024120941126186932, 0.011454576110866452, 0.033000642234193425, 0.024716418369540145, 0.012353720675621713, 0.03274428152612277, 0.06625253241509199, 0.04015143781102129, 0.028785178970013345, 0.007974068052135408, 0.035936741291412284, 0.01251098558506263, 0.05971774485494409, 0.02273267204873264, 0.043610019010624716, 0.04693710012361407, 0.012719078704581728, 0.0592896571116788, 0.009556129275422012, 0.021616934865180935, 0.02795962746521192, 0.041377920391304154, 0.05966614226677588, 0.03691650175356439, 0.02115047935928617, 0.06818637078894035, 0.11006367259791919, 0.05599521692576153, 0.018428045890427062, 0.06385334794010435, 0.021771355864724944, 0.06721635069698095, 0.007791033230854997, 0.03577784535342029, 0.10522923272635255, 0.03944181910316859, 0.08821514355284826, 0.04763408111674445, 0.03603656736335584, 0.07054079230874777, 0.03224652859249285, 0.015286905424935477, 0.019518577194373523, 0.03867838239031179, 0.03806220813255225, 0.041958023727472336, 0.024455718430025235, 0.026197332922103148, 0.0423564052076212, 0.029412498165454184, 0.07863751319902283, 0.020732598479038904, 0.04186167175482426, 0.03744561657575624, 0.007572189572134188, 0.006526425040127444, 0.02607041464320251, 0.03562169408957873, 0.05292114795052579, 0.016435985819303563, 0.04241422317656023, 0.058791374920734336, 0.025769681137587343, 0.036169543263635466, 0.028127629343154173, 0.010205999582207628, 0.03565606528094836, 0.042593651584216526, 0.0143945589328983, 0.024117723173860992, 0.02235416485927999, 0.025628936011344194, 0.07529154845646449, 0.013079424056091478, 0.020823104872501323, 0.02948800554232938, 0.03138951511521425, 0.006486554322431662, 0.0264565316028893, 0.02955728057505829, 0.043511444835790565, 0.04150627886078187, 0.04107495450547763, 0.08726024800645453, 0.08313370336379323, 0.04520860340978418, 0.07505968625524215, 0.014124785283846515, 0.042858734859951904, 0.02705047874977546, 0.00708684153089832, 0.021872783279312507, 0.0458364348991641, 0.01663034878272031, 0.02170229117785181, 0.09474921865122658, 0.03123395417683891, 0.054540743186537705, 0.09207693061658315, 0.04556236442710672, 0.025614734273403883, 0.020294400563995754, 0.05208265508658119, 0.045065653044730425, 0.07775242533534765, 0.006750923864144299, 0.014152712088876536, 0.017075578016894202, 0.00836532491458846, 0.02300387740667377, 0.036317009279238324, 0.03440088066937668, 0.03312749096325465, 0.025316017713131647, 0.06195490873817887, 0.028336131280022006, 0.02267100169722523, 0.024681767282475318, 0.03789918330897178, 0.01387927689523037, 0.0167395963133978, 0.018559447589463422, 0.005874879600014538, 0.055472083389759064, 0.02089990146591195, 0.05659699945577553, 0.035822720266878605, 0.049476714206061194, 0.056512973071741204, 0.060946558203016005, 0.010224488813297024, 0.04537025419995189, 0.016752641149131314, 0.015339695449386324, 0.03770866085376058, 0.01347253077463912, 0.04261064210108348, 0.028811329709632055, 0.01957571323561881, 0.0646097312814423, 0.048271982065801106, 0.040907403853322775, 0.015500655830172556, 0.04319803290335195, 0.08595830215407269, 0.017527460286925946, 0.008175311360641249, 0.03560311919344323, 0.04019060285229768, 0.034245448652654886, 0.05086916645190545, 0.06135286497218268, 0.02490134460718504, 0.0252102900828634, 0.052068857076976977, 0.05169076379388571, 0.02777350361325911, 0.04466646071523428, 0.03484618623874017, 0.02851268948454942, 0.021189417091331313, 0.026096672252086655, 0.08787490573844739, 0.029694819623338323, 0.021646591934508512, 0.01865413715131581, 0.018630826080750142, 0.059702491387724876, 0.02674437972850033, 0.021693719584228735, 0.020997091429308057, 0.0023379070376644707, 0.014945693912782838, 0.059750938788056374, 0.066512580960989, 0.038055507599243095, 0.02106171171180904, 0.02601990449641432, 0.07435738215489046, 0.014946182457996266, 0.02654303633607924, 0.022152477110336934, 0.05786324758082628, 0.04433848402862038, 0.04250455993626799, 0.04565553067784224, 0.02346376808626311, 0.02902075954313789, 0.029883296295468296, 0.022732643210994344, 0.05734689600233521, 0.04088432687733855, 0.06397738414151327, 0.03759305884263345, 0.007522879584160234, 0.048514229245483875, 0.03794497424470527, 0.08067300968936511, 0.017969675129279494, 0.037382333007241995, 0.042765646640743525, 0.03117719472252897, 0.008860864975888814, 0.019800472871533463, 0.07517380227467843, 0.02367878395930997, 0.013464892166666687, 0.026850385558126227, 0.03970216281179871, 0.00678646086349285, 0.08270075052444424, 0.03263278465185847, 0.1098754605544465, 0.0907571596492614, 0.02958504283534629, 0.04085800989664026, 0.02072096669248172, 0.03570556780323386, 0.019847753191632882, 0.044617721544844766, 0.024372999922239354, 0.026696829690731, 0.01038864763852741, 0.03470116973455463, 0.06847073802990572, 0.0530044313387147, 0.03313199643577848, 0.022368995938450098, 0.016725611706663455, 0.011840872882333184, 0.02182738419755229, 0.041923601645976305, 0.025190863625279496, 0.011982208334042557, 0.04620753927156329, 0.002264395189870681, 0.017617340731833662, 0.02630211738869548, 0.008119718138394611, 0.027443213122231618, 0.03047592538808073, 0.012863965438944953, 0.011383757410970117, 0.017153789355818714, 0.026265369628423026, 0.05340950656682253, 0.01091278116551361, 0.03309013761047806, 0.030011661550296203, 0.022497766617951647, 0.028273809534896697, 0.04022947273084095, 0.04214959791196244, 0.026495140245450393, 0.06426386841173683, 0.0546281995650913, 0.022680653857865503, 0.07669770371701036, 0.04385671738002982, 0.092008629281606, 0.0077764286127473626, 0.03265517970014896, 0.03204250329041055, 0.0947392238304019, 0.04514404758810997, 0.05133506216640983, 0.010636213684587606, 0.013485862291418016, 0.03929226319970829, 0.023122802543054734, 0.02245538023167423, 0.16420732012816838, 0.03153624152764678, 0.04277054227090307, 0.01898084837011993, 0.06496083244149174, 0.018216607593266026, 0.04955031489953399, 0.07481520330267293, 0.019881688424253037, 0.026292400767228434, 0.0549244988443596, 0.05394281812810472, 0.051135104681764326, 0.0540560859787677, 0.010097050606938345, 0.01109518070838281, 0.08240383038563387, 0.023255318735859225, 0.01926117154237415, 0.04941901158807533, 0.04024569311046174, 0.04485594161919185, 0.02604810780446444, 0.052411412088466544, 0.03935223212465644, 0.024715476902201772, 0.031245187324072634, 0.006727285824516522, 0.06991394130246979, 0.017565575295260975, 0.05986907173480306, 0.03035261861181685, 0.026127433637157083, 0.04656488634645939, 0.014480232460690396, 0.04758634278550744, 0.037572760467550585, 0.02892616158351302, 0.01739777867416186, 0.040809603208409886, 0.00971299215286438, 0.06138225232384034, 0.01828624733856746, 0.031672403149838955, 0.06622722984424659, 0.06937893001096589, 0.03992161460752998, 0.034928251656570604, 0.01245754077431879, 0.013941489226583923, 0.007280416969609047, 0.012558911361598542, 0.021356511428686123, 0.028836832448307956, 0.029777719639241695, 0.08709593396633863, 0.015318789785461766, 0.03298146344189133, 0.02941105288586446, 0.10024047363549471, 0.09736739351813282, 0.020269062370061874, 0.067259396958564, 0.021923430829441974, 0.10887627024203539, 0.12534852884709835, 0.12303336736346994, 0.12625509234411375, 0.08193625868963343, 0.17018229594188078, 0.15989034463252338, 0.1194724834391049, 0.13962263933249883, 0.06845238365765129, 0.1410392304616315, 0.10782352994595255, 0.11687882404242243, 0.11368191987276077, 0.1888696931834732, 0.12407832486288888, 0.1550624051264354, 0.15683510500405515, 0.07178815001887934, 0.21023080338324818, 0.18449439081762517, 0.08358617087027856, 0.09613581174718482, 0.15277799484985216, 0.19366522585707052, 0.05805828568658658, 0.12332979217171669, 0.114051097205707, 0.16030714155307837, 0.1441389141338212, 0.08754072045641285, 0.12111219045306955, 0.10241826570459775, 0.13723682878272875, 0.1344578614724534, 0.11068074591457844, 0.12021485503230776, 0.20010999217629433, 0.14671475520091398, 0.12159419458891664, 0.13126943899052484, 0.09925822634249926, 0.1318787770079715, 0.3294067941606045, 0.08441941187317882, 0.12441852875053883, 0.16895603388547897, 0.06360483448952436, 0.09399875213525125, 0.15131177566945553, 0.08673099069190876, 0.24595160090497561, 0.14196214665259632, 0.17032938876322337, 0.16125221869775228, 0.11712856564138617, 0.15196687408855983, 0.06397288545433964, 0.1582902776343482, 0.08206211336489234, 0.0987082737098847, 0.17171328807515757, 0.1245272300605263, 0.10224485250988177, 0.15920438644077095, 0.16119860086057866, 0.13277266547083855, 0.15250027046671935, 0.10371835237102849, 0.09437892852084977, 0.1073465266131929, 0.08954627319638218, 0.17582381250602858, 0.0878176170268229, 0.1345800520586116, 0.18196431015219006, 0.08983530197292566, 0.09290411908711706, 0.15134395180003984, 0.12540948843317373, 0.08350530306675605, 0.12016263497727257, 0.08099528668182236, 0.17835621376122746, 0.11441169785601751, 0.06997070075677973, 0.14757002145051956, 0.0589110752833741, 0.07106483847435031, 0.12864992740963185, 0.06946800808821406, 0.18069447257689067, 0.12186921840267521, 0.13371422780411585, 0.1267437054110425, 0.09208326813365732, 0.12573950072484358, 0.09887902704732758, 0.1464504250990493, 0.10184782131442002, 0.18980452444936546, 0.18557582635964665, 0.09376424364745617, 0.15412308195871965, 0.17277856091303484, 0.12080815248191357, 0.11868587136268616, 0.0983399445457118, 0.15588028409651347, 0.07631813122757844, 0.11806858091482095, 0.11559777706861496, 0.24193204087870462, 0.15284685258354458, 0.12631218428058283, 0.16363021252410753, 0.18528229211057934, 0.1767699753067323, 0.08209433699292795, 0.14384787689362252, 0.12627015582152776, 0.09592769148626498, 0.15745646666203225, 0.16298550926148891, 0.13131088390946388, 0.059752282287393294, 0.05239131388121417, 0.10671696146684033, 0.13117143139243126, 0.07527129418615784, 0.12318913186235086, 0.21710733510553837, 0.15018843380468233, 0.1847614622009652, 0.08005427396191017, 0.1312904464347022, 0.08682388213596173, 0.05327795898275716, 0.11058885191700288, 0.13516048448426382, 0.176015580072999, 0.07490253754492317, 0.18211296360407556, 0.1639893882508789, 0.10253147927245923, 0.19022459190871033, 0.15191941734935555, 0.11727037946028368, 0.07285000982561282, 0.08271466727767672, 0.08260898544852223, 0.11679479426571301, 0.13303555707846368, 0.16663811754967484, 0.1380009949207306, 0.0699093204789928, 0.12970933770494802, 0.2062298623578889, 0.12375066030238356, 0.06834863565329995, 0.08093648483710629, 0.11082065305007355, 0.12841588711099966, 0.08255686717373983, 0.2642726706607001, 0.09684566115694386, 0.1036553911066481, 0.15871943746294292, 0.14072472948048795, 0.11814159128282752, 0.1114427475258708, 0.16711201997739927, 0.21550832662199224, 0.2426321804523468, 0.15976599630500588, 0.08151822683534451], [0.016188900684937835, 0.034103566980255504, 0.00371312046523339, 0.018627024588308165, 0.05342729775501149, 0.010909771862705904, 0.04205222135143621, 0.06222587491252592, 0.020832667127251625, 0.03575635954205479, 0.03697927302813955, 0.02370683629331844, 0.07088677052940641, 0.010128158893037056, 0.01101490662300161, 0.057127837756914754, 0.033924406593931575, 0.07147462612816266, 0.027567805722355843, 0.0075781174236908555, 0.0324133294634521, 0.018894453898870518, 0.050592042572264156, 0.05481939376997096, 0.06266329929764781, 0.060784103348851204, 0.01578884831230555, 0.028509171280477728, 0.014116458810998924, 0.01888207233111773, 0.03836626645975879, 0.010077607185978974, 0.017281715259222046, 0.1121907170329775, 0.021265457118196145, 0.041881783532777, 0.019166848389431834, 0.025851977257324115, 0.018384419481403062, 0.006234169829570289, 0.021777299831488302, 0.0490016854102058, 0.018748947153134004, 0.010090064240752586, 0.034956760305379114, 0.05496135686657258, 0.046492137214435, 0.05346603531922613, 0.017220991464065652, 0.025924989321668233, 0.032491422058748345, 0.09555902983993292, 0.07229405215808324, 0.0389446531023298, 0.02627113039073135, 0.049075021475021324, 0.018289640013660704, 0.043381013441830873, 0.01442429912276566, 0.026873981613399725, 0.0301603150021817, 0.021819784605343426, 0.02044426180821444, 0.015548368716346366, 0.024080576774265085, 0.027624063060751984, 0.05954961744802339, 0.022054747711601, 0.022875978644671183, 0.019208866670461636, 0.0330112002390836, 0.05384164855682424, 0.031007167417556047, 0.03641753763492618, 0.017241016728803515, 0.03867073190797653, 0.0029791652507680866, 0.09411275280373436, 0.023825917492753694, 0.031240332406014204, 0.03334137537915792, 0.016793036035129, 0.03853791207075119, 0.01898477369520281, 0.010426775369394039, 0.07459105604461261, 0.04268441242831094, 0.03419363571863089, 0.05076564236411026, 0.01926050827439342, 0.038911394708390744, 0.07690714033586638, 0.08265758891190801, 0.008362459800472217, 0.022835965434621488, 0.027408745239621828, 0.03727401167686496, 0.007221861942006009, 0.018632059318146536, 0.03479633427092007, 0.03395559884873884, 0.03892152523621917, 0.06172618815409286, 0.02191827735597534, 0.00958974814108972, 0.051319527107157877, 0.02241309223297451, 0.028859539622707025, 0.043392351761992486, 0.030860383329646926, 0.030755230757806982, 0.0427891544864646, 0.057005525034453185, 0.048233163077384233, 0.05034986663875835, 0.03330997956384506, 0.02359963284938463, 0.024949456132682304, 0.056435148497777324, 0.01669904706068337, 0.024691081871943812, 0.02666486390600247, 0.056948093830474784, 0.031152339984795878, 0.0794755243031042, 0.035140941850841045, 0.02404006484097668, 0.04938533250242472, 0.029154000072074786, 0.018747924261593392, 0.050881787203252316, 0.06456401837723595, 0.05729929677077702, 0.0769551263323852, 0.02350528764405421, 0.05429226705538375, 0.029707745715443577, 0.012559410933006023, 0.042622628422187905, 0.04951738898775407, 0.03075759545234697, 0.046593578199722936, 0.012660153875393527, 0.024651910045317242, 0.028628797004265443, 0.04469476241086211, 0.012605934686559652, 0.0681506119934576, 0.036933970637619495, 0.03555781341024807, 0.03535202391711729, 0.019468352032293166, 0.03817225633455174, 0.021836035519040058, 0.03650713139878852, 0.05504382601273911, 0.04780923814645835, 0.03135910996102861, 0.0031225710824531105, 0.06812687005315508, 0.07426701486110687, 0.0784234693273902, 0.043654161106262884, 0.023316585359030535, 0.028780785455767597, 0.023113347157569866, 0.018665850362075225, 0.021534365635099154, 0.021540933854079673, 0.039075165920491726, 0.0033925523208121634, 0.01385873933655343, 0.03281492719958935, 0.03967853622244937, 0.05225757462903857, 0.046516048788492165, 0.046713678898023706, 0.05018179012196405, 0.04531155074281352, 0.02730467662747417, 0.044953687981303246, 0.02685076553773667, 0.07637195941060781, 0.055111238466841836, 0.01746307240266885, 0.029674317687749863, 0.024597469484433532, 0.057144638283976486, 0.1098408145563943, 0.04339840090168374, 0.015722482498469095, 0.05704657640308142, 0.07220407841461045, 0.07099465081202132, 0.032006951448108466, 0.012519750561166023, 0.026504602416285446, 0.018980181709464108, 0.021747759809451442, 0.033566869529230256, 0.05291267644081797, 0.049933592190167735, 0.05175923815529261, 0.013945528206282427, 0.06377470573144299, 0.05855099031967776, 0.054413307524685345, 0.016551111159580092, 0.025165830772104006, 0.039895735281918726, 0.02825671384510185, 0.020671957804422294, 0.023557831699560796, 0.04221815030489649, 0.02750002177033041, 0.04455795278772712, 0.01156752250556435, 0.023411319025659134, 0.018990936489509683, 0.019467990712395737, 0.004984139963718397, 0.040938328086797676, 0.007565524661913514, 0.013176464741783482, 0.05762877980513232, 0.052730058918574026, 0.02528622663313789, 0.10415076916771275, 0.027276612419102873, 0.05293331408341016, 0.04492146096059254, 0.008021801294359778, 0.07319364710045712, 0.06016208351190601, 0.023028757589470063, 0.06657388659992389, 0.054466365570468564, 0.04802004540605204, 0.014546281059405633, 0.050268194771238735, 0.04357451805844903, 0.016440944213952337, 0.028138908291501657, 0.014266387060550707, 0.03709980798885226, 0.02763133865248944, 0.05968662045363869, 0.0069120568472759, 0.03878900395440204, 0.01704922710944499, 0.016223646766905273, 0.04291531110980681, 0.0346660928667656, 0.038856022858193943, 0.007338981327068592, 0.08379498323691742, 0.03515114701752152, 0.03889664335708533, 0.005101043489828173, 0.02965240439932261, 0.029000820791614906, 0.07805609689759356, 0.03873256680422595, 0.05103336514106818, 0.05539874053959336, 0.02757518648702119, 0.029142308913703476, 0.05542364616745284, 0.16728503283645424, 0.07281815939183746, 0.04673235218173691, 0.02362740189502282, 0.032488521321543624, 0.02926648421479123, 0.04307741312576192, 0.07701535310064044, 0.018985645612701774, 0.02535406656430236, 0.016439239394717982, 0.06235005360628877, 0.03757147464369025, 0.04124044919652598, 0.009000562613696923, 0.052048762262399705, 0.04525240623791303, 0.028102618542366793, 0.05130544750552092, 0.052212173850940805, 0.058142179756292274, 0.06353074525083814, 0.04990508693403431, 0.033498225534068685, 0.0764297027406948, 0.03164535674399563, 0.017732164124026895, 0.053369707095303705, 0.028824900410005024, 0.08041237760335207, 0.03900633193552494, 0.029035894266728843, 0.048921642026730945, 0.04696308122947812, 0.012550544176649834, 0.11346674963299717, 0.07243747410497495, 0.027543239362005676, 0.04357064701616764, 0.04919379563736064, 0.05904700620365994, 0.027372216306892887, 0.04699638033551829, 0.04233076676194157, 0.019828801708562032, 0.07854053018880741, 0.02589999378791877, 0.013566855623918985, 0.03872946589919073, 0.0337765470280179, 0.018441874434107115, 0.0208062975600894, 0.044262593279459646, 0.07470772335571901, 0.03661775974822896, 0.04001450265890785, 0.007097641263888883, 0.0234668859546738, 0.05573996562244637, 0.029282480677855865, 0.006752876772744847, 0.021518562554514835, 0.012267467000388672, 0.02848362104435052, 0.021367792073371153, 0.035695508521582396, 0.03673052548297814, 0.030415142221110206, 0.04056599556601473, 0.054106972712491236, 0.015225818613544106, 0.03008337252374206, 0.030382178989904265, 0.010469176174540604, 0.029286205835108246, 0.03240085459713425, 0.024773320316204002, 0.0296759563498199, 0.03151672346783536, 0.03295059349121792, 0.012759487161279788, 0.07463276559220892, 0.07844999326126915, 0.07340056635439396, 0.12349755316972733, 0.13908580956714495, 0.16163061053625175, 0.11551120957093579, 0.07711887718843562, 0.11562415851014, 0.1284568163433245, 0.24784265086054802, 0.17457642086914607, 0.17257741599210671, 0.15815824829041958, 0.14071187802723475, 0.24186074041894504, 0.09453296275543314, 0.08788694294967822, 0.1493534150400332, 0.10141947572784764, 0.12454925530723163, 0.1194298035864319, 0.15589126279311522, 0.0713019050391657, 0.16621331391589983, 0.13437445594796113, 0.09635865621800933, 0.1347049567848444, 0.14019913625504288, 0.10559988926563944, 0.07598619189645563, 0.07843423089278595, 0.057486294236566336, 0.07877687750650303, 0.10540901057954345, 0.16998271165149553, 0.1977031606116465, 0.09966110650982175, 0.1346938152398382, 0.09294745711875813, 0.14857096916862897, 0.116015849635005, 0.1025528327694961, 0.12197342781083924, 0.08652633095958404, 0.12111624809248106, 0.22042781407279627, 0.14795188738831452, 0.19476023209946497, 0.09896851224558693, 0.24697833295379365, 0.15299629313605173, 0.09275849868676492, 0.13583470402019365, 0.16220819311482565, 0.16178607647972448, 0.18174503477556364, 0.10547884540366274, 0.15533782249050482, 0.1338288595101663, 0.15621139561491354, 0.052722160770956955, 0.0998458308832986, 0.0881445894816092, 0.217877933755517, 0.10490235526646886, 0.0769796689440097, 0.15688471948461874, 0.11756206809410027, 0.07478939183056355, 0.07648029431168522, 0.16153809907180922, 0.12189850397408009, 0.14932065536933287, 0.17179453585829052, 0.10864409591470446, 0.09156646872205393, 0.08568317656006132, 0.11910802870988846, 0.11581669960703168, 0.1294887595410858, 0.05597822301621948, 0.10628610530069896, 0.17359524566148007, 0.11300247561718736, 0.11634854892534868, 0.0830515395583851, 0.14979356713593006, 0.16727370130164282, 0.10634948725679091, 0.16272135557872908, 0.13553057105413505, 0.08104032783636025, 0.13833026082387992, 0.09238043933042459, 0.26700640682663235, 0.10789060991789613, 0.11499267310968467, 0.12847011562969002, 0.0960572509627257, 0.09911521830196891, 0.14255563409200736, 0.13865454627999238, 0.10590377117374114, 0.0923398154388581, 0.1235920459564243, 0.10069969256541558, 0.07192654402128287, 0.12700963685555117, 0.1635625490120479, 0.2883957305124828, 0.14846711259867462, 0.14729818675134862, 0.17420229023056372, 0.22877473118049757, 0.14983011303203447, 0.13110813764589174, 0.16823718031602247, 0.14085461465375765, 0.1343322374991008, 0.0762138268245118, 0.09738401084073953, 0.10371167558644499, 0.10535797117544071, 0.11880483212215559, 0.11763155008000986, 0.11512743016438824, 0.13620727402823313, 0.10448898494775806, 0.10179635443325553, 0.1775992400944233, 0.11715297933135714, 0.26475635756339344, 0.22153343260288239, 0.14689939815018857, 0.1525830788803952, 0.09106427816940205, 0.1800196830715452, 0.13763628234820707, 0.07014334720692464, 0.1398019625672272, 0.21642787727926457, 0.0869145615558539, 0.17083507377122129, 0.08880339948726551, 0.11884289793670177, 0.09935755029852901, 0.08225609295602355, 0.15463773719966412, 0.07605737021991185, 0.20351847713547094, 0.15735300364238874, 0.13235893552856787, 0.10048689719821725, 0.10141309071332216, 0.12273649472211089, 0.11000616675508873, 0.16732563637197018, 0.1139294630182641, 0.1364852969667741, 0.1288967648787158, 0.09947697924716131, 0.1127439605604325, 0.10295795888773032, 0.11578068296824183, 0.1026330559647509, 0.09671660379639693, 0.1017641918733716, 0.11864647561950342, 0.10977190932525055, 0.07875552400946617, 0.10954093600490264, 0.12755596611116612, 0.12163743084030491, 0.08252556635332958, 0.10359736279185329, 0.19022186419793538, 0.16748081733073505, 0.15887753612228803], [0.05159283422731927, 0.023557578945266347, 0.021585240494459867, 0.019066599929439168, 0.017115340168987, 0.03419085372505443, 0.036067732476762364, 0.024031447446239845, 0.015426284999453595, 0.0885490302794746, 0.01682052348873445, 0.044134143207754405, 0.06481949359710727, 0.04127687295632703, 0.08760782756975719, 0.025109950020643215, 0.043134372747902355, 0.02463912814190345, 0.035903947693961005, 0.02062973765922444, 0.004086366039700806, 0.012636729150212236, 0.06710203790238925, 0.047840589856995006, 0.067066116258502, 0.04923845002693789, 0.02339796206381704, 0.06544268729963473, 0.03831111852611814, 0.06393512498055186, 0.0217808909780745, 0.05415522333766733, 0.07777712401002645, 0.02009279084657984, 0.015391209828002113, 0.060264725504176955, 0.010609369991081101, 0.10312704981437751, 0.06779978903276579, 0.004933061119767704, 0.07661011841680322, 0.043687260044472556, 0.0696646814633693, 0.030908097912158285, 0.060858715059501786, 0.029640258622488806, 0.015405257199225681, 0.04433194295104061, 0.004528974008280784, 0.04156752343156508, 0.03558237298524805, 0.011811399017460644, 0.02190682029218546, 0.010319403139874339, 0.02391845440225942, 0.015040765150583215, 0.06415482783424002, 0.015525593688445432, 0.00873145308079464, 0.0601234341572438, 0.06731296051293612, 0.009848958696238697, 0.047090689917760234, 0.04072868790743606, 0.004502423781169844, 0.02267540369315871, 0.016858304318572794, 0.06178298153515373, 0.032047005370259285, 0.022788057469629815, 0.044938668608665466, 0.011048578075133264, 0.04867110654179539, 0.017354650988376567, 0.01871228081706379, 0.019600734214431474, 0.050274240518254895, 0.025953855897699083, 0.031152431587023393, 0.044604642782360315, 0.04060753547985639, 0.04005861422047019, 0.06169524695724249, 0.05608731787651777, 0.03399961202272347, 0.030354945986930813, 0.036488220627818785, 0.024666783532926014, 0.02566357352770865, 0.017592847313998, 0.015548350056633353, 0.030044570498700653, 0.013148318261041172, 0.03195375090997134, 0.01709244300478271, 0.021710577786767056, 0.01766338781453669, 0.035186081392956634, 0.06570951441036803, 0.06406175318573203, 0.04657490152333464, 0.03553606975557549, 0.08333578466304711, 0.017103070559512292, 0.0313570065024708, 0.006416811524624271, 0.0194682587337281, 0.03492644336074591, 0.05159930405872209, 0.02480776614642569, 0.017386209652093903, 0.03117102005385927, 0.02454976168727236, 0.02694536858637418, 0.01394020764356745, 0.04919606872967311, 0.04159626956763012, 0.0362843378180904, 0.056924521523926935, 0.009576906865861799, 0.01590026376236762, 0.006860161216796509, 0.04318072686770132, 0.007977503135667315, 0.07175608245389802, 0.06347037599022899, 0.049380504725767035, 0.03989071412278073, 0.02098460977764002, 0.035925928835890124, 0.018983126551445042, 0.015122085876230682, 0.08204859016197068, 0.04607108587931309, 0.04012969076367361, 0.05005293632192271, 0.03308653458952904, 0.02440869086422026, 0.06744897285742418, 0.027967932733840177, 0.0497345032303461, 0.01868425901713116, 0.03539196588099003, 0.027727156278810332, 0.02671072948058801, 0.04955316474661231, 0.02912953888465251, 0.014025132238332714, 0.008253336102435631, 0.053921172861009836, 0.01264242799620011, 0.08571362921169826, 0.03307414793276361, 0.040643029646681886, 0.03593944186078651, 0.035764613920556645, 0.04554022382944822, 0.06884279913668122, 0.025836744146155458, 0.024396304207454835, 0.04321195983460971, 0.02185693270127688, 0.031864978173481565, 0.03679496595369918, 0.027640492089891007, 0.02332136733457446, 0.020188437142808522, 0.036067528916256766, 0.03867311017321689, 0.016502629832497666, 0.05591537371011717, 0.06010770571551152, 0.07353735901415348, 0.05520874055634652, 0.03457474848255515, 0.05601910814376814, 0.03338436396526439, 0.017156488228855387, 0.044832328600542884, 0.07025690682764564, 0.09378336476428167, 0.09531783099685397, 0.003883811886355813, 0.035471893913511715, 0.03075617052880781, 0.017759968792753558, 0.011092165468393691, 0.001977219238012497, 0.0518328931315669, 0.02384826334725533, 0.042644368684185405, 0.03541265780638371, 0.0194490069989115, 0.03399662986131651, 0.07559177306081567, 0.02289793943054974, 0.006611257608580802, 0.041604245746774335, 0.10445586565349783, 0.0016805928836609902, 0.06591533443757466, 0.05042054284630077, 0.04451582933376942, 0.03355769234310303, 0.05097245305244412, 0.01748974391791437, 0.02189019279155348, 0.04441268861825977, 0.05950576372976814, 0.010761545039713383, 0.010549181390420666, 0.04435421247035265, 0.03174747287162712, 0.04612580633589199, 0.036990838657532416, 0.04134209034964442, 0.04398993755291615, 0.051428856062037606, 0.04635388231171029, 0.06283586432359048, 0.02280481898092798, 0.04339371561737997, 0.02485370127085064, 0.028371469383793216, 0.029574383050203323, 0.02676009290319468, 0.06027000450662204, 0.02335828642493912, 0.07361146182354007, 0.0215098942696516, 0.00898298092319497, 0.024803952779620886, 0.05467080817158733, 0.016495712167982544, 0.02172562769348068, 0.06774522803191628, 0.026521672661017095, 0.010669602696517748, 0.010469544279788221, 0.03874381352216005, 0.09386623424610921, 0.06546213411326919, 0.09354309551417828, 0.0575195492378303, 0.03519919408219201, 0.0619616669469646, 0.03724435969655003, 0.04457383729251368, 0.07869457120874099, 0.07661218116325991, 0.028139169527483836, 0.042422104360801835, 0.05495128740689584, 0.0469563128426671, 0.05342741649863975, 0.06312768187906061, 0.03467182309499808, 0.04130597871595195, 0.05381561656083379, 0.04391821300876992, 0.035028355927871804, 0.008866239821405282, 0.038039718089359145, 0.011118172867489713, 0.04228350340521761, 0.037276858131268194, 0.04533702973276377, 0.03951801858576281, 0.05522574803658894, 0.03568463839058365, 0.007485428691974708, 0.034831272039030275, 0.00786565596769963, 0.026228845784706727, 0.06097979963357959, 0.019175570957096558, 0.052922538947314024, 0.026127603270911744, 0.01579434614229415, 0.05670100191075887, 0.003996088227722794, 0.044274623705340285, 0.02820890596402543, 0.07909581610666853, 0.03672645427286625, 0.01140854090252625, 0.02387235642942999, 0.03800292452797294, 0.013319533850465502, 0.014251313405111432, 0.028741528812263693, 0.02739804474237774, 0.02396624192728528, 0.021559968457690308, 0.02965219405346683, 0.07400019453572375, 0.020784345255898576, 0.0075786305657987085, 0.04833265666716865, 0.06939134720180716, 0.022029007485668575, 0.05775728076696396, 0.027435498179069588, 0.012754419352859259, 0.020620472263544798, 0.01822616475900369, 0.039862381893077066, 0.01404589880257845, 0.05412876386461513, 0.03051020497722285, 0.048198852954166274, 0.032194627448916435, 0.038097037335059473, 0.03230404122067349, 0.04677454688187156, 0.019651744780795913, 0.04292648318888886, 0.043243213157568655, 0.03304504217313869, 0.024897772120311856, 0.0784951565521104, 0.0077961858561528576, 0.01069459823026721, 0.012681938242167234, 0.03271833095433457, 0.04022529634780117, 0.05136117558660252, 0.058798635245433876, 0.006264537240245512, 0.022983546801177517, 0.08012030898992505, 0.019280587821932774, 0.028146265307441354, 0.03517949281792555, 0.08148285480482237, 0.02150260510721377, 0.047677361472908936, 0.031857622853879414, 0.03418166636090193, 0.06793775555810758, 0.030009707369442497, 0.040527658337461095, 0.018488208197855523, 0.016395163456244127, 0.014129365395222391, 0.04116586801995124, 0.044421339939747534, 0.025413945583360534, 0.07497358694672585, 0.06339074312044041, 0.04308061920372503, 0.050116569335971556, 0.09290242953492062, 0.1047327486532075, 0.11386189450110708, 0.10158334193485123, 0.17368463586483682, 0.18156158604792186, 0.06862669930394207, 0.09977602998593024, 0.12710091338625976, 0.15284355490335397, 0.09316456796867506, 0.07986714078911714, 0.1783314472330468, 0.06556146485464913, 0.15172906113522394, 0.09003806859254837, 0.12488568654017788, 0.15288669615983963, 0.13934431783854961, 0.15632012406630175, 0.12237666760172163, 0.15869829431176186, 0.15817526594868728, 0.15499927422830037, 0.2252025157213211, 0.12653072683938912, 0.09636476303317718, 0.11278085250939641, 0.11891137569078378, 0.14673558622598648, 0.09103889417435442, 0.08793405363602297, 0.2443020822746413, 0.058233659847506454, 0.12045851695750441, 0.1269549605037485, 0.10971459347222533, 0.1329785601368972, 0.15638432704976626, 0.11787560555551733, 0.12406263713325773, 0.18904847359018667, 0.12242272655878748, 0.11909402374710355, 0.10210539999284915, 0.12487180371369634, 0.09869050966309649, 0.1172407546213695, 0.1143913689468588, 0.22158787825277873, 0.12710873010967458, 0.08896787637578589, 0.18350903583424433, 0.11054705415985414, 0.10886786319315434, 0.08012516051530838, 0.14725174781467232, 0.08030227851122618, 0.13584653767091887, 0.13218798541596957, 0.1382926157010453, 0.121509974822402, 0.07042772801859037, 0.1710579725248473, 0.22180837499243872, 0.130246208182403, 0.14598678212080682, 0.12001183735472815, 0.11105189099907875, 0.10817792878619262, 0.25549579305308207, 0.12116660896156516, 0.13896931867514337, 0.11672457946198327, 0.08805861230939627, 0.12944650038012437, 0.12921341003051826, 0.20954475019659313, 0.1109377546235919, 0.11128712551934378, 0.11672422662377357, 0.1660080435020583, 0.14127119444310665, 0.2477930635213852, 0.05992640794387885, 0.1411250787121909, 0.09467745678765432, 0.11847898603550025, 0.15395852364599705, 0.07997711774493967, 0.11688987059252602, 0.1024333495380623, 0.12304653094283172, 0.11853873782924243, 0.15221050887235574, 0.09882874081709556, 0.11834792021129813, 0.09888225008866616, 0.24513206630945206, 0.20238635502755642, 0.07069905381649733, 0.24081373374376977, 0.11397444989000048, 0.14938146567770413, 0.13485185961638177, 0.11059912493718521, 0.15237365583223955, 0.17800104139106615, 0.09625627206904547, 0.06252031161316804, 0.1783407838749034, 0.08560679387301207, 0.14190631679126195, 0.16029838845133781, 0.10700773407838174, 0.11978744582406112, 0.19080102097775253, 0.12003395759633609, 0.15234340674110822, 0.10936850668596369, 0.11134151010108845, 0.09645031951367855, 0.1261815255773919, 0.16126288526824542, 0.16828741904880318, 0.12502104070569786, 0.11294539725141865, 0.09638741253209965, 0.09234100966049091, 0.11573440687997, 0.08278047160378524, 0.0776552591206772, 0.1342953523354871, 0.10329999481993062, 0.15372689893203123, 0.14702952759606497, 0.0903097540140152, 0.10204307655138628, 0.2357543052307197, 0.1033476415489401, 0.14105612598359585, 0.13898719128753456, 0.12034372240304947, 0.08915822580456734, 0.1396600537534271, 0.18292359582015447, 0.07550758722105197, 0.0740298465160387, 0.07831845924790416, 0.09262504441929714, 0.18145672524613993, 0.1321150293307645, 0.07572156323918275, 0.1486334622438465, 0.1561393216252327, 0.12126830779016018, 0.1422684509307146, 0.18286902803395474, 0.18450625160975115, 0.06505466026387044, 0.10930018499493599, 0.09776060456143958, 0.12897430786064693, 0.13173696318907396, 0.06442776176014117, 0.13926226938409464, 0.08596651242779833, 0.10797861590981483, 0.10623712864305292, 0.1128532521958862, 0.19737194052764348, 0.11628581157752446, 0.18042273287262234, 0.16587393784097262, 0.12754747085273266, 0.16442382708191872], [0.05707005371472665, 0.029865861338164126, 0.02464938589504787, 0.03607061625059162, 0.010642628385020154, 0.014948962755235178, 0.016531180889744843, 0.03857121117679136, 0.04590602545067668, 0.02281287149526179, 0.03647322500390666, 0.028265768894925714, 0.05498088510440929, 0.019193971130464758, 0.029394153971225023, 0.03402646843876157, 0.0906336119930659, 0.015490279333399875, 0.07532958712960992, 0.05717593231903655, 0.03628270933404565, 0.06410703182752643, 0.051961947099438736, 0.03812583436125091, 0.052854023873806, 0.05075089101280485, 0.015491046077970947, 0.020688929661576237, 0.013801575305738618, 0.03304148664964097, 0.06126318299876792, 0.041660482729119916, 0.029710330933864628, 0.10270261258951255, 0.023618569065417563, 0.01730987785517105, 0.017212630216298357, 0.03084645639838917, 0.04097269927816732, 0.060836336974586756, 0.017987613898835013, 0.06620591705931084, 0.014223539270460606, 0.037334893231413195, 0.04612558241933584, 0.038755470753780434, 0.04355631296389869, 0.040841589349188974, 0.026562427170574665, 0.05723023547657898, 0.04481351960982595, 0.022016948222049644, 0.0016810229052290587, 0.02284852342147912, 0.05077462616775717, 0.006717517040669918, 0.028963660821318626, 0.044195618480443954, 0.035823449692023654, 0.037865626359624524, 0.037148482698415, 0.03836726051356111, 0.001286108951067685, 0.05921512682523046, 0.019418374535494616, 0.10969596090061323, 0.04330538732132741, 0.0609789921769074, 0.01953986962325871, 0.04181874423686947, 0.00022521261105014543, 0.015979530223246132, 0.09161701958094325, 0.04508197520460401, 0.013848554525923516, 0.04928386437573603, 0.023264880990609527, 0.040433766054255624, 0.039718780134405406, 0.03438337107322045, 0.012592856772243977, 0.05762453217591558, 0.022580680204555392, 0.035888008906372955, 0.04068060691601463, 0.03721723186650446, 0.01990395624722753, 0.030012207770986215, 0.02688667700359864, 0.006112169657301689, 0.01016845878413213, 0.04039623967504927, 0.018669712922668884, 0.03262625035962888, 0.02635405076268528, 0.018218826402777007, 0.1045927804495607, 0.027067152051521198, 0.05524448917380401, 0.01126848194482071, 0.07503276198570218, 0.047475487126835754, 0.07603731951011078, 0.0076582150899672085, 0.03193736428927098, 0.031176801172218153, 0.015397313250494855, 0.056526255394731245, 0.008800836679126536, 0.034003533955131254, 0.01483846502378583, 0.0325077611819974, 0.02071107704458492, 0.022684526596484438, 0.028778919484466314, 0.05962403916886874, 0.036058283876627684, 0.011365812704233187, 0.01465836147378598, 0.03339503053575754, 0.016481242408709865, 0.008169244409405758, 0.029889270796307495, 0.008672531644281532, 0.06750508091811623, 0.02129539747589401, 0.10239026256437812, 0.03252860577777028, 0.02477982746703284, 0.03526383811341865, 0.06133159289934805, 0.032951031146304946, 0.02282798077378954, 0.09298451870147671, 0.05018117944044726, 0.04188335094867008, 0.05360552854835987, 0.007625930393779916, 0.04071406887045928, 0.05492783384397626, 0.028558046157870973, 0.08346317961279835, 0.09352695316608463, 0.05678705372182386, 0.05855265273047345, 0.03002716607547232, 0.0535731318938945, 0.03563295777088829, 0.023100461777565733, 0.028543986912284578, 0.019749043309795003, 0.06587995562170233, 0.061904785356351306, 0.02479958301410079, 0.043716182599642446, 0.05514792685530015, 0.05689176863857678, 0.03501846627997501, 0.026875057091404284, 0.010425691409701747, 0.010887178342922457, 0.04859273913981659, 0.08916621894708701, 0.022300899860316088, 0.06258202437311411, 0.036983300133475235, 0.03713830806581037, 0.027198814986539737, 0.03871881289939795, 0.020489986586783613, 0.05599250278568693, 0.06517609767615795, 0.019946658152288625, 0.029595197111900364, 0.06613253349704401, 0.012205928115041127, 0.03920832841790148, 0.048828703085226674, 0.0257391046533095, 0.05007341450878552, 0.040535631123930216, 0.07204268886042492, 0.06038015788154943, 0.031163936148264577, 0.032560323897217, 0.01334401369760079, 0.0022592192399315536, 0.04028254095464945, 0.02506118031617786, 0.03327508590051106, 0.03379701164418033, 0.022918361638273512, 0.007953555938521666, 0.051023645126926045, 0.029537901614925692, 0.04620810245562877, 0.03498821718884366, 0.01472331932745874, 0.045406389582370005, 0.06615037896803447, 0.012753036837758762, 0.032240530342928, 0.024098708926300918, 0.0586799933974232, 0.05367793841287494, 0.025625662079879215, 0.027158347158027545, 0.1018867352977395, 0.021046397176438143, 0.0674332512010421, 0.041070666164159775, 0.013420141085849276, 0.006453883709452514, 0.012257483205758035, 0.023529591072084646, 0.040729288410927565, 0.0418277653599424, 0.04921878608209746, 0.029303983452596834, 0.011653998401015997, 0.012093516066670418, 0.024445167210485255, 0.031601089119379006, 0.02867330890148878, 0.03717322887054511, 0.09116127475031785, 0.03378133748524955, 0.014863251908017057, 0.03563888477427619, 0.05924363886671407, 0.022758232462885122, 0.001961086431817551, 0.01642805035226047, 0.015505705827048846, 0.018948438144954186, 0.024780343153647015, 0.01518761200298156, 0.05294038781097957, 0.06448857885386262, 0.03247230772727302, 0.008133761268774313, 0.04015588900074363, 0.008171998413412698, 0.02696224714496306, 0.01344416631452207, 0.05336723383516073, 0.027613262479592646, 0.032313513569533825, 0.07006793482495205, 0.03684219199099711, 0.010371780954301357, 0.02650923341778772, 0.030134924221783876, 0.06275890488177538, 0.0205586712940463, 0.0720611789396831, 0.061292502496923716, 0.05527985102630087, 0.05051657251481499, 0.0033999693446925706, 0.026717545364850333, 0.03681321515302573, 0.043008962513080666, 0.036055535809802156, 0.03872798330017498, 0.04127976351550647, 0.04921023654086249, 0.037683544880045314, 0.026525438530370593, 0.03438566452158349, 0.05169270779671414, 0.051870558610452075, 0.00989731788701777, 0.05130323887403522, 0.03130989242345095, 0.07634484515126262, 0.0427625491283834, 0.058243423966424804, 0.03400534564363105, 0.05656569863536528, 0.05305095509226833, 0.03341221104242972, 0.03930024616420269, 0.005490110804592925, 0.01286666770465672, 0.03149813160832439, 0.011574511416256428, 0.0466490212960967, 0.04032761603593826, 0.07923777920327016, 0.05823385662266186, 0.07216380057590348, 0.011059544049203396, 0.041098258790693114, 0.01986069285443851, 0.03699403455747025, 0.038536666958991966, 0.026959376941834177, 0.04870514864368098, 0.021993492962792516, 0.038550098559686115, 0.03698418901434966, 0.0635352371526616, 0.020105179199682813, 0.010192763908500118, 0.012089412626145142, 0.059046056254633834, 0.019613178546673486, 0.023375214177316854, 0.049001169723591635, 0.025095225810738545, 0.048255799005606344, 0.03705409508464592, 0.037189944580729516, 0.023798187462879077, 0.04882943929572191, 0.03738976635837129, 0.07510940251605851, 0.05016361216881445, 0.029711199458688498, 0.058502339358840666, 0.04977803125179239, 0.009489740561028677, 0.04942053829186729, 0.02976961453844394, 0.021302413527986834, 0.017679153575694988, 0.10345394084496157, 0.014896819035389593, 0.04785306811598795, 0.0070340858572827914, 0.055945222465587516, 0.016319308330171874, 0.011660752368957868, 0.03728666974763785, 0.03616015573165246, 0.020539102344108478, 0.023833091304238354, 0.04152239067479968, 0.025813388970813582, 0.045937743570123396, 0.011524231971374579, 0.01880574901588261, 0.021429837315476367, 0.011638408210793776, 0.02560404734686017, 0.05226387482668672, 0.02780067385174334, 0.01593642628618649, 0.05165993455531342, 0.04539352116574134, 0.0223514982166567, 0.10918695107102394, 0.1310526199106659, 0.08578663279435464, 0.081315066665411, 0.07019072252192668, 0.16389475975717815, 0.15092072236750806, 0.06268929397421223, 0.13650768862238952, 0.13375545559184893, 0.11296953952738217, 0.10866371236209359, 0.11780815917466368, 0.13140388391911983, 0.07878069087330784, 0.11316605683948312, 0.1457725686154195, 0.11072915260280881, 0.22536795612956795, 0.12128649252865996, 0.15595265664160252, 0.11978280464453356, 0.10800266997622592, 0.1506490505167416, 0.13622820004820824, 0.13771012052893639, 0.10550684854388237, 0.1014833055170519, 0.16292651742696762, 0.15072750273559773, 0.12841229087540082, 0.21108844450541905, 0.1006036934309772, 0.24964114863957676, 0.09345260608409132, 0.11029478162527084, 0.14517594634422235, 0.1008786086791328, 0.0728343017399311, 0.1558213872568948, 0.06737018137105874, 0.1439790241420269, 0.09137039924306528, 0.12917245365679264, 0.07813684256481272, 0.1267661784908601, 0.1351187817220177, 0.08900359445916754, 0.080282187089324, 0.14067674348396914, 0.09693698518510376, 0.16048643764640602, 0.1357503892587764, 0.09980980067380837, 0.0739664781306471, 0.14204408654144832, 0.10728740585701806, 0.11535013892820903, 0.10931689052709512, 0.14533408571566853, 0.08910346124321222, 0.18707248462097986, 0.13172873934464796, 0.12806756794452667, 0.11274018112037863, 0.15966394463820116, 0.08487136369304997, 0.1672223633421319, 0.18427606539002486, 0.1230800234313522, 0.11171743207212005, 0.09850208727376801, 0.18236714282206126, 0.17241899163595267, 0.08904621324368886, 0.13778113600398811, 0.09989805772368397, 0.13690748145537718, 0.10124323982745409, 0.20882542165262358, 0.1152518056333065, 0.13940367608198098, 0.2968861034938267, 0.10528167669794389, 0.11353241825210196, 0.09326634143612214, 0.107509137530412, 0.11339755941714559, 0.17181757890752383, 0.08838065859994718, 0.1760191898792982, 0.08024935956512179, 0.0821033004405243, 0.14101706950792245, 0.25783008922423634, 0.19149802571960858, 0.23190771735140256, 0.08072579292846577, 0.13955390373510973, 0.20096018298396043, 0.22458749158041819, 0.08068988485527889, 0.16071343475154468, 0.08717330052916493, 0.15438994978155407, 0.11710016216550555, 0.1174828287746225, 0.10948940805558648, 0.08055817442280905, 0.11682980667267527, 0.07924293606941189, 0.07165438362530299, 0.0901897211692163, 0.1734458322503737, 0.11866738806877818, 0.16335240671677248, 0.0958799836891038, 0.15238318246390137, 0.10977079652781997, 0.1180051921733788, 0.11060240904667548, 0.11201540394020931, 0.12571043228464468, 0.1553049542542015, 0.1780129021831921, 0.11423531946327005, 0.239646599228893, 0.1079930347789611, 0.0924038216471672, 0.10687118569122893, 0.1597100171659674, 0.08078816386737994, 0.14297351666859218, 0.24097785779408046, 0.1322606158043657, 0.20269025729170867, 0.1509207087968077, 0.11355837221656527, 0.11762272912476744, 0.10558152132268463, 0.17008876667491027, 0.21833401785365172, 0.17583370554660047, 0.11755415637578283, 0.20836300003741468, 0.20438360928424767, 0.20668802277318069, 0.15629345764006886, 0.1313923623945032, 0.10957643695707832, 0.1370630016816514, 0.15671166591346264, 0.19784663005598954, 0.12297995308680193, 0.12414604265774999, 0.09374112595937081, 0.10158457686858517, 0.11628914996981621, 0.10419654992542096, 0.07790626279477562, 0.10055602634591715, 0.11400381688560758, 0.25442077645233696, 0.07855442658598934, 0.1611548624932766, 0.08579256997576781, 0.1397419257887772, 0.14766190866274492, 0.12455008311995439, 0.12839213838534697, 0.12171221897006035, 0.11408887803554535, 0.07706033997237682, 0.28610442632011, 0.11021468056631939, 0.09349229359733206], [0.03290471434593201, 0.019152003739561354, 0.017191941683579768, 0.07137988906885896, 0.07056033411728484, 0.06190209835767746, 0.004133100987278989, 0.056947591714560986, 0.01913766629461731, 0.020005892563079084, 0.048535837193152735, 0.014525273615228278, 0.022781119449064136, 0.051922005135565996, 0.04913830504353557, 0.04409454729674118, 0.0456618749802666, 0.013973469430181597, 0.02318654073003147, 0.030638536305299828, 0.015385425316968133, 0.034962565172463655, 0.032547621721667905, 0.021764824965170453, 0.07996159964906317, 0.046535132585891655, 0.020765212264710238, 0.04905898429985557, 0.05190976097115448, 0.07268990270261254, 0.048406192899814675, 0.02888196859774845, 0.02936889889783093, 0.035560045790459426, 0.030272802537573234, 0.05610524816438556, 0.06616697593459062, 0.040336243608700376, 0.03907232964411378, 0.07987346473549094, 0.05195255956745573, 0.056798585424465795, 0.01629104225763253, 0.012544718953514737, 0.03052053228020668, 0.07178930352841105, 0.0195368382680629, 0.03042471295754824, 0.065720574531172, 0.015526711574888654, 0.00804881886246481, 0.03298454399087599, 0.03916972316801548, 0.03342122198747737, 0.03647066014153617, 0.023140488558315804, 0.021027476227443134, 0.034493541411523304, 0.03545435378327966, 0.05862626699464662, 0.016657902393490076, 0.003654126086205776, 0.04014290523316179, 0.03687631890976003, 0.025346473757443682, 0.021842968450593095, 0.09157701994159392, 0.08714695301439081, 0.04947833251208067, 0.049242833363158364, 0.035265123937278986, 0.03345023275219968, 0.03596689538764102, 0.0331208888175232, 0.06851931435189076, 0.02749463589861989, 0.021578545050163354, 0.04530645155214837, 0.04305970336177519, 0.04088477471045085, 0.016174697250659977, 0.06099753653896706, 0.025514935342861072, 0.0433343607666237, 0.014869962619351489, 0.03277519897424749, 0.03404622059315443, 0.010032282743070806, 0.03773131374535816, 0.02164540110555078, 0.013516608409450521, 0.029336610808968544, 0.05668003857135773, 0.055220547065671, 0.02197557794196265, 0.05714969336986542, 0.0462922272272408, 0.05112540841634784, 0.06521321354167801, 0.06701897164540631, 0.020998543494247963, 0.024271845617996793, 0.018401939255584563, 0.04565953403445227, 0.008420137821563652, 0.09870690985449723, 0.0715482539630362, 0.021073552147884454, 0.06361695312495742, 0.029289825819432735, 0.017383191867598465, 0.03496633782716734, 0.008081666742717581, 0.05874581807958228, 0.07476218936166593, 0.04232789995148778, 0.01949131704999932, 0.01618402880350394, 0.0764962195285729, 0.03974466285269175, 0.024567352707630823, 0.04230435139366558, 0.058742941091103215, 0.03544397559016943, 0.018031900183164647, 0.0719269307862435, 0.06200482855950083, 0.03680131025612354, 0.048960233705916574, 0.044839012170476575, 0.04173621402255126, 0.011687006585166922, 0.05247913666867784, 0.011482537690816181, 0.011832752514497509, 0.012458726514263876, 0.030728432017245462, 0.08729393048478024, 0.01119302969891578, 0.06155848143888371, 0.042417944941137514, 0.07085568684020213, 0.015993245112310563, 0.03486624712656651, 0.02539653776745711, 0.047153308521956205, 0.03929261603791799, 0.056369208464665074, 0.024218514461868575, 0.053966142769370756, 0.05460581808750119, 0.03840577755389469, 0.008276846492663026, 0.038063761977744956, 0.012499455578758248, 0.08046836352774075, 0.04908435472420283, 0.040288369570459635, 0.020105822111612985, 0.026751136240948523, 0.037484516988375356, 0.04481009640065687, 0.010384245642593928, 0.035170777035611014, 0.004858647456525692, 0.044392274892223735, 0.0405484893625336, 0.08288187866232224, 0.038627044430800846, 0.039180735791368146, 0.03174819890409708, 0.039515691210648844, 0.05179043719545007, 0.061384491489401886, 0.03621792959581528, 0.03206955648160406, 0.034069931999381096, 0.055495486062552245, 0.06872436763452631, 0.02527267119980284, 0.051852614751883915, 0.037654137172337086, 0.052073287910648754, 0.013821085732031082, 0.06670420603560549, 0.03214622076068606, 0.02125925021911306, 0.024641599705708877, 0.026284461907510246, 0.045096428000501225, 0.054796615349394937, 0.052823818887450864, 0.03728748059698513, 0.006748712264067892, 0.03856288894478764, 0.019724945138607706, 0.045523369019584994, 0.03446272913632648, 0.04063319767426167, 0.04572577262297273, 0.0314764897339046, 0.02833324241718011, 0.009953440366578954, 0.05740410328975745, 0.06412693325962339, 0.0542379740758666, 0.049827309857521734, 0.03429560935390847, 0.06505268572696618, 0.021164043274308954, 0.029872117431036065, 0.014651937443496925, 0.04888914019933768, 0.03084793221205473, 0.042531294216002734, 0.02689706876740924, 0.003695189329196832, 0.06273265236190387, 0.024545576822544848, 0.019673512184194157, 0.07149871412132468, 0.02244808428388621, 0.03903616712029491, 0.026359623231525933, 0.11244858069611446, 0.03167869995481201, 0.04536853072100452, 0.043782984372228384, 0.03246456903538533, 0.030545682180672884, 0.06672519312373229, 0.03855977446905204, 0.037155169661023786, 0.02952225459739566, 0.01892107622032719, 0.01513604334156428, 0.04849410389683076, 0.04108582802915147, 0.07952995638230018, 0.05409348004364541, 0.029527659128819193, 0.022951090774898018, 0.04257426583873374, 0.05258039105683565, 0.08199040578412158, 0.06885905683572803, 0.03092475255419101, 0.006615645609729524, 0.04734873339267714, 0.013742220454982348, 0.02609364259322839, 0.011437116556667855, 0.03933012545374887, 0.006728075469644474, 0.052799988737595935, 0.04023833100550941, 0.02888975478708744, 0.03575451731947916, 0.009404851589351892, 0.037381847854703665, 0.03904720349237323, 0.0002551583228133885, 0.020222075516358018, 0.026175350083836486, 0.06580952368676662, 0.027766597823106816, 0.010097249078431299, 0.028037960940439786, 0.05700362513640097, 0.03985198334391628, 0.03344585280865431, 0.02489788068591484, 0.03743491268583706, 0.09697773799832378, 0.05558804841712117, 0.0657676173640149, 0.026950310017647486, 0.03948179838646736, 0.061833674886396954, 0.014634358297501291, 0.03479289070570043, 0.03801466318379555, 0.027952377318537662, 0.07409972883760929, 0.024644800694659352, 0.02146467160699623, 0.03401318272309644, 0.031832109937178235, 0.07667034518505846, 0.047768824600747654, 0.023227419072229947, 0.053771884978881905, 0.05083740422768252, 0.01974830201028713, 0.037986476839120896, 0.027968721530799354, 0.036076393976275406, 0.04790171568414994, 0.019961925190208212, 0.047161033643143516, 0.07367365634334938, 0.041559679566749504, 0.01484809852471309, 0.012247394238199507, 0.0645172062462994, 0.03491387010685035, 0.02118908630550972, 0.07223765232733317, 0.03161801517541919, 0.04148027400619217, 0.013177714942555343, 0.019272023013659885, 0.023399451448182975, 0.029777397335107838, 0.07259878902030842, 0.03803840512409806, 0.0215285963911031, 0.04453466207321201, 0.04850464154567037, 0.02734918173934732, 0.03036243701353669, 0.006965598773344287, 0.02920760094587292, 0.03148403504331197, 0.04145180606948478, 0.08969095721840858, 0.08087542347077813, 0.04865847221974816, 0.029544666609061614, 0.03242170258558222, 0.016261892393231392, 0.02954606439120003, 0.058622928602354865, 0.03449035568961075, 0.03641741210594773, 0.04669557897640126, 0.04464251860710127, 0.054060781441096745, 0.018893627782485316, 0.013745823475931371, 0.0322236619623644, 0.03969943170834865, 0.031115712664489235, 0.07550454059881823, 0.051227595790156295, 0.01406236769564982, 0.015672269210751568, 0.049848378369850774, 0.0030908851934197757, 0.060071865495826514, 0.04134801735303231, 0.04966907549117293, 0.0940488280196275, 0.13701634561376913, 0.13361799796777113, 0.13846914337149688, 0.27729272629533497, 0.1538144163787365, 0.13198352924415044, 0.09645153409136192, 0.11811868394059793, 0.22210295418543474, 0.15506817267409392, 0.06924923482750144, 0.09397489484399557, 0.13691365612404688, 0.1880933948393379, 0.0884240712704403, 0.2411798440984317, 0.08833811445427792, 0.08546552966747965, 0.13284255457775934, 0.10637862355049167, 0.08225698862224817, 0.08112570789775678, 0.17463231858398232, 0.15320049146456377, 0.1053597421518394, 0.11403511092066765, 0.16125956044665404, 0.12214703778071062, 0.19537425200854028, 0.22442198331866944, 0.12916205850030693, 0.16754563099571637, 0.1283229956669467, 0.08170158735343389, 0.15948224653090748, 0.1638945426259722, 0.0944291672536305, 0.0833586852199265, 0.1563933922776154, 0.1048247783577868, 0.24428183478968485, 0.1346059585256236, 0.11772282661071845, 0.13021633907088212, 0.09353864432445594, 0.19749600387045316, 0.1128833791507142, 0.32456246124846594, 0.11203116630869252, 0.12500266597739287, 0.1347247292952878, 0.15379653019564493, 0.09466776730758802, 0.10897203188921724, 0.0963532007964594, 0.15162839367985725, 0.06769346938069377, 0.13493755858923706, 0.08512290340981313, 0.13853456771799497, 0.13185384763138636, 0.15814657748809882, 0.15042497111218317, 0.0993464087535228, 0.11974788723247391, 0.20206960131015095, 0.12727518832044943, 0.16184779602502072, 0.1590814223246915, 0.14553286933473178, 0.08089575916528702, 0.1738693466676133, 0.1282476782798767, 0.11796601356140204, 0.05195917189121246, 0.07874459959566593, 0.16651227644511632, 0.1627179900450366, 0.13798651498343262, 0.13117295131087303, 0.08767327227230583, 0.07087185632969652, 0.10137781367770263, 0.10292772336729936, 0.179371356431927, 0.12345707177051476, 0.13334783246474607, 0.1747890737439905, 0.07229598598288638, 0.07846787265901055, 0.17293515322463854, 0.11984128079244069, 0.16244421473571233, 0.11973143954362188, 0.11398587641971451, 0.19761553459933826, 0.15145382019025938, 0.2652842849493027, 0.13608952106109687, 0.17177743677582058, 0.09612676009003605, 0.06432044466159173, 0.11631893765713487, 0.15980456423546585, 0.19051189720630646, 0.19889113972229616, 0.10662025665598256, 0.13973618538251945, 0.08682221293981586, 0.09205272048711777, 0.19427643663116864, 0.1341524664312601, 0.18544353917241096, 0.1829446168350322, 0.1023900250771216, 0.19087403134575912, 0.12737308735294, 0.17368607435907635, 0.06631676253995725, 0.16508311884743826, 0.16758409036057337, 0.13170402709926876, 0.1550386564007827, 0.10953280715537922, 0.29384192398616243, 0.1569769052522523, 0.15126878369067395, 0.13717065804771014, 0.2294972895511559, 0.08716460849557604, 0.23288811902914727, 0.1015142806406532, 0.18732655527336256, 0.21020911740405218, 0.062334759426968436, 0.07167929943118777, 0.183869242934244, 0.20284208628748143, 0.09498691625360932, 0.08882361304547105, 0.13366683891841344, 0.09635275974869728, 0.07857117283024959, 0.14877385113920483, 0.14069471109126294, 0.12464587869388716, 0.13864518249673502, 0.24909840204886027, 0.13111877707498415, 0.16796161367424897, 0.15097670150654657, 0.15129464944558485, 0.14542990843100206, 0.07278414443135262, 0.19972442143729754, 0.12998202735824244, 0.0975046136549541, 0.11597544965999466, 0.08194438075380665, 0.17681831414146082, 0.14305994845926762, 0.06588426431907074, 0.10290275327861309, 0.13709513710013457, 0.09639380433197532, 0.18620568327605724, 0.2230734085398061, 0.10678638238459826, 0.0948686001024076, 0.1101716478754367, 0.17166710698178836, 0.11076115231428828, 0.1597932462713548, 0.10564359370619059, 0.09866282543433563], [0.08523920431200947, 0.019625198794528842, 0.07030884189797298, 0.026615551373522197, 0.05165566996272121, 0.051258384316627464, 0.05520435043477586, 0.023153426524783884, 0.013245991680638065, 0.03481230019990887, 0.06050223311675446, 0.022648703340174894, 0.04982307240633028, 0.03338943262185369, 0.026044104447854415, 0.02462191370848034, 0.06560123379209212, 0.05253404372238687, 0.043342662642576864, 0.04784209281206131, 0.0340656165166625, 0.0384943297665034, 0.03303144772404006, 0.025068462693265507, 0.027061014702277522, 0.007521474168502859, 0.020610536814534237, 0.03200649343697088, 0.012729173609321671, 0.039664643217942545, 0.04006420195634876, 0.025839538014094745, 0.026016929120357548, 0.059457289188035896, 0.037047859347824535, 0.04980303526722959, 0.0291186009001519, 0.036592928759221516, 0.01864608802965709, 0.05024629505351186, 0.009924073370971849, 0.009293385249163424, 0.01615920799252178, 0.01855670121897544, 0.021539576784042374, 0.039078236291451116, 0.04851378819772175, 0.020186491443642547, 0.03671255448300924, 0.053468206631285806, 0.026595314066591005, 0.03374062877680574, 0.02099493029527366, 0.05470932521192091, 0.01641482570474701, 0.09564607909747533, 0.037637821797813685, 0.029501477855124643, 0.02906914587531771, 0.01612421763794763, 0.06106450115995748, 0.06902286875993013, 0.04808359021054847, 0.0609410892107657, 0.03435760370588728, 0.036222519885216437, 0.03571756090968847, 0.060460781412465234, 0.005931068660824427, 0.030327743518033197, 0.018168049930994, 0.0388224082333701, 0.053090459401054044, 0.010710768567930375, 0.04794946758608733, 0.01864876315396811, 0.04635244381747075, 0.0110330845761512, 0.023898047461573566, 0.024032953793981245, 0.07877208026392118, 0.05545017010133181, 0.017840181809983084, 0.052613513743770976, 0.07774756023926394, 0.024148786507014717, 0.04194265490929995, 0.03473067582984056, 0.028282158908301165, 0.02515137967254434, 0.06139074758227382, 0.009342908127499478, 0.09366326406598091, 0.027346689819491336, 0.009675779596104153, 0.00570783657687051, 0.027921266487932632, 0.026832775878054754, 0.016544654898877655, 0.016601779065760117, 0.03756555781832763, 0.03575635954205479, 0.007796262191342456, 0.0518163741965379, 0.0339603893059705, 0.09691558419061558, 0.039554547518491745, 0.03583138855174184, 0.03264996176585555, 0.04319819914443152, 0.02628832107542881, 0.039210940777723274, 0.0137933514613126, 0.02860896003299526, 0.04133944406307169, 0.027401663030364683, 0.03769141588626163, 0.048899209659014425, 0.03031776226790888, 0.01787816789666457, 0.019805254847077385, 0.044801743634577305, 0.04000231616997293, 0.04596432517947895, 0.019902765418269804, 0.04773265868425369, 0.012398536217265894, 0.0492595830000937, 0.06519572769424745, 0.05614523423303451, 0.06344047295195715, 0.0929393350545849, 0.03118786129302212, 0.01286171270268304, 0.0389067501361881, 0.020167324525703276, 0.06388797358210598, 0.015349958291543382, 0.06726253857570035, 0.03621416033378669, 0.01584837449315403, 0.03681303194857069, 0.11069583653339318, 0.066434060888631, 0.05095080439267414, 0.027538309805095196, 0.06768268745924745, 0.015707783733627627, 0.041517627358968766, 0.09219223407230207, 0.09938643553427287, 0.0671745054423809, 0.01145652520270752, 0.057832537085882256, 0.08516884701592581, 0.02926034008019737, 0.037271470563220124, 0.02902422346440809, 0.021061353784586703, 0.020074886003775255, 0.014405381566445743, 0.030804010640297617, 0.013904637989721127, 0.02399310512867357, 0.05058988822357995, 0.07621002702840737, 0.024655438427414213, 0.0174558443083827, 0.014703282188358051, 0.0636443252276097, 0.029929555420364653, 0.04700668388977647, 0.03878151971314635, 0.0320113042502531, 0.09791227070880787, 0.07795586370463882, 0.09071662396724735, 0.008094506321607955, 0.03082386457494327, 0.023769407400063107, 0.0487955566495657, 0.0312793413842363, 0.05125592462718487, 0.07592278279896293, 0.009305378355618035, 0.018180589258138622, 0.07775615049260003, 0.020438699517399073, 0.041349964748535833, 0.03924197357680116, 0.022015552136248777, 0.02671855129301548, 0.04194356753890004, 0.045386807061731815, 0.029987556593758718, 0.022575021222499863, 0.022896680748090148, 0.017509092343971133, 0.05311315979010292, 0.0764519383332559, 0.015526592831260391, 0.006297576806641051, 0.028139778512663076, 0.04002398179311838, 0.041586698831192086, 0.0003488547850533255, 0.014317568957007356, 0.036614872581724606, 0.04691935643287642, 0.0414813630548971, 0.021619506512901614, 0.02320013857180519, 0.012252169428393245, 0.06931107650910105, 0.02737698980074908, 0.03536203230864235, 0.05738509752388511, 0.03816473138119493, 0.006646080873906612, 0.01897058722430042, 0.05386089180995311, 0.021885073244837776, 0.026233010293383683, 0.020898401903520738, 0.03572691112224545, 0.021012779158939208, 0.07461673859506845, 0.03223337179848126, 0.04021190206653305, 0.02020280681816595, 0.05226187314838171, 0.03961980562391026, 0.004608350731099823, 0.01782897750048765, 0.03377434178920729, 0.022052768085684096, 0.030926910295550312, 0.01935508248529264, 0.0298782242462039, 0.05027809798983591, 0.04867211416629808, 0.04735305905342102, 0.028400088294542263, 0.0408633635379374, 0.037348375722233734, 0.019399117711665373, 0.023929022585174868, 0.06280913004385573, 0.03678693209907838, 0.039446433141295395, 0.018042765225150754, 0.021525861894977943, 0.014658534500215734, 0.092550412352596, 0.027279182370486002, 0.0618208505745445, 0.04630726695592914, 0.02970002737960645, 0.04898146506665008, 0.04328522126057318, 0.01915480100017573, 0.032801085085208924, 0.014314147444175822, 0.05063234415969678, 0.05486115420769368, 0.016558074625208974, 0.03012395231053233, 0.05518609105742403, 0.0571306740332927, 0.07137758204979555, 0.07218399377805845, 0.06511631195566484, 0.04369433716471706, 0.01259207391246621, 0.021065128135627935, 0.05901332372533424, 0.01148208137601614, 0.03030293288507632, 0.02515486903887774, 0.011559294420294464, 0.004271573445294052, 0.015589803457260132, 0.06319837844265358, 0.05543172412684985, 0.05474809670288648, 0.02253407672313707, 0.023945838379274522, 0.019195075446207608, 0.0586599087608712, 0.07452010163771254, 0.025088308146223426, 0.015634230537606136, 0.017477321638060466, 0.04180864424311689, 0.07131133667592492, 0.020847421871232133, 0.027515879133716226, 0.03958465750994427, 0.017518564692831466, 0.050407844063426764, 0.034235487758581123, 0.038079626126480956, 0.038023813228522024, 0.035141650919935534, 0.05552052061206528, 0.015766572007643323, 0.01929923226790769, 0.05604409858850496, 0.005821328768174031, 0.021982117323204875, 0.017668968765065074, 0.035968859746520004, 0.02586408062571926, 0.007502109627239406, 0.05708396368260894, 0.05598756644342627, 0.09743994926767689, 0.009181292112251478, 0.011959564772301486, 0.039403576869517565, 0.03775181228827153, 0.05513032565691641, 0.06736115685531072, 0.03470677104113357, 0.012079321114080293, 0.056256887170353105, 0.03181936365685292, 0.03351610153913498, 0.006720804542835269, 0.06513662050877299, 0.02011136574271534, 0.011678486729839017, 0.05765482197914805, 0.008625739869395537, 0.01546899538620242, 0.031316881334143024, 0.036257413548550436, 0.03494564590177365, 0.03833467047661543, 0.0319202855628516, 0.030692225388650383, 0.10116002429276705, 0.012259095574596097, 0.020740143788446273, 0.07181539998522826, 0.025916555131386434, 0.057234659524900575, 0.05334598211837666, 0.0567673558502325, 0.0425773463877184, 0.04869698586740664, 0.0010460085925712648, 0.21357235764818533, 0.0770215413400105, 0.17367916687258653, 0.09997066775602953, 0.08019914797374181, 0.15193989553621837, 0.12395477720669337, 0.16113024524280004, 0.058778835593589714, 0.123290179297328, 0.23032483085989952, 0.07749332673847675, 0.11671518853732518, 0.15214110831064837, 0.09885187886123147, 0.09749498524303947, 0.11429801609899316, 0.25610832018511637, 0.09919493259595973, 0.16333325845854624, 0.05509837344288826, 0.07175020634063653, 0.0742875812575221, 0.13909163139760494, 0.12536214025957243, 0.1527516541204282, 0.07779287280780928, 0.11292346699961595, 0.16832279786467552, 0.11754343552248818, 0.09672326022492987, 0.11255798089717116, 0.10582911875098944, 0.12881726771593094, 0.10070974845439196, 0.1909399985202721, 0.10277370270341635, 0.0946173317996519, 0.10474862637264387, 0.19547658866005285, 0.11923163064888545, 0.14619786079440797, 0.07841489943010466, 0.10045586779181447, 0.2454605315412794, 0.1605455516172307, 0.1281674075871706, 0.11007284639137131, 0.09102415639374938, 0.10453114232846669, 0.15633541824562208, 0.19248977250286511, 0.09636994704071965, 0.09806061881993498, 0.15030306551073278, 0.19796344664480003, 0.12243914710623877, 0.07864860724657774, 0.12014198037130491, 0.05666545006845679, 0.12683996238878795, 0.12215401312070233, 0.10123114833342177, 0.10940398049673863, 0.12283178818012987, 0.06520399225077458, 0.0997456316170948, 0.17868189699947834, 0.12440307172281401, 0.0910517049155065, 0.08765610533633403, 0.14242364546017988, 0.16934939420648984, 0.11861664722008364, 0.11121509902711425, 0.12671345631991113, 0.13246763683855534, 0.16755029931664467, 0.14345689144517693, 0.1473446392587253, 0.1899300127157143, 0.1501734381807702, 0.18614727498165198, 0.08760045189410448, 0.20553623672042573, 0.11793748794921807, 0.15361587703227997, 0.1063237911356347, 0.12581149329032215, 0.05120951622458441, 0.14586073745574268, 0.1498753170349768, 0.1474616594080414, 0.10072300024330616, 0.14945260328905924, 0.143401224432247, 0.13944396749138832, 0.12171885504254273, 0.05687782474394355, 0.11532290253256049, 0.1261362944330488, 0.14706710486539773, 0.10512804279902152, 0.14535555456365856, 0.07570920711649315, 0.22684507258236408, 0.11029090719031436, 0.1678551651005234, 0.11354575825056859, 0.09395135646419865, 0.08507013374141284, 0.13932126121861593, 0.10586506753627743, 0.10992725313241992, 0.12589932286313602, 0.13994840399495193, 0.06935306425605502, 0.1536598868135895, 0.11230489412056548, 0.08351207484624215, 0.12365977732198578, 0.19112370509122098, 0.10214772700731244, 0.073760603820639, 0.18036796152591705, 0.1528572477400303, 0.0727092477359942, 0.15832648426294327, 0.11376241448202304, 0.18406874580042704, 0.12247714506728308, 0.1191345594291176, 0.053347895587129254, 0.10037780233791896, 0.10035475928868566, 0.12405264909778323, 0.1495729618306671, 0.09212385131312267, 0.2502151078411511, 0.18178713108812058, 0.14758710696228913, 0.09391589622412409, 0.16087787092796393, 0.1761694582445281, 0.10084261918174368, 0.13448918264891419, 0.2309407235256263, 0.11578928679227829, 0.1432136773530926, 0.10635038292301552, 0.2389934142785413, 0.10332786225314651, 0.14502497230257305, 0.17922623136213847, 0.21142772558544362, 0.06790705184851374, 0.12080709396728448, 0.1431791806327445, 0.10334987392915146, 0.11955738174063818, 0.10713235381990671, 0.1412795947066375, 0.06850594042667321, 0.16943513389144624, 0.21313539466687612, 0.1867253053933382, 0.10489965469709464, 0.07392448359834296, 0.14062832322503838, 0.12033292012555258, 0.18731411094112055, 0.09758146453116621, 0.12232485466769763, 0.1685009268777711, 0.18745473053838524, 0.11849239388746874], [0.031882915246699534, 0.048413263234708986, 0.05152193071054561, 0.026305781477796178, 0.029596689888941388, 0.018848488240369728, 0.0562138646574957, 0.0875699178182653, 0.06044700036623648, 0.02196137620402234, 0.0059631616708689505, 0.01981271873228252, 0.038028586722378216, 0.034952312508331876, 0.01797939175074654, 0.06756532804242202, 0.028588634516511644, 0.023993880354932377, 0.04702246661431023, 0.04837528223704014, 0.07153850341481821, 0.05670140563909497, 0.03233718087098428, 0.1036221564614347, 0.007312852639837989, 0.06589504624051706, 0.04511241089286549, 0.04578329882185374, 0.04467375157400966, 0.03674228449485131, 0.049462013744882176, 0.06606377075825419, 0.02165777249527829, 0.018200779067618505, 0.047754208956445963, 0.015167832707187958, 0.03717776148446968, 0.0441421295649239, 0.01780804808783744, 0.015297885817874755, 0.026031614314498644, 0.004697097174357623, 0.05980116395013673, 0.0650810349200453, 0.0168149001297674, 0.03995051680664931, 0.019495624051030194, 0.05130813789686986, 0.005553713708650321, 0.02097994145671172, 0.036010230026607, 0.05324250552803278, 0.07750317906694752, 0.022691259360206977, 0.033509431539901664, 0.0698957158518689, 0.05590192853872265, 0.020078485632049184, 0.0792536772787571, 0.04561439788501177, 0.00825238784974707, 0.053583968098142316, 0.08735210129192897, 0.030592748762241433, 0.026037946742560183, 0.011772976123860903, 0.04215611184814146, 0.006625662058857935, 0.018877115632806505, 0.025118048336090784, 0.04719435649790934, 0.028131378249132206, 0.06708318141422101, 0.08528957196644374, 0.04948074131139687, 0.04095719814566629, 0.0324408881632345, 0.04039662304733481, 0.02258377941325307, 0.018190843618607948, 0.01599596264506025, 0.04803846763180835, 0.1147458084992, 0.025829933350905776, 0.01605441843691681, 0.03926260443404317, 0.04074326283963663, 0.0684987683115261, 0.026080567223419036, 0.03989920598853912, 0.0860295822577817, 0.029052983171173503, 0.04531114022912724, 0.03738662813391004, 0.04760339097785098, 0.03594434427629624, 0.025434691791555712, 0.13649035883801325, 0.0445971687191299, 0.03220045606472662, 0.05413504370621272, 0.03066974552348256, 0.05834627630455153, 0.02215077568377767, 0.024112430600715534, 0.04913045439336981, 0.04991697147488594, 0.04621132549696735, 0.01725619555717068, 0.05620164763448494, 0.09272848029753991, 0.019990323577076197, 0.06141843181103468, 0.03921484913943069, 0.010841121930362923, 0.04786979400419763, 0.03176387306302786, 0.06347932586712496, 0.0690350348928145, 0.01319035011277135, 0.026927518026371087, 0.0639528211738382, 0.014124964247457683, 0.030889489089271853, 0.026526955056137273, 0.05277552415749856, 0.050108844214784246, 0.08302321072135653, 0.07352180020617587, 0.03256025604371514, 0.030997128491955142, 0.021370451930644255, 0.03006234811618924, 0.017156550993344614, 0.03488865913823247, 0.06450285523065499, 0.057330102260623655, 0.01324137849068003, 0.05039247863792947, 0.01802772719279996, 0.034206812868693044, 0.05405248635049377, 0.023861314968339035, 0.04191661952063441, 0.03083190182223916, 0.013301327059577619, 0.056930302642285824, 0.028045959171972105, 0.0239414312943284, 0.054718261518116505, 0.10470878279634885, 0.09304750710725784, 0.03250139652352248, 0.06419873583529677, 0.022003733752561466, 0.03315846608685596, 0.03514867375737854, 0.01074936194345355, 0.014608207557882582, 0.021702986676245928, 0.048915077200425525, 0.03671256126835942, 0.024894978252372572, 0.08261911597635065, 0.04315415882904615, 0.02382589374402804, 0.02079384135348456, 0.08356525842100382, 0.043954344998512945, 0.03340521195371236, 0.03972041201112526, 0.014148068364842661, 0.051671642677060196, 0.020619651236172234, 0.0607794350279229, 0.023759461773027266, 0.05738807629261698, 0.06284174043685198, 0.006685849387265209, 0.0031855921427320156, 0.0493563760205039, 0.008282698857198869, 0.029212829058191607, 0.10291367090706315, 0.09279499030006783, 0.06524870770850352, 0.015929269438077296, 0.02021173633901136, 0.030553091783076525, 0.06461891186024461, 0.026333216344937682, 0.02493696939200163, 0.028143082978203893, 0.007508030693445886, 0.08551444525697402, 0.050920266924159865, 0.040506572861756594, 0.015031065492491637, 0.04561889317951032, 0.0856672716992242, 0.01925649813243321, 0.05331843698929463, 0.01747073815204203, 0.015070043936637896, 0.015243713278323412, 0.03743957761409027, 0.04414460961041706, 0.04338839251015868, 0.03558545692690781, 0.0190049601120076, 0.053869560094816346, 0.020245189811768274, 0.014879984581576926, 0.025640888405697684, 0.010087259346619248, 0.03007156940709267, 0.04144670009346945, 0.019448226683640053, 0.036138076202145646, 0.055153965816966126, 0.016149850994614617, 0.0496117562454726, 0.03448734977947814, 0.04903501505032182, 0.06618870941123792, 0.020548204891383648, 0.049157432945711274, 0.019611653539219072, 0.06102316480662141, 0.09506859151380402, 0.03027764388493129, 0.05053295574284025, 0.07069159671664238, 0.0011172582682255389, 0.023037486942484975, 0.04693859629333019, 0.05534123130408781, 0.03578681219369173, 0.05184138499732528, 0.024672094765784483, 0.03403618506022862, 0.0411512795170503, 0.023102292125778537, 0.07550764150385346, 0.01892777675363634, 0.030936202832630703, 0.03907083347439766, 0.05947442898260696, 0.014490826088669044, 0.03126013884320855, 0.005337596912535706, 0.019425578881055117, 0.046048507626567564, 0.061378723941743374, 0.006160672188603452, 0.05089438759854861, 0.07290691855762686, 0.059169393564973555, 0.08679342269897461, 0.038813709414431026, 0.0006687735502574858, 0.04899453365110925, 0.033646149560809135, 0.06989324598440103, 0.052138186392507384, 0.029804857647312537, 0.011630964681639202, 0.06942507039223399, 0.01868493415947471, 0.05309748902384724, 0.03720454665433083, 0.07101829775742122, 0.012845906229423625, 0.031194989303393022, 0.018844283019591655, 0.003463931448225464, 0.051843186507799795, 0.016641712547945123, 0.033041276303785186, 0.020318395258592706, 0.05151295708492398, 0.0545835214267884, 0.02353980132777776, 0.0465840074632849, 0.010420932334714701, 0.048066050080316405, 0.03362300812399813, 0.06822355450796229, 0.013850385722305094, 0.01317140371871314, 0.014414864093331354, 0.03114627388172916, 0.007461342395150236, 0.01550871173718146, 0.03737955101366554, 0.038219031146062274, 0.05435561847739986, 0.021591381236378635, 0.03441591361271484, 0.0530377677641809, 0.05025433569348284, 0.09853409377059766, 0.05486839417634266, 0.06082649143146617, 0.013480568870103784, 0.061420277426285405, 0.016688260050224404, 0.02552245181453015, 0.034816754782306295, 0.03090386724631701, 0.03793742214994771, 0.01817795823860381, 0.0682827906150903, 0.06413256510027818, 0.011210293326127743, 0.01242982770781964, 0.0215517123828509, 0.06767506751098804, 0.008342616043851843, 0.040693689071174176, 0.025325517203392725, 0.034055564020361216, 0.042179707903414965, 0.039985980439398966, 0.06650082194911582, 0.05970331920044763, 0.022003140034420148, 0.04392643685319594, 0.011330595040427787, 0.15885335313422339, 0.0103017128837694, 0.014572258772594588, 0.05622163388345923, 0.015633753866755536, 0.023358895410118357, 0.02497342198954097, 0.03887202949928386, 0.03989051056227513, 0.09478874331606285, 0.012687633695480014, 0.01779570383951068, 0.0316474330611527, 0.04201730054670146, 0.0834316820172327, 0.010509707615710795, 0.02744260922606502, 0.01744810052748237, 0.03156312508508563, 0.008840168809651263, 0.025434690095218163, 0.08111753833613225, 0.012854560943586486, 0.09050716699234077, 0.19417984038591385, 0.08633389842829534, 0.09716027070369039, 0.10640427895954677, 0.06967480520584754, 0.174381572753191, 0.1687156967818737, 0.1606858048055853, 0.1552106650280101, 0.11579163452344281, 0.1699894562895809, 0.14055080738450798, 0.13529191671737603, 0.122495261952281, 0.1747504651014294, 0.14736867296908582, 0.16501479037106037, 0.18850191363266536, 0.14669913532478468, 0.10568212092454944, 0.11478753840284688, 0.10678072340254273, 0.2063916251063347, 0.060908940221582136, 0.14661738542573793, 0.07763845859361546, 0.1157152857631445, 0.07200736432735409, 0.1000338936490672, 0.18511687884373323, 0.11801260177578245, 0.10874577438724892, 0.05800177729023354, 0.1352809380207743, 0.10508815851062536, 0.08689161350152322, 0.19188681271459374, 0.08893836688782487, 0.1243960013879197, 0.15674658332552227, 0.09286927631390945, 0.19699581499610627, 0.14322511745350702, 0.09478421070213829, 0.1362536315407072, 0.16944065716649803, 0.14935091803116457, 0.07167739274778537, 0.12358469063682215, 0.22772631315248354, 0.14192155668778078, 0.1250805210854326, 0.17668210502181733, 0.07812961616686412, 0.13729104373071874, 0.14407458901405334, 0.09114855221871819, 0.19356495195201465, 0.13828672601708344, 0.19922926729278906, 0.09637411324573414, 0.1023349483896579, 0.10673155675509147, 0.11736883489148957, 0.13031939496951445, 0.11457930957632405, 0.16902793145605496, 0.1838064920157194, 0.08349283159311328, 0.2257474200533969, 0.1568415510867323, 0.22927451293383325, 0.13029624335467815, 0.12591832184365817, 0.11541192632700716, 0.11244740683053221, 0.13115153674568447, 0.1017268860180463, 0.1292634452027934, 0.16706630028784275, 0.13129719107278756, 0.22869596683553287, 0.1372621517096247, 0.13188317391489232, 0.19202712018574986, 0.11110468780887978, 0.15957148745656013, 0.10474357128675495, 0.2078316935471126, 0.12284086697867938, 0.16350023235593522, 0.09523533470928669, 0.1420219120170389, 0.14472435414791107, 0.13054882123001985, 0.14719785856349127, 0.1672581492790154, 0.11240294243076018, 0.11777398815112454, 0.1600846770618643, 0.0953106317403061, 0.12195242036666189, 0.13821049939308847, 0.08009675703942776, 0.14875973761081696, 0.21800545762692178, 0.09731961786746979, 0.08172213339379855, 0.09425664293978896, 0.30012257982577595, 0.18307708044137272, 0.11711708482887064, 0.2378009296953678, 0.06404941063374281, 0.1413570698350668, 0.09325773761208568, 0.20039971305855683, 0.20353332348167896, 0.14419188057737692, 0.13336102318550858, 0.14199270786983625, 0.08292264504624264, 0.13090479427150317, 0.08428563869425229, 0.32890150270291735, 0.1922425821955715, 0.15381371070231709, 0.14618917554616928, 0.09031096859169857, 0.14683774645839417, 0.10045857514653887, 0.17264999209770135, 0.15461538625614984, 0.11026738238121782, 0.1450498473963567, 0.11528832438801016, 0.09482352502111878, 0.19462814847273485, 0.0740653881803155, 0.14579243612076553, 0.15691373364201613, 0.15499641081052168, 0.13955504367394106, 0.12397940802787032, 0.23872718427862438, 0.11268312989601068, 0.08076820815248148, 0.12947850009160383, 0.15167256630957127, 0.18273679512952054, 0.1641597683940615, 0.15068938263825007, 0.3199109679886273, 0.14040190966001578, 0.0697606670271073, 0.18797143495508603, 0.08319954840200287, 0.18493896696184361, 0.1279295946338347, 0.09987211054457085, 0.09306255022862128, 0.22098030442638056, 0.13677560138915265, 0.1187632107841117, 0.07072257862559386, 0.14407547110957758, 0.15698165499738284, 0.0919134376038398, 0.10551874326275927, 0.08749604571078505, 0.13294084716056073, 0.18847104028931685, 0.0890570833746876, 0.19206582382321358, 0.1037825078570417], [0.05431426176801324, 0.00279074689024128, 0.03823418283302869, 0.03922477949942861, 0.047705371398478746, 0.043604682332703044, 0.03229557310364076, 0.013686634018085897, 0.04588571011221834, 0.0770523196884564, 0.03618190956435033, 0.07040264936430113, 0.02844180293115122, 0.037033067284418006, 0.005527014203835279, 0.024124729047928537, 0.06225450909031289, 0.013004684271956128, 0.04222687626523631, 0.045643082952925136, 0.008155532913016421, 0.056604884032692225, 0.06917941357408251, 0.07064251149339335, 0.042077598561133654, 0.018122001151953424, 0.03724259550550154, 0.026567182004717842, 0.027389848039352467, 0.0076389014388301545, 0.03163643400850041, 0.02671547922571855, 0.04769480660823839, 0.05852203044508185, 0.039912403494651826, 0.011077788159517305, 0.03835302145619478, 0.012973415681959262, 0.014735365020377296, 0.01600915675849787, 0.0166644672197955, 0.05855730748070138, 0.020658186936218823, 0.05410279972212655, 0.037812307077859125, 0.0028763434467171983, 0.012502708306003894, 0.01225212701995458, 0.04714235696675522, 0.0172090950488512, 0.012429985467211475, 0.015578331126432334, 0.012161324615590274, 0.05379823588633111, 0.04530803253874183, 0.05088258108922413, 0.049540730592395575, 0.009223582655457514, 0.044441869016736746, 0.0455904863109546, 0.07125591393560171, 0.02688964898698032, 0.039394128269382885, 0.0393433670646378, 0.020008582954428027, 0.060381684585341384, 0.029326955255653177, 0.009240137213574988, 0.07719035406730004, 0.031379611896617074, 0.048552654683589935, 0.03729633887165359, 0.014002570948962654, 0.03589894010552338, 0.05235758051276207, 0.051595388911664486, 0.03723825288138219, 0.05216949399826782, 0.08409849195075886, 0.021753517179084674, 0.02616592523242746, 0.07319904823920556, 0.04289741135601487, 0.04437292646616697, 0.021940377241532718, 0.03271356085315347, 0.06290032515036208, 0.03338007901662162, 0.05445521045476198, 0.04759039363956877, 0.038092677747564654, 0.027649022971412966, 0.008871936122886837, 0.05970402487686702, 0.0417978453582951, 0.02735534792632929, 0.04826922042827521, 0.02892453988481845, 0.039799206890165806, 0.07508603377001626, 0.02676370270949389, 0.009022616698140544, 0.045943975914269686, 0.05578380237732615, 0.08493448102048465, 0.01700985511498792, 0.03305862644421203, 0.014896627349246825, 0.024137198825233748, 0.05576588905283383, 0.07912004659218447, 0.01663086107665939, 0.05800281544881208, 0.02986086392775178, 0.060538432959999354, 0.020157735129552226, 0.046135838476142714, 0.06372146787387983, 0.005846947281887489, 0.024935831149507846, 0.022461415800665106, 0.05164158696840916, 0.005260891073183822, 0.018574460176751018, 0.07193925976753235, 0.0252777381600546, 0.0576531392123018, 0.03087551805323788, 0.04574428305828145, 0.03095193805971316, 0.07122109830379486, 0.02253987141219633, 0.06406072859785386, 0.015050181520304509, 0.043516886686640124, 0.051671673211136034, 0.049293886337961466, 0.025940544736970748, 0.03220969092633043, 0.021976665294330035, 0.03333183517679572, 0.06417211690651518, 0.026781171593548994, 0.0275260334102703, 0.03692481380754283, 0.04279516291405473, 0.06233521404543093, 0.05107725278607436, 0.09749744832515717, 0.030735872153724943, 0.014945293577121837, 0.06448937952518463, 0.011882277089171112, 0.036917580624244044, 0.04512963550431388, 0.07304933627269097, 0.024040529637464454, 0.029252357115702968, 0.06439735660595552, 0.038763718346932104, 0.025594797218218446, 0.03563835212428655, 0.029257839678653648, 0.009817986965312489, 0.016949156764894724, 0.04460798117465206, 0.04932962477739368, 0.02084824798761734, 0.0944675248382347, 0.08098870489214148, 0.04548495715217931, 0.03463082600917135, 0.02188660334130483, 0.05622625131426113, 0.03416676912456751, 0.022355253907984922, 0.02801481950362878, 0.08165294996329717, 0.03278103098273277, 0.048558676681880436, 0.08514884380357605, 0.052620299093957455, 0.031791516579687595, 0.023653715483046005, 0.037732165306806564, 0.013878537292060043, 0.01854323229885527, 0.04159397611926709, 0.023724566413355724, 0.023439904009657245, 0.009019633688564812, 0.015775538847914765, 0.027659660704167824, 0.024495531472244432, 0.03189338843471237, 0.025136338247518455, 0.06060128565877676, 0.043540740585220714, 0.040165690439088006, 0.043424432897674184, 0.0444478638736265, 0.03774461981707385, 0.0027621326444204897, 0.031551756230848174, 0.01697696652263403, 0.0047233899822458625, 0.012570836614551288, 0.019267341122031212, 0.03942681330123118, 0.0844033102371863, 0.03468547861224838, 0.029522495477327278, 0.02647273501913462, 0.015928441625354544, 0.049758034824792824, 0.014394009319533194, 0.0067272909135291615, 0.03757999365084937, 0.08291910987879549, 0.05238133602376495, 0.038904181881142516, 0.04434176135276045, 0.015929556119122674, 0.06122862521026816, 0.05537376366555691, 0.04059531845684562, 0.009892436675727367, 0.04858040337317756, 0.00998480140697211, 0.05706317336963756, 0.07533644711864845, 0.008941067815093058, 0.05241381749510765, 0.021557775093242526, 0.007659465290739068, 0.01594113531921591, 0.07944292069545814, 0.008530848443375101, 0.07859287238014595, 0.01807224078636084, 0.022458845849281976, 0.05976057398532118, 0.04555879872558372, 0.035119710490107536, 0.026177887804806232, 0.0069274468696676195, 0.09080702518778187, 0.01774699181052191, 0.06095648517033883, 0.01490906489613865, 0.07199175123657499, 0.05498056958562561, 0.02548913744145206, 0.037341760005801916, 0.09119953734001943, 0.016487261014325277, 0.061120358162692616, 0.03175839389275227, 0.024494868204263703, 0.019055453295420324, 0.02852662998650755, 0.052568364023630104, 0.0027015818756938514, 0.038095619196870496, 0.05851393552230937, 0.012418219669988113, 0.06941384742302553, 0.039569397257374864, 0.06103675586304494, 0.039774565890963585, 0.07312101671206099, 0.017026594573897973, 0.05324128416499921, 0.02032001526094973, 0.04099006977464471, 0.0656641950564725, 0.033330623991787434, 0.03389713627153209, 0.017505949030497243, 0.014110177273063787, 0.046907675452530384, 0.015037192663710033, 0.03788447606244257, 0.013151076505891979, 0.05185458928878818, 0.024431562583361353, 0.056396180231656344, 0.047563618647732904, 0.02122555417008698, 0.016275330779275725, 0.06002335024199315, 0.029736902365194898, 0.010313278513162263, 0.01479193618121956, 0.01703470476370837, 0.00746005487495235, 0.07309262002153055, 0.09557508397847414, 0.01689604782898511, 0.04168987347345267, 0.0428878033001508, 0.058738693461886475, 0.0111756363018815, 0.06360549266849246, 0.01302426339991923, 0.027841575942667465, 0.016238946035238247, 0.02369147595683379, 0.07561728597751685, 0.024675182100119333, 0.024163369920903018, 0.05436702465106334, 0.022930329299664924, 0.03251404441627009, 0.02645703711147819, 0.03584448427760175, 0.061823910767478604, 0.04822918346949986, 0.004957793721197439, 0.025522068442244614, 0.024185340884806852, 0.035455785492169004, 0.052706147344516854, 0.0160751324146986, 0.027069509960711002, 0.024570579141644493, 0.08565505128353834, 0.03614315164408513, 0.055776307958045175, 0.02379212135981236, 0.026753919930862527, 0.026467739305059825, 0.02629968653699117, 0.03536845803526895, 0.049621679820120335, 0.041884762301508865, 0.03086349441270743, 0.08138157666793891, 0.011463406395965388, 0.03449573307963354, 0.03325668063813022, 0.022282262199691365, 0.015768936702183316, 0.020663491383727108, 0.07258904525744063, 0.052123014349490404, 0.014038786059245467, 0.039160206714378934, 0.009321049970042492, 0.05403969257271715, 0.03243103583476373, 0.01617671419600291, 0.13901573047041893, 0.1800315167222704, 0.11424495466053486, 0.10624761879444122, 0.15468117701155798, 0.10464506835809775, 0.10144648820694004, 0.10232273475932223, 0.1648946761020592, 0.11022268049418926, 0.07598718255758286, 0.21246561274996825, 0.07623534995530333, 0.10092965486858572, 0.14149595238268375, 0.10791456220405442, 0.17813997822148459, 0.1433075458875724, 0.19607691573245184, 0.13837934604712895, 0.097088977029281, 0.08868361091507332, 0.17351725484643662, 0.11579050815531186, 0.09378632996231318, 0.130599548508014, 0.11275147194308893, 0.09720651965056147, 0.11348629822688443, 0.04991967204426016, 0.09170499164611101, 0.0983633811452559, 0.08141604624688625, 0.27675133677465574, 0.09325204470327922, 0.08924431832773344, 0.10073541064879724, 0.08487528562545776, 0.13444984118853295, 0.08294178651911871, 0.06815475105707135, 0.10798854966248785, 0.15499746932515077, 0.10633150607879673, 0.12545883149972983, 0.07627905439585447, 0.15384011928524288, 0.15060196018644742, 0.14458021973924978, 0.07049010574285473, 0.08600978260593754, 0.12285308060901505, 0.08040495443024806, 0.13881990526403698, 0.15291619886245045, 0.12493412036980901, 0.20644138886460237, 0.04995834854032312, 0.09108830509441239, 0.17348706003810677, 0.18623053122844013, 0.13539117281990393, 0.13012579535799368, 0.1427130542163338, 0.13619767954306944, 0.14957856652992113, 0.12327104460980211, 0.1557422022202185, 0.16876209500644887, 0.08399867944951568, 0.1571918787168605, 0.0818332095763513, 0.1264737163271223, 0.11680183745920658, 0.2254876768482583, 0.17080481110938958, 0.09362584964505263, 0.2039900589734316, 0.2505177344594683, 0.0911615461643253, 0.1702687413032566, 0.16503148233251913, 0.20097999620650495, 0.11930295825004578, 0.0464040294422635, 0.13981055282056332, 0.11155742672937256, 0.13356918415852956, 0.15023514415536607, 0.1737139214362417, 0.14544733321028097, 0.08215763752481767, 0.12982774206570216, 0.13415522128343582, 0.1822285588298525, 0.09371132470135178, 0.13023627442973001, 0.1611398940107652, 0.09716685249337129, 0.15937935348067964, 0.2194955883813756, 0.1250513983624322, 0.14728838870567934, 0.08951913858098642, 0.14619183540344238, 0.08469796406903438, 0.12953515776566096, 0.13371827187282698, 0.102257086496268, 0.20551735987620695, 0.20053425298205443, 0.11491203600806849, 0.13616322353482246, 0.1207908634096384, 0.13345908506640367, 0.06717181165835687, 0.08794193142758948, 0.16944300489766256, 0.0825047760403582, 0.09986615300710712, 0.15879562337483677, 0.14113045270953858, 0.09384764238659825, 0.0884059543854424, 0.25661963703376905, 0.13334613612719945, 0.0938745734414884, 0.11155414261988231, 0.10927361356360571, 0.09155203628220729, 0.1318832960511957, 0.07352478576025792, 0.15162196116788046, 0.13671184623880045, 0.24921776992934092, 0.1481962957020317, 0.08558390010148287, 0.18614743783005647, 0.15885126324636595, 0.08334662086729493, 0.10696289648434945, 0.19960232584604196, 0.09080035518854856, 0.10529530846646853, 0.10242475249937602, 0.11699618345924787, 0.2418565877846309, 0.13974869756826333, 0.1885406986943313, 0.10460618830152921, 0.113552285757448, 0.12986385369939463, 0.09693913614111287, 0.2318483048251697, 0.10538982160921608, 0.16085025455270494, 0.07234556653669902, 0.10425691240067993, 0.11465181782841682, 0.09976055260215487, 0.12088026718369552, 0.1340467371046543, 0.11911640183201858, 0.141671340114304, 0.1009107848097171, 0.09971519253615822, 0.08592831090624843, 0.05542706259127174, 0.20092403063816683, 0.09659872190760714, 0.14425069599279336, 0.15597287698515824, 0.09513224488390343, 0.1713540173534836, 0.14224969622279915, 0.14467767093862804], [0.04491325407954199, 0.04175116554168718, 0.012718559625292463, 0.02989389161978449, 0.039851769605385404, 0.029572802063609873, 0.014396982999252421, 0.0625784620642662, 0.12739139422774315, 0.04541380597012384, 0.0667511945856469, 0.035255641410393376, 0.061244102594043524, 0.032082679348864725, 0.02191691010791276, 0.02334588110846068, 0.03304106256525431, 0.022018096642568707, 0.02975441196135112, 0.050955866263913255, 0.057372008583375385, 0.09298498010528938, 0.005790399021602103, 0.05274615376921637, 0.03730059667889561, 0.04681109277797597, 0.02964301347466452, 0.014443293014275176, 0.05210299078109009, 0.03285186664600458, 0.010722023767552205, 0.018075840414634774, 0.025973000763250247, 0.007899174749452089, 0.039125486077474694, 0.003625084363323237, 0.04678774778065937, 0.014357041035379683, 0.015296474465035965, 0.04269006462501628, 0.07564923140619483, 0.040497969037720134, 0.07001977919467858, 0.030279811804315875, 0.022283819437559162, 0.03876911270033036, 0.02357932599261403, 0.07471131959131785, 0.018674661139292375, 0.029238358938268254, 0.04609922472653644, 0.050860311569912095, 0.027314288076013327, 0.009298233381871666, 0.03169412644846099, 0.05134127754718065, 0.011890408483200839, 0.044423233052449565, 0.08606011633362089, 0.052223267898495705, 0.052631542419216464, 0.04004187136888504, 0.013507293819982027, 0.024250785587355494, 0.05766627565026283, 0.05022603739053011, 0.03290795774332114, 0.009719155795340027, 0.020456059835851192, 0.03178263455629349, 0.05372154785852347, 0.0239532530706908, 0.050734891157065115, 0.05001899600028992, 0.028397477631058012, 0.04083995747246912, 0.023753558518365026, 0.02415502394017364, 0.02383930329233408, 0.03503338726503508, 0.014866544499195047, 0.025046322095607008, 0.01356257067527622, 0.045631130558571646, 0.028423485878322805, 0.03264455384175692, 0.09985113024179425, 0.025420240691996047, 0.023441300095458115, 0.10170258089367833, 0.02354150784334966, 0.0428086318341749, 0.019950137340596745, 0.0405570253330682, 0.008684840269519814, 0.013909557368606329, 0.03624005662277341, 0.05497432367077895, 0.04090776686955776, 0.0411061976504113, 0.012626165208140654, 0.012088878279817956, 0.02495268595937107, 0.05793786607682705, 0.09417239603187356, 0.03515300281079752, 0.034202100442988534, 0.03817399338419948, 0.03555583208799362, 0.06303344015032053, 0.013775866462050803, 0.028992759795593362, 0.03650746388094766, 0.006245296107538576, 0.058986229822039604, 0.027563062762575488, 0.0177634632480996, 0.030319149872022014, 0.07597011061651365, 0.02148646445545767, 0.08613386630479779, 0.035323840965117724, 0.035859127063304186, 0.04640550186325397, 0.03553774912974664, 0.019379141640716364, 0.020438531579981958, 0.029072664079389403, 0.07179553926523242, 0.04358916762950165, 0.010938635894230433, 0.030356119852513075, 0.02759078939977501, 0.04961382916995457, 0.048363373947462866, 0.0036388972158809857, 0.029433251158999543, 0.06938301479177815, 0.014713322810296501, 0.05227676020669086, 0.043170165470136065, 0.05962051757212196, 0.050496538768389394, 0.033474917856178114, 0.03874606965109706, 0.009278946023966585, 0.013961789298004337, 0.012563025828317871, 0.02391353671971176, 0.023680176652435745, 0.03579371289483138, 0.03445477670590792, 0.04291668853589466, 0.05198735145053693, 0.05810569492833955, 0.00720817589067987, 0.016571005806326866, 0.04399883993236082, 0.07583703632865633, 0.017400577631113783, 0.04905129989076938, 0.048339235064174445, 0.03477612749806472, 0.010950500927200275, 0.03271844630528774, 0.05060986429452896, 0.04437334376520344, 0.033835637250116894, 0.04463398602924176, 0.028384151203291755, 0.042208348866552114, 0.016861914124872004, 0.021545354509726167, 0.02223481224583728, 0.021915132346163903, 0.01998045258889241, 0.02380087785422802, 0.0366978641998555, 0.053883120617164035, 0.05976584620241608, 0.019100932105045234, 0.00797909005944218, 0.02711501082272402, 0.01099018844044102, 0.05140113112117563, 0.06275667250156403, 0.015006706085322159, 0.019865619018673897, 0.03879358067310282, 0.02707206973406885, 0.03271443277065243, 0.015331661594765527, 0.010056463186629117, 0.008243281061628034, 0.039171280405883274, 0.09537096707416431, 0.04069130741325872, 0.012381141972062843, 0.040141873859933445, 0.031519111911101, 0.059587079366402965, 0.035825135851544995, 0.09175924052085195, 0.028574812758181776, 0.016018194844946265, 0.004674876848834434, 0.02623732407976474, 0.027680361111249243, 0.010451518148849053, 0.0387699439057282, 0.006584672606550157, 0.041116480848618915, 0.023150885411139046, 0.029588917270302773, 0.05002638863931809, 0.009567465051077306, 0.021587330382317305, 0.04537825412782175, 0.025204514053517153, 0.07372165591056858, 0.02296155208854803, 0.01646802793922169, 0.038322948784168274, 0.03339778199525816, 0.018111146287992597, 0.020895993104204535, 0.031492703328175206, 0.08949369351778712, 0.03308840734618051, 0.04018591756799391, 0.011936447932384908, 0.013146023116340595, 0.043535950127989054, 0.03320318154458489, 0.050573169120720456, 0.06299292482435703, 0.06464031964008297, 0.021061939021040286, 0.051557760752205334, 0.022587385826877186, 0.04693150220971022, 0.07749032761369433, 0.013316943543031812, 0.02340734620312495, 0.04279370406376464, 0.08813678632889475, 0.02406149636954069, 0.05860663697655712, 0.023169728328606913, 0.03648175418909107, 0.008725889093641723, 0.04916023529533829, 0.02675924982343401, 0.02003036901753928, 0.005969377475724156, 0.04911662584968975, 0.02301427086682192, 0.034381023342055936, 0.04647654787238155, 0.07279873971960374, 0.04431717124368463, 0.04032547525795443, 0.06505380530974694, 0.005331514694262296, 0.005351111209685249, 0.059571778401732445, 0.021470110065170696, 0.03595496674201318, 0.05671427405572363, 0.06447760694261108, 0.042398006189614534, 0.11606249213218689, 0.04059324213968856, 0.05306188289874366, 0.04294942785054445, 0.04015364983518209, 0.02641887290935431, 0.03906699296619211, 0.009228597029245325, 0.10529975287084069, 0.007531066109160227, 0.0752320545060294, 0.05076667034466352, 0.038072155455925634, 0.06361700062240873, 0.08206530247947999, 0.04146542765998414, 0.02841263949604971, 0.006285364448558539, 0.050492331851273775, 0.03353245084040931, 0.04123455272721393, 0.04667402531153389, 0.008004211970338864, 0.04860049140240465, 0.016419599198603203, 0.06570861874414341, 0.07840265865836825, 0.01561885154140847, 0.03115922032988497, 0.05571523302101663, 0.018542060129610554, 0.021610286918335726, 0.04948786932176777, 0.03876715512680156, 0.05132033456383007, 0.022207063556249653, 0.06507297392402377, 0.036578302936894555, 0.03448466617347939, 0.01587269827723503, 0.009066433096969766, 0.05757345884506192, 0.025806028562198793, 0.032742178067564964, 0.00899972631928644, 0.014830534645755376, 0.07174890355340072, 0.01722998883841293, 0.021358845589150275, 0.009531183783630175, 0.041000668491636, 0.035569002452705584, 0.06433303148618766, 0.027057313293750797, 0.04538517179233687, 0.012533551963445331, 0.025845911154257398, 0.08709155063011817, 0.025272890027346354, 0.03643423977441021, 0.05528069919507418, 0.03880491899326444, 0.01633406477048993, 0.060021491056042056, 0.05024081927591136, 0.013954628209051276, 0.03904778703248926, 0.017989939577611427, 0.034578551671334674, 0.0507006624580494, 0.03985520977792995, 0.005218607739412359, 0.04806473372238023, 0.015426771848329475, 0.05146500162248101, 0.008535386146312314, 0.03698981746232935, 0.007867733133025467, 0.052084161434322596, 0.027693378805582012, 0.03838234095435057, 0.17672823183238506, 0.15207461187882082, 0.07946609945169517, 0.14232973621359893, 0.14311709467853817, 0.1345695483365229, 0.08621455090386526, 0.12984131276607513, 0.2925923067544188, 0.1720014483268772, 0.2567143605223724, 0.07204243780246802, 0.13499152926462038, 0.09048629525516715, 0.08386160859039851, 0.09015474947435514, 0.1371278017759323, 0.09726216630744082, 0.09413122931229216, 0.24300773601446832, 0.16469323262572289, 0.11950096833918776, 0.10101327752428395, 0.1612343867974622, 0.10258443214531456, 0.09279365358608109, 0.13846710776644094, 0.08186596246170146, 0.11162823185856853, 0.0826913799558367, 0.0741094658151269, 0.10966755063938242, 0.08106508079384055, 0.09468683414161205, 0.08447735197842121, 0.13584043085575104, 0.16936236779604638, 0.09315052907913923, 0.09594879392534494, 0.045794406440109015, 0.15176734408097609, 0.15781953717981065, 0.3196135253778526, 0.21736424203429902, 0.10973745331700359, 0.17450239269861154, 0.09669803229293653, 0.11166356996233974, 0.16302600423140184, 0.128462909587792, 0.15092684275337628, 0.234245949025665, 0.09110223541834525, 0.16993814547147068, 0.12252609458352838, 0.16768310219049454, 0.10091674913253103, 0.09109460189938545, 0.08407546925757613, 0.2128017997103078, 0.11237688668604408, 0.14858456701040268, 0.15054562820919923, 0.10396109148859978, 0.23096080816217832, 0.12900682325874055, 0.1129145985469222, 0.09437038576496498, 0.08324784652463027, 0.11147378371762377, 0.14337947059954914, 0.11242378702653305, 0.06743664387613535, 0.13881525051380905, 0.13940421890999588, 0.14883638492652349, 0.08919241039880685, 0.05165188034464206, 0.05594575511557715, 0.1079000144132546, 0.09041181246617011, 0.09069697359310729, 0.14234664530626365, 0.13965788244136743, 0.11787780400897775, 0.19835285789200238, 0.19181959703564644, 0.11699516565671988, 0.06938706564583949, 0.15753555670380592, 0.10294245436255421, 0.09907388873398304, 0.13626698510987417, 0.1768784594855138, 0.16563761766467774, 0.13773889041372708, 0.08988386472421032, 0.11440540105104446, 0.12194575715277876, 0.1410418360361031, 0.15032240375876427, 0.18862639766718658, 0.13215183307017597, 0.1650294331567628, 0.14155033017907823, 0.15706652615751537, 0.09110603521444968, 0.19411520314003738, 0.1053984390039529, 0.15500463465494768, 0.1254013188715492, 0.12995271464543684, 0.1279943133039134, 0.08518916235438415, 0.11025900247373752, 0.10498414587761674, 0.14264961119209016, 0.07199889621032135, 0.16172230775867188, 0.07504753369305815, 0.10245974455028772, 0.16605385818651744, 0.14617442419486387, 0.11084135515349251, 0.2500156728284699, 0.24205675561513218, 0.12557871506682464, 0.10346991355930056, 0.1558729830597128, 0.14010799543133803, 0.06716335032667432, 0.11233747737216097, 0.1346929467150143, 0.20260092137115343, 0.12448512017726898, 0.11525819743318216, 0.0906419986858964, 0.12873918190598488, 0.061793715959148746, 0.09206922245877129, 0.07458724267780781, 0.11359869076737336, 0.21039756014943123, 0.13431425632110663, 0.12019914016127586, 0.09860238832022462, 0.19293200091591903, 0.15535532869398594, 0.07818661989378077, 0.15184944681823254, 0.1330007618027074, 0.07477874561612095, 0.2688179053366184, 0.11506528992738042, 0.14872228247778757, 0.08935836649366788, 0.09013456984290055, 0.13261889586491243, 0.22329543876860822, 0.13880169338413648, 0.08223735860415868, 0.10829188195722443, 0.11008803879043885, 0.07694834098219872, 0.1266783353473459, 0.1781300308981112, 0.10807925622378077, 0.1591501986341817, 0.16204379765050753, 0.07386448074664388, 0.10745442725185837, 0.08964044707162039, 0.09006860266838755, 0.2295401729643345, 0.1497001192931618, 0.09582100542528288], [0.06324578089905636, 0.06324590303535972, 0.03510049098570432, 0.04475777456536889, 0.019006914292861308, 0.04524847073480487, 0.05290892753483994, 0.04948726203292608, 0.03432572952338627, 0.1380030440964869, 0.017049503612465093, 0.034363286436668465, 0.0652431980041521, 0.06093826650508812, 0.00840152136515826, 0.052331663867724795, 0.06067100513194289, 0.046682625742895265, 0.015948858744065677, 0.06643416945423399, 0.059962302446365356, 0.03667093653764043, 0.08094346696244818, 0.008476295076044542, 0.04235969270978655, 0.013203004790869142, 0.018426933092996478, 0.050866649086986265, 0.0383426670118102, 0.07060188081647668, 0.029764074300016676, 0.025474581168964505, 0.02797626005485654, 0.06321542324232203, 0.011075276731779533, 0.00952808203042618, 0.04193213422383581, 0.020352313527837396, 0.055698710693312545, 0.0735161140827196, 0.022236025127183114, 0.02542080557239907, 0.012722331431827374, 0.05174049023272736, 0.06564056168177299, 0.025851544691249728, 0.08336030691862106, 0.03053245074780924, 0.03856982696535332, 0.05237612148214664, 0.0024858567215103123, 0.032666019297071865, 0.01056202351381736, 0.01402887435896056, 0.039671282683100016, 0.050666087706174166, 0.0315058567295117, 0.059699851886502335, 0.03415066748857498, 0.02737629260601742, 0.012267013230094952, 0.05252217275223561, 0.025422009972057173, 0.023115679621696472, 0.03489620444763984, 0.0071334657924515855, 0.027637211373075843, 0.032725679488586526, 0.019330148019694855, 0.03328783218083637, 0.05400968096884234, 0.0382683165371418, 0.02099992600934846, 0.07365880999714136, 0.012244768307677336, 0.014709645150495427, 0.0059171336719633216, 0.0532492739148438, 0.038539041831557236, 0.019569273938291838, 0.046144388017377684, 0.04668800313291805, 0.08996825412447963, 0.021114182824801122, 0.06187023435320173, 0.025347181130200624, 0.07408452286784138, 0.010433964447916617, 0.0779006038127201, 0.03793695056810975, 0.01195078028831631, 0.05235649824940732, 0.09312857168593577, 0.04070430814421602, 0.03950277190389378, 0.07816465571522713, 0.00687435532121786, 0.054930032297436676, 0.02633067183861775, 0.029991811008325646, 0.06997703148850373, 0.03502186234774334, 0.05301238716180835, 0.03614702607904162, 0.07815115286835603, 0.045114534707473855, 0.0032280436259627876, 0.061267247423529625, 0.07570884070758309, 0.017376511690339873, 0.026956601733607904, 0.06362027116119862, 0.007700936502910086, 0.01250356326012739, 0.04947498394176364, 0.02171078134727265, 0.030399759832237448, 0.00639938165633274, 0.013132354876558696, 0.02693749249114522, 0.0464687888244433, 0.01996980807078736, 0.044890509585716894, 0.0684168284226741, 0.033372119800852876, 0.02997500030323863, 0.028404500468501022, 0.030744625255465508, 0.06716847326606512, 0.01590096265343683, 0.03595437641654696, 0.04721776595605271, 0.018405360768416097, 0.05102375029985394, 0.03277670532198889, 0.03368132481617587, 0.04396899117689047, 0.028203285997733474, 0.02596941470567669, 0.07197672168591193, 0.03126476984471083, 0.01417910455659564, 0.06632208225450345, 0.030758928773658614, 0.0312789919387017, 0.040604417611445696, 0.08469105658254453, 0.03885620266997388, 0.03391949060772147, 0.047289307295743904, 0.09406051917799882, 0.020618263632059097, 0.06307422689029149, 0.0215472696748163, 0.046066224175904474, 0.0485742083484573, 0.021855529830125824, 0.012210916195596968, 0.01013364824133792, 0.028956302109041383, 0.05306143506563135, 0.04915060688342367, 0.10336845221796206, 0.024370153467836123, 0.012038829536842448, 0.002419403970374593, 0.023154522358839, 0.03202804370916315, 0.01702044535029147, 0.02173645541604076, 0.03071668996874775, 0.05918783614678042, 0.03657419101468154, 0.05520383135548659, 0.014088829713208335, 0.010769672192899244, 0.05470418870182974, 0.014488597101132785, 0.013836195858727609, 0.0446653445251286, 0.03404263114290578, 0.033340092947972674, 0.06132617818989924, 0.05252924308712993, 0.03984791213380439, 0.07207793196929352, 0.026564435634229864, 0.01495294745213219, 0.01430382183752954, 0.031033684566084827, 0.029636357046131576, 0.08775912052286522, 0.007333572554801191, 0.018869254804615463, 0.03075528164793338, 0.028196865360119512, 0.13433613229010785, 0.06489587628415652, 0.054249376856854985, 0.03765007274757538, 0.08990763380591359, 0.029046170679586272, 0.02937937547851886, 0.08847201655485801, 0.02484687520856304, 0.014117838781593102, 0.02347439564099269, 0.015125598991289735, 0.03604213135050876, 0.05444151083273547, 0.03320795843111617, 0.008556108605781836, 0.03445737888770444, 0.014149586586946887, 0.12166223808058671, 0.044990244055432935, 0.04378991900011897, 0.02656009470644806, 0.038938447899584255, 0.03493104722084744, 0.028335434085290347, 0.054362237586506774, 0.014761697268113494, 0.05643259042075702, 0.03170724253037146, 0.036209088284522295, 0.003162613554325487, 0.02510207222907671, 0.007332977140322328, 0.030653277478579963, 0.01434414038833763, 0.034208960432027063, 0.0091368260161419, 0.033491138235798905, 0.0426539088865476, 0.021272407013124654, 0.01122076142512794, 0.03987323506070035, 0.0034609333836540046, 0.041181304691625495, 0.031191325214292322, 0.0414030499357198, 0.0454735645492162, 0.015343632648832031, 0.04320440434717706, 0.035941830304052146, 0.013357362177755152, 0.08874255525214331, 0.020281006282727634, 0.07867500225880317, 0.05167702685243317, 0.018137303812961494, 0.01781294371799699, 0.04971013364515134, 0.040072483476251364, 0.026431327419621602, 0.0604512072833521, 0.03479853950973068, 0.036271438867385895, 0.020347490840192353, 0.05221011110448411, 0.013834943961618202, 0.05341706544693027, 0.022758257907948325, 0.014190724468789995, 0.029639183144484247, 0.027769600340564336, 0.04613506494622145, 0.03445949252428753, 0.03932167090741651, 0.031208481972238848, 0.03464016604370304, 0.08718121224748236, 0.04471620751012649, 0.024087016071592058, 0.05866535061172076, 0.11184547163013901, 0.04412245883473328, 0.05826025842023747, 0.013838192448019981, 0.038777787770543776, 0.05237229454464146, 0.015910628384777477, 0.035058306463594945, 0.01361163893514978, 0.03756322365786348, 0.012059703818522394, 0.00744419835973531, 0.02951999507578356, 0.04961663830493178, 0.06681711426270859, 0.03895520432186978, 0.03758719290739723, 0.05053169706038066, 0.014276380185037851, 0.019082581125465885, 0.048843817452767065, 0.009981640281953981, 0.03270357960302915, 0.08543046976306609, 0.02590291148849896, 0.0721132361463138, 0.04644665840481009, 0.02107776076133762, 0.056340601428278854, 0.07622498194021837, 0.019462679479537264, 0.0148169673380575, 0.07378917693027429, 0.01715212524868548, 0.06188337079116276, 0.03975786375147956, 0.058127048425376415, 0.011748191784135997, 0.06324802006461791, 0.03326306225998061, 0.03403068892657757, 0.03132819929825408, 0.02401012278694127, 0.03463193880660193, 0.01629588021231549, 0.037100106544260464, 0.08930911163666419, 0.012733850411937704, 0.041331410208450894, 0.00014273467838523044, 0.058648353309503624, 0.03952078700863889, 0.029825091561568633, 0.07255845011344977, 0.04474768474964159, 0.06121825719518321, 0.013051710141423558, 0.025551762830998217, 0.003881298762280494, 0.014780363766476512, 0.018587771337479353, 0.07616865674832038, 0.10127236255045448, 0.0755010936409235, 0.06700727370168481, 0.04487531379397426, 0.0498877232229071, 0.03212010055514319, 0.024064315682543174, 0.058006418469761095, 0.026004754505785446, 0.03997581598481961, 0.03813579186264958, 0.03613483959010669, 0.021552463860384057, 0.023008323507383466, 0.22427615257246153, 0.20056025444396905, 0.1227664045457329, 0.1317691800317594, 0.16767459336136067, 0.20190448659871305, 0.12164294054465634, 0.18279258427875383, 0.1273444260337523, 0.16759950667619705, 0.17305566104395048, 0.09373482236904757, 0.15340243705681392, 0.11811100292418684, 0.14774182651724133, 0.1747952484126602, 0.13910267794770853, 0.11116726909364973, 0.10275502941970314, 0.12475738913885184, 0.22187724629683153, 0.10458971347127642, 0.1847841524119888, 0.17403128583516392, 0.1794607059231826, 0.13397718726524285, 0.04866914896826659, 0.10493410391999142, 0.18690308156822408, 0.17614853222455296, 0.17416011249380453, 0.11286748107522726, 0.12351651143814836, 0.1465821965996708, 0.08540984229849917, 0.09786636102944613, 0.1888935776161296, 0.09635975544473954, 0.17768569902649947, 0.12787714387689317, 0.12279369522418294, 0.09946202433535031, 0.07710468902119569, 0.09809391453330006, 0.14816876075097493, 0.1516314335167408, 0.11200659655566726, 0.17814369659338677, 0.1781626684325082, 0.10834209354860441, 0.10445024059819323, 0.12045596566583429, 0.10553222575357982, 0.09097492867814642, 0.18426808581820556, 0.12518141924270562, 0.12047036417893, 0.16860581482095377, 0.1509120642606701, 0.09843021005924259, 0.06950346832828862, 0.18961385610912526, 0.07050090802035161, 0.06547746221934046, 0.07343874073454312, 0.10921682696789503, 0.17106785199471883, 0.14161032624542713, 0.08930771385452577, 0.08381124093596425, 0.1074557164683938, 0.2171536654766117, 0.11652841498809201, 0.14325105106191977, 0.11268132499286107, 0.10243188390242201, 0.09024917440755026, 0.1414460800588131, 0.13854018598794937, 0.11205695063940116, 0.18166511692106724, 0.1106413026739444, 0.30908040915216717, 0.11543069460562297, 0.18638995981642179, 0.09657179085271698, 0.11300698787506137, 0.07366560213267803, 0.16774741373956203, 0.10510011429765395, 0.10920482368341514, 0.16197173723152705, 0.18754074163734913, 0.2156043800392321, 0.16296554676124028, 0.16536680076803478, 0.22759623798940862, 0.15640726153339657, 0.09541363335613694, 0.09438136446156672, 0.2528945883469922, 0.09680270989026342, 0.14035032742789813, 0.12746322394481727, 0.17461961640843324, 0.10935723621930395, 0.04640339161934597, 0.12448225675949029, 0.10856134856918029, 0.12230671064129897, 0.17433676230055944, 0.127715367557747, 0.05447696089478476, 0.08786168109093394, 0.1389098111540079, 0.14389184596283094, 0.08399296618465867, 0.1577685656292098, 0.1060049475303718, 0.13237881660461426, 0.12796517701021262, 0.10837680061480828, 0.17500883766583034, 0.15171650823737892, 0.07791072755519833, 0.14596672462565558, 0.08875354073409523, 0.08782272639551333, 0.233310764921563, 0.16534864317093576, 0.0690818741651518, 0.1964916227651494, 0.14663930210684026, 0.11507108461643968, 0.12258181587925979, 0.16722397825547627, 0.15811875755233423, 0.06442395517868654, 0.18211859544473036, 0.0838455476665071, 0.1481714341789484, 0.09547573288104363, 0.15932448713907174, 0.11371365495558296, 0.10948445474995033, 0.1002679407330496, 0.16116171569696494, 0.19559329668326036, 0.134053712444646, 0.11457308062485286, 0.17801432710673126, 0.15990054979920387, 0.14584916164832457, 0.17795676019574913, 0.2659823346350874, 0.17014740567122186, 0.0766276992591364, 0.1133834458887577, 0.06266975895102535, 0.14869964654956544, 0.10822311243308441, 0.1541766319423914, 0.1328503577304738, 0.1525870550956045, 0.12173933322940554, 0.12016438559762069, 0.05775763360517366, 0.07030038056629044, 0.09433023684791156, 0.12898884208074637, 0.09497656180922474, 0.10708199973617281, 0.10533475170710258, 0.1532244301800217, 0.06323686494891133, 0.10299309343099594], [0.019467887235805392, 0.0764104730582663, 0.026485430409333537, 0.012630815717524715, 0.03079410402902535, 0.020252400942678963, 0.019721801825133816, 0.012557400773013276, 0.01980252204728978, 0.06947997066059283, 0.022127507021650672, 0.02200780326633581, 0.03794439070458923, 0.023943041118660142, 0.01757494586386851, 0.048741860780864954, 0.01184247252863965, 0.021760158340579698, 0.06455746372895581, 0.019339671258681586, 0.029524955166769878, 0.08967695904097386, 0.020089024977226342, 0.02010272120657776, 0.0224695259904755, 0.05602864495345524, 0.02735846409840243, 0.014927164817761098, 0.06307299874190773, 0.027358411511938487, 0.030160976573824883, 0.018212180152269344, 0.02906792111960905, 0.030978431459516287, 0.037899447937629054, 0.023585639760962555, 0.03522173501551151, 0.01821395112866802, 0.04969274279262338, 0.05187676042052252, 0.03387557242863944, 0.012031424175282674, 0.02194629406689533, 0.02646451796005879, 0.0596460508448737, 0.024949893787769333, 0.06840515762035336, 0.04087985533156565, 0.022932909429073334, 0.02569628061194505, 0.02594306888724012, 0.031659697581614764, 0.026091120139296566, 0.035323430451431444, 0.0955950329080224, 0.07058028983218329, 0.04210924882707851, 0.027135975858462707, 0.03660815169236489, 0.010378943739591964, 0.041295118762978485, 0.05947262407945735, 0.007117390449691031, 0.04619584132784179, 0.09355448811714139, 0.0838442448792713, 0.03564449625888041, 0.013690993605580713, 0.013760532418798124, 0.029804111258792024, 0.05696369335055351, 0.01389909435861877, 0.04229732516354748, 0.03118342367400016, 0.02018027945554682, 0.009668342004130994, 0.03856684819662145, 0.016606684873944948, 0.027684281347319484, 0.042777005316955705, 0.039346128702163696, 0.014906993667994226, 0.04123746703511902, 0.013716132479852863, 0.04440137065414872, 0.06507101295781986, 0.0184758944836046, 0.018067223019897938, 0.032411870613162, 0.05481612662385617, 0.09942982784871544, 0.04621971558247294, 0.040033481283379455, 0.021243638824671507, 0.02772366182346429, 0.05810367289398398, 0.045085035397538116, 0.04469377853508506, 0.01995841377148671, 0.0650415306112596, 0.018432950002274344, 0.0706631186019097, 0.036734715436718295, 0.015694791484358053, 0.016190524079969952, 0.039600229888622246, 0.0051308133656026, 0.015925512050411532, 0.07510350604674645, 0.007582980823437018, 0.018332231656781266, 0.008767177101357706, 0.0028959847030429436, 0.06765953584441117, 0.02770739733906729, 0.019636323376159583, 0.02739919485923435, 0.05538622156849929, 0.03531950173367347, 0.016385149975706424, 0.030738447194120715, 0.061756932575787814, 0.04893416099782501, 0.03841834741511515, 0.05777124501764774, 0.013052822090685368, 0.05988927172230823, 0.025251816426004683, 0.01095361540293587, 0.10476482978888921, 0.025023781162287508, 0.027643888157659342, 0.038414262634302886, 0.047691335901618004, 0.05742294620722532, 0.017095021437853575, 0.0785545487222927, 0.04636875240664397, 0.022824318381026387, 0.03786101232149771, 0.029063636170966283, 0.028982954964573895, 0.02071992683756564, 0.027414935175329447, 0.051222489814140966, 0.04392079144184079, 0.04320213125486459, 0.036315906659833024, 0.09106845794511692, 0.037779048683920076, 0.0016106471614745843, 0.06651342234441213, 0.016046479577198625, 0.04336016884605799, 0.05772211229694741, 0.041170322602348666, 0.03348325026620712, 0.029798404779285192, 0.02370071760378778, 0.027837014491004602, 0.04676497953810862, 0.01848341095527368, 0.05623352520966104, 0.09661903724606548, 0.014079946841645454, 0.025460930740726844, 0.01401167010356273, 0.03130445735795157, 0.034850783313491514, 0.04606948792934418, 0.06161089148372412, 0.06471172866544553, 0.06382200640759297, 0.04097989514204008, 0.04030315484851599, 0.04342358133622578, 0.06013320506151233, 0.05391619919932314, 0.026129179168492556, 0.06363933799522263, 0.026132634608075023, 0.03354768734425306, 0.016580669841329967, 0.010602464200928807, 0.011879048110651118, 0.06054835992732218, 0.06116342478032623, 0.029581677301653793, 0.039405544621071646, 0.014224725858574467, 0.06297618536544697, 0.015027588000521064, 0.05829878563859633, 0.032839123758354356, 0.12502682182405675, 0.029039870481938124, 0.021779101341962814, 0.028480676202369586, 0.0021031903244355427, 0.04813220724463463, 0.03628507063591054, 0.02474096437383975, 0.03420257202482649, 0.0388357143050858, 0.025920762048502053, 0.010676591607209827, 0.04321471129411033, 0.08477017376571894, 0.05100427973749382, 0.004828206679251577, 0.01036969615545656, 0.0641423902873482, 0.018465363620115176, 0.013770853784600539, 0.021239738944651823, 0.019454411530335034, 0.02404172046642218, 0.02391970290669373, 0.03266870629574571, 0.017020279109211903, 0.02178797997268183, 0.09344729994024549, 0.018651122759495462, 0.04367553835202541, 0.03311263104634626, 0.0037522634541216704, 0.037215477853481255, 0.023412940724353706, 0.023475830742557133, 0.0218617435145591, 0.03685778133305056, 0.016281252693650976, 0.021812469997842397, 0.021599633918542947, 0.03641928146992411, 0.09050897189549037, 0.04512630050469722, 0.06615324238581316, 0.015517395289082612, 0.021775399933436086, 0.036252158294831, 0.06290559736745698, 0.04718927087794457, 0.03286735760048032, 0.018026163169581975, 0.001710288756709945, 0.025731635679091727, 0.010484807076863945, 0.016637990783367838, 0.05149261121238981, 0.03873467704813395, 0.014326964970678091, 0.021884913789108396, 0.011628409149125218, 0.03490545287994402, 0.04832832422107458, 0.026528072942580496, 0.056714307982474566, 0.03384452945153628, 0.018630386729325567, 0.023046669217624834, 0.04268625465088657, 0.017492039062614952, 0.021575547621718476, 0.030850541179201434, 0.03423958271741867, 0.00966833097793694, 0.030854707384215932, 0.01773679512552917, 0.020152474786820154, 0.021037303110850707, 0.0154157151202006, 0.03544653705986483, 0.013304411001237375, 0.027910625362502675, 0.07917437689112765, 0.03268168667065246, 0.05900326783635786, 0.01001317858962076, 0.043879980953144174, 0.05570358257474644, 0.03759702827249255, 0.02147692934210811, 0.03165813695107188, 0.06609483409140791, 0.022983468769650375, 0.059342704979436736, 0.029833047384662286, 0.02733938199734049, 0.02298376732505858, 0.018777993540944796, 0.028307819406368902, 0.030628812898482596, 0.1074409583317382, 0.039221403787710836, 0.013530898356943257, 0.029362788689987998, 0.034740670650665245, 0.015103919797443917, 0.028945764460201775, 0.013779236236587167, 0.03273348942665117, 0.009939081717415579, 0.013346006046049297, 0.043986527914447446, 0.11946371676666395, 0.0586648281397564, 0.0041092305494073245, 0.04162846944694008, 0.029840392526239157, 0.007075085063531462, 0.004998201753811112, 0.034070077884410105, 0.06360658510987248, 0.029127635593925203, 0.09909368160047702, 0.022904388905901994, 0.024808950190033232, 0.02142985597518938, 0.018003622236262475, 0.06512157738740955, 0.03543436074895518, 0.019255536309044276, 0.04715176824746387, 0.05274281876959971, 0.026857825694605708, 0.06166461110115051, 0.01551313917817814, 0.024391233854527985, 0.0156831715721637, 0.025843965455091426, 0.007899215461553206, 0.04916813005028026, 0.05903358478099108, 0.021773047113258923, 0.05913945659995079, 0.021339524304494262, 0.03035582129710487, 0.05709626552249704, 0.07613631098398141, 0.037243840617260764, 0.037487655212836604, 0.015905055915936828, 0.09342562074639968, 0.01571264543703624, 0.02288970710443599, 0.029902943276933262, 0.030667679384350777, 0.03904575142743332, 0.02328775101341307, 0.013179697112978568, 0.01949189550110272, 0.15211976159896168, 0.1615490506270102, 0.088051616613354, 0.11058421073747532, 0.1255194382475955, 0.09119052639497177, 0.08712546381035022, 0.14247821324637958, 0.11454307580632822, 0.17090406721191748, 0.09431537014565297, 0.12402381135949067, 0.17841752618551254, 0.07662394696048327, 0.10555173363536596, 0.17411568202078342, 0.16943066913102353, 0.11090489317263875, 0.31325652077794075, 0.09474075053419385, 0.09971262088843755, 0.22119971551001072, 0.0903616619429418, 0.22045392410031386, 0.08866634898419891, 0.2312878348997661, 0.1486735636634486, 0.1134614095624004, 0.12449076558862414, 0.11779737046786717, 0.22264123601572855, 0.20716827628867968, 0.1252258632864271, 0.10683115212512867, 0.10796957782336644, 0.12438859178551606, 0.15835002942809037, 0.08767593212957893, 0.10663131677678653, 0.13583903307361261, 0.1328381441001381, 0.12245712828423296, 0.11873250028916768, 0.10734643161829029, 0.10555859362440449, 0.16756362574441092, 0.24303989857435226, 0.11444015561469964, 0.11082036806536572, 0.04983610027868833, 0.10006947602544512, 0.07768590176211936, 0.11938225185232502, 0.15463366598955222, 0.15010888235909597, 0.1469036593501057, 0.13412486362670148, 0.14869120557393345, 0.09630305027323109, 0.22267818903284414, 0.09980338173253195, 0.10925446530537945, 0.04801585205963679, 0.12644183875194617, 0.15472152270376682, 0.142836846145136, 0.09665554243006877, 0.08619693613478116, 0.09374692064843007, 0.16274164377578668, 0.1299926396459341, 0.13116816085364136, 0.11889001540839672, 0.10134051460772753, 0.13748889097145625, 0.18929331616631576, 0.10796783398836851, 0.11919919667499405, 0.07996757075722728, 0.11444476965282645, 0.1000776184456689, 0.13983241521886416, 0.09060845191457442, 0.1313637282167162, 0.08080832992813416, 0.11658743396401405, 0.05881447225276913, 0.07475382981023618, 0.08422307098018271, 0.11779561984751906, 0.13309442677668162, 0.23377024169479096, 0.14011716922479017, 0.12247027829289436, 0.1035955986008048, 0.15936760125415667, 0.10303616004862956, 0.15504236120198453, 0.09973022208682128, 0.1802502085587808, 0.12085400787847382, 0.1459766990904297, 0.09030576422810555, 0.10660351041172232, 0.1282317191362381, 0.12809796631336212, 0.11298593293343272, 0.08910681999155454, 0.18920953066221305, 0.06295992766640016, 0.20267983499382222, 0.10394327994436026, 0.12846805288323335, 0.1705670388681548, 0.10901381607566561, 0.09591303512986217, 0.11938602450702872, 0.23276856115886144, 0.13449724364493573, 0.09003177178757531, 0.11163901378001485, 0.09626469947397709, 0.13407324068248272, 0.0977089341197695, 0.11889494157263211, 0.1394293247056859, 0.15462814271450043, 0.08668865689209529, 0.1218487944986139, 0.2031012595232044, 0.08698277468127863, 0.08280069194734097, 0.15714510051267488, 0.09588157146104745, 0.13859738649002143, 0.15945853851735592, 0.09963776490518025, 0.1309347990900278, 0.09425850212574005, 0.20654235487537725, 0.09878777087266956, 0.11553161990429674, 0.13544712481754168, 0.15761953219771385, 0.13791658516441072, 0.16055080347827502, 0.11298074892589025, 0.14994830026158265, 0.11050727843706097, 0.0608719600630658, 0.10227288279150214, 0.13242099434137344, 0.08939514309167862, 0.166151282244495, 0.1091397318190762, 0.16169371429298604, 0.13914013308073792, 0.15968135584677967, 0.15591980197599956, 0.1218269592417138, 0.12762095619525227, 0.1384209809558732, 0.1960729259465422, 0.1537360862961837, 0.09067801532468625, 0.18634072531546864, 0.0902595017105341, 0.1497316983129297, 0.08869528171739408, 0.10409618781081267, 0.18336560710200242, 0.17575238990996564, 0.15711840694504126, 0.11854552317942892, 0.09722003606813294, 0.11545601753251893], [0.02537239040248096, 0.06905822043440171, 0.06459623521992139, 0.04940043669193983, 0.06670806011451141, 0.023109779759709324, 0.05604993738234043, 0.07262668359492506, 0.02873693173751235, 0.04075091332197189, 0.025848016309152757, 0.042010498233139515, 0.028122204455680082, 0.04131793450298054, 0.030480101771120514, 0.028537130315921137, 0.03653462903041925, 0.017246217699721456, 0.007937811381582702, 0.05886703157531364, 0.029677221817629676, 0.0089940741225811, 0.019374271455620016, 0.02913755238322275, 0.029172530863434076, 0.006141431055896516, 0.045582201398376904, 0.0429700892418623, 0.03016995019944651, 0.028331286539988856, 0.01429475491334285, 0.019098903285339475, 0.02146361648504223, 0.01720564978729401, 0.01924317849001714, 0.03904848253088338, 0.01583540259993502, 0.028919708715485673, 0.05115281105307596, 0.03682414974485125, 0.015203342141051377, 0.05997716236327376, 0.02925917978531548, 0.030588775939707245, 0.019335243817684904, 0.035903048635061295, 0.030887674008096968, 0.024660356109961867, 0.004877748641385031, 0.021003985345097523, 0.028856934048235416, 0.020051557969834124, 0.03217394230887294, 0.009767326692651426, 0.020856419245579412, 0.034876136774463315, 0.057573730259069374, 0.05051925951348884, 0.02155480989521103, 0.06605691076921565, 0.014467306368585144, 0.011654181605471032, 0.01628787349909544, 0.06648064910301141, 0.022512453508430293, 0.02788299711288086, 0.06140783987939358, 0.04978584118985704, 0.031340731840048514, 0.027529197079794746, 0.08404964421476636, 0.037770010597471676, 0.0329517571787749, 0.09939476794430188, 0.027596892822267752, 0.04251691945163267, 0.040689499117434025, 0.0780367993616632, 0.06757579105240957, 0.024903717783412764, 0.01317865980256881, 0.042898188278611214, 0.04690244394753661, 0.07737809792160988, 0.06113635801843234, 0.0336249826609024, 0.06413087554808174, 0.030333198939583132, 0.038013899831899574, 0.04184539709240198, 0.06619069751884256, 0.027527933308322514, 0.020450326214943613, 0.030497139785438776, 0.028167461045086384, 0.03380889279235687, 0.017659689798685055, 0.019523243818964277, 0.027967143936880996, 0.006559538397206259, 0.036881136508392434, 0.06455227972141334, 0.028507871885917017, 0.012357456010899373, 0.07654101641050406, 0.016010713996365666, 0.009788545330853334, 0.016353565866925886, 0.01995000332993056, 0.026857338845729828, 0.0464932907239667, 0.04158427646117551, 0.0029000663032223073, 0.007429515710100532, 0.05083973838814667, 0.0204242518105145, 0.026959471936736788, 0.03342059434258512, 0.02736101030105991, 0.026130446332639883, 0.01834436895192734, 0.03327155751841409, 0.08145054975258452, 0.026627615726153766, 0.016079071310481856, 0.06688929003264223, 0.07725488274757351, 0.014132923463226428, 0.028132273915356824, 0.011751559862334813, 0.04265350855088659, 0.026060696325397918, 0.03227551221581442, 0.026688174976568137, 0.010321916263949658, 0.06121345316725118, 0.037935352618140836, 0.018957466053377305, 0.09371097864849226, 0.02609926595219544, 0.04146629957748311, 0.0316902045160532, 0.07359494628118617, 0.05651030982179301, 0.02793314085075898, 0.049745003559759686, 0.03436507098376751, 0.030482727701642683, 0.050602034000413756, 0.05870638840964862, 0.03788999255214419, 0.024712896772793362, 0.07913115421043974, 0.028747808653861284, 0.04257483580814941, 0.029765278699674776, 0.012716139799782207, 0.018966276830594455, 0.03982036700472236, 0.07054180332592555, 0.022849485244868056, 0.01813283565986369, 0.03718581230246595, 0.015741868243951882, 0.021876915557576076, 0.010494215813066279, 0.09192798539463963, 0.014053014938586524, 0.023091854560854178, 0.044792125400687964, 0.0324607692392809, 0.06463571238730635, 0.009856632079130836, 0.005724367810346718, 0.06337219197303057, 0.02475806345630969, 0.020686405511306863, 0.015044152736663818, 0.06782280494059835, 0.04635107996208327, 0.031206215665276562, 0.032406174311680455, 0.02930578835574644, 0.021242422550650578, 0.06577318135116782, 0.03528814323778663, 0.004588967530123357, 0.08690357607390199, 0.01921622877541397, 0.0707501203620008, 0.019319837680086493, 0.0415324703125017, 0.05261056550911494, 0.026675348968378136, 0.04911812201940587, 0.03284583446968879, 0.02133623171331627, 0.03846837240936501, 0.039594248602432866, 0.007975365750358572, 0.016651965212076902, 0.017448711208999157, 0.01689210893320186, 0.042930106565888436, 0.017743906172524606, 0.033742735628038645, 0.03923442826739379, 0.011036829241285366, 0.029169314607445682, 0.05886720799441848, 0.09475821602557387, 0.03069271393386381, 0.02803185412527195, 0.012355708783226354, 0.02776626025193504, 0.031250042242131064, 0.04815589150946055, 0.05035781567650182, 0.016357095945360403, 0.03915584034153393, 0.006226078299472907, 0.041604113432445695, 0.04636551579460502, 0.0142601903394929, 0.04263130688507642, 0.07894882506557874, 0.019289047457277775, 0.019135788448953202, 0.0186576553553875, 0.005256366940946984, 0.03968741485316839, 0.04468958179599472, 0.011781827613179172, 0.034944960581404824, 0.029005044672105993, 0.05634367519191333, 0.08486942308289663, 0.06303030531853437, 0.08166464112166848, 0.025612885265478065, 0.05836334824562073, 0.049933612546218295, 0.06911168899387121, 0.015709768448557173, 0.048351044966174025, 0.024771824146487882, 0.05550323832514031, 0.03014939058838146, 0.038435046161924086, 0.06725935624646288, 0.013434118059064661, 0.06943109578319959, 0.04188717110082507, 0.0336738812870213, 0.05167778341897896, 0.04600689985922404, 0.024040298935558115, 0.06647726999861853, 0.007239004281083388, 0.06538976835353033, 0.0784026315169675, 0.006779490188429398, 0.02302580256946385, 0.07743060296135289, 0.06357707562191145, 0.07883292449904339, 0.03260578913614154, 0.052845124887036424, 0.025056282989680767, 0.028120981396308968, 0.01297896694658058, 0.013963003875687718, 0.027066485390865376, 0.0211575937989567, 0.04658378693940384, 0.004552721461680318, 0.019329228604744588, 0.031372541561722755, 0.03151897620409727, 0.030701205799622194, 0.02153557851644499, 0.011785437419478382, 0.023450819941769754, 0.044512450229376554, 0.0426543092222086, 0.01663786355805184, 0.06391398861472096, 0.014658242730157716, 0.04507755454895752, 0.03597122444106, 0.02137034336504127, 0.045091786820973666, 0.034138847408550124, 0.011423004724617516, 0.04575770787362542, 0.026685628773910657, 0.05486158507743052, 0.10856295669717447, 0.0791120534496648, 0.025281906061406647, 0.04182812159082719, 0.03305828378402761, 0.059023121771003516, 0.018677833290504556, 0.03051396066855107, 0.04111738330019372, 0.03479237841176135, 0.03384446159803441, 0.031564668752253056, 0.03777769500655787, 0.00837476333669786, 0.03122485502223883, 0.04324363384928022, 0.04212245311854141, 0.056853848709059615, 0.010834362025239637, 0.06674543382333857, 0.027432327724194953, 0.023742393224633167, 0.0909284083172679, 0.056989681241767745, 0.07093523150043828, 0.023925860611987964, 0.026983851699956825, 0.009520940449354904, 0.014758106121527297, 0.04835988627746701, 0.006665953044180891, 0.008283698000013828, 0.04071659302072866, 0.05545347795954772, 0.02314713311248592, 0.02875223270218287, 0.012915373796464076, 0.06314474703477961, 0.057176346225397925, 0.05753426666238478, 0.04752394809786763, 0.07388071130428996, 0.03858834418601223, 0.014095158748594778, 0.03764572673078094, 0.03822332966540541, 0.04060403763183525, 0.034263779276183674, 0.06311161416981902, 0.03947355079331568, 0.04967051059273737, 0.01947302544223411, 0.019319040401439582, 0.011191534377368433, 0.02703847037628293, 0.09832045023462602, 0.1151025007878031, 0.19234200114650385, 0.13960735872387886, 0.12129006162285805, 0.12495051377585956, 0.202695509152753, 0.16251809362854275, 0.10121930111199617, 0.14388647196548326, 0.14585870185068675, 0.12016140004353863, 0.10248936260385172, 0.09704705035047871, 0.144751386983054, 0.110208953730762, 0.21532001958361693, 0.08570317298706089, 0.09097288628774029, 0.1913988103291818, 0.13547550115202153, 0.08581743828420128, 0.10900846921971866, 0.07452075303133045, 0.11860299509550844, 0.13361536525189877, 0.12934073034141744, 0.10408668153520141, 0.11232919924493347, 0.10112323412405592, 0.10123049693980388, 0.059811436970319064, 0.1611010953783989, 0.10097519135368721, 0.08906732925346919, 0.11620685724275452, 0.10816762862460953, 0.12399211020341941, 0.10440030042082071, 0.1230962947010994, 0.17129954456218652, 0.14040925140891755, 0.17514187124158653, 0.1934552871223007, 0.08117884397506714, 0.1746124510786363, 0.1451329815068415, 0.12236931228211947, 0.1721138951501676, 0.15198668731110437, 0.10420332170490708, 0.09582521912774869, 0.07632166639502559, 0.11636210605502129, 0.0925057376069682, 0.07122801257563488, 0.13742091533328804, 0.1438380924186536, 0.07004836587501423, 0.15070254621761187, 0.13700122785355362, 0.17913148073213442, 0.08579811360687017, 0.14146231061645917, 0.12970556505024433, 0.06504775956273079, 0.1087698352390102, 0.12518918168331894, 0.08897353535784142, 0.07760042670582022, 0.12424953281879425, 0.12938218883105687, 0.1230199323701007, 0.22454192116856575, 0.10192685707339219, 0.1313622761517763, 0.19817011484077998, 0.1157092603721789, 0.14669758826494217, 0.13689226870025906, 0.11482495282377515, 0.11604167467781476, 0.17410209774971008, 0.20584397949278355, 0.21968675883752958, 0.1645742447248527, 0.07587332438145365, 0.15105215460062027, 0.12655130002115453, 0.23434327808873995, 0.24418035309229577, 0.14523693307169847, 0.12361187274966921, 0.1528125051409006, 0.11028563497321946, 0.12209640549761908, 0.08135232502328497, 0.08654853941074439, 0.19291179414306367, 0.11249275332582848, 0.1060611234445657, 0.1251268107444048, 0.13942802191845008, 0.13052351187382424, 0.08030624794108526, 0.09345939143427781, 0.08851859119853803, 0.1680247038602829, 0.11264912172087602, 0.08945813149745975, 0.13119200457419666, 0.10700714375291552, 0.1323372766907726, 0.053827758944992504, 0.19978320971131325, 0.1886324637702533, 0.09182425096098866, 0.0848240562315498, 0.10425265120076281, 0.11440210337085382, 0.17770643505666936, 0.22261085121759347, 0.2027278481317418, 0.08107354891087327, 0.09162550805402653, 0.1971044484525919, 0.38469295895525385, 0.11579651997557708, 0.125847618494715, 0.20206075321350778, 0.11325759799884898, 0.09550541200275932, 0.10112600254693202, 0.08654157764145307, 0.09997755488646881, 0.18307131289371423, 0.1094075088788356, 0.1124439463019371, 0.1397276629826852, 0.09844695630350284, 0.20142966136336327, 0.08559686012033906, 0.09665972220578364, 0.1913529820740223, 0.14900615438818932, 0.11102235436971698, 0.17989766890449183, 0.15930544744644845, 0.09521593539310352, 0.1054627980504717, 0.11277893225529365, 0.12149096227117948, 0.1575165441525834, 0.17041252287370817, 0.15072055453700678, 0.09995663565184389, 0.11397871108991758, 0.13012625676180634, 0.1348302007785865, 0.18164021468588284, 0.14211673050054482, 0.0959810989775828, 0.150948773005179, 0.0796758821234107, 0.09814427540238414, 0.15543543653828756, 0.15066077560186386, 0.08946292195469141, 0.1034634674766234, 0.13067656223263058, 0.11614284424909524, 0.15258264461798327, 0.07261209509202413, 0.0833465326577425, 0.1018753426947764, 0.10322929825633764], [0.05955712204532964, 0.007004795620949673, 0.06185481803757804, 0.01061395603963839, 0.04645544204062649, 0.023718887075249637, 0.028977832025183097, 0.03946686043803181, 0.020576286063130413, 0.03141046827659011, 0.053486798490796766, 0.02427224934633289, 0.05561726952769926, 0.022091364853882363, 0.032180727659059424, 0.029511326790920327, 0.01906097148145948, 0.023807573298524533, 0.07103312374757868, 0.008596875837871006, 0.04701378136607153, 0.09580761792936496, 0.038583472304578335, 0.01856257054688675, 0.027102463013891662, 0.04115408865202751, 0.02054015576972493, 0.05774100271186658, 0.07616424627069916, 0.03231022606736847, 0.05635395499744585, 0.019152037666312287, 0.04293905305010932, 0.04086739064327308, 0.01820256870373019, 0.02582907161143209, 0.005121791818445283, 0.04645026142575911, 0.043857423056449206, 0.02533894371507423, 0.007178039605995374, 0.014328064197408301, 0.08261423730956656, 0.02692939417569765, 0.04981107251452548, 0.004972283412436289, 0.02420267236552068, 0.06949485771890197, 0.03566417038174612, 0.00925891991105995, 0.012435248354449868, 0.04776537764285292, 0.04271798294835857, 0.02429157741633909, 0.052328410292310376, 0.022078859453488673, 0.006336338967750115, 0.03151124769023486, 0.03237339089225445, 0.004543943763045328, 0.05504852147506816, 0.03637273057496973, 0.08275454478072268, 0.035034215077757835, 0.038336309138685465, 0.025578712545601383, 0.046294347649174075, 0.053997592867485115, 0.09845602153135197, 0.021331524376624396, 0.05898914752261979, 0.014643739044134105, 0.03687746563394155, 0.07357832217322928, 0.014971513866579958, 0.051041643268295696, 0.018552918386246477, 0.024837640346959233, 0.024533627820866447, 0.05529477879671114, 0.04122847983879702, 0.04006259043567947, 0.04665828329910125, 0.049092534463852644, 0.035611322681818686, 0.023414984811097383, 0.029621944962335483, 0.026820597870807563, 0.015017345514414566, 0.03717834163191063, 0.054533506610563824, 0.03092307996537004, 0.04319652994828565, 0.02951538103765675, 0.016616153830130185, 0.018855792669845477, 0.08304850650685174, 0.007194975840060839, 0.030870395113847086, 0.022887244022318294, 0.01785937078031046, 0.0296897102546479, 0.013803772911030267, 0.04532390008015292, 0.03403279577781047, 0.02613583898970059, 0.028831071685999632, 0.04326679564214178, 0.040839665702411106, 0.017230248378057565, 0.05105618088107024, 0.035435568541288376, 0.016547163782109107, 0.01891746641402798, 0.03807736321219376, 0.021362606369491135, 0.041841488730694563, 0.022099955107218454, 0.06372684187122754, 0.040284837795687575, 0.08569314423948526, 0.022800456000758067, 0.08290760192487921, 0.033160986844450235, 0.011310152476653457, 0.005094534642661789, 0.09021384308912925, 0.04226487422628062, 0.03076673871172326, 0.06709266054843153, 0.05242021268765841, 0.05803425197622605, 0.10487716126122645, 0.025997867375346165, 0.027280743001028895, 0.012780092573458595, 0.0393981384113431, 0.051845490134188106, 0.04804625382114734, 0.04184858620698963, 0.014558077390704836, 0.09268875207219805, 0.00869304545423282, 0.05331142093720181, 0.021694172506353686, 0.031242310335593562, 0.028728239703923464, 0.0020030828725014415, 0.029902112071535418, 0.074606424862785, 0.03878549932103072, 0.014148215946209217, 0.014293508105246084, 0.07276675357882466, 0.0037122485477344264, 0.050176880921104124, 0.017479170645986284, 0.01122291577381215, 0.030402864129947763, 0.05568559800407716, 0.01282410744378077, 0.0640672357486827, 0.03625254166711654, 0.04255427619708436, 0.016108553657042127, 0.09982559018369232, 0.025117909236411964, 0.008636217298252242, 0.004301026954116034, 0.023908220397840654, 0.11665394396654197, 0.04153164928512914, 0.009661007888748177, 0.04623981039705021, 0.01078385187845145, 0.06876286092613425, 0.006747154178031321, 0.039406212978065014, 0.004355778368855161, 0.08384484199008771, 0.0273221064957657, 0.012690323238660182, 0.05408731894567609, 0.05735478736460209, 0.04472151704664741, 0.05016491495605026, 0.016092402827260748, 0.01715045265986451, 0.06265943164804152, 0.002286336891951838, 0.028601333299385648, 0.03897664263578398, 0.04736542874681098, 0.08646913724286215, 0.03393047269699829, 0.04063792706334165, 0.024884408373119574, 0.051070996693202426, 0.01463778320300792, 0.042239595404160876, 0.021823433427406207, 0.06383548889841352, 0.008627037567618703, 0.02182862930931151, 0.07616533871207919, 0.04090272874704429, 0.034436622501483986, 0.031810128795249124, 0.03265111188271216, 0.031160672394824878, 0.03190979541146329, 0.047180005482264926, 0.012666712764517536, 0.004519052554054984, 0.044509155941861014, 0.024630997596042495, 0.005882011851229305, 0.03641363945124405, 0.0695903275960258, 0.033242495863565376, 0.04215893455381904, 0.043213571355279, 0.014875752219398106, 0.03225677107859935, 0.016598842705466917, 0.011397079597892506, 0.019861054174335938, 0.06183968670666218, 0.026659920778391615, 0.03280363976955414, 0.012013002797695143, 0.026401958727676953, 0.03829069462205682, 0.016730827944619314, 0.06442585507673876, 0.05615106624151979, 0.03218022554314562, 0.047415345175457854, 0.09327043300228459, 0.03183084446936846, 0.01578241240765367, 0.009605575818568468, 0.021154874569869468, 0.01593971548468939, 0.07786431575992278, 0.04113140861902918, 0.05077001212963036, 0.010833155081075217, 0.016793785816324607, 0.06845657021871634, 0.05848882972661938, 0.052800158371350596, 0.03099763739321913, 0.02376030824546303, 0.023621398556445326, 0.026077998968373452, 0.007491609297825822, 0.04181317685704146, 0.03208974289840885, 0.015090503463787692, 0.054724995978176594, 0.047587550577840636, 0.011013228945168001, 0.07880512491932937, 0.058884347788989544, 0.0371376431014921, 0.022592210210859776, 0.029705547261983156, 0.03496096722249474, 0.025954312212499123, 0.020651318465492556, 0.026222467555531433, 0.01861934017922197, 0.04532239373241152, 0.020775792321988514, 0.025346270196938088, 0.0080777032500399, 0.011714857055007346, 0.012422999101025718, 0.03818486351519823, 0.017768450480486666, 0.03491391081895147, 0.005010417928653104, 0.025757788115047982, 0.024596020812168717, 0.021908111205058436, 0.03355194175881999, 0.023140342673286796, 0.03136310313961335, 0.0027843082290408866, 0.05858913755842617, 0.022957185715703026, 0.05349670510206904, 0.06938412758920874, 0.03947557622034635, 0.028080606866361837, 0.05410219243328486, 0.04523082882432001, 0.022091666801965663, 0.03196485174287643, 0.025029757359464253, 0.02742678578943014, 0.055955729580351284, 0.059063155337103775, 0.008067038375884295, 0.04343933352668371, 0.10285182922546353, 0.03610789496451616, 0.03875675657764077, 0.042936243915132115, 0.01974886349801506, 0.010635954144942974, 0.042155613124902756, 0.056422130803444555, 0.032505915566746674, 0.03028090763837099, 0.06219938490539789, 0.026177290693989823, 0.043102552848202844, 0.06750541340027537, 0.04388161961521421, 0.015564480530364173, 0.011744948386746858, 0.05482258966990879, 0.03885640623047948, 0.04720378813466855, 0.04259003159989204, 0.019107362920684472, 0.017875026279528226, 0.02663991247702922, 0.0017164672421391255, 0.02265912394172379, 0.01258683986296611, 0.08517506239669663, 0.025063965702429414, 0.0633634931540915, 0.018878316639789512, 0.06211576224969966, 0.0853221280766385, 0.07161082846245595, 0.039478931576013565, 0.03741831911195602, 0.00634406620935936, 0.007621144177392125, 0.014060948709292071, 0.032171299414975305, 0.07942280213215522, 0.06127743901950972, 0.04797891939857176, 0.046004284106727154, 0.03043837526014873, 0.055353126022964716, 0.22883503937295505, 0.10275040859622614, 0.10536272770592145, 0.14553609916142055, 0.09468825227980103, 0.10944157133677176, 0.13088850943105562, 0.10622278441275869, 0.07005753966846637, 0.08084101495998246, 0.08846481051295996, 0.11569545896989958, 0.17669697850942612, 0.08581398454095636, 0.13256511517933436, 0.1506711029048477, 0.11849822928862912, 0.14733336200671537, 0.144876807395901, 0.09592625299202544, 0.09586259962192603, 0.16104267351329327, 0.13383780260171207, 0.07973097238157477, 0.09052650524037224, 0.1756068848605667, 0.14306369397257054, 0.09553104705576386, 0.16361050786716597, 0.12756659196955816, 0.1371235812881163, 0.182984161855919, 0.09873972380799906, 0.13046583639723913, 0.07546856467212949, 0.15377879329025745, 0.13178068798567566, 0.13429704867303371, 0.16257609480193683, 0.11439624082829271, 0.07331021263131074, 0.12196569251162664, 0.17171902848141535, 0.14668495394289494, 0.10456611402332783, 0.11767226218112878, 0.12539224007299968, 0.11825014331511088, 0.1401381359568664, 0.0838866668886372, 0.06035531671451671, 0.18420669196971826, 0.13833575695753098, 0.06076745209949357, 0.1444470640271902, 0.07609311544469424, 0.14175254718533584, 0.0976407074236444, 0.15638222359120846, 0.10847873014530965, 0.14630766133112566, 0.15357437783053943, 0.23964844484414372, 0.10464734823576041, 0.17561278811522893, 0.0886821656354836, 0.11749113404325076, 0.11585418188146182, 0.1616287242088999, 0.09826573995607239, 0.11452624813786574, 0.07212686791483845, 0.0849693984325443, 0.2087345386722258, 0.1929387862661055, 0.18572213208036764, 0.12007297335990838, 0.13391423278621264, 0.13241708597966603, 0.1925262234040669, 0.1844658244933401, 0.26466505389128414, 0.13843316744480813, 0.12475348077714443, 0.1243658744330917, 0.1057948934446488, 0.08538625642125096, 0.15225436937596115, 0.10913082265428134, 0.1266281780387674, 0.07338675138141428, 0.08317055460065603, 0.11005063115486077, 0.13902465999126434, 0.1313309142632144, 0.07964244391769171, 0.20916255856198923, 0.10712691875440733, 0.15575645145561012, 0.07888497492032391, 0.11212163538272892, 0.10977056582591363, 0.08230522567672388, 0.12455498214278903, 0.10652311758271285, 0.09987298585474491, 0.10530547970639807, 0.13601261590208324, 0.20610301702150277, 0.11281286579157625, 0.12399262589003358, 0.15312559476920537, 0.0842550096235105, 0.10730484420699732, 0.14707433804869652, 0.09783040545880795, 0.14544015430978366, 0.10702990181744099, 0.16674324976546423, 0.12514282417084488, 0.20099223697824137, 0.07557776809803077, 0.19408741034567356, 0.1339365430176258, 0.0748268673196435, 0.16970554366707802, 0.24829173247729028, 0.19715483646307672, 0.06051182081656797, 0.1395021179424865, 0.18151539138385228, 0.132980880726661, 0.21488494292965957, 0.165895637390869, 0.12341717391141824, 0.09240078181028366, 0.14460341206618718, 0.13464980545852864, 0.1834944744727441, 0.12023618817329407, 0.10793331691196986, 0.2080350233508008, 0.13529841708285467, 0.156261661489095, 0.12164380906948022, 0.089359608212752, 0.12978954054415226, 0.08517992070743016, 0.06377982867083379, 0.15876673135374272, 0.10644129304481403, 0.1384422326726573, 0.17903607870851243, 0.1666668602930648, 0.10042486552681242, 0.0768139028389539, 0.09163262588637215, 0.14234186841973237, 0.17141792178153992, 0.1087040648396526, 0.06696976428585392, 0.18541666918567248, 0.1498197043048484, 0.16199775226414204, 0.07744667745594468, 0.1836139644895281, 0.1461146181183202, 0.11647687346807548, 0.06315717779632125, 0.10597463058573858, 0.22634937560984067, 0.1249376894640071, 0.10520662393953119, 0.12674803446446145, 0.11547245165067059, 0.15138048412544386], [0.013429221580736339, 0.01844664623162576, 0.018814985573823963, 0.05704483256808349, 0.02004899480380118, 0.04343248710834554, 0.0816347109419959, 0.020251893737752522, 0.03916530251236899, 0.0320235009172133, 0.04935399436258844, 0.054385290813765357, 0.036841347214898894, 0.03571362201390522, 0.030132118479481766, 0.014838537966300334, 0.0056504969751196244, 0.027747444475867918, 0.07584172500563519, 0.03320567516077842, 0.040507980821920295, 0.03621866241363542, 0.027179276570677757, 0.03378125945372241, 0.024708586379087398, 0.10102983377873898, 0.05430674360000661, 0.04654229452301349, 0.03214245828400765, 0.031741393197860034, 0.03649926717792239, 0.03552791037197624, 0.030758104353610958, 0.030894768091716936, 0.08194263013345854, 0.027998254767486026, 0.04272013051169259, 0.042109669518790076, 0.04284482149939452, 0.03357903226943953, 0.0693693830232535, 0.05671008749465857, 0.05847163564924683, 0.02679960399733058, 0.04586126928084663, 0.010573510263514305, 0.025912702748818055, 0.027279491103919487, 0.06723784668637173, 0.01884396919714553, 0.0293482782186142, 0.04466872362952147, 0.0668493446760944, 0.029554335733077357, 0.03606542885037405, 0.022788795376462594, 0.06271774494754416, 0.035088840539434125, 0.08288487778710467, 0.03988817300913589, 0.06453820011977639, 0.05733871965536049, 0.010306868053573583, 0.03383189852216414, 0.04263654178274529, 0.06453260220587254, 0.03483870878283467, 0.04088814024414335, 0.061259505338966846, 0.04785391967743635, 0.02936070558748075, 0.061769600824585984, 0.05498714798263141, 0.07354400187198605, 0.03430324965821845, 0.03406560294596212, 0.07255611595298563, 0.03549041113417063, 0.019362503962059106, 0.049702289780335765, 0.03371425751330597, 0.046336382893579345, 0.08918759280017444, 0.008244091062806547, 0.07958951818623713, 0.021402203976841908, 0.025145227056262747, 0.025453315881480063, 0.002890849677247128, 0.00842837693302759, 0.04245032802490251, 0.08255164923944644, 0.03032311930188111, 0.082255271928651, 0.07005839462258986, 0.08104646179292883, 0.031557259149849415, 0.06866153529179947, 0.03587532030152423, 0.045849503483623266, 0.03285125596448779, 0.006548156396352819, 0.016567411267065575, 0.04461724317765661, 0.052691070296402485, 0.041721296430166276, 0.02264399261080793, 0.05247184580990246, 0.03858701086470059, 0.07623190299740859, 0.027442878943734934, 0.07833873387426138, 0.0792942401021719, 0.07928290178201028, 0.016622684729684676, 0.02112073577674372, 0.0169500473421067, 0.052590911742299795, 0.04740036651492119, 0.018242614144193273, 0.018777754357350723, 0.052161836730582375, 0.011125113432561713, 0.06641052929418427, 0.02541489553238664, 0.01388512586709112, 0.020445047212498527, 0.0763645905203053, 0.02176532708108425, 0.042187843538288555, 0.013630301192668932, 0.013747703017933028, 0.016123513657865778, 0.029160357945199524, 0.01825036640678133, 0.060642113110848835, 0.026338590342285376, 0.03220535848023636, 0.04877640839133944, 0.010862246421830994, 0.07071992555367095, 0.028755272539066415, 0.009100293690737869, 0.03118742024526, 0.031560943595000675, 0.06209881244493382, 0.04342551855370402, 0.03925507948068636, 0.004896267558381493, 0.02836712675967387, 0.05415909777262381, 0.03647148795425892, 0.011264715227298439, 0.037968722970357964, 0.0850209060258099, 0.04161881050094962, 0.056468936149030924, 0.043635494607899866, 0.037961350687380345, 0.02020127502536135, 0.0422654374103461, 0.04934902748625193, 0.1183325717491763, 0.011860113590955734, 0.08006645366549492, 0.03190724411979318, 0.029639603836195808, 0.05444263041551624, 0.0108675279687824, 0.032741262045289786, 0.016730746520417075, 0.010848346631973982, 0.07442140193389994, 0.05684424404587064, 0.01911123057029077, 0.01949726271310023, 0.01838751869010074, 0.034420066247028966, 0.009767443739942141, 0.01233998458233795, 0.02660320033984525, 0.019330840125413876, 0.06367122914109911, 0.010713274058486735, 0.047409635303275924, 0.01954825801242675, 0.013181719147334141, 0.05969546176493168, 0.039872634557208846, 0.020018989985276545, 0.0717707998784525, 0.09151555823960475, 0.03978166336725865, 0.04757614101150206, 0.016982922363760214, 0.02824170804316444, 0.009318524123435574, 0.02113814528898469, 0.0747520113363862, 0.01889679823735995, 0.017366162334967936, 0.03737944244806256, 0.022666399533461248, 0.017163142961050783, 0.015017756028100848, 0.06675388836967093, 0.04863286091546927, 0.06737362154360328, 0.006172520258197827, 0.02574067037286503, 0.024620665204046027, 0.016240628802084496, 0.018052851648202965, 0.016497432254254818, 0.037547071131744554, 0.031187372747808695, 0.025968227269394056, 0.016226427064144185, 0.008963213501764196, 0.022723788329000984, 0.0031180045417776065, 0.008795605174132755, 0.062067498053823195, 0.05781381630471774, 0.04975128000868218, 0.0908047588808196, 0.019361011185018078, 0.01332380692474544, 0.008795522901761745, 0.053771844266780784, 0.03173472659130182, 0.02962782446827207, 0.035442567630005736, 0.004872638000441449, 0.007622718378635389, 0.010920479993468948, 0.033934876389269314, 0.01473428275702255, 0.02751988757933889, 0.03304676225941096, 0.03504211661805, 0.02491550563302423, 0.03564573797796454, 0.05060911451333335, 0.037861975841224194, 0.03892505022564104, 0.07638368449573006, 0.10244562423654965, 0.02123680936970881, 0.05954720864870718, 0.031436615623533726, 0.03685250233060547, 0.03082554055643933, 0.04043607307331903, 0.014445852787633027, 0.010183568910828658, 0.043783825755651505, 0.017853353871032596, 0.03471884557179042, 0.03955824553434338, 0.016387267004964606, 0.026145815150812268, 0.010170156818016298, 0.02845793679755713, 0.003691684695825513, 0.014037973513560635, 0.022472765995189548, 0.06509680407387869, 0.04609889902972749, 0.04578590439632535, 0.06640608488981213, 0.027787583214896064, 0.02503552151444767, 0.03177186620554753, 0.03819046142910208, 0.00638722485330488, 0.019611982628703117, 0.0173031518767987, 0.029577480562563454, 0.0744826193632824, 0.039838395680167844, 0.04379755251907876, 0.00977695086372218, 0.026088146459577338, 0.03060132883755224, 0.061036823716546805, 0.009492670984140463, 0.049931101966649294, 0.054933384260428805, 0.053523558125432046, 0.0446012874266931, 0.04465366015210748, 0.023261328859786903, 0.01787520100229553, 0.017431457759812474, 0.039339071937969754, 0.036366603403751335, 0.007754433051949101, 0.04966973367014101, 0.0346631310614092, 0.03610784746706486, 0.0021163865582950947, 0.024504084406154494, 0.0407757103842284, 0.033663207931177955, 0.05096085010362523, 0.02438377675467304, 0.006418233479572726, 0.027145823097920845, 0.03360444001321282, 0.03715421971199768, 0.05044140779812421, 0.01857532361256225, 0.030321921687573195, 0.07542037511510508, 0.03421176617432918, 0.06503193612609591, 0.013010796176136603, 0.057200610637664795, 0.04820680199190974, 0.01893365117056029, 0.01315783047383385, 0.022519891948572228, 0.026272589241021445, 0.030844261337603842, 0.012477364174888601, 0.035664289125374386, 0.04124442880441036, 0.029417241125234535, 0.011954566513720368, 0.053511646443179677, 0.02956217959789293, 0.011084717698395252, 0.013063916986409043, 0.05563565104135445, 0.02063566635894988, 0.015109753502266747, 0.026592092721589973, 0.024612388773156062, 0.06916283696357693, 0.014259148788239275, 0.08100531542939798, 0.026115574541368654, 0.02947966634695019, 0.009632889397575386, 0.030311658845416138, 0.009197370847687125, 0.028906212653964758, 0.022731557554964508, 0.04401893474693809, 0.014306211977132728, 0.0157984631535198, 0.05823849101683923, 0.08425657025405339, 0.12312397892986025, 0.11740474296467644, 0.09053542797586747, 0.1227913067809173, 0.2679579571953842, 0.05577074057821717, 0.10716603629823242, 0.11469889458801065, 0.11007804396961417, 0.1968468494181122, 0.09159551680620227, 0.18822260147758893, 0.14570478296705655, 0.14858251783464635, 0.29536455656800953, 0.14587652018027647, 0.26030782769833294, 0.14988664856978826, 0.22202017291315965, 0.13631626032292843, 0.10493800549634866, 0.1285943282502038, 0.10504036928926196, 0.12605936213263444, 0.10898776711629969, 0.0900791199611766, 0.07900275502886091, 0.12148048569049154, 0.12597953927304062, 0.17670646442898683, 0.1352878183658634, 0.09263904938208205, 0.18831788136490754, 0.10079053483371224, 0.18045884450631483, 0.09131494257599115, 0.12927151976951531, 0.15289132376866682, 0.17848799883254937, 0.2071096780044692, 0.08598749951592513, 0.08934284839779139, 0.09251721841948372, 0.09505373838224582, 0.12604005102600369, 0.1619792011167322, 0.15168817261500017, 0.11512352180268083, 0.10452931706926652, 0.11155909592551844, 0.13176950572856835, 0.12020532840064593, 0.08882133995315858, 0.1302551105618477, 0.12089857405849866, 0.2581427853022303, 0.13838575141770498, 0.09014858837638583, 0.1235331084047045, 0.09813170214848858, 0.09181477182677814, 0.15210400601582869, 0.10807443183979817, 0.09225972795060702, 0.09998897463083267, 0.18476896679827146, 0.1358984320291451, 0.12677546084991523, 0.12194435937064034, 0.14796532238168375, 0.14284220657178334, 0.13937600542392048, 0.16055828093418054, 0.11037694543067898, 0.15784395086978162, 0.13931442158562796, 0.09296035606946264, 0.0771573908360941, 0.11471329310110637, 0.0895079563238791, 0.2034626608448369, 0.14549105800688267, 0.33441837238413946, 0.11667264439165592, 0.09573357618813004, 0.12549879721232823, 0.12445713739309992, 0.04962654152352895, 0.17980720661580563, 0.2348351888358593, 0.06276318643774305, 0.19958845659026078, 0.17507324420980044, 0.17434630250292166, 0.0771051300689578, 0.15595754209373677, 0.13024950586259365, 0.11114259077502148, 0.08665063178965024, 0.1415387408009597, 0.1074402051578675, 0.1675518870885883, 0.10251789500138589, 0.12612866769943917, 0.14438219607940742, 0.09711952467582055, 0.06292144116014242, 0.19715277371662004, 0.09892384428530931, 0.24886482315404074, 0.16015729387956007, 0.1600491353975875, 0.13920657522976398, 0.11715398356318474, 0.09259852048541818, 0.11030537355691195, 0.14136085606047086, 0.12777036960635865, 0.18002105371228286, 0.13798827917448112, 0.12938205312405313, 0.1426407088126455, 0.11555786563881806, 0.08687832778585808, 0.11087724965597902, 0.17485820289169038, 0.11117902810552291, 0.11838130413421563, 0.08823112305253744, 0.11751625340964113, 0.1673287304916552, 0.08096533614609923, 0.114755850817476, 0.1621612792036363, 0.16904087790421077, 0.11910672592265265, 0.12605820862310274, 0.1432806080473321, 0.24814877871956142, 0.05434911132657102, 0.1080531869083643, 0.1419437854949917, 0.12425645387598447, 0.12999782365347656, 0.08202942154769387, 0.08675923131938491, 0.1569269515041794, 0.09433728004140512, 0.10056595331323998, 0.11077035324914114, 0.08086211061371223, 0.13353470100888185, 0.24405696828450474, 0.112511474106993, 0.15416164988917963, 0.14025502039917878, 0.17729281368000166, 0.09440485534391233, 0.09905349197132246, 0.16850902858589376, 0.1419752152370555, 0.16952860887561524, 0.168573258710759, 0.14576005642967566, 0.08479868580720254, 0.11168644337781838, 0.15674111433327198, 0.08448621364576475, 0.12781721566404614, 0.08656159442450319, 0.2018896131111043, 0.12115554884076118, 0.05993494391441345, 0.1109800273552537], [0.10370667478335754, 0.044057010739509544, 0.030994064906345944, 0.03207492708627667, 0.0266444162532155, 0.005535421252716333, 0.033698715668703826, 0.0509851620133434, 0.04683072279606547, 0.06414979988975184, 0.03237273610596146, 0.02363929831023727, 0.06464074033179454, 0.03279427598629679, 0.024286198329978755, 0.07408544567546674, 0.025712424656376243, 0.009255862262632166, 0.04275415565020271, 0.013264832053599613, 0.03664795794923391, 0.02123636662560914, 0.030634427775761912, 0.011308478191494942, 0.006996164655512465, 0.05185780893745167, 0.04988599635128464, 0.03371595724352768, 0.04899142596072384, 0.0023059448576532304, 0.012795969444726194, 0.06492926699242421, 0.055907689301030974, 0.024302347463422587, 0.005698778982540327, 0.04240426228248647, 0.043672949740929265, 0.0500905950154577, 0.04421110264956951, 0.05389609759939568, 0.009526875086261757, 0.10656874227736678, 0.05125698992716415, 0.06343376224062272, 0.027572021121159196, 0.02182256829525743, 0.030867236533335278, 0.015426047512197068, 0.05002902474786554, 0.03972995560616255, 0.024686752818524837, 0.011483044047573847, 0.11013306637427636, 0.02137368175733302, 0.05608503121350493, 0.045492278545030525, 0.012933473718086523, 0.0338705241281007, 0.017888237356341312, 0.01950263331777283, 0.0281487266932215, 0.005683089980656015, 0.028258698560031395, 0.012350244879988688, 0.06922988979411976, 0.02525334821880928, 0.09958025227699961, 0.04335535464010068, 0.01748141150788537, 0.07251980754413775, 0.04468029604426452, 0.05123219286490764, 0.02696055080741644, 0.03642536453636629, 0.014779479974614722, 0.026177399259592806, 0.046233418597174544, 0.027291078785700456, 0.018926070238064443, 0.030849034831460034, 0.03226607379370502, 0.020253434012244855, 0.029683579690754414, 0.05070919164323381, 0.04512643960437604, 0.02547521559920694, 0.0220857737253287, 0.04005943185516766, 0.03227317127000008, 0.026806063650708114, 0.032168924542410035, 0.02606036384323878, 0.005543138740384685, 0.0533452119811305, 0.049902800271021466, 0.004750289230807019, 0.10425273941031524, 0.05164879301030721, 0.009035657293030193, 0.05731317281190838, 0.03840008464508823, 0.02264953624191029, 0.044866513194782395, 0.014405792080132025, 0.0753735290574176, 0.028927942737936974, 0.009531779198109038, 0.061435558034905365, 0.06273063711289849, 0.051473561341741254, 0.0669038106820413, 0.0723272053790944, 0.026272138015234044, 0.014990731674645628, 0.04425148226852928, 0.013828964371766363, 0.04903439079810466, 0.031129147657858472, 0.027482591902038882, 0.018907514001641954, 0.03099094025258507, 0.001534918518570651, 0.03427062230184674, 0.03247989035610642, 0.03820545705301421, 0.02699648602200406, 0.03755530854687095, 0.014417683406333839, 0.035977059842220376, 0.02696851171952273, 0.030119731822716336, 0.012427261997280377, 0.06314670800098351, 0.011784026914808367, 0.031230371511940445, 0.0328992453536817, 0.024717729638463685, 0.04472983588597604, 0.07513832846390349, 0.028065061629084603, 0.015663276925416927, 0.032991118995206695, 0.03814832440444401, 0.08841643096613032, 0.04343090612175209, 0.011013324788239385, 0.07485533864902598, 0.04846068943983742, 0.030893906352243254, 0.024522131741312996, 0.026568101419668113, 0.019359347077884843, 0.03623874705018742, 0.025147026870399714, 0.03636352964011686, 0.018069886269846132, 0.02655168087221682, 0.018337356292509606, 0.09447869352464165, 0.08170862376157727, 0.04294992657378316, 0.06400416591869933, 0.012141854053230157, 0.043753373104014566, 0.030716601759195328, 0.018570222725559558, 0.022105717565864325, 0.01869361601503832, 0.004861712738472436, 0.0463416279692735, 0.050596368233008046, 0.02856848541913288, 0.01772643219945686, 0.07371224462985992, 0.01773579089370157, 0.02082233812793025, 0.07560007154409375, 0.02578711779122906, 0.036775363077010424, 0.026572398242673705, 0.016090597924111143, 0.0360947212071291, 0.016234208164470534, 0.02118439762853086, 0.014705850443403636, 0.0427465831993946, 0.07134505308100156, 0.028768045960792472, 0.016717487946152687, 0.028359075941677605, 0.02726411889307201, 0.09165220840701035, 0.010992172307201793, 0.04834546062297054, 0.04009894634197865, 0.018840717318068658, 0.04503363297720041, 0.010285883509953107, 0.017159561992489865, 0.019418318556355577, 0.025151440740696022, 0.07938563198383365, 0.02303331225578274, 0.03598213528415986, 0.0566114760003984, 0.05019543206851397, 0.04091149541948523, 0.01912947976961732, 0.03465305481638227, 0.09885967522859573, 0.008972027671656438, 0.05373755789228848, 0.04843387373590043, 0.02278757910244167, 0.06304431028131928, 0.024733352907268063, 0.012741111584806016, 0.008715810304108475, 0.0358549031828131, 0.03102340136787721, 0.029050055292568037, 0.02312325207250459, 0.04818629327097109, 0.048297854606062174, 0.03210536277453814, 0.0307600415710892, 0.02518868213519454, 0.03464421350508928, 0.07114767402942691, 0.026210462574713995, 0.0451877079238849, 0.014834385331986206, 0.012526893838574844, 0.002298871554168207, 0.06182657741010189, 0.03747193016377943, 0.015604546326877815, 0.05909871057208095, 0.0562607073225081, 0.04782551959423082, 0.03292537573724985, 0.010543893058119076, 0.01763455686159432, 0.03812467745904412, 0.03402438872892942, 0.050585457389908176, 0.021345286763140132, 0.06308900538299765, 0.013092171184585562, 0.02971836818116052, 0.015705368148961237, 0.04445210471749306, 0.03759889763646892, 0.020396769445921694, 0.06254976681832757, 0.006282308496468301, 0.027659469018025056, 0.021857729979923794, 0.01701944281480142, 0.03508381938029613, 0.028852601602141346, 0.0383583309927157, 0.02050563699698874, 0.014900895334514124, 0.016465837967449, 0.01793083069579942, 0.022834908616329943, 0.006492835012198026, 0.0029649435808616026, 0.11860684917441436, 0.02485420847577708, 0.04581610599000539, 0.05744993154491697, 0.029943716446203843, 0.024622704201777066, 0.03144392344568457, 0.01858871110848018, 0.03555206961131521, 0.016426019836217165, 0.03640109673142433, 0.07715437135526113, 0.022394305294645683, 0.021778071665072014, 0.011616393990282501, 0.041287278290838, 0.04695468096594725, 0.01905767380126885, 0.024857869172202687, 0.02488926498751555, 0.04004416820992317, 0.06801105091082198, 0.018201706964256506, 0.015227562448542033, 0.07494483741798572, 0.014301053414653455, 0.03165572815175567, 0.036488953445638926, 0.006008087898538048, 0.029364647875939096, 0.047124867726649554, 0.02495532376425607, 0.08241938919361148, 0.031100666150450706, 0.022159584764657275, 0.03405976754480174, 0.01995920087210834, 0.028283761947282722, 0.016852725064381957, 0.04026684304699302, 0.04871173043336187, 0.037592417627040825, 0.03660419583320618, 0.0234349829344345, 0.0227100751362741, 0.0596619149936097, 0.03585939847731164, 0.024384857321690236, 0.034958504140377045, 0.02212061989121139, 0.048540661577135324, 0.08228799088725022, 0.029579838471753255, 0.043094919329243045, 0.07144647371023893, 0.055077467778963704, 0.08187813537993602, 0.03206469817087054, 0.029688020702451468, 0.03887286749003189, 0.02360626552919192, 0.03307142022198864, 0.014185132492067558, 0.015100198032866632, 0.04189257223957351, 0.08638694629605327, 0.02040327829308808, 0.020945178411368812, 0.034771591491465054, 0.03575180996475475, 0.045911033039114306, 0.029916490228580575, 0.015863624567698156, 0.016115871657218252, 0.01935201550700835, 0.03898051028539028, 0.02177638720188822, 0.039316283339368444, 0.010044988311294998, 0.022061092014025365, 0.015585750906861253, 0.03366394414167319, 0.01721938672874655, 0.22121334049318517, 0.09293537919542619, 0.09525073066885982, 0.16959045055721486, 0.11810876375862531, 0.18122408272964613, 0.08731413047228541, 0.1415037962474993, 0.08117324606116329, 0.19237520865031651, 0.09329150151461363, 0.13207780489964144, 0.15239036136439868, 0.1752463113516569, 0.11239068808832339, 0.10880666611982243, 0.08012790858213391, 0.10549113367285047, 0.14350813440978527, 0.1311348040721246, 0.10498707714889731, 0.06515275607151644, 0.08247186030660357, 0.10319083889148065, 0.07773772826684372, 0.15085827000439167, 0.1190771825079407, 0.15051084650414331, 0.14648538322321006, 0.11512295183326517, 0.12749295734933444, 0.12557418245290006, 0.19071357138454914, 0.20262418155159267, 0.06424083214785371, 0.085947106326265, 0.17499651546989167, 0.1814591544015067, 0.06915829756430217, 0.12159566022455692, 0.1570802732769932, 0.16230895556509495, 0.1129402539559773, 0.11247953546366521, 0.101956868677267, 0.06340604408511094, 0.12589313462376595, 0.10543409601918288, 0.06784947815218142, 0.08567332423159055, 0.13680975884199142, 0.1437203801636185, 0.22338123273636612, 0.10044292134365865, 0.0990350968869669, 0.1039434020806636, 0.10663072645132031, 0.07626326488597052, 0.15086163553808415, 0.1732021024716752, 0.09344407011355672, 0.13581516221165657, 0.11383870217416968, 0.17679612604635103, 0.17738197318145207, 0.14718065091541835, 0.16400256540094102, 0.08584946513708148, 0.12618631603462355, 0.1841814233256238, 0.1092048983222672, 0.1890157682022878, 0.10452399056937013, 0.10391497824873243, 0.14234940015843936, 0.12005094811320305, 0.19950543104537896, 0.08022487802164895, 0.15514548495411873, 0.07458196367536273, 0.11712758855095931, 0.09493849599467856, 0.10238176730594464, 0.09858009165951184, 0.11267682630568743, 0.10387940265770469, 0.10166567537401404, 0.14065573603979178, 0.11216172323163066, 0.08872627719704594, 0.10177350137382746, 0.0604153127808656, 0.09675869332360369, 0.2000425729368414, 0.12202735777412142, 0.07261390678052392, 0.3012912342590945, 0.08323886272098337, 0.1391860427600997, 0.12380879718278136, 0.11108439961182219, 0.07493861525186471, 0.16823412690843853, 0.09283880330622196, 0.17301792092621326, 0.1448856419218438, 0.10486415374491896, 0.12008760257491044, 0.10610267014375754, 0.11072550208440848, 0.09531141205557755, 0.12147359177470207, 0.21419267436223371, 0.06853555169488702, 0.1040046059393457, 0.1105849299845951, 0.0809023884524192, 0.14708150337849343, 0.15065848215350083, 0.10625850249614034, 0.1330319337014641, 0.08549615195287125, 0.13726080821028777, 0.13370048068463802, 0.10082911633487258, 0.14249293745628425, 0.07313253145132746, 0.0812657168135047, 0.11056962901992456, 0.19182953078831944, 0.1601989016469036, 0.08537757117301226, 0.12358369997569493, 0.14518699289432593, 0.1260075763400112, 0.12311177887022495, 0.08090172348810093, 0.1351470494908946, 0.08763419544058186, 0.12898539512285165, 0.09382343904248305, 0.10966076528919594, 0.07404858765325376, 0.2085521620299135, 0.1308363572295223, 0.09262268311743226, 0.13432003743946552, 0.12061329079525811, 0.1580929732216256, 0.09154571912118367, 0.14541720625545296, 0.18120669866246836, 0.11046036452587162, 0.08327875379472971, 0.1868675806160484, 0.09225073057625975, 0.0840747771518571, 0.17365410178899765, 0.21149494126439095, 0.13258536266429083, 0.10388869858746018, 0.15279497179601872, 0.09879177422927958, 0.1305813637695142, 0.1127785522756832, 0.2075287140905857, 0.10012074613145419, 0.10999510663428477, 0.0788091757733907, 0.11406936336840902, 0.11295759731105395, 0.08095801475324801, 0.12466746967818056, 0.17425069691879408, 0.0881690438836813, 0.13497141748666763], [0.04825891348134194, 0.08161282818764448, 0.01228107332385012, 0.020082833345181177, 0.11338180383401257, 0.02027289948559233, 0.037226873849119456, 0.05725764150598219, 0.02780509620372738, 0.05333177698776126, 0.06480822313044753, 0.03520728561228939, 0.05321495022092547, 0.04880993141393576, 0.01755236421844789, 0.01632856185148869, 0.021818575116672685, 0.042876505692090304, 0.041931197845510075, 0.1113146333289998, 0.035708953692976914, 0.005169540327707571, 0.01117866680890854, 0.022153250640258193, 0.02594238187053374, 0.010984771186485887, 0.05539382455338325, 0.03248824651486107, 0.02789031172038189, 0.0470571736805141, 0.02021282708405384, 0.03563974312107478, 0.018077624961733818, 0.032919078932276795, 0.029139492993376086, 0.00133600396345303, 0.033251788400645764, 0.006808563717640936, 0.050275041189576895, 0.014486200176179409, 0.013924659013615122, 0.027615467718403255, 0.017370350592370545, 0.07482202936496053, 0.03174659077610288, 0.04582752234169415, 0.0389890292925494, 0.08296565738107477, 0.05211847834289074, 0.030961203455392803, 0.02190901874564588, 0.04645718926829951, 0.026660261742238487, 0.012960150322344686, 0.0633281482649701, 0.07122679799795151, 0.025693137298471162, 0.021019908865647655, 0.06262735729771, 0.04879730387723871, 0.02351288723626307, 0.09946161721433912, 0.03550947118284447, 0.019628128369471858, 0.008193443512677081, 0.03628903328041945, 0.029816016155694212, 0.010719853303661304, 0.07069793423371655, 0.01043850215085383, 0.015647031100732938, 0.014402864201526557, 0.03537582692557147, 0.024883202277123928, 0.026100237953609655, 0.03251069584595306, 0.012301770338256444, 0.03743851570678609, 0.019605024252086878, 0.009233724209479988, 0.002644313732162118, 0.04053948520283614, 0.02445707719640008, 0.044441438146999905, 0.009648018183984926, 0.027366292696180086, 0.11224467413766043, 0.042665186138557534, 0.013469370497789766, 0.03947522338213665, 0.029251892319215194, 0.04572360809626324, 0.014788434940523334, 0.05959979511265244, 0.03596186065780265, 0.04024595095376883, 0.02609444665722549, 0.06465859258813517, 0.08474288987261908, 0.04558359578784023, 0.029008420383823768, 0.02470566867850721, 0.047387060443205495, 0.02848854720858591, 0.0033448873561740455, 0.02002254550877426, 0.03107389455128993, 0.022268416692635844, 0.015652659548712627, 0.044696384109556675, 0.006230920919084123, 0.020815216902909533, 0.03234794243638005, 0.03388173013393368, 0.02507043383749468, 0.016760742857253978, 0.034586388750800064, 0.009316376560101551, 0.03933329421228596, 0.027376122972262756, 0.024688133637287786, 0.042842032720467875, 0.035300835235310454, 0.05727471344705139, 0.0547237881858434, 0.051968542459819994, 0.04522167877959354, 0.012792674309041883, 0.0653895308662738, 0.034575257383819134, 0.0367354652179139, 0.019289810809173753, 0.005782905874574291, 0.02304419595748186, 0.012816473924820977, 0.035174105249877484, 0.022995025917355503, 0.01958576912459518, 0.03142784895109279, 0.04163030149149043, 0.023677396355196834, 0.027693597633125525, 0.033264419330017905, 0.040163478414927206, 0.034095522947609425, 0.022095807561916963, 0.042073880189231465, 0.030926964578351805, 0.04451750870794058, 0.034336345203753026, 0.031115671952388117, 0.02092216589621135, 0.014955074659415653, 0.013221311665672277, 0.0354258654905217, 0.005381755971549345, 0.04019618719550116, 0.02065414117117013, 0.027654610707291534, 0.008481101648482894, 0.024711332749575377, 0.04049947538546153, 0.020904132131753222, 0.05384249672559755, 0.0474400709915374, 0.02215276039870722, 0.0517310823446938, 0.019138879175963144, 0.01786035974510014, 0.02867169738081949, 0.04888898752895849, 0.012107504066079855, 0.05602938455662557, 0.017520764842629433, 0.03139368471290384, 0.004803223443949329, 0.007599017998602773, 0.032372963415192704, 0.017963780356304984, 0.03758937779015728, 0.02402119478210807, 0.04283985462305801, 0.0279026831101094, 0.011332885944284499, 0.04176972008177212, 0.013826346922931927, 0.03724302637523838, 0.024927086529455016, 0.02332075495672013, 0.04060664659898196, 0.08582436612674169, 0.06174830161035061, 0.0018657367826173349, 0.02736728166096977, 0.028462091128208807, 0.004614875269388514, 0.02152718503826431, 0.01616956582958145, 0.017496921122074127, 0.012404642184264958, 0.015154665735151087, 0.03026513509186251, 0.029408420169992105, 0.02772638783790171, 0.024704701766105633, 0.0421820997393557, 0.026789032421740036, 0.008300560443396015, 0.018220381944307258, 0.02456534424397562, 0.061105125051523955, 0.05565734380590064, 0.056173400221658606, 0.019039137920896922, 0.021684206523267285, 0.07203663632805858, 0.02753036585636437, 0.04338701847674591, 0.03581792302429676, 0.00967982960199671, 0.05127023493072816, 0.012113560839290065, 0.010541424038819969, 0.024238583831382648, 0.0036004471808804995, 0.014544367590653045, 0.02413834724575281, 0.045996820221522024, 0.07678456298474755, 0.019596515422953025, 0.042052869352379015, 0.04844977520406246, 0.03112233177359615, 0.008144276865225817, 0.028864414896816015, 0.008588383123943848, 0.043495539974953444, 0.0615786678556885, 0.02561170800722071, 0.007566155699480857, 0.019135978438758423, 0.04339842465040939, 0.01377020578365773, 0.06025876118136304, 0.04994143605498331, 0.02145079047685223, 0.028253701149619052, 0.01309312113361167, 0.06684312929532357, 0.014932805140103613, 0.05036389195759382, 0.01961410305063639, 0.009759414974333984, 0.04548800716708813, 0.04021205812958734, 0.06304293964058161, 0.031417155239198885, 0.04600344272330403, 0.02459835327629532, 0.05040787120482751, 0.023796794769753302, 0.051003981182085614, 0.01679234053673489, 0.03895162504964641, 0.035894672120256085, 0.016779629879498055, 0.01182032938647483, 0.048320283581103594, 0.05530712813405054, 0.016834837184952836, 0.055432104106460295, 0.03768675095800843, 0.056058639593954594, 0.034325105271169117, 0.02224455091969243, 0.0009631800348870456, 0.025678906722792556, 0.05069676427436726, 0.04676345283431666, 0.04104622533278806, 0.01673031395434269, 0.01743569181832884, 0.0159114952132638, 0.0367749763120498, 0.027098451175593903, 0.019863858220300505, 0.028491427589740072, 0.07735109222786767, 0.017662030744499395, 0.03156165944944535, 0.03812204474317176, 0.018036385299637914, 0.11194594909570046, 0.03339206533772605, 0.02540749271533319, 0.006537650977926595, 0.009632867345187281, 0.036387912796011994, 0.03377394823889647, 0.0477766311461372, 0.0660168704177652, 0.024066407266738157, 0.03212803941486137, 0.12290121588323798, 0.03307376456047807, 0.02047909440339676, 0.04585551869656358, 0.07381800109786646, 0.012870001856104603, 0.01730189997968929, 0.026190099738804356, 0.040081986359187534, 0.04953166197187134, 0.05110222966011081, 0.10952891914972238, 0.01943475945985743, 0.07205560816717999, 0.03900378742920501, 0.03441577451303601, 0.017777396964707544, 0.012267773189315838, 0.014752681234053202, 0.0349335747637919, 0.008550167183524795, 0.026972740689026456, 0.07193701381662063, 0.035317405060465844, 0.018734268744343092, 0.007591152929567865, 0.05080245628154703, 0.010815776951078857, 0.01978809978546841, 0.019781563796901276, 0.008047390546250557, 0.0023833665514497882, 0.05808164764727865, 0.022678368891190206, 0.04401078214868903, 0.054546958567308526, 0.07604779609079872, 0.0259035934161927, 0.05351443522210632, 0.02990334021991917, 0.009672928052688283, 0.015427971158974936, 0.040776690867330344, 0.030219737706439834, 0.04397580027580261, 0.013554411291676973, 0.027739754977769086, 0.03601622149082167, 0.02572588509480868, 0.1219339913555554, 0.15606112724968366, 0.0908805105303015, 0.14727840067020484, 0.28373468347958153, 0.15099304062979563, 0.17782789282500744, 0.14927097303526743, 0.07947578893176147, 0.1646589801779815, 0.2683785674827439, 0.1341676384742771, 0.07970070971974305, 0.11797370814851352, 0.16775518975087575, 0.13434241552438053, 0.1251710240862199, 0.08864759427628346, 0.11633827590516635, 0.18331749896918023, 0.11243066058627196, 0.09675772980387722, 0.0870528266366039, 0.11160584698830332, 0.11693759874573775, 0.15498993758644375, 0.15870091345693382, 0.11603977477976254, 0.13063662366143294, 0.14038782327302865, 0.07906214041369301, 0.1697712122861828, 0.09765691083988973, 0.09947649748729807, 0.12354841615472521, 0.11042981687933207, 0.07173162126647574, 0.1030268030507224, 0.14236271301550524, 0.13924806086080416, 0.15797421602266176, 0.11766045567180429, 0.0888844912073442, 0.10787935302193676, 0.2220850001488413, 0.08846837282180786, 0.12061589636972972, 0.15910057058291777, 0.10964112170040607, 0.10085492102163178, 0.10817892623267003, 0.09718620431210313, 0.1943259154047285, 0.0831214761627572, 0.15568169046725544, 0.13979375229350158, 0.09055595366018158, 0.08525218468691621, 0.29514186137488907, 0.12497435749641486, 0.09876511458839689, 0.14568625896104745, 0.15595243951039656, 0.09614403559161083, 0.10920277450765882, 0.09392400471759693, 0.11271877334054027, 0.14292302009250435, 0.18865803096975597, 0.14619490238172667, 0.08520672962601696, 0.09229136125317641, 0.13821974104004248, 0.10663269420287438, 0.08890528152031557, 0.11785244036998067, 0.1355268798236336, 0.10642731522342988, 0.10279939882457256, 0.14117860155446188, 0.10158398654311895, 0.17816234273569925, 0.13393164399479116, 0.11571263947657176, 0.0857632097655109, 0.16012093797326088, 0.1614524136696543, 0.1061428054901106, 0.11482249652700764, 0.1200519794864314, 0.08542005425052983, 0.14827894126730307, 0.15542152657040528, 0.15766318914081368, 0.14353212740804466, 0.09941525291651487, 0.12558418405907495, 0.17269245481916837, 0.21182130303766045, 0.07439005361603838, 0.18574783498687403, 0.11759029515087605, 0.14333840566022055, 0.11826892516442708, 0.06876832313303437, 0.11676601081022195, 0.07786572032741138, 0.13014256874365465, 0.08212261154715504, 0.17282186501792499, 0.18332602136901446, 0.22358415541904314, 0.09038933938635246, 0.1053842847634639, 0.1747433269130332, 0.1353859616709607, 0.1931842938065529, 0.07944728367562805, 0.13513575866818428, 0.11940077585833413, 0.10947604770106928, 0.11407074757984706, 0.12344183187399592, 0.14178860453622683, 0.23899116154227937, 0.20807239705962793, 0.1317122509436948, 0.2568372025021485, 0.11132765441600766, 0.11236036435833999, 0.21402712538838387, 0.15304661329303468, 0.08381837912436042, 0.0956861533756767, 0.09615249692329339, 0.15557981521955558, 0.11739566416612693, 0.11846211765493665, 0.19384764321148396, 0.09478159834231649, 0.12953684053250722, 0.12067070842853614, 0.14115549065172672, 0.14788168615528516, 0.10764744332326309, 0.06244889580245529, 0.16156507762415068, 0.1740902369575841, 0.10948861416961465, 0.12761094101837703, 0.16807167205427373, 0.15932893832879408, 0.08390974386462144, 0.08658223545977048, 0.07177104415105921, 0.13156471028923988, 0.13542439389441693, 0.16587999037333898, 0.10388430168053933, 0.18028862721153668, 0.1419587539775031, 0.11044442573828356, 0.11817230177777154, 0.17597960414631025, 0.1455610692501068, 0.09645753912627697, 0.277599532689367, 0.07967009421970163, 0.12072306419057505, 0.1503488394830908, 0.14430276677012444, 0.09185283085597412, 0.14950622112623282, 0.18076930141874722, 0.1956731602549553, 0.08125334033476454], [0.005694958830385336, 0.03178269223177007, 0.041246125141956975, 0.015047431757141436, 0.043574735189654996, 0.052288559930665154, 0.026993269766015664, 0.011843205346459789, 0.037043367446001084, 0.026070195815658996, 0.020839550865015814, 0.028081280312367847, 0.036285847558506897, 0.013995540478000683, 0.0182555538069989, 0.03705144879807319, 0.05120541787307177, 0.07887332447405372, 0.0863622815481254, 0.04099877198625888, 0.018434434297627637, 0.05024817459551351, 0.032132236153951714, 0.03354218103257673, 0.06734819683645453, 0.03264623321592808, 0.01920187775976956, 0.008884043732125844, 0.020485459061871682, 0.05516104632988572, 0.02360749876658831, 0.014636232750490308, 0.04447731229343584, 0.02908227892060365, 0.010896932283815528, 0.006800261841687773, 0.02347164587782962, 0.010243676087286855, 0.018928346723052006, 0.03949163714423776, 0.016281208588874767, 0.051421873936695714, 0.02783634783034878, 0.03593741643375584, 0.03555819678253361, 0.012693910144402512, 0.037780073271798234, 0.02434313589973109, 0.044766799081116915, 0.045907195923583846, 0.04844435370926346, 0.022264484582202773, 0.027180301158555915, 0.01866770445901368, 0.04201246937736869, 0.040185910782643726, 0.02939419129065105, 0.0524049558277641, 0.08297068532556295, 0.005547706553313349, 0.027755805723635212, 0.07162472485963788, 0.09958065261266061, 0.02578547064747129, 0.08336208468036992, 0.05197648471221328, 0.015358093926416976, 0.029124483798763583, 0.04312124648796661, 0.026667352433183363, 0.042449564673006535, 0.045162408745714595, 0.017484069668820927, 0.029591105545737913, 0.010819111102526742, 0.034557076037994454, 0.03407705322440181, 0.06304450705647469, 0.038430201421890936, 0.012417182359578354, 0.035589063340531926, 0.05429953755810857, 0.07828352826514415, 0.005354192182754299, 0.04154374077916145, 0.040191182999738624, 0.016905569371634295, 0.014016416456018175, 0.03588448730962617, 0.07562675154102699, 0.042932949627616575, 0.04288720618933439, 0.033177281862923076, 0.02621636413303869, 0.04840526330683913, 0.04473330998527152, 0.021221138603453125, 0.015546770766377449, 0.05361098057723471, 0.016433495595785122, 0.025022495338427167, 0.04354898478569729, 0.031083041203341315, 0.041866821835615804, 0.029872483839946132, 0.019433726390291537, 0.04800965703491654, 0.016165235079824924, 0.02144939439105136, 0.03839940611006958, 0.02955620170437864, 0.053271156669195206, 0.02558559289069048, 0.028106866171583533, 0.051847881970128844, 0.030741558277181218, 0.07361488164003406, 0.03641520347446203, 0.03804756873952491, 0.0374735009723476, 0.004347770807466337, 0.07688756460057837, 0.056199825767959864, 0.007645521396105843, 0.020668690658307502, 0.008287565649620124, 0.04311333137697407, 0.014572194311767817, 0.05419909401929804, 0.029867231978901794, 0.05133713169821671, 0.02558130624571017, 0.045809354566569836, 0.0820524917383279, 0.04253169455166374, 0.04052346499104585, 0.013748875187177743, 0.03013786906376481, 0.04186004327077951, 0.026071435838405575, 0.043862400110810995, 0.05673794474984918, 0.022156868928245137, 0.02049103153071233, 0.06950202983404909, 0.03249047889507242, 0.02202075649984181, 0.053540131343262534, 0.02372863931980516, 0.05172245816460677, 0.08145565912127495, 0.027052322668688636, 0.00536410345895482, 0.004461115417403302, 0.04490627873955028, 0.04540283405887229, 0.07124535593071155, 0.0391560574727399, 0.04592705325090459, 0.01786894490942359, 0.021060877113736103, 0.12052269279956818, 0.04007637148190822, 0.010814928782305546, 0.04505074563037072, 0.043849192426673005, 0.01740421288247619, 0.03541729559323617, 0.008845044083760252, 0.06860770032341991, 0.021154252013989856, 0.04688389280012675, 0.08134552610239812, 0.029849009920975993, 0.019136416093845452, 0.08906874739165817, 0.04925432774637427, 0.025448727288416455, 0.0823127506300807, 0.00969798635092697, 0.03521043401477592, 0.023959673708304763, 0.01907624869740435, 0.036597885457532744, 0.031645760472331724, 0.02234571540196027, 0.04247759156195181, 0.05819513941449778, 0.027323882561177015, 0.06651294736989907, 0.03399467228778771, 0.023375931728099073, 0.047900786091174395, 0.041440345613019805, 0.023105530434155037, 0.07082091192049639, 0.014890150732493826, 0.018512737238779664, 0.07041056108261858, 0.03268982569820114, 0.040920944019619904, 0.03213825475956712, 0.027378913447526947, 0.03609644129340138, 0.013701060520751136, 0.031460184537406476, 0.06168774914528642, 0.046218005674225945, 0.01174037845339626, 0.04682357103696891, 0.03499174557094063, 0.036753426039857526, 0.03160534353394594, 0.03676277964508959, 0.038074438726263385, 0.029227244534662793, 0.02222429834572332, 0.05076793920514839, 0.037637021126491685, 0.010901271515259785, 0.030429540734205927, 0.04509348655119538, 0.006160488984148417, 0.03075343942535775, 0.017618373801399554, 0.03325570694037846, 0.029561453565422977, 0.011718398159635919, 0.04492729636175292, 0.037994649793420515, 0.04398287400337202, 0.03481040369453175, 0.007849654415622354, 0.09136364103427955, 0.07884764192359787, 0.046964570613844056, 0.05552231194451451, 0.0369047495270414, 0.06099584698677063, 0.013312500834997212, 0.044023416470736265, 0.052923380330737145, 0.01663102731773896, 0.032718120608478785, 0.03382438035415752, 0.02125553015087332, 0.04494654979290707, 0.04302024994311588, 0.03638139546715787, 0.06996105198881455, 0.03398497262969613, 0.017721743522478, 0.014661872892507484, 0.0012764596529970212, 0.018226020570312227, 0.03331640189779656, 0.030084397111620222, 0.02109836278084133, 0.06893972786409513, 0.027923076480094875, 0.03846788386415158, 0.03948318938325558, 0.012629121076315641, 0.046437722098614485, 0.027403523912653327, 0.09630429199231522, 0.08358009798186165, 0.054702248091676405, 0.04528209553765399, 0.036818453443369696, 0.05333859287202358, 0.05012988558571253, 0.018148129839184027, 0.03186860155048115, 0.002013969754833462, 0.02634888711119337, 0.029986148633595024, 0.019992559349962642, 0.03505424203883324, 0.054961400971348794, 0.01666164112144283, 0.016875042081145302, 0.012637965780283724, 0.02234208015059786, 0.032344658326889784, 0.01347975547625018, 0.006904454710560718, 0.042869197869939465, 0.012389510853349097, 0.05270754512665527, 0.008436884913992668, 0.04470241967854755, 0.050753337131547074, 0.08028963061847857, 0.039836658630520105, 0.02942902727850846, 0.024905663482578735, 0.034476798559938154, 0.033214526650096686, 0.013438656610170645, 0.021488522112901722, 0.048502948600798845, 0.0016272133819126922, 0.017935851854937415, 0.08638033736497164, 0.03835197990494115, 0.026060947383354818, 0.05049909006005951, 0.04508976817929319, 0.030065007973462343, 0.05638575114841972, 0.03136209551511066, 0.01726336088696761, 0.009612987965478428, 0.07098084940974202, 0.08236275866095509, 0.03130316814141614, 0.02442848033803914, 0.011615155663873469, 0.013550035588975464, 0.05263380194082856, 0.0550209390265601, 0.03275566055838551, 0.021105611231178045, 0.03323596835668598, 0.0356888317369989, 0.038445878973496814, 0.036920406722596714, 0.049616848650787554, 0.010127662714304668, 0.011260692362806626, 0.05500996032995837, 0.043758217844047716, 0.039132800684975724, 0.024267336752797877, 0.06826434124793325, 0.01760377681681088, 0.08192711882293224, 0.035117776665304384, 0.041016675132725916, 0.032765095587819815, 0.07879484511379685, 0.03381798855428185, 0.01178986910131893, 0.05336633477626102, 0.042909899793033085, 0.02324319670775107, 0.06931334960141353, 0.03948451591921704, 0.045143779566777606, 0.061311732179352214, 0.019060559271435653, 0.13273354114166327, 0.12522560544312, 0.12929575704038143, 0.10437471965061766, 0.17494748452944414, 0.19918562392038958, 0.11307159797953707, 0.08548591285943985, 0.14666736631521157, 0.1576184058295829, 0.15972646485481942, 0.16156224134777272, 0.14503135053174837, 0.1012351516900318, 0.12446385488978454, 0.0864969232518758, 0.10781024423028741, 0.12611512414046697, 0.17808466404676437, 0.15663824842444488, 0.16398873685726098, 0.13613657067928994, 0.13810984550842217, 0.16918848641216755, 0.13763302538011754, 0.16997009090014867, 0.09136013300823313, 0.054644833851073465, 0.14857448398002557, 0.08475159547690835, 0.14192307660622255, 0.1072848749213985, 0.11296350735106639, 0.10140234271862678, 0.10955279001167842, 0.124202768185309, 0.10158186272851058, 0.0678500888336982, 0.18706080024795874, 0.08758985996246338, 0.09836177980261189, 0.1246333122253418, 0.11534647483910833, 0.17274487843470915, 0.1269057395734957, 0.14962378410356386, 0.08385421255869524, 0.15427337746535028, 0.21699654390769346, 0.14615102830742085, 0.17465108686259814, 0.11664930278701441, 0.12153510775949274, 0.09041631793869392, 0.10441443430525915, 0.09412515642387526, 0.12895977364054748, 0.17807539525840962, 0.09920726836259876, 0.1359249491776739, 0.16896697186997958, 0.17059407170329774, 0.17435420065053872, 0.07168801182082721, 0.17701289084340843, 0.08819214800106627, 0.10372337353016649, 0.091310097835958, 0.09623127483895846, 0.07312176310058151, 0.11145567361797605, 0.1566542482801846, 0.17454868235758372, 0.19691226019390992, 0.10287954738097531, 0.08306382104222264, 0.13369862149868691, 0.1734439187816211, 0.11423393525183201, 0.11930841367159571, 0.07492493598588876, 0.11459748074412346, 0.13567444761948927, 0.12326423211821488, 0.1436478854822261, 0.13047562087220804, 0.094242563338152, 0.07503221915768725, 0.09951666676040206, 0.17011843222592557, 0.18064951284655503, 0.17252689227461815, 0.12282234297267028, 0.14274113199540547, 0.1329963920371873, 0.07721842506102153, 0.11266525049826928, 0.11895986380321638, 0.08339773491024971, 0.10334592485534293, 0.09947460437459604, 0.12573116831481457, 0.14336560134376797, 0.15425984747707844, 0.11691347004047462, 0.11916357358651501, 0.1641418957816703, 0.1506098990461656, 0.09875830888215985, 0.11391042332564082, 0.07624519549842391, 0.1410007303846734, 0.16104077361524105, 0.09136109652795962, 0.1133372580100383, 0.08938005247286387, 0.14684967510402203, 0.19989070322896751, 0.12626275978982449, 0.09998563623854093, 0.09267157156552587, 0.137493138600673, 0.20695737403418335, 0.10749634714531046, 0.1988511604389974, 0.11028491572609969, 0.11349528203053133, 0.10093638593597071, 0.23315345336283955, 0.1217564187411751, 0.10614169269268002, 0.1504123503608363, 0.14977630520505564, 0.19787444999175413, 0.15919525335941995, 0.1168678453458207, 0.06731469756258385, 0.08217449912003108, 0.2551830969750881, 0.167964599228331, 0.13763698802462646, 0.12631906462567194, 0.14851701206394605, 0.06482948163258177, 0.23118057208401815, 0.18588531975235256, 0.09123498400939362, 0.1448476439607995, 0.10769126311476741, 0.11082637988563095, 0.14656831377318927, 0.09026026845510517, 0.10618123092821666, 0.0926037316343614, 0.12166685211871352, 0.12851654099566595, 0.14428581696535858, 0.1583728010633162, 0.16235965570168837, 0.15499581369970525, 0.07665989574577127, 0.23031714984348842, 0.13636272640100547, 0.20108453131147794, 0.12574948876031808, 0.23258163833192416, 0.13634788005479745, 0.08303494259182896, 0.1541105562022754, 0.10010631369160754, 0.12877760055874074, 0.19784346808280262, 0.1306316160729953, 0.08503476849624089, 0.1511516414050545, 0.15734507835337094], [0.02656584189805601, 0.02844370622187853, 0.042910483333149126, 0.023363706223400574, 0.010558142293510693, 0.04978267243131995, 0.016019981088382856, 0.02273965926308717, 0.02019933271887047, 0.03411867456244571, 0.016629889075245177, 0.012221942389650004, 0.052281092652784925, 0.04022541848410453, 0.02523151126557163, 0.006606247899721244, 0.08425528103751795, 0.04864384639742119, 0.026455805570419346, 0.06266637984663248, 0.00319535647369256, 0.03380492675517287, 0.03186593490785786, 0.028499298595956395, 0.021733732794278433, 0.07674792209374053, 0.033825774743620834, 0.031210375084940876, 0.02619164001329669, 0.019536985849429454, 0.0556447637666549, 0.04612591829417007, 0.07226849174393074, 0.019420004715876918, 0.009406746398391468, 0.05974897103650229, 0.02387910954920309, 0.0691066203372819, 0.035971594242645163, 0.027870534120925834, 0.04705291248059698, 0.014251652672620756, 0.02922356008951153, 0.02921282566551651, 0.04719724366441369, 0.022185569263196418, 0.010562010791285761, 0.03343799876581345, 0.018273236429584876, 0.02074970943587167, 0.031102586404553483, 0.03979258778105889, 0.04119059383603079, 0.008997018964562033, 0.05400525013517056, 0.03963169016476188, 0.027732525187145387, 0.05761687151555504, 0.007343829459776836, 0.03253636821838362, 0.03885711529957397, 0.03760792215221694, 0.01986412624163287, 0.04358441449169602, 0.030103962668882947, 0.035980330381010256, 0.05372765128101621, 0.049117077075477154, 0.013901928938659174, 0.025824153928884437, 0.022697571432217956, 0.01921455279391791, 0.0532642831094563, 0.03849006856658629, 0.0295911632212145, 0.07305607412542615, 0.07332874342267003, 0.05733242963573762, 0.033514147358281274, 0.03585272847807833, 0.09380393116069691, 0.026034090967316712, 0.03768946509808302, 0.07085846883377858, 0.058502732909151485, 0.05985092092305422, 0.007961875626019068, 0.0442727068439126, 0.03880867129191756, 0.023893041569473486, 0.07753675297967025, 0.019976108268435513, 0.05689034710771271, 0.02093137870542705, 0.014949261310643383, 0.012038205284625292, 0.056474439068032165, 0.01945136660443885, 0.049819306536976776, 0.02265761250496975, 0.016301968367770314, 0.008310118457302451, 0.01813797895530505, 0.037817043252289295, 0.045560695230960846, 0.07117235234805516, 0.062792329516794, 0.019752753200009465, 0.050435721674667935, 0.021935452773634876, 0.027260291955566833, 0.018702414917892644, 0.04006286184968693, 0.04971736343577504, 0.0309633136993008, 0.028355893612440144, 0.08223206603101321, 0.032735891440617185, 0.03189840620117528, 0.010947823258382934, 0.013984914619608648, 0.03077591929052557, 0.07240954560360738, 0.006087214411568961, 0.002940637820367036, 0.13042008956628187, 0.02733646090408521, 0.05165347829461098, 0.02685573241407318, 0.03048590663820505, 0.025701839510085325, 0.0632810036518744, 0.008814706783076482, 0.023370140431714908, 0.009539272769221237, 0.0487984166746693, 0.055077952931502035, 0.0703707378623741, 0.02480448373327298, 0.045964328572154045, 0.07561011386236974, 0.009237240717214133, 0.05674199221123542, 0.051319167483597994, 0.031001450760023933, 0.013307428785732814, 0.038124297479433675, 0.03533283155411482, 0.04098225644390498, 0.06669952414397683, 0.04296248625697834, 0.047085475376141925, 0.06554332761360065, 0.01536275546199509, 0.03545422486162611, 0.029562949735139097, 0.05277488972725613, 0.05417781855378832, 0.02191557169758848, 0.018489874001326304, 0.06741385188485895, 0.04062293143942952, 0.030468800770384923, 0.022312725029353584, 0.010134356462263634, 0.019613483887431876, 0.02616602022733007, 0.0660975482314825, 0.052154783359063525, 0.025864177316959416, 0.03056356157841427, 0.045363384032888074, 0.03966272635651486, 0.05880784975098712, 0.016527767858601043, 0.03255956733067121, 0.05691528326964804, 0.01512924611701497, 0.03298171449984823, 0.03154578851535916, 0.02870448080024549, 0.061546586720006805, 0.0146092270567481, 0.03139214104573641, 0.064665208304567, 0.0014856463801282058, 0.038466811778822114, 0.03161661060793059, 0.03740582049691251, 0.024243647398959314, 0.0303070583779897, 0.023709122956331288, 0.034568899510694404, 0.09566501022449561, 0.06778585192348276, 0.01049637864343822, 0.03738621422754867, 0.073003636939185, 0.03204425730343376, 0.032780043714280636, 0.037129894231579134, 0.0557798600888678, 0.05892607769263642, 0.011365975552637662, 0.06140070169099739, 0.11405842538390841, 0.016764563009408966, 0.023007587296888232, 0.07360924301402909, 0.021179054165259004, 0.02064971373017345, 0.040883960468428474, 0.011267045146918722, 0.07354731312287704, 0.013193484944557505, 0.044799253411058865, 0.03779927581282599, 0.02354076654384179, 0.018632722586127262, 0.027658349435244287, 0.04137682794992413, 0.015112786553800106, 0.03753454198262521, 0.012399839852670473, 0.022243514457451444, 0.050088301567094665, 0.0998491964169911, 0.0531167865597776, 0.04611547564023307, 0.027524778120485798, 0.06536854377814702, 0.05097318247758916, 0.06523448561451264, 0.024416129304362193, 0.023273808815117394, 0.05716563894280365, 0.04332352116970079, 0.029802689727927958, 0.008480836171656847, 0.07921405083366803, 0.023136310478938476, 0.013457977046657885, 0.06008916135345187, 0.04688222021130579, 0.06433418499571936, 0.011302157637796231, 0.047392146063170264, 0.025480428444487706, 0.05399269045197538, 0.06128003102328096, 0.010856664623133838, 0.09810519857066018, 0.03856854114149298, 0.020223252774615372, 0.0433496719093195, 0.018759610330952064, 0.05181436234020761, 0.030973474761205058, 0.04702552341456924, 0.030236986066613878, 0.03723009010510785, 0.0645175048017076, 0.07000417288924966, 0.048163141656134806, 0.01496485065269683, 0.04560302224542413, 0.049059927463531494, 0.0034087207500955886, 0.018386131085987602, 0.04348118895930903, 0.050865943410566876, 0.030980175294514214, 0.004375359193155808, 0.019291744633976902, 0.03221240506640502, 0.03972169104963541, 0.014012802408875098, 0.022173055381114994, 0.04128289495461753, 0.028944393819464103, 0.019352800911292434, 0.04211195278912783, 0.03256106010771223, 0.04609917722908514, 0.02788268668310983, 0.0931764016194003, 0.006955323632740016, 0.003948033105448953, 0.07152042724192142, 0.015592168151800121, 0.03055754636547395, 0.026441135643316165, 0.06678270575191293, 0.007369974262214133, 0.06758465271975313, 0.007639655460869628, 0.018505828055952276, 0.06156201660633087, 0.0370805104529219, 0.0651750188054783, 0.04724924319556781, 0.02107785745257778, 0.019786067573087554, 0.01952944732537227, 0.006973532544049833, 0.0464249147501375, 0.014877826840217625, 0.051316551731101105, 0.007502939136299703, 0.03535453449668629, 0.06111019370811326, 0.025084951094218662, 0.018142347024487596, 0.03206668967115028, 0.02068369137123227, 0.016277800646743605, 0.04948639011542712, 0.038546604104340076, 0.04641204633350883, 0.07664760069123336, 0.030592446814158132, 0.040795642350401194, 0.04299008906153696, 0.040847146550991704, 0.011119520607670503, 0.05521596695429512, 0.02758194299946938, 0.07020440857325282, 0.0352971948949354, 0.007866656806852137, 0.06273375837398426, 0.07931150203304631, 0.02493280657966222, 0.05932847610009568, 0.032595509330609014, 0.03921537161139505, 0.07380445075354405, 0.04991502068670733, 0.05390819587877818, 0.03370787589145558, 0.002999916123891515, 0.028112267310331975, 0.06573841321681227, 0.03489041993660586, 0.04942831091050591, 0.01145382208882698, 0.01866158576948302, 0.020447520472641503, 0.03236173366063407, 0.044775891450366805, 0.04197277847145285, 0.11394201591610909, 0.11591070384851523, 0.07813904780362334, 0.13239674349980696, 0.11991604178079537, 0.13248248318476336, 0.15964276077491896, 0.05610068501638515, 0.10084202207092728, 0.18246012926101685, 0.1361741886607238, 0.10752394994986908, 0.07780801770942551, 0.15618069869066986, 0.13878633135131427, 0.1245417914220265, 0.09286114746438605, 0.11586311140230723, 0.1349270955792495, 0.16462569124996662, 0.17225342909140245, 0.09376511217228004, 0.14432646121297563, 0.09140732511878014, 0.11328827456704207, 0.08784299423652035, 0.1341256642980235, 0.10969974034066711, 0.1285608493323837, 0.12543832617146627, 0.19020245809640202, 0.17238385709268705, 0.11591828987002373, 0.27507695662123816, 0.10567087081394025, 0.09151426223771912, 0.11863504908978939, 0.10183346351342541, 0.19323749095201492, 0.08715580789638416, 0.11327387605394636, 0.08719827740320138, 0.08122382406145334, 0.1307452842593193, 0.09328371871794973, 0.13388515077531338, 0.07629368361085653, 0.11450427717396192, 0.09786752132432801, 0.09673139585980348, 0.1752965093723365, 0.16737603795315537, 0.10072008254272596, 0.1762811451085976, 0.10598750239504234, 0.17842731066048145, 0.11135244130023889, 0.06150766595133713, 0.08607395844800131, 0.06967466271349362, 0.11817839502223901, 0.08620903441416365, 0.09789307495313031, 0.09046574242945228, 0.1287514633898224, 0.10365788811551672, 0.10579068652753319, 0.12152621895074844, 0.17102837482733385, 0.15341360574322088, 0.09843340595918042, 0.09807860678327934, 0.08532992444400277, 0.14304825051554612, 0.11866141696061407, 0.05526503182149359, 0.15002823168677942, 0.14173517668885843, 0.09111387907926526, 0.11230741827083485, 0.13479239280734742, 0.15652802719601563, 0.08975400669234139, 0.11532995929675442, 0.1293767469802073, 0.16565110694084847, 0.18447626036192688, 0.12730080980275357, 0.287576005927154, 0.11601993441581726, 0.13914142229727336, 0.12708973112915242, 0.07250798067876271, 0.14193006551691464, 0.12723256275057793, 0.130481768399477, 0.09310774744621345, 0.09472906616117273, 0.08401953761598893, 0.09868190583906003, 0.11265502497553825, 0.08489226257162434, 0.08313988481781312, 0.0828687490097114, 0.11405648477375507, 0.11880937830678054, 0.11359765260879483, 0.12027436255344323, 0.09450970936034407, 0.18514875641890935, 0.22074707836977073, 0.08665692859462329, 0.11240409594029188, 0.16563399428767817, 0.07440735625901393, 0.1538272135491882, 0.15151152280824526, 0.1526439841836691, 0.08422054682991334, 0.2229033133813313, 0.07750127238354512, 0.04622300647731338, 0.17385806941560336, 0.20772669703832694, 0.09476094373634883, 0.106498344269182, 0.20815601971532616, 0.08553311854068722, 0.100340326848839, 0.08581457486642258, 0.1515032718224185, 0.058670412482959886, 0.1705337499401399, 0.09268653326268707, 0.0721384844343577, 0.08774437595691, 0.1210662264909063, 0.1640503614076546, 0.11714419908821583, 0.11567854987723486, 0.12669984490743705, 0.16517127411706106, 0.12144661322236061, 0.14534211957028934, 0.13897818034248693, 0.141212881143604, 0.11856555353317942, 0.12307212528373514, 0.1348684701536383, 0.13111980844821247, 0.16543668987495558, 0.17138897547764437, 0.2137752939015627, 0.1359261026872056, 0.13283378790531838, 0.13854741917124816, 0.18734748129333767, 0.07554421454135861, 0.11651594351444926, 0.06262571524296488, 0.14155449638409273, 0.15960135656808103, 0.27493693413478987, 0.11306052428803273, 0.13064518677336828, 0.10007403578077044, 0.16454666906169482, 0.1494785776095731, 0.13665570425135748, 0.2019698838038104, 0.18818999108459267, 0.07632286061665841, 0.15103263993348393, 0.15934937580355577, 0.09179898231689419, 0.08378494770399161, 0.17445018621427671], [0.022897966571950486, 0.00951654014975897, 0.010466737689317336, 0.03973299544304609, 0.02936363685876131, 0.01397084180332188, 0.023812855693644712, 0.014025240803935697, 0.020621512118460875, 0.01364126377406397, 0.03276710405147501, 0.03492048243060708, 0.030624490630413805, 0.00915778087385531, 0.013212564501113125, 0.058425820964787684, 0.02086547768807837, 0.02860428492671677, 0.04468649446165987, 0.09228341560810804, 0.03446918539702892, 0.02050957758910954, 0.05232993021075215, 0.05443395195262773, 0.03595655790663191, 0.04409893063296165, 0.04820640844159892, 0.020040869346952865, 0.025383386062458158, 0.04389744983719928, 0.012594793989722217, 0.053150923656565804, 0.09921000285872392, 0.11331333286528077, 0.03361531692956175, 0.03847293895004051, 0.015408439528463143, 0.019324916514701078, 0.07281013910791703, 0.036653562648487945, 0.03292681762416448, 0.05703894966947181, 0.04857573165957417, 0.04645204597285815, 0.07658561651727983, 0.010093439104301589, 0.026448110983307873, 0.04551249549591115, 0.01922498018081699, 0.045961872275386534, 0.01735898682714573, 0.04948071416999612, 0.07906108868441411, 0.010907530152638043, 0.019634869614882127, 0.09275467174925975, 0.050304079095699956, 0.044139612200004716, 0.04410061679248299, 0.05274355837277003, 0.0116449603145676, 0.009241841184640569, 0.012630729204309838, 0.022225265258124897, 0.017410594504326582, 0.02818066194387419, 0.042617668331201584, 0.05948377919516393, 0.020596058573573828, 0.02807079185731709, 0.050880962783204656, 0.05777662580034562, 0.021682087797671556, 0.029345401230135133, 0.019649185007438064, 0.03338603994676045, 0.015564767211409552, 0.020106414133416753, 0.032636089117399285, 0.016791025875136256, 0.006251947871143264, 0.037388660346290896, 0.016098529998479143, 0.017236965874742185, 0.032106160053185055, 0.0791769146120974, 0.027022524803344692, 0.1147106196731329, 0.032331169050719054, 0.0835785169952682, 0.01304901296472443, 0.005914689673643027, 0.0333179896697402, 0.03690331103280187, 0.03658172953873873, 0.02018170607542353, 0.04855697016630854, 0.07101326302758285, 0.058714781887829304, 0.07231820121939693, 0.06824486050754786, 0.05490561182211552, 0.03912121130685721, 0.006629978389745312, 0.029051541284258877, 0.02754100358911923, 0.06788609190178768, 0.07857215670602662, 0.02709792022194181, 0.04999065359256097, 0.06513463918651853, 0.048835213628730605, 0.12273270849670682, 0.009519427316263318, 0.008979871536472013, 0.01856761715108795, 0.025656908617487977, 0.04152662812599114, 0.0642405403777957, 0.09154884038226944, 0.023034699859895875, 0.07056650200060435, 0.04614637273230723, 0.04331551106380565, 0.049913107217954736, 0.03247770547334637, 0.03746329241299203, 0.06970168197793619, 0.04545182089454361, 0.02546668641402253, 0.032614070656044145, 0.03316084435209632, 0.04526242141478828, 0.02746768109500408, 0.027176340210384557, 0.03748196230403014, 0.025921347284955636, 0.013862684169518096, 0.01873054019441562, 0.029365231416055133, 0.015019694941916635, 0.03631314841498222, 0.030042741846825396, 0.018360295865152563, 0.057365182521087785, 0.020458863881815757, 0.029016589945448295, 0.016166904275970798, 0.08675885133977447, 0.04891614928575499, 0.03088070884613054, 0.05604080430098942, 0.028762471795614277, 0.007828231368746077, 0.019769555423408747, 0.03064461937174201, 0.031434440918798955, 0.10136289947799274, 0.021162078915429965, 0.010546163605925227, 0.08730046477700983, 0.07379869677658592, 0.01910102879628539, 0.023402413253539374, 0.0028852581246090786, 0.012397833933521594, 0.04536004564059632, 0.014813981783975447, 0.011005890588941318, 0.03798392554745078, 0.06348119862377644, 0.054079732924167595, 0.06027763802558184, 0.026817106808136617, 0.022775453681658422, 0.07141184128288712, 0.03239527025393077, 0.023947782382102947, 0.02441917423025838, 0.032790985091456344, 0.053531921069536886, 0.05759929067322186, 0.052939281798899174, 0.01575668914509671, 0.03193828370422125, 0.052231800476355214, 0.024257518351078033, 0.08421320508101157, 0.054382647919867716, 0.04024041750069175, 0.04021190206653305, 0.01635710951606078, 0.03692911232688597, 0.04140465806371399, 0.05720470220382724, 0.03015232185966202, 0.08683199741478477, 0.03386387448491795, 0.023936944481517588, 0.054964362776705196, 0.018312974832952023, 0.017287694849073887, 0.05468209899429764, 0.02612218856146293, 0.06542517431080341, 0.02599823548059378, 0.011382762508999025, 0.03174509121371167, 0.031068673224321434, 0.03454935091680714, 0.037599528674036264, 0.017783446104398797, 0.02203443576581776, 0.05549583890076194, 0.04274519220260637, 0.027809406597433344, 0.062402965767042975, 0.03851155437795179, 0.010347092457647835, 0.027295803085767796, 0.06035254829164062, 0.043151563432599814, 0.015651334709088718, 0.04052832330177937, 0.03572506211431963, 0.021945849626458118, 0.03669313481077552, 0.06247455121151038, 0.07524005443389926, 0.05742060526141098, 0.007468608657031187, 0.03863815883440631, 0.038251936701791625, 0.038104932090001445, 0.011070828086563518, 0.013317846842775387, 0.025392242640789067, 0.03393492388672062, 0.05942469236574002, 0.01966362083995981, 0.0723423163539597, 0.014371327590197325, 0.05013049626722932, 0.07942141113536698, 0.07883584219962358, 0.04939584300986358, 0.013120343110391071, 0.026059364700423818, 0.0664103189483285, 0.03279949392059019, 0.011547950162951435, 0.020867983178634728, 0.056719977142555375, 0.010470040458520609, 0.011157629678824117, 0.04213770319308553, 0.04457804760230439, 0.06150979655129569, 0.048789059676762135, 0.015743211743288806, 0.054343961245779476, 0.034852279483207634, 0.04196635274482625, 0.06971265388918774, 0.009407911782285996, 0.0663182417462979, 0.029277255958212272, 0.025250267669824616, 0.025613709685525725, 0.025317152562950338, 0.06759055597441536, 0.008235728966870477, 0.01400707387698016, 0.06353091488459281, 0.0327920096793345, 0.07096276645149503, 0.10441623920840876, 0.04614884259977511, 0.03751169231587222, 0.03090763311567051, 0.03224815368386252, 0.032382747890161614, 0.0861511757331235, 0.049380257060485225, 0.034779638916786225, 0.06646344824028866, 0.09643958508968353, 0.07039857136883906, 0.0659328813531569, 0.020455120064850365, 0.04220244221921478, 0.041968608873763254, 0.030675048274653297, 0.05203955793487174, 0.0057247672978389475, 0.08346308461789574, 0.02170319702210171, 0.05496605232890163, 0.04342641082725354, 0.06475495813148362, 0.02822033758275211, 0.03796040073835424, 0.02399284898170403, 0.038758446129837205, 0.044292767731738944, 0.033293379204613824, 0.029209826540734087, 0.05073543059240494, 0.031562667073948045, 0.017750893386879137, 0.02599725330115429, 0.06455186581505196, 0.058937443154198785, 0.03696982103532978, 0.04271357925608754, 0.010961371058199023, 0.054715608446193595, 0.0361609428322741, 0.05279475383992706, 0.04955044721386262, 0.03804809460416436, 0.00946916822743203, 0.038059700945658345, 0.019929374169026102, 0.07402452001614229, 0.00843922670797578, 0.029696936652596508, 0.03822389624214598, 0.04154990866248097, 0.041684424837252924, 0.021165527569662248, 0.020802918455696533, 0.028993428152586733, 0.039995747950992415, 0.005828337186747896, 0.04809000915182488, 0.14408046512731484, 0.03499147076425808, 0.042642512890909395, 0.0356501722043114, 0.03152119840628334, 0.009929724719508417, 0.058617954940668175, 0.01423515918265496, 0.025598211945699792, 0.033403288306934495, 0.07174139217074428, 0.05309753312862345, 0.042719105923814435, 0.034031055335487635, 0.022862163671691502, 0.06556090167058365, 0.12092686896877629, 0.11832419862704617, 0.05090658765818391, 0.17729915119707584, 0.10252867692283221, 0.12705899349280766, 0.14963763978864464, 0.07278895524463483, 0.1799420179533107, 0.12492668362600462, 0.08757821630154337, 0.13828862591513566, 0.13191281232450688, 0.07608805357345513, 0.10589539805161101, 0.1557517559932811, 0.1148869302123785, 0.27425055525132586, 0.16039119847118855, 0.13284870210502828, 0.14101421966084413, 0.12658152197088512, 0.08353889733552933, 0.15234393599842275, 0.13825263641774654, 0.18195284291037492, 0.15665332547255925, 0.0884239219927362, 0.12290053734821932, 0.12625214750213282, 0.08732249680906534, 0.17237390976931366, 0.09850465892148869, 0.22816204120005878, 0.13754332305065223, 0.20833851849394186, 0.06630814514522042, 0.10180862913174288, 0.18655763939023018, 0.07715129759162664, 0.14821886377675192, 0.19041907361575536, 0.18581754767468997, 0.12102053394275052, 0.13737649843096733, 0.1356456641639982, 0.11905948631465435, 0.1389381739177874, 0.08747911626206976, 0.17731418753308908, 0.1298700419387647, 0.1837229507842234, 0.17175211384892464, 0.15249444863625936, 0.06256680483264582, 0.11204861822937216, 0.17208093191896165, 0.20131669885345868, 0.1252523532935551, 0.11846636528415339, 0.10097749158740044, 0.06368591263890266, 0.092021982850773, 0.19414831564894744, 0.1678443628230265, 0.08724491311503307, 0.08595666688467775, 0.16916950100234576, 0.1515475937298366, 0.13876991080386297, 0.08807446967278208, 0.11864942046148436, 0.1429884580097028, 0.18614812993577548, 0.11496910080313683, 0.12405997727598463, 0.17697793271924767, 0.09611629708004849, 0.11473710968026093, 0.17075947139944347, 0.09736649106655802, 0.13306302417601856, 0.1445420996419021, 0.10952272412500211, 0.08586821305964674, 0.203242530514087, 0.09199244622141123, 0.23857839511973516, 0.07094433744038854, 0.14107002238077776, 0.19170795088367804, 0.10843672204230513, 0.27527682589633123, 0.1208281149821622, 0.19742896461061069, 0.11591017459120069, 0.08195699471980333, 0.1942031548491546, 0.07893868775240012, 0.23920327158910887, 0.13137054070830345, 0.12525383249989577, 0.377838778176478, 0.09559817452515874, 0.18485324084758759, 0.12761244736611843, 0.16958945989608765, 0.2712702937424183, 0.09813327634973185, 0.19037202399756226, 0.08613665508372442, 0.13501316096101487, 0.180856764582651, 0.0779367018757122, 0.12887891940772533, 0.08584363652127129, 0.09783266498042004, 0.08967481487031494, 0.12477188264685017, 0.1444561428257397, 0.1887314756001745, 0.1580239390688283, 0.10281767855797495, 0.15715827766273702, 0.1964258998632431, 0.09885384661278554, 0.10043419538331883, 0.2148298051740442, 0.1326457115688494, 0.14876345598271914, 0.12527076873396123, 0.12059947582227842, 0.10009534178035599, 0.09616482590458222, 0.10100169493151562, 0.1196856927126646, 0.13367324428898947, 0.1450226517128093, 0.1595050860196352, 0.11857129393943719, 0.11004015457417284, 0.10876398626714945, 0.12130215311689035, 0.13332906418613025, 0.11430538498929568, 0.0720680999968733, 0.15674085648996489, 0.08241507371089288, 0.15426881771002496, 0.062039589908506186, 0.07983045918600899, 0.13983890201364244, 0.13585583360067435, 0.11175950802862644, 0.07380852196365595, 0.08302554488182068, 0.09617614386869328, 0.16612525364117964, 0.07974830216595105, 0.11307450210941689, 0.3317887234900679, 0.13321247829922608, 0.10714558525277035, 0.12867860229951994, 0.10313599290592329, 0.1172546645892518, 0.19898271480841295, 0.08677160779812507, 0.08307110850832292, 0.0748670840901988, 0.12579412279384478, 0.11671263724565506, 0.17241350907300199, 0.13468418004257338, 0.1303355169615575, 0.14187076155628475], [0.049885216036013195, 0.008268988208978303, 0.011659833802176374, 0.010712880508175917, 0.03185802658221551, 0.03718044509046844, 0.05252744496933051, 0.045224518448646576, 0.015852047063942467, 0.02563694442090179, 0.0686666446604899, 0.06499764296625342, 0.02548649624389197, 0.04881606876317944, 0.03222763478489859, 0.07940956391394138, 0.03699896750705583, 0.08406915209655251, 0.052255579736083746, 0.008976200662021126, 0.006087770810284252, 0.014621065796485968, 0.04507913553555097, 0.04500276641920209, 0.04425167904368468, 0.03381007005061422, 0.013704523593852562, 0.055724783401404104, 0.030882649456283877, 0.046125287256602726, 0.019462268965850984, 0.002566246157844684, 0.030925553225513016, 0.01269327147331621, 0.03266910323873162, 0.02459025496084775, 0.047642922428037436, 0.01252265808372093, 0.06919113865920476, 0.04922159182439957, 0.0203476163691708, 0.047148613059627156, 0.017738615295716693, 0.05821343271860054, 0.015929983596184423, 0.04748166858085564, 0.047147038858383894, 0.0518026202917099, 0.041283034054296355, 0.03660120349377394, 0.00399066079574238, 0.03293179467852626, 0.07838682165103299, 0.014042178734338709, 0.026840078611192957, 0.02019146510532924, 0.08257474657148123, 0.05222067928739956, 0.020044343446248343, 0.02627885720825621, 0.07430856156029872, 0.005338553646912, 0.03229278093203902, 0.023193154750125747, 0.0492204722416188, 0.032308482232370546, 0.017876656459910528, 0.054836570883968046, 0.00530335125014452, 0.03220747550949454, 0.09703762549906969, 0.04845895239018968, 0.023500129081574932, 0.023538222037521855, 0.04607412910887173, 0.025290570953594785, 0.023469533937584077, 0.009433755484808768, 0.02658440831250378, 0.03948139126545616, 0.01906770424518202, 0.041827317526830096, 0.06418477158461298, 0.02466346210400973, 0.026509725355676243, 0.057684426462011676, 0.038959699616368325, 0.028043238246547322, 0.017434955607833605, 0.027722599916160107, 0.04483065601172192, 0.09365771364952837, 0.06058797958706107, 0.031212895842535154, 0.009498702312287475, 0.04571917386991637, 0.006211698022005814, 0.04539948209588017, 0.014363605861685105, 0.019814608452309455, 0.05588973526443754, 0.029002418741583824, 0.03875798133334943, 0.08760592088635479, 0.0263451297235276, 0.027426305725904446, 0.056646060930298905, 0.05245839724583285, 0.037585832444684844, 0.004607250656200839, 0.015712669185761894, 0.04616138192691973, 0.01894500306142228, 0.04035823153597968, 0.07372165591056858, 0.03526333939017994, 0.006695679663347879, 0.025697775085323622, 0.0660987560238157, 0.02847928859825645, 0.013336146932228335, 0.024080446156273996, 0.025054932704993656, 0.032728536121015034, 0.0180138002615422, 0.027951673338455812, 0.03172438232494252, 0.03721679421141744, 0.0402909480035305, 0.032862394116818905, 0.031140126354460205, 0.009768241866757827, 0.064473528947149, 0.04590525192075542, 0.042942567861505916, 0.06383561103471688, 0.011993560224904545, 0.08072269880878073, 0.06076737067529133, 0.0020884845622016913, 0.07994834786014897, 0.025981928587758114, 0.028317999127986174, 0.048970618684376986, 0.014302106840269906, 0.018699867018897618, 0.009205901729209083, 0.04653497991551246, 0.014044078632390924, 0.047827195575726886, 0.01829932101203927, 0.04826574972165482, 0.01723516097159258, 0.015315917885995336, 0.05347012349271348, 0.014187929752681936, 0.013561895532932664, 0.010016126824276788, 0.07282884631838117, 0.042556070922208686, 0.04070874237056289, 0.0584427843402539, 0.02732945672635521, 0.045686349738389254, 0.005541896173131785, 0.040583335528416295, 0.005553394373107169, 0.04267638875171542, 0.03669240538563047, 0.024787296441250613, 0.05013857422662633, 0.050339753074305396, 0.038195760787597725, 0.02609169519772487, 0.05204624489748052, 0.022639597400224636, 0.007839608704671264, 0.03571004952703204, 0.03922008742977466, 0.06047246578548636, 0.024663882795721292, 0.04134133717577372, 0.019528214087975875, 0.030161251380507435, 0.01745719289673226, 0.05473617484260883, 0.008226666283527655, 0.0805148296058178, 0.09434280331645693, 0.025105419103056192, 0.10023699275084905, 0.003482743619575298, 0.006029284484351852, 0.05893035924860409, 0.11591349941279207, 0.044491877047611136, 0.020343502750620246, 0.04107245071125882, 0.037398855334946086, 0.013905085822833436, 0.014137031144595571, 0.07359062401311738, 0.005219578892657799, 0.02774009424527841, 0.032752820889332464, 0.038495697014565976, 0.019615032643611943, 0.04914282747943487, 0.02499039384669491, 0.02672397448415203, 0.04577954313052552, 0.03878357906692794, 0.021680247271433473, 0.06127344923360007, 0.02360019094443747, 0.0278218305736248, 0.028942052873649766, 0.005731830847383077, 0.03462660552135535, 0.05451709624113781, 0.03836288735536592, 0.010770365146787038, 0.04704634765429156, 0.031360287219285965, 0.03194304023470197, 0.057454335237188, 0.014240258373320103, 0.02939743808071528, 0.04183933777468545, 0.02984975291682141, 0.03847482188471726, 0.045795061226402006, 0.071449751034379, 0.04642314377373882, 0.053657918237149715, 0.034630788689745326, 0.06281132171196596, 0.017797208490914533, 0.050897871875869374, 0.01156685414857098, 0.04702518414705992, 0.02092231178124036, 0.008820844132320156, 0.04161130251096828, 0.04620594810694456, 0.02061958677534546, 0.024875914811023643, 0.020186155568808317, 0.03177637167807136, 0.0031332370168196833, 0.013635613273696175, 0.01379341252946428, 0.02789523618827973, 0.017768565831439834, 0.0343089493523751, 0.024661457033029625, 0.02824842045083642, 0.04542673545490418, 0.0868094429107649, 0.028625689313880036, 0.035483853093215396, 0.04557983670383692, 0.014218656362832656, 0.009867611623901342, 0.05763167714966195, 0.025873693770595958, 0.01677609301571335, 0.038445712732417245, 0.024415309973327175, 0.04485359049535223, 0.03080880449020437, 0.05210508406162262, 0.01987622112834028, 0.02874371030234865, 0.0267093283057745, 0.03101450577378273, 0.02675929053553513, 0.037734879446881156, 0.04731878624962909, 0.05146567337214947, 0.050971509888768196, 0.022403575779337968, 0.022403121160875474, 0.022449210652017167, 0.10663036682776042, 0.002726586951342012, 0.07978214070733104, 0.014008967837850963, 0.0506535212376288, 0.04288153363657849, 0.036277932447514365, 0.03087162326223084, 0.048649376457823176, 0.00992395038649972, 0.027629660974655832, 0.03827517991885543, 0.04550023436812418, 0.03425230524901833, 0.05049118173441716, 0.07002001668193511, 0.05068150402179786, 0.018917613995394537, 0.06120898840682847, 0.0730675413672413, 0.044765693069036515, 0.0383348842151463, 0.004848719216949705, 0.06995147107435123, 0.04679811918841941, 0.020409352877842526, 0.0083033034212089, 0.021576258387150507, 0.07755271212330886, 0.035510977530585866, 0.02806565534722592, 0.08831521389739853, 0.031972098496875594, 0.04454943717324308, 0.05337154253252915, 0.0580478837447507, 0.005543391070594745, 0.027941425763336674, 0.03388797604878034, 0.0440933327190578, 0.044962966947683265, 0.032659210198159726, 0.0371322216066931, 0.011050191292140101, 0.020479862844305377, 0.042573220894805024, 0.05951577890664339, 0.025835454929620028, 0.049014323124928136, 0.0091147490311414, 0.014214222984654563, 0.04020784103444644, 0.014790524828380771, 0.02164604401748095, 0.045766230273459635, 0.061374700229082785, 0.021975516873810972, 0.025905959807070236, 0.05560347830344524, 0.02095835216875587, 0.0017843602898730232, 0.028067324543371797, 0.02270444159928177, 0.03883423509874514, 0.010223859472067227, 0.03862596895279629, 0.014993976768372315, 0.03136245853134564, 0.09626898102994476, 0.12770432100764342, 0.08772025403699704, 0.11966532309140478, 0.13212500379553863, 0.167750032884734, 0.13038810342550278, 0.10700065695813724, 0.12125561918531146, 0.11264765608523573, 0.1864179697419916, 0.17432623143707002, 0.11241425360952105, 0.17142146373433725, 0.13944802513079985, 0.20103350547807558, 0.08087712659367494, 0.136223097464868, 0.2121822836675814, 0.11728017750595297, 0.12169300285833222, 0.132923938067896, 0.16022980213165283, 0.05990351417234965, 0.11888404430023261, 0.1178317450519119, 0.083217454941145, 0.0969979108444282, 0.19076387797083172, 0.11113326091851507, 0.08281344162034136, 0.1740353163331747, 0.11598564125597477, 0.09210525945361171, 0.13286243565380573, 0.1808713259441512, 0.14858468914670603, 0.11102662914033447, 0.1380991925086294, 0.13717588276735374, 0.09914117226643221, 0.10962191237402813, 0.16700136448655808, 0.10467244046075003, 0.08311792063925948, 0.0736172225858484, 0.15228555484541825, 0.1698602225099291, 0.08104048389941454, 0.0819797052868775, 0.05604761000722647, 0.15096205872084412, 0.1550802777388266, 0.06653478262679917, 0.046291602975023646, 0.09223990794271231, 0.20368995650538377, 0.18016555452985422, 0.12538978377623217, 0.13483290134796075, 0.15487812858607086, 0.049743330970938714, 0.19633093210203306, 0.08357741098318781, 0.19653838739863463, 0.10879889010850873, 0.08010117430239916, 0.1445077657699585, 0.0967494584619999, 0.11999214626848698, 0.11020438040473632, 0.08888493225510631, 0.11574598268738814, 0.08932553218411547, 0.12200629604714257, 0.05953317654452153, 0.09415961921747242, 0.10532265342772007, 0.1987220895077501, 0.11942561024001666, 0.1597379863794361, 0.12841704062053136, 0.21417059483272688, 0.10674883225666625, 0.1626410713153226, 0.1491228352699961, 0.16575729767126696, 0.0987803205581648, 0.1814018724752324, 0.16299894425485814, 0.09019310705895935, 0.17776203421609743, 0.14638361654111318, 0.16113435716501304, 0.0652670417247074, 0.12951849294560297, 0.09411269173558269, 0.08196377328463963, 0.16887332046670572, 0.10198360974235193, 0.09189511037298612, 0.11696529654519898, 0.12915247758584364, 0.14286780091268675, 0.1367838116628783, 0.10416021437517234, 0.11949324661067554, 0.09581844734826259, 0.21237228704350336, 0.042265932740909715, 0.2022672314196825, 0.23173116253955023, 0.11602389706032616, 0.11615973977105958, 0.14864630012639932, 0.18586204600121292, 0.11701381179903235, 0.0935126089357904, 0.1467860692313739, 0.14843809844127723, 0.10990242553608758, 0.10288238365735326, 0.14227269855993135, 0.13553848277245248, 0.14314814444099153, 0.11160455777176789, 0.12727453692683152, 0.20016420712428434, 0.10148198237376553, 0.09926837722637824, 0.19462405012122222, 0.09316131778593574, 0.13458553462156228, 0.14588831311890058, 0.16175681804972036, 0.09677201296601977, 0.12966071388551167, 0.21330310138208525, 0.16682102344930172, 0.24102736370904104, 0.18027078174054623, 0.11481725823666368, 0.14888530730136804, 0.12259560371083872, 0.14803797991148063, 0.10610227659344673, 0.09427914994635753, 0.07982157716261488, 0.15295190337513173, 0.11596254392393998, 0.11863438412547112, 0.11915521403508526, 0.15285404505474226, 0.04055728996172547, 0.20440963788756303, 0.1493019006614174, 0.08176609567765679, 0.07578676366912467, 0.12572104457233632, 0.10109084086226565, 0.08215636866433279, 0.12415463291108608, 0.17556295650345938, 0.1543196671243225, 0.11409320708896432, 0.1498718157942806, 0.07981631851622037, 0.088832379717912, 0.19168766268662044, 0.18128155464572565, 0.1761756329131978, 0.17659298623246805, 0.11588981854064123, 0.21306276427847998, 0.11183444543608598, 0.07676160814506666], [0.09736081172845193, 0.035017224560890875, 0.060537917273385186, 0.03973281563126615, 0.037014807907066176, 0.009784497021298324, 0.05904254822858742, 0.04621322200234447, 0.041244045432124815, 0.02219239532548402, 0.0655528949573636, 0.04180075966620019, 0.027380075438746383, 0.04349330759474209, 0.03989690236215081, 0.0187961901538074, 0.054273359677089114, 0.017378567651446377, 0.02421119815803, 0.008769699555289532, 0.03477220556565693, 0.014472271548584104, 0.02690355895486261, 0.024091521544115882, 0.05711585482848542, 0.02007163582103593, 0.05326510752950396, 0.044022649726165194, 0.036748465948871205, 0.03556592868907111, 0.07561761845967599, 0.0481469823446657, 0.04335382793630872, 0.009609797154553235, 0.06141964638871806, 0.053222044304545434, 0.049774126282760074, 0.050503008599792204, 0.034079957354281626, 0.02197825306627367, 0.05090883021642055, 0.024665392536137785, 0.03490088294659342, 0.051127338848475895, 0.10786667120243822, 0.03687592875212431, 0.03362664846437318, 0.01923244576235967, 0.04152229228722198, 0.016125333828053305, 0.014108667532647294, 0.05076205291386161, 0.04903677245602012, 0.01694340618061168, 0.03200805067483868, 0.053398219136787314, 0.031704562317047796, 0.03763074128489409, 0.020919612908203686, 0.013146867044270039, 0.06854606898767607, 0.012373038567602634, 0.03836900095588394, 0.011286096713904823, 0.021675869024225643, 0.022276528578783785, 0.0148383038717189, 0.06386455055326223, 0.007955673815948623, 0.045968650840222836, 0.02776800069425787, 0.053524141665548086, 0.02477658915865634, 0.02126415602729789, 0.03395148014117565, 0.028105772033865963, 0.012110572740701693, 0.0366496169673545, 0.043080181548638005, 0.017734908798177327, 0.041030629205384424, 0.024213902120079314, 0.03420119459873863, 0.013257153581694832, 0.01609133922361902, 0.021648347643869262, 0.06262387641306434, 0.048778019912008724, 0.028055684275126884, 0.04943808860012463, 0.08742612267711333, 0.017922086075746586, 0.09026678239128419, 0.025110804974766712, 0.06905939429998398, 0.029244577711714164, 0.01656480908526906, 0.03480952838435769, 0.03633316519803234, 0.06625262062464442, 0.03599141085786479, 0.007173815725504288, 0.027439929012741362, 0.0927083006660853, 0.0512958699837327, 0.0480483301383044, 0.04552755558065005, 0.052187726234218905, 0.06280353891530208, 0.047880022919603756, 0.05994904387210097, 0.02630161527278168, 0.049322154106838365, 0.01818055024237505, 0.09757939499935933, 0.021754467128110782, 0.04618523243282523, 0.006033298443071544, 0.016139561011056815, 0.026678266668958322, 0.045622391027531455, 0.03471230110153556, 0.01652889931574464, 0.013542927086486347, 0.026276986147942286, 0.04024006805515715, 0.010048201174608298, 0.03033012178327356, 0.02742867042044444, 0.04478519077279738, 0.016730442875996232, 0.04470293875783682, 0.013279003257464086, 0.05127259962526815, 0.07666957844048738, 0.01810030160205705, 0.02442056522704661, 0.028565204702317715, 0.012785162926385445, 0.006962385910030986, 0.036680795651461394, 0.06911562449697937, 0.07297421566077641, 0.05375545086073024, 0.027243418485990593, 0.02924326474645308, 0.03329512303961175, 0.03213520135198321, 0.04366952992443528, 0.0516332375950047, 0.032812535363648615, 0.018447245038779717, 0.03994036931544542, 0.04496434098109603, 0.02859440545684525, 0.06550981476902962, 0.012181652676580208, 0.05208614614925214, 0.011246460090790476, 0.003411449521081522, 0.02313758273209844, 0.03239097173458763, 0.08601229318550654, 0.02224505812461887, 0.058205677063337395, 0.024624280099357878, 0.04877588252669998, 0.01651946428631033, 0.0616653710603714, 0.04420889401808381, 0.0596880725185786, 0.03716193126248462, 0.016402664660875286, 0.01934813767937677, 0.05253015910940511, 0.04146980421085443, 0.0450687776984913, 0.028192890841247778, 0.03446232880066548, 0.07040482746171099, 0.02128988946788013, 0.04601429249825222, 0.04079586626695735, 0.016882782469370534, 0.030320160889199803, 0.04782451196972813, 0.0417355422728828, 0.03809640629749213, 0.042600481039179225, 0.021858929290569255, 0.03411509868289743, 0.021991876353110586, 0.03743993045229997, 0.038395144910152466, 0.023130924607227956, 0.028542443245117153, 0.04554356561441507, 0.027357941626438072, 0.030429808755538294, 0.05211605936554926, 0.061570572932916026, 0.10806450487247535, 0.07294737960078887, 0.03857237486434834, 0.013532878831028938, 0.023604776144825985, 0.08787853590079717, 0.019028903916478157, 0.027764229735891734, 0.0805855125987104, 0.08602006919682026, 0.012279964767263403, 0.010029484634287655, 0.037691117330853424, 0.04176983543272529, 0.06721671032054083, 0.05817369770790849, 0.01192697643169335, 0.04062555736995169, 0.044906916562467813, 0.038754028866865804, 0.0916761810492192, 0.032546705699392726, 0.01544388450149979, 0.03625325412888612, 0.01456361254011946, 0.004954986282557781, 0.043343541345426014, 0.06116556216563497, 0.06171523659889187, 0.0557319656945765, 0.02008673152886331, 0.054774966689624956, 0.020980769269434468, 0.022190561584596123, 0.06593001793537821, 0.008998031678077365, 0.024996366651196564, 0.01947379218680518, 0.06530822201498918, 0.01967972586862743, 0.0887022502720356, 0.01908113923855126, 0.025519116814913492, 0.015244900714606047, 0.028320043214729855, 0.02972793552492346, 0.07643333290304456, 0.0605380122682878, 0.01671280775086156, 0.03822090390271374, 0.03978752251714468, 0.06070532543318612, 0.06087109832359212, 0.03571572207978793, 0.02255652266155396, 0.026463337309126343, 0.015037150255271366, 0.01515366998501122, 0.045876699167170694, 0.008280592854134738, 0.033310271333903074, 0.0035977054753207733, 0.04557710560038686, 0.0523020390288106, 0.07259068052683558, 0.016850255196914077, 0.009020341061321753, 0.05237032340041228, 0.012702521601957934, 0.008902500732801855, 0.03151068789884448, 0.02036638295144907, 0.028288947651162744, 0.029999356317733015, 0.02613936397912247, 0.03043898594166551, 0.031242541037499905, 0.1311389702771391, 0.05554658653480666, 0.01894862304574677, 0.02950386969106538, 0.021382200764492154, 0.030040105738277947, 0.042540912449892075, 0.03334306493135435, 0.06991465376423937, 0.02833920843633158, 0.00893065145438803, 0.0464418849109539, 0.07190012186765671, 0.015180933522060513, 0.044570970482059886, 0.014281513302453926, 0.06389499641954899, 0.025562044332868288, 0.05628718715161085, 0.03733184660917946, 0.045179212665451426, 0.048097517141806226, 0.020051766619352356, 0.022446401517039964, 0.01884335173027856, 0.02465585572645068, 0.04388208441170199, 0.02735326312748449, 0.03839333322165268, 0.04661951180813568, 0.0049568938141289565, 0.015362197366942252, 0.01386385633876281, 0.02096401454348649, 0.06723954980926854, 0.06185888246233974, 0.004138968618852752, 0.030183826240577867, 0.07073485332408122, 0.0020980131022432552, 0.04458263449903045, 0.029751819957579886, 0.014457296280722533, 0.0322725096983569, 0.025787952389301996, 0.03820493797372494, 0.04297916464773672, 0.039052882830479314, 0.010276791988871992, 0.049335996221218786, 0.03818787621068103, 0.034836174454540014, 0.04461481402228985, 0.08710339785154377, 0.04167545799698148, 0.022814048753519143, 0.017690853215754032, 0.03814786978598152, 0.02659438786629055, 0.0456809044948646, 0.04688869682805879, 0.07324708851852588, 0.02352637142342116, 0.04788511532491871, 0.07011562226606266, 0.05872826437864985, 0.01570388046093285, 0.07927043030836753, 0.05375238048977085, 0.038755470753780434, 0.016257071401923895, 0.09422502320791994, 0.06543648548956428, 0.015084885193833282, 0.19624535526548112, 0.13138077301638468, 0.09931984410754272, 0.06987103753324066, 0.15649230911263398, 0.17266152719301836, 0.11000165449721472, 0.13116432034543582, 0.16066481093210833, 0.10357714244829756, 0.248559048133237, 0.07201933368508305, 0.13737723124878748, 0.14023767704410212, 0.11863769537636212, 0.05953603996230023, 0.17913699043648584, 0.0930805110505649, 0.11549332338784422, 0.09203064095761095, 0.15058794165296213, 0.13656023437423365, 0.124945872596332, 0.09567805845290422, 0.12081117874809674, 0.15465012724910462, 0.3071293224181448, 0.08621022185044629, 0.18114947101899556, 0.09295782513384308, 0.20151598458843573, 0.12864908602620873, 0.12869903977428163, 0.12179125472903252, 0.16649829862373217, 0.06920918090535061, 0.16103313331093105, 0.09920292573847941, 0.162980854511261, 0.14514613151550293, 0.11622620906148638, 0.0898215752094984, 0.10700919971402202, 0.1364507188222238, 0.11914528028241225, 0.12593684584966727, 0.18237619447921002, 0.14284193515777588, 0.12099352824900832, 0.14956169814935752, 0.13336225811924252, 0.12743590612496647, 0.09515344231788601, 0.18603607666279587, 0.11569556753550257, 0.12081740769956793, 0.092651018739811, 0.16153900830873422, 0.22015530083860668, 0.12410857395402022, 0.23539408456001962, 0.11303009199244635, 0.09403694008610078, 0.09622534444289547, 0.08647879279617753, 0.16789207740553788, 0.0912956925375121, 0.09552342032215425, 0.08161613265318529, 0.15567060320505074, 0.053657802886196544, 0.10782532127840178, 0.1682349004383598, 0.06979000688131366, 0.11776131311697619, 0.16277204214462213, 0.12472164391406945, 0.11695393786898681, 0.1124473593330809, 0.07620501943996974, 0.18405125316764626, 0.06873208257768836, 0.11786343263728277, 0.1515200316373791, 0.09141750314405986, 0.20387687933232101, 0.1289021795881646, 0.16850874360118592, 0.09274108747818641, 0.1492821688630751, 0.13300984060125692, 0.06554925122431346, 0.1126879882067442, 0.13984557879822596, 0.10863319864230496, 0.12721061892807484, 0.15905143107686723, 0.12451432432447161, 0.1406823753246239, 0.10215757255043302, 0.1083758913778833, 0.10761573538184166, 0.16678333761436598, 0.23119221574493817, 0.13940102979540825, 0.14226235768624715, 0.20936742185481957, 0.16096792609563895, 0.25426094074334415, 0.17041538629148686, 0.11746864739273276, 0.10835365578532219, 0.14093677167381558, 0.11466982614781175, 0.24001547800643103, 0.12228418327867985, 0.1368365338338273, 0.13676678043391022, 0.0844842866063118, 0.1302444575620549, 0.1750235075929335, 0.1561503003218344, 0.09614864962973765, 0.22082303357975824, 0.14785472117364407, 0.0786599184253386, 0.07324571109243802, 0.1459353898784944, 0.13931097462773323, 0.15311457536050252, 0.09823384202484574, 0.25781518859522684, 0.13364095959280217, 0.08075342965977532, 0.15650259570351668, 0.0808754845389298, 0.11835386417806149, 0.1207348842705999, 0.0697819594559925, 0.08532179559447936, 0.14424727617629937, 0.12965806759893894, 0.20240667036601476, 0.0930344249520983, 0.11183766847742455, 0.1292352724288191, 0.16793582934354032, 0.15535516584558146, 0.08534621606980052, 0.13323652558028698, 0.08551664371043444, 0.1364480046821492, 0.1461469435266086, 0.08302557880857162, 0.051844306090580564, 0.20508355886808463, 0.07884249184280634, 0.1120341382920742, 0.11894682236015797, 0.0926372716203332, 0.1273355915078095, 0.12644976404096397, 0.11718915881855146, 0.23805809446743556, 0.11733978002199105, 0.30601226378764423, 0.2001233593161617, 0.15580362321010657, 0.13651812449097633, 0.13878193444439343, 0.1366765759885311, 0.10208257407482181, 0.0682661190096821, 0.10006142181477376, 0.15543118890907082, 0.14892228745988437], [0.056419586297124624, 0.06756862572261266, 0.024524019765002385, 0.01797955629548856, 0.005392518809198269, 0.03732591960579157, 0.014366325090772339, 0.014714084465854933, 0.09562660514244012, 0.009547531388566961, 0.015955214920852865, 0.042718651305351935, 0.05017556456316795, 0.021362094075552056, 0.032148212260965786, 0.05345955530979803, 0.0491904029622674, 0.027528265790481652, 0.09823688186172928, 0.02772220127683665, 0.05169359328491347, 0.03720900462940335, 0.016008792045925344, 0.004766901040316692, 0.03429786887552057, 0.020907711403976594, 0.061635135539940426, 0.06204929295927286, 0.06766466556915215, 0.052985191478260925, 0.015504280903509684, 0.04750916621248637, 0.0628552839958242, 0.04852939789582576, 0.01888669315459473, 0.050309612548777034, 0.07307581270911864, 0.05401941794635994, 0.023950289568996856, 0.044063507712313106, 0.020321151807105968, 0.04748541748683367, 0.03113328672147223, 0.03316079006929483, 0.06044727178024394, 0.041506163509828706, 0.03114246390759945, 0.06111626659653016, 0.027262965383540307, 0.022667844813050966, 0.013322767917998135, 0.027715387088911872, 0.031669597407536845, 0.010346679399455232, 0.02147337212227285, 0.033134177925863435, 0.034814471511968544, 0.021882282769573585, 0.04144850838929415, 0.058059982024133205, 0.03562964991267238, 0.02748941457165139, 0.01576088079517441, 0.048587914755834, 0.022467028981606876, 0.011436831571960022, 0.013509270053223839, 0.05908294141824756, 0.029326972219028642, 0.007764280291407236, 0.008469515663039471, 0.025023424931402718, 0.02085866350015359, 0.02930029561477048, 0.036933295495275936, 0.023423778624939065, 0.06503591234130518, 0.01864739760224308, 0.03730977386502283, 0.035698202305606434, 0.04426611487620643, 0.014852916123345494, 0.009337931073137691, 0.03572309775544064, 0.04602109481181417, 0.06357924693397113, 0.0630522287849869, 0.10408657975494862, 0.0419867596855121, 0.0665307521287884, 0.023560172645375133, 0.09935957233288459, 0.025449621258303523, 0.016178167957280363, 0.015090106520801783, 0.03745463091347899, 0.023867906936045204, 0.03181081411561795, 0.02226121404341289, 0.06976399863404886, 0.013706757670401462, 0.020379152980500033, 0.07302471223686423, 0.09161093312182597, 0.02881017280742526, 0.013275782760631825, 0.022736665227317383, 0.04466677623401795, 0.02964180228965623, 0.03192063161571111, 0.021998317346775105, 0.013549284959611083, 0.008944746323062905, 0.07921302624578987, 0.025070454193545238, 0.013578445850206273, 0.052411842958203385, 0.06772037329418318, 0.012405051849782467, 0.0746562225478036, 0.015146679377981594, 0.022000176532726203, 0.04689389440630164, 0.026472916527252113, 0.04457119439861604, 0.023820825087438737, 0.07233969042343752, 0.032876151414322, 0.040464595292827914, 0.0806347606703639, 0.03551017346658877, 0.026933580736762712, 0.020402560742305856, 0.03927541517519525, 0.032824470794626644, 0.021992308919184973, 0.03790312559743013, 0.03357070325208562, 0.012986966026281672, 0.052709760543491156, 0.09188775505338397, 0.02217479751977537, 0.04970873586301293, 0.053786978990371735, 0.0444499741175345, 0.030858561463121856, 0.03052140080503055, 0.05541082185560039, 0.02126378961838782, 0.007265102434238153, 0.041541233592267544, 0.00650174926600552, 0.08722083869257144, 0.02904220124972718, 0.012742333796008356, 0.03572410877261843, 0.051384228813861094, 0.03240945163582053, 0.01758369557293398, 0.03342255191611392, 0.03662626179201262, 0.037973642349243164, 0.024378808181998984, 0.031528652113463194, 0.0735127485490271, 0.03205806209838816, 0.02272511656129999, 0.023877414907994013, 0.0017045961659667747, 0.03807662021634834, 0.059813499716775756, 0.08973793219774961, 0.09685661949749504, 0.060947467439941, 0.03156783411811505, 0.04830001234742148, 0.044725581471409113, 0.0426557137896972, 0.03212897240051201, 0.028309519136590616, 0.013891683059877582, 0.0688258425465652, 0.01732056138903967, 0.019365358898150067, 0.038975696079432964, 0.03424874633284552, 0.0348588239534625, 0.016952469712123275, 0.05701176755662475, 0.11847628546612603, 0.053565634081938436, 0.06203916921679463, 0.040958310943096876, 0.022058220114558935, 0.05957771558314562, 0.014265080880639809, 0.017560167371162345, 0.06295393620218549, 0.03263233003339597, 0.03386116034484335, 0.05610867137355464, 0.04627912810870579, 0.03743386774190834, 0.020655469403469136, 0.08920127206615039, 0.04903619909392936, 0.006463979462361229, 0.02797063669588949, 0.01015509758144617, 0.06584267690777779, 0.04656569380313158, 0.04142087844333478, 0.07117357371108872, 0.023802277332703983, 0.006502150449835296, 0.016921072200472866, 0.0616648689444576, 0.0923356017363923, 0.029942311878715242, 0.03814248900328364, 0.04050121922045946, 0.011351424369162746, 0.03843128029257059, 0.09354179951229266, 0.021422804300008074, 0.018624529275777083, 0.05740344511078937, 0.005162204091902822, 0.08761345941041197, 0.020029722712934017, 0.03970441894073572, 0.016248613462916443, 0.029973694123327732, 0.02666678585644279, 0.05188689434102603, 0.0550572881475091, 0.01494955986605159, 0.005324970648091818, 0.032069380062499216, 0.04093783614890916, 0.024333293749285594, 0.047461193786667924, 0.024848050770482848, 0.04721714509651065, 0.005972488982869046, 0.03438849401261125, 0.02967775786029441, 0.0594413232590471, 0.02033307875639626, 0.023544089669095616, 0.05572722952014633, 0.02642752423084208, 0.037346340117177794, 0.02225111235332276, 0.024096883667100753, 0.019284728581884077, 0.01638484124227294, 0.05220443855172821, 0.010626898246950336, 0.06782241817563772, 0.09796372401927199, 0.03332769611318197, 0.03799647505262068, 0.03588698771116989, 0.08150582321520362, 0.1422530888978924, 0.006367697463636952, 0.04278258966015918, 0.0999299217281597, 0.02112920898278909, 0.04422765551134944, 0.030576762477202073, 0.046610711208943806, 0.01762694200234754, 0.007154996556762073, 0.03501761132585151, 0.021380270332364098, 0.031464394847197194, 0.027392445132136345, 0.031124889850616455, 0.029827093239873648, 0.060798155809087415, 0.06719479363943849, 0.05784897120403392, 0.030409449312303747, 0.009585630281695297, 0.050278094597160816, 0.015500009525567293, 0.014964521563212787, 0.016261975513771176, 0.015852693368547728, 0.03902268462947436, 0.04006282113758581, 0.0465251682991428, 0.026775439668978964, 0.04893478185736707, 0.0203603439897831, 0.011719631397032311, 0.07129207985209567, 0.022365367472437874, 0.01769045796910567, 0.03784511763868587, 0.027698995379198874, 0.03649356409109064, 0.03311867679336241, 0.024507624662614295, 0.023041237544800554, 0.04118698402973158, 0.06150018171008144, 0.02887714421376586, 0.01235410150340093, 0.0520282840755369, 0.023526697120230113, 0.013582478044554591, 0.022816649238978113, 0.04485261679760047, 0.031038916071078608, 0.011730392114259303, 0.06841629916535956, 0.05393805141959872, 0.01187287429015019, 0.01889956835657358, 0.06392866532717432, 0.10270045484815325, 0.035961450144116364, 0.05119036796635815, 0.019280769330050265, 0.005691312128744487, 0.038465410604008606, 0.03613831368940217, 0.05401313131941216, 0.007895428387980376, 0.03211671466540013, 0.06018853959228311, 0.008163828851788171, 0.03948720291789089, 0.04560897299753768, 0.004619899397117219, 0.015243117863844548, 0.0519385681753712, 0.030898296473813907, 0.029356077978653566, 0.05403481051325798, 0.055883163652781925, 0.0544462130804147, 0.032655322192502875, 0.054371876176446676, 0.0718947546556592, 0.06632025699530329, 0.017176018163029636, 0.047322463909430165, 0.04180964847494449, 0.13830140951488698, 0.23749518181596482, 0.11008062240268503, 0.11889937919165407, 0.09883874920862061, 0.11403205751308373, 0.17415180722517626, 0.04709945659020117, 0.15416967017310007, 0.06251012680253812, 0.16020931037408964, 0.22828816728932516, 0.16468050330877304, 0.17059184610843658, 0.18913932942918368, 0.2295820250042847, 0.13902726556573594, 0.08274989003049475, 0.14363510188247475, 0.1476459495191063, 0.11765405030122825, 0.12430355777697903, 0.08479046874812671, 0.126791243574449, 0.22507858808551515, 0.12886038183101586, 0.24892722123435565, 0.08756016727004733, 0.1422108161662306, 0.11535062747342245, 0.13086337649396487, 0.22435646397726877, 0.15366478583642415, 0.1152005490979978, 0.18457037316901342, 0.15218648873269558, 0.11056491320154496, 0.2177962924220732, 0.09857686183282308, 0.08848093250500304, 0.08228094769375664, 0.22190786179687294, 0.0890568323167307, 0.10987238679081202, 0.13259346437241348, 0.08115920717162745, 0.06712978319930178, 0.2545809649995395, 0.22434629952268942, 0.10044524193342243, 0.16225216218403407, 0.12880023648696287, 0.1302687084036214, 0.05754515714943409, 0.07833844888955355, 0.13503100643200533, 0.07797800430229732, 0.13206751830875874, 0.19567035111997808, 0.13887046969362668, 0.07742144273860113, 0.0682670825294086, 0.16706832232219831, 0.12067315115460328, 0.06509257680071251, 0.17542399253164018, 0.12170157954096794, 0.11985519076032297, 0.09430497498916728, 0.13257128984800406, 0.09683895044560943, 0.1384506057947874, 0.08083064015954733, 0.09307597165129014, 0.09859581331589393, 0.10964955589068787, 0.20448757441980497, 0.09759430241371904, 0.12851474966321672, 0.10841416075293507, 0.2143600010978324, 0.09631982365889208, 0.07162074864442859, 0.22288415155240468, 0.18479826594037668, 0.18823272522006715, 0.26993661959256443, 0.2621884010732174, 0.25411492000733105, 0.2603113560804299, 0.1183123921177217, 0.15570553418781075, 0.17668245786002704, 0.14013106562197208, 0.14443999369229588, 0.16675610121871742, 0.14948122389614582, 0.07616017506058727, 0.0797857233722295, 0.15692472590931825, 0.08756606373935938, 0.1530473189694541, 0.18736325044717106, 0.18460546700017794, 0.16674912587872573, 0.14447037849043096, 0.12201709832463946, 0.1936776294772114, 0.07823590189218521, 0.11948214577777044, 0.14664017063166412, 0.08340644051453897, 0.07105570539299931, 0.13090183585882187, 0.08771659673324653, 0.18656636535057, 0.11735058229948793, 0.16150096963558877, 0.09189713240734168, 0.27753854596189087, 0.08656118051814181, 0.10715927808944668, 0.17386247989322456, 0.10721001893814121, 0.09814135770180396, 0.08468758248324905, 0.1807050441524812, 0.08144024959100143, 0.2336292149765151, 0.1746464999658721, 0.128281455753105, 0.07353222250406231, 0.16766984361623014, 0.13434888874845846, 0.10499200331313269, 0.1517035753599235, 0.06369358008461339, 0.08774632335241352, 0.16741284169256687, 0.14265949066196168, 0.1802293775337083, 0.06644323468208313, 0.12383070029318333, 0.10904887598007917, 0.1487928365490266, 0.13793850184551307, 0.1444396408540862, 0.17709928192198277, 0.14131335860916547, 0.1633683658604111, 0.14399059994944505, 0.08912797671343599, 0.18005403051418917, 0.15504914655217103, 0.13792544683175428, 0.10913417461727347, 0.135168531909585, 0.11628537731511251, 0.17317680668617996, 0.24556206752146992, 0.09679380751081876, 0.11492534886513438, 0.16870296746492386, 0.12929904114987167, 0.12117680055754525, 0.17169295916599886, 0.09205104450562171, 0.16097049095800944, 0.07307327498814889, 0.13778318517974444, 0.16154951203082288, 0.20972598690007413, 0.20832432354135172, 0.0870533287525177, 0.14841394259461335, 0.13590113259851933], [0.061441617352621894, 0.04739588139844792, 0.01323735901886331, 0.024565211929646984, 0.06456730248672621, 0.0177558076767517, 0.012176448312987174, 0.05157122627965041, 0.053145084862730334, 0.013945960772356816, 0.03963784108470593, 0.02738149357693536, 0.02206924121959933, 0.03291063456396971, 0.015453675761818886, 0.03602084909964885, 0.016268443648836443, 0.03755952224933675, 0.029692770447582006, 0.05386320222169161, 0.03386908902653626, 0.09037509693631104, 0.024213589993970733, 0.001745111809993562, 0.04598830121436289, 0.0047624825050921315, 0.023856948595494032, 0.024363575070830326, 0.032683566212654114, 0.013383183827889817, 0.022562670188822916, 0.11169822274574212, 0.04186330023886902, 0.015240804059430957, 0.05800098340426173, 0.051609600827630074, 0.04596789427367704, 0.017571062947224294, 0.01831578227159168, 0.06243447693330901, 0.019655222272766486, 0.04979247726233942, 0.019585058359163146, 0.038219143104340346, 0.04134440415405801, 0.02783091106851186, 0.03262885932677558, 0.03694616051922951, 0.037233998466815264, 0.020250650322330848, 0.02668220386840403, 0.02027755762849535, 0.016103912477514574, 0.01811321751613702, 0.01547692746057042, 0.05799077145223107, 0.04654852347448468, 0.043990548234432936, 0.056831714896751304, 0.016240884949054037, 0.03459812401394759, 0.06912575502480779, 0.04887946089729667, 0.04391890172181385, 0.07984358205326966, 0.07631381574485983, 0.03504861359085355, 0.022204481730503694, 0.028314107729654227, 0.04431703214400581, 0.03175450927977051, 0.06331224340413298, 0.04224579382155623, 0.058610504626163414, 0.08825695488069739, 0.01490200643560716, 0.029957270183201348, 0.03757183087457504, 0.0563358075783721, 0.017824521221752678, 0.03872212075761386, 0.029299752786755562, 0.02845189953222871, 0.11991282552480698, 0.020802821764456372, 0.033826544880867004, 0.051085344316171746, 0.03319683724216052, 0.026771142845973372, 0.01600943156518042, 0.07041575866086142, 0.07807483803480864, 0.027008887945807407, 0.02316843911207148, 0.042105757764407566, 0.021011335575687032, 0.04709435061418584, 0.031022220716944764, 0.017119072111589567, 0.01504333849464144, 0.021730825271723524, 0.05260521186781781, 0.028937374374696186, 0.023027758446655104, 0.060009067079850605, 0.018158774357289076, 0.010425276655171598, 0.018994632809023772, 0.013016076874919236, 0.022529435543609515, 0.074781330834542, 0.028187333639445047, 0.0372410077335579, 0.022697603662631342, 0.028211006029908146, 0.004551143443677574, 0.0538211330505354, 0.02206861018203199, 0.041800729132124355, 0.02800923685676285, 0.04479801169197474, 0.02716897301641958, 0.05349111397351537, 0.027535741550049612, 0.029115632309445312, 0.01098764393412109, 0.029534617505435432, 0.04779851050781352, 0.015927802106099467, 0.012393537110516002, 0.03464729744674904, 0.018385232027087892, 0.03473297267087868, 0.04011250347165125, 0.039256344948496134, 0.04093235697863357, 0.017517394219924296, 0.05301910126581788, 0.03829747997224331, 0.030543863706822907, 0.03782608812408788, 0.03353569423779845, 0.009956973837688565, 0.027375463096957122, 0.0213794917134302, 0.023605598868536096, 0.08615952171385288, 0.040432609152048826, 0.014105832952606891, 0.03373594009982688, 0.062016071884759834, 0.038081902611468516, 0.06799902048494134, 0.030570380855351686, 0.005377890866449369, 0.1154995116272143, 0.026681786569367563, 0.024733447902170674, 0.04397850423785193, 0.02809331413092358, 0.07684316126895802, 0.041257592383772135, 0.04421389142849615, 0.017400185777140514, 0.07758775167167187, 0.02654054950523589, 0.04850826492266996, 0.03620693732851318, 0.03418608023119824, 0.049463771150580475, 0.02871922536620072, 0.050369177745389085, 0.035141572888408384, 0.03920439970014351, 0.04937025884698544, 0.10048053253974233, 0.018217733961396983, 0.04776910958545549, 0.051760106680116484, 0.01935508248529264, 0.024781896998839717, 0.05235029983201197, 0.014699765680623906, 0.09274243776287351, 0.022812476248613427, 0.049486461361604075, 0.04579058628795402, 0.03316151270908969, 0.03393001129318561, 0.04133117950654455, 0.02255876861246569, 0.05635166494175792, 0.01343623678466039, 0.08100447404597487, 0.044817648495414426, 0.02203533991373011, 0.07251403321112905, 0.05565354400979621, 0.07004488499036857, 0.036838785745203495, 0.026109318448496715, 0.06677951663732529, 0.008151285283799683, 0.083988684628691, 0.027470978775194714, 0.05165193462744355, 0.02994158923892038, 0.0031859636406547254, 0.04307835289676275, 0.032759748731872866, 0.05058322161702173, 0.046104110178670714, 0.07284169777163438, 0.033698064275085926, 0.04900429437735251, 0.00766088512526559, 0.03391758392431906, 0.007540540154358106, 0.05376981544707503, 0.03507034706750086, 0.012892133972075368, 0.07711642089166812, 0.03493157308548689, 0.045655992081654925, 0.04775392736441322, 0.025681363019560064, 0.01164437338177647, 0.06245630540485893, 0.015267531553815519, 0.04139442575563278, 0.038751372402267795, 0.04651602503976651, 0.014249364313270365, 0.04379291133955121, 0.08019815731261458, 0.05754511643733297, 0.03420070266085012, 0.04749274566503508, 0.013291480668288256, 0.03597847119505916, 0.03937726667416947, 0.01174586610535958, 0.013464040605218282, 0.009315881229537939, 0.0456685551575252, 0.013476285617798567, 0.015677205553012233, 0.038291295125548325, 0.00848965797506805, 0.046111017665160556, 0.02802501109960888, 0.039165913193885765, 0.017747414198571017, 0.029961806189801012, 0.020824841922149062, 0.018738421378657222, 0.03868979534932545, 0.018230624430413758, 0.021367049077525735, 0.043424025776662996, 0.08719242164599043, 0.018284118434946452, 0.01718289850811873, 0.028371069048132216, 0.021326817039932524, 0.055960503074207475, 0.03255192024101104, 0.050709710722523074, 0.05261146456801465, 0.08376484949673925, 0.004166541313419917, 0.045002216805836985, 0.05050286950011339, 0.04760352668485471, 0.014274656706090485, 0.057280664199164937, 0.03696920696113791, 0.05435533688536712, 0.055465650877782276, 0.021502701798453927, 0.04621188868103283, 0.03134398541546293, 0.07160090828048331, 0.03177069573264037, 0.06645271381629364, 0.023681547293173413, 0.053434826101043394, 0.04703602374398282, 0.01963981443883053, 0.013640172180852719, 0.01933136090104069, 0.06484799885324069, 0.049696793646684716, 0.03613999306357332, 0.019077254625569497, 0.0026229288528806394, 0.03927987315026777, 0.03405729767733386, 0.10433068272790738, 0.0519108059150832, 0.05341468718168991, 0.027814483735710382, 0.042486083427710195, 0.03606149673994098, 0.014523290596636278, 0.0016679269673269509, 0.024345212216888155, 0.04509315746171134, 0.07051580186401095, 0.02800334886913853, 0.03504105131807072, 0.0215017365823899, 0.02749636785925499, 0.00818160901378308, 0.018162947347653762, 0.02018629466848714, 0.039928287999438386, 0.049265035028968535, 0.026574533931644898, 0.00969995919149369, 0.03586196333968213, 0.04460635269060731, 0.032063595551465235, 0.007598520971701613, 0.01336126884312502, 0.061979783831962516, 0.031289811179574044, 0.010971577921217042, 0.03475185290777257, 0.016911962867847512, 0.027551069656120877, 0.06016502156853676, 0.08672776086522, 0.07734290231019258, 0.052968468982726336, 0.013715996772849133, 0.05264480099348085, 0.014564623557297247, 0.07284817099571228, 0.014969122030639222, 0.01623693248257041, 0.020634894525366168, 0.028836113201188188, 0.008051707725306707, 0.037520584517291615, 0.0096553981004815, 0.07414297865969793, 0.02011410193517804, 0.01690789674674826, 0.05209501799462097, 0.05492292803579143, 0.15689123342079775, 0.21579773537814617, 0.13289200620991842, 0.17539930742766174, 0.09949808847159147, 0.15496067915643963, 0.16409975875701222, 0.09874209868056433, 0.11710020287760667, 0.10702991538814136, 0.10590186449033873, 0.08430604902761323, 0.11271075984197003, 0.07560625299811363, 0.17212809010275773, 0.07866638486406632, 0.12445598388356821, 0.10182927016701017, 0.17355819764946187, 0.14857660100928374, 0.10038672507341419, 0.14678279869258404, 0.16506531408854894, 0.2299487053283623, 0.1246028867151056, 0.12552283092268876, 0.1363570402775492, 0.13049985814307416, 0.1278829657073532, 0.15897345383252415, 0.10272492282092571, 0.11338941021157162, 0.13941302629453795, 0.12716228009334632, 0.0772755712802921, 0.1344182893101658, 0.145926351792046, 0.19293882697820663, 0.07857297094804899, 0.12934017394270214, 0.1794684547930956, 0.11664086181138243, 0.19805088266730309, 0.11868266867739813, 0.1220293255256755, 0.18948684792433465, 0.16852831255112374, 0.13391489775053092, 0.1356980742088386, 0.10626450753105537, 0.09023859604660954, 0.14767254809183733, 0.15463597300861562, 0.07757720723748207, 0.11838294618896075, 0.1028003284175481, 0.16709629153566702, 0.12900744751095772, 0.10379464006317513, 0.26006241515278816, 0.11391262177910123, 0.16137332362788065, 0.16420789009758405, 0.11762806241001401, 0.10433012632919209, 0.21316701439874514, 0.11428445896932057, 0.07851017931742327, 0.05149600728015814, 0.1298511108117444, 0.09939244056918792, 0.09417534765920468, 0.18245509453117847, 0.15379882364400796, 0.21292204968631268, 0.1169035362878016, 0.09152520022221974, 0.12121364500905786, 0.06890102422663144, 0.086582072611366, 0.09527688819382872, 0.1713933316724641, 0.14171194364981993, 0.17434665534113133, 0.2695761003664562, 0.13243775415633405, 0.10712803155183792, 0.13466976795877728, 0.1375776840639966, 0.0947693439998797, 0.1969459019601345, 0.16596123815647193, 0.16346839549286024, 0.09521628144596304, 0.15163367268230232, 0.08447735197842121, 0.12806954926678113, 0.26566407456994057, 0.08743099455854722, 0.10087088016527039, 0.09915283628340278, 0.11177190486341715, 0.11899691181523459, 0.15165499225258827, 0.16015744315726416, 0.16802344178514822, 0.13675817660987377, 0.21509269678166934, 0.12215195037424564, 0.15976273933691637, 0.09169912910354988, 0.1297483534685203, 0.18454471097460814, 0.14132231527141162, 0.0698745319885867, 0.08320960429097925, 0.08439032986227955, 0.11055250279605389, 0.11418567784130573, 0.08506406763834612, 0.08018061718238251, 0.16340477604951176, 0.10938566005123512, 0.20274869272751467, 0.12823490825082573, 0.11504766158759594, 0.2086493553859847, 0.175320868779506, 0.09830100342099156, 0.11005250391151224, 0.14407598679619177, 0.18106838608426706, 0.10019347830010311, 0.17158368788659573, 0.11741515169186251, 0.04124475110854421, 0.11315114263977323, 0.17632671552045004, 0.12302386787320886, 0.0852365783814873, 0.06634532207889215, 0.09671850369444915, 0.20029482511537416, 0.11141008963542325, 0.11507173601005759, 0.07605766877532005, 0.06917739153972693, 0.16649893644664968, 0.11499142460525036, 0.09547991265675851, 0.11175173880266291, 0.15673214410032543, 0.08045083018285887, 0.1540284806064197, 0.15731795052332537, 0.0845227934686201, 0.19908821343311242, 0.15140679771346705, 0.17113445699214935, 0.10156341336135354, 0.1071763364598155, 0.20043118351272174, 0.14842946747584002, 0.16683367134204932, 0.1342150137892791, 0.11488150193222932, 0.08810858641351972, 0.10852669578577791, 0.10255171997206551, 0.24301891827157565, 0.09048584063670465, 0.1270173992961645, 0.10921428924692528, 0.13143843492226942, 0.16130570082792214, 0.1458066175026553, 0.27479004487395287], [0.014620321104303002, 0.017817277860428606, 0.035555445323032994, 0.014675379132053681, 0.025447080144658685, 0.0333050839336855, 0.02477527449705771, 0.03747982152604631, 0.04004090784915856, 0.024088805707703744, 0.04111710849351116, 0.02642044541426003, 0.06372800895145961, 0.037218039323176653, 0.050956052861043384, 0.036298234215272326, 0.020682734636855975, 0.03241614538377949, 0.04119049884112818, 0.04023058892094663, 0.02121634644988392, 0.04844767174550465, 0.01830380952118763, 0.036771661668483696, 0.09466988433684621, 0.019520858768373728, 0.07533063885888883, 0.03461964375206402, 0.019024975198720182, 0.023905974446928928, 0.03683956266779985, 0.005617146554868668, 0.015675612692055956, 0.02947395308209317, 0.01837852131575346, 0.004068249154702893, 0.056937189772725105, 0.02694323968275317, 0.03137208355058517, 0.05975556639688356, 0.06694484169461898, 0.040983973137502155, 0.02216300627748881, 0.0424870842668627, 0.04319830092468432, 0.02190055911030088, 0.03707415257979717, 0.03082454650263701, 0.010392286282564913, 0.022673186579985277, 0.037500150435205014, 0.054794942760573964, 0.00920169141941837, 0.031246256016727005, 0.025736946911950196, 0.03286336102922048, 0.03708370974553483, 0.027858680114150047, 0.016264615014993718, 0.04989715485966631, 0.025265658540385108, 0.05727168718086822, 0.01303042789056365, 0.024647826960842525, 0.0321159275647785, 0.004239024968618261, 0.04625408338116748, 0.012466749342690622, 0.008958465452971203, 0.03606259596667119, 0.03143830178305507, 0.05834582168608904, 0.032131957954594066, 0.08033859370542423, 0.012312008583519076, 0.049800487368234565, 0.007569177724820162, 0.06543325566287551, 0.05659727765513318, 0.06194390290017639, 0.0518135141714343, 0.030150649270841053, 0.04857953484835369, 0.02979772285159145, 0.031451278765286715, 0.11791331853185381, 0.023410803339044963, 0.03894197967435632, 0.05144244711846113, 0.032315942724900584, 0.04638712713494897, 0.0213858411048672, 0.0409933403134346, 0.016972827459020273, 0.041985562071204185, 0.049516690096684864, 0.028426764898800423, 0.05874556702162538, 0.03510654691074576, 0.0009178183785739488, 0.07487550470978022, 0.012502521708873766, 0.0493334822489747, 0.009249477248106684, 0.027878257545775602, 0.03777698254478829, 0.036235293306942494, 0.07504367282880203, 0.010257483426747578, 0.03658167864861233, 0.048100828392697234, 0.0239991898914533, 0.048331269063055515, 0.05786043844584908, 0.1546298119106463, 0.01206208038742521, 0.03645688248798251, 0.030729086803538457, 0.05712840094098023, 0.031361277880413194, 0.023594394559040666, 0.03825884418828147, 0.07586324135107653, 0.01933433288442237, 0.008116743610506611, 0.026507009519264102, 0.03299416222476533, 0.02923545820106353, 0.0270388622302562, 0.0299531277269125, 0.02091964004960443, 0.03333223211978163, 0.09148125829441206, 0.037023706893835745, 0.018297840109361068, 0.04601230778332267, 0.002689405988868592, 0.037050349571342976, 0.02651965062666152, 0.08276553026267461, 0.017316792127011076, 0.06922403403690883, 0.02097847412473389, 0.0044644033436530405, 0.03320022313190358, 0.02442384764019932, 0.08319445938936301, 0.006311781513172069, 0.01610721185404275, 0.05183664203754493, 0.026305767907095805, 0.038238528849823136, 0.01746059235717569, 0.021911113722515956, 0.055635888528610976, 0.03734972939959594, 0.02639738200897617, 0.00935585712016161, 0.049071940926036665, 0.03630661412275263, 0.09770537859627179, 0.007571338010685784, 0.04834067016573889, 0.01101973355149052, 0.028133111906104853, 0.008354468354290085, 0.06937842110970191, 0.041795769041138034, 0.020132936370958174, 0.011326923317808126, 0.012241764942051044, 0.006308088586333075, 0.043130990250834396, 0.04379202924402697, 0.01865787079025592, 0.06950095096336943, 0.017836782349539653, 0.03505113095577274, 0.022126226286802973, 0.020754260709509254, 0.0290288883926613, 0.025029063557407687, 0.05780932440289429, 0.022123159308518683, 0.032358059393508096, 0.048428713477083614, 0.004090078474421586, 0.03984782053157687, 0.053137281710015874, 0.03542613351185407, 0.04006888724065252, 0.043438336080206294, 0.0258728184604219, 0.05167642974161676, 0.027178754098713398, 0.055233883671462536, 0.03192082839086652, 0.02407179992379887, 0.046378625091165304, 0.02336238308011421, 0.04133500983672483, 0.01599582184904388, 0.08127614589674131, 0.026874217404318706, 0.01416631247515657, 0.05250587773376277, 0.027850252709218433, 0.053991435162190876, 0.012518145825846918, 0.04263586324772664, 0.01915188499593309, 0.030044438184372017, 0.06332390742110354, 0.012411469942890108, 0.05296098813414574, 0.04002086392470768, 0.02734031667932868, 0.02777678263373673, 0.051443478491689475, 0.01725737620810313, 0.036458683998457024, 0.01794521733453231, 0.005925517396203109, 0.03796026503135051, 0.02776434169416981, 0.0387544834853283, 0.0324902922979423, 0.035208269488066435, 0.0564260730919029, 0.02252736601180264, 0.03883756670568671, 0.040365915945065875, 0.01237936845115785, 0.06393412753407444, 0.025548475328832865, 0.05178628456113594, 0.03714284746508513, 0.021552680991590023, 0.037185096448021274, 0.019063670354496156, 0.02141744048068566, 0.007977582015363234, 0.03910810201029692, 0.028040028775909116, 0.021168341793652092, 0.05240283201315573, 0.06015442285154547, 0.02762137945475323, 0.043689241366727014, 0.026216733934623853, 0.022073617770469615, 0.022966888766469698, 0.05994597010846649, 0.08516919985413551, 0.024056298791297843, 0.06469604093581438, 0.05313763454822557, 0.0009153966446839539, 0.02197132183105818, 0.044855286832898855, 0.039572881534695625, 0.013751814940146037, 0.038131177824522765, 0.018748811446130276, 0.009293928077178342, 0.0035960006560864194, 0.027941264611269747, 0.022376056095319133, 0.018035559183252708, 0.021338844073138068, 0.029544948201094354, 0.046144483012280295, 0.025233316168721234, 0.08842706360987254, 0.023923675729227916, 0.011766277286889297, 0.02366160854165043, 0.05894994855459247, 0.01623991464397737, 0.03666087047063878, 0.01463909786460655, 0.0365394737704524, 0.011780764857706214, 0.027950964269361327, 0.0019655908441304094, 0.05228433944284916, 0.04230737087449857, 0.005968007259070873, 0.030210621588464295, 0.0330774150788784, 0.08089007982718092, 0.009010469224969191, 0.046238432970962355, 0.03268946607464126, 0.07242120962057795, 0.05051712552085519, 0.09124000516853162, 0.02809056606409805, 0.0664919942085232, 0.04389694093593529, 0.02479834808036685, 0.0395567798987031, 0.020851180955235447, 0.021676717192998955, 0.03669296517702086, 0.07050554241452898, 0.020795286633074284, 0.025670218081878762, 0.028664369202618088, 0.050839019141026905, 0.03635493599410568, 0.04386096840192165, 0.04221574489825538, 0.05102178594097495, 0.018559427233412862, 0.06273659465036222, 0.00817227830910789, 0.06560949834861926, 0.02276288721311305, 0.05817990630332913, 0.0011595039645076863, 0.034895590373447964, 0.08366102685353585, 0.04292040690779686, 0.026827340812555382, 0.03110347528542791, 0.09022876407418932, 0.052754082450909276, 0.049031737726181746, 0.011914649994910827, 0.04350971117881792, 0.04323452451665487, 0.03600181958505085, 0.06902607144521815, 0.005663632140827498, 0.046405712209109745, 0.027226212534255216, 0.07469173707067966, 0.011498904803634753, 0.04815066678981696, 0.048273383240614615, 0.04992719699761697, 0.0779743469985468, 0.025427341560966203, 0.03200846118852496, 0.003736011268171881, 0.026358846308929578, 0.034197479619511535, 0.003854427927373243, 0.02538278216629156, 0.02808547535512064, 0.010589018181365515, 0.24073154958231108, 0.1264214962720871, 0.07751602373485054, 0.07791838821555887, 0.09091578078057085, 0.13197013496288232, 0.15602667124143668, 0.14653577123369488, 0.13467871105032309, 0.13596994962011064, 0.1111543294308441, 0.13022735847958497, 0.1454011792583125, 0.07586219640714781, 0.06956794951111078, 0.13626503092902048, 0.09938557379479919, 0.11853739432990551, 0.1672104482672044, 0.1817146364067282, 0.11185992442603622, 0.1243560356753213, 0.07314846345356532, 0.10168387368321419, 0.18032859292413506, 0.06584239192306995, 0.22276658857507364, 0.0978328346141747, 0.09726999660155602, 0.19581122856054986, 0.15692492946982384, 0.08694580809346267, 0.1254539189061948, 0.09797336600188698, 0.10737571040434496, 0.08203918566661221, 0.14139585489673273, 0.07833350915461779, 0.1744798110531909, 0.1485117059201002, 0.14717436768114567, 0.1104086601574506, 0.1378359752041953, 0.13409013620444707, 0.07974991029394524, 0.060043414522494586, 0.18083883768745831, 0.0850243190569537, 0.08151117007115058, 0.16161872260272503, 0.11544844508171082, 0.1266717128455639, 0.15817176470799105, 0.12893096304365567, 0.12794171326926776, 0.12094551511108875, 0.12894914778215544, 0.12686695451182978, 0.08623270171561412, 0.1760897846626384, 0.2803398370742798, 0.15290541015565395, 0.18608052070651734, 0.09635716344096831, 0.08278663270175457, 0.14906022005847522, 0.12316604810101645, 0.11764695282493319, 0.0869355486439807, 0.12074560512389455, 0.0866294614970684, 0.17489078614328588, 0.08668411070747034, 0.17251602214361939, 0.07685398390250546, 0.06775687847818647, 0.1175853011331388, 0.1901565348463399, 0.17241113420043672, 0.17876584535198553, 0.15260777755507401, 0.1062403041869402, 0.11486888118088245, 0.12769969339881623, 0.07621994721038, 0.18480688333511353, 0.07350443649504866, 0.13614632801285811, 0.1597256370420967, 0.0972312997494425, 0.19549414914633545, 0.07211483070360762, 0.13532281720212527, 0.09205806734306471, 0.14472967386245728, 0.14631800220480987, 0.09164865288351264, 0.11515349947980472, 0.08586931907172714, 0.14331000218433992, 0.1523816218333585, 0.13290906458028726, 0.155710636771151, 0.11948958252157484, 0.07721757010689803, 0.1666851807385683, 0.06478378908442599, 0.17642738297581673, 0.08508475617106472, 0.16385429192866596, 0.15012708066829614, 0.0810052611465965, 0.17640948322202477, 0.10903212973581893, 0.1982415510075433, 0.0743181085480111, 0.13118692913225719, 0.1434105203620025, 0.1128225756276931, 0.20964362631951058, 0.10894090070256165, 0.08907328000558273, 0.14250876089291914, 0.07776989761207785, 0.1617673353425094, 0.22362351045012474, 0.0998450777094279, 0.09593088060085263, 0.12034624655331884, 0.1762044842221907, 0.06680549774318933, 0.1795986792338746, 0.22620198423308985, 0.17766735143959522, 0.14156054891645908, 0.15740907777632984, 0.14477189231131757, 0.15383926433111939, 0.13486496891294206, 0.15594299430293695, 0.08215885210250105, 0.12858964635857514, 0.08698648626783065, 0.13760125637054443, 0.1289985587022134, 0.057330014051071236, 0.16883494252605097, 0.1300205545766013, 0.10399655172867434, 0.08959535163428102, 0.22735835718257086, 0.12409386331481592, 0.1332401353865862, 0.13258840250117437, 0.16357196707810673, 0.1333976640765156, 0.12285860388406686, 0.15872592425772122, 0.12725994842393057, 0.11599162593483925, 0.20805839209684304, 0.12499877118638583, 0.106248629811619, 0.1362835956471307, 0.12097934686711856, 0.1756210391010557, 0.1328898484685591, 0.09020384826830455, 0.12765613145061902, 0.08530247770249844, 0.17288082971104554, 0.09318545327654906, 0.1514800659247807, 0.21156491179551395, 0.12901926759098256, 0.10719118959137372], [0.016795387158968618, 0.051489930999066146, 0.05754342009978635, 0.052652180061808655, 0.03661290822284562, 0.03953938226082495, 0.032263658209038634, 0.014778796350583434, 0.05104152113199234, 0.02388639192629073, 0.060779292535568984, 0.014740075749744262, 0.05619916080364159, 0.011099905856618924, 0.0023927852536352085, 0.009212246031633444, 0.013892132589327437, 0.020484890788793564, 0.04862455903951611, 0.05289529576631529, 0.06164711846836975, 0.02855615983051913, 0.01859489086616252, 0.05546358473865049, 0.05758402363530227, 0.017062231233077388, 0.02626500152317541, 0.04702386439644864, 0.018153659899586012, 0.023614565708807538, 0.04526572927300419, 0.04530014796182513, 0.01075342552004648, 0.07930115437401192, 0.018132923869416118, 0.044808271141456704, 0.024787125111158406, 0.04672481365767973, 0.029750639306647435, 0.06555457093885966, 0.012145371409133077, 0.023300237754093747, 0.006595307370714311, 0.03315513447991439, 0.012089930857265634, 0.03972755019952144, 0.03583152765142066, 0.03133779378341777, 0.023692695623529807, 0.003258590424333566, 0.023003176819267016, 0.01826623734086752, 0.02883034904620477, 0.016222391477120773, 0.04852455315579261, 0.01852882530407182, 0.056140993389167955, 0.0405256498738059, 0.03994018950366548, 0.05776849016547203, 0.017665238518800055, 0.022922256429280554, 0.028573381049292426, 0.026522590379629816, 0.059252344471003325, 0.018365861548643028, 0.03370959597772785, 0.05525848735123873, 0.05637750694794314, 0.00931496690360031, 0.015491619440061706, 0.004806260312242168, 0.01843438171116369, 0.021147626119532754, 0.06906857487878629, 0.05424431498561587, 0.012869508221878536, 0.0494735454475241, 0.002550555459622826, 0.0010001904094159336, 0.09080142727387802, 0.048824625089764595, 0.05689688818529248, 0.01673103998681264, 0.04175125375123961, 0.02826767897100321, 0.014858442791072386, 0.024948153345446502, 0.0266818171034434, 0.06516385690442153, 0.04281209236277001, 0.0745686711743474, 0.07380094951284782, 0.05956897605210543, 0.038451344573072026, 0.009687670922305967, 0.059560406154819896, 0.03785521763243845, 0.02908925765327045, 0.05075283840830837, 0.012125593809677022, 0.035717448951410394, 0.01893486744458122, 0.02999701537191868, 0.0893591060968382, 0.08077919363443341, 0.01576981201235737, 0.07568186215524163, 0.019724273388939242, 0.02593851930994008, 0.03412122246144073, 0.05836768408438989, 0.014509324649614947, 0.03451202470543129, 0.06675942521542311, 0.08217511658689805, 0.07405170212898936, 0.01988420748550977, 0.009815068416563528, 0.040396965707519224, 0.017592713303331817, 0.039418430001075776, 0.016211585806948797, 0.057526524577822, 0.026301527063229253, 0.07025736823145833, 0.020055844614814435, 0.055035856618945084, 0.06534900196960994, 0.00573061330110899, 0.06634035520255566, 0.05985458501215492, 0.009948127437382936, 0.017119681096768806, 0.031813568967793665, 0.005067265168431082, 0.02238083298185042, 0.06314097438007593, 0.022311766598639742, 0.05672536810327854, 0.05001690611243248, 0.06009723592017378, 0.09207732416689396, 0.07475720212927886, 0.06366288994571992, 0.04014234544177141, 0.04279171934883509, 0.033149217654551776, 0.035086404598717175, 0.0426253425622625, 0.014237354243440288, 0.018395240418612957, 0.03162177086674741, 0.025948419135862162, 0.04454752370449049, 0.02068806792210255, 0.0630529819588576, 0.008754964319190808, 0.024572638495426093, 0.022324002281363522, 0.02516679259549294, 0.05318052813942943, 0.028774346158440624, 0.05422644915857485, 0.012381593197850245, 0.030321392430258647, 0.052900971711746285, 0.022501539272655333, 0.00960985737453614, 0.041382432649178166, 0.057232264296284745, 0.015016532968729734, 0.015754828262808065, 0.06019666844180652, 0.029209792613983154, 0.0542331055871078, 0.028794230627162114, 0.042790229964469156, 0.05906356245811496, 0.032136728055775166, 0.02640544470133526, 0.025651838264561126, 0.02305183286911675, 0.0525821247138083, 0.014179687248542905, 0.04586287401616573, 0.056962797684328895, 0.013382803848279374, 0.07521654998085328, 0.0789991452225617, 0.05731554089912346, 0.06562606138842446, 0.01872170906114791, 0.04561407218820282, 0.044272058842969794, 0.06422821818185703, 0.04482411154146705, 0.04376892851931708, 0.07173044061554329, 0.03961343078741005, 0.01961233207423772, 0.03894106704475624, 0.023723887878337076, 0.033178160565772226, 0.019878818221124153, 0.027591344102152755, 0.10136991553008556, 0.010845692711882293, 0.060806813915925365, 0.08846392163208552, 0.014370732175718461, 0.026655276206188967, 0.02851749351248145, 0.019482984639970318, 0.05123972460361464, 0.04866635001131466, 0.06233136675187519, 0.04068497668153473, 0.01347466985628541, 0.02338215728689517, 0.016518224263563752, 0.03630946736250605, 0.0462154679532562, 0.029452996528042213, 0.03510785309065666, 0.018733395130506585, 0.07237346111131565, 0.02268646551030023, 0.03241043211892247, 0.044191330139126093, 0.027767335729939596, 0.018508745756532465, 0.022810613669987236, 0.03391070697190506, 0.019568373183054582, 0.04574463250381606, 0.06416548083403281, 0.044560996017285755, 0.023243500352171913, 0.01833752083725163, 0.02086386107839644, 0.08116962268416371, 0.03111469486196126, 0.03874653444758483, 0.04494913161865302, 0.029129491387201206, 0.040153846610337496, 0.06367475752319608, 0.10640941546963793, 0.03814901651016303, 0.0167896738941116, 0.044875150945569785, 0.00166610287435885, 0.02431281386608524, 0.028070198139175773, 0.06706589912729603, 0.03828786173835397, 0.05603565422019788, 0.016954009986615608, 0.018782712751999497, 0.06604631883757454, 0.023793816001021435, 0.04071768206943359, 0.05337057901280267, 0.009353932625214969, 0.032663868341062746, 0.024803114788872854, 0.045048401291881285, 0.06825282650866679, 0.0283597307279706, 0.03361142213855471, 0.0068394328201455724, 0.016418196327452148, 0.011162973142095974, 0.024171939818188548, 0.04297677959714617, 0.0332624651491642, 0.01582378099140312, 0.03779348112376673, 0.01751320087350905, 0.06292427743652038, 0.031145025377294848, 0.01983374313983534, 0.036989437482718907, 0.0056755942891218835, 0.03227753425016999, 0.0314317064226738, 0.08474318842802729, 0.01503305190375873, 0.06357615959963628, 0.041931910307279656, 0.006596097439926649, 0.062488291545638015, 0.04828905739954539, 0.02373889707294958, 0.027859061790098037, 0.010269725894821542, 0.07476381784571068, 0.0555192042541291, 0.05344313815502184, 0.051646798117352385, 0.031282204802015, 0.04325998993590474, 0.03370295990524547, 0.01910287780421121, 0.04226042303655829, 0.05753088755799191, 0.03100155932562692, 0.043864663025098186, 0.07223825622349977, 0.01909347839786538, 0.03058999391006572, 0.056117492328797064, 0.01927214514996324, 0.04062956411923681, 0.02589120506308973, 0.06625542297427144, 0.0292844721781356, 0.02360701191771243, 0.025760096830448935, 0.07044454890170268, 0.04399666522762605, 0.019246194578175033, 0.026046068806733404, 0.016196491795458963, 0.038700377102941275, 0.024681197313059653, 0.01462399706776653, 0.021014853779758726, 0.02716296967784209, 0.08037458320281335, 0.03411218776766743, 0.06079430851553168, 0.023133765972618545, 0.05706268482442413, 0.03416134084441832, 0.04467761243826576, 0.012819109185199653, 0.07099752101515021, 0.03955452376976609, 0.01249976091951664, 0.057880143102790625, 0.007438316309292401, 0.03320782272411244, 0.032764064214591465, 0.04691385351387518, 0.009645365112062012, 0.0471207286630358, 0.03513324726372957, 0.01864539592393807, 0.0652966122808201, 0.05930866966290133, 0.07422094911869083, 0.1839279362133571, 0.130051726475358, 0.07975990511476994, 0.15805581664400442, 0.1442848534456321, 0.1854518037289381, 0.10477832585041012, 0.08588368365807192, 0.13555653180394853, 0.18880033333386692, 0.06255512045962469, 0.22063315234013967, 0.09224708005785942, 0.15185461725507463, 0.14487878871815546, 0.11463342952941145, 0.18348759412765503, 0.13995920627244882, 0.12011137844196387, 0.09277327717947108, 0.12809799345476286, 0.20675233432224818, 0.18027695640921593, 0.1275220393602337, 0.14122092856892518, 0.1114198537543416, 0.11231992367122855, 0.19784236885607243, 0.11477879887180668, 0.1531414317765406, 0.11281969185386385, 0.10893575740712029, 0.17335935974759714, 0.05084721923672727, 0.13680580976818288, 0.11905317593898092, 0.11129636038094759, 0.1025335555896163, 0.18847504364592688, 0.1317020050649132, 0.1074343833274075, 0.09406330795692545, 0.13747411247875008, 0.09540703799575567, 0.0872230100046311, 0.12714182904788426, 0.11175719422421285, 0.11051807392920766, 0.10731210453169686, 0.169940194647227, 0.12638001064104692, 0.11633040489895002, 0.10173116757401399, 0.18751792929002217, 0.12042541801929474, 0.14047414649810108, 0.17487880321485655, 0.14273583942226, 0.1363426824765546, 0.20824849046766758, 0.1905129285795348, 0.1338752984468426, 0.10139339962708098, 0.0791103435414178, 0.10515366428132568, 0.11946812724428517, 0.1766957300049918, 0.11245197337120771, 0.17301246550466332, 0.04592759607891951, 0.10444215246077095, 0.15990239541445458, 0.08001405719135489, 0.14348424997712883, 0.1488617214241198, 0.11053482017346791, 0.15423175612730639, 0.11356333230755158, 0.11557448974677495, 0.17214864971382277, 0.10927127940314156, 0.16893651921834263, 0.18911771130348953, 0.16178519438420022, 0.08678776371691908, 0.09098870293902499, 0.09544353639440877, 0.16868339851498604, 0.14254008206937993, 0.1707990707031318, 0.16048958604889257, 0.1868654635867902, 0.11476277187466621, 0.1482393555343151, 0.13899765429752214, 0.17966171513710702, 0.13116571812757424, 0.13319989825998033, 0.15417694406849997, 0.07494799939117261, 0.09145107705678258, 0.08996729739010334, 0.23279358553034918, 0.1788600938660758, 0.16261327852095875, 0.11263127624988556, 0.1657819827752454, 0.11183194164186716, 0.10898618612970624, 0.09364950337580272, 0.12133089586028031, 0.07783614977129868, 0.10721497224377734, 0.16609538452965872, 0.15421140007674694, 0.24582794468317712, 0.09626471304467746, 0.1258697658777237, 0.08097311215741293, 0.1301687601953745, 0.0880756638944149, 0.10305615647562913, 0.18625333000506672, 0.16828197719795362, 0.18766789909984383, 0.11055055540055037, 0.16271290103239672, 0.1940173041075468, 0.15884120735738957, 0.16170549366090978, 0.2269803588943822, 0.07270755139844758, 0.13596749332334312, 0.1167985126376152, 0.06726702369217362, 0.1779127504144396, 0.10126255093408482, 0.16696880837636335, 0.17189357482961246, 0.22415001291249478, 0.16071897159729684, 0.11770931019314698, 0.11672020969646317, 0.1752290494207825, 0.20556161393012318, 0.19368271848985127, 0.1100589974916407, 0.11652585012572152, 0.10168879984744958, 0.15143982879817486, 0.08423149838511433, 0.15814626536199025, 0.10304202937654086, 0.14445834127920015, 0.07404866229210581, 0.1446165485041482, 0.08891655198697533, 0.14543042411761625, 0.10270078733031239, 0.13993068066026482, 0.174212888947555, 0.13713029878480093, 0.19014285558036395, 0.15537303845797265, 0.08334807971758501, 0.0854997414031199, 0.09576914499380759, 0.13118618274373667, 0.12827481968062265, 0.10163631516375712, 0.1794195052768503, 0.09130601984049593, 0.09125601180962153, 0.17590420533503803, 0.10424220176147563], [0.05269652232527733, 0.04849323537200689, 0.04106401312830193, 0.07223953186933484, 0.01891414328877415, 0.06368049792945385, 0.030976233006055866, 0.04193718930972474, 0.046602260055286546, 0.031957543920725584, 0.024260756659454534, 0.033616680784949234, 0.02508890356070229, 0.06658766764615263, 0.042423057702503035, 0.012242626681524729, 0.016512076736294796, 0.027511017430307608, 0.036359661990510564, 0.07530823363257305, 0.05861456226557493, 0.06122194842568465, 0.011678339148472463, 0.023959851823747158, 0.018365868333993212, 0.00991116848308593, 0.08054415588932377, 0.04099746919902308, 0.0520847110476877, 0.01493042687486325, 0.011105841341694551, 0.013252886444596308, 0.06955963067178215, 0.049082960334739516, 0.028293444641998837, 0.0279940512430455, 0.003973946357811136, 0.012236004179742719, 0.0182367278529065, 0.035391171995018206, 0.058544713870755265, 0.02884963640410985, 0.006499571168595659, 0.0038551013733792517, 0.057828045184058804, 0.024603033471586447, 0.04184946490983878, 0.059137705979602675, 0.05731936105127845, 0.05308410831327949, 0.041230298312647004, 0.015056885446288755, 0.03786992148629256, 0.050965973043016026, 0.01021472639071622, 0.00801712364357497, 0.03910674833293472, 0.01222534354643098, 0.02748472589467253, 0.032198406888970306, 0.0343057330963867, 0.017513133020007184, 0.026777151273563504, 0.034255881128566604, 0.030522401644183055, 0.00998284892245595, 0.08445139122860772, 0.06478203846407787, 0.014937010360881686, 0.0745943740808538, 0.050174729965095005, 0.0377345062526209, 0.012762884925385671, 0.02740941529295274, 0.04705846628972462, 0.011064156390992659, 0.012555321911349893, 0.031950175030423064, 0.04459519078955054, 0.015748687520889298, 0.010888451444251197, 0.059933281503617764, 0.044956361409276724, 0.021350787985803824, 0.055806740253631554, 0.07937641069293022, 0.03040586325473019, 0.0599513848179153, 0.028270376147702336, 0.05342384401176657, 0.07350083347409964, 0.0533124285617045, 0.040965696796774864, 0.03571659738996199, 0.05364614565457616, 0.019357382719005858, 0.026219154608302882, 0.009822105672875685, 0.04158755378531558, 0.030523103927927356, 0.035787497514060566, 0.04967319080606103, 0.015469473753390568, 0.004954780177545867, 0.004138574644457549, 0.008233849424868822, 0.03475654837010162, 0.02059249796106347, 0.026414820358955433, 0.013710147800988384, 0.04201075268377151, 0.031252515502274036, 0.03031692427716085, 0.03377590920510037, 0.04550356258239065, 0.028240257674562078, 0.026322425941803625, 0.003436001462562542, 0.10549971714083638, 0.026319241916228617, 0.009213630243071487, 0.02984879618244512, 0.01703473529778421, 0.05093786133719342, 0.06953469450984683, 0.02271058064486299, 0.023977312226114527, 0.09265065233090095, 0.06168658885040453, 0.023003222620380775, 0.05595136660018137, 0.04496240037094269, 0.01319241285922804, 0.021769230353779027, 0.060873432484056265, 0.058266141318849156, 0.013201386484849666, 0.006758627781112279, 0.021480617179934467, 0.0482278569335384, 0.11416612246206828, 0.017780163691246083, 0.03322931871350322, 0.021779567834788134, 0.0335685556887516, 0.025082576221653392, 0.01056315581912973, 0.06844808853098325, 0.02023411781660148, 0.016502857141728913, 0.07875155457960707, 0.03421957611239382, 0.02817014465108514, 0.021317256481519768, 0.018864856201357076, 0.03282286605930754, 0.05120125845340746, 0.042974784704191346, 0.012023674457200935, 0.04763735165553434, 0.03355669828930071, 0.04042412407164063, 0.09751975177122013, 0.04971722772877131, 0.04305219876446894, 0.04693298480872597, 0.038387626742145846, 0.05210169477920447, 0.02175383948321853, 0.02161360495457692, 0.029012803720044236, 0.026121062193331972, 0.01138325359871877, 0.03821174707263708, 0.013789565235908543, 0.011051580592590784, 0.03598638630605169, 0.017785736160086732, 0.009101697410057698, 0.00503719546499529, 0.0038333937658795287, 0.035840114512081654, 0.02665665023960173, 0.018511325885940875, 0.07664008930857692, 0.008269940702510732, 0.0035999675414391924, 0.03993368235283664, 0.025389886427936808, 0.08076163993350097, 0.04478966910392046, 0.018226702498005967, 0.01616837500062372, 0.06807245833000966, 0.04106261195348842, 0.0405808215561722, 0.050678209734282324, 0.07259020555232253, 0.05556745487930519, 0.014433069187881691, 0.010732186525794012, 0.017177536385133862, 0.042703180706926754, 0.07053497047828776, 0.038912911234157424, 0.0071695994785321605, 0.032895543945154974, 0.02372352995111474, 0.03580941419516291, 0.015218514184068357, 0.05608371485556875, 0.04362442430907062, 0.019723063900268505, 0.014278934869383062, 0.04718728616301503, 0.02731622020447893, 0.044256282903786213, 0.02980190601998142, 0.027485336576189314, 0.06657796459538595, 0.02145453599015517, 0.00300730112940073, 0.05972539872995444, 0.017444880878818885, 0.04111133755317756, 0.03441092977300286, 0.01835984124669007, 0.033383291879934926, 0.018351887119933963, 0.04728395365444677, 0.031165357679128647, 0.051167226529547145, 0.03979827729719026, 0.04918203323281237, 0.04565916084019201, 0.02767891243898443, 0.027002592837171893, 0.021125271783343384, 0.07496733763920409, 0.047645429614931345, 0.05783744289406708, 0.05201584652864507, 0.027856647901769196, 0.05884339141526392, 0.04999894529048886, 0.0872748704361064, 0.013612166496126779, 0.04419957094692758, 0.013730927087765719, 0.032383870865617476, 0.011634733095499021, 0.04277385691446917, 0.017417676713583723, 0.049546213155346255, 0.04669297340192965, 0.024726691389722482, 0.00396251177049375, 0.021028002092082585, 0.06284163865659918, 0.03634868668658393, 0.023894995750327195, 0.01251201017294079, 0.009534518783246832, 0.014952357126665967, 0.03148980598364558, 0.014491119555064609, 0.05960117932409048, 0.0045036124897056395, 0.08167524662400995, 0.0705504139353122, 0.029112266775752817, 0.08680534455925226, 0.10594406936849866, 0.034465806292636056, 0.017169131032590355, 0.024012085449482714, 0.026023427789498652, 0.027420522911208015, 0.021831582632980177, 0.03780459552737219, 0.007466991199180484, 0.03075544788901295, 0.049181432729320865, 0.04647653090900608, 0.0183195634079831, 0.029530162923038006, 0.020826433086767793, 0.06461514599089112, 0.046573859972081015, 0.012717472272925079, 0.03303840270798121, 0.039594146822180064, 0.052441959735006094, 0.043705726375005076, 0.05091318641124027, 0.09717369891170945, 0.008051677191230868, 0.022338790952094963, 0.005900967151059636, 0.03795193940667169, 0.07514390602175679, 0.057273274952811856, 0.018995905062183738, 0.08280097014669861, 0.003961747146344611, 0.00651649764872023, 0.015679814520158937, 0.04237109888345003, 0.06892291376633303, 0.03071607928723097, 0.030123117712459395, 0.08709302305110864, 0.020792784535193017, 0.014779803975086128, 0.06291454045900277, 0.0446986300604684, 0.013742265407927334, 0.08905042016080447, 0.010967097893756415, 0.058270904634680064, 0.021048200383250202, 0.07628489658236504, 0.03091917499633772, 0.04195057341296758, 0.03819815940888865, 0.021415484603494406, 0.022447158083585755, 0.03272453276440501, 0.09043229065303292, 0.03622754104435444, 0.0355175864616675, 0.015174366999417543, 0.02188093587756157, 0.04168519497449909, 0.018415498081594706, 0.06630953614200864, 0.04461299554843988, 0.07971585462135927, 0.057472825316446166, 0.033590455406478474, 0.040357159450650215, 0.028526060017091886, 0.03872979159599968, 0.03243935128141727, 0.013526290255997862, 0.024438585420804362, 0.03496072294988802, 0.043178708226020844, 0.052637008018791676, 0.06920558466975178, 0.042302539705165794, 0.0793378156210695, 0.12805382082504885, 0.11933142957942826, 0.15431951784661838, 0.13537192956677505, 0.0986709746399096, 0.14471508535955632, 0.18452332355082035, 0.11002116916435105, 0.13004131774817193, 0.11270869709551334, 0.06456689536571503, 0.13136756872492178, 0.13981610323701585, 0.16571293505174772, 0.15417201790426457, 0.08505684124039752, 0.09433698148599692, 0.09419337633465018, 0.11268255314124481, 0.18690464219876698, 0.12223409382360322, 0.1710032554609435, 0.13328449800610542, 0.10220263406102147, 0.09888697269239596, 0.13816133274563722, 0.13356978126934596, 0.15469580622656004, 0.15370389659489903, 0.06666451173701457, 0.06916915412460055, 0.1469831700835909, 0.1568965802767447, 0.16734251832323416, 0.15027756616473198, 0.19928036097969326, 0.09167479683778115, 0.05491867022854941, 0.10621515089379889, 0.1096666549731578, 0.15508546174636909, 0.13631293550133705, 0.08298042230308056, 0.13868970796465874, 0.16858695154743536, 0.06783537140914372, 0.1382366908448083, 0.1438681786613805, 0.10714633164129087, 0.153994580996888, 0.06031242651598794, 0.15463509091309138, 0.08295170670109135, 0.13783855363726616, 0.09569785810474839, 0.11337332214627947, 0.1350688279739448, 0.1349813783807414, 0.1463198885321617, 0.15749130264988967, 0.10413415184510605, 0.11693514244897024, 0.22514710655169828, 0.08064700144210032, 0.11783079510288579, 0.13122114086789743, 0.09905866240816456, 0.15310008185250418, 0.1398098607148443, 0.2923172829406602, 0.07618287884231124, 0.17792104211236748, 0.09688518582178013, 0.1083670568519405, 0.07209634740969964, 0.10155248216220311, 0.13967002821820124, 0.104880601433771, 0.2556604599314076, 0.09061113212789808, 0.1016026394707816, 0.08524444938770362, 0.18274602320577416, 0.13012388188924107, 0.09988061937370471, 0.17135460089359963, 0.06879116262176208, 0.10254908725619316, 0.11359294357576541, 0.04719393580619778, 0.10878122105662312, 0.14479712024331093, 0.16813268592315062, 0.17542108840176038, 0.12958053818770818, 0.13714676004435333, 0.1618284306355885, 0.10263395163097552, 0.11575036602360861, 0.08843791338482074, 0.15655404222863062, 0.10857793196503605, 0.0544070548244885, 0.17973914955343517, 0.1346928517201117, 0.07464607166392462, 0.13256050114120754, 0.17149319845650876, 0.10341724567115307, 0.10321828563298498, 0.1470949790839638, 0.13029621621327742, 0.09874929115176201, 0.08750729582139424, 0.11602068080433778, 0.13757894613913127, 0.15753468817898206, 0.1223569493740797, 0.19863717763551644, 0.1603768678115947, 0.11052617563733033, 0.12458810822239944, 0.09515718783118896, 0.1372825349015849, 0.16428007265286787, 0.1277558896690607, 0.17216888362807886, 0.2684444939451558, 0.10524710533874375, 0.15362346305378846, 0.0981629758274981, 0.08258738767887865, 0.10044467874935695, 0.1319167206862143, 0.20477219271872724, 0.24862638594848768, 0.07074783369898796, 0.15843407277550015, 0.08600422540413481, 0.16332351469567843, 0.19407811441591807, 0.1753386463969946, 0.12452808501464979, 0.0849262232493077, 0.12212388616587434, 0.21794084752244608, 0.10885516101760523, 0.17108815376247677, 0.0957752110968743, 0.10259656435144798, 0.19954013132623263, 0.12261688256902353, 0.09941760064767939, 0.13711596812520707, 0.06565890248332705, 0.12955715587096556, 0.14770929754844733, 0.156578143792493, 0.11577167202319417, 0.15319775018308843, 0.14479910156556539, 0.20086798364562647, 0.1428371989833457, 0.09082183082188879, 0.15279228479734488, 0.08494749532214232, 0.14786172365503653, 0.13213066277759417, 0.13842923194169998, 0.12749465368688107, 0.12327895632811955, 0.16039149702659675, 0.11556904789592538, 0.29324598024998394, 0.11515504653964724, 0.09509785672915833], [0.020363779073315005, 0.0189006387455655, 0.04188151890411973, 0.016067690581881573, 0.0363336910626718, 0.010874606785364449, 0.035444114689848254, 0.04230830046747412, 0.03892931481823325, 0.06148832770330565, 0.04449879131945116, 0.031004395602004867, 0.033103871159255505, 0.04644707231117146, 0.011340950332981135, 0.022910231092412556, 0.0501757375895977, 0.04330735507288149, 0.07881249380963189, 0.03229998018858688, 0.023458760497825484, 0.025584931319047297, 0.04345401702448726, 0.03545439788805587, 0.054053392194743664, 0.038232065803770504, 0.11118303824748312, 0.029670134519359896, 0.03583980917132326, 0.046692593422319205, 0.06583331990987062, 0.0016049456649592944, 0.076470062003604, 0.03445432208744543, 0.0673954025177019, 0.0479049014060625, 0.04415291487904532, 0.05955680991922106, 0.00668643632005634, 0.039542045510773144, 0.017547461802938154, 0.023097488097846508, 0.03762115019240549, 0.008341715288614588, 0.011481128882483711, 0.005925644621519106, 0.03692720903615866, 0.05636983950223241, 0.09711507348609821, 0.050806055909820964, 0.07087967983846154, 0.006083958715732608, 0.023136278248525093, 0.03345053130760789, 0.010757310981197017, 0.0962239330900567, 0.021646600416196243, 0.02830030463103737, 0.03377383628061839, 0.03379832121676632, 0.03369056985580495, 0.03664745244064501, 0.04290403046512178, 0.025483290165928856, 0.019220232132024, 0.04235397944492953, 0.025887663110292385, 0.00669748244607555, 0.08407133019396237, 0.01166317134629935, 0.03804210653262479, 0.026529413049242327, 0.08085947789783988, 0.04100187967664429, 0.10420594085007906, 0.07624833711556026, 0.01685231624703322, 0.0737884169710534, 0.02697521903818207, 0.03268252805407558, 0.02711931612741734, 0.1391142401844263, 0.018357500300875733, 0.04043049890814083, 0.03395909330408488, 0.06472639180719852, 0.061132944987288544, 0.0619350615888834, 0.00749984332027712, 0.06986632171486105, 0.03590111481025815, 0.013024316834551948, 0.002597244818129444, 0.006337995865448777, 0.008298202534206212, 0.03601296791540725, 0.04754123717014279, 0.026523207846496786, 0.029560676642826626, 0.010803766033080007, 0.05025535010333572, 0.037505894234137874, 0.0362656645343772, 0.03971016613234367, 0.03678968695125409, 0.027769635963652815, 0.04009260543222938, 0.027678603705550944, 0.03822135852117624, 0.046808527915605476, 0.039965437791709385, 0.010036311544744032, 0.029041716097188846, 0.044596910875822814, 0.020285306498408318, 0.03084450900288565, 0.027604948729276657, 0.05101069189342005, 0.06447078088032347, 0.055672814404325824, 0.026410805127982582, 0.030272375060511485, 0.04526474539722715, 0.028469154677752937, 0.029487930903477327, 0.009011593048593827, 0.020257303358188698, 0.008042058957341527, 0.05047511402517557, 0.009393518358202917, 0.010217091933424984, 0.011924826323853006, 0.07014767626034361, 0.02129390130617789, 0.02488638799903648, 0.06486268913639442, 0.023452848761475513, 0.02116259460204414, 0.03470955642738512, 0.06131900607475212, 0.027334466011130383, 0.05660365249163338, 0.0373475886216121, 0.07330985300775085, 0.023409446269007664, 0.05639207848746862, 0.010430653197025614, 0.022745481093547175, 0.045299479604831765, 0.021546445254768645, 0.05777317884245089, 0.0630038356674569, 0.027041267636897307, 0.044477057842803855, 0.01784428525050836, 0.07990532873996667, 0.05450382409617305, 0.027060622848304253, 0.030660385132900307, 0.05394964758306742, 0.08408700435289315, 0.02105604764074087, 0.05609431696523513, 0.05838242865034512, 0.016135830764791796, 0.019496541769642915, 0.03356049808540514, 0.026150495346103395, 0.022346517769619823, 0.07219300472310611, 0.016776649414428642, 0.013824044144712389, 0.04350634903780051, 0.02330398666007178, 0.017041464668831656, 0.08512727317533322, 0.04111918820334332, 0.0344250670501164, 0.00991683594682919, 0.045849425452096124, 0.050817299235079966, 0.016020389905731593, 0.0219786652762975, 0.009016362301606153, 0.010358032986654766, 0.02058674568044288, 0.07415200996079616, 0.0073122207541018724, 0.0111553803352373, 0.0335201591785465, 0.016832789705534066, 0.02077561929555876, 0.05125882875706468, 0.018844142223575285, 0.07308359550578253, 0.04616315968866859, 0.018596963790644492, 0.020497280838234083, 0.049970898045493026, 0.03252852435356804, 0.04989133302920631, 0.05610838299617171, 0.01713551640776651, 0.06012039432036025, 0.05330557196534105, 0.06918292838547911, 0.0636477857562048, 0.038983478876096864, 0.09748682246676513, 0.07457463549716131, 0.04124009635831628, 0.014094254600682428, 0.03522493430812444, 0.032470302656292915, 0.0018036968415669563, 0.014869854053748506, 0.025751036691612432, 0.027876819051536064, 0.02853194291570357, 0.032797984180173705, 0.010726345187452222, 0.012238440120459666, 0.03192268757681761, 0.05605575582012534, 0.050663207325020006, 0.02001708499821169, 0.03183426767853754, 0.1131583351109709, 0.07920886004077536, 0.041971234804285426, 0.01981944471065487, 0.015200628000976784, 0.03422115031363709, 0.03534867873947535, 0.015751466121790663, 0.040114203201872964, 0.020380337024107575, 0.04665116885943072, 0.05872345356536763, 0.0277592764302556, 0.021565954832892333, 0.03705142504934754, 0.01736651347684009, 0.011911011350873326, 0.022818864655814, 0.04833731481007167, 0.03314271728907313, 0.023035001807979176, 0.03391857458544629, 0.03649658017924853, 0.0721287949542914, 0.04143118539026805, 0.030875646974891424, 0.10379288944282702, 0.06359743845782109, 0.03150632152599948, 0.05507978836872748, 0.06399210156606776, 0.05749065721673625, 0.04280458776546376, 0.06828146747180394, 0.020235471493963684, 0.05971840303391218, 0.01620818634650537, 0.022630259062030485, 0.06589921923088175, 0.024869358466405953, 0.03200453247076698, 0.09405984742833035, 0.02427204917850239, 0.018542518140748143, 0.03361740681741919, 0.09443791357002088, 0.031153880259288207, 0.05488866880269987, 0.008995940093882382, 0.06724703405052423, 0.018539023685402105, 0.05038820725998708, 0.0427333314104804, 0.03798402054235339, 0.01828321598337165, 0.018472578143700957, 0.0604372023205672, 0.024208485714292953, 0.014152202339443778, 0.020510742973004068, 0.0800526522632156, 0.013665215212053486, 0.03219603540908013, 0.019997190351464918, 0.023227324077327336, 0.04272378781544311, 0.011090345298206168, 0.04014448621975524, 0.031333664897829294, 0.0075618444576061195, 0.05136515519448689, 0.007293015668567802, 0.015997742103146653, 0.03952657491234796, 0.024235050360273038, 0.024609730612220507, 0.007812822686641343, 0.02405696714829121, 0.031883464860064645, 0.04433148154722793, 0.013336587131821682, 0.0032252730826647685, 0.0322525302347328, 0.035991200512009006, 0.04855559613289578, 0.023136381725115434, 0.05705565520163093, 0.043926942361784835, 0.06777217944285699, 0.04933956192274179, 0.0171820859624339, 0.0327292587608099, 0.047273107272173674, 0.01065020592484091, 0.015323744787435447, 0.033840152900666, 0.03444597949939115, 0.06506492649870259, 0.016927011078223586, 0.0884009807237557, 0.05906270071864128, 0.015322133266766156, 0.014126987978150802, 0.08282197759087596, 0.018865080117913227, 0.07909682033849613, 0.03216754033097199, 0.09053390127207551, 0.06093040906957217, 0.05393900476129992, 0.03361788857728243, 0.033777625898697546, 0.015200897718646696, 0.027603288014818515, 0.010833706390777869, 0.022435911365651658, 0.015426590340211987, 0.02828813510547791, 0.1449507134301322, 0.028020610800012946, 0.0043424281923632535, 0.03129130056393998, 0.029124185243355374, 0.018605345394462347, 0.027991130149790218, 0.1607457465891327, 0.13730750499027117, 0.10025954725486891, 0.08308217541447707, 0.14639813719051226, 0.17695062847009727, 0.08144238697631018, 0.10316678482506957, 0.10963251787636961, 0.11759370139666966, 0.17723794733839376, 0.10669579117425851, 0.10145728369908673, 0.19868863773133072, 0.05878650303930044, 0.099623529240489, 0.14357145529772553, 0.1377051400818995, 0.16196601039596967, 0.10803135843681437, 0.1607732679694891, 0.13963458154882702, 0.1599974310291665, 0.11885870780263628, 0.13262550479599408, 0.17370747535356454, 0.20878644660115242, 0.14490352810493537, 0.1246656376336302, 0.2605120124561446, 0.1871336477675608, 0.08731700746076447, 0.19099692760833673, 0.15678445915026323, 0.1043654712183135, 0.13929770248276846, 0.08957057832075016, 0.12049464216189724, 0.0936716982562627, 0.14243881750319684, 0.17517254102442945, 0.1353416261928422, 0.167198316061071, 0.21185810677707195, 0.13063171106789792, 0.11542040801474027, 0.1732593843979495, 0.15432840665536268, 0.1333210981850113, 0.10616586211004428, 0.17359520494937897, 0.18017550185322762, 0.1920907531997987, 0.11300904383616787, 0.14484503838632787, 0.16050280391105584, 0.13417088187166623, 0.0999633531485285, 0.09971116203814745, 0.28763229719230105, 0.07772862911224365, 0.14250805521649973, 0.14468498554612907, 0.10849799375448908, 0.10300319003207342, 0.10329527221620083, 0.12606211698481015, 0.07872178046298878, 0.19377533851989678, 0.06398102108921323, 0.07750835628913981, 0.15137680646564278, 0.14793052710592747, 0.1330378098147256, 0.25590937371764866, 0.12777150954518998, 0.0926144253462553, 0.19578590563365392, 0.09903194848448038, 0.08151897322386503, 0.09986012083079134, 0.23056533081190927, 0.15779544918664865, 0.2461438434464591, 0.11505300844354288, 0.14395851881376334, 0.08858416482274022, 0.17414183276040213, 0.07315472633178745, 0.15455602801271848, 0.09513960698885576, 0.11224044686449425, 0.12488556440387454, 0.08675759604998998, 0.16573802727673734, 0.13082320722086088, 0.17243967338332108, 0.12120520403342587, 0.15389723836311273, 0.0982435450756124, 0.11635704418378216, 0.1280859833849328, 0.17145905457437038, 0.09614406273301158, 0.17030540933566435, 0.11460617956306253, 0.16838311962783337, 0.15915057861379214, 0.09097954271627323, 0.15105747431516647, 0.12319333877946649, 0.1487847212702036, 0.11483913420566491, 0.11956564629716532, 0.07047371233680419, 0.14015068885471138, 0.09657837264239788, 0.14234979370875017, 0.21337151128266538, 0.12813671066292695, 0.10916343304727759, 0.10163248822625194, 0.12456475304705755, 0.14970600897712366, 0.11724744497665338, 0.0817219569746937, 0.10693434373076473, 0.10634998258735452, 0.1594524724142892, 0.12822774292102881, 0.1365512777119875, 0.053054296877235174, 0.1935656847698348, 0.0727926396897861, 0.10510527794914586, 0.18932364668164933, 0.06380760789449726, 0.10229603440633842, 0.119272220613701, 0.19284820184111595, 0.09410912942673479, 0.08177963923662901, 0.13912069983780384, 0.11909875992153372, 0.09345480453755174, 0.1667443761335952, 0.06593475410980837, 0.06346346171838896, 0.13776947877236775, 0.08460313880017825, 0.16435214664254869, 0.1883659487856286, 0.06932595678206001, 0.09020885585674218, 0.15099822463733809, 0.14206787597920212, 0.15613029710948467, 0.12041935191622802, 0.19821002627057688, 0.10273145711315529, 0.14410536736249924, 0.1799887961574963, 0.10990309728575604, 0.11406322941184044, 0.10101258541856493, 0.09084910114428826, 0.057272033233727725, 0.06967445915298802, 0.09224790787058217, 0.2508975512215069, 0.15004979552967207, 0.11931998947901384, 0.19249853917530604, 0.14060933781521662, 0.13471244781145028, 0.24548414455992834], [0.04034707981294819, 0.04473685533074396, 0.047150838654488325, 0.07073936558195523, 0.05122027439730508, 0.037491977480905395, 0.020719115988218358, 0.05832879724247115, 0.02631733862550131, 0.009630663802714219, 0.08603206569594996, 0.0516489965708128, 0.022776983778125474, 0.007715722629135209, 0.044583258751247606, 0.03922278121379869, 0.025841549870425036, 0.012487435330902892, 0.021444627682545354, 0.03925056383013725, 0.02676633881804134, 0.016045371868780682, 0.014560403069481254, 0.011767250984641058, 0.023891530132719448, 0.007442028744013182, 0.023760661083672727, 0.04332159073757274, 0.02498672975759421, 0.017792480798172097, 0.05987236262964351, 0.035791253205388784, 0.045520807549889596, 0.060199382581881115, 0.019751903334898607, 0.024884499975347092, 0.049640308999057324, 0.04957453520702464, 0.029606545610087256, 0.051228640734085014, 0.03193472478804844, 0.06145795647587095, 0.08778276746826512, 0.06086043853844915, 0.02443771011063031, 0.05739458344344582, 0.04357365971165044, 0.045112285363887034, 0.009751833193669361, 0.08805565389671496, 0.029613666835107973, 0.030246064865163395, 0.02171034029951053, 0.01857049753224211, 0.05235728874270405, 0.02536803251132369, 0.0074398039973207885, 0.039066463708877563, 0.04416860600135156, 0.01004404854029417, 0.0783879751605647, 0.01045881664114339, 0.09235498748187508, 0.0372500458200063, 0.040176251836653264, 0.022846090873437266, 0.059798626229166985, 0.03447789100131818, 0.04904327621417386, 0.04354256923709597, 0.08798397345734493, 0.031383764530931196, 0.020859705051407218, 0.04923358153817909, 0.032134631382567544, 0.027449908566528132, 0.034912777665470324, 0.023287248897499273, 0.010086118559619146, 0.0347874318914754, 0.033607965002634695, 0.019343749254143665, 0.04314173824552979, 0.061847706990582604, 0.04281010764784046, 0.039321487702961476, 0.019575353612058928, 0.049326303348477395, 0.02610428032598325, 0.043979728993560584, 0.030053299851715565, 0.04432654520496726, 0.09354891055928809, 0.04052427244771804, 0.0318200286211712, 0.01552041816259069, 0.025606625779931034, 0.08177302352019719, 0.12421419471502304, 0.05008997415591564, 0.021029001234897544, 0.0419581424711006, 0.048530035718743286, 0.042320483563733954, 0.05814475140401295, 0.05376878068117159, 0.0600592718858804, 0.00769606716598251, 0.018737485000331486, 0.030436139487262284, 0.0056454236536020675, 0.04224069123821599, 0.05641769996977278, 0.023022133391350508, 0.014005730377643235, 0.047309853336108584, 0.046086417378059456, 0.029434747328715663, 0.03097605997962611, 0.038385177230728526, 0.011597526475920208, 0.011398115211964717, 0.01088628776571048, 0.058997792058757374, 0.02933012062151517, 0.04142460020791207, 0.010695029100004052, 0.013869273592717946, 0.02755756662892444, 0.06429812764482838, 0.026525606467787708, 0.05811633435743196, 0.023541368743670837, 0.019701128559453145, 0.008362075580017907, 0.04764506320602127, 0.003938268986530602, 0.08191444378878389, 0.01143284687506301, 0.01217917347925582, 0.023653550938303982, 0.06948104274592229, 0.014922537208933915, 0.06140333440686975, 0.054414036949830394, 0.050976293560649664, 0.030200599626238857, 0.022633366752415895, 0.056298345659992526, 0.016527157177084258, 0.010707537044904061, 0.022080174115087305, 0.0038987561960571577, 0.01822032087615558, 0.027890016557648778, 0.033555320863212855, 0.024887229382459606, 0.023886446209092225, 0.020310831289472323, 0.017658751724021773, 0.019717264122196605, 0.00807449293123292, 0.04797778624509062, 0.07171633387250559, 0.06246212723531893, 0.10816510447434016, 0.012136621700067605, 0.02198970164837582, 0.020255925932100842, 0.04241210614730205, 0.02041548683441111, 0.010816556418181529, 0.05722501754228558, 0.04425848814259682, 0.0413070609793067, 0.004995406189534281, 0.005218365587227578, 0.009980608060556864, 0.04503754473158291, 0.047688994955803664, 0.030172043479979038, 0.0025790552026592195, 0.07703303572322641, 0.07155852698321853, 0.029171913396567106, 0.033322824231748066, 0.05604449213881578, 0.02601113443129829, 0.04891822560291205, 0.017029320588335395, 0.01289652578998357, 0.040112781671008894, 0.0034778064291458577, 0.026374866520719867, 0.04321950514401708, 0.01118313750651266, 0.04184103411223207, 0.0829523920214602, 0.012253076120811914, 0.07760717812925577, 0.04400161514058709, 0.027008826877655726, 0.04042733693495393, 0.018667361798829267, 0.018041233432346156, 0.13502754590341023, 0.04788293044215866, 0.05739387098167624, 0.052362075807260614, 0.04626007145270705, 0.026941923324816992, 0.040114030175443204, 0.02953934689451541, 0.04167182104928153, 0.027646366506814957, 0.05570187945184963, 0.05338510984022703, 0.036195375091795406, 0.04061965072261436, 0.028744263308388845, 0.014958396088331938, 0.03882750403136015, 0.017741356577192034, 0.0055100359854155356, 0.03179561832387533, 0.037291080225259066, 0.04142447807160871, 0.019458570949999348, 0.032979332841932774, 0.05110531020909548, 0.022667800708274757, 0.01355657581838646, 0.04083526201014008, 0.037301909644156694, 0.03955262726438897, 0.019316689277599965, 0.020150255977309177, 0.007512406396147395, 0.013311561063996382, 0.0061563596744755545, 0.012620910802589995, 0.050484640656837394, 0.031395102851092815, 0.0058704309547985235, 0.055779863481542895, 0.10580390438969646, 0.017032251859615957, 0.01779036207257637, 0.06428509977247034, 0.09556182540420975, 0.033872098329343965, 0.03913352332477059, 0.030850564927927086, 0.061917596097503386, 0.06388995490436043, 0.062071107860122404, 0.042442942171224525, 0.052618616327111206, 0.05569358096857156, 0.1049279903194734, 0.026998409668781927, 0.09509254379996232, 0.06840340021465506, 0.017948017987821783, 0.04956972100106733, 0.03199521279228585, 0.014381112065166235, 0.04745527356863022, 0.07856723732714142, 0.1160314559404339, 0.01600063605500119, 0.05185562405469162, 0.07836093554007155, 0.06784964778593608, 0.09188591622348342, 0.03400539653375745, 0.051467725940580876, 0.0469673085026443, 0.050971174013933966, 0.09456412786883966, 0.019956856533618908, 0.0852142885061247, 0.038677985447325876, 0.011559551415432776, 0.04401856494535293, 0.03935124146352921, 0.02086684663247849, 0.04982776786865933, 0.05327167574848447, 0.031604067888110876, 0.03991894117955651, 0.06374253638620887, 0.07361644905592714, 0.015487263245241982, 0.04622902847560389, 0.01816115092619189, 0.023472069962216274, 0.014364686428702303, 0.007077629145767007, 0.03023945932675685, 0.07219333720526525, 0.01227553393359163, 0.015423922001251152, 0.011589841218665242, 0.028675453072147708, 0.0012192506692372262, 0.01699074587252523, 0.039233488496392965, 0.025143342425248454, 0.013847607969572502, 0.022285844864589826, 0.018267560484153882, 0.018583031770374094, 0.05750871303358248, 0.02796096078652356, 0.038373031453894715, 0.04446090531668492, 0.039118042548320124, 0.005915686271951667, 0.036989152498011074, 0.06110356442098107, 0.055290361533739736, 0.028044396845091666, 0.031556380447000265, 0.0410293332034988, 0.015994544506871274, 0.06602804588952235, 0.02284432837872633, 0.030361907756222144, 0.026976959480504905, 0.0559080760659916, 0.024084888864308596, 0.04770234852497067, 0.060184156256062646, 0.005842625437903085, 0.04381552351904767, 0.018727824358003478, 0.0383199734081115, 0.04112250284690942, 0.012458247298906957, 0.033868804041828425, 0.07785940995173794, 0.03243971090497715, 0.014885996401842152, 0.0272492878139019, 0.026662236279142753, 0.017871180682310035, 0.05954842322639056, 0.02749340096488595, 0.04740729775013668, 0.040432904314781935, 0.0332250642989363, 0.09325880969741515, 0.09591766952403954, 0.10091173475874321, 0.21192449464329652, 0.11991704601262297, 0.08857440070382186, 0.20381824033600943, 0.13773844258061477, 0.05979589851839202, 0.1022661720801677, 0.21392890065908432, 0.14208755349474295, 0.1991572611566101, 0.1509100150849138, 0.24796443432569504, 0.1743599817688976, 0.11235444753297738, 0.08851130373243775, 0.12349295270230089, 0.12658146768808365, 0.08828689184572015, 0.1345750308994736, 0.04193749125780804, 0.23118684174759047, 0.13443438416080816, 0.15028144738503865, 0.1518341526389122, 0.07839111677770104, 0.08027452642896346, 0.14741352413381847, 0.14029554251049245, 0.1292367380644594, 0.1959910946232932, 0.11889894492924213, 0.05948412524802344, 0.09628239566726343, 0.16662679958556378, 0.1353902771536793, 0.09286136459559202, 0.1488785355218819, 0.1619204535548176, 0.11641839732016836, 0.15031382707612856, 0.12134670572621481, 0.09438088270170347, 0.13889573833772115, 0.08563205573175635, 0.12311222670333725, 0.06837759552789585, 0.16915043416832173, 0.07321823720953294, 0.07429427839815617, 0.11609500753028051, 0.10238659847527742, 0.1148090615336384, 0.118381317704916, 0.07289835544569151, 0.11486863690827574, 0.14110416626291616, 0.09619627600269658, 0.1344970129430294, 0.09581162128597498, 0.09449626758162465, 0.06631763106478111, 0.13402613678148814, 0.12686884083918162, 0.10669501764433724, 0.14515329684529985, 0.10320867079177073, 0.1831468338412898, 0.08096779922821692, 0.10153623803385667, 0.1321917444999729, 0.17355856405837194, 0.11198094114661217, 0.08090664965233632, 0.17374345128025326, 0.11550065156604562, 0.2445592741881098, 0.1662713015185935, 0.16994489010955605, 0.2528669312596321, 0.17084096345518315, 0.2265270296484232, 0.1943648090319974, 0.23563626727887563, 0.2520909586123058, 0.18226999017809117, 0.1580024566501379, 0.1536468317998307, 0.18290839663573674, 0.1482590330498559, 0.20603092946112156, 0.1277573960168021, 0.14377706497907639, 0.1519242213772876, 0.1864120936287301, 0.20278603929494107, 0.18460474775305816, 0.1342195871153048, 0.12127289468688623, 0.197533038311771, 0.12542649252074106, 0.15937564867947782, 0.19006337198827947, 0.14949019412909234, 0.18865136775587285, 0.11298369376787118, 0.16663160361349583, 0.12282899261585303, 0.05323626300586121, 0.13988553094012396, 0.19436692606125558, 0.14997251039104803, 0.11486710341913359, 0.22499203415853636, 0.14920150462005818, 0.1346211712807417, 0.10183009119438273, 0.1116472240537405, 0.18350910368774617, 0.06149468557643039, 0.10237979955439057, 0.11804092382746083, 0.11486688628792763, 0.1201158839144877, 0.06527760651494775, 0.09293826975460563, 0.09022255547876869, 0.0903841485934598, 0.059951201613460264, 0.14610639427389416, 0.08739334943571261, 0.09858878369310073, 0.13833419632698807, 0.1992344105882304, 0.08927533416343586, 0.14018644765019417, 0.15841063617595605, 0.10725230524050337, 0.20920968960438455, 0.14262427469449385, 0.10665550655020134, 0.12207022761659962, 0.09000736488295452, 0.1411462082926716, 0.08509473063583885, 0.11173571180552244, 0.10985327924468688, 0.1672259188656296, 0.055179102146731954, 0.09419860105429377, 0.11307110264897346, 0.044755966269544194, 0.1330941960747753, 0.12129436353487627, 0.11463921064777033, 0.13909110214029038, 0.06939828182969775, 0.06879747978278569, 0.12496341951191425, 0.06765969190746546, 0.12468698434531689, 0.11330050855342831, 0.10055675237838711, 0.309651002820049, 0.12896866244929178, 0.16169086444590772, 0.1525946818292141, 0.21524966907288345, 0.1620932492826666, 0.2920709475874901, 0.14350261113473348, 0.15144706198147365, 0.14428353708769592, 0.12787334408078874], [0.05596587707155517, 0.030819952820560763, 0.039185499107199054, 0.10043296723493508, 0.02835188007780484, 0.02359551244548389, 0.03175183245912194, 0.05046333804992693, 0.007513795696598078, 0.04966941475868225, 0.007929316971317997, 0.04795920456360493, 0.021648388355970383, 0.022063780709036758, 0.046422366851142476, 0.02615121120054807, 0.035381740358258994, 0.04823067285386579, 0.010074756490731878, 0.029794197862169573, 0.06708618732435362, 0.032678219356707165, 0.026252151766259755, 0.02105929103813001, 0.018349313775875738, 0.005514739929432315, 0.01907008420675993, 0.06948262373251574, 0.041212510517133136, 0.09839891602418252, 0.04246370873547026, 0.032429987498159916, 0.0011607966797393082, 0.036962292689297876, 0.03607821584280048, 0.039216779571558745, 0.04053928503500564, 0.05745269996779306, 0.04714125434734991, 0.008918319080424095, 0.055802099074104, 0.03720560856163502, 0.037227023126823564, 0.021839336591905782, 0.01572352065704763, 0.1394399098519768, 0.02558893637199487, 0.060402115274752886, 0.06208621883498771, 0.03648999160421746, 0.016779324538739662, 0.051379560492932796, 0.022493576664211493, 0.09676397911139897, 0.020792248492528285, 0.05774513499013015, 0.019042408459686806, 0.025598225516400168, 0.06999128750924553, 0.039648270167942555, 0.06946069348071303, 0.0206682139874569, 0.02370007469185761, 0.02988695359921881, 0.07097164847488914, 0.021733897339020456, 0.0710136905046446, 0.05615559207009418, 0.014763578506452697, 0.0668220811390451, 0.13161169205393108, 0.0882300373965076, 0.04106207251814859, 0.05435687376718436, 0.032729214656033685, 0.1537486391940287, 0.059208341475043974, 0.30233104846307207, 0.45648709365299767, 2.0181492269039154, 2.304054353918348, 1.9065329304763248, 3.5992917205606187, 2.9365618995257785, 4.102916044848306, 4.081979385444096, 2.052786214011056, 2.1229543345315114, 2.377612326826368, 0.7606293420706476, 1.1508223158972604, 0.7895435648305076, 2.564963770764215, 2.690155544451305, 3.651132881641388, 2.4356638746602193, 2.2767787660871233, 1.1743332828794206, 0.2980041934975556, 0.6858523402895246, 0.25090075390679495, 0.039600752360586605, 0.026605514144258838, 0.026549728387700658, 0.042429944832942317, 0.048183195758610964, 0.007874991761387458, 0.03538876319570201, 0.038676594450537644, 0.04418342859883394, 0.030301643668540885, 0.040367652994713614, 0.043225778200264485, 0.018239204505724565, 0.06120276624070747, 0.01839668909087777, 0.031984987269554815, 0.06057735372866903, 0.044582865200936794, 0.030408421331750493, 0.031550219349030934, 0.013264666660688818, 0.0438553195978914, 0.02488009289040097, 0.029027253123266355, 0.004383078377161707, 0.017032077136848654, 0.022433338021593432, 0.05209784409297364, 0.043017094755279164, 0.01607338009801294, 0.017093328492982045, 0.015785201186580316, 0.018315498983221393, 0.040744721689926724, 0.03445112958018269, 0.011854469027769352, 0.040304064085440974, 0.015370297378727367, 0.036914347404880185, 0.006875956663861871, 0.03430850491193788, 0.03719831770285964, 0.012937511001447482, 0.01414229572817151, 0.042838925030082464, 0.004717437957879156, 0.07861563044467143, 0.041643719521484206, 0.014288987365684338, 0.00961624238906162, 0.017985366251585738, 0.02263470516274018, 0.01993497208292995, 0.05662972180704985, 0.06450833779360567, 0.05915386189839669, 0.023741916553782563, 0.0580191681427615, 0.03522461200399058, 0.023533950659579465, 0.04211017842005406, 0.02246699675119349, 0.03944088951019304, 0.055065009876021316, 0.01042970409616828, 0.038443331074501784, 0.06007745662438018, 0.028380410779001455, 0.02313227828459016, 0.06751371866890363, 0.03546749361391578, 0.015411589627287217, 0.021202780838523592, 0.054978896996804645, 0.0218041596402015, 0.024301199042903524, 0.0199088416993618, 0.021404896064528396, 0.0772475613547223, 0.031275283744824786, 0.0500429516791233, 0.0318795191789312, 0.016957825049757957, 0.00466400247699182, 0.04884965963927763, 0.026273296613778387, 0.0585897278838924, 0.042060594473566325, 0.012924349966592022, 0.09363024655197348, 0.03236822384808745, 0.024331646605527828, 0.015080410255385297, 0.016310991187180792, 0.06896273698657751, 0.03492607695183583, 0.03379522370440619, 0.02087005440677915, 0.0517366022270705, 0.07241446498249259, 0.02155365129666669, 0.04164567030966282, 0.01714720417346273, 0.008593007340095937, 0.10770077617572886, 0.054353386097188504, 0.05715323532266276, 0.021662924272407378, 0.036314749757626226, 0.050627719943544695, 0.0661067830930863, 0.0029493455450782286, 0.0550656205575381, 0.04121828145746674, 0.028671758448971168, 0.029074089002928565, 0.06074045319110155, 0.06048440121646438, 0.06019601704818862, 0.015856228535994887, 0.042791261337697506, 0.07483895202832562, 0.012164474714414349, 0.011189742196750427, 0.028725413605570793, 0.021917712475572313, 0.07014047021844558, 0.01571709832309612, 0.06346366527889456, 0.009520258521661162, 0.06185690114008529, 0.016698446557191864, 0.004317805004705275, 0.017888501984998584, 0.055085308251104186, 0.02996291220188141, 0.038633273382272036, 0.021487054780923893, 0.0688680609954255, 0.05621442444888609, 0.018994734589276568, 0.04351164839629616, 0.04695913215566959, 0.016125323650028025, 0.10521056622798954, 0.070531340315938, 0.09866060662482466, 0.0929178526358945, 0.1664411931165627, 0.10219626261719636, 0.17934608778783254, 0.11318086925894022, 0.4476768864052636, 0.43327199508036884, 1.8249124416283198, 2.5327458424227576, 2.3501196077891757, 4.6324825542313715, 3.959526070526668, 4.965632174696241, 4.952668138912745, 2.531333838190351, 2.862413546868733, 2.6723685903208594, 1.2320824755089623, 1.5772405373198646, 1.1439009330102374, 3.0258568908487047, 2.9294645317963193, 3.746554664203099, 3.217731829200472, 3.345490093742098, 1.9572995092187608, 1.0537027844360896, 1.1678620129823685, 0.40991258567997385, 0.08318153329725776, 0.01856215494418783, 0.04296781614954982, 0.0802260043897799, 0.02144214085170201, 0.05315617551761014, 0.048016737547836134, 0.04130674546052303, 0.0465298875101975, 0.00748014629685453, 0.07435886136123113, 0.04307549287165914, 0.014744793264461415, 0.05800169586603131, 0.004789096344861069, 0.03515467539961849, 0.029216116560356956, 0.06569113968206303, 0.013683727343699761, 0.058132680266031196, 0.02396453371537583, 0.03312228999233671, 0.022622898653415695, 0.01583467996014016, 0.11607385080839906, 0.010623351205140352, 0.0224393040407449, 0.020557132715891515, 0.02183125015082104, 0.011290508887863584, 0.06908281732882772, 0.03674046941367643, 0.03270905198795455, 0.01935940475336143, 0.017022518274773444, 0.030282044184527228, 0.04350630154034921, 0.047922119232160706, 0.01652551512233913, 0.03885123918631247, 0.020170842729774967, 0.027969201594325047, 0.03451517989326801, 0.11372065065162522, 0.01235431439376303, 0.009372978255019655, 0.05040088229413543, 0.0305327730519431, 0.047358999627509286, 0.024880301539919207, 0.024957781757361124, 0.06275927807603564, 0.037652020143078904, 0.006855969142634422, 0.040757630818656514, 0.012061681748101754, 0.052171037665435245, 0.026401073239477615, 0.00407073598554624, 0.08740545450044529, 0.009804947218591613, 0.026016477894570147, 0.07890964645360198, 0.007728904020041227, 0.009865065421243864, 0.0049475906749389, 0.04335331224969455, 0.06651569543672459, 0.013240862804065858, 0.09292684322489159, 0.04426459835043975, 0.007395145366899669, 0.044515517207660844, 0.03890970515619431, 0.007033654563461563, 0.20312925587807382, 0.09545715459223304, 0.11476720949368817, 0.15912436002067157, 0.13532363144414766, 0.12054995633661747, 0.1426388496266944, 0.09262337522315127, 0.11733565452907767, 0.1263248457440308, 0.05393704040242093, 0.14923566207289696, 0.11160300392657518, 0.1177772722606148, 0.16946268241320336, 0.10422600513058049, 0.0556665006359773, 0.12243669080947127, 0.07089331160698618, 0.195203410461545, 0.10909509100019932, 0.1298796907067299, 0.13515929026263102, 0.1236461659095117, 0.12314738838800363, 0.1399208554731948, 0.17682587302156857, 0.14794553630053997, 0.1070465123546975, 0.28247467109135216, 0.21512697637081146, 0.0696580046787858, 0.07981039490550756, 0.1539247597434691, 0.08207808607923132, 0.13815388243113244, 0.19175956025719643, 0.11883094214967319, 0.16828634696347372, 0.0766060132799404, 0.15578030874686583, 0.11299217545560428, 0.11766008926289422, 0.1596999205648899, 0.10142824240028858, 0.2461731018764632, 0.26842397504619186, 0.12377124705484935, 0.10538874273853642, 0.10319092710103307, 0.09910009375640325, 0.18294332761849674, 0.14544266488935265, 0.1863657496869564, 0.12694836514336721, 0.1428690901292222, 0.10732098655509097, 0.13146405640457356, 0.17612244933843613, 0.11401030368038587, 0.17380666360259056, 0.18190846672015532, 0.09020837409687893, 0.11751667410135269, 0.11256980097719602, 0.1354864119951214, 0.23903789903436387, 0.15333214082888194, 0.09838881263775484, 0.20023012001599583, 0.3651868413601603, 0.18757867174489157, 0.1440436342465026, 0.3674762456544808, 0.17258154148502008, 0.4158923519509179, 0.2855665108987263, 0.8029517967786107, 0.8702141046524048, 2.64839882510049, 3.466373550040381, 3.006938248872757, 6.0266629202025275, 5.681693545409611, 6.72634174142565, 7.1063026785850525, 3.5230167848723273, 4.279695587498801, 4.420948990753718, 2.3335088534014563, 2.5714490456240515, 2.09696763753891, 4.253763607570103, 5.045776605606079, 6.381435768944876, 5.604454330035618, 5.555647577558245, 3.712319152695792, 1.9254116203103746, 2.3839749225548337, 0.7297133324401719, 0.17652577055352076, 0.12423769916806902, 0.14596713174666676, 0.11658663329269205, 0.15649348976356642, 0.09857416804879904, 0.11225958155202014, 0.13198181933590344, 0.09052933473140001, 0.1756254088665758, 0.12566198488431318, 0.11943269414561135, 0.08878542509462152, 0.11103338056377002, 0.08115028443613223, 0.14556811244360038, 0.1478665005415678, 0.10746528381215674, 0.16618993159915718, 0.22213333898356982, 0.06436661218426057, 0.19235460832715034, 0.10968540968107325, 0.1127731850636857, 0.14081078129155294, 0.12365000641771726, 0.09654318381633077, 0.0751351122079151, 0.17033420636185578, 0.11934740229376725, 0.14094652900738375, 0.15962625880326542, 0.11653532247458186, 0.10126850168619837, 0.10735504901302712, 0.08186497180057423, 0.1405051148363522, 0.09648069074111325, 0.15022191272250243, 0.2398356662264892, 0.14986486759568962, 0.10352744654353176, 0.20233040302991867, 0.15734988238130296, 0.14876912853547505, 0.0965791190309184, 0.23191262994493755, 0.12886647507548332, 0.09395280852913857, 0.07032873654471976, 0.14459856732615403, 0.11896417928593499, 0.10844498659883227, 0.1692803736243929, 0.19026336339967592, 0.13795944143618855, 0.14379584682839258, 0.1869403195700475, 0.07617591028766972, 0.2383293727678912, 0.09615723988307373, 0.1316955725529364, 0.13528137228318624, 0.11059777465249811, 0.14458685581173214, 0.11857860854693822, 0.12783326980258736, 0.1405207754245826, 0.10266273508646659, 0.23879634056772503, 0.1309950394289834, 0.12194110240255084, 0.109885848925582, 0.18842591771057673, 0.12720740267208644], [0.04485415367941771, 0.07406430252428566, 0.038402439161602936, 0.006058285495133272, 0.0565694543266935, 0.020934513537213206, 0.03197925364864724, 0.0869344969147018, 0.024544818559661508, 0.06225752857114587, 0.048512339525456936, 0.11080003237085682, 0.04947549284302762, 0.032179065248263736, 0.017188791584755694, 0.11803865752049855, 0.019637420906552246, 0.06854006395276104, 0.018500672886148095, 0.025513590147186602, 0.07667360893849816, 0.12694828371916497, 0.06421410465346915, 0.035747996597949944, 0.13293476748679364, 0.05970109360558646, 0.010926861615319337, 0.11784380940454346, 0.07013103179633617, 0.02070812032824116, 0.0496080921563719, 0.03593190672940441, 0.07203913333692721, 0.01624308679518955, 0.03587576813463654, 0.04797188977577856, 0.02880134167415755, 0.025081675466416136, 0.02605450808602784, 0.0493628492445818, 0.041445041075348854, 0.07541887555271387, 0.04350982992244618, 0.0761278292962483, 0.06852641861353602, 0.09708923487258808, 0.033704028597899845, 0.039808183908462524, 0.021973371006814495, 0.06656666698732547, 0.07159927979643856, 0.03560796732615147, 0.04473369675023215, 0.07033096892493111, 0.04267234807567937, 0.014534830780965942, 0.06901214790663548, 0.03182717698759266, 0.06317983408059392, 0.057019950688949654, 0.021236877223210673, 0.019984131945031028, 0.0630487139735903, 0.07059431515101876, 0.07697702265743699, 0.06446013466588088, 0.09353544163916792, 0.055510980409703085, 0.10094313057405607, 0.22641037590801716, 0.2736282300736223, 0.5077301125441278, 0.8755675288183349, 2.7344722407204762, 3.115277601139886, 4.977270407336099, 6.142362151827131, 10.05200753893171, 19.699989489146642, 16.139199256896973, 23.34371863092695, 29.804002557482036, 29.879526002066477, 27.502460411616735, 30.862838540758403, 26.532844509397233, 27.939550740378245, 32.50557681492397, 26.8024537222726, 26.507903950554983, 23.41538061414446, 23.758176939828054, 21.09605281693595, 21.011687789644512, 27.692752463477, 27.88220030920846, 33.673829555511475, 22.267387083598546, 27.098255906786235, 21.297432456697734, 15.98729773930141, 5.963832965918949, 2.5264507744993483, 0.4426961950957775, 0.054805249707507234, 0.09570049082062074, 0.09098621950085674, 0.04363777109288743, 0.08377301227301359, 0.06658884829708508, 0.022494109314201132, 0.09821866998182875, 0.054710702638008764, 0.04842122245047774, 0.06009830800550325, 0.02175995647641165, 0.03204402320885232, 0.06395392040056841, 0.09218329098075628, 0.05236154654994607, 0.06337592391563313, 0.07636419696999447, 0.011049516997965319, 0.027734489546024373, 0.06381216764982257, 0.03498203573482377, 0.039501944091171026, 0.06431487388908863, 0.0647421677463821, 0.03733435379607337, 0.1072505342641047, 0.019438932450222116, 0.00944327109027654, 0.08584913265492235, 0.04631178599915334, 0.007868062222509511, 0.07067032464380775, 0.08183875320745365, 0.005938217875414661, 0.03494444828746574, 0.051550357935151885, 0.021748925193345973, 0.03572882119832294, 0.0812422666432602, 0.03383007326296397, 0.04118005618719118, 0.07577248050698213, 0.04635235560791833, 0.05343442576538239, 0.055008477730942626, 0.06328702225748982, 0.12119064267192568, 0.04718514199235609, 0.08837608527392149, 0.055591549657817395, 0.09514008874871901, 0.0633330676438553, 0.02418750710785389, 0.06276806510452713, 0.03837977948465517, 0.10893682270709958, 0.041479374947292466, 0.011259833167839264, 0.06440634719495263, 0.06546713491635663, 0.06530111096799374, 0.016222876629659107, 0.07159921872828688, 0.0573697422764131, 0.0632274875949536, 0.03822889704523342, 0.08656351467860596, 0.00436026942250984, 0.018057886378041337, 0.0322122150765998, 0.01756930384518845, 0.030421781686267683, 0.06183241281126227, 0.07744338656110422, 0.031011265769068683, 0.011192554724402726, 0.016848976158403924, 0.07574434165975877, 0.049359795836997886, 0.01472690368869475, 0.06462141565446343, 0.005597413060188825, 0.05198316828214696, 0.0737865035023008, 0.01631121171106185, 0.040904652393822155, 0.053018938417413404, 0.010695992619730532, 0.1181720167930637, 0.0393936193681189, 0.05671949538269213, 0.01179319986009172, 0.07052285862820488, 0.033040523129914484, 0.135410606062838, 0.09881398946579013, 0.049138121839080534, 0.06760713258492095, 0.03351386237357344, 0.03766251029446721, 0.038348845073154995, 0.03243474063596555, 0.041572531020002704, 0.061871055380574295, 0.0407068322944854, 0.06114253268710204, 0.036008055321872234, 0.01802452450751194, 0.016881303263029883, 0.02418018232232758, 0.05733054330838578, 0.03100906392293317, 0.07986701865281377, 0.019763345131650567, 0.03936484609065311, 0.06718947392489229, 0.052034173759498765, 0.05459178598331554, 0.06451062445661851, 0.043714011287582774, 0.05875873060098716, 0.020301628658281903, 0.04790245867999537, 0.042394952782030614, 0.07213735806622676, 0.046147231079105816, 0.032724800785737376, 0.08414398772375924, 0.014394121277811272, 0.019422189598636966, 0.05060356070420571, 0.057189720150615485, 0.043800419329532554, 0.029035436255591254, 0.11870206120823111, 0.06659861241600343, 0.06289561611733266, 0.06106893877897944, 0.06981520088655607, 0.12373297767979757, 0.1983981297484466, 0.416225865483284, 0.6787511184811592, 1.450655541249684, 3.480561771563121, 3.870939144066402, 7.410615972110203, 9.505638548306056, 14.890769515718732, 25.999502522604807, 23.465774161475046, 32.812391894204275, 39.83673231942313, 38.711075510297505, 36.74314764567784, 38.338499205453054, 32.21413809912545, 34.67247676849365, 40.1457256589617, 32.17236205509731, 32.86805043901716, 29.037611041750225, 27.393241677965435, 24.288932459694998, 25.335642099380493, 31.86864239828927, 32.950754846845356, 39.356007303510395, 26.046988248825073, 33.15356581551688, 28.30754123415266, 21.788300105503627, 9.37202729497637, 4.094109637396676, 0.5858055001923016, 0.0949150322537337, 0.09771130220698458, 0.09171343940709319, 0.05328009297539081, 0.03606927614392979, 0.06915736797132663, 0.07871962272162948, 0.11861501873603889, 0.09839966919805322, 0.06701331266335078, 0.07533971765743834, 0.029842872571732317, 0.01470684788988105, 0.05689462527100529, 0.06788023614457675, 0.015379308323775018, 0.09106520097702742, 0.04989601492083498, 0.05286046317113297, 0.030366175741489445, 0.047594542881207805, 0.020000730607924715, 0.038883713872304985, 0.07584354347948517, 0.05939769345734801, 0.06907500739076308, 0.10980526610676732, 0.07566293781357152, 0.03561744646036199, 0.0810121347063354, 0.04310313638831888, 0.05924968461373022, 0.008148721269597965, 0.0906881322818143, 0.04594327363052538, 0.015890967832612138, 0.01159944333734789, 0.022723493166267872, 0.043026170161153586, 0.05261880970959153, 0.05427874724513718, 0.07447611899780375, 0.05944913998246193, 0.10875861226980175, 0.05771261280668633, 0.07886778762830154, 0.09997463040053844, 0.045202086080930064, 0.0847919818812183, 0.07280954199710063, 0.06482672678040606, 0.11716558651200362, 0.04073847916775516, 0.0784510246344975, 0.0404089757773493, 0.03580893582797476, 0.0033434800321369296, 0.035450048478586335, 0.08102893523339715, 0.02078178887521582, 0.037343072971063, 0.1454974226653576, 0.0203029348381928, 0.0540857074250068, 0.04930696849312101, 0.011283601401373744, 0.026860994453142797, 0.01367599967800613, 0.035226019964154275, 0.03049269538106663, 0.044499503781220744, 0.030999608537448303, 0.16278462218386786, 0.2829615878207343, 0.19524142199328967, 0.14577235148421355, 0.1064516067770975, 0.1967290285974741, 0.15382387515689644, 0.16415762422340258, 0.13047735792185577, 0.16449423187545367, 0.15521610687885964, 0.2598170026072434, 0.13994005801422255, 0.257683769932815, 0.1456439048051834, 0.19909426596547874, 0.08189327349620205, 0.20567400647061213, 0.2131080904177257, 0.17991965343909605, 0.2155195360205003, 0.24311494454741478, 0.09867995844355651, 0.3193909658917359, 0.2675872870853969, 0.15292784252337047, 0.14244485646486282, 0.17997329841767037, 0.10540242878986256, 0.09465765713581017, 0.18812931648322515, 0.12602018352065766, 0.25095682804073605, 0.1305701272296054, 0.2854926862886974, 0.1461380547178643, 0.08695296663790941, 0.14491476464484418, 0.13374729960092477, 0.16561905294656754, 0.11034742237201758, 0.15994819652821335, 0.10123015767229454, 0.20233707981450216, 0.16902721220893518, 0.1589174068399838, 0.1427496951073408, 0.1549397667071649, 0.15319046271698816, 0.1988957944725241, 0.16859908375356877, 0.10187540376292807, 0.15147032216191292, 0.18535190980349267, 0.20444992929697037, 0.1755590752831527, 0.13769352356238024, 0.15027413277753762, 0.12052334419318608, 0.15766109925295624, 0.1285661690469299, 0.06885077192315034, 0.12303735714937959, 0.27767387298601015, 0.08250613989574568, 0.2683084341032164, 0.18095925051186765, 0.2736313784761088, 0.3255719042250088, 0.3885910340717861, 0.7176404574087688, 1.3266861076865877, 2.042185868535723, 4.744985614504133, 5.5910243306841165, 9.516076479639326, 12.275693382535662, 20.35890453202384, 32.70673758643014, 29.153161321367534, 41.41623156411307, 47.17151130948748, 49.580733163016184, 47.792336327689036, 47.95293698992048, 39.196441922869, 41.601376737867085, 48.956444467817036, 40.49611636570522, 42.77489273888724, 40.06815596989223, 36.749758856637136, 33.48476559775216, 36.322594029562815, 44.390182154519216, 44.81810086114066, 49.55080379758562, 35.63358286448887, 41.77742324556623, 36.910217080797466, 29.85707289831979, 12.33436918258667, 4.471484107630594, 0.6373724788427353, 0.26499452335493906, 0.18288496003619262, 0.150474449885743, 0.17330559263271944, 0.19682846111910685, 0.17415317786591394, 0.1478527398513896, 0.26689680985042025, 0.27077846441950115, 0.2585573430572237, 0.18929442896374635, 0.10555444099009037, 0.1255029769880431, 0.14993284323385783, 0.21926589070686273, 0.1211347585277898, 0.16276058847350733, 0.1518011215542044, 0.14561345215354646, 0.12189887038299016, 0.10733752923884562, 0.0771145209936159, 0.14295126071998052, 0.17905395132090363, 0.18548916386706488, 0.18178862386516162, 0.30030754847185953, 0.177040819344776, 0.09812560211867094, 0.22762469574809074, 0.17110776342451572, 0.16381195134350232, 0.2150534638868911, 0.17637514935008117, 0.1064269488145198, 0.10411213338375092, 0.09649657524589982, 0.1469833329319954, 0.20981813195560658, 0.13003479024129255, 0.2112716489604541, 0.13262766253735336, 0.23794838892562048, 0.18668571966035025, 0.16032747046223708, 0.2049031906894275, 0.17820912093988486, 0.3579626961478165, 0.3189197097505842, 0.21243463084101677, 0.10569654657904591, 0.29415649282080786, 0.1598565535885947, 0.21755314618349075, 0.1980478564011199, 0.08436307311058044, 0.15928256724561962, 0.08791820305798735, 0.1364771816879511, 0.15294984062867506, 0.20272742744003022, 0.18205743229814939, 0.15229683209742817, 0.12889970972069673, 0.22296877843993052, 0.14737393840083055, 0.11790651961096696, 0.1594543180295399, 0.14036589302122593, 0.19243995446179593, 0.09272634291223117, 0.09043896065226623], [0.10243538514311824, 0.037357471484158716, 0.07427616151315825, 0.054086416494101286, 0.03675014193036726, 0.023472443156476532, 0.04812265686424715, 0.04608860904616969, 0.0599347674953086, 0.037497083456920724, 0.07949144951999187, 0.00319596567091399, 0.02056366191910846, 0.03059835685417056, 0.035927085738096914, 0.03896812702129994, 0.04436145583167672, 0.04511519627911704, 0.036140077880450656, 0.06721088849008083, 0.018964188639074564, 0.014216091500462165, 0.06282933681671109, 0.022532629747209803, 0.015582739907716001, 0.013027175163318003, 0.046173850007887395, 0.03707179467060736, 0.018657285553802336, 0.049917300564369986, 0.06229826781366553, 0.03415260131337813, 0.02441624295897782, 0.016395068461341516, 0.05815012540136065, 0.05297244180526052, 0.033740303079996786, 0.014404049941471644, 0.025712368677237203, 0.0076673439304743496, 0.04182655078225902, 0.0758040188146489, 0.035852409566619566, 0.03031542132209454, 0.03684329121772732, 0.008467439345882406, 0.026185434810551148, 0.036057259288749526, 0.0356010259129107, 0.03563591279089451, 0.012022367429121264, 0.06389290653169155, 0.013681788429883974, 0.05243882829589503, 0.02982534601220063, 0.009384761015618486, 0.062016126167561324, 0.02468169603629836, 0.049133019255740304, 0.06391494534909725, 0.03706036135554314, 0.01910829760267266, 0.12997102152023995, 0.317347951233387, 0.4985571876168251, 0.9122033715248108, 1.95822731086186, 2.2944395669869015, 3.389049002102443, 6.59146374464035, 10.571877837181091, 12.19453842299325, 19.663216148103984, 24.456604651042394, 37.42491878782, 47.46582657950265, 55.45273917061942, 62.65740966796875, 69.80992003849575, 75.15202862875802, 78.92219761439732, 71.84416498456682, 67.17715031760079, 51.711033480507986, 66.2675199508667, 63.545674324035645, 71.05810138157436, 73.62819140298026, 72.71264117104667, 64.83484309060233, 63.19911207471575, 59.19587966373989, 50.64829955782209, 54.44596951348441, 57.29743378502982, 66.72635814121791, 62.28554902757917, 62.513762610299246, 61.45312704358782, 63.58759280613491, 61.00616332462856, 41.50885452542986, 27.94547060557774, 9.776784181594849, 2.3132403067180087, 0.504078128508159, 0.07642424731914486, 0.054572736112666984, 0.005392387767122793, 0.03591106552630663, 0.018201366000409638, 0.02491125970014504, 0.02021652679624302, 0.02587917972622173, 0.03424961825034448, 0.0837187837543232, 0.004201368395505207, 0.06617513871086494, 0.03744193213060498, 0.019356290277625834, 0.0332939898861306, 0.07498454528727702, 0.004891732399950602, 0.026154503791726062, 0.0695800342197929, 0.01955693308264017, 0.05076786795897143, 0.019393385787095343, 0.039385446413819275, 0.02152443357876369, 0.011537178419530392, 0.037118104685630114, 0.03272113669663668, 0.06786267565829412, 0.04034526473177331, 0.027699287149256895, 0.018945206621927873, 0.06894178382520165, 0.05725060509783881, 0.03660913896081703, 0.038084280876708884, 0.01342009358839797, 0.04681795955236469, 0.029826475773006678, 0.0215036687108555, 0.03299529537824648, 0.03605401249868529, 0.029892371701342717, 0.02459214298453714, 0.031180468653993945, 0.04199076643479722, 0.03196357948971646, 0.0824658688423889, 0.04809051126773868, 0.07387889961579017, 0.008168393696126128, 0.036588779517582486, 0.03631829510309866, 0.04442198794069035, 0.03340334937508617, 0.052028521562793424, 0.04615129889654262, 0.05746308155357838, 0.036458626322980435, 0.03891045154471483, 0.053391745912709405, 0.1724485079092639, 0.020092112311561192, 0.020356812215011035, 0.015708752342366746, 0.06107813971383231, 0.021409684825422506, 0.0250131417331951, 0.008863905660941132, 0.023708305321633816, 0.043130915611982346, 0.0795383770018816, 0.024786119182993258, 0.03776635329372116, 0.04763950261154345, 0.035050381174577136, 0.03257563843258789, 0.015098467768569077, 0.019683632533997297, 0.03137279261967965, 0.03966163730780993, 0.02393860010696309, 0.026475440677521483, 0.06558150199374982, 0.07058865616896323, 0.03413189242460898, 0.016234157274344137, 0.02853210915678314, 0.07760117987969092, 0.010765432197201465, 0.06789198837109975, 0.052579726092517376, 0.026260831925485815, 0.0488452559470066, 0.04367425592084016, 0.01679013020891164, 0.04056451635967408, 0.025055507763421962, 0.02723929299307721, 0.07561798486858606, 0.03582763286041362, 0.021379644383809397, 0.027511375357529948, 0.04645405104383826, 0.04334162448399833, 0.0400514285346227, 0.04857000143134168, 0.05224190725545798, 0.0038447180912563844, 0.04108730384281703, 0.035142885853669474, 0.029899513282413994, 0.06984023882874421, 0.047868908515998294, 0.04218027448015554, 0.028826199804565737, 0.050867846701294184, 0.0066711226328542185, 0.06242944898882082, 0.047386124064879756, 0.032563112676143646, 0.012356738460117152, 0.02925451146438718, 0.06824904706861291, 0.05973793127174888, 0.04033359732212765, 0.024937132240406105, 0.036501390992530754, 0.038853240864617486, 0.05166973938633289, 0.011828129146514195, 0.010069472399274153, 0.06903465491320405, 0.1583455918090684, 0.4025780021079949, 0.49043094366788864, 0.6591867825814656, 1.999247086899621, 3.100333111626761, 4.096586670194354, 7.074928956372397, 12.37881246634892, 14.123012678963796, 22.554917437689646, 28.643542221614293, 44.24849101475307, 55.402760778154644, 66.54938752310616, 75.40196922847203, 81.13887446267265, 87.09182003566197, 92.49707385471889, 83.43661594390869, 79.56976277487618, 65.83193043300084, 81.2051533290318, 77.99917112077985, 82.6003863470895, 82.76774065835136, 81.58480290004185, 76.42756502968925, 71.90278693607875, 69.26183223724365, 59.433709553309846, 63.30379363468715, 66.74822412218366, 74.93977505820138, 72.0940499986921, 72.79210771833147, 72.44117505209786, 72.56417206355503, 70.9586101259504, 51.19265270233154, 36.188709190913606, 15.630380937031337, 3.763620742729732, 1.0078869057553155, 0.02721213293261826, 0.06705694246504988, 0.04109173467648881, 0.04974934279120394, 0.056442934687116315, 0.045396537253899236, 0.028483251242765358, 0.01725952377143715, 0.07213146159691469, 0.10404319422585623, 0.019663407101428935, 0.10287185957921402, 0.07552239964050905, 0.018802878812753727, 0.01821124886295625, 0.008062172431631811, 0.010675079322287014, 0.010931552836804517, 0.032399042908634455, 0.024845255206206014, 0.10194561856665782, 0.030778216131563698, 0.10775740670838527, 0.016118991221966486, 0.05679664820698755, 0.01657963846810162, 0.03337274744574513, 0.02200757765344211, 0.04000896242048059, 0.008561218822641032, 0.08601475626762424, 0.03938718346346702, 0.05689031657363687, 0.04615931918046304, 0.08989379169153315, 0.010550728450263185, 0.02298696831400905, 0.021006416196801832, 0.005892580458229142, 0.03850987839645573, 0.03031946878348078, 0.018095970852300525, 0.011986245617403515, 0.012737326207570732, 0.028033192535596232, 0.014635460916906595, 0.08849626061107431, 0.036328646154808145, 0.018168701324611902, 0.0423523373901844, 0.01115479170610862, 0.03140321473724075, 0.04042266182867544, 0.055361560213246515, 0.03265106438526085, 0.09815783253205673, 0.035469335836491415, 0.02992888367069619, 0.033864312140004973, 0.01815418915690056, 0.03051737030701978, 0.013626143469342163, 0.10115127797637667, 0.06953020939337355, 0.04075294553435274, 0.026608477645952786, 0.04651088174432516, 0.04161822696083358, 0.014050808851607144, 0.03074845897832087, 0.17828567326068878, 0.10760137758084706, 0.20095156558922359, 0.14092816784977913, 0.14467080416423933, 0.13587787241808005, 0.08447817300579377, 0.1727963521012238, 0.08624206549887146, 0.149473407172731, 0.10838415593441043, 0.10977568876530443, 0.15305248940629618, 0.12274659132318837, 0.13683405039565905, 0.09326569682785443, 0.1467497404664755, 0.2023914304694959, 0.06484556969787393, 0.172375158273748, 0.12776800830449375, 0.13266526694808686, 0.09416162768112761, 0.059359614072101455, 0.09662764785545212, 0.15951335057616234, 0.09212299635899918, 0.137806092521974, 0.22939545501555714, 0.11704479370798383, 0.15652083472481795, 0.0823389081550496, 0.08963245392910071, 0.16699183785489627, 0.15223588608205318, 0.14301862567663193, 0.14779027391757282, 0.06727925767855984, 0.0944014016006674, 0.08266626737479653, 0.055446176922747066, 0.1871135767017092, 0.16012651553111418, 0.2016162449227912, 0.10312662233731576, 0.16493166983127594, 0.07051882813019411, 0.1334224170339959, 0.1501976211688348, 0.07100693908120904, 0.12917514065546648, 0.08798009223703827, 0.09367749973067216, 0.18982665826167378, 0.18706264586320945, 0.09836059915167944, 0.13060036275003636, 0.20253899826535157, 0.18686706492943422, 0.1403547107641186, 0.1883066448249987, 0.20179560886962072, 0.40041154835905346, 0.7944453560880252, 1.0231142086642129, 1.6972060714449202, 3.7197089961596896, 5.27603382723672, 6.823804991585868, 11.041263392993383, 16.866244861057826, 19.213009357452393, 28.229983704430715, 35.24952466147286, 52.17746952601841, 67.06668785640171, 77.2572146824428, 90.31092044285366, 95.19130734034947, 102.07620089394706, 107.57310145241874, 97.83333206176758, 94.96872874668666, 80.08030945914132, 96.05992943899972, 92.4440313066755, 94.8029933656965, 93.6110507420131, 95.95486572810582, 90.62916878291539, 84.56233528682164, 81.33415358407157, 72.56001009259904, 76.34334591456822, 79.24392700195312, 88.32996817997524, 83.28344290597099, 84.84930978502545, 81.80308055877686, 83.68352712903703, 79.86509595598493, 61.9039192199707, 43.19984456471035, 17.877642018454416, 4.463815901960645, 1.3484362491539545, 0.23081014624663762, 0.17067081401390688, 0.11165749028857265, 0.09224446769803762, 0.09671749267727137, 0.12612064741551876, 0.21236660092004708, 0.08034706860780716, 0.16294576068009647, 0.17432551218995027, 0.12900972738862038, 0.21980349400213786, 0.22223080375364848, 0.1090651268937758, 0.137499761102455, 0.13480710344655172, 0.09420234656759671, 0.17360923705356462, 0.17843941572521413, 0.21001762125108922, 0.1297540803040777, 0.0937743198924831, 0.17554409322994097, 0.08512048782514674, 0.12650305618132862, 0.11102302611938544, 0.09166009298392705, 0.25631128357989447, 0.1575374294604574, 0.07721926644444466, 0.12335128816110746, 0.23116382583975792, 0.13238298280962876, 0.09039385164422648, 0.2489362321794033, 0.09832674703959908, 0.10925666375883988, 0.08967324066907167, 0.08967383777988808, 0.13172736870391027, 0.18724452038960798, 0.09464556564177785, 0.10261867780770574, 0.08284047445548431, 0.19555998061384472, 0.1657339832080262, 0.1596746112086943, 0.1408487656818969, 0.14344447425433568, 0.1259612323982375, 0.1438029171632869, 0.08358264927353178, 0.1884494221636227, 0.1530475089592593, 0.09929333374436412, 0.15982500171022757, 0.13233064061829022, 0.12515323289803096, 0.13991716424269335, 0.16312961652874947, 0.25709290163857595, 0.11531324019389493, 0.1878791270511491, 0.16001575147467, 0.197290054921593, 0.12245259567030839, 0.2163941812302385, 0.10485274757125548, 0.12715499262724603, 0.19270486810377666], [0.013143858589631106, 0.037487529683858156, 0.044293849995093684, 0.03705147933214903, 0.0018945774895005993, 0.0559177655460579, 0.05180235566305263, 0.020841647538223436, 0.019111272978729436, 0.050133950010474236, 0.030679217872342894, 0.03756090985344989, 0.019104268800999438, 0.01674735705767359, 0.017573568437780653, 0.039457228633442094, 0.07892172437693391, 0.09685410213257585, 0.0330321330444089, 0.05996093859097787, 0.03938137859638248, 0.017990699536832314, 0.032877321887229166, 0.02554956777021289, 0.07095295483512537, 0.04579508836780276, 0.03386695503390261, 0.04268771010850157, 0.047909152427954335, 0.052311667440725226, 0.07888180616178683, 0.0650731571284788, 0.03849241290507572, 0.034261384047567844, 0.06332871144903557, 0.062260710900383334, 0.011302366287314465, 0.016138466873339245, 0.04704445114891444, 0.06034175958484411, 0.07416931260377169, 0.025261865529630865, 0.09094674233347178, 0.015392312447407415, 0.04365810000204614, 0.027242509249065603, 0.008328975793639464, 0.03712526323007686, 0.02386364064711545, 0.06191464447017227, 0.08864555867122752, 0.05818054412624665, 0.03017877454736403, 0.048271496913262775, 0.08742543735674449, 0.04036683875269123, 0.06262826653463499, 0.056546540199113746, 0.23073330894112587, 0.1427883580327034, 1.317685367805617, 1.914928091423852, 6.914802074432373, 8.235437495367867, 11.020351920809064, 11.535859618868146, 18.55411515917097, 18.07048579624721, 29.249105521610804, 33.77398089000157, 35.87190955025809, 51.08440671648298, 57.309113706861226, 64.18336609431675, 76.10023539406913, 75.47693334306989, 76.13415649959019, 79.59137167249406, 76.4863189969744, 75.57192911420549, 69.46134281158447, 73.49524457114083, 66.0972682407924, 57.4869042124067, 68.28189304896763, 57.87841783251081, 67.86235386984688, 61.950930731637136, 56.973102297101704, 59.40962709699358, 59.16185433523995, 57.36911140169416, 61.10362570626395, 60.600756781441824, 64.18388720921108, 58.362693377903526, 62.00728062220982, 57.04812894548689, 60.8270457131522, 61.205430712018696, 60.72816589900425, 61.186462129865376, 62.392731939043315, 52.80418314252581, 28.220570632389613, 11.556540063449315, 2.4116784759930203, 0.20350535426821026, 0.05843930345560823, 0.010909338448462742, 0.030746192671358585, 0.049248668764318736, 0.0058438200836202926, 0.023760608497208784, 0.00865710515063256, 0.010292798629961908, 0.016482278870950853, 0.03527423326990434, 0.013393405957945755, 0.06223170352833612, 0.05448925934199776, 0.01765393921440201, 0.10391742097479956, 0.052883329801261425, 0.040380453557840416, 0.035735090861895254, 0.016069700741874318, 0.05168537961851273, 0.0077029280031898194, 0.014857614978349634, 0.08946268446743488, 0.01670133033102112, 0.06182952903743301, 0.008592329653246062, 0.009825220148611282, 0.1094622395134398, 0.015372521277250988, 0.011741397104093006, 0.058563041101608954, 0.12180027924478054, 0.0821419565805367, 0.015657901231731688, 0.027957632572257092, 0.0534112266530948, 0.1036642324179411, 0.016421928270054714, 0.02606596514981772, 0.016165330074727535, 0.07697772154850618, 0.011593515485791224, 0.054190707326467545, 0.06975282316229173, 0.07126601732202939, 0.05574985866301826, 0.12778683086591108, 0.02824748237617314, 0.03882821649312973, 0.08187164858515773, 0.08677242882549763, 0.015624724261994873, 0.011795347423425742, 0.01785159985800939, 0.02196741516568831, 0.09519994910806417, 0.018197340591411506, 0.049894735882324834, 0.028934660234621594, 0.05225794443062373, 0.03790838424382465, 0.021818934740232568, 0.020157635045636977, 0.08487612700888089, 0.04895759420469403, 0.04993850478370275, 0.0392255394586495, 0.03855885844677687, 0.01280298549681902, 0.02850627732862319, 0.06750687225056545, 0.035577056663376946, 0.08384227712771722, 0.03470382959182773, 0.024613335329507078, 0.06869131619376795, 0.07078994358224527, 0.01989311834664217, 0.04291604732030204, 0.020497716796983565, 0.06206065842083522, 0.02929550176486373, 0.030656917818955014, 0.04714558679344399, 0.01921763164656503, 0.05308007781526872, 0.019235936825030615, 0.03455226183203714, 0.024747132257159268, 0.07616508086877209, 0.06163170893809625, 0.018974894225331287, 0.04945586961028831, 0.057062196279210706, 0.050345724182469506, 0.04927075168650065, 0.026371563751516596, 0.05665557399126036, 0.0937475109738963, 0.007996415602974594, 0.02996765516166176, 0.01833233343703406, 0.05558795002954347, 0.07921413904322044, 0.012402021342755427, 0.032338208851537535, 0.02454001792440457, 0.030927290275160755, 0.08060618077537843, 0.04365170820217047, 0.06235198064574173, 0.05206919295181121, 0.1324854280267443, 0.018557332256542783, 0.006965031772519329, 0.04876961625580277, 0.08291300306362764, 0.013575440788242434, 0.06840565295091697, 0.06224880939615624, 0.05890872076685939, 0.06754848680325917, 0.08024697790720633, 0.014618260054183858, 0.11026561140481915, 0.030015264571245228, 0.179373758445893, 0.1874165968703372, 1.340190583041736, 2.2761152131216864, 7.160392667566027, 7.820710812296186, 11.398333924157278, 12.029397981507437, 19.559258937835693, 19.867767640522548, 30.496665000915527, 39.04059730257307, 41.94032376153128, 60.13164915357317, 67.61390713282994, 74.54722963060651, 85.53698689596993, 86.32033375331334, 86.95249475751604, 89.63987731933594, 85.93238803318569, 88.9272770200457, 81.63688659667969, 84.66815635136196, 76.25688253130231, 67.83622169494629, 76.72406550816127, 67.88672120230538, 75.33724675859723, 73.84525312696184, 66.23438399178642, 66.66220542362758, 69.28782544817243, 65.19719164712089, 69.48113822937012, 68.72444466182164, 73.6413790839059, 66.96957288469586, 68.42913232530866, 66.36857455117362, 67.79207284109933, 70.7284163066319, 68.85598100934709, 71.16973114013672, 73.90705040522984, 64.11095196860177, 38.640947341918945, 15.724383115768433, 3.5392069561140875, 0.36784897851092474, 0.04065998623679791, 0.0018299442724258239, 0.11544393960918699, 0.07337607124022075, 0.05758200838629689, 0.062389625768576346, 0.049869501164981296, 0.02264271187596023, 0.010785603346968336, 0.01483053803843047, 0.0770378533218588, 0.07538015155919961, 0.050389774675880156, 0.06633663004530327, 0.021938730097774948, 0.05675654000203524, 0.05760760951255049, 0.06831880725388016, 0.06562730310750858, 0.03342241960178528, 0.03038655893344964, 0.022527930892205665, 0.03850044336702142, 0.033465021422931125, 0.06219994808946337, 0.03138073147939784, 0.07253232651523181, 0.03417237721649664, 0.07086370712412254, 0.07126082652913672, 0.050472274356122525, 0.08762376635734524, 0.05119701082419072, 0.08629305740552289, 0.039537668959902864, 0.020771237655675838, 0.024956490844488144, 0.025507929468793527, 0.0712578274043543, 0.04488869111186691, 0.08352550983961139, 0.05169748807592051, 0.050129441145275316, 0.05443650324429784, 0.022588724237201468, 0.06556709669530392, 0.04688869682805879, 0.03869140347731965, 0.01763312006369233, 0.034138063700603585, 0.056926224646823745, 0.025668219796248844, 0.03504568910492318, 0.03334353990586741, 0.025263495710013167, 0.03576706682464906, 0.035959526497338495, 0.015516547120309301, 0.02239152499740677, 0.05938452309263604, 0.0645879435219935, 0.05813998808818204, 0.022303622482078414, 0.07517752743193082, 0.11027079541236162, 0.09530941716262273, 0.10249827855399676, 0.037729824360992224, 0.15450166378702435, 0.15061775648168155, 0.14016633587224142, 0.15469580622656004, 0.12271001828568322, 0.09450354147702456, 0.09617862730686154, 0.1663371736982039, 0.14961133977132185, 0.10335618430482489, 0.09688790674720492, 0.09281953969704253, 0.11175514504845653, 0.10350846791906015, 0.10031796233462435, 0.1378467639109918, 0.12362039514950343, 0.1788029476468052, 0.0895635351272566, 0.09182254783809185, 0.10247251457933869, 0.15213863844318049, 0.1088339432275721, 0.049345010558941534, 0.22311308926769666, 0.19039181007870606, 0.1578697216297899, 0.0878901117082153, 0.15853706082063063, 0.16023677747164453, 0.1537971001650606, 0.18859133097742284, 0.13346213847398758, 0.20460437743791512, 0.1873093204838889, 0.27432505839637344, 0.13151244952210359, 0.13627989084592887, 0.14530276453920773, 0.10486235562711954, 0.159844557089465, 0.11784203164279461, 0.1410890892148018, 0.1919132891510214, 0.20426359001014913, 0.08178724561418806, 0.12832511269620486, 0.3100441460098539, 0.13231697492301464, 0.1388604545167514, 0.20232144636767252, 0.08795365651271173, 0.20685163113687718, 0.27816781933818546, 0.19965773501566478, 0.1934575398585626, 0.19142597887132848, 0.14337079892201082, 0.43204813503793305, 0.32116224084581646, 1.5655722320079803, 3.857339782374246, 9.834114636693682, 13.445043069975716, 17.578509909766062, 18.538247210638865, 27.38612151145935, 27.76356676646641, 41.35163763591221, 49.29771566390991, 52.41583790097918, 71.57511683872768, 77.3041080747332, 85.67937632969448, 96.06766278403146, 96.90603937421525, 97.48726313454765, 102.71075902666364, 99.086578641619, 99.58080400739397, 91.6560777936663, 96.51015881129673, 87.93667929513114, 80.53285258156913, 90.43551553998674, 81.67870085580009, 88.83906963893345, 83.00854437691825, 76.43485369001115, 79.63563169751848, 79.26235362461635, 76.63236318315778, 81.13070338112968, 78.12582983289445, 84.33120346069336, 76.66747937883649, 82.28340257917131, 76.25964791434151, 81.57721546718052, 81.49124540601457, 78.27201298304966, 83.43328080858502, 81.75048269544328, 75.95016125270298, 45.42405326025826, 20.140409742082866, 4.782965336527143, 0.8765591127531869, 0.15958748731229985, 0.11349098690386329, 0.2008286150438445, 0.14449792701218808, 0.18116924352943897, 0.29837049384202274, 0.1337965883846794, 0.10637179748820406, 0.15165750283215726, 0.06491987606776611, 0.1139391932104315, 0.24124292071376527, 0.13102474569209985, 0.1633557586797646, 0.21919676155916282, 0.1409429327717849, 0.11094090981142861, 0.22997134125658444, 0.0989381070914013, 0.11188773079110043, 0.1205016989260912, 0.08192840803946767, 0.1775038516415017, 0.10738107083099228, 0.13951464369893074, 0.19082912589822495, 0.11319361214659043, 0.20004918186792306, 0.17867726939065115, 0.16236338764429092, 0.16027759813836642, 0.2621503488293716, 0.185046609757202, 0.207488409110478, 0.09233602242810385, 0.1703578465219055, 0.18556689683880123, 0.10650394218308584, 0.14839753561786242, 0.1762182449123689, 0.12164504400321416, 0.09554459061473608, 0.12881865192736897, 0.20747804109539303, 0.17928493821195193, 0.12542195990681648, 0.23111915109413012, 0.13965651180062974, 0.11725781299173832, 0.2691383638552257, 0.22269471814589842, 0.08925822151026555, 0.23712307321173803, 0.12048383988440037, 0.06800576512302671, 0.1637359011386122, 0.24873544009668486, 0.15990517740803106, 0.1412418953010014, 0.2345496341586113, 0.15014367763485226, 0.15166031196713448, 0.1272958700678178, 0.16591797476368292, 0.1644816654069083, 0.14202138275972434, 0.23890734889677592, 0.09996279674981322], [0.040550049993076494, 0.07336559465953282, 0.01927313581109047, 0.03805669164285064, 0.0169241917652211, 0.05664891077737723, 0.037638164457998106, 0.026976437008540546, 0.0046595852140204185, 0.008840619187269892, 0.046643246963088, 0.09346869414938347, 0.025969738706148097, 0.026981302104624252, 0.04248998161139233, 0.055726360995322466, 0.07818915761475052, 0.03409612684377602, 0.06545161682048015, 0.0027126097660844345, 0.012781962785603744, 0.03395099498863731, 0.03567744252671089, 0.05863212275185755, 0.036706518914018355, 0.05553508875891566, 0.006988634613143014, 0.06304787259016718, 0.010980373431396271, 0.08407626314354794, 0.07512534130364656, 0.026555691014177034, 0.052629221829452684, 0.05499396386689373, 0.03446731942572764, 0.025012035721114705, 0.04941599889259253, 0.06076446654541152, 0.08334685156920127, 0.05629344324448279, 0.022252228543428437, 0.03724052597369466, 0.052046573986964564, 0.06166934049023049, 0.015170792816206813, 0.008760248410648533, 0.029563828437988247, 0.0711747882887721, 0.11438807126666818, 0.02594659896567464, 0.020091191200273376, 0.09498068730213813, 0.09493323056293385, 0.03527809752683554, 0.08122254841561828, 0.042276538243251185, 0.05295976337843707, 0.3332657856600625, 2.129090679543359, 6.245521187782288, 8.85435175895691, 23.787442752293178, 33.60692187717983, 29.85635028566633, 39.784818853650776, 43.3991744858878, 50.15106562205723, 49.69279023579189, 56.637726647513254, 55.16210991995675, 62.804475239345, 66.74522944859096, 69.00091348375592, 63.60522733415876, 61.318019321986604, 60.67350442068917, 61.780651228768484, 35.877454212733674, 47.303798062460764, 55.03920670918056, 41.86532143184117, 36.65882430757795, 34.036695752825054, 22.646734407969884, 35.452443327222554, 33.8042368207659, 37.38831915174212, 33.859919684273855, 36.34186485835484, 42.42472784859793, 35.47712332861764, 41.035706520080566, 45.48575326374599, 39.54798950467791, 40.21171964917864, 45.707261834825786, 40.70424965449742, 32.80895253590175, 42.08640268870762, 42.364782265254426, 51.858387402125764, 50.401815686907085, 62.43881934029715, 65.4788716179984, 67.14408384050641, 44.783061095646445, 25.595468248639786, 15.24861216545105, 1.895603631223951, 0.7918170914053917, 0.08945677442742245, 0.0033197959793532, 0.0664215622735875, 0.05915392975189856, 0.13018573714154108, 0.01895924381512616, 0.0038514644256792963, 0.06205071109746184, 0.07005654222198895, 0.10142691247165203, 0.0278442951717547, 0.020908157540751354, 0.07218453660607338, 0.06747124916208641, 0.06431085696177823, 0.10125936181949717, 0.03656291376267161, 0.08733791991003922, 0.08407837338745594, 0.034623898166630945, 0.06856699500765119, 0.027667446893506815, 0.024338155452694212, 0.01569075759367219, 0.07392931476767574, 0.03197633934074214, 0.024430443000580584, 0.040738998247044425, 0.07006124446966819, 0.02072732286926891, 0.046210762312901874, 0.04681472633300083, 0.021599058860114644, 0.03451828758365341, 0.029366445993738513, 0.037197968257325034, 0.01334139031158494, 0.01128962594417057, 0.05159998259374073, 0.10145883075892925, 0.02787918035340096, 0.008738459803030958, 0.014847386062943509, 0.03464220164875899, 0.0836201858307634, 0.032473406954003234, 0.12225649904991899, 0.028970212076923678, 0.038350527840001244, 0.06531772829060044, 0.03375177371448704, 0.08218144053327185, 0.051815108728728125, 0.07188467162528209, 0.01393794218477394, 0.018815224757418036, 0.04689538718334266, 0.04115782737998026, 0.09719394639666591, 0.09347795615238802, 0.08005403647465364, 0.0385321852351938, 0.011641851776013417, 0.02825361124372908, 0.028089417643578987, 0.038359528607023616, 0.061455649456807544, 0.05607403216085263, 0.07793756361518588, 0.031080656152750765, 0.07444836691554103, 0.03864033693181617, 0.019672509648704102, 0.011637564282864332, 0.019421239649610858, 0.03461745208395379, 0.048062250284211974, 0.019928544659965804, 0.02961930206843785, 0.013125964773020573, 0.054953584247933965, 0.022754902552281107, 0.045299757804189406, 0.10310292110911437, 0.039754284479256184, 0.015290289618340986, 0.015950957113610845, 0.012720832717604935, 0.07018658345831291, 0.073354758455285, 0.18207818189901964, 0.04677038746220725, 0.09259835763701371, 0.039353911498827596, 0.0034680122002360542, 0.08152341084288699, 0.066976753196546, 0.015094840998894401, 0.03518296352454594, 0.03834069247490593, 0.03024583077058196, 0.03524672546024833, 0.05398624776197331, 0.07298725031848464, 0.014214331550257546, 0.09895395088408675, 0.053977219853550196, 0.02972910599783063, 0.04343718257067459, 0.05752122521932636, 0.032764702037508996, 0.10738306572394711, 0.06988836053226676, 0.04396322023655687, 0.021958695990698676, 0.10380305389740638, 0.04352464234190328, 0.04506315264318671, 0.13394203915127686, 0.024126121741054312, 0.09963008388876915, 0.06161613655941827, 0.04720904338838799, 0.5351839108126504, 2.3949383114065443, 8.230351413999285, 12.202024238450186, 27.706080845424108, 39.079687867845806, 33.170800822121755, 45.223500456128804, 47.24580839702061, 54.51950577327183, 53.8573876108442, 65.08594403948102, 61.68886552538191, 71.15232590266636, 73.08174337659563, 77.23156888144356, 74.13582679203579, 72.07003007616315, 68.95314461844308, 68.53288282666887, 46.88387673241751, 60.90041174207415, 67.7049285343715, 51.445716517312185, 44.30317333766392, 44.46982935496739, 30.680323260171072, 49.16592223303658, 43.80347973959786, 47.75603893824986, 44.87227249145508, 46.62952402659825, 52.116502557482036, 43.336873463221956, 52.848109654017854, 55.20519569941929, 47.39341592788696, 49.04868875231062, 53.091268811907085, 52.996453693934846, 41.22469752175467, 48.91122906548636, 52.337159974234446, 60.67786094120571, 57.96047258377075, 69.68278190067836, 73.44501604352678, 77.37524373190743, 56.73823234013149, 33.910103048597065, 21.74553394317627, 4.2531704051154, 1.586849244577544, 0.38696659409574097, 0.0459284544257181, 0.042994333298078606, 0.030236531448151385, 0.05649583327717014, 0.050982990701283724, 0.05273803170504315, 0.0030589289505899486, 0.010217380310807909, 0.06475759084735598, 0.01634579155194972, 0.027001215411084037, 0.05766901693173817, 0.11665945367089339, 0.01839758306076484, 0.08003892549978835, 0.03135085218985166, 0.09073904276426349, 0.03813480459419744, 0.0560447330187474, 0.06969923925186906, 0.12300809871937547, 0.025251504299896102, 0.049838671926409006, 0.03628891792946628, 0.04229589006198304, 0.05094911144780261, 0.020172886816518645, 0.09891837529305901, 0.07953048563961472, 0.031118246992783885, 0.028020381794444153, 0.03669659873204572, 0.01608436049095222, 0.03943043328555567, 0.026733579147340994, 0.05476034765264817, 0.015639195717605095, 0.08181746077856847, 0.0909801669684904, 0.05525874858722091, 0.04499809470559869, 0.08601272744791848, 0.025890314485877752, 0.050356231297233274, 0.02621440147049725, 0.11052203657371656, 0.06800828927329608, 0.09646989524896656, 0.0345782395452261, 0.042757755278476646, 0.08155728331101791, 0.037917781953832934, 0.10739513686192886, 0.02063343228240098, 0.024695103888266852, 0.0682646669447422, 0.07642751785793475, 0.05494715512863227, 0.09935028997382947, 0.08951611910015345, 0.0477779373260481, 0.04204112391120621, 0.053418982308357954, 0.03950757593182581, 0.030972026088940244, 0.1664180957845279, 0.1041079196812851, 0.1301802545785904, 0.1280483789741993, 0.1304731781461409, 0.14974509259419783, 0.16088314993040903, 0.08456364127674273, 0.16380235685833863, 0.14061176697058336, 0.13832523966474192, 0.2086772703166519, 0.21646952575870923, 0.2400260360113212, 0.20028498635760375, 0.21301921590098313, 0.18528956600597926, 0.2611128959272589, 0.1342153259153877, 0.13099091393607004, 0.1056198381951877, 0.11908964041088309, 0.15254821575113706, 0.15848826058208942, 0.29545108335358755, 0.14735632363174642, 0.1793134231120348, 0.19975232279726438, 0.09406988296125617, 0.17755415822778428, 0.18842413994882787, 0.15206083761794226, 0.16339028254151344, 0.14359021000564098, 0.11131097602524928, 0.15279721096158028, 0.14111932473523275, 0.1670347891215767, 0.20025547008429254, 0.16785026607768877, 0.06499244538801056, 0.10504632682672568, 0.12162913914237704, 0.21395471213119371, 0.1531579473188945, 0.15862289550048964, 0.209141591829913, 0.15318036611591065, 0.2011480421892234, 0.091306386249406, 0.19942309760621615, 0.14524175067033085, 0.2563613866056715, 0.17417536596102373, 0.20469345551516327, 0.20818218402564526, 0.17841490704034055, 1.0695015766790934, 4.259349959237235, 12.142744813646589, 17.586884226117814, 36.59772879736764, 47.69424165998186, 43.67320449011666, 55.23865474973406, 59.835954666137695, 67.24905027662004, 66.36865098135812, 73.99985749380929, 75.69901861463273, 82.46732139587402, 84.05628408704484, 89.06702613830566, 84.38435023171562, 80.85858413151333, 81.46620409829276, 80.0073881149292, 59.545881271362305, 68.54175567626953, 78.62875434330532, 60.18897874014718, 55.92565441131592, 51.807846205575125, 36.714197976248606, 58.20723785672869, 51.579055922372, 53.36471516745431, 50.52378783907209, 54.042678696768625, 60.545303208487375, 51.889887060437886, 59.25375815800258, 62.786667006356375, 56.8788743019104, 58.51530361175537, 65.58366434914726, 58.86747305733817, 50.591404233660015, 60.77280112675258, 60.82585062299456, 71.53995895385742, 70.64639282226562, 80.15819876534599, 83.28630556379045, 88.24793079921177, 66.83021981375558, 40.590747356414795, 25.56027909687587, 7.0617499606949945, 2.4718335909502844, 0.6467384334121431, 0.1689050623348781, 0.23171031794377736, 0.27161059262497084, 0.18311718186097486, 0.23150602462036268, 0.17607990519276687, 0.16495056024619512, 0.31652127844946726, 0.23066982520478113, 0.1658053243798869, 0.08379817913685526, 0.156047095145498, 0.16949545565460408, 0.2488530980689185, 0.2273031244320529, 0.08743245340883732, 0.26914808047669275, 0.1726066879928112, 0.11084438141967569, 0.24610967242291995, 0.17082556071025984, 0.12176612179194178, 0.18045196416122572, 0.1877927224018744, 0.09224016578601939, 0.11032026740057127, 0.131713241604822, 0.21306413491921766, 0.1666990907064506, 0.10020231282604591, 0.22854231936591013, 0.1381896955094167, 0.15224679692515306, 0.12081596920532839, 0.08554852128561054, 0.20263950287231378, 0.10809879803231784, 0.18562875209110125, 0.21467516704329423, 0.18941606315118925, 0.10002045865569796, 0.11470269438411508, 0.15979598755283014, 0.13010552073163645, 0.1374301841216428, 0.21590583957731724, 0.09838649883334126, 0.1514473333954811, 0.12911487317511014, 0.1206960313554321, 0.1990448007626193, 0.12267746217548847, 0.13960501099271433, 0.193205219826528, 0.1476553404437644, 0.14865783522171633, 0.2164965993059533, 0.15744752357048647, 0.2184193232761962, 0.20335974065320833, 0.1488959603011608, 0.09181456148092236, 0.15493425700281346, 0.26207652421934263, 0.203330075102193], [0.058982653942491324, 0.0705874144498791, 0.10156363727790968, 0.07732369976916484, 0.033223954894180806, 0.05550256657547184, 0.026389068258660178, 0.013466130493075719, 0.049243803668235026, 0.0636713377067021, 0.01536478428170085, 0.016764856475804533, 0.04498305497691035, 0.0838900324223297, 0.030517587438225746, 0.04333073399694903, 0.06423188227095775, 0.044203645549714565, 0.057496004072683196, 0.012513866814385568, 0.03400923025661281, 0.03523592996810164, 0.060541316733828614, 0.030412519683263133, 0.0398356069012412, 0.04989102090309773, 0.031116621901414225, 0.07296029890754394, 0.021114401652344635, 0.07096818116094385, 0.015249667423112052, 0.05588070396333933, 0.022878373873287013, 0.0272621392671551, 0.02833090995305351, 0.03202021341504795, 0.02092993851484997, 0.05397900100797415, 0.06427954935601779, 0.011039398344499724, 0.02624140546790191, 0.04138615441375545, 0.029707793212894882, 0.012261713023430534, 0.07103291340172291, 0.054781548479305844, 0.015710440198225633, 0.05845526259924684, 0.029554430727979968, 0.13269976366843494, 0.02045839399631534, 0.13633064526532376, 0.027287038109664406, 0.0706134701945952, 0.05802150908857584, 0.6968711518815586, 5.212013125419617, 16.547803708485194, 31.741580690656388, 37.07725177492414, 49.53024755205427, 55.28361654281616, 63.75321701594761, 60.051696232386995, 60.861564363752095, 58.603913988385884, 59.40510381971087, 61.12470654078892, 63.679010254996165, 56.96991307394845, 58.47615051269531, 56.04230076926095, 46.105852195194785, 42.296505791800364, 38.98390000207083, 34.0445750100272, 32.9960675239563, 26.572834866387502, 37.06398071561541, 39.93599428449358, 67.55461815425328, 40.798265729631694, 15.091728789465767, 15.373678003038679, 9.231515611921038, 12.406720774514334, 16.020725522722515, 15.082360880715505, 11.816662379673549, 17.86081521851676, 16.124496868678502, 14.481029033660889, 20.244419063840592, 24.28260612487793, 25.17431535039629, 22.615286861147197, 19.00021035330636, 27.349785906927927, 27.55346887452262, 23.38366208757673, 25.508789471217565, 35.81021302086966, 41.095474924360005, 46.24889823368618, 54.77145092827933, 65.69209098815918, 61.14152118137905, 53.16959932872227, 40.313013962336946, 26.236674070358276, 13.81800673689161, 5.961563076291766, 0.967838357601847, 0.45718511619738167, 0.05170092485578997, 0.05702349942709718, 0.021893588859321814, 0.03290299425965973, 0.013689167498211776, 0.03033986554614135, 0.06379370471196515, 0.05809613436992679, 0.07024660666606256, 0.034618754871189594, 0.1066418747816767, 0.11965743851448808, 0.01522616297006607, 0.11138716193714313, 0.0597190476421799, 0.051505605157996924, 0.11965590502534594, 0.0252785642764398, 0.06123530878020184, 0.05457761138677597, 0.02529499669825392, 0.05833421873727015, 0.0340739998168179, 0.018134248709040027, 0.03808882366865873, 0.07139770739844867, 0.10146923948611532, 0.04007961827197245, 0.013453275647147425, 0.0631885803969843, 0.023387768771499395, 0.06846855993249587, 0.019170819515628473, 0.016535306382658224, 0.06578474358788558, 0.03695052010672433, 0.03728038651336517, 0.005475113060258861, 0.059158862701484134, 0.035847225559077094, 0.08172330725938082, 0.020165679078283053, 0.04178565886936017, 0.030565135779657533, 0.001000861416936719, 0.047176073371831856, 0.016586664698219726, 0.029531560705176423, 0.07407754074249949, 0.04222357179969549, 0.012855917165455009, 0.08374640691493239, 0.09715249469237668, 0.05207560171506234, 0.038658453816814084, 0.026203495716410022, 0.12957529989736422, 0.04094513379303472, 0.02625526624199535, 0.036409951613417695, 0.033352079269077094, 0.03362903351496373, 0.03495419205033353, 0.011058526246675422, 0.08131674943225724, 0.11283981720251696, 0.0730835615790316, 0.01458702708727547, 0.043040460108646324, 0.029183536701436554, 0.04817134175183518, 0.02184733991245074, 0.012979796455640878, 0.01907895944480385, 0.036411763301917484, 0.0613466292353613, 0.04861536828268852, 0.07033282132553202, 0.02788039153840925, 0.01997317699715495, 0.01146467016743762, 0.024554725170933774, 0.056346626819244454, 0.03472831113530057, 0.05872777583343642, 0.008723918797581323, 0.03606709465384483, 0.06997141321854931, 0.08865986897477082, 0.008187052560970187, 0.03963562227519495, 0.08212685239102159, 0.05821474229118653, 0.054935776096369536, 0.03739644653562989, 0.035839290092034, 0.05386089180995311, 0.01733375889515238, 0.04685635784907, 0.08092726354620286, 0.020899821738047258, 0.08049647523356335, 0.026237853337079287, 0.042340293393603394, 0.04089769062453082, 0.07072090942944799, 0.039386722059654336, 0.053478547504970005, 0.03458453295752406, 0.1305880948368992, 0.10914554007883583, 0.14169922790357045, 0.06439583668751375, 0.17627383050109657, 0.0274217120438282, 0.048078080506197045, 0.012580513372085989, 1.39909328520298, 8.865604366574969, 21.593086991991314, 39.641206536974224, 45.12575319835118, 55.97386448723929, 63.85489000592913, 70.40864631107875, 67.24008015223912, 67.7771828515189, 65.82748358590263, 68.24797194344657, 70.63478933061872, 72.58816419328961, 68.11061300550188, 68.40325028555733, 66.92149135044643, 57.45018993105207, 53.06866979598999, 50.262709277016775, 46.68694393975394, 42.12341226850237, 33.34188631602696, 38.52018070220947, 50.29411860874721, 70.50084195818219, 51.59978239876883, 22.592262268066406, 25.222714764731272, 23.06909802981785, 24.85640573501587, 26.470110961369105, 29.907450812203543, 24.709616354533605, 29.689155782972062, 27.82854805673872, 20.47518958364214, 29.862655775887625, 28.808515037809098, 30.136133398328507, 32.85823610850743, 30.158159187861852, 34.47332055228097, 40.61481244223458, 32.10456848144531, 37.137398856026785, 45.01138237544468, 49.83073282241821, 54.240789209093364, 61.96579987662179, 74.97955349513462, 71.94877706255231, 63.862213407244, 49.13116039548601, 32.312354360307964, 17.80834068570818, 7.4970480884824475, 1.696198039821216, 0.5637676598770278, 0.034251372263367684, 0.02656284955862377, 0.01180002252970423, 0.07686312376920666, 0.03805624720241342, 0.023411088323752795, 0.06853386892804078, 0.04255829990974494, 0.07644749392888375, 0.032994548989725966, 0.04956710185589535, 0.03857027819114072, 0.04473178328147956, 0.0638413242995739, 0.0037336177358935985, 0.06427400572491543, 0.06138947193643876, 0.0969129650454436, 0.02612866517821593, 0.08330065690513168, 0.045641430720154724, 0.06454514153301716, 0.034701970405876637, 0.04756698078875031, 0.06579392416668789, 0.05333852841119681, 0.012056896379882736, 0.10657927992620639, 0.05721312282340867, 0.052192143497190306, 0.008995779789984226, 0.047713510426027436, 0.06055690946855715, 0.07428593241742679, 0.05511873967147299, 0.03411974664777517, 0.03310637834614941, 0.012495390305827771, 0.04620519154039877, 0.03481166237699134, 0.06424999915595565, 0.055718710512987206, 0.024463821834485446, 0.050185189582407475, 0.041090852580964565, 0.11762646106737, 0.025328918360173702, 0.05564796984461801, 0.0788993395066687, 0.059896898455917835, 0.11471205816737243, 0.03732015884348324, 0.04292787079300199, 0.06968000956944057, 0.014785680088347622, 0.0349556135811976, 0.018870393047109246, 0.015591827187953251, 0.05112084526834743, 0.031856147040213854, 0.0194464709742793, 0.03644704033753701, 0.07031300810298749, 0.20764692846153462, 0.1722802176539387, 0.19935152573244913, 0.13785235503954546, 0.09671430356268372, 0.16213320142456464, 0.08775815021778856, 0.22943035885691643, 0.13381402673465864, 0.09844023880681821, 0.09925804313804422, 0.10413116629102401, 0.22867278807929584, 0.15559639861541136, 0.16253033440027917, 0.12477655096777848, 0.1262163751359497, 0.1156165860593319, 0.21765792556107044, 0.19395196118525096, 0.13957231917551585, 0.1123193401311125, 0.1368736768407481, 0.13274374630834374, 0.1832517082137721, 0.14039014386279242, 0.18684071062930993, 0.112528939598373, 0.20868029658283505, 0.1074976906446474, 0.1529930361679622, 0.15450412008379186, 0.09961827059409448, 0.1594587013657604, 0.0634506441918867, 0.11776699924043246, 0.1980918797531298, 0.10324221077774252, 0.18340026667075499, 0.1577548456511327, 0.19936447218060493, 0.11991631319480282, 0.11168544593134097, 0.19166711664625577, 0.16666933016053267, 0.13604188790278776, 0.22639485102679047, 0.2649851052888802, 0.27631853999836103, 0.15545974166265555, 0.2579200358263084, 0.19501297282321112, 0.1950374815080847, 0.2044531726943595, 2.160724090678351, 11.963427441460745, 32.2660550389971, 53.21218831198556, 60.102188791547505, 73.05745942252022, 75.38005461011613, 81.82088879176548, 77.82160295758928, 78.36985751560756, 76.35444913591657, 77.81438377925328, 78.08054842267717, 81.7841467176165, 74.69024440220424, 76.6981417792184, 75.92828137534005, 63.86517333984375, 59.67351967947823, 55.51641593660627, 51.147875036512104, 50.876888343266074, 42.46774067197527, 53.4698657308306, 57.080538817814414, 80.16815553392682, 56.708938734872, 28.391633544649395, 27.12849794115339, 22.77628183364868, 25.315249136516027, 28.432400362832205, 28.41597134726388, 23.433664798736572, 31.50005783353533, 28.691674130303518, 26.028900350843156, 34.28180735451834, 37.61104365757534, 38.30274377550398, 38.44205863135201, 33.24285364151001, 41.238593918936594, 43.76782505852835, 38.70793145043509, 40.47532735552107, 53.578108242579866, 57.95555673326765, 65.20615482330322, 72.9464133126395, 86.10259805406842, 83.03404426574707, 73.33412974221366, 59.79747554234096, 40.83340971810477, 23.116356202534266, 10.977104595729283, 2.5036969440323964, 1.0561229288578033, 0.25752697406070574, 0.10509423818439245, 0.20666307982589516, 0.1497743103121008, 0.09817865677177906, 0.11754061281681061, 0.20116526340799673, 0.1691851887319769, 0.1736539253698928, 0.09324209737990584, 0.23767556356532232, 0.1649434356284993, 0.22143064811825752, 0.20995510103447096, 0.1599652956106833, 0.16853684852165834, 0.1991898851203067, 0.22463387623429298, 0.1374184318951198, 0.1956244550113167, 0.1912453392786639, 0.24077253309743746, 0.14595723870609487, 0.14492275778736385, 0.16103322830583366, 0.14390473812818527, 0.2032378486224583, 0.17838773849819387, 0.11454912833869457, 0.11792957623090063, 0.14737382983522757, 0.13104427392993653, 0.13034047026719364, 0.15817416672195705, 0.20013108104467392, 0.12067279831639358, 0.16759523190557957, 0.11055400235844509, 0.2266338039189577, 0.10818223748356104, 0.24946082117302076, 0.13744736462831497, 0.10565323568880558, 0.11831691116094589, 0.15672116540372372, 0.17051309533417225, 0.07638992023255144, 0.12555742263793945, 0.16492976993322372, 0.1860355202640806, 0.15628881646054132, 0.11844149019036974, 0.1620555498770305, 0.16294928906219347, 0.1946667842566967, 0.16902749719364302, 0.2629873624869755, 0.13762006536126137, 0.09526305965014867, 0.086471824241536, 0.14614813774824142, 0.13179786849234784], [0.04015510529279709, 0.02928030936579619, 0.023666768800467253, 0.06754847323255879, 0.00785709115942674, 0.02517339983023703, 0.017410241666116884, 0.060629336296447685, 0.02120394113340548, 0.06026627256401947, 0.014398540237120219, 0.0031538742353274885, 0.06831521101828132, 0.029678443180663244, 0.015553936096174377, 0.0255910805426538, 0.03051524649241141, 0.014442624657281806, 0.059779172630182335, 0.05656008715076106, 0.032265171342130215, 0.041973864127482684, 0.044183160577501567, 0.03811753587797284, 0.04977811606866973, 0.007193022507375905, 0.030600233003497124, 0.023254102461838295, 0.01847161801664957, 0.010877283606013017, 0.013718560787050851, 0.00718870448015098, 0.024071062016966085, 0.07230928526925189, 0.023074144796867455, 0.016249047725328376, 0.05508592911064625, 0.03515984583646059, 0.08258331646876675, 0.048377867455461195, 0.027988580554457645, 0.06377790163138083, 0.0464680899333741, 0.10344596127314226, 0.014868899015709758, 0.053449811546930244, 0.04923394794708916, 0.029741353554917232, 0.011428555141070058, 0.009622555309241372, 0.02374925830268434, 0.06617203780582973, 0.10412016045302153, 0.5624389797449112, 5.248651845114572, 26.129649230412074, 44.37593139920916, 54.40094518661499, 62.20873669215611, 60.777081217084614, 63.24942398071289, 58.36291572025844, 63.53716972896031, 53.45657730102539, 50.420690468379426, 56.973067556108745, 49.7693315914699, 47.43193326677595, 45.30899109159197, 29.198348930903844, 25.827776057379587, 25.69419346536909, 15.103367022105626, 17.054033824375697, 18.445667675563268, 15.471828256334577, 20.82371817316328, 29.29080513545445, 47.2804069519043, 39.26227610451834, 75.86986092158726, 41.26566062654768, 12.519937327929906, 22.34012082644871, 19.657782656805857, 18.117905514580862, 18.216142620359147, 16.450874601091655, 23.328780003956386, 18.229332038334437, 17.17437141282218, 22.18494497026716, 19.03628018924168, 22.363114152635845, 17.944916214261735, 15.762877873011998, 15.674251862934657, 16.247882979256765, 12.186058146612984, 19.724214383534022, 15.429366077695574, 23.544637952532085, 22.335898058755056, 24.25640967914036, 34.78960950034005, 48.205007212502615, 48.54335669108799, 56.17209659303938, 58.10994570595877, 53.36406898498535, 42.054857867104666, 36.3017007963998, 16.31377969469343, 4.370645335742405, 3.6045111204896654, 1.1261000824826104, 0.26186973388705936, 0.09199523500033788, 0.03810301862124886, 0.04149846892271723, 0.05932063902063029, 0.027903342985415032, 0.02899645102609481, 0.028711008307124888, 0.05615810604233827, 0.03819184564054012, 0.026671228564477394, 0.06573434200670038, 0.0622678558741297, 0.02767541628730084, 0.03654441011271306, 0.06770547266517367, 0.028158955608627627, 0.06236428248562983, 0.057165984995663166, 0.026427622618419782, 0.023129810113459826, 0.06612038093486003, 0.04025487708193915, 0.01575838548264333, 0.0368754300288856, 0.08463625809443848, 0.08757319514240537, 0.01658681227958628, 0.021966750201370035, 0.069881602323481, 0.058086377036358626, 0.05196947883814573, 0.010603903543337114, 0.060512825048395565, 0.033359468515430174, 0.01932098949328065, 0.07428776446197714, 0.013537134093764638, 0.05682357247652752, 0.020615858225417987, 0.06138552286263023, 0.03560865264652031, 0.061003656924835274, 0.03256933484226465, 0.017813342357320443, 0.06571352455232825, 0.023957670333662202, 0.05837403517216444, 0.06486731674522161, 0.024816342829061405, 0.021103843647454466, 0.03868497096534286, 0.012575294589623809, 0.05878868792206049, 0.02887196359889848, 0.010630664116303836, 0.02559676157709743, 0.02173753089404532, 0.04517919909475105, 0.04929320101759263, 0.02546581788919866, 0.023320230788418224, 0.010560183835748051, 0.009530656222653176, 0.015456154110974498, 0.03138320134686572, 0.011037261807359755, 0.13881024292537145, 0.019005937202434455, 0.04928472272253462, 0.01383485660023455, 0.03484802167596562, 0.056122102974248786, 0.024628607456439307, 0.016728514140205722, 0.04378108786685126, 0.044348200650087426, 0.03243068638922913, 0.021912489452266266, 0.10503487994096108, 0.06126724063817944, 0.025980452774092555, 0.048299690043287616, 0.02914783897410546, 0.01978679190921996, 0.008726026496983, 0.029130923096090555, 0.07616337774587528, 0.017342215137822286, 0.021784678899816105, 0.01178144000004977, 0.049755290150642395, 0.05627542474706258, 0.040426790714263916, 0.05063117368678961, 0.05682266323960253, 0.02264475087369127, 0.06870051034327064, 0.0989324888214469, 0.04611526529437729, 0.14338166905300959, 0.024988692420135652, 0.049099045007356575, 0.056228320846068006, 0.04752763254301889, 0.08231017219700984, 0.008817374273868544, 0.05089117812791041, 0.024875697679817677, 0.05421179958752223, 0.01026315173865961, 0.022854823619127274, 0.26979689566152437, 1.1158295593091418, 8.892778771264211, 33.57516166142055, 53.48236206599644, 64.10758209228516, 69.24101543426514, 68.5111141204834, 71.57768072400773, 67.30674811771938, 70.78977584838867, 63.094430514744346, 58.76272896357945, 63.37306717463902, 58.14716373171125, 54.067063399723594, 55.581975664411274, 37.649904932294575, 37.6956900869097, 35.63683462142944, 24.75900067601885, 26.216022287096294, 28.824450731277466, 23.31843066215515, 30.699604511260986, 35.13971185684204, 50.24195153372628, 44.9686405318124, 74.38762256077358, 40.91673598970686, 15.48619886807033, 21.152861288615636, 16.94132535798209, 22.811641216278076, 25.987968512943812, 21.32998824119568, 27.88516197885786, 29.40307412828718, 24.558765751974924, 26.265479564666748, 25.688723496028356, 33.681753976004465, 27.47131163733346, 27.862590755735123, 19.462109225136892, 24.794723102024623, 22.838601963860647, 31.178929465157644, 27.842659848076956, 35.45616061346871, 32.741440364292686, 34.54714516230992, 44.65018721989223, 54.65298761640276, 55.02848563875471, 63.89173630305699, 66.53827735355922, 61.29198442186628, 50.773867402757915, 42.61940247671944, 20.98305426325117, 5.775212390082223, 3.7405453409467424, 1.1633037775754929, 0.3275989868811199, 0.09772250482014247, 0.09227873371647936, 0.009980050813672798, 0.09522419316428048, 0.045669925798262866, 0.03517834270106895, 0.05963819340935775, 0.013823079776817133, 0.026157353638804386, 0.05153039882757834, 0.06094575074634381, 0.045295252331665585, 0.03087381153766598, 0.027673691112015928, 0.037624410553170104, 0.08105128617691142, 0.043208509484039884, 0.012575957857604538, 0.07070608343929052, 0.03641965127150927, 0.008815932386953915, 0.05293696799448558, 0.00949603651783296, 0.021842824261901633, 0.026599339475589137, 0.009570339495050055, 0.012787179871728378, 0.014262729756800192, 0.045643208481903584, 0.05974298635763781, 0.06543497235647269, 0.019652553933805654, 0.03764193711270179, 0.08611393094594989, 0.09212244674563408, 0.04441336715327842, 0.04614065607477512, 0.02320839634298214, 0.04022681965891804, 0.06222755089402199, 0.014836863681141819, 0.06936255696096591, 0.059520501510373185, 0.06233182815568788, 0.01647380566490548, 0.030183527685169662, 0.040239189352308, 0.05281776974775961, 0.005804087617434561, 0.09692965700690236, 0.061670901120773385, 0.0041570719331502914, 0.0066518742907127094, 0.06737700743334633, 0.058033247744398456, 0.07390356436371803, 0.025045814890680567, 0.01334379826273237, 0.019349206372031143, 0.10764742975256272, 0.12559563773018972, 0.117705890376653, 0.09936815580087048, 0.1390255827988897, 0.07694751316947596, 0.06691387335636786, 0.18968987917261465, 0.13367616198956966, 0.15008749493530818, 0.06640890081013952, 0.11095952881234032, 0.10340476062680994, 0.20583646132477693, 0.13494658310498509, 0.11679541851793017, 0.10218361472444874, 0.10633529230420079, 0.15972189152879374, 0.13615353405475616, 0.13361351963664803, 0.12083029986492225, 0.12492048181593418, 0.12115854796554361, 0.16092473055635179, 0.0983533456123301, 0.11152479598032576, 0.20114646798798017, 0.09935962661568608, 0.09485984700066702, 0.1306508050433227, 0.17312766718012945, 0.12229258354221072, 0.10498027144266026, 0.09329260074134384, 0.14047629066876002, 0.1375209585364376, 0.1267849603401763, 0.16614271913255962, 0.1722938697785139, 0.27870519193155424, 0.202193786789264, 0.1297690352158887, 0.2108426248388631, 0.17852675675281457, 0.16902253031730652, 0.2025034837424755, 0.1719022872192519, 0.04486571930881057, 0.1296655179134437, 0.12744263719235147, 0.16399420584951127, 0.37076106082115856, 2.077751091548375, 12.941834551947457, 41.207361766270225, 66.79836927141461, 74.25639888218471, 80.05502496446881, 76.65938472747803, 79.30011708395821, 74.70635727473667, 80.67583261217389, 70.63446971348354, 68.08378601074219, 74.46672085353306, 68.70498970576695, 64.81446402413505, 65.0795030593872, 44.33169221878052, 39.99831962585449, 39.08166115624564, 28.552644150597708, 28.500442334583827, 29.166498388562882, 28.640434639794485, 35.50721945081438, 45.65756484440395, 65.17447103772844, 57.40313673019409, 87.8107362474714, 52.30034841809954, 29.518810272216797, 37.87138223648071, 30.85312843322754, 30.21037142617362, 27.714564595903667, 25.423196349825176, 35.75645480837141, 28.660888399396622, 26.50389657701765, 34.88724558694022, 32.2451548576355, 36.10981239591326, 32.07043545586722, 27.089841638292583, 24.528026921408518, 28.64281439781189, 19.345636572156632, 33.620387486049104, 28.07445001602173, 38.09676442827497, 35.120583466121126, 39.39153691700527, 53.270928382873535, 65.74966376168388, 64.79461996895927, 75.23658820561, 75.46464197976249, 72.30505984170097, 59.34004088810512, 49.98807825360979, 27.749246529170446, 10.13059687614441, 5.569315986973899, 2.2929502640451704, 0.5914611167141369, 0.25012046577675, 0.1925707081598895, 0.14079330222947256, 0.2275878241551774, 0.13507463623370441, 0.095478257031313, 0.1580052657851151, 0.09453761072031089, 0.14485193230211735, 0.09829855390957423, 0.18749021791986056, 0.14288571423717908, 0.1197307745793036, 0.1531633348869426, 0.18623249897999422, 0.13094085162239416, 0.15190872363746166, 0.14907687130783284, 0.10549324391675846, 0.10769399082554237, 0.1443563981779984, 0.10165607410350017, 0.11052286438643932, 0.13036170841327735, 0.17997879455132143, 0.1497151827705758, 0.10301013823066439, 0.1085835298789399, 0.13746598362922668, 0.1625413130968809, 0.10131538167063679, 0.1311661931020873, 0.0916429396186556, 0.17468793131411076, 0.22733838111162186, 0.22960183822682925, 0.08727864987616028, 0.10367147238659007, 0.11275633703917265, 0.1470946262457541, 0.13805994604315075, 0.18704812521381037, 0.16496360168925353, 0.1356853584625891, 0.16696374650512422, 0.2517441729349749, 0.119378248495715, 0.17415719479322433, 0.14774779762540544, 0.19442219952387468, 0.12092217350644724, 0.06615174960877214, 0.1129623945536358, 0.16678838591490472, 0.10400419203298432, 0.14498165462698254, 0.08297485831592764, 0.07148656155914068, 0.1312968653759786], [0.031446566339582205, 0.03701517092330115, 0.02140382058652384, 0.06614001095294952, 0.021366075379773974, 0.05170991883746215, 0.06474038998463325, 0.0732070142403245, 0.03704846663666623, 0.04628711446587529, 0.040511519382042546, 0.036554520284490924, 0.04231260237949235, 0.022276338588978564, 0.04410051840490528, 0.03814440925738641, 0.08601082754986626, 0.02083362895064056, 0.04022627004555293, 0.04920321709609457, 0.034293075025613816, 0.058015341205256324, 0.020728815646309937, 0.08893551025539637, 0.04885217021884663, 0.03872655498396073, 0.012944712802501661, 0.02283240482211113, 0.061335793031113486, 0.08385592925229243, 0.06845246508185353, 0.04355242835091693, 0.0263800963293761, 0.060458596529705186, 0.10986714850046805, 0.042510961914168935, 0.11488061983670507, 0.021110143845102618, 0.03429323787401829, 0.007544398474107895, 0.07578497912202563, 0.025393788004294038, 0.07557703528021063, 0.038550285156816244, 0.06749001065535204, 0.05048381962946483, 0.026913584309763143, 0.06571627940450396, 0.11405299710375921, 0.03948652438287224, 0.25827010561312946, 2.466125645807811, 9.800025037356786, 27.366631814411708, 49.8754757472447, 66.90106364658901, 63.60217707497733, 65.47562680925641, 58.02312101636614, 55.09086309160505, 56.18639251164028, 48.04199205126081, 48.216405732291086, 44.51286997113909, 40.50251913070679, 34.142523765563965, 31.582230704171316, 31.62876626423427, 29.024075950895035, 20.964424405779155, 14.548914670944214, 16.617751223700388, 18.522481748035975, 12.98873576096126, 18.252453906195505, 19.871418918882096, 22.040158408028738, 36.16292095184326, 27.655857528959, 27.122291462762014, 46.90039954866682, 59.59248978751046, 41.9838924407959, 51.401220253535676, 47.31205252238682, 44.41870103563581, 36.79144804818289, 55.75024018968855, 58.51629720415388, 63.41976601736886, 46.162038803100586, 28.355549812316895, 30.315758228302002, 27.269482101712907, 30.760338715144567, 18.856670992715017, 30.795600822993688, 23.51715087890625, 26.957867554255895, 21.201324973787578, 19.065731866019114, 15.540571996143886, 18.81657988684518, 20.424184594835552, 31.522729805537633, 41.151196002960205, 35.87178448268345, 50.14782428741455, 49.30375017438616, 59.280300276620046, 60.09114810398647, 62.83835465567452, 55.45131131580898, 35.34776871544974, 22.99784251621791, 13.684955682073321, 9.044371094022479, 2.737682742731912, 0.9783559760877064, 0.10424954351037741, 0.022684470617345402, 0.03243338356592825, 0.02444900941502835, 0.12772717406707151, 0.024814751664442674, 0.031033922053341354, 0.02894756257800119, 0.0701214305258223, 0.05861268950892346, 0.06396507551627499, 0.011280279124288686, 0.009493533571782922, 0.011774271277577748, 0.024176351992147307, 0.011058101314119995, 0.012867447171759392, 0.08728261930601937, 0.03851271467283368, 0.006621802466854985, 0.016271836323929683, 0.03947781877858298, 0.02528031150411282, 0.059917030589921136, 0.02222841196427388, 0.02828882890753448, 0.042016879854989905, 0.021032349805214574, 0.03875418832259519, 0.03420888240049992, 0.006481652755090701, 0.07842824621392147, 0.03178729948454669, 0.025954196861545955, 0.00683691757564832, 0.03509878786280751, 0.041835561727306673, 0.022493344265967607, 0.027108612237498164, 0.055460670430745394, 0.13370107779545443, 0.03270348460812654, 0.057839926332235336, 0.06833231010075126, 0.009667756767677409, 0.010306889257792915, 0.03671959089115262, 0.023798217996954918, 0.043802051206252406, 0.040235728823712895, 0.013382528193428047, 0.020312688779085875, 0.046330469460891824, 0.04019783603559647, 0.0209119505515056, 0.057262099481054714, 0.02786571143328079, 0.03914199483447841, 0.02902041349027838, 0.03450706800712006, 0.06792254958833967, 0.05870588629373482, 0.048195355106145144, 0.07198438234627247, 0.0269518350251019, 0.07077063926096473, 0.015384356624313762, 0.004213147763428944, 0.060041467126991065, 0.031531410358314, 0.016564398571582775, 0.02528803832163768, 0.0320798803919128, 0.06160430290869304, 0.0703186331582921, 0.05667953984811902, 0.05629122104229672, 0.023451518832838962, 0.03946408862248063, 0.038877199936125956, 0.0915239585031356, 0.032765136299920936, 0.02970924527783479, 0.014718081037114774, 0.048391417799783606, 0.06927662728620426, 0.05166754771822265, 0.0379276885651052, 0.03865223165069308, 0.013432748266495764, 0.03527994653476136, 0.029079021952514137, 0.06391002597021204, 0.048953611204134564, 0.05170726915821433, 0.06458451692014933, 0.034261292445340326, 0.15577801529850277, 0.01951605304410415, 0.05231004234935556, 0.028265224370573248, 0.06528448007468667, 0.012417561491020024, 0.004171322440795068, 0.03001449104132397, 0.10345588824046509, 0.0732295483882938, 0.5465044262153762, 3.469501107931137, 15.840916565486364, 39.577477659497944, 61.478481020246235, 75.73596218654087, 73.70911012377057, 73.17566217694963, 67.47479724884033, 63.28347710200718, 63.79064001355852, 55.56553970064436, 58.99844660077776, 50.736958571842735, 45.62210818699428, 40.79388836451939, 41.0295295715332, 40.654253891536165, 36.246830872126985, 26.77530711037772, 23.482158013752528, 22.121770211628505, 18.401951347078594, 17.470534903662546, 19.665113006319316, 22.361217294420513, 24.428052765982493, 36.46943725858416, 36.69271067210606, 31.818486826760427, 52.71001073292324, 54.8863011768886, 33.406480244227815, 37.43872833251953, 33.936693804604666, 32.20722811562674, 34.48176956176758, 39.48784589767456, 55.7086934362139, 49.620883328574045, 38.31822436196463, 35.55568661008562, 34.05530650275094, 30.275729656219482, 41.004755769457134, 24.070600952420914, 30.07436043875558, 27.217118740081787, 26.400283302579606, 31.84116574696132, 22.606248991830007, 24.603783130645752, 26.062190907342092, 31.3419029372079, 39.915406772068565, 52.78641659872872, 47.07074505942208, 56.935404845646445, 58.17242043358939, 65.64836597442627, 67.04109069279262, 71.21730545588902, 63.42970194135393, 43.611983912331716, 29.172293186187744, 17.67571347100394, 10.807491251400538, 3.5321675624166216, 1.0782107093504496, 0.1818421467074326, 0.03435931700680937, 0.056234587116965225, 0.04071745476020234, 0.016793249773659875, 0.06182437895664147, 0.0778062738744276, 0.05537716651867543, 0.008909638921198035, 0.0907264898664185, 0.06623514834791422, 0.09406528249382973, 0.018402887508273125, 0.09141504684729235, 0.02256984569664512, 0.05759830679744482, 0.02998839458450675, 0.19384290703705379, 0.011416278746245163, 0.06964867482227938, 0.03171141891341124, 0.019001318075295006, 0.043617421827678166, 0.007303480374892908, 0.03602492370243583, 0.010580500870543932, 0.08891097442912203, 0.03696357851315822, 0.03652868167098079, 0.08642932080796786, 0.038130618033132384, 0.03695199592038989, 0.05711333067821605, 0.03428280200543148, 0.01457725787934448, 0.03433238934459431, 0.05683168097000037, 0.010926027865415173, 0.028311498762507523, 0.036049530774887116, 0.03927146949406181, 0.07461646718106099, 0.05823976666267429, 0.043858447644327364, 0.03674824542499014, 0.06711767813456909, 0.08098867775074073, 0.010112936808062451, 0.04028506849759391, 0.043937795529408116, 0.06515477132052183, 0.018768602616286705, 0.052567675310586176, 0.02773207056868289, 0.07156452523278338, 0.034228346177509854, 0.01881927900415446, 0.08215870282479695, 0.1682921823646341, 0.14227480201848916, 0.1113586566810097, 0.129660252481699, 0.11382570822856256, 0.28283168907676426, 0.19641986090157712, 0.17749934616897786, 0.09759662300348282, 0.12375238378133092, 0.17214270574705942, 0.1559891211135047, 0.11294428445398808, 0.15612367460770266, 0.11812415293284825, 0.21556012598531588, 0.13369022123515606, 0.13781692194087164, 0.21291092171200685, 0.14723437731819494, 0.15307367326957838, 0.17790363090378897, 0.2727325095662049, 0.11174492631107569, 0.12342302288327898, 0.1570811825139182, 0.10364798150424447, 0.23808746146304266, 0.12712300648646696, 0.11816924837018762, 0.11189558822661638, 0.07763727115733282, 0.1845134033688477, 0.18427301198244095, 0.14377696998417377, 0.18879931553133897, 0.14991577129278863, 0.13596385637564318, 0.05789013792361532, 0.19977647864392825, 0.15409542487135955, 0.23884674214891025, 0.18666805060846464, 0.1452746053359338, 0.12190866842865944, 0.11715520492621831, 0.1621258325342621, 0.22376043881688798, 0.1437495028866189, 0.7766314776880401, 5.212120388235364, 21.31166931561061, 49.26962062290737, 73.60260813576835, 86.59710829598563, 80.88616847991943, 81.68515573229108, 75.16136005946568, 71.83397892543248, 72.4530564716884, 64.43885135650635, 65.85369913918632, 60.85497052328927, 55.73753193446568, 50.727912017277305, 47.81736373901367, 46.39079434531075, 42.6770829473223, 34.69530854906355, 25.38719252177647, 28.245109932763235, 28.57095091683524, 23.6840500831604, 29.622324534824916, 33.260394368852886, 35.08806242261614, 54.390950202941895, 45.1863797051566, 42.62655912126814, 61.28401483808245, 74.45417935507638, 59.358960832868306, 69.83387742723737, 63.921259198869976, 60.988646915980745, 51.7157895224435, 75.99667944226945, 74.89862782614571, 77.8922313962664, 63.33409472874233, 40.55944572176252, 43.68425907407488, 39.673828329358784, 44.82463564191546, 27.46900830950056, 42.13340030397688, 35.94599124363491, 36.761994634355815, 32.90504264831543, 28.81145065171378, 25.901869910103933, 25.71263919557844, 32.19540922982352, 46.5579263142177, 57.345272132328574, 53.261666434151785, 66.38746670314244, 67.0370329448155, 73.8023202078683, 77.3725061416626, 79.28542164393834, 73.58190250396729, 52.549257210322786, 36.59765584128243, 23.492337124688284, 14.205966353416443, 4.818609161036355, 1.7788658610412051, 0.6281262721334184, 0.13103605008551053, 0.11616694581295763, 0.13896416180900165, 0.17181977736098425, 0.1479181641978877, 0.25502543257815496, 0.19009877794555255, 0.2109851036220789, 0.11577870164598737, 0.12822044188422815, 0.15382006179009164, 0.08044174459895917, 0.26320579648017883, 0.14327811103846344, 0.14702380076050758, 0.09941466259104864, 0.34574344754219055, 0.1138097219435232, 0.09810675241585289, 0.17594813369214535, 0.07948807041559901, 0.09100863829787288, 0.1028306046500802, 0.0936904326081276, 0.13243334367871284, 0.14729465836925165, 0.11055759180869375, 0.16090506661151135, 0.16726295330694743, 0.11123728712222405, 0.23888558149337769, 0.2327454909682274, 0.07102998213044234, 0.09922645054757595, 0.11366586573421955, 0.1734862865081855, 0.09766572500978198, 0.1532442569732666, 0.12459083593317441, 0.18656598537095956, 0.2899075879582337, 0.1951241847127676, 0.1698263364710978, 0.15674300066062383, 0.13265181838401727, 0.153365253337792, 0.12120700893657547, 0.1474896150508097, 0.14096455089747906, 0.17540704272687435, 0.10394258783864123, 0.11233359615185431, 0.10737121171717133, 0.16906538658908435, 0.1324085092970303, 0.0814034729929907], [0.05882943394993033, 0.04983172033514295, 0.06592111555593354, 0.09340995337281909, 0.006352354090527764, 0.02413668653129467, 0.06602145731449127, 0.03055429957540972, 0.06569352812532868, 0.03595298881243382, 0.055560069025627205, 0.023777911140184318, 0.08353222055094582, 0.027808371831529906, 0.03180268865876964, 0.024751544431118027, 0.016521579619230967, 0.02265690004320017, 0.03867898289380329, 0.07711234289620604, 0.009188765327313116, 0.013627637942720736, 0.037503071528460295, 0.04028746372620974, 0.03610248704041753, 0.043190063509557924, 0.00944176474253514, 0.024855752142944505, 0.06439839476453406, 0.010054519183800688, 0.03005862295893686, 0.07021081394382886, 0.06200493033975363, 0.049035310213054926, 0.01038774349061506, 0.06301104849470512, 0.039702281555426974, 0.04253714658053858, 0.08903632020311696, 0.022120608016848564, 0.07416849157639913, 0.014009596330911984, 0.0441029204188713, 0.05990397557616234, 0.040441175656659265, 0.03271925715463502, 0.04169833141246012, 0.032150682128433666, 0.31386508526546614, 3.5987719084535326, 12.549768550055367, 24.70037351335798, 52.885438850947786, 68.18317999158586, 67.4677517754691, 57.69100407191685, 59.54838957105364, 47.24590914590018, 49.32479279381888, 35.344808782849995, 35.57594060897827, 25.57032445498875, 19.43358165877206, 24.956362519945415, 15.81623135294233, 27.033026218414307, 18.33501935005188, 13.45208854334695, 20.59062695503235, 31.954313686915807, 29.789619786398752, 24.94948206629072, 24.81514733178275, 31.694513593401226, 51.02617038999285, 42.64778586796352, 52.259913376399446, 38.81573622567313, 30.639141287122452, 45.93664618900844, 32.27240569250924, 33.46084295000349, 37.92970541545323, 34.40452296393258, 26.095516204833984, 37.683749607631135, 47.10128239222935, 52.54524115153721, 44.14416381290981, 62.917001315525596, 50.78180571964809, 45.41977316992623, 46.49802936826433, 48.44230209078108, 43.920150416237966, 57.33005210331508, 44.5491395677839, 40.761127608163015, 53.09619508470808, 40.38792596544538, 32.62680550983974, 26.01999623434884, 22.111179419926234, 16.946632044655935, 16.91738533973694, 9.922507013593401, 17.169040407453263, 31.779886109488352, 28.56331310953413, 32.05896397999355, 38.79923077992031, 41.73302773066929, 50.21873760223389, 57.51769168036324, 54.75732176644461, 49.18788548878261, 41.822530950818745, 24.539880548204692, 13.177806666919164, 4.877978912421635, 2.099965350968497, 0.6080694826585906, 0.054226011503487825, 0.02651089073957077, 0.05958598692502294, 0.026560423795932105, 0.009785376572316247, 0.011373682862280734, 0.034946304080741744, 0.03380185977688857, 0.03981591920767512, 0.00961605494376272, 0.0400741730284478, 0.004690823694025832, 0.044405835414571423, 0.07410455322159187, 0.07774216588586569, 0.0236705109210951, 0.037431313057563136, 0.029643773433885405, 0.07255829405039549, 0.05909136203782899, 0.007854268453749163, 0.04257849311189992, 0.015609528470252241, 0.007598605788578945, 0.015920555352100303, 0.09217989830566303, 0.05260126279400928, 0.06327586714178324, 0.05197017094386475, 0.06197182461619377, 0.015757712036637322, 0.0333327478063958, 0.12945680054170744, 0.036711197412971935, 0.033415803885353465, 0.01492311226736222, 0.01916707230598799, 0.06232758052647114, 0.03036918504429715, 0.02959117679191487, 0.0629666790898357, 0.02597696171142161, 0.03480082617274352, 0.01795054892344134, 0.031716552030827315, 0.05684152990579605, 0.03198516708133476, 0.005800451517903379, 0.0426755948657436, 0.039441028609871864, 0.009218039024355156, 0.014802392405856932, 0.06474944164178201, 0.11046896156455789, 0.07109799848071166, 0.02377068134956062, 0.04799148586711713, 0.060213618246572356, 0.063713359380407, 0.010371965855093939, 0.012131793923409922, 0.061598467507532666, 0.046947729374681196, 0.04615523779232587, 0.030088878835418394, 0.04512535394834621, 0.05926427311663117, 0.060461588869137425, 0.02367164916358888, 0.016292109253949354, 0.050318908478532515, 0.020718213536643555, 0.011116984583038305, 0.057737705031675954, 0.0410145275693919, 0.03150286099740437, 0.0327367871068418, 0.02725574916361698, 0.037731622478791645, 0.060051848712776384, 0.00871697229532791, 0.026063778570720127, 0.04591798802305545, 0.03457278073100107, 0.06712509452232293, 0.02224666455627552, 0.04042984751452293, 0.03934385560985122, 0.03264288803828614, 0.07273277254509074, 0.020315460594637052, 0.057257315809173245, 0.02123240737377533, 0.04860735817679337, 0.07903439511678048, 0.05592553477202143, 0.06294951893921409, 0.05484244699722954, 0.09127963161362068, 0.0632343679400427, 0.02942345989868045, 0.04614468996546098, 0.6514298245310783, 5.695466177804129, 16.155294758932932, 37.780916690826416, 68.79100145612443, 77.69021947043282, 76.50102138519287, 66.17066901070731, 66.60053321293422, 57.32798154013497, 56.27157047816685, 43.24391351427351, 45.742760181427, 34.99887534550258, 29.9237790788923, 31.511383397238596, 23.44730932371957, 34.155857358660015, 21.838184697287424, 22.679066113063268, 26.930443014417374, 36.396915435791016, 29.839685031345912, 28.027997834341868, 30.582242488861084, 26.770356518881663, 40.22325365883963, 35.8863513810294, 38.988909653254915, 39.74129186357771, 32.85254553386143, 40.18017830167498, 31.825591359819683, 38.28653015409197, 39.78307832990374, 36.113084997449604, 24.834148917879375, 28.86834944997515, 28.904917819159373, 35.81412138257708, 29.930852345057897, 44.11863265718733, 32.39482947758266, 25.746905973979406, 32.89996351514544, 35.96630777631487, 34.510288442884175, 36.60282530103411, 39.24818515777588, 36.41925042016165, 46.78497954777309, 35.9752014705113, 22.34007740020752, 27.788476058415004, 23.65421278136117, 20.974869285311016, 26.668554987226212, 21.64373414857047, 25.524457659040177, 41.141412939344136, 38.722901344299316, 38.83027185712542, 47.171063150678364, 49.97171177182879, 57.83009658540998, 65.7968281337193, 64.70849704742432, 58.6008289882115, 50.343864236559185, 32.760287352970664, 20.39985374041966, 6.441926785877772, 1.9726986714771815, 0.5337757063763482, 0.061235966959169934, 0.034027557487466505, 0.07462484030319111, 0.02062829746864736, 0.03105009832818593, 0.07321266643702984, 0.0034461640087621553, 0.03718268086335488, 0.08685983770659991, 0.05190098751336336, 0.03282884056014674, 0.026906539419932023, 0.013411124203620213, 0.016756240777405243, 0.052197866940072606, 0.024451350360842686, 0.018698308084692274, 0.036343126092106104, 0.024839662381314805, 0.032961355056613684, 0.06327232518898589, 0.03610195778310299, 0.013101473051522459, 0.042449317007724724, 0.02354624232144228, 0.022283780421795588, 0.0390822600041117, 0.03164693773058908, 0.021130403204421912, 0.034225075638719966, 0.03802902437746525, 0.06552248301782779, 0.06294449778007609, 0.029333079034196477, 0.024737419028367316, 0.02500275845107223, 0.04313107846038682, 0.015867344635937895, 0.014058940245636871, 0.04721612390130758, 0.03891675513503807, 0.020756684775863374, 0.021873616181047897, 0.018244093350533928, 0.0190932171618832, 0.022871524062273756, 0.03458323695563844, 0.025096392890970622, 0.019957173748740127, 0.053655750317765136, 0.04364573709400637, 0.005474742834589311, 0.08522089065185615, 0.013957040401042571, 0.15710109073136533, 0.13432794915778296, 0.19608017270054134, 0.23134266052927288, 0.12645676652235643, 0.09526639125709023, 0.15235258053456033, 0.08745346085301467, 0.13541256024369172, 0.16048546055597918, 0.12167168328804628, 0.13137668823557241, 0.20370476213949068, 0.1662502805037158, 0.06995336418705327, 0.06931031654988017, 0.0723955813529236, 0.12546212917992047, 0.14028137469930307, 0.18262041280312197, 0.10116888596011059, 0.13559398693697794, 0.11321745586714574, 0.1561369196112667, 0.12118406088224479, 0.16065916552075318, 0.07035137925829206, 0.08480279094406537, 0.1613120519156967, 0.09853614973170416, 0.10567775115902935, 0.19312399918479578, 0.09366273480866637, 0.11393651978245803, 0.16062304031636032, 0.13742543437651225, 0.13228545018604823, 0.12653021115277494, 0.18369129034025328, 0.05877087637782097, 0.20218648575246334, 0.13195360584982804, 0.13087183104029723, 0.15825736868594373, 0.15241853413837297, 0.2174384059118373, 0.10987300425767899, 0.1953169157994645, 0.7756375595927238, 7.545590809413365, 20.82897969654628, 50.116185665130615, 83.67027691432408, 88.13397339412144, 84.75272982461112, 74.48642594473702, 76.18426690782819, 64.17119979858398, 64.89060933249337, 51.01255192075457, 52.48224530901228, 39.32148517881121, 33.230055059705464, 38.855737004961284, 29.05693745613098, 40.58502204077584, 30.039633342197963, 24.279439483370098, 33.0438746043614, 45.099707875932964, 40.13848911012922, 37.79666478293282, 38.86665957314627, 45.51547418321882, 68.6159485408238, 57.5716826575143, 69.21797520773751, 55.26316104616438, 46.44760629108974, 61.35713768005371, 46.20101819719587, 44.765791348048616, 49.96435015542166, 46.03014809744698, 36.4646430015564, 49.34216676439558, 58.973280225481304, 65.08594403948102, 55.032324518476216, 75.54369163513184, 61.970892906188965, 58.80385535103934, 60.167960439409526, 63.87653364453997, 57.18822199957711, 72.17662933894566, 60.82733753749302, 57.77271488734654, 69.19199589320591, 54.06472185679844, 49.300067629132954, 37.54633855819702, 31.929852553776332, 26.05738970211574, 29.510197980063303, 19.878254209245952, 29.500751904078893, 48.028658458164756, 43.38508701324463, 48.41116026469639, 53.76950332096645, 57.1322021484375, 68.14083766937256, 74.13849490029472, 73.28699316297258, 67.39599078042167, 57.643210887908936, 40.97392313820975, 25.582749571119034, 9.533294115747724, 2.953245609998703, 0.722725507404123, 0.16634811168270452, 0.15004307803298744, 0.16621125116944313, 0.11943345410483223, 0.11124979930796794, 0.1663100187267576, 0.08995046972164086, 0.17902150377631187, 0.14919537066348962, 0.21798066395734036, 0.15705448894628457, 0.12456537729927472, 0.1258496269583702, 0.16723035648465157, 0.17701367794403008, 0.1607426388987473, 0.07998259352254015, 0.08368210215121508, 0.12581052977059567, 0.09402912336268596, 0.12594106633748325, 0.0969496127218008, 0.06476612681789057, 0.09568106436303683, 0.10828392952680588, 0.15791085442262037, 0.2187101433851889, 0.13831131612615927, 0.23408584190266474, 0.12434535553412777, 0.09475274024797337, 0.12112102497901235, 0.14514777357024805, 0.0713171652917351, 0.09456798873309578, 0.11482825050396578, 0.17259246589882032, 0.1458067667803594, 0.12503147657428468, 0.09068452926086527, 0.1859005189367703, 0.07111508399248123, 0.12718013913503715, 0.07272866062287774, 0.057351130060851574, 0.19535191463572638, 0.07296574754374367, 0.16722921654582024, 0.20159981080463954, 0.12138213882488863, 0.15839623766286032, 0.1010326836258173, 0.1415645929851702, 0.14763948986572878], [0.013974721327291002, 0.08634346577205829, 0.022199952509254217, 0.02983555457155619, 0.02965991917465414, 0.020982874424329827, 0.040086366302732906, 0.04227923881262541, 0.024990327689530592, 0.03867567164291229, 0.06815836764872074, 0.050674674566835165, 0.08831517997064761, 0.0679178134139095, 0.018742260190525224, 0.037960081826895475, 0.06912552432290145, 0.03361865192917841, 0.03975195710414222, 0.07758907481495823, 0.0745508528447577, 0.04474053638322013, 0.06277242808469705, 0.04448649287223816, 0.06423777195491961, 0.06456120924225875, 0.13626176039023058, 0.0374018103549523, 0.017665806791878173, 0.060855417379311154, 0.006400639490623559, 0.026655791892803142, 0.05638915400153824, 0.013084623330671872, 0.011974478123842605, 0.04430262345288481, 0.07285269682428666, 0.01851050146589322, 0.12483364290424756, 0.09581546179418053, 0.025122470688074827, 0.034038200309234004, 0.11643392220139503, 0.08684750193996088, 0.07989478430577687, 0.05271438815231834, 1.0678905716964175, 3.7871755702154974, 15.547966616494314, 38.45371770858765, 49.83188622338431, 56.682250704084126, 66.48144803728376, 55.78162520272391, 50.62378283909389, 57.56985528128487, 46.551523549216135, 32.93967594419207, 23.368033851896012, 23.744275331497192, 17.614062104906353, 18.719449281692505, 11.286962117467608, 15.651043142591204, 8.49029655115945, 9.734596456800189, 21.71110909325736, 19.051585333687918, 22.337852239608765, 21.05869061606271, 64.47130639212472, 49.119275501796174, 37.28463813236782, 55.82342209134783, 44.17027514321463, 44.63848992756435, 36.33708449772426, 28.687701497759136, 23.862882818494523, 18.690112250191824, 12.17522851058415, 7.96535667351314, 7.0270393661090305, 6.244797272341592, 7.263992914131709, 8.411692449024745, 12.219755172729492, 8.772086824689593, 19.634071929114207, 9.612463627542768, 13.144717608179365, 22.008427722113474, 20.833136456353323, 21.516245126724243, 37.93193578720093, 47.401222229003906, 37.048097133636475, 45.14118167332241, 48.715480940682546, 67.04734407152448, 43.950840609414236, 42.87487036841256, 36.1131649017334, 27.903930800301687, 20.31225085258484, 17.623954602650233, 26.327995981488908, 25.570915051868983, 26.666540009634836, 52.945877756391255, 58.309046336582725, 45.958178656441824, 50.885688236781526, 38.95647198813302, 44.41041530881609, 47.80994653701782, 53.75266783578055, 56.28964969090053, 53.58995839527675, 26.906487362725393, 18.812186888286046, 5.3515355587005615, 2.168567955493927, 0.0881450983828732, 0.05691435367667249, 0.07380415898348604, 0.02755553780921868, 0.08037302257227046, 0.05852809654814856, 0.037807855888136795, 0.15972795763186046, 0.0317922663608832, 0.04684343854231494, 0.056166248462562046, 0.03781851228060467, 0.04655397550335952, 0.0519889256517802, 0.01648565288633108, 0.03870063494624836, 0.06547645120216267, 0.029142393730580807, 0.04934737864615662, 0.052540533909840245, 0.10787379582013402, 0.051735299439834695, 0.03554034113351788, 0.053318732152027745, 0.050128732076180835, 0.043052253047270436, 0.035807884098695855, 0.040067116264253855, 0.03216575239119785, 0.08463874153260674, 0.06184155267796346, 0.05553042722333755, 0.05707050833318915, 0.053735763167164156, 0.11747495776840619, 0.03658657767144697, 0.06461513920554093, 0.024497458511697393, 0.018894204537251165, 0.04754819893943412, 0.049659240126077614, 0.128340108320117, 0.068245885095426, 0.008320509372944278, 0.061704685379351885, 0.015010502488751496, 0.011185061153290527, 0.04805838941995587, 0.07753799469875437, 0.011750839767046273, 0.06862145422824792, 0.03012013215837734, 0.056174102505402904, 0.053777625385139666, 0.030303818373275653, 0.053753493287201436, 0.05427181940259678, 0.054030481459839005, 0.006414490934860493, 0.06396982526140553, 0.03238003035741193, 0.043150114760335, 0.047986485064029694, 0.04795597812959126, 0.009158786802020456, 0.041859412233212163, 0.049106790484594445, 0.006980122815418456, 0.03665425814688206, 0.03292683458753994, 0.08970296050288848, 0.053673049568065574, 0.049663026351481676, 0.07919658534228802, 0.02731222363321909, 0.009941783983127346, 0.0721629388364298, 0.06689574290066957, 0.03738056881619351, 0.02207469324847417, 0.011757222237065434, 0.04830101318657398, 0.018189540831372142, 0.061030520126223564, 0.018432573415338993, 0.08087984073374953, 0.07492931932210922, 0.018686912089054073, 0.03815320985657828, 0.04427485440724662, 0.04609416964064751, 0.04584039415099791, 0.061804396100342274, 0.03248038568667003, 0.034648685050862174, 0.11473485694399901, 0.0630495146449123, 0.03935397256697927, 0.14217570876436575, 1.8351771022592271, 6.331158169678279, 22.233228002275737, 48.55969190597534, 62.597738538469585, 71.19698892320905, 74.42139080592564, 65.2386862891061, 60.79339558737618, 66.40230805533272, 53.764309542519705, 40.438366413116455, 33.94940553392683, 31.46766880580357, 28.70185671533857, 25.643021719796316, 16.18132097380502, 27.755557230540685, 13.391588841165815, 20.840399060930523, 30.52072661263602, 20.280386413846696, 30.023919991084508, 30.04654332569667, 47.66605976649693, 41.93074566977364, 33.1538576398577, 40.278120109013145, 41.679057598114014, 36.68177073342459, 34.574462005070274, 24.96005548749651, 23.28239730426243, 19.430201360157557, 12.167172074317932, 7.326019048690796, 7.2991920539311, 5.159344911575317, 5.200860832418714, 5.064762992518289, 7.057711320263999, 6.105940997600555, 10.257246903010778, 7.1894248468535285, 8.438388296536036, 12.958703909601484, 13.925466707774572, 14.831315517425537, 22.316998958587646, 29.896952084132604, 24.710323333740234, 33.06496933528355, 37.73300886154175, 43.68718426568167, 34.90295198985508, 39.11923006602696, 30.780676092420304, 23.41240504809788, 23.588081564222062, 20.14205993924822, 27.660012551716395, 29.65718364715576, 30.082781655447825, 54.69466291155134, 60.47810023171561, 49.48751265662057, 59.92394665309361, 47.71078879492623, 52.402132579258506, 57.015753814152305, 62.508961405072895, 66.6063141141619, 64.35093579973493, 36.398183482033865, 26.512032917567662, 8.739333016531807, 2.829949608870915, 0.1955440350409065, 0.05172031060127275, 0.08037871548107692, 0.03272702298792345, 0.058310598933271, 0.060944074764847755, 0.08528639642255646, 0.08837698094014611, 0.03701828879171184, 0.0676240756043366, 0.044501094945839474, 0.05662076514480369, 0.053389781553830416, 0.03596546367875167, 0.04723838324259434, 0.02470420134652938, 0.07246659004262515, 0.04066418976123844, 0.02710472253550376, 0.08483377285301685, 0.06239344592073134, 0.01458976836875081, 0.08691657001950912, 0.017006855990205492, 0.06391389361981835, 0.006405155141172665, 0.028310226509347558, 0.013749728444963694, 0.04464341088065079, 0.08601154679698603, 0.01528713951951691, 0.00923810076035027, 0.029690018988081386, 0.03457014462245362, 0.05027634058413761, 0.045464651991746256, 0.02278296336797731, 0.01698314119130373, 0.07269939540752343, 0.05321313513975058, 0.049025783581393104, 0.03231986465730837, 0.035372675130409856, 0.025507785280102065, 0.033947585350168605, 0.031906457019171545, 0.08464936739099876, 0.054707920644432306, 0.04886049584352544, 0.0716450469834464, 0.012942088568317038, 0.047078327009720464, 0.06099752296826669, 0.12347540578671864, 0.16155552385108812, 0.12775861737983568, 0.21270474206124032, 0.16210713210914815, 0.09685313861284937, 0.13340837135910988, 0.11488279114876475, 0.10926806993250336, 0.13351997679897717, 0.15998148545622826, 0.15563052892684937, 0.17615196561174734, 0.18920355955404894, 0.11393132220421519, 0.12485121696123055, 0.2241817954927683, 0.18075274516429218, 0.16129692058478082, 0.18042885325849056, 0.14101093555135386, 0.23063834117991583, 0.1285301252667393, 0.12788774259388447, 0.1540115172309535, 0.1713484940784318, 0.2389966712466308, 0.14461348152586392, 0.1786496258739914, 0.14552710178707326, 0.13176824365343365, 0.08565440667527062, 0.15360043357525552, 0.12890033397291387, 0.09643795660563878, 0.1276525216443198, 0.09406904157783304, 0.12150810206575052, 0.2170567706759487, 0.1789198320891176, 0.1942123422133071, 0.0891681799132909, 0.24460856297186442, 0.13969512044319085, 0.21087471954524517, 0.20163817517459393, 2.859381743839809, 10.021154931613378, 32.10082687650408, 59.33608736310686, 76.01614829472133, 85.02168069566999, 83.74625546591622, 72.76182052067348, 68.2353401184082, 73.77691759381975, 62.081709725516184, 47.873929023742676, 36.9046550478254, 35.03084748131888, 30.14056634902954, 28.803781577519008, 19.056108610970632, 29.78725392477853, 17.68853289740426, 19.771081720079692, 33.92499998637608, 30.178666796003068, 34.479348114558626, 33.824720110212056, 76.56782136644635, 62.5424656186785, 49.076530184064595, 72.01616069248745, 59.27852848597935, 56.51420157296317, 46.634033407483784, 37.862742151532856, 33.4887295450483, 25.17558513368879, 16.69962532179696, 12.402879289218358, 10.179606863430568, 8.090325236320496, 9.942144359861102, 11.502787062100001, 15.069154092243739, 11.612949013710022, 25.05261591502598, 11.468383925301687, 16.930875267301285, 27.496795892715454, 25.588320289339336, 26.110164744513376, 46.39502232415335, 58.4006861277989, 48.409791469573975, 57.643586090632844, 60.191174370901926, 82.13142463139125, 57.68683167866298, 58.299812180655344, 49.1705983706883, 41.407268387930735, 32.8508015360151, 28.34751422064645, 38.677717208862305, 38.12531110218593, 38.71409102848598, 64.41724245888847, 69.3358791896275, 60.14528846740723, 67.93215547289167, 56.14084359577724, 61.58804716382708, 64.92526694706508, 72.60758440835136, 77.55376379830497, 72.99121529715401, 45.770563398088726, 32.04332358496529, 12.693288803100586, 4.054521407399859, 0.4421105650918824, 0.1628454596336399, 0.23336040654352733, 0.13188045977481774, 0.22792585673076765, 0.18794255650469235, 0.21122774774474756, 0.2194934170693159, 0.09245057949530226, 0.22366974582629545, 0.10894144353057657, 0.16576203384569713, 0.2353933517421995, 0.13134130941970007, 0.19658201720033372, 0.10890225134789944, 0.2262022149349962, 0.1100394217563527, 0.11476095340081624, 0.20970249601772853, 0.21360327170363494, 0.14612330336655888, 0.26955748136554447, 0.17217085137963295, 0.2041382917336055, 0.12708476425281592, 0.16802040194826467, 0.07814705451684338, 0.25980451756290024, 0.1759327852300235, 0.1678820215165615, 0.12315540867192404, 0.18604740819760732, 0.12655250781348773, 0.3161805724459035, 0.13578986642616137, 0.127175986500723, 0.1771124726427453, 0.10229927101837737, 0.18714810056345804, 0.13719885796308517, 0.15059939532407693, 0.12394717761448451, 0.1409921944141388, 0.09298094960727862, 0.13387628910796984, 0.16405918236289704, 0.18782135657966137, 0.11121621182454483, 0.16903038775282248, 0.1608386244624853, 0.1757004005568368, 0.12564059746052536], [0.04184962097289307, 0.017585865188656107, 0.01920049185199397, 0.03337468805589846, 0.020722120202013423, 0.04774177819490433, 0.024349388599927937, 0.045364038819181066, 0.03138621404234852, 0.06047418247908354, 0.024498276146394864, 0.020912983621071492, 0.011152241262607276, 0.03183286650372403, 0.021049392908545475, 0.006851187591174883, 0.05676543220345463, 0.04684969802786197, 0.02737178882983114, 0.02283657611613827, 0.04031696642882057, 0.04135790700092912, 0.017812901309558322, 0.036959422486169, 0.06903145222791604, 0.08105254825204611, 0.06626541100974594, 0.0645910579977291, 0.06777758058160543, 0.033983730910612006, 0.053160239942371845, 0.07492490205913782, 0.07141354440578393, 0.06037050911358424, 0.032929460518062115, 0.060500889617417536, 0.05233711589659963, 0.05908409492777927, 0.03983327613345214, 0.015014056315911668, 0.0443872198063348, 0.030412557002689158, 0.018122616922482848, 0.029229100327938795, 0.38572403362819124, 6.546229669025966, 24.278072425297328, 40.10662119729178, 60.86646284375872, 68.19652053288051, 65.85199683053153, 58.63691793169294, 52.90401833398001, 37.7172121320452, 64.42967973436627, 54.298681599753245, 24.00339102745056, 22.651381015777588, 19.10415540422712, 19.64270853996277, 16.649282148906163, 18.42134550639561, 23.511229276657104, 13.295469198908124, 21.436577081680298, 25.539378915514263, 16.977829456329346, 36.84548418862479, 30.686924048832484, 38.09868907928467, 66.04102952139718, 55.82465887069702, 47.78858082635062, 34.013791016169954, 22.313587393079484, 15.434768302100045, 7.038459599018097, 6.954433730670384, 2.4539988679545264, 1.4866099719490324, 0.2569368657256876, 0.9059381048594202, 0.70235925167799, 0.5264201696429933, 0.29147028124758173, 0.5447865926793644, 0.021233248757198453, 0.14992300447608742, 0.07850435748696327, 0.7712992780974933, 0.9385772134576524, 0.947605203304972, 2.06028180037226, 2.7637291508061543, 3.1873608188969746, 5.947942001479013, 11.826462813786097, 14.201393570218768, 22.28711301939828, 24.66025287764413, 26.205117089407786, 46.263016973223, 46.97372736249651, 41.81714609691075, 37.789876392909456, 38.506145341055735, 26.21414974757603, 29.504931245531353, 49.103791441236226, 57.53084462029593, 41.703636850629536, 31.24220323562622, 23.131913219179424, 27.18330012048994, 36.51823445728847, 31.76569788796561, 42.11003351211548, 49.22302252905709, 53.10175016948155, 58.85622392381941, 56.62729740142822, 45.27017845426287, 22.747396435056412, 7.087990701198578, 1.4441526787621635, 0.11353414173104934, 0.11194870394787618, 0.005233860782547188, 0.05912909537021603, 0.028179186130208627, 0.07756791130772658, 0.05244374767478023, 0.12770666873880795, 0.03755905745284898, 0.019971105769010525, 0.06894422655126878, 0.03417817869090608, 0.033286570105701685, 0.007949761231429875, 0.04008128407544323, 0.028587267268449068, 0.0463035248353013, 0.05418587615713477, 0.0188445866640125, 0.028971528434859853, 0.013389162569572883, 0.028633173555135727, 0.0766975883660572, 0.06508690424795661, 0.0647147549316287, 0.018627742139090384, 0.04456797135727746, 0.0576766843774489, 0.06931474738355194, 0.03214402569990073, 0.037936302567166943, 0.046707392271075926, 0.09343847219965287, 0.06614092018987451, 0.06941851574395384, 0.07205346399652106, 0.03558187086933425, 0.032259305406894, 0.026663927527676736, 0.15332260062651976, 0.06661166742976223, 0.1057594060631735, 0.03654592663847974, 0.044594128882246356, 0.019797967380977104, 0.0915929451584816, 0.047896053309419324, 0.026837444198983054, 0.019879920840529457, 0.055905107475285015, 0.03394065072227802, 0.0359816128121955, 0.024079318091805493, 0.009788777729097222, 0.030493075360677073, 0.03777010559237429, 0.05620975612795778, 0.014411691942119172, 0.00945984770078212, 0.04394990737949099, 0.037792928117726526, 0.005547703584722642, 0.07334502826311759, 0.06847001878278595, 0.026113019857023443, 0.04460373354543533, 0.00968991602504892, 0.08909254361476217, 0.013254971243441105, 0.006760430139755564, 0.052598918455519846, 0.0040631495399533635, 0.021907580251406347, 0.03994418268225022, 0.06595717290682451, 0.018740177088017975, 0.08717470509665352, 0.027920207973303537, 0.044297334272414446, 0.03155456536582538, 0.021683146312300648, 0.07287945146007196, 0.00883407810969012, 0.07933552217270647, 0.03625077747606805, 0.04912647817816053, 0.021503283642232418, 0.01186450116802007, 0.01570670316661043, 0.04703465310324516, 0.05770055523940495, 0.08486597612500191, 0.04991496640390583, 0.056928565592638085, 0.07173614709505013, 0.758589720087392, 8.6375584091459, 31.146401473454066, 49.22903619493757, 70.48017801557268, 75.33874756949288, 75.08899457114083, 64.05845832824707, 63.340264729091096, 47.42239686420986, 67.70475482940674, 66.01571723393032, 32.64664956501552, 31.406225885663712, 26.05831033842904, 27.49735869680132, 25.905750479016984, 21.729771954672678, 25.19007386480059, 22.68501203400748, 28.58408648627145, 20.427656957081386, 23.62205478123256, 31.166575568062918, 30.019653797149658, 29.675228118896484, 52.7628378868103, 41.62725877761841, 34.17773723602295, 29.51559325626918, 17.547684226717266, 12.229076181139265, 6.725066312721797, 6.253189827714648, 2.6151777505874634, 1.121734116758619, 0.28776900842785835, 0.5510215695415224, 0.3573251175028937, 0.22760215481477125, 0.11978070118597575, 0.1497574962143387, 0.07311906931655747, 0.05049695946010096, 0.14287138357758522, 0.3748011126049927, 0.27477357004370007, 0.38005910760590006, 0.7127368205360004, 1.1656620396035058, 2.1293073764869144, 3.178908118179866, 8.117471848215375, 10.854375958442688, 15.496671540396553, 19.240124702453613, 22.295033965791973, 32.977456774030415, 37.79247154508318, 36.83415862492153, 31.777224949428014, 33.8900158064706, 30.899056025913783, 34.26918942587716, 50.96414729527065, 65.90545627049038, 52.29163190296718, 40.259068148476736, 32.532608781542095, 34.1023770741054, 48.085668427603586, 41.16783346448626, 49.679286411830354, 57.30469117845808, 60.352671350751606, 68.06369182041713, 66.90569114685059, 55.962448596954346, 30.807145254952566, 9.920260139874049, 2.546196469238826, 0.1893896817096642, 0.018040181703067253, 0.05083956536171692, 0.013422469309132014, 0.047039643728307316, 0.01632328115270606, 0.07480248077107327, 0.07272458941276584, 0.02564274419897369, 0.04779844943966184, 0.10283571401877062, 0.0004777575138307709, 0.047918519603886774, 0.03521632369873779, 0.06432233777429376, 0.009781845645712954, 0.01817301511099296, 0.05209225635709507, 0.058960018014269214, 0.0767932210915855, 0.022955170466697643, 0.03115180054945605, 0.026518892363778183, 0.006854072213172913, 0.03840506509212511, 0.05231016109298382, 0.09848454035818577, 0.0453298847590174, 0.022294486008052315, 0.015563315146469643, 0.07840457212712083, 0.02677127007128937, 0.07656824602080242, 0.06918552717460053, 0.03846005696271147, 0.03147318187568869, 0.04535160805763943, 0.03470214682498148, 0.007553148183173367, 0.06341408472508192, 0.01292712687115584, 0.0759581480441349, 0.025034194978486215, 0.07769580158804144, 0.035828559060714076, 0.011519330404033619, 0.037424123979040554, 0.06711748135941369, 0.026109493171264018, 0.1027713685429522, 0.02995110229988183, 0.10107105478112187, 0.07243471246744905, 0.05453286200229611, 0.1411285935235875, 0.09032508890543665, 0.10499319074941532, 0.14680387399026326, 0.1336047529642071, 0.09958668478897639, 0.1595893329275506, 0.10927961859852076, 0.09740165275122438, 0.12402496486902237, 0.0742643414331334, 0.11829631083777972, 0.11546996821250234, 0.17411652340420655, 0.10495114871965987, 0.08161972888878413, 0.318778927304915, 0.07393884139933757, 0.16594576755804674, 0.09967928446297135, 0.20739530053521904, 0.18236092744129045, 0.29770805367401665, 0.19871622696518898, 0.10816522661064353, 0.170856203351702, 0.11972412493612085, 0.1493820763592209, 0.141129231346505, 0.17254466989210673, 0.1515717495765005, 0.10286801228565828, 0.12316497601568699, 0.1398924384266138, 0.1215498319693974, 0.15156530349382333, 0.20799188209431513, 0.21004056930541992, 0.18290959085736955, 0.1724553746836526, 0.23683537436383112, 1.1709274713482176, 13.031606146267482, 40.49985449654715, 60.97354848044259, 81.25162288120815, 84.73016207558769, 82.98611559186662, 73.7002511705671, 71.54216848100934, 54.47854961667742, 77.40268911634172, 68.8344624383109, 36.90338352748326, 33.95164632797241, 30.920744827815465, 29.972009999411448, 25.740289551871165, 28.397560358047485, 36.14634255000523, 21.46444456917899, 32.582868576049805, 35.93753528594971, 26.945586613246373, 52.74105528422764, 42.26875121252877, 52.06941114153181, 80.86906201498849, 68.59133802141461, 59.333301135471885, 42.837155546460835, 28.77156972885132, 19.910042217799596, 9.49928789479392, 10.413290415491376, 4.03641049351011, 2.2680989461285725, 0.6222618839570454, 1.6906823643616267, 1.1601705742733819, 1.0034661144018173, 0.878205021577222, 1.0299806573561259, 0.3147514691310269, 0.387432476239545, 0.21008638398987906, 1.0672303842646735, 1.0853738678353173, 1.189647763967514, 2.705277647290911, 3.8064919965607777, 4.46183305978775, 7.598674178123474, 15.487103870936803, 18.794604471751622, 27.8181848185403, 32.732737745557515, 35.54396847316197, 58.72932897295271, 61.038958821977886, 57.73489236831665, 50.07881130490984, 51.910801138196675, 35.49256917408535, 38.64201389040266, 55.57591683523995, 66.06691850934709, 52.84703268323626, 44.46141161237444, 36.80614348820278, 42.43384735924857, 54.10257911682129, 48.79340846197945, 60.1127222606114, 68.86962727137974, 68.93923432486397, 78.47316333225795, 75.60666315896171, 65.68783174242292, 36.082710947309224, 13.27140498161316, 3.3374175897666385, 0.5320595013243812, 0.1598828671766179, 0.21167335526219436, 0.23787437432578631, 0.28063755109906197, 0.23360853322914668, 0.15401200577616692, 0.19064111741525785, 0.1646767035126686, 0.17225600752447331, 0.20181547637496675, 0.15598821187657969, 0.12443057953247003, 0.09889731356608016, 0.20943220837840013, 0.09247612633875438, 0.07544834432857377, 0.145082132092544, 0.18328130591128552, 0.15463369313095296, 0.10437338972198111, 0.13249713954116615, 0.1328677146562508, 0.1085601339914969, 0.08891406176345688, 0.1037081607750484, 0.16008599341980048, 0.205946166866592, 0.1275495607405901, 0.11976993962058, 0.10791184806397983, 0.12841812627656118, 0.2787683228296893, 0.15971824101039342, 0.14638244946088108, 0.14769024428512367, 0.15677262549953802, 0.12107497959264688, 0.17967943847179413, 0.2236828686935561, 0.1562669269208397, 0.15538447855838708, 0.21298155720744813, 0.16015304625034332, 0.20738521750484193, 0.19657297911388533, 0.2003122634653534, 0.1843111863625901, 0.10723671250577484, 0.18766464213175432, 0.08267795174781765], [0.05577708827331662, 0.07434117195329495, 0.010069191655410188, 0.030730050323264937, 0.10810697437929255, 0.057572291764829836, 0.029227851823504482, 0.008291304377572877, 0.025441170104646256, 0.03279670174898846, 0.015160670770066125, 0.05818112088101251, 0.06676144724977867, 0.04477249198992338, 0.010436586985763694, 0.059338810188429694, 0.06382976884820632, 0.008613328615735685, 0.02355375200776117, 0.060184359816568236, 0.044769282519285164, 0.04632999787905386, 0.08057438462440457, 0.03988691093400121, 0.028837846858160834, 0.006654057477135211, 0.053989297776882134, 0.04061631911567279, 0.007388948645841862, 0.02350294839457742, 0.012908844593247133, 0.0455024328215846, 0.011603203269519975, 0.04661816152344857, 0.008372034777754118, 0.03256232218284692, 0.010640272172167897, 0.03741248710347073, 0.03183483086260302, 0.13083969562181405, 0.09432657954416104, 0.13680336704211576, 0.5431317814758846, 1.437360706073897, 13.940156936645508, 38.352725642068044, 55.26849726268223, 61.47316564832415, 61.644306727818076, 54.97382068634033, 53.000945704323904, 42.52792944226946, 38.74015024730137, 46.92540611539568, 74.78621292114258, 50.45979840414864, 14.942464113235474, 17.665171316691808, 17.05703718321664, 26.355102641241892, 25.710943835122244, 32.33143758773804, 36.918690408979145, 43.50962652478899, 40.08947651726859, 50.910017354147776, 53.83024099894932, 52.713651588984895, 54.250426360539024, 48.931538649967735, 21.768026999064855, 13.964896866253444, 8.637382967131478, 3.933358286108289, 3.103527545928955, 0.6196285166910717, 0.5160523716892514, 0.025053261812510233, 0.17246804971780094, 0.011922844153429781, 0.14470664438392433, 0.08993937567408596, 0.07646008753882987, 0.058531930271003924, 0.06534248124808073, 0.06978454467441354, 0.09198699758521148, 0.0635895538809044, 0.11055328989667551, 0.030948966076331477, 0.05873982661536761, 0.13077987597457, 0.05512704494010125, 0.030213362869939635, 0.14684674383274146, 0.18198440835944243, 0.08795873195465122, 0.4028014844017369, 1.4619155313287462, 1.762173899582454, 4.46666726895741, 11.393411125455584, 21.40422453199114, 27.45847484043666, 43.129765033721924, 45.22486230305263, 39.77343423025948, 34.71900885445731, 26.89291753087725, 21.836176667894634, 18.001531873430523, 29.97844750540597, 20.9006347315652, 21.77278130395072, 20.303452696119034, 20.454975536891393, 25.86345158304487, 31.922084467751638, 32.146629401615684, 40.49476841517857, 50.45116874149868, 56.932594299316406, 54.092928068978445, 35.09976666314261, 26.008424009595597, 10.847685711724417, 1.9703165250165122, 0.20134641868727549, 0.012720892089419067, 0.09537728423518793, 0.024951257643156817, 0.025510272110945413, 0.0587879279628396, 0.050738558638840914, 0.03385162014248116, 0.029550339161817516, 0.024101034605077336, 0.07366974798164197, 0.03204424712540848, 0.03009880580274122, 0.013962205748872032, 0.03912854287773371, 0.023504161275923252, 0.03228767495602369, 0.07663797906466893, 0.05907200343374695, 0.028444596799090505, 0.057699109959815226, 0.07385893711554152, 0.006429574344240661, 0.06668251327105931, 0.04921951550724251, 0.047420193308166096, 0.06673143564590386, 0.02424833777227572, 0.005939066468272358, 0.023016869655943344, 0.08543436455407313, 0.027460054361394474, 0.027387865020760467, 0.015358687644558293, 0.017631652731714503, 0.02339453206929777, 0.031132808354284083, 0.008256198672045554, 0.05996933885450874, 0.07881336233445577, 0.07710812240839005, 0.077124312253935, 0.03949609172663518, 0.016729506497670497, 0.0823870502146227, 0.06212978756853512, 0.03575373700420771, 0.043803211501134295, 0.036130629280315976, 0.017255230341106653, 0.03734799913529839, 0.04809329665399023, 0.013044787387895797, 0.044168117456138134, 0.03954730076449258, 0.01877467380836606, 0.02235019882209599, 0.0603420174281512, 0.006596460456161627, 0.03410874759512288, 0.02186137710564903, 0.027258286884586726, 0.04460130439006856, 0.02356769929506949, 0.023012355701731782, 0.023124980640464594, 0.039622397627681494, 0.038075765262224844, 0.06333466898649931, 0.03604062161009226, 0.02384625149092504, 0.027545765208612596, 0.055198314865784984, 0.019396903991167034, 0.07817057932593993, 0.037381959812981744, 0.012827864831446536, 0.05791748288486685, 0.04640355446775045, 0.022364052810839245, 0.03196900098451546, 0.022701603626566272, 0.05401972667979343, 0.0209034654710974, 0.042101791727223566, 0.010209801074649607, 0.021113604373697723, 0.07273663340934686, 0.058877596365553994, 0.022707566253042648, 0.09432161945317473, 0.5078777617641858, 1.790329628757068, 19.835673911230906, 46.41557856968471, 64.70137514386857, 68.86110183170864, 69.9175615310669, 62.49452304840088, 61.21501922607422, 50.5499894959586, 47.769952705928254, 47.92034993852888, 78.75923456464494, 54.20404018674578, 26.948614290782384, 24.455253226416453, 24.0475172996521, 29.28776182447161, 20.821460008621216, 26.586851119995117, 31.221278735569545, 31.44125870295933, 30.884503023965017, 43.6488927432469, 37.72365311213902, 43.00824104036604, 39.65282392501831, 37.05663299560547, 19.493066923958914, 13.547698361533028, 6.421072202069419, 3.0699768662452698, 2.490161636046001, 0.5718584028737885, 0.31742980969803675, 0.15908435359597206, 0.019800717144140174, 0.05170265512008752, 0.10768277464168412, 0.10222106307212796, 0.13814134310398782, 0.04601108642028911, 0.05286856148658054, 0.049069671226399283, 0.06484583432653121, 0.03228897095790931, 0.18801259488931724, 0.10799988119729928, 0.04200036770531109, 0.08005730701344353, 0.05130943050608039, 0.05401791838396873, 0.1168974159019334, 0.14777469475354466, 0.027226684116093174, 0.13203428366354533, 0.7019868173769542, 1.2631211642708098, 2.7703234255313873, 7.684409737586975, 13.600886821746826, 20.962013380868093, 31.07559585571289, 34.50692898886544, 32.47152369362967, 35.16506930759975, 33.21732248578753, 32.879542759486604, 22.119770867483957, 35.64296988078526, 29.225978442600795, 30.184600557599747, 30.543627875191824, 24.874509266444615, 31.503361701965332, 40.82335567474365, 40.442816734313965, 47.48212010519845, 58.36431925637381, 65.30126176561627, 65.00242669241769, 45.690815448760986, 34.071940490177695, 14.026944279670715, 3.6673165389469693, 0.25351799918072565, 0.05373429413884878, 0.05516656621226242, 0.045857876605753384, 0.06589771288314036, 0.019006035590012158, 0.039975134057125876, 0.014522320291559612, 0.007708140848470586, 0.04159165552950331, 0.021671636662046825, 0.051014610433152745, 0.05590699040996177, 0.0408220475406519, 0.025849439536354372, 0.07949252839067153, 0.05134470075634973, 0.0583146633580327, 0.024881416033687334, 0.04600066751507776, 0.018692051991820335, 0.0271003612516714, 0.05596670827695301, 0.0733709754422307, 0.031406943287168226, 0.036420991378171105, 0.028347920825971023, 0.053543350991926024, 0.02557242422231606, 0.018448888789862394, 0.06357826984354428, 0.01851073556047465, 0.03064092474856547, 0.053195466087864976, 0.013738664083315857, 0.028112893258886676, 0.02543569093437067, 0.09161343691604477, 0.050410218935992034, 0.02384039234103901, 0.105173579284123, 0.06798857783100434, 0.009629145580609995, 0.03940725792199373, 0.0245222555739539, 0.03988378628024033, 0.028963820277048007, 0.05653649788083775, 0.010950929252430797, 0.16675433702766895, 0.1593893143747534, 0.15241368939833982, 0.07492937360491071, 0.12225413774805409, 0.10732887113200766, 0.0842327129627977, 0.1353116620864187, 0.24387316671865328, 0.12604176093425068, 0.1007156517090542, 0.1499697691095727, 0.13627444899507932, 0.1033754614847047, 0.09158779507769005, 0.13768155420465128, 0.17490466896976742, 0.10968597965048892, 0.06960660565112319, 0.25298931183559553, 0.15786394051143102, 0.14122776820191316, 0.17489301173814706, 0.17054980407868112, 0.10719341518623487, 0.15012892628354685, 0.17427089012094907, 0.1470714882016182, 0.1313316470810345, 0.061819737777113914, 0.05608763000262635, 0.11812602568949972, 0.08045797515660524, 0.13255647064319678, 0.05441317181768162, 0.1774050976548876, 0.13044837090585912, 0.09298440335052353, 0.09385117076869522, 0.17616142438990728, 0.18493078382951872, 0.22000638954341412, 0.7853805082184928, 3.2492979296616147, 27.105966670172556, 57.589470045907156, 75.05107130323137, 77.85463469369071, 77.38170555659703, 72.43660313742501, 70.35590253557477, 61.77562073298863, 53.05742761066982, 57.76211541039603, 84.08600848061698, 60.51622499738421, 27.525804621832712, 26.48879987852914, 26.76238693509783, 39.590939794267925, 35.823636940547395, 46.426640101841514, 49.20682627814156, 57.06366164343697, 52.92181267057146, 66.92229734148297, 69.90125410897392, 67.72471700395856, 69.14894485473633, 60.78245217459542, 28.241680996758596, 18.927888291222708, 11.7704690183912, 5.328454511506217, 4.364016320024218, 1.1400422943489892, 1.0112127044371195, 0.2487388327717781, 0.5164555300559316, 0.2879506658230509, 0.34992240901504246, 0.12929324646081242, 0.16790267612252915, 0.17598871008626052, 0.16117586993745395, 0.1340345913278205, 0.3296416758426598, 0.2389090045222214, 0.3036079970853669, 0.12775043424751076, 0.12435195089450904, 0.249290726014546, 0.22096239110188826, 0.10409253050706216, 0.4081397908074515, 0.48032430027212414, 0.39567339260663303, 0.8693730469260896, 2.2259624642985205, 2.5547375423567633, 6.073313559804644, 15.268890483038765, 27.627192735671997, 35.00426367350987, 54.74822310038975, 56.51913826806204, 53.756729057856965, 45.63719620023455, 38.67463220868792, 33.42577191761562, 27.97973390987941, 43.01792335510254, 32.021735531943186, 34.602299962724956, 32.176669938223704, 32.210893290383474, 39.56318174089704, 48.06837088721139, 49.78764704295567, 56.98472663334438, 66.64301449911935, 74.77198301042829, 73.77377005985805, 53.8935877255031, 39.390640599387034, 17.53856819016593, 4.867848438876016, 0.6698226832917759, 0.226945020790611, 0.2232925889215299, 0.11384878520454679, 0.15310412592121533, 0.18668124132922717, 0.18603922506528242, 0.07973651601267712, 0.11768937483429909, 0.16904083719210966, 0.11490697413682938, 0.18075076384203775, 0.09521426619695765, 0.13757088514310972, 0.14848400812063897, 0.1603510563394853, 0.16322301008871623, 0.1859018217240061, 0.1203266368912799, 0.10237919565822397, 0.1267096158117056, 0.1293506505233901, 0.10824885605169193, 0.1650444966341768, 0.12202138666595731, 0.14875705061214312, 0.17174885688083513, 0.13099266455641814, 0.1465535895632846, 0.16481379472783633, 0.1700553148984909, 0.09658768892820392, 0.12705935990171774, 0.11065336024122578, 0.10064876851226602, 0.06445140870554106, 0.11950137546019894, 0.16654720742787632, 0.23777251264878682, 0.24783415560211453, 0.15889422808374676, 0.14998608109142098, 0.07810672239533492, 0.18622413942856447, 0.09034733128334795, 0.16035244055092335, 0.08884306664445571, 0.09842290223709174, 0.11415540160877363], [0.02683733563338007, 0.012751100468449295, 0.10640778698559318, 0.014456112237114991, 0.021766570496505926, 0.10049687844834157, 0.057569224786545546, 0.06460496796561138, 0.006986252107058785, 0.03366249207673328, 0.06503096582101923, 0.08411401004663535, 0.04693045387310641, 0.0640158774331212, 0.03408295987173915, 0.02230088459327817, 0.016368778622043983, 0.022825096999960284, 0.03768735485417502, 0.06345627603254148, 0.029680790911827768, 0.02815081488474139, 0.05223444337025285, 0.02710570301860571, 0.020850102084555795, 0.03737222962081432, 0.10627847178173916, 0.025441315989675264, 0.011004871090075799, 0.041903398265796046, 0.04477068030142358, 0.0692127567848989, 0.03800158102863601, 0.04688170452469161, 0.051742217104349814, 0.07053060749811785, 0.004435567725782416, 0.06308120223028318, 0.020670130848884583, 0.019386274740099907, 0.036574486177414656, 0.2421358727983066, 1.5442692722593034, 23.9896422794887, 53.456587723323274, 61.33281203678676, 59.328131675720215, 60.97628607068743, 52.49528707776751, 50.21782391411917, 38.95307779312134, 33.048811299460276, 34.55388144084385, 41.874760559626985, 19.16282946722848, 28.247324671064103, 13.869340028081622, 21.74064588546753, 32.71314035143171, 40.841598170144216, 75.5700739451817, 50.110397815704346, 52.702308654785156, 56.42652225494385, 54.40357855388096, 37.84404454912458, 43.21804189682007, 24.858714273997716, 15.743455920900617, 5.8717480557305475, 2.523772678204945, 0.4443143111254488, 0.31226349834884914, 0.1017233304945486, 0.07588458127741303, 0.02131297662188964, 0.027001885464414954, 0.056954790971108844, 0.015995842205094438, 0.06040457835687058, 0.029689927385853868, 0.05472288912694369, 0.019025518026735102, 0.04358401754871011, 0.06174652384860175, 0.1247436555900744, 0.0792983045269336, 0.021163956761094074, 0.03192614471273763, 0.038963665653552325, 0.02645542050179626, 0.0715371056326798, 0.018421927200896398, 0.02767790651081928, 0.04746406398979681, 0.0771690887798156, 0.09749565020735775, 0.08368572552821466, 0.15801619019891533, 0.10054266599139997, 0.05683443582217608, 0.10449701880237885, 0.9278318243367332, 1.4905920497008731, 5.956601628235408, 14.516352806772504, 30.84514147894723, 29.334259169442312, 43.04293687002999, 35.9079463822501, 72.54772567749023, 52.63128416878836, 28.39851920945304, 27.21397294316973, 19.313330922807964, 25.50547170639038, 12.38839750630515, 20.280381202697754, 25.323427166257584, 25.652438265936716, 40.0481173651559, 49.90196575437273, 52.742688110896516, 64.19397599356515, 54.1964110646929, 43.204892430986675, 25.16778404372079, 10.032063603401184, 5.761058475290026, 1.9065281535897936, 0.024884435514520322, 0.04951851196320994, 0.0918950153780835, 0.022280262217723897, 0.04478947911411524, 0.07857932882117373, 0.01038559592728104, 0.0444726168311068, 0.01773030324173825, 0.0490569113753736, 0.039857852671827586, 0.047135683574846814, 0.09956990461796522, 0.03761219013748424, 0.05694896235529866, 0.032465834503195116, 0.07998642724539552, 0.0640810439363122, 0.07798259798437357, 0.04198390644575868, 0.03492637550724404, 0.022038581614781703, 0.022717688299183334, 0.10113960717405591, 0.013450975413434207, 0.0606005596263068, 0.03546853516516941, 0.014235188020393252, 0.029662392434797118, 0.0032067420792632867, 0.03674636249031339, 0.05069551576993295, 0.04244337982631155, 0.02195772059660937, 0.042712707338588576, 0.06032158673873969, 0.05829257025782551, 0.031688063738069365, 0.04105101918269481, 0.018163921045405523, 0.02583620640715318, 0.07028282686535801, 0.045425883893455775, 0.039462202295128784, 0.03059810579621366, 0.008410996258524912, 0.012293459980615547, 0.09425537407930408, 0.045214167396937094, 0.043702469406915564, 0.030251140307102884, 0.0799220274867756, 0.038559916961405954, 0.03366302811939802, 0.027805501628401022, 0.04279865736940077, 0.024078617504398738, 0.01750581162715597, 0.04331554838323167, 0.08701208739408425, 0.04168432305700012, 0.019720963834385787, 0.055985961708107164, 0.04826860635408333, 0.043085548760635514, 0.04995489140440311, 0.03930402560425656, 0.022050101443060806, 0.041906241327524185, 0.03607351020244615, 0.01624379925695913, 0.03544081022430744, 0.0783124202862382, 0.03543561603873968, 0.08750993532261678, 0.019404177886566946, 0.05061630019918084, 0.020576991739549806, 0.06571862713566848, 0.02075382135808468, 0.05716156094734158, 0.03128022347976055, 0.009352507701675807, 0.020718339065622007, 0.022435790925685848, 0.06714534879262958, 0.02686564750703318, 0.3584646220718111, 6.19225195475987, 35.21654156276158, 62.69108758653913, 71.17444896697998, 66.75758334568569, 69.01986122131348, 60.14813722882952, 56.76680680683681, 50.993194239480154, 46.2885342325483, 39.58861562183925, 45.13937514168875, 30.59955392565046, 40.14742449351719, 16.698654311043875, 25.52522369793483, 25.49971686090742, 34.81562008176531, 55.06883730207171, 40.5045862197876, 38.871585845947266, 43.74714027132307, 41.004158224378315, 30.98871558053153, 35.39564527784075, 23.181288855416433, 14.291624614170619, 5.248437319483076, 2.6824154683521817, 0.6605719711099352, 0.33415235951542854, 0.12368613162211009, 0.07634078072650091, 0.03827437246218324, 0.07102549701396908, 0.01856508112645575, 0.061292875691183975, 0.01133372393503253, 0.05712588357606104, 0.03415081676627908, 0.03876187273168138, 0.015117867084752237, 0.13918657201741422, 0.06831312791577407, 0.10978183629257338, 0.041328343230166605, 0.03329430201223918, 0.011270405591598578, 0.11867394271705832, 0.06540270123098578, 0.04594566546646612, 0.12004968603806836, 0.10187524769987379, 0.06252798584422894, 0.08566725134317364, 0.09635837801865169, 0.1457649011697088, 0.08505909397665944, 0.05500556342303753, 0.053409197833389044, 0.5579899070518357, 1.0286283642053604, 4.8450110128947665, 10.80739050252097, 21.71699595451355, 26.37388709613255, 36.55372585569109, 34.088484151022776, 59.88899721418108, 51.3660797391619, 31.026131629943848, 27.136194808142527, 26.297377007348196, 29.389820439474924, 22.795028073447092, 30.479044369288854, 33.99844591958182, 34.29110057013375, 48.48628418786185, 58.264567443302695, 60.33886528015137, 74.04675783429826, 63.277390480041504, 53.361001355307444, 33.50782666887556, 14.549258606774465, 9.558446594646998, 2.92267136488642, 0.10175371529268366, 0.029896493801581006, 0.09365293676299707, 0.04947082112942423, 0.10449054557830095, 0.11811943032911845, 0.06466240595493998, 0.01792443041423602, 0.059985813684761524, 0.020399634560037936, 0.05597124428355268, 0.036768258815365176, 0.09399279459778752, 0.008524498203769326, 0.020245286503008435, 0.02583347021469048, 0.05283592055950846, 0.04538806574419141, 0.030424733313598802, 0.03319504590971129, 0.009365722171163984, 0.05539726811860289, 0.0390864770992526, 0.03843410639092326, 0.04420891098145928, 0.052198012825101614, 0.04031177224325282, 0.0816127128366913, 0.08780990886901106, 0.012110660950254117, 0.006981176665119294, 0.04381549298497183, 0.02666928286531142, 0.08231476587908608, 0.0044747056256580564, 0.01475911374602999, 0.026298468566632698, 0.0951748840244753, 0.012357217675474073, 0.02637379613172795, 0.04720280425889151, 0.035868402637009106, 0.02012369133132909, 0.02111407256286059, 0.04132156127265521, 0.010970971480544125, 0.1546790056994983, 0.13968929861273083, 0.14782641269266605, 0.14866042722548756, 0.10325792564877442, 0.18114063649305276, 0.15912064164876938, 0.2219405129019703, 0.120023657434753, 0.12554733960756234, 0.11995695744241987, 0.1299770197698048, 0.15049718080886773, 0.1812372055969068, 0.10375381939645324, 0.17666613230747835, 0.1945146567055157, 0.11338145778115306, 0.12223811075091362, 0.18836577236652374, 0.1528893695878131, 0.14935983398130961, 0.17672793327697686, 0.21535724401474, 0.051332690686519654, 0.10303666216454335, 0.1516204955322402, 0.09456093196890183, 0.15134127837206635, 0.1017864817487342, 0.13191528219197476, 0.3038680931287152, 0.10977404671055929, 0.20093381511313574, 0.22941676101514272, 0.14257008688790457, 0.07706992088684014, 0.18022613413631916, 0.11972858969654356, 0.1738546767405101, 0.08253051965896573, 0.6799646647913116, 9.912552850587026, 47.43936783926827, 72.53548989977155, 80.66609123774937, 74.02691377912248, 78.58329227992466, 69.25346660614014, 65.73210566384452, 55.94009971618652, 47.22362279891968, 47.61213479723249, 52.97991698128836, 28.061342239379883, 38.36275536673409, 21.315902505602153, 32.63291645050049, 43.467652457101, 56.661916800907676, 95.80025441305978, 65.36952086857387, 65.82544776371547, 71.99374580383301, 71.45853301456997, 47.80334922245571, 55.10597889763968, 33.27911628995623, 21.898971012660436, 8.456270354134695, 3.887089363166264, 0.9902188309601375, 0.5741118990949222, 0.33589871866362436, 0.21129644263003552, 0.09432248119264841, 0.17191237024962902, 0.137822974473238, 0.19246059549706324, 0.09908220078796148, 0.26449338453156607, 0.15066207838909967, 0.23315060351576122, 0.10442090752933707, 0.29311629863721983, 0.31970909024987904, 0.15386279592556612, 0.1067732527319874, 0.10358918644487858, 0.2217876118208681, 0.22266315269683087, 0.2345147846000535, 0.1653151913945164, 0.24783931246825627, 0.36065542165722164, 0.15768715499767236, 0.41322424369198935, 0.2525262523974691, 0.3139123927269663, 0.5283443321074758, 0.30563334269183023, 0.3832604358238833, 1.513591238430568, 2.153122761419841, 8.726333805492946, 19.46509173938206, 39.152029037475586, 39.89425645555769, 54.02797283445086, 48.494788782937185, 89.51899950844901, 63.075899669102256, 40.83690813609532, 39.29135084152222, 31.341308866228374, 39.22889348438808, 25.174619334084646, 31.62143244062151, 38.78734588623047, 40.49791594914028, 56.81974860600063, 66.7649484361921, 70.22552653721401, 82.88561684744698, 71.70923791612897, 60.877246447971885, 40.310905184064595, 19.277643237795147, 12.110272407531738, 3.7554926531655446, 0.24506548845342227, 0.12285379985613482, 0.28351475670933723, 0.11906175262161664, 0.12637010402977467, 0.17357391252049378, 0.16143546386488847, 0.12669558370751993, 0.20548682580036776, 0.12874361952500685, 0.15014713816344738, 0.20396248331027372, 0.19593236063207897, 0.08445869905075856, 0.1291156467050314, 0.07419473731092044, 0.21509610302746296, 0.09258054609277419, 0.08884657467050211, 0.13688105930175098, 0.16092319706720964, 0.1473441778549126, 0.1595283733414752, 0.16799088567495346, 0.16622543255133287, 0.1102369229442307, 0.1096460750060422, 0.15690154715308122, 0.13097876815923623, 0.10970134846866131, 0.18655728655202047, 0.09960803150066308, 0.17149454195584568, 0.18400030875844614, 0.1572080957038062, 0.12132725891258035, 0.11854815589530127, 0.14995556058628218, 0.16599834045129164, 0.09716873203537293, 0.1252066878868001, 0.1187623558299882, 0.1248560074184622, 0.12668894763503755, 0.13906572493059294, 0.11686813033052854], [0.019039129439209188, 0.04332479003018566, 0.044675352916653664, 0.04682134883478284, 0.02630629377173526, 0.031601055192628076, 0.04768848266186459, 0.13265066487448557, 0.05155250210581081, 0.08180993582521166, 0.0433442504145205, 0.014050540830274778, 0.051093608872698884, 0.07720309016960007, 0.028386400546878576, 0.1409964556140559, 0.04791433643549681, 0.04022928274103573, 0.023180951297815357, 0.015258537572143334, 0.08692214079201221, 0.04759154375642538, 0.017770413143028106, 0.03323623637801834, 0.054259381855704954, 0.0765328129221286, 0.09031628830624477, 0.044073851978672404, 0.03854605449097497, 0.027083827049604485, 0.030265057060335363, 0.06150470753865583, 0.1162400511758668, 0.054427041073462794, 0.03804870189300605, 0.02230619582613664, 0.016485108361978616, 0.038484379050454924, 0.03862956179572003, 0.11504895080413137, 2.7379398260797774, 11.319098404475621, 42.37893227168492, 56.5521456854684, 56.452338286808555, 56.883303778512136, 55.02617188862392, 39.50901011058262, 36.68600913456508, 35.68037550789969, 22.895035232816422, 13.105077266693115, 21.53234236580985, 23.01992389133998, 18.413883141108922, 33.461166041237966, 48.038125378744944, 51.12129817690168, 56.40062631879534, 40.35926464625767, 33.128034659794395, 28.691769668034144, 26.6814022064209, 21.070431334631785, 12.899234277861458, 14.38537231513432, 7.505617822919573, 4.172418441091265, 0.7436436020902225, 0.3637330122292042, 0.13256602441625936, 0.04035232149596725, 0.07110531308821269, 0.005412539833092264, 0.04965865319328649, 0.06675792565303189, 0.09136333569352116, 0.04502548037895134, 0.07843296203230109, 0.05439769782658134, 0.017658324246960025, 0.08123168828231947, 0.02876820880919695, 0.10076786497873919, 0.04822476959920355, 0.048777276916163306, 0.07843684325260775, 0.07656130460756165, 0.1724637070936816, 0.19307883589395455, 0.0824103443218129, 0.09628941171935626, 0.05836032876478774, 0.12036345420139176, 0.010014136172165828, 0.09856587635087115, 0.04229129637990679, 0.060399869323841164, 0.03636467975697347, 0.07162804968122925, 0.06054360339684146, 0.03064745564811996, 0.14409757778048515, 0.031932997916425974, 0.07046139692621571, 0.3367141549076353, 1.0685142810855592, 3.257625997066498, 7.8188521691731045, 21.600731747491018, 27.65442967414856, 39.70421974999564, 47.63242353711809, 42.90409796578543, 36.95539774213518, 23.179449319839478, 18.336415937968663, 26.42360666819981, 20.562516280582972, 22.00291085243225, 24.371183497565134, 28.896399327686854, 34.53228643962315, 43.60422624860491, 54.081592082977295, 59.222519057137625, 56.80087729862758, 52.472639424460276, 44.6356828553336, 27.9456182547978, 11.053068382399422, 0.6768294530255454, 0.02915749452742083, 0.03480332996696234, 0.04751524927892855, 0.033132983704230616, 0.02633161500229367, 0.07200696399169308, 0.019597368680738976, 0.035975919903389046, 0.023684851758714234, 0.016873108256342154, 0.022257899399846792, 0.017642027532149638, 0.05399984560374703, 0.007851399946957827, 0.017387425926114832, 0.04593668505549431, 0.08841156587004662, 0.0823454831593803, 0.04060295197580542, 0.06788624796484198, 0.06520832808954374, 0.024690635735169053, 0.06769588496536016, 0.026248116179236343, 0.04520434220986707, 0.062177759994353564, 0.04008549438523395, 0.04471701157412358, 0.01337716352593686, 0.0729568519496492, 0.033149780838617256, 0.02745750137338681, 0.04722408990242651, 0.03440999678735222, 0.025247176942814673, 0.04211779836831348, 0.0832618379167148, 0.028492672701499293, 0.029317489692143033, 0.04222031143893089, 0.028087507567501495, 0.045707825371729474, 0.03611647503982697, 0.06443489316318717, 0.03340385488367506, 0.024787248943799307, 0.027416621334850788, 0.05484273537461247, 0.046710014808923006, 0.0384372480080596, 0.014953427515657884, 0.10441688381667648, 0.0691955830635769, 0.05393808534634965, 0.045021524519792626, 0.05159496143460274, 0.01065431275804128, 0.06050895739878927, 0.0347502820992044, 0.09078998038811342, 0.01823950475747032, 0.009368323504791727, 0.04178894976420062, 0.014287781269688691, 0.06835623524550881, 0.031420150971306224, 0.05915377368884427, 0.04894619142370565, 0.06480706283556563, 0.05155014080394592, 0.019569938902610114, 0.045362953163151226, 0.043862159230879376, 0.07631750697536127, 0.014335553527676632, 0.05063612020707556, 0.08453369752636977, 0.027607043706146733, 0.05123488325625658, 0.01441526273265481, 0.009028054308146238, 0.020091533860457794, 0.04889242770150304, 0.09921828777130161, 3.1479647500174384, 17.16101176398141, 57.98276240485055, 65.61862073625836, 64.49563203539167, 64.43811484745571, 61.0574688230242, 47.19928673335484, 47.139643396650044, 47.71582623890468, 32.33642986842564, 19.672797713960918, 22.924539021083287, 27.316438027790614, 20.174530608313425, 39.26427371161324, 39.39076566696167, 39.47053793498448, 45.16560806546892, 34.74717685154506, 33.54025738579886, 24.186146020889282, 21.278548989977153, 15.920615877423968, 11.737006493977137, 12.138852953910828, 7.10908934048244, 3.6913269077028548, 1.00074893449034, 0.25191581515329226, 0.08995351634387459, 0.034258822577872446, 0.032903625297227075, 0.0454363163693675, 0.028373730601742864, 0.05106834022860442, 0.22335307353309222, 0.05161439807021192, 0.027524243774158613, 0.022720268428591744, 0.07129900090928588, 0.10102909417556864, 0.021033069052334343, 0.10744912789336272, 0.062449343635567596, 0.07478478457778692, 0.24785766005516052, 0.2677792582128729, 0.6682988022054944, 0.4338991514274052, 0.17108144983649254, 0.19566309079527855, 0.08350828862083809, 0.1676092775804656, 0.051946771663746664, 0.10633733469460692, 0.13070250941174372, 0.08480150172752993, 0.05846624808119876, 0.11742630680756909, 0.13539441621729306, 0.008761473166357194, 0.07293700480035373, 0.024582723222140754, 0.046480076254478524, 0.18856417600597652, 0.8902326247521809, 2.3948951022965566, 6.565009781292506, 13.09956647668566, 26.549497604370117, 32.1190242086138, 38.69905512673514, 45.697638579777305, 32.401364258357454, 28.70248031616211, 21.267390183040074, 25.981388568878174, 24.43466223989214, 28.30952320780073, 33.51130771636963, 39.32388925552368, 43.13442727497646, 50.7058549608503, 62.10454845428467, 68.86518737248012, 67.64985711233956, 63.76132556370327, 54.25909423828125, 37.15582200459072, 15.127619709287371, 1.8075611612626483, 0.1322394183703831, 0.04381569654547742, 0.033551524459783516, 0.028216003440320492, 0.06731194271040813, 0.09889121353626251, 0.018321634636127522, 0.036767743128751, 0.04188953579536506, 0.03896183021632688, 0.046457925478794744, 0.007391516052718673, 0.04244239255785942, 0.044809204127107344, 0.019259120670280287, 0.03856076852285436, 0.038457705838871856, 0.0293291028189872, 0.010814368990915162, 0.03620593988203576, 0.025362029172746197, 0.018368568903367435, 0.010379791908365275, 0.08134221485150711, 0.009443966588670654, 0.05725820469004767, 0.07253203474517379, 0.04500564340768116, 0.04640462655307991, 0.027852993990693773, 0.0052299816826624525, 0.022290720138698816, 0.03751487803778478, 0.020531412846009647, 0.08649494192962136, 0.039745796006172895, 0.03261880004512412, 0.03281482541933656, 0.09260776891772236, 0.02940221157457147, 0.014672380007271255, 0.001328377123822325, 0.024923681979998946, 0.04756245156750083, 0.11518112942576408, 0.1246715137468917, 0.12466191926172801, 0.10344340319612197, 0.1704402749559709, 0.14756657449262484, 0.09344014139579875, 0.28271891655666487, 0.24887999519705772, 0.25681472942233086, 0.19283877020435675, 0.1086195736591305, 0.17081125719206675, 0.1533036423580987, 0.18587393393473967, 0.2099000039909567, 0.11541263200342655, 0.099946742611272, 0.07771990315190383, 0.08311908771949154, 0.21176039773438657, 0.16076451486774854, 0.0768406642600894, 0.10107673411922795, 0.19457276644451277, 0.18163348361849785, 0.10526503223393645, 0.24075394123792648, 0.1909611416714532, 0.13265322973685606, 0.14065494893917016, 0.12328452031527247, 0.17170229580785545, 0.09690942987799644, 0.12244448039148535, 0.13630862001861843, 0.1355519313365221, 0.16671310923993587, 0.1566665569054229, 0.39284420013427734, 4.480035168784005, 24.002574614116124, 70.36836760384696, 75.42414787837437, 72.51666028159005, 72.46651513235909, 71.36622619628906, 54.73252364567348, 51.2619366645813, 49.34059994561331, 36.15480545588902, 25.83127100127084, 32.678309031895225, 31.709792682102748, 27.230617352894374, 44.994602475847515, 62.640956333705354, 68.046265738351, 73.0866835457938, 53.7070529120309, 43.67369086401803, 37.50513574055263, 33.55485555103847, 25.4432019506182, 17.464913811002457, 19.584081377301896, 10.769965767860413, 5.865619310310908, 1.4466350312743868, 0.6691426826374871, 0.24522087297269277, 0.1940821720553296, 0.1928851141461304, 0.15121939991201672, 0.21418515619422707, 0.25415888907653944, 0.3996149482471602, 0.2521071620285511, 0.24165696278214455, 0.23921401958380425, 0.2461831984775407, 0.1783251775694745, 0.1392102257481643, 0.2832641058734485, 0.15623232163488865, 0.16145558921354158, 0.28494714413370403, 0.2633225316447871, 1.0488940881831306, 0.5448364785739354, 0.29386200862271444, 0.5575256262506757, 0.13965602325541632, 0.27479216190321104, 0.17465339388166154, 0.20172219138060296, 0.25622027846319334, 0.170930611501847, 0.19915485914264405, 0.14710624276527337, 0.12471285010022776, 0.289189019373485, 0.21191990774657044, 0.3192610942891666, 0.12824096078319208, 0.6088809562580926, 1.5724691876343317, 4.798130648476737, 11.147745404924665, 28.73709797859192, 34.70964963095528, 48.47643859045846, 61.201852389744346, 59.96218258993966, 52.043810503823416, 39.06462069920131, 29.84757818494524, 36.748754841940745, 31.291615349905832, 33.17231900351388, 36.0991747038705, 43.351040840148926, 51.07226126534598, 59.69783837454659, 73.66468334197998, 77.59095750536237, 77.55444472176688, 72.79866681780133, 62.412249428885325, 44.37356206348964, 19.08069133758545, 3.048706476177488, 0.27024339884519577, 0.17131181247532368, 0.17116353900304862, 0.17834026818828924, 0.11711381429008075, 0.17562295256980828, 0.10269497907055275, 0.1125075521745852, 0.20733409667653696, 0.10177264641970396, 0.11764528362878732, 0.13569472224584647, 0.20677309749381884, 0.18931395720158303, 0.07668636539684874, 0.13416242732533387, 0.1576083635113069, 0.20042053051292896, 0.09405035472341947, 0.10711353804383959, 0.15013701442096913, 0.10666980328304426, 0.1028977796169264, 0.25708405354193276, 0.10365975408681802, 0.13483104216200964, 0.18499873232628616, 0.1969903324331556, 0.11913128889032773, 0.1971956028469971, 0.09805870535118238, 0.12945952825248241, 0.14643176538603647, 0.09889934238578592, 0.20248856954276562, 0.14295434126896517, 0.13720313273370266, 0.12025039669658456, 0.1526608932763338, 0.13379349426499434, 0.08046458408768688, 0.08450630506766693, 0.08797959012112447, 0.2090534908430917], [0.038625080071921856, 0.030892871586339812, 0.006006643043032714, 0.06380213890224695, 0.037992200282003195, 0.06970284227281809, 0.020055427315777967, 0.05192635454503553, 0.06369811269853796, 0.021750646975955794, 0.02957832194598658, 0.013095740278783654, 0.035084216323282034, 0.04257815723706569, 0.004980610733452652, 0.030907734895923307, 0.012322662431480629, 0.04774545246203031, 0.08808134323252098, 0.08677606577319757, 0.02990050394354122, 0.024429689826709882, 0.06896431118782077, 0.04366312116118414, 0.05441954326150673, 0.04256819634299193, 0.03315691902701344, 0.0029904774897399223, 0.01467603222200913, 0.04802615222121988, 0.03487750741520098, 0.03671658158834491, 0.04107767543090241, 0.03439076031957354, 0.055640193833304305, 0.046627175861171315, 0.019384022003837993, 0.12688604848725454, 0.2594413384795189, 4.34766069480351, 22.385244165148052, 48.297928946358816, 63.48658684321812, 59.80791868482317, 58.45289489201137, 53.179799284253804, 43.88924135480608, 35.43159178325108, 22.214137826647075, 15.321663788386754, 25.710368871688843, 33.98487956183297, 26.737510647092545, 18.948541811534337, 47.237477506910054, 72.02217783246721, 41.651469775608604, 46.68554040363857, 26.474599497658865, 20.98039310319083, 10.128355213574, 5.219239686216627, 2.184431344270706, 1.3833872079849243, 1.084867300731795, 0.2762540248887879, 0.20968959028167383, 0.04939920175820589, 0.04040923022798129, 0.044168324409318824, 0.023971196929258958, 0.049900483073932786, 0.08989073828394924, 0.030865682688142573, 0.0830385863248791, 0.051896224197532446, 0.1187441846621888, 0.10913659020193986, 0.04675622643636806, 0.056112091190048625, 0.03935886819713882, 0.008201250058066632, 0.08581078185566834, 0.07203930975603205, 0.057280487780060084, 0.07900915361408677, 0.08717468474060297, 0.1931250441287245, 0.25465720519423485, 0.06274949360106673, 0.13056145555206708, 0.12409270980528422, 0.12363950269562857, 0.07515894914312021, 0.11696953060371534, 0.0168860886312489, 0.05754104522722108, 0.028558344713279178, 0.038008980453014374, 0.2949364281126431, 0.29705874994397163, 0.012499962783684688, 0.036512915909822495, 0.0772168372890779, 0.12116530617432934, 0.055584859302533526, 0.02548931216421936, 0.15628876217773982, 0.47158362929310116, 1.4058222898415156, 2.5117249361106326, 8.490836773599897, 22.279975482395717, 24.261412382125854, 44.317952156066895, 40.76887832369123, 56.130341393607004, 40.616170815059114, 27.646331548690796, 19.462837048939296, 15.051820073808942, 18.248250246047974, 22.137738909040177, 34.40671859468733, 36.45140668324062, 42.23164783205305, 52.360023021698, 56.46066917691912, 62.28805037907192, 65.08585371289934, 47.84410735539028, 29.547554969787598, 10.769469840185982, 2.1588634933744157, 0.2984787066067968, 0.26937006999339375, 0.08236288079725844, 0.07172740756400994, 0.13214331067034177, 0.06434998807630368, 0.038423226081899235, 0.010703449719585478, 0.031081524677574635, 0.009522916682596718, 0.0833287143281528, 0.05215186905115843, 0.02432678490211921, 0.034988285042345524, 0.03995222332222121, 0.05897643177637032, 0.027107317931950092, 0.062230203965944905, 0.04334632673167756, 0.021161083165290098, 0.019866015961659805, 0.04272353336481111, 0.04984561673232487, 0.05005098892641919, 0.07936961177204337, 0.04342923353293112, 0.04461829151426043, 0.050140925350465944, 0.06189994740166834, 0.03427662055141159, 0.02639242191798985, 0.023507392798949565, 0.03750906638535006, 0.039967816056949754, 0.04567125572689942, 0.04760992866275566, 0.038354174965726476, 0.03866188381133335, 0.04788559369210686, 0.01756489336756723, 0.039197814517787526, 0.04171335078509791, 0.01474670334053891, 0.033875616533415656, 0.01583686314656266, 0.02900486146765096, 0.054144129290112426, 0.019135489893544997, 0.07115076136376176, 0.06386654544621706, 0.09598456629152809, 0.028890833657767092, 0.03496324031480721, 0.07486109262598412, 0.03486331585528595, 0.02168448981163757, 0.03435708123392292, 0.01152820564207754, 0.010269462114333041, 0.05854840510125671, 0.0211839260466929, 0.03655028961864965, 0.08852320523666483, 0.023403794072302322, 0.03360019577667117, 0.02102246694266796, 0.04380993917584419, 0.032556748017668724, 0.060747849222804816, 0.005257046748218792, 0.030947802388774495, 0.03698175307363272, 0.05901246877121074, 0.04738557445151465, 0.06557331207607474, 0.008697808770063733, 0.059708998538553715, 0.05760797592146056, 0.052604231384715865, 0.021169298528028384, 0.3368141438279833, 7.000502458640507, 29.70309386934553, 56.80572019304548, 71.08201013292584, 66.13961056300572, 65.99852739061627, 60.75868238721575, 53.308288846697124, 43.882359164101736, 31.36989722933088, 26.97573832103184, 31.26961040496826, 32.72297205243792, 30.62729808262416, 29.059985978262766, 48.07072980063302, 58.23411348887852, 40.17983783994402, 37.01323454720633, 23.065017700195312, 15.088473558425903, 7.061646171978541, 3.8142279471669878, 2.136738474879946, 1.3509631135634013, 0.8353255710431507, 0.27465197656835827, 0.2798270545899868, 0.062203469686210155, 0.08540737921638147, 0.07112144865095615, 0.2891468144953251, 0.17379917257598468, 0.15887626047645295, 0.05870822723954916, 0.12072094716131687, 0.3468093717736857, 0.3355123336826052, 0.18165565814290727, 0.31849535394992146, 0.05943976262850421, 0.07511156025741782, 0.12427864197109427, 0.14035954193345138, 0.021274500293657184, 0.05771577477987323, 0.0017838596582545765, 0.055349869054875205, 0.7122860561524118, 1.3451423687594277, 0.970776685646602, 0.6324781786118234, 0.6480700990983418, 0.5973239306892667, 0.5793071431773049, 0.5860187773193631, 0.4351513742336205, 0.6246157490781375, 0.4767812618187496, 0.23862309700676373, 0.6001854485699109, 0.6588192337325641, 0.15798421762883663, 0.3637991286814213, 0.19594470996941837, 0.3472336461501462, 0.08604766521602869, 0.0915640734934381, 0.05668131082451769, 0.13551511402641023, 0.9325387946196965, 1.575199938246182, 8.205443859100342, 15.533846139907837, 22.063658952713013, 35.52872065135411, 40.01232372011457, 43.85923555919102, 39.728958811078755, 29.31976522718157, 28.761963844299316, 21.903756584439957, 26.42561990874154, 31.795623779296875, 42.59259980065482, 46.04852260862078, 49.54603385925293, 63.635139329092844, 64.98086643218994, 70.68121719360352, 74.0195208958217, 58.68879318237305, 35.63128648485456, 15.165985924857003, 2.6461178617818013, 0.2740965006606919, 0.27189650014042854, 0.019602740981749127, 0.0237852749414742, 0.04183296972353544, 0.008010779341150607, 0.017326993901016455, 0.05395711825362273, 0.024208041273855736, 0.04082563699090055, 0.06696552344198738, 0.04124057133282934, 0.05800496640482119, 0.04106160432898572, 0.05962261424532958, 0.07171608281454869, 0.05888178971196924, 0.06980631886316196, 0.006537662852289421, 0.03977961079882724, 0.051496896161032576, 0.025794571498408914, 0.021240376767569354, 0.10414193464176995, 0.013030735775828362, 0.012573466785917324, 0.029260577567453896, 0.06498840131929942, 0.016530281830845133, 0.019685381458007863, 0.031149381572114568, 0.04045128922111221, 0.0495682791141527, 0.02427822215083454, 0.04034915952278035, 0.035506356707108874, 0.06366642511316709, 0.06536181271076202, 0.018339464840080057, 0.041788797093821425, 0.04165638777028237, 0.03385738429746457, 0.08577271604112216, 0.13080631169889653, 0.22218517905899457, 0.15386533364653587, 0.09915274807385036, 0.16662525252572127, 0.12139983501817499, 0.1647497545927763, 0.1884608758347375, 0.11149649428469793, 0.16287253318088396, 0.15461909105735167, 0.13953733390995435, 0.10475954400109393, 0.18263232787804945, 0.08363942908389227, 0.17857671050088747, 0.22567816876939364, 0.17338123571659836, 0.16103857516178063, 0.17970524994390352, 0.11176397957439933, 0.16344687236206873, 0.14151672912495478, 0.18424905969628266, 0.10486061179212161, 0.1535617435084922, 0.08929787509675537, 0.13308978559715406, 0.13795034906693868, 0.1310384656701769, 0.13851328885981015, 0.19406378375632422, 0.08594849053770304, 0.16333671898714133, 0.13952809226300034, 0.13397182683859551, 0.19731537784848893, 0.6188866879258836, 8.67652998651777, 35.29077959060669, 67.41611971173967, 81.15325028555733, 74.62507029942104, 75.7490039552961, 70.32316957201276, 58.83029324667794, 50.44959150041853, 35.12577029636928, 24.484451293945312, 37.56197895322527, 43.32922349657331, 37.45093284334455, 31.859554154532297, 61.25877203260149, 87.31797695159912, 53.574335370744976, 58.584396498543875, 33.01810373578753, 26.61969178063529, 13.43741568497249, 7.163889782769339, 3.2498544369425093, 2.0784821723188673, 1.7216293151889528, 0.6746623207415853, 0.5918522242988858, 0.17066662066749164, 0.16814028551535948, 0.24433299633009092, 0.33064791613391464, 0.2904994876257011, 0.24255930579134397, 0.1612424613641841, 0.11423094969774995, 0.2630660725491387, 0.4363322965800762, 0.26093878384147373, 0.28237788485629217, 0.12958382229719842, 0.19594010950199195, 0.20079197415283748, 0.2892702535859176, 0.24791446700692177, 0.3782236703804561, 0.2447279037109443, 0.23865824512072972, 0.4640927112528256, 0.8746548177940505, 0.5124391455735479, 0.46460666081735064, 0.3185418743108, 0.34560461927737507, 0.4069468176790646, 0.4326961902635438, 0.3113171048462391, 0.38285830883043154, 0.2772054938333375, 0.21556217516107218, 1.0269452716623033, 0.6946563050150871, 0.10753568182034151, 0.388765281864575, 0.337601081601211, 0.49446274446589605, 0.2208209301212004, 0.2111736142209598, 0.4985005706548691, 0.9060777745076588, 2.2628015960965837, 3.7828824520111084, 11.452640175819397, 28.286960669926234, 33.18370015280587, 57.934861523764475, 55.79011590140206, 72.9999839237758, 57.697827202933176, 43.53273970740182, 32.05476379394531, 24.858170577457972, 28.152448756354197, 34.03880453109741, 49.963717869349885, 52.62197010857718, 61.313364028930664, 71.54559394291469, 75.04951490674699, 79.40837001800537, 82.95302132197789, 70.19457231249127, 44.6499787739345, 19.739168643951416, 4.305089516299112, 0.6029673335807664, 0.394443154335022, 0.20393160996692522, 0.26086094230413437, 0.2690828596907002, 0.09324219237480845, 0.0986948726432664, 0.12653112038969994, 0.085187628865242, 0.12683891744485923, 0.1624639058219535, 0.11987815238535404, 0.12127875722944736, 0.17708819465977804, 0.13724987022578716, 0.12809754562165054, 0.1255084459802934, 0.15602543630770274, 0.14874128145830973, 0.1335116715303489, 0.24078330823353358, 0.17389722088617937, 0.11610970459878445, 0.1870703540210213, 0.10039458929428033, 0.11593844236007758, 0.19749810732901096, 0.13641206946756157, 0.11070517317524978, 0.0990380145875471, 0.1654920176203762, 0.08380474057048559, 0.16944915242493153, 0.13441439451915876, 0.1480123991412776, 0.09841792179005486, 0.10370630837444748, 0.11409118505460875, 0.1270995291748217, 0.11620111683649675, 0.18276857770979404, 0.20359538229448454], [0.031191528774797916, 0.03412868295397077, 0.03807919525674411, 0.07945738706205573, 0.04127553963501539, 0.05296142239655767, 0.026845717237197926, 0.016001175490341017, 0.019220917452392832, 0.016153642309031317, 0.0460849856691701, 0.05784897120403392, 0.07304600466574941, 0.05959949655724423, 0.01709599683194288, 0.06570667813399009, 0.03941572603902646, 0.006934045198639589, 0.08166001351284129, 0.014394377424780811, 0.08053437141435486, 0.01746988489425608, 0.04804373306355306, 0.06253655574151448, 0.04249104691137161, 0.0812153627297708, 0.06533566875649349, 0.11557062209716865, 0.025712148153356144, 0.039906042228851996, 0.019411026001242653, 0.0050254351808689535, 0.02663998881221882, 0.024063357251829336, 0.02682156308687159, 0.07508878862219197, 0.01698487824095147, 0.9628915659018925, 5.672603564602988, 33.21064874104091, 57.46824829918997, 59.04078892299107, 56.8592769077846, 54.28962809698922, 39.66808911732265, 40.462851864951, 32.5097005707877, 15.443688052041189, 15.838938065937587, 13.503420966012136, 11.94801025731223, 17.202918086733135, 17.37567809649876, 32.371205602373394, 40.871260029929026, 37.339105061122346, 21.201913833618164, 9.074396865708486, 4.187905541488102, 1.1981803689684187, 0.4782356066363198, 0.07960481236555747, 0.024158596427046826, 0.04003242616142545, 0.10652940760233573, 0.10313074104487896, 0.03863929198788745, 0.11677090983305659, 0.032827507238835096, 0.031176163349300623, 0.11463285955999579, 0.04842169403231569, 0.1587309047047581, 0.03891624962644918, 0.12010842002928257, 0.1498496819819723, 0.18128401094249316, 0.4971698277762958, 0.2742049034152712, 0.17672956176102161, 0.07877332876835551, 0.062000879485692294, 0.18284901125090464, 0.04598923759268863, 0.04752563765006406, 0.07945638283022813, 0.2684306246893746, 0.5746901737792152, 1.4004675086055483, 1.4501247640166963, 0.552319905587605, 0.27130069211125374, 0.45458787413580076, 0.433815311640501, 0.32190898220453945, 0.5323982802884919, 0.38433908937232836, 0.1993269356233733, 0.12533679019127572, 0.4011370651423931, 0.5449783195342336, 0.33538132214120453, 0.09536486704434667, 0.04720616300723382, 0.11485662683844566, 0.06038270238786936, 0.12102972130690302, 0.045005585732204575, 0.05118749437055417, 0.06143238927636828, 0.2623686471155712, 0.029274528247437308, 0.6612431236675808, 3.9588334219796315, 10.8272545337677, 20.0041503565652, 32.14730337687901, 37.24696847370693, 32.647934981754844, 33.7515868459429, 30.09683438709804, 20.52342745235988, 15.393136433192662, 20.546292236873082, 26.95060842377799, 32.551500933510916, 33.43063565662929, 38.92439215523856, 56.36196306773594, 53.673593861716135, 67.3921901157924, 59.463301931108745, 51.51143257958548, 25.556756360190256, 6.119643713746752, 2.18850667987551, 0.32168856688908165, 0.061149446958942075, 0.038137505163571665, 0.03889097758967962, 0.026627892229173864, 0.01366815242051546, 0.022530385492635623, 0.0648618545383215, 0.056023640757692714, 0.03087182343006134, 0.02527094602451793, 0.013612140202894807, 0.011187632801011205, 0.024143823023353304, 0.03703993405880673, 0.02842339257975774, 0.02689416124485433, 0.053517047581928115, 0.004615751427731344, 0.01915942521632782, 0.023655632344473685, 0.03453950537368655, 0.011859393495667194, 0.03425789637757199, 0.026167597821248428, 0.06075287038194282, 0.03520506001742823, 0.04487562592008284, 0.028060121894148842, 0.020677915341886025, 0.05085216575701322, 0.01616058372227209, 0.0185848112284605, 0.031051292549818754, 0.010761622223071754, 0.01566136345666434, 0.042676955328455994, 0.018378499263365353, 0.03242981447173016, 0.01244357313095991, 0.024674830958247185, 0.022282011141734462, 0.04537512268871069, 0.015212485400427665, 0.021004312738244022, 0.04061144044888871, 0.013445583604542273, 0.06747846877468483, 0.018638878595083952, 0.03765534157199519, 0.03729264424847705, 0.04614606060619865, 0.03501093114859291, 0.0686030862852931, 0.012476847640105655, 0.025870106016684855, 0.010251463972963393, 0.005825561978521624, 0.06932335799293858, 0.041819270101508925, 0.03859679873234459, 0.038127344101667404, 0.05576226567583425, 0.01882221027543502, 0.06460991448589734, 0.024700309948197434, 0.03669343675885882, 0.081383944755154, 0.07431297882327012, 0.009051000666139382, 0.0168836543868695, 0.02465159452653357, 0.052844415817941935, 0.056703230898295126, 0.016415587360305444, 0.08345427044800349, 0.03680730850568839, 0.9835277157170432, 10.518718906811305, 42.992194175720215, 66.36548955099923, 68.19153867449079, 64.41123921530587, 62.642269543239046, 48.417517866407124, 49.51700775963919, 39.488294056483674, 27.191271441323416, 24.029940094266617, 16.551486253738403, 22.843913861683436, 31.25535270145961, 28.307152135031565, 34.798423290252686, 36.534392493111746, 36.194076674325125, 16.77096768787929, 7.534748145512172, 3.527282327413559, 1.1822371844734465, 0.47709740485463825, 0.038165206355707984, 0.026354848041332195, 0.07326274232140609, 0.07792286654668194, 0.18226628537688935, 0.2574109174311161, 0.2786354385316372, 0.4251621173960822, 0.6273285863654954, 0.8643863573670387, 0.4441802868885653, 0.7477338111826352, 0.49852353227990015, 0.6216520166822842, 0.9560471560273851, 0.9938779260431017, 1.5068396521466119, 2.322818181344441, 0.5260302019970757, 0.17869666192148412, 0.018500009618167366, 0.2392435222864151, 0.23051965183445386, 0.17858851701021194, 0.17884448756064686, 0.834288878100259, 3.163752794265747, 4.008094412939889, 2.9640756802899495, 2.227009470973696, 1.8432437436921256, 2.371806238378797, 2.269706802708762, 2.52157552753176, 1.5053402526038033, 1.100932512964521, 0.7638134083577565, 1.1175655233008521, 1.5316861931766783, 3.868976277964456, 3.7965543355260576, 0.3214807723249708, 0.5457890331745148, 0.44413699635437554, 0.408243145261492, 0.24497980305126735, 0.12091074697673321, 0.08306590414472989, 0.024867629898445945, 0.08197420236787625, 0.04299275909683534, 0.6268723394189561, 3.3020349740982056, 8.750152230262756, 16.33157924243382, 30.976403372628347, 37.22913244792393, 36.40972791399275, 29.711383070264542, 26.311005898884364, 26.791652747562953, 24.44004535675049, 30.192066396985734, 35.41899469920567, 40.95700774874006, 42.66411413465227, 48.07707698004586, 63.40999685014997, 58.68007319314139, 75.47227805001395, 67.72129849025181, 59.57843358176095, 30.17639126096453, 8.06921226637704, 2.321293268884931, 0.344317546912602, 0.06003751805318253, 0.04421678538035069, 0.00636579205248771, 0.07749954890459776, 0.02556706888468138, 0.007385946976553116, 0.06686541917068617, 0.005128632299602032, 0.033663289355380197, 0.05203222297132015, 0.04420269560068846, 0.03302910677822573, 0.07744523896170513, 0.024894890042820146, 0.013158751585121666, 0.023247118640158857, 0.046726662665605545, 0.012599133221166474, 0.03606804460287094, 0.005542771059221455, 0.010253568279689975, 0.06314401421695948, 0.040743809060326645, 0.05637123728437083, 0.02939016079264028, 0.009277057152108421, 0.08525996069822993, 0.05257231988278883, 0.018527341008718525, 0.04370105126872659, 0.008485149958037903, 0.04545725935271808, 0.02879229001700878, 0.051044055460286994, 0.023012150444888642, 0.044172911306044886, 0.04329895820202572, 0.049677764132086716, 0.06508615107408591, 0.20593635525022233, 0.1141143502401454, 0.14769401693982737, 0.10456770858062164, 0.12046252031411443, 0.14292527282876627, 0.15340451337397099, 0.0871487647028906, 0.09065406303852797, 0.11244410915034157, 0.16656129381486348, 0.15791153295763902, 0.09553295373916626, 0.149490764098508, 0.10492973415447132, 0.12459261369492326, 0.06993350346705743, 0.06978979653545789, 0.22039654717913695, 0.16541018629712717, 0.17399152368307114, 0.13938099944165774, 0.13665586709976196, 0.09680073535335915, 0.18327407272798674, 0.2473659392978464, 0.11512148619762488, 0.14754825404712132, 0.12380174041858741, 0.13771614591990197, 0.13561416656843253, 0.1009917611788426, 0.1567162528101887, 0.10749685604657445, 0.11132517776318959, 0.17742818141622202, 0.2156547409083162, 1.8749607503414154, 15.06424171583993, 51.34489120755877, 76.69976765768868, 75.7433203288487, 70.5346588407244, 71.44660990578788, 55.783379622868125, 55.01132706233433, 45.15799631391253, 26.388429675783428, 24.883970975875854, 20.064439875738962, 18.80786337171282, 26.8209376675742, 27.945734637124197, 43.53259032113211, 52.993427753448486, 46.9522886957441, 27.586328642708914, 11.663452863693237, 5.329310008457728, 1.9300638735294342, 0.8401992438094956, 0.22238363698124886, 0.1221339963376522, 0.12573840149811336, 0.17693829270345823, 0.24776679064546311, 0.3808407799473831, 0.3199806942471436, 0.43495831745011465, 0.4673886001110077, 0.6878283971122333, 0.28385931679180687, 0.44677858746477533, 0.41125793063214844, 0.42356644730482784, 0.6667963085430009, 0.494396085185664, 1.8840722271374293, 1.768574059009552, 0.3307514877191612, 0.25093017518520355, 0.19030843169561454, 0.6796623095870018, 0.5246289457593645, 0.41115889166082653, 0.3828698710671493, 1.3782628029584885, 4.708473265171051, 5.534584982054574, 3.4720897461686815, 1.5820843002625873, 1.3796926119497843, 1.4089564702340533, 1.5530834964343478, 0.8132406675389835, 0.7166902369686535, 0.7697728457195419, 0.32255242339202334, 0.8636477312871388, 0.9459036546094077, 2.1543949331556047, 2.5209975242614746, 0.18622947271381105, 0.2733954111380236, 0.4895153556551252, 0.4420183928949492, 0.3249818773141929, 0.13609009103051253, 0.13642705152077333, 0.12669219103242668, 0.6082897079842431, 0.18823690499578202, 1.248329535126686, 5.855461478233337, 14.39935382774898, 26.44970236505781, 42.3685690334865, 51.38297775813511, 48.03841025488717, 47.66395793642317, 43.424347809382844, 28.967064244406565, 23.980540139334543, 30.654687881469727, 38.63551385062081, 50.16202640533447, 49.25287546430315, 55.6463611466544, 71.70673656463623, 69.55858979906354, 84.07986627306256, 76.9122713633946, 67.86930206843785, 39.76336281640189, 13.450770122664315, 4.601250401565006, 0.5656326540878841, 0.180189669664417, 0.2875322268477508, 0.11554823044155325, 0.17592221365443297, 0.14138961237456116, 0.1314568096505744, 0.15670542339129107, 0.07678927201777697, 0.10914298200181552, 0.12109980040362903, 0.13733023591339588, 0.09064690449408122, 0.19128210230597428, 0.08901989287031548, 0.14581888541579247, 0.09473460979227509, 0.13520799550626958, 0.0951252831146121, 0.08933018014899322, 0.09870365288640771, 0.1432741212525538, 0.11920480137424809, 0.15910162909754685, 0.10884316451847553, 0.13296608866325446, 0.15916714843894753, 0.29051750951579636, 0.13832320405968598, 0.10948961161609207, 0.129295268495168, 0.10557318212730543, 0.1361917627177068, 0.07056049696568932, 0.24204467769180024, 0.11766060494950839, 0.13958754550133431, 0.13355673982628755, 0.13492514139839581, 0.16852140506463392], [0.012421053401859743, 0.014333930132644517, 0.027655889745801687, 0.019970941224268506, 0.06925078867269413, 0.02649033282484327, 0.02911193429359368, 0.021232534599091326, 0.04883844684809446, 0.0358077619623925, 0.00272146486011999, 0.08820041934294359, 0.03443809492247445, 0.06614036379115922, 0.007624362129718065, 0.011337025856067027, 0.03646209363692573, 0.06827018343444381, 0.01880399669919695, 0.05793975918952908, 0.08977840681161199, 0.062448237623487196, 0.051156960294715, 0.07445043644734792, 0.011057108108486449, 0.05645857831197126, 0.00912382613335337, 0.013491142990200647, 0.02143960482706981, 0.08065817691385746, 0.011745698167942464, 0.04770475732428687, 0.05661390854844025, 0.024826856729175364, 0.052694099955260754, 0.10658153944781848, 1.5512543831552779, 11.214392525809151, 41.849747044699534, 56.585135732378276, 56.94552142279488, 55.90722778865269, 57.458979402269634, 43.81787988117763, 42.651697703770225, 24.18933524404253, 19.13567590713501, 15.040386813027517, 17.13123525891985, 29.99944496154785, 23.758143935884746, 32.44730922154018, 36.28808232716152, 33.19670718056815, 28.33164974621364, 5.863025460924421, 3.46432535137449, 0.6457959211298397, 0.013553951584201838, 0.10998298121350152, 0.0334861170766609, 0.08150039493505444, 0.1443852223455906, 0.09643721700246845, 0.14452943817845412, 0.04360161196174366, 0.055437250794576745, 0.09635038487613201, 0.47606999427080154, 0.04856303966205035, 0.7825782128742763, 0.37600602794970783, 0.5452751378927911, 0.21039118192025594, 0.7800533569284848, 1.0585309139319827, 1.1173133254051208, 0.6149580787335123, 0.9333315406526838, 0.5934431446450097, 0.09738238235669476, 0.04284872646842684, 0.14791333302855492, 0.062266756647399495, 0.12734605451779707, 0.04678068423111524, 0.41075510904192924, 2.6315474893365587, 1.936959092106138, 1.7042062729597092, 1.9241744066987718, 3.251427335398538, 3.7973989759172713, 1.6957666001149585, 4.162227605070386, 1.2711937768118722, 2.1192609327180043, 1.855083474091121, 1.0498035422393253, 1.0753869180168425, 3.251436237777982, 4.070174830300467, 0.5736762253301484, 0.3369377457669803, 0.22489763636674198, 0.20283504309398787, 0.18856777224157537, 0.14927121730787413, 0.19992427714169025, 0.13646376026528223, 0.11580882860081536, 0.19676504523626395, 0.029528035715754544, 0.026420599780976772, 0.5973678997584752, 2.3386529088020325, 6.927152931690216, 20.912886142730713, 31.104152951921733, 50.16675812857491, 48.33504274913243, 33.88590942110334, 22.914801120758057, 18.364142724445887, 15.865261316299438, 20.407251834869385, 26.551806143351964, 31.036342007773264, 35.76856551851545, 44.2143406186785, 52.72701644897461, 56.03187499727522, 61.49777616773333, 52.24185848236084, 32.39365175792149, 17.91037150791713, 4.502260284764426, 0.6020263412169048, 0.10707656467067343, 0.07487699070147105, 0.055041400250047445, 0.019617538134168302, 0.061867554139878066, 0.06216525459395988, 0.04430437068055783, 0.05171680257522634, 0.054818854334631135, 0.023827091358335953, 0.07540316068168197, 0.08290674697075572, 0.022740213965464915, 0.06931059474923781, 0.041429828320230754, 0.061738808905439715, 0.030895019149673835, 0.04771782930142113, 0.015495163089196597, 0.014357259862923195, 0.014992760494351387, 0.05480283412284084, 0.0431909320343818, 0.02382380555250815, 0.027259114697309475, 0.046017060921128304, 0.024127090349793434, 0.03029561827757529, 0.04636379910100784, 0.02553995292899864, 0.03237337053620389, 0.031612054245280366, 0.022869948164692948, 0.05810481283281531, 0.08182109094091825, 0.04001390554809144, 0.02651277367424752, 0.039567867160907814, 0.021492330390693884, 0.033391580185187716, 0.022322636729638492, 0.02640467626042664, 0.01866010486680482, 0.007626205200462469, 0.02539404754393867, 0.03308844127293144, 0.008967231277243366, 0.02984190226665565, 0.038047148047813346, 0.06015604455024004, 0.034963718681995354, 0.05470594950020313, 0.04804709520457046, 0.03765524996976767, 0.04440599147762571, 0.043949425619627745, 0.02961683559364506, 0.09834606493157999, 0.07816169051719563, 0.09050201012619905, 0.046722113088305504, 0.044364682265690396, 0.02901180288089173, 0.09762810024299792, 0.025051260134205222, 0.038953619942601235, 0.02994617274297135, 0.04407528029488666, 0.03948597816218223, 0.04304954908522112, 0.055526281374373605, 0.016543769410678318, 0.03446296662358301, 0.0833858876888241, 2.2277733385562897, 15.657128027507238, 54.37904446465628, 67.73861340114048, 65.70141547066825, 64.90665967123849, 64.89680017743791, 52.3106803894043, 51.335980142865864, 36.072736808231895, 30.21773304258074, 21.41824425969805, 20.824142013277324, 28.160800491060527, 19.43501819883074, 25.65392518043518, 29.82830388205392, 28.06758345876421, 19.836740459714616, 6.202882264341627, 2.7439563146659305, 0.4965546950697899, 0.07387007866054773, 0.04137666170884456, 0.027384412973853092, 0.030190927109548023, 0.3093154808240277, 0.1885040035205228, 0.3854072391986847, 0.5266012027859688, 0.5110633479697364, 0.876201009111745, 1.6008221805095673, 1.6523750999144144, 4.046627385275705, 2.549438021012715, 3.0825242272445132, 2.2924033105373383, 3.2212749762194495, 3.0418694487639835, 5.273642344134195, 3.9806429488318305, 4.701433002948761, 3.479158018316541, 0.6416878529957363, 0.10226265048342091, 0.20284154345946653, 0.13231270015239716, 0.291805803243603, 0.2296648605593613, 1.477294174688203, 2.3317461822714125, 4.937045548643384, 6.302865105015891, 3.559292026928493, 6.635058913912092, 6.471091415200915, 5.068811620984759, 8.435060977935791, 4.256263656275613, 7.29644056728908, 4.8818173578807285, 5.236634935651507, 2.2630480400153568, 5.5669640217508585, 3.91586663041796, 1.7239360085555484, 1.8751018856252943, 0.8989642847861562, 0.8960292137094906, 0.49893027331147877, 0.6776909210852214, 0.7791087276169232, 0.48543958578790936, 0.1337089759430715, 0.2793946649347033, 0.10433396005204745, 0.044426656261618645, 0.15675970619278295, 1.9120382922036308, 4.642124916825976, 17.548153230122157, 26.085387468338013, 40.31448698043823, 44.414938586098806, 29.574812752859934, 20.1016457421439, 23.71500083378383, 20.391210181372507, 29.62434298651559, 36.44785267966134, 43.5252981867109, 46.64894424165998, 51.395765917641775, 61.03356007167271, 62.69622925349644, 69.1942332131522, 60.43486854008266, 38.34793833323887, 20.87000012397766, 5.383800387382507, 0.5837646297046116, 0.11041095360581364, 0.039437004897211275, 0.03910495700048549, 0.030616843540753638, 0.02592989512985306, 0.12459238299301692, 0.020025059481018355, 0.05426029787798013, 0.02481473470106721, 0.05855512259794133, 0.04984604760206171, 0.022425752000084946, 0.03783542476594448, 0.054250778031668494, 0.03027496367160763, 0.05101270374975034, 0.07555909481431757, 0.03374515799805522, 0.04281337479395526, 0.011342327759068991, 0.03490613820031285, 0.027054884138384035, 0.05955382436513901, 0.020518239088622586, 0.015512082359886594, 0.03587704717314669, 0.03395858779549599, 0.10555314498820476, 0.023766119897897755, 0.061701523406164985, 0.008479811583778687, 0.05301423616973417, 0.01935611555485853, 0.05394995292382581, 0.054759136467639885, 0.05123456773747291, 0.03577454088787947, 0.035327552551669736, 0.1477009922798191, 0.12811767097030366, 0.11159997087504182, 0.18888928927481174, 0.1185509514595781, 0.1447187087365559, 0.154856374753373, 0.10182173164295298, 0.12217344636363642, 0.10113952574985367, 0.12079060556633131, 0.13690693862736225, 0.1451564859598875, 0.1904887727328709, 0.15614321641623974, 0.10312499385327101, 0.1274129037878343, 0.16509963438979217, 0.0680434238165617, 0.1797099725476333, 0.1630325045968805, 0.20219799370637961, 0.17549282312393188, 0.1923029718122312, 0.09773667941668204, 0.1988292166164943, 0.12587515344577177, 0.21935408668858664, 0.06532376046691622, 0.0970763291365334, 0.11537383337106023, 0.15744208171963692, 0.07683650484042508, 0.1413123408066375, 0.14967645199171134, 0.30314507335424423, 3.069020620414189, 19.901787757873535, 63.55503354753767, 76.30194854736328, 71.73661381857735, 72.70228140694755, 72.62269674028668, 57.73838036400931, 55.69479009083339, 38.55638081686837, 31.360885415758403, 23.536838599613734, 25.243964093072073, 41.8526930809021, 32.62157351630074, 43.83224875586373, 49.50004720687866, 44.94291830062866, 35.958543164389475, 7.867421814373561, 4.7379622885159085, 0.8133430991853986, 0.18951126161430562, 0.29789467794554575, 0.11204424846385207, 0.16681338314499172, 0.3969880949173655, 0.35786447141851696, 0.4227247381848948, 0.3284089405621801, 0.28887132927775383, 0.3453025354870728, 0.9399604478052684, 1.1506304804767882, 3.9998564549854825, 2.2186770609446933, 3.2189853276525224, 1.9389873147010803, 2.455093643495015, 3.2578353115490506, 6.806892207690647, 3.5725665603365218, 5.103616450514112, 3.400323757103511, 0.4933517926505634, 0.2279277023460184, 0.6825036342654909, 0.42104552686214447, 0.6763083924140249, 0.6792122508798326, 2.078670425074441, 7.7973735502788, 9.903822439057485, 9.36872603212084, 7.085848918982914, 8.160964965820312, 10.030340450150625, 8.011562194143023, 8.448727216039385, 5.3376283049583435, 8.691234111785889, 6.7151833687509805, 4.450800623212542, 5.6220979775701245, 9.0848981993539, 14.89546823501587, 1.6098447420767374, 1.747351003544671, 0.6852455671344484, 0.7658373968941825, 0.3510778455861977, 0.685282153742654, 0.751789930675711, 0.877213111945561, 0.21726930141448975, 0.5372990944555828, 0.18523626029491425, 0.1155612583139113, 1.1187833036695207, 3.763586435999189, 9.19175454548427, 27.62805952344622, 41.341847624097554, 64.4992242540632, 65.35814666748047, 47.7275686945234, 35.25342607498169, 27.842800549098424, 23.32654094696045, 32.27675526482718, 39.388326849256245, 45.163825852530344, 52.42615597588675, 61.861250332423616, 70.59357261657715, 73.5912756238665, 80.54030105045864, 68.68924508775983, 51.414373193468364, 28.500190462384904, 8.620011602129255, 1.1079584445272173, 0.21606005701635564, 0.127216155773827, 0.13361446958567413, 0.16566874885133334, 0.19572875941438334, 0.17119581012853555, 0.1341917264674391, 0.16224560753575393, 0.1323416328855923, 0.1637416144034692, 0.1860548856535128, 0.21342906462294714, 0.07073000179869787, 0.135915856808424, 0.09662634506821632, 0.17412001107420239, 0.14776451672826493, 0.07457252525325332, 0.1482254998492343, 0.08737511719976153, 0.11486708984843322, 0.1747283177184207, 0.17762878350913525, 0.12353215845567839, 0.12171464812542711, 0.12215997065816607, 0.08889137833778347, 0.12851784378290176, 0.08779388187187058, 0.24935450830629893, 0.10719331340598208, 0.13209185057452746, 0.0938258749832, 0.13418186056826795, 0.1773386419351612, 0.10926908773503133, 0.10397112702152558, 0.17599169564034256], [0.02641778894966202, 0.06200396003467696, 0.0205854293225067, 0.03314973673384104, 0.009500555561057158, 0.013167709095536597, 0.012390628739792322, 0.05353554444653647, 0.041042866584445746, 0.029716139193624258, 0.013083954973678504, 0.09214140501405511, 0.07021143819604601, 0.029457956619028534, 0.03057225021932806, 0.025829241245186756, 0.08716817758977413, 0.03390219135742102, 0.03612695840586509, 0.0361141510573881, 0.046518712038440366, 0.07222112999962908, 0.05408542583297406, 0.015257015957364013, 0.05009776373792972, 0.07054568454623222, 0.024361498753673265, 0.021269653857286488, 0.043473185638764074, 0.01988373590367181, 0.0305120370217732, 0.040379272906907966, 0.013256468261325998, 0.04153458394908479, 0.08135626052639314, 1.3385118331227983, 16.828087091445923, 40.811609745025635, 59.07787145887102, 64.66580036708287, 55.87249721799578, 41.37060969216483, 33.45215422766549, 35.880355085645405, 24.930023636136735, 19.812487772532872, 13.828045146805898, 18.45861738068717, 27.14145633152553, 31.168100697653635, 59.21605723244803, 59.37938853672573, 28.786520515169414, 10.777135440281459, 2.0469844681876044, 0.2578004508146218, 0.05077502989609327, 0.02759659935587219, 0.05008741947157042, 0.10076377341257674, 0.07229220654283251, 0.04083305337865438, 0.09045924206397363, 0.08812543443803277, 0.2125365739422185, 0.943617154444967, 1.4917772603886468, 1.676760888525418, 1.8040037921496799, 1.8331903517246246, 2.730200184243066, 2.566603328500475, 3.9218967982700894, 1.7034397998026438, 1.8243077312197005, 2.5504965356418063, 4.078479664666312, 1.6318225456135613, 3.843883727278028, 2.5454191395214627, 0.7051897740789822, 0.29186803847551346, 0.06723747349211148, 0.1396067344716617, 0.16587935255042144, 0.17687491753271647, 0.9213528462818691, 0.35934848178710255, 4.117285788059235, 3.400910879884447, 4.905069504465375, 4.603716577802386, 5.674890390464237, 4.034961359841483, 18.73318760735648, 6.052653091294425, 3.9097244228635515, 3.363113113812038, 3.7528809990201677, 2.154875010251999, 9.330498780523028, 4.679200070244925, 1.5756799067769731, 2.1638225529875075, 0.966549466763224, 0.4122732090098517, 0.522548720240593, 0.4202310134257589, 0.20304604034338677, 0.10027196444571018, 0.1406213343143463, 0.023088955519987003, 0.07546608123396124, 0.06135125684418848, 0.051628559096051116, 0.012198866261834545, 0.4006395904081208, 1.4589399652821677, 7.882786887032645, 18.668128149850027, 26.89177107810974, 55.19832393101284, 62.99033955165318, 30.648990358625138, 25.772054978779384, 29.892585141318186, 16.95873406955174, 12.248855965478079, 14.341457962989807, 20.59908812386649, 37.91952977861677, 48.527844837733674, 58.923836844308035, 57.30891568320138, 50.921231746673584, 38.58660895483834, 26.35155211176191, 10.85377493926457, 1.3594398072787692, 0.07239921151527337, 0.06599095716540303, 0.05422246276534029, 0.015790042533938373, 0.03860823204740882, 0.0548500465894384, 0.03422212401138885, 0.07097115314432553, 0.011765230646623033, 0.061233836359211376, 0.029428531947944845, 0.04289091099053621, 0.019648406388504163, 0.03363428876868316, 0.02160309105446296, 0.020786338452515856, 0.06563906890473195, 0.032476361974009445, 0.041277792371277294, 0.014442063169553876, 0.07230022004140274, 0.056182747041540484, 0.009168712921174509, 0.004201779333275876, 0.0422789911473436, 0.06210935687912362, 0.04922907267298017, 0.05907587108335324, 0.07474374677985907, 0.07288582968924727, 0.07166865321674518, 0.061232899980885644, 0.021134510037622282, 0.058034855872392654, 0.04325101970295821, 0.04271621536463499, 0.05574173999152013, 0.00863458966237626, 0.12763546327395098, 0.01324955907849861, 0.038148504216223955, 0.03175889600866607, 0.09479075177971806, 0.025933598234717335, 0.04299661996109145, 0.06604038844151155, 0.011252724665350147, 0.04644326912239194, 0.06518178379961423, 0.010418014634134514, 0.029524670182062045, 0.01314145403115877, 0.016006995624463474, 0.0341326320277793, 0.05770415147500379, 0.014094654936343431, 0.05670877792207258, 0.03468055584068809, 0.0588530944660306, 0.04236151796898671, 0.028957682927804332, 0.03824290879336851, 0.04414522707728403, 0.017567777141396488, 0.04719072633555957, 0.0710037024691701, 0.0034069873051651356, 0.03591879064749394, 0.06687314768454858, 0.05260130689878549, 0.10514320805668831, 0.07562490592577628, 1.929905584880284, 24.20916713987078, 53.16697290965489, 71.08332334245954, 70.69639205932617, 64.19021701812744, 49.575219767434255, 44.40051759992327, 43.652603081294465, 36.78976311002459, 28.940890380314418, 22.186754976000103, 21.238150426319667, 24.112965856279644, 32.90487241744995, 43.58414248057774, 47.882913044520784, 24.21874349457877, 8.62283604485648, 1.5519265128033501, 0.25201270995395525, 0.03820570811097111, 0.021054956895698394, 0.1744312279458557, 0.2741398183362824, 0.26451669899480684, 0.3563015338565622, 0.324812650680542, 0.6293068687830652, 1.0951998148645674, 2.497311983789716, 3.4841283687523434, 3.7886472855295454, 4.605887455599649, 4.921002592359271, 6.95577950988497, 8.36402520111629, 5.833961146218436, 5.272646580423627, 4.366300106048584, 7.335724813597543, 8.133958186422076, 7.019975219454084, 8.280553017343793, 6.627982173647199, 3.125577219894954, 0.916597130043166, 0.1803186863128628, 0.2484328949025699, 0.5631779315216201, 0.18334017560950347, 0.721809865108558, 1.0136569504226958, 0.7505088565605027, 3.550327765090125, 5.577502267701285, 5.40927335194179, 7.303407004901341, 6.560395308903285, 11.797817996570043, 6.789566874504089, 6.609013591493879, 6.429969370365143, 6.140338488987513, 7.882078170776367, 5.621610300881522, 7.029868151460375, 6.032932366643633, 4.0741622277668545, 2.670602227960314, 1.7263777575322559, 2.757633626461029, 1.6981803391660963, 0.7778666285531861, 0.4389445478362696, 0.9109453133174351, 0.23248409213764326, 0.4946957805327007, 0.23569196143320628, 0.0579985881756459, 0.05934773292392492, 0.2910080903342792, 1.0050683255706514, 6.408240616321564, 16.07383234160287, 27.968338864190237, 42.10537127086094, 51.09856367111206, 25.212217773709977, 19.471777643476212, 29.198883942195348, 21.43785902432033, 22.580196721213206, 23.73512281690325, 31.085615158081055, 44.826341424669536, 55.83796467099871, 67.0414103099278, 63.166316577366416, 59.8000602722168, 46.45760127476284, 30.35547760554722, 12.869606290544782, 1.609381384083203, 0.04662220898483481, 0.022786296671256423, 0.08592913193362099, 0.019823164778894613, 0.04908422580254929, 0.03148136840068868, 0.03409556705238564, 0.042170466256460974, 0.053376852069050074, 0.04693089831354363, 0.03155923707942877, 0.024133175112573162, 0.03773028915748, 0.05070480491433825, 0.0643047501466104, 0.04970970956076469, 0.038196191657334566, 0.08113019301423005, 0.05676478759518691, 0.019649480170171176, 0.12250153161585331, 0.012392085045576096, 0.029682273510843515, 0.007999713283165224, 0.01068543631117791, 0.03980901850653546, 0.0068661514087580144, 0.06042724821184363, 0.021213925776204894, 0.021681560236694555, 0.09663009058151927, 0.006876161920705012, 0.028054060880094767, 0.07652705894517046, 0.013369759012545859, 0.03266934072598815, 0.05893917341849633, 0.15416451330695832, 0.1828663003231798, 0.13849989457854203, 0.13745653842176708, 0.11604483665100165, 0.21840402909687587, 0.08307535613753966, 0.11434927263430186, 0.1747553234121629, 0.10278362967073917, 0.16589328965970448, 0.12387677282094955, 0.1584660724869796, 0.1123358556734664, 0.14081901870667934, 0.07066708124641861, 0.1486413875328643, 0.09140450919845275, 0.20378991828433105, 0.17481134326330253, 0.17226478776761464, 0.17792590042310102, 0.19133272101836546, 0.07700069674423762, 0.2459417214351041, 0.18621934897133283, 0.1695558045591627, 0.16788903756865434, 0.17691234552434512, 0.08242092268275363, 0.08534782419779471, 0.16674063062029226, 0.17681025314543927, 0.16845532932451793, 0.15407500096729823, 2.644251836197717, 28.050171273095266, 60.838781220572336, 81.24495261056083, 79.67238071986607, 73.64487402779716, 57.71218565532139, 48.74271787915911, 48.464699608939036, 35.268402917044504, 29.810877799987793, 22.47568539210728, 26.780961206981114, 39.819709232875276, 42.9301815032959, 75.14531666891915, 74.54959896632603, 36.06618465696062, 13.665123786245074, 2.98965699332101, 0.5099698752164841, 0.22520183718630246, 0.25461662880011965, 0.3097185849079064, 0.3483140096068382, 0.20023663395217486, 0.2822809900556292, 0.2193211777401822, 0.3213554061949253, 0.7229221739939281, 3.1903201001031056, 4.05482235125133, 5.890665829181671, 5.961700737476349, 7.831550870622907, 9.068633334977285, 11.404563852718898, 11.878123538834707, 7.037685743400028, 6.751203264508929, 10.033946565219335, 12.00071234362466, 11.647411210196358, 13.947480337960378, 13.740384936332703, 7.308014529091971, 1.8548984783036369, 0.3641471357217857, 0.4822237640619278, 0.7428143780146326, 1.1048891863652637, 4.712397260325296, 9.044338958603994, 12.267186181885855, 10.96617681639535, 18.16562921660287, 13.396907687187195, 14.363315258707319, 14.185391868863787, 33.91348682131086, 18.17194512912205, 12.393161364964076, 14.240988748414175, 9.960548400878906, 9.874541861670357, 22.24811451775687, 16.61031665120806, 7.9596235411507745, 5.088126310280391, 3.6087864339351654, 2.791086814233235, 3.2975581628935675, 1.311927156788962, 0.34694757578628405, 0.22851857064025743, 0.5429359834109033, 0.160385539489133, 0.3641924075782299, 0.3163789489439556, 0.1877080819436482, 0.15888998045453004, 0.8404903624738965, 2.2568771711417606, 10.415841272899083, 23.82104250362941, 36.979608740125386, 69.682142666408, 80.41664396013532, 41.74184499468122, 37.11780841009957, 42.06158719744001, 29.048333849225724, 21.13802514757429, 24.5883755002703, 33.61460658482143, 52.77914530890328, 65.93669537135533, 74.82213510785783, 72.81814956665039, 68.0873921258109, 57.63361542565482, 38.84103809084211, 19.615066868918284, 3.009009680577687, 0.16832412779331207, 0.11665821873715945, 0.20072967106742517, 0.12425406543271882, 0.11455241244818483, 0.15780778495328768, 0.13662765361368656, 0.2281654067337513, 0.23874203062483243, 0.1048710069486073, 0.16250563572560037, 0.13291287794709206, 0.14461813627609185, 0.16380779870918818, 0.1590624911976712, 0.1510577592998743, 0.12574643535273416, 0.12253296135791711, 0.14778544274824007, 0.1137271374464035, 0.21799669095448085, 0.09365852110620056, 0.1338412631303072, 0.06757781308676515, 0.09212704042771033, 0.16621762939861842, 0.15499244816601276, 0.14174679320837769, 0.11958813294768333, 0.13646350242197514, 0.1718710067548922, 0.10970583358513457, 0.1572947446256876, 0.21087482811084815, 0.12254512070545129, 0.10625167643385273, 0.17604390212467738], [0.08312260253088814, 0.05443619790353945, 0.07256233811910663, 0.09784590998398406, 0.03180470730045012, 0.05222911347768136, 0.07945039815136365, 0.016203889523499777, 0.04102212376892567, 0.0076558868666844705, 0.0052749554077828565, 0.020128539464037334, 0.026065352771963392, 0.0302489723877183, 0.03301620104217103, 0.16439422938440526, 0.08517513703554869, 0.06665260344743729, 0.03126463753038219, 0.04017731035128236, 0.04020157137087413, 0.029351592862180302, 0.026272786016176854, 0.062307183763810566, 0.02167402849798756, 0.029725285845675638, 0.013808224948921373, 0.10319905595055648, 0.039180749362068515, 0.027681117677795034, 0.02614589318233941, 0.017823101387226155, 0.01850497310182878, 0.0594016628872071, 0.8335630084787096, 18.844032219478063, 51.19392422267369, 61.17900671277727, 57.273740427834646, 48.060019152505056, 48.42100238800049, 39.030689171382356, 30.235492638179235, 25.38055178097316, 19.54284381866455, 19.26587646348136, 33.034678663526265, 37.704347542354036, 43.39907373700823, 43.705162729535786, 33.230055059705464, 13.587213635444641, 3.507460419620786, 0.2738208525947162, 0.10316147189587355, 0.075578358423497, 0.1660765212561403, 0.04947481430800898, 0.05365060702232378, 0.14220731492553437, 0.18074632622301579, 0.204907356894442, 1.284594354884965, 0.48102639402662006, 0.47231785846608026, 1.52065267094544, 2.338555416890553, 3.5361781929220473, 3.260055043867656, 3.2365807720593045, 6.24586295230048, 4.6226261002676825, 4.118954658508301, 5.975660536970411, 7.341454471860613, 4.97830308335168, 4.624496468475886, 4.60606941155025, 5.664386885506766, 2.711597033909389, 2.356312406914575, 0.46027603319713045, 0.36460957090769497, 0.2258170920291117, 0.09301242684679371, 0.6374450006655284, 4.450588268893106, 7.98311540058681, 7.1702903764588495, 5.447164050170353, 2.1111037475722174, 7.465298295021057, 6.058701063905444, 4.046990428652082, 6.297003430979593, 2.9420616158417294, 8.398530823843819, 4.787525526114872, 8.313849653516497, 2.6929224474089484, 2.442912582840238, 2.6843440277235846, 2.6354617135865346, 2.542450304542269, 2.1149367647511617, 1.9192841776779719, 1.5148166183914458, 1.126643996153559, 1.8928167521953583, 0.31664146057197023, 0.4391912631690502, 0.22043130174279213, 0.07028455712965556, 0.007030002772808075, 0.04649924486875534, 0.09183470718562603, 0.06713562538581234, 0.11333096120506525, 0.12575673551431724, 2.1670278438499997, 9.16682962008885, 23.43499537876674, 29.216233594076975, 49.43712084633963, 43.19164916447231, 46.971955571855815, 59.925787925720215, 28.341867072241648, 20.397084883281163, 15.365810905184064, 34.50587633677891, 40.75508267538888, 46.87647690091814, 47.227677072797505, 57.27798925127302, 58.017131669180735, 47.676638398851665, 29.329655987875803, 10.969560589109149, 0.13760626395898207, 0.0941868352570704, 0.009490554803051054, 0.04780757234298757, 0.01439159203852926, 0.04659693694806524, 0.0251021519569414, 0.03584911188642893, 0.02152366513785507, 0.0634585694809045, 0.025934928163353885, 0.052558504909809144, 0.015567966504022479, 0.012539286432521684, 0.029137535419847285, 0.028136448602059057, 0.02966193442365953, 0.041458571063620706, 0.03121920282553349, 0.03669448848813772, 0.19764218745487078, 0.13685790768691472, 0.05056180365915809, 0.03674482221582106, 0.04116945747019989, 0.11855669186583587, 0.09658625721931458, 0.10885210761002131, 0.06404514264847551, 0.038926868699491024, 0.04416156280785799, 0.031421725172549486, 0.015843809648816074, 0.0844821220796023, 0.04858029820024967, 0.027128169313073158, 0.06855425212000098, 0.08659800461360387, 0.01254485550868724, 0.06330126470753125, 0.049301329867116044, 0.05202288972213864, 0.06341224589518138, 0.038249426122222624, 0.037424985718514235, 0.05996964419526713, 0.04105346190876194, 0.04168667757351484, 0.050309446307697465, 0.029226199590734074, 0.02657056280544826, 0.06165089112307344, 0.09530030443732228, 0.0819187592715025, 0.09952506702393293, 0.023075691856709973, 0.011545867908612957, 0.04848359678206699, 0.11221262014337949, 0.02694828628695437, 0.08072330949029752, 0.03303612622299364, 0.057471793943217823, 0.01798042142763734, 0.06409297258194004, 0.03035287306244884, 0.013132111452120756, 0.03891930642670818, 0.021314265838425075, 0.012362848667960082, 0.0668067191062229, 1.8305198550224304, 29.29497058050973, 64.72851480756486, 73.61943667275565, 65.58498450687954, 57.416036060878206, 55.36057479040963, 49.39452838897705, 39.4971147945949, 34.92149325779506, 25.919382844652446, 27.51788020133972, 31.02492264338902, 26.567714044025966, 33.18999522072928, 33.91753414699009, 31.677657263619558, 13.254192556653704, 3.077603382723672, 0.3280545010098389, 0.0741238711135728, 0.118077388299363, 0.22514365959380353, 0.24299967501844677, 0.3339167721569538, 0.5391036719083786, 1.4820242694446017, 1.7734805728707994, 2.813503005674907, 3.837235604013715, 4.4145054050854275, 5.1217508145741055, 6.892036301749093, 7.650261947086879, 7.302547165325709, 7.467941216060093, 8.127285310200282, 7.357339790889195, 6.325116276741028, 7.794105291366577, 5.997094426836286, 9.133590306554522, 7.685388565063477, 7.217255422047206, 8.818743978227888, 3.5812565854617526, 5.555534669331141, 2.1327923323426927, 0.5507909219179834, 0.31229446668710026, 0.10627638189388172, 0.04537161805533937, 3.933494210243225, 7.369351489203317, 7.526531900678362, 7.513727239200047, 2.8350693455764224, 1.6768772708518165, 3.8413363439696173, 5.706747446741376, 7.890504598617554, 5.708720300878797, 9.91333018030439, 7.522818957056318, 8.228619575500488, 6.572248501437051, 5.587121180125645, 4.18136294398989, 3.9251889416149686, 4.203659279005868, 4.848363518714905, 5.193303797926221, 4.774161968912397, 3.3362209796905518, 5.504748114517756, 3.1676379229341234, 2.4658342557294026, 2.064036650317056, 0.6997251787355968, 0.37588514015078545, 0.3310662465436118, 0.17418584254171166, 0.05856177902647427, 0.04755471966096333, 0.09729802688317639, 1.2989913480622428, 7.546021597726004, 20.55758305958339, 33.69282940455845, 39.41758918762207, 37.23108489172799, 46.75690535136631, 44.65867791857038, 20.890525102615356, 21.189299379076274, 19.088311774390085, 41.57427528926304, 48.31474706104824, 54.588237353733604, 53.6720027242388, 65.68059171949113, 68.2627785546439, 57.148704120091026, 35.98117692129952, 13.745457989828926, 0.25570570464645115, 0.1676249245979956, 0.024104825919494033, 0.04515064634116633, 0.035195957470153055, 0.01324359730019101, 0.03931184232767139, 0.07697129582187959, 0.029499618669173548, 0.045889777929655144, 0.01874825674375253, 0.035649564915469716, 0.0471960833695318, 0.0053221687225491875, 0.0389630244379597, 0.06604284473827907, 0.012944705168982702, 0.027260972186923027, 0.057528797670134475, 0.04221977539626615, 0.07711054477840662, 0.18648670533938067, 0.0614094344366874, 0.028384047726701413, 0.07053190350000348, 0.0033685569900886287, 0.058905904846532006, 0.039214984846434424, 0.10458429197647742, 0.016994725480409603, 0.03784608455108745, 0.025985830164115344, 0.04002320487052202, 0.00526391521894506, 0.042204518536371846, 0.03205162619373628, 0.031078973385904516, 0.2101263361317771, 0.15024821273982525, 0.15074256621301174, 0.20595908617334707, 0.15668932854064874, 0.1277757707451071, 0.16747640685311385, 0.12023787094014031, 0.11541370408875601, 0.11592686655265944, 0.10708400141447783, 0.12066895780818802, 0.11019696401698248, 0.06518200771617037, 0.20465234986373357, 0.35902004369667595, 0.12935495243540832, 0.12731002430830682, 0.06942357761519295, 0.05896255573523896, 0.11927004930164133, 0.13801265215235098, 0.2815973253122398, 0.29939293754952295, 0.1259928114180054, 0.18492508413536207, 0.08779142557510308, 0.17205878453595297, 0.09966040761875254, 0.13258899961199078, 0.11990882216819695, 0.10944441439849989, 0.1595664798681225, 0.17365235116864952, 3.0474277905055454, 34.75188773018973, 76.25999532427106, 87.59642601013184, 77.19615391322544, 66.08068983895438, 62.80341216496059, 54.42147363935198, 44.55077586855207, 34.77644961220877, 27.187627111162456, 28.51790142059326, 44.89170660291399, 49.91397571563721, 59.066399982997346, 56.59343882969448, 43.39727415357317, 17.2163176877158, 4.983380479472024, 0.5151089365993227, 0.2855034614247935, 0.3088233529457024, 0.5746993475726673, 0.23262539026992662, 0.31924901636583464, 0.37110714082206997, 1.0110205433198383, 1.2821073340518134, 4.130336676325117, 4.1031865903309415, 6.401592493057251, 6.558341247694833, 10.866920930998665, 12.321940592357091, 13.980578950473241, 12.56669088772365, 16.4049174785614, 15.389790875571114, 12.98167291709355, 13.415862372943334, 19.310324089867727, 12.584098730768476, 12.576000605310712, 14.244504536901202, 15.095274107796804, 10.563417536871773, 7.319899422781808, 1.9601901769638062, 1.2329219047512328, 0.5179414674639702, 0.6959841709051813, 1.0176537930965424, 4.050056321280343, 4.645069215978895, 4.4249216232981, 10.049787589481898, 9.045806765556335, 18.40419214112418, 13.333291717938014, 12.74913842337472, 18.189845425742014, 10.678826246942792, 17.161979300635203, 12.799673540251595, 17.884411300931657, 9.670629603522164, 11.844439540590558, 8.249404243060521, 8.812433276857648, 8.947600058146886, 9.1129515511649, 9.363933512142726, 7.309908781732831, 5.640694831098829, 6.287600781236376, 2.8962032880101884, 2.286627403327397, 1.856779920203345, 0.4580661260655948, 0.29655538552573746, 0.32610463563885006, 0.3496488779783249, 0.14148117388997758, 0.18279114578451428, 0.30768943950533867, 3.0426574179104398, 12.893394316945757, 30.212282180786133, 39.89500686100551, 62.727961676461355, 56.32835463115147, 58.81342996869768, 71.31011254446847, 39.974695750645225, 31.69927658353533, 27.084915365491593, 47.97377116339547, 54.77207626615252, 61.56771673474993, 61.97358880724226, 72.44090407235282, 74.23982048034668, 65.7292707988194, 45.23670898165022, 18.43723429952349, 1.1169873028993607, 0.28552229755691116, 0.142300776339003, 0.18592284273888382, 0.17369847797921725, 0.18693373778036662, 0.15653292621885026, 0.14681646760020936, 0.07850093767046928, 0.17203697642045362, 0.15009816150580133, 0.16478114362273896, 0.11118506706718888, 0.057908112316259315, 0.07978729757347278, 0.22604465910366603, 0.17689497502786772, 0.11302471799509865, 0.10172018887741224, 0.14042568552706922, 0.2187435815909079, 0.25134212736572537, 0.128892042274986, 0.10294946362929684, 0.19684793507414206, 0.2324285608317171, 0.16259510735315935, 0.1260503918996879, 0.22134629264473915, 0.10802012189690556, 0.15907750039228372, 0.13644701402102197, 0.10951363854110241, 0.14679688507957117, 0.11263603956571647, 0.26721265433090075, 0.11701766587793827], [0.08204785055880036, 0.2507531318281378, 0.3024946025439671, 0.16973037804876054, 0.06442657432385854, 0.026597454844574844, 0.09461671433278493, 0.0018661330894766642, 0.10507793977324452, 0.0673861133732966, 0.02997083749089922, 0.03290578643126147, 0.08546192664653063, 0.06458325484501463, 0.24253270721861295, 0.2671089470386505, 0.24734623464090483, 0.05601823961894427, 0.13180389388331346, 0.03995371949193733, 0.018513446307874153, 0.04702457346554313, 0.028469134321702377, 0.038081325856702666, 0.030334135317908864, 0.06345590283828122, 0.04738999171448605, 0.04647166920559747, 0.033986702893993685, 0.048056045081466436, 0.0821465231212122, 0.009345282151895975, 0.049742713504071744, 1.5130184463092258, 25.282552650996617, 57.21695627485003, 65.73938737596784, 56.089496408190044, 56.93418891089303, 53.32269246237618, 39.1864504132952, 31.72934491293771, 20.089946712766373, 13.3717326266425, 19.360034976686748, 27.32858521597726, 44.11460617610386, 58.601058278764995, 42.29538713182722, 36.90411308833531, 10.110557402883257, 2.116425633430481, 0.19236249290406704, 0.04149733576923609, 0.18396701983043126, 0.11517312271254403, 0.10051302079643522, 0.18572081572243146, 0.05880053514348609, 0.2897212893835136, 1.2224838648523604, 1.4573401425565993, 3.1203638996396745, 3.9595156482287814, 3.998623149735587, 3.4552093148231506, 3.6015385942799703, 3.229034159864698, 4.175899054322924, 5.72301013980593, 7.445766040257045, 6.030547397477286, 2.9087261131831577, 3.495901874133519, 1.4697739439351218, 7.974846175738743, 8.246155960219246, 4.176558698926653, 6.8291138495717725, 1.6874573145593916, 2.9376686172825948, 0.8780580780335835, 0.3255261981061527, 0.28547949556793484, 0.6041767001152039, 10.385115470205035, 33.39346626826695, 39.197244439806255, 41.9806615284511, 25.437492268426077, 10.830682601247515, 5.273268444197519, 2.945711591414043, 2.829260434423174, 3.8843118207795277, 4.392447480133601, 6.648511060646602, 4.0632613727024625, 3.782643607684544, 10.108819484710693, 2.284608517374311, 3.3095188353742873, 5.241615925516401, 2.953017839363643, 2.8483217316014424, 2.3693528728825703, 3.6915106007031033, 3.193979412317276, 2.6070351132324765, 1.9166353940963745, 1.9858459659985133, 1.5776966214179993, 0.9142807743379048, 0.2796741670795849, 0.04814141157216259, 0.004196109325026295, 0.13204842433333397, 0.105763972603849, 0.10481374537838356, 0.04051020980945655, 0.4294682363314288, 3.4543067003999437, 15.578040157045637, 32.90265941619873, 42.158976622990195, 71.52246338980538, 83.76952498299735, 88.99700219290597, 55.64625344957624, 30.252512250627788, 20.031640904290335, 20.380820887429373, 37.28622579574585, 46.46528945650373, 46.49266535895211, 52.21292270932879, 58.158183574676514, 50.79359333855765, 27.021146535873413, 5.859390684536525, 0.313690538917269, 0.07945967372506857, 0.043179888876953294, 0.018258617392608097, 0.05957447897110667, 0.02747717040723988, 0.13904925010034017, 0.04771180051778044, 0.05508375779858657, 0.01882527725371931, 0.11368554324976035, 0.10722812903778893, 0.02973087358155421, 0.14118454552122525, 0.10038473696580955, 0.19432748960597174, 0.046823794953525066, 0.05931126166667257, 0.1076034606833543, 0.17582265899649688, 0.1441384255886078, 0.0786225718579122, 0.05189418519980141, 0.01743751877386655, 0.19734007652316773, 0.07769295174096312, 0.020868478509198343, 0.07444781051682574, 0.009005847553323423, 0.043426214052098136, 0.05077928431066019, 0.04121278193114059, 0.0950621793578778, 0.060125110138739855, 0.03838451565908534, 0.09946733047919613, 0.011705267658856298, 0.11449361060346876, 0.12371577003172465, 0.09138628374785185, 0.07143875198172671, 0.01939602698465543, 0.0872372253132718, 0.021532905088471513, 0.05351834697648883, 0.03870768153241702, 0.04436546936631203, 0.04319725937343069, 0.038517399957137446, 0.06381708702870778, 0.15769824225987705, 0.20892477275005408, 0.2674570083618164, 0.09871936775743961, 0.0684799389647586, 0.0639059344040496, 0.015578951985974396, 0.07236905741904463, 0.017532903834113052, 0.05552451039797493, 0.03201803871031318, 0.01710561167315713, 0.0067158067083385375, 0.07325528522155114, 0.03785074608666556, 0.07158289996108838, 0.03802543153454151, 0.045093530655971596, 0.01249549038974302, 3.357073392186846, 37.43239157540457, 69.54360253470284, 78.40597425188336, 65.06950460161481, 66.75056566510881, 63.651724679129465, 50.92932987213135, 41.80957950864519, 31.1793463570731, 22.823868308748516, 20.696119717189244, 24.32424667903355, 39.43489020211356, 50.64615256445748, 39.83664199284145, 31.08106756210327, 9.816177862031118, 1.7505084169762475, 0.22362595317619188, 0.0048555003262923235, 0.09555008674838714, 0.27324806047337397, 0.5275263445717948, 0.8494468618716512, 1.027281499334744, 2.4781675253595625, 2.6808332332542966, 5.524089728082929, 6.144256838730403, 5.835844108036586, 7.31208530494145, 6.104600429534912, 6.6711656621524265, 6.275783632482801, 8.150357672146388, 7.175538871969495, 7.214831803526197, 7.891177705356053, 6.471034961087363, 7.208495046411242, 6.255928286484309, 6.958999565669468, 8.1113999911717, 5.428802566868918, 4.81781359229769, 6.256663492747715, 4.896149320261819, 1.9926588918481554, 0.9888806513377598, 0.20073039031454495, 1.199259728193283, 11.316753387451172, 35.40163809912545, 43.149984291621614, 46.5373283794948, 31.326074940817698, 12.48928621837071, 4.185367711952754, 3.2853564747742245, 4.234181412628718, 4.956287716116224, 4.5999089649745395, 7.218130895069667, 5.376447890486036, 3.506115508931024, 4.479480181421552, 3.9591348000935147, 3.7465603096144537, 4.9049209867204935, 5.918690085411072, 4.310510848249708, 4.471094574247088, 4.154020045484815, 7.154324718884059, 6.753753687654223, 6.063547432422638, 6.37049583026341, 4.309345722198486, 2.5583920776844025, 1.8327962585857935, 0.5963721903307098, 0.2535318412951061, 0.3822502057467188, 0.1071195023666535, 0.0853968754942928, 0.06497643874692065, 0.4036672408027308, 2.3314728140830994, 9.75635039806366, 30.750916957855225, 45.86985315595354, 71.70893914358956, 79.19017573765346, 69.68572793688092, 46.00763940811157, 29.668988636561803, 28.14411265509469, 26.20298225539071, 41.947598525456016, 52.62363420213972, 53.863911969321116, 58.89591203417097, 65.52989224025181, 59.59665175846645, 32.16956887926374, 8.06959615434919, 0.5273931888597352, 0.062182197613375526, 0.027047537300469618, 0.06054886204323598, 0.01991229035359408, 0.05626761480899794, 0.06792965384998492, 0.04250818670594266, 0.07839798355208975, 0.06630538350769452, 0.07061960415116378, 0.07622371307973351, 0.0337114314149533, 0.03569239065317171, 0.052222355268895626, 0.09157790203711816, 0.07534753438085318, 0.03294175217992493, 0.10241774323263339, 0.09346608857491187, 0.15513236208685807, 0.07930034013198954, 0.03898193860160453, 0.08342097473463841, 0.11958612448402814, 0.06318794257406678, 0.020013622773279036, 0.018938942047368203, 0.04743813716673425, 0.043620230962655375, 0.11345778618540082, 0.043713556669120274, 0.02206406569374459, 0.08683739176818303, 0.02168772303100143, 0.007239844816337738, 0.13229256123304367, 0.2637026741036347, 0.42643057075994356, 0.3286547330873353, 0.1857341828622988, 0.07018952830029385, 0.21308690655444348, 0.1627076491713524, 0.20046037408922399, 0.14888513088226318, 0.09543316837932382, 0.16776573418506555, 0.19263888735856327, 0.14399625893150056, 0.3299691639840603, 0.44972427082913263, 0.30433240107127596, 0.17910651064344815, 0.18709431987787994, 0.3095216197626931, 0.11064299222614084, 0.19872217093195232, 0.18863398368869508, 0.12219586516065256, 0.17015636233346804, 0.17946788482367992, 0.11251490070883717, 0.15719015523791313, 0.1763557025364467, 0.1298878059855529, 0.10517676839871065, 0.16909189016691276, 0.1477800958922931, 4.332279554435185, 44.71488537107195, 83.33749294281006, 88.50648716517857, 74.96557371956962, 73.4788954598563, 69.97870567866734, 54.43174655096871, 43.84235143661499, 31.274435928889684, 21.124606439045497, 29.25801658630371, 38.70768478938511, 60.665722438267295, 76.38928740365165, 53.354379722050254, 44.91239139011928, 12.686100023133413, 3.3002199743475233, 0.44841225551707403, 0.24910369462200574, 0.28383239252226694, 0.23002543406827108, 0.4142293169030121, 0.7049461528658867, 0.7556482436401504, 2.270454385450908, 4.709578463009425, 6.316483574254172, 9.203054053442818, 11.145430786269051, 12.834398031234741, 11.857025333813258, 14.128831795283727, 8.585027422223773, 11.695824520928518, 15.690230982644216, 17.467375210353307, 16.40387351172311, 12.515608600207738, 15.603058883122035, 11.445737140519277, 20.350247076579503, 16.796285186495098, 13.487334149224417, 17.030503749847412, 12.930211084229605, 8.779858384813581, 3.123259995664869, 1.109610270176615, 0.6911591898117746, 1.0895697112594331, 9.77048477104732, 25.599664960588726, 30.185976300920757, 30.850227560315812, 20.289672681263514, 10.403868658202034, 11.832288009779793, 9.727176649229866, 11.549111570630755, 11.540704250335693, 15.022734914507184, 19.304277420043945, 11.490211691175189, 14.520725829260689, 24.179333312170847, 8.195243903568812, 12.741189684186663, 15.786899532590594, 11.944200907434736, 9.244327221597944, 8.215196524347578, 10.473316771643502, 11.220022303717476, 11.278530478477478, 11.166001796722412, 9.063493405069623, 3.5442031451634, 3.2243712672165463, 1.835772910288402, 0.39291579914944513, 0.14464810038251535, 0.6191431198801313, 0.18672996014356613, 0.23095402281199182, 0.13497419948024408, 0.8486687721950668, 4.737753842558179, 19.898044415882655, 39.83184773581368, 49.25515447344099, 76.2770323072161, 85.9794898714338, 95.77834674290249, 65.08240740639823, 42.97711658477783, 31.042463370731898, 32.39086205618722, 50.4072596005031, 60.76162147521973, 61.93556131635393, 67.92975834437779, 73.25713675362724, 66.52500629425049, 40.73643718447004, 12.37479293346405, 1.613789907523564, 0.1561766681926591, 0.12209104507097177, 0.17099841072091035, 0.14635817147791386, 0.09179115202277899, 0.22055407586906636, 0.20718290550368174, 0.16672525501676969, 0.22734034886317595, 0.16320698309157575, 0.11992654550288405, 0.28513710679752485, 0.31491206479924067, 0.23592024775488035, 0.23930364048906735, 0.20023210133825028, 0.14404807186552457, 0.21057119726070336, 0.17705601852919373, 0.250424612313509, 0.23843356860535486, 0.15963517475341046, 0.18909628316760063, 0.41637365041034563, 0.21871942574424402, 0.22179366435323442, 0.17703388471688541, 0.1297171272869621, 0.10536856989243201, 0.15641517325171403, 0.07903098887098686, 0.3465292182351862, 0.22408176586031914, 0.18312593496271543, 0.15428218484989234], [0.03550082664670689, 0.2673471128301961, 0.2588796743324825, 0.13128497744245188, 0.022290399530902505, 0.058306303806602955, 0.15142727590032987, 0.1576941574790648, 0.024936689496306435, 0.06117759259151561, 0.11674500336604458, 0.07181393434958798, 0.04115924212549414, 0.010346537755270089, 0.21898178809455462, 0.2683315042938505, 0.18043418654373714, 0.061964367516338825, 0.0791799748050315, 0.04000105070216315, 0.04383073966684086, 0.19707533930029186, 0.03947227175480553, 0.04724943318537303, 0.11363956571689673, 0.04238945325570447, 0.01667682673516018, 0.11827385132866246, 0.010012541614872004, 0.03895729420972722, 0.031312185871813975, 0.06781467609107494, 3.02173313498497, 24.459008727754863, 61.42357635498047, 67.14684227534703, 63.1760162625994, 49.32861777714321, 27.05763152667454, 27.6012898513249, 18.00234133856637, 18.46125943320138, 15.918757234300886, 17.96038637842451, 25.634207929883683, 56.24100535256522, 50.99432332175118, 35.975128514426096, 21.588145085743495, 5.719232491084507, 0.4558524734207562, 0.07772839841033731, 0.043541958555579185, 0.05236944130488804, 0.07676277522529874, 0.08035195405994143, 0.2395317368209362, 0.6583235231893403, 1.3229743582861764, 2.02442410162517, 2.006093450954982, 4.155836999416351, 4.018771622862134, 5.084148032324655, 5.297515485967908, 3.84449907711574, 4.930240222385951, 7.413165960993085, 6.968309283256531, 4.195929842335837, 1.634236827492714, 5.4443322249821255, 2.6337800323963165, 4.591836895261492, 4.447266161441803, 6.528155667441232, 5.86947078364236, 3.5193702833993092, 6.118725248745509, 4.320993508611407, 5.89605415718896, 2.9233155931745256, 1.2753483653068542, 0.6659338091100965, 15.569007498877388, 38.41220569610596, 60.408785002572195, 56.42634160178048, 64.54504067557198, 56.23826081412179, 44.15989453451974, 15.523274455751691, 3.142309133495603, 2.7908816252435957, 3.1791628130844662, 1.5220252658639635, 7.322275706699916, 6.638703678335462, 3.6124140449932645, 5.107955166271754, 1.906044602394104, 2.3655116047177995, 3.373318063361304, 2.226528091090066, 3.7608779413359503, 1.9143533451216561, 4.136132776737213, 3.5367783435753415, 4.787255849157061, 4.700993963650294, 3.7358275141034807, 3.5676446301596503, 1.4851536729506083, 0.8818763302905219, 0.8798968536513192, 0.9137946175677436, 0.14180114386337145, 0.042351160131927044, 0.14815044030547142, 0.008146471077842372, 0.044098038359412124, 0.32876831984945704, 3.4795683962958197, 8.640754580497742, 23.395340272358485, 39.55597298485892, 45.5623710496085, 56.22405522210257, 55.511854444231304, 43.75123276029314, 25.554994991847447, 24.95917306627546, 45.358139174325125, 26.796007531029836, 36.554101058415, 43.49697732925415, 50.021909032549175, 50.32795286178589, 55.02579321180071, 36.65413774762835, 7.832792861121042, 0.1844975527908121, 0.06152458182935204, 0.00924417534510472, 0.035907859448343515, 0.05961000027933291, 0.01467700591976089, 0.04566026006692222, 0.01671083491029484, 0.03336978903306382, 0.06726670478071485, 0.25030779572469847, 0.08705963234284095, 0.10666324184941393, 0.1991156262478658, 0.2511451893619129, 0.04703461239114404, 0.06888539077980177, 0.17868053992944105, 0.29536379660878864, 0.15516214977417672, 0.19845900791031973, 0.04456459564555969, 0.006908061972353607, 0.05157265459586467, 0.05992291348853281, 0.0078132340484964, 0.09356860843087945, 0.042595280068261285, 0.03895842736320836, 0.027584601160404936, 0.08051290256636483, 0.11986507023019449, 0.02209739194118551, 0.08819608350417443, 0.03897789792556848, 0.047594960180244276, 0.14982175348060472, 0.1614097880997828, 0.11806493039642062, 0.013814346182958355, 0.004671611823141575, 0.1260690651834011, 0.08229097644133226, 0.025678211224398444, 0.02327663152079497, 0.08731326194746153, 0.03576946544593998, 0.09373579267412424, 0.12858945636876992, 0.17335072878215993, 0.23474464512297086, 0.02743063647566097, 0.029486166712428843, 0.09870480639593941, 0.02265857263202114, 0.009470713590937001, 0.12181249287511621, 0.03928105380120022, 0.056618298670010905, 0.14894414985818522, 0.12692486069032125, 0.016301456073831235, 0.05143911551151957, 0.05118817969092301, 0.03367354541218706, 0.020788014434011917, 0.11803951247462205, 4.9080502816608975, 34.4191107068743, 72.22432177407401, 74.59702042170933, 71.16330405644008, 60.305103983197895, 42.17586421966553, 40.32356480189732, 28.80793833732605, 30.020063740866526, 24.500442573002406, 17.128389971596853, 18.49995916230338, 36.72577020100185, 44.30353464399065, 35.47334698268345, 21.722545828138077, 5.585522660187312, 0.561461400772844, 0.07809239173574106, 0.03132772771641612, 0.1324073150753975, 0.3214692643710545, 1.0701263717242648, 1.316892296075821, 1.797696782009942, 3.8819238117762973, 5.0367109434945245, 4.1127859609467645, 6.447600424289703, 6.858542510441371, 7.205262831279209, 7.064775901181357, 6.090064798082624, 7.283248978001731, 5.363664942128318, 12.331570795604161, 6.733016788959503, 5.710234573909214, 9.000353387423925, 6.733088876519885, 7.127086911882673, 4.833252055304391, 5.137477193559919, 5.949041988168444, 6.275445342063904, 3.5521234401634763, 2.9868531780583516, 2.352607931409563, 0.8159418883068221, 0.3718608575207846, 1.8582944103649683, 17.545403480529785, 46.383818353925435, 71.89577620370048, 67.82434722355434, 72.42906434195382, 64.00460978916713, 49.36116313934326, 17.485800095966884, 2.600659489631653, 1.9982228790010725, 0.8865335775273187, 2.2380021725382124, 2.0960988955838338, 1.8417746339525496, 2.16018191405705, 1.5668727393661226, 2.810491612979344, 2.074409442288535, 3.1978506445884705, 2.197338274547032, 6.650040532861437, 5.092150620051792, 6.3294476100376675, 5.102504304477146, 5.177457996777125, 8.130339912005834, 8.068188275609698, 6.734157162053244, 4.597173980304173, 4.274596043995448, 3.7428990432194302, 2.6522301052297865, 0.8623522722295353, 0.3352462665310928, 0.0443061416569565, 0.031999528275004456, 0.10367581501070942, 0.106903680733272, 2.0340936056205203, 8.43159816946302, 25.860927649906703, 43.5739494732448, 50.94476876940046, 55.12224463054112, 54.81195197786604, 45.19520391736712, 26.868770803724015, 28.683977263314382, 50.372539452144075, 32.46141753877912, 42.86020966938564, 48.76463597161429, 55.88242966788155, 59.897703307015554, 64.19276005881173, 44.33859177998134, 8.657619595527649, 0.39895967340895105, 0.020413822727277875, 0.046288474928587675, 0.035644384300602336, 0.07208346202969551, 0.029842557052948644, 0.07680690714291163, 0.09991052241197654, 0.014681377381618534, 0.07984660831945282, 0.18592827101903303, 0.04127044722970043, 0.11002512502350978, 0.097584986127913, 0.2092528308608702, 0.030457815288433006, 0.05183832819706627, 0.09028272796422243, 0.05713252643389361, 0.13472626278442995, 0.12533335680408136, 0.037607124873570034, 0.035696299014879126, 0.06393944046327046, 0.1073787027437772, 0.02699428078319345, 0.05601889440523727, 0.048561017627694776, 0.03560345846095255, 0.012421721758853112, 0.06271895952522755, 0.08480356447398663, 0.025247246492654085, 0.033120407057659965, 0.004602182847780308, 0.12329093925654888, 0.34102173947862213, 0.3504618714962687, 0.36028619004147394, 0.10455626169485704, 0.13906997255980968, 0.23982008706246102, 0.2106417649026428, 0.1262267024389335, 0.2069444004446268, 0.17377199046313763, 0.12990311373557362, 0.18631270181919846, 0.20561122841068677, 0.5407965353557042, 0.43076228403619354, 0.2774992452136108, 0.24569986441305705, 0.3187217132321426, 0.11756729281374387, 0.11582033655473165, 0.2351865071271147, 0.20622010502432073, 0.14323319202022894, 0.2800773525876658, 0.21278233932597296, 0.13596327283552714, 0.2055640702268907, 0.14332425141973154, 0.11674687612269606, 0.07798514927604369, 0.39529216449175564, 7.228306531906128, 43.69957985196795, 85.14943722316197, 85.30664716448102, 80.40477643694196, 67.70777034759521, 43.95768458502633, 43.31683485848563, 28.612987518310547, 28.022755418504985, 25.032622473580496, 27.399859837123326, 38.43639932359968, 76.32701764787946, 65.14627524784633, 47.44033016477312, 29.380103383745464, 7.810223375047956, 1.1443681993654795, 0.1331295341785465, 0.18898231642586844, 0.2323483851339136, 0.3524628441248621, 0.5519654388938631, 1.601338192820549, 2.504115572997502, 3.9671252284731184, 6.424920201301575, 8.771276491028921, 13.151789137295314, 13.824503302574158, 16.672476972852433, 14.365643773760114, 13.345345973968506, 11.764180898666382, 15.594253778457642, 14.38080300603594, 11.061987263815743, 13.333520139966692, 15.63800311088562, 12.88719826085227, 18.276946306228638, 10.742381419454302, 17.10903229032244, 13.723908151899066, 12.509958846228463, 12.960881301334926, 9.916836415018354, 14.512697185788836, 10.647541982786995, 5.64191814831325, 2.013934927327292, 20.645185947418213, 40.584049292973106, 60.97921126229422, 58.41012872968401, 62.98675428118025, 55.10585730416434, 45.52204370498657, 20.521563598087855, 7.8602712494986395, 8.091930270195007, 8.648414100919451, 8.049647876194545, 17.203710181372507, 15.0651501928057, 13.761886136872427, 14.538223998887197, 8.554100121770587, 7.31553942816598, 8.59566945689065, 7.543477688516889, 10.846286518233162, 8.423673748970032, 10.429722905158997, 8.655033128602163, 13.108867509024483, 14.28781179019383, 10.548760311944143, 9.903446367808751, 7.747285723686218, 2.7773482714380537, 3.982632739203317, 2.3543768993445804, 0.7499373672263963, 0.34043317820344654, 0.3518837551985468, 0.1386506107768842, 0.20113703635122093, 0.5210941040090152, 4.956837926592145, 11.180815356118337, 30.15464687347412, 48.90296070916312, 54.25288254874093, 63.49409089769636, 64.43029812404087, 53.04963173185076, 35.57557235445295, 36.50820820672171, 54.80776916231428, 37.115977559770855, 51.35284342084612, 56.26162413188389, 64.25685719081334, 68.16421140943254, 70.91462802886963, 51.26871463230678, 12.397906984601702, 0.7619445057851928, 0.19562486213232788, 0.12769015319645405, 0.10802884107189518, 0.16839157417416573, 0.18482012833867753, 0.2464559424136366, 0.16187937504478864, 0.09104019696159021, 0.20146228532705987, 0.46857788200889317, 0.2569066302052566, 0.16616189453218663, 0.428029117839677, 0.4182658674461501, 0.15385184437036514, 0.25068584829568863, 0.37709328532218933, 0.32673192769289017, 0.361384602529662, 0.28965194310460773, 0.15192124939390592, 0.10876706681613411, 0.19097070901521615, 0.3051824968840395, 0.194523654079863, 0.30629078884209904, 0.22135097453636782, 0.17351949401199818, 0.11562148508216653, 0.11640916924391474, 0.27441698632069994, 0.08545464596578053, 0.2529149443975517, 0.14508924313953944], [0.025529798652444567, 0.12343017464237553, 0.12155885648514543, 0.09021921708647694, 0.011354559200948902, 0.07533572787152869, 0.051870405940072875, 0.11768866915787969, 0.03643912183386939, 0.06321085670164653, 0.07777753791638783, 0.048109992008124075, 0.06180925441107579, 0.010023059755829828, 0.08659961952694825, 0.21634474316877977, 0.12094094178506307, 0.2186665814369917, 0.08202835624771458, 0.04754994955978223, 0.07192481375698533, 0.12088511192372867, 0.09895103996885674, 0.11149714567831584, 0.1481303149568183, 0.03903915945972715, 0.020024486118927598, 0.05859367695770093, 0.14253082685172558, 0.06399342470935412, 0.09573596463139568, 2.5017073707921162, 31.649583067212784, 63.02118260519845, 63.45534079415457, 50.93165404456002, 45.43457630702427, 32.050177982875276, 43.23147971289498, 73.32423550742013, 37.10360629217965, 13.732120054108755, 26.093018327440532, 42.56188528878348, 41.47261619567871, 42.229698862348286, 36.17173474175589, 16.881629909787858, 3.565866542713983, 0.26489195600152016, 0.08020613688443388, 0.1194170064159802, 0.13277030416897365, 0.030906313365059238, 0.22144183037536486, 1.2272174337080546, 1.2974417912108558, 2.547172691140856, 3.277355189834322, 4.24825325182506, 1.689189804451806, 7.229995378426143, 6.646043581621988, 4.953292173998697, 4.361555789198194, 3.4476885412420546, 7.163745607648577, 5.058576924460275, 15.312855209623065, 7.055199546473367, 3.7726785881178717, 6.7445564440318515, 3.653892619269235, 3.796885243483952, 3.273823985031673, 2.446111794028963, 4.364641223634992, 2.541250003235681, 1.5829804007496153, 2.106326861040933, 0.8286710966910634, 4.657171240874699, 9.056713700294495, 16.183151824133738, 42.193578651973176, 48.95626381465367, 48.97089672088623, 51.03282676424299, 57.95516068594796, 60.36321871621268, 56.37514380046299, 36.339245387486045, 13.04972357409341, 5.18317723274231, 5.226277342864445, 5.8002771479742865, 4.084759967667716, 4.548226526805332, 1.9403163748128074, 2.982527490173067, 2.889731909547533, 1.5351532357079642, 2.9621610173157285, 2.577092719929559, 3.904911492552076, 3.585193608488355, 3.349592787878854, 7.822347113064357, 4.99030088526862, 5.428783893585205, 6.7154256871768405, 7.240799392972674, 3.12536529983793, 3.9310523527009145, 3.101045084851129, 0.9126681408711842, 0.7462044475334031, 0.013406305756819035, 0.168039115944079, 0.2196263149380684, 0.05925767097089972, 0.04440666322729417, 0.05690002640975373, 0.22587148339620658, 3.286741554737091, 16.078169754573278, 22.82892312322344, 22.57544241632734, 23.568251405443462, 23.370239904948644, 29.465048585619243, 29.289707320077078, 36.83891119275774, 23.14326136452811, 29.942094530378068, 40.67081839697701, 49.419666971479145, 47.70096056801932, 50.80826793398176, 54.41350058146885, 19.57048896380833, 3.4079852317060744, 0.7373972801225526, 0.023025212243997624, 0.0322157807781228, 0.10375802631356887, 0.06232270864503724, 0.035395813174545765, 0.0713843877560326, 0.047025421634316444, 0.048231426027736495, 0.16865275587354386, 0.15951922668942384, 0.09245878298367773, 0.10097730159759521, 0.036819345716919215, 0.055171587371400425, 0.035644285913024626, 0.12144814671150275, 0.11582414992153645, 0.10813701312456812, 0.19133870569722994, 0.04753388863589082, 0.022475855025861944, 0.04535802699891584, 0.04603425160582576, 0.018574394019586698, 0.07223453785159759, 0.06740379599588257, 0.021590081841817925, 0.019618868062804853, 0.020670271644900953, 0.14257995278707572, 0.04871480080432125, 0.11317369035844292, 0.04499303961970976, 0.01668684191203543, 0.005438705839748893, 0.14826477345611366, 0.07593469108854022, 0.08492690856967654, 0.02890517110271113, 0.038916951910193474, 0.09140241252524511, 0.012772245315967925, 0.05027587239497474, 0.01689515894811068, 0.032498831661151986, 0.05221607203462294, 0.027307841993336166, 0.053164843802473376, 0.140214349010161, 0.10428219461547476, 0.10753765635724578, 0.04154624457338026, 0.019927128218114376, 0.04634175689092704, 0.14658556213336332, 0.07929151239139692, 0.11681884154677391, 0.28631919622421265, 0.05523787685004728, 0.014378567558846303, 0.048668134558413706, 0.09679527993180922, 0.045624969460602315, 0.08940506327365126, 4.685484281608036, 40.698176928928916, 72.72384861537388, 71.64871215820312, 62.267817224775044, 55.41120631354195, 41.749289989471436, 49.42228991644723, 67.68862806047711, 29.742799350193568, 18.340454578399658, 26.094901289258683, 30.196680000850133, 38.416954789842876, 42.7067482812064, 34.02124990735735, 18.74883668763297, 3.462599809680666, 0.3383815868624619, 0.0510392310763044, 0.10162309051624366, 0.5174409800342151, 0.19368016719818115, 1.1202533904995238, 3.110955604485103, 4.5162248611450195, 2.9457378642899648, 5.664669156074524, 7.887235471180507, 7.050938563687461, 6.409962466784886, 9.90447383267539, 8.469499724251882, 8.030668871743337, 5.353970033781869, 5.852366055761065, 6.403582717691149, 12.813142623220172, 11.080060396875654, 7.384728721209934, 6.323482581547328, 6.3401274255343845, 4.04893114737102, 3.9486334664481024, 2.011264430625098, 2.2368693990366797, 0.34836709818669725, 1.3573140927723475, 1.225879579782486, 2.43652697120394, 5.207199326583317, 9.572769437517438, 20.384611129760742, 48.0215539251055, 58.6769117627825, 59.47595460074288, 57.38241025379726, 66.84249033246721, 69.8158676964896, 65.0492992401123, 42.56746816635132, 16.076741899762833, 7.3751393386295865, 6.368927274431501, 4.372454038688114, 3.4939926394394467, 3.145902220691953, 3.0092441822801317, 3.8252729773521423, 3.914106999124799, 2.6697198067392622, 3.393285231930869, 4.122834358896528, 4.534391794885908, 6.7019487874848505, 6.32487656388964, 9.191241247313362, 9.13334972517831, 6.800599745341709, 5.522151180676051, 8.03828844002315, 7.813973665237427, 7.578883102961949, 7.1388949411255975, 6.022662929126194, 3.198749133518764, 2.195632274661745, 1.0231376588344574, 0.3606980879391943, 0.07448263971933297, 0.07314836167331253, 0.04735275371266263, 0.20526818824665888, 3.285452229636056, 14.139036093439374, 26.78459858894348, 27.283725908824376, 28.146313496998378, 29.074210677828106, 34.41131482805525, 32.348578793661936, 38.74302680151803, 27.50086580004011, 32.8449581010001, 46.633508818490164, 57.257822104862754, 55.06148958206177, 57.39191538946969, 65.58699948447091, 33.192899567740305, 4.379881228719439, 0.8310144852314676, 0.03232254147795694, 0.07323685621044465, 0.11982543021440506, 0.10032656615866081, 0.03201028984040022, 0.06038866671068328, 0.02569246894147779, 0.1134639744247709, 0.13537799566984177, 0.1299705465457269, 0.01448650042792516, 0.07751285497631345, 0.061172177882066796, 0.017949573529352034, 0.12301197993968215, 0.10285123211464711, 0.07974150324506418, 0.025051794480532408, 0.1487256751528808, 0.05871772672981024, 0.07435635078166213, 0.07038582169583865, 0.022246416890993714, 0.028612098257456507, 0.07503048210803952, 0.01975734348941062, 0.004260294072862182, 0.03618889508236732, 0.05089088975052748, 0.14836495236626693, 0.040564004065735, 0.10040336953742163, 0.13042133807071618, 0.08178100987736668, 0.23236844262906484, 0.4254341556557587, 0.2366394948746477, 0.14149892436606543, 0.1041721837329013, 0.22994069861514227, 0.23663754069379397, 0.13519095070660114, 0.1950030526412385, 0.23735648925815309, 0.1625919725213732, 0.17448959552815982, 0.24421927386096545, 0.37430670484900475, 0.39011480659246445, 0.31568353197404314, 0.37506397707121714, 0.16918186391038553, 0.11054390575736761, 0.1971119259084974, 0.25707778387836044, 0.2261756027915648, 0.298222193228347, 0.5056865821991647, 0.14060332599495137, 0.1675420483308179, 0.12400266820830957, 0.26481644862464493, 0.15125499585909502, 0.33018675659384045, 8.484264646257673, 48.976955550057546, 81.93756989070347, 80.2861498423985, 71.81188365391323, 64.16070107051304, 47.42916440963745, 54.719971724918906, 80.68301704951695, 47.82016733714512, 19.28666721071516, 36.17307226998465, 60.367297308785574, 53.740022114345, 56.29295703342983, 48.48445681163243, 24.036896978105815, 5.595893715109144, 0.7657060325145721, 0.4281913691333362, 0.23468194848724774, 0.3848279331411634, 0.16129559065614427, 0.8058351363454546, 2.351566787276949, 5.659906165940421, 6.591737329959869, 10.4642493724823, 15.209723097937447, 7.916192088808332, 16.0228134563991, 15.827600342886788, 14.312663759504046, 12.611418179103307, 12.222536189215523, 17.505981138774327, 16.269389390945435, 27.503101382936748, 18.221237386975968, 9.830732601029531, 15.702537979398455, 13.660373823983328, 11.183335815157209, 13.218194808278765, 8.413688319069998, 12.797400610787527, 8.852947354316711, 6.427010306290217, 8.606417451586042, 7.527733939034598, 9.643301469939095, 13.578470196042742, 20.599383422306605, 54.626004287174766, 58.009096077510286, 62.0654787336077, 60.43699468885149, 71.9300377709525, 70.31754847935268, 65.06814275469098, 44.19076885495867, 20.062060117721558, 11.716376423835754, 10.439006567001343, 10.429396339825221, 11.351986833981105, 10.270769834518433, 5.092587053775787, 6.749087972300393, 6.200264096260071, 4.538443463189261, 7.387453283582415, 8.278140255383082, 10.769481131008693, 11.422095894813538, 10.792972121919904, 17.148543221609934, 10.919920921325684, 14.485106757708959, 14.219586559704371, 16.246856382914952, 11.460261481148855, 10.831779548100062, 9.608304262161255, 5.325795088495527, 2.977224277598517, 1.3804061050925935, 0.7379698008298874, 0.4335307611950806, 0.20227309396224363, 0.18180273739354952, 0.1847789819751467, 0.6003903118627412, 4.819460315363748, 22.152182476861135, 33.65576771327427, 34.388048785073416, 33.3868168422154, 34.6253228187561, 42.47251408440726, 40.873591150556294, 44.55739055361067, 33.3698319707598, 41.988981996263774, 54.019207681928364, 65.01925522940499, 65.71903610229492, 66.28558526720319, 72.36295223236084, 41.406660420554026, 6.960739655154092, 1.2207116399492537, 0.12881916761398315, 0.1755431704223156, 0.20596693003816263, 0.1485116516372987, 0.22479515043752535, 0.20555626707417624, 0.2288503742643765, 0.26797242356198175, 0.5053121937172753, 0.21943631156214646, 0.17413226541663918, 0.24680574078645023, 0.19082048136208737, 0.218569225232516, 0.160275399684906, 0.28021118683474405, 0.37085184880665367, 0.12023006778742586, 0.3017028878842081, 0.1192077055041279, 0.1859249733388424, 0.13484818195658071, 0.21978307009807654, 0.10986957765583481, 0.16264700171138557, 0.176984093817217, 0.1389477141201496, 0.12346012517809868, 0.12207933355654989, 0.27641071219529423, 0.23859302433473722, 0.2597311814980847, 0.21008130854793958], [0.11493165924080781, 0.02943043184599706, 0.0408036219222205, 0.025628111591296535, 0.013273961742275527, 0.019671544432640076, 0.0386010633249368, 0.052918104720967155, 0.023402684667546834, 0.04748322581872344, 0.03992487496829458, 0.039193767056401284, 0.03830500153292503, 0.0389620710962585, 0.04035477779273476, 0.024347687173368673, 0.022848572615267973, 0.02689396107702383, 0.0015315758854350342, 0.014790512954017945, 0.03392349735700658, 0.022615992863263403, 0.20368087770683424, 0.11360361014625855, 0.06928023030715329, 0.08028212602117232, 0.14770941968475068, 0.04101410687768033, 0.04280189737411482, 0.05575802483196769, 5.594639565263476, 26.803702660969325, 62.30763735089983, 64.98648057665143, 59.97498117174421, 49.2888879776001, 34.37357568740845, 28.273286615099224, 37.38638060433524, 110.26619543348039, 64.45514488220215, 25.425659486225673, 41.7775239944458, 42.626941272190635, 33.67873845781599, 20.411999191556657, 8.713979908398219, 1.5093117994921548, 0.0796826064054455, 0.07467790852699961, 0.06068954270865236, 0.04963126751993384, 0.1888435288731541, 0.8866207014237131, 2.294775686093739, 4.753465022359576, 2.3679966713700975, 1.99062437244824, 5.40503408227648, 4.642540071691785, 4.058001586369105, 4.691805405276162, 2.536726943084172, 3.5563284030982425, 5.078094414302281, 4.32050279208592, 4.431440336363656, 1.2117341331073215, 11.181191427367073, 8.309459260531835, 7.216962729181562, 7.836179239409311, 4.544187452111926, 3.8771660327911377, 3.4930040410586765, 3.1506296013082777, 1.979789525270462, 2.8688677719661166, 6.7661579591887335, 13.59892395564488, 16.861719846725464, 23.08694100379944, 34.58936589104788, 45.97174154009138, 50.914561476026265, 40.4635397366115, 37.80643742425101, 50.12169558661324, 50.04314620154244, 45.15834719794137, 49.81782306943621, 45.51540470123291, 32.70173488344465, 24.54019148009164, 24.39313633101327, 29.781862122671946, 21.33970182282584, 27.877892426082067, 24.73069371495928, 21.71984645298549, 14.40441037927355, 15.200737340109688, 11.00348343167986, 7.1288904036794385, 7.708885635648455, 10.803296276501246, 8.978290251323156, 6.200971943991525, 9.206639323915754, 5.356146556990487, 6.624292245932987, 4.76519010748182, 2.41481927888734, 7.934314727783203, 6.383335666997092, 5.254425798143659, 2.475999253136771, 0.7944032326340675, 0.1766306720674038, 0.08631717254008565, 0.10601927140461546, 0.11042702810040542, 0.06498681354735579, 0.11020714204226222, 0.4705130638820784, 2.637718358210155, 13.824940170560565, 34.26652479171753, 37.485093661717, 27.41415228162493, 22.832081079483032, 52.3542560168675, 36.26904426302229, 19.925170183181763, 27.146340915134974, 26.3183171408517, 32.816473960876465, 39.02691977364676, 54.07747874941145, 57.70016527175903, 53.82523134776524, 30.200897557394846, 3.234070518187114, 0.599195655967508, 0.05204581402774368, 0.047651546608124457, 0.017575887331206883, 0.0933572312018701, 0.05083803865792496, 0.02990632577400122, 0.037481239664235284, 0.02700041134708694, 0.07892134439732347, 0.024106099868991544, 0.12423179591340677, 0.1129111380183271, 0.08554735420537846, 0.04644231238801565, 0.08909611270896026, 0.08457145800015756, 0.13727079624576227, 0.09976837611091988, 0.06564624780522925, 0.12491140301738467, 0.03539506678602525, 0.034345122054219246, 0.07509326695331506, 0.0640381673084838, 0.17909747255699976, 0.09457155104194369, 0.03725007635408214, 0.05480643714378987, 0.14487626456788608, 0.11163033531712634, 0.057905024981924465, 0.03913423917921526, 0.04151689114847353, 0.03023947968280741, 0.022876655483352284, 0.03344634135386773, 0.037295772294913015, 0.031247891286121945, 0.07404206014637436, 0.03063898753108723, 0.03502626604001437, 0.013662643564332808, 0.0595403758010694, 0.02947758324444294, 0.04365682774888618, 0.050298202982438464, 0.02780469586806638, 0.03816963040402957, 0.05904870932655675, 0.11236632189580373, 0.03515407828880208, 0.04777716379612684, 0.013289605367130466, 0.03304560535720416, 0.126658508554101, 0.0786812040688736, 0.0638247544744185, 0.04419261257031134, 0.08985554267253194, 0.07668608041214091, 0.11584469596190111, 0.09305421781859227, 6.74609329870769, 33.55503967830113, 73.48644815172467, 70.52983679090227, 68.90479905264718, 56.828190667288645, 45.01632949284145, 34.82036917550223, 49.062425340924946, 125.235109601702, 76.38264492579869, 22.614590304238455, 32.35327230181013, 44.42275183541434, 35.93294252668108, 23.76373897280012, 9.6203168290002, 1.5142552256584167, 0.04159726362143244, 0.07041110391063349, 0.06697684140609843, 0.08043815514871053, 0.6195413927946771, 1.9138487321989877, 3.134308934211731, 6.727666241782052, 4.197515768664224, 5.164899127823966, 5.417453118732997, 9.532515917505537, 3.9693625484194075, 7.006397570882525, 7.756543329783848, 6.046547361782618, 6.968186821256365, 6.7012956568173, 10.174764837537493, 4.570814686162131, 6.087175215993609, 6.655680733067649, 3.5829612825598036, 3.806812047958374, 3.007369254316602, 1.8885116917746407, 0.6551033588392394, 1.4434044446263994, 0.4142799356154033, 1.9283470170838493, 5.753391138144901, 14.959770338875906, 20.19689338547843, 28.395083325249807, 39.246767725263325, 51.551259653908865, 57.03826597758702, 48.29879052298409, 45.880942480904714, 56.459081513541086, 55.347932543073384, 53.4266687801906, 55.85415744781494, 51.884533473423545, 37.803682463509695, 28.5558021068573, 27.331746646336146, 32.41359656197684, 24.54665330478123, 29.567333017076763, 29.190532207489014, 26.107074533190044, 18.146120412009104, 18.417299917766027, 14.23928643975939, 9.600147077015468, 8.547124998910085, 10.659460748944964, 8.409545455660139, 7.17446494102478, 6.450835244996207, 6.720551286424909, 8.663245030811854, 5.831244834831782, 11.219550694738116, 10.879024692944117, 8.495835133961268, 7.225314029625483, 4.74063343661172, 4.1434752855982095, 2.936083559479032, 0.6402514215026582, 0.3815397795821939, 0.38810726574489046, 0.15734794177114964, 0.0378703557487045, 0.2953888752630779, 2.417159301894052, 11.005657349314008, 28.606457948684692, 32.58983761923653, 30.902950491224015, 25.88703203201294, 44.42446109226772, 38.9521849496024, 23.264616864068167, 32.14230762209211, 33.249940804072786, 37.97312123434884, 45.32823065349034, 61.086234365190776, 65.90896511077881, 65.10408578600202, 46.619935512542725, 8.962666358266558, 0.512641674705914, 0.016396383122940148, 0.04363149803664003, 0.01309435861185193, 0.03848685909594808, 0.04587700790060418, 0.012541041293713664, 0.02587584642294262, 0.07362308512840952, 0.10908302664756775, 0.05558288137295416, 0.13958859044526303, 0.0938801442139915, 0.05480381799861789, 0.0305931151711515, 0.11450818553566933, 0.04351186552750213, 0.10851326079240867, 0.11856912262737751, 0.1015223687780755, 0.09436884549047266, 0.04900342245985355, 0.029751348375741924, 0.06195321240063224, 0.02414544132937278, 0.10149957678679909, 0.035029685856508355, 0.08879397463585649, 0.029634976227368628, 0.12410626693495683, 0.17754141534013407, 0.05759342134531055, 0.06997088396123477, 0.12089934758841991, 0.28465491267187254, 0.21551253353910788, 0.29960276771868977, 0.11174559127539396, 0.14140543581119605, 0.1624648150588785, 0.14093401682163986, 0.1700265043015991, 0.08407493321491138, 0.15207907663924353, 0.11333735979029111, 0.1366650273225137, 0.10729736675109182, 0.24972889678818838, 0.19074221913303646, 0.164889356387513, 0.17952378253851617, 0.13375826472682611, 0.0580981360482318, 0.1944221452410732, 0.1280806093875851, 0.30736623970525606, 0.3222918116620609, 0.18397685858820165, 0.12336413961436067, 0.17712638261062758, 0.27198104560375214, 0.17926142018820557, 0.25365766882896423, 9.067091703414917, 42.73645183018276, 84.59536007472447, 80.44358907427106, 78.14925915854317, 64.92036151885986, 49.362434659685405, 41.57204839161464, 48.27867201396397, 111.57645198277065, 67.23434094020298, 35.2564172744751, 55.027297496795654, 57.53937700816563, 47.536719049726216, 29.15121235166277, 12.25672219480787, 2.5359279002462114, 0.2877134499805314, 0.15668293674077305, 0.25342818828565733, 0.1445100727890219, 0.6166503450700215, 2.0450784904616217, 4.448603255408151, 9.457870551518031, 6.808564117976597, 7.863496082169669, 13.527440888541085, 14.577007974897112, 13.056955780301776, 13.608220645359584, 13.368648494992938, 13.44615912437439, 16.927948338644846, 14.652887514659337, 16.044615166527883, 9.299311791147504, 21.584356580461773, 17.319659982408794, 17.587598153523036, 18.913927623203822, 12.685342669487, 11.435226253100804, 10.297661100115095, 8.001428246498108, 7.131332695484161, 6.570769837924412, 11.845848287854876, 17.14908865519932, 21.40610228266035, 30.378893034798757, 43.8712420463562, 52.22925097601754, 64.27099677494594, 50.7691912651062, 50.92170769827706, 59.854013034275596, 61.518843105861116, 59.26526437486921, 62.546502522059846, 57.16972936902727, 43.98481035232544, 33.328910555158345, 29.66470854622977, 33.151446614946636, 24.771794046674454, 30.674243586403982, 33.653155190604075, 30.39250455583845, 18.562708343778336, 21.63730185372489, 19.213144847324916, 13.79565872464861, 15.664661611829485, 20.174567086356028, 19.58041446549552, 16.166318075997488, 20.53807772908892, 13.90118796484811, 18.7583452974047, 11.768903936658587, 10.32347365788051, 14.763184956141881, 15.680705002376012, 14.896083150591169, 8.235807486942836, 4.3705524035862515, 1.9607490726879664, 0.5973882558090347, 0.49140206298657824, 0.32431561020868166, 0.2854869323117392, 0.29310432927949087, 0.8524383327790669, 3.7848066687583923, 17.60410533632551, 44.95852395466396, 49.272490228925435, 39.00258370808193, 33.035380431583945, 63.67584882463728, 45.61885643005371, 30.203770637512207, 38.61058023997715, 39.45876768657139, 45.384799412318635, 54.50413635798863, 68.33458123888288, 76.40298230307442, 75.80715342930385, 55.26389755521502, 11.90249868801662, 0.8926561889903886, 0.10055449964212519, 0.23733282195670263, 0.09722611574190003, 0.12364323463823114, 0.19312034866639546, 0.16718854515680245, 0.12513632380536624, 0.2097171795155321, 0.21434983664325305, 0.25784227571317125, 0.2656992498253073, 0.23420852103403636, 0.1297395189425775, 0.18711626370038303, 0.2998652793467045, 0.1908712764935834, 0.3876819871366024, 0.2488888432937009, 0.23351133987307549, 0.18763494943933828, 0.1547657089041812, 0.14446647012872355, 0.10282182440693889, 0.10276792837040764, 0.2236621326633862, 0.16012864613107272, 0.11912720410951547, 0.14591421958591255, 0.3309364563652447, 0.31341670932514326, 0.14630998192088945, 0.17537068682057516], [0.06495870862688337, 0.06827123516372272, 0.07210524300379412, 0.02562917349860072, 0.01886803513791944, 0.09587418221469436, 0.09335955179163388, 0.014155686616764536, 0.060559935734740326, 0.039066914934664965, 0.018711734596373777, 0.010689997762840773, 0.03567970544099808, 0.034105829894542694, 0.08732244931161404, 0.06869161474917616, 0.03694547859153577, 0.012986124642858548, 0.030358776317111084, 0.03524773647742612, 0.0480060099091913, 0.045017840074641366, 0.05793064646422863, 0.05998282813067947, 0.062324920669198036, 0.02960166355062808, 0.0479558559932879, 0.1409994140267372, 0.10159198647098881, 1.2571693807840347, 20.07603815623692, 53.97101150240217, 60.73202909742083, 64.47021552494594, 46.728574071611675, 46.15822424207415, 39.74794823782784, 28.262756620134624, 15.437215805053711, 10.63171832902091, 11.903567842074803, 31.94925192424229, 40.70451021194458, 28.646531684058054, 22.49812286240714, 7.687070029122489, 1.130078143307141, 0.14202012068458966, 0.04571366077288985, 0.12364926002919674, 0.18440787760274752, 0.2852389956159251, 1.0807456076145172, 1.5971906610897608, 2.3657393753528595, 4.938007005623408, 4.4961002724511285, 2.9725455343723297, 3.0326496234961917, 4.757387280464172, 5.089557204927717, 2.4796978660992215, 6.536731481552124, 4.308141512530191, 5.234577834606171, 2.561740458011627, 3.345075807401112, 2.3269102360521043, 3.6533193928854804, 5.255144936697824, 6.479273787566593, 3.7049223610333035, 4.267442005021231, 9.48092988559178, 8.39710557460785, 7.13122239283153, 9.661204372133527, 17.482548339026316, 32.01714972087315, 48.52685471943447, 37.840883118765696, 31.04152536392212, 52.64660842078072, 64.51841517857143, 49.46431609562465, 32.86312416621617, 37.94942787715367, 46.21916341781616, 45.31103733607701, 42.96834448405674, 44.20048591068813, 43.72182450975691, 42.71178225108555, 31.894573075430735, 50.37612819671631, 50.616883277893066, 52.766895634787424, 51.02185903276716, 39.143159661974224, 38.83626815250942, 31.37935025351388, 26.853865180696758, 29.8350054195949, 29.7142596244812, 18.995601960590907, 20.612234115600586, 18.94835421017238, 16.377937623432704, 16.768707786287578, 7.325741120747157, 5.014448046684265, 3.9785867163113187, 9.5254157270704, 6.858555104051318, 6.027618731771197, 8.270333954266139, 4.290195184094565, 6.261598450796945, 3.3387142973286763, 1.272303425839969, 0.3711157446461064, 0.40376562838043484, 0.07221077555524451, 0.00917136260042233, 0.026218409916119914, 0.01209317849549864, 0.6451874652079174, 7.993594152586801, 36.026843956538606, 49.205989020211355, 41.957093238830566, 32.84968982424055, 27.54138595717294, 24.38040896824428, 14.083055325916835, 22.521592140197754, 33.77814286095755, 37.153185163225444, 44.061132839747835, 51.13248130253383, 58.13323259353638, 58.47453853062221, 37.70530639375959, 6.667947343417576, 0.35416998394898, 0.1054167662348066, 0.03779692468898637, 0.05429979200874056, 0.0369483759360654, 0.02822767593897879, 0.07185242764119591, 0.02621030142264707, 0.049997062355812104, 0.12165775974946362, 0.018479594195793782, 0.04657343249501927, 0.03578355183292713, 0.04312890375565205, 0.045120370108634233, 0.13615081991468156, 0.06538203983966794, 0.10767776026789631, 0.019680311105081012, 0.17085799468415125, 0.04363151839269059, 0.055104368299778016, 0.039433001540601254, 0.039471766246216636, 0.0905925470537373, 0.16834909788199834, 0.060860547104052136, 0.043184506307755194, 0.02282152960209974, 0.09313662589660712, 0.14971375784703664, 0.10880665933447224, 0.033444835006126335, 0.06664688339723007, 0.02093559071155531, 0.035584405197628906, 0.0643394368567637, 0.11804964978780065, 0.09527500865182706, 0.0564756231116397, 0.03721582729901586, 0.038016037217208316, 0.015864387919594134, 0.046333410910197666, 0.01640523291592087, 0.034613984770008495, 0.02028795617765614, 0.04585553905261414, 0.045119633898139, 0.015298803536487477, 0.007308250476074005, 0.047011525237134526, 0.023827152426487634, 0.012623464638766433, 0.038775918406567404, 0.07199000740157706, 0.04457288734348757, 0.04151729826948472, 0.027692462783306837, 0.12201845539467675, 0.09404324367642403, 1.7866389410836356, 26.71029281616211, 64.9131770815168, 68.75639247894287, 71.9892225265503, 57.336767537253245, 57.5835918698992, 51.896341936928884, 39.493543420519146, 22.287740094321116, 23.201487268720353, 24.080062661852153, 31.139185769217356, 40.700011253356934, 30.90166507448469, 22.4551499911717, 7.293480634689331, 1.0652916197265898, 0.05478383853499379, 0.07666691858321428, 0.28394196235707825, 0.5392429072942052, 0.7846188662307603, 3.44341561623982, 4.8792547753879, 4.004090513501849, 6.404518987451281, 5.130604990891047, 3.425989317042487, 4.768678537436894, 7.60247050012861, 8.4629545211792, 5.731667160987854, 9.42734798363277, 8.691030008452278, 7.454879471233912, 4.200539103576115, 5.338649255888803, 3.440376647881099, 4.018148456301008, 1.32886860200337, 4.032870820590428, 3.903907912118094, 5.116680800914764, 8.511630994932991, 9.231209022658211, 6.894261028085436, 10.71158526624952, 19.689158984592982, 35.27022334507534, 50.96973712103707, 42.44322395324707, 35.77607304709298, 58.76400743212019, 65.28906767708915, 55.20762409482683, 38.19725275039673, 43.43755980900356, 52.886210100991384, 52.810655389513286, 50.58877781459263, 51.11128234863281, 48.60542147500174, 47.108765602111816, 35.380206380571636, 54.188757623944966, 52.822453430720735, 54.49340833936419, 52.8845077923366, 45.206856046404155, 40.542992387499126, 35.97542381286621, 28.84294162477766, 34.46385015760149, 33.465265478406636, 24.476087399891444, 21.279148272105626, 18.27170389039176, 15.984973566872732, 12.766974449157715, 7.644656487873622, 6.84191677400044, 2.9084625158991133, 7.276473181588309, 7.2910626615796765, 9.318781512124197, 10.076664958681379, 5.23239175762449, 5.380661104406629, 4.811926731041499, 3.3238043316773007, 2.4844984199319566, 0.6054632025105613, 0.23642334075910704, 0.0473401159979403, 0.08283151100788798, 0.04793524209942136, 0.5412595676524299, 7.962058884756906, 29.27279887880598, 39.291882378714426, 34.95532751083374, 40.601913111550466, 32.969369070870535, 23.871828624180385, 22.74825280053275, 30.446453843797954, 42.96779557636806, 46.35287455150059, 49.92864683696202, 59.22363771711077, 64.39893395560128, 66.93900775909424, 52.89682000023978, 12.702413524900164, 0.4119728079863957, 0.07022111410541193, 0.03403095694790993, 0.018906514858826995, 0.056474513706884215, 0.027760553772428205, 0.08563402348331042, 0.04736435666148152, 0.0559756038710475, 0.14443569178027765, 0.07565014064311981, 0.1037371681470956, 0.04045564541593194, 0.10591954711292471, 0.03783472587487527, 0.13691957294940948, 0.03886735778568046, 0.0840017328570996, 0.10199837466435772, 0.12724480352231435, 0.04588849889114499, 0.036484420831714354, 0.04603182923580919, 0.04036803636699915, 0.07566533304218735, 0.09939649142324924, 0.048542961810848544, 0.026071617346523062, 0.0577411927016718, 0.09559587429144553, 0.0713519605674914, 0.11667101590761117, 0.18889652245811053, 0.20667129009962082, 0.17409785012049334, 0.1896593315260751, 0.12686547530548914, 0.23828000255993434, 0.24989405221172742, 0.16593032410102232, 0.21094151453248092, 0.2511470078357628, 0.15827023370989732, 0.2021242505205529, 0.10674749554267951, 0.11022173054516315, 0.2271539552935532, 0.17415187507867813, 0.13710494871650422, 0.07783188178603138, 0.1207590401172638, 0.13830729919884885, 0.15002232843211719, 0.08222723486168043, 0.12386318854987621, 0.2043309821082013, 0.18177890724369458, 0.11174175076718841, 0.14891540711479528, 0.2936218072261129, 0.26847920779670986, 2.9830392684255327, 33.89334051949637, 77.60960647038051, 76.45791476113456, 81.27669892992292, 64.99791731153215, 62.61082894461495, 52.75139420373099, 38.88374171938215, 22.635598182678223, 16.729122161865234, 17.051462990897043, 43.2127161026001, 54.191661970955984, 40.30037171500069, 30.315254483904155, 10.361453379903521, 1.9240243690354484, 0.3043670334986278, 0.2461466390107359, 0.4487917737237045, 0.5792613284928458, 0.6640628980738776, 2.846687819276537, 5.938515901565552, 6.948239411626544, 9.826854637690953, 10.573974456105914, 7.7184533051082065, 11.71910011768341, 13.03803322996412, 13.243148394993373, 11.469615493501935, 18.482279470988683, 16.925624166216167, 15.794631140572683, 11.595633234296526, 10.310977322714669, 9.513946856771197, 8.484476566314697, 13.199185405458723, 13.17983032975878, 10.524914962904793, 11.055706092289515, 15.124256781169347, 14.131056087357656, 11.165831565856934, 12.84744848523821, 21.984277520860942, 37.59686238425118, 53.60929523195539, 46.53887087958199, 40.88470826830183, 65.00027275085449, 64.88223675319126, 59.125362396240234, 40.28546435492379, 47.908520630427766, 57.368315832955496, 58.49332645961216, 58.41049698420933, 55.31657184873308, 51.96008818490164, 51.71483414513724, 38.51511199133736, 57.390174865722656, 53.73231308800833, 54.46693917683193, 56.109375204358784, 45.383882250104634, 42.29199641091483, 42.0098682812282, 36.4462684903826, 37.8712363243103, 37.77813046319144, 25.7980568749564, 28.641931976590836, 26.36918490273612, 22.12319459233965, 26.716407230922155, 14.618584258215767, 11.033167004585266, 12.167690583637782, 19.392840896333965, 16.126122747148784, 14.088598251342773, 16.3300176348005, 14.28014966419765, 13.43600172655923, 9.350770149912153, 4.415456005505153, 2.3402611996446336, 0.816370505307402, 0.22070328571966716, 0.2042522991874388, 0.11125681536006075, 0.17644259573093482, 1.2373317309788294, 10.477587308202471, 45.48764317376273, 62.082508768354145, 55.46509306771414, 43.31621299471174, 38.669692039489746, 35.17684303011213, 23.791851384299143, 34.23754038129534, 46.22954750061035, 50.09634508405413, 60.21501364026751, 69.03445243835449, 72.54164600372314, 77.09622492109025, 65.76904923575265, 15.664399317332677, 0.6182085328868457, 0.22243108014975274, 0.0925097545342786, 0.15567004680633545, 0.28020852697747095, 0.18765884744269506, 0.22444727910416468, 0.18356128303068026, 0.11617734096944332, 0.23753863519855908, 0.25907251398478237, 0.12708982612405503, 0.15937925848577703, 0.22016444749065808, 0.22546476950602873, 0.3389076686331204, 0.24803682044148445, 0.3333364890090057, 0.1690631474235228, 0.28271956795028275, 0.1214760345007692, 0.17124489535178455, 0.14902224923883164, 0.17416171383644852, 0.15018873236009053, 0.25295174813696314, 0.12127091336463179, 0.10187828075140715, 0.10628613244209971, 0.34659082921487944, 0.2602492022727217, 0.23398902852620396], [0.042182625603995154, 0.11262852139770985, 0.11461797250168664, 0.04752117967499154, 0.094262939744762, 0.0175940008235297, 0.039422134802277596, 0.08535468418683324, 0.04620916436293295, 0.1401555064533438, 0.02921971958130598, 0.02964549691283277, 0.020807004932846342, 0.03007185099912541, 0.03295969603849309, 0.03754066236849342, 0.06451527920684644, 0.030668968600886207, 0.04365157249516674, 0.011824665225243993, 0.08275164065084287, 0.027981673067967807, 0.035250867916537185, 0.0510294398159853, 0.004827017546631396, 0.05608752143702336, 0.10748376710606472, 0.04913105150418622, 0.15877038187214307, 13.973968608038765, 57.01647295270647, 66.77451610565186, 62.530167307172505, 53.49188804626465, 44.91465997695923, 23.896763971873693, 17.288530315671647, 14.54274206502097, 24.438428163528442, 26.908038548060826, 29.748750482286724, 36.38827187674386, 31.490069798060826, 23.00458574295044, 4.001950902598245, 0.7382130420633725, 0.045498042700013945, 0.06323034422738211, 0.10678786837628909, 0.06200623991233962, 0.22623582955982002, 1.5278127895934241, 1.4099983743258884, 2.06116053036281, 3.100501388311386, 5.356756261416844, 3.7536301016807556, 2.8557441447462355, 1.6309402329581124, 5.646288565226963, 2.109351933002472, 3.740219209875379, 6.530000414167132, 4.673612415790558, 3.4829732307365964, 2.3615702390670776, 6.588095605373383, 4.828498184680939, 6.27370525257928, 9.94857839175633, 15.8692877973829, 16.84829592704773, 17.95294485773359, 39.113706248147146, 45.80672182355608, 50.72326019832066, 46.26627567836216, 55.468553270612446, 55.800215108054026, 60.29416751861572, 51.08887440817696, 42.94110754558018, 52.9044143812997, 64.10731806073869, 47.05755737849644, 31.85196324757167, 38.55724586759295, 39.59128720419747, 37.6650242124285, 35.94882263456072, 38.568821566445486, 59.455645016261506, 42.030855315072195, 38.84756244931902, 59.81998075757708, 61.624233382088796, 55.27298927307129, 59.1393004826137, 59.09427615574428, 46.94242572784424, 46.47306449072701, 51.18964065824236, 48.5093799999782, 39.8238434110369, 42.63070024762835, 43.04350314821516, 40.38313170841762, 32.91601732798985, 22.84936993462699, 19.73171148981367, 15.12903366770063, 6.992900260857173, 13.618428417614528, 9.806542447635106, 8.281041996819631, 4.852357864379883, 3.0342396753174916, 5.575914604323251, 3.0476599037647247, 0.8004711813160351, 1.273191926734788, 1.1628164265836989, 0.35447280055710245, 0.3488006006394114, 0.10035324615559407, 0.18604363554290362, 0.07056764872478587, 0.3217873344463961, 5.205234723431723, 36.02030917576381, 48.53056158338274, 26.264428649629863, 23.029868500573293, 28.262199027197703, 19.928844043186732, 15.131305728639875, 12.27251284463065, 22.04666539600917, 32.65718303407942, 44.0792989049639, 53.5930746623448, 57.75105735233852, 60.44528388977051, 50.80841384615217, 8.353715811456953, 0.0767374455130526, 0.05986525158264807, 0.04770902530955417, 0.045924291613378694, 0.05969823697315795, 0.0026080437029512332, 0.09312432405671903, 0.05983253262404885, 0.25258851477078026, 0.04317174306405442, 0.03516670921817422, 0.04661483670185719, 0.025310105976781676, 0.014993301626028759, 0.06379510249410357, 0.030872708918260675, 0.04018405159669263, 0.04743323814389961, 0.06827857012727431, 0.06827493317957435, 0.01869647773647947, 0.07932026192013707, 0.03185002326167055, 0.07852488317127738, 0.05719917892877545, 0.03206766676157713, 0.027759943090911423, 0.040219355773712905, 0.060597105883061886, 0.04657706605004413, 0.07576129824987479, 0.05024797782035811, 0.030819148756563663, 0.03517555731481739, 0.03751695096226675, 0.0808052968766008, 0.08704547131700174, 0.05766164804143565, 0.05404200637713075, 0.05939111166766711, 0.12785340872194084, 0.06932641140052251, 0.027775810632322515, 0.02503110425147627, 0.08821514355284826, 0.06224785266177995, 0.024759875144809484, 0.010028010516959642, 0.021177910833752582, 0.016015087154560854, 0.0708577088745577, 0.05961933692118951, 0.03055839453424726, 0.04752458931346025, 0.01495801780505904, 0.10713148529508285, 0.06697638000228576, 0.058550868183374405, 0.053679692425898144, 0.14687948993274144, 18.745364325387136, 66.58372552054269, 75.26194218226841, 67.8303782599313, 62.13454382760184, 53.56726210457938, 36.11502007075718, 29.717386313847133, 23.18317355428423, 25.762164218085154, 26.461997202464513, 20.165397201265606, 30.617105075291224, 32.16065781457083, 19.648176772253855, 4.796759682042258, 0.4815635766301836, 0.038268998464835544, 0.03416946630126663, 0.30362520473343985, 0.44526439585856026, 1.606627183301108, 3.4292506277561188, 4.840906364577157, 5.840354791709355, 8.060723304748535, 6.895659787314279, 7.5451409135546, 7.547662241118295, 7.453250987189157, 9.583503535815648, 5.6717042071478705, 8.231986846242632, 8.54586216381618, 8.987030216625758, 5.954055113451822, 4.12411847284862, 3.4637393142495836, 5.570519762379782, 7.5954267638070245, 10.150744046483721, 16.036246061325073, 19.90665670803615, 23.679259300231934, 41.32978902544294, 49.91654307501656, 54.13857773372105, 49.029258114951, 57.711459568568635, 56.07903242111206, 61.53221838814871, 56.62624822344099, 47.40208727972848, 58.50479098728725, 64.29594775608608, 50.064845425742014, 38.02409321921212, 42.85849346433367, 47.144548824855256, 41.97150380270821, 43.525836672101704, 47.975793089185444, 62.5088780266898, 44.80564968926566, 40.64949437550136, 61.789690835135325, 58.31144346509661, 55.92593928745815, 60.49435206821987, 57.136287689208984, 49.963505949292866, 50.84901564461844, 55.29675211225237, 51.53795037950788, 44.30047048841204, 45.73549236570086, 45.195957796914236, 42.25806488309588, 32.629998207092285, 23.762005397251674, 18.175789219992502, 11.240866030965533, 7.73006808757782, 5.158275323254721, 3.8965636662074496, 3.946725751672472, 6.33975178854806, 6.707806118897029, 8.15158576624734, 6.41702400786536, 5.286920785903931, 3.44813192316464, 3.647171105657305, 1.725989961198398, 0.758709250816277, 0.3302854427269527, 0.17250929107623442, 0.024175817645820122, 0.1520176420786551, 5.6200421793120245, 27.38368443080357, 42.842919077192036, 29.03913790839059, 24.425613948277064, 30.469230038779124, 24.021980932780675, 19.702039207730973, 19.79531008856637, 30.916954585484095, 40.54198489870344, 50.92633172443935, 61.495511054992676, 64.33211312975202, 69.0332226072039, 63.832634925842285, 13.512831432478768, 0.03932516197008746, 0.16990799137524196, 0.06902582717261144, 0.029907699807413986, 0.031800008445445976, 0.0861404820212296, 0.05754741667104619, 0.04708610302103417, 0.14019083098641463, 0.095154351554811, 0.07786498072424106, 0.02677164156921208, 0.0379210117805217, 0.04906834808311292, 0.06293263020259993, 0.05502819595858455, 0.029456524910139184, 0.03430710034444928, 0.04633141940991793, 0.01221611038116472, 0.025374283515182987, 0.05520038100491677, 0.016788070855130042, 0.006959688733331859, 0.1392302561019148, 0.018879454882283295, 0.07520757974790675, 0.06118704458432538, 0.07404037059417792, 0.10065566242805549, 0.2460244484245777, 0.1181025890899556, 0.19724409095942974, 0.2138112291161503, 0.09731258824467659, 0.23605424485036305, 0.20351545086928777, 0.19830352839614662, 0.2600859467472349, 0.22753648619566644, 0.2679816787796361, 0.09729749084051166, 0.1400061473250389, 0.13729565776884556, 0.15460110987935746, 0.18633145652711391, 0.1793786846101284, 0.09513297091637339, 0.17755145765841007, 0.1938233652285167, 0.09598498019788947, 0.18911977404994623, 0.07836633667882, 0.10446945670992136, 0.1377592193228858, 0.25256870154823574, 0.25579494557210375, 0.1866863981953689, 0.2503020688891411, 0.2937639467418194, 25.31669088772365, 78.59868948800224, 83.19071224757603, 79.70158399854387, 69.24207850864956, 60.62802151271275, 38.481454917362754, 26.56075542313712, 22.024220977510723, 36.10510151726859, 38.52035093307495, 42.59064735685076, 50.49470615386963, 40.72223506655012, 28.99285422052656, 5.749077609607151, 1.4213129729032516, 0.2301028413431985, 0.21304947856281484, 0.33297558980328695, 0.4405257787023272, 0.865249508193561, 4.0976084896496365, 6.676595679351261, 7.888784919466291, 11.098791003227234, 12.761197890554156, 8.15470290184021, 10.05220469406673, 8.605790376663208, 12.525150213922773, 10.095102872167315, 14.816290037972585, 13.247907042503357, 13.369516151291982, 11.180056265422277, 9.338627304349627, 14.705504485539027, 11.638570496014186, 12.781648176056997, 14.8757301398686, 20.209023203168595, 21.830465248652867, 27.25495341845921, 44.70351116997855, 50.13194417953491, 55.88221079962594, 50.817456926618306, 58.39643383026123, 57.50523703438895, 60.74158981868199, 60.26556178501674, 49.36615889413016, 62.34799943651472, 65.2336071559361, 53.276792662484304, 41.03589064734322, 46.58864777428763, 52.605561937604634, 49.57878419331142, 48.82744768687657, 52.90589782169887, 63.591310092381065, 51.950649057115825, 43.396770409175325, 62.36426516941616, 58.17546027047293, 56.13257871355329, 59.87226595197405, 56.30956322806222, 53.923148836408345, 56.917947496686665, 57.07630041667393, 53.0285439491272, 46.14600583485195, 45.983727182660786, 47.699772426060264, 44.34724923542568, 39.66266604832241, 30.486805507114955, 24.39256831577846, 25.748226131711686, 13.985439215387617, 20.642325026648386, 19.182386909212383, 17.959196499415807, 11.75903228351048, 10.754829117230006, 15.99794932774135, 10.741690942219325, 6.243663847446442, 4.22083956854684, 4.0633929542132785, 1.6599858743803841, 1.1274829911334174, 0.33264313478554997, 0.6430156103202275, 0.18301495377506527, 0.525330876665456, 7.634772675377982, 45.64514146532331, 61.516063826424734, 37.08932774407523, 33.01288216454642, 41.941664763859336, 30.648952143532888, 24.833224807466777, 21.295572076525005, 32.79731430326189, 45.856425762176514, 57.06466565813337, 71.01270880017961, 72.22300161634172, 76.58656065804618, 74.37551185062954, 17.191761016845703, 0.19875892038856233, 0.2323592688356127, 0.13696557762367384, 0.13505026325583458, 0.1525456780301673, 0.17860410974494048, 0.21850857777254923, 0.15832982265523501, 0.3544448177729334, 0.2170707756387336, 0.22792561245816095, 0.10613714650805507, 0.1418219341763428, 0.1535485934998308, 0.1659970512347562, 0.14166802886341298, 0.20044703409075737, 0.1069673408887216, 0.14374323322304658, 0.11331629127796207, 0.18539034202694893, 0.12281215137669019, 0.1774162527705942, 0.11866339828286852, 0.2047586084476539, 0.1421427455331598, 0.1495985561715705, 0.17268682297851357, 0.30725457998258726, 0.2317484516118254, 0.3582240678369999], [0.018909541125010167, 0.05690066762534635, 0.006234196546886648, 0.022133269480296543, 0.04985641561714666, 0.02831592450716666, 0.08697911059217793, 0.061209850146302154, 0.043008565570094755, 0.019118523125403693, 0.033439708674060445, 0.01549133106267878, 0.029126631362097602, 0.06399090055908475, 0.02503305334331734, 0.05103484774008393, 0.04950486323130982, 0.023704364729513015, 0.024684128584340215, 0.040672664663621357, 0.07604547550103494, 0.05258097120427659, 0.03542814197550927, 0.02889751044235059, 0.028258489910513163, 0.06317359834377255, 0.07358864269086293, 0.07388382578002554, 4.735632036413465, 46.8420798437936, 70.1562113080706, 56.33415985107422, 53.31031772068569, 41.68393175942557, 30.15994140080043, 26.125428199768066, 21.109851939337595, 18.767732313701085, 21.109982218061173, 28.24917984008789, 40.806944029671804, 43.78725222178868, 25.587255477905273, 4.25708006961005, 0.30283088449920925, 0.0797910023746746, 0.2726589020873819, 0.07297450064548425, 0.13507979309984616, 0.2778164196227278, 0.35074577054807116, 2.397683718374797, 3.7371871897152493, 6.361472725868225, 3.6038762288434163, 4.996770092419215, 4.058323374816349, 3.3126305426870073, 4.4103065218244275, 9.282961811338152, 7.788328732763018, 4.784274637699127, 8.765280195644923, 8.368644884654454, 8.325881327901568, 6.377741064344134, 9.746997254235403, 20.26829481124878, 29.5485520362854, 28.55876898765564, 42.169319016592844, 52.45300381524222, 53.993627888815745, 56.88508946555001, 62.60638904571533, 63.007821219308035, 60.826559339250835, 55.763400077819824, 58.397837366376606, 61.20292936052595, 55.78016608101981, 62.9070862361363, 60.77088342394148, 57.05840880530221, 55.535787514277864, 45.270303521837505, 34.24664599554879, 35.99486834662301, 32.71517617361886, 28.286722694124492, 53.777934959956575, 62.251044273376465, 49.76311642783028, 55.97444813592093, 63.062711988176616, 55.26960550035749, 56.13523987361363, 58.26612383978707, 51.16768087659563, 54.795432635716026, 57.04313319069998, 53.27444417136056, 50.36076920373099, 53.24322591509138, 54.6644868850708, 57.08230366025652, 57.18911484309605, 55.28880337306431, 50.371149812425884, 35.681278773716514, 27.189725467136928, 16.05113778795515, 12.164692435945783, 7.362761122839792, 7.316025802067347, 6.297788143157959, 3.3595823432718004, 1.9033339364188058, 2.910709172487259, 4.700267442635127, 3.4834255150386264, 1.818251833319664, 1.418490158660071, 0.3560687963451658, 0.24619155802897044, 0.20361531765333243, 0.06769096558647496, 0.11756927413599831, 0.33115961296217783, 4.589815837996347, 22.676785366875784, 53.75559997558594, 56.83945369720459, 31.941299710954937, 27.745334693363734, 28.649783440998622, 25.100977114268712, 19.385163136890956, 19.48118029321943, 32.946849959237234, 37.43208238056728, 43.01350777489798, 54.3004082271031, 58.852902684892925, 43.374390261513845, 7.815450157438006, 0.1546052082308701, 0.04534973530098796, 0.05201788213370102, 0.05128301174512931, 0.029973571987024376, 0.05859798565506935, 0.09348508077008383, 0.047026168022836955, 0.013065615868461984, 0.03571196299578462, 0.015318699879571795, 0.011442013034996177, 0.026625284958364706, 0.05108826880210212, 0.014180784778935569, 0.04027095836188112, 0.07556087936141662, 0.09318461189312593, 0.04952235925676567, 0.008307675731235316, 0.050490811932832, 0.03432142421869295, 0.10329016963286058, 0.016728254600561092, 0.05081345533419933, 0.00422456326694893, 0.0566004803404212, 0.03806097998416849, 0.05748045205005577, 0.06786444663469281, 0.007911566495230156, 0.03337073898208993, 0.026443442662379572, 0.030799091261412417, 0.08753846772015095, 0.06529134684907538, 0.024632670184863464, 0.09819326563073055, 0.023110658462558473, 0.029143319930881262, 0.047787402889558246, 0.025224237370171716, 0.07852064911276102, 0.010344382558417107, 0.02202338582303907, 0.004378429140030805, 0.04642616664724691, 0.023802441877446005, 0.03837274646918688, 0.028270401592765535, 0.1313347683421203, 0.03206412820145488, 0.04600829764136246, 0.0660657724365592, 0.05847646003322942, 0.05570780306256243, 0.06395506033939974, 0.07811411842703819, 6.8565023456301, 55.79825224195208, 77.60234560285295, 63.54605647495815, 62.10685525621687, 50.37584679467337, 41.744909150259836, 35.285801206316265, 23.920247146061488, 23.861705098833355, 21.0967024735042, 22.960190228053502, 32.693351881844656, 39.35078920636858, 20.007674830300466, 3.990172403199332, 0.07644148210861854, 0.11166103224137, 0.21729758275406702, 0.21692305856517383, 0.651114712868418, 1.7991113918168204, 4.695616492203303, 7.6153550658907205, 8.885388493537903, 8.30372873374394, 9.064048392432076, 11.44942489692143, 8.101834058761597, 8.36464706489018, 6.6609435592378885, 9.380350368363516, 8.372324824333191, 6.594957820006779, 8.947237014770508, 10.110013706343514, 6.480073264666966, 7.320126107760838, 9.53466464791979, 20.304534878049576, 30.794211183275493, 32.78552668435233, 44.9934594971793, 53.79803262438093, 59.0651284626552, 59.272914341517854, 61.72181388310024, 61.28104100908552, 61.92056710379464, 56.47194957733154, 58.73557540348598, 60.03080299922398, 60.094392912728445, 66.55819089072091, 63.18013654436384, 58.40331254686628, 57.67147963387625, 49.24360309328352, 40.70737286976406, 42.373321601322715, 39.85875116075788, 36.666912010737825, 56.27594436917986, 61.91938591003418, 52.78367900848389, 56.9500481741769, 62.07282297951834, 55.87128823144095, 56.55878816332136, 58.80446679251534, 53.093026706150596, 55.774941035679404, 58.471495219639365, 55.63504947934832, 53.09483323778425, 51.71323953356062, 54.827547209603445, 57.4471709387643, 57.591870648520334, 55.73385286331177, 49.939381803785054, 36.702028206416536, 26.844782148088726, 16.15572033609663, 13.549313817705427, 8.853484102657863, 6.957459236894335, 5.783528515270778, 2.678237646818161, 4.717375644615718, 4.115179181098938, 6.087889143398829, 3.6505327309880937, 4.722556395190103, 4.515972554683685, 2.30509614944458, 0.7943512839930398, 0.6725759612662452, 0.09788385366222688, 0.1365039838211877, 0.17903317457863263, 4.116461992263794, 20.01375276701791, 47.21831437519619, 42.79994099480765, 33.379323210035054, 25.331353323800222, 20.953442777906144, 25.721109049660818, 25.86202199118478, 33.37239933013916, 45.89821917670113, 46.8662873676845, 50.14990874699184, 61.53241293770926, 64.79411275046212, 55.29775265284947, 12.012722304889135, 0.19656608519809587, 0.04330877999642065, 0.03319431309189115, 0.07195941904293639, 0.04557529730456216, 0.027308305093486394, 0.09739273680107934, 0.04054468617375408, 0.05091734243822949, 0.020550391470481242, 0.07110740976142031, 0.01030779764654913, 0.01908863365783223, 0.024160654084490876, 0.027090480085462332, 0.0368685530764716, 0.09879144853247063, 0.04605000718895878, 0.031177985215825692, 0.08436403663030692, 0.07336405438504048, 0.03567674702831677, 0.043596882572663684, 0.01716531427311046, 0.058386316656001976, 0.05701607625399317, 0.041758836380073, 0.06508041745317833, 0.0398410283960402, 0.04891736386343837, 0.11241366328405482, 0.08353633247315884, 0.1711095818983657, 0.11319462994911841, 0.20684146668229783, 0.17049340424793108, 0.1527206857821771, 0.23847311362624168, 0.15786080567964486, 0.13811363173382624, 0.1278817986271211, 0.09218016293432031, 0.18041199844862732, 0.14250072703829833, 0.13265639171004295, 0.1011481499299407, 0.09986178324158702, 0.18519379757344723, 0.08200076701385633, 0.11651214371834483, 0.23517418493117603, 0.18562135605939797, 0.13647604174911976, 0.09033779108098575, 0.13580269073801382, 0.11905850922422749, 0.18157734163105488, 0.19162164122930594, 10.691531028066363, 67.40230669294084, 86.30804239000592, 72.99342482430595, 68.82640947614397, 57.63478619711739, 43.384044783455984, 36.97726024900164, 30.63492373057774, 29.16637679508754, 34.34703009469168, 37.705771923065186, 52.0711099760873, 56.354608399527415, 33.14995970044817, 5.503047977175031, 0.5415013432502747, 0.21399963114942822, 0.48981363964932306, 0.36547777003475596, 0.5202448495796749, 1.6471792587212153, 6.14904762165887, 11.286804914474487, 16.23907266344343, 16.63267421722412, 8.061360801969256, 12.920085821832929, 10.448456117085048, 9.263895085879735, 11.617493135588509, 18.049328531537736, 18.47341009548732, 10.693208149501256, 21.01963652883257, 18.750724860600062, 16.828648158482142, 12.571638005120413, 14.005293692861285, 25.77387888090951, 35.84082678386143, 33.36382525307791, 45.76788486753191, 54.641748905181885, 58.99948188236782, 65.381714957101, 61.60228402273995, 61.101582935878206, 61.08617877960205, 56.24492413657052, 59.49786227090018, 62.997899191720144, 60.51236874716622, 64.57718304225376, 62.812882559640066, 59.59815256936209, 58.9343911579677, 53.22556012017386, 44.76594420841762, 47.81738805770874, 43.77848359516689, 42.83654063088553, 57.96468666621617, 63.03357819148472, 53.387077944619314, 58.49400738307408, 66.1480039869036, 58.567838941301616, 59.855583327157156, 59.43910135541643, 56.877231052943635, 58.326917103358674, 58.90081051417759, 56.99064302444458, 54.614901065826416, 53.91682597569057, 56.17685610907418, 58.29870741707938, 61.10947608947754, 60.745258467538015, 55.56160354614258, 42.22841344560896, 33.13405179977417, 21.02312105042594, 19.09573245048523, 14.091432247843061, 14.379540170942034, 14.245832511356898, 9.714088848658971, 8.907574960163661, 9.092292819704328, 11.593629547527858, 8.218865173203604, 5.229581645556858, 4.9637088264737805, 2.0237110427447726, 0.36191065715891974, 0.5897928976586887, 0.22647114550428732, 0.3238980126168047, 0.6841346696019173, 6.080752040658679, 30.41915089743478, 69.28086335318429, 71.40383679526192, 45.27643878119332, 39.12646314076015, 42.2868686403547, 36.01575115748814, 29.64056703022548, 33.12343495232718, 47.60567992074149, 51.74151175362723, 60.278923170907156, 71.08956282479423, 74.10278115953717, 66.96725913456508, 17.05978693280901, 0.2892766318150929, 0.14243851894778864, 0.19150884156780584, 0.19602797978690692, 0.1815455047679799, 0.16681474021502904, 0.2827190251222679, 0.13769021231148923, 0.16713749218199933, 0.14187027301107133, 0.11691390430288655, 0.10697701001273734, 0.06824923027306795, 0.1373077356921775, 0.17165155495916093, 0.12348137689488274, 0.2017942110874823, 0.17990590631961823, 0.14574967484389031, 0.18989747017621994, 0.16755484550126962, 0.1386659185269049, 0.1867832387132304, 0.0782798370346427, 0.2572323541556086, 0.11529528615730149, 0.14085120840796403, 0.19037054479122162, 0.2930471423481192, 0.2587299352245671], [0.022656280879995654, 0.025978295032733252, 0.039431223778852394, 0.01952694183481591, 0.013968311715871096, 0.052634480475847206, 0.01667037047445774, 0.10533239719058786, 0.039207314008048604, 0.020254981072087373, 0.035571122874638865, 0.02193462156823703, 0.05246711302814739, 0.036553268387381516, 0.04252747745652284, 0.087515546807221, 0.04678133901740823, 0.0076109729374625856, 0.03671175381168723, 0.022152726471956288, 0.05587431216346366, 0.03378760714882186, 0.02468881556498153, 0.029256089058305536, 0.048688487216298065, 0.05530350136437586, 0.05320665852299758, 1.5915718483073371, 22.778277703693934, 61.32559980664934, 64.08037294660295, 62.45953886849539, 45.05631637573242, 31.197435992104666, 17.777422939028057, 12.755317108971731, 26.747557742255076, 21.920020580291748, 42.94948707308088, 47.43062353134155, 38.94894361495972, 19.110075269426616, 3.8603088344846452, 0.09842394718102046, 0.10752014336841446, 0.18249375745654106, 0.10007235301392418, 0.07504872112934079, 0.5546522747193063, 1.3022005472864424, 3.759364971092769, 5.467605650424957, 5.80951304095132, 4.115403260503497, 10.85286385672433, 5.741794160434178, 9.837990862982613, 10.537008302552358, 9.081026315689087, 9.762688892228262, 2.8423362927777425, 8.52196991443634, 11.24006003992898, 17.386805636542185, 16.912617138453893, 23.45001564707075, 25.18510937690735, 38.22030339922224, 49.940316336495535, 53.992401531764436, 57.521058082580566, 54.71730361665998, 56.45951230185372, 57.292510986328125, 57.74739217758179, 58.24893052237374, 56.5441517829895, 62.18473066602434, 61.0144316809518, 62.42801489148821, 60.57261657714844, 62.29548495156424, 62.1125180380685, 62.5455436706543, 59.79038143157959, 53.18030650275094, 30.74399307795933, 31.952653067452566, 31.34131928852626, 30.259377070835658, 63.946488107953755, 56.13657392774309, 56.83526740755354, 54.92154938834054, 55.19201149259295, 55.82956429890224, 56.8343745640346, 55.10651738303048, 51.502208845955984, 52.19890819277082, 49.57173524584089, 50.76663780212402, 52.895385197230745, 51.720681054251536, 55.69386945452009, 59.07241712297712, 55.68018845149449, 53.3684116091047, 53.584556170872276, 56.65863725117275, 46.645702907017295, 41.405878748212544, 32.85443891797747, 26.883313383374894, 19.052502495901926, 19.972633327756608, 14.900385822568621, 11.383873854364667, 4.915880901472909, 5.820601497377668, 2.5223539429051534, 4.943776181765965, 3.118578212601798, 2.0875845296042304, 0.7909945983971868, 0.2281411423214844, 0.10997755293335233, 0.029965171723493507, 0.1350921695785863, 0.28358939556138857, 3.090402181659426, 12.788860406194415, 41.5517110143389, 52.48524693080357, 50.63590049743652, 31.200312546321324, 30.78561278751918, 21.11262948172433, 9.662428992135183, 14.539365240505763, 26.56662491389683, 40.75902925218855, 45.64417913981846, 52.112007072993684, 57.246711935315815, 44.870101179395405, 6.865794692720685, 0.15552124407674583, 0.022708048012905886, 0.07791502268186637, 0.10845257262034075, 0.010444847301446965, 0.03361084199111376, 0.04741092791248645, 0.01047029999816524, 0.05436447335939322, 0.0438824270718864, 0.06810129606830222, 0.029668407647737434, 0.0929099680589778, 0.06597017363778182, 0.02332437494104462, 0.059717473440936635, 0.11234306850071464, 0.013903130793810954, 0.02982431124629719, 0.10122143171195473, 0.05749676403190408, 0.08651387305664164, 0.05640365768756185, 0.09750629642180034, 0.020397948400516595, 0.04557726166344114, 0.017272555036470294, 0.03288565429725817, 0.033136216923594475, 0.09454130195081234, 0.043067143498254676, 0.008971510288704718, 0.035551927118961296, 0.04795917742220419, 0.050867867057344744, 0.041984456059123786, 0.01304069666990212, 0.032855639300708256, 0.03958349721506238, 0.028584139222013097, 0.07430594920047692, 0.06998878371502672, 0.023084577272779176, 0.028969445332352604, 0.05267524007441742, 0.022083174936207275, 0.03181436285376549, 0.11210509269897427, 0.015648327102618556, 0.02959454232560737, 0.01689551687533302, 0.07918517238327435, 0.0093279489748446, 0.03552540657775743, 0.039607005060783455, 0.04000245526965175, 2.058210802929742, 28.58313458306449, 69.66698864528111, 72.04255689893449, 70.06375857761928, 52.70936802455357, 41.5053700038365, 24.508750881467545, 22.464147908346995, 33.80718285696847, 20.297152417046682, 34.14765501022339, 34.540978636060444, 40.05145250047956, 20.54019171851022, 2.7125220128468106, 0.11533093638718128, 0.044340733372207196, 0.14880950136908463, 0.1656611899712256, 0.8433605656027794, 2.22733017376491, 3.6172560708863393, 6.792466010366168, 7.3841476781027655, 7.824263947350638, 8.249024697712489, 13.395128079823085, 11.648854698453631, 10.930036629949297, 12.767447795186724, 8.99841136591775, 7.508886081831796, 6.134769507816859, 6.671512637819562, 8.762936915670123, 12.390396850449697, 15.258706160954066, 20.388813052858623, 29.237144197736466, 39.57140493392944, 51.968613624572754, 55.72984375272478, 58.76972579956055, 55.25552845001221, 58.93623243059431, 59.79595388684954, 61.13603210449219, 59.495124680655344, 58.22643920353481, 63.538455145699636, 60.49135739462716, 62.332630021231516, 61.10102013179234, 63.11810997554234, 63.79970741271973, 62.75876304081508, 60.09437206813267, 54.9419458253043, 37.14099107469831, 37.52204418182373, 36.789005756378174, 36.198030199323384, 63.29519871303013, 55.73440524509975, 57.36753763471331, 56.24554600034441, 58.67054026467459, 56.59774671282087, 56.108885356358115, 57.81802756445748, 56.52632965360369, 56.23484924861363, 52.597620146615164, 53.46789591653006, 52.83204541887556, 52.50723450524466, 55.57464184079851, 59.78309971945626, 57.39291593006679, 55.41882848739624, 56.909046854291645, 58.061593191964285, 49.39760991505214, 41.29159477778843, 33.053046226501465, 26.73744637625558, 19.88190722465515, 16.272792271205358, 10.250926647867475, 9.26638514654977, 3.28283297589847, 3.9793093289647783, 4.667747267654963, 5.920834038938795, 6.242193000657218, 4.881831688540323, 3.7209805165018355, 1.1511090376547404, 0.7690091409853527, 0.16696540213056973, 0.025273804353283982, 0.09859247492360217, 2.637330127613885, 12.802550094468252, 39.699314321790425, 45.8636588369097, 38.82846532549177, 32.1073442867824, 24.799849135535105, 17.69950062888009, 16.757790429251536, 25.959051847457886, 38.903974873679026, 51.87295082637242, 55.758178506578716, 61.65184552328927, 63.994069371904644, 55.2161078453064, 9.601310900279454, 0.10843564995697566, 0.06345413864723273, 0.06833281221666507, 0.11280588366623436, 0.013594897779902177, 0.07265126691865069, 0.06667747854122094, 0.04099051082240684, 0.04416564080332007, 0.06321684816586119, 0.018047185880797248, 0.01261155550102038, 0.09863446267055613, 0.08729899914136954, 0.03726499394646712, 0.03265091510755675, 0.031676613459629674, 0.055284091870167425, 0.06083215719887188, 0.07100551415766988, 0.06616219226270914, 0.029857396613806486, 0.07498886755534581, 0.02462794927747122, 0.052211912614958625, 0.03961514748100724, 0.06035810549344335, 0.012592576028380011, 0.08523314499429294, 0.1711286080202886, 0.08708948788366147, 0.16267745436302253, 0.10486622327672583, 0.10993749901120152, 0.14086073503962585, 0.09438736949648176, 0.24264257560883248, 0.1450471875390836, 0.11830785950379712, 0.15560804227633135, 0.09811019937374763, 0.1861280317285231, 0.10058001934417657, 0.14417214877903461, 0.2246795009289469, 0.11101204063743353, 0.11220031830349139, 0.2227756402322224, 0.0649427291271942, 0.2163746937045029, 0.15455244534782, 0.20628768711217813, 0.0964469336239355, 0.16040239429899625, 0.0879139079313193, 0.20929757345999989, 2.6097657552787235, 36.954438890729634, 80.44080284663609, 80.99945190974644, 79.33051545279366, 60.776087624686106, 45.92547695977347, 28.309639590127126, 21.732441799981252, 36.66182245526995, 32.33425508226667, 55.63025522232056, 62.83593668256487, 49.20334870474679, 25.049793209348405, 4.465356230735779, 0.22309322176235064, 0.1695500234408038, 0.3327881512897355, 0.167577345722488, 0.878348382455962, 2.0195764303207397, 4.50238014119012, 13.18895070893424, 12.666590350014822, 14.455808809825353, 11.59008422919682, 22.55557577950614, 15.520291941506521, 20.98813339642116, 21.889747279030935, 19.604111296789988, 19.490906034197124, 9.24657496384212, 16.582334518432617, 21.03451783316476, 25.165788173675537, 23.20151332446507, 30.655473027910503, 30.732976709093364, 44.08495821271624, 54.50898272650582, 57.69940791811262, 63.87868063790457, 60.32120295933315, 58.78301770346505, 57.631951332092285, 60.757119042532786, 59.43380682809012, 58.05580881663731, 65.38760008130754, 63.62476566859654, 64.24404471261161, 63.20889513833182, 60.767715045383994, 63.852409499032156, 64.46905517578125, 61.8377445765904, 57.35875163759504, 41.01982293810163, 41.23550197056362, 41.50781576974051, 41.55751623426165, 63.851158823285786, 56.830976894923616, 57.225752694266184, 55.12657683236258, 57.91480207443237, 57.73767512185233, 57.307328019823345, 57.807511465890066, 56.38923822130476, 57.77300671168736, 54.68596376691546, 54.72388008662632, 55.36641822542463, 52.71888358252389, 58.09626122883388, 62.463666098458425, 59.487321853637695, 58.657234464372905, 57.12102597100394, 60.56218038286482, 51.64619289125715, 45.17398064477103, 36.4492631639753, 31.71738706316267, 23.680796589170182, 28.012049981525966, 20.689286163875035, 18.24346467426845, 11.231707436697823, 13.366915787969317, 7.660717248916626, 9.415717567716326, 8.891904166766576, 7.375445059367588, 4.064676633902958, 0.8113611798201288, 0.31948889206562725, 0.19575007898466928, 0.4143230361597878, 0.48222142990146366, 3.9785676087651933, 18.175146511622838, 53.77867146900722, 67.11785439082554, 66.18073695046562, 45.88569157464163, 41.6663875579834, 29.855099609919957, 18.66675935472761, 24.98831033706665, 39.82610157557896, 54.720579692295615, 61.33491039276123, 70.25946848733085, 71.29269341060093, 62.58331407819475, 11.917676159313746, 0.21923957711883954, 0.13383119367063046, 0.20489177773041384, 0.28279806088124004, 0.07340722956827708, 0.12450034650308744, 0.1678585170635155, 0.0717325508594513, 0.12448330170341901, 0.1146899786378656, 0.26514268826161114, 0.11646475483264242, 0.1458485373961074, 0.18761311418243817, 0.10861032522682633, 0.11408908159605094, 0.20427969843149185, 0.21477770725531237, 0.23504499186362537, 0.17800889882658208, 0.19774594902992249, 0.17847965285182, 0.1878453902900219, 0.12975063334618295, 0.11167730351111718, 0.14044430452798093, 0.09987418007637773, 0.15314333167459282, 0.16113048951540673], [0.06345715134271554, 0.008115382299625447, 0.02461619196193559, 0.07389548301164593, 0.05094199700813208, 0.0389760794517185, 0.05997106233345611, 0.05916658442999635, 0.009112410629833383, 0.03752941904323442, 0.01570670655928552, 0.054434019806129594, 0.052394255330520015, 0.054401056574923654, 0.10480802532817636, 0.05446676251345447, 0.04078311998663204, 0.04884263001648443, 0.020443881828604, 0.03777134731145842, 0.004521943537318813, 0.022379177356404916, 0.03701863145189626, 0.009065218519286385, 0.05509246340287583, 0.03971971312005605, 0.06238264364323445, 12.984875168119158, 53.70668118340628, 63.65130083901541, 59.54729175567627, 49.64026185444423, 34.27195828301566, 25.26930938448225, 24.489358459200176, 25.338306733540126, 19.817749295915874, 45.466461590358186, 60.20874636513846, 41.29404749189104, 21.461097274507793, 4.145493303026472, 0.08755071527723755, 0.23199101431029184, 0.03446375711687973, 0.12780289857515267, 0.19748978848968232, 0.8064116739800998, 1.8441276848316193, 2.83886501618794, 3.1366250727857863, 5.286560348102024, 7.190902641841343, 5.453290190015521, 10.076846480369568, 15.394095284598214, 8.670691762651716, 10.774918964930944, 6.181384972163609, 8.458519833428518, 11.314610736710684, 11.36153279032026, 18.565129790987285, 31.570064408438547, 32.860852105276926, 38.26763105392456, 46.28095374788557, 51.75062779017857, 53.98401505606515, 50.47138799939837, 46.5456280027117, 49.06454454149519, 51.94122382572719, 54.90215001787458, 57.69804607118879, 59.183220045907156, 57.782855783190044, 56.173527921949116, 60.10825456891741, 58.59671565464565, 58.8822796685355, 58.297644342694966, 59.303048678806846, 60.176388604300364, 58.6045949118478, 59.47928278786795, 40.20017521721976, 30.11110598700387, 26.206961836133683, 37.84053223473685, 60.97836358206612, 54.17414208820888, 57.27313593455723, 56.99167135783604, 59.798156465802876, 56.39039857046944, 59.14756189073835, 56.78389242717198, 59.927837644304546, 52.86578934533255, 54.369459424700054, 50.07531288691929, 49.579756941114155, 52.56867395128523, 55.52494485037667, 54.54777799333845, 52.37448222296578, 52.682534081595286, 51.14929941722325, 53.63279751368931, 57.03178678240095, 51.77047879355294, 51.24830082484654, 46.36672925949097, 46.07395996366228, 35.35883719580514, 26.821681124823435, 25.99857667514256, 17.226031269345963, 8.606890797615051, 3.3078914369855608, 6.368847370147705, 5.040505528450012, 2.6447790307658057, 3.6380817762442996, 1.487213813832828, 0.4154308938554355, 0.17108435396637234, 0.14448179144944462, 0.023622156819328666, 0.12637053829218658, 1.6252614919628416, 12.91443259375436, 34.870847838265554, 50.961903027125764, 33.900788988385884, 53.985147612435476, 50.397521700177876, 32.25110598972866, 23.860827888761246, 14.264973061425344, 25.562973260879517, 32.70275626863752, 49.03805453436715, 54.693603311266216, 55.567895139966694, 27.023660046713694, 1.6725172762359892, 0.06266093799578291, 0.030777072800057273, 0.07420862013740198, 0.05616129854960101, 0.041825536372406144, 0.0774544941793595, 0.006717825774103403, 0.02484361993681107, 0.06318459061107465, 0.031710550388587375, 0.03862820133300764, 0.07948042332593884, 0.08914808849138872, 0.09497438371181488, 0.015142285863735845, 0.03258650517091155, 0.1144743130675384, 0.04732464879219021, 0.03582302900031209, 0.021106878395325372, 0.04040376123573099, 0.03131439111062458, 0.0763979269457715, 0.017216508043929935, 0.06423978041857481, 0.03232072300410696, 0.018637000749419843, 0.01077414713134723, 0.029696560065661157, 0.020083191272403513, 0.0479223702901176, 0.01865154005853193, 0.030243489824767624, 0.051426718676728864, 0.014642962121537753, 0.0940516439399549, 0.04729782969557813, 0.049234582377331595, 0.05073069441797478, 0.060066912190190384, 0.027745357980685573, 0.06758103612810373, 0.004512125983767743, 0.03244644197236214, 0.055749142808573585, 0.012813531627346362, 0.029773801099509, 0.09330479401562895, 0.008684185483226818, 0.04327440880505102, 0.08074131780969244, 0.021373125358617732, 0.06439703769449677, 0.02256174398852246, 0.1756618461970772, 16.30460112435477, 61.794776916503906, 75.33101422446114, 67.48417731693813, 57.84618166514805, 42.83425119944981, 33.39575917380196, 30.758101395198278, 25.56752780505589, 17.079874174935476, 34.42684057780674, 58.149970803942, 47.125844274248394, 21.985813072749547, 4.132745095661708, 0.07065344269254378, 0.06920154738639082, 0.06792451055454356, 0.21691471258444445, 0.9154203874724252, 3.089849365609033, 4.3460847565105984, 5.253812619618007, 5.949674708502633, 7.089438097817557, 7.053492026669638, 10.538507376398359, 15.625036035265241, 8.009715710367475, 8.665633474077497, 6.449652314186096, 9.999466129711696, 7.734799810818263, 9.232781052589417, 10.791100450924464, 16.951457568577357, 27.20695526259286, 35.35171529224941, 40.166525091443745, 47.34723820005144, 53.6787702696664, 57.52676255362374, 54.20757334572928, 51.92100804192679, 52.8661402293614, 54.891929217747276, 55.43754346030099, 60.52027579716274, 59.73399680001395, 60.343013354710166, 58.359358242579866, 61.13403102329799, 60.370778356279644, 60.599943842206685, 61.133329255240305, 60.47980254037039, 60.092676707676475, 59.16709327697754, 60.34808553968157, 43.758139269692556, 35.348810945238384, 31.35373224530901, 41.142079966408865, 60.52026884896414, 54.11808749607631, 58.47125203268868, 55.56055784225464, 58.4758517401559, 56.81897388185774, 60.790928976876394, 57.99128089632307, 60.66343648093087, 53.64923695155552, 54.97725657054356, 50.96685014452253, 51.27694129943848, 51.89910731996809, 58.11365256990705, 56.27801145826067, 56.84104830878121, 54.246184485299246, 53.543867519923616, 56.16455084936959, 60.43798828125, 53.23408555984497, 53.35759326389858, 45.4789023399353, 45.284912109375, 36.49344675881522, 29.391140597207205, 24.61913343838283, 16.291656630379812, 9.122322934014456, 6.069761293275016, 4.5142068437167575, 4.928242181028638, 9.984582219805036, 6.576366177627018, 3.3827404720442633, 2.056292448725019, 0.9164990953036717, 0.4205996479306902, 0.0525219284796289, 0.02441912842914462, 1.9854438390050615, 12.114427430289131, 34.885032585689, 46.75328533990042, 36.15365900312151, 51.82848582948957, 43.84837205069405, 21.731856414249965, 21.838929891586304, 24.45924322945731, 36.29369299752371, 39.2674594606672, 53.88145269666399, 62.206360408238, 63.85286113194057, 32.55830669403076, 1.9905201494693756, 0.06549929069089037, 0.006582915624936244, 0.018245604787287966, 0.1115623325375574, 0.012242272995146257, 0.05124469147995114, 0.01835929332966251, 0.02331937074528209, 0.01738050826159971, 0.012440687660793108, 0.03489107133022376, 0.09322942234575748, 0.03245099154966218, 0.149712862180812, 0.029701798356005123, 0.02618278852397842, 0.03704587463289499, 0.0663523313456348, 0.019050204827051078, 0.04426306486129761, 0.03740073487694774, 0.0479112762425627, 0.07304030497159276, 0.04049044069168823, 0.07619077698992831, 0.012996853977840925, 0.0071510695353416455, 0.08607609583331005, 0.18284758632736547, 0.17611765888120445, 0.10461760126054287, 0.08802486197756869, 0.12112315557897091, 0.10574487184307405, 0.14432384206780366, 0.3166881166398525, 0.09720938306834016, 0.13024635746010713, 0.13022767060569354, 0.16494017866040978, 0.09155361726880074, 0.18085588248712675, 0.20939754880964756, 0.1646999501224075, 0.16367405945701258, 0.07950041975293841, 0.05624571509127106, 0.197004391678742, 0.07125764419989926, 0.09476715233176947, 0.14451064275843756, 0.1309437964643751, 0.11947818313326154, 0.13448292655604227, 0.38082647642918993, 22.476020642689296, 73.49400084359306, 80.49099663325718, 75.9302338191441, 66.03672858646938, 47.54477548599243, 36.627397605351035, 34.42545093808855, 34.84575094495501, 30.11209957940238, 59.42040375300816, 72.15564577920097, 52.46191487993513, 27.628749132156372, 5.559740500790732, 0.3057655484548637, 0.35988246170537813, 0.15711812196033342, 0.1878862516688449, 0.582683479147298, 3.601561393056597, 6.412129436220441, 11.849624633789062, 13.650010585784912, 13.52546238899231, 16.67636275291443, 11.4974273954119, 22.587930066244944, 25.710705859320505, 17.070527110780986, 19.024263279778616, 13.197759287697927, 16.342826638902935, 18.979129518781388, 18.937900645392283, 23.642227138791764, 38.529856068747385, 40.43630974633353, 44.67850112915039, 52.358004570007324, 59.21474402291434, 61.89378179822649, 56.672474588666645, 55.29549101420811, 54.212346758161274, 55.95367649623326, 54.76966871534075, 59.41017600468227, 61.108503341674805, 60.806082998003276, 61.49700491768973, 64.76575715201241, 63.79530225481306, 62.41479246956961, 63.402520588466096, 62.31669085366385, 63.57844202859061, 60.494004658290315, 62.57076563153948, 48.658206939697266, 39.53926256724766, 36.303368364061626, 45.66842140470232, 60.45901353018624, 54.40905720846993, 57.34973982402256, 56.43830292565482, 59.76987034933907, 58.19368886947632, 60.73872716086251, 58.25278329849243, 62.007989338466096, 55.64875480106899, 54.91599777766636, 51.01987532206944, 51.58915512902396, 54.569032532828196, 59.807064056396484, 58.31646006447928, 58.115778718675884, 57.11722183227539, 55.556173528943745, 59.61816338130406, 64.71700164249965, 54.41736725398472, 53.45009463174002, 48.276653562273296, 47.406648772103445, 41.08651522227696, 33.07537426267351, 30.228874479021343, 22.36355710029602, 12.95291084902627, 10.566200290407453, 13.800517252513341, 14.024838975497655, 10.9562634740557, 12.285458207130432, 4.885702703680311, 1.603188693523407, 0.38677801564335823, 0.4217105454632214, 0.11440565889435154, 0.20735498198441096, 3.0034880340099335, 17.694970403398784, 47.401673861912315, 65.82815061296735, 46.10613707133702, 69.0047836303711, 65.37617029462541, 45.51603351320539, 34.312810216631206, 23.482637439455303, 37.149620737348286, 45.67315312794277, 63.52464212690081, 71.21440805707658, 73.75871331351144, 40.85803413391113, 2.9498162397316525, 0.12761342445654528, 0.1810914019920996, 0.1615006032266787, 0.2036220215793167, 0.1145323413823332, 0.17468863699053014, 0.12578569538891315, 0.14918740466237068, 0.14507384039461613, 0.11058780018772398, 0.13298349987183297, 0.19890601320990495, 0.11171275696584157, 0.2272217816540173, 0.16362354931022438, 0.09211612958461046, 0.11701735375182969, 0.114029411226511, 0.1829282912824835, 0.11146184150129557, 0.2313902394047805, 0.13187938768948826, 0.16354956185179098, 0.17395168010677609, 0.18822098656424455, 0.10232061773006405, 0.09654774357165609, 0.14002885110676289], [0.05068328178354672, 0.012275550896967096, 0.015034268177779657, 0.030580423173627684, 0.012055152544884809, 0.0673821914408888, 0.016178775246122053, 0.05217123783326574, 0.026682317523019652, 0.049335751948612075, 0.0060557863658427125, 0.07141695743692772, 0.02092229312152735, 0.024140756045069014, 0.055518831059868844, 0.035783450052674325, 0.042543026086475165, 0.04205903384302344, 0.03442474135330745, 0.0413356273035918, 0.014500200049951673, 0.05560051989076393, 0.0155351729065712, 0.014398049995569246, 0.04242062854713627, 0.03098929819783994, 3.722712355000632, 37.63352108001709, 61.88496453421456, 58.90384687696184, 57.636693477630615, 46.09080587114607, 31.58667755126953, 20.922177621296473, 13.610873988696508, 31.259809970855713, 42.583285740443635, 42.4794032233102, 38.31763029098511, 21.22057843208313, 6.503575112138476, 0.2080931602311986, 0.03785261884331703, 0.042404404774840386, 0.07672017001147781, 0.16507530212402344, 0.9384357524769646, 1.0063296407461166, 4.6139603938375195, 1.8827796450683048, 5.25687677519662, 6.572100417954581, 4.102337607315608, 10.098101888384138, 13.517213140215192, 10.76231927531106, 18.051644018718175, 18.229031528745377, 22.010878699166433, 17.827628884996685, 19.727933406829834, 25.89613938331604, 33.35373299462454, 40.8101749420166, 49.526822090148926, 45.50166811261858, 49.640209742954795, 46.84208679199219, 48.19906997680664, 50.50818913323538, 54.264652797154014, 56.99365854263306, 56.16112886156355, 55.71842786243984, 58.30123656136649, 58.59509672437395, 56.57963275909424, 56.63796288626534, 55.94879886082241, 52.728187220437185, 57.711459568568635, 57.06270626613072, 56.05699968338013, 57.48970433643886, 56.942617075783865, 59.444659914289204, 49.14029727663313, 26.8879200390407, 24.989581857408794, 48.06584869112287, 55.761180128370015, 53.20025478090559, 53.790302753448486, 52.3892297744751, 56.0689297403608, 57.047517504010884, 53.41651398794991, 54.152825014931814, 54.904116358075825, 56.312349455697195, 53.85245786394392, 53.160806383405415, 50.2068110193525, 49.972549029758994, 56.58535460063389, 54.93348291942051, 53.44043663569859, 47.361860683986116, 48.29166514532906, 53.265824931008474, 52.95292322976248, 56.201744556427, 52.09492840085711, 51.33229412351336, 48.85709912436349, 49.51068489892142, 52.04509939466204, 46.71614721843174, 34.065287590026855, 25.770076479230607, 19.842952149254934, 6.460444603647504, 4.729297884872981, 7.160155126026698, 3.4378948381968906, 2.2304116998400008, 3.8521633744239807, 1.064333202583449, 0.11679991041975361, 0.054434169083833694, 0.07661956362426281, 0.059523249577198706, 1.246947820697512, 10.79573142528534, 29.655589035579137, 41.92276913779122, 31.62295409611293, 33.975238936288015, 55.92367764881679, 44.594990730285645, 21.045506409236364, 18.778540236609324, 31.399520874023438, 47.88018587657383, 51.66757944652012, 56.46632153647286, 45.191034998212544, 13.226739355495997, 0.2125527909291642, 0.03155767644888588, 0.012236645395335342, 0.04516120434605649, 0.0389288873411715, 0.024163118862946118, 0.06393473143024103, 0.0490831672879202, 0.05902131686785391, 0.01736569414580507, 0.031691184999155145, 0.1211847122758627, 0.03202674092192735, 0.08575977637831654, 0.0528548279378031, 0.006837442592119, 0.02731511588873608, 0.05109150202146598, 0.03145422360726765, 0.015140301148806299, 0.04493296891450882, 0.04636004340967961, 0.013354747273427035, 0.023155121165992956, 0.06634165798979146, 0.02567243010603956, 0.05176707862743309, 0.03634269522236926, 0.04280113062954374, 0.0666522438238774, 0.012840822305796402, 0.04660481473963175, 0.02026831598154136, 0.0356786401410188, 0.031110029933708053, 0.03913358439292226, 0.028824588283896446, 0.010591893473507037, 0.024218790964888673, 0.06248824404818671, 0.06102845737976687, 0.024877933452704122, 0.03312292442257915, 0.06784862319805793, 0.04068055941856333, 0.03990983523960624, 0.025940476883468882, 0.021598208995003785, 0.028034598799422383, 0.0173212501020836, 0.03493922356782215, 0.06001410859503916, 0.040947366173246076, 0.04736920140151467, 4.678942986897059, 44.85923072269985, 72.6985502243042, 66.11454146248954, 66.04013320377895, 54.15763316835676, 39.15487779889788, 27.371667521340505, 17.110804080963135, 29.923511573246547, 36.985111713409424, 44.02259465626308, 41.052118165152415, 22.132074390138897, 5.258199972765786, 0.2362102536218507, 0.039357690938881466, 0.08812794501760177, 0.13841434488339083, 0.780462703534535, 4.436902488980975, 3.4837572915213446, 9.344309193747383, 7.382639050483704, 8.30013825212206, 10.53407529422215, 8.856219955853053, 9.832813586507525, 6.296041973999568, 9.416781510625567, 11.09480013166155, 12.076478106634957, 15.42053839138576, 16.590036596570695, 17.50484163420541, 22.814453499657766, 32.15221227918352, 43.99357203074864, 49.727378368377686, 51.21491125651768, 54.624253341129844, 53.17490775244576, 53.2078526360648, 55.21912336349487, 55.45402111325945, 57.42111866814749, 56.220956325531006, 56.3337846483503, 59.66914231436593, 61.18600354875837, 58.565643310546875, 58.58646011352539, 57.65631519045149, 55.80075011934553, 58.31415326254708, 58.13019275665283, 57.46136263438633, 59.811858313424246, 59.32819420950753, 60.32886682237898, 48.769913128444124, 32.3047182900565, 31.38964400972639, 48.8678549357823, 56.74831765038626, 52.59422247750418, 54.075804233551025, 52.05936752046858, 57.66041810171944, 58.50483267647879, 54.97389364242554, 57.24275146211897, 57.27157258987427, 57.911425249917166, 54.375678062438965, 53.66859810692923, 51.450079986027305, 51.08634178979056, 56.21765940529959, 58.61912359510149, 54.16850709915161, 50.32510757446289, 51.59244510105678, 55.339605127062114, 55.519163949149, 56.83703572409493, 53.21584306444441, 53.003082275390625, 50.57960966655186, 53.04438236781529, 55.75797006062099, 47.37768520627703, 37.948646204812185, 25.81556112425668, 15.516491276877266, 5.586753359862736, 5.202834989343371, 7.673973543303354, 7.963656970432826, 5.661951541900635, 6.5060204437800815, 2.983344772032329, 0.8762923670666558, 0.33839048924190657, 0.02056051351662193, 0.07048726946647678, 1.02516371011734, 11.843551908220563, 30.02345793587821, 45.895321777888704, 36.288565226963584, 34.720037187848774, 50.120267731802805, 38.61014945166451, 21.375981841768535, 25.247465985161917, 41.159186431339805, 56.94229051045009, 58.60938916887556, 65.20804473331997, 53.65830782481602, 16.887535878590175, 0.18685200145202024, 0.02825706159429891, 0.0318499995129449, 0.06954468933067151, 0.05768425004290683, 0.02958871710247227, 0.05758833911802087, 0.006627064505924604, 0.05309340085035988, 0.07064099836030177, 0.04283295052924326, 0.028992834434445416, 0.0430558323194938, 0.008122293178790381, 0.029145284289760248, 0.050345700433743854, 0.01111016615426966, 0.04090778383293322, 0.02873981211866651, 0.11321755764739853, 0.04030891900349941, 0.006608247033519936, 0.029204103097851788, 0.0653332599571773, 0.037624332521642954, 0.012212762659016465, 0.08960792488817658, 0.02558898556578372, 0.07911494400884424, 0.1222963019141129, 0.10724018660507031, 0.20937726061258996, 0.1255467017846448, 0.11766403833670275, 0.06123897286930254, 0.18158986738749913, 0.1095939160191587, 0.10122771494622741, 0.08061992789485625, 0.15031753187733038, 0.11361158293272768, 0.056584704401237626, 0.14163883828691073, 0.21105591553662503, 0.12984494971377508, 0.1312997830765588, 0.16005748137831688, 0.16944983095995017, 0.11493807818208422, 0.16777787996189936, 0.15106047343994888, 0.0999938804390175, 0.1607775834522077, 0.11338620074093342, 7.760754806654794, 59.76606273651123, 82.61341421944755, 74.90198380606515, 75.54624162401471, 62.65843105316162, 45.46590573447091, 31.48204115458897, 20.31022718974522, 43.38386065619332, 55.935110909598215, 53.10786805834089, 49.389480522700715, 28.1827290058136, 8.36407731260572, 0.3354863322206906, 0.10652018631143229, 0.20367212460509368, 0.2362302839756012, 0.5012728476098606, 3.886507885796683, 7.704812254224505, 12.013268607003347, 10.827279720987592, 12.481912442616053, 15.909946918487549, 11.46281407560621, 19.02789545059204, 21.336562974112375, 18.732675177710398, 23.699294430868967, 23.414972407477244, 27.56023120880127, 24.42361981528146, 26.26704638344901, 30.231000627790177, 38.52007300513131, 52.22112505776541, 58.50326238359724, 56.25190360205514, 60.917962891714915, 55.92539037976946, 56.17926018578665, 57.077891554151265, 57.81106546946934, 57.16376781463623, 56.686176436288015, 57.4723790032523, 62.06525639125279, 63.7077271597726, 61.07888317108154, 60.925369671412874, 61.85648386819022, 56.50516196659633, 61.928342138017925, 61.55910096849714, 60.21369348253523, 61.473436628069194, 59.97896943773542, 62.200614248003276, 53.214453424726216, 35.52122007097517, 36.812108516693115, 51.2743114062718, 56.04547957011631, 53.03997026171003, 54.19681406021118, 53.621729033333914, 59.36638845716204, 59.982325417654856, 56.26516423906599, 59.23278849465506, 59.93568216051374, 59.94133799416678, 56.473770005362375, 54.487610067640034, 51.2121319770813, 50.58723184040615, 59.13706316266741, 59.92350891658238, 58.36798095703125, 52.578901699611116, 53.07234539304461, 58.350388118198936, 58.3946134022304, 58.17896563666207, 53.42466075079781, 52.55880403518677, 50.96963289805821, 53.54886327471052, 56.95274754932949, 53.367296423230854, 40.01389053889683, 31.743727684020996, 27.844068595341273, 13.352009296417236, 14.231426290103368, 14.102980153901235, 12.09218624659947, 8.787401522908892, 9.163757647786822, 2.717434823513031, 0.4823826498218945, 0.22094873897731304, 0.2109488019985812, 0.21497106259422644, 2.1732063123158047, 15.729552575520106, 40.39295646122524, 53.673524379730225, 45.729384899139404, 45.79188047136579, 72.39601870945522, 62.516152790614534, 30.95447138377598, 27.949578727994645, 44.47945955821446, 63.59271362849644, 66.50326538085938, 74.01848561423165, 63.038254329136436, 20.446592535291398, 0.3949608765542507, 0.19466662140829222, 0.14620977586933545, 0.18964886851608753, 0.13777154151882443, 0.09040655381977558, 0.14553111871438368, 0.14069671955491814, 0.17080688742654665, 0.12865857194576943, 0.1755791599197047, 0.23113106616905757, 0.1284912044980696, 0.1729317605495453, 0.0928474139156086, 0.1393838764301368, 0.10164437615977866, 0.17319457073296818, 0.09777313031788383, 0.16022121187831673, 0.11375102866441011, 0.14087012596428394, 0.14830260856875352, 0.13013490129794392, 0.21543313137122563, 0.15175002786730016, 0.2163523156195879, 0.09128410315939359], [0.025919384622414197, 0.019823490475703563, 0.057366919570735524, 0.042218693132911406, 0.013431485343192304, 0.03863782635224717, 0.04951598781294056, 0.031327513977885246, 0.020007850136607885, 0.04241191615749683, 0.04872588128117578, 0.022472913576556102, 0.041137339015092166, 0.01942956866696477, 0.03736168518662453, 0.02351599492664848, 0.013374943020088332, 0.05147147484655891, 0.006120673821507288, 0.017903680813365748, 0.023074477279026593, 0.02064766116174204, 0.04540882891576205, 0.0262782346523766, 0.015389399835839868, 0.28360505614961895, 20.064674377441406, 56.371895517621724, 66.92209584372384, 58.55055182320731, 55.47223234176636, 34.81672831944057, 22.20750403404236, 27.051511900765554, 28.308281217302593, 29.46227625438145, 24.143265213285172, 36.095641544886995, 26.81717869213649, 7.15150157894407, 0.26312863347785814, 0.11528181045183114, 0.06884950306266546, 0.12665329740515777, 0.43101475334593226, 1.2455012926033564, 2.9139066466263364, 3.0894339936120168, 5.276121113981519, 3.6627194370542253, 2.079646429845265, 5.188644162246159, 8.02170135293688, 15.923608813967023, 14.61507020677839, 13.917953099523272, 21.65311595371791, 16.51796988078526, 29.266038281576975, 28.28258851596287, 31.616033690316335, 33.79445028305054, 45.50398881094796, 46.8344680922372, 49.00056900296892, 46.03817326681954, 50.62973049708775, 53.91033288410732, 59.28750555855887, 54.62124129704067, 55.84759487424578, 55.59358263015747, 55.70680005209786, 57.93562582560948, 59.8116637638637, 55.17004476274763, 57.683892590659006, 51.2101274217878, 53.889755793980186, 49.517191886901855, 53.41842474256243, 52.989112922123496, 55.478582995278494, 52.33960574013846, 56.96537242616926, 55.504739488874165, 57.09101670128958, 26.871053286961146, 24.89328156198774, 52.099180698394775, 50.83432715279715, 51.38092803955078, 52.081035477774485, 52.99154131753104, 54.63467563901629, 55.18914883477347, 52.203368936266216, 51.20348146983555, 53.43445423671177, 54.84793669836861, 57.37479502814156, 54.72154549189976, 51.43267822265625, 50.63316985539028, 54.22052478790283, 53.544433798108784, 51.92197036743164, 43.77895607267107, 44.67765344892229, 48.84865358897618, 52.802842140197754, 53.81164761951992, 53.9795160974775, 52.32895762579781, 55.084151131766184, 59.228807176862446, 61.932149750845774, 55.88971138000488, 53.188727719443186, 44.39451783043997, 29.351219722202845, 14.597317559378487, 4.592187779290335, 9.209444659096853, 5.046419748238154, 3.26386222243309, 4.5205284016472955, 3.6776541556630815, 1.9410292165619987, 0.08337961802525179, 0.031176000500896146, 0.19356910458632878, 0.08149576732622725, 1.4901742892605918, 10.185686537197657, 28.82933705193656, 52.168475082942415, 60.965759549822124, 63.19237927028111, 65.64232104165214, 44.34115219116211, 17.151084525244578, 16.501384530748638, 28.270503861563547, 41.15451724188668, 48.474406242370605, 59.49231760842459, 30.04181855065482, 1.2040685330118452, 0.029176055852855955, 0.01932971545362047, 0.00406688021030277, 0.02050248520182712, 0.06880144242729459, 0.04820860010970916, 0.04678007694227355, 0.036863182471799, 0.0466836096186723, 0.03522709883483393, 0.0604864503922207, 0.036621925953243456, 0.04405970452353358, 0.0252607171091118, 0.06625424910868917, 0.03028220364025661, 0.052643216614212306, 0.04979589707883341, 0.02977271205080407, 0.02410654261309121, 0.02567591777603541, 0.03005412087908813, 0.05098311962293727, 0.10960105420755488, 0.01878762704187206, 0.046016786114445755, 0.003263227150975061, 0.04581952580649938, 0.018736811554325477, 0.009649017326799887, 0.017167022485019903, 0.055215098429471254, 0.053267858989004574, 0.01854333238277052, 0.044177077511059384, 0.02567357343754598, 0.0558154017531446, 0.029310276864894798, 0.03634418799941029, 0.024795033436800753, 0.027915529474349957, 0.01951905047254903, 0.010293080221994646, 0.04244854687047856, 0.02483714501639562, 0.029299399948545864, 0.02684942543107484, 0.01165797037538141, 0.03622156993619033, 0.01805869213837598, 0.07604671722011906, 0.03888833469578198, 0.4169731225286211, 23.47251738820757, 65.35832732064384, 73.80596106392997, 65.3591888972691, 63.74065467289516, 42.80295303889683, 31.23413290296282, 32.84150832039969, 30.322570937020437, 27.51673722267151, 27.387104681559972, 38.09149421964373, 27.333997862679617, 6.349571330206735, 0.3142858584012304, 0.15021257608064584, 0.08976456469723157, 0.33933576994708603, 1.2318210495369775, 3.698533058166504, 4.925726933138711, 4.678089226995196, 7.662306649344308, 6.182883611747196, 8.505919575691223, 9.554660694939749, 7.459625959396362, 8.565521223204476, 10.467869383948189, 14.671095269066946, 18.423518555504934, 20.478691475731985, 25.903591326304845, 27.220294066837855, 33.0404943057469, 38.95947013582502, 47.78374488013131, 51.517981256757466, 53.97718497685024, 52.158393246786936, 53.552264417920796, 56.81021220343453, 58.41387380872454, 55.114070074898855, 55.830533572605674, 55.642876625061035, 56.456045150756836, 59.439351490565706, 60.636421884809224, 56.477105140686035, 60.43700163705008, 52.816613469805034, 55.06948695863996, 52.30264132363455, 55.03618771689278, 55.21859877450125, 56.34457867486136, 54.428612913404194, 59.815304619925364, 58.306843757629395, 57.47192737034389, 31.272396632603236, 28.370281730379375, 53.0624372618539, 51.5639887537275, 54.355861800057546, 52.82335669653756, 53.25186252593994, 56.0037521634783, 56.27749034336635, 54.987869943891255, 52.77726582118443, 55.2312444959368, 56.34065294265747, 58.414589473179404, 56.61338363374983, 52.62957143783569, 51.573101316179546, 54.98484400340489, 55.83621372495379, 51.89685262952532, 46.777051653180806, 46.63668761934553, 52.332115582057405, 56.45374182292393, 56.2352557182312, 52.47375808443342, 52.479618889944895, 53.80127395902361, 60.368395124162944, 62.626517977033345, 60.086117608206614, 56.40011215209961, 46.36344970975603, 32.31802061625889, 15.622847352709089, 5.120881421225412, 10.432893020766121, 6.506556757858821, 7.678104247365679, 6.312841849667685, 6.2168963466371805, 4.017905703612736, 0.9667202404567173, 0.09940175685499396, 0.05841235204466751, 0.07505085851464953, 1.2196296751499176, 11.416496515274048, 26.821304185049875, 50.863099643162315, 59.60139042990548, 62.4374783379691, 64.46730422973633, 42.79493134362357, 22.910578353064402, 24.81681489944458, 35.671196937561035, 48.28992114748274, 55.0062062399728, 66.42048454284668, 36.381719725472585, 1.778213490332876, 0.03917524983574237, 0.028995993014957224, 0.015206867130473256, 0.02412115316838026, 0.050159300078770945, 0.054890388888972144, 0.036221281558807404, 0.10010394560439245, 0.03732675081118941, 0.03099202930129, 0.06846908240446023, 0.10826978885701724, 0.007829954847693443, 0.009236346747327064, 0.012752260763331183, 0.025233892923487083, 0.03474546789324709, 0.037548346777579615, 0.03000845547233309, 0.024352598070566143, 0.029128802674157277, 0.08148959944290773, 0.025684163672849536, 0.016740144230425358, 0.03357921547389456, 0.07873957165117774, 0.0850144260163818, 0.1137610234852348, 0.11437663116625377, 0.12178723780172211, 0.1826345127608095, 0.14380257789577755, 0.16613824080143655, 0.1881246074501957, 0.18043049531323568, 0.11635099165141582, 0.14365809064890656, 0.12830498734755175, 0.08309014141559601, 0.13070997329694883, 0.08631938456424645, 0.10985129113708224, 0.074881937221757, 0.16144515334495477, 0.12934761068650655, 0.1719221140124968, 0.13300925706114086, 0.04218467138707638, 0.11440644599497318, 0.09780260587909392, 0.18779812354062284, 0.1094930110765355, 0.7957867383956909, 30.138846669878276, 75.88545267922538, 81.37435586111886, 75.80019133431571, 69.4847721372332, 49.19066824231829, 33.17462580544608, 35.84003816332136, 38.62953839983259, 41.01542820249285, 33.84173624856131, 46.836458751133506, 34.44152559552874, 9.320839047431946, 0.5672572840537343, 0.2701421342790127, 0.1353859073881592, 0.5662134800638471, 1.0048403378043855, 5.041202519621168, 9.913450036730085, 11.165538004466466, 12.383008309773036, 9.346378888402667, 9.67134700502668, 15.551473719733101, 15.264881372451782, 22.931553227560862, 21.538170167378016, 19.992149080548966, 27.832256657736643, 23.755114521299088, 36.957353660038535, 34.8662759235927, 39.945739133017405, 42.5474191393171, 54.56765678950718, 53.87116936274937, 57.589056628090994, 53.76227024623326, 54.54638487952096, 57.56594691957746, 59.874114172799246, 56.920827525002615, 58.133708545139854, 57.432697841099326, 59.02346706390381, 60.567176137651714, 63.01211520603725, 59.34470312935965, 62.68760653904506, 55.5138589995248, 59.33576079777309, 54.689503874097554, 58.512955120631624, 57.22672544206892, 59.39079747881208, 56.139276776994976, 61.72931793757847, 59.26468072618757, 59.99542277199881, 34.15792097364153, 33.01826007025582, 54.33179324013846, 51.223891803196494, 55.40766273226057, 53.737135137830464, 52.448438848767964, 57.716827051980154, 59.23776340484619, 57.46335676738194, 54.862163134983604, 58.95758424486433, 58.632512773786274, 61.569558007376536, 58.29603236062186, 55.431634017399375, 52.30410739353725, 55.61381231035505, 57.06504086085728, 55.80627393722534, 47.90992416654314, 49.589995111737935, 53.54822404044015, 59.279417855399, 57.86587980815342, 52.82546547480992, 52.322711195264546, 54.36910506657192, 61.04469108581543, 64.83612850734166, 60.15439755575997, 58.64718042101179, 47.828487804957796, 36.06412104197911, 19.404979399272374, 10.250159740447998, 17.310368503843033, 12.617058379309517, 12.396740555763245, 10.14148644038609, 10.484741347176687, 3.799985008580344, 0.6515772023371288, 0.15493125787803105, 0.40219405985304285, 0.1987278163433075, 2.283485080514635, 13.493386030197144, 38.81292567934309, 63.86503437587193, 66.59357806614467, 65.53848716190883, 74.01796449933732, 56.23249380929129, 27.538837705339702, 25.302181312016078, 40.36627190453665, 57.382035051073345, 65.58706896645683, 74.09136526925224, 47.3727137701852, 3.1122868359088898, 0.1690265065325158, 0.18036303536168166, 0.11175545038921492, 0.16103121984217847, 0.15383573594902242, 0.1858107623245035, 0.11832476859646184, 0.1813373573656593, 0.16392357035407, 0.14786046157990182, 0.1063374907576612, 0.13067456733967575, 0.14163691124745778, 0.11408074918602194, 0.13372063317469188, 0.074049870084439, 0.16118268242904119, 0.08122912341994898, 0.1742226734225239, 0.10946145241281816, 0.1827004120818206, 0.17397810226040228, 0.13562225470585482, 0.21504396439663, 0.09380319834287677, 0.200118785990136, 0.10865770732717854], [0.028134151761020933, 0.0591727862400668, 0.013977422744833996, 0.025016337633132935, 0.051069687120616436, 0.07719631839011397, 0.033091057025428326, 0.08714451707367386, 0.05475091940856405, 0.0321554861563657, 0.03500217465417726, 0.037034122406372, 0.04002151871100068, 0.03334090718999505, 0.0500256286800972, 0.0478436025524778, 0.026021117377760153, 0.06461311038583517, 0.00698803029289203, 0.0157613133612488, 0.05252860865688749, 0.02287022806038814, 0.06081836258194276, 0.027974947089595453, 0.03886525093444756, 3.9755738036973134, 33.504085063934326, 65.7488021850586, 64.76435361589704, 53.62103073937552, 48.868254457201274, 39.14650174549648, 22.91347575187683, 16.2263730934688, 23.792940514428274, 39.22020476205008, 51.38744197572981, 32.06326144082205, 7.199455874306815, 0.4841165510671479, 0.02364948481720473, 0.09777121006378106, 0.09170904250017234, 0.22118775972298213, 0.19747016525694303, 1.8137604743242264, 6.3167146018573215, 2.3882558814116885, 11.602934922490801, 10.933332681655884, 13.258447459765843, 13.1019184419087, 15.269613095692225, 9.593316129275731, 15.124800477709089, 29.148526872907365, 30.61461067199707, 40.404869147709434, 40.48158768245152, 43.71704414912632, 44.13950504575457, 49.03890221459525, 47.104106834956575, 50.148043155670166, 56.06579957689558, 55.26724311283657, 57.77055399758475, 57.71477385929653, 53.54719223294939, 54.30558116095406, 55.25410059520176, 54.61078078406197, 55.96266399111067, 57.96353326525007, 54.36608607428414, 52.584321294512065, 49.819570541381836, 49.09928553444998, 47.9048033441816, 48.015616689409526, 49.56805617468697, 51.718433312007356, 53.42709262030465, 51.71446936471121, 56.57332032067435, 54.217088903699604, 59.63744463239397, 32.21759482792446, 32.78407451084682, 55.75452028002058, 51.88805621010916, 56.017947333199636, 50.28196273531233, 51.66177075249808, 52.929042271205354, 54.24627481188093, 49.8134491784232, 49.140245165143696, 47.19496842793056, 52.27326086589268, 51.82564401626587, 55.37363740376064, 54.737790380205425, 54.49806015832083, 52.56088849476406, 56.26389619282314, 52.589466435568674, 43.84632928030831, 39.626518045152935, 50.11570971352713, 52.970318044934956, 55.35361269542149, 51.156758308410645, 51.140662806374685, 52.429522378104075, 57.714582783835276, 56.75494623184204, 55.434670380183626, 54.46693222863333, 54.172436305454795, 46.91998304639544, 26.532205275126866, 12.669381788798741, 11.13552873475211, 7.437427333423069, 3.945056446960994, 6.582629110131945, 4.552095370633261, 2.6438006375517165, 1.270373129418918, 0.2938256120043141, 0.11142779261405979, 0.059664025237517695, 0.059663760608860424, 1.4736675407205309, 10.010655335017614, 26.951487370899745, 52.131114619118826, 73.94901752471924, 70.6773123059954, 56.30800683157784, 29.152487346104213, 18.42995432444981, 24.985941001347133, 35.92925303322928, 47.65230580738613, 48.58115141732352, 44.77458429336548, 12.15517166682652, 0.05009378073737025, 0.05384541781885283, 0.04301570715116603, 0.019860382424667478, 0.022112184004592042, 0.06881678410406623, 0.03049478187624897, 0.028268287956182445, 0.03257949251149382, 0.03585981238367302, 0.08739172095166785, 0.05776879550623042, 0.04576599278620311, 0.05170771020597645, 0.1652090006640979, 0.026742988731712103, 0.025581777827548127, 0.07734860878969942, 0.02774162094907037, 0.03833394105147038, 0.04458074817167861, 0.024533191862116967, 0.025146528147161007, 0.01305198494810611, 0.05147922710914697, 0.01568847262699689, 0.05045953146847231, 0.03158120125798242, 0.06689667927899531, 0.0915888264509184, 0.039045904097812514, 0.0565509778181357, 0.0382591291729893, 0.01754388931606497, 0.057675123746906004, 0.023112595680036714, 0.045542944754873, 0.0041160956274585, 0.030840838128434758, 0.017263808720079914, 0.019536478644503013, 0.022524450007559996, 0.05693315927471433, 0.021682174310886433, 0.04181609455762165, 0.049455031619540284, 0.029093271187905754, 0.07496176686670099, 0.023052969415272986, 0.026701550598123243, 0.08737557181822402, 0.06301756921623435, 5.249123888356345, 42.205772740500315, 76.47652203696114, 71.44777025495256, 60.25593852996826, 54.764700753348215, 47.12969357626778, 28.12768190247672, 21.7276770727975, 24.85177823475429, 37.0470792225429, 39.55533722468785, 29.957036631447927, 7.088543951511383, 0.5872716786605972, 0.058851520264787335, 0.044562156312167645, 0.13694096037319728, 1.4539134864296233, 2.6035388665539876, 5.202159711292811, 10.214408653123037, 7.02095057283129, 13.84708321094513, 9.48507535457611, 7.785789166178022, 8.133630752563477, 11.655401638575963, 13.374720352036611, 17.83265243257795, 29.963008608136857, 34.591196741376606, 42.565293380192344, 43.75441156114851, 48.07390512738909, 47.724160603114534, 51.76218959263393, 51.94237722669329, 53.84671170370919, 55.325389112745015, 54.122551713671, 57.106660570417134, 57.41030032294137, 53.67178038188389, 54.035355295453755, 54.9084381375994, 54.684365681239534, 56.75480031967163, 57.186589172908235, 57.469426018851145, 55.73279673712594, 51.95997701372419, 50.673882825034006, 49.70297976902553, 49.5767240524292, 52.39239815303257, 54.924189703805105, 55.3261638368879, 53.28037793295724, 58.073512826647075, 55.76631484712873, 60.06032589503697, 35.36936719076974, 35.78660304205758, 56.125512395586284, 53.443236759730745, 56.972209453582764, 52.47674233572823, 51.82270492826189, 54.048473494393484, 56.18027114868164, 52.790168625967844, 50.4546845299857, 49.78352328709194, 54.45755216053554, 53.99070617130825, 57.29937580653599, 57.219589642116, 55.04830884933472, 52.554367610386436, 58.40035956246512, 55.188047545296804, 45.146229539598735, 42.13104139055525, 53.25453758239746, 55.91425241742815, 56.817351477486746, 51.77553013392857, 51.560358319963726, 53.756068978990825, 60.20680781773159, 58.42966706412179, 57.1453446660723, 56.40518781117031, 57.949626445770264, 49.9312732560294, 32.24101025717599, 16.74145347731454, 9.74036693572998, 6.232529359204428, 8.098778588431221, 9.62016657420567, 6.41541028874261, 8.085060238838196, 3.206588004316602, 1.0070440024137497, 0.24523205522980007, 0.041717221827379296, 0.04671911057084799, 1.1677724463599068, 9.397698283195496, 30.92306900024414, 57.32640777315412, 79.50474848066057, 76.60516793387276, 55.99821097510201, 29.67424147469657, 18.78824165889195, 35.199810300554546, 44.63028410502842, 54.10659517560686, 56.91268423625401, 53.0466752733503, 14.642704929624285, 0.10590193912919078, 0.0802885585331491, 0.07117983658931085, 0.020076338068715165, 0.03596664432968412, 0.04999305899920208, 0.03144043577568872, 0.06360283959656954, 0.043344776279159954, 0.01673351663963071, 0.014742241972791297, 0.016287664849577204, 0.030355953611433506, 0.011693671495387596, 0.05869848347668137, 0.0326208186868046, 0.017616753799042532, 0.07213228262428727, 0.019667729369497726, 0.05497933804456677, 0.01957484131811985, 0.034854186166610034, 0.009037480007724037, 0.030879300885966847, 0.09775683869208608, 0.02971763875601547, 0.04626160833452429, 0.14418107829988003, 0.1193751815174307, 0.14923786052635737, 0.1423414477280208, 0.0896494851580688, 0.16421538112418993, 0.1175198767866407, 0.21369503677955695, 0.09365527092346124, 0.09662646720451967, 0.131223162902253, 0.10070554832262651, 0.09753870325429098, 0.10101844796112605, 0.1153362968138286, 0.11067349237522908, 0.15889859784926685, 0.15880983189812728, 0.1252321329499994, 0.1589203788233655, 0.14802892825433187, 0.11526407354644366, 0.1184152037437473, 0.18456790330154554, 0.12166682497731277, 8.021789942468915, 55.263501507895334, 86.35412979125977, 80.53545815604073, 69.78533731188092, 63.608805656433105, 53.77354717254639, 31.55817256655012, 22.57951579775129, 32.763719763074604, 52.71206045150757, 64.37198884146554, 40.40701266697475, 10.341682280812945, 0.8557967011417661, 0.13024652030851158, 0.22280725996409143, 0.3316759509699685, 1.1849675008228846, 3.448679745197296, 7.78720051901681, 15.33035945892334, 9.332843797547476, 22.420306512287684, 18.344355991908483, 21.664705548967632, 23.586594649723597, 27.077235868998937, 16.299096414021083, 22.014595985412598, 37.06337969643729, 37.26533603668213, 45.843793937138145, 45.979266439165386, 52.07253435679844, 50.11564023154122, 53.68853596278599, 51.56262690680367, 55.760433197021484, 56.66071128845215, 54.91659184864589, 58.905382428850444, 58.88578156062535, 55.55546828678676, 57.372269357953755, 56.23617288044521, 56.52273048673357, 57.32953446252005, 60.18485845838274, 60.07736982618059, 59.65932450975691, 54.44882869720459, 55.92893048695156, 51.5365503174918, 51.05303907394409, 53.55369922092983, 56.223030362810405, 56.21191324506487, 56.33436482293265, 60.85092667170933, 57.45936502729143, 59.45137187412807, 38.723870618002756, 40.032810483660015, 56.97102131162371, 55.91001401628767, 58.41364451817104, 52.449897970472065, 50.95763683319092, 56.347611563546316, 57.04367167609078, 55.90134961264474, 53.58575473512922, 50.943726539611816, 56.80244064331055, 56.298199449266704, 57.94539499282837, 59.05469226837158, 58.25694179534912, 53.52578483309065, 60.09287820543562, 56.69295787811279, 47.9248697417123, 43.38669899531773, 54.39174577168056, 59.360503332955496, 58.86500644683838, 51.19347258976528, 51.4188026700701, 54.442874091012136, 63.19194848196847, 62.016667638506206, 60.58337238856724, 57.96416902542114, 59.12003312792097, 51.999665124075754, 32.33157307761056, 19.26802693094526, 21.04710102081299, 17.657219103404454, 12.60604201044355, 17.171277727399552, 14.633250168391637, 11.70224118232727, 2.8297374716826846, 0.44723594720874515, 0.30713665059634615, 0.35269767152411596, 0.30084896513393944, 2.2659680204732076, 12.996557695525032, 36.18820892061506, 62.56596442631313, 77.80492728097099, 75.73005621773856, 65.27427496228898, 38.26064116614205, 27.71430230140686, 38.82552971158709, 49.51248795645577, 63.15274674551827, 65.7940627506801, 61.62633868626186, 17.534435749053955, 0.1810727965618883, 0.17167515440710954, 0.17831124046019145, 0.10480822210333177, 0.13116612524858542, 0.19399925507605076, 0.09732103600565876, 0.12562275198953493, 0.12952161420668873, 0.11631629137056214, 0.1975429177816425, 0.14227287497903618, 0.21293298767081328, 0.1236754379102162, 0.21863261397395814, 0.1450276728719473, 0.09633533496941839, 0.1608367245644331, 0.1377104597964457, 0.138004102611116, 0.2367452649133546, 0.14632723028106348, 0.09521259021546159, 0.14200296731931822, 0.18500831324074948, 0.14936543868056365, 0.16503062737839563], [0.008517234486394694, 0.019333120003076534, 0.0553134724364749, 0.05770437539155994, 0.017297857607315694, 0.02125286520458758, 0.0875896428312574, 0.028274053807503412, 0.026870670362508724, 0.012052603797721011, 0.11102223223341362, 0.047055823395826986, 0.05177090556493827, 0.016153969702177813, 0.03139664991093533, 0.03254843257101519, 0.024769505253061652, 0.015105873978297626, 0.023792048417297856, 0.037377922529620786, 0.05561913549900055, 0.015600093440817935, 0.04972319544426032, 0.018362292454444935, 0.12611422847424233, 17.735306433268956, 55.436258043561665, 60.29177039010184, 55.083035945892334, 42.57280438286917, 34.8691212109157, 20.29100673539298, 18.27254114832197, 32.96658631733486, 42.2396000453404, 44.192120279584614, 38.7397437776838, 9.983591232981, 0.7403645409005029, 0.008445101124899728, 0.08590817198689495, 0.02040364809467324, 0.14636225625872612, 1.1198990323713847, 2.184827608721597, 4.825753211975098, 4.374261873109, 4.309781721660069, 5.830491823809488, 5.774299570492335, 13.774265221187047, 11.271524957248143, 16.937239817210607, 27.753160102026804, 38.923242228371755, 49.916477067129954, 57.35481548309326, 56.7865640095302, 55.092509814671104, 56.022199630737305, 59.273567472185405, 55.645235538482666, 55.175502572740825, 54.502058846609934, 54.482388496398926, 53.9236421585083, 52.507265772138325, 54.24697657993862, 54.885060923440115, 54.69442319869995, 54.79980305262974, 52.288974217006135, 54.29608644757952, 54.44206462587629, 52.621178013937815, 49.76348120825631, 48.55652700151716, 44.83830969674246, 46.09118454796927, 47.70661987577166, 51.93243782860892, 52.5923673084804, 55.06793751035418, 52.15162917545864, 56.36602428981236, 53.27111598423549, 58.6041293825422, 32.89590229306902, 40.10414069039481, 56.853805201394216, 53.09671967370169, 54.85077156339373, 54.03961454119001, 53.6010650907244, 49.40397793906075, 56.66754831586565, 51.2392612184797, 50.13881942204067, 44.266372203826904, 46.623030935014995, 48.40173155920846, 50.14586836951119, 50.5600574357169, 54.63507168633597, 53.84755938393729, 53.30320276532854, 54.65780619212559, 44.78027834211077, 40.38141202926636, 49.117340428488596, 54.718884331839426, 53.10711417879377, 50.08284820829119, 49.28275271824428, 55.940513134002686, 56.8143880707877, 55.04304906300136, 55.59010853086199, 55.27193662098476, 57.757147448403494, 56.56030634471348, 50.654149941035676, 32.6457428250994, 31.674141475132533, 8.75676691532135, 7.745767542294093, 4.686344989708491, 3.6955349104745046, 7.345859629767282, 2.2534050260271346, 0.831168702670506, 0.019631714427045414, 0.16373218276671, 0.015258266158135874, 0.03614650021440216, 0.5332677279199872, 7.472536580903189, 29.16972930090768, 34.89264433724539, 59.404415948050364, 68.69112804957798, 48.03795167378017, 56.74674735750471, 27.66635799407959, 31.114443234034947, 43.16265433175223, 47.90144736426217, 50.0966751234872, 22.40908169746399, 0.7289626012955392, 0.06827439035155944, 0.04080602732886161, 0.034808768425136805, 0.05853007108505283, 0.032003769118871005, 0.08170648637626853, 0.032370347662695816, 0.061093209976596494, 0.05543975119612046, 0.06385224192802395, 0.07778004171060664, 0.06837553956678935, 0.0352772663214377, 0.10043008346110582, 0.02600152637543423, 0.026086331378402453, 0.020746501661571007, 0.03511743739779506, 0.04248949645885399, 0.02947723040623324, 0.03921125290383186, 0.02721189714169928, 0.031019018031656742, 0.02806280380381005, 0.03205227419467909, 0.04481055780446955, 0.046178362265761407, 0.009912329626136591, 0.03861998088125672, 0.05153380846604705, 0.04341196820938161, 0.015469348224412118, 0.06268698016979865, 0.029510573617049625, 0.021920302783006003, 0.09115604324532406, 0.041857166282300434, 0.0353292760306171, 0.029097176156938076, 0.01819437539338001, 0.03921532750661884, 0.028969465688403164, 0.03705886857850211, 0.036599327344447374, 0.06570097165448324, 0.03651478527379887, 0.02534705220854708, 0.014664654886083943, 0.0657505454229457, 0.03924739507160016, 0.2311657800206116, 21.943041699273245, 63.55767386300223, 69.08158901759556, 61.43012850625174, 51.35851315089634, 43.239286014011924, 28.144831793648855, 23.083293199539185, 26.351272446768625, 34.30738714763096, 44.7048521723066, 38.84041970116751, 9.777068189212255, 0.8259331264666149, 0.03963004471734166, 0.09713549739015953, 0.14305639293576988, 1.211937042219298, 3.4358566275664737, 4.918370962142944, 9.404047199657985, 10.781448534556798, 9.03835221699306, 13.498425211225237, 9.191079701696124, 7.073044691767011, 8.16787929194314, 16.998184204101562, 28.969221660069056, 41.59373719351632, 51.07001352310181, 57.492091042654856, 58.112040587833945, 56.59861523764474, 56.21418878010341, 59.88761452266148, 54.80361066545759, 54.35436793736049, 54.50282314845494, 54.89366626739502, 54.122280733925955, 51.63242850984846, 53.00975602013724, 55.06859064102173, 54.35344730104719, 55.599373953683035, 52.60856703349522, 56.26465702056885, 55.805777141026084, 55.57929365975516, 51.131769112178254, 50.75663587025234, 46.971816607883994, 48.717409065791536, 50.587409019470215, 53.33222886494228, 54.95246539797102, 57.59230143683297, 54.025468008858816, 56.779466424669536, 54.091357776096885, 58.799477985927034, 36.51886326926095, 42.302946771894185, 58.4488718850272, 54.385659149714876, 56.97935914993286, 55.35772602898734, 53.40664407185146, 51.2391813141959, 57.86539690835135, 52.87345320837838, 52.61268731525966, 47.396212577819824, 47.28346415928432, 50.39218895775931, 51.81497853142874, 53.52876213618687, 57.12667833055769, 55.392574719020296, 53.93507889338902, 57.1703269141061, 46.0950790132795, 43.47789410182408, 51.569602898189, 56.46666547230312, 54.22704914637974, 50.342012541634695, 49.89676850182669, 55.67521006720406, 58.662806919642854, 57.12734188352312, 56.50156627382551, 57.975824628557476, 59.33105686732701, 59.2271535055978, 52.01450300216675, 35.597080503191265, 23.93855217524937, 8.000934055873326, 7.6098712001528055, 8.633405123438154, 9.01510180745806, 8.140192457607814, 6.040679608072553, 3.7971167053495134, 0.6540917445506368, 0.3259022422134876, 0.014949405499334847, 0.06787469251347439, 0.8305085152387619, 8.35558487687792, 33.84832314082554, 44.104937757764546, 59.640071051461355, 69.23153114318848, 44.7439774785723, 46.609704290117534, 30.41451644897461, 36.41822208677019, 49.50846494947161, 54.494495732443674, 57.86084931237357, 27.278790950775146, 1.0471356511116028, 0.08277274987527303, 0.03197917900979519, 0.043149605859071016, 0.0673439899193389, 0.04088599946615951, 0.057255517691373825, 0.0421524782931166, 0.03544365328603557, 0.05851386088345732, 0.02625234514874007, 0.01974736393562385, 0.042625077933605225, 0.031028110400906632, 0.03379902010783553, 0.05611070358593549, 0.027428946923464537, 0.03631324340988483, 0.05071815509083016, 0.01772540252256606, 0.01868989085778594, 0.08715248307479279, 0.053028763604483435, 0.054986941029450724, 0.016477206821686456, 0.024746681031371866, 0.04970298867140498, 0.16428368245916708, 0.11572764867118426, 0.1957272259252412, 0.14379504615707056, 0.09326779350106205, 0.08438195674014942, 0.1067435871809721, 0.12224857376090117, 0.09193333225058657, 0.13706659791725023, 0.15276864463729517, 0.06072908772953919, 0.12098006611423832, 0.13934203796088696, 0.09254632078643356, 0.15151047786431654, 0.05328121255817158, 0.20819891669920512, 0.19801002128848008, 0.1262950309153114, 0.1214453647179263, 0.07960874108331543, 0.15926431465361798, 0.13967602646776608, 0.5403715010200227, 29.4847571509225, 74.13480540684291, 75.11043671199253, 71.80385848454067, 57.37801551818848, 48.08563368661063, 31.23740550449916, 26.07221715790885, 44.12082828794207, 56.463014193943565, 57.09130505153111, 51.12321935381208, 12.384532570838928, 1.1963231371981757, 0.1366670357861689, 0.35267321712204386, 0.22474052836852415, 0.9394438926662717, 3.854286483355931, 8.652423211506434, 14.724575553621564, 12.683204361370631, 11.600227730614797, 14.691111292157855, 11.505477752004351, 23.257562705448695, 19.558096851621354, 22.534467152186803, 33.914303234645296, 43.7273656981332, 53.15569250924246, 60.46275860922677, 60.56675924573626, 59.50967420850481, 59.52719061715262, 62.393760272434776, 56.02099411828177, 56.20785549708775, 56.01813840866089, 55.205602169036865, 53.88814728600638, 52.88038403647286, 53.847514220646445, 55.41861309323992, 54.763790539332796, 56.36219235828945, 54.93304170880999, 57.40438740594046, 58.69815935407366, 57.652479784829275, 54.30411161695208, 52.98809501102993, 51.0292067527771, 49.86214215414864, 53.411431380680625, 54.843955380576, 58.47888810294015, 59.932902881077354, 56.17632457188198, 59.881548745291575, 56.595450333186555, 59.2254581451416, 40.483866691589355, 45.094128472464426, 59.350067138671875, 56.41169479915074, 58.5654696055821, 57.935101236615864, 55.31251410075596, 50.93614952904837, 60.47179821559361, 56.029394490378245, 56.05475888933454, 49.400687967027935, 49.59074204308646, 52.46967601776123, 53.66679157529558, 54.61638103212629, 57.73717137745449, 55.62257398877825, 56.486290659223286, 59.79727404458182, 48.00627136230469, 45.66480139323643, 54.612823554447715, 61.250517572675435, 55.13131897790091, 50.43246419089181, 50.5899520601545, 56.75821188517979, 60.73124395098005, 60.679007393973215, 59.02491923740932, 61.13092517852783, 60.88418769836426, 61.319290842328755, 54.55364574704851, 37.26613507952009, 38.58613647733416, 14.648169687816075, 15.913480077471052, 10.814759935651507, 11.68843858582633, 12.757579616137914, 8.624523588589259, 3.1384884927953993, 0.3283955869930131, 0.413918032177857, 0.16016549058258533, 0.24302065532122338, 1.1986641372953142, 10.919807144573756, 39.52231591088431, 46.5063533101763, 65.5821704864502, 74.87214824131557, 57.80734123502459, 67.50620310647147, 36.418704986572266, 41.6212729045323, 56.38149445397513, 62.701190267290386, 65.59744957515171, 33.32855272293091, 1.5434561158929552, 0.12936069284166607, 0.15358595363795757, 0.0847578379990799, 0.1710105836391449, 0.09271594775574547, 0.18280877412429877, 0.10521507848586355, 0.1378817084644522, 0.12962838847722324, 0.12876474910548755, 0.12011862519596304, 0.07632273848035506, 0.1158214086400611, 0.16765707358717918, 0.07612048076199633, 0.08877828012087516, 0.08344565983861685, 0.07532902394554444, 0.09171037242880889, 0.10875453427433968, 0.17480054098580564, 0.10329640536968197, 0.16877551642911776, 0.12294921545045716, 0.11563002105270113, 0.1811229402997664], [0.07165771523224455, 0.00644833710975945, 0.06446404981293849, 0.0458277971483767, 0.050658851130200286, 0.019256565985935073, 0.014147578123291689, 0.07540187146514654, 0.08046709466725588, 0.09145879199994461, 0.014345427908535515, 0.05457929754629731, 0.03153613296204379, 0.01901101434071149, 0.00872166860582573, 0.006306419390187199, 0.0251757492577391, 0.056093628252191205, 0.05754736917359488, 0.025568266498989294, 0.07460931542196444, 0.014745600721133607, 0.04692971766261118, 0.04196591169706412, 0.866277950150626, 25.860102551324026, 60.554718017578125, 57.70691892078945, 54.12425749642508, 39.91349949155535, 25.07187979561942, 21.165204763412476, 25.56802633830479, 37.10367577416556, 45.29613692419869, 40.98738874707903, 14.311168159757342, 1.139335532273565, 0.029631220536040406, 0.07280306877302271, 0.027512961433136036, 0.2139093317091465, 0.3935512607651097, 3.4034956097602844, 3.168410910027368, 4.385452381202152, 10.920498490333557, 6.517338625022343, 11.328972663198199, 11.934644528797694, 10.36741146019527, 20.784721408571514, 35.684985637664795, 52.191216536930625, 56.56071628843035, 55.95166151864188, 54.57048123223441, 54.05673142841884, 55.13706513813564, 55.03933872495379, 54.65130615234375, 58.50215762002127, 54.11459602628435, 53.24919441768101, 54.225159236363, 51.719729151044575, 54.58197355270386, 51.992821148463655, 54.787511689322336, 51.63655226571219, 52.493605613708496, 52.52301386424473, 54.45234101159232, 54.016480513981406, 50.53311232158116, 46.7561479977199, 45.79101889474051, 44.20322002683367, 46.22393683024815, 47.26383202416556, 51.68418564115252, 51.792813777923584, 54.77429968970162, 52.18076992034912, 56.25665616989136, 51.67170320238386, 60.253590038844514, 31.999713216509136, 39.06528772626604, 56.1086664881025, 49.819612230573384, 53.13472631999424, 50.70989533833095, 51.63069840839931, 49.22388757978167, 55.08609662737165, 51.51030002321516, 50.10170909336635, 46.92817497253418, 45.03262996673584, 42.64647265842983, 46.93341391427176, 48.67976025172642, 53.51157924107143, 54.790124211992534, 54.560600893838064, 53.843074321746826, 42.29919474465506, 40.36007063729422, 51.484706333705354, 51.59007576533726, 53.64790289742606, 48.985067571912495, 48.47742176055908, 52.75766147886004, 56.151300634656636, 52.04509244646345, 49.72446012496948, 50.94315331322806, 54.27254247665405, 56.14681557246617, 56.9693363734654, 51.1444982119969, 28.78863624164036, 15.149421419416155, 11.52345187323434, 9.845148376056127, 5.287808418273926, 5.97358432837895, 5.240743926593235, 5.098077867712293, 0.5392666831612587, 0.12775344694299356, 0.054369531837957244, 0.0859997606437121, 0.09926600235381297, 0.7053572365215847, 11.478572590010506, 35.645471232278005, 43.43832411084856, 43.06989588056292, 64.21083927154541, 84.63536780221122, 46.074759006500244, 25.184704644339426, 46.10352802276611, 47.666073662894114, 54.96973861966814, 36.13000386101859, 4.3047785844121655, 0.06375457359743969, 0.024036843495975648, 0.011466381772022163, 0.040893337822386196, 0.021577766431229453, 0.07981388257550341, 0.00641647183303056, 0.003951508476997593, 0.04685205254437668, 0.023572874820924232, 0.02140485874510237, 0.08210242513035025, 0.040734770973878245, 0.03366040558155094, 0.08225421341402189, 0.018952953795503293, 0.06814002006181649, 0.0698656906772937, 0.03347886014463646, 0.07957046492291348, 0.05986512266099453, 0.009205785530087138, 0.01291749082572226, 0.04207217028098447, 0.03978910350373813, 0.022027945578364388, 0.11115443799644709, 0.021741885392527496, 0.007739777543715068, 0.019075000192970037, 0.034568434714206626, 0.019845768476703336, 0.020997257670387626, 0.018014271843380163, 0.01614259066991508, 0.04416266881993838, 0.018914221320301294, 0.018755941152838723, 0.06692997499236039, 0.017978570723373975, 0.05393112018438322, 0.026216654206759164, 0.030104145873337984, 0.02347086725889572, 0.03623068605416587, 0.0639797318726778, 0.06740448131625142, 0.030312252563557456, 0.019144310848787427, 0.061818652121084075, 1.1566852927207947, 33.311467102595735, 68.60898644583565, 65.51617649623326, 58.73323386056082, 45.44159746170044, 36.32809352874756, 28.68863081932068, 25.1158584186009, 35.1990772656032, 44.22243527003697, 39.38546766553606, 14.825558934892927, 1.6253425904682703, 0.046539173261927705, 0.06360858678817749, 0.10782918892800808, 0.7879781031182834, 2.192690363952092, 5.130413915429797, 5.557421539510999, 7.067092256886618, 15.32752285684858, 10.863796847207205, 10.4062579699925, 7.240926197596958, 13.61683293751308, 22.913474014827184, 36.36086818150112, 51.09541266305106, 58.4567164012364, 57.89404780524117, 58.1179951940264, 57.28364161082676, 57.85922343390328, 59.10817950112479, 55.690965107509065, 59.01467064448765, 55.17213617052351, 53.68805653708321, 53.44318812234061, 50.333702496119905, 53.40705401556832, 51.90561430794852, 54.688388688223704, 51.97945281437465, 54.01192944390433, 53.54354790278843, 56.437503882816856, 55.16859258924212, 54.05047804968697, 49.384550775800435, 48.441819190979004, 46.75079788480486, 49.00667994362967, 49.26960325241089, 54.340006010872976, 53.982479504176546, 56.0789281981332, 53.94229112352644, 57.40807342529297, 51.92731005804879, 60.660261154174805, 34.58737523215157, 41.889594963618684, 58.278950214385986, 52.4188186781747, 53.00987761361258, 54.32161065510341, 52.83766998563494, 50.8447390283857, 55.71526990618025, 53.8238000188555, 51.38616350718907, 50.21584367752075, 47.049115317208425, 44.942560468401226, 47.8449307169233, 51.040633065359934, 56.35890933445522, 55.24121168681553, 54.963231631687705, 56.24525417600359, 42.500577858516145, 43.05369962964739, 52.01814385822841, 54.708163261413574, 53.37342473438808, 48.57027748652867, 49.26612567901611, 54.13360282352993, 57.23948580878121, 54.269850049700054, 50.984637532915386, 52.81121471949986, 55.18783562523978, 59.01182188306536, 59.62407629830496, 54.28720317568098, 34.39826611110142, 17.101865223475865, 7.380119459969657, 6.15351140499115, 7.158173586641039, 8.995138764381409, 7.790363686425345, 6.827096700668335, 3.519867730992181, 0.5105217141764504, 0.11207553571356194, 0.08061470317521266, 0.08239524013229779, 0.7705512610929353, 12.392539501190186, 35.1421263558524, 45.00381578717913, 46.498595646449495, 57.028145926339285, 76.62077358790806, 45.04986844744001, 28.868505784443446, 49.872633934020996, 54.02015611103603, 60.756278310503276, 43.46178470339094, 5.522999729428973, 0.10543769225478172, 0.016201857311118926, 0.014530547528660722, 0.061098502549741945, 0.024398327938147953, 0.020742622137601887, 0.026850098877080848, 0.06064377552164452, 0.04898224877459662, 0.052413878563259325, 0.03052826418674418, 0.09066281614026853, 0.010449599591083825, 0.018272761455071822, 0.030749351251870394, 0.02955418306269816, 0.05099630355834961, 0.04553883961801018, 0.01258207909164152, 0.09088372678628989, 0.006189558696600476, 0.023786526838583604, 0.02221531793475151, 0.011236818956344255, 0.06906423225466694, 0.03494856360235384, 0.19245617144874164, 0.11922620236873627, 0.17095654511025973, 0.12964304483362607, 0.09867322059082133, 0.11298863350280694, 0.13401685442243302, 0.23349630353706224, 0.1683830517743315, 0.18159416929951736, 0.1386377186115299, 0.13338756747543812, 0.13228037474410875, 0.08088840384568487, 0.15514126446630272, 0.05103027102138315, 0.10075025020965508, 0.15318929563675607, 0.13603264625583375, 0.1044002054259181, 0.1322961574686425, 0.12204726599156857, 0.13059120252728462, 0.2280334723847253, 1.7494687927620751, 41.90720864704677, 77.9932165145874, 74.0875437600272, 69.98640428270612, 54.04981797082083, 38.81639977863857, 32.88357966286795, 36.10243688310896, 49.88183682305472, 57.208663599831716, 51.68492215020316, 18.535172632762364, 2.1865991822310855, 0.1913826069129365, 0.18165993291352475, 0.11983279910470758, 1.0672290814774377, 2.5936743787356784, 8.886644380433218, 12.294280682291303, 13.348492639405386, 21.13152858189174, 12.96242380142212, 20.463052817753383, 21.16108795574733, 16.235945974077495, 26.7724791935512, 38.49801942280361, 55.12136220932007, 60.4366820199149, 61.08912481580462, 60.37205682482038, 60.6707946232387, 58.90761974879673, 61.13751901899065, 57.639375482286724, 62.156861441476, 56.08371550696236, 56.33630684443882, 54.01003605978829, 50.896107060568674, 54.06200858524868, 51.78414937428066, 55.85891348975045, 52.681665556771414, 55.5106315612793, 54.77564764022827, 57.69191428593227, 58.22831521715437, 55.347546918051584, 50.851190430777415, 51.082693985530305, 49.40798010144915, 51.1482571874346, 51.32959474836077, 55.59804684775216, 55.37391880580357, 57.61916664668492, 55.75886637823922, 59.49670192173549, 54.24675076348441, 62.894739287240164, 37.84024388449532, 42.65327147075108, 58.993999753679546, 53.293343271527974, 55.9483437538147, 55.940356799534385, 54.72167750767299, 51.232778549194336, 57.05223880495344, 55.41357217516218, 52.206422669546946, 51.39447702680315, 49.327704089028494, 46.608811446598594, 49.35979087012154, 52.514578751155305, 57.94852863039289, 56.44906915937151, 57.64573655809675, 59.97132641928536, 45.941551617213655, 45.10922343390328, 55.225109236580984, 57.396244117191856, 55.07673045567104, 49.02842780521938, 49.258899552481516, 54.79422017506191, 61.508177621024, 56.32144117355347, 54.23552942276001, 54.100432123456685, 59.267411368233816, 61.793679101126536, 62.131368500845774, 55.005497523716514, 35.34430503845215, 19.780334983553203, 19.00256405557905, 20.305007355553762, 14.416706085205078, 14.750405481883458, 16.96715702329363, 11.252953290939331, 2.7799408180373053, 0.2613774431603295, 0.1553983206727675, 0.21602070198527404, 0.1968355043126004, 1.3781152623040336, 16.290956599371775, 48.567925521305625, 55.409177439553396, 50.84479808807373, 71.50420352390834, 89.55485221317836, 54.43102046421596, 34.729778562273296, 60.05994374411446, 62.946697916303364, 68.73160130637032, 51.158026354653494, 7.887599383081708, 0.2216444137905325, 0.1345119678548404, 0.07930216539118971, 0.1801084761640855, 0.142457015812397, 0.19601732678711414, 0.0701608873371567, 0.1428134095455919, 0.1227943194764001, 0.1352184856576579, 0.09578199644706079, 0.25663209493671146, 0.10835717059671879, 0.14821739814111165, 0.11005535375859056, 0.08401017383273159, 0.14591352748019354, 0.12257813821945872, 0.07294927271349089, 0.15745071268507413, 0.09227171766438655, 0.13456280369843754, 0.12667283921369485, 0.07363240819956575, 0.13171685141112122, 0.13410183414816856], [0.06457538383879832, 0.015774168207177093, 0.03523711061903408, 0.026936571379857402, 0.07071285521877663, 0.06641174387186766, 0.0261755434663168, 0.049178236829383035, 0.03652194721092071, 0.018806220597720573, 0.007587932432735605, 0.021044388712782944, 0.025949979766405055, 0.03128222855074065, 0.09369926034872021, 0.02745860568912966, 0.02999225544876286, 0.022620966524950097, 0.034687653316983154, 0.06886882095464639, 0.04483546003965395, 0.032603105530142784, 0.024732718477025628, 0.05698280089667865, 9.649935262543814, 51.572382177625386, 57.87790019171578, 52.52882603236607, 41.1873266356332, 35.085401262555806, 17.9796815259116, 15.649111543382917, 25.11751208986555, 35.650550365448, 45.51692983082363, 21.72549707548959, 2.6808475639138902, 0.0726627070190651, 0.07605264083083187, 0.05881823133677244, 0.12464537657797337, 0.25427695416978424, 2.3363345989159177, 3.6586629918643405, 3.6397992840835025, 8.175737704549517, 13.571147663252694, 11.989748086248126, 18.938602413449967, 14.700161320822579, 28.333623034613474, 35.17722518103463, 49.13267510277884, 52.20690556934902, 54.453386715480256, 51.976941040584016, 51.66032205309187, 51.49267939158848, 51.993112972804475, 51.1481043270656, 54.52754136494228, 53.067978450230186, 56.010929652622764, 54.89316599709647, 56.0982163974217, 52.155228342328755, 50.30091742106846, 53.026115553719656, 53.15486567361014, 53.8744523865836, 52.76101745877947, 51.27766043799264, 53.1127804347447, 53.02156795774187, 50.16884953635079, 46.44259663990566, 47.067191055842805, 44.31109775815691, 47.53083392551967, 51.20287697655814, 55.33486992972237, 51.38718836648123, 53.63533708027431, 51.66535949707031, 55.44198335920061, 50.2011273929051, 59.114009039742605, 34.11104842594692, 45.13559184755598, 56.36767101287842, 48.84308460780552, 49.360805307115825, 50.73335593087332, 53.72160243988037, 48.40767226900373, 52.917782715388704, 53.16097661427089, 53.04066855566842, 49.51288052967617, 47.00093303407942, 44.52735696520124, 43.345412799290244, 45.70883560180664, 49.976565088544575, 52.54915298734392, 52.17272738048008, 48.069604192461284, 39.96637528283255, 40.5100405556815, 48.34787607192993, 52.57109192439488, 51.698957511356895, 48.755585942949565, 50.04951769965035, 56.92109155654907, 55.1029668535505, 51.41847610473633, 45.97465978349958, 48.997133118765696, 49.3932603427342, 53.107246194567, 56.033594676426475, 58.06254856927054, 50.37441546576363, 34.713571889059885, 16.156712191445486, 13.31821152142116, 9.050772990499224, 7.339026944977896, 6.280701220035553, 5.896970885140555, 2.6311425396374295, 1.1283365339040756, 0.05192701272400362, 0.09950406636510577, 0.07243060733058623, 0.0835269144071, 1.6005801877805164, 22.4803215776171, 45.527689116341726, 49.52419219698225, 83.52150208609444, 79.10371235438755, 42.56823246819632, 28.55619294302804, 35.60780504771641, 43.13395479747227, 51.51223162242344, 42.38257312774658, 12.860597082546779, 0.04906244143577559, 0.03248074870290501, 0.08596710953861475, 0.011215815753010767, 0.07627700522009816, 0.02637414218458746, 0.027377101759027158, 0.03694085098270859, 0.04991708343316402, 0.016258055277700936, 0.024529008693726997, 0.03705627657473087, 0.028321953290807347, 0.054752198447074206, 0.07621522460665021, 0.044666135018425326, 0.058318463154137135, 0.01534359363306846, 0.10463250188955239, 0.01996574194968811, 0.06915001265172448, 0.043488038770322285, 0.07462502350764615, 0.0954794648236462, 0.04104643567864384, 0.016657510539516807, 0.016545889832611595, 0.08239382199410882, 0.10092004681272165, 0.05089874040069325, 0.05782124626317194, 0.07268642860331706, 0.0342681829684547, 0.06505354746643986, 0.022172292029219012, 0.02527229461286749, 0.06953810754099063, 0.03909197323290365, 0.033940002721335204, 0.06595013649868113, 0.08014865139765398, 0.027566392673179507, 0.02111791816007878, 0.009637959750502237, 0.05305787614945855, 0.00891280937607267, 0.036618238115417104, 0.019780630811250637, 0.02346368835839842, 0.03324587157528315, 11.745949694088527, 59.57220104762486, 65.33454363686698, 60.77221747807094, 48.836886814662385, 42.834400585719514, 20.882324491228374, 19.841592039380753, 26.58607986995152, 33.00363411222185, 40.867049421582905, 22.139185871396744, 2.941196999379567, 0.11302574258297682, 0.08295721640544278, 0.14654487717364514, 0.5770094064729554, 3.1607162143502916, 6.038774498871394, 6.604402593203953, 7.054623280252729, 8.192534974643163, 11.376124007361275, 11.755553841590881, 8.232505355562482, 11.767317141805377, 26.09108325413295, 39.21705722808838, 51.75012057168143, 55.8554185458592, 57.77998965127127, 55.308313914707725, 52.628414562770296, 52.97531727382115, 54.20144850867135, 54.12049157278878, 56.73063448497227, 55.86511475699288, 57.28743532725743, 55.47192314692906, 57.6125693321228, 53.09975951058524, 51.47415896824428, 53.49692896434239, 52.9685115133013, 53.52155685424805, 52.498879296439036, 52.20790263584682, 56.190804617745535, 53.22985063280378, 52.37598303386143, 47.35052122388567, 48.74158532278878, 46.63677099772862, 49.394479751586914, 51.471511704581125, 58.26499823161534, 53.43221691676548, 55.31481395448957, 52.84472588130406, 55.36160659790039, 52.25955554417202, 58.54447214944022, 35.575273581913535, 47.27882971082415, 59.403269495282856, 49.84213481630598, 50.38186046055385, 53.004103660583496, 54.87397854668753, 49.40492636816842, 53.15501158578055, 55.083782877240864, 54.54021487917219, 52.77270780290876, 49.78966202054705, 46.98896128790719, 44.53961706161499, 48.17921897343227, 51.307860783168245, 53.33143677030291, 53.50943572180611, 49.80836309705462, 41.5671568598066, 42.973878724234446, 51.324171679360525, 54.80174854823521, 52.71740014212472, 48.61445413316999, 51.473533630371094, 57.39395121165684, 57.84550421578543, 53.851047379629954, 47.82429804120745, 51.08376400811331, 51.97119835444859, 54.23586293629238, 57.91844293049404, 59.702097620282856, 52.319587979997905, 36.332377093178884, 18.181742089135305, 8.208724277360098, 9.014842118535723, 8.47369122505188, 8.29500961303711, 8.890895809446063, 6.061884207384927, 2.2080011538096835, 0.5174465168799672, 0.2322884297796658, 0.027704718822081174, 0.13050072666789803, 1.853641722883497, 23.43525767326355, 46.66092641013009, 45.07802949632917, 72.77051966530937, 80.45927115849086, 47.78620106833321, 30.5663971219744, 41.02355759484427, 48.55787147794451, 56.88480806350708, 50.78486292702811, 14.579726457595825, 0.06800831641469683, 0.06315085384994745, 0.09033579618803092, 0.06912589073181152, 0.033097570961607356, 0.08733901913676943, 0.026537290840808834, 0.04338760201686195, 0.042224939047758064, 0.0367433464021555, 0.032423809436815124, 0.015501442930794187, 0.023936652711459568, 0.0574704504438809, 0.045248199320797405, 0.005796408721445394, 0.06492541291351829, 0.004319134085173053, 0.06720346531697682, 0.09561580965029341, 0.06003576064748423, 0.04460333660244942, 0.04417746427602001, 0.020534359384328127, 0.030875022722674266, 0.002162714596904282, 0.13473459519445896, 0.1407595926097461, 0.14619121115122521, 0.126224137576563, 0.10604739668113844, 0.16720333722020897, 0.11498716340533324, 0.1506475984518017, 0.21987710148096085, 0.05857746675610542, 0.11231288047773497, 0.21081081511718885, 0.13707241974771023, 0.1262826272951705, 0.15497183427214622, 0.11285697735313859, 0.18099461575703962, 0.09933917557022401, 0.2594348245433399, 0.10418599870588098, 0.1571646151798112, 0.1362068261951208, 0.1365279225366456, 0.16054270177015237, 17.35915528024946, 70.16945457458496, 73.49754442487443, 69.80247851780483, 55.58008575439453, 49.512731143406455, 27.088106325694493, 22.001071316855295, 37.06515496117728, 48.19411938531058, 56.23271267754691, 27.773466212408884, 3.558624565601349, 0.3100323937833309, 0.23162256979516574, 0.2636989285903317, 0.41972504343305317, 3.3674049292291914, 9.049090657915388, 15.324239833014351, 11.851043803351265, 16.96945513997759, 22.511777809688024, 19.771542038236344, 27.699367148535593, 20.45768186024257, 32.7189108303615, 42.694258894239155, 53.79543399810791, 56.98576191493443, 59.73336451394217, 57.334151540483745, 54.78733451025826, 54.459344795772004, 57.366387707846506, 54.94890792029244, 58.842132977076936, 57.54535593305315, 61.17226696014404, 58.608451162065776, 58.92430237361363, 54.5005441393171, 52.27406685692923, 54.768035888671875, 53.428402355739046, 54.38503728594099, 53.651057379586355, 53.9935861996242, 57.73827266693115, 56.73450810568673, 53.536578859601704, 49.93731471470424, 51.10232959474836, 49.86637708118984, 51.17901338849749, 55.435879366738455, 60.54014764513288, 56.92624364580427, 56.54892519542149, 55.66584389550345, 57.51349496841431, 52.73843581335885, 59.73483058384487, 39.62958567483084, 50.2121124948774, 60.705598149980815, 53.67332983016968, 52.389313152858186, 55.7163850920541, 57.99961526053292, 49.547444343566895, 54.36049277441842, 56.86361605780465, 57.09866319383894, 55.83226019995553, 51.88712862559727, 49.313453333718435, 47.126427922930034, 50.78845861979893, 54.87099082129342, 57.46828651428223, 56.49274900981358, 51.583065032958984, 43.558190958840505, 45.04917710168021, 54.15894637789045, 57.13842078617641, 53.19264302934919, 49.28991978509085, 52.68255145209176, 59.5999938419887, 59.97281333378383, 56.69232906614031, 49.086931637355256, 53.581769943237305, 53.21882036754063, 56.83974552154541, 60.01531546456473, 61.763371058872764, 52.94091326849801, 38.955759797777446, 21.667701959609985, 19.897076879228862, 19.351554700306483, 13.858312368392944, 13.206130129950386, 13.883880870682852, 8.924813440867833, 2.3603979476860593, 0.18471057207456656, 0.24212444626859256, 0.2450639685349805, 0.3099736055093152, 2.8340822671140944, 28.738140208380564, 57.673206261226106, 59.32274682181222, 88.35604476928711, 81.55604430607387, 48.77839340482439, 41.31554174423218, 50.527821268354145, 56.07367883409773, 65.08333846500942, 59.1133211680821, 17.67688250541687, 0.15460128629846231, 0.08401416361864124, 0.18215126012052807, 0.1997836846858263, 0.10726173687726259, 0.13251319367970738, 0.14092002542955534, 0.14670000384960855, 0.1818016924496208, 0.0695078516645091, 0.15434379582958563, 0.1277047281286546, 0.10083840547927789, 0.21306199074855872, 0.09997366688081197, 0.12268989293703012, 0.1301032408539738, 0.05354247907442706, 0.2519124767610005, 0.19368784821459226, 0.30972884435738834, 0.23209955277187483, 0.15507133464728082, 0.10588669244732175, 0.09061719144561461, 0.0797017343076212], [0.04188553583143013, 0.0285263042896986, 0.02651929609211428, 0.03939652010532362, 0.017726081057584712, 0.03519077006993549, 0.014017223064521593, 0.04833705357408949, 0.09295251220464706, 0.04565944582489984, 0.04623271292075515, 0.031626327229397636, 0.005924551331970308, 0.07347504235804081, 0.06258743229721274, 0.03065684318010296, 0.04257961269468069, 0.020626531581261327, 0.022745542161698853, 0.05241431961102145, 0.030927843281200955, 0.030936202832630703, 0.03618425729551485, 0.3052596056035587, 22.378410611833843, 58.52885954720633, 58.82688862936837, 48.85133211953299, 35.26708623341152, 27.607494592666626, 28.520227330071585, 30.117880480630056, 38.66418211800711, 50.032661369868684, 31.309246403830393, 4.905240169593266, 0.31119561993650025, 0.0821256378133382, 0.05136869375460914, 0.05736628174781799, 0.6552177869847843, 1.6659809755427497, 2.4970514263425554, 4.0980744532176425, 4.384574736867632, 3.4717675234590257, 20.618560450417654, 12.139086587088448, 10.921525086675372, 26.5565812928336, 47.40608596801758, 58.65457330431257, 57.463481834956575, 57.421858651297434, 54.04943234579903, 53.58913850784302, 48.29011917114258, 46.77842392240252, 46.75337566648211, 46.87986762183053, 50.01684379577637, 53.11592102050781, 49.60133457183838, 52.44783435549055, 52.89622245516096, 56.616760458265034, 55.753366879054475, 52.06497124263218, 52.85893842152187, 50.13986512592861, 51.07783024651663, 51.06670618057251, 55.01103523799351, 51.44523709160941, 50.49252094541277, 45.17805576324463, 43.326711722782676, 44.17350952965872, 47.484847273145405, 50.40469571522304, 55.441288539341514, 48.67692191260201, 52.57343346732003, 50.842366218566895, 54.41428920200893, 51.68945932388306, 58.230816568647114, 33.604225976126536, 43.180580684116904, 55.035941055842805, 47.82351636886597, 46.680339676993235, 50.506167207445415, 52.796838896615164, 49.66433736256191, 51.186437538691926, 51.47420760563442, 54.412729331425254, 51.198999881744385, 48.30650649751936, 44.19330494744437, 44.50806876591274, 41.4885379927499, 44.41258314677647, 46.55881220953805, 46.80038022994995, 43.08004372460501, 37.89365816116333, 40.981441089085166, 50.58070748192923, 52.37009790965489, 52.1641845703125, 48.163846084049766, 47.975268500191824, 53.20454181943621, 54.19862059184483, 49.61980288369315, 43.524078777858186, 48.495455810001914, 53.25194590432303, 55.66255044937134, 54.139321190970286, 56.90625715255737, 52.12077917371477, 49.399770804813926, 32.20633527210781, 15.60556891986302, 8.790847829410009, 7.524616803441729, 5.819351255893707, 7.05761057138443, 7.388192398207528, 2.426753895623343, 0.7694964919771466, 0.2121015108589615, 0.13632854180676596, 0.03677571591522012, 0.03684702655300498, 3.8482024669647217, 27.70517063140869, 46.56689991269793, 48.099839278629844, 42.2384466443743, 17.286695991243633, 18.566406522478374, 36.1897931098938, 40.369850226810996, 47.785200527736116, 52.78447805132185, 14.962316853659493, 0.6099144465156964, 0.05771483161619731, 0.05776618993175881, 0.022167152126452754, 0.06812131285135235, 0.04110107810369559, 0.12237334278013025, 0.041165776417723725, 0.024116009872938906, 0.032950895439301214, 0.08330226503312588, 0.05248918577230402, 0.06810755216117416, 0.0401078555067735, 0.003312046473313655, 0.07683046587875911, 0.08772259498281137, 0.013824911821367485, 0.08069045482469456, 0.014257014795605625, 0.024771038742203797, 0.024865618042115654, 0.05468836187251976, 0.024319044513893977, 0.03902575500043375, 0.029377109171556573, 0.06030276417732239, 0.036091847611325126, 0.010485531412996352, 0.02766732475720346, 0.02026317098976246, 0.015574658555643899, 0.014673886355012655, 0.03597155353054404, 0.024781991993742328, 0.01819027534552983, 0.05496520416012832, 0.011380174746071654, 0.06101225396352155, 0.0336005825416318, 0.05897270661911794, 0.013603248849644192, 0.025686372304335237, 0.023709440171452503, 0.01918056158215872, 0.024367653066292405, 0.025190400525129268, 0.02798959326797298, 0.046935230759637694, 0.720765192593847, 29.75209951400757, 67.14088072095598, 65.93760558537075, 55.959627628326416, 41.83173731395176, 33.910255908966064, 32.4217745917184, 26.646020242146083, 29.370094503675187, 47.90531403677804, 32.25111641202654, 5.142302717481341, 0.20070960000157356, 0.04567407164722681, 0.007677559275180101, 0.4114300071128777, 2.9122679574148993, 5.980864303452628, 7.192860731056758, 7.52070757320949, 8.787101881844656, 8.420723370143346, 10.61034653867994, 10.1427093233381, 16.302766799926758, 28.17228412628174, 50.16426372528076, 59.928240639822825, 59.47994981493269, 58.35732936859131, 55.98444659369332, 54.41014460154942, 52.29471690314156, 49.55494144984654, 48.13995470319475, 48.926713126046316, 52.309315068381174, 53.909881251198904, 53.794332708631245, 53.2517409324646, 55.21907820020403, 57.604749134608674, 56.10261460712978, 51.905478818076, 52.616804122924805, 50.53862224306379, 51.2374199458531, 52.66465636662075, 56.95267459324428, 53.80743701117379, 52.660091400146484, 47.25121756962368, 45.03584003448486, 44.916261536734446, 49.719669342041016, 52.892960275922505, 55.14490965434483, 49.381490094321116, 54.35338476725987, 51.31308235440935, 56.06484072549002, 52.013780389513286, 59.43278544289725, 36.10307264328003, 45.94721787316458, 57.28801897593907, 49.26838036945888, 48.82189607620239, 51.46249641690935, 54.417190074920654, 49.96888385500227, 51.513503142765586, 52.093170506613596, 54.815978458949495, 52.449647835322786, 50.797081334250315, 46.194059576307026, 44.47418934958321, 44.18855932780674, 46.965208871024, 48.079689502716064, 48.96663052695138, 45.345104353768484, 39.72499138968331, 43.18144226074219, 53.254746028355186, 54.075331756046836, 52.894742488861084, 48.75785105569022, 48.643386432102744, 56.0679361479623, 56.225552558898926, 51.690150669642854, 44.83309507369995, 50.74961124147688, 55.643383843558176, 58.57349477495466, 57.62644835880825, 58.604316983904155, 55.33786460331508, 50.28401245389666, 33.927285943712505, 17.606382608413696, 5.2662325245993475, 7.649495908192225, 6.131586364337376, 9.360346504620143, 11.922036153929573, 8.075568999562945, 2.21978160738945, 0.5934098692876952, 0.13269186552081788, 0.0736940802474107, 0.09424103663436004, 4.596381885664804, 31.303847653525217, 44.03422246660505, 50.91183778217861, 53.77449212755476, 27.111575603485107, 27.936707190104894, 41.61413710457938, 45.4920448575701, 52.78410979679653, 60.63626902444022, 20.092347315379552, 0.6249220669269562, 0.04801981131147061, 0.05071623483672738, 0.06905978785029479, 0.019718493966917907, 0.025840272528252432, 0.07068367142762456, 0.037808768517736874, 0.053638980324779234, 0.049637839131589444, 0.02858682282801185, 0.010011812189726957, 0.06593832998935666, 0.027748192560725977, 0.05198116321116686, 0.05784013667809112, 0.07551302228655134, 0.03629452602139541, 0.047170353321624656, 0.054965241479554346, 0.004175014519465289, 0.012783425028568931, 0.06468730140477419, 0.01903677831536957, 0.04120912802006517, 0.06959055151258196, 0.18556829462093966, 0.144005079886743, 0.05562593102721231, 0.11327310930937529, 0.20557553746870585, 0.10979597017701183, 0.08069468888321094, 0.1556017861834594, 0.13558603450655937, 0.1115264380350709, 0.08583873071308647, 0.10062073144529547, 0.11209673314754452, 0.10580834200871841, 0.175530305398362, 0.09657958043473107, 0.19700998280729565, 0.14170884953013488, 0.08080500510654279, 0.14314958293523106, 0.103810972401074, 0.16738032629447325, 0.09108638484030962, 1.1199076090540205, 37.258943693978445, 74.82822172982353, 73.97967992510114, 64.83787945338658, 49.60060848508562, 39.53778607504708, 38.23572145189558, 41.31024374280657, 53.16963406971523, 63.77650042942592, 40.54144641331264, 6.756153856004987, 0.5723084615809577, 0.1621503955019372, 0.18011154314236982, 0.37416111837540356, 2.6698364061968665, 6.581589485917773, 10.02696623120989, 10.914250322750636, 12.86272236279079, 10.012375014168875, 26.69532813344683, 20.453907251358032, 18.598618371146067, 30.279794352395193, 53.11382613863264, 62.8000214440482, 61.02595179421561, 59.64481667109898, 58.29439953395298, 58.0706501688276, 53.888727460588726, 51.626310620989116, 50.58864579881941, 51.2104366166251, 54.27771193640572, 56.97369636808123, 54.83221639905657, 56.394268717084614, 56.64877775737217, 62.18187495640346, 57.458295004708425, 54.066962650844026, 52.61883299691336, 49.83346346446446, 51.794846126011436, 52.93478495734078, 57.66487537111555, 55.55147654669625, 55.979502950395855, 49.83767407281058, 47.2631059374128, 48.83753647123064, 52.045610087258474, 54.209602219717844, 58.280166149139404, 52.51392214638846, 57.30494131360735, 53.33078711373465, 57.70175640923636, 55.830175740378245, 61.00588539668492, 39.41878775187901, 49.509104183741975, 60.09730420793806, 52.84521572930472, 50.93149423599243, 55.21007333483015, 57.32500076293945, 50.83534158979143, 51.858217171260286, 52.855578967503135, 56.615603583199636, 54.94820267813546, 52.908385276794434, 48.61625024250576, 48.9835250718253, 46.55087389264788, 48.72854355403355, 50.377427509852815, 50.82016324996948, 47.71806008475167, 41.27745519365583, 44.98802947998047, 55.91185876301357, 57.27418163844517, 53.906872681209016, 49.378898416246685, 49.10159928458077, 58.604754720415386, 58.97911671229771, 54.545655318668906, 47.477350166865754, 53.39830623354231, 58.21208422524588, 61.68329307011196, 58.61842877524239, 60.52086639404297, 55.41038990020752, 51.32703086308071, 36.55915934698922, 20.653832980564662, 15.640005929129464, 18.760499238967896, 15.231439692633492, 14.844546624592372, 17.95281979015895, 7.457423380443028, 2.5865372759955267, 0.6560255693537849, 0.327394395002297, 0.17727310902306012, 0.16358848262046063, 6.060346918446677, 38.662872382572715, 59.96630981990269, 54.8140538079398, 50.582590443747385, 27.168934719903127, 32.232675892966135, 48.09431198665074, 54.61515120097569, 60.0005783353533, 69.15039702824184, 25.315129280090332, 0.8290143268448966, 0.0692038611908044, 0.12190640212169715, 0.12901169514017446, 0.20887312266443456, 0.13658449878650053, 0.32030478971345083, 0.16496885355029786, 0.15855676547757216, 0.13634181395173073, 0.21049031588648046, 0.06514139739530427, 0.1821472839053188, 0.12922419873731478, 0.11214200500398874, 0.13701129731323036, 0.2000383660197258, 0.12988453544676304, 0.1678037185754095, 0.10032094788870641, 0.11514664627611637, 0.08421144767531327, 0.10507159547082015, 0.12547895684838295, 0.16135764946894987, 0.1410923461828913], [0.022813480480441024, 0.03770742592002664, 0.05718757597995656, 0.02766088885255158, 0.005752473578987909, 0.02914500269772751, 0.024683268541204076, 0.0601830231025815, 0.08575119969568082, 0.027587333960192542, 0.017807181259351115, 0.04374163444819195, 0.008183659885876944, 0.030813520308583975, 0.002024928095384634, 0.030897438127015318, 0.05986620831702437, 0.04053601449621575, 0.055199665150472095, 0.012500894072997783, 0.02927542052098683, 0.0267218048684299, 0.03401709787015404, 3.014163289751325, 41.518377031598774, 62.75501101357596, 53.649643421173096, 43.62109300068447, 24.853688989366802, 17.948134967258998, 20.476447207587107, 28.9185015474047, 42.308922222682405, 36.91721044267927, 10.34830391407013, 0.46166019035237177, 0.06157017259725502, 0.013668212640498365, 0.05861523401524339, 0.18854954679097446, 2.3026890328952243, 6.852331689425877, 5.951749180044446, 3.5861806869506836, 5.298422225884028, 11.280486396380834, 10.208518317767552, 17.840001889637538, 39.47486318860735, 43.520107882363455, 56.95577696391514, 55.55545439038958, 54.056602886744905, 55.3233185495649, 53.803233351026265, 52.73035158429827, 53.05125413622175, 47.49680512292044, 41.37270457404, 43.48351866858346, 48.22427109309605, 46.48950045449393, 49.28674793243408, 49.36559609004429, 51.12549488885062, 50.300722871507915, 54.33940846579415, 50.619401999882285, 50.519500800541465, 51.019416740962434, 52.41692876815796, 49.230891363961355, 55.00749513081142, 51.583502769470215, 49.54497078486851, 44.71297114236014, 42.10676785877773, 39.36950765337263, 49.07582494190761, 50.60913951056344, 53.46374784197126, 50.29745374407087, 50.14200864519392, 50.433853830610005, 53.18720953805106, 50.07728270121983, 57.02892412458147, 34.60077830723354, 43.31352056775774, 55.360074520111084, 44.89068521772112, 43.49149520056588, 48.03197969709124, 54.34747185025896, 51.54406132016863, 50.711938108716694, 49.73107133592878, 52.030577659606934, 51.073511941092356, 49.14521312713623, 49.05105461393084, 45.10745164326259, 42.05565343584333, 43.01717642375401, 44.08333580834525, 41.05285814830235, 38.94521243231637, 40.69516488483974, 40.87803104945591, 47.6983654158456, 51.28994137900216, 48.92344052450997, 47.71236603600638, 50.33090584618704, 52.77994782584054, 56.29275206157139, 49.587910652160645, 45.208415916987825, 52.56401865822928, 54.13565949031285, 55.97665766307286, 56.87165859767369, 54.80892603737967, 57.21635178157261, 56.040122509002686, 53.022203717912944, 40.806944029671804, 25.66316454751151, 8.369579417364937, 5.748651598181043, 7.993844287736075, 5.2572576233318875, 4.426056785242898, 2.450306986059461, 0.20922863430210523, 0.08455019271267311, 0.10775421759379761, 0.018475938588380814, 0.25623604761702673, 11.76017005102975, 40.943444865090505, 31.65919589996338, 14.319447806903295, 20.519682373319352, 24.611895152500697, 28.285529341016495, 40.57051420211792, 48.5236759185791, 51.56404781341553, 34.84822450365339, 2.096907926457269, 0.04171034826764038, 0.0055157233811249685, 0.0638775173574686, 0.03850781225732394, 0.02202932639712734, 0.12475806767387049, 0.04425938720149653, 0.021843068534508348, 0.03916837627600346, 0.07997897693089076, 0.01998632022046617, 0.004820253400664244, 0.05155580996402672, 0.06265670393726655, 0.08826771644609314, 0.030967652930745056, 0.02951839373313955, 0.020026043356795396, 0.07769388811928885, 0.04202854387196047, 0.031557279505899975, 0.010558331435147141, 0.05071956305099385, 0.019233663732718145, 0.08565760936055865, 0.0991420882887074, 0.028750081746173755, 0.0593512070232204, 0.024605253977434974, 0.00844105620801981, 0.005209368212880301, 0.036252806295773814, 0.047865149431994984, 0.038288811687380075, 0.016036408421184336, 0.029373177061123506, 0.0183190104019429, 0.024633772804268768, 0.05908009157116924, 0.005174754021157111, 0.01908948182660554, 0.042134473366396766, 0.057723876487995894, 0.029729177244007587, 0.0764866318287594, 0.030463996742452894, 0.019412841082417538, 0.04740349456135716, 4.872060350009373, 49.899179526737754, 70.1490546635219, 61.26224613189697, 50.72622013092041, 31.608335086277553, 23.708365304129465, 26.97223469189235, 35.87264953340803, 45.743746825626914, 37.49514423097883, 10.358639359474182, 0.4794189174260412, 0.020632974271263396, 0.019971263528402363, 0.28658485625471386, 0.6461361657295908, 3.9745159404618398, 7.689409834997995, 7.099215081759861, 8.691491195133754, 8.25051508631025, 8.489829284804207, 11.405391556876046, 21.831941740853445, 38.52219220570156, 49.90571083341326, 57.66772065843855, 57.99080841881888, 55.53223698479788, 56.2933600289481, 55.821341105869834, 55.66330780301775, 54.37520211083548, 49.17178651264736, 42.23213768005371, 46.37696048191616, 49.54407794134957, 48.95076778956822, 50.29110656465803, 50.29512957164219, 52.47045421600342, 52.38591548374721, 55.724556173597065, 51.16499539784023, 51.172398703438894, 51.189953327178955, 52.41314894812447, 49.96936328070504, 56.74989489146641, 53.447037424360005, 51.883411339351106, 47.86609492983137, 44.09197241919381, 40.55369956152779, 50.681504998888286, 52.86489302771432, 55.39501701082502, 52.06988361903599, 52.615233830043245, 51.06747743061611, 53.832123960767476, 51.21306650979178, 56.25381783076695, 36.6355756350926, 45.5198689188276, 56.2701530456543, 46.91682856423514, 45.02353477478027, 49.95790917532784, 56.91153430938721, 52.984422888074604, 51.07594381059919, 50.431821482522146, 52.668307644980295, 52.12561164583479, 50.036222321646555, 50.2291008404323, 47.13773611613682, 45.15733276094709, 46.09470381055559, 44.98763690676008, 43.18483645575387, 41.37713057654244, 42.55489192690168, 42.92960827691214, 50.70274216788155, 54.2725042615618, 50.09765829358782, 48.94519880839756, 50.053492069244385, 53.96475117547171, 56.71591820035662, 50.64886236190796, 46.32311194283621, 55.95959983553205, 56.413581235068186, 57.47240332194737, 56.37454972948347, 56.22435399464199, 57.189111368996755, 57.22337293624878, 55.571275438581196, 41.29678160803658, 21.780846425465175, 7.105050265789032, 4.579315372875758, 7.884749753134591, 11.241935185023717, 10.719222205025808, 8.094250968524388, 2.9559601843357086, 0.3858471470219748, 0.0059460850648715025, 0.06500705424696207, 0.306413006569658, 12.450934767723083, 41.257024015699116, 38.76463222503662, 21.371804237365723, 23.20670883996146, 24.57421507154192, 35.42871175493513, 44.77805839266096, 55.635674817221506, 60.07078988211495, 42.31552995954241, 2.994317497525896, 0.0720763374119997, 0.029284916618572812, 0.024564078776165843, 0.04250092977391822, 0.04497406438791326, 0.027939668357638375, 0.07243069554013865, 0.04801238135301641, 0.04682571181495275, 0.016879438988066146, 0.04655506455206445, 0.014363828081903713, 0.043851418021534166, 0.05622011735769255, 0.0394548639389021, 0.056697222470704994, 0.06611189924712692, 0.030040618032217026, 0.07406572744782482, 0.04266911146364041, 0.03801901598594018, 0.03384289757481643, 0.0551641167008451, 0.003251047235348129, 0.02296991503265287, 0.11160432028451137, 0.09317783332828965, 0.1170435044914484, 0.17609072104096413, 0.11149988695979118, 0.09430276975035667, 0.10703414944665772, 0.16116101002054556, 0.10236183873244695, 0.1091228091557111, 0.0918794022873044, 0.08911031444690057, 0.09223007597029209, 0.15603075602224895, 0.11648943993662085, 0.09463309416813509, 0.1194561714572566, 0.1419162234025342, 0.17065622551100595, 0.16824697836169175, 0.1515225286462477, 0.31262496752398355, 0.1665576568671635, 7.0648314867700845, 59.933694975716726, 77.51447173527309, 69.05137825012207, 58.358698163713726, 37.32204375948225, 28.504187413624354, 27.127955981663295, 38.050392150878906, 55.40182277134487, 47.32619905471802, 13.408981050763812, 0.9256047095571245, 0.15638172147529467, 0.17010450868734292, 0.5220422074198723, 0.8748291741524423, 5.788384003298623, 14.367228831563677, 14.666452135358538, 12.871044567653112, 12.39767335142408, 20.184638500213623, 18.36941119602748, 24.499600103923253, 41.53252703802926, 47.456224169049946, 60.54379544939314, 59.40787615094866, 56.9088488306318, 58.068694250924246, 56.55457408087594, 56.54450614111764, 58.375547545296804, 51.68314688546317, 44.856534821646555, 48.64128112792969, 52.06155967712402, 51.084837504795615, 52.447976793561665, 53.05033002580915, 55.64645842143467, 54.457065786634175, 57.692011560712544, 50.968128613063264, 50.84660114560808, 51.73926053728376, 53.345652784620015, 51.116163458142964, 59.26352732522147, 56.19494227000645, 52.93180070604597, 49.93042210170201, 45.73044102532523, 42.805812222617014, 52.943056787763325, 55.178796018872944, 57.04738201413836, 54.215073926108225, 55.576007161821636, 53.3234532901219, 54.60961348669869, 53.05499921526228, 57.854373591286794, 38.19352156775338, 47.2236818586077, 59.48199953351702, 49.386760302952354, 46.97545746394566, 53.48140321459089, 60.02522359575544, 54.791513851710725, 52.69050713947841, 51.901000704084126, 52.74899707521711, 53.82522439956665, 52.21843957901001, 53.82529040745327, 49.31427322115217, 47.64926249640328, 47.98839364733015, 47.18671744210379, 45.24728413990566, 42.62267507825579, 45.14401306424822, 45.13561616625105, 54.26741470609392, 56.377263001033235, 53.41420371191842, 49.49541623251778, 50.26519673211234, 55.46792793273926, 58.944090843200684, 53.72432960782732, 48.33395883015224, 58.08875370025635, 59.258774757385254, 59.58148384094238, 58.612036432538716, 56.22501059940883, 59.52187524523054, 59.376803806849885, 57.05782515662057, 44.90049260003226, 30.045772075653076, 17.13079057421003, 15.196519783564977, 14.550879274095808, 17.097090073994227, 13.58623741354261, 6.696705937385559, 1.3389719341482436, 0.3283743624176298, 0.19647275949163095, 0.20480613304036005, 0.701186471751758, 17.15057556969779, 54.505043097904746, 42.25716856547764, 20.71290830203465, 28.84416103363037, 33.636312757219585, 40.756555693490164, 53.456931659153526, 62.62782423836844, 65.47693307059151, 50.46073293685913, 4.423442091260638, 0.15931680612266064, 0.13433909070278915, 0.1422795517636197, 0.19906963514430182, 0.13148126405264648, 0.129893084987998, 0.23098469259483473, 0.12437248336417334, 0.12170604430139065, 0.11448594315775804, 0.12745775495256695, 0.13942484637456282, 0.11935701034963131, 0.12187296391597816, 0.17360786641282694, 0.2036700075758355, 0.1654776462486812, 0.12425815021353108, 0.19745096271591528, 0.17175842422459806, 0.08795205517006771, 0.098082596569189, 0.15582308359444141, 0.07847178780606814, 0.1755388006567955], [0.010683139470139784, 0.023602355471146957, 0.02159105214689459, 0.01107347522130502, 0.061285540727632384, 0.08061370572873525, 0.032914098485239913, 0.06666006054729223, 0.014147858867155654, 0.03140944368871195, 0.033109109449599466, 0.043855306027191024, 0.03490798381556358, 0.002908026367159826, 0.03974404877849987, 0.0075826610638094795, 0.007374601022872541, 0.02402584274698581, 0.028625994654638425, 0.018871797614597847, 0.00879514801116394, 0.025931274252278463, 0.13190499560109206, 10.8304637329919, 58.88152231488909, 63.30856704711914, 56.67835276467459, 39.81839949744088, 24.948109797069005, 18.16225586618696, 30.802086966378347, 44.113254751477925, 36.09837566103254, 25.16428562573024, 2.6588497843061174, 0.11258535978517362, 0.10755322195057358, 0.002567567816835695, 0.11081938418958868, 0.6404710497174944, 4.457204256738935, 7.6644788299288065, 5.913354737418039, 8.518391592161995, 16.04850094658988, 9.293517862047468, 17.377658333097184, 45.60362597874233, 53.0907998085022, 57.114807333265034, 57.97161749431065, 54.209060260227744, 55.09118618283953, 56.86751399721418, 55.34687294278826, 54.31187622887747, 52.9624457359314, 50.984182425907676, 43.43563515799386, 40.56873198917934, 42.76054470879691, 45.678774220602854, 43.149282523563926, 44.59168686185564, 47.821834904806956, 50.65018946783883, 54.352550983428955, 52.45922245298113, 51.040375982012065, 53.1224627494812, 50.35241052082607, 50.06588765553066, 54.039993218013215, 51.94856807163784, 49.29571805681501, 42.58005135399954, 40.450518812452046, 39.997385093144004, 41.88991110665457, 45.8788788659232, 51.23371308190482, 50.87519645690918, 50.44456100463867, 47.3565731048584, 53.40724509102957, 47.94476243427822, 56.1728469984872, 31.55191571371896, 42.79532739094326, 55.51797233309065, 46.95058291299002, 41.11565596716744, 44.63912568773542, 52.75296797071184, 51.97416870934622, 51.859262875148225, 46.63743107659476, 50.06461613518851, 51.11829655511038, 50.624762535095215, 46.62431982585362, 46.10358360835484, 44.02044071469988, 44.040889263153076, 43.37247950690133, 44.351379939488, 43.32044097355434, 41.166749545506065, 41.74565608160836, 47.706588608878, 51.00219563075474, 51.71597712380545, 49.38536718913487, 47.9900438444955, 51.914469787052695, 54.51067113876343, 48.50542994907924, 43.025611536843435, 53.21802479880196, 52.67072214399065, 51.8331515448434, 54.480887685503276, 55.5219258580889, 54.52221209662301, 56.762530190604075, 57.029108251844136, 55.162759576525005, 39.83554417746407, 22.098019531794957, 5.39974650314876, 7.64262935093471, 12.793338520186287, 13.365386315754481, 3.306344811405454, 1.367933220096997, 0.31699845141598154, 0.11918876080640725, 0.019560425841648663, 0.031054535947207893, 1.0362826734781265, 20.924336774008616, 34.818746771131245, 26.664010865347727, 26.20936243874686, 28.090076514652797, 33.7791816166469, 28.8239244052342, 40.371507372174946, 47.852386134011404, 50.19210515703474, 10.521439126559667, 0.052861406334808896, 0.01438476936891675, 0.013381856443759586, 0.01970200895863984, 0.0374196320772171, 0.062385832757822106, 0.025016432628035545, 0.02713831001892686, 0.06342614907771349, 0.014052819011599889, 0.023175902997276614, 0.03466184863022395, 0.06486572218792779, 0.08566318013306175, 0.0479044467876, 0.023703647178730795, 0.026444881156619107, 0.01704123057425022, 0.03889497076826436, 0.028147700409005796, 0.026796498003282716, 0.028906792801405703, 0.06798183997826916, 0.024875316003869687, 0.07523983730269329, 0.0427352889840092, 0.02876484327550445, 0.08201940637081861, 0.050389774675880156, 0.055011805945209095, 0.05662210185879043, 0.036650363355875015, 0.039088482170232704, 0.03362169176606195, 0.01230158458929509, 0.058782146844480715, 0.04188974614122084, 0.02067549297186945, 0.050380516065550704, 0.041464874653943946, 0.046057681420019696, 0.010146123107655771, 0.03201681734727962, 0.05965909228793212, 0.018343615778056637, 0.04426810637648616, 0.014875362061762383, 0.12621337601116725, 15.503109046391078, 68.88804694584438, 68.98607213156563, 63.956271171569824, 46.00993578774588, 29.982084887368337, 20.77840028490339, 27.042708533150808, 27.89768958091736, 33.270170484270366, 27.114420890808105, 2.8069882009710585, 0.04552053274320705, 0.07669308289353337, 0.0880217949992844, 0.3988350400967257, 3.8295000876699175, 6.063403257301875, 6.686809531279972, 4.363890818187168, 7.727941938808986, 13.313827208110265, 17.69395422935486, 26.28492409842355, 45.784522329057964, 55.566738264901296, 59.41150311061314, 60.91103553771973, 56.71035616738455, 55.27649811335972, 58.00825187138149, 56.01973302023751, 55.26155948638916, 54.188139234270366, 51.78798130580357, 45.84583323342459, 43.037923744746614, 44.98497922079903, 47.478896141052246, 46.03257996695382, 47.26217835290091, 49.59469904218401, 51.09231376647949, 55.110974652426584, 52.49954979760306, 51.18089287621634, 52.61257266998291, 50.40314279283796, 51.514034679957796, 55.976244245256694, 53.82029812676566, 50.498089926583425, 45.02086666652134, 43.26711354936872, 41.68514769417899, 45.73417568206787, 48.73801047461373, 52.22788912909371, 50.794868332999094, 53.78851011821202, 49.624201093401226, 55.286611216408865, 49.41963223048619, 56.21467515400478, 33.09225838524954, 44.045725209372385, 56.70098999568394, 48.33541100365775, 42.56081526620047, 47.356482778276714, 54.265608174460276, 53.88130331039429, 52.03028236116682, 47.10496841158186, 50.20828751155308, 52.24360248020717, 52.37437799998692, 48.06424365724836, 47.469453539167134, 46.97276503699166, 46.84406008039202, 44.818441322871614, 46.78226280212402, 45.53272656032017, 44.26436070033482, 43.55890314919608, 49.266674586704795, 53.21944917951311, 52.624290806906565, 48.69083915437971, 48.84926503045218, 52.449665205819265, 56.40901279449463, 50.518180642809185, 44.28669915880476, 54.840418747493196, 54.43411936078753, 52.930758476257324, 54.02318205152239, 56.67919002260481, 56.425292423793245, 59.174423626491, 58.38899230957031, 57.949233872549875, 42.49926812308175, 20.068747758865356, 4.89718633890152, 3.0935733829225813, 7.042733175413949, 8.751204882349287, 8.370469655309405, 3.75043306180409, 1.0844225074563707, 0.24963789167148726, 0.10920388051973921, 0.0084480892234881, 1.2498270890542438, 24.759089265550884, 40.897524220602854, 29.515975407191686, 28.99609555516924, 31.520916325705393, 39.65262590135847, 34.45563391276768, 46.60565001623971, 53.441103662763325, 59.148611068725586, 14.55427346910749, 0.060242740969572744, 0.03134710667654872, 0.05915517147098269, 0.025515310233458877, 0.03326285869947501, 0.061967495562774796, 0.04307290765323809, 0.06867789477109909, 0.039352208375930786, 0.01224939591650452, 0.028359055585627044, 0.0819326624540346, 0.023686364891805818, 0.029068094146038805, 0.01951085716219885, 0.021641999948769808, 0.04045232059434056, 0.014648278443408864, 0.02075062206547175, 0.034858158989144225, 0.024737936411319033, 0.032249680387654474, 0.044801465435219665, 0.01056384707667998, 0.017512569835941707, 0.13667525963059493, 0.14447273979229586, 0.16283931210637093, 0.24336708816034452, 0.17022869416645595, 0.247961231640407, 0.13408131524920464, 0.18855740422649042, 0.1283194808555501, 0.08145892966006484, 0.15120710485747882, 0.16853142024150916, 0.12137964181602001, 0.08904015392597232, 0.15057141253990786, 0.15040629782846995, 0.0711250923840063, 0.0657231868909938, 0.19425498135387897, 0.09312169134084668, 0.09891880955547094, 0.13306929383959087, 0.2291847834629672, 21.43254886354719, 79.62304850987026, 76.56411102839878, 72.23359067099435, 53.606561115809846, 36.266820839473176, 26.698583364486694, 40.96469940458025, 55.81969438280378, 46.121065276009695, 33.653078760419575, 3.544388792344502, 0.273404666355678, 0.1689295574490513, 0.22645582418356622, 0.26072670093604494, 3.590688547917775, 11.830470187323433, 16.28198300089155, 13.14125566823142, 14.844237429755074, 24.413260051182338, 15.908319302967616, 26.581617389406475, 48.09690366472517, 53.93469326836722, 60.88458374568394, 62.76072938101632, 58.32563863481794, 57.719245025089805, 59.63892459869385, 57.80923114504133, 57.53249134336199, 57.264238766261506, 55.55993945258004, 47.74141992841448, 44.74094806398664, 47.11370924540928, 49.46683134351458, 48.42938538960048, 48.63136952263968, 51.90453386306763, 53.803584235055105, 57.77340275900704, 54.27962269101824, 52.17360980170113, 55.1324828011649, 50.9453558921814, 51.468920026506694, 57.66797774178641, 55.411567619868684, 54.23160369055611, 46.81793485369001, 44.41669300624302, 44.597050871167866, 47.93680674689156, 50.318885462624685, 54.957617487226216, 54.08764048985073, 54.45626326969692, 50.99572685786656, 57.43380955287388, 51.31092841284615, 58.0195392199925, 34.93324613571167, 48.27882487433297, 59.08088002886091, 50.58092287608555, 45.53283773149763, 49.164424896240234, 55.83325726645333, 56.009661606379915, 54.40023647035871, 48.015272753579275, 51.7981812613351, 53.61755664008004, 53.74287782396589, 51.352099963596885, 50.25764056614467, 48.79549639565604, 48.853968960898264, 46.303434644426616, 48.401026317051475, 46.31718512943813, 45.64637129647391, 46.25882026127407, 52.22393560409546, 55.54499735151018, 53.87468862533569, 49.38212932859148, 48.51165553501674, 54.51562173025948, 59.51487840924944, 53.19903884615217, 47.527748925345286, 58.14791761125837, 56.45779957090105, 55.985009397779194, 56.250326360974995, 59.32035664149693, 59.04308877672468, 62.31481484004429, 61.49451051439558, 61.10614790235247, 43.309313433510916, 26.130538599831716, 10.962499482291085, 18.554215908050537, 21.937293801988872, 22.70683111463274, 11.810812864984785, 3.1912898080689565, 0.6844222598842212, 0.2755175158381462, 0.1713284637246813, 0.1671070395303624, 1.8659637016909463, 29.363987037113734, 49.00315720694405, 36.81135811124529, 36.991243498665945, 37.71639919281006, 46.36817448479788, 42.62148693629673, 55.31115572793143, 59.876414026532856, 64.91996547154018, 19.307292938232422, 0.22446987432028565, 0.11050332257790224, 0.1522753361080374, 0.120005282706448, 0.12745426728257112, 0.20192306488752365, 0.08378630477402892, 0.13625831343233585, 0.10138824276093926, 0.11505131210599627, 0.14680349401065282, 0.1908236433352743, 0.1044371041602322, 0.23881832510232925, 0.1378118193575314, 0.10267980702753578, 0.10615639654653412, 0.17964323184319905, 0.11233436968177557, 0.11119026464543172, 0.059539676910000186, 0.16003340695585522, 0.09814393613487482, 0.1020696751241173, 0.10400150503431048], [0.03803745178239686, 0.056670271059764285, 0.021596812909202914, 0.06413498747029475, 0.030094079806336334, 0.06053815476064171, 0.01236549495453281, 0.024607905353020345, 0.020031773585027883, 0.04701888394941177, 0.002310679547788043, 0.023675778049177358, 0.027857139839657714, 0.04354408237018755, 0.05660112155601382, 0.011764185702694314, 0.04792762554383703, 0.060178707619862895, 0.050149457928325446, 0.002272919286042452, 0.006963484712676811, 0.03415719838812947, 0.768034710415772, 24.86923905781337, 60.41144616263253, 56.23315388815743, 42.578185762677876, 31.98174170085362, 20.945365497044154, 19.819635731833323, 37.78174352645874, 69.57284750257219, 48.96279512132917, 7.884013244083949, 0.2396562887089593, 0.044374595662312846, 0.08665023145398923, 0.009382757640975927, 0.6578621736594609, 1.4325109720230103, 2.1567419043609073, 4.958003052643367, 5.460249245166779, 17.334025382995605, 33.29921048028128, 28.89158943721226, 45.03955384663173, 58.08203479221889, 54.26987784249442, 57.95937129429409, 51.32463720866612, 50.588221958705354, 49.8394319670541, 54.959715843200684, 53.77596514565604, 50.733039787837434, 55.682227747780935, 51.79278251102993, 47.91721977506365, 38.887851578848704, 41.15952689307076, 39.86656093597412, 44.29898009981428, 45.76495967592512, 47.103603090558735, 50.5368469783238, 52.56248310634068, 53.181755202157156, 49.814974308013916, 51.16465146200997, 49.11520733152117, 48.96948971067156, 54.01030356543404, 49.46503523417881, 46.81874084472656, 41.52378273010254, 40.06724228177752, 38.56932531084333, 41.06369038990566, 39.64279767445156, 47.88309369768415, 48.611042567661826, 52.43562984466553, 48.04973929268973, 51.10261794498989, 47.231578486306326, 55.12176520483834, 29.11805033683777, 37.2798056602478, 56.719972474234446, 47.01387405395508, 42.12232487542288, 39.93206855228969, 51.74976968765259, 49.23027992248535, 54.643076011112754, 49.795182364327566, 51.74030276707241, 51.01794719696045, 51.81782381875174, 49.19962099620274, 46.73496641431536, 47.52934353692191, 47.94279956817627, 47.49234785352434, 48.44599158423287, 46.076978955950054, 45.334490980420796, 43.1340138571603, 46.78011580875942, 49.33780329568045, 51.5593786239624, 48.10509211676461, 47.154272828783306, 51.92102541242327, 53.14039952414376, 48.73434182575771, 41.46920115607125, 50.80999108723232, 55.28936965124947, 51.65128592082432, 54.243818623679026, 53.46930987494332, 53.49242305755615, 53.661663804735454, 54.19547305788313, 55.95350973946707, 56.72535385404314, 45.81394100189209, 23.03096284185137, 7.211301684379578, 5.776656746864319, 9.745098658970424, 13.716086217335292, 11.850951739719935, 2.345961328063692, 0.05148190053712044, 0.07010688273502247, 0.06675095709839038, 0.052944428487015624, 4.6276952454022, 33.51742213112967, 37.4535870552063, 28.80343243053981, 16.368814638682775, 23.898600033351354, 33.5665910584586, 43.61611114229475, 48.96852738516671, 53.22334017072405, 32.05675445284162, 1.6261058066572462, 0.027096145852868046, 0.08809180624250855, 0.023567921515288096, 0.017624283841411983, 0.07621469534933567, 0.031530609686992, 0.014386608198817288, 0.03084041065137301, 0.03600343789107033, 0.07383666081087929, 0.04767845052161387, 0.026289116657738174, 0.030412668960967233, 0.02629516919010452, 0.04894696156095181, 0.017217676820499555, 0.07905144670179912, 0.02224239657100822, 0.05309371976181865, 0.05258158527846847, 0.038539808576128314, 0.0365561385905104, 0.03448916146797793, 0.02477928124634283, 0.04186136302139078, 0.04320941532828978, 0.03377158693703158, 0.060508787765034606, 0.009131930385982352, 0.05391018398638282, 0.04746272727581007, 0.017812424638707722, 0.030091799928673675, 0.03684026495154415, 0.020292025691430484, 0.03529543409656201, 0.06367021812392132, 0.037872527060764175, 0.045927701251847405, 0.022186229138502052, 0.0644155413444553, 0.044779368942337375, 0.012293460828784322, 0.0467752796996917, 0.03118284691923431, 0.06054670430187668, 0.9486549241202218, 30.712687969207764, 68.22272913796562, 63.78583186013358, 49.649259771619526, 40.86502749579293, 24.0601213318961, 22.273388590131486, 37.66461774281093, 64.61511325836182, 49.28504214968, 8.708718385015215, 0.43648464126246317, 0.01876487406635923, 0.058680529440087933, 0.19588805229536124, 2.8018367631094794, 5.179388293198176, 8.906286937849861, 8.894910999706813, 7.916649801390512, 9.606955443109785, 24.956451109477452, 30.452568258558, 46.924318722316194, 56.486582483564106, 54.29312651497977, 59.74750409807478, 54.090673378535676, 53.558041845049175, 52.41014037813459, 56.50314351490566, 56.57905605861119, 54.51443011420113, 56.47774090085711, 54.59507785524641, 50.512924330575125, 40.998207092285156, 44.63933760779244, 42.36275339126587, 44.490125043051584, 46.94779321125576, 49.73208229882376, 52.232009410858154, 54.22137246813093, 54.71886001314436, 50.306528091430664, 51.87902007784162, 49.96373871394566, 49.78990520749773, 55.057508264269146, 50.74288885934012, 48.73047167914254, 43.59818826402937, 42.28983204705374, 39.93626179013933, 43.51911081586565, 42.143756593976704, 49.55972875867571, 50.5262370790754, 53.93077448436192, 50.383354323250906, 53.34632675988333, 48.97193200247628, 56.826936517442974, 30.916301454816544, 39.10217571258545, 58.74389239719936, 48.50279310771397, 43.92125865391323, 42.14961045128958, 53.72840125220162, 51.75724942343575, 56.2992798941476, 50.23005274363926, 51.706016881125315, 52.741444383348735, 53.00307880129133, 50.54059900556292, 49.606872286115376, 49.20814643587385, 49.222119263240266, 48.94954490661621, 49.73084551947457, 47.7616982460022, 45.912216322762625, 44.91478157043457, 48.65774141039167, 52.59445524215698, 52.99328531537737, 47.28434658050537, 47.81074905395508, 52.49210480281285, 56.017912592206685, 50.38760314668928, 43.73824657712664, 52.900499071393696, 56.87578582763672, 53.21128852026803, 56.030784130096436, 53.89385175704956, 53.92082118988037, 54.34947640555245, 56.068300928388325, 56.28784663336617, 58.984557151794434, 47.206467696598594, 22.796739067350114, 7.183126304830823, 5.155260239328657, 8.290742550577436, 13.444785118103027, 7.741426655224391, 3.9677058373178755, 0.7409321761557034, 0.373246073190655, 0.030224392456667762, 0.10699218884110451, 5.1370390227862766, 34.649891648973735, 31.151320798056467, 23.447941609791346, 22.19902375766209, 31.08963121686663, 38.683404309409006, 49.588657583509175, 55.71156651633126, 59.68293448856899, 37.85283749444144, 2.2173393155847276, 0.04001024145899074, 0.037569968295948844, 0.018360740305589776, 0.03954003704711795, 0.08620617099638496, 0.014359458316383618, 0.041378928015806844, 0.028371209844148586, 0.010603526956401765, 0.0827244178258947, 0.024998275030936514, 0.012861854346868182, 0.12539686768182687, 0.06462974127914224, 0.021520138452095643, 0.01717648804853005, 0.04591559279443962, 0.07918432421450104, 0.021809309720993042, 0.015276189660653472, 0.03377746305029307, 0.08920415583997965, 0.0350511513118233, 0.012758420164962965, 0.09084447353546109, 0.10745347730283226, 0.12623711116611958, 0.13727002271584102, 0.12352575308510236, 0.11473291633384568, 0.15300446269767626, 0.14869698669229234, 0.12634702026844025, 0.11831106218908514, 0.13460792627717766, 0.12717727571725845, 0.1765119962926422, 0.10659251814442021, 0.122438427859119, 0.11594815898154463, 0.17053974818970474, 0.14917183906904288, 0.17024504686040537, 0.09093641503048794, 0.11596817576459476, 0.1569521115826709, 1.197176571403231, 41.39350400652204, 76.86664254324776, 70.98303999219621, 60.21906444004604, 45.701533045087544, 30.637612683432444, 29.169461795261928, 47.67032596043178, 79.58382592882428, 61.22207164764404, 10.540769015039716, 0.6373859952603067, 0.06720340424882514, 0.4186246224812099, 0.176935700699687, 2.790353996413095, 5.9389762197222025, 10.54366033417838, 11.519785829952784, 11.398575374058314, 23.198449168886455, 35.09152957371303, 36.783235277448384, 49.4031788962228, 57.31328610011509, 55.2100316456386, 61.322153500148225, 55.76773227964129, 54.61467524937221, 54.34237534659249, 58.98292432512556, 57.13370295933315, 55.005820614951, 59.99669429234096, 55.64685794285366, 52.90113483156477, 42.39538213184902, 47.00835371017456, 43.48715952464512, 47.831121172223774, 50.22462272644043, 51.43767050334385, 54.48385109220232, 56.65999909809658, 57.01314129148211, 51.49805382319859, 52.55452047075544, 51.189730984824045, 51.52327230998448, 58.69656126839774, 54.24551051003592, 50.93724039622715, 45.95264789036342, 44.460060187748496, 41.792070048195974, 45.83405256271362, 44.0826027733939, 51.411878790174214, 53.057920932769775, 56.195605822971885, 51.45561422620501, 54.937849862234934, 49.20006568091256, 56.56956829343523, 32.60452263695853, 40.249952111925396, 60.73254326411656, 51.80136006219046, 44.877928325108115, 43.92507668903896, 55.54008150100708, 53.667607988630024, 59.541448320661274, 52.411849634987966, 52.721739292144775, 55.14471510478428, 54.99717705590384, 53.14064271109444, 51.70148318154471, 51.73012365613665, 52.52763441630772, 51.763589654650005, 53.879715647016255, 50.91703503472464, 48.92996835708618, 47.13705519267491, 51.07301861899239, 54.6112185205732, 54.32777370725359, 49.017394065856934, 48.37809031350272, 54.186082567487446, 56.88918890271868, 52.165278911590576, 45.54395832334246, 56.570395129067556, 58.81099809919085, 54.80157136917114, 59.02882412501744, 57.34687369210379, 56.43018742970058, 58.17565482003348, 58.310317856924875, 60.73951230730329, 61.699128014700754, 51.638271944863455, 29.14387505395072, 12.376611624445234, 15.049709558486938, 21.520240340914043, 24.038177183696202, 23.040030241012573, 5.670100041798182, 0.8000257366469928, 0.3641047679952213, 0.2045456027345998, 0.2259230791990246, 6.162377740655627, 45.89996664864676, 51.25553042548043, 39.98988103866577, 25.27906812940325, 35.79591710226876, 45.1846079145159, 56.442794936043875, 61.51806490761893, 66.53009932381767, 45.98049974441528, 2.7112259566783905, 0.11190339816468102, 0.12887643596955708, 0.10475501817251955, 0.09162254285599504, 0.18091638066938945, 0.15812498650380544, 0.09035101572849921, 0.12393210056637015, 0.11869720289749758, 0.16462592195187295, 0.16326279938220978, 0.17900063203913824, 0.20462227719170706, 0.13321460889918463, 0.14947298648101942, 0.0807553499138781, 0.16976513261241571, 0.1571408664541585, 0.08906172455421515, 0.1326688224715846, 0.11089903063007764, 0.19040562505168573, 0.08601014222949743, 0.15176935254463128], [0.028351335553452373, 0.032724590439881594, 0.05738312977233103, 0.010288551848913943, 0.02579066652937659, 0.020469869719818234, 0.07492300894643579, 0.06800316633390528, 0.06663614897323505, 0.010853765582266663, 0.010615918702179832, 0.010903087444603443, 0.056566892856998105, 0.03254302803959165, 0.02060927982841219, 0.022727442240076404, 0.020268522934722047, 0.05575332258428846, 0.031527573242783546, 0.06165529481534447, 0.09835839391286884, 0.019892860503335084, 2.7513370386191776, 44.95258671896798, 58.437066895621165, 55.37273761204311, 43.98594985689436, 29.982981204986572, 24.770656279155187, 26.349811588014873, 31.28209284373692, 29.85117040361677, 19.97130274772644, 1.2761134271110808, 0.06026074250361749, 0.02821109423946057, 0.11107095104775258, 0.1450193268912179, 1.5494603365659714, 6.789638093539646, 7.051389762333461, 5.353085441248758, 8.7073860679354, 25.86833269255502, 31.074192319597515, 51.604990073612754, 61.13863073076521, 54.79682574953352, 56.30562012536185, 56.31547614506313, 55.48717791693551, 51.4531615121024, 47.986281394958496, 52.93247468130929, 55.33164596557617, 51.06278739656721, 51.78410421098982, 53.01464407784598, 50.73734767096383, 41.45941809245518, 38.16410289491926, 39.18037073952811, 42.3468976020813, 45.973006112234934, 50.408958435058594, 51.685950483594624, 53.081263405936106, 50.9731764793396, 49.61852094105312, 47.53975888660976, 47.33666998999459, 48.42874615533011, 51.98432002748762, 48.83608429772513, 46.558186871664866, 38.96641833441598, 39.57115132468087, 38.54292215619768, 40.63775191988264, 38.94759913853237, 43.15636968612671, 48.81121669496809, 52.18252434049334, 49.84566797528948, 52.271892070770264, 48.6484933580671, 54.28986433574131, 34.609449659075054, 38.934269019535606, 57.32854781832014, 46.026722635541645, 44.596467222486226, 38.127652645111084, 45.146135738917756, 48.46000610079084, 51.13044548034668, 48.96253456388201, 48.98895856312343, 50.39999525887625, 51.758420194898335, 49.02641977582659, 48.96286112921578, 49.561962604522705, 48.16618415287563, 48.716328620910645, 51.180597577776226, 49.562389918736045, 47.71423510142735, 45.30431842803955, 47.8995817729405, 49.19341625486101, 51.88881703785488, 47.506556919642854, 47.45936475481306, 50.87603371483939, 53.58681780951363, 46.79989733014788, 39.543080602373394, 41.41909074783325, 49.25478621891567, 52.059899057660786, 48.99414191927229, 50.480038506644114, 49.46199887139456, 49.431822844914024, 51.01487609318325, 52.99122517449515, 52.39283241544451, 55.7553505897522, 40.09823819569179, 20.903054441724503, 4.198252711977277, 2.645074112074716, 6.245528135980878, 4.29534249646323, 3.418593611036028, 1.2193508786814553, 0.20051502329962595, 0.11207587498107127, 0.04257851346795048, 0.32481802467788967, 15.343536717551094, 51.272282532283235, 45.01123646327427, 34.45470632825579, 37.24921274185181, 20.774486712047032, 36.7426369530814, 41.924721581595286, 45.37734399523054, 47.8545366014753, 10.801635657038007, 0.3013731470065457, 0.07161517787192549, 0.03513625995921237, 0.02814854009609137, 0.08177507948130369, 0.03859832543613655, 0.052343205748392005, 0.033207385069025416, 0.04095130167635424, 0.027307838600661074, 0.0698123781808785, 0.006573184160515666, 0.02673901421284037, 0.038494896343243976, 0.06420436767595154, 0.06721126168434109, 0.04033593487526689, 0.06639825459569693, 0.019951753950278674, 0.020100229286721776, 0.04411608399823308, 0.020809844601899385, 0.05783495267054864, 0.06728284034345831, 0.037194511121405024, 0.048317664435931613, 0.023825167711558085, 0.022732453221189122, 0.022993899549224546, 0.02103643967503948, 0.0462825377471745, 0.08136257768741675, 0.03324955602043441, 0.004343319193659616, 0.018660869915038347, 0.061930902169219086, 0.018878903572580645, 0.056829957491053004, 0.03264520862804992, 0.037036677090717215, 0.008770743651049477, 0.007506825445619012, 0.02123319447439696, 0.03623106942645141, 0.06414374057203531, 0.05213357235438057, 4.924984344414302, 53.333243301936555, 66.4755003792899, 61.394150733947754, 51.95623888288225, 36.332745347704204, 26.215662717819214, 28.7565564087459, 31.989471571786062, 39.65127100263323, 23.867433888571604, 1.6581410190888812, 0.09414224193564483, 0.06093145401350089, 0.15858690600310052, 1.0571220581020628, 5.179676643439701, 8.468766689300537, 7.986341970307486, 7.967309985842023, 9.609156285013471, 23.100632429122925, 32.53619752611433, 51.411090169634136, 61.41393920353481, 55.07244341714041, 56.988958086286274, 57.399023396628245, 59.84208297729492, 53.26720067432949, 50.756166866847444, 54.76227930613926, 57.17100436346871, 53.07670886175973, 53.33099903379168, 54.68117298398699, 52.97080789293562, 43.57309831891741, 39.995759214673726, 40.60011352811541, 44.67913688932146, 48.72795990535191, 51.966751507350374, 52.99242026465279, 54.674704211098806, 52.06926870346069, 50.93510382516043, 48.65322160720825, 48.54751866204398, 50.18526118142264, 53.4135297366551, 50.83876010349819, 48.053303718566895, 40.942492961883545, 41.304511478969026, 40.21331078665597, 41.31972803388323, 40.533396925245015, 44.3921172278268, 50.18720667702811, 54.69547585078648, 52.836318561008994, 54.308377810886924, 50.187369959695, 54.79696123940604, 35.731969356536865, 40.29878057752337, 57.6564611026219, 48.3491267476763, 48.06269073486328, 39.429255213056294, 48.00030633381435, 50.11393097468785, 54.12609529495239, 50.34971114567348, 50.09571279798235, 50.07715763364519, 53.870283467429026, 50.45234646115984, 51.160006591251914, 50.67005089351109, 50.861539772578645, 50.33068697793143, 52.055684975215364, 51.12003013065883, 49.90582547869001, 45.38447979518345, 48.49848869868687, 50.70610162190029, 52.61890942709786, 46.472279344286235, 47.48624733516148, 53.051643235342844, 55.57918248857771, 50.179633140563965, 41.21106168201992, 43.374442373003276, 50.549756731305806, 54.21174226488386, 52.00722129004342, 53.38652556283133, 50.2889005116054, 54.1361597606114, 52.50271817616054, 54.51642772129604, 56.07376568658011, 58.00799478803362, 42.324736322675435, 24.014273643493652, 7.5695594889777045, 7.533931732177734, 10.198641453470502, 7.897429347038269, 6.742310438837324, 2.3823390560490743, 0.4472062273749283, 0.05712907947599888, 0.10464582831731864, 0.3569352312811783, 17.18681389944894, 46.25945602144514, 37.749514307294575, 33.79197325025286, 39.83962971823556, 32.390903745378765, 43.65293312072754, 48.658436230250764, 50.68802240916661, 56.93277495247977, 13.574661714690071, 0.301553338766098, 0.023196925708491887, 0.02673306515706437, 0.09492509492806026, 0.01729784912562796, 0.060431054793298244, 0.06049783620983362, 0.028115746498640095, 0.032657602070165534, 0.02390670047939888, 0.0195079954407577, 0.013265507195943167, 0.04516709063734327, 0.05739794897713831, 0.0379573066186692, 0.005410819322735603, 0.022743101131969264, 0.043257095984050205, 0.05142826234389629, 0.039469086032892974, 0.030050507680113827, 0.024623258904154812, 0.057720341320548735, 0.02398058106856687, 0.06548477682684149, 0.10925618878432683, 0.16149916473243917, 0.17729512069906506, 0.14644929873091833, 0.12625756221158163, 0.10737022784139429, 0.18333165320966924, 0.10745674105627195, 0.08887958539915936, 0.07766561356506177, 0.08760568339909826, 0.15308755609605992, 0.1251283578042473, 0.17076088275228227, 0.07277555417801652, 0.10150939518851892, 0.17293509894183703, 0.14251531554119928, 0.13826448363917215, 0.1908392903528043, 0.1452664900571108, 7.980232766696385, 66.2571393421718, 73.43492031097412, 70.73275893075126, 58.07015684672764, 41.68543951851981, 33.96394463947841, 37.09846115112305, 40.08659996305193, 41.58866500854492, 28.171391282762798, 2.0594949168818335, 0.26215756844197, 0.12191354031009333, 0.3333603734416621, 0.7946846889598029, 4.951323228222983, 14.531214135033743, 14.611047199794225, 12.59295334134783, 14.621101243155342, 30.785633632114955, 38.171659060886924, 57.778638226645334, 64.6494859967913, 57.34441402980259, 55.33048561641148, 59.20799037388393, 61.44469887869698, 55.92378534589495, 51.506627900259836, 57.265395641326904, 59.08692496163504, 53.894643851688926, 55.05065039225987, 57.255292960575645, 56.13043172018868, 45.72687659944807, 43.13573701041085, 42.010378973824636, 45.95954745156424, 50.825610637664795, 54.182160309382844, 53.926741055079866, 55.33978925432478, 53.75514834267752, 51.61991480418614, 49.666630268096924, 48.18982539858137, 51.240355559757774, 55.691361154828755, 52.75073412486485, 50.64926535742623, 43.93592630113874, 44.26519101006644, 42.078801359449116, 44.68838841574532, 43.158071994781494, 45.396076338631765, 52.49791349683489, 57.880905287606375, 53.93707997458321, 56.53437219347273, 52.71739666802542, 54.11238302503313, 38.23944221224104, 43.533813204084126, 61.05569008418492, 50.06046806062971, 50.25559432165963, 41.96930469785418, 49.26516682761056, 52.8692877633231, 55.65174947466169, 50.78059325899397, 51.287040506090435, 52.73628881999424, 55.134469985961914, 52.93994746889387, 52.56834391185215, 54.632573808942524, 52.08296707698277, 53.39871965135847, 54.4485889843532, 52.745620250701904, 51.87191554478237, 48.24377816064017, 51.98875297818865, 53.43913732256208, 54.05013063975743, 46.180729457310264, 47.76048231124878, 54.62316247395107, 59.83718449728829, 52.01436056409563, 44.07212836401803, 44.69528797694615, 54.42232826777867, 57.108821460178916, 52.994935512542725, 55.037167412894114, 54.87747349057879, 55.07399981362479, 55.01541607720511, 57.71291869027274, 58.0406756401062, 60.40481063297817, 44.74718059812273, 26.184272493634904, 8.990548610687256, 9.90624736036573, 12.824914608682905, 10.113281096730914, 9.048513957432338, 2.8075108357838223, 0.4188250888671194, 0.21196329327566282, 0.2312123818056924, 0.6335696429014206, 21.70825685773577, 66.71610260009766, 57.87654529299055, 42.5943820135934, 44.951759883335654, 32.39532279968262, 49.216553756168906, 57.28136607578823, 57.03487178257534, 63.64840344020298, 18.085900374821254, 0.4432221140180315, 0.13723388394074781, 0.08272793942264148, 0.21175733075610229, 0.12563111154096468, 0.1448421071150473, 0.14826332139117376, 0.2162465862929821, 0.10272689735782997, 0.13064815875674995, 0.1661557877170188, 0.11610031367412635, 0.0764977733737656, 0.15758793960724557, 0.26794805058411186, 0.15502199158072472, 0.17055109329521656, 0.1648780248527016, 0.21686661802232265, 0.10118336589740855, 0.16399727282779558, 0.17056865378149919, 0.13577556290796824, 0.1724432289068188], [0.017845929001591036, 0.03152305080688425, 0.02744532166980207, 0.026474014057644775, 0.05133316566103271, 0.01166069638981883, 0.034263423045298884, 0.0888949813587325, 0.06335682994020836, 0.0282305325714073, 0.05950627263103213, 0.057994673028588295, 0.01142269090217139, 0.06866783888212272, 0.03518290924174445, 0.030468132413391556, 0.05623943864234856, 0.01597450567143304, 0.036330257675477436, 0.04142026097646781, 0.06512916340891804, 0.04360745754092932, 8.5435015133449, 53.478130613054546, 52.50079699925014, 56.22470140457153, 30.55019392286028, 21.298464264188492, 18.863874537604197, 28.36774042674473, 36.445896761757986, 39.91589662006923, 10.446406398500715, 0.03917883250064083, 0.015350950649008155, 0.03954153660950916, 0.1763118827449424, 1.0976346156426837, 5.14893651008606, 5.572407501084464, 9.905516930988856, 16.47450542449951, 34.07635607038225, 30.868657657078334, 45.65284701756069, 58.55558231898716, 53.706024578639436, 60.17006574358259, 55.256907667432515, 55.93149437223162, 53.61186606543404, 48.139621189662385, 43.30229575293404, 49.46491016660418, 52.83564111164638, 52.597654887608115, 51.04490968159267, 53.4710955619812, 51.51169661113194, 43.310376507895334, 37.065575327192036, 38.98914589200701, 43.47667816707066, 49.774712971278596, 50.41907501220703, 51.63176495688302, 52.66953747613089, 50.723420006888254, 49.66940259933472, 48.87926040376936, 48.545861516680034, 48.38683462142944, 51.943916252681184, 50.930337360927034, 46.436041014535085, 38.54249136788504, 37.25274242673601, 37.661480631147114, 37.428948743002756, 39.801598753247944, 43.57390430995396, 46.96201269967215, 50.03050742830549, 50.79134907041277, 51.191151891435894, 46.831820828574045, 54.54965053285871, 35.22379895618984, 38.14197635650635, 56.86091668265206, 46.20178944723946, 45.93341180256435, 36.734597887311665, 41.84429618290493, 46.46398319516863, 52.16344806126186, 50.01199395315987, 48.671839305332725, 47.0990937096732, 52.184382983616416, 51.45503057752337, 50.788601057870046, 50.30332497188023, 51.500958170209614, 50.80104180744716, 50.79126916612898, 50.856498854500906, 50.97720990862165, 47.125621931893484, 47.407489504132954, 49.73279448917934, 51.57972294943673, 48.48203536442348, 45.67595672607422, 50.65888166427612, 51.960956709725515, 48.28970922742571, 43.50863988058907, 39.37257528305054, 38.05951166152954, 40.65068599155971, 44.73234619413103, 43.3058671270098, 44.4266219820295, 45.17660706383841, 47.08354016712734, 51.8795759337289, 53.388853209359304, 57.516229084559846, 53.57136501584734, 34.66458361489432, 14.28004457269396, 4.6132499405315945, 11.993468846593585, 3.5140861783708846, 2.966251117842538, 0.781297790152686, 0.7375460149986404, 0.08707184597317662, 0.0342014151226197, 0.04019248239429934, 1.7319295853376389, 26.389638662338257, 32.249945640563965, 35.50954362324306, 34.23074851717268, 22.684916496276855, 32.742711884634836, 36.181309359414236, 48.66343545913696, 48.90562186922346, 31.79059328351702, 0.6576592102646828, 0.11029094111706529, 0.01613127100946648, 0.05758085487676518, 0.031718295865825245, 0.06108141703797238, 0.06982972832130534, 0.021467489223661165, 0.05153932834842375, 0.020799076251153435, 0.03435207703816039, 0.02812052677784647, 0.01168446971236595, 0.02375289864305939, 0.07134381814726762, 0.048294828339879, 0.027429360829825913, 0.021185715682804585, 0.015952134371868203, 0.008691623075199979, 0.058151475686047754, 0.03565705594207559, 0.05078735209203192, 0.039602438520107947, 0.013128874840081801, 0.032378764889602146, 0.022296382513429438, 0.065851199307612, 0.0417496490159205, 0.05107438936829567, 0.04795095357777817, 0.0266072410158813, 0.05231041893629091, 0.040535651479980776, 0.07346959372184106, 0.04184080341032573, 0.03784619311669043, 0.011984894484547632, 0.02685497415118984, 0.03239699712555323, 0.04650863240073834, 0.06403121910989285, 0.030689372148896967, 0.04040709962802274, 0.08276096372199909, 0.009167349065787025, 12.89633514199938, 61.52178914206368, 58.601169449942454, 61.46102019718715, 40.13732181276594, 24.92840644291469, 27.48131009510585, 33.55315671648298, 33.252341406685964, 38.68438400541033, 10.259349601609365, 0.015392699212368046, 0.02976172317617706, 0.03686988979045834, 0.6649227376495088, 3.0023183482033864, 6.8020302057266235, 7.785364457539149, 10.250363843781606, 10.470304727554321, 27.147899048668997, 33.69009528841291, 50.23251240594046, 60.18376064300537, 56.66271236964634, 60.85195500510079, 55.884010383060996, 56.46651608603341, 56.03568261010306, 51.015765462602886, 44.848464488983154, 51.093164920806885, 55.19870260783604, 54.07325077056885, 51.41892773764474, 55.26009341648647, 54.99053110395159, 46.42651850836617, 40.09007753644671, 40.23457227434431, 45.80539819172451, 51.92236294065203, 53.0252366065979, 53.557322706495015, 52.642220633370535, 50.2571576663426, 50.86813708714077, 49.91822106497628, 49.04372773851667, 49.310486452920095, 53.66533940179007, 52.429821150643484, 48.36680991309029, 40.68185561043875, 39.345314025878906, 38.85035215105329, 39.759760175432476, 41.379319259098594, 45.06584235600063, 49.4477550642831, 52.502874510628835, 53.3744079044887, 53.144075121198384, 48.85702269417899, 54.0426960672651, 36.01546628134591, 39.467852456229075, 58.1893983568464, 48.604139532361714, 47.51527343477522, 38.831512110573904, 42.507387093135286, 48.62950393131801, 54.08075482504708, 51.2297317641122, 49.16305957521711, 48.149421623774934, 52.729455266680034, 53.96810368129185, 53.59026064191546, 51.58218955993652, 52.810370513371055, 51.95692328044346, 53.4664055279323, 51.21702350888933, 53.43213701248169, 50.39249120439802, 49.09642287663051, 52.04123272214617, 53.50613185337612, 48.351093087877544, 46.612285545894075, 52.82507984978812, 54.4892463684082, 51.371541023254395, 46.15758500780378, 41.79653773988996, 40.38787037985665, 43.462733132498606, 46.59463364737374, 44.571425914764404, 47.85025651114327, 46.34267807006836, 48.65025820050921, 53.73474843161446, 55.365535804203574, 58.44070775168282, 56.27939414978027, 33.17146437508719, 15.617783852985927, 4.549201011657715, 12.60384030001504, 10.534886496407644, 5.829410510403769, 5.010681254523141, 2.7896847980363026, 0.4506494940391609, 0.15088077022561006, 0.018061346906636442, 2.138080562864031, 31.987178666251047, 34.744724137442454, 33.28384106499808, 44.359644821711946, 23.76738851411002, 37.128369671957834, 42.866483892713276, 53.33116231645857, 55.37152862548828, 40.459485462733674, 1.7509292172534126, 0.1210579483636788, 0.03942237228953412, 0.021330165610249554, 0.02404267211178584, 0.08177744078316859, 0.018077591034982885, 0.0584969042933413, 0.07959749775805644, 0.006472987014733787, 0.0171610004867294, 0.03317785183233874, 0.07957362689610038, 0.01768890242757542, 0.01353241573087871, 0.012013765301422348, 0.01774673566355237, 0.039334247553987164, 0.013363454574053841, 0.007467215115736637, 0.030083362345716784, 0.01551148185639509, 0.03350080057446446, 0.027945758209430745, 0.10202859661408833, 0.12312404678336211, 0.1478650484766279, 0.12655926602227346, 0.3048039014850344, 0.19900022101189407, 0.10275778427187886, 0.22591455679919037, 0.2500213182398251, 0.09462720448417322, 0.1531419474631548, 0.18106438272765704, 0.14601328569863523, 0.07936928607523441, 0.07440701020615441, 0.12408098472016198, 0.1261182725429535, 0.2565948840762888, 0.177710641973785, 0.14469675134335244, 0.17489431452538284, 0.17810780209090027, 18.795537267412456, 72.73078291756767, 64.84305586133684, 70.32740797315324, 44.9330518586295, 31.89805064882551, 27.44795526776995, 37.330221789223806, 46.146773610796245, 52.39230782645089, 14.209056564739772, 0.0853311118802854, 0.24646489907588276, 0.1762320056025471, 0.47815135972840445, 4.8932927421161105, 14.827264717647008, 12.438215221677508, 16.2716440813882, 23.89278612818037, 39.34614780970982, 39.34728036608015, 54.00629792894636, 63.30361992972237, 57.956862994602744, 64.58534717559814, 56.9308294568743, 56.896269117082866, 58.269128935677664, 52.006731442042756, 46.25658294132778, 53.836021900177, 57.35494749886649, 55.10758393151419, 53.245286055973594, 57.455533095768516, 57.06139653069632, 48.359754017421174, 41.91006783076695, 43.035766329084126, 47.95334345953805, 54.68622432436262, 54.75774213245937, 55.70605659484863, 54.64154740742275, 50.55211564472744, 51.10712732587542, 50.44072559901646, 50.0089819090707, 51.34871966498238, 56.33934668132237, 55.327959946223665, 51.088269914899556, 42.84877640860421, 42.00450427191598, 40.45390258516584, 41.159144742148264, 44.06093481608799, 46.80905505589077, 51.60506650379726, 54.89127608707973, 56.29468366077968, 55.11955567768642, 51.2143554006304, 54.85157755443028, 37.81730440684727, 42.65238210133144, 61.377600124904085, 52.38570703778948, 51.138508864811485, 40.77199459075928, 44.1504693031311, 50.897420270102366, 56.20171676363264, 53.43288394383022, 47.752512727464946, 48.8217362676348, 54.24956478391375, 55.82673290797642, 55.34844323566982, 54.28315585000174, 53.698642117636545, 54.27121884482247, 53.90715755735125, 53.17391068594796, 55.61802986689976, 52.86424684524536, 51.62940604346139, 54.84202030726841, 55.15358100618635, 49.562323910849436, 45.91840021950858, 53.566925116947715, 55.96283769607544, 54.016831398010254, 47.276116439274375, 44.1202654838562, 43.150199685777935, 45.34853328977312, 48.34641000202724, 47.62590612683977, 49.792514256068635, 49.532745429447715, 50.737114906311035, 57.32856518881661, 57.676576137542725, 61.21185084751674, 58.651224272591726, 38.58177300861904, 19.482034921646118, 10.908179334231786, 25.22851824760437, 14.232704758644104, 10.146831342152186, 6.974357255867549, 2.7662161716393063, 0.34260354031409535, 0.17908662956740173, 0.16189271504325525, 2.94805617417608, 36.82025180544172, 43.958549635750906, 44.477871894836426, 41.377547468457905, 31.90358141490391, 45.66576024464199, 49.459292548043386, 62.19463184901646, 62.90029089791434, 50.85275724955967, 2.829633900097438, 0.25455979470695766, 0.09365362208336592, 0.12764201792223112, 0.10043693666479417, 0.16761592722364835, 0.15613060923559324, 0.09130298000361238, 0.24535288874592098, 0.20589235903961317, 0.09334790134536368, 0.09917333482631616, 0.1577373937304531, 0.09804859517940454, 0.09725876006164721, 0.15793339535593987, 0.12613591445343836, 0.1227726334972041, 0.06896154276494469, 0.1127241812646389, 0.12863993937415735, 0.09303360392472573, 0.11646915173956326, 0.100433001161686], [0.021343358027349626, 0.02979884243437222, 0.021671193917947154, 0.011917972271995885, 0.07670629397034645, 0.027056619491694228, 0.035016875115356276, 0.05962109432688781, 0.06516957016927855, 0.022371957743806497, 0.04086742117734892, 0.026674368485276188, 0.027919734695128033, 0.06302917216505323, 0.040596373578799624, 0.025845269938664775, 0.01530983142687806, 0.03438617681552257, 0.029008481451975446, 0.05925067527485745, 0.0383603903464973, 0.8084233946033886, 22.83077481814793, 54.4731057030814, 58.963198389325825, 41.251003401620046, 47.23880461284092, 38.958295890263145, 20.165991272245133, 31.193340029035294, 35.08559581211635, 31.29346009663173, 0.6495700957519668, 0.05094919965735503, 0.0756969324180058, 0.21955785075468676, 0.7653175847870963, 2.2161911257675717, 5.511500460760934, 9.688741820199148, 6.39835159267698, 16.516344002314977, 30.39546796253749, 39.755188260759624, 56.86402252742222, 53.28714895248413, 54.69674389702933, 53.47826957702637, 56.5775100844247, 54.88930279867989, 55.48994329997471, 49.374364716666086, 41.68480723244803, 47.1682630266462, 51.62110294614519, 51.40430525371006, 48.740536144801546, 50.857773848942344, 50.419311250959126, 46.57561295373099, 37.71700716018677, 37.32648365838187, 42.99640825816563, 49.06228290285383, 51.902334758213584, 51.944037846156526, 51.917249066489084, 48.64361572265625, 49.10931525911604, 48.497627122061594, 49.18967464991978, 47.95649446759905, 51.573212487357004, 48.58938503265381, 43.68180635997227, 39.02214288711548, 37.37937682015555, 36.251281193324495, 39.13124350139073, 40.286669867379324, 47.41103308541434, 47.00749213354928, 50.22047812598092, 49.10641438620431, 53.33381305422102, 46.602380888802664, 53.7568575995309, 34.87235907145909, 36.32885435649327, 56.170078141348704, 45.44888264792306, 47.01146650314331, 38.042818614414756, 38.78604309899466, 42.41373927252633, 52.41798142024449, 49.018286909375874, 48.318235056740896, 46.33560480390276, 48.31182534354073, 48.46192032950265, 50.75005940028599, 48.95294604982649, 49.94907801491873, 48.89111055646624, 49.1427013533456, 50.893928800310405, 50.79561526434762, 48.74453830718994, 50.766380718776155, 50.92139850343977, 50.31555380140032, 50.04434823989868, 48.23625673566546, 47.97647401264736, 52.454768657684326, 49.49527726854597, 49.911022731236045, 47.62660094669887, 45.10857030323574, 37.55348130634853, 39.297875199999126, 40.32535743713379, 40.51602642876761, 44.02685390199934, 47.819027832576204, 47.88056107929775, 48.63439893722534, 54.51508671896798, 54.23249305997576, 52.79687016350882, 28.285895858492168, 16.18457794189453, 9.600168790136065, 10.025743348257881, 7.127446481159755, 3.4362109856946126, 1.3335000106266566, 0.10284004985753979, 0.05941841591681753, 0.03247126956869449, 0.29536241239735056, 10.581319570541382, 38.12470660890852, 29.66640043258667, 11.51091298035213, 24.073738064084733, 24.147720745631627, 32.85129485811506, 37.26190710067749, 45.100162982940674, 40.849366256168906, 11.82563771520342, 0.023601973795198967, 0.05358571871849043, 0.038099361317498345, 0.04628566579361047, 0.0794477586501411, 0.04981370523039784, 0.023990642046555877, 0.03679835184344223, 0.02097848430275917, 0.006693984598054418, 0.017200340250773088, 0.06456496154091187, 0.030598791116582494, 0.00925471299394433, 0.06813437465046134, 0.04555792680808476, 0.0431237061774092, 0.038162424362131527, 0.0653967165521213, 0.05207094357215932, 0.11253936868160963, 0.03050895986546363, 0.02183067169971764, 0.036937709365572245, 0.027235700150153468, 0.03637933272070118, 0.01910501010050731, 0.09197179161544357, 0.039453995414078236, 0.053533939711217365, 0.006891314455840204, 0.040592241300536056, 0.04052772958363805, 0.05986710398324898, 0.00848916603717953, 0.031202765314706733, 0.025139646105734364, 0.06086822812046323, 0.037468598556837866, 0.04804892046377063, 0.06579666544816323, 0.06272107655448572, 0.03861305643139141, 0.08087228863899197, 1.1165524976594108, 28.811883177076066, 63.23515932900565, 66.00125108446393, 50.54603944505964, 48.734557219914024, 42.30571910313198, 27.46408029964992, 30.96149253845215, 36.20230681555611, 31.421282632010325, 0.9433992632797786, 0.014565715998677271, 0.026342446117528846, 0.26787813433579033, 1.3998902652944838, 5.797583852495466, 7.340286305972508, 6.507868230342865, 6.423883182661874, 15.670206274305071, 30.386935574667795, 44.17012228284563, 59.50979927607945, 55.02994128635952, 57.301540170397075, 55.854115758623394, 58.662105151585166, 55.39109475272042, 56.498019218444824, 51.9667306627546, 44.2795147214617, 47.78345652988979, 53.26228829792568, 53.926886967250276, 50.83262137004307, 51.642037868499756, 53.631446089063374, 48.1369218145098, 39.594500746045796, 39.35410697119576, 44.932871205466135, 52.63161073412214, 52.6121175629752, 51.38805341720581, 51.58079644611904, 49.28695985249111, 49.67144884381975, 50.008891582489014, 49.918443407331196, 48.28695774078369, 52.58415453774588, 51.350474085126606, 45.816723755427766, 39.650819369724815, 39.59197507585798, 39.87440892628261, 40.709794316973, 44.17226580211094, 48.80972283227103, 48.51379558018276, 51.998456137520925, 51.155396461486816, 55.91297047478812, 47.9276316506522, 52.36239235741751, 35.02542093821934, 37.86182846341814, 58.60176699502127, 48.35357706887381, 48.42719323294503, 39.91551794324602, 40.806739057813374, 43.84579426901681, 52.703938007354736, 49.91409036091396, 49.331932067871094, 45.891903264181956, 49.74344607761928, 48.25178943361555, 51.87904439653669, 50.24485240663801, 50.78480386734009, 48.99310316358294, 49.893117223467144, 50.805287156786235, 52.60636098044259, 50.47316326413836, 51.246556827000205, 52.520067828042166, 50.47475092751639, 48.232636724199565, 48.88543735231672, 49.68998663766043, 53.44552966526577, 51.1358824457441, 51.36956426075527, 48.93769475391933, 46.63995674678257, 39.26943622316633, 41.90588501521519, 42.12274524143764, 43.39036764417376, 44.59939936229161, 50.207509313310894, 50.44365773882185, 52.414086954934255, 53.690168789454866, 59.00998755863735, 52.83189950670515, 32.09254462378365, 9.415706276893616, 10.18364029271262, 11.462066275732857, 7.824831962585449, 7.291771377835955, 3.5853080366339003, 1.6109601450817925, 0.2435032565678869, 0.03352127876132727, 0.08972934194441352, 12.731656755719866, 37.16578919546944, 28.28885405404227, 15.714181423187256, 29.985906396593364, 32.55438443592617, 39.69194228308541, 42.693640504564556, 51.06226628167288, 48.76727628707886, 16.152939319610596, 0.043454814303134165, 0.06100520398467779, 0.02733767717810614, 0.039923830024365864, 0.08241512799369437, 0.012374080967025032, 0.09363503022385494, 0.07277283325259175, 0.023276312609336207, 0.04260543095214026, 0.014797595163275088, 0.033067766310913224, 0.02035735504302595, 0.02375338040292263, 0.04429247256900583, 0.025019479250269275, 0.023007875674271157, 0.05308921089661973, 0.06499106117657252, 0.02963216369971633, 0.022543248820251653, 0.02869856058220778, 0.015854457559596215, 0.0817001217177936, 0.16135199048689433, 0.08422706076609236, 0.15227195700364454, 0.24822282046079636, 0.23130371261920246, 0.12061368434556893, 0.11755389853247575, 0.1714640078800065, 0.06787686382553407, 0.1809914537838527, 0.1093238794377872, 0.12377772027892725, 0.09547757849629436, 0.12127487600914069, 0.07185600352074419, 0.10334475098976068, 0.17414244344191893, 0.1157099117657968, 0.21027405320533685, 0.1387502197176218, 1.5427117901188987, 39.037376812526155, 70.44251877920968, 73.37481839316231, 55.80593694959368, 59.062363079616, 48.12066650390625, 28.670617614473613, 38.94115121023995, 45.875137260981965, 39.63660682950701, 1.1180477717093058, 0.20968144786145004, 0.2224336585828236, 0.5619249216147831, 1.8309664939131056, 7.109833666256495, 13.576922484806605, 19.689749581473215, 13.141950488090515, 20.70572212764195, 34.941250460488455, 47.556715965270996, 64.56202207292829, 56.66200712748936, 61.559601238795686, 57.42583302089146, 59.83807386670794, 55.56613377162388, 60.67001642499651, 54.42761584690639, 45.98295245851789, 50.310815129961284, 55.362954548427034, 55.34935344968523, 50.84483630316598, 53.52180698939732, 54.201000349862234, 51.68900421687535, 41.623687403542654, 40.96149628502982, 48.13215882437569, 54.99946648733956, 55.08278233664376, 53.92445509774344, 52.92128808157784, 50.31025232587542, 52.25163459777832, 51.58850547245571, 51.670667920793804, 50.20165198189871, 54.27382789339338, 54.40261275427682, 47.248778751918245, 40.97308240618025, 40.429156575884136, 41.00042356763567, 42.2010931287493, 45.83336121695382, 51.2105929510934, 49.97353219985962, 53.31480278287615, 51.93572432654244, 58.661590984889436, 49.844858510153635, 53.02804020472935, 37.5079983983721, 40.179240294865195, 59.59405313219343, 50.420381273542134, 50.74251365661621, 41.346117292131694, 43.02906131744385, 46.470521450042725, 55.093413080487935, 52.48985011237008, 51.09972402027675, 46.66569287436349, 49.55006381443569, 50.01357119424002, 53.348404271262034, 51.461134569985525, 52.2259783744812, 49.734201499394004, 49.563866410936626, 53.156870228903635, 52.9988751411438, 53.4618683542524, 53.244917801448274, 54.35131767817906, 51.40830741609846, 50.35013151168823, 48.71161079406738, 51.28811400277274, 56.777416706085205, 54.18608604158674, 54.05744709287371, 51.32730879102434, 49.3512202671596, 41.68540130342756, 42.72577244894845, 45.164649214063374, 43.971146719796316, 48.92362117767334, 52.29581124441964, 53.390225478581016, 54.55090815680367, 59.381271498543875, 59.87824835096087, 58.71559933253697, 35.67270469665527, 24.565251895359584, 20.396558557237896, 14.833337443215505, 18.54614904948643, 9.140077318464007, 4.976777953760965, 0.7679337444049972, 0.1959570457360574, 0.16307475018714154, 0.5142584879483495, 15.994939020701818, 51.36250836508614, 40.523148332323345, 18.54444326673235, 33.427849428994314, 37.81322928837368, 44.450447354997905, 51.003057207380024, 57.58587782723563, 57.3068277495248, 22.152335337230138, 0.1942381943975176, 0.2092898788728884, 0.10120051926267998, 0.1517736951687506, 0.18174337915011815, 0.09364327442433153, 0.12284473462828568, 0.147959581975426, 0.04349682579881378, 0.13593214164887155, 0.10919526991035257, 0.14871350223464624, 0.10666219690548522, 0.08307823312601872, 0.11794549466243812, 0.08299979447786297, 0.13983373157680035, 0.09146958749209132, 0.1545496904956443, 0.08206399969224419, 0.1277200358786753, 0.09669303827519928, 0.10178019172911133], [0.07302655785211495, 0.0075350584395762, 0.020630358518766503, 0.028846257299716984, 0.03613031376153231, 0.03788191120007208, 0.05041573542569365, 0.026372128631919622, 0.04564783609073077, 0.038004420697689056, 0.04097726581884282, 0.02658865085270788, 0.023054273898846338, 0.03198806781853948, 0.015702326615740145, 0.022495741190920984, 0.02997179761795061, 0.05985683774841683, 0.04589528084865638, 0.051715469253914695, 0.060530711231487136, 2.1406713724136353, 35.43948493685041, 56.54640647343227, 48.71739169529506, 31.688204629080637, 32.25948551722935, 20.310110807418823, 23.841543163572037, 42.25314903259277, 43.29402044841221, 14.555930614471436, 0.02843433734960854, 0.1196073762008122, 0.015628585126250982, 0.20535991261047976, 2.140452069895608, 4.673081312860761, 3.921435611588614, 4.723487888063703, 15.450069972446986, 30.116619382585796, 37.10342563901629, 50.928339753832134, 56.97726426805769, 51.82352828979492, 48.14900820595877, 53.26525517872402, 53.607314995356965, 56.26148864201137, 51.38451678412301, 50.07041440691267, 41.45727457318987, 44.171372958592, 49.33337729317801, 53.49557406561715, 50.39405107498169, 49.36648893356323, 50.692472730364116, 47.07292331968035, 39.40722942352295, 36.34292098454067, 42.75994021551949, 49.55819320678711, 50.955507210322786, 48.563777446746826, 48.71050255639212, 48.054804529462544, 49.538099016462056, 49.18067673274449, 49.158362592969624, 49.6517368044172, 50.40036351340157, 47.40415784290859, 44.680356298174175, 38.21611016137259, 37.33005155835833, 35.08338975906372, 39.269113131931846, 46.07076031821114, 48.981662954602925, 49.262790543692454, 49.83714253561837, 50.800579752240864, 50.4113312448774, 44.798051834106445, 51.79037496021816, 37.93216855185372, 39.126174790518625, 53.40334020342146, 47.39747714996338, 48.03631884711129, 39.35462461199079, 38.93601301738194, 37.4448253767831, 50.09107487542288, 50.897111075265066, 52.33718776702881, 49.31833096912929, 49.40952260153634, 48.607398237500874, 48.18900203704834, 46.517880371638704, 47.71753549575806, 47.19280406406948, 46.185978821345735, 46.23103788920811, 49.722507681165425, 48.77698639460972, 50.60198286601475, 50.237567220415386, 48.72294678006853, 44.46117884772164, 44.911766052246094, 45.74179438182286, 50.384604998997276, 51.80869735990252, 52.93455566678728, 52.91814054761614, 52.85925109045846, 42.92504678453718, 39.96609040669033, 39.39982611792428, 41.362935406821116, 46.58242218835013, 52.90553651537214, 51.10995176860264, 52.165122577122276, 47.551313740866526, 57.879661560058594, 49.18876096180507, 49.575605392456055, 12.388599872589111, 14.418273772512164, 15.233986207417079, 3.682774978024619, 7.517711162567139, 3.9058151926313127, 1.6977887430361338, 0.18775392376950809, 0.07689996143536908, 0.06863705374832664, 2.068651122706277, 22.156957626342773, 43.78072438921247, 36.44236012867519, 12.920738952500479, 14.812334775924683, 23.609393426350184, 38.05658646992275, 46.325258936200825, 48.00497899736677, 23.64625883102417, 1.1722030086176736, 0.29323737642594744, 0.04686161310278943, 0.09572467380868536, 0.015884956012346914, 0.04616797050195081, 0.010163890547119081, 0.01677218295766839, 0.03527786343225411, 0.026889318201158727, 0.03924171234081898, 0.07307199934231383, 0.023514615804223076, 0.010419867882904197, 0.018077144898208122, 0.009615603717975318, 0.0529270172784371, 0.06547079222010714, 0.02718763442576996, 0.05820448284170457, 0.016492153251809732, 0.002486978000628629, 0.05618006343554173, 0.012542481484290744, 0.032149779676858864, 0.07837852995310511, 0.01669756615800517, 0.030819169112614224, 0.044800227108810625, 0.007047733741014132, 0.011605614613342499, 0.01935297902673483, 0.03667830203526786, 0.04392573456945164, 0.016288282316444174, 0.047526933651949675, 0.06512677496565239, 0.05037244149882879, 0.02624612976796925, 0.10306146261947495, 0.032114017488701005, 0.04659433476626873, 0.03630710606064115, 0.0097385228811098, 3.2167690694332123, 46.377523286002024, 63.72132478441511, 55.31749595914568, 35.512076241629465, 40.012556484767366, 28.586511407579692, 23.108839988708496, 34.86986466816494, 40.90137004852295, 15.698739051818848, 0.07366005171622549, 0.056516060406076055, 0.06285492437226431, 0.6091969364455768, 2.373930650097983, 6.447771089417594, 4.949496720518384, 7.786510910306658, 11.351535201072693, 28.260296957833425, 39.578488622392925, 54.96305792672293, 59.23754106249128, 54.51402711868286, 50.78507137298584, 55.85077714920044, 55.21014976501465, 57.89003522055489, 53.90000786100115, 52.66434022358486, 41.89214495250157, 45.912970202309744, 52.36707891736712, 54.69850526537214, 49.894010066986084, 50.58853810174124, 53.735762868608745, 48.8141245160784, 40.10563107899257, 38.20537519454956, 44.80998189108712, 53.06491082055228, 52.6393267086574, 49.167099952697754, 49.0092716217041, 49.618798868996755, 50.100527899605886, 50.48895999363491, 50.918990952628, 50.38647753851754, 51.16756623131888, 50.31520986557007, 46.73721068246024, 40.08428621292114, 38.96205833980015, 36.82742234638759, 41.8473082269941, 46.943186555589946, 51.4366317476545, 50.53972353254046, 51.4286447933742, 53.38310357502529, 52.62091398239136, 47.4507211957659, 51.048967429569785, 37.90540409088135, 39.7045567376273, 55.304447242191856, 49.182253973824636, 50.399811131613596, 40.09489263807024, 39.83334159851074, 38.72551039287022, 50.75393649509975, 53.034811224256245, 53.29669925144741, 49.28579255512783, 48.7251250403268, 49.36353942326137, 47.66528851645333, 46.42810269764492, 49.53180742263794, 47.897716181618826, 46.03615481512887, 46.70311934607369, 50.91050025394985, 51.08575814110892, 51.693916593279155, 52.161273275102886, 47.759971618652344, 46.30600200380598, 45.846899781908306, 45.26795850481306, 53.20432989937918, 53.96386875425066, 55.409622124263215, 55.08448117119925, 55.75293609074184, 44.936265400477815, 40.05519757952009, 41.724411964416504, 41.98083175931658, 47.549760818481445, 53.98925052370344, 53.66317851202828, 51.63492291314261, 51.20439863204956, 56.0784626688276, 53.34851891653878, 48.04865884780884, 15.580769062042236, 5.168738876070295, 9.650272250175476, 9.47367422921317, 8.02228500161852, 6.89560159615108, 4.5299588441848755, 0.4232912063598633, 0.23403815446155413, 0.07772054097482137, 1.962909311056137, 25.18848099027361, 38.46154832839966, 30.63757446834019, 17.810666595186504, 22.206555604934692, 29.533321584974015, 45.18440989085606, 51.75065558297293, 54.98896428516933, 32.84699044908796, 2.210050003869193, 0.27274260616728235, 0.06519874717508044, 0.03236487527777042, 0.021628332557156682, 0.016605234505342584, 0.0488248727550464, 0.008993607629755778, 0.03837320448032447, 0.018049916984247308, 0.030378932199840034, 0.09150499344936439, 0.028690635293189968, 0.0426918593501406, 0.03654724978176611, 0.06140999083540269, 0.04165313080219286, 0.0204964699888868, 0.033761761749961545, 0.035306562070867846, 0.028105388661580424, 0.03360852479402508, 0.03560382826253772, 0.1011896152049303, 0.10009281084473644, 0.09448403359523841, 0.14707659078495844, 0.10135863149272543, 0.1106511957145163, 0.09124335713152375, 0.10222225050841059, 0.10247735253402165, 0.13650854357651301, 0.14290129340120725, 0.07634753214993648, 0.1372427727494921, 0.17080011564706052, 0.1932751089334488, 0.20621144691748278, 0.11702860386243888, 0.13688404485583305, 0.1422154844871589, 0.16139560671789305, 0.13516387715935707, 5.808577639716012, 55.15598855699812, 71.93248353685651, 64.48018618992397, 44.59459468296596, 42.906793866838726, 28.580315351486206, 33.94051878792899, 53.493187359401155, 55.54793643951416, 19.133405583245413, 0.2176266722381115, 0.3555470300572259, 0.1518904303333589, 0.6567317886011941, 5.948035802159991, 12.107249941144671, 13.262905597686768, 10.55935457774571, 21.84839333806719, 35.790066719055176, 46.70304291588919, 57.86971868787493, 61.878606932503835, 56.554709570748464, 50.75648300988333, 58.12719113486153, 57.576574189322336, 58.00494800295149, 55.01922369003296, 54.11078493935721, 44.164608887263704, 49.172338894435335, 53.8244184085301, 56.60780423028128, 51.36978660311018, 51.57801716668265, 55.79438556943621, 51.84104469844273, 43.87574100494385, 39.811030932835166, 45.633308683122905, 53.72381544113159, 53.76426090512957, 49.97038466589791, 49.01426042829241, 50.26528358459473, 51.93586329051426, 52.13871942247663, 53.42956270490374, 51.63826152256557, 52.89505863189697, 53.49714435849871, 47.93582705089024, 42.03397853033883, 39.96078545706612, 38.713288511548726, 44.470034326825825, 49.59915631158011, 53.18289123262678, 51.912774426596506, 54.58622237614223, 54.192742415836875, 54.95909397942679, 49.17116117477417, 50.79516363143921, 40.6849684034075, 43.66673224312918, 56.62570973805019, 51.01210723604475, 52.310927050454275, 42.89752844401768, 41.519273349217, 41.72722945894514, 54.8865339415414, 56.614710739680696, 54.93440702983311, 51.07236896242414, 49.65614891052246, 51.744527271815706, 48.69090863636562, 47.776334626334055, 49.69757407052176, 47.57508700234549, 46.19474049976894, 47.76283427647182, 51.75548110689436, 51.37423345020839, 54.54102087020874, 53.82929604394095, 48.5995328766959, 46.22491305215018, 48.28663812364851, 45.74199587958199, 54.141079085213796, 56.430788448878694, 57.67237595149449, 58.93886579786028, 58.444313866751536, 46.56421790804182, 44.08135209764753, 43.612386907849995, 45.12651750019619, 50.83293056488037, 58.96333735329764, 55.40306997299194, 57.23361110687256, 51.497244358062744, 61.2910464150565, 52.42168828419277, 56.481322697230745, 17.54046504838126, 25.604553018297466, 30.535081590924943, 13.682954600879125, 18.313625846590313, 8.385931134223938, 5.661596315247672, 0.2163342937294926, 0.3185322391135352, 0.14939038162784918, 2.9160838212285722, 31.697893892015728, 57.74084002631051, 49.57363210405622, 20.298813036509923, 23.557674510138376, 34.959628445761545, 51.060174873897004, 60.192605699811665, 61.360674313136506, 42.32135254996163, 3.6155505052634647, 0.44154672963278635, 0.15507978919361318, 0.16582850313612393, 0.09006232621946506, 0.1489992740431002, 0.1083045027085713, 0.10859036951192788, 0.11832007313413279, 0.10066418482788972, 0.13188568449446134, 0.2505830095282623, 0.15954442748001643, 0.09523146705968039, 0.1526079268327781, 0.14870002652917588, 0.14184577789689812, 0.11840444217835154, 0.1229070241429976, 0.17441378959587642, 0.09308379516005516, 0.13796998587037834, 0.10619179571845702], [0.027137528007317866, 0.00611090164498559, 0.076944276557437, 0.038183520015861304, 0.027462225673454146, 0.07114702942115919, 0.011944205283985605, 0.03037039962198053, 0.08475038089922496, 0.0014775509272502469, 0.045656321171138964, 0.042422046685325246, 0.013889572815969586, 0.02973331291494625, 0.03132296100791011, 0.07131557073444128, 0.05913318693637848, 0.011036003973068935, 0.05709727653967483, 0.016645503862361823, 0.08289950700210673, 9.472583362034388, 50.32090391431536, 54.413375513894216, 48.502515179770334, 31.740771225520543, 15.762893506458827, 19.686859130859375, 34.559499059404644, 33.9331328528268, 38.095048223223, 2.928135254553386, 0.030642200394400528, 0.06520023995212146, 0.2407708503305912, 0.19968095448400291, 1.7952030301094055, 4.580995099885123, 5.315705435616629, 5.3858848469597955, 22.460098845618113, 33.5589028767177, 42.51574230194092, 54.74806676592146, 53.11934995651245, 50.33805206843785, 46.46590437207903, 52.043921675000874, 53.83854062216622, 53.0741970879691, 54.026788166591096, 51.38447856903076, 40.68318271636963, 44.40004859651838, 51.137251240866526, 51.47412422725132, 50.30970689228603, 50.625106470925466, 52.282964025224956, 48.500361238207134, 39.39716495786394, 36.38305377960205, 41.696372509002686, 48.72226933070591, 51.05621092660086, 47.146119117736816, 48.360271658216206, 51.09650700432913, 50.61476755142212, 50.28012841088431, 48.38698748179844, 46.71944066456386, 50.43659489495413, 46.140992709568565, 42.14168603079659, 35.03722940172468, 36.87962416240147, 34.02715935025896, 42.02207626615252, 47.79394136156355, 52.06520400728498, 51.43700347627912, 51.74976621355329, 48.15771777289254, 50.179125922066824, 44.962574754442485, 50.771122864314485, 32.42879227229527, 32.4664306640625, 57.02691609518868, 45.57968943459647, 50.152417046683176, 45.22066906520298, 41.78608417510986, 35.212570667266846, 38.49229063306536, 45.91307095118931, 50.42975091934204, 50.00630337851388, 50.638012749808176, 45.800232206072124, 46.59622825895037, 45.41177231924874, 47.4538756779262, 47.07529960359846, 48.90925577708653, 45.82333149228777, 47.402431215558735, 46.63896662848336, 47.81217343466622, 46.51269006729126, 47.7838317326137, 42.816178934914724, 46.640446594783235, 49.91785281045096, 47.06900453567505, 48.06054721559797, 49.68175997052874, 50.8247629574367, 51.47350583757673, 50.371855054582866, 41.208914688655305, 38.083319664001465, 38.97472837993077, 49.644062519073486, 52.35155316761562, 52.04523835863386, 53.51854828425816, 47.70468132836478, 48.89585965020316, 53.90956163406372, 56.04978050504412, 34.843510150909424, 10.721724425043378, 6.511113473347255, 6.604938473020281, 6.420185003961835, 4.379668874400003, 4.752937827791486, 1.5630297341517039, 0.07969870804143803, 0.07105746279869761, 0.04192013093935592, 7.850168568747384, 37.42822960444859, 29.258096490587505, 26.437744515282766, 26.746536357062205, 15.458088193620954, 25.99517032078334, 35.817942891802105, 47.24763229915074, 40.00659493037632, 8.684913856642586, 0.04703733670924391, 0.017899058293551207, 0.014494893906105841, 0.03653534488486392, 0.0593142065086535, 0.07093819669846978, 0.04691041334133063, 0.061547163474772654, 0.03837400854432157, 0.0804886177980474, 0.018802724446036985, 0.022931995103135705, 0.022360500680016618, 0.005764400528278202, 0.019796815567782948, 0.0334172898770443, 0.042487562634050846, 0.026248477499133775, 0.04334646922403148, 0.03458928609532969, 0.091005768094744, 0.052996699432177205, 0.03438091816912804, 0.04449481510424188, 0.027955537595387017, 0.02030102476211531, 0.04415868242670383, 0.02075325308500656, 0.006897245700071965, 0.042667191209537644, 0.0407956389577261, 0.01618646813689598, 0.019324877498937503, 0.018686126684769988, 0.01693515689112246, 0.008563860868369895, 0.0415077207476965, 0.05659804779237934, 0.03517451237088867, 0.022946397008906518, 0.0435670541732439, 0.03325373240347419, 0.011123901399384652, 11.620565976415362, 60.74502222878592, 59.93063082013811, 55.57894624982561, 36.92619446345738, 22.20309887613569, 19.967455182756694, 29.569052696228027, 34.14478193010603, 39.112778663635254, 3.3056884237698148, 0.020229225579117025, 0.009692121263859528, 0.39316680282354355, 2.5556507962090627, 4.871867537498474, 5.609549530914851, 7.71112642969404, 5.315576893942697, 21.82100353922163, 34.960656779153005, 47.71556568145752, 57.648991789136616, 56.69286060333252, 54.13747297014509, 48.973842757088796, 54.969245297568186, 57.57356909343174, 55.968149593898225, 55.38342046737671, 52.733158656529014, 42.532393659864155, 47.05580643245152, 51.634766578674316, 53.16490929467337, 51.326186656951904, 50.886494227818076, 54.656798703329905, 50.45063025610787, 41.3657876423427, 38.11667449133736, 45.02419137954712, 51.9212303842817, 51.08660234723772, 47.551904337746755, 48.82484211240496, 52.96555505480085, 52.766371045793804, 51.691825185503276, 50.34403794152396, 48.681462560381206, 51.66889613015311, 48.72405154364449, 44.34747157778059, 37.90059246335711, 38.24570948737008, 35.981138706207275, 43.33809634617397, 50.01482881818499, 53.296456064496724, 53.241447176252095, 52.36251047679356, 49.98979793276106, 51.4992801802499, 45.88726534162249, 50.556392260960166, 34.391126837049214, 33.983847754342214, 57.75464957101004, 47.12000778743199, 52.30472925731114, 47.41066830498831, 43.03888954435076, 36.81324107306344, 40.48878949029105, 48.50816753932408, 52.37197044917515, 51.86547109058925, 52.66654975073678, 45.63252701078142, 46.553889410836355, 47.10440213339669, 47.39724438531058, 46.869678088596885, 49.423808097839355, 47.01582997185843, 48.298981598445344, 48.768766675676616, 49.041233335222515, 47.002656187329976, 47.57913780212402, 42.98555169786726, 48.207741328648154, 49.13207755770002, 47.45527226584298, 48.34255722590855, 51.754765442439485, 51.294812066214426, 54.59456021445138, 51.12501893724714, 43.7853935786656, 38.905979428972515, 41.74719163349697, 51.12794760295323, 54.09461300713675, 54.415852546691895, 55.58099249431065, 48.475142751421245, 51.69885328837803, 55.41566358293806, 56.32169825690133, 33.81933178220476, 11.54513372693743, 9.122375914028712, 9.35489651135036, 9.550481353487287, 9.370737535612923, 4.998623958655766, 2.930667438677379, 0.44222990583096233, 0.1581267506948539, 0.08678663734878812, 8.94434482710702, 37.800937925066265, 29.98391921179635, 22.758624723979406, 29.065421206610544, 23.970929043633596, 31.90613487788609, 43.63023335593087, 52.81929547446114, 47.107296058109824, 11.632717507226126, 0.0857728992455772, 0.02323818063762571, 0.05964139609464577, 0.052630684072417874, 0.029540164529212883, 0.007384136984390872, 0.012552502598347408, 0.03356661168592317, 0.05243577828098621, 0.05089031978111182, 0.036200986576399634, 0.01616789832977312, 0.026721435066844736, 0.03412905275555594, 0.0059270080528222024, 0.04828872152471116, 0.056701792404055595, 0.00877474870399705, 0.06173808965831995, 0.0275923754753811, 0.05224151709782226, 0.042575799327875884, 0.12878659793308803, 0.1304784164364849, 0.11746682891888277, 0.24745360602225575, 0.18456418492964335, 0.1598224097064563, 0.08675528224557638, 0.12685164676180907, 0.15517771536750452, 0.07726917269506625, 0.08444270598036901, 0.1154097957270486, 0.12653095754129545, 0.13844118772872857, 0.09278044929461819, 0.1915783914072173, 0.11108005020235266, 0.12925564205007894, 0.1374979019165039, 0.08471327860440526, 0.1628028340637684, 15.37662056514195, 69.45744487217495, 67.31433555058071, 63.84509999411446, 45.83229814256941, 26.621383666992188, 28.422195196151733, 45.608121463230674, 46.544929708753315, 49.25867026192801, 4.267938801220485, 0.1682495567947626, 0.17779760302177497, 0.5470423687781606, 2.4066972689969197, 8.067514300346375, 13.13706590448107, 13.387042113712855, 12.674835256167821, 26.959517751421245, 41.0049398967198, 50.50552797317505, 58.508404050554546, 60.171705518450054, 56.905548436301096, 50.766314710889546, 57.00691570554461, 59.27757658277239, 56.92374576841082, 57.28020920072283, 55.79551117760794, 45.26728800364903, 50.28384222303118, 53.187946047101704, 56.083315985543386, 51.238882541656494, 53.5534143447876, 57.10272094181606, 52.09291342326573, 42.92128780909947, 41.27375875200544, 47.30106742041451, 51.95727416447231, 54.128659180232454, 48.26096452985491, 49.69298478535244, 53.80544982637678, 54.87078932353428, 54.19616787774222, 51.90273427963257, 49.60788324901036, 54.192700726645334, 51.539923667907715, 47.26438440595354, 40.50623641695295, 40.77269983291626, 37.91798727852957, 46.78106771196638, 51.2566351890564, 55.82247018814087, 55.28532232557024, 53.07582296643938, 51.40068871634347, 54.020691122327534, 46.04759155000959, 50.70096342904227, 36.09345286233084, 36.096089703696116, 59.306710379464285, 50.50417307444981, 53.73577676500593, 48.85381610052926, 45.61273854119437, 39.66189479827881, 42.88683516638619, 49.815342562539236, 54.46208586011614, 53.00144944872175, 54.67528785978045, 45.93922744478498, 47.180161816733225, 47.482394559042795, 47.8305583681379, 47.55528116226196, 49.73973573957171, 47.65490790775844, 47.64681325639997, 48.51466757910592, 48.53008910587856, 48.91240678514753, 49.14388254710606, 44.271767480032786, 50.121466296059744, 50.20768649237496, 50.54194695608956, 49.09762838908604, 52.55486788068499, 53.335789816720144, 57.78890766416277, 54.55655704225813, 45.747168813432964, 41.53306552342006, 43.05148662839617, 54.85157755443028, 56.94782475062779, 55.99674143110003, 58.66188975742885, 51.05740254265921, 53.34086894989014, 58.34076486315046, 60.215124811444966, 41.07094430923462, 15.830721821103777, 14.533106650624957, 15.56080515044076, 14.715023517608643, 12.970308269773211, 11.130534717014857, 3.070214624915804, 0.4946141391992569, 0.31321138462850023, 0.26798897981643677, 11.891784565789358, 50.63710948399135, 43.42129407610212, 35.62417500359671, 35.3914589881897, 25.677601167133876, 38.00684431621006, 47.81136049543108, 60.027308055332725, 55.50566012518746, 16.000591380255564, 0.2315973825752735, 0.09989098738878965, 0.13011987853263104, 0.14625765330025128, 0.19742823179279054, 0.10273647827229329, 0.19147255351500853, 0.11898830799119813, 0.07636086536305291, 0.08813544282955782, 0.15760068249489578, 0.10539254931999104, 0.24866617524198123, 0.10096273345074483, 0.19407496601343155, 0.08592816162854433, 0.10164664925209113, 0.08670899258660418, 0.1320528755230563, 0.08185506518930197, 0.16617348391030515, 0.16267343743571214], [0.06702363318098442, 0.010096545946518225, 0.061453009955585, 0.044679454660841396, 0.09478725732437202, 0.09816321331475462, 0.08278364036232233, 0.007296283662851367, 0.04223289487085172, 0.03548013132863811, 0.033064326138368676, 0.021104878413357904, 0.018224502348208, 0.02474181932796325, 0.028099258097686937, 0.03473804472014308, 0.04192564742905753, 0.05196876298370106, 0.004881346997405801, 0.06865386784608875, 0.09519743852849517, 15.712651082447596, 57.87444346291678, 49.89744247709002, 46.15483352116176, 42.03236654826573, 27.30824957575117, 31.706860542297363, 42.258387974330354, 42.909614835466655, 21.145959990365164, 0.2686280512384006, 0.029394991961973052, 0.026711233292839358, 0.05639869420390044, 1.3585363243307387, 1.7994718296187264, 4.081010111740657, 3.123258258615221, 14.377695424216133, 31.661089284079416, 37.13674572535923, 53.0529008592878, 54.38355384554182, 53.82444967542376, 49.56878226143973, 42.77134220940726, 47.75746331896101, 51.605222838265554, 52.882788113185335, 53.45968314579555, 45.84019824436733, 38.751514026096885, 44.489437171391074, 49.06769207545689, 51.26640088217599, 49.818840980529785, 51.0944607598441, 51.96750538689749, 47.3944616317749, 40.24619313648769, 35.34847395760672, 41.46443121773856, 49.35877643312727, 51.11102873938424, 48.29597650255476, 51.06182507106236, 49.40656961713518, 51.2474878856114, 48.35050596509661, 50.425095626286094, 49.701875005449565, 47.685591152736116, 43.74838399887085, 41.35016461781093, 34.47348036084856, 38.57943146569388, 34.01431907926287, 46.13334274291992, 50.77494437353951, 51.94554213115147, 48.46947302137102, 51.949176039014546, 44.68632827486311, 49.1552289554051, 44.82366289411272, 52.146247795649934, 32.551834447043284, 27.2268705368042, 55.25979811804635, 47.829019342150005, 51.23192392076765, 46.04937028884888, 49.511574268341064, 38.97047955649239, 36.1234621320452, 37.08357810974121, 45.40651600701468, 48.802534920828684, 52.031605992998394, 49.88840634482247, 49.80383634567261, 48.54079280580793, 48.74644558770316, 46.170202936444966, 45.87944861820766, 45.2751498903547, 47.14742885317121, 44.858702659606934, 44.90333093915667, 45.86120959690639, 45.43991947174072, 48.920160974775044, 52.19601079395839, 50.016336577279226, 51.60120677947998, 49.236363070351736, 46.70644753319876, 51.89014761788504, 52.45948301042829, 48.09439189093453, 43.73012065887451, 37.27098839623587, 37.96548168999808, 49.469086033957346, 52.30021640232631, 53.3208372933524, 53.48870229721069, 49.409296785082134, 48.546907220567974, 49.800730500902446, 53.36432259423392, 47.20291369301932, 24.303070306777954, 14.147384354046412, 8.490485889571053, 5.676267870834895, 8.776297433035714, 4.803793430328369, 3.40173402428627, 0.4115893542766571, 0.05372541890080486, 0.039298777135887315, 1.4132837866033827, 25.61620341028486, 41.869889872414724, 39.210355690547395, 32.95775168282645, 15.406973770686559, 35.78341729300362, 42.102397441864014, 47.92464392525809, 45.10095507758004, 27.748607294900076, 1.555814029914992, 0.02065703003401203, 0.04285770348672356, 0.02977036771231464, 0.01919630529092891, 0.018643828508044993, 0.0556289505080453, 0.030524840977575098, 0.06070808707071202, 0.04696380726194807, 0.0675187059012907, 0.026801897445693612, 0.03765520925766655, 0.02154854023163872, 0.015452222000541431, 0.10111005697399378, 0.0611996856917228, 0.06362435594201088, 0.11529443120317799, 0.01908024526866419, 0.03210615666050996, 0.05543735936017973, 0.04559101556826915, 0.05318874180583017, 0.04199587580348764, 0.03152617206797004, 0.022751621835465943, 0.04793661952550922, 0.018412395480221937, 0.033359828138990064, 0.0608686963096261, 0.01555942714081279, 0.06381507856505257, 0.026673817175573537, 0.02231420762836933, 0.007440023673033076, 0.06406468445701258, 0.02776358343128647, 0.052035310305655, 0.021060739710394825, 0.06378317384847573, 0.05845194456300565, 0.272988887237651, 22.262146404811315, 65.5164544241769, 56.91198941639492, 52.92179182597569, 48.8822272845677, 30.033143724714005, 34.366551058632986, 44.47376550946917, 42.10499259403774, 22.581497771399363, 0.30989736531461987, 0.1696514237139906, 0.03676585001604898, 0.6188447816031319, 4.044816076755524, 6.00581875869206, 4.959321473326002, 4.803647952420371, 12.117303115980965, 29.171198844909668, 39.54403597967965, 56.46087762287685, 55.46291133335659, 57.32836021695818, 51.46848576409476, 45.17255973815918, 50.612182821546284, 53.06599473953247, 54.08307204927717, 54.86369521277291, 48.832950660160606, 41.263711656842915, 45.88926642281668, 52.09153420584542, 53.69482060841152, 51.38028185708182, 51.10809659957886, 53.91834415708269, 48.83120666231428, 40.0291348866054, 35.35000950949532, 43.24801295144217, 50.061492919921875, 52.753878184727256, 48.99361038208008, 52.669558320726665, 52.559279986790244, 51.93869120734078, 50.14825854982649, 52.04869161333357, 51.36672592163086, 49.69096633366176, 47.050074168613975, 43.70447833197457, 37.15225063051496, 40.06692961284092, 35.512573037828716, 47.81550162179129, 51.44329507010323, 53.43091065543038, 48.85857561656407, 51.808214460100444, 45.87274013246809, 49.17356177738735, 44.504264627184185, 51.58681011199951, 33.8006272315979, 28.40017809186663, 56.171578952244346, 49.42027146475655, 52.20873989377703, 49.20340429033552, 51.70633997235979, 40.99631370816912, 38.59528725487845, 39.2929801940918, 46.09649991989136, 49.61714172363281, 52.85608966009957, 50.595993518829346, 49.247733797345845, 48.263274805886404, 50.12755639212472, 48.01831953866141, 46.93969508579799, 46.693141732897075, 48.07204301016671, 45.799513067517964, 45.7539050919669, 46.42744261877877, 45.61060544422695, 49.47290754318237, 52.106504099709646, 50.984929357256206, 52.78439814703805, 50.25512184415545, 45.95409311567034, 52.250908511025564, 54.42381170817784, 51.1325021471296, 45.476699760981965, 39.00754819597517, 40.38349996294294, 51.33430562700544, 54.020527839660645, 55.36986105782645, 55.47973987034389, 52.93760592596871, 49.24521507535662, 50.600718293871196, 55.245484828948975, 50.27756799970354, 26.410354716437205, 7.675093940326145, 4.1257282836096625, 5.153699500220163, 8.733836991446358, 7.444449356624058, 5.643082405839648, 0.8167446223752839, 0.1913472416677645, 0.05342931639669197, 1.244843167918069, 29.189840861729213, 34.5529225894383, 37.319862025124685, 31.902316842760357, 16.85753182002476, 41.0400595664978, 44.80419751576015, 53.09169265202114, 52.596386841365266, 33.40324933188302, 1.689639266048159, 0.014758523420563765, 0.020891412992828658, 0.04293709208390542, 0.029720441105642488, 0.050892881250807216, 0.035196201742759774, 0.020315630228391716, 0.0577833161556295, 0.1049451572554452, 0.06338068723146405, 0.025484606523865035, 0.019766437554998056, 0.023077216864164387, 0.03892592214314001, 0.04255803867376276, 0.05408738001382776, 0.0300644278260214, 0.06768215141658272, 0.05259800921859486, 0.0499688013722854, 0.06657808673168931, 0.15253867554877484, 0.11358598859182426, 0.09424568459923778, 0.11794465327901499, 0.14228493933166775, 0.19947702756949834, 0.14475030132702418, 0.08450422875050988, 0.21852973449443067, 0.14123574777373246, 0.22670515866151877, 0.09449746858860765, 0.0776768976024219, 0.07605426931487662, 0.10099048553300755, 0.11172771187765257, 0.13471452412860735, 0.07058057481689112, 0.13960142832781586, 0.15956557063119753, 0.6493926995566913, 29.5925132887704, 74.20619814736503, 63.76189531598772, 61.06352765219552, 53.65037645612444, 37.5295204435076, 42.24926846367972, 52.454028674534385, 53.08678374971662, 27.98396188872201, 0.5166868290730885, 0.31686239157404217, 0.19362288527190685, 0.6331045478582382, 3.6406678089073727, 10.126561709812709, 10.751361097608294, 9.168581434658595, 23.552286182131084, 36.825080803462434, 44.74983828408377, 58.850387437003, 57.840473720005576, 58.964518547058105, 55.118100030081614, 46.89093957628523, 52.201020445142476, 53.922231674194336, 57.446660246167866, 57.50059216363089, 49.608644076756065, 42.691590785980225, 49.510726588112966, 54.0680569921221, 54.84996557235718, 51.48399066925049, 53.096997601645334, 56.434933049338206, 51.088843141283306, 43.6750214440482, 38.08953135354178, 46.33523654937744, 53.649865763528005, 54.73295790808541, 48.90030997140067, 52.93427079064505, 54.982603209359304, 53.397034713200156, 52.255925110408235, 53.436590807778494, 54.82211371830532, 50.45857204709734, 48.53026281084333, 45.665715081351145, 38.90367957523891, 43.017978940691265, 37.90970849990845, 49.424013069697786, 53.769110747746055, 54.44363144465855, 50.61517749513899, 53.76671709333147, 47.61877727508545, 51.329289027622764, 46.70482512882778, 51.755727767944336, 37.34517778669085, 31.017585345676967, 56.676845005580354, 53.04485484531948, 53.497887815747944, 50.70384693145752, 52.38876077107021, 42.91513865334647, 40.29754727227347, 40.95858151572091, 48.981259959084646, 52.17168515069144, 55.441941670009065, 52.62536777768816, 51.251830509730745, 50.685722555433, 52.10583012444632, 49.03310741697039, 47.18962178911482, 46.82272911071777, 48.51493508475167, 45.50946399143764, 46.18461350032261, 46.07196235656738, 46.30625908715384, 51.66766629900251, 55.393415451049805, 53.43522548675537, 56.73887504850115, 52.32098456791469, 45.79632384436471, 52.71446105412075, 57.69452680860247, 53.019323689596995, 48.461294991629465, 42.469700063977925, 42.66778973170689, 54.90200757980347, 56.83178636005947, 57.065079075949534, 56.880409853799, 54.65540211541312, 53.50592688151768, 53.542710644858225, 58.32495771135603, 53.117671966552734, 33.166204588753835, 22.806355374200002, 16.954321963446482, 14.07581443446023, 18.867272206715175, 13.795102000236511, 8.153859564236232, 0.5978744125791958, 0.5018091616886002, 0.09756164452327148, 1.8596675481115068, 34.82574708121163, 55.062378951481406, 47.85593318939209, 38.526958669934956, 23.871451684406825, 47.56145463671003, 53.90781763621739, 60.34388187953404, 59.13322080884661, 39.33952965055193, 2.0179344841412137, 0.08945051833455052, 0.16389131279928343, 0.14050378490771565, 0.07125065528920718, 0.09851761215499469, 0.11678728966840676, 0.10406863928905555, 0.12379730279956545, 0.18342402896710805, 0.15183578112295695, 0.0926444980182818, 0.07862256507256202, 0.09553447365760803, 0.13256271316536836, 0.1513766571879387, 0.1025718046086175, 0.12454246995704514, 0.17988880723714828, 0.15577150136232376, 0.14280082950634615, 0.14334885509950773], [0.030962272148047174, 0.04716901321496282, 0.07243621202984027, 0.042240864264645746, 0.02885997388511896, 0.03740387988675918, 0.02296323824806937, 0.025164220947772264, 0.034559997131249735, 0.03379381235156741, 0.039845279417932034, 0.021806091768667102, 0.02812919336637216, 0.03889479434915951, 0.025098226631858518, 0.00992313020729593, 0.048268263693898916, 0.04067069012671709, 0.07231590098568372, 0.07389050934995924, 0.557166219821998, 33.67500032697405, 56.374073777879985, 47.43195758547102, 42.22582524163382, 24.46799795968192, 15.366785390036446, 28.25235342979431, 36.59021084649222, 37.84534733636038, 6.8249145320483615, 0.09521999981786523, 0.03457141348293849, 0.04815435802031841, 0.5064888277224132, 6.111490436962672, 3.04801013639995, 3.673957279750279, 7.58779764175415, 19.13392322404044, 34.54237869807652, 42.991464614868164, 54.725578921181814, 54.97431400844029, 52.50180796214512, 49.769404547555105, 43.2346967288426, 43.55682563781738, 48.42180837903704, 49.65658664703369, 48.17433091572353, 40.16915151051113, 40.11285720552717, 47.25884321757725, 52.66426379340035, 51.3065128326416, 51.07776771272932, 48.152030672345845, 52.177754402160645, 47.68487548828125, 40.25133827754429, 35.99254764829363, 39.05284350258963, 45.22059610911778, 51.985911164964946, 48.55189255305699, 52.350003719329834, 49.65523869650704, 48.66036088126046, 47.61364950452532, 49.60564940316336, 46.490382875714985, 45.929350580487935, 42.12384305681501, 37.573276724134175, 35.497547558375764, 37.357285022735596, 35.43335315159389, 45.75615630831037, 49.94086871828352, 50.91043077196394, 48.85739442280361, 53.09699412754604, 47.8480087688991, 53.79859890256609, 45.65961456298828, 53.7460948399135, 31.064815725599015, 24.047967195510864, 53.091887201581685, 45.451675823756624, 52.69771589551653, 47.38645035879952, 51.85635157993862, 47.408629008701865, 40.20016132082258, 34.654995100838796, 36.54275117601667, 42.07634517124721, 48.248277119227815, 48.22808218002319, 52.02755171912057, 49.93747104917254, 49.01758861541748, 48.296240534101216, 49.813584668295725, 48.14524575642177, 48.37322310038975, 45.349909033094136, 46.58761944089617, 46.29696934563773, 48.01479680197579, 49.61760030473982, 45.65870782307216, 47.48028230667114, 47.2100043296814, 51.123820372990195, 50.20578963415963, 45.98550592150007, 51.320708002362935, 50.204629284994944, 44.55588279451643, 36.322062492370605, 38.46241685322353, 44.70474100112915, 52.64848443440029, 49.75938177108765, 51.76667465482439, 51.324248109545024, 49.228817326681956, 48.56270742416382, 51.24126577377319, 51.054637159620015, 50.43595218658447, 30.344961506979807, 11.25058742931911, 5.642754103456225, 7.337462731770106, 3.3919209965637753, 3.761376908847264, 1.0542854560273034, 0.29051938227244783, 0.036863145152372975, 0.09585487110806362, 8.098610094615392, 36.20464488438198, 29.605249336787633, 22.9693375314985, 23.102704729352677, 19.352051496505737, 33.26486553464617, 36.904592514038086, 50.79938466208321, 39.30522639410836, 4.496799869196756, 0.08879259042441845, 0.09331602377018758, 0.03614921435447676, 0.05368755664676428, 0.05408472015655466, 0.030976870828973394, 0.039958201215735505, 0.06971638583179031, 0.0029439369848530206, 0.019900687404775193, 0.10245313561920609, 0.0033630207804630375, 0.055588387684630494, 0.05777902781431164, 0.05031278469998922, 0.0391248312911817, 0.035018391641122956, 0.048317481231476576, 0.0448046579424824, 0.02256660399559353, 0.016078067078654255, 0.0590848820284009, 0.022539445631472126, 0.048732602170535495, 0.04566653651584472, 0.03342536783644131, 0.04307661245443991, 0.028631114201354127, 0.037171261118991036, 0.05675986821630171, 0.025175579623984437, 0.025305166241845915, 0.050178733321705034, 0.015011196290808064, 0.034513412309544425, 0.02026016847230494, 0.04239043373880642, 0.05953307476426874, 0.09621616386409317, 0.09473247240696635, 0.05433366786954658, 1.281054899096489, 41.89256531851632, 62.17867183685303, 54.11344609941755, 47.9553028515407, 31.56980732509068, 21.101946626390728, 32.27775927952358, 37.10629177093506, 37.84381873267037, 8.740009597369603, 0.12461626742567335, 0.036307150165417364, 0.09809234711740698, 1.3408364398138863, 6.211450695991516, 5.834282500403268, 4.769913145474025, 4.714648910931178, 17.92625161579677, 36.042216845921104, 47.278218269348145, 56.458282470703125, 56.70856353214809, 56.08495576041085, 51.73153761454991, 45.705375398908345, 44.92076744352068, 51.77520704269409, 52.070255347660606, 51.823469230106895, 41.1107679094587, 41.49667085920061, 49.12295109885079, 54.580615179879324, 53.693889549800325, 51.28607818058559, 49.54189968109131, 53.432578223092214, 50.10444668361119, 41.71164812360491, 36.855850900922505, 40.743093558720176, 48.78659575326102, 52.357678004673545, 48.98187140056065, 52.5339538029262, 51.667607239314485, 49.87061895642962, 49.429217270442415, 51.7933418410165, 49.00694050107683, 46.96590369088309, 43.11252655301775, 40.91614539282662, 36.5345001901899, 39.145949363708496, 37.36064100265503, 46.33121354239327, 51.25602722167969, 51.47235243661063, 49.28414930616106, 54.13806356702532, 49.25172553743635, 54.16493572507586, 45.7283148765564, 53.24703352791922, 33.01963581357683, 25.10568799291338, 54.03733205795288, 46.197922774723594, 52.293827533721924, 48.664293561662944, 52.997600146702354, 49.2642878804888, 40.9843419619969, 36.16779511315482, 39.28977360044207, 43.60803733553205, 49.75416019984654, 49.12865209579468, 52.795237336839946, 51.34073271070208, 50.56924990245274, 49.93376071112496, 51.83864409582955, 49.650010177067344, 49.83422776630947, 46.726319381168906, 48.04355887004307, 45.31695372717721, 48.80706514630999, 51.90444701058524, 47.866966928754536, 47.53412389755249, 50.21151147569929, 52.57579585484096, 51.1074469430106, 45.806287561144146, 54.23127365112305, 53.69364288875035, 46.37943751471383, 37.94369213921683, 40.574085576193674, 48.22088732038225, 55.570441654750276, 53.09865474700928, 53.568863664354595, 52.55198785236904, 51.310289178575786, 49.23463644300188, 54.157945837293354, 54.16381359100342, 53.06269087110247, 28.04560456957136, 8.991823605128697, 4.041244268417358, 6.776332293237958, 8.312228986195155, 6.782794986452375, 3.24141954098429, 0.39160155824252535, 0.056028356576072316, 0.07085457404277154, 10.264405284609113, 37.59878008706229, 32.514223848070415, 29.70120743342808, 25.152478899274552, 28.439579589026316, 38.88775430406843, 42.492347717285156, 54.46687664304461, 47.015843868255615, 5.020916819572449, 0.03378948669082352, 0.010133340356073208, 0.051629285128521066, 0.06768405131463494, 0.043260760073150904, 0.02584615203418902, 0.03633242898753711, 0.05583445501646825, 0.013957017500485693, 0.05300422099285892, 0.07441289989011628, 0.014073585575845624, 0.07927677461079188, 0.015241485987124699, 0.0473262094227331, 0.0359057084923344, 0.025510691106319427, 0.03339944440605385, 0.05880703550896474, 0.02311981698897268, 0.032177436764218977, 0.122390835412911, 0.13268981634506158, 0.1865185693438564, 0.11414259086762156, 0.12747698463499546, 0.12788496060030802, 0.20323255604931287, 0.08955012048993792, 0.16049334513289587, 0.16902622154780797, 0.09775645192712545, 0.08344964283917632, 0.1427848432213068, 0.06797255761921406, 0.1664853657462767, 0.176579049123185, 0.17915494447307928, 0.2480225440646921, 0.20756779770765985, 0.2154096947716815, 2.478049405983516, 49.51735169546944, 71.65220710209438, 62.109502519880024, 57.711793082101, 35.090056555611746, 22.980838537216187, 37.47536618368966, 45.421433789389475, 49.53006342479161, 10.787464806011744, 0.18271881395152637, 0.3771287591329643, 0.35003520867654253, 2.42268876518522, 13.201628565788269, 12.402953113828387, 11.810343861579895, 13.050294194902692, 21.85109966141837, 42.42419631140572, 48.90683780397688, 57.529666900634766, 58.814632007053916, 58.08879886354719, 54.60610464641026, 47.22147233145577, 47.533974511282786, 52.8341646194458, 54.66134282520839, 53.8301020349775, 42.932939938136506, 43.94003963470459, 51.581949847085134, 57.134213651929585, 55.57794223512922, 52.004382950919016, 50.0675448008946, 56.35735641207014, 52.65005472728184, 43.684915678841726, 39.28045606613159, 42.838003226688926, 50.99219369888306, 54.960205691201345, 49.59815924508231, 55.65236439023699, 54.68155860900879, 53.00430168424334, 51.43045827320644, 54.51831415721348, 50.427308627537315, 49.04376942770821, 46.36038555417742, 42.94063854217529, 38.723603112357004, 42.06875079018729, 39.20941768373762, 47.78291457039969, 52.54767649514334, 54.47828558513096, 51.16889681134905, 55.86175530297415, 51.40782451629639, 55.70028959001814, 47.402875900268555, 54.23888887677874, 35.708685943058555, 27.84851370538984, 54.31877926417759, 47.38793727329799, 55.273020539964946, 50.93471472603934, 55.086947781699045, 51.92489903313773, 44.11353962762015, 38.48817035130092, 40.3315726007734, 44.3269431250436, 52.56654780251639, 51.8161631992885, 54.9211985043117, 53.933067389896934, 51.55893741335188, 52.1153005191258, 52.79509489876883, 50.80235154288155, 50.95476375307356, 47.6140525000436, 49.186926637377056, 45.64495038986206, 48.654295103890554, 54.405246121542795, 50.86675786972046, 49.847644737788606, 52.63343811035156, 56.37855536597115, 52.321741921561106, 46.85239444460188, 55.95843253816877, 55.333278792245046, 48.817636830466135, 40.288403442927766, 43.51564366476876, 49.15046943937029, 57.88041196550642, 53.39167070388794, 54.78267574310303, 55.025299889700754, 54.32496663502285, 53.024965626852854, 57.20116301945278, 57.268800258636475, 57.94417905807495, 36.43141671589443, 18.12817668914795, 16.855568953922816, 17.7620952129364, 11.063628775732857, 9.805665237562996, 3.3685125155108313, 0.6008775542889322, 0.15220206789672375, 0.39564478557024685, 12.623783367020742, 48.85619585854666, 41.86749621800014, 32.14824833188738, 33.214772496904644, 31.305775778634207, 45.10001359667097, 49.44059147153582, 63.05793857574463, 53.50573580605643, 7.012418184961591, 0.3085818759032658, 0.2880628683737346, 0.08442742537174906, 0.14933121337422303, 0.14179958323282854, 0.09936430172196456, 0.07765110648636307, 0.14309566654264927, 0.1119998994150332, 0.12144935450383595, 0.23702878398554666, 0.14455709526581423, 0.16330646989601, 0.18669603339263371, 0.1316503006964922, 0.12398189146603857, 0.0872494660850082, 0.17915520231638635, 0.13576261645981244, 0.1352271709058966, 0.09553245162325245], [0.07501404798988785, 0.043841521588287184, 0.08879618666001729, 0.024990156359438385, 0.01937116206889706, 0.06496157883001225, 0.055421634311122556, 0.07738729885646276, 0.11903664682592664, 0.05855608611766781, 0.06614469962992839, 0.02110316341609827, 0.07545918053282158, 0.0756068229675293, 0.04531623263444219, 0.022547832324302623, 0.061264234728046825, 0.10980502861951079, 0.06958252444331135, 0.059150442081902704, 5.584745330469949, 47.625579561506, 59.1731173651559, 38.48077399390084, 33.78452478136335, 18.57590992110116, 22.025219781058176, 34.68080765860421, 39.235952854156494, 29.423220430101665, 1.3672792209046227, 0.018647833560992564, 0.0982299472338387, 0.03247474366798997, 0.5397847582186971, 3.751349789755685, 4.635416431086404, 3.0047189508165633, 10.77538536276136, 24.319316932133265, 40.68402344839913, 53.39553737640381, 53.95932810647147, 55.09177677971976, 54.33074753625052, 50.8244502885001, 43.67579616819109, 41.32933044433594, 41.620473861694336, 42.84208876746041, 38.324918951307026, 38.70702818461827, 45.50075789860317, 49.020447799137656, 50.89515863146101, 53.40170390265328, 50.687963349478586, 50.20109960011074, 51.01869065420968, 49.45849697930472, 42.71738944734846, 35.20008475439889, 37.71585028512137, 45.00685214996338, 51.68860469545637, 47.563782283238, 49.276193618774414, 47.794643129621235, 45.89411973953247, 44.44582680293492, 46.15580974306379, 43.26986503601074, 41.39496660232544, 37.449227060590474, 36.22354398454939, 34.694825649261475, 37.56262860979353, 35.28917803083147, 43.843108790261404, 48.41255685261318, 50.54971851621355, 49.91455936431885, 52.2393536567688, 48.183724880218506, 51.517369815281455, 46.969603606632774, 53.811088289533345, 30.10091645377023, 22.035810572760447, 51.60098443712507, 40.00231484004429, 47.495349475315635, 45.566671984536306, 51.61881004061018, 44.956519399370464, 45.798759187970845, 33.65727547236851, 38.69394472667149, 35.945543084825786, 39.89154665810721, 43.8961443901062, 47.83210781642369, 46.47483280726841, 49.250912598201204, 49.439431122371126, 48.92000811440604, 49.5569703238351, 50.1014415877206, 47.12372159957886, 47.81522021974836, 44.76971708025251, 47.59634154183524, 48.596670218876426, 47.19027839388166, 42.171386105673655, 47.09364979607718, 49.00548137937273, 50.45026894978115, 46.30988604681832, 48.78297574179513, 49.485094683510916, 44.60520805631365, 37.453660011291504, 39.994352204459055, 46.34208399908883, 52.07133231844221, 51.07952560697283, 50.80407122203282, 53.477237769535606, 54.05547727857317, 49.18684673309326, 47.349287918635774, 51.55625193459647, 54.35270731789725, 42.81004367555891, 21.48648946625846, 5.084875421864646, 5.957273866449084, 6.973989869867053, 4.735604243619101, 0.25965054439646856, 0.06632550885634762, 0.0878631535119244, 0.037618646398186684, 1.9759369662829807, 20.54847570828029, 34.85883787700108, 16.971166133880615, 9.312278866767883, 23.22630970818656, 37.628775460379465, 46.02485704421997, 48.01265328271048, 45.212696007319856, 9.342162200382777, 0.13893976168973105, 0.01613404112868011, 0.08794054721615144, 0.04506603641701596, 0.04763970956472414, 0.04062556415530188, 0.04521790951756494, 0.02185858493404729, 0.012511090757990522, 0.04535692437951054, 0.02546174159007413, 0.04120064293965697, 0.027586178754323294, 0.08639538048633508, 0.020601335879681364, 0.04576783161610365, 0.050702039884137254, 0.09451040146606308, 0.04517293282385383, 0.0711079186626843, 0.009339881013147533, 0.053293979194547446, 0.05893576717270272, 0.11686720752290317, 0.0294616885616311, 0.05939918623438903, 0.023882831313780377, 0.032279278085167916, 0.08589204320950167, 0.10834679579628365, 0.06733075848647527, 0.027224100594009672, 0.03464375888662679, 0.06665596898112978, 0.04825385161010282, 0.04407971452123352, 0.043130498312945874, 0.02303992797221456, 0.06277758495083877, 0.039913974303219996, 0.10686034948698112, 7.413636701447623, 56.54856388909476, 64.09372738429478, 46.27335589272635, 39.121672357831685, 24.933192014694214, 23.863341399601527, 37.38768686567034, 36.4283629826137, 31.300345761435374, 1.6185897013970783, 0.026934834330209663, 0.03151869461206453, 0.34465551163469044, 2.3351586163043976, 6.808962770870753, 8.38059491770608, 3.7084016714777266, 9.858046838215419, 27.138993195125035, 42.75417668478829, 54.90235498973301, 55.43923882075718, 57.26623289925711, 56.264851570129395, 53.53434501375471, 45.7397585596357, 43.747025626046316, 42.50667142868042, 45.91134432383946, 40.74220766339983, 41.46556030000959, 45.92303466796875, 51.32663481576102, 52.19073016302926, 54.70094060897827, 49.72568995612008, 50.94671426500593, 52.5888306753976, 51.03542539051601, 44.37029988425118, 36.565836565835134, 39.26004225867135, 47.60946668897356, 53.152058601379395, 50.23035151617867, 51.45939752033779, 48.85097081320626, 47.4318151473999, 46.539388520377024, 48.93453679765974, 46.35567120143345, 43.785483905247276, 39.38775014877319, 38.3672855922154, 37.11810023444039, 38.59279979978289, 38.41494328635079, 45.48024334226336, 51.859589440482004, 53.01903881345476, 51.58271762302944, 55.06208365304129, 50.07191869190761, 52.936178071158274, 49.08707060132708, 53.42189884185791, 29.86312825339181, 23.510631731578282, 51.07774339403425, 40.718733174460276, 50.27852685110909, 47.31641251700265, 54.41165236064366, 47.097957679203574, 47.121901171548025, 36.15007025854928, 40.44587046759469, 37.790769236428396, 42.707206862313406, 46.62215893609183, 49.928799697331016, 48.578233173915315, 51.32525907244001, 49.80285317557198, 50.955840723855154, 51.884217330387656, 52.0199990272522, 48.559497356414795, 48.63910634177071, 45.27632761001587, 50.44482503618513, 49.89229733603341, 48.98493555613926, 45.01842437471662, 48.48216043199812, 50.859799248831614, 52.23705727713448, 47.51249415533883, 49.64386796951294, 51.2794565473284, 47.56668663024902, 40.06107228142874, 41.235310895102366, 46.978413922446116, 53.30368913922991, 51.94983959197998, 51.52861200060163, 54.9573986189706, 55.3589836529323, 51.207730293273926, 50.34780733925955, 53.46350812911987, 56.50276831218174, 42.674004895346506, 19.359272411891393, 4.438808900969369, 1.718554737312453, 6.691671098981585, 8.89156196798597, 4.836159007889884, 0.7954691840069634, 0.07356958942753927, 0.06509430706501007, 2.003783174923488, 25.933402572359356, 32.6864766393389, 17.131554876055034, 13.67890293257577, 26.611423424312047, 41.03962877818516, 50.61849873406546, 54.370025702885215, 52.34484120777675, 12.83676997252873, 0.21412206600819314, 0.037225618559334955, 0.08896519616246223, 0.04019328306562134, 0.01076535671018064, 0.036347919942012856, 0.09817990527621337, 0.020847145368212035, 0.03526466931881649, 0.02085025984394763, 0.05451248898836119, 0.026388722205800668, 0.0285022570086377, 0.03880995372310281, 0.02892809540831617, 0.0317812198107796, 0.07814392647040741, 0.10899597060467515, 0.06945299889360156, 0.04945657528670771, 0.05487112527979272, 0.10404415096023253, 0.1583955455571413, 0.12644376579139913, 0.17493314029914991, 0.12777806419347013, 0.07371550159794943, 0.1751657828156437, 0.16924586333334446, 0.2520578461033957, 0.16547080661569322, 0.12298810907772609, 0.11850113341850893, 0.13048220266188892, 0.12066396379045077, 0.10657061503401824, 0.14888549729117326, 0.16736652489219392, 0.2582346318023545, 0.13987871844853672, 0.14823071099817753, 9.734345453126089, 64.85520131247384, 70.45854132516044, 52.69681262969971, 44.91909987585885, 29.034830025264196, 30.978974206107004, 44.023129667554585, 49.92408881868635, 38.719812870025635, 2.253730071442468, 0.15887778039489472, 0.2621141422007765, 0.2859380223921367, 3.4036567211151123, 13.772872975894384, 12.504151889256068, 9.299493312835693, 15.289264338357107, 31.855819497789653, 45.45822450092861, 56.44243710381644, 57.462005342756, 60.15341091156006, 57.48397902079991, 56.926469462258474, 47.17522512163435, 46.017689977373394, 44.55233573913574, 47.07132870810372, 42.35171965190342, 43.56460762023926, 48.23433208465576, 54.31241124016898, 54.40523222514561, 57.427028111049104, 50.12516968590872, 51.850671427590505, 54.57881907054356, 54.64658832550049, 46.85581990650722, 39.153734820229666, 41.70039899008614, 50.0960602079119, 55.42065238952637, 50.03850480488369, 54.10439954485212, 51.2375693321228, 49.979316575186594, 48.04727963038853, 52.25412900107247, 47.70883635112217, 45.58406332560948, 41.42941229684012, 39.99682228905814, 39.74457836151123, 41.40462112426758, 40.217083658490864, 47.096634047372, 54.88249008996146, 54.47075721195766, 53.95139673777989, 58.06220463344029, 51.43391152790615, 54.91058165686471, 52.26686157499041, 53.64091648374285, 32.535266467503135, 26.18350124359131, 50.42083638054984, 41.86427225385393, 51.14220878056118, 48.9114340373448, 55.55620132173811, 49.49359580448696, 48.95215742928641, 37.577025277274, 42.691041878291536, 39.79103749138968, 43.42674841199602, 48.93832009179251, 51.96625471115112, 51.09267507280622, 52.78794867651803, 53.87061350686209, 52.62757383074079, 54.180385044642854, 54.145029136112754, 50.35629456383841, 49.39084584372384, 46.244614669254844, 50.713411126817974, 53.34626422609602, 53.04452133178711, 48.19776371547154, 50.50447184698922, 53.64407444000244, 54.62388856070382, 48.41402987071446, 50.506073406764436, 54.06889077595302, 49.298094340733115, 42.04344892501831, 44.13990109307425, 49.814765862056184, 56.89838484355381, 55.28693430764334, 52.98791435786656, 56.99715348652431, 58.11793960843767, 53.06158610752651, 52.3834627696446, 56.566278321402415, 59.076363699776785, 47.71378346851894, 24.017158882958547, 9.345250674656459, 13.018474919455391, 16.710928303854807, 15.224984816142491, 5.7454211200986585, 0.5762606295091766, 0.19846914522349834, 0.13163770708654607, 2.7164340657847266, 29.293014662606375, 48.6917667388916, 27.48831214223589, 16.0045223236084, 33.20191832951137, 48.40996170043945, 58.25595167704991, 58.33483110155378, 60.68599033355713, 17.57984917504447, 0.3828430553632123, 0.05624833084376795, 0.22133820450731687, 0.11620407524917807, 0.14800633303821087, 0.1412199650491987, 0.22834410571626254, 0.16768608774457658, 0.1542424498392003, 0.13669387863150664, 0.13250511911298546, 0.10459413073424782, 0.15939907170832157, 0.11814636816935879, 0.20930798218718596, 0.18537210300564766, 0.13804956445736544, 0.13991978338786534, 0.1542234644293785, 0.11239699167864663, 0.18801475263067655], [0.009281621996446379, 0.019069327640214136, 0.05239333252289465, 0.02275622739190502, 0.03966058557853103, 0.03957553121394344, 0.009722326250214661, 0.07477801958365099, 0.015594575254778777, 0.02661885753540056, 0.025031842158309052, 0.0397990067223353, 0.07250849636537687, 0.035630111316485066, 0.0019273187125301255, 0.05239576167826142, 0.017346260902870978, 0.03564509336969682, 0.04902986157685518, 0.19169138105852263, 7.5432614258357455, 54.74821615219116, 50.31168018068586, 43.880583899361746, 26.02693748474121, 17.65281741959708, 27.20557951927185, 28.40651658603123, 41.51425327573504, 13.043822816440038, 0.22023709144975456, 0.06718774366059474, 0.011228646002044635, 0.08480020572564431, 1.3795400772775923, 5.882374891213008, 4.280847251415253, 6.402973881789616, 18.546192475727626, 40.37508569444929, 58.014731066567556, 56.1005197252546, 55.284029960632324, 53.94182906832014, 51.57662752696446, 51.43505103247506, 46.73281247275216, 40.841674600328716, 38.22268663133894, 36.47658348083496, 38.75685371671404, 44.732829093933105, 49.50087056841169, 52.56716619219099, 53.15080445153372, 49.236901555742534, 52.000832421439036, 48.89228132792881, 50.73266805921282, 49.07564428874424, 42.51779202052525, 34.72766630990164, 35.85174240384783, 41.50934089933123, 50.07796015058245, 50.99472631726946, 49.94293580736433, 44.81080872671944, 41.381699017116, 40.00683116912842, 40.48055934906006, 37.07576138632638, 37.41026503699166, 35.52633741923741, 35.785050119672505, 35.94006095613752, 36.52502979551043, 37.49920197895595, 38.64179849624634, 43.722439425332205, 46.0983099256243, 45.33778095245361, 46.80971513475691, 46.31639650889805, 51.33532701219831, 46.63247006280081, 55.40446308680943, 33.06805433545794, 22.321214778082712, 53.47854750497, 46.43209791183472, 51.53697068350655, 47.519404138837544, 50.27096373694283, 47.049664224897114, 45.169304507119314, 35.552035331726074, 37.18082857131958, 36.533037594386506, 37.11832257679531, 36.792042119162424, 42.02782590048653, 42.74309083393642, 44.507207189287456, 44.05867665154593, 48.24720709664481, 47.7605413709368, 48.05065298080444, 46.502438000270296, 49.951172896793906, 44.90060724530901, 49.859658173152376, 48.098050117492676, 46.354302406311035, 39.69636481148856, 40.40243033000401, 47.06242111751011, 50.724868706294465, 47.02474103655134, 49.189980370657786, 49.474005358559744, 43.77080930982317, 38.51342705317906, 37.193206787109375, 42.03675086157662, 50.887136936187744, 50.13673496246338, 49.54685722078596, 50.310644899095806, 53.57527337755476, 48.17064837047032, 49.73336771556309, 49.66104391642979, 53.5678596496582, 53.08988612038748, 42.07479919706072, 15.766553470066615, 4.51267910855157, 5.004344931670597, 6.417635449341365, 6.1254888858113965, 1.1579109983784812, 0.10991641014282193, 0.07127218520534889, 0.021323726312922578, 9.577102507863726, 37.65152733666556, 40.13708209991455, 22.63345640046256, 24.933676651545934, 31.695823328835623, 36.00773293631417, 43.636507579258506, 46.41838216781616, 20.761288608823502, 1.1977133197443826, 0.03609134549541133, 0.1091746695871864, 0.030410657104636942, 0.03697075741365552, 0.04396680290145533, 0.06615264527499676, 0.023630204244649837, 0.03253526559897831, 0.019811750123543397, 0.060748181704963954, 0.0376069891665663, 0.04866348659353597, 0.004805851070809045, 0.019739847463954772, 0.008812504088772195, 0.023977715954450623, 0.0030058075041909304, 0.05955205338874033, 0.023981449593390738, 0.032132365075605254, 0.058865097750510485, 0.018375747803864733, 0.024959135434723327, 0.010685091106487172, 0.08130486149873052, 0.042211772075721195, 0.0407225437728422, 0.05323052938495364, 0.09757008549890347, 0.0024855876399669796, 0.05654899310320616, 0.019514142968026654, 0.06750212929078511, 0.012178408431022294, 0.04911875644964831, 0.05174134179417576, 0.01087354657439781, 0.10052652364330632, 0.08758011619959559, 0.06424443516880274, 13.839920486722674, 63.75087547302246, 55.19303982598441, 48.996146474565776, 31.044884817940847, 20.407434225082397, 29.024904523577007, 27.726671831948416, 39.03907912118094, 15.486202342169625, 0.13355735050780432, 0.028002504093040313, 0.046304172836244106, 0.7769073428852218, 3.256950067622321, 6.523492991924286, 7.697168367249625, 6.631865348134722, 21.59103032520839, 44.929619448525564, 57.99019002914429, 59.37886047363281, 56.65286677224295, 57.17841114316668, 54.03962843758719, 54.621578284672324, 48.76217630931309, 42.55121980394636, 39.561528069632395, 38.788346426827566, 40.29260015487671, 46.478796754564556, 51.831866128104075, 53.510088852473665, 53.694910934993196, 50.46885190691267, 51.3454019001552, 48.86118813923427, 52.18551206588745, 50.83411175864083, 44.03941624505179, 36.2974728175572, 37.70805788040161, 43.38370432172503, 50.12214374542236, 53.25863354546683, 51.431858335222515, 46.66312551498413, 42.67021117891584, 42.666156905038015, 41.4991409437997, 39.85452318191528, 38.09524972098214, 36.79346997397286, 36.80947862352644, 38.43026406424386, 38.49919366836548, 37.88270432608468, 41.31118174961635, 45.63175923483712, 47.754381792885916, 47.8772155216762, 48.69779430116926, 48.560372829437256, 52.788358620234895, 48.40203033174787, 56.54182413646153, 34.68624462400164, 23.86566036088126, 54.49626404898507, 46.71260016305106, 52.88926036017281, 48.27666398457119, 51.28627273014614, 47.77108873639788, 46.455857276916504, 38.11929396220616, 38.81917210987636, 38.64025599615914, 39.40188973290579, 38.390902519226074, 43.56960684912545, 43.83861330577305, 46.06408657346453, 45.38259335926601, 51.107134274074006, 49.74319246837071, 50.01668398720877, 48.70926925114223, 50.28208432878767, 45.82237958908081, 51.73056834084647, 50.329613481249126, 48.58329841068813, 41.60856464930943, 41.905468123299734, 50.27024459838867, 52.46710518428257, 48.622465406145366, 50.69997331074306, 53.13947193963187, 46.206962381090435, 40.79199845450265, 38.96062353679112, 44.80712270736694, 52.257425921303884, 53.192583969661165, 51.7984869820731, 51.42489276613508, 54.83305018288748, 51.300665923527305, 51.33101912907192, 52.18034608023507, 54.7547995703561, 56.16965082713536, 39.643214566367014, 16.5792738369533, 3.3653706269604817, 6.958261753831591, 6.169854436601911, 5.98849299124309, 4.231700471469334, 0.456117644906044, 0.03395523922517896, 0.036632178617375236, 11.86739899430956, 39.98925222669329, 34.67319243294852, 22.41997299875532, 32.28340816497803, 38.52973447527204, 41.31842177254813, 47.80211591720581, 53.09344359806606, 26.10771724155971, 1.2371236107179095, 0.05222325772047043, 0.08455914258956909, 0.040816822821008306, 0.0463571392797998, 0.038002412234033854, 0.09051373521132128, 0.025849682112623538, 0.034511017080928595, 0.025850206280925443, 0.053529790469578335, 0.03514460254726665, 0.013268130581959017, 0.06877988536975213, 0.04469804312767727, 0.0575917928612658, 0.042086073463516574, 0.03810133585440261, 0.03921093399237309, 0.04671111064297812, 0.083710953460208, 0.23885713730539593, 0.12377128776695047, 0.10059523888464485, 0.1435390348945345, 0.17218822187611035, 0.14139191939362458, 0.14940421017152922, 0.14410600518541677, 0.1525012068450451, 0.08073828475815908, 0.12435231730341911, 0.11939488617437226, 0.16036633694810526, 0.11662661257599082, 0.17750455731792109, 0.12333401265953269, 0.09971095847764186, 0.09821883283023324, 0.15532138837235315, 0.28784592715757235, 20.998336826051982, 74.52043042864118, 62.7984094619751, 58.521292958940776, 38.52537448065621, 28.356625046048844, 35.59253290721348, 38.559438024248394, 52.50736999511719, 18.723378487995692, 0.47607162275484627, 0.21012168138154916, 0.22676303769860948, 0.9756098091602325, 6.332975123609815, 12.59493270942143, 12.296902758734566, 12.909764272826058, 23.908714873450144, 47.40793418884277, 60.750094413757324, 61.56678567613874, 58.60695729936872, 58.32074710300991, 53.86039270673479, 56.10107905524117, 50.25018514905657, 44.957103048052105, 41.62808908735003, 39.85342536653791, 42.29723187855312, 49.19451059613909, 55.32760558809553, 55.717430795942036, 55.32153633662632, 51.93516499655587, 52.86976024082729, 49.91233941486904, 54.415404387882774, 53.598799977983745, 46.009459836142405, 38.013507638658794, 39.360019888196675, 45.04782567705427, 52.930751528058735, 56.15882553373064, 52.383619104112896, 49.24287353243147, 43.92502457754952, 45.02653292247227, 43.08910764966692, 41.07135077885219, 40.57240758623396, 39.24115705490112, 39.10315888268607, 40.21404034750802, 41.2769410269601, 41.097969327654155, 43.39312955311367, 47.20637042181832, 48.244580677577424, 49.26530579158238, 50.08500909805298, 51.540361404418945, 54.504323959350586, 51.62987504686628, 57.441744395664756, 36.59400108882359, 26.24937537738255, 55.37866789954049, 49.64375679833548, 55.707783222198486, 50.78174318586077, 53.908620153154644, 50.07376691273281, 48.45151192801339, 40.04973629542759, 41.26053980418614, 40.91681589399065, 41.83336666652134, 41.27142415727888, 46.740014280591694, 46.34400517599923, 47.605961322784424, 47.593124525887625, 53.785192353384836, 50.40669332231794, 53.230469022478374, 51.00746931348528, 52.82124097006661, 47.4863862991333, 53.10234076636178, 52.26632308959961, 51.66082927158901, 44.48487567901611, 44.133567810058594, 51.27092068535941, 55.63429907390049, 49.34154837472098, 53.762450899396626, 54.59819759641375, 48.771174226488384, 42.21230057307652, 41.23530394690377, 47.27343790871756, 56.138540267944336, 56.08290951592581, 53.38765811920166, 52.2291328566415, 57.71458625793457, 53.278217043195454, 54.19851984296526, 53.56474685668945, 58.65011256081717, 57.99357727595738, 47.37251574652535, 20.088282619203838, 9.147141899381365, 14.10635437284197, 14.857072489602224, 12.543921640941075, 3.7988125000681197, 0.35111657636506216, 0.17483646262969288, 0.18776459034000123, 14.41549449307578, 54.081206457955496, 52.69648606436593, 32.023458685193745, 34.9020938873291, 43.52978672300066, 46.266268730163574, 56.54750081471035, 61.36937345777239, 32.85310138974871, 1.7723401997770583, 0.14312332363000937, 0.2802523603396756, 0.09993177412876061, 0.20453019998967648, 0.1597579081675836, 0.21086768992245197, 0.13989040282155785, 0.11754353051739079, 0.1428345934088741, 0.14165605950568402, 0.16449378404234136, 0.090662178317351, 0.19691660281802925, 0.09903107317430632, 0.13404000603726932, 0.09809700186763491, 0.12473157766674246, 0.08929268430386271, 0.13119790782885893, 0.17834621215505259], [0.06656170011098896, 0.037865924915032725, 0.03186936490237713, 0.08930194630686726, 0.04022071962910039, 0.0457395434911762, 0.02463826979510486, 0.025152238019342934, 0.019436292948999574, 0.014362632163933345, 0.026930159223931174, 0.004073833073821983, 0.03833121334069541, 0.0391821641075824, 0.03843372641131282, 0.0727188897186092, 0.04352677294186183, 0.03642092013199415, 0.049633337051740715, 0.26788090275866644, 24.43565583229065, 58.41389465332031, 48.454329422542024, 40.532066345214844, 24.588571786880493, 20.944344111851283, 24.711468049458094, 40.1349698475429, 34.02555431638445, 5.774538849081312, 0.08510641500885997, 0.040657448515828164, 0.14372998821948255, 0.8260353952646255, 1.7103908210992813, 3.794025191238948, 9.116449100630623, 6.199590555259159, 27.251244817461284, 53.626703943525044, 54.23840250287737, 52.31577341897147, 51.144470419202534, 51.45005566733224, 53.7091269493103, 53.52522202900478, 46.77829885482788, 43.215947014944895, 38.00148378099714, 39.46374259676252, 43.30247988019671, 47.84626824515206, 50.87715932301113, 51.704439640045166, 49.82218653815133, 51.06484406335013, 51.25883429391043, 49.1008106640407, 52.470502853393555, 48.45704616819109, 43.00379071916853, 36.27850423540388, 36.78042820521763, 37.870003019060405, 44.10101202556065, 47.071721281324116, 45.66519744055611, 39.885925565447124, 35.72608770642962, 35.11010558264596, 35.67208283288138, 34.527155194963726, 34.563932010105674, 35.15940305164882, 35.96917738233294, 35.379400389535085, 38.113179547446116, 36.15173087801252, 37.37018435341971, 38.58880805969238, 41.626904419490266, 39.82532337733677, 43.043499674115864, 42.0906480380467, 49.76416213171822, 45.53802803584507, 52.78486715044294, 37.40963275091988, 23.159620898110525, 55.06889983585903, 44.92410952704293, 49.21565396445138, 45.26405709130423, 48.00676121030535, 42.970540114811485, 42.54638385772705, 36.4960731778826, 38.219552993774414, 36.05452210562569, 36.65895979745047, 35.33670718329293, 36.29818153381348, 37.41354806082589, 38.05543654305594, 39.45008243833269, 42.53804949351719, 42.61827686854771, 45.63994768687657, 46.564728600638254, 48.368064062935964, 48.591000488826204, 46.54302242824009, 49.404255867004395, 46.9977160181318, 39.100654057094026, 36.93219075884138, 45.02994448798043, 50.47819375991821, 49.6621903691973, 49.74948753629412, 48.97279705320086, 45.627169949667795, 39.09923315048218, 38.675538948604036, 39.05273927961077, 46.64166600363595, 50.42877469744001, 52.56498793193272, 48.235638345990864, 48.19408464431763, 50.33815976551601, 54.436589445386616, 49.65903588703701, 50.808632714407786, 51.81472839627947, 47.62905018670218, 26.56727978161403, 7.296181746891566, 5.011832918439593, 5.17316574709756, 5.547613288675036, 3.2581822872161865, 0.14042166859975883, 0.0576963143955384, 0.018255416403657625, 2.4903839784009114, 20.329609189714702, 35.3261250768389, 21.400055612836564, 19.320704698562622, 33.77355704988752, 29.58255304609026, 40.004503522600444, 43.57781267166138, 36.28807885306222, 4.3407971773828775, 0.034081565482275825, 0.01265233291113483, 0.03518467004011784, 0.05830310112131493, 0.032347396215690036, 0.0470103310155017, 0.040545361316097636, 0.04811281132112656, 0.051949428128344674, 0.03414978878572583, 0.030905265028455427, 0.02590692841580936, 0.04769908816420606, 0.06899806830499854, 0.013264711613633802, 0.039498459813850265, 0.05369034203301583, 0.06612378039530345, 0.032579685893974135, 0.04833462781139782, 0.05610434910548585, 0.028520424783762013, 0.028255275350862315, 0.10691047965415887, 0.030047871571566378, 0.04192282472337995, 0.04219002163569842, 0.03393921222803848, 0.03193981719336339, 0.0616151662543416, 0.017971934650891593, 0.04606659058481455, 0.03585259955642479, 0.0778917692867773, 0.03615467995405197, 0.027862530800380876, 0.04362317580463631, 0.032469698760126314, 0.16745292954146862, 0.6948076997484479, 34.133098534175325, 64.65049348558698, 55.226387705121724, 44.75910023280552, 33.89051955086844, 25.625359398978098, 25.511900527136667, 36.1257654598781, 37.00297900608608, 6.6780595779418945, 0.13631620604012692, 0.009836199693381786, 0.25185732543468475, 1.864582747220993, 4.103008108479636, 8.81659003666469, 6.220564995493207, 8.456612552915301, 28.05134551865714, 57.00711720330374, 55.67268787111555, 56.89967720849173, 52.69991500037057, 54.18545375551496, 54.834735121045796, 54.92968920298985, 49.29459244864327, 44.10654279163906, 39.69243213108608, 40.872878960200715, 44.06063256944929, 50.187488079071045, 52.504159927368164, 53.45779323577881, 51.93899692807879, 51.35602569580078, 52.00544602530343, 48.96278469903128, 52.37963431222098, 49.87925556727818, 43.767991815294536, 37.679368768419536, 38.30463368552071, 38.90781375340053, 46.979226861681255, 48.35264948436192, 48.97684785297939, 42.565123149326865, 37.909434046064106, 36.77184023175921, 37.68994740077427, 36.881798948560444, 37.85172230856759, 36.678567613874165, 37.286951882498606, 37.258050850459504, 40.14535740443638, 38.20053230013166, 38.24534123284476, 39.82518441336495, 43.33794348580496, 42.079725469861714, 45.39401967184884, 43.00595508302961, 52.20418534960066, 47.429477078574045, 55.244362694876536, 38.12606150763375, 24.744583163942607, 55.83410494668143, 46.71327761241368, 51.74288749694824, 47.11074931280953, 50.10733713422503, 43.16627434321812, 45.586126940590994, 37.496474811008994, 39.74723604747227, 37.431606428963796, 39.13135119846889, 36.73690468924386, 38.939174447740825, 38.30694048745291, 41.11239378792899, 41.42161641802107, 44.9481155531747, 43.526257038116455, 47.66956513268607, 47.81169400896345, 51.1263564654759, 49.323760986328125, 47.92359127317156, 51.263305459703716, 50.2233373097011, 41.19609873635428, 37.90142624718802, 46.50186824798584, 52.89673662185669, 51.067960330418174, 51.03110361099243, 50.819847106933594, 47.44107362202236, 41.35365956170218, 39.69191101619175, 41.04393318721226, 49.58626045499529, 52.26942546027047, 53.83327041353498, 51.37707873753139, 49.31794881820679, 53.13646336964199, 53.44283723831177, 51.74251924242292, 51.69575439180647, 53.804904392787385, 49.57221119744437, 28.529103653771536, 8.865973489625112, 2.52031877211162, 2.474651736872537, 7.070347053664071, 7.344463041850498, 0.9895778596401215, 0.20144317778093473, 0.046155556703784635, 3.5977255531719754, 24.678969587598527, 39.30546958105904, 23.768607922962733, 21.414335897990636, 40.11007792609078, 32.61070653370449, 45.25702551433018, 49.38499893460955, 43.627811908721924, 5.892340779304504, 0.07694582361727953, 0.04090627069984164, 0.05654773781342166, 0.044656275904604366, 0.07229787231023822, 0.03817575418257287, 0.036737219230937104, 0.02363565457718713, 0.06168736916567598, 0.019617996145305888, 0.030117329808750322, 0.057451275044253895, 0.010191102345873202, 0.040682561096868346, 0.03230613450120602, 0.01535532550354089, 0.03960877264450703, 0.027917441246765, 0.042770752616758854, 0.04805560403370431, 0.1772222596087626, 0.1294873889003481, 0.12645682080515794, 0.2910045348107815, 0.1060408488182085, 0.11761010837342058, 0.11334427406213113, 0.10914965200104884, 0.08962208591401577, 0.0905818533418434, 0.08842514335576977, 0.13724113069474697, 0.10028626796390329, 0.1107236903959087, 0.11518726338233266, 0.08388813252427749, 0.10703988985291549, 0.09203685633838177, 0.2797949191715036, 1.1822579205036163, 42.38396624156407, 69.99100399017334, 61.80900682721819, 53.54874168123518, 36.19215202331543, 31.678112370627268, 33.53947571345738, 50.86438505990164, 47.684632301330566, 8.259194254875183, 0.4200196633381503, 0.23939491701977594, 0.4994784210409437, 2.025223578725542, 9.81808601106916, 11.602726476533071, 17.213001659938268, 10.0298992395401, 30.74207190104893, 58.050316265651155, 58.07438135147095, 58.54331874847412, 54.60045576095581, 55.639687401907786, 56.241783550807405, 57.993566853659495, 51.50074625015259, 46.06419079644339, 41.71913480758667, 44.261810711451936, 47.78245946339199, 51.04714700153896, 54.01781456811087, 54.87135212762015, 52.38679443086897, 51.56173406328474, 52.37396458217076, 50.76647104535784, 56.20864759172712, 52.814247608184814, 46.370081765311106, 39.220663343157085, 40.609226090567454, 42.055844511304585, 47.15697915213448, 49.815349510737825, 50.55572175979614, 45.12149395261492, 39.34689474105835, 37.951467173440115, 39.12569189071655, 38.331974846976145, 38.87274619511196, 39.58384220940726, 39.478149686540874, 38.72207798276629, 42.87280675343105, 39.70409120832171, 39.68814161845616, 42.73526021412441, 45.252443177359446, 43.911531175885884, 46.84719371795654, 45.93520443780081, 54.08214099066598, 50.536774022238596, 54.99812201091221, 41.01064436776297, 27.46734595298767, 56.94487176622663, 48.04154736655099, 53.46202816282, 49.71585478101458, 52.157465662275044, 44.72229562486921, 48.80116612570626, 38.849452359335764, 41.97648218699864, 39.08524642671858, 41.22830016272408, 38.14640235900879, 40.364764145442415, 41.11498546600342, 42.36120046888079, 43.85158559254238, 47.21263074874878, 45.640006746564595, 50.91388055256435, 51.82752350398472, 52.50914178575788, 51.15332589830671, 50.67791625431606, 54.052864755902974, 52.40343884059361, 43.30089569091797, 41.776130880628315, 48.9420200075422, 56.317838532584055, 52.890969617026194, 54.22304698399135, 53.01333434241158, 49.8811628477914, 43.262312344142366, 42.05670608792986, 44.16155167988369, 51.18605538776943, 55.94055134909493, 56.860569272722515, 53.24687371935163, 52.475092138562886, 51.373392718178884, 58.22016150610787, 53.86125428336007, 53.63069568361555, 55.72058180400303, 52.28635474613735, 30.120625019073486, 10.407447849001203, 8.948050822530474, 11.689956767218453, 13.340229494231087, 8.311380437442235, 0.8579424460019384, 0.2896415208067213, 0.2042205708899668, 3.7755412459373474, 32.60988317217146, 48.4840920312064, 30.378201689038956, 26.340867519378662, 44.15295328412737, 39.69449922016689, 51.952879428863525, 55.847789423806326, 51.69169316973005, 7.261497208050319, 0.17638297964419636, 0.1511001270264387, 0.14070946244256838, 0.11387018619903497, 0.14271316278193677, 0.11798411687569958, 0.20845093817583152, 0.11760651213782174, 0.22837086713739804, 0.09720461975250926, 0.12400741795344011, 0.11188241786190442, 0.17473868573350565, 0.1811417764318841, 0.11006475825394903, 0.10847199229257447, 0.11623416149190494, 0.1356755739876202, 0.08952863128589732, 0.10919729194470815], [0.05578527819099171, 0.01115914705275957, 0.029648224623607736, 0.010572045476042798, 0.014316227154007979, 0.030660690473658696, 0.0859385160729289, 0.09297560953668185, 0.03480090759694576, 0.021909826202318072, 0.0019518218843066798, 0.007001062406093946, 0.05792285009686436, 0.03409177404163139, 0.023746874948431338, 0.0769012506519045, 0.038190424109676054, 0.057802579764808924, 0.028371426975354552, 2.430756275142942, 34.90895870753697, 54.98350994927542, 43.85543142046247, 29.077351263591222, 15.734770672661917, 18.477811779294694, 28.856525353022985, 38.86631563731602, 20.632437740053447, 0.8368370213678905, 0.10256964686725821, 0.04880709174488272, 0.15069114682929857, 2.0601432706628526, 2.55886281813894, 4.711612548146929, 6.139162940638406, 15.837524107524327, 44.78077861240932, 56.264104638780864, 52.792159284864155, 51.655114378247944, 47.56632532392229, 49.13164676938738, 49.268331732068745, 50.86343663079398, 48.10857663835798, 41.722098214285715, 39.25606788907732, 43.84860828944615, 47.62156350272042, 50.32879706791469, 51.8915615762983, 51.34754541942051, 48.588832650865825, 47.868988854544504, 47.83508511951992, 49.72238261359078, 48.93677759170532, 47.780844007219585, 39.40813616343907, 35.714939321790425, 34.99435206821987, 35.54900939123971, 37.8380343573434, 38.89149590900966, 38.09373153959002, 36.549219948904856, 35.81733839852469, 35.04701941353934, 34.65431765147618, 35.44453280312674, 35.55074296678816, 33.51784249714443, 35.644894531794954, 36.4504200390407, 37.564855507441926, 34.906770024980815, 35.805998938424246, 35.026900904519216, 37.20731510434832, 36.60953031267439, 38.03960854666573, 37.8254303250994, 44.9099178314209, 45.224271706172395, 51.35251338141305, 38.57425505774361, 25.035278422491892, 54.31412397112165, 45.54083858217512, 47.67747218268258, 39.92968532017299, 42.69374820164272, 38.86777823311942, 38.130018506731304, 35.787475040980745, 35.7580737386431, 37.515155042920796, 36.70930297034127, 33.60328449521746, 38.24163089479719, 35.34606293269566, 35.426477909088135, 35.352045331682476, 38.75480399812971, 39.69093826838902, 41.67200517654419, 45.25544132505144, 49.39700889587402, 49.00132288251604, 50.386526175907676, 48.73054116112845, 45.50003528594971, 38.941335337502615, 36.30257279532296, 40.090918268476216, 49.91145004544939, 48.4465126991272, 51.40345409938267, 47.47975771767752, 43.03085742677961, 40.92951372691563, 38.62531736918858, 37.53285905293056, 40.482834884098594, 46.9291581426348, 48.30949074881417, 49.6733318056379, 46.976680346897666, 49.48099872044155, 48.90777581078665, 53.35205554962158, 52.565217222486226, 56.4702924319676, 51.72305038997105, 44.725411891937256, 19.322351421628678, 10.406319635254995, 3.2541201966149464, 4.190639657633645, 7.774505291666303, 1.7495928832462855, 0.039622506193284474, 0.03564493391396744, 0.46419970265456606, 13.101815087454659, 37.86726542881557, 26.083872761045182, 21.268258707863943, 41.876768589019775, 34.74978242601667, 34.79020357131958, 44.174402373177664, 40.33559560775757, 12.694170355796814, 0.09962891002318688, 0.08765721134841442, 0.0893321411151971, 0.0526445770769247, 0.0618119617658002, 0.02176490130036005, 0.06181784466441188, 0.022200354541252767, 0.07199526604797159, 0.022786464608673538, 0.019834686303511262, 0.027895509298624735, 0.05823272346918072, 0.048745416304362674, 0.007184823259844312, 0.004685380995007498, 0.07763809897005558, 0.016131408412807753, 0.014464035829795259, 0.07966293567525488, 0.03209969022178224, 0.050842072548610825, 0.014766296039202383, 0.020953943387472203, 0.04133236694282719, 0.02302983815648726, 0.0587685015052557, 0.04708903429231473, 0.05024736035349114, 0.020430238185716525, 0.045636908284255435, 0.07500611591551985, 0.05665693784664784, 0.05029357876628637, 0.0456522397830018, 0.0805851122630494, 0.017930180998519063, 0.07107792062950985, 0.038617314238633425, 2.982336414711816, 41.99112898962838, 62.22128513881138, 50.591543197631836, 35.452589239392964, 22.326929671423777, 22.551533664975846, 27.06810072490147, 38.11507640566145, 25.130654607500347, 1.107184806040355, 0.07353849895298481, 0.06293664034456015, 0.45831479557922905, 2.4008963916982924, 5.968122610024043, 7.208426867212568, 5.914764787469592, 16.30420333998544, 46.085685048784526, 57.007169314793174, 54.24548271724156, 53.70320013591221, 50.64599970408848, 51.9328408241272, 51.09595809664045, 53.57899413790022, 50.16113703591483, 44.02762862614223, 41.3539583342416, 46.24791506358555, 49.97878851209368, 53.3545812198094, 53.05770206451416, 52.28437103543963, 48.05075372968401, 47.22132989338466, 47.96601349966866, 52.140289715358186, 51.21524477005005, 50.464825425829204, 41.946500710078645, 37.57277645383562, 36.420323916843955, 37.11908687864031, 38.547115394047324, 40.28075000217983, 41.15848813738142, 37.083296707698274, 37.13469253267561, 36.95507117680141, 36.576786926814485, 36.725242137908936, 37.69454710824149, 35.805724484579905, 37.37639604296003, 37.67065920148577, 39.80675779070173, 36.880503109523225, 37.67154162270682, 36.114165442330496, 38.02414533070156, 37.29910775593349, 40.24866322108677, 39.81486981255667, 46.56431518282209, 48.38916226795742, 52.99058594022478, 39.967448779514854, 26.289369208472117, 55.77293995448521, 47.96180289132254, 48.56587927682059, 42.79098129272461, 44.45767000743321, 41.135993344443186, 40.06654746191842, 38.674010344914024, 37.36385107040405, 39.18277481624058, 38.11220679964338, 35.41713605608259, 39.97377164023263, 36.82541084289551, 38.026313168661936, 36.66221502849034, 40.43305104119437, 41.37457363946097, 43.42864179611206, 47.12371117728097, 50.9928503036499, 51.30089521408081, 50.99194703783308, 51.10007837840489, 47.65074593680245, 40.4928229195731, 37.58688129697527, 43.3575165612357, 51.32201426369803, 49.94700397763933, 53.16561801092965, 49.21991321018764, 45.55562087467739, 42.55761562074934, 39.443353107997346, 38.88261958530971, 43.10950061253139, 49.93020323344639, 50.68297106879098, 51.06591756003243, 50.38157211031233, 49.27153485161917, 52.48805052893502, 54.62935331889561, 54.52533878598894, 56.482489994594026, 54.61093364443098, 44.05451815468924, 20.659987347466604, 7.97273131779262, 3.056709715298244, 3.938096523284912, 8.138025488172259, 2.552930793591908, 0.565884146307196, 0.01348880204438631, 0.28463632081236157, 15.983835799353463, 38.82253156389509, 23.791404962539673, 22.71161147526332, 45.43769604819161, 38.54939440318516, 39.319237436567036, 49.94059773853847, 48.01092318126133, 15.832648209163121, 0.07372133699910981, 0.024818548067872013, 0.03021021107477801, 0.015390421031042933, 0.02676550591630595, 0.039537689315953424, 0.0378235164763672, 0.03389670200912016, 0.037541408757013936, 0.019668236574424163, 0.05188963562250137, 0.020169494141425406, 0.06170497036405972, 0.02966462481500847, 0.02046065521426499, 0.02375724126717874, 0.044680387646492035, 0.022388366416894963, 0.01758949365466833, 0.04783666453191212, 0.1437242885253259, 0.1417794307427747, 0.0962533950805664, 0.08833497283714158, 0.11011814538921628, 0.09691109907414232, 0.143619210592338, 0.1911487566041095, 0.15550729339676245, 0.11467942063297544, 0.13760840812964098, 0.13019791005977563, 0.17917584335165365, 0.14754487494272844, 0.20967410611254828, 0.14253617370767252, 0.09713856436844383, 0.23710616411907331, 0.12583545914718083, 4.463843694755009, 50.96953909737723, 67.46589660644531, 56.495927810668945, 43.6567268371582, 25.68263861111232, 28.200016123907908, 39.27851751872471, 51.62043244498116, 31.198103019169398, 1.7332854611533028, 0.26859146463019506, 0.1377872292484556, 0.7981431548084531, 4.963542069707598, 12.2342369556427, 13.665626662118093, 15.044811078480311, 20.82830398423331, 48.727074010031565, 60.90300342014858, 57.35926233019148, 56.42211709703718, 52.89745576041085, 53.41712542942592, 52.80619464601789, 54.91710254124233, 51.999703339168, 45.08833714893886, 42.968191623687744, 47.89354378836495, 53.03683315004621, 54.79763521466936, 54.69458300726754, 51.63212973730904, 49.24301944460188, 46.47845976693289, 48.66698251451765, 54.1521440914699, 53.0183961050851, 52.47514425005232, 44.33552762440273, 39.24375220707485, 39.23819364820208, 38.301892621176584, 41.41477244240897, 41.59369203022548, 42.373853138514924, 39.898508753095356, 39.428285939352854, 38.591166973114014, 37.44550977434431, 38.324839047023225, 38.828434058598106, 37.19663224901472, 39.29775013242449, 40.306805746895925, 40.73833404268537, 38.0621554510934, 40.01348059517996, 37.644766739436555, 40.10715273448399, 40.26387977600098, 41.810646057128906, 40.720532757895334, 48.606182302747456, 50.73106302533831, 54.650246552058626, 43.04314531598772, 28.001082250050136, 57.32078668049404, 50.601336683545796, 51.09974486487252, 44.35556970323835, 47.58941766193935, 43.17724207469395, 42.08977256502424, 40.5014317376273, 39.91159915924072, 40.95484338487898, 39.989453724452424, 38.25093453271048, 41.93088115964617, 39.653042793273926, 38.94239493778774, 38.9490339415414, 42.93869999476841, 44.00076341629028, 46.336886746542795, 49.24857800347464, 53.86811910356794, 53.44766623633248, 54.27978597368513, 54.14782231194632, 51.07456806727818, 43.38290875298636, 40.02706432342529, 45.194241591862266, 54.12025533403669, 53.92828702926636, 55.68152250562395, 52.52270119530814, 47.96300145557949, 45.24322291782924, 42.49872268949236, 41.61602701459612, 44.396348680768696, 51.48094041006905, 52.72535582951137, 55.047732148851665, 51.73288556507656, 51.0614081791469, 50.49079084396362, 58.022756235940115, 55.32799816131592, 59.99328967503139, 54.6039194379534, 51.69921806880406, 23.38171832902091, 14.168829100472585, 8.586721914155142, 11.655873247555324, 17.203126532690867, 3.273162820509502, 0.541225152356284, 0.10558713959263903, 0.87830137354987, 19.597625153405325, 50.83162777764456, 36.15730333328247, 28.488368102482386, 49.662471771240234, 45.47162757601057, 45.73321335656302, 57.357886586870464, 54.48848901476179, 21.411554881504603, 0.30413828577314106, 0.16481147413807257, 0.12230257157768522, 0.08916898058461291, 0.0936937370736684, 0.13482849087033952, 0.24875248489635332, 0.1001603047230414, 0.11748132242688111, 0.10565652658364602, 0.13518567170415605, 0.10873079911938735, 0.09047665327255215, 0.10259981453418732, 0.12348907148199421, 0.08376916497945786, 0.2602147055523736, 0.10381697743598904, 0.12342048516230923, 0.1489278378763369], [0.06750449059265, 0.024958433150979023, 0.05290043227640646, 0.05661043444914477, 0.03555755217426589, 0.018678486380460005, 0.1009860411286354, 0.04712231643497944, 0.06222274008073977, 0.026384625550625578, 0.04353787377476692, 0.0426759952014046, 0.040204560317631276, 0.1130519068932959, 0.06489868541913373, 0.011306296701409986, 0.026819792110472918, 0.059790192038885186, 0.0677497877872416, 6.088768524782998, 38.1161082131522, 53.5719382422311, 46.29381486347744, 31.001541955130442, 18.114797932761057, 23.99527553149632, 38.83684137889317, 40.535290309361045, 11.077033587864467, 0.12055241263338498, 0.042180420365184546, 0.0661983581792031, 0.36867776832410265, 2.42206038747515, 2.4570146032742093, 8.40342582975115, 8.492345401218959, 31.680405276162283, 52.27741936274937, 54.392426695142476, 50.60842037200928, 49.64473302023751, 47.56498779569353, 46.899649143218994, 47.25224937711443, 49.162034715924946, 43.266213757651194, 39.49572515487671, 36.198287282671245, 43.12318508965628, 50.567822047642295, 51.49941914422171, 51.177064418792725, 47.712501525878906, 48.18170990262713, 47.56326116834368, 50.701752049582346, 49.178050313677105, 48.49038015093122, 43.402353286743164, 36.94690356935774, 35.836088112422395, 35.489598819187705, 35.570111070360454, 35.90426731109619, 35.97382572719029, 38.4044897215707, 34.67007269178118, 34.89775473730904, 35.031281743730815, 36.03557436806815, 36.606150014059885, 35.653822966984336, 34.214847564697266, 35.59660107748849, 35.64293513979231, 36.529125758579795, 35.55266414369856, 39.85199751172747, 38.98795427594866, 42.224397386823384, 41.17012637002127, 42.89344637734549, 39.161304882594514, 45.71821219580514, 43.92815474101475, 52.17120919908796, 39.01563242503575, 27.64913167272295, 53.00841849190848, 44.58988380432129, 46.664313656943186, 39.25041205542428, 42.31803478513445, 37.98509645462036, 38.55396631785801, 36.68014832905361, 36.07138885770525, 35.36150877816336, 38.63833829334804, 34.00766965321132, 37.2834187235151, 34.88014105388096, 35.49895804268973, 35.36794628415789, 35.62193768365042, 36.48822866167341, 40.28342505863735, 42.628709588732036, 45.62606518609183, 46.51692499433245, 48.03859438214983, 46.72810506820679, 40.34215818132673, 36.77670744487217, 35.75620467322213, 34.888315609523225, 43.806981631687705, 48.67810658046177, 47.09043278012957, 43.71099574225289, 42.279579980032786, 39.8283041545323, 38.05511692592076, 39.760934420994346, 37.51183032989502, 42.8448680468968, 47.73280416216169, 49.69491638456072, 46.95901802607945, 45.24470983232771, 51.13107081821987, 50.552216393607004, 51.134051595415386, 50.00818634033203, 45.07379804338728, 46.25411633082798, 32.96021481922695, 17.294127089636667, 5.109082945755549, 3.482111219848905, 7.810194713728769, 1.4101246361221587, 0.1055422273597547, 0.011239272708605443, 0.06823343397783381, 3.568605435746057, 26.82764789036342, 31.48361839566912, 22.627687658582413, 19.477855580193655, 38.158756256103516, 33.447926248822895, 45.739383356911794, 42.82211964470999, 25.930604185376847, 2.481135926076344, 0.14363928165818962, 0.07595008026276316, 0.010564673193065184, 0.09840687523995127, 0.06065025553107262, 0.029834719973483255, 0.053586132624851804, 0.05328805897650974, 0.03567892851840172, 0.028704260276364427, 0.023667566079114164, 0.06784086754279477, 0.04766809607722929, 0.10338572771953684, 0.016694002152819718, 0.01011791979960565, 0.027261477695511918, 0.05275086958759597, 0.03182090053867016, 0.07042994004275117, 0.043848517284329445, 0.05402116517403296, 0.006780458373084132, 0.024335237752114023, 0.03932604745828679, 0.02656633892495717, 0.029969242933605398, 0.024365469879869903, 0.034424361373697004, 0.015696615047220672, 0.030258624548358575, 0.021885354836870517, 0.023016810284129212, 0.01514793636410364, 0.08109655803335564, 0.029166963483606066, 0.02864875950451408, 0.0962656494230032, 8.397129893302917, 48.15518862860543, 60.75285979679653, 50.23957872390747, 39.28835269383022, 19.740820578166417, 27.058368035725184, 38.60207564490182, 39.03475386755807, 14.213642375809805, 0.2130653698529516, 0.03762026131153107, 0.26927198097109795, 1.096824390547616, 5.026140996388026, 5.447557491915567, 7.353520018713815, 6.8293101361819675, 31.60750825064523, 54.48761701583862, 56.40736607142857, 53.042280537741526, 51.80246829986572, 49.28175217764718, 49.41882971354893, 49.89396142959595, 51.61563471385411, 46.17940929957798, 42.36971548625401, 38.73035676138741, 45.43126201629639, 52.330642563956125, 53.230017389569966, 51.34500585283552, 49.13954339708601, 48.71252795628139, 49.169097559792654, 53.34984254837036, 52.00599493299212, 51.25567633765084, 44.522170134953086, 39.11494302749634, 38.25201497759138, 37.624408517565044, 37.57617064884731, 37.04228843961443, 37.63138450895037, 40.18097734451294, 35.44334118706839, 36.83672251020159, 36.605034828186035, 37.31763512747628, 37.13778795514788, 36.69549342564174, 36.077128069741384, 38.2553049496242, 37.606468268803184, 38.06131819316319, 36.60432958602905, 41.10595975603376, 40.94331284931728, 45.018056120191304, 41.614984784807476, 44.66223192214966, 39.831295354025706, 47.942504269736155, 46.83021232060024, 53.66352244785854, 39.674915722438264, 28.242665903908865, 54.795776571546284, 46.859492029462544, 48.70333201544625, 42.400593280792236, 43.53482069287981, 40.49576200757708, 40.70484372547695, 38.36311667306082, 38.238452093941824, 36.85367611476353, 40.84908138002668, 36.248970917293, 38.643827370234895, 37.195110593523296, 37.00368077414376, 36.85780334472656, 37.16585520335606, 37.29888193947928, 40.004281180245535, 43.754133633204866, 47.35348115648542, 49.77693292072841, 50.46349137169974, 49.437562056950156, 41.99908815111433, 38.2216339792524, 38.66683980396816, 37.650881154196604, 44.44321428026472, 49.87506580352783, 49.38882391793387, 46.04746995653425, 43.78799915313721, 41.63342182976859, 39.23635237557547, 40.6521520614624, 39.5424622126988, 44.03920085089547, 50.275212560381206, 51.91686691556658, 49.4142404283796, 46.708858558109824, 50.314358711242676, 52.08348471777779, 52.32350328990391, 49.81245558602469, 47.310305050441194, 48.35488680430821, 36.80087327957153, 19.02788155419486, 6.2307163136346, 4.0753073777471265, 6.116732852799552, 2.916668555566243, 0.8458478035671371, 0.017897185536899736, 0.04794581028233681, 4.472770827157157, 31.20871639251709, 33.9551134790693, 21.18820677484785, 23.34089071410043, 43.107110432216096, 38.64293452671596, 50.86652510506766, 49.12480974197388, 32.749399525778635, 3.223986727850778, 0.09083150673125472, 0.05950081720948219, 0.04438748104231698, 0.05536948550226433, 0.047027033154985735, 0.017069503432139754, 0.02208246077810015, 0.062077750717954974, 0.01870887117859508, 0.07197233834969145, 0.041317021873380454, 0.02135864202864468, 0.03129374668268221, 0.059876807034015656, 0.005976122961978295, 0.020364096288436224, 0.06593030292008605, 0.0426387470215559, 0.0392859324679843, 0.1293393461299794, 0.09970720617898873, 0.1169522822435413, 0.11305616130786282, 0.10098185456757035, 0.1438782616917576, 0.21095566877296992, 0.16213238718254225, 0.10694984825594084, 0.09033102608684983, 0.11047469518546547, 0.18971156515181065, 0.15140208868043764, 0.24405951957617486, 0.14876376810882772, 0.15942644381097384, 0.12039615958929062, 0.08799113878714186, 0.225519540852734, 11.200714128358022, 57.79628317696707, 66.36193902151925, 57.92957394463675, 44.63474137442452, 27.96194131033761, 34.86891276495797, 50.229385716574534, 52.63473742348807, 16.37211503301348, 0.5086459719708988, 0.09403998670833451, 0.30569905202303616, 0.773902952671051, 7.291449155126299, 9.673639910561697, 16.60792647089277, 14.488838808877126, 36.18429708480835, 55.389725957598, 58.810747964041575, 54.78765760149275, 55.1971948487418, 52.67287608555385, 52.6244923046657, 51.86503335407802, 54.00540508542742, 47.197448934827534, 43.84231322152274, 40.60290322984968, 48.885440826416016, 55.02916308811733, 55.3103323663984, 52.34069660731724, 48.03325121743338, 48.22297872815813, 48.64105878557478, 55.47917706625802, 53.38242612566267, 54.990826402391704, 46.751103605542866, 41.218183585575645, 39.515204429626465, 38.434825556618826, 38.91843407494681, 39.701509952545166, 39.33804621015276, 41.35938835144043, 37.72258308955601, 38.857890946524485, 39.45171526500157, 40.15120431355068, 40.189249174935476, 39.363792760031565, 37.70134244646345, 39.45031172888619, 39.35619143077305, 41.13563551221575, 39.00955622536795, 42.98309203556606, 42.94413348606655, 46.91894429070609, 44.54924726486206, 47.946562017713276, 43.87521641595023, 51.976604052952354, 47.9121858051845, 55.836769580841064, 41.49247414725167, 30.003137929098948, 56.37152031489781, 48.40666478020804, 50.183027335575645, 43.969611167907715, 46.15217236110142, 42.454691955021445, 43.465210165296284, 39.60411705289568, 39.899818488529746, 40.003304958343506, 42.57686560494559, 38.32098627090454, 40.59836605616978, 39.157688345227925, 38.39376170294625, 39.112538950783865, 39.57325662885393, 39.5878061567034, 42.49488728387015, 46.68667296000889, 48.96382692881993, 51.361618995666504, 52.32071706226894, 51.920723165784565, 44.63754844665527, 40.78946931021554, 39.47868122373308, 40.22923953192574, 46.707729475838796, 53.94008159637451, 51.675601141793386, 47.0643527167184, 46.38792126519339, 44.198012351989746, 41.284375599452424, 43.42558806283133, 41.91278110231672, 46.81985950469971, 52.97011654717581, 54.748261315482004, 51.04372501373291, 50.48152542114258, 53.02274220330374, 52.39979798453194, 52.04481451851981, 51.10649503980364, 45.12931415012905, 48.91924728666033, 37.85070787157331, 21.352396181651525, 8.439410550253731, 12.821790524891444, 17.953924553734915, 4.301390903336661, 0.9961117718900953, 0.16312933154404163, 0.20227145190749848, 5.555770039558411, 40.56756469181606, 42.96972370147705, 32.892862456185476, 28.66853141784668, 49.58843176705496, 44.82097046715872, 58.6674622126988, 56.02223089763096, 40.8056447165353, 3.9753518956048146, 0.21694325176732882, 0.20136555337480136, 0.10140213237277099, 0.13511625757174833, 0.19187170852507862, 0.09121453974928175, 0.1630614644714764, 0.12563789689115115, 0.11256747360208205, 0.19796202172126087, 0.15145711787045002, 0.1476081551185676, 0.16539314149745873, 0.20479028246232442, 0.1274846520807062, 0.08401991081024919, 0.13604093795376165, 0.14300098376614706, 0.11218003689178399], [0.01429746566074235, 0.039346294943243265, 0.07783863999481712, 0.019068827220637883, 0.06404718503888164, 0.00805528021217989, 0.05223496584221721, 0.024017808892365013, 0.004826830101332494, 0.0373516089415976, 0.0305614886539323, 0.05895985516586474, 0.021302053904426948, 0.009870459774642118, 0.04344595263579062, 0.02613090943279011, 0.044435918264623196, 0.037032351429973326, 0.2962993064096996, 12.19342497416905, 53.25124066216605, 49.422255175454275, 46.43854584012713, 23.14840997968401, 23.46848222187587, 25.303805453436716, 38.05797610964094, 31.54189988545009, 5.308291273457663, 0.09185754667435374, 0.22928165112222942, 0.049163702609283585, 0.9639532289334706, 2.519590731178011, 4.802551439830235, 5.932496156011309, 13.768922924995422, 48.89420597893851, 54.11115319388253, 52.49780232565743, 49.35696642739432, 47.91962385177612, 41.92537818636213, 43.522181919642854, 40.34679957798549, 40.939876965114046, 39.26344687598092, 36.4491137777056, 35.51792662484305, 42.633854729788645, 49.997187341962544, 50.516784054892405, 49.74638169152396, 47.18575164249965, 47.11198609215872, 49.4299989427839, 50.005556447165354, 46.482072830200195, 43.40531669344221, 38.746420996529714, 37.48512492861067, 36.354451520102366, 34.46959979193551, 34.937762464795796, 36.22338765008109, 36.21633522851126, 37.30638599395752, 35.6274128641401, 36.069349561418804, 34.5340894971575, 35.87301083973476, 36.169372354234966, 35.988462107522146, 35.24460186277117, 37.53631230763027, 33.89411176953997, 36.284264292035786, 43.733045850481304, 47.018115929194856, 47.42321327754429, 48.35268422535488, 46.34207705089024, 46.438441617148264, 42.540523052215576, 47.141383920397075, 43.996434688568115, 51.433644022260395, 36.16860805238996, 22.87878860746111, 52.72749934877668, 45.215767111097065, 48.9736864226205, 43.127065658569336, 44.97642251423427, 40.43821702684675, 43.04349272591727, 38.78686646052769, 38.531554903302876, 35.74133900233677, 37.99664436067854, 36.35871076583862, 37.303200244903564, 36.86770452771868, 36.96570192064558, 35.03073631014143, 35.82699639456612, 35.30262279510498, 36.739819458552766, 36.677580969674246, 38.842403411865234, 39.21602542059762, 39.468220710754395, 36.43413346154349, 38.112707069941926, 35.29303775514875, 35.31854459217617, 34.42961638314383, 36.58433614458357, 37.76654781614031, 40.51921565192086, 38.808093207223074, 39.14229808534895, 38.32081256593977, 37.442376136779785, 38.06140504564558, 40.199932030269075, 44.88405663626534, 49.603259222848074, 48.15309027263096, 48.58995825903756, 46.446939264025005, 44.08135904584612, 46.64130122320992, 49.24542004721505, 48.01051671164376, 52.60707317079817, 48.219747815813335, 43.93952546800886, 24.788695539746964, 11.744954364640371, 3.878447106906346, 3.5842729721750533, 2.9331281866346086, 1.3099478972809655, 0.020430468887622868, 0.030714654363691807, 1.008218682238034, 19.490268536976405, 34.1270466532026, 24.110683373042516, 16.21207022666931, 32.96397726876395, 42.003208432878765, 40.95995725904192, 44.98533705302647, 33.84691613061087, 8.82879020486559, 0.005215600981110973, 0.05031084408983588, 0.09763065153466803, 0.022443784068205526, 0.044544721354863474, 0.06243791710585356, 0.06646632522876773, 0.05072568343686206, 0.03470021978552852, 0.045662010687270334, 0.06455462745257787, 0.06758393347263336, 0.06367469645504441, 0.045810962694564035, 0.025459017271974256, 0.007215293723025492, 0.0378170907497406, 0.04495364048385194, 0.05521883037207382, 0.03845689159684947, 0.05420138746766107, 0.06695858881409679, 0.031493239370839934, 0.05331839966986861, 0.014328043841357743, 0.08113632697079863, 0.037808849941939116, 0.055024857566292794, 0.042239140785698376, 0.0319006046546357, 0.027316165921677436, 0.030713131052574942, 0.0304151965039117, 0.10613314315144505, 0.08650183584541082, 0.022973407791661363, 0.010218173348610955, 0.2414711798940386, 17.040446622031077, 61.711468015398296, 55.33863237925938, 50.70434372765677, 29.508565153394425, 27.26560500689915, 29.675533839634486, 39.36457443237305, 36.24819966724941, 6.09034880570003, 0.08787734846451453, 0.052303803219859085, 0.1143052764236927, 1.6247298462050301, 5.766070297786167, 8.321251222065516, 3.5547298831599097, 15.188930613654, 47.834018571036204, 56.18095554624285, 54.177855900355745, 53.26943104607718, 48.22010564804077, 45.957202434539795, 43.67587954657418, 43.959946223667686, 43.37777403422764, 42.6334274155753, 38.544450759887695, 38.061092376708984, 44.404054233006065, 52.00698505129133, 53.34357874734061, 50.31490761893136, 47.97046034676688, 47.315262590135845, 50.95292248044695, 52.45831918716431, 48.791713101523264, 46.24163041796003, 39.84655359813145, 39.501982007707866, 37.98041336877005, 36.624524525233674, 35.845436913626536, 38.35484831673758, 37.12779644557408, 39.90289306640625, 36.520989418029785, 38.34802865982056, 35.72660534722464, 37.247572966984336, 37.85256651469639, 37.30151878084455, 36.90360934393746, 38.66307388033186, 35.49323272705078, 38.22749131066458, 45.235781397138325, 48.8889149257115, 48.66661773409162, 50.26242092677525, 48.635851110730854, 49.06959935597011, 44.58099358422415, 49.204488209315706, 46.19842651912144, 53.535147530691965, 37.90115874154227, 23.890118019921438, 55.33646106719971, 47.459712164742605, 51.69859273093087, 44.719700472695486, 46.356598785945344, 43.659301144736155, 44.667675835745676, 41.69383989061628, 40.94121101924351, 37.775649956294465, 39.4038074357169, 37.65273979731968, 38.10972629274641, 38.92120293208531, 38.431299345833914, 35.326267514910015, 37.72533457619803, 37.56284400394985, 37.874675682612825, 38.64207295009068, 40.937066418784006, 41.69124821254185, 42.65567554746355, 38.28964989525931, 38.86323063714163, 37.59826939446585, 37.214190346854075, 36.50172553743635, 37.75198091779436, 38.51737362997872, 43.040737765175955, 42.18567507607596, 41.409564767565044, 39.86894416809082, 38.71637003762381, 40.67394856044224, 42.363118171691895, 47.82900544575283, 50.87185089928763, 50.04977478299822, 50.34009831292288, 50.17251123700823, 47.4545704977853, 47.5887645312718, 49.58127164840698, 47.89933858598982, 51.84283038548061, 49.80458327702114, 45.16912037985665, 25.59110999107361, 11.684930614062718, 6.29310462304524, 8.273729017802648, 6.52862423658371, 1.9219991862773895, 0.09206829286579575, 0.01982525466675205, 0.9006252842290061, 22.99897333553859, 35.62622472218105, 30.148619311196462, 23.01104061944144, 38.315681321280344, 45.19505800519671, 45.71266058513096, 50.128268582480295, 41.23888226917812, 10.7076221874782, 0.047095877317977805, 0.08431763162038156, 0.06798667793295213, 0.022912631410041025, 0.026714447852490202, 0.042417252835418494, 0.027099711554391042, 0.008449795739060002, 0.01559375592374376, 0.05617194137136851, 0.028763594771070138, 0.010762936036501611, 0.06345818950129406, 0.033219710657639165, 0.024787165823259523, 0.0014934288587288133, 0.038218749554029534, 0.012102239482503916, 0.05736448363001857, 0.1465640797146729, 0.13842351867684297, 0.14632705386195863, 0.08257061429321766, 0.15346802425171646, 0.09029131143220834, 0.2187336478382349, 0.11238723434507847, 0.1326949732112033, 0.09500159296606268, 0.19028062533055032, 0.22426739947072097, 0.07513551932892629, 0.095247426203319, 0.2059930536363806, 0.2193270945655448, 0.17470998370221683, 0.07319482775138957, 0.44893166050314903, 22.827245133263723, 69.8033470426287, 61.815510341099326, 59.56418282645089, 35.0747948374067, 33.79957457951137, 33.432292801993235, 49.23806190490723, 42.559627124241416, 8.087086507252284, 0.3315013774803707, 0.250910470528262, 0.3055237185742174, 2.8988555456910814, 9.408851878983633, 13.475616880825587, 14.387349077633449, 16.829928364072526, 53.967026710510254, 58.3618665422712, 57.91741459710257, 54.19534799030849, 52.527478081839426, 46.68764918191092, 47.00520270211356, 45.5762049130031, 43.69734253202166, 44.550237383161274, 42.14930820465088, 39.78744527271816, 47.048257214682444, 54.022080762045725, 53.326579979487825, 50.73324475969587, 48.81344706671578, 46.590572425297324, 53.24541112354824, 54.43933398383004, 52.22492572239467, 47.72190938677107, 43.0986544745309, 40.55267817633492, 39.576105390276226, 38.387480531420024, 37.90798882075718, 39.178404399326865, 40.5086578641619, 42.13846901484898, 38.56114728110177, 39.094240869794575, 38.463431290217805, 39.1903726713998, 40.630338191986084, 39.427361828940256, 39.92101396833147, 41.89774867466518, 37.22956323623657, 41.070461409432546, 48.443208830697195, 51.310511520930696, 52.266840730394634, 52.74040215356009, 52.056939125061035, 50.8663444519043, 46.443913323538645, 51.15453141076224, 48.70757041658674, 55.33888251440865, 40.30397088187081, 26.503097534179688, 55.23426696232387, 49.2449232510158, 53.1893287386213, 47.28252962657383, 48.69950703212193, 45.324937207358225, 47.10258865356445, 43.85075180871146, 43.01325763974871, 39.7656626701355, 41.335503918784006, 41.01917328153338, 40.80349424907139, 40.99741847174508, 40.961663041796, 37.84294325964791, 39.974139894757954, 39.73847784314837, 40.365914072309224, 41.23038462230137, 41.97758000237601, 43.597086974552695, 44.50675903047834, 40.31699875422886, 41.11182056154524, 39.18936170850481, 39.712700026375906, 38.00959927695138, 40.07559401648385, 41.097257137298584, 45.05373511995588, 43.63345384597778, 44.18936531884329, 42.17734071186611, 41.582752091544016, 42.18669646126883, 43.95541252408709, 49.792608056749614, 52.811631611415315, 53.6035977091108, 52.99144056865147, 50.826270716530935, 49.83464813232422, 48.99857486997332, 49.85986314501081, 47.613225664411274, 54.180086272103445, 49.41889224733625, 46.1714049748012, 28.951738255364553, 18.778074707303727, 8.71351785319192, 10.9738632610866, 11.245799251965114, 2.7112389845507483, 0.14404903538525105, 0.08139219574098076, 1.465530657342502, 27.870457853589738, 44.30932249341692, 36.611705098833355, 24.270865406308854, 42.17528404508318, 53.31627580097744, 51.11381844111851, 57.08291857583182, 49.30300324303763, 15.111433880669729, 0.13516740554145404, 0.186352708243898, 0.1767286118119955, 0.08295164563293968, 0.08773655923349516, 0.15427569805511407, 0.149897410135184, 0.14120015182665416, 0.16246595499770983, 0.10774760866271597, 0.11684605080102171, 0.10414601942258221, 0.1020114975316184, 0.11928420354213033, 0.08390686687614236, 0.09910641091742686, 0.14551593310066632, 0.099816009269229, 0.295601880976132], [0.036099423454808335, 0.054109310265630484, 0.038476426620036364, 0.05033533920400909, 0.028097673718418394, 0.03897769436506288, 0.09815869427153043, 0.05689876094194395, 0.04018410587949412, 0.013888216594101062, 0.019614362590281025, 0.005474326383721615, 0.05614931222849658, 0.09533354586788587, 0.10361273839537587, 0.027497811442507163, 0.040737519040703773, 0.12592934125236102, 1.236386233142444, 25.805885757718766, 52.848773206983296, 49.82561894825527, 41.40610456466675, 22.059839180537633, 18.016456604003906, 25.693403107779368, 34.80359969820295, 23.86791331427438, 2.1406637728214264, 0.020080534807805504, 0.031315385164426904, 0.23440095356532506, 2.5574560250554765, 4.41913377387183, 2.4484754843371253, 6.508039763995579, 29.12226789338248, 53.97395406450544, 51.956961495535715, 51.804768153599326, 48.164610385894775, 41.75341027123587, 39.82872452054705, 37.99486909593855, 39.76731981549944, 39.942532539367676, 36.10826294762747, 36.213566371372764, 36.02165365219116, 39.778669697897776, 47.205585275377544, 50.237789562770296, 49.573298590523855, 50.31872912815639, 52.597835540771484, 47.380349840436665, 48.97715009961809, 46.35669258662632, 42.19150114059448, 36.32077360153198, 39.3506988797869, 36.65904664993286, 35.43386731828962, 34.22325141089303, 36.74131679534912, 35.251869678497314, 36.03788117000035, 35.06666544505528, 37.14435747691563, 34.197602135794504, 36.765006678445, 35.650136947631836, 36.412264006478445, 35.03861209324428, 36.093772479466026, 34.533467633383616, 42.87895590918404, 48.4071615764073, 51.814346245356965, 47.8246419770377, 50.00821760722569, 48.061579023088726, 50.66108424322945, 48.271473680223735, 48.57554422106062, 45.43895367213658, 54.068737915584016, 32.23774112973894, 23.711874144417898, 50.484669481004985, 44.52750287737165, 49.138476848602295, 46.19439308983939, 47.10542351858956, 45.24024908883231, 45.891121591840474, 43.04743582861764, 41.3034553527832, 34.380159105573384, 36.8318691934858, 34.84232895714896, 35.331996304648264, 36.482006549835205, 34.47023902620588, 34.41713047027588, 36.04968615940639, 34.988748346056255, 35.90516015461513, 37.26232399259295, 34.86165189743042, 35.28406068256923, 34.95944431849888, 32.540446349552695, 35.79676478249686, 34.67256014687674, 34.76503372192383, 35.67512614386422, 36.2918586730957, 35.83065462112427, 35.537346839904785, 35.52198089872088, 36.45154217311314, 35.595614433288574, 37.17611769267491, 38.57590178080967, 43.14711121150425, 46.68691267286028, 48.70714657647269, 49.44792876924787, 46.17580665860857, 47.77479560034615, 42.35592678615025, 47.22519656590053, 47.60209812436785, 52.02631493977138, 48.83686249596732, 53.78550502232143, 46.720795563289094, 29.712102208818706, 11.504390358924866, 4.929055120263781, 4.499773698193686, 3.031584160668509, 1.4926893200193132, 0.08348628373018332, 0.24236966882433209, 0.02454845720369901, 7.379382082394191, 32.10300861086164, 27.713275705065044, 11.525650109563555, 31.663493360791886, 37.842297077178955, 35.825651918138774, 44.341680254255024, 40.148001194000244, 18.1046552998679, 0.21094504291457788, 0.023859749248783504, 0.04142501411427345, 0.004247942615100848, 0.050883955122636895, 0.027166377619973252, 0.11548773225929056, 0.008149584705409194, 0.05387839122808405, 0.021853492528732334, 0.037944048044404814, 0.011580816702917218, 0.019202929489048462, 0.0439644585629659, 0.04112730008949127, 0.03998103391911302, 0.07677472422697715, 0.04964660919670548, 0.01884961630483823, 0.05977191909083298, 0.030247072489666085, 0.0076228973422465575, 0.045514765195548534, 0.07439198065549135, 0.03063164238951036, 0.11082448677292892, 0.05845733891640391, 0.019391959167218635, 0.01678001494812114, 0.04670930573982852, 0.01464364574556904, 0.05770847374307258, 0.043512605130672455, 0.03445429155336959, 0.034949805321437974, 0.04883041977882385, 0.1874498993690525, 1.8771253313337053, 34.795070784432546, 60.59578187125069, 56.77997016906738, 49.40018074853079, 29.283485208238872, 23.21596905163356, 29.919547625950404, 36.33794607434954, 29.46367631639753, 2.236212360007422, 0.09196576622447797, 0.029331046821815625, 1.2212389430829456, 6.83097379548209, 7.34975756917681, 6.354997004781451, 4.468535900115967, 30.690366881234304, 56.16929299490792, 54.479421615600586, 54.08651835577828, 50.07204375948225, 44.36346633093697, 42.09714807782854, 39.88114867891584, 42.07657446180071, 41.003494671412874, 38.530429295131135, 38.13635178974697, 37.03065020697457, 41.41870512281145, 49.841367040361675, 52.42248385293143, 50.5052604675293, 50.394329002925325, 50.97829730170113, 49.64791529519217, 51.286877223423545, 49.18315029144287, 44.418753147125244, 38.23683663776943, 40.71268129348755, 36.46266623905727, 35.89375468662807, 35.59410320009504, 38.20469774518694, 37.77927344185965, 37.3854148047311, 36.91571657998221, 39.02337966646467, 37.02514028549194, 38.39769090924944, 36.240108489990234, 37.781764371054514, 36.51516682761056, 38.16850805282593, 36.76370389120919, 44.78940480095999, 50.023170130593435, 52.63431358337402, 50.25562558855329, 51.7769684110369, 49.415206227983745, 50.84541647774832, 49.82592466899327, 51.3803756577628, 48.73562029429844, 55.05957187925066, 33.12237535204206, 24.632678951535905, 51.12824637549264, 46.27675356183733, 51.56309243610927, 47.46548959187099, 48.9278039932251, 46.788738523210796, 48.41791391372681, 43.96049165725708, 42.31373732430594, 35.919918128422324, 38.900862080710276, 37.56176355906895, 37.44691331045968, 38.49491705213274, 37.21584401811872, 36.87120641980852, 37.376031262534006, 36.33887365886143, 37.50438533510481, 38.12004089355469, 36.82913160324097, 35.355321407318115, 37.33599921635219, 34.82322835922241, 37.66536120006016, 36.6479503767831, 36.883032253810335, 36.57829121180943, 37.853931835719514, 35.9874198777335, 37.239453996930806, 37.38132578986031, 38.12818765640259, 37.25041478020804, 38.281475339617046, 39.79375076293945, 45.527602263859336, 50.49082211085728, 51.348921162741526, 52.27277449199131, 47.35416555404663, 48.39626332691738, 43.4266928264073, 48.238407203129356, 48.120732511792866, 50.79160267966134, 50.40747152056013, 55.32710879189627, 48.09562519618443, 31.338967323303223, 12.13524944441659, 7.253131142684391, 10.600844877106802, 6.350644826889038, 3.16413277387619, 0.45657085201569964, 0.2527941380228315, 0.0491284018249384, 9.511764253888812, 35.60924332482474, 26.052803891045706, 13.539079989705767, 34.638684204646516, 44.81933069229126, 41.627074650355745, 50.191045556749614, 47.32647350856236, 23.509881326130458, 0.6267986233745302, 0.049306103360972235, 0.042863654238837104, 0.03984057377757771, 0.028101588865475993, 0.012055821750046951, 0.0877861397873078, 0.008331058896146715, 0.0111037582391873, 0.04588344719793115, 0.04801025753840804, 0.005208252870943397, 0.017126407075141157, 0.08805243764072657, 0.044200497147228034, 0.014800455188378692, 0.04077803436666727, 0.04384421197963612, 0.05461885953055961, 0.15963768533297948, 0.13348576506333693, 0.11455105537814753, 0.10587173075016056, 0.10556674961532865, 0.1060426469360079, 0.1993753287409033, 0.14245056972971984, 0.1627849071685757, 0.10794213108186211, 0.0882410364491599, 0.09349800686218909, 0.17727859158601078, 0.1271487908171756, 0.19659535719880036, 0.08014058361628226, 0.175846095596041, 0.24463586722101482, 2.1785053993974413, 43.31001172746931, 66.01831586020333, 66.41510663713727, 53.755023275102886, 33.4134110723223, 25.935580832617624, 37.820507526397705, 46.329570293426514, 33.707017626081196, 2.848497825009482, 0.1527878064662218, 0.11474902475518839, 0.8243749386497906, 7.705392428806849, 12.19662548814501, 9.8207654101508, 12.359279343060084, 32.71970987319946, 59.01870059967041, 55.73266472135271, 56.489254065922324, 53.36624724524361, 45.67082895551409, 43.61886610303606, 42.31502968924386, 42.6079865864345, 43.001463072640554, 40.65817962374006, 39.50747108459473, 38.88226522718157, 43.16148356028965, 50.91805294581822, 54.227010931287495, 52.60043069294521, 50.09682450975691, 51.71915245056152, 50.926842417035786, 54.419917242867605, 50.28252553939819, 46.519356863839285, 40.62095464978899, 42.0565184865679, 39.73870365960257, 36.926072869982036, 37.015374592372346, 40.072703565870015, 38.504359654017854, 39.48816898890904, 39.32315969467163, 41.272876330784385, 38.43422801154, 40.264942850385395, 38.50734390531267, 40.143860067640034, 38.31001159123012, 40.392873082842144, 38.842368670872276, 47.15303952353341, 52.75906501497541, 54.948817593710764, 51.90637166159493, 53.391733237675254, 53.22865901674543, 53.22244732720511, 53.499756881168906, 52.28709125518799, 50.71115296227591, 55.735506534576416, 36.037252358027864, 28.596871171678814, 50.902221475328716, 49.23268052509853, 53.897996357509065, 51.06382267815726, 50.06725992475237, 51.11691733769008, 50.47825629370553, 48.072734355926514, 46.2424190385001, 37.889100142887656, 39.74382100786482, 38.71312175478254, 39.32284007753645, 40.665881701878135, 38.90512480054583, 38.46988269260952, 39.87433597019741, 38.879937580653596, 39.98868594850813, 40.417184829711914, 38.528310094560894, 37.67350796290806, 39.24806703839983, 36.71045289720808, 40.549224921635215, 38.27211959021432, 39.13148321424212, 39.96228626796177, 39.76486362729754, 40.02879442487444, 37.86825902121407, 39.16311488832746, 40.61115421567644, 40.63375323159354, 40.22011307307652, 41.29752506528582, 47.692897183554514, 52.875363962990896, 53.650491101401194, 54.120171955653596, 48.218247004917686, 50.930705615452354, 43.765334129333496, 47.82319327763149, 48.61171306882586, 53.51042584010533, 51.03380993434361, 57.86271490369524, 49.98129333768572, 33.03658594403948, 13.169049331120082, 8.911366071019854, 10.375850915908813, 8.725024938583374, 5.863688145365034, 0.24789554945060185, 0.5220914962036269, 0.11518083087035588, 11.618789843150548, 44.88505022866385, 36.298720019204275, 19.348351580756052, 41.93207624980381, 49.80072007860456, 48.51495940344674, 56.63405799865723, 53.40847839627947, 30.709634235927037, 1.5576160017933165, 0.23980325939399855, 0.14110059716871806, 0.08403614136789526, 0.1260206720658711, 0.16712533283446515, 0.1948163876576083, 0.11292327022446053, 0.14960592506187304, 0.13785657552736147, 0.08797319153589861, 0.09547659462051732, 0.0959061412140727, 0.11149457403059516, 0.07278769995485034, 0.11428957512336117, 0.13567133992910385, 0.11694639255957943, 0.1291808132082224], [0.021108004763456326, 0.011716070784521955, 0.04677892682541694, 0.007172944656174097, 0.045182727476848025, 0.020463574611182724, 0.04302367654496005, 0.014917612741036075, 0.03616342966311744, 0.04196731626455273, 0.05179548888866391, 0.0669758982424225, 0.05882688265826021, 0.0028400978023585466, 0.06227718573063612, 0.07853894920221396, 0.03167944973600762, 0.08068377125476088, 4.84974490744727, 41.81209475653512, 53.26374741962978, 43.50250462123326, 26.4795309816088, 17.364953551973613, 20.26843203817095, 21.554746832166398, 30.19832672391619, 14.905636923653738, 0.24330371298960277, 0.07661080373717205, 0.10503315646201372, 1.0733614095619746, 2.2835080964224677, 5.611841133662632, 9.723602669579641, 7.01264443567821, 48.108090264456614, 53.85350704193115, 54.95543227876936, 45.98767375946045, 46.12487983703613, 38.67998232160296, 38.34992899213518, 39.31903593880789, 43.03740610395159, 42.48248127528599, 41.79115983418056, 38.293763228825156, 35.37855618340628, 35.09601811000279, 44.51986333302089, 50.27338171005249, 49.47935547147478, 47.24460635866438, 47.4561060496739, 45.50652837753296, 48.78323629924229, 46.6182644707816, 46.906809261866975, 43.38427059991019, 45.95052521569388, 44.99095467158726, 41.27432155609131, 35.6216493334089, 36.27870225906372, 36.64699847357613, 37.77593830653599, 36.153989042554585, 37.320650645664756, 35.59110157830374, 36.29043776648385, 35.63489954812186, 37.04355648585728, 34.96098334448678, 34.23429209845406, 35.332322869982036, 45.030601092747276, 49.25002670288086, 47.63508122307913, 42.13226774760655, 48.81233535494123, 44.85805300303868, 50.26930659157889, 46.785966191973, 50.90040104729788, 45.65108217511858, 52.23536886487688, 28.47335478237697, 23.80672574043274, 53.181463377816335, 43.08814532416207, 49.95888887132917, 44.658215863364084, 47.48366607938494, 44.580531529017854, 45.731194904872346, 40.84566286631993, 38.38736241204398, 36.40504830224173, 37.26692370006016, 36.035084520067485, 35.468632629939485, 35.78963245664324, 35.56718935285296, 33.51257923671177, 36.15215819222586, 34.76613501140049, 35.584629331316265, 35.95434992653983, 35.47195039476667, 34.291465350559776, 36.48498732703072, 33.74471160343715, 34.99450840268816, 33.675594397953574, 34.86398649215698, 35.6945150920323, 36.76405130113874, 41.14076328277588, 43.22584124973842, 43.5774826322283, 43.26860046386719, 40.853243350982666, 40.738667556217735, 40.32039989743914, 43.89043297086443, 48.77591289792742, 49.22585391998291, 45.92779070990426, 46.141750063214985, 50.03373834065029, 48.981662954602925, 46.787665026528494, 50.56581401824951, 51.61933462960379, 51.782172611781526, 52.58248002188546, 54.86515780857631, 41.52452271325247, 18.497947658811295, 9.839753968375069, 11.318401847566877, 4.78496207509722, 2.0294967208589827, 0.3809302108628409, 0.047800159347908835, 0.03402315718787057, 3.6129199607031683, 26.440890312194824, 47.899269104003906, 30.760161536080496, 17.169132471084595, 35.849578039986746, 35.525468894413535, 40.76056480407715, 43.73790611539568, 29.76628773553031, 4.582332193851471, 0.028339430656550185, 0.02524481394461223, 0.053756631511662684, 0.06390159177993025, 0.037599281008754454, 0.047282521945557425, 0.05482956840257559, 0.05117221036925912, 0.008264565008825489, 0.021609228403706635, 0.03596714644559792, 0.04806049966386386, 0.013741589417415006, 0.022617131105757186, 0.02237954206897744, 0.05392538995615073, 0.037877351444746764, 0.06727574965251343, 0.022031256829255393, 0.005424247530754656, 0.09224912244826555, 0.039536715618201664, 0.0467129291168281, 0.02259520085395447, 0.030365517562521354, 0.014552701697019594, 0.0670668219349214, 0.04159656473036323, 0.05150980868243745, 0.018662276178864495, 0.03714080846735409, 0.033067318477800915, 0.05975204480013677, 0.05441874598285981, 0.03504302246229989, 0.12761347873934678, 6.582255210195269, 47.67527655192784, 57.254754475184846, 49.12824215207781, 32.28961638041905, 23.82960615839277, 24.785858937672206, 23.052966049739293, 34.02237204142979, 18.217018093381608, 0.2944370263389179, 0.03396631970203348, 0.07545124845845358, 2.0157840166773116, 10.027627178600856, 7.179537560258593, 4.956238644463675, 8.939558386802673, 47.35467972074236, 55.701401301792686, 55.90208959579468, 48.76690455845424, 46.12286138534546, 41.656420367104666, 39.83651345116751, 41.43030514035906, 44.758124010903494, 43.68053136553083, 43.54372828347342, 40.76309047426496, 37.003687722342356, 36.664476667131694, 46.368914467947825, 51.45359577451433, 51.49181086676461, 47.43661635262625, 48.88535049983433, 46.28511224474226, 52.0082357270377, 49.08908905301775, 49.03792946679251, 45.0664781161717, 47.101209436144146, 45.994632380349294, 42.27722454071045, 36.3667185647147, 37.061131954193115, 38.43583304541451, 39.31650332042149, 37.10328320094517, 39.459045614515034, 37.41511835370745, 38.87989936556135, 37.440590449741904, 38.48154524394444, 36.03942019598824, 37.75400979178292, 37.544122082846506, 47.83112464632307, 50.56231907435826, 48.853590284075054, 44.61759669440133, 49.198349475860596, 45.797181946890696, 51.498720850263325, 47.955323696136475, 51.98984037126814, 46.939590862819124, 51.94291918618338, 30.158159187861852, 23.87328600883484, 54.83006593159267, 44.86005755833217, 51.38711541039603, 47.34102651051113, 49.005964279174805, 46.46739476067679, 47.22228874479021, 42.96990782873971, 40.23043114798409, 37.71402985709054, 38.98359080723354, 37.26306744984218, 37.58496012006487, 35.925938742501394, 36.83941841125488, 35.49673114504133, 36.852849279131206, 35.84541606903076, 38.12708289282662, 36.90779215948922, 37.02921887806484, 36.159474645342144, 37.40114900044033, 35.621906416756765, 37.26299796785627, 35.1206807409014, 36.25456421715872, 36.5021459034511, 38.71587324142456, 41.006301743643625, 45.15242385864258, 45.74286787850516, 45.48580190113613, 41.71007783072335, 42.17791741234915, 42.19482585362026, 46.663917609623496, 49.72003412246704, 51.409992354256765, 47.764626911708284, 47.02451522009713, 49.12041848046439, 48.47490651266915, 46.984003748212544, 52.28181757245745, 53.017093317849294, 53.042356967926025, 53.96580382755825, 56.28946556363787, 40.936851024627686, 20.572499104908534, 10.072246772902352, 11.793466687202454, 6.932595108236585, 4.515679861818041, 1.0881050527095795, 0.07151123987776892, 0.03432550899950521, 3.5731614998408725, 29.756435189928325, 45.98687471662249, 31.260900838034495, 23.192661319460186, 39.55353764125279, 40.349863733564106, 44.42352655955723, 49.42832442692348, 35.977536065237864, 5.783849435193198, 0.0652236154835139, 0.03053813347859042, 0.06642977254731314, 0.010094373786289777, 0.07899544042135988, 0.07475733105093241, 0.02672613731452397, 0.009771126488755857, 0.06206511639590774, 0.004964567197021097, 0.04446862704519715, 0.03476458561739751, 0.046186012748096666, 0.023145097507429973, 0.008466687020180481, 0.04060564575982945, 0.02180396456138364, 0.013529202019396638, 0.10098641432289567, 0.1261640600860119, 0.174937618630273, 0.21749846983168805, 0.1539885691766228, 0.10687449694211994, 0.15568804155503, 0.1139900019126279, 0.14375741460493632, 0.16760508423405035, 0.13470301617469105, 0.14878419201288903, 0.09715892720435347, 0.07517912877457482, 0.2127033035670008, 0.12770574593118258, 0.0774467588801469, 0.2591107019356319, 8.650026082992554, 57.8533695765904, 62.90760040283203, 57.25380604607718, 38.21770477294922, 27.238934346607753, 29.8788937159947, 31.409699984959193, 41.67267567770821, 21.922084195273264, 0.443006801285914, 0.1723308635077306, 0.17148695593433722, 2.1464585704462866, 7.006336339882441, 12.408794811793737, 18.018963166645594, 9.30134413923536, 50.918546267918174, 58.4458772114345, 59.79027026040213, 50.42058277130127, 49.58416209902082, 43.1244774545942, 41.56056301934378, 44.735083784375874, 48.038392884390696, 45.17546755926949, 46.51659842899868, 42.376246792929514, 38.84777436937605, 37.68972505841936, 47.77972534724644, 53.328431674412315, 53.01206977026803, 47.36823565619332, 48.83061606543404, 46.640661988939556, 52.759544440678184, 51.78890889031546, 50.93434994561331, 48.193952628544395, 49.55908257620675, 47.76364721570696, 45.94055802481515, 39.81441123144967, 39.46404136930193, 39.96833120073591, 42.459778036390034, 39.66850600923811, 41.54115322657994, 39.15579496111189, 41.979000908987864, 39.4085738999503, 40.15827757971627, 38.00545120239258, 39.44114705494472, 39.729361806597026, 49.16914619718279, 52.413895879473, 53.438042981284006, 45.427829606192454, 49.01178339549473, 45.57183797018868, 52.62506900514875, 49.37345102855137, 52.73136602129255, 49.0570022719247, 51.16334867477417, 31.192249161856516, 26.773511001041957, 55.90520238876343, 46.432935169764924, 53.40346874509539, 48.89237512860979, 50.62927886417934, 47.450380734034944, 48.82403612136841, 45.856769698006765, 41.29605899538313, 40.73028455461775, 40.6041921206883, 38.887500694819856, 39.6543664251055, 38.73722505569458, 39.480887276785715, 37.212098939078196, 38.90382548740932, 37.82590627670288, 39.734590326036724, 39.47510984965733, 38.0905179977417, 38.49653598240444, 40.46243149893624, 37.364691802433555, 38.91914973940168, 37.128953320639475, 38.7858624458313, 39.30468096051897, 41.7653785433088, 45.69936868122646, 47.54307665143694, 48.749593121664866, 47.83965703419277, 45.02665104184832, 44.627876554216655, 44.787521839141846, 48.021849223545615, 52.76496056147984, 52.78758042199271, 48.50856706074306, 47.13848304748535, 51.41410221372332, 50.272099767412456, 47.45920842034476, 53.855952807835166, 55.66033744812012, 56.69664389746529, 56.12971952983311, 57.95702975136893, 44.212478501456125, 22.186332872935704, 12.85893906865801, 19.257785286222184, 13.709460241453987, 5.721723420279367, 0.8833478284733636, 0.20037601861570561, 0.1282760410436562, 4.785958273070199, 37.05402742113386, 59.001218932015554, 41.359888621738975, 25.10978048188346, 45.451394421713694, 46.76012931551252, 51.98649133954729, 55.658207825251985, 43.823952606746126, 8.33827691418784, 0.2423064022191933, 0.10137991035091025, 0.1861902941018343, 0.11402361653745174, 0.14866449843559945, 0.1403651059206043, 0.23957293746726854, 0.16356936150363513, 0.14737078999834402, 0.1204609325421708, 0.09187761774020535, 0.16238797775336675, 0.11189299622284514, 0.10599438274013144, 0.10010725685528346, 0.11520472887371268, 0.10524309519678354, 0.14498887423958096], [0.05695806150989873, 0.041408342508865256, 0.016542549743982296, 0.0215365505178592, 0.01863903126546315, 0.05401907528617552, 0.08983616371239934, 0.0332588010600635, 0.04144801305873053, 0.03431797047544803, 0.0208643581052976, 0.009403270602758442, 0.09730430333209888, 0.05886071441429002, 0.06541470451546566, 0.07352813093789987, 0.11357980713780437, 0.07303995891873326, 9.64543456690652, 49.4591292653765, 46.074356010981965, 46.791191237313406, 31.891752106802805, 20.01465255873544, 19.76741133417402, 30.952817712511333, 30.096052714756556, 8.542008519172668, 0.02891945087217859, 0.07007933421326534, 0.11065336024122578, 4.131158300808497, 13.804425614220754, 3.928977446896689, 5.030862731592996, 16.616054126194545, 52.5244973046439, 53.79599332809448, 50.313028131212505, 44.510858467647004, 40.72307232448033, 40.62993172236851, 44.95084619522095, 47.1603490284511, 52.58850411006382, 50.766884463174, 49.63429682595389, 48.302403586251394, 41.42304079873221, 35.54687629427229, 39.727895736694336, 45.35765280042376, 49.56869888305664, 48.938271454402376, 48.82962247303554, 45.18303067343575, 48.234154905591694, 50.79287420000349, 49.52040542875017, 47.63455663408552, 49.98554563522339, 48.51684236526489, 48.52001769202096, 38.66220882960728, 36.54012475694929, 36.8155791418893, 38.23343549455915, 38.249788079942974, 38.50859110695975, 37.790296758924214, 34.49218838555472, 36.898075103759766, 36.77259063720703, 35.72436802727835, 34.70955583027431, 36.284236499241416, 43.74804353713989, 47.4612581389291, 45.68761232921055, 45.48501328059605, 49.628821645464214, 44.344827788216726, 47.332688672201975, 43.49545219966343, 48.88228981835501, 43.11659819739205, 49.998319898332866, 25.657218626567296, 24.516020434243337, 53.853750228881836, 42.08112553187779, 49.176559925079346, 44.4871129989624, 47.018425124032156, 42.399776867457796, 40.46720143726894, 36.989982400621685, 38.25369644165039, 36.10814135415213, 36.91622379847935, 36.336896896362305, 34.68686301367623, 35.68601744515555, 34.71566677093506, 33.83647298812866, 36.081863267081125, 34.91511828558785, 36.21583148411342, 34.084325654166086, 34.99650253568377, 34.190664359501426, 36.579145840236116, 38.490049839019775, 36.332797459193635, 35.263549600328716, 35.62091282435826, 36.55016837801252, 40.59478425979614, 46.94841854912894, 47.35359580176217, 49.93109260286604, 48.82459545135498, 47.66157817840576, 44.297774587358745, 45.232967376708984, 45.82298060825893, 48.89629738671439, 48.527563435690745, 47.173703466142925, 47.65078067779541, 50.676255634852815, 49.14308697836739, 50.32577460152762, 49.29982096808297, 49.68419531413487, 46.138112681252615, 52.10501023701259, 49.605156081063406, 46.729168142591206, 23.55331972667149, 16.950906923839025, 15.611745868410383, 6.7188016431672235, 2.573859202010291, 1.4325908763068063, 0.05102170451677271, 0.025153230376807705, 0.1943267025053501, 16.433238336018153, 33.24066495895386, 24.685243810926163, 20.25313557897295, 46.75165946143014, 43.01304571969168, 34.81821175983974, 46.40902294431414, 38.99520819527762, 11.914832609040396, 0.14758402641330445, 0.021638727713642374, 0.04900873199637447, 0.04582474374079278, 0.024559573303642016, 0.037049039998756986, 0.048507291224918196, 0.04887613607570529, 0.030286949992712055, 0.03325436683371663, 0.04492157631154571, 0.04984462267852255, 0.058269303292036057, 0.060651992580720356, 0.07940547234777894, 0.04902149524007525, 0.03096618390242968, 0.03700042975002101, 0.032817587056862454, 0.06652315253657953, 0.026749684176008617, 0.040513534631047926, 0.023069917523701276, 0.024183807395664707, 0.020221636164933443, 0.05820474747036185, 0.03937826072797179, 0.04221883223259023, 0.09098235863660063, 0.0156033741576331, 0.00729049660731107, 0.030884997187448398, 0.008688064159027167, 0.03645284181194646, 0.08213238923677377, 0.1121078882632511, 13.268430284091405, 57.182534899030415, 52.14612967627389, 52.781250613076345, 38.69046367917742, 22.185353176934377, 20.369696821485245, 25.21871086529323, 33.36692067555019, 9.606059125491551, 0.13202270785612719, 0.024350367386692336, 0.13607160773660454, 3.324267255408423, 15.514783757073538, 8.170806220599584, 5.28777584859303, 18.18529088156564, 53.27039337158203, 55.49621057510376, 52.711372579847065, 47.261813572474885, 43.17404590334211, 42.60885511125837, 46.79529414858137, 47.87589883804321, 55.21784836905343, 52.7296359198434, 51.89237104143415, 50.22923980440412, 41.08993026188442, 36.98954813820975, 41.16181632450649, 47.66529199055263, 51.56209536961147, 50.001241615840364, 48.19811807359968, 45.0820768220084, 48.661945070539204, 52.93403107779366, 50.400134222848074, 49.938308307102744, 51.870241028921946, 50.58887161527361, 50.212741306849885, 41.38734095437186, 38.26540068217686, 37.27896840231759, 38.65626117161342, 38.82080841064453, 39.084061758858816, 38.146006311689106, 37.50535460880825, 38.16499573843819, 37.71303973879133, 36.56589215142386, 36.82155111857823, 37.660546098436626, 47.282797132219585, 49.584127358027864, 47.1193824495588, 45.73800066539219, 48.74650812149048, 44.48382650102888, 46.184033325740266, 44.82581336157662, 50.70522614887783, 42.33032962254116, 49.96337740761893, 27.160713263920375, 26.335522617612565, 56.4899697303772, 44.74076393672398, 50.77932173865182, 46.818862438201904, 49.012328829084126, 44.58479077475411, 43.45268603733608, 38.904787812914165, 39.630145004817415, 36.62774501528059, 38.12573494229998, 38.842146328517366, 36.596134185791016, 35.95592369352068, 36.73121411459786, 36.614519119262695, 37.414121287209646, 36.854631492069785, 37.61070319584438, 35.58229126249041, 36.392652715955464, 36.30051612854004, 38.91768019539969, 39.71133470535278, 38.63438129425049, 36.38381808144705, 36.511102131434846, 37.80779927117484, 42.7999792098999, 47.68659169333321, 48.368519169943674, 50.78206280299595, 51.46594967160906, 50.3891213280814, 45.51695762361799, 45.6967978477478, 49.950617040906636, 49.53173794065203, 49.60618094035557, 46.57616533551897, 50.14720937183925, 51.801030022757395, 51.31687607084002, 51.02211959021432, 50.752088274274556, 50.43948187146868, 49.079163551330566, 51.27680580956595, 51.97540201459612, 47.34116547448294, 27.89112527029855, 12.205659883362905, 8.88899026598249, 6.2582398653030396, 5.072789030415671, 2.112493170159204, 0.22576446485306534, 0.04285246519637959, 0.23805565174136842, 18.6472453389849, 34.565554414476665, 25.9380943434579, 22.290642704282487, 50.948329721178325, 46.93041924067906, 41.456096853528706, 52.26153925486973, 47.12592070443289, 15.469721215111868, 0.10488176851400308, 0.015022792454276766, 0.03233331322137799, 0.03761048022923725, 0.0218497436227543, 0.010426883086828249, 0.12354324571788311, 0.0025734032179960714, 0.04233339947781392, 0.031614676783127446, 0.025712602771818638, 0.017452397350487963, 0.012414477549360266, 0.011068946848224317, 0.04265414298112903, 0.032600710301526954, 0.019477642873036008, 0.06006408269916262, 0.14793461188673973, 0.23115131365401403, 0.15522228154752934, 0.08817359685365643, 0.11584025834287916, 0.10512770353151218, 0.11876439143504415, 0.08365100489131042, 0.1107347369460123, 0.17640066226678236, 0.18364491925707885, 0.07136996888688632, 0.14303856103547982, 0.15687851767454827, 0.08256896545312234, 0.13942517207137176, 0.361359388168369, 0.3034625734601702, 17.67352131434849, 64.48693983895438, 57.34723499843052, 60.183274269104004, 43.20460755484444, 30.73773969922747, 29.683882100241526, 41.47759805406843, 42.22239977972848, 12.053765313965933, 0.2761729806661606, 0.1631953665720565, 0.20413876670811856, 8.5855633020401, 23.2781571660723, 10.35804876259395, 10.997760721615382, 19.706303664616176, 55.60304260253906, 58.571875844682964, 54.658761569431846, 48.917475496019634, 44.73404502868652, 45.18287781306675, 50.07971109662737, 50.60180916104998, 57.1240553855896, 53.70610795702253, 54.12425054822649, 53.209263120378765, 45.4269471849714, 39.41340637207031, 43.39970254898071, 48.61755650384085, 54.67321034840175, 51.809538091932026, 50.30076803479876, 45.764355182647705, 50.671548230307444, 56.090688024248394, 54.296176774161204, 51.242707524980815, 55.07494476863316, 52.69828912190029, 53.58034903662545, 42.365692479269846, 39.876118183135986, 40.100923674447195, 41.56427683149065, 41.33213056836809, 41.67602818352835, 39.89856433868408, 39.34032869338989, 39.819073472704204, 39.26025765282767, 38.71909373147147, 37.231331552777974, 40.009554862976074, 49.137566634586875, 51.804066385541645, 48.20348903111049, 47.13673210144043, 51.45137235096523, 45.669015475681846, 47.28875868661063, 46.235981532505576, 51.74389498574393, 43.64202444893973, 49.56570768356323, 28.550457205091202, 28.027586153575353, 56.39327165058681, 46.80319425037929, 53.182793957846506, 49.44901268822806, 51.729710238320486, 46.961818150111604, 46.021379470825195, 41.044666222163606, 41.36164999008179, 39.79446642739432, 39.68856545857021, 40.79208183288574, 38.08769008091518, 38.179969106401714, 39.42449222292219, 38.21280281884329, 39.74284478596279, 39.08094549179077, 39.90227467673165, 36.47841433116368, 38.82049921580723, 39.424478326525005, 41.121971879686626, 43.29284620285034, 40.45090096337454, 38.936294419424875, 39.11578723362514, 41.20000014986311, 45.84243209021432, 50.608135495867046, 50.22745411736624, 53.305186476026265, 52.87409244264875, 52.310284342084614, 48.55723571777344, 48.595291001456125, 51.69592809677124, 53.13680035727364, 51.19271176201956, 48.540639945438926, 50.736163003104075, 54.91446222577776, 52.886939661843435, 52.89769894736153, 52.601747376578196, 53.88036182948521, 50.75592367989676, 55.13952480043684, 54.73199905667986, 51.0936929838998, 25.769678694861277, 21.861581018992833, 24.427674089159282, 15.93710047858102, 9.605947954314095, 3.5699036632265364, 0.7195720023342541, 0.14565986394882202, 0.49349423072167803, 22.62469298498971, 46.25649956294468, 32.61816195079258, 28.61967168535505, 55.470276423863, 52.50851992198399, 46.918874808720176, 59.512008803231375, 53.740557125636506, 19.894745758601598, 0.23584254192454474, 0.08317934841449771, 0.1703657718109233, 0.10160460722233568, 0.07985568033265215, 0.07923855951854161, 0.22801165069852555, 0.11889176602874484, 0.13975656857447966, 0.10618917657328503, 0.1817667886082615, 0.1119932226304497, 0.10734098298209054, 0.1688407100737095, 0.1223497704735824, 0.17644992390913622, 0.12912055929856642, 0.11600227893463202], [0.015925174479239752, 0.052081637284053225, 0.04585115571639367, 0.02584762106250439, 0.040933144079255204, 0.06030152924358845, 0.03311337743486677, 0.16115222977740423, 0.1001175841582673, 0.024915536167100072, 0.09152273714010205, 0.02831114422796028, 0.03574394913656371, 0.009512561390043368, 0.03013923970450248, 0.05868388818843024, 0.03035260843379157, 0.33260855664099964, 18.955748830522808, 52.045755999428884, 47.95443432671683, 36.80776589257376, 20.478899921689713, 22.467364924294607, 32.032418387276785, 33.15529244286673, 28.69392360959734, 4.25283385174615, 0.04452476224728993, 0.08366207179746457, 0.16884826895381722, 1.207830114024026, 16.58260723522731, 6.066854774951935, 3.4970452870641435, 21.46771022251674, 54.74710444041661, 52.39116832188198, 49.269804750170024, 45.48615973336356, 44.25733259746006, 47.60091345650809, 48.91824327196394, 50.98988689695086, 43.2870375088283, 47.492639677865164, 51.41716636930193, 48.527271611349924, 46.1870835849217, 37.388284410749165, 38.11191497530256, 41.94755336216518, 48.338478633335654, 48.9742249080113, 49.67619446345738, 44.54340730394636, 46.47660459790911, 46.042720862797324, 50.05982187816075, 45.93360982622419, 48.99456923348563, 49.4458304132734, 47.030164105551584, 43.283115250723704, 37.31324734006609, 36.30883312225342, 37.80895962033953, 38.01620353971209, 37.80174739020211, 35.56205463409424, 38.42599787030901, 37.246895517621724, 36.65560729163033, 36.10463946206229, 34.571359634399414, 35.11641802106585, 39.451524189540315, 43.509056772504536, 49.36079488481794, 48.2797281401498, 48.06601544788906, 49.38458204269409, 49.78858504976545, 45.382742745535715, 54.04322760445731, 46.55613715308053, 53.21620437077114, 28.27971543584551, 28.822713681629725, 55.28662163870675, 42.720318113054546, 48.21659680775234, 41.767435210091726, 40.035853794642854, 34.85324110303606, 38.07447113309588, 36.373572962624685, 36.5315055165972, 35.92556701387678, 37.4988545690264, 34.68846109935215, 37.155766419001985, 34.85131297792707, 34.75303765705654, 34.58356067112514, 35.506580216544016, 35.76172501700265, 35.97188717978341, 35.12293543134417, 36.448339053562705, 40.735495703560964, 44.951169286455425, 43.650716645377024, 41.02104582105364, 36.43554741995675, 35.71115950175694, 43.671384062085835, 47.2268328666687, 47.229605197906494, 48.66090284075056, 46.00776447568621, 48.33188826697213, 47.78627749851772, 47.5481071472168, 47.668877261025564, 48.49697051729475, 49.61314998354231, 46.78332587650844, 47.88547692980085, 50.45997905731201, 49.568976811000276, 48.998838901519775, 49.694860798971995, 49.032502923692974, 46.492842538016184, 48.62773214067732, 50.92431327274868, 56.176786627088276, 51.071305888039724, 34.175774369921, 18.3285106250218, 11.835379958152771, 4.970545853887286, 5.323558637074061, 1.8479976143155779, 0.2652447942112173, 0.048198310126151354, 0.1763305560286556, 8.929809195654732, 36.44151244844709, 45.13028342383248, 21.640068973813737, 38.84145498275757, 40.582746505737305, 33.89271518162319, 44.198404925210134, 43.216992718832834, 22.90316983631679, 0.20428523527724401, 0.0399000168378864, 0.04167289313461099, 0.06786790716328792, 0.03144253584157143, 0.0706813440525106, 0.04368417949548789, 0.1756183249609811, 0.02986335415127022, 0.03618751087092927, 0.038261680464659414, 0.06557598550404821, 0.04531961852418525, 0.021879734870578562, 0.05316104061369385, 0.04170362737828067, 0.08113700550581728, 0.04863411620525377, 0.03422735212370753, 0.023841907170468142, 0.02275052260873573, 0.020978226459452083, 0.05004461408991899, 0.0519182867636638, 0.054601414395230155, 0.08106162026524544, 0.07318042245294366, 0.05162162446816053, 0.012418495324839438, 0.0705162293410727, 0.03894762847838657, 0.05664165045267769, 0.04023639718070626, 0.04391700182376163, 0.05828556099108287, 0.5003072108541216, 24.388976097106934, 57.33723654065813, 53.238671370915, 43.191378184727256, 28.093343905040197, 27.08746882847377, 32.859726497105186, 38.36284916741507, 31.716810362679617, 4.600781832422529, 0.027229074255696366, 0.0809179065482957, 0.4337162726691791, 5.69123602764947, 14.06841720853533, 6.389420986175537, 4.92570869411741, 23.721452236175537, 55.988403592790874, 53.07960973467146, 52.52090508597237, 47.354467800685335, 45.954475266592844, 50.212776047842844, 51.82255206789289, 52.48128298350743, 45.35126393181937, 49.2204030581883, 52.6140387398856, 50.73205314363752, 48.96071066175188, 39.7824147769383, 40.74836029325213, 45.5015013558524, 49.104423727308, 50.622163908822195, 50.13895491191319, 45.80981029782976, 46.1634909766061, 48.16982153483799, 51.18334559031895, 48.92817224775042, 51.15386438369751, 51.01547711236136, 49.156090532030376, 44.63858372824532, 39.42325891767229, 36.850087370191304, 40.291603088378906, 41.29618753705706, 40.12077815192086, 37.38707889829363, 40.29171773365566, 38.25356442587716, 38.05337987627302, 37.310026850019185, 35.89984825679234, 37.51883063997541, 41.352704184395925, 46.232903480529785, 50.16413170950753, 49.839317321777344, 49.69408260072981, 52.364223207746235, 51.66138512747628, 46.128412996019634, 54.20419304711478, 47.348096302577424, 53.531527519226074, 28.459507022585186, 30.40402466910226, 54.43753787449428, 43.50481489726475, 50.088632583618164, 43.1423134803772, 41.72118105207171, 38.14244883401053, 38.94353791645595, 38.19230910709926, 39.39216225487845, 37.851559025900706, 40.01520374843052, 37.435118743351524, 38.16093104226248, 36.61245550428118, 37.38549470901489, 34.9680392401559, 37.92381681714739, 37.04450144086565, 37.47585603169033, 36.66465384619576, 37.64332151412964, 42.436254910060335, 46.31557662146432, 46.1563378061567, 42.36637340273176, 37.900780064719065, 37.29180172511509, 43.992317880902974, 47.618697370801655, 49.80623000008719, 50.10514497756958, 48.12219163349697, 49.14643253598894, 48.55235808236258, 49.60042435782296, 49.49227564675467, 51.530206612178254, 50.93922063282558, 48.13116870607649, 48.935169083731516, 51.586177825927734, 52.06889350073678, 50.85444218771798, 50.661900656563894, 50.062649794987266, 49.65123306001936, 49.37918676648821, 53.72535446711949, 56.73489025660923, 53.02794292994908, 35.93974133900234, 19.08815543992179, 4.731809658663614, 3.5254015369074683, 6.173246894563947, 4.067557965006147, 0.2799388500196593, 0.03158095020002552, 0.09079738320516688, 9.54081380367279, 38.31466688428606, 33.79959889820644, 24.265487500599452, 43.34268910544259, 45.460013662065776, 38.87898220334734, 49.78248453140259, 49.10629626682827, 28.250213384628296, 0.7153923894677843, 0.09304402622261218, 0.05160897318273783, 0.0518205437942275, 0.02678406554540353, 0.08960774168372154, 0.02480487897992134, 0.05751558659332139, 0.017702154216489623, 0.03400543046050838, 0.09017392487398215, 0.036547005509159396, 0.07480860115694148, 0.010834804769339306, 0.045385256609214206, 0.03136103700048157, 0.0347546009745981, 0.016841259518904344, 0.09455299310918365, 0.09829327490712915, 0.10695801781756537, 0.058166837718869956, 0.13352370874157973, 0.1852769045425313, 0.15078775664525373, 0.20578821748495102, 0.20507838843124254, 0.11229740987930979, 0.19666027942938463, 0.18409998555268559, 0.09169379581830331, 0.10354009443627936, 0.15122089268905775, 0.1281068551221064, 0.2035875791417701, 0.9271628430911473, 32.34570918764387, 65.99940286363874, 58.074395247868125, 49.678466524396626, 29.594993795667374, 34.03839111328125, 42.899564266204834, 44.601181575230186, 38.724193709237234, 6.365068418639047, 0.16958180602107728, 0.2691008544393948, 0.4052578897348472, 6.0244108353342325, 28.87217617034912, 16.283777373177664, 6.510701792580741, 24.378937687192643, 57.42809118543352, 56.22368001937866, 54.03378847667149, 50.12554488863264, 47.46469054903303, 53.24677644457136, 54.64652579171317, 55.10243879045759, 46.569738251822336, 50.32650416237967, 56.19471992765154, 52.42307792391096, 51.50679465702602, 42.421180793217246, 42.563955851963584, 47.84421852656773, 51.295781339917866, 52.89355782100132, 51.042151246752056, 45.44106592450823, 47.03800514766148, 49.163472993033274, 52.7560772895813, 50.38505663190569, 54.17831795556204, 54.76760510035923, 50.48026084899902, 47.6578608921596, 40.64127465656826, 39.635727882385254, 42.06064919063023, 43.674135548727854, 41.10232932226998, 39.64115789958409, 42.519119126456125, 40.22318417685372, 40.53209066390991, 39.14397260120937, 37.87633282797677, 40.91932419368199, 43.66548156738281, 47.42093079430716, 52.73284598759243, 53.933585030691965, 50.49573796136038, 55.39369337899344, 54.67472505569458, 49.33201544625418, 57.31870916911534, 49.90531478609358, 55.299851008823936, 30.54360703059605, 33.77291086741856, 56.83895690100533, 45.64980370657784, 52.31985548564366, 45.0841578074864, 42.9602289881025, 38.99074050358364, 41.724842752729145, 41.16876104899815, 42.17452669143677, 40.73904275894165, 43.22834954942976, 37.92056853430611, 40.62073925563267, 38.714302948543, 40.684037344796316, 37.47991377966744, 39.15959562574114, 40.29331929343087, 40.48077474321638, 37.93558359146118, 40.12316138403756, 46.03878123419625, 49.33440562656948, 48.35769387653896, 45.198702335357666, 41.40009784698486, 39.41321529660906, 47.61827005658831, 51.70932074955532, 51.33560494014195, 51.67409685679844, 48.4518141746521, 52.08041361400059, 49.78073011125837, 51.71967009135655, 51.30383082798549, 54.50614786148071, 53.26075274603707, 48.36722680500576, 50.1423282623291, 53.83784927640642, 54.611847332545686, 54.0927335194179, 54.44246762139456, 52.854981422424316, 51.48434502737862, 52.50513962336949, 54.745860712868826, 57.84889841079712, 52.14568151746477, 37.911883286067415, 23.75539939744132, 19.200502599988663, 14.346919247082301, 11.786029509135656, 6.439347701413291, 0.36140669562986916, 0.17039589876575129, 0.400127323610442, 12.908255645206996, 51.06504556110927, 55.63336106709072, 32.5156169618879, 45.29954848970686, 49.27785423823765, 45.17540155138288, 56.41329288482666, 55.4310816356114, 35.00558383124215, 1.448811228786196, 0.1705561823078564, 0.09603294583835773, 0.20378510068569863, 0.09060191762234483, 0.25037364076290813, 0.15177613789481775, 0.21881305000611714, 0.05129097096089806, 0.08977360278367996, 0.1896843287561621, 0.13867267673569067, 0.11154623090156487, 0.11218619120440312, 0.11906559312982218, 0.1605479943432978, 0.18922395631670952, 0.202442592009902], [0.03360355452501348, 0.05443645913952163, 0.04343315546533891, 0.014901478874630161, 0.026571489005748714, 0.01570826718982841, 0.03420639556965657, 0.09204194535102163, 0.08458054358405726, 0.028957788100732223, 0.0038305765732989778, 0.018677527949746166, 0.07173069845885038, 0.08399126984711204, 0.0693738545690264, 0.054860048195613284, 0.0492692215900336, 1.001645143542971, 24.919879266193934, 49.40565592902047, 46.5163448197501, 37.579064573560444, 21.7267564364842, 20.29180751528059, 32.88196420669556, 33.39759349822998, 25.426182338169642, 2.6838758928435187, 0.10232725380254643, 0.11199042028082268, 0.2463180369564465, 2.550693690776825, 11.986103756087166, 7.414256828171866, 2.7975670950753346, 24.867752143314906, 54.91017171314785, 52.237019062042236, 51.05821200779506, 48.884985719408306, 49.07028375353132, 51.21057210649763, 50.12171990530831, 49.932892186301096, 43.190864018031526, 44.125695501055034, 49.768007959638325, 48.476164136614116, 47.094024998801096, 39.65429694311959, 38.02377012797764, 42.67434535707746, 45.86471496309553, 48.60946880068098, 47.52459096908569, 45.384733404432026, 45.443890367235454, 44.591124057769775, 43.16008349827358, 43.572236742292134, 42.991884980882915, 46.548271792275564, 48.84160116740635, 46.27289383752005, 39.147585664476665, 34.673473834991455, 37.25886378969465, 38.68778167452131, 38.63002824783325, 36.40601757594517, 36.62022706440517, 35.60141617911202, 35.71655477796282, 35.893466336386545, 36.542539255959646, 37.22597796576363, 38.215943404606406, 36.47113609313965, 42.125184059143066, 40.461330209459575, 42.950004713875906, 42.16117920194353, 46.81944261278425, 45.37722934995379, 49.11592994417463, 43.74094247817993, 53.99536146436419, 31.50718321119036, 31.297128745487758, 53.4975369317191, 42.77071687153408, 46.0139970098223, 38.12578010559082, 38.001185008457725, 38.77615928649902, 41.24874523707798, 43.46297631944929, 45.04540075574602, 39.70935794285366, 38.01610279083252, 34.4316417830331, 35.894664900643484, 34.31057637078421, 37.26630531038557, 35.924250330243794, 35.547105584825786, 36.656312533787315, 37.55584716796875, 33.99150466918945, 40.7563715662275, 48.57767036982945, 47.359810965401785, 46.646852833884104, 44.51852233069283, 42.16140154429844, 41.83935601370675, 45.57018082482474, 46.90272372109549, 48.13243327822004, 43.65387807573591, 45.066349574497764, 45.84370013645717, 48.134674072265625, 48.43799420765468, 48.96708910805838, 51.41505759102957, 45.16673714773995, 43.16079568862915, 50.56602941240583, 47.45801680428641, 46.10096761158535, 44.53296068736485, 47.61213479723249, 43.77330718721662, 48.68330035890852, 46.27733373641968, 54.09697192055838, 43.063117912837434, 39.36426176343645, 39.01108135495867, 27.30349005971636, 9.408659934997559, 2.6861553362437656, 2.5981485843658447, 1.3835477765117372, 0.3508670926094055, 0.18718426647995198, 0.14760616022561276, 3.4268270092351094, 20.579721757343837, 54.029755047389436, 29.108604260853358, 25.86513999530247, 37.924772194453645, 31.680012702941895, 40.034071581704275, 43.93070820399693, 31.94983557292393, 2.2565158648150305, 0.07944637443870306, 0.053250932932964394, 0.05275630126042025, 0.049651443758713346, 0.0581096372167979, 0.02144474981884871, 0.035848463885486126, 0.06963819145624127, 0.03605936953265752, 0.078198053208845, 0.039491593039461544, 0.0457355231711907, 0.020540478073858788, 0.05536330744091954, 0.014007902537871684, 0.04822599435491221, 0.01174712902866304, 0.037860798582966836, 0.04743677331134677, 0.08177518804690667, 0.008306332231898392, 0.05018991218613727, 0.01347469275684229, 0.0337396957911551, 0.05014630952583892, 0.07530932607395308, 0.04290978783475501, 0.009435087109782865, 0.005244268661564482, 0.02196534733021898, 0.01470534154213965, 0.0171890392500375, 0.08515849257154123, 0.06061751621642283, 1.4118278133017677, 32.4019444329398, 56.4659880229405, 52.780392510550364, 43.0119618007115, 25.662099736077444, 28.751303570611135, 36.93150288718087, 34.09764882496425, 29.544119085584367, 2.3519398186888014, 0.04920598891164575, 0.17958076590938227, 1.341352669256074, 8.192923205239431, 13.813506041254316, 8.989283170018878, 5.447934431689126, 27.24801390511649, 56.38568769182478, 55.68114382880074, 52.793548924582346, 51.215446267809185, 52.68657445907593, 53.011972495487754, 51.35422958646502, 48.860305718013215, 44.50193003245762, 44.872251646859304, 51.262138162340435, 50.81902721949986, 48.465015751974924, 42.17646523884365, 40.47316646575928, 44.08591706412179, 47.91197735922677, 49.65428679330008, 49.01401029314314, 45.820812770298545, 46.58401332582746, 43.719455174037385, 42.951453413282124, 43.99577808380127, 44.323938029153005, 48.40338870457241, 49.4616653578622, 47.01150819233486, 39.53826550074986, 37.244717257363455, 40.23200144086565, 40.071220125470845, 40.31567512239729, 38.609270504542756, 38.16174398149763, 37.66055652073452, 36.79709345953805, 36.318331309727256, 36.41804838180542, 38.13979809624808, 40.19717706952776, 38.02353388922555, 44.57728672027588, 41.69719934463501, 46.195129598890034, 44.22228935786656, 48.982931000845774, 47.42891080038888, 49.63966430936541, 45.71162530354091, 54.23036691120693, 32.25466346740723, 32.74585941859654, 55.25269358498709, 44.702069418770925, 48.134159905569895, 38.78134959084647, 39.9200690133231, 39.08126858302525, 43.93087148666382, 44.842443874904085, 46.316271441323416, 40.59956462042672, 39.441671643938335, 36.33525364739554, 37.56891672951834, 36.823135307856965, 38.68254273278372, 36.60503135408674, 37.39334617342268, 37.6976112638201, 38.75270216805594, 36.72985921587263, 41.99694115774972, 51.54394667489188, 48.91863931928362, 47.47012751443045, 45.95185579572405, 42.72341353552682, 44.081911427634104, 48.68661117553711, 48.37017978940691, 50.264022486550466, 44.01442010062081, 46.637041977473665, 45.87415061678205, 48.422669955662315, 50.04707540784563, 50.810397556849885, 53.42721421377999, 46.34465830666678, 44.92382117680141, 51.67768212727138, 48.923461369105745, 48.90893963405064, 47.65686729976109, 50.36332614081246, 44.896605082920615, 50.63225964137486, 48.20948532649449, 55.781830174582346, 43.12230266843523, 41.574226651872905, 41.84010641915457, 27.80658480099269, 8.747526679720197, 2.298242837190628, 5.006869733333588, 4.643895838941846, 1.5373604829822267, 0.2847989520856312, 0.12689644364374025, 3.0849810668400357, 25.985753774642944, 53.40566437585013, 27.542617525373185, 30.409225395747594, 39.461394105638774, 34.3456369808742, 47.18492133276803, 49.94455473763602, 39.287842001233784, 3.0481271701199666, 0.1597238728510482, 0.0311701515290354, 0.08991882284837109, 0.07661783335996525, 0.0412882825226656, 0.023976109522793974, 0.01910853508992919, 0.09382212268454687, 0.07117955160460301, 0.041126116045883725, 0.02637746530984129, 0.014713455124625137, 0.04724482593259641, 0.043153307267597744, 0.06527936392064605, 0.05091383780485817, 0.13555361410336836, 0.11552974714764527, 0.14142983593046665, 0.12993718976421015, 0.07742940195436988, 0.11710806031312261, 0.10438345918165785, 0.08514668606221676, 0.23447393679193088, 0.16153998539916106, 0.11816091596015862, 0.07571206374892167, 0.12391790561378002, 0.13860582746565342, 0.12589745010648454, 0.0997361864096352, 0.18152791714029654, 0.1446489281952381, 2.186944855110986, 41.06813376290457, 62.414702142987935, 60.42386259351458, 49.13557250159127, 32.60104158946446, 30.693246909550258, 43.048651763371055, 43.12433154242379, 33.91667604446411, 3.5097281379359107, 0.18769252992102078, 0.3515222045992102, 1.516645080276898, 10.105085696492877, 20.65441141809736, 12.345847606658936, 5.851512295859201, 29.253906726837158, 58.993819100516184, 58.001310620989116, 55.67848266874041, 52.400030749184744, 53.820124421800884, 54.80500030517578, 53.03510652269636, 51.18113258906773, 45.17780910219465, 47.4609489440918, 51.230617659432546, 52.92571060998099, 50.29831184659685, 42.88104384286063, 40.992863927568706, 45.87813540867397, 50.01355382374355, 52.06021867479597, 49.114001819065635, 47.094184807368684, 46.918541295187815, 44.32223572049822, 43.11567061288016, 43.799060685294016, 43.804914542606895, 50.21544763020107, 51.718912737710134, 50.09386110305786, 42.69659348896572, 39.465597765786306, 42.4286014693124, 41.48178781781878, 42.239207472120015, 40.899712903159006, 39.16966009140015, 39.05688040597098, 38.11853313446045, 39.366683210645405, 39.99497059413365, 40.54336411612374, 41.88057272774832, 39.093691962105886, 46.35553223746163, 43.986220836639404, 45.6739695412772, 45.79030670438494, 50.49819762366158, 50.44320263181414, 50.88112327030727, 48.22202335085188, 56.14526265008109, 35.04157897404262, 35.82419627053397, 55.589222635541645, 47.28579180581229, 49.252733026232036, 42.16421556472778, 41.97655514308384, 43.40152645111084, 46.93732575007847, 47.33694791793823, 49.98073400769915, 42.6691654750279, 41.92221328190395, 38.792574405670166, 40.21389443533761, 39.297600746154785, 41.17360046931675, 38.87510163443429, 39.61077342714582, 41.038002899714876, 41.458452292851035, 38.13161659240723, 44.119042600904194, 54.07481064115252, 50.105662618364605, 50.07590348379952, 47.89013917105538, 45.695033005305696, 46.107943602970664, 50.419471059526714, 51.12601947784424, 52.144396100725444, 45.398879936763215, 47.05435773304531, 48.52528095245361, 50.457786900656565, 52.74012769971575, 53.53596741812569, 55.32860960279192, 46.08280502046858, 44.889799322400776, 52.0203811781747, 51.720295429229736, 51.30515793391636, 50.15750312805176, 52.34840215955462, 48.077090876443044, 53.218695299965994, 51.37563351222447, 57.99922268731253, 49.42434310913086, 44.21102285385132, 42.15552684238979, 30.83365958077567, 12.55728997503008, 8.425556710788182, 11.271633522851126, 5.827815464564732, 2.1377492206437245, 0.550029171364648, 0.17628403566777706, 4.347202982221331, 32.301199027470176, 63.761631284441265, 36.07164246695382, 33.341882841927664, 45.42658240454537, 42.141953536442344, 53.70918600899832, 57.34175286974226, 47.01521853038243, 4.935544303485325, 0.22094721905887127, 0.09768639997180019, 0.18518702579396112, 0.12827932515314647, 0.14570628931479795, 0.10295089533818619, 0.14441677422395774, 0.26700100568788393, 0.09864795873207705, 0.1493044655237879, 0.09728671570441552, 0.10908801387995481, 0.14247236427451881, 0.12116579471954278, 0.09473853172468287, 0.1302445661276579, 0.20558946100728853], [0.013651434165824736, 0.04647498384916356, 0.04017973950664912, 0.035680258447038274, 0.0331675822048315, 0.01506349946638303, 0.06622749447290387, 0.034477341387953074, 0.028789776044764688, 0.021914779507954205, 0.017508077934118252, 0.0646955795320017, 0.027162097760343125, 0.0807413924485445, 0.005742760350195957, 0.01144997394710247, 0.05400942651821034, 4.4726123213768005, 41.92699016843523, 45.165121691567556, 46.45103175299508, 27.503365414483206, 16.088470458984375, 16.9860873903547, 32.24086781910488, 42.16615411213466, 20.973524808883667, 0.7117710752146584, 0.011383797274902463, 0.06732850575021335, 0.36165213531681467, 6.735796502658299, 10.946807844298226, 6.816566705703735, 4.406649163791111, 25.88028880528041, 57.01816831316267, 52.29943125588553, 55.144409384046284, 50.326191493443076, 52.71657330649239, 50.043681212833945, 50.634889534541536, 50.00548696517944, 53.7835282598223, 46.386218956538606, 48.67729016712734, 48.390145438058035, 47.39616741452898, 39.46923862184797, 41.830847944532124, 45.99413211005074, 46.23051677431379, 49.32499776567732, 47.70900310788836, 44.9464236668178, 45.026821272713796, 47.237161363874165, 47.007235050201416, 44.26365893227713, 44.12385422842843, 46.21699905395508, 47.97287484577724, 44.59458078656878, 39.44445787157331, 34.64646618706839, 38.61943571908133, 37.43747418267386, 39.983186449323384, 35.900633403233115, 34.978888852255686, 35.82813242503575, 35.54308952604021, 34.76470020839146, 35.748426164899556, 34.55594852992466, 36.24680655343192, 34.58312293461391, 34.861492088862825, 34.550813811165945, 35.05907801219395, 34.425607272556846, 38.656278542109895, 39.05867304120745, 44.19158526829311, 44.1690731048584, 51.460773263658794, 33.24309682846069, 36.19261755262102, 52.16406297683716, 42.99344137736729, 46.0004688671657, 41.92926222937447, 45.56126281193325, 45.62121534347534, 48.97633368628365, 45.78390393938337, 48.713660512651714, 46.3404928616115, 43.23696878978184, 36.49487461362566, 35.071087973458425, 34.021562576293945, 35.07116092954363, 37.003611292157856, 36.56904315948486, 33.96505635125296, 35.790434973580496, 36.29845598765782, 44.95268399374825, 48.75564847673689, 48.64906311035156, 48.40891252245222, 45.20593888419015, 46.323858874184744, 45.456779275621685, 47.54366724831717, 48.017940861838206, 44.40441901343209, 45.38537958690098, 44.095887729099815, 42.42477996008736, 44.00112124851772, 43.37343488420759, 46.24881138120379, 47.31788553510393, 45.724312714168, 49.01785959516253, 49.204366615840364, 48.20672689165388, 46.99453026907784, 41.96168599809919, 42.83746474129813, 41.177599157605854, 49.312852314540315, 50.001005377088276, 51.7461496761867, 25.244683231626237, 31.43878514426095, 46.73154442650931, 34.61992059435163, 14.739498547145299, 2.3459606766700745, 6.240508496761322, 5.166190189974649, 0.6759551742247173, 0.21576226156737122, 0.2465339739407812, 0.7571736446448735, 18.40289282798767, 36.0019485609872, 59.35990578787667, 21.945607321602957, 24.938434430531093, 40.389864512852256, 38.60036986214774, 40.78384821755545, 39.16252081734793, 7.3705830574035645, 0.2551613838544914, 0.05550731632060238, 0.011672647087834775, 0.04248218524402805, 0.02464489060054932, 0.04210823780990072, 0.058275226902748854, 0.013557267924105483, 0.010130054550245404, 0.03900236929101603, 0.014212390091935439, 0.024268201884946654, 0.021816510673878447, 0.020116592158696482, 0.039976382561560185, 0.00836298312060535, 0.04167058611554759, 0.020410597989601747, 0.014372839026951363, 0.01930067585115986, 0.04021362215280533, 0.024800529570451806, 0.036659978197089264, 0.03469266429809587, 0.03202541438596589, 0.0207633734348097, 0.030469815180237805, 0.03594919240900448, 0.011257634714378842, 0.019544787305806364, 0.04943038383498788, 0.041456362432135005, 0.02714125994992043, 0.03774139338306018, 6.584858179092407, 49.66901697431292, 50.378553118024556, 52.73686899457659, 34.57264157703945, 23.66039146695818, 19.44495759691511, 31.975912162235804, 45.99083171572004, 22.433610575539724, 0.6968547041927065, 0.08931775617280177, 0.12284833086388451, 2.7682198584079742, 11.906200340815953, 8.701546107019697, 8.361555116517202, 4.6445954356874735, 26.826369421822683, 58.96592903137207, 52.86673430034092, 57.70808621815273, 52.051595960344585, 54.2891834122794, 50.33734335218157, 53.399709769657676, 49.54171207972935, 53.48319237572806, 48.10708972385952, 50.593506063733784, 49.62809555871146, 49.54892430986677, 42.17485325677054, 44.1430937903268, 47.0595132963998, 48.12745141983032, 51.146544456481934, 48.84808383669172, 45.601159368242534, 45.59725100653512, 47.04190656117031, 47.48691783632551, 44.27641235079084, 44.34442479269845, 46.547372000558035, 49.945187023707796, 46.06389202390398, 40.746025698525564, 36.70288283484322, 41.12283345631191, 39.69329718181065, 40.810348646981375, 37.353581632886616, 35.82341112409319, 37.629418168749126, 36.607348578316824, 36.302294867379324, 37.50819294793265, 37.07621649333409, 37.723795550210134, 36.3027777671814, 36.43135418210711, 35.43000411987305, 37.49099963051932, 36.46396902629307, 39.78447144372122, 39.95447996684483, 45.814458642687114, 46.29918234688895, 52.61371564865112, 33.416402271815706, 36.641290528433665, 53.29240526471819, 46.83127539498465, 48.769607407706125, 43.09419025693621, 47.354238510131836, 46.93764884131295, 49.838400159563335, 48.730006149836946, 50.33072171892439, 48.19059317452567, 45.516804763248985, 37.8396498135158, 37.78136484963553, 36.36426585061209, 37.21630259922573, 37.32181099482945, 37.4661146572658, 37.28337008612496, 38.56286001205444, 37.88634865624564, 47.054336888449534, 50.54272515433175, 50.283331530434744, 50.19276871000017, 46.97574928828648, 47.163764068058555, 48.047592299325125, 48.68544387817383, 49.80411079951695, 45.31064823695591, 44.087845189230784, 43.461034297943115, 42.13028403690883, 44.88275037493025, 45.288834367479595, 47.76391472135271, 47.67694411958967, 45.71167394093105, 50.079193455832346, 52.05969755990164, 50.278617177690776, 48.59332466125488, 44.6107040813991, 44.81615536553519, 44.58422449656895, 50.779488495418, 51.65594468797956, 53.831290176936555, 29.76340423311506, 34.34366716657366, 47.64530897140503, 35.72730711528233, 16.134710720607213, 3.1838899765695845, 3.0142093215669905, 4.67878144127982, 1.7000373538051332, 0.5309537606579917, 0.03936260353241648, 0.7332271124635423, 20.352757113320486, 50.025921617235454, 55.9805451801845, 23.01096245220729, 32.78159747804914, 42.883392333984375, 45.078887598855154, 46.556196212768555, 47.18195097787039, 10.813160112925939, 0.2011605543749673, 0.014110222226008773, 0.040814634545573165, 0.04267156436773283, 0.04294203860419137, 0.01895061624236405, 0.045847871606903415, 0.03854893487212913, 0.03696319853354778, 0.06947374849447183, 0.053039772835161, 0.053505617659538984, 0.045611816059265814, 0.045223018886255364, 0.052321255140538724, 0.041083015501499176, 0.03998110177261489, 0.09249300829001836, 0.10951079547937427, 0.265068239399365, 0.15185205239270413, 0.12918533225144657, 0.13414224769387925, 0.15851812969361032, 0.109679214656353, 0.06677229023937668, 0.12274631990918092, 0.12396054475435189, 0.07061016572905437, 0.17438241413661412, 0.1405240459633725, 0.13259981546018804, 0.12047419111643519, 0.12109722197055817, 9.717714939798627, 57.77973256792341, 56.400938987731934, 59.27007252829415, 39.36210782187325, 25.375062704086304, 26.310927731650217, 41.47117444447109, 55.13106189455305, 27.818702459335327, 0.8704267303858484, 0.16954261383840016, 0.3720525843756539, 2.202466696500778, 16.626782144818986, 21.23803230694362, 16.982962438038417, 8.389894212995257, 31.012697287968226, 60.5858667918614, 55.04989998681204, 60.89123317173549, 54.3484445980617, 54.44821378162929, 52.67050674983433, 52.46957179478237, 52.40619032723563, 55.20630046299526, 48.543103081839426, 53.14636107853481, 51.773640223911826, 51.258323601314, 44.06828253609793, 46.19595643452236, 49.0986601965768, 49.58921691349575, 51.33247825077602, 49.38686105183193, 46.60098777498518, 46.506822313581196, 47.82391936438424, 47.57435049329485, 43.49915558951241, 44.02038860321045, 48.43391561508179, 51.520103931427, 48.22083173479353, 42.26259510857718, 38.44644294466291, 42.56889602116176, 41.08666808264596, 42.45878791809082, 40.52857834952218, 38.70987694604056, 40.1603307723999, 38.4500594820295, 39.055094718933105, 40.56386130196707, 38.293950830187114, 39.167780603681294, 37.72649839946202, 38.74199499402727, 38.813068117414204, 38.32810122626168, 38.34144524165562, 42.71456847872053, 42.87793104989188, 48.349078110286165, 48.558545453207834, 53.96577256066458, 35.55444983073643, 38.90186262130737, 56.45912667683193, 48.2422182900565, 50.86174821853638, 46.49254029137747, 50.13883679253714, 48.55239977155413, 53.246307441166465, 51.64527920314244, 52.871976716177805, 51.7891902923584, 48.08276060649327, 40.661073548453196, 39.06027112688337, 38.729804379599436, 39.216744559151785, 40.29632438932146, 40.7663700239999, 38.75186143602644, 41.023390838078086, 40.810932295663015, 50.432714326041086, 53.36922107424055, 52.38975088936942, 52.584613118852886, 48.057865210941856, 50.840479782649446, 50.20267684119088, 51.30849654333932, 51.04665715353829, 45.17696837016514, 44.99770484651838, 43.13955504553658, 42.48165096555437, 45.420610427856445, 45.40062393460955, 48.53284059252058, 47.358702727726524, 46.74418667384556, 51.05136455808367, 54.53784901755196, 52.109926087515696, 50.77192538125174, 45.972724710192, 46.93141630717686, 47.00781522478376, 53.60623107637678, 53.98981332778931, 56.914841651916504, 31.113776206970215, 36.56498541150774, 48.37238584245954, 39.96940469741821, 19.152217830930436, 5.258196064404078, 11.914357525961739, 12.381812351090566, 1.183222200189318, 0.2863174048917634, 0.5654888046639306, 0.9533437639474869, 25.930760519845144, 48.99317264556885, 65.57253333500454, 28.230543034417288, 35.79594142096383, 49.9310439654759, 52.140539850507466, 52.25007472719465, 56.15331213814871, 15.47101879119873, 0.36614653414913584, 0.24360625818371773, 0.11111308807241065, 0.12883856014481612, 0.09096503563757453, 0.12673510158700602, 0.2070564672883068, 0.10997055045195989, 0.08478128138397421, 0.12217864394187927, 0.15620043048901217, 0.14804981356220587, 0.11636739862816674, 0.10291099069373948, 0.12237814680806228, 0.22993670882923262, 0.09847168890493256], [0.03946935744690044, 0.04942935924710972, 0.062494126946798394, 0.00953560443927667, 0.013197463704273105, 0.025551752652972937, 0.013556015178827303, 0.01429628161713481, 0.05227335396089724, 0.04281596679772649, 0.06566868017294578, 0.04861608752980828, 0.054610656042184146, 0.07194949886096375, 0.015421009389683604, 0.14677355704563005, 0.039609234048319716, 18.249610355922155, 48.27530213764736, 47.491791997637065, 44.05913870675223, 27.671940871647426, 16.945553336824688, 27.98169677598136, 35.85888862609863, 33.748390674591064, 17.08333264078413, 0.1266209448554686, 0.9706464069230216, 2.0418838390282223, 2.9759191019194464, 9.082673907279968, 9.78308880329132, 7.700400148119245, 2.516870294298444, 19.2786420413426, 56.154309204646516, 49.681825978415354, 52.18238190242222, 51.184457302093506, 53.47073425565447, 48.51143666676113, 50.83181537900652, 47.79248571395874, 51.277420725141255, 49.25872932161604, 50.5726614679609, 46.670553139277864, 46.585538455418174, 42.30706705365862, 45.503901958465576, 46.599886485508506, 49.042049748556956, 46.73605728149414, 44.70108624867031, 46.02022606985909, 48.84813594818115, 47.85516193934849, 50.12823384148734, 45.70864452634539, 46.14292083467756, 43.32986273084368, 49.92716339656285, 46.98905856268746, 41.56321723120553, 34.837260246276855, 37.77575070517403, 38.05918857029506, 38.200490610940115, 34.60614579064505, 34.6499993460519, 33.33907576969692, 35.361540045057026, 32.74121107373919, 35.10957057135445, 33.08025189808437, 35.79857478822981, 35.93057319096157, 42.6003018787929, 38.44234350749424, 41.555994578770225, 39.948747703007285, 42.96365097590855, 40.589048521859304, 48.14105599267142, 43.05048261369978, 51.825279235839844, 28.28100606373378, 33.20997823987688, 52.332511629377095, 43.269309180123464, 48.09484004974365, 44.286747796194895, 46.64095728737967, 45.19763926097325, 50.12563868931362, 45.28647197995867, 48.02671296255929, 46.45258467538016, 44.469714709690635, 42.800555910382954, 37.35639565331595, 34.08191115515572, 34.886036600385395, 35.00221395492554, 38.62001936776297, 35.423563139779226, 35.34313079289028, 36.565520422799246, 44.4394657271249, 47.215232849121094, 46.89076934541975, 45.93485355377197, 47.2273713520595, 47.00930213928223, 48.04977403368269, 47.430779865809846, 45.18245397295271, 41.94973857062203, 45.25476734978812, 46.2172144481114, 45.39001750946045, 45.1340389251709, 44.37468767166138, 44.88652672086443, 44.51142127173287, 45.26173291887556, 50.386474064418245, 48.298700196402415, 48.68020841053554, 45.396305629185264, 44.60026093891689, 41.63459954942976, 42.83934422901699, 43.37251772199358, 48.99827609743391, 47.53190047400338, 55.16105726787022, 51.70421034949166, 47.70723826544625, 45.170600346156526, 24.081269911357335, 5.621307185717991, 1.2984690389462878, 5.675550035067967, 3.5870622396469116, 6.9423629726682385, 0.06771202052810363, 0.06597944921148674, 9.358406220163618, 25.786687885011943, 37.62156670434134, 39.19120298113142, 15.979958704539708, 25.755011047635758, 37.42319563456944, 41.776704107012065, 40.70816149030413, 13.88658024583544, 0.5470902462090764, 0.0534760878155274, 0.0028462118269609554, 0.0335713648237288, 0.032230189469243796, 0.011882154952867754, 0.07752938408936773, 0.06060089210846594, 0.039195154660514424, 0.04415550009746637, 0.030305192406688417, 0.0330233969060438, 0.049713570425020795, 0.04858164848493678, 0.03606056036161525, 0.03522650511669261, 0.05345338064112833, 0.018307548249140382, 0.009569348833922828, 0.014305757358670235, 0.010672226930702371, 0.03416904221687998, 0.031491519284567664, 0.055549405847809145, 0.04541048114853246, 0.03496637514659336, 0.016304799555135623, 0.1112069430361901, 0.04123423720843025, 0.09203030847545181, 0.04019196670768516, 0.0213281079528055, 0.11345486169947044, 0.06952045884515558, 23.141366243362427, 54.4077023097447, 52.64617763246809, 48.18146324157715, 35.489984444209504, 19.45022085734776, 24.36599145616804, 37.10334573473249, 38.21646104540144, 18.830556188310894, 0.03169268456154636, 1.1578126379421778, 3.8908331394195557, 4.359349301883152, 12.914136426789419, 11.57883596420288, 9.295215828078133, 4.2182387709617615, 20.899964230401174, 56.99008369445801, 49.94563518251692, 54.82508407320295, 50.96865667615618, 55.38781520298549, 50.49477563585554, 53.00491312571934, 48.862612519945415, 52.41970109939575, 50.03701441628592, 51.72650711877005, 48.46675974982125, 49.731390953063965, 45.35735402788435, 47.13319894245693, 47.69889347893851, 50.2708351952689, 47.34659896578108, 45.29477507727486, 45.99542447498867, 49.411596638815745, 49.75388922010149, 50.66841459274292, 46.73929861613682, 45.11354521342686, 44.176702226911274, 50.50716079984392, 49.34761415209089, 42.957480975559776, 36.99570076806204, 38.29245696749006, 39.913805212293354, 39.26481219700405, 36.82466738564627, 37.02275357927595, 35.13970143454415, 36.89057799748012, 35.29473311560494, 37.08718075071062, 34.839549677712576, 38.332051277160645, 37.0169483593532, 42.13472740990775, 38.59129204068865, 42.27377823420933, 41.181570053100586, 43.20189080919538, 42.064633982522146, 48.714820861816406, 44.042303221566335, 53.987822668892996, 29.880022798265728, 33.9867798941476, 54.73355197906494, 44.70646415437971, 48.965942655290874, 47.49145153590611, 48.20391634532383, 47.26673984527588, 52.012887545994346, 47.42020123345511, 47.583195550101145, 47.930251121520996, 46.282878398895264, 44.26973860604422, 39.201402936662944, 36.56221655436924, 36.29228598730904, 35.7251010622297, 40.772352422986714, 37.20183992385864, 37.37252242224557, 37.511903285980225, 47.149249281202046, 49.538929326193674, 48.75614179883684, 49.67842483520508, 49.36032935551235, 48.389794554029194, 50.50924178532192, 49.39145033700125, 46.15494816643851, 42.28414494650704, 44.295981952122276, 46.95586354391915, 46.3680077280317, 44.22813279288155, 44.028076784951345, 44.403738089970176, 44.224398136138916, 45.70588261740548, 51.11364126205444, 48.77837256022862, 51.31248133523123, 46.72513471330915, 46.11342225755964, 42.996258871895925, 43.22804730279105, 46.333857331957134, 51.139179365975515, 49.822923047201975, 56.27564559664045, 53.228096212659565, 49.82803692136492, 44.8336752482823, 25.65803156580244, 6.916498737675803, 5.058788844517299, 7.039897441864014, 4.43787784235818, 7.333362426076617, 0.07099186881844487, 0.050832301644342284, 10.20937989439283, 30.09329775401524, 40.29351731709072, 40.57895278930664, 21.596109458378383, 34.17567709514073, 42.876419816698345, 45.93491261345999, 47.8201082774571, 19.579386132104055, 0.6925312961850847, 0.07330195486013379, 0.029480653615402322, 0.07269086622233902, 0.001121154543527934, 0.05508088420278259, 0.04330317529716662, 0.027127870757664953, 0.030887514552367584, 0.02477633810069944, 0.032637673496667824, 0.06486590539238282, 0.07945208770356008, 0.05867991875857115, 0.033831786563886065, 0.07488446137202637, 0.010637745477392204, 0.07305821829608508, 0.23619557012404713, 0.09558013227901288, 0.11672296454863888, 0.10868060788405792, 0.13972945431513445, 0.16424462598349365, 0.11167389726532356, 0.14519650595528738, 0.13098133302160672, 0.21111460881573813, 0.12551669696612017, 0.14075656634356293, 0.14325798568981035, 0.0994765381993992, 0.22828971434916767, 0.1332518740424088, 30.120680604662212, 61.403773988996235, 60.702742440359934, 56.00631604875837, 38.53226709365845, 25.015206813812256, 37.12192521776472, 45.42480366570609, 45.89195537567139, 21.573234251567296, 0.18510534374841622, 1.4973493899617876, 3.934489973953792, 4.8725059032440186, 16.745563336781093, 19.55918424470084, 14.331263218607221, 5.6373588272503445, 22.095231567110332, 56.4345508984157, 50.71203885759626, 54.37547309058053, 53.43030963625227, 55.6811021396092, 50.74084608895438, 54.83922365733555, 50.58686705998012, 54.670629092625205, 51.21107932499477, 52.86042881011963, 49.55208921432495, 50.68229014532906, 47.67018699645996, 50.567161968776155, 49.289829458509175, 52.41191564287458, 47.481425285339355, 45.229184082576204, 46.95946271078927, 52.19028895241873, 52.84233570098877, 52.42180640356881, 47.03947121756417, 46.16024269376482, 44.995033264160156, 54.92207397733416, 51.39406360898699, 44.40869910376412, 38.64595351900373, 41.30100263868059, 42.46898439952305, 40.94304534367153, 39.073031493595664, 38.496848651341026, 36.0582845551627, 38.619741439819336, 37.598613330296104, 38.30976145608084, 36.641366958618164, 40.27633442197527, 39.02243818555559, 45.06481749670846, 41.36197655541556, 44.98847763878958, 42.811645235334126, 47.07924965449742, 42.800847734723774, 52.36283356802804, 46.05530057634626, 53.87688078199114, 31.16399778638567, 37.555593558720176, 56.1819143976484, 46.96139430999756, 50.604817731039866, 50.11512606484549, 49.4853378704616, 48.719879150390625, 54.40749733788626, 47.831395626068115, 49.8326644216265, 51.64156539099557, 49.038196972438264, 46.387803145817344, 41.15405518668038, 39.8250732421875, 38.21508182798113, 38.49652903420584, 43.12384169442313, 39.72113166536604, 39.14642184121268, 40.19810812813895, 50.22582129069737, 52.29573481423514, 50.174838883536204, 49.63350125721523, 50.168220724378315, 51.13384314945766, 51.99725062506539, 50.98454373223441, 45.73474196025303, 42.98013210296631, 46.1232122693743, 49.016306672777446, 46.966021810259136, 44.9978472845895, 44.22165012359619, 45.97880090985979, 45.88327707563128, 45.976410729544504, 52.78564534868513, 51.05525207519531, 52.933433532714844, 50.43705347606114, 49.173961298806326, 45.737566402980256, 47.427305766514365, 48.81869295665196, 53.15540415900094, 53.429354258946006, 56.95591245378767, 53.01613794054304, 51.3532464163644, 47.4984518459865, 26.748203924724034, 8.610205088342939, 4.371225076062339, 10.842501487050738, 7.284719824790955, 12.104236160005842, 0.40009247405188425, 0.1577368373317378, 13.690255420548574, 36.49339812142508, 50.462365763528005, 44.76124722617013, 24.107125895363943, 36.77743353162493, 49.22604846954346, 52.322408948625835, 56.10080112729754, 26.532339027949742, 0.943236414875303, 0.11470330506563187, 0.08790354670158454, 0.12070544942149095, 0.08709173383457319, 0.1756898154105459, 0.1274707421128239, 0.23626915046146937, 0.08148210163095168, 0.12164128491921083, 0.10513277897345168, 0.25276810941951616, 0.19462554289826325, 0.224034349833216, 0.1166782762323107, 0.12748691838766846, 0.1740762862776007], [0.03917180627052273, 0.03916290728375316, 0.015763342180954557, 0.061027229231383116, 0.02375067474453577, 0.02392767569316285, 0.05027312772082431, 0.04572059540078044, 0.030897801143250296, 0.04655588557943702, 0.02456289133988321, 0.0416809202038816, 0.018126369221135974, 0.030328435623752217, 0.08912444833133902, 0.029820433418665613, 0.8950233533978462, 24.653586081096105, 48.34849098750523, 40.02087000438145, 29.127536364964076, 14.007847155843463, 26.149732998439244, 41.92238698686872, 35.04984385626656, 39.24743127822876, 8.873795424188886, 0.16016785188445024, 2.7174984429563795, 16.708692720958165, 8.648275136947632, 13.574365547725133, 4.775249361991882, 8.924684899193899, 1.5248972603252955, 9.28703258718763, 54.645883083343506, 46.48671422685896, 53.00584765842983, 49.171911580221995, 52.20491491045271, 46.89929825919015, 48.240859917231965, 46.067324434007915, 49.861971923283164, 49.282325404030935, 48.584312847682405, 49.071840150015696, 47.21562542234148, 45.37127821786063, 49.58770220620291, 48.33300345284598, 47.632340158735005, 44.02876813071114, 42.62705591746739, 46.05787140982491, 47.32531663349697, 43.81035498210362, 47.199790477752686, 50.47567851202828, 43.3431442124503, 43.953995091574534, 47.63934741701399, 45.14354058674404, 44.13030563082014, 36.4311318397522, 38.97838313238961, 35.92773485183716, 37.69498484475272, 34.22571454729353, 35.10389736720494, 33.0461814062936, 34.02910137176514, 31.858147144317627, 37.24858045578003, 39.43996933528355, 46.576321669987266, 46.344210147857666, 45.97939845493862, 46.86222614560808, 48.73847600391933, 45.2213499886649, 47.76641954694475, 44.87223080226353, 50.25273513793945, 44.42349181856428, 52.43376077924456, 25.747541734150477, 24.42990619795663, 51.593945911952424, 45.55580152784075, 49.160995960235596, 45.85813154493059, 50.082115173339844, 46.827599797930034, 48.32512419564383, 41.46921852656773, 39.14700896399361, 45.33625929696219, 46.549883774348665, 43.6526586668832, 41.78627872467041, 34.09800665719168, 34.332713331495015, 34.88858311516898, 34.691473143441335, 34.58282763617379, 35.131283691951204, 36.418944699423655, 44.00961889539446, 50.32691410609654, 46.36220250810896, 44.97545324053083, 45.57439490727016, 47.66886683872768, 45.54647357123238, 43.01983410971505, 44.22511032649449, 49.23659930910383, 49.53808512006487, 48.830650806427, 48.11832843508039, 46.395557335444856, 46.853825773511616, 44.37775182723999, 44.551043374197825, 45.326927866254536, 47.38884401321411, 49.0004300389971, 45.81787715639387, 48.020313671657014, 46.458643504551475, 47.55833142144339, 45.08114576339722, 40.229302065713064, 45.389114243643625, 49.70152064732143, 48.79066044943673, 49.2495368548802, 52.221969263894216, 48.398299149104524, 31.738818781716482, 13.008549417768206, 1.7558468048061644, 2.6214901890073503, 4.757574013301304, 53.12498494556972, 9.723128455025808, 0.008422899459089552, 4.5652565615517755, 39.190341404506135, 27.762204919542583, 19.686685425894602, 31.300880772726877, 19.70718608583723, 33.52266107286726, 41.90061828068325, 43.06715134211949, 25.18198616164071, 2.7567353546619415, 0.06436516011932067, 0.08160522181008543, 0.04656664375215769, 0.06696333177387714, 0.013434073106119675, 0.026481776498258114, 0.07654637683715139, 0.12147649590458189, 0.027023713935964873, 0.01348484109621495, 0.03274166577362588, 0.023187853695292557, 0.021313320978411605, 0.06245112818266664, 0.011252116528339684, 0.03159698737519128, 0.042924400086381605, 0.04940211945878608, 0.0023010848505821612, 0.03329585585743189, 0.07035502977669239, 0.04393191941614662, 0.0439067254109042, 0.04027532134205103, 0.03759096895477601, 0.025136472258184637, 0.026689467585778663, 0.08652847513024296, 0.033599208508219035, 0.01621536524700267, 0.04230638360604644, 0.016024418707404817, 1.2453321473939079, 33.67990575517927, 53.37231649671282, 46.46817295891898, 36.97126742771694, 26.393291677747452, 27.50123926571437, 37.79466717583792, 39.16426134109497, 43.06753696714129, 10.418063827923365, 0.24411363952926227, 3.499578122581754, 21.624536275863647, 10.340866736003331, 9.318481002535139, 8.740056497710091, 9.584173168454852, 2.225534064429147, 12.15319229875292, 52.52008172443935, 47.520536695207866, 54.52125324521746, 49.87909575871059, 53.15030765533447, 48.40068585532052, 49.267181805201936, 48.539121764046804, 52.32820374625069, 51.39514752796718, 48.30138914925711, 50.61963823863438, 48.89718675613403, 46.78802980695452, 50.74527556555611, 50.91246312005179, 50.0816843850272, 43.84290034430367, 42.65100983210972, 47.93569156101772, 50.10325506755284, 45.719007764543804, 48.29937069756644, 49.722472940172466, 44.507849897657124, 43.546792439052034, 48.84543309892927, 47.339796679360525, 45.482539721897666, 38.446144172123496, 40.51816299983433, 39.20209428242275, 38.67506994519915, 36.5282051222665, 37.541127409253804, 35.952890804835725, 37.08553750174386, 33.97514166150774, 38.183880942208425, 42.034662927900044, 47.46558339255196, 48.09085873195103, 47.12290171214512, 48.14393949508667, 50.86505903516497, 48.03458527156285, 51.03358064379011, 48.67121049336025, 52.05841909136091, 46.255849906376426, 53.40874590192522, 27.50426173210144, 26.78396282877241, 54.134071826934814, 46.91790553501674, 51.20580564226423, 47.6199688911438, 50.03700051988874, 48.902179036821636, 49.91078649248396, 42.94363668986729, 40.58086701801845, 48.045817034585134, 47.859692164829795, 45.088021005902974, 42.62025710514614, 36.797875131879536, 35.82613481794085, 35.906355244772776, 37.023160048893516, 36.583081994737896, 36.198502676827566, 37.79201643807547, 46.04607684271676, 51.50624574933733, 47.477676732199534, 44.276370661599294, 46.879447255815776, 48.56157486779349, 46.185405594961985, 41.20390851157052, 44.12015778677804, 49.32822172982352, 50.97127962112427, 50.25135244641985, 49.41038417816162, 48.37574529647827, 48.29234259469168, 46.03053024836949, 43.08214555467878, 46.43622514179775, 49.551064355032786, 52.27548428944179, 47.46919298171997, 50.06996972220284, 48.854792322431294, 49.845601967402864, 46.188441957746235, 43.03074625560215, 46.65080288478306, 50.89521769114903, 49.84320136478969, 51.29047639029366, 54.77292742047991, 50.153108392442974, 33.72657333101545, 13.838787061827523, 4.167125216552189, 5.60155953679766, 8.22247736794608, 58.170516627175466, 12.675353765487671, 0.0775150398590735, 5.897756900106158, 37.46782044001988, 31.907184055873326, 30.310220514025005, 30.562318529401505, 21.631232602255686, 39.75964205605643, 46.4391051701137, 48.45164046968733, 32.99881553649902, 3.8573949337005615, 0.08700050480131592, 0.03541255263345582, 0.019261946768632958, 0.05004242920715894, 0.08518744566078697, 0.01819531516438084, 0.07446423784962722, 0.03258201666176319, 0.0583043699817998, 0.02663032477721572, 0.022840781336916343, 0.03025649394840002, 0.04878276626446417, 0.0710139890600528, 0.029187088832259178, 0.051068879663944244, 0.12315618220184531, 0.12597636372915336, 0.04965883979041662, 0.19434205096747192, 0.13565342660461152, 0.10598822164216212, 0.18814828832234654, 0.08089266504560198, 0.1406437395406621, 0.11097531832222428, 0.16459922838423932, 0.08022060325103146, 0.19744921209556715, 0.15122587313609465, 0.13086493712450775, 0.18926257852997097, 2.1491870411804745, 43.27148744038173, 62.35518387385777, 52.819701944078716, 41.391120774405344, 24.407472201756068, 36.347419943128315, 53.269007205963135, 43.60482726778303, 52.145598139081685, 10.636899948120117, 0.33312109485268593, 3.1714453186307634, 25.834939650126866, 17.37302562168666, 24.948893206460134, 11.618080258369446, 22.763886247362407, 6.530010836465018, 10.409054619925362, 57.00920861107962, 47.0206172806876, 56.475861413138254, 52.66548320225307, 56.69058159419468, 50.57925878252302, 50.45259312220982, 51.039920875004356, 54.278521401541575, 52.481144019535606, 49.77656814030239, 52.188576221466064, 51.71025875636509, 49.35580955232893, 54.40433938162667, 51.06812361308506, 51.11150121688843, 44.29392181124006, 43.00575705936977, 49.90110765184675, 52.81575189317976, 48.21341453279768, 51.24405894960676, 53.04566778455462, 45.649188791002544, 45.48825808933803, 49.90623542240688, 49.075602599552695, 47.05098785672869, 40.31836754935128, 43.301527976989746, 40.39569057737078, 42.0820392199925, 37.95824861526489, 38.880760942186626, 37.53211212158203, 38.39293139321463, 33.98189531053816, 41.22955083847046, 43.87966673714774, 49.654224259512766, 51.53395863941738, 49.85821294784546, 50.49524463926043, 51.494930607931956, 49.677882875714985, 51.96979481833321, 51.40178305762154, 53.05017716544015, 48.97573266710554, 53.432665075574604, 29.599273885999406, 27.448262725557598, 53.25639622552054, 48.85650852748326, 53.59452336175101, 48.70388092313494, 52.629991803850444, 49.302690574101035, 50.889263084956575, 43.51980216162545, 39.8186148915972, 48.90339149747576, 50.20071744918823, 46.68923337118966, 45.92689091818673, 38.42004326411656, 38.04552493776594, 37.50712292534964, 39.14935745511736, 38.3653678894043, 38.54287004470825, 41.219583647591726, 48.11221054622105, 55.31219795772007, 48.784507819584434, 44.15405804770333, 47.49540158680507, 50.03786557061331, 47.53420032773699, 43.00886985233852, 44.8438161441258, 51.6425450869969, 53.625588757651194, 54.611631938389365, 51.43729182652065, 49.73187385286604, 49.742143290383474, 46.17561558314732, 44.97300052642822, 48.32088926860264, 50.30699709483555, 52.548819473811555, 49.59846496582031, 52.81864929199219, 51.167865003858296, 51.912260259900776, 49.41565786089216, 44.50795759473528, 50.26096180507115, 52.9712039402553, 53.920463357652935, 54.53810262680054, 55.91144534519741, 50.001036643981934, 36.8809860093253, 16.263290609632218, 4.578016928264073, 6.901733815670013, 12.263184888022286, 61.93838923318045, 12.778689111982073, 0.11748779565095901, 6.431322532040732, 51.24619204657418, 36.26978077207293, 30.369773524148123, 39.510170459747314, 28.520117895943777, 45.1714688709804, 55.312027726854595, 56.78206157684326, 42.13371992111206, 5.661587195737021, 0.1764610247420413, 0.15344857743808202, 0.10058149176516704, 0.1722912506333419, 0.10860630151416574, 0.1467775468315397, 0.1130322768752064, 0.2336309248847621, 0.11957844346761703, 0.193378924791302, 0.07475078997335263, 0.16378780906753881, 0.08727620036474296, 0.11148569200720106, 0.13271437931273664, 0.17498477681406907], [0.06671793279903275, 0.012773469223507812, 0.08024931206767048, 0.07897467046443905, 0.07181777485779353, 0.0459985369151192, 0.026217997706096088, 0.029111896974167654, 0.043839462234505584, 0.04100101115182042, 0.03467947018465825, 0.06757469861102955, 0.06023206082837922, 0.06536584999412298, 0.04156057184029903, 0.05061850543799145, 4.517831197806767, 38.17751291819981, 44.58146258762905, 44.20973743711199, 31.173423017774308, 22.71073947634016, 36.057252747671946, 42.96282761437552, 40.40050915309361, 31.704046521868023, 4.276908491339002, 0.12775008140930108, 5.129039474896022, 18.17541401726859, 5.230397624628885, 9.505164333752223, 11.397820625986371, 6.061569367136274, 3.3914554672581807, 11.130421808787755, 46.78631707600185, 50.38709592819214, 52.13235834666661, 48.65172774451119, 48.29892601285662, 45.34813724245344, 44.60182428359985, 45.500504289354595, 47.39244665418352, 49.36396326337542, 46.70345980780465, 44.237672669546946, 49.33472524370466, 47.2781731060573, 48.682080950055806, 45.36668198449271, 45.57003491265433, 44.00589118685041, 46.399219036102295, 45.72852332251412, 45.64084053039551, 41.244159426007954, 44.989912441798616, 47.29376833779471, 48.29861681801932, 43.577083110809326, 47.79527888979231, 47.39074087142944, 43.44648477009365, 40.14692422321865, 38.54852587836129, 38.20654944011143, 37.05225910459246, 34.77392741612026, 34.97204835074288, 33.564735889434814, 34.32974297659737, 35.95490230832781, 44.576348713466096, 45.351031167166575, 48.14772278921944, 44.65113912309919, 51.487520354134695, 46.860655852726524, 48.522640636989046, 46.15994739532471, 49.31291484832764, 44.75157880783081, 50.10011100769043, 42.87733697891235, 47.48469788687569, 24.397789887019567, 22.778220381055558, 45.391709395817344, 38.61265080315726, 43.471435751233784, 39.12710237503052, 42.55241142000471, 40.34705318723406, 40.07173081806728, 41.331539971487864, 42.98733738490513, 40.702880859375, 43.91782624380929, 45.19417905807495, 43.538690839494976, 37.75146675109863, 34.053051812308176, 33.54534694126674, 35.66241788864136, 33.617378916059224, 36.44671317509243, 37.71353653499058, 42.273052147456575, 46.20818526404244, 45.78212867464338, 41.25504377910069, 45.887056895664756, 41.894201619284495, 43.11977005004883, 41.77649218695504, 46.92436735970633, 47.65984460285732, 48.69471624919346, 44.00581475666591, 47.662936551230295, 46.14836822237287, 49.074813979012625, 46.75596387045724, 45.824398040771484, 45.039828300476074, 49.40879651478359, 48.810956137520925, 50.6223897252764, 48.86926194599697, 49.70555755070278, 48.642556122371126, 47.40651328223092, 45.87876074654715, 43.188248021262034, 44.75021348680769, 48.93105227606637, 49.780611991882324, 50.553519180842805, 54.62657751355852, 43.9171279498509, 18.97738552093506, 14.741720233644758, 8.771760259355817, 3.587092855146953, 7.096455344132014, 8.690917100225176, 0.1227502418415887, 0.9631661283118385, 26.241292885371617, 33.566657066345215, 21.38443432535444, 22.951362541743688, 31.3846378326416, 30.12581879752023, 40.695699896131245, 41.654808385031565, 41.382185391017366, 7.472864883286612, 0.013532670181510704, 0.012636526437875415, 0.044022483485085626, 0.09482908222292151, 0.006853324976483626, 0.049989211705646346, 0.022371604905596802, 0.022727130113967826, 0.051274716654526334, 0.07327043012316738, 0.019744946654619913, 0.00686284143012017, 0.016135388020692126, 0.036411932935672145, 0.038470496223973374, 0.042983052653393576, 0.0187793726633702, 0.07315214789871659, 0.01758937830371516, 0.042032194390360794, 0.023907345087666596, 0.023993454574208175, 0.12075849728924887, 0.02999311379556145, 0.041896025982818434, 0.017309499571898153, 0.07203443108924798, 0.05592740074332271, 0.04676550879542317, 0.047045031296355386, 0.041094798262098005, 0.05606591009667941, 5.769628209727151, 43.86944593702044, 52.70888859885079, 50.98810120991298, 36.26256159373692, 20.117897578648158, 34.53669507162911, 44.82336759567261, 43.838067872183665, 37.63241284234183, 5.019237526825496, 0.2692226107631411, 6.857313113553183, 22.658598457063945, 6.275594728333609, 9.159452370234899, 15.804539271763392, 9.326364602361407, 2.417030325957707, 11.350624987057277, 49.294717516217915, 52.979802336011616, 53.336074692862375, 51.468614305768696, 49.132456234523225, 47.74507120677403, 45.91374145235334, 48.32047585078648, 48.89276770183018, 50.686365263802664, 47.22673559188843, 48.58203731264387, 51.08355556215559, 50.3115690095084, 48.88439859662737, 46.717623710632324, 44.524296283721924, 43.10546023505074, 46.126665524074006, 45.67085674830845, 48.04825585229056, 43.68388387135097, 46.14917768750872, 48.94127655029297, 49.60648666109358, 44.966726303100586, 48.13678285053798, 49.35311017717634, 45.180188860212056, 40.99821056638445, 39.74866042818342, 39.45386920656477, 38.54157073157174, 35.32783085959298, 36.67519078935896, 35.89800698416573, 36.52776738575527, 35.974989550454275, 45.16306502478463, 47.518031869615825, 50.465033871786936, 47.33135461807251, 53.30587087358747, 47.84537887573242, 50.55593367985317, 48.21926491601126, 49.115520000457764, 47.03175176892962, 51.00790357589722, 44.1985890524728, 47.56477240153721, 24.92274366106306, 24.476754426956177, 44.998719283512656, 40.276348318372456, 45.51169783728463, 40.94182593481881, 42.70997224535261, 40.36132826123919, 40.36945417949131, 41.7814427784511, 40.012726715632844, 41.62329830442156, 46.03718662261963, 46.96726553780692, 45.78046110698155, 38.80819048200335, 36.69654260362898, 35.32785170418875, 38.42152323041643, 35.00737646647862, 38.53425775255476, 39.65881674630301, 43.87227037974766, 49.236988408224924, 47.52102306910923, 41.94890826089041, 43.46571043559483, 40.77494410106114, 43.17207956314087, 41.018082414354595, 47.347564765385215, 49.51756361552647, 49.483816214970176, 46.7712116922651, 49.04860189982823, 48.44409472601754, 49.265191146305625, 47.37659781319754, 45.7653591973441, 45.792009013039724, 50.04579693930489, 49.390310832432334, 52.440198285239084, 51.65754277365548, 50.68961007254464, 50.22820799691336, 48.60012347357613, 48.59234496525356, 45.09313140596662, 46.682472773960654, 50.774141856602256, 52.39270387377058, 50.67207629340035, 53.96173218318394, 44.925075326647075, 21.79628184863499, 7.51313316822052, 8.416340793882098, 6.345272566590991, 13.533341646194458, 12.549759864807129, 0.08519554058355944, 1.105060937149184, 29.185748372759136, 34.75985036577497, 23.649767671312603, 29.404147624969482, 33.28494235447475, 36.25390761239188, 46.880149023873464, 49.14498036248343, 48.23625326156616, 10.440755775996617, 0.005163895340436804, 0.06260776120637145, 0.053470316875193796, 0.01013413000120116, 0.049400294199585915, 0.007082200775455151, 0.03545303063999329, 0.1377823030842202, 0.014637196270216788, 0.07325307998274054, 0.06215436410691057, 0.026163238233753612, 0.0527864485712988, 0.048530765143888335, 0.09564514950449977, 0.027072154550946186, 0.19414089247584343, 0.1510076698447977, 0.14603271894156933, 0.22416114088680061, 0.1343498658388853, 0.06206964222448213, 0.17304779003773416, 0.12350190936454705, 0.0923125519018088, 0.08772783327315535, 0.21438206705663884, 0.10939095262438059, 0.1640080886759928, 0.2513401731848717, 0.11764778063765594, 0.16304467751511506, 8.333158697400775, 54.0267846924918, 58.24561275754656, 57.72411918640137, 42.05032416752407, 32.61936746324812, 46.73123523167202, 51.50850738797869, 48.71506404876709, 42.10470424379621, 5.620909835611071, 0.3305426617818219, 8.51539170742035, 31.464166913713726, 12.328247819628034, 19.60576844215393, 21.333865336009435, 15.286269664764404, 9.42812705039978, 14.30697579043252, 51.61362321036202, 55.00813089098249, 56.7180061340332, 52.950380189078196, 51.17425734656197, 49.0045850617545, 48.634805406842915, 49.43436935969761, 51.60982601983206, 51.964694840567454, 48.54230056490217, 50.011531897953574, 51.10149233681815, 51.48311172212873, 50.180953298296245, 47.51206684112549, 46.605528422764365, 44.02588810239519, 47.82357890265328, 49.21912458964756, 49.69811603001186, 45.28781993048531, 48.13164118358067, 51.01240253448486, 49.89109182357788, 44.59873580932617, 49.66743973323277, 52.2893077305385, 46.64190224238804, 43.485346044812886, 41.24883903775896, 41.38759456362043, 39.62896033695766, 38.20062610081264, 37.73653507232666, 37.20898962020874, 38.243461745125906, 39.56977558135986, 48.168004580906455, 49.659025464739116, 52.28181757245745, 49.04267161233084, 55.513108594076975, 49.2837358883449, 52.12234946659633, 49.16838884353638, 50.49262864249093, 48.02168246677944, 51.365145206451416, 46.14815977641514, 47.3628751209804, 27.8266008240836, 26.294827018465313, 45.20211042676653, 41.9716670853751, 45.93938725335257, 42.95663676943098, 42.696496214185444, 42.187763009752544, 40.599495138440815, 42.43956920078823, 41.814519677843364, 45.007682459695, 47.5214330128261, 48.74536861692156, 48.45643125261579, 41.1684935433524, 37.92609930038452, 37.36378506251744, 39.41984735216413, 38.65956504004342, 40.90899222237723, 42.565588678632466, 45.38070344924927, 48.34652464730399, 48.3596636908395, 44.768560205187114, 44.08789382662092, 42.078877789633616, 42.617919036320274, 40.79033088684082, 49.123041425432476, 50.62873690468924, 52.41058158874512, 48.61059440885271, 52.29691253389631, 49.95484501974923, 51.60753658839634, 50.63896812711443, 48.01323693139212, 47.23116854258946, 52.47110039847237, 51.055116585322786, 55.42033624649048, 52.2813207762582, 53.27948161533901, 52.2473440851484, 51.30849654333932, 49.994203090667725, 47.54045023236956, 48.76943370274135, 53.93941804340908, 53.870651721954346, 54.62454169137137, 53.65050499779837, 45.55656235558646, 23.793951477323258, 20.347929852349417, 19.563714470182145, 10.386002234050206, 9.074295248304095, 11.491579617772784, 0.22986470269305365, 1.8171348018305642, 34.0190612248012, 43.741706780024934, 29.297451087406703, 35.05587836674282, 40.64306729180472, 40.42368834359305, 54.2280809538705, 55.28691693714687, 54.903275626046316, 13.52121182850429, 0.08032136570130076, 0.2414300606719085, 0.20931716955133847, 0.17745634061949594, 0.16836356424859591, 0.10755052816654954, 0.13509174888687475, 0.22589440430913652, 0.10163559591663734, 0.1749806377504553, 0.10983095544257335, 0.14641997244741234, 0.15452051348984241, 0.06330502379153456, 0.1855638570019177, 0.12945123655455454], [0.013666877622849174, 0.04606878225292478, 0.006041702099277505, 0.013608130060934594, 0.042167026083916426, 0.020848273432680538, 0.039535375511539836, 0.002578427133682583, 0.057890958950987885, 0.05767612119338342, 0.02101545937226287, 0.0776940645383937, 0.07189831017915692, 0.03094908142728465, 0.1134654807725123, 0.04252027480729988, 8.104589019502912, 44.22741365432739, 44.68467460359846, 43.1943485396249, 33.62740516662598, 46.664181641169954, 57.301592281886506, 47.5621703011649, 42.156534331185476, 25.541697876793997, 2.5519183107784817, 0.3628624246588775, 2.9101984798908234, 4.073464368070875, 4.995116421154567, 6.327044401850019, 6.465505932058607, 5.571955433913639, 1.8786439469882419, 21.74132854597909, 45.16767862864903, 50.586825370788574, 52.168766907283235, 48.61473206111363, 46.17498677117484, 41.55188124520438, 39.626674379621235, 44.2407020841326, 48.853034428187776, 48.95774378095354, 49.509184088025776, 40.723475319998606, 42.98094851630074, 45.4060435295105, 46.081627300807405, 46.177772998809814, 46.93639816556658, 47.287695612226216, 47.478774547576904, 47.90048851285662, 43.78982652936663, 38.34569753919329, 43.170436314174104, 46.010863372257774, 46.90866790499006, 42.90306615829468, 46.00712871551514, 47.006727831704275, 43.790389333452495, 41.156890051705496, 40.62640898568289, 38.43171623774937, 35.24047115870884, 34.09001275471279, 35.478116921016145, 33.40814781188965, 34.79193367276873, 40.50361694608416, 46.74502740587507, 44.54735735484532, 45.96417842592512, 45.3271050453186, 47.05926316125052, 48.18517010552542, 48.47901289803641, 44.41854470116751, 48.55019719260079, 43.277660914829795, 47.75141143798828, 38.97518348693848, 45.3953572000776, 24.34106479372297, 21.212125948497228, 46.62001541682652, 36.824472836085725, 41.65747996738979, 38.18156024387905, 42.307157380240305, 37.20192330224173, 40.18410055977957, 39.36371980394636, 43.20239107949393, 42.05443402699062, 43.389492171151296, 45.41323491505214, 46.964083262852256, 38.07009029388428, 33.739549091884065, 32.72470562798636, 35.03037847791399, 35.46090275900704, 36.462207657950266, 35.80843080793108, 39.796453612191335, 48.79746273585728, 44.37490653991699, 40.7764344896589, 45.5696701322283, 43.777500425066265, 44.20429352351597, 43.787446771349224, 47.849412305014475, 45.488046169281006, 44.29547125952584, 41.234143597739084, 43.34431150981358, 44.10515662602016, 44.63954605375017, 45.685513973236084, 45.51488011223929, 41.82979529244559, 45.26547452381679, 47.952579157693044, 49.106841700417654, 49.32471636363438, 47.00723852430071, 51.04996797016689, 50.738709517887656, 50.740734917776926, 50.37757689612252, 48.37225382668631, 49.315666334969656, 50.93662895475115, 55.6745673588344, 43.95571477072579, 43.88333191190447, 26.273892096110753, 8.414714915411812, 4.600552541869027, 8.000278319631304, 9.534170457295009, 10.79789318357195, 1.2831085260425295, 0.1085384955097522, 19.96573724065508, 38.17400060381208, 34.90829515457153, 21.940276316234044, 22.825792959758214, 28.30584761074611, 35.67192997251238, 41.06901618412563, 40.404132638658794, 14.298560653414045, 0.17629064459885868, 0.05287434599761452, 0.014065203123858996, 0.03591729108510273, 0.03387737733178905, 0.0411225130249347, 0.05274195024477584, 0.03616865099008594, 0.04929290246218443, 0.02000181287127946, 0.05791373737156391, 0.017832624626212885, 0.02737294403570039, 0.05986803357622453, 0.026681515155360103, 0.013382497659352208, 0.017676737991028597, 0.06214531923511198, 0.08130208629050426, 0.021699721226468682, 0.05880438922239201, 0.018072079634293914, 0.08892119995185307, 0.06713956088892051, 0.028388956927561333, 0.09999169555625745, 0.029508205529834543, 0.03459050745836326, 0.08953448704310826, 0.021599080912502747, 0.18272378082786286, 0.0686106655214514, 11.135201300893511, 51.78294733592442, 51.47847032546997, 47.43387876238142, 41.9323159626552, 44.61771133967808, 55.76216329847063, 51.13731377465384, 49.71027190344674, 29.971217904772075, 2.34902309519904, 0.4101017883845738, 4.509757825306483, 5.125181921890803, 3.438073537179402, 12.143630708966937, 11.491187044552394, 6.488548329898289, 1.965748735836574, 22.550091913768224, 47.87976203645979, 51.96187039784023, 52.768420764378135, 51.396589279174805, 47.65172563280378, 42.93489238194057, 41.97782666342599, 46.055328369140625, 50.32920353753226, 51.35683863503592, 50.20605713980538, 40.00800888878958, 45.710391998291016, 47.70357656478882, 47.538998058864046, 46.175191743033274, 47.620590754917686, 48.98572070258004, 49.27160780770438, 49.23157576152256, 46.38952282496861, 40.003836495535715, 45.23758445467268, 48.59728166035244, 48.41972739355904, 41.86096143722534, 46.942397935049875, 49.441018785749165, 45.99319062914167, 43.545670304979595, 43.30495343889509, 40.8295430455889, 37.27447639192854, 35.70982197352818, 37.792509760175435, 35.85417079925537, 36.825056484767366, 41.67217540740967, 47.855422496795654, 46.383439677102224, 47.10312713895525, 45.80358471189226, 48.03660372325352, 47.87224061148507, 48.82451554707119, 44.874808583940776, 47.75167546953474, 44.016876288822715, 47.61776283809117, 39.68229818344116, 45.19947011130196, 24.874841042927333, 22.7858338696616, 47.92170483725411, 37.17857388087681, 41.642940861838206, 39.17414515359061, 42.910900252205984, 37.433319159916465, 42.377782344818115, 39.61172880445208, 42.981688499450684, 43.09384284700666, 44.32160690852574, 46.98660584858486, 49.17712620326451, 39.908590589250835, 35.719601563044954, 35.08380317687988, 37.72392756598336, 37.44353996004377, 38.56462138039725, 37.80810151781355, 42.36697442190987, 50.543968881879536, 48.204923834119526, 44.56015593664986, 45.671777384621755, 44.21558782032558, 43.55397687639509, 45.13729763031006, 47.97286442347935, 47.8568434034075, 46.48104797090803, 43.911788259233745, 45.678593567439485, 46.03547041756766, 47.263401235852925, 46.77407087598528, 47.22359153202602, 43.249861172267366, 48.09902286529541, 48.20002882821219, 50.376048292432515, 50.541609968457905, 49.19034515108381, 52.280313287462505, 53.70919643129621, 51.68235131672451, 53.21457849230085, 50.577170848846436, 50.8221434865679, 50.975392954690115, 56.398778097970144, 45.19016299928938, 43.801364013126914, 26.30093969617571, 11.54466906615666, 6.887698020253863, 7.041837726320539, 5.1712484785488675, 7.803574817521231, 1.489090261714799, 0.04280449616323624, 21.57572865486145, 41.30627632141113, 29.347655296325684, 25.855101585388184, 29.29057584490095, 31.13228620801653, 43.338537556784495, 46.10243715558733, 47.013175759996685, 18.071528026035853, 0.17070327512919903, 0.0363315808187638, 0.01692904159426689, 0.0636427238849657, 0.053511900893811665, 0.0241606439064656, 0.0369166985287198, 0.0046609325301168215, 0.04231322663170951, 0.026794928891052092, 0.01897309610753187, 0.018642030390245572, 0.009044501996998276, 0.042939629804875167, 0.015134889832032579, 0.026172474791694964, 0.0936352066429598, 0.10051652882248163, 0.11711807548999786, 0.1415358366710799, 0.08632459571318966, 0.08654024092746632, 0.1476184009973492, 0.17235082600797924, 0.1216495359050376, 0.15800348802336625, 0.1137893862490143, 0.11497769105647292, 0.21643242346388952, 0.18123485786574228, 0.27818749685372623, 0.21490850166550704, 15.519623177392141, 61.213858876909526, 59.12922559465681, 54.142569473811555, 44.096933432987754, 55.902360575539724, 66.56260994502476, 52.1917758669172, 52.98902954374041, 32.93837315695626, 2.897363854306085, 0.6085153073072433, 7.886161974498203, 10.002224564552307, 11.949947936194283, 15.403970411845616, 15.81536282811846, 13.127129980495997, 6.492812786783491, 26.575647149767192, 46.16613824026925, 52.66093213217599, 54.06998859133039, 54.499418531145366, 49.70575557436262, 45.38199928828648, 43.01898990358625, 49.086073534829275, 51.98544216156006, 54.21022060939244, 50.51913602011544, 41.96864461898804, 45.594919885907856, 47.044894286564414, 47.94353607722691, 46.54191419056484, 49.62720966339111, 50.72908626283918, 50.17544685091291, 51.860996450696675, 48.18476711000715, 42.35974482127598, 45.895783833095, 50.76072141102382, 49.117107663835796, 42.46359954561506, 46.59518255506243, 50.50604561397007, 47.42208072117397, 46.029303891318186, 43.53307669503348, 42.68535130364554, 39.094213077000205, 36.873506273542134, 40.413464069366455, 38.262138502938406, 39.524240561894004, 45.45772770472935, 50.56798880440848, 48.4913945879255, 49.39074509484427, 47.20575898034232, 49.22991861615862, 47.210396902901785, 49.60176188605172, 46.25056232724871, 49.74585015433175, 45.17044748578753, 47.504635742732454, 43.230652877262656, 44.314992223467144, 27.144318989345006, 24.92188903263637, 46.252514771052766, 37.87524890899658, 41.8443899835859, 39.081942558288574, 43.87692567280361, 40.38204778943743, 43.65584441593715, 41.147860867636545, 46.787786620003835, 43.957090514046804, 44.55623715264456, 48.803306170872276, 50.01701055254255, 42.77548680986677, 37.29431349890572, 37.783737659454346, 39.41940614155361, 39.939221722739084, 40.82683324813843, 39.4190274647304, 43.60817282540457, 52.73849834714617, 49.978475843157085, 47.34583118983677, 46.97898020063128, 45.97511836460659, 46.24998215266636, 45.973513330732075, 50.64682306562151, 50.93140043531145, 48.56547280720302, 46.13930777141026, 47.43167270932879, 48.05920621326992, 48.33832924706595, 49.094571181706016, 49.121446813855854, 44.490882396698, 48.46885115759713, 49.33310978753226, 51.853784220559255, 51.806724071502686, 51.50077404294695, 53.796517917088096, 54.0429288319179, 54.64266259329659, 54.66802699225289, 53.92653955732073, 53.25857448577881, 54.57704380580357, 58.49901703425816, 50.15803466524397, 44.118431159428184, 28.44695336478097, 11.758588467325483, 10.214590174811226, 11.596010174070086, 15.773539883749825, 13.037829995155334, 1.634242798600878, 0.30926255509257317, 25.752523592540197, 49.9462605203901, 44.62517370496477, 33.135229519435335, 31.67545121056693, 37.03710160936628, 48.463567052568706, 53.896881171635215, 55.34843628747122, 22.55635224069868, 0.37005394590752466, 0.1369191115455968, 0.1061925013948764, 0.21645440799849375, 0.10080082820994513, 0.1185540184378624, 0.18137557245790958, 0.06524116918444633, 0.12660170160233974, 0.19667376870555536, 0.18274966015347413, 0.0925101073724883, 0.16627550843570912, 0.1833688369286912, 0.10147012158163957, 0.06784467412424938], [0.01140635771610375, 0.01561095000111631, 0.03165635918932302, 0.04133329314312764, 0.03670423225100551, 0.11157289054244757, 0.061823327227362564, 0.05648552972291197, 0.04833841064412679, 0.029702626168727875, 0.03790078465161579, 0.06094436653490577, 0.10739829204976559, 0.04175508747409497, 0.09454436214374644, 0.12449411755161625, 10.537023935999189, 39.55644546236311, 40.814788545881, 30.234429563794816, 14.929144416536603, 33.31861332484654, 47.24928944451468, 37.45792620522635, 32.315012046269004, 20.10310138974871, 0.5856961746300969, 0.13944258327995027, 14.342977012906756, 9.042622753552028, 2.2926814556121826, 10.50274065562657, 14.744442190442767, 9.633428948266165, 8.256774544715881, 38.19185747419085, 48.531179973057334, 51.44080761500767, 51.62154068265642, 51.00648961748396, 48.19296945844378, 44.14937496185303, 37.04258026395525, 42.10475982938494, 46.67783832550049, 49.459514890398296, 48.15132195608956, 51.78443077632359, 45.754356724875315, 45.04336493355887, 48.40872144699097, 47.50831481388637, 47.218911920275005, 46.444281578063965, 47.6223521232605, 43.7586464881897, 41.59493228367397, 35.716714586530415, 39.242762088775635, 46.65791436604091, 47.870447976248606, 46.03995895385742, 46.2715493610927, 48.95899445669991, 46.702188287462505, 42.54494558061872, 41.30738455908639, 39.05807202202933, 35.06416061946324, 33.71829802649361, 34.27805880137852, 33.11203990663801, 36.001965931483674, 44.15848405020577, 47.9673683983939, 45.90845039912632, 48.227620124816895, 43.71110691343035, 42.79020309448242, 42.96644415174212, 50.35670798165457, 43.58102968760899, 48.048620632716585, 45.415868282318115, 48.99518762316023, 44.781723567417686, 48.13210671288626, 26.125146797725133, 21.491909061159404, 45.001376969473704, 40.39601019450596, 50.14743518829346, 44.85997070584978, 48.801840100969585, 47.737035615103586, 48.87141588756016, 46.04623665128435, 47.16733544213431, 48.32145207268851, 48.305578913007466, 45.47743627003261, 48.46976831981114, 41.58693143299648, 35.24731860842024, 33.763113907405305, 34.69998468671526, 33.02753938947405, 35.33777025767735, 34.68633842468262, 38.4421454838344, 45.82651376724243, 49.247792857033865, 51.38795961652483, 48.96279164722988, 47.59553207669939, 47.92710358755929, 46.38493701389858, 46.76847757611956, 44.33099045072283, 39.10403782980782, 37.41691793714251, 40.954721791403635, 45.35921267100743, 47.34582771573748, 46.715438502175466, 40.87806231634957, 41.474196910858154, 45.605568000248496, 43.851418835776194, 46.26110274451119, 45.211031913757324, 44.94243540082659, 44.606215545109336, 48.13265214647566, 49.47947359085083, 49.89100497109549, 50.082511220659526, 53.154125690460205, 51.440897941589355, 50.06107950210571, 38.809767723083496, 31.00590889794486, 24.309592928205216, 8.836702466011047, 5.3971830521311075, 6.7133846538407465, 8.720479948180062, 18.553515877042496, 2.7464415984494344, 0.21457327822489397, 11.070188743727547, 33.68081944329398, 46.59218788146973, 41.076857226235525, 23.494897535869054, 23.686681713376725, 32.59383283342634, 43.94631733213152, 41.76903329576765, 21.435717242104666, 0.17671402330909455, 0.15511322739933217, 0.048486897854932716, 0.03832009554441486, 0.047827772330492735, 0.028881473267184835, 0.015086072630115917, 0.0275617277449263, 0.0619128192109721, 0.03382556100508996, 0.034877371708197255, 0.014248570427298546, 0.015934631561062167, 0.012588580305288945, 0.030395810758428912, 0.02223011678350823, 0.014932786480390599, 0.03640848597777741, 0.04451570041211588, 0.013732380849043173, 0.029856582371784107, 0.12561074191970484, 0.007593991750452135, 0.04645284325150507, 0.046214952266642025, 0.016973809638459767, 0.132694416812488, 0.06434243598154613, 0.10724661911704711, 0.03540336526930332, 0.031633071867483, 0.06950530037283897, 16.41085818835667, 48.99293988091605, 47.63116243907383, 35.84847675051008, 22.570160048348562, 41.061018807547434, 51.517362867082866, 43.55222593035017, 38.06856516429356, 23.267707075391495, 0.6364495626517704, 0.4006985143891403, 20.20731394631522, 9.146147438458033, 5.329418574060712, 16.25128585951669, 10.207450900759016, 4.394013430391039, 8.161288925579615, 39.07812104906355, 50.290595872061594, 53.391802719661165, 53.18276269095284, 52.71516629627773, 49.1240245955331, 46.71147108078003, 38.397968837193076, 44.37142896652222, 47.91282156535557, 50.763354778289795, 49.31199768611363, 50.10815702165876, 45.331058570316856, 44.81484563010079, 48.91522775377546, 50.23001452854702, 49.92336620603289, 49.90550238745553, 49.333630902426584, 45.42999049595424, 44.28691455296108, 37.169555119105745, 41.78504889351981, 48.72913762501308, 48.06230163574219, 46.262933594839915, 46.5653053011213, 49.577620370047434, 48.25023998532976, 45.99436140060425, 42.900877475738525, 40.20006057194301, 37.360467297690256, 36.00498144967215, 36.59041581835066, 35.163940225328716, 37.88594913482666, 46.04213374001639, 49.169132300785606, 47.75215836933681, 48.25177901131766, 44.34347983769008, 43.033251081194194, 45.28708342143467, 50.34079660688128, 44.29646832602364, 49.123889105660574, 46.037217889513286, 49.8945311818804, 45.17850044795445, 47.74089533942086, 27.418211766651698, 22.455613783427648, 45.86394023895264, 41.29339436122349, 49.68454967226301, 46.67879370280674, 49.24863706316267, 48.32682997839791, 50.291040556771414, 47.50232546670096, 49.295033659253804, 48.20058121000017, 49.64944737298148, 48.9462479863848, 50.65322930472237, 43.11562544958932, 35.33630766187395, 35.62028053828648, 36.71201624189104, 35.015280042375835, 36.69784191676548, 37.440969126565115, 40.661073548453196, 46.70582914352417, 50.403351238795686, 51.857428550720215, 51.56258174351284, 49.5771861076355, 49.3990273475647, 48.59487063544137, 48.040004866463796, 46.8086381639753, 41.956054483141216, 38.738465309143066, 42.29223264966692, 47.726745332990376, 50.207349504743306, 47.37295000893729, 43.4616631099156, 43.188428674425396, 45.23577444893973, 46.24223838533674, 47.238259179251536, 44.92108358655657, 44.93754734311785, 45.315564087459016, 49.61917059762137, 51.53571653366089, 51.01902069364275, 51.42855794089181, 54.885522978646414, 55.13090903418404, 51.01633868898664, 39.106768471854075, 31.826762131282262, 26.147830929074967, 10.736946191106524, 8.295244114739553, 2.1499661079474857, 3.6251353280884877, 21.67150957243783, 2.596340749944959, 0.23748874930398806, 12.007979290825979, 38.14711454936436, 43.87023108346121, 42.443081515175955, 29.691928114209855, 28.224098580224172, 38.60340969903128, 48.812568119594026, 49.56353289740426, 26.980289391108922, 0.4046729654073715, 0.041214773431420326, 0.011819306494934219, 0.1425334731382983, 0.07520081475377083, 0.006505919711863888, 0.01337722035324467, 0.028433406060295444, 0.03958534961566329, 0.041893328806119304, 0.016895086005596176, 0.023013824730047157, 0.06586780305951834, 0.011197775203202451, 0.03610909597149917, 0.014881541819444724, 0.08767159629080977, 0.11774232770715441, 0.1832601899015052, 0.12782906288547174, 0.12934002466499805, 0.19229020178318024, 0.12000431918672153, 0.1088236023538879, 0.1850683093070984, 0.09671317040920258, 0.22014642560056277, 0.18503880660448754, 0.20600176602602005, 0.10642103877450738, 0.24754960515669414, 0.26481810425009045, 22.854297944477626, 57.21277345929827, 55.49884046827044, 43.088683809552876, 23.422749178750173, 40.16172388621739, 53.65301329748971, 42.64678185326712, 43.621037415095735, 27.367210251944407, 0.7391613626054355, 0.4985234779970986, 22.177579879760742, 13.835979989596776, 5.764779235635485, 18.72139130319868, 22.309097119740077, 18.240124327795847, 11.519584332193647, 42.18262134279524, 50.86709138325283, 53.144940171922954, 54.75626564025879, 54.82899938310896, 51.28987537111555, 48.69278812408447, 40.721595832279746, 45.836265563964844, 50.23098380225045, 53.405601842062815, 50.433228492736816, 52.144260610852925, 47.8904344694955, 46.18133742468697, 50.960652351379395, 51.70873710087368, 53.25087935583932, 51.25172628675188, 51.03358064379011, 48.12172263009207, 44.49705587114607, 39.617547920772004, 44.082693099975586, 52.47698204857962, 50.50696972438267, 47.66505227770124, 47.07815531321934, 52.46699401310512, 50.844794613974436, 47.1618845803397, 45.71362638473511, 42.64962714059012, 39.08882474899292, 37.8627803666251, 39.49226147787911, 36.42862006596157, 39.790613651275635, 46.92826877321516, 53.220137051173616, 48.3632732800075, 47.82236991609846, 45.366053172520225, 44.45553343636649, 45.47138786315918, 49.60652487618582, 46.71773835590908, 49.471389361790244, 48.308552742004395, 50.86362770625523, 49.04127155031477, 47.5914534841265, 29.85390451976231, 25.420668942587717, 44.73696674619402, 42.41746698107038, 52.42187588555472, 48.72068861552647, 50.17505775179182, 51.295711857931956, 51.360496861594065, 49.63115971429007, 50.568739209856304, 50.56963552747454, 51.426362310137065, 49.38186182294573, 52.76996673856463, 45.80449145180838, 38.40777274540493, 37.83317756652832, 37.498851094927105, 36.76474264689854, 39.30437871388027, 39.2287232535226, 42.20812817982265, 49.79732935769217, 52.889211722782676, 53.03010381971087, 53.056152616228374, 51.60030698776245, 50.469362599509104, 50.429691859654014, 50.15801729474749, 47.08915431158883, 42.93787663323538, 40.73679501669747, 44.18065227781023, 50.12701790673392, 51.399771554129465, 49.18977887289864, 44.847557749067036, 45.02738407679966, 47.06195906230381, 46.52276495524815, 48.08632155827114, 44.58516597747803, 45.56726952961513, 45.25148432595389, 50.19900124413626, 52.22169133595058, 53.025445052555625, 52.00893749509539, 57.043581349509104, 54.47275134495327, 52.0704151562282, 41.443798542022705, 37.50795323508126, 29.065336091177805, 12.069763541221619, 11.1038510288511, 14.301886234964643, 14.886376517159597, 23.532570668629237, 3.2898113557270596, 0.3382267180298056, 14.023119296346392, 44.65329653876168, 55.81378493990217, 49.01222113200596, 31.335052013397217, 34.184900828770225, 43.88595485687256, 56.7617380959647, 56.49813386372158, 34.21121713093349, 0.8558744341135025, 0.3834520269717489, 0.14840198680758476, 0.28325680483664784, 0.17259015887975693, 0.15961855064545358, 0.05887934020055192, 0.09044066377516304, 0.15643308657620633, 0.0975159044776644, 0.0974888445011207, 0.10638116127146141, 0.09084780514240265, 0.07810389968965735, 0.1626331324556044, 0.08563563161130462], [0.05042330448382667, 0.04913906839543155, 0.060365895075457435, 0.02257913993006306, 0.010830855695530772, 0.024739878717809916, 0.08169225071157728, 0.011599077776606594, 0.05328324816322752, 0.015764945219936113, 0.07645347860774823, 0.11646870390645095, 0.020154371292197278, 0.03397822120626058, 0.11526699124702386, 0.8175867114748273, 15.527976649148123, 33.327889169965474, 44.081678662981304, 23.9432178906032, 26.964536087853567, 36.346877983638215, 45.1208929334368, 29.201499938964844, 35.10255289077759, 16.297508750643047, 0.11036631278693676, 0.4540511800774506, 10.758118220738002, 9.722545674868993, 2.3589789952550615, 17.441142286573136, 9.381203259740557, 3.205427655151912, 27.041843482426234, 56.046956062316895, 52.16785321916853, 52.307352202279226, 50.372765268598286, 48.70630237034389, 48.350783893040244, 48.43181725910732, 37.44336972917829, 39.01392664228167, 43.93554415021624, 46.76582336425781, 46.886065414973665, 49.9548728125436, 53.666260038103374, 48.874625955309185, 48.703429290226524, 47.37070574079241, 44.41897201538086, 42.53406122752598, 39.73809221812657, 38.94867263521467, 35.2418086869376, 35.26278877258301, 35.81467029026577, 44.51512813568115, 48.466620785849436, 46.25504738943917, 45.1530248778207, 47.2206837109157, 47.318865231105256, 42.92837149756295, 38.478025981358115, 34.559631075177876, 32.969129358019146, 32.822775976998464, 34.26480163846697, 33.69938850402832, 37.89101089750017, 45.81389931270054, 44.54019376209804, 44.828443254743306, 43.98232289722988, 44.646862506866455, 44.53594146456037, 40.478384562901084, 46.9477584702628, 44.584134169987266, 46.62936074393136, 44.40055928911482, 47.633333751133506, 44.859741415296284, 50.66711180550711, 29.41757501874651, 20.123028823307582, 47.004414081573486, 41.410527093069895, 49.79221200942993, 43.6708698953901, 47.01466614859444, 43.19910110746111, 47.439020429338726, 45.61385720116751, 49.207524572099956, 44.64778314317976, 49.72568995612008, 45.650432518550325, 47.464079107557026, 38.835423946380615, 36.38368606567383, 33.446442808423726, 36.11107349395752, 34.77250303540911, 33.88856015886579, 33.238330364227295, 37.92939622061593, 39.96308183670044, 48.268086433410645, 45.136616706848145, 46.45846285138811, 46.01413597379412, 47.55131026676723, 48.674500465393066, 47.930626324244905, 42.59913458142962, 37.03030974524361, 38.8607223374503, 43.38835266658238, 46.07028089250837, 45.70602852957589, 43.48769106183733, 43.648958751133506, 42.67801053183419, 42.869697434561594, 43.86349827902657, 44.79052693503243, 44.64172083990914, 49.6791787147522, 46.9100992338998, 47.29417828151158, 47.20782954352242, 48.12558582850865, 49.337379455566406, 47.85041284561157, 45.39264740262713, 42.395455087934224, 33.232320172446116, 23.98769157273429, 14.536730136190142, 13.190083265304565, 8.779214807919093, 3.9390497292791093, 3.7024214438029697, 11.83161837714059, 0.6547607257962227, 0.15688469234321797, 4.451526275702885, 36.06874506814139, 47.93871750150408, 61.0795293535505, 28.13855757032122, 20.512803656714304, 25.82996300288609, 41.33195686340332, 41.34114933013916, 31.383859634399414, 0.4907531120947429, 0.09430992829480342, 0.024378543553341712, 0.024653321398156028, 0.010089899696010565, 0.07239109623645033, 0.04554508892553193, 0.08566036421273436, 0.07033638363437993, 0.05390773108229041, 0.021025391428598335, 0.06776295815195356, 0.0516975932488484, 0.017577473406812975, 0.045236918676112375, 0.023605475035895194, 0.021461429905944636, 0.05989925975778273, 0.04018137477604406, 0.03249361372685858, 0.057085280040545125, 0.027960116010425345, 0.02887467434629798, 0.02772735644664083, 0.044591007621160576, 0.03571834461763501, 0.05162592638017876, 0.0589845741965941, 0.02634723318208541, 0.011912119907460042, 0.09143820524747882, 0.8560533502272197, 22.38321008001055, 42.43994092941284, 50.32167863845825, 31.9174257005964, 27.233744042260305, 38.0907438141959, 49.91487203325544, 32.3761944089617, 36.77193750653948, 18.112084661211284, 0.0757256005225437, 0.4209540874830314, 13.919382691383362, 13.489881532532827, 6.03589620760509, 11.409645591463361, 6.743172449725015, 3.272866870675768, 28.144512176513672, 59.10455254146031, 53.94626896721976, 52.81849643162319, 50.551545892442974, 50.845322677067344, 50.55779232297625, 49.68437596729824, 40.17245537894112, 40.79375287464687, 45.80623197555542, 48.27422864096505, 48.48900440761021, 51.1541805267334, 53.33813830784389, 48.57198326928275, 49.53063317707607, 49.244165897369385, 46.51635176794869, 43.946174894060405, 43.0483078275408, 40.60201733452933, 38.15158224105835, 37.104255948747905, 37.50520174843924, 45.99542447498867, 49.13016332898821, 46.29705967221941, 45.93597221374512, 50.18138408660889, 48.72597272055489, 45.62178856985909, 40.80546753747122, 36.95209387370518, 36.56661128997803, 35.19379663467407, 35.719938550676616, 35.59553105490548, 40.66212272644043, 49.06911645616804, 46.87376362936837, 46.15633085795811, 45.15957008089338, 45.80199357441494, 44.09242752620152, 42.22531802313668, 48.39113903045654, 46.037002495356965, 48.5353593145098, 46.175928252083914, 49.13403694970267, 47.63147163391113, 49.785944734300884, 30.41815730503627, 22.4398170539311, 47.65398032324654, 43.48828860691616, 50.464078494480674, 45.51923663275582, 48.81287384033203, 44.91080720084054, 50.00986780439104, 46.44756460189819, 48.910895551954, 46.747990812574116, 50.817154679979595, 47.95081778935024, 47.70170055116926, 40.871048109872, 37.518882751464844, 35.55942126682827, 37.45478214536394, 36.227580887930735, 34.57301330566406, 34.624183314187185, 40.02784252166748, 43.47811644417899, 50.10458217348371, 46.90290437425886, 48.37043339865548, 47.34485844203404, 49.25937550408499, 49.82792575018746, 48.5002326965332, 43.539455141339985, 38.95639903204781, 41.41722168241228, 44.63990388597761, 48.75288656779698, 47.95859282357352, 44.00110387802124, 44.9114533833095, 44.77128389903477, 44.43959774289812, 44.47664206368582, 45.13379226412092, 45.23906094687325, 49.41420568738665, 46.463027817862375, 47.65507466452462, 46.097715854644775, 48.49799885068621, 50.47264909744263, 49.444687434605186, 47.49435935701643, 45.938595158713206, 34.99397339139666, 24.628490924835205, 14.939820323671613, 13.813095229012625, 10.113668458802358, 5.038019810404096, 5.948462247848511, 16.601376056671143, 1.0170102162020547, 0.1841116292136056, 4.8430012464523315, 41.61113200868879, 48.70004899161202, 54.33105673108782, 30.43050077983311, 23.572062492370605, 30.011201313563756, 48.20388160433088, 49.16849306651524, 37.143471581595286, 1.094347357749939, 0.06332288961857557, 0.09560337210340158, 0.011751672668781663, 0.027719802655545727, 0.06987893568085772, 0.07313067226537637, 0.030549054499715567, 0.012332642833436174, 0.07498495919363839, 0.024722900075305785, 0.031676898444337506, 0.02316703454458288, 0.013028979218298835, 0.03384840049381767, 0.08388868892299277, 0.21305882877537183, 0.13156860508024693, 0.14212730207613536, 0.14825037494301796, 0.13644191143768175, 0.09555025638214179, 0.13256624154746532, 0.0594508091786078, 0.13945991306432656, 0.1312677562236786, 0.1643678072307791, 0.21812793319778784, 0.09170445560344628, 0.06761633351977382, 0.17198736193989003, 1.1153494822127479, 33.42112704685756, 50.153855323791504, 58.62546730041504, 35.90958963121687, 36.500374112810405, 45.049097197396414, 53.61440215791975, 35.13500792639596, 46.46965639931815, 21.828974860055105, 0.1720275447836944, 0.8882722013763019, 17.67034251349313, 13.471960391317095, 8.734188744000026, 26.867080654416764, 17.1874965599605, 8.366708942822047, 30.42026260920933, 59.94154644012451, 56.51746375220162, 54.98018176215035, 52.45721789768764, 54.20031247820173, 51.74002136502947, 52.29869474683489, 41.98360061645508, 42.77861697333199, 47.475988319941926, 50.134563650403706, 50.20146785463606, 53.40867294584002, 52.92942442212786, 49.76969289779663, 50.878521169934956, 51.31583384105137, 47.7955116544451, 46.78623022351946, 44.16054766518729, 43.71338939666748, 40.084331376211985, 40.195738792419434, 39.20850052152361, 49.51505878993443, 51.35266276768276, 47.717115129743306, 46.1407356262207, 51.8685804094587, 50.87217051642281, 47.42011438097273, 42.68498304912022, 39.59767607280186, 36.90866068431309, 37.1861925806318, 37.470391273498535, 37.8441070829119, 42.317729064396445, 50.593040534428184, 48.42435141972133, 48.778455938611714, 46.7446174621582, 48.367911202566965, 45.453461510794504, 43.182289940970286, 47.18908330372402, 47.96558271135603, 48.27340875353132, 46.85119935444423, 51.5658335004534, 49.91816200528826, 50.54792588097708, 32.28450945445469, 25.14877724647522, 47.900620528629844, 44.96218565532139, 52.90299347468785, 48.74697365079607, 50.40498753956386, 47.63553285598755, 51.440220492226736, 47.83556801932198, 51.7904930795942, 49.01776579448155, 53.026560238429475, 49.14391033990042, 50.54008136476789, 42.91871697562081, 38.5943284034729, 38.102090222494944, 39.73750162124634, 38.379490103040425, 36.37123836789812, 37.10823031834194, 42.8536262512207, 43.31204407555716, 52.45321920939854, 50.64376933234078, 49.94120223181588, 49.80419070380074, 51.41344908305577, 53.199761458805625, 51.45878607886178, 47.15779903956822, 39.18570000784737, 43.60819367000035, 48.3608900478908, 51.54028844833374, 49.86395910808018, 46.37849603380476, 47.11087785448347, 46.69580289295742, 45.71368891852242, 44.864309855869834, 45.63224908283779, 45.73233788354056, 51.706374713352744, 48.916124071393696, 49.555667536599294, 47.26401962552752, 48.359180791037424, 50.150794642312185, 50.08249037606375, 48.26051984514509, 46.1883898462568, 36.38461365018572, 24.887597935540335, 17.63832000323704, 16.607139587402344, 14.079800963401794, 6.7062419056892395, 9.431176441056387, 20.288574865886144, 1.8633500933647156, 0.30545722214238985, 5.85337267603193, 47.0002521106175, 58.36854376111712, 63.87959085191999, 35.50862646102905, 29.14817946297782, 37.6902357510158, 56.584652832576204, 56.66590854099819, 46.49247775759016, 1.951245891196387, 0.23769507823245867, 0.15885989421180316, 0.10285398018147264, 0.10927862115204334, 0.20957315367247376, 0.13920854298131807, 0.15121672648404325, 0.12036599192236151, 0.12309947024498667, 0.057550795775439055, 0.11965000177068369, 0.19746836035379342, 0.09273741660373551, 0.20738467467682703, 0.12361093637134347], [0.00946519710123539, 0.028055136358099322, 0.03874994069337845, 0.055225781963339875, 0.004005326482001692, 0.03231806314683386, 0.03862564325598734, 0.04647913648347769, 0.040853188905332766, 0.06503099296241999, 0.05168786305668099, 0.06065411639532872, 0.0656291555081095, 0.01885914632917515, 0.10339751387281076, 1.007095788206373, 22.352424349103654, 37.31388310023716, 38.45101833343506, 23.34184088025774, 21.206468377794536, 23.44572513444083, 34.93486854008266, 23.389811243329728, 33.612292834690635, 8.761231132916041, 0.03423181349145515, 0.12014242820441723, 1.7413120418787003, 3.8042954972812106, 7.780736088752747, 14.210111822400775, 7.495746169771467, 13.461098619869777, 43.8742401940482, 53.231730120522634, 49.00336217880249, 49.3423022542681, 49.09885127203805, 52.02493224825178, 47.43164839063372, 42.92551578794207, 36.24063307898385, 37.46746955599104, 39.62720591681344, 44.51430477414812, 46.19942011151995, 48.55319881439209, 48.33015816552298, 46.671796866825645, 46.235585485185894, 47.77920423235212, 44.119230202266145, 41.750050817217144, 36.58997113364083, 35.5551689692906, 34.23648425510952, 34.49301174708775, 31.899752957480295, 36.991913999829976, 44.849544933864046, 47.9224830354963, 46.99936621529715, 45.73344612121582, 42.76703780038016, 37.10516963686262, 33.50842421395438, 33.684171949114116, 34.784856932503835, 32.45330204282488, 36.93722472872053, 34.621747970581055, 40.188373701913015, 47.584275994982036, 44.039131368909565, 45.01365443638393, 47.10771295002529, 43.96133933748518, 42.1600535937718, 43.3383013180324, 44.8575770514352, 46.44724498476301, 47.62270300728934, 43.760324478149414, 46.89973946980068, 45.192938804626465, 50.443449292864116, 31.355052403041295, 21.579742976597377, 47.742667130061555, 44.67877210889544, 47.05978775024414, 42.77920062201363, 44.753527777535574, 41.97283785683768, 44.89667109080723, 42.005431856427876, 44.808428968702046, 41.70449147905622, 45.08356373650687, 44.08848442350115, 43.529362882886616, 35.7867420060294, 35.768568992614746, 33.53560904094151, 36.553017139434814, 34.05615765707833, 37.364462511880056, 34.256033011845176, 34.981313773563926, 36.32991395677839, 38.982350553785054, 40.95306812013899, 42.63750600814819, 41.64474739347185, 44.32889904294695, 43.33073820386614, 40.22561604636056, 35.47195734296526, 36.14023855754307, 40.45602525983538, 46.1923885345459, 45.399335043770925, 44.69757740838187, 43.88555186135428, 47.02736398151943, 46.86171545301165, 44.15145247323172, 43.05485650471279, 44.27303205217634, 48.170217582157676, 49.116266931806294, 47.509662764413015, 50.74363579068865, 47.78539160319737, 45.84035457883562, 42.97531352724348, 46.36373805999756, 47.820445265088765, 48.01730162756783, 42.32096345084054, 39.227017470768516, 32.02960784094674, 18.301421335765294, 11.92879935673305, 0.9758421395506177, 7.263802707195282, 8.383974347795759, 0.4892241827079228, 0.0715210447087884, 0.49638478990112034, 23.7325085571834, 46.92074040004185, 69.73952089037213, 47.32579953329903, 25.612319367272512, 32.422702176230295, 37.55950886862618, 42.96029152188982, 36.120408398764475, 2.150465943983623, 0.06190053094178438, 0.040138803488974056, 0.017037976998835802, 0.06439209117421082, 0.016358710858704786, 0.006423300439824483, 0.022382044166858708, 0.0601714269391128, 0.012463404165048684, 0.041894472137625725, 0.04138625280133315, 0.008811702569281417, 0.016663622443697283, 0.0691572797617742, 0.05407164478674531, 0.049693536678595204, 0.07493428619844572, 0.07453105997826372, 0.06163947816405978, 0.017159003897437027, 0.04884958500042558, 0.013134197099134326, 0.014236115917031254, 0.026131772868601338, 0.04692012317744749, 0.04046432727149554, 0.04710260160001261, 0.023508089993681227, 0.0251641530942704, 0.009729395736940205, 1.8020438573190143, 31.080549921308243, 45.966832637786865, 45.24388994489397, 28.298143795558385, 23.925612892423356, 30.10154526574271, 40.843627044132774, 24.978016580854142, 37.747051170894075, 10.434329560824803, 0.08899019339254924, 0.11491356949721064, 2.9687717940126146, 7.993378758430481, 7.7874133075986585, 10.13976502418518, 4.947886475494929, 12.202387281826564, 46.462218352726524, 54.40466594696045, 50.30950539452689, 51.15343359538487, 50.6308456829616, 53.834851128714426, 50.241065638405935, 44.54990039552961, 38.341278484889436, 39.86667210715157, 41.3698662349156, 45.49147163118635, 47.679674761635916, 49.0474728175572, 47.87253590992519, 46.59855243137905, 47.361971855163574, 48.94454915182931, 46.09243869781494, 42.56450128555298, 38.54953684125628, 37.14604936327253, 35.9061016355242, 36.68073197773525, 34.2979862349374, 40.09005669185093, 47.67206301007952, 48.60636643001011, 49.182201862335205, 49.10639354160854, 44.76653133119856, 39.585923194885254, 35.46423094613211, 35.863828795296804, 37.535297870635986, 34.56656190327236, 37.847004481724326, 35.78848252977644, 43.11455542700631, 47.87556185041155, 46.34247309820992, 47.19753231321062, 47.156965255737305, 46.694951738630024, 44.00343499864851, 44.38373075212751, 47.95978791373116, 47.2093824659075, 48.853736196245464, 44.85079213551113, 47.5668568611145, 45.99211365836007, 51.76747022356306, 32.61329126358032, 23.792033774512156, 50.73478031158447, 44.232207911355154, 49.29331398010254, 45.293413230351035, 44.78696250915527, 44.740340096609934, 47.17393970489502, 44.13874421800886, 46.4288009916033, 43.38135583060128, 46.935571329934255, 47.28873436791556, 45.23484686442784, 36.29958159582955, 36.602530002593994, 35.95416579927717, 38.67639010293143, 36.41653367451259, 38.19937195096697, 35.96202768598284, 36.94089337757656, 39.1100514956883, 41.1942400932312, 44.12923213413784, 44.318619183131624, 44.35452052525112, 47.20413310187203, 46.12622083936419, 43.20591729027884, 38.3091013772147, 38.22626495361328, 42.30293982369559, 47.24899762017386, 46.47024004799979, 47.10214744295393, 46.56079939433506, 48.95194550922939, 46.998428208487375, 45.404719897678916, 44.18539094924927, 45.35318510872977, 49.10935000010899, 50.50135905402047, 50.32336010251726, 51.768279688698904, 49.45539460863386, 47.471468516758506, 45.50454119273594, 47.11741610935756, 49.3352289881025, 49.00546748297555, 45.306465421404155, 42.60862929480416, 34.761858395167756, 17.401851960590907, 8.753724472863333, 5.5525699598448615, 9.588296055793762, 10.354535579681396, 0.5502308319721902, 0.04887248555730496, 0.6914290296179908, 28.046858719417028, 52.647341455732075, 60.745953287397114, 44.10191529137747, 30.876863479614258, 36.86972297940935, 43.27508660725185, 50.19403328214373, 41.564603396824424, 3.4760048389434814, 0.054506080225110054, 0.008009018542777215, 0.012510806621451463, 0.026952840953267047, 0.07419099858296768, 0.022667083157492534, 0.06798274921519415, 0.02866078314504453, 0.06232525993670736, 0.04952908353880048, 0.016109242370086055, 0.035805393875177415, 0.050280262516545396, 0.0325802049732634, 0.1055074863667999, 0.11733570881187916, 0.08023714593478612, 0.17286284853305134, 0.12434716043727738, 0.11289244437856333, 0.2127644938549825, 0.0934433847931879, 0.1551843514399869, 0.11007861393902983, 0.2150633976395641, 0.19157871710402624, 0.12277272849210671, 0.13176668302289077, 0.084412796156747, 0.1531561424157449, 2.8724832236766815, 42.87134763172695, 52.850023882729666, 53.511624404362266, 33.13583748681204, 30.842150279453822, 30.87637710571289, 42.63733230318342, 31.75532422746931, 45.45029313223702, 11.696995292391096, 0.27632445682372364, 0.3108501913292067, 5.13327831029892, 8.542959553854805, 14.824634824480329, 21.711173364094325, 14.518180183001927, 18.965337344578334, 47.758324895586284, 57.49129894801548, 52.18445941380092, 53.43167495727539, 53.30779205049787, 56.88595451627459, 52.304930755070274, 47.05396515982491, 40.217118399483816, 41.91775253840855, 42.69692005429949, 48.412577697208945, 49.671483584812705, 51.102802072252544, 49.95646047592163, 47.43882935387747, 49.008423941476, 52.2943833896092, 47.773444175720215, 45.886952672685894, 40.70102916445051, 39.605544907706125, 39.21203020640782, 38.2529182434082, 36.17120320456368, 40.832954611097065, 48.66168103899275, 51.15478502001081, 50.96187176023211, 50.28169870376587, 46.186048303331646, 40.495887075151714, 36.149361542293, 37.34049817493984, 38.389186314174104, 35.724885668073384, 40.900894096919465, 38.084441798073904, 45.175985200064524, 50.53756264277867, 47.59322527476719, 49.157573972429546, 48.13651187079293, 48.994326046534944, 44.51038599014282, 45.75378002439226, 48.10227462223598, 48.60224962234497, 50.856352942330496, 46.69251292092459, 49.274915150233674, 47.310503074101035, 53.61710500717163, 34.51443999154227, 26.81024091584342, 51.729751927512034, 47.50161327634539, 50.80052069255284, 47.12404121671404, 47.356937885284424, 46.34044075012207, 48.14396728788103, 45.83434091295515, 48.42220095225743, 45.52299560819353, 50.38296522412981, 48.99634102412632, 47.21677187510899, 40.07321078436715, 39.38508204051426, 37.339970111846924, 40.22709253856114, 38.10875007084438, 41.56028509140015, 38.05484594617571, 39.383873053959434, 41.35128327778408, 43.229846886226106, 45.299708298274446, 47.10015330995832, 45.94853803089687, 49.21178729193551, 48.24201679229736, 45.04438631875174, 40.150565079280305, 39.685438769204275, 44.79277120317732, 49.32448359898159, 48.24817984444754, 48.3316068649292, 49.31919601985386, 50.90129041671753, 50.29273591722761, 45.940985339028494, 45.12764310836792, 46.525658879961284, 50.69220869881766, 52.83064883095877, 51.98426444189889, 53.61092458452497, 51.441908904484336, 47.34541777202061, 47.14048065458025, 47.34388222013201, 49.82725524902344, 49.219544955662315, 47.52477857044765, 44.27210446766445, 37.002124377659385, 18.852474280766078, 16.43560767173767, 7.838834319795881, 9.68811127117702, 11.470885276794434, 0.35627574952585356, 0.2652629789497171, 0.8957701761807714, 32.737017835889546, 56.163897718702046, 72.94796970912388, 57.120063645499094, 34.74933079310826, 43.57628059387207, 50.188287121909006, 56.95139612470354, 51.0082231930324, 5.685330058847155, 0.14202138275972434, 0.11017985814916235, 0.17818170812513145, 0.16860152647963592, 0.16653093615812914, 0.1916550930057253, 0.13507665826806, 0.10094863349305731, 0.18579677093241895, 0.16328449893210614, 0.13530797085591725, 0.15828892056431088, 0.11686268847967897, 0.1656167594982045, 0.19739518713738236], [0.02824211516417563, 0.008468322289575423, 0.04233874294108578, 0.03277092081095491, 0.020626046428722993, 0.008860329781392855, 0.0431851068112467, 0.02077620622834989, 0.04002836512933884, 0.06602758448570967, 0.029874607654554502, 0.033835766171770434, 0.03226908648918782, 0.07702403156352894, 0.018683259874316197, 2.924062090260642, 24.396137952804565, 38.53769016265869, 41.25678082874843, 33.27687897000994, 27.08965229988098, 29.93465300968715, 35.27398579461234, 25.498269898550852, 35.97499997275216, 5.400982848235539, 0.026553158382219926, 0.16628613429410116, 2.179233657462256, 6.636251398495265, 6.039025502545493, 4.6107286129678995, 5.627617018563407, 19.598134108952113, 55.771102155957905, 49.57872860772269, 48.72302668435233, 43.457911082676475, 44.412527561187744, 40.233950410570415, 39.62827941349575, 38.36899484906878, 39.924984863826204, 43.61188663755144, 45.207054070064, 45.86103241784232, 46.063558510371614, 46.26204422542027, 48.69969463348389, 46.292362689971924, 45.120750495365684, 48.06207234518868, 46.94593109403338, 44.51674706595284, 42.715360573359895, 37.84529869897025, 34.765141419001985, 33.578267506190706, 32.835432120731895, 30.377850805010112, 34.74866029194423, 38.03302165440151, 41.36860513687134, 38.755665574754985, 36.262988907950266, 31.98807498386928, 33.100919314793174, 32.90602234431675, 34.56190313611712, 32.374036993299214, 35.074885163988384, 33.80268737248012, 39.37540667397635, 48.11022336142403, 45.64963347571236, 45.353244168417795, 43.985904693603516, 46.0241413797651, 46.940313475472585, 43.320357595171245, 44.028153215135845, 48.20046656472342, 44.58732339314052, 42.20929895128523, 45.77308212007795, 44.46134213038853, 50.88463905879429, 34.32301017216274, 23.584692580359324, 48.19807638440813, 43.630386216299875, 48.16670874186924, 42.43192270823887, 41.78410741261074, 38.670025553022114, 40.30794177736555, 39.3601519039699, 41.7118114062718, 38.20430169786726, 39.89772708075387, 37.399533544267925, 36.171616622379844, 37.24474852425711, 35.603160176958355, 34.55673715046474, 34.97935438156128, 35.554376874651226, 35.752549920763286, 35.85370179585048, 35.39942509787423, 34.20689882550921, 35.173167433057515, 34.659393310546875, 36.10528564453125, 36.02555853979928, 34.429244654519216, 35.338121141706196, 34.114939417157856, 34.745721203940256, 38.04070288794381, 39.34919112069266, 44.18204191752842, 43.72807788848877, 44.97123915808541, 45.34031704493931, 45.597747802734375, 45.99751935686384, 44.70455339976719, 41.89917305537632, 47.70548037120274, 49.42341899871826, 45.80521059036255, 43.753723689488, 46.7905033656529, 47.99255214418684, 47.789873191288535, 45.017045157296316, 52.58563450404576, 48.54259238924299, 53.03125722067696, 51.26486185618809, 55.614996978214805, 43.62753745487758, 30.869487966809952, 9.075801270348684, 5.720758489200047, 3.666295153754098, 2.0431657816682542, 0.7917936955179486, 0.0580400534506355, 0.7831004677074296, 13.024822098868233, 48.15207930973598, 47.070887497493196, 29.70806530543736, 17.894310746874126, 25.278547014508927, 42.335078716278076, 46.22350604193551, 38.47364166804722, 5.806860131876809, 0.1026216090789863, 0.04344294333298292, 0.03930577961727977, 0.030258770433387587, 0.02989150656919394, 0.01362106463472758, 0.03624075212116752, 0.06565539445728064, 0.0012596492659732966, 0.030223517146493708, 0.0200647978843855, 0.0724836823397449, 0.02010775763275368, 0.04515395759205733, 0.05500608589500189, 0.05257221470986094, 0.02909960870497993, 0.02410316520503589, 0.03412785853392311, 0.00711544559869383, 0.009494687081314623, 0.01278173378003495, 0.039045944809913635, 0.025533905485644937, 0.026425368185820322, 0.06072469760796853, 0.023129182468567575, 0.028257724862279635, 0.016767100730378712, 0.04189691147101777, 4.247769049235752, 31.886895315987722, 46.390488624572754, 47.21076168332781, 36.84518889018467, 25.200463158743723, 27.010163170950754, 34.61651250294277, 26.257631574358257, 40.01358481815883, 6.068308251244681, 0.2522621394268104, 0.40122950875333374, 3.761235773563385, 9.046747377940587, 6.185340668473925, 7.094570645264216, 5.059304748262678, 20.428270135607036, 56.07850783211844, 51.48007883344378, 49.88810409818377, 46.00853572572981, 45.1856883593968, 42.01522534234183, 41.152363300323486, 40.16053574425833, 41.63933474676949, 45.55620452335903, 46.38884537560599, 46.50992815835135, 48.41780621664864, 47.79184300558907, 50.359796455928254, 44.752020018441335, 45.440676825387136, 49.86654036385672, 49.6182985986982, 46.62906544549124, 43.693854536329, 38.37976108278547, 36.32863548823765, 35.816973618098665, 35.07807438714163, 33.13138369151524, 37.074927602495464, 41.12116241455078, 43.06260027204241, 41.07583236694336, 38.237854548863, 34.82437481198992, 36.15627152579171, 34.096637862069265, 35.980384826660156, 34.15600674492972, 37.038321018218994, 36.96708461216518, 41.206017289842876, 48.94862427030291, 47.70335422243391, 47.425238677433555, 46.57187829698835, 47.80967208317348, 46.98012317929949, 44.429713930402485, 45.564663955143516, 49.02338688714163, 46.023224217551096, 44.20292820249285, 47.10856063025338, 47.100865500313894, 51.091466086251394, 37.0870487349374, 25.254228319440568, 50.136971201215474, 45.4582279750279, 50.118440355573384, 43.375633989061626, 42.61476802825928, 40.608541693006245, 42.51025669915335, 40.592077936444966, 43.076917035239084, 40.518604210444856, 41.719669818878174, 39.781806809561594, 37.99265262058803, 37.45644276482718, 35.729002475738525, 36.65428018569946, 36.71127278464181, 36.82138783591134, 37.97344085148403, 36.30796112333025, 36.61709690093994, 35.94425419398716, 36.514840262276785, 35.89310155596052, 37.02982684544155, 36.16076353618077, 37.64587845121111, 37.62658330372402, 35.96414341245379, 36.3524990762983, 40.115553106580464, 42.18053340911865, 47.54443155016218, 47.22039188657488, 45.663397857121055, 47.11236824308123, 46.410416058131624, 46.718860489981516, 45.205852031707764, 43.238070079258506, 48.758417333875386, 50.46026740755354, 47.16426433835711, 46.397683484213694, 48.17113821847098, 50.160073961530415, 49.5530480657305, 47.72774934768677, 52.936761719839915, 49.71073048455374, 54.22209855488369, 51.529820987156455, 56.98779773712158, 45.63862405504499, 29.85346678325108, 11.113057391984121, 10.066828915051051, 7.2273277044296265, 3.890664645603725, 1.6315120479890277, 0.11334182455071382, 0.37188368343881195, 16.444737604686193, 52.75191184452602, 51.06141512734549, 34.84880815233503, 21.63580104282924, 29.696788379124232, 48.099085399082725, 51.108419690813335, 45.75296013695853, 7.801372238567897, 0.10358475561120681, 0.0688496387696692, 0.05678287733878408, 0.006809880075577114, 0.04801601151536618, 0.045008310050304444, 0.019891915643321614, 0.0232769165055028, 0.07892020445849214, 0.02505977574868926, 0.07149220018514565, 0.057798800324755054, 0.005406269321351179, 0.05242653324135712, 0.05085599947986858, 0.10133514061037983, 0.07655798657132046, 0.11503513583115169, 0.15326269955507346, 0.10357700674129383, 0.1571236995181867, 0.10603119326489312, 0.1358347718736955, 0.1222776286303997, 0.12685858138969966, 0.12615179217287473, 0.09719824152333395, 0.07786272120262895, 0.19082633033394814, 0.09523013713104383, 6.602151811122894, 43.454568999154226, 53.35633563995361, 53.87074899673462, 45.139635699135916, 37.515728269304546, 38.76452105385916, 43.53690167835781, 36.25239985329764, 47.67360898426601, 6.564539909362793, 0.464336875293936, 0.5302271310772214, 4.575960695743561, 13.822305934769766, 15.176618405750819, 12.433208176067897, 12.545129758971077, 23.33490136691502, 57.80922072274344, 54.020520891462056, 51.93119062696184, 47.2697935785566, 48.086703709193635, 44.87606620788574, 43.234981604984824, 43.02215828214373, 43.511301040649414, 46.84424768175398, 48.698697566986084, 49.94975199018206, 49.480686051504954, 49.70282343455723, 52.38155548913138, 46.589606625693186, 44.62553153719221, 50.91354356493269, 51.25756624766758, 49.02978965214321, 46.57103756495884, 41.559631960732595, 38.17543193272182, 38.19546011516026, 36.785232884543284, 34.93445859636579, 37.57750470297677, 42.36877053124564, 44.6195387159075, 43.647492681230815, 40.172827107565745, 36.19456999642508, 37.35569735935756, 36.68178810392107, 38.44879838398525, 35.03478363582066, 37.81180143356323, 37.31855228969029, 42.18685974393572, 52.865886620112825, 50.15863915852138, 49.599924087524414, 46.91814177376883, 50.166504519326345, 49.2473064831325, 45.58163145610264, 45.749906403677805, 51.096628597804475, 48.59171267918178, 45.93713256290981, 47.5393419946943, 48.852443831307546, 52.581733090536936, 38.19365358352661, 27.605696746281215, 49.90342835017613, 47.91184534345354, 51.31682048525129, 45.26069416318621, 44.851132597242085, 42.5468876021249, 43.70471109662737, 43.6067727633885, 45.14746631894793, 41.926444734845845, 43.72806051799229, 41.98099504198347, 39.57637984412057, 40.39556203569685, 38.73070764541626, 39.99660689490182, 39.265048435756135, 38.43031964983259, 39.885001455034526, 38.91099950245449, 39.595028809138704, 39.33506195885794, 39.07396950040545, 38.63580567496163, 39.70974704197475, 37.97949620655605, 38.667753492082866, 39.34919459479195, 38.43434613091605, 38.38324213027954, 43.58089419773647, 43.14036798477173, 49.82998589106968, 49.08598320824759, 48.94333321707589, 50.95489576884678, 50.43038667951311, 50.239418915339876, 47.85228885923113, 44.027381965092246, 50.56658179419381, 50.493458952222554, 48.726705755506245, 47.3730194909232, 51.4558504649571, 51.282076018197195, 52.671736580984934, 49.03184284482683, 56.61630187715803, 51.92035838535854, 57.018269062042236, 53.66220923832485, 60.6878524507795, 45.32682016917637, 39.867908886500764, 16.472389698028564, 9.58702974660056, 8.35012880393437, 5.036125992025648, 1.8589903158800942, 0.19306166895798274, 1.3401951427970613, 19.456965821129934, 58.61990179334368, 54.49983889716012, 38.105991636003765, 26.559205974851334, 35.85449736458914, 53.608523981911794, 59.78136266980852, 54.21827009746006, 11.3259745155062, 0.2339852558715003, 0.2235849696610655, 0.11531507223844528, 0.11769841292074748, 0.10616655421576329, 0.1298466053392206, 0.09473895241639443, 0.1057247668504715, 0.1547313750322376, 0.17534906869488104, 0.11237980438662426, 0.18810206651687622, 0.08591831608542375, 0.24387932781662258, 0.11342886702290603], [0.04024698571967227, 0.038309948053210974, 0.023664945237604634, 0.030427857967359678, 0.02305895579047501, 0.05039184420768704, 0.005137805244885385, 0.023733326300446476, 0.04110156325623393, 0.06502972410193511, 0.06678978287215744, 0.007483756103153739, 0.012353902183739203, 0.0880509652197361, 0.055777071309941154, 4.716180120195661, 30.2618054662432, 37.92304556710379, 37.6163763999939, 24.094858850751603, 15.6565808568682, 23.322036777223857, 27.53900272505624, 26.47697057042803, 35.1604939188276, 2.471651634999684, 0.1658676274652992, 0.8457794615200588, 0.7890468771968568, 7.612141524042402, 4.655990481376648, 7.095053110803876, 8.476697189467293, 39.02576984677996, 53.58636270250593, 48.54249164036342, 45.873292514256065, 38.41010039193289, 39.573986189705984, 43.35917370659964, 46.31261321476528, 46.179315498897004, 45.90981224605015, 43.57198313304356, 46.45031956263951, 48.32355042866298, 46.916321345738, 47.866098403930664, 47.398998805454795, 44.068338121686665, 44.23490033830915, 46.52500922339303, 44.71890490395682, 46.899572713034495, 43.12657233646938, 38.1516169820513, 36.70727757045201, 34.35987731388637, 31.978149482182094, 33.272880281720845, 32.008082321711946, 32.0233370917184, 33.558562414986746, 32.89719813210623, 35.665110315595356, 34.94642686843872, 33.40852648871285, 34.23630012784685, 34.70658547537667, 33.74670573643276, 33.89522000721523, 34.10809196744646, 33.941005161830354, 40.10429355076381, 42.026113169533865, 44.028823716299875, 44.88346603938511, 45.386890820094514, 45.01130247116089, 43.441044330596924, 43.88040672029768, 48.15828405107771, 43.66554757526943, 43.125735078539165, 46.27919932774135, 46.95792715890067, 48.89756890705654, 32.61065442221505, 24.71997438158308, 48.36351646695818, 44.711699622017996, 46.36272709710257, 41.55876691000802, 40.310269423893516, 40.77292217527117, 42.333654335566926, 40.52467346191406, 39.58115325655256, 38.349689279283794, 38.037124565669465, 34.352289881025044, 36.541896547589985, 35.04756484712873, 34.291208267211914, 34.37941217422485, 36.00961937223162, 33.911423206329346, 39.18192713601248, 34.2689323425293, 34.445631980895996, 34.06345673969814, 35.37960188729422, 33.77539832251412, 34.66378804615566, 34.9962454523359, 35.618432317461284, 35.353862285614014, 35.3453437941415, 34.940573011125835, 37.26770537240164, 38.03243105752127, 40.76055090767996, 41.2790150642395, 42.29135717664446, 43.260606561388286, 45.602952003479004, 48.09922783715384, 43.61006620952061, 44.60057708195278, 48.93704162325178, 45.851822580610005, 46.78550066266741, 43.297237464359824, 46.28742946897234, 44.97929212025234, 46.98052964891706, 46.7846599306379, 50.94563382012503, 48.260078634534565, 51.37560224533081, 52.909114837646484, 54.29400198800223, 49.96273817334856, 26.684072051729473, 9.196910108838763, 9.456493939672198, 5.462910405227116, 3.7100045340401784, 2.184591369969504, 0.0665625822065132, 0.058151957445911, 11.252526845250811, 34.2536358833313, 30.457546642848424, 25.73204551424299, 23.748614481517247, 25.754027877535137, 40.5577712059021, 42.120987347194124, 39.97688095910208, 8.84881317615509, 0.0819686044539724, 0.017111628582434993, 0.0401545963915331, 0.025014288457376615, 0.06932272017002106, 0.029403310801301683, 0.012202186842582055, 0.030935273239655153, 0.04159275475623352, 0.11594574339687824, 0.04104465791689498, 0.04687683264325772, 0.016854521485843828, 0.08264091730649982, 0.0831121327355504, 0.05196002345266087, 0.02499420042814953, 0.027006231481209397, 0.007588683062099985, 0.014096159587747284, 0.03433233166911772, 0.04946101290572967, 0.0435097688542945, 0.03338545640664441, 0.07831747537212712, 0.04481180291622877, 0.004881592118181288, 0.029283294919878244, 0.07262631718601499, 0.055757845020187755, 6.849470334393637, 37.04264974594116, 45.57843181065151, 45.162755829947336, 32.380512714385986, 28.135535103934153, 33.681316239493235, 31.89897128513881, 28.813920736312866, 39.75257921218872, 2.6554566749504636, 0.20337700258408273, 2.16635799407959, 3.407728148358209, 10.782435178756714, 7.337207385471888, 7.378858361925397, 6.421926396233695, 42.95570223672049, 55.08977222442627, 50.675880432128906, 47.23680700574602, 41.19956241335188, 41.70467560631888, 45.46616281781878, 46.34832695552281, 47.75767523901803, 48.13092204502651, 47.09363589968, 48.23697240012032, 49.04365478243147, 47.23973914555141, 49.89667122704642, 47.89974158150809, 44.64841195515224, 45.36604275022234, 48.08406686782837, 46.05400126320975, 47.831892422267366, 44.4403828893389, 40.10537052154541, 38.40688337598528, 35.966929640088765, 35.171948024204795, 34.85045140130179, 33.2934365272522, 34.33576706477574, 36.13497529711042, 35.225605487823486, 37.93522923333304, 36.055150917598176, 35.64339372089931, 35.75679874420166, 35.77056312561035, 33.80707515989031, 34.929914474487305, 35.10833726610456, 35.36285672869001, 42.42754881722586, 44.05345508030483, 47.61637667247227, 47.009781564985005, 46.93089519228254, 47.42621142523629, 44.17848443984985, 46.12750973020281, 47.89657320295061, 45.38079724993025, 45.94154119491577, 47.68728303909302, 49.09667648587908, 49.81077412196568, 33.679815428597585, 24.608474901744298, 49.70862170628139, 47.290231704711914, 47.99235759462629, 44.51456880569458, 41.781533105032786, 42.13327176230294, 43.75998054231916, 42.43952056339809, 42.39872768947056, 39.34703370503017, 39.32600845609392, 36.35959318705967, 38.48137501307896, 36.195226601191926, 35.766116278512136, 35.63907194137573, 36.69760567801339, 35.766519274030415, 40.90289865221296, 36.19589362825666, 36.043873991285054, 36.86979593549456, 37.51213952473232, 36.05713810239519, 36.22948122024536, 35.841483388628276, 37.036281721932546, 36.873377731868196, 37.088288988385884, 37.48792157854353, 39.73357936314174, 40.74214512961251, 43.453624044145855, 42.799055099487305, 43.949801853724885, 44.70986877168928, 47.683593545641216, 48.18626792090279, 45.34034831183297, 43.99448571886335, 48.56900944028582, 46.95305299758911, 47.12175873347691, 45.65737724304199, 47.910295895167756, 46.726361070360454, 48.90790435246059, 48.64956685474941, 53.289004121507915, 49.90217072623116, 53.521271978105815, 53.64975111825125, 55.532143184116904, 49.778221811567036, 31.428828375680105, 8.737121752330236, 11.25164702960423, 9.526178291865758, 3.33126083442143, 2.2142675604139055, 0.15917383879423141, 0.12066868639418057, 11.326572060585022, 43.74691445486886, 36.58548607145037, 33.279140608651296, 27.959043911525182, 30.503585406712123, 45.83025189808437, 49.106824329921174, 48.510436126164024, 12.322058711733137, 0.05002652773899691, 0.009832255708585893, 0.05362909406955753, 0.058710690321666856, 0.048019489007336755, 0.044556317518332174, 0.07703184150159359, 0.046422309175665886, 0.01206791918126068, 0.042484220849084, 0.030877292422311645, 0.02268471149727702, 0.033897519643817625, 0.06726580911449023, 0.028560108904327666, 0.12454735540917941, 0.13471746897058828, 0.07242861922298159, 0.08417693738426481, 0.12671053861933096, 0.14350257042263234, 0.13797485775181226, 0.1279652855758156, 0.13050420076719352, 0.27292646201593534, 0.13445889284568174, 0.14862498055611337, 0.09645757983837809, 0.2383017156805311, 0.11358128634414502, 9.946342808859688, 45.7690486907959, 54.028084005628315, 51.88986274174282, 35.95518718447004, 27.258837461471558, 32.37645149230957, 38.031010150909424, 35.55215345110212, 45.70314155306135, 3.4743535561220984, 0.3194362920309816, 1.9653841725417545, 2.280139305761882, 11.806766407830374, 12.78001708643777, 16.063050474439347, 12.907164778028216, 43.635256903512136, 57.411860193525044, 52.463915961129324, 49.98961727959769, 42.035444600241526, 43.69476475034441, 47.6322637285505, 50.174890995025635, 50.62267460141863, 49.96656663077218, 48.579296248299734, 51.03375087465559, 53.06943409783499, 46.93463332312447, 50.374040263039724, 48.073866912296836, 45.99008478437151, 45.09718567984444, 48.21676009041922, 49.3200159072876, 51.06911373138428, 47.620660236903596, 41.76992266518729, 40.811394350869314, 39.46039009094238, 37.24451575960432, 37.041107245853965, 36.09160811560494, 35.26468563079834, 37.09458753040859, 35.346848079136436, 39.442647865840364, 37.920707498277935, 36.805334023066926, 37.50266565595354, 37.907509395054404, 35.87760707310268, 36.989357062748496, 37.84985671724592, 37.89792782919747, 43.675823960985454, 45.456404072897776, 49.074866090502056, 48.851123673575266, 49.33082035609654, 49.2881167275565, 45.598640646253315, 47.27713087626866, 51.67378766196114, 48.08846160343715, 47.75555256434849, 48.76022386550903, 51.02322782788958, 51.76309980664934, 34.46035521371024, 27.76839402743748, 49.49109097889492, 49.99837895802089, 50.06963620867048, 45.632058007376536, 42.72725241524832, 44.16363613946097, 46.48876741954258, 43.490748269217356, 44.68788814544678, 42.642599037715364, 42.066207749503, 38.29223462513515, 40.86144917351859, 38.3333158493042, 37.62273052760533, 39.02897644042969, 38.509351934705464, 37.27039432525635, 42.74080835069929, 39.03700508390154, 38.669692039489746, 38.40755387714931, 40.53553349631173, 36.84412234170096, 37.46710130146572, 39.41194030216762, 39.11708654676165, 39.45309795652117, 40.41692427226475, 38.949575901031494, 42.934610979897634, 42.04952165058681, 45.94147866112845, 45.05277974264962, 47.14358649935041, 46.944096769605366, 50.54295791898455, 50.990296840667725, 45.95188358851841, 46.58768197468349, 50.75430474962507, 48.468858105795725, 49.62527459008353, 48.31001533780779, 50.40456369944981, 48.85334709712437, 50.849175453186035, 51.66585281917027, 54.888378688267295, 52.06420694078718, 56.947591985974995, 58.723951067243306, 58.08626971926008, 53.59803567613874, 32.540095465523855, 12.29371874673026, 18.56807061604091, 12.800921610423497, 9.345355766160147, 4.895400217601231, 0.3250408284366131, 0.2222011789147343, 15.15292157445635, 45.84894950049264, 41.36505113329206, 38.73777048928397, 32.24547100067139, 36.02235542024885, 53.19698912756783, 54.437127930777415, 55.24922295979091, 16.354876552309307, 0.1091712022732411, 0.0818735756246107, 0.1464022355420249, 0.09202442557684012, 0.15978956861155375, 0.138018365417208, 0.12364000481154237, 0.19207722321152687, 0.13090771197208337, 0.21825785908315862, 0.10745925163584095, 0.11389286283935819, 0.0791668722938214, 0.24346783703991345, 0.22503191844693252], [0.02874907072899597, 0.003100078706795882, 0.02388680074363947, 0.028943735640496016, 0.024976592444415604, 0.03087647139493908, 0.0743991324145879, 0.01799237382199083, 0.05243074694382293, 0.09070121443697385, 0.0053134635423443145, 0.04997170889484031, 0.0379093138368002, 0.05803413662527289, 0.07217439250754458, 6.676291261400495, 31.299029077802384, 36.302072525024414, 37.58145475387573, 14.75751175199236, 9.626015220369611, 15.608162334987096, 21.023885352270945, 31.153019632611954, 29.973587240491593, 1.2459358807121004, 0.38489233968513353, 2.652653293950217, 2.792889871767589, 5.335872147764478, 2.2596095502376556, 11.124535816056387, 20.400081293923513, 43.632689544132774, 53.262944902692524, 49.20766701017107, 46.30289615903582, 41.58870322363717, 45.83323962347848, 47.40654802322388, 49.60474961144583, 47.693550314222065, 48.37788881574358, 46.4030579158238, 47.79371901920864, 45.840406690325054, 45.54216916220528, 45.16736248561314, 46.49397162028721, 45.00831821986607, 45.96109342575073, 43.06273576191494, 44.749386651175364, 46.622440338134766, 42.15695469720023, 37.76442861557007, 35.01383481706892, 33.85844666617257, 34.44745588302612, 32.37500279290335, 34.03736277988979, 33.803750446864534, 33.65474285398211, 32.917129039764404, 34.6066460609436, 33.2124205316816, 33.801961285727366, 32.683051177433555, 33.5028726032802, 31.800126211983816, 32.978922843933105, 32.42665570122855, 33.85199873788016, 35.08587721415928, 40.819721766880576, 41.880308696201865, 44.802811350141255, 45.10684714998518, 45.076136112213135, 43.23934507369995, 45.544597557612825, 45.376961844308035, 42.490082604544504, 44.85640627997262, 47.822717326028005, 42.13043342317854, 42.79834985733032, 34.250554357256206, 23.97248022896903, 50.70125525338309, 43.98066227776663, 47.322544302259175, 42.41542073658535, 42.2926356451852, 42.27842310496739, 43.59777137211391, 42.61279821395874, 43.21652718952724, 40.38466726030622, 39.295311314719065, 35.99420826775687, 35.53120810644967, 32.1724419593811, 35.46665586744036, 32.93770612989153, 34.91013642719814, 34.69315113340105, 39.94159800665719, 38.35584538323538, 34.73353058951241, 35.99953406197684, 35.54938806806292, 34.541037695748464, 33.450497082301546, 36.01684202466692, 34.70534174782889, 34.75487545558384, 34.07635954448155, 34.34666531426566, 35.62604406901768, 36.1978634425572, 37.78552334649222, 38.20991931642805, 40.64267471858433, 43.016221046447754, 46.12509175709316, 45.178396224975586, 45.65509475980486, 46.15790809903826, 47.4013021332877, 45.373498167310444, 45.89275441850935, 44.22224766867501, 44.96232114519392, 41.56215068272182, 47.3017691884722, 45.725365366254536, 45.99479913711548, 45.098988737378804, 46.429898806980674, 48.16048663003104, 52.97725234712873, 52.80235924039568, 38.93387992041451, 16.03102970123291, 12.506113886833191, 10.76929439817156, 2.562824376991817, 1.936678124325616, 0.21147301101258822, 0.05554595549723931, 10.286248683929443, 31.897199494498118, 37.336454323359895, 35.81293671471732, 17.08464411326817, 22.049922364098684, 37.207742418561665, 46.70719446454729, 40.629427977970664, 9.21928070272718, 0.046121188905090094, 0.05783194676041603, 0.05446825868317059, 0.08018942456692457, 0.04389581796047943, 0.03295208626825895, 0.027100023680499623, 0.03962613296295915, 0.043861446769109795, 0.02234612252297146, 0.04292744331594024, 0.044095493853092194, 0.10618818591215781, 0.05748273192771843, 0.047414218807326894, 0.008561919410047787, 0.01703398721292615, 0.025004108735759343, 0.013945074435988707, 0.06382231853370156, 0.05745788397533553, 0.04664984910881945, 0.016872792737558484, 0.06500634857054267, 0.038818418447460444, 0.01456811631630574, 0.009816243978483337, 0.022275675320997834, 0.1243874654173851, 0.1049077631905675, 9.607420103890554, 38.888907705034526, 44.44320733206612, 43.86559663500105, 18.59612396785191, 12.907547797475543, 19.707239934376307, 25.85160664149693, 35.56214496067592, 33.9718725340707, 1.4500126157488142, 0.4415996553642409, 2.369768896273204, 5.612432599067688, 7.463180831500462, 5.869880293096815, 6.7350196072033475, 21.75552545275007, 49.07731185640608, 53.90036221912929, 52.68204770769392, 48.02123430797032, 42.96325145448957, 47.0303829738072, 50.201387950352256, 50.43105718067714, 49.64532709121704, 50.1832913671221, 49.027163233075825, 48.8710788999285, 48.11905452183315, 46.87088360105242, 46.32223646981375, 45.619777066367014, 45.43381895337786, 46.517498220716206, 44.681085859026226, 46.786893776484895, 47.96423128673008, 44.89661203111921, 39.33969293321882, 37.123318331582205, 36.81918178285871, 35.7438507761274, 34.368864808763774, 37.13868427276611, 35.601179940359934, 36.08374970299857, 35.31239891052246, 36.9665287562779, 34.70153066090175, 34.577713762010845, 33.707597800663535, 34.962928840092246, 33.604267665318076, 35.44474124908447, 35.349696840558735, 35.68559013094221, 36.99597174780709, 41.33249534879412, 43.76657090868269, 46.566177300044465, 46.985855443137034, 47.03104305267334, 45.100618089948384, 48.048783915383474, 45.49601922716413, 44.17750474384853, 47.10648659297398, 48.41145208903721, 43.849146774836946, 44.00120462690081, 35.17234059742519, 26.30659552982875, 51.41490125656128, 46.853540897369385, 48.48222296578543, 43.13742194856916, 42.895148686000276, 42.72216285978045, 44.223119667598176, 44.29914338248116, 44.591860566820415, 41.10014063971383, 42.123554706573486, 38.05793789454869, 37.85406732559204, 34.45977851322719, 36.552631514413015, 35.56486865452358, 37.17945630209786, 36.41178110667637, 40.53869840076992, 40.23351614815848, 36.547364779881065, 36.89131450653076, 36.265518052237375, 35.65113748822893, 34.79410151072911, 37.49391787392752, 37.81221832547869, 37.345827443259104, 35.45756414958409, 36.78990207399641, 38.30502625874111, 38.37280593599592, 38.969857692718506, 40.574453830718994, 42.40418202536446, 44.913225173950195, 49.15145260947091, 47.19352667672293, 45.50192519596645, 46.58904382160732, 48.21303238187517, 49.642474855695454, 47.92226069314139, 45.02368416104998, 46.52466181346348, 44.732235022953574, 48.79705279214041, 47.980834007263184, 47.482172216687886, 47.70907606397356, 48.62769392558506, 50.17002725601196, 54.7362756729126, 53.323314326150076, 37.49666588647025, 11.155617713928223, 13.364622013909475, 8.847454803330557, 3.9941589321408952, 3.7490073783057074, 0.3282052172081811, 0.03541909371103559, 11.066312517438616, 35.831123624529155, 42.27391719818115, 39.30652223314558, 17.073636429650442, 26.897100346429006, 42.96227175848824, 52.03407260349819, 47.70202364240374, 13.051709021840777, 0.07780382436301027, 0.02797442801030619, 0.018740904816825475, 0.07405699470213481, 0.03758311491193516, 0.023918763135692904, 0.044078228529542685, 0.06159014188285385, 0.02683406339825264, 0.03028151492721268, 0.06413347433720316, 0.0358803550313626, 0.04928599836836968, 0.077190679764109, 0.04983835640762534, 0.14073360471853189, 0.3076885709805148, 0.09722731674888305, 0.09936590306460857, 0.15974395748760017, 0.16782682947814465, 0.09697073551693133, 0.06889630840825182, 0.1333772266017539, 0.19315633816378458, 0.17843690514564514, 0.09196628191109214, 0.07332114383046116, 0.18734133376606874, 0.37512545234390665, 12.20310207775661, 47.51187923976353, 52.86669608524868, 51.3747615133013, 24.59625996862139, 17.14865439278739, 21.40139661516462, 30.91532870701381, 43.38670941761562, 39.34457751682827, 1.3600619967494691, 0.5276633000799588, 3.904918006488255, 5.746645740100315, 10.027682764189583, 9.598586337906973, 17.05702154976981, 24.435230255126953, 50.65983704158238, 56.80799225398472, 53.36265850067139, 50.13928147724697, 45.60943814686367, 49.2830445425851, 51.81244591304234, 52.67969921657017, 52.315207140786306, 51.87978785378592, 51.270045212336946, 49.2838887487139, 48.10069390705654, 45.690617425101145, 46.660127367292134, 45.85765906742641, 44.95912149974278, 47.20752729688372, 47.112211908612935, 47.88199935640608, 50.75543730599539, 45.91353300639561, 42.02161421094622, 39.94665976933071, 39.019499097551616, 38.03658955437796, 35.92812047685896, 38.6716479573931, 38.25638886860439, 37.65699904305594, 36.877862794058665, 37.56158985410418, 36.758426734379356, 36.68661710194179, 36.11064965384347, 36.57166263035366, 35.02790144511631, 37.431613377162385, 37.19214023862566, 37.39374222074236, 38.35595308031355, 43.49840865816389, 45.775597367967876, 48.10969182423183, 47.77412509918213, 46.88242455891201, 45.41790757860456, 48.986009052821565, 48.538444314684185, 45.26052393232073, 49.65607942853655, 50.06819098336356, 44.47063534600394, 46.03491803577968, 36.110931055886404, 28.68128136226109, 51.61970635822841, 48.69211762292044, 50.33605098724365, 47.36593580245972, 44.57256889343262, 45.21949134554182, 45.78483847209385, 46.48538364682879, 46.89597007206508, 43.53559194292341, 44.358470576150076, 39.55910314832415, 39.8127749306815, 35.74434062412807, 37.86594874518258, 36.76295695986067, 39.29022523335048, 38.52140358516148, 41.741289138793945, 40.27367326191494, 38.235519954136436, 39.50906917027065, 39.43735681261335, 38.27824790137154, 36.71677228382656, 40.96639129093715, 37.41765444619315, 39.06356804711478, 37.455143451690674, 38.303143296922954, 40.501393522535054, 40.990633555821006, 41.2222969191415, 44.06348480497088, 44.4084072794233, 47.21185255050659, 50.19842801775251, 46.91226012366158, 47.543972969055176, 48.873889446258545, 49.723831312997, 49.75962495803833, 49.281654902866904, 48.71022810254778, 51.0393511227199, 46.84448044640677, 50.419481481824604, 48.564830098833355, 50.05975239617484, 50.5128617967878, 50.62604795183454, 52.48025465011597, 57.423237868717735, 57.45552614756993, 41.6453275680542, 19.857430458068848, 21.896926505225046, 18.58541853087289, 8.768776876585823, 4.367002308368683, 0.5398376839501517, 0.13597034317042145, 12.909937977790833, 43.24311447143555, 46.447901589529856, 47.31118399756295, 24.964573553630284, 31.992789336613246, 49.861443860190256, 58.711951528276714, 54.90394612721035, 18.925279242651804, 0.07761187359158482, 0.15905931565378392, 0.14047041455549852, 0.1994860792266471, 0.1530888724539961, 0.10275103284844331, 0.13171012034373625, 0.2064419724047184, 0.09863890707492828, 0.1162664597587926, 0.1099865028102483, 0.11293521244078875, 0.16311871925634996, 0.2375060926590647, 0.14263028651475906], [0.029373377228954008, 0.06705082886453186, 0.037554721614079814, 0.0721779480310423, 0.04553140287420579, 0.03529103718964117, 0.006777086478125836, 0.020492995889591317, 0.010536568272592766, 0.06401056450392519, 0.013666012490700399, 0.036599978738065274, 0.021459630091807673, 0.03983338809173022, 0.1161216739565134, 10.366266744477407, 34.151347977774485, 39.04905326025826, 34.10922104971749, 25.75738559450422, 15.237918887819562, 24.411599431719097, 24.800217390060425, 32.052053996494834, 25.524801594870432, 0.32217057102492874, 0.37756679419960293, 2.1340840458869934, 11.301905087062291, 13.47223310811179, 10.072565521512713, 9.127829381397792, 24.930880001613072, 51.339082513536724, 49.53240149361746, 48.90024743761335, 44.75838804244995, 42.703079632350374, 45.157575947897776, 48.7142893246242, 47.83889620644705, 47.55388804844448, 47.99512297766549, 45.87636014393398, 44.735340867723735, 43.39922659737723, 43.2240868295942, 45.09363515036446, 45.02376059123448, 45.09836687360491, 45.85273279462542, 47.597025939396445, 46.51492738723755, 43.39530781337193, 38.63859190259661, 35.533375944410054, 33.850529193878174, 32.829018933432444, 34.26898792811802, 31.95067630495344, 33.62975365774972, 33.316949231284006, 34.47525562558855, 34.091166155678884, 34.54907676151821, 33.92018141065325, 33.058441502707346, 33.18049355915615, 33.122684546879356, 33.18166085651943, 33.35851335525513, 32.681731019701274, 33.47979416166033, 34.63391774041312, 38.80573776790074, 44.34458807536534, 46.68284797668457, 44.63715934753418, 45.34610489436558, 43.60040126528059, 45.688762256077354, 43.37592233930315, 43.865989208221436, 45.14836958476475, 48.33094678606306, 42.74830545697893, 42.98981441770281, 36.07455028806414, 27.540666818618774, 49.507707595825195, 43.75536346435547, 44.792333466666086, 42.97243002482823, 43.42710624422346, 43.33209310259138, 43.571079867226736, 41.39122152328491, 41.467801094055176, 41.10848890032087, 40.31113794871739, 36.16264649799892, 35.78119386945452, 33.69000843593052, 32.80574246815273, 32.90696382522583, 35.4936774117606, 35.20573016575405, 34.159776142665315, 35.6820569719587, 33.57283748899187, 34.68605007444109, 34.68899611064366, 35.864342961992534, 35.739522048405235, 34.62375947407314, 34.38216713496617, 34.19436774935041, 33.03677007130214, 34.060639245169504, 32.31683942249843, 32.894071442740305, 35.70044885362898, 35.367154189518516, 40.813899176461355, 44.69854668208531, 46.21432399749756, 45.84962347575596, 44.42983899797712, 46.008473191942485, 48.91070447649275, 47.79891627175467, 46.50921596799578, 45.76946210861206, 44.34141274860927, 40.90539305550711, 40.8840377671378, 39.06100068773542, 41.882264614105225, 40.568082332611084, 44.39874580928257, 47.014353479657856, 51.746180943080354, 51.31275231497628, 41.75599152701241, 10.566586783954076, 10.604137454714094, 7.9165021521704535, 2.120404997042247, 0.8428380393556186, 0.1390378235706261, 0.0968747635238937, 4.48988858291081, 42.156937326703755, 34.719189507620676, 45.874056816101074, 40.504541056496755, 27.07558219773429, 35.367282731192454, 46.94997147151402, 42.894325324467246, 11.962507673672267, 0.23571112326213292, 0.10416079112993819, 0.05951905623078346, 0.0113928150053003, 0.028970826151115552, 0.041572419061724625, 0.034445077047816346, 0.02585917990654707, 0.009882374849569584, 0.029916110248970132, 0.06072129136217492, 0.02789832521895213, 0.017638684050845246, 0.021343514090403914, 0.05271669517138174, 0.06990506606442587, 0.04685555039239781, 0.06867822046790804, 0.0836774677570377, 0.024074376660532186, 0.041098913576986106, 0.05106587714648672, 0.027267988239015852, 0.05514473434803741, 0.07157983976815428, 0.044983675836452415, 0.05955328153712409, 0.05207419714757374, 0.16918023542634078, 0.14117771945893764, 12.380870870181493, 40.88060883113316, 44.505619525909424, 40.35440438134329, 29.406669821058, 17.498994725091116, 24.22128653526306, 31.7841523034232, 37.757872990199495, 29.54522384916033, 0.3248728503073965, 1.1415170494999205, 3.1595341520650044, 7.931574531963893, 18.620823076793126, 8.49684088570731, 12.721840688160487, 25.639344385692052, 51.78784234183175, 51.96685920442854, 51.01447309766497, 46.37643241882324, 44.55233226503645, 48.14361640385219, 50.111613750457764, 48.995066029684885, 48.024010113307405, 48.808218547276084, 46.999234199523926, 46.9852683203561, 44.71454838344029, 44.47406080790928, 44.51763643537249, 45.38684565680367, 46.79561723981585, 46.69355167661394, 47.17512089865548, 47.51457861491612, 45.713487420763286, 41.93143354143415, 37.84982892445156, 36.880579539707725, 34.814734186444966, 35.1758633341108, 34.780792236328125, 35.4441819190979, 35.35319873264858, 37.14181443623134, 36.598816190447124, 35.41389124734061, 35.715137345450266, 35.34369707107544, 34.80228648866926, 34.1132892199925, 34.145490646362305, 34.52839544841221, 36.4760172026498, 33.793244770595, 36.63522127696446, 39.80800151824951, 46.42032071522304, 49.0758318901062, 47.17514174325125, 46.399802684783936, 44.94286618913923, 46.31710869925362, 44.412089824676514, 44.90480048315865, 46.82568209511893, 49.947149889809744, 45.769104276384624, 43.8211281640189, 35.90964869090489, 29.618044444492885, 50.78938620431082, 46.74416582924979, 47.02882310322353, 43.939282281058176, 44.8799398286002, 44.073834146772114, 45.32182788848877, 42.89151477813721, 43.84781619480678, 42.48157453536987, 42.238081863948274, 37.97608116694859, 36.52227830886841, 34.85710430145264, 34.78398840767996, 35.31533799852644, 36.99899074009487, 35.54792199816023, 36.37650510243007, 36.59138856615339, 34.66096707752773, 35.630574294498985, 36.8111948285784, 37.17638519832066, 36.99826465334211, 36.90317855562483, 36.47948087964739, 34.971607140132356, 36.32884393419538, 36.54713201522827, 35.312642097473145, 34.981039319719585, 37.67229550225394, 37.64832421711513, 42.90455654689244, 46.855976240975515, 48.40279115949358, 47.156784602573936, 45.9973143850054, 47.55610799789429, 49.021562985011506, 49.15784495217459, 48.47309650693621, 48.213779313223704, 46.54560368401663, 42.73448201588222, 41.991056033543174, 41.28128712517874, 43.18623999186924, 43.96758576801845, 45.148835114070344, 48.85246467590332, 53.12527676991054, 54.50198589052473, 43.609590257917134, 14.048600946153913, 10.609756810324532, 8.250793882778712, 4.608702344553811, 4.317997966493879, 0.05834481745426144, 0.043366353692752976, 5.279800185135432, 41.236714431217735, 41.591496399470735, 48.702161243983674, 36.64148160389492, 30.66874408721924, 40.30089282989502, 52.34802000863211, 48.884026868002756, 18.55966329574585, 0.2132853509059974, 0.13118512422910758, 0.06969627405383758, 0.020693947428039143, 0.014197778688477618, 0.029331559115754705, 0.021307577179478746, 0.038059901113488843, 0.0033148789329321255, 0.03048431547358632, 0.04853843937494925, 0.05421930079215339, 0.042244138196110725, 0.050668482934789996, 0.037597455749554295, 0.13491353844957693, 0.14636585249432496, 0.23677894739168032, 0.24077326591525758, 0.1027686069054263, 0.11691997040595327, 0.08525656802313668, 0.15099152071135385, 0.1604910245431321, 0.14789052068122796, 0.13867073612553732, 0.16981455710317406, 0.08212229263569627, 0.35577116374458584, 0.45463016043816296, 15.877986942018781, 49.58708381652832, 52.66276298250471, 47.60182367052351, 35.92392723900931, 23.816868373325892, 30.762107031685964, 35.41296018872942, 42.56058944974627, 32.503805024283274, 0.4114471876195499, 1.4790667252881187, 5.443306497165135, 17.34519461223057, 22.651773588997976, 18.11754420825413, 13.568968534469604, 26.97916030883789, 55.36115843909127, 52.68293360301426, 53.36019536427089, 47.96538468769619, 47.69564867019653, 48.440773487091064, 52.60062524250576, 50.55683694566999, 49.90293155397688, 49.54553706305367, 48.04796402794974, 47.13824680873326, 44.31486020769392, 43.46031863348824, 46.94900219781058, 46.056804861341206, 48.54533345358712, 49.64877339771816, 50.3546130997794, 49.94752161843436, 47.46289791379656, 43.035165309906006, 40.075882366725374, 39.27058615003313, 37.66929388046265, 36.92604855128697, 36.950870990753174, 35.91656909670149, 37.43914522443499, 39.82052217211042, 38.329838275909424, 37.9089789390564, 36.97403975895473, 36.719169412340435, 37.15913282121931, 35.90465293611799, 37.112121309552876, 36.421223708561485, 38.330696378435405, 35.66647563661848, 38.178760119846885, 41.99760471071516, 48.356710706438335, 49.287050179072786, 47.82166814804077, 47.360995633261545, 47.53463111604963, 49.52549498421805, 47.492379120418, 46.864953313555034, 49.453365734645296, 51.12099245616368, 46.503799847194124, 45.2560909816197, 36.38280364445278, 33.24446562358311, 51.19171469552176, 47.46703209195818, 48.45863035746983, 46.53329495021275, 45.796296051570344, 46.521080017089844, 47.37818547657558, 44.08395767211914, 43.840666498456685, 45.63114431926182, 44.11290734154837, 40.56520925249372, 39.10940531321934, 37.231571265629356, 35.96060330527169, 37.59486130305699, 38.40182508741106, 38.308462142944336, 37.516558579036165, 38.01412950243269, 36.00791358947754, 37.49852800369263, 38.94957937513079, 39.41252742494856, 39.32253435679844, 38.162546498434885, 38.19019685472761, 38.419932092939106, 36.754945686885286, 38.80780485698155, 36.450458254132954, 36.13609395708357, 41.809162616729736, 40.53460938589913, 45.393658365522114, 49.29762186322893, 49.616165501730784, 48.83424302509853, 48.17259039197649, 48.23120886938912, 51.32114921297346, 50.885775089263916, 50.58855199813843, 49.726356983184814, 48.81937735421317, 44.34845127378191, 44.218085697719026, 42.80876520701817, 46.76935652324131, 45.974986348833355, 49.598131452287944, 51.30902460643223, 56.90665667397635, 55.03280394417899, 45.37625312805176, 12.604563781193324, 18.317185061318533, 17.38335759299142, 8.215658579553876, 5.338497698307037, 0.37031781460557667, 0.20537960369672092, 5.8479509098189215, 52.48179367610386, 44.82792908804757, 53.94307279586792, 50.2624591418675, 39.80790424346924, 47.62890427453177, 60.69220897129604, 57.56990739277431, 26.826753309794835, 0.29377436903970583, 0.2305090938295637, 0.21320265105792455, 0.06807900619293962, 0.12708215867834433, 0.20258900629622595, 0.08337996407811131, 0.09957545503441777, 0.15307820588350296, 0.08074534830770322, 0.14335531475288527, 0.14514124606336865, 0.1287408782435315, 0.17409513598041876, 0.15281169089887822], [0.02993681913773928, 0.011832407309806772, 0.041059066608015976, 0.03250422262187515, 0.05125643692112394, 0.007363936996885708, 0.0817740141813244, 0.04169134250176804, 0.026213331081505333, 0.009463795078253108, 0.032184429067586146, 0.03401522172082748, 0.03814338127683316, 0.046034010725894144, 0.12066528014838696, 11.859101976667132, 34.41824565614973, 42.83237518583025, 31.97464759009225, 16.958433559962682, 13.695357135363988, 19.77243661880493, 30.989142894744873, 36.94889770235334, 21.814355850219727, 0.05241708803389754, 0.5485057245407785, 4.806896669524057, 18.721917629241943, 17.815208980015345, 2.39461977992739, 13.565536992890493, 36.034372329711914, 53.10367829459054, 49.98727573667254, 47.65152413504464, 44.85563155582973, 44.83784416743687, 45.89882366997855, 46.87594188962664, 48.22957951681954, 43.32225792748587, 46.802836418151855, 45.55665268216814, 42.73018108095442, 44.53686210087368, 46.141604151044575, 47.09646034240723, 45.01475919995989, 47.09351430620466, 45.029023851667134, 45.83588688714163, 42.00619963237217, 40.61529534203665, 36.29296343667166, 36.41394199643816, 33.2238781111581, 33.20330449513027, 33.98320852007185, 34.43869767870222, 37.03406177248274, 34.6974208014352, 35.5473244530814, 33.082655974796836, 34.9220004762922, 33.71618924822126, 33.31445830208914, 33.04692486354283, 33.28469916752407, 32.68922812598092, 33.18354729243687, 32.189009938921245, 34.36674908229283, 33.7251489503043, 40.00507327488491, 44.66046360560826, 45.7761184828622, 44.08687244142805, 43.39444623674665, 43.831328119550435, 44.263544287000386, 43.26673834664481, 44.30007096699306, 44.1128100667681, 46.39109659194946, 45.139892782483784, 41.457733154296875, 38.040452752794536, 29.49357441493443, 48.6075302532741, 45.32464190891811, 45.39980752127511, 41.440838609422954, 43.691054412296836, 42.557646887642996, 43.46441807065691, 41.695976461683, 40.9462936265128, 40.50000735691616, 39.38929264886038, 34.80287708554949, 32.77997507367815, 33.32131617409842, 34.925300870622905, 34.401170458112446, 35.136995111192974, 34.217651162828716, 33.71181188310896, 34.08629199436733, 34.91765437807356, 34.0379637990679, 34.64663641793387, 34.31792409079415, 34.42175102233887, 34.510114737919395, 34.79945509774344, 33.77225078855242, 33.67125872203282, 33.32833385467529, 32.07908248901367, 35.877370834350586, 34.14085619790213, 36.239823613848, 40.910774435315815, 46.80360419409615, 47.335843154362266, 44.26890482221331, 43.863689354487825, 44.86459820611136, 44.40243877683367, 48.56178331375122, 48.03424480983189, 48.58563647951399, 43.78243712016514, 41.02080610820225, 39.39712674277169, 37.05209929602486, 43.53878811427525, 47.60992179598127, 47.47606127602713, 48.68043770108904, 49.66406985691616, 54.25481762204851, 46.539141859327046, 23.070875031607493, 10.821438891547066, 4.76670047215053, 2.1105524514402663, 5.595045166356223, 0.36688461740102085, 0.01031647271676255, 2.9597007036209106, 31.612670762198313, 36.002268178122385, 24.287492445537023, 26.68679400852748, 35.14677817480904, 41.10638359614781, 44.06190756389073, 48.23225457327706, 13.92184235368456, 0.5720699972340039, 0.08824978276555027, 0.049468086633299074, 0.057674587704241276, 0.03697534431038158, 0.02920403185167483, 0.07360179269952433, 0.029432464058377912, 0.0014397374429141305, 0.046856320529643974, 0.05477076316518443, 0.05202951222392065, 0.03232976448323045, 0.007641115159328494, 0.052891224556203396, 0.025796700402029922, 0.043776925054511855, 0.009179314182672118, 0.03959599243743079, 0.055691525007465055, 0.015101726432996137, 0.052697390850101195, 0.06017817157719817, 0.035707291282181225, 0.022383913530835083, 0.030184911896607707, 0.05446448263579181, 0.028255373738440018, 0.08282623879079308, 0.30164795368909836, 14.646623713629586, 42.53856366021292, 48.855640002659385, 40.45790474755423, 22.60989853313991, 13.908737182617188, 21.30281036240714, 32.113555976322715, 41.766184534345356, 24.474716867719376, 0.07484929968736001, 0.7519587501883507, 6.483823989118848, 18.87438542502267, 18.87371666090829, 9.366164752415248, 11.934875556400844, 36.902952739170615, 54.43715919767107, 52.44978679929461, 49.92174727576119, 45.84673997334072, 46.954334940229145, 48.356495312282014, 49.554878916059224, 47.49559266226632, 44.46968691689627, 46.28675201960972, 44.94075393676758, 43.78636632646833, 44.22784791673933, 45.45540700639997, 47.37336342675345, 45.940822056361604, 47.27587672642299, 47.341933250427246, 46.99122987474714, 43.90353379930769, 41.56456170763288, 37.562093598502024, 37.83193383898054, 34.54058606284005, 34.19132443836757, 35.72808531352452, 36.86765241622925, 38.41610016141619, 36.70783690043858, 37.45849943161011, 34.69025720868792, 36.54443611417498, 35.35812847954886, 34.81585284641811, 33.865262848990305, 34.17770249502999, 35.0446709224156, 34.78647238867623, 33.85322509493147, 34.61445236206055, 34.11089903967721, 40.83563314165388, 46.05932010923113, 47.006734779902864, 46.92663942064558, 44.64112329483032, 45.26628398895264, 47.042889731270925, 43.86884491784232, 46.60795334407261, 45.82523877280099, 47.885042667388916, 45.881842272622244, 43.166708605630056, 38.4433023588998, 30.8179566519601, 50.8897042955671, 47.0163128716605, 46.72802168982369, 42.776817389896934, 44.33793864931379, 45.169759614127024, 43.81743172236851, 43.91705846786499, 44.22736154283796, 41.84425796781267, 40.621864863804404, 37.25200244358608, 35.37013496671404, 35.30932085854666, 37.42209781919207, 35.32432549340384, 35.80632202965872, 34.99088839122227, 35.76908663340977, 35.15798909323556, 36.73283999306815, 36.18054853166853, 36.59286158425467, 35.7730644771031, 36.33546209335327, 35.72406578063965, 36.112192153930664, 35.170207500457764, 35.33322613579886, 35.21497474397932, 35.17546033859253, 36.8295658656529, 36.13243920462472, 38.95301178523472, 42.42036090578352, 47.91012219020298, 48.40553222383772, 46.00298064095633, 45.07198108945574, 44.44864082336426, 46.90277583258492, 49.95337200164795, 50.67012732369559, 50.87574189049857, 47.45900692258562, 42.65753766468593, 40.120270933423726, 39.42627790996006, 43.67917646680559, 48.08340678896223, 47.90103742054531, 51.22107778276716, 52.21816165106637, 54.64941276822771, 48.13578578404018, 20.43912669590541, 8.815427081925527, 8.35115018912724, 4.577868410519191, 3.556171634367534, 0.05947947049779551, 0.028953706712595055, 3.211447400706155, 35.65445177895682, 38.72594812938145, 29.42895269393921, 35.808298792157856, 44.12960386276245, 45.04989971433367, 50.94892726625715, 54.52825355529785, 20.289219311305455, 0.5521006030695779, 0.06837357181523528, 0.06773138591753584, 0.061386242109749994, 0.0426743429686342, 0.07510736691100256, 0.03573859210259148, 0.006994683752834264, 0.04718167807108589, 0.05334605675722871, 0.019554663383002793, 0.01700117325942431, 0.005122907160382185, 0.03342572746000119, 0.07245272078684398, 0.11010973834033523, 0.23295800813606807, 0.09569707100412675, 0.11730201276285307, 0.2213662958570889, 0.09181431042296545, 0.14495505605425152, 0.1506828415606703, 0.19530177089784825, 0.15030651246862753, 0.1851336658000946, 0.1805443534893649, 0.10288188154143946, 0.19652107118495873, 0.39123628927128656, 17.69763330050877, 51.6937255178179, 56.823198386601035, 44.65365089688982, 26.693940230778285, 21.123538153512136, 26.765980890819005, 40.846743311200825, 49.302047865731375, 26.683035033089773, 0.235076014484678, 0.8627905515687806, 9.300931589944021, 26.669407878603252, 24.729239804404124, 10.469183462006704, 15.473054613385882, 39.538185596466064, 57.25220101220267, 55.09178720201765, 52.514571802956716, 48.495817116328645, 48.386494159698486, 51.67667811257498, 49.90575252260481, 49.81085055215018, 44.16196162360055, 47.966711793627056, 46.302628653390066, 44.15584026064192, 44.58091367994036, 46.58896739142281, 49.24308892658779, 48.339142186301096, 50.864583083561485, 48.36100469316755, 48.63378054755074, 45.01969242095947, 43.37051664079939, 39.5721310206822, 41.17619562149048, 37.111099924360005, 36.736876896449495, 38.79635075160435, 38.836299419403076, 40.8123254094805, 37.712681906563894, 40.06032187598092, 36.19227014269148, 38.87022052492414, 36.22478076389858, 35.98762137549264, 34.81081540243966, 36.27252531051636, 36.66798550742013, 37.6345876285008, 35.16273123877389, 37.238870348249165, 36.540850843702046, 42.69092375891549, 49.285841192517964, 49.13814333506993, 47.11195135116577, 44.00508866991316, 45.626054763793945, 47.951894760131836, 45.70792538779122, 48.65291936056954, 49.01774147578648, 49.33560071672712, 47.005251339503694, 44.8779422215053, 39.36574867793492, 34.512782846178325, 51.70842790603638, 49.498452595302034, 49.404968057359966, 45.37702785219465, 46.84357023239136, 46.9729700088501, 47.70473691395351, 46.02411706107003, 45.23106704439436, 44.4869636126927, 41.88023921421596, 39.587879112788606, 37.026710578373496, 38.2861966405596, 38.855813435145784, 37.81281934465681, 38.69975342069353, 37.1207092830113, 36.27620785576956, 37.494581426892964, 38.879364354269846, 38.44223928451538, 38.74199499402727, 38.473773683820454, 38.38862351008824, 37.90309381484985, 37.0191787311009, 36.884088379996165, 37.98777845927647, 37.5434376852853, 36.33598320824759, 40.74260718481881, 39.16090188707624, 41.97002731050764, 44.74736819948469, 50.69560636792864, 50.26848323004586, 47.977182728903635, 47.177879333496094, 47.57817200251988, 46.80131823675973, 50.908686774117605, 51.349160875592915, 53.28917782647269, 48.54836981637137, 45.05750451769148, 42.519949436187744, 41.56360980442592, 46.19319799968174, 52.17498901912144, 51.52193825585501, 53.83554594857352, 53.4136825970241, 58.300764083862305, 50.23115750721523, 26.197562660489762, 17.086464541299, 15.155422925949097, 12.067369886807032, 8.843122601509094, 1.5030352962868554, 0.07475984163050141, 3.708344348839351, 40.27106768744332, 47.584866591862266, 34.83989361354283, 35.58879477637154, 45.97557347161429, 52.244384152548655, 57.1621002469744, 60.86505235944475, 28.478560720171245, 0.8359744133693832, 0.141061662829348, 0.22640701037432465, 0.21676951966115407, 0.11609738240284578, 0.16918497160077095, 0.10423587781510182, 0.08474236061530453, 0.12115932149546486, 0.11213880910405091, 0.1214682992015566, 0.1419040369135993, 0.14235295568193707, 0.13567475974559784, 0.187356953642198], [0.037966066505759954, 0.0436225244110184, 0.0222194145899266, 0.02704691474459001, 0.018019632270027484, 0.04145366864811097, 0.06400520407727786, 0.05888317392340728, 0.020861674499298846, 0.03450489330238529, 0.047792641179902215, 0.03671317194987621, 0.01063280489428767, 0.039137645425008874, 0.07529805560729333, 10.324659194265093, 30.648663793291362, 41.426278659275596, 31.995356695992605, 20.45152575629098, 21.475382770810807, 26.91324622290475, 31.127040318080358, 38.40192583629063, 14.70468807220459, 0.11270928742097956, 0.02581522610437657, 1.9072494634560175, 21.078154257365636, 13.080422452517919, 10.40047185761588, 21.766788482666016, 44.2185685975211, 50.72704349245344, 50.03299488340105, 45.597817284720286, 44.73146724700928, 43.652568340301514, 46.52991812569754, 47.37005955832345, 49.19535827636719, 41.75415025438581, 42.70639392307827, 41.309277943202424, 41.458264691489084, 41.98429543631417, 43.188369614737375, 42.164027963365825, 45.6017986025129, 43.45457942145211, 41.322416986737935, 40.245828356061665, 39.0644747870309, 35.80114562170846, 33.497300148010254, 32.47063432421003, 33.43698631014143, 34.42466926574707, 35.2708625793457, 35.08922277178083, 35.632179328373496, 34.96853256225586, 34.54887873785836, 33.21194805417742, 33.672627517155235, 34.10882500239781, 34.72786085946219, 33.67969036102295, 33.888605322156636, 32.65646736962454, 32.22292757034302, 32.18102298464094, 32.249629497528076, 33.57428271429879, 41.372023650578086, 45.54547650473458, 46.73666524887085, 40.61992631639753, 43.75235142026629, 44.230700152260916, 46.17162036895752, 44.34644324438912, 44.79632520675659, 45.52728959492275, 47.464687074933735, 41.62102276938302, 39.799128668648855, 37.83708940233503, 31.296041352408274, 46.90616307939802, 44.14441047395979, 42.63990661076137, 41.692582266671316, 42.26814324515206, 39.664858204977854, 38.79069144385201, 36.91820403507778, 36.11566277912685, 35.505857603890554, 33.57987948826381, 34.87715680258614, 34.27400452750069, 34.114671911512104, 33.46617569242205, 33.65531955446516, 34.574764251708984, 33.78356940405709, 33.83357906341553, 34.38112490517752, 34.23279823575701, 36.000809056418284, 33.99227244513375, 34.260698727199006, 35.251887048993794, 35.25873449870518, 33.20574331283569, 33.360302516392295, 35.99524007524763, 35.70347132001604, 34.12404155731201, 35.30402980531965, 35.464550563267295, 37.857107162475586, 41.1872467313494, 44.330316475459504, 46.92168535505022, 48.347827434539795, 47.23510469709124, 46.45197670800345, 45.74332645961216, 47.05575779506138, 46.55717243467058, 48.71994168417794, 46.33051872253418, 42.19941861288888, 35.23341178894043, 38.35282639094761, 49.36743041447231, 49.55962800979614, 49.519498688834055, 51.866148539951865, 51.7836525780814, 52.50899587358747, 49.72231313160488, 28.779551471982682, 10.215536866869245, 6.314093828201294, 1.81007619202137, 4.097254565783909, 0.2443597306098257, 0.04254820330866745, 0.8045743639980043, 29.48253720147269, 44.9810083253043, 29.896281582968577, 18.238567931311472, 30.37285852432251, 37.14675807952881, 44.173116956438335, 47.98795591081892, 23.100338867732457, 0.2925061599484512, 0.02928942209109664, 0.03654125492487635, 0.05889788456261158, 0.03776498604565859, 0.031846030083085806, 0.04478581163233944, 0.04722222393112523, 0.0235040357469448, 0.030011705655072416, 0.04629967075639537, 0.11353911539273602, 0.016760937936071838, 0.019480738689058592, 0.017155365253399526, 0.02155514237737017, 0.08147806434759072, 0.038184178194829395, 0.012563516918037618, 0.09384357117648635, 0.027287955828277127, 0.04767198069021106, 0.07714460045099258, 0.06844164923365627, 0.029131011305642978, 0.06911176363272326, 0.060401701368391514, 0.020675750815176537, 0.005696858304353165, 0.174651955387422, 13.2513325044087, 38.824754987444194, 47.46043130329677, 36.93388959339687, 22.147548028400966, 22.077954871313914, 23.13789735521589, 32.76231970105852, 44.51049368722098, 15.618893827710833, 0.15670011724744523, 0.08721365979207413, 3.1870635662760054, 23.12387067931039, 12.664745603288923, 12.9530611038208, 18.709202425820486, 45.407273360661094, 53.29637268611363, 52.69660765784127, 47.101390089307515, 45.742120947156636, 44.90078442437308, 47.13480050223214, 47.68873173849923, 50.44185120718819, 42.7315012386867, 45.812811919621055, 42.11390365873064, 41.529174532209126, 42.48120975494385, 43.97429077965872, 44.510285241263254, 46.00415488651821, 45.39875486918858, 43.513941356113975, 41.604496479034424, 41.128291266305105, 36.67004564830235, 35.4008321080889, 34.88596364430019, 36.55927399226597, 35.569152218954905, 36.79101378577096, 36.98731081826346, 38.643347944532124, 37.0668294770377, 36.67237329483032, 35.81399284090315, 35.078084809439524, 35.70035852704729, 35.870328835078645, 34.05723115376064, 34.94864681788853, 34.69520085198538, 34.0454226902553, 33.33183227266584, 33.540646484919954, 35.09856809888567, 42.69134759902954, 47.36630753108433, 47.83484888076782, 42.50733845574515, 43.466710976191926, 47.05546597072056, 46.43852152143206, 46.702428000313894, 47.09596702030727, 46.18040984017508, 47.05994755881173, 43.21284464427403, 42.11115217208862, 37.231383664267405, 33.99268238885062, 49.15729604448591, 46.78240524019514, 43.70532601220267, 43.12124654224941, 43.38445125307356, 42.83953530447823, 42.520446232386995, 38.89926746913365, 38.83374943052019, 37.552935872759136, 35.122160707201274, 35.96152741568429, 36.54821246010916, 35.332475730351035, 35.595923628125874, 35.104685987745015, 36.241188934871126, 36.4552629334586, 37.05334302357265, 36.70533207484654, 35.81183195114136, 36.84848928451538, 37.27103008542742, 36.38600328990391, 37.14543792179653, 37.49727037974766, 35.070358412606375, 36.00022888183594, 37.0656031199864, 37.067812647138325, 36.207841055733816, 37.1994115284511, 37.57034805842808, 38.70647232873099, 43.81081703730992, 46.537071296146934, 47.353224073137554, 48.336328165871755, 48.82132979801723, 47.65745789664132, 45.467653206416536, 46.482656478881836, 48.42257962908064, 49.534982749394004, 47.59789793831961, 43.51418454306466, 37.92539753232683, 40.4479375566755, 50.08705881663731, 51.13990545272827, 52.04665926524571, 52.721808774130686, 53.2402868270874, 54.28438915525164, 51.182209559849326, 28.052047286714824, 7.248426343713488, 6.65152918440955, 7.250717077936445, 5.553335998739515, 0.44086884600775583, 0.029148303770593235, 0.6742228471807071, 33.24219356264387, 46.5786805834089, 33.13598687308175, 20.152748005730764, 31.499877180371964, 43.213407448359895, 49.86653341565813, 55.43367678778512, 27.915530817849294, 0.6663470640778542, 0.08492864561932427, 0.08927473705261946, 0.007549014208572251, 0.022531187860295177, 0.02266771928407252, 0.01603289700246283, 0.016111320383580666, 0.012956168169953992, 0.01145696540230087, 0.009958900877141526, 0.0385334914151047, 0.049648787294115336, 0.033862429205328226, 0.04111836039062057, 0.10045696023319449, 0.12250241371137754, 0.07847485478435244, 0.1402104270777532, 0.13533759569483145, 0.09068258186536175, 0.16230141025568756, 0.17381586453744344, 0.17660825327038765, 0.15266351242150578, 0.10824166358049427, 0.16771312057971954, 0.13270690185683115, 0.09442546923777886, 0.47642207252127783, 16.673887457166398, 46.49658761705671, 55.34235313960484, 44.474526337214876, 31.549796513148717, 30.655893393925258, 37.339577538626536, 40.855008193424766, 50.98092024666922, 17.496920687811716, 0.2717784893299852, 0.19717697027538503, 4.969561380999429, 27.149314744131907, 17.117929458618164, 17.057518345969065, 24.85396691731044, 46.56783444540841, 54.7903048651559, 54.166012695857454, 48.74317298616682, 47.52562277657645, 47.12909950528826, 48.65677213668823, 48.97579172679356, 51.39379610334124, 42.598200048719136, 46.394261496407644, 43.418466159275596, 41.35300990513393, 43.03181627818516, 44.57833589826311, 45.30841439110892, 47.96405758176531, 47.99167667116438, 45.91935559681484, 44.669371196201865, 42.67726707458496, 39.02529042107718, 37.12684106826782, 35.285999229976106, 38.221640927451, 37.9500149999346, 39.80557312284197, 39.912293979099815, 39.71788338252476, 39.87959575653076, 39.77430970328194, 37.605929783412385, 37.39677163532802, 38.27395044054304, 38.43819890703474, 36.55824218477522, 37.359195777348106, 37.173647608075825, 35.1339761189052, 34.635074615478516, 36.478386538369314, 37.857850619724815, 45.71933780397688, 49.27717331477574, 49.01623024259295, 42.98553780147007, 43.43133074896676, 49.317500659397666, 48.36715384892055, 47.60663529804775, 49.40298087256295, 47.99163498197283, 49.454352378845215, 44.859192507607595, 43.55686732700893, 38.8144508089338, 36.4716328893389, 50.51797914505005, 47.76813227789742, 44.94031272615705, 44.76883813313076, 45.1686235836574, 45.338041509900776, 44.117489678519114, 40.04361145836966, 39.82081747055054, 40.40545974458967, 36.606973375592915, 37.97870411191668, 38.38677876336234, 37.595570019313264, 37.749865191323416, 37.60879591533116, 37.78125715255737, 38.57938977650234, 37.84567390169416, 38.65709148134504, 38.13902684620449, 39.6816520009722, 38.700691427503315, 38.166027545928955, 38.440912178584504, 37.79229784011841, 36.70810440608433, 38.54363782065255, 40.31194741385323, 39.47542946679251, 38.18014975956508, 38.91587018966675, 39.74749313082014, 41.9780455316816, 46.33360024860927, 48.726268018995015, 48.79978690828596, 51.32576281683785, 50.609490394592285, 49.68571696962629, 47.521985394614084, 48.560904366629465, 49.87560428891863, 52.02893788473946, 50.60457106998989, 45.84095212391445, 39.459337438855854, 43.72193220683506, 53.134854861668174, 53.767061029161724, 53.63991594314575, 55.47781521933419, 56.26323611395699, 55.88480595179966, 53.4035382270813, 34.88451841899327, 14.840391601834979, 13.127924680709839, 10.63545993396214, 9.824749333517891, 0.851409565125193, 0.19649622323257582, 1.0919140768902642, 37.92696435110909, 55.91579491751534, 41.47832761492048, 27.92977809906006, 39.24968596867153, 51.45213317871094, 57.17029912131173, 63.32438809531075, 34.56555788857596, 1.195452658193452, 0.15156553419572966, 0.18657252644853933, 0.26247162159000126, 0.1499702033719846, 0.09892306397003786, 0.15125940633671625, 0.16126281741474355, 0.11853196604975633, 0.08866281381675176, 0.06177779074226107, 0.20268177560397557, 0.11678187495895795, 0.17225310339459352, 0.11142886469938926], [0.08391692276511874, 0.04682676015155656, 0.016242968051561286, 0.017254146381414363, 0.021040604183716432, 0.03924132218318326, 0.057080319949558804, 0.017489285906776786, 0.04668179453749742, 0.005614742844565106, 0.02478458060483847, 0.05003114177712372, 0.01445640400717301, 0.03450772279341306, 0.36143321277839796, 10.267836826188223, 27.8022369657244, 39.32942696980068, 33.3451623916626, 20.63846182823181, 10.006251045635768, 24.165393488747732, 28.10097302709307, 37.36272546223232, 11.800081372261047, 0.011327957235542791, 0.10299385339021683, 1.3140547169106347, 4.327363269669669, 5.785821855068207, 16.50811559813363, 21.536785738808767, 49.98579577037266, 49.47956739153181, 48.661034856523784, 44.21616799490792, 42.77327380861555, 43.47583048684256, 46.59917776925223, 48.392441817692344, 46.55300004141671, 45.584643500191824, 42.35804598672049, 40.74046713965279, 44.23068625586373, 44.49804251534598, 43.114468574523926, 42.378605706351145, 45.59967940194266, 42.08776453563145, 41.44044951030186, 37.74776336124965, 35.190795012882774, 34.43044669287545, 33.75509916033064, 32.01829269954136, 33.04600075313023, 33.392580372946604, 35.28405720846993, 34.617169107709614, 36.39460515975952, 34.04636069706508, 34.1048367364066, 33.00375917979649, 34.36099944795881, 37.298517159053254, 33.01042945044381, 34.04464449201311, 31.80341270991734, 33.64080824170794, 32.653090545109336, 32.90027270998274, 32.84093509401594, 36.11397089276995, 43.0822046143668, 44.30122436795916, 44.08404105050223, 45.57347774505615, 41.906069142477854, 43.75836508614676, 45.693876130240305, 45.28271300452096, 46.92478077752249, 44.367774214063374, 44.66856173106602, 40.884524141039165, 39.75269733156477, 39.652914251599995, 29.686049938201904, 48.19336550576346, 43.74568462371826, 45.10814993722098, 40.3953674861363, 39.03934662682669, 36.040726457323345, 33.909526348114014, 32.981212275368826, 33.11754635402134, 34.024331433432444, 33.8904709134783, 34.85765668324062, 33.81705972126552, 33.642017228262766, 32.952537059783936, 33.711318561008994, 33.6150929587228, 33.88523891993931, 34.435793331691194, 33.358381339481895, 33.552739824567524, 35.46320956093924, 35.576482568468364, 37.58129147120884, 35.88203654970442, 35.564767905644004, 36.29410294124058, 37.13337584904262, 38.17330578395298, 37.249528884887695, 36.22604186194283, 35.30805281230381, 33.67200217928205, 37.003027643476216, 39.82081052235195, 44.03271818161011, 46.32087114879063, 45.356673104422434, 45.22131177357265, 47.53577756881714, 46.62011269160679, 46.623479093824116, 49.377262115478516, 47.696051665714805, 45.30538845062256, 38.87339237758091, 38.247258935655864, 39.83696855817522, 46.62221104758126, 50.46203919819423, 50.83671038491385, 50.43461118425642, 50.87523119790213, 48.97773027420044, 51.604468958718435, 42.37214388166155, 18.644735302243912, 6.100415008408683, 3.8972719482013156, 1.55566040958677, 0.15373281575739384, 0.050704865982489924, 0.22858012733714922, 21.171055146626063, 42.69651705878121, 35.88876240594046, 26.103593485695974, 36.059712409973145, 43.02555595125471, 45.15781218664986, 51.4043538911002, 18.943242073059082, 0.37154026329517365, 0.03098471469378897, 0.024449457248140658, 0.0507567874821169, 0.053656883471246274, 0.04715063509398273, 0.04826238758063742, 0.013424398893091296, 0.01482257034097399, 0.026010569550895264, 0.01212837580325348, 0.021463497741413966, 0.05161719363448875, 0.030282929672726562, 0.04112248927620905, 0.02760620741173625, 0.04378917600427355, 0.09308381551610571, 0.018416914523446133, 0.0487447513400444, 0.019819778889151554, 0.011473343541313494, 0.03275969784174647, 0.041104280788983615, 0.0484259586249079, 0.014503363719476121, 0.023297479509242942, 0.04126347528238382, 0.028339154153530086, 0.4494317408118929, 13.233553801264081, 35.71015201296125, 45.022172927856445, 38.99765396118164, 23.88676725115095, 16.21244021824428, 27.951720510210308, 31.527749879019602, 42.99211079733712, 13.108724202428546, 0.13452456146478653, 0.20420600952846663, 2.1591507579599107, 8.365673661231995, 6.069972779069628, 7.409260204860142, 20.660895824432373, 50.275691986083984, 51.19717945371355, 50.5313127381461, 46.14376504080636, 43.869265283857075, 45.94655432019915, 47.792687211717876, 49.869535037449424, 47.823078632354736, 46.40377010617937, 42.57758821759905, 42.6029109273638, 44.674867221287315, 44.48718595504761, 43.46975776127407, 42.92311518532889, 45.760186263493125, 44.03011608123779, 43.186677728380474, 40.67017221450806, 36.78340550831386, 37.901287283216206, 35.30027430398123, 34.395396505083355, 34.25558832713536, 36.014993803841726, 36.966257776532856, 37.07632419041225, 37.29514033453805, 35.79452051435198, 35.44732250486101, 35.465228012629915, 35.12909500939505, 38.68320975984846, 34.98507622310093, 35.1976945740836, 33.053244250161306, 36.17608778817313, 34.11387634277344, 34.699036257607595, 34.84563282557896, 37.39177588054112, 44.55675826753889, 45.797102042606895, 45.091647965567454, 44.451656341552734, 44.138619150434224, 44.68920830317906, 47.53220966884068, 47.30510779789516, 48.55224691118513, 44.40222685677664, 45.07470825740269, 41.01959017344883, 41.32111419950213, 39.82443053381783, 31.51636872972761, 48.61317913872855, 46.597520623888286, 45.35261188234602, 43.19705138887678, 41.04778596333095, 38.61729914801461, 36.3283679825919, 34.79966006960188, 34.45050266810826, 35.26045070375715, 35.5477865082877, 36.20573575156075, 34.61663062231881, 34.88485540662493, 34.847196170261924, 35.94155829293387, 35.43875537599836, 35.48890052522932, 36.57237482070923, 37.51010022844587, 36.52439750943865, 38.50720146724156, 38.19015863963536, 38.427008833204, 38.087460790361675, 36.42955459867205, 38.05397047315325, 38.97995342527117, 38.90719536372593, 38.583235604422434, 38.992074557713096, 36.9762909752982, 34.82909263883318, 40.43150854110718, 42.29385505403791, 45.73590925761631, 48.632248469761436, 47.73176540647234, 47.6516353062221, 49.277496406010215, 47.50072043282645, 47.8813601221357, 48.80723190307617, 50.401721886226106, 46.70270592825753, 41.64807905469622, 39.660852568490164, 40.897395678928916, 49.056112902505056, 53.16395739146641, 53.06573418208531, 53.341355323791504, 51.2977511542184, 51.65565981183733, 54.01751232147217, 43.135243688310894, 15.092289856501989, 1.4247172645160129, 6.14363671200616, 5.010547501700265, 1.030494824051857, 0.07651698270014354, 0.21482648035245283, 23.509714569364274, 45.94616869517735, 37.24679824284145, 26.54489094870431, 36.23530033656529, 47.82293619428362, 49.41354560852051, 59.350428444998606, 25.469995941434586, 0.5620363642062459, 0.011888190521858633, 0.09652812033891678, 0.08080338340784822, 0.012051852320187857, 0.06287076816494976, 0.014392986427992582, 0.01418702645293836, 0.033003393693694046, 0.046311819925904274, 0.08208033203014306, 0.03784999630546995, 0.03466588252090982, 0.036119219713977406, 0.02474514245321708, 0.1667867845722607, 0.11507085391453334, 0.2137077660965068, 0.11595763133040496, 0.09544339390205485, 0.10420334884630782, 0.20769104680844716, 0.1987563826675926, 0.12211187609604426, 0.10345144383609295, 0.09515734389424324, 0.10812456879232611, 0.12023462754275117, 0.10139532666653395, 0.7668939573424203, 16.368950128555298, 43.831550461905344, 51.11941868918282, 45.963049343654085, 30.22255161830357, 17.408348526273453, 34.51021201269967, 38.222287109919954, 49.44578872408186, 14.619424990245275, 0.2081889965172325, 0.3844363641526018, 2.1975569256714413, 8.471095204353333, 9.216576984950475, 22.93373496191842, 23.029988356998988, 52.91741793496268, 52.85798304421561, 53.123751640319824, 48.82625954491751, 46.153256280081614, 46.874600887298584, 48.99331160954067, 51.424534933907644, 48.747216837746755, 47.16694286891392, 42.86881848743984, 42.945491858891074, 44.587187903267996, 46.087477684020996, 45.05724048614502, 46.58815792628697, 46.76404115131923, 45.640135288238525, 44.691160746983115, 42.710191113608225, 39.72119419915335, 40.292502880096436, 37.506851945604595, 36.17912415095738, 37.46362720217024, 37.96037823813302, 38.706632137298584, 38.21548134940011, 39.694040639059885, 37.0218676839556, 38.06583799634661, 37.49527972085135, 37.120257650102886, 40.43506601878575, 36.25461285454886, 37.503218037741526, 34.08067437580654, 37.98869909558977, 35.87760359900338, 36.4553393636431, 36.95723206656319, 39.152320861816406, 46.35530989510672, 47.75597987856184, 46.16890709740775, 45.08410569599697, 43.891318866184776, 46.559729371752056, 47.27074548176357, 47.80900853020804, 47.529378277914866, 46.29078197479248, 46.16562407357352, 42.53332471847534, 42.67305646623884, 40.57441561562674, 36.04144906997681, 50.992509841918945, 48.04081085750035, 48.1768114226205, 45.14187996728079, 43.603246552603586, 40.87140246800014, 38.24982282093593, 35.837092127118794, 37.0070332799639, 38.785112040383474, 37.308578150612966, 39.243415219443186, 35.855727195739746, 37.00940261568342, 37.22299371446882, 37.49264635358538, 36.57125268663679, 36.36022547313145, 37.56163501739502, 38.09023312159947, 38.42445189612252, 40.70317268371582, 39.50205496379307, 42.00293745313372, 38.50811168125698, 38.21897281919207, 40.429920877729145, 40.52468041011265, 41.90704536437988, 40.76174947193691, 41.07563434328352, 39.872265407017295, 35.72741481236049, 42.474577699388774, 43.58216919217791, 47.12256472451346, 51.20111213411604, 50.3911988394601, 49.82589340209961, 50.36541754858834, 49.05497339793614, 49.039440699986045, 50.6110189982823, 52.10337741034371, 50.27928767885481, 43.02558721814837, 42.45720372881208, 42.41775533131191, 50.80859102521624, 56.24184955869402, 55.28430788857596, 54.597106729234966, 53.024065835135325, 51.83429799761091, 56.00779948915754, 46.97488423756191, 22.92758754321507, 14.719418253217425, 10.717135139874049, 6.225242001669748, 1.2852003680808204, 0.16623889468610287, 0.3850608335009643, 26.349389484950475, 53.33083922522408, 45.08372701917376, 37.734068461826865, 46.49143900190081, 53.82504722050258, 57.37590673991612, 67.47080203465053, 31.927858420780726, 0.823744172496455, 0.09206124288695199, 0.21713936195841857, 0.17854811703520163, 0.09905938165528433, 0.11913229312215533, 0.14873110343302998, 0.16221472062170506, 0.0993398337491921, 0.13317097909748554, 0.13805265857705049, 0.12711936953876699, 0.20333844822432312, 0.13738606577473028, 0.08723888772406749], [0.05890921609742301, 0.013182002435704427, 0.0760785269417933, 0.048550856565790515, 0.03972862907020109, 0.011001284184333469, 0.042182808808450184, 0.023956795023488145, 0.019840682856738567, 0.022137164271303585, 0.009064774078849171, 0.025592602157433118, 0.08135404171688215, 0.05584062968513795, 0.5999990414295877, 9.53969861779894, 29.169777938297816, 39.09850358963013, 36.02768816266741, 24.43134273801531, 12.099764125687734, 24.348277023860387, 30.987687247140066, 37.91126489639282, 8.220128876822335, 0.11451083182224206, 0.19072360013212475, 2.7455270418098996, 3.6526858040264676, 5.081432589462825, 14.004556315285818, 24.942797899246216, 50.538931437901084, 48.83140468597412, 47.47799287523542, 45.37393937792097, 43.359486375536235, 41.581695965358186, 46.25040946687971, 48.3018616267613, 45.83742938722883, 44.241136346544536, 47.68751580374581, 47.042451994759695, 46.083308764866416, 46.49679258891514, 47.00236783708845, 46.209081581660676, 45.11782530375889, 43.82516506740025, 42.56472362790789, 38.0128128187997, 34.23248209272112, 33.23604440689087, 34.4732962335859, 31.44023036956787, 33.169814177921836, 32.60835804258074, 34.17345367159162, 33.892805508204866, 32.60290370668684, 33.68013504573277, 34.66353791100638, 35.20344768251692, 33.283538818359375, 34.83301837103707, 32.354898180280415, 33.71298612867083, 32.50320747920445, 34.04592643465315, 31.7956793648856, 32.5627361706325, 32.688995361328125, 37.78532184873308, 45.34160246167864, 46.26078312737601, 48.320052010672434, 38.94832522528512, 39.58174385343279, 42.24412332262312, 43.028064250946045, 42.612211091177805, 42.0652836390904, 40.97247791290283, 40.91115311213902, 39.07048497881208, 40.48492629187447, 38.16886241095406, 28.888450588498795, 48.22168983731951, 46.21308721814837, 43.132790974208284, 42.34166213444301, 40.821514402117046, 38.74850198200771, 40.339768001011436, 37.34750543321882, 37.81048474993025, 33.854072775159565, 31.60065037863595, 33.20093863351004, 32.45322561264038, 33.15590041024344, 32.77235289982387, 32.94169439588274, 33.01223945617676, 34.261195523398264, 32.97655003411429, 33.73090205873762, 34.67193480900356, 36.28648771558489, 37.983383723667686, 39.50980567932129, 39.996916089739116, 39.63174309049334, 40.455361706869944, 41.61464779717581, 41.40051473890032, 38.51175601141793, 34.21326337541853, 34.231808117457796, 33.079275676182334, 35.50209515435355, 39.120942796979634, 41.84807252883911, 43.745191301618306, 44.08820302145821, 45.259412220546174, 46.45167098726545, 47.73874487195696, 45.147876262664795, 52.24862602778843, 47.651864596775596, 46.26360757010323, 44.378425802503315, 41.80870056152344, 38.37811435971941, 42.84874166761126, 47.77644232341221, 48.5487311226981, 50.95621592657906, 49.70946591241019, 54.44724450792585, 52.251731872558594, 41.67900896072388, 29.48524352482387, 5.675898313522339, 4.893201981272016, 5.567646682262421, 0.8954433937157903, 0.0676038416900805, 0.05045640002936125, 15.940173319407872, 47.045127051217214, 40.55235855919974, 23.240421499524796, 23.30866149493626, 44.49693775177002, 45.579713753291536, 48.60736002240862, 18.29044144494193, 1.0754785473857607, 0.04634636075102857, 0.0343806908598968, 0.04956494750721114, 0.01900074810587934, 0.030745470031563724, 0.044609216108386, 0.005905244466183441, 0.05342626977445824, 0.018371656237702285, 0.046939329111150334, 0.02610816154628992, 0.03738703525492123, 0.01624257450125047, 0.014918303150417549, 0.0923579866066575, 0.018183413660153747, 0.036392740572669675, 0.04767907477383103, 0.019090667566550628, 0.013321164879016578, 0.028040342598355243, 0.02816950173915497, 0.04405829656336989, 0.0794809932953545, 0.04412440962291189, 0.015969045160870467, 0.037610378448984454, 0.10679770713405949, 0.5352840082986015, 11.68849069731576, 37.708429609026226, 45.95284243992397, 40.884798594883506, 28.280740295137676, 16.08569986479623, 28.13652695928301, 35.573053632463726, 42.994653838021414, 8.953737923077174, 0.24569633603096008, 0.3206194671136992, 3.4524126648902893, 4.284982732364109, 6.393351061003549, 5.55864702803748, 24.72416935648237, 52.65467527934483, 49.86177389962332, 49.24470438276018, 45.864985942840576, 44.58661815098354, 43.41827508381435, 47.189343861171174, 48.38247462681362, 46.883630071367534, 45.253342969076975, 47.231415203639436, 47.61418104171753, 48.42401443208967, 47.71646894727434, 47.99821145193917, 46.397211006709504, 46.841079303196494, 45.77322803224836, 43.016950607299805, 40.575773988451274, 36.414414473942344, 34.83043711526053, 35.75512075424194, 34.27152749470302, 35.098863397325786, 35.178131920950754, 35.6226463999067, 35.85690491540091, 35.39990104947771, 35.42310455867222, 36.909056731632774, 36.693874495370046, 34.669450828007285, 36.07779162270682, 34.80394015993391, 34.672650473458425, 34.02255964279175, 36.02633326394217, 33.969242640904014, 34.1787759917123, 33.848489897591726, 39.55073056902204, 47.692358698163716, 46.52754878997803, 46.56719173703875, 41.644594533102854, 39.679734298161094, 43.35346228735787, 43.160705362047466, 43.064980030059814, 43.55629410062517, 40.878625120435444, 40.617699418749126, 40.50692081451416, 41.193520954677034, 39.803485189165386, 30.520452158791677, 49.371370043073384, 46.908372606549946, 45.05643449510847, 43.306200640542166, 41.50570004326956, 39.39021328517369, 42.23620932442801, 38.947637353624614, 38.67066478729248, 35.09262044089181, 33.78346865517752, 34.009708949497764, 34.46869305201939, 34.74351167678833, 33.94501427241734, 34.77739109311785, 33.810622215270996, 36.11169883183071, 35.69008214133126, 36.358985219682964, 36.76910958971296, 37.97966991152082, 39.37061589104788, 40.25703232628958, 41.9063401222229, 41.85466289520264, 42.35572876249041, 43.49739422116961, 42.11576577595302, 40.64767394747053, 36.33886671066284, 36.39075585774013, 35.61130346570696, 37.230421338762554, 40.75505140849522, 43.31447941916329, 45.468921252659385, 45.519653524671284, 45.64817435400826, 48.41095529283796, 49.575622762952534, 44.9210592678615, 52.642581939697266, 51.38022974559239, 48.58146061216082, 46.215039661952424, 43.03566558020455, 41.13848427363804, 44.549233368464876, 50.8302937235151, 49.94679205758231, 52.541635036468506, 50.62609658922468, 53.11779008592878, 51.69935008457729, 46.32657214573452, 31.393833773476736, 8.488234673227582, 5.90362856217793, 3.9886785405022755, 1.336644287620272, 0.07386999045099531, 0.018687940069607327, 16.79335478373936, 51.113092354365754, 43.183120250701904, 28.801917723246984, 30.28523826599121, 49.103207792554585, 50.84484672546387, 56.570693901606965, 24.485811403819493, 1.4177316107920237, 0.01813270164919751, 0.02679052689511861, 0.04486094242227929, 0.03302713902667165, 0.0005193372916047727, 0.046193174685218504, 0.030574306180434566, 0.03053832346839564, 0.07190071219312293, 0.023061880276405385, 0.003094104417998876, 0.08245355343180043, 0.10244578029960394, 0.019772578296916823, 0.20684317659054482, 0.1161412021943501, 0.20657674303012236, 0.1125005768345935, 0.08165355385946375, 0.11497045787317411, 0.09753486953143563, 0.09973094811929123, 0.11748771422675677, 0.12764285930565425, 0.1824550266776766, 0.07549803344798939, 0.1073586248925754, 0.20431659716580594, 0.8802668995090893, 16.606851237160818, 46.68953561782837, 52.415990761348176, 45.587523528507774, 36.01393072945731, 20.34753727912903, 31.85135875429426, 40.701623235430034, 47.7610798563276, 10.364521009581429, 0.3204503490456513, 0.4448742925056389, 6.9103052871567865, 4.8991570217268805, 11.134398783956255, 23.941946370261057, 26.524723802294048, 54.56861216681344, 51.003477573394775, 51.69561890193394, 48.41997405460903, 48.228888171059744, 45.716846874782014, 48.37291390555245, 50.22510215214321, 46.723018986838206, 47.17683710370745, 48.255934034075054, 49.82938487189156, 49.61396639687674, 49.335260254996165, 49.322937624795095, 50.436184951237266, 49.78964465005057, 46.7147228377206, 45.78608567374093, 42.52886744907924, 38.69564356122698, 37.757650647844585, 39.49504770551409, 35.672673429761616, 36.7057454926627, 36.65904664993286, 37.50645242418562, 38.56397519792829, 37.108105250767295, 36.307561601911274, 39.64880091803414, 39.53028202056885, 36.7643153326852, 37.331875460488455, 36.55836725234985, 37.333935601370676, 34.822894845690044, 38.20131049837385, 34.42596857888358, 35.53246225629534, 35.60624170303345, 41.42981876645769, 51.305501869746614, 48.48431089946202, 46.56125797544207, 41.85900551932198, 41.42479174477713, 44.48058516638619, 44.5761194229126, 44.68655409131731, 44.05973277773176, 42.372241156441824, 41.75027663367135, 42.71516949789864, 43.358767236982075, 40.160580907549175, 35.240568433489116, 51.4407068661281, 50.46812582015991, 46.797861507960725, 45.42517886843, 43.418021474565776, 41.24111611502511, 47.54684952327183, 40.29219021115984, 42.37507254736764, 38.12269857951573, 36.30007839202881, 37.30498940604073, 36.4118332181658, 36.774532658713206, 36.13044854572841, 36.88193791253226, 35.99413183757237, 37.218494755881174, 36.60412808826992, 37.51742710386004, 39.33385297230312, 39.7658120564052, 42.440774713243755, 43.53629718508039, 44.75751256942749, 44.64901644842965, 44.94451986040388, 46.57896198545183, 44.82624762398856, 42.75845330102103, 38.145127364567344, 37.97780779429844, 38.514292103903635, 38.497175216674805, 43.93051018033709, 44.573381832667756, 48.36687592097691, 47.936414173671174, 49.116239139011924, 50.33929579598563, 51.362115791865754, 43.72810220718384, 54.41342415128435, 53.23689958027431, 50.69173622131348, 48.006396429879324, 45.04027645928519, 42.84950596945626, 47.35461718695504, 51.36819893973214, 52.56906999860491, 54.50716577257429, 52.97185012272426, 55.89407137462071, 53.52814027241298, 47.034975733075825, 35.32454783575875, 8.867582866123744, 14.073483313832964, 13.516095348766871, 1.71958469918796, 0.2515904711825507, 0.1052959259333355, 18.90734073093959, 59.55845056261335, 51.96000133241926, 33.21517201832363, 32.99413939884731, 55.490401881081716, 56.25114277430943, 62.94562094552176, 31.734729766845703, 2.252006483929498, 0.19802908812250408, 0.08097835723310709, 0.1845044602773019, 0.09388261408145938, 0.0985008387693337, 0.09464817800159965, 0.06265405765069382, 0.15491137680198463, 0.17002061461763723, 0.23605117787207874, 0.07194169570824929, 0.19396798818239144, 0.20300790667533875, 0.15730440696435316], [0.06155875963824136, 0.040850400126406124, 0.02634810170690928, 0.022391964348831346, 0.04365922976285219, 0.06889651875410761, 0.023960072347628217, 0.012217948362896485, 0.019258326784308468, 0.03634618289236512, 0.018331809268732156, 0.10282128836427416, 0.004817835695575923, 0.08947354781308345, 1.6568679788282938, 11.878835729190282, 34.41120365687779, 45.781100341251914, 28.86149331501552, 18.44388198852539, 11.616068754877363, 22.149331978389196, 30.137245110103063, 36.795498847961426, 5.0819927879742215, 0.11953846418431827, 0.23039086588791438, 3.6480235627719333, 6.649006554058619, 2.086900132043021, 2.2885197017874037, 24.211776188441686, 50.90856865474156, 51.44110638754708, 47.94202484403338, 49.428480761391775, 42.06631892068045, 43.40618174416678, 46.395668506622314, 48.647117614746094, 45.505684171404155, 47.121644088200156, 45.58613041469029, 45.59792498179844, 43.60170405251639, 45.886584418160574, 44.34990692138672, 43.958619117736816, 45.098877566201345, 44.99184404100691, 41.82475437436785, 37.476470947265625, 35.545656885419575, 35.309588364192415, 32.83354568481445, 31.242446422576904, 31.560927527291433, 32.49426167351859, 32.91342912401472, 32.08868489946638, 32.49982023239136, 34.01549332482474, 33.19690520422799, 33.47930083956037, 32.80310215268816, 32.39223779950823, 33.01784665243966, 32.54015105111258, 32.808990750994, 33.07024301801409, 32.09618200574602, 31.78658069883074, 33.21144430977957, 40.39518683297293, 46.20866468974522, 42.66802944455828, 37.13156584330967, 40.20891605104719, 44.278138978140696, 43.28667967660086, 42.18473359516689, 42.62023278645107, 39.7181578363691, 40.17990732192993, 40.078758920942036, 39.95110314232962, 39.26036882400513, 40.50584384373256, 27.934600148882183, 47.57741117477417, 44.77352121898106, 44.1980470929827, 43.11009120941162, 45.328675338200156, 44.284055369240896, 43.75044413975307, 43.931517669132774, 42.532470090048655, 40.91805614743914, 33.13434362411499, 30.82946286882673, 34.20678765433175, 31.25489412035261, 32.83523062297276, 31.761077335902623, 34.24121250425066, 34.32415662493025, 34.27366059167044, 33.86049638475691, 35.20970800944737, 36.017324924468994, 38.631077425820486, 39.06600339072091, 40.2290484564645, 42.114223275865825, 41.755755288260325, 41.507701124463765, 42.38499804905483, 39.42696578162057, 35.84330381665911, 35.19607216971261, 33.27308177947998, 34.96947404316494, 36.36843824386597, 37.78896965299334, 38.936798163822715, 40.374925885881694, 44.256339005061555, 47.597335134233745, 46.43558938162667, 48.942294461386545, 46.309083529881065, 49.28990241459438, 47.67866727284023, 46.28740515027727, 46.29526356288365, 46.26592132023403, 41.13143185206822, 44.318699087415425, 50.80133015768868, 49.96018818446568, 54.678577831813264, 51.342445441654746, 56.966970511845176, 47.48783499853951, 24.07950333186558, 6.90540029321398, 4.57887372800282, 2.832515448331833, 1.773422707404409, 0.07977597960936171, 0.07367244176566601, 9.650389501026698, 45.97929423195975, 34.21419095993042, 29.763682161058696, 26.910426991326467, 46.33615371159145, 45.674897125789094, 50.39610774176461, 25.605329479490006, 1.1726860169853484, 0.05481476276846869, 0.0416375482454896, 0.02775892019937081, 0.03595334165064352, 0.022020342593480433, 0.005415191632762019, 0.03644897076966507, 0.04888008514951382, 0.035118190571665764, 0.08842986595949956, 0.03943686919020755, 0.035056192827011855, 0.045182893717927594, 0.02800554223358631, 0.08709351159632206, 0.07145493504192148, 0.052956194284238985, 0.014115566537449402, 0.06956395293985095, 0.04802821836035166, 0.07439970916935376, 0.03201089373656681, 0.08254695377711739, 0.04312007262238434, 0.07354658030505691, 0.015070805592196328, 0.08294752692537648, 0.08695452048310212, 1.5128114117043359, 17.325600692204066, 41.274307659694124, 49.560718876974924, 33.7395212990897, 25.61368989944458, 12.236370921134949, 24.752670867102488, 35.21920272282192, 41.44547653198242, 5.752378003937857, 0.10192154414419617, 0.6912633585078376, 6.739641462053571, 6.4777503950255255, 6.1898921728134155, 4.673098683357239, 23.532881600516184, 54.09817048481533, 52.23789800916399, 50.488313811165945, 49.81135777064732, 44.69173049926758, 45.51039852414812, 49.20596817561558, 50.4511513710022, 46.22298492704119, 46.96764074053083, 46.30106183460781, 47.04061419623238, 46.20308181217739, 46.95895896639143, 45.97139065606253, 46.017922742026194, 47.666768482753206, 46.5306442124503, 43.890606675829204, 39.870337281908306, 37.51002032416207, 36.85040698732649, 33.84602676119123, 32.808327198028564, 33.392948627471924, 34.23058870860508, 34.18888214656285, 34.223765577588765, 33.349046434674946, 35.07176194872175, 35.772505147116526, 35.058945996420725, 33.733323505946565, 33.153916699545725, 33.68509258542742, 33.596308503832134, 34.00877441678728, 33.28560243334089, 33.71676247460501, 33.480509826115195, 34.92435244151524, 42.270307609013145, 46.80705744879586, 43.924857820783345, 39.13782344545637, 41.222574847085134, 44.22142430714199, 44.52212497166225, 43.202345916203086, 43.77595445087978, 41.14449099131993, 40.36978769302368, 40.802323477608816, 41.44914518083845, 41.645713193076, 42.2209267616272, 30.051330634525844, 47.62675380706787, 45.9667318889073, 46.03365693773542, 46.04890128544399, 45.538476194654194, 44.70166294915335, 45.90897846221924, 44.67083379200527, 44.364341803959434, 42.742844172886436, 35.42198589869908, 32.836710589272634, 36.14733961650303, 33.437232971191406, 34.45169428416661, 34.4471675327846, 35.33912168230329, 36.232743399483816, 35.72490998676845, 36.1980163029262, 37.72218704223633, 38.30860110691616, 39.47097567149571, 41.5846072605678, 41.27205644335066, 43.75144468035017, 44.7773323059082, 41.567347935267854, 43.82744060243879, 40.63387482506888, 37.52116870880127, 36.501704692840576, 35.31749888828823, 36.88164608819144, 38.65898139136178, 39.802019119262695, 41.19740152359009, 42.26279660633632, 46.40168217250279, 49.21131828853062, 48.73628732136318, 48.057274614061626, 46.88582917622158, 52.737004484449116, 50.278137751988, 49.33453416824341, 48.62262521471296, 46.93573808670044, 43.60067571912493, 46.52310541697911, 51.522111960819785, 53.070663928985596, 55.554964542388916, 52.99894462312971, 56.389946937561035, 45.49714830943516, 26.145319155284337, 11.510546462876455, 8.346687708582197, 4.345751677240644, 2.4152715631893704, 0.16113983972796372, 0.09328899772039481, 11.929139818464007, 51.3616988999503, 40.62920910971505, 31.465368952069962, 31.166954244886124, 50.755201067243306, 51.40091453279768, 56.318043504442485, 30.851248945508683, 1.9271074150289809, 0.04246514044435961, 0.04441516527107783, 0.02570347986849291, 0.047608086440180025, 0.04357698453324182, 0.020273847738280892, 0.019410949666053057, 0.020402129872569015, 0.01509686472958752, 0.017513920120628815, 0.02824692937013294, 0.0179999700215246, 0.007111772603821009, 0.009802673278110368, 0.2201607155480555, 0.1566531490534544, 0.11906210545982633, 0.0675611754081079, 0.13525824780975068, 0.16670436970889568, 0.10506271344742604, 0.08486655287976776, 0.1042113352034773, 0.26149892807006836, 0.23156180019889558, 0.13899708432810648, 0.1602080754403557, 0.24618713398064884, 2.2955714719636098, 24.510842289243424, 51.54326227733067, 57.09114524296352, 40.309265409197124, 28.281049489974976, 15.659728390829903, 31.05579001562936, 40.98804535184588, 47.477600302015034, 6.8414351769856045, 0.3496590017208031, 0.6873748643057687, 5.867660777909415, 10.755704590252467, 7.711234126772199, 5.193966482366834, 27.794491461345128, 55.783845152173726, 55.295838424137656, 52.07731819152832, 52.951578753335134, 45.710777623312815, 48.34780658994402, 50.35866042545864, 51.918954849243164, 47.21028920582363, 47.090387616838726, 46.57974018369402, 49.28325646264212, 48.24849598748343, 50.243657316480366, 48.98496682303292, 48.10101005009243, 48.125696999686106, 48.39129536492484, 45.66864027295794, 41.27265746252877, 39.264131273542134, 39.173696994781494, 36.236551012311665, 34.23511893408639, 35.04277059010097, 36.410318510872976, 36.43624223981585, 35.2283604485648, 34.41117933818272, 37.07529238292149, 36.64939907618931, 37.57569817134312, 35.22112389973232, 35.5438677242824, 35.40480300358364, 35.51219088690621, 35.72580977848598, 35.514518533434185, 34.95516422816685, 35.51433788027082, 36.38813986097063, 44.30582754952567, 49.125417709350586, 43.712607724326, 39.57106099809919, 43.32156310762678, 45.94308022090367, 44.74257741655622, 43.12065247126988, 44.816068513052805, 41.815266609191895, 42.703593799046104, 41.91827712740217, 42.02689136777605, 42.62585735321045, 43.93630845206124, 32.7569556917463, 50.731327056884766, 49.07982363019671, 47.69162218911307, 48.949419839041575, 49.2083409854344, 47.7239591053554, 48.23415837969099, 46.71644251687186, 46.072323662894114, 45.30762924466814, 38.27202231543404, 34.68101263046265, 38.97880349840437, 35.61290849958147, 36.53142213821411, 35.825318404606406, 37.94781242098127, 38.59984527315412, 37.96618345805577, 38.01151350566319, 38.75424814224243, 40.29873194013323, 42.26558630807059, 44.59362193516323, 43.82023532049996, 46.45549597058977, 46.54080942698887, 44.46183892658779, 46.258115019117085, 42.90380614144461, 39.54127754483904, 39.789206641060964, 36.558103220803396, 40.52330814089094, 39.40302923747471, 40.68428747994559, 42.65560606547764, 44.373614174979075, 49.194378580365864, 51.205611092703684, 47.96943548747471, 49.2463059425354, 48.584656783512656, 54.26994037628174, 50.15207658495222, 51.87873867579869, 50.67976100104195, 50.698271002088276, 46.018110343388145, 49.62131411688668, 53.10836138044085, 54.83007287979126, 57.205797467912944, 55.56999002184187, 53.93435280663626, 49.73103312083653, 28.087026255471365, 12.51605328491756, 7.198540014880044, 8.940483365740095, 4.244565495422908, 0.5178737768105098, 0.2637609195496355, 12.377087576048714, 58.89617606571743, 44.513818400246755, 41.5137425831386, 36.92736870901925, 57.71274845940726, 56.886878626687185, 64.58843912397111, 37.66154316493443, 3.152827186243875, 0.14559461602142879, 0.14280715345271996, 0.1817854211798736, 0.2176697999238968, 0.1156884700592075, 0.09614393381135804, 0.12148656536425863, 0.0948822522269828, 0.07637444963412625, 0.13421301889632428, 0.09078723232128791, 0.14073125698736735, 0.18947354863796914, 0.0694857042815004], [0.011723537214233406, 0.02086886527415897, 0.011326191348156758, 0.02009690785780549, 0.04696493023740394, 0.09285737480968237, 0.021164640385125364, 0.038288923645658154, 0.049732613510319164, 0.07512524630874395, 0.0785890386572906, 0.04735697080780353, 0.06660150976053306, 0.054008459605808766, 1.4328221210411616, 13.49156299659184, 36.62705019542149, 46.11523573739188, 27.2955812726702, 17.65177345275879, 17.69708960396903, 24.801514966147288, 36.70200041362217, 35.20615747996739, 3.5102839938231876, 0.08009932868714843, 1.361124636871474, 5.955259757382529, 6.349016777106693, 6.422243407794407, 4.119836211204529, 24.298194408416748, 47.6181206703186, 48.47342307226998, 49.721684319632395, 47.08809123720442, 43.84892095838274, 42.414663382938926, 45.942368030548096, 48.32093095779419, 45.00802639552525, 43.330519335610525, 44.444701194763184, 46.98984718322754, 42.69995641708374, 40.419012205941335, 40.35495328903198, 42.208861214774, 42.70151628766741, 44.342621735164094, 40.89056559971401, 37.475630215236116, 35.19936214174543, 32.97414943150112, 31.739517075674875, 31.241320814405167, 32.09871115003313, 33.87377091816494, 33.07278953279768, 33.08753361020769, 31.46039056777954, 32.03276579720633, 32.56105818067278, 32.974806036267964, 33.12689515522548, 32.61804035731724, 31.83274105616978, 33.49341263089861, 32.36146422794887, 33.108708245413645, 33.343949931008474, 31.334520476205007, 32.581993103027344, 42.45283331189837, 44.641060761043, 40.335317679813926, 44.60653863634382, 46.04251936503819, 43.42682484218052, 45.782302379608154, 43.093568393162315, 43.183849811553955, 40.51452909197126, 41.69698742457798, 41.52794122695923, 41.06814765930176, 38.0699964932033, 40.40148884909493, 28.23162521634783, 43.81464202063424, 45.81730393001011, 44.401406969342915, 46.48730482373919, 44.63963985443115, 45.74076952253069, 45.22614771979195, 46.00417225701468, 44.624249594552175, 44.403626918792725, 37.35887963431222, 30.85176658630371, 32.62031241825649, 32.42682245799473, 31.264065742492676, 32.27824912752424, 33.53717238562447, 35.30256373541695, 34.92727415902274, 33.77204234259469, 33.34895610809326, 34.151709284101216, 36.98017849240984, 39.67153194972447, 40.00238084793091, 42.74154485974993, 43.08047103881836, 44.02558585575649, 42.03186975206648, 42.03479494367327, 38.20354087012154, 34.46087980270386, 35.66117416109358, 35.28203528267996, 35.36905104773385, 34.92275782993862, 33.873347078050884, 37.25024454934256, 43.763729095458984, 47.66304077420916, 47.817478384290425, 38.24261406489781, 45.943180969783235, 47.68684877668108, 50.64784792491368, 53.26619665963309, 48.83437851497105, 49.10415622166225, 47.6697735786438, 40.324169295174734, 46.68392842156546, 51.32090255192348, 49.44778285707746, 47.705313614436555, 39.39126941135952, 54.38567304611206, 36.191026415143696, 12.669603262628828, 6.171677904469626, 1.7090526414769036, 1.2137066615479333, 0.09627971545393978, 0.06213869673332997, 7.794313737324305, 44.62410020828247, 41.92555883952549, 35.66256380081177, 27.814865316663468, 43.67244018827166, 45.91727113723755, 47.66488552093506, 27.0920216356005, 2.121382087469101, 0.09258719573595695, 0.015588816188807999, 0.05643066338130406, 0.03903811790847352, 0.039424153443958075, 0.08733789955398866, 0.05865829384752682, 0.03343609208241105, 0.03740164750654783, 0.024250107052336847, 0.04025094157883099, 0.02240697693611894, 0.03226273540141327, 0.03921729525817292, 0.019337691632764678, 0.04758889068450246, 0.009340258448251655, 0.04156729272965874, 0.06301165239087173, 0.09561566037258931, 0.04997943740870271, 0.041259631381503174, 0.035930515732616186, 0.022159968136942813, 0.06346891035458871, 0.07176855392754078, 0.05893406404980591, 0.07926559235368456, 1.5527441203594208, 18.972122260502406, 42.27598428726196, 53.62549148287092, 30.529092243739537, 18.927282060895646, 15.812548807689122, 24.500974110194615, 36.99611071177891, 39.31335578645979, 3.633248652730669, 0.11470700986683369, 0.6109237266438348, 7.326720816748483, 8.4101516859872, 10.556055051939827, 5.179693579673767, 26.617367608206614, 48.50455447605678, 49.93739461898804, 51.673089368002756, 47.8534700529916, 46.56679916381836, 44.04042373384748, 46.66132593154907, 49.54735401698521, 45.7718140738351, 43.67660215922764, 45.52892936979021, 47.6437907900129, 44.918207032339915, 43.24300330025809, 42.35493319375174, 45.13113457815987, 44.046152523585725, 45.22099910463606, 43.24123845781599, 39.97829144341605, 36.82577562332153, 35.45635516302926, 33.516963550022666, 33.34965787615095, 34.37022318158831, 33.949384689331055, 35.503828729902, 34.90744400024414, 32.84594474520002, 33.738590240478516, 33.329098156520296, 34.18243074417114, 34.32797466005598, 34.595810345241, 32.912008217402864, 34.22984177725655, 33.53652620315552, 33.608228138514924, 33.337286608559744, 33.17131846291678, 34.461769172123496, 42.77311747414725, 46.89419828142439, 42.90455307279314, 44.03782858167376, 47.12905434199742, 45.618797370365684, 46.16691296441214, 43.25670167378017, 43.914293084825786, 43.20275933401925, 43.06801291874477, 43.06655727113996, 42.946624415261404, 40.18840496880667, 39.18067646026611, 30.49504954474313, 44.837402956826345, 47.58046490805489, 47.334161690303254, 47.905220236097065, 46.02284901482718, 48.112808091299875, 46.36627415248326, 47.38083274023873, 46.07261896133423, 45.95184884752546, 39.161992754255024, 32.24271603993007, 34.695402349744526, 33.50492579596383, 33.48218086787632, 34.83134732927595, 36.30409097671509, 36.32266698564802, 36.8098121370588, 35.85519565854754, 36.55368069240025, 37.1119510786874, 39.57149873461042, 41.86897618430001, 43.35900000163487, 43.94651882989066, 45.33606127330235, 45.33301796231951, 44.36264296940395, 42.21963439668928, 39.036588191986084, 36.99439798082624, 36.40890107836042, 35.73749664851597, 36.96594858169556, 35.394321646009175, 35.74427114214216, 39.20589147295271, 46.09091009412493, 48.33027975899832, 49.748883043016704, 41.023126806531636, 46.40065383911133, 48.57680531910488, 53.64877142224993, 53.76828738621303, 49.09477267946516, 51.17443799972534, 48.69154439653669, 42.63032157080514, 49.02509961809431, 50.54265219824654, 51.596829414367676, 50.12836933135986, 45.09146383830479, 56.542025634220664, 31.82458734512329, 11.886311990874153, 9.334719811167036, 4.253230767590659, 2.551199823617935, 0.049073976531092606, 0.11975996515580586, 9.62882489817483, 51.19880185808454, 41.804889474596294, 38.93563781465803, 32.14492014476231, 49.18021467753819, 50.46673618044172, 53.1647355897086, 33.58250938143049, 3.0604745532785143, 0.03649571504709976, 0.021881887522925223, 0.018766158193882023, 0.04970443734366979, 0.033532589940088134, 0.04541105451062322, 0.05904664658010006, 0.04403154532025967, 0.009308566622036909, 0.07524846148278032, 0.04084198289949979, 0.05216546689293214, 0.07123160881123372, 0.02639690024911293, 0.08270866902811186, 0.0932132460709129, 0.07612578690584217, 0.09592850572828736, 0.07308851488466774, 0.21193974811051572, 0.10612696848277535, 0.10527629591524601, 0.146724580387984, 0.13227661566010543, 0.18894891893225058, 0.1925526862697942, 0.16434864540185246, 0.14340764337352344, 2.0209647672516957, 24.928700004305156, 50.86871378762381, 57.82645920344761, 38.39017990657261, 27.017462253570557, 25.09173427309309, 34.73545871462141, 47.935840947287424, 44.676430565970286, 4.332715553896768, 0.2692622100668294, 2.4221216184752326, 12.959219813346863, 13.154983571597509, 11.498673728534154, 6.320338521684919, 26.987133366721018, 48.60855858666556, 49.42791100910732, 52.447896889277864, 50.22998326165335, 48.383697509765625, 46.048741476876394, 48.84278583526611, 52.26109109606062, 46.27700022288731, 44.54817376817976, 47.0955570765904, 50.53261205128261, 45.17867067881993, 44.429842472076416, 44.36787496294294, 47.203691891261506, 46.22809880120413, 48.17569623674665, 44.9933101109096, 42.567054748535156, 39.94384574890137, 37.86603559766497, 35.511930329459055, 34.702378341129844, 36.411242621285574, 36.42957891736712, 37.619350228990825, 37.24040937423706, 33.69838796343122, 34.634414536612375, 35.74098811830793, 36.49101488930838, 35.274079595293315, 35.5484813281468, 34.85241426740374, 36.88863250187465, 34.79839549745832, 36.022417954036165, 35.213230746132986, 34.365828445979524, 36.012190205710276, 46.42640733718872, 47.69748994282314, 44.240733351026265, 47.16702972139631, 48.39688866479056, 46.60399981907436, 48.40700871603829, 45.93542678015572, 44.67476647240775, 45.46498509815761, 43.988485949380056, 45.43537882396153, 44.65137536185128, 40.42325060708182, 40.117713996342246, 32.95735910960606, 46.38066387176514, 48.38781779153006, 48.68285567419869, 49.93592854908535, 48.067623955862864, 49.63151754651751, 49.50116239275251, 50.40296908787319, 47.07530655179705, 48.4099999155317, 41.145682607378276, 35.025726658957346, 36.22394003186907, 36.39884008680071, 35.2772410256522, 36.96913433074951, 38.86214324406215, 39.630739075796946, 39.39421544756208, 38.56122023718697, 37.476401465279714, 39.5084090914045, 41.59082242420742, 42.76218100956508, 44.30908625466483, 46.479852880750386, 46.85729987280709, 47.3799329485212, 45.40664107458932, 45.38134963171822, 40.474889619009836, 38.60928092684065, 38.3660557610648, 38.08768660681588, 38.85172094617571, 38.81041390555245, 36.88769449506487, 40.61591720581055, 50.19998094013759, 51.88939373833792, 51.427279472351074, 43.5461288860866, 46.86281326838902, 50.242917333330425, 54.0780519757952, 54.554066113063264, 51.62698459625244, 53.14355400630406, 51.38714667728969, 43.67856502532959, 51.585938113076345, 54.28831488745553, 55.0117370060512, 53.38937432425362, 47.87119490759713, 54.68914951596941, 37.22565140042986, 15.753648928233556, 11.55951910359519, 7.188414318220956, 3.4757907475743974, 0.19967138714024, 0.24796036311558314, 10.769577537264142, 55.87722199303763, 52.96519374847412, 47.17734432220459, 37.28876883643014, 55.14076852798462, 55.98377261843, 61.61850111825125, 40.79480900083269, 5.027810735361917, 0.19131959815110477, 0.07817751395383052, 0.22271987822438988, 0.1539245154708624, 0.15956550277769566, 0.24654092213937215, 0.16482914318995817, 0.1364618060844285, 0.1891771238297224, 0.12825383937784604, 0.12125690840184689, 0.12691841460764408, 0.16209836543670722, 0.1789223969514881], [0.08630132196205002, 0.05116824093940003, 0.036225790424006324, 0.042117184294121604, 0.035785804569189034, 0.025232724146917462, 0.026403127504246574, 0.05786512712282794, 0.07309048942157201, 0.059787118275250704, 0.039627805551780124, 0.05064235594389694, 0.04555055113243205, 0.03266580895121608, 0.7549647688865662, 12.549958756991796, 41.67182799748012, 47.57478822980608, 38.51511199133736, 24.301909957613262, 13.177337663514272, 22.406677620751516, 32.854188782828196, 32.37346724101475, 2.469912196908678, 0.06119204538741282, 9.892582859311785, 11.638438480240957, 6.396806487015315, 9.556219696998596, 4.07804366520473, 23.676299367632183, 42.5595645904541, 49.600730078560964, 50.82106304168701, 48.80508838381086, 44.95530693871634, 44.51190764563424, 45.01500586100987, 47.73694181442261, 44.737724099840435, 45.20995494297573, 44.44091442653111, 46.228616441999165, 43.72351292201451, 39.31973770686558, 36.00415461403983, 34.272062505994526, 36.60639667510986, 36.836274351392476, 35.419925757816856, 34.19153635842459, 32.47147853033883, 33.06723097392491, 32.89233091899327, 31.24111236844744, 31.893711498805455, 31.439702306474956, 31.12154081889561, 31.71681383677891, 32.81579303741455, 34.489106859479634, 33.277605056762695, 33.06413902555193, 33.11251238414219, 32.42844486236572, 32.707474095480784, 32.403955936431885, 32.57474960599627, 32.366654532296316, 31.964666502816335, 32.911778926849365, 32.104228019714355, 38.21512699127197, 42.72525480815342, 44.926826272692, 43.331360067640034, 43.28320905140468, 43.23127474103655, 43.51700551169259, 42.944671971457346, 43.30895560128348, 43.276872294289724, 40.862220423562185, 42.80327960423061, 42.32712650299072, 39.675739083971294, 41.65944978169033, 29.197400501796178, 38.66512707301548, 46.566288471221924, 46.88560683386666, 49.498942443302695, 47.35240765980312, 45.93517664500645, 45.49115548815046, 44.57547671454293, 44.030828271593364, 44.241376059395925, 40.84400224685669, 34.35520812443325, 32.39235244478498, 31.804044995989116, 32.84751851218087, 32.600492681775776, 33.64875003269741, 34.26157072612217, 33.85984672818865, 33.90660810470581, 32.702777113233296, 32.72270107269287, 35.00594513756888, 35.38512223107474, 38.54731341770717, 40.861765316554475, 43.05394976479666, 41.90926531382969, 43.50791379383632, 40.600075313023154, 39.139147077287944, 36.41411222730364, 34.195371764046804, 34.35256086077009, 34.505160672324045, 36.295384883880615, 34.458458355494905, 33.75288963317871, 40.974579742976594, 46.11948456083025, 47.75134195600237, 45.61293656485421, 45.0400367464338, 49.12790169034685, 44.622995444706504, 42.53018413271223, 48.717933654785156, 52.351136275700156, 49.034194810049875, 46.56705624716622, 43.566646916525706, 49.44256475993565, 50.729430198669434, 51.24251297542027, 46.53811352593558, 40.29526131493704, 46.09710093906948, 18.31156744275774, 17.816285950796946, 2.0131241594042097, 1.8081082233360835, 0.16289830394089222, 0.10441768448799849, 5.426708119256156, 43.23734399250576, 43.71459143502371, 25.7444133077349, 25.777370350701467, 34.27622447695051, 44.621831621442524, 47.719189167022705, 31.263200691768102, 3.941229292324611, 0.02810239971482328, 0.04053692712581583, 0.04965906709964786, 0.03886449097522667, 0.0589285475601043, 0.0031208594778685695, 0.02197665341996721, 0.05665350445945348, 0.02282701725406306, 0.04948741131063018, 0.05807353236845561, 0.027731344536212937, 0.04752799216657877, 0.030076678775783097, 0.03532527606668217, 0.03772644864927445, 0.07300918057028737, 0.04905030922964215, 0.040739093241947036, 0.04597044556534716, 0.0402066094933876, 0.028271144588610957, 0.06214103089379413, 0.09582571445831231, 0.044976588538182635, 0.03389163674520595, 0.026335825312084386, 0.023029680397095423, 0.8764034296785082, 18.274073226111277, 47.69662141799927, 52.543048994881765, 41.86265332358224, 26.7152190889631, 16.536651849746704, 24.3402327469417, 37.81960078648159, 35.88937037331717, 2.8661503749234334, 0.015941233706793616, 9.752565366881234, 8.468989031655447, 6.227354688303811, 9.46828590120588, 7.222875646182469, 25.826049430029734, 43.79277603966849, 49.955220222473145, 50.68908895765032, 50.65564727783203, 46.242335660117014, 47.43752309254238, 46.05064875738961, 50.07637248720442, 45.34713322775704, 44.666414737701416, 46.48361880438668, 47.43752656664167, 45.30823373794556, 39.84070668901716, 36.72418948582241, 35.31525462014334, 38.59770175388881, 39.76419660023281, 37.26500252314976, 36.59680816105434, 34.15918901988438, 35.30762202399117, 33.99920327322823, 33.259949684143066, 34.282213824135916, 34.00114182063511, 32.91142804282052, 33.22247110094343, 34.069737911224365, 35.769819668361116, 34.57773460660662, 34.62373168127877, 33.04099110194615, 34.57028266361782, 34.17250871658325, 34.63523094994681, 33.79151119504656, 34.67988354819161, 33.85886008398873, 34.50843674795968, 34.65631525857108, 41.362521989004954, 44.02977909360613, 45.75868197849819, 46.21328524180821, 44.61230911527361, 45.4762898172651, 46.06554569516863, 45.16387448992048, 45.45522287913731, 44.96053198405674, 42.75031696047102, 44.78427703039986, 43.962492738451274, 41.37556375776018, 43.36440222603934, 31.447623252868652, 40.379942485264365, 47.33145884105137, 46.8489168712071, 50.78870528084891, 49.431096758161274, 47.506001063755576, 45.86649717603411, 45.22800636291504, 46.62669610977173, 45.766036646706716, 43.1391589982169, 37.08978285108294, 33.674336774008616, 34.78450257437569, 34.37546212332589, 35.00187349319458, 35.36842918395996, 36.20716708047049, 36.345762797764365, 34.8414500100272, 35.65633126667568, 35.3153657913208, 37.34309680121285, 37.50527123042515, 38.865214347839355, 43.09256785256522, 45.86959259850638, 44.3562228339059, 45.839805671146934, 43.04997886930193, 41.109030859810964, 36.97766671861921, 35.74237428392683, 35.65158217293875, 35.92354508808681, 37.400707789829795, 36.267498288835796, 36.21516793114798, 42.12893608638218, 47.59884636742728, 49.329385553087505, 47.830141476222444, 45.56538656779698, 48.98776694706508, 45.08017996379307, 46.76365205219814, 49.64263466426304, 52.737456117357524, 50.47902406964983, 47.9420873778207, 46.24824162891933, 53.74573005948748, 51.89534139633179, 54.321207659585134, 46.44352075031826, 45.385775634220664, 45.80897651399885, 16.263971533094132, 8.311782564435687, 3.6035941754068648, 1.5959485620260239, 0.1612823320818799, 0.10704302468470164, 6.187030383518763, 47.67143072400774, 45.920088631766184, 29.79530688694545, 31.528114659445627, 42.1007194519043, 51.21436929702759, 54.56907074792044, 34.832955837249756, 4.995489886828831, 0.0542760263197124, 0.04604983416252902, 0.031163264398596117, 0.10664948115923575, 0.03697027904646737, 0.04993047092908195, 0.023819308561672057, 0.02540703640053315, 0.07883271415318761, 0.03760184247844985, 0.03849590057507157, 0.04723153343158109, 0.07888631841966084, 0.02243526336470885, 0.24548455168093952, 0.08032337416495595, 0.12653493375650474, 0.12897810765675136, 0.13409390885915073, 0.15377663554889814, 0.06067535454141242, 0.17526681667992047, 0.11429158358701638, 0.14072201534041337, 0.2047723691378321, 0.17534594743379525, 0.1457738442612546, 0.20813052036932536, 1.7878752861704146, 24.777328286852153, 53.45832477297102, 57.420562812260215, 49.34972293036324, 32.683131081717356, 20.895666769572667, 30.23406825746809, 43.228637899671284, 41.98522302082607, 3.2327946552208493, 0.18681840039789677, 11.889400465147835, 17.863161972590856, 11.009442380496434, 15.337611641202654, 7.016452917030879, 27.011254038129533, 47.853056635175435, 51.963082858494346, 52.532751764569966, 53.2050907271249, 48.431424685886924, 48.533222743443076, 47.493900775909424, 51.80776630129133, 45.94852760859898, 46.29859522410801, 47.35724360602242, 49.770071574619834, 48.441496099744526, 43.21707609721592, 38.740574087415425, 38.25901528767177, 40.67586278915405, 41.877393926892964, 40.44053425107683, 39.052221638815745, 36.86348349707467, 36.99474539075579, 36.125070640019004, 34.52165222167969, 35.89121512004307, 35.933272566114155, 33.84648881639753, 34.3634660584586, 36.62560844421387, 37.331489835466655, 36.66872549057007, 34.9884078843253, 36.80582734516689, 36.42750835418701, 36.31990507670811, 35.88052184241158, 35.300267355782644, 35.84410980769566, 36.01658494131905, 36.150490624564036, 35.760727950504844, 42.67386245727539, 44.97582496915545, 48.019629274095806, 46.2173638343811, 46.41317796707153, 47.75803654534476, 46.824549538748606, 46.88489464351109, 45.70215490886143, 45.694973945617676, 44.03173153741019, 45.65197154453823, 46.25477293559483, 42.82315840039934, 43.270587648664204, 34.58961950029646, 40.93258135659354, 48.77013199669974, 48.19179173878261, 51.38890109743391, 50.60711758477347, 49.670566422598704, 47.2388254574367, 45.90755755560738, 49.78635120391846, 48.19778108596802, 45.087121214185444, 38.52300861903599, 36.00392879758562, 36.697970458439414, 37.25823497772217, 37.47333383560181, 37.73137256077358, 37.95606688090733, 38.49473292487008, 36.82787050519671, 37.17404365539551, 35.62105873652867, 39.34057535443987, 38.790062631879536, 40.71485955374581, 46.35392025538853, 47.65111071722848, 45.84780304772513, 47.29046446936471, 45.588854108537944, 43.12111105237688, 39.033152307782856, 37.37760155541556, 37.61150918688093, 37.432151862553184, 40.515053680964876, 37.45226689747402, 38.141219002859934, 44.78956460952759, 49.893711294446675, 52.0697272845677, 48.934960637773784, 50.75322083064488, 50.3865852355957, 46.24317291804722, 45.261121477399556, 50.613770484924316, 55.43147768293108, 52.18023838315691, 49.09663132258824, 48.435406003679546, 55.98985576629639, 54.39995159421648, 56.81722640991211, 49.006846700395855, 51.09193508965628, 43.93307406561715, 20.686175107955933, 23.55392074584961, 6.262252884251731, 3.5574768100466048, 0.5898174877677644, 0.23757068919284002, 6.984595860753741, 56.085647106170654, 54.47300495420183, 36.51025445120675, 35.55054841722761, 48.31972891943795, 58.98617608206612, 61.680562428065706, 43.120857443128315, 6.744007970605578, 0.14637103650186742, 0.09222262565578733, 0.09951295517385006, 0.2747409189386027, 0.17470218054950237, 0.1131926757682647, 0.08922921413821833, 0.14936367448951515, 0.15549840458801814, 0.1587070067014013, 0.13616950676909514, 0.17113516266856874, 0.10968586429953575, 0.15841150470077991], [0.06377398648432323, 0.03385160317910569, 0.021150112950376103, 0.03474462650982397, 0.02283675253524312, 0.07636394591203757, 0.06370871820087944, 0.020317913498729467, 0.05773623939603567, 0.036067993712744544, 0.08028151533965554, 0.07171406756554331, 0.051983548261757405, 0.05992674721138818, 1.1126781169857298, 12.219812495367867, 40.60501895632063, 43.43596519742693, 31.011554309300013, 15.702049868447439, 10.43684915133885, 24.061172246932983, 38.62607472283499, 26.480088574545725, 2.0055111050605774, 0.05588902619534305, 18.667054653167725, 10.313060913767133, 6.545760231358664, 14.97335580417088, 4.855886680739267, 19.88655035836356, 20.007897172655376, 28.431035041809082, 47.239534173692974, 47.563393184116904, 47.12494100843157, 45.25569493430001, 44.55411447797503, 46.232594285692485, 45.123574938092915, 43.476230008261545, 46.672998905181885, 45.90476090567452, 43.82481418337141, 41.719009740012034, 38.30397708075387, 34.13726397923061, 32.039588928222656, 32.695092405591694, 30.056416715894425, 31.90306724820818, 31.137615476335796, 31.73446226119995, 33.26938533782959, 32.74937520708357, 32.05026136125837, 31.04552057811192, 32.37484645843506, 37.12325232369559, 37.41460418701172, 35.50899818965367, 34.71964461462838, 33.60203729357038, 31.4580386025565, 33.5974896975926, 31.758638518197195, 32.48856067657471, 31.89871072769165, 32.95588261740548, 32.31646074567522, 32.788510935647146, 33.71121086393084, 35.32308176585606, 36.86781569889614, 38.2219431740897, 37.89202186039516, 41.52508551733834, 40.67253460202898, 43.35588720866612, 43.05834797450474, 44.448526178087505, 41.89069972719465, 43.350627422332764, 41.40550007138933, 42.82131017957415, 40.704951422555105, 42.893647875104634, 30.069375106266566, 37.36151647567749, 42.94886520930699, 41.96653931481497, 42.28449583053589, 39.8328343800136, 39.741340500967844, 42.28862306049892, 42.266826561519075, 42.432766914367676, 45.43635851996285, 41.5029867717198, 35.823671681540354, 32.967704977308, 33.430507114955354, 33.263284819466726, 33.43346357345581, 32.84439182281494, 31.743835381099156, 32.866389819553916, 34.54828814097813, 34.48384359904698, 33.86479384558541, 35.5453268459865, 33.87737355913435, 34.7429176058088, 34.68617861611502, 36.263082708631245, 39.13122613089425, 40.56302751813616, 41.20430455889021, 39.06935242244175, 39.867335660117014, 36.048428535461426, 35.487635953085764, 34.51890073503767, 34.46034131731306, 35.468299116407124, 35.690954140254426, 35.65202338354928, 39.739478383745464, 43.45006309236799, 42.329058102199006, 45.07704632622855, 45.95016390936715, 47.687321254185264, 37.6281292779105, 44.764318329947336, 45.92684228079659, 52.01814733232771, 45.36860316140311, 44.574743679591585, 45.21299825395857, 51.75756904057094, 46.820189544132774, 53.69910069874355, 41.62980876650129, 38.159937449863975, 26.728444984980992, 7.73269624369485, 2.0189693314688544, 2.664811121565955, 0.22604297633681977, 0.09603594496314015, 3.53178910272462, 36.69200542994908, 38.36202580588204, 28.601606369018555, 24.7425925050463, 25.957476343427384, 42.473994050707134, 48.7269663129534, 33.066765444619314, 3.211046793631145, 0.04278074743758355, 0.048300287154104025, 0.06030133246843304, 0.05581744753622583, 0.0376376657347594, 0.045959276878940206, 0.05016676057130098, 0.010965417671416487, 0.011847287582765733, 0.046887994544314485, 0.028482891619205475, 0.04696096759289503, 0.08949531521648169, 0.05629919382876583, 0.02410627798443394, 0.07451575222824301, 0.008327679791753846, 0.05417623756719487, 0.011591093115774649, 0.05350527839202966, 0.0389018307573029, 0.06493340605603797, 0.04595707503280469, 0.05468038230070046, 0.0854172044034515, 0.04358155107391732, 0.056227123231760094, 0.024664527403989008, 1.1037488132715225, 17.14465744154794, 47.011265005384175, 49.033722332545686, 38.06326021466936, 20.78217315673828, 10.332249232700892, 22.55382830756051, 40.502995082310264, 30.426314490182058, 2.3469688168593814, 0.035603845225913186, 21.111978088106426, 10.112157225608826, 7.273577954087939, 7.369539090565272, 4.7804843953677585, 19.35567671912057, 21.987857580184937, 31.484476498195104, 49.737317766462056, 49.51370736530849, 48.21242094039917, 45.956472873687744, 46.44173853737967, 47.42327928543091, 45.21938712256295, 43.641086442129954, 46.083058629717144, 46.96260329655239, 44.531963620867046, 42.71977962766375, 39.48015424183437, 34.70700584139143, 33.42742906297956, 34.6170197214399, 32.71852173124041, 33.32366119112287, 32.932682582310264, 33.643723011016846, 34.56246246610369, 34.572902134486604, 34.77133921214512, 32.903062411717, 32.683558395930696, 36.98237759726388, 38.76401036126273, 38.04914147513253, 36.539759976523264, 34.75535488128662, 33.711551325661794, 34.17889758518764, 33.81604528427124, 33.98219060897827, 34.25715167181832, 35.0090058190482, 33.27362721306937, 33.846867493220735, 34.32117237363543, 37.275324072156636, 40.450286047799246, 42.13417502811977, 40.44806957244873, 42.939481667109895, 43.30003758839199, 45.52848468508039, 45.28923041479928, 45.17340047018868, 44.10875231879098, 44.33118500028338, 43.195057255881174, 43.03379304068429, 41.11333874293736, 41.6460918698992, 32.442785944257466, 38.376575333731516, 42.33460276467459, 42.03771666118077, 45.02451794488089, 42.03724070957729, 40.09771360669817, 42.47865629196167, 44.1138071332659, 43.88782739639282, 46.43907390322004, 43.76346158981323, 37.39737960270473, 33.799147265298025, 35.05874102456229, 34.26007686342512, 33.53621353421892, 35.6539306640625, 33.9251389503479, 34.91763700757708, 36.814811365945, 35.454791818346294, 35.90388863427298, 36.82611608505249, 35.48458916800362, 35.97175516401018, 37.72660609654018, 39.063154629298616, 42.02395575387137, 43.24390309197562, 42.12863383974348, 42.48682737350464, 42.32839454923357, 38.87108904974801, 37.06195878982544, 35.795701708112446, 36.62547295434134, 37.88681765965053, 37.857791560036794, 37.59996475492205, 42.85917438779558, 45.451290198734824, 46.773028646196636, 47.17520080293928, 48.7351200239999, 49.45837191173008, 36.99852173668997, 46.50062452043806, 49.321839809417725, 53.69090877260481, 48.91344901493618, 44.92184094020298, 47.81210742677961, 52.712974139622276, 49.718536785670686, 55.51028415134975, 45.70926291601998, 40.72914505004883, 24.319862365722656, 5.178579696587153, 2.928227969578334, 2.4245810636452267, 0.3279138814125742, 0.10002496412822179, 3.7753870827811102, 41.346461227961946, 43.234776633126394, 32.08308465140206, 27.76805703980582, 31.400389398847306, 47.77171754837036, 54.555962971278596, 39.59053679874965, 4.952762808118548, 0.031265814788639545, 0.012289296320107366, 0.05245835653373173, 0.06970128842762538, 0.02325061648817999, 0.03982469266546624, 0.03155150856556637, 0.03836615450148072, 0.044178780633956194, 0.06015801230179412, 0.01630322026487972, 0.03807750231187258, 0.06324504808123622, 0.04367404896765947, 0.11886845156550407, 0.16599329215075287, 0.12996791382985456, 0.1276229646589075, 0.11712362590645041, 0.18370123766362667, 0.12538983805903367, 0.12366834043392114, 0.18236753637237207, 0.15777928648250444, 0.20173797410513672, 0.2090274758104767, 0.20475772635212966, 0.18355992596064294, 2.0291590818337033, 22.02213478088379, 52.946794918605256, 53.902293818337576, 42.3781019619533, 24.858931405203684, 16.63374250275748, 32.87525224685669, 47.64745249067034, 34.57003600256783, 2.7237372738974432, 0.09747175220400095, 22.20226856640407, 16.578770092555455, 14.50852826663426, 23.943428073610576, 6.983486320291247, 20.728315932410105, 22.330204010009766, 33.05841370991298, 51.482246671404155, 51.520138672419954, 51.79514142445156, 49.17087629863194, 47.198699610573904, 48.16895648411342, 46.36815711430141, 44.484337193625315, 48.23606218610491, 49.577912194388254, 46.356383391789024, 45.53984151567732, 41.425722803388325, 37.89486019951956, 35.63217238017491, 36.50474452972412, 33.11087608337402, 34.38470670155117, 35.00335693359375, 35.335161209106445, 36.810753617967876, 36.16097545623779, 35.71668331963675, 34.5839011328561, 33.81435687201363, 39.73540326527187, 42.274844782693044, 39.87822348730904, 39.40976899010794, 36.11643055507115, 34.08420058659145, 35.10720818383353, 34.785131386348176, 35.419213567461284, 36.21050221579415, 36.722445487976074, 35.582909652165, 37.0718287059239, 37.05457632882254, 38.93418564115252, 40.88108825683594, 42.951126847948345, 42.20343814577375, 45.19275120326451, 45.825634820120676, 48.04716151101248, 46.66142668042864, 47.33457163402012, 44.48907239096505, 47.17751455307007, 44.438889026641846, 44.27919510432652, 43.36376646586827, 43.652474539620535, 35.69663776670183, 40.37037828990391, 43.73352875028338, 42.89776120867048, 45.25402389253889, 42.510569368089946, 40.52338457107544, 44.289207458496094, 45.95011527197701, 45.5508439881461, 49.291893073490684, 46.63661813735962, 39.725776536124094, 36.06955453327724, 38.01902103424072, 38.06831155504499, 36.18478345870972, 36.60486459732056, 34.78113269805908, 36.96443387440273, 38.77457162312099, 37.988959653036936, 38.06311430249895, 39.19286707469395, 36.84008543831961, 39.613465854099815, 38.82747173309326, 39.22434936250959, 44.742389815194265, 44.69470432826451, 44.341068812779014, 44.51266152518136, 45.29589721134731, 40.582739557538716, 39.35706342969622, 37.590914726257324, 38.75724976403372, 40.01966449192592, 40.03719479697091, 39.4858899797712, 44.20635713849749, 48.03049973079136, 46.61924764088222, 50.33411243983677, 50.500157015664236, 51.34014906202044, 40.64413731438773, 47.313171182359966, 50.77883883884975, 55.334710121154785, 49.858793122427805, 47.16199575151716, 50.79049096788679, 55.50283220836094, 50.35100698471069, 57.92518615722656, 49.302888597760884, 45.228867939540315, 25.06011302130563, 11.388958198683602, 8.077946152005877, 5.187008730002812, 0.5562775560787746, 0.23253927060535975, 4.974690454346793, 46.81681619371687, 50.78715235846383, 41.02520431791033, 33.17181178501674, 36.955203192574636, 54.89638301304409, 60.52561201368059, 47.816842624119346, 7.153514385223389, 0.1156723073550633, 0.18120098539761134, 0.1711906532623938, 0.23273745711360658, 0.1696272271552256, 0.14958816101508482, 0.14516540191003255, 0.13386583966868265, 0.11697890795767307, 0.10089210474065372, 0.089846776000091, 0.08536231770579304, 0.15098438252295765, 0.11692420446446963], [0.005590313887556216, 0.04441577255991953, 0.03950082450839026, 0.024588144716939757, 0.06458893418312073, 0.032999519258737564, 0.04249578647847686, 0.12986489864332335, 0.03821357911718743, 0.024700920629714216, 0.03085679727207337, 0.04141041882602232, 0.10400507412850857, 0.002944674255559221, 0.7374063453504017, 16.453825848443167, 44.158661229269846, 41.4474915095738, 35.847048895699636, 18.91391372680664, 25.26274159976414, 30.025938442775182, 39.215559891292024, 26.90765118598938, 1.8789770262581962, 0.05870979465544224, 14.76857328414917, 13.764019233839852, 2.5976439714431763, 3.0487366574151173, 3.4788108255181993, 17.515236139297485, 19.433208193097794, 25.481943368911743, 41.76036541802542, 52.24901165281023, 46.91760676247733, 49.50790214538574, 45.664443561008994, 45.848452704293386, 43.47988476072039, 44.71360690253121, 43.72710861478533, 44.077075481414795, 43.040213176182334, 42.225752285548616, 39.088581562042236, 36.30673129217965, 33.800682817186626, 33.72708749771118, 34.4040470123291, 36.60786621911185, 33.37826360974993, 33.53289924349104, 33.510334968566895, 32.42908409663609, 30.661337307521276, 33.19223601477486, 38.00471816744123, 42.296936580113, 41.75337553024292, 38.7265248298645, 35.715522970472065, 34.180665901729036, 31.879061222076416, 32.37897368839809, 31.914010660988943, 32.97132846287319, 31.216366359165736, 33.80156176430838, 33.55855546678816, 33.47538552965437, 33.01362909589495, 32.846556186676025, 31.853891372680664, 35.255041531154085, 35.70333235604422, 40.21555852890015, 42.024251052311485, 43.640245710100444, 41.926878997257774, 42.161002022879465, 42.424627099718364, 44.334690366472515, 42.11704077039446, 42.05313471385411, 39.426364762442454, 42.59184939520699, 28.70419478416443, 36.161020619528635, 38.982263701302664, 37.51081589290074, 42.19466951915196, 44.57048443385533, 46.385937554495676, 44.65370648247855, 46.447967597416465, 44.86228445598057, 44.45209755216326, 40.08748933247158, 34.16693278721401, 32.369722161974224, 32.53304304395403, 32.56782920019967, 33.25520059040615, 31.70983784539359, 33.00408574513027, 33.39212874003819, 33.85981893539429, 32.601329939705984, 34.410755498068674, 34.14590406417847, 33.46194771357945, 32.88048076629639, 35.38270425796509, 32.700564111982075, 34.915827001844136, 35.905222688402446, 37.20233672005789, 37.818749632154194, 37.132086958204, 37.13187851224627, 36.054935523441856, 33.77953250067574, 36.09121206828526, 35.51670721599034, 35.53171532494681, 34.96867152622768, 38.08356285095215, 39.461533069610596, 40.51148925508772, 42.18757193429129, 47.27791254861014, 46.377943652016775, 57.06784793308803, 44.00439732415335, 46.386260645730154, 52.46318640027727, 49.425767489842, 44.56475911821638, 44.68838841574532, 46.36813626970564, 51.97857734135219, 49.20320626667568, 55.38795069285801, 36.57859345844814, 21.323479516165598, 9.65735593863896, 3.4754748216697147, 0.5747578644326755, 0.272853533072131, 0.04747246425332768, 1.2443046825272697, 31.015476567404612, 40.356756346566335, 26.50962015560695, 21.646709714617046, 36.53179039273943, 44.76641321182251, 50.49572059086391, 35.44521025248936, 4.612464359828404, 0.13468324366424764, 0.09510428924113512, 0.014087789010123482, 0.013776418619922228, 0.049339046236127615, 0.08594207159642663, 0.01583025760815612, 0.030895952135324478, 0.07419090358806507, 0.035729632047670226, 0.0649450361462576, 0.0697362736931869, 0.024936099170840213, 0.03175541512402041, 0.035222844420267005, 0.0483126500621438, 0.01702650636434555, 0.02990445980269994, 0.08042292203754187, 0.017349811337356056, 0.005081854095416409, 0.0458137412954654, 0.00450517948151433, 0.031089812982827425, 0.03631136726055827, 0.08001941761800221, 0.07579840054469449, 0.041114943966801674, 1.151960300547736, 19.560641629355295, 48.05441543034145, 46.46286106109619, 39.98577812739781, 21.75418792452131, 22.622285434177943, 32.81443466459002, 43.2622081211635, 30.334803240639822, 1.9509401704583849, 0.05879540541874511, 12.03971345084054, 11.637510895729065, 4.822370742048536, 4.199374411787305, 5.413637689181736, 19.914145129067556, 19.5205557346344, 27.270743199757167, 45.81144659859793, 53.21746894291469, 47.78768450873238, 51.09364434650966, 46.30394186292376, 47.09474761145455, 45.4244840485709, 44.127738271440776, 44.540812151772634, 47.193804604666575, 45.32253313064575, 44.27653047016689, 40.74894741603306, 37.547516277858186, 36.547187600817, 37.18225990022932, 36.7178874697004, 36.97297321047102, 34.97828435897827, 34.47586011886597, 35.931024823869976, 33.392726285117014, 33.130247661045615, 35.2953063419887, 39.063762596675325, 44.12433018003191, 43.248624392918174, 41.813164779118125, 36.36456462315151, 36.04518372671944, 34.73705332619803, 33.58352729252407, 32.284571988242014, 35.89513390404837, 32.155877453940256, 34.91227994646345, 34.24946001597813, 34.25534861428397, 34.330972807747976, 35.45957565307617, 34.53331824711391, 37.06109373910086, 37.01286629268101, 40.69347994668143, 42.85727405548096, 45.21702820914132, 44.328020095825195, 43.777826990400044, 42.68904079709734, 45.30971370424543, 44.78689650126866, 42.716784954071045, 41.24762657710484, 43.035919189453125, 31.601425102778844, 36.48448705673218, 39.74291426794869, 37.62120887211391, 42.128022398267476, 43.31277016230992, 46.86299739565168, 46.11072635650635, 47.018571036202566, 46.74061182567051, 47.31421341214861, 42.41003935677664, 36.095033577510286, 33.767084802900044, 34.193787574768066, 33.46279191970825, 34.42112915856497, 33.96165868214199, 33.81283521652222, 33.66236155373709, 35.270299775259836, 34.36777394158499, 34.78675031661987, 36.11416891642979, 34.559252398354666, 35.17811107635498, 36.67151519230434, 35.73445333753313, 36.254539898463655, 38.16818496159145, 39.90537357330322, 40.03929662704468, 39.781000818525044, 39.407670634133474, 37.2832658631461, 35.495292867933, 37.746460574013845, 37.17101076671055, 38.00896004268101, 36.94990519114903, 39.99215309960501, 41.95732947758266, 42.150541509900776, 44.516708850860596, 48.13293354851859, 48.362001759665354, 55.354192870003835, 46.05774981634957, 48.650358949388774, 54.66839872087751, 50.579689570835654, 46.47557973861694, 45.579432351248606, 49.309482438223704, 52.113740648542134, 51.34153175354004, 55.856988838740754, 38.972755091530935, 24.0237284047263, 10.073176094463893, 2.583604919058936, 2.6959310173988342, 0.2020944764039346, 0.01344702040244426, 1.565294195498739, 34.76754896981375, 46.60260670525687, 33.856608867645264, 25.473680223737443, 38.877363273075645, 49.27638469423567, 55.388371058872764, 40.41265113013131, 5.41157146862575, 0.08158717277858939, 0.023084109083616307, 0.02888197199042354, 0.01708856687348868, 0.062079582762505324, 0.05964751648051398, 0.010855839354917407, 0.00349208471431796, 0.11339388175734452, 0.056355088150927, 0.09347185612257038, 0.05345616602737989, 0.03916296495922974, 0.037768327830625434, 0.1437590295182807, 0.1323183048516512, 0.10413659457117319, 0.1376126693295581, 0.14280666490750654, 0.14331316415752682, 0.15698598405080183, 0.1836177778563329, 0.1395801766110318, 0.15352823744927133, 0.11727506135191236, 0.2711241644408022, 0.20458263717591763, 0.11874776732708726, 1.5313993628535951, 24.373024770191737, 57.44382190704346, 52.07098143441336, 45.990199429648264, 28.402420622961863, 34.34939595631191, 39.5500739642552, 50.88534777505057, 35.33129801068987, 2.459599550281252, 0.13420042528637818, 16.409861121858867, 22.203164884022303, 8.693819710186549, 8.768259235790797, 6.210472737039838, 19.3143036706107, 20.755928073610576, 29.377275466918945, 47.25683866228376, 56.880705152239116, 49.37784229006086, 52.47387967790876, 47.48736252103533, 47.46138668060303, 45.46596132005964, 46.18987328665597, 47.24791022709438, 46.86747203554426, 47.72697809764317, 46.256193842206685, 42.690253257751465, 40.479200976235525, 38.281843594142366, 37.77977023805891, 39.06997081211635, 39.662311690194265, 37.40535266058785, 36.445080348423545, 37.261653491428916, 35.00271075112479, 33.13363838195801, 36.09716667447771, 42.66933223179409, 45.71534953798567, 45.31332676751273, 43.909731592450825, 39.75341647011893, 38.051788738795686, 36.816284384046284, 35.07243939808437, 35.31554991858346, 36.581049646650044, 33.457236834934776, 37.57109151567732, 36.82756131035941, 35.55571092878069, 36.682715688432964, 36.488155705588206, 36.34160082680838, 39.16775975908552, 39.17275898797171, 42.27827371869768, 46.132203238351, 47.21013287135533, 45.42047841208321, 45.08780908584595, 44.50284024647304, 46.52888979230608, 45.28709036963326, 44.41751984187535, 42.71438782555716, 43.83192913872855, 34.575955867767334, 38.097966466631206, 39.72356353487287, 40.100409507751465, 43.81012569155012, 46.506777150290354, 49.7286707333156, 48.34991536821638, 49.31717756816319, 48.52665669577462, 49.551106044224326, 45.31437594549996, 37.37466246741158, 35.93003470557076, 35.67609889166695, 34.47741651535034, 37.690430300576345, 34.84554944719587, 35.530940600803916, 35.86976603099278, 37.993785176958355, 35.13355227879116, 36.533569131578716, 38.14835132871355, 36.202831404549734, 36.241446018218994, 38.70040307726179, 36.934570516858784, 38.275430406842915, 38.97551352637154, 41.31443003245762, 40.78783648354666, 43.34784466879708, 40.420374052865164, 39.08770261492048, 36.30040495736258, 40.22123520714896, 39.65973738261631, 40.05204309735979, 39.58743442807879, 42.440792083740234, 43.97725766045706, 44.67712538582938, 46.41657911028181, 50.604157652173726, 51.88079881668091, 57.58492244992937, 48.82161120006016, 50.039394174303325, 56.26988901410784, 54.22442620141165, 48.80884735924857, 48.30369595118931, 52.245867592947825, 54.99018716812134, 53.97147355760847, 57.596175057547434, 43.129876204899375, 26.193939174924576, 11.313832538468496, 7.456567883491516, 4.161469382899148, 0.6108284603272165, 0.15269551213298524, 1.703940938626017, 39.24078532627651, 51.82510553087507, 38.144005230494905, 33.4461544581822, 47.62396757943289, 56.53041172027588, 62.04195213317871, 47.38533864702497, 8.283267157418386, 0.24097172383751186, 0.16296850517392159, 0.1736261054341282, 0.14368838045213903, 0.19810802888657364, 0.15239298050957067, 0.07157069990145308, 0.08061553777328559, 0.22982445199574741, 0.07263114835534777, 0.19124993974609034, 0.21872444690338202, 0.14385714568197727, 0.15449006083820546], [0.042265223671815226, 0.02385085535102657, 0.019608578079247048, 0.04044930789885776, 0.04329601336004479, 0.05090391423021044, 0.030720164068043232, 0.018748380576393435, 0.08024642829384122, 0.07566443737596273, 0.036542157376451154, 0.010217658510165555, 0.03869225164609296, 0.036943286923425536, 0.30665516214711325, 14.388751745223999, 45.842887197222026, 49.03126614434378, 39.75208241598946, 21.07051818711417, 18.8701366015843, 25.75065800121852, 39.09914629799979, 23.87555980682373, 1.2521082695041383, 0.22643031126686505, 5.302014010293143, 10.030523708888463, 4.140088473047529, 3.842400286878858, 1.9697943244661604, 15.821345227105276, 40.774308340890066, 45.38360432216099, 46.36490535736084, 46.7885821887425, 46.938315868377686, 45.55680554253714, 43.851787090301514, 43.54362753459385, 42.937612601688926, 44.2854380607605, 43.61178241457258, 44.94980049133301, 44.77338225500924, 42.43896123341152, 38.875556741442, 36.87818935939244, 32.82596867425101, 33.3393224307469, 32.29675218037197, 32.449153968266074, 31.938919952937535, 31.292636735098704, 31.22734103884016, 31.191724572862896, 32.68584435326712, 35.17205572128296, 37.76523460660662, 43.353931290762766, 43.34584706170218, 40.21675361905779, 35.92986100060599, 32.47072812489101, 32.98126091275896, 32.509335790361675, 31.216918740953716, 32.870840140751426, 30.492648942129954, 32.47945506232125, 31.66413606916155, 33.16295978001186, 30.742478370666504, 31.49430125100272, 33.075040749141145, 30.65423972266061, 34.504552704947336, 39.2694535936628, 40.21598584311349, 42.929715973990305, 42.32764761788504, 43.70904677254813, 43.0961183820452, 43.42360782623291, 40.632679734911235, 44.596759046827046, 41.755505153111045, 42.465746538979666, 30.038862092154368, 35.22901010513306, 42.65272603716169, 44.49244226728167, 46.428064482552664, 44.8940029825483, 43.59697232927595, 43.5365195274353, 43.04444810322353, 40.221943923405235, 39.67091008595058, 33.612167767116, 32.9574807030814, 31.470472403935023, 33.00946365083967, 33.08897883551461, 32.82680593218122, 32.95828322001866, 31.981182370867046, 32.486517906188965, 32.43352746963501, 33.99128580093384, 33.53395536967686, 31.64837408065796, 33.565163203648154, 33.288374764578684, 34.18770095280239, 31.69869293485369, 32.64592000416347, 33.28549126216343, 35.102215903145925, 35.54083136149815, 36.14739520209176, 34.26935270854405, 34.99985156740461, 35.230219091687886, 34.51546137673514, 37.17739268711635, 36.80713708060128, 38.85462876728603, 39.88919121878487, 38.386149951389854, 41.044176374162944, 42.96717718669346, 46.715438502175466, 48.860100746154785, 48.08810377120972, 48.153034687042236, 47.81453234808785, 50.629796504974365, 49.26821708679199, 46.18917499269758, 40.910541670663015, 45.369742665972026, 49.30113417761666, 50.85092987333025, 52.11518587384905, 49.16203819002424, 18.146116937909806, 7.0809573871748785, 0.9425572284630367, 0.7648482556853975, 0.24969293443220003, 0.07371429380561624, 1.212860718369484, 27.318895953042166, 42.30025781903948, 36.51999582563128, 23.22095612117222, 30.739115442548478, 52.687859875815256, 45.17896250316075, 39.93081092834473, 5.76093818460192, 0.04220970254391432, 0.03917892071019326, 0.015576777281239629, 0.005456032655534467, 0.038683803885110786, 0.016070898356182233, 0.05286958946713379, 0.03106632549315691, 0.019118194035919647, 0.02175107614935509, 0.00707132979628763, 0.033702159233923466, 0.07346477612320866, 0.04823085605832083, 0.020906425580116253, 0.03847572094361697, 0.02769403189553746, 0.004524761578068137, 0.0182972735326205, 0.03119268567700471, 0.04510099454117673, 0.04488462668710521, 0.05140487663447857, 0.04733558338401573, 0.028728304164750234, 0.028175829078203866, 0.01483278229300465, 0.08384698616074664, 0.7217568308115005, 17.55408525466919, 52.077672549656455, 51.81433234895979, 44.69129623685564, 24.037398985454015, 22.892441817692347, 26.33509530339922, 42.644659178597585, 28.228866781507218, 1.4776904391390937, 0.2783666843814509, 5.687166120324816, 8.969945464815412, 2.6500412055424283, 5.849264553615025, 3.954043073313577, 20.944064446857997, 43.06083195550101, 50.08316087722778, 46.05601624080113, 49.18838228498186, 47.220190388815745, 47.84718540736607, 45.41262347357613, 44.162517479487825, 42.75964839117867, 44.445997033800396, 44.46363156182425, 46.06834929330008, 47.126712799072266, 45.418414797101704, 40.279468059539795, 38.45933532714844, 35.834073134831016, 34.70674180984497, 33.80091210774013, 34.08882808685303, 33.455333028520855, 33.15254095622471, 33.07073286601475, 32.866417612348286, 34.889663560049875, 37.28162956237793, 39.04168469565255, 45.39799404144287, 44.75879798616682, 43.12886871610369, 36.862194606236045, 33.741265296936035, 33.81400946208409, 33.174684865134104, 32.46876873288836, 34.10028566632952, 33.486891746520996, 33.23967831475394, 33.923891748700825, 34.06899445397513, 31.905561651502335, 33.7699613571167, 34.497218881334575, 31.880207674843923, 35.977261611393516, 41.3563346181597, 43.12307391847883, 44.66356250217983, 44.446598052978516, 44.9693284034729, 43.53102350234985, 44.18775681086949, 42.617474351610454, 44.059579917362754, 42.513713427952354, 43.43402665002005, 32.06038836070469, 36.708896500723704, 41.50564793178013, 44.672112260546, 47.104568890162874, 47.07501820155552, 46.57802745274135, 46.43393223626273, 44.96828269958496, 44.135669640132356, 42.173494883946006, 35.93320655822754, 34.61040503638131, 33.792226859501426, 34.63144418171474, 34.49278940473284, 34.3141234261649, 33.609412806374685, 34.274772303445, 34.34421954836164, 35.21986280168806, 34.776932512010845, 35.60644320079258, 33.5584442956107, 35.35259771347046, 33.53459112984793, 35.84449543271746, 34.33208104542324, 34.386794635227744, 35.44930968965803, 36.85921730313982, 37.55053527014596, 37.77789075034005, 36.53838423320225, 35.40118299211775, 37.35257761819022, 36.455259459359304, 38.33180809020996, 37.627608163016184, 41.09679160799299, 42.046478339603965, 40.512979643685476, 42.20572757720947, 44.26059477669852, 49.18729836600167, 50.04843725476946, 50.54673426491873, 48.86672585351126, 48.78744690758841, 52.47941044398716, 51.42106778281075, 47.40221929550171, 43.04129362106323, 46.974401337759836, 51.139874185834614, 53.81391968045916, 54.27285861968994, 49.12108203342983, 20.28826740809849, 8.577927231788635, 2.9165230776582445, 2.459854462317058, 0.7173242058072771, 0.09138388851923601, 0.9720850097281593, 31.71775531768799, 47.120647021702354, 37.201634952000205, 27.164809226989746, 36.501944405691965, 58.66852528708321, 53.133357524871826, 46.28989607947213, 7.867128252983093, 0.15145258525652544, 0.06414386270833866, 0.003747888599588935, 0.0377266216757042, 0.0564835042958813, 0.02006991912743875, 0.016155574437496916, 0.03052522095718554, 0.02248076083404677, 0.03119791718199849, 0.06457321931208883, 0.04420419516307967, 0.07032126587416444, 0.042087423748203685, 0.09649732163442032, 0.11672102393848555, 0.10241487981485468, 0.1406042623732771, 0.10162938732121672, 0.11551509079124246, 0.15984356642833777, 0.12385685103280203, 0.14267451342727455, 0.16456805648548262, 0.1419350052518504, 0.1064232847254191, 0.16092421486973763, 0.18704241194895335, 0.9967086655752999, 21.912834405899048, 57.70446620668684, 59.96209226335798, 50.59695584433419, 29.999632562909806, 27.060905865260533, 33.71428196770804, 51.370623861040386, 31.520037378583634, 1.8446559650557381, 0.3179281529571329, 8.452483585902623, 14.857058593205043, 12.73371342250279, 10.107732091631208, 4.18351514850344, 19.413553476333618, 45.89862217221941, 50.580565043858115, 47.44892161233084, 48.56063338688442, 48.72983244487217, 47.61123847961426, 46.28281586510794, 44.70395932878767, 43.714000838143484, 46.347844055720735, 45.70876611982073, 47.44441570554461, 48.68751791545323, 45.823779651096885, 42.98430102212088, 40.76673480442592, 37.03792149680001, 35.58978489467076, 36.607994760785786, 34.953753743852886, 35.37929964065552, 33.91659961427961, 34.81382049833025, 33.345888478415354, 35.23684419904436, 39.27351828983852, 40.0531131199428, 47.649363245282856, 46.95498807089669, 44.591193539755686, 39.01230076381138, 36.11860186713082, 34.836290972573416, 34.85635042190552, 34.37992286682129, 35.4784608568464, 33.85771710532052, 34.29242072786604, 35.336557797023225, 35.889863695417134, 32.99670328412737, 35.328240803309846, 36.253056458064485, 33.05516195297241, 38.02275916508266, 41.92216464451381, 45.53053787776402, 46.60511153084891, 45.6891895702907, 47.33185141427176, 47.440674100603374, 46.30956642968314, 44.76678841454642, 45.50003528594971, 44.33182770865304, 43.105609621320454, 35.532055786677766, 37.79677595411028, 42.72474758965628, 47.56748219898769, 48.853600706372944, 50.00425713402884, 48.454596928187776, 48.68719482421875, 46.65086194447109, 46.38883147920881, 44.44977685383388, 35.88609777178083, 37.14521210534232, 34.683489663260325, 36.395275660923545, 36.75223241533552, 36.585850851876394, 35.397896494184224, 35.794096674237935, 36.57996572766985, 36.78351320539202, 38.878659112112864, 37.64673655373709, 35.69201374053955, 37.93505552836827, 35.92753335407802, 37.48880052566528, 34.67419992174421, 36.23618275778634, 37.326917920793804, 38.633519717625205, 38.233341693878174, 39.295241832733154, 36.921507903507774, 39.11570732934134, 38.43662166595459, 38.360563210078645, 40.195120402744834, 40.01852151325771, 43.146555355616975, 44.11447416033064, 43.22597326551165, 45.01239333833967, 48.574613162449424, 50.9904705456325, 53.63678577968052, 54.02676384789603, 50.15180560520717, 50.01007277624947, 53.52216134752546, 52.989971024649485, 50.127521651131765, 46.21346589497158, 49.42995377949306, 55.230667795453755, 56.960359300885884, 55.308289596012656, 50.819753306252615, 23.7791257585798, 11.200953841209412, 5.810104940618787, 4.614421146256583, 0.8937023814235414, 0.18670615713511193, 1.657434148447854, 34.317868505205425, 54.04431847163609, 48.03013842446463, 33.317480768476216, 41.39063440050398, 64.40927287510463, 59.530720302036826, 54.48485163279942, 10.862949166979108, 0.24217004382184573, 0.19260892325213977, 0.09880295648638691, 0.0813349409561072, 0.13495464410100663, 0.07608194675828729, 0.1866661642811128, 0.11353460313486201, 0.11355813472930874, 0.07841318952185766, 0.13585195238036768, 0.19842285556452616, 0.15773871008838924, 0.15602211148611136], [0.007863082623641406, 0.03972874781382935, 0.03963436698541045, 0.020259242272004485, 0.03913502627983689, 0.03930196964315005, 0.060259745057140074, 0.022462124869759594, 0.03288413777149149, 0.025531238843021647, 0.018047879682853818, 0.07860259578696319, 0.03848513900967581, 0.0535223740818245, 0.4046001721705709, 16.4002673966544, 45.82262625013079, 47.630401611328125, 35.401374067579, 23.638212817055837, 28.718184982027324, 41.106800488063264, 43.04904086249215, 24.983510868889944, 1.6023279854229517, 0.1350304636039904, 2.233835424695696, 9.076642002378192, 2.4114778467587064, 1.6716077136141914, 2.290794151169913, 11.224787899426051, 38.36924498421805, 50.753286838531494, 45.527918406895225, 47.86619220461164, 45.33154147011893, 48.0948782648359, 43.31329822540283, 46.13293974740164, 44.0850624356951, 45.41543401990618, 44.45168760844639, 44.8874751499721, 42.761573042188374, 42.796585014888215, 38.13652549471174, 33.69336788994925, 34.33420372009277, 31.655940668923513, 31.929129941122874, 31.468189920697892, 30.644192627498082, 32.31151015417916, 31.914702006748744, 32.481518677302766, 30.78028699329921, 34.35144567489624, 37.46571513584682, 41.50209392820086, 42.18468495777675, 42.83655800138201, 37.40398733956473, 32.598713942936485, 31.837823663439067, 32.32937397275652, 31.69900212969099, 32.26229953765869, 32.38531739371163, 31.700641904558452, 30.68134117126465, 31.997079849243164, 30.324096066611155, 32.40274347577776, 30.456368923187256, 32.82861246381487, 33.712923594883506, 40.63074813570295, 42.68089056015015, 41.83735145841326, 43.98659256526402, 45.37960910797119, 42.35593373434884, 42.89227213178362, 42.36508798599243, 43.91631848471505, 44.412089824676514, 47.903656891414094, 30.202787467411586, 35.06700938088553, 47.85420308794294, 42.38777732849121, 43.9486380304609, 41.713729109082905, 40.88480206898281, 37.43634510040283, 35.58434445517403, 33.381279127938406, 32.02635955810547, 31.436419282640728, 33.45901557377407, 32.044862610953196, 33.030217920030864, 33.15378468377249, 32.97741855893816, 33.70978995731899, 33.678477900368826, 33.89380604880196, 33.996368408203125, 33.425174372536794, 33.29718855449131, 33.74817875453404, 32.90381629126412, 32.25579602377755, 31.628533499581472, 32.99037347521101, 32.289595535823274, 31.716369152069092, 31.55733530861991, 32.85812841142927, 34.02033621924264, 34.300539697919575, 34.80216489519392, 34.818899631500244, 35.54965557370867, 36.01026208060128, 36.82681785311018, 43.911572865077424, 42.431898389543804, 41.56767102650234, 41.77593633106777, 41.79924406324114, 46.194941997528076, 48.82060718536377, 50.84625026157924, 51.74272768838065, 49.89018855776106, 51.00126804624285, 51.52570417949131, 50.7936350277492, 42.1734288760594, 42.20770781380789, 47.692511558532715, 50.922447681427, 52.581302302224294, 49.300084999629426, 25.897364003317698, 9.414455601147242, 1.5333823135920932, 2.0202464972223555, 0.10658346648727145, 0.06329896447381803, 0.5512127535683768, 24.90563198498317, 49.54910496303013, 41.78941931043352, 29.713533537728445, 32.03904349463326, 43.800773416246685, 50.78761441367013, 40.29826988492693, 6.0078541466168, 0.06850997092468397, 0.05773905531636306, 0.00930034532211721, 0.027344145313171402, 0.03250895540363022, 0.020338641047211628, 0.007281840196810663, 0.025917376158758998, 0.04078988837344306, 0.017142836104280183, 0.02093221160716244, 0.04903038404881954, 0.05200851835044367, 0.07216657578412976, 0.04687436616846493, 0.011006256997851389, 0.029085746234548942, 0.019003450371591107, 0.05386322257774217, 0.03392892224448068, 0.026128797492544566, 0.020526554535276124, 0.02519034454599023, 0.025324112635904124, 0.03928943710135562, 0.08852971238749367, 0.06296228218291487, 0.015877717740035484, 0.5225123507635934, 20.238374131066458, 51.156681878226145, 53.91414049693516, 40.46476261956351, 27.320909193583898, 22.09047552517482, 33.01754787990025, 46.43785102026803, 27.362475054604666, 1.8382000029087067, 0.240454761577504, 2.80671027302742, 7.146309537546975, 4.133684405258723, 7.427092756543841, 5.483889622347696, 11.727444035666329, 40.04974671772548, 48.68485675539289, 46.367920875549316, 48.34837286812918, 46.34482853753226, 47.64155347006661, 44.11256340571812, 48.12549202782767, 44.97498423712594, 45.688585077013286, 46.892429964882986, 46.112310545785085, 45.431022303445, 44.98936700820923, 41.547847815922324, 35.98840652193342, 35.292679922921316, 33.36692067555019, 33.657716682979036, 33.338540758405415, 31.547854491642543, 32.98494345801217, 32.81013372966221, 33.31355503627232, 33.10078035082136, 35.316185678754536, 39.354933806828086, 43.841385637010845, 44.316392285483225, 43.40131800515311, 39.06763621738979, 33.64976794379098, 33.70199407849993, 34.13866056714739, 34.173523153577534, 34.239079407283235, 33.70349836349487, 33.516466753823416, 31.557707037244523, 32.51250416891915, 33.0715388570513, 34.52445929391043, 32.57768521990095, 33.89530685969761, 37.4177690914699, 40.96150323322841, 44.137906960078645, 45.61827278137207, 45.58878115245274, 47.65911851610456, 44.72642632893154, 44.87942566190447, 43.51401778629848, 46.72500964573452, 44.896382740565706, 48.03292465209961, 32.556903157915386, 35.190395491463796, 48.46186126981463, 45.097171783447266, 45.50701127733503, 43.79782043184553, 42.893303939274375, 40.09765107291085, 37.77891213553292, 36.01720333099365, 33.59562758037022, 33.617034980228965, 35.65339912687029, 33.61772632598877, 35.09002528871809, 35.05705261230469, 34.27750294549124, 35.14648635046822, 34.14276000431606, 35.371715681893484, 33.925288336617605, 34.725498471941265, 34.84309673309326, 34.958186694553916, 34.49814993994576, 34.38828502382551, 32.737924575805664, 34.24116734095982, 33.85555968965803, 33.60196781158447, 33.85506289345877, 34.64588253838675, 37.26334537778582, 35.674129077366416, 37.008120673043386, 36.64017881665911, 37.022499970027376, 37.22731549399239, 37.90995863505772, 44.65394619532994, 44.96839039666312, 43.69259691238403, 43.47903708049229, 44.740607602255686, 48.11787332807268, 49.99494654791695, 52.325236865452354, 53.00949893678938, 52.50026546205793, 53.19649927956717, 51.869869300297324, 51.30052695955549, 44.442894663129536, 43.02772726331438, 49.24159506389073, 52.623415333884104, 54.988717624119346, 50.04750272205898, 28.852476290294103, 9.104931592941284, 3.3400338036673407, 2.8132993366037096, 0.7911278083920479, 0.058854268331612856, 0.45506786980799263, 29.060870136533463, 52.34593902315412, 42.03421476909092, 32.15146534783499, 36.14263916015625, 50.52765451158796, 55.1957357270377, 45.272679805755615, 7.496893491063799, 0.10602529679558106, 0.02765146060846746, 0.01453166880777904, 0.012469390540250709, 0.04273943483297314, 0.0528488025468375, 0.054616627150348256, 0.02562108027216579, 0.05618202440174563, 0.018384288863411972, 0.019837793993896673, 0.06386151071637869, 0.03359213138797453, 0.03070575537692223, 0.12206513860395976, 0.10335942091686384, 0.1869558851633753, 0.16847493898655685, 0.1076660216120737, 0.11259312901113715, 0.16232020567570413, 0.09229637562696423, 0.12682043415095123, 0.11331384176654474, 0.11312258988618851, 0.17938773626727716, 0.17634654231369495, 0.15352010859974793, 0.8962458020874432, 25.938954183033534, 57.80569798605782, 57.950501918792725, 46.80243689673287, 33.34972735813686, 37.52606718880789, 48.644341809409006, 54.216119629996165, 33.19412245069231, 2.093681139605386, 0.2702750728598663, 2.838692396879196, 15.4260413646698, 9.48301955631801, 7.428106325013297, 6.578102358749934, 13.824637923921857, 41.777294703892295, 48.90564618791853, 47.26839004244123, 49.9666291645595, 46.779341084616526, 49.40691702706473, 45.50667428970337, 49.361646039145334, 47.07883971078055, 47.954267569950645, 48.68407508305141, 47.756490571158274, 46.97444302695138, 46.83571181978498, 44.237019538879395, 37.2862674849374, 38.59577362877982, 35.211024693080354, 35.40533454077584, 34.14599439076015, 34.080868925367085, 35.449664047786165, 35.46475900922503, 34.77293382372175, 34.13403654098511, 36.3377445765904, 41.731940337589805, 45.7503719329834, 46.12180525915963, 45.64169863292149, 41.42175538199288, 36.12662703650338, 35.12193489074707, 36.976270130702424, 35.52712951387678, 36.43851777485439, 35.9950281551906, 35.36499677385603, 33.47997481482369, 34.1351968901498, 35.47179058619908, 36.583964415958945, 33.890516076769146, 34.82965544291905, 38.93539115360805, 43.7082199369158, 47.90224640710013, 45.336915901729036, 48.195515973227366, 50.147751331329346, 48.353153228759766, 46.2109124319894, 47.541572366442, 48.33439309256417, 49.756807463509695, 50.068892751421245, 34.69853598730904, 38.550822257995605, 49.63284117834908, 48.241023199898855, 47.792027132851736, 46.37020335878645, 44.236686025347026, 42.23118577684675, 38.11568437303816, 38.2300934110369, 36.59679079055786, 35.943500314440044, 37.253155844552175, 36.028105054582866, 37.87167058672224, 35.98218788419451, 36.89930146081107, 37.3680408341544, 37.50948878696987, 37.31456402369908, 36.767799854278564, 36.91896138872419, 36.96558380126953, 37.971825395311626, 36.110785143715994, 36.72350508826119, 35.12596484592983, 37.36211402075631, 35.02702597209385, 35.477550642830984, 35.31455980028425, 36.08567782810756, 37.340251513889854, 37.566801003047395, 38.3857295853751, 37.89568703515189, 38.2512333052499, 38.11587544849941, 40.62515483583723, 47.91731357574463, 47.273965971810476, 46.900455134255544, 46.177755628313335, 45.42753430775234, 50.52107456752232, 53.17771829877581, 53.597222736903596, 55.41190460750035, 55.754388264247346, 55.827729974474224, 54.66837787628174, 56.36532946995327, 45.22958707809448, 47.11936855316162, 52.07117598397391, 55.83614771706717, 58.1873208454677, 52.283742223467144, 29.228385993412562, 12.784668905394417, 6.036639664854322, 9.158856562205724, 1.7030763221638543, 0.09303724765777588, 0.975265764764377, 32.378813879830496, 62.272472517830984, 52.02054793494088, 41.14871897016253, 43.970201764787944, 57.50893347603934, 62.412186895098, 53.86862979616438, 10.575421418462481, 0.27131624413388117, 0.1730000754552228, 0.11795480416289397, 0.09732694604567119, 0.1258524496640478, 0.11356335266360215, 0.13878231442400388, 0.10889431248818125, 0.10234786769641296, 0.05773519445210695, 0.2310978722359453, 0.12615186002637657, 0.10043813767177717, 0.11539477296173573], [0.05396087055227586, 0.06206306043480124, 0.02324662670227034, 0.006296006846241653, 0.022487234058124677, 0.027692800354478613, 0.04412648933274405, 0.021827034752017686, 0.028227336671469466, 0.02222330598825855, 0.019894093740731478, 0.0054558134039065665, 0.02564643373313759, 0.03355478821322322, 0.7237353846430779, 16.83029661859785, 40.91843135016305, 46.481068815503804, 43.67327397210257, 24.6743003981454, 37.0636055128915, 56.342223235539024, 38.4164718900408, 29.85328265598842, 1.4314857870340347, 0.06560468753533703, 0.9485083605561937, 6.797587701252528, 1.122341324176107, 7.411282999174936, 4.075796357222965, 5.710171605859484, 32.19836221422468, 49.83306394304548, 47.4282819884164, 50.39109809058053, 46.89217635563442, 48.041710649217876, 46.231145586286274, 46.8128696169172, 45.8857923235212, 48.406696047101704, 44.58066007069179, 43.616225787571494, 41.38594784055437, 37.23535108566284, 32.457071440560476, 31.0570650100708, 29.883677550724574, 31.940431186131068, 30.386928626469203, 31.910265581948416, 34.50421919141497, 37.26856347492763, 37.469428947993684, 37.40720435551235, 35.21012837546212, 34.78299134118216, 38.08815908432007, 43.43638208934239, 43.52386685780117, 43.68873718806675, 38.194393566676546, 33.17563329424177, 32.017514501299175, 33.85071332114083, 31.65409939629691, 31.613118921007427, 30.90893289021083, 32.23394046510969, 31.434379986354283, 31.899297850472585, 31.630875042506627, 32.78583587918963, 31.324282305581228, 31.632896968296595, 32.120639664786204, 35.322435583387104, 35.25373179571969, 39.11791685649327, 37.03990520749773, 41.1786379132952, 38.395929540906636, 42.41580636160714, 39.28454508100237, 44.18181610107422, 42.40745462690081, 48.14242131369454, 31.31237656729562, 34.57403121675764, 46.79254961013794, 41.617385387420654, 43.68149021693638, 37.1426169531686, 35.76462936401367, 31.499720845903667, 31.37377085004534, 31.45213610785348, 32.75809172221592, 30.566754954201834, 31.595275947025844, 33.18149062565395, 33.52637488501412, 33.05395991461617, 33.12796170370919, 32.59333951132638, 32.652593748910085, 34.173745495932444, 34.49719456263951, 32.31855910164969, 33.41926840373448, 32.8653302192688, 34.19686562674386, 34.204008374895366, 36.63137892314366, 37.71175084795271, 37.963105406079976, 36.93377147402082, 35.34422860826765, 32.36191586085728, 32.12463140487671, 31.815676280430385, 35.34661878858294, 37.747600078582764, 36.58852243423462, 35.23810182298933, 38.412299496786936, 44.956418650490896, 42.551042624882285, 40.888658319200786, 39.442804200308665, 41.29124736785889, 44.87096275602068, 45.34342288970947, 45.1805362701416, 45.43961722510201, 46.864251545497346, 51.67045600073678, 49.19356911523001, 50.1752279826573, 41.739795276096885, 39.95735304696219, 47.99328170503889, 50.0003730910165, 51.8925655909947, 48.94967344829014, 32.185907568250386, 8.7109774180821, 1.3708816447428294, 1.7039023978369576, 0.9716622552701405, 0.03635684267750808, 0.3614491176392351, 24.61915602002825, 46.22198438644409, 36.35656724657331, 22.567158426557267, 26.916173151561193, 43.696946484701975, 48.27202606201172, 40.79501397269112, 7.6936638695853095, 0.046033810558063645, 0.11430049953716141, 0.07102496775665454, 0.040249594686818976, 0.11164398065635137, 0.039220033146973164, 0.028762186810906445, 0.06061242041843278, 0.0369252819967057, 0.023948106382574354, 0.03260962625167199, 0.06102553967918668, 0.014049776630210025, 0.020007488816710453, 0.06453279219567776, 0.03451845721740808, 0.04536512108253581, 0.025287249524678503, 0.026284997950174978, 0.031113422608801296, 0.022275222398872887, 0.08896931487002543, 0.055544143808739524, 0.04772745432066066, 0.0365230532230011, 0.014024312059128923, 0.038278219755738974, 0.057269027323595116, 1.1012632037912096, 21.504678113119944, 47.8551549911499, 52.77933985846383, 47.16297197341919, 30.843070915767125, 38.53297233581543, 61.159252984183176, 45.14171668461391, 34.31743771689278, 1.358653140919549, 0.03389380466459053, 0.2953352981380054, 7.868015016828265, 4.169886691229684, 10.518493958881923, 5.2250822527068, 6.1221107585089545, 36.128211225782124, 49.82807861055647, 49.04388059888567, 50.32526738303048, 49.40508965083531, 49.37033128738403, 48.15945482254028, 47.12077556337629, 47.259138516017366, 49.233187743595664, 46.542407512664795, 45.29895789282662, 42.89143834795271, 40.082615171160015, 33.98412568228585, 34.76933465685163, 32.29879495075771, 34.07414306913103, 31.577221052987234, 32.787437438964844, 35.443893568856375, 38.199941703251426, 40.26443910598755, 38.675941944122314, 36.32897594996861, 36.5480318069458, 39.058353424072266, 44.21930510657174, 46.315045084272114, 44.642259325299946, 40.68187992913382, 36.487339292253765, 34.20493943350655, 34.52183287484305, 33.94944027491978, 32.72757175990513, 32.23971789223807, 33.90186595916748, 33.90199450084141, 32.27100910459246, 33.293846470969065, 33.273891244615825, 32.7732526915414, 34.108626978737966, 34.206415925707134, 38.47569833483015, 37.93254722867693, 41.06659473691668, 40.25695937020438, 43.14437362125942, 42.11403567450387, 44.260292530059814, 42.236223220825195, 47.01961326599121, 44.40216432298933, 50.438425745282856, 33.29919310978481, 36.662023953029085, 47.88628986903599, 43.48384175981794, 45.41753584997994, 40.60267046519688, 38.50410604476929, 33.7511282648359, 32.64644111905779, 33.16113587788173, 34.1718555859157, 32.49173252923148, 34.04406431743077, 34.348576068878174, 35.38997554779053, 34.92553016117641, 33.91934067862374, 34.81650250298636, 35.323908601488384, 34.33424540928432, 37.137749740055625, 34.35781022480556, 35.29865537370954, 34.505681787218364, 35.92919397354126, 35.63511841637747, 38.01276765550886, 38.655319690704346, 39.11725330352783, 37.281032017299104, 36.43964685712542, 33.44074181147984, 34.853039605276926, 33.68760435921805, 35.96571370533535, 38.60309703009469, 36.66939599173409, 37.00300679888044, 40.10949775150844, 45.78583901269095, 44.72751719611031, 43.68808058329991, 41.93033920015608, 43.63233518600464, 46.66183662414551, 47.54615122931344, 46.82295145307268, 47.684531552451, 49.858192103249685, 53.846322604588096, 51.10128041676113, 51.627905232565745, 41.986546652657644, 41.381268228803364, 51.473755972726, 52.29835775920323, 53.46180234636579, 50.95395081383841, 32.05606658118111, 11.548956104687282, 2.906120104449136, 3.504629680088588, 0.6781288204448563, 0.032198814009981494, 0.30918294936418533, 26.71679633004325, 53.0620551109314, 40.56580332347325, 32.598279680524556, 33.87055390221732, 50.65401445116316, 55.225897857121055, 46.03393139157976, 9.509141308920723, 0.0681301745186959, 0.08212800590055329, 0.06230135514800038, 0.03266053334144609, 0.037120038510433266, 0.03540790466857808, 0.053783294545220475, 0.0080767117407439, 0.020679435260327797, 0.010610912810079753, 0.05745766005877938, 0.029701211423213993, 0.010505187724317824, 0.008327380388176866, 0.1672383631978716, 0.17382161851440156, 0.07969946121530873, 0.09953464115304606, 0.13475809964750493, 0.1723967899701425, 0.11683258866625172, 0.21869244719190256, 0.10752416708107505, 0.1203872843512467, 0.19626476136701448, 0.10827542069767203, 0.13123344949313573, 0.12067149552915778, 1.6242855957576205, 27.243238755634852, 55.77075822012765, 58.353021485464915, 54.22827202933175, 33.90650040762765, 44.267855644226074, 63.75226511274065, 47.84033100945609, 38.44176680701119, 1.989782554762704, 0.1720256855977433, 1.3921035059860773, 9.384143216269356, 4.639057287148066, 14.78911737033299, 8.980164527893066, 7.922547084944589, 37.48359285082136, 50.674414362226216, 48.68457882744925, 52.35105984551566, 50.86581638881138, 50.91580172947475, 49.82525764192854, 50.38462584359305, 49.889629227774485, 52.82749434879848, 48.13384028843471, 47.75758491243635, 44.165880407605854, 40.584504399980815, 35.9095583643232, 36.118761675698416, 33.4820419039045, 34.68336806978498, 32.8492625100272, 35.369162218911306, 36.958399363926475, 40.525104250226704, 43.03339351926531, 40.41421447481428, 38.35780130113874, 38.09683738436018, 41.259542737688335, 47.02790246691023, 47.41462182998657, 47.414733001164024, 41.636347021375386, 37.40809719903128, 34.86148861476353, 36.51492364065987, 35.45807831627982, 34.823495864868164, 33.00473540169852, 35.822087492261616, 34.75840514046805, 33.92879022870745, 34.30138042994908, 34.54305614743914, 34.89680283410208, 34.51918561117989, 35.70985671452114, 39.09315000261579, 40.054540974753245, 42.67371654510498, 40.4321790422712, 45.36699117933001, 43.7543420791626, 45.13722120012556, 44.49654517854963, 49.594282150268555, 47.927753244127544, 52.695885045187815, 35.69176013129098, 38.735658236912315, 49.19824525288173, 46.11685119356428, 46.64397280556815, 41.286057063511436, 39.29056569508144, 34.758307865687776, 35.62832307815552, 35.25304739815848, 36.41977500915527, 33.99334246771676, 35.478273255484446, 37.13630451474871, 37.80038901737758, 37.22119413103376, 36.06811278206961, 36.27438047954014, 35.53607184546334, 36.99010051999773, 37.82280738013131, 36.38027797426496, 37.52334349496024, 36.61576632090977, 38.11790084838867, 36.889490604400635, 39.253215653555735, 41.350835118974956, 41.57506390980312, 40.21539177213396, 39.42044142314366, 35.40806865692139, 34.715475695473806, 35.594704219273154, 37.90914569582258, 41.35600110462734, 39.042726925441194, 38.188167980739046, 42.30563225064959, 48.31663349696568, 45.965272767203196, 45.55042709623064, 43.68496431623186, 44.99062115805489, 48.076962334769114, 48.86922025680542, 48.818880558013916, 48.787898540496826, 51.725360666002544, 55.46317883900234, 54.2984106200082, 54.77949694224766, 44.328329290662495, 42.89245973314558, 53.79116433007376, 54.305859088897705, 54.830204895564485, 52.10297441482544, 35.14505154745919, 12.082204290798732, 3.9081332853862216, 5.452437732900892, 2.6065142154693604, 0.16025272304458277, 0.5457035920449665, 31.243919440678187, 58.917750222342356, 48.100047724587576, 33.28966018131801, 37.385171617780415, 55.82138279506138, 62.80516311100551, 56.05316775185721, 13.740362354687282, 0.14826598124844687, 0.2603712300104754, 0.20781524585826056, 0.14090748610241072, 0.1448292556617941, 0.1275872601462262, 0.10233798822654144, 0.08919139938162905, 0.154708684821214, 0.155439236334392, 0.08170919373099293, 0.09384937943624598, 0.061374550951378684, 0.10678459105214902], [0.0421184904740325, 0.021106450918263624, 0.0403127357629793, 0.03797979326918721, 0.07899537256785802, 0.002966737245774961, 0.02433926146477461, 0.038305493470813544, 0.04391131570030536, 0.10729592825685229, 0.05968568407531295, 0.021850830975121686, 0.04366719237129603, 0.0330050255704139, 0.5810815936752728, 16.950722796576365, 41.432591097695486, 45.84515578406197, 34.83966779708862, 24.08792281150818, 40.53274726867676, 40.50508649008614, 31.495430333273752, 34.768400124141145, 2.403376681464059, 0.04894658836669155, 0.9121513686009816, 5.445924230984279, 3.5501473290579657, 8.266711337225777, 6.951813391276768, 3.2294860099043166, 27.90828558376857, 46.32326480320522, 49.44342286246163, 46.23269503457205, 46.010102544512065, 45.223774909973145, 43.94791889190674, 43.47982917513166, 43.9846852847508, 42.370938369206016, 42.59334325790405, 38.52768128258841, 35.191208430698936, 32.353703090122764, 31.29946334021432, 31.137389659881592, 31.83239712033953, 30.768763405936106, 33.379444803510395, 39.23365994862148, 44.51265457698277, 44.78865786961147, 42.88935041427612, 44.184084687914165, 41.89070667539324, 41.260564122881206, 42.98765352794102, 43.787387711661204, 44.074827739170615, 43.49207884924752, 39.9820191519601, 34.48246785572597, 31.633689062935964, 31.925152097429546, 32.27531351361956, 32.77281495503017, 33.34801115308489, 31.663205010550364, 31.456867831093923, 31.058843748910085, 32.19790710721697, 32.721589360918315, 31.127405098506383, 32.61124154499599, 30.169939858572825, 31.885418823787145, 32.62441185542515, 33.038270882197786, 32.372279099055696, 34.94921657017299, 33.31468064444405, 35.76682152066912, 36.020722593579976, 40.61320046016148, 41.25194835662842, 47.48900924410139, 34.04101753234863, 34.51992212023054, 46.929036549159456, 40.758973666599815, 42.338250568934846, 37.98996019363403, 39.039864267621724, 37.594156060900005, 39.060212067195344, 37.97887781688145, 38.378777912684846, 35.36788722446987, 32.94790955952236, 32.608799253191265, 32.20896863937378, 31.709341049194336, 32.637321608407156, 33.984997681209016, 32.39710848672049, 32.467035157339915, 35.0153842653547, 33.03979253768921, 34.729854992457796, 33.46941702706473, 33.9412761415754, 33.7696521622794, 37.49111080169678, 41.40691750390189, 43.27723707471575, 45.1113634790693, 42.46803249631609, 39.27416794640677, 33.908001218523296, 33.82350417545864, 34.765801497868125, 34.59525796345302, 34.81786782400948, 33.89251715796334, 38.23821585518973, 44.244249139513286, 45.519775118146626, 44.5949455669948, 40.61921065194266, 38.27432911736624, 37.64814008985247, 37.94199677876064, 37.86831113270351, 38.781537192208425, 43.182963916233604, 48.79796995435442, 52.22734716960362, 48.16684423174177, 39.47392865589687, 41.50503996440342, 48.78068283626011, 51.88116012300764, 51.55644995825631, 52.25509132657732, 32.45263154166085, 11.91511401108333, 3.1408851870468686, 1.6427478279386247, 0.8010055412139211, 0.06320715190044471, 0.24216711255056517, 23.428983449935913, 44.72269514628819, 34.671128817967, 20.24142439024789, 16.626316615513392, 40.47745697838919, 46.4069002696446, 41.790381635938374, 7.8735978943961005, 0.02527827081004424, 0.021767634100147655, 0.10099665341632706, 0.029779829883149693, 0.06808863460485425, 0.05474184739536472, 0.014193833855512952, 0.028205866127141883, 0.032388586683997085, 0.031031553966126273, 0.032257201948336194, 0.016473015171608756, 0.02229524257459811, 0.04858229648587959, 0.048196142206766775, 0.09800288227519818, 0.0376997177622148, 0.0323614690319768, 0.038925426812576394, 0.06952991083796535, 0.04762803536972829, 0.05462652358359524, 0.01675719072643135, 0.023697547148913145, 0.01862473283628268, 0.04544715257361531, 0.09555053458149944, 0.003853466103984309, 1.048343117747988, 21.074539457048687, 47.92464392525809, 50.769924300057546, 42.10511071341378, 30.603990350450786, 43.453273160117014, 51.88212244851248, 39.74965749468122, 38.0209561075483, 2.7124937857900346, 0.07617876013474804, 0.9961558495249067, 6.848699518612452, 4.639499800545829, 10.828941208975655, 5.330774341310773, 4.144308200904301, 30.965453011648997, 46.40295716694423, 50.404688767024446, 48.06104401179722, 47.55795274462019, 47.76817396708897, 46.13937725339617, 46.67291552679879, 45.91573558534895, 45.352608408246724, 44.05473354884556, 40.87764195033482, 36.85912697655814, 34.51515218189785, 33.24712678364345, 32.84959602355957, 33.02438838141305, 32.040513038635254, 34.01805026190621, 40.466742856161936, 46.24370098114014, 46.84713118416922, 44.92734391348702, 45.203527859279085, 43.79413788659232, 43.53567879540579, 44.39610201971871, 45.26518269947597, 46.01595292772566, 43.53852408272879, 41.30545990807669, 36.31036172594343, 32.36581032616751, 34.2657014301845, 34.13645451409476, 34.84132841655186, 34.15879644666399, 33.76687635694231, 31.153964587620326, 32.46640287126814, 33.33311768940517, 33.370422567640034, 32.24418558393206, 34.51690312794277, 31.791979449135916, 32.89779567718506, 34.2985212462289, 34.71177230562483, 35.050337178366526, 36.35253381729126, 35.753296852111816, 38.57042660032, 37.42210129329136, 41.92039285387312, 42.053165980747764, 50.72971854891096, 35.10148981639317, 36.00950820105416, 49.1388589995248, 43.658554213387625, 43.86400202342442, 39.25680092402867, 40.92227022988455, 39.87320341382708, 40.09107460294451, 37.79834277289254, 38.91232660838536, 38.12537016187395, 33.943235533578054, 33.9921612739563, 33.35597378867013, 33.878672872270855, 34.576737540108816, 36.15229368209839, 33.780522618974956, 33.986422061920166, 36.95720427376883, 35.450563839503694, 35.83969075339181, 35.697874546051025, 36.38135494504656, 36.703330993652344, 39.81274018968855, 42.17575652258736, 45.65713405609131, 47.031501633780344, 45.17509235654558, 40.37360225405012, 36.822200775146484, 35.53097186769758, 35.26183339527675, 35.400307519095286, 37.04294157028198, 34.90173952920096, 40.509644508361816, 46.57275377001081, 46.654596601213726, 46.06101199558803, 43.53000211715698, 40.62352548326765, 38.970747062138145, 40.86285618373326, 40.3411090033395, 41.256610597882954, 45.81625822612217, 51.844532694135395, 52.84182153429304, 50.08482149669102, 41.915529114859446, 43.973967688424246, 49.87376996449062, 53.04793637139456, 54.11187580653599, 52.336628437042236, 32.338038376399446, 12.707840067999703, 1.6143806129693985, 3.473008211169924, 0.5711529978684017, 0.05100728564762643, 0.21507630337561878, 26.07402890069144, 49.031158447265625, 40.022700854710166, 22.70665567261832, 21.150009053094045, 45.358045373644146, 51.685092381068635, 47.76917450768607, 10.634583592414856, 0.0609643833179559, 0.01931435172446072, 0.022974859856601273, 0.030835728759744337, 0.045873968063720634, 0.047326277276234965, 0.12698982363300665, 0.05551466824752944, 0.0051070171424986, 0.07211911904492549, 0.02415569399350456, 0.04927916552073189, 0.04478068190759846, 0.027118569738896828, 0.15248288639954158, 0.13497440304074967, 0.1504499547715698, 0.10172735420720917, 0.10056077609104769, 0.21098423509725503, 0.13659220694431237, 0.1444040041949068, 0.0799587769433856, 0.1982769841062171, 0.08088152350059577, 0.08673844100641352, 0.1981923436479909, 0.17994498993669236, 1.269652579511915, 27.141366004943848, 56.15244013922555, 57.54901415961129, 47.907791069575715, 35.50553798675537, 49.538227558135986, 48.41135481425694, 40.93058722359793, 44.14531373977661, 3.2755371502467563, 0.19987238278346403, 2.1646574224744524, 7.993714877537318, 7.117358565330505, 16.709509134292603, 14.883538178035192, 5.140643400805337, 34.86508083343506, 46.94408982140677, 52.9486083984375, 51.290229729243684, 50.685020787375315, 49.491379329136436, 48.028606346675325, 47.71702132906233, 47.105360984802246, 46.25903218133109, 47.30126196997506, 43.07833446775164, 39.327988692692344, 36.371960980551584, 34.98631647654942, 33.78963170732771, 35.31667900085449, 33.48115600858416, 36.004540239061626, 41.954390389578684, 48.84767041887556, 49.18070452553885, 47.11459861482893, 47.825538294655935, 46.65647608893258, 46.07393217086792, 48.996299334934776, 45.71905640193394, 47.324250085013254, 46.184874057769775, 43.756919860839844, 37.94166326522827, 34.85454389027187, 35.577142647334504, 36.55873898097447, 36.67785889761788, 37.25133541652134, 35.69178097588675, 33.39054455075945, 34.28171355383736, 34.319188662937705, 35.41944285801479, 33.84361226218087, 36.585517338344026, 34.234938280923025, 34.61516802651541, 36.56021547317505, 36.286362648010254, 36.68801021575928, 38.432518754686626, 37.011928285871235, 40.20471239089966, 40.966064725603374, 43.92907885142735, 46.64844397136143, 51.6013457434518, 37.94665902001517, 38.46517528806414, 50.34181104387556, 46.63457536697388, 45.37875100544521, 42.25496598652431, 44.04028476987566, 42.23610162734985, 42.997381005968364, 40.733241013118196, 43.08025911876133, 39.80998522894723, 35.70399938310896, 35.921547480991904, 34.71711894444057, 35.90401370184762, 35.72888783046177, 37.85843774250576, 36.22640316826956, 36.10999652317592, 39.774629320417134, 37.1348488671439, 37.21882479531424, 38.023652008601594, 39.583692823137554, 37.228948320661274, 41.724446705409456, 44.935389927455354, 48.89247587748936, 49.69541665485927, 48.36909934452602, 43.464515345437185, 37.767409392765586, 36.98826272147042, 37.24707964488438, 36.968922410692485, 38.491814681461875, 37.291478633880615, 41.44020284925188, 48.57995980126517, 48.98725972856794, 49.06807770047869, 45.21359232493809, 42.12413488115583, 41.37492799758911, 42.37353004728045, 41.40655272347586, 43.00363438470023, 47.67296974999564, 53.13427121298653, 55.94336884362357, 51.33674097061157, 43.951441628592356, 46.808151790073936, 52.30726882389614, 56.957871845790315, 56.30582162312099, 53.76768636703491, 34.336475781032014, 15.4341881275177, 6.467571718352182, 6.649205880505698, 1.2158577804054533, 0.11676857567259244, 0.47924238975558964, 29.722639151981898, 56.154632295881, 47.2281356539045, 29.289971351623535, 26.28925977434431, 52.835043566567556, 58.61070932660784, 54.53140456335885, 14.545200858797346, 0.21651760675013065, 0.10011789628437587, 0.13978187793067523, 0.14362225042922155, 0.1940676649766309, 0.13383345997759274, 0.12969801974083695, 0.14579937074865612, 0.15164492279291153, 0.1497509279953582, 0.08301922093544688, 0.1491847855171987, 0.1443872715213469, 0.09693857295704739], [0.035409207455813885, 0.06291780421244246, 0.01648580894938537, 0.06524887055690799, 0.022988754557445645, 0.05100237983944161, 0.05593219120055437, 0.06791955724890743, 0.034648464526981115, 0.04490505398384162, 0.046396979463419745, 0.018966120767540166, 0.048304215871862004, 0.02786707698500582, 0.7362903452345303, 15.426753555025373, 40.554352692195344, 41.566079889025005, 28.075876133782522, 27.047829355512345, 38.620606490543906, 29.649471146719797, 28.63013219833374, 37.04766287122454, 2.5312254897185733, 0.03938731577779565, 0.4528503359428474, 7.701591764177595, 6.430064473833356, 8.990797877311707, 2.772344699927739, 3.836169055530003, 27.92884530339922, 49.35802602767944, 48.558177198682515, 45.78491490227835, 42.93077557427542, 39.06809827259609, 37.14072009495327, 36.261196272713796, 37.980597496032715, 35.90214811052595, 35.21878235680716, 33.516928809029714, 32.220009326934814, 31.114828859056743, 31.935598714011057, 33.156352043151855, 31.374267646244594, 32.26633644104004, 40.32154287610735, 44.2629919052124, 43.14495726994106, 41.860878058842246, 42.984175954546245, 44.56724309921265, 44.42489882877895, 43.59216070175171, 43.92805051803589, 43.401238100869314, 42.62330389022827, 43.78549780164446, 42.916114875248496, 33.346155984061106, 31.113213402884348, 33.597691195351736, 31.603624207632883, 32.406443391527446, 32.292058672223774, 30.95310606275286, 31.225107192993164, 31.216029371534074, 31.21863842010498, 32.65378189086914, 30.859968934740337, 31.638431208474294, 30.929374490465435, 31.357025691441127, 30.246602807726177, 32.29925005776541, 32.8035329410008, 31.168267454419816, 30.009318351745605, 33.351572104862754, 32.54337848935808, 37.655230726514546, 39.8707263810294, 45.204820224217, 37.78600972039359, 34.21563618523734, 44.234712736947195, 43.144026211329866, 45.12190042223249, 43.0219463620867, 44.23204810278756, 43.88569777352469, 44.08901596069336, 43.29650442940848, 42.67633254187447, 38.373761313302175, 37.81009565080915, 34.43114846093314, 31.998076915740967, 31.68857635770525, 32.992694173540386, 33.27734102521624, 32.16034514563424, 33.38126870564052, 32.76765591757638, 32.67014142445156, 34.21734544209072, 33.64331306729998, 34.68763426371983, 36.11263683864048, 37.26837239946638, 39.96089315414429, 42.97516761507307, 47.01085158756801, 46.68559946332659, 43.3215457371303, 40.447815963200156, 34.57146038327898, 33.20107412338257, 34.38151747839791, 33.771347522735596, 35.2828551701137, 35.77802201679775, 44.2824364389692, 46.40006671633039, 46.88163941247122, 46.13678904942104, 45.28800753184727, 40.341946261269705, 38.609235763549805, 35.62977177756173, 36.00520379202706, 35.74322543825422, 41.34410578863961, 42.18015820639474, 39.29917451313564, 36.7271911076137, 46.12855543409075, 50.21319988795689, 54.15647281919207, 50.37085798808506, 54.755223410470144, 34.91974925994873, 15.550662517547607, 2.2639263357434953, 2.720305949449539, 0.07478612807712384, 0.022645831440708468, 0.168070627110345, 22.839064019066946, 45.91660411017281, 35.95031302315848, 30.3572632925851, 31.074630056108745, 47.33114269801548, 47.06253923688616, 43.7019943509783, 9.697208200182233, 0.015041270659172108, 0.02037600627435105, 0.014219529976669167, 0.022959545321230377, 0.080935127767069, 0.030003125579761605, 0.008770741954711931, 0.009195355598681738, 0.009049870057164558, 0.04643553721585444, 0.0424869315964835, 0.0555177996866405, 0.04751306100349341, 0.029828565660864115, 0.023939560234014477, 0.06859824154525995, 0.0825655727780291, 0.04537269353334393, 0.06346257283751454, 0.018664858004610454, 0.046384497811751704, 0.047245178770806105, 0.02973833746675934, 0.006211036026278245, 0.026032080807323967, 0.053328268961714845, 0.01747447348731969, 0.05372461822948285, 0.9207932991640908, 20.451127971921647, 46.879454204014365, 47.626920563834055, 33.010676111493794, 29.259117875780376, 47.421663829258506, 39.539797578539165, 36.150994368961875, 41.08726562772478, 3.285102431263242, 0.0817558497988752, 0.9281619723354066, 8.281691653387886, 8.780916248049055, 8.496158225195748, 3.19523486495018, 6.3812121238027295, 30.265758991241455, 49.404495579855784, 51.072730268750874, 47.4567939213344, 44.61748899732317, 41.28942346572876, 38.9826215335301, 39.275012152535574, 39.268255029405864, 38.70070532390049, 37.95450006212507, 35.159350940159385, 33.98553269250052, 32.39493717466082, 34.10179689952305, 34.83879927226475, 32.554544244493755, 33.85566738673619, 41.75179134096418, 46.88477305003575, 44.48022386005947, 43.33929491043091, 44.624051570892334, 46.0932377406529, 45.53312955583845, 45.62847968510219, 45.155286516462056, 44.09222950254168, 42.92213201522827, 44.95642907278878, 43.19575554983956, 35.21484272820609, 32.99586950029646, 35.10926832471575, 32.83982685634068, 34.59955195018223, 34.06398480279105, 34.3806072643825, 31.837135791778564, 32.93938759395054, 32.39672633579799, 34.311712401253835, 33.52060440608433, 32.797394207545686, 33.08289221354893, 34.173540524074006, 32.77191168921334, 34.35941178458077, 34.21939863477434, 31.703407287597656, 33.186955383845735, 34.56032242093767, 34.89790064947945, 40.24457768031529, 42.02567890712193, 48.13651187079293, 40.12258815765381, 36.15509728022984, 46.289534773145405, 44.24351263046265, 46.73906932558332, 46.10148525238037, 45.861122744424, 44.47390794754028, 46.26767921447754, 43.720869132450645, 43.07363053730556, 40.80517223903111, 38.39035708563668, 35.65215539932251, 32.93370744160244, 33.52930702481951, 34.26118162700108, 35.46923017501831, 33.54730633326939, 34.874964645930696, 33.82461241313389, 34.83079842158726, 36.31842163630894, 36.16026326588222, 37.261181013924734, 38.004033769880024, 39.792611258370535, 42.49750675473894, 46.25939001355852, 48.55108308792114, 47.60159090587071, 45.99125902993338, 42.12331846782139, 35.20222132546561, 35.55429697036743, 34.40571110589163, 35.46902520315987, 35.53441817419869, 37.772606645311626, 45.3796820640564, 48.349988324301584, 49.531432219914024, 47.58187886646816, 46.86451210294451, 41.31006308964321, 40.07975598743984, 38.266845907483784, 38.31768935067313, 39.14593546731131, 42.87987307139805, 44.62241179602486, 41.395348753247944, 40.28260864530291, 47.84212017059326, 51.90906408854893, 53.97109835488455, 53.47737325940813, 52.482123715536936, 36.811952182224815, 14.231364624840872, 2.690180080277579, 3.42369966847556, 1.2231922554118293, 0.050100837501564195, 0.18078375421464443, 25.393018586294993, 50.05461767741612, 40.59767818450928, 30.336446489606583, 32.454121930258616, 52.81352846963065, 53.59298433576311, 50.31335122244698, 12.331767082214355, 0.011846188356035521, 0.08334409671702556, 0.013051929817135845, 0.026201161555945873, 0.08496820421091147, 0.023840283775436025, 0.013448300289123185, 0.013255653171134847, 0.03902525966987014, 0.035693486487226825, 0.033941929760788164, 0.023403179998110448, 0.02233065531722137, 0.011879194843848901, 0.17651708530528204, 0.17812401907784597, 0.16886315601212637, 0.10499776407544102, 0.10427614886845861, 0.1686044441802161, 0.12267717719078064, 0.12739470547863416, 0.08398561086505651, 0.10300421461995159, 0.10246340185403824, 0.2407014226274831, 0.14672443111027988, 0.14750195081744874, 1.3637475818395615, 25.161961453301565, 54.50024536677769, 53.60856219700405, 38.03524855204991, 36.90514489582607, 45.07574006489345, 37.33589499337332, 38.885047980717246, 46.54890060424805, 3.569331305367606, 0.16818361676165036, 0.9399246211562837, 12.565574833324977, 15.911680494035993, 19.568762336458477, 5.934333954538618, 6.1114561302321295, 34.00383424758911, 51.39540113721575, 54.28104359763009, 49.01500735964094, 46.84757934297834, 42.740933418273926, 40.84159122194563, 39.76366853713989, 42.25099509102957, 40.140660422188894, 39.8140811920166, 36.812921455928254, 36.29609707423619, 34.96543713978359, 35.414533955710276, 37.32847779137747, 34.992309297834126, 35.376502990722656, 44.835481779915945, 48.04968023300171, 45.9146968296596, 44.24694504056658, 45.555659089769634, 47.93748072215489, 47.42877531051636, 46.31673002243042, 47.29038456508091, 44.289645195007324, 44.8638790675572, 47.00497341156006, 47.403688839503694, 35.37768765858242, 35.21949107306344, 38.41562073571341, 34.38920566013881, 35.30730588095528, 36.68098211288452, 35.251612595149446, 34.120581354413716, 34.92393554959978, 34.88441072191511, 36.987727710178916, 35.15836429595947, 34.86784621647426, 35.35111774717058, 35.63904414858137, 34.73102576392037, 37.04026998792376, 37.330093247549875, 33.752823625292095, 34.74571772984096, 36.74578101294381, 37.08755247933524, 42.01582983561924, 44.121366773332866, 48.42197513580322, 43.52456167766026, 39.32291998182024, 46.52317837306431, 45.01723970685686, 49.24260950088501, 49.56058686120169, 48.602475438799175, 48.69354200363159, 48.84169496808733, 45.86666393280029, 45.52496542249407, 41.90577384403774, 40.880674839019775, 38.25019802365984, 35.236760820661274, 36.39519575663975, 36.30114146641323, 37.08052437646048, 35.382513182503835, 36.8583904675075, 37.68619189943586, 37.43973582131522, 38.14953947067261, 38.77852167401995, 39.7671982220241, 40.326031412397114, 40.70001472745623, 44.59893383298601, 48.392375809805735, 51.43051733289446, 49.750925813402446, 47.47496346064976, 43.9022136415754, 37.70518480028425, 37.03360319137573, 36.71460444586617, 37.74660996028355, 38.30801745823452, 38.680322783333914, 45.926126616341726, 50.61307566506522, 51.02056319372994, 50.3981157711574, 50.22278840201241, 44.71110555103847, 41.87611893245152, 40.590181078229634, 39.570849078042166, 40.11250632149832, 45.25703593662807, 46.32169451032366, 44.40090669904436, 40.36064386367798, 51.308538232530864, 54.70131581170218, 58.16333218983242, 54.24128947939192, 55.79656730379377, 39.5639842578343, 19.892187084470475, 5.417426194463458, 7.11584255525044, 2.0892416749681746, 0.15421057226402418, 0.4203153688992773, 27.31667079244341, 57.77355909347534, 49.158491134643555, 41.731717995234895, 40.461691515786306, 59.107116426740376, 61.520121574401855, 57.47758667809622, 16.677318130220684, 0.25767114918146816, 0.2621234788426331, 0.09651852585375309, 0.10450200603476592, 0.1679025132741247, 0.13072187480117592, 0.18090643334601605, 0.07460598381502287, 0.17202113941311836, 0.20096871895449503, 0.11310935845332486, 0.09865177209888186, 0.15421099295573576, 0.09779419883021287], [0.012143954119112874, 0.11254546192607709, 0.011965580833410578, 0.01909115950443915, 0.01116437855775335, 0.032755256830049415, 0.023670378606766462, 0.06544189341366291, 0.01295195786016328, 0.07655035305236067, 0.03679234002317701, 0.025348877467747246, 0.02576129953376949, 0.023485253897628615, 0.6949155053922108, 17.408987760543823, 42.202875341687886, 42.66354438236782, 32.09649814878191, 27.388789619718278, 16.448475735528127, 28.29295870235988, 43.355060373033794, 34.232287543160574, 5.580327578953334, 0.24402388291699545, 1.1153593616826194, 2.2391097588198523, 4.859225290162223, 6.255547438349042, 3.480997771024704, 11.63881368296487, 24.21954948561532, 42.12291547230312, 46.17842960357666, 45.59421811785017, 43.59534297670637, 36.995582648685996, 33.82198599406651, 33.60207550866263, 33.41898700169155, 32.49592229298183, 31.783249037606375, 31.440428393227712, 33.22167553220476, 31.031957694462367, 31.589147635868617, 32.20558139256069, 32.78214985983712, 39.89848443440029, 44.175920554569785, 46.10225302832467, 43.74935327257429, 42.91113996505737, 43.79562827519008, 43.61351251602173, 44.079364912850515, 44.14680412837437, 43.672155312129426, 43.43275512967791, 42.61016137259347, 43.77302231107439, 40.51207637786865, 33.170686176845, 32.02286114011492, 32.127945695604595, 34.30919367926461, 34.98151874542236, 30.70987047467913, 32.41612223216465, 30.453120640345983, 30.394311087472097, 31.681947776249476, 33.004700660705566, 31.544508934020996, 31.38274792262486, 30.485238688332693, 31.8185841015407, 31.910199574061803, 32.59687614440918, 31.49159492765154, 31.811399664197648, 31.652275494166783, 34.62711197989327, 35.112676416124614, 39.92957762309483, 39.44260617664882, 45.935110637119834, 36.11392572947911, 32.4366854258946, 45.973940644945415, 40.0244448525565, 45.48199776240757, 42.16700874056135, 45.454920632498606, 44.48003625869751, 44.7005477632795, 43.64562708990914, 41.953438486371724, 40.05123363222395, 39.6270808492388, 34.944133962903706, 32.64604507173811, 31.21089812687465, 33.42012998035976, 33.633210386548726, 33.8841723714556, 32.656811305454795, 33.380643367767334, 33.665443079812185, 33.723015853336875, 33.81419358934675, 34.65265008381435, 33.672328744615825, 35.831116676330566, 37.172136374882285, 41.80869013922555, 44.58114644459316, 43.079411438533235, 45.301216057368684, 43.81984622137887, 36.05276421138218, 32.97356578281948, 33.70818839754377, 33.19921548025948, 32.010319641658235, 32.2528395652771, 38.224868365696494, 48.152965205056326, 45.474538871220176, 49.86362559454781, 47.714909076690674, 47.68981565747942, 45.4828975541251, 44.71537174497332, 42.45868369511196, 38.13004629952567, 35.004972389766145, 36.45173672267369, 35.84512424468994, 39.54842724118914, 48.36405495234898, 51.15575429371425, 53.54619516645159, 51.905492714473176, 49.51056677954537, 38.293634687151226, 16.630080802100046, 0.5527929802026067, 2.468463497502463, 0.4994716356907572, 0.02186064768050398, 0.17135396307068212, 21.653419937406266, 47.735687664576936, 33.365218366895405, 27.740114859172277, 26.915165662765503, 41.53859976359776, 50.134956223624094, 41.982593127659385, 11.414104597909109, 0.2804126574524811, 0.024155068044949855, 0.06348294924412455, 0.04956803823422108, 0.06205542691584144, 0.04361168820677059, 0.05952652690133878, 0.06755037991596119, 0.03717298120526331, 0.1128746939024755, 0.03843863561217274, 0.03865547165540712, 0.0347739290446043, 0.04938701866194606, 0.01663565492656614, 0.08309437547411237, 0.016479315369256904, 0.023712544469162822, 0.03030431709651436, 0.03402099944651127, 0.058516296824174266, 0.03518748935312033, 0.07772235944867134, 0.018796061232153858, 0.01943358898695026, 0.005635513225570321, 0.03123805931370173, 0.06862334055559975, 1.3051331213542392, 20.253293650490896, 47.91883175713675, 48.61535045078823, 36.37056786673409, 30.696026188986643, 21.301090683255875, 27.612307957240514, 42.30234227861677, 38.965699195861816, 5.631449384348733, 0.16550849245062896, 0.6251539630549294, 4.720020302704402, 5.520170075552804, 8.646464262689863, 3.8627120426722934, 10.588733298437935, 27.593763215201243, 43.12283073152815, 49.56917830875942, 47.83014842442104, 43.96233640398298, 38.59281022208077, 35.39317866734096, 34.92886529650007, 34.44798742021833, 33.78807531084333, 33.48424448285784, 33.699322496141704, 34.06364434106009, 33.37967756816319, 33.508990492139546, 33.46376119341169, 33.429332869393484, 41.826387201036724, 46.43959501811436, 46.925409589494976, 44.52588742119925, 45.72426060267857, 45.741089139665874, 46.491213185446604, 45.563121455056326, 46.51148802893502, 44.989106450762065, 43.499270234789165, 43.125623907361714, 44.57375356129238, 43.94874572753906, 34.721270493098665, 32.658656052180696, 33.725228854588096, 35.29944746834891, 36.35848494938442, 32.86816161019461, 33.53756495884487, 31.44022342136928, 32.654455866132466, 32.81139135360718, 34.19484370095389, 33.3509259223938, 33.23075335366385, 31.738415786198207, 33.37683922903878, 33.88587120601109, 33.31397540228707, 32.022308758326936, 34.49582576751709, 34.2390307698931, 35.49302428109305, 36.532728399549214, 41.09371703011649, 41.234932218279155, 48.885791710444856, 38.70114653451102, 34.0554906300136, 46.15061943871634, 41.82602589470999, 46.44564342498779, 44.156816482543945, 46.31186975751604, 46.54057318823678, 46.00410624912807, 44.86939941133772, 42.94213935307094, 41.15007734298706, 41.205298151288716, 36.86306313105992, 34.70440026691982, 34.07549796785627, 35.176169054848806, 33.52852187837873, 36.04671927860805, 34.69947052001953, 35.23463467189244, 34.72240999766758, 34.06171274185181, 37.56261471339634, 36.30003670283726, 35.70786952972412, 36.59707566670009, 40.09988144465855, 44.15988411222185, 46.6460850579398, 44.34555040087019, 46.94311012540545, 46.01002264022827, 37.30645547594343, 34.11030149459839, 34.74058301108224, 34.23023087637765, 35.06302111489432, 34.65854563031878, 41.79770851135254, 49.52506767000471, 47.86220046452114, 51.26307964324951, 49.648022992270334, 48.945945739746094, 47.854797158922466, 45.580742086683, 43.72431196485247, 40.22952788216727, 36.96275935854231, 38.05698251724243, 39.18750306538173, 40.58767625263759, 50.49132585525513, 54.30777331760952, 55.91248410088675, 53.76963186264038, 50.07539973940168, 39.10169281278338, 16.309065341949463, 1.8257638130869185, 3.7603264280727933, 1.066491378205163, 0.08491841331124306, 0.19237664714455605, 23.218565940856934, 52.388361249651226, 40.15655442646572, 35.01458869661604, 32.81081117902483, 48.52632665634155, 55.66511780875069, 49.99771193095616, 14.057325278009687, 0.1876296704368932, 0.0431486084125936, 0.018023728925202574, 0.03950864462448018, 0.035748770127871206, 0.03335884765588811, 0.024109231308102608, 0.02324361739946263, 0.028975107707083225, 0.062010738599513254, 0.07663088158837386, 0.05234771461359092, 0.07484790869057178, 0.10592323155807597, 0.12370605341025762, 0.24580880999565125, 0.16743608830230577, 0.1961925652410303, 0.10264579885240112, 0.13399911751704557, 0.1364369174199445, 0.12034354598394462, 0.18891107024891035, 0.15895929959203514, 0.08171304102454867, 0.07628535798617772, 0.22771941923669406, 0.16500690579414368, 1.5329670501606805, 25.822220972606114, 55.07773447036743, 56.16934858049665, 42.83439711162022, 38.00795602798462, 23.899789912360056, 37.29108953475952, 53.34514556612287, 43.361282484872, 7.1997281568390985, 0.33610062354377335, 2.4996891362326483, 5.496176208768572, 9.431109564644949, 13.25854560307094, 8.400340829576765, 16.339802435466222, 29.992573193141393, 45.58972610746111, 50.19037505558559, 49.630642073495046, 49.41641174043928, 41.22676113673619, 37.82717432294573, 37.10860552106585, 36.97991098676409, 35.25952659334455, 35.5672345161438, 34.838959080832346, 36.31552076339722, 34.20678070613316, 34.14657803944179, 34.664444650922505, 36.08153322764805, 44.43120084490095, 47.91460725239345, 47.321352686200825, 45.48232780184065, 46.98454570770264, 47.45423003605434, 48.2434515953064, 46.66557822908674, 47.82311337334769, 44.57722418648856, 44.41248934609549, 43.489042486463276, 48.12483194896153, 45.1032132421221, 36.072052410670686, 34.90461955751692, 35.79757077353341, 36.757054465157644, 38.92824840545654, 32.96754169464111, 35.55841030393328, 33.20582321711949, 33.08720357077462, 34.69325188228062, 36.07990040097918, 34.515329360961914, 35.62025274549212, 33.26082515716553, 37.06375142506191, 35.21128872462681, 35.3708575793675, 34.39569180352347, 37.13424437386649, 35.851318563733784, 38.73538725716727, 39.296982356480186, 42.36721066066197, 43.873937947409495, 49.76999861853463, 40.95422499520438, 35.64624943052019, 47.564748082842144, 43.71525846208845, 48.95265422548567, 46.2302006312779, 48.34327289036342, 48.75499882016863, 47.94891398293631, 48.43862301962716, 46.06251628058297, 43.90580586024693, 43.193115234375, 39.10048382622855, 36.54605851854597, 35.00204719815935, 36.815450600215364, 36.540986333574565, 37.80095876966204, 36.17992319379534, 36.85683059692383, 38.44344827107021, 36.90968901770455, 40.00359330858503, 39.05063744953701, 37.92639807292393, 39.24766056878226, 41.206555775233674, 45.83794355392456, 48.554310526166645, 46.07899045944214, 47.64176886422293, 48.19812502179827, 39.48688357216971, 36.408338274274556, 37.6491892678397, 34.892012051173616, 37.42328943525042, 35.79773753029959, 43.79065683909825, 52.14733518872942, 48.13939189910889, 53.14439821243286, 51.292401041303364, 51.6184834752764, 50.72264528274536, 48.68270976202828, 46.44835669653756, 43.01942764009748, 38.87382663999285, 41.12063782555716, 40.423907211848665, 43.582895278930664, 52.56244836534773, 56.4649909564427, 58.655553000313894, 55.51703780038016, 51.20051458903721, 42.056306566510884, 21.539658818926128, 3.1840495680059706, 5.178792919431414, 1.7980238901717323, 0.2424675678568227, 0.44590908555047853, 26.18932557106018, 59.69157109941755, 44.27824320111956, 40.95004217965262, 38.188192299434114, 54.45255640574864, 63.43582330431257, 57.94893510001046, 17.407940319606237, 0.35485128739050453, 0.11678422269012247, 0.112501832124378, 0.17256178254527704, 0.1497492180871112, 0.09204922603177172, 0.09838694666645356, 0.11557132777358804, 0.105624506516116, 0.2063755573970931, 0.12120288344366209, 0.16932126214461668, 0.23357897624373436, 0.1725611582930599], [0.033689104220164676, 0.04257014034582036, 0.03928351688331791, 0.036079800222069025, 0.014255104719528129, 0.014115686977415212, 0.02176794283358114, 0.03964703862688371, 0.009999728329213602, 0.04739035473072103, 0.017354045395872424, 0.05920036190322467, 0.03984041092917323, 0.06289453046130282, 0.04824639451024788, 14.613908120564052, 46.16583946772984, 41.39913899557931, 37.97209290095738, 28.91455670765468, 21.18846559524536, 24.320762157440186, 35.073120321546284, 35.84834473473685, 5.0916342820440015, 0.037621750695897, 0.21599723824432918, 2.035612221275057, 4.916873625346592, 6.6826766559055875, 3.006782348666872, 9.39970804963793, 26.537016902651104, 43.447391510009766, 48.04367004122053, 44.90934460503714, 43.68598222732544, 42.44253955568586, 38.782933780125205, 35.86748007365635, 33.1181960105896, 31.482200963156565, 33.352329458509175, 32.802341324942454, 32.1449305670602, 33.72743143354143, 35.158683913094656, 31.55947882788522, 36.78493758610317, 45.34116472516741, 42.72675561904907, 43.063343729291645, 44.54252140862601, 41.02677113669259, 40.24965681348528, 39.741830348968506, 39.9993896484375, 42.86933612823486, 44.16440044130598, 46.54308148792812, 45.73091002873012, 43.808604036058696, 42.07928773335048, 34.702166421072825, 32.41806077957153, 33.03367117473057, 32.46690314156668, 31.4917825290135, 31.216522693634033, 30.93169171469552, 32.08595078332083, 31.22654547010149, 30.785835129874094, 32.45622028623308, 31.46255145754133, 30.85665464401245, 31.329667159489222, 31.430697441101074, 30.082378659929546, 31.366190365382604, 30.437862396240234, 30.715015615735734, 31.156278337751115, 37.72396230697632, 36.832129750932964, 42.69699648448399, 42.543111256190706, 46.05106217520577, 37.043226446424214, 32.13069370814732, 37.595948696136475, 35.83656406402588, 41.98269387653896, 43.02711582183838, 43.54111576080322, 43.9639379637582, 41.67688628605434, 41.843358176095144, 43.9527131489345, 43.43022945949009, 40.83595623288836, 34.619090284620015, 32.635195459638325, 30.78547034944807, 32.77752930777413, 32.42348384857178, 33.28423711231777, 32.825134890420095, 32.17630863189697, 31.685362815856934, 34.13074656895229, 35.10932738440377, 36.66296195983887, 34.605576038360596, 33.46214573723929, 35.53614827564785, 43.46097176415579, 44.651955536433626, 47.16516065597534, 44.27922984531948, 43.47834573473249, 34.3909843989781, 34.202549253191265, 33.659731660570415, 33.598795958927695, 32.51982757023403, 34.02716282435826, 32.970338344573975, 41.21932309014456, 48.862296376909526, 47.203195095062256, 50.221926825387136, 48.99032735824585, 49.93443816048758, 46.319460664476665, 46.70243147441319, 43.166354247501914, 38.800220898219514, 38.06121049608503, 38.62450442995344, 39.6353040422712, 49.23043973105294, 50.26508208683559, 52.61928462982178, 52.862721715654644, 49.16880226135254, 38.027751445770264, 13.108318601335798, 4.278199987752097, 3.8596548352922713, 0.9899310235466275, 0.03334462895457234, 0.19379443249532155, 20.783755608967372, 46.79506833212716, 36.846946784428184, 30.90371479306902, 25.513156414031982, 37.27094670704433, 49.7978504725865, 41.43259457179478, 10.349463394709996, 0.20099932088383607, 0.023847932561433742, 0.034015693302665434, 0.02506979092556451, 0.0962213139448847, 0.038580008383308134, 0.0778786057074155, 0.04964130983820983, 0.022351542321432914, 0.023395414164822017, 0.04050811652892402, 0.05300898430868983, 0.037464422173798084, 0.04912526699315224, 0.017545132731486644, 0.02657917680751, 0.03655778743060572, 0.05198294097291572, 0.028040115289123993, 0.054127518752855916, 0.029214430400835614, 0.02231087432509022, 0.04433868080377579, 0.03186068983216371, 0.026265177942280258, 0.04870076530746051, 0.04818301933950611, 0.0509641783178917, 0.461952340390001, 20.190737281526836, 52.274535860334126, 49.5711099079677, 43.67014728273664, 31.312842096601212, 24.619251557758876, 33.78791897637503, 41.468040806906565, 39.247486863817485, 5.83661926644189, 0.033399169599371295, 0.06581027007528714, 2.5234680431229726, 4.828292344297681, 4.261797896453312, 6.265967999185834, 13.78755625656673, 29.322360379355295, 44.63714892523629, 49.71674067633492, 46.444434438432964, 46.758003166743684, 44.41385119301932, 40.77091414587838, 36.515389169965474, 33.838369846343994, 33.769641739981516, 34.14824908120291, 34.653820855276926, 34.69419683728899, 34.104107175554546, 35.9474538394383, 32.83457054410662, 39.05880158288138, 47.362228938511436, 43.682066917419434, 44.40562105178833, 46.533642360142295, 42.806079728262766, 40.69992440087454, 42.15823316574097, 41.97332075663975, 44.343386037009104, 45.662842001233784, 47.778151580265586, 45.96700981685093, 44.46364198412214, 42.56377867289952, 35.14932121549334, 34.18765926361084, 33.66377551215035, 34.01431907926287, 32.808695452553884, 32.10572188241141, 32.83252777372088, 33.93764918191092, 32.71390812737601, 32.071231024605886, 32.82840401785714, 32.76529005595616, 31.731884479522705, 33.23553718839373, 32.82417951311384, 32.11975029536656, 33.1283403805324, 32.97073091779436, 31.953438213893346, 32.85273313522339, 39.33126824242728, 38.894282136644634, 43.7528794833592, 44.2231822013855, 47.83879198346819, 39.20332758767264, 32.90428876876831, 39.351925236838206, 37.55586106436593, 42.87930679321289, 43.24366337912423, 44.251607281821116, 44.86789860044207, 43.38011557715279, 42.464666094098774, 44.31700372695923, 45.1055200440543, 41.6640807560512, 35.75170571463448, 33.89943061556135, 31.90741334642683, 34.58740302494594, 32.7724084854126, 34.46643141337803, 33.318644591740195, 34.36643641335623, 34.59470558166504, 36.26379837308611, 36.146321705409456, 38.52711500440325, 36.32634258270264, 34.89911658423287, 38.0229571887425, 45.172014304569785, 46.37626566205706, 48.07030596051897, 44.68284027917044, 43.97022608348301, 37.105850560324534, 34.66634150913784, 34.18074928011213, 33.622326033455984, 34.5314804485866, 35.875988142830984, 34.40092727116176, 44.30719287054879, 50.10354689189366, 48.91962596348354, 51.275471755436485, 50.424195834568565, 51.01538678577968, 47.89609030314854, 47.982748235974995, 43.526976176670615, 41.83061170578003, 39.210150718688965, 41.62235334941319, 41.97429003034319, 50.59111588341849, 52.58678443091256, 54.238784653799875, 54.92783055986677, 51.2655462537493, 37.22230931690761, 15.113214356558663, 3.7107336606298174, 4.409039344106402, 1.3230008482933044, 0.0784381799665945, 0.32332706611071316, 22.850915908813477, 52.49302543912615, 39.05570616040911, 34.608157294137136, 30.490196228027344, 44.113081046513145, 56.444500718797954, 47.127140113285606, 13.45399842943464, 0.20860063657164574, 0.05215302256069013, 0.03285799042454787, 0.023083333857357502, 0.033299944030919244, 0.03348235120730741, 0.07052863296121359, 0.035229127654539685, 0.045158310394201956, 0.046614432973521094, 0.06980244442820549, 0.017719999687480073, 0.016139250581285784, 0.03871595626696944, 0.1086040148511529, 0.11139763851783105, 0.11453471625489847, 0.13652899462197507, 0.09291556597288166, 0.13468074665537902, 0.11459631366389138, 0.18445551076105662, 0.10049638311777796, 0.11516656806426388, 0.08065418712794781, 0.10731770244560071, 0.18486727295177324, 0.19327970940087522, 1.2138039363282067, 24.253925698144094, 57.819087164742605, 54.37079347882952, 48.99729640143258, 38.031774452754426, 29.990217753819056, 34.259454999651226, 43.34971373421805, 43.292873995644705, 7.002226046153477, 0.13912595169884817, 0.7712550918970789, 6.263968655041285, 10.733558944293431, 12.919307623590742, 6.837239767823901, 10.908331326075963, 30.116765294756206, 45.744639669145855, 52.0322903905596, 48.45275565556118, 48.9337933404105, 46.17789806638445, 43.67627559389387, 39.59260736192976, 36.13034432274954, 35.82275104522705, 37.04528658730643, 35.60208320617676, 36.10734578541347, 36.178811482020784, 37.066089493887766, 34.56969206673758, 41.57511602129255, 50.92731836863926, 44.736859049115864, 45.922954763684956, 49.387816429138184, 46.12888199942452, 43.28629057747977, 44.006280285971506, 43.57242781775338, 47.122321537562776, 50.782913957323345, 50.324280738830566, 47.82684455599104, 45.17926822389875, 45.48114660808018, 37.48893254143851, 35.84217473438808, 35.62709672110421, 34.95649133409773, 33.83500344412667, 34.84842947551182, 33.473572049822124, 34.653237206595286, 34.29066630772182, 34.81260803767613, 35.91203192302159, 34.17536095210484, 33.6482914515904, 35.53492191859654, 34.070088795253206, 34.66937787192208, 34.10215820584978, 35.56527859824044, 33.85207864216396, 35.89294522149222, 41.76982886450631, 41.188042300088064, 45.23653875078474, 47.79198544366019, 49.021872179848806, 41.32909073148455, 35.03807013375418, 41.79130574635097, 39.307814598083496, 44.610408782958984, 46.5873693057469, 45.74251699447632, 46.80082491465977, 44.34610973085676, 45.24241345269339, 47.269995076315745, 46.29971388408116, 44.69175134386335, 37.88961778368269, 37.360852922712056, 35.45512185777937, 36.96384327752249, 35.094576358795166, 36.83638899666922, 35.27362101418631, 34.49372741154262, 36.32732922690255, 38.63624341147286, 39.266087191445486, 41.063436780657085, 36.63487039293562, 36.41208335331508, 39.67376579557146, 46.838105474199565, 48.86377286911011, 49.18644373757498, 46.045972619737896, 47.17083733422415, 38.79661478315081, 36.86033943721226, 37.61531332560948, 36.30327456338065, 36.093438965933665, 36.899051325661794, 36.0852609361921, 45.50624350139073, 52.676530838012695, 51.24521235057286, 53.0534462928772, 53.59285579408918, 52.687995365687776, 50.504252978733604, 51.51680701119559, 47.24533939361572, 45.256653785705566, 42.12937034879412, 44.226996762411936, 44.45822238922119, 53.6289621080671, 54.75198207582746, 56.72436720984322, 56.69351373400007, 52.255789620535715, 41.157560552869526, 16.617230108806066, 6.29787369285311, 11.529378686632429, 1.3807555777685983, 0.2061757424048015, 0.5718351155519485, 25.851863724844797, 58.36481952667236, 47.805454526628765, 41.214952673230854, 35.806127480098176, 49.999244008745464, 62.98473930358887, 54.42702872412545, 17.931335960115703, 0.6374256759881973, 0.2205822350723403, 0.1355779463691371, 0.10833928441362721, 0.1497243565640279, 0.13445564944829258, 0.1766765953174659, 0.11917406373790332, 0.07409557620329515, 0.0755107356235385, 0.15538408500807627, 0.09664817353976624, 0.10246467071452312, 0.11377942535494055], [0.018677522860733525, 0.0369686064576464, 0.05132278407524739, 0.04464446600260479, 0.0243497838465763, 0.06671222631952592, 0.05596020451879927, 0.10789494575666529, 0.04257358730371509, 0.05551703294206943, 0.039424360397138765, 0.04049300555405872, 0.023225748179746524, 0.04876453402851309, 0.40493308859212057, 10.555324622562953, 39.6982547215053, 41.8031975882394, 37.77561174120222, 21.599328211375646, 10.906004548072815, 16.842188460486277, 32.26204592841012, 38.31593493052891, 7.702957953725543, 0.04871287715754338, 0.10509879115436759, 0.3974882023675101, 2.395783168928964, 3.893360112394605, 4.1520615220069885, 13.251988240650721, 28.035175323486328, 42.165084089551655, 47.42624964032854, 46.25806638172695, 45.60570349012102, 42.98178924833025, 43.303386620112825, 40.58016177586147, 37.07941613878523, 33.726670605795725, 31.29021876198905, 31.251843861171178, 33.26584870474679, 33.832453455243794, 31.85421446391514, 34.19138697215489, 44.0132006917681, 44.116787910461426, 42.12805713926043, 44.07789189474923, 41.74845620564052, 38.07643052509853, 37.060979093824116, 35.99455220358712, 34.73244319643293, 36.529657295772004, 40.159382343292236, 42.02079084941319, 42.717993940625874, 43.61650718961443, 38.69493137087141, 32.52851629257202, 31.808321612221853, 31.0599867275783, 31.304671015058243, 32.48127201625279, 31.93045357295445, 31.197276183537074, 31.87517023086548, 32.17505100795201, 33.562779971531455, 31.755223478589738, 31.115558419908794, 31.034973212650844, 31.959972994668142, 32.156176226479666, 34.15812941959926, 34.75443424497332, 32.638950960976736, 32.586728300367085, 32.988407135009766, 34.914840357644216, 40.51014477866036, 40.94728374481201, 42.586853640420095, 45.34619174684797, 36.158508845738, 31.95144408089774, 39.300095149448936, 41.92695542744228, 46.285511766161235, 44.49165712084089, 45.44828510284424, 42.80352973937988, 45.112502983638215, 43.78397614615304, 45.12645844050816, 42.25212069920131, 40.08868094852993, 32.36087015696934, 31.881284645625524, 31.736848967415945, 33.38136945452009, 32.502217360905235, 33.39215653283255, 32.854685579027446, 32.55369309016636, 32.802900654929026, 34.36565474101475, 32.92803423745291, 33.59522111075265, 33.42745338167463, 33.39455713544573, 37.205571106501985, 44.63973365511213, 45.54652220862252, 45.223389284951345, 43.593400955200195, 38.6847939491272, 35.186320372990195, 34.06357485907418, 36.156431334359304, 38.073595660073416, 38.65060881205967, 35.282010963984895, 34.94150754383632, 33.03914635522025, 39.29696498598371, 48.375807830265586, 48.792880398886545, 46.974759169987266, 47.13025638035366, 50.02928107125418, 50.249778679439, 45.54774161747524, 43.24324301310948, 37.97729710170201, 38.28818729945591, 37.73060825892857, 44.82031733649117, 51.652282987322124, 52.0256861277989, 52.59685237067086, 52.10226222446987, 34.36639472416469, 13.237699270248413, 1.7698309229952949, 1.8606719970703125, 1.0350818293435233, 0.06412900279143027, 0.3897921767617975, 20.911878653935023, 47.80653149741036, 39.89681339263916, 34.68798514774868, 33.42458724975586, 43.81948838915144, 47.04235471997942, 42.94913966315133, 12.78609676020486, 0.26538318821362084, 0.08137232823563473, 0.027879672291289483, 0.029208486434072256, 0.015876772880022014, 0.022525064081751874, 0.028573235164263418, 0.04015886776947549, 0.0410695499740541, 0.04602681825469647, 0.04761664955211537, 0.01844732985565705, 0.025389808396409665, 0.09940122081232922, 0.06168522499501705, 0.11300567151712519, 0.04574354345511113, 0.03131848267678704, 0.020835077622905374, 0.030446443041520457, 0.06047594667013202, 0.008648388520149248, 0.030995330374155725, 0.02588236884080938, 0.036476488757346354, 0.0647110433450767, 0.0440585408359766, 0.00942513469739684, 0.6078080566866058, 13.694321853773934, 47.07083191190447, 48.078428404671804, 43.506749970572336, 29.296658992767334, 16.049492801938737, 22.841402087892803, 39.847911970955984, 43.11696645191738, 8.312229854719979, 0.022434013163936988, 0.07586705471788134, 0.9652048817702702, 5.803908450262887, 5.912100153309958, 6.931436061859131, 17.11633137294224, 28.95638312612261, 42.078943797520225, 49.599451610020225, 48.71368135724749, 46.93912533351353, 44.13389090129307, 43.83979449953352, 41.02768135070801, 38.454263142177034, 35.51976094927107, 32.64153569085257, 32.74901042665754, 34.41092572893415, 35.163801261356895, 33.19202756881714, 35.98104837962559, 45.10947356905256, 45.150328976767405, 41.72968564714704, 45.305933884211946, 42.81158964974539, 40.33827066421509, 39.2509331703186, 37.57981845310756, 36.951291356767925, 39.060118266514365, 42.42081601279122, 43.477928842817036, 45.23537492752075, 44.10778651918684, 41.27414090292794, 33.969242640904014, 33.68364041192191, 33.39862183162144, 31.37184967313494, 34.633598123277935, 33.735414913722444, 33.20582321711949, 34.19479506356375, 32.89628791809082, 33.47857822690691, 32.54306582042149, 34.133793354034424, 32.217247417994905, 33.03499828066145, 32.821945667266846, 35.576913356781006, 34.91750151770455, 34.84576484135219, 34.007388251168386, 34.06770208903721, 36.6006817817688, 41.1563515663147, 42.5096035684858, 44.539964471544536, 46.93610634122576, 38.27587856565203, 33.41558238438198, 40.061864376068115, 42.58867059435163, 47.001968315669465, 46.328653131212505, 46.74861962454659, 44.7731807572501, 45.53898341315133, 44.11598539352417, 45.76233325685774, 43.26856572287423, 41.5043625150408, 34.14679690769741, 33.277261120932444, 33.5017226764134, 34.54411922182356, 34.344556535993306, 34.87793500082833, 35.0245280947004, 34.41130093165806, 35.15682874407087, 34.953694684164866, 35.09964506966727, 35.04795742034912, 34.63905593327114, 35.11034876959664, 38.511366912296836, 46.12817675726754, 48.13958297457014, 46.11209862572806, 46.383790561131065, 41.61813579286848, 36.3707936831883, 36.324900831495015, 36.50364671434675, 39.96867513656616, 38.94360045024327, 36.66826343536377, 35.487027985709055, 35.22961112431118, 43.29784543173653, 50.940089157649446, 50.34668867928641, 49.8988355909075, 50.2476282119751, 51.89969444274902, 51.32240683691842, 47.717653615134104, 44.73143250601632, 39.65025309153965, 38.819995471409385, 40.75458240509033, 47.58226796558925, 52.97503587177822, 53.6658535684858, 54.34365381513323, 52.97872189113072, 36.39716557094029, 14.11755747454507, 2.4625364669731686, 2.9442965473447527, 0.4349964511181627, 0.029539893115205423, 0.26433637152825085, 24.326249497277395, 53.02185978208269, 43.52827548980713, 39.048414025987896, 35.68799420765468, 48.21197278159005, 52.28110190800258, 49.203939301627024, 15.3062561580113, 0.3085930310189724, 0.04182289008583341, 0.10945567807980947, 0.0429196808753269, 0.11202482200626816, 0.044986009996916564, 0.030075138501290764, 0.028366811240890195, 0.03419378838901009, 0.021924402830856185, 0.045771190364445956, 0.03957397397607565, 0.023070022696629167, 0.042450161783822944, 0.1773156938808305, 0.24748202306883677, 0.16071409971586295, 0.13276801072061062, 0.11490539993558611, 0.14754539062934263, 0.2066191786101886, 0.1831561162003449, 0.09445455803402833, 0.11331731586584023, 0.11400925873645715, 0.18831823420311722, 0.24510951180543217, 0.14222669388566697, 0.9175912652696881, 18.16774841717311, 53.36712966646467, 53.630949292864116, 48.42735998971121, 32.50671284539359, 17.539617368153163, 22.90762710571289, 42.62410988126482, 49.315708024161204, 10.181933641433716, 0.15134951578719275, 0.21059483742075308, 2.238859406539372, 9.034007855824061, 8.988529290471758, 8.283713579177856, 16.95963212421962, 30.067947251456125, 43.44364990506853, 48.9109650339399, 50.026581696101594, 49.54143067768642, 46.209012099674766, 46.094154902866904, 44.72501237051827, 40.79814413615635, 37.725692408425466, 34.860387325286865, 34.34739140101841, 36.24519109725952, 36.505932671683176, 34.529864992414204, 38.24809619358608, 47.91982534953526, 46.59268120356968, 41.99332462038313, 47.60850783756801, 44.92398793356759, 42.90531390053885, 40.51178455352783, 39.50225298745291, 38.47110210146223, 40.022641795022146, 44.07273285729544, 45.28087520599365, 45.73145546231951, 48.3898605619158, 43.54066065379551, 35.50699363436018, 35.35185773032052, 35.53593635559082, 33.707906995500835, 35.96744728088379, 35.28962966373989, 34.73225212097168, 34.90327855518886, 35.146420342581614, 36.86833681379046, 34.81676653453282, 35.59633009774344, 33.41498136520386, 35.5437148639134, 35.1093030657087, 36.77641909463065, 38.314788477761404, 36.72660745893206, 36.24603877748762, 36.185089179447715, 38.562234674181255, 44.22631583895002, 45.531187534332275, 47.36890268325806, 47.55084821156093, 41.32277134486607, 36.386899607522146, 38.81593772343227, 43.03395979745047, 49.90342140197754, 49.21047060830252, 48.93685054779053, 47.31531817572457, 47.91753591809954, 46.83567360469273, 47.46391582489014, 45.5506911277771, 43.56078611101423, 36.75825997761318, 35.005934715270996, 36.36025326592581, 37.114615712847026, 36.49619824545724, 36.434876918792725, 37.94921595709664, 35.78983048030308, 36.70915010997227, 37.60353265489851, 36.183258329119, 36.97956705093384, 36.90231697899954, 37.26471069880894, 40.27226972579956, 49.85437754222325, 50.670537267412456, 47.363882609776084, 50.4685948235648, 43.16348464148385, 39.75787721361433, 37.231845719473704, 40.0873191016061, 43.30466161455427, 41.325529779706685, 38.63689306804112, 38.71851355688912, 36.4297456741333, 43.69660602297102, 52.63620696749006, 53.17316028050014, 51.922283036368235, 50.17738887241909, 52.52758577891758, 53.983612060546875, 49.61633920669556, 47.33808742250715, 43.241287095206125, 42.24524545669556, 41.95880944388253, 49.3896472794669, 56.79981075014387, 56.20004572187151, 57.003396442958284, 55.047054699489046, 38.1471597126552, 17.199982472828456, 3.9208797557013373, 6.873608376298632, 1.8872030419962746, 0.22057739033230714, 0.6686151623725891, 26.27477972848075, 59.70741299220494, 50.11207927976336, 47.844489506312776, 43.26670013155256, 55.94991752079555, 58.753807476588655, 56.80986131940569, 18.349918024880544, 0.6597947499581746, 0.22774330366935047, 0.14489701416875633, 0.14669597335159779, 0.23938897305301257, 0.10113993287086487, 0.136928760313562, 0.10837964367653642, 0.1125234706061227, 0.13004925660789013, 0.12650027418775217, 0.08211360738745757, 0.0987741458894951, 0.14377996910895618], [0.07566891570708581, 0.03634851366015417, 0.062022904732397625, 0.02099556302917855, 0.03167209780908056, 0.050555788446217775, 0.015577969806534904, 0.03088597088520016, 0.07656895169722182, 0.04578530050015875, 0.06045209616422653, 0.04324910623420562, 0.050776034127920866, 0.006164155193671052, 0.19645177918885434, 7.871263299669538, 31.650927543640137, 44.518577916281565, 40.33009263447353, 24.942658935274395, 24.8677955695561, 33.28402519226074, 30.86297403063093, 39.24129949297224, 10.107595733233861, 0.08926238771528006, 0.08691274308200393, 0.964497793998037, 4.454387630735125, 3.418247069631304, 8.655924235071454, 24.649488380977086, 33.1254221371242, 46.91346216201782, 48.42725229263306, 45.64993224825178, 46.25408158983503, 44.64219331741333, 45.02540384020124, 43.312700680324006, 40.759411403111045, 38.65868956702096, 35.4675417627607, 33.100321769714355, 33.30755179268973, 33.19955594199044, 31.803280694144114, 37.38084289005825, 46.04161957332066, 43.304390634809224, 42.11394534792219, 43.21003409794399, 39.34060314723423, 37.775830609457834, 33.76809923989432, 31.039659772600444, 30.816476685660227, 32.605960914066856, 35.50908851623535, 38.795933859688894, 39.40370668683733, 39.057029792240684, 34.14247512817383, 33.15199899673462, 33.7170855658395, 31.41757924216134, 33.2485476902553, 31.788772855486187, 32.0012800352914, 32.51235825674874, 33.903370244162424, 30.014734472547257, 31.70077739443098, 31.686453683035715, 30.127958842686244, 32.74181209291731, 34.15155642373221, 37.4492062159947, 36.25761447634016, 39.42007316861834, 37.15565872192383, 35.230681146894185, 35.010332924979075, 36.88273695537022, 38.971896989004954, 40.12934528078352, 43.01348345620291, 45.99267993654524, 35.74956914356777, 35.48158059801374, 48.35749237877982, 43.32013872691563, 46.33715772628784, 42.05426032202584, 42.645934173039024, 42.02012382234846, 43.32790681294033, 43.529241289411274, 44.21754373822893, 42.43388557434082, 35.766870158059255, 31.10049819946289, 32.985019888196675, 31.95806224005563, 33.12292773383004, 32.69128131866455, 33.35000876017979, 32.120031697409495, 33.085212911878315, 33.58127955027989, 33.88149731499808, 33.43496091025216, 33.86936923435756, 31.939058916909353, 34.04825060708182, 38.46922608784267, 45.2293438911438, 42.596928528376985, 45.49081155232021, 42.182722091674805, 40.145301818847656, 40.29868330274309, 41.91407694135393, 42.76799317768642, 44.69527408054897, 45.012758118765696, 44.28283248628889, 34.69146272114345, 34.399478571755544, 32.44377606255667, 38.21638114111764, 45.60713481903076, 48.088881969451904, 46.536088126046316, 48.285495144980295, 48.840162890298025, 48.310817854745046, 44.973181179591585, 41.04806389127459, 38.517884322575156, 41.38360629762922, 41.18761845997402, 46.58588933944702, 49.51784501756941, 51.764989716666086, 49.350591455187114, 35.12032290867397, 11.817037582397461, 2.865906970841544, 1.370096932564463, 1.2318537277834756, 0.08446206458445106, 0.16777365947408335, 23.069985662187847, 46.322187832423616, 36.81821250915527, 31.16648871558053, 28.568032673427037, 38.89785351072039, 50.38583830424717, 42.90647077560425, 7.3012304816927225, 0.2569344772824219, 0.12341471761465073, 0.06818566511252097, 0.0544800516217947, 0.04134805127978325, 0.03469137168888535, 0.088294600003532, 0.008378765845139111, 0.037148411452238045, 0.024359429221866385, 0.012348907317833176, 0.03688255125390632, 0.07644636077540261, 0.053424654861113856, 0.06939013940947396, 0.03711822342925838, 0.055147960782051086, 0.0316414551676384, 0.0031749622555383083, 0.04068408101531012, 0.05101264268159866, 0.028478613455912898, 0.06068694391953094, 0.073728875523167, 0.07836802623101644, 0.004768228424446923, 0.04703624087518879, 0.028406914356829863, 0.20745689794421196, 10.247776508331299, 38.71836069652012, 51.129326820373535, 45.271349225725444, 26.20916267803737, 20.67590914453779, 23.82763808114188, 34.52261454718453, 45.87704801559448, 11.14580772604261, 0.032467174609856944, 0.10606733203998633, 2.4458744696208408, 6.47077179806573, 2.9828662148543765, 11.776542612484523, 21.023984364100865, 31.05818019594465, 48.15627254758562, 47.23787008013044, 47.220336300986155, 47.996074880872456, 45.28843137196132, 45.763170514787944, 45.32363094602312, 42.490777424403596, 40.71857336589268, 36.45772954395839, 34.44933884484427, 35.09215838568551, 33.12124626977103, 33.54260587692261, 39.66087688718523, 45.60227802821568, 43.44626242773873, 43.26257290158953, 44.45419938223702, 40.775145598820274, 40.24875354766846, 34.628908089229036, 32.870145320892334, 32.97950996671404, 34.454737595149446, 38.14813593455723, 40.690467902592246, 41.79305321829659, 40.84520775931222, 37.12119565691267, 34.60620832443237, 33.72911637169974, 33.3121897152492, 34.94120529719761, 34.3110488482884, 33.657751423971995, 33.25817094530378, 35.48466212408883, 32.342419215611045, 31.654610088893346, 32.50320053100586, 32.26765659877232, 33.92161968776158, 35.07693140847342, 38.753393513815745, 38.16429744447981, 39.622797284807476, 38.04181112561907, 36.96687964030674, 36.87951299122402, 39.411075251443044, 40.63694592884609, 42.10403026853289, 43.69596331460135, 47.951172147478374, 37.588677406311035, 36.37405586242676, 47.584446225847515, 44.173711027417866, 49.111945152282715, 46.31719555173601, 45.5103429385594, 44.0055889402117, 46.486821923937114, 44.8132266998291, 44.73325988224575, 43.72084133965628, 38.02510070800781, 33.14096178327288, 35.086968081338064, 33.67286375590733, 34.73462840488979, 34.254959515162874, 34.63822214944022, 33.203961099897114, 34.62397139413016, 34.189292090279714, 34.836589745112825, 34.986948762621196, 34.667317731039866, 34.01116459710257, 35.783865451812744, 41.23873288290841, 46.94028568267822, 45.180744716099326, 47.0369142804827, 44.259298937661306, 41.8664539882115, 41.42121689660208, 43.48598527908325, 44.88054779597691, 44.62534046173096, 45.698857988630024, 44.39274256569998, 36.322131974356516, 35.97329766409737, 34.69631603785923, 41.775547231946675, 48.28273671013968, 48.98935808454241, 48.56540332521711, 48.44541140965053, 49.241327558244976, 49.53109870638166, 48.489848613739014, 43.049766949244905, 40.1804701260158, 42.285888944353374, 43.0617664882115, 48.14530481610979, 53.144700459071565, 53.761863776615684, 54.10053982053484, 37.28021560396467, 14.789800030844551, 2.287414069686617, 3.6755154132843018, 0.8035184549433845, 0.05874377568917615, 0.375651018427951, 24.271502903529576, 53.744458539145334, 41.737300872802734, 38.21323708125523, 37.316311495644705, 46.396095820835654, 55.178375652858186, 51.27363395690918, 10.603366204670497, 0.52552059505667, 0.12022985065621988, 0.04588803070198212, 0.022190659972173826, 0.04322019046438592, 0.03533921317596521, 0.08778551553509065, 0.018002148118934462, 0.038093505560287406, 0.019440074085390995, 0.0239216011084084, 0.03774791410458939, 0.05331029796174594, 0.05406524280884436, 0.12476360451962266, 0.17991753640983785, 0.2658729547900813, 0.30851668225867407, 0.12875006560768398, 0.11385866467441831, 0.12104593829384871, 0.1900436809020383, 0.19704502235565866, 0.16141090089721338, 0.23621986167771475, 0.08066452800163201, 0.11753214469977788, 0.10092774139983313, 0.33035267197660034, 12.022633910179138, 44.9035393851144, 56.782759870801655, 51.991268226078574, 34.75155421665737, 32.965672629220144, 44.05952433177403, 40.994156292506624, 49.770280020577566, 12.369980437414986, 0.16800001875630446, 0.21745676706944192, 5.536211294787271, 11.582284007753644, 9.783345886639186, 13.120598673820496, 27.136741978781565, 35.21593706948416, 48.366031714848106, 50.43173810413906, 47.491885798318044, 49.33211966923305, 48.124536650521414, 47.07382658549717, 47.87994268962315, 44.165571212768555, 43.355345249176025, 39.26379081181118, 36.78750841958182, 36.36553042275565, 35.58009215763637, 35.06220817565918, 42.24289001737322, 48.75875779560634, 43.6119978087289, 44.09803124836513, 46.42345782688686, 42.46431868416922, 41.61564833777291, 36.60040732792446, 33.90109470912388, 34.179192883627756, 36.20638540812901, 39.41563326971871, 42.42017330442156, 44.32396929604666, 43.039236954280305, 39.069654669080464, 37.93251248768398, 36.80714750289917, 36.01866940089634, 37.59158870152065, 36.553659847804475, 35.53214611325945, 34.813619000571116, 36.36713893072945, 33.28542872837612, 33.34071207046509, 35.02917643955776, 33.6759626524789, 35.765178271702354, 37.344368321555, 40.451693058013916, 40.38132865088326, 43.447158745356965, 42.355263233184814, 39.132389954158235, 38.44243383407593, 41.26158898217337, 42.01669488634382, 43.59927913120815, 47.06288317271641, 49.85521480015346, 39.150705405644004, 38.77941451753889, 48.28486285890852, 47.69624968937465, 50.25503499167306, 48.17127023424421, 46.9185517174857, 45.789420809064595, 47.32811328342983, 47.4687100819179, 47.308429036821636, 47.02514403206961, 40.19778503690447, 35.95084803444998, 36.94791453225272, 36.203758989061626, 38.49142210824149, 35.84968226296561, 37.246621063777376, 35.59210559300014, 36.60942261559622, 36.919228894369944, 36.16685363224575, 36.88538769313267, 37.09790876933506, 35.527348382132395, 38.15656409944807, 43.83756760188511, 50.21203259059361, 46.20402676718575, 49.15531233378819, 47.09504638399397, 44.32843351364136, 45.202885150909424, 45.047735350472585, 47.364716393607004, 46.96904080254691, 48.54437460218157, 47.96237959180559, 38.61859846115112, 37.34946829932076, 36.523654052189414, 41.53768607548305, 50.07773086002895, 51.941671984536306, 51.83966200692313, 49.63913624627249, 49.77983726773943, 51.65012557165963, 49.01097740445818, 45.39779601778303, 41.88404335294451, 46.07574217660086, 45.34390231541225, 51.33408675874983, 54.954504694257466, 57.48806456157139, 55.596004077366416, 39.321248940059114, 14.065873299326215, 4.897740457739149, 3.8319923196520125, 3.68229946068355, 0.22308176809123584, 0.5060898491314479, 27.75677490234375, 56.84178481783186, 48.31940235410418, 41.62970454352242, 40.21581561224801, 52.752061230795725, 61.821999958583284, 59.357175145830425, 13.55659466130393, 0.6394232830830983, 0.22106563699032578, 0.19164040950792177, 0.19662541630012648, 0.12299710645207337, 0.12114747427403927, 0.12220191769301891, 0.09116292359041316, 0.09941913413682155, 0.17567973238016876, 0.2090704542185579, 0.1209694402558463, 0.1677835660853556, 0.1889470868877002], [0.05050603825865047, 0.06486709282866546, 0.06357877195945807, 0.04022108264533537, 0.07662837779415504, 0.03032903273456863, 0.03441255147169743, 0.06383409111627511, 0.032787409211908064, 0.012898708976406072, 0.013454849000221916, 0.06636695377528667, 0.023244811621095453, 0.0671873636809843, 0.0428646584706647, 4.867960912840707, 27.87090253829956, 45.13412577765328, 44.94251530511038, 34.0871570450919, 20.730306591306412, 35.190506662641255, 41.200785296303884, 36.9782121522086, 13.994464056832449, 0.042693718536091704, 0.18889364546963147, 0.9554056418793542, 5.129838951996394, 3.065264467682157, 11.487300395965576, 22.474637951169694, 34.46426010131836, 47.19428750446865, 48.07379048211234, 48.68758739743914, 46.84758281707764, 45.59811953135899, 45.185177666800364, 44.57618890489851, 42.99077674320766, 40.920557498931885, 40.65674482073103, 33.11721978868757, 32.33284459795271, 31.733659744262695, 33.697557653699604, 42.290554659707205, 43.59865379333496, 42.90735667092459, 42.501126766204834, 43.93126405988421, 37.35903249468122, 36.43078442982265, 33.19189902714321, 32.2277808870588, 31.02771929332188, 32.29062039511544, 33.37494584492275, 33.53307294845581, 33.90274143218994, 34.275633880070274, 32.13903502055577, 32.05606310708182, 30.907560620989116, 33.14983810697283, 32.23730339322771, 31.344637053353445, 32.011691910879954, 32.22711385999407, 33.1278018951416, 30.042968477521622, 32.133212430136545, 32.23759869166783, 30.887278829302105, 33.58899205071585, 37.58999061584473, 40.205935273851665, 44.8000876562936, 42.67232690538679, 40.4297263281686, 38.20178297587803, 36.761994634355815, 35.557197843279155, 39.07848235539028, 41.31922081538609, 41.92008713313511, 44.739843300410676, 35.41464512688773, 38.24862078257969, 46.683528900146484, 41.58041054861886, 43.519423484802246, 41.426657336098806, 39.9782532283238, 40.97141136441912, 43.640082427433555, 42.3133100100926, 42.98985263279506, 38.221467222486226, 32.874946526118684, 32.8428111076355, 34.32783569608416, 31.889254229409353, 32.8618700163705, 33.022957052503315, 33.14099999836513, 32.627698353358674, 32.49386215209961, 32.640219007219585, 33.85963828223092, 32.476571559906006, 33.501861640385215, 31.80723421914237, 31.34348017828805, 38.926799706050325, 45.13876370021275, 44.59078359603882, 43.52456167766026, 44.63327183042254, 46.60326678412301, 45.21832752227783, 44.01522609165737, 41.15833180291312, 43.03660706111363, 42.68658460889544, 43.606331552777974, 48.064980166299, 35.71786798749651, 32.27322210584368, 31.884185518537247, 38.24597699301583, 45.90322535378592, 49.12768629619053, 48.71049908229283, 49.00173282623291, 51.49070610318865, 46.352141516549246, 42.50871767316546, 44.90140628814697, 46.83310277121407, 47.401899678366526, 46.92939785548619, 49.93628290721348, 50.66332851137434, 50.54954481124878, 33.73019681658064, 11.913691367421832, 0.6737626918724605, 2.5602880673749104, 0.05392221101958837, 0.06524526075060878, 0.4035445073885577, 22.549846989767893, 49.67902932848249, 40.39570794786726, 30.02387135369437, 28.097754274095806, 41.5178177016122, 48.77295643942696, 44.79688801084246, 9.288414410182408, 0.019326989439183047, 0.032697130127676895, 0.004387323037787739, 0.03759467036330274, 0.033651832291590314, 0.09235595778695174, 0.06521808542311192, 0.02811567864513823, 0.08521335891314916, 0.0372790633700788, 0.02076833352579602, 0.06810588975037847, 0.05481483740732074, 0.050010571988033395, 0.02476673004483538, 0.07131403045994894, 0.058513433406395574, 0.023137455506782447, 0.048905252013355494, 0.079144480638206, 0.0546132887580565, 0.01840158811371241, 0.041686541866511106, 0.04915589606389403, 0.019727094398279275, 0.07734119240194559, 0.06767971547586576, 0.036496977122234445, 0.048531084055347104, 6.140517839363643, 34.12259285790579, 49.86437947409493, 50.66199098314558, 37.4892486844744, 25.917741332735332, 39.04603426797049, 39.230001722063335, 41.30086020060948, 14.164808699062892, 0.06262957610722099, 0.16250787489116192, 3.1303719111851285, 4.946346146719796, 4.800139112131936, 8.411987747464861, 19.335268122809275, 35.85756499426705, 48.724055017743794, 49.553909642355784, 49.34278167997088, 46.84943103790283, 46.29416227340698, 48.27867201396397, 46.82756853103638, 44.69927624293736, 42.36699526650565, 42.33365086146763, 34.05884313583374, 34.56601299558367, 32.77380507332938, 36.040452003479004, 42.996265820094514, 45.54140486036028, 42.48038639341082, 42.76847955158779, 45.681039333343506, 39.516302245003835, 38.52002089364188, 35.321309975215364, 33.62848561150687, 32.276998451777864, 33.80995518820626, 33.92522232873099, 36.04178605760847, 36.36988694327218, 36.4128407069615, 34.08258165631975, 33.439171518598286, 32.53323759351458, 34.59235709054129, 33.78481313160488, 32.45824916022164, 32.96513066973005, 33.55205542700631, 35.09345422472273, 32.84297439030239, 33.31605291366577, 33.62351764951433, 32.6083128792899, 34.33829273496355, 40.573314326150076, 42.00683886664254, 45.91993229729788, 44.71094921657017, 42.63276733670916, 40.05923448290144, 39.01371124812535, 37.38765907287598, 40.316085066114155, 42.467837946755544, 44.161728858947754, 45.06674214771816, 35.90176943370274, 38.90876913070679, 50.140334129333496, 43.03241382326399, 44.198172160557334, 43.098466873168945, 42.37969657352993, 42.49180228369576, 45.0564866065979, 43.441148553575786, 44.39523696899414, 40.45504208973476, 33.99417972564697, 33.43929311207363, 35.168637207576204, 33.82223265511649, 34.50252383095877, 34.21019227164132, 34.73944698061262, 34.83096170425415, 34.59990283421108, 34.540266445704866, 34.90359122412545, 34.22767741339547, 36.110983167375835, 33.40417691639492, 33.56985323769705, 41.440345287323, 47.024084431784495, 45.972877570560996, 44.47019066129412, 48.11083827699934, 48.226643902914866, 47.74304233278547, 47.29947280883789, 44.790471349443706, 45.39158085414341, 44.085291726248606, 45.67350401197161, 48.97816801071167, 37.3897192137582, 33.555595534188406, 34.82317624773298, 40.93037877764021, 47.40226098469326, 51.031989506312776, 49.906145095825195, 50.682561125074116, 52.947573116847444, 48.57603406906128, 43.91609614236014, 45.713720185416086, 47.658201353890554, 49.32255547387259, 49.29647193636213, 51.23253188814436, 52.343041624341694, 53.56875944137573, 36.39965650013515, 12.759680577686854, 2.315656977040427, 2.354295475142343, 0.7297749434198652, 0.045708090000386746, 0.3256964289716312, 25.031147718429565, 53.10390411104475, 45.634354387010845, 30.524819101606095, 28.437703575406754, 47.45921189444405, 54.125032220567974, 51.609794752938406, 11.828225919178553, 0.12506671968315328, 0.05039011733606458, 0.03627184938107218, 0.0579052081863795, 0.022663291843075837, 0.04048857132771185, 0.0319851976154106, 0.03149420289056642, 0.029711721930652857, 0.0880522680069719, 0.007559845323807427, 0.02339008596858808, 0.015896557264828255, 0.03607595292851329, 0.1488050908914634, 0.21170755342713424, 0.2309313326009682, 0.11281624489596911, 0.19869158257331165, 0.2171115284519536, 0.10359767491796187, 0.21847157047263213, 0.08495928826076643, 0.178933891334704, 0.12941467708774976, 0.18328559425260338, 0.09449651185423136, 0.19574094590331825, 0.14305266099316732, 6.799455463886261, 39.52387578146798, 57.3049065726144, 56.50746529442923, 45.43843603134155, 29.43480655125209, 41.2313608442034, 49.517997877938406, 46.642239230019705, 18.262077161243983, 0.16380014483417782, 0.26432907049145016, 3.6667528663362776, 12.280864579336983, 9.024726799556188, 16.711716924394878, 24.718266861779348, 38.268072264535085, 50.30477367128645, 50.74753720419747, 52.19107757295881, 48.566931928907124, 48.06652614048549, 49.056342193058555, 47.33544710704258, 46.801154954092844, 44.69387401853289, 45.29241268975394, 36.37207909992763, 36.29335600989205, 34.62607322420393, 36.81520741326468, 46.19766916547503, 45.88273859024048, 43.501431124550955, 45.00948551722935, 47.780705043247764, 41.486168657030376, 40.2856137411935, 37.43819332122803, 36.35944727488926, 33.95396702630179, 35.749763693128315, 36.08308962413243, 37.75573294503348, 37.87740979875837, 38.170675890786306, 35.54680681228638, 35.40453897203718, 33.462441035679404, 36.70659664699009, 35.22755445752825, 34.226843629564556, 34.68195758547102, 34.80439874104091, 37.3647369657244, 33.81172003064837, 35.46441159929548, 36.846658434186665, 34.854821818215505, 37.558939116341726, 41.846464020865305, 44.75837067195347, 48.23353999001639, 46.29355083193098, 44.670882429395405, 41.60424634388515, 40.03042377744402, 39.70200327464512, 42.9426326751709, 45.25815807070051, 46.40329415457589, 46.40314824240548, 37.59954786300659, 42.901158877781455, 52.258155482155935, 46.357731342315674, 46.822909763881135, 45.036041532244, 44.6160819871085, 46.017245292663574, 47.50747408185686, 45.984797205243794, 46.71028988701956, 42.71437045506069, 35.27843264171055, 34.38671473094395, 39.137965883527485, 35.34700093950544, 36.601915087018696, 37.18561588014875, 35.85128729684012, 36.45419291087559, 36.59509890420096, 37.36961807523455, 36.91436168125698, 35.434999874659944, 36.97024604252407, 34.684524944850374, 35.16886649812971, 43.194654260362896, 49.90073939732143, 47.99797521318708, 45.83961806978498, 48.188098771231516, 51.117535727364675, 50.72381258010864, 50.46842111860003, 46.59936537061419, 44.70909404754639, 45.56901005336216, 47.28941529137747, 53.43718487875802, 39.13821949277605, 35.48852184840611, 35.87035662787301, 43.43958868299212, 49.94659055982317, 52.8467686516898, 50.793641975947786, 51.1364244052342, 54.10540008544922, 52.53613206318447, 45.427753176007954, 49.151063510349815, 50.43917267663138, 52.238200255802695, 50.54535852159773, 55.094552585056846, 53.9872077533177, 55.10850804192679, 37.850169386182515, 15.11661376271929, 2.9987771553652625, 7.957194277218409, 1.2094569695847375, 0.21692957250135286, 0.5926841625145504, 27.16697359085083, 60.84693840571812, 51.41677379608154, 41.860019956316265, 36.976638385227744, 53.72353751318795, 60.78629452841622, 61.034671783447266, 15.332061767578125, 0.2380257419177464, 0.18686166379068578, 0.13258627190121583, 0.13389522023499012, 0.15376590112490313, 0.10245482517140252, 0.09954318390893084, 0.15422815989170754, 0.26308268308639526, 0.17617097816296987, 0.08875293005257845, 0.08472271702651467, 0.14999358568872723, 0.1741684449038335], [0.030112152586558034, 0.05048336501100233, 0.017748676273705702, 0.026112979144922326, 0.0068430752809425545, 0.027660398611000607, 0.023281528847292066, 0.01962925134492772, 0.049925358167716434, 0.04664775582828692, 0.025651741573320966, 0.04138600513605135, 0.04357019239770515, 0.03999863851017185, 0.009485862733397101, 1.402947689805712, 24.13408316884722, 46.451570238385884, 43.820718220302034, 30.28742000034877, 16.194145611354283, 26.78571551186698, 42.38744381495884, 38.20875201906477, 20.29146010535104, 0.28273723700216835, 0.14868265603269848, 2.3222460406167165, 3.5899387938635687, 2.7385054528713226, 9.16615651335035, 19.31582532610212, 37.03715372085571, 53.2347525869097, 45.76279183796474, 47.51141023635864, 47.54965312140328, 46.89301013946533, 43.696988173893516, 47.230539730616975, 45.5355475289481, 44.560732637132915, 43.94572673525129, 36.07016944885254, 31.58829300744193, 33.16072246006557, 36.112682001931326, 43.46299021584647, 43.468382017953054, 42.04626989364624, 41.29412739617484, 42.587239265441895, 38.54992594037737, 37.75927652631487, 35.464543615068706, 32.60251808166504, 31.87350266320365, 31.199989455086843, 30.700896876198904, 30.993044308253697, 30.9735198702131, 31.995912551879883, 31.65554462160383, 34.935615471431184, 33.81518370764596, 31.808988639286586, 31.42404454095023, 30.95947061266218, 32.060263293130056, 32.09418092455183, 30.69016538347517, 32.04099246433803, 31.443541186196462, 32.4366055216108, 31.324098178318568, 35.36150530406407, 40.37692696707589, 43.24572352000645, 41.24237721306937, 38.848559515816824, 42.425631114414756, 42.12476716722761, 41.46496275493077, 39.417936597551616, 42.25150578362601, 42.934739521571565, 45.450734342847554, 42.98918213163103, 37.6039981842041, 39.023914677756174, 45.199164390563965, 40.83948244367327, 40.1928448677063, 36.29942873546055, 35.97981507437569, 36.054087843213765, 36.75641523088728, 36.342059407915386, 37.251147815159385, 33.71898242405483, 31.58238009044102, 33.78069632393973, 34.23588671003069, 33.78554269245693, 31.933875560760498, 31.70987606048584, 32.505708830697195, 31.96193586077009, 32.03677838189261, 32.08408866609846, 33.85556663785662, 32.4323810168675, 33.15087686266218, 31.97336564745222, 33.672766481127056, 40.9091728755406, 44.55750172478812, 44.03461503982544, 44.32175976889474, 41.17900616782052, 42.04543958391462, 42.47777039664132, 43.59830290930611, 44.62324210575649, 46.52066312517439, 42.356128283909385, 43.82050282614571, 45.05712236676897, 47.04249368395124, 36.126411642347065, 33.069801807403564, 34.536417143685476, 38.976639134543284, 46.49596922738211, 48.40466717311314, 48.39052758898054, 49.695923873356406, 48.33378165108817, 45.98543643951416, 47.35198381968907, 48.225612095424104, 49.27061421530587, 51.727882862091064, 51.7205525125776, 54.730220317840576, 48.7990608215332, 29.959194047110422, 9.500624554497854, 1.0402365241731917, 4.580564745834895, 0.6166649471436227, 0.04472143901512027, 0.40430500943745884, 21.78944308417184, 50.331096921648296, 34.45628704343523, 34.84461144038609, 37.79694618497576, 40.29074845995222, 50.346111978803364, 44.307918957301546, 6.855103586401258, 0.059583360994500775, 0.08955470738666398, 0.07231396716088057, 0.012542299976173257, 0.03702499271769609, 0.06514220485197646, 0.023872500618121455, 0.10203652868845633, 0.020417286648548076, 0.10170132560389382, 0.015308815320687634, 0.029014401670013155, 0.03449544470225062, 0.07397495303303003, 0.02595159807242453, 0.024891823064535856, 0.02239205764739641, 0.02328148134984076, 0.03662109814052071, 0.018771788338199258, 0.06851948398564543, 0.02234698595878269, 0.04849759156682661, 0.02880952480648245, 0.01935640732491655, 0.022915172523685863, 0.01731386424840561, 0.06310909001954965, 0.026916851455877935, 2.5336814607892717, 29.342107159750803, 52.30000795636858, 48.1381516456604, 35.712417125701904, 18.467794213976177, 30.245703016008648, 48.21965748923165, 43.23487390790667, 21.47105230603899, 0.2522301397153309, 0.08039777552975075, 1.3222540255103792, 3.716627904347011, 3.4669309258461, 8.946452736854553, 18.10965973990304, 39.807428291865754, 53.67270449229649, 50.35386616843087, 48.29150881086077, 49.42710849217006, 47.0949421610151, 47.185289587293354, 48.1403785433088, 45.65440341404506, 46.91820083345686, 44.562198707035606, 37.24350132261004, 34.36035673958914, 34.42781679970877, 37.45326048987252, 45.163499287196565, 44.84338188171387, 42.52383347920009, 42.397060121808735, 42.97889184951782, 40.5271053314209, 39.606211934770855, 36.59018305369786, 34.21110943385533, 32.721314907073975, 32.940471512930735, 31.867339611053467, 31.396877084459575, 32.53331749779837, 33.8041603905814, 33.23570047106062, 35.9289334160941, 35.90292978286743, 34.15090676716396, 32.84001098360334, 33.10919809341431, 35.69555732182094, 33.299762862069265, 32.421003341674805, 33.209936550685335, 32.961882386888774, 34.79949331283569, 33.59102092470442, 36.6823787008013, 41.31019857951573, 42.896416732243125, 44.707495961870464, 40.70731381007603, 43.25097983224051, 44.9687100137983, 43.011805466243196, 42.159876414707725, 42.4132980619158, 45.130689893450054, 46.66032886505127, 43.798998151506694, 38.06206512451172, 40.21377631596157, 46.41028751645769, 42.91731343950544, 42.50119277409145, 37.736514227730886, 38.13957575389317, 37.749111311776296, 39.35366576058524, 38.287565435682026, 40.001682553972515, 35.96870837892805, 34.2294978414263, 35.40440000806536, 35.43229702540806, 34.618096692221506, 34.638409750802175, 33.33596645082746, 34.18678726468767, 33.24628257751465, 34.904650824410574, 34.07213503973824, 36.80388879776001, 33.72272055489676, 34.43782567977905, 33.03336545399257, 35.99807146617344, 42.254514353615896, 45.521908215114046, 47.349555424281526, 44.71846716744559, 43.01580762863159, 45.53584977558681, 44.512859548841206, 45.94453934260777, 46.583474840436665, 46.87908247538975, 42.409931659698486, 45.261993476322715, 47.4817726952689, 47.996825286320274, 36.17659500667027, 34.586531026022776, 35.72761978421892, 40.51651975086757, 48.38297489711216, 50.305009910038535, 48.82190997259957, 51.60145344052996, 50.50027860913958, 48.08729778017317, 48.92390605381557, 50.11145741598946, 51.747973578316824, 54.066139289310996, 53.08985832759312, 55.17556858062744, 50.829366139003206, 33.3921982220241, 11.930852549416677, 2.884669712611607, 5.980959406920841, 0.5124692725283759, 0.044870177283883095, 0.3031833970120975, 24.307124580655778, 55.12674706322806, 41.663083689553396, 36.390457085200715, 38.73642948695591, 46.836656774793354, 55.748635155814036, 49.82037305831909, 9.815114787646703, 0.11652537515120846, 0.04224837225462709, 0.053807236653353484, 0.04441913470093693, 0.02928737291534032, 0.045092628204396794, 0.03408676306051867, 0.030691896299166337, 0.04172368487343192, 0.03264671836846641, 0.03458697907626629, 0.02339918173051306, 0.06768571372543063, 0.0010401296167401597, 0.11037990384336029, 0.08214181408818279, 0.1486176795193127, 0.14085419396204607, 0.08427092805504799, 0.11162665087197508, 0.2825325094163418, 0.08678447282207863, 0.1547021573143346, 0.12449428040002074, 0.12663702613541059, 0.1205283517816237, 0.1027615704972829, 0.12623807468584605, 0.1747855453618935, 2.8698848145348683, 33.27943590709141, 59.25248663766043, 53.72950254167829, 41.70314352852957, 25.45816489628383, 34.69693442753383, 51.97967515672956, 48.5993070602417, 26.377998692648752, 0.49404786101409365, 0.45240402274898117, 5.034978670733316, 12.13835094656263, 6.762359465871539, 14.088902235031128, 21.715238060270035, 38.68166378566197, 58.098397799900596, 51.38365173339844, 50.13106870651245, 50.979054655347554, 50.32358591897147, 47.8822877066476, 51.097667353493826, 48.5166825566973, 50.140813555036274, 46.93604033333914, 39.30806820733206, 34.82468400682722, 36.6726199558803, 39.604332447052, 48.089163371494834, 45.441851070949006, 43.50481489726475, 42.369600840977256, 46.20692764009748, 43.66670445033482, 42.06483200618199, 38.62792294366019, 36.364001819065635, 34.013909135546, 34.94045489174979, 34.178254876817974, 33.2498574256897, 33.469465664454866, 35.4629351070949, 33.87138073784964, 39.48125205721174, 36.55928094046456, 35.3841564314706, 34.459583963666645, 34.47274732589722, 35.806641646793906, 35.01573167528425, 32.792902197156636, 35.32787602288382, 34.35579524721418, 36.65834140777588, 35.356068338666645, 39.78280735015869, 43.684269496372764, 45.193223680768696, 43.915338788713726, 41.95218433652605, 46.40540293284825, 47.190615381513325, 45.46076059341431, 43.52819211142403, 46.54443986075265, 48.53232989992414, 48.187066963740754, 45.89352566855294, 40.43926273073469, 42.59716476712908, 46.782745701926096, 46.30568586077009, 43.1215626852853, 40.72084195273263, 40.339118344443186, 40.33828108651297, 41.37764821733747, 40.77605581283569, 42.13525199890137, 38.136984075818745, 36.23427200317383, 38.15856170654297, 36.76120253971645, 36.650687967027935, 35.83174548830305, 35.219438961574006, 35.76376778738839, 35.55597496032715, 35.88126182556152, 35.90991619655064, 40.222065516880576, 35.57769502912249, 35.87148223604475, 33.738281045641216, 36.899033955165315, 43.835830552237375, 47.6407196862357, 48.43238353729248, 45.74718270983015, 46.277358055114746, 47.358678409031455, 46.70985215050833, 46.66294486182076, 47.70421232495989, 49.41687726974487, 44.757592473711284, 43.96690831865583, 50.51560980933053, 51.853363854544504, 39.83101395198277, 36.83643763405936, 37.93888051169259, 41.85152578353882, 50.16484389986311, 53.21891416822161, 48.86668069022042, 52.8524557522365, 52.50304821559361, 51.02787617274693, 52.3976058278765, 52.073017256600515, 54.81957067762102, 54.92589896065848, 56.305971009390696, 58.45967633383614, 52.626125131334575, 33.074672494615825, 12.3338463306427, 3.0205430388450623, 10.047437361308507, 1.4541993396622794, 0.20494683406182698, 0.4921625107526779, 26.824206795011246, 61.57500539507185, 46.69236353465489, 46.15346820013863, 50.213557720184326, 51.00489500590733, 60.76930618286133, 59.22390174865723, 12.843409844807216, 0.2598918585905007, 0.13453982850270613, 0.15372543329639093, 0.0715727490772094, 0.20325920890484536, 0.14956855135304586, 0.0890116486698389, 0.1966272076325757, 0.13548559775309904, 0.14488326704927854, 0.10356446062879902, 0.12789272304092134, 0.17700867035559245, 0.13731635308691434], [0.040585167572966645, 0.05152389506942459, 0.040529497167361636, 0.08771891053766012, 0.03720774933961885, 0.06918465186442647, 0.038172897550144365, 0.021550465574754134, 0.02134182962722012, 0.08396112932158367, 0.04393808051411595, 0.029459225479513407, 0.0385047724204404, 0.059173661550240855, 0.1002453455169286, 0.49753677951438086, 16.372627462659562, 46.13776527132307, 48.37217392240252, 36.78600066048758, 23.917490448270524, 21.92134247507368, 21.937041929789952, 42.79034900665283, 24.092446088790894, 1.1635056010314395, 0.022419121016615202, 3.9912919316973006, 1.3536653114216668, 3.5067710280418396, 3.340908191033772, 19.81711527279445, 40.966571944100515, 47.17344985689436, 47.86439609527588, 45.902276924678254, 45.30294268471854, 47.18574469430106, 45.31657157625471, 45.25624731608799, 44.924620219639365, 43.86960574558803, 43.93041637965611, 35.78868055343628, 31.606681415012904, 34.104371207101, 37.70804050990513, 42.02623128890991, 44.662186758858816, 43.008425167628694, 40.65428168433053, 44.29446029663086, 40.74325336728777, 38.00840071269444, 37.58031872340611, 33.77414069856916, 32.67743008477347, 31.263280596051896, 30.11461135319301, 31.832035814012798, 30.18231460026332, 32.14775153568813, 32.07616771970476, 31.326283386775426, 31.81684705189296, 31.650451592036656, 31.796231746673584, 33.35660260064261, 31.7711626461574, 31.334475312914165, 31.18190676825387, 31.344598838261195, 31.049991743905203, 31.206364427294048, 29.547554969787598, 36.664778913770405, 41.02318239212036, 46.306728090558735, 34.16864204406738, 41.07947669710432, 41.23922620500837, 41.59856966563633, 42.49720450810024, 41.114572048187256, 44.04900128500802, 43.51693950380598, 40.82402270180838, 40.44452599116734, 38.28472709655762, 39.340151514325825, 45.63488245010376, 40.184548718588694, 39.41551167624337, 34.484090260096956, 34.194833278656006, 32.908134596688406, 32.88035569872175, 31.189118998391287, 31.884303637913295, 31.142639023917063, 33.60872840881348, 33.14979641778128, 33.4631393296378, 32.139497075762065, 32.859066418239046, 32.18486533846174, 32.13080140522548, 33.40429503577096, 32.884576729365754, 32.73148706981114, 32.41871043613979, 34.46204710006714, 33.339878286634175, 33.2131917817252, 30.623278549739293, 37.506844997406006, 44.29796913691929, 44.769651072365896, 43.65818248476301, 41.92958532060896, 45.59222745895386, 44.750314235687256, 46.967307226998464, 47.76891395023891, 47.69717032568795, 45.53328241620745, 47.68028620311192, 46.919493198394775, 47.977405071258545, 45.5530743598938, 34.117913246154785, 33.596815722329275, 37.359984397888184, 42.11375079836164, 51.8745767048427, 49.026784556252615, 51.08495909827096, 48.8507901600429, 48.02652883529663, 47.9709849357605, 51.3225735936846, 51.19749559674944, 54.6717894417899, 48.44767304829189, 50.58572408131191, 44.62019879477364, 24.630332197461808, 4.240928547722953, 2.8573787084647586, 0.7865353748202324, 0.9024385469300407, 0.22191204157258781, 0.11723862402141094, 23.205129861831665, 45.64248030526297, 45.12408215659005, 30.45430530820574, 21.720801830291748, 34.07805143083845, 44.54660694939749, 41.8986554145813, 5.5942352669579645, 0.15779835331652844, 0.07560851251972572, 0.013900322507002523, 0.013384633348323405, 0.045051318992461474, 0.01623945663283978, 0.017719974242416874, 0.03805413356583033, 0.07608962098934821, 0.04342297404738409, 0.014752246971641268, 0.05471939127892256, 0.051787957149956904, 0.030233868198203187, 0.027161402261949012, 0.02564973819867841, 0.028754940056907277, 0.050879744812846184, 0.015303911208840353, 0.028945401443966796, 0.037192489087049446, 0.01730491776418473, 0.0351111914829484, 0.06600146767284189, 0.028983901520924907, 0.0174502701432045, 0.06480349374136754, 0.04064128581168396, 0.03696018923074007, 0.7658480906060764, 21.95326771054949, 53.57260874339512, 53.772654329027446, 42.857743058885845, 24.606081247329712, 25.068541186196462, 31.797176701681956, 46.90830659866333, 26.675048078809464, 1.0912164343254906, 0.11290874278971127, 2.8415958753653934, 1.7381709132875716, 4.984615521771567, 5.07379651921136, 17.418393884386333, 40.91837576457432, 48.647975717272075, 49.150893279484336, 49.905328682490754, 46.700096879686626, 49.232597146715435, 46.09426259994507, 46.48774256025042, 47.001846722194124, 46.47045544215611, 45.48909534726824, 38.27534008026123, 33.516689096178325, 35.44301462173462, 39.060583795819966, 44.755535806928364, 46.02494042260306, 44.17114019393921, 40.675744669778005, 45.45213093076433, 41.34097909927368, 39.982321398598806, 39.025311265672954, 35.82561022894723, 34.38342128481184, 33.08992379052298, 32.50586516516549, 33.37764869417463, 32.42282376970564, 33.09547887529646, 33.09926911762783, 33.66607536588396, 32.817040239061626, 32.285808767591206, 33.57771512440273, 34.79575865609305, 32.16417012895857, 34.01793909072876, 33.61029175349644, 33.3420843396868, 32.14675794328962, 33.552583490099224, 30.32039267676217, 38.98616164071219, 41.49512488501412, 47.40354987553188, 37.40398039136614, 43.43637861524309, 45.24833331789289, 43.9357248033796, 46.67061219896589, 42.88585547038487, 45.09828349522182, 43.68142073495047, 43.216888495853965, 40.67063774381365, 38.819387504032676, 41.07346303122384, 47.7324914932251, 42.49854898452759, 41.18625313895089, 36.447876998356406, 36.64638008390154, 36.22094535827637, 34.008562496730256, 33.27039630072457, 34.388423987797324, 33.8343676839556, 34.573485783168245, 34.52157926559448, 33.67138726370675, 33.56654242106846, 33.531464440482004, 33.77389056341988, 33.80853080749512, 35.207672187260215, 35.609396185193745, 33.564186981746126, 33.589304719652446, 35.42426143373762, 34.13043737411499, 34.94869892937796, 32.494070598057334, 39.45659984861101, 46.55683544703892, 45.57149403435843, 45.2321891784668, 43.26433079583304, 46.53803709575108, 47.42202860968453, 49.00179188592093, 47.518358434949604, 48.76741177695138, 47.091811997549875, 47.263606207711355, 48.04229429789952, 50.67875351224627, 45.72221088409424, 36.37397248404366, 34.92283078602382, 38.569026538303916, 45.164329596928184, 53.326538290296284, 49.949175289699006, 52.93826947893415, 51.22131749561855, 49.34175682067871, 51.64319821766445, 54.168913568769185, 52.573054790496826, 55.59864786693028, 51.36580181121826, 54.46178361347744, 46.65058749062674, 24.85632583073207, 5.263843647071293, 2.85821379508291, 4.372051911694663, 0.7748520874551365, 0.03444503972839032, 0.11921359518808977, 24.472866909844534, 52.10281808035714, 46.2757773399353, 37.93642084939139, 31.72838953563145, 38.27498919623238, 50.51673889160156, 49.215917995997835, 7.318890196936471, 0.18072047403880528, 0.13018072955310345, 0.05026326860700335, 0.027015364562560405, 0.011841611637334739, 0.045769114047288895, 0.004861233947199902, 0.023081815635253276, 0.06796168748821531, 0.03573268884792924, 0.11853763860251222, 0.06289044568049056, 0.06549304138336863, 0.04901702369430235, 0.07134514129055397, 0.14707125749971184, 0.09630604939801352, 0.16693228962165968, 0.11287171513374362, 0.16952019504138402, 0.20442133583128452, 0.10046040040573903, 0.15191350052399294, 0.18679718939321382, 0.21792502408581121, 0.1466091615813119, 0.15868637923683437, 0.14126626827887126, 0.2341314937387194, 1.0423430225678851, 25.418379511151993, 58.11744628633772, 59.676757540021626, 49.008458682468955, 33.3267114503043, 30.36381196975708, 31.017908436911448, 53.821618284497944, 29.764411721910747, 1.7108722009829112, 0.17876287336860383, 6.560918160847255, 7.355811187199183, 9.384857143674578, 6.712949088641575, 23.295406069074357, 42.85349423544747, 49.572492599487305, 50.345792361668174, 51.3393361227853, 48.70515939167568, 51.19435501098633, 48.02767876216343, 48.94187062127249, 47.905793462480815, 48.56092173712594, 47.51864331109183, 39.500825132642476, 34.86295815876552, 37.53949110848563, 41.622839723314556, 46.98775577545166, 48.73981005804879, 45.28867455891201, 41.693051270076204, 47.26540926524571, 43.88560744694301, 41.94251939228603, 41.94861643654959, 37.249376024518696, 36.87737989425659, 34.78028849193028, 33.54800462722778, 34.00474098750523, 34.140303816114155, 34.65494646344866, 35.743743079049246, 35.351829937526155, 35.74367707116263, 34.448762144361226, 35.24063791547503, 36.75325380052839, 35.00298867906843, 35.81954097747803, 34.629964215414866, 34.7845755304609, 33.96726587840489, 34.98430149895804, 31.90878561564854, 39.91985361916678, 44.742191791534424, 47.421997342790874, 39.629957403455464, 47.35554824556623, 45.037736892700195, 47.06921992983137, 48.224799156188965, 44.759367738451274, 48.65594530105591, 46.168889726911274, 45.11683518545968, 42.853379590170725, 39.872359207698274, 44.71214778082711, 50.12875495638166, 43.309250899723594, 43.08313567297799, 38.92594160352434, 38.65930795669556, 36.627870082855225, 36.1989369392395, 34.744776248931885, 35.89203153337751, 35.33205189023699, 36.52140283584595, 37.06081233705793, 36.39466074534825, 34.87093816484724, 35.915829113551546, 34.47947318213326, 35.94397279194423, 37.77020951679775, 36.53574044363839, 36.19301012584141, 35.286325795309885, 37.36599458966936, 36.049147674015586, 36.041532448359895, 34.05634525844029, 41.38966860089983, 49.99570737566267, 46.69706399100167, 47.98300531932286, 46.458045959472656, 48.24942009789603, 48.17515080315726, 49.761636461530415, 50.899511677878245, 52.143899304526194, 48.457879952022004, 49.736654213496614, 50.54134593691145, 51.1255886895316, 48.711364133017405, 39.04907757895333, 36.67621217455183, 41.739110878535676, 45.51112808500017, 56.02710853304182, 52.53071941648211, 54.35865497589111, 52.18935094560896, 52.615449224199565, 52.44434983389718, 55.37181002753121, 54.14268411908831, 57.489506312779014, 52.684514318193706, 56.810858385903494, 47.952947412218364, 28.111952917916433, 6.084219191755567, 7.2290321843964715, 5.313153275421687, 1.9915335008076258, 0.5418580898216793, 0.3151562831231526, 27.923950297491892, 57.391606194632395, 54.79567582266671, 41.37836735589163, 33.67063685825893, 45.967655999319895, 54.819622789110454, 57.69431488854544, 11.454504030091421, 0.46300938938345226, 0.2774731351860932, 0.1083166484854051, 0.14345432658280644, 0.1553804480603763, 0.11994416027196816, 0.08966764275516782, 0.17385606095194817, 0.15489539051694529, 0.10582267945366246, 0.17189022286662034, 0.18777528405189514, 0.10399413614400796, 0.1684317977300712], [0.008096889675860959, 0.039444356824138334, 0.013831106846087744, 0.025514499384111593, 0.018883761883314167, 0.016872585784377794, 0.04948611191606947, 0.016983298950695565, 0.030859596229025295, 0.12311400446508612, 0.03913818146767361, 0.056117739994078875, 0.06729922017880849, 0.0543641815893352, 0.055979413845177205, 0.2054413232420172, 12.617472665650503, 43.79165390559605, 45.96560628073556, 38.1344028200422, 22.02509992463248, 23.340357439858572, 34.31630168642317, 40.488615785326274, 30.62930611201695, 2.395258579935346, 0.06081203185021877, 0.42160553538373535, 1.8689017040388924, 2.029493681022099, 4.432035710130419, 10.581008638654437, 34.9174667767116, 49.67138283593314, 48.461131708962576, 44.50031457628523, 44.88167340414864, 45.27286393301827, 46.338276386260986, 45.46557569503784, 45.29864174979073, 45.88016428266253, 43.467885221753804, 35.55561365400042, 32.326994214739116, 33.11126518249512, 35.91398089272635, 40.40431676592146, 39.98714344842093, 43.75225761958531, 43.45576408931187, 40.21750749860491, 42.699730600629536, 40.90630326952253, 39.201413358960835, 37.334915297372, 33.34257766178676, 32.00440672465733, 32.44097246442522, 30.910353796822683, 31.81030532291957, 30.924510751451763, 32.3828889983041, 31.042022160121373, 32.000751972198486, 32.548103264399934, 31.00197274344308, 32.28938708986555, 32.09944418498448, 30.59970678601946, 31.561935016087123, 30.570673738207134, 31.616165706089564, 30.24390343257359, 31.13203607286726, 36.95993491581508, 44.04382140295846, 41.826585224696565, 37.9294240134103, 45.579362869262695, 41.12626934051514, 42.64898790631975, 39.30438913617815, 41.205312047685894, 39.200141838618684, 42.649752208164756, 40.73710421153477, 42.14186668395996, 40.194078172956196, 39.69926221030099, 45.86910622460501, 41.08706412996565, 40.245071002415244, 34.65666961669922, 33.393438475472585, 30.83807168688093, 33.3556090082441, 30.55227838243757, 31.53339876447405, 32.42888607297625, 31.485789707728795, 33.12625592095511, 32.98890740530831, 33.12164231709072, 32.618714332580566, 32.52666112354824, 32.8120688029698, 33.167816570826936, 33.079063756125315, 32.46163988113403, 32.14073385511126, 33.783590248652864, 33.05902862548828, 33.33934327534267, 31.214038712637766, 35.348272459847585, 43.114656175885884, 45.02760641915457, 44.915677888052805, 46.310438428606304, 46.47006981713431, 45.43991947174072, 43.22863442557198, 42.054823126111714, 41.68626288005284, 41.932180472782676, 42.90070029667446, 46.037690367017476, 46.317393575395855, 45.517999853406636, 43.6446647644043, 33.99729251861572, 33.27516623905727, 35.84792784282139, 46.16778496333531, 49.20727096285139, 49.39992019108364, 51.70522478648594, 48.65880101067679, 49.58130291530064, 52.89208132880074, 49.71408993857247, 50.511312348502024, 45.80064214978899, 50.277081625802175, 41.223707403455464, 20.531636748995098, 2.554447455065591, 1.83001480783735, 5.748750610010965, 0.12051417039973394, 0.07923940768731491, 0.2899567681763853, 22.55736494064331, 52.37622969491141, 37.753794397626606, 26.99300112043108, 19.00902761731829, 39.61798218318394, 46.65670885358538, 42.83385167803083, 6.529704247202192, 0.2294262605054038, 0.06725046743771859, 0.051341596458639414, 0.03002917793180261, 0.046173571808529754, 0.004270351658176098, 0.04439422568040235, 0.03407885134220123, 0.024752165290660093, 0.01099483301264367, 0.03573360826287951, 0.02016234747134149, 0.032445736295942745, 0.025860959364633476, 0.010914712445810437, 0.047936724698437114, 0.059791426972619126, 0.012352210087036448, 0.058026774520320554, 0.03046476687969906, 0.031125239296151058, 0.062277233228087425, 0.05862997858119862, 0.03429566363670996, 0.029843032027461698, 0.056854500102677515, 0.06723594678831951, 0.03817099425941706, 0.0429270124462034, 0.17548987828195095, 15.806154727935791, 48.37728084836687, 53.66470711571829, 44.12112011228289, 28.404562405177526, 26.448024375098093, 33.59397043500628, 46.731388092041016, 32.2407740184239, 2.351375928946904, 0.016949523173804795, 0.8800504739795412, 2.1878027405057634, 4.3026476587568006, 4.964315056800842, 16.881758451461792, 37.11231238501412, 51.61592306409563, 49.91879776545933, 46.05512687138149, 46.33589662824358, 46.1493444442749, 48.003113406045095, 46.750433104378835, 45.39181361879621, 47.82700783865792, 45.53468247822353, 36.97170863832746, 32.15616233008248, 35.09002528871809, 37.96882724761963, 43.208005223955425, 42.396973269326345, 45.61787673405239, 44.65807689939226, 42.47200339181082, 43.92375653130667, 43.25243200574602, 41.393847942352295, 38.55851738793509, 34.83456781932286, 33.50002384185791, 34.664444650922505, 33.21582167489188, 33.15450382232666, 32.764713355473106, 34.116131033216206, 33.44959381648472, 34.04196943555559, 33.94459738050188, 33.14866386141096, 33.65968997137887, 33.29108108792986, 32.20583847590855, 32.89255673544747, 34.05836023603167, 32.90976742335728, 32.658906187329976, 33.90229674748012, 38.719538416181294, 45.44566215787615, 43.409298011234824, 39.93804747717721, 46.525207247052876, 42.761976037706646, 43.671957288469585, 42.12920706612723, 43.21638127735683, 42.41420480183193, 44.992733410426546, 42.88422611781529, 44.18530409676688, 39.57901668548584, 42.20425108500889, 45.86708777291434, 43.53206920623779, 41.91809300013951, 36.650295393807546, 35.530374322618755, 33.67259277616228, 34.16025904246739, 32.23605966567993, 33.2415578024728, 34.285951954977854, 32.8846948487418, 34.972652844020296, 34.58377953938076, 35.00850902284895, 34.883521352495464, 34.296756403786794, 33.85908242634365, 36.37841238294329, 35.3497246333531, 34.68139478138515, 33.25083712169102, 35.38411126817976, 34.05689416612898, 33.96501466206142, 33.68835823876517, 36.9041165624346, 46.4733042035784, 46.46459811074393, 45.876509530203684, 47.67545025689261, 46.854485852377756, 47.05061265400478, 45.357145581926616, 43.9287314414978, 44.53294679096767, 43.74406916754586, 44.80851929528372, 47.690520899636404, 48.13040440423148, 47.6551684652056, 44.503149441310335, 34.817270278930664, 35.83235692977905, 38.52007647923061, 48.07489177158901, 50.5941835130964, 51.227984292166575, 52.321946893419536, 51.976899351392476, 51.88221277509417, 53.21573884146554, 52.204070704323904, 53.29466690335955, 47.69016306740897, 51.32729836872646, 43.39566911969866, 20.01360511779785, 3.59554077897753, 4.689264101641519, 5.8456653867449075, 0.5079413269247327, 0.05026678341839995, 0.349581241607666, 25.48845556804112, 55.59369380133492, 44.76764651707241, 32.76421308517456, 22.32367444038391, 44.35641390936715, 50.34645244053432, 50.01171255111694, 8.508955069950648, 0.27134547542248455, 0.03585538494267634, 0.022267933236435056, 0.05226882813232286, 0.060136597736605575, 0.038446947666151185, 0.052651074049728255, 0.08880969629223857, 0.03565255386222686, 0.050235777760722806, 0.05030092390786324, 0.07259116228669882, 0.024626804249627248, 0.03139952011406422, 0.1143372082816703, 0.16147065269095556, 0.09576648513653449, 0.07116486810679946, 0.16386858187615871, 0.1382203245801585, 0.12371479294129781, 0.1459941781525101, 0.10249080788344145, 0.2058074064552784, 0.15287498464541777, 0.14139972254633904, 0.12695673826549733, 0.12673689291945525, 0.07183032097028834, 0.44025409328086035, 17.588091475622996, 54.494033677237375, 59.5327422278268, 50.240971837724956, 30.82505771092006, 31.38846629006522, 43.98994507108416, 51.97049311229161, 37.25711631774902, 3.4440411712442125, 0.2417891142623765, 1.6080015152692795, 5.265030486243112, 8.991071462631226, 7.418652432305472, 12.869303175381251, 37.72500453676496, 52.437050751277376, 51.66423388889858, 47.88556725638253, 49.391109875270296, 48.63880409513201, 50.17616598946707, 48.825807912009104, 49.166929721832275, 50.65983009338379, 47.75817550931658, 38.302028111049104, 35.110602378845215, 37.07101229258946, 39.45267759050642, 44.94984565462385, 44.00034999847412, 47.08899450302124, 44.9088408606393, 42.88831513268607, 46.349251065935405, 44.46230098179409, 43.19693326950073, 41.3474235534668, 37.58702026094709, 34.45541851861136, 36.166575704302105, 34.17748015267508, 36.110990115574424, 34.24897364207676, 36.0785038130624, 34.17097316469465, 35.14695187977382, 35.88765416826521, 35.24271890095302, 35.819419384002686, 35.19079153878348, 34.09956652777535, 34.35334948131016, 35.78647797448294, 34.804930278233115, 33.83774103437151, 34.580107416425435, 42.03541333334786, 47.661084856305806, 45.487153325762065, 42.154682636260986, 48.21661070414952, 44.74747242246355, 45.332705293382915, 43.81989138466971, 45.44411965778896, 44.23348985399519, 46.86454336983817, 45.20724514552525, 45.567828859601704, 42.41758510044643, 45.1574057170323, 48.067359924316406, 45.31459133965628, 44.84280865533011, 38.82765586035592, 37.268872669764924, 35.54887042726789, 36.56408909388951, 34.988911628723145, 35.076782022203716, 35.88513197217669, 34.19895356042044, 38.03390754972185, 36.117465836661204, 37.437581879752024, 36.02609702519008, 35.950087206704275, 35.59894609451294, 37.670217990875244, 36.51495490755354, 36.59561307089669, 35.55697897502354, 36.57433768681118, 35.88390908922468, 36.03079400743757, 35.3455696105957, 37.888078757694785, 49.36530079160418, 49.45752075740269, 48.21398081098284, 47.7872120312282, 49.750324794224326, 49.44226598739624, 47.32010548455374, 45.37927559443882, 47.111294746398926, 45.45780413491385, 47.92109339577811, 50.0025200843811, 49.29335566929409, 48.14742749077933, 48.277775696345735, 38.10006134850638, 37.39358588627407, 40.4011344909668, 51.117518356868196, 53.29436118262154, 53.113676752362935, 53.357270172664094, 54.79497058050973, 53.66759409223284, 56.565062386649, 52.79975019182478, 55.19579826082502, 48.15374687739781, 53.439790453229634, 44.86490045275007, 22.70684674807957, 4.568090123789651, 8.176103353500366, 13.739257591111318, 1.109764541898455, 0.17171201242932252, 0.46577678088630947, 28.405053990227835, 63.34526743207659, 48.008960315159385, 37.98640966415405, 27.323579038892472, 51.54761184964861, 60.60382093702044, 57.07679026467459, 11.401954804147993, 0.4847256583826882, 0.13322340271302632, 0.10916665608861617, 0.11885792070201465, 0.2050606786672558, 0.12451222086591379, 0.11964940465986729, 0.1595896314829588, 0.12431811913847923, 0.12914238098476613, 0.15413738547691277, 0.12504116605435098, 0.14814072368400438, 0.07788614423147269], [0.029484589118510485, 0.015518547102276768, 0.1191464609333447, 0.03055970071415816, 0.036333640172545395, 0.058802333261285505, 0.028742081818303893, 0.05788565959249224, 0.018311807752719948, 0.02745063290266054, 0.06400085466780833, 0.041418547675545724, 0.05501248787290283, 0.022967443468847444, 0.06626604883266346, 0.1070543969316142, 6.82146692276001, 37.691538538251606, 48.39836515699114, 40.4211140360151, 18.81347577912467, 22.059658527374268, 33.89538328988211, 39.81604405811855, 37.91762944630214, 5.069737902709416, 0.08269205849085536, 0.4313897117972374, 0.5715809091925621, 2.580343174082892, 3.9446456347193037, 6.815513185092381, 27.1185359614236, 50.57388087681362, 47.234493255615234, 44.927475929260254, 41.430669920785085, 42.49106577464512, 43.33396216801235, 44.94769171306065, 45.958505221775596, 44.69019147327968, 40.19227164132254, 32.22607510430472, 33.566872460501536, 33.94649076461792, 33.27703183037894, 36.80571617398943, 38.028446265629356, 44.31152159827096, 43.53898613793509, 41.67173767089844, 43.362383774348665, 42.69747591018677, 40.66674675260271, 38.89837809971401, 34.2522531918117, 31.152627059391566, 31.711446353367396, 30.912479945591517, 31.684800011771067, 30.483810833522252, 31.857209137507848, 32.26019770758492, 32.40499816622053, 33.17895105906895, 32.028492655072895, 32.468126024518696, 31.518807547433035, 32.77883556910923, 32.23419060025896, 32.01783411843436, 32.67323684692383, 31.96151202065604, 32.15400838851929, 38.582724911826, 42.39425652367728, 38.7119961466108, 39.63516855239868, 44.295262813568115, 43.601169041224885, 43.6508139201573, 42.196295397622244, 41.739374910082134, 40.291696889059885, 45.015801429748535, 43.75462000710623, 43.10504681723458, 39.96251555851528, 40.073047501700266, 47.08035094397408, 41.27783039637974, 38.372920581272666, 34.78133419581822, 33.69670649937221, 32.7493508883885, 31.495381695883616, 31.467964104243688, 30.75241776875087, 33.152030263628276, 32.35542276927403, 32.14904390062605, 33.01215260369437, 32.48642757960728, 33.386372157505576, 32.74757562364851, 33.95843819209507, 35.62703766141619, 34.70182248524257, 32.64515570231846, 34.47796194893973, 33.44831187384469, 33.35864189692906, 33.76493433543614, 32.351319858006065, 33.50534963607788, 40.05148376737322, 43.90117141178676, 46.52949775968279, 43.540566853114534, 43.0473906653268, 40.54364551816668, 39.94152505057198, 38.369543756757466, 39.11047533580235, 39.41392401286534, 40.52901956013271, 43.202241693224224, 46.6371739932469, 45.93696928024292, 45.32723706109183, 39.72511993135725, 32.529794761112754, 34.35381153651646, 38.209391253335134, 47.83169092450823, 47.70447288240705, 49.38767051696777, 50.75411367416382, 50.205970287323, 48.660274028778076, 46.899777684892925, 47.69228226797921, 53.83614001955305, 54.035105160304475, 37.51895918164934, 10.437966074262347, 0.867099791765213, 1.0948170125484467, 2.1339602810995917, 0.4699725700276238, 0.03898378421685525, 0.415028522589377, 23.43400526046753, 50.12251547404698, 45.222746576581685, 40.72322865894863, 29.753492627825054, 37.52079003197806, 52.70553609303066, 44.18149300983974, 10.473209074565343, 0.054862446816904206, 0.022722857039687887, 0.04144123788656933, 0.06422649470290967, 0.04018149012699723, 0.026370574786726917, 0.05775589655552592, 0.024566725062738572, 0.011430031802904392, 0.022154193803934113, 0.07375674295638289, 0.041874401071774106, 0.04585276045171278, 0.030785517168364356, 0.0687745792259063, 0.0026108647122912642, 0.09702136101467268, 0.022543416757668768, 0.11353454206671033, 0.019455303803884556, 0.019776595224227225, 0.019484718296942965, 0.055342306782092364, 0.056346026315752945, 0.10969389136880636, 0.03206882705645902, 0.046547553169408014, 0.04768770234659314, 0.044280082519565306, 0.13705298650477613, 9.49128530706678, 43.24186379568917, 53.44873625891549, 45.20817967823574, 21.462559870311193, 23.011351551328385, 37.950282505580354, 43.8415002822876, 41.220705781664165, 4.922518168176923, 0.06412644471440997, 0.22177325401987347, 2.4581897173609053, 3.4094882139137814, 2.7763735694544653, 8.669251748493739, 30.030736173902238, 50.70706047330584, 49.838768414088655, 47.86994423185076, 44.58729560034615, 45.10731267929077, 44.10354811804635, 47.29107591084072, 47.28806039265224, 46.90836565835135, 42.61788429532732, 34.79691205705915, 35.09623350415911, 35.35459532056536, 34.742049080984934, 40.050080231257844, 40.254412855420796, 47.1243052482605, 45.1072883605957, 41.88387312207903, 43.58685922622681, 44.50520610809326, 41.34409189224243, 40.36640044621059, 35.714192390441895, 33.8246853692191, 33.664088181086946, 33.334757464272634, 33.61122976030622, 32.7976895059858, 33.9757843698774, 33.75856631142752, 35.49203068869454, 34.07405274254935, 34.24975878851754, 34.23355906350272, 32.92034258161272, 34.34174598966326, 33.550262791769846, 33.59964363915579, 33.33971152986799, 33.787554195949006, 33.05550936290196, 38.47497224807739, 43.31189121518816, 40.02728319168091, 40.56756469181606, 45.29472991398403, 44.58573225566319, 44.03466020311628, 43.13796738215855, 42.35869216918945, 41.7777532849993, 45.1323435647147, 44.74183395930699, 44.521732398441856, 40.16339145387922, 42.19112941196987, 47.85134390422276, 42.67440441676548, 41.272560187748496, 36.42979083742414, 35.32083402361189, 33.855031626565115, 33.34874766213553, 32.661115714481895, 32.744271755218506, 34.11101368495396, 33.458292961120605, 34.01731027875628, 36.00510651724679, 34.008159501211985, 35.82005167007446, 33.91635990142822, 35.43871021270752, 35.601770537240164, 35.162105900900706, 33.77634327752249, 35.71806601115635, 34.0734030859811, 34.153269154684885, 33.86863967350551, 33.52747964859009, 35.5326498576573, 41.82672766276768, 46.556599208286826, 47.13243811471121, 46.50767694200788, 45.35259451184954, 42.847807134900776, 42.81246164866856, 40.56867640359061, 41.61595753261021, 41.14266014099121, 43.988749980926514, 44.83314023699079, 47.913742201668875, 47.93973888669695, 48.57665940693447, 40.847076824733186, 35.01006194523403, 36.71052932739258, 40.40083571842739, 49.3413781438555, 48.85385084152222, 51.77862903050014, 52.840761934007915, 51.63511051450457, 49.30804763521467, 47.90750271933419, 49.2949572290693, 55.08007601329258, 57.03585842677525, 40.08151388168335, 14.83517871584211, 1.7702550888061523, 3.1521267209734236, 4.547359304768698, 0.7304866995130266, 0.07479365981583085, 0.2743301609797137, 26.388817037854874, 56.14748954772949, 46.79845210484096, 39.20179898398263, 29.092272520065308, 44.26556273869106, 58.06897217886788, 50.00673416682652, 11.839171937533788, 0.08915941324084997, 0.033287126504416974, 0.030241182805704217, 0.0226388866347926, 0.05367236764037183, 0.03970002203381487, 0.047771945861833434, 0.05010613686005984, 0.04016515439642327, 0.019616561043741446, 0.05106677281271134, 0.026983999281323383, 0.03433562934930835, 0.027160693192854524, 0.1257852611265012, 0.096651511932058, 0.20057986410600798, 0.11049205889659268, 0.13605980122728006, 0.1143837422132492, 0.0832871472729104, 0.12786354603511946, 0.13973780029586383, 0.09416521034602608, 0.17704848679048674, 0.11646684472049985, 0.08028874852295433, 0.12449987152857439, 0.14140829922897474, 0.30281742236443926, 10.279092907905579, 48.571785245622905, 58.922405515398296, 52.51237269810268, 26.948134865079606, 30.055159091949463, 44.76041691643851, 49.3443797656468, 46.64095728737967, 6.8408754127366205, 0.20963696310562746, 1.1878557801246643, 4.665314095360892, 6.230451847825732, 7.514068569455828, 9.750958595957075, 30.485804966517858, 51.82584203992571, 51.38055978502546, 50.01199047906058, 46.079459462847026, 45.74800607136318, 47.66934626443045, 49.14260407856533, 50.94156912394932, 49.29401227406093, 44.9313634463719, 36.31447158540998, 36.805368764059885, 37.72167634963989, 36.27452639171055, 41.11378342764718, 41.64875302995954, 48.53395230429513, 45.943087169102256, 41.809186935424805, 44.651149545397075, 46.6161869594029, 44.958562169756206, 42.67052732195173, 36.74269601276943, 35.03967864172799, 35.2730165209089, 34.131983348301475, 34.91059848240444, 33.88261250087193, 34.38721152714321, 35.40768303189959, 37.11749226706368, 36.07085037231445, 36.29144525527954, 36.54931722368513, 34.41621330806187, 36.354757240840364, 34.78479092461722, 35.59054919651577, 35.54947492054531, 35.835282121385845, 35.403917108263286, 40.26294524329049, 45.05253308159964, 43.94677938733782, 43.66621807643345, 48.23846278871809, 46.51051875523159, 45.90581355776106, 44.73101561410086, 42.98793145588466, 42.629661491939, 48.234102794102256, 46.50395965576172, 45.493594305855886, 41.11326926095145, 44.05741902760097, 50.0507093157087, 44.757953780038015, 42.393721512385774, 38.20385353905814, 39.161836419786724, 37.860133102961946, 34.494543824877056, 35.08310488292149, 34.89997468675886, 37.2791872705732, 35.2165241922651, 36.01576852798462, 36.498067310878206, 35.5350296156747, 36.85050426210676, 36.5717043195452, 37.064005034310476, 39.25844764709473, 37.64142465591431, 35.592776094164165, 37.96734380722046, 36.79403625215803, 37.54709938594273, 34.153630461011616, 35.39715303693499, 37.25182179042271, 44.205360071999685, 49.69911309650966, 50.952265875680105, 48.09557655879429, 48.36231442860195, 44.60302632195609, 44.28341613497053, 42.96716676439558, 44.68980932235718, 42.468018599918906, 45.765084743499756, 48.33511223111834, 50.782406738826204, 49.25115231105259, 49.4520559992109, 43.730492387499126, 36.262353147779194, 39.44068152563912, 41.47092430932181, 51.67190817424229, 50.90182195390974, 53.01535974230085, 52.19488171168736, 52.292549065181184, 50.35733331952776, 49.994758946555, 50.46089274542672, 55.12952634266445, 58.99215153285435, 41.31303691864014, 13.67990347317287, 2.7302223316260745, 3.4582215760435377, 7.579211405345371, 2.7341422012874057, 0.17745335506541388, 0.4343660649444376, 29.64706012180873, 61.68409906114851, 54.38081278119768, 52.339876719883506, 38.88645151683262, 50.266860825674875, 66.48988315037319, 57.53914424351284, 15.658191101891653, 0.3618911967745849, 0.14213624516768114, 0.1693881114146539, 0.13518514244684152, 0.220273528780256, 0.12609904286052498, 0.11857660008328301, 0.09850060128207717, 0.10949459206312895, 0.07844244795186178, 0.17857331782579422, 0.09198294673115015, 0.1989943856107337, 0.0886990815134985], [0.03711923783911126, 0.07821529478366886, 0.025917939342824475, 0.046269652367170365, 0.032033068260976245, 0.022370429343676994, 0.05082733816068087, 0.042183280390288146, 0.059317538115595064, 0.03683947445824742, 0.03642051640365805, 0.06567824751670871, 0.059559116938284466, 0.03307703849194305, 0.015681415862802948, 0.034055509737559726, 2.7500622613089423, 30.587752410343715, 49.35649394989014, 39.96247386932373, 31.116166387285503, 21.165920427867345, 31.071492944444927, 38.22492395128523, 40.936635630471365, 9.811920353344508, 0.07280475153986897, 0.10893583883132253, 2.2966338949544087, 2.251003120626722, 1.9597066257681166, 6.849828600883484, 27.161689485822404, 50.27131462097168, 45.996202673230854, 44.4760479927063, 40.66143485477993, 38.7536540712629, 40.747279848371235, 41.82406997680664, 40.858833176749094, 42.024337904793875, 35.904371534075054, 33.74241869790213, 33.43939733505249, 35.5822947365897, 32.04609939030239, 35.6580787386213, 39.6799635887146, 44.243297236306326, 42.45141587938581, 41.656444685799734, 44.43465409960066, 45.89065606253487, 41.93907308578491, 39.79830183301653, 35.30069119589669, 32.87150369371687, 33.13402053288051, 32.72392742974417, 31.389553683144705, 32.683728626796174, 31.24607685634068, 33.14069775172642, 32.654282161167686, 34.83160093852452, 32.76241002764021, 32.631651878356934, 33.267168862479075, 31.79678065436227, 31.58428042275565, 32.4176994732448, 31.00125707898821, 32.19008343560355, 31.10392713546753, 36.82324995313372, 40.08420283453805, 34.557560511997764, 43.93962969098772, 43.230173451559885, 43.151408672332764, 43.8416531426566, 40.89323370797293, 43.42680399758475, 42.6144449370248, 44.74384893689837, 43.83362797328404, 43.85170718601772, 39.99106918062483, 39.69421434402466, 46.388112340654644, 42.40841347830636, 40.92155109133039, 35.285964488983154, 32.65100955963135, 32.024434907095774, 32.2672119140625, 31.351908343178884, 31.009931904929026, 33.36561441421509, 33.55320882797241, 32.51059341430664, 32.464558124542236, 31.188750743865967, 31.56385271889823, 32.846865381513325, 33.4372364452907, 34.68583468028477, 34.062893935612266, 33.40921436037336, 33.48531450544085, 33.3638356753758, 33.80418470927647, 33.55176707676479, 34.28385707310268, 32.97637285505022, 34.2726148877825, 37.56996938160488, 39.95895113263811, 39.4879674911499, 37.83304555075509, 36.947372572762625, 34.794125829424175, 34.1200532913208, 33.55738469532558, 37.78137527193342, 39.744307381766184, 41.24646275384085, 46.21042953218733, 44.13860872813633, 46.869257722582134, 45.89787176677159, 37.04316391263689, 33.756228242601665, 33.573681695120676, 40.28506483350481, 47.249946049281526, 48.52012538909912, 49.27708298819405, 49.32179812022618, 47.599728788648335, 50.40872914450509, 52.64646945680891, 51.50236865452358, 50.67114870888846, 36.76320709500994, 10.366555094718933, 2.6089052643094743, 5.822268196514674, 2.9927943221160342, 0.3748533869428294, 0.04562614671885967, 0.3751588634082249, 25.331045866012573, 48.85366671425955, 45.18072387150356, 36.17748785018921, 28.204007863998413, 39.166272844587056, 47.7988155228751, 38.42936427252633, 10.810574514525277, 0.01662521736164178, 0.034475583982254775, 0.12594816381377832, 0.03602282363655312, 0.01548997568897903, 0.05156148930213281, 0.026096509403682182, 0.02911409203495298, 0.07235389894672803, 0.0498486158571073, 0.044470360702169795, 0.04904928803443909, 0.0523982281530542, 0.03196134710950511, 0.00941619839120124, 0.03740950833473887, 0.048209125974348614, 0.06027980933764151, 0.04816719590287123, 0.0332427333508219, 0.014081223335649286, 0.07212238958371536, 0.06071173080376216, 0.03352755521024976, 0.009523228808705295, 0.02897734347996967, 0.06621340808591672, 0.026294315932318568, 0.08075113621141229, 0.04204437748662063, 4.1130973270961215, 38.05770165579659, 55.62816381454468, 45.7675061907087, 32.120389529636924, 23.60644565309797, 34.56914663314819, 42.66731030600411, 45.26613807678223, 10.342486534799848, 0.05061695498547383, 0.13431866679872784, 1.247068111385618, 1.8310998124735696, 2.923137979848044, 7.296364137104579, 28.37713439123971, 52.33481495720999, 48.43168176923479, 47.21851934705462, 43.13749143055507, 42.19504819597517, 41.9419253213065, 43.278126444135395, 43.28179161889212, 44.15417616707938, 38.787540435791016, 36.26781095777239, 35.17052016939436, 36.62537220546177, 34.46449981416975, 36.100342001233784, 40.853559494018555, 46.20562832696097, 43.38444083077567, 43.034050124032156, 44.70886823109218, 46.95166335787092, 42.54095384052822, 41.34754514694214, 36.54144491468157, 33.728119305201936, 34.603731291634695, 33.71372611182076, 33.66076346806118, 33.61594411305019, 33.327493122645784, 34.09625571114676, 35.0986966405596, 36.409290177481516, 34.556344577244346, 33.17451116016933, 35.27887037822178, 34.38489777701241, 33.34168829236712, 34.28239100319998, 32.97085945946829, 33.72042070116316, 31.770950726100377, 38.91779484067644, 41.21063436780657, 36.921716349465505, 44.83352238791329, 44.88569641113281, 45.07927322387695, 45.685180459703716, 43.09114694595337, 45.15147542953491, 42.616112504686626, 45.18974263327462, 46.280495166778564, 44.6948676109314, 41.28072779519217, 42.324788434164866, 46.64043269838606, 43.61798368181501, 41.69552830287388, 36.207497119903564, 34.25995526994978, 33.89790896006993, 34.5678334236145, 33.345099857875276, 32.79495538984026, 33.310063566480366, 34.74320943014962, 35.22637326376778, 35.14964778082711, 32.99095712389265, 33.427182401929585, 34.748781885419575, 35.11390277317592, 36.19330889838082, 34.97963925770351, 34.36634956087385, 34.688634804316926, 34.85560349055699, 34.6672899382455, 33.80997950690133, 34.28500005177089, 33.77025318145752, 35.95324516296387, 40.71919175556728, 41.858734539576936, 41.974585328783306, 39.73435756138393, 38.449343817574636, 36.02603101730347, 36.52023206438337, 34.51628821236746, 39.26440225328718, 41.21573087147304, 43.7175235748291, 47.60793113708496, 45.79320410319737, 47.35137585231236, 48.064215864454, 38.844196047101704, 36.235692909785676, 34.3889798436846, 42.66267238344465, 51.161844389779226, 50.34443398884365, 51.05728094918387, 50.581930364881245, 48.97272062301636, 50.18061978476388, 52.365268911634175, 54.4806410244533, 51.28218371527535, 40.68893929890224, 10.68495716367449, 3.6026783159800937, 6.460952256407056, 2.4331642602171217, 1.2509306584085738, 0.07851553295872041, 0.3879654790673937, 28.651958227157593, 55.438915729522705, 51.73263195582798, 47.84582008634295, 36.33983251026699, 43.8749350139073, 53.807794843401226, 48.32247345788138, 13.558587057249886, 0.07465581542679242, 0.005961098500327873, 0.02855352372197168, 0.034591141888605695, 0.04258001981569188, 0.06647996378264256, 0.05441211669572762, 0.0020163802504872103, 0.04425476637801953, 0.0680563770500677, 0.024895970609837344, 0.015964427730068564, 0.06876443512737751, 0.026948238789503063, 0.25578691171748297, 0.14612651962254727, 0.12970160240573542, 0.223433914195214, 0.19614833832851478, 0.13813424562769278, 0.13695155909018858, 0.2626795247197151, 0.28509715465562685, 0.12424390097813946, 0.15047602408698627, 0.15790994518569537, 0.18822923755007132, 0.28167410833495005, 0.18840868292110308, 0.14670182232345852, 4.891299043382917, 44.5461414200919, 61.25274794442313, 51.05493940625872, 40.66719838551113, 29.102270977837698, 41.148048468998496, 49.45548840931484, 49.6957814352853, 13.162285259791783, 0.2929704136082104, 0.4628266734736306, 5.995604038238525, 6.219190989221845, 5.485384353569575, 10.016390204429626, 32.1130313873291, 53.2683436529977, 50.8445132119315, 47.72204140254429, 46.760004247937886, 43.0167247908456, 43.29539271763393, 45.763736792973106, 44.35828297478812, 46.200865336826865, 40.57696213041033, 38.14824710573469, 37.575461932591026, 38.47187335150582, 35.31935405731201, 37.98377282278878, 43.5280670438494, 47.65568263190133, 44.240149702344624, 42.99710307802473, 46.07515852791922, 48.958518505096436, 46.29516281400408, 44.328763553074424, 39.30036612919399, 35.075795378003804, 36.61952182224819, 36.42791829790388, 34.473671436309814, 35.4348782811846, 35.0558123588562, 35.857578890664236, 36.47557599203927, 38.46922608784267, 36.01394462585449, 35.05559696469988, 37.11848585946219, 35.418616022382466, 35.74717896325247, 34.961462770189556, 35.55991111482893, 35.65634516307286, 33.02143887111119, 40.59034783499581, 42.98064626966204, 40.53601292201451, 46.792844908578054, 46.0758672441755, 46.73366710117885, 47.32824877330235, 44.4536018371582, 47.16436856133597, 45.015492234911235, 46.23422711236136, 45.57291146687099, 46.97232730048043, 43.43454776491438, 44.55181809834072, 48.694532121930806, 46.0608799798148, 43.183446816035676, 38.509171281542095, 35.674549443381174, 35.72082792009626, 36.47139665058681, 35.27512182508196, 34.85080575942993, 36.938308647700715, 36.373941217150005, 37.141574723379954, 36.306429045540945, 34.593500069209504, 34.437408787863596, 35.46340411049979, 35.86501693725586, 38.13789081573486, 37.40566880362374, 36.63688884462629, 36.39457736696516, 37.27199241093227, 37.415535245622905, 37.30157436643328, 37.05828319277082, 35.97571216310774, 36.997382232121055, 42.43688372203282, 43.781453950064524, 43.47206803730556, 41.63434941428048, 39.9253739629473, 38.800273009708945, 38.44692931856428, 36.920635904584614, 42.163315773010254, 43.73382404872349, 46.38047974450247, 48.015950202941895, 46.941154207502095, 49.24801867348807, 51.147847243717735, 42.10780661446707, 39.4733693259103, 36.58240801947457, 43.94696004050118, 52.04987975529262, 53.55749293736049, 54.137365273066926, 51.46833985192435, 51.870164598737446, 52.76520027433123, 54.82705388750349, 56.04468400137765, 54.14077683857509, 40.63556323732649, 12.674225551741463, 4.8607712643487115, 14.311486039842878, 8.70805309500013, 1.7999368160963058, 0.26889962809426443, 0.49703135234969004, 31.66289234161377, 61.20460387638637, 56.23656892776489, 45.75648634774344, 40.16046278817313, 51.126495429447715, 61.752670833042686, 56.20411736624581, 16.143646103995188, 0.24339192254202707, 0.10901188225086246, 0.1727405765226909, 0.10923389212361403, 0.11776138097047806, 0.22164408809372357, 0.16331934849066393, 0.13541501654045923, 0.14724528816129479, 0.1420148823942457, 0.0939928013831377, 0.12121762122426714, 0.19757486321032047, 0.14496995668326104], [0.026482368520061885, 0.057769711528505595, 0.02359668122205351, 0.04041812242940068, 0.04023044642859271, 0.041374870376395326, 0.03971505158447793, 0.07500710657664708, 0.03392683235662324, 0.009286853501440158, 0.05144842840465052, 0.037633068660008054, 0.026536425708660057, 0.039927280374935696, 0.030397656373679638, 0.05422766034358314, 1.1559522577694483, 26.65011099406651, 52.658590589250835, 47.42316116605486, 35.66560711179461, 21.16683759008135, 30.114107608795166, 34.63978549412319, 47.30077559607369, 14.579132386616298, 0.17215063103607722, 0.040035014772521596, 0.8562915431601661, 2.471642081226621, 0.31985622378332274, 0.6638094516737121, 15.230592012405396, 46.516518524714876, 45.65302767072405, 45.28304999215262, 41.238861424582346, 39.707012925829204, 37.32214798246111, 39.255796909332275, 37.64259890147618, 36.28764459065029, 31.59345551899501, 33.78647027696882, 35.186810220990864, 34.885126386369976, 35.38052599770682, 38.44325024741036, 42.97809975487845, 43.65522255216326, 42.27361842564174, 41.26043210710798, 41.0586598941258, 45.19896636690412, 41.52707270213536, 39.72089542661394, 33.391423497881206, 31.186124324798584, 32.8893084526062, 31.8859920501709, 31.74878249849592, 32.8617970602853, 32.16555282047817, 32.95005307878767, 32.7555000441415, 31.227434839521134, 31.671598434448242, 32.64567681721279, 33.78607075554984, 32.424255098615376, 31.320214135306223, 31.44726194654192, 31.10953085763114, 31.890939167567662, 31.7667053767613, 36.16252837862287, 38.48298699515206, 37.1343868119376, 42.49115262712751, 44.208556243351524, 43.031976086752756, 41.79829910823277, 42.939328806740896, 43.49284315109253, 44.67781673158918, 46.867732592991416, 45.138228688921245, 46.11573600769043, 39.97021068845476, 38.81512825829642, 44.626994132995605, 41.171269348689485, 41.536727224077495, 37.08147280556815, 37.739668709891184, 35.624821186065674, 36.006402356284006, 32.78491176877703, 32.065151350838796, 31.16891016278948, 33.06935017449515, 33.153298309871126, 34.39589330128261, 33.79331772668021, 33.23636402402605, 33.83683776855469, 33.69301700592041, 33.495201792035786, 35.05359935760498, 34.26427010127476, 33.640248911721365, 32.79056065423148, 35.3130589893886, 32.25559800011771, 32.81118985584804, 32.798742158072336, 35.286992822374614, 34.99433817182268, 32.20305572237287, 33.06871788842337, 32.33350467681885, 33.73210409709385, 32.270345551627024, 33.130101748875205, 34.01466996329171, 34.77317353657314, 40.17248317173549, 43.71100616455078, 44.502197538103374, 44.39732142857143, 45.58762427738735, 47.68490328107561, 43.29008081981114, 37.00269412994385, 32.77495500019619, 34.627528871808735, 39.567152636391775, 47.023483412606375, 48.796813079289024, 49.869743483407156, 50.83798885345459, 51.42347880772182, 48.359232902526855, 48.86614220482962, 52.04073592594692, 40.184739794049946, 10.56253251007625, 1.899437082665307, 2.928042756659644, 1.8738201601164681, 1.019880582179342, 0.16715498481478008, 0.3840931611401694, 22.590417521340505, 47.65677349908011, 38.37845829554966, 29.964624064309255, 16.89122189794268, 42.58312245777675, 47.069866112300325, 32.73492990221296, 11.683675595692225, 0.024631986560832177, 0.044364003730671744, 0.03954278850661857, 0.03397181922835963, 0.07417278670306716, 0.025724341427641254, 0.023740737599187663, 0.07959757918225867, 0.014048273675143719, 0.08026425340878111, 0.040953591732042174, 0.034383191261440516, 0.037935332262090275, 0.021431740606203675, 0.022460718605933443, 0.05825931525656155, 0.027874403466869677, 0.09853488765656948, 0.02635939252961959, 0.04145236586087516, 0.060413446809564314, 0.0414724267487015, 0.011571120437500733, 0.04719836663986955, 0.055579536195312224, 0.0227648973731058, 0.027604436435337578, 0.06721439651612725, 0.042805741274995465, 0.005684321521714861, 1.41737562417984, 31.297017574310303, 57.674922466278076, 50.84624678747994, 39.6042594909668, 20.140635558537074, 33.8829460144043, 40.90236711502075, 50.68466295514788, 16.80313263620649, 0.14599734012569698, 0.05620851440887366, 0.9712185476507459, 3.8621792026928494, 1.9882513454982211, 1.999334590775626, 18.683132784707205, 47.66751194000244, 47.926537309374126, 47.63531051363264, 43.10933385576521, 41.47821644374302, 39.46597644260952, 42.690096923283164, 39.88066577911377, 38.017864159175325, 34.415334360940115, 35.26756565911429, 37.52988869803292, 36.62033476148333, 35.8773569379534, 40.125079086848665, 44.01225226266043, 44.65544353212629, 43.53802381243025, 39.418714795793804, 41.241310664585654, 46.769109862191335, 43.24157197134835, 42.54963908876692, 34.795626640319824, 33.429461411067415, 34.677830355507986, 33.415683133261545, 32.15581839425223, 33.6480621610369, 33.62017209189278, 34.18667956760952, 33.90912682669503, 33.39776720319475, 33.590385164533345, 34.31910875865391, 36.66360466820853, 34.324702058519634, 33.01411894389561, 32.68329783848354, 32.92954199654715, 32.407197271074565, 33.2204179082598, 38.38305800301688, 40.51666218893868, 39.01146003178188, 44.52348334448678, 46.14015545163836, 45.14804649353027, 42.97199576241629, 43.269079889569966, 44.550126211983816, 45.18387835366385, 47.66261345999581, 46.11905377251761, 46.72378328868321, 41.71930851255144, 41.72283819743565, 47.34146077292306, 44.34777729851859, 44.055647236960276, 38.2885034424918, 37.775667326790945, 36.940049171447754, 37.784189292362754, 34.532703331538606, 34.27320201056344, 34.640191963740754, 34.314088685171946, 34.67079530443464, 36.140481744493755, 35.050052302224294, 34.67114618846348, 34.59137044634138, 35.543416091373985, 34.11653055463518, 35.07417297363281, 36.07998030526297, 35.762624808720176, 34.264780793871196, 36.260713372911724, 34.745196614946636, 34.58531856536865, 33.99939782278878, 37.00834648949759, 36.31329039164952, 36.15060526984078, 35.91945259911673, 34.948830945151194, 35.30207388741629, 33.96128000531878, 35.43116446903774, 35.37929616655622, 37.95426729747227, 41.93171494347708, 46.33341612134661, 47.321196351732524, 44.680047103336875, 46.22235264096941, 49.81726026535034, 44.66238130841936, 37.686289174216135, 34.967723097120015, 36.06895003999983, 43.4023254939488, 49.81629793984549, 50.11359746115548, 51.334864956992014, 50.95414883749825, 52.612499713897705, 50.228631837027415, 53.13364240101406, 53.2827160017831, 40.876967975071494, 10.499958770615713, 3.342617230755942, 6.31908871446337, 4.953974834510258, 0.9940120045627866, 0.09145773348531552, 0.39553331583738327, 26.07424603189741, 53.34930753707886, 45.27218648365566, 33.257000173841206, 21.524556909288677, 48.06345851080758, 52.24268184389387, 41.06253351484026, 13.652436375617981, 0.05302050244063139, 0.046093294330473454, 0.026979693976630057, 0.05836509886596884, 0.035087642925126214, 0.013711305551363953, 0.04891662086759295, 0.017143943812698126, 0.03085155219637922, 0.0012445590712429422, 0.026190260890871286, 0.06172593031078577, 0.07292678606297288, 0.004975400856762592, 0.14107403930808815, 0.20205223081367357, 0.11511755069451672, 0.1304445711097547, 0.07492228969931602, 0.19666824543050357, 0.14315989666751452, 0.09389677510729857, 0.11840142948286873, 0.08294869400560856, 0.10896774354789938, 0.13145724391298635, 0.11893657648137637, 0.12036528624594212, 0.18036724227879727, 0.12611474416085652, 2.0111617275646756, 36.20387710843767, 66.08929170880998, 56.960772718702046, 45.463157721928184, 29.167644841330393, 40.0001539502825, 46.067915030888145, 56.09253624507359, 19.80315113067627, 0.6717612306986536, 0.1618413363716432, 3.607560076883861, 8.310643928391592, 4.674671581813267, 2.097480935709817, 16.742330687386648, 49.79811103003365, 49.66264547620501, 48.66733339854649, 46.2426552772522, 43.22494145802089, 41.012301513126914, 44.16113131386893, 42.15936919621059, 40.362012658800396, 35.027362959725515, 36.852738107953755, 39.007888657706125, 38.50431449072701, 38.79481519971575, 42.99726983479091, 46.676393100193565, 46.5303384917123, 44.13765335083008, 40.39676407405308, 42.21498952593122, 49.21439981460571, 45.61328744888306, 45.50459677832467, 36.53179734093802, 35.29890203475952, 35.3746269771031, 33.895035879952566, 33.733479840414866, 35.96473748343331, 34.78829629080636, 36.57530001231602, 35.15247222355434, 35.73298726763044, 35.695567744118826, 35.99694585800171, 39.00992100579398, 35.32360635484968, 34.17420060294015, 35.31335081372942, 34.10728250231062, 35.68257808685303, 35.562009470803396, 40.69940676007952, 41.919069222041536, 42.94353941508702, 46.16824007034302, 48.336842332567485, 45.46789639336722, 44.9484977040972, 44.86960785729544, 46.5072774205889, 46.27134091513497, 49.30015448161534, 48.46089199611119, 48.55385889325823, 41.843316486903596, 43.29986735752651, 49.253931590488975, 45.20349311828613, 47.52378845214844, 40.931268147059846, 40.612116541181294, 38.767970834459575, 40.45637614386422, 36.2321389062064, 35.612363065992085, 35.324801445007324, 36.62144647325788, 37.23725836617606, 39.125497341156006, 36.39517491204398, 36.38228947775704, 37.6143753187997, 37.74256263460432, 36.48675911767142, 37.73836244855608, 38.38997840881348, 37.08928952898298, 35.96169069835118, 39.05825962339129, 35.518822942461284, 36.76138666697911, 35.930844170706614, 38.13972166606358, 39.08331135341099, 35.91677406855992, 37.077046803065706, 37.24209778649466, 37.147011688777376, 34.76731620516096, 37.6026154926845, 37.87614522661482, 38.63949169431414, 43.91959803444998, 48.404319763183594, 49.11361271994454, 46.240911279405864, 47.27133955274309, 51.121513571058, 47.820059640066965, 41.25153146471296, 36.554945264543804, 38.27490929194859, 43.5659555707659, 51.21797888619559, 52.90897934777396, 54.65676048823765, 54.694287708827424, 53.354209491184776, 52.948792525700156, 54.07881627764021, 57.21978071757725, 42.287500926426475, 13.570633496556963, 4.140309512615204, 9.437133652823311, 9.99038917677743, 2.5863336069243292, 0.2767918588859694, 0.47043136826583315, 28.294753074645996, 58.252074582236155, 51.20792831693377, 41.197502272469656, 28.82745930126735, 54.06241158076695, 60.95102936880929, 51.64581421443394, 15.903938463756017, 0.23340749687382153, 0.16284106272671903, 0.14717538548367365, 0.07177569211593696, 0.14244880553867134, 0.0848427363006132, 0.09166256285139493, 0.1958868716444288, 0.08918014927101986, 0.14716409466096333, 0.11990929714271001, 0.13948731230837957, 0.11337388533034495, 0.11033276601561479], [0.07690568148557629, 0.03572652774995991, 0.024735651444643736, 0.039034867725734196, 0.011142662044481506, 0.036209128996623416, 0.0211699176912329, 0.03611814423597284, 0.022333915677985976, 0.04859160937901054, 0.10001156984695367, 0.007108036420374576, 0.043528784798192124, 0.041599078702607324, 0.012429135602100619, 0.014761524241683739, 0.5226628769721303, 16.182688031877788, 43.992627075740266, 42.69767393384661, 35.77335630144392, 31.262811592647008, 27.844699144363403, 30.67805814743042, 44.84777661732265, 23.902193989072526, 0.671033461179052, 0.07751858859722104, 0.2149969283491373, 1.8064434783799308, 2.896726139954158, 3.465856126376561, 13.133961796760559, 45.41069882256644, 48.490491322108674, 45.51247256142752, 41.066657270704, 38.36109127317156, 36.68844795227051, 36.07262563705444, 34.490840435028076, 36.243342876434326, 33.879489285605295, 35.75196279798235, 36.83366182872227, 38.25786883490426, 40.22444180079869, 40.32413455418178, 46.2447258404323, 40.85315302440098, 41.224634987967356, 38.46176719665527, 41.4210501398359, 46.77864279065813, 40.876815114702495, 39.28382246834891, 31.642044271741593, 31.923116275242396, 32.352907521384104, 33.35820416041783, 31.451403072902135, 33.49043880190168, 32.0994997705732, 33.210384709494456, 33.18423168999808, 32.282925265175955, 31.908518110002788, 32.96977206638881, 30.96322958809989, 32.06442526408604, 32.1964236668178, 32.310478346688406, 31.753472532544816, 32.40863902228219, 31.275380883898052, 32.886946065085276, 37.994684968675884, 42.9805246761867, 42.62963022504534, 43.56238419669015, 41.52685383387974, 41.71543836593628, 41.397936957223074, 44.77682508741106, 43.65421853746687, 44.28452784674508, 44.785444327763145, 47.821647303445, 40.54232883453369, 39.29949413027082, 47.59954466138567, 43.02775158200945, 43.12206642968314, 40.26248666218349, 41.68541867392403, 40.06508834021432, 40.32688256672451, 37.75615331104824, 36.17268664496285, 32.268389633723665, 34.15783759525844, 35.555655343191965, 33.121732643672395, 32.87870897565569, 33.50494316646031, 33.01195110593523, 33.08275324957711, 32.76713827678135, 32.890965597970144, 32.70877340861729, 33.105824742998394, 33.67180068152291, 34.677330085209434, 33.32183034079415, 32.652156012398855, 32.19825799124581, 33.025552204677034, 34.30503518240792, 33.79100745064871, 33.593025479997905, 32.065116609845845, 33.00903286252703, 33.505644934517996, 31.958694526127406, 33.48299033301217, 36.59658234460013, 40.68361350468227, 44.25402525493077, 45.86259576252529, 45.37208768299648, 44.5646653175354, 46.56098352159773, 47.799958501543315, 43.560223306928364, 35.89884771619524, 34.228653635297505, 34.05416004998343, 36.91166925430298, 43.61804968970162, 48.64981004170009, 48.099464075905935, 49.04383543559483, 45.285346371786936, 49.135965074811665, 50.08311571393694, 42.15779195513044, 9.562627673149109, 3.2081708908081055, 5.28875207049506, 2.915371848004205, 0.8811721737895692, 0.03665164578706026, 0.5570891925266811, 20.92028250013079, 48.08422667639596, 43.662472997392925, 39.471736499241416, 37.86098773138863, 41.738235405513215, 53.78753389630999, 35.155553749629426, 5.71954038313457, 0.074917377105781, 0.02543799625709653, 0.04504951069663678, 0.019934288458898664, 0.05836563490863357, 0.010781756053412599, 0.09488122085375444, 0.03209961558293019, 0.08027675202382462, 0.01806277861552579, 0.06494711924876485, 0.038054123387805054, 0.037873612716794014, 0.06899660266935825, 0.07227757054248027, 0.03337895943384085, 0.04870712657326034, 0.04260007052549294, 0.05971062702259847, 0.01755941080461655, 0.030376289305942397, 0.05630456782611353, 0.030880871694535017, 0.020071432260530334, 0.02480149139384074, 0.04624047536136849, 0.032796918880194426, 0.014278505695983768, 0.03730901051312685, 0.02892242624823536, 0.6191310690982001, 22.074510301862443, 51.6313932282584, 50.48415184020996, 38.77081264768328, 32.94560623168945, 34.954438141414094, 38.20170654569353, 49.54022863933018, 24.328693526131765, 0.6751204675861767, 0.053579978312232664, 0.5453549336109842, 3.0121181309223175, 2.13142375435148, 0.8446795833962304, 14.815815823418752, 45.85461228234427, 50.91675015858242, 48.298957279750276, 43.515219824654714, 38.926962988717214, 38.6176951953343, 37.697573048727854, 37.87233413968767, 37.88852344240461, 36.052434171949116, 37.22570698601859, 38.27122674669538, 39.81286178316389, 41.64550127301897, 41.12180512292044, 46.948699951171875, 42.596115589141846, 41.7785974911281, 39.06484651565552, 41.67148058755057, 47.686584745134624, 43.15272535596575, 40.48749017715454, 34.26732383455549, 33.47841494424002, 33.63888359069824, 34.051231384277344, 32.84975583212716, 34.34172167096819, 35.05806704929897, 35.46129533222744, 34.509003026144846, 33.26163114820208, 33.1234245300293, 33.62772478376116, 32.02570642743792, 33.94000809533255, 33.38699402127947, 33.39723219190325, 32.01992205211094, 33.77747583389282, 32.33845179421561, 35.13132190704346, 39.218519823891775, 44.491059575762065, 42.85764578410557, 45.76354224341256, 42.78684711456299, 41.38453735624041, 42.63011312484741, 46.18454054423741, 45.09093230111258, 44.09918464933123, 44.94047948292324, 46.751457963671, 41.59667975561959, 41.60213756561279, 48.90603181294033, 44.18784366335188, 44.90964685167585, 42.22978571483067, 42.60723965508597, 40.42066935130528, 41.70563098362514, 40.000414507729666, 35.78622089113508, 33.76953056880406, 36.424218382154194, 36.65591301236834, 34.80165420259748, 34.3537837437221, 34.92556142807007, 34.37144953863961, 35.30576685496739, 34.34697798320225, 35.12248032433646, 33.71240595408848, 34.225050994328086, 34.144205229622976, 36.68143374579293, 34.866088322230745, 34.37260641370501, 34.33859845570156, 34.43116583142962, 34.8859532220023, 35.713455881391255, 34.577175276620046, 33.994207518441335, 34.323889119284495, 34.05536208833967, 32.7757887840271, 34.747381823403494, 37.21555914197649, 42.715610708509175, 46.07319566181728, 47.92108992167881, 47.049560001918245, 45.146702017102925, 47.56228494644165, 49.79164225714547, 43.550419398716514, 36.59310129710606, 35.749315534319194, 36.68716253553118, 39.44388811928885, 46.63122286115374, 50.07196038109915, 50.02327782767159, 51.05928897857666, 48.45421825136457, 50.78102057320731, 54.11511366707938, 43.00121988568987, 10.129074352128164, 2.3066353925636838, 4.849146493843623, 3.8808524864060536, 0.7863251918128559, 0.07127781704600368, 0.41823275493724005, 23.025993142809185, 52.42660413469587, 47.605575697762625, 39.01803650174822, 35.86585419518607, 47.886394092014854, 61.559934752328054, 45.203604289463584, 8.288404481751577, 0.009591468227361994, 0.029078048254762377, 0.04135616995128138, 0.11335154117218085, 0.025166675548202226, 0.016055024029420953, 0.013001095669876252, 0.022279324143060615, 0.03949333008910928, 0.03218585399112531, 0.037571786769798825, 0.041052501781710556, 0.04348498197006328, 0.02814434844601367, 0.18223282002976962, 0.11410460647727762, 0.15404332695262773, 0.12992835523826735, 0.09930980178926672, 0.13174038300556795, 0.10569165434156146, 0.15346796996891499, 0.1379071535276515, 0.11201607568987779, 0.20557614815022263, 0.1916836050472089, 0.12145510848079409, 0.128815123545272, 0.09070227295160294, 0.16144908884806292, 0.9825596362352371, 24.141389199665614, 58.7328656060355, 52.79210369927542, 45.64009012494768, 39.25013065338135, 38.618334429604666, 40.9313827923366, 54.78103249413626, 29.473000798906597, 1.189120243702616, 0.17849725405020372, 1.3305405122893197, 4.855437653405326, 9.438239284924098, 8.277050256729126, 15.716604607445852, 49.49768481935774, 52.42075375148228, 50.367936270577566, 45.69004419871739, 41.4855363709586, 39.759246008736746, 39.673432282039094, 39.93952744347708, 40.43223810195923, 38.138578687395366, 39.2377142224993, 39.259114674159456, 42.54995175770351, 43.87127678734915, 43.58756794248308, 50.83853081294468, 43.61329017366682, 41.971642766680034, 40.8528334072658, 42.938446385519846, 50.71274062565395, 45.858485903058735, 42.49036748068673, 35.54497248785836, 34.952801840645925, 34.93958289282662, 36.33419057301113, 34.37755353110177, 36.444354261670796, 36.8045106615339, 36.91624116897583, 37.01839011056082, 35.753303800310405, 35.65299265725272, 36.334204469408306, 33.58691453933716, 35.108948707580566, 35.79224150521414, 35.960849966321675, 35.000042642865864, 35.82062142235892, 33.12093012673514, 36.20396048682076, 41.072868960244314, 46.9248537336077, 45.923323018210276, 48.03943164008004, 43.58681058883667, 42.047096729278564, 42.36767618996756, 46.661721978868755, 46.52678796223232, 46.120679650987896, 46.39020374843052, 49.43502596446446, 41.46869741167341, 43.14652756282261, 51.21271562576294, 47.724539279937744, 47.85501255307879, 44.82401030404227, 45.879212379455566, 44.09648527417864, 43.846565519060405, 41.47280032294137, 39.33818864822388, 35.585060119628906, 37.25565024784633, 37.932258878435405, 36.7046685218811, 35.31185695103237, 36.885759421757285, 35.57482194900513, 37.207141399383545, 36.80207184382847, 37.19799757003784, 36.08123792920794, 35.51811075210571, 37.367144516536165, 37.56329216275896, 38.05184779848371, 36.46767589024135, 36.860061509268625, 37.04180553981236, 36.334221839904785, 37.09776285716465, 37.163468497140066, 35.24367080415998, 36.206166539873394, 35.540664604731965, 34.40091684886387, 37.0357015473502, 39.60779612404959, 45.34884943280901, 48.658738476889475, 50.833003520965576, 49.38234124864851, 45.767176151275635, 49.76486389977591, 51.436471939086914, 47.44327967507498, 39.276676246098106, 37.59628568376814, 38.627228123801096, 41.37541784558977, 47.61700548444475, 52.77718244280134, 53.38135610307966, 53.59318583352225, 49.7350491796221, 53.64751379830496, 55.89970636367798, 45.931382928575786, 12.0880320923669, 9.6663555928639, 15.884082249232701, 6.805829133306231, 3.1561970625604903, 0.12193054439766066, 0.6790890289204461, 25.6797742162432, 58.878103801182334, 54.922338008880615, 52.038846015930176, 48.87620667048863, 54.41936486107962, 70.14402416774205, 56.61849403381348, 10.37817074571337, 0.13681541782404694, 0.09348923340439796, 0.11145467617149864, 0.2649718331439154, 0.09130388245518718, 0.11397491129381315, 0.15083165786096028, 0.1218676713428327, 0.09510620949523789, 0.10895817620413643, 0.11863024506185736, 0.0939093144344432, 0.14188250021210738, 0.12961588986217976], [0.010963526255052005, 0.053344655582415204, 0.03620640128584845, 0.0337981346196362, 0.08038436767778226, 0.029222912088568722, 0.0471700785149421, 0.039699903290186606, 0.0039365595023679945, 0.013930399419872888, 0.03901280855227794, 0.052091937445636304, 0.03276220842131546, 0.0354505641652005, 0.020060933627454296, 0.029815775275762593, 0.10713571256824903, 11.336097172328405, 41.19059228897095, 44.779882294791086, 38.850293091365266, 18.52455231121608, 18.75071791240147, 29.573520387922013, 43.990424496786936, 29.99174635750907, 1.9755348392895289, 0.037149649778647084, 0.3010876194706985, 4.30951942716326, 3.5353248672825948, 1.4034575138773238, 12.678032296044485, 41.25272308077131, 48.33564376831055, 46.539138385227744, 42.73089327130999, 39.38495697293963, 36.56414467947823, 35.26139565876552, 36.97872631890433, 36.35423265184675, 37.34487206595284, 38.00870295933315, 38.87996537344796, 41.61975819723946, 43.503199441092356, 45.833058970315115, 42.00916651317051, 42.44246659960066, 44.987699440547395, 43.771653515951975, 41.1899356842041, 43.18524987357003, 39.6340776852199, 34.30307926450457, 30.83584131513323, 32.691361222948345, 30.878235748835973, 32.985155378069194, 31.89624411719186, 32.8965345791408, 33.85794986997332, 32.89690283366612, 32.25503519603184, 32.416698932647705, 32.43296466554914, 32.21736901147025, 32.068375314985005, 32.40522745677403, 32.575295039585654, 31.60839067186628, 31.172929695674352, 31.26562213897705, 30.988448074885778, 32.18608822141375, 35.26441465105329, 39.21856151308332, 43.294631889888215, 45.67172874723162, 44.71458659853254, 43.18871702466692, 43.17165224892752, 41.82530328205654, 44.377480847494944, 42.549962180001394, 48.04771041870117, 47.12704978670393, 40.7117154938834, 39.8167736189706, 45.835938998631065, 44.52910443714687, 42.62963717324393, 44.08751514979771, 42.51901142937796, 43.306603636060444, 42.66865825653076, 44.36504009791783, 41.206333432878765, 33.27335623332432, 32.785106318337576, 35.76565422330584, 34.32774884360177, 33.05145161492484, 32.375030585697715, 33.8416667665754, 32.756823675973074, 33.76664011819022, 32.22697489602225, 34.87747989382063, 34.282606397356304, 32.963136536734446, 32.854258264814106, 32.65150982992989, 33.82551915305001, 33.52219901766096, 33.802628312792095, 34.674425738198416, 32.13991396767752, 33.71737739018032, 32.21069179262434, 32.67071117673601, 32.20425081253052, 32.914523465292795, 32.95767872674124, 37.09778370176043, 38.88067408970424, 44.16433095932007, 43.69527544294085, 48.16697972161429, 45.84272044045584, 43.587536675589426, 48.561880588531494, 47.92214952196394, 39.16649171284267, 34.247073309762136, 34.740461417606895, 34.54592227935791, 35.6407082421439, 39.99672848837716, 41.08052934919085, 41.62203025817871, 45.26538419723511, 48.90096657616751, 51.78443425042288, 41.175052642822266, 10.526744944708687, 2.314479474510465, 3.582314665828432, 4.5872593351772855, 0.8744615710207394, 0.01597650395706296, 1.0056074623550688, 21.709837572915212, 44.703862054007395, 41.34160096304757, 35.23455476760864, 31.182917731148855, 43.53212826592581, 52.47594329289028, 36.716504778180806, 3.6613102555274963, 0.06467281468212605, 0.035334022383072546, 0.04116938961669803, 0.05855350089924676, 0.015233290980436971, 0.015620059333741665, 0.009280041858021702, 0.04599793980430279, 0.028530216044081107, 0.07095712104013988, 0.0345419888118548, 0.014057491573372057, 0.014661760934229408, 0.018370670665587698, 0.05265917915052601, 0.04972042702138424, 0.054230092891625, 0.07919706710215126, 0.049570589525891204, 0.01408874404816223, 0.04584264010190964, 0.06361000492636647, 0.03563141071104577, 0.031220936482506137, 0.04633762121998838, 0.044437244800584655, 0.01157480912349586, 0.08529651337968451, 0.016320076771080494, 0.013101636748095708, 0.2699054069817066, 14.776761736188616, 47.808876514434814, 48.55615874699184, 44.59911101205008, 26.7656386920384, 27.322050435202463, 35.622437953948975, 48.46826750891549, 32.621670791081016, 2.0995478076594214, 0.059023630672267506, 0.2843716921550887, 5.168271175452641, 3.683156260422298, 2.514870298760278, 12.84299990109035, 43.48199353899275, 50.020647934504915, 48.981815814971924, 43.764990193503245, 40.77894278935024, 37.57754291806902, 37.529919964926584, 38.02288770675659, 37.20360129220145, 39.34145777566092, 39.828060967581614, 40.01127801622663, 44.095436096191406, 44.900329317365376, 46.2275881086077, 41.64606755120413, 42.57344709123884, 45.787739345005576, 43.93714918409075, 43.03160088402884, 45.807986395699636, 41.8252546446664, 37.23405524662563, 32.567724977220806, 33.943294593266074, 32.735746315547395, 33.4946528843471, 33.33336782455444, 33.82230908530099, 35.72767536980765, 36.237200668879915, 33.48566538946969, 35.42236804962158, 32.15224354607718, 33.67541027069092, 34.18811089651925, 33.970548902239116, 33.538916383470806, 32.98049313681466, 33.50914682660784, 33.397965226854595, 32.806663104466026, 35.57387004579817, 36.75573778152466, 40.566657951899934, 44.116110461098806, 46.90954337801252, 46.04845660073416, 43.93185118266514, 44.24895306995937, 42.818461418151855, 44.75028991699219, 44.79221534729004, 46.0817106791905, 49.026405879429404, 40.995667525700156, 41.46241276604788, 46.081411906651084, 47.70191594532558, 44.66352081298828, 45.48102848870413, 44.04026045118059, 45.44971990585327, 44.18274368558611, 45.59242895671299, 40.72197103500366, 34.30856834139143, 34.15492977414812, 38.21496370860508, 35.50646209716797, 34.31951870237078, 34.24514865875244, 35.12821953637259, 35.28132309232439, 35.88150153841291, 34.94157702582223, 36.07597119467599, 36.079632895333425, 35.586234365190776, 34.844076429094585, 34.62436396735055, 34.67374134063721, 35.05157743181501, 34.62135887145996, 35.556450911930625, 32.59973185403006, 34.351028782980784, 34.3786061831883, 35.31576531273978, 33.427842480795725, 34.45379958833967, 35.061902454921174, 39.37663303102766, 41.141531058720176, 46.14795480455671, 46.27298069000244, 48.69285065787179, 46.990958895002095, 45.63677930831909, 48.98452908652169, 48.646707671029226, 41.13655614852905, 35.51465054920742, 36.16549873352051, 36.545652048928396, 37.528179441179546, 43.208623613630024, 43.35879155567714, 44.82185288837978, 47.44873401096889, 51.05476917539324, 54.10890197753906, 43.164502552577424, 11.217404569898333, 2.937975423676627, 4.893965848854609, 5.012902506760188, 1.6535783324922835, 0.039672911167144775, 0.87284133796181, 23.33800721168518, 51.54813296454293, 44.55293328421456, 41.38076101030622, 39.858435017721995, 47.48011554990496, 58.544916834150044, 41.95472737721035, 5.893269666603633, 0.11186873181057827, 0.030496403574943542, 0.03231351696220892, 0.040518565968211205, 0.047028268088719676, 0.014742515083136303, 0.008412740941691612, 0.023938386368432214, 0.05618679789560182, 0.0489719689690641, 0.028540234613631452, 0.053501427705798826, 0.06432523511882339, 0.02278491245981838, 0.09159648032592875, 0.15048788487911224, 0.15942226403525897, 0.14213222824037075, 0.18867669068276882, 0.10254519246518612, 0.10969988283302103, 0.18004742158310755, 0.09757402778736182, 0.1375873735440629, 0.11673416037644659, 0.15616706013679504, 0.17051430312650545, 0.18292464076408319, 0.08070321128304515, 0.10896199635629143, 0.5428071703229631, 17.31543721471514, 53.07011154719761, 56.55585602351597, 51.22196020398821, 28.365461417606898, 26.940001998628887, 40.04502889088222, 53.29630667822701, 36.59490435464041, 3.335844474179404, 0.12152826812650476, 1.6120370072977883, 9.174611602510724, 6.722074244703565, 2.7045730565275465, 16.21489119529724, 45.72507701601301, 51.917290755680625, 51.809270586286274, 46.971142632620676, 43.37259415217808, 40.18315213067191, 39.27122885840279, 40.48242841448103, 39.956397669655935, 41.868673937661306, 41.892040729522705, 42.18705429349627, 47.68248183386666, 46.8558338029044, 49.04735469818115, 43.144113063812256, 43.883575098855154, 46.842316082545686, 47.101226806640625, 45.2418714932033, 46.88752801077706, 43.593261991228374, 37.18664421354021, 33.85185629980904, 36.89235673631941, 33.85155405317034, 35.5264242717198, 35.31239196232387, 35.870398317064556, 37.87178175789969, 37.82711178915841, 34.499886989593506, 36.97510978153774, 35.491478306906565, 35.541703360421316, 35.45175545556204, 35.70599351610456, 35.32400240216936, 33.95602021898542, 34.4271046093532, 33.83309963771275, 35.134184564862935, 36.47835527147566, 39.17311682019915, 42.779759952000205, 46.06650454657418, 51.09017372131348, 47.55503102711269, 45.49076291493007, 46.35862765993391, 43.54557303019932, 45.27256168637957, 45.705288546425955, 47.125750473567415, 50.20998634610857, 41.95455714634487, 43.24142605917794, 49.116756779806956, 48.901921953473774, 47.30244663783482, 48.20262050628662, 45.768041202000205, 48.30414758409773, 45.78575216020857, 48.90526056289673, 44.81459549495152, 36.13146645682198, 36.26446887425014, 37.955771582467214, 37.40373025621687, 36.63183055605207, 35.74896117619106, 36.84918063027518, 37.74004738671439, 37.048319475991384, 36.33630977358137, 38.46590832301548, 37.87733336857387, 36.48441062654768, 35.91917814527239, 36.52802446910313, 37.429118973868235, 36.99595090321132, 38.1914301599775, 38.277785846165244, 35.01566219329834, 37.051758834293906, 35.70249857221331, 36.63725015095302, 35.10397032329014, 36.55098826544625, 36.10699142728533, 41.60197080884661, 42.00487947463989, 49.6880133492606, 47.85373061043875, 50.17159060069493, 49.12445885794503, 45.518976075308665, 50.61602864946638, 52.160946709769114, 42.92709650312151, 38.205969265529085, 39.30679668698992, 38.85954461778913, 39.16393477576119, 45.30490902491978, 45.77178628104073, 46.054042952401296, 50.145819732121055, 53.371104036058696, 56.62384762082781, 43.34502717426845, 13.928526520729065, 8.564888937132698, 9.77387375491006, 12.993748886244637, 2.605007976293564, 0.13815426241074288, 1.254675737449101, 27.004696675709315, 56.31249189376831, 53.220824922834126, 47.1246908732823, 42.45552921295166, 55.19555854797363, 65.89644445691789, 50.22723524911063, 8.45047903060913, 0.26035985776356285, 0.09597211517393589, 0.12097447498568467, 0.1328195250992264, 0.15865325315722398, 0.11932615057698318, 0.14490166891898426, 0.1828662053282772, 0.10832032614520617, 0.14202140990112508, 0.14237133041024208, 0.08439282008579799, 0.10738363569336278, 0.07286813349596091], [0.05916929178472076, 0.02416650644902672, 0.04830993252939411, 0.04580605349370411, 0.013472428994386323, 0.04366945528558322, 0.014572224845843655, 0.05539144628814288, 0.04210209706798196, 0.07023170603705303, 0.03653090726584196, 0.04729359224438667, 0.09247839943106685, 0.060611131201897345, 0.04168971062504819, 0.06317337442721639, 0.09352881235203572, 6.664755080427442, 38.77154915673392, 45.90730047225952, 40.70199843815395, 16.832824025835308, 19.73197899545942, 33.09654542378017, 41.54053136280605, 36.43900762285505, 5.867592164448329, 0.014105859245838863, 0.2804891419197832, 2.4143952216420854, 6.495669364929199, 3.2089870870113373, 6.617031812667847, 35.547574588230674, 50.73278617858887, 46.503990922655376, 45.26432112285069, 43.83193956102644, 40.939515658787315, 38.46489041192191, 38.44525132860456, 40.39455802100045, 41.30751657485962, 41.27002756936209, 42.571195874895366, 43.29890155792236, 44.550313813345774, 41.72190713882446, 44.23176670074463, 44.349809646606445, 42.766332558223176, 42.63225664411272, 41.21330942426409, 39.089766229902, 34.86730078288487, 30.624039377485, 31.53076539720808, 32.01409598759243, 34.63088485172817, 36.899694034031455, 36.89063010896955, 35.86968960080828, 36.71703631537301, 35.9460711479187, 35.697950976235525, 34.015104225703645, 32.59927674702236, 31.191272939954484, 32.96002721786499, 32.596570423671174, 31.915362085614884, 32.10130977630615, 32.16836336680821, 32.11154099873134, 30.7352557182312, 30.849612644740514, 33.98573766435896, 36.6995199067252, 40.03714963368007, 43.77713564464024, 42.356301988874165, 44.93965264729091, 43.8849265234811, 43.047804083142964, 39.49020481109619, 44.28119271142142, 48.901004791259766, 36.433487279074534, 41.61490488052368, 37.752891131809776, 47.57939141137259, 44.771082401275635, 44.202709334237234, 43.90093169893537, 44.50360107421875, 43.97024692807879, 45.940353052956716, 45.24187844140189, 44.15259892599923, 36.00627381461007, 32.13390724999564, 32.164107595171245, 32.22030462537493, 33.381682123456685, 33.79606226512364, 34.00256620134626, 32.66496501650129, 32.618523257119314, 34.105100767953054, 32.09922531672886, 33.453311102730886, 32.80063901628767, 33.39611005783081, 33.276257106236045, 34.3288779258728, 33.41123628616333, 32.797616549900596, 33.950131620679585, 32.7393593788147, 32.949139390672954, 32.239182880946565, 32.2932641846793, 31.59450122288295, 30.729669366564067, 32.730490003313335, 34.81910112925938, 37.598536900111604, 42.29399054391043, 42.824266638074604, 46.562626770564485, 46.32091283798218, 44.906843253544395, 45.238008294786724, 49.00121865953718, 43.147232804979595, 40.26259088516235, 34.15721573148455, 36.370922224862234, 34.172262055533274, 34.848234925951274, 36.361351081303184, 38.93291412081037, 44.44835247312273, 50.62326519829886, 53.06016867501395, 40.987117767333984, 8.447426165853228, 1.5886693469115665, 2.393750386578696, 3.1475765194211687, 0.660639933177403, 0.013537228240498474, 1.1895357242652347, 24.267943688801356, 44.91793257849557, 41.34089919498989, 26.824621949877056, 27.35229594366891, 45.55058690479824, 50.81592832292829, 35.616643156324116, 4.4165321077619275, 0.04766332936872329, 0.061007341369986534, 0.04090988050614085, 0.04838762818170445, 0.03127834054508379, 0.05320819540481482, 0.03919467290065118, 0.0185006949385362, 0.033622332981654575, 0.023691679517339383, 0.025467407357479845, 0.015311811052794968, 0.0534224224809025, 0.03711901392255511, 0.04583810409530997, 0.09849700504647833, 0.04823504601206098, 0.07163792915110077, 0.029219224250742366, 0.06727919661040817, 0.03538446806903396, 0.02525041694752872, 0.06690257574830737, 0.04519773327878543, 0.02243786385016782, 0.013686952081375887, 0.0676959663895624, 0.04026921791955829, 0.04050715300919754, 0.0209927267528006, 0.10130360230271306, 8.80799685205732, 45.23611838476998, 52.740318775177, 45.520202432359966, 19.898252861840383, 17.72532708304269, 38.12690223966326, 46.59742682320731, 40.056410040174214, 5.7265749999455045, 0.045992762582110505, 0.3519036498452936, 4.498885631561279, 5.256634891033173, 3.078015063490186, 8.268452729497637, 37.21715027945382, 52.66805056163243, 48.08861098970686, 46.76565660749163, 43.87778377532959, 41.78631346566336, 38.85636581693377, 39.33726453781128, 41.970683915274485, 42.586871010916575, 42.86690425872803, 44.664629050663535, 44.41388245991298, 46.02089309692383, 42.798224789755686, 45.62828860964094, 46.15848479952131, 45.311739104134695, 44.80379799434117, 43.11500358581543, 40.26572799682617, 36.89547995158604, 31.84654712677002, 33.13113355636597, 34.41232579095023, 35.60624170303345, 37.44731978007725, 38.64621407645089, 37.95696667262486, 37.21385683332171, 36.85715021405901, 35.60023845945086, 34.54306309563773, 33.82312549863543, 32.205841950007844, 33.610399450574604, 34.45322983605521, 33.5648192678179, 33.00905023302351, 34.2972149848938, 32.53373438971383, 33.40959998539516, 32.67995228086199, 35.445307527269634, 38.110674721854075, 42.44310235977173, 45.79292270115444, 44.477948325020925, 45.549846921648296, 45.34666422435215, 42.63971553530012, 41.25834764753069, 42.5613294328962, 50.472756794520784, 39.39070660727364, 41.27103853225708, 40.45650468553816, 46.65974521636963, 47.10176529203142, 45.73087528773716, 46.00003807885306, 45.83751623971121, 45.46200432096209, 48.37107263292585, 46.11508635112217, 44.250842979976106, 38.20848103931972, 34.002336910792756, 33.4679787499564, 33.95161158697945, 35.34424945286342, 34.633229868752615, 35.89351497377668, 33.74654245376587, 33.85321119853428, 35.39582940510341, 34.03188759940011, 34.536434514181956, 35.719816957201274, 35.280631746564595, 33.70083720343453, 35.30973080226353, 34.02153825759888, 35.20012296949114, 35.367842061179026, 34.41174214226859, 34.6713615826198, 33.762300968170166, 34.3849081993103, 33.047188895089285, 33.186125074114116, 35.2694034576416, 36.45686101913452, 40.41600363595145, 43.48947327477591, 46.296076502118794, 47.733853340148926, 47.21674408231463, 45.32980442047119, 45.95186274392264, 50.88057436261858, 44.39113753182547, 42.29354238510132, 35.450796604156494, 37.25561898095267, 36.95192016874041, 37.062400000435964, 39.560405935559956, 41.645563806806294, 46.855305739811485, 53.552552768162315, 54.698491368974956, 41.81230320249285, 9.472346254757472, 3.6529255168778554, 6.171465115887778, 3.1812175256865363, 1.0514730640820094, 0.028051029524898956, 1.0898590385913849, 26.798246588025773, 49.68099914278303, 45.78715222222464, 31.186360563550675, 30.25145959854126, 50.26164272853306, 57.93510818481445, 42.908972127096995, 5.726241052150726, 0.08835035522601434, 0.01835773778813226, 0.019716180162504315, 0.06893443529094968, 0.0333939957698541, 0.05062247486785054, 0.04500069688739521, 0.038435887545347214, 0.06680395068334681, 0.046059116521584134, 0.03122064471244812, 0.01400632833662842, 0.015614474990538188, 0.01825555719967399, 0.21408326737582684, 0.1704815841679062, 0.07930350210517645, 0.16990824921854905, 0.13491522121642316, 0.11691486782261304, 0.10456387485776629, 0.24094531525458607, 0.14349737284438951, 0.13258167143378938, 0.16624953411519527, 0.14522368806813443, 0.15439905572150434, 0.13550782656030996, 0.1398498671395438, 0.14211630980883325, 0.18385548224406584, 9.587649004799978, 50.29259695325579, 59.303076471601216, 51.42503867830549, 26.366230181285314, 27.514296667916433, 42.90668616976057, 52.09290647506714, 45.30685452052525, 8.149250302995954, 0.10273737393851791, 1.131612392408507, 6.376585926328387, 9.335452846118383, 5.450816197054727, 7.885084135191781, 39.22085441861834, 54.02130256380354, 49.28853709357125, 48.05138601575579, 47.582365240369526, 44.92488425118582, 42.29522384916033, 41.3280519757952, 45.60066952024187, 45.27236713681902, 44.80635493142264, 46.66064500808716, 46.423537731170654, 45.66627441133772, 43.01211813517979, 47.659993989127024, 49.57343408039638, 47.62389809744698, 47.66983263833182, 44.07004737854004, 42.74476882389614, 37.847122601100374, 34.811044692993164, 34.54490784236363, 37.16095324925014, 37.49256297520229, 39.55278376170567, 40.34428433009556, 39.73083135059902, 40.1820821080889, 39.88113825661795, 37.65327480861119, 37.557479994637625, 36.33464568001883, 34.79905557632446, 35.77093138013567, 36.30520616258894, 35.6442414011274, 35.70213379178728, 35.17244482040405, 34.575844696589876, 34.67556871686663, 34.40327228818621, 38.14192424501692, 39.97719362803868, 42.96664564950125, 48.60885041100638, 44.759815897260395, 48.32313701084682, 46.59957381657192, 43.503609384809224, 41.347517354147776, 43.87991687229702, 48.98501546042306, 41.59799296515328, 42.36953483309065, 42.43180806296212, 47.149471623556956, 48.7074418749128, 47.588726316179546, 48.850522654397146, 47.54351091384888, 46.19294091633388, 50.301761627197266, 48.67494167600359, 46.129587241581504, 40.042079380580354, 36.0197811126709, 35.68396772657122, 35.336342402866904, 37.26129218510219, 36.362230028424946, 37.12965856279646, 36.07699605396816, 34.91355146680559, 37.204706055777415, 34.759867736271445, 37.59575414657593, 37.89425570624215, 37.46245643070766, 35.24002299989973, 38.08240597588675, 36.57863514763968, 37.3157764843532, 37.0952719279698, 35.40517125810896, 36.60600757598877, 35.18726532799857, 34.77570615495954, 34.80478089196341, 33.92027521133423, 35.64034693581717, 39.251044341496055, 40.945313930511475, 45.34558725357056, 49.50480672291347, 50.59323508398873, 48.45389863422939, 47.01026446478707, 46.1073043687003, 54.163869176592144, 47.98298100062779, 45.14350584575108, 38.70445735113961, 40.59342588697161, 39.35256099700928, 38.586897305079866, 40.934335776737754, 43.51121766226632, 48.97771290370396, 56.139731884002686, 58.21851825714111, 44.02679136821202, 10.637040649141584, 4.689784348011017, 7.930455003465925, 10.99164022718157, 2.7888180102620805, 0.07092627483819212, 1.8522618540695734, 29.3868396622794, 57.22400522232056, 52.63490765435355, 38.406021799360005, 37.824596541268484, 59.38550295148577, 64.72283118111747, 49.36857339314052, 7.325222611427307, 0.18574753643146583, 0.10905163083225489, 0.12127570382186345, 0.1525958896215473, 0.064831781866295, 0.11616914426641804, 0.204160140561206, 0.12021816628319876, 0.16519894477512154, 0.11659605135875088, 0.08710434101521969, 0.06397973865802799, 0.10446596225457531, 0.11643814268921103], [0.04230491457773106, 0.09429677828614201, 0.019198630969705324, 0.022486226433621984, 0.010624268923753073, 0.03981804641495858, 0.030779169473264898, 0.07373931139175381, 0.014560453959607651, 0.016957255080342293, 0.050549908940281184, 0.011051940216150666, 0.056627896547849686, 0.050346524853791506, 0.057584695384970734, 0.021936282282695174, 0.020588379253500273, 2.8586560913494656, 30.899229730878556, 45.75150796345302, 47.34371893746512, 38.22149501528059, 28.268711226327078, 30.084640298570903, 41.58282504762922, 43.332440512520925, 11.64161467552185, 0.06507709263158695, 0.08027804802571024, 3.409262614590781, 2.716331796986716, 2.6581167493547713, 3.6555380395480563, 24.03311194692339, 43.769972051892964, 49.39899260657174, 46.65416233880179, 45.048186983381, 43.37783309391567, 42.90602956499372, 43.965838296072825, 43.49997547694615, 45.72524724687849, 45.493507453373496, 45.410063062395366, 45.22637006214687, 42.785405363355366, 43.61989443642752, 43.111286299569265, 39.924446378435405, 38.842584065028596, 37.39584057671683, 34.42589562279837, 32.359810556684224, 31.14021062850952, 32.75267907551357, 32.58853483200073, 36.27101060322353, 40.39737898962838, 42.249855586460654, 42.288685594286235, 42.39399596623012, 42.39718518938337, 42.17064959662301, 40.92241266795567, 39.69724028451102, 38.2085713659014, 35.587870665958945, 32.61862400599888, 33.07975510188511, 31.843743528638566, 30.049732548849924, 32.050323895045686, 31.29930353164673, 33.20117139816284, 31.896355288369314, 31.386663232530864, 33.03476551600865, 33.63520104544503, 40.03097268513271, 43.64940343584333, 43.16891118458339, 45.33110720770699, 43.987179688044954, 45.04629359926496, 48.485099520002095, 34.707995959690635, 40.892969676426475, 41.68367120197841, 38.43187952041626, 46.24246767589024, 43.120256423950195, 44.709417138780864, 43.429381779261995, 44.947097642081125, 45.48005921500069, 44.45695434297834, 44.901399339948384, 44.63689879008702, 38.617622239249094, 30.858096395220073, 33.48258038929531, 32.51063857759748, 34.23945461000715, 33.879555293491904, 33.61848367963518, 33.4758996963501, 33.02468715395246, 33.67453479766846, 34.81513718196324, 33.87126956667219, 35.13486201422555, 38.582988943372456, 41.950582776750835, 42.25647027151925, 38.769687039511545, 36.88196570532662, 36.376188959394185, 33.08831875664847, 31.16892405918666, 31.68371261869158, 33.04812690189907, 32.992840085710796, 33.70712879725865, 33.00086872918265, 33.505874225071494, 34.003038678850444, 38.08979885918753, 40.45972517558506, 44.07985476085118, 45.761704444885254, 49.779496806008474, 44.82229062489101, 46.81230681283133, 48.952008043016704, 43.34339782169887, 40.52378409249442, 38.25206014088222, 36.22609397343227, 37.05517387390137, 36.79673910140991, 42.383038657052175, 46.05546038491385, 52.33197314398629, 53.782169886997764, 37.56324005126953, 7.75893611567361, 3.005267641374043, 3.683555781841278, 2.7223072477749417, 0.7636589195047105, 0.06009905439402376, 1.1784557359559196, 28.748256785529, 48.09946060180664, 40.704454626355854, 35.62135403496878, 29.795675141470774, 41.13277980259487, 49.326863356998985, 31.176601818629674, 2.497295916080475, 0.051558829444859705, 0.06613231636583805, 0.05803474052143948, 0.041488816762076955, 0.053799145123256106, 0.02650718593836895, 0.008504693462912525, 0.05233168422377535, 0.0450957867849086, 0.02005223141584013, 0.014010677746097957, 0.008779554428266627, 0.05612190619909337, 0.01645400601306132, 0.0320735055554126, 0.036234601201223474, 0.015970110460849743, 0.054542317387780974, 0.07076586915978364, 0.03062185112919126, 0.006836080008984676, 0.09567799738475255, 0.04029760103938835, 0.029326694019670998, 0.058312308841517994, 0.02823915844783187, 0.023714198398270776, 0.028105641415874873, 0.05789668578654528, 0.05689444885190044, 0.032316356631261964, 3.5684447586536407, 37.24688162122454, 50.2300249508449, 50.16087647846767, 35.89861495154244, 30.350224767412456, 38.789117676871165, 46.355031967163086, 47.052064827510286, 11.83167483125414, 0.06778543801712138, 0.07537526610706534, 1.633495650121144, 6.389427065849304, 3.798509819167001, 3.156633496284485, 25.293866055352346, 48.66850069590977, 52.075685364859446, 47.87479060036795, 47.96092047010149, 45.857575689043315, 43.82284089497158, 45.58104085922241, 45.8088583946228, 46.589690004076274, 46.200257369450156, 46.14740937096732, 45.484787464141846, 44.36145830154419, 45.08769791466849, 45.488730566842214, 42.64471476418631, 40.62621096202305, 39.63652345112392, 36.132206439971924, 35.35760389055525, 32.36057138442993, 33.839116777692524, 34.55678578785488, 37.00929839270455, 42.12002502168928, 43.00182785306658, 43.34864371163504, 45.88200555528913, 44.11852496010916, 43.91373722893851, 42.01802199227469, 41.04563896996634, 38.702251298086985, 36.051996435437886, 34.33720881598336, 34.577550479343955, 32.82658706392561, 33.01543910162789, 34.552220821380615, 32.863381249564036, 33.845894745418, 33.30854538508824, 34.0966135433742, 34.903014523642405, 36.50605426515852, 42.16010570526123, 43.634228570120676, 45.814691407339915, 46.43700681413923, 45.31202745437622, 43.6045423916408, 48.13090467453003, 36.81559303828648, 40.40282637732369, 41.97323043005807, 40.61151899610247, 47.159452710832866, 45.5344740322658, 47.05252340861729, 44.98929752622332, 46.7966490473066, 46.06239816120693, 46.51299926212856, 46.57701996394566, 46.18855312892369, 38.39001662390572, 32.69302879061018, 35.10165309906006, 34.65044750486101, 35.448934486934114, 34.927684102739605, 35.561596052987234, 34.66723435265677, 35.41879667554583, 35.42683574131557, 34.629095690590994, 35.56766530445644, 36.01349994114467, 38.87229108810425, 42.54474408285958, 42.21741097314017, 41.59503650665283, 37.43920428412301, 39.13988011223929, 35.35582515171596, 34.13455418178013, 34.29540497916085, 34.524848393031526, 35.092825412750244, 35.00913436072213, 34.87798363821847, 33.625129631587434, 35.4266585622515, 39.64313466208321, 42.69156994138445, 45.273836680821006, 48.10366773605347, 51.76552472795759, 45.6639016015189, 49.47707993643624, 50.437077794756206, 45.23690700531006, 42.182874952043804, 37.63717583247593, 37.54769345692226, 38.16940437044416, 38.42566783087594, 43.107565539223806, 47.89084093911307, 52.720238481249126, 56.037489141736714, 37.47322266442435, 10.764504483767919, 4.463201420647757, 8.065221394811358, 4.389497969831739, 0.8778030031493732, 0.08629443483161074, 1.1597453228064944, 30.885197843824113, 52.11833340781075, 45.48993607929775, 36.27462019239153, 35.038837909698486, 48.28446681158883, 56.69575105394636, 37.97011266435896, 3.5726210602692197, 0.04673071691234197, 0.061816161897565634, 0.058067724108695984, 0.04577460678826485, 0.03352675114625266, 0.051589193886944225, 0.019069665211385915, 0.014870284923485346, 0.046376453779105625, 0.03254729602485895, 0.03290621051564813, 0.041344058101198504, 0.04232683804418359, 0.015140075535912598, 0.1172030009329319, 0.18172976773764404, 0.11388269838477884, 0.11698151353214468, 0.14781271985598973, 0.13662192677812918, 0.10568501826907907, 0.17031653730997018, 0.13107545939939363, 0.14252622638429913, 0.18538309527294977, 0.10755991909120764, 0.1539473413888897, 0.09532424993813038, 0.13403362780809402, 0.16230462651167596, 0.08886859991720744, 4.15740772656032, 43.123848642621724, 58.41552747998919, 56.08119331087385, 46.20462083816528, 37.71876505443028, 39.89974900654384, 50.92218017578125, 52.34568541390555, 14.649908474513463, 0.22704488757465566, 0.20474055941615785, 6.9661140867641995, 5.484904059341975, 4.414640460695539, 5.319105710302081, 26.449980293001445, 48.17991379329136, 54.212715012686594, 50.54450389317104, 49.563967159816194, 47.49427597863333, 46.839588914598735, 47.89679207120623, 48.7988315309797, 49.24462447847639, 48.047213622501914, 47.19828619275774, 46.99262646266392, 46.61234113148281, 47.74767330714634, 47.75514956883022, 44.48368058885847, 42.01433597292219, 40.77816459110805, 36.9138058253697, 35.24418844495501, 34.74103116989136, 36.36692353657314, 36.453227111271445, 39.02509934561593, 43.84410585675921, 46.33627183096749, 45.59131724493844, 47.190948895045686, 44.86138466426304, 46.80309350149972, 45.1303494317191, 44.064485345567974, 42.504642554691856, 38.835886001586914, 35.737166609082905, 35.235774176461355, 35.08659635271345, 33.37580394744873, 36.1030934878758, 34.318622384752544, 36.058426993233816, 35.98290702274868, 34.26055976322719, 36.48537990025112, 37.06127091816494, 44.37432983943394, 46.577384744371685, 48.226289544786724, 48.917708260672434, 48.321021284375874, 45.17272302082607, 47.40313993181501, 40.93304341179984, 42.75527102606637, 42.90146459851946, 43.185649394989014, 48.48101397923061, 45.66119875226702, 48.57185820170811, 45.70188045501709, 48.77364778518677, 48.32967873982021, 49.68160711015974, 48.92542770930699, 47.89278990881783, 40.73059374945504, 33.93753106253487, 37.99649844850813, 35.4506367955889, 36.99937983921596, 36.650809560503276, 36.67070920126778, 37.01419687271118, 37.19064637592861, 37.65104443686349, 37.79639727728707, 36.97356728145054, 38.61942529678345, 41.43669400896345, 46.457177434648784, 45.91061128888811, 43.22665766307286, 38.73838887895857, 41.92499256134033, 37.348262786865234, 36.053375652858186, 35.01362984521048, 36.39015136446272, 36.45855985369001, 36.9663724218096, 37.131235803876606, 36.837636198316304, 37.43232904161726, 42.20268774032593, 43.83364534378052, 48.049676758902415, 49.170935358319966, 54.928271770477295, 47.16181509835379, 50.883989402226035, 53.89464732578823, 48.53959076745169, 44.54065581730434, 41.63306747164045, 39.92909819739205, 41.85842881883894, 40.79932880401611, 45.23290831702096, 50.71297686440604, 56.33246796471732, 57.33777502604893, 40.62057249886649, 10.527997357504708, 7.575607027326312, 10.204459701265607, 8.807176096098763, 2.7205832259995595, 0.2209192905575037, 1.8382445148059299, 33.98131513595581, 59.15437807355608, 53.31495911734444, 46.60766151973179, 40.609285150255474, 54.979466097695486, 62.282165254865376, 45.77544798169817, 5.023332187107631, 0.1489115258944886, 0.14161698945931026, 0.1840190498956612, 0.15730281919240952, 0.130391713231802, 0.09447906671890191, 0.11585640747632299, 0.07920420529054743, 0.1609846723398992, 0.0852942606434226, 0.17569475514548166, 0.15763695697699273, 0.1636500528880528, 0.08996921085885592], [0.04597002826631069, 0.018106944459889616, 0.08846294454165868, 0.056648530797766786, 0.058364108204841614, 0.028183510094614964, 0.02147707692347467, 0.035330337937921286, 0.011273097679285067, 0.03991897510630744, 0.007900435976418001, 0.061651013259376795, 0.06298933537410838, 0.10003993939608335, 0.024509877398876206, 0.04911612034110086, 0.04990405556080597, 1.5654778884989875, 25.362639325005667, 46.07460267203194, 46.65568746839251, 32.17573887961251, 15.527589287076678, 30.431629862104142, 41.42780031476702, 44.36643321173531, 19.859707730157034, 0.31118593045643395, 0.17142126017383166, 1.3370590082236697, 3.6696706754820685, 2.175225632531302, 1.6068988144397736, 11.374477284295217, 33.93788194656372, 46.267898082733154, 48.03584636960711, 47.99455322538103, 47.578495093754356, 44.717716761997764, 46.08506318501064, 43.76396186011178, 46.564068521772114, 44.77593919209072, 43.85033144269671, 39.775768824986045, 44.37045969281878, 42.91565976824079, 40.60247591563633, 37.56571708406721, 37.24485274723598, 32.36604656491961, 30.42287860597883, 31.303701741354807, 31.65692731312343, 33.7415258543832, 35.638370173318044, 40.788711956569124, 42.28572218758719, 44.14087731497628, 43.82225724628994, 42.872424602508545, 44.276568685259136, 43.38680321829659, 44.696205139160156, 44.047121797289165, 42.273892879486084, 40.997706821986604, 35.64128841672625, 32.268149920872276, 31.932708263397217, 31.66141584941319, 32.08208063670567, 31.83140352794102, 31.92862967082432, 30.131287029811315, 30.33486577442714, 31.07641921724592, 31.755817549569265, 36.03983013970511, 40.30391182218279, 41.13186264038086, 43.38991601126534, 41.76139027731759, 41.49866499219622, 31.770981992994034, 39.31222670418875, 44.845678261348176, 41.229377133505686, 39.02360895701817, 44.928490366254536, 44.29643358503069, 44.36750323431832, 46.51644556862967, 45.480938162122456, 43.78470223290579, 44.66364588056292, 44.13846976416451, 44.59688758850098, 38.44325719560896, 32.116894585745676, 32.9629350389753, 32.11369146619524, 34.06638193130493, 33.08302770342146, 33.108777727399556, 32.429302964891704, 36.10207210268293, 36.28273221424648, 36.306936264038086, 36.780372619628906, 39.915792397090364, 44.931165422712056, 45.22610255650112, 46.234334809439524, 45.42071465083531, 42.091791016714915, 42.0798852784293, 39.533950669424875, 36.91091537475586, 35.931024823869976, 34.68995148794991, 33.601721150534495, 32.82655232293265, 31.91355902808053, 32.72462919780186, 32.34623030253819, 32.46055596215384, 36.352752685546875, 42.106747014181956, 44.16104793548584, 46.43837560926165, 48.229746273585725, 45.7592829976763, 48.720230034419465, 47.08472830908639, 43.824098518916536, 45.26157658440726, 40.03764295578003, 36.71336766651699, 35.67051601409912, 41.107172216687886, 45.46921655109951, 51.791229588644846, 52.6646146774292, 32.982369150434224, 4.793538757732936, 3.503335795232228, 9.446193235261099, 0.7277087228638786, 0.6468303884778703, 0.016411207416760068, 1.291435073528971, 33.45951931817191, 48.36344003677368, 42.399297441755024, 22.47286789757865, 29.624808515821183, 44.50888170514788, 47.50738722937447, 29.683826514652797, 1.7604542204311915, 0.04205296773995672, 0.010893287702596613, 0.08438433161271469, 0.03458387477855597, 0.017297922068142464, 0.004013119456690869, 0.03568129660561681, 0.03848733067778604, 0.038436579651066234, 0.06553722079843283, 0.03775578850348081, 0.034088544214942625, 0.014434015744232705, 0.03710447291710547, 0.05094689603096672, 0.048968488084418435, 0.019623222561287026, 0.04301017369808895, 0.008158242812247148, 0.016766680038667152, 0.031008799294275895, 0.06891942609633718, 0.038053790905645916, 0.027193244214036634, 0.013521225840252424, 0.04571876674890518, 0.003568184112996927, 0.04333168733865023, 0.06172641885599919, 0.029866427914904695, 0.0899191756865808, 2.136331136737551, 29.990947314671107, 51.909661633627756, 51.49342632293701, 39.44548967906407, 18.738258055278234, 32.15077747617449, 45.0932252066476, 47.9140305519104, 20.124270813805715, 0.20505658031574317, 0.040893242827483585, 0.4831757758344923, 5.169375070503779, 4.417054525443485, 1.921574043376105, 16.005830321993145, 35.522658348083496, 49.067198753356934, 48.2098605292184, 49.31823716844831, 49.839953081948416, 47.608559949057444, 46.91740526471819, 46.58246735164097, 48.439529759543284, 45.7454491342817, 44.697275161743164, 42.47398362840925, 45.89055183955601, 45.04881232125418, 42.299344130924766, 39.489562102726524, 39.45251778193882, 35.3664037840707, 31.196859291621617, 31.33295018332345, 34.009041922433035, 34.866536481039866, 36.74477352414812, 43.29490286963326, 44.63244846888951, 46.716782978602815, 45.1220498085022, 45.4516202381679, 45.286194052015034, 45.51200008392334, 46.66009610039847, 46.45696551459176, 44.53224502290998, 43.023697308131624, 37.16394097464425, 33.817233426230295, 32.965425968170166, 33.394689151218955, 33.5215493610927, 33.675372055598665, 34.316565717969624, 32.98677430834089, 31.79697867802211, 32.39384283338274, 33.19879164014544, 37.8567076410566, 42.51985910960606, 42.451982157570974, 46.562585081372944, 43.17163487843105, 42.69913305555071, 35.2664018358503, 38.788516657693044, 46.4098984173366, 42.25470890317644, 41.0135452406747, 46.772660391671316, 45.54956899370466, 46.06369400024414, 47.92060007367815, 46.99713584354946, 45.93438802446638, 45.50255053383963, 46.01554993220738, 45.11936432974679, 40.0063031060355, 33.51466369628906, 33.895438875470845, 33.25122274671282, 35.77314438138689, 34.46865136282784, 34.602960041591096, 34.17711189814976, 37.33367851802281, 36.887972423008506, 37.38375765936715, 36.6212032863072, 41.651094572884695, 47.04169464111328, 46.903345584869385, 47.57977703639439, 45.818721362522666, 45.45820713043213, 43.30485269001552, 40.37003435407366, 37.44314043862479, 37.308456557137625, 35.85004356929234, 35.82893146787371, 34.645055702754426, 34.32708529063633, 34.0866185597011, 34.91275242396763, 34.816832542419434, 38.661038058144705, 44.028771604810444, 45.5008100100926, 48.39061096736363, 50.31384107044765, 46.56156369618007, 49.4180133002145, 49.9649407523019, 46.5091985974993, 47.391685826437815, 42.12493044989449, 38.67069258008684, 37.85406732559204, 44.65134062085833, 48.47905458722796, 54.097798756190706, 54.632386207580566, 34.96655232565743, 9.595120055334908, 3.6251170890671864, 6.339456055845533, 4.262195680822645, 0.7711293729288238, 0.14918551833501884, 1.5809166772024972, 34.15782369886126, 52.74568625858852, 49.029150417872835, 33.66952862058367, 36.692040170942036, 50.57033382143293, 53.200894015175955, 34.6127222606114, 2.4783412303243364, 0.02766918224681701, 0.04209075535514525, 0.03498440721471395, 0.010404726373963058, 0.05281821418819683, 0.01132918962477041, 0.021476517132084285, 0.005227172547685248, 0.04488710333992328, 0.038532361654298644, 0.06291722067232643, 0.0667487857863307, 0.030262780575347797, 0.010573710431344807, 0.1858172762606825, 0.1421941513461726, 0.12232219481042453, 0.13655495537178858, 0.08445158800376312, 0.21555069434855664, 0.14777586183377675, 0.22989431396126747, 0.15251266051615986, 0.1009293088157262, 0.055227912563298426, 0.10518610504056726, 0.13430510966905526, 0.19173315167427063, 0.15292672972593988, 0.18550033255347184, 0.23727020674518176, 2.2267767063208987, 33.95104878289359, 58.40138789585659, 55.4185470853533, 42.981671128954204, 22.37029685292925, 39.82406227929251, 50.54050520488194, 53.69481713431222, 24.217685631343297, 0.568869483258043, 0.18999023948396954, 4.923709349972861, 7.637102058955601, 5.004436995301928, 3.8473417588642667, 13.657573699951172, 36.066896847316194, 50.54379170281546, 49.462506089891704, 51.365291118621826, 50.752532958984375, 49.45652716500418, 48.231684820992605, 47.9260960987636, 49.56355026790074, 46.74822357722691, 45.781683989933555, 46.040570395333425, 49.27805921009609, 46.50674935749599, 44.67866093771798, 41.41449451446533, 41.18195915222168, 35.78814901624407, 32.556593963078086, 33.59699290139334, 35.232567582811626, 38.30813210351126, 38.96721042905535, 45.72059195382254, 45.531246594020296, 48.8257349559239, 46.74670539583479, 46.62617152077811, 48.56771012714931, 47.62859855379377, 48.58529601778303, 48.56398589270455, 46.42828335080828, 45.95485046931675, 40.27074112210955, 36.14050258908953, 35.2568758555821, 34.61934389386858, 34.63599872589111, 34.15989078794207, 35.55737154824393, 34.33665296009609, 32.48170975276402, 34.74135078702654, 35.114177227020264, 39.37701170785086, 44.8807875088283, 43.75876113346645, 47.65167352131435, 45.0906126839774, 43.572563307625906, 38.45238018035889, 43.09766435623169, 46.79160465512957, 43.160670621054514, 43.02050461087908, 48.620047433035715, 48.9723037311009, 47.035489899771555, 50.98092024666922, 48.95936271122524, 48.37358440671648, 47.30508347920009, 46.84031500135149, 47.71398149217878, 42.04419585636684, 36.416954040527344, 36.61719764981951, 36.047705922807964, 37.66139725276402, 36.17469120025635, 35.938459396362305, 36.90710081372942, 38.89596012660435, 39.081042766571045, 39.965642247881206, 39.20572819028582, 44.206259863717214, 49.63023907797677, 50.86739362989153, 50.88189452035086, 48.5893120765686, 47.87738922664097, 45.77252973828997, 44.381767886025564, 40.78603342601231, 39.476291043417795, 38.42873893465315, 37.25352757317679, 36.5060646874564, 36.76950911113194, 35.076344285692485, 36.41138505935669, 35.34222057887486, 40.10312625340053, 46.19536236354283, 48.307086672101704, 50.3614570753915, 51.7795844078064, 47.63777712413243, 51.17933995383126, 51.467658928462434, 47.95335735593523, 50.70946455001831, 44.12957606996809, 41.59272623062134, 39.034059047698975, 46.04176548549107, 50.508526120867046, 55.67565475191389, 57.26103912081037, 35.01664188929966, 6.663763659340995, 6.848762920924595, 18.456334897450038, 5.63941592829568, 0.9979725863252367, 0.17866797346089566, 1.9758069046906062, 39.5207074029105, 59.56431484222412, 54.36197274071829, 33.84792709350586, 40.20227704729353, 57.15403686250959, 59.52564811706543, 42.949223041534424, 3.367240126643862, 0.08382076078227588, 0.1591739473598344, 0.20767306563045296, 0.1362388123358999, 0.11332789422678095, 0.11862286260085446, 0.12858367525041103, 0.12436877856297152, 0.1830820066056081, 0.1651699441884245, 0.14196775135185036, 0.16591462280069078, 0.09882877474384648, 0.075946945430977], [0.02661109509478722, 0.0515435725849654, 0.0409966040668743, 0.07835301703640393, 0.050448719012950144, 0.07325888145714998, 0.03721523018819945, 0.019580844656697342, 0.04915792488359979, 0.029870163250182356, 0.02367056520389659, 0.039376469395522556, 0.030854245980403254, 0.017102030704596212, 0.025876295952392474, 0.03952307367165174, 0.03696219090904508, 0.514518773981503, 17.806011302130564, 43.99435370309012, 44.76997068950108, 33.22467367989676, 27.14464381762913, 31.463558946337017, 45.01215015138899, 40.71648890631539, 27.955542019435338, 1.0749547183513641, 0.055565195357693095, 0.5661759163652147, 6.328516551426478, 2.8194843190056935, 1.1926897721631187, 3.4525883240359168, 14.51926497050694, 35.34451001031058, 46.676750932421, 46.877390589032856, 44.93383353097098, 44.95962871823992, 46.150640283312114, 46.59622825895037, 45.94102355412075, 46.63677447182791, 45.32474960599627, 46.46474402291434, 43.71369511740548, 42.25028984887259, 40.63084193638393, 34.499456201280864, 32.38752344676426, 31.979368891034806, 31.12002263750349, 33.12951462609427, 34.30422224317278, 37.73331110818045, 39.881912980760845, 43.40266595567976, 44.761803082057405, 43.68799720491682, 44.22393260683332, 42.24940047945295, 44.248126234327046, 44.79960823059082, 44.939079420907156, 45.06083965301514, 44.66116189956665, 42.9391759463719, 41.570985317230225, 34.231773376464844, 32.212143966129844, 32.16651514598301, 34.224133832114084, 34.016149929591585, 32.65238182885306, 32.084460394723074, 32.02694320678711, 31.868833473750524, 31.519144535064697, 34.00974021639143, 36.163310050964355, 40.5689126423427, 43.766619546072825, 44.35348524366106, 37.73800809042794, 42.648741245269775, 45.585880279541016, 44.03307253973824, 44.261029039110454, 35.49471269335066, 40.571153436388286, 41.52586718967983, 43.50940765653338, 44.28608424322945, 44.5061024257115, 44.25691223144531, 45.914352893829346, 44.064905711582725, 44.6026337487357, 36.9061940738133, 31.771190438951763, 31.451781749725342, 33.31616408484322, 33.55634593963623, 33.78931556429182, 33.01831912994385, 35.59342227663313, 37.869137968335835, 40.90305151258196, 41.11370699746268, 40.88461446762085, 45.257122789110454, 43.65944358280727, 45.91039589473179, 45.39984573636736, 45.1986745425633, 44.77130821772984, 44.78237669808524, 45.09034865243094, 42.53085115977696, 43.329456261226106, 41.801186084747314, 41.110274587358745, 37.79149184908186, 36.74039963313511, 33.098056656973704, 31.990937641688756, 33.749266147613525, 34.07488305228097, 36.1881741796221, 43.4093952860151, 44.967386381966726, 48.00979062489101, 47.28418329783848, 49.72200393676758, 39.08605241775513, 44.72578362056187, 46.051159449986045, 43.48836503710066, 40.44477265221732, 36.8039721761431, 42.514529841286794, 45.908141204289024, 51.043523515973774, 53.729252406529014, 28.29458805492946, 11.202089871679034, 2.2455305457115173, 4.345047737870898, 3.467786205666406, 0.6094604794468198, 0.07792126520403794, 1.4183396867343356, 32.6161539213998, 46.047438689640586, 35.208162035260884, 14.122852870396205, 29.660442352294922, 46.94059140341622, 47.779978956495015, 26.753812858036586, 0.6508266883237022, 0.09749012014695577, 0.0626117984897324, 0.037680647535515685, 0.03831781227407711, 0.03572147944942117, 0.058208649046719074, 0.06030279810407332, 0.03740039900211351, 0.03266526273052607, 0.019236052175983787, 0.016845958373908485, 0.01421992267881121, 0.07856476067432336, 0.030199513970209018, 0.03537818822743637, 0.0739089994292174, 0.03960079985803791, 0.03221087836261306, 0.02605134272016585, 0.05052096942173583, 0.0563341994503779, 0.03313614567741752, 0.013270037265361419, 0.06937816326639482, 0.04481350943180067, 0.03369564529774444, 0.05175644598369088, 0.012957347972717668, 0.07250965666025877, 0.02073103784849601, 0.041769580982093296, 0.6031737710748399, 20.98752542904445, 49.41481712886265, 50.760019642966135, 35.7300968170166, 22.492705004555837, 35.14116750444685, 49.76718807220459, 47.54490750176566, 29.260997363499232, 0.9571049106972558, 0.020355631564078585, 0.2922202795743942, 3.9711742912020003, 5.812249328408923, 1.8135712444782257, 5.155783525535038, 17.98824691772461, 38.96456663949149, 48.59951203210013, 48.25431857790266, 47.199661936078755, 46.11627449308123, 45.96777759279524, 47.26666341509138, 44.352613244737896, 47.06348419189453, 45.458134174346924, 46.86951133183071, 46.72284875597273, 42.35213654381888, 42.20876046589443, 37.09428180967058, 32.906008447919575, 32.05504519598824, 32.47252076012747, 33.79482201167515, 34.13536017281668, 39.81155204772949, 41.731811795915874, 44.03246109826224, 45.60911158152989, 45.665027209690635, 44.8788628578186, 43.976145948682515, 46.55435494014195, 44.940750462668284, 46.590874671936035, 46.21093675068447, 46.31738315309797, 46.20744528089251, 43.21093388966152, 35.49506705147879, 33.419153758457725, 34.12098434993199, 35.16288409914289, 34.836565426417756, 32.81368425914219, 32.68643495014736, 32.372894014631, 32.77398225239345, 34.94894559042794, 36.289520604269846, 38.79722622462681, 41.83177900314331, 44.87413460867745, 44.58557939529419, 39.73205770765032, 42.75372505187988, 47.47659976141793, 44.836972168513704, 45.942830085754395, 36.8595403943743, 42.11906269618443, 41.29368618556431, 45.20486191340855, 45.47844723292759, 45.82621499470302, 45.80461304528372, 46.42954792295183, 44.20563799994332, 45.49831908089774, 38.750537804194856, 32.56493180138724, 34.014214856284006, 34.11292791366577, 35.803115436008994, 33.586046014513286, 33.601266043526785, 37.6786287852696, 39.53862680707659, 42.447368553706575, 42.486163820539204, 42.950605733054026, 47.23037992204939, 46.46927424839565, 47.294647284916465, 46.9072504724775, 47.37610796519688, 47.96455785206386, 46.870699473789756, 45.94165236609322, 45.61502797263009, 43.87447990689959, 41.423620973314556, 41.59267064503261, 38.15209640775408, 37.686504568372456, 34.545019013541086, 33.66442516871861, 35.49661649976458, 35.51136057717459, 38.505193437848774, 46.027775287628174, 47.2219899722508, 49.98072705950056, 48.93754536764962, 50.34307214191982, 42.634275095803396, 46.46790892737252, 49.859442778996055, 45.03057677405221, 42.34861728123256, 39.34111731392996, 44.09076343263899, 47.75314153943743, 53.02647338594709, 53.409058570861816, 30.683196340288433, 7.772719604628427, 6.575575385774885, 7.27630512203489, 5.9703338742256165, 0.764407750751291, 0.1736196864928518, 1.55403833091259, 36.011467593056814, 51.69566753932408, 46.16107300349644, 18.16190845625741, 33.879437174115864, 52.6573920249939, 54.1035692351205, 33.18861600330898, 1.1866235605307986, 0.04599034360476902, 0.054204420519194434, 0.07058628129639796, 0.032825709121035676, 0.03758210728743246, 0.04008379465501223, 0.07553892196821314, 0.008827051879572017, 0.05039158297170486, 0.07843143532850913, 0.08925736655614205, 0.05910693441650697, 0.05948219820857048, 0.08166958085660424, 0.06328061010156359, 0.12103638452078615, 0.1292059597160135, 0.18874183004455908, 0.06577984456505094, 0.19127140859408037, 0.1148290918873889, 0.11154857863272939, 0.1213959673685687, 0.2516704026077475, 0.08993113147360937, 0.14979130082896777, 0.08767670565950018, 0.1210384201258421, 0.17767967363553389, 0.16530072502791882, 0.16720918619206973, 0.7627494111657143, 22.507872922079905, 54.88817024230957, 56.635332993098665, 43.66881670270647, 37.23789412634713, 40.892893246241975, 54.33448566709246, 50.12005581174578, 34.51512091500418, 1.484881498983928, 0.09653498711330549, 1.5393180293696267, 12.666296788624354, 7.701522282191685, 3.5521258286067416, 5.16994525705065, 16.314073256083898, 38.5347649710519, 47.84663649967739, 48.488931451525005, 47.08261605671474, 48.40514659881592, 47.00964607511248, 50.739807333265034, 46.103305680411204, 49.049800464085166, 46.754754883902415, 48.2407591683524, 46.70993900299072, 45.61780030386788, 44.643346718379426, 37.99593217032296, 34.51837614604405, 34.99139213562012, 34.40816034589495, 37.63649490901402, 37.05086599077497, 42.12747349057879, 43.79506894520351, 46.41662427357265, 48.25531564440046, 46.83491277694702, 47.38403238568987, 45.721366677965435, 48.89556087766375, 48.49903065817696, 47.18512283052717, 47.99337203162057, 48.92823478153774, 48.571295397622244, 45.69729116984776, 38.258143288748606, 34.782772472926546, 35.85156869888306, 36.98787014825003, 37.91983897345406, 35.868897506168906, 33.73978533063616, 34.88827044623238, 35.39308834075928, 35.40239545277187, 38.45587165015084, 40.219494683401926, 43.69866616385323, 47.17616660254342, 47.06498500279018, 41.4813882963998, 46.577162402016775, 47.17027800423758, 47.22424118859427, 47.184851850782124, 40.38605342592512, 44.12369441986084, 44.15390171323504, 46.960730757032124, 46.98756469999041, 48.59662505558559, 45.99319062914167, 50.3041205406189, 46.49363463265555, 46.879478522709434, 40.48071568352835, 33.88762215205601, 34.84529931204659, 36.47250836236136, 37.329363686697825, 35.26046460015433, 35.27121346337454, 40.125971930367605, 42.248587540217805, 45.75873408998762, 45.157721860068186, 44.33997794560024, 50.18828017371041, 48.354105131966726, 49.56675338745117, 48.16314084189278, 48.19093711035592, 49.339022704533164, 51.79650674547468, 47.704344340733115, 46.7630649294172, 48.84759051459176, 44.868881770542686, 44.18862533569336, 41.287446703229634, 40.198844637189595, 37.004441601889475, 35.161779335566926, 37.62128530229841, 36.47586781638009, 40.16549675805228, 48.17663771765572, 50.24640185492379, 51.65170281273978, 50.442695413317, 51.01254497255598, 43.60590771266392, 48.654434067862375, 50.536360604422434, 47.61825268609183, 44.71396126065935, 41.08524717603411, 46.269294670649934, 49.821533407483784, 54.927371978759766, 56.43439456394741, 31.323177542005265, 13.824137653623309, 7.960532018116542, 11.235614929880414, 11.257427062307086, 2.9542530987943922, 0.5220631605812481, 2.1550758566175188, 39.949657917022705, 58.182092326028005, 46.26744644982474, 22.235315935952322, 40.33446652548653, 58.903839928763254, 62.15779250008719, 39.181895869118826, 2.380249385322843, 0.23326750152877399, 0.1421980732785804, 0.17936063557863235, 0.15039295783000334, 0.1036976638383099, 0.13620610694800103, 0.22316407438899788, 0.0786934584113104, 0.1417778701122318, 0.19512520251529558, 0.1735363488218614, 0.12737592362931796, 0.16194482653268746, 0.10277664754539728], [0.09089432550328118, 0.048648039743836434, 0.06173230853996106, 0.06832347557480846, 0.0036337551926927908, 0.03034534810909203, 0.04298300176326718, 0.043696966487914324, 0.020387683862021992, 0.0588462141209415, 0.03095924248918891, 0.0645990918523499, 0.03405726375058293, 0.02861813721912248, 0.01607389239195202, 0.04740434951548066, 0.13645979762077332, 0.09096345465098109, 9.56717266355242, 38.86205986567906, 44.201364857809885, 38.257041999271934, 10.843865939549037, 21.69884725979396, 35.49123511995588, 36.30819041388375, 33.73005090441023, 2.680856466293335, 0.02322377703551735, 0.16637632516877993, 1.4783313018935067, 3.7956306593758717, 1.282991492322513, 2.407257467508316, 4.973842339856284, 20.46150163241795, 39.570341859545024, 47.296012605939595, 46.065910475594656, 46.92996760777065, 47.0603540284293, 47.3836259160723, 47.6138197353908, 48.27706698008946, 47.69867461068289, 44.694739069257466, 43.31446552276611, 40.2575569152832, 34.984589849199565, 31.654533658708843, 31.520885058811732, 31.440087931496755, 33.44896847861153, 35.24329212733677, 37.951467173440115, 40.9904911177499, 41.746323108673096, 43.33924279894148, 42.80439479010445, 42.97917325156075, 43.00960636138916, 45.997474193573, 44.410665443965364, 44.88845484597342, 45.18556329182216, 44.10889823096139, 44.940073013305664, 43.416947977883474, 42.006251743861604, 38.20147030694144, 32.0172678402492, 31.60082060950143, 32.21950905663626, 32.78910500662667, 32.86255441393171, 33.02324192864554, 32.00305530003139, 31.80809579576765, 30.558945178985596, 32.18112025942121, 34.44189732415335, 37.206179073878694, 39.77299301964896, 41.20665652411324, 44.492525645664756, 42.35642358234951, 43.707174233027864, 45.5059551511492, 43.11876950945173, 36.856424127306255, 39.05081810270037, 42.56775999069214, 42.75866869517735, 44.73064735957554, 43.94629301343645, 45.37343563352312, 45.04758596420288, 45.62793772561209, 42.5414263180324, 38.09688254765102, 32.46969631740025, 32.20261103766305, 32.940829345158164, 32.97706420081002, 32.87481451034546, 34.629578590393066, 35.79383611679077, 39.75126600265503, 43.847739764622276, 43.42082159859793, 44.244728565216064, 44.62483671733311, 46.64042922428676, 45.67575522831508, 43.68771232877459, 44.55350998469761, 45.36158200672695, 48.266533511025564, 44.9549560546875, 45.74173184803554, 45.434861183166504, 45.32247059685843, 44.40960584368025, 44.323003496442524, 43.502091203417095, 40.7353949546814, 35.040842464991975, 33.11360672542027, 33.127444062914165, 33.44455289840698, 35.921985217503135, 42.98481866291591, 43.756301471165244, 47.25896481105259, 47.90413631711687, 46.06269345964704, 47.05464955738613, 49.82040432521275, 49.18291752679007, 46.968988691057476, 41.45170211791992, 40.52783489227295, 46.021754673549104, 49.97238227299282, 50.59006323133196, 24.42166563442775, 7.27520991223199, 4.128238754613059, 3.732432884829385, 3.134788359914507, 0.7730951703020504, 0.13094523495861463, 2.2743961853640418, 30.218928132738384, 44.57385083607265, 41.281050886426655, 33.03967441831316, 35.67927074432373, 45.9671175139291, 48.23809106009347, 22.968416895185197, 1.007376647421292, 0.0913176770721163, 0.029204676459942545, 0.0362003012560308, 0.06192413717508316, 0.020372988489855613, 0.08420943921165806, 0.0637746989460928, 0.04176400342424001, 0.008230667943800134, 0.07279678553875003, 0.0430154730565846, 0.034465670585632324, 0.058848989329167774, 0.030757283326238394, 0.07115399797580071, 0.0635849330574274, 0.06875598736639534, 0.007847489040744091, 0.0163555675452309, 0.029219376921121563, 0.04050671535411051, 0.020943777236555303, 0.0477854181746287, 0.05057327090097325, 0.01370451765667115, 0.0731824648433498, 0.0331338454437043, 0.02061335782387427, 0.010808418238801616, 0.021875918111098663, 0.021297543342890482, 0.18891117881451333, 12.650209103311811, 46.33350644792829, 50.48251553944179, 42.930400371551514, 19.250757183347428, 26.90274054663522, 42.52460820334298, 40.73476961680821, 35.863015856061665, 2.914910444191524, 0.07244657325957503, 0.05598791249628578, 2.3512764828545705, 5.870944236006055, 3.5899010130337308, 3.0805081639971053, 6.403955749103001, 24.56542386327471, 41.27243512017386, 48.0803530556815, 46.29002809524536, 48.26439693995884, 47.65230928148542, 48.953039850507466, 48.37287221636091, 49.20268515178135, 48.16783782414028, 45.751320362091064, 44.19833196912493, 42.39263064520699, 37.01716375350952, 33.77574225834438, 32.02221495764596, 32.460052217756, 33.55417462757656, 36.019100189208984, 38.997511523110525, 43.38200201307024, 43.73726340702602, 45.10764619282314, 44.476009777614046, 43.83009134020124, 43.97513498578753, 45.182186467306956, 46.65878289086478, 45.90722056797573, 46.85430172511509, 45.538920879364014, 46.61016634532383, 45.45094973700387, 43.821003096444265, 39.03487893513271, 33.957625252859934, 34.21178340911865, 34.16421604156494, 33.618389878954204, 34.36157267434256, 33.50191722597395, 33.77112170628139, 33.80429588045393, 32.29082189287458, 34.134366580418174, 36.907180718013215, 39.56446368353707, 41.9098732812064, 43.87288876942226, 46.502858366285054, 44.97254889351981, 44.28084182739258, 46.7228696005685, 43.7441212790353, 40.02980191367013, 42.49157994134085, 45.40131180627005, 46.1229065486363, 45.31797511237008, 46.572781562805176, 46.75571026120867, 45.596469334193635, 46.29746961593628, 43.98136057172503, 39.05277749470302, 33.77866050175258, 34.02035706383841, 33.25575992039272, 34.335978984832764, 34.40257052012852, 35.076087202344624, 38.55130863189697, 42.343531199863975, 45.570118291037424, 45.18864829199654, 46.70978266852242, 46.04553140912737, 48.341858931950156, 46.79094457626343, 44.37377050944737, 45.57527038029262, 45.15227099827358, 49.3509875025068, 46.95126036235264, 48.22170025961739, 47.15000663484846, 46.85235970360892, 47.29038803918021, 46.7555365562439, 44.043331554957796, 40.90066828046526, 36.60255779538836, 34.32981593268258, 35.438936029161724, 36.354149273463655, 38.25819887433733, 44.27557509286063, 46.66221182686942, 49.00343860898699, 48.81821353094918, 46.21640498297555, 46.8626708303179, 51.143098149980815, 51.36358533586775, 49.17292949131557, 43.93278224127633, 42.319059644426616, 47.987601552690776, 51.73757559912545, 52.27861097880772, 25.52071257999965, 6.554053340639387, 5.099999478885105, 4.621592555727277, 6.509008169174194, 0.8230550523315157, 0.10345361514815263, 2.2446127321038927, 33.033229964120046, 51.300023215157644, 43.3372278213501, 28.569203444889613, 37.72438267299107, 50.80747931344168, 55.95389536448887, 28.145151410784038, 1.4102094258580888, 0.0347318089833217, 0.06165855178343398, 0.10672118874000651, 0.04645325376519135, 0.018238322410200323, 0.039975931335772784, 0.05300510648105826, 0.02776164960648332, 0.02800729624660952, 0.05902287071304662, 0.023608716736946787, 0.019384395198098252, 0.06092137098312378, 0.026241381719176258, 0.3256519984986101, 0.15644080830471857, 0.19866919091769628, 0.13951353090150015, 0.15811700693198613, 0.16232600036476338, 0.17425940930843353, 0.1633819229900837, 0.14961189617003712, 0.14883922120290144, 0.17948695165770395, 0.17006896702306612, 0.0700991949332612, 0.18366530244903906, 0.1443072451012475, 0.14149631879159383, 0.18272915482521057, 0.29767730246697155, 13.111083115850176, 51.20028182438442, 57.17330074310303, 50.102824279240195, 19.498300654547556, 29.626034872872488, 45.33596747262137, 45.915996142796104, 40.3469420160566, 3.4944349357060025, 0.10948281269520521, 0.6432616742593902, 5.708388958658491, 8.572975771767751, 5.285812982491084, 5.41555061510631, 6.195754281112126, 23.91158274241856, 41.244690963200156, 48.53686012540545, 47.909368310655864, 50.033588954380576, 50.56606762749808, 50.332458768572124, 51.825470311301096, 53.29920060294015, 50.7187751361302, 48.87436539786202, 47.94110768181937, 44.73404502868652, 38.28913572856358, 35.4613995552063, 35.019712993076865, 34.7554486819676, 36.07066624505179, 38.84787859235491, 42.17925146647862, 45.30955389567784, 44.956064292362754, 46.917710985456196, 45.84635434831892, 46.984792368752615, 45.88038662501744, 48.57389054979597, 47.64549657276699, 47.24898719787598, 47.94134392057146, 47.73765400477818, 47.79111691883632, 46.883338247026714, 44.97298315593174, 41.24400309153965, 35.739317076546804, 35.41478756495884, 36.14411217825753, 36.02401951381138, 37.110627446855815, 36.54875789369856, 35.57347747257778, 35.250685010637554, 32.43792915344238, 35.77187286104475, 37.81676244735718, 39.93546274730137, 43.57555798121861, 45.341018812997, 48.03250776018415, 46.94018145969936, 47.45329550334385, 49.742497648511616, 45.03363050733294, 42.811266558510916, 43.724961621420725, 47.22957740511213, 48.016318457467214, 46.302208287375315, 48.77994632720947, 48.863265650612966, 47.43706798553467, 49.54891388756888, 44.385026591164724, 41.79931354522705, 36.33301632744925, 35.462855202811106, 35.45597301210676, 36.436874525887625, 36.49287005833217, 37.859111717769075, 40.68343979971749, 44.880169119153706, 47.877889496939524, 48.48348753792899, 49.57654687336513, 47.81338936941964, 51.317595209394185, 48.47962433951241, 46.49673005512783, 45.91322728565761, 46.13632352011544, 52.99051298413958, 47.60969597952706, 49.774375983646934, 49.87474618639265, 49.501259667532786, 49.46438210351126, 47.81543213980538, 47.771884305136545, 44.4222411428179, 39.32334034783499, 36.159835951668875, 36.91726950236729, 37.75946760177612, 39.251370906829834, 46.575394085475374, 47.835029533931184, 52.17616326468331, 51.898402077811106, 48.56216893877302, 48.48020451409476, 53.766324520111084, 53.72485419682094, 52.33760118484497, 45.51721470696585, 44.791499682835166, 50.350072452000205, 54.689239842551096, 53.61682707922799, 29.37299190248762, 10.942499961171832, 9.809383392333984, 10.129302774156843, 6.072748150144305, 2.1255010664463043, 0.3505918245230402, 3.3211457771914343, 37.86685201099941, 56.400254590170725, 50.83992392676217, 42.25418431418282, 49.03364590236119, 58.6168098449707, 63.5681517464774, 33.542432171957834, 1.9800863436290195, 0.1572638169995376, 0.12772796116769314, 0.26627863730703083, 0.11628431880048343, 0.1519577138658081, 0.18848067548658165, 0.16196489759853908, 0.15862012707761355, 0.11617016206894602, 0.18743103609553405, 0.13384118170610496, 0.11121999804994889, 0.15307420252689294, 0.16065091453492641], [0.05338359670713544, 0.02193544089927205, 0.03385796444490552, 0.04246686053063188, 0.04480125508936388, 0.008506041203093315, 0.09812249442828552, 0.010535624260748071, 0.04397760857162731, 0.06520343585205929, 0.006819704838562757, 0.022803500926654254, 0.051023662090301514, 0.008951736081923758, 0.03163568761997989, 0.047522109267967086, 0.1126440598496369, 0.10380242964518921, 2.991387094770159, 35.05263008390154, 43.20307547705514, 31.790551594325475, 20.983292239052908, 33.03958061763218, 38.80782570157732, 40.03768811907087, 37.35066338947841, 6.665573665073939, 0.031895437610468695, 0.12758907862007618, 1.6989514806440897, 3.8589982305254256, 3.5005369739873067, 0.7757427596620151, 1.594484337738582, 9.785655294145856, 30.140392644064768, 45.44598872320992, 47.53178582872663, 46.4087484904698, 45.83627946036202, 44.41105801718575, 43.33967358725411, 42.34180109841483, 43.45753240585327, 41.487290791102815, 40.43982553482056, 33.48971618924822, 32.843373911721365, 30.39873708997454, 31.870358603341238, 33.3354036467416, 37.669307776859824, 39.75622354234968, 40.830630438668386, 42.45155831745693, 42.872768538338796, 42.58129160744803, 39.97816290174212, 41.050242151532856, 42.181495734623496, 42.800246715545654, 43.41186537061419, 45.59409999847412, 43.67333997998919, 44.27101012638637, 43.37298672539847, 43.82025269099644, 43.455701555524556, 39.899703843253, 33.493263244628906, 31.275940213884624, 31.827317987169536, 32.7511886869158, 32.24426201411656, 32.43856143951416, 33.421453612191335, 32.33935506003243, 31.2798798424857, 31.354322842189244, 33.4610652923584, 34.12854398999895, 37.819708483559744, 38.99013601030622, 39.58274786812918, 41.03725249426705, 44.79730142865862, 43.72443355832781, 45.362186500004356, 38.53788471221924, 36.2977021081107, 42.65705476488386, 42.47329923084804, 42.20357016154698, 44.661610058375764, 43.69858973366873, 45.24131563731602, 43.8857672555106, 41.75363261359078, 37.546574796949116, 30.911600998469762, 33.187865597861155, 32.76328897476196, 35.25622272491455, 32.87244864872524, 33.84930978502546, 35.759821210588726, 43.697279998234336, 45.973023482731406, 47.33944926943098, 44.505810601370676, 47.08883816855294, 47.07419484002249, 46.706638608660015, 47.619930676051546, 45.42754125595093, 46.756161894117085, 45.2474022592817, 48.07613549913679, 46.8091801234654, 47.007311480385916, 47.83584247316633, 46.67280088152204, 47.2926218850272, 45.63458020346505, 43.134180613926475, 42.648438998631065, 38.28456033979143, 33.02020556586129, 32.133278438023154, 33.9797865322658, 36.902824197496685, 42.14303050722395, 43.63244635718209, 46.75398015975952, 49.93009901046753, 47.1627322605678, 47.90873255048479, 44.670274462018696, 48.63152585710798, 44.3409298488072, 42.71987690244402, 47.42917135783604, 50.25286715371268, 47.70619950975691, 17.237052849360875, 1.7114571524517876, 3.129679262638092, 4.861757040023804, 10.412143962723867, 0.009339330551613654, 0.06155556373830352, 3.1185834237507413, 32.094417163303916, 42.71757010051182, 40.58247552599226, 28.288405895233154, 32.099492822374614, 49.180923393794465, 42.47203465870449, 18.23621075493949, 0.37999695379819187, 0.027402699492605667, 0.03615116174998028, 0.03406670217269233, 0.03840450190805963, 0.060750210524669716, 0.05193650542891451, 0.034401128334658485, 0.042562164166676145, 0.03543273565758552, 0.0018315844187912131, 0.018498006243524805, 0.071691133081913, 0.021824968612885902, 0.06078536542398589, 0.062180141652269025, 0.061779439582356384, 0.019603058196870343, 0.05241031625441142, 0.00276050712896644, 0.031405450510127206, 0.03632923987294946, 0.01698400462711496, 0.04773347292627607, 0.02155297276164804, 0.019028503580817153, 0.03750516141631773, 0.047265327868184874, 0.028181701798790267, 0.02215084862629218, 0.08675707357802562, 0.07388369685837201, 0.04477698389174683, 4.684581884316035, 40.76478583472115, 49.04665987832205, 39.297975948878694, 19.001629522868566, 30.882689544132777, 43.26978165762765, 43.270413943699424, 41.602335589272634, 6.407313900334494, 0.02147918038203248, 0.04512331834329026, 0.8720165650759424, 7.2866983243397305, 5.1279242890221735, 3.7216940096446445, 4.96942241702761, 12.905723895345416, 32.8840069770813, 46.296795640672954, 51.280943461826865, 48.49332618713379, 47.14646305356707, 47.11642599105835, 45.73226840155465, 43.715981074741904, 44.033485957554404, 43.216759954180034, 42.68485450744629, 36.046267645699636, 34.296078954424175, 32.252012729644775, 34.08709798540388, 35.047224385397776, 38.22952365875244, 42.846191678728374, 42.53867483139038, 44.55821738924299, 45.19450214930943, 44.68709257670811, 41.31807088851929, 43.79794897351946, 42.73322091783796, 44.68757547651018, 45.977859428950715, 48.146663188934326, 45.87087106704712, 46.10901015145438, 45.97983966554914, 46.37401097161429, 45.789969716753276, 41.342636244637625, 34.80556256430489, 33.243809018816265, 33.238476276397705, 33.69666133608137, 33.29057386943272, 33.727191720690044, 35.842845235552105, 33.598452023097444, 33.29273475919451, 33.81636142730713, 35.35854537146432, 36.139769554138184, 40.035839898245676, 40.52412802832467, 41.903539998190745, 42.82286657605852, 46.06810958044869, 46.970249789101736, 47.79996197564261, 39.578127316066194, 39.08289793559483, 44.512626784188406, 44.71455880573818, 43.58253049850464, 45.77459682737078, 45.857978684561594, 46.98970474515642, 45.37866415296282, 43.26148203441075, 37.96698944909232, 32.350138664245605, 34.05552537100655, 34.66291952133179, 35.342818123953684, 35.49617181505476, 34.555872099740164, 37.08694451195853, 43.93637445994786, 47.69650329862322, 48.77977957044329, 48.44960117340088, 48.33985090255737, 47.55784852164132, 47.49869155883789, 47.906196457999094, 46.64932986668178, 46.936703886304585, 46.41065577098301, 49.246215615953716, 46.59794446400234, 48.05590581893921, 48.14559316635132, 48.95195245742798, 49.41853094100952, 48.06295824050903, 45.28193480627877, 44.193826062338694, 38.75866024834769, 34.361454554966514, 33.839408602033345, 34.78183446611677, 38.79249450138637, 45.343252658843994, 47.2918575831822, 49.081248010907856, 51.67914819717407, 48.635507174900596, 50.11093977519444, 48.86309541974749, 50.22988598687308, 46.89278432301113, 44.90512704849243, 48.22647019795009, 52.732713971819194, 49.27445656912667, 19.40987093108041, 3.5643917875630513, 4.765735975333622, 6.312122276851109, 5.48600925718035, 0.3223209072436605, 0.06711389869451523, 3.070902496576309, 34.623429434640066, 49.87092815126692, 42.30770628792899, 29.913853577205114, 39.30610186713082, 55.192334583827424, 50.198163986206055, 22.761574234281266, 0.4507345551890986, 0.022597365380663956, 0.010319624511924173, 0.009466195395881576, 0.012946468511862414, 0.016634387762418816, 0.02217345910945109, 0.09874199011496135, 0.010132431967316993, 0.026543426493714963, 0.016920369916728566, 0.01668785123287567, 0.035703328637672324, 0.011469516603808318, 0.037750180411551676, 0.2010875575776611, 0.13633087596723012, 0.1344756255192416, 0.13793937037033693, 0.13144161046615668, 0.15709256833153112, 0.18530874140560627, 0.10505658627620765, 0.09286585649741547, 0.09304499652768884, 0.06100632356745856, 0.08180839555071932, 0.0921069218644074, 0.16048497201076575, 0.12362989463976451, 0.2239055638866765, 0.14730901617024625, 0.20769666507840157, 5.427487620285579, 47.00482749938965, 54.25918803896223, 44.634925501687185, 31.038905893053325, 43.24446242196219, 49.47428676060268, 48.66744804382324, 46.05123588017055, 8.185594592775617, 0.128828477114439, 0.34593251453978674, 4.09458862883704, 8.8388911485672, 9.807028821536473, 3.3321940643446784, 3.3380937363420213, 11.892194509506226, 33.185909679957796, 48.03344924109322, 51.30015523093087, 51.18209491457258, 48.59581559044974, 49.134558064596995, 48.48051370893206, 46.81467267445156, 45.74787058149065, 44.987803663526265, 43.26638398851667, 37.016712120601106, 36.775498458317344, 34.21329811641148, 36.182362011500764, 36.94764007840838, 40.828792640141074, 44.343146324157715, 44.565339292798726, 46.68868446350098, 46.630284854343955, 45.9206931250436, 42.686772210257395, 45.83357661111014, 45.57960605621338, 47.25622027260916, 47.226245743887766, 49.5234591620309, 47.72621726989746, 48.06640107291085, 46.70884813581194, 47.53230694362095, 47.18587671007429, 43.404274463653564, 37.416497571127756, 34.7198600087847, 35.73289346694946, 36.74134111404419, 35.72345086506435, 35.56956563677107, 38.26632479258946, 36.146252223423545, 33.400779247283936, 35.00881821768624, 37.925244671957834, 37.231307234082905, 42.19477721623012, 42.61969082696097, 42.905379908425466, 45.92225299562727, 50.3959653036935, 49.53862707955496, 49.88895525251116, 43.962930474962505, 39.68767261505127, 46.93538720267159, 47.62487779344831, 46.93702697753906, 48.79864045551845, 47.38204867499215, 49.17964492525373, 46.101273332323345, 44.73970086233956, 40.11658838817051, 33.41170876366751, 35.951125962393625, 36.19804409572056, 38.75532858712332, 35.94302436283657, 35.731403078351704, 39.95118304661342, 46.406670979091096, 49.94406141553606, 51.330390317099436, 51.35138429914202, 50.28039591653006, 49.890716620853965, 51.279185567583355, 51.51008115495954, 47.99935443060738, 49.5922463280814, 48.25337014879499, 50.544198172433035, 49.01576471328735, 50.299753597804475, 51.24942990711757, 48.721216678619385, 50.78443561281477, 48.94408709662301, 47.840723582676475, 47.25900650024414, 41.87372875213623, 37.06306702750069, 35.7649142401559, 36.446195534297395, 39.498250825064524, 46.95708990097046, 49.41057177952358, 50.52987446103777, 52.94179916381836, 49.112890107291086, 51.51143257958548, 50.763056005750386, 52.33858435494559, 48.07399197987148, 48.02512182508196, 52.09843724114554, 53.83251305988857, 52.47634628840855, 20.14819172450474, 3.914458751678467, 7.779006855828421, 16.668278523853846, 19.539003201893397, 0.3439394129174096, 0.2656021921762398, 4.439448135239737, 40.84794882365635, 55.104071617126465, 51.66007191794259, 38.75622490474156, 43.71487283706665, 62.252503395080566, 56.84173270634243, 27.997340645108903, 1.1158411758286613, 0.1662360584097249, 0.1617969601814236, 0.12301569831158433, 0.1213633841169732, 0.17142130088593277, 0.12127102193023477, 0.18001417336719377, 0.14948880991765431, 0.102478784242911, 0.12814469023474626, 0.09371068687843424, 0.08931453991681337, 0.09744870915476765, 0.1168783897800105], [0.05404874422986593, 0.017124193354642818, 0.05291941768622824, 0.046772155045930824, 0.04816685663536191, 0.045583873987197876, 0.018030471866950393, 0.04100416973233223, 0.02976826425375683, 0.031542819924652576, 0.053240378320749314, 0.036038341732429605, 0.03906763757445982, 0.03140167446274843, 0.05552875802719167, 0.05472805277843561, 0.028141164420438663, 0.0104001742521567, 1.1621834891183036, 23.080557346343994, 43.7737831388201, 37.050994532448904, 26.352210453578405, 33.41390439442226, 33.96066856384277, 36.78086246762957, 43.88458606175014, 12.283652544021606, 0.08985935603933674, 0.0903085937191333, 0.4185299804168088, 4.856408664158412, 7.988719991275242, 2.667463162115642, 3.127336634056909, 8.086327416556221, 26.697089501789637, 43.42698465074812, 49.19861350740705, 45.42386218479702, 44.28568819590977, 42.098461287362234, 40.92996188572475, 39.546255929129465, 38.84839275905064, 35.4707796233041, 32.34876292092459, 31.779281616210938, 33.39630808149065, 33.25094134466988, 36.89324957983834, 37.00951378686087, 38.64900377818516, 42.35353313173567, 41.97006205150059, 42.265634945460725, 42.17165013722011, 40.05317565373012, 37.83682884488787, 36.56023979187012, 38.519350392477854, 40.27731759207589, 41.7324857711792, 41.22887338910784, 41.094693252018516, 41.50960145677839, 44.200395584106445, 45.79524687358311, 46.12786756243025, 43.66274050303868, 36.13335289273943, 32.01002434321812, 32.548026834215435, 31.626869406018937, 31.72722918646676, 31.558387960706437, 31.57650191443307, 31.271069526672363, 32.20118318285261, 31.52825709751674, 31.30315283366612, 31.856899942670548, 35.841045652117046, 37.32034839902605, 40.71903542109898, 39.33496468407767, 41.94084140232631, 42.151191166469026, 44.59077664784023, 36.16785764694214, 35.69479649407523, 43.96155820574079, 42.43518141337803, 44.38126066752842, 39.79898623057774, 43.029599802834646, 45.11798511232649, 45.07723045349121, 40.60268088749477, 36.19024126870291, 31.866502353123256, 32.744622639247346, 33.7883289200919, 31.966757910592214, 33.78343391418457, 33.353232724326, 36.28875630242484, 43.067210401807515, 45.93565607070923, 48.94492088045393, 46.64256579535348, 45.22572387967791, 46.19224609647478, 46.159902232033865, 46.40385001046317, 47.20530039923531, 45.038542883736746, 48.10714183534895, 47.0213885307312, 47.31963300704956, 46.905850410461426, 47.300143310001914, 47.39942611966814, 46.82598434175764, 47.541381290980745, 47.38452223369053, 44.88860770634243, 42.24850416183472, 42.07900285720825, 37.011601720537456, 33.63911288125174, 35.63736268452236, 38.560150214603965, 42.51226472854614, 44.425913265773225, 42.85660702841622, 49.025009291512625, 46.880423477717805, 48.002383845193044, 48.17828096662249, 48.18101160866873, 46.704512459891184, 47.118076188223704, 50.54951701845442, 43.1438490322658, 11.960783651896886, 2.2158028951713016, 5.511693273271833, 2.205286362341472, 4.785324684211186, 0.6542984534587178, 0.04454893845000437, 2.998161805527551, 30.958713259015763, 43.14330359867641, 40.81846761703491, 32.83648477281843, 35.9073349407741, 45.26595394951956, 37.73574645178658, 12.072114637919835, 0.19271174844886574, 0.021984656740512167, 0.031354054875139675, 0.01887589257343539, 0.03738414469574179, 0.04665035801008344, 0.01279825865224536, 0.08180908087108817, 0.030266505732600178, 0.019703479683292762, 0.057828771216528754, 0.07602816607270922, 0.012585359808456684, 0.02399957665641393, 0.014551475244973387, 0.0715419300166624, 0.043102756408708434, 0.034792229134057245, 0.03213258899216141, 0.033106904210788865, 0.021029542366574918, 0.03269052119659526, 0.0772964090907148, 0.031249533340867077, 0.010623194293917289, 0.07932997175625392, 0.10140244449887957, 0.015715305294309343, 0.023187597548323016, 0.06392262636550836, 0.03978039111409869, 0.0513459696168346, 0.027032845320978334, 1.7622130917651313, 29.73035512651716, 48.85226665224348, 42.161592619759695, 33.155306339263916, 38.60853052139282, 42.91309935706002, 43.31376028060913, 47.35955040795462, 12.573500990867615, 0.03238882077857852, 0.02614443433204932, 0.4417585954070091, 5.710859911782401, 8.3328503710883, 7.034748826708112, 4.077104789870126, 8.220028127942767, 29.440813268933976, 43.09881428309849, 51.48475497109549, 47.02103417260306, 45.98752089909145, 42.80919599533081, 43.3730423109872, 42.96624960218157, 41.44353798457554, 38.152176312037874, 35.0771815436227, 33.51474360057286, 34.377911363329204, 33.637719767434255, 38.069006374904085, 39.15189354760306, 41.16868461881365, 44.17103944505964, 44.4839619909014, 43.92479876109532, 43.97829294204712, 43.32724673407418, 41.44421195983887, 38.59603418622698, 41.51095288140433, 42.259794984545024, 43.80182259423392, 42.68211691720145, 43.68391513824463, 43.48856653485979, 45.617744718279155, 46.934609004429404, 48.370131152016775, 42.94525562013899, 37.58204187665667, 32.33471713747297, 34.03631360190255, 33.97046552385603, 33.77220909936087, 32.44293533052717, 33.85277346202305, 33.91604028429304, 33.60091168539864, 32.16567441395351, 33.536189215523855, 34.99950763157436, 38.535702977861675, 38.8835506439209, 41.97514118467058, 41.575359208243235, 44.07001611164638, 45.38199234008789, 46.45831346511841, 38.71887833731515, 38.82787472861153, 45.461170537131174, 44.63866015842983, 45.51030819756644, 43.21113191332136, 44.50341347285679, 45.14988776615688, 45.230514662606375, 41.94458300726754, 37.00362171445574, 34.07765538351876, 33.83700105122158, 35.608055182865684, 34.82076869692121, 35.704965182713096, 35.098571572984966, 37.77955484390259, 45.500452177865164, 48.01630803516933, 49.59148897443499, 48.80305256162371, 47.1414464541844, 48.41311618259975, 48.50956065314156, 45.60904557364327, 48.51895809173584, 47.306139605385916, 47.5656270299639, 49.34876755305699, 48.70080981935774, 48.56914840425764, 48.91515827178955, 47.628153869083945, 48.50895963396345, 47.74395949499947, 48.30975825445992, 45.67700242996216, 46.818417753492085, 42.59016793114798, 38.51003285816738, 35.538830280303955, 35.873097692217144, 40.867073740277974, 44.12890556880406, 46.26591784613473, 45.530166149139404, 49.13500622340611, 49.285875933510916, 48.48583255495344, 48.57834434509277, 49.696771553584504, 48.22770350319998, 48.73517213548933, 52.85318531308855, 45.51327160426548, 14.189952492713928, 2.2362685969897678, 5.776803961821964, 3.9940177968570163, 4.76376485824585, 0.3027212603815964, 0.029563811474612782, 3.7523138523101807, 35.93453366415841, 50.035715103149414, 41.43540511812483, 32.49323681422642, 37.569271087646484, 51.07771907533918, 45.67468867983137, 15.38117163521903, 0.41096382641366547, 0.03665957446875317, 0.046210745349526405, 0.06121837254613638, 0.07007731217890978, 0.021596977453944937, 0.021394163336870924, 0.06840077428413288, 0.05814022557543857, 0.02922325474875314, 0.02366128284484148, 0.015320782982079046, 0.06604286509432963, 0.03426111602623548, 0.020099917160613195, 0.13359906684075082, 0.11052452001188483, 0.10716766478227717, 0.20099953801504203, 0.1544497829994985, 0.21967632296894277, 0.15659455076924392, 0.1769717037677765, 0.10721736068704299, 0.13991616001086576, 0.1534378837261881, 0.11312816744404179, 0.09850383110876594, 0.11579566502145358, 0.18646716353084358, 0.20536890998482704, 0.09442211727478675, 0.21604962114776882, 2.4779080535684312, 32.64137240818569, 54.990013463156565, 48.53137104851859, 36.366162708827424, 41.27322374071394, 44.71264110292707, 46.12347282682146, 52.5698447227478, 15.34477002280099, 0.15716917493513652, 0.22920522093772888, 3.346210535083498, 13.197332842009407, 14.027361171586172, 8.394300239426748, 5.989568224975041, 9.89433901650565, 29.018522603171213, 46.963155678340364, 52.8646741594587, 49.57532399041312, 49.193888732365195, 45.44403975350516, 44.223359380449565, 44.8407415662493, 42.923035281045095, 38.83493757247925, 35.840677397591726, 35.08616556440081, 36.175528458186555, 37.476238182612825, 41.26731777191162, 40.50124413626534, 42.47209371839251, 46.39665515082223, 46.40898125512259, 46.37406655720302, 46.66467496326992, 45.131127629961284, 42.60542270115444, 39.746725354875835, 42.8583197593689, 43.49237067358834, 45.665037631988525, 44.10093559537615, 45.75222710200718, 45.621003423418315, 48.955551624298096, 49.547736167907715, 49.762362548283164, 45.51409149169922, 40.24535240445818, 34.56205252238682, 35.372959409441265, 36.197019236428396, 35.222388471875874, 34.60620832443237, 34.566721711839946, 35.404285362788606, 35.20773472104754, 35.492141859872, 35.050719329289024, 35.744781834738596, 40.61893272399902, 40.326312814440044, 43.60566799981253, 43.40142222813198, 46.94494097573416, 46.782957621983115, 48.83900601523263, 41.9189441544669, 40.28459930419922, 45.57354375294277, 46.81499229158674, 47.15384898866926, 44.983137948172434, 46.32754489353725, 47.84964854376656, 47.549090317317415, 43.23111840656826, 38.71047796521868, 35.64456101826259, 36.22797693525042, 38.05820540019444, 36.36342511858259, 36.53639357430594, 36.770603452410015, 39.12686266217913, 46.99704899106707, 50.80020454951695, 51.86095128740583, 49.8323517526899, 48.449159962790354, 49.69972106388637, 51.04130704062325, 49.555743966783794, 50.97690766198294, 48.74868638174874, 51.53351395470755, 50.18736301149641, 49.632716110774446, 50.74364621298653, 49.999838079724995, 50.69040216718401, 48.72049406596592, 48.46681880950928, 51.091459138052805, 49.002542291368755, 47.51458903721401, 46.59254918779646, 43.53606442042759, 37.96260513578142, 39.365342208317344, 42.532657691410606, 46.86780207497733, 48.67192963191441, 46.861531325748985, 52.47402211597988, 48.86842121396746, 50.49452897480556, 50.299392291477744, 52.564967087336946, 50.09208236421858, 51.56671939577375, 54.309065682547434, 48.62370913369315, 14.406963842255728, 6.915807391916003, 15.81389502116612, 7.300624251365662, 11.940742441586085, 1.6164271831512451, 0.3358771955328328, 3.8643735306603566, 40.363940783909385, 54.59313930783953, 52.01996776035854, 43.602808816092356, 46.86456421443394, 58.19576638085501, 52.97463982445853, 17.99556510789054, 0.7746760483298982, 0.1501334724681718, 0.10368783865123987, 0.1314213765519006, 0.12418116363031523, 0.12228966584163052, 0.08189379596816641, 0.21369302831590176, 0.15683908121926443, 0.07350152557981865, 0.11088491031633955, 0.10560385869549853, 0.1717238732214485, 0.11662096716463566, 0.08558668888040952], [0.020953580371237228, 0.05585125554352999, 0.02128616770330284, 0.025116994910474335, 0.022528441489807198, 0.06974452467901365, 0.05082728727055447, 0.0725658665012036, 0.04902319836297205, 0.039600945743066926, 0.06034719465034349, 0.01571723911911249, 0.03312855626323393, 0.02096194331534207, 0.03176596973623548, 0.034770156389900615, 0.0523751851038209, 0.09194100648164749, 0.3170787085379873, 14.953928640910558, 43.637435163770405, 38.44086701529366, 24.199288538524083, 25.252732719693864, 29.466393062046595, 34.53837306158883, 38.39445652280535, 21.001663276127406, 0.6069332893405641, 0.07011689112654754, 0.1350268537976912, 2.065645375422069, 1.4952641704252787, 8.382649847439357, 3.5303896921021596, 6.5996778181621005, 24.377284015927994, 42.23872109821865, 48.81402724129813, 45.14907830102103, 44.60560410363333, 39.41188471657889, 38.141271114349365, 34.142436913081575, 33.26890591212681, 32.10500969205584, 33.73061718259539, 34.61793688365391, 35.86109120505196, 36.034202098846436, 40.33618967873709, 39.076727935246055, 41.82942703792027, 41.6758405821664, 40.952661650521414, 40.702071394239155, 38.2215575490679, 35.53870521272932, 33.22042485645839, 33.73951435089111, 35.221752711704795, 37.726446287972585, 37.80423831939697, 38.0869049344744, 36.619921343667166, 41.05724246161324, 43.08786392211914, 44.59584188461304, 45.66142804282052, 45.28673601150513, 39.06408221381051, 33.04988479614258, 31.934205600193568, 32.2536073412214, 31.289082731519425, 32.29086358206612, 32.5754965373448, 30.73213597706386, 33.07748998914446, 31.75085653577532, 32.2785096849714, 32.787565980638774, 33.450823647635325, 36.139283180236816, 38.04689025878906, 37.72911787033081, 42.668324742998394, 42.287733691079275, 43.940397466932026, 38.38643830163138, 39.37277678080967, 44.94097627912249, 40.1064509664263, 43.23623922892979, 42.47904191698347, 44.08604907989502, 44.18260472161429, 43.909731592450825, 41.05258022035871, 35.64455754416329, 32.39224822180611, 31.325790064675466, 32.615264551980154, 32.46064976283482, 33.60026202883039, 33.221335070473806, 35.668726852961946, 44.6762638092041, 45.55932079042707, 46.689521721431184, 46.15965209688459, 46.979525634220664, 42.69703469957624, 44.44026129586356, 43.54772697176252, 43.056044646671836, 44.36607885360718, 44.212415967668804, 44.32449735913958, 44.703604970659526, 42.74468197141375, 44.30559478487287, 44.954879624503, 46.88641977310181, 45.611467020852224, 47.61513989312308, 48.04547657285418, 44.43904536111014, 43.54477398736136, 42.95013325554984, 41.90566962105887, 40.537058625902446, 41.444587162562776, 42.74294492176601, 44.11079856327602, 46.46648802076067, 47.23912075587681, 47.89228963851929, 49.242366313934326, 49.851813656943186, 51.37617547171456, 50.85169070107596, 52.745165143694194, 50.849140712193076, 35.40644972664969, 8.214928150177002, 1.3914879390171595, 3.380511837346213, 3.369257492678506, 2.6442116669246127, 0.09389048508767571, 0.07055780318166528, 3.085442904915128, 29.800500665392192, 42.00289576394217, 34.79993799754551, 31.632382801600865, 36.0374573298863, 41.87621968133109, 36.99580846514021, 7.378749796322413, 0.0487494162682976, 0.060626995350633345, 0.024262140870892575, 0.007980498019605875, 0.013596167488555824, 0.03279370940955622, 0.02850969714511718, 0.0444971153379551, 0.04867596485252891, 0.045336968664612086, 0.07724003640136548, 0.041400892194360495, 0.04666179132514766, 0.05998187139630318, 0.009174979192071726, 0.03513030242174864, 0.033841153739818504, 0.025411626689934304, 0.06563639547675848, 0.020014934042202573, 0.05715206824243069, 0.027901197118418555, 0.010910402052104473, 0.058180734116051874, 0.032245191878506115, 0.026425247745854512, 0.07062478137335607, 0.02733840829958873, 0.018363166068281447, 0.03713118005543947, 0.03201101587287017, 0.026269844566871012, 0.018759539084775106, 0.5854789348585265, 19.79841419628688, 49.16261141640799, 44.52256270817348, 25.50694646154131, 30.974815709250315, 34.87198386873518, 39.553916318076, 44.67689609527588, 20.659054551805767, 0.7030833842498916, 0.049920628778636456, 0.45464782949004856, 4.664677032402583, 6.175408652850559, 8.441498483930316, 5.800116905144282, 7.169877392905099, 23.331941434315272, 44.918429374694824, 48.94104378564017, 47.16364942278181, 46.13073716844831, 42.98378338132586, 40.2972936630249, 35.32053525107247, 33.80021381378174, 33.437608173915315, 34.26016024180821, 36.5909994670323, 37.61915567943028, 38.38537870134626, 41.27579457419259, 41.62586913790022, 44.115860325949534, 44.42234189169747, 42.59829037530081, 43.14859465190342, 40.384556089128765, 38.30058635984148, 34.01223809378487, 34.39076553072248, 36.28629316602434, 39.03635195323399, 40.10592290333339, 39.13845225742885, 38.2269424029759, 43.01896905899048, 44.44493048531668, 46.143900530678884, 46.784243038722444, 45.29129402978079, 39.55220358712332, 34.21313830784389, 33.14144120897566, 34.33389105115618, 33.156657763889854, 33.29977675846645, 33.74072333744594, 32.42982060568673, 34.621754918779644, 33.895188740321565, 34.477298395974294, 34.810137953077046, 35.775367804935996, 37.96088893072945, 40.307448455265586, 41.235439436776296, 44.7549660546439, 44.56335210800171, 44.933538232530864, 41.945625237056184, 43.15957280567714, 45.617897578648154, 42.23550408227103, 45.06349733897618, 44.070710931505474, 46.65843200683594, 45.66521828515189, 46.31225190843855, 41.501148973192485, 37.71565573556082, 33.875038964407786, 33.24586568559919, 34.02337258202689, 32.968382426670615, 34.62534713745117, 35.282841273716514, 37.21507624217442, 46.14019019263131, 47.19041388375418, 48.80911833899361, 47.77432312284197, 47.98525653566633, 45.03791754586356, 45.21854639053345, 44.90934113093785, 45.78747878755842, 45.05507959638323, 46.11802543912615, 46.882782391139436, 46.03673498971121, 46.48825325284685, 46.84158999579293, 47.658329895564485, 47.87124701908657, 47.28922421591622, 48.76833241326468, 50.29074873243059, 46.03590815407889, 45.01503365380423, 44.649982248033794, 42.96450560433524, 40.526031834738596, 43.96876696177891, 45.74506350925991, 46.27523190634591, 48.75551993506295, 49.747983251299175, 49.87358583722796, 50.86062608446394, 51.497390270233154, 53.006803035736084, 51.78001867021833, 54.80192225319998, 53.682425022125244, 39.270415919167654, 9.555254765919276, 2.3293605617114475, 4.057826144354684, 4.553456349032266, 3.1124360050473894, 0.26040952652692795, 0.13985767029225826, 2.8235123200075964, 33.71838140487671, 47.0791905948094, 40.32765729086739, 35.249476024082725, 40.35278197697231, 48.356950419289724, 41.25975118364607, 9.478015116282872, 0.07611180908445801, 0.05969799270055123, 0.04142641189641186, 0.03467911734644856, 0.0123933878328119, 0.02712157734536699, 0.012917956470378807, 0.045014040278536935, 0.03376340041203158, 0.01595879080040114, 0.03540839999914169, 0.08727788313158921, 0.04876734655616539, 0.030281993294400827, 0.002686353217411254, 0.16718273689704283, 0.09955499720360551, 0.1425426605024508, 0.1962808562176568, 0.14021206913249834, 0.1666932688759906, 0.07309179899415799, 0.12921944899218424, 0.09916679374873638, 0.12049275583454541, 0.10841529390641622, 0.10559591983578034, 0.11193841057164328, 0.09195417684635945, 0.12309511405016695, 0.13438479682164534, 0.14442984280841692, 0.22016887153897965, 0.7689547496182578, 22.957652398518153, 55.65009580339704, 50.245533330099924, 33.5984068598066, 35.68941511426653, 39.05018581662859, 43.6521966116769, 48.22784941537039, 25.898576463971818, 1.1587638897555215, 0.24155599677136966, 1.3524842262268066, 7.028364300727844, 7.390388897487095, 14.517943944249835, 7.96074480669839, 8.769998022488185, 26.280776023864746, 44.7548166683742, 52.06246294294085, 49.5317622593471, 49.43012053625924, 43.3574401310512, 43.0842091696603, 36.666321413857595, 35.857929774693076, 34.64988817487444, 35.806214332580566, 38.446776458195274, 40.48074000222342, 40.83481672831944, 44.53654943193708, 42.946537562779014, 46.01300689152309, 45.55642339161464, 44.8186845098223, 45.17139938899449, 41.12783963339669, 38.82963957105364, 36.18046515328543, 36.979605266026084, 38.05643360955374, 40.7818922996521, 41.34747913905552, 41.263795035226, 39.60708045959473, 44.57817261559622, 46.75420250211443, 48.34609038489205, 49.88935129983084, 47.865361894880024, 42.362586634499685, 36.9224146434239, 35.22796092714582, 35.82534967150007, 34.79378884179251, 35.689651353018625, 37.0765117917742, 34.53066403525216, 36.958784988948274, 36.13735505512783, 37.06789949962071, 36.24822746004377, 36.208431652614046, 40.01654475075858, 42.416070393153596, 41.49264437811715, 47.70025532586234, 46.755783217293875, 47.15808391571045, 44.40624291556222, 43.97928653444563, 47.732977867126465, 44.11755568640572, 47.053284236363, 45.45752273287092, 47.14225244522095, 47.739630767277305, 47.6748422895159, 45.14490590776716, 39.42704221180507, 35.594707693372456, 32.97422238758632, 35.89729479381016, 35.54439926147461, 36.66896867752075, 36.71361085346767, 39.12997545514788, 49.337608746119905, 49.64230809892927, 50.108639921460835, 49.14059952327183, 51.833571910858154, 46.76935999734061, 47.74407761437552, 46.588713782174246, 47.227899415152415, 48.108135427747456, 48.65024430411202, 48.06518166405814, 48.68092060089111, 47.74354955128261, 49.28279093333653, 48.03494310379028, 48.5140700340271, 48.943392276763916, 51.46177380425589, 51.25728484562465, 47.8324864932469, 48.0561455317906, 47.58810445240566, 46.75321585791451, 43.34860897064209, 46.750846522195, 48.091060229710166, 48.12750700541905, 52.6076602935791, 50.78496020180838, 51.10461207798549, 51.60666806357247, 52.01397493907383, 55.661028793879915, 55.13743339266096, 57.94441877092634, 56.758027757917134, 39.544550146375386, 11.53199120930263, 3.4129601418972015, 8.479088238307408, 9.202935065541949, 6.279539133821215, 0.7002105755465371, 0.2624217899782317, 3.830258744103568, 39.82204382760184, 54.89471197128296, 48.37591552734375, 44.077742508479524, 46.48208325249808, 54.44618143354143, 49.37816538129534, 11.58299011843545, 0.19415925363344805, 0.23642244509288243, 0.12505374609359673, 0.09522126189299993, 0.14415602678699152, 0.19515030831098557, 0.08278921792017561, 0.14147771336138248, 0.11546425494764533, 0.1680217861597027, 0.1451641669762986, 0.2405270119862897, 0.2085587845316955, 0.12070899137428828, 0.06580894014665059], [0.021793187728949955, 0.049831988356475315, 0.096391354820558, 0.06173724148954664, 0.12099947221577168, 0.024488583273653473, 0.02928713882075889, 0.02053593358557139, 0.015897612386782254, 0.07313655516398804, 0.06260339144085135, 0.03596158924379519, 0.03019239953053849, 0.052232475618698766, 0.050184812995472124, 0.0941412512745176, 0.0595433342137507, 0.053438591970396895, 0.2938370928168297, 9.89920014994485, 37.00346885408674, 45.448024545397075, 34.74747214998518, 22.363108941486903, 29.892616408211843, 39.52782235826765, 41.05255242756435, 29.76655524117606, 2.5959707583699907, 0.06722801471395151, 0.14343213848769665, 3.0381753955568587, 7.364661455154419, 11.446210486548287, 2.909072654587882, 5.072556700025286, 22.30745039667402, 41.53692177363804, 48.390652656555176, 42.99466078622, 42.07499027252197, 39.732054233551025, 36.93958364214216, 36.57007496697562, 35.57062176295689, 35.42054067339216, 35.68644823346819, 38.0471647126334, 37.86546931947981, 39.58313001905169, 42.15378284454346, 41.160954747881206, 41.58272082465035, 37.95581327165876, 36.40718139920916, 37.820962633405415, 34.068535872868125, 32.8607930455889, 30.48499550138201, 34.114053521837505, 33.02091080801827, 34.450818811144146, 34.407840728759766, 32.910722800663535, 32.654744216373985, 35.897082873753135, 39.98110546384539, 43.36562858309065, 42.02313239233834, 40.93508965628487, 39.28834227153233, 33.76535817555019, 31.72102791922433, 32.25694942474365, 31.671758243015834, 32.27322210584368, 31.089801447732107, 30.99109533854893, 31.72084379196167, 31.50426149368286, 30.941273280552455, 33.429642064230784, 32.563444886888774, 34.80462803159441, 36.13984598432268, 37.48639644895281, 41.11774737494332, 42.61977073124477, 44.316166469029014, 40.835449014391216, 37.75210945946829, 43.13928059169224, 42.50341967173985, 42.965662479400635, 44.15356125150408, 42.935333592551096, 44.66489308220999, 45.49970872061593, 41.58220665795462, 35.304641246795654, 32.02916315623692, 32.392328126089915, 33.122187750680105, 31.624920436314174, 32.040711062295095, 33.43419313430786, 37.47968448911394, 44.74207714625767, 45.54228728158133, 48.500639166150776, 45.342404978615896, 44.181923798152376, 40.417476654052734, 38.176189286368235, 38.45456886291504, 41.33076524734497, 40.08289309910366, 41.57760347638811, 42.56837838036673, 43.02392659868513, 42.12034463882446, 43.07345683234078, 42.175423009055, 42.928402764456614, 45.79489598955427, 48.128834111349924, 47.49250418799264, 49.77868734087263, 46.47165748051235, 44.149638993399485, 43.90042448043823, 45.38387530190604, 43.25267171859741, 44.641606194632395, 43.97918231146676, 44.74583612169538, 46.58511461530413, 46.894736766815186, 48.17528976712908, 47.998791626521516, 49.46140480041504, 49.770894936152864, 53.58439288820539, 45.666819844927105, 20.409640278135026, 3.5454948587077, 0.4424902190055166, 2.5134698024817874, 2.5878754556179047, 2.1931519848959784, 0.011057471124721425, 0.06122173807982888, 5.381300338676997, 35.75935568128313, 43.55448062079293, 32.58436591284615, 30.787780625479563, 43.81415912083217, 41.36340093612671, 29.459965978349956, 4.440642356872559, 0.16516334882804326, 0.0621329631124224, 0.03739622261907373, 0.03678523915420685, 0.025796065971787487, 0.05326529751930918, 0.0627966449995126, 0.013364488491788507, 0.0388408304591264, 0.06230214224862201, 0.06169859892023461, 0.016449855075084736, 0.03490461488919599, 0.02958007256633469, 0.05216937864731465, 0.05035890472520675, 0.02646027541985469, 0.03365165587248547, 0.07039409303771597, 0.0834884075447917, 0.050489152914711406, 0.034372412732669284, 0.048802023088293414, 0.09208773289408002, 0.03222402497859938, 0.08385546106312956, 0.03071722261873739, 0.07876245863735676, 0.0374751091003418, 0.03442439190777285, 0.0401660941674241, 0.06945280890379633, 0.08259572687425784, 0.23671378088848932, 12.851137110165187, 45.00216906411307, 50.08380705969674, 36.972875935690745, 26.044174228395732, 33.00779608317784, 43.86137907845633, 44.759815897260395, 30.861118861607142, 2.399199511323656, 0.04553402541205287, 0.37805330380797386, 3.007970924888338, 6.573043201650892, 6.126155912876129, 4.784500019890921, 5.76402839592525, 22.7535560131073, 43.34543364388602, 51.2304995400565, 45.10107667105538, 44.07950040272304, 40.843842438289094, 38.83280447551182, 36.99242121832711, 37.02395561763218, 35.93832390648978, 37.673098019191194, 38.91281645638602, 40.00986753191267, 41.18673256465367, 42.59919364111764, 41.77250392096383, 43.49951342173985, 41.59801033564976, 38.86653797967093, 39.223998478480745, 35.04926715578352, 35.84957456588745, 33.75585651397705, 34.42473874773298, 34.364775793892996, 36.31074387686593, 37.08555487224034, 35.71284096581595, 34.32768978391375, 38.08119351523263, 42.80613531385149, 46.055106026785715, 45.331729071480886, 42.8231966154916, 40.42543581553868, 34.02140276772635, 33.8039345741272, 33.63304362978254, 32.89627054759434, 33.95297690800258, 33.05206653050014, 32.30795267650059, 32.2775890486581, 31.797555378505162, 33.80396236692156, 34.811447688511436, 34.38297660010201, 35.53814935684204, 37.94439043317522, 40.81032085418701, 42.72393465042114, 44.22123670578003, 46.89732149669102, 42.37817144393921, 41.4227420261928, 45.25089372907366, 44.08548280170986, 44.54140622275216, 45.06378221511841, 45.87338978903634, 47.43003988265991, 45.90378468377249, 44.03574759619576, 37.5887816292899, 33.26458413260323, 33.295569624219624, 34.59641483851841, 33.57529367719378, 34.171292781829834, 34.6499958719526, 38.48945229394095, 46.59264298847744, 46.88421719414847, 49.78729963302612, 46.7893499646868, 45.27349969318935, 43.04004641941616, 40.208026681627544, 41.15580265862601, 43.09986693518502, 41.50070776258196, 44.580003465924946, 45.42328895841326, 44.941747529166086, 44.45533888680594, 45.23156384059361, 44.404877594539094, 44.46250942775181, 46.9002571105957, 50.94309772763933, 49.26987770625523, 51.18427317483084, 47.93460416793823, 46.37342037473406, 47.72270495550973, 46.74509341376168, 45.598459993089946, 46.426171098436626, 46.161274501255576, 46.537536825452534, 47.72900002343314, 50.32152925218855, 51.396127223968506, 50.88038328715733, 51.361236844744, 50.45946489061628, 55.20843703406197, 48.17859710965838, 24.36399037497384, 4.759536445140839, 4.048724872725351, 7.001651951244899, 3.481024261031832, 1.8825077967984336, 0.20273270644247532, 0.09641718664871794, 4.501556779657092, 37.97870758601597, 47.49636738640921, 40.63420833860125, 36.92491946901594, 47.78734057290213, 47.33347381864275, 36.59671088627407, 5.747105189732142, 0.1425418191190277, 0.030485441841717278, 0.053802398698670525, 0.037511658389121294, 0.05769173428416252, 0.05421937543100544, 0.06324628980032035, 0.016601500866402472, 0.049665832093783786, 0.023871867884216563, 0.06650744445089783, 0.026592925623325363, 0.05655661305146558, 0.06480581433113132, 0.043935546185821295, 0.16394936825547898, 0.11933474083031927, 0.13871306314000062, 0.21150822698005609, 0.19912026742739336, 0.18890414919172013, 0.1514960250684193, 0.20227825082838535, 0.19393358645694597, 0.20136750755565508, 0.22156752220221929, 0.12831192197544233, 0.09923571933593069, 0.1312429896954979, 0.04722390669797148, 0.2093183502022709, 0.1104033404429044, 0.14272245871169226, 0.40692947432398796, 15.03568114553179, 48.53463322775704, 57.743059975760325, 44.9959191594805, 33.479026385716026, 40.84423153741019, 49.36237212589809, 49.31683710643223, 36.514687401907786, 3.983947685786656, 0.13699427965496266, 1.2196791810648782, 9.134710703577314, 14.1750442641122, 19.925006900514873, 5.919265917369297, 6.699029675551823, 25.86059066227504, 44.002590792519705, 52.69595800127302, 47.70381280354091, 47.31049960000174, 43.21460253851754, 41.56715338570731, 39.43246875490461, 39.64772047315325, 37.703697885785786, 40.240912505558555, 41.312244824000764, 42.93423925127302, 43.614391463143484, 45.96382059369768, 44.66710955756051, 45.142526149749756, 42.334126813071116, 39.99649224962507, 41.83789689200265, 37.09833608354841, 37.22436945778983, 35.22124549320766, 38.18342236110142, 35.351298400333945, 38.06295101983206, 38.62697451455252, 37.8564783505031, 35.78099584579468, 40.488094670431956, 43.93268149239676, 47.828557286943706, 46.259143352508545, 44.91547291619437, 42.08619771684919, 36.13804292678833, 35.24394873210362, 35.20950303758894, 34.473278863089426, 35.99875586373465, 34.38720457894461, 35.04646355765206, 35.213463510785786, 34.64666073662894, 34.29664870670864, 37.54436526979719, 35.14678512300764, 37.55393641335623, 39.389952727726524, 41.70817402430943, 44.69390181132725, 46.47802203042166, 48.04143966947283, 46.66950396129063, 41.39575522286551, 44.85086856569563, 47.243213244846885, 47.46770259312221, 48.08302116394043, 48.8469478062221, 49.25478274481637, 47.12778976985386, 45.1708539554051, 38.94208574295044, 34.990148408072336, 35.01070465360369, 36.18935884748186, 35.638568196977886, 35.46249737058367, 37.77251979282924, 40.28497450692313, 49.339932918548584, 50.21376964024135, 49.82629987171718, 48.416829994746614, 47.17065668106079, 45.2298024722508, 42.05177286693028, 43.4338355745588, 45.70169285365513, 42.93595545632498, 46.240595136369976, 47.90617561340332, 46.23676667894636, 45.12430797304426, 47.33709730420794, 46.20167480196272, 46.37005744661604, 49.363900729588096, 51.68387297221592, 50.05869279588972, 54.258104119982036, 50.03561088017055, 49.2160187448774, 50.39922400883266, 48.99661200387137, 46.65983901705061, 50.204132488795686, 47.704208850860596, 47.564748082842144, 49.00190305709839, 51.31143910544259, 52.79424721854073, 51.17509807859148, 52.397133350372314, 51.002595152173726, 57.15031610216413, 50.24294860022408, 23.74932667187282, 5.628879853657313, 3.970031746796199, 11.702846544129507, 11.159332394599915, 5.4965353437832425, 0.9845086059400013, 0.1654189529695681, 6.452188840934208, 42.89442259924752, 56.012878622327534, 43.587981360299246, 43.034341948372976, 54.95030450820923, 54.99302898134504, 43.47171367917742, 6.984794318675995, 0.2905168581221785, 0.13026178734643118, 0.12307082249649934, 0.09239842050841876, 0.19111298423792633, 0.11140472920877592, 0.16337261348962784, 0.10826696615133967, 0.17755322184945854, 0.07410306044455085, 0.13209995228265012, 0.09654878173023462, 0.14935972541570663, 0.12094209529459476, 0.11043650044926576], [0.0075836525731054795, 0.09667984755443675, 0.03477426491943853, 0.014672505536249705, 0.06379861730550017, 0.014856926265305706, 0.041399375668593814, 0.036417602095752954, 0.04805747339768069, 0.06087207541401897, 0.08002070683453764, 0.005975252316732491, 0.12019889588866915, 0.038774907389389615, 0.032408790064177344, 0.042679085928414545, 0.030336449122322456, 0.022611670595194613, 0.037211664486676455, 4.728934407234192, 27.770405530929565, 46.08198513303484, 36.37907593590872, 30.150106225694927, 32.43526799338204, 34.32050882066999, 41.5972112928118, 39.86074529375349, 6.598779329231807, 0.08114876451769046, 0.1804418811308486, 2.141142112868173, 7.729444486754281, 4.417814484664372, 4.865498210702624, 5.3011711069515774, 17.687923192977905, 44.22701413290841, 48.82278197152274, 46.76195321764265, 41.85010140282767, 40.06789888654436, 38.835347516196116, 36.60181086403983, 37.00668587003435, 38.15456301825387, 40.70373201370239, 41.637503896440776, 41.92224107469831, 40.8230117389134, 39.528544970921104, 39.53021601268223, 37.562187399183, 34.81417138235909, 34.46264117104666, 32.71125044141497, 32.55491597311837, 33.06568847383772, 33.10104785646711, 34.06405428477696, 32.420496123177664, 32.52640404020037, 33.745131969451904, 34.99544988359724, 33.98756504058838, 34.42761182785034, 35.476873193468364, 38.42599787030901, 40.95000743865967, 38.70472138268607, 36.13289778573172, 33.9300582749503, 32.70032787322998, 31.351606096540177, 31.92692388807024, 31.917783532823833, 31.286765507289342, 32.78864642551967, 34.53046601159232, 38.07420015335083, 37.80224766050066, 37.48680639266968, 35.83813088280814, 35.498357023511616, 34.55798087801252, 37.23033101218087, 41.56729929787772, 42.86553546360561, 43.389523438044954, 40.53207329341343, 37.13922275815691, 43.84833036150251, 41.48216996874128, 41.1684171131679, 44.13243177958897, 44.05895110539028, 45.70964854104178, 43.28607518332345, 42.01515586035592, 37.981094292231965, 33.57430008479527, 31.59320538384574, 32.11140203475952, 32.345146383558, 32.19260563169207, 33.179110867636545, 38.32780940192086, 45.422983237675254, 44.4376939364842, 47.27129438945225, 44.976234912872314, 43.911642347063335, 37.96698944909232, 35.03296320778983, 35.11708852222988, 33.5419214793614, 34.71243585859026, 34.735139097486226, 34.406666483197895, 36.333245618002756, 35.55501610892159, 37.34746721812657, 39.47363683155605, 40.327928270612446, 43.14311599731445, 43.27831751959664, 44.02446372168404, 45.58747836521694, 47.44234166826521, 48.779459953308105, 46.56363425936018, 48.27128260476248, 47.00996569224766, 47.635136808667866, 47.42677075522286, 49.703896931239534, 47.49026339394705, 46.24950967516218, 47.178601946149556, 49.16054432732718, 50.64601012638637, 50.921600001198904, 48.536172253744944, 36.09275804247175, 12.552378467151097, 1.1812479346990585, 2.4923014640808105, 3.5137583102498735, 2.1266225491251265, 2.3827199041843414, 0.07802898942359857, 0.10110074747353792, 7.190989060061319, 38.22542769568307, 37.86229051862444, 33.209561347961426, 34.04393924985613, 43.428078992026194, 42.70919404711042, 28.883008411952428, 2.2312255075999667, 0.04032697821302073, 0.01817486751159387, 0.03861620144120284, 0.035940371453762054, 0.01770768258055406, 0.02228128002025187, 0.01621542970782944, 0.01601348750825439, 0.013964556024542876, 0.045301447356385846, 0.0438035575539938, 0.07704467259879623, 0.015185343999681728, 0.01286205112202359, 0.005046379436472697, 0.008273277398464935, 0.07223462606115, 0.03409145513017263, 0.010291260051807123, 0.04530637691329632, 0.07251494923340422, 0.013013916589053614, 0.08895598165690899, 0.03396328665050013, 0.0453421357087791, 0.03858729245673333, 0.02199198491871357, 0.04376258421689272, 0.03093999923606004, 0.024234575385759984, 0.023414119678948606, 0.03490358351596764, 0.04197047823773963, 0.03971445108098643, 6.681461589676993, 34.355625016348704, 52.11359821047102, 40.23635796138218, 31.098312991006033, 34.35021236964634, 41.23601961135864, 47.26127161298479, 43.29845339911324, 6.580176396029336, 0.031076836000595773, 0.06885236648044415, 3.3021170496940613, 9.84020299570901, 8.982722333499364, 8.186463986124311, 6.369835751397269, 18.973699501582555, 45.693591254098074, 50.596181120191304, 48.63602828979492, 44.402452673230854, 42.29425457545689, 40.959387506757466, 38.137043135506765, 38.59495374134609, 39.77298607145037, 41.696455887385774, 43.33157546179635, 43.70549971716744, 42.76069409506661, 42.21337406975882, 41.78884955814907, 38.952765124184744, 37.44693068095616, 36.49405820029122, 33.69257232121059, 34.450252532958984, 34.32762377602713, 34.183334009987966, 34.88805157797677, 34.325570583343506, 35.32948105675833, 35.543023518153596, 35.95196322032383, 35.71846553257534, 35.418768882751465, 36.98190859385899, 40.76264578955514, 42.61742224012102, 42.94782992771694, 39.21495539801461, 35.22596679415022, 33.83431557246617, 33.15326009477888, 33.30029787336077, 33.67194659369332, 32.35511357443673, 34.4101996421814, 36.07369565963745, 38.85838079452515, 38.954060963221956, 38.634506361825125, 37.35307788848877, 37.36395876748221, 35.81782129832676, 38.22668184552874, 43.51887457711356, 43.7650214603969, 45.97908926010132, 41.497230189187185, 40.44603722436087, 46.28187091009957, 43.579448972429546, 45.070091179439, 45.14491980416434, 45.24889612197876, 46.79097236905779, 43.921425410679404, 43.369005407605854, 39.16325037819998, 34.300685610089985, 33.45471811294556, 33.91703735079084, 33.77800737108503, 33.80314942768642, 34.34584890093122, 39.21096018382481, 47.82529163360596, 46.80812747137887, 48.64095456259591, 46.843372208731516, 45.230549403599326, 40.33100979668753, 37.126028129032676, 36.89007772718157, 36.46729026521955, 37.16486855915615, 36.85898801258632, 37.921075752803254, 39.45451886313302, 38.43813289914812, 39.455828598567415, 41.61482845033918, 43.065768650599885, 44.67545434406826, 45.45253392628261, 45.72623041697911, 47.45860045296805, 48.68562453133719, 50.126698289598735, 48.53292397090367, 48.09302656991141, 47.57914822442191, 49.21929482051304, 48.90857832772391, 50.93152550288609, 50.07256487437657, 48.240311009543284, 48.054634298597065, 51.72424895422799, 52.95371879850115, 52.27457754952567, 50.99299968991961, 38.03063842228481, 15.276325055531093, 2.3356132890496935, 4.018474587372371, 3.844566822052002, 4.648186785834176, 2.4221945745604376, 0.11831064149737358, 0.03891743367005672, 7.457225356783185, 42.06315401622227, 46.5384053502764, 36.74619790485927, 37.60375847135271, 49.886978490012034, 47.864608015332905, 34.31945269448416, 3.748945713043213, 0.01066904969047755, 0.117520433185356, 0.11456249547856194, 0.033142914064228535, 0.06811886333993503, 0.043725475136722834, 0.018992368198399032, 0.03395134782684701, 0.0361948763685567, 0.003240004289961819, 0.020132452914757386, 0.014074876488718604, 0.018400136048772504, 0.05300878753353443, 0.02231380559637078, 0.06940630211361817, 0.15383745942796978, 0.09927588182368449, 0.1746351955724614, 0.10212714025484664, 0.15167355697069848, 0.08346882502415351, 0.24129476078919002, 0.12871088699570724, 0.2223303448408842, 0.14282338401036604, 0.10169899822877985, 0.13442569891256945, 0.19059865469379084, 0.17965632756905897, 0.1842631867953709, 0.11675469284611088, 0.12081634918493883, 0.13067462162247725, 7.828407679285322, 39.23019279752459, 58.06609909875052, 45.45628942762102, 39.25727687563215, 43.12337963921683, 45.15672479357038, 53.415739263807026, 48.61596189226423, 8.097101466996328, 0.20511980620878084, 0.9051771685481071, 5.901903671877725, 17.696655341557094, 9.973709157535009, 12.216486045292445, 8.023340259279523, 20.496355533599854, 48.032928126198904, 53.40673787253243, 50.613245895930696, 45.59979057312012, 43.72186967304775, 42.934485912323, 40.216618129185264, 41.60660178320748, 41.960452692849294, 44.62692812510899, 45.35092347008841, 45.689717633383616, 44.11591591153826, 42.9978916985648, 43.333830152239116, 42.126709188733784, 39.040131773267476, 37.900634152548655, 35.225595065525596, 36.4299749646868, 36.54419987542288, 37.04441806248256, 36.525860105242046, 34.93920074190412, 35.87350416183472, 37.197441714150564, 37.5470472744533, 37.42528704234532, 38.35401800700596, 37.550893102373394, 42.50720296587263, 44.480769293648855, 42.59978076389858, 40.737555844443186, 36.30718639918736, 35.69454983302525, 34.19356175831386, 35.551298822675435, 35.316116196768625, 34.77974305834089, 35.605793544224326, 37.9002172606332, 42.18824590955462, 41.538724831172395, 40.57370342527117, 39.73291233607701, 39.59593902315412, 38.14438738141741, 39.82317638397217, 46.52365779876709, 47.01236629486084, 47.27447319030762, 44.22847672871181, 41.932204791477744, 46.12991033281599, 44.453858920506065, 47.374165943690706, 47.521151610783164, 45.91621848515102, 48.478992053440635, 47.16457005909511, 47.22959130150931, 41.148100580487935, 36.8138108253479, 35.23863683428083, 36.09751755850655, 35.47786331176758, 35.592400891440256, 35.846552099500386, 40.7911125591823, 50.75175476074219, 47.83041593006679, 48.661027908325195, 48.71295179639544, 47.500529357365195, 42.41098083768572, 37.89146253040859, 38.907247475215364, 37.23117521830967, 38.672144753592356, 37.604224000658306, 38.61083384922573, 40.59365865162441, 38.833700793130056, 40.63673748288836, 43.39058998652867, 44.90146534783499, 48.83277695519583, 47.36933694566999, 47.211512088775635, 48.64616571153913, 49.98197078704834, 53.31995139803205, 52.01059464045933, 51.82465737206595, 50.20326048987252, 52.534002440316335, 51.96047033582415, 52.67332771846226, 51.34029844829014, 51.73548419134957, 50.12883833476475, 54.421487535749165, 55.382600579942974, 52.94613831383841, 49.44400651114327, 39.28023024967739, 15.658387388501849, 3.0971458426543643, 7.098704389163426, 9.66823160648346, 8.410212482724871, 9.409227950232369, 0.7575233344520841, 0.22339857609144279, 9.07924497127533, 46.73752335139683, 50.90228400911604, 43.98287875311715, 43.385906900678364, 53.493843964168, 54.86726311274937, 40.313114711216514, 4.900565334728785, 0.1138050536225949, 0.2361738570034504, 0.21312818862497807, 0.14753804888044084, 0.13744037571762288, 0.11772910984499113, 0.054887172632983754, 0.11217629816383123, 0.10153173256133284, 0.13424496432500227, 0.11640323884785175, 0.1730641291609832, 0.13238018724535192, 0.2347138396331242, 0.08676819476698126], [0.037149737988199504, 0.04700563555317266, 0.002877366974384391, 0.022752239302332913, 0.028401793113776615, 0.082984914204904, 0.03182929401685085, 0.03772101697645017, 0.026607179947729622, 0.04403702449053526, 0.0320156197329717, 0.07621348077165228, 0.03455757476123316, 0.03684452615146126, 0.05156496340142829, 0.06513767902340208, 0.03467415725546224, 0.04458618662985308, 0.01019874689102705, 2.2863876904760088, 21.311695371355327, 46.06388854980469, 40.68957853317261, 28.582267795290264, 23.87696507998875, 33.369015557425364, 41.402884074619834, 41.99999836512974, 12.050702895436968, 0.05404331934239183, 0.10130895594401018, 1.7147016354969569, 1.503117914710726, 3.6853271382195607, 5.3792540941919595, 2.621913160596575, 18.646324702671595, 40.69540459769112, 50.53416844776699, 44.86140898295811, 43.985046591077534, 41.65582629612514, 39.418537616729736, 36.883428301130024, 38.41202504294259, 40.45306185313633, 40.043118136269705, 39.17761925288609, 41.122666699545725, 37.95120314189366, 38.1239527293614, 33.66554730279105, 32.19776119504656, 32.445759773254395, 32.11919443947928, 31.843837329319545, 33.97891105924334, 33.69283287865775, 35.09254401070731, 33.254179205213276, 32.702276842934744, 32.77665383475167, 33.94060911451067, 33.004818780081614, 32.62656927108765, 33.86203193664551, 33.226028578622, 34.205439703805105, 35.63186318533761, 36.72810132162911, 36.15816490990775, 33.60020644324166, 31.536424704960414, 30.69996929168701, 31.976165771484375, 31.98158884048462, 32.553154604775564, 35.978487968444824, 40.05316523143223, 42.966100215911865, 42.15132665634155, 43.28754472732544, 42.04877471923828, 40.852642331804546, 40.33420596803938, 37.32829019001552, 39.77037354878017, 42.34167603084019, 44.11806637900216, 39.579895632607595, 39.30837392807007, 39.91263096673148, 45.92818675722395, 39.474581786564414, 40.67460169110979, 42.594131878444124, 44.40971006665911, 45.84287330082485, 41.58766099384853, 38.153128215244834, 31.63663509913853, 29.90424769265311, 32.6440509387425, 32.50173098700387, 31.97008262361799, 32.61326347078596, 35.84985944202968, 44.57567126410348, 45.816577843257356, 46.9067119870867, 46.494284289223806, 44.221438203539165, 36.16192735944475, 34.64113344464983, 34.37883199964251, 32.84942579269409, 33.98920828955514, 33.12371635437012, 32.52531317302159, 33.599997997283936, 33.003978048052105, 33.98237126214163, 33.67597654887608, 34.19303022112165, 38.62920141220093, 40.965463706425254, 41.479196139744346, 44.51726470674787, 44.620132786887034, 45.35891389846802, 47.32965925761631, 48.28513036455427, 47.56388998031616, 47.8111173084804, 47.87061125891549, 45.94368471418108, 46.28701605115618, 43.45203985486712, 40.82910878317696, 45.99951696395874, 48.117755208696636, 52.73689678737095, 44.76678146634783, 25.10912561416626, 4.727255983012063, 1.8519637329237801, 3.554647590432848, 5.091785839625767, 1.22889173243727, 0.699863382748195, 0.2548794118421418, 0.1555027472121375, 6.965797943728311, 36.4784699167524, 38.151509284973145, 36.36575276511056, 44.31526320321219, 42.970310824257986, 44.050595896584646, 22.94617918559483, 0.5940312987991742, 0.03485977390248861, 0.05215149924957326, 0.044261131036494455, 0.011905214117307748, 0.04239844723737665, 0.026658580671729784, 0.01758670317940414, 0.03222140922610249, 0.023366888552638035, 0.048231772080596, 0.1182309543447835, 0.028126438514196446, 0.02686963220393019, 0.05479542112776211, 0.019464291000206555, 0.021089662265564715, 0.005402851201194737, 0.017701497733859078, 0.024730245216882656, 0.02533494884015194, 0.03551786466102515, 0.016214595109756504, 0.050713476591876576, 0.05217415214117084, 0.04481121937611273, 0.04065042567838516, 0.07457081534500633, 0.025068267614447644, 0.05333262176385947, 0.01743902512160795, 0.016708322634388293, 0.08962599427572318, 0.016000298483829414, 0.041890322895986695, 2.910834674324308, 27.477205446788243, 52.811933858054026, 47.25405938284737, 33.374640124184744, 31.06614977972848, 35.857957567487446, 46.45953287397112, 44.08035503114973, 12.959854704993111, 0.026935394121600047, 0.099678253089743, 2.3241279167788367, 2.4712241036551337, 1.4090019592217036, 6.581249458449228, 4.698577293327876, 19.562486376081193, 42.76035015923636, 52.435508251190186, 47.81943777629307, 46.985768590654644, 42.71201154163906, 41.13633033207485, 38.50205980028425, 39.89076151166643, 42.35233804157802, 40.59062923703875, 42.29917390005929, 42.65129470825195, 40.57269941057478, 39.67890746252877, 36.213569845472065, 34.5030379976545, 33.96876668930054, 34.13263995306832, 32.65409108570644, 35.250445297786165, 34.74147238050188, 36.359339577811106, 34.752158709934776, 34.27036714553833, 34.262473991939, 35.24085330963135, 35.524447509220664, 35.06310796737671, 34.02860457556588, 34.68101610456194, 37.26942505155291, 38.52595118113926, 39.476881640298025, 37.41856118610927, 35.01053442273821, 33.76339878354754, 33.150845595768516, 33.02109840938023, 34.387388706207275, 34.19047328404018, 37.16536882945469, 41.65803929737636, 43.5506591115679, 44.19342654091971, 44.78973831449236, 44.99501936776297, 40.95610795702253, 41.95277145930699, 39.87917539051601, 41.54482534953526, 44.017529419490266, 45.61341251645769, 41.61111116409302, 40.449094431740896, 42.947704860142295, 46.73906585148403, 41.00421033586775, 43.23398801258632, 44.744404792785645, 46.4504793712071, 47.23026180267334, 41.57911123548235, 38.510373319898335, 33.37999023709978, 31.595557349068777, 33.937610966818674, 34.11881651197161, 33.522195543561665, 33.8206067766462, 37.88135290145874, 46.91010965619768, 46.95460591997419, 48.802225725991384, 48.410889284951345, 44.53045238767351, 37.88651193891253, 36.70469978877476, 36.05934068134853, 35.198573521205354, 35.831561361040386, 35.26560626711164, 33.18357161113194, 35.24659252166748, 34.15738943644932, 34.77492448261806, 35.3680921963283, 35.63956526347569, 41.02174064091274, 43.070312772478374, 44.24148375647408, 45.85423707962036, 47.7543157849993, 47.242511476789204, 49.69474615369524, 50.2142664364406, 49.525630474090576, 48.76164129802159, 49.010140146527974, 47.74160752977644, 47.660567215510774, 46.02399199349539, 43.66607911246163, 48.4051570211138, 49.77234016145979, 55.11076968056815, 45.25914471490042, 28.536307198660715, 6.34509755883898, 2.5072722264698575, 6.653814707483564, 5.1556554181235175, 4.8780067052159986, 2.6887122733252387, 0.21904795882957323, 0.05656977663082736, 7.953111342021397, 41.693919794900076, 43.476813656943186, 39.791635036468506, 46.95143754141671, 48.77311624799456, 50.42373725346157, 28.908343281064713, 0.890085409794535, 0.0573567890429071, 0.0282765677797475, 0.01630970197064536, 0.030779410353196517, 0.02496479102410376, 0.07153482575501714, 0.021386869085420455, 0.017975006718188524, 0.08663694573832409, 0.015369126905820199, 0.054974500089883804, 0.05289013211482337, 0.01775074071649994, 0.049130847943680625, 0.04300932552931564, 0.14962123281189374, 0.1342632169170039, 0.12458311420466218, 0.1536469403654337, 0.13018026814929076, 0.17776804603636265, 0.10418445843138865, 0.14084690649594578, 0.16831594466098718, 0.10994356511426823, 0.10835196623312575, 0.2678627451615674, 0.07940414241914238, 0.09271249401250056, 0.1310873744743211, 0.13191494292446546, 0.22950228356889316, 0.13398595393768378, 0.13625656281198772, 3.1312842965126038, 32.049260820661274, 59.724776540483745, 52.36165584836687, 41.5720796585083, 33.52694811139788, 42.63455997194563, 49.75361476625715, 50.021412236349924, 15.735347373144966, 0.2355799488723278, 0.3765569712434496, 4.446390688419342, 6.33199759892055, 12.432985833712987, 12.024671469415937, 5.2573349220412116, 21.596161569867814, 43.63388810838972, 53.23761871882847, 48.399174622126985, 48.33133241108486, 45.17485611779349, 43.59100382668631, 39.820265088762554, 43.04041814804077, 44.327787331172395, 42.90884011132376, 43.82757261821202, 44.031644684927805, 41.19501829147339, 42.40282365253994, 37.64243561880929, 35.76731136866978, 35.25094209398542, 35.341772420065745, 34.477374826158794, 37.535603591373985, 37.00340632029942, 37.65319490432739, 35.17162493297032, 36.21364974975586, 36.44868646349226, 35.895311083112446, 37.39734486171177, 36.58986691066197, 37.21614973885672, 37.73099388395037, 39.31053134373256, 39.16399383544922, 40.862279483250205, 40.380053656441824, 38.33738054547991, 35.357885292598176, 34.04336254937308, 35.92409399577549, 35.124939986637656, 35.72524002620152, 39.27103083474295, 43.662413937704905, 45.3689992087228, 46.547802788870676, 46.406910691942485, 47.66388498033796, 43.9912999698094, 43.940032686506, 42.62202542168753, 43.68747956412179, 47.52192633492606, 47.46467317853655, 44.37239824022566, 43.683369704655235, 44.482030391693115, 45.922489234379356, 42.36443485532488, 45.72987822123936, 46.44667175837925, 48.22721365519932, 48.933821133204866, 43.06946856634957, 40.99827657427107, 34.276589257376536, 32.9428790637425, 35.03947366986956, 35.741880961826865, 34.48858227048601, 34.847283022744314, 38.74904046739851, 49.68961490903582, 50.3390143939427, 50.596309661865234, 50.2958139692034, 46.65399905613491, 38.993054253714426, 38.560820715767996, 36.974335057394846, 37.24258416039603, 37.21433278492519, 36.67747674669538, 34.94594049453735, 38.467360496520996, 35.859524386269705, 38.74064356940133, 37.39618798664638, 37.22249344417027, 41.93674543925694, 45.458339146205354, 45.674615723746165, 48.77252912521362, 49.81055525371006, 48.32889011928013, 51.604569707598, 52.472107887268066, 51.89172485896519, 50.76249320166451, 49.864733832223074, 48.883321625845774, 50.24169792447771, 47.57039696829659, 44.81003747667585, 50.003388609204976, 51.62089450018746, 56.07495035443987, 46.256631578717915, 29.705240862710134, 7.032204917498997, 3.605479959930692, 8.750688978603907, 12.537701266152517, 8.418730105672564, 3.992731945855277, 1.3035592458077838, 0.35288264017019955, 8.951432858194623, 46.688142504010884, 50.493458952222554, 49.543070452553884, 54.861263343266074, 54.328524112701416, 58.99990572248186, 31.633411134992325, 1.2455994359084537, 0.1482826460685049, 0.15477908961474895, 0.11064811516553164, 0.0690948273986578, 0.08015727557774101, 0.15740305238536426, 0.1750500111707619, 0.07731287035026721, 0.14749676680990628, 0.1235736712281193, 0.33590392981256756, 0.11201714777520724, 0.14908263885549136, 0.13022940765534127, 0.07095006427594594], [0.02463061422375696, 0.04406736179121903, 0.058605870231986046, 0.03157809017492192, 0.022892134563465203, 0.034622815903276205, 0.005151459913966911, 0.04332520054387195, 0.04864672338590026, 0.03843185365466135, 0.037077063495027165, 0.04171874513849616, 0.04242019767739943, 0.023674700874835253, 0.0338936180674604, 0.03462960125346269, 0.018116298065121685, 0.06026615042771612, 0.0320456924049982, 0.6351454183459282, 14.549691132136754, 42.08509990147182, 41.675448008946006, 28.50389732633318, 26.77255736078535, 34.56802102497646, 37.52717195238386, 46.00316824231829, 18.77774293082101, 0.0805759723963482, 0.05937579034694603, 2.648700854607991, 8.772554959569659, 29.16574103491647, 9.361488614763532, 3.7132332750729153, 16.2123863697052, 43.771368639809744, 46.45007290158953, 47.66884252003261, 44.056185722351074, 41.796496050698416, 38.56151206152779, 37.560971464429585, 37.114938804081504, 40.0913907459804, 40.11112710407802, 39.110687255859375, 37.645367758614675, 36.03677988052368, 33.26348631722586, 32.5233850479126, 32.058640888759065, 31.8854535647801, 33.113089084625244, 33.377898829323904, 33.04218619210379, 32.79290567125593, 31.557321412222727, 32.41489587511335, 32.80560350418091, 33.92827953611101, 33.4068797656468, 33.183397906167166, 32.50281490598406, 32.27533783231463, 32.06173978533064, 33.80756153379168, 33.6439905166626, 34.69017383030483, 32.981733390263145, 31.80972167423793, 32.113840852464946, 32.20973294121878, 30.62744399479457, 32.627406529017854, 33.14984505517142, 43.40222474506923, 46.06539978299822, 46.28155129296439, 43.127211570739746, 44.20443596158709, 45.33007192611694, 42.49169111251831, 44.32636642456055, 41.079216139657156, 42.24572835649763, 42.82362740380423, 46.38981464930943, 37.87948036193848, 39.91548320225307, 39.85037858145577, 38.535789830344065, 44.96422495160784, 40.775944641658235, 44.34785720280239, 43.70051438467843, 43.967141083308626, 43.01675605773926, 40.31373657499041, 34.098937715802876, 31.40253986631121, 30.853062425340923, 33.48078080586025, 33.24989564078194, 33.425834451402935, 33.995340074811665, 42.58609628677368, 46.43148994445801, 47.16337844303676, 45.674254417419434, 44.63180228642055, 38.09125798089163, 32.42552661895752, 33.02116094316755, 33.80734961373465, 33.75959464481899, 31.68931634085519, 32.186126436506, 33.38678557532174, 33.91681153433663, 33.548727239881245, 32.08450903211321, 32.09370844704764, 32.40475845336914, 33.26671722957066, 35.817345346723286, 39.631927217756, 42.56525863919939, 44.454616274152485, 44.95539379119873, 46.713763986315044, 47.48021282468523, 46.660891669137136, 46.33190141405378, 43.616983141217915, 43.23021166665213, 38.94177654811314, 40.8936436516898, 44.26887355531965, 48.92355169568743, 52.68274252755301, 40.4153505052839, 15.404998745237078, 2.8092596105166843, 0.9892126449516842, 5.075874899114881, 1.6317255965300967, 3.295519083738327, 2.0035328226430074, 0.12091384109641824, 0.15702221782079764, 8.39217930180686, 37.68698746817452, 35.304349422454834, 26.73211189678737, 39.1913732119969, 40.47240563801357, 43.73927838461739, 13.043092387063162, 0.25182282871433664, 0.027276547958276103, 0.0075871088608567205, 0.07750332155930144, 0.013765294886460262, 0.03220318716817668, 0.04432780049475176, 0.031681512482464314, 0.020571509176599126, 0.03970724503908839, 0.04042980680242181, 0.009099400569019573, 0.03429214543263827, 0.009181885830392795, 0.028964760048048835, 0.058542562914746146, 0.0336358731479517, 0.025814271066337824, 0.00926210478480373, 0.03954278511394348, 0.06937620908554111, 0.0711555111088923, 0.03694403331194605, 0.06688083548630987, 0.029382625661258186, 0.03259956697002053, 0.04466215201786586, 0.04084635605769498, 0.045878666918724775, 0.029400739153581004, 0.058290941773780754, 0.007019405752154333, 0.05253728372710092, 0.02361455383444471, 0.02617709052615932, 0.713554536657674, 19.293203728539602, 49.84987163543701, 45.087489468710764, 33.206250531332834, 28.489509344100952, 39.132535866328645, 45.30963032586234, 49.03502859388079, 19.382145881652832, 0.11102318218243973, 0.05947140950177397, 2.004123853785651, 5.423052498272487, 20.025556019374303, 5.717521931443896, 4.301043493407113, 17.545139448983328, 45.232943058013916, 48.949753352573936, 48.63593101501465, 46.507068974631174, 43.645880699157715, 39.61081164223807, 39.528075967516216, 40.105356625148225, 43.03957046781267, 41.76311690466744, 41.04709809167044, 40.428993293217246, 38.956871509552, 36.23476879937308, 34.089974539620535, 33.355945995875764, 33.79467262540545, 34.225506101335796, 33.70328296933855, 34.557682105473106, 34.11239637647356, 32.95265517915998, 34.56492907660348, 34.47092342376709, 34.41690812792097, 35.53499487468174, 34.49664912905012, 34.465868609292166, 33.27313041687012, 34.662787505558555, 35.72555269513811, 35.687952518463135, 37.03359276907784, 34.84626858575003, 34.31545748029436, 33.41521412985665, 33.65776879446847, 33.486005851200645, 33.9736373765128, 35.775934083121165, 44.83027063097273, 46.96341623578753, 47.870086669921875, 45.68825503758022, 46.175817080906455, 46.57238204138619, 45.77736221040998, 45.34987081800188, 41.60585832595825, 44.00122547149658, 45.424452781677246, 47.34443460191999, 41.95587035587856, 40.96699925831386, 41.757391589028494, 42.851500102451865, 45.25306504113333, 41.49980449676514, 45.782646315438406, 43.67800916944231, 45.43202631814139, 44.48681770052229, 40.93851511819022, 34.71065364565168, 32.64820943559919, 32.491697788238525, 34.17398173468453, 34.6360821042742, 34.838014125823975, 36.7071281841823, 44.62522234235491, 46.94129317147391, 49.135193824768066, 46.95388330732073, 46.609620911734446, 39.1113612311227, 33.521208899361746, 34.37840468542916, 35.41546154022217, 34.91513565608433, 34.30493790762765, 33.50094100407192, 34.53686530249459, 35.138815539223806, 33.86903919492449, 33.22451039722988, 33.71366705213274, 34.29563079561506, 36.71832868031093, 39.22584669930594, 42.29046433312552, 46.52223341805594, 45.67799254826137, 47.20776700973511, 48.03824349812099, 47.82322454452515, 49.14763110024588, 49.477024350847515, 45.99913828713553, 45.12612492697579, 39.89374576296125, 42.604759148189, 46.22790077754429, 50.53572137015206, 53.98503296715872, 42.42823668888637, 17.46366834640503, 4.855171884809222, 2.9655671545437405, 6.6985476442745755, 4.293439558574131, 4.953560548169272, 2.7292474125112807, 0.2574042135051319, 0.1536325282816376, 9.207515665463038, 42.158479826790945, 43.332277229854036, 34.34489352362496, 43.34757716315133, 46.96537215369088, 49.92211205618722, 17.81502311570304, 0.4125515440745013, 0.022825653398675576, 0.02303532580845058, 0.027393513824790716, 0.03398708626627922, 0.05182740378326603, 0.031667782326361964, 0.08283630825046982, 0.030871976100440537, 0.03531857892604811, 0.013832816754334738, 0.0021478710072447677, 0.020835603487544825, 0.06313450115599803, 0.0666328648637448, 0.02654818811320833, 0.07975335725183998, 0.13397739082574844, 0.13017927748816355, 0.17623982232596191, 0.1297765669545957, 0.178538997524551, 0.11166084903691496, 0.15311119625610964, 0.10265737465981926, 0.11366482079029083, 0.12923183904162475, 0.11588719939546925, 0.13493109893585953, 0.08558273980660097, 0.13851870356925897, 0.09137497935444117, 0.1186110425208296, 0.1433661034596818, 0.21087712155921118, 1.0098457549299513, 22.75375577381679, 55.69286891392299, 53.38114070892334, 39.738186018807546, 35.585574286324636, 43.68672915867397, 48.21420662743704, 55.30133792332241, 24.811727081026348, 0.2997689273740564, 0.2731951618833201, 6.47997077873775, 14.589335816247122, 36.45884472983224, 17.598772593906947, 6.514036927904401, 18.06069925853184, 46.6252578326634, 50.28335237503052, 51.17897169930594, 47.33370310919625, 46.07427610669817, 41.64446251732962, 41.36451959609985, 40.780009337833945, 44.99812868663243, 43.09887681688581, 43.19272266115461, 42.199383871895925, 40.36011927468436, 37.59709514890398, 35.410389355250764, 36.10858951296125, 35.051459312438965, 35.41975552695138, 36.13715008326939, 36.93896177836827, 36.29250485556466, 33.64398009436471, 35.84022576468331, 35.97453096934727, 36.04850149154663, 37.34228733607701, 35.89967802592686, 36.02581214904785, 35.719132559640066, 37.11285087040493, 37.54816593442644, 38.232271671295166, 38.61171974454607, 36.075533458164756, 35.49788107190813, 34.896709033421104, 35.51987212044852, 34.78255360467093, 37.570018018995015, 37.79470886502947, 47.44647584642683, 49.728629044124055, 49.62890154974801, 46.823142528533936, 48.336720739092144, 48.538228920527864, 48.69544581004551, 47.88967016765049, 45.10264696393694, 45.65024839128767, 47.91841833932059, 48.38665049416678, 44.481429372514995, 41.257340158735005, 44.76515211377825, 42.96344600405012, 45.60414709363665, 42.90855176108224, 47.744553565979004, 46.95116656167166, 47.46222741263253, 46.5457079069955, 43.05751419067383, 36.90446744646345, 34.39218296323504, 33.77141353062221, 36.0709684916905, 36.71236712591988, 36.08917277199881, 37.85876778193882, 45.76343107223511, 50.188207217625205, 50.319924218314036, 48.98747512272426, 49.018929617745535, 41.24267945970808, 34.89482259750366, 35.585803576878135, 37.669533593314036, 36.327256270817344, 36.14914962223598, 35.25173418862479, 36.39319120134626, 38.07136181422642, 36.15239443097796, 35.16704259599958, 35.069861616407124, 35.76531376157488, 36.89278405053275, 40.03261593409947, 44.46435417447771, 47.442421572549, 48.74873849323818, 50.12430463518415, 51.01703003474644, 51.305581774030415, 52.54485552651541, 50.39637872150966, 48.113895484379356, 46.28164161954607, 42.29581444604056, 45.35195180347988, 48.18017782483782, 53.6904501914978, 56.459217003413606, 42.9602289881025, 18.925784724099294, 4.812413973467691, 3.6317055012498582, 10.648943781852722, 8.132764833314077, 12.397577813693456, 5.509691323552813, 0.4846464054925101, 0.2811699296746935, 10.618076409612383, 46.37739127022879, 49.00458853585379, 40.00424991335188, 49.02074657167707, 53.32009731020246, 57.34343433380127, 20.819255692618235, 0.6026964081185204, 0.11465299847934927, 0.16368160476641996, 0.2206282126052039, 0.10472741536796093, 0.1709376818367413, 0.1391959222299712, 0.1876828811530556, 0.09358757348465067, 0.09024470286177737, 0.054461520830435414, 0.1233648317200797, 0.11569282625402723, 0.124393938641463, 0.11418090095477444, 0.15269411435084684], [0.008071700759631182, 0.027033457698832666, 0.0651428901723453, 0.02927736791649035, 0.03938636922144464, 0.023856809495815208, 0.03761603403836489, 0.05157402523660234, 0.0273846351940717, 0.03325757630435484, 0.06439238972961903, 0.05343493127397128, 0.03883836059165852, 0.010209775629586406, 0.08285376695649964, 0.05478803527408412, 0.015776638074644973, 0.03287739652608122, 0.029330246150493622, 0.328329579106399, 7.072574819837298, 40.72706753867013, 47.58986234664917, 37.35568346296038, 30.80123928615025, 34.233086585998535, 36.56467274257115, 41.84226383481707, 24.842889751706803, 0.9274942938770566, 0.10366650551025357, 0.18986046287630284, 6.123726648943765, 26.99109557696751, 10.342157363891602, 2.877054921218327, 14.287159528051104, 40.61816494805472, 49.905835900987896, 47.461786202022004, 45.522446700504844, 41.598965712956016, 39.60113974979946, 39.12039041519165, 38.63122681209019, 38.552903243473594, 36.364613260541645, 34.080688272203716, 33.36102512904576, 31.73722764423915, 31.868625027792795, 30.811091831752233, 32.275000844682964, 31.429290430886404, 34.814998217991416, 35.013435295649934, 34.57555634634835, 33.896922315870015, 34.07958698272705, 32.15735394614083, 33.315531798771445, 33.3655275617327, 33.29252283913748, 33.797524860927034, 33.02210937227522, 35.36356891904558, 36.03352812358311, 35.85792630059378, 37.06878192084176, 35.80368518829346, 33.763697556086946, 31.70658608845302, 32.439610617501394, 30.966029712132045, 32.75436748777117, 32.78883055278233, 37.52811343329293, 44.65341813223702, 47.56952844347273, 43.959244455610005, 42.19214037486485, 42.25559132439749, 42.99211427143642, 45.68220315660749, 43.828121525900706, 44.79953180040632, 42.00282628195626, 44.118973118918284, 43.44440378461565, 38.14404691968645, 38.83626467841012, 44.92812558582851, 35.83582060677664, 39.44365188053676, 42.268490655081614, 40.61247089930943, 44.22492272513253, 47.39112997055054, 41.920107977730886, 42.018755027226035, 35.14155312946865, 32.720269203186035, 32.757383005959646, 30.418699264526367, 31.744835921696254, 33.41530098233904, 36.273397309439524, 39.40965781893049, 44.81754500525338, 45.98854923248291, 45.24447359357561, 43.86097608293806, 39.78878627504621, 33.20503112248012, 32.434955324445454, 34.05837760652815, 32.40261493410383, 33.219215869903564, 33.364068440028596, 32.1186455317906, 33.70192459651402, 32.7301356451852, 32.771241188049316, 32.88324267523629, 32.53789636066982, 32.79403822762625, 31.338126591273717, 32.728989192417686, 36.03354549407959, 38.85421534946987, 41.69593129839216, 44.096394947596956, 44.38470002583095, 42.54541458402361, 39.759492669786724, 37.44973080498831, 34.27309431348528, 36.71395478929792, 38.45604535511562, 43.79516274588448, 47.78781305040632, 50.913137095315115, 36.35770675114223, 12.42287620476314, 3.0053191014698575, 3.1739180088043213, 6.719015300273895, 4.003191156046731, 3.3687782841069356, 1.4216090313025882, 0.1949805931321212, 0.21110350798283303, 10.407648478235517, 41.08831480571202, 32.96858392442976, 32.74939257758004, 38.409999643053325, 36.581855637686594, 40.35250057492937, 9.939226116452899, 0.1691190315676587, 0.021950433130509088, 0.06838459122393813, 0.0617399217028703, 0.09941048281533377, 0.03440194936203105, 0.009075469487080616, 0.029034757720572606, 0.055829793480890136, 0.028669899263020073, 0.01921453752687999, 0.011501619791878121, 0.06986510713717767, 0.0313049425104899, 0.08530247770249844, 0.015266087970563343, 0.0868167168061648, 0.015605791438637035, 0.08178422613335506, 0.019251609287623848, 0.04372728003987244, 0.04215230526668685, 0.0514628472737968, 0.04773678417716708, 0.033045205021543164, 0.0014663483140923614, 0.014598056674003601, 0.04619881331122347, 0.011003555580308395, 0.04953904104019914, 0.05675739495615874, 0.07115886307188443, 0.0530508668827159, 0.025922312501019666, 0.043990622873284986, 0.42313853598066736, 9.915297389030457, 48.10416105815342, 52.011953013283865, 41.81337669917515, 31.885971205575125, 36.77857651029314, 41.743397917066304, 47.933954511369976, 26.456693989889963, 1.0326309608561652, 0.05545654154515692, 0.6424697967512267, 8.81477221420833, 31.02146938868931, 11.028269393103463, 4.873707073075431, 16.288835661751882, 42.69575275693621, 50.62975481578282, 48.82642977578299, 47.461188656943186, 43.6124598639352, 40.19359179905483, 40.66643755776541, 40.19957767214094, 40.68579871313912, 39.40219892774309, 36.79488740648542, 35.11435440608433, 33.53221484592983, 33.16228233064924, 32.68338816506522, 34.046756744384766, 33.57245881216866, 34.606399399893625, 36.14030456542969, 35.44453975132534, 34.72829164777483, 35.356374059404644, 33.54718821389334, 34.34558139528547, 34.89507620675223, 35.76869058609009, 34.67118092945644, 34.10696635927473, 36.137963022504536, 37.48273474829537, 37.581465176173616, 38.12070097242083, 37.902100222451345, 35.69710329600743, 33.208084855760845, 33.784611633845735, 33.782040800367085, 34.315210819244385, 34.7863438470023, 36.90355723244803, 45.631953784397666, 48.7512572152274, 43.51250307900565, 43.37175689424787, 43.305248737335205, 46.302038056509836, 47.455063819885254, 45.135168007441926, 46.430312224796836, 43.994145257132395, 45.53454351425171, 45.29363904680525, 40.28632940564837, 40.59408943993704, 45.19098636082241, 36.71078641074044, 41.58272082465035, 44.29071174349104, 42.1486759185791, 44.85166760853359, 47.351733684539795, 43.90399585451399, 43.76805782318115, 36.42031349454607, 33.96671002251761, 33.46895497185843, 33.53199250357491, 33.7228456224714, 34.58463764190674, 37.84520489828927, 40.88266202381679, 46.227115631103516, 46.91300010681152, 48.708233969552175, 46.206799098423545, 42.16053996767317, 34.50402116775513, 34.194600514003206, 36.0437593460083, 34.27957698277065, 34.55831439154488, 35.79803282873971, 33.259004729134695, 35.068642207554404, 33.84237895693098, 34.59062351499285, 33.99036863871983, 34.50438594818115, 34.451437200818745, 32.77161291667393, 35.43463509423392, 38.281499658312114, 41.67009094783238, 43.686878544943674, 45.56858968734741, 47.50993374415806, 45.9957058770316, 42.839358125414165, 39.18587718691145, 37.95987449373518, 39.50375032424927, 41.20089299338204, 45.738490513392854, 50.5568265233721, 53.0485234941755, 38.04418740953718, 14.338906237057277, 3.3864786028862, 3.8045365129198347, 5.889228854860578, 5.1955298270498, 4.037229512419019, 2.9382201305457523, 0.12843963583665235, 0.15200076012739114, 11.421256031308856, 46.3059846333095, 38.88629518236433, 34.602768966129844, 41.15710891996111, 41.51617097854614, 44.82988153185163, 12.859790222985403, 0.1412268453942878, 0.03969082449163709, 0.014725375288565243, 0.04712578035624964, 0.07089006142424685, 0.022599489195272326, 0.06979444450033562, 0.040446600544133356, 0.020622339931183627, 0.052482983962233574, 0.07187097200325557, 0.012376368478206652, 0.0635268029623798, 0.005044649172175143, 0.03662618376048548, 0.016475486735414182, 0.13216330031199114, 0.12295672004776341, 0.17480702778058393, 0.09991123487374612, 0.11117444799414702, 0.13188421885882104, 0.12869376077183656, 0.14112191673900398, 0.15699233513857636, 0.09694284094231469, 0.17762845781232628, 0.12377645820379257, 0.08801063309822764, 0.1073478836832302, 0.22478053479322366, 0.14797311196369783, 0.15395886291350636, 0.11535851205033915, 0.10147538022803408, 0.5241485972489629, 12.030184864997864, 52.17702831540789, 58.629219327654155, 48.540452344076975, 40.66456849234444, 43.07980401175362, 47.328623976026265, 51.9603522164481, 30.65691477911813, 1.5178644891296114, 0.4674159043601581, 1.559916289789336, 9.830158506120954, 32.04091950825283, 16.671193293162755, 6.165911768163953, 17.935294696262904, 42.96836532865252, 52.8715945652553, 52.89177213396345, 50.20405605861119, 45.67724214281355, 42.42099666595459, 42.67312247412545, 40.984512192862375, 41.59019708633423, 40.17826407296317, 38.59047910145351, 36.592958859034944, 36.66156884602138, 35.313833713531494, 34.17240449360439, 35.13278450284685, 35.812627519880024, 37.84765066419329, 37.86634826660156, 38.27647958483015, 36.90907062802996, 37.30359629222325, 34.8767329624721, 37.165757928575786, 36.525387627737864, 36.868583474840435, 36.54478005000523, 36.06761598587036, 38.761901582990376, 39.35929380144392, 39.37908227103097, 41.244107314518516, 39.59648445674351, 37.170131819588796, 34.487828390938894, 35.46450192587716, 34.48541041782924, 37.20939608982631, 37.24173995426723, 40.31644637244088, 47.74219465255737, 51.36539881569998, 45.283928939274375, 44.95829813820975, 43.46713481630598, 46.10789843967983, 50.19335583278111, 47.14922496250698, 49.993080956595286, 45.612033299037385, 48.01340021405901, 45.68041746956961, 43.58965240206037, 41.33902318137032, 46.612191745213096, 42.63782909938267, 43.612908022744314, 46.84957695007324, 43.51133925574166, 44.621161120278494, 48.468927587781636, 45.13897909436907, 45.46728842599051, 38.50121906825474, 37.347790309361045, 37.1802727154323, 35.21120187214443, 35.220647948128835, 35.967683519635884, 40.81845024653843, 43.79216807229178, 48.143755367824006, 49.24350929260254, 49.9058324268886, 46.075033460344585, 43.48479018892561, 36.07552998406546, 35.95413105828421, 37.75670569283621, 35.63647678920201, 36.344915117536274, 36.68758290154593, 35.441638878413606, 36.79216023853847, 35.21224062783377, 35.8706762450082, 36.003011635371614, 35.49366004126412, 35.424400397709434, 33.82578318459647, 36.97779873439244, 39.58962311063494, 42.64400952202933, 45.39431149618966, 47.48698731831142, 49.94302265984671, 47.925953660692485, 43.88267183303833, 41.16476583480835, 39.05565752301897, 40.87040192740304, 42.492517948150635, 47.71710123334612, 53.117070947374614, 54.75508792059762, 39.88813509259905, 16.470383405685425, 4.772972524166107, 8.107450808797564, 12.529198408126831, 10.631302305630275, 10.953425134931292, 5.90815053667341, 0.9361150541475841, 0.40013123197214945, 13.081942370959691, 52.46657712118966, 45.745393548692974, 43.19552278518677, 47.74396991729736, 49.833692755017964, 52.00489016941616, 15.63881778717041, 0.26419092076165335, 0.19827200365918024, 0.11036944083337273, 0.18929347901472024, 0.2264794779143163, 0.10462965882782425, 0.13247777415173395, 0.09322719675089632, 0.13980994213904652, 0.13442882017365523, 0.13528336717614106, 0.04858220488365207, 0.2150944202606167, 0.11379252108080046, 0.15973534009286336, 0.08169473414974553], [0.03744154875831945, 0.0028127454196302487, 0.020588586206680963, 0.015209772956690617, 0.08937036299279758, 0.012350915781488376, 0.03170241475371378, 0.025962931303573505, 0.06754698724086795, 0.08320633375218936, 0.03551009204238653, 0.018040051085076163, 0.010896732115985026, 0.01583723464448537, 0.05491956928744912, 0.05121394705825618, 0.057357956123139174, 0.06255520866917712, 0.051801473567528386, 0.09864355503980603, 5.370145005839212, 32.39346763065883, 45.65015459060669, 41.72853224618094, 30.36284269605364, 32.135647773742676, 32.21276930400303, 40.59148733956473, 28.29587173461914, 2.8403934027467455, 0.13832020493490355, 0.23886848241090775, 1.870815064225878, 18.84226390293666, 14.676132713045392, 2.306019825594766, 8.934969970158168, 31.865765844072612, 51.439345019204275, 48.24947220938546, 45.55705567768642, 40.633058411734446, 42.70511198043823, 38.0009001323155, 35.94159303392683, 34.884945733206614, 33.80092600413731, 31.709354945591517, 32.53700351715088, 30.555276530129568, 32.02142981120518, 32.70592812129429, 34.09731878553118, 39.12791184016636, 42.11223956516811, 42.468282631465364, 40.693598066057476, 36.89106437138149, 33.47558355331421, 33.00749036243984, 32.92425789151873, 32.92545645577567, 35.481007371629985, 33.36913367680141, 37.48836973735264, 38.72946391786848, 40.432047026497976, 38.08971895490374, 36.85412427357265, 33.45923791612898, 33.78682116099766, 31.196160997663224, 31.935101917811803, 31.454915387289866, 32.207763126918245, 31.541979789733887, 38.74111952100481, 46.64332662309919, 44.20587076459612, 45.3062812941415, 44.921087060655864, 43.27709811074393, 44.4054126058306, 44.01483004433768, 46.07134396689278, 44.45131587982178, 43.64168746130807, 40.57134451184954, 42.5391959462847, 37.165858677455354, 39.81590856824602, 41.127328940800254, 44.660616465977256, 45.40034253256661, 40.19787188938686, 40.365656988961355, 35.64114250455584, 40.08987603868757, 45.17157309395926, 39.867335660117014, 35.892976488385884, 32.37915434156145, 32.272617612566265, 31.73682812282017, 32.92018624714443, 32.89565215791975, 34.27279206684658, 36.563804217747276, 41.30395909718105, 44.9730144228254, 46.94558368410383, 44.519088608878, 40.94471638543265, 32.24393892288208, 33.620234625680105, 33.37316015788487, 33.47310652051653, 32.64414473942348, 32.917566776275635, 32.678232601710725, 35.754717758723665, 34.938627515520366, 32.76151371002197, 33.26318754468645, 33.45377663203648, 33.68444292885916, 32.107948780059814, 30.77155658176967, 32.44309861319405, 31.384158406938823, 34.23666838237217, 34.44618436268398, 36.752878597804475, 34.4316417830331, 35.28960534504482, 34.922462531498496, 36.762321199689595, 37.0928886958531, 41.56612505231585, 42.491034507751465, 47.60887261799404, 47.78737531389509, 33.50696856634957, 7.597305383001055, 2.5052479122366225, 1.9148842309202467, 4.891622568879809, 2.7780743581908087, 1.548828701887812, 2.3263756590230122, 0.2052603986646448, 0.3718014449945518, 9.605432050568716, 39.67409930910383, 36.18875435420445, 31.78202268055507, 38.99413122449602, 45.61262389591762, 35.24549470629011, 5.1877817170960565, 0.08498828884746347, 0.06874789244362287, 0.07013681291469506, 0.03377972257190517, 0.03413801620315228, 0.028033521625080278, 0.06059788619833333, 0.01974260401246803, 0.03428277147135564, 0.054042735802275796, 0.046031340690595765, 0.02248012979647943, 0.03888811417190092, 0.021664844526510154, 0.017041549485708987, 0.03709714473890407, 0.04097453132271767, 0.02441851605129029, 0.021065272324319397, 0.10651197603770665, 0.09412220479654414, 0.00818207805111472, 0.019730814466519014, 0.015096669650769659, 0.061909704735236507, 0.0816534317231604, 0.025277178368664215, 0.04278780759445258, 0.024127488989116888, 0.0779126478093011, 0.0586865209043026, 0.03812802263668605, 0.051381148264876435, 0.041226423877690516, 0.04353560746780463, 0.04962618189996906, 6.978826250348773, 39.38147592544556, 50.23398542404175, 44.31138263429914, 32.49834026609148, 33.88301202229091, 37.87265723092215, 46.01832921164376, 31.237940515790665, 3.226845694439752, 0.14948135960314954, 0.08387606817164592, 3.421018749475479, 22.17452440943037, 15.225771699632917, 3.99328476190567, 11.052696653774806, 34.3078214100429, 52.9848814691816, 50.343565464019775, 48.167500836508616, 42.36853429249355, 43.71484157017299, 40.748804977961946, 37.350996903010774, 36.54502323695591, 36.54974453789847, 33.69367013658796, 35.64291776929583, 33.151165212903706, 34.15284184047154, 34.513745171683176, 35.0496632031032, 40.408009733472554, 43.2328519821167, 42.953655992235454, 42.08806330817086, 38.57496724809919, 35.12762199129377, 35.42649875368391, 34.399822507585796, 34.21050841467721, 36.20499229431152, 35.27936717442104, 39.11607905796596, 40.72073425565447, 41.8031975882394, 39.856503418513704, 38.16400909423828, 35.40989603315081, 35.44908734730312, 32.572053704942974, 33.89062377384731, 33.385969161987305, 34.00419207981655, 32.916100706372944, 41.48220818383353, 48.361154079437256, 45.670644828251426, 47.22860813140869, 46.24648026057652, 45.39337348937988, 45.84531211853027, 45.03497845785958, 48.00454126085554, 45.11745357513428, 44.97435542515346, 43.260186195373535, 44.53542034966605, 41.075175762176514, 41.11329705374581, 43.50961262839181, 45.498881884983604, 43.86853919710432, 42.350427286965505, 40.99860313960484, 37.76662424632481, 43.55787828990391, 47.33456121172224, 41.949269567217144, 37.705643381391255, 33.306572096688406, 34.45089176722935, 33.47306483132498, 34.17079945972988, 34.57819666181292, 35.82122244153704, 37.949983733040945, 44.61575542177473, 47.46959250313895, 47.39714363643101, 46.15395457404, 43.017457825796946, 34.457558563777376, 34.49976192201887, 33.30806943348476, 35.50777530670166, 33.926368781498496, 34.48653255190168, 34.16946887969971, 36.356063502175466, 35.89860452924456, 34.97831562587193, 34.36674213409424, 35.56659875597273, 35.269320079258506, 33.35367740903582, 32.89224754061018, 33.214449405670166, 34.91119602748326, 36.14193739209856, 37.21373871394566, 37.673931803022114, 37.069716453552246, 37.951088496616904, 37.33008629935128, 37.84194966724941, 38.59296655654907, 43.24245091847011, 45.83740854263306, 49.347127778189524, 50.84511423110962, 35.04271500451224, 10.794799498149327, 3.0302105886595587, 5.397909573146275, 5.987275319440024, 5.525138906070164, 5.660337822777884, 2.8123993277549744, 0.16195763727383955, 0.5379168870193618, 11.379888193947927, 44.1524703843253, 39.78981460843767, 35.78719016483852, 45.13909721374512, 50.13639450073242, 42.477391719818115, 7.225837750094278, 0.18908045973096574, 0.013820201092000519, 0.030610977605517422, 0.026710882150967206, 0.030183904272105013, 0.011747181615126985, 0.03686492630679693, 0.012267802875222904, 0.03412939541574035, 0.06157409452966281, 0.03654933288427336, 0.05944711794810636, 0.018340801554066793, 0.06600556602435452, 0.04125731418441449, 0.039728527289948294, 0.12384524808398314, 0.05545429898692029, 0.12987560592591763, 0.1429892722517252, 0.10971105151942798, 0.09456357825547457, 0.05701140793306487, 0.057219148214374266, 0.13617026672831603, 0.210407303912299, 0.07146231071757418, 0.09965178343866553, 0.07243279221334628, 0.1977401679115636, 0.25216763306941303, 0.1782488152384758, 0.1921903621405363, 0.1878531120185341, 0.11533360981515475, 0.13440817913838796, 8.046613250459943, 43.501337323869976, 56.842785358428955, 52.4466427394322, 41.583360058920725, 41.1328249658857, 42.75252996172224, 49.184661524636404, 35.995681285858154, 4.194132430212838, 0.23559900213565144, 1.8054289328200477, 4.4670281410217285, 26.196593386786326, 19.17455628940037, 5.504961771624429, 12.531737974711827, 35.00236334119524, 55.034183161599294, 52.84267963681902, 50.00329828262329, 43.438240732465474, 47.279812880924766, 42.36953135899135, 38.86831324441092, 38.03711066927229, 36.871935980660574, 35.1129960332598, 36.56497846330915, 34.29568638120379, 35.87140927995954, 37.396059444972444, 37.29918418611799, 43.03127779279436, 46.01533106395176, 46.14644357136318, 44.09083638872419, 39.975213391440256, 36.61322328022548, 37.277988706316265, 36.172811712537495, 35.31616136005947, 39.82378782544817, 35.78757231576102, 42.09989609037127, 42.82346412113735, 43.529908316476, 41.62059892926897, 40.03271320887974, 37.123026507241384, 37.753936835697715, 34.63301794869559, 35.66715656008039, 34.48103652681623, 36.54192434038435, 35.44119766780308, 43.30998740877424, 51.17152323041643, 47.743789264133994, 48.84251138142177, 48.054675987788606, 46.98320470537458, 46.66951090948922, 46.693749700273784, 49.61558185304914, 47.68601499285017, 47.6009065083095, 45.929479122161865, 45.991957323891775, 42.860873222351074, 41.54929304122925, 44.96867527280535, 46.77649579729353, 45.2176570211138, 44.03693573815482, 42.88997227805001, 41.74108069283621, 43.313068934849326, 48.568397998809814, 43.862310137067524, 38.90681321280343, 34.83057260513306, 35.918521540505544, 35.515255042484824, 35.84980385644095, 35.99016441617693, 37.60666281836373, 40.1374260357448, 46.463986669267925, 49.41392081124442, 50.29192645209176, 48.40228394099644, 44.69641011101859, 35.30307790211269, 36.97499861036028, 35.231330803462434, 38.66458511352539, 36.165512629917686, 36.17241219111851, 35.235756805964876, 38.624209131513325, 38.19125992911202, 36.403533594948904, 37.58720786230904, 37.31789221082415, 36.97884791237967, 35.725434575762065, 34.814869676317485, 34.86391006197248, 35.806221280779155, 38.37150314876011, 38.013559750148225, 40.213335105351035, 38.394418307713096, 38.68958820615496, 38.83846378326416, 41.91731480189732, 41.53241239275251, 45.07706369672503, 46.9001007761274, 51.810444831848145, 49.800817353384836, 37.55789341245379, 10.825982144900731, 5.844823351928166, 7.487224204199655, 12.36630310331072, 7.151313543319702, 7.439387593950544, 7.142878430230277, 0.3302968963980675, 0.7716603130102158, 13.989505648612976, 49.75340979439871, 47.72927795137678, 42.32405539921352, 50.54092904499599, 56.98369829995291, 50.10810491016933, 8.975772397858755, 0.21461270110947744, 0.12973125438605035, 0.10159079903470618, 0.1860376237226384, 0.11461097002029419, 0.08401606351669345, 0.136708155008299, 0.08910234166043145, 0.1918062163250787, 0.10182859841734171, 0.10219906496682338, 0.17579920882625238, 0.0682273678747671, 0.16997751407325268, 0.12233679688402585, 0.09945316266800676], [0.01994002377614379, 0.028084622097334692, 0.016589003947696516, 0.052436948753893375, 0.02350842077950282, 0.05741196751062359, 0.04732288120846663, 0.03809165655236159, 0.046266873766269, 0.03351845944832478, 0.06236559205821582, 0.010946064156347086, 0.02892634818064315, 0.02805254774700318, 0.028281963829483305, 0.0377586519212595, 0.03877114152003612, 0.041719878291977305, 0.04253228487712996, 0.08088364052985396, 1.8968760200909205, 21.613083907536097, 47.170875549316406, 41.61270577566964, 23.58691426685878, 24.766398770468577, 30.429184096200125, 34.326605864933555, 37.964741706848145, 7.475004059927804, 0.20670631607728346, 0.1706393707011427, 1.7667907604149409, 26.586083344050817, 17.151322501046316, 3.867452451160976, 5.099292499678476, 23.137223379952566, 46.7585312298366, 46.979219913482666, 48.861438274383545, 44.29877165385655, 42.57883194514683, 37.598967688424246, 38.26758589063372, 34.696910108838765, 33.759889943259104, 32.34517070225307, 33.20284938812256, 33.47452047892979, 36.111257621220176, 38.197687012808665, 42.00627258845738, 42.06174005780901, 44.9426577431815, 45.384361675807405, 44.336027894701274, 42.51523508344378, 35.06193024771554, 31.268314565931046, 33.33765486308506, 31.7259680884225, 32.00202349254063, 33.57352883475167, 40.77738986696516, 40.87679079600743, 42.22657217298235, 39.64148793901716, 35.67149223600115, 31.804684230259486, 32.55427326474871, 31.271458625793457, 31.921994141169957, 31.778096948351177, 33.290261200496126, 30.290223598480225, 38.322626045772004, 42.54729754584176, 44.45955296925136, 42.81114149093628, 45.25267941611153, 44.89004945755005, 44.68824250357491, 43.86949110031128, 48.22371176310948, 43.805286271231516, 45.07388489586966, 38.57220881325858, 40.84234162739345, 38.89207260949271, 36.195629596710205, 42.921920095171245, 44.062574590955464, 43.72777564185006, 44.15521839686802, 42.23609120505196, 42.236831188201904, 39.8616555077689, 42.67017643792288, 41.35059540612357, 36.860051086970735, 31.566388811383927, 31.519815036228724, 32.6082329750061, 31.658473287309917, 32.075577122824534, 32.78111457824707, 34.53112261635916, 39.189306122916086, 42.455584798540386, 45.510058062417166, 44.95509501865932, 40.66441910607474, 33.585017681121826, 32.202447754996165, 33.029766287122456, 33.711242130824495, 31.974772657666886, 35.78771127973284, 40.84225130081177, 41.61201442990984, 39.61268070765904, 36.98630332946777, 35.983101572309224, 33.16504423958914, 33.87436498914446, 31.837240014757427, 33.563242026737754, 33.361494132450645, 33.357328687395366, 33.870425360543386, 34.423557553972515, 34.28893968037197, 34.779683998652864, 36.428394249507356, 36.73614386149815, 37.580829416002544, 41.798347745622905, 43.5828674861363, 47.53815385273525, 49.60363095147269, 50.03655236107962, 28.12484703745161, 7.043908289500645, 1.1041499631745475, 4.243686982563563, 4.023796038968222, 8.217067326818194, 4.951620263712747, 1.827029253755297, 0.09458907760147538, 0.444350924875055, 14.558513607297625, 38.1716764313834, 37.03230387823922, 35.71413333075387, 42.52018914903913, 41.12705448695591, 26.600542545318604, 1.1813692024775913, 0.0544391359601702, 0.05508577983294215, 0.020480592269450426, 0.04296644211613706, 0.08379769059164183, 0.0809057539861117, 0.06679043426577534, 0.06663648145539419, 0.01270936632395855, 0.023277528883357133, 0.03227078961208463, 0.009345516246477408, 0.05434896544154201, 0.03742275333830288, 0.02460214289437447, 0.11254200139748198, 0.014076858659141829, 0.031172658715929304, 0.030237213375845125, 0.08316077012568712, 0.018605247006884644, 0.02297113978836153, 0.04265955090522766, 0.05157430004328489, 0.06699533148535661, 0.06235508155077696, 0.02045096912687378, 0.015515215495335204, 0.004665074986405671, 0.02249740529805422, 0.042638377219970734, 0.043941062675522904, 0.024451116266261255, 0.08545685120459114, 0.05637608202440398, 0.054131746026022096, 2.8915866443089078, 27.43189103262765, 53.46848998750959, 47.2471980367388, 30.441676957266672, 29.650402205330984, 35.647451468876426, 41.27991138185774, 37.97280509131295, 7.138912311622074, 0.09011271422994988, 0.2559919650001185, 3.1386198571750095, 28.201200791767665, 21.50917533465794, 5.381646011556898, 6.149943505014692, 26.900390318461827, 48.62662042890276, 50.376201152801514, 49.86589070728847, 46.920445101601736, 45.55678469794137, 39.55093901497977, 39.40170213154384, 36.53547641209194, 36.494464669908794, 33.519972120012554, 34.55498620441982, 35.07774087360927, 36.70530775615147, 39.099855014256065, 42.16009875706264, 44.012967927115305, 46.40019873210362, 45.76947600500924, 46.66843741280692, 44.27729824611119, 35.70472894396101, 32.37523555755615, 34.97409806932722, 33.62210716520037, 33.90381145477295, 35.27206809180123, 42.01943595068795, 42.44130972453526, 44.81413343974522, 41.03334065846035, 37.82742098399571, 33.31177282333374, 33.63039984021868, 33.658633845193044, 32.95834922790527, 33.13597297668457, 34.70782920292446, 32.57759836741856, 40.738816942487446, 44.99173981802804, 46.07439422607422, 44.52305255617414, 46.50451898574829, 45.533039229256765, 46.56835208620344, 45.358781882694785, 48.90119586672102, 45.712045669555664, 46.7011912209647, 41.38249805995396, 41.80069971084595, 40.59183127539498, 38.227373191288535, 43.84602008547102, 43.96206195013863, 45.27798822947911, 45.54775203977312, 43.90968642915998, 43.293318680354524, 41.4072197505406, 45.82694455555507, 43.78918729509626, 37.270356110164094, 32.32207489013672, 32.70317663465227, 33.376620360783164, 33.753716468811035, 34.256783417293, 34.78747640337263, 35.157655579703196, 40.31291321345738, 45.1112106187003, 46.86564465931484, 45.09251996449062, 42.9621536391122, 35.349662099565776, 34.03770671572004, 34.63875716073172, 34.72494956425258, 33.325787339891704, 36.7210419518607, 41.52979987008231, 43.26649168559483, 41.16832678658621, 38.44680425098964, 36.42587552751814, 34.707790987832205, 36.27242456163679, 33.32849366324288, 33.55892719541277, 34.23414271218436, 35.08272968019758, 35.16974197115217, 35.967419488089426, 35.14476319721767, 34.78689970288958, 37.27404907771519, 38.31565005438668, 38.87620987210955, 42.610272543770925, 46.15322848728725, 48.81502430779593, 51.82097135271345, 50.30587496076311, 30.832388060433523, 8.500716243471418, 3.0113371099744524, 4.8542760014534, 5.6744431001799445, 6.579234915120261, 4.346410019057138, 1.6504894239561898, 0.18828288252864564, 0.46989635697432924, 15.462043455668859, 41.984034878867014, 42.58187525612967, 36.944457803453716, 47.19003520693098, 46.67336368560791, 32.890666825430735, 2.087521778685706, 0.1006988783233932, 0.013875141224291707, 0.015454186359420419, 0.03532120824924537, 0.023464377071442347, 0.023276843562988297, 0.013766524731181562, 0.029131784835564237, 0.025762885609375577, 0.07624682398246867, 0.0394678680625345, 0.010373406893839794, 0.028853459948939935, 0.055078824849001, 0.035625504063708444, 0.06124077098710196, 0.08319844917527267, 0.105609042703041, 0.14120902706469807, 0.23560448469860212, 0.12437523821634905, 0.15490033025188105, 0.09495180206639425, 0.14955492636987142, 0.13807047690664018, 0.14514391949134214, 0.20706170557865075, 0.12497110052832536, 0.1445106698998383, 0.13413672441882746, 0.11672638436513287, 0.165124115933265, 0.12268845444279057, 0.20128636833812508, 0.19451053121260234, 0.08654730447701045, 2.9126972258090973, 32.07727248328072, 60.95251628330776, 53.259050437382285, 34.4967394556318, 35.52373879296439, 39.82872452054705, 45.63266944885254, 45.32280758449009, 9.60190670830863, 0.3035939378397805, 0.7243207703743662, 6.311755325113024, 31.720624923706055, 22.01177327973502, 6.471796657357897, 6.779865452221461, 26.396824836730957, 48.92116151537214, 50.837016105651855, 53.36882502692086, 49.59882974624634, 47.20865290505545, 40.9378376688276, 41.71334000996181, 39.579732349940706, 37.68330144882202, 35.82108695166451, 36.561240332467214, 36.265302658081055, 40.35198988233294, 42.47569635936192, 44.54933064324515, 45.707640511649, 47.960204805646626, 48.82812166213989, 47.438898835863384, 45.633892331804546, 38.43160854067121, 34.024664946964805, 36.61039883749825, 34.69821637017386, 35.87400095803397, 35.8557619367327, 44.554222175053184, 43.84822266442435, 45.90814815248762, 43.590295110430034, 39.04936940329415, 35.11907570702689, 35.369384561266216, 35.668101515088765, 34.96740000588553, 34.162881987435476, 37.57433285032, 33.47219978060041, 41.87156091417585, 47.069737570626394, 49.21756819316319, 46.781192779541016, 48.06848553248814, 47.35331439971924, 48.35068661825997, 47.690951687949045, 51.52588135855538, 47.81555025918143, 47.286048889160156, 43.19457088197981, 43.82702023642403, 43.75784049715315, 37.97380910600935, 44.144681453704834, 46.42941590717861, 48.07200826917376, 47.149909360068186, 44.82611560821533, 44.933923857552664, 43.67384025028774, 47.19264078140259, 45.49498741967337, 40.21511731828962, 34.81171866825649, 33.6925618989127, 35.194904872349326, 34.803971426827566, 36.08270747320992, 35.91164629799979, 37.145048822675435, 42.630509172167095, 46.10539013998849, 50.16622659138271, 47.32495185307094, 44.627946036202566, 37.90332657950265, 35.10698584147862, 36.55283996037075, 36.994630745479036, 35.15974351337978, 39.09570346559797, 44.32603291102818, 45.95977326801845, 43.38589300428118, 42.06691646575928, 38.743832792554585, 36.873044218335835, 37.98911598750523, 35.08675616128104, 36.96947826657976, 35.59822695595877, 36.02988031932286, 37.59822423117501, 37.159789425986155, 37.39287369591849, 36.79086439950125, 39.44555916104998, 41.4368850844247, 40.884388651166645, 45.81484774180821, 48.40925645828247, 51.09756660461426, 52.26745564596993, 53.050135476248606, 31.863219329289027, 10.491467203412737, 4.171126510415759, 8.777453439576284, 9.743346844400678, 17.06739173616682, 14.362750717571803, 5.392503440380096, 0.5202688968607357, 0.7005903380257743, 18.432919468198502, 48.73895195552281, 50.09121036529541, 45.61060197012765, 52.75365236827305, 52.444047587258474, 40.2592522757394, 3.063310069697244, 0.17896689527801105, 0.08298920254622187, 0.11759072941328798, 0.11348996231598513, 0.24398789341960633, 0.14117512745516642, 0.16890791218195642, 0.17990518707249845, 0.08879700090203967, 0.09170104935765266, 0.11680156604519912, 0.09090490386422191, 0.1454915465520961, 0.12426218071154185, 0.10862072716866221, 0.2690460559512888], [0.012100085133819707, 0.03856589485492025, 0.04205895581149629, 0.047868962798799784, 0.03239729228828635, 0.05544662814853447, 0.023731394171980873, 0.06411910975085837, 0.10649269207247666, 0.03431551078600543, 0.061750927540872774, 0.04841508510123406, 0.015631168648334484, 0.01328674958287073, 0.04764321080542036, 0.06330218072980642, 0.0312211570063872, 0.032769828369574885, 0.0839253230286496, 0.027081284239622097, 0.4171388479215758, 12.769418478012085, 39.656978947775706, 39.61281272343227, 23.09803032875061, 18.034789425986155, 30.580078125, 38.54449592317854, 41.327885219029014, 11.888782075473241, 0.21411750625286782, 0.1456893937928336, 2.130625145775931, 18.495956999914988, 20.545550516673497, 4.256362668105534, 1.53462039572852, 19.13298348018101, 42.76841354370117, 49.58414125442505, 49.37884977885655, 44.29531145095825, 42.44036476952689, 37.958422320229666, 35.12735448564802, 35.34544106892177, 36.72781644548689, 36.248845849718364, 37.58984122957502, 40.084425176892964, 42.26190028871809, 42.20942054476057, 43.41681248801095, 43.329268659864155, 45.066061224256245, 43.864874022347585, 45.35696145466396, 42.87067365646362, 38.00887666429792, 30.706246989113943, 32.920113291059224, 34.254181316920686, 34.439277853284565, 35.80469267708914, 40.81599405833653, 42.752060958317344, 43.76916258675711, 41.55490023749215, 36.31985991341727, 31.194333621433803, 32.48208148138863, 32.29889569963728, 32.007491724831716, 31.416738510131836, 31.390960693359375, 32.5006331716265, 37.22781923839024, 41.003762177058626, 41.06292608806065, 40.39604146139962, 44.304747104644775, 41.63181332179478, 44.26182460784912, 44.263916015625, 47.39002520697457, 44.19299922670637, 43.98873608452933, 40.67183630807059, 42.056890215192524, 38.04064730235508, 40.1828533581325, 45.466204507010325, 43.978779315948486, 45.15393509183611, 44.59639426640102, 43.04026528767177, 41.71619919368199, 44.81736087799072, 44.30589008331299, 42.06523152760097, 37.126055921827046, 32.52988508769444, 31.366096564701625, 31.436342852456228, 32.96652378354754, 31.95027330943516, 32.798808165958945, 34.8582820211138, 38.22043888909476, 40.306652886526926, 42.65119048527309, 42.63945150375366, 39.609522751399446, 33.07097257886614, 33.41153505870274, 32.84108100618635, 34.18111406053816, 33.95806646347046, 41.65148367200579, 46.88861540385655, 45.942882197243826, 44.529990332467214, 44.69302633830479, 41.75903136389596, 41.20958866391863, 38.61208799907139, 36.292108808244976, 35.34082746505737, 34.24569409234183, 32.510006291525706, 33.891304697309224, 33.61087540217808, 34.365727697099956, 36.817159857068745, 35.29063367843628, 37.17457866668701, 37.893800599234446, 42.979141984667095, 45.6858857018607, 46.44981581824166, 50.98145178386143, 45.873309884752544, 24.27541995048523, 7.4284893444606235, 2.480373578412192, 3.9165657929011752, 4.068230637482234, 4.591127744742802, 7.31386056968144, 1.816742554306984, 0.054040320217609406, 1.8038331270217896, 21.557765824454172, 40.02179758889334, 26.004524333136423, 33.590805530548096, 46.09324468885149, 48.06760311126709, 19.67387294769287, 0.48557133014713016, 0.039126425848475525, 0.06107971391507557, 0.024017191425498043, 0.027594699457819973, 0.03826040821149945, 0.023211615991645625, 0.05268182186409831, 0.05652990930580667, 0.013416184378521783, 0.026922819171366946, 0.007122309828576232, 0.0190652038436383, 0.039960426810596666, 0.04505618069587009, 0.05048818600230983, 0.09487874420093638, 0.018096891963588338, 0.04747871695352452, 0.04901997192895838, 0.033860929642937014, 0.014807235449552536, 0.039054809869932275, 0.047736404197556634, 0.03145488517891083, 0.025987616407551935, 0.04424581650112357, 0.0935918278992176, 0.03132250299677253, 0.014774818439036608, 0.03235679053302322, 0.04377490980550647, 0.043286133890173266, 0.03727967405159559, 0.009614790324121714, 0.03854369997446026, 0.05994017541940723, 0.5986523394073758, 17.135854073933192, 46.362841742379324, 45.86510753631592, 27.58521693093436, 24.555338553019933, 36.37579986027309, 42.18469885417393, 44.58897359030587, 12.519124388694763, 0.08164245302655868, 0.05961431576205151, 1.159950620361737, 19.852867228644236, 20.38554045132228, 4.254924825259617, 3.8425184062549045, 20.30832164628165, 45.79509053911482, 50.13462618419102, 50.37189326967512, 45.781023911067415, 44.58813285827637, 38.2059588432312, 36.90349122456142, 37.058387415749685, 36.27667685917446, 36.57403196607317, 39.19088683809553, 42.41181809561593, 44.090245791843955, 42.167654923030305, 44.48437540871756, 45.640229088919504, 46.281506129673545, 46.517505168914795, 47.267326968056814, 44.73249210630144, 38.379542214529856, 32.09106813158308, 34.7656694820949, 35.611623082842144, 35.36696311405727, 37.45813117708479, 43.16530506951468, 43.915877274104524, 45.13970170702253, 42.14562913349697, 38.705346720559255, 32.342068331582205, 33.458292961120605, 33.02038621902466, 33.547747543879915, 33.199208532060894, 33.37260430199759, 33.51805789130074, 39.650159290858674, 42.57571915217808, 43.65422201156616, 44.142187050410676, 45.38543864658901, 42.80020155225481, 46.03944478716169, 46.03314971923828, 49.60123034885952, 45.441309111458914, 44.99241031919207, 42.2534304346357, 44.979021140507285, 39.41554989133562, 41.46366344179426, 46.43291432516915, 44.403189182281494, 45.06093692779541, 46.321030957358225, 44.95792293548584, 42.834240777151926, 45.58928142275129, 45.062107699257986, 43.42917333330427, 38.55942760195051, 33.44134283065796, 33.05365071977888, 32.908356939043315, 34.35346760068621, 33.09625359943935, 33.860305309295654, 36.50548103877476, 39.772141865321565, 42.058408396584646, 45.41894286019461, 44.409234115055625, 41.354427337646484, 35.875585147312705, 34.15027100699288, 33.85869680132185, 35.26217385700771, 35.015787260872976, 42.53864009039742, 47.6118985584804, 47.68293694087437, 46.5103554725647, 45.57432542528425, 42.886067390441895, 42.96294920785086, 39.79883337020874, 37.037268366132466, 36.36746202196394, 36.16533892495291, 35.52586841583252, 35.7015814099993, 35.969587326049805, 36.55672747748238, 36.937940393175396, 36.38895974840437, 38.76644223076956, 40.000077520098, 45.543767247881206, 47.74031516483852, 48.30528014046805, 52.816332067762104, 47.64889076777867, 27.17243140084403, 7.3486597537994385, 3.0384754708835056, 7.595004660742624, 6.00474613053458, 6.698720914976938, 6.849082538059779, 1.2957582644053867, 0.1695192450923579, 1.6876158203397478, 22.571688652038574, 44.51833125523159, 34.429939474378315, 41.59583902359009, 50.70942980902535, 51.96477474485125, 25.752025059291295, 0.7798100071293967, 0.0445705633610487, 0.054628728822405846, 0.025903503510302732, 0.02867312230435865, 0.0201501185739679, 0.025396529285769378, 0.03307567124388047, 0.014162399024436516, 0.010011148921746229, 0.03169681005445974, 0.05574832856655121, 0.030459538767380372, 0.05470975947433284, 0.03933025098272732, 0.03758391219058207, 0.0023148075852077454, 0.07331729653690543, 0.14351088926196098, 0.13243775415633405, 0.11675797695560114, 0.0832813661545515, 0.15420443830745562, 0.15438465720840863, 0.13947120388703688, 0.1187593974173069, 0.1182010852332626, 0.1499717640025275, 0.17047281749546528, 0.09027670257325683, 0.09110478671001536, 0.14299727896494524, 0.12751832098833152, 0.12446838750370912, 0.12232440683458533, 0.17921217211655208, 0.2087304810328143, 0.6812655521290643, 19.110480001994542, 53.398250647953574, 51.76180049351284, 34.21407284055437, 27.920979942594254, 40.11735616411482, 47.0362993649074, 48.73806606020246, 15.86710432597569, 0.4577962862593787, 0.930444455572537, 4.6168643065861295, 22.506271362304688, 23.240379810333252, 8.496570774487086, 3.114375203847885, 22.204099416732788, 45.85517161233084, 51.39593267440796, 52.057828494480674, 49.141794613429475, 47.07393428257534, 40.9411415372576, 38.641829763139995, 39.35696268081665, 39.75806828907558, 40.346601554325645, 41.11572544915335, 45.20192977360317, 46.172944000789094, 44.747507163456504, 47.76129872458321, 47.939245564596995, 47.6006737436567, 47.9867399760655, 50.032637051173616, 46.862663882119314, 41.148013728005544, 33.24422591073172, 35.44136789866856, 37.96873344693865, 37.365636757441926, 39.47037812641689, 45.44902508599417, 45.943010738917756, 46.95749984468733, 44.5516027041844, 41.021959509168354, 34.021409715924946, 35.517023359026226, 35.74358327048165, 35.367849009377615, 35.045094762529644, 35.849876812526155, 35.73978607995169, 39.89572599955967, 44.04776797975813, 46.74760866165161, 45.076625960213796, 48.38372530255999, 44.65080908366612, 47.686636856624055, 48.294027532849995, 50.8863969530378, 48.50428697041103, 46.16151768820626, 42.58955996377127, 44.22897699901036, 42.48783833639962, 42.75289821624756, 46.479835510253906, 45.323373862675254, 47.93430886949812, 49.71031706673758, 48.72532306398664, 44.29020799909319, 46.23895883560181, 47.411595889500205, 46.19134977885655, 40.931664194379536, 35.385632923671174, 34.633229868752615, 34.60296698978969, 37.437217099326, 36.00873000281197, 36.01987143925258, 38.84003407614571, 41.731349740709575, 42.90121446337019, 45.963709422520225, 46.239188126155305, 42.40724965504238, 36.46319777624947, 37.02638748713902, 35.953404971531455, 37.31351137161255, 36.90151793616158, 45.37090996333531, 50.8882486479623, 49.8160617010934, 47.053781032562256, 48.3001697404044, 45.61594860894339, 43.60726955958775, 42.67948007583618, 40.43127230235508, 39.16535915647234, 39.018401282174246, 36.811163561684744, 37.59147753034319, 36.80001517704555, 38.015574727739605, 38.66946274893624, 39.2833708354405, 41.14919144766671, 42.820306164877756, 48.208213806152344, 50.52800192151751, 51.10597045081002, 56.06388882228306, 47.41340242113386, 29.62643439429147, 10.228924308504377, 5.405430998120989, 10.48671897820064, 12.498035737446376, 8.96676926953452, 14.790192604064941, 4.850285998412541, 0.2985307638134275, 2.461430617741176, 26.197329895836965, 51.760261467524934, 38.11890486308506, 45.593203680855886, 57.49560335704258, 61.32824012211391, 31.724043437412806, 1.2722963690757751, 0.222542102049504, 0.14959634414740972, 0.10528722032904625, 0.08714040515146085, 0.11339366462613855, 0.12964403549475328, 0.10334831329860858, 0.19308837609631674, 0.04933231856141772, 0.14674934691616467, 0.060647107128586085, 0.16675269497292383, 0.16100854320185526, 0.12233177572488785, 0.12743446763072694, 0.2178342089589153], [0.03318204857142908, 0.013613841629454067, 0.03917785541021398, 0.030059664510190487, 0.047856040099369626, 0.038008753143783124, 0.0639700423926115, 0.019407161744311452, 0.037658160884997675, 0.024970582320487926, 0.04295866610482335, 0.024217549245804548, 0.036280059654797824, 0.020540405131344284, 0.012500201967278761, 0.072551508700209, 0.0650435865723661, 0.0454958578172539, 0.07257170868771416, 0.03702632603900773, 0.052993089625877995, 4.910376191139221, 33.215203285217285, 39.33938026428223, 33.43254293714251, 21.47705728667123, 22.95531780379159, 32.187286785670686, 43.75105210712978, 22.02553939819336, 0.8996865717428071, 0.08468859350042683, 6.845004379749298, 26.537194081715175, 22.927306141172135, 7.637581484658377, 3.139600855963571, 13.52724460193089, 40.38988535744803, 52.24914366858346, 45.60147551127842, 47.3817811693464, 44.20666285923549, 40.9009427343096, 39.056279386792866, 39.44052519117083, 38.9337374823434, 40.8408408164978, 43.233946323394775, 45.06817347662789, 43.80568926674979, 45.49790218898228, 46.500732217516216, 44.641595772334504, 44.422869954790386, 44.00510604040963, 43.185941219329834, 44.535385608673096, 37.4734901700701, 32.101813520704, 32.67813532693045, 34.12277351106916, 33.45178597314017, 36.173933846609934, 40.2472596849714, 43.493301732199534, 45.78201750346592, 44.1320253099714, 37.58042294638497, 32.0961194719587, 31.34320225034441, 30.365528174809047, 30.729047502790177, 33.568817956107004, 31.89968694959368, 31.04558311189924, 35.97022308622088, 35.79309613364083, 38.273509229932515, 38.75931337901524, 41.03215946469988, 40.57089287894112, 44.1464775630406, 42.19950546537127, 44.363376004355295, 43.9764586176191, 44.4297764641898, 42.64057016372681, 43.95305708476475, 39.859164578574045, 39.33562476294381, 43.44417101996285, 41.016154289245605, 46.72424534388951, 44.306459835597444, 46.118619510105674, 42.5919223512922, 44.31223031452724, 42.987882818494526, 42.17761516571045, 35.59707702909197, 32.8264342035566, 30.94495235170637, 32.81714446204049, 30.396444184439524, 31.655864238739014, 31.934101377214702, 36.142951829092844, 39.06290449414934, 43.33717223576137, 41.54319599696568, 41.04287706102644, 35.66102824892317, 33.76443059103829, 33.35556384495327, 32.49637392589024, 32.44547142301287, 35.521508421216694, 45.64159093584333, 46.11984586715698, 46.15761627469744, 46.176855836595806, 43.485551016671316, 45.45580652781895, 44.637180192129954, 42.088608741760254, 44.57516057150704, 42.970369883946006, 41.09719807761056, 37.906474113464355, 36.211725098746165, 33.708045959472656, 36.74210541588919, 33.64665167672293, 36.828478472573416, 37.27161373410906, 39.887162344796316, 43.31192248208182, 45.18567098890032, 47.14081416811262, 51.90661137444632, 41.426827566964285, 25.755474839891704, 4.985185274056025, 2.6167254618235996, 3.9899179254259383, 4.259084624903543, 2.5064705780574252, 3.0080349785940985, 1.4699568769761493, 0.15834625677338668, 0.8891673247729028, 18.416492189679825, 33.47949538912092, 30.08439016342163, 25.895243065697805, 48.55680840356009, 44.27826751981463, 12.690248966217041, 0.21585507158722195, 0.08251186673130308, 0.03867702192759939, 0.023518848166401898, 0.060187067171292644, 0.0918514398591859, 0.08202976081520319, 0.05467614824218409, 0.03187894242416535, 0.019534571961100613, 0.026546939608774016, 0.05928084972713675, 0.043205160913722854, 0.02439273172058165, 0.044071667095912356, 0.04282923894269126, 0.027749810866745453, 0.010127061362644392, 0.018179637612774968, 0.07252908311784267, 0.03651161312258669, 0.03699985978060535, 0.017996943755341426, 0.009931817151872175, 0.03205555830416935, 0.04991539727364268, 0.0420185897632369, 0.057607629868601046, 0.05278849096170493, 0.04579157355640616, 0.014288461501044887, 0.008166579463120018, 0.07512713942144598, 0.031612651356096776, 0.026483001253966774, 0.026969317479857376, 0.0461674242812608, 0.14093964866229466, 7.560215898922511, 40.38732842036656, 45.74130800792149, 37.72932979038784, 22.839578185762676, 28.461991003581456, 37.51361949103219, 48.107009819575715, 22.51112641607012, 0.791744732431003, 0.15860891767910548, 5.464521518775395, 28.067816223417008, 22.202675036021642, 4.3653295295579095, 4.157693036964961, 15.112856524331228, 41.45120184762137, 53.17619316918509, 51.170873573848176, 50.13731861114502, 46.963860920497346, 41.90200444630214, 40.01376894542149, 38.51935734067644, 40.634541852133616, 41.665251527513774, 44.65783371244158, 46.4986686025347, 44.556077344076975, 47.37674025126866, 47.55425977706909, 47.39351667676653, 46.53843661717006, 45.06664834703718, 45.598793506622314, 47.825913497379844, 40.75241804122925, 32.43265547071184, 34.936414514269146, 35.38414600917271, 35.33146824155535, 37.576062951769146, 42.99970517839704, 45.66161911828177, 47.33991827283587, 45.3258821623666, 38.84627703257969, 34.54296929495675, 32.21096624646868, 31.29733371734619, 33.028091771262034, 34.84771033695766, 33.62716545377459, 32.92948988505772, 36.863104820251465, 38.345833029065815, 40.77992595945086, 39.91500377655029, 43.481048583984375, 42.30453790937151, 44.58570793696812, 43.59258106776646, 47.23866217476981, 44.77557093756539, 44.60009070805141, 43.81608029774257, 43.997393539973665, 41.214924880436485, 40.57175098146711, 44.373468262808665, 42.623262201036724, 46.613907950265066, 45.43398571014404, 46.54575307028634, 45.393488134656636, 44.73450708389282, 45.88151223318917, 44.294755595070974, 38.68195561000279, 33.335504395621165, 33.147920404161724, 33.05044412612915, 33.47909934180123, 33.45573602403913, 33.367275033678325, 38.6932499068124, 42.3032351221357, 43.819898332868306, 44.929174763815745, 42.35309192112514, 36.28893000738961, 35.14699704306466, 35.475691999707905, 34.568806171417236, 34.3258033479963, 37.92104796000889, 47.20977503912789, 47.868141174316406, 46.901733602796284, 48.26227079119001, 45.55654845918928, 47.33856337411063, 45.897465297154014, 43.44724212374006, 46.17822463171822, 43.95842456817627, 42.74912534441267, 38.267565046037944, 38.19637380327497, 35.13179438454764, 38.23234462738037, 35.822174344744, 38.90962723323277, 38.27219254629952, 42.037244183676584, 45.083612373897004, 47.32716832842146, 48.36776876449585, 52.75335706983294, 43.43134464536394, 27.048560653414043, 6.0091999258313855, 3.099672164235796, 5.1505723765918185, 6.550957918167114, 4.171960728509085, 5.659216557230268, 2.821926827941622, 0.04287457186728716, 1.2738233442817415, 22.835992915289744, 39.794129439762656, 31.145022256033762, 29.416866302490234, 52.23972538539341, 50.38095372063773, 17.500700507845195, 0.4284005750502859, 0.049495855678937266, 0.062253749131092, 0.02336169945608292, 0.013446053490042686, 0.03449024712400777, 0.04494776437059045, 0.033604148243154795, 0.015133629453235438, 0.04489894377599869, 0.0425005871137338, 0.03812328985493098, 0.05118634764637266, 0.060452645777591636, 0.039263625629246235, 0.025029029630656754, 0.035955920083714385, 0.10326166437672717, 0.059187578303473334, 0.21643654895680292, 0.11278130712785892, 0.05874520061271531, 0.10044938778238637, 0.14772094120936735, 0.07204949456666197, 0.119900964732681, 0.22012777945825032, 0.15144438855350018, 0.15193389728665352, 0.12338256862546716, 0.23629113499607357, 0.08027730163718973, 0.1391974285777126, 0.1573135129043034, 0.14979567059448787, 0.21931256034544536, 0.0807890866750053, 0.3013995827308723, 8.499098181724548, 44.760545458112446, 52.544146810259136, 45.3461674281529, 32.0692994253976, 33.78906542914254, 41.09245245797293, 53.1058600289481, 26.806990895952495, 1.4357407987117767, 0.4632028532879693, 11.068777390888759, 32.44170549937657, 27.9096074785505, 12.167850392205374, 5.618867933750153, 17.99444992201669, 41.48919459751674, 54.3070889200483, 51.52947357722691, 51.482469013759065, 49.33735166277204, 44.866470745631624, 43.97948455810547, 42.165167467934744, 43.26108251299177, 43.5717260496957, 48.26360831941877, 48.882189069475444, 47.08031620298113, 49.67281763894217, 50.509040287562776, 48.34366546358381, 47.946353571755544, 48.152148791721885, 46.53497641427176, 48.822438035692485, 43.095635482243125, 35.37125015258789, 35.73449502672468, 37.772262709481375, 35.931188106536865, 40.54533045632498, 43.90324544906616, 46.11012186322893, 49.479932171957834, 48.0516847882952, 41.27061816624233, 36.35304798398699, 34.7153263092041, 32.779634611947195, 35.307076590401785, 36.97570037841797, 36.035477093287874, 34.718845571790425, 39.564039843423025, 40.658613886152, 42.49141665867397, 43.04392351422991, 45.01185832704817, 44.15567697797503, 46.54926538467407, 45.09285347802298, 48.19034998757498, 47.311944825308665, 46.16469996316092, 45.6164037159511, 43.83753286089216, 43.90219627107893, 42.102508613041465, 44.553607259477886, 43.680798871176584, 49.565520082201274, 47.99220820835659, 47.690409728458945, 46.90194204875401, 46.60070289884295, 47.37492677143642, 45.28138589859009, 40.344579628535676, 34.937151023319785, 34.88274662835257, 35.169884409223286, 34.59531702314104, 35.1509644644601, 34.89905752454485, 39.93921824863979, 43.61411006110055, 46.63702460697719, 46.775557790483745, 44.99172592163086, 39.09605434962681, 37.914190087999614, 36.31354400089809, 36.251420157296316, 35.63904414858137, 39.9650342805045, 49.98967286518642, 49.59589760644095, 46.52337987082345, 50.02555683680943, 47.191994598933626, 48.470727171216694, 48.62237855366298, 45.369965008326936, 49.248769078935894, 45.81767218453543, 45.362797941480366, 41.4072927066258, 40.540112359183176, 37.84566000529698, 40.9669679914202, 38.37411914552961, 41.041803564344136, 40.842977387564524, 45.78524841581072, 46.88897671018328, 50.685448101588655, 51.65925897870745, 54.470725945064, 43.930336475372314, 30.612571375710623, 7.469119804246085, 6.6786549517086575, 10.083311779158455, 12.047665664127894, 9.19960514136723, 7.443050163132804, 4.0221097980226785, 0.3198325021990708, 1.4145288169384003, 24.77075355393546, 44.88496337618147, 40.92513288770403, 38.0727653503418, 57.33020843778338, 55.5209253174918, 21.548307589122228, 0.8182520014899117, 0.12891184192683014, 0.1410014767731939, 0.1306068224034139, 0.19736845285764762, 0.27182669245770996, 0.22495265198605402, 0.15640735652829918, 0.11330428799348218, 0.06861255863415343, 0.1359254920056888, 0.1774468139878341, 0.201876286683338, 0.12294481854353632, 0.11371156506772552, 0.19640177115797997, 0.13497860995786531], [0.03674652533871787, 0.020253634180075357, 0.06911865076316254, 0.017620802956766317, 0.06474370802087442, 0.08601343990968806, 0.02671327398690794, 0.0484618565200695, 0.030125170280890803, 0.03405119764751621, 0.036385632918349335, 0.028269090323842, 0.03151759199265923, 0.028045455359720757, 0.04535039687263114, 0.05726315121033362, 0.03923982601346714, 0.03461075494331973, 0.09834255012018339, 0.04977254868884172, 0.01640454420287694, 1.0870173339332854, 20.116940464292252, 40.61519806725638, 40.108625752585276, 26.22007656097412, 27.51960161754063, 36.44963141850063, 43.31044946398054, 30.05692046029227, 3.1141910765852248, 0.14015154380883488, 8.472049713134766, 32.39367607661656, 34.782557078770225, 16.29087495803833, 1.0741102950913566, 9.82249551159995, 34.37972484316145, 44.574298994881765, 50.32520832334246, 46.2027621950422, 43.1790520804269, 43.83470841816494, 41.33808517456055, 44.15486403873989, 44.00164583751133, 43.453641414642334, 44.59268045425415, 46.97482517787388, 47.01105655942644, 46.51902682440621, 44.65062495640346, 43.7068407194955, 46.282322543007986, 45.79621614728655, 41.54519707815987, 42.18276030676705, 34.303565638405935, 33.14750003814697, 33.05535650253296, 33.24590390069144, 33.0883743422372, 35.843619959695, 41.53381245476859, 43.193563393184114, 44.9039944921221, 43.32690627234322, 38.47645568847656, 32.07861001150948, 31.960924897875103, 31.261613028390066, 31.935966968536377, 33.23259115219116, 33.66607883998326, 30.371896198817662, 34.695690699986045, 38.09034776687622, 40.53938627243042, 41.93349020821707, 43.5797164780753, 42.75103609902518, 44.87275539125715, 42.42704507282802, 45.568388189588276, 44.90748248781477, 44.72002356392996, 44.34108965737479, 47.002114227839876, 38.11937734058925, 37.5133033479963, 41.28298248563494, 42.43954140799386, 44.60508646283831, 43.14564861570086, 43.129577432359966, 43.35064479282924, 42.937028953007285, 44.028660433632986, 40.3799216406686, 35.88601091929844, 33.471411160060335, 31.62845012119838, 32.04038102286202, 31.867370877947124, 32.64258139474051, 33.03335503169468, 36.88395983832223, 40.14114679609026, 42.231196199144634, 37.96282400403704, 36.25811127253941, 32.77932889120919, 33.25734410967146, 33.43095874786377, 33.0447153363909, 32.56531742640904, 35.829768725803916, 45.42181246621268, 44.27372339793614, 43.31336770738874, 45.33355297361101, 44.78411027363369, 47.1418251310076, 45.18475035258702, 45.48875141143799, 46.33479881286621, 45.068152632032124, 44.088119643075125, 45.42008236476353, 40.50918592725481, 38.80133955819266, 35.56897851399013, 35.94531379427229, 35.74748468399048, 38.44473021371024, 42.10351957593645, 46.02594791139875, 46.17803355625698, 48.56871066774641, 47.329259736197336, 40.400394507816856, 23.656999008996145, 4.329650964055743, 2.0678027910845618, 5.642528287002018, 4.060188966138022, 3.8347433720316206, 2.8726282673222676, 1.25844307243824, 0.06264183723500796, 1.056927508541516, 21.066050495420182, 38.40695285797119, 33.73971932274954, 39.29905639375959, 49.7810948916844, 41.67698008673531, 9.689212560653687, 0.09816520142235927, 0.05131596140563488, 0.009627697756513953, 0.011366640516955937, 0.024187371400850158, 0.017625695194250772, 0.039170408488384316, 0.10763527719037873, 0.03526735292481525, 0.012571229316693331, 0.1189294382929802, 0.012764678802341223, 0.0051500909695667875, 0.03125286494780864, 0.023881304609988416, 0.08181968637342964, 0.0539899695265506, 0.025517551095357964, 0.02505557392058628, 0.046149154725883684, 0.04095566126384905, 0.09344276054097073, 0.04388369932504637, 0.010294651878731591, 0.07952183431812695, 0.05835205063756023, 0.01604527687387807, 0.040565320423671176, 0.002586616839315476, 0.011306457005308142, 0.04503494933513658, 0.016191199222313504, 0.03308131665523563, 0.009514842115874802, 0.02436688632172133, 0.02651081101170608, 0.03703780345884817, 0.015652569642822658, 2.1771611401012967, 25.30178005354745, 47.27239915302822, 44.86214896610805, 29.3583242552621, 28.365702867507935, 39.619865145002095, 49.19374629429409, 31.727448054722377, 3.02043925012861, 0.11265090626797505, 10.647409098488943, 35.941151823316304, 34.20786115101406, 12.967473404748098, 2.4861894377640317, 12.035916260310582, 36.29137577329363, 48.9793735231672, 50.049503803253174, 49.54426901681082, 44.37952709197998, 47.08317886080061, 42.42730910437447, 45.71528353009905, 43.761731488364084, 46.63913685934884, 45.68016038622175, 48.09650761740548, 46.91203430720738, 47.63637706211635, 45.55605513708932, 44.26041064943586, 48.22025850840977, 48.47950274603707, 43.828058992113384, 44.27974401201521, 36.87626470838274, 34.00663437162127, 34.894242422921316, 34.96890776497977, 34.64570535932268, 38.069478852408274, 42.75936351503645, 45.28708342143467, 47.208374977111816, 46.32091978618077, 39.46077919006348, 32.93585096086775, 33.20754289627075, 34.040058680943076, 33.726010526929585, 35.61426339830671, 35.505471978868755, 31.699825491224015, 35.640531063079834, 39.972767625536235, 41.12079416002546, 43.80867004394531, 43.614975111825125, 43.53028351919991, 44.85253265925816, 43.8169001851763, 47.591126918792725, 46.68567936761038, 44.99688148498535, 44.78705630983625, 44.627001081194194, 39.840908186776296, 39.32023797716413, 42.31170497621809, 43.28506769452776, 45.35897643225533, 44.21732834407261, 45.00668886729649, 45.58058227811541, 45.26781606674194, 45.06852436065674, 42.387249265398296, 37.77316944939749, 35.44352184023176, 33.361066818237305, 34.01288080215454, 33.617705481392996, 33.520854541233604, 35.12336621965681, 38.833638259342735, 41.043860231127056, 43.667371477399556, 40.34796340124947, 37.43567112513951, 34.203219754355295, 34.96869237082345, 34.79782574517386, 34.583418233054026, 34.07886784417288, 37.239589486803325, 47.051720891680034, 46.44352075031826, 43.31327043260847, 45.241603987557546, 47.42482525961739, 48.48319571358817, 47.68305853434971, 47.910698890686035, 47.77009514399937, 45.56346886498587, 44.9404308455331, 46.332068170819966, 43.102350916181294, 39.26225873402187, 37.175919669015066, 37.54340294429234, 37.980218819209504, 39.4413138117109, 43.586876596723286, 46.54348448344639, 47.729719161987305, 49.65116010393415, 50.75893224988665, 41.2320556640625, 26.645417485918315, 5.337678245135716, 2.420503556728363, 5.667439316000257, 7.921157445226397, 6.154503260340009, 3.5628720862524847, 2.0864263517515997, 0.09147720744035073, 1.2482323689120156, 21.005934681211198, 41.016223771231516, 35.321150166647776, 39.22914014543806, 53.597615310123985, 49.07218061174665, 12.349844557898384, 0.06271329375782184, 0.06896453510437693, 0.07312200058783803, 0.030491772573441267, 0.05840621130274875, 0.009357019111381044, 0.10787815880030394, 0.12254073736923081, 0.022339935979938934, 0.026882568474060724, 0.03545962939304965, 0.04646291271118181, 0.0620952094239848, 0.02742621921268957, 0.04316748186413731, 0.024793974922171662, 0.03953233228198119, 0.08433479177100317, 0.10588574928364583, 0.15648462809622288, 0.131667576198067, 0.18822290003299713, 0.2309989146888256, 0.1612198661480631, 0.0913226982312543, 0.16602749031569275, 0.0949463127180934, 0.15793737157114915, 0.0861752772969859, 0.12997919108186448, 0.17057177504258497, 0.05949198268353939, 0.1694333968417985, 0.08764585267220225, 0.18840165329830988, 0.16364767801548752, 0.09904244542121887, 0.11456086699451719, 2.427579862730844, 28.022956916264125, 53.99365220751081, 51.47143874849592, 36.98734903335571, 36.70753812789917, 46.07954978942871, 53.1445962360927, 37.20421968187605, 4.1855418511799405, 0.5849634110927582, 12.450003709111895, 37.874977929251536, 39.67607954570225, 20.001419714518956, 3.0427375393254414, 12.32236008984702, 39.576028960091726, 49.53899533408028, 51.98104395185198, 51.08807536533901, 48.0065666607448, 48.68066699164254, 44.548427377428325, 47.5336548941476, 47.66481256484985, 48.43061522075108, 47.461435317993164, 50.35455404009138, 48.814729009355815, 49.697157178606304, 46.80538988113403, 45.95701135907854, 51.093807629176546, 50.62035042898995, 45.81675502232143, 45.19595084871565, 38.61144529070173, 36.46960054125105, 36.18614877973284, 37.49863222667149, 36.10131474903652, 39.777929714747835, 45.77451344898769, 47.609341621398926, 48.56339182172503, 47.5002236366272, 41.93040868214199, 35.15459142412458, 35.98171540669033, 34.42822674342564, 34.87517309188843, 37.30938066755022, 38.5952525138855, 33.735390595027376, 37.86889130728585, 42.66907514844622, 43.023141452244346, 45.57133769989014, 46.85772371292114, 45.39204290934971, 47.79025534221104, 44.785402638571604, 49.94464159011841, 49.248091629573274, 46.585951873234336, 45.28077793121338, 43.89525849478585, 42.00301388331822, 40.38313518251692, 42.36128384726388, 45.03109441484724, 46.33107805252075, 46.85312747955322, 46.85517372403826, 48.28208705357143, 45.83636631284441, 47.75758491243635, 43.93360907690865, 39.87091745649065, 37.02799252101353, 35.30433900015694, 35.98374775477818, 35.27415949957711, 34.92025300434658, 37.32666083744594, 41.88430043629238, 43.82177782058716, 46.62313515799386, 42.10154628753662, 38.94403123855591, 35.97867556980678, 35.44320569719587, 36.00807339804513, 37.078495502471924, 35.6048902784075, 38.60159969329834, 48.99797732489449, 48.53448731558663, 45.548749106270925, 46.819265433720176, 48.83019569941929, 52.29033606392996, 50.09177316938128, 49.71976661682129, 50.81941979272025, 48.36022996902466, 47.861811365400044, 49.80110917772566, 44.952155930655344, 42.9487019266401, 38.84262922831944, 38.946136542728965, 39.10553169250488, 42.206321648189, 46.76592411313738, 50.246596404484336, 49.9608656338283, 50.725768498011995, 50.46716002055577, 43.09431879861014, 28.193267686026438, 6.584769589560373, 4.927652886935642, 13.175059522901263, 10.437629086630684, 10.796648587499346, 8.137518269675118, 3.3632416554859708, 0.4114589941288744, 1.6472530833312442, 27.58264262335641, 50.65923949650356, 43.361477034432546, 48.761234828404014, 59.30313900538853, 55.052088669368196, 15.478672231946673, 0.37129501359803335, 0.18801627254911832, 0.15181170670049532, 0.15140830406120845, 0.13820242482636655, 0.15165102960807936, 0.2153097465634346, 0.19910219125449657, 0.09623819589614868, 0.06315700816256659, 0.2880485648555415, 0.10025068558752537, 0.20161206514707633, 0.08949040940829686, 0.17001198365220002, 0.14569338357874326, 0.060566123974110396], [0.0692174726032785, 0.0429198844358325, 0.03177751500957778, 0.09748232377959148, 0.0333480114516403, 0.07185617993984904, 0.09364747455609695, 0.04083743332219975, 0.024032472034118006, 0.04923361885760512, 0.027838244335725904, 0.06026147532143763, 0.005792434202573661, 0.030563490332237313, 0.023964732186868787, 0.030108135659247637, 0.04712501361167856, 0.04314371956778424, 0.004207176655264837, 0.014558869580339109, 0.07552274569336857, 0.20219536099050725, 13.251252600124904, 34.71299171447754, 40.88191161836897, 25.9422094140734, 26.156733308519634, 28.655731098992483, 40.65487922940935, 34.78911617824009, 5.969965185437884, 0.2705983269427504, 13.427270446504865, 35.56157520839146, 27.04743504524231, 14.328776632036481, 2.352174971784864, 8.032297355788094, 24.677873509270803, 42.02678714479719, 49.35061229978289, 49.69399574824742, 48.23046888623919, 46.1702480997358, 44.295186383383616, 42.91062579836164, 46.58780356815883, 48.2281551361084, 48.672131129673545, 44.23771088463919, 44.78399215425764, 43.5094667162214, 45.19300481251308, 45.33492176873343, 45.205997943878174, 43.76533760343279, 41.614703382764546, 38.921869959150044, 34.0422716821943, 31.911033357892716, 34.8496766771589, 32.82482916968209, 34.863302094595774, 37.690645694732666, 41.638122286115376, 44.455199922834126, 45.481143133980886, 45.01530115944998, 38.068467889513286, 31.738693714141846, 32.574138164520264, 31.074445928846085, 31.75624486378261, 31.848780972617014, 32.41407251358032, 32.07743576594761, 34.800497327532085, 40.912101541246685, 45.81094980239868, 43.07895285742623, 45.605731282915386, 45.33503988810948, 44.38783713749477, 46.10939230237688, 44.51960972377232, 41.9821241242545, 45.68725797108242, 43.87220089776175, 41.30650561196463, 40.21738590512957, 39.413812841687886, 41.21335458755493, 41.7224942616054, 45.064490931374685, 43.83261006219046, 43.209259373801096, 43.567435537065776, 42.28730637686593, 40.72823831013271, 38.000587463378906, 35.00165115083967, 31.31555884225028, 32.814545835767476, 30.09269326073783, 33.192993368421284, 33.46179485321045, 34.8722687448774, 38.346569538116455, 40.1855388368879, 41.82759618759155, 40.096233640398296, 37.24397380011422, 33.582735197884695, 33.38145978110177, 32.0728360584804, 33.10450111116682, 32.97567803519112, 33.272244521549766, 40.53987264633179, 46.217700822012766, 43.65622309276036, 44.608598777226035, 43.16788632529122, 43.210979052952354, 44.08622278485979, 46.02817480904715, 45.986624581473215, 47.34701933179583, 45.000227042606895, 44.92446041107178, 44.878098555973594, 44.81096158708845, 41.10137047086443, 36.02574961526053, 34.70187112263271, 35.89152084078108, 42.60034704208374, 45.0626357623509, 46.451372214726035, 48.96953139986311, 47.54061351503645, 36.822339739118306, 20.806404999324254, 3.5017863469464436, 1.0129177272319794, 2.393150670187814, 7.82373935835702, 3.4595237118857245, 2.1299967680658614, 0.6551641012941087, 0.12087768875062466, 1.8982602315289634, 25.430370364870342, 33.891561780657085, 28.665639230183192, 34.44182436806815, 47.62769181387765, 34.56110061917986, 5.361735948494502, 0.053853675590029786, 0.0414576211145946, 0.009400253666431775, 0.016089089880032197, 0.05161192820274404, 0.024332650837355425, 0.027188750615875636, 0.015648282997842346, 0.07912603127104895, 0.01697007260684456, 0.02432943458136703, 0.04366766734580908, 0.001139625220925414, 0.03213019037087049, 0.060358207273696146, 0.01837008542913411, 0.05634782104087727, 0.04188937973231077, 0.024156479397788644, 0.025597971065768173, 0.03552529461947935, 0.0366740170866251, 0.06574574139501367, 0.1049391318644796, 0.05899196344294718, 0.014562102799702967, 0.08197470448379006, 0.005976153496054134, 0.025125715781801512, 0.03587552386202982, 0.03596199297213128, 0.03414030625884022, 0.028687530995479653, 0.05079681087019188, 0.022731267481244037, 0.01189398521091789, 0.02060242832106139, 0.039369025866367986, 0.30400428867765833, 16.37917787688119, 42.21898474012102, 47.079590116228374, 30.0547456741333, 26.482570818492345, 35.55931009565081, 45.04816266468593, 38.18638924189976, 6.6399291668619425, 0.17594964003988675, 13.989644612584796, 35.57847670146397, 31.186631543295725, 14.758276053837367, 3.249553058828626, 8.826052614620753, 28.195168018341064, 44.16487986700875, 49.06863008226667, 53.2183062008449, 49.286390100206646, 48.602614402770996, 45.01397752761841, 44.74303599766323, 49.09295572553362, 50.34045614515032, 48.828670569828574, 46.66081871305193, 46.44512925829206, 44.43237509046282, 45.73839323861258, 46.1897725377764, 46.88187217712402, 46.389286586216514, 42.15555116108486, 41.36750732149397, 35.87539407185146, 33.17687702178955, 36.42847762789045, 35.09589304242815, 36.30488307135445, 39.440935134887695, 43.161073616572786, 45.227547781808035, 47.329033919743125, 47.42311600276402, 40.085960728781565, 33.38756029946463, 33.715247767312185, 33.50409548623221, 34.50864519391741, 33.64366395132882, 34.07268394742693, 34.48037297385079, 36.14400100708008, 43.04634496143886, 45.37213979448591, 44.90241725104195, 46.44493123463222, 47.05034167425973, 46.60590362548828, 47.1854042325701, 46.61033657618931, 43.83721671785627, 46.867492880140034, 46.612132685525076, 42.99001244136265, 40.237191745213096, 40.07374232155936, 42.04463011877877, 45.720741340092246, 47.408938203539165, 45.670293944222585, 45.24861124583653, 45.220200061798096, 43.44765206745693, 42.22534234183175, 39.956397669655935, 36.143233231135774, 32.677805287497385, 34.93702595574515, 32.869297640664236, 34.18295880726406, 34.400628498622346, 35.77971042905535, 38.82840973990304, 42.15055193219866, 43.50764281409127, 42.49325793130057, 37.93492351259504, 35.57434947150094, 34.29615191050938, 33.76465293339321, 34.674759251730784, 33.87331928525652, 35.01834767205374, 43.945625986371724, 47.63607134137835, 46.435731819697786, 46.481916495731895, 45.70718887874058, 45.84050396510533, 46.107363428388325, 48.70584031513759, 47.746610232761924, 48.88108777999878, 47.96280690601894, 47.890090533665244, 47.02854170118059, 46.39561639513288, 40.85359076091221, 36.67125116075788, 36.28177336284092, 37.57934944970267, 43.374466691698345, 47.45972606113979, 48.498731885637554, 49.48150941303798, 47.553165435791016, 39.01786627088274, 23.35261753627232, 4.688636592456272, 1.5533181067023958, 4.943376226084573, 9.684146455356053, 5.168115709509168, 4.0138892105647495, 1.419927892940385, 0.13746710999735764, 2.071148565837315, 28.701514516557964, 40.92585897445679, 34.050821440560476, 39.3279504776001, 52.165588106427876, 40.643004758017405, 6.766012047018323, 0.05357462806361062, 0.042733307661754746, 0.0279062199738941, 0.027767250913062265, 0.049619484759335, 0.00715141134735729, 0.05220084910147956, 0.039260538294911385, 0.09647405466863088, 0.01324824950591262, 0.04509512182059033, 0.026458541762882044, 0.05231881919982178, 0.03085680745009865, 0.044655885746968646, 0.023569909622892737, 0.06049004662781954, 0.13527853600680828, 0.11407616228929587, 0.09656679683497973, 0.20172269349651678, 0.11873699219099113, 0.1779470435742821, 0.1718677497868027, 0.08619249851575919, 0.13269771449267864, 0.14911708129303797, 0.11335114762187004, 0.11438782699406147, 0.11443474090525083, 0.10715857919837747, 0.1848083489707538, 0.19563323525445803, 0.20559878407844476, 0.13081799607191766, 0.18117197124021395, 0.09838617992188249, 0.16375458799302578, 0.561829003904547, 18.500249249594553, 47.27944115230015, 54.265743664332796, 37.58099964686802, 35.7294089453561, 38.86798667907715, 50.86416619164603, 42.79895782470703, 8.11969440323966, 0.4452235751918384, 18.13434147834778, 43.012493337903706, 33.58943673542568, 16.941198553357804, 5.500120179993766, 11.58963085923876, 31.15063292639596, 44.70833321980068, 49.32194403239659, 55.23942599977766, 52.641088077000205, 50.32578502382551, 47.69819865907942, 46.36702455793108, 50.92072800227574, 53.61770255225045, 50.81512580599104, 46.051847321646555, 45.64441885266985, 45.6100287437439, 46.71322202682495, 48.23732328414917, 47.6080562046596, 48.21188940320696, 44.375973088400706, 44.0128949710301, 37.34501102992466, 34.842242104666575, 38.1463954108102, 37.677190508161274, 38.12690918786185, 42.168203830718994, 44.825646604810444, 48.06444862910679, 48.76144674846104, 50.13956635338919, 41.195820808410645, 36.00781284059797, 35.05923434666225, 35.37338324955532, 35.31993770599365, 34.70580727713448, 35.83036627088274, 36.21194396700178, 38.72959245954241, 45.31791605268206, 49.13367216927664, 46.90242147445679, 48.748933042798726, 48.63149459021432, 48.51712029320853, 48.20096336092268, 48.215203693934846, 45.811422279902864, 48.65838759286063, 47.48937749862671, 41.32309443610055, 42.495175634111675, 41.69102239608765, 43.17531047548567, 46.951368059430806, 49.56171246937343, 48.858273369925364, 47.37598637172154, 46.56073686054775, 45.17587750298636, 45.40126664297921, 41.88440465927124, 37.909201281411306, 34.35400261197771, 37.140879903520855, 33.616041387830464, 35.547696181706016, 36.12727321897234, 37.604755537850515, 41.55693258558001, 43.449663570949006, 46.07682262148176, 43.40545218331473, 39.128016063145225, 37.44726766858782, 35.82372726712908, 36.16373041697911, 36.07175711223057, 37.55790383475167, 36.3813271522522, 43.06271491731916, 49.68059614726475, 48.296014717647004, 47.01528453826904, 45.914078439985005, 47.77034527914864, 46.15998213631766, 49.417745794568745, 49.47043398448399, 52.275261947086875, 49.7077636037554, 49.59134306226458, 50.30929347446987, 49.49494028091431, 44.50778388977051, 38.6423647744315, 37.30108451843262, 38.751156193869456, 46.46417427062988, 50.400262764522004, 52.160964080265586, 51.693701199122835, 50.05538197926113, 40.957386425563264, 25.02374267578125, 5.440579763480595, 4.963781782558986, 8.264110973903112, 15.113850116729736, 9.32084252153124, 9.428324205534798, 3.35098221046584, 0.22291729120271547, 2.9957844359534125, 32.28452335085188, 45.32528114318848, 39.52984775815691, 44.21558434622628, 57.75026873179844, 45.4049665587289, 9.462075080190386, 0.22468395211866923, 0.10692280185009752, 0.1160096749663353, 0.08455039627317872, 0.13564835116267204, 0.10558868665248156, 0.13004946016839572, 0.09852760019046919, 0.1636536762650524, 0.08650999862168517, 0.11627864624772753, 0.1048151363751718, 0.13876028917729855, 0.10804176037865025, 0.21557157965643065, 0.09650112143052475, 0.1203525433582919], [0.062166224899036546, 0.01743087761237153, 0.023878755014655844, 0.0808318615225809, 0.057379961013793945, 0.07163205982318946, 0.021371732665491954, 0.026677308238244483, 0.08440525084733963, 0.035053366728659184, 0.021892282679410915, 0.06803720843579088, 0.027357383531385233, 0.1304453717810767, 0.16244948016745703, 0.05986366381070443, 0.050713731042508564, 0.046996970660984516, 0.02823014241377158, 0.12202207877167634, 0.032908001848097355, 0.07419056432055575, 5.147124333041055, 29.71896355492728, 43.31287438528878, 29.133226939610072, 18.808834382465907, 28.073767355510167, 39.27667972019741, 36.81060423169817, 9.238886782101222, 0.14362131405089582, 2.789142838546208, 25.850816283907207, 26.938412598201207, 8.339100275720869, 3.0947024651936124, 5.727777472564152, 26.314087424959453, 48.36669179371425, 47.310082708086284, 49.15446465356009, 46.61780588967459, 46.95806959697178, 48.02336393083845, 47.27011319569179, 45.61370086669922, 46.011457443237305, 44.97108629771641, 44.03775215148926, 44.14262131282261, 46.65873077937535, 44.2419353893825, 44.86043276105608, 42.97761338097708, 41.61506816319057, 39.61327477863857, 34.24557944706508, 32.34952374867031, 32.83428219386509, 33.717863764081685, 33.425827503204346, 33.04189089366368, 38.60541772842407, 42.302043506077354, 45.84696578979492, 46.85525015422276, 45.65157202311924, 40.753349099840435, 32.607086522238596, 34.45325068065098, 33.57818412780762, 31.63776765550886, 32.98495388031006, 32.345677920750205, 31.99834442138672, 35.50473199571882, 42.51617309025356, 44.374163082667756, 45.37684025083269, 44.98961366925921, 43.37092311041695, 46.14834042957851, 43.742898396083284, 40.03834819793701, 42.95420489992414, 45.07484027317592, 42.01612860815865, 42.163597175053184, 39.26271384102957, 37.711834226335796, 43.346451554979595, 43.17241655077253, 44.983113629477366, 41.496208803994314, 43.24148511886597, 40.68763303756714, 41.38078532900129, 38.84412656511579, 36.3485038621085, 33.544113636016846, 31.96264805112566, 32.63431651251656, 31.1061019216265, 31.04475280216762, 32.41802256447928, 32.876124245779856, 35.7290997505188, 40.584469658987864, 42.016225882938926, 41.70434556688581, 41.35725178037371, 38.83991248267037, 35.55936220714024, 31.686130591801234, 32.75439528056553, 32.26973411015102, 31.893551690237864, 35.98453984941755, 44.08288764953613, 45.03475611550467, 44.53012234824044, 44.86007840292794, 45.429792472294395, 44.26995052610125, 43.80224296024868, 44.08787298202515, 47.01127542768206, 46.7096471786499, 47.48754664829799, 44.78327301570347, 44.380138533455984, 44.210977690560476, 42.34034545081002, 36.0848058291844, 38.89587674822126, 41.37469175883702, 44.920093468257356, 44.891786507197786, 48.267607007707866, 43.62612002236502, 35.450258118765696, 16.379735469818115, 3.410618381840842, 1.3787918431418282, 5.4142404454095026, 8.485790644373212, 4.659746416977473, 3.513626511607851, 0.6477616099374635, 0.06061820832214185, 1.4877103929008757, 17.235070875712804, 30.34449597767421, 30.599196093423025, 33.69534812654768, 44.02850062506539, 25.253616877964564, 3.6089998739106313, 0.10429714274193559, 0.07800363256995167, 0.04759781341999769, 0.083577417768538, 0.005648486815126879, 0.04236993858856814, 0.03623584970565779, 0.01857532700523734, 0.036825109871902635, 0.05432240418823702, 0.008816588021415685, 0.029066869390330145, 0.020793447803173746, 0.04114408704585262, 0.033931364970547814, 0.026201823127589056, 0.10045425966382027, 0.028814271158937897, 0.03038550720417074, 0.07297576272061893, 0.050190071641866646, 0.05368345829525164, 0.03372959919007761, 0.029266528319567442, 0.06016372556665114, 0.0039041789631093188, 0.05966300743498972, 0.05295262858271599, 0.012135229855110603, 0.014785167794408543, 0.12182166666856833, 0.04518717188122017, 0.03836872614920139, 0.001780581910030118, 0.15064774772950582, 0.027601802023127675, 0.11068023701331445, 0.017808870811547552, 0.03205883902098451, 7.476885284696307, 36.39201348168509, 47.95974622453962, 33.49071672984532, 22.833899770464214, 31.186836515154155, 44.833630084991455, 40.608805724552695, 9.04351212297167, 0.09528870827385358, 4.353770332677024, 35.53697511128017, 30.27764388493129, 9.670369046075002, 1.6511404918772834, 6.05486261844635, 28.937193938664027, 47.56498432159424, 46.833724634987966, 49.82826621191842, 47.065217767442974, 49.73448290143694, 49.03619589124407, 49.27519655227661, 46.92474603652954, 47.37481212615967, 45.667900289808, 44.83192777633667, 44.69515596117292, 47.435522011348176, 46.67699759347098, 46.89077629361834, 44.62116459437779, 44.282863753182546, 41.85494082314627, 37.77932555334908, 34.07910755702427, 33.93300778525216, 35.77486406053816, 34.067927905491416, 35.69553995132446, 38.5346850667681, 43.596677030835835, 47.266041551317485, 47.58862556729998, 45.30971023014614, 41.3846242087228, 34.27905586787632, 34.52098519461495, 34.76258448192051, 34.164407117026194, 33.158606733594624, 33.79113599232265, 34.48045982633318, 37.02202749252319, 44.71661894662039, 45.546143531799316, 47.15362664631435, 46.35582058770316, 45.595663343157085, 47.49473803383963, 45.16312755857195, 43.34169551304409, 45.29123844419207, 45.721665450504844, 42.73889412198748, 41.82758229119437, 41.51936020169939, 39.26263393674578, 42.86338152204241, 44.56379679271153, 46.0980806350708, 43.923777375902446, 43.11304071971348, 42.50621632167271, 42.49661043712071, 41.17673758098057, 38.47083112171718, 36.31565625326974, 34.13397748129708, 33.685019629342214, 32.80835151672363, 32.832166467394146, 33.575943333762034, 34.20666953495571, 38.43207059587751, 43.67541401726859, 42.031814166477744, 42.50536864144461, 42.403216225760325, 41.01414278575352, 35.45020948137556, 34.132198742457796, 34.360103130340576, 35.06408071517944, 33.83968652997698, 38.74335336685181, 45.92662688664028, 45.746717180524556, 47.67246947969709, 46.5630784034729, 47.53529814311436, 45.489175251552034, 44.78198412486485, 45.633624826158794, 48.065445695604595, 47.37283536366054, 49.38530118124825, 47.76541205814907, 46.3982949256897, 46.62936074393136, 42.9989721434457, 38.028335094451904, 39.650461537497385, 43.38539273398263, 45.96581472669329, 47.25825262069702, 50.599207060677664, 47.00940983636038, 37.2316164289202, 19.174900225230626, 3.7397562861442566, 1.9305910680975233, 5.991520668779101, 8.478166733469282, 6.463441014289856, 4.8086875677108765, 0.8256071582436562, 0.048019170095877986, 1.9112181876386916, 20.90427906172616, 35.1919275692531, 36.672408035823274, 39.02838931764875, 51.66583544867379, 31.480116503579275, 4.900376864842006, 0.06012418733111449, 0.07077660358377866, 0.0650526721562658, 0.008486868347972631, 0.015089271922728844, 0.04040188169372933, 0.06637022431407656, 0.020912953086995652, 0.009917727372209941, 0.029845308512449265, 0.013611661835706659, 0.07448392215051822, 0.023972023045644164, 0.026030145286183273, 0.01788780479026692, 0.013562626654415258, 0.09297208115458488, 0.12079160979815892, 0.10817690419831447, 0.156655754627926, 0.21370011222149643, 0.14414202182420663, 0.14684018918446132, 0.1294664085975715, 0.142435221267598, 0.11926464816289288, 0.12207438025091376, 0.14824168969477924, 0.10583399741777352, 0.060507423909647126, 0.327277306999479, 0.1738857672150646, 0.16305686400404998, 0.12055796304983751, 0.21940181484179838, 0.25855134480765884, 0.24497271914567265, 0.09353094295199428, 0.13896762233759674, 7.467222946030753, 41.59984813417707, 55.78023903710501, 41.19869041442871, 30.56636585508074, 37.87351533344814, 49.60953344617571, 45.65943043572562, 11.958118149212428, 0.3993329219520092, 4.276248846735273, 34.58492946624756, 29.871931621006556, 12.143828732626778, 5.800218088286264, 8.661545327731542, 30.745750972202845, 49.47348771776472, 46.42631006240845, 52.43590777260916, 48.43472160611834, 51.5830511365618, 49.85684415272304, 49.49935933521816, 47.469571658543174, 47.66820675986153, 46.70373773574829, 45.17391463688442, 47.70783233642578, 49.683017594473704, 47.40858384541103, 48.08542176655361, 46.64574807030814, 44.83309159960066, 42.75114379610334, 37.87521416800362, 35.53945214407784, 36.31581606183733, 37.902183600834434, 35.687865665980745, 37.3232353755406, 41.25978592463902, 44.56600979396275, 50.30274827139718, 49.73461839130947, 49.10706751687186, 42.378303459712434, 36.0470666885376, 36.79895557676043, 36.00727782930647, 34.744519165584016, 35.24010637828282, 36.75791951588222, 36.70673908506121, 38.456024510519846, 47.44177539008004, 47.41492755072457, 48.81181076594761, 47.7430214881897, 46.680989333561485, 48.46145132609776, 47.27071074077061, 45.100524289267405, 45.727738176073345, 46.922449656895225, 43.530630929129465, 42.177302496773855, 43.04950291769845, 41.374184540339876, 43.03958783830915, 47.71515573774065, 48.591584137507844, 46.09190716062273, 45.170103549957275, 44.605642318725586, 44.19298185620989, 43.15196105412075, 40.12573569161551, 37.8774653843471, 35.42901052747454, 36.48422997338431, 33.894837856292725, 34.40161166872297, 35.57560362134661, 35.10506119046892, 39.229925291878835, 44.51407895769392, 45.057487147195, 45.8462918145316, 44.6306106703622, 43.021668434143066, 37.700025762830464, 34.92861863545009, 36.29218176433018, 37.08205298015049, 34.81581463132586, 40.17038481576102, 47.543559551239014, 49.184869970594136, 49.658115250723704, 48.153135435921804, 47.199720995766775, 45.68393325805664, 45.16158158438546, 45.289383275168284, 49.20678111485073, 49.91839129584176, 51.40646961757115, 48.63374580655779, 48.36163003104073, 48.0512227330889, 46.37098503112793, 40.50617388316563, 42.73138311931065, 45.11527531487601, 47.39324917112078, 48.55117341450283, 51.311359201158794, 47.441601685115266, 41.16857692173549, 20.770826748439244, 4.94721119744437, 4.345812473978315, 11.387087396212987, 17.65615255492074, 12.486481751714434, 7.323783465794154, 1.9104925351483482, 0.28277762340647833, 2.626403433935983, 25.331659044538224, 40.07324205126081, 39.716128962380544, 45.38119329724993, 56.771500314985005, 36.678223678043906, 6.706935857023511, 0.25226137946758953, 0.19550997258297034, 0.11924087229583945, 0.22211831621825695, 0.10713352768548898, 0.08933574413614613, 0.22121963729815824, 0.1865613849035331, 0.11801855931324617, 0.13226133505148546, 0.1283923283751522, 0.1202655415982008, 0.13330797531775065, 0.1308981581990208, 0.10089634558452026, 0.1160888464323112, 0.2869268650455134], [0.03275718726217747, 0.02737897281934108, 0.029846577372934138, 0.009707900595718195, 0.024848271294363906, 0.0361277047943856, 0.013469465492692376, 0.039218879637441466, 0.08963271855775799, 0.10603772755712271, 0.051732775289565325, 0.03188829602939742, 0.04295269838933434, 0.0066232664061577195, 0.0286657194873052, 0.0066191264943751904, 0.010673277811812503, 0.028549737496567622, 0.0180700779559889, 0.0559358926090811, 0.046945893937455754, 0.04975706451971616, 1.240488818713597, 18.559404475348337, 40.97117165156773, 33.52193151201521, 21.22759437561035, 24.958202055522374, 33.278959955487935, 39.05190202168056, 12.685557195118495, 0.20986378379166126, 0.12092921669994082, 0.5252422328506197, 5.811697815145765, 13.04282488141741, 2.753912648984364, 3.540802436215537, 30.59086172921317, 46.276611123766216, 48.917176723480225, 48.46820150102888, 48.46765259334019, 43.852860586983816, 46.13525349753243, 44.74622174671718, 47.590869835444856, 45.3988174029759, 46.706183501652305, 44.12137024743216, 46.17534807750157, 44.38968883241926, 43.24108559744698, 42.59151588167463, 41.325272696358816, 38.27739674704415, 34.929330825805664, 33.248999323163716, 32.799110412597656, 32.46332481929234, 33.16149371010916, 33.043485505240305, 34.1850015776498, 41.00303609030587, 43.75469296319144, 46.671421664101736, 45.54037652696882, 44.95867681503296, 39.868923323495046, 33.238469328199116, 33.169866289411274, 32.24620056152344, 31.894892692565918, 32.337010043007986, 32.38293763569423, 32.53759411403111, 31.618594101497106, 39.357317038944785, 44.25770432608468, 43.860774585178916, 44.96840081896101, 43.430875641959055, 42.63146802357265, 38.049996103559224, 42.44570098604475, 43.21752773012434, 43.854444776262554, 42.68450014931815, 41.76521178654262, 37.75440583910261, 37.538136209760395, 42.344580377851216, 43.95367200034005, 42.9951297896249, 43.1235568182809, 40.825217791966026, 40.20264530181885, 37.90519911902291, 36.557074887411936, 35.37932743344988, 33.532989570072715, 31.43811811719622, 31.413823740822927, 32.597824573516846, 31.60596922465733, 31.870709487370082, 32.0470860345023, 34.29627350398472, 37.6372765813555, 43.759330885750906, 43.47880778993879, 43.21168082101004, 41.83240781511579, 40.02924953188215, 35.23585755484444, 33.540365082877024, 32.27924619402204, 30.791612557002477, 31.712662288120814, 36.53051887239729, 41.44891936438424, 44.010720184871126, 45.00574043818882, 44.670375210898264, 45.248507022857666, 46.077347210475374, 44.55994054249355, 43.20083468300955, 43.74024765832083, 45.14029925210135, 47.59121029717581, 47.78572164263044, 46.27591282980782, 44.57426077978951, 42.591303961617605, 36.30787774494716, 39.66354499544416, 43.97856739589146, 45.16842903409685, 48.342355728149414, 41.045284611838206, 35.64047200339181, 15.474513735089984, 2.208313605615071, 0.37981524212019785, 2.74107563495636, 7.634236795561654, 4.7844535538128445, 2.1347445590155463, 0.5695880247013909, 0.051414226847035546, 3.1061954370566776, 25.122648545673915, 32.411338397434776, 27.865013939993723, 30.925132615225657, 40.65959358215332, 19.89721063205174, 1.0297540809426988, 0.010245695577136107, 0.02757308811747602, 0.04634958718504224, 0.01385074364952743, 0.01280940613443298, 0.01617700087704829, 0.02658869495748409, 0.037014088659946404, 0.09310205453740698, 0.008214747815925096, 0.021592461803395833, 0.04138550641281264, 0.027330715408814803, 0.04309066830735121, 0.034334811714610884, 0.07093711782779012, 0.023507141740992665, 0.06380908031548772, 0.05173828160124166, 0.03715021296271256, 0.08252650273165532, 0.016080503019371202, 0.030932199476020675, 0.024147894233465195, 0.04904875877712454, 0.06174549926072359, 0.01918460225819477, 0.029865874908864498, 0.023602452162387114, 0.021543137396552732, 0.03362540674528905, 0.01349077742945935, 0.014879772539383598, 0.027465255332312415, 0.0440257065264242, 0.05754812913281577, 0.024052241151886325, 0.02113343116694263, 0.013493330417467015, 2.024095364979335, 24.29782267979213, 48.35287530081612, 38.13416658129011, 25.596576486315044, 30.98526927403041, 38.562328474862234, 43.242384910583496, 13.940746665000916, 0.3990866680230413, 0.04661867042471256, 1.988486064331872, 10.356475864137922, 13.858987212181091, 2.9520268525396074, 4.619478566305978, 32.00770364488874, 47.331420625959126, 49.82273891993931, 48.325051239558626, 48.443069866725374, 44.59163475036621, 47.01368645259312, 46.21683577128819, 47.71994652066912, 44.75946848733084, 46.73054388591221, 45.3358667237418, 48.038844517299104, 45.77644852229527, 45.249844551086426, 44.486942768096924, 44.489610876355854, 40.939533029283794, 36.76351976394653, 35.5531678880964, 33.50167751312256, 34.387593678065706, 34.39433690479824, 34.45741612570626, 35.53921937942505, 40.778449467250276, 45.74822841371809, 47.47805888312203, 47.613920484270366, 47.87302575792585, 42.623022488185335, 33.7950895173209, 34.5748302595956, 34.482116971697124, 34.6709794316973, 33.35789496558053, 33.94029297147478, 33.9033876146589, 33.761734689985005, 41.38951226643154, 47.02780171803066, 45.56579303741455, 45.60340016228812, 45.365768296378, 43.256507124219624, 40.72923885072981, 45.04536601475307, 43.638883863176616, 44.59960780824934, 43.636250495910645, 42.234507015773225, 40.40049525669643, 39.14080074855259, 43.71295166015625, 46.81266811915806, 45.7820383480617, 43.78988558905465, 43.54718501227242, 42.235021182468955, 38.98652294703892, 37.01596518925258, 36.737040179116384, 34.282453536987305, 32.61099835804531, 33.7311487197876, 33.44551869801113, 33.36877931867327, 32.683978761945454, 32.961607933044434, 35.05493688583374, 41.1777902330671, 43.96999331883022, 44.76852546419416, 45.08777434485299, 43.935797759464805, 41.88925797598702, 35.630859170641216, 36.512679372514995, 33.488142422267366, 32.559571266174316, 33.637358461107524, 38.05243492126465, 44.700731890542166, 44.519366536821636, 46.64150619506836, 45.89300455365862, 47.93028238841465, 47.33153179713658, 44.91490316390991, 44.645695209503174, 43.75181640897478, 45.67539044788906, 49.32582460130964, 48.75803518295288, 47.83854532241821, 47.336298261369976, 43.52848046166556, 37.07928759711129, 41.92860909870693, 46.12791272572109, 48.07677820750645, 50.34093904495239, 43.97045189993722, 38.669997760227744, 16.410149472100393, 1.8991600232464927, 1.8863145411014557, 6.9406333054815015, 8.53527397768838, 5.170405140944889, 5.407544553279877, 0.7876545233385903, 0.04853545721354229, 3.5743780859879086, 24.73512840270996, 34.7074852670942, 31.06269305092948, 38.14163589477539, 46.08420160838536, 24.69442411831447, 2.091516124350684, 0.013971045363827475, 0.042616871052554677, 0.0726848951141749, 0.01122932114438819, 0.05146121200440185, 0.0348024953688894, 0.01113796403764614, 0.009464126712243472, 0.019619524545435394, 0.06129132863134146, 0.06418297346681356, 0.013697140284680893, 0.06165556622935193, 0.06168335223836558, 0.02604969557640808, 0.06408830426101174, 0.006416035450196692, 0.13140069480453218, 0.09172836717750345, 0.12506898599011557, 0.1752853271152292, 0.07158572266676597, 0.0930004371330142, 0.15609148490641797, 0.12565586449844496, 0.20339681580662727, 0.21843651735356875, 0.14044349028595857, 0.08447634774659361, 0.06851353323353188, 0.11707266792654991, 0.12097281936023917, 0.14630620926618576, 0.14729818675134862, 0.14579304680228233, 0.19633983448147774, 0.07861521653831005, 0.13942422212234565, 0.2286045274564198, 2.309585554259164, 26.91562945502145, 54.029386792864116, 45.82079192570278, 31.71386432647705, 34.53807428904942, 43.66066299165998, 49.14110326766968, 15.99797190938677, 0.5694129626665796, 0.47646349029881613, 2.639773939337049, 8.568122455051967, 17.935794966561453, 7.053720014435904, 5.915670224598475, 36.99318552017212, 47.827028683253694, 49.95959063938686, 49.116781098502024, 49.58068452562605, 44.502920150756836, 47.32375676291329, 46.0329794883728, 49.63041973114014, 46.52685744421822, 50.05442312785557, 47.933318751198904, 49.27856295449393, 47.512250968388145, 46.84631824493408, 47.20860079356602, 44.773896421704976, 41.808457374572754, 39.61517858505249, 37.37398154394967, 35.77070556368147, 36.426789215632844, 35.73791354043143, 35.784518582480295, 37.31095096043178, 43.854361397879465, 48.38204383850098, 50.81475755146572, 48.74392339161464, 50.46301542009626, 43.55270883015224, 36.47442259107317, 34.83493259974888, 36.56815726416451, 34.99218075616019, 35.24685655321394, 36.21700920377459, 36.80846766063145, 35.23740700313023, 42.940787928445, 47.88429921013968, 46.188501017434255, 47.62531552995954, 47.051703521183555, 44.476704597473145, 42.91766432353428, 45.90651879991804, 45.88586180550711, 45.780235290527344, 45.81765481403896, 41.20895290374756, 41.92676087788173, 40.28345285143171, 43.380674907139365, 49.08355481284005, 46.804858343941824, 47.5441883632115, 44.44212341308594, 44.77670349393572, 40.58445923668997, 37.90944446836199, 38.792418071201865, 36.23963948658535, 33.42252363477434, 34.51604502541678, 34.81004067829677, 34.13545049939837, 34.10261331285749, 34.02529028483799, 37.00477164132254, 41.54480103084019, 47.69603429521833, 47.482102734701975, 47.358018330165315, 46.15504544121878, 43.91271931784493, 38.96945817129952, 38.48802096503121, 35.39488097599575, 34.87733050755092, 36.263749735695974, 40.077497822897776, 45.91351216179984, 46.42239475250244, 49.796457358769004, 48.81199141911098, 48.71614101954869, 49.6190698487418, 46.90769515718733, 45.27344410760062, 44.124059200286865, 45.95410353796822, 50.40896190915789, 50.09701558521816, 48.859353814806255, 49.13183437074934, 47.74762119565691, 38.85407291139875, 43.336592061179026, 48.648806027003694, 49.347419602530344, 52.19531944819859, 45.68121998650687, 42.02374383381435, 19.215667043413433, 3.606317217860903, 1.677240314228194, 8.864268575395856, 17.16128969192505, 13.556172558239528, 8.795781918934413, 2.1833736981664384, 0.2493147732956069, 4.556205664362226, 33.98030069896153, 43.03483874457223, 37.17936250141689, 42.22504704339163, 51.89694990430559, 27.25515491621835, 2.259111451251166, 0.11946843937039375, 0.14769316198570387, 0.13164453314883368, 0.16530531192464487, 0.1352742069533893, 0.18057505041360855, 0.1576651840337685, 0.10383628175726958, 0.19024661715541566, 0.14915758983365127, 0.18601565275873455, 0.13949435550187314, 0.18001794602189744, 0.19211740605533123, 0.16910976277930395, 0.1608613689563104, 0.13319926043706282], [0.04426022858491965, 0.062067348776119094, 0.056709612520145516, 0.0114756378378453, 0.029067296867391894, 0.038667603861540556, 0.054150843394121954, 0.01521773386879691, 0.039669447245874574, 0.019615173439628313, 0.01332297402301005, 0.025610841178734387, 0.027050641598179936, 0.01637001525211547, 0.03416418390614646, 0.009608355267638606, 0.014950801585135716, 0.00757780360124473, 0.0944430772215128, 0.05192325024732521, 0.03496474326987352, 0.04918007226660848, 0.8832730267729078, 13.782959154673986, 35.53090933391026, 44.92921297890799, 32.21708066122872, 32.159212589263916, 36.989555086408345, 38.04331888471331, 19.109828608376638, 0.8864690895591463, 0.07424840943089553, 0.535734664116587, 6.151984104088374, 34.241156918661936, 5.985170015266963, 5.764605096408299, 34.912505762917654, 45.09077249254499, 54.206301825387136, 50.19014229093279, 46.747848374503, 47.16102647781372, 47.86026886531285, 48.59027092797415, 47.26924467086792, 48.01305627822876, 44.7872508593968, 45.33215638569423, 44.15393645422799, 43.198590414864675, 41.890334946768625, 39.28708117348807, 38.01825325829642, 34.08238363265991, 33.3663717678615, 33.70438078471592, 32.95238767351423, 31.974859510149273, 33.79451976503645, 34.05799545560564, 33.87935726983206, 39.091736044202534, 42.86624417986189, 45.80372714996338, 45.079033511025564, 44.654665333884104, 42.03267226900373, 36.35130051204136, 32.19561767578125, 32.27987848009382, 33.09703527178083, 32.053249086652485, 31.28223875590733, 30.469243935176305, 31.252100944519043, 34.10739367348807, 40.51438317980085, 44.08495473861694, 43.53765903200422, 44.309471879686626, 43.26021746226719, 40.54998574938093, 43.53423704419817, 44.47552340371268, 45.325006689344136, 41.70337629318237, 43.069541522434776, 37.400502817971365, 38.61224433353969, 44.365071364811485, 43.154660429273335, 44.9349695614406, 42.814403670174734, 42.973670278276714, 39.13465159279959, 37.60498135430472, 36.6367255619594, 32.22330972126552, 32.21369341441563, 31.410898549216135, 30.430598054613384, 30.9466164452689, 30.753612858908518, 31.188260895865305, 32.26295614242554, 32.48354755129133, 35.2946914264134, 38.975791454315186, 41.32235097885132, 43.35124928610665, 45.746407985687256, 42.97253772190639, 41.13394015175955, 35.470640659332275, 33.0249650818961, 32.92089148930141, 32.43889842714582, 31.887961864471436, 34.68874944959368, 37.585265840802876, 40.78637736184256, 42.35202884674072, 43.44715527125767, 42.6776179586138, 46.64443138667515, 44.367610931396484, 44.92259134565081, 44.80282524653843, 44.660265581948416, 46.5500922203064, 48.59605182920183, 45.79371132169451, 46.82860728672573, 43.30261884416853, 41.63211556843349, 43.300874846322195, 47.905227184295654, 46.60065426145281, 39.10299907411848, 25.30424666404724, 11.222620929990496, 1.5673329489571708, 1.9350227160113198, 7.466817344938006, 4.840291449001857, 3.288913301059178, 3.5618444042546407, 0.7403515130281448, 0.05173435966883387, 5.676303046090262, 31.569588456835064, 24.73662052835737, 25.40787557193211, 33.30916377476284, 37.60710402897426, 12.577560475894384, 0.4194311834871769, 0.04215105676225253, 0.027310674877039025, 0.07618207817098924, 0.03378884886790599, 0.01827084628998169, 0.07503884844481945, 0.05457476832504783, 0.04501802667177149, 0.016448172308238487, 0.02893562036167298, 0.0392814643148865, 0.016187319698344384, 0.03500719242064016, 0.07981034062270607, 0.02276785748212465, 0.07129304337182216, 0.04353619779327086, 0.023449245740526488, 0.023752450809947083, 0.0143647627638919, 0.052396053448319435, 0.0386675326153636, 0.015072786914450782, 0.02275175414979458, 0.016558922793982283, 0.01071961666457355, 0.03095301693039281, 0.059157105295785835, 0.03193425659888557, 0.02603551249818078, 0.0334529842117003, 0.016975962290806428, 0.022546811129099557, 0.022507983658994948, 0.013150579478990818, 0.027725575292216878, 0.042937757048223696, 0.0410307920537889, 0.022429662058129907, 1.1479175346238273, 17.685824837003434, 44.46369409561157, 48.23727117265974, 34.9079338482448, 32.127876213618684, 41.77985858917236, 40.780328954969136, 20.756277220589773, 0.42900457978248596, 0.19782104928578648, 1.609032779932022, 9.2369430235454, 38.96404552459717, 4.637096158095768, 6.425631957394736, 38.49263456889561, 44.93885360445295, 51.871251991816926, 50.984199796404155, 46.96772411891392, 46.79951170512608, 48.1757344518389, 48.91507141930716, 50.66516283580235, 50.2374074118478, 47.90974351337978, 46.943735463278635, 46.235714026859824, 45.01416860307966, 43.86622197287423, 41.46294777733939, 38.67706060409546, 35.52215460368565, 33.549825055258616, 34.31309856687273, 34.57180084500994, 34.1875376701355, 35.08100652694702, 36.91675533567156, 34.51457895551409, 40.03646523611886, 45.33754818780081, 47.38188886642456, 46.019955090114046, 46.604447977883474, 44.068911348070415, 36.93267713274275, 33.852863788604736, 35.4125189781189, 34.481929370335166, 33.66839953831264, 33.001601764133994, 33.72464868000576, 33.221352440970286, 35.870047433035715, 42.91710499354771, 46.225715569087434, 46.29649339403425, 45.641385963984895, 43.74646282196045, 41.83329371043614, 43.435308592660085, 45.250838143484934, 45.35084009170532, 43.39764240809849, 43.590124879564556, 38.512145110539024, 41.67000062125069, 44.20617995943342, 44.56713540213448, 45.73373099735805, 43.79932819093977, 43.581394468035015, 40.77162981033325, 39.96809148788452, 37.11841637747628, 33.955440044403076, 34.24898753847395, 31.671070371355327, 32.94377885546003, 32.63698809487479, 32.68949563162667, 33.591243267059326, 34.31040613991873, 33.966525895254954, 37.4338368007115, 41.23484883989607, 43.254321915762766, 45.556697845458984, 46.26819338117327, 44.99460594994681, 42.15112515858242, 36.13421446936471, 34.88532093593052, 33.591851234436035, 32.76624195916312, 33.50134399959019, 36.339565004621235, 40.5954339163644, 42.79749870300293, 45.29028654098511, 44.56012119565691, 45.58569267817906, 46.716129847935264, 47.58528348377773, 44.99366446903774, 44.60488843917847, 45.96739544187273, 47.580895696367534, 49.02200766972133, 47.46027496882847, 48.04058851514544, 44.46071679251534, 42.95552853175572, 45.72159596851894, 49.35377025604248, 49.15367603302002, 42.10757384981428, 29.544397013528005, 12.157531448772975, 1.6795575384582793, 2.1941071450710297, 7.622980713844299, 6.651552634579795, 4.235715227467673, 3.358655627284731, 0.12531005591154099, 0.10060814462069954, 6.0659675768443515, 35.48053142002651, 29.51889365059989, 26.808927706309728, 37.18258646556309, 43.992345673697336, 16.799384083066666, 0.697690062224865, 0.032528985757380724, 0.06468234131378786, 0.09030942153185606, 0.04239849473482796, 0.04480561806953379, 0.0762776362576655, 0.020708469773775766, 0.04312735330313444, 0.08353890412087951, 0.018351232333640968, 0.011154541496320494, 0.10219460020640067, 0.03472885396331549, 0.0497767759620079, 0.024675724928134253, 0.03497748615752373, 0.020057025265746882, 0.12711081999753202, 0.10253840032964945, 0.08389864303171635, 0.11729966503168855, 0.28327021268861635, 0.15133260669452803, 0.08541250215577227, 0.14448293138827595, 0.09051184209861926, 0.07767118433756487, 0.11226048400359494, 0.1284770095454795, 0.17358010075986385, 0.1186500582844019, 0.12982629000076226, 0.16654975871954644, 0.09360335620918445, 0.12530356911676271, 0.19757551460393838, 0.13462506607174873, 0.12942461084042275, 0.12132891453802586, 1.458957770041057, 21.69070049694606, 50.168974603925435, 56.00321020398821, 41.93722833905901, 42.277262755802695, 48.30269888469151, 47.58273696899414, 24.51555143083845, 1.2573902032205035, 0.2730592648897852, 2.8858702310494015, 11.13488255228315, 48.94368757520403, 9.374611156327383, 7.414467011179243, 40.57173361097063, 46.580865791865754, 53.547518798283164, 51.88638516834804, 47.54566485541207, 47.31463030406407, 49.52983066013881, 50.75133439472744, 51.950906140463694, 51.38610097340175, 51.13305800301688, 49.31319277627127, 48.160674231392996, 45.15830550874983, 45.08084699085781, 42.431366852351594, 42.300751141139436, 36.875007084437776, 35.45856816428048, 36.25526598521641, 36.841075556618826, 35.268823283059255, 37.58839947836739, 39.26570156642369, 37.7490348815918, 42.535770484379356, 46.157963684626985, 49.133974415915354, 47.863638741629465, 49.32434810910906, 46.038333075387136, 39.4053499358041, 36.239069734300884, 35.477964060647146, 36.91341325214931, 34.98306124550955, 34.76577717917306, 33.729422092437744, 35.48373801367623, 37.00033869062151, 43.943027360098704, 48.21982077189854, 48.02494812011719, 48.01418883459908, 46.73223229816982, 43.47996813910348, 45.187630380902974, 47.85155235018049, 46.48373692376273, 45.30687883922032, 44.01183189664568, 40.26592254638672, 43.61135162625994, 44.877045903887065, 47.057870047433035, 47.29964998790196, 46.51040758405413, 46.903835432870046, 43.10780872617449, 40.209322520664756, 38.899524552481516, 34.17678880691528, 36.47688920157296, 33.233424936022075, 33.81111206327166, 33.24159254346575, 33.855493681771414, 34.15576008387974, 36.969950744083945, 35.98705162320818, 38.81930065155029, 42.37647260938372, 45.757538999829976, 46.921129499162944, 49.990541390010286, 46.47062914712088, 45.55402626310076, 38.57874359403338, 36.943120275224956, 35.68197011947632, 35.012761320386616, 34.715930802481516, 37.63085297175816, 41.97813933236258, 43.24229458400181, 47.28579527991158, 47.35552740097046, 48.049152169908794, 50.10552365439278, 48.689067363739014, 47.65182638168335, 45.763455390930176, 44.747069426945274, 48.71477222442627, 51.53631060464041, 49.027222292763845, 49.28195367540632, 47.423894201006206, 45.77570506504604, 47.65420961380005, 50.65829106739589, 51.040521894182476, 43.324668952396934, 30.093492303575786, 13.908074498176575, 2.4459026966776167, 3.3646575680800845, 16.462005615234375, 11.653747967311315, 10.135883586747305, 9.30565983908517, 1.897040171282632, 0.18381627649068832, 8.01475749697004, 40.007470403398784, 35.73339373724801, 35.78216314315796, 44.863267626081196, 50.04560933794294, 20.01036204610552, 0.9056039942162377, 0.1848975084722042, 0.24062499244298252, 0.1737230545175927, 0.154461589508823, 0.14157943933137826, 0.21297531468527658, 0.11486357503703662, 0.15460419042834214, 0.12786646373569965, 0.16224049138171331, 0.10182529395180089, 0.27658284295882496, 0.18949416253183568, 0.16533096054834978, 0.08574237874043839, 0.1442075954484088, 0.23683287735496247], [0.08249635542077677, 0.006804288098854678, 0.031355496762054305, 0.027707393946392194, 0.04649005750460284, 0.02786434248888067, 0.01109648943280003, 0.019020108406298926, 0.0786482747644186, 0.025753560841881802, 0.051739078879888566, 0.023578851018100977, 0.012120889017491468, 0.06980027311614581, 0.05977474179651056, 0.03436874185821839, 0.0422328066612993, 0.025936448081795658, 0.01427398156374693, 0.0023063521907066126, 0.05277880148163863, 0.023548820754513144, 0.15442979335784912, 7.594027570315769, 34.197379793439595, 43.079463550022666, 32.45080416543143, 26.399072578975133, 38.69702625274658, 42.67074271610805, 24.897358417510986, 2.5275622691426958, 0.1779524175716298, 0.6756175894822393, 5.269173349652972, 7.4161258935928345, 8.2298389843532, 7.228183201381138, 26.62246584892273, 45.99252012797764, 50.249667508261545, 46.11737925665719, 45.500281946999685, 48.92838764190674, 49.76192133767264, 47.729625361306326, 43.716248580387656, 46.41986213411604, 44.07193381445748, 44.708364486694336, 43.16456856046404, 38.761745248522075, 37.2809590612139, 36.07293830599104, 34.00419207981655, 32.38126311983381, 33.438191822596956, 33.640241963522776, 32.852121693747385, 34.19210958480835, 34.23506334849766, 33.53130463191441, 34.53372819083077, 38.80352824074881, 42.83874320983887, 44.47410944529942, 44.50858293260847, 46.25148296356201, 44.53808150972639, 38.82329933983939, 35.54754332133702, 34.19938087463379, 34.560391902923584, 32.61096361705235, 32.28220265252249, 31.491414274488175, 31.044447081429617, 30.700476510184153, 34.77151639120919, 39.60098688943045, 42.49151393345424, 43.489202295030864, 44.262734821864534, 42.222149644579204, 44.36791665213448, 44.30216237476894, 44.810812200818745, 44.42223072052002, 45.69943468911307, 37.786780970437185, 37.414069175720215, 43.461395604269846, 41.138519014631, 45.15026644298008, 41.72843149730137, 43.34724017551967, 42.85960170200893, 39.120668343135286, 35.19076027188982, 32.973294803074424, 30.96234369277954, 32.7688753264291, 31.82754727772304, 31.059691429138184, 32.44083002635411, 32.509328842163086, 33.511200019291465, 32.899859292166575, 31.938874789646693, 34.02506446838379, 38.05627032688686, 40.14571523666382, 42.373630796160015, 43.708421434674946, 42.31946611404419, 39.8307603427342, 33.14927530288696, 32.33765275137765, 30.97026811327253, 31.838789463043213, 31.922754968915665, 32.56309052876064, 32.817950453077046, 35.390479292188374, 39.89715385437012, 43.509070668901714, 44.6178503036499, 44.39439623696463, 43.78616482870919, 46.27442938940865, 46.64414651053292, 45.72377075467791, 48.11001491546631, 46.75967073440552, 45.288671084812705, 43.52092776979719, 43.936475208827424, 45.42004067557198, 46.40021957669939, 44.8883193561009, 37.690996578761506, 17.31576030594962, 2.7843820197241644, 0.09287190902978182, 1.5304604875189918, 5.511843528066363, 6.103767948491233, 3.4083480579512457, 3.1888522931507657, 0.16397523401038988, 0.10867752054972307, 5.217874799455915, 24.093199968338013, 23.63377639225551, 26.00339698791504, 34.79912158421108, 29.899668829781668, 7.934868846620832, 0.2435480398791177, 0.03231355088895985, 0.052223267898495705, 0.06543987816465752, 0.056058452996824465, 0.0190471056183534, 0.042903114442846606, 0.14174296627087252, 0.07492261539612498, 0.028833907962377583, 0.0295481882058084, 0.03178075501429183, 0.02157190558500588, 0.012643927558591323, 0.05966137216559478, 0.05976372917315789, 0.009983976138755679, 0.04111490664737565, 0.05335332386727844, 0.051540682025785954, 0.040716474277100394, 0.040142135095915625, 0.017813171027228236, 0.06035655164825065, 0.009704201731697788, 0.058381186931260994, 0.04424526010240827, 0.04888113009344254, 0.04408632684499025, 0.013658182196585196, 0.020159614671553885, 0.07448190011616264, 0.06748765613883734, 0.07588545658758708, 0.04346814412357552, 0.005206099370427961, 0.0678194190508553, 0.009046116910342659, 0.09837173391133547, 0.02322415022977761, 0.19704086972134455, 11.668062124933515, 41.18487392153059, 49.35796349389212, 37.68261705126081, 33.08632809775216, 38.704544203622, 44.77473020553589, 26.284640959330968, 2.5558648875781467, 0.1449152531900576, 0.38232810156685965, 7.145574331283569, 18.096956695829117, 11.674331137112208, 9.601232733045306, 29.864000252314977, 48.12717349188668, 52.6420955657959, 49.61766978672573, 45.821128913334434, 48.65335014888218, 51.06399638312203, 50.76797185625349, 47.65897955213274, 47.172226973942344, 47.02483136313302, 45.87340021133423, 45.018605027879985, 41.77589464187622, 39.69391209738595, 38.40560490744454, 36.21626227242606, 34.37648350851876, 34.16421256746565, 34.079538345336914, 34.841057436806814, 35.30758728299822, 35.35392829350063, 35.06779105322701, 35.0774872643607, 40.13466412680489, 44.639959471566335, 47.635373047419954, 45.18794304983956, 48.23788956233433, 46.40813357489449, 41.21631799425398, 37.2545941216605, 34.960003648485454, 36.168069566999165, 34.028430870601106, 34.23263495309012, 32.36669969558716, 32.72147471564156, 32.56855181285313, 37.16776943206787, 42.45996216365269, 44.76439128603254, 45.87251431601388, 44.760107721601216, 44.3137971333095, 45.513855252947124, 45.6469931602478, 45.97236687796456, 45.866511072431294, 47.378942830221995, 38.55192354747227, 38.99860239028931, 42.43222842897688, 43.803524902888704, 47.63285085133144, 43.52825117111206, 45.13138471330915, 45.031417506081716, 40.30402646745954, 36.40044164657593, 34.536382402692524, 32.48520817075457, 33.75655828203474, 32.70999281747, 33.2004348891122, 33.31000798089163, 33.60120350973946, 35.175352641514365, 34.81848621368408, 33.844810826437815, 36.05965335028512, 39.97499104908535, 42.59996141706194, 43.89219086510794, 45.185973235539024, 42.242956025259836, 41.473898138318745, 35.118818623679026, 33.60631390980312, 33.22677550997053, 33.790871960776194, 34.39018188204084, 33.71244069508144, 34.73578527995518, 38.056461402348106, 42.00338561194283, 45.61602851322719, 45.58557455880301, 46.38940470559256, 46.328892844063894, 48.06297908510481, 45.99859285354614, 46.60944025857108, 48.504787240709575, 47.720106329236714, 47.26035097667149, 45.20901346206665, 45.61104318073818, 47.426937511989046, 48.121382168361116, 47.17196294239589, 39.860491684504915, 19.426352058138164, 3.769917981965201, 0.8201023936271667, 3.9386732237679616, 8.323778629302979, 7.288050617490496, 4.67614894253867, 2.7981477039200917, 0.3429453048322882, 0.1413310548024518, 6.302859025342124, 32.10841430936541, 27.438856601715088, 30.24825300489153, 40.40991701398577, 36.70000975472586, 10.055798649787903, 0.3620511681905815, 0.0303809576268707, 0.09010801876762084, 0.03844682892252292, 0.039079243915953805, 0.05639973236247897, 0.015146180654742887, 0.08888164136026587, 0.061333187456641874, 0.045405643193849494, 0.07202952528106314, 0.0050776026494401905, 0.0951123773785574, 0.06882996803947858, 0.07051119461123433, 0.04527288103210075, 0.024137410867427076, 0.04462516846667443, 0.11391011119953223, 0.17543981596827507, 0.13169308911476815, 0.14266121414090904, 0.10524113423057965, 0.1559072355074542, 0.17171081820768969, 0.12397150988025324, 0.09691621522818293, 0.10915688518434763, 0.15692651724176748, 0.10061480783458267, 0.10199310244726283, 0.1438776102981397, 0.12102820138846125, 0.14494049469275133, 0.1135928892929639, 0.10357092706752674, 0.19141836570841925, 0.08740780223160982, 0.31398138616766247, 0.10493974254599639, 0.4208972533898694, 12.806967411722455, 50.64462743486677, 56.2749924659729, 42.00736345563616, 36.77778788975307, 48.09650761740548, 51.40438863209316, 31.22499602181571, 3.5650216851915633, 0.39158185358558384, 1.8679046375410897, 10.72920502935137, 15.392684800284249, 12.239702582359314, 10.75298089640481, 31.769411700112478, 51.48750993183681, 54.038391658238, 49.83861902781895, 44.38871955871582, 49.87157085963658, 52.610491684504915, 53.29752261298043, 48.0345470564706, 49.822766712733674, 48.8893735068185, 49.3363823890686, 46.65636144365583, 43.2973312650408, 40.83948939187186, 40.69111408506121, 37.860174792153494, 35.97338451657976, 37.13786785943167, 35.77676091875349, 35.31534147262573, 38.028324672154014, 38.53754077638899, 36.99617671966553, 36.524418354034424, 43.29720272336687, 46.426556723458425, 48.54729979378836, 46.54024314880371, 49.23346219744001, 49.14686679840088, 42.71244927815029, 39.17326620646885, 37.42559276308332, 37.854894161224365, 35.56489297321865, 34.96983534949166, 34.3986691066197, 35.189724990299766, 33.69138765335083, 37.76905958993094, 44.676677227020264, 45.952453340802876, 46.07743753705706, 47.99544259480068, 45.11842632293701, 47.28445080348423, 47.13427243913923, 46.47736195155552, 48.01967791148594, 48.512635231018066, 40.7764310155596, 40.43796689169747, 42.04313278198242, 44.03672729219709, 47.30675452096121, 44.17464208602905, 47.74123232705252, 48.881883348737446, 42.54806184768677, 39.086240019117085, 35.91204581941877, 33.780522618974956, 36.42500352859497, 36.20193856103079, 34.45637389591762, 35.99272830145699, 35.271936076028005, 37.60874727794102, 36.570116656167166, 35.283529145377024, 37.16854763031006, 41.32640872682844, 43.30069071905953, 45.89958797182356, 47.601861885615754, 44.75990969794137, 44.72130898066929, 36.602488313402446, 35.030645983559744, 35.12396376473563, 35.906601905822754, 36.08528525488717, 35.69329220908028, 35.85510185786656, 38.748772961752756, 42.579787322453086, 49.07202080317906, 48.935620716639924, 48.177558353969026, 46.007066181727815, 49.48750570842198, 47.49421344484602, 46.79964372089931, 48.63130004065377, 49.17693165370396, 48.60635600771223, 45.728637967790874, 47.11843054635184, 49.197543484824045, 50.970497948782786, 49.17881808962141, 40.10073607308524, 21.357708079474314, 4.269859978130885, 0.619565657206944, 4.8050210901669095, 12.76547450678689, 15.597449949809484, 8.9606157711574, 6.2970364349229, 0.7941335556762559, 0.43844300189188545, 7.8895648547581265, 34.7864967073713, 34.511007581438335, 38.27317224230085, 46.73971898215157, 40.64376558576311, 12.016969391277858, 0.5424195368375097, 0.08711580825703484, 0.13340875133872032, 0.16097790056041308, 0.10329364373215608, 0.08226230833679438, 0.19523589871823788, 0.23124014745865548, 0.20360638813248702, 0.08803632243403367, 0.14953386464289256, 0.12244281119533948, 0.1525487992912531, 0.15055113791355065, 0.19806057214736938, 0.17211294520114148, 0.13579032782997402, 0.13379947894385882], [0.05717953533998557, 0.07013246350522552, 0.03572715200217707, 0.0430231506803206, 0.013824122176239533, 0.029852657046701227, 0.013599032602672066, 0.05674555112740823, 0.08361401794744389, 0.046155495635632954, 0.06614327470638923, 0.01213862931555403, 0.047707685202892335, 0.015651444971029247, 0.03321850625798106, 0.05380263279325195, 0.037422515851046355, 0.076380698941648, 0.027466729449640428, 0.07049151031034333, 0.03873611554237349, 0.081755442677864, 0.023854863796649233, 4.432838227067675, 34.07611983163016, 39.89723028455462, 30.912149906158447, 36.67258174078805, 56.62419850485665, 43.76307249069214, 26.57941481045314, 5.240119022982461, 0.15733572814081395, 0.9316505108560834, 4.0228345819881985, 8.814972843442645, 13.70389473438263, 6.852855844157083, 28.95386961528233, 32.75554173333304, 38.54585429600307, 48.82076699393136, 48.7909939629691, 49.92944935389927, 48.07517664773123, 46.15740782873971, 43.143150738307405, 43.385889530181885, 41.533652646201, 38.33440324238369, 36.50416088104248, 36.754302978515625, 35.56403834479195, 33.97014938082014, 32.974489893232075, 33.79774720328194, 33.40233564376831, 34.06599630628313, 32.88688005719866, 32.26618358067104, 35.507573808942524, 35.407415526253835, 33.37747151511056, 38.782284123556956, 43.15305192129952, 44.39172118050711, 46.094370297023225, 43.98197201320103, 42.21973167146955, 41.709129401615684, 36.61511319024222, 33.57725306919643, 33.742800848824636, 32.85111767905099, 32.65407024111067, 32.85683952059065, 31.68001617704119, 31.697859151022776, 32.64699002674648, 36.07056202207293, 39.50744676589966, 42.75557674680437, 43.28187499727522, 42.77617815562657, 42.77550070626395, 43.94728660583496, 44.868763651166645, 42.74874666758946, 46.10234335490635, 38.13329458236694, 35.40824236188616, 43.708959920065745, 39.65305321557181, 43.83271428516933, 44.44955798557827, 44.968661376408164, 43.112116609300884, 42.5244414465768, 40.90139436721802, 35.244004317692344, 31.64798150743757, 32.59740768160139, 31.642818995884486, 32.2130263873509, 30.527039051055908, 30.64138902936663, 33.48632199423653, 33.315771511622835, 34.177921363285606, 32.50704983302525, 32.98858083997454, 39.10709851128714, 42.19074378694807, 44.717925207955496, 45.752616201128276, 42.07015780040196, 36.47458587374006, 33.13609804425921, 32.433009828839985, 31.668357099805558, 31.589265755244664, 32.13621405192784, 32.11597742353167, 33.27311999457223, 32.72251694543021, 36.39351429258074, 41.05769756862095, 44.35202612195696, 44.104618140629356, 43.30120488575527, 47.061795779636924, 45.29775585447039, 44.28897816794259, 47.04691621235439, 47.560367243630544, 49.83228921890259, 46.89514671053205, 47.19244275774275, 48.27264445168631, 45.25794962474278, 28.837791272572108, 10.710172176361084, 1.1913308565105711, 0.6731247061065265, 3.651026487350464, 4.89421728679112, 4.8963560291699, 2.3634942386831557, 1.7274243299450194, 0.130454260589821, 0.05771947279572487, 7.516103523118155, 28.778106246675762, 28.144878693989344, 22.124723196029663, 35.228450775146484, 23.905400582722255, 4.060552009514399, 0.10597328030105148, 0.03533467038401535, 0.015175656215952975, 0.032421811151185205, 0.01955146069771477, 0.015080980224800962, 0.07667785656771489, 0.03326302833322968, 0.026436089039114968, 0.05862741371882813, 0.03843608771317771, 0.048531212977000644, 0.027197597016181265, 0.016315035255891935, 0.017130257761371986, 0.022111369762569666, 0.028762258057083403, 0.04626890937132495, 0.047529725823551416, 0.04483550414443016, 0.047153213527053595, 0.03129899175837636, 0.039943626283534935, 0.018158910064292804, 0.03440246844132032, 0.05834622202175004, 0.06054007501474448, 0.03239217274157064, 0.03879052048016872, 0.015308413288689085, 0.08640346183840718, 0.019120891212618778, 0.013904535361299557, 0.03548380559576409, 0.052021132316440344, 0.028631453468863453, 0.03135925245338252, 0.054688402584620883, 0.0444690002394574, 0.04718138969370297, 0.024550659049834524, 5.874366223812103, 41.20491600036621, 48.40179756709507, 35.492044585091726, 33.801565238407676, 53.74213784081595, 47.330836977277485, 29.451940808977398, 5.977964299065726, 0.19492515682109765, 0.78081000489848, 4.335682434695108, 11.696560161454336, 18.994634423937114, 7.685327768325806, 32.56782225200108, 37.3336090360369, 43.54644850322178, 48.46147217069353, 50.329630851745605, 51.03080831255232, 48.60441746030535, 46.925496441977366, 46.14478642599923, 47.029545715876985, 43.35345186505999, 41.5502484185355, 38.77858073370797, 38.040761947631836, 38.00337021691458, 35.072922297886436, 33.32633972167969, 36.07546050207955, 34.65986926215035, 35.5321044240679, 35.86045544488089, 33.82601247514997, 35.86829996109009, 37.64402675628662, 34.988970688411165, 40.57163981028965, 45.10776778629848, 46.605976581573486, 47.79437214987618, 44.75586584636143, 44.18814243589129, 43.439269065856934, 38.46080834524972, 36.061692646571565, 35.52417305537632, 33.576749324798584, 34.71472529002598, 35.309084619794575, 33.93557167053223, 32.38512979234968, 34.22607585362026, 37.93984978539603, 40.86075782775879, 45.48594086510794, 44.272160053253174, 43.6831682068961, 44.06379747390747, 44.78551728384835, 46.60117537634713, 45.312159470149446, 47.52215562547956, 40.85237830025809, 36.210884366716655, 42.54849263599941, 41.894750526973176, 46.23064184188843, 46.023967674800325, 47.46743508747646, 44.769428730010986, 44.68903807231358, 41.37182215281895, 36.828426361083984, 32.80662488937378, 33.65157100132534, 33.07612814222063, 34.2746124948774, 31.514239106859478, 33.83068513870239, 33.525350025721956, 35.012761320386616, 35.313149315970286, 34.16671391895839, 34.178591864449636, 40.242920534951345, 43.87109613418579, 46.39862149102347, 45.386995043073384, 44.37539291381836, 38.29155717577253, 34.49239683151245, 32.919359411512104, 33.59462703977312, 32.43674795968192, 33.90359606061663, 33.82496329716274, 34.62957164219448, 34.775629724775044, 39.32297209330967, 42.544834409441265, 45.676974637167795, 44.85830661228725, 45.22142989294869, 48.66101401192801, 46.13962044034685, 44.67719834191458, 47.14255469185965, 48.542192867824006, 51.28988579341343, 49.48316308430263, 48.45602478299822, 49.85605205808367, 46.5806052344186, 33.65457609721592, 12.303817084857396, 2.0758125441414967, 1.9528196581772395, 5.823654796395983, 5.9703903283391675, 7.19107026713235, 4.978801182338169, 1.221990977014814, 0.3056554900748389, 0.20946206391922065, 8.145441821643285, 28.704752377101354, 31.363866192953928, 27.42428970336914, 40.79207141058785, 29.578123569488525, 6.404260167053767, 0.09466294970895563, 0.02307601585718138, 0.029961202293634415, 0.03810965808640633, 0.0465802415939314, 0.028605116132114614, 0.03440611217437046, 0.013970080147763448, 0.010053852523144866, 0.036110273229756525, 0.06468844134360552, 0.04615398928789156, 0.029823032207787037, 0.06421376538595983, 0.021489332962249006, 0.026073284846331393, 0.04446288324626429, 0.07159967334674937, 0.10681439231016807, 0.1434419093919652, 0.11998998852712767, 0.09806277656129428, 0.12402877823582717, 0.13451867178082466, 0.15316281920032843, 0.12379709923905985, 0.22241300397685596, 0.0943191224443061, 0.18468341710312025, 0.13294531192098344, 0.09569836022066218, 0.11198180967143603, 0.09861191495188645, 0.1499550991824695, 0.28061540371605326, 0.10394924426717417, 0.1420150859547513, 0.15281927692038672, 0.10109426067875964, 0.2416051769895213, 0.20868978250239575, 8.023294227463857, 46.74303674697876, 55.68242924554007, 43.04975652694702, 46.464285441807334, 61.870296886989046, 51.85153300421578, 34.1109824180603, 7.221139030797141, 0.4386269391647407, 2.474743366241455, 9.97586396762303, 17.38395513807024, 20.151565074920654, 9.944421631949288, 36.27279281616211, 39.32562977927071, 44.127634048461914, 49.08560453142439, 51.937374523707796, 52.198644161224365, 51.12116616112845, 47.83330985477993, 47.14370461872646, 48.676890645708355, 44.949557304382324, 42.60380029678345, 40.231567178453716, 40.77859885351998, 40.73430756160191, 36.804552350725444, 35.13356964928763, 38.49789782932827, 36.472195693424766, 37.96445683070591, 37.49315357208252, 34.827647413526265, 38.712600639888215, 39.23791224615914, 37.85979264123099, 41.56722286769322, 48.240526403699604, 48.1978714125497, 49.402324267796104, 44.68883310045515, 47.37733779634748, 46.604114464351106, 39.83245917728969, 37.42842762810843, 37.869342940194265, 35.01037114007132, 38.11024740764073, 36.85551738739014, 35.90336751937866, 34.03196750368391, 35.1844756262643, 39.80523266111101, 42.541506222316194, 46.26388897214617, 45.90336431775774, 45.45165845326015, 45.22819743837629, 46.59099973951067, 48.40613671711513, 46.52806643077305, 48.044865131378174, 42.95988505227225, 38.447301047188894, 44.669079371861045, 42.39896740232195, 45.58191633224487, 48.0921128817967, 48.71258701596941, 47.00197178976876, 45.83450419562203, 44.788866315569194, 38.60296848842076, 34.410300391060964, 34.8243921824864, 34.001075812748496, 35.83404186793736, 33.098244258335654, 34.41367026737758, 36.177109173366, 37.15260846274239, 36.84364986419678, 34.52373668125698, 35.809403555733816, 41.989558696746826, 45.73239346912929, 49.256599698747905, 49.70296587262835, 46.45906734466553, 40.71759019579206, 35.765001092638286, 34.917161055973594, 35.6204195022583, 35.33956289291382, 34.830089705330984, 35.023503235408235, 36.818761416843955, 35.90122052601406, 39.256731442042756, 43.64341756275722, 47.711924825395855, 47.643144607543945, 47.51191398075649, 50.77159186771938, 46.50253527505057, 44.00024924959455, 48.93323401042393, 49.91027232578823, 53.93945625850132, 51.86836848940168, 50.430421420506065, 51.82572392054966, 48.98939629963466, 34.63052701950073, 14.26668666090284, 1.8238545783928461, 1.1248187912361962, 6.552495207105364, 13.422414524214608, 12.932815790176392, 8.138695989336286, 6.233734437397548, 0.7573266678622791, 0.484984533063003, 10.711302127156939, 38.77230651038033, 38.98079415730068, 33.07224757330758, 47.215139048440115, 34.57074819292341, 6.807074163641248, 0.25203043328864233, 0.1567497860108103, 0.06558793450572661, 0.15013620017894677, 0.08383226195084197, 0.09740856023771421, 0.10673874922628913, 0.08059686448957239, 0.054053918059383116, 0.10173354923192944, 0.08079748015318598, 0.07281653769314289, 0.12161209434270859, 0.1898170094937086, 0.1512137816420623, 0.07548935498510088, 0.1444311455956527, 0.13985655749482767], [0.14748960148010934, 0.028748426120728254, 0.015858452434518507, 0.04872626465346132, 0.031565116585365365, 0.03926135592960885, 0.03447903433282461, 0.024725480204714195, 0.03527961065992713, 0.034144818516714234, 0.034348314561481984, 0.011483317157918853, 0.04702389832319958, 0.030570411389427524, 0.011779539253828781, 0.06139051688036748, 0.06777414040906088, 0.049429179435329776, 0.02088334860413202, 0.006133348007486867, 0.02705916399801416, 0.02277616105441536, 0.0573688398248383, 5.851556590625218, 28.186342069080897, 42.66128969192505, 35.77746616091047, 55.05353389467512, 67.2521561213902, 47.0274577822004, 26.033475739615305, 8.88054473059518, 0.021410219171749692, 0.25644609491739956, 2.0133916650499617, 8.507690497807094, 5.418801937784467, 5.123084000178745, 17.084300177437918, 27.099086216517858, 51.192096846444265, 48.45251594270979, 53.15114491326468, 47.65595361164638, 49.49064629418509, 41.747070040021626, 41.02310596193586, 36.84942381722586, 35.83187402997698, 34.28964144842965, 32.45105430058071, 32.19544049671718, 35.12501294272286, 31.956217493329728, 33.091726848057334, 32.89388036727905, 33.99593414579119, 33.71965292521885, 35.03520747593471, 33.7813390323094, 35.09750849860055, 33.5498354775565, 36.1233857018607, 37.84061213902065, 41.194611821855815, 41.3808513368879, 44.788206236703054, 42.06143086297171, 43.25001055853707, 41.04835224151611, 35.89439739499773, 33.14208044324602, 33.52207047598702, 32.297863892146516, 33.82349375316075, 32.21306807654244, 33.43697936194283, 31.351091929844447, 33.05960185187203, 34.025926045009065, 39.32136011123657, 40.71680852345058, 44.0052102633885, 41.82713760648455, 43.051173959459575, 40.70643138885498, 42.8687663759504, 41.208855628967285, 48.2005603654044, 40.72262069157192, 37.05273853029524, 41.44763394764492, 38.290306500026155, 42.48957191194807, 46.00942162105015, 46.76684127535139, 47.35583659580776, 43.341111864362446, 43.63732051849365, 39.43888889040266, 32.04451520102364, 31.140161991119385, 31.28926338468279, 31.601862839290074, 31.163334233420237, 33.02608026776995, 32.83431346075875, 34.20792021070208, 36.30840580804007, 37.175742489951, 38.13507679530552, 41.14049925122942, 42.36669649396624, 47.123624324798584, 42.38711724962507, 41.314457825251985, 37.23533371516636, 32.77653571537563, 32.824620723724365, 33.08965628487723, 32.114414078848704, 32.2084127834865, 31.520204135349818, 31.9757627759661, 31.687867641448975, 32.649189131600515, 35.048207555498394, 37.82178946903774, 42.67007221494402, 42.88503210885184, 44.943821566445486, 45.34423235484532, 44.40321350097656, 45.80814620426723, 45.84492301940918, 43.24404900414603, 46.87489965983799, 47.068083899361746, 48.05266101019723, 39.59074177060808, 22.681221791676112, 8.13023829460144, 4.891885297639029, 2.859078411545072, 3.967146941593715, 5.606916597911289, 6.014878341129847, 4.788354533059256, 1.8863240948745181, 0.05530776256429298, 0.37620112033826963, 12.233057498931885, 33.65677867616926, 28.708507878439768, 35.035002504076274, 39.47899736676897, 19.919192995343888, 1.5424049837248666, 0.03188134104545627, 0.02872884360009006, 0.05160487822390028, 0.019918288603158932, 0.049675294264618836, 0.06527117400297097, 0.05362787609919906, 0.046294496926878176, 0.0337982330072139, 0.02274901286831924, 0.06439582990216357, 0.004195269213856331, 0.06571672723761626, 0.025952778723356978, 0.03329261585271784, 0.01699049142189324, 0.015203550790569611, 0.03584757500461169, 0.0806029848754406, 0.0031987425754778087, 0.02044662311007934, 0.02124158795257764, 0.018889610855174915, 0.006815669675623732, 0.024499582326305763, 0.01217111078689673, 0.03776105393522552, 0.00695557426661253, 0.011963466348658715, 0.07713427314800875, 0.02937224068279777, 0.01140254519746772, 0.019278840594259754, 0.05554965690576604, 0.01989884178952447, 0.047285100378628285, 0.03837165063513177, 0.09595521965197154, 0.035851530863770416, 0.008770844583133501, 0.07087431262646403, 7.500075766018458, 33.95364393506731, 49.119636808122905, 38.86628089632307, 56.6924159186227, 66.0972682407924, 50.6310749735151, 30.162005015781947, 9.693117448261805, 0.08211959206632205, 0.60551482545478, 3.8189583676201955, 14.337556549480983, 12.685928055218287, 7.2322704792022705, 22.303703580583843, 30.638140746525355, 52.16558115822928, 48.04263823372977, 52.28430502755301, 50.35973392214094, 49.691859177180696, 44.201139041355674, 43.08530698503767, 38.94705023084368, 38.044388907296316, 35.783042090279714, 35.261920247759136, 35.58471270969936, 35.57449190957205, 33.25556884493147, 35.39562790734427, 34.106070041656494, 35.70772361755371, 35.43509714944022, 36.77401154381888, 35.75382144110543, 36.99781649453299, 35.28020095825195, 38.6119316646031, 38.665550913129536, 42.788386140550884, 43.57688856124878, 46.28609888894217, 43.272842339106965, 44.13898045676095, 43.011478900909424, 38.20215470450265, 34.04488073076521, 34.99212864467076, 34.361232212611604, 35.279707636152, 33.160194396972656, 36.4602621623448, 33.31242595400129, 33.89235040119716, 35.982476234436035, 40.54629973002842, 41.89370829718453, 45.21818855830601, 44.04954324449812, 44.99649933406285, 42.09443480627877, 43.89717967169625, 42.941625186375205, 47.66912392207554, 42.857381752559114, 37.840983867645264, 42.07522998537336, 39.68169021606445, 42.8455559185573, 46.05260467529297, 46.950277192252024, 48.834753717694966, 45.905365398951936, 46.49132088252476, 39.43650565828596, 33.13933937890189, 33.65041412625994, 32.05910641806466, 32.0948166847229, 33.296375615256174, 34.15066705431257, 34.54366758891514, 35.40096412386213, 38.24985408782959, 37.2028717313494, 39.03692865371704, 44.37744958060128, 44.64511850902012, 47.00242689677647, 45.677353313991, 43.178138392312185, 37.70032800946917, 34.10884584699358, 34.52669313975743, 34.14907244273594, 33.086609499795095, 33.143452712467735, 34.558435985020225, 34.2813835144043, 34.51742771693638, 34.193794522966655, 36.387062890189036, 39.90472739083426, 44.875107356480186, 44.631684167044504, 46.964316027505056, 47.36417096001761, 43.24180473600115, 46.65932485035488, 45.96781928198678, 43.719156401497976, 48.17531061172485, 47.72506734303066, 49.337712969098774, 41.616391795022146, 23.94013636452811, 10.17423677444458, 4.613263836928776, 4.684327406542642, 5.477010037217822, 8.316908597946167, 4.338020069258554, 1.4813905720199858, 0.3836744236094611, 0.15466566570103168, 0.38416723002280506, 12.070443596158709, 36.17478847503662, 31.1516022000994, 37.25192253930228, 45.5080361366272, 24.906305960246495, 2.3660615980625153, 0.07775015902838536, 0.03674082225188613, 0.04769738164863416, 0.06288632018757717, 0.047569905274680684, 0.03173753233360393, 0.05109603124271546, 0.022762751506109322, 0.018150993256962726, 0.026175417937338352, 0.05712899126644645, 0.07862981861191136, 0.01933956947842879, 0.040481412783265114, 0.07204638009092637, 0.042543701228818724, 0.010585589035015022, 0.03051180631986686, 0.1695893784718854, 0.18703749935541833, 0.08728643267282418, 0.07948522735387087, 0.07748905196785927, 0.06726160219737462, 0.08951193253908839, 0.1369577744709594, 0.11203451148633446, 0.0820295572546976, 0.17308049542563303, 0.1634772435895034, 0.07997908549649374, 0.1118579770305327, 0.1460275077926261, 0.2157595067151955, 0.11304991878569126, 0.14290114412350313, 0.14080330383564743, 0.15849412312465055, 0.11389944462903909, 0.07756512252879993, 0.19565418841583387, 8.455118690218244, 39.14795739310128, 57.49955688204084, 45.993458134787424, 62.67542634691511, 69.32383796146938, 53.77140365328108, 34.558498518807546, 12.264740415981837, 0.16395159385034017, 1.2196264181818282, 7.45456680229732, 15.192330019814626, 11.713376539094106, 8.768772533961705, 23.425700426101685, 32.22699226651873, 53.540824208940776, 49.104072843279155, 53.99668857029506, 51.425049100603374, 52.57506281988961, 45.201547622680664, 44.587858404432026, 40.64930330004011, 39.510222571236746, 38.89933000292097, 36.067112241472515, 36.25184399741036, 38.286714281354634, 34.73436089924404, 36.509559631347656, 35.707237243652344, 37.44035073689052, 37.21281112943377, 39.5310845375061, 37.36228425162179, 38.439713614327566, 37.68851954596383, 40.47802325657436, 40.85117278780256, 44.74871615001133, 44.27000611168997, 48.8541704586574, 46.062283515930176, 45.751455851963584, 45.1089837210519, 39.21672371455601, 35.86792128426688, 35.65966987609863, 36.20671892166138, 36.93474074772426, 34.743883405412944, 37.70316982269287, 34.68567487171718, 36.00254610606602, 37.09761347089495, 42.117499351501465, 44.22466564178467, 47.45912504196167, 45.94025230407715, 45.73208427429199, 44.73501430238996, 45.550284658159526, 45.07369382040841, 49.12579986027309, 45.133281571524485, 40.01040949140276, 41.087404591696604, 39.3987387248448, 42.412776947021484, 46.241647788456504, 48.5414320400783, 51.53358343669346, 49.08949899673462, 47.777276107243125, 43.52011483056204, 34.95388228552682, 35.10677739552089, 35.01411621911185, 34.27692971910749, 34.481964111328125, 35.92521960394723, 36.01874930518014, 37.673862321036204, 39.21752275739397, 40.43053579330444, 42.82948126111712, 45.60458830424717, 45.25988122395107, 49.85725062234061, 46.33189793995449, 44.94484295163836, 40.9464430127825, 35.89058630807059, 35.97399943215506, 36.51306847163609, 35.259877477373394, 34.74059343338013, 36.03536939620972, 35.47052601405552, 34.572877815791536, 36.34263610839844, 37.22837162017822, 42.03108460562569, 45.21182748249599, 47.162193775177, 49.8179863521031, 48.86288349969046, 44.09793397358486, 46.42587232589722, 46.6117331641061, 43.920699323926655, 47.33619403839111, 48.82175363813128, 49.289683546338765, 43.40358659199306, 25.857344116483414, 11.283046807561602, 8.994081769670759, 9.165868163108826, 12.526934163911001, 13.687356284686498, 15.294961861201696, 13.562769872801644, 4.737205369131906, 0.3338900650186198, 0.7008088805845806, 15.30884609903608, 44.19991963250296, 38.77442223685128, 44.26132433755057, 52.35891825812203, 29.314258779798234, 3.361562362739018, 0.19003157583730562, 0.07882662090872015, 0.18212296521025045, 0.14579259896917002, 0.09629473821925265, 0.0792119541604604, 0.2093791062278407, 0.1587218259062086, 0.08924847774739776, 0.10693031323275395, 0.09744057351989405, 0.10852948456470456, 0.1495712519224201, 0.10304010233708791, 0.16746747733226844, 0.1482522612703698, 0.11946739442646503, 0.10300316289067268], [0.027329877418066775, 0.01847672738533999, 0.04378296062350273, 0.02210616709531418, 0.029293422055031573, 0.048258733669562, 0.0711902995992984, 0.03854945734409349, 0.013927610640946244, 0.026581231072278957, 0.040181286566491635, 0.07117622678301164, 0.053696716869516034, 0.0406514570516135, 0.03132334438019565, 0.07422822301409074, 0.04584938134731991, 0.017797011715759124, 0.02008822769857943, 0.0541206960832434, 0.013497461847561811, 0.040113100582467656, 0.06437622702547482, 3.055524613176073, 24.150812694004603, 45.35435240609305, 39.59292350496565, 40.33380992071969, 55.67724241529192, 36.13543735231672, 29.790217331477574, 15.362057140895299, 0.4540039540401527, 0.6716053304927689, 3.7834951962743486, 2.46935156413487, 2.7704309054783414, 0.9247856906482151, 9.006500806127276, 26.32524970599583, 37.45678322655814, 50.21493346350533, 50.98034702028547, 49.95361866269793, 45.15562350409371, 44.5952582359314, 39.86482736042568, 38.05169493811471, 35.33776330947876, 35.35521371023995, 33.963704926627024, 33.74270704814366, 33.439845493861604, 35.05804967880249, 35.33723177228655, 37.30651453563145, 36.903880323682515, 38.094276973179404, 35.964991092681885, 35.3434156690325, 34.003201961517334, 33.1350280216762, 33.27378354753767, 38.27078553608486, 36.95937211172921, 36.675600733075825, 38.63892194202968, 37.13248300552368, 36.96093545641218, 38.77947357722691, 34.20430019923619, 33.37775986535208, 32.512827260153635, 31.195559978485107, 32.8033800806318, 32.62624270575387, 31.605076381138392, 32.00722769328526, 32.810376916612896, 34.50638702937535, 35.59008714130947, 39.263221059526714, 41.30532441820417, 40.10963324138096, 39.025672571999685, 40.378038678850444, 41.15476042883736, 42.05963127953665, 47.093663692474365, 40.02253409794399, 35.78769390923636, 43.14333486557007, 39.30083513259888, 45.87354959760393, 43.39669745309012, 44.45851421356201, 44.044832365853445, 46.75598471505301, 43.71562671661377, 41.970888887132915, 34.36713470731463, 32.09790863309588, 32.229191371372764, 32.95228345053536, 31.295134612492152, 33.66022845676967, 33.03292424338204, 36.77196182523455, 37.02039813995361, 41.476854596819194, 42.014537470681326, 44.58489152363369, 43.494667053222656, 44.660512242998394, 40.910249846322195, 40.758125986371724, 33.93526594979422, 32.28246668406895, 31.086375985826763, 32.38801676886422, 30.987263407026017, 32.600353717803955, 31.426198482513428, 30.338530949183873, 30.470942769731792, 31.83194896153041, 32.10937663487026, 33.53757190704346, 37.39843920298985, 41.200562953948975, 43.654190744672505, 44.62686211722237, 46.53146409988403, 42.86064740589687, 46.57311855043684, 46.99349498748779, 46.0843996320452, 48.46488721030099, 46.791302408490864, 37.37640993935721, 19.065224647521973, 7.2027219619069776, 7.00395701612745, 9.991584266935076, 4.403606287070683, 4.458360697541918, 2.6883021124771664, 0.9059654091085706, 0.14446923855159963, 0.5998027548193932, 0.5021371383752141, 13.231346011161804, 33.82914958681379, 29.307418278285436, 32.45934350149972, 35.50411013194493, 13.164791822433472, 0.3520036930484431, 0.029294209155653204, 0.08528511399137122, 0.029457888765526668, 0.02688977960497141, 0.02189487129050706, 0.068782063467162, 0.024407925815986733, 0.02389745713610734, 0.02480919106996485, 0.06540901160665921, 0.017174301469432454, 0.029000776686838696, 0.024041292989360433, 0.0049831463340004635, 0.03658805687778762, 0.02165560457589371, 0.02688938096564795, 0.022242662896003042, 0.0396726974286139, 0.03498154040426016, 0.04026832225333367, 0.04047749085085733, 0.05427696269803813, 0.05506793436195169, 0.03594704145299537, 0.01235599716060928, 0.02651613581526492, 0.02165536199962454, 0.06352141539433173, 0.027445822089378322, 0.030185305446918522, 0.038269894131060155, 0.07795231496649128, 0.0273084764235786, 0.00922149361576885, 0.037371313598539145, 0.020259769832981483, 0.0354788319340774, 0.040239192744983096, 0.03957932422469769, 0.03365352862913694, 4.283807618277414, 29.705272129603795, 51.097246987479075, 43.70893212727138, 46.22922788347517, 63.39277226584298, 41.61184072494507, 34.45910106386457, 14.704206909452166, 0.5420102445142609, 0.16763008146413735, 1.9679914840630122, 5.447601786681584, 5.726827306406839, 2.054830070052828, 13.696871842656817, 30.130317756107875, 40.59561456952776, 50.155116421835764, 51.5841315814427, 50.79327719552176, 49.13198028291975, 46.70533929552351, 41.20052126475743, 39.03114080429077, 38.633022921425955, 35.99227319444929, 34.89240115029471, 35.581387996673584, 35.70790774481637, 35.61407579694475, 36.18469313212803, 38.41238634926932, 39.19372517721993, 40.00330148424421, 39.1388760975429, 36.78493411200387, 36.524529525211875, 35.13313538687569, 35.24805859157017, 40.11033500943865, 38.919007301330566, 39.28054986681257, 40.10451589311872, 40.14803940909249, 39.60644122532436, 39.6393791607448, 35.98544658933367, 34.817777497427805, 34.421198640550884, 33.16468293326241, 33.6346868787493, 34.70210041318621, 33.43010759353638, 34.43891307285854, 33.681555952344624, 35.53099966049194, 37.905306816101074, 40.704548427036826, 42.292691230773926, 41.70160102844238, 42.406662532261436, 41.906934193202424, 43.04173830577305, 43.549436228615896, 48.851491928100586, 42.2826441356114, 38.0251076562064, 42.34020301273891, 38.68558604376656, 44.72901800700596, 43.37803111757551, 45.36574745178223, 45.31949329376221, 47.55190086364746, 45.520424774714876, 44.04627411706107, 34.94996002742222, 35.04757179532732, 33.68088892527989, 34.08667414528983, 32.707508836473735, 34.50821440560477, 35.20299257550921, 37.285982608795166, 39.13446399143764, 43.099043573652, 45.08923346655709, 46.9546788760594, 46.42381565911429, 46.2823086466108, 43.72913401467459, 42.024647099631174, 35.484790665762766, 33.84474829265049, 33.583165986197336, 34.12369762148176, 32.80048268181937, 33.76561178479876, 32.84184183393206, 31.63915034702846, 33.120329107557026, 33.26860019138881, 33.71133245740618, 34.5088849067688, 39.51331451960972, 43.50519357408796, 45.67176348822457, 45.903246198381694, 45.98192759922573, 43.03069761821202, 47.6371830531529, 46.49563571384975, 47.250168391636436, 47.13543626240322, 47.11357028143746, 37.70266955239432, 21.321836267198833, 9.68896416255406, 9.493224722998482, 11.31413652215685, 2.5833699830940793, 4.3063536541802545, 1.976784429379872, 0.10935621841677598, 0.17782886991543428, 0.5710154995322227, 0.8298805717911039, 15.163020781108312, 38.99148048673357, 33.31262745176043, 39.69563177653721, 42.78736128125872, 17.988589116505214, 0.8435038179159164, 0.07229361111032111, 0.06709797347762755, 0.06508511291550738, 0.019176658309463943, 0.025138353496523838, 0.06264687196484633, 0.04971704113164118, 0.018385422016893114, 0.05475329088845423, 0.09134898467787675, 0.046022363672299046, 0.008330434643929558, 0.02106767433828541, 0.0668667151725718, 0.02220389310137502, 0.012642255817939128, 0.008980966522358358, 0.016160062946645275, 0.11808338654892785, 0.20783096072929247, 0.14468780825180666, 0.06167553551495075, 0.11743858829140663, 0.14983448279755457, 0.1384684241243771, 0.1212220588432891, 0.08611469090517078, 0.1340504961886576, 0.165554958528706, 0.19408872670360974, 0.15977036607052597, 0.12087663023599557, 0.14321208958114895, 0.12757629502032483, 0.08913366962224245, 0.23021857227597917, 0.11019876892013208, 0.14635456167161465, 0.0994880800800664, 0.08812635046030794, 0.10695240633296114, 4.891566114766257, 33.39502961294991, 59.04748003823416, 50.81902721949986, 49.245340142931255, 61.22534424918038, 44.49514511653355, 39.305007525852744, 19.651690823691233, 0.9167807144778115, 1.3769452508006776, 6.455993413925171, 10.46726836477007, 7.481706465993609, 1.441202734197889, 16.456054483141216, 34.02885818481445, 41.7649199622018, 52.71385656084333, 53.02666098730904, 53.25659772327968, 50.45766530718122, 49.04825448989868, 43.24198538916451, 41.47843878609793, 39.394003527505056, 37.87665939331055, 36.86178813661848, 37.247847420828684, 38.201143741607666, 38.93196569170271, 39.25063787187849, 40.48968928200858, 40.97944000789097, 41.787244524274556, 39.54710360935756, 38.72672980172293, 37.7666311945234, 36.23779126576015, 37.46449225289481, 41.63719122750418, 39.912888050079346, 39.868888582502095, 41.7965863772801, 41.35521248408726, 41.181879247937886, 41.697032587868826, 36.937349796295166, 37.7438063621521, 35.292447158268516, 35.19425868988037, 35.4240460395813, 35.81291587012154, 35.84549944741385, 35.6324850491115, 35.01318168640137, 37.268212590898784, 38.644702843257356, 42.571307046072825, 44.54778119495937, 43.75250775473458, 43.65709509168352, 44.400590556008474, 44.40832042694092, 45.72280148097447, 50.87112133843558, 44.3095691544669, 39.35437100274222, 42.46166099820818, 40.59849112374442, 45.4456239427839, 44.78106696265084, 44.758092744009836, 46.544627462114605, 48.35097844260079, 47.35629170281546, 46.253303391592844, 37.673897062029155, 35.56217622756958, 36.175931453704834, 35.41035461425781, 33.62112052100045, 36.72300481796265, 36.43446697507586, 38.80268750871931, 40.514042718069895, 45.69911854607718, 47.433579989842, 49.5773354939052, 47.32486152648926, 47.4787780216762, 45.103703090122764, 43.60758917672293, 37.58001300266811, 34.15017720631191, 35.301201888493125, 35.0322927066258, 34.79703712463379, 35.11343724387032, 34.63249683380127, 33.48019715717861, 33.95006561279297, 34.85552706037249, 36.36238636289324, 36.86128786631993, 41.08693906239101, 45.04628665106637, 47.67625624792916, 47.69896990912301, 48.38826942443848, 42.11515433447701, 49.215567111968994, 48.514796120779856, 48.48164973940168, 47.0605068887983, 49.13843863351004, 39.96751478740147, 25.82934982436044, 13.389995966638837, 11.624622855867658, 17.6395446232387, 11.431027804102216, 12.602569648197719, 10.496800814356122, 5.937222668102809, 0.45528752516422955, 1.7934913848127638, 1.2805679823671068, 19.05000809260777, 43.674708775111604, 38.87884323937552, 44.9280561038426, 48.776500020708355, 20.199834210532053, 1.104960405400821, 0.19010404337729725, 0.2156771325639316, 0.1188558850969587, 0.08940578930612121, 0.16354063233094557, 0.2040399041559015, 0.10944576468318701, 0.11265689094683953, 0.11197555357856409, 0.2843838243612221, 0.15220375066357, 0.11698802746832371, 0.07707188185304403, 0.09666059073060751, 0.14179646197174275, 0.10613254604062863, 0.13983313446598394, 0.1301173543823617], [0.05438941969935383, 0.056084328929760625, 0.017821438976430466, 0.0077263781734343085, 0.04913967568427324, 0.003429201481464718, 0.025429288956469724, 0.05036383767479232, 0.01597899926959404, 0.02515190892985889, 0.03375831479206681, 0.03080317604222468, 0.036349880908216746, 0.04566607850470713, 0.0164842381408172, 0.035568507122141976, 0.02484416276482599, 0.007238293515651354, 0.06289134134671517, 0.02471975845816944, 0.04707170111526336, 0.04517649852537683, 0.06471336393484048, 1.3295201041868754, 17.059604542596, 37.75523962293352, 41.8127235685076, 34.06682661601475, 29.060651268277848, 28.42959155355181, 35.39530481610979, 19.796956811632427, 1.3721321033579963, 0.19662030014608586, 1.1835030594042368, 2.729078701564244, 3.36420984353338, 0.9124879219702312, 0.954692582998957, 10.823873366628375, 26.505760431289673, 41.948533058166504, 48.68551336015974, 48.2738812310355, 48.381828444344656, 44.59730448041643, 42.28235925946917, 38.00736543110439, 37.36716883523123, 36.666724409375874, 35.318249293736045, 37.181766578129356, 37.01553440093994, 38.280617237091064, 38.81780678885323, 40.21286262784685, 41.29097638811384, 38.219038827078684, 36.42968314034598, 34.70931611742292, 35.01965740748814, 32.95274897984096, 33.88539525440761, 33.07610729762486, 33.9402756009783, 33.341945375714985, 33.05233403614589, 33.599775654929026, 34.47824682508196, 34.680856295994346, 33.791292326790945, 34.75157853535244, 32.99942697797503, 32.38018267495291, 33.00893211364746, 31.786622388022288, 31.187249932970317, 31.939260414668492, 32.15317807878767, 32.525424344199045, 33.22031715938023, 34.44367258889334, 36.14239249910627, 37.68349947248186, 37.694359506879536, 36.958076272692, 39.923727239881245, 42.991954462868826, 44.9405072757176, 38.72708763395037, 35.80059323992048, 45.764045987810405, 44.41543538229806, 44.590265955243794, 45.45815849304199, 44.12602206638881, 45.3265700340271, 44.30051565170288, 43.00216136659895, 40.68620865685599, 34.23762723377773, 31.98268665586199, 32.37274462836129, 32.69403975350516, 31.90027059827532, 33.320669991629465, 38.142900466918945, 40.42466803959438, 41.92289767946516, 42.35802166802542, 45.85716921942574, 44.33401986530849, 44.688433579036165, 42.50078977857317, 41.8264810017177, 37.96361262457711, 32.50929062707083, 31.305880001613072, 32.39336340767996, 30.720463003431046, 31.78249863215855, 31.492463452475413, 32.815487316676546, 32.99296862738473, 35.13465009416853, 34.11226783479963, 33.52175433295113, 32.75262696402413, 36.87884249005999, 39.51574638911656, 42.25806835719517, 44.94647577830723, 46.00137908118111, 41.73729739870344, 40.88619865689959, 40.39934185573033, 44.04798337391445, 40.24321583339146, 41.45593009676252, 24.437366826193674, 13.513667821884155, 2.7414039373397827, 0.20843679750604288, 5.078561680657523, 4.709290112767901, 4.573864945343562, 1.2471659289939063, 0.40712334534951616, 0.06368180071668965, 0.26456316507288385, 1.5688649181808745, 14.831970385142736, 36.990489619118826, 43.41476624352591, 42.086510385785786, 27.652247939790996, 8.142561793327332, 0.17328311955290182, 0.026369283873853937, 0.0032892828956911607, 0.04650608450174332, 0.05647873080202511, 0.015214972231271011, 0.014037367921056492, 0.026216019776516726, 0.006608234310988337, 0.025518748709665875, 0.09182937390037946, 0.014400796366057225, 0.02531527810996132, 0.06371042810912643, 0.031186809563743215, 0.011682557939950908, 0.020274638231577616, 0.012996079599750894, 0.01892252658892955, 0.01545810659549066, 0.048804136724876504, 0.02003995841369033, 0.044747287806655676, 0.027765122009441257, 0.02485235098616353, 0.01945328007319144, 0.09917223559958593, 0.020300037493663173, 0.02167962641189141, 0.025835224227713685, 0.035499659566474814, 0.0545671008793371, 0.04134171037003398, 0.02569440785529358, 0.034659799454467635, 0.016300616386745657, 0.008609363426720458, 0.08660745660641364, 0.006558334845716932, 0.039570859500340054, 0.0855530538995351, 0.011985282945845808, 2.073327043226787, 21.145398923328944, 43.12592267990112, 49.043446336473735, 41.4464110646929, 38.49842936652047, 38.95030893598284, 40.01745843887329, 21.997242859431676, 1.132441399352891, 0.10870163568428584, 2.2323387392929623, 6.929102335657392, 6.7985144172395975, 3.2121469974517822, 3.0028607419558933, 16.31928266797747, 32.74242353439331, 45.41594818660191, 50.03646550859724, 50.40907308033535, 51.123983655657085, 46.046563216618125, 42.84600060326712, 40.32239750453404, 38.29651124136788, 37.657329082489014, 36.894969258989605, 38.0643823487418, 37.448223045894075, 40.645113536289756, 40.45078979219709, 42.18143320083618, 42.435202257973806, 40.51946578707014, 38.71821131025042, 36.22264419283186, 35.687070097242085, 34.716872283390586, 35.551656654902864, 35.87542533874512, 35.82531145640782, 36.19038370677403, 35.70303358350481, 36.193631989615305, 36.814099175589426, 37.324979373386924, 35.5404109954834, 35.14634043829781, 34.571248463221956, 33.69997215270996, 35.089163712092805, 33.85605648585728, 32.944904463631765, 33.03696462086269, 33.98714814867292, 33.97876862117222, 34.77547686440604, 36.191050733838765, 38.2476931980678, 38.736095973423545, 39.12355184555054, 38.657094955444336, 41.70565182822091, 44.49522154671805, 46.20956448146275, 42.610821451459614, 38.033188411167686, 44.81196560178484, 44.890080724443706, 46.69278737476894, 46.93754461833409, 46.00992883954729, 46.70375510624477, 47.168798037937705, 43.55794429779053, 40.728568349565776, 36.073330879211426, 33.59074647086007, 34.07335444859096, 33.357627459934776, 33.73042958123343, 34.037932532174246, 38.15858255113874, 40.784185205187114, 43.756742681775776, 45.16784191131592, 46.765541962214876, 46.18926879337856, 45.968899726867676, 44.36223302568708, 41.687325954437256, 39.87337711879185, 34.7252448626927, 33.22024072919573, 33.59485285622733, 32.25629281997681, 32.87081582205636, 33.93801743643624, 34.61421264920916, 35.21749346596854, 35.57895960126604, 34.649978501456125, 34.85101767948696, 34.700314726148335, 37.823814868927, 42.419270038604736, 43.85791540145874, 45.87075989586966, 46.54042380196707, 43.70590966088431, 43.06136001859392, 44.9537227494376, 44.902854987553184, 43.28704793112618, 43.51968404224941, 32.581006458827424, 19.467217888150895, 3.9324163709368025, 1.1829442722456796, 4.626404617513929, 2.039752696241651, 0.44625079578586985, 0.15773947004761013, 0.19425008233104432, 0.3906664012798241, 0.8899494856595993, 1.6324028287615096, 17.77086557660784, 41.510126045772004, 44.750543526240754, 42.89462062290737, 34.04287617547171, 10.292757408959524, 0.23334292748144694, 0.02747664284626288, 0.02390453764902694, 0.025239750377035568, 0.032019433099776506, 0.007366311869450978, 0.01250177956119712, 0.013067109493671783, 0.06837791443935462, 0.02540632393876357, 0.059981851040252616, 0.028001335316470692, 0.0362338853467788, 0.014582608127966523, 0.010546049103140831, 0.02049988471636815, 0.07815885424081769, 0.04301727117438402, 0.05218813335523009, 0.0917254291208727, 0.09874424285122327, 0.13265774878008024, 0.09415632153728179, 0.12874421663582325, 0.1376694491399186, 0.09990983709160771, 0.16048742830753326, 0.04512706046391811, 0.07932935428938695, 0.1998912189155817, 0.14325983130506106, 0.14106987310307367, 0.13783201255968638, 0.11150400566735438, 0.10745399977479662, 0.14952292665839195, 0.1155113045658384, 0.19271058136863367, 0.09874370002320834, 0.11955654035721507, 0.21387387146907194, 0.14292147303266184, 2.012793685708727, 24.855915887015207, 50.809667995997835, 54.29497820990426, 44.66928086962019, 41.56577416828701, 40.3909866469247, 45.449285643441335, 25.310705014637538, 2.00523795400347, 0.38199746502297266, 5.092072018555232, 8.6518543277468, 10.667597958019801, 3.3687893577984402, 2.2473173184054236, 17.307174069540842, 36.62500047683716, 47.66665383747646, 52.45750972202846, 52.43971538543701, 53.84013523374285, 48.44739859444754, 46.97446039744786, 41.483201776232036, 40.44203158787319, 39.01746327536446, 39.122846603393555, 40.844186374119346, 39.63978910446167, 43.003745555877686, 41.571311882564, 44.46512542452131, 45.680584226335796, 43.70972769601004, 40.933435985020225, 39.24301222392491, 37.30588224955967, 35.7395533152989, 37.298604011535645, 37.29678010940552, 37.38738809313093, 37.01318938391549, 38.0802971976144, 37.5769488470895, 38.132384368351524, 38.57606158937727, 38.18579864501953, 37.030903816223145, 36.20294604982649, 35.1807861328125, 37.2695049558367, 34.539203371320454, 34.64139747619629, 36.43024941853115, 35.75564534323556, 35.782288210732595, 35.75019448144095, 37.86444446018764, 40.29589360100882, 41.455349922180176, 40.71568986347744, 40.77477387019566, 44.08396462031773, 47.30787665503365, 47.163920402526855, 44.00075299399239, 41.16966431481497, 46.425424167088096, 46.98256547110421, 46.96525056021554, 49.497260979243684, 47.83428955078125, 47.77657781328474, 48.16293587003435, 45.54182175227574, 43.16310249056135, 37.819031034197124, 34.6984942981175, 34.933687346322195, 35.51315321241106, 34.45620713915144, 36.150480202266145, 40.86083773204258, 43.29239109584263, 45.84671218054635, 46.06350292478289, 50.23272780009678, 47.482634271894185, 48.2790333202907, 46.48484516143799, 43.06125232151577, 41.48718656812395, 36.42979431152344, 34.267754622868125, 36.57646383558001, 33.69068935939244, 34.200013160705566, 36.29618740081787, 36.125803674970356, 37.75580937521798, 39.311604840414866, 37.551459380558555, 37.44841064725603, 36.89709193365914, 39.38645083563668, 45.04298625673567, 45.96025269372122, 48.84416505268642, 47.854015486580984, 44.10115098953247, 42.441830839429585, 46.45447111129761, 46.33613634109497, 45.909343242645264, 45.424296447208945, 37.86257539476667, 20.30299585206168, 4.570655311856951, 0.7606076832328523, 10.360172305788312, 10.12735641002655, 11.976761903081622, 4.856101206370762, 0.967223984854562, 1.114806654197829, 1.9877293620790755, 3.070957430771419, 21.300053664616176, 45.91503381729126, 50.04081508091518, 52.87060792105538, 39.79667942864554, 11.904095905167715, 0.4509462852563177, 0.1908107783113207, 0.11439896853906767, 0.09992713973458324, 0.1916837136128119, 0.10972297337970563, 0.13911683218819754, 0.1319856055613075, 0.12877202300088747, 0.0871907863765955, 0.1737154684960842, 0.07476609093802315, 0.1241202854684421, 0.13733923328774317, 0.10604110666151557, 0.14085724736962998, 0.1623813688222851, 0.04786279830815537, 0.09843730075018746], [0.014798238075205257, 0.016958535815189992, 0.05816963328314679, 0.03237072764230626, 0.06185115394847734, 0.025902098942814127, 0.025896974307085787, 0.04699801221223814, 0.011953637768913592, 0.044529155761535676, 0.09582118184438773, 0.050238997409386296, 0.006907438992389611, 0.0435583689250052, 0.012740343143897397, 0.045587181845413785, 0.05665479028331382, 0.004201374756771007, 0.04936254390382341, 0.027715838314699273, 0.04072558021705065, 0.06350914069584437, 0.05959701990442617, 0.07214073717061963, 7.703120367867606, 30.23145920889718, 35.74879789352417, 36.3954667363848, 31.234845093318395, 16.751863615853445, 33.86431441988264, 23.014796120779856, 1.9939608105591364, 0.12600632783557686, 1.3078879735299518, 6.453241058758326, 6.8438505445207864, 2.83790551338877, 1.32361815231187, 2.266600523676191, 14.436378172465734, 28.931147268840245, 45.07223817280361, 47.04793412344796, 46.53035238810948, 44.813674858638215, 42.44349840709141, 40.37650660106114, 38.437413760593955, 38.38328381947109, 39.30662298202515, 42.81279863630022, 43.261249269757954, 45.236570017678396, 44.817482471466064, 45.241972242082866, 43.244528429848806, 40.95143876756941, 37.137107031685964, 33.79663896560669, 34.39648389816284, 32.096741335732595, 34.73900229590279, 33.1512451171875, 33.4881945337568, 34.20294877461025, 32.46883126667568, 32.07769979749407, 34.41202354431152, 32.782163756234304, 33.09089306422642, 33.54134130477905, 35.007494585854666, 32.82221664701189, 33.23954977308001, 31.9410982131958, 32.140431608472554, 30.984438964298793, 32.37951912198748, 32.40105506352016, 33.18090697697231, 32.721314907073975, 34.74204560688564, 32.82235908508301, 35.30417571749006, 35.53637409210205, 41.717863287244526, 42.87536021641323, 46.571450982775005, 39.34932313646589, 36.820863246917725, 46.18207393373762, 43.17488316127232, 44.65762874058315, 42.626374994005474, 44.38898011616298, 43.73878506251744, 45.10605158124651, 43.14586053575788, 39.945728710719514, 33.47307177952358, 31.15117835998535, 32.24796887806484, 32.91785512651716, 33.94583068575178, 36.07973711831229, 39.18238919121878, 41.37703330176217, 40.60204512732369, 42.09767961502075, 42.61243690763201, 43.3036402293614, 43.05716678074428, 43.67968715940203, 38.487802096775596, 33.69223533357893, 31.723723820277623, 32.24928208759853, 31.979379313332693, 30.010624613080704, 34.392266341618125, 35.07547228676932, 37.84987408774239, 37.19722979409354, 36.05558170591082, 34.140988213675364, 31.425163200923375, 32.523322514125276, 34.87515572139195, 37.43982267379761, 42.765234742845806, 43.38153995786394, 44.2542337008885, 44.244190079825266, 43.315101282937185, 39.80151884896414, 47.08421414239066, 34.514283657073975, 30.170367172786168, 11.008190836225237, 2.76995603953089, 0.9933587653296334, 3.551649442740849, 4.778680469308581, 2.134179583617619, 0.3700492504451956, 0.16885474217789515, 0.13420098168509348, 0.5299082196184567, 0.24972186716539518, 3.4697062969207764, 19.673593282699585, 29.566516603742325, 41.490420954568044, 49.5143153326852, 26.174847262246267, 3.8493523938315253, 0.07342696815196957, 0.07657855296773569, 0.02528539882041514, 0.044943679589778185, 0.034229676106146405, 0.07049470621028117, 0.057686129584908485, 0.02585950051434338, 0.037140089220234325, 0.07678429157074008, 0.026291908829339912, 0.02887166504349027, 0.031762047803827693, 0.04591987435040729, 0.01537838381981211, 0.05201229100514736, 0.020558588173506514, 0.05559688633573907, 0.05695257894694805, 0.022727086009191613, 0.007535469801431256, 0.07810343828584466, 0.014961144155157464, 0.03502495986010347, 0.03214912489056587, 0.04374316115198391, 0.03580549565543022, 0.09780158129121576, 0.06479875756693737, 0.0480890456320984, 0.02000128531030246, 0.057487902364560535, 0.045576294751039574, 0.03644043140645538, 0.03357984311878681, 0.061625351064971516, 0.03270009532570839, 0.046991318464279175, 0.014308597027723278, 0.056089319554822784, 0.053788454804037295, 0.08020757537867342, 0.28618310924087254, 11.913703526769366, 38.24706091199602, 43.725114481789724, 41.397037165505544, 34.40943881443569, 22.82550460951669, 40.241548265729634, 26.147792713982717, 2.489940596478326, 0.03523287316784263, 1.1034289790051324, 5.778890592711313, 5.677775629929133, 3.9141591106142317, 1.6343299767800739, 2.8714323086397986, 18.584437097821915, 33.180104460035054, 47.74834380831037, 49.719370569501606, 48.99271753856114, 47.51682983125959, 44.26625061035156, 41.69330835342407, 39.885248116084504, 39.08322450092861, 40.391365323747905, 44.19857863017491, 45.21038225718907, 46.278855391911094, 45.95188011441912, 46.70918164934431, 46.62126956667219, 41.37482377461025, 38.122903551374165, 35.16852951049805, 35.56810998916626, 33.9777055467878, 36.778253419058665, 35.5842193875994, 35.27029630116054, 35.3472614969526, 33.46243756158011, 34.260243620191304, 35.53993156978062, 33.963388783591135, 35.057382651737754, 36.12920134408133, 35.711628505161826, 33.567042691367014, 34.316315582820344, 33.738659722464426, 33.15048428944179, 33.72728899547032, 34.20073577335903, 33.0769167627607, 34.457343169621055, 34.10616036823818, 36.57084969111851, 35.21834462029593, 36.10931212561471, 37.56127371106829, 43.324081829616, 45.68549312864031, 48.88226202556065, 42.2103967666626, 37.32827629361834, 46.53254107066563, 46.34623902184622, 45.398452622549875, 43.98962892804827, 46.368612221309114, 47.442115851810996, 46.01208278111049, 44.24444368907383, 41.185787609645296, 35.828987053462434, 33.60308299745832, 34.509062085832866, 33.60568857192993, 35.32429075241089, 36.42518070765904, 40.38772446768624, 43.02126196452549, 43.890460763658794, 44.88821513312203, 43.999408517565044, 45.421715191432405, 44.75741529464722, 44.11867434637887, 40.55310549054827, 34.78261613845825, 33.35657828194754, 32.56101996558053, 33.97688218525478, 32.0045804296221, 34.811475481305806, 36.16549525942121, 39.0703911781311, 38.21855592727661, 37.147174971444265, 36.798695019313264, 33.0698504447937, 34.389462743486675, 36.619980403355186, 40.16242218017578, 45.146340710776194, 46.047900744846885, 46.15477793557303, 44.85374164581299, 43.35592542375837, 40.695338589804514, 48.343453543526785, 38.375751972198486, 35.296015058244976, 16.97994691984994, 4.534731388092041, 1.734019364629473, 1.8574458616120475, 4.965606118951525, 1.655438386968204, 0.762113379580634, 0.2231736553034612, 0.2007743322423526, 0.7880373799375125, 0.2670811542442867, 4.408228576183319, 22.632275206702097, 35.02450377600533, 46.96822091511318, 55.94327851704189, 31.401052951812744, 5.27137028319495, 0.043082539457827806, 0.061130889026182036, 0.05881032640380519, 0.029053739737719297, 0.021039642360327498, 0.05333978030830622, 0.05697386459048305, 0.056927608858261786, 0.031687520910054445, 0.013998735529769744, 0.02994219652776207, 0.03601764980703592, 0.03218211865584765, 0.06003749769713197, 0.0038713743394639876, 0.030074938333460262, 0.0683018167370132, 0.036227697107408724, 0.05283235825066056, 0.09509886774633612, 0.10268762375095061, 0.16277247640703404, 0.08846175032002584, 0.15403200898851666, 0.09454838585640703, 0.11067878494837455, 0.1362479454172509, 0.1800420611564602, 0.18171029378260883, 0.18916465235607965, 0.10541748548192637, 0.11944189508046422, 0.1151545172823327, 0.13167472795716353, 0.14147038518318109, 0.2135635366929429, 0.0759758578081216, 0.2077762165239879, 0.0773534874564835, 0.09773511200078897, 0.1387298908084631, 0.1316662598401308, 0.43105009144970347, 12.31707685334342, 41.95104135785784, 50.689446789877756, 49.50090878350394, 42.45322935921805, 29.53205701283046, 45.627753598349436, 30.7830627986363, 3.228288097040994, 0.26201743738991873, 3.3257619866303036, 11.62152830192021, 10.401937927518572, 6.0425421595573425, 2.3483030881200517, 3.1061641701630185, 18.8228280544281, 35.37471035548619, 50.17682259423392, 51.29449939727783, 51.00963715144566, 48.996497358594624, 46.53043576649257, 43.83140802383423, 42.16623054231916, 42.14602518081665, 43.10238218307495, 46.893920353480745, 46.87626150676182, 49.368375369480674, 48.40452126094273, 49.52346611022949, 47.93667125701904, 44.16708244596209, 40.72150897979736, 36.42940868650164, 37.67761434827532, 36.57837806429182, 39.03240885053362, 36.91094316755022, 36.34067324229649, 36.646539892469136, 34.75261034284319, 36.10408360617501, 38.00096614020211, 35.55951506750924, 36.482683999197825, 37.731643540518625, 38.05007948194231, 35.6141939163208, 36.55302061353411, 34.920214789254324, 34.87433235985892, 33.750423022678916, 34.620796067374094, 34.61525140489851, 35.89462668555123, 36.736911637442454, 38.08935417447771, 37.335339137486045, 38.16621862139021, 39.35557304109846, 46.24519484383719, 47.017858845846995, 49.22744853155953, 44.72650970731463, 40.801448004586355, 47.731032371520996, 47.5455641065325, 48.26492847715105, 45.85819755281721, 48.24543530600411, 49.59885059084211, 47.93481261389596, 45.82529435838972, 42.60040610177176, 36.835544790540425, 35.0533561706543, 36.11350883756365, 36.12326758248465, 37.214103494371685, 38.248057978493826, 41.5348790032523, 44.80522584915161, 45.65058537891933, 45.81321838923863, 45.57148361206055, 46.20862994875227, 45.78590849467686, 47.22453301293509, 41.120071547372, 36.08669573920113, 35.1152229309082, 36.432132380349294, 35.927988461085725, 34.13950824737549, 37.12426676068987, 38.512086050851, 42.619173186165945, 40.114490032196045, 39.801650864737375, 37.36878776550293, 35.23898771830967, 36.92646891730172, 38.91663449151175, 42.02443170547485, 46.97297695704869, 47.78305353437151, 47.931227343423025, 45.435052258627756, 43.83887733731951, 41.537849358149934, 49.13449553080967, 40.02646677834647, 37.99024159567696, 18.249049288885935, 4.913457282951899, 1.9136357264859336, 6.675671134676252, 13.841263226100377, 6.588681425367083, 3.7746531793049405, 0.8626683066998209, 0.4032523030681269, 2.2045676580497195, 1.1715404327426637, 6.860568344593048, 27.520054987498693, 41.14721815926688, 49.393340247017996, 59.79489081246512, 37.1945721081325, 5.968503023896899, 0.11054026880966765, 0.19707358867994376, 0.119162881480796, 0.09869554439293486, 0.1678426664854799, 0.15212029085627624, 0.09969043279332773, 0.1329020620988948, 0.18924124538898468, 0.16546939526285442, 0.1030752436657037, 0.08541292284748384, 0.14037886661078247, 0.11638000580881323, 0.07735477667301893, 0.12659146929425852, 0.26968770580632345, 0.11932921755526747, 0.2096641452184745], [0.027953198345910226, 0.035972852925104756, 0.04703620355576277, 0.020690551360270808, 0.029945042982165302, 0.06769583068255867, 0.030874948083822216, 0.03143185230770281, 0.02646672150253185, 0.08055049340639796, 0.07568089185016495, 0.04151744754718883, 0.07696655286209923, 0.034198470280638764, 0.019908867144425, 0.013495199781443392, 0.03374695611585464, 0.023174788503508483, 0.025343735868643438, 0.04573563512946878, 0.0440385579796774, 0.028541835956275463, 0.022024668254224316, 0.035972886851855686, 1.4762443453073502, 18.952974762235367, 33.83393342154366, 34.02817031315395, 35.69184350967407, 22.07486465999058, 18.462669917515345, 23.05591208594186, 3.1973625336374556, 0.10384196109537568, 0.9595424256154469, 6.416734789099012, 2.498644083738327, 1.0307037042719978, 0.7340370661446026, 0.47351571704660145, 6.124419731753213, 21.89207492555891, 40.59689998626709, 50.81301007952009, 50.91465875080654, 45.86341912405831, 44.78312710353306, 41.740302494594026, 42.91106006077358, 42.403970105307444, 44.671608516148154, 45.61741815294538, 46.31000764029366, 45.91560009547642, 47.43314225333077, 44.617065157209126, 45.42554017475673, 40.59760522842407, 34.599666595458984, 33.26800959450858, 33.13067150115967, 34.10797037397112, 33.038750307900564, 33.561751638139995, 32.93523951939174, 32.659503732408794, 33.41821575164795, 32.483766419546946, 33.3502311025347, 34.22479738507952, 34.260365213666645, 33.40200907843453, 33.56954056876046, 33.91314288548061, 33.555824824741904, 32.60799673625401, 33.31781080790928, 31.418982778276714, 33.185395513262065, 32.40526219776699, 32.82216453552246, 32.88705723626273, 33.83679607936314, 34.331083978925435, 36.945152623312815, 36.85671942574637, 41.16547802516392, 42.16990613937378, 46.13405493327549, 39.37683800288609, 34.63693673270089, 47.42216757365635, 41.938656193869456, 43.373573848179404, 42.088309969220845, 42.39849145071847, 40.53228868756975, 40.037768023354666, 37.79651539666312, 35.200136865888325, 31.846210139138357, 32.149745668683735, 31.141228539603098, 32.51346302032471, 33.984115259987966, 36.63395323072161, 39.18137475422451, 41.54349476950509, 40.91524907520839, 41.407233646937776, 41.71538972854614, 42.08916112354824, 40.25369371686663, 37.66286679676601, 33.60278769901821, 31.70450857707432, 32.55206373759678, 31.373221942356654, 32.955083574567524, 33.17364610944475, 35.40633160727364, 40.50423533575875, 40.71025289808001, 39.51835196358817, 36.07079478672573, 36.08183894838606, 34.306918144226074, 32.275806835719514, 33.48648527690342, 37.52128335407802, 40.94541467939104, 43.27860934393746, 44.5372234072004, 44.476405824933735, 45.74740852628435, 46.99504790987287, 40.80043704169137, 35.19855615070888, 16.238113812037877, 5.853553763457707, 2.124195239373616, 0.165480658944164, 0.850623930139201, 0.7011134613837514, 0.24525040281670435, 0.1459354441612959, 0.021104612088363086, 0.21530072204768658, 0.022185277493138398, 1.0374587646552493, 8.165969405855451, 20.407580137252808, 31.04253285271781, 32.71825075149536, 34.629825251443044, 12.360383238111224, 0.7581993724618639, 0.05830626987985202, 0.03502509895978229, 0.03852638376078435, 0.059718728730721135, 0.018408568542716757, 0.020589302061125636, 0.03547370220933642, 0.060169486328959465, 0.022401348488139253, 0.015421667568651693, 0.016696814680472016, 0.026040102787581936, 0.012264295697345265, 0.0384791170113853, 0.05726191627659968, 0.02808352795961712, 0.052287772830043516, 0.045588922287736616, 0.05215069857825126, 0.04959650956360357, 0.01650899279463504, 0.02419984626716801, 0.004590925951820931, 0.017448533093556762, 0.0034616102223351064, 0.02777228394656309, 0.04178208977516208, 0.026867452410182784, 0.07172077149152756, 0.12715564402086393, 0.02648033800401858, 0.0876134390543614, 0.04416661110839673, 0.04498335692499365, 0.02062237385793456, 0.022946342726105025, 0.005364541538126234, 0.04525258265701788, 0.043863930207278044, 0.05847681287143912, 0.07360900552677256, 0.024317354961697544, 0.03281092045030423, 3.324549525976181, 25.6985274042402, 42.15398434230259, 42.32353775841849, 41.10585553305489, 24.524997506822857, 29.920822620391846, 27.53627555710929, 3.84029107434409, 0.0548867485485971, 1.1393703818321228, 4.0921958429472785, 1.9076068614210402, 1.6775373497179575, 2.007869149957384, 1.8730202487536838, 7.417479055268424, 25.943103994641984, 43.41836193629673, 51.98543173926217, 51.51744277136666, 49.417530400412424, 45.551062856401714, 44.92840698787144, 43.446946825299946, 43.734015124184744, 45.910972595214844, 48.11757802963257, 47.804811818259104, 47.36834682737078, 49.06424576895577, 47.03638621738979, 46.93509885243007, 42.466733183179585, 36.33118895121983, 35.33036000388009, 34.7515298979623, 36.807727677481516, 36.35559797286987, 35.24528626033238, 34.740103585379465, 33.431830746786936, 34.54987233025687, 34.53044516699654, 34.464392117091585, 33.82066583633423, 35.2793949672154, 35.70506593159267, 34.69943577902657, 35.44230243137905, 35.24468524115426, 35.00305468695504, 34.83126047679356, 33.22962079729353, 34.823693888528005, 34.00221184321812, 35.16837665012905, 34.50679349899292, 35.004440852573936, 36.771357331957134, 38.41708333151681, 38.61660085405622, 41.67858164651053, 43.711833000183105, 47.304767336164204, 40.76267358234951, 36.207250458853586, 48.70122671127319, 43.506986209324424, 44.878230571746826, 43.47998898369925, 43.64931658336094, 43.23820209503174, 43.93193803514753, 39.5328563281468, 37.4752584866115, 34.30842590332031, 33.871874059949604, 32.42555441175188, 33.86824362618582, 35.117112840924946, 38.06509106499808, 40.31095034735543, 42.965860503060476, 43.859256403786794, 43.282403060368125, 43.02245705468314, 44.039857455662315, 42.40212535858154, 39.36541516440255, 34.67639207839966, 33.44301387241909, 32.07665409360613, 32.63069650105068, 34.60199771608625, 33.16439458302089, 37.22077029091971, 41.82057850701468, 41.154256684439524, 41.216950280325754, 37.856582573481965, 37.87090628487723, 36.10633134841919, 33.48293127332415, 34.560996396201, 40.12034041540963, 42.781774929591585, 45.96866001401629, 45.79849515642439, 45.53956011363438, 45.60939645767212, 47.109217235020225, 42.300785882132395, 36.60467004776001, 20.762563603264944, 7.442009670393808, 2.549097776412964, 0.5648042985371181, 1.962789237499237, 1.468397549220494, 0.5137334104095186, 0.09185111416237694, 0.04416489102212446, 0.35844225755759646, 0.19340612047484942, 1.6058218436581748, 9.027148246765137, 26.304749046053203, 36.45343903132847, 37.805002621241975, 43.22829048974173, 19.69976714679173, 1.6307527401617594, 0.022960305280451263, 0.07158291353178875, 0.02648435832400407, 0.02469845924393407, 0.06501255038061313, 0.021821937257690088, 0.052113569142030816, 0.013270641161528016, 0.01795600095231618, 0.02057605196854898, 0.03812470460044486, 0.011531463458335825, 0.026368973444082906, 0.03608548973820039, 0.06750158646277019, 0.03369030183447259, 0.04086128043543015, 0.017381213938019106, 0.01574980540733252, 0.14013035994555267, 0.12661595083773136, 0.23695191953863415, 0.05540923408365675, 0.20633833296597004, 0.10738831079964127, 0.10944490972906351, 0.1376085981194462, 0.07419682719877788, 0.2592409535178116, 0.17358418554067612, 0.10433701345963137, 0.2793120736522334, 0.06470100781215088, 0.09369371671761785, 0.09881213027983904, 0.17159161317561353, 0.11127153956996542, 0.1065393617110593, 0.15231245197355747, 0.11883574617760521, 0.1523640477763755, 0.1354010115776743, 0.08862330272261586, 3.534996564899172, 26.76455651010786, 48.12972695486886, 48.97819232940674, 47.922128677368164, 35.55827133996146, 29.275491305759974, 30.302994387490408, 5.80348721572331, 0.29805367227111546, 2.4828886091709137, 11.394647904804774, 13.205122641154698, 8.622123854500906, 2.324875065258571, 1.8318202538149697, 9.281219550541469, 26.88357741492135, 43.22150557381766, 53.936739512852256, 53.82252155031477, 51.030599866594585, 47.46034792491368, 46.10648448126656, 46.846551009586875, 46.226830754961284, 48.69260399682181, 51.208852427346365, 50.5104855128697, 49.36457123075213, 51.257020814078196, 49.524661200387136, 49.67063937868391, 44.53017793382917, 38.08470235552107, 37.426794801439556, 36.51819971629551, 39.278941358838765, 37.43791886738369, 38.14631898062569, 35.72561870302473, 35.588832991463796, 36.661217961992534, 36.04342583247593, 35.89247621808733, 36.583988734654014, 37.43966633932931, 37.271231583186555, 35.42970534733364, 37.602750982557026, 36.83519738061087, 36.22922761099679, 36.8101213318961, 35.08795472553798, 36.56586783272879, 35.83984361376081, 36.06324209485735, 36.46462563105992, 38.007566928863525, 37.634716170174734, 39.96633011954171, 40.74873202187674, 44.88369532993862, 46.02396420070103, 48.393421513693674, 44.387392452784944, 38.79209845406668, 49.421080929892405, 45.556510244097026, 46.42607729775565, 45.18049110685076, 45.69306666510445, 44.66540724890572, 43.94208935328892, 41.178234917776926, 38.9231345312936, 35.61336013248989, 35.20001527241298, 32.18647732053484, 35.409114360809326, 36.957662854875835, 39.12399305616106, 42.66777583530971, 44.83711460658482, 45.44532864434378, 44.433365208762034, 45.7593663760594, 44.55634832382202, 43.541372844151084, 40.95117473602295, 37.361203806740896, 34.337007318224224, 34.55651133401053, 34.82706723894392, 35.94825983047485, 36.356181621551514, 38.623514311654226, 44.524133001055034, 43.14482178006853, 42.69415814535958, 40.27695281164986, 39.92321654728481, 39.2049743107387, 35.51849985122681, 36.9986572265625, 42.6437211717878, 44.56283099310738, 48.135643345969065, 48.725357804979595, 45.91601003919329, 45.76659597669329, 46.47844934463501, 41.500582695007324, 37.86382607051304, 21.577832221984863, 8.745286754199437, 3.995224177837372, 1.4777509101799555, 5.8886260986328125, 2.5032110043934415, 1.438971711056573, 0.7885854191013745, 0.14529338718525, 0.8570075875946453, 0.274065830877849, 3.562277581010546, 12.61672226020268, 29.413767405918666, 41.42797401973179, 43.48507159096854, 48.122650214603965, 21.13996195793152, 1.8655984870025089, 0.12397934017436844, 0.21610836870968342, 0.09996243034090314, 0.21754144823976926, 0.09383198858371802, 0.1286489096071039, 0.1387989656733615, 0.14623100044471876, 0.1798847903098379, 0.07180020080081054, 0.11439634939389569, 0.11505203135311604, 0.08351649210921355, 0.12001250231904642, 0.12183097616902419, 0.15840957766132696, 0.16604245879820415, 0.1807663022939648, 0.15323407894798688], [0.02502176252060703, 0.02449299205493714, 0.010723183214265321, 0.03720578158806477, 0.032132700950439484, 0.0389850157579141, 0.022946120505886416, 0.032268855787281475, 0.028683011952255453, 0.04066734155640006, 0.0742634321962084, 0.03946640581956931, 0.08025134767272643, 0.026099042035639286, 0.051608125013964515, 0.006685790439535464, 0.041420294903218746, 0.023026065501783575, 0.054211677451218875, 0.06404692041022436, 0.11418170162609645, 0.03947823268494435, 0.027236032632312605, 0.04081010193164859, 0.1829631815531424, 7.036015135901315, 25.25896004268101, 30.681789330073766, 38.50382464272635, 29.37774794442313, 21.883606808526174, 22.95693325996399, 5.25562001977648, 0.03349501606343048, 0.6394578612276486, 2.197644646678652, 1.048971712589264, 1.5492517820426395, 1.2632490545511246, 0.8042508927839143, 0.8865331975477082, 9.78586721420288, 32.44628088814871, 48.16249465942383, 49.74868154525757, 50.13282312665667, 46.068894726889475, 44.817027364458355, 44.09461273465838, 44.25570324489048, 46.67324904033116, 48.67122091565813, 47.6889089175633, 48.85524048124041, 46.625122342790874, 45.73044449942452, 41.29344994681222, 36.708931241716655, 33.45988062449864, 34.07488652638027, 34.81247254780361, 33.74803631646292, 34.917901039123535, 38.574755328042166, 36.86572081702096, 34.81936168670654, 33.06613315854754, 32.88137708391462, 34.26312364850725, 33.144338607788086, 32.742711884634836, 33.66501923969814, 33.81164360046387, 34.27321590696062, 33.016213825770784, 31.80886009761265, 33.95575966153826, 35.986579145704, 32.86837353025164, 34.482248987470356, 33.681597641536165, 34.147359711783274, 34.88980252402169, 37.13132960455758, 38.74215132849557, 39.55868625640869, 42.591005189078196, 42.676464557647705, 44.9132216998509, 39.18904903956822, 36.650757449013845, 45.713529109954834, 41.955189432416645, 44.083085673195974, 36.24108818599156, 35.835796288081575, 34.13810818535941, 34.69787243434361, 34.71252965927124, 32.698333740234375, 33.398927552359446, 32.96842758996146, 32.715766770499094, 32.98431464603969, 34.786427225385395, 37.35440846851894, 38.61228949683053, 39.237283434186665, 38.3522983278547, 36.43696485246931, 35.47891596385411, 35.61816481181553, 34.19198451723371, 33.05706575938633, 32.64210196903774, 32.07316262381417, 31.376723834446498, 32.31141287939889, 33.218298707689556, 33.98773179735456, 36.16402224131993, 40.55136844090053, 42.745296886989046, 41.16393205097744, 39.452038356236045, 37.45469529288155, 36.82881546020508, 36.03935071400234, 35.501323904309956, 36.94989824295044, 40.52015713282994, 43.160483019692556, 43.75373411178589, 45.8837947164263, 43.513361181531636, 42.49871574129377, 39.60853958129883, 23.97285716874259, 7.301221796444484, 1.3040474653244019, 0.8586187011429242, 0.32398728068385807, 0.05915500862257821, 0.11429003652717386, 0.09690414409020118, 0.08287771924265794, 0.1143560851258891, 0.09782699242766414, 0.22866545990109444, 2.6683069339820316, 14.779582704816546, 16.886570078986033, 31.464014053344727, 36.072952202388215, 28.292203085763113, 2.496132961341313, 0.44597186361040386, 0.04316727491095662, 0.03925861804080861, 0.028274913850639547, 0.0665267894842795, 0.01662072885249342, 0.035242314982627115, 0.0271795802150986, 0.024292415407087122, 0.04157717898488045, 0.08673558437398501, 0.015732825068490844, 0.01870147853956691, 0.07160170895180532, 0.010926224640570581, 0.02674890894974981, 0.03734446736052632, 0.023039088285128986, 0.05540558695793152, 0.008114912414125033, 0.10015845232244049, 0.0034300063936305897, 0.0423378303114857, 0.0356586097872683, 0.026939687551930547, 0.03898253910509603, 0.05675348659445133, 0.00736694545152464, 0.024663127925513045, 0.061933480602289946, 0.03483820327424577, 0.03453168525759663, 0.04356297278510673, 0.03950414254463144, 0.03541643385376249, 0.02219653608543532, 0.021896096046215723, 0.08031308757407324, 0.034993129782378674, 0.0422794932632574, 0.04694667764540229, 0.02443581190891564, 0.03668022568204573, 0.09136846541826214, 0.43161414404000553, 11.035282731056213, 32.96566220692226, 38.42701578140259, 44.371880599430625, 33.76639345714024, 23.473024606704712, 25.95728005681719, 5.845299303531647, 0.04428533438060965, 0.3381578331547124, 0.7792856352669852, 1.1370490321091242, 0.8430968597531319, 2.1370570063591003, 1.0398213693073817, 2.495684802532196, 11.1152069909232, 35.398744174412315, 51.098695686885286, 50.96621091025216, 51.699464729854036, 48.25445406777518, 45.17435237339565, 46.3819214957101, 46.76800857271467, 48.76562261581421, 48.57523155212402, 48.89655099596296, 48.94583804266793, 48.17628683362688, 47.912036418914795, 42.98939752578735, 39.126525674547466, 35.48803200040545, 35.593161719185964, 36.722574029650005, 34.49484607151577, 36.59428596496582, 39.62920699800764, 37.21923473903111, 36.2132328578404, 33.54953670501709, 34.70636313302176, 34.89109836305891, 34.531914710998535, 34.62351976122175, 34.40964726039341, 35.68577773230416, 34.69636467524937, 34.936303343091694, 32.786221504211426, 36.6487911088126, 36.81981406893049, 34.353009019579204, 35.351093428475515, 35.69216660090855, 35.31503227778843, 36.66292721884591, 38.46891341890608, 39.88192687715803, 40.384351117270334, 45.180564062935964, 44.12715809685843, 46.798570224217, 39.973966189793174, 39.17344338553292, 46.228967326028005, 41.61446714401245, 45.04427514757429, 38.53835718972342, 37.23670598438808, 36.473053795950754, 37.51905645642962, 35.90748085294451, 34.90675960268293, 33.7193089893886, 32.97313846860613, 33.59391137531826, 34.22333826337542, 35.224309648786274, 39.09822218758719, 40.536919661930625, 40.56091526576451, 40.52875900268555, 39.92449501582554, 38.693711962018696, 37.16701555252075, 37.66401324953352, 34.166217122759136, 34.39565358843122, 33.837331090654644, 32.354022707257954, 32.76706184659685, 34.7752753666469, 35.926154136657715, 37.4462045942034, 42.4218304497855, 44.189650194985525, 43.44001252310616, 40.261288097926546, 39.11637088230678, 39.398769991738455, 37.64824431283133, 37.3825660433088, 39.96349178041731, 41.67979063306536, 44.64409364972796, 46.14616911751883, 47.303395066942485, 44.78211614063808, 43.7020777293614, 40.18374620165144, 27.754494156156266, 9.220210024288722, 2.0301795985017503, 1.3930235994713647, 0.857841859970774, 0.27489326362098965, 0.12949108013084956, 0.025679605613861765, 0.04298060992732644, 0.062360821957034726, 0.014153859661226826, 0.3590276161474841, 3.6024181927953447, 17.463850736618042, 22.371877568108694, 34.679980822971885, 39.060556003025596, 34.925662176949636, 5.737489751407078, 0.5843050692762647, 0.11882197191672665, 0.056543917661266666, 0.05673854186066559, 0.024243301346099803, 0.0514123914098101, 0.06284665981573717, 0.008470268836910171, 0.06175615904586656, 0.059495660343340466, 0.04771861979471786, 0.036760828856910975, 0.029941277112811804, 0.06862958986312151, 0.024957362761987106, 0.031483441325170655, 0.11450857908598014, 0.10905166475900582, 0.06326265606497015, 0.011030182990777706, 0.10450797035757985, 0.06187503838113376, 0.10224970403526511, 0.10713771424655404, 0.09326807848576989, 0.08965350887072937, 0.1077547739925129, 0.10775377654603549, 0.1739261807607753, 0.08799143055719988, 0.14473967546863215, 0.19083319710833685, 0.12560781064842427, 0.13845048365848406, 0.13106609561613627, 0.08777789558683123, 0.18787885563714163, 0.20937572712344782, 0.13341461388128145, 0.1231186320739133, 0.16401943378150463, 0.10453064021255289, 0.1394205308918442, 0.1042122987232038, 0.4677592973623957, 11.236160363469805, 37.78639187131609, 46.34309148788452, 49.43301098687308, 39.98028210231236, 31.50548437663487, 32.21647964205061, 9.191291621753148, 0.2422344232244151, 1.1749884762934275, 5.23369801895959, 6.603136718273163, 8.465691242899213, 6.533962624413626, 1.5634418491806303, 1.4052424409559794, 12.10874901499067, 36.36509268624442, 51.20638581684658, 51.680075781685964, 53.861236912863596, 50.26251472745623, 48.499968664986746, 48.73982742854527, 49.414785861968994, 52.10258184160505, 50.555113792419434, 50.00448989868164, 51.652901376996724, 50.36184617451259, 49.93329170772007, 45.53394596917288, 41.19021361214774, 36.35501085008894, 37.190615109034944, 38.81151519502912, 36.60054976599557, 38.847135135105674, 43.445102078574045, 38.7273725100926, 39.274748120989116, 34.15992900303432, 36.285438537597656, 36.21854475566319, 35.82984863008772, 36.433153765542166, 36.44059528623308, 37.85212530408587, 37.72124556132725, 36.8563094820295, 34.13728829792568, 37.619812284197124, 40.35638114384243, 34.74121182305472, 37.77318334579468, 37.207888330732075, 38.12782635007586, 38.93230267933437, 41.10646002633231, 41.95328215190342, 42.91692781448364, 45.57260227203369, 46.78265537534441, 48.3119330406189, 41.82342726843697, 42.95082112721035, 46.695955753326416, 44.751429421561106, 47.52663026537214, 39.720638343266074, 37.93153626578194, 38.08748858315604, 38.82536990301949, 38.62100601196289, 35.762666497911724, 36.18525941031319, 34.9188494682312, 34.96363755634853, 35.593359742845806, 37.54227038792202, 40.79556288037981, 42.65728752953665, 41.96173463548933, 42.41887746538435, 41.41069037573678, 40.08002349308559, 39.81353923252651, 39.13448831013271, 35.459527015686035, 36.605187688555034, 34.86196804046631, 34.198484557015554, 34.19777584075928, 35.92849915368216, 37.67053760801043, 38.9611029624939, 44.19340917042324, 46.224662917000906, 46.09227194104876, 42.21988453183855, 40.147691999162944, 41.01705755506243, 40.92805807931082, 39.082018988473074, 40.5006604875837, 44.06343616758074, 46.46727664130074, 46.82572725840977, 49.150344371795654, 43.60117251532418, 44.247747557503835, 41.494047914232524, 29.474901131221227, 10.153405206544058, 2.8386226977620805, 2.204580685922078, 1.8671959212848117, 0.9443273906196866, 0.3872267444218908, 0.21631665181900772, 0.15195837883012636, 0.3746774292417935, 0.357012828545911, 0.9710993426186698, 6.702620591436114, 23.244018929345266, 28.172417879104614, 41.74930388586861, 46.23812157767159, 40.382179805210654, 8.528975435665675, 0.7835957439882415, 0.18564153569085257, 0.16769174672663212, 0.09041832640234913, 0.12933619772749289, 0.1077581870236567, 0.11192877537437848, 0.13774838990398816, 0.1355147883296013, 0.1817145278411252, 0.09647085876869303, 0.1037473122456244, 0.10221156358186688, 0.17405677161046437, 0.09216690436005592, 0.13779387889163836, 0.1665989932204996, 0.22146199643611908, 0.254585931875876, 0.07590651831456594], [0.08033041057309934, 0.06112189165183476, 0.06534419115632772, 0.04658238576459033, 0.05297440616413951, 0.049876591855926175, 0.041866879511092386, 0.033991808870009015, 0.05532432221142309, 0.026259854835058962, 0.04384544012801988, 0.028378409100696445, 0.08776356492723737, 0.012665285296472055, 0.03984129981004766, 0.051242747477122715, 0.04406728036701679, 0.036172192942883284, 0.036891463811376264, 0.02695425569878093, 0.01540593573424433, 0.015010811222184981, 0.05612826407221811, 0.016079985636419485, 0.028654737398028374, 1.1866800146443504, 15.67899921962193, 26.88624552318028, 31.012467997414724, 35.54040404728481, 24.834895849227905, 22.6463748386928, 8.655767032078334, 0.18190534545906953, 0.10353685782424041, 0.99791048680033, 0.5062975351299558, 0.12128901667892933, 1.6128245421818324, 0.7955584792154176, 1.6565161177090235, 2.6653202942439487, 17.668692316327775, 39.35405485970633, 52.16685962677002, 49.21882234300886, 46.843163762773784, 47.00444882256644, 46.06813389914376, 49.30427128928048, 47.67485271181379, 47.456161635262625, 46.62298577172415, 46.43411636352539, 44.26079627445766, 41.58727189472744, 36.71861008235386, 34.055195331573486, 34.03871073041643, 35.478116921016145, 33.553622245788574, 35.791105474744526, 41.09978628158569, 42.10597576413836, 41.785365036555696, 42.94569335665022, 39.55662611552647, 36.79725674220494, 37.31875031335013, 36.78008426938738, 34.87509666170393, 35.174504961286274, 34.87456859861101, 32.615935053144185, 33.70022228785923, 32.97994770322527, 33.09282466343471, 35.36633430208479, 36.98854759761265, 37.484256403786794, 37.82071944645473, 34.578589235033306, 38.51086664199829, 39.25663764136178, 43.26977123532976, 42.12514931815011, 45.68035840988159, 43.83106756210327, 47.91569117137364, 39.357105118887766, 34.216278893607004, 47.05479894365583, 41.032909870147705, 40.99936049325125, 35.80950777871268, 34.63940681729998, 32.86615705490112, 31.923501900264196, 31.76353005000523, 32.52694252559117, 33.47399936403547, 31.967880044664653, 30.77197347368513, 33.546753951481406, 34.38285848072597, 36.51670585359846, 38.54470436913626, 37.59281505857195, 34.02104493549892, 33.05703101839338, 32.572199617113384, 35.405150413513184, 32.99608142035348, 32.76420613697597, 31.799914291926793, 31.570543834141322, 31.88120821544102, 30.926577840532573, 32.845809255327495, 32.30750799179077, 39.35159519740513, 43.26518889835903, 43.79504810060774, 44.25931978225708, 43.07934890474592, 40.400130476270405, 37.479865142277305, 37.33048234667097, 36.912068775721956, 36.76235246658325, 38.752201897757395, 43.489733832223074, 42.31822238649641, 45.52799483707973, 45.196763787950786, 42.685399941035676, 27.767339638301305, 10.283316544124059, 1.0155885496309824, 0.240554967629058, 0.5628504976630211, 0.16279245247798307, 0.11989552288183145, 0.030363709266696657, 0.0278004940399634, 0.03312172002292105, 0.14313647363867077, 0.0737597488665155, 0.36186299685920986, 10.353382178715297, 28.620326553072246, 26.808404854365758, 29.803408486502512, 34.92808015005929, 21.084788049970353, 2.4446218396936144, 0.07390661098595176, 0.054508607768054516, 0.08679045071559292, 0.040492900381130834, 0.0342019647359848, 0.01774446596391499, 0.03206194331869483, 0.06098746707929032, 0.010927473993173667, 0.0039015085037265506, 0.03987402216132198, 0.038862513045647314, 0.04528335082743849, 0.0438226345660431, 0.08647966810635158, 0.02117259451188147, 0.06820800248533487, 0.016982135263138583, 0.04995279473119548, 0.04472308446254049, 0.04922707099467516, 0.08121103367635182, 0.013844624111827995, 0.026900980521791747, 0.029069495320852314, 0.05448539508506656, 0.05088295767615948, 0.019293074562613453, 0.009439353398712618, 0.039834076804774146, 0.04654131064723645, 0.01898301120049187, 0.08012260922363826, 0.0385505565708237, 0.04435929809031742, 0.032203115921999724, 0.016757012610988956, 0.022021004165123616, 0.005448534419494016, 0.032189385765897374, 0.008086934718968613, 0.03669757582247257, 0.0211958241582449, 0.010646895522118678, 0.031698553889457665, 2.622534372976848, 23.05934623309544, 36.99602385929653, 40.50987032481602, 40.54763725825718, 27.491405827658518, 26.974584920065745, 10.047215018953596, 0.2222198929105486, 0.08003660491002457, 0.2726467970226492, 0.12753506723259175, 0.14336902116026196, 0.735323785671166, 2.05607379760061, 2.8129714684826985, 4.481476051466806, 21.405530793326243, 43.184225014277864, 52.17104591642107, 51.88498510633196, 50.30167824881417, 49.88856962748936, 48.41895266941616, 50.409962449754985, 49.0575407573155, 48.434669494628906, 48.01517200469971, 49.3965676852635, 46.98631055014474, 43.534796374184744, 39.37213407244001, 36.01914882659912, 35.462184701647075, 37.066808632441926, 36.21536595480782, 37.595580441611155, 41.84644317626953, 43.124328068324495, 44.28595570155552, 43.685002531324116, 41.25216375078474, 37.12312378202166, 37.61050169808524, 37.887126854487825, 36.513957841055735, 35.903892108372276, 36.137976918901714, 35.17676312582833, 34.67602382387434, 34.087667737688335, 33.76593835013253, 36.90547146115984, 36.94261653082711, 38.385107721601216, 37.926863602229524, 36.41082920346941, 38.682160581861226, 41.02826847348894, 44.14990649904524, 44.72261871610369, 46.396860122680664, 44.98802947998047, 48.83159923553467, 42.101900645664756, 37.88006053652082, 49.0311028616769, 43.025062629154746, 42.33957420076643, 37.69274752480643, 35.28558928625924, 34.16377135685512, 34.07234001159668, 34.01465606689453, 34.397088391440256, 33.13311031886509, 33.23879936763218, 33.49530948911394, 34.51087556566511, 36.00854934964861, 38.317199502672466, 39.75906882967268, 39.15075751713344, 34.95209659848894, 34.828085150037495, 34.37793568202427, 36.52888951982771, 34.35818542752947, 34.93334341049194, 34.35388101850237, 32.935805797576904, 33.74072333744594, 32.6329025541033, 34.566436835697715, 33.62679719924927, 40.77100447246006, 44.75229099818638, 44.73570564814976, 45.53375836781093, 44.87899834769112, 42.16828720910208, 38.77906363351004, 40.11132165363857, 37.76777764729091, 38.33081102371216, 40.559317180088584, 44.25740902764456, 43.49402434485299, 46.521656717572895, 45.56779759270804, 43.53100960595267, 30.296539510999406, 11.87305656501225, 1.2202862799167633, 1.6133080933775221, 1.6017703924860274, 0.6501615611570222, 0.22191198728978634, 0.02287102025002241, 0.035679922572204044, 0.026852351613342762, 0.11516713803367955, 0.09190978708543948, 0.7955351376107761, 11.83640742301941, 30.329692840576172, 28.31824667113168, 36.99476970945086, 39.81474127088274, 25.96970864704677, 2.8624009532587866, 0.20089861271636827, 0.012215338547581008, 0.047648737473147254, 0.08142874842243535, 0.02462334032835705, 0.021824259543791413, 0.027635153715631793, 0.037225940863468816, 0.03222417764897857, 0.05819629970937967, 0.05979467037000826, 0.049228543415665627, 0.006285863171797246, 0.022039470495656133, 0.06861188688448497, 0.03451641143432685, 0.016000547845448767, 0.03607779175841382, 0.032304533158562014, 0.018707905962531055, 0.17111790073769434, 0.2265232162816184, 0.19241524221641676, 0.11023091790931565, 0.11795111293239252, 0.10870527941733599, 0.06966216409845011, 0.11446171945759229, 0.09936709050089121, 0.08516857560191836, 0.15857438024665627, 0.08973936390663896, 0.16912868033562387, 0.11581653675862721, 0.17939848426197255, 0.133292450436524, 0.16447378082999162, 0.12126100675335952, 0.14007144953523362, 0.12670064557875904, 0.14848446952445166, 0.10992583499423095, 0.18025356052177294, 0.09561821166425943, 0.14952828708503926, 2.5234293937683105, 25.66435616356986, 44.34367438725063, 47.17231035232544, 47.999267578125, 36.673422472817556, 34.26287003925869, 13.427909680775233, 0.5641422654901231, 0.5704267482672418, 2.501121767929622, 1.6994363346270152, 0.979273898260934, 6.203496311392103, 3.622575351170131, 3.2707719888005937, 3.5665730876582007, 22.19401236942836, 42.55179303033011, 54.01215526035854, 53.50981787272862, 51.81637511934553, 50.5713586807251, 50.07654619216919, 53.73982409068516, 50.50899165017264, 49.01789781025478, 49.93297209058489, 49.56684718813215, 48.51493855885097, 45.44746174131121, 40.21279661996024, 38.02077892848423, 37.58169446672712, 39.39478519984654, 38.63218913759504, 39.895496709006174, 45.48853254318237, 46.16657945087978, 46.171102728162495, 45.67172179903303, 44.03774172919137, 39.97760704585484, 40.6139543397086, 40.03070865358625, 37.956039088112966, 38.75970942633492, 38.59577710287911, 36.524050099509104, 36.5312762260437, 36.647568225860596, 35.74141890662057, 37.35414791107178, 38.67109210150582, 40.41890103476388, 40.635406902858186, 39.083898476191926, 40.77146652766636, 44.04179947716849, 47.92093358721052, 45.552376065935405, 48.34801503590175, 46.911919661930625, 51.235401494162424, 42.183475971221924, 41.63184458868844, 50.606891768319265, 44.7900926726205, 44.23581402642386, 39.54905257906233, 37.16570929118565, 36.428651332855225, 35.575763429914204, 34.814716815948486, 34.93028967721121, 35.513549259730745, 34.29197951725551, 33.710008825574604, 36.537633827754426, 36.862573283059255, 39.25268064226423, 41.26393747329712, 41.431423800332205, 37.07849897657122, 36.601355757032124, 36.38392577852522, 39.102505752018516, 36.37525790078299, 36.74036489214216, 35.3884608404977, 35.75426265171596, 35.45887041091919, 33.81995712007795, 36.44586896896362, 34.466271604810444, 43.360671043395996, 46.46817295891898, 47.696437290736604, 46.48261478969029, 46.761254923684255, 45.09818969454084, 41.91680758340018, 41.785785402570454, 39.26943622316633, 39.693901675088064, 41.65909889766148, 46.2261255128043, 45.25414201191494, 46.98815529687064, 46.457684653145925, 43.114895888737266, 30.22976037434169, 12.322834304400853, 1.852832474878856, 1.5145523697137833, 1.5770067955766405, 1.87380713224411, 0.26963494292327334, 0.10475939472338983, 0.19003173868571008, 0.13880894013813563, 0.5009716323443821, 0.3371375064764704, 2.005293539592198, 22.133146149771555, 37.98742757524763, 36.35868992124285, 40.491273471287315, 45.72139794485909, 30.360119002205984, 4.605551336492811, 0.2134362706648452, 0.21651348125721726, 0.14318057841488294, 0.16975186046745094, 0.1101546844999705, 0.05536920730290668, 0.06902033782431058, 0.18939178516822203, 0.09018432681581803, 0.10865249617823533, 0.2094216232321092, 0.10671790463051625, 0.1259661585624729, 0.14702632491077694, 0.2252588884106704, 0.10860166711998837, 0.2350438247833933, 0.0765248401356595, 0.0927086060068437, 0.09780684672296047], [0.0765615828069193, 0.02400983780223344, 0.05280981392466596, 0.056780590675771236, 0.01644816213021321, 0.007488611869380942, 0.04759367435638394, 0.06543988495000772, 0.024516420172793523, 0.06764237569378954, 0.019542839910302843, 0.020667318321232284, 0.027605578070506454, 0.04250461082639439, 0.051172366432313404, 0.032487140502780676, 0.03869454509445599, 0.017189770371520093, 0.06192013381847313, 0.06320709761764322, 0.04951800645462104, 0.057549995104117055, 0.026109800208359957, 0.040889934969267676, 0.08548663210655962, 0.11246289099965777, 4.8762935400009155, 15.708892107009888, 20.101558889661515, 33.18389817646572, 25.44376128060477, 17.148788145610265, 13.305649178368704, 0.93133273933615, 0.07071904345814671, 0.22727434097656182, 0.05677535238542727, 0.12782609090209007, 0.8797170147299767, 1.4598907828330994, 4.194976202079228, 0.3454258660120623, 5.270785331726074, 21.668921368462698, 40.405761991228374, 50.286503383091514, 49.351209844861714, 48.638421944209504, 50.05792154584612, 47.02628353663853, 48.035818576812744, 48.48764256068638, 48.78831890651158, 45.762510435921804, 43.20515646253313, 38.924878529139924, 34.6505308832441, 33.33440310614449, 33.85993010657174, 32.015002727508545, 35.7878155027117, 38.50819853373936, 43.05344254629952, 44.50712033680507, 47.11681856427874, 44.5362298148019, 46.68613794871739, 45.350423199789866, 43.82394218444824, 42.0051052910941, 42.39605958121163, 42.63065161023821, 40.17610318320138, 34.08588205065046, 33.170953682490754, 32.94814927237374, 33.302566460200715, 35.08773585728237, 36.84366028649466, 36.936568123953684, 35.74811002186367, 35.63485785893032, 38.54815067563738, 41.55656085695539, 45.44944197790963, 44.771749428340364, 47.786006518772666, 43.27770260402134, 45.80514805657523, 42.193071433476035, 35.54142195837838, 47.8765241759164, 40.648691858564106, 43.041345732552664, 36.574136189052034, 34.57670974731445, 31.864904267447336, 32.042931011744905, 31.745992796761648, 33.32909120832171, 32.085165636880056, 32.19323444366455, 32.57068838391985, 32.980791909354075, 35.29032448359898, 36.53467042105538, 36.25606850215367, 34.566756452832905, 32.66939101900373, 33.560671193259104, 32.080319268362864, 32.56198923928397, 32.35064240864345, 32.67862517493111, 33.567626340048655, 32.47161749431065, 31.558506080082484, 31.94859184537615, 32.194634505680625, 31.542181287493023, 37.26867812020438, 44.74078478131975, 44.06099387577602, 44.818125179835725, 44.23519216264997, 41.99989414215088, 41.23159013475691, 42.110895088740754, 37.18915946143014, 38.98762771061489, 40.00020258767264, 42.8402544430324, 44.41765533174787, 45.93437760216849, 43.40157161440168, 33.495215688432964, 13.14178546837398, 1.5041506992919105, 0.38932450328554424, 1.8842441950525557, 1.1236257638250078, 0.3055188331220831, 0.3538822036768709, 0.08879468709762607, 0.05718554037490061, 0.045835603693766255, 0.1466735274131809, 0.10558965017220803, 2.377486390726907, 11.872439912387303, 25.718750136239187, 24.72644141742161, 25.491618735449656, 30.11883933203561, 15.462158100945608, 0.873930033828531, 0.01891013314681394, 0.06348197215369769, 0.027631101165232912, 0.040008786001375744, 0.014918620365538766, 0.09455631114542484, 0.03810279131201761, 0.029550892167857716, 0.06401603349617549, 0.023700322357139418, 0.05430783943406173, 0.040134165702121596, 0.023736264357077222, 0.045276338168020756, 0.05236890526222331, 0.03211670109469976, 0.03687333335567798, 0.04638119673888598, 0.04860420977430684, 0.034569533940936835, 0.09190539696386882, 0.03422233774991972, 0.040684145476136885, 0.06358090255941663, 0.02462807989546231, 0.09016070701181889, 0.040934172059808455, 0.0687583147415093, 0.027184984746522138, 0.014642972299563033, 0.04971127697665777, 0.011711969040334225, 0.01192100701986679, 0.06032383268965142, 0.025589816771181564, 0.014510184692751085, 0.013971086924097367, 0.02320778226879026, 0.030729365002896105, 0.04591184388846159, 0.03967548620754054, 0.03407767069126878, 0.041685252649975676, 0.014236813111762916, 0.015631248376199176, 0.05670553791735854, 8.906141894204275, 25.320291791643413, 30.761485167912074, 44.46231140409197, 28.651859215327672, 24.93570031438555, 15.308950322014944, 1.0308503764016288, 0.019070810239229883, 0.027061009613264884, 0.06548991333693266, 0.11070163122245244, 0.4330709044422422, 0.39594969206622666, 4.169074620519366, 1.7179216912814548, 6.815970029149737, 25.771346262523107, 44.25037397657122, 52.41192259107317, 51.80076251711164, 48.99281481334141, 50.35862568446568, 49.586340359279085, 48.158916337149485, 49.58655227933611, 49.6326014654977, 47.41508041109358, 45.03908831732613, 40.173212732587544, 37.22222246442522, 37.274198463984895, 35.00500018256051, 33.768627302987234, 37.26968560900007, 40.58234698431832, 43.989392689296174, 46.26111316680908, 48.19320222309658, 45.99905490875244, 47.86685923167637, 46.16557543618338, 44.25742987224034, 44.072486196245464, 43.31569882801601, 42.822783197675435, 41.64101621082851, 35.75747619356428, 34.60382161821638, 34.72293111256191, 34.756661142621724, 36.523862498147146, 37.11460876464844, 38.827002729688374, 37.66362762451172, 36.20985950742449, 41.55155120577131, 43.30068724496024, 46.24312775475638, 47.19335991995675, 48.68544735227312, 46.53764452253069, 46.244239466530935, 40.34790781566075, 38.1329402242388, 48.340399810246055, 42.04158680779593, 44.287758759089876, 38.244163513183594, 36.648450647081646, 33.39079121180943, 33.25328288759504, 32.92234366280692, 34.050991671425955, 33.90096616744995, 33.533274446214946, 33.17194727488926, 35.05277599607195, 35.89343506949288, 37.98301894324166, 37.029548917497905, 36.68532126290457, 34.71103579657418, 34.41785308292934, 33.186621870313374, 34.219905853271484, 35.15066916601998, 34.099545683179585, 35.114222390311106, 33.82549136025565, 33.956860951014924, 32.29840932573591, 33.95156294958932, 33.93126378740583, 40.63162360872541, 46.826922348567415, 46.00651032584054, 46.3847633089338, 46.80473327636719, 43.065494196755544, 42.67170851571219, 42.542725631168906, 40.409006799970356, 40.050889696393696, 42.50012622560774, 42.7913703918457, 45.660354546138215, 46.10437570299421, 43.835288592747276, 34.98584052494594, 17.45658118384225, 2.5781349497182027, 1.7229942019496645, 4.196820080280304, 3.177819639444351, 1.236259319952556, 0.7884675168565342, 0.20035757603389875, 0.04989679523610643, 0.06403011309781245, 0.03800051233598164, 0.041921111422457864, 2.852901028735297, 16.91596269607544, 34.582963126046316, 30.24144377027239, 31.55876316343035, 35.67085647583008, 19.878966399601527, 1.431904198867934, 0.05166716095326202, 0.02328738969351564, 0.06860370375216007, 0.058684593864849637, 0.00988793374770986, 0.023606784608481184, 0.017517821696986045, 0.018659539986401796, 0.024415228549124937, 0.028850630457912172, 0.03882103759263243, 0.042636419646441936, 0.06361366901546717, 0.07866584203605141, 0.030748974664935043, 0.020025190099009445, 0.007873258104414811, 0.029666704524840628, 0.03409785032272339, 0.04012153138007436, 0.21826488870595182, 0.13516389073005744, 0.10693526653839008, 0.1053676131580557, 0.16679544267909868, 0.17188218901199953, 0.10856102287237133, 0.1135297380387783, 0.08303555327334575, 0.1578340713999101, 0.19974476391715662, 0.07959090918302536, 0.10668805587504591, 0.09652546048164368, 0.1368101252509015, 0.06638662450547729, 0.15279403541769299, 0.11794633604586124, 0.13188185755695614, 0.1877481019390481, 0.10536186596644775, 0.12186833630715098, 0.1934263679598059, 0.09932076012981789, 0.1771970181060689, 0.19916073525590555, 9.029392514910016, 29.14884649004255, 36.97778483799526, 50.04500137056623, 36.77754470280239, 30.096195152827672, 18.808184725897654, 1.7153938497815813, 0.46640439863715855, 0.5151049739548138, 0.13624087508235658, 0.7477871711765016, 1.8161657452583313, 6.363285771438053, 8.753368377685547, 0.9880782429661069, 7.3719805138451715, 24.98848056793213, 44.16426842553275, 52.243981157030376, 52.767083236149375, 51.33822441101074, 53.35674210957119, 51.261627469744, 49.951172896793906, 51.289038113185335, 52.402226379939485, 50.692059312547954, 47.541461195264546, 41.93646403721401, 39.80256455285208, 38.673343317849294, 36.5364213671003, 35.35638100760323, 39.57123817716326, 43.43613542829241, 47.10498578207833, 48.606248310634065, 50.88583067485264, 47.95824541364397, 51.358283860342844, 48.91966765267508, 47.39981174468994, 47.429167883736746, 45.61124815259661, 46.88989734649658, 43.878218037741526, 37.51111813953945, 37.38956635338919, 35.86911984852382, 35.94426809038435, 37.382117884499685, 37.85759006227766, 40.33601597377232, 39.81958416530064, 38.99017422539847, 42.91329043252127, 45.36652217592512, 47.3184483391898, 49.93916293552944, 51.749953814915244, 47.793364661080496, 45.08720806666783, 40.64871270315987, 41.673818656376426, 50.29846123286656, 44.53151198795864, 46.16758346557617, 40.32305063520159, 37.780041217803955, 35.06886454990932, 34.74434546061924, 33.37669331686837, 36.13757392338344, 34.39016451154436, 34.66258948189871, 34.36370577130999, 35.958095005580354, 38.6224581854684, 39.391627243586946, 38.373563289642334, 38.07913337435041, 35.82022190093994, 36.838570731026785, 34.160634245191304, 35.99467032296317, 35.36651495524815, 35.88503122329712, 37.48577805927822, 36.3033127784729, 35.730409485953196, 34.42919601712908, 34.924401078905376, 34.83834763935634, 41.76847743988037, 47.6596222605024, 47.066687311444966, 47.654042857033865, 48.32014581135341, 44.30943019049508, 45.55362674168178, 47.17406824656895, 41.816225460597444, 42.114806924547466, 44.04384224755423, 45.53798287255423, 48.726823874882285, 48.21724646432059, 43.55023179735456, 36.81005532400948, 16.80094221660069, 2.1969083547592163, 1.6145603976079395, 6.7529546448162625, 4.225844442844391, 1.4982776258672987, 1.0884107734475816, 0.33905463931815966, 0.14210724458098412, 0.2034889744328601, 0.3120086134544441, 0.2521355247923306, 6.510458605630057, 20.687502213886805, 34.344855308532715, 35.54151575905936, 36.01815523420061, 42.50033119746617, 21.570646047592163, 1.3440175205469131, 0.1613112376736743, 0.10191313709531512, 0.21156388042228563, 0.09741877897509507, 0.07878701481968164, 0.1831891065729516, 0.10245196175362382, 0.14967730694583484, 0.14511972293257713, 0.16531874691801413, 0.16320934439344065, 0.20308371260762215, 0.17250585768904003, 0.1541392310921635, 0.18803058963801178, 0.10239769930818252, 0.13433959281870297, 0.10562998907906668, 0.14679362811148167, 0.1402015382690089], [0.116476710619671, 0.02251112357979374, 0.03670024925044604, 0.006683153906903628, 0.0653207545567836, 0.017864042493913854, 0.043544889826859744, 0.03657372282551868, 0.09059617721608706, 0.06410139998687164, 0.07956816468920026, 0.05770766628640039, 0.08136518326188837, 0.02986132533156446, 0.01681620461334075, 0.019259661801957657, 0.02146715504516448, 0.036855413245835474, 0.026026959564270716, 0.07657871581614017, 0.05512608481304986, 0.005422871801004345, 0.05130182412852134, 0.027604165021330118, 0.06871474600796189, 0.10802827110247952, 1.2494907528162003, 16.28369746889387, 19.982379913330078, 26.854928255081177, 35.73844507762364, 14.365551710128784, 12.356862238475255, 3.4773004608494893, 0.05683660034888557, 0.04712556322504367, 0.05434575257822871, 0.0312268295591431, 0.11918344109186105, 0.7649265857679504, 5.631003396851676, 3.0006764020238603, 0.42740882826702936, 8.433668732643127, 25.0398451260158, 43.45256791796003, 50.42819799695696, 51.053591455732075, 47.28014292035784, 49.516239983694895, 49.63041625704084, 47.0472149848938, 45.561877727508545, 42.03997482572283, 40.11046355111258, 35.66561753409249, 35.87416076660156, 33.865596362522666, 33.84817375455584, 35.505788121904644, 34.50546639306204, 38.0709935597011, 41.89702953611101, 43.97967215946743, 45.68925557817732, 48.13815859385899, 45.14103923525129, 45.77522216524397, 45.164555413382395, 45.28864676611764, 46.265403679439, 46.10144703728812, 44.60225159781319, 43.085852418627056, 34.57691819327218, 32.943111828395296, 34.193443638937815, 35.804890700748985, 36.31797347749983, 34.617245537894114, 34.00210414613996, 33.29410702841622, 39.702579975128174, 43.56452076775687, 46.57375431060791, 45.9362154006958, 46.46087040219988, 42.95758172443935, 44.41870450973511, 53.4946916443961, 36.460001604897634, 48.70062221799578, 43.94546617780413, 42.929062843322754, 38.85113034929548, 35.31689092091152, 33.63711527415684, 32.17746550696236, 31.43088504246303, 32.69430725915091, 31.445903573717388, 33.19296210152762, 32.200269494737896, 32.12515251977103, 34.56043011801583, 34.81678737912859, 34.04559639522007, 32.9451129095895, 32.630640915461946, 33.441700662885395, 32.62894902910505, 33.91649539130074, 33.2663038117545, 37.51718044281006, 40.94319820404053, 40.698135239737375, 35.96031495503017, 32.1693673815046, 32.70767559323992, 31.41713455745152, 36.96060194287981, 43.727782590048655, 45.530569144657676, 45.593526772090364, 44.70655795506069, 45.833420276641846, 42.12424952643258, 40.23651429585048, 39.898216928754536, 39.549730028424946, 40.81502825873238, 42.76266738346645, 43.113464559827534, 45.41992255619594, 40.6462391444615, 18.789573975971766, 2.5390452529702867, 0.07151191162743739, 1.9428785230432237, 1.9906280636787415, 2.3355980898652757, 0.9289631864854268, 0.5485449167234557, 0.036758420057594776, 0.01598610183490174, 0.05034023144149354, 0.05882597342133522, 0.17361547957573617, 2.520332451377596, 11.932302985872541, 27.65983189855303, 24.340253591537476, 32.15766314097813, 27.297297477722168, 3.336189929928098, 0.0326594782194921, 0.0488994233975453, 0.009348457695783248, 0.057402542659214566, 0.07701056264340878, 0.019649164651387503, 0.02865490024643285, 0.07145449399415936, 0.04365322472793715, 0.04479257323380027, 0.057719656000179906, 0.03314399293490818, 0.026882578652086, 0.04573864782495158, 0.06333827879279852, 0.06830708216875792, 0.07105492507772786, 0.04128102559064116, 0.0359924591944686, 0.041094988251903226, 0.013348897453397512, 0.011119836126454175, 0.02810930211230048, 0.017883380741945336, 0.02383155102974602, 0.05179643205233982, 0.0325905458469476, 0.01983117318845221, 0.02423806135941829, 0.028099705930799246, 0.09966548306069203, 0.018119587263624583, 0.02992675985608782, 0.0414382387617869, 0.047659292085362334, 0.03229236024032746, 0.05065676463501794, 0.10282928150679384, 0.04695518308186105, 0.036390029825270176, 0.04010923971821155, 0.04609375912696123, 0.017724549264780114, 0.016048194574458257, 0.03166186210832425, 0.028004239446350505, 0.020158703738291348, 1.8514888669763292, 19.142490352903092, 27.655683823994227, 37.59970072337559, 39.960392883845735, 21.580469063350133, 18.95247449193682, 3.7346272127968922, 0.05570449859702161, 0.12312452175787517, 0.05437299915190254, 0.021045114745252898, 0.048338057805917094, 0.21504233591258526, 5.114347943237849, 1.3786122756344932, 0.7222301768405097, 9.618927189282008, 28.986969096320017, 46.810906750815256, 52.88398667744228, 51.518940108163015, 50.67800310679844, 49.894816058022634, 51.5569224357605, 48.102500438690186, 47.33257402692522, 44.3480725969587, 41.797534806387766, 37.69393914086478, 36.94548961094448, 35.475080558231895, 35.16069541658674, 36.712995937892366, 37.11726297651018, 39.944905349186485, 44.558074951171875, 44.30005012239729, 47.9350141116551, 48.132454122815815, 46.84145450592041, 47.32088368279593, 46.3946019581386, 47.225446701049805, 47.40022168840681, 48.1662049974714, 45.475636686597554, 43.329557010105674, 36.34002358572823, 33.248697076525005, 36.209925515311106, 38.27933529445103, 38.17171464647566, 37.93375621523176, 35.92235347202846, 33.72242178235735, 41.25283425194876, 44.28993354524885, 46.870313848767964, 48.01675271987915, 47.540960924965994, 44.26753602709089, 44.559113706861226, 50.035621302468435, 38.89791604450771, 49.381281648363384, 45.70092855181013, 44.749876499176025, 39.939666407448904, 36.89870391573225, 34.904709884098594, 34.44152559552874, 34.38596085139683, 33.70712532315935, 33.12215995788574, 33.89346906117031, 34.085360935756135, 34.394899708884104, 36.130761214665, 36.766146183013916, 35.36432974679129, 35.4413401058742, 34.51460327420916, 34.272034713200156, 34.64936358588082, 35.27487516403198, 34.442362853458945, 37.26847662244524, 40.86147001811436, 40.892549310411724, 36.954042843409944, 32.64707687922886, 34.34516102927071, 32.533852509089876, 38.47378063201904, 44.67923069000244, 45.38484457560948, 47.13968161174229, 46.90290437425886, 44.821085112435476, 43.27914088112967, 42.99361855643136, 40.84935583387102, 40.570646217891145, 42.81722811290196, 44.09772552762713, 45.51182290485927, 46.57914958681379, 41.76883527210781, 21.10198484148298, 4.719096192291804, 1.4848401354891914, 5.23887529543468, 8.033482892172676, 4.137477687426975, 0.8766000962683133, 0.8650830771241869, 0.23848587008459227, 0.02404982895989503, 0.1392397013093744, 0.04721978799040828, 0.23954023207936967, 3.7033637932368686, 15.404248339789254, 30.80336196081979, 26.90992498397827, 33.87889868872506, 31.208351612091064, 7.060664738927569, 0.09280297665723733, 0.025227316222818832, 0.04932038652311478, 0.0277399229151862, 0.08155343601746218, 0.050816644448786974, 0.05122477308447872, 0.04285732011443802, 0.07130939606577158, 0.0387946934705334, 0.07253292362604823, 0.013124651807759489, 0.034257628356239626, 0.06017866012241159, 0.0676539447158575, 0.0376110569840031, 0.0700309139543346, 0.03169842157512903, 0.055056290701031685, 0.07453637969280992, 0.028284594849018112, 0.21512757348162787, 0.1199939918837377, 0.10386064116443906, 0.11312702750521046, 0.1948867245976414, 0.17484182305634022, 0.1142858024686575, 0.0768731457314321, 0.23305273162467138, 0.18313430808484554, 0.2136444044964654, 0.1472994623971837, 0.21920608463031904, 0.13507070073059627, 0.06880231095211846, 0.10994929194982563, 0.1481722348502704, 0.17072068633777754, 0.115272636658379, 0.18632939378065722, 0.22182558264051164, 0.14074984884687833, 0.11749927646347455, 0.09949413261243276, 0.1635929202394826, 0.16626731173268386, 1.9591077779020583, 23.36839689527239, 38.50534629821777, 44.6488253729684, 45.91244561331612, 27.01437030519758, 18.50419408934457, 5.09572069134031, 0.23700568665351185, 0.31351979236517635, 0.21609721359397682, 0.12809333870453493, 0.4661334731749126, 3.02620820913996, 11.141384329114642, 6.655347219535282, 0.9364446593182427, 10.919580459594727, 27.89831839288984, 47.72574479239327, 53.07527405875069, 53.38100521905081, 50.306872027260916, 51.409478187561035, 53.31431293487549, 49.772757053375244, 49.63093042373657, 46.09804589407784, 43.20687961578369, 39.11849355697632, 39.54380668912615, 37.36131150381905, 37.35978637422834, 39.34984425136021, 39.25138827732631, 41.88007245744978, 45.68751852852957, 46.65658726011004, 48.64171886444092, 51.013604572841096, 47.869760104588096, 49.00561686924526, 49.34567560468401, 49.518657956804546, 50.39370366505214, 50.63612283979143, 48.21776410511562, 46.98942334311349, 38.92703594480242, 34.92558227266584, 37.320761816842214, 39.391585554395405, 40.04052298409598, 37.425696986062185, 37.41928032466343, 35.574769837515696, 43.44864565985543, 45.8861015183585, 49.133366448538645, 49.90120145252773, 47.15983138765608, 46.14583560398647, 45.1221991947719, 53.22255849838257, 41.67708083561489, 51.222700187138145, 48.690877369471956, 46.4532447542463, 40.95465578351702, 38.150164808545796, 36.870393480573384, 36.543584959847585, 35.80308764321463, 35.919198989868164, 34.49517958504813, 35.45012957709176, 35.60411555426461, 35.440565381731304, 37.948201520102366, 38.028592177799766, 36.66810015269688, 36.24423919405256, 35.09736606052944, 36.23112446921212, 36.80717182159424, 38.28379256384713, 36.027385916028706, 40.10940395082746, 43.81933205468314, 44.8729464667184, 39.6063300541469, 34.476773806980674, 35.16443007332938, 34.253913811274934, 40.56215899331229, 46.25930316107613, 48.92989540100098, 49.04290785108294, 46.79390450886318, 47.87988362993513, 44.29093755994524, 44.6627391406468, 43.804462909698486, 43.186080183301655, 43.38192905698504, 46.40958227430071, 45.77092817851475, 47.58523137228829, 43.021605900355745, 21.713794572012766, 3.447844224316733, 1.1753738841840198, 3.044372537306377, 5.073152073792048, 5.219442052500589, 1.6543857348816735, 2.512158981391362, 0.4219028694289071, 0.13546776585280895, 0.22660336483802113, 0.13069560192525387, 0.615845113992691, 4.985858815056937, 18.36968217577253, 37.46601390838623, 32.66146659851074, 43.69370515005929, 36.14846175057547, 7.447567360741751, 0.1196322784359966, 0.13535458621169838, 0.04405135515012911, 0.10776066367647477, 0.2039587242262704, 0.1293265896716288, 0.15984478779137135, 0.12175954000226089, 0.1088337871645178, 0.12102915133748736, 0.14313749144119875, 0.12171338605029242, 0.11017548838364226, 0.156067288347653, 0.1632869959409748, 0.11498591490089893, 0.15583294949361257, 0.1336019302585295, 0.11290701252541371, 0.2045430921550308, 0.21250016375311784], [0.0710831182077527, 0.035892365101192675, 0.06479457100587231, 0.013807581188822431, 0.01760961052163371, 0.044050673222435374, 0.02654254948720336, 0.015900328223194395, 0.01956406109301107, 0.01776935632473656, 0.05356867052614689, 0.003968309004059327, 0.06696509596492563, 0.0018260287012838358, 0.017276453220152428, 0.007251931221357414, 0.040771439006286006, 0.010741654633810478, 0.01765494344622961, 0.025502287450113466, 0.014180275877671582, 0.029343857562967708, 0.030956850653248172, 0.0300594066668834, 0.03495980014226266, 0.08569009761725153, 0.09927341195621661, 5.372499142374311, 22.589548996516637, 23.235319784709386, 32.014582361493794, 25.126183441707067, 13.644731691905431, 7.306347829954965, 0.6331705014620508, 0.03963471643094506, 0.06750973566834416, 0.09741131508988993, 0.0168946720992348, 0.12207148969173431, 0.8577798690114702, 3.229589581489563, 0.093911926794265, 0.6044041993362563, 10.477923427309308, 31.03964240210397, 46.08337824685233, 52.5302608353751, 50.93478420802525, 47.57932540348598, 46.89058174405779, 45.57585750307356, 41.95998021534511, 40.319712025778635, 35.93862962722778, 36.321444102696006, 34.84051200321743, 34.10336371830532, 35.717148848942344, 34.14677606310163, 33.94621631077358, 38.37523085730416, 41.268683092934744, 43.84276832853045, 47.9748272895813, 45.043080057416645, 45.58395562853132, 45.41078914914812, 43.853239263807026, 46.02664620535714, 44.48652935028076, 44.93344790594918, 45.773710932050435, 44.81788894108364, 40.90888452529907, 32.535217830113, 32.37204286030361, 32.55080611365182, 33.95845556259155, 34.047201429094585, 33.19068309238979, 33.78669261932373, 35.944007532937185, 42.26157372338431, 44.39147799355643, 45.461702074323384, 46.82226358141218, 46.40603174482073, 42.5294372013637, 30.663890770503453, 38.81321055548531, 46.21403912135533, 43.04536526543753, 42.99845450265067, 38.8448873928615, 35.953561305999756, 34.23986107962472, 32.8139865057809, 33.8779467855181, 33.538169452122276, 32.51560653959002, 32.04158306121826, 31.65082332066127, 33.059785979134695, 31.991173880440847, 31.92162241254534, 31.438573224203928, 31.970176424298966, 33.17298603057861, 33.60049826758248, 32.5395222391401, 32.90862097058977, 37.7782381602696, 42.11833313533238, 43.7338935307094, 43.28892741884504, 41.35819673538208, 34.2083648954119, 33.23054838180542, 32.521067823682515, 33.88727821622576, 42.86000122342791, 43.61948101861136, 43.786856174468994, 44.84359032767159, 44.84815876824515, 45.315880230494905, 42.48095267159598, 41.49231781278338, 40.220022746494834, 42.13658605303083, 42.305243151528494, 47.35333177021572, 40.50318963187081, 25.75738733155387, 3.9455462949616567, 1.7246504787887846, 1.3662585956709725, 7.230547325951712, 11.303721172469002, 4.6512804712568006, 1.8132450048412596, 0.9054824550236974, 0.20089341513812542, 0.100706111506692, 0.07731664979032107, 0.026173256803303957, 0.01691135048999318, 5.136237374373844, 18.73634730066572, 27.5868011202131, 28.63839360645839, 30.838311399732316, 18.764572620391846, 0.8231035811560494, 0.02858516720256635, 0.03579898511192628, 0.08611815143376589, 0.029179458705974475, 0.08810397237539291, 0.04125394865072199, 0.04318748168381197, 0.01289404574449041, 0.04867799367223467, 0.06824996987623827, 0.012005786577771817, 0.04056041122281125, 0.053267417941242456, 0.008809274262083428, 0.033682346011378934, 0.017318157678736106, 0.09257894475013018, 0.010769908831986998, 0.07518539165279695, 0.007367681662019874, 0.040168547071516514, 0.07620330953172275, 0.013004418795130082, 0.07304442367915596, 0.030904823980693306, 0.015392741620806711, 0.04219774336421064, 0.04628676841301577, 0.022417811444029212, 0.02887587874595608, 0.010208591585978866, 0.026977432758680413, 0.03165515139698982, 0.08243536190795046, 0.025613468805594102, 0.03696094918996096, 0.02043727968287255, 0.03625633128519569, 0.026174518878438642, 0.038602030237338374, 0.053033852617123296, 0.037599362432956696, 0.04099567447389875, 0.05967456288635731, 0.028458686578752737, 0.07626568725598709, 0.09246003827346222, 0.15667279942759446, 9.24680859701974, 29.225433009011404, 31.364533220018657, 41.815402099064414, 24.330022369112285, 17.38566092082432, 8.970329352787562, 0.543857216835022, 0.03824874758720398, 0.06781059809561286, 0.06742696796676942, 0.07563337404280901, 0.06574137841484376, 1.2338152910981859, 3.527984312602452, 0.39645642201815334, 1.7933936757700784, 12.454478349004473, 33.20292581830706, 49.0087366104126, 54.8258171081543, 50.8250652040754, 49.70427908216204, 48.67357635498047, 47.09925351824079, 43.26068993977138, 41.640126841408865, 37.901214327131, 37.41410391671317, 36.50532470430647, 36.27369608197893, 37.32010521207537, 35.512503555842805, 35.21697235107422, 40.860452107020784, 43.45711203983852, 46.377207142966135, 47.93259961264474, 46.352544512067524, 46.24366624014718, 47.930275440216064, 45.71676002229963, 46.11949150902884, 45.98123277936663, 46.614376953669954, 48.6312062399728, 46.58278349467686, 42.109842436654226, 34.20492901120867, 35.2512651852199, 34.227632250104634, 35.80059323992048, 36.12336833136422, 33.630980014801025, 34.41179425375802, 37.80081980569022, 43.065862451280864, 46.821426323481965, 46.847600187574116, 47.96143116269793, 45.64997393744332, 42.62234156472342, 35.13392400741577, 40.97987427030291, 47.27319124766758, 44.45986911228725, 44.22936609813145, 40.57684401103428, 38.15452132906233, 37.049785545894075, 34.178838525499614, 35.46097224099295, 33.73387588773455, 35.19860131399972, 35.40307985033308, 32.474487100328716, 33.9613390650068, 33.86463403701782, 34.28940173557827, 32.88032095772879, 33.072991030556814, 34.586923599243164, 35.40103013174874, 34.17617736543928, 35.27890164511544, 38.87881892068045, 43.847072737557546, 44.99751377105713, 44.07740899494716, 43.27304383686611, 34.177803243909565, 33.67000457218715, 33.41090277263096, 35.28433166231428, 44.553840024130686, 45.17428983960833, 46.094071524483816, 45.719428130558555, 46.67673356192452, 47.486646856580464, 42.66042116710118, 42.40583569662911, 42.24480424608503, 44.3416177204677, 43.750506673540386, 48.12269537789481, 42.26351227079119, 28.100309474127634, 7.518158452851432, 2.698115791593279, 3.1854604865823473, 7.837379540715899, 10.78691155569894, 5.494750091007777, 2.0582672570432936, 0.4070386370377881, 0.33812431352479116, 0.05226823102150645, 0.10923098120838404, 0.017553772178611586, 0.08531001622655562, 5.132074534893036, 20.560060092381068, 32.81146430969238, 33.63125099454607, 35.329613072531565, 23.369439125061035, 1.7002969341618674, 0.024496683285438588, 0.019971860639218773, 0.06559698616287538, 0.009368762008047529, 0.00833591296603637, 0.010051728708536496, 0.01417068054433912, 0.06334389706275292, 0.07313280965068511, 0.1476581088666405, 0.06572609102087361, 0.0049304351892455345, 0.06206894333341292, 0.015551330521702766, 0.00822828967855977, 0.05449759514470186, 0.02126441726328007, 0.03487037601215499, 0.03231634306056159, 0.020406811764197688, 0.0331748594929065, 0.1827622266220195, 0.07711038871535233, 0.13796633535197803, 0.17622925075037138, 0.11139169455106769, 0.09423902138535466, 0.09868017557476248, 0.12493098553802286, 0.12666878157428332, 0.082603774299579, 0.12596105597913265, 0.09304221453411238, 0.22989499249628612, 0.0928851676040462, 0.12414195787693773, 0.09960085260016577, 0.12944230703370913, 0.12404384171324116, 0.13327197224966117, 0.14546061892594608, 0.15325352576162132, 0.12122492226106779, 0.10794029903731175, 0.09626982241336789, 0.1872683641101633, 0.2924149919833456, 0.2596858282174383, 8.910286494663783, 38.914383275168284, 39.68215921946934, 46.39154127665928, 34.94255324772426, 21.945232118879044, 10.625747220856802, 1.0238129368850162, 0.09654188102909497, 0.2412031585616725, 0.37515126381601605, 0.16608162383948052, 0.44787081171359333, 2.029338215078626, 9.409625734601702, 0.4216539285012654, 1.6938229501247406, 12.786504098347255, 33.45935256140572, 49.045169489724294, 54.63970960889544, 51.755595752171104, 49.350139822278706, 49.308634757995605, 47.89645855767386, 46.137445654187886, 43.88693455287388, 40.06701993942261, 39.43012373788016, 38.59516566140311, 37.90745728356497, 39.01147045407976, 37.2110949243818, 36.485195772988455, 42.522325720105854, 44.55667488915579, 46.86487340927124, 51.829927580697195, 47.461178234645296, 47.785912718091694, 48.75362655094692, 48.170895031520296, 48.871530532836914, 48.43398857116699, 47.273312841142925, 49.621550355638774, 48.13379512514387, 44.76142093113491, 36.16433143615723, 36.14631128311157, 36.26901994432722, 37.601927621024, 38.59579447337559, 35.798804078783306, 37.85380329404558, 38.53177029745919, 45.22533130645752, 49.32730456760952, 49.11554431915283, 49.5874069077628, 47.76309135981968, 45.20278092793056, 39.95355238233294, 44.00376851218087, 49.0437068939209, 46.23558895928519, 46.54516247340611, 41.66557114464896, 38.7738698550633, 38.875949314662385, 36.831368923187256, 37.56871523175921, 35.79004240036011, 36.92594085420881, 35.295361927577424, 34.17303677967617, 35.371337005070274, 34.71339470999581, 35.363013063158306, 34.13859108516148, 34.009427547454834, 34.816370487213135, 36.02984210423061, 35.72717162540981, 38.07770551953997, 41.325383867536274, 45.811467443193706, 46.34989030020577, 46.55625179835728, 45.412463665008545, 35.34834541593279, 35.48623936516898, 35.755079065050396, 37.98633670806885, 46.89504943575178, 47.045481409345356, 46.84348685400826, 47.462223938533235, 46.633595670972554, 49.754493713378906, 45.854977062770296, 44.95446620668684, 42.81856911523001, 46.61276497159685, 44.58537442343575, 51.2005215372358, 43.31484419958932, 28.980375255857194, 6.225347527435847, 2.618057344641004, 5.504307772432055, 13.413902980940682, 21.40851504462106, 13.41839325428009, 3.796343283993857, 1.559950813651085, 0.5065523928829602, 0.24449850459183964, 0.344304410474641, 0.08638609134192977, 0.3258986866899899, 6.90654240335737, 27.25146542276655, 37.23636899675642, 39.43422317504883, 40.72310011727469, 25.762400456837245, 1.9803857675620486, 0.08877543027379683, 0.14737213349768094, 0.24348637461662292, 0.12924644111522607, 0.12319173743682248, 0.08732789116246359, 0.1815251758588212, 0.15473160573414393, 0.14788383032594407, 0.2385440883891923, 0.06854300879474197, 0.10274234081485442, 0.15757143763559206, 0.12240916942911488, 0.09386642423591443, 0.06944758418415274, 0.11116054481161491, 0.09832027381552116, 0.1410206657435213, 0.07066570382033076, 0.13006943623934472], [0.04752271316413369, 0.024109151580237916, 0.044709143960582357, 0.06344305817037821, 0.046440975674028905, 0.10353328873004232, 0.008255288586951792, 0.010832439226630543, 0.05596660988937531, 0.0090502627593066, 0.06941171682306699, 0.042537319606968334, 0.036833021590220075, 0.03084864467382431, 0.03057138847985438, 0.039143148344010115, 0.08233320846089295, 0.06542685707764966, 0.04901932392801557, 0.06553681367742163, 0.045000584929117134, 0.024785201464380537, 0.03508104417206986, 0.021427986611213003, 0.07221150837306466, 0.013971372756973972, 0.11004719098231622, 1.200790828892163, 13.773646831512451, 19.675561359950475, 24.435881648744854, 37.68110234396798, 19.965377671378, 12.678099172455923, 2.8684419776712144, 0.34221416977899416, 0.29765759781003, 0.0845492495489972, 0.07940591339554105, 0.11586661264300346, 0.03680074367938297, 0.43300104247672216, 1.691743158868381, 0.27527848152177675, 2.0485350021294186, 12.138473408562795, 31.8271164894104, 47.141658374241416, 53.26137808391026, 47.81092275891985, 48.2356835092817, 45.77382557732718, 43.36273465837751, 40.671113695417134, 36.94686188016619, 36.678404331207275, 36.482381752559114, 37.30159868512835, 37.68837363379342, 34.922538961683, 35.349780218941824, 33.36659411021641, 40.768614292144775, 43.753584725516184, 47.500376496996196, 45.61700473512922, 44.97574506487165, 43.1078017779759, 44.008885860443115, 43.23341826030186, 45.571379389081685, 41.80720322472708, 46.16693728310721, 46.81865399224417, 42.96450213023594, 37.098509788513184, 33.489959376198904, 33.83170999799456, 33.44048472813198, 32.46068797792707, 31.64302396774292, 31.667366981506348, 34.313279220036094, 40.329925877707346, 44.07620348249163, 45.1352652822222, 45.717885630471365, 44.66987146650042, 44.85701772144863, 31.277117933545792, 30.19511318206787, 46.77661739076887, 43.58692176001412, 42.78827496937343, 41.32644346782139, 37.86760241644723, 36.96075132914952, 33.386851583208355, 33.511953898838584, 35.08657898221697, 32.78603737694876, 33.31586878640311, 33.38056346348354, 33.204346724918906, 31.26078619275774, 32.225609574999126, 32.298541341509136, 32.54396908623831, 32.5814858845302, 33.24525077002389, 34.88369158336094, 35.25176545551845, 40.62836490358625, 42.2326831136431, 44.106685229710166, 44.38211529595511, 42.015659604753765, 37.119236264910015, 31.984520980290004, 32.04125302178519, 33.20170293535505, 40.25230060304914, 43.40249572481428, 43.48385565621512, 44.33138302394322, 43.681594439915244, 44.109096254621235, 42.13132974079677, 43.390461444854736, 41.62458719526018, 41.85349907193865, 44.34001268659319, 43.59258106776646, 32.11243731634957, 10.189108525003705, 0.6648919593010629, 1.633627991591181, 1.9354771716254098, 8.154201763016836, 10.939628618104116, 3.0910920075007846, 0.728156393127782, 0.3688349170344216, 0.08187037293932267, 0.049795432282345634, 0.06675479082124573, 0.0467504826374352, 0.6577962743384498, 8.464985132217407, 26.555023159299576, 24.329343182700022, 28.615381172725133, 28.94720802988325, 8.833798119000026, 0.034694218143288574, 0.07728593929537705, 0.035235132689454725, 0.052332169376313686, 0.07859684181000505, 0.0264760343956628, 0.03322359187794583, 0.06635522869016443, 0.02039697639910238, 0.07115091742681605, 0.01786662431965981, 0.019588644416736703, 0.027710099604779055, 0.015367023447262389, 0.00946258898225746, 0.07780889301959958, 0.04398689093068242, 0.037141079881361554, 0.028241022722795606, 0.037200573831796646, 0.032149314880371094, 0.05704734993300267, 0.011793472970436727, 0.05884292322610106, 0.031176804564893246, 0.03714132076129317, 0.07299865649214812, 0.0422168916224369, 0.018244164596710886, 0.01714259522434856, 0.013879399879702499, 0.03193223795720509, 0.0277223776959415, 0.02517425817703562, 0.06272712908685207, 0.03477190701024873, 0.023646149817588072, 0.07463655181761299, 0.03364984757666077, 0.022797190550980822, 0.04811040930716055, 0.03952662580247436, 0.030846653173544576, 0.012384091054887643, 0.03454418387264013, 0.03811200921024595, 0.05991050308304174, 0.022222851369796053, 0.05473496705027563, 1.8757630501474654, 21.246312822614396, 28.35259509086609, 35.72297143936157, 40.59109476634434, 19.451370784214564, 15.115444728306361, 2.5243556754929677, 0.055213354594473324, 0.6166218465992382, 0.12804342566856317, 0.1243774773819106, 0.13924367752458366, 0.07435976381280593, 0.6337374853236335, 1.0981914486203874, 1.2975647960390364, 3.489894505058016, 14.81196825844901, 34.762921469552175, 49.75848545346941, 54.81426225389753, 50.51533535548619, 48.81984635761806, 48.41842113222395, 45.50426326479231, 41.72522490365164, 38.8940806388855, 38.047157764434814, 39.05499397005354, 38.61666338784354, 38.59880999156407, 36.00726740700858, 37.60236535753523, 35.140083585466655, 42.478162969861714, 45.77964121954781, 48.761321680886404, 46.29233489717756, 46.51739747183663, 44.25305945532662, 45.80759382247925, 45.28158392224993, 45.68398536954607, 43.00943613052368, 47.66379812785557, 47.269470487322124, 44.600778579711914, 38.89482757023403, 35.0359822000776, 35.43908541543143, 34.94166735240391, 34.48616082327706, 33.35946873256138, 33.58701876231602, 35.86842850276402, 41.70861176082066, 47.07789475577218, 47.61903435843331, 47.25400727135794, 44.48866939544678, 45.99764789853777, 31.405795097351074, 32.96523141860962, 47.50793613706316, 44.8357458114624, 43.95109074456351, 43.03913620540074, 40.386675289699006, 38.0851331438337, 35.513934884752544, 34.89797360556466, 36.9480812890189, 35.53420625414167, 34.735163416181294, 34.60776819501604, 34.15444687434605, 32.67826386860439, 33.53927074159895, 33.352603912353516, 34.75881855828421, 34.40928595406668, 34.43123183931623, 34.92611033575875, 36.15126187460763, 41.92530175617763, 45.26211506979806, 44.628296920231406, 45.62807321548462, 42.81439324787685, 38.79707683835711, 33.04944011143276, 34.41214861188616, 33.84508180618286, 40.454531397138325, 45.280989851270405, 45.56695686067854, 45.74266985484532, 44.97876058306013, 45.07368687220982, 44.60538523537772, 44.71168919972011, 43.801509925297324, 43.20542744227818, 45.73480101994106, 43.76493460791451, 32.825193950108115, 12.654503958565847, 2.228492042848042, 2.670957454613277, 5.609603813716343, 11.438563125474111, 11.083478042057582, 5.295315078326634, 1.2549958974123, 0.6252694768565041, 0.35787975202713695, 0.30519283775772366, 0.14543839011873516, 0.1113224568377648, 0.479092894920281, 9.974467379706246, 27.954979215349468, 27.746901512145996, 32.24532508850098, 32.92354570116316, 12.619298304830279, 0.2758265749684402, 0.12825313370142663, 0.05007455784029194, 0.06328605195241314, 0.06589388594563518, 0.06220078268753631, 0.0366884766678725, 0.043942691159567664, 0.033640365049775155, 0.03844326322099992, 0.01176309835032693, 0.04480141454509326, 0.07213756162673235, 0.033622706175914834, 0.013321650031554912, 0.03701744062293853, 0.06001407466828823, 0.049117921851575375, 0.005007713118435017, 0.058279610238969326, 0.024898991787007878, 0.03575606098664658, 0.07526923143970114, 0.11561765814466135, 0.11981762706169061, 0.2546467828963484, 0.17552949115633965, 0.2384803332388401, 0.12495598276810986, 0.17871247178741864, 0.07925470865198544, 0.06872228453201906, 0.16435304230877332, 0.13054261941994938, 0.17022517935505935, 0.175684834963509, 0.1461442836693355, 0.12288954508091722, 0.11916365501071725, 0.21811023700450147, 0.15485268352287157, 0.12424419953354768, 0.15185305662453175, 0.10108372302992003, 0.07205752842128277, 0.14679091397140706, 0.1596210612250226, 0.10309171849595648, 0.11842672526836395, 2.0959023918424333, 24.16408896446228, 37.07337120601109, 41.727333681924, 47.773888860430034, 30.00349576132638, 19.402511051722936, 3.9138720631599426, 0.7803210254226411, 1.5614291514669145, 0.3442057514829295, 0.22206735823835644, 0.3807533032127789, 0.18792020556117806, 1.6074332829032625, 4.835533670016697, 1.1212555595806666, 3.4526250192097256, 13.89507441861289, 34.95544563020979, 49.07166297095162, 56.04259259360177, 51.131393909454346, 51.56447512762887, 49.62188039507185, 46.289850916181294, 43.82268108640398, 41.04116085597447, 39.750894274030415, 41.001566546303884, 40.72946119308472, 41.2821695463998, 37.53564180646624, 39.02926826477051, 36.01929473876953, 45.3158837045942, 47.339497906821116, 50.52378783907209, 48.06955555507115, 47.17674330302647, 43.12473106384277, 46.59278195244925, 46.05208356039864, 45.96057578495571, 42.061253683907644, 50.878347464970176, 50.178594384874614, 45.755701201302664, 41.14386912754604, 37.53291811261858, 37.74962895257132, 37.590973785945344, 34.424269744328086, 34.76830284936087, 34.88066216877529, 37.63526160376412, 43.94961077826363, 48.107523986271445, 48.69597039903913, 49.571224553244456, 46.80274609157017, 49.23802716391427, 35.97711222512381, 36.482076031821116, 50.52461467470442, 47.46008389336722, 45.97845002583095, 44.11917461667742, 41.20324495860508, 40.0704836164202, 37.46407536097935, 36.8854467528207, 37.32265520095825, 35.93505130495344, 35.918872424534385, 36.23403229032244, 36.554757663181846, 33.78640079498291, 35.09288099833897, 34.840234075273784, 35.60172537394932, 35.64917809622628, 35.73049633843558, 37.95274911608015, 38.42620631626674, 44.193113871983115, 46.064736230032786, 45.7868013381958, 46.27715655735561, 45.27279792513166, 39.256988525390625, 35.06229155404227, 34.81114196777344, 36.112886973789756, 42.80553082057408, 47.696805545261924, 45.95474624633789, 47.09222541536604, 45.465370723179404, 45.46659360613142, 45.08434888294765, 46.64155830655779, 44.075369698660715, 45.353987625667024, 47.30337422234671, 45.03164332253592, 35.381474426814485, 11.971155575343541, 1.5586655054773604, 3.476675340107509, 6.580790443079812, 18.92473554611206, 22.170730692999705, 8.972911477088928, 1.8073827879769462, 0.9219017539705548, 0.3896973989903927, 0.3929108865559101, 0.4118632110101836, 0.20500659942626953, 1.2903489832367216, 11.196757997785296, 34.183907236371724, 34.805833544049946, 38.09259898321969, 38.62481015069144, 13.383231026785714, 0.3105646366519587, 0.1996534059622458, 0.15267021634749003, 0.19423173474414007, 0.21410099071051392, 0.20148066005536489, 0.11496707876878125, 0.1466741245239973, 0.1303962729871273, 0.15427142328449658, 0.07467389838503939, 0.15408116206526756, 0.21776930029903138, 0.1029210669387664, 0.06744958353894097, 0.24188864177891187, 0.18032990928207124, 0.08468383696994611, 0.06940099596977234, 0.14550903918487684, 0.1321433785238436, 0.17143825069069862], [0.029319555831274817, 0.048756171084408245, 0.020625769925702895, 0.05273659321080361, 0.0058210658358543044, 0.01897013939118811, 0.021935557946562767, 0.011490815818043692, 0.035115574819168875, 0.04458596271329692, 0.03405765051554356, 0.04244540525334222, 0.052860300322728496, 0.046508120106799264, 0.056310243771544526, 0.0550577393732965, 0.034670462632285695, 0.006527378381828645, 0.0313239245276366, 0.031142606399953365, 0.03610231740666287, 0.027029495054323758, 0.0276890921606017, 0.034431268860186846, 0.08432155355278935, 0.04618935114038842, 0.04277787723445466, 0.052958233281970024, 2.9650586332593645, 17.283699580601283, 16.57074839728219, 33.200382777622764, 28.48746657371521, 16.969475984573364, 8.952577573912484, 0.4275132140942982, 1.7356399233852113, 0.17114262655377388, 0.050248608857925446, 0.06529567590249435, 0.06350624335131475, 0.22646886562662466, 0.9164190824542726, 1.456641088638987, 0.3751785952065672, 2.9436095442090715, 14.271609459604536, 37.623064041137695, 49.698376587459016, 50.55374499729702, 49.16334792545864, 45.70006002698626, 44.497003759656636, 41.90097958700997, 39.20536688395909, 38.793026038578574, 39.62041057859148, 39.51113278525216, 37.075691904340474, 35.11147090366909, 34.69315808159964, 34.980010986328125, 38.3604416166033, 43.130647454942974, 46.33261360440935, 48.41990457262312, 47.61603273664202, 46.97720840999058, 47.66913781847273, 47.70076949255807, 48.5290572983878, 44.809075151171, 43.15438597542899, 47.011925084250315, 45.32331132888794, 43.279137407030376, 35.57097612108503, 32.87244170052664, 34.44677495956421, 33.742456912994385, 31.66123172215053, 32.0420103754316, 35.02229772295271, 36.26022699901036, 40.84722621100289, 42.65909406117031, 42.6036057472229, 43.202210426330566, 48.2246914591108, 44.3457692691258, 34.57960019792829, 48.228134291512625, 45.22026606968471, 44.88320895603725, 42.73368297304426, 39.55377388000488, 36.735323974064414, 35.397271156311035, 35.70464209147862, 35.82518291473389, 32.67143726348877, 32.45770372663225, 32.36848538262503, 30.459676265716553, 33.158196789877756, 32.01474217006138, 32.182791301182334, 31.693492208208355, 33.62182576315743, 34.00684976577759, 34.43657847813198, 37.01742778505598, 40.679371629442485, 42.156329359327046, 44.902900150844026, 44.024578366960796, 43.927188941410606, 38.649556159973145, 32.71136161259243, 32.084581988198416, 33.54226541519165, 39.05539696557181, 41.92135517937796, 44.16902099336897, 42.83570684705462, 43.923124245234895, 43.70801843915667, 42.4827036176409, 42.50048753193447, 43.41052784238543, 44.72869838987078, 44.21139805657523, 34.952510016305105, 15.513758897781372, 2.1950164905616214, 1.788433856197766, 2.636072503668921, 3.989751602922167, 7.175045549869537, 6.206811904907227, 3.3903869645936147, 1.37281411247594, 0.37453512687768253, 0.17324026328112396, 0.23125979783279554, 0.048302102235278914, 0.04607908919985805, 1.7036772327763694, 12.864463755062648, 27.36041143962315, 23.62108724457877, 28.912216901779175, 21.21915578842163, 2.916104014430727, 0.07048443319009882, 0.0412856735555189, 0.05518248803647501, 0.00810897268820554, 0.003471857585412051, 0.04492557966815574, 0.02723315734017108, 0.020307689672335982, 0.0424737273050206, 0.06336530484259129, 0.043054119018571715, 0.05389278634850468, 0.08240951650909015, 0.033467097740088186, 0.025186592247337103, 0.03360907440739019, 0.041449960454234054, 0.04154672294056841, 0.01851111723642264, 0.0427129448258451, 0.03077994639586125, 0.017990494279989173, 0.04276064923033118, 0.030452797521970103, 0.027253761056012342, 0.019075809345979775, 0.017808697785117795, 0.01158396849807884, 0.03096410079992243, 0.053333436005881855, 0.021685256556208645, 0.042489750909485986, 0.05957863160542079, 0.01729517400131694, 0.04948315689606326, 0.0055128209475827005, 0.03822936862707138, 0.04887945071927138, 0.03262004515688334, 0.035469688674701114, 0.0649513600926314, 0.011374572591323937, 0.08003469144127198, 0.035521080917013545, 0.05233009645183172, 0.06499066084091153, 0.07599404933197157, 0.0016770534753699654, 0.054761402774602175, 0.0361455807994519, 7.1663398912974765, 28.16112879344395, 27.013889142445155, 43.34144537789481, 30.715679168701172, 22.068722452436173, 8.873006803648812, 0.407986224762031, 1.3938682398625781, 0.11496226117014885, 0.04317432149712529, 0.12728098300950869, 0.05325994048533695, 0.3243941574224404, 1.1073612251452036, 1.8764079298291887, 1.851243074451174, 4.807614505290985, 17.08798793384007, 40.174432141440256, 51.53039421354021, 53.44298662458147, 50.53533227103097, 48.232355322156636, 46.516699177878245, 43.30141680581229, 41.19679703031267, 40.680042130606516, 39.90327174322945, 41.23863908222744, 38.05227858679635, 37.177333627428325, 35.3097551209586, 35.90193271636963, 38.65677186420986, 45.32773733139038, 47.52898917879377, 48.91837528773716, 47.99706847327096, 46.666627407073975, 48.168199130467, 48.347441809517996, 49.22468662261963, 44.91117892946516, 43.96046733856201, 49.00321626663208, 46.73407357079642, 44.624197483062744, 37.899588448660715, 33.87285375595093, 36.88111455099923, 35.43652500425066, 34.29682241167341, 33.62392411913191, 35.89100667408535, 38.20386048725673, 42.66367987224034, 44.41497680119106, 45.31480325971331, 45.176190171922954, 49.07523087092808, 46.00868163790022, 36.514729091099326, 47.61825616019112, 47.62380429676601, 46.49560792105538, 43.77427993501936, 41.235078130449565, 38.668104376111714, 37.1407652582441, 38.51799896785191, 35.86815057482038, 34.340780190059114, 35.5968199457441, 33.67735229219709, 32.345052582877024, 33.42880828039986, 33.370276655469624, 33.20641728809902, 32.145833832877024, 35.16851561410086, 36.58951255253383, 35.309744698660715, 38.9056841305324, 42.28012888772147, 45.09381232942854, 45.30190740312849, 44.00575222287859, 45.09583078111921, 40.29246119090489, 34.59667192186628, 33.125661849975586, 34.88255902699062, 41.603356974465505, 43.71922588348389, 45.07090064457485, 44.39256191253662, 45.45035566602434, 44.32914570399693, 44.113657746996196, 44.56969928741455, 44.36174317768642, 44.8335988180978, 44.91687297821045, 35.9629795891898, 19.29340522629874, 3.812549957207271, 2.0649727029459815, 3.6282418242522647, 7.0332084979329785, 7.554649523326328, 6.7997846347945075, 5.486894283975873, 1.3512357217924935, 0.47735313113246647, 0.48216323873826433, 0.3377573075039046, 0.14290646383804934, 0.1939369384199381, 1.5254666869129454, 15.027576071875435, 30.842021737779888, 29.6294082232884, 33.314340182713096, 26.3774984223502, 4.626454123428889, 0.02088077356373625, 0.08684687090239354, 0.03233273307393704, 0.03865054549117174, 0.044647241210831065, 0.020181656881634678, 0.05084801312269909, 0.06478537007101945, 0.0342142156857465, 0.03779226315340825, 0.03740907746500202, 0.05707078653254679, 0.0729887770222766, 0.04195053270086646, 0.03650312125682831, 0.04944103004943047, 0.06793770806065627, 0.05474444618448615, 0.04017001949250698, 0.02382685726375452, 0.03523272728281362, 0.0119146762881428, 0.1410724108240434, 0.10301686929804937, 0.10555812543524162, 0.10894769962344851, 0.28912037877099855, 0.14912043325603008, 0.06440566865993397, 0.17145560761647566, 0.10672595884118762, 0.16015217772551946, 0.14645194501749106, 0.13871433878583567, 0.14803179167211056, 0.09710380301943847, 0.17520108020731381, 0.17012421334428446, 0.09573152701237372, 0.128897063434124, 0.08882864098995924, 0.0946768189647368, 0.17973819960440907, 0.1246580109000206, 0.15172621128814562, 0.22241434747619288, 0.24885817351085798, 0.14995594056589262, 0.163165185334427, 0.10452981918518033, 9.559138808931623, 36.15905775342669, 34.33722618647984, 47.33504063742501, 38.012910093579976, 28.479001930781774, 11.014239243098668, 2.5793272171701704, 4.30893577848162, 0.4100982871438776, 0.1393932266426938, 0.3870505153068474, 0.16066073972199643, 0.9280539495604379, 2.6540316428456987, 4.0974895017487665, 1.2147479142461504, 4.733369963509696, 17.325169903891428, 40.14113637379238, 52.71947765350342, 53.995239870888845, 52.911042962755474, 49.74683332443237, 48.04370130811419, 46.486179215567454, 44.58076776776995, 42.17643744604928, 42.80174057824271, 44.2380930355617, 40.51771484102522, 38.69468470982143, 36.939934526171, 37.96268504006522, 41.310076986040386, 46.411944661821636, 48.943836961473735, 51.85599027361189, 50.8475843157087, 49.78372131075178, 50.50111934116909, 51.375664779118125, 51.5275593485151, 46.28283323560442, 44.06063256944929, 50.416994026729036, 48.4524256161281, 46.25922325679234, 40.411119052342, 36.49713625226702, 38.68641287939889, 37.224532740456716, 34.47895901543753, 35.68283864430019, 38.70934540884835, 39.26294313158308, 43.38002872467041, 46.39628342219761, 46.91910409927368, 46.22281469617571, 49.83405406134469, 48.268892424447195, 40.01792744227818, 47.44128554207938, 49.26095969336373, 47.30412115369524, 45.68782424926758, 42.92523438589913, 40.41419015611921, 39.47597142628261, 40.28356749670846, 39.077773639133994, 35.545073236737935, 35.365403243473594, 35.20650141579764, 32.44386638913836, 35.09205068860735, 34.37344019753592, 34.94868850708008, 32.921485560280935, 37.052238259996685, 37.77052565983364, 36.93251732417515, 41.62036616461617, 43.555453368595664, 46.77523817334856, 48.116973536355154, 44.88275037493025, 47.88124547685896, 41.69670949663435, 36.24265847887312, 34.53002827508109, 37.0195608820234, 42.71002088274275, 45.31328507832119, 47.21172400883266, 44.89336027417864, 47.56105164119175, 45.938800130571636, 45.7947153363909, 45.812589577266145, 45.90341295514788, 46.45543691090175, 46.39755841663906, 38.10831233433315, 18.36553236416408, 3.4250447962965285, 2.6266131826809476, 7.923641426222665, 9.211383206503731, 12.461542929921832, 11.711001123700823, 11.426760741642543, 2.4584687309605733, 1.7494641244411469, 0.604782930442265, 0.992193205016, 0.2107287530920335, 0.19772758787231787, 2.3387004605361392, 17.292707920074463, 36.82960755484444, 33.078223024095806, 38.42577205385481, 29.482325281415665, 4.433459656579154, 0.186796904408506, 0.2750097002301897, 0.10449251332985503, 0.17721630207129888, 0.10865964115198169, 0.15370509081653186, 0.1090437937527895, 0.15773144976368972, 0.14074868176664623, 0.1429687397820609, 0.13058703632227012, 0.09350691602698394, 0.21178677917591163, 0.10792648406433207, 0.20863661249833448, 0.09559316693672112, 0.1936306341418198, 0.15251700314027922, 0.12640351509409292, 0.10138414440942661, 0.12589073260979994, 0.17365062768970216], [0.053823925222137144, 0.06862243131867476, 0.024843608062448244, 0.018753786804154515, 0.040996505679296594, 0.04008107712226255, 0.07963749739740576, 0.023843881707372408, 0.054770885301487784, 0.05508737439023597, 0.03875394065731338, 0.038474594575486014, 0.02441284349853439, 0.030353897650327002, 0.04751346133915441, 0.046282429181571515, 0.008796630610179688, 0.02646656713581511, 0.01817857740180833, 0.07526203896850348, 0.06540586998952286, 0.025376634639022604, 0.02134893897787801, 0.076476284169725, 0.04386958918933358, 0.06177490018308163, 0.03405999485403299, 0.10851450251149279, 1.7069764328854424, 11.978185415267944, 14.221048286982946, 24.468942914690288, 32.990463801792686, 16.995208638054983, 19.039651802607946, 2.803437237228666, 0.8080406465700695, 0.15864251873322896, 0.039470290432551076, 0.17680177145770617, 0.020562869729474187, 0.13469851070216723, 0.35190033859440256, 1.8761953583785465, 2.212262353726796, 0.6666379113282476, 1.9971585018294198, 18.939941678728374, 40.030607904706685, 53.02034854888916, 49.22680582318987, 47.93535457338606, 47.37295348303658, 44.125560011182515, 40.94992406027657, 40.049437522888184, 40.15231255122593, 40.499267373766216, 40.83038377761841, 38.98989282335554, 33.68013851983206, 33.94139773505074, 34.552384104047505, 40.46500928061349, 44.15561791828701, 47.771189485277446, 46.671428612300325, 47.343569551195415, 47.42449174608503, 45.107392583574565, 45.91625670024327, 47.026571886880056, 44.13007286616734, 45.06788512638637, 47.22725670678275, 43.97424909046718, 41.71007088252476, 34.82289831978934, 33.92299543108259, 34.6977994782584, 33.293707506997244, 33.19604362760271, 33.589259556361604, 35.279756273542134, 37.17211205618722, 38.57149314880371, 41.228730951036724, 43.50997393471854, 45.19757325308663, 43.45633731569563, 35.46438728060041, 45.43065057482038, 45.212199211120605, 45.198202065059114, 44.30015434537615, 43.391712120601106, 41.132432392665315, 38.997966630118235, 36.99529777254377, 37.15905639103481, 34.02994557789394, 31.04942546572004, 31.46766185760498, 31.342347621917725, 33.73474441255842, 32.7359756061009, 31.12483079092843, 32.43401036943708, 35.08134698867798, 36.4180588041033, 38.74432264055525, 41.29895639419556, 42.14081750597273, 42.587607519967214, 43.23198693139212, 43.62467132295881, 43.8170599937439, 38.66528688158308, 32.888651847839355, 31.84203427178519, 34.08175482068743, 40.73850427355085, 42.1633539881025, 44.11931358064924, 44.33209521429879, 43.11739029203142, 43.19368151256016, 41.726016998291016, 43.502178055899485, 41.731040545872276, 43.48629099982125, 36.64797469547817, 20.860422032220022, 4.503678585801806, 0.767844666327749, 1.8927147005285536, 2.041825213602611, 8.106421606881277, 9.001029099736895, 6.837918085711343, 3.304482477051871, 0.5101740871156965, 0.7129358212862695, 0.0772113072286759, 0.3279833091156823, 0.20445801743439265, 0.5652215161493847, 4.238931809152875, 16.751156636646815, 23.31182987349374, 25.40808401788984, 29.925780160086497, 15.160152912139893, 0.97055065206119, 0.0907468730583787, 0.023586109646462967, 0.05121292247037802, 0.004787406792664635, 0.03138848713466099, 0.06309831488345351, 0.018070897287023917, 0.036233705534998856, 0.020868178257452588, 0.028891590224312882, 0.049371989111282995, 0.050141169623072655, 0.0243264642943229, 0.05324320102642689, 0.006801520524147365, 0.03495946087475334, 0.020142233997051204, 0.007304605046686317, 0.031481381971389055, 0.017690656440598623, 0.07531123275735549, 0.021607803480167474, 0.04874104653884258, 0.07050444318779878, 0.004140485568703818, 0.007841172727889248, 0.0431237604602107, 0.025634179390700798, 0.04128541910488691, 0.07957062098596777, 0.03971794553633247, 0.021462001571697847, 0.037423750784780295, 0.03427354000242693, 0.01118011208849826, 0.037048157903232744, 0.03933201178110071, 0.07418137695640326, 0.11222458271575825, 0.04106362975601639, 0.034477755294314454, 0.024000623296680193, 0.018962587296430553, 0.04295494094757097, 0.036521116005522866, 0.027684369556871907, 0.010750121902674437, 0.040317814597593885, 0.06564946406121765, 0.04884010247353997, 1.8380866604191917, 18.213240010397776, 21.84425047465733, 35.73482506615775, 40.48200110026768, 20.7026458127158, 20.025682823998586, 3.8757442576544623, 1.4665750584432056, 0.15540332826120512, 0.020523584248231988, 0.12445101700723171, 0.019612788389037763, 0.3871341108211449, 0.4973527608173234, 3.023584612778255, 5.587796458176204, 2.482292584010533, 2.328062334230968, 21.936447858810425, 42.61456653050014, 54.15861981255667, 52.352473803928916, 49.27665567398071, 47.252440452575684, 44.32699523653303, 42.38030801500593, 41.91269424983433, 41.86185428074428, 41.821311541966026, 42.982084546770366, 40.428565979003906, 36.39612681525094, 35.31273589815412, 37.87643357685634, 39.684118611471995, 47.210455962589805, 49.264145442417686, 49.49915088926043, 48.035853317805696, 48.44041218076433, 46.85038294110979, 48.34161227090018, 47.02441447121756, 43.61396414893014, 45.73844535010201, 48.052532468523296, 45.7463732446943, 43.0407064982823, 37.22079113551548, 35.29452466964722, 34.90106207983834, 34.439197949000764, 34.538525921957834, 34.85236215591431, 36.67695215770176, 38.77774347577776, 41.201865741184776, 43.382245200020925, 46.326433181762695, 46.08787373134068, 45.26053435461861, 37.83622087751116, 45.31000900268555, 46.840697152274, 48.48784058434622, 45.741380964006694, 44.21562950951712, 42.341026374271934, 40.884892395564485, 37.7909950528826, 38.077333790915354, 35.69080127988543, 33.98131513595581, 32.744435037885395, 32.189086369105745, 34.712824957711355, 33.63636834280831, 33.86262253352574, 33.72214732851301, 35.57654162815639, 37.8025985445295, 39.40689243589129, 42.28043460845947, 44.91180426733834, 45.32686880656651, 44.250662326812744, 44.9226712499346, 44.734896183013916, 40.29568862915039, 34.38506800787789, 33.75672851290022, 34.3325708934239, 42.13375118800572, 43.70058386666434, 44.84931564331055, 45.282233578818186, 44.78339113507952, 43.71499790464129, 43.27528463091169, 44.72701692581177, 43.402412346431184, 44.98260988507952, 39.66019943782261, 23.231998545782908, 6.212748272078378, 2.1991841069289615, 3.2884160705975125, 3.686394989490509, 8.576061640466962, 8.951067209243774, 8.727709548813955, 4.401631261621203, 2.026605401720319, 1.295956613762038, 1.1877819555146354, 0.3033229038119316, 0.1257549034697669, 0.19635640430663312, 4.817660731928689, 19.65652503286089, 27.316014187676565, 27.465497732162476, 33.058816705431255, 19.22048388208662, 1.417576579110963, 0.04911323317459651, 0.027356443760384406, 0.05979657705341067, 0.01748709423866655, 0.03649728246299284, 0.060156634875706265, 0.020843567792326212, 0.05897608572351081, 0.005258343174188797, 0.04695761562990291, 0.04867379693314433, 0.013189512970192092, 0.03202141781470605, 0.03539489715227059, 0.05351476091891527, 0.04524467093870044, 0.0096286273494895, 0.015493105431752545, 0.034658710405762704, 0.009062679101979094, 0.05050196026318839, 0.04280428242470537, 0.1184841293309416, 0.14173076621123723, 0.1196347890155656, 0.1584941909781524, 0.13079762645065784, 0.1644745407892125, 0.12650571603860172, 0.17032702746135847, 0.22659747515405926, 0.12073105733309474, 0.15064808699701512, 0.10626585781574249, 0.0739170332838382, 0.18268514504390104, 0.1476892400532961, 0.18978496907012804, 0.2680090644529888, 0.1796462173972811, 0.1222006149057831, 0.26993580535054207, 0.1512113796280963, 0.17269762525601046, 0.10896801496190683, 0.1186834422073194, 0.08156626032931463, 0.18719193392566272, 0.08736089510577065, 0.1497755859579359, 2.401664819036211, 24.456495216914586, 33.02224833624703, 42.4953875541687, 45.172160216740195, 27.20241982596261, 25.368413278034755, 7.3746442794799805, 2.1327864698001315, 0.29558955878019333, 0.14286940225533076, 0.4730701638119561, 0.43091812995927675, 0.7561630617294992, 1.3393173898969377, 4.934120791299002, 7.802039265632629, 1.9585710295609065, 3.2750611986432756, 21.71419756753104, 43.9120557648795, 56.52256720406668, 53.07848760059902, 52.46325240816389, 50.25748075757708, 46.90284878867013, 44.245965344565256, 43.67084905079433, 44.45597464697701, 44.979493618011475, 45.97582360676357, 43.45273814882551, 38.51413229533604, 36.11774376460484, 39.0043728692191, 42.82289784295218, 49.7149202483041, 50.66639266695295, 50.08136824199131, 50.47924641200474, 51.454968043736045, 47.350764410836355, 50.3504615511213, 50.30468334470476, 45.01548181261335, 47.261094433920725, 51.27129241398403, 47.49883052280971, 46.47122321810041, 39.33885220118931, 37.72565419333321, 37.82052142279488, 36.29174402781895, 36.03802013397217, 36.405447823660715, 39.1524007661002, 39.90822580882481, 42.00728702545166, 43.38851594924927, 47.45344488961356, 47.8617662021092, 47.078843184879844, 39.981907980782644, 44.87982865742275, 47.82829325539725, 49.299595151628765, 47.847782952444895, 47.248299326215474, 44.74061802455357, 42.6644024848938, 39.21890892301287, 40.18348911830357, 37.40206616265433, 35.39589888708932, 33.79009028843471, 33.34134783063616, 36.37957273210798, 34.57384014129639, 34.427125453948975, 34.963647978646414, 37.75350604738508, 39.74048587254116, 41.59989677156721, 45.38987854548863, 46.27874422073364, 46.37679719924927, 45.72365263530186, 44.97766971588135, 46.3589368547712, 41.76111929757254, 35.86150114876883, 35.06140913282122, 36.72129556110927, 43.72980451583862, 44.802158219473704, 47.67128133773804, 45.934169156210764, 46.614376953669954, 44.74937275477818, 43.770743301936555, 47.27718646185738, 45.104519503457205, 44.82845715114048, 40.47009883608137, 22.27135103089469, 5.703115710190364, 1.5203681205000197, 4.569362078394208, 7.563385146004813, 14.690680503845215, 15.478192806243896, 16.80812665394374, 10.22287677015577, 1.7738428562879562, 1.4393426797219684, 3.1517330620970045, 2.081054525715964, 1.6623165607452393, 1.0704281841005598, 6.073844228472028, 22.483620234898158, 31.898905277252197, 36.65625, 40.15224654333932, 20.622892652239116, 1.4805526626961572, 0.20253141224384308, 0.18247254645185812, 0.1421812456101179, 0.1200502695781844, 0.1760510674544743, 0.17300272174179554, 0.15993295663169452, 0.16045479077313626, 0.1393885990338666, 0.07776647779558386, 0.15217816989336694, 0.15985788351723126, 0.1172288531171424, 0.1420447922178677, 0.11909285666687147, 0.12283398663359028, 0.09966966283640691, 0.12355235165783338, 0.14826017298868724, 0.09219746557729584, 0.13094188299562248, 0.13004252554050513], [0.04153120484469192, 0.06318273821047374, 0.04395864691053118, 0.018284649388598542, 0.03827698142932994, 0.0632040984928608, 0.053962865445230684, 0.013845818333460816, 0.0066976359646235195, 0.015898640367335508, 0.0409965022866215, 0.03934682080788272, 0.05378093324335558, 0.047399799938180616, 0.028898015950939486, 0.02254651766270399, 0.0339784620861922, 0.018740602868742177, 0.04014031322939055, 0.0240420376815434, 0.03670972838465657, 0.021611260616087487, 0.023444433230906725, 0.04792587153081383, 0.05370893728520189, 0.030813089438847134, 0.08193917639021363, 0.048348663308258565, 0.06579338133867298, 4.450600862503052, 20.949970415660314, 22.365222930908203, 37.376552377428325, 35.14472150802612, 23.467026574271067, 7.057526324476514, 0.7086614306483949, 0.04381918760814837, 0.10447132946657282, 0.18133468393768581, 0.08525919395365886, 0.3068866511540753, 0.44543351392660824, 2.1123242420809607, 2.6998506699289595, 3.1258564506258284, 0.20768955403140613, 2.696486004761287, 21.51889933858599, 48.789159638541086, 54.036015374319895, 48.41478375026158, 48.06326396124703, 45.955632141658235, 43.57899733952114, 42.80265426635742, 41.75328867776053, 41.07477971485683, 41.319047110421316, 41.12061698096139, 37.904059614454, 35.12216765539986, 33.34137562343052, 35.862216813223704, 42.20291355678013, 42.415497166769846, 44.35969693320138, 46.14683614458357, 44.23469884055001, 44.91717175074986, 45.92633853639875, 46.96743924277169, 46.97667687279837, 44.708517347063335, 48.63262367248535, 45.70369046075003, 43.986651624952046, 41.061456544058665, 36.52244853973389, 33.1706931250436, 32.32906130381993, 32.99992030007498, 32.89640603746687, 34.20956345966884, 34.870747089385986, 35.29053292955671, 41.033354554857524, 43.46435901096889, 46.38256420407976, 45.46679162979126, 33.47974899836949, 44.1819064276559, 43.818790095193044, 46.816649436950684, 46.188115392412456, 46.90923765727452, 43.454808712005615, 42.82445771353585, 40.2471797806876, 37.44892133985247, 33.45538166591099, 31.949832098824636, 31.811410086495535, 33.22576107297625, 33.35321882792881, 31.15158482960292, 32.64473533630371, 34.292160170418875, 37.86682769230434, 41.37804079055786, 40.904778139931814, 42.57473945617676, 42.96840354374477, 45.362360204969136, 44.90589482443673, 44.83266428538731, 42.4707909311567, 39.5568345614842, 33.41216039657593, 32.08256006240845, 36.74801138469151, 42.55127886363438, 45.950240339551655, 44.20200061798096, 43.484880515507285, 46.14418193272182, 43.98158638817923, 42.36838143212454, 40.68506915228707, 42.70394468307495, 34.88079765864781, 23.94556290762765, 9.673522659710475, 0.9612016337258475, 0.9009252509900502, 3.2270287360463823, 2.414090152297701, 6.41893823657717, 5.924396727766309, 4.065195577485221, 4.640644082001277, 2.3431275486946106, 1.4369911487613405, 0.7746383760656629, 0.14441000244447164, 0.047670606656798294, 0.7630651742219925, 7.124086592878614, 20.82319358416966, 22.96408121926444, 29.345216478620255, 25.19950430733817, 5.196868223803384, 0.19087962247431278, 0.030163137707859278, 0.05169321669797812, 0.03246857239199536, 0.04916301728891475, 0.04092727814401899, 0.026077905669808388, 0.07534370065799781, 0.05197790624307735, 0.06162343081086874, 0.0229792381038091, 0.03756851623100894, 0.0679654058601175, 0.09058812300541572, 0.057493215293756554, 0.013776668829710355, 0.031629116008324284, 0.0325654943340591, 0.018097582372969816, 0.06407626026443072, 0.044061129447072744, 0.031014763617089817, 0.0037874043586530854, 0.014464232604950666, 0.02425882453098893, 0.03197048358353121, 0.008578944701834448, 0.037411292881837914, 0.07915072994572775, 0.07048363930412702, 0.021671619698671356, 0.04073127651853221, 0.016660433329109634, 0.01070771855302155, 0.016582868294790387, 0.03560987740222897, 0.09235331828572921, 0.012175989453680813, 0.023541660513728857, 0.05954847750919206, 0.031710815017244647, 0.02203899891381817, 0.04968196426385215, 0.0467529898243291, 0.028147797100245953, 0.02622752433775791, 0.05572740254657609, 0.05223679788676756, 0.05184949688347323, 0.02421520321097757, 0.08014269386019025, 0.09802636637219361, 8.927772504942757, 26.929185390472412, 30.41298089708601, 44.93762377330235, 33.966730867113384, 30.100179944719585, 9.251329268727984, 0.5452437624335289, 0.03168453535597239, 0.06597099466515438, 0.20445254844214233, 0.19864131669913018, 0.18491418686296257, 0.5512319153973034, 2.010819745915277, 6.665220609733036, 4.735058810029711, 1.062979172383036, 3.8675058654376437, 26.44750326020377, 50.45834275654384, 55.30234888621739, 49.98550394603184, 49.87363447461809, 47.08892502103533, 44.91453490938459, 43.56784895488194, 44.51096616472517, 42.76106582369123, 44.079639366694856, 41.95167016983032, 40.10784755434309, 36.609478201184956, 35.20475046975272, 38.31180075236729, 44.99952874864851, 43.99581977299282, 45.004687786102295, 48.231983593532014, 45.793697425297324, 46.190498624529155, 47.48655652999878, 47.92084673472813, 46.947953019823345, 46.00761161531721, 50.65154784066336, 47.54546683175223, 45.19536372593471, 43.110223225184846, 38.40781443459647, 35.470588547842844, 34.60253620147705, 34.731793539864675, 34.269849504743306, 36.24484716142927, 37.303380898066926, 37.6219835962568, 41.88006203515189, 45.80889660971505, 46.89476803370884, 46.977871962956016, 35.785967281886506, 43.38208886555263, 45.30851513998849, 48.16858128138951, 46.89645297186715, 48.82889291218349, 45.18272147859846, 44.057891505105154, 40.82349811281477, 38.635319301060264, 35.12704529081072, 32.61698770523071, 33.492884567805696, 34.464753423418315, 34.636189801352366, 33.269319329942974, 33.553750787462505, 35.42400435038975, 38.670463289533345, 41.11759451457432, 42.56137459618704, 44.38836867468697, 43.839679854256765, 46.70627382823399, 46.87640047073364, 45.400151457105366, 45.774732317243306, 40.9761917250497, 35.430104868752615, 33.89969464710781, 37.56908001218523, 44.16405997957502, 46.0998524257115, 45.78182642800467, 44.884772300720215, 46.55230174745832, 44.572145053318565, 42.52044970648629, 44.88591875348772, 43.25785160064697, 39.414778641292024, 26.404855217252457, 12.636003511292593, 2.2775395938328336, 3.2883628734520505, 4.620542509215219, 5.2403378912380765, 8.99745512008667, 9.155510136059352, 8.408832396779742, 5.631677372114999, 3.7882373418126787, 2.053969144821167, 0.8470926710537502, 0.04643465851300529, 0.0694688901837383, 1.0126563012599945, 7.779809372765677, 20.716497046606882, 27.517748185566493, 33.71024853842599, 30.43968629837036, 8.727436832019261, 0.2975916170648166, 0.050651438135121546, 0.09138247038104705, 0.006940692297316023, 0.023216847496639405, 0.03569633972698024, 0.019049550040758083, 0.10074802461479392, 0.09900165868124791, 0.06378204069499459, 0.03224005536841495, 0.039864702482840846, 0.10405729418354374, 0.07032143550791911, 0.011756093324428158, 0.015945159031876495, 0.05261007696390152, 0.031386923111443005, 0.01619189472070762, 0.04360766449411001, 0.03191351717604058, 0.07335158291139773, 0.028168826596811414, 0.05974059791437217, 0.15050023421645164, 0.13077342989189283, 0.10702859224485499, 0.20025146672768251, 0.1741729775177581, 0.1721913567078965, 0.056122883289520226, 0.12549874292952673, 0.09854609705507755, 0.17687607104224817, 0.12204195984772273, 0.1275785748979875, 0.18743987062147685, 0.07021601830742188, 0.12049414004598345, 0.14260237158409186, 0.09898224579436438, 0.08887022161590201, 0.11039059755525418, 0.12837015385074274, 0.1352384074458054, 0.12833645780171665, 0.1795802909348692, 0.2380031059895243, 0.1579484316919531, 0.12272149909819875, 0.1361275054514408, 0.18529669062367507, 11.622318659509931, 38.91001980645316, 39.82488216672625, 52.11580426352364, 46.252754483904155, 36.208827699933735, 14.760311876024518, 0.9800892259393419, 0.1488340643367597, 0.3051167061286313, 0.6129794706191335, 0.33972109641347614, 0.9278775304555893, 1.1425175900970186, 4.353703022003174, 10.221961344991412, 7.150355126176562, 1.1039913488285882, 4.26919903073992, 26.879302535738262, 53.448527812957764, 56.894872529166086, 51.89622729165213, 52.08338744299752, 49.85661138807024, 49.02303947721209, 45.025876317705425, 45.75327975409371, 44.60152203696114, 45.676606382642476, 43.215405055454795, 42.07670995167324, 39.17872749056135, 36.8730685370309, 39.38947677612305, 47.02416433606829, 45.84058386938912, 46.62381955555507, 49.90950454984392, 48.38153314590454, 48.41700369971139, 49.86541822978428, 50.075590814862935, 49.08699417114258, 46.383807931627544, 53.043315819331575, 49.68086017881121, 47.39350972856794, 45.69202790941511, 40.37282058170864, 36.51586512156895, 35.59373494556972, 36.52648891721453, 35.26587724685669, 38.634565421513145, 37.84589624404907, 40.53064891270229, 44.56721183231899, 46.92582995550973, 48.96217325755528, 48.241572107587544, 38.50089250292097, 43.01990359170096, 44.09838213239397, 50.303707122802734, 48.742690086364746, 51.2703092438834, 47.00253111975533, 45.52833182471139, 44.78941869735718, 41.13408606392996, 37.12165771211897, 34.31078134264265, 34.29559258052281, 36.11701767785208, 35.98126377378191, 34.12327378136771, 34.88820791244507, 36.639959948403494, 39.68275329044887, 44.27079473223005, 44.2528475352696, 45.77374914714268, 46.14434174128941, 49.0686821937561, 47.14384705679757, 46.82657493863787, 47.45804112298148, 43.24856880732945, 36.46931913920811, 35.39509637015206, 38.496223313467844, 45.807420117514475, 48.64133671351841, 46.9606682232448, 45.55435977663313, 48.358055182865684, 44.98031350544521, 45.01797274180821, 43.816639627729145, 45.05534710202898, 37.7838453565325, 25.539547409330094, 11.654606069837298, 1.684903851577214, 2.882532273020063, 8.089717268943787, 6.929154012884412, 13.437856895583016, 13.658867801938738, 11.635289209229605, 10.467855487551008, 5.355473015989576, 5.2856279867036005, 3.2367607738290514, 0.25715019713555065, 0.24439097036208424, 1.3607891691582543, 10.531718117850167, 27.841998032161168, 32.89491217476981, 39.32459102358137, 36.02418279647827, 8.450231501034327, 0.45257238085780827, 0.05365304296304073, 0.1700290555932692, 0.17999343733702386, 0.1496406253427267, 0.16034484095871449, 0.13972266896494798, 0.192955613934568, 0.33935254333274706, 0.10124266985803843, 0.0820875855694924, 0.17636973464063235, 0.1135638819209167, 0.22307201075766767, 0.24653153121471405, 0.08066043643546955, 0.1331276749925954, 0.14117039128073625, 0.05652037928146975, 0.12558463189218724, 0.21259509080222674, 0.15657836092369898, 0.09467469515012843], [0.05647420158077564, 0.06769017848585333, 0.013645184858302985, 0.02747092958140586, 0.021162184088357856, 0.07744558501456465, 0.01867222010956279, 0.01459103892557323, 0.028820174413600137, 0.02308009215630591, 0.090467988380364, 0.039202228388083835, 0.03627705035199012, 0.018718871088432412, 0.04061804937997034, 0.030745982325502803, 0.01807547909473734, 0.06929091044834682, 0.05638816334041102, 0.06303819668080125, 0.07920790330639907, 0.04438101799626436, 0.06400622866515603, 0.018998987307505946, 0.019066401457946216, 0.021942443380664502, 0.054818124909486086, 0.03015046606638602, 0.08129183362637248, 1.6613574922084808, 15.847526039396014, 20.360004084450857, 33.30085025514875, 36.1450571332659, 17.734552553721837, 16.2252995967865, 3.461940816470555, 0.08869283220597676, 0.0035170874575019945, 0.06958876696548291, 0.13754713641745703, 0.0743389395730836, 0.21910597357366765, 2.144613606589181, 6.660841507571084, 2.731315370116915, 1.0194157042673655, 0.10140610858798027, 3.8174080508095876, 28.406360251562937, 52.21677895954677, 53.313100474221365, 48.25486748559134, 46.41636719022478, 46.71075194222586, 43.296431473323274, 43.68254634312221, 43.87774556023734, 44.715204988207134, 44.984235763549805, 39.62649720055716, 36.016418184552876, 35.33469915390015, 35.15014805112566, 36.339478152138845, 38.410875116075786, 41.584294591631206, 40.660719190325054, 42.306726591927664, 42.39295026234218, 44.602098737444194, 45.43412120001656, 46.1931597845895, 44.69149078641619, 45.82203912734985, 45.23867532185146, 46.6740654536656, 44.79526560647147, 40.54640742710659, 36.033000060490195, 35.25098378317696, 33.481180327279226, 32.71393244607108, 33.3118040902274, 34.26121289389474, 38.59214319501604, 42.89173712049212, 45.03035790579659, 46.763117040906636, 44.539099420819966, 32.98540551321847, 43.68660756519863, 44.510764666966026, 44.3775885445731, 48.06096063341413, 44.24682344709124, 47.11316728591919, 43.28497041974749, 41.11431496483939, 39.35638945443289, 34.03332935060774, 32.49354600906372, 32.1158002444676, 32.09861387525286, 31.724950177328928, 32.40332017626081, 33.625292914254324, 40.79946429388863, 41.29907103947231, 42.268035548073904, 44.697275161743164, 44.29985557283674, 44.52037749971662, 43.494538511548726, 43.005006653921946, 43.183481557028635, 43.10647814614432, 39.879237924303325, 34.817023617880686, 33.53295135498047, 40.39445032392229, 42.9385575566973, 43.47036920275007, 45.63441344669887, 43.019146238054546, 44.98790441240583, 44.475888184138704, 43.67896107264927, 42.7046012878418, 38.955707686288015, 29.59773486001151, 13.664186647960118, 3.1710368948323384, 0.7981582454272679, 4.436381808349064, 3.0877729398863654, 3.865527365888868, 5.775080808571406, 8.428648659161158, 7.575167553765433, 2.993437681879316, 4.670616005148206, 1.5844422365937914, 0.3841688313654491, 0.08906088317079203, 0.33706232479640413, 2.74156722000667, 13.40464276926858, 21.621678829193115, 19.70361123766218, 23.875271456582205, 15.250208514077322, 1.8462796722139632, 0.04578137517507587, 0.01830933618891452, 0.00891442344124828, 0.011780507862567902, 0.004693418242303389, 0.013828350297574486, 0.03662022283034665, 0.040448955060648065, 0.012504780382317091, 0.038829855155199766, 0.0888571258900421, 0.025440578082842485, 0.03924940014258027, 0.023515811722193445, 0.09617827446865183, 0.051724978922201056, 0.02173874038271606, 0.04150566478659, 0.03275834755705936, 0.03715274389833212, 0.04326660565233656, 0.021295767277479172, 0.04140297868954284, 0.04809051466041377, 0.07454229651817254, 0.010555954866244324, 0.031070759719503776, 0.009354544154900526, 0.02610630914568901, 0.055989313671099286, 0.03892594589186566, 0.020148093146937232, 0.04308804916217923, 0.049949195102921555, 0.048021283732461076, 0.02281500379155789, 0.032404484759484015, 0.08469556205506835, 0.033565220689134936, 0.004663195868488401, 0.015620240841859152, 0.039750586463404555, 0.06481454029147114, 0.038825570206557, 0.029286653668220555, 0.01593210910713034, 0.026864868888099278, 0.0387969021020191, 0.04346690240449139, 0.036534374579787254, 0.013227784889750183, 0.0847702891166721, 2.4601286990301947, 24.329930305480957, 27.50040374483381, 42.8995920589992, 43.82414020810808, 24.530778408050537, 16.462789024625504, 3.3942699219499315, 0.014893143071926065, 0.042465187941810915, 0.12783925448145184, 0.26395346064652714, 0.3676290517406804, 0.9877280103308814, 2.492770250354494, 3.311130600316184, 4.360755443572998, 2.5913567202431813, 0.2256169377693108, 5.838497451373509, 31.39284712927682, 53.7993597303118, 52.97141238621303, 50.57886273520333, 47.135165282658164, 47.722103936331614, 45.06151015417916, 45.77021598815918, 46.067188944135395, 46.22491652624947, 45.12316152027675, 41.60547964913504, 36.032298292432515, 36.56542314801897, 36.61381735120501, 38.73718684060233, 40.71101719992501, 42.89498540333339, 43.39976855686733, 44.90858377729143, 44.61584227425711, 45.80963659286499, 46.060240745544434, 47.36655419213431, 44.45885467529297, 47.64981140409197, 47.45097827911377, 47.382663590567454, 46.658324309757774, 42.48848451886858, 37.963035924094065, 36.18254961286272, 34.629766191755024, 34.70973300933838, 35.797344957079204, 35.70519099916731, 40.0418883051191, 45.97193261555263, 47.9305533681597, 47.34220423017229, 45.057758126940044, 35.31994465419224, 44.61997297831944, 43.86246647153582, 45.601141997746055, 49.169389384133474, 46.06083829062325, 47.31357765197754, 45.463289737701416, 42.73955420085362, 41.4429543358939, 35.516516140529085, 34.30132484436035, 34.15842471803938, 33.74039677211216, 33.12326124736241, 33.47523961748396, 34.4284143447876, 41.082784039633616, 41.80512918744768, 43.299638066973, 44.712158203125, 45.18934658595494, 47.11082921709333, 45.399418422154014, 44.48967341014317, 45.26981367383684, 43.45960296903338, 41.135083130427766, 36.23597778592791, 33.89251020976475, 41.359332765851704, 44.53375278200422, 44.779750279017854, 46.85616384233747, 45.11864866529192, 44.46332584108625, 45.59753588267735, 44.5026387487139, 43.75116327830723, 40.85358381271362, 31.9384092603411, 16.386824369430542, 4.841474379811968, 1.4179867399590356, 3.7423631634031023, 3.315311244555882, 5.089457758835383, 8.463991539818899, 9.402143393244062, 7.356073481695993, 5.033643313816615, 4.918898156711033, 1.560109862259456, 0.6537374949881009, 0.06640588132930653, 0.3012818976172379, 2.3878413779394965, 14.170530540602547, 25.525197642190115, 24.040018456322805, 29.32287107195173, 20.260257482528687, 2.8704230827944617, 0.07158900677625622, 0.021766675669433813, 0.04134930317689266, 0.04056389889280711, 0.02458064690498369, 0.034831624877239974, 0.02944822981953621, 0.03153641116140144, 0.07047221955976316, 0.029449084773659706, 0.027073866155530726, 0.014879285690507718, 0.034047241788357496, 0.05420160120619195, 0.016613504150882363, 0.015453976013564637, 0.03851898433640599, 0.06296760189746108, 0.02331278725926365, 0.018654379727584974, 0.004655885925915624, 0.025625182016353523, 0.02707451076379844, 0.2111566508454936, 0.2062302559081997, 0.07035819853522948, 0.10122810849653822, 0.16072488842265947, 0.1880448524441038, 0.15524674952030182, 0.12176844238170556, 0.06920006818005017, 0.14243537054530211, 0.16354238295129367, 0.13553985341319016, 0.11723084801009723, 0.0936487094898309, 0.20836408569344453, 0.14302257475044045, 0.05716180521994829, 0.19212340430489608, 0.12585401029459067, 0.16318308508821897, 0.24823907815984317, 0.14161077407853945, 0.23738192075065204, 0.12360647161092077, 0.1296323918338333, 0.13231901052807057, 0.1766579356044531, 0.0764293499024851, 0.12793087027966976, 3.444493672677449, 31.13027123042515, 38.03831965582711, 47.318212100437705, 49.469367436000276, 29.163406440189906, 24.679101603371755, 4.867579196180616, 0.2606223965329783, 0.20548561800803455, 0.5843627718942506, 0.7450275963970593, 0.6767223530582019, 1.7990917414426804, 4.012334551130023, 10.720444219452993, 9.914702449526105, 2.9084525278636386, 0.23673074426395552, 5.251958753381457, 31.855916772569927, 53.411011014665874, 57.21517406191145, 50.94270168031965, 48.67348255429949, 50.69887202126639, 47.57245710917881, 46.8526827948434, 48.44811773300171, 47.501738343920024, 49.22273417881557, 43.34062896456037, 38.278303486960276, 38.93767711094448, 38.722470555986675, 40.67122139249529, 42.646913869040354, 44.33180686405727, 44.28787340436663, 45.21767439161028, 46.11528090068272, 48.47595221655709, 48.3698011125837, 48.473016602652415, 45.577604975019185, 47.28565631593977, 48.50452320916312, 50.292558738163535, 48.41173696517944, 44.237825529915945, 39.19954776763916, 38.59917824608939, 35.63751554489136, 35.98239633015224, 37.49672842025757, 37.38440384183611, 42.29379946844918, 47.23600796290806, 49.85858120237078, 49.70095089503697, 45.77757065636771, 39.23860706601824, 43.9410262789045, 44.19584451402937, 46.775206906454905, 51.389849526541575, 47.647080762045725, 48.95280013765608, 47.679612227848594, 44.914778096335276, 43.695014885493684, 38.4613607270377, 36.64352437428066, 35.46327904292515, 35.229479108537944, 35.20863103866577, 35.89584609440395, 36.10645294189453, 44.565485204969136, 43.35671751839774, 44.673383780888145, 47.07708181653704, 46.336063385009766, 47.50489630017962, 46.63782364981515, 45.21877915518624, 46.079931940351216, 45.503109863826204, 42.75645221982683, 38.843362263270784, 36.88934816632952, 44.41015822546822, 45.980715138571604, 46.38388436181204, 48.555543831416536, 45.20706449236189, 46.300030027117046, 47.00659581593105, 46.015445709228516, 43.83800533839634, 41.735661097935264, 32.34384707042149, 16.505470071520122, 3.997100191456931, 1.6534774750471115, 7.164086503641946, 7.950570038386753, 9.12114521435329, 15.22759907586234, 17.393161501203263, 14.30677342414856, 9.618539827210562, 12.106685400009155, 5.32040719475065, 1.577223601085799, 0.23616715307746614, 0.5550555416515895, 4.149624441351209, 17.700235400881084, 30.74151951926095, 27.141461542674474, 33.89621707371303, 22.916520799909318, 3.14273145369121, 0.18043220522148268, 0.16133691343877996, 0.08032392377832107, 0.13970531203917094, 0.12788559842322553, 0.15911511837371758, 0.1404969859868288, 0.19869235610323294, 0.1140437690275056, 0.08815163946045296, 0.15257237159780093, 0.144232891233904, 0.12555590271949768, 0.12491794409496443, 0.11824504073177065, 0.1389020894254957, 0.13993910806519644, 0.16003812955958502, 0.10419097236756768, 0.11450754771275179, 0.1049010321231825, 0.07399458983646971, 0.12474243422704083], [0.0447012933104166, 0.056559578249497075, 0.006067096696434808, 0.024778545035847595, 0.03500898714576449, 0.00996494832049523, 0.014119209422330772, 0.06049381249717303, 0.06729817523487977, 0.07948186860552856, 0.06372126431337424, 0.06937158147671393, 0.028224086488730142, 0.01705088103855295, 0.07030287757515907, 0.06578730845025607, 0.023980782932734916, 0.017574957738231336, 0.012870570129182721, 0.08509207756391593, 0.11551505007914134, 0.042103528776871305, 0.07549427436398608, 0.01640101073176733, 0.033483898267149925, 0.08804094325751066, 0.0912280154547521, 0.05160908174834081, 0.13736319914460182, 0.24493466690182686, 7.13470778294972, 16.260603393827164, 19.065539053508214, 31.119404247828893, 22.561858688082012, 13.063847524779183, 8.125843558992658, 1.1513152037348067, 0.10893241222947836, 0.1585003656468221, 0.08271798531391791, 0.044396464845963886, 0.6245704772216933, 0.8743621249284063, 4.331915208271571, 4.396696303571973, 2.5148060279233113, 0.4737211231674467, 0.2136615850031376, 3.2880803857530867, 28.5651787008558, 51.082704407828196, 51.10928821563721, 49.83767754690987, 46.078285217285156, 46.103375162397114, 43.77906724384853, 46.078483240945, 44.81470666612898, 44.10111972263881, 40.4512483733041, 38.00569438934326, 35.64049284798758, 35.90843275615147, 34.59436859403338, 34.14017527444022, 35.56766183035714, 39.00096477781023, 38.556207111903596, 40.505037852696006, 41.70056574685233, 46.15769617898123, 45.96893099376133, 47.7513211114066, 45.23721272604806, 45.17206294195992, 47.83315699441092, 46.31794248308454, 42.59824521200997, 37.38207619530814, 34.032846450805664, 34.06324134554182, 33.21037081309727, 32.571515219552175, 37.690291336604524, 42.791165419987266, 44.66520227704729, 47.749493735177175, 47.44313723700387, 45.50496850694929, 33.33018902369908, 42.95106084006173, 45.51957014628819, 46.266835008348735, 43.85130071640015, 46.89960050582886, 42.6651667867388, 42.455449308667866, 46.40316908700125, 40.49445922034127, 33.28760004043579, 31.258990083421978, 32.394238880702424, 32.010920660836355, 32.17884472438267, 31.462739058903285, 37.06053440911429, 42.73102181298392, 44.01593828201294, 44.82063347952706, 42.633861677987234, 45.17881659099034, 44.292681557791575, 43.50930690765381, 45.77641030720302, 44.14426456178938, 43.572236742292134, 38.27577086857387, 34.58692707334246, 36.643718923841206, 41.05552625656128, 43.5605776650565, 44.45297997338431, 44.856600829533164, 44.48183931623186, 43.07870967047555, 44.94741031101772, 43.93252515792847, 44.9015348298209, 33.36646556854248, 21.945586477007183, 7.1900714635849, 1.5260036523853029, 0.9859077994312558, 3.502705463341304, 2.325583781514849, 5.351711869239807, 7.535178065299988, 6.586249555860247, 5.4006341355187555, 4.268347007887704, 2.4205072479588643, 0.8878601949129785, 0.22705889253744058, 0.26822565283094135, 0.9769371322223118, 11.61094011579241, 16.52435006414141, 16.448369775499614, 23.81354366030012, 26.835766860416957, 8.277622614588056, 0.47281682597739355, 0.06758571123438221, 0.02048345229455403, 0.04413737303444317, 0.021828536010746444, 0.04253535185541425, 0.014119003317318857, 0.02902254069756184, 0.050006460065820386, 0.026952354104391167, 0.023924014996737242, 0.03168572957760521, 0.026371502683364918, 0.07571530036096062, 0.043603939336857626, 0.019093748115535294, 0.007020487591424691, 0.04106749740562268, 0.0833107874329601, 0.03853546595200896, 0.038083025586924384, 0.01343248872685113, 0.03990813550938453, 0.024640899118302122, 0.04914787577997361, 0.03982152729960425, 0.010280124443982328, 0.10859329399785825, 0.08113743976822921, 0.04697596660948225, 0.012385269161313772, 0.04266557290351816, 0.0391416996717453, 0.020170060718165975, 0.0846002007435475, 0.05969468144966023, 0.036153149857584915, 0.023012615241376416, 0.06386271172336169, 0.058560238751981936, 0.011779934500477143, 0.003501104989222118, 0.015504374202074749, 0.0700748423114419, 0.01236426510981151, 0.08660833191658769, 0.005597779469098896, 0.06502909984971796, 0.054582445948783836, 0.05891949590295553, 0.046841637031840425, 0.06118405224489314, 0.11522222150649343, 0.2221345603466034, 11.666438852037702, 26.580550840922765, 30.573751790182932, 41.684494563511436, 24.713905130113872, 17.63660032408578, 11.015022652489797, 0.7679336358393941, 0.06087307964584657, 0.17564796337059566, 0.09050589813185589, 0.19657487901193754, 0.9497581677777427, 1.958434454032353, 3.7704642840794156, 4.725372152669089, 3.3074276447296143, 1.8175674357584544, 0.5666846004979951, 5.462141760757991, 33.53082868031093, 52.89948116030012, 51.67950255530221, 50.29023803983416, 47.7633831841605, 47.27143335342407, 45.70392322540283, 47.1824060848781, 45.270081179482595, 44.76613180977957, 42.4859345299857, 40.18078974315098, 36.85106706619263, 37.09115859440395, 36.17551108769008, 36.171901498522075, 38.35019302368164, 40.32521499906267, 40.22356285367693, 43.16387374060494, 43.97139685494559, 47.41128322056362, 47.05479894365583, 46.57195125307356, 45.62664883477347, 46.486307757241384, 49.07743344988142, 46.45902565547398, 43.99866853441511, 39.5928818157741, 36.23184708186558, 35.00394058227539, 35.37400163922991, 33.9959271975926, 38.25126804624285, 43.943645749773296, 46.61679492677961, 48.0500728062221, 48.64644711358206, 46.9662059375218, 36.71939522879464, 43.04597323281424, 45.29653297151838, 46.004269531794954, 44.98689692361014, 47.40104504993984, 44.371512344905305, 44.4662093435015, 47.012077944619314, 41.57078729357038, 35.98009647641863, 32.30541658401489, 33.97060101372855, 33.43639918736049, 34.27633217402867, 33.32822963169643, 38.273936544145855, 44.408789430345806, 45.977560656411306, 45.74695341927664, 45.2430214200701, 46.027278491428916, 44.476774079459055, 43.33848544529506, 46.609912736075266, 44.37894344329834, 44.86074890409197, 39.488380908966064, 35.82292127609253, 37.69121197291783, 41.38634736197335, 46.46705429894583, 45.065185751233784, 46.300776958465576, 44.761813504355295, 45.178566455841064, 45.24492522648403, 46.06626830782209, 44.574795791081016, 36.04965141841343, 24.10351456914629, 8.415670292718069, 1.9022007286548615, 2.167732434613364, 5.09119176864624, 4.0520113706588745, 5.637863874435425, 8.538188746997289, 9.365496856825692, 7.110215817178998, 3.2620569935866763, 3.0138421526976993, 0.7578772583178112, 0.05235006234475544, 0.11143373658082315, 1.0633894417967116, 8.979916998318263, 18.92345881462097, 22.40482939992632, 24.501425743103027, 29.564529418945312, 11.617231709616524, 0.7781322343008858, 0.0020592233756490585, 0.022878898041588918, 0.051091685225921016, 0.05831989486302648, 0.07103589895580496, 0.03741392899038536, 0.0029692571552004665, 0.026601398829370737, 0.032864528109452555, 0.04586783071447696, 0.02809286629781127, 0.07533322407730988, 0.02344522881321609, 0.0606487084712301, 0.027273241796397736, 0.025212454609572887, 0.03303315763228706, 0.004137736653709518, 0.028585757528032576, 0.04516451220427241, 0.0013856925527631703, 0.03292727563530207, 0.02399829592156623, 0.10089029983750411, 0.0765670043017183, 0.10478230206561939, 0.21099499666265079, 0.16967701805489405, 0.11729965146098818, 0.0874309063489948, 0.11655296438506671, 0.15074388257094792, 0.192669150020395, 0.15934541315904685, 0.16094036400318146, 0.11823786183127336, 0.13256271316536836, 0.12399570643901825, 0.20285750260310514, 0.12930107675492764, 0.14714671059378556, 0.06627499870955944, 0.1368002322103296, 0.15155006359730447, 0.12571117867316517, 0.15313726557152613, 0.17125625402799674, 0.11466335292373385, 0.12569804223520414, 0.22385789001626627, 0.10455215655799423, 0.2816668887223516, 0.23792100325226784, 15.617747374943324, 37.222986766270225, 35.81020259857178, 48.09937374932425, 36.80590377535139, 21.94708033970424, 11.852971928460256, 1.5345491766929626, 0.20071886878992828, 0.5243471094540187, 0.5495225499783243, 0.36618002663765636, 1.3574075677565165, 3.494857690164021, 7.143710042749133, 7.809340085302081, 5.882153417382922, 2.352757534810475, 0.44537811832768576, 5.068274438381195, 31.85581602369036, 52.6667651448931, 53.78725249426705, 53.62561307634626, 50.21115016937256, 50.10399505070278, 47.31087132862636, 49.149350779397146, 48.682841777801514, 47.62109449931553, 44.19763714926583, 42.385088375636506, 38.58155761446272, 39.2580064364842, 38.8591867855617, 37.673177923474995, 39.52010638373238, 41.89249931062971, 41.43395641871861, 44.81787157058716, 45.67296552658081, 49.73454543522426, 50.12347779955183, 49.252809456416536, 47.27038764953613, 48.200247696467805, 51.43073272705078, 49.201795782361714, 45.662894112723215, 40.06214230401175, 37.57140418461391, 37.239169120788574, 37.07908609935215, 35.66008676801409, 41.59791306086949, 47.791450432368684, 48.779939379010884, 51.41028765269688, 50.63963862827846, 47.472034794943674, 40.06700951712472, 43.17631449018206, 44.72203506742205, 45.5586815561567, 44.22224072047642, 48.167705808367046, 45.57454081944057, 46.333086081913535, 48.948707648685996, 44.961907727377756, 37.322022914886475, 33.970514161246165, 36.450732707977295, 34.91775860105242, 35.45592090061733, 35.35786097390311, 41.04808473587036, 45.79062979561942, 47.13446698869978, 47.352744647434776, 44.604697363717214, 47.174797807421, 46.82741567066738, 44.20666633333479, 47.95328092575073, 45.45058495657784, 46.824480056762695, 40.97174487795149, 37.84691762924194, 39.24703523090908, 44.39572334289551, 47.537618841443745, 47.06109401157924, 48.4493545123509, 46.8111013003758, 45.61986739294869, 47.076109068734304, 45.00409024102347, 45.182082244328086, 36.61793415887015, 24.44083571434021, 7.713079742022923, 2.4829507086958205, 3.9937958887645175, 7.979946153504508, 5.781927389757974, 11.62246196610587, 12.534049119268145, 14.24484760420663, 14.119562029838562, 11.392749309539795, 7.593368359974452, 3.0118334719112942, 0.815678779567991, 0.6872043077434812, 1.7135105622666222, 13.496898344584874, 23.06332060268947, 25.43875684056963, 32.626586641584126, 36.18781982149397, 12.235213177544729, 0.9542203226259777, 0.18922578836125986, 0.10371887484299284, 0.09130757368568863, 0.18515959940850735, 0.10557863754885537, 0.10061507924859013, 0.1464099572705371, 0.20324877303625855, 0.09550260286778212, 0.1597630243216242, 0.15046052634716034, 0.15208941751292773, 0.19619019036846502, 0.09026640919702393, 0.10012043400534562, 0.0864270409303052, 0.1458110279802765, 0.13978630197899683, 0.0926489627787045, 0.17182315646537713, 0.0677752396357911, 0.1032105435484222, 0.10165924286203724], [0.04556604887225798, 0.02466602187736758, 0.03508348350546189, 0.04342406648876412, 0.02688339798312102, 0.02239400504289993, 0.009189161422130252, 0.004855420598427632, 0.04731224177937422, 0.0149270630375083, 0.028348507758762156, 0.05240758854363646, 0.047538024306829484, 0.027961724138419543, 0.03341140019308243, 0.030780974376414503, 0.05176930422229426, 0.01779123568641288, 0.03372336006058114, 0.060901252419820855, 0.02074472389982215, 0.040157829610896964, 0.04979986311601741, 0.03053987052823816, 0.008628418386381651, 0.0652834079893572, 0.026451588475278447, 0.046118512084441524, 0.03130520374647208, 0.013708889966697564, 1.14494674546378, 7.66178640297481, 15.138646500451223, 18.781724248613628, 33.42756802695138, 24.043322324752808, 11.433444908687047, 4.859126278332301, 0.30584328142660006, 0.11405811325779983, 0.041820990187781196, 0.3934584100331579, 0.8570150243384498, 1.6332451892750603, 1.809908892427172, 2.945791061435427, 3.2711144047124043, 1.085262913789068, 0.6704080147402627, 0.25483864545822144, 4.447594029562814, 29.14137543950762, 47.24520737784249, 48.68679877689907, 49.56740999221802, 46.82433761869158, 46.741025243486675, 45.77660138266427, 45.134000710078645, 44.90755196980068, 43.092230864933555, 43.03216021401541, 42.13954945972988, 42.176590306418284, 41.67648676463536, 39.84531681878226, 35.06944472449166, 33.992647647857666, 37.55735840116228, 38.28190612792969, 41.82335083825247, 45.153261116572786, 47.65842717034476, 47.657440526144846, 43.63353375026158, 44.95401109967913, 48.32554803575788, 46.10343074798584, 42.826153073992046, 39.619708810533794, 35.55834429604666, 34.48073775427682, 35.20908614567348, 33.89610937663487, 35.638404914310996, 41.40679243632725, 46.4479398046221, 46.997955730983186, 49.36062117985317, 44.4737411907741, 35.884947844914024, 43.61648287091936, 42.21804673331124, 45.76529318945748, 42.70781830378941, 42.52502856935774, 43.15378843035017, 48.3920909336635, 44.34445605959211, 41.34812879562378, 31.782613277435303, 31.695750372750418, 32.44908448628017, 32.10162244524275, 31.778829983302526, 33.96884311948504, 41.62501103537423, 44.44700452259609, 43.89066226141793, 43.2920297895159, 44.51489884512765, 43.021644115448, 44.867526871817454, 45.3851363999503, 44.327926295144216, 43.03989355904715, 39.228295939309255, 37.353143896375386, 35.66959885188511, 38.30247974395752, 39.33538852419172, 42.44126456124442, 42.54853432519095, 43.80979912621634, 42.64980779375349, 42.016757420131135, 43.63415561403547, 43.30055522918701, 41.66098880767822, 28.230046238218033, 14.5576103414808, 3.9852461303983415, 0.4291116254670279, 1.0603815232004439, 4.1912367684500555, 2.803472629615239, 2.554328032902309, 6.890636673995426, 8.278532828603472, 4.561916215079171, 2.105831801891327, 1.7891994608300072, 0.5016282371112278, 0.07246163673698902, 0.48780224472284317, 3.930595942905971, 20.106340987341746, 29.196802956717356, 15.695740904126849, 29.474171570369176, 19.829265935080393, 3.367420779807227, 0.05072047228791884, 0.0167327414133719, 0.03791027735652668, 0.03987354040145874, 0.08242566564253398, 0.007960855278984776, 0.027925415729571666, 0.011740078201650508, 0.02458517612623317, 0.1415996461042336, 0.026995846502748982, 0.02046710468961724, 0.080591938325337, 0.030753473352108682, 0.036191212279456, 0.051490955586944304, 0.05531046313366719, 0.08704349678009748, 0.034591667753245146, 0.02458193103250648, 0.06302416457661561, 0.022373084111937454, 0.05142984672316483, 0.00781048258899578, 0.0511560544504651, 0.0688874399555581, 0.011953301045910587, 0.04149155125820211, 0.029983841614531617, 0.02758513211405703, 0.008975349948741496, 0.06693480616169316, 0.025210778628076826, 0.04884990051920925, 0.01896159493896578, 0.030730230135044882, 0.019750588673299978, 0.04932191661958184, 0.013999632892331906, 0.027398246606545787, 0.015112085966393352, 0.01706001751257905, 0.024388450164613978, 0.058543940340834, 0.05568551318719983, 0.029357669143272296, 0.05589584207960537, 0.05699964892119169, 0.04465810455647962, 0.1303113339734929, 0.006592944372511868, 0.03537275994728718, 0.021642191634912575, 0.1261544113180467, 2.3148043027945926, 17.42947452408927, 23.018535988671438, 29.5650018964495, 41.069294112069265, 20.446364981787546, 13.547969341278076, 5.272649620260511, 0.1690349882202489, 0.021927827736362815, 0.11997696065476962, 1.0406198693173272, 0.9885107683283942, 2.5551429263183048, 2.2829717823437283, 3.615088015794754, 4.837608141558511, 3.6392136812210083, 2.3534488805702756, 0.6728420555591583, 5.83341658115387, 34.261195523398264, 49.82056065968105, 50.84079245158604, 50.79576117651803, 48.73755884170532, 48.48013503210885, 46.66050951821463, 47.083665234701975, 46.99713584354946, 44.51825829914638, 43.14672211238316, 42.59774841581072, 43.66398770468575, 42.73314448765346, 41.300842830113, 37.22336196899414, 36.90701396124703, 37.55626405988421, 40.07519449506487, 44.84371886934553, 46.98101602281843, 49.06504828589303, 48.22321844100952, 43.63347469057356, 46.249068464551655, 48.91344206673758, 47.4217472076416, 44.30473320824759, 42.00720017296927, 36.36567286082676, 35.88014663968767, 36.293171882629395, 35.503099169049946, 37.51564489092146, 43.41695840018136, 48.02641419001988, 49.620657512119834, 50.73023966380528, 44.868746280670166, 37.86404146466936, 43.43700047901699, 43.91464744295393, 46.73889214651925, 43.33404554639544, 45.6744315964835, 44.55685901641846, 50.06324734006609, 46.482611315590994, 42.64084114347185, 33.92118195125035, 33.86509609222412, 33.854079723358154, 33.91464369637625, 33.78533772059849, 35.66944946561541, 44.23988219669887, 45.07053239004952, 44.985246726444785, 44.3795930998666, 45.192028590611045, 43.54185226985386, 45.40534176145281, 45.887512002672466, 45.86541673115322, 43.80887848990304, 40.80530078070504, 39.11073589324951, 35.78187826701573, 38.02221720559256, 41.67972462517874, 43.58621999195644, 44.76984214782715, 44.57990966524397, 44.760337012154714, 42.06936917986189, 46.63352618898664, 44.20689214978899, 43.999477999550955, 29.418693678719656, 17.04617714881897, 5.497911087104252, 1.4081872829369135, 2.6807329186371396, 4.146913341113499, 4.565476732594626, 6.267136165073939, 8.962881752422877, 7.564214587211609, 5.746368246419089, 4.271960505417415, 1.5092355864388602, 0.4377935081720352, 0.10604719312063285, 0.40515087119170595, 3.618569931813649, 21.48957794053214, 28.15413543156215, 19.39518765040806, 31.809186662946427, 26.443697384425572, 5.110105633735657, 0.18105363473296165, 0.02989031234756112, 0.046238097096128125, 0.06476553649242435, 0.0423960146893348, 0.027112529080893313, 0.049276152825249095, 0.04722709920523422, 0.05513953337711947, 0.06605963847999062, 0.007930009925205792, 0.04669170793411987, 0.05688706299822245, 0.032510203908064535, 0.05660913844725915, 0.030913176746772866, 0.07713608483650855, 0.06041156726756266, 0.09370696172118187, 0.012283472793309816, 0.014658005242901189, 0.04685523148093905, 0.05655262326555593, 0.04764422521527324, 0.17786433015550884, 0.2087125948497227, 0.1229910132076059, 0.1780790186354092, 0.20657051407865115, 0.11467962419348103, 0.11126689160508768, 0.07896321000797407, 0.13842161877879075, 0.16698060131498746, 0.1468418990927083, 0.09339686443230935, 0.09247010094778878, 0.18597188725003175, 0.134190776518413, 0.08879892794149262, 0.10367741635335342, 0.11520680519086973, 0.10780680405774287, 0.13915295739259037, 0.11658690470669951, 0.13328210956283978, 0.16063681457723888, 0.11970689014664718, 0.161466228642634, 0.2431800024850028, 0.08923800116670982, 0.21426789675440105, 0.09560845433069126, 0.19446665713829653, 3.810445521559034, 26.965666907174246, 33.17881556919643, 34.59368072237287, 50.24228852135794, 33.26478910446167, 17.634191036224365, 7.052364247185843, 0.5133878460952214, 0.2119236939719745, 0.34602522956473486, 1.3788499257394244, 1.8773072872843062, 3.2030003454004015, 3.3422650439398627, 5.772292409624372, 9.964673893792288, 4.416939011641911, 2.774133643933705, 0.723192990890571, 5.984789167131696, 32.005278723580496, 49.03848532267979, 51.9872591154916, 52.92733301435198, 50.04335464750017, 51.59103809084211, 48.17747150148664, 48.320305619921, 48.72976991108486, 45.97019209180559, 46.569984912872314, 45.86692796434675, 46.154027530125205, 45.4739864894322, 43.57413707460676, 38.35972247804914, 38.9033008984157, 39.46817554746355, 41.884640898023335, 45.04369497299194, 49.088811125074116, 51.27021891730172, 49.848860672542024, 45.424640383039204, 48.199844700949534, 50.9352844783238, 51.27329002107893, 45.53554058074951, 43.99131039210728, 38.51734236308506, 38.58058834075928, 37.30966206959316, 38.46377522604806, 38.729286738804404, 45.01921994345528, 49.04327957970755, 52.060326371874126, 52.88170766830444, 46.52622168404715, 42.03125483649117, 44.393524238041465, 45.82003804615566, 48.84675325666155, 45.219658102308, 46.53012309755598, 46.887232712336946, 51.024468081338064, 48.15933322906494, 44.642926352364675, 34.858313288007466, 35.47572674070086, 36.15364163262503, 34.957352910723, 36.287759235927034, 36.47134106499808, 45.19942842211042, 47.53245285579136, 45.89621809550694, 44.37341962541853, 45.813711711338584, 44.67845596585955, 45.7026378086635, 47.38080842154366, 47.72680786677769, 46.11746610913958, 42.16324976512364, 41.395477294921875, 38.090952260153635, 41.4042980330331, 43.159145491463796, 46.448929922921316, 45.80282041004726, 46.36036818368094, 47.093045302799766, 45.07202625274658, 47.808438777923584, 45.50124774660383, 44.20121547154018, 30.338381562914165, 16.584347758974346, 5.819972685405186, 1.1289058519261224, 3.8901860884257724, 9.021224038941519, 7.87498232296535, 8.361945952687945, 14.684732845851354, 16.00068518093654, 12.213007603372846, 8.070414304733276, 5.347297591822488, 1.3250603377819061, 0.3396380708685943, 0.7232098185590335, 5.625719726085663, 24.81563196863447, 35.211806365421836, 24.342848743711198, 38.805848939078196, 29.377838271004812, 5.787368697779519, 0.2076267216886793, 0.09845341595688037, 0.12221084721386433, 0.17878620140254498, 0.14265503947223934, 0.09601301047950983, 0.1299500140760626, 0.08065626344510488, 0.14980312090899262, 0.12340060408626284, 0.09515518615288393, 0.07648506441286632, 0.1722384606088911, 0.0847540789150766, 0.15579272593770707, 0.1816652933401721, 0.16866330030773366, 0.15470997403774941, 0.11662113001304013, 0.08767068705388478, 0.16370745695063046, 0.1289064950708832, 0.09667203761637211, 0.20011208206415176], [0.044295254562582285, 0.031144088998969113, 0.055456765461713076, 0.024805528677201698, 0.034101738328380246, 0.032729791410799534, 0.005208116315770894, 0.044410211965441704, 0.0391316573534693, 0.020585330934928994, 0.07845024431922606, 0.003078441709346537, 0.046639053616672754, 0.02078442837643836, 0.02202147913963667, 0.04680956607418401, 0.010966502479277551, 0.03025440066786749, 0.06395684488649879, 0.02149273411902998, 0.022821010522810475, 0.06289992481470108, 0.03131304421861257, 0.025337311838354384, 0.047322328202426434, 0.01731135875784925, 0.05266732496342488, 0.0445249759858208, 0.02391344851015934, 0.03613827297730105, 0.20584262242274626, 6.758337327412196, 12.806972622871399, 12.487579567091805, 20.814558710370743, 32.54106821332659, 12.665360518864222, 5.5218545794487, 0.7932483117495264, 0.04927190858870745, 0.1414805089256593, 0.6234621309808323, 1.0046052932739258, 2.1066232451370785, 3.3647194504737854, 6.153538763523102, 2.129051595926285, 3.490848579577037, 1.818892913205283, 0.20745085898254598, 0.16676307655870914, 3.5226098809923445, 23.16745499202183, 43.09014640535627, 49.778381620134624, 49.91622345788138, 47.51697574343, 48.19221905299595, 44.48751252038138, 45.149352754865376, 48.93819849831717, 46.175382818494526, 42.786433696746826, 46.24990572248186, 47.297760077885215, 47.73668820517403, 44.825354780469624, 34.996672766549246, 34.584797450474326, 37.746238231658936, 40.83548722948347, 45.28358152934483, 45.8228485924857, 49.399291379111155, 45.227610315595356, 46.72911603110177, 46.94458661760603, 44.61194780894688, 40.654194831848145, 38.0267995425633, 35.21219893864223, 34.61123882021223, 36.04758085523333, 34.9393709727696, 37.03600379398891, 42.94579757962908, 46.3225074495588, 46.23838560921805, 47.83054099764143, 47.433187416621614, 34.38437666211809, 44.504358427865164, 43.39117363521031, 42.01774753843035, 44.76866790226528, 46.99484988621303, 46.63034043993269, 45.81662648064749, 42.749816690172466, 34.3954381942749, 30.8251793043954, 31.966580731528147, 33.18238694327218, 34.08555895941598, 31.588049820491246, 36.44955498831612, 43.6770954813276, 43.62145778111049, 45.54985039574759, 43.92387465068272, 42.552758829934255, 42.14240516935076, 41.92454440253121, 42.519873006003245, 43.43919958387102, 42.17202186584473, 38.652832235608784, 34.59552894319807, 35.61124440601894, 37.2700469153268, 38.222332273210796, 41.64988906042916, 40.80038145610264, 41.24203675133841, 41.63820913859776, 40.385174478803364, 41.272191933223176, 44.24970694950649, 39.07586635862078, 21.518487657819474, 8.746388912200928, 1.629987352660724, 1.1028149319546563, 1.8527742837156569, 4.174788211073194, 3.643885476248605, 6.441821260111673, 7.933666808264596, 6.007274406296866, 3.9632889543260847, 1.9929444193840027, 1.0376702504498618, 0.1887197640857526, 0.17814425299210207, 1.8352641718728202, 11.680826834269933, 23.001976694379533, 37.185463019779746, 25.734791789736065, 26.62080349240984, 12.935804384095327, 0.4940594232508114, 0.13207137238766464, 0.0510286900347897, 0.019670426546196853, 0.079769913506295, 0.02894291461312345, 0.019704248124201382, 0.014228076973397816, 0.021479056549391577, 0.04535451897286943, 0.07591056916862726, 0.04272719745391181, 0.03255664963009102, 0.03730763987238918, 0.05793913493731192, 0.010999156128881233, 0.010064903314092329, 0.039225946579660685, 0.0029466403107757545, 0.04215771319078548, 0.04497425437771848, 0.06597879103251866, 0.017881674226373434, 0.05463260325736233, 0.08657417446374893, 0.046061386221221516, 0.017716103200135485, 0.0642285370933158, 0.02552133223174938, 0.008638928893820515, 0.02639451519852238, 0.02319904273775007, 0.032940907403826714, 0.011972383146972528, 0.01556321675889194, 0.06327715635831867, 0.005403493264956134, 0.03352119394444993, 0.023412158712744713, 0.022507523951519812, 0.03215188313541668, 0.006321674553743962, 0.0158760773816279, 0.06690774618514947, 0.014029503700190356, 0.013149090094624885, 0.09485377411225013, 0.04162473750433751, 0.03800532314926386, 0.015092825749889016, 0.006983718202848519, 0.06607288348355464, 0.050276764668524265, 0.00947571439402444, 0.058251396752893925, 0.23191857391170093, 8.646808198520116, 20.59509638377598, 17.931587832314626, 34.99295548030308, 36.15699066434588, 15.331898484911237, 9.022459949765887, 1.2856351733207703, 0.025551654265395234, 0.1485507216836725, 0.747281092618193, 2.3363157085009982, 4.794207956109728, 4.943175596850259, 6.701469796044486, 5.6688901867185315, 4.407472091061728, 4.277903386524745, 2.141439799751554, 0.4220560554947172, 5.613352366856166, 27.722707884652273, 43.96722446169172, 51.661597047533306, 50.61529214041573, 49.825896876198904, 49.0110364641462, 47.11851045063564, 47.60307434626988, 49.82282229832241, 47.69165345600673, 45.13561964035034, 47.785638264247346, 49.35328735624041, 48.522949831826345, 45.02464301245553, 36.45434924534389, 35.58087730407715, 38.97441918509347, 42.2042476109096, 48.10937915529524, 47.5856100491115, 50.5313891683306, 45.460055351257324, 48.32927227020264, 47.323788029806956, 46.48128768375942, 43.16051081248692, 40.228110449654714, 35.48396035603115, 36.19067553111485, 37.73470074789864, 35.96622439793178, 38.85279444285801, 43.39315734590803, 46.83986684254238, 47.89769533702305, 49.89894676208496, 48.08222212110247, 36.32518918173653, 43.68886225564139, 43.688997745513916, 43.764809540339876, 46.04622622898647, 46.42795678547451, 48.15311459132603, 46.822388648986816, 43.01960481916155, 37.895127705165315, 32.712250982012065, 32.78378963470459, 33.7730324608939, 35.741745471954346, 33.717175892421174, 37.000230993543354, 44.86501857212612, 45.89929267338344, 44.98222426005772, 44.02753482546125, 42.61381265095302, 43.28237874167306, 43.39945241383144, 44.2268716948373, 44.590370178222656, 43.19838196890694, 40.29061644417899, 36.83016341073172, 37.72828756059919, 39.18165268216814, 41.08514642715454, 43.161879607609336, 42.8288767678397, 42.73119551794869, 42.435063294001985, 43.148476532527376, 43.68710783549717, 44.698425088609966, 39.61349017279488, 22.883058275495255, 10.235452141080584, 2.124186771256583, 1.7960304085697447, 3.6779042908123563, 4.856378265789576, 5.831449806690216, 5.957319464002337, 9.887858084269933, 5.01130485534668, 7.219392427376338, 2.6905322670936584, 0.4560179273997034, 0.11802739383918898, 0.16287866713745253, 1.6300767021519798, 12.25933906010219, 27.311562129429408, 38.47475685392107, 24.46906450816563, 30.839475222996303, 16.670064210891724, 1.2074335238763263, 0.04044490081391164, 0.060418318690998216, 0.009847924778504031, 0.05462680856830307, 0.03441182204655238, 0.040508486330509186, 0.005060705855222685, 0.028736131066190343, 0.041901824064552784, 0.04033466601478202, 0.06949282889919621, 0.0321845037064382, 0.024518372657309686, 0.04210356609629733, 0.04814243955271585, 0.03866201273298689, 0.04946756076865962, 0.047173864740346155, 0.09446873941591807, 0.05737180502286979, 0.13207658353660787, 0.020129806628184657, 0.02883774507790804, 0.045208189503422806, 0.1432386745831796, 0.06446513546896832, 0.1271771400102547, 0.14588758030108043, 0.14037385902234487, 0.10604125593921968, 0.09892432604517255, 0.1300480216741562, 0.1581878595586334, 0.06142006029507943, 0.22943120024033956, 0.15979598755283014, 0.10560746171644755, 0.15979036928287574, 0.10770733760935919, 0.2536668154810156, 0.08870667432035718, 0.10306297575256654, 0.16528613652501786, 0.12992132561547415, 0.15183797957641737, 0.14440099149942398, 0.13258209212550096, 0.1341819962752717, 0.11021481627332312, 0.07895407692662307, 0.1404892506876162, 0.1355936476694686, 0.08070173886205469, 0.23255050714526856, 0.32160830976707594, 14.390589543751307, 31.20265061514718, 27.136748926980154, 38.73723547799246, 46.56937347139631, 19.672142846243723, 8.973162480763026, 1.7086662564958846, 0.22567934942032608, 0.37878123617597986, 5.1223127501351495, 5.571593693324497, 4.822014212608337, 7.963333879198347, 8.463715348924909, 8.035655941282, 7.5133285863058905, 6.264958339078086, 1.9268531543867928, 0.2973264998623303, 4.418508870261056, 25.25026958329337, 45.03952605383736, 52.18989985329764, 51.855952058519634, 51.0900764465332, 50.884444509233745, 49.04311282294137, 47.85857350485665, 54.480776514325825, 50.272468021937776, 45.49359083175659, 49.60793536049979, 50.918480260031565, 51.40024750573294, 48.29931511197771, 39.09026650020054, 38.2390843800136, 41.73054722377232, 44.14935759135655, 49.80640370505196, 50.124169145311626, 51.99523217337472, 45.649824551173616, 48.585935252053396, 49.424860749925884, 49.06054237910679, 45.54789447784424, 42.18069669178554, 38.11130700792585, 38.68812213625227, 38.77319587979998, 38.3094870022365, 41.1561917577471, 45.79093551635742, 50.377653326307026, 49.30726943697248, 50.27382639476231, 49.58341516767229, 39.54878159931728, 43.804462909698486, 44.95613030024937, 47.58152103424072, 48.29478488649641, 48.91459199360439, 49.69665690830776, 49.82760265895298, 45.249858447483604, 38.394546849387034, 34.64951297215053, 34.592694078172954, 35.59335626874651, 37.651249408721924, 34.10759517124721, 39.50180830274309, 46.64325366701399, 46.9951034954616, 47.04002012525286, 44.05470923015049, 42.68685558864048, 44.62725121634347, 44.299119063786094, 44.267991134098594, 45.54971490587507, 46.107551029750276, 41.43844495500837, 38.42919404166085, 38.87981251307896, 40.460868154253276, 42.323311941964285, 45.21956082752773, 44.49895967755999, 45.54401738303048, 43.98006820678711, 43.767887592315674, 44.2689117704119, 46.635867731911794, 41.46459797450474, 23.68059856551034, 10.679111123085022, 2.1692210861614774, 3.0546688990933553, 6.16359714950834, 9.06264659336635, 9.410026124545507, 12.345602682658605, 15.40977042061942, 14.06894440310342, 13.026225634983607, 6.456739042486463, 2.254723229578563, 0.6985023500663894, 0.42185480200818604, 2.9882176305566515, 14.994325467518397, 31.78604221343994, 43.733837945120676, 33.640891620091026, 36.84571695327759, 18.551827464784893, 1.2893050163984299, 0.2682331438575472, 0.15104899262743338, 0.10485300541456256, 0.1703511154545205, 0.12588968766587122, 0.08885037446660654, 0.14638945194227354, 0.08930862309145075, 0.09942167864314147, 0.18366957721965654, 0.15186570451727935, 0.096389753477914, 0.14434047974646091, 0.1754686537065676, 0.15612273822937692, 0.1269302482583693, 0.10665309775088515, 0.06254680162029606, 0.1332072535795825, 0.21261662750371865, 0.3044713921844959, 0.08761388010212354, 0.24217639490962029, 0.192827099402036], [0.02590907258646829, 0.04116396472922393, 0.003155410268975954, 0.0632869340479374, 0.06677148278270449, 0.01629835686513356, 0.04933194875983255, 0.032978885008820465, 0.024988729739561677, 0.0677536486514977, 0.03277713279905064, 0.0550225471545543, 0.048757724929600954, 0.03987161675468087, 0.05542263515027506, 0.06037847511470318, 0.010491631442814, 0.043013128718095164, 0.016716549871489406, 0.04960598869781409, 0.01493438273402197, 0.02708202214645488, 0.003297811868833378, 0.01455581108374255, 0.038722470203148465, 0.05770050774195364, 0.03951134858652949, 0.026061692075537782, 0.034104469431830306, 0.06153186929545232, 0.03435520847727146, 2.9597617174897874, 17.390614986419678, 19.137254885264806, 13.028199791908264, 28.232099430901663, 23.773174626486643, 7.123252374785287, 4.057765781879425, 0.04904927446373871, 0.1162169131317309, 0.24487864705068724, 1.493499219417572, 4.634084982531411, 2.807024896144867, 3.8073422823633467, 3.919026323727199, 4.208943384034293, 3.648828251021249, 2.778576365539006, 0.3272198757955006, 0.1700400478605713, 2.6953438946178983, 20.182790279388428, 41.1308273587908, 47.31027030944824, 49.31541272572109, 47.70630720683506, 48.5609564781189, 45.03577750069754, 48.96537290300642, 47.230703013283865, 45.114740303584504, 47.87255328042166, 47.129481656210764, 46.39400788715908, 45.908804757254465, 38.95877531596592, 35.053679261888774, 35.522297041756765, 40.240186418805806, 45.04081147057669, 46.79331738608224, 49.00070101874215, 45.4823625428336, 46.99609708786011, 45.65005384172712, 43.78480645588466, 40.95727872848511, 36.952236311776296, 35.170242241450715, 34.36164910452706, 36.29564891542707, 34.43591145106724, 35.084557056427, 41.50811454227993, 42.41050488608224, 47.062737260546, 48.109299251011436, 45.53722899300711, 34.917188848767964, 43.30007232938494, 44.50300700323922, 46.078233105795725, 44.49348102297102, 44.125758034842356, 43.48657240186419, 41.33322490964617, 36.49124070576259, 32.918747970036094, 32.59819630214146, 33.777444566999165, 33.86410597392491, 32.501755305698936, 32.000595637730186, 35.03583628790719, 42.326417786734446, 45.52887378420149, 43.93813930238996, 43.752434798649375, 44.58968230656215, 43.62365688596453, 43.85921471459525, 44.304316316332134, 40.21798345020839, 39.9764849117824, 35.66188635144915, 34.25575508390154, 33.909349169049946, 36.64262458256313, 36.75989627838135, 36.70631871904646, 37.975330761500764, 38.95685413905552, 40.60304914202009, 42.44184473582676, 42.83857992717198, 43.229367460523335, 32.73084436144148, 15.357837847300939, 4.6548110246658325, 0.769293908561979, 1.3921708166599274, 2.0169458857604434, 2.7587750852108, 4.133105099201202, 4.0939923865454535, 10.429253033229283, 3.854349885668073, 4.512432013239179, 2.4018150738307407, 0.47738293239048546, 0.10198992011802537, 1.283927327820233, 6.769579078469958, 19.257073095866613, 25.34122497694833, 30.511471612112864, 34.45602648598807, 23.978301082338604, 5.698568114212581, 0.17171142888920649, 0.03105158431987677, 0.03607081641842212, 0.074783841414111, 0.050643862291638336, 0.06051117620830025, 0.01955940295010805, 0.0182179527889405, 0.08960206234561545, 0.04405167406158788, 0.04301624997918095, 0.03646702319383621, 0.011691039627684014, 0.030340289630528008, 0.059754195756145885, 0.01696065454078572, 0.02698347172034638, 0.028279051217915754, 0.032967811317316124, 0.02509708160401455, 0.03106905659660697, 0.04574836105374353, 0.08745711815676518, 0.04533091613224574, 0.04427831154316664, 0.04657345285106983, 0.050097427863095484, 0.05607231207458036, 0.03804960095190576, 0.02616162840942187, 0.028599528396236043, 0.025725126831925342, 0.02380761401062565, 0.0207602114616228, 0.025074513529294302, 0.017934435413085988, 0.06806188675441913, 0.027793053903483918, 0.04424603023965444, 0.015767058856519203, 0.025539990248424665, 0.07693235469715935, 0.09779326923723732, 0.053108230233192444, 0.021975274297541807, 0.034910779379840405, 0.06957797147333622, 0.027378258661233952, 0.017575977237096856, 0.06453969289681741, 0.05964007295135941, 0.008496365293727388, 0.05335571909589427, 0.050367155711033514, 0.020831298182851503, 0.035759372237537584, 4.260986694267817, 20.888167926243373, 23.865107979093278, 20.987742560250418, 39.10635505403791, 23.349040951047623, 10.259104677609034, 4.166566755090441, 0.1477113738656044, 0.1288104552243437, 0.26750146597623825, 1.5888366465057646, 5.068817266396113, 6.221814368452344, 8.347071596554347, 8.895304441452026, 5.935152539185115, 4.157500224454062, 3.900782525539398, 2.196917257138661, 0.9006218101297105, 4.503572625773294, 24.55383426802499, 43.53857619421822, 49.918679646083284, 49.72069420133318, 48.42449038369315, 51.431834016527446, 47.61091538837978, 51.724547726767405, 49.46191896711077, 46.72223384039742, 49.88608564649309, 49.09770481927054, 49.13744156701224, 48.12245566504342, 41.259834562029155, 36.560503823416575, 37.65758963993618, 42.58675636563982, 46.4644660949707, 48.50440508978707, 50.55440160206386, 45.96567923682076, 47.96067033495222, 47.124190602983745, 46.809798513139995, 42.22052724020821, 38.935787200927734, 37.16887419564383, 36.02914728437151, 36.73356260572161, 36.87846033913748, 36.305862767355784, 43.51640796661377, 44.849273954119, 48.51264565331595, 49.26605272293091, 46.43713188171387, 36.96494109289986, 44.48260014397757, 46.54911252430507, 47.412061418805806, 46.81857756205967, 47.54588719776699, 46.23798608779907, 42.97864171436855, 38.564996583121165, 34.010834557669504, 33.913358279636924, 34.323305470602854, 35.185507433755056, 35.12078843797956, 33.38068505695888, 35.4449462209429, 44.28501769474575, 46.018746103559224, 45.06772184371948, 43.893180983407156, 43.99817173821585, 44.337084020887104, 46.26863806588309, 45.35688502447945, 42.9250294140407, 41.73912477493286, 38.02192538125174, 35.85460158756801, 36.391426358904155, 38.0165752683367, 39.261720248631065, 39.105045318603516, 39.57933630262102, 40.15834706170218, 43.2261643409729, 42.14865854808262, 44.38889326368059, 43.6962308202471, 36.36739253997803, 18.765298707144602, 5.498773532254355, 1.8625603871686118, 3.6111698831830705, 4.623855931418283, 4.586913662297385, 5.25193269763674, 9.186953340257917, 10.580818431718008, 5.425612475190844, 3.5671439255986894, 0.8409587144851685, 0.13830510074538843, 0.20597189691449913, 1.0647916751248496, 6.7066996182714185, 20.629941599709646, 30.827930791037424, 36.91271843229021, 37.80277572359358, 28.534222739083425, 9.004893166678292, 0.394549874322755, 0.045049079826899936, 0.09138857719621488, 0.071815135356571, 0.07407299455787454, 0.019236449118969694, 0.043410142950181446, 0.015137334254437258, 0.031967514992824624, 0.02904052526823112, 0.04569801714803491, 0.02428191847034863, 0.06607529906822102, 0.006299243034196219, 0.015760305736746107, 0.0570930221251079, 0.019953855712498938, 0.03888145095801779, 0.0528263125036444, 0.029986837346638952, 0.04740226302029831, 0.03322695741163833, 0.05794290080666542, 0.052875584324023554, 0.06552174341465745, 0.1355639278356518, 0.1015230133863432, 0.11305751837790012, 0.23215009006006376, 0.12672068950320992, 0.07262533331023795, 0.1162849837648017, 0.09452037593083722, 0.08754222001880407, 0.15524760447442532, 0.10942974447139672, 0.11463473231664725, 0.1056706943948354, 0.06611664220690727, 0.15258964709937572, 0.11310038822037832, 0.16446143149265222, 0.16481494823736803, 0.15467055115316594, 0.19120687991380692, 0.11609263265771524, 0.15651635639369488, 0.07193693917776857, 0.11030787735113076, 0.13665400791381085, 0.29856232926249504, 0.26849891245365143, 0.15762692822941712, 0.1627494062164, 0.12351548006492001, 0.10961771902761289, 5.227223600660052, 29.061483315059117, 34.71553128106253, 29.78059755052839, 41.964423588344026, 33.38914448874337, 12.667305145944868, 6.011031210422516, 0.32869663941008703, 0.3693558419389384, 0.6742814726063183, 5.4524529320853095, 11.096802081380572, 11.421235186713082, 13.693420325006757, 10.789492811475482, 10.355707219668798, 9.278444613729205, 6.753556532519204, 1.8005389209304536, 0.6015830135771206, 3.4858682411057607, 22.317108392715454, 43.52031980242048, 49.70866339547293, 50.626819201878135, 49.986219610486714, 52.115713936941965, 48.94485139846802, 53.12425538471767, 50.70997871671404, 49.23393814904349, 51.955700397491455, 50.95674398967198, 50.23690366744995, 49.61615507943289, 42.260986600603374, 40.07754298618862, 40.03208439690726, 44.38230984551566, 48.62400443213326, 50.54444135938372, 52.43338557652065, 47.07732847758702, 49.993654182979036, 48.643963132585796, 49.05026946749006, 43.74855422973633, 41.24136625017439, 39.037738118852886, 38.08749900545393, 39.03312451498849, 37.34827668326241, 37.482189314705984, 44.98636886051723, 45.85923283440726, 50.528401442936485, 51.8957965033395, 46.23649222510201, 39.96445410592215, 45.80018356868199, 47.866320746285574, 48.4869373185294, 48.90388134547642, 48.76545238494873, 47.41592461722237, 44.74752800805228, 39.5248589515686, 36.39002629688808, 35.78272247314453, 37.023083618709016, 36.18831314359392, 35.9180907521929, 35.16243941443307, 37.18582780020577, 44.346464088984895, 47.929521560668945, 45.00861699240548, 43.78479603358677, 44.619945185525076, 44.84760291235787, 46.77498109000069, 46.77588088171822, 44.3526097706386, 43.14709036690848, 38.750176497868125, 37.95090784345354, 36.846863406045095, 40.04074532645089, 40.132763794490266, 39.881829602377756, 40.64280673435756, 41.636190686907085, 44.82152284894671, 45.1029874256679, 46.33306176321847, 43.87077651705061, 36.12935420445034, 17.856604610170635, 5.88552416222436, 2.2531392574310303, 5.521594890526362, 7.226537346839905, 7.503311020987375, 8.61957733971732, 12.572125247546605, 22.20296859741211, 9.233577489852905, 10.830514975956508, 4.112695634365082, 1.0442885181733539, 0.3548316370163645, 1.7825368983404977, 9.48724753516061, 24.51063731738499, 35.835368973868235, 40.23784487588065, 42.32142898014614, 32.146552971431184, 9.944914085524422, 0.43075932562351227, 0.15249978192150593, 0.12136330269277096, 0.1765825639345816, 0.174294611705201, 0.08867016235100371, 0.17820939235389233, 0.09360195164169584, 0.22254586113350733, 0.1030015954747796, 0.14243877679109573, 0.08554396153028522, 0.08266379750732865, 0.09596418988491807, 0.13285418466797896, 0.1715834029018879, 0.1064149591007403, 0.09518227327082839, 0.10642050273184266, 0.11335748513894421, 0.1866678741893598, 0.07297616984163012, 0.15571246881570133, 0.16260946515415395, 0.15883222355374269], [0.050043647177517414, 0.03548937976094229, 0.0489078066977007, 0.002923390096319573, 0.05780167731323412, 0.06058594398200512, 0.10320393461734056, 0.02732481893950275, 0.025974652996020656, 0.030287255333470445, 0.06324324317808662, 0.06292753440460988, 0.013361285806500485, 0.05205929312588913, 0.030073903567556824, 0.037211457533495765, 0.0045651662180067176, 0.05916920357516833, 0.0024893492684766117, 0.0234929416993899, 0.12387399082737309, 0.04218359251639672, 0.05254479171708226, 0.04413426534405776, 0.028695676808378527, 0.051316734935556135, 0.006847378889298332, 0.0693985532437052, 0.009368720447777637, 0.01280355716257223, 0.08198775271219866, 0.23269772210291453, 9.813356024878365, 16.902399812425884, 14.985542944499425, 20.759030444281443, 34.48142910003662, 15.269107614244733, 5.438864861215864, 1.9862715431622096, 0.14618392368512495, 0.0951255816700203, 0.7932028227618763, 3.8930261645998274, 5.039352561746325, 7.39898555619376, 7.377155184745789, 3.6899937220982144, 3.2441753702504292, 2.2276795378753116, 2.76192935023989, 0.8137254672391074, 0.4402129740587303, 3.441104471683502, 19.657409191131592, 36.68066596984863, 48.59634712764195, 49.39536564690726, 48.537270069122314, 48.194244452885215, 48.89684282030378, 48.24277067184448, 50.340289388384136, 46.00383179528372, 47.559227739061626, 48.911896092551096, 48.212202072143555, 40.473618098667686, 37.47873953410557, 38.24550104141235, 40.499086720602854, 47.21363476344517, 45.18944386073521, 49.62759181431362, 44.97425467627389, 47.392422335488455, 46.55273600987026, 44.698664801461355, 39.64001839501517, 36.10627228873116, 33.967769622802734, 33.95536708831787, 34.72026647840227, 36.40828616278512, 34.69308859961373, 40.21268197468349, 44.716844763074604, 45.61931848526001, 47.05513245718819, 47.89027118682861, 32.95207500457764, 43.59543677738735, 45.66936635971069, 43.359364782060894, 42.7524083682469, 41.18688195092337, 37.47534533909389, 33.70352963038853, 31.18527317047119, 31.932746478489467, 33.161299160548616, 33.24530635561262, 33.54200833184378, 33.46502576555525, 33.38919660023281, 33.65250553403582, 41.228133405957905, 44.27161461966378, 44.56372731072562, 43.71492494855608, 40.16819960730416, 45.53883055278233, 43.498092515128, 42.71164676121303, 40.17735733304705, 37.61635208129883, 36.06172043936593, 33.34276526314871, 32.66755322047642, 34.04653092793056, 34.59440680912563, 36.7494809286935, 35.47874573298863, 38.33463600703648, 40.5637640271868, 42.62236588341849, 45.087611062186106, 41.575880323137554, 25.788676806858607, 9.48127555847168, 1.1645332830292838, 0.8416159706456321, 1.8177997661488396, 3.4060338735580444, 3.2298814058303833, 4.695349420819964, 5.359955906867981, 5.584818286555154, 3.739367187023163, 4.120789417198726, 0.7940678734864507, 0.017732986847737005, 0.3741689622402191, 4.21987680877958, 15.89000037738255, 26.058577844074794, 25.954089096614293, 23.033948830195836, 30.50192826134818, 16.120545080729894, 1.7238806400980269, 0.08492502224232469, 0.04554313474467822, 0.02009722337658916, 0.019273549717451845, 0.06073765084147453, 0.0452252105543656, 0.02352290919848851, 0.057076092676392624, 0.021271728478106003, 0.02203663082660309, 0.08582072239369154, 0.021164107735135725, 0.07324904269937958, 0.03345487393172724, 0.031160282237189155, 0.048673898713397126, 0.01600801681966654, 0.01625495606900326, 0.0250503424155925, 0.01654209682185735, 0.028862481072012867, 0.0449119411142809, 0.06493179792804377, 0.015194380389792579, 0.04340226176593985, 0.043049515158470185, 0.025732965607728277, 0.0328342315208699, 0.03628957610843437, 0.042667696718126535, 0.05431077070534229, 0.13206157434199536, 0.04653667964573417, 0.01746316230855882, 0.04726823199806469, 0.01543563012299793, 0.03131252174664821, 0.02535609538400812, 0.033277623621480804, 0.06984002169753824, 0.04014918507475938, 0.007415314820328993, 0.04672134295105934, 0.009361709484697452, 0.02398557847897921, 0.023493430244603326, 0.05313460149669221, 0.03916480378913028, 0.01086334734489875, 0.027071379324687377, 0.05734327941068581, 0.0696127260369914, 0.010620753264187701, 0.02565155497619084, 0.004451643492627356, 0.07342605891504458, 0.47885513624974657, 13.108027645519801, 24.87611256326948, 19.32472770554679, 28.905459778649465, 37.890611376081196, 14.841444253921509, 9.038773451532636, 1.3299958386591502, 0.191630448613848, 0.14079628778355463, 1.1035140944378716, 4.518552941935403, 6.474478227751596, 7.626629386629377, 9.02656807218279, 8.174057109015328, 6.068685191018241, 5.55274453333446, 5.085842958518437, 2.1867338035787856, 1.1475188817296709, 4.514740986483438, 23.46969815662929, 38.576162338256836, 50.51980652127947, 51.89316661017281, 51.26143986838204, 50.06032909665789, 50.535940238407676, 48.88384621483939, 52.26278298241751, 48.325652258736746, 49.14581067221505, 49.60551391329084, 49.593080111912315, 42.83969163894653, 38.92304767881121, 39.106108392987935, 42.98058026177542, 49.755727018628804, 47.51361976351057, 48.92714044025966, 45.29931919915335, 48.02189786093575, 48.22588654926845, 46.77426195144653, 41.63830988747733, 37.6412787437439, 35.645558084760395, 34.67212241036551, 36.52959476198469, 37.976789883204866, 36.0949467250279, 41.72253247669765, 45.94234371185303, 46.78575079781668, 48.985710280282156, 48.62065887451172, 35.31176315035139, 44.70492512839181, 47.81309754507882, 45.16191509791783, 45.2833696092878, 43.18603502001081, 39.95242330006191, 35.13325350625174, 32.74276052202497, 32.55301216670445, 34.48255818230765, 33.44800615310669, 35.46636751719883, 34.49149356569563, 33.540424142565044, 35.34847048350743, 43.378034591674805, 46.23748581750052, 45.301011085510254, 44.83552346910749, 40.59668459211077, 47.623112951006206, 45.50575017929077, 44.32191262926374, 41.7742965562003, 39.48871442249843, 37.4002492087228, 34.82026842662266, 34.98313420159476, 36.5088335445949, 36.080258233206614, 38.20504168101719, 36.95656851359776, 39.95566463470459, 43.24754394803728, 44.71306494304112, 45.44493954522269, 42.365202631269185, 26.891036306108745, 10.084386144365583, 2.7194178828171323, 1.6472711052213396, 3.51478316954204, 3.976912634713309, 5.899482658931187, 7.337380221911839, 9.534856591905866, 8.533455286707197, 5.178141091551099, 1.43627906697137, 0.2158596177718469, 0.15822151489555836, 0.21303144310201916, 4.515462730612073, 15.126945734024048, 31.323024681636266, 30.364722183772496, 28.411870173045568, 34.746019976479666, 22.31829653467451, 2.6719881764480045, 0.06342215929180384, 0.07548430668456213, 0.02459362388721534, 0.025001396292022297, 0.011347775547099965, 0.014671518267797572, 0.047148758944656165, 0.008785426300684256, 0.035420959682336876, 0.040715894129659445, 0.025954782097999538, 0.031501130733106814, 0.09186814539134502, 0.010609824609543596, 0.05785377523196595, 0.020323095809934393, 0.01893584114233298, 0.05142076113926513, 0.02000675769522786, 0.015928864013403654, 0.07191450002470187, 0.0587060966395906, 0.02656665614007839, 0.056914737048958025, 0.025626652741006443, 0.13753075658210687, 0.2028443661651441, 0.13847558945417404, 0.0981863174321396, 0.16547901688941888, 0.1720499771514109, 0.24274275451898575, 0.1512933195169483, 0.08084556792995759, 0.10092559044382401, 0.15371547240231717, 0.10039219406566449, 0.08680931398911135, 0.16179473458656243, 0.13347509849284375, 0.10802791826426983, 0.08264982647129468, 0.10002946281539542, 0.09760260089699711, 0.09671418142638036, 0.20734423398971558, 0.19791217653879098, 0.1512442614351, 0.06551523626382862, 0.08363278622605971, 0.14967865044517176, 0.0832106356642076, 0.09451137855648994, 0.09577753168663808, 0.1492226884833404, 0.14505565565611633, 0.800839652972562, 16.079434326716832, 32.808327198028564, 28.66576429775783, 35.688088008335654, 46.499130657741, 22.667356661387853, 9.267124261174883, 3.0931015568120137, 0.24392628243991307, 0.6798089274338314, 3.1738548236233846, 11.231927173478262, 13.335026162011282, 15.819589069911412, 14.541890910693578, 12.037767086710248, 9.946082251412527, 7.360240663800921, 6.5900033201490125, 2.426348294530596, 0.9500047202621187, 4.3370994329452515, 21.78310111590794, 38.59384897777012, 50.91724348068237, 52.73115757533482, 52.81279196058001, 50.16527121407645, 52.617394719805034, 49.59316349029541, 53.49679347446987, 48.503081457955496, 51.21294491631644, 51.544863837105886, 53.37933070319039, 45.37319592067173, 42.56172548021589, 41.38278988429478, 45.05520813805716, 51.397489070892334, 48.7168983731951, 50.31055804661342, 44.69596195220947, 49.15510041373116, 51.22533355440412, 48.95840733391898, 42.931334904261995, 38.659940242767334, 37.72661304473877, 36.281321729932515, 38.27397475923811, 38.96270799636841, 38.76228025981358, 43.60286092758179, 48.4732597896031, 49.19567789350237, 50.60510608128139, 50.30160876682827, 39.58333846500942, 45.535783767700195, 48.82355669566563, 48.30651691981724, 46.0971599987575, 45.235764026641846, 40.37988689967564, 37.357823508126394, 33.65599352972848, 33.11489561625889, 35.653409549168174, 35.42420237404959, 37.39986705780029, 35.76111010142735, 35.28945595877511, 36.2047004699707, 46.273359366825645, 47.594899790627615, 46.95101717540196, 45.318180084228516, 41.18447092601231, 48.368331568581716, 46.61730909347534, 46.041084562029155, 44.243088790348594, 40.567613329206196, 39.981984410967144, 36.60594851630074, 36.3567340033395, 37.09069306509835, 38.21267427716936, 40.751959460122244, 39.54771157673427, 42.34108543395996, 45.05281795774187, 45.88980838230678, 47.3847028868539, 43.76696695600237, 27.06094060625349, 10.69455349445343, 1.7289987483194895, 2.1800863317080905, 5.217496122632708, 7.095122592789786, 7.873478037970407, 10.200230853898184, 14.20764434337616, 14.857986177716937, 11.582868524960109, 9.513407502855573, 2.70778203862054, 0.24573677671807154, 0.7214669063687325, 5.718739603246961, 19.32445846285139, 33.598830699920654, 33.51957607269287, 33.12499482291085, 39.131722927093506, 24.169140304837907, 3.0525957303387776, 0.14387609037969792, 0.19876685924828053, 0.16988165064581803, 0.09563550752188478, 0.12120861027921949, 0.1329222417303494, 0.1372705248317548, 0.20368338828640326, 0.1418297237583569, 0.08691000858587877, 0.13872742094099522, 0.10087415070406028, 0.2071639472352607, 0.2759690944637571, 0.2139273535992418, 0.18192434443959168, 0.13610032333859376, 0.11302874849310943, 0.0846282649519188, 0.060855064541101456, 0.10454011934676341, 0.09920760763010808, 0.13442599746797765, 0.15460423114044325, 0.1169879324734211], [0.028421870964978422, 0.08139834326824971, 0.013539399552558149, 0.003496077256776126, 0.024956114257552793, 0.03258032710956676, 0.04094445525801607, 0.053617056858326705, 0.05257607896679214, 0.009845315811357327, 0.022099030603255545, 0.01563640184966581, 0.052139343294714174, 0.015301254744242345, 0.06969438772648573, 0.03426871561844434, 0.032419249681489806, 0.054407065002513785, 0.030680849749062742, 0.06552370438086134, 0.0027634886542468196, 0.034728870926690955, 0.04887067386880517, 0.029365618181015764, 0.04962912674195, 0.0881965516933373, 0.058256411126681736, 0.07790134341589042, 0.033636833275003095, 0.05493233931650009, 0.040362340065517595, 0.07012724557093211, 2.668638493333544, 15.278093372072492, 16.271447794778005, 15.044534887586321, 32.971436159951345, 29.976807730538503, 8.562327657427106, 4.415796032973698, 0.899807079562119, 0.06023448998374598, 0.5473917871713638, 2.9798146528857092, 3.035107114485332, 4.398132843630655, 8.225025619779315, 6.591477641037532, 3.2810924521514346, 5.004041382244655, 4.062750680106027, 2.215691941125052, 0.5862639184509004, 0.6289605987923486, 4.735355411257062, 18.095867565699987, 33.68966102600098, 44.50440011705671, 48.260068212236675, 48.97723000390189, 47.9733646937779, 46.39919819150652, 48.846259934561594, 51.09536402566092, 47.97442429406302, 46.83652475902012, 45.78696114676339, 41.16877147129604, 37.103707041059224, 38.114732469831196, 42.82414851869856, 47.18321207591465, 47.94727073396955, 47.73670557567051, 44.458774771009175, 47.45099912370954, 46.944319111960276, 44.344372681209016, 41.089829513004844, 35.32569776262556, 34.082925592150005, 33.45070900235857, 33.69594914572579, 36.1942469051906, 35.64852843965803, 35.62883029665266, 44.57782520566668, 47.162419591631206, 45.11339930125645, 47.296141147613525, 33.94798810141427, 45.3464800970895, 48.37125676018851, 43.75430038997105, 44.94100407191685, 38.023592948913574, 33.674190861838206, 32.431748730795725, 34.01089014325823, 34.78484651020595, 34.36804492133004, 33.36766760689871, 34.509524141039165, 32.6102340562003, 34.28670236042568, 32.977019037519185, 37.23088339396885, 43.083354541233604, 43.966421944754465, 43.41680901391165, 44.414292403629844, 44.7225318636213, 44.555973121098106, 43.52006271907261, 41.12836422239031, 37.42758689607893, 33.3989622933524, 33.14399119785854, 34.47481094087873, 35.246432713099885, 36.254171643938335, 35.51757574081421, 38.56854363850185, 39.28450686591012, 42.86994756971087, 42.63174942561558, 42.97945465360369, 31.67679568699428, 16.977674858910696, 4.244494710649763, 1.83499710048948, 1.7499995699950626, 3.1295648344925473, 3.4315107464790344, 4.6646592276436945, 4.717511134488242, 9.769664015088763, 8.385462999343872, 3.2598442094666615, 0.6021198704838753, 0.10486195529145853, 0.4677496350237301, 2.990231739623206, 12.17130104133061, 20.824089901787893, 28.009319339479717, 25.682503121239797, 29.28875889096941, 23.874131952013286, 6.00663343497685, 0.28224418631621767, 0.008461325745364385, 0.01211634198469775, 0.03228970377572945, 0.07550944640700306, 0.017559580438371216, 0.033278410722102435, 0.03695370922131198, 0.04802781802469066, 0.0558470825531653, 0.03773570725960391, 0.06074232594775302, 0.043946378997394016, 0.022781295868168985, 0.011669444402546754, 0.005669445913684155, 0.0340374471353633, 0.02254769661729889, 0.06772213748523168, 0.011694683360734155, 0.016818528595779623, 0.033943242726049254, 0.014456103755427259, 0.02768980462237128, 0.05275569057890347, 0.03647029712530119, 0.045823349351329465, 0.05547918765140431, 0.03017832332157663, 0.03402450747255768, 0.05757205427757331, 0.054870840295084884, 0.028133247613108585, 0.03513550678534167, 0.01388293843982475, 0.01106963980211211, 0.055468232703528235, 0.014940689717020308, 0.03408350269975407, 0.008968592588124531, 0.020743948673563342, 0.00695343518496624, 0.030909522835697447, 0.01315335214271077, 0.02780583411056016, 0.02779618534259498, 0.04267782385327986, 0.02461568475700915, 0.04561845552442329, 0.026341718388721347, 0.0613725357023733, 0.013337535384510244, 0.019100855769855634, 0.027399512074355568, 0.03547117805906704, 0.11406298513923373, 0.020138396881520748, 0.05057868221774697, 4.96990053994315, 19.394987889698573, 22.540354013442993, 22.482340029307775, 41.20175804410662, 28.413193804877146, 10.615569846970693, 6.5664524010249545, 0.730116925069264, 0.08849518174039465, 0.21037641699825013, 0.7391484432986805, 3.7047556042671204, 6.715179460389273, 7.150799376623971, 10.238863706588745, 7.971143654414585, 6.373404519898551, 3.944555308137621, 4.086412336145129, 2.0371981476034438, 1.2706816728625978, 7.24747530903135, 21.249429089682444, 36.475197315216064, 47.701995849609375, 50.49564068658011, 51.35142251423427, 49.42379420144217, 47.66067491258894, 48.6520334652492, 50.499427454812185, 48.85015787397112, 49.20031929016113, 49.21980898720877, 43.328737122671946, 38.938444886888774, 39.002608026777, 44.27569668633597, 47.69446747643607, 48.47361414773123, 49.589824880872456, 44.81554739815848, 48.79449585505894, 47.53363752365112, 46.27986635480608, 42.15731600352696, 36.71142911911011, 35.5462509563991, 35.781857422419954, 35.298919405256, 37.462157658168245, 37.309408460344585, 38.023558207920615, 47.12352705001831, 49.56162214279175, 46.91139159883772, 48.846259934561594, 37.59014695031302, 46.87743575232369, 50.02875648226057, 44.87982518332345, 46.44004317692348, 40.656168120247976, 34.60665648324149, 33.457674571446006, 35.66535350254604, 36.44624417168753, 34.98970719746181, 34.3807566506522, 35.73030178887503, 33.8871739932469, 36.050648484911235, 34.01850536891392, 39.28693873541695, 44.258920260838096, 45.26443576812744, 44.57069982801165, 43.774832316807334, 44.79794066292899, 46.58749784742083, 43.8208259173802, 42.966767242976594, 38.30929592677525, 33.92551415307181, 35.903610706329346, 35.96019336155483, 36.67094196592058, 37.36285400390625, 36.73054361343384, 38.82599524089268, 41.47447483880179, 44.121547426496235, 43.6742501940046, 44.22045155933925, 34.493953227996826, 19.55076823915754, 5.514245433466775, 3.06643437061991, 3.0230919420719147, 3.597845192466463, 4.475486704281398, 5.008881236825671, 6.70346827166421, 6.512155703135899, 4.138415259974344, 1.7719290618385588, 0.4637330876929419, 0.07042342610657215, 0.3494567440024444, 2.669787985937936, 13.321462409836904, 24.642488070896693, 31.03765869140625, 26.328782864979335, 30.786849566868373, 29.60001039505005, 9.311888030597142, 0.29185490203755243, 0.023669949433367168, 0.029666338115930557, 0.005643765483650246, 0.05970559907811029, 0.03394987201318145, 0.026986939034291675, 0.03834706391873104, 0.03505288157612085, 0.0703446346202067, 0.04040061283324446, 0.019348889156909924, 0.05336902516760996, 0.023037717644391314, 0.03565466071345976, 0.04714603801923139, 0.04757138787369643, 0.12181511202028819, 0.014424154934074198, 0.015943844370277863, 0.017065276158973575, 0.019289614034018347, 0.02031798304856888, 0.08258603060884134, 0.010146518354304135, 0.023426265455782413, 0.16764819834913525, 0.11991901376417705, 0.07692404264318091, 0.12923132335501059, 0.1358482747205666, 0.16350590490869113, 0.08530149382672139, 0.1560812797397375, 0.12851157411932945, 0.12777446795787128, 0.14163030231637613, 0.1127885403111577, 0.13385947501020773, 0.1324550432286092, 0.13497844710946083, 0.10693569401545183, 0.11132766798670803, 0.1129480367526412, 0.15942244045436382, 0.14399160418127263, 0.1296389057700123, 0.10002604299890143, 0.19951632831777844, 0.15104897905673298, 0.2810013272932598, 0.11909923489604678, 0.10226563603750297, 0.12653091682919435, 0.08172588569245168, 0.19479495952171938, 0.13232936497245515, 0.17370845244399138, 5.724124022892543, 25.766187225069316, 32.913783482142854, 30.044948714120046, 46.6254871232169, 38.72354752676827, 13.729492766516548, 6.542854147297995, 1.413487238543374, 0.21358636261097022, 1.442537548286574, 7.146607441561563, 10.379040139062063, 11.248335344450814, 18.033813204084122, 14.271954263959612, 10.52976654257093, 12.229810953140259, 8.155391642025538, 4.636877289840153, 1.6814408259732383, 0.9546924744333539, 6.292669926370893, 19.556187834058488, 35.55907038279942, 47.49396330969674, 49.55826963697161, 49.50613382884434, 48.07415526253836, 46.60231488091605, 49.92047922951834, 53.56334679467337, 50.21218892506191, 50.41785907745361, 49.43115929194859, 45.85934053148542, 40.884207998003276, 41.33131415503365, 46.53115837914603, 49.649214608328684, 50.54859290804182, 50.11149910518101, 44.44151544570923, 50.22614785603115, 50.05251932144165, 47.758026123046875, 44.236342089516775, 38.83239800589425, 38.46062421798706, 37.38877425874983, 37.47857972553798, 39.888892446245464, 38.391013690403526, 40.08615527834211, 49.13898059300014, 50.212380000523154, 50.16648367473057, 49.63474498476301, 41.04437092372349, 49.33752189363752, 52.20651299612862, 47.340609618595664, 50.77033076967512, 42.19562489645821, 36.93611996514456, 34.63046448571341, 37.66376658848354, 38.38283913476126, 36.63240725653512, 35.17384140832083, 37.21415213176182, 36.10130780083792, 38.32821239743914, 36.40602799824306, 40.07134171894619, 45.28339740208217, 47.43860701152256, 46.564249174935476, 46.20002113069807, 44.76758745738438, 48.26412943431309, 46.1655650138855, 45.16277320044381, 39.764227867126465, 36.03989962169102, 37.341908659253804, 37.6637978553772, 38.83309629985264, 40.2272002356393, 37.683391775403706, 41.73027971812657, 43.360094342912944, 46.48413297108242, 45.085457120622905, 45.00788048335484, 34.22076048169817, 19.441895178386144, 5.368622916085379, 4.143138297966548, 4.489486021654947, 7.955754263060434, 9.204895326069423, 9.784281287874494, 11.668602347373962, 16.407833984919957, 15.226911204201834, 8.150227393422808, 2.562602686030524, 0.26898270792194773, 0.8317797098840986, 4.299986932958875, 14.802444015230451, 27.986999988555908, 36.272497517721995, 33.78160653795515, 38.8447345324925, 33.1427891595023, 10.186273659978594, 0.4929629106606756, 0.10938850311296326, 0.14810292928346566, 0.09559978265315294, 0.1341467938785042, 0.140123968145677, 0.1138651514691966, 0.21975596940943173, 0.11354942912501947, 0.1949343170438494, 0.11732532722609383, 0.11396687743919236, 0.17891247676951544, 0.1593725545597928, 0.14298513318811143, 0.13145895382123335, 0.19413323860083306, 0.21833050304225513, 0.14604576038462774, 0.13128731160291604, 0.0689372376405767, 0.1389659395707505, 0.10924687249852078, 0.3079276867210865, 0.1779273660587413, 0.14840635657310486], [0.022214602080306838, 0.035408532313470326, 0.021822997468656728, 0.04964185605889984, 0.04159373523933547, 0.034182460246873755, 0.0403517956313278, 0.057466969559235234, 0.034859617839434316, 0.01638309740727501, 0.028961876274219582, 0.024924173917887465, 0.0182431535795331, 0.029749241524509022, 0.05243197509220668, 0.087433315148311, 0.06264632913683142, 0.03204899008518883, 0.010294145521973925, 0.04049714801034757, 0.044699848030826876, 0.01636892620341054, 0.03655747530449714, 0.007181815653374153, 0.029403846843966415, 0.03508514930893268, 0.04105707510773625, 0.034136886442346234, 0.02218373043329588, 0.031230374904615537, 0.030300347666655267, 0.06373737273471695, 0.25951364317110603, 9.276288066591535, 17.638158457619802, 16.78297417504447, 30.41496113368443, 43.73321955544608, 30.652488776615687, 7.097387705530439, 3.1717729696205685, 0.3030866379184382, 0.06824123713054828, 1.022813264812742, 3.183017760515213, 6.141281706946237, 5.826857915946415, 9.235622865813118, 6.905055923121316, 4.681326653276171, 3.275612494775227, 4.293128626687186, 2.04956876380103, 0.8055043369531631, 1.8857808325971877, 7.743353911808558, 18.457913875579834, 29.39778654915946, 40.15499108178275, 48.734164646693635, 48.95357138769967, 50.282028743198936, 51.360357897622244, 49.77539389474051, 48.712392466408865, 46.744068554469514, 43.39657933371407, 43.719524656023296, 37.237831592559814, 38.657709871019634, 45.102883202689036, 48.653850419180735, 47.55683755874634, 45.98731940133231, 44.9511137008667, 46.41383457183838, 48.04912437711443, 47.25413233893258, 41.660363469805034, 37.76959807532174, 34.39611216953823, 35.56916611535208, 34.25329542160034, 34.22616270610264, 34.57900612694876, 38.62593228476388, 42.20467839922224, 45.49148552758353, 44.781365735190256, 49.09812865938459, 35.495098318372456, 45.58382361275809, 48.00492688587734, 43.224969250815256, 42.10627106257847, 36.0050995690482, 33.41431433813912, 33.75414030892508, 34.643648692539756, 35.090793064662385, 37.77333968026297, 37.973618030548096, 35.84568010057722, 34.97929532187325, 34.1504864011492, 33.092998368399485, 33.24520560673305, 41.25535644803728, 44.16612012045724, 44.468773228781565, 46.05394567762102, 45.90133196966988, 44.71634449277605, 44.21314205442156, 42.65063462938581, 40.055913243974956, 36.277316093444824, 36.36050687517439, 36.441925866263254, 38.40723426001412, 37.359598772866384, 40.314017977033345, 39.87067774363926, 41.81143120356968, 41.22865104675293, 44.26817526136126, 39.020381518772666, 22.206859588623047, 6.563564121723175, 0.4652776505265917, 1.913959903376443, 1.8122688915048326, 2.4624239930084775, 2.1341761095183234, 5.053552508354187, 7.046923807689121, 3.847103783062526, 2.869747587612697, 2.085444701569421, 0.5229307625974927, 0.21302814542182855, 2.7191551540579115, 9.81988559450422, 18.582639251436504, 24.502671207700455, 32.928173201424734, 28.425320148468018, 23.60623720714024, 13.280266540391104, 1.735114682997976, 0.014490359595843723, 0.06037650057779891, 0.059134503294314654, 0.07228498014488391, 0.02911588336740221, 0.05544146788971765, 0.01463392742776445, 0.0626829361010875, 0.018899933069146106, 0.02646214478383107, 0.013084730199937309, 0.10594948407794748, 0.006499304419516453, 0.007238226510318262, 0.09161156415939331, 0.04486893556479897, 0.05864662304520607, 0.046086522550987344, 0.045796241877334457, 0.03005087748169899, 0.026036133357722844, 0.011987328728927034, 0.025455519423953125, 0.0382566185934203, 0.0008341866050614044, 0.0565576037125928, 0.11679502496761934, 0.0509196460646178, 0.014591764958043183, 0.05513611016795039, 0.038768451128687174, 0.0381604294691767, 0.0426675135136715, 0.04108843021094799, 0.06133709581834929, 0.005559010946724031, 0.028300523458580886, 0.033762033163969, 0.05356657046026417, 0.0369404472543725, 0.07373251247086696, 0.08018392843327352, 0.010685231054334767, 0.04644121994663562, 0.01905920898674854, 0.01821664491269205, 0.04798378788733056, 0.008823468366504779, 0.02853175631857344, 0.031226761705641235, 0.04708093258419207, 0.07434051377432686, 0.05299511166023357, 0.019929107844031284, 0.059700598275022845, 0.007884033240510948, 0.03903630621997373, 0.0376252621146185, 0.6379258377211434, 12.062192610331945, 24.888989312308176, 21.34233171599252, 39.2535526411874, 45.90522296088082, 24.651664904185704, 9.666556222098214, 4.511495743479047, 0.2923859506845474, 0.24686200491019658, 0.22464518062770367, 1.0650734028645923, 5.649367051465171, 6.961314184325082, 7.7914745296750745, 10.530215569904872, 6.260240512234824, 4.817175226552146, 6.05661313022886, 5.255297362804413, 2.2126021640641347, 2.387479203087943, 8.119146364075796, 21.31500792503357, 32.16714743205479, 42.73015676225935, 49.04239021028791, 49.13729565484183, 50.01184456689017, 51.7248534475054, 51.89458751678467, 51.64818007605416, 49.12765155519758, 46.20519059044974, 44.59516443525042, 39.021222250802175, 38.827492577689036, 46.42507675715855, 50.160800048283164, 49.453546387808665, 46.89153364726475, 44.44532305853707, 47.58900771822248, 49.4136255128043, 47.60910190854754, 44.46391296386719, 37.63038049425398, 36.21243034090315, 35.286683627537315, 36.12202385493687, 35.25837319237845, 36.86608212334769, 39.71504156930106, 44.47652741840908, 47.16807542528425, 47.19953686850411, 50.778463636125835, 39.258471965789795, 47.352018560682026, 48.30367163249424, 44.942807129451204, 43.751055581229075, 36.96910653795515, 35.217833927699495, 35.00256831305367, 35.81617110116141, 36.84668970108032, 37.51666627611433, 37.61973932811192, 36.81515877587454, 35.414085796901155, 33.80878789084298, 34.74518271854946, 34.22859804970877, 42.81115886143276, 45.810223715645925, 45.730044978005544, 47.46911655153547, 45.88808522905622, 45.57354375294277, 46.47277961458479, 43.85082129069737, 41.64307287761143, 37.20093665804182, 36.512748854500906, 38.030683585575645, 39.71230397905622, 38.6036285672869, 41.6086619240897, 40.96556098120553, 42.981285503932405, 42.96867452348982, 45.083365712847026, 40.65178380693708, 25.136451142174856, 9.272469162940979, 1.669411865728242, 2.6641814410686493, 2.6046158373355865, 3.000070605959211, 4.155608577387674, 5.5716957449913025, 5.495226042611258, 4.731947319848197, 2.9320996361119405, 1.0132365844079425, 0.3171060399285385, 0.19014255702495575, 1.8923201731273105, 10.543816668646675, 19.943268503461564, 26.786641359329224, 34.719564710344585, 32.226082052503315, 30.22809280667986, 17.69771146774292, 2.8093336522579193, 0.004394696168934128, 0.016328385432383845, 0.059649301027613025, 0.04528457558314715, 0.05693040442253862, 0.022695881880021522, 0.026422045060566494, 0.06282392889261246, 0.03436448405097638, 0.006047219013063503, 0.015186813027997102, 0.04038099977853043, 0.02930950333497354, 0.03788423518251095, 0.008709237844284092, 0.05248551829052823, 0.0490648434497416, 0.045704140926578214, 0.02013491769321263, 0.018087580766794936, 0.03623521527541535, 0.029909447035087005, 0.021414102088393908, 0.024454795622399876, 0.0014974107990773128, 0.04098252446523734, 0.1503784100392035, 0.137201653527362, 0.13781466920460972, 0.1235434492783887, 0.1484590380319527, 0.16195866864706787, 0.18783887635384286, 0.1491122501237052, 0.17092986511332647, 0.10391723098499434, 0.09484145191631146, 0.19172009666051182, 0.18441137884344372, 0.1688970827630588, 0.11597031993525368, 0.1759489479341677, 0.11429129860230855, 0.09408308725271906, 0.10587298603994505, 0.09018232513751302, 0.11590036297483103, 0.10678117802100522, 0.11767467776579515, 0.11992022155651025, 0.12747823313942977, 0.20652909630111285, 0.16161855975432055, 0.15188403853348323, 0.09871065536780016, 0.08999275602400303, 0.10907536598720721, 0.12795806596321718, 0.823223600430148, 15.313848802021571, 32.40480361665998, 31.558766637529644, 45.53166348593575, 54.06581967217581, 39.60152884892055, 11.296354344912938, 4.686898674283709, 0.676507827426706, 0.5971797012857029, 2.4222373494080136, 7.043470987251826, 13.207247052873884, 13.687078356742859, 17.632554735456193, 17.38913675716945, 11.50252389907837, 9.106435877936226, 8.97048829283033, 5.388526465211596, 2.191479206085205, 2.9078740903309415, 8.71678524357932, 21.396227155412944, 30.783889634268625, 42.5189072063991, 49.89471183504377, 50.31324005126953, 51.30640166146414, 53.947502272469656, 51.97738572529384, 53.679020404815674, 51.284956046513145, 49.02593340192522, 48.7500273840768, 41.64608839579991, 40.979631083352224, 48.04770694460188, 52.242532457624165, 51.11810547964913, 47.25881889888218, 45.43577487128121, 49.02438047954014, 50.92709950038365, 51.13260637010847, 46.11380788258144, 40.825388022831504, 38.32689571380615, 38.67754350389753, 38.019743646894185, 36.440192290714805, 38.1889704976763, 43.19129828044346, 46.615981987544465, 49.43819086892264, 48.44929892676217, 53.07864046096802, 42.48797035217285, 48.87840230124337, 51.687538146972656, 47.38941029139927, 45.23288747242519, 39.94953979764666, 37.4008606501988, 35.52130344935826, 37.5409710747855, 38.176488058907644, 41.939621993473594, 40.61555242538452, 38.99395057133266, 39.18904903956822, 35.695334979466026, 36.3925450188773, 36.2355956350054, 43.583058561597554, 47.9997296333313, 47.55506576810564, 48.47228356770107, 45.48823724474226, 46.89919056211199, 48.80041572025844, 45.071849073682515, 43.38806084224156, 39.45531095777239, 38.53984757832119, 39.503774642944336, 41.7892872946603, 40.49003669193813, 44.5229309626988, 44.381958961486816, 45.28774002620152, 43.94162729808262, 46.2224360193525, 41.184450081416536, 23.692684956959315, 8.186885220663887, 1.1571215093135834, 5.054323758397784, 4.122397490910121, 5.031455499785287, 6.506288383688245, 9.745117766516548, 13.287109647478376, 12.7744220495224, 7.9644768578665595, 3.385791165488107, 1.0732107205050332, 0.37972252709524973, 3.513039605958121, 12.863222633089338, 23.701194763183594, 32.94576951435634, 42.50733845574515, 37.470460755484446, 33.889400890895296, 19.956193889890397, 2.897645039217813, 0.12276109840188708, 0.1253382693976164, 0.1777668111026287, 0.12253305635281972, 0.13120313254850252, 0.16728188443396771, 0.12773311803383486, 0.13950089657945292, 0.07525238341518811, 0.07734705494450671, 0.09057061680193458, 0.13202197503830704, 0.14775990269013814, 0.15382443155561173, 0.1935256783451353, 0.15605837239750794, 0.08490767888724804, 0.14803190023771354, 0.15423433456037725, 0.14558062462934426, 0.06952852662652731, 0.16592178813048772, 0.12671645544469357, 0.12405844378684248, 0.13545435800084046, 0.19242247539971555], [0.023108806061957563, 0.042169601124312193, 0.0321681374417884, 0.04800923973588007, 0.03271997979442988, 0.019403541759986962, 0.043467262028051276, 0.02802861581689545, 0.0485203903434532, 0.013266393532311278, 0.06029061161513839, 0.033223225469035764, 0.01064364958022322, 0.020829684965844666, 0.12959927932492324, 0.027694462765274302, 0.03183466801419854, 0.030721633096358607, 0.019986075947859457, 0.023903506275798594, 0.009356532262505164, 0.030476783734879324, 0.03126500054661717, 0.03798499424010515, 0.05887817312031984, 0.016922166338190436, 0.023844857101461718, 0.06385054559047733, 0.019746242656505535, 0.04583651293069124, 0.029281663043158393, 0.08234306078936372, 0.04282518808862992, 4.366984069347382, 16.60157755443028, 24.678764615740093, 20.6447343145098, 33.23997013909476, 54.596533502851216, 34.976811340876985, 6.842649374689374, 2.221197519983564, 0.35242137206452234, 0.0940815605489271, 0.6652948462537357, 3.315550523144858, 5.167520335742405, 5.955474283014025, 7.1095887422561646, 4.944645140852247, 2.78080586876188, 5.245222474847521, 4.370792550700052, 2.091210186481476, 1.431429875748498, 2.5751381048134396, 9.898889218057905, 19.286592517580303, 31.758106981004985, 44.4402300289699, 51.435641629355295, 50.27649450302124, 51.01528256280081, 47.62679202216012, 46.57924338749477, 45.7693578856332, 44.26617418016706, 42.081191539764404, 41.69810608455113, 39.26886299678257, 45.755009855542866, 48.895592144557405, 47.087215764181956, 46.41634634562901, 45.77864415305001, 46.23863574436733, 47.904608794621055, 46.053646905081614, 46.432893480573384, 41.5706969669887, 34.35073001044137, 34.60212278366089, 34.47965383529663, 36.24006332669939, 36.228095054626465, 38.21784373692104, 41.96753290721348, 46.593386445726665, 47.38985845020839, 47.64976971490042, 35.94888516834804, 46.60675130571638, 48.771115166800364, 44.47116340909685, 42.334338733128135, 34.988140378679546, 33.86240366527012, 33.68188599177769, 36.07484906060355, 38.60476459775652, 41.23970215661185, 41.916335105895996, 42.35194546835763, 40.89812176568167, 37.3069349016462, 34.40377950668335, 31.950339317321777, 34.74688502720424, 42.53191076006208, 43.281468527657644, 43.82415757860456, 45.10758713313511, 45.39276899610247, 44.07331998007638, 42.268636567252024, 40.650182247161865, 36.79273346492222, 36.3712592124939, 39.38323034558977, 41.95841687066214, 40.63413190841675, 40.712146282196045, 41.95249700546265, 43.213424818856375, 43.64933047975813, 41.85632004056658, 26.994788544518606, 10.443869437490191, 1.8275597052914756, 1.3174846300057002, 1.9678540400096347, 3.069628587790898, 2.5247575853552138, 3.7890906674521307, 3.661635083811624, 3.6155055591038296, 1.7193582313401359, 1.8045760414430072, 0.8020130842924118, 0.038911489703293355, 1.3580778517893382, 7.594199538230896, 21.2815488747188, 25.13743257522583, 31.242234502519878, 25.117185524531774, 25.97787799154009, 15.804883207593646, 5.99138821874346, 0.3388007586555821, 0.030969579970198016, 0.07577906229666301, 0.023367885999115448, 0.04090567019635013, 0.0780816844531468, 0.029442774397986274, 0.008063287773568715, 0.07480707445314952, 0.01760294391507549, 0.03896603374076741, 0.042473340540059974, 0.04329039848276547, 0.14528653398156166, 0.01256508009308683, 0.021997197763994336, 0.03130134288221598, 0.030863586014934948, 0.06817303757582392, 0.013894373451226523, 0.03209932042019708, 0.021517010405659676, 0.04275452884446297, 0.022919194540008903, 0.04062010194840176, 0.047859073150902987, 0.0400799948589078, 0.08536114384021078, 0.06124735277678285, 0.03261996034000601, 0.010943932708219757, 0.03120067881952439, 0.02966547298378178, 0.02654992346651852, 0.014400368888995476, 0.027442351382757937, 0.07485540650252785, 0.028837497412626232, 0.02221741121528404, 0.02543330249110503, 0.05989350578082459, 0.12004712117569787, 0.05082014908215829, 0.06037653450454984, 0.013960338081233203, 0.04239267629704305, 0.04111267765983939, 0.012663103806387101, 0.02259794043909226, 0.0451205872398402, 0.040471424747790606, 0.04944471449458173, 0.04041962877714208, 0.11850042774208955, 0.03049683105200529, 0.01206329750961491, 0.041840911975928714, 0.0460376476735941, 0.10509490314871073, 0.08850432839244604, 5.459456282002585, 19.57802775927952, 29.89438819885254, 26.12978819438389, 42.43516056878226, 52.24408538000924, 26.115627765655518, 6.783290045601981, 3.2617684262139455, 0.09310186454760176, 0.07775710044162613, 0.8437537359339851, 2.4402449088437215, 5.372713233743395, 5.637160803590502, 6.977271590914045, 7.22730599130903, 7.146095446177891, 4.794344748769488, 7.69623817716326, 3.039874881505966, 1.6229585983923502, 4.070102742740086, 10.687069416046143, 21.37580292565482, 33.86765302930559, 46.340169770377024, 52.296707562037874, 51.35667535236904, 51.30516835621425, 48.70268930707659, 48.11782816478184, 47.65386915206909, 45.669943060193745, 45.700932025909424, 43.07388414655413, 41.08981909070696, 47.69522483008248, 50.92795760290963, 49.989186491285054, 47.477266788482666, 45.8102445602417, 47.378703117370605, 49.77654382160732, 48.03151764188494, 48.29061596734183, 43.56485775538853, 36.469544955662315, 36.03104761668614, 36.35261024747576, 36.13142129353115, 38.267565046037944, 39.38138559886387, 44.136055265154155, 47.68521595001221, 50.05989136014666, 49.35124111175537, 38.60468121937343, 48.02612931387765, 49.14934383119856, 46.48040526253836, 43.51989596230643, 36.155086857931956, 36.0634331703186, 35.633826051439556, 37.61924600601196, 39.47278915132795, 42.281198910304475, 41.402456760406494, 42.76694747379848, 41.104865414755686, 38.391333307538716, 36.04550681795393, 33.69485827854702, 37.686518464769634, 44.219346795763286, 43.2262407711574, 45.95031329563686, 45.42173603602818, 45.20892660958426, 44.8183787890843, 44.782324586595806, 41.845084803445, 39.13746561322893, 38.34587124415806, 40.30145215988159, 41.465535981314524, 41.385041100638254, 41.56172684260777, 42.15750013078962, 43.26224981035505, 44.11090626035418, 43.90000064032418, 29.772429943084717, 13.118343114852905, 2.929364000047956, 1.7935852940593446, 4.001321656363351, 3.368394613265991, 4.666735001972743, 5.100764649254935, 4.62699738570622, 6.090850813048227, 2.664111307689122, 0.964064074414117, 0.4806243213159697, 0.07903134849454675, 1.2174404497657503, 7.898567983082362, 23.344352654048375, 26.16873632158552, 33.403256280081614, 30.522821494511195, 30.561505590166362, 18.603046110698156, 9.00414536680494, 0.5183275810309819, 0.04765252709122641, 0.02490263382372047, 0.039252830137099536, 0.004488678782113961, 0.03865803312510252, 0.008784741828484195, 0.03513571713119745, 0.04279321212587612, 0.033283255462135584, 0.034827251719044786, 0.05721608802144017, 0.06790899924401726, 0.06304291928453104, 0.032324397271232944, 0.021070449546511685, 0.021028197170900445, 0.030417832612459148, 0.08167165038841111, 0.045164145795362334, 0.017800229668085064, 0.030906717093395333, 0.030960932041385343, 0.013169014427278723, 0.00931015778665564, 0.09337216575763055, 0.03718907944858074, 0.19779392145574093, 0.10774397850036621, 0.12753020892185823, 0.0799134983015912, 0.08606911370796816, 0.0867763032604541, 0.13416765204497746, 0.09231850265392236, 0.10174143380884614, 0.17816616967320442, 0.1413859754268612, 0.07728752706732069, 0.2490441735301699, 0.10643821249582938, 0.20322743989527225, 0.1747508179396391, 0.13444662493254456, 0.16549543743687017, 0.11336380229996783, 0.2108119007732187, 0.051003177118088515, 0.1915217473038605, 0.13659152840929373, 0.20588545155312332, 0.14795950055122375, 0.11378389690071344, 0.12996954231389932, 0.12304369466645376, 0.15225213021039963, 0.11023469056401934, 0.10987611194806439, 0.19615749855126652, 0.16517318758581365, 6.293211451598576, 26.554519414901733, 39.061626025608604, 32.62004838671003, 43.37322643824986, 62.43234361921038, 41.25263622828892, 10.181046877588544, 3.4047625703471045, 0.6281356630580766, 0.2571456916630268, 3.308737597295216, 7.863974639347621, 12.542362638882228, 15.342053277151924, 16.67410285132272, 12.809440101896014, 8.59909405027117, 11.149642263139997, 10.47978207043239, 4.717336560998644, 2.7549520560673306, 3.259422106402261, 11.12076120717185, 21.351565871919902, 34.94164303370884, 46.90152168273926, 54.984208243233816, 53.03633982794625, 53.141511235918315, 50.29137059620449, 49.82405907767159, 49.79014492034912, 47.69352946962629, 46.531714235033306, 44.76371383666992, 41.80937453678676, 48.62248625074114, 53.24161393301827, 50.62073605401175, 47.04699264253889, 46.60293327059065, 47.88438606262207, 51.004599707467214, 49.03313520976475, 49.91345807484218, 46.404166153499055, 38.28039836883545, 37.83595337186541, 38.254804679325645, 39.50522681644985, 39.827366147722515, 41.16047879627773, 46.26264871869768, 50.311252866472515, 52.75779696873256, 50.429316656930105, 41.20810522351946, 49.67009741919381, 51.92965160097395, 48.7408766065325, 46.65452364512852, 39.63249002184187, 36.66916670118059, 37.71991498129708, 39.50274978365217, 42.2429838180542, 44.199923106602256, 44.568302699497764, 44.78920330320086, 43.718742983681814, 41.013031073978965, 39.118524823869976, 34.96351943697248, 38.475993633270264, 45.24492522648403, 46.28674159731184, 46.915803704942974, 46.57461936133248, 46.11302273614066, 45.89301150185721, 47.24252189908709, 43.50075714928763, 40.17307376861572, 39.74179213387625, 42.31690917696272, 44.20746537617275, 43.27042784009661, 43.929513113839285, 44.96431875228882, 46.45782361711775, 46.37117958068848, 44.94528068814959, 29.35272053309849, 12.491982119424001, 3.055846184492111, 3.4513202777930667, 5.586422451904841, 7.506495901516505, 7.878985353878566, 7.77781697681972, 8.27333470753261, 10.128549763134547, 7.69099315575191, 4.506982454231807, 1.952455746276038, 0.3435352774603026, 1.7603694306952613, 9.88263043335506, 25.814621380397252, 33.04165465491158, 41.00900459289551, 33.72629540307181, 36.88512366158621, 22.26170345715114, 9.079846858978271, 0.4896742956978934, 0.18650438796196664, 0.1346285401710442, 0.14924710217331136, 0.1287972509328808, 0.19916023313999176, 0.0761875200218388, 0.1296210331576211, 0.09274745213666133, 0.09692511082227741, 0.19056487722056253, 0.20767297063555035, 0.13663267477282456, 0.18462663729275974, 0.08048356949750866, 0.07936312497726508, 0.1489683192755495, 0.12801856414547988, 0.18419601182852471, 0.13121481692152365, 0.14252562927348272, 0.09424151839422328, 0.14135293077145303, 0.09817704185843468, 0.12582898592310293, 0.2420311884156295, 0.15655709563621453], [0.011196898196690848, 0.03572524192609957, 0.014979473082348704, 0.015332229867843645, 0.04912867323894586, 0.0378496231112097, 0.035264577716588974, 0.09295176581612655, 0.030198435099529367, 0.05163611119080867, 0.030437208179916655, 0.06931738688477448, 0.008613588155380316, 0.03150790251259293, 0.02950809696423156, 0.022697545987154757, 0.09510830616844551, 0.10569766616182667, 0.08786949102899858, 0.02506323458094682, 0.030692340739603554, 0.03144056469734226, 0.04468933413071292, 0.029598379441137825, 0.03051903611049056, 0.0299526256109987, 0.04550498750592981, 0.05784155481628009, 0.046314964935715706, 0.006433749879111669, 0.05088493899841394, 0.027136864739337137, 0.013736228990767683, 0.4520718391452517, 11.459398167473928, 21.54865847315107, 21.284164871488297, 20.66770158495222, 35.30901861190796, 60.24933079310826, 30.190711498260498, 8.808771576200213, 1.880014262029103, 0.38597017899155617, 0.3630312984543187, 1.9906753982816423, 3.507340346063886, 3.348280881132398, 6.51479515007564, 4.88526279585702, 5.675827094486781, 3.5400170726435523, 6.641242376395634, 2.8751076885632108, 0.7832205955471311, 0.9284861492259162, 3.808653320584978, 12.303907411439077, 23.902487550462993, 36.699103014809744, 49.82851982116699, 52.53362723759243, 49.977874823978965, 47.74319519315447, 47.65273659569876, 46.691307408469065, 45.05369343076433, 42.87513092585972, 42.47577626364571, 40.69460555485317, 47.038970947265625, 51.3719197000776, 48.580918652670725, 47.289099148341585, 46.93317072732108, 46.53148494447981, 48.42107881818499, 48.8746919631958, 46.670692103249685, 45.069233076913015, 37.26964739390782, 35.30779572895595, 36.44624069758824, 35.837505544934956, 35.09065410069057, 38.67301327841622, 43.69873564583914, 45.500511237553184, 46.25694077355521, 49.075765882219585, 37.92263214928763, 46.67912374223982, 47.49332060132708, 42.75860268729073, 41.78477096557617, 35.248722144535606, 35.283942563193186, 33.910690171378, 37.155346052987234, 38.27286652156285, 41.8318623815264, 42.245012692042756, 43.155004365103586, 42.29868752615792, 43.97948803220476, 39.17786938803536, 34.76577370507376, 31.43477255957467, 36.15749093464443, 41.775981494358604, 44.94814682006836, 43.74469797951834, 45.78789220537458, 44.74622869491577, 44.31570093972342, 41.56531211308071, 41.32891007832119, 38.28841659000942, 39.70541484015328, 42.10001768384661, 41.29449217660086, 43.11814764567784, 43.330964020320344, 43.530474594661165, 43.35006809234619, 30.02597665786743, 12.33665600844792, 1.9085377029010226, 0.8764773628541401, 1.7776073685714175, 1.8549820738179343, 1.366729553256716, 3.103861710854939, 4.039020410605839, 4.752522238663264, 4.5380191888128, 1.7851042577198573, 0.7325667079005922, 0.3231987687093871, 0.9088939119662557, 5.860364735126495, 16.192177534103394, 25.329013517924718, 21.948853867394583, 20.33170059749058, 23.832244736807688, 24.970113004956925, 9.455001814024788, 1.2813894982848848, 0.04098377975502184, 0.02801462951382356, 0.03784559600587402, 0.054129089561424086, 0.0433436465183539, 0.09958469668137175, 0.036255747745079656, 0.050678392938737354, 0.026418455610317842, 0.11121845099010638, 0.11065021183873926, 0.05008365360221692, 0.09492514921086175, 0.05947411685649838, 0.023150139022618532, 0.03126815573445388, 0.024291847134009004, 0.023263786852891957, 0.013282230539646531, 0.036351940261998346, 0.041317870042153766, 0.08936592537377562, 0.028293997648039033, 0.06444228919489042, 0.04045149278161781, 0.03336105289469872, 0.061547780941639624, 0.026740686801661338, 0.04342548462695309, 0.05096455490482705, 0.0063025364735429835, 0.059626108700675626, 0.05710435365991933, 0.037787784822285175, 0.03735126967408827, 0.041087914524333816, 0.026984548894688487, 0.03843898845038243, 0.04589302471971937, 0.04443718373243298, 0.020231724284323196, 0.021257631913093582, 0.03576705664662378, 0.05481439296688352, 0.061973453100238524, 0.008179301146550902, 0.021943286460425173, 0.043627243622073104, 0.005348229980362313, 0.0019873527344316244, 0.030780957413039038, 0.04000622792435544, 0.03365021398557084, 0.00740167117744152, 0.010154042459492172, 0.10379626854721989, 0.020499453846631304, 0.03166704611586673, 0.026360289892181754, 0.06387815518038613, 0.8045356060777391, 15.169084821428571, 28.53037691116333, 26.126864739826747, 25.930350576128276, 47.12822750636509, 57.71490240097046, 23.44520401954651, 7.981034415108817, 3.2938914682183946, 0.35344935261777466, 0.21837772907955305, 0.835527665913105, 2.670588331563132, 4.216967684882028, 7.496874383517674, 7.30034111227308, 6.020677047116416, 5.471712904317038, 7.833113346781049, 3.6512483954429626, 2.5411175532000403, 2.5470489263534546, 5.84694732938494, 13.441394397190638, 24.401178870882305, 38.09458269391741, 50.671051434108186, 52.58866739273071, 52.154335498809814, 49.900972161974224, 48.595273630959646, 48.15584175927298, 46.33817911148071, 43.9490236554827, 43.087009293692454, 42.3779421533857, 48.29068544932774, 51.57276780264718, 50.22640493937901, 47.799211570194785, 46.686992577144075, 47.11767666680472, 49.191967555454795, 50.964400904519216, 48.19432783126831, 45.069507530757356, 37.13909421648298, 36.36537756238665, 38.293273380824495, 37.068806239536826, 37.895120756966726, 40.88066789082119, 46.1816257749285, 46.9402231488909, 47.81542866570609, 50.057469912937705, 40.186966691698345, 47.88952772957938, 47.87881013325283, 45.81916952133179, 43.81024728502546, 36.759052072252544, 37.54609884534563, 35.556186880384175, 37.563413756234304, 40.467993531908306, 42.853007861546104, 44.27841343198504, 44.45048904418945, 44.95284032821655, 44.263294151851106, 40.15809692655291, 34.9607366834368, 34.01775843756539, 37.59056036812918, 43.379577091761995, 45.930000237056184, 46.060362339019775, 45.59159517288208, 45.29176303318569, 45.97175543648856, 43.604514598846436, 42.986687728336875, 38.68274770464216, 41.36069113867623, 43.970854895455496, 43.20163025174822, 44.026822635105674, 43.98117644446236, 44.84597355978829, 45.629115445273264, 34.67292145320347, 14.806684153420584, 3.545036928994315, 1.915236417736326, 2.6929563198770796, 3.252087197133473, 3.6110413415091376, 4.356057592800685, 6.624158927372523, 5.626658167157855, 2.1233697065285275, 1.6859896161726542, 0.19313903552080902, 0.10223562443362814, 0.6831081818257059, 5.470017543860844, 17.484561579568044, 28.194568736212595, 26.0378965309688, 27.318574598857335, 28.919995410101755, 30.068690708705358, 13.156787497656685, 1.9885099487645286, 0.04751667420246771, 0.03282583804268922, 0.04551722827766623, 0.044055572245270014, 0.06860305914389235, 0.11647312795477253, 0.06598495213048798, 0.004098024543574346, 0.03501971139173422, 0.026854092055665593, 0.09645773590143238, 0.035473576680357964, 0.03978767518752387, 0.05218996200710535, 0.022621987720153162, 0.10011553498251097, 0.018460418796166778, 0.010793048572460455, 0.06329950051648275, 0.054890806188008616, 0.06732976103999785, 0.01775134970167918, 0.02589072839223913, 0.03506634031821575, 0.042492180064852746, 0.002744163976915713, 0.06383167553160872, 0.09765484809343304, 0.11932027446372168, 0.07042453211865254, 0.11550435636724744, 0.11616937496832438, 0.09117375979466097, 0.08636188799781458, 0.20267636089452676, 0.0624636471537607, 0.11059656007481472, 0.11160809972456523, 0.12996099277266435, 0.0862784960440227, 0.08170563820749521, 0.09023331704416446, 0.1828921525073903, 0.14288366506142275, 0.15496979866709026, 0.12816767900117806, 0.14447265836809361, 0.10915166725005422, 0.09111875096069914, 0.08323344801153455, 0.14321234742445604, 0.17906653136014938, 0.08438159711658955, 0.13487521479172365, 0.09201896336994, 0.17096822948328086, 0.1360584712986435, 0.24607200015868458, 0.10437438038310834, 0.13157169919993195, 0.9693881315844399, 17.472006184714182, 34.455776350838796, 36.12665482929775, 33.47414180210659, 44.29560674939837, 65.62902218954903, 35.19439417975289, 11.585359454154968, 3.330573179892131, 0.6120129653385707, 0.754020628120218, 4.0985048072678705, 10.17620050907135, 12.147374050957815, 14.16823068686894, 12.618753739765712, 13.019629188946315, 10.77029754434313, 13.314305765288216, 7.271619430610111, 3.1456727130072455, 1.5905604511499405, 4.7973415936742505, 13.217186450958252, 24.87124535015651, 40.03056968961443, 53.31618200029646, 55.91941145488194, 52.714627810886924, 51.40379108701433, 52.01502759116036, 50.26993192945208, 48.39822619301932, 46.64806876863752, 47.08232423237392, 44.43927117756435, 51.27906050000872, 55.39513513020107, 53.058796405792236, 50.37894221714565, 46.93467501231602, 47.35834836959839, 50.07365574155535, 53.319756848471506, 49.590036800929475, 47.503892285483225, 39.52517509460449, 38.74299553462437, 40.54894004549299, 38.49524014336722, 40.51469932283674, 42.1199312210083, 48.118053981236045, 47.51829937526158, 49.84551511492048, 52.05512564522879, 44.61278159277779, 50.32210595267159, 50.18907921654837, 47.293163844517295, 45.887348720005576, 37.98589202335903, 38.19555738994053, 36.65082345690046, 40.385542733328684, 41.893822942461284, 44.9202150617327, 46.694024154118125, 45.77926254272461, 46.47456182752337, 46.7765930720738, 44.099104745047434, 37.95491695404053, 35.185952118464876, 38.61690657479422, 43.751097270420615, 47.656238487788606, 47.80737917763846, 46.62890216282436, 45.685187407902305, 47.776119232177734, 45.08596086502075, 45.1921432358878, 41.81074333190918, 42.645843846457346, 46.29179293768746, 43.75668709618704, 45.66172334126064, 45.726108823503765, 47.45907987867083, 45.50011171613421, 33.68817063740322, 13.906575424330574, 3.276928092752184, 1.9548758906977517, 4.718941594873156, 5.699414491653442, 6.057659268379211, 7.948905944824219, 10.808926922934395, 11.553963150296893, 10.275402545928955, 4.178779082638877, 1.9256048670836856, 0.6374028229287693, 1.4589325828211648, 7.372001358440944, 20.145094564982823, 31.680224622998917, 29.560384818485804, 30.9138765335083, 34.5518456186567, 33.802405970437185, 13.469989708491735, 1.8341411692755563, 0.10212915550385203, 0.07620520942977496, 0.10596716670053345, 0.11223068953092609, 0.14581642911902495, 0.2414591291121074, 0.08708015802715506, 0.11575270018407277, 0.1132306805146592, 0.12562929306711468, 0.16026417671569756, 0.14322338040385926, 0.2677978500723839, 0.15474643850965158, 0.1218612931136574, 0.21662455743977002, 0.11895719037524291, 0.08609599726540701, 0.20845454798213073, 0.136293977232916, 0.09889430765594755, 0.1925693375191518, 0.13486438537282602, 0.1448837420237916, 0.15895281279725687, 0.10554576252720185, 0.1636798677167722], [0.023356591783730046, 0.01314539716778589, 0.009994050687445062, 0.01867927348108164, 0.04954474073435579, 0.04288987622463277, 0.0701088844133275, 0.033470839860716035, 0.012268545871068324, 0.029753563792577813, 0.07000441037650619, 0.016241599107161164, 0.06423404679766723, 0.017171195475384593, 0.010594591498374939, 0.04890112652044211, 0.036799240724316666, 0.06107279285788536, 0.005486959433515689, 0.006085089324707431, 0.008127236306401235, 0.03595673432573676, 0.09137459258948054, 0.032628940750977824, 0.025137408636510372, 0.06066455904926572, 0.03600649469132934, 0.04087387743805136, 0.021301913108410578, 0.033503202588430474, 0.02752090707820441, 0.05855972306536777, 0.026112541489835297, 0.03161172854847141, 2.0286811760493686, 17.94968788964408, 26.871028968266078, 21.380760465349468, 17.264004911695206, 35.283574308667866, 52.14291960852486, 28.635600430624827, 7.621666635785784, 2.9650323603834425, 0.1337475845856326, 0.06858369375446013, 1.1769325605460574, 1.6287427565881183, 3.993085435458592, 5.551235471452985, 4.997128358909062, 3.20473370381764, 6.662656290190561, 2.1782346367836, 1.4532259404659271, 2.546404263802937, 2.72036566053118, 6.944294571876526, 17.23035478591919, 28.437041759490967, 42.93777241025652, 49.67400925500052, 50.403108051845, 47.97610228402274, 47.519668170383994, 44.088540009089876, 45.20557062966483, 44.41923604692732, 43.379587514059885, 40.466166155678884, 47.23157501220703, 49.30778707776751, 50.85556084769112, 46.895584447043284, 47.02978890282767, 47.924025535583496, 48.96151665278843, 50.03084094183785, 49.34200695582798, 46.89462212153843, 40.00758852277483, 34.374652658190044, 36.121075425829204, 36.79952185494559, 37.422059604099815, 39.82050827571324, 44.23888513020107, 46.50531455448696, 45.73709739957537, 46.95048563820975, 35.31488289151873, 45.7219294820513, 49.27063505990164, 44.00055497033255, 43.04559803009033, 39.19838741847447, 37.316311495644705, 37.35366153717041, 37.131524154118125, 37.674553666796, 39.965788160051616, 43.39999437332153, 46.391739300319124, 45.721151283809114, 45.16429138183594, 44.25942747933524, 42.63624143600464, 37.27668244498116, 34.345918382917134, 36.57853092466082, 43.59782000950405, 43.4096280506679, 44.86079406738281, 44.52778775351388, 45.09823138373238, 43.17347962515694, 41.96815129688808, 39.960041999816895, 42.65130860464913, 44.22097267423357, 43.20634807859148, 43.40118946347918, 44.81826066970825, 43.24559497833252, 32.63422271183559, 15.617992298943655, 2.023948367152895, 0.3194969802030495, 1.4176593061004366, 2.15832587650844, 3.342118046113423, 1.9819434668336595, 4.1346905912671765, 5.243187955447605, 3.0926032406943182, 2.1246182109628404, 2.603238574096135, 0.15305877264056886, 0.5786386504769325, 2.755740676607404, 13.233699713434492, 23.923033373696462, 25.781292608806066, 13.71738292489733, 19.781246934618267, 18.1460439818246, 13.247202668871198, 1.8598084662641798, 0.08068898240370409, 0.043413905426859856, 0.05126930194507752, 0.09448373503983021, 0.008251119837430971, 0.043497914847518714, 0.04663466688777719, 0.0809195621737412, 0.027883892779105475, 0.029122397303581238, 0.09115755637841565, 0.07659218473626034, 0.024580227909609675, 0.05920497594135148, 0.024862430623865554, 0.012160938698798418, 0.03737149341031909, 0.004981748127777661, 0.045677895192056894, 0.03695921214031322, 0.03815911989659071, 0.04194445302709937, 0.05594346166721412, 0.027121227899832383, 0.018138341971540024, 0.04024858706231628, 0.01584980620204338, 0.06849629165870802, 0.035550729504653385, 0.019425309163385203, 0.04176119089658771, 0.013121534787517573, 0.046877782592283826, 0.068157431270395, 0.038020485014255555, 0.03178615954571536, 0.04544209409505129, 0.045777365033115656, 0.046111010879810364, 0.038110038066016774, 0.047294077396925004, 0.038256333608712466, 0.08415917333747659, 0.007410637169544185, 0.0426242874403085, 0.07319805757807833, 0.0411532370905791, 0.05385161284357309, 0.014285806732784425, 0.031233845611235926, 0.046107943901526074, 0.02175688780178981, 0.03719255354787622, 0.033683173824101686, 0.015953199671847478, 0.021872155634420257, 0.021961885105286325, 0.03627410890268428, 0.058866088411637714, 0.017849610054067204, 0.017769454712314264, 0.031220064565007175, 3.5151499041489194, 21.820187125887188, 32.1118015561785, 24.28069363321577, 23.148359605244227, 47.15067366191319, 50.0515569959368, 24.700500317982264, 7.33264068194798, 3.0485219146524156, 0.09572809362517935, 0.11647907192153589, 0.672580901001181, 2.083713948726654, 6.9764490979058404, 8.063681500298635, 4.636732246194567, 5.8267819200243265, 7.118381687573024, 5.645968513829367, 4.5989145040512085, 3.4753844950880324, 4.609558275767735, 8.327599270003182, 18.24480220249721, 30.005020890917095, 44.715455123356406, 51.032677377973286, 51.72072621754238, 47.97694649015154, 48.624789578574045, 47.42450564248221, 47.68446901866368, 47.056532519204275, 44.595042841775076, 42.79570606776646, 46.93075622831072, 51.357307638440815, 51.74421807697841, 48.826725074223106, 47.47596747534615, 46.370491709027974, 48.13421549115862, 51.53231191635132, 49.53320401055472, 48.38958263397217, 41.719815731048584, 36.77012750080654, 37.689221314021516, 38.126315116882324, 37.96935878481184, 41.6725297655378, 45.30410998208182, 48.472478117261616, 47.64523254122053, 49.71434702192034, 39.2934387751988, 47.22555439812796, 48.95521811076573, 45.784421580178396, 44.419190883636475, 40.085821764809744, 38.916509423937114, 37.88186011995588, 39.05954156603132, 39.36447368349348, 42.35267850330898, 44.82415621621268, 47.41788053512573, 45.927995681762695, 47.04035016468593, 44.82033123288836, 43.53242009026663, 39.161023480551584, 35.58203765324184, 39.30249922616141, 43.75589500154768, 44.727135045187815, 46.33037975856236, 45.337575980595176, 45.544264044080464, 44.37817914145333, 41.232694898332866, 41.880774225507466, 42.384838240487234, 45.22942726952689, 44.84338535581316, 46.054720401763916, 45.48071581976754, 44.21894727434431, 35.269354820251465, 18.09845576967512, 3.6447183915546963, 1.1636619354997362, 3.9430119395256042, 2.9065941018717627, 3.867699546473367, 5.122921586036682, 4.903659888676234, 5.3109815290996005, 4.804924249649048, 1.080044490950448, 0.9997888888631548, 0.15294110109763487, 0.606075675359794, 3.027645183461053, 13.928366712161473, 24.90747846875872, 26.51736044883728, 17.699198382241384, 21.66626020840236, 24.82954052516392, 17.750441346849712, 3.6042236387729645, 0.2779045748923506, 0.036470639785485606, 0.02891901321709156, 0.005382903119815248, 0.023788984831688658, 0.0663368132497583, 0.022913393065599457, 0.0323323022042002, 0.06799483392387629, 0.037143943299140246, 0.04994666416730199, 0.05778106341936758, 0.04219098176274981, 0.038133875001221895, 0.029312200511672666, 0.06725065742752381, 0.044717242276029925, 0.043315741765711985, 0.04663674659760935, 0.07217184800122466, 0.03220251541850822, 0.08951026334294251, 0.05001732001879385, 0.030163463404668227, 0.039661932470543046, 0.008770231357110398, 0.14613209718040057, 0.03438447708530085, 0.08682516456714698, 0.09407244782362666, 0.10135664338512079, 0.10173996817320585, 0.16828773117491178, 0.11237922084650823, 0.13530574526105607, 0.10726489885044949, 0.17283300656293119, 0.18220358874116624, 0.3533517521406923, 0.07282828313431569, 0.1620639908526625, 0.1157135758548975, 0.20254757494798728, 0.15047405633543218, 0.1715606041252613, 0.1534526486481939, 0.08925427243645702, 0.14374017981546267, 0.08375630674085446, 0.1823677806449788, 0.26289204188755577, 0.22034069017640182, 0.0971089598855802, 0.22663797012397222, 0.16212565611515725, 0.11072064377367496, 0.10757296731961624, 0.15255718598408358, 0.18697674332984857, 0.13849944674542972, 0.08110092101352555, 0.13410500969205583, 3.554640207971845, 26.467729466302053, 40.018875871385845, 34.05044971193586, 26.793560028076172, 45.498291288103374, 58.85632814679827, 33.64338254928589, 10.72146647317069, 4.359408795833588, 0.5675110018679074, 1.3712246034826552, 4.321240603923798, 6.143835604190826, 11.253543019294739, 12.473768285342626, 11.860819050243922, 8.786635484014239, 14.254571608134679, 7.131109484604426, 4.359762719699314, 5.34150105714798, 3.918905598776681, 8.214880381311689, 18.976341554096766, 30.622569833483013, 45.58983033043997, 53.86248411451067, 54.22514533996582, 50.76179838180542, 52.03488554273333, 48.9249587059021, 48.96932642800467, 49.11620787211827, 46.87261022840227, 43.567143712724956, 50.39128916604178, 53.183238642556326, 54.280192443302695, 48.63133825574602, 46.92019844055176, 46.89025170462472, 49.44696991784232, 52.13310527801514, 52.577967166900635, 50.78161811828613, 44.21338176727295, 39.45102391924177, 39.17713287898472, 39.32020671027047, 41.43847969600132, 43.6071514402117, 49.22377988270351, 49.46344757080078, 50.221652371542795, 50.76774951389858, 40.5465463910784, 48.57754877635411, 51.21356330599104, 47.764098848615376, 45.53330326080322, 43.932532106127056, 41.137636593409944, 41.42162684031895, 40.70619862420218, 41.431045123508994, 43.81357894624983, 47.08660432270595, 49.99870204925537, 47.79636975697109, 49.038568701062886, 47.69077450888497, 45.7808849470956, 40.87905590874808, 37.05823802947998, 39.966628892081125, 46.15978758675711, 46.21522726331438, 47.805301666259766, 46.50818763460432, 46.41360528128487, 47.026519775390625, 44.881899220602854, 44.23583139692034, 44.2591495513916, 47.9279408454895, 45.5809713772365, 47.309836047036306, 46.88160119737898, 45.49081155232021, 34.015420368739534, 17.262705598558696, 3.094283401966095, 1.3169280141592026, 4.685846022197178, 6.4332979917526245, 7.83485039642879, 7.286557623318263, 10.936849338667733, 11.148181404386248, 7.793326224599566, 6.294269314834049, 4.462279047284808, 0.3088029426123415, 1.0195608564785548, 3.8772828493799483, 16.314028092793055, 29.847828320094518, 34.12464952468872, 21.71642620222909, 28.975356919424875, 30.764941896711075, 19.389396326882498, 3.6743546298571994, 0.2943088917859963, 0.1035812950826117, 0.1534371916204691, 0.16180111281573772, 0.15660968210015977, 0.13716677682740347, 0.10924798529595137, 0.14589630626142025, 0.1305006995264973, 0.2634427680500916, 0.1367515405373914, 0.15361257935208933, 0.10018389060028962, 0.19527396453278406, 0.09874609525182418, 0.1637681858347995, 0.11298893884356533, 0.1589673605880567, 0.1361208829496588, 0.11392488969223839, 0.137586613584842, 0.23612657668335096, 0.14437367367957318, 0.14387245343199798, 0.11726283415087632, 0.125799225377185, 0.19172460213303566, 0.14547390464161122], [0.014383709157950111, 0.024737720976450613, 0.026453479891642928, 0.01678120916975396, 0.027930518312911903, 0.03337404005495565, 0.020086275214063268, 0.023644750339112112, 0.027621642387072955, 0.04100365065304296, 0.01842161168211273, 0.050546207531754456, 0.04653133957513741, 0.03514712330486093, 0.050608225632458925, 0.011468836372452123, 0.05614979398835983, 0.014655274139451129, 0.02055735493611012, 0.05493590501802308, 0.034584705983953815, 0.026638879407463328, 0.045243955084255764, 0.014096079859882593, 0.008244564340982054, 0.025147454347461462, 0.041672374055321725, 0.04299954105434673, 0.019984805391037037, 0.028718719857611825, 0.06814569261457239, 0.0922723419166037, 0.07244902955634253, 0.022589977830648422, 0.041742717780705006, 5.453307560511997, 23.669396332332067, 29.80905737195696, 22.57310434750148, 23.861767632620676, 47.02640513011387, 52.80502387455532, 33.472905022757395, 12.216882961136953, 2.087797535317285, 0.21666140189128263, 0.3411487340927124, 1.6957749596663882, 7.173139137881143, 7.6296092953000745, 1.615078581230981, 4.979686209133693, 4.732604793139866, 4.087237868990217, 5.03257155418396, 2.4849852280957356, 2.2057861983776093, 2.6882137400763373, 8.325892618724279, 19.12212344578334, 32.88819326673235, 44.579332964760916, 50.086711406707764, 49.44039692197527, 49.07869107382638, 48.4174553326198, 48.06901012148176, 47.16352088110787, 46.05330296925136, 43.03436974116734, 46.00786869866507, 48.49025508335659, 49.38702433449881, 47.92589807510376, 48.85626534053257, 49.55480943407331, 45.860403605869834, 49.93186732700893, 48.718242849622456, 46.90967191968645, 38.04991967337472, 36.309319496154785, 35.664749009268625, 38.31968695776803, 38.71257979529244, 42.46292209625244, 47.008280754089355, 47.98247030803135, 46.0800187928336, 51.378433636256624, 36.7108211517334, 45.363114084516255, 48.45986018862043, 45.353139945438926, 43.96575491768973, 43.751844201769146, 42.29481043134417, 39.601792880467, 38.81080995287214, 36.24383619853428, 37.67016587938581, 41.85918617248535, 43.49285009929112, 45.93565607070923, 46.126175676073345, 44.64337451117379, 43.9658591406686, 43.10472025190081, 39.26493379047939, 37.599266460963655, 39.23744671685355, 42.80093458720616, 43.13755049024309, 45.49008199146816, 44.196459429604666, 47.08109092712402, 43.51454584939139, 41.8089576448713, 42.01649338858468, 43.87015812737601, 43.81127561841692, 45.3820618220738, 41.98368052073887, 35.18623004640852, 17.654896668025426, 3.6378381550312042, 0.503046918128218, 0.7475219454084123, 2.8864328180040633, 1.9860322645732333, 2.0695474403245107, 3.380632996559143, 2.3216708600521088, 4.519728056022099, 5.054858769689288, 0.4116787037679127, 0.33847655462367193, 0.30820694459336145, 2.7281584995133534, 12.48511643069131, 20.539948531559535, 27.81287292071751, 34.48004988261631, 16.363725083214895, 24.605978761400493, 15.60683696610587, 5.590326036725726, 0.2837543338537216, 0.030467253710542406, 0.04987838997372559, 0.0026049801173420356, 0.024360548804647157, 0.0588982238301209, 0.06411466534648623, 0.06607065110334329, 0.073021210996168, 0.05100661050528288, 0.0475720053405634, 0.07662389946303197, 0.0318484931652035, 0.030535636469721794, 0.006899830494408629, 0.06168798663254295, 0.06467613271836724, 0.07405903709254094, 0.04423181153833866, 0.01889472022386534, 0.03811005502939224, 0.020584291080012918, 0.11841251674507346, 0.007099217585554081, 0.021257019535239254, 0.08236427179404668, 0.037672226915934255, 0.005570346722379327, 0.03220621682703495, 0.028053674115134136, 0.02075178575302873, 0.048505021525280814, 0.045659523856426985, 0.039379237818398645, 0.029899201156305413, 0.012240788699792964, 0.06277051461594445, 0.01902490564888077, 0.015455828414165547, 0.03165835068960275, 0.045865123359752555, 0.07579038026077406, 0.0246090826112777, 0.008616459206677973, 0.06014940169240747, 0.06507986105446305, 0.0504072232038847, 0.017366026627964208, 0.03512654673042042, 0.04769231977739504, 0.01792163654629673, 0.05179868818127683, 0.06514295124049697, 0.06180122734180518, 0.0946324427745172, 0.06246212723531893, 0.0383316747445081, 0.03284232983631747, 0.011571759956755807, 0.0574732595788581, 0.03612994395994714, 0.06597156463457005, 0.037969228478946855, 0.13163691998592444, 7.966761946678162, 29.008173261369976, 32.377698693956646, 24.244931255068096, 27.879594734736852, 56.879701137542725, 51.36232771192278, 25.85701581409999, 10.000429323741368, 1.7715713381767273, 0.102574369470988, 0.1685161396328892, 0.06072907415883882, 3.4861754817622046, 7.0502515605517795, 3.891370322023119, 5.050959093230111, 7.085434198379517, 9.860793113708496, 8.212346025875636, 3.6016845064503804, 3.1519595299448286, 3.850116261414119, 8.883975403649465, 20.882838657924108, 34.68230152130127, 46.988401957920615, 51.59766319819859, 52.1317503792899, 49.651479721069336, 49.85320329666138, 48.81977687563215, 48.74530955723354, 47.708436829703196, 43.90589966092791, 47.40648896353585, 50.781371457236155, 52.79944447108677, 47.8583094733102, 48.15658869062151, 50.58842693056379, 46.975068364824565, 51.395105838775635, 50.59658758980887, 48.80594996043614, 39.47729158401489, 36.87168237141201, 38.51054355076381, 40.86891848700387, 39.504160267966135, 43.06356259754726, 48.90017795562744, 50.43028245653425, 48.89702694756644, 50.13414328438895, 39.36842373439244, 47.6108215876988, 49.66235017776489, 47.113830838884624, 46.0621098109654, 44.65254613331386, 44.10887738636562, 40.455181053706575, 40.21733726773943, 37.87906347002302, 41.66589423588344, 44.06293937138149, 44.888843945094514, 47.65123231070382, 47.0884108543396, 46.28965984072004, 45.48422813415527, 44.13016666684832, 40.52871036529541, 37.88642856052944, 41.558627946036204, 44.652643408094136, 46.21789537157331, 46.55845090321132, 44.97198608943394, 47.08722966057913, 45.52744245529175, 42.50890180042812, 42.660678250449045, 44.65914692197527, 44.843500001089915, 45.56555332456316, 44.1347142628261, 37.54551519666399, 20.478281532015117, 5.658845262868064, 0.9941827782562801, 1.4121291914156504, 5.439039434705462, 5.6009789279529025, 5.411512843200138, 4.6693054011889865, 4.868113338947296, 5.3607527783938815, 3.630450700010572, 0.8302482834884098, 0.169924330498491, 0.1938079624835934, 2.308476448059082, 10.619174224989754, 23.531382526670182, 32.95696306228638, 33.09999173028128, 16.984855822154454, 28.99823907443455, 19.065929889678955, 7.90744343825749, 0.6030133653964315, 0.013538800745404192, 0.04183299686493618, 0.09167193342000246, 0.0196187934239528, 0.025207937262686234, 0.06877508812717029, 0.030530625488609076, 0.0432404786614435, 0.023479901952669024, 0.04624044482729264, 0.04872761833082352, 0.0059794660191982985, 0.037508706761790175, 0.012886168801092675, 0.01699130396757807, 0.05484212130042059, 0.03738891818959798, 0.0196786113748593, 0.07367639762482472, 0.016286065203270743, 0.01586304442025721, 0.04014084587938019, 0.06268955860286951, 0.02149894610712571, 0.07390621743564095, 0.034719154305223904, 0.03725279049415674, 0.04511783917301467, 0.07123175130358764, 0.07512179935084921, 0.19531899211662157, 0.0839877211089645, 0.12108289131096431, 0.12836620477693422, 0.09608302172273397, 0.15544853226414748, 0.07575700990855694, 0.12921853975525924, 0.21165438342307294, 0.17462623891021523, 0.2326037042907306, 0.10264002451939241, 0.08019188086369208, 0.14727451944989817, 0.17644179505961283, 0.12224063490118299, 0.16069691920919077, 0.272080410271883, 0.12778810651174613, 0.09593211553458657, 0.2076396681368351, 0.12284639025373117, 0.1552756279706955, 0.23810176498123578, 0.22817642614245415, 0.12057392219347612, 0.12163440457412175, 0.06382210140249558, 0.15030424616166524, 0.17017122225037642, 0.09929180704057217, 0.2028764065887247, 0.30648938247135704, 8.500257662364415, 33.95221608025687, 42.0834184374128, 33.867979594639365, 35.300343785967144, 55.09936073848179, 59.70103454589844, 37.83453246525356, 14.672146184103829, 3.2796107488019124, 0.5620971066611153, 1.3251407848937171, 3.85810147864478, 13.203534109251839, 17.403811352593557, 8.015624284744263, 12.558229718889509, 11.078042813709803, 9.5616340807506, 11.31437189238412, 5.8530964851379395, 4.593706829207284, 3.8063065665108815, 9.305198652403694, 21.17831254005432, 36.66650206702096, 47.44093118395124, 52.281727245875764, 53.418490750449045, 51.716185569763184, 52.298389026096885, 51.17898906980242, 51.72096593039376, 51.20268242699759, 45.36275972638811, 48.29634823117937, 52.41887426376343, 53.236611230032786, 48.84627035685948, 48.4780193056379, 49.78989825929914, 46.315034661974224, 52.757230690547395, 51.97906371525356, 50.3544602394104, 41.06072003500802, 38.954953806740896, 40.65755775996617, 41.791024344308035, 41.702761377607075, 44.83104535511562, 51.467353207724436, 50.93998146057129, 50.10548196520124, 51.54766396113804, 42.861199787684846, 49.62801912852696, 51.061738218579976, 49.746663093566895, 46.80806841169085, 47.972482272556846, 45.56906563895089, 42.08313703536987, 41.69856813975743, 40.27136298588344, 41.96817561558315, 45.67830869129726, 47.57789060047695, 49.2436135155814, 49.08885281426566, 48.554901123046875, 48.64157295227051, 47.21824141911098, 42.869610582079204, 39.913694041115896, 43.099606377737864, 46.17608806065151, 48.506941182272776, 48.321365220206125, 45.001720905303955, 50.56022766658238, 46.57796491895403, 43.47013643809727, 45.39771611349923, 46.6798220361982, 47.34154067720686, 45.918236936841694, 44.88666915893555, 37.83686358588082, 19.484595332826885, 5.102585511548178, 1.1939882167748042, 1.7221672577517373, 8.028316906520299, 7.922183173043387, 7.177987243447985, 9.587244272232056, 7.674964530127389, 12.622308611869812, 9.594497323036194, 1.8764491847583225, 0.9883622505835125, 0.535209803708962, 3.6318959253174916, 14.670779126031057, 26.3705450126103, 34.151646750313894, 41.102780955178396, 24.11697496686663, 35.71338987350464, 26.912811960492814, 7.355105076517377, 0.7553208097815514, 0.16152813817773545, 0.11444352114839212, 0.13002419152430125, 0.24034228761281284, 0.09844875442130224, 0.12006468166198049, 0.16321292705833912, 0.19525683830891336, 0.11878371611237526, 0.11923241774950709, 0.12244963725762707, 0.11587520289633955, 0.12215010475899492, 0.0666041492617556, 0.1298709511756897, 0.19418978770928724, 0.14806136222822325, 0.16462350636720657, 0.17917924959744724, 0.1417283777679716, 0.1071899885843907, 0.18624904166374887, 0.17076221268091882, 0.16272724526269094, 0.23358413310987608, 0.11268046325338738, 0.14969874865242414, 0.14094803535512515], [0.026419417433706776, 0.058173243089446, 0.02365226681078119, 0.005223208206838795, 0.0188529445191047, 0.026980928910363997, 0.059086205171687264, 0.04896286981446402, 0.06639916383262191, 0.04577470856851765, 0.03292406616466386, 0.027201211911493113, 0.04060636500694922, 0.023621206870302558, 0.03562870674899646, 0.0636798193944352, 0.03883401118218899, 0.03936678670080645, 0.030616833362728357, 0.010242645562227284, 0.06941424775868654, 0.01472573830480022, 0.07288142599697624, 0.037626266346446106, 0.041843456482248645, 0.02959190621705992, 0.03162841033190489, 0.030030009137200456, 0.0368397356942296, 0.06293034353958708, 0.030202418100088835, 0.054131125166480026, 0.08393679027046476, 0.09003275566335235, 0.0211055840897773, 0.5447052770427295, 10.576374190194265, 30.111085142408097, 27.028832980564662, 20.56134377207075, 15.727930171149117, 42.499928201947895, 48.54510416303362, 27.960959877286637, 12.01308534826551, 2.035004905291966, 0.14318493460970266, 0.17810576648584434, 3.0335396443094527, 5.227531926972525, 1.8306861775262016, 3.4659494927951267, 4.545141092368534, 9.707208395004272, 7.421067799840655, 2.3927009914602553, 3.5144218632153104, 1.426241199885096, 2.5728877569947923, 11.46728958402361, 22.038944210324967, 33.1075096811567, 42.734440326690674, 49.99592971801758, 48.595495973314556, 48.624671459198, 47.65231275558472, 48.56785256522042, 48.12419271469116, 45.90084212166922, 44.22438423974173, 50.0310354913984, 50.337048053741455, 50.2663813999721, 46.58674396787371, 44.739801611219136, 49.0851320539202, 50.33102396556309, 48.97359957013811, 45.40720040457589, 37.0722108568464, 36.43913269042969, 35.646972043173655, 38.66785076686314, 40.95571885790144, 45.93456867762974, 44.995950426374165, 49.03573036193848, 47.218602725437705, 49.814467089516775, 37.8120550428118, 43.90242208753313, 46.63040297372, 44.538376808166504, 50.0919121333531, 45.14515951701573, 45.17764581952776, 41.967320987156455, 42.93366602488926, 37.54549087796892, 35.573164803641184, 37.74428926195417, 43.695744446345735, 42.528533935546875, 44.436081954411094, 47.411314487457275, 46.751034123556956, 44.67521810531616, 43.746990885053364, 40.22533464431763, 40.00577156884329, 42.0018743787493, 43.92116485323225, 44.69904695238386, 45.664016246795654, 43.02334642410278, 43.014866147722515, 43.079411438533235, 45.02902037756783, 44.57892996924264, 45.12463106427874, 38.818237577165874, 31.04453045981271, 17.447798660823278, 6.007856317928859, 0.8974708020687103, 0.16986236668058804, 0.9584082407610757, 4.311212616307395, 2.3865149234022414, 3.9488145538738797, 3.7761757033211842, 3.2429121008941104, 3.6149633824825287, 2.234457288469587, 0.6416840531996318, 0.19346148893237114, 2.4979455726487294, 9.71634875025068, 16.644708497183665, 21.458547285624913, 22.4696752003261, 44.84184980392456, 28.56771653039115, 20.684934854507446, 13.523780924933297, 1.3429078715188163, 0.07530988247266837, 0.08914668392390013, 0.04224926792085171, 0.034763214976659844, 0.030625630569245135, 0.0796045952343515, 0.07336074313414948, 0.010771264205686748, 0.07554684725723096, 0.02322361079443778, 0.036934940942696164, 0.02795379376038909, 0.07084235362708569, 0.005789219218838427, 0.022519703655104552, 0.013649893891332405, 0.11172552020954234, 0.06412281455206019, 0.03482329925256116, 0.013964105646924248, 0.04282280643071447, 0.006268481649125793, 0.03652507865003177, 0.021097528182768395, 0.03487589589453169, 0.05346626602113247, 0.007970521858494197, 0.03847427905670234, 0.07331604124712092, 0.014113973676493126, 0.0018781376462097146, 0.01947516282754285, 0.04544422130233475, 0.05155315689210381, 0.007082612137310207, 0.018401969789660404, 0.025399333331733942, 0.0493122949930174, 0.038995770537959676, 0.03108387240873916, 0.02381494897417724, 0.02217993402986654, 0.004631315324721592, 0.025914426227765422, 0.04767723594393049, 0.0470038069012974, 0.029365662285791974, 0.05957850268376725, 0.03507118845092399, 0.037198083608278205, 0.004762810746407402, 0.036659004499337504, 0.05600113035844905, 0.005912704534629094, 0.0346929526754788, 0.04041661268898419, 0.02121902327053249, 0.009331872603589935, 0.05520003495205726, 0.01527401665225625, 0.040024667113487206, 0.06682238647980349, 0.04749286440866334, 0.06772411202213593, 0.7756959678871291, 14.814627681459699, 35.36333615439278, 31.66734961100987, 22.18655695234026, 27.37729729924883, 51.7765862601144, 51.44590064457485, 28.805327551705496, 9.57197734287807, 1.566375183207648, 0.0973047511652112, 0.18638807348906994, 0.8308139645627567, 1.9661337094647544, 4.372601687908173, 4.816524701459067, 6.813080881323133, 16.515696082796367, 8.837040322167532, 4.689981937408447, 4.521180663790021, 1.7918279426438468, 3.7845582706587653, 13.322706137384687, 23.910090616771154, 35.99506984438215, 45.549228531973704, 51.68030159814017, 48.997449261801584, 51.71008505140032, 50.53593329020909, 50.53779193333217, 50.35627371924264, 47.143193926130024, 47.38919142314366, 52.46364498138428, 51.71328469685146, 49.390988281794954, 46.75770092010498, 45.5949581010001, 49.69245672225952, 52.69507558005196, 48.06394141060965, 47.273622035980225, 38.99767827987671, 38.13743223462786, 37.96780586242676, 39.97824280602591, 42.493699141911094, 48.73282017026629, 48.226796763283865, 50.89425883974348, 49.228431701660156, 49.09779167175293, 39.164935316358296, 46.59069749287197, 49.28731421061924, 47.57297474997384, 51.340979371752056, 45.77544798169817, 46.74669844763619, 44.11687476294381, 43.92357587814331, 39.2824467250279, 37.30534029006958, 39.433764593941824, 46.23180913925171, 45.89099999836513, 47.36467817851475, 48.215888091496055, 48.65693889345442, 46.75131899969918, 45.47034215927124, 41.773514883858816, 40.465721470969065, 43.05779211861746, 44.58963366917202, 45.81322533743722, 45.09539304460798, 43.37887532370431, 44.30775914873396, 44.689413275037495, 45.51898649760655, 45.48034756524222, 45.64320639201573, 41.424555506025044, 33.69564342498779, 21.65017339161464, 7.77702488218035, 1.7517493218183517, 1.0014738270214625, 2.884796300104686, 3.0944749116897583, 4.56418480191912, 5.070384085178375, 5.601226023265293, 4.2822494847433905, 3.449694182191576, 1.6910287972007478, 0.2323188010071005, 0.10440854462129728, 1.7709685819489616, 10.85995362486158, 21.813669715608867, 27.288131066731044, 27.612671000616892, 46.65456880841936, 29.135014363697596, 25.37102406365531, 17.850670848573955, 2.536378230367388, 0.1023367532928075, 0.0509103603128876, 0.060585224734885354, 0.018717619191323007, 0.05788109305181673, 0.043698408374828954, 0.007457690180412361, 0.046009128846760304, 0.03400969844577568, 0.012642134529804545, 0.0429423269815743, 0.04964647688237684, 0.058964414921190055, 0.005944759377078819, 0.02843996919026332, 0.02741305054431515, 0.04001743393018842, 0.06304597947746515, 0.029045950155705214, 0.01607709507724004, 0.08585699687578849, 0.04154304528076734, 0.027397871715947986, 0.017607505366738354, 0.06103273893573454, 0.02817459753714502, 0.028100766141765883, 0.028879525871681314, 0.024233957918893014, 0.08080005180090666, 0.12892113785658563, 0.12579021443213734, 0.14765447191894054, 0.12866765074431896, 0.1247688020978655, 0.18676584107535227, 0.10813300976795809, 0.20780364290944167, 0.18828660090054783, 0.08572965620883874, 0.07637131480234009, 0.18766438428844723, 0.10209767826433692, 0.13510681236428873, 0.1619104112365416, 0.1446296985128096, 0.1521668519292559, 0.11407992137329918, 0.08924767029072557, 0.1610267007989543, 0.10963265358337335, 0.10888448051576104, 0.1622555141470262, 0.1445810068398714, 0.12251898353653294, 0.1533948646060058, 0.14477060309478215, 0.07157884232167687, 0.16055536323360034, 0.07137114953781877, 0.10376821112419878, 0.11701024270483426, 0.17459882609546185, 0.11521715963525431, 1.0633404787097658, 15.789942843573433, 41.157188824244905, 38.4661271912711, 29.243581703730992, 25.720419440950664, 49.885408197130474, 55.8109952381679, 32.95108141217913, 14.584051711218697, 2.9147313109466007, 0.40325935983232086, 1.4726285678999764, 7.758758068084717, 13.77041244506836, 9.619560343878609, 8.590817877224513, 10.425869260515485, 16.942796639033727, 14.295277629579816, 7.104939094611576, 6.526961445808411, 3.0446828177997043, 3.4210226578371863, 13.50199397972652, 24.15637125287737, 36.34137501035418, 46.72899791172573, 53.73720461981637, 52.421042101723806, 52.87992892946516, 51.200483322143555, 51.405448232378276, 51.990215573992046, 48.694532121930806, 49.53769254684448, 54.40773705073765, 53.480736187526155, 49.49002095631191, 48.117282731192454, 46.16015236718314, 50.26625633239746, 54.64705385480608, 51.79589877809797, 48.40104021344866, 42.112319469451904, 39.9181478364127, 39.008684226444785, 41.33950955527169, 45.226432595934185, 49.57310404096331, 49.99472767966134, 53.30914000102452, 51.11645180838448, 49.428842067718506, 42.76831974302019, 47.67394249779837, 48.400220326014924, 50.699229853493826, 53.834573200770784, 48.504297392708914, 48.73847600391933, 45.43126201629639, 46.80220760617937, 41.8342456136431, 38.871714387621196, 41.479237828935894, 47.44314071110317, 47.30732774734497, 46.837146622794016, 49.96334614072527, 50.182530539376394, 48.350467750004356, 47.56780181612287, 43.745910440172466, 43.29313455309187, 46.307336057935444, 46.93671778270176, 47.00283336639404, 46.09066343307495, 43.163456848689485, 45.45387492861067, 46.34066309247698, 47.91568422317505, 48.569263049534385, 47.593784604753765, 39.776456696646555, 32.825555256434846, 19.938147681100027, 7.341962558882577, 1.5989772166524614, 1.2563206148999078, 4.891743293830326, 9.717069625854492, 5.8264705538749695, 8.431035365377154, 10.025445444243294, 9.654913646834236, 8.18439255441938, 7.146483676774161, 1.5223119876214435, 0.6709088278668267, 3.196910249335425, 12.615084222384862, 21.708675486700876, 27.790006399154663, 28.85936369214739, 48.856251444135395, 36.47956425803048, 30.265804154532297, 20.526541982378276, 2.3175427615642548, 0.1621880406247718, 0.24107203845466885, 0.1352228961352791, 0.13327079159872873, 0.14790764690509864, 0.17738369666039944, 0.12135790155402251, 0.11517684108444623, 0.20293860110853398, 0.11601069276886326, 0.15303821302950382, 0.10892378804939133, 0.20896610910339014, 0.11832231229969434, 0.15027638551379952, 0.07413397450000048, 0.20853621645697526, 0.1561136730015278, 0.060837755112775734, 0.10379029743905578, 0.1518540879977601, 0.05160330402265702, 0.14676024418856415, 0.08585142610328537, 0.15186041194413388, 0.26147070101329256, 0.11448910513094493, 0.16390135511755943, 0.14865608460136823], [0.08878904168627091, 0.010475944561351622, 0.01829648812833641, 0.05124224875388401, 0.017651983337210755, 0.10200325333114181, 0.009381080811311091, 0.030669694633356163, 0.059247180819511414, 0.045476193872413466, 0.029505301399954727, 0.020896493523780788, 0.03901602480826633, 0.08430416270026139, 0.01075373255714242, 0.06033118122390338, 0.018503887445798943, 0.05284089422119515, 0.015212514238165957, 0.013058301260960954, 0.046306191477924585, 0.09362721350044012, 0.05454705695488623, 0.046925955185932774, 0.026776867985193218, 0.06269584862249238, 0.07737815898976155, 0.055100385299218554, 0.07284742460719176, 0.04733953245782426, 0.06094068208975451, 0.06413166943405356, 0.03871464669438345, 0.021365211943962743, 0.02804120264149138, 0.054735377563961914, 1.546270570584706, 15.385114737919398, 29.319070407322474, 25.965539727892192, 18.118259872709, 22.71150377818516, 51.1032988684518, 31.569098608834402, 24.368279150554113, 12.488919700895037, 1.9249313260827745, 0.21188226262373583, 0.336918013968638, 1.1389383992978503, 2.5926202067307065, 3.531040434326444, 5.846156537532806, 18.44787720271519, 8.230760489191328, 3.076047203370503, 2.502750251974378, 1.0060093722173145, 0.45695452285664423, 2.3858728664261952, 9.959462744849068, 22.870730434145244, 32.08775036675589, 42.06848675864083, 48.45780004773821, 51.44656767163958, 48.6394224848066, 51.67272111347744, 47.54975734438215, 49.54623188291277, 48.33878435407366, 49.65311254773821, 50.29964590072632, 47.067493302481516, 48.16700056621006, 47.855321747916086, 50.95455878121512, 48.669421332223074, 45.308539458683555, 41.18237951823643, 36.235779762268066, 38.151526655469624, 38.35591833932059, 40.841528688158306, 47.268803460257395, 48.47708477292742, 47.25238834108625, 51.4715325491769, 45.94736725943429, 50.529124055589946, 38.15574073791504, 42.45335790089199, 49.95804813929966, 40.02768966129848, 51.27889721734183, 48.33973625728062, 47.898633343832834, 47.022666999271934, 47.963599000658306, 42.39626802716936, 35.81823124204363, 35.554505416325156, 38.41380030768258, 40.9310735974993, 43.14422423498971, 42.887373651777, 44.32865585599627, 44.17110545294625, 42.43995829990932, 42.46766076769148, 40.66333518709455, 41.70541558946882, 43.73355654307774, 46.436416217258994, 46.03586299078805, 47.62645503452846, 46.16281352724348, 45.64477668489729, 44.116273743765696, 42.54923261914934, 35.59287684304373, 29.356052194322857, 17.150384494236537, 6.514989265373774, 1.263720229268074, 0.3875122448163373, 0.9304088460547584, 1.9033962530749184, 2.2068332050527846, 4.9711876937321255, 3.666401982307434, 4.137812503746577, 2.8336723233972276, 2.47525623014995, 1.0542697140148707, 0.1285543218255043, 1.199740782380104, 5.925699515002115, 17.760547501700266, 20.494786977767944, 23.080986397606985, 18.038907970700944, 39.91773441859654, 35.69641195024763, 15.903540679386683, 4.716310398919242, 0.043494495031024726, 0.02868473543120282, 0.04490053154794233, 0.028094425232016614, 0.019937036525724188, 0.028072981829089776, 0.032425010443798134, 0.04580841479556901, 0.11365051727209773, 0.06759195375655379, 0.06454584720943655, 0.045220308138855865, 0.029503489711454937, 0.02869541896507144, 0.027933931344055703, 0.04637218240116324, 0.022397197550162673, 0.07252857421657868, 0.028308421606197953, 0.052053586646382294, 0.06643151638231107, 0.04003548974703465, 0.053303726350090334, 0.03516244462558201, 0.04612046965797033, 0.08594262799514191, 0.05138756720615285, 0.05419588115598474, 0.028736969056938375, 0.025141786883718202, 0.08040407233472381, 0.022781180517215813, 0.04461837633113776, 0.020302788953163793, 0.018191250739619136, 0.04191949650911348, 0.01000585125958813, 0.024912718550435135, 0.04193880083039403, 0.046789189667574, 0.011121511259781463, 0.05727351922541857, 0.06645689359200851, 0.0930628894961306, 0.030745113800678934, 0.03678003479061382, 0.01127642419721399, 0.0195811924058944, 0.011780863245283919, 0.03546990580590708, 0.037825854029506445, 0.07153967049505029, 0.07348925766668149, 0.031203321713422025, 0.01835674373432994, 0.040086610575339625, 0.05343423916825226, 0.030871087219566107, 0.03502430846648557, 0.06875134618686778, 0.06253418086894921, 0.03272480757108756, 0.04191563564485737, 0.02109437808394432, 0.03388454944693616, 0.052945344509290795, 2.2452567432607924, 21.920460053852626, 32.915061950683594, 27.910196338381084, 17.07417665209089, 29.915361336299352, 54.629589557647705, 37.78358479908535, 27.358816828046525, 9.953813859394618, 1.6938853753464562, 0.0610080606171063, 0.2523557229765824, 0.8608552068471909, 2.4079422993319373, 3.9924262251172746, 8.317166549818856, 15.624009438923427, 9.439084359577723, 5.178694776126316, 4.290276391165597, 1.4341657289436884, 1.9273508191108704, 3.1864679753780365, 11.157379950795855, 23.687826429094585, 34.69436706815447, 45.7377609525408, 52.6695305279323, 52.95493820735386, 49.6331330026899, 53.07354048320225, 50.148352350507466, 51.30924347468785, 48.9340295791626, 51.04489231109619, 53.30201809746878, 48.07531213760376, 47.80589573723929, 47.87022910799299, 51.59264659881592, 51.53212431498936, 47.79434435708182, 43.05076054164341, 37.22453621455601, 39.41947214944022, 39.91439233507429, 42.3553466115679, 47.95660563877651, 50.01534298488072, 48.367327553885325, 53.69894783837454, 47.751439230782644, 48.04792928695679, 40.69951793125698, 44.06821305411202, 50.116783210209434, 41.93582827704293, 52.99508489881243, 49.86624159131731, 48.754137243543354, 48.814061982291086, 49.01452098573957, 43.51443815231323, 37.67112125669207, 37.7278984614781, 39.347183091299875, 43.067689827510286, 44.810218129839214, 45.84732709612165, 46.06868628093174, 45.05538879122053, 45.041002546037944, 43.666315351213726, 41.65027468545096, 44.20091322490147, 45.24197571618216, 47.385244846343994, 46.38452359608242, 46.74227591923305, 46.802176339285715, 45.856057507651194, 44.74521425792149, 43.30991097858974, 38.29163360595703, 32.349006107875276, 19.754133326666697, 7.4847515140260965, 2.9088982982294898, 1.9774195381573267, 2.2378875272614613, 2.5859136751719882, 3.4908865775380815, 4.7482616901397705, 5.580655881336757, 3.3609244312558855, 4.380733251571655, 2.2407102329390387, 0.38138963335326737, 0.13439295281256947, 0.7457823444690023, 6.393262471471514, 19.180573429380143, 24.69834463936942, 23.400652170181274, 20.114486013139995, 43.257518087114605, 38.13636916024344, 20.339552061898367, 6.6021617991583685, 0.2503502720168659, 0.040258829548422775, 0.019410106586292386, 0.050102669546114545, 0.04845270647534302, 0.025227916726310338, 0.03407157066145113, 0.04648245112704379, 0.09284372947045735, 0.08144295016037566, 0.08022020291537046, 0.04627705857689891, 0.011709043706235076, 0.02200049883686006, 0.027403830949749266, 0.013008177879133394, 0.01903087506070733, 0.05517908179068139, 0.02595658869748669, 0.06817652524581977, 0.06009410108838763, 0.05514401849359274, 0.027434914638953548, 0.06637593757893358, 0.03925793272043977, 0.022720962230648314, 0.04753726774028369, 0.04303423794252532, 0.0720446091145277, 0.023492900987288783, 0.2229327889425414, 0.11218975351325103, 0.19468659747924122, 0.1257917479212795, 0.08648401073047093, 0.16092173143156938, 0.09943040460348129, 0.18632210631455692, 0.14941981647695812, 0.14856697938271932, 0.04792536262954984, 0.18984904991728918, 0.11272498193596091, 0.28697992648397175, 0.07614716754427978, 0.15843230858445168, 0.08831260832292692, 0.11556887147682053, 0.06253531402243034, 0.1109184774437121, 0.13527654111385345, 0.21540119951324804, 0.13859577157667705, 0.1300334467419556, 0.10781958087214402, 0.13508234439151628, 0.1638578474521637, 0.1538756066667182, 0.191307452374271, 0.11119170313967125, 0.1785910004483802, 0.08815596851387195, 0.1113895368097084, 0.2771442899746554, 0.15742673325751508, 0.10679214314690658, 2.7687138319015503, 23.312576804842266, 41.70801421574184, 36.4712472643171, 26.03293899127415, 31.50278500148228, 58.24164533615112, 40.508932318006245, 29.856423241751536, 14.601107801709857, 2.422494215624673, 0.6198755034378597, 1.9080059485776084, 4.871197036334446, 7.272385469504765, 11.45719906261989, 14.538948348590306, 28.199587072644913, 14.702224935804095, 9.122850128582545, 5.187520291124072, 2.798922428062984, 1.8824565538338252, 3.5263048027242934, 11.067629201071602, 25.467075960976736, 34.7333082471575, 44.73463215146746, 53.19253533227103, 55.54381963184902, 51.6894211087908, 56.996083463941304, 50.95477417537144, 53.29185288293021, 51.447404929569785, 52.9631336075919, 53.60284730366298, 48.403016975947786, 48.661319732666016, 47.89939417157854, 54.89584105355399, 52.507727827344624, 48.94000850405012, 45.25629595347813, 40.30297381537301, 42.51739944730486, 41.52958100182669, 43.97859171458653, 52.24025692258562, 53.4604161807469, 51.473130634852815, 55.93790061133248, 47.23887756892613, 48.63733802522932, 43.210603850228445, 46.162184715270996, 48.54077890941075, 43.66594362258911, 53.76294769559588, 52.988564014434814, 51.501448018210276, 51.04748746326992, 51.66203825814383, 46.58735193525042, 40.065807478768484, 39.26850516455514, 41.197363308497835, 44.02400861467634, 46.38861608505249, 45.59523950304304, 49.46594197409493, 46.79257392883301, 46.395758833204, 45.82412706102644, 43.27369001933506, 44.89467348371233, 46.488743100847515, 48.8181266784668, 47.5011442729405, 47.5314279964992, 46.634384291512625, 46.970986298152376, 44.84120709555489, 44.69668803896223, 37.653601373944966, 31.584183147975377, 18.729663133621216, 7.807411091668265, 2.3157614171504974, 1.677428241286959, 2.933625851358686, 6.365752816200256, 9.210487757410322, 11.485516445977346, 8.640940444810049, 9.945040890148707, 9.78976081098829, 7.124367560659136, 2.9341087511607578, 0.5356159476297242, 1.8306501337460108, 7.532407471111842, 22.094126803534373, 28.208942822047643, 29.820803301674978, 25.55779685292925, 46.01106487001692, 44.90716634477888, 25.5221334866115, 6.917114521775927, 0.3629853752042566, 0.0890763130571161, 0.09356611820736102, 0.197578703718526, 0.123112253844738, 0.1253762130758592, 0.1477343083492347, 0.16341397698436463, 0.22349217321191514, 0.1291838123330048, 0.10636576531188828, 0.12111897580325603, 0.18254300552819455, 0.09577532644782748, 0.08106742852500506, 0.1091489191832287, 0.1573636837835823, 0.17431603984108993, 0.06157737185380288, 0.10379156629954066, 0.13576585985720158, 0.18885317764111928, 0.21138344439012663, 0.19456541112491063, 0.13690423805798801, 0.17795405962637492, 0.1355825468365635, 0.16075506966028894, 0.16205930896103382, 0.14271878105189117], [0.03180214922342982, 0.04681301981742893, 0.019814170797222426, 0.01985467933783574, 0.05540351742612464, 0.044439511107546945, 0.05731060794953789, 0.027534535454053963, 0.016258240178493515, 0.032299953047186136, 0.02170175004617444, 0.021615248705659593, 0.09015294457120554, 0.044746090192347765, 0.033959856655980857, 0.03825496636064989, 0.025885739463514516, 0.04854250379971095, 0.05213055965889778, 0.01608128672731774, 0.08324145472475461, 0.06755304655858449, 0.046417725671614916, 0.009927969010147666, 0.06637022431407656, 0.05786608385720423, 0.11576783151498862, 0.0041765403750884745, 0.03718027545671378, 0.03719595979366984, 0.05722582499895777, 0.02907228409977896, 0.018428783797259842, 0.019971568869160752, 0.06992223300039768, 0.02801339966910226, 0.09625532890536956, 2.666040518454143, 17.773634433746338, 29.791047641209193, 26.807815994535172, 19.355989388057164, 33.89196130207607, 42.29482780184065, 19.06162200655256, 23.90189000538417, 10.915401986667089, 2.3495661403451646, 0.10040177498012781, 0.44598353441272465, 1.9025598636695316, 1.1829568658556258, 6.439177904810224, 18.377601385116577, 8.320573772702899, 6.414345911570957, 3.6121050672871724, 0.558562264910766, 0.7142838803785188, 0.8238061634557587, 1.772420972585678, 9.17095945562635, 18.35397229875837, 29.052091087613785, 35.50928653989519, 41.924068450927734, 46.188518387930735, 53.276459148951936, 52.73127222061157, 52.30716807501656, 52.379915714263916, 52.17816087177822, 49.12108550752912, 48.24626908983503, 47.29566519601004, 50.94795799255371, 51.25105925968715, 49.3017247744969, 46.37026936667306, 40.541439465114046, 37.54324313572475, 39.51623623711722, 41.82194035393851, 46.12016201019287, 47.97138098308018, 49.52648857661656, 49.47007615225655, 49.89910657065255, 46.6720643724714, 47.90358393532889, 39.03964539936611, 40.3696209362575, 52.185953276497976, 40.31667218889509, 48.793248653411865, 49.34679773875645, 47.2199124608721, 48.37213223321097, 48.22609152112688, 45.674959659576416, 37.78544691630772, 35.31108570098877, 38.33051572527204, 40.229583467756, 40.557423795972554, 42.256390367235454, 42.879146984645296, 41.33606672286987, 42.333327770233154, 42.70489311218262, 41.97759737287249, 43.432411193847656, 44.903442110334126, 45.078939710344585, 44.78246702466692, 44.59307302747454, 44.44028908865792, 43.818397521972656, 41.84177051271711, 34.43677650179182, 26.69382905960083, 15.88770226069859, 7.0227523275784085, 0.9136433856827872, 1.3829953947237559, 2.1377292445727756, 1.0204097309282847, 1.8938296692711967, 0.900615350476333, 2.948802019868578, 3.5097268351486752, 2.5782550232751027, 2.751228473016194, 0.9061392226389476, 0.20657192543148994, 0.7001834341457912, 6.05135942356927, 16.847038303102764, 20.411684785570415, 17.693592923028127, 21.97759335381644, 22.240247419902257, 34.12076200757708, 29.712797028677805, 8.793518543243408, 1.3561038034302848, 0.010209481315022069, 0.03483354852401784, 0.0469856832309493, 0.007463106586198721, 0.037014034377144914, 0.06925266821469579, 0.015789906826934645, 0.02837294519745878, 0.028541846134300743, 0.03006416659003922, 0.02404079256978418, 0.010719676884556455, 0.012791974569803901, 0.017962977988645434, 0.030565190062459027, 0.02175274195282587, 0.12270349077880383, 0.06979396952582256, 0.027480649595548, 0.02030363372926201, 0.07860410213470459, 0.04355800590877022, 0.01760061314728643, 0.039367655225630314, 0.05910650693944522, 0.012529848010412284, 0.042031000168727975, 0.032228018157184124, 0.07187340115862233, 0.025667814371575202, 0.06628164156739201, 0.0372745477195297, 0.05653393980381744, 0.046101379075220654, 0.002972538720184405, 0.04189479783443468, 0.038639129139482975, 0.04073603644168802, 0.01757074742844062, 0.034953934207026444, 0.003936127360377992, 0.022934804238112907, 0.025815933477133512, 0.023465613701513836, 0.045647886980857165, 0.040901134189750464, 0.019996796801154102, 0.02642324097853686, 0.018178674093048488, 0.02237043952170227, 0.07146966603717633, 0.02806608791330031, 0.023542242357507348, 0.0592075747304729, 0.038180941582790444, 0.09654008291129555, 0.06704208933349166, 0.02303846233657428, 0.05265976608331714, 0.031212152846689736, 0.05545888588364635, 0.02555416484496423, 0.0038516518709781978, 0.0300440955241876, 0.0006004274213669955, 0.03695458113881094, 0.12460588583988802, 4.476071221487863, 24.787965978894913, 34.70400421960013, 28.137777635029384, 20.783858094896587, 43.060984815870015, 40.99353095463344, 26.84921509878976, 31.638750825609478, 10.612364990370613, 2.229822405747005, 0.10305576971066849, 0.1995409591389554, 0.8303108172757285, 2.7950188432421004, 4.128481073038919, 14.435088413102285, 9.526742833001272, 5.134369611740112, 4.192091831139155, 2.6577875784465244, 2.035572052001953, 1.7802124002150126, 2.5929202820573534, 12.892398118972778, 19.98953308377947, 30.65315580368042, 37.28651762008667, 45.08095816203526, 49.93679707390921, 54.50872564315796, 53.585098130362375, 54.03306933811733, 54.54040595463344, 53.246686117989675, 50.81126955577305, 47.94207000732422, 47.79222168241228, 51.03360496248518, 52.93293326241629, 52.70304863793509, 48.331523486546104, 42.22119426727295, 39.10875218255179, 41.39892707552229, 42.37605571746826, 47.808893884931294, 49.65608637673514, 51.8625111579895, 51.59125348499843, 51.78045988082886, 46.84972286224365, 47.8173428944179, 40.79261337007795, 41.60206113542829, 51.86654806137085, 42.86027567727225, 49.314148153577534, 51.21326453345162, 49.62188386917114, 50.22139528819493, 50.45759929929461, 46.320568902151926, 39.19177968161446, 37.390959467206685, 39.6181697845459, 41.89141539164952, 43.28425128119332, 44.652900491442, 44.361274174281526, 44.12054688589913, 44.05679021562849, 44.720169476100374, 42.62069484165737, 45.29799904142107, 46.772309507642476, 45.83756487710135, 45.11391346795218, 44.619927815028596, 45.88159213747297, 45.38545601708548, 42.55955416815621, 37.08216415132795, 28.40887897355216, 18.983058725084575, 7.749034932681492, 1.823002121278218, 1.7222435793706348, 2.388052212340491, 2.9311631492206027, 5.235113280160086, 2.9064282136304036, 6.843807552542005, 7.481662171227591, 2.7139448736395155, 3.4359704043184007, 1.0458555540868213, 0.14287845391247952, 0.5434326167617525, 5.788391385759626, 17.39243541445051, 24.4381901877267, 24.720509392874582, 27.03670355251857, 22.708453519003733, 38.593164580208914, 35.11318710872105, 11.354226759501866, 1.9856216694627489, 0.022733555840594426, 0.025251565368047783, 0.035451544648302455, 0.01490453228221408, 0.03638661679412637, 0.03718355956620403, 0.016677988726379614, 0.05365815572440624, 0.04050340410321951, 0.036150174481528144, 0.04936864732631615, 0.03418866544961929, 0.037576295634997744, 0.06622976077986614, 0.05178523961720722, 0.02986183762550354, 0.045190076011099985, 0.04334458289667964, 0.0520434934379799, 0.03751179748880012, 0.06241813102470977, 0.032843347638845444, 0.01518956957651036, 0.027746195971433605, 0.06288290037108318, 0.05317093365426574, 0.030032499360718896, 0.0496927360072732, 0.0353795792242246, 0.03616844064423016, 0.1513073651918343, 0.12251164178763117, 0.135394049808383, 0.1322220614446061, 0.10529821259634835, 0.10950390834893499, 0.23572075845939772, 0.15160244650074414, 0.13215450649814947, 0.12470041933868613, 0.11637875730437891, 0.0663771792980177, 0.1415346831615482, 0.18725521410150187, 0.18112147466412612, 0.06700323641832386, 0.16300862016422407, 0.13982154508786543, 0.11781631516558783, 0.22237769301448548, 0.21548666778419698, 0.17629297875932284, 0.11780178094548838, 0.13089990881936892, 0.14872089826634952, 0.16426055798573153, 0.18193866152848515, 0.0489789477017309, 0.19919624977878161, 0.14840637014380523, 0.13456417433917522, 0.12016908105994974, 0.1443582980760506, 0.0930271917687995, 0.15471152109759195, 0.0814633129962853, 0.178006130403706, 4.814171867711203, 29.118474176951818, 42.156541279384065, 36.85888726370675, 29.628630025046213, 43.04940216881888, 49.209692410060335, 26.46356749534607, 31.653943061828613, 14.191121527126857, 2.7375496413026537, 0.2959405785160405, 0.8447854891419411, 6.302964551108224, 8.314762473106384, 14.251810567719595, 29.059668098177227, 14.919420412608556, 12.27429940019335, 7.229647534234183, 3.190940661089761, 2.608728302376611, 1.972969434091023, 2.4581200182437897, 10.767839619091578, 20.084389890943253, 30.85664769581386, 37.05708810261318, 43.60247877665928, 48.96191964830671, 55.29442793982369, 54.892255783081055, 57.52578285762242, 58.49973964691162, 55.93675415856497, 51.50466850825718, 48.450101443699424, 47.412050996507915, 50.889607020786826, 56.21131917408535, 55.660959311894004, 50.29608147484915, 43.80326434544155, 41.85441623415266, 43.88483272280012, 45.315074239458355, 48.35217700685774, 52.62118148803711, 53.25766774586269, 53.66508231844221, 52.27576569148472, 47.04066630772182, 47.54737063816616, 42.803960527692524, 44.16864231654576, 50.065418652125764, 41.60694224493844, 50.15408114024571, 51.36072615214756, 49.73204755783081, 52.00063092367989, 52.38106216703142, 49.08581297738211, 41.038902691432405, 39.349257128579275, 41.74177898679461, 44.229765619550435, 45.02542815889631, 46.442214488983154, 46.240536076681956, 45.841358593532014, 46.07657596043178, 46.24274560383388, 44.62960318156651, 47.58759723390852, 48.33827713557652, 47.46435703550066, 46.02836241040911, 44.39819690159389, 46.07155588694981, 44.63936192648751, 43.79652806690761, 37.35072592326573, 29.408351285117014, 18.322939906801494, 8.334861874580383, 1.440407165459224, 2.7038313363279616, 5.03656416279929, 4.260760009288788, 6.507961596761431, 4.225542630468096, 9.531576173646108, 11.466827528817312, 8.41483998298645, 7.999644296509879, 3.0818862957613806, 0.4345010934131486, 1.229632475546428, 7.746975660324097, 21.18945918764387, 27.47076620374407, 24.03847769328526, 30.40292685372489, 31.13691370827811, 43.29905094419207, 37.692077023642405, 14.133400235857282, 1.984391404049737, 0.10948053960289274, 0.1093123782692211, 0.147146181336471, 0.09741975606552192, 0.12777507863938808, 0.1342510168573686, 0.12158629644129958, 0.1650384712432112, 0.10070015396922827, 0.16050120256841183, 0.12136144350681986, 0.13393467026097433, 0.08181678224354982, 0.12515422355915817, 0.19801711876477512, 0.17512876194502625, 0.147504325690014, 0.14687510659652098, 0.16174342376845224, 0.10925053658762149, 0.14569383141185555, 0.1276289764791727, 0.10257232708058187, 0.1309788224420377, 0.1320906292114939, 0.16984031429248198, 0.10257882066071033, 0.31017233484557694, 0.1814917376531022, 0.04311313460181866], [0.03889132024986403, 0.016985136084258556, 0.01647220941127411, 0.08015176587338958, 0.060398444400302, 0.008977173511604113, 0.05411736108362675, 0.02021464895057891, 0.03805039483787758, 0.03286019905603357, 0.013854342429632587, 0.009543157382203, 0.06326994353107043, 0.08447129944605486, 0.04961363918014935, 0.032814499722527604, 0.04618622309395245, 0.02782445989682206, 0.025211099235873138, 0.0358444096387497, 0.04993654381749885, 0.043506566169006486, 0.06012103892862797, 0.034034967089870145, 0.05789921672216483, 0.027027481501655917, 0.058815639333001206, 0.010659858933649957, 0.039161139700029574, 0.005470512168748038, 0.039747797684477906, 0.08661582294319357, 0.016591539972328713, 0.027209562981235128, 0.04294407420924731, 0.06498446581619126, 0.049586470638002665, 0.2630753277667931, 5.621703667300088, 23.93619326182774, 26.763113021850586, 20.809410095214844, 18.308690888541086, 50.689967904772075, 22.053467682429723, 16.84894905771528, 25.54638269969395, 10.85583073752267, 2.6344972167696272, 0.3950630639280592, 0.1817529872059822, 1.3909085243940353, 3.6867376225335255, 8.570031472614833, 8.66224101611546, 3.1164891932691847, 3.398660097803388, 1.144644933087485, 1.6695280309234346, 0.35879810846277643, 0.30778101459145546, 2.4628109208175113, 7.1330706136567255, 14.427426287106105, 22.900213377816335, 30.012792451041086, 34.518803460257395, 41.62037311281477, 47.01912341799055, 52.635352339063374, 49.5504390171596, 50.70270047869001, 48.241339342934744, 47.88384757723127, 48.54007019315447, 51.17919404166085, 50.213265895843506, 48.71370915004185, 43.220373017447336, 40.39944955280849, 38.96943385260445, 43.52778216770717, 47.41871779305594, 50.32166474206107, 49.94730622427804, 54.13595478875296, 50.02374683107649, 48.500729492732454, 46.07730552128383, 48.55883032935006, 44.356104714529856, 39.137031350817, 53.24493169784546, 44.37269353866577, 45.10931723458426, 51.03091253553118, 48.805081435612266, 49.1187161718096, 48.7707017489842, 44.532425676073345, 36.3231429372515, 36.04493359157017, 36.359947545187815, 38.594074794224326, 40.25669881275722, 39.89304746900286, 42.21182114737374, 42.30398900168282, 41.22829668862479, 43.80798217228481, 42.25586230414254, 43.28684295926775, 43.703463894980295, 47.50386449268886, 47.54623460769653, 46.67689337049212, 45.693077087402344, 38.150084904261995, 29.009578534535, 22.790919951030187, 14.42290735244751, 6.687052718230656, 1.102643832564354, 0.6204336392027991, 0.7627787238785199, 1.3079231487853187, 3.0874209702014923, 5.123049693448203, 1.5745590754917689, 3.950133408818926, 5.488474130630493, 1.0311122366360255, 2.5602494180202484, 0.5962179186088699, 0.7176709100604057, 3.059949095760073, 10.853735855647496, 20.254716294152395, 17.324127674102783, 17.282207454953873, 16.678667817796978, 24.25839512688773, 19.883302075522288, 11.41770897592817, 3.5038230376584187, 0.041693418818925104, 0.04177153516294701, 0.03686968622995274, 0.05665091245568224, 0.06669975484588317, 0.04218575365043112, 0.038774442592901845, 0.05498668318614364, 0.028058318687336783, 0.01992089587396809, 0.025115921128807322, 0.0513503902724811, 0.017525694399539913, 0.05930944997817278, 0.03701695886307529, 0.006453560133065496, 0.06539037224969693, 0.0005308344843797386, 0.05193713985915695, 0.061361930200031826, 0.018637823473129953, 0.0034800761287832366, 0.05247676518878766, 0.021361664902152758, 0.017251216806471348, 0.04005990343700562, 0.03774453839287162, 0.029878689042691673, 0.02718861660520945, 0.010492228553630412, 0.03500131970005376, 0.018840980250388384, 0.03540595727307456, 0.027562594573412622, 0.024287122833941664, 0.06355715383376394, 0.03701933373564056, 0.02005680643820337, 0.0799530026103769, 0.03818520278270755, 0.030541627933936458, 0.014328756303127323, 0.048175263684242964, 0.042198601711009226, 0.06620384752750397, 0.019148032613364712, 0.04885721851938537, 0.019110711491001502, 0.019985862209328582, 0.07820886905704226, 0.02047258216355528, 0.050457892806402276, 0.02876424277201295, 0.019737051899677942, 0.012343171152419277, 0.04552734184211918, 0.04912852396124175, 0.02419419746313776, 0.04264804973666157, 0.04738768130274756, 0.041384373259331496, 0.0368226162557091, 0.04665442582752023, 0.029938881884195974, 0.016296943815957223, 0.05226762033998966, 0.04180213709228805, 0.06428523547947407, 0.35004611951964243, 8.117658581052508, 28.93573134286063, 33.01179824556623, 24.42516926356724, 23.970953362328665, 48.63203654970442, 20.730933666229248, 26.60756196294512, 28.17920626912798, 9.414421728679113, 2.5858118406363895, 0.15335506174181188, 0.1498312529708658, 0.4691724958164351, 4.344346404075623, 12.077878168651036, 9.051314081464495, 5.509077710764749, 4.515498340129852, 2.831879036767142, 3.442361009972436, 1.706117244703429, 0.5926489329763821, 3.781182748930795, 9.73437237739563, 17.75365662574768, 25.2099735055651, 31.906669889177593, 36.99640948431832, 45.93843535014561, 50.942979608263286, 53.62762457983834, 52.293594769069124, 51.78141525813511, 48.98582492555891, 47.75183180400303, 47.239603655678884, 52.96834128243582, 51.496233395167756, 49.30955539430891, 46.565010002681184, 40.536721638270784, 41.38744517735073, 44.057644844055176, 49.27288975034441, 50.8743314061846, 50.76238897868565, 54.06606980732509, 50.47276374271938, 48.55116299220494, 48.09602471760341, 48.20327016285488, 43.88294281278338, 40.809174401419504, 53.34693125316075, 46.18099001475743, 45.87563058308193, 51.92620529447283, 50.63321501868111, 49.50336844580514, 49.41644648143223, 46.4247328213283, 38.38487843104771, 37.11386183329991, 38.93156964438302, 40.182061263493125, 41.84863880702427, 41.64820759637015, 44.344063486371724, 43.78790535245623, 43.38071659633091, 46.143532276153564, 45.22190931865147, 44.916362285614014, 46.0424359866551, 48.2222317968096, 46.6410893031529, 46.76800857271467, 46.02638912200928, 41.73405258996146, 34.58201469693865, 25.29824342046465, 16.515558855874197, 9.02972081729344, 1.928388706275395, 1.31751991382667, 3.234632019485746, 4.783882064478738, 3.2154447862080167, 4.2348262923104425, 4.833996381078448, 6.426358478409903, 6.654727527073451, 2.256728870528085, 1.0154920348099299, 0.1853296131427799, 0.4322351392890726, 3.3208105266094208, 11.780670710972377, 23.628153562545776, 22.377641098839895, 16.97985311916896, 19.523232528141566, 27.733750309262955, 27.259705986295426, 16.179919174739293, 4.967568985053471, 0.1317763996443578, 0.04858892238033669, 0.07217336113431624, 0.045041069721004794, 0.09795799718371459, 0.017048604553565383, 0.028707188154969896, 0.026172032047595297, 0.008200613083317876, 0.02620834724179336, 0.06713645998388529, 0.022629565259973918, 0.09839761323694672, 0.050164701217519383, 0.011239832499995828, 0.032549212886286635, 0.019136153161525726, 0.046675775931882005, 0.10073595347681216, 0.0718407364828246, 0.00994211052810507, 0.026846938600231494, 0.05473140474142773, 0.09709750621446542, 0.023725611357284442, 0.024912647304258177, 0.07209035594548498, 0.024061062107128755, 0.04426652199721762, 0.06397169123270682, 0.015466130272086178, 0.08844527548977307, 0.09460758125143391, 0.12344392176185336, 0.18887342512607574, 0.1599732344704015, 0.13183094028915676, 0.09016675954418522, 0.21718414526964935, 0.14979807260845387, 0.19541356632752077, 0.05799820141068526, 0.10398227535188198, 0.11858120055070945, 0.1361894556986434, 0.11138234433851071, 0.1660864142967122, 0.18395914882421494, 0.10842343632663999, 0.2149378415197134, 0.10482576901891402, 0.1294437726693494, 0.1368724283363138, 0.10527920683047601, 0.09087685322655098, 0.12883554744933332, 0.11526137297706944, 0.17349123981382164, 0.11562063012804304, 0.1293786061661584, 0.16953409143856593, 0.1849423867783376, 0.1839302568031209, 0.09403809359563248, 0.09187090702887092, 0.11060574743896723, 0.12585592376334326, 0.1711256496076073, 0.6269840534244264, 8.31212910584041, 34.62284926005772, 38.02448926653181, 32.925164631434846, 26.80146881512233, 57.29960857118879, 27.93114342008318, 24.712122917175293, 33.506381443568635, 14.068638682365417, 3.555249695266996, 0.6706466962184224, 1.141914508172444, 4.456309241907937, 8.901271206992012, 14.770246062959943, 19.834676844733103, 8.972526720591954, 9.402293648038592, 4.265839576721191, 4.619560641901834, 1.9755396161760603, 0.8654018800173486, 3.941709586552211, 9.160698703357152, 15.884817021233694, 22.959611790520803, 31.463690962110245, 35.51040519986834, 45.045647416796, 49.70201396942139, 54.23329210281372, 51.41253539494106, 52.0818657875061, 47.03352703366961, 47.32414238793509, 48.09315858568464, 53.65693555559431, 53.95925167628697, 50.80064576012747, 47.53007657187325, 43.48130914143154, 42.68651860100882, 48.006087235042024, 51.979581356048584, 54.289395332336426, 54.2159355027335, 57.54304565702166, 51.77482836587088, 49.13011121749878, 48.40380907058716, 47.20999043328421, 46.64015824454171, 44.109308174678254, 52.00656121117728, 45.58418491908482, 45.05287701742989, 53.34267200742449, 50.96470662525722, 51.548035689762656, 52.20154503413609, 48.59985249383109, 39.23231199809483, 39.37623698370797, 39.93485130582537, 42.5538774899074, 43.4336062840053, 42.797856535230366, 46.33223145348685, 46.54920285088675, 44.708896023886545, 47.78165347235543, 45.26059341430664, 45.95805358886719, 47.26156343732561, 49.851744174957275, 46.572187491825645, 46.79183741978237, 45.62106595720564, 41.7598477772304, 33.7658862386431, 26.275163616452897, 16.49339062826974, 8.134166632379804, 1.7431521202836717, 1.222853422164917, 2.1969802251883914, 4.2664284365517755, 6.364252873829432, 11.023100801876613, 6.491747106824603, 11.799667085920062, 10.470836264746529, 5.146271441664014, 5.2306360346930365, 1.5349731253726142, 1.026846476963588, 4.102779686450958, 14.181834391185216, 27.25556833403451, 23.526569162096294, 22.56202891894749, 25.072974136897496, 34.51721232278006, 30.214085238320486, 17.62729147502354, 5.256524588380541, 0.24669220830712998, 0.11173216985272509, 0.20016017662627356, 0.160398092386978, 0.2093003825949771, 0.1742577129708869, 0.15013250894844532, 0.11981013603508472, 0.18104404024779797, 0.0739637232784714, 0.09176686046911137, 0.12947327537196024, 0.11502894759178162, 0.16556046823305742, 0.06442532581942421, 0.12941171867506845, 0.14610872843435832, 0.11702675824718815, 0.14602194380547318, 0.09834378505391733, 0.20618324700210774, 0.0952092246817691, 0.1514608362423522, 0.1337169555148908, 0.11217452718743257, 0.15016350442809717, 0.10441022738814354, 0.12166146455066544, 0.10860361451549189, 0.15173706784844398, 0.14390024622636183], [0.021043827225055014, 0.07625782303512096, 0.05019698252103158, 0.06222637024308954, 0.017244311016319052, 0.027629408220361387, 0.02522295154631138, 0.03244705604655402, 0.077607368119061, 0.01848348559412573, 0.06758804539484636, 0.038531615265778134, 0.021749820859570588, 0.0048421688095134285, 0.028131232364103198, 0.08820461947470903, 0.017295933960537826, 0.03460380335205367, 0.08446226135960647, 0.017242823328290666, 0.040033932509166856, 0.02408589988148638, 0.04974667275590556, 0.046228271909058094, 0.07612793786185128, 0.06110685531582151, 0.02132573477657778, 0.004184052605913686, 0.02661832488541092, 0.0368209097401372, 0.008058275944287223, 0.0389594112389854, 0.007010187429841608, 0.043519712784992795, 0.04036375820370657, 0.02581124480015465, 0.022777109307103922, 0.07919712138495275, 0.3249392924564225, 10.287092890058245, 24.595480033329554, 23.853327308382305, 17.61242754118783, 27.905028615679058, 28.18219746862139, 19.726710523877824, 19.962155444281443, 24.531233515058243, 11.430854967662267, 2.631798275879451, 0.05290127365982958, 0.598610975912639, 2.621626330273492, 13.425016624586922, 7.172255413872855, 4.521601898329599, 3.462593730006899, 2.1639500090054105, 3.282261920826776, 2.2268659472465515, 0.5232541252459798, 1.14914855999606, 1.6635032913514545, 4.2312310338020325, 9.07241576058524, 15.759315184184484, 21.75797642980303, 29.628765514918737, 39.36080156053816, 46.14877469199044, 50.639048031398225, 50.70488568714687, 49.17165102277483, 47.53100068228585, 49.56734051023211, 51.3263395173209, 51.47779982430594, 47.06736823490688, 44.14767612729754, 42.7594746862139, 45.537951605660574, 48.00118180683681, 48.35037742342268, 50.77317605699812, 50.607843671526226, 49.48466736929757, 49.57148163659232, 50.5192471912929, 49.35727562223162, 49.66277749197823, 45.11387177876064, 38.73461600712368, 53.60354559762137, 45.97856814520699, 45.79523297718593, 51.74496153422764, 49.51487813677107, 46.134013244083945, 46.965747356414795, 43.13245398657662, 39.564286504473, 40.17621782847813, 40.19447769437517, 40.70166492462158, 40.93981095722744, 41.520211356026785, 41.01256207057408, 40.74288511276245, 43.478835582733154, 44.279250689915244, 46.16700676509312, 45.3992030279977, 49.40253618785313, 48.69322238649641, 42.36995867320469, 39.23899963923863, 32.69402238300869, 25.303313868386404, 15.553033590316772, 9.783239926610674, 4.5077745488711765, 1.3450589903763361, 0.5252000551138605, 0.4237529630107539, 3.2732779000486647, 5.528320746762412, 1.643995572413717, 3.4697977091584886, 3.7942162667001997, 5.7912062747137885, 6.481511541775294, 2.06193916286741, 0.4443957896104881, 1.0400984287261963, 2.443641926561083, 8.766732369150434, 22.787831476756505, 26.490387541907175, 20.493558883666992, 16.634821210588726, 21.27273334775652, 20.658658504486084, 10.752854091780526, 3.4320616083485738, 0.3345162442752293, 0.07650862314871379, 0.051614883222750256, 0.041055996237056594, 0.007375199830026499, 0.05028618951993329, 0.02847507828846574, 0.09686636326036283, 0.03840929575796638, 0.029881878157279322, 0.02626737639574068, 0.025410286583272473, 0.04144589263679726, 0.05048499349504709, 0.009200610004232397, 0.0576274838032467, 0.028376561789108173, 0.015795297787657807, 0.02160936750338546, 0.023144072919551815, 0.04331897837775094, 0.04020642289625747, 0.03653148062793272, 0.032022371156407256, 0.013326767881933068, 0.0846979979957853, 0.00789377445887242, 0.020958255477515713, 0.014908394842807735, 0.034796907633010826, 0.030824363298181976, 0.017366968095302582, 0.026257871816466962, 0.04888816989426102, 0.017807634181476066, 0.03469860487218414, 0.04572969116270542, 0.03343346615188888, 0.03341268262426768, 0.025402215409225652, 0.09223335329443216, 0.013087168685160577, 0.07838859262743167, 0.0362028627257262, 0.037180909886956215, 0.010940883541479707, 0.012028993323578365, 0.06743076097752367, 0.053597565939916034, 0.016448433544220667, 0.02756571753083595, 0.040125728119164705, 0.026141976338944266, 0.014801232110975044, 0.04837494636220591, 0.0030253251399179654, 0.03462351140167032, 0.05038991038288389, 0.03179401698123131, 0.027065873013011048, 0.007195386353747121, 0.03294426954484411, 0.028057163481467536, 0.0419994109709348, 0.058809892141393254, 0.02909878428493227, 0.004332494439690241, 0.00737602000923029, 0.020790562333006943, 0.05081476490678532, 0.9431058104549135, 13.892646023205348, 29.47474479675293, 29.11663464137486, 19.071071556636266, 36.97488396508353, 25.028733219419205, 15.816457169396536, 29.208705220903667, 27.314447368894303, 10.366284114973885, 2.2412669573511397, 0.1271004384117467, 0.49381857046059197, 0.5791217131274087, 4.284985772200993, 8.050981061799185, 5.363426097801753, 3.4792748349053517, 2.5030042954853604, 4.708978746618543, 3.006277301481792, 1.868257041488375, 1.8292557171412875, 3.578090161085129, 7.195567922932761, 9.93254108088357, 17.53067329951695, 24.929155111312866, 31.95165252685547, 42.164500440870015, 46.96038334710257, 51.56395401273455, 50.60038478033883, 50.044719968523296, 49.31721578325544, 49.937179224831716, 51.471862588609966, 52.59119306291853, 49.4047144481114, 44.37094259262085, 44.42234189169747, 47.485806124550955, 49.322183745247976, 49.99347700391497, 52.15567650113787, 52.038630621773855, 49.119939054761616, 49.24774421964373, 50.68144941329956, 49.78649016789028, 49.59839200973511, 45.65597023282732, 40.864749567849294, 53.13849571772984, 49.82398959568569, 46.29495784214565, 50.79175901412964, 50.24651997429984, 48.51740516935076, 49.30734586715698, 45.092196873256135, 40.768193926130024, 40.96103770392281, 40.825388022831504, 41.543519088200156, 43.49809946332659, 41.08070305415562, 43.17071424211775, 42.26647220339094, 45.904337065560476, 46.47617033549717, 46.75649193355015, 47.24523169653756, 49.89200898579189, 49.190734250204905, 45.213338715689524, 43.062294551304404, 35.33822536468506, 28.087153060095652, 19.27227749143328, 13.996459926877703, 6.87285840511322, 3.9562143853732517, 1.549416041799954, 2.7368487417697906, 4.938141626971109, 5.166809013911656, 5.302848662648882, 7.831830535616193, 6.701590086732592, 4.239726509366717, 5.432827745165143, 2.6175473034381866, 0.5964170822075435, 0.9937007469790322, 2.4987563405718123, 8.004986592701503, 21.508058411734446, 25.990888493401663, 19.501550674438477, 17.241343361990793, 23.15078800065177, 25.973575319562638, 14.683841739382062, 5.697853318282536, 0.6325781675321716, 0.030643340333231857, 0.07510454420532499, 0.025062808800222616, 0.03650104833234634, 0.027051930814715366, 0.053728292496608834, 0.03947772717635546, 0.02333063442659165, 0.015353172851194228, 0.018399925702916722, 0.07049913025860276, 0.028100564277597835, 0.010207205678203275, 0.00967554550152272, 0.0488638308431421, 0.0743639435885208, 0.04852805778916393, 0.006843652459792793, 0.014721709503126996, 0.056078099978289435, 0.11721558097217764, 0.05093433974044664, 0.03389889706990548, 0.06473711266049317, 0.024237087661666528, 0.051843111868947744, 0.06484616002334015, 0.02615036642444985, 0.05282367978777204, 0.04248524543696216, 0.052340905514678786, 0.0766162523733718, 0.21711378118821553, 0.17967831210366317, 0.20321096506501946, 0.1337127893098763, 0.14663012831338815, 0.1680733955332211, 0.08743106919739928, 0.13854314440063067, 0.09707434781427894, 0.1580063650118453, 0.1071627861154931, 0.11280352914971964, 0.14561626128852367, 0.10293072927743196, 0.17533404592956814, 0.15387845651379653, 0.12059247334088598, 0.14357266309005873, 0.12533265112766198, 0.1423658071351903, 0.0981093579903245, 0.08364642477993454, 0.10545058442013604, 0.16289875177400454, 0.10312196080173765, 0.1723128009055342, 0.1043198804504105, 0.16188445048672812, 0.14421875056411537, 0.12108082856450762, 0.13236315601638385, 0.1370300655918462, 0.1248912505273308, 0.050497736382697306, 0.12173727048294884, 0.08077947861914124, 0.20535235373037203, 1.0271797733647483, 14.787470647266932, 34.9013261113848, 36.8952054977417, 25.993044172014507, 39.122075353349956, 37.98731640407017, 27.324155739375524, 29.329360689435685, 30.714862755366735, 14.568011794771467, 3.901451289653778, 0.48077235051563805, 1.7182249150105884, 5.439658258642469, 18.708590984344482, 16.336356128965104, 10.17743468284607, 8.206134336335317, 5.848212335790906, 8.785703556878225, 5.744823575019836, 1.9756038870130266, 2.5856294504233768, 2.6571053521973744, 5.451227877821241, 9.481828808784485, 16.49910725866045, 23.260590382984706, 31.072792257581437, 42.37544427599226, 48.086422307150706, 52.10474967956543, 51.13628544126238, 49.885658332279746, 49.023046425410676, 50.02609879629952, 54.737946714673726, 55.10951900482178, 50.54682459150042, 47.423320974622456, 46.77557863507952, 49.526957580021445, 51.416158880506245, 52.079190731048584, 54.16203137806484, 54.21905524390084, 50.79013660975865, 50.44900090353829, 52.261525358472554, 50.144843510219026, 48.600074836185996, 47.8071950503758, 42.449348790305, 53.07390178952898, 47.21822057451521, 45.7750415120806, 53.56783185686384, 51.12082569939749, 49.67240422112601, 50.081576687949045, 47.28090374810355, 41.88869169780186, 44.01722717285156, 42.97112028939383, 44.790874344961985, 45.15798936571394, 44.617808614458355, 44.28997523444039, 44.686880656651084, 48.34028516496931, 48.237173897879465, 50.55878938947405, 48.372649874006, 51.893263884953086, 49.36734356198992, 46.64307301385062, 45.578153882707866, 37.68311732155936, 32.85588066918509, 20.031522784914287, 13.18650668007987, 6.355556334768023, 2.846420313630785, 1.6259745508432388, 2.0696976951190402, 5.129868047577994, 9.94642184461866, 4.846673369407654, 9.236295972551618, 10.721287557056971, 10.829683797700064, 12.526605861527578, 4.290709350790296, 1.6593983173370361, 1.6747265862567084, 4.250684252807072, 12.029055782726832, 28.16344949177333, 33.11765405109951, 26.751893418175833, 23.702653884887695, 30.606484753744944, 29.60022578920637, 16.107822929109844, 5.240175477096012, 0.758184933236667, 0.13932692020067147, 0.1649664786777326, 0.13670312027846063, 0.15146281756460667, 0.0915123623396669, 0.16110207246882574, 0.20741527660616807, 0.12704379430838994, 0.09693517349660397, 0.0991619625794036, 0.13340170814522676, 0.1267011205532721, 0.14375392693494046, 0.09762333014181682, 0.09932808152266911, 0.15396315125482424, 0.18331834035260336, 0.11146200434970004, 0.11977661640516349, 0.12559562415948936, 0.16118735074996948, 0.17349791659840516, 0.12571735334183487, 0.06679177097976208, 0.12161358711974961, 0.12746493385306426, 0.11460236619625773, 0.14804826650236333, 0.15108173872743333, 0.23978157341480255, 0.1488529818930796], [0.03743860391633851, 0.015182492456265857, 0.04778694148574557, 0.02261528549050646, 0.026276185476620282, 0.09959403332322836, 0.034141639580151865, 0.03217702964320779, 0.024644792212971618, 0.04376139338793499, 0.03360015845724514, 0.01998286138820861, 0.03307906731164881, 0.01790620496363512, 0.03227781584220273, 0.024976114077227454, 0.04354840124558125, 0.05883534398994275, 0.052640746746744425, 0.02506626084712999, 0.04539276120652046, 0.027573739511093924, 0.035576055824224434, 0.023763655119442513, 0.060467668542904515, 0.02717828082053789, 0.029529877938330173, 0.04167527139985135, 0.051968376218740425, 0.05120355190177049, 0.04785014363005757, 0.10169088973530702, 0.09256829853568758, 0.017287145235708783, 0.011758688720874488, 0.04540201642417482, 0.03497534877221499, 0.10874407126435212, 0.07982576372367994, 0.6253243024860109, 11.61521325792585, 22.04861089161464, 27.369755029678345, 20.7471889768328, 23.58498614174979, 18.896140234810964, 6.423924003328596, 15.313687256404332, 21.265201500483922, 12.516812375613622, 3.492566304547446, 0.5370428253497396, 0.4932695542063032, 5.815207523959024, 5.393278164522989, 6.300542235374451, 3.1844445296696255, 2.1130125480038777, 3.227667970316751, 2.3288207735334123, 1.4141657735620226, 1.060787667121206, 1.8366713992186954, 1.9429230349404472, 3.1374757928507666, 6.016852498054504, 10.757122891289846, 18.571211201804026, 27.38356978552682, 34.31711115155901, 38.82934079851423, 44.214191232408794, 47.26178230558123, 50.94947269984654, 51.02346754074097, 51.852446692330496, 49.14253807067871, 47.08214357921055, 45.70119605745588, 48.60895115988595, 49.38781990323748, 51.74643802642822, 51.6648279598781, 52.346025875636506, 48.944823605673655, 49.10091488701956, 50.186897482190815, 48.93193122318813, 48.61901909964425, 49.792816502707346, 45.80296284811837, 38.81555904660906, 51.88536378315517, 52.10138675144741, 50.70498991012573, 48.440662315913606, 50.85108273369925, 45.26933077403477, 47.192011969430105, 45.22801331111363, 46.32690218516758, 45.47852366311209, 46.00514153071812, 42.64560760770525, 41.216925961630686, 42.1368396622794, 46.11991534914289, 45.416389397212434, 45.267354011535645, 44.80583381652832, 45.323728220803396, 46.39472355161394, 43.84837899889265, 34.358883721487864, 37.20976087025234, 32.55556910378592, 21.199678250721522, 11.171297192573547, 6.0437997835023065, 2.6133403863225664, 0.47157298986400875, 2.246615333216531, 0.3854675745325429, 3.859047302177974, 7.916107841900416, 6.358771179403577, 5.518756985664368, 3.6191238335200717, 4.979833858353751, 4.226641748632703, 5.522225005286081, 3.890163941042764, 1.190630174108914, 1.524312960250037, 4.924453241484506, 18.740278244018555, 25.143025875091553, 24.46782078061785, 18.961788552148, 23.93092826434544, 22.059142623628887, 10.97008170400347, 3.8291274905204773, 0.3149288110435009, 0.06628463390682425, 0.07200306241533586, 0.011132389872467943, 0.041689137262957435, 0.005951906047162733, 0.03346182552299329, 0.10673717502504587, 0.04574435430445841, 0.04916656602706228, 0.028437436558306217, 0.024366307870617936, 0.012201845878735185, 0.012314894901854652, 0.028082547476515174, 0.0132018970824512, 0.0809120372203844, 0.023692953466836895, 0.04298669299376862, 0.026440146678526486, 0.018328370792525153, 0.02790150585185204, 0.038083846614296944, 0.053622600489429066, 0.01719395523624761, 0.06464554435972657, 0.0611925067912255, 0.052900825826717277, 0.04356041131541133, 0.06695833097078971, 0.052680800668895245, 0.019794803711452653, 0.08464677538722754, 0.028405263820397, 0.010901626897975802, 0.020037225613902723, 0.026373080277283276, 0.005689656503298985, 0.00886642387402909, 0.039095569468502483, 0.03859768422054393, 0.06297421082854271, 0.02254752698354423, 0.03226334608293005, 0.0034355065560833153, 0.01610916942757155, 0.014152378758548625, 0.016277905819671493, 0.029589918109455278, 0.01394609987203564, 0.029527075588703156, 0.05449557311034628, 0.04988758751590337, 0.021231727142419134, 0.05007619310968688, 0.03291695511766842, 0.029460552015474865, 0.036282027406351905, 0.060901985237640996, 0.03839437138023121, 0.007384560220608754, 0.026540939662871615, 0.020986289151811173, 0.061399432830512524, 0.01892832975967654, 0.04636978038719722, 0.007544831040182284, 0.02841372854475464, 0.038046788424253464, 0.014750750801925148, 0.1626797749527863, 0.07163206660853964, 1.2829339525529315, 15.745865208762032, 27.793688944407872, 29.9220871925354, 24.39170847620283, 29.76487030301775, 18.779599836894445, 11.195903369358607, 28.872900520052227, 26.86441080910819, 11.383545551981245, 2.456347576209477, 0.2661750928631851, 0.06614222976246051, 1.594723942024367, 3.070114961692265, 5.49112617118018, 5.26052153961999, 3.128069017614637, 4.552416724818094, 3.46901364837374, 2.0411186686583926, 2.4344698701586043, 2.0444329593862807, 4.1233424459184915, 4.253359743527003, 7.152266749313899, 12.26547258240836, 20.633247205189296, 30.330783707754954, 37.202260289873394, 42.69495718819754, 47.49784387860979, 49.23090178625924, 49.65926170349121, 51.31484719685146, 53.457327706473215, 50.447322913578574, 48.98409135001046, 47.28936665398734, 49.44067137581961, 51.078045640672954, 52.52457026072911, 52.06755597250802, 54.21299988882882, 49.48675530297415, 49.77681132725307, 49.25506067276001, 50.335727896009175, 48.22759928022112, 50.502102511269705, 46.51125526428223, 40.7908867427281, 51.529049737112864, 51.860096658979145, 52.170010634831016, 50.69728088378906, 50.38821458816528, 48.43156712395804, 48.41077811377389, 47.50648396355765, 47.85594361168997, 47.074677739824565, 46.02263709477016, 45.08706562859671, 42.26869910103934, 43.249089922223774, 45.53427253450666, 46.578003134046284, 45.76292732783726, 47.509568963732036, 47.867258753095356, 48.359740121024, 47.43586942127773, 38.26641859327044, 40.430143220084055, 36.467873913901194, 26.287788493292673, 16.199148314339773, 8.895561524799891, 4.811846826757703, 1.8291048109531403, 2.669093817472458, 1.133998881493296, 3.75699520111084, 10.261028460093907, 8.86896903174264, 9.097728048052106, 7.325643845966884, 4.320734253951481, 4.8658773217882425, 3.9489491752215793, 1.1961386842387063, 0.9922102498156684, 2.5154048757893697, 4.439615760530744, 19.280227967670985, 29.9351532799857, 28.262801783425466, 20.378112827028545, 25.95214533805847, 27.218173129217966, 15.591608251844134, 6.058289383138929, 0.7179132284862655, 0.01038393606099167, 0.0388418855810804, 0.017090441326477697, 0.032618280965834856, 0.02796155450466488, 0.036146208444344144, 0.0682624074231301, 0.11327710588063512, 0.03258455777540803, 0.08962653710373811, 0.023140990674229603, 0.04312083936695542, 0.04603126605174371, 0.08423035166093282, 0.022526841843500733, 0.03813506583017962, 0.019397743678252612, 0.03500246303156018, 0.0508909304626286, 0.058386187734348435, 0.07135817594826221, 0.052607729232736995, 0.0860172329204423, 0.047378941771707365, 0.05070943930851562, 0.05810868726777179, 0.0533599192276597, 0.016836168809926937, 0.08220679060156856, 0.015733167728675262, 0.03000494066093649, 0.05612944811582565, 0.11897719358759266, 0.09869025181978941, 0.1536569691130093, 0.1556951661727258, 0.14483039560062544, 0.2892426779227597, 0.19541306421160698, 0.11170120829982416, 0.13264216961605207, 0.11126365499304873, 0.2118617980075734, 0.05966785217502287, 0.07262819672801665, 0.0720031913369894, 0.08129181327032191, 0.12425478467983858, 0.08263825744922672, 0.19231880881956645, 0.13153144850262574, 0.18460569770208426, 0.09098055373345103, 0.17085979958730085, 0.2083951218851975, 0.09746812204165117, 0.1970042424010379, 0.1996873462838786, 0.1235084640128272, 0.12258579209446907, 0.1374181333397116, 0.10766507844839777, 0.1811753096325057, 0.17620075227958815, 0.1544068588742188, 0.11601764096745423, 0.10836804072771754, 0.1403492282011679, 0.08647157996892929, 0.26990608551672524, 0.1560051752520459, 1.4530017524957657, 17.59276761327471, 34.161089352199006, 39.45024224690029, 31.556060314178467, 34.08791787283761, 28.1692373411996, 13.069738728659493, 24.17800620623997, 27.965537003108434, 16.010195527757915, 4.248649299144745, 0.8530476029430116, 0.9724614066737038, 9.654952730451312, 10.17279849733625, 16.607973371233257, 8.911663975034442, 6.1079108119010925, 9.249019861221313, 5.362088135310581, 3.257905227797372, 3.2288595863751004, 3.3793339005538394, 3.684418661253793, 3.7912181190082004, 7.665772063391549, 12.191735693386622, 21.24406681741987, 30.561446530478342, 37.13120453698294, 40.90851627077375, 45.97955478940691, 47.71786206109183, 49.82670981543404, 53.8776033946446, 53.78204134532383, 52.15792424338204, 52.1661057472229, 49.548688071114675, 52.16971186229161, 53.38983290536063, 55.47984756742205, 54.39719663347517, 54.96371453148978, 50.792537212371826, 50.50947107587542, 52.28065027509417, 50.55702454703194, 49.21218681335449, 49.572527340480256, 48.26240280696324, 43.840187072753906, 52.33618375233242, 51.68662445885794, 49.780938557216096, 51.56738294873919, 53.418720041002544, 49.72473457881382, 50.97597312927246, 49.667710712977815, 49.8830110686166, 49.30982289995466, 48.97332164219448, 47.75075135912214, 44.55857869556972, 45.0646333694458, 49.08975608008248, 48.95830658503941, 48.535845688411165, 47.4626338822501, 48.45899861199515, 49.64033828462873, 48.00513185773577, 42.91104963847569, 44.50192308425903, 38.35693277631487, 25.361550194876536, 13.84896877833775, 9.108632377215795, 4.047815527234759, 1.5852505075080054, 4.251853721482413, 2.395982495376042, 6.716568665845053, 14.754463229860578, 12.24927806854248, 15.568244934082031, 8.642774769238063, 10.009217926434108, 11.651365603719439, 10.174479961395264, 6.344347153391157, 2.0409330214772905, 2.8671578637191226, 7.995929615838187, 25.746513400759014, 34.445562498910085, 34.319643769945415, 26.749395540782384, 32.741030420575825, 31.711877141680034, 16.429010357175553, 5.604149912084852, 0.658893384039402, 0.16995082050561905, 0.14084922708570957, 0.05304317568827953, 0.13264766574970313, 0.08189684937575034, 0.11433036864868232, 0.1781070964144809, 0.22650634790105478, 0.1202162935265473, 0.18326327045048985, 0.20481470972299576, 0.10736297430204493, 0.07115331944078207, 0.13277309973325047, 0.08417125126080853, 0.14883998116212233, 0.10673560082380261, 0.0784897350573114, 0.09803572337010077, 0.12086949204759938, 0.11016782772328172, 0.15264042866017136, 0.16751798747905663, 0.10057629418692418, 0.20896410063973495, 0.1753757894039154, 0.27099643700889176, 0.1205277953829084, 0.11176041726555143, 0.10875915509781667, 0.12248507035630089, 0.22794572423611367], [0.03799072786101273, 0.04477010015398264, 0.01096702749574823, 0.030144776550254652, 0.051812187635472844, 0.020405363091932874, 0.03706613229587674, 0.03953513463160821, 0.020338919246569276, 0.026613858428650668, 0.019935723560463105, 0.025134535040706396, 0.018470350852502242, 0.06515245751610824, 0.010609869562488581, 0.05071531542177711, 0.033126802250210724, 0.051221645038042746, 0.03647057193198374, 0.061952316734407625, 0.027043730719015002, 0.039757802683327875, 0.07584346884063312, 0.009978832843314325, 0.041593711490609815, 0.0534825644322804, 0.09602638440472738, 0.03333733131044677, 0.0467552018484899, 0.009681746463424392, 0.034695961978286505, 0.003673531339570348, 0.053481054691863913, 0.02318831509910524, 0.01540068896221263, 0.03863654052838683, 0.03602241651554193, 0.027183176450697438, 0.061013495682605674, 0.06347187555262021, 0.6761388129421643, 10.138668077332632, 25.345729146684917, 27.229170390537806, 18.7788268498012, 18.657552991594585, 9.217881509235927, 11.198819875717163, 14.388710056032453, 17.81393051147461, 10.968685984611511, 3.686247340270451, 0.62334270881755, 0.7051867342420987, 3.0670838100569586, 2.012380919286183, 3.5040907604353766, 2.7150507228715077, 2.2897176146507263, 3.574482960360391, 2.3191530065877095, 1.5966365422521318, 1.753082615988595, 2.3015914346490587, 0.5450888393180711, 1.1405568953071321, 4.727797073977334, 6.7484087858881265, 14.25123039313725, 20.921079805919103, 25.58020826748439, 31.080494335719518, 40.76925352641514, 45.03124727521624, 52.26428379331316, 53.75810827527727, 49.04093108858381, 49.63877841404506, 49.90677738189697, 51.39786427361624, 52.33171258653913, 51.374636445726665, 53.44829157420567, 51.893204825265066, 49.45668002537319, 49.58083391189575, 49.14418479374477, 49.40370001111712, 50.3167975289481, 50.90875278200422, 46.740014280591694, 37.75293976919991, 51.932340553828645, 50.80862576620919, 50.77305098942348, 50.7382926259722, 51.00897012438093, 48.38105719430106, 46.72775765827724, 49.00857332774571, 50.33194807597569, 48.74229403904506, 46.39734649658203, 45.66616324016026, 46.74257121767317, 45.57411697932652, 46.36878940037319, 45.23594120570591, 46.6825179372515, 45.70125164304461, 47.88954162597656, 43.91752052307129, 34.38883740561349, 36.12119007110596, 33.809593881879536, 21.625397852488927, 10.383833527565002, 4.73187610081264, 1.1756646228688103, 0.8612109220453671, 0.346622286098344, 1.0796602772814887, 1.6860860224281038, 4.288728679929461, 8.348581961223058, 5.490235498973301, 8.92681278501238, 13.547616720199585, 6.009879112243652, 3.2870839706489017, 2.5898978156702857, 0.6975165743912969, 1.8538697106497628, 4.425213013376508, 7.413276263645717, 22.452719858714513, 24.437858411243983, 21.198029790605815, 21.38196424075535, 23.284089190619333, 10.997712952750069, 3.7905780162130083, 0.13284054611410412, 0.06911035906523466, 0.024334029959780828, 0.023905429922576462, 0.018487232803766216, 0.028953350481710265, 0.01517555782837527, 0.026837725791015794, 0.036749548212225945, 0.038419185405863185, 0.011226914889578308, 0.01642160426958331, 0.009552029227571828, 0.09052972149636064, 0.024975075918648924, 0.09307175116347415, 0.015623798061694418, 0.027119921719921485, 0.04312151111662388, 0.020216874545440078, 0.025554595714701072, 0.05145422987905996, 0.029604262339749506, 0.039460183653448305, 0.03628323859136019, 0.0481694723878588, 0.04141240014827677, 0.019847184918554764, 0.04343960154801607, 0.030946207831480672, 0.04004798157672797, 0.004908785681306783, 0.06147317601633923, 0.08712837472558022, 0.040283860705260716, 0.0150743594193565, 0.030291733664593527, 0.019437544846108983, 0.031519766697393994, 0.01321743129353438, 0.02542909387765186, 0.0601281499756234, 0.037288556074989695, 0.06531652728361742, 0.0070891451572866315, 0.010734596173278987, 0.04459289734118751, 0.062208687620503564, 0.05962748612676348, 0.016433495595785122, 0.068071888360594, 0.01976355547750635, 0.04216278863272496, 0.08204949939889566, 0.026246552156018357, 0.08107364390577589, 0.12538985162973404, 0.013925456292262035, 0.0635480886059148, 0.052634195491139374, 0.06848016966666494, 0.04944524375189628, 0.03725320440051811, 0.047229596214102845, 0.019234391461525644, 0.0273693494964391, 0.025025635259225965, 0.07545334513166121, 0.02964536120582904, 0.03630978627396481, 0.0308652178916548, 0.06887550452458006, 0.002707516512600705, 0.07536341210028955, 1.8086588680744171, 14.22708887713296, 32.07212039402553, 31.672109127044678, 27.00288666997637, 24.840320655277797, 9.467546786580767, 12.672770772661481, 24.81145089013236, 24.59441348484584, 12.255505391529628, 2.726665939603533, 0.3322032541036606, 0.26564529272062437, 1.1252306891339166, 2.1131895099367415, 3.757258798394884, 3.259085987295423, 5.6697322215352735, 5.268735613141741, 5.284285247325897, 3.6671124356133595, 1.9672339132853915, 1.5366486183234622, 0.7410024723836354, 2.532857664993831, 6.090069140706744, 9.315083333424159, 17.223569869995117, 23.43716147967747, 27.84755311693464, 33.66072525296892, 43.180083887917654, 48.70032344545637, 53.596604347229004, 53.821031161717, 49.89450338908604, 51.412684781210764, 51.30440752846854, 53.2737215587071, 53.18743882860456, 53.87380273001534, 53.7402548789978, 52.916893345969065, 49.823583126068115, 50.68406541006905, 51.79275471823556, 49.17641053880964, 50.50575726372855, 50.4845826285226, 46.771322863442556, 40.64599595751081, 50.7949412890843, 52.43717929295131, 51.67123767307827, 51.32191004071917, 51.983868394579204, 49.98610149111067, 49.24502747399466, 48.513705253601074, 50.4567585672651, 50.046391010284424, 48.08128758839199, 46.18045500346592, 48.419060366494314, 46.661860942840576, 49.90222978591919, 46.84879527773176, 46.19797488621303, 47.44866452898298, 49.585235595703125, 48.102816581726074, 38.33916623251778, 40.77149779456002, 35.36807829993111, 25.431987558092388, 13.146912370409284, 6.495859137603214, 1.845466515847615, 1.6762846112251282, 0.5196485530052866, 1.577717900276184, 2.3758281597069333, 4.747090484414782, 7.357264229229518, 4.598953153405871, 7.314159342220851, 7.282471214021955, 4.483445865767343, 2.0628634904112135, 0.7789463134748595, 0.47967431800706045, 1.9843030316489083, 4.978045131478991, 9.649199622017996, 28.009215116500854, 30.053953579493932, 26.32425958769662, 25.166026149477275, 27.77758649417332, 15.76102444103786, 5.421593810830798, 0.4758283815213612, 0.07079166027584247, 0.07665393820830754, 0.022292141669562886, 0.02463134195256446, 0.025066508512411798, 0.056067168779139004, 0.01808232720941305, 0.006432978893696729, 0.013887591493715132, 0.03190175477149231, 0.038595180426325114, 0.024189237372151444, 0.012193106347694993, 0.036994713092488904, 0.06343517359346151, 0.03379783945690308, 0.058924042087580474, 0.03196780676288264, 0.008754545323816794, 0.05463399086147547, 0.021056732961109707, 0.053392234457922835, 0.03558216603206737, 0.010130228424843932, 0.04279922055346625, 0.018940036185085773, 0.03930890087836555, 0.01805350643449596, 0.06567267674420561, 0.05340456683188677, 0.021412612704027976, 0.037281872505056005, 0.04338941370536174, 0.13363128368343624, 0.1704622052077736, 0.06208179478666612, 0.174130148387381, 0.14553920685180596, 0.10348843756530966, 0.07982509197401148, 0.1313898925270353, 0.12427644351763384, 0.17833032086491585, 0.10912941808679275, 0.13286829819636686, 0.12501910009554454, 0.17840274769280637, 0.12229015438684396, 0.27196904910462244, 0.1461432794375079, 0.10327433262552534, 0.10287079427923475, 0.23542136166776928, 0.10465672558971814, 0.1625937774245228, 0.20308949372598104, 0.14865402185491153, 0.16404938431722776, 0.17987059535724775, 0.19737223908305168, 0.16677315958908626, 0.15560828654893807, 0.11682805605232716, 0.12337519973516464, 0.07118358888796397, 0.184332723064082, 0.09827037435024977, 0.13673176802694798, 0.17008956734623226, 0.1353839396366051, 0.14430928070630344, 0.20313928462564945, 0.17748634543802055, 2.212869018316269, 15.792704752513341, 36.7682341166905, 38.251195090157644, 33.20728233882359, 30.09338113239833, 18.191103049686976, 17.190734420503887, 20.890257596969604, 25.435181992394583, 14.89197850227356, 5.040246273790087, 1.0543192199298312, 1.384157155241285, 5.393939980438777, 5.46055713721684, 8.502724272864205, 8.728745698928833, 6.848472399371011, 8.959678632872444, 7.100085777895791, 4.129944971629551, 5.774054212229593, 5.353509281362806, 0.9480897315910884, 1.2891748462404524, 5.606801952634539, 7.859741449356079, 16.520592825753347, 21.630093097686768, 27.365414142608643, 33.31161648886544, 42.89565590449742, 46.58691767283848, 55.352570465632844, 55.8609527860369, 51.0160677092416, 53.25059795379639, 54.1219367980957, 56.054932594299316, 55.60537372316633, 55.231602328164236, 56.53873913628714, 53.336081641060964, 49.70955971309117, 50.411077635628835, 51.76894671576363, 50.07994038718087, 51.45739991324288, 50.13766949517386, 48.763319287981304, 43.6770954813276, 51.70762538909912, 51.03208678109305, 52.00760691506522, 54.08021286555699, 53.719632625579834, 51.96348237991333, 50.67225694656372, 50.70505591801235, 53.51545980998448, 52.10027503967285, 50.406686374119346, 49.28878722872053, 51.26176643371582, 49.0550011907305, 51.05767352240426, 47.949827671051025, 49.71624040603638, 50.37119844981602, 51.23960862840925, 50.57654898507254, 43.42159979684012, 42.11184351784842, 34.22629819597517, 22.922760282244, 11.599627579961505, 5.2548426900591165, 2.0952918188912526, 1.9308568366936274, 1.1462116433041436, 2.3575118396963393, 5.487916103431156, 10.301363621439252, 16.97556608063834, 13.698415211268834, 18.652979339872086, 19.989267315183366, 13.132597344262258, 6.3938513313020975, 4.076050400733948, 1.299636336309569, 2.624150046280452, 6.918572340692792, 13.350975751876831, 32.8169082232884, 34.80497196742466, 31.223029681614467, 31.183011531829834, 31.283485957554408, 17.490401540483745, 5.656428158283234, 0.40534229949116707, 0.12487238725381238, 0.13532709197274276, 0.13772935021136487, 0.14528487835611614, 0.1476976674582277, 0.11638984456658363, 0.1216457768210343, 0.139739917325122, 0.12772223433213575, 0.07806865658078875, 0.08976571820676327, 0.11843364632555417, 0.2021757106163672, 0.11085907848817961, 0.20616639219224453, 0.16069534500794752, 0.11581667246563093, 0.14051228016614914, 0.0684987683115261, 0.18335179212902272, 0.07319674122014216, 0.09150718511747462, 0.24938371245350155, 0.13800266411687645, 0.10922810421990496, 0.1398916920380933, 0.19147152214178018, 0.09022170730999537, 0.08937324676662683, 0.1323388373213155, 0.08067535063517944, 0.16021615000707762, 0.2540217435785702], [0.020412810013762543, 0.04744429487202849, 0.028881564869412353, 0.02349865835692201, 0.05334597533302648, 0.06248087515788419, 0.03092701207580311, 0.029308315898690904, 0.029093922581523657, 0.015697478483031903, 0.04026836296543479, 0.04026669037661382, 0.02497208527555423, 0.030921346308397393, 0.008640514121257832, 0.049697801271187406, 0.035627709302519045, 0.013004016763131534, 0.00818744271860591, 0.033937929796853235, 0.044868043291249445, 0.025107054372451136, 0.04936846412186112, 0.03010981503341879, 0.018953790089913776, 0.061016230178730826, 0.015282369418335813, 0.09138837363570929, 0.042802877857216766, 0.04611802693190319, 0.03676585001604898, 0.02566926134750247, 0.05896126651870353, 0.04390493407845497, 0.03447763994336128, 0.04646631217162524, 0.037850976788571904, 0.016892346420458386, 0.026203470271346823, 0.0802581330229129, 0.04219742784542697, 0.9441810441868645, 10.150351473263331, 19.35293218067714, 22.937959466661724, 19.58422555242266, 18.325029577527726, 12.281399590628487, 10.949419498443604, 18.12387922831944, 22.514777694429668, 14.24701804774148, 5.156139186450413, 0.9280856507165092, 0.5794650518468448, 1.5371690818241663, 2.8298801268850053, 1.6676187962293625, 4.157586642674037, 2.9778220398085455, 2.932328926665442, 3.449086431946073, 0.9108210057020187, 1.2336501628160477, 0.677095927298069, 1.2190953152520316, 2.001925834587642, 3.158114331109183, 5.118894670690809, 9.148059061595372, 13.5630920955113, 17.338861329214915, 26.02351549693516, 37.3723452431815, 46.831879888262065, 54.29016310828072, 53.63337421417236, 53.24452870232718, 52.839295864105225, 52.79391023090908, 52.823843070438926, 51.82196841921125, 51.268217836107524, 50.56914915357317, 50.61313125065395, 53.09501041684832, 52.090870652879985, 51.03170115607125, 51.698623997824534, 50.53150381360735, 49.66902044841221, 35.59842150551932, 51.694131987435476, 48.53425802503313, 49.07380301611764, 51.2045202255249, 51.111070428575786, 51.952278409685405, 51.09430095127651, 50.31005777631487, 51.44013711384365, 49.19171394620623, 48.5183744430542, 47.81689126150948, 46.04244293485369, 47.21657037734985, 45.887984480176655, 46.2468797819955, 47.413225242069785, 48.25032683781215, 40.91004140036446, 29.00897925240653, 30.877040658678325, 27.738280534744263, 12.393870949745178, 6.050922121320452, 1.9444757401943207, 0.9383223014218467, 0.13562165759503841, 1.0586248231785638, 0.9681356102228165, 2.804906781230654, 2.2341665497847965, 4.098792288984571, 6.738383403846195, 5.281681409903935, 4.278973843370165, 4.7079960107803345, 1.5981626489332743, 0.642991834453174, 0.7870244085788727, 2.192080659525735, 8.237288321767535, 8.8241913659232, 10.061227798461914, 20.619437660489762, 18.806301764079503, 23.813420329775127, 22.717350687299454, 14.362939187458583, 3.534247462238584, 0.47754621505737305, 0.07846372002469641, 0.020637944540274993, 0.021151327528059483, 0.06637464157704796, 0.03939795520688806, 0.05652968538925052, 0.01205563684925437, 0.07622186746448278, 0.02448501587579293, 0.04133199035589184, 0.020597666701568023, 0.04718446345733745, 0.02544108698410647, 0.03855379318286266, 0.1129071753738182, 0.04745301743969321, 0.055756236892193556, 0.06613002970282521, 0.04194360485832606, 0.03563443358455386, 0.0507174799484866, 0.023313531951446618, 0.015411280893853732, 0.06117654764758689, 0.007082989148329943, 0.01981977210380137, 0.01697819127834269, 0.026077116872849207, 0.02537153714469501, 0.053852176027638574, 0.02968546941078135, 0.03322534928364413, 0.016920480178669095, 0.023099583074716584, 0.03043387657297509, 0.09570508450269699, 0.04983414609783462, 0.04997941365997706, 0.03764920422275152, 0.03535051756937589, 0.021759761397593787, 0.016485043901151845, 0.014022720894510192, 0.055767385222549946, 0.05025176065308707, 0.07813713433487074, 0.025692507957241366, 0.060936251256082735, 0.004402397541395787, 0.02977451356127858, 0.03810294058972171, 0.020805286542911614, 0.04067820829472371, 0.047586946681674035, 0.022023584294532026, 0.025907893631873385, 0.02892012262184705, 0.007024712744168937, 0.006824806573734219, 0.08172625210136175, 0.03807451675779053, 0.013800498131396515, 0.05783719862146037, 0.030745917864676033, 0.04217923292890191, 0.02203364696885858, 0.0710311627813748, 0.04318296264058777, 0.03137491304161293, 0.04467171257627862, 0.04955616047871964, 0.035088450381798406, 0.052696926053613424, 0.009813055712064462, 0.023882342768566947, 2.12352625812803, 14.832413332802908, 26.7810480594635, 29.441407339913503, 25.288620165416173, 21.47717366899763, 9.947539636066981, 13.309759906360082, 24.978855575834, 25.77617699759347, 13.452486327716283, 4.479833236762455, 0.9057721080524581, 0.13299929616706713, 0.4588390588760376, 0.8947421142033168, 1.3508012422493525, 3.5102036552769795, 3.1254456383841376, 4.588877396924155, 4.322941175528935, 2.7429062681538716, 3.277906051703862, 1.5348379611968994, 2.1131617171423773, 2.239768100636346, 3.9071479439735413, 5.373170077800751, 12.401315076010567, 15.908644131251744, 20.87297395297459, 28.39309787750244, 38.41193471636091, 48.36585800988333, 56.28235060828072, 55.48742110388619, 55.84452029636928, 55.42175020490374, 54.07985503332955, 54.80781085150582, 51.644917896815706, 50.99898208890642, 51.95928566796439, 50.86670228413173, 53.38453837803432, 53.35821860177176, 52.211324623652864, 51.07095152991158, 51.20400605882917, 49.70568609237671, 37.890583583286826, 50.35558237348284, 49.24658039637974, 50.01128871100289, 51.832164900643484, 51.02662549700056, 53.00077199935913, 51.5042724609375, 51.98799909864153, 52.53968606676374, 50.78652007239205, 49.79206609725952, 49.00660003934588, 47.96878930500576, 49.014239583696636, 47.05769634246826, 47.132663931165425, 49.46900960377285, 48.286839621407644, 45.93681294577462, 35.662296295166016, 37.07832179750715, 31.61777421406337, 16.76760823386056, 8.042744840894427, 2.8740978113242557, 1.6133535823651721, 0.5789488224046571, 1.4929234960249491, 2.2917736300400326, 4.969214839594705, 2.9701366807733263, 3.6839157853807722, 6.024389556476048, 5.464441614491599, 5.918863356113434, 3.8433122379439215, 2.495770352227347, 0.4503331881548677, 0.543439510677542, 1.7383260535342353, 7.3536902495792935, 10.365307024547032, 12.516680359840393, 25.875784635543823, 24.090867110661097, 26.573646068572998, 28.415248734610422, 18.01687523296901, 5.29898806980678, 0.9462836342198508, 0.06482313733015742, 0.025842659275180528, 0.021764958975836635, 0.03358743253297039, 0.10737653821706772, 0.01649870959642742, 0.004031598509754986, 0.04113744079534497, 0.06387484392949513, 0.032463188216622384, 0.061227010296923776, 0.09860456641763449, 0.028263838462797657, 0.017383804245452796, 0.06271049140819482, 0.04515732651842492, 0.016435363263423954, 0.022722799364211302, 0.05246435817597168, 0.012544021758783077, 0.008061074901239147, 0.022441127603607516, 0.023794394452124834, 0.02806011850147375, 0.023692280020830885, 0.04330451540382845, 0.01538078922645322, 0.009736372773269457, 0.07527406260903392, 0.03016570596290486, 0.03868925252131053, 0.023783388614122356, 0.018472495023161173, 0.022927299640806656, 0.09699687268584967, 0.13632305924381527, 0.12100627113665853, 0.2022428855832134, 0.20651823974081449, 0.14054220356047153, 0.11026045453867742, 0.07791607441114527, 0.1368503895189081, 0.1824503176446472, 0.2048165417675461, 0.2772508199725832, 0.15863970959825174, 0.1460467917578561, 0.13130948612732546, 0.12386080010661057, 0.0582126999007804, 0.17043647515986646, 0.09091899025120906, 0.13109649398497172, 0.07417785535965647, 0.08780244498380593, 0.10174537609730448, 0.08861874975264072, 0.12709477942969116, 0.14931924401649407, 0.12320386964295592, 0.10802979102092129, 0.12972277269831725, 0.09378920016544205, 0.09875363377588135, 0.07465683322932039, 0.1670291301395212, 0.1448422156806503, 0.07654258382639714, 0.09163628997547285, 0.07964233535208873, 0.11141663071300302, 0.17993968379284653, 0.1162345821836165, 0.16402581201067992, 2.3481452337333133, 16.1174670287541, 31.82563999720982, 38.14712149756295, 31.4477413722447, 29.016545840672084, 20.374954870768956, 17.371158293315343, 25.25364293370928, 28.605764865875244, 18.54730592455183, 6.744902551174164, 1.6399657257965632, 1.2920484691858292, 4.591932432992118, 6.2570408667836865, 7.112343268735068, 8.666587114334106, 7.823513541902814, 6.344321097646441, 8.116756183760506, 2.9559191465377808, 3.838160148688725, 3.51042816894395, 4.1504299981253485, 3.7284889136041914, 4.409183953489576, 5.760916905743735, 10.90969751562391, 14.814907346452985, 19.913269656045095, 27.540031058447703, 39.48833574567522, 49.705974442618235, 56.44839865820748, 57.160797459738596, 58.026101793561665, 56.47046961103167, 54.206531115940635, 55.310707569122314, 53.319326060158865, 52.43263169697353, 53.371110984257285, 51.01835366657802, 55.36888831002371, 55.161362988608225, 51.895435197012766, 52.93107809339251, 52.030723571777344, 50.6427583694458, 42.466990266527446, 50.50891521998814, 48.5783999306815, 49.573368072509766, 52.37819603511265, 53.55347687857491, 55.22209024429321, 52.78903259549822, 52.64099080221993, 54.115061555589946, 52.86774526323591, 51.51024791172573, 51.80300331115723, 49.9282021522522, 51.49386058534895, 49.711831774030415, 50.34818254198347, 50.17248691831316, 49.3974153654916, 46.107269627707346, 39.92043031964983, 37.80200794764927, 31.058558872767858, 15.296813556126185, 7.40680227960859, 2.6146095182214464, 1.6984058299234934, 0.8487196351800645, 2.440555189337049, 3.1378060494150435, 8.232912693704877, 5.311183895383563, 8.3587532554354, 13.649524211883545, 12.805989452770778, 11.869235924312047, 9.630810345922198, 4.17028534412384, 1.8681838682719638, 1.4417817145586014, 3.2373290061950684, 11.215398277555193, 14.761169978550502, 17.404728514807566, 31.279532432556152, 29.440660408564977, 33.288934094565256, 33.03991413116455, 19.958961009979248, 5.1949149114745, 0.7668466770223209, 0.12826692153300556, 0.18915516643651895, 0.07477986519890172, 0.13206474988588265, 0.20018168618636473, 0.08899085157151733, 0.14113588098968777, 0.09869370556303433, 0.14898840391210147, 0.25147813292486326, 0.16704331152141094, 0.17025183221059187, 0.10167343781462737, 0.08244962471404246, 0.16517746235643113, 0.10995570410575185, 0.09979722741991282, 0.10233119609100477, 0.08611747968409743, 0.056021846032568386, 0.10163609803255115, 0.13438909873366356, 0.14630825844194206, 0.09900836939258234, 0.15735707485250064, 0.13669469287352903, 0.08481337609035627, 0.16823631179119858, 0.21617603222174303, 0.13767624806080545, 0.12587682264191763, 0.11133762888078179, 0.19208285505218164, 0.13262547765459332], [0.037057345267385244, 0.04154148465022445, 0.05402730930862682, 0.010794682993686624, 0.09565595178199665, 0.01708509447053075, 0.04023520295907344, 0.046043890195765665, 0.03945714381656476, 0.008816878095136156, 0.015056860001225556, 0.013637547098499323, 0.03489462685372148, 0.01024484571202525, 0.0678702209677015, 0.029382259252348115, 0.026683011325076222, 0.037546979529517036, 0.05979431074644838, 0.02601324297886874, 0.04227447549679449, 0.0032772386870679577, 0.026108146279252002, 0.11826399900019169, 0.017233866666044508, 0.03148714951904757, 0.031215844077191184, 0.04983056682561125, 0.0058920405988049296, 0.036228073694344075, 0.026738856453448534, 0.04069635910647256, 0.022055996216035316, 0.02086754043453506, 0.04405004557754312, 0.019878836880837168, 0.010546934591340167, 0.07253566490752356, 0.036536335545991144, 0.03807770247970309, 0.04253616609743663, 0.05442896132756557, 1.2274303308555057, 9.108199851853506, 17.991314547402517, 23.812833206994192, 18.72994453566415, 14.467460938862391, 9.197347845349993, 14.351265345300947, 21.522137199129375, 16.080123935426982, 15.58028268814087, 6.81648940699441, 1.3474860829966409, 0.04528167823861752, 0.35261909716895645, 0.7782191410660744, 4.322248526981898, 2.791452463184084, 6.176934216703687, 4.384896091052464, 1.4072780460119247, 1.013507455587387, 0.4480779820254871, 1.452573026929583, 0.7284355152930532, 0.7206614038773945, 1.1620373598166873, 2.777231671980449, 4.334083046231951, 6.704880927290235, 12.313023447990417, 20.402316876820155, 31.499501977648052, 42.01680605752127, 53.32912302017212, 53.897843497140066, 54.35599034173148, 51.98363562992641, 51.64737408501761, 52.22723947252546, 50.440447671072825, 51.84911503110613, 51.50563778196062, 53.54726866313389, 54.161812509809224, 53.42168344770159, 51.182612555367605, 52.15565913064139, 50.8820195879255, 43.57550239562988, 50.71529408863613, 54.47479064123971, 53.37360886165074, 52.237394264766145, 52.604120186397004, 51.31114033290318, 50.08999443054199, 51.30514751161848, 51.76349237986973, 52.1254448890686, 49.49769524165562, 50.192737443106516, 49.88797903060913, 49.27752767290388, 49.337094579424175, 48.79035472869873, 47.71673992701939, 41.78270387649536, 28.301195791789464, 32.20077671323504, 23.481760229383195, 7.6405205726623535, 1.8966337016650607, 0.31195370640073505, 0.11173662104244743, 0.531932913831302, 0.6539822018572262, 1.2033913007804324, 1.9623300049986159, 2.2821325702326636, 2.469682037830353, 1.501887974994523, 3.0076213436467305, 2.021079195397241, 3.3724469329629625, 2.9737942559378485, 3.1718724157129015, 0.913203912121909, 3.2315960909639085, 9.527313453810555, 19.10283350944519, 17.462433304105485, 18.378341368266515, 17.041645186288015, 21.4535584790366, 23.493650334221975, 12.847220063209534, 3.4064681359699795, 0.3389412968286446, 0.04997713038963931, 0.024620941707066128, 0.014974757263969098, 0.014088230906054378, 0.061783632928771634, 0.03226973109745553, 0.010859302428018833, 0.06644153155918632, 0.01892345448556755, 0.05720316192933491, 0.02445446314024074, 0.025727671338245273, 0.029096612972872596, 0.06213909028364079, 0.029751409443893602, 0.03368727896096451, 0.04657620770324554, 0.0316368377368365, 0.011708896973037293, 0.02032734513548868, 0.020370862978909696, 0.056877994377698214, 0.07099527506423847, 0.02301763809685196, 0.019385492728490914, 0.01719494759371238, 0.02002550901046821, 0.03593068536637085, 0.05281060102528759, 0.09650629186736685, 0.07620427983679942, 0.05509190361148544, 0.09803701937198639, 0.05728147844118731, 0.023663423622825315, 0.02457514568232, 0.03398260793515614, 0.018436739620353495, 0.03094605855377657, 0.015476252318226864, 0.08268538170627185, 0.08366144754524742, 0.07534473203122616, 0.03483010156612311, 0.030690396736775125, 0.0461170668048518, 0.04622109640123589, 0.03636913773204599, 0.05237716981875045, 0.09539261912660939, 0.02841823740995356, 0.015925897119034613, 0.04371067289529102, 0.05728801951876708, 0.03621267094942076, 0.03891335906726973, 0.03286999370902777, 0.028556628019682, 0.04844783798658422, 0.005806225850912077, 0.015448430686124733, 0.03668173881513732, 0.0671131048085434, 0.0231574587191322, 0.023122359798955064, 0.04421063446040664, 0.07937527753944908, 0.04068299535928028, 0.07418816909193993, 0.05608711092333708, 0.03178470069542527, 0.05708846915513277, 0.05276007391512394, 0.02897188805841974, 0.049667433436427794, 0.04890503827482462, 0.06427538315100328, 2.3181783046041216, 13.856640458106995, 25.686163084847585, 28.660810232162476, 23.852896520069667, 16.415536063058035, 7.129542665822165, 15.740117311477661, 29.693196160452707, 25.29942808832441, 17.401579243796213, 6.0630093812942505, 1.2332039581877845, 0.07093226630240679, 0.5578755874718938, 0.8727834182126182, 2.8154033379895345, 3.455106394631522, 3.882046273776463, 4.146335772105625, 5.330115565231868, 4.610230079718998, 3.332684563738959, 4.2913307803017755, 1.6863006566252028, 1.381317404764039, 2.2941974656922475, 4.0547250764710565, 5.341230511665344, 8.37406621660505, 14.31668416091374, 23.918053252356394, 35.35290690830776, 45.20394822529384, 53.84049654006958, 54.70551947184971, 54.14523410797119, 52.031873498644146, 51.53213126318795, 52.61499759129116, 52.08796283176967, 52.96656601769583, 52.748416900634766, 55.77691432407924, 53.513434410095215, 54.08789757319859, 51.754261698041645, 54.01148475919451, 50.10394293921334, 43.626012325286865, 50.01692370006016, 54.89757810320173, 54.113741397857666, 53.197051661355154, 53.71068334579468, 52.24864687238421, 52.13480758666992, 52.54257999147688, 52.30815124511719, 52.48941584995815, 50.99647031511579, 50.513799803597585, 51.9126215662275, 49.1739821434021, 51.57003368650164, 50.487414019448416, 49.07530035291399, 44.81324407032558, 34.1713171005249, 37.65379244940621, 28.35381623676845, 10.30861232961927, 3.6330810274396623, 1.1215321847370692, 0.48380252506051746, 1.2145937510899134, 2.319171245609011, 1.9865268894604273, 3.0435255084718977, 5.160541304520198, 2.464657621724265, 3.9102976492473056, 3.527355717761176, 2.811707330601556, 2.6452308808054243, 0.515748279435294, 0.6199455825345856, 0.8331235892006329, 3.048859987940107, 9.649623462132045, 20.801742758069718, 17.261811017990112, 21.76929157120841, 23.424580029078893, 23.911025149481638, 27.680428096226283, 17.177972316741943, 5.631888423647199, 0.6985407280070441, 0.14944223527397427, 0.021281333141294972, 0.05370992116097893, 0.02089488030677395, 0.004718960420827248, 0.04918592802381941, 0.045765181936855824, 0.009517173731832631, 0.018976860280547823, 0.0207172873363431, 0.07834552600979805, 0.024053452336894612, 0.008564332450207855, 0.019492285658738444, 0.10383669566363096, 0.03110068989917636, 0.009586436890198715, 0.0348435128107667, 0.05779791822923081, 0.03738857213673847, 0.05034933059609362, 0.03700430418497749, 0.060452496499887536, 0.03807188743459327, 0.041957833737667115, 0.03351778769865632, 0.022373370792982832, 0.023487029963039925, 0.015943231992423534, 0.054355445450970104, 0.03729714972100087, 0.08183935031827007, 0.06938429043761321, 0.06542688421905041, 0.010953333810903132, 0.16936520407242434, 0.15611604787409306, 0.11504269471125943, 0.10823189267622572, 0.14319789462855884, 0.1603466458618641, 0.2402891447501523, 0.2026794957263129, 0.1508714064423527, 0.0626010097829359, 0.12741423371647084, 0.12400443239935807, 0.17761430357183727, 0.11489934740321976, 0.1339745952614716, 0.1153991020151547, 0.10984285016145025, 0.2778241549219404, 0.14537474353398594, 0.0829792959349496, 0.15025665371545724, 0.07926847612751381, 0.11883776821196079, 0.18881371404443467, 0.09254260241453137, 0.10232879407703876, 0.07626256599490132, 0.06898474187723228, 0.10244847408362798, 0.09955467829214674, 0.11227520821349961, 0.15193909486489637, 0.08890617040119, 0.12375762207167489, 0.1065505032560655, 0.17410943949861185, 0.22052090907735483, 0.1321864112147263, 0.10236052237451077, 0.14153605380228587, 0.1683215493602412, 0.1904406781707491, 2.7730206293719153, 15.923898901258196, 30.202103069850377, 37.55323811939785, 30.65238802773612, 24.3008816242218, 17.17349420275007, 20.01873115130833, 29.615369388035365, 23.527382101331437, 20.34760328701564, 8.82511373928615, 1.9667336429868425, 0.43196456666503635, 1.6868037496294295, 3.7013470785958424, 11.242020300456456, 12.564593400274005, 11.456337485994611, 11.173841970307485, 5.869548516614096, 3.1384980465684618, 1.2827947714499064, 4.4708257658141, 1.774858487503869, 1.3893652643476213, 2.039554238319397, 3.5778908346380507, 5.995016481195178, 7.656358991350446, 14.629142045974731, 22.399593932288035, 34.832500730242046, 45.49983378819057, 55.43927008765084, 55.890329769679475, 57.14002582005092, 53.47895744868687, 53.389085974012104, 53.65073776245117, 51.422950744628906, 53.4894631249564, 52.36889934539795, 56.676462854657856, 55.237268584115164, 56.00651754651751, 51.187757696424214, 54.66032838821411, 51.65295696258545, 47.99078035354614, 50.55907426561628, 55.04689141682216, 56.7743490764073, 54.578370911734446, 55.485135146549766, 54.33224139894758, 51.93332372392927, 53.307465485164094, 53.15518529074532, 54.85039288657052, 52.88444873264858, 54.015844753810335, 51.78230462755476, 52.10004922321865, 51.31891189302717, 50.293924059186665, 48.72614642551967, 48.772581236703054, 40.052456515175955, 40.44227824892317, 28.33019757270813, 9.899338245391846, 2.6078764966556003, 0.949755345072065, 0.1510918488992112, 1.6027594251292092, 2.803629615477153, 3.1730805337429047, 5.972023155008044, 7.187775952475412, 7.5601290464401245, 5.68088755437306, 8.931115456989833, 4.748470136097499, 8.389776962144033, 7.79726585320064, 5.2697087952068875, 1.793575631720679, 4.275564449174063, 12.239177993365697, 25.307540110179357, 25.505298001425608, 27.110338824135916, 29.306685243334087, 30.643421377454484, 33.275676931653706, 18.228640692574636, 4.888007768562861, 0.5482843049934932, 0.32088613137602806, 0.088669517742736, 0.07208370630230222, 0.08173994493803807, 0.1017816166526505, 0.17802983841725759, 0.19146565959921905, 0.2599988228508404, 0.12130146101117134, 0.15101374951856478, 0.20913975978536264, 0.0970483667084149, 0.06191855961722987, 0.0878641102463007, 0.12868880746620043, 0.10008001367428473, 0.08491512241640262, 0.10891603917947837, 0.15686367132834025, 0.08293513009058577, 0.09653559779482228, 0.1790317225136927, 0.12137615414602415, 0.08551296605063335, 0.10001047740557364, 0.2596243529447487, 0.08721505757421255, 0.18247379495629243, 0.2333125291126115, 0.4210336389286177, 0.18012637591787747, 0.18631798082164355, 0.16990603719438824, 0.1375262782509838, 0.14962721749075822], [0.01784568981799696, 0.042135579378477166, 0.04912552144378424, 0.010456624124864382, 0.015649502664538364, 0.044191615123833926, 0.021916731992470365, 0.03677190254841532, 0.03601943774681006, 0.025824973259919455, 0.03680837719834276, 0.06667618253933531, 0.06367038775767599, 0.0428618493356875, 0.05536212678998709, 0.048354539421520064, 0.03717031456264002, 0.0763270811044744, 0.061971627841038365, 0.010203908846181418, 0.019629626235525523, 0.05039829707571438, 0.009367072455851095, 0.025281795799466114, 0.05670402817694204, 0.029621778721255914, 0.049400202597358396, 0.03871119295113853, 0.030907273492110626, 0.05270300233470542, 0.03293614748067089, 0.038631587222750695, 0.047984822653234005, 0.05930940926607166, 0.06668338179588318, 0.048007685890687365, 0.06094558789793934, 0.004334791280728365, 0.051793636488063, 0.036853448886956484, 0.06965862214565277, 0.014612913198236908, 0.0172028949351183, 0.6674624128001077, 8.703950183732168, 18.516587938581193, 24.525751386369976, 18.75022632735116, 20.408196789877756, 11.613676837512426, 9.667142476354327, 15.323645762034825, 19.641695840018137, 20.258268560682023, 8.380627053124563, 1.8987116473061698, 0.4851354935339519, 0.5233536799039159, 0.8621170105678695, 1.4867340624332428, 1.5615369571106774, 1.759549000433513, 6.311147791998727, 8.070510710988726, 5.5606589657919745, 2.330044742141451, 0.40445276722311974, 0.42485631523387773, 0.5054848130260194, 0.9767470338514873, 0.7010707408189774, 1.5818496899945396, 2.6247352148805345, 7.3897340297698975, 13.034955177988325, 23.338450159345353, 37.1805054800851, 47.513220242091585, 51.7251626423427, 51.57913930075509, 51.18491588320051, 52.86566775185721, 51.76011902945382, 52.59578234808785, 54.55597339357649, 55.36665793827602, 55.52627543040684, 52.4124367577689, 51.83258874075753, 53.26598126547677, 53.16954026903425, 51.45283842086792, 51.43104192188808, 44.60531227929251, 46.563870498112266, 50.86752217156546, 51.095815658569336, 50.32334620612008, 51.18741723469326, 49.894423484802246, 53.03911215918404, 51.74854680470058, 52.039238589150564, 50.02230855396816, 51.03219100407192, 50.91067048481533, 49.80919688088553, 44.69338069643293, 38.86770180293492, 25.47641781398228, 25.16109640257699, 18.716049875531876, 6.326190641948155, 0.9508230877774102, 0.11234008294663259, 0.49771189583199366, 1.7865379750728607, 1.227761673075812, 1.5653898417949677, 1.2238137934889113, 2.195914762360709, 4.527271628379822, 1.2570180403334754, 2.9446522082601274, 2.0314804315567017, 4.120070712906974, 2.9562561341694424, 0.43152387174112455, 0.8581772191183907, 4.01945732321058, 9.462620513779775, 17.70332040105547, 18.00496428353446, 25.041486637932913, 22.35014533996582, 21.062925543103898, 23.645862783704484, 14.842507328305926, 4.208648519856589, 0.3392069297177451, 0.014071369310840964, 0.03218071748103414, 0.026527435119662966, 0.0740582567772695, 0.04408912240926709, 0.0049506211819659385, 0.0377788858355156, 0.0229786121552544, 0.018333909334614873, 0.051910347903945615, 0.0655236772394606, 0.05500937339716724, 0.014369975609172667, 0.029136751711900746, 0.027823297905602624, 0.0329699317392494, 0.06073583236762455, 0.028886348541293825, 0.02137661981396377, 0.03965632437861391, 0.012593766009168965, 0.03276540092857821, 0.024903454851093035, 0.0661130120445575, 0.05838336502867086, 0.030842531073306288, 0.07751814076410872, 0.09221957224820342, 0.07176935459886279, 0.056095087102481296, 0.03531499286847455, 0.007842806300946643, 0.0467529389342027, 0.01571900161382343, 0.06319719779172114, 0.04019723892478006, 0.027777198236435652, 0.03973070199468306, 0.046715080072837215, 0.01627458947976785, 0.031367208276476176, 0.1375575451446431, 0.05384741610448275, 0.00693250195555655, 0.07994764896907977, 0.013755298369298024, 0.03792931704914995, 0.048046728795660396, 0.054502935215298615, 0.06335327441671065, 0.0547778572488044, 0.03144825589177864, 0.04020966290097151, 0.09302889489169631, 0.0276184821102236, 0.001992420118767768, 0.02523358249371605, 0.10433046559670142, 0.031511895691177676, 0.014229666441679, 0.0105414452430393, 0.023628745394359742, 0.027926803333684802, 0.019843815992187177, 0.025287841546482275, 0.061256770842841694, 0.07423016362424407, 0.03189147496595979, 0.03909122005903295, 0.06108777491109712, 0.0427403576405985, 0.05761780110853059, 0.023846962256357074, 0.04355853855875986, 0.011839250335469842, 0.06660976074635983, 0.12137460708618164, 0.022712144668080976, 0.07523894842181887, 1.798919664961951, 12.472951003483363, 25.556334257125854, 29.97950710569109, 24.63833131108965, 22.707767384392874, 9.712258866855077, 14.24985464981624, 23.18163800239563, 28.82525324821472, 22.504115683691843, 8.494249207632881, 1.5265891466821944, 0.144118639507464, 0.2629373680268015, 0.564697687114988, 1.9111369805676597, 2.820704813514437, 4.513053008488246, 10.60207210268293, 15.494052069527761, 13.23799283163888, 4.997830126966749, 1.6197799061025893, 1.5963164908545358, 0.721974179148674, 1.7793097857918059, 1.1314346705164229, 2.295365197317941, 3.7197315778051103, 10.099090269633702, 16.58157890183585, 27.801840918404714, 41.09228570120675, 50.758209637233186, 52.398780073438374, 53.43839386531285, 53.18077203205654, 53.6010616166251, 52.112642833164756, 53.5139034135001, 54.595946380070274, 55.72660936628069, 57.05015434537615, 54.37843302318028, 53.02917276109968, 54.3123973437718, 53.45622641699654, 50.67832619803292, 50.72136334010533, 46.2918381009783, 51.718082427978516, 52.28175851276943, 52.628438881465364, 50.86023003714425, 52.005324431828086, 52.28552096230643, 54.45129183360508, 53.78530699866158, 53.3008508001055, 51.58162328175136, 52.33830990110125, 52.690892764500205, 50.657940183367046, 47.16259329659598, 41.76151534489223, 32.009496280125205, 28.94365402630397, 23.20564923967634, 9.614519425800868, 1.642031837786947, 0.6821937880345753, 1.297893749816077, 2.074569902249745, 2.7182141074112485, 2.6310014043535506, 3.151329198053905, 3.7893273404666354, 4.48223123380116, 3.087097010442189, 3.3170973658561707, 2.840502619743347, 1.9246850992952074, 1.3094730313335146, 0.45641164055892397, 0.6904632842966488, 2.7399928016321997, 10.900114212717328, 18.567806584494456, 24.776114089148386, 27.453241109848022, 25.58996527535575, 23.859311444418772, 28.03774615696498, 19.38788856778826, 6.587815071855273, 0.5716030565755708, 0.05658188508823514, 0.04869170007961137, 0.0506830884010664, 0.009857295347111565, 0.019894580589607358, 0.04710694422413196, 0.05898740368762186, 0.020976771001837084, 0.03704285515206201, 0.06897013980363097, 0.009261729894205928, 0.02328832776817892, 0.09445329595889364, 0.00920220710603254, 0.017265079276902334, 0.0219477155977594, 0.020494855075542415, 0.03699101507663727, 0.027979072582508837, 0.02625449949742428, 0.05995753913053444, 0.03177584581343191, 0.0920562149424638, 0.08692486171743699, 0.03325780361358609, 0.04624044821996774, 0.017579766855176007, 0.04519437453044312, 0.038146322726139, 0.012192548252642155, 0.010512593085877597, 0.06157278495707682, 0.03375238439600382, 0.024731023835816553, 0.0842703173735312, 0.05413926758670381, 0.15346787497401237, 0.08992999832012824, 0.10780968783157212, 0.08810859998422009, 0.08690863794514112, 0.2156475077250174, 0.09301569060023342, 0.1459671181759664, 0.1576181479862758, 0.07743229251354933, 0.09189888981303998, 0.13108257044638905, 0.1619933553572212, 0.18979518780750887, 0.13085076931331838, 0.110411476077778, 0.11240065576774733, 0.24101205595902034, 0.1791474941585745, 0.12809147951858385, 0.1423946177320821, 0.1278715527483395, 0.11212344028587852, 0.2524063145475728, 0.10625208355486393, 0.16121127589472703, 0.11578582626368318, 0.1409445476851293, 0.20615101658872195, 0.11110404998596225, 0.1497201089348112, 0.12258873693645, 0.16509056916194303, 0.16910886711307935, 0.098280898428389, 0.18620458404932702, 0.10881723091006279, 0.10986902125711952, 0.12127159189965044, 0.21341119201055594, 0.19107282853552274, 0.07346100346850497, 0.22580626261021408, 1.643100883279528, 13.838268552507673, 29.696208204541886, 36.84041895185198, 29.727284022739955, 31.836430549621582, 19.8057792867933, 16.199966464723857, 21.63630305017744, 25.943203006471904, 24.724247523716517, 11.073120883532933, 2.8999253511428833, 0.8739317165953773, 1.447814705116408, 3.312751267637525, 4.495246512549264, 6.1284909418651035, 8.335632256099156, 10.455608419009618, 12.552220395633153, 10.886042373520986, 6.176662368433816, 1.9220595487526484, 2.160326523440225, 1.037722796201706, 1.9074572580201286, 1.059491285255977, 2.1645369146551405, 3.5852993513856615, 9.039664558001927, 15.979948282241821, 26.56752817971366, 40.922694069998606, 50.94107927594866, 53.77167115892683, 53.45648350034441, 52.94212225505284, 54.743227345602854, 53.553584575653076, 54.434313910348074, 55.62369959694998, 57.4707670211792, 57.94018036978585, 54.32422317777361, 53.43842165810721, 54.01612615585327, 54.364185741969514, 53.48237943649292, 53.17096812384469, 50.09501450402396, 52.92628731046404, 52.09426832199097, 53.240022795540945, 51.20822361537388, 54.002518108912874, 52.17012528010777, 56.22276633126395, 52.985340050288606, 53.67199925013951, 52.209104674203054, 54.186832972935264, 54.34054102216448, 52.65584257670811, 49.66483415876116, 42.663919585091726, 36.190981251852854, 28.714636189596995, 21.2973438671657, 9.877962112426758, 1.3352924287319183, 0.7322581101741109, 1.4312613819326674, 5.841129081589835, 4.218564902033124, 3.889962443283626, 5.491973417145865, 7.702146751540048, 11.674123559679304, 4.183093913963862, 6.479001070771899, 7.003914458411081, 10.204903517450605, 5.76068457535335, 2.211637232984815, 1.7802655973604746, 5.179226747580937, 12.214334709303719, 23.807321548461914, 27.68877809388297, 34.52336842673165, 31.662909712110245, 31.748299598693848, 32.075921058654785, 20.23489829472133, 6.144297659397125, 0.5457013121673039, 0.1857234484383038, 0.12452307742621217, 0.12590547039040498, 0.14898811892739364, 0.17504819269691194, 0.09173933230340481, 0.1288931957845177, 0.12264471607548849, 0.2014872282743454, 0.2017995443727289, 0.10558361121054206, 0.1055461900042636, 0.12645663081535272, 0.10756017693451472, 0.10361150346164193, 0.0982593142294458, 0.18046573842210428, 0.10233390344572918, 0.1216674085174288, 0.15390859703932488, 0.15510766341217927, 0.11765616733048644, 0.139862718592797, 0.17981012431638582, 0.119301438331604, 0.13204927928745747, 0.13298548119408743, 0.1438035142741033, 0.1265900715121201, 0.20665991785270826, 0.17314149572380952, 0.11348087673208543, 0.1388453503272363, 0.11481204708772046, 0.18818418282483304, 0.1522398894386632], [0.08849351932959897, 0.03210583096370101, 0.04050920218495386, 0.038730422633567026, 0.03445848150710974, 0.0038301537611654824, 0.10330611520579883, 0.0411694540775248, 0.007532110204920173, 0.0712894539215735, 0.02580521601651396, 0.04481233556621841, 0.07406401753957782, 0.04617777533297028, 0.044293178245425224, 0.02936414915270039, 0.04291091759556106, 0.03900378064385482, 0.0350705302719559, 0.02863788598084024, 0.020374399842694402, 0.04292465114433851, 0.02946070468585406, 0.03244540720645871, 0.04575713790420975, 0.11549287555473191, 0.016671596926503947, 0.0249077906898622, 0.01681476951177631, 0.005186475289519876, 0.04137145055990134, 0.02344421440336321, 0.04429854545742273, 0.03839218649747116, 0.017112958511071544, 0.03220116174114602, 0.011521057275656079, 0.04461960447952151, 0.03546124769906912, 0.03349480911024979, 0.015910621599427292, 0.049081311494644196, 0.09502787262733493, 0.021266768387119685, 0.7436718834297997, 6.3144581743649075, 17.62235999107361, 25.034213611057826, 29.145476613725933, 18.13527774810791, 9.291889378002711, 10.114988616534642, 12.898084350994655, 16.17919656208583, 21.770262581961497, 12.706812603133065, 4.345075964927673, 0.6815601991755622, 0.8276002055832318, 1.549642183950969, 1.7737012867416655, 2.7789385403905595, 8.313120092664446, 20.36173071180071, 20.513092006955826, 6.895463934966496, 2.535877960068839, 1.3936740159988403, 1.3260651124375207, 1.4682077765464783, 0.2292161589222295, 0.4851565552609307, 0.39301920788628714, 1.6427175381353922, 2.096291273832321, 8.108829157693044, 19.066596916743688, 33.532656056540354, 45.09251649039132, 49.97557149614607, 52.15988710948399, 53.573769092559814, 53.52304376874651, 54.057117053440635, 53.78702320371355, 53.441829749516074, 52.2749388558524, 52.01144232068743, 53.554251602717805, 51.811389786856516, 50.55971349988665, 51.42391654423305, 48.64226082393101, 50.05671255929129, 51.32181624003819, 57.61942720413208, 50.6987886428833, 52.979347229003906, 50.16470840999058, 55.4170879636492, 54.42952312741961, 54.8263521194458, 51.69596631186349, 51.957989828927175, 49.46003600529262, 48.825106143951416, 43.37519972664969, 36.2522782598223, 21.286680119378225, 17.95599685396467, 10.075548904282705, 1.429065534046718, 0.1498673510338579, 0.06417219833071743, 0.2080108132213354, 0.4739752752440316, 1.3253226322787148, 1.933945310967309, 2.713987431355885, 2.332558252981731, 1.7664168604782648, 2.0621076566832404, 1.8599765258175986, 2.1604198898587907, 1.9209358947617667, 1.0554289775235313, 0.7129685538155692, 1.1246218532323837, 3.129827780382974, 11.035123791013445, 18.638898815427506, 17.960388115474156, 16.698287793568202, 17.227175985063823, 24.053788048880442, 25.11188578605652, 13.941412823540823, 5.484696047646659, 0.3581172392836639, 0.03544103753353868, 0.05241632807467665, 0.027699460175686648, 0.06279171883527722, 0.009651328586707158, 0.0791142111910241, 0.020187249706525887, 0.049082434470100064, 0.051890015602111816, 0.0824029143633587, 0.04680563057107585, 0.07826309757573263, 0.03444064621414457, 0.06448183421577726, 0.018025345534884503, 0.046185246003525596, 0.06454130781016179, 0.03408281059403505, 0.10353351943194866, 0.013679213389488203, 0.0282235792838037, 0.04019113889496241, 0.056008580672953806, 0.008394722444271403, 0.046060561801173856, 0.05935352761298418, 0.030116152550492967, 0.0581756993862135, 0.05461858472387705, 0.02905340047020997, 0.13789142508591923, 0.03487010459814753, 0.0471910147129425, 0.047679797413625886, 0.03870029567873903, 0.01691730463478182, 0.10033346685980048, 0.040193618940455575, 0.04644823260605335, 0.06889398781848804, 0.04192347272432276, 0.02354583520043109, 0.02194266390454556, 0.05331718848486032, 0.01773643210929419, 0.026052233297377825, 0.020424570721973265, 0.07133360619523696, 0.046423958015761206, 0.03898738045245409, 0.015904689507026757, 0.012635087095467108, 0.029672017454036644, 0.06900900628949914, 0.06066360231488943, 0.044468148678008995, 0.03870052298797028, 0.00952184883811112, 0.007262216964071351, 0.05717465667320149, 0.03690011513286403, 0.09093722927251033, 0.05015126622415014, 0.01664587705662208, 0.022927153755777648, 0.050804749729910066, 0.01952296053059399, 0.014828117364751441, 0.006933032061039869, 0.027560596287782704, 0.02673595062723117, 0.007147760828956962, 0.030799362675419877, 0.03524606388860515, 0.08567040653101035, 0.041052800337118764, 0.04893801846940603, 0.06941922142037324, 0.053269287305218835, 0.0446723232577954, 0.007301711094831782, 1.798620023897716, 10.300484674317495, 24.086022479193552, 30.119940621512278, 33.27172340665545, 21.73288127354213, 8.443909508841378, 9.404037645884923, 17.178654977253505, 26.370777777263097, 28.040850264685496, 12.224094322749547, 3.800499175276075, 0.5158642274992806, 0.172957110617842, 0.1770959571003914, 0.4639211233173098, 4.197953070913043, 13.339155129023961, 13.949879203523908, 11.383113026618958, 8.378658975873675, 5.565686855997358, 2.6383552040372575, 2.509162787880216, 2.271655338151114, 1.5748098620346613, 0.8073704711028508, 0.9212784788438252, 2.656280905008316, 3.3061841343130385, 11.025172233581543, 22.013845579964773, 37.579182692936485, 46.03598458426339, 50.837676184517996, 51.01023122242519, 52.65354272297451, 53.87572043282645, 54.74368245261056, 55.53842088154384, 56.84608227866036, 54.781088079724995, 53.58397599628994, 53.851613657815115, 53.67601530892508, 52.86088391712734, 49.61954232624599, 50.3369334084647, 53.39104536601475, 52.87320307322911, 57.74663482393537, 52.2773950440543, 52.414899894169395, 51.843500886644634, 54.26762662615095, 55.20358371734619, 55.62903928756714, 52.14367348807198, 53.34475646700178, 50.40958377293178, 50.80697209494454, 45.56580693381173, 38.805306979588096, 26.086990765162877, 21.457584960120066, 12.816056524004255, 3.619732452290399, 0.34909554624131744, 0.06258116941899061, 0.8703204989433289, 1.9588906466960907, 3.6143697457654134, 4.559244632720947, 4.662143111228943, 2.6941564040524617, 3.981026836803981, 3.0205671404089247, 2.872205729995455, 3.866381994315556, 1.5461801354374205, 0.8300158445324216, 0.7884336986712047, 0.9352863729000092, 3.1851749590465, 12.111186964171273, 18.22982014928545, 21.85605893816267, 19.28143695422581, 22.773043973105295, 26.886724948883057, 28.96740644318717, 18.63541603088379, 7.702805961881365, 0.7187586831195014, 0.04478512291929551, 0.04052602306806615, 0.02145762841350266, 0.024118103153471435, 0.017952917010656426, 0.03236761316657066, 0.0183351256086358, 0.02835565273250852, 0.02448131107459111, 0.04748310028974499, 0.028257324526618634, 0.03889458400330373, 0.01669480960949191, 0.019957643634240543, 0.10122474296284573, 0.0210941372040127, 0.027653268904292157, 0.04290129936167172, 0.021562387435031787, 0.04896517683352743, 0.011939723560187434, 0.061033193554197035, 0.022312996443361044, 0.04042840902028339, 0.0594016628872071, 0.04276327516085335, 0.03375211298199637, 0.04702225626845445, 0.06700662230806691, 0.014759875401588423, 0.06385910870241267, 0.01112219997282539, 0.040660054090299776, 0.013298081965850932, 0.04309096007740923, 0.06537664548626967, 0.044913240508841615, 0.18482892215251923, 0.12105052519057478, 0.14159199222922325, 0.14952121675014496, 0.07814033702015877, 0.14336497709155083, 0.20158685078578337, 0.10974780776138816, 0.11642219711627279, 0.07140467595309019, 0.14993103833070823, 0.12825126094477518, 0.16933887691370078, 0.14769412550543035, 0.18966490908392838, 0.09559142988707338, 0.08638198620506696, 0.11730844527482986, 0.17121859533446177, 0.2157457053129162, 0.1426798738539219, 0.1300731681819473, 0.12623282282480172, 0.16658293908195837, 0.1905668042600155, 0.13951161743274756, 0.09433035898421492, 0.07152675118829523, 0.13586624232786043, 0.09267834334501199, 0.15645732384707245, 0.11095684859901667, 0.171945116349629, 0.11374125776014157, 0.10739737602749042, 0.1663711547319378, 0.12610257124262197, 0.2670384336795126, 0.10184464577053275, 0.1819788579429899, 0.16565091695104325, 0.15618509559759072, 0.140323688143066, 0.2111031280032226, 1.9730332706655775, 10.57505316393716, 27.310113430023193, 37.323787757328574, 41.895976884024485, 28.61820908955165, 17.81383149964469, 15.746608666011266, 19.37868741580418, 22.776439905166626, 28.64678876740592, 15.651284592492239, 5.098260257925306, 1.1139670078243529, 1.747706230197634, 3.8056912166731696, 6.744835240500314, 9.65449241229466, 14.696482249668666, 31.64533076967512, 35.37998056411743, 18.760969979422434, 4.665662808077676, 4.490763621670859, 3.8663524644715443, 3.804516536848886, 1.1195543365819114, 1.1774077521903175, 1.0766877510717936, 2.1242440938949585, 2.905050733259746, 10.29948239667075, 21.412930624825613, 36.569025788988384, 46.89730412619454, 51.50743041719709, 53.375905241285054, 53.60246862683977, 54.601803711482454, 53.58267320905413, 55.287743772779194, 54.97544656481062, 55.06187868118286, 54.876750877925325, 55.014537130083355, 54.01481294631958, 53.757107734680176, 50.859448364802766, 50.25355849947248, 53.10222612108503, 53.146117891584126, 57.91568796975272, 53.25452716009957, 52.94484942299979, 53.12606191635132, 55.419999258858816, 55.896770749773296, 55.34637614658901, 53.38464954921177, 53.876258918217246, 51.67237717764718, 50.196816035679404, 47.352702958243235, 37.752300534929546, 29.150461946214946, 21.635358095169067, 11.002822484288897, 2.7995330010141646, 0.48653343852077213, 0.24363163539341517, 1.238811371581895, 1.88144884790693, 4.959429170404162, 6.159991468702044, 6.651908295495169, 6.193456164428166, 6.560180349009378, 8.040695990834918, 6.216550673757281, 7.3065597500119885, 4.578932353428431, 2.8600235836846486, 1.952381270272391, 1.7770610664572035, 4.628587654658726, 13.648284826959882, 23.725725378308976, 25.282552650996617, 25.54603702681405, 26.911199978419713, 32.71148668016706, 33.46188170569283, 20.4488593850817, 7.959432465689523, 0.6926020266754287, 0.14494232673730167, 0.1862825612936701, 0.11404279193707875, 0.1866903608398778, 0.05896332926516022, 0.13688538835516997, 0.08786311958517347, 0.12719983022127831, 0.12051057416413512, 0.15383289967264446, 0.17101081434105123, 0.15634270571172237, 0.18946186426494802, 0.14527679021869386, 0.18478359601327352, 0.174296430179051, 0.11919877598328249, 0.11257403503571238, 0.19173137391252176, 0.1470000520348549, 0.11336429763053145, 0.08923121581652335, 0.1470245878611292, 0.14978067497057573, 0.1231871098279953, 0.1289428509771824, 0.07969649601727724, 0.191572121743645, 0.1662412831293685, 0.10864175496889011, 0.1327549692775522, 0.1297080892005137, 0.1609110241489751, 0.1511760958071266, 0.10794259927102498, 0.10913193545171193, 0.19317716918885708], [0.061607532735381804, 0.025420452734189372, 0.06223420732255493, 0.0508453973702022, 0.015320070520309466, 0.04849309966500316, 0.030728102927761416, 0.054368337616324425, 0.03393631488350885, 0.030513957275875976, 0.03595162834972143, 0.044880976168704886, 0.004374831208094422, 0.07461492690656867, 0.02001186367124319, 0.027354772867900983, 0.03267239074089697, 0.033917363400438, 0.02356883923390082, 0.1274286186588662, 0.06264035124331713, 0.08402061648666859, 0.04919631639495492, 0.030395498632320335, 0.02789956354536116, 0.06739458149032933, 0.024118535719545822, 0.05127160557146583, 0.028743605129420757, 0.007345735295010465, 0.04542140895500779, 0.012291176710277796, 0.0346378793806902, 0.06691343909395592, 0.05561712703534535, 0.048293813930026123, 0.05170667544007301, 0.030361008697322438, 0.02203290058033807, 0.0481753451084452, 0.029825183163796152, 0.030352574507040635, 0.008941539396931018, 0.08144367619284562, 0.010632190820095795, 0.5466575037155832, 5.671786717006138, 16.62581287111555, 27.009369339261735, 27.04112434387207, 25.736261333738053, 17.74202707835606, 14.810450077056885, 14.873643943241664, 15.592428139277867, 23.983196088245936, 15.484923873628889, 3.818494141101837, 1.1209887053285326, 0.24769872001239232, 0.4487132807927472, 2.6416362736906325, 18.769285236086162, 15.562788861138479, 11.80680809702192, 2.769504406622478, 3.022533046347754, 1.2935768557446343, 1.3518017828464508, 1.835238116128104, 2.097541949578694, 0.4755437767931393, 0.4304876130606447, 0.532223815364497, 0.6505138565387044, 2.0197390615940094, 5.628866391522544, 16.499836819512502, 25.432706696646555, 34.27134684153965, 40.401742458343506, 49.30705404281616, 54.26796013968331, 53.48578405380249, 56.30447367259434, 54.519175733838765, 54.54602009909493, 53.21025323867798, 53.946310656411306, 51.49116815839495, 46.79460627692086, 45.05818544115339, 44.17424256461007, 58.80671106066023, 48.6916937828064, 56.12943465369088, 54.503215721675325, 54.74842807224819, 51.45151478903634, 52.18756873267037, 53.35412263870239, 52.19986009597778, 55.21654558181763, 55.25002200262887, 49.079177447727744, 42.36058555330549, 27.460508925574167, 18.299604381833756, 9.026873792920794, 4.508649587631226, 0.2825748228601047, 0.5272935256361961, 0.2205802673207862, 0.19749698096088, 1.0309976999248778, 2.772884488105774, 2.2273729486124854, 3.6281330415180753, 3.1103784697396413, 2.907174059322902, 2.2526114114693234, 1.787258307848658, 2.9474167227745056, 2.023930128131594, 1.531133485691888, 1.1494575377021516, 1.2649849099772317, 4.466691587652479, 10.218628815242223, 14.449465104511805, 17.770155123301915, 13.394188335963658, 15.551154102597918, 20.847138813563756, 27.320047616958618, 16.067994117736816, 6.706626662186213, 0.6490983782070023, 0.05226381715121014, 0.0987524531249489, 0.015510835551789828, 0.01769718055480293, 0.026162824327392236, 0.06335440757019178, 0.05011175513001425, 0.04627005270283137, 0.03208945791370102, 0.02457894547842443, 0.02155239091786955, 0.0595771727551307, 0.029242352116853, 0.05231940273993781, 0.048465771667127094, 0.02494482682751758, 0.030304941348731518, 0.06793888192623854, 0.06388367845543794, 0.06402657793036529, 0.022351160645484924, 0.10231073147484235, 0.07225081590669495, 0.006243344471191189, 0.028544231184891293, 0.061914413768265925, 0.03396405678774629, 0.031064792004014765, 0.04644778477294104, 0.022055811315242733, 0.027666764965813075, 0.016343616847214953, 0.03445617448804634, 0.07944978746984686, 0.005919331701339355, 0.027738689677789807, 0.04951337545311876, 0.049657710029610565, 0.06693220058722155, 0.0555811070038804, 0.052959220550422154, 0.018561783446265117, 0.05246754389788423, 0.03761876514181495, 0.018553179622228657, 0.03955981295023646, 0.0311135718865054, 0.0734314736244934, 0.04266113528449621, 0.011091303728920008, 0.024856795390535678, 0.01315737415903381, 0.04090702387371233, 0.02559155212449176, 0.05682230700871774, 0.05230658860611064, 0.03667449206113815, 0.06469624449631997, 0.02268237224780023, 0.03065446830753769, 0.020254619752189944, 0.008076583667259132, 0.020477605019030825, 0.06512862058090312, 0.01788885991222092, 0.0942580746486783, 0.032720892424029965, 0.05024007288739085, 0.036294729581901004, 0.053797886440796513, 0.03497716046071478, 0.03493159344153745, 0.06306822864072663, 0.027250938350334764, 0.0165236474547003, 0.019110925229532377, 0.03578061716897147, 0.06197889495108809, 0.051513001189700196, 0.05666724479358111, 0.036758620225425274, 0.03426787762769631, 0.05015945274915014, 1.3772656278950828, 8.902863212994166, 22.611870084490093, 32.97019590650286, 31.671323980603898, 27.340140070234025, 15.798558609826223, 9.083406942231314, 11.67726240839277, 25.47747220311846, 32.446187087467735, 14.550294756889343, 3.6165011056831906, 0.5939714248691286, 0.06499254716826336, 0.1914554951446397, 1.7885581638131822, 4.6950706243515015, 5.4386733514922, 5.839861469609397, 3.6564169866698126, 7.647430556161063, 4.288729548454285, 1.6625465026923587, 2.363966064793723, 2.348427938563483, 1.961493615593229, 1.4378421945231301, 1.58855958708695, 0.8821185944335801, 2.6712427650179182, 7.936830844197955, 19.044506856373378, 29.276488372257777, 37.13210432870047, 45.066172395433696, 52.05951690673828, 53.490366390773225, 53.1821825163705, 56.38993304116385, 55.640361377171104, 55.298787934439524, 52.765224593026296, 55.625384535108296, 54.64741516113281, 51.85233899525234, 44.07278149468558, 47.03828654970442, 60.573033469063894, 52.46905067988804, 58.12160478319441, 54.69270004544939, 55.478138310568674, 51.45176145008632, 54.39889546803066, 54.98441668919155, 54.04178932734898, 54.703233514513286, 54.31916836329869, 49.74160133089338, 44.83168806348528, 32.789640017918174, 23.606489079339163, 12.257524711745125, 7.050482153892517, 1.9101677068642207, 1.0113484114408493, 0.6467206286532539, 0.9202390717608588, 2.1883375346660614, 3.1782217664378027, 5.091145736830575, 4.112653945173536, 4.388610771724156, 5.2909073148454935, 4.376003699643271, 2.5652788281440735, 3.4079652556351254, 1.8463172359125954, 0.7011690469724792, 0.27967017729367527, 0.9584688203675407, 3.9545724391937256, 11.782809019088745, 17.144153697150095, 22.95822388785226, 17.32504483631679, 19.45712215559823, 24.432186944144114, 30.454003061567033, 21.034596000398906, 8.953203780310494, 1.2854104425225938, 0.050224663357117345, 0.041051361842879226, 0.052565822909985266, 0.025741515148963248, 0.023150457934077297, 0.03944779699668288, 0.0466929462605289, 0.023444433230906725, 0.04969700738521559, 0.033919650063450844, 0.014010603107245905, 0.05761799109833581, 0.03099906910210848, 0.032404993660748005, 0.06955040938087872, 0.010908969495046352, 0.03681913197838834, 0.064514899227236, 0.012969907655912851, 0.051481157541275024, 0.048565109193857224, 0.07279026481722083, 0.04172263653682811, 0.04991440661251545, 0.018049413171995963, 0.09633173873381955, 0.042013955369059525, 0.027705992771578685, 0.028353035283674086, 0.05035559008164065, 0.017278332762154083, 0.04705313300447805, 0.05159109039232135, 0.05248964378344161, 0.02176000058118786, 0.03493253321253827, 0.030662329135728732, 0.03544628939458302, 0.27199127791183336, 0.1719815129680293, 0.14826959105474607, 0.13110019878617354, 0.2091464094285454, 0.11396514038954463, 0.1182858342570918, 0.12283140820051942, 0.13669020097170556, 0.24783222856266157, 0.12125058445547308, 0.08075699196862322, 0.11958761726106916, 0.2581455537251064, 0.1021079309284687, 0.17515413915472372, 0.10284790729305573, 0.16315165534615517, 0.09855983738920518, 0.22452548705041409, 0.1264176829052823, 0.10466708003410272, 0.15526208441172326, 0.16280200625104563, 0.07942924821483237, 0.14406779009316648, 0.14564066140779428, 0.15673450540219033, 0.11246504195566688, 0.12445799234722342, 0.11582539842597075, 0.12563951180449554, 0.12098678361092295, 0.15672316029667854, 0.15524513460695744, 0.1736353470810822, 0.13365106976458005, 0.08797385650021688, 0.1886135462139334, 0.15664354099759034, 0.14161823796374456, 0.1336771390799965, 0.1278107560106686, 0.19593394840402262, 0.21868095280868666, 1.272684816803251, 9.289246456963674, 24.80574815613883, 39.26397146497454, 38.936061654772075, 38.335077217647004, 27.474634613309586, 21.878479037966045, 21.543506383895874, 22.492319379534038, 31.898669038500103, 19.552326372691564, 5.319783593927111, 1.9087101050785609, 0.4994821665542466, 2.0798242603029524, 5.953824085848672, 28.061484677451, 26.997500079018728, 22.038087844848633, 8.60189938545227, 8.886633958135333, 5.84057800258909, 2.6178890679563795, 4.731388858386448, 5.317138501576014, 2.4305445722171237, 2.205848515033722, 2.0000107373510088, 1.5784241195235933, 3.4490013165133337, 6.736771421773093, 18.444526433944702, 27.992374420166016, 37.134268692561555, 42.525428090776714, 51.78516033717564, 54.03186729976109, 53.78931263514927, 57.54204511642456, 56.54823384966169, 56.762596198490684, 53.01566546303885, 55.19958850315639, 55.96859080450875, 51.951934473855154, 45.37988356181553, 48.42472662244524, 61.660634994506836, 52.93719250815255, 57.774281706128804, 56.231691292354036, 56.248961039951865, 52.45080818448748, 53.990275382995605, 55.39485720225743, 53.241499287741526, 53.86141061782837, 54.73830802100045, 49.374225752694265, 44.86937509264265, 32.62690625871931, 22.87496883528573, 11.672844222613744, 4.845040542738778, 1.3772619366645813, 0.9284024451460157, 0.516994124012334, 0.9298223746674401, 3.4616572431155612, 6.634503492287227, 7.260906611170087, 7.4076734100069315, 8.21924124445234, 6.325980458940778, 7.75186892918178, 5.515376252787454, 7.506884132112775, 5.937997392245701, 3.9252475670405795, 2.5221663415431976, 2.15529602766037, 6.186853638717106, 13.972655398505074, 20.666881697518484, 23.805952753339493, 20.369526590619767, 24.90922941480364, 29.258030482700892, 35.69872222627912, 23.055800914764404, 8.970238157681056, 1.115155692611422, 0.14867801485317095, 0.15490845910140447, 0.12613306460636003, 0.15984112370227063, 0.12480935135057994, 0.16907521177615437, 0.15780854491250856, 0.08058724964835814, 0.16571682984275476, 0.09422049059399537, 0.12955635519964354, 0.19544209193970474, 0.2646554186940193, 0.17684328423014709, 0.18793643611882413, 0.17813297574009213, 0.11259494069963694, 0.11233714489000184, 0.1523817711110626, 0.14567567381475652, 0.12852509053690092, 0.20778601456965717, 0.17064694315195084, 0.1282646552260433, 0.1489983783768756, 0.14572781244558947, 0.16835490614175797, 0.1400716666664396, 0.12126691000802176, 0.16249999031424522, 0.19243899094206945, 0.10308082800890718, 0.14183441922068596, 0.24983990511723927, 0.0950306003381099, 0.12064051362020628, 0.13328428087489946, 0.10324983751135212], [0.019637008696528416, 0.015099039434322288, 0.07514477454658065, 0.04410425034750785, 0.03544219782842057, 0.05093674514708774, 0.013780650982101048, 0.07871561257966928, 0.022072862900261368, 0.015773147011974027, 0.012305041725215102, 0.027911135960104208, 0.0048744051600806415, 0.05294537843604173, 0.029085695344422544, 0.04467220790684223, 0.0635050084175808, 0.03412879491224885, 0.03327614441514015, 0.029812514914997985, 0.01833491526278002, 0.0519624186812767, 0.04101478202002389, 0.012151289930833238, 0.044469627884349654, 0.035202451050281525, 0.04986344863261495, 0.034352060074784925, 0.01829487151865448, 0.020461878273636103, 0.056210845176662715, 0.0459015946170049, 0.04549260424183948, 0.05926617980003357, 0.021502116562000344, 0.054738264730466266, 0.0896708657965064, 0.013624045099796993, 0.03988687700725027, 0.04914442203672869, 0.12229976244270802, 0.054204176246587715, 0.039646760427526066, 0.04540359741076827, 0.02927500322195036, 0.07796283904463053, 0.17633203523499624, 3.1478774632726396, 12.45524091379983, 22.145310708454677, 27.992469957896642, 26.56220759664263, 22.31234019143241, 21.342866727284022, 17.08917781284877, 18.79093929699489, 32.38323293413435, 23.493582589285715, 10.496024353163582, 2.8927202863352637, 0.5014080117855753, 1.4676067573683602, 3.982897639274597, 2.3758985102176666, 2.029117609773363, 3.097428547484534, 13.05646766935076, 3.2846362505640303, 2.835288865225656, 1.2994015089103153, 2.0935428270271847, 1.0527887706245695, 0.8555388578346798, 1.7389377121414458, 0.6820176403437341, 0.37812007165380884, 0.6779056095651218, 2.2024417264120917, 6.858792211328234, 13.326221057346888, 21.412030833108084, 32.249997752053396, 43.622017111097065, 49.62142528806414, 52.5452480997358, 53.80532128470284, 56.21179859978812, 54.257683753967285, 57.238641602652415, 46.6768343108041, 32.808858735220774, 33.928776332310264, 31.05049201420375, 56.42042521068028, 47.842655181884766, 53.26940325328282, 57.62999888828823, 53.16897051674979, 51.790937764304026, 53.25830350603376, 53.65956892286028, 53.26934766769409, 49.60114697047642, 44.04899781090872, 35.10832336970738, 21.493276119232178, 12.684504543031965, 5.368966851915632, 1.3636946018253053, 0.35852786153554916, 0.38952285264219555, 1.3456257028239114, 1.2661654523440768, 0.9882395714521408, 2.530660731451852, 2.4290852333818163, 4.170165487698146, 3.261771031788417, 3.749164581298828, 3.9716320037841797, 3.8004574860845293, 1.4019567029816764, 1.0999416347060884, 2.5998513272830417, 0.695371860904353, 1.6548718916518348, 6.301967484610421, 12.138376133782522, 15.161631141390119, 16.39602552141462, 14.243553502219063, 17.58581941468375, 19.941986560821533, 24.938203402927943, 17.668582882199967, 6.190260861601148, 0.8665362820029259, 0.05991405860653945, 0.031773840742451806, 0.01003310377044337, 0.042673433731709204, 0.049054505968732495, 0.013363341767606991, 0.07728479935654572, 0.043185951587344916, 0.13875753432512283, 0.017063347423183065, 0.02458881985928331, 0.06894086780292646, 0.023736082848959734, 0.09191314583378178, 0.04479254609239953, 0.039603568280914, 0.030512461106159856, 0.054972067541841946, 0.020243498563234295, 0.016518824767055254, 0.05562165964926992, 0.03300415026023984, 0.026809215445869734, 0.054487074459237714, 0.041013397808585844, 0.030565078104180948, 0.06796406914613076, 0.00881009953029986, 0.04332218784838915, 0.05732240767351218, 0.06363688169845513, 0.051719045133462975, 0.024787008063867688, 0.019196508851434504, 0.06448416837624141, 0.0412519876845181, 0.019360361487737725, 0.04048668500036001, 0.011883495907698358, 0.021393394895962307, 0.05582894531211682, 0.03119852107816509, 0.03955508356115647, 0.0187951604769166, 0.03856124349736741, 0.05611197244642036, 0.043790689137365134, 0.029383399191179445, 0.03788296632202608, 0.031020191897239004, 0.06743376010230609, 0.0773876245532717, 0.06551913784018584, 0.019788815639913082, 0.017961748143924133, 0.02192808727600745, 0.037446050838168175, 0.026121949377868856, 0.013017173557143127, 0.03035686963370868, 0.034295205625572374, 0.02069703645871154, 0.044291515834629536, 0.03707468183711171, 0.01371835553020771, 0.025931387906894088, 0.0486246133223176, 0.01898925032998834, 0.014378090887995703, 0.043625374258096726, 0.021543027134612203, 0.12095418678862707, 0.056047810175056965, 0.04095281480944582, 0.07996859534510545, 0.03257490561476775, 0.03896230519083994, 0.00658233929425478, 0.024308744352310896, 0.08254337111221892, 0.025302397818969827, 0.029661880140858035, 0.029961473707641875, 0.004301109650571431, 0.037013868136065345, 0.6852169600980622, 6.295228600502014, 18.017846243722097, 29.908701487949916, 34.11257355553763, 30.492409229278564, 20.884579181671143, 16.401238407407487, 11.842012013707842, 25.93040442466736, 39.245280810764854, 25.2789135319846, 12.755604590688433, 2.928928869111197, 0.5103234191026006, 0.39515838452747887, 0.3929597410772528, 1.0101062038115092, 2.381166113274438, 2.923207027571542, 8.042264546666827, 3.6705383317811147, 3.995195516518184, 2.8371462055615018, 3.608200613941465, 1.6956058144569397, 2.3182117428098405, 2.895072034427098, 1.3752032071352005, 1.1175760541643416, 1.2028984129428864, 3.8695008669580733, 10.281643765313284, 16.733096531459264, 23.524548973355973, 34.712831905909944, 46.62173857007708, 51.690505027770996, 54.2586669240679, 56.30155542918614, 56.64658907481602, 52.79916306904384, 58.13569572993687, 51.08333669389997, 37.935896260397776, 38.0867486000061, 36.44981207166399, 57.76729529244559, 49.60029581614903, 55.67478622709002, 57.14334011077881, 53.255218505859375, 53.69289595740182, 52.20810413360596, 52.88331617627825, 54.81792048045567, 52.579280376434326, 46.8332382610866, 39.344754695892334, 24.92654606274196, 16.590620245252335, 7.289838910102844, 2.8765301150935034, 1.180978149175644, 1.0618510672024317, 3.525231088910784, 2.203169550214495, 2.374807208776474, 4.546279728412628, 3.8350495270320346, 5.235732104097094, 5.854501758302961, 4.220031406198229, 4.85865466935294, 2.322351566382817, 2.0417424866131375, 2.047355111156191, 0.6965360641479492, 0.33699951959507807, 1.053019146834101, 5.536529174872807, 13.012853826795306, 16.604056324277604, 21.98535101754325, 15.97997260093689, 18.110450097492762, 23.78830780301775, 28.759234939302715, 23.385531152997697, 9.32361832686833, 1.8516938388347626, 0.08628541031586272, 0.054556739649602344, 0.06407261653138058, 0.10001416863607508, 0.04345076684174793, 0.033387875383985896, 0.08177375633801733, 0.04054846900648304, 0.025817628118342588, 0.0633799069161926, 0.028467716183513403, 0.02605130709707737, 0.017676970389272486, 0.06737886661929743, 0.010003552722212459, 0.05369775842076965, 0.08772749400564603, 0.03459989499034626, 0.010413113914962326, 0.03453654017565506, 0.014584804885089397, 0.05894648124064718, 0.0553726101560252, 0.059034419379064014, 0.018040873808786273, 0.05170033113764865, 0.029655569765184606, 0.0807856736438615, 0.01929517462849617, 0.061116673717541356, 0.034910555463284254, 0.06647914954062019, 0.04716079954856208, 0.027258890780753324, 0.027439145304794823, 0.0050083089569982675, 0.01074709733282881, 0.00983691300332014, 0.02137307107581624, 0.26558721012302805, 0.13279684845890316, 0.08582010492682457, 0.11528884007462434, 0.1422043429421527, 0.17789590917527676, 0.08490183670073748, 0.14395334837692125, 0.1455611778157098, 0.16132984310388565, 0.13719368752624306, 0.15604773296841554, 0.10525440637554441, 0.10443336543227945, 0.10475448212985482, 0.18436035301004136, 0.11090685413884264, 0.17941293705786976, 0.13467757111149176, 0.11872760126633303, 0.10680190048047475, 0.16098140180110931, 0.14947698983762944, 0.1832712228809084, 0.11368080707533018, 0.10561124115650143, 0.12122670002281666, 0.21657567577702658, 0.08147200502987419, 0.11243034846016339, 0.1210945485425847, 0.14092725861285413, 0.23221373664481298, 0.12369120706404958, 0.12370252502816063, 0.17812625824340753, 0.13159554292048725, 0.12496877993856158, 0.13505076537174837, 0.11613134986587934, 0.30869776968445095, 0.2307852032993521, 0.11374604821737323, 0.1443414839782885, 0.08656367752701044, 0.21728998316185816, 0.7048457296831268, 6.1441278627940585, 19.779565470559255, 32.99612658364432, 39.52324002129691, 38.656879561288015, 32.901248931884766, 31.761191981179373, 23.324805634362356, 25.541505064283097, 39.40212597165789, 28.191193648747035, 13.23928780215127, 3.4891169582094466, 0.7240795918873378, 2.170384692294257, 6.7957651019096375, 6.01503597838538, 6.761384981019156, 10.160954424313136, 23.298042910439626, 11.377181002071925, 7.3851317167282104, 4.486075758934021, 5.766197536672864, 3.8448855706623624, 2.12958009328161, 3.28523878966059, 1.5204646353210722, 1.0844314098358154, 1.0712630535875047, 2.8915212878159116, 8.693403686795916, 14.626043149403163, 23.895339591162546, 35.67227390834263, 46.61235850197928, 50.54378475461687, 53.3721011025565, 54.41902787344796, 55.950226715632844, 53.83603579657418, 58.964956283569336, 51.35007456370762, 39.757231031145366, 41.32055139541626, 39.77861411230904, 59.4029220853533, 54.995415687561035, 55.98511709485735, 55.67601605824062, 53.29874897003174, 54.00467552457537, 53.61713627406529, 53.22115843636649, 56.02592386518206, 52.74376508167812, 45.50927986417498, 37.358108384268625, 23.731461116245814, 15.762370654514857, 7.176554611751011, 1.8590413417134966, 0.8906700898494039, 1.582453640443938, 3.8820831860814775, 3.3159943393298557, 3.0857887949262346, 6.735354423522949, 7.442078283854893, 10.199600304876055, 8.106148021561758, 7.509583507265363, 11.22596561908722, 8.679279736110143, 6.847094050475529, 5.279599990163531, 4.252459951809474, 1.3742343676941735, 2.4963642060756683, 8.046674915722438, 15.509216512952532, 19.971737010138376, 23.356981004987443, 21.039299930844987, 24.997971807207378, 29.79789161682129, 34.17783103670393, 25.3736435345241, 9.26015521798815, 1.5657902317387717, 0.1618422456085682, 0.11567704352949347, 0.10120182204991579, 0.12788042798638344, 0.18009099710200513, 0.1123055862262845, 0.22220290239368165, 0.10223784324313913, 0.1827311497181654, 0.1552723167198045, 0.19104027242532798, 0.1764429621398449, 0.10273523655320917, 0.2324260366814477, 0.15841435454785824, 0.10836230032145977, 0.22833968166794094, 0.18659056190933498, 0.13926380287323678, 0.1018579179154975, 0.16212425833301886, 0.15044371224939823, 0.10797797130154711, 0.1294014456548861, 0.14130985736846924, 0.14995743334293365, 0.21282579270856722, 0.14445326583726065, 0.11562015515352998, 0.3069281774972166, 0.1753752872880016, 0.10175830897475992, 0.11007199143724782, 0.06266201008111238, 0.12627624906599522, 0.11265011916735343, 0.10060386306473187, 0.14672505536249705, 0.11216349420802933], [0.08981366349118096, 0.10979140363633633, 0.07438078482768365, 0.04712185842384185, 0.07240027681525264, 0.025396807485127022, 0.08836658578366041, 0.03398819567103471, 0.046075296189103804, 0.03768834551530225, 0.07738497826669898, 0.11435099611324923, 0.04396864173135587, 0.0051652549549804205, 0.05968904282365527, 0.03437346446194819, 0.05093177148540105, 0.03686174737023456, 0.059380119400365014, 0.05782723094203642, 0.042248942224042754, 0.03519441719566073, 0.03114641298140798, 0.020795228957597698, 0.023529005835631063, 0.07191757378833634, 0.009282634709961712, 0.025628213371549333, 0.05196373164653778, 0.016045516057472144, 0.0943803738004395, 0.055276536382734776, 0.08167774363287858, 0.019547162178371633, 0.02472906626228775, 0.06375956082982676, 0.023650460211294036, 0.06363093773169176, 0.04727017939356821, 0.04878475097939372, 0.04481421850089516, 0.07666385160492999, 0.0365266732073256, 0.05725209787487984, 0.061328885544623644, 0.09395256425653185, 0.04262357837121401, 0.15780030749738216, 1.9315490509782518, 7.592682225363595, 19.00160867827279, 25.684948887143815, 27.947072165352957, 28.98496801512582, 29.023469720567974, 15.716121707643781, 9.872083067893982, 14.473804644175939, 14.637370450156075, 7.33340585231781, 2.2063704984528676, 0.6879804975220135, 0.47980253398418427, 0.9753490345818656, 2.4196363346917287, 1.412165343761444, 2.774641296693257, 2.6631915399006436, 2.210310127053942, 1.5082979053258896, 2.1048601397446225, 1.2165748562131609, 2.2458549397332326, 2.2149421870708466, 0.8206361564142364, 0.9266850458724158, 0.2521920603300844, 0.17363418000085012, 0.38013236224651337, 0.8783751438770975, 3.6829955833298818, 11.635444675173078, 21.508951255253383, 29.311969348362513, 41.422780241285054, 45.24020739964077, 49.70529351915632, 47.18619980130877, 48.71475485392979, 45.17690931047712, 30.677971294948033, 26.849727528435842, 26.218558379581996, 45.82941811425345, 57.050894328526084, 46.60940204347883, 48.02559430258614, 55.54067209788731, 52.855752672467915, 52.21955476488386, 48.27462468828474, 44.080031939915244, 36.22010462624686, 22.39056474821908, 12.784961598260061, 4.944656865937369, 1.0334259867668152, 0.42863111410822186, 0.43049705826810425, 1.4173674817596162, 1.1331771484443118, 3.451146138565881, 2.394282792295728, 1.6834066233464648, 2.4206003972462247, 2.3126833651747023, 4.53835574218205, 4.661511259419577, 3.660007034029279, 4.9791703053883145, 1.4096842940364565, 1.3597792919192995, 1.9166825115680695, 0.5841941152300153, 2.684037221329553, 6.910906306334904, 15.12908056804112, 14.291100025177002, 12.66548558643886, 9.04822473866599, 15.891490765980311, 19.566010849816458, 24.18640657833644, 19.315368482044764, 7.343122908047267, 1.2236494251659937, 0.03307925730145403, 0.010826984653249383, 0.037314014708889384, 0.011916909516522927, 0.021457876078784466, 0.0477244212691273, 0.030698172748088837, 0.03338599244930914, 0.06816448124923877, 0.05161179249574031, 0.14552586685333932, 0.04657033498265913, 0.06542881804385356, 0.023156834466915046, 0.046676919263388426, 0.01814323760169957, 0.06143820432147809, 0.028652779824499573, 0.0715824453426259, 0.03746622707694769, 0.02626460966920214, 0.0675654908908265, 0.028035435093832866, 0.061562247308237214, 0.006607466294164104, 0.03195370001984494, 0.13085721539599554, 0.02743201220541128, 0.002561105618951842, 0.059083375680659495, 0.06833396572619677, 0.005724969162006995, 0.0099249266287578, 0.032351206189819744, 0.06069869614605393, 0.11205929158521549, 0.05780684096472604, 0.012789160345814057, 0.036838785745203495, 0.03245838079601526, 0.03247837383033974, 0.042996070347726345, 0.03048557076337082, 0.029895170658294643, 0.02001361598792885, 0.03266938143808927, 0.007419835559890738, 0.07830231011446033, 0.03743401362693735, 0.02392431694482054, 0.02773137337395123, 0.036108179949223995, 0.02264000621757337, 0.008295831054316034, 0.07503916057092802, 0.06083022337406874, 0.0356954067413296, 0.027416205732151866, 0.04360567299383027, 0.09688899240323476, 0.08827153659824814, 0.01532054040580988, 0.057536634749599865, 0.035316621352519305, 0.011316171082268869, 0.02460138632782868, 0.047563564364931414, 0.026014386310375164, 0.025988277979195118, 0.012181979221557932, 0.07755166039402996, 0.012329445237160792, 0.01633389344039772, 0.1039511373798762, 0.0036185517674311996, 0.0645654975835766, 0.006993089195540441, 0.05939666208411966, 0.05777140108070203, 0.06512131954410247, 0.01950789874951754, 0.05639686555202518, 0.04028177760275347, 0.06054160850388663, 0.026646784340430583, 0.07308246913765158, 0.035439453154270134, 0.38701238163879936, 3.988662907055446, 12.650315063340322, 25.880469458443777, 31.41773557662964, 32.79249572753906, 32.27878761291504, 24.68862932068961, 12.259593537875585, 19.20576238632202, 25.211218970162527, 20.442668540137156, 8.746711134910583, 4.973401129245758, 1.2430745256798608, 0.28240480912583216, 0.10453390396599259, 1.9015695282391138, 0.8622742135609899, 2.843033501080104, 3.347418870244707, 5.149276103292193, 4.605412806783404, 3.2446558816092352, 3.018394308430808, 2.9395075014659335, 4.754461220332554, 2.2983103649956838, 1.5577526858874728, 1.2243390338761466, 0.8035160122173173, 1.1840685776301791, 2.892412828547614, 7.867118699210031, 16.213635308401926, 23.853059802736553, 33.40423597608294, 41.85716424669538, 46.74465915134975, 51.21623488834926, 49.032631465366904, 52.084790979112896, 50.57273094994681, 33.070882252284456, 30.095114707946777, 30.0870270047869, 54.15862676075527, 58.35858004433768, 51.1203601700919, 52.979507037571494, 57.57870033809117, 53.27376324789864, 53.88461760112217, 51.135277952466694, 47.28142138889858, 38.412907464163645, 27.695467472076416, 17.551575217928203, 8.100850888660975, 3.0159841520445685, 1.657741931932313, 0.9598908126354218, 1.9821703689438956, 2.1976081686360494, 4.656028262206486, 3.4337741221700395, 3.8130215661866322, 4.0344502329826355, 4.763082197734287, 5.374210136277335, 4.605336376598903, 4.151428367410388, 2.5952520540782382, 1.870881940637316, 0.605966295514788, 0.1599154504282134, 0.4468934770141329, 2.6425553900854926, 8.094681756837026, 17.03440342630659, 20.378757272447857, 18.39519248689924, 11.732858419418335, 16.536075149263652, 23.353607654571533, 27.848357370921544, 23.33258240563529, 10.07133742741176, 2.261756326471056, 0.10622424326304879, 0.015038724456514631, 0.037473738459604125, 0.047808468009212186, 0.011763619974122515, 0.09639947009938103, 0.052125256907727034, 0.028661363292485476, 0.05587462089689715, 0.024361373224694814, 0.06269525151167597, 0.05976118466683796, 0.05767217890492507, 0.03294948408646243, 0.04760347240205322, 0.019388184816177403, 0.046395914163440466, 0.012860568523007845, 0.14173517668885843, 0.058683881403080056, 0.030988524667918682, 0.028262335507731353, 0.035699342244437764, 0.07056003556187664, 0.03652849507385066, 0.09109070710837841, 0.011542873872843171, 0.037828137299844196, 0.04616503583799515, 0.02515154760996146, 0.06134069883929832, 0.008525403199850448, 0.05591228298310723, 0.04934716830030084, 0.02074487996287644, 0.04172596135841949, 0.083272979461721, 0.00957421732268163, 0.03460115706548095, 0.03800566580944827, 0.12132567114063672, 0.1910181250423193, 0.10979826362537486, 0.12850031043801988, 0.255811474685158, 0.11451510659285954, 0.18527367471584252, 0.12232936014022146, 0.13006408938339778, 0.13434195412056787, 0.16749217600694724, 0.1987602367464985, 0.16930682291941984, 0.13213795024369443, 0.19609750248491764, 0.12008563482335635, 0.17831752369446413, 0.05568282279585089, 0.14437015886817658, 0.22429540939629078, 0.18861693888902664, 0.16013640857168607, 0.08170757881764855, 0.11775722833616392, 0.27021481895021027, 0.13652264353420052, 0.1168454536902053, 0.1348704650465931, 0.17287245658891542, 0.12966355016188963, 0.19663450866937637, 0.17795556597411633, 0.14308444357344083, 0.1671727081494672, 0.14834717474877834, 0.16832856541233404, 0.2461550799863679, 0.17221905450735772, 0.15289166303617613, 0.11505227562572275, 0.18494709581136703, 0.17575428980801786, 0.12914653361908027, 0.1598016872469868, 0.22538292461207934, 0.14409301802515984, 0.14603377745619842, 0.3693783421601568, 3.776392834527152, 12.874395336423602, 29.447917801993235, 38.066536290305, 40.56493132455008, 40.42688798904419, 38.84733315876552, 23.61245584487915, 15.231168712888445, 21.214047125407628, 21.821564606257848, 10.22279165472303, 3.5157973894051144, 1.218618386558124, 1.0156219878367014, 2.964506902865001, 6.805579432419368, 4.815409515585218, 9.162889991487775, 10.920597502163478, 7.965350593839373, 5.672780743667057, 6.515057010310037, 3.7385607617241994, 6.990127061094556, 5.994689915861402, 3.062160359961646, 1.8491405929837907, 1.1312356697661536, 0.7642725322927747, 1.011364913412503, 2.073440602847508, 5.936151342732566, 12.668345638683864, 23.351061139787944, 32.140396867479595, 42.338559763772146, 46.746719292231965, 52.13933086395264, 48.19872604097639, 51.77287244796753, 53.55281679970877, 39.1359543800354, 35.86914069311959, 34.45329931804112, 58.044316496167866, 62.411443437848774, 55.069514751434326, 57.053638866969514, 58.02448981148856, 54.99179220199585, 54.590057781764436, 49.42956468037197, 45.38622031893049, 37.38229853766305, 25.628442662102835, 14.860086270741053, 6.127479978970118, 1.989462069102696, 0.995419014777456, 0.8970244345920426, 3.3241975562913075, 2.504855773278645, 6.895680197647639, 6.444623989718301, 4.293246311800821, 6.569494843482971, 6.672032015664237, 10.342008846146719, 11.689066529273987, 10.200842295374189, 10.774020910263062, 4.937587942395892, 3.2436357992036, 3.5825743547507694, 1.1723911528076445, 3.59439280629158, 8.930095808846609, 19.63501862117222, 22.088861806052073, 20.5677604334695, 15.402122191020421, 23.650217567171367, 28.67467188835144, 33.811212812151226, 25.750916821616038, 10.515315158026558, 2.066511946065085, 0.17171194457582065, 0.1187105971787657, 0.10305599362722465, 0.1392705746527229, 0.07969464361667633, 0.14254247051264557, 0.1159956157207489, 0.06002178282610007, 0.1927188052130597, 0.18461956695786544, 0.26627752450960024, 0.13808757598911012, 0.12100910741303648, 0.10633422021887132, 0.15653749954487595, 0.10383269909237113, 0.10929454636893102, 0.11792580357619695, 0.2993720386709486, 0.14310602098703384, 0.11226155608892441, 0.1370015535503626, 0.14062647760978766, 0.28493729180523325, 0.13127238383250578, 0.20567269011267594, 0.22661537490785122, 0.12134171170847756, 0.13273276761174202, 0.14315722323954105, 0.25272357038089205, 0.08908784136708293, 0.08836946955748967, 0.09099506759749991, 0.13852444397551672, 0.2066081999135869, 0.18611777227904114, 0.07670906239322253, 0.11349176721913473, 0.0967766134334462], [0.05640947951802185, 0.11152394102620226, 0.021164350311404893, 0.008309296581761112, 0.03894869038569076, 0.015873626173873032, 0.010995749034918845, 0.01593454335150974, 0.026515190955251455, 0.030237644245581966, 0.05498605554125138, 0.04964387809325542, 0.0668607372790575, 0.03560538550040551, 0.04191156782742057, 0.007150622550398111, 0.04330571980348655, 0.016118594278980578, 0.027786127757281065, 0.02882417437753507, 0.03889955427231533, 0.03076791936265571, 0.016361864350203956, 0.04368338221684098, 0.029879764520696232, 0.10084044108433382, 0.029186447616666555, 0.06574795341917447, 0.025831037666648626, 0.046939610703183074, 0.017476342851296067, 0.05871761816420725, 0.08729396441153117, 0.0031348269091852543, 0.030678155965038707, 0.03213266023833837, 0.013583086181565054, 0.036453333749834976, 0.06362021009304694, 0.05490979838318058, 0.08682498814804213, 0.03337606208931122, 0.04093145452705877, 0.04282946625192251, 0.04060025479910629, 0.06477065264646496, 0.06538408223007407, 0.022607923385554125, 0.058838139554219585, 1.0296044775417872, 5.767754801682063, 15.872214726039342, 30.625449861798966, 32.96592276436942, 36.38260909489223, 31.67120933532715, 23.659149476460048, 44.58832393373762, 61.250184059143066, 30.93236221585955, 10.538743615150452, 3.588168740272522, 1.87797583426748, 0.1269844632063593, 0.5189030330095972, 0.5535488682133811, 2.4886219586644853, 1.016374130334173, 4.536733337811061, 4.311262122222355, 2.4959627304758345, 1.9890484341553278, 2.8176899467195784, 6.131920746394566, 1.9883136621543338, 1.8327840992382594, 1.1016375379902976, 0.7966260590723583, 0.5901310795119831, 0.7853769255535943, 0.3283385629100459, 1.1286505056279046, 3.74688036101205, 10.639647960662842, 17.29965959276472, 23.842159816196986, 28.39953190939767, 31.68436574935913, 31.800213064466202, 32.37253965650286, 28.059181349618093, 25.19208710534232, 36.52902848379952, 35.8951095853533, 33.675149713243755, 47.675325189317974, 39.17917217527117, 40.10733686174665, 42.7641647202628, 40.61254038129534, 25.515438897269114, 18.913910252707346, 9.880840403693062, 5.757699889796121, 2.3981629269463673, 1.2961601742676325, 1.1915695922715324, 1.1607322927032198, 1.3262130873543876, 1.2580798119306564, 2.744968797479357, 3.850470619542258, 1.7562932265656335, 2.5029966958931515, 3.7693065404891968, 3.288670548370906, 2.7298436548028673, 3.983742279665811, 2.7681369142872945, 1.580683369721685, 0.617100675191198, 0.782683792923178, 1.5268158316612244, 4.269861715180533, 10.052539944648743, 13.639029826436724, 12.232400025640215, 8.467401368277413, 9.040387170655386, 16.799422298158916, 19.487933942249843, 24.280004024505615, 18.360404593603953, 7.779391612325396, 1.144084734576089, 0.1000231931518231, 0.023047220527327487, 0.03793359181976744, 0.09589105738060814, 0.021023106461923038, 0.034822369659585614, 0.043529025678123744, 0.030339919828942845, 0.010148576011748185, 0.05648991305913244, 0.030834073134298836, 0.030901651829481125, 0.04658648750877806, 0.026486334557245885, 0.014484225639275141, 0.0117284981533885, 0.053347084737781963, 0.013667026052384504, 0.026209132646077445, 0.010725160295675908, 0.012633221972334598, 0.10032331597592149, 0.05125603658546295, 0.013800033334908741, 0.02994971808844379, 0.04342805288199868, 0.05146092362701893, 0.04371151088603905, 0.01557276544294187, 0.04490924733025687, 0.02700418739446572, 0.07031167817435094, 0.07761038081454379, 0.025638784947139875, 0.005335022296224321, 0.03996739875791328, 0.022082862810098698, 0.017151580724333013, 0.02536720978761358, 0.019469084850113307, 0.030629678030631373, 0.07128842254834515, 0.010692991798610559, 0.059272456248956065, 0.06295530005757298, 0.049802044606102366, 0.03282491184238877, 0.03671873593702912, 0.03973091573321393, 0.047228066117635796, 0.03524659653859479, 0.07230878993868828, 0.015093987741108452, 0.025743479507842233, 0.027546879702380726, 0.07460595667362213, 0.06360788789710828, 0.021234236025650586, 0.08844662577446018, 0.020540618869875158, 0.05636149352150304, 0.03184848637985332, 0.03207453692864094, 0.04064335195081575, 0.0503846822705652, 0.029346710802721124, 0.045244084005909305, 0.057859325648418496, 0.036134554605398855, 0.007402602466754615, 0.015160263649054935, 0.011093688779510558, 0.04209425998851657, 0.08117453527769872, 0.014471428468823433, 0.03681307266067181, 0.018476264285189763, 0.04349614726379514, 0.02606098131010575, 0.029221453238278627, 0.038222176155873706, 0.10730769405407564, 0.06742725973682744, 0.0978205870570881, 0.04715550019006644, 0.029186698674623455, 0.059701873920857906, 0.04777169141120144, 0.026521357142233422, 0.13689514568873815, 2.0569108383996144, 10.052873458181109, 21.92537590435573, 34.0774712562561, 35.29102625165667, 36.86773232051304, 28.32789077077593, 12.148799300193787, 28.383427722113474, 45.13771104812622, 23.69504039628165, 9.800342917442322, 6.688793241977692, 2.489158924136843, 0.17049036441104753, 0.4139883555471897, 0.4316733122936317, 0.5861519873142242, 1.9416756161621638, 3.059014128787177, 4.000775354249137, 4.404021441936493, 4.1247985277857095, 5.11170415367399, 5.842446633747645, 4.508907539503915, 4.602876714297703, 2.2988816371985843, 1.5447762736252375, 2.1749442304883684, 1.9807435997894831, 0.9028064757585526, 3.934742714677538, 6.51949690920966, 13.027450254985265, 23.099399123873027, 26.99784575189863, 35.06406681878226, 32.82250499725342, 36.664195265088765, 37.80892487934658, 32.236754485539024, 26.797393696648733, 39.73973199299404, 41.81274093900408, 43.87164504187447, 50.367376940590994, 44.423332009996685, 46.02842494419643, 47.064456939697266, 42.79905162538801, 31.483125073569163, 22.017331838607788, 14.618778807776314, 7.997881191117423, 5.389540467943464, 1.885036506823131, 1.4625093851770674, 2.0832686126232147, 1.9839006875242506, 2.5475426827158247, 3.2795558146068027, 3.6384569789682115, 4.077768342835562, 5.121283113956451, 4.2641472561018805, 5.27152053798948, 4.565057669367109, 2.473220842225211, 2.684818459408624, 1.5701244963066918, 0.7443791340504373, 0.2687859870493412, 1.1958985371249062, 4.21484066758837, 11.239846382822309, 18.130528654370988, 20.028712238584244, 14.623581750052315, 11.98056083066123, 14.842981542859759, 20.04674628802708, 27.057261535099574, 22.24493224280221, 11.7098468542099, 2.261542235101972, 0.19099539411919458, 0.039709986320563724, 0.05617564956524542, 0.014707884352122034, 0.01088361518590578, 0.020514113595709205, 0.048328911153865714, 0.05915165665958609, 0.03650297197912421, 0.033122449448066096, 0.024623382736795714, 0.018705909373238683, 0.06927351959581886, 0.0636775123753718, 0.09719842472778899, 0.039214984846434424, 0.02584876778668591, 0.058914244041911194, 0.04288809507020882, 0.02418951048249645, 0.02083180538777794, 0.024739722654755627, 0.028571131705705608, 0.05820288149906056, 0.004333276027214846, 0.027395929409457103, 0.07842061948031187, 0.07258221240980284, 0.030127545153456073, 0.037246720998414924, 0.045313084231955666, 0.022855610719748905, 0.033571989075945954, 0.05363901425153017, 0.029438397847115993, 0.038794367773724456, 0.0091246895691646, 0.05320222768932581, 0.04872402209522469, 0.02319620137235948, 0.027603708706530075, 0.13825378992727824, 0.18292510216789587, 0.12398105008261544, 0.10609605442732573, 0.14981761441699096, 0.0856337859960539, 0.10816572194120713, 0.11304634290614299, 0.10821628637079682, 0.09658335308943476, 0.14952409373862402, 0.18442021336938652, 0.2969132720359734, 0.15604037764881337, 0.23435652309230395, 0.1371693688311747, 0.12275849282741547, 0.23483928718737193, 0.05093278589525393, 0.1829214652201959, 0.2628087449286665, 0.1804022139736584, 0.1720657598759447, 0.16331352666020393, 0.1216672592397247, 0.19576610598180974, 0.12313233848129, 0.18547814445836203, 0.1255649272352457, 0.08980157878249884, 0.09302551578730345, 0.1172734871506691, 0.14139277434774808, 0.05548326564686639, 0.08282640163919755, 0.1205165588429996, 0.16942847067756311, 0.13757201151124068, 0.14320187084376812, 0.10962289624980517, 0.2065300733915397, 0.15056507502283367, 0.1293891506003482, 0.1210168291415487, 0.09855974239430257, 0.15817628375121526, 0.16904173285833426, 0.0830368832019823, 0.18851074815860816, 1.9853648032460893, 9.658721259662084, 24.15848003114973, 42.148842675345286, 44.01816170556204, 45.67224291392735, 41.452313559395925, 28.695240293230327, 50.58204501015799, 68.16860267094204, 38.32215009416853, 13.821083051817757, 4.92494352374758, 2.7675211301871707, 0.40288928683315006, 1.2103848797934396, 1.607396696295057, 6.7372612697737555, 4.911082301821027, 12.556581258773804, 12.612842559814453, 5.858148694038391, 8.619589499064855, 9.156310047422137, 13.240765162876674, 4.982264859335763, 5.539986772196634, 3.1379506587982178, 2.1769131762640814, 1.5770793173994337, 1.8099365766559328, 0.7111055137855666, 1.7790328349385942, 4.228149941989353, 11.169523664883204, 19.10918763705662, 24.96957799366542, 31.025617463248118, 33.13010522297451, 35.31638022831508, 39.59393099376133, 36.88183716365269, 34.09172201156616, 44.24374886921474, 47.947340215955464, 48.958612305777415, 57.40792056492397, 47.309561593191965, 48.65373577390398, 49.80527809688023, 45.03037180219378, 30.116435255323136, 21.827154432024273, 12.635254842894417, 7.406109196799142, 4.5673874872071405, 2.03742179274559, 2.079897867781775, 1.9663391155855996, 3.909433032785143, 3.664974561759404, 7.579080258096967, 8.390581216130938, 5.001711564404624, 7.0504791140556335, 8.831021445138113, 9.824285541261945, 8.081475836890084, 10.587449618748256, 7.512064882687159, 6.292672531945365, 2.3246796471732, 1.830656430550984, 1.9453438307557787, 5.35761957509177, 12.403432539531163, 19.44122120312282, 19.43035248347691, 16.717678478785924, 15.651487827301025, 23.57926951135908, 28.862457377570017, 33.01380974905831, 24.659104687826975, 12.03687858581543, 1.8829272942883628, 0.25156951802117483, 0.22578600155455725, 0.1308533206049885, 0.1863441722733634, 0.07862409177635397, 0.12259572584714208, 0.09573622926005296, 0.08023526639278446, 0.16316576887454304, 0.13056714167552336, 0.06244643272033759, 0.12066215888730117, 0.18035747137452873, 0.09864103088953666, 0.1329854947647878, 0.09688027322824512, 0.09645985293069056, 0.19925220177641936, 0.14179163080240997, 0.1286109523581607, 0.1308635664837701, 0.1868596417563302, 0.19902284336941584, 0.23971529411418097, 0.16158361520086015, 0.15009362889187677, 0.16799900095377648, 0.16016025229224137, 0.09491837743137564, 0.17485882714390755, 0.11070150908614908, 0.1110299743179764, 0.12036657546247755, 0.19443834865731852, 0.12649859142090591, 0.09523540934813873, 0.07133161130228213, 0.11558054227914129, 0.08498744746404034, 0.1882893286113228, 0.14041970084820474], [0.037176024434821944, 0.046943220509482284, 0.05416207993403077, 0.042269389876829724, 0.022421726591086814, 0.03355855747525181, 0.09718044354979481, 0.03715929854661226, 0.012475495659081, 0.023062031250447035, 0.0372600372481559, 0.03351077164656349, 0.019684088848797337, 0.02448718379517751, 0.044905159156769514, 0.0382129921843963, 0.0034383294738030857, 0.048672453433807404, 0.018154523335397243, 0.03967050576050367, 0.05162830125274403, 0.07431372521179062, 0.019311344117990563, 0.08103110654545681, 0.09785135183483362, 0.07300823062126126, 0.059436654938118796, 0.016779053124732206, 0.07743801934910671, 0.02835309804816331, 0.053128959478012154, 0.0491007888423545, 0.04415314897362675, 0.08181054650672845, 0.06600287902568068, 0.017702071095949838, 0.0896215159446001, 0.04485324444249272, 0.03836137082959924, 0.003710835498558091, 0.025656733894720674, 0.029940157530031035, 0.02375157719611057, 0.03133247746154666, 0.019811366751257862, 0.045789429385747225, 0.0394820256956986, 0.02327505562321416, 0.03877218985663993, 0.04069117170625499, 0.0859084976837039, 3.7395300354276384, 13.22845903464726, 28.42676189967564, 39.80796677725655, 35.775975772312705, 51.4778345652989, 64.73427486419678, 30.05748326437814, 13.88835551057543, 12.359199438776288, 8.47625424180712, 6.610822728702, 3.6260540102209364, 1.27905664060797, 0.5535225410546575, 0.3934641368687153, 0.7015280734215463, 2.036052997623171, 3.9584868805749074, 3.861283753599439, 4.104346939495631, 1.8933571917670113, 3.2839201518467496, 2.293852227074759, 2.2961538178580145, 1.8357705218451363, 1.5441938191652298, 1.5610764218228204, 1.9825125677245004, 1.359061564717974, 2.978332515273775, 0.8063587482486452, 0.6291187788758958, 4.936484481607165, 5.131006683622088, 9.152788179261343, 8.840735026768275, 9.033977457455226, 14.747968401227679, 17.421975680759974, 15.92307380267552, 23.751788071223668, 26.07419913155692, 22.27344764981951, 27.963277101516724, 29.842266287122452, 26.62420810971941, 18.993712050574167, 14.457934958594185, 7.772711787905012, 4.4039219958441596, 1.8240526020526886, 0.7658416309526989, 0.8337895848921367, 0.5043031850031444, 1.5438134052923747, 1.7579966208764484, 2.311694766793932, 2.9712716255869185, 3.5584740936756134, 2.977186062506267, 2.0305211458887373, 5.5472467711993625, 2.278248961482729, 4.721938439777919, 3.6407798486096516, 1.6175415005002702, 1.653841386948313, 0.5547237108860696, 1.8156851253339221, 2.232294661658151, 5.025110925946917, 8.758236459323339, 14.281504562922887, 13.753761955669948, 10.765516315187726, 12.056207605770656, 16.28237557411194, 21.23976935659136, 26.942374808447703, 16.78224114009312, 5.985993811062404, 1.150871821812221, 0.06711775955877133, 0.0891042279877833, 0.015509040826665503, 0.07947682709034, 0.0765846733536039, 0.041065088606306484, 0.021105721493118575, 0.050075416187090535, 0.05507099794756089, 0.006790614345975752, 0.018083545179771524, 0.008999678821835135, 0.02929996991796153, 0.06645130924880505, 0.04126300709322095, 0.04156995937228203, 0.012522263685241342, 0.013673460260698838, 0.1288741696625948, 0.07949962586696659, 0.021184250047164302, 0.018775228510743806, 0.03771687791283641, 0.059513370107327185, 0.1007224777713418, 0.04330286317105804, 0.04830710643104144, 0.01674805085973016, 0.11326675822160073, 0.013889352292088526, 0.026210674616907324, 0.029155852472675697, 0.011021980350571019, 0.07766029385051557, 0.054517978336662054, 0.05283300964427846, 0.041074055446577926, 0.07430258366678442, 0.004941675545913833, 0.021922429990289465, 0.02692378099475588, 0.09252000041306019, 0.0875397501513362, 0.033195123941238434, 0.03272768116689154, 0.03612005091937525, 0.0426377936798547, 0.04766075432832752, 0.034847329570246596, 0.04249366605654359, 0.007856332048374628, 0.01965806194181953, 0.04307463452486055, 0.05844190224472966, 0.042448631687355895, 0.01963065760875387, 0.08386162894644908, 0.08212793804705143, 0.05461077478581241, 0.03759984080014484, 0.04268703157348292, 0.042503386070685725, 0.04327048008729305, 0.0314580641154732, 0.0255039770023099, 0.11064259867583003, 0.0594214421830007, 0.05491578984739525, 0.040093657161508284, 0.030515470408967564, 0.022265010446842228, 0.04354793644909348, 0.06881502669836793, 0.04593434410967997, 0.07281300252569572, 0.03769672203010746, 0.04157741986481207, 0.01099303743935057, 0.055838923169566054, 0.01472763650651489, 0.0322984127726938, 0.011364436974482877, 0.05373993615752884, 0.021558187303266356, 0.026310936647600362, 0.05138615924598915, 0.07047248418842043, 0.050811613111623695, 0.06149393918790987, 0.02015483608868505, 0.004675652499177626, 0.03865013837016054, 0.6767236015626362, 6.912863092763083, 19.20378909792219, 36.59546715872628, 44.09350797108242, 39.183764934539795, 44.7561159815107, 62.224050521850586, 44.945468289511545, 28.28273442813328, 19.157854557037354, 13.393265094075884, 10.94140909399305, 4.902872136660984, 1.2993145478623254, 0.14711940634463513, 0.16363954916596413, 0.4452590490026133, 1.0557474004370826, 2.0542451185839514, 3.3876044281891415, 3.055339834519795, 4.25443845135825, 4.363252452441624, 4.349826795714242, 5.363472998142242, 3.688153317996434, 3.2103560992649625, 3.7689734612192427, 2.8543254094464436, 3.4001070601599555, 4.905139854976109, 1.4084401322262627, 1.5977218725851603, 5.632664450577327, 7.745021479470389, 11.602310453142438, 13.289296592984881, 12.798791987555367, 18.325046948024205, 20.118201562336512, 19.55411900792803, 29.56855242592948, 33.0127466746739, 29.049233640943253, 35.61763327462332, 34.030230454036165, 32.11822516577584, 24.22952709879194, 18.890698058264597, 10.58483796460288, 6.470049185412271, 2.3545849110398973, 1.8425415413720267, 2.3178593388625552, 2.842266159398215, 2.0989265952791487, 3.2051896793501715, 3.962726584502629, 5.309303104877472, 4.944110563823155, 4.292010835238865, 4.8596890824181695, 5.70760554926736, 4.959960273333958, 3.950782196862357, 2.9760396097387587, 1.6161234165940965, 0.7994994106037276, 0.5669466235807964, 0.7433408669063023, 2.2635124836649214, 7.384085144315447, 14.490898081234523, 19.30447891780308, 18.05303192138672, 11.702348010880606, 13.135264583996364, 15.571510587419782, 23.96795174053737, 29.566186564309255, 23.694451536451066, 8.946740218571254, 2.0788415244647434, 0.18482318174626144, 0.08540879735457045, 0.022530058099489127, 0.07271618914923497, 0.02892685029655695, 0.06775110414517777, 0.04990366879584534, 0.011800142121501267, 0.01610025347742651, 0.009295162162743509, 0.06451719267559902, 0.014397347711824944, 0.03855647000351122, 0.03422622914825167, 0.04790958669036627, 0.0467620788009039, 0.06318773222821099, 0.015716708165460398, 0.035799690788345676, 0.015947357485336915, 0.12956307269632816, 0.023864312396783913, 0.030064081773161888, 0.07867403195372649, 0.0351215357493077, 0.06861992073910576, 0.016250096061932187, 0.06890984518187386, 0.0766202693006822, 0.10195563374353306, 0.0674535393980997, 0.06761184840330056, 0.06765067417706762, 0.0023898626760845737, 0.05735771185053246, 0.03568862478381821, 0.05836469853030784, 0.025225141518084065, 0.004926346591673791, 0.020614523207768798, 0.03394130211589592, 0.016668470576405525, 0.1339638065546751, 0.09403579336191926, 0.14150561472134932, 0.13294221780129842, 0.10515985252069575, 0.12018763220735959, 0.19068303730870995, 0.15279715667877877, 0.08298023909862552, 0.16284134771142686, 0.0702771543126021, 0.20792420501155512, 0.09466154514146702, 0.08500004107398645, 0.15183880738914013, 0.21023224187748774, 0.11058715557945625, 0.16986478226525442, 0.17579424194991589, 0.13346380767013344, 0.13885285492454255, 0.1488225156707423, 0.05615680664777756, 0.16475052812269755, 0.18070348352193832, 0.307677225875003, 0.16859905661216804, 0.14209987569068158, 0.20103963943464415, 0.10434679793460028, 0.1844476397548403, 0.26952822293554035, 0.10518907023859875, 0.2217745025243078, 0.10837865980075938, 0.09055029467812606, 0.1452367566525936, 0.11337313215647425, 0.10227543408317225, 0.06231035252234765, 0.1254695930651256, 0.1914239568369729, 0.08125751332512923, 0.16625769010611943, 0.15093193176601613, 0.14413663425615855, 0.20012174440281733, 0.09956259001046419, 0.11082658344613654, 0.0853137888812593, 0.5539559892245701, 6.428040810993739, 18.625381095068796, 38.55219105311802, 50.77485057285854, 46.8774288041251, 57.486841678619385, 68.57964420318604, 36.64980901990618, 20.015217099870952, 20.354973588671, 13.259088431085859, 9.481950402259827, 4.74417484658105, 1.7188880337136132, 0.9949618450232914, 0.7381872577326638, 1.95725217461586, 5.2955890979085645, 9.971332005092076, 10.639002646718707, 10.481960330690656, 7.473850658961704, 10.369183250835963, 7.083532997540065, 8.753303238323756, 5.493581056594849, 5.766314787524087, 4.853089162281581, 4.954806012766702, 3.310368686914444, 4.1763163805007935, 1.1876718699932098, 1.59904702433518, 6.942468064171927, 6.367828590529306, 10.612263372966222, 10.442442451204572, 11.318274174417768, 18.702797923769268, 21.548140832356044, 21.784344843455724, 29.95410101754325, 33.39290346418108, 33.29030983788626, 35.59897041320801, 33.90497180393764, 32.283276149204795, 25.375566448484147, 18.115058490208217, 10.049418466431753, 6.515130834920066, 2.5768408477306366, 1.6346823807273592, 1.9371369225638253, 2.7102419180529456, 4.680212335927146, 5.428447774478367, 5.005372396537235, 10.483539308820452, 7.016855478286743, 7.662324888365609, 7.406339355877467, 11.293321456227984, 8.46520573752267, 10.868982808930532, 7.083774881703513, 5.804353134972708, 3.5114182872431616, 1.1623769530228205, 2.6542991484914507, 3.3583006177629744, 7.342966573578971, 12.736576080322266, 20.531075681958878, 21.367091621671403, 17.139526196888514, 18.85620025226048, 23.11078895841326, 30.122976984296525, 35.1902356828962, 24.81734643663679, 8.710444143840245, 1.7817236334085464, 0.15792932414582797, 0.2720917010945933, 0.12581147971962178, 0.1831717767885753, 0.20053098244326456, 0.12626444255667074, 0.12110752213214125, 0.08881168439984322, 0.24452320326651844, 0.1070983660008226, 0.10338592449469225, 0.10386559447007519, 0.1412268996770893, 0.14714054949581623, 0.1297770690705095, 0.13177463545330934, 0.2199494197432484, 0.05917762419474976, 0.24646983881081852, 0.17040276554014, 0.219939363854272, 0.14997811509030207, 0.1435315710093294, 0.1632842682301998, 0.2337171531149319, 0.12620349654129573, 0.23527865218264715, 0.1676570057336773, 0.22316205235464232, 0.1791950866047825, 0.16907772235572338, 0.17513036328767026, 0.17981837530221256, 0.21756231997694286, 0.15067283995449543, 0.14954051428607532, 0.09663368003176791, 0.1368697549083403, 0.08552336120711905, 0.10980967658438853, 0.1456088245447193, 0.18400248007050582], [0.07019475980528764, 0.015130808443895407, 0.03887469953458224, 0.052664319053292274, 0.07282434763120753, 0.006761235476005822, 0.04316476772406271, 0.018077516396130835, 0.017542532246027673, 0.0541031254189355, 0.021920567411663275, 0.014602495989363109, 0.07628078466015202, 0.028721454353736978, 0.08051986433565617, 0.037672878309552155, 0.04333705794332283, 0.08816622796335391, 0.024096379854849408, 0.035577297543308566, 0.09429350096200194, 0.017449861325855767, 0.023527041476752077, 0.08576388151517936, 0.0134911921839895, 0.06337064491318804, 0.0015559031682122232, 0.04816711787134409, 0.03203359751829079, 0.028195392939129045, 0.018103158234485557, 0.07355107220688037, 0.017240495953176702, 0.017800394212827086, 0.04628648003563285, 0.01405406412335911, 0.05766269977071455, 0.031632990443280766, 0.049860575036810975, 0.09300322591194085, 0.042364106580082855, 0.0055871044169180095, 0.024866111676341722, 0.038797071735773764, 0.04460673945556794, 0.005955754188887242, 0.032700984206582816, 0.019971282188115374, 0.054636006110480854, 0.023222660845411674, 0.017794786120897958, 0.2594764323106834, 2.2323576297078813, 6.834034042698996, 24.69377793584551, 39.88415377480643, 35.2250531060355, 22.676021065030778, 14.551888499941144, 13.1683623279844, 11.40070847102574, 11.351058380944387, 7.477814606257847, 5.510394828660147, 4.852825130735125, 2.457141407898494, 0.568245176758085, 0.4906704936708723, 0.15623312230621064, 1.3330381725515639, 2.3512515127658844, 1.8917456439563205, 3.929786043507712, 2.5705700985022952, 7.270540722778865, 5.198937484196254, 2.775146778140749, 1.01310076883861, 6.169382393360138, 4.279803718839373, 2.179148759160723, 6.123973744256156, 1.7777477438960756, 0.49356458123241154, 0.11561400762626103, 0.4343081723366465, 0.8813610236559595, 1.4621488388095583, 1.563350219811712, 2.676780913557325, 6.693984849112375, 6.919580263750894, 9.715720806803022, 7.8177951744624545, 8.181193777493068, 7.490989259311131, 6.756816106183188, 6.69870354448046, 4.053835707051413, 1.2854488747460502, 0.8083891421556473, 0.4343965990202767, 0.632632178919656, 1.076411668743406, 2.986904638154166, 2.5233694655554633, 0.989727897303445, 2.506457333053861, 2.7189299889973233, 2.083733707666397, 2.5739734130246297, 1.3961196733372552, 2.968174248933792, 4.067862817219325, 4.203815613474164, 3.1625477160726274, 2.557279714516231, 0.8034002812845367, 0.7939404717513493, 2.1986100120203833, 4.672483767781939, 8.868420992578779, 11.09398284980229, 14.152395742280142, 8.548968008586339, 15.006225994655065, 19.082885231290543, 24.41745502608163, 23.963405881609233, 24.923268250056676, 13.847951735769, 4.073955084596362, 0.8784559166857174, 0.09714860668671982, 0.024036719663334743, 0.06926790811121464, 0.053990257903933525, 0.012665900218832706, 0.0401377280109695, 0.08486495832247393, 0.02623982448130846, 0.025437524675258567, 0.02655598278423505, 0.03429197579888361, 0.07904043407844645, 0.06614720342414719, 0.022250437210979204, 0.07614200389278786, 0.0371838784776628, 0.05754059739410877, 0.05563794109704239, 0.008770708876129771, 0.01463883662862437, 0.022753082382093583, 0.04382334702781268, 0.01462191905427192, 0.04323690278189523, 0.03029467850657446, 0.039177346508949995, 0.0439427216936435, 0.02488286470595215, 0.031071570568851063, 0.04861802813996162, 0.01542373201144593, 0.04209280453090157, 0.08938419153647763, 0.02729102280656142, 0.023842236259952188, 0.0946444867710982, 0.02722285208957536, 0.01851423001582069, 0.01895999359632177, 0.0467062523322446, 0.03945834482354777, 0.07483226845839194, 0.034283086990139315, 0.019177581117089306, 0.03869579020621521, 0.030747719375150542, 0.02271910474103476, 0.04141403541767171, 0.02544637446823929, 0.07177233336759464, 0.03289821058777826, 0.024295005714520812, 0.033624673927468915, 0.12799831666052341, 0.05743555338787181, 0.05644035625404545, 0.04387958061748317, 0.04063967429101467, 0.022252737444692423, 0.04991114964442594, 0.044741004572382996, 0.017883022814722996, 0.04458604074482407, 0.029676526319235563, 0.04569231066852808, 0.041731172507362704, 0.08191624190658331, 0.04248004446604422, 0.056668432229863744, 0.06452783889004163, 0.06862821243703365, 0.05429933399760297, 0.05843513046524354, 0.04879164489518319, 0.0939952644652554, 0.06683426762798003, 0.02209034196234175, 0.03139879068891917, 0.030473336776984588, 0.019106077096824135, 0.04005056340247393, 0.041488331609538624, 0.049265221626098664, 0.025471980683505535, 0.017737064843199084, 0.008186223900078662, 0.017258426241044487, 0.02272573742084205, 0.027254995989746282, 0.034068937945578776, 0.02517447021922895, 0.08345758848424469, 0.027938765906063572, 0.01655385413739298, 0.5840413634266172, 3.948496673788343, 12.608600684574672, 32.65997620991298, 44.25573451178414, 39.77664777210781, 29.3500246320452, 11.913264921733312, 8.106712562697274, 11.7389954158238, 14.616399049758911, 12.583714842796326, 12.527640274592809, 8.651898622512817, 3.8944105931690762, 0.8434119171329907, 0.12616458934332642, 0.21843516028353147, 0.5957451154078756, 0.2560201920568943, 0.7528595732791084, 1.7556366217987878, 2.9096200423581258, 4.2509543640272955, 3.796432307788304, 4.707695935453687, 4.1359564661979675, 4.280737817287445, 6.108814077717917, 4.100781210831233, 4.800760975905827, 3.1664393586771826, 1.193916454911232, 1.4280518570116587, 1.6055736626897539, 1.8176014167921883, 1.939123455967222, 2.7682515595640456, 4.349923201969691, 9.026439530508858, 9.653772405215673, 12.375011801719666, 11.117141195705958, 11.492257935660225, 10.608369776180812, 9.709708877972194, 9.08582752091544, 6.941300766808646, 2.5839549345629553, 1.9144423689161028, 1.3118193511451994, 1.400555555309568, 2.909927500145776, 4.404389262199402, 3.7105790632111684, 3.1954263746738434, 4.052043506077357, 2.6258649485451833, 3.889812622751508, 4.198540193693979, 4.834779790469578, 6.362911002976554, 2.3361344039440155, 2.660804399422237, 1.847763981137957, 0.9914736321994236, 0.631592717553888, 0.6087691879698208, 1.902190306356975, 5.144341579505375, 8.599899172782898, 15.093158381325857, 17.607542957578385, 14.982935632978167, 14.839088814599172, 17.978611503328594, 22.784445966993058, 26.137823786054337, 28.55136047090803, 19.184830938066753, 6.1538088747433255, 1.4876429736614227, 0.06460720034582274, 0.029082065182072774, 0.016082937263750603, 0.03817347091223512, 0.02059214173017868, 0.029799290267484527, 0.06572167375790221, 0.07865579293242522, 0.027423313386472206, 0.03521857304232461, 0.04975788554708872, 0.050943818874657154, 0.08160885875778538, 0.011908198823221028, 0.05373311348791633, 0.015767067338206937, 0.053805910117392025, 0.03154237548421536, 0.0198475174007139, 0.07082192972302437, 0.04583169872473393, 0.03897654085553118, 0.005461687396746129, 0.007786422585403281, 0.012306727884736444, 0.07324148381927184, 0.008362838083745112, 0.03445436279954655, 0.05252936522343329, 0.024063874634781053, 0.05647086997383407, 0.08497741871646472, 0.02227028605661222, 0.1404986009001732, 0.016283284906031828, 0.05373670633084007, 0.01671721483580768, 0.028411545358332138, 0.018623486028185914, 0.021167274797335267, 0.06481627734111887, 0.008103530837355979, 0.03799617649721248, 0.11929803208581038, 0.123808675046478, 0.09411141608974763, 0.10615273924278361, 0.16313116358859198, 0.16972630683864864, 0.14313643292656966, 0.20383327667202267, 0.08161938962127481, 0.14651039402399743, 0.206447088558759, 0.2651972696185112, 0.23656966005052837, 0.11955987874950681, 0.1606312913021871, 0.14192463723676546, 0.11545711675924913, 0.18948703791413987, 0.07023066787847451, 0.10596972477755376, 0.18316343080784592, 0.12125346144395215, 0.10482300738138811, 0.17613573505410127, 0.11998346102024827, 0.08939021014209304, 0.12499275936612061, 0.12446753254958562, 0.15067402060542787, 0.21059539381946835, 0.18574868994099752, 0.31786507634179934, 0.1270770968071052, 0.09316124314708368, 0.12903871440461703, 0.12037653635655131, 0.19242349320224353, 0.1369521426303046, 0.15182843937405519, 0.1674800438008138, 0.13893639615603856, 0.08336610160768032, 0.0947311424783298, 0.09907033321048532, 0.12988351764423506, 0.1429754165666444, 0.10577781471822943, 0.09894261256392513, 0.15547355663563522, 0.16873645995344433, 0.13151783709015163, 0.4950817312513079, 3.6090205013751984, 13.157967822892324, 38.268902574266704, 51.59878185817173, 46.138755389622276, 32.53306041445051, 20.855485337121145, 19.10158630779811, 18.367529971258982, 17.9518609387534, 12.066456198692322, 11.03819489479065, 7.024681321212223, 4.191968500614166, 0.9859897664615086, 1.0558400068964278, 1.3785664609500339, 3.3068372649805884, 6.228497666972024, 4.694971178259168, 11.05370761666979, 10.120417765208654, 15.352261917931692, 11.66632160118648, 8.958757996559143, 6.909645642553057, 13.021596397672381, 9.592637811388288, 7.986114416803632, 11.144200086593628, 3.9714856573513577, 1.5913793614932468, 0.511844206069197, 0.7474022518311227, 1.2449414197887694, 2.0777319840022495, 2.6079205742904117, 3.52786054781505, 9.432278599057879, 10.328389508383614, 12.342435172625951, 10.696733491761343, 11.12536699431283, 9.601887600762502, 9.532247543334961, 8.331442492348806, 5.752507848399026, 2.5902000623089925, 1.927005797624588, 0.8214763456157276, 1.1968383895499366, 2.3429540608610426, 5.747696655137198, 5.886997180325644, 3.5357083209923337, 8.136082598141261, 6.2736870135579785, 6.863622946398599, 8.285476684570312, 6.967819000993456, 12.878261140414647, 10.753295302391052, 11.638838001659938, 8.149574262755257, 5.390276976994105, 1.585119468825204, 1.776336825319699, 2.823316250528608, 5.7690614972795755, 11.885160326957703, 15.030975478036062, 20.492033754076274, 15.370681592396327, 20.392264570508683, 26.264027391161235, 31.82846096583775, 33.55084644045149, 34.29539803096226, 20.726947137287684, 6.284315586090088, 1.3198602625301905, 0.1451531339968954, 0.1377430566187416, 0.1476117649248668, 0.15429783186742238, 0.1090957016817161, 0.16423082458121435, 0.1382952212755169, 0.08600168768316507, 0.1788908043610198, 0.06431502316679273, 0.1314676119280713, 0.13235125451215676, 0.20131017134657928, 0.08345063350030354, 0.120913759672216, 0.1304473802447319, 0.14324544636266573, 0.10715965128370694, 0.09721415995487145, 0.22184093110263348, 0.19530272084687436, 0.16428100903119358, 0.13681362649159773, 0.09961613999413592, 0.06477243040821382, 0.21423809549638204, 0.08979654405266047, 0.08930250270558254, 0.08060072535382849, 0.1887950814728226, 0.1186878119728395, 0.14862518411661896, 0.2036661942090307, 0.16766567741121563, 0.14943851690207208, 0.17644734547606536, 0.13407383779329912, 0.0709476215498788, 0.09893742177103247, 0.11637305761022226, 0.1594354547560215, 0.1548082801912512, 0.11756900272199086], [0.0317905089551849, 0.015052222214373094, 0.05091218217941267, 0.047604741262538094, 0.026919677554230605, 0.0054809900216891295, 0.027834157858576094, 0.029116276917713027, 0.004847461382658886, 0.04851933182882411, 0.08041237081800189, 0.06096126205687012, 0.015153815870040228, 0.07550256606191397, 0.08207841856139046, 0.014338837637166892, 0.07601219335837023, 0.04449783119239977, 0.01131912779861263, 0.04936975673107164, 0.026902642932587435, 0.014585444404344474, 0.0163372691521155, 0.04428121567304645, 0.013820745616352983, 0.00762455296769206, 0.0777181661022561, 0.032224798508520634, 0.05200726645333426, 0.10780047332601887, 0.0020022234654918846, 0.02805947219686849, 0.029095205012708902, 0.06822761214737381, 0.026113167438389998, 0.04822532260524375, 0.01950164944199579, 0.02473033681911017, 0.02949021417381508, 0.031895624207598824, 0.007836749527736433, 0.006870480038092605, 0.056582363455423286, 0.0424876847703542, 0.04136675509757229, 0.029623220608170544, 0.05748771237475531, 0.026758542450677072, 0.0324504792557231, 0.03847697623340147, 0.02147583520439054, 0.03484499880245753, 0.04614190457920943, 0.561721741088799, 6.400826454162598, 21.861468110765728, 37.1448403767177, 40.62438358579363, 42.79099866322109, 38.27798386982509, 30.115716116768972, 23.708738769803727, 21.613547699792043, 16.742497444152832, 13.696770225252424, 9.415642874581472, 4.918870363916669, 2.239039191177913, 0.38275020463126047, 0.4752193827714239, 0.11240692543131964, 0.8307741209864616, 2.284921620573316, 2.445734419992992, 0.9314885309764317, 2.86795060975211, 3.585643070084708, 2.635487986462457, 2.2016620082514624, 3.477142823593957, 6.2534099987574985, 6.0550728014537265, 3.740648695400783, 1.5582901941878455, 1.7605156685624803, 2.3405150260244096, 0.8318048428211893, 0.10810075221317154, 0.24944844469428062, 0.19314579372959478, 0.8998866038663047, 1.5274456207241331, 1.3863109882388795, 1.2965625183922904, 0.5898047855922154, 0.25565956426518305, 0.24935893235462053, 0.17527406343391963, 0.13315025663801602, 0.03355627081223896, 0.17269548108535154, 0.677726747734206, 1.8612326298441206, 5.706591980797904, 3.334461131266185, 3.8910897885050093, 1.9947974170957292, 1.9529015166418893, 2.16337873680251, 1.9087819755077362, 2.9775039425918033, 3.126211460147585, 3.3261630279677252, 1.5807057342358997, 1.3903045739446367, 1.022343935711043, 1.2429239451885223, 1.2829554485423225, 3.5917312119688307, 4.487250004495893, 24.24587447302682, 27.585383687700542, 17.254647425242833, 14.255580833980016, 13.544227736336843, 14.190709846360342, 17.82452998842512, 27.169127532414027, 24.867859840393066, 15.35699016707284, 4.208093098231724, 0.6745566864098821, 0.04728623692478452, 0.057783804700842926, 0.054248867955590994, 0.06510997443859066, 0.07010026701859065, 0.027314729123775448, 0.07701889505343777, 0.015880533660362874, 0.06372930495334522, 0.03263518666582448, 0.023727166898814694, 0.053672581378902705, 0.039653287934405465, 0.03290247518037047, 0.06181408558040857, 0.10341253663812365, 0.08740475560937609, 0.08977312102381672, 0.061123574418681006, 0.04482470865228346, 0.030974370427429676, 0.052765081503561566, 0.04326067525627358, 0.032900578674993346, 0.0345956066490284, 0.04418829369491764, 0.01673804925355528, 0.051446216380489726, 0.018821022839152386, 0.07904609984585217, 0.01493649637060506, 0.025238830962085297, 0.030783447636557475, 0.012136595406835633, 0.01583631692587265, 0.0488153359453593, 0.01665471158256488, 0.040902202882404835, 0.07046495923506362, 0.03271046334079333, 0.027800217536943297, 0.04187014665720718, 0.06694024122719254, 0.041528572128819566, 0.010859012354298361, 0.016434197879529426, 0.034807211187269003, 0.018627258682889596, 0.006072546604887715, 0.06783702024923903, 0.02787878001773996, 0.018441799795255065, 0.03730812163225242, 0.05632199939074261, 0.1565957721322775, 0.037440307039235315, 0.00910915366174387, 0.03834494010412267, 0.048026410064526966, 0.06518073207033531, 0.0038199324792783174, 0.05240202794915863, 0.013716880564710923, 0.018357946437650492, 0.012273288830848677, 0.029570620573524917, 0.0192246748400586, 0.020460229433540787, 0.061611692155046124, 0.04806306791890945, 0.02281977898175163, 0.032459452881344726, 0.055969836323388984, 0.054313953034579754, 0.08394822358552899, 0.021128106363383786, 0.04750028418909226, 0.08550054207444191, 0.036862710889961035, 0.009125110260876161, 0.03169385842712862, 0.026552451009462987, 0.04507050117743867, 0.031491573567369154, 0.05382092609735472, 0.06787525569753987, 0.034200505885694704, 0.0470306158198842, 0.01893542553963406, 0.011650213871949484, 0.06066440977156162, 0.021520979835518768, 0.032499991956033876, 0.03391408268362284, 0.038805723057261536, 0.05286904324644378, 0.035312377115977664, 0.999907985329628, 10.418972304889135, 29.180422578539165, 42.38968808310372, 41.58370746885027, 40.329144205365864, 29.077410323279246, 15.429805551256452, 12.768743634223938, 14.554267389433724, 16.086379051208496, 16.846373013087682, 13.422534380640302, 7.091523860182081, 2.5717232823371887, 0.7002429823790277, 0.21975742147437163, 0.29099354254347937, 0.3119830462549414, 0.7614199167915753, 1.6009480080434253, 2.0371657950537543, 2.4404926555497304, 3.1674970047814504, 3.3837601201874867, 6.354629618780954, 6.117840221949986, 1.0736420516456877, 7.670528973851885, 4.630064146859305, 3.253835971866335, 4.105362679277148, 3.5935216758932387, 1.9098678486687797, 0.8911025609288896, 0.5760710196835654, 0.5374769791960716, 1.178900963493756, 2.5135685971805026, 2.2124599431242262, 1.9256187634808677, 1.3181958432708467, 0.5588594632489341, 0.7826523088983127, 0.4907464353101594, 0.18252604215272836, 0.2625625181410994, 0.3323810574199472, 1.735362972532, 4.504544505051204, 5.4687186649867465, 7.1428892867905756, 7.2122818146433145, 3.3823646179267337, 3.5498498593057906, 4.371230721473694, 3.324510008096695, 4.027812097753797, 3.3006375176565985, 3.703380729470934, 1.2623429660286223, 0.9475043458598, 0.625871473125049, 0.5479910150170326, 0.847877980342933, 4.516345151833125, 8.54864057472774, 20.79052315439497, 30.313152653830393, 21.137144463402883, 13.652524096625191, 9.549764820507594, 12.233410120010376, 20.366160188402446, 30.1010936328343, 29.149711540767125, 20.18081177983965, 5.732582586152213, 1.4176770022937228, 0.12527748623064586, 0.07413309918982641, 0.09702243310000215, 0.04680704531658973, 0.043839055113494396, 0.015130084107763, 0.04994995166946735, 0.035725893319717476, 0.0630298371293715, 0.05091990390792489, 0.04563723737373948, 0.0173100542742759, 0.04153866194454687, 0.01525690230274839, 0.07795479161930935, 0.007109200532015945, 0.048811044211366346, 0.06626496996198382, 0.05971236407224621, 0.011835629502976579, 0.022751576034352183, 0.050349333988768716, 0.01956562850890415, 0.021468116868553416, 0.040221469410295994, 0.025162750223119344, 0.004746137868746051, 0.04072935287175434, 0.052820416034332345, 0.04822572633357985, 0.04734145271192704, 0.002562031183125717, 0.03338322402643306, 0.04192392395011016, 0.04806312220171094, 0.03873282125485795, 0.013114643416234424, 0.035964201603616984, 0.04897210128339274, 0.0388307406433991, 0.01960787918817784, 0.024956702886681472, 0.0586116649210453, 0.04530827681134854, 0.11167280482394354, 0.08948525254215513, 0.12083172478846141, 0.10795870090701751, 0.1757414247840643, 0.12421788594552449, 0.12537681018667562, 0.1620245272559779, 0.1792174239775964, 0.1536219838474478, 0.3174278826585838, 0.11547602074486868, 0.11964544201535837, 0.16547301863985403, 0.22537870412426336, 0.163537701059665, 0.19088697779391492, 0.17662050761282444, 0.08883249506886516, 0.13421345315873623, 0.128868646387543, 0.0860160319134593, 0.07851811139179127, 0.10596918873488903, 0.10509605665824243, 0.14999102082635674, 0.12580974266997405, 0.08040246420672961, 0.16439859914992536, 0.1677581753049578, 0.1758525688201189, 0.1203913012785571, 0.13475652544626168, 0.16053905125175202, 0.14566080032714776, 0.16673927355025495, 0.18462020478078298, 0.09292706035609756, 0.12556822491543634, 0.0875711731080498, 0.09314708212124449, 0.07327266250337873, 0.19710880464741162, 0.17732640116342477, 0.11177078528063637, 0.1015767805012209, 0.20737958566418715, 0.06591643366430487, 0.08473963968987976, 0.0816071963469897, 0.16783198634428637, 0.11788525432348251, 0.17584602774253913, 1.4006193918841225, 11.955594216074262, 30.881452764783585, 50.12171295710972, 54.147346360342844, 54.365610122680664, 47.921357427324565, 38.558625085013254, 33.000934737069265, 31.777770383017405, 24.306914397648402, 20.08367075238909, 13.84771636554173, 7.165031458650317, 3.0767142304352353, 0.8386801396097455, 1.1637280519519533, 1.0988065813268935, 2.6007600213800157, 3.481672180550439, 6.720815317971366, 7.2353163957595825, 8.696363619395665, 12.643298251288277, 9.456551262310573, 7.366865771157401, 8.990605064800807, 16.583248206547328, 18.670448848179408, 7.284731115613665, 4.888891926833561, 3.9080208114215305, 5.5299548762185236, 1.860173898083823, 0.6661914895687784, 0.7337631551282746, 0.6558677692498479, 1.3174909268106734, 2.4254042080470493, 1.869185711656298, 2.1326742129666463, 0.9466928179774965, 0.6602619620306152, 0.5304298773407936, 0.5056061893701553, 0.2729406841099262, 0.17673740562583717, 0.518783719411918, 1.6369453221559525, 3.390170701912471, 9.682064601353236, 8.48450435910906, 9.824895245688301, 6.254304579326084, 6.566109767981938, 8.607867888041906, 6.173718503543308, 8.8646958896092, 9.913418769836426, 9.181728294917516, 4.665784401553018, 3.8529202938079834, 2.4103079438209534, 2.1362460213048116, 1.9474908241203852, 4.959700150149209, 6.459589106695993, 28.414711986269268, 34.12155062811715, 24.54032175881522, 19.737322160175868, 18.61020622934614, 19.721851996013097, 26.60405659675598, 36.683351448604036, 34.646417549678254, 22.381983722959244, 5.6835474116461615, 1.3787484169006348, 0.14711614937654563, 0.22754712562475884, 0.1840495839715004, 0.13904059199350222, 0.13183349158082688, 0.10901836226029055, 0.137311209791473, 0.09729704979274954, 0.13957511473979267, 0.07625835229243551, 0.14524207636713982, 0.1721043006650039, 0.16133903046803816, 0.08879620023071766, 0.20169309579900332, 0.1362980077309268, 0.20858671303306306, 0.08684937469661236, 0.12470565762903009, 0.06806052968438182, 0.19305454434028693, 0.1933516612542527, 0.11225140520504542, 0.14981959573924541, 0.17310508553470882, 0.10957703406789474, 0.1527449366237436, 0.10122889559715986, 0.14070068219942705, 0.18983299577874796, 0.14009340692843708, 0.14732743161065237, 0.09169487468898296, 0.09395240140812737, 0.13906697343502725, 0.16219694300421647, 0.09872447034077984, 0.09552044833877257, 0.14935768981065067, 0.19527560658752918, 0.13513647791530403, 0.15397402138582297, 0.17394490832728998, 0.14037764524774893], [0.02154452839334096, 0.04926225982074227, 0.0651878227612802, 0.04231469226734979, 0.011732881489608969, 0.01734693774155208, 0.07591736808951412, 0.03711024046476398, 0.04807430785149336, 0.029723368984247957, 0.03663800723318543, 0.03616686983566199, 0.0058684347895905375, 0.06638821227742092, 0.03534030561734523, 0.032751453641269884, 0.07240786962211132, 0.045980603234576325, 0.021240056159773042, 0.05011943614642535, 0.04522077293534364, 0.023632273776456714, 0.019418949593922923, 0.03802124836615153, 0.04004027681159122, 0.033267805219760964, 0.005276439279051763, 0.024515032568680387, 0.020642911416611502, 0.06158672885171004, 0.04960374613957746, 0.016971236294401542, 0.03767449322289654, 0.029910281633159945, 0.03495234304240771, 0.04461088530453188, 0.05018525743590934, 0.018223336964313473, 0.07872896614883627, 0.015629752206483057, 0.04347119753115943, 0.05039345233568123, 0.056722966089312515, 0.06092078744300774, 0.013745243328490427, 0.0152805933529245, 0.07580821894641433, 0.06298528452004705, 0.025501023678641235, 0.0253015343831586, 0.044732543240700445, 0.0043150433671793765, 0.03714820449905736, 0.07521967802728925, 0.2936572810368878, 2.1933988630771637, 13.588611960411072, 26.285443476268224, 32.696113790784565, 33.73596034731184, 29.16278110231672, 24.390603712626866, 20.094796555382864, 15.533375399453298, 18.744452374322073, 18.78230616024562, 16.128453867776052, 10.241319026265826, 4.9129661321640015, 2.428567809717996, 0.881878555885383, 0.12186738635812487, 0.3280683974070208, 1.4631212609154838, 1.188298510653632, 1.3721451312303543, 2.705585756472179, 3.2694375004087175, 6.209664574691227, 7.518400771277292, 1.0821349216359002, 2.387892403772899, 3.8870528851236616, 2.590812155178615, 8.393091252871923, 3.722793127809252, 2.1714414698737006, 0.7026462991322789, 0.6453711039253643, 0.344863333340202, 0.1823159677109548, 0.3490033197615828, 0.09244399770562138, 0.03586241795814463, 0.20524192894143717, 0.10193991208715097, 0.003269993417364146, 0.4920786981071745, 0.6770983700241361, 0.5841872755970273, 0.09350929089954921, 2.245705553463527, 3.1643887715680257, 3.3604910373687744, 6.821671460356031, 3.74983377967562, 3.6635610376085554, 1.8589618716921126, 2.0253182479313443, 2.496023092951093, 2.5205680387360707, 2.148400809083666, 3.9364836726869856, 0.416568037122488, 0.9216054784400123, 0.4903797007032803, 3.295162771429334, 6.029153849397387, 9.513938171522957, 12.685093402862549, 48.13363879067557, 32.13566861833845, 9.609316093581063, 16.701089654650005, 19.14249208995274, 20.298564638410294, 25.029089314596995, 23.563253913606914, 9.939927884510585, 3.1798971508230482, 0.34149500408342903, 0.08603847785187618, 0.022707235467221056, 0.0286110465281776, 0.011896238795348575, 0.023639466247654388, 0.01195855629963002, 0.027453679524894272, 0.03777923188837511, 0.011330413532310298, 0.007799748165000762, 0.02003348010059978, 0.03300322745261448, 0.023552328780559555, 0.04373628080689481, 0.04546660277992487, 0.006733770922957254, 0.04676809740651931, 0.037718523360256634, 0.013436757560287203, 0.018187710483159338, 0.056760288908013275, 0.044312787907464166, 0.08312748119767223, 0.008018149927790676, 0.008013382371115898, 0.05804775482309716, 0.022105707387839044, 0.03763864282518625, 0.008051450730168393, 0.048834969356123886, 0.034192767193807025, 0.0350225340974118, 0.07094668517155306, 0.07475727676813092, 0.02623233006202749, 0.06502780384783234, 0.016018547683155963, 0.029663478090826954, 0.027478424000686834, 0.014777771762705274, 0.013710726252091783, 0.057557289355567524, 0.025556402314188223, 0.003665365170620914, 0.023231666701446687, 0.03532727435231209, 0.08543023227580956, 0.05739862072680678, 0.01154453119462622, 0.009257014923995095, 0.02701396508408444, 0.08172379580459424, 0.033498673367180994, 0.04680870094203523, 0.0692297201603651, 0.02219460395696972, 0.05105038279933589, 0.05082562825243388, 0.010637345141731203, 0.04451956466904708, 0.01851735297324402, 0.023464935166495185, 0.018408875579812696, 0.03627509277846132, 0.01166353012169046, 0.0725097923672625, 0.05991828587970563, 0.047798452832336934, 0.06595463518585477, 0.03997779391439898, 0.020694010192528367, 0.02088062428603215, 0.013636860929961716, 0.021943537518382072, 0.0026622794310761882, 0.011551229183429053, 0.020110480254516006, 0.03148877461041723, 0.03255701943167618, 0.04735734060938869, 0.03444971144199371, 0.015522815087544066, 0.07001538228775774, 0.01945182291923889, 0.044926936738193035, 0.040243043431213925, 0.05362060220379915, 0.042824685972716124, 0.08182575247649636, 0.004960273342606212, 0.030547473513122116, 0.03408021519758871, 0.037098986961479695, 0.05113664495625666, 0.030568687910480157, 0.014905729896521993, 0.006070068255732102, 0.0631186030805111, 0.08683321877781834, 0.653047994843551, 4.643226206302643, 20.64095275742667, 34.85532903671265, 40.63523319789341, 36.36144835608346, 30.214769635881694, 17.76319476536342, 14.812505006790161, 12.020395721708026, 22.90433018548148, 24.690071071897233, 19.170795576913015, 16.469560044152395, 7.353944727352687, 2.293613817010607, 0.15919819820140088, 0.18413368160171167, 0.02512638413879488, 0.43527071497270037, 0.5462475057159151, 1.1986777079956872, 0.7402410475271088, 2.279966903584344, 2.6502034025532857, 1.6298833468130656, 2.704843602010182, 2.6700687365872517, 4.946885500635419, 4.8587701831545145, 6.048603160040719, 2.151401779481343, 2.328963428735733, 2.309665241411754, 1.7511402687856128, 1.378820613026619, 0.6827982813119888, 0.6749975170407976, 0.28277162515691345, 0.22262010643524782, 0.5194678455591202, 0.9157491241182599, 0.8348417484334537, 1.2309806432042802, 1.5617714588131224, 1.5235204313482558, 1.776543208530971, 3.965670015130724, 7.711473839623587, 7.70715206010001, 5.57770984513419, 6.540341070720127, 4.372584751674107, 2.424297056027821, 2.4370884725025723, 1.7534003875085284, 1.7890398693936211, 0.984951336468969, 0.31805281341075897, 0.2489028482564858, 0.17464685280408176, 0.6579675365771566, 2.9225530283791676, 8.262759549277169, 13.595419457980565, 14.851866551807948, 51.11001777648926, 37.644561767578125, 11.941523245402745, 11.974960582596914, 17.466228757585796, 20.834670271192277, 28.69866749218532, 27.76805877685547, 14.384203280721392, 4.974583191531045, 0.6391200593539647, 0.13877594976552896, 0.06208297543759857, 0.03815953380295208, 0.019027950574776957, 0.046178820276899, 0.04335485252418688, 0.052352332044392824, 0.04091859968113048, 0.017600431639168943, 0.02816977145682488, 0.06870684786034481, 0.010484656950991069, 0.04371263725417001, 0.00539617780928633, 0.02291313013327973, 0.01888707822321781, 0.039262913167476654, 0.04590983542480639, 0.006168660666194877, 0.03422160832477467, 0.04547395470685192, 0.021873923218143836, 0.02515246193589909, 0.01518406835384667, 0.06747285050473043, 0.052845708427152464, 0.06383713095315866, 0.011530360838930522, 0.050082992030573745, 0.004801782829287861, 0.04355556996805327, 0.010110729872914297, 0.021173390094190836, 0.06059852402125086, 0.02358535647259227, 0.05291645588087184, 0.010918149225679892, 0.030132108301456486, 0.020641030178272297, 0.03176019540322678, 0.01660722091660968, 0.07642536690192563, 0.032050292872424634, 0.017694269639572928, 0.13613944766776903, 0.1150449203061206, 0.11989108526280948, 0.11569281268332686, 0.115899779434715, 0.12171186613185064, 0.0825151236993926, 0.12040880748203822, 0.12102783497955118, 0.1491150049758809, 0.11488002272588865, 0.08820993918925524, 0.0903039796810065, 0.07722811454108783, 0.11325825617781707, 0.10243930029017584, 0.16594812885991164, 0.17458003067544528, 0.15089154536170618, 0.11080828335668359, 0.1927496242736067, 0.2398540409547942, 0.1762171456856387, 0.11350076459348202, 0.14604380620377405, 0.1707004252821207, 0.09526402316987514, 0.09567784132169825, 0.17280387026923044, 0.13882613421550818, 0.1138564119381564, 0.10671254420386893, 0.13270509695368155, 0.14303812677306788, 0.07449013074593884, 0.14158802958471434, 0.07477654716266052, 0.1168082021176815, 0.1761477179825306, 0.1802461509193693, 0.10920601111969777, 0.1248702702245542, 0.16615949251822063, 0.1463218562837158, 0.1962037474981376, 0.11332775851977722, 0.07988140359520912, 0.12013622639434678, 0.17116689096604074, 0.13178968536002295, 0.10727700391518218, 0.21766745219273226, 0.10061515388744217, 0.12389577180147171, 0.16442962177097797, 0.48736070841550827, 5.546872002737863, 21.730671746390207, 38.361393519810264, 47.710055759974885, 46.35998950685774, 39.798142024448936, 33.076208046504426, 26.860754319599696, 25.171009744916642, 27.206107582364762, 26.118737084524973, 21.819481883730205, 14.695455653326851, 6.620046896593911, 3.464076736143657, 1.1738613482032503, 0.4111111770783152, 0.8224032244512013, 3.046641775539943, 4.005840591021946, 3.4433852178709845, 6.4762899705341885, 7.3409342254911145, 11.702466130256653, 16.71126355443682, 5.426544836589268, 6.771318733692169, 11.993903109005519, 8.319404738289968, 19.488865000861033, 9.454202771186829, 6.66975040095193, 3.7120490414755682, 2.6304716042109897, 1.2769339659384318, 0.7626186981797218, 1.1879691226141793, 0.4357459066169602, 0.10326358463082995, 0.5254868311541421, 0.8344465153557914, 0.5180847197771072, 1.424704670906067, 1.5414424410888126, 1.4568859040737152, 1.8579411378928592, 5.684221386909485, 6.811555317470005, 8.025793841906957, 14.833462510790143, 9.896030034337725, 9.242907183510916, 7.095866050039019, 5.942115502698081, 8.49158717904772, 7.202238627842494, 5.7810592991965155, 6.684355080127716, 1.656793937087059, 1.9084944937910353, 0.8761405380708831, 4.6548987456730435, 8.167934009007045, 12.369391577584402, 16.854309592928203, 54.98308958326067, 37.29005077907017, 14.661793368203298, 22.800996576036724, 25.94415317262922, 27.617301974977764, 34.492563588278635, 32.95163379396711, 15.878200599125453, 5.430974747453417, 0.5409073808363506, 0.2141670121678284, 0.3117312283388206, 0.15151268988847733, 0.06440448800900153, 0.20371872639017446, 0.12845279941601412, 0.1957819022770439, 0.18479818451617444, 0.11099208492253508, 0.1705137331570898, 0.18151935402836117, 0.09524808438228709, 0.16386980323919229, 0.10844177712819406, 0.06097534165850707, 0.08002717327326536, 0.13243983047349112, 0.14248235230999334, 0.04957594316718834, 0.14860686367111547, 0.1854346367929663, 0.14523884654045105, 0.16518568620085716, 0.06621905349727188, 0.18921767308243684, 0.10471132051731859, 0.11407323101801531, 0.14356503635644913, 0.21837732195854187, 0.10968911448227507, 0.14874126788760933, 0.11282565617667777, 0.14838431775569916, 0.17968398465641908, 0.12422004368688379, 0.10636298331831183, 0.12090324237942696, 0.1259747352451086, 0.07768731990030833, 0.10693243704736233, 0.08941259501235825, 0.14537653486643518, 0.15585578898234026, 0.11116272290902478, 0.18645017301397665], [0.04676219754453216, 0.0685225645346301, 0.08268411963113717, 0.031469880802822967, 0.05596486944705248, 0.006213003353747938, 0.055157853822622976, 0.028300192672759295, 0.03394882367657764, 0.015046827860974839, 0.08563975031886782, 0.006043592243388827, 0.019305759774787084, 0.009640188738038498, 0.03292208144973431, 0.012506878751862262, 0.025383467486660396, 0.04748548534033554, 0.04254608627940927, 0.02457367326132953, 0.04256554666374411, 0.10372519200401646, 0.04745827947876283, 0.04290589304374797, 0.03549867569069777, 0.055175607691385915, 0.012902471453084477, 0.012453220202587545, 0.029634837127689804, 0.03167385182210377, 0.023532398510724306, 0.028882592849965607, 0.015652189663212215, 0.040338167255478244, 0.04349954333156347, 0.07829365879297256, 0.04095218716455357, 0.03560271546510713, 0.024245718627103736, 0.029067225621214936, 0.0026886036212090403, 0.02913710455011044, 0.03374129713379911, 0.04736464164618935, 0.0045324498039138105, 0.03484198271429964, 0.010859920743054577, 0.008984773951981748, 0.029815863485315015, 0.041644839104264975, 0.030208979533719163, 0.06850826101643698, 0.034245353657752275, 0.017061174414785843, 0.016449531074613333, 0.07807344703802041, 1.0840653266225542, 6.317754226071494, 22.36694782120841, 33.167472634996685, 34.122714451381135, 28.723321437835693, 24.486337729862758, 23.033323492322648, 15.883925914764404, 16.694735527038574, 16.420193093163626, 16.28978409085955, 9.662384697369166, 10.262834991727557, 7.989952428000314, 3.522746022258486, 1.5064855111496789, 0.4701538745846067, 0.16037154809704848, 1.1844856866768427, 0.3255402302103383, 1.7492332054036004, 4.954513319901057, 0.7683038445455688, 0.29810475238731926, 2.5132353007793427, 2.6271597019263675, 2.8968449107238223, 4.092303974287851, 1.3406401532036918, 2.859633181776319, 2.3009797760418484, 1.3778164897646223, 1.2344679875033242, 0.3699827268719673, 0.4800294360944203, 0.12706277971821173, 1.304794722369739, 0.5171637034841946, 0.9972790692533765, 1.5250437153237206, 1.0154606593506676, 0.8086123530353818, 2.245506227016449, 1.9389395458357674, 2.622734133686338, 11.557403377124242, 5.400334928716932, 5.7669722608157565, 8.545940331050328, 3.069739976099559, 2.2939334341457913, 3.549858544554029, 1.3236888285194124, 1.9883560027394975, 0.4986433887055942, 0.9518018066883087, 1.1112553647586276, 3.301878639629909, 7.291750533240182, 14.622860874448504, 17.121577262878418, 13.106654507773262, 20.257684912000382, 45.78519977842058, 29.38788536616734, 18.309099095208303, 22.888370173318044, 22.571118899754115, 28.667633363178798, 16.17669173649379, 8.463703189577375, 1.4436242899724414, 0.08841636989797864, 0.04056271145652447, 0.04956478126613157, 0.05980928601430995, 0.046806431242397854, 0.04234627807246787, 0.09209554283214466, 0.0661650285390871, 0.03486737010202237, 0.04754483001306653, 0.04039039070318852, 0.007919609679707458, 0.015763187814237814, 0.041453980774219544, 0.03131163965112396, 0.031805884558707476, 0.014927476943869675, 0.016772420444924916, 0.025725888487483774, 0.05636023823171854, 0.0753736240523202, 0.014881392541740621, 0.04134491644799709, 0.09360531717538834, 0.010236233406301056, 0.03014012858537691, 0.021376799625743712, 0.06420753643448864, 0.019387384144855396, 0.06043897329696587, 0.020098507504111955, 0.014997254092512386, 0.05684543148215328, 0.013627676110315536, 0.05913113097527197, 0.038669843027102094, 0.03774025005155376, 0.008424729807302356, 0.03801901259326509, 0.036537349955844026, 0.05719134184931006, 0.02442782894442124, 0.039598041613187106, 0.04603024485654064, 0.04548082487391574, 0.03288089098142726, 0.010843477295046406, 0.048895470931061676, 0.023404618492349982, 0.006571139225603214, 0.016930466517806053, 0.06077778618782759, 0.016070007778970257, 0.04864693033908095, 0.03328840554292713, 0.010817973708201731, 0.024155515878062164, 0.008576337431025292, 0.07419863888727767, 0.0437069172039628, 0.045908542815595865, 0.025065047965784158, 0.06365890015981027, 0.03877450705372861, 0.029631410525845628, 0.03974146016740373, 0.060416466290397305, 0.05311167040573699, 0.087953921141369, 0.06089046371302434, 0.022552875535828725, 0.050162255098777156, 0.012121102756022342, 0.019983366896797503, 0.042336049157061746, 0.03484368583719645, 0.009403681116444724, 0.060177459115428586, 0.030426643389676298, 0.04380626151604312, 0.02077278301918081, 0.060216630942055156, 0.03192696574011019, 0.01737432850391737, 0.05687575860481177, 0.03371011166434203, 0.0716043755944286, 0.03962397861427494, 0.013117062393575907, 0.02888051314013345, 0.05723759079618113, 0.02308571890794805, 0.04862089155774031, 0.04903541538598282, 0.12544507080955164, 0.024180009295897822, 0.015589179205042976, 0.06630510530833687, 0.0463502623273858, 0.02933127073837178, 0.015530511370993086, 0.022780406987294555, 0.07043085606502635, 1.8306755380971091, 10.253698110580444, 28.448485442570277, 39.81843771253313, 37.97097076688494, 28.973288093294414, 21.016730444771902, 17.24638601711818, 11.4327118737357, 13.987884981291634, 21.126022134508403, 20.80150999341692, 17.63726908820016, 18.523211308888026, 10.629627789769854, 3.844506025314331, 1.3238617735249656, 0.5124380056347165, 0.32132112660578316, 0.08466533331998757, 0.2746774080608572, 0.5520485458629472, 0.6326446639639991, 0.5996747559734753, 0.4548119535403592, 1.5622128865548541, 2.5633522229535237, 2.5948284310953955, 2.7223411202430725, 1.0707420472587859, 1.8314969454492842, 1.2232310133320945, 1.174691440803664, 2.2527319192886353, 1.2021537614720208, 1.2603087723255157, 0.7077387315886361, 0.9737420465265001, 2.2447599470615387, 1.6403106387172426, 2.1260527968406677, 1.9271284767559596, 0.9120467113597053, 1.8371866515704562, 2.217319122382573, 2.5452749644007002, 5.962213601384844, 6.427981751305716, 3.108798840216228, 4.6119150178773065, 3.6401334490094865, 1.643060605440821, 1.195279821753502, 0.7553334576742989, 0.23898160776921681, 0.16940024362078734, 0.6667506024241447, 1.5741523887429918, 4.765068514006479, 8.40993629183088, 18.3951473236084, 22.158800636019024, 16.881525686808995, 17.525187696729386, 49.22031967980521, 30.811533042362758, 11.454145329339163, 21.85475962502616, 23.857277359281266, 32.55130638395037, 21.91900440624782, 12.396827408245631, 2.6108019053936005, 0.2175596465489694, 0.0747610494228346, 0.028509941417723894, 0.044281802605837584, 0.020213532760473232, 0.003453572338912636, 0.1357845738530159, 0.03756929315360529, 0.038439982504184754, 0.04985313829300659, 0.05132927765537586, 0.006151157007220068, 0.03870562217863543, 0.04969692596101335, 0.06338315031358174, 0.02725016142773841, 0.09798518608191184, 0.03168062699426498, 0.019963733486032913, 0.011753347802108951, 0.04278024871434484, 0.009240705486653107, 0.06460021822048084, 0.01475885251004781, 0.0709277947566339, 0.0417416660514261, 0.04365965723991394, 0.06970427398170743, 0.03366529103368521, 0.07268714106508664, 0.04600306613636868, 0.06389193622661488, 0.05303068385858621, 0.048727533513946195, 0.03489457257091999, 0.03422982199117541, 0.03292408652071442, 0.030467084076787745, 0.019739355526066253, 0.03579004880573068, 0.09117183275520802, 0.01555612776428461, 0.053649911523929665, 0.01911712364692773, 0.025656150354604636, 0.035948775109968016, 0.01615390693768859, 0.1882681040359395, 0.14501233798052582, 0.13404619427663939, 0.14535696591649735, 0.11574423206704003, 0.08346475381404161, 0.15820586787802832, 0.09064547957054206, 0.1732759406524045, 0.11936382284121853, 0.1334996750312192, 0.08093062907989536, 0.08141935071242706, 0.11738731818539755, 0.16925811767578125, 0.13600368638123783, 0.1366906352341175, 0.154247715270945, 0.1538939813950232, 0.10820838822317974, 0.14383254200220108, 0.12487029736595494, 0.1061178082600236, 0.17289134700383457, 0.1903730553707906, 0.14611183612474374, 0.11632041686347552, 0.09431780608636992, 0.10193383241338388, 0.14992850060973847, 0.11281986827296869, 0.1528943907469511, 0.15903136001101562, 0.14829270195748123, 0.12086052181465284, 0.1538897201951061, 0.11109074391424656, 0.17779996432363987, 0.07379590121230908, 0.1836434264800378, 0.12268640526703425, 0.11305119443152632, 0.0715050787797996, 0.1788701226136514, 0.16231943214578287, 0.20953435504010745, 0.14153796727103846, 0.2071563205016511, 0.12299908777432782, 0.09522949930812631, 0.19663376228085586, 0.13438795879483223, 0.12802114257855074, 0.15545879171362945, 0.10443472928766694, 0.224748236526336, 2.498023739882878, 12.043067693710327, 33.580317224775044, 47.88831179482596, 47.404126576014924, 41.824271474565776, 33.87031071526663, 31.954490865979874, 22.35355864252363, 22.635565178734915, 22.78297642299107, 23.60450189454215, 15.610201631273542, 16.06942023549761, 11.216805287769862, 4.906041383743286, 2.015866743666785, 0.9610899197203773, 0.5059799264584268, 2.5170164236000607, 1.4273263130869185, 3.531310111284256, 7.506964904921396, 1.9855159265654427, 1.5122681494270052, 6.9225558297974725, 7.4900599377495904, 6.904600381851196, 8.349500860486712, 5.042002430983952, 6.469232337815421, 8.605121612548828, 3.619837109531675, 4.670487029211862, 2.9693864924567084, 2.2890284402029852, 1.14601611665317, 2.458738842180797, 2.9566756316593716, 3.0813460733209337, 4.1609673755509515, 3.9703730770519803, 3.4969141398157393, 5.3000533155032565, 5.546191079275949, 7.053714369024549, 17.038693938936504, 9.752620952469961, 14.630875621523176, 18.491998263767787, 6.640362995011466, 6.56541451386043, 6.815832802227565, 4.562204131058284, 4.5792550104005, 1.4066846264260155, 1.5099473425320216, 1.6888843008450098, 4.605539611407688, 10.20780439036233, 19.233068806784495, 23.44798677308219, 19.062893526894705, 26.486890860966273, 51.805994510650635, 35.5809884752546, 23.908042635236466, 31.028084073747905, 32.10067401613508, 39.040729318346294, 24.455350501196726, 13.56416038104466, 3.017692974635533, 0.23862996378115245, 0.1497821541769164, 0.16269154075000966, 0.23830936955554144, 0.18374528815703733, 0.08937641552516393, 0.29171889647841454, 0.10102150815406016, 0.12013291514345578, 0.07379982993006706, 0.11977407868419375, 0.137534800650818, 0.15572883508035115, 0.16640528504337582, 0.14865339760269436, 0.10980509647301265, 0.15176586487463542, 0.15478976975594247, 0.12139919719525746, 0.12029881695551531, 0.17678892000445298, 0.0961528904736042, 0.13478501034634455, 0.18275803327560425, 0.24374446219631604, 0.0662588020786643, 0.10461382182048899, 0.08383642137050629, 0.09912547096610069, 0.18940802929656847, 0.12312372108655316, 0.2294921598264149, 0.12193651550582477, 0.20977362005838326, 0.2033663767256907, 0.15632228180766106, 0.10597625228443316, 0.1020547134269561, 0.15292914531060628, 0.12211623229086399, 0.21452757210603782, 0.1374507708741086, 0.11460836444582258, 0.17915003187954426, 0.1276552357843944, 0.10420826143984284, 0.11125823349824973], [0.07034659558641058, 0.028873049254928316, 0.022091129062963382, 0.026536064388762628, 0.06427000915365559, 0.0409932894233082, 0.08206227621329681, 0.07331317782934223, 0.024896803511572734, 0.01152449066285044, 0.08377937014613833, 0.08336914822991405, 0.023842338040204983, 0.08820126072636672, 0.042780818683760505, 0.11909553009484496, 0.020505886358608092, 0.04689547200021999, 0.0071791379845568114, 0.011744327527204794, 0.02809236927091011, 0.017092521036309854, 0.04303729813545942, 0.10851372219622135, 0.05279956804588437, 0.04115223964410169, 0.01857970016343253, 0.011896788408713681, 0.0035275377449579537, 0.03904847574553319, 0.023147333280316422, 0.04388993845454284, 0.010152034844005746, 0.08843331970274448, 0.022670351999944875, 0.017338542567033852, 0.0816480102283614, 0.04561109681214605, 0.024757262784987688, 0.032306327883686335, 0.06765833483742816, 0.0486864617892674, 0.04972979419731668, 0.02898783702403307, 0.06789966260216065, 0.047611621607627184, 0.030013008442308222, 0.06604805588722229, 0.012849680580464857, 0.034998184868267605, 0.057326716370880604, 0.06085558022771563, 0.0345396817927914, 0.02376458640875561, 0.0803458947422249, 0.0031361731650706914, 0.03875421207132084, 0.2573613300919533, 3.245513767004013, 12.119471822466169, 25.65190499169486, 34.442939553942, 36.42654602868216, 30.45816503252302, 28.929745469774517, 24.875277042388916, 20.840642247881206, 21.533964770180837, 22.028309992381505, 9.373336161885943, 11.276277525084359, 12.482508250645228, 10.203849996839251, 7.442700147628784, 3.910383633204869, 2.052498080900737, 0.8027377054095268, 0.5342753252812794, 0.04618925614548581, 0.14609732904604503, 0.9982523598841259, 0.6450171257768358, 2.09632471203804, 3.3203308837754384, 1.8397889690739768, 0.2552206606737205, 0.6805520047034536, 0.5312264774526868, 1.4411057851144244, 1.8042359054088593, 1.37678305378982, 1.0508695478950227, 0.4452489252601351, 1.1095152752740043, 1.9510960706642695, 1.3845791497400828, 0.9810121421303067, 1.173795991710254, 1.0726674582277025, 1.9203746105943407, 2.0445940707411085, 1.9704669969422477, 8.329167825835091, 7.660871846335275, 0.954959111554282, 2.2382251662867407, 2.9238553813525607, 0.7272123066442353, 0.5300640655415398, 0.6574232429265976, 0.536318475646632, 2.3209232773099626, 4.69285067490169, 9.338360667228699, 14.096268194062368, 15.47753620147705, 13.929612176758901, 15.934750250407628, 13.789294174739293, 20.813321931021555, 34.812691416059224, 29.237359591892787, 27.375895500183105, 24.258516720363072, 25.996950796672277, 14.00301034109933, 3.830325620515006, 0.8231445646711758, 0.022677661518433263, 0.03184347200606551, 0.08044216529067073, 0.02816511670659695, 0.06375423432993037, 0.0426842292238559, 0.027500386482902935, 0.03579090375985418, 0.0564654857984611, 0.02271107427908906, 0.034662228609834395, 0.05280007355447326, 0.040330055369330306, 0.03255939769691654, 0.03285422794786947, 0.07939857843198947, 0.06371442468038627, 0.02644646553588765, 0.036543972457626035, 0.05474006624094077, 0.035623037588915656, 0.018175493460148573, 0.008995251380838454, 0.03860012355393597, 0.10624207516333886, 0.04472266037815383, 0.02277803890007947, 0.006242222767988486, 0.0350187682280583, 0.06344663404992648, 0.03819206277174609, 0.023637188066329275, 0.015850510182125226, 0.02628981215613229, 0.03266290821401136, 0.06954589712300471, 0.0842273457508002, 0.09779824289892401, 0.060491071215697696, 0.04614315986899393, 0.07227244081773929, 0.044176775562976084, 0.015898635278322866, 0.01815026213548013, 0.03307537268847227, 0.06526209520442144, 0.04390095786324569, 0.030680425664676086, 0.022873798850923777, 0.07401287635522229, 0.04139592871069908, 0.07322363834828138, 0.01893280809079962, 0.05570341294099178, 0.021935693653566495, 0.041564622694360356, 0.03213540830516389, 0.03591373556160501, 0.023013836604409983, 0.011928196946558143, 0.05988177391035216, 0.04383869209725942, 0.04750110521646483, 0.027513801120221615, 0.09971276338079146, 0.04483976534434727, 0.044034435879439116, 0.037590137749378166, 0.03380452302683677, 0.03262485936284065, 0.021022395696491003, 0.0320099505728909, 0.044162078494472165, 0.05028433372665729, 0.0437290069114949, 0.07802126090973616, 0.026771817988316928, 0.022969538445717523, 0.06628271365272147, 0.04076889789264117, 0.07031544404370443, 0.037232393731496165, 0.006174533386781279, 0.05996716754244907, 0.010038210594627475, 0.026221047721004913, 0.08182048025940146, 0.0362395104020834, 0.07444572741431849, 0.06778175357197012, 0.04601237902949963, 0.029940544294991663, 0.05317578517964908, 0.0334774861112237, 0.0333680418053908, 0.028854521856244122, 0.06104443687945604, 0.01935163213472281, 0.014564704981499484, 0.03869220754131675, 0.0217438650184444, 0.07820394967815705, 0.052432419532643895, 0.022513607017961994, 0.0639570416616542, 0.6688762083649635, 5.304324286324637, 17.48579662186759, 33.336817605154856, 41.04184177943638, 39.619403089795796, 32.22804839270455, 20.909026418413433, 15.218053988048009, 12.293573703084673, 14.905127968106951, 20.191975797925675, 18.426848479679652, 22.61404660769871, 18.927309853690012, 11.373599205698286, 6.854264157158988, 4.5975252985954285, 2.3861907465117316, 0.662958025932312, 0.3369384785848004, 0.1402891914227179, 0.11525525259120123, 0.3519974776676723, 0.44685314489262445, 0.2543649465910026, 0.3715520698044981, 0.10879449320158788, 0.6415326584662709, 0.5260709683809961, 0.7967040634581021, 0.8125152321798461, 1.0190827335630144, 0.5408923987831388, 0.9056270644068718, 0.8135015506829534, 0.7996525423867362, 1.5289698817900248, 1.830101877450943, 1.1619109894548143, 1.5488397755793162, 0.8767495368208204, 1.1282324194908142, 1.1558198077338082, 1.5103624973978316, 1.2744903713464737, 2.373041932071958, 0.5820360481739044, 0.44497428142598694, 0.25245373057467596, 0.0942695215344429, 0.19899943391127245, 0.15204137723360742, 0.6080489637596267, 1.4592499200786864, 3.877717546054295, 7.475782258169992, 15.634200709206716, 19.832163333892822, 22.92358190672738, 21.48747784750802, 12.62093721117292, 17.69047318186079, 37.42415796007429, 29.823659011295863, 25.470833199364797, 28.037952865873063, 29.878963197980607, 19.088143280574254, 5.885839436735425, 1.7725501656532288, 0.07941411009856633, 0.09482246650648968, 0.12405829450913838, 0.049517724862588305, 0.08380016045910971, 0.054247975682041476, 0.03879244412694659, 0.04342096897640398, 0.050270169308143, 0.08828653900751046, 0.03216939951692309, 0.06365640315094165, 0.017840543129880513, 0.014335918240249157, 0.03162569958450539, 0.08090153349829571, 0.027118661341124346, 0.07468251577977623, 0.019942561497113535, 0.04961620743519493, 0.052445067425391505, 0.006026536417526326, 0.03588353396792497, 0.0014046906851165528, 0.04722708224185875, 0.08110442225422178, 0.026710173081872717, 0.0665775371183242, 0.012998442597953337, 0.02373294801717358, 0.024103121100259677, 0.03694698493927717, 0.03555188640686018, 0.06499426386186055, 0.03947999009064265, 0.019982220172615986, 0.05308664942692433, 0.007152341788501612, 0.05518124971006598, 0.07907436082937888, 0.050570624614400525, 0.10684945899993181, 0.04551331652328372, 0.007617065333761275, 0.02427972001688821, 0.06805486391697611, 0.055026133212127855, 0.01657780472721372, 0.11472558815564428, 0.13600718762193406, 0.15358929203024932, 0.11517374696476118, 0.12452514017266886, 0.16665045331631387, 0.09513943735510111, 0.12994849415762083, 0.129868087757911, 0.09601968047874314, 0.18387397910867417, 0.21668128296732903, 0.14111697700406822, 0.19085288819457802, 0.14319021361214773, 0.1878720567162548, 0.13520126443888458, 0.1274617040263755, 0.08383065382284777, 0.1801991962960788, 0.07867981307208538, 0.1139104776084423, 0.07240820888962064, 0.14871746487915516, 0.12612688993769033, 0.1470127406397036, 0.12202655710279942, 0.2481049724987575, 0.07853004003741912, 0.13276110323412077, 0.13197128847241402, 0.15287996509245463, 0.1618422863206693, 0.12236560748091765, 0.07761201608393874, 0.1306037147130285, 0.1764253338000604, 0.11156992534441607, 0.13208935356565885, 0.09738479794136115, 0.13663271548492567, 0.24658144425068582, 0.11939369195273944, 0.1617166759180171, 0.17275485289948328, 0.2574627303651401, 0.12680199156914437, 0.1342217448566641, 0.14090559977505887, 0.11020608352763311, 0.13174830829458578, 0.16570910811424255, 0.16914926708808967, 0.1911875688071762, 0.24917456081935338, 0.0938801442139915, 0.08709482116890804, 0.6565704058323587, 5.238586510930743, 20.456351280212402, 38.16754225322178, 49.09204551151821, 49.84367036819458, 43.40349279131208, 37.58679791859218, 34.50512245723179, 29.39003930773054, 31.116586753300258, 27.95978042057582, 15.851823500224523, 18.621754135404313, 17.84970678601946, 13.109082903180804, 10.286579591887337, 5.344643814223153, 3.1421708209174017, 1.77708386523383, 1.0003439847912108, 0.38904505542346407, 0.3186399090502943, 2.0611948370933533, 2.26118158016886, 4.3464230469294955, 6.738434646810804, 5.614853177751813, 3.806137638432639, 4.097494278635297, 2.887391669409616, 4.298864364624023, 7.079469169889178, 4.4298188005174906, 2.897824606725148, 3.158067430768694, 2.8815777642386298, 6.093666136264801, 4.125352646623339, 5.176610316549029, 4.0833399295806885, 4.905976678643908, 5.991986198084695, 6.74189658675875, 6.581899549279894, 15.305252143314906, 15.46165783064706, 4.637815296649933, 5.636725238391331, 6.547811686992645, 2.2371188827923367, 1.0765947103500366, 1.1509338127715247, 0.8857710127319608, 3.3335237758500234, 6.1928212727819165, 12.083917890276227, 18.9703973702022, 21.64338152749198, 20.19381012235369, 21.693811552865164, 19.09418821334839, 27.994118418012345, 40.772335052490234, 36.3313626561846, 35.55029828207833, 34.80088990075247, 36.00742374147688, 20.817018372671946, 6.295682838984898, 1.6514874675444193, 0.13191567574228558, 0.20370252297392913, 0.20584689719336374, 0.09663488103875092, 0.16408103119049752, 0.16152387697781834, 0.1719672501619373, 0.16774114407598972, 0.08582612353243999, 0.17531913172985825, 0.12583680264651775, 0.17871908071850026, 0.12895129195281438, 0.09941610108528819, 0.1278456598520279, 0.21945072364594254, 0.1376645772584847, 0.10492250097117253, 0.13818102383187839, 0.20228252559900284, 0.141895840210574, 0.12027293762990407, 0.1113853638193437, 0.2652260666447026, 0.2204355222306081, 0.13356944200183662, 0.09205972296851021, 0.1095357791387609, 0.15162610023149423, 0.10798060401741948, 0.06571629297520433, 0.09213472822947161, 0.10659717967999832, 0.17461695655116014, 0.09613999152289969, 0.18225152045488358, 0.17335222155920096, 0.17225242485957487, 0.16958610793309553, 0.15733411322746957, 0.14794595699225152, 0.16628932340868882, 0.0755558649876288, 0.07960796755339418, 0.13219010244522775, 0.11852153018116951, 0.12310352788439818, 0.17466764311705316], [0.04723619157448411, 0.052884578305695734, 0.01975465309806168, 0.011859609778704388, 0.04918875412217208, 0.03591293149760791, 0.027848636099536504, 0.006402105974432613, 0.05972635546433074, 0.023484700891588415, 0.027952066888766627, 0.019988415197336247, 0.0684366620012692, 0.03371154676590647, 0.005113532775015171, 0.03975802320720894, 0.013851372142588454, 0.06748351707522358, 0.03440487724063652, 0.009722020061287497, 0.009589821931772997, 0.019748771895787547, 0.03263828078550952, 0.0445411420826401, 0.010304842626542916, 0.04756036846499358, 0.0067066274017893845, 0.03425300074741244, 0.07815592296953712, 0.04464374336280993, 0.054094178934714625, 0.0494416169822216, 0.011813389669571604, 0.0833648598885962, 0.08783683313855103, 0.02484949435373502, 0.03059823132519211, 0.03694674066667046, 0.025118667499295304, 0.033019128920776505, 0.035923740560454984, 0.025856492907873223, 0.03897250357217022, 0.031680657528340816, 0.027552421637145535, 0.030600989570042918, 0.035344366649431844, 0.042712147547198195, 0.015540636809808868, 0.02670645640630807, 0.020930805343336294, 0.03418224650834288, 0.1420510754521404, 0.01950239752685385, 0.020444517955183983, 0.08739022138927664, 0.019364171461867433, 0.0716732604695218, 0.039673342036881616, 1.1933695014033998, 7.807088000433786, 17.995683227266582, 31.900628430502756, 36.57697800227574, 34.468036447252544, 30.66765669413975, 26.08103268487113, 26.54210298401969, 22.071235963276454, 26.489197662898473, 18.778852905545914, 14.359921063695635, 17.240731920514786, 17.90409902163914, 18.374935013907297, 11.089660201753889, 7.727465987205505, 4.466235612119947, 2.7493559334959303, 1.8726430918489183, 0.7085629616464887, 0.7302330902644566, 0.3817262681467192, 0.2503757035093648, 0.527672256742205, 0.11903870957238333, 0.5041487504329, 0.07585445432258503, 0.3438257175896849, 0.4670277823294912, 0.312224306166172, 0.5839332863688469, 0.7459610977343151, 0.657289978648935, 1.5746086899723326, 1.0804696338517326, 1.2608654967376163, 0.7101763007896287, 0.38687140920332497, 0.5640876027090209, 0.5047744682856968, 1.8320736459323337, 0.840992098408086, 3.123680578810828, 0.681968514408384, 0.42434695256607874, 0.7339979825275285, 0.41158338316849297, 2.2018971613475253, 3.5844377747603824, 8.061678682054792, 12.240609322275434, 16.37267436300005, 23.88213106564113, 23.216505799974712, 21.288656881877355, 20.967125517981394, 21.256359917776926, 17.32674888202122, 18.620989833559307, 25.98228141239711, 29.40126759665353, 30.09321437563215, 19.40653579575675, 7.691575067383902, 2.927339251552309, 0.2595620634300368, 0.022920334478840232, 0.0481542630254158, 0.04648515508909311, 0.0356460568894233, 0.014127221224563462, 0.013257788860106041, 0.02932249049523047, 0.024596468645281026, 0.007438946498690971, 0.030053021652357917, 0.029121348966977427, 0.010648165230772324, 0.03238980465435556, 0.07508352997579745, 0.007170791155658662, 0.018947785054998736, 0.02536534720898739, 0.036844359910381694, 0.04942431094657097, 0.011003771015176815, 0.008722536282480826, 0.06466293521225452, 0.0131757904476087, 0.10593554696866445, 0.02513657573477498, 0.012462430467296923, 0.04749441146850586, 0.019513384705143313, 0.05439023394137621, 0.03733580246833818, 0.013855446745375437, 0.025077375250735452, 0.022719907108694315, 0.07080605878893818, 0.042682885724518976, 0.06227013575179236, 0.014118979568593204, 0.009963392778964979, 0.01704676742000239, 0.048799688927829266, 0.039582740648516586, 0.05032771247039948, 0.04742289048486522, 0.009491986511940402, 0.057539762796035836, 0.05769026864852224, 0.04063043603673577, 0.04919696778857282, 0.05877827240952423, 0.04401598311960697, 0.04731390079749482, 0.044285714360220094, 0.04762033738994172, 0.03846942413864391, 0.013437084105264927, 0.01523237326182425, 0.02292533528192767, 0.03646577808207699, 0.028146155045500824, 0.027333728104297603, 0.042088017466345, 0.05757708900741168, 0.05095196808023112, 0.05241472673203264, 0.0914245124108025, 0.04112496253635202, 0.034857992748064656, 0.00834511305272047, 0.026736817455717495, 0.022102394440610493, 0.006931571938496615, 0.05317658245829599, 0.03569293348118663, 0.0439779648025121, 0.04115453987781491, 0.0024067333891123, 0.04622762051544019, 0.046827350477022786, 0.017679145094007254, 0.007559151521750859, 0.06240803442363228, 0.041502041409590414, 0.013020307540760508, 0.11007515341043472, 0.02314987269762371, 0.053694793222738166, 0.03596623720867293, 0.04155462448086057, 0.024568686028942466, 0.020809376412736516, 0.07452538742550782, 0.012289946017387723, 0.01930021444734718, 0.044688655595694265, 0.02235929628035852, 0.006592002905173493, 0.012252985366753169, 0.019791975916762437, 0.06021998290504728, 0.049075811968318055, 0.026181880983390977, 0.017081550821395855, 0.05761617262448583, 0.05019593079175268, 0.016922590422577093, 0.010678169201128185, 0.04170261636110289, 0.11109864206186362, 2.613529507602964, 11.154915945870535, 23.62952756881714, 37.999705042157856, 40.54511158806937, 35.85921171733311, 30.883644921439036, 18.789084127971105, 18.580773660114833, 13.487080539975848, 12.238860981804983, 17.1760824067252, 22.81256185259138, 24.499391657965525, 23.9181626864842, 16.915691716330393, 12.976136939866201, 10.788942166737147, 5.316919633320399, 3.1080575542790547, 1.4000943686280931, 0.35918522626161575, 0.2681516653725079, 0.22359412988381727, 0.17609135886388166, 0.3482868682060923, 0.19118165198181356, 0.2696411854454449, 0.232975107218538, 0.45737049196447643, 0.2493761671440942, 0.3229929826089314, 0.3311539404094219, 0.29379046389034813, 0.526278762945107, 0.6886220659528459, 0.4857184908219746, 0.3727559266345841, 0.34423946110265596, 0.2612573967448303, 0.24717765940087183, 0.45644453593662804, 0.3263115616781371, 0.28952828688280924, 0.45899088787181036, 0.2056407853960991, 0.2772418904517378, 0.5168221018144062, 0.3979638011327812, 1.8830532303878238, 3.810905839715685, 8.568648781095233, 15.03084693636213, 19.81846843447004, 28.328196491513932, 27.024443456104823, 19.9426657472338, 14.755191053662982, 13.994899187769208, 13.332659431866237, 19.724957840783254, 30.442243235451834, 31.40235573904855, 34.63143375941685, 24.566304547446116, 12.071907060486929, 3.9575375829424178, 0.6689338024173463, 0.007510442037268409, 0.060890328006020615, 0.03297527180984616, 0.09913237845259053, 0.033416567237249444, 0.04453569683911545, 0.030940453854522536, 0.018226122350565026, 0.028930382071329013, 0.03711276800770845, 0.030441584730786935, 0.015914971008896828, 0.03040436708501407, 0.05566546247739877, 0.029444718400814703, 0.08312324035380568, 0.0032596858343042967, 0.012828569659697158, 0.08087050409189292, 0.04075603286868759, 0.0313586655205914, 0.05298331193625927, 0.09220456305359091, 0.04382431394021426, 0.028224843055275933, 0.008187146707704025, 0.04127751417191965, 0.056030375217752795, 0.033826955394553285, 0.0426271508580872, 0.023269469583673135, 0.007456720723504466, 0.054320758740816794, 0.037931345868855715, 0.07565252230103527, 0.10969773187701191, 0.03738348990944879, 0.03142275315310274, 0.03242768047909651, 0.028025275728266155, 0.03253769475434508, 0.010320425183246178, 0.04044752674443381, 0.0553065445939345, 0.027138924093118737, 0.046915023986782343, 0.06850947559412036, 0.06223621578621013, 0.024935851505558406, 0.09323715764497008, 0.12796932964452676, 0.09299827260630471, 0.15746664468731197, 0.0741488276315587, 0.09138128294476441, 0.10344680944191557, 0.13845644119594777, 0.09323314750300986, 0.09517916558044297, 0.17112868944449083, 0.15483787788876466, 0.13583934519972118, 0.07049703358539514, 0.09811340205903564, 0.24763762471931322, 0.12036208356065409, 0.13866346223013742, 0.13175860845616885, 0.07007844533239092, 0.07540606481156178, 0.09778094704129867, 0.10076843494815485, 0.1302927556846823, 0.16238383868975298, 0.1838418844022921, 0.10364594589918852, 0.0740735170298389, 0.15586421638727188, 0.11948058514722756, 0.10522030320550714, 0.201211702344673, 0.12931729374187334, 0.15980075086866105, 0.19571282741214546, 0.20510106507156575, 0.1279094557144812, 0.1466237772256136, 0.162874826629247, 0.136371696633952, 0.15439951712531702, 0.1664829230202096, 0.1050705166001405, 0.11383393885833876, 0.16645593089716776, 0.21652417496911117, 0.12847125556852135, 0.08323591109365225, 0.12904958453561577, 0.12736527062952518, 0.11621497252157756, 0.09943320016775813, 0.13467321491667203, 0.12254050666732447, 0.1163946350238153, 0.12079360469111375, 0.06332429418606417, 0.13496293579893454, 0.1511724860008274, 2.399167810167585, 11.315956950187683, 27.89533587864467, 44.15164702279227, 48.357551438467844, 47.122450079236714, 41.74227578299386, 32.71881355558123, 33.07932431357247, 30.37435586111886, 34.953840596335276, 28.862855161939347, 22.10747603007725, 27.812172889709473, 25.86271854809352, 24.02498255457197, 13.998435820852007, 10.501816545213972, 6.287339789526803, 4.02026765687125, 2.6464246681758334, 1.2582907548972537, 1.2476032312427248, 0.8140957302280835, 0.9258234692471368, 1.0939985364675522, 0.45371704229286736, 1.1151234486273356, 1.6129633975880486, 1.543251361165728, 1.3081859861101424, 1.4935643587793623, 2.0087648161820004, 2.360651339803423, 1.4313489943742752, 4.651887135846274, 2.908523746899196, 3.642710579293115, 2.671867234366281, 1.4594431668519974, 2.44113775236266, 2.192649109022958, 4.060174201216016, 2.8200321410383498, 5.542860286576407, 1.9012242896216256, 1.751887200134141, 1.826427583183561, 0.7724444280777658, 3.6543021287236894, 4.957374240670886, 10.862031136240278, 16.80337061200823, 22.129140513283865, 32.127997807094026, 31.028792790004186, 28.286090408052715, 27.866493906293595, 27.71076566832406, 23.862144572394236, 27.480015993118286, 35.41916840417044, 38.532214982169016, 41.68729816164289, 28.81365670476641, 13.830885222979955, 3.8962701048169817, 0.7219533345529011, 0.08309386657284838, 0.11905295880777494, 0.14923730412764208, 0.17996769371841634, 0.21493195183575153, 0.10026595262544495, 0.13857757326747688, 0.1406915219766753, 0.14180214809519903, 0.17881513413574013, 0.09987234803182737, 0.12374284357896873, 0.1740363748478038, 0.21017657486455782, 0.07801510659711701, 0.19817631665085042, 0.13610226394874708, 0.12797855772078037, 0.1489093681531293, 0.13039244604962213, 0.09605908300727606, 0.16456979353513035, 0.13036763880934032, 0.2933685779571533, 0.14567597237016472, 0.07442485567714487, 0.187159961355584, 0.12024381490690367, 0.15137832638408455, 0.15852107453559125, 0.07604716505323138, 0.1483417328979288, 0.10638139875871794, 0.10823455931884901, 0.14772915148309299, 0.17027939430304936, 0.11956339356090341, 0.12554028284336838, 0.08236726413347892, 0.08515925931611232, 0.16579335502215795, 0.17524407218609536, 0.17471971389438423, 0.0700682130243097, 0.11103301415485994, 0.11776216807109968, 0.20646110709224427, 0.11575848130243165, 0.11646543336766106], [0.022317976890397922, 0.03637348035616534, 0.023498945037967393, 0.013724474219738372, 0.04470916431663292, 0.023001098805772405, 0.03274118062108755, 0.02328169339203409, 0.05221645201423338, 0.029805973837418214, 0.04789526620879769, 0.03585941544068711, 0.02817297074943781, 0.04582771572417446, 0.031544967487986596, 0.046005576715937684, 0.03506022671769772, 0.032366493583789895, 0.02522492777955319, 0.03362060271735702, 0.019158517675740377, 0.03085644104118858, 0.0362345910231982, 0.0146322955510446, 0.011147991088884217, 0.05441567221922534, 0.061070743682129044, 0.046591335641486306, 0.028323841314496737, 0.024457837155620967, 0.048342414000736814, 0.0743506375168051, 0.0655904043731945, 0.017670200306123922, 0.09364513361028262, 0.1086427184886166, 0.06403919868171215, 0.009000420121343007, 0.018879897626382963, 0.04118873804275479, 0.05110950355551072, 0.029335606577140943, 0.0357843660749495, 0.029851757987801517, 0.026060155193720545, 0.04252896344821368, 0.08642880512135369, 0.038930970443678756, 0.02200507725189839, 0.04327365902385541, 0.03465539236952152, 0.04377860103600791, 0.024977153932143534, 0.029542342626622746, 0.024649202690592835, 0.04144937012876783, 0.07239707412996463, 0.1112646252981254, 0.10408074435378824, 0.022388446144759655, 0.0310314895052995, 3.0720561146736145, 10.868361813681465, 20.820773874010357, 30.51739147731236, 34.87537111554827, 34.14531346729824, 29.349819660186768, 28.478755269731792, 31.376671722957067, 28.40296605655125, 21.027849299567087, 14.75286340713501, 14.185094833374023, 38.036575657980784, 28.73953332219805, 16.01265171595982, 15.242271934236799, 13.93546255997249, 10.03654866559165, 8.221480301448278, 4.47405754668372, 3.729158980505807, 2.984264756952013, 2.132071239607675, 1.278896506343569, 0.8194617480039597, 0.4603568602885519, 0.4583412855863571, 0.2041999434253999, 0.4041484578379563, 0.2692068416093077, 0.14714973685996874, 0.43357402458786964, 0.5659978144935199, 0.269072844513825, 0.5112710882510457, 0.5136697366833687, 0.8641018612044198, 0.2861496981765543, 0.3767686741692679, 0.6777535634381431, 0.9424205443688801, 0.8802799816642488, 1.5098893685000283, 3.5327446971620833, 5.48594411781856, 8.308692353112356, 11.315935237067086, 15.154523134231567, 16.20447584560939, 13.424602338245936, 17.900084699903214, 10.929228033338275, 12.96990614277976, 17.281844411577495, 29.042321920394897, 39.01564284733364, 25.641232558659144, 26.230778523853846, 25.809762852532522, 24.957910231181554, 15.801442112241473, 4.579392671585083, 0.6183647587895393, 0.030026959122291634, 0.05666636948340705, 0.06625706502901656, 0.0189952451868781, 0.036156912334263325, 0.034157934598624706, 0.0329055218026042, 0.01360405545814761, 0.07368261300559555, 0.036475053655781915, 0.04732878107045378, 0.024270549616111175, 0.030502445929284607, 0.014153854572214186, 0.02822054623227034, 0.012475215763385807, 0.011327999643981457, 0.02909855019035084, 0.04538271549556937, 0.11528447030910424, 0.021282831007348638, 0.0459928643623633, 0.07416394539177418, 0.02909543571461524, 0.025192960298487117, 0.0605082381516695, 0.027706038572692444, 0.059043871371873786, 0.02061411439042006, 0.05188778322190046, 0.04136374579476459, 0.05545044830068946, 0.01889846912984337, 0.019153985061815808, 0.05086168221064976, 0.08680237936122076, 0.03708463255316019, 0.0838671318654503, 0.03352955349587968, 0.025906171849263564, 0.06640170155359165, 0.036505021154880524, 0.06553120219281741, 0.0762472650302308, 0.020493706655023352, 0.04568161017128399, 0.029458367132714817, 0.01488267327658832, 0.03018860991245934, 0.03971766733697482, 0.037549320475331376, 0.08004903567156621, 0.03162331114123974, 0.03954941100840058, 0.07331355102360249, 0.0698802520387939, 0.035243984178772995, 0.018044373353144953, 0.08293213775115353, 0.09105262772313186, 0.0688410010188818, 0.02032209836345698, 0.02403338805639318, 0.07802604458161763, 0.02362770214676857, 0.06248918721186263, 0.02258031888465796, 0.0494529654804085, 0.03625360018174563, 0.05623121479792254, 0.06798118179930107, 0.050590190171663246, 0.01479595310852996, 0.009158638372485126, 0.04411332236070718, 0.015191623841279318, 0.031808615662157536, 0.009383643129175263, 0.09188151253121239, 0.04021532188302704, 0.017979960023824657, 0.017631274448441606, 0.03728450182825327, 0.03290475505803313, 0.033440197219273875, 0.04627882955329759, 0.0239056606244828, 0.0949026286335928, 0.018343768448435833, 0.04615755159673946, 0.051161608259592734, 0.09483183028974704, 0.055641086106853824, 0.054675123654305935, 0.0430794792648937, 0.0355426922573575, 0.008743695548868604, 0.06139319709369114, 0.02440599029484604, 0.0419695384667388, 0.02712595389623727, 0.08674038161656686, 0.006571860593144915, 0.023150865055088485, 0.05194674791502101, 0.03033403693033116, 0.03615484619513154, 0.06216809765568801, 0.11848239228129387, 0.1222769772367818, 0.07260480084057365, 0.5362074673175812, 5.660920602934701, 16.171862738473074, 27.736376728330338, 37.369298458099365, 40.215933731624055, 35.60933712550572, 28.601795707430156, 19.42220398357936, 19.365544898169382, 20.074919496263774, 13.416258420263018, 19.790434190205165, 20.274805273328507, 38.218583720070974, 29.606308937072754, 22.809202398572648, 20.739082166126796, 17.861086198261805, 11.921522855758667, 10.610462921006338, 7.389463918549674, 2.924460308892386, 2.382242215531213, 1.6052235386201312, 1.0549179592302866, 0.5329035446047783, 0.3537118099629879, 0.2325087365295206, 0.08706834473248039, 0.06882590361471687, 0.16382447709994657, 0.09551075207335608, 0.29705834282296045, 0.20182207173534802, 0.3992936212037291, 0.06649793817528657, 0.24357944247978075, 0.24860350574765885, 0.1639129037835768, 0.3546589362834181, 0.43008331475513323, 1.1963643921273095, 1.8489616768700736, 2.0522149418081557, 3.583030547414507, 6.994233012199402, 10.155284694262914, 14.48502859047481, 20.52902943747384, 23.021383013044083, 20.055384635925293, 23.97682111603873, 18.36052792412894, 15.814037459237234, 17.04628484589713, 26.101632356643677, 35.50254331316267, 25.458227430071148, 26.69333921160017, 29.771161896841868, 30.034752232687815, 20.2553277356284, 7.2288841009140015, 1.231638333627156, 0.08451480032610041, 0.030352543972964798, 0.02587776498070785, 0.01608939013177795, 0.019838175669844662, 0.1041096295895321, 0.10679259098001889, 0.02709261916710862, 0.05099991675732391, 0.029607817863247225, 0.015314482784430896, 0.06575592620564358, 0.0020559034310281277, 0.03615415748208761, 0.020539840250941258, 0.05518882894622428, 0.034220437851867506, 0.03101591712662152, 0.07406316937080451, 0.10055186692625284, 0.029598338729036704, 0.03598983326394643, 0.04405444926981415, 0.051938541033970456, 0.025073317611323934, 0.047602515667676926, 0.039283133511032374, 0.07654288238180534, 0.023926703691748635, 0.042370284641427655, 0.023542819112273197, 0.14474595870290483, 0.032425275072455406, 0.05058546756793346, 0.03741221568946328, 0.0667836217741881, 0.015843422883855443, 0.0564805967733264, 0.028579474293759892, 0.023697664196203862, 0.05805844853499106, 0.03528772933142526, 0.04436644306406379, 0.06447687412479094, 0.04538256282519017, 0.0332321923093072, 0.01921130939652877, 0.02133078986246671, 0.06726641301065683, 0.043304467906377146, 0.032135767928723774, 0.1239073204674891, 0.09360913054219314, 0.09543294446276766, 0.16553636666919502, 0.15392560112689221, 0.1577334582273449, 0.18475255982152053, 0.14640053920447826, 0.14689091646245547, 0.19837899506092072, 0.10573829005339316, 0.11665211192199162, 0.17957830961261476, 0.12927014912877763, 0.13611933588981628, 0.13276145607233047, 0.13391336426138878, 0.16879302263259888, 0.12933646914150032, 0.17619258271796362, 0.1326847273324217, 0.08270963254783835, 0.11155862773635558, 0.07003410985427243, 0.10574933660349675, 0.19356815463730268, 0.21169343989874634, 0.15131659326808794, 0.14626629783638886, 0.10484337021729775, 0.19016812422445842, 0.20004866618130887, 0.14076455948608263, 0.18219982965716294, 0.160939074786646, 0.21008961381656782, 0.19445660124932015, 0.13108689949980804, 0.08951908429818493, 0.1448603325656482, 0.2287895232439041, 0.15516679095370428, 0.14543948934546538, 0.12439524142869882, 0.16014965357525007, 0.09559062921575137, 0.1914261688611337, 0.18542892352810927, 0.1577004407133375, 0.08547506986984185, 0.1829150462789195, 0.09875369484403304, 0.05059972698135035, 0.1637735462614468, 0.06435335360999618, 0.17163248812513693, 0.18677487916180066, 0.16799600182899407, 0.28064634491290363, 0.11518300218241555, 0.39728795311280657, 4.928612172603607, 16.852112225123815, 32.18869379588536, 45.78934785297939, 50.24904217038836, 49.096947465624126, 42.03843232563564, 37.59236689976284, 42.639753750392366, 37.99877398354666, 28.670054810387747, 21.851916074752808, 21.460543155670166, 49.11104883466448, 36.815957818712505, 21.772147280829294, 21.87360313960484, 18.90165536744254, 13.719742706843785, 10.992402791976929, 6.504654688494546, 4.925102463790348, 4.323237776756287, 3.1369086461407796, 1.9631240538188388, 1.543096655181476, 0.9884283670357296, 0.966608309320041, 0.9038373061588832, 0.769130680177893, 0.6624825085912431, 0.5574370910014425, 1.114673987030983, 1.3753495535680225, 1.323911713702338, 1.1237325923783439, 1.100257234913962, 1.175106487103871, 0.6222640009863036, 0.9783007161957877, 1.0248924046754837, 1.2825874111482074, 1.4814161935022898, 2.42832635981696, 4.862186091286795, 8.227327210562569, 11.723293355533055, 15.648173536573138, 22.32478788920811, 23.159598316465104, 19.62252402305603, 26.25031512124198, 17.997873646872385, 19.821975537708827, 23.95866026197161, 36.272924831935335, 45.720703125, 33.340368134634836, 36.39720378603254, 35.628045150211875, 33.87166561399187, 20.95310926437378, 7.161723681858607, 1.1380848565271922, 0.14904211674417767, 0.18002355072115148, 0.15882827447993414, 0.09054159585918699, 0.11343439029795782, 0.18855117527501924, 0.19851367069142206, 0.11293810299996819, 0.16410980107528822, 0.08989390704248633, 0.16132658613579615, 0.1367085078465087, 0.06948664065982614, 0.1096979354375175, 0.15877947424139294, 0.12476542299347264, 0.08022122071789843, 0.1259967197797128, 0.3022382791553225, 0.1918054156537567, 0.13623465970158577, 0.0733023484104446, 0.20834368893078395, 0.1308962990130697, 0.07156315459204571, 0.14267538195209845, 0.12080602188195501, 0.19313218231712068, 0.11782563823674407, 0.13461552586938652, 0.16125880048743316, 0.19101599444236073, 0.11511229883347239, 0.10970761813223362, 0.14686164446175098, 0.17458035637225422, 0.0832291596702167, 0.1844220454139369, 0.15698203497699328, 0.08622975008828299, 0.19852376729249954, 0.14700212835201196, 0.19370011612772942, 0.14897648883717401, 0.12125776335597038, 0.1471257574324097, 0.17129092716744967, 0.09878144014094557, 0.11241801947887455, 0.10387959264750991, 0.15170049481093884], [0.04731816878276212, 0.04865647054144314, 0.05163523927330971, 0.0738254649830716, 0.018510055329118456, 0.02186502592771181, 0.06172286333250148, 0.06100341943757875, 0.04058474688125508, 0.017649367584713867, 0.015576974056395037, 0.11249054130166769, 0.029748033732175827, 0.02731959252352161, 0.035199886187911034, 0.0791089932567307, 0.023160037152203064, 0.015899322295029248, 0.07750490933124508, 0.08050009861056294, 0.01832961929695947, 0.0981591556753431, 0.06486836847450052, 0.043806838270808966, 0.07209929903703076, 0.027616702652137195, 0.04915540073333042, 0.02340573807513075, 0.013793918886221945, 0.021138645708560944, 0.04185079823115042, 0.03182457819847124, 0.021814678629328097, 0.02979376699243273, 0.015675534660528814, 0.017461891751736403, 0.010842277984400945, 0.03299018261688096, 0.053508674459798, 0.04666682266231094, 0.014916179335809179, 0.024638459784910083, 0.06765866053423711, 0.04537222873685615, 0.01330004632472992, 0.014902788447216153, 0.05002981863383736, 0.060525004751980305, 0.06726761401763984, 0.018328937369265726, 0.04234721105811851, 0.037928781006485224, 0.07819487766495772, 0.05368344811722636, 0.12459718702094895, 0.05319293515224542, 0.09942215361765452, 0.029458567300545316, 0.04961741862020322, 0.06465733051300049, 0.020035537758043835, 0.02329876702944083, 0.2078685922814267, 3.674954346248082, 12.185748951775686, 21.2025009563991, 31.32427535738264, 36.12259013312203, 34.70901387078421, 31.22604172570365, 25.784467935562134, 32.514661584581646, 16.403277703693934, 16.710836240223475, 22.688130038125173, 47.6001352582659, 32.834532329014365, 20.920932156699045, 21.150488478796824, 20.50487228802272, 15.395731585366384, 20.013325452804565, 18.383899927139282, 13.406785420009069, 11.806465898241315, 9.389922380447388, 8.393555045127869, 7.319756984710693, 6.013343223503657, 4.834088444709778, 4.442383749144418, 3.721371352672577, 3.612082919904164, 3.2632197311946323, 2.8494770867483954, 3.2418362157685414, 2.654261801924024, 2.5050926634243558, 2.5670742860862186, 4.077831310885293, 4.457080057689121, 5.378279175077166, 6.648102853979383, 8.741711906024388, 13.277414304869515, 18.838188784463064, 17.460095235279628, 15.355689116886683, 14.559554100036621, 13.263124465942383, 17.42021778651646, 19.136756352015905, 16.947524888174875, 21.563774279185704, 22.76190253666469, 23.163742916924612, 25.940229177474976, 29.563268320901052, 30.207276003701345, 26.700264828545706, 16.631526027406963, 7.699760913848877, 1.8513822555541992, 0.1400891864406211, 0.023773831448384693, 0.03327555408967393, 0.05222353252715298, 0.044611842038908174, 0.08618126876120057, 0.041575866019619365, 0.044925399856375794, 0.003757647629494646, 0.060984875075519085, 0.037795116393161673, 0.0342059816632952, 0.056154292675533464, 0.050660964766783376, 0.021074887165533643, 0.05794980150780507, 0.02674270374700427, 0.0221259871032089, 0.002474635448639414, 0.08645580402974572, 0.026274843673620905, 0.024707351445353458, 0.01818414478163634, 0.004496644359148506, 0.01916192561787154, 0.013406215850929064, 0.012185989363518144, 0.07589281190718923, 0.0428520614680435, 0.042900566543851576, 0.037860259147627015, 0.012922031073165792, 0.03617674591285842, 0.01504321805467563, 0.04240134118923119, 0.007261652083668325, 0.021263730246573687, 0.016231056369308914, 0.04197326023131609, 0.07531216235033103, 0.07194535979734999, 0.01046910577653242, 0.015744059912062118, 0.06664022696869713, 0.07148313495729651, 0.022614486515522003, 0.02527205373293587, 0.006529528913753373, 0.034581001182751994, 0.02173036047523575, 0.07631886404539857, 0.045919429909970076, 0.06237566151789256, 0.02418498126124697, 0.007877445513648646, 0.023943266731553843, 0.06008872030568974, 0.063604820918824, 0.04941605996074421, 0.03284393457163658, 0.03289030226213591, 0.052230266987213066, 0.047130391001701355, 0.06600208513970886, 0.046272047595786195, 0.04310181324503251, 0.0675958146208099, 0.02733473403246275, 0.06925495487770864, 0.02080455542142902, 0.030228969175368547, 0.0767534589394927, 0.06338741829884903, 0.013201478935245956, 0.055313048352088244, 0.09890043482716594, 0.00993705798672246, 0.025366838289690868, 0.12005637639335223, 0.02340752601490489, 0.015788602343361293, 0.01808280896927629, 0.08401131377156291, 0.035779002255627086, 0.037930053259645186, 0.0034885518793349285, 0.007037827977910638, 0.06898252306772129, 0.014654090095843588, 0.007410291964853448, 0.033177577025656185, 0.027887338040662662, 0.04755735576951078, 0.0011107126317386115, 0.06667121566299881, 0.033373405624713214, 0.03959138857732926, 0.0682419767337186, 0.006444936801147248, 0.021980960420998077, 0.07336633426270314, 0.06245346912848098, 0.014035791175306907, 0.09484275470354728, 0.062241759417312484, 0.06566165733550276, 0.054428594918655496, 0.010897322441451252, 0.021468917539875423, 0.048065412257398875, 0.057194775236504417, 0.0746508553358061, 0.02892403437622956, 0.026557938661426306, 0.021000504460451857, 1.0127434794391905, 6.601184274469103, 16.284102201461792, 28.893614837101527, 38.39966419764927, 40.69148928778512, 37.153779234204976, 33.82372999191284, 23.332071713038854, 19.70152677808489, 11.400777953011648, 13.263593469347272, 33.487371172223774, 40.83038377761841, 26.11953960146223, 23.798849957329885, 30.515574523380824, 27.19206527301243, 24.815070901598247, 22.05765744618007, 23.658650943211146, 17.630016905920847, 15.802053553717476, 12.032193762915474, 8.265463267053876, 9.524684429168701, 5.550415584019252, 5.973579551492419, 4.6384866663387845, 4.119651215417044, 2.9779429818902696, 2.4858567927564894, 3.579363852739334, 3.0670577543122426, 3.960726806095668, 3.9905888608523776, 4.05531827892576, 3.783866924898965, 4.986634407724653, 7.68953229699816, 9.282953994614736, 11.26126594202859, 13.635541830744062, 21.32049352782113, 19.421265976769583, 23.257024220057897, 22.72620964050293, 19.882727112088883, 18.248809576034546, 15.853808947971888, 15.622685807091848, 14.25027414730617, 17.87131220953805, 23.718756335122244, 28.31554208483015, 32.254361220768516, 32.76113850729806, 30.956253596714564, 21.39897690500532, 11.467796802520752, 3.32563887323652, 0.296313039958477, 0.042086412731025896, 0.06447302683123521, 0.11679315221096788, 0.013696120785815375, 0.06320263285722051, 0.03534714525033321, 0.021524226625583003, 0.017134403610335927, 0.032096107556883774, 0.0757253494645868, 0.009921330393158963, 0.012351638421283236, 0.005994049009002213, 0.024947405260588442, 0.043568967641996484, 0.01869047270156443, 0.014100603992119431, 0.01934961010036724, 0.07673711303089346, 0.025617465376853943, 0.026177132934597985, 0.030431718831615787, 0.014197037388969744, 0.010910903319849499, 0.034972980684999905, 0.013178691184813423, 0.0784949054941535, 0.022775915085471103, 0.04877578074644719, 0.025575207912230065, 0.018009332108444402, 0.015494313224085739, 0.0341982531494328, 0.06172873944576297, 0.059789567786668024, 0.045405080009784014, 0.024462196743115783, 0.020221103514943804, 0.05722902768424579, 0.011039785109460354, 0.016204873399276818, 0.010774520325607486, 0.05862136118646179, 0.05716499433453594, 0.010870761188146259, 0.08297649358532258, 0.0201106583699584, 0.022223981130602102, 0.027753729406478148, 0.06393173230545861, 0.03102514859555023, 0.040184319618024995, 0.11323824618011713, 0.11025115860892193, 0.17292983351009233, 0.1601880993694067, 0.20828599988349847, 0.11667480213301522, 0.16099946440330573, 0.09042585814105612, 0.17812306912881987, 0.1231634153851441, 0.21140222623944283, 0.2241709525031703, 0.1330911833792925, 0.12012538340474878, 0.1575880210314478, 0.16998073032924108, 0.1462348545236247, 0.129656140559486, 0.2707813142665795, 0.16775411766554627, 0.16694238622273716, 0.2775782538311822, 0.17358322202094964, 0.2260960784873792, 0.11496342825038092, 0.25650507318122046, 0.1576799489557743, 0.1339420120098761, 0.1886709231351103, 0.21399043021457537, 0.1427574846893549, 0.13818149880639144, 0.10604771559259721, 0.10997071330036436, 0.18662014603614807, 0.1145773825368711, 0.1129709305241704, 0.19603536224790982, 0.20810772159269877, 0.15449403705341475, 0.14750262935246738, 0.10832090968532221, 0.1082557567528316, 0.22578882426023483, 0.1275679218981947, 0.16852234144295963, 0.13581402227282524, 0.18594283238053322, 0.1970924383827618, 0.08726313178028379, 0.1556914070887225, 0.16046040904309067, 0.1436051106346505, 0.19475826434791088, 0.1665849204042128, 0.14474823858056748, 0.27135931753686493, 0.14101189907108033, 0.1731118844555957, 0.19349270154322895, 0.14395880379847117, 0.10620286940996136, 0.8205971813627652, 6.946561855929239, 18.471263102122716, 34.52207606179373, 46.72564540590559, 50.903423513684956, 48.235686983381, 43.744357517787385, 35.20648404530117, 42.90377834865025, 24.49475720950535, 23.131650924682617, 34.196837833949495, 56.431604862213135, 43.06185334069388, 28.523793492998394, 30.791442326137, 29.728791781834193, 23.222217219216482, 24.91086745262146, 24.898626463753835, 18.389632190976823, 14.690779515675136, 12.057922942297798, 11.179133892059326, 9.779255134718758, 8.094198857034955, 6.805735332625253, 6.220512015478952, 5.335681072303227, 4.9500187039375305, 4.462031517710004, 3.920656110559191, 4.423972759928022, 4.193926155567169, 3.3812848244394575, 4.03111857175827, 5.9762042335101535, 6.111147803919656, 7.708298512867518, 10.046865003449575, 11.810482825551714, 18.915970393589564, 26.57003821645464, 25.096693549837383, 23.753519909722463, 23.722223486219132, 20.54542718614851, 24.468715361186437, 26.349554504667008, 24.61075391088213, 28.636276142937795, 30.158690725054058, 33.182136808122905, 35.88883188792637, 38.860635484967915, 39.74915722438267, 34.601740632738384, 22.785001822880336, 11.408886500767299, 2.6111768909863065, 0.3175857370453221, 0.13869433557348593, 0.10155491810292006, 0.12601582732583794, 0.15691720774131163, 0.12777039674775942, 0.09130148044122116, 0.14378300894583973, 0.0773511261546186, 0.09630547264324767, 0.0812608449320708, 0.14637730616543973, 0.1380434576421976, 0.1737234616386039, 0.13998975391898835, 0.18488053152603762, 0.07138866252665009, 0.10572244626070772, 0.09689944862787213, 0.19036990696830408, 0.07506207469850779, 0.10153275714921099, 0.175801922966327, 0.09396011635128941, 0.1430027343864952, 0.16553103338394845, 0.17997684037046774, 0.21242062587823185, 0.15422294874276432, 0.18067415723843233, 0.21577404093529495, 0.0883017246212278, 0.1102645800315908, 0.0848918825920139, 0.24048334147248948, 0.13415097365421907, 0.17103404738008976, 0.10602816021335976, 0.16138548297541483, 0.23922381762947353, 0.18214646966329642, 0.06798504266355719, 0.11895828960197312, 0.2138744278677872, 0.17192530312708446, 0.1073836764054639, 0.15480054489203862, 0.1831221758787121, 0.1189360607947622, 0.09490053196038518, 0.18913134985736438, 0.14245618799967424, 0.11747277288564614], [0.029979984142950604, 0.03940840803885034, 0.022681045711838772, 0.024327872254486595, 0.03739008526983006, 0.03855830544073667, 0.054634082463702986, 0.07336381011243377, 0.07088056193398577, 0.09858651060078825, 0.0160364762746862, 0.009745437152949827, 0.05161899853763836, 0.05255368391850165, 0.026601227499278526, 0.029757210918303047, 0.12688026736889566, 0.02574216654258115, 0.07736411331487553, 0.0119419618775802, 0.10749336837657861, 0.03239553148991295, 0.10035095949258123, 0.05469037712152515, 0.08128755885575499, 0.02165057323873043, 0.03577152479972158, 0.03690160112455487, 0.024225187853776982, 0.08015621706311192, 0.07418277473854167, 0.12949601986578532, 0.04205370395045195, 0.0629007119153227, 0.04351435914369566, 0.030844013672322035, 0.056517892450626404, 0.072992793949587, 0.07750693136560065, 0.009196615129310106, 0.06400054932704993, 0.03607976968799319, 0.0926801889602627, 0.03993102928091373, 0.025111317268705795, 0.04948891426569649, 0.0838565399338092, 0.04767373131055917, 0.06731572215046201, 0.0711625407316855, 0.024429857764126997, 0.02258674630762211, 0.020168941135385206, 0.04066956375858613, 0.03318524107869182, 0.023296234397483722, 0.062454955120171816, 0.06848992021488291, 0.04818691073783806, 0.15113736502826214, 0.011927120620384812, 0.05829928096915994, 0.056380132878465314, 0.0346264324949256, 0.6458017293895993, 4.1824164646012445, 13.689833317484174, 24.52159983771188, 30.8179566519601, 32.76471682957241, 35.916676793779644, 34.812708786555696, 33.25867468970162, 24.252544743674143, 19.618737254823955, 53.880837781088694, 55.580440112522666, 22.992589678083146, 20.897424663816178, 15.53117629459926, 18.1555369581495, 22.67719531059265, 23.222998891557964, 21.590319871902466, 18.197045496531896, 18.130985498428345, 19.942816870553152, 20.30007587160383, 21.165703296661377, 17.321150371006556, 16.015001944133214, 14.829496826444354, 16.351994786943706, 16.397774730409893, 13.919359241213117, 14.400661826133728, 11.722856487546649, 11.522669332368032, 12.585977349962507, 22.58183823313032, 22.45919210570199, 15.228309529168264, 18.533025639397756, 20.629595926829747, 22.323116847446986, 22.88263096128191, 28.436548437391007, 15.323699610573904, 14.560946345329285, 20.2857243674142, 22.336031811577932, 24.034571068627493, 22.566569566726685, 32.54870775767735, 34.4014344896589, 34.3869058064052, 31.36559976850237, 26.669215066092356, 18.085884741374425, 9.822111623627798, 5.151716223784855, 0.7369344649570329, 0.012312223170218723, 0.08042440124388252, 0.05910603875028236, 0.049381190046135864, 0.0777548069932631, 0.03940243014533605, 0.029920639470219612, 0.06110743885593755, 0.042355428117194345, 0.036243527329393795, 0.045288348237850835, 0.01125215893677835, 0.001874902518466115, 0.0075843022703858355, 0.03498293479372348, 0.04114825325086713, 0.013759550239358629, 0.05499615553500397, 0.11529660251523767, 0.03463030692988208, 0.015623555485425251, 0.02547435725240835, 0.0275606726229723, 0.01871406875683793, 0.013637815968000462, 0.07906076298760516, 0.04221247775214059, 0.04400647345132061, 0.07722079314823661, 0.03293404062943799, 0.02177054331904011, 0.02493618568405509, 0.03568750859371253, 0.010824222167554711, 0.022592766609575068, 0.012861418388118702, 0.013494376209564507, 0.08374627120792866, 0.04498625087684818, 0.05291122776855316, 0.03175976114081485, 0.037884035014680455, 0.034924455253141265, 0.050537454430013895, 0.011318461986125579, 0.026404155484799827, 0.02116932736576668, 0.024041903670877218, 0.09985248731183154, 0.042047091626695225, 0.032092837018093893, 0.04312316334939428, 0.0503492898839925, 0.013948970923333295, 0.07267878829900708, 0.07081545649894647, 0.01774988745871399, 0.039919087064585516, 0.050830886898828406, 0.0309580923723323, 0.02198614103586546, 0.006543862966022321, 0.03013327538168856, 0.04364231049216219, 0.02696792987574424, 0.04085067154041358, 0.026190308388322592, 0.06529836290116821, 0.01988112015117492, 0.011618985994053739, 0.017592452067349638, 0.015613011051235455, 0.006031041465965765, 0.05224264007327812, 0.027775976873402084, 0.056113366835883687, 0.03283295926770993, 0.0518374596722424, 0.07165230730814592, 0.028063071825142418, 0.03479302302002907, 0.024408287135884166, 0.026371553573491316, 0.08171200286597013, 0.031670455754335435, 0.041144429706037045, 0.07474044231431824, 0.09207436575421266, 0.01669338807862784, 0.04398488925237741, 0.042818345062966855, 0.07122068439743348, 0.0535778511049492, 0.027532196204577173, 0.026612418238073587, 0.06103507988154888, 0.020888100045600107, 0.03598851012066007, 0.01148989301041833, 0.01697893936320075, 0.062409065796860626, 0.021791399789175818, 0.03946649402912174, 0.045382861380598376, 0.03862046264111996, 0.056268462977771244, 0.03903772435816271, 0.042897048339779885, 0.03580805712512561, 0.01222960474634809, 0.04367704130709171, 0.03125093112300549, 0.047944880689361265, 0.08502066853855338, 0.01654087545882378, 0.06644242722541094, 0.048001419619790146, 0.04447553453168698, 1.3693226426839828, 6.786987355777195, 17.66483085496085, 32.02913188934326, 37.93722684042794, 41.1374385697501, 38.09021922520229, 37.53153542109898, 26.255583592823573, 20.50269229071481, 20.566271781921387, 58.46480410439627, 46.93094730377197, 17.781584909984044, 17.200293404715403, 19.992612872804912, 18.901382650647843, 25.321580682482036, 32.00230489458357, 28.63960085596357, 28.34291798727853, 26.802271332059586, 30.160743917737687, 24.852796145847865, 22.492659841264995, 23.241993529456003, 25.889733144215175, 19.901395184653147, 21.42695903778076, 20.87413603918893, 18.103692974363053, 19.617693287985666, 16.31590758051191, 16.39669602257865, 19.346923725945608, 21.622338908059255, 25.19311022758484, 20.846416200910294, 22.1043267590659, 22.26984327180045, 31.941139902387345, 29.97255195890154, 33.44977099554879, 16.125856978552683, 13.882135135786873, 14.006837929998126, 18.119376795632498, 19.437133925301687, 21.131995848246984, 31.772788524627686, 34.996971539088655, 36.996294839041575, 33.681281498500276, 30.883603232247488, 22.74681626047407, 13.425205962998525, 6.634654181344168, 1.331346394760268, 0.14239820039698056, 0.0493820789270103, 0.07846289899732385, 0.030572141653725078, 0.030043152360511676, 0.027469197620770762, 0.024869592560987388, 0.0882164327693837, 0.02048480766825378, 0.01718712578128491, 0.00573520571093208, 0.056019074217017205, 0.009065124372552549, 0.0344502203432577, 0.04903469953153815, 0.029205941927752326, 0.03643879274438534, 0.024420380326254026, 0.06067931718592133, 0.04508650781852858, 0.050691006904734034, 0.021368382398837378, 0.08969575446099043, 0.02794735785573721, 0.10383932837950331, 0.04555116181394883, 0.07521039566823415, 0.040429277545107264, 0.0935358012627278, 0.020257052300231795, 0.028953418335212127, 0.016251906054094434, 0.032308031006583145, 0.010507837403565645, 0.013349369035235472, 0.015413006069138646, 0.038809404109737704, 0.08339337871542998, 0.01611867909585791, 0.12347255593964032, 0.0398717049642333, 0.05516641014920814, 0.03568420412817171, 0.0063519677496515214, 0.10502987235252347, 0.02979968042512025, 0.009614691088375236, 0.01879851583258382, 0.09828525462320872, 0.05773467198014259, 0.0427612938385989, 0.027976845291310122, 0.04095137631520629, 0.04766229460281985, 0.15738716109522752, 0.11621704883873463, 0.12053790555468627, 0.11626717900591237, 0.09902145833309207, 0.11163185523556811, 0.09960211467530046, 0.1418092455714941, 0.12260507605969906, 0.13480115947978838, 0.07957168628594705, 0.15270659939518996, 0.10488896098520074, 0.18136744360838616, 0.090947732994599, 0.16697444021701813, 0.21303729207387992, 0.09438874692256961, 0.11675906261163098, 0.15360155994338648, 0.19340595762644494, 0.1354303378611803, 0.2599056735634804, 0.15525909885764122, 0.11139939592352935, 0.08119992605809655, 0.1213771855192525, 0.154606076755694, 0.15102592243679933, 0.1669348951961313, 0.13776012855981076, 0.21078873558768205, 0.17674480165754045, 0.11830363901598112, 0.1271025011582034, 0.14103977328964643, 0.16455467577491487, 0.13664772467953817, 0.1870376079210213, 0.12079338755990777, 0.14691884496382304, 0.17503308850739682, 0.16490900676165307, 0.09504900220781565, 0.1250557274158512, 0.12458193355372973, 0.1500697173178196, 0.10235755039112908, 0.13410350334431442, 0.135259496314185, 0.1286802307835647, 0.0961994786879846, 0.07323361281305552, 0.120801909959742, 0.10736294716064419, 0.11878728520657335, 0.12588933482766151, 0.24506234005093575, 0.16712561781917298, 0.22807461874825613, 0.1258553537939276, 0.1558937733726842, 0.17736138642898627, 0.1498330578740154, 1.2352562823465891, 6.665033442633493, 20.312403712953838, 36.42295033591134, 48.114041396549766, 49.9446450642177, 50.88758162089756, 47.485403129032676, 42.82785538264683, 32.55116047177996, 28.201245955058507, 61.01205539703369, 66.17867333548409, 31.777575833456858, 29.215809753962926, 24.172546659197124, 27.68198275566101, 31.360961845942906, 34.60667732783726, 31.146762779780797, 27.5667017187391, 25.878940854753765, 29.26633358001709, 27.016055243355886, 28.30116105079651, 23.662870236805507, 23.293118374688284, 19.935891253607615, 22.804135424750193, 22.692710638046265, 18.59996632167271, 19.45704572541373, 16.893337624413626, 16.633360351834977, 18.337706565856934, 28.277815103530884, 31.103746482304164, 21.240127188818796, 26.052473851612636, 28.148833956037247, 33.19383757455008, 33.451928411211284, 37.24746526990618, 22.3890152999333, 20.362640925816127, 27.8829402923584, 30.275941576276505, 31.920986652374268, 33.26621001107352, 43.845467703683035, 45.80152457101004, 45.853528363364084, 40.830849306924, 34.01397861753191, 22.84378010886056, 12.326344013214111, 6.087974693093981, 1.1097584622246879, 0.22162882105580398, 0.19947212854666369, 0.1320824053670679, 0.1675891386611121, 0.14935314362602575, 0.10038394307983772, 0.11513695679605007, 0.2564484290778637, 0.1137551066598722, 0.10870126249002558, 0.10289940810097115, 0.10895767408822264, 0.11204822467906134, 0.07979283441922494, 0.11761199470077242, 0.21634610023881706, 0.1258899997919798, 0.11444399612290518, 0.23379912014518464, 0.0956158639330949, 0.10298251507005521, 0.1523551589676312, 0.15557179493563517, 0.0974375404683607, 0.1710961197635957, 0.13205835808600697, 0.19863370353622095, 0.1477069091051817, 0.2260232445384775, 0.13749856688082218, 0.11333650483616761, 0.13122950041932718, 0.15604360747550214, 0.07192919709320579, 0.10664239046829087, 0.109963059425354, 0.1464251293135541, 0.18366184192044394, 0.11110875223364149, 0.27822183072566986, 0.10369252054286854, 0.1412032866584403, 0.18057243126843656, 0.1327405029109546, 0.14035901267613682, 0.14352828689983912, 0.1170281967414277, 0.19058505685201713, 0.26269154836024555, 0.12678892298468522, 0.12764948180743627, 0.18504959531128407, 0.19994968149278844, 0.10234784734036241], [0.05549658528928246, 0.02615572345842208, 0.05281754583120346, 0.05687180953100324, 0.06746401597878762, 0.032302158285996745, 0.006713324542423444, 0.035629544739744494, 0.015652437328494022, 0.002702042643379952, 0.04121798290205853, 0.06816055253148079, 0.03998870136482375, 0.04193017325763192, 0.0380320608216737, 0.04969903959759644, 0.08480530152363436, 0.018015444012624875, 0.06696454635156052, 0.04062872273581369, 0.028056009971935834, 0.028180287053276385, 0.01686400401272944, 0.022413497657648156, 0.0102461883631934, 0.008177393614979727, 0.0652029812335968, 0.06244175761405911, 0.020363728183188608, 0.01558589848822781, 0.030147175171545575, 0.016216471259083067, 0.11886862798460893, 0.08353491433496986, 0.05939712348793234, 0.03811375304524388, 0.008958986228598016, 0.09637698344886303, 0.052836985859487734, 0.04720026653792177, 0.011817421015751148, 0.020848263254655258, 0.0604235976934433, 0.011328675634493785, 0.04447098495438695, 0.022248477941112857, 0.01700678135135344, 0.05851955379226378, 0.05828803085855075, 0.03319779397653682, 0.1049065486128841, 0.06260583416691848, 0.015079831804281898, 0.03963216853195003, 0.015783615110974227, 0.03437462814950517, 0.06252239471567528, 0.023481810332408974, 0.03227063015635524, 0.028902107517101934, 0.05423966023538794, 0.02723029052971729, 0.057240773125418594, 0.1500805603074176, 0.06696774903684855, 0.05863176312829767, 0.4798638735498701, 2.9676016739436557, 8.845194901738848, 19.04066971370152, 28.080269132341655, 36.2443642616272, 40.73533589499337, 34.835158416203086, 32.27100910459246, 41.977767603737966, 70.44441563742501, 51.056686878204346, 31.280619825635636, 23.900978054319108, 24.63538006373814, 24.055031776428223, 17.805749007633754, 20.099495274680002, 22.496097462517874, 17.464661938803538, 17.64080572128296, 29.164354869297572, 20.932028429848806, 22.65069661821638, 17.913395711353846, 23.634170702525548, 20.656511511121476, 14.050892983164106, 18.63506167275565, 12.63310524395534, 17.838679994855607, 23.725612470081874, 18.87418740136283, 47.55486079624721, 35.22716883250645, 13.406371133668081, 16.218750919614518, 17.94321390560695, 13.67336174419948, 16.727815900530132, 27.025004523141043, 22.891807794570923, 26.466612543378556, 33.610767705099924, 35.53289304460798, 36.288172653743196, 36.99257755279541, 30.074405602046422, 23.464787517275127, 13.645701834133693, 9.645744630268641, 5.559021362236567, 1.9195918525968279, 0.5505939839141709, 0.08789527535970722, 0.014219937097680355, 0.05795525014400482, 0.02831692704265671, 0.03394285935376372, 0.02548823498987726, 0.04879116992067013, 0.020061279680313807, 0.05036316592512386, 0.018209214954237853, 0.01941229316538998, 0.023286041105166078, 0.029876395594328642, 0.03902220626228622, 0.03660859613280211, 0.04433658752324326, 0.06838108319789171, 0.013474685123323329, 0.008238440562438751, 0.07113731958504234, 0.04934299530993615, 0.03500986245593854, 0.06684734299778938, 0.10042668400066239, 0.022248523742226616, 0.021108569643859352, 0.060295273150716505, 0.08246584848633834, 0.011977417876810899, 0.03845449297555855, 0.05270428815856576, 0.02959213013361607, 0.040522511649344645, 0.026756255787664225, 0.06463691339428936, 0.03413336145292435, 0.05385715647467545, 0.032538994148905785, 0.03822916167389069, 0.03023278932752354, 0.015215850934120161, 0.05879389228565352, 0.020992709789425135, 0.0672034246048757, 0.05655546971995916, 0.00831548821380628, 0.02780014798710389, 0.09307677910796233, 0.020269474580085704, 0.019380132301843593, 0.01862525870092213, 0.033973980362394025, 0.039448193939668794, 0.0787573696247169, 0.0297190297528037, 0.05233046964609197, 0.06795038988015481, 0.029255081433802843, 0.024111974285915494, 0.030170167330652475, 0.07139519003352948, 0.050579167370285304, 0.02831656572275928, 0.05339216660442097, 0.0322369171439537, 0.025807202427781055, 0.04423118728612151, 0.04421676841697522, 0.04934081721252628, 0.043133439762251716, 0.05857925808855465, 0.061414828790085654, 0.012213850011383849, 0.02691886161587068, 0.03397050965577364, 0.018083786059703146, 0.07536338495888881, 0.024823959384645735, 0.04785636240350349, 0.012977318954654038, 0.0255955232506884, 0.09029479910220418, 0.0205556840436267, 0.044439935191933594, 0.01737165846861899, 0.023687260558030436, 0.05762434897146054, 0.026917893007131558, 0.03468045745311039, 0.02380197199194559, 0.01822213426099292, 0.028248408576473594, 0.03695595177954861, 0.0630278354510665, 0.040403608565351794, 0.07130095509013959, 0.020972961027707373, 0.03327365079894662, 0.05041996269885983, 0.015945220100028173, 0.010542021997805153, 0.02537828347911792, 0.021023097980235304, 0.029815432615578175, 0.08026596331702811, 0.02937808965465852, 0.015447655459865928, 0.06600093841552734, 0.020183595795450465, 0.036631934344768524, 0.04328168270045093, 0.052186247027878246, 0.024655582616105676, 0.040194721559860876, 0.016581446763926318, 0.018759413555796658, 0.058990606372909885, 0.058394791558384895, 0.0687595157484923, 0.12476455446864877, 0.09933790670973913, 0.17088801307337625, 1.1153631614787238, 4.473071336746216, 13.039154495511736, 24.0756870337895, 36.6984464100429, 43.42121764591762, 47.377740791865754, 37.681553976876394, 32.4863407271249, 45.43220002310616, 72.99815654754639, 46.04825162887573, 25.256382261003765, 13.899052262306213, 18.06777252469744, 19.437026228223527, 20.44965842791966, 21.688532658985682, 18.272827761513845, 17.40806712423052, 22.836322954722814, 27.59510248047965, 31.311831133706228, 25.463556698390416, 21.552243743624004, 26.6910080909729, 28.220483779907227, 23.915190594536917, 25.15102846281869, 22.144661051886423, 22.18976354598999, 25.038575342723302, 19.405239956719534, 49.4735815184457, 40.594176292419434, 17.264923810958862, 19.723043612071447, 18.61247307913644, 17.060221195220947, 18.660057817186626, 26.506397928510392, 18.423117297036306, 20.011359112603323, 29.456033297947474, 33.655684334891184, 36.17024782725743, 38.67629977634975, 34.94739614214216, 30.55055522918701, 21.145376341683523, 16.337947266442434, 9.459112542016165, 3.573314360209874, 1.4776399561337061, 0.2295409600649561, 0.06583551157798086, 0.07711025979369879, 0.0424559564728822, 0.005873564938415906, 0.02201791513445122, 0.0204971468275679, 0.04070947518838303, 0.017551146248089414, 0.02070831031804638, 0.041826282760926654, 0.02750663409408714, 0.03487513254263571, 0.07448605953582696, 0.024378843805087463, 0.010393935122660227, 0.0418492036738566, 0.08066391732011523, 0.013811003549822738, 0.03984120481514505, 0.07266723284763948, 0.0458159499269511, 0.0393932665299092, 0.02128812188415655, 0.05294898145699075, 0.03180879208126238, 0.049099964422306845, 0.0404604324804885, 0.014681468983846051, 0.03570233119119491, 0.04297328514180013, 0.04793224636731403, 0.03932477520512683, 0.05282835489405053, 0.048670936908040724, 0.013209589125056351, 0.02640560924607728, 0.03843279681833727, 0.03449462367487805, 0.03940925960029874, 0.07190551622105495, 0.03818583721294999, 0.020269114956525818, 0.03502196412799614, 0.052908656120832474, 0.01317155045191092, 0.04527370205947331, 0.04264486062207392, 0.0076557867827692205, 0.032924520783126354, 0.030218960783843483, 0.03562530389587794, 0.035512002118464024, 0.04352358721994928, 0.02959825051948428, 0.03167092055082321, 0.16955577741776193, 0.131092137790152, 0.19544943368860654, 0.143626850896648, 0.1438700785594327, 0.17010944842227868, 0.11557776028556482, 0.06852962129882403, 0.11264405306428671, 0.16196606467877114, 0.16954741786633218, 0.13086881834481442, 0.1756060163357428, 0.12093263651643481, 0.13940976932644844, 0.2097377119851964, 0.1441282204219273, 0.1469455656728574, 0.18293810289885315, 0.12077590849782739, 0.18167847049023422, 0.10402226820588112, 0.12486025504767895, 0.08625270492796387, 0.10449754127434321, 0.23744993710092135, 0.17884379545492785, 0.1126987294160894, 0.10566855700952665, 0.0792798280183758, 0.18515844589897565, 0.0943067188241652, 0.14064455378268445, 0.16641550378075667, 0.1293738428503275, 0.1159635888678687, 0.11023262781756264, 0.13608863896557263, 0.14434527020369256, 0.14872092540775025, 0.09366465506276914, 0.12040119431912899, 0.09910164760159594, 0.11366509898964848, 0.13373710800494465, 0.05851160136184522, 0.08173458451139075, 0.14357558079063892, 0.1253771223127842, 0.12445815519562789, 0.13816327335579054, 0.10199314315936395, 0.12864767467336996, 0.16807843026305946, 0.10164164166365351, 0.11052997543343476, 0.19177600794604846, 0.19308416917920113, 0.08825966902077198, 0.09906189223485333, 0.10416674866740193, 0.17297942084925516, 0.15630255000931875, 0.2157098108104297, 0.25193674117326736, 0.24601807019540242, 1.061681704861777, 4.509057794298444, 13.7738596200943, 28.6401914528438, 44.84377792903355, 52.98000035967146, 57.78831706728254, 47.79317011151995, 44.412141936165945, 51.39210074288504, 76.92868300846645, 60.58446325574602, 40.705920696258545, 33.19600888660976, 35.014321190970286, 32.13278859002249, 28.606169598443167, 28.70572338785444, 29.95931911468506, 24.6079329422542, 27.195290974208287, 41.320589610508506, 33.24536541530064, 32.83006463732038, 26.239651373454503, 35.11728654588972, 30.016012941087993, 24.669447081429617, 27.99199226924351, 20.05932947567531, 27.120378971099854, 32.14805030822754, 25.606767756598337, 59.85677146911621, 44.92039918899536, 20.988666670663015, 25.685080902917043, 26.910222019468033, 22.195025069372996, 25.976448399680002, 37.36612313134329, 31.770106519971574, 35.570052010672434, 42.87963683264596, 45.156502451215474, 47.31701701028006, 46.44022730418614, 42.00870793206351, 33.903867040361675, 21.900874819074357, 15.441657441002981, 8.604960066931588, 3.108445784875325, 1.1215195911271232, 0.26276890135237146, 0.11733427031763963, 0.15308222281081335, 0.1669239436409303, 0.18630981126001903, 0.11594452203384467, 0.13034588497664246, 0.13128987646528653, 0.10384498736155884, 0.10101844117577587, 0.12710288113781384, 0.1478772892483643, 0.08379272371530533, 0.2049110345542431, 0.10101637164396898, 0.14460917961384567, 0.1105317599805338, 0.15659518859216146, 0.09186701223786388, 0.06917089795959847, 0.16298337866153034, 0.1896380390971899, 0.1180727199784347, 0.18552326703710215, 0.08774912570204053, 0.05881403120500701, 0.21287642499165876, 0.15369195437857083, 0.06652191760284559, 0.18072522378393582, 0.17858561288033212, 0.13793022371828556, 0.12808630908174173, 0.13208148255944252, 0.184351097792387, 0.08972264480377946, 0.12335843992020402, 0.2064974494278431, 0.12479860335588455, 0.11515271237918309, 0.12753164741609777, 0.14043099167091505, 0.11574370280972548, 0.1974467829402004, 0.17860020138323307, 0.14301931778235094, 0.08334753010421991, 0.14135793835989066, 0.19234546167509897, 0.10193565767258406, 0.10488264382417713, 0.12682887512658322, 0.13467576620834215, 0.14207094295748643, 0.11322581541857549, 0.21539233784590447], [0.04388491390272975, 0.01859915885142982, 0.020256685891321728, 0.022568419076768414, 0.04303537109600646, 0.012101571125510548, 0.05984910923455443, 0.01741520345344075, 0.0482503503694066, 0.02752954652532935, 0.038358361526791535, 0.02433659991116396, 0.04889405957822289, 0.07577331510505506, 0.007922549432675754, 0.008225309213490357, 0.04002746607043913, 0.020319877857608453, 0.01965016549054001, 0.0379374764327492, 0.06674953217485122, 0.07875173778406211, 0.046831255446055105, 0.022194325757612075, 0.006678690842818469, 0.06073026838047164, 0.08854045359683888, 0.009688669216952153, 0.04363411378913692, 0.04647181509062648, 0.06181104574352503, 0.0217214258653777, 0.02037947528463389, 0.06502833989049707, 0.012011172449482339, 0.004567778153744127, 0.009343012452258595, 0.035568574975643835, 0.0469887434238834, 0.05366838124713727, 0.019028291538623825, 0.025765358869518553, 0.04995072180671351, 0.07944615730749709, 0.05275264395666974, 0.016396466243479933, 0.07120584483657565, 0.03403404428224478, 0.05247568292543292, 0.06439771622951541, 0.046775072746511014, 0.06871506491942064, 0.07087032962590456, 0.06258277076163463, 0.018548803071358373, 0.06373923192066805, 0.01571048769567694, 0.010260000791666763, 0.013304941954889467, 0.03396193636581302, 0.014070371864363551, 0.049563834709780555, 0.014431547573102372, 0.02371395582200161, 0.015314233422811543, 0.006870103875241641, 0.02390414409871612, 0.045254652188824754, 0.16569655521639756, 1.1051454011883055, 5.077109941414424, 14.41819907937731, 27.096371207918438, 39.483527592250276, 40.91125386101859, 40.9412179674421, 51.5214900970459, 53.694997787475586, 34.987563678196494, 43.50443622044155, 38.68099675859724, 38.54035479681832, 27.08773807116917, 25.054573569978984, 37.682891505105154, 29.195972646985734, 25.214074679783412, 31.383699825831822, 15.827350207737513, 21.821503809520177, 21.05011132785252, 19.121550219399587, 19.098204272133962, 15.024496282849993, 24.659208910805837, 18.958764348711284, 17.608732836587087, 22.834735291344778, 41.17390619005476, 79.70752470833915, 28.933045864105225, 17.301311526979717, 21.933090141841344, 19.732934372765676, 32.45126622063773, 26.12791739191328, 39.98950931004116, 41.07376527786255, 39.888833386557444, 33.198524134499685, 32.54992716653006, 22.435102701187134, 13.481296164648873, 8.449442880494253, 3.0271210287298476, 1.528301443372454, 0.38252927362918854, 0.04291468007223947, 0.007065806097151446, 0.012815926855962192, 0.045685043558478355, 0.026762968195336204, 0.058256445053432665, 0.02716902899555862, 0.06813297008297273, 0.00778567958955786, 0.04524693724566272, 0.025555140239053538, 0.03560847622741546, 0.009954861049274248, 0.03315454415444817, 0.03922733079109873, 0.03370953830225127, 0.029394781616117274, 0.02093739222202982, 0.03508499663855348, 0.031272817270032, 0.05322755061622177, 0.04042110798348274, 0.0388674901000091, 0.018515834751139795, 0.024945037173373357, 0.028407391027680466, 0.012732789352802294, 0.02008120995014906, 0.03186560581837382, 0.05118873269696321, 0.05199292561571513, 0.024953847950590507, 0.03075742581859231, 0.044213016118322096, 0.0554459089014147, 0.06524526075060878, 0.045029022331748686, 0.03597661540178316, 0.0528316322181906, 0.04264119653297322, 0.057119512132235935, 0.06133761829031365, 0.02855316749108689, 0.007313123205676675, 0.038611892743834426, 0.025700641895777414, 0.06512698531150818, 0.011421423738024064, 0.03973285973604236, 0.02779856021516025, 0.02781269749227379, 0.028747102977441888, 0.05472072120755911, 0.007946150576961892, 0.1034529705398849, 0.024370380777067373, 0.033075060562363694, 0.051343526890767474, 0.044501074589788914, 0.018044098546462398, 0.04581306954579694, 0.05760153662413359, 0.0346821062932057, 0.016866962425410748, 0.025356680620461702, 0.07639528065919876, 0.026195689171020473, 0.0425274944198983, 0.031682353865887435, 0.011766484240069985, 0.013872543283339058, 0.051089401955583265, 0.01432998275517353, 0.0520307437649795, 0.025044888690380112, 0.019373519978086864, 0.03222437781680908, 0.014899341489321418, 0.015328504710591264, 0.021339907676779797, 0.0756447734311223, 0.05024230187492711, 0.037682272626885345, 0.003322958588666682, 0.014878664830965655, 0.023170568015692488, 0.04780616777549897, 0.04961618707914438, 0.05065726335825665, 0.032135079215679846, 0.048157211260071824, 0.038310996389814785, 0.05166274369029062, 0.005143975672711219, 0.049856405439121385, 0.004010441787873528, 0.023726785222866704, 0.08370618335902691, 0.0709525952115655, 0.03194442105346492, 0.01534226200809436, 0.04318306442084057, 0.023202772984015088, 0.0703394099005631, 0.03453262163592236, 0.056057842315307686, 0.025665945007598827, 0.021895476883011203, 0.012160235566885343, 0.05720687351588692, 0.039781303743698766, 0.025380651566333005, 0.02159373914556844, 0.042088153173348734, 0.02402709125142012, 0.06471605093351432, 0.0026601910275141044, 0.025373993441462517, 0.07196833499308143, 0.03515936407659735, 0.012807602927620922, 0.02533477751005973, 0.050103453254061084, 0.058085779925542216, 0.008631756778673401, 0.0579844271498067, 0.04865049264792885, 0.2930731980928353, 2.3104707981858934, 7.579943571771894, 19.682537351335796, 32.16618858064924, 44.31428350721087, 46.147614342825754, 46.00911937441145, 57.48792559759957, 58.370350292750764, 36.715017863682334, 39.13893515723092, 34.322912897382466, 36.016855921064106, 24.043994562966482, 18.29360634940011, 28.121088062013897, 19.11738477434431, 20.810240404946462, 30.862501553126744, 18.115600449698313, 22.702340841293335, 17.711887529918126, 22.130841084889003, 19.516734225409373, 15.340085199901036, 20.159406117030553, 12.796516452516828, 18.298600367137364, 22.810083082744054, 32.32103613444737, 80.84310354505266, 30.905847890036448, 10.844962886401586, 17.1015681879861, 17.015189920152935, 25.967688458306448, 25.442767688206263, 37.58024229322161, 41.31140061787197, 42.73451328277588, 39.62700094495501, 36.803353786468506, 29.579638276781353, 20.30556842258998, 13.881354331970215, 6.471875258854457, 2.5462928754942755, 0.7993013869438852, 0.0746546687026109, 0.03239257986258183, 0.056091718176113706, 0.014657888195610471, 0.025367465934583118, 0.039578435343823264, 0.015301887478147234, 0.017363887546317916, 0.01718162795129631, 0.0224048649958734, 0.050905240766171894, 0.054393816606274674, 0.015504482767677732, 0.02657177738313164, 0.019368810945057442, 0.04152922352243747, 0.0412776905910245, 0.04926528608692544, 0.036026240060372014, 0.043500802014023066, 0.014774111066279667, 0.032148721162229776, 0.0459263984646116, 0.02196974423713982, 0.02927029418892094, 0.046242826485208104, 0.026421517499589493, 0.036888902341680865, 0.06888290734163352, 0.029587533058864728, 0.007542275507668299, 0.058963858522474766, 0.052482983962233574, 0.038113800542695184, 0.03097580892166921, 0.047122703199940066, 0.014453240337648561, 0.025364300568721125, 0.09407615941017866, 0.010328778797494513, 0.07081536828939404, 0.011300393446747745, 0.02277190494351089, 0.06183070968836546, 0.0363515602823879, 0.012901209377949792, 0.03141893639362284, 0.016681893695411936, 0.026209672081417272, 0.015338893081726772, 0.04753093361588461, 0.02491248954486634, 0.012197991799829262, 0.04561356667961393, 0.06514107169849531, 0.009144215262494981, 0.02344663338070469, 0.03521366723413978, 0.011508940336560565, 0.09472608060709067, 0.10875122302344867, 0.13740697822400502, 0.10098703178976264, 0.08755297479884964, 0.1953089362276452, 0.17376611434987613, 0.14674870909324714, 0.19403238115566118, 0.12557372104908737, 0.13320817638720783, 0.1146863145487649, 0.12591524129467352, 0.13576767833105155, 0.1651511759098087, 0.09273002735738244, 0.10661182925105095, 0.1552978703486068, 0.08122333551623992, 0.1335713690412896, 0.11127660822655473, 0.14299858175218105, 0.11695875546761922, 0.09889170886682612, 0.10177377278783492, 0.10869682487100363, 0.21201585259820732, 0.09629006989832435, 0.15388327411242894, 0.18333453019814833, 0.19156404717692307, 0.10974607749709062, 0.12164123063640934, 0.12080366058009011, 0.10944576468318701, 0.2184043683643852, 0.14665718828993185, 0.10109213007880108, 0.13640330279512064, 0.13729350002748625, 0.12154610002679483, 0.08149069188428776, 0.1498761312769992, 0.12646615744701453, 0.1317766574876649, 0.1348374475325857, 0.16005668070699486, 0.12601844647100993, 0.1254420852554696, 0.14793766529432364, 0.16245302212025436, 0.10243007221392222, 0.12419446291668074, 0.12028884249074118, 0.1770753160651241, 0.180818413783397, 0.17290034437818186, 0.07405027042010001, 0.1002233134848731, 0.21241362339683942, 0.1857103391417435, 0.22368908407432692, 0.13087719146694454, 0.10382295532950334, 0.12083488676164832, 0.10038100502320699, 0.13152611521737917, 0.20097212520028862, 0.3837474611188684, 2.428732395172119, 8.0156329699925, 21.532582078661235, 38.052080563136506, 53.314285142081125, 55.79708841868809, 56.353177070617676, 62.5695983341762, 65.32552487509591, 48.28061056137085, 53.46245200293404, 50.4622928074428, 49.941344669886995, 36.51146343776158, 34.251092842647004, 48.71139539991106, 39.144111565181184, 36.08604608263288, 42.64344671794346, 25.010747807366506, 32.400978633335654, 32.29421608788626, 30.482803344726562, 29.230345385415212, 25.325839928218297, 33.798341274261475, 25.90357048170907, 28.17862262044634, 33.33289187295096, 47.256129946027485, 87.86566870553153, 35.224076884133474, 24.423156023025513, 29.947600977761404, 29.42225115639823, 39.99449116843087, 36.85681670052664, 49.71926982062203, 52.95682116917202, 51.6191782951355, 46.07612780162266, 41.19656079156058, 31.913757051740372, 21.01361244065421, 14.813265834535871, 6.582321218081883, 2.772644340991974, 0.6884524321981839, 0.0968700952029654, 0.10025240906647273, 0.08740004657634667, 0.14111350290477276, 0.09991860376404864, 0.17911352669554098, 0.19563091466469423, 0.16334948901619228, 0.13916166978222982, 0.19135190998869284, 0.19658498918371542, 0.16578582328345093, 0.09536486025899649, 0.1819506308862141, 0.12841983618480818, 0.0783944008871913, 0.10521452208714825, 0.10926720819302968, 0.09281864403081791, 0.11473214280392442, 0.15780296735465527, 0.21888205701751368, 0.1828707650836025, 0.17327826124216827, 0.06987587548792362, 0.09673266472028834, 0.09105002893401043, 0.13344212169093744, 0.16365162708929606, 0.10875272258583989, 0.10054754465818405, 0.10636748879083566, 0.10610979476145335, 0.11307444104126521, 0.09683607345713036, 0.18411066569387913, 0.14232143094497068, 0.0735335795740996, 0.17927689078663075, 0.1365639798875366, 0.22920207253524236, 0.11944346928170749, 0.10287672467529774, 0.2419670804270676, 0.11918779728668076, 0.11075981560030154, 0.15000604359166964, 0.1172559130936861, 0.07069152207779032, 0.04956762432785971, 0.21185946384710924, 0.08518584431814295, 0.16747194209269115, 0.0843030024053795, 0.2589651697448322, 0.08688292825328452, 0.10236288367637567, 0.12638991725231918, 0.10297561436891556], [0.010891935721571957, 0.041676943988672326, 0.0497800872128989, 0.05171227674665196, 0.033765076393527646, 0.016172961897349784, 0.02961224191156881, 0.08158645353146962, 0.0310954991062837, 0.04225714910509331, 0.04789464195658054, 0.056424716021865606, 0.03479017656562584, 0.12207507235663277, 0.005528624452251408, 0.04318107631323593, 0.03940956833373223, 0.06290151258664471, 0.0508443422482482, 0.043533724533127885, 0.02025737121169056, 0.03679088456556201, 0.07285073585808277, 0.04243967502510973, 0.048740479962102005, 0.08065183939678328, 0.04405919562226959, 0.05408125623528447, 0.03090809451948319, 0.034926141412662606, 0.022742222429120114, 0.008010993079681481, 0.07571259300623621, 0.07276156278593199, 0.11147269127624375, 0.03362937278247305, 0.021353615780494044, 0.043001417203673294, 0.03830137137057526, 0.1053495980533106, 0.009012696516167904, 0.03819270398733871, 0.02684030252774911, 0.04460209488336529, 0.06595973098384482, 0.010296033545663314, 0.041983818236206255, 0.028634031901934316, 0.08962345655475344, 0.11236178928187915, 0.04665526381826826, 0.07319543843290635, 0.0215666231898857, 0.023602380916210156, 0.04116543036486421, 0.024773121844711046, 0.05082879022562078, 0.05858664733490773, 0.02221784208502088, 0.05224412267229386, 0.014505066842372929, 0.03379048752997603, 0.010079655513566519, 0.031190365087240934, 0.02245410967485181, 0.008776295763839568, 0.10720742693436996, 0.03002610756084323, 0.017081591533496976, 0.047219777812383006, 0.04841256434363978, 0.4241168206291539, 2.1538071589810506, 6.933273860386439, 20.947046961103165, 28.336270298276627, 33.36100428444998, 38.78541081292288, 44.57599435533796, 42.842797483716694, 50.93319654464722, 48.470341546194895, 46.681975977761404, 47.76362289701189, 49.16281638826643, 41.41596058436802, 47.53837619509016, 45.59418337685721, 40.029322487967356, 31.520766939435685, 31.62099470411028, 26.6885119506291, 33.97800431932722, 33.27151843479702, 37.46037891932896, 33.61878245217459, 28.215427228382655, 25.146357536315918, 48.413331576756065, 70.76360893249512, 35.37344230924334, 39.03024448667254, 38.68029499053955, 41.64072091238839, 38.60053314481463, 36.64987850189209, 35.359403473990305, 29.315895080566406, 20.41232749394008, 11.219959769930158, 7.183321722916194, 2.455440402030945, 0.9165616290909904, 0.2763900304479258, 0.26324550434947014, 0.049443845969757864, 0.07087385122265134, 0.025654840782018642, 0.004817011699612651, 0.01804915872136397, 0.020094139434929405, 0.034199817172650776, 0.06381259512688432, 0.035066930643681965, 0.023066791173602854, 0.028380310695086206, 0.05536732097555484, 0.03742034453898668, 0.043131753602730374, 0.035709611871945005, 0.033839396334120204, 0.0532960622970547, 0.008091316358851535, 0.09977321406560284, 0.04526704563094037, 0.022994247298421602, 0.03987397127119558, 0.022843134157093506, 0.038155764540923495, 0.06958806128906352, 0.022910899449405924, 0.03594528743997216, 0.04859341088948505, 0.04839368749942098, 0.060546555024172576, 0.012456871569156647, 0.05313467613554426, 0.017209983929725628, 0.04724821860768965, 0.027512179421527044, 0.028108940792403052, 0.0437384453336043, 0.018229645643649355, 0.019625398962359344, 0.035848307822431834, 0.02684444159136287, 0.08152963979435818, 0.028022598907617585, 0.044485475069710186, 0.03144053077059133, 0.022240481405918087, 0.0038105669996834225, 0.09544774331152439, 0.05201427232740181, 0.026755548414907286, 0.03213341001953397, 0.00597703643974715, 0.019798798586374948, 0.0320839448166745, 0.04838158243468829, 0.04788157676479646, 0.0014340935158543289, 0.0443104571396751, 0.013271157696310962, 0.01317990491432803, 0.04072701871129019, 0.038235234562307596, 0.07208034755395991, 0.014954606470252787, 0.03507198912224599, 0.025700160135914172, 0.04433649931369083, 0.032454268873802254, 0.009222904120438864, 0.04997532209381461, 0.053500772919505835, 0.0741306971758604, 0.01579862939459937, 0.021483405958861113, 0.05574369077969875, 0.007953245508750635, 0.05370445216872862, 0.022616588277742267, 0.04151714899178062, 0.006882430312024164, 0.04547711328736373, 0.054451905989221165, 0.058751504203038554, 0.018855651873829107, 0.06463313395423548, 0.029323135103498186, 0.03952387095029865, 0.02949792572430202, 0.06286544845040355, 0.09910703516964402, 0.008522657677531242, 0.029146078175732067, 0.03428865436996732, 0.023263103228860667, 0.06789821732257094, 0.03447846436340894, 0.021401729002328854, 0.03397724072315863, 0.055203142642442665, 0.029304400751633302, 0.018184892866494398, 0.015540937061554619, 0.04173673310184053, 0.07548719045839139, 0.06561743042298726, 0.04661050086308803, 0.07447594257869891, 0.018219264057864035, 0.01987697260587343, 0.029679874889552593, 0.07314920984208584, 0.049085124861449, 0.05555360937224967, 0.03749389773500817, 0.0654331606679729, 0.03718308459169098, 0.029779365086661916, 0.01908755478715258, 0.046805284518216334, 0.029135089301105057, 0.052104011976293156, 0.012429564775499915, 0.053873431137097735, 0.01760359700503094, 0.08491800619023186, 0.04859065603730934, 0.03340561907472355, 0.0380801044936691, 0.054846938899053, 0.021375137214948024, 0.020701090705447962, 0.05762621494276183, 0.6859973296523094, 3.483689329453877, 10.867195384843008, 26.29308475766863, 35.889453751700266, 39.799660205841064, 45.252432755061555, 49.20494679042271, 49.345474106924875, 55.276758670806885, 51.82550852639334, 48.139218194144114, 46.31891870498657, 50.78204543249947, 40.91571113041469, 44.94869572775704, 46.5340245110648, 36.57691546848842, 31.38743100847517, 30.317814895084926, 25.866998638425553, 31.39338561466762, 31.844744069235666, 32.656366620744976, 27.62053462437221, 25.074709449495586, 24.993650027683803, 48.08860404150826, 78.7886323928833, 33.396422726767405, 33.609061922345845, 36.769095693315776, 42.15471042905535, 45.42330632890974, 42.098548139844624, 42.93992635181972, 36.606956005096436, 27.956219468797954, 17.19445170675005, 11.111216987882342, 4.464197618620736, 1.6554498949221201, 0.6570140048861504, 0.30775167473724907, 0.08133177898292031, 0.03793657737384949, 0.1054028630522745, 0.01136937246857477, 0.04951205909518259, 0.02867143614483731, 0.015974561650572077, 0.053958132663475614, 0.027536832295092087, 0.03528790235785501, 0.053717558072613816, 0.03160226298496127, 0.013826515708517815, 0.094077991454729, 0.031893619136618714, 0.10971732796835047, 0.06698250038815395, 0.05339067043470485, 0.039094901111509116, 0.020883267179929783, 0.013531719384315823, 0.008612767976176525, 0.031654571249548874, 0.052617907258016725, 0.022792089663978134, 0.039350376331380436, 0.014413250876324517, 0.0186590599228761, 0.0633788484015635, 0.016359901687662517, 0.01774614703442369, 0.045486521175397296, 0.030973915808967183, 0.05457408639735409, 0.02147954679094255, 0.014790256807048405, 0.08981699509812252, 0.005614316639756518, 0.04076514220131295, 0.02288611595784979, 0.031244905732039894, 0.10861687308975629, 0.02573218529245683, 0.08221674471029214, 0.05047875775822571, 0.05780055094510317, 0.06475154510033981, 0.05504943410466824, 0.025439816427284052, 0.03680893359705806, 0.055305082350969315, 0.025697121995368173, 0.030959062677408968, 0.044042795430868864, 0.05283257198919143, 0.013198818229804081, 0.006819234953062343, 0.02123316902933376, 0.03206905436569026, 0.023242044894556915, 0.06450931488403253, 0.1554536891302892, 0.13862280441182, 0.1265225572777646, 0.17788438765066011, 0.13221927945102963, 0.15173942915030889, 0.09028409181960992, 0.14675492447401794, 0.08891065551766328, 0.09817528445273638, 0.14643703081778117, 0.11816386080213956, 0.13760261344058172, 0.19112597139818327, 0.05080125866723912, 0.14467912300356797, 0.11848714202642441, 0.1285024681793792, 0.2363675380391734, 0.17560840477900846, 0.09957381976502282, 0.12761864917618887, 0.14084081325147832, 0.1433418933302164, 0.2412488375391279, 0.15476317118321145, 0.1391745890889849, 0.14676447824708053, 0.15378074747111115, 0.07406176480331592, 0.09229303044932229, 0.10688031198722975, 0.18158175210867608, 0.13162533060780593, 0.15747177441205296, 0.07341628801077604, 0.2136675018285002, 0.08885287826082536, 0.14860663296920912, 0.16180441049592836, 0.06383045416857515, 0.1833171732723713, 0.2220661233046225, 0.23103208148053714, 0.1372878953282322, 0.18380094159926685, 0.1389789945845093, 0.11566495203546115, 0.1591697268720184, 0.23464468334402355, 0.09672588615545205, 0.2540082814438002, 0.06920006818005017, 0.11347795224615506, 0.08932482650769608, 0.16231556449617657, 0.12392942713839666, 0.24134122686726706, 0.12970267449106487, 0.24144102579780988, 0.07048927793013197, 0.15914069914392062, 0.08132396225950547, 0.15655233232038362, 0.09984154254198074, 0.17612749763897487, 0.24572260890688213, 0.14979847972946508, 0.11778249698025839, 0.1647186776889222, 0.25145821113671574, 0.7005362180726868, 3.9050973568643843, 11.91505321434566, 28.860661268234253, 41.67619146619524, 47.294383253370015, 52.68717547825405, 58.578205653599326, 57.78634377888271, 65.94512353624616, 61.50784410749163, 61.9336644581386, 63.211757796151296, 61.41172967638288, 54.1908802986145, 58.328925132751465, 57.70904854365757, 50.47329527991158, 42.58131940024239, 42.92220497131348, 38.06713383538382, 45.009874616350444, 44.54684318814959, 49.1895044190543, 42.537948744637625, 38.446710450308665, 35.1716388293675, 58.16684797831944, 76.55653054373605, 45.053839342934744, 50.371340887887136, 49.48664065769741, 54.09880971908569, 53.901178632463726, 51.50878184182303, 48.80834708895002, 39.45447717394148, 30.676765782492502, 18.54354521206447, 10.447256684303284, 4.649982026645115, 1.3837958489145552, 0.5761238911322185, 0.34083115256258417, 0.22551956799413475, 0.2132769235010658, 0.1678366410945143, 0.10315977555832692, 0.21897611554179872, 0.1304459688918931, 0.13137622683175973, 0.1764841220740761, 0.12789315730333328, 0.1316351829362767, 0.15995671892804758, 0.1117791109053152, 0.13104846727635178, 0.27408881964428083, 0.10187679475971631, 0.27305638790130615, 0.12804346638066427, 0.2277325013918536, 0.24745219466941698, 0.18593660342906201, 0.122982830075281, 0.18567629025450774, 0.1583314918513809, 0.11703173869422503, 0.1307677844805377, 0.1184058671018907, 0.1543652918189764, 0.14176830276846886, 0.1771215107291937, 0.2408062427171639, 0.11614170431026391, 0.12699287704059056, 0.08393183017947844, 0.20252636394330434, 0.11170329140233141, 0.10751569896404232, 0.25249094143509865, 0.11966320606214659, 0.1359272561967373, 0.09479043965360948, 0.11301217866795403, 0.23373330224837574, 0.09492550204907145, 0.2001817947519677, 0.15088504499622754, 0.1545479805873973, 0.12276654025273663, 0.1572230099035161, 0.12889709057552473, 0.10136559326201677, 0.1478001262460436, 0.07503799349069595, 0.13172484455364092, 0.12270307008709226, 0.16630722316248076, 0.1401748854134764, 0.06408426697765078, 0.14146448192851885, 0.1644906084984541, 0.08485201187431812, 0.1139597799628973], [0.042530249272074015, 0.02491512056440115, 0.04980502337483423, 0.03714438434690237, 0.0335047971457243, 0.013086062673080181, 0.04341055007119264, 0.023600307991728187, 0.02550117634902043, 0.01400690000238163, 0.016176961861284714, 0.025408463020409857, 0.032148290292492936, 0.10724628663488797, 0.041826584709009955, 0.004808097869889545, 0.028985231449561458, 0.01860649211864386, 0.03846835544598954, 0.034677756883736165, 0.021692320105752776, 0.0248107720565583, 0.039012927295906205, 0.12874603510967322, 0.07707090476261717, 0.030058673849063258, 0.027008441809032644, 0.013878836695637022, 0.026985643032406057, 0.05233771300741604, 0.05144772951358131, 0.044731216704738994, 0.06942181342414447, 0.056329181683915, 0.029155893184776818, 0.025430703701983606, 0.02317117021552154, 0.07345759722271136, 0.021751669867496406, 0.025022437662950585, 0.08883861545473337, 0.07082520026181426, 0.016682577319443226, 0.058487425159130774, 0.03112385169203792, 0.04484792812062161, 0.005319718362963093, 0.026691469264083674, 0.04540406220725604, 0.04235992680436798, 0.03467116491603, 0.05487897253728338, 0.04127791450758066, 0.02208861000170665, 0.059704208081322055, 0.03925367830587285, 0.01662429285767887, 0.05308321603972997, 0.06825761018054825, 0.024259475924606835, 0.04154666526509183, 0.0655987842806748, 0.04936745649735842, 0.030236592516303062, 0.01595610549806484, 0.014639116524319564, 0.062252161359148364, 0.01759505085647106, 0.021352265495806932, 0.027827228319698145, 0.03922627227646964, 0.05321089597418904, 0.03512682492977806, 0.017335097305476665, 0.7264258031334195, 2.65817819748606, 4.525339160646711, 11.11305044378553, 13.645489045551844, 17.095358235495432, 20.513093744005474, 27.171747003282817, 27.343398775373185, 28.627022879464285, 38.711478505815776, 41.16467203412737, 37.59968335287911, 42.90136384963989, 46.156118937901084, 44.910317352839876, 44.15201527731759, 46.26730401175362, 47.88755791527884, 46.13123396464756, 48.887233461652485, 43.73907341275896, 46.02097300120762, 43.449465547289165, 48.720796312604634, 48.14450577327183, 41.200528212956016, 37.230945927756174, 31.968057223728724, 22.74746070589338, 23.429617473057338, 15.472509179796491, 8.876103963170733, 4.878122219017573, 2.0397099213940755, 0.2204740901610681, 0.12125643342733383, 0.12494070215948991, 0.04270152847415634, 0.02879174718899386, 0.02056943964479225, 0.06630049805556025, 0.013702477810771337, 0.03389264436970864, 0.03324577318770545, 0.04231864473383341, 0.10133201934929405, 0.04060555076492684, 0.07733650372496673, 0.09400006170783724, 0.05701866825776441, 0.039966523447739224, 0.025336874183267355, 0.03350159106776118, 0.042525424888091426, 0.05280464348782386, 0.04487693209999374, 0.05640211741306952, 0.09293132155601468, 0.03983593938340034, 0.055777763415660174, 0.036352503446063826, 0.04191608347796968, 0.00900408675495003, 0.06074488402477332, 0.03680315587137427, 0.049288407167685885, 0.06606718378939799, 0.017276912927627563, 0.054580966742443185, 0.08599716185459069, 0.05537255248054862, 0.06454503296741418, 0.05188754912731903, 0.02104284504561552, 0.03224991448223591, 0.03398512190740023, 0.03758963902613946, 0.023829018397788917, 0.044097536243498325, 0.052170905351106606, 0.04429849795997143, 0.052549246299479685, 0.04919184145650693, 0.020246132975444198, 0.0231234963451113, 0.013373526578236903, 0.016583370410704186, 0.010886658415464419, 0.011712589899876287, 0.0893752213035311, 0.04195752839690872, 0.049189585327569924, 0.05008754160787378, 0.02611738283719335, 0.011839033204263874, 0.020100208930671215, 0.009797505385774587, 0.06134997441300324, 0.007357091426716319, 0.04573140446362751, 0.03967899762626205, 0.022076113083000694, 0.017101708400462354, 0.025187438719772866, 0.02339267118700913, 0.04926499431686742, 0.06763261836022139, 0.029481912297861915, 0.02066727421645607, 0.028770105314574072, 0.05898534772651536, 0.040010848747832437, 0.013823916919396391, 0.03141756575288517, 0.05718932660030467, 0.03047273966616818, 0.03333748058815088, 0.044992188058261356, 0.016730366540806632, 0.015156507957726717, 0.028548943610595803, 0.08450447302311659, 0.015599572665191122, 0.0747822807835681, 0.03799786265673382, 0.0554146827198565, 0.07072393569563117, 0.03026254308809127, 0.029516154567578008, 0.030902303223099028, 0.007610665052197874, 0.05416782373296363, 0.052603145728686025, 0.006095586261445922, 0.04426454406763826, 0.007597026498323041, 0.041597507894039154, 0.03923715597816876, 0.023171392435740148, 0.015253991387518389, 0.01393430947791785, 0.06792646473539726, 0.038728102043803246, 0.01623461358914418, 0.01358114811591804, 0.04351057970364179, 0.046714968114559136, 0.021043214847200682, 0.05707303248345852, 0.018012838438153267, 0.01729306884642158, 0.026128064674724425, 0.03290758454906089, 0.04089126489790423, 0.04788242832624486, 0.02971176603542907, 0.04735130504039781, 0.008692377945408225, 0.04866820241191557, 0.05478638643398881, 0.01817569532431662, 0.027228567050769925, 0.022041046393236945, 0.06333931016602687, 0.04144130913274629, 0.01686220250225493, 0.03536697204357811, 0.04846141886498247, 0.031252515502274036, 0.08397456431495291, 0.018985143496787975, 0.03097815326015864, 0.03625060784231339, 0.04055764279993517, 0.08910293198589768, 1.2233050550733293, 3.7787243894168308, 7.842737470354352, 15.276121820722308, 19.360307693481445, 24.051104307174683, 29.066359213420323, 35.66193846293858, 35.842108726501465, 37.889451026916504, 46.95940017700195, 50.29165199824742, 48.47006361825125, 51.11551032747541, 53.14791052682059, 49.94912665230887, 48.48385231835501, 49.12610558101109, 53.06285415376936, 51.46345179421561, 51.92622266496931, 47.863534518650596, 47.162676674979075, 46.293804441179546, 51.44411148343767, 55.34694242477417, 46.35462202344622, 44.80288083212716, 38.41906704221453, 33.56062255586897, 28.85731397356306, 20.467539616993495, 12.89920995916639, 7.475449613162449, 3.6553838763918196, 0.6828761771321297, 0.12914474228663103, 0.1125694549243365, 0.0420942430251411, 0.03051454420866711, 0.07084047408508402, 0.026154164524216737, 0.03583575492458684, 0.028073629830032587, 0.06839598382690124, 0.06635405482458216, 0.03296387581420796, 0.10794178502900259, 0.02459438215009868, 0.11429338849016599, 0.04564013132559402, 0.03679524415305682, 0.0700695225968957, 0.04164379755301135, 0.04330234409176877, 0.08559887536934443, 0.08100927128855671, 0.09491499154163258, 0.05819802997367723, 0.0924077842916761, 0.0858174722109522, 0.020939951995387673, 0.06951505770640713, 0.033674413937010934, 0.012923914856011314, 0.02343517292423972, 0.06683507508465222, 0.11203712384615626, 0.030955673394990817, 0.03637867793440819, 0.1123466511656131, 0.018456049030646682, 0.04256281556029405, 0.02302422497554549, 0.03898646103750382, 0.02711388106191797, 0.05438917881942221, 0.1113181888524975, 0.04473842953198722, 0.05218435391517622, 0.039459566186581335, 0.031214045959391763, 0.0331752123311162, 0.10077925079635211, 0.036686057690531015, 0.020050453654091274, 0.037178606260567904, 0.037917368047471554, 0.08201377453016383, 0.020569504105619023, 0.03310466504522732, 0.006784642389642873, 0.0690590821738754, 0.04470451295908008, 0.06276921861405883, 0.0796759839036635, 0.05650585184672049, 0.029178498578923087, 0.04952392327998366, 0.01715590468873935, 0.013396684130254601, 0.010977825532401246, 0.18180447444319725, 0.07634660255696092, 0.12396438526255743, 0.14125267043709755, 0.09647710807621479, 0.1375360627259527, 0.12369188559906823, 0.1892036274075508, 0.1112610629892775, 0.2825819339071001, 0.11172150328223195, 0.1533358320593834, 0.14891251655561583, 0.23107911752802984, 0.1101478584376829, 0.09818759986332484, 0.13303899046565804, 0.04709633532911539, 0.11123161456946816, 0.16878538232828888, 0.1486740250672613, 0.11746240487056119, 0.20871989588652337, 0.1986363905348948, 0.21821170513119015, 0.13815494094576153, 0.09985386473791939, 0.064276536660535, 0.09708850205476795, 0.16699607191341265, 0.11124912077294928, 0.11249337757804564, 0.1535432737852846, 0.16329127071159227, 0.10938344802707434, 0.1353547762015036, 0.1486052894698722, 0.13549857134265558, 0.09396827912756375, 0.08904185704886913, 0.2056782269584281, 0.17722551657685212, 0.12256061844527721, 0.09482882437961442, 0.18645246646233968, 0.1675634900374072, 0.12547935039869376, 0.1256160752049514, 0.13413040047245367, 0.12061373862837042, 0.23478451584066662, 0.1341958926724536, 0.2105949324156557, 0.10909722838550806, 0.11109540544982467, 0.2696775277810437, 0.16561418106513365, 0.12481942081025668, 0.15553961880505085, 0.11823870321469647, 0.10686074982264213, 0.17584339502666677, 0.1912566843841757, 0.11185157165995666, 0.07438495781804834, 0.12042932638100215, 0.14693732825773104, 0.08819687739014626, 0.16436311176845006, 0.12163516453334264, 0.125603942998818, 0.09889375804258244, 0.1770902166941336, 0.2524636914687497, 1.3441444337368011, 4.2901608773640225, 8.548458184514727, 15.607625586645943, 20.29119954790388, 25.340054205485753, 30.2370559828622, 36.217273235321045, 41.48786054338728, 44.91850233078003, 52.7430876323155, 59.312852587018696, 56.454123973846436, 59.52716282435826, 61.56099782671247, 60.07719612121582, 60.13838195800781, 60.59300259181431, 62.5555282320295, 62.437520027160645, 61.62333011627197, 57.29024587358747, 59.76321397508894, 58.015846252441406, 60.02106162479946, 60.41082082475935, 57.673980985369, 54.170303208487375, 47.0935594694955, 40.392351967947825, 32.20015484946114, 21.267720222473145, 13.709052034786769, 7.26181161403656, 3.592715250594275, 0.7358721505318369, 0.3076827627207552, 0.36652773512261255, 0.09623784984328917, 0.11010309548250266, 0.14698118876133645, 0.10680131015500852, 0.20864455135805265, 0.10753568182034151, 0.13627060848687375, 0.23884427228144237, 0.19738244424973214, 0.16720461286604404, 0.19005674948649748, 0.333347779831716, 0.1823507494160107, 0.15724236172224793, 0.13043089184377873, 0.13195208593138627, 0.20423344948462077, 0.16972589971763746, 0.11810887232422829, 0.21376206246869905, 0.26455955526658465, 0.18317892854767187, 0.1593963439975466, 0.1111356018643294, 0.16652634926140308, 0.16605043837002345, 0.0994969688888107, 0.15783244291586535, 0.19622233935764857, 0.21826577080147608, 0.12183550878294877, 0.10638614171849829, 0.16660562929298195, 0.12314665557018348, 0.12894857781273977, 0.145881269925407, 0.15664151896323475, 0.2097583801618644, 0.094300198102636, 0.2743251941033772, 0.16026758296149118, 0.1322939454444817, 0.23659403302839824, 0.12382884110723223, 0.11820047455174582, 0.23991014223013604, 0.14902290063244955, 0.12858531730515615, 0.13023216250751699, 0.0923064247305904, 0.10818670224398375, 0.1062953198062522, 0.15542627631553582, 0.20250585861504078, 0.1510240768215486, 0.09933236986398697, 0.12869525354887756, 0.22013589473707335, 0.12146079460425036, 0.11027442557471138, 0.0983399377603616, 0.10682538457747016, 0.10500110246773277, 0.08263305987098388], [0.011822733944947166, 0.02433229291013309, 0.017374723750565733, 0.01266907576271998, 0.07140127649264676, 0.03201734660459416, 0.03092381956854037, 0.054750759952834675, 0.028889934598867382, 0.07031674683094025, 0.014421293212633048, 0.02638255262614361, 0.04038122030241149, 0.0211047800257802, 0.025545981712639332, 0.018401106353849173, 0.08165126719645091, 0.026431656509105648, 0.010580437257885933, 0.05991788554404463, 0.0459422083305461, 0.02944003650918603, 0.05297006354002016, 0.02949850247906787, 0.03353432020438569, 0.03954443395403879, 0.026550808954717856, 0.020636568810524683, 0.02599803022375064, 0.023170764790847898, 0.022001696451167976, 0.07444541528820992, 0.020422784478536675, 0.0285293678753078, 0.02752760421883847, 0.07130423241427966, 0.016043287069935883, 0.03147338204351919, 0.03359474714047142, 0.02847993659919926, 0.005503818060138396, 0.033332476392388344, 0.05632738695879068, 0.044229952352387567, 0.09053967560508422, 0.02742107761358576, 0.03499666494982583, 0.014903119233037745, 0.04036390408873558, 0.016518770484253764, 0.0479235271923244, 0.10805431327649526, 0.02890141201870782, 0.06296902682100024, 0.02516582059407873, 0.05010589598012822, 0.033463691494294574, 0.029156822777752365, 0.05073164436700089, 0.013873324446779276, 0.06420098857155868, 0.022307227199364985, 0.04786272706197841, 0.05854659341275692, 0.01877970514552934, 0.029829234017857482, 0.015453986191589917, 0.04871734870331628, 0.06966742953019482, 0.0050948552504581, 0.013524749133336757, 0.10819022384073053, 0.057367611676454544, 0.03001880313136748, 0.031357830922518454, 0.04587211227044463, 0.08228705450892448, 0.13510314827518805, 0.15851555126053946, 0.9179360696247646, 1.3082183386598314, 2.2805894187518527, 3.9594027400016785, 5.7902535029820035, 8.41761144569942, 9.611018402235848, 11.460243242127554, 14.69012985910688, 14.660679919379097, 17.00812360218593, 19.490273748125347, 18.60287066868373, 19.60272513117109, 19.967585461480276, 23.626400879451207, 24.790396111352102, 29.09712062563215, 31.574191638401576, 29.65659999847412, 29.21141849245344, 23.927895375660487, 17.698486191885813, 8.278320908546448, 4.6845267329897196, 2.3464694150856564, 0.4065422479595457, 0.15479109968457902, 0.04305421740614942, 0.016497618851384947, 0.041848976364625354, 0.07088843972555228, 0.03534074327243226, 0.02055335327583764, 0.025679797300004532, 0.061758153938821385, 0.03284952570019024, 0.02994940596233521, 0.03277015745905893, 0.00880273403267243, 0.054608243850192854, 0.025529754547668353, 0.010254764197660344, 0.06370832465056862, 0.044541973288037946, 0.00622174670154761, 0.054898979142308235, 0.020148281440404908, 0.016322729843003408, 0.024468678448881422, 0.008301512936928442, 0.08684603630432061, 0.04549188160204461, 0.009803267844420458, 0.033638404083571265, 0.04166838087673698, 0.028663979044982364, 0.09034393182290451, 0.013287250002446984, 0.059484640934637616, 0.026011285405339937, 0.022814374450328093, 0.027351939984198128, 0.020314712509778992, 0.06985544479851212, 0.07487328590026923, 0.06745661994708435, 0.04689943803740399, 0.038102577573486736, 0.05489060602017811, 0.04124280371304069, 0.030343780693198954, 0.06356703330363546, 0.008258365743261362, 0.08798064185040337, 0.0585624168493918, 0.05101360280865005, 0.03939598406265889, 0.03130149555259517, 0.06489428172686271, 0.01823002053424716, 0.03683910804933735, 0.08294526740376439, 0.030564260469483476, 0.05352914246863552, 0.012871668507744159, 0.0288202931572284, 0.10405512287148408, 0.011368802499159105, 0.015595613413357308, 0.0540702436119318, 0.021855333054970418, 0.04327224088566644, 0.006215055074010576, 0.04149291850626469, 0.0382077708574278, 0.05311303086844938, 0.009681975468993187, 0.0081665260284873, 0.0511780423777444, 0.04460643072213445, 0.024365132308698127, 0.0283813183195889, 0.014970401069149375, 0.019591063394078186, 0.036765680382294316, 0.017655165666448216, 0.016115070985896245, 0.02825808957485216, 0.04660761369658368, 0.027784324550469006, 0.06237068107085569, 0.08077264577150345, 0.0312970647189234, 0.011217259336262941, 0.015089913138321467, 0.0568788052270455, 0.05029990949801036, 0.015123802569827862, 0.04107279676411833, 0.028840513500784124, 0.08559945212411028, 0.0392220246472529, 0.0439909655334694, 0.06939893322331564, 0.041178573588175435, 0.010125795894834613, 0.009890489280223846, 0.07155304442026786, 0.04095770365425518, 0.028096041841698543, 0.029680495749094656, 0.025493189991850938, 0.031771370874983926, 0.07406496070325375, 0.01566196565649339, 0.021198273669662218, 0.018381640880501697, 0.039277318465922556, 0.018693071490685855, 0.041451605901654275, 0.05297336122021079, 0.015204556718734758, 0.027565600483545234, 0.0443568485789001, 0.033909533106322796, 0.08235910814255476, 0.03158555406012705, 0.08966352404760462, 0.049370713465447934, 0.05557349044829607, 0.02030535551187183, 0.004957270825148693, 0.03146385541185737, 0.0467723178943353, 0.03195436837683831, 0.02775451141808714, 0.05309019137972167, 0.016548960203570977, 0.05627589972157564, 0.054547986547861776, 0.0320675785520247, 0.02856753207743168, 0.033209681910063536, 0.040905928039657216, 0.02570452820509672, 0.0570508036762476, 0.047533240634948015, 0.03049020855022328, 0.12535004876554012, 0.019447710997025882, 0.1259535513818264, 0.01690142012999526, 0.11373122222721577, 0.3545454852283001, 0.5260141342878342, 1.4854680789368493, 2.7124149671622684, 3.980752382959638, 6.5408439465931485, 9.601562772478376, 12.468691757747106, 14.743921075548444, 16.693774938583374, 21.89539963858468, 21.776642765317643, 24.126139640808105, 27.334102085658483, 27.543614591870988, 27.795101165771484, 28.068113258906774, 31.825153623308452, 32.4276909828186, 36.50832980019705, 38.48683977127075, 37.222833905901226, 35.65404183523995, 29.742966106959752, 22.397208963121685, 12.234573943274361, 6.536314589636667, 3.9072717087609425, 1.040555164217949, 0.30575417620795114, 0.066072496718594, 0.04109570749902299, 0.014150236284227243, 0.04235370124557188, 0.023974979761987925, 0.043083750642836094, 0.015843329585290382, 0.04454682820609637, 0.04207947471046022, 0.04464306482779128, 0.05151695365618382, 0.015873113879933953, 0.0491669595773731, 0.03858738745163594, 0.05696076886462314, 0.08777473361364432, 0.022806712093630006, 0.027899451587083082, 0.031001454152699028, 0.0799531586734312, 0.039972477592527866, 0.03252705871792776, 0.024705921432801654, 0.028589526790061166, 0.008012406128857816, 0.0456292951213462, 0.025720034426610385, 0.05785142071545124, 0.035263889003545046, 0.06273867096751928, 0.05404628114774823, 0.04748587549797126, 0.056018365147922716, 0.031978381731148274, 0.06693325231650046, 0.04498735688892858, 0.018148950866556594, 0.04103191163656967, 0.007813837944662996, 0.0347148897126317, 0.04090480167152626, 0.03348776252408113, 0.0727863564555134, 0.0755220807290503, 0.018833455297031572, 0.026656175265088677, 0.05890195577272347, 0.02303278469480574, 0.031097636491592442, 0.044731667930526395, 0.05303899930523975, 0.040099777547376494, 0.03152722379724894, 0.02339414191166205, 0.032181080497269116, 0.006855952179258955, 0.014800879272765346, 0.052406960898744206, 0.043339371747736416, 0.07031722859080348, 0.01288676930458418, 0.01902192009479872, 0.03011408301868609, 0.05142175858574254, 0.03836512652092746, 0.027173593839896575, 0.0052595382439903915, 0.05553484448630895, 0.0353646718098649, 0.05769197177141905, 0.0551667799507933, 0.1989235465547868, 0.11632139395390238, 0.15657253909323895, 0.11581258768481867, 0.10287481799189534, 0.11794892804963247, 0.0966317258509142, 0.13969978876411915, 0.11978845005588871, 0.15802096708544663, 0.11972949893346854, 0.12592324800789356, 0.1766364396150623, 0.20267177399780067, 0.21209897313799175, 0.15207609108516149, 0.13782526792160102, 0.18184408731758595, 0.13584409494485172, 0.16103214264980384, 0.2868022860160896, 0.10891227331012487, 0.15542565206331865, 0.13640370991613182, 0.17322196997702122, 0.17033879325858184, 0.12676661275327206, 0.09609236514994077, 0.09918956538396222, 0.15593783743679523, 0.08686952040131603, 0.10443905834108591, 0.0887802614431296, 0.21009201583053383, 0.1195602315877165, 0.1569743403898818, 0.09071119568709816, 0.06776201498827764, 0.12047169410756656, 0.10492157137819699, 0.12364969429160867, 0.10740678052284888, 0.16355778569621698, 0.1647773573973349, 0.11627438504781042, 0.1148697089936052, 0.12508159317076206, 0.1865731371300561, 0.13767946431679384, 0.1678906660526991, 0.12067453536604132, 0.155394955139075, 0.126890431823475, 0.17747972293623857, 0.10301085069243397, 0.13171689212322235, 0.1509946012603385, 0.09453970060816833, 0.14536175637372903, 0.09229429252445698, 0.15969191385166986, 0.13028668958161557, 0.11400533680404935, 0.10200745346290724, 0.13278540835848876, 0.13912249117025308, 0.17300789217863763, 0.2251372949353286, 0.08935466169246606, 0.2671759048742907, 0.266298911933388, 0.08531590591051749, 0.22998116644365446, 0.12311196886003017, 0.22923724779060908, 0.4677018661584173, 0.6777500893388475, 1.4639183495725905, 1.9107954331806727, 3.4009944753987447, 5.241897761821747, 7.964028699057443, 11.621746301651001, 13.998269064085823, 18.093199457441056, 21.2212906224387, 23.007425819124492, 23.777268852506364, 27.188182967049734, 28.103038379124232, 28.83823595728193, 30.415735857827322, 33.811230182647705, 34.50793995176043, 39.381927558353965, 41.85984625135149, 41.5729203905378, 38.71467467716762, 33.13713332584926, 24.633139269692556, 12.957474078450884, 6.167788650308337, 3.2191312398229326, 0.8410523523177419, 0.25731836525457247, 0.1449301673897675, 0.14292107948235103, 0.2137501338230712, 0.1706537285021373, 0.11100759623306138, 0.08191892211990696, 0.1217097355318921, 0.10032300384981291, 0.1661478081451995, 0.17083928068833693, 0.20126886213464396, 0.08275909775069781, 0.18035515078476497, 0.14402895074869904, 0.1715414287256343, 0.1671087901507105, 0.08224279366965805, 0.18535945511290006, 0.2008532187236207, 0.14802563057414123, 0.19343521605644906, 0.10320898970322949, 0.11395097257835524, 0.1287161795688527, 0.14357179456523486, 0.06750598336969103, 0.14320838477994713, 0.13244931639305182, 0.17221875595194952, 0.176011359585183, 0.14268763629453524, 0.19598517779793057, 0.12033499644270965, 0.09508254897913762, 0.11317390748964888, 0.07126292998769454, 0.11468928653214659, 0.15439103543758392, 0.17953600973955222, 0.13117935668144906, 0.1578926018306187, 0.1367845173392977, 0.13542599523706095, 0.15613565753613198, 0.1752897375928504, 0.12701282597013883, 0.2557895172919546, 0.10346996784210205, 0.13655947441501276, 0.1288778201809951, 0.21464940985398634, 0.1060251814446279, 0.07606769752289567, 0.12663927887167248, 0.15635244947459015, 0.11312497832945415, 0.1995937084513051, 0.15316131285258702, 0.08781897409686021, 0.21677892415651254, 0.12175336533359118, 0.06785232799925975, 0.17613030677395208, 0.14227299711533956, 0.15434219448694161, 0.11547907415245261, 0.09948915216539587, 0.11669806231345449, 0.1952336731233767], [0.059901851761553965, 0.016200651215123277, 0.03388146211260131, 0.035460799865956814, 0.011110954103060067, 0.017255518718489578, 0.0473651200133775, 0.034686326781021695, 0.04114812093653849, 0.026549714817000285, 0.058636207532669814, 0.09640303919357912, 0.07885288021394185, 0.031458759613867314, 0.007232140899369759, 0.010662230413540133, 0.005323007561465991, 0.021382534942988838, 0.041796206696225066, 0.13998041727713176, 0.013115154013835957, 0.08810196391173772, 0.01889719518034586, 0.04422434086778334, 0.10365826809512717, 0.022855780353503566, 0.06014239921101502, 0.015608994123925055, 0.004682680425633277, 0.03676772955805063, 0.021728039885471975, 0.02404680099737431, 0.026552145668704594, 0.005632480598121349, 0.018197120067530444, 0.015000168400417482, 0.05822664379541363, 0.0066999103291891515, 0.028343808903758014, 0.09726075495460204, 0.021143816145403043, 0.031027587928942273, 0.011452929815277457, 0.06377926548676831, 0.03244926807071481, 0.03872468561998435, 0.020656030891197066, 0.043173904198088815, 0.019354707594694834, 0.0328632490709424, 0.020684712566435337, 0.05644668698576944, 0.04701817148764219, 0.02734189766592213, 0.05872677160160882, 0.025443699343928268, 0.029691053753984824, 0.04258574325857418, 0.022164232729535018, 0.03297652709963066, 0.04399579331012709, 0.010655513765024287, 0.021693960464160358, 0.017937680506812673, 0.03941552587119596, 0.04019298451021314, 0.0589357264606016, 0.03410980610975197, 0.07591964118182659, 0.04614751945648875, 0.055791239121130536, 0.05300037030662809, 0.005711011696673397, 0.00512594954177205, 0.014700128696858883, 0.06399829659078803, 0.07296958126659904, 0.03146050684154034, 0.043629079059298546, 0.021423481138689176, 0.036722104863396714, 0.06815834729267017, 0.034751859693122764, 0.09046080269451652, 0.023252877706129636, 0.13238987672541822, 0.2077172789722681, 0.16928386129438877, 0.5869940764137677, 0.8233616415943418, 0.6883440837264061, 1.0168508418968745, 1.2161771804094315, 1.3247720961059843, 1.2930099261658532, 2.0275199583598544, 1.9854844425405775, 2.031837829521724, 2.593342819384166, 2.2569994160107205, 1.3050673305988312, 0.3552633209952286, 0.0872993723356298, 0.033928091039082835, 0.11542324429111821, 0.02714728025187339, 0.08608665383820023, 0.041217148303985596, 0.03921551410374897, 0.021444205294496248, 0.09549794811755419, 0.02078050305135548, 0.0004824210638097221, 0.05855497332023723, 0.03391822174723659, 0.062009001549865515, 0.06550875625440053, 0.0209666710080845, 0.027450644777023366, 0.0542383235214012, 0.023131933928068196, 0.04765621153637767, 0.014402246734659587, 0.035827846598944495, 0.039475114816533666, 0.01195518228424979, 0.04314174163820488, 0.0069588299624488825, 0.04826777854136058, 0.05784945296389716, 0.06488140991755895, 0.027743420763207332, 0.0728729103824922, 0.020787417323195508, 0.013292250805534422, 0.06378988455981016, 0.016392362802954655, 0.016192300145381262, 0.024628777090193968, 0.02275044796988368, 0.010532631073147058, 0.014870500358353769, 0.037570928423000235, 0.010254752323297518, 0.014250643351780517, 0.029384070940847908, 0.04595895118213125, 0.018159032200596163, 0.03926040258790765, 0.03556679042854479, 0.045097679897610626, 0.034214748335736136, 0.0036036388399744673, 0.07636075001209974, 0.06677195775721755, 0.009263789247987526, 0.010314864588768353, 0.13228227464216097, 0.026830682597522224, 0.045891559084079096, 0.04891612892970443, 0.014317141479945608, 0.05323726384501372, 0.006409831943788699, 0.03059084547151412, 0.030699709629906074, 0.023814972722902894, 0.012820157521803464, 0.03363190371809261, 0.02800805790216795, 0.021243964521480457, 0.03270358978105443, 0.0016446152606347042, 0.029533219723297015, 0.04300416527049882, 0.053441523241677454, 0.04247855508167829, 0.0752061480390174, 0.060729854474110265, 0.05398554547822901, 0.044984690246305296, 0.05837432694222246, 0.05702833059642996, 0.00302155630197376, 0.06420902242617947, 0.022409726699282016, 0.03630928076537592, 0.023506856756284833, 0.016717011275302087, 0.0319116003146129, 0.0728230584146721, 0.034067519807389805, 0.03538222211812224, 0.059098398445972374, 0.022735822147556713, 0.011869335730027939, 0.046029953086482625, 0.0534926067505564, 0.018897904249440347, 0.03089718706905842, 0.04846378016684737, 0.0817052378718342, 0.0971194025395172, 0.02245488659744816, 0.022510311034108912, 0.062293809838593006, 0.02798975950905255, 0.021387232101655433, 0.025307018642446825, 0.0534423035569489, 0.047234661478017054, 0.028450774860435298, 0.06903341997947011, 0.03851262307060616, 0.06106631963380745, 0.059196317834513526, 0.020168130286037922, 0.016931061932284917, 0.07003305812499352, 0.01711979305504688, 0.03201839494119797, 0.07399302920592682, 0.024581603639359986, 0.03679329336487821, 0.010231917075413679, 0.028768833061414104, 0.01634910449917827, 0.021908299498526112, 0.04063040210998484, 0.05517342280862587, 0.07137000281363726, 0.021757785164351975, 0.06734977103769779, 0.0393972325670932, 0.01815111200059099, 0.00996533762996218, 0.12522450621638978, 0.05937414150685072, 0.04485994158312678, 0.020289348870781914, 0.041696699535740275, 0.03936709543423993, 0.07949564286640712, 0.11217614210077695, 0.00969710001455886, 0.010909669234284332, 0.044018510662551434, 0.049387011876595874, 0.017169546635289277, 0.004006192038234855, 0.04141410666384867, 0.01949664524623326, 0.07710820383259229, 0.039870721088456254, 0.03005406998896173, 0.04002080964190619, 0.03984764750514712, 0.04742608638480306, 0.050704194232821465, 0.06258317109729562, 0.16161113658121654, 0.3497194456202643, 0.6468137779406139, 0.6621409069214548, 1.257147559097835, 1.7820448790277754, 1.8368583491870334, 2.2816446764128546, 2.4811107388564517, 2.8762241772242954, 2.847683365855898, 3.416956658874239, 4.6752009476934155, 4.222079821995326, 4.337128528526851, 3.688431680202484, 2.5929452521460394, 0.8548548945358821, 0.3580680319241115, 0.024616112234070897, 0.07971013457115207, 0.09355380958212273, 0.021846428979188204, 0.09852192085236311, 0.011085568411674882, 0.01614644644515855, 0.060034810698458126, 0.018811150154631053, 0.008529986703901418, 0.03358609921165875, 0.0505465366212385, 0.05835379447255816, 0.009057792801676052, 0.0006126629450591281, 0.13982637625719818, 0.05174477518137012, 0.044042574906987805, 0.039693640411964486, 0.024249248705538254, 0.10196086524852685, 0.05180793661358101, 0.07161358331463166, 0.01913767647264259, 0.04106261195348842, 0.025712061640141264, 0.043040032631584575, 0.05081902610670243, 0.020302526020844067, 0.0743211687409452, 0.019120585871860385, 0.014158657751977444, 0.045900308793144565, 0.011451674525492957, 0.023103667855528847, 0.022218098231990422, 0.07174302744013922, 0.027240426146558354, 0.02009209874086082, 0.030166788226259605, 0.00720917503349483, 0.06755122129938432, 0.04000419571197458, 0.06039721625191825, 0.04092058100338493, 0.01266498928557017, 0.03681496238069875, 0.03217113656657083, 0.016011200845241547, 0.024942652122782807, 0.03420107924778547, 0.051263907591679266, 0.016228494899613515, 0.03839444601908326, 0.06507465669087001, 0.05413908438224878, 0.051312171787555726, 0.019767830248123834, 0.02767882083675691, 0.02349017158017627, 0.007654703671245703, 0.07782462824668203, 0.006097630348189601, 0.027660164516419172, 0.03204155334138444, 0.029640926979482174, 0.017069471201726368, 0.021781284528385316, 0.0716358053364924, 0.07555181413356747, 0.06206901118691478, 0.044311607256531715, 0.06731113525373594, 0.10994751418807677, 0.1117412079391735, 0.12900079786777496, 0.12730238400399685, 0.07701386710894959, 0.17550486033516272, 0.1365311930754355, 0.09772341405706746, 0.16435727636728967, 0.10048282598810536, 0.15666954245950493, 0.18977084197103977, 0.1603425339396511, 0.08368026332131454, 0.11523226382476942, 0.08508829133851187, 0.05824710162622588, 0.09285632308040347, 0.1235790995082685, 0.17340877066765512, 0.0738467031291553, 0.22501931126628602, 0.14461357652076653, 0.11517586399401937, 0.20771973526903562, 0.12281562547598567, 0.2194760465728385, 0.10862099179731947, 0.1415967419743538, 0.168021541887096, 0.0560994025851999, 0.0943002456000873, 0.10628852088536535, 0.14894724397787026, 0.16443089741681302, 0.07637525709079844, 0.1584975022290434, 0.1326913634049041, 0.16122059896588326, 0.1987960769661835, 0.13066704917166913, 0.08720977178641728, 0.13124022127262183, 0.07966229785233736, 0.09813213641090052, 0.1451209850077118, 0.1100385193047779, 0.14666881838015147, 0.23124921268650464, 0.09301864901291472, 0.11678923027856009, 0.18220018249537262, 0.12978884843843325, 0.10087843904537813, 0.14235170717750276, 0.1294123022151845, 0.23757432614053997, 0.1423603245722396, 0.13435766899159976, 0.11162729548024279, 0.24391016044786998, 0.15545983665755816, 0.216571143163102, 0.14390640732433113, 0.05646665287869317, 0.08186392685664551, 0.1139471727822508, 0.23890167634402001, 0.09375493414700031, 0.14682999758848123, 0.15550490495349678, 0.14382919003920897, 0.10286383250994341, 0.08753666281700134, 0.10464869852044753, 0.1351310224937541, 0.20234096103480884, 0.06751821735607726, 0.0720698166904705, 0.057972227090171406, 0.12177559414080211, 0.10071848798543215, 0.17072980584842817, 0.13962160795927048, 0.18053764956338064, 0.2601424280021872, 0.5462903891290937, 0.6431340553930828, 1.1087845202003206, 1.3973551498992103, 1.41213244838374, 1.5814970689160484, 1.8743679821491241, 2.205905620540891, 2.632140040397644, 3.250216177531651, 4.071350812911987, 4.099930925028665, 4.678496130875178, 3.2755288992609297, 2.3113265122686113, 0.6794606489794595, 0.3430742807686329, 0.1021517100078719, 0.16357146496219294, 0.1227006409317255, 0.17923950350710324, 0.25666295470935957, 0.17009036801755428, 0.1500722821801901, 0.13797400279768876, 0.12941393069922924, 0.11694447909082685, 0.12817708349653653, 0.13627106989068644, 0.16914443591875689, 0.15333838335105351, 0.09166512771376542, 0.22557602210768632, 0.10381111489342791, 0.12154874631336757, 0.20903469542307512, 0.0976718318249498, 0.17447825042264803, 0.2631434526826654, 0.12114100104996137, 0.0691609913483262, 0.08278177439102105, 0.1561938894114324, 0.14073120270456585, 0.12586036138236523, 0.09575369475143296, 0.12184924233172621, 0.136443485638925, 0.0880418796358364, 0.11343648697116546, 0.13257982581853867, 0.12385182987366404, 0.13556243505861076, 0.22274646322642053, 0.13187167953167642, 0.16164662396269186, 0.12104116140731744, 0.15637653746775218, 0.21210434713533946, 0.23513990534203394, 0.2215337311582906, 0.07780866231769323, 0.11662106215953827, 0.18874062225222588, 0.1740946474352053, 0.13469078897365502, 0.167493695925389, 0.18385295809379645, 0.18172409518488816, 0.13163645858211176, 0.11346185061016253, 0.1624753052102668, 0.12969567200967244, 0.11907342342393738, 0.19635108459208692, 0.1281042495476348, 0.11122881900519133, 0.11869861425033637, 0.11870055486048971, 0.1581868553268058, 0.12687840818294457, 0.14952828708503926, 0.15106691952262605, 0.14561565060700687, 0.13689057236271246, 0.1971947478928736, 0.14244378437953337, 0.08839623097862516, 0.09965410402842931, 0.09753740046705518], [0.025352064885997345, 0.012752125904496227, 0.039545960657830746, 0.02163421715210591, 0.0447525498457253, 0.034098664564745765, 0.044659400558365245, 0.028731286326157193, 0.021512783132493496, 0.019195925311318467, 0.04967940279415675, 0.0028353739263755934, 0.023735124418245893, 0.01722635019437543, 0.06385138018855027, 0.04954730220405119, 0.01965563278645277, 0.06698540451803378, 0.030455705044525008, 0.03118451950805528, 0.04784219119963901, 0.04352943958448512, 0.0657117400052292, 0.052338340652308295, 0.048168512260807414, 0.016150132586647357, 0.06304616268192019, 0.06129342530454908, 0.02257419001710202, 0.014034415445556598, 0.02843018132261932, 0.06160426898194211, 0.04565994115546346, 0.021260497027209828, 0.08359146344342402, 0.025331954804382155, 0.044172232771026235, 0.05867682463888611, 0.014833747509068676, 0.050241575842457156, 0.062242471879082065, 0.022971397631668618, 0.06806405806647879, 0.0077346189812357935, 0.02576482113051627, 0.06634080982101814, 0.011064302276021667, 0.04454888416720288, 0.030213749634900262, 0.019934622637395347, 0.019465871986800005, 0.0023784673165729536, 0.0366556898557714, 0.00671968114329502, 0.01673992540288184, 0.016687372865687524, 0.06404071181480374, 0.034179990379405875, 0.04888375263128962, 0.029604479470955472, 0.004438945133837738, 0.027159185148775578, 0.0015893214419650445, 0.04236820832427059, 0.04789896422464933, 0.014743826352059841, 0.04798284811632974, 0.01704271656594106, 0.014456144467528378, 0.02241032550643597, 0.048674285478357754, 0.0449766529990094, 0.03124432558459895, 0.023329944017210176, 0.031073636707982848, 0.006054442018337015, 0.06632377180669989, 0.034900940622070005, 0.05009005558011787, 0.02657801142361547, 0.05763070684458528, 0.07443186494388751, 0.040162752382457256, 0.009666524378449788, 0.06944717027779136, 0.07006172622953143, 0.02354806418796735, 0.03073846755017127, 0.0598823574504682, 0.028295899242428795, 0.06666197401604482, 0.010505089336740119, 0.07480873007859502, 0.06493679873113122, 0.014312902332416602, 0.03317737685782569, 0.0032572503176717354, 0.08445927580552441, 0.047654616979083846, 0.014053846143984368, 0.03149192301290376, 0.07048933221293346, 0.0254970746048327, 0.06778631332729544, 0.029762014946235076, 0.04240464226209691, 0.04980656364932656, 0.02187799782093082, 0.0459197216800281, 0.01828619814477861, 0.012904734367371669, 0.017202842348654355, 0.020542924192601016, 0.013636982218096299, 0.05080281929778201, 0.07857027037867478, 0.042627754754253795, 0.028395180790019885, 0.04146654724276491, 0.056312672926911285, 0.038861264541213, 0.01856084706793938, 0.07534554627324853, 0.018380431391830956, 0.04688631856281843, 0.038555523447160206, 0.014191157034864383, 0.021439538669905493, 0.023178527231461236, 0.03899084437372429, 0.0608203506895474, 0.06888101422893149, 0.010037293724183525, 0.06361674956445183, 0.04132210749334522, 0.022560598960678493, 0.04674002302012273, 0.03014315485156008, 0.03742295350613339, 0.07003402164472, 0.02740222112541752, 0.009555390520420457, 0.046274629421532154, 0.030589841239686524, 0.06944284122437239, 0.06782335455396346, 0.009840528746800763, 0.02125213577944253, 0.07343417419386761, 0.018339279939287474, 0.02798886045015284, 0.03160315865118589, 0.02969931491783687, 0.05773466519479241, 0.021564266977033446, 0.01976485826474215, 0.05999549637947764, 0.015684839071972028, 0.023136059420981576, 0.06296684193824019, 0.0468535487140928, 0.01717421834889267, 0.05432337110063859, 0.06337264659149305, 0.03315795718559197, 0.06355733703821898, 0.0957439849153161, 0.02918876481375524, 0.0546413529664278, 0.02334475134765463, 0.04663708247244358, 0.13020835949906281, 0.06218441642288651, 0.046645750757306814, 0.015004809579945036, 0.03633492599640574, 0.036081337103886266, 0.009189280165758516, 0.022328070098800317, 0.07120228252772774, 0.012145852320827544, 0.0275913712435535, 0.03291222233591335, 0.01102253420477999, 0.03353159249361072, 0.08043350718383278, 0.034705318976193666, 0.0289096562191844, 0.027232712899733866, 0.05050606879272631, 0.04856419995693224, 0.11359516917062656, 0.07566654083452054, 0.028832666243293455, 0.03448399781648602, 0.01732241887865322, 0.015419682853722146, 0.053674620376633744, 0.05703369780842747, 0.05623537761026195, 0.003973090555518866, 0.005495596760218697, 0.0828770339222891, 0.018183228759361163, 0.004290428237124745, 0.013555625869360353, 0.06437683092164141, 0.016994191134082418, 0.023631629168189, 0.04724300745874643, 0.03128891551334943, 0.06393134554049798, 0.014423454346667443, 0.01324460662103125, 0.026758372816922407, 0.03475808525191886, 0.04141220337312136, 0.009689740454112845, 0.00908141175750643, 0.01931647553906909, 0.03036190097087196, 0.01262529329064169, 0.10736783261277846, 0.07129818666726351, 0.041818577995789905, 0.030003502166696956, 0.031724935330982716, 0.026321849187037775, 0.030403881932475736, 0.025507184776610563, 0.040992617673639736, 0.029100640078208277, 0.07698983339858906, 0.048743434982108216, 0.02958490712834256, 0.041060043698442836, 0.04330226606024163, 0.019340037667591656, 0.019620357447170785, 0.03336492393698011, 0.05671580754486578, 0.03674506309575268, 0.02969167461352689, 0.052405145817569325, 0.027963776706850955, 0.006967360843970839, 0.04485194504793201, 0.05516518878617457, 0.030566957646182606, 0.06289282055305583, 0.04744601495830076, 0.01740145972663803, 0.011341001223107534, 0.013276284028376852, 0.02916505340752857, 0.03843958556119885, 0.08230171086532728, 0.027557446188958626, 0.08159446024468966, 0.06993307598999568, 0.037943186304931126, 0.053021113122148175, 0.013315673834378166, 0.0759636645338365, 0.052863089101655145, 0.030089893245271275, 0.07195990080279963, 0.053511731260057004, 0.07443293024386678, 0.01830872890007283, 0.014929588884115219, 0.037919125453169854, 0.07147601712495089, 0.11922606666173254, 0.06268727872520685, 0.013327356511061745, 0.022919404885864685, 0.03465397423133254, 0.05049488314294389, 0.022703364424939667, 0.036216888044561656, 0.037824188226035664, 0.013804064681088286, 0.00814068571863962, 0.04150841624609061, 0.042973621016634364, 0.027164523523034792, 0.08416253887116909, 0.022635008807161024, 0.03163520586011665, 0.02116325617368732, 0.06280140152999333, 0.00552720292138734, 0.0036415316280908883, 0.030936752445995808, 0.042983252821224074, 0.036194326755191596, 0.03370407609535115, 0.060103091677384715, 0.0209092143590429, 0.11898567527532578, 0.020129029705588306, 0.03538676491007209, 0.023140020369152938, 0.014230248285457492, 0.07527775383953537, 0.02784204243549279, 0.03004767479641097, 0.059103677448417456, 0.014840473487441028, 0.03597917008612837, 0.024723897521783198, 0.08123795794589178, 0.015408755047246814, 0.031752843476299725, 0.03432774477239166, 0.02394608943723142, 0.017125755681523254, 0.011085451364384165, 0.045859454199671745, 0.04514411883428693, 0.03396147156932524, 0.019904507556930184, 0.07134565697716815, 0.06820042324917656, 0.026635181391611695, 0.007876009563915431, 0.022890506079420447, 0.017678461469975964, 0.04735057222257767, 0.04108740223039474, 0.02707083480033491, 0.02347435153621648, 0.013572037086955138, 0.022925087616645863, 0.04812783408643944, 0.03897276141547731, 0.0362271576720689, 0.02363176826786782, 0.016801873953746896, 0.04837820672297052, 0.037271175400487015, 0.05067649304068514, 0.023198398129482354, 0.039734138774552515, 0.019495196573968445, 0.04216677502595952, 0.03625103531937514, 0.009193891659379005, 0.010180361984696771, 0.04935763131028839, 0.04273511595757944, 0.14679345169237681, 0.07080244219728879, 0.10869301828954901, 0.18098365063113825, 0.12116785746599947, 0.1629268838358777, 0.139584695654256, 0.10759203415364027, 0.10842992990676846, 0.17582910507917404, 0.10301209919686828, 0.09987884161195584, 0.09005044507128851, 0.10341634321957827, 0.15373478350894793, 0.14990450761147908, 0.11354723745690924, 0.22443544545343944, 0.10186962942991938, 0.13353415818086692, 0.13327617916677678, 0.13673710131219455, 0.22471325126077446, 0.12081101589969226, 0.20519669779709407, 0.09476785800818886, 0.1435712245958192, 0.1669470409729651, 0.07065431800271783, 0.14124603436461516, 0.1305006995264973, 0.19775023737124034, 0.1378898373139756, 0.08613197997744594, 0.14792632018881186, 0.17149507121316024, 0.09642049111425877, 0.08739348514271633, 0.0965134504118136, 0.11569973374051706, 0.14773523115686008, 0.12878823998783315, 0.1291843687317201, 0.07655538099684886, 0.16820234432816505, 0.10601729008236102, 0.19357631062822683, 0.1118056144831436, 0.11826807021030358, 0.18213459530047008, 0.07818838408482925, 0.1536534543016127, 0.11730993805187089, 0.08840126570846353, 0.08526656284396138, 0.08395624386944942, 0.13107514727328504, 0.12311238955174174, 0.118600905207651, 0.08810082397290639, 0.13321629166603088, 0.17441358603537083, 0.07460378536156245, 0.172400155503835, 0.10268877726048231, 0.06406475909586463, 0.20844811547015393, 0.1278646859739508, 0.13375960822616303, 0.11611838984702315, 0.11198658655796732, 0.12852137216499873, 0.12807515396603517, 0.17895424738526344, 0.12473332828709058, 0.12416694153632436, 0.15628914215735026, 0.06749655173293181, 0.18406825725521359, 0.21923963140164102, 0.15220255644193717, 0.14296936403427804, 0.17435884183006628, 0.1570163145661354, 0.14534586508359226, 0.13459198070423944, 0.07087776636970894, 0.19476585036941937, 0.17724754182355745, 0.1652050923023905, 0.13282120786607265, 0.19388693038906368, 0.17780711608273642, 0.17018112886164868, 0.0727471032046846, 0.16240196914545127, 0.10148107313684054, 0.18020861436213764, 0.13234472700527736, 0.06765694384063993, 0.08578476003770318, 0.1694863090025527, 0.1044911223330668, 0.1138760894536972, 0.05459422192403248, 0.09550633481038467, 0.08397523606462137, 0.12698284829301493, 0.2075273705912488, 0.14368205650576524, 0.10065568278410605, 0.13002349941858224, 0.07620748252208744, 0.09417517124009983, 0.13735811013196195, 0.17460897697934083, 0.07569992475743804, 0.11374994979373046, 0.12673339167875902, 0.1318050745342459, 0.10151880646922759, 0.13300787284970284, 0.11306062606828553, 0.0732472242255296, 0.24843970739415713, 0.1878372478697981, 0.18795475656432764, 0.09867276597235884, 0.12514376054917062, 0.22208050824701786, 0.12426793468849999, 0.22086081440959657, 0.11576065261449132, 0.07752218483281986, 0.1160084128912006, 0.07090588486088173, 0.15810955661748136, 0.12227076185601098, 0.10189029082123723, 0.1508804988116026, 0.06295655534735747, 0.13337193402860845, 0.108621229284576, 0.1778530121913978, 0.12382084796471254, 0.1397254645292248, 0.07511911913752556, 0.18587544028248104, 0.18161261188132422, 0.13628109863826207, 0.08082058427057096, 0.10744638661188738, 0.09372469184121915, 0.14039880196963037, 0.1180989792836564, 0.07544790328081165, 0.13582068548670836, 0.07838024664670229, 0.0825281719278012, 0.1696750367326396, 0.14656312976564678, 0.1393769553729466, 0.20223088908408368, 0.15410359443298408, 0.11318825171994311, 0.13533608934709004, 0.14497055379407747, 0.11854059701519352, 0.1562640770737614, 0.11809622443148068, 0.09501891596508877, 0.2266997710934707, 0.10959606697516781, 0.07870300539902278, 0.12833164020308427, 0.11797613730388028], [0.05123514449223876, 0.02380282524973154, 0.03013153833204082, 0.024736506398767233, 0.011339626341525997, 0.018420205418286578, 0.03361741699544447, 0.034571369378162284, 0.0408951427255358, 0.010051429304959518, 0.0053031421765418986, 0.03553215121584279, 0.04040888078244669, 0.01937107725201973, 0.04476366764200585, 0.037564509481723816, 0.07136591124747481, 0.0356870743313006, 0.04878039817724909, 0.038476972840726376, 0.039588671044579575, 0.03334994188376835, 0.09182784719658749, 0.02337532613559493, 0.018076115221317326, 0.030189376657030413, 0.017116291814350655, 0.02483109587670437, 0.031667446451527734, 0.04033360071480274, 0.06436433230659791, 0.062468837946653366, 0.03556834766641259, 0.024714189382003884, 0.06511370638119322, 0.017398173920810223, 0.037557340759251795, 0.02285762596875429, 0.06218725948461464, 0.025701588452128426, 0.03984214797882097, 0.03838466154411435, 0.022470944128664475, 0.06401295973254101, 0.049283219767468314, 0.0030024311563465744, 0.042966509969638925, 0.03785243903153709, 0.03149328686829124, 0.04519481557820525, 0.04557609119053398, 0.022451958718842695, 0.006441559817176312, 0.03252323856577277, 0.03831167153215834, 0.022749698188688074, 0.01616195436300976, 0.01836564272109951, 0.013021981825919023, 0.030777551167245423, 0.0260063354923789, 0.05866746085562876, 0.06523123543177332, 0.02861241377624018, 0.0378982672866966, 0.035348461608269384, 0.041599794557052, 0.040234507460679324, 0.02105423595224108, 0.02723981885771666, 0.04122240695038012, 0.020004586383168186, 0.009101788164116442, 0.023369254943515574, 0.02219355053135327, 0.03629482118412852, 0.016438745760491917, 0.014814037763114487, 0.02427686677713479, 0.021568925119936466, 0.033964141604623625, 0.06848386089716639, 0.038368373310991695, 0.020351470448076725, 0.05279539505551968, 0.030948650557547808, 0.010024134385665613, 0.024784606049901674, 0.021096413689000264, 0.07208485302648374, 0.0767327229093228, 0.03817611041345766, 0.020341706329158375, 0.04782445090157645, 0.02311193071571844, 0.026481313398107886, 0.05219293399048703, 0.03959056076460651, 0.09222601833088057, 0.053412811032363346, 0.06435057161641972, 0.041541369299271276, 0.007847004736374532, 0.04215852743280785, 0.018959036861945475, 0.05519180092960596, 0.05333699492205467, 0.004829508194234222, 0.041788926015474966, 0.04810730840212532, 0.01334366764474128, 0.018957008042239716, 0.04604074518595423, 0.015264866607529777, 0.04636155993544629, 0.009492087444024426, 0.049592550311769755, 0.018363783535148417, 0.060098043376845975, 0.025296097621321678, 0.015895016990335922, 0.012894413849738027, 0.058453552690999847, 0.05489036514024649, 0.04826028412207961, 0.032102845409618955, 0.016245093562507203, 0.041033706361694, 0.034254893860114474, 0.10957372281700373, 0.02786421187088958, 0.0140985234341185, 0.06260373749371086, 0.033913516106882265, 0.010811741364055445, 0.06123813148587942, 0.030548321681895425, 0.019147389701434543, 0.06634940007435423, 0.04532113504995193, 0.01659172826579639, 0.02921665260302169, 0.06105797365307808, 0.03702361529160823, 0.051395455175744634, 0.01265953471218901, 0.12603409348853997, 0.09679308826369898, 0.04591279723016279, 0.024450257919462662, 0.034185096355421205, 0.031185564451983998, 0.004771991325209716, 0.037327222393027375, 0.04855612878288541, 0.034864177594759634, 0.02340075253908123, 0.06837322576237576, 0.029750439138816934, 0.07508674623178584, 0.05734718777239323, 0.014340503440637673, 0.041742768670831404, 0.0638835970312357, 0.052560211425381045, 0.049667382546301396, 0.017548320149736743, 0.03379377842481647, 0.04572572512552142, 0.09453440124967269, 0.019841939842860614, 0.05244387320375868, 0.014086108787783554, 0.006992340262513608, 0.022042113389553766, 0.04440040034907205, 0.022917657658191662, 0.01909897962052907, 0.03095025529286691, 0.049164292934749804, 0.0452115584297904, 0.001314908839828734, 0.020411088231152723, 0.02109306342234569, 0.036350630689412355, 0.014331733375521643, 0.024818673596850464, 0.03769382807825293, 0.05890605412423611, 0.03156594439808812, 0.05266157777181693, 0.05208367967445936, 0.030821988425616707, 0.021373764877872806, 0.019284163701481054, 0.012780107840496515, 0.013475676632619329, 0.010624889783295137, 0.0429457909028445, 0.011056202264236552, 0.034529035578348806, 0.014574056890394007, 0.0338328213297895, 0.025785231463877217, 0.05688682211829083, 0.044827992761773724, 0.025835310740928565, 0.05571407951148493, 0.03715431470690029, 0.038028176208691936, 0.022266910344894444, 0.03706084650808147, 0.031833477185240815, 0.051479345852775235, 0.008602450851217976, 0.027720455745501176, 0.017575615917199423, 0.019798208260908723, 0.019558342739141414, 0.06912912055850029, 0.00671163880698649, 0.022024135604234676, 0.015154448603945119, 0.029870706078197275, 0.057009718380868435, 0.03424126209158983, 0.05429852993360587, 0.02608162064903549, 0.017459971497633626, 0.019744975492358208, 0.01838897245137819, 0.019540419236623814, 0.06908552468355213, 0.04394718645406621, 0.01956916367635131, 0.03655788242550833, 0.07443948489214693, 0.025952831309820925, 0.03573850389303906, 0.06523050261395318, 0.03836875668327723, 0.10340518810387168, 0.05011993147698896, 0.03322751381035362, 0.018492528769586767, 0.05911616249276059, 0.002941467541469527, 0.027653735397117477, 0.036342362740210125, 0.05427744106522628, 0.05605433428926127, 0.04126588747437511, 0.0639812382204192, 0.01664731724719916, 0.04231656502400126, 0.033325799607804844, 0.04835457334827099, 0.06338663798357759, 0.03189075571884002, 0.012194553323622261, 0.02682347146661154, 0.01031276282654809, 0.034757566172629595, 0.037930914999118874, 0.010740981187804468, 0.011169869602391762, 0.09929514543286391, 0.04979948992175715, 0.012232915997239096, 0.0678385401676808, 0.029150023856865506, 0.02020191284827888, 0.055864554829895496, 0.029171967679368596, 0.09364395295935017, 0.0719019335561565, 0.06563751505953924, 0.01183323172985443, 0.044964985589363744, 0.03785405394488147, 0.04941273174647774, 0.02076096972450614, 0.050359993773911677, 0.08380400096731526, 0.11329928040504456, 0.044426208428506336, 0.05080655463305967, 0.023840339754575064, 0.07260710107428686, 0.011818969771931214, 0.016008807312963263, 0.006463157586819891, 0.024799391327958022, 0.03846233344769903, 0.024323402405051247, 0.0308963931830866, 0.0609291402090873, 0.025175430346280336, 0.037222443015447686, 0.03235335714582886, 0.05477321606927684, 0.0438008976967207, 0.030864010099321604, 0.06574831982808453, 0.028693132302058593, 0.0313056481869093, 0.024799966386386325, 0.05847750497715814, 0.06743242338831935, 0.05011400108092597, 0.013351969520694442, 0.040220241261912246, 0.017468363279476762, 0.03488489666155406, 0.02573996300010809, 0.008936145891701537, 0.0294376412805702, 0.05113717082089611, 0.027636515874681727, 0.03418416676244565, 0.01968487086040633, 0.007167223757798118, 0.054575806483626366, 0.063927016487079, 0.007869795031313385, 0.03092996709580932, 0.0737309789817248, 0.036887351889163256, 0.03892789328736918, 0.04039514384099415, 0.009443064137095851, 0.03734799574262329, 0.1067496125719377, 0.08681710357112543, 0.011944636153722448, 0.02926555462181568, 0.021545951620542576, 0.015815034675012742, 0.02163957248974059, 0.02489063053924058, 0.04075225342863372, 0.04331443558580109, 0.0192793952966375, 0.06754014760787998, 0.04379942527573023, 0.037519088347575495, 0.010108674759976566, 0.016096591084663357, 0.03530834661796689, 0.01408168304312442, 0.030800478865525553, 0.021733605568962436, 0.12221810753856387, 0.11500058482800211, 0.13837694403316292, 0.14549290362213338, 0.13993042281695775, 0.14475623172308716, 0.10701487905212811, 0.20378748912896427, 0.16104575406227792, 0.09730558576328413, 0.1134054847061634, 0.14127507566341332, 0.15401706764740603, 0.12467041452016149, 0.1360245445477111, 0.1265231951006821, 0.17074553429016046, 0.07506192542080369, 0.09820257513118641, 0.07856761730675187, 0.08673867170831986, 0.13482751377991267, 0.2334336611841406, 0.06577732720013175, 0.1289842687547207, 0.09099717105605773, 0.1947400253266096, 0.06687145134700195, 0.1778667185987745, 0.17429668802235807, 0.12947262397834233, 0.16066592372953892, 0.11668624223342963, 0.09147086313792638, 0.09474290827555315, 0.09017403343958513, 0.09946623803781611, 0.08474842671837125, 0.19249779278678553, 0.12259084039500781, 0.16616857131677015, 0.08454420124845845, 0.10162811167538166, 0.1886042095720768, 0.09121158812195063, 0.12711632970188344, 0.13945795888347284, 0.10815126235995974, 0.12579698621162347, 0.131386825548751, 0.12855033203959465, 0.12581489953611577, 0.12551139082227433, 0.07641245438052074, 0.1108884522691369, 0.1301499783460583, 0.14676417969167233, 0.09443808998912573, 0.11233041382261685, 0.12849649707121508, 0.1392536655600582, 0.06702130580587046, 0.12829791701265744, 0.11701704162572112, 0.12649165679301533, 0.15186817438474723, 0.13147587648459844, 0.1618514329727207, 0.09160036154623542, 0.13388544933072158, 0.10747507507247583, 0.07514031657150813, 0.10298113085861717, 0.12517557027084486, 0.1677006491060768, 0.13337681948074273, 0.18210786102073534, 0.12514746535037244, 0.08456324772643191, 0.1775814624769347, 0.12490870244801044, 0.17948343684630735, 0.08351428687040295, 0.10025996794658047, 0.15659764488892897, 0.12065628277403967, 0.06267424406749861, 0.10519485135695764, 0.09405671938189439, 0.11190514199967895, 0.23135102008070263, 0.17414484545588493, 0.1071517395653895, 0.1537523711366313, 0.14723287097045354, 0.14198873165462697, 0.14324616560978548, 0.21815773445580686, 0.1518831971500601, 0.20465746601777418, 0.1518292807574783, 0.07551598069923264, 0.12389692531100341, 0.09355759580752679, 0.1136654382571578, 0.146642640499132, 0.11887349986604281, 0.19288729902889046, 0.1907840304608856, 0.13753178795533522, 0.16388312966695853, 0.09941745815532547, 0.16482272424868175, 0.08631154069943087, 0.1682522166520357, 0.1417493037879467, 0.1838599062923874, 0.08336110758994307, 0.10101840724902493, 0.14802364925188677, 0.14091433930609906, 0.08723699461136546, 0.1805227625050715, 0.12642786093056202, 0.1472659699086632, 0.09980663191527128, 0.0990580924387489, 0.12101046448307377, 0.13552943111530372, 0.20623928042394774, 0.11472614455435957, 0.08769088025603976, 0.1634932163038424, 0.11650098860263824, 0.08754728189004318, 0.12283546583993094, 0.09632198140025139, 0.12408114756856646, 0.16369893455079623, 0.06384471018931695, 0.09145640355667897, 0.12258207372256688, 0.11643177803073611, 0.14656175912490912, 0.1525764156665121, 0.053218865367983065, 0.19549550621637277, 0.1845935926373516, 0.06724409599389349, 0.1202334061797176, 0.13949245560382093, 0.15148265792855195, 0.07870713767728635, 0.10347518577639546, 0.10687478871217795, 0.18276808916458062, 0.15041286604745047, 0.1239063162356615, 0.16121526568063668, 0.1782226102160556, 0.14088437519967556, 0.1641457634312766, 0.11776727065443993, 0.14777318840580328, 0.09679798728653363, 0.18312035740486213, 0.1473114046135119, 0.17860341763922147, 0.15479675866663456, 0.1711556272847312, 0.09029325204236166, 0.13337323681584426, 0.1540723546807255, 0.07722525112330914, 0.0909443674609065, 0.10424866820020334], [0.05384663239653621, 0.0758122494444251, 0.025197036597611647, 0.06021751982292958, 0.024434554922793592, 0.07670488261750766, 0.037918531735028536, 0.030843752436339855, 0.01849778911231884, 0.03526704419138176, 0.10101819011781897, 0.01598530455625483, 0.030034914945385287, 0.04717542537088905, 0.02169734296122832, 0.0733645497156041, 0.040634894011808295, 0.028321067802608013, 0.08996488859078713, 0.07371974922716618, 0.058005631369139464, 0.015036878841263908, 0.06888043747416564, 0.013100620641905283, 0.056835979489343505, 0.0295454265682825, 0.0060298226474385175, 0.008457541216297873, 0.021154699847102165, 0.048569227901420424, 0.010877410831329013, 0.023741906375757287, 0.053726165289325375, 0.040834664899323664, 0.0649679299177868, 0.04619715429310288, 0.01266803081879126, 0.004739866084751806, 0.05061386425846389, 0.05923250410705805, 0.046510176067905765, 0.021884968071909885, 0.0034121359016613235, 0.09966030583849975, 0.014796095600883876, 0.019541145269093767, 0.05213473604193755, 0.019785655363063728, 0.06047283897974661, 0.07635821907648019, 0.0433422419508653, 0.03126991992550237, 0.0518640175328723, 0.02822253603621253, 0.021243182509871464, 0.033863226483975134, 0.04608908402068274, 0.006965275196957269, 0.0295077237699713, 0.042362332211009095, 0.029932371340692043, 0.01190230913925916, 0.05439794888453824, 0.036665362372462235, 0.03181206940540245, 0.039721582484032424, 0.024968317709863186, 0.04185811623132654, 0.03365106215434415, 0.060345430459294996, 0.02291803594146456, 0.057954585179686546, 0.03681461972051433, 0.022454543937263743, 0.0426389471893864, 0.02244441001676023, 0.04563212800504906, 0.04768632831318038, 0.08996895301554884, 0.018572012361671244, 0.08663735285933528, 0.021108216805649654, 0.030218166897871664, 0.033929736486503055, 0.009684743891869272, 0.05213005415030888, 0.04442967574245163, 0.04919072865907635, 0.030292330775409937, 0.014723989380789655, 0.035921528536294184, 0.06193300562777689, 0.03721788326012237, 0.017497307887034755, 0.06665763817727566, 0.04580235547785248, 0.026917117780872753, 0.04161057308582323, 0.05879866238683462, 0.023507180756756237, 0.12612583142306122, 0.014733432891911693, 0.028640467806586196, 0.011186472506129315, 0.04368399629103286, 0.008633454812557569, 0.03710461201678429, 0.030167141064469303, 0.03448687819764018, 0.04940062328906996, 0.0068998593321469215, 0.032241266553423235, 0.015542268686528717, 0.03672782152092882, 0.0692221409242068, 0.03774024326620357, 0.019213728373870254, 0.04166541907138058, 0.02229214845491307, 0.019060932465695908, 0.03123348598767604, 0.011797215091064572, 0.008147259026632776, 0.030641779702688967, 0.05971303582191467, 0.05157915156866823, 0.03405893973207899, 0.06392382058714118, 0.04282909305766225, 0.01415715818958623, 0.04431576667619603, 0.07522334211638995, 0.11217720740075622, 0.029877287867878164, 0.037469565469239435, 0.02503928229478853, 0.08367993762450558, 0.01584026260700609, 0.05882180043097053, 0.07932900823652744, 0.017791912525093982, 0.01513942244595715, 0.016939426572727304, 0.010365236484046494, 0.0424632337609572, 0.025673476746305823, 0.03240187239966222, 0.058431418878691535, 0.010947246503617083, 0.062019987031817436, 0.025527406816503832, 0.014758928845237409, 0.028008865358840142, 0.040958385581948926, 0.08650153050465242, 0.05984001686530454, 0.010167614008033914, 0.016314609475167732, 0.024200020989935313, 0.011467502202971705, 0.030178740620613098, 0.022954588622919152, 0.01924529721561287, 0.030291075485625436, 0.012472046156679946, 0.033247662907732387, 0.04515634264264788, 0.02060723743800606, 0.029245313922209398, 0.017964725216318454, 0.06706701871007681, 0.02174513048625418, 0.05608104482027037, 0.010965906216629913, 0.0615357980132103, 0.02007002430036664, 0.023211164765858223, 0.019405947166628072, 0.02609375455150647, 0.05344716186768242, 0.00974915043583938, 0.04096545930951834, 0.03332642725269709, 0.05815710752670254, 0.05068269485075559, 0.013809995077151273, 0.030651516680206572, 0.03284690316234316, 0.02589081320911646, 0.06422208422528845, 0.03436530168567385, 0.053038548079452345, 0.055839730626238246, 0.03515514698145645, 0.07356954871543817, 0.04467265573995454, 0.033458212324018986, 0.03818098568756666, 0.026603914497952377, 0.047980948218277523, 0.03735275227310402, 0.04496424598619342, 0.028025591247049824, 0.030826985836029053, 0.0014324067202064075, 0.030767776870301793, 0.04296040315447109, 0.06602484998958451, 0.08296168116586548, 0.010457738618632513, 0.02671377779915929, 0.05037719802930951, 0.038780763146600554, 0.007442539341614715, 0.03111525804602674, 0.05471059407240578, 0.02817852795124054, 0.03456209719713245, 0.021905169755752598, 0.08693438156374864, 0.015440367993765643, 0.04936562445280807, 0.0339784078033907, 0.08790693259132759, 0.049451347174389024, 0.009264476264693906, 0.03264331551534789, 0.03506025046642337, 0.0490491794688361, 0.050200286986572404, 0.023439349307279502, 0.04500797078279512, 0.06553158895777804, 0.026014118289042796, 0.025740722959328975, 0.019809397303366234, 0.017836283626300947, 0.040421494748443365, 0.023335733617256795, 0.07318971159734897, 0.004124524304643273, 0.019419059855863452, 0.03817088908648916, 0.01826478018691497, 0.02706599175663931, 0.01573912356980145, 0.008499562041833997, 0.04761009829651032, 0.08189591978277479, 0.06340328244758503, 0.02617728221230209, 0.018629272235557437, 0.020975334203935096, 0.0609779404476285, 0.023097861292106763, 0.025913863043699945, 0.02236977286104645, 0.0292033431386309, 0.0166701652176146, 0.01487811012858791, 0.034229146848831854, 0.06167071113096816, 0.054001813355301104, 0.044753252129469595, 0.03958110537912164, 0.04945977457932063, 0.012035128976484495, 0.021070936395387565, 0.047249202483466694, 0.017845742404460907, 0.08107596449553967, 0.03981867405985083, 0.029396834184548686, 0.04669004552332418, 0.0328862412300493, 0.02238049541067864, 0.04787097465513008, 0.021063589557473148, 0.009818045488957847, 0.012320821905242545, 0.023193879086258154, 0.04271410512072699, 0.04189831264583128, 0.0285352914860206, 0.02759422448330692, 0.012385253046107079, 0.040067923720926046, 0.02033103466965258, 0.04777702469644802, 0.03677820274606347, 0.07529743135507617, 0.04359380541635411, 0.03937526838853955, 0.0280837891955993, 0.08103374604667936, 0.021490177738347223, 0.02531032480432519, 0.052652722889823575, 0.04419518421803202, 0.039204861103956185, 0.033289355491953235, 0.015182158277769173, 0.009634802018159201, 0.009907199053226836, 0.026926008285954595, 0.03170909153829728, 0.057021993079355786, 0.055866943273161135, 0.009932707729084151, 0.03108534143705453, 0.051464167024408064, 0.01926048282933022, 0.0630776331360851, 0.00631245962410633, 0.03681720154626029, 0.0672569881592478, 0.039493428476686986, 0.025899763086012433, 0.015457450112860118, 0.016157900116273334, 0.07691389854465212, 0.056295312608459165, 0.005958774941973388, 0.03991446624110852, 0.03061551700479218, 0.05685553147590586, 0.010518267334971045, 0.04389149569241064, 0.014160887587682476, 0.010587009717710316, 0.04720437167478459, 0.038902102171310356, 0.013318644969591072, 0.06416463945060968, 0.02560467499175242, 0.06622820693467345, 0.032336129141705375, 0.025442756180252348, 0.10129225041185107, 0.016904785663687756, 0.020078877486022453, 0.022019087303695933, 0.06265656823026282, 0.04770558174433453, 0.02751122777616339, 0.024678876723295877, 0.031589961145073175, 0.041431575547903776, 0.04996499479083078, 0.06627311916755778, 0.043981754420591254, 0.025396877034966434, 0.09372716170868703, 0.10237208461122853, 0.09493440442851611, 0.09193204303405114, 0.1635133009403944, 0.18203130869993142, 0.17639052495360374, 0.16287508447255405, 0.09744000355047838, 0.07676608647618975, 0.18976416518645628, 0.08361975156835147, 0.16581071194793495, 0.0802941293056522, 0.057482813351920674, 0.1628778257540294, 0.12760704622736999, 0.1229285608444895, 0.213249714246818, 0.18462278321385384, 0.13167600360299858, 0.07574244176170655, 0.11641849231507097, 0.11137388979217835, 0.1715211540992771, 0.15099024506551878, 0.0921320751575487, 0.15049700438976288, 0.11860204514648233, 0.17483065436993325, 0.06079663589064564, 0.17678608372807503, 0.21090097885046685, 0.06045835904244866, 0.10060877565826688, 0.11793356601681028, 0.12205890965248857, 0.12207516735153538, 0.15177267736622266, 0.1449019539036921, 0.143302036183221, 0.09137347979204995, 0.10680891653256756, 0.26583381689020563, 0.07997928905699934, 0.11874691237296377, 0.13628396205604076, 0.25960011567388264, 0.18663588804858072, 0.13985727674194745, 0.2176334983003991, 0.11208732186683587, 0.10812578337000948, 0.1290758302701371, 0.1580048179520028, 0.06337247017238822, 0.18022005446255207, 0.15545653897736753, 0.1495078360395772, 0.11647874622472695, 0.2512920786227499, 0.11619887767093522, 0.18384728554104054, 0.18192334020776407, 0.0852314079446452, 0.114603031160576, 0.0827054866988744, 0.18916896783879825, 0.15523886494338512, 0.13297508603760175, 0.0720285481906363, 0.13361119904688426, 0.12223295388477189, 0.2733623529119151, 0.12141926826110908, 0.09097216704062053, 0.10092246239738804, 0.15246593659477575, 0.17650569948766912, 0.11550024444503443, 0.13079648651182652, 0.09460178656237465, 0.14539869582014425, 0.07961874268949032, 0.07004162802227906, 0.1395287165152175, 0.1856485110308443, 0.14290961224053586, 0.15946144264723572, 0.19627636431583337, 0.09302117994853429, 0.11248636152595282, 0.13177456759980746, 0.12860097789338656, 0.15048968978226185, 0.1820526418409177, 0.16323274028088364, 0.1507071873971394, 0.1341659692781312, 0.07878822939736502, 0.28953319947634426, 0.08013585422720228, 0.08663231812949691, 0.07171903444187981, 0.12114731142563478, 0.06684610806405544, 0.13386210772608007, 0.16387599147856236, 0.1236398419631379, 0.11943099780806474, 0.16728425930653298, 0.09796327618615967, 0.1464590967765876, 0.16868436203471251, 0.13554727658629417, 0.13927064250622476, 0.11777628159948758, 0.08843956222491604, 0.14268190945897782, 0.07312923377113682, 0.13924134336411953, 0.10170298801468951, 0.14027741205479416, 0.12980319266872747, 0.09543367049523763, 0.0930880427892719, 0.07039593186761652, 0.1635140608996153, 0.12458512266831738, 0.09290741676730768, 0.09286223312041589, 0.1412301023623773, 0.12642678884523256, 0.11630600477967944, 0.11236209462263755, 0.13219939837498323, 0.19809139120791638, 0.10345062959407057, 0.16774931363761425, 0.19961451233497687, 0.0905700061204178, 0.08112498865063701, 0.06385635385023695, 0.11698859743773937, 0.1487014785941158, 0.14359178420688423, 0.13380584360233375, 0.12628345510789327, 0.13261962868273258, 0.22280544149024145, 0.0660189331642219, 0.11712657074843134, 0.15285490000886576, 0.07413600331970624, 0.20386235868292196, 0.1366953442671469, 0.0481552638645683, 0.08621373666184289, 0.09519680070557765, 0.1542286348662206, 0.1165281707154853, 0.1288189911948783, 0.18218311055430345, 0.10105289718402283, 0.0829088097172124, 0.09671828656324319, 0.06994881800242833, 0.11565903521009854, 0.12134715355932713, 0.12347398086317948, 0.14298795589378901, 0.1178741127784763, 0.14469578782362597, 0.20154820143112115, 0.15639883412846498, 0.10213727078267507], [0.0031965273706841147, 0.05384202853643468, 0.01905432014193918, 0.03222118191687124, 0.03232275182381272, 0.017912176071799228, 0.04328510930229511, 0.027371232431115847, 0.004910686851612159, 0.038771243300288916, 0.043550450421337566, 0.060104835512382646, 0.026503932362954532, 0.010256430001131125, 0.011875935331253069, 0.03249837025733931, 0.038010551261582544, 0.05222390911408833, 0.01810848473438195, 0.013816074750918363, 0.05847410551671471, 0.0709852259606123, 0.01675892268706645, 0.050073390760059865, 0.017554679719199027, 0.06212258152663708, 0.014696870032431824, 0.03703499771654606, 0.05079628161287733, 0.022236686698826294, 0.02264510201556342, 0.02974638149940542, 0.00994268897920847, 0.07256251453821148, 0.038016352735991986, 0.05674394639208913, 0.021328111345480596, 0.09827053719865424, 0.059218146306063445, 0.023021739841039692, 0.024207579870043055, 0.047743250615894794, 0.02448202353636069, 0.01962978738759245, 0.05171372541891677, 0.0339789133119796, 0.024925570003688335, 0.025927547398688536, 0.05264672124758363, 0.00674830938390057, 0.030781140617494072, 0.029582922413413013, 0.04720936569252184, 0.026203494020072476, 0.05309501237102917, 0.08378125647349016, 0.02512310172564217, 0.04457020713016391, 0.045658533195299764, 0.03722979833504983, 0.04351520731246897, 0.020063722406380942, 0.04650894452684692, 0.04510573410828199, 0.06761244551411696, 0.027662401985643164, 0.04417093337646552, 0.048037198771323474, 0.08908338339201041, 0.024947775062173605, 0.09516165259161166, 0.05924822576344013, 0.024579031991639307, 0.05886003587927137, 0.06873487814196519, 0.01604730060457119, 0.035557816802923164, 0.030780360302222625, 0.024703046140660132, 0.023400128286864077, 0.07179156305002314, 0.022554437862709165, 0.007765202250863824, 0.015186451708099671, 0.030245722204978977, 0.046358516705887656, 0.02725459565408528, 0.03148741075502975, 0.03606953737991197, 0.026442362095362375, 0.04229765425303152, 0.019243763726470724, 0.0895121293142438, 0.04205651647810425, 0.014255740846108114, 0.03502384366999779, 0.028641468645738702, 0.04398996808699199, 0.03998223153342094, 0.042922306805849075, 0.041687827690371444, 0.02763126740631248, 0.01134684425778687, 0.019742797394948344, 0.07504609519881861, 0.05972518159874848, 0.058557022495993545, 0.04822130907060845, 0.042001551748918634, 0.02879040368965694, 0.031361671430724006, 0.012790403761235731, 0.04809961381501385, 0.04717738294441785, 0.02338319714181125, 0.037099193914660385, 0.02577003906480968, 0.018851726548746228, 0.01283103019730853, 0.06953725258686713, 0.019017680947269713, 0.02572968658725066, 0.06091746940676655, 0.05769684365285294, 0.05026624059038503, 0.018137885656739985, 0.04408040662695255, 0.012716617318801582, 0.034121748326080184, 0.020741414345268692, 0.010761094662094755, 0.01426896040460893, 0.0444823063111731, 0.036503789613821676, 0.03956469500969563, 0.022602186371971453, 0.08537886717489787, 0.04843437924448933, 0.08825238155467169, 0.0482407117794667, 0.02179635309481195, 0.034058800632400174, 0.01421961055270263, 0.02410793530621699, 0.04053836901273046, 0.02701952907123736, 0.008909166491191303, 0.02750347212090024, 0.040209500052567036, 0.046918844138937335, 0.024407756182232072, 0.08278861402400903, 0.060845130788428445, 0.04333122593483754, 0.016440659229244505, 0.06788725898201976, 0.03050326695665717, 0.00851948807082538, 0.029731854064656154, 0.022442676359787583, 0.030022809880652597, 0.040469568954514604, 0.057210320473781655, 0.08741230770413365, 0.007471996243111789, 0.02338371452476297, 0.030020753919546093, 0.03556203389806407, 0.024873960630169938, 0.025038630901170627, 0.020556177677852765, 0.03276268678850361, 0.025128100832392062, 0.050037774456931014, 0.05850418497409139, 0.04833891615271568, 0.02904829110151955, 0.041538407493914874, 0.022371603209259253, 0.07735829826976572, 0.0038060449878685176, 0.07262225276125328, 0.025079227651336362, 0.07518189041210072, 0.04015629951442991, 0.049674323959542174, 0.036934024920420985, 0.06862488083009209, 0.04221735981159976, 0.032722476803298504, 0.05635623148243342, 0.04153209711824145, 0.04964178481272288, 0.028395024726965597, 0.047755800121064694, 0.011858081378574883, 0.049632566914494546, 0.04911529252837811, 0.04621019234348621, 0.008062524421672736, 0.02854203273143087, 0.04048090727467622, 0.025109383443902646, 0.05192272099001067, 0.03866389227498855, 0.027087350342688814, 0.03333620494231582, 0.11499245597847871, 0.028202671923541596, 0.04070269662354674, 0.02394677815027535, 0.07267992145248822, 0.024285847188106606, 0.04505779900188957, 0.03601693055991616, 0.0123361313516008, 0.005262524646241218, 0.044125861687851806, 0.02621748371581946, 0.06071785118963037, 0.07893135278884854, 0.07924497845981802, 0.04930572338136179, 0.05464763620070048, 0.046195814186441045, 0.035225382141236744, 0.053305110561528375, 0.025278628737266575, 0.027506596774661114, 0.05151665170810052, 0.04918723420373031, 0.016090667473950555, 0.014737339557281562, 0.05775393558932202, 0.031467180233448744, 0.030072648277772323, 0.05152168643793889, 0.0423865287697741, 0.03475119812147958, 0.06112400868109294, 0.014528193012146013, 0.029350782012833015, 0.01336229088649686, 0.026786923874169588, 0.05168462983731713, 0.03821947219382439, 0.04451169705550585, 0.04467966839937227, 0.018238237593322992, 0.05587552674114704, 0.03175648381667478, 0.034701539536139796, 0.05697120473320995, 0.05805424161787544, 0.05446059802281005, 0.05567485000938177, 0.002321957647966753, 0.0205222237855196, 0.02820873972294586, 0.0250419082253107, 0.08677797245659999, 0.018647083779796958, 0.016819907718205025, 0.07768247516027518, 0.055504378263971636, 0.018964443089706556, 0.06560244158442531, 0.038779100735804865, 0.020004711912146637, 0.019624301431966678, 0.06515070689576012, 0.014615456008219292, 0.038098906699035845, 0.09512244005288396, 0.06286719228540148, 0.036832516081631184, 0.11116901971399784, 0.13179007891033376, 0.06769518607429095, 0.03795566117124898, 0.05947274621576071, 0.05630000467811312, 0.02539478036175881, 0.04234986752271652, 0.01872101695542889, 0.03788069322971361, 0.03362771376435246, 0.021698784848142947, 0.05106693905379091, 0.0808073596230575, 0.025424764824232886, 0.03840919737038868, 0.04634036589413881, 0.023172534070909023, 0.013228097864027535, 0.055703514721244574, 0.015926326292433908, 0.047856359010828395, 0.03467954482351031, 0.03440579665558679, 0.031031275766768625, 0.02947299974039197, 0.016785780799442103, 0.030388818455061743, 0.011384200155069786, 0.02506527697135295, 0.020251866596351777, 0.015001259145459958, 0.033736876478152614, 0.02514502010308206, 0.04213244454669101, 0.015613779492144073, 0.09329553879797459, 0.029687630544815744, 0.02905786523063268, 0.07584251889160701, 0.03481708387179034, 0.012696279079786368, 0.003565089145143117, 0.010252648016570933, 0.006296461040619761, 0.028555148813341345, 0.08675274452460663, 0.041130099046443186, 0.029872504195996692, 0.05505933053791523, 0.021771825750225356, 0.04913439328915306, 0.02423625815260623, 0.0760243119938033, 0.031361461084868224, 0.0278279289071049, 0.01799078774638474, 0.034322163821863275, 0.0595166270754167, 0.056987197803599496, 0.018060822738334537, 0.0934081416843193, 0.08936514505850417, 0.027320846116968563, 0.021003698664052144, 0.02867893056411828, 0.10224240978381463, 0.038285310446683846, 0.04643114709428378, 0.017977517297757522, 0.019245454975004708, 0.10873160657605954, 0.06502499471285514, 0.016317018274483935, 0.008676648655507182, 0.005295639275573194, 0.11454169159489018, 0.1323051412722894, 0.1902114147586482, 0.18819186384124414, 0.21394373343459197, 0.12159047621701445, 0.1688800651047911, 0.2146476592336382, 0.08200553711503744, 0.07601855801684515, 0.11246614118239709, 0.28550525275724276, 0.08875931506710392, 0.09475866385868617, 0.1106016897995557, 0.1268286444246769, 0.11556649660425526, 0.2004138265869447, 0.10448330560965197, 0.07156791112252645, 0.1365887192743165, 0.18142553977668285, 0.17742601010416234, 0.12508396804332733, 0.08157590231192963, 0.11516149262232439, 0.05608353504378881, 0.24731901181595667, 0.17352196387946606, 0.07394515177501099, 0.09327886040721621, 0.32259153415049824, 0.11792884341308049, 0.18131945761186735, 0.14784573736999715, 0.1249993411558015, 0.09662067251546042, 0.14543689734169415, 0.1261708861482995, 0.13865652760224684, 0.14444363063999585, 0.10649003221520356, 0.12475517711469106, 0.1619117683065789, 0.13826242089271545, 0.1116536497803671, 0.14197487596954617, 0.11612060187118393, 0.2465689049235412, 0.13409470953047276, 0.11298055893608502, 0.09780869912356138, 0.13502332541559423, 0.08750573519085135, 0.15354910918644496, 0.14273053327841417, 0.12150747781353337, 0.14746202581695148, 0.12259529158473015, 0.0912932294553944, 0.19675455508487566, 0.07615090627223253, 0.10280963113265378, 0.1315589698829821, 0.20163782233638422, 0.08869168548179523, 0.10859326007110731, 0.09817421236740691, 0.1521348793591772, 0.17843007908335753, 0.20331590729100363, 0.11536539239542824, 0.11909315522227969, 0.15827412850090436, 0.1657101394874709, 0.11391287962240831, 0.1816191936710051, 0.14714168943464756, 0.1489931129451309, 0.19367563458425657, 0.1184611948473113, 0.09099417193127529, 0.10209150359566722, 0.11438343008714062, 0.17300166322716645, 0.20900274999439716, 0.11349929895784173, 0.14136267453432083, 0.15252372063696384, 0.10624755772628955, 0.1241900660097599, 0.08780807003911052, 0.23584303046975816, 0.14108931991670812, 0.13938881616507257, 0.08597274137926952, 0.14956328592130116, 0.32208879398448126, 0.05983180659157889, 0.11439462591494833, 0.16696929692157678, 0.22875521651336125, 0.09056770588670458, 0.14195404494447367, 0.10851860764835562, 0.14176503222967896, 0.09044319471078259, 0.1352092440107039, 0.10897072910198144, 0.18372354789503983, 0.11575819631772381, 0.10273278025644166, 0.1429572861109461, 0.16321846390409128, 0.09085222919072423, 0.1455714644065925, 0.20650192775896617, 0.10895001342786209, 0.10565345282001154, 0.21071092119174345, 0.12244169839790889, 0.17351102589496545, 0.12446042150259018, 0.23985702650887625, 0.11955188560698714, 0.0669383548998407, 0.18149897083640099, 0.10219742291207824, 0.11177299730479717, 0.12800633694444383, 0.09684490119772297, 0.1422747748770884, 0.10920458619615861, 0.14290864872080938, 0.18695363242711338, 0.15160403427268776, 0.16135906082178864, 0.11516218472804342, 0.17341286901916775, 0.1389004202293498, 0.09912343536104475, 0.0679728901013732, 0.10289492976984807, 0.08224132803401776, 0.12280077912977763, 0.1091772819470082, 0.16213630911495003, 0.09176010904567582, 0.2149194667914084, 0.1695009653589555, 0.07455319379057203, 0.16398815331714495, 0.12829414435795375, 0.13429240749350616, 0.09117974447352545, 0.13968267611094884, 0.0714445331000856, 0.07271563953586987, 0.08716815044837338, 0.19979682112378733, 0.05854292932365622, 0.1455791047109025, 0.1374328982617174, 0.19780591795487062, 0.11944209864096982, 0.1444298970912184, 0.15006773599556514, 0.14016366244426795, 0.09685815977198736, 0.07273456387753997, 0.06235453872276204, 0.11153356943811689, 0.1823173112102917, 0.16092736327222415, 0.16740184942526476, 0.1375818909811122], [0.004561799836145448, 0.02965346969930189, 0.011464645570543195, 0.04673550058422344, 0.04899733939341136, 0.023994513088837266, 0.118553312761443, 0.05590586064915572, 0.024927405440913777, 0.02378721724796508, 0.030296412163547108, 0.05342294495286686, 0.0399135196847575, 0.015177299967035651, 0.022187472553923726, 0.048971904508237324, 0.05776424253625529, 0.018429192614608576, 0.0726079356723598, 0.023102407476731708, 0.055759938300720284, 0.07560334208288363, 0.01479744418923344, 0.015029513343636478, 0.04016506279419575, 0.030244829931429455, 0.07063470155532871, 0.0762040898469942, 0.013023819807650787, 0.030432346476508037, 0.05122160432594163, 0.028958079870790243, 0.11362355907580682, 0.01406680277016546, 0.026553546843518103, 0.06872004536645752, 0.06810074645493712, 0.01696700562856027, 0.012961906031705439, 0.00945501568328057, 0.06508292124739715, 0.029051850017692362, 0.0762103662959167, 0.013669796171598136, 0.028773799937750612, 0.04912575214569058, 0.008920816089292722, 0.024807940869192992, 0.045536844725055356, 0.0026985079000171807, 0.011947881247449135, 0.026113467690135752, 0.03600969398394227, 0.003079756795029555, 0.033195856759058576, 0.0055787079701466215, 0.031618971909795485, 0.036309677708361826, 0.024057720322161913, 0.04299886930467827, 0.024615045237754072, 0.0617851053497621, 0.03512577320049916, 0.012130639565709447, 0.019514947032023753, 0.03748011329610433, 0.03541966707312635, 0.029244360580508198, 0.029255240889532224, 0.08796648082456418, 0.09879290059741054, 0.03512827020936778, 0.07402576852057662, 0.054385993097509654, 0.02216768477644239, 0.03722381704886045, 0.037760880908795764, 0.055652872260127745, 0.01726650759311659, 0.08523701264389924, 0.08011878907148327, 0.021889999409073164, 0.03473912359082273, 0.02907010939504419, 0.03473206343395369, 0.02330622073662068, 0.029826452024281025, 0.022585026221349835, 0.05127029260620475, 0.05614147514903119, 0.03502446792221495, 0.015236376618434275, 0.017594938898192983, 0.030405395065567324, 0.007565284630150667, 0.05373523051717451, 0.058924293145537376, 0.015316503122448921, 0.0325248806205179, 0.04714991584686296, 0.022252484690397978, 0.033777028787881136, 0.01925159741326102, 0.03323060793003865, 0.0073330093707357135, 0.0651780857837626, 0.026217497286519835, 0.03717301513201424, 0.06667895096221141, 0.022734103757621985, 0.004386345947360886, 0.048734135659677644, 0.019938797324097583, 0.03593220867748771, 0.04431529848703316, 0.038449505743171485, 0.048132665255772214, 0.03366016470161932, 0.030042813093002354, 0.06261025821524006, 0.01843662596573787, 0.011204373956258808, 0.034732945529477935, 0.03944071648376329, 0.06556869125259773, 0.013736807441871082, 0.03879603696987033, 0.05826528636472566, 0.04594004041116152, 0.01729298911855689, 0.046078519230442386, 0.030854625960013697, 0.07108616482998643, 0.008234561886638403, 0.043728674429335763, 0.0413739272127194, 0.050777862779796124, 0.01266546595642077, 0.022189983133492724, 0.03144936868920922, 0.02705985101472054, 0.017007727907704454, 0.06302224432251283, 0.09166062902659178, 0.06411175443125622, 0.02442488070976521, 0.05940877393420253, 0.017429937841370702, 0.040119085261332135, 0.04444434227687972, 0.025306832045316696, 0.06426596508494445, 0.01048942790034094, 0.025029655579211454, 0.033277647370206456, 0.036621722392737865, 0.02606980735436082, 0.027056834926562648, 0.027761099993118217, 0.021125219196879437, 0.02708160993643105, 0.029347820207476616, 0.01388365259793188, 0.015487836607332741, 0.042798328279916725, 0.015508375862347228, 0.06836357020906039, 0.03633048837738378, 0.04368571637730513, 0.08771697671285697, 0.018115924870861427, 0.06801804660686425, 0.03909597319683858, 0.037208370199160914, 0.01533032996979143, 0.025264918937214782, 0.03302462166175246, 0.0914677350914904, 0.05857309020523514, 0.006808794843631664, 0.031372069979884794, 0.029822903286133493, 0.055550579713391404, 0.0593580873683095, 0.015971068891563585, 0.027205215268103138, 0.072918494365045, 0.07821785964603935, 0.012383557556729232, 0.036708486665572436, 0.020180252314146076, 0.020999763160943985, 0.05765541230461427, 0.0382215790450573, 0.027546253753826022, 0.01983621809631586, 0.03294529752539737, 0.06519827220056738, 0.02803915516207261, 0.017869389349860803, 0.032458889697279246, 0.004621201760268637, 0.054929601427699835, 0.0568346258119813, 0.07831901564661946, 0.032108216014291556, 0.032344926348222156, 0.04044709926737206, 0.05830337932067258, 0.022153696777032952, 0.038880942056753805, 0.032319216656365564, 0.032867086186472855, 0.03684945231569665, 0.06378390666629587, 0.0023427074608792153, 0.027111509582027793, 0.020684933090316396, 0.06504120491445065, 0.0657446760950344, 0.010829360373983426, 0.005393199040554464, 0.04085390815245254, 0.02229860980462815, 0.043929320627025197, 0.011772289955323296, 0.06114896519907883, 0.00997723065250154, 0.018606159636484723, 0.08169174859566347, 0.02783898733157132, 0.011741431879012712, 0.005275976178901536, 0.03645972554971065, 0.02780995112178581, 0.022933375921898654, 0.07219257724604436, 0.11412608889596802, 0.07680915309382336, 0.013584949608360018, 0.04627825619120683, 0.011158551638280707, 0.047214142579053126, 0.00966153375338763, 0.008739932224021425, 0.012345348401660365, 0.09976104114736829, 0.06180605851113796, 0.023914008301549723, 0.06832191494426557, 0.002919575881345996, 0.023962277586438825, 0.036244070157408714, 0.013633068767376244, 0.04577925814581769, 0.035053444760186334, 0.01866881047109408, 0.014494169569973434, 0.04871538434443729, 0.011502740222827663, 0.06624495317893368, 0.1149472248341356, 0.01413124832989914, 0.040391466181193075, 0.07052242436579295, 0.017697392596996257, 0.030036265230072395, 0.021071704836296182, 0.029144860205373595, 0.02630438199932022, 0.03798804086233888, 0.015830758027732372, 0.07137030136904546, 0.023081890274105326, 0.04805322916113904, 0.09245099340166364, 0.05166968510353139, 0.08108163704829556, 0.02207386034673878, 0.04612794711387583, 0.08111770118453673, 0.03585689468309283, 0.00687807666171076, 0.015057699688311135, 0.019061210665053556, 0.05340406471597297, 0.025169040242742215, 0.03404801531827875, 0.0051803790764617065, 0.031146877777895758, 0.05110020762575524, 0.04313777560102088, 0.01378098176792264, 0.010456753046517926, 0.03114687099254557, 0.03537958261689969, 0.02661488640920392, 0.026292762087125863, 0.043981489791933975, 0.02938320580869913, 0.035640587897173, 0.0432176357800407, 0.017841184345473136, 0.03458759654313326, 0.04919083722467933, 0.049823530417467864, 0.041182305530778, 0.013905679540974753, 0.06258378856416259, 0.04135829715856484, 0.07084603807223694, 0.00803126600970115, 0.02871209057047963, 0.02932149644142815, 0.0260627115744033, 0.06555170752108097, 0.014970372231411082, 0.013801924751273223, 0.01945149722242994, 0.01123948983981141, 0.01234304138259696, 0.016277178090863993, 0.019162473534899097, 0.028619419650307724, 0.010774709467243935, 0.019939433450677564, 0.014674076344817877, 0.005105442093086562, 0.03623371571302414, 0.06924975051411561, 0.06854488155139343, 0.019206473138183355, 0.017315151768603494, 0.013167146759639894, 0.022203312953934073, 0.05156768771952816, 0.030529404125575508, 0.0131316619226709, 0.04819896491244435, 0.03885053011721798, 0.06536541573171105, 0.020281693299434016, 0.09112276110265936, 0.02876116900837847, 0.02928264352626034, 0.07401425378131014, 0.03488677620355572, 0.06816728359886579, 0.07515587537948575, 0.04807567170688084, 0.019353347131982446, 0.01672806291441832, 0.14243288710713387, 0.15940866619348526, 0.1729404322270836, 0.12149246861892087, 0.1266538809452738, 0.13135023894054548, 0.13989927805960178, 0.20087516254612378, 0.10494430908667189, 0.13838862840618404, 0.12364204041659832, 0.16772944613226823, 0.16366734196032795, 0.05726159057979073, 0.12431951692061764, 0.15157298451023443, 0.1404958731893982, 0.09199138092143194, 0.08168985548296145, 0.07783521339297295, 0.09633006953767367, 0.15789775869676045, 0.12450738969658103, 0.11689029128423759, 0.17500134663922445, 0.10410843536789928, 0.14012485024120125, 0.17100187124950544, 0.12802152255816118, 0.09002081344702415, 0.15910785804901803, 0.14359253059540475, 0.1841277512056487, 0.12299781212849276, 0.09929913521877357, 0.11023712650473629, 0.12989723762231214, 0.08911781225885664, 0.09166125327880893, 0.06125774793326855, 0.1225697108145271, 0.09756391761558396, 0.15600152473364556, 0.09828723594546318, 0.07895211596041918, 0.1109545212239027, 0.07841846852430276, 0.12304537743330002, 0.15427966069962296, 0.11681770160794258, 0.1352189334907702, 0.10401733525629554, 0.1711631454527378, 0.08038763821657215, 0.08734554664364882, 0.10189046724034206, 0.10435650098536696, 0.0872276851109096, 0.10634137197796788, 0.2593793746616159, 0.20893244019576482, 0.182744706847838, 0.14281570299395493, 0.11627239015485559, 0.090047188103199, 0.09135671997708933, 0.0888899601995945, 0.0928255854440587, 0.1086038655734488, 0.18009977734514646, 0.16814477741718292, 0.15857800362365587, 0.12233097505356584, 0.20308956157948288, 0.11735412425228528, 0.0733847836298602, 0.1119245955986636, 0.12635267925049576, 0.15457404990281376, 0.18422802511070455, 0.16770833012248787, 0.14149900579026767, 0.18530271601464066, 0.1497319018734353, 0.14088764573846543, 0.1811924629977771, 0.1529784340943609, 0.14497320008065018, 0.16117888263293675, 0.12192261910864285, 0.09659560064652137, 0.16308654312576565, 0.09444395931703703, 0.08495782262512616, 0.12782056762703828, 0.12778589448758534, 0.13411962533635752, 0.10000123575861965, 0.16526823677122593, 0.25128485901015146, 0.12564157455095223, 0.2898077076034886, 0.07365701187934194, 0.1498257161251136, 0.1133799310773611, 0.1687940132937261, 0.11774726744209017, 0.1333487145602703, 0.12431384436786175, 0.15401172079145908, 0.10028738076133387, 0.19597529832805904, 0.2383617524589811, 0.1059096065749015, 0.13660451556955064, 0.09858195763081312, 0.18113081130598271, 0.16424610518983432, 0.10783175379037857, 0.11501796889517989, 0.11336386336811952, 0.10900661003376756, 0.17176701447793416, 0.13581809348293714, 0.10952918377837964, 0.12396830719496522, 0.08648546279541083, 0.1130558695378048, 0.1928059562508549, 0.11783528700470924, 0.1072018425911665, 0.08043561742774077, 0.10574337228068284, 0.08373666993741478, 0.1703311800956726, 0.13981148919888906, 0.08687304199806281, 0.12248042917677335, 0.20919246838561126, 0.11034230621797697, 0.10640885228557245, 0.08239310274698905, 0.230810851923057, 0.12240830090429101, 0.12918516940304212, 0.0934675745666027, 0.19241163241011755, 0.12979023264987127, 0.11820873910827295, 0.11840174160897732, 0.12209379992314748, 0.21696888682033333, 0.10609045651342187, 0.11610289210719721, 0.1487437377550772, 0.135848179725664, 0.07322793347494942, 0.09664379020354577, 0.1828504226037434, 0.1281083614698478, 0.10484300380838768, 0.104837921581098, 0.1354206890932151, 0.15302024542221002, 0.12315935774573258, 0.1666109897196293, 0.18109471324299062, 0.1161115909261363, 0.11794050064470087, 0.2056174302207572, 0.08403742379908051, 0.22389545371489866, 0.23935827612876892, 0.08794852000262056, 0.08257207992885794, 0.08845661380993468], [0.008140140346118381, 0.009859646470951182, 0.07609848265669175, 0.03185466444119811, 0.013622498888123249, 0.027191184860255038, 0.05706590786576271, 0.03648439369031361, 0.040528503113559315, 0.025635782429682355, 0.03912002047789948, 0.016907060452337776, 0.020828153173040067, 0.05892816079514367, 0.028362365140180503, 0.029553548632455722, 0.036200986576399634, 0.029097613812025105, 0.0485561355682356, 0.005072511516378394, 0.032135323488286564, 0.002579269153232287, 0.01779116952924856, 0.059932779387703965, 0.003154701199881466, 0.024048948560708334, 0.01923374006790774, 0.06979554372706584, 0.029506777213620286, 0.09689191010381494, 0.018269453596855913, 0.04236743479434933, 0.003081447831521343, 0.0644376412300127, 0.01885203019316707, 0.019549798286919082, 0.029152666750763143, 0.009123762520695371, 0.01333881272668285, 0.06804940849542618, 0.05101271392777562, 0.02376798926187413, 0.036747885801430256, 0.025239579046943357, 0.03846615020717893, 0.037822580098041465, 0.007555543411789196, 0.07897761530641999, 0.023075310180761983, 0.08934729280216352, 0.0449254473538271, 0.003189256019790524, 0.048404323535838296, 0.010490386331054782, 0.027393563018579568, 0.04226938309147954, 0.017409334125529443, 0.05308715493551322, 0.018344180658459663, 0.013440726141977524, 0.018610078176217418, 0.09239715164793388, 0.03894597624561616, 0.0597197465332491, 0.05887313160513129, 0.06750090114240136, 0.069544743613473, 0.07477664215756313, 0.012356511150885905, 0.03269528111975108, 0.044986837809639316, 0.04770184301638177, 0.021156236728919402, 0.03489848771797759, 0.05511010531336069, 0.040909687123660526, 0.014832492219284177, 0.04891765902617148, 0.03580255759879947, 0.036982906583164415, 0.02358650489311133, 0.06561530660837889, 0.03532072988205722, 0.04841806726264102, 0.037368643563240767, 0.025886161851563623, 0.060629472003451416, 0.019939552194305828, 0.05316242482513189, 0.060109673467065604, 0.018627971144659177, 0.03417902685967939, 0.028739937647644962, 0.017365358270970837, 0.02266401787554579, 0.05944547589336123, 0.03707673101286803, 0.070172687061131, 0.016957375520308102, 0.029675868140267472, 0.012533145690602916, 0.012933940210911845, 0.021865239666242684, 0.06754651905170508, 0.029298772303653613, 0.02486678003333509, 0.05211504834837147, 0.014434456791994827, 0.016522234405523965, 0.022253784084958688, 0.031155725874538933, 0.06823427536125694, 0.026973846701106856, 0.0991652263328433, 0.02636451377267284, 0.023483260701011335, 0.06707227057112114, 0.08749671067510333, 0.022900221004549946, 0.05929235089570284, 0.12423354653375489, 0.023051949916407466, 0.053706331710730276, 0.025531323659898977, 0.016901740737791573, 0.031727201637945006, 0.019321898730205636, 0.07875850277819804, 0.022874733532911966, 0.01867697833638106, 0.01106072639647339, 0.03816189171214189, 0.017986283970198462, 0.04763791823227491, 0.018498352296384316, 0.08422678256673471, 0.0736806248979909, 0.03096094900476081, 0.0953231303553496, 0.05932814361793654, 0.035838156938552856, 0.03139838696058307, 0.01661296810821763, 0.04429455227883799, 0.009097118995019367, 0.029106634935098033, 0.02211511697221015, 0.007288826562996421, 0.01289737141425056, 0.006997189243390624, 0.06444346306047269, 0.0576636836464916, 0.07772956549056939, 0.06691233986722571, 0.03501216608232685, 0.05005793033965996, 0.020229174688990628, 0.020378766215539405, 0.024454076375280107, 0.019611665413581898, 0.03317805878551943, 0.06355142699820654, 0.07747419883630105, 0.026316127440493022, 0.02152963794235672, 0.012190181013595845, 0.07280668536467211, 0.07429489586502314, 0.027962194023919956, 0.010017499161352004, 0.022074817081115077, 0.02128022543287703, 0.017480159610775963, 0.034116774664393494, 0.039226469051625044, 0.0460714353248477, 0.09208383810307298, 0.02885412491325821, 0.04244751549725022, 0.04704217805660196, 0.06325077491679362, 0.037059574254921505, 0.02671467516172145, 0.054930802434682846, 0.0058249822551650655, 0.03003210581040808, 0.0711399455155645, 0.023806016060656736, 0.05537811307502644, 0.02587263016695423, 0.02732476804937635, 0.03563329364572253, 0.04135877213307789, 0.07299249539417879, 0.019414042089400545, 0.018562814819493463, 0.08268689483936344, 0.021941060865564004, 0.033098934816994836, 0.07497643000845398, 0.042400509983833344, 0.0483940301596054, 0.026424233336001635, 0.02713938888960651, 0.025658737269363234, 0.10823055596223899, 0.0260596004913428, 0.018342100948627506, 0.013037178465830428, 0.01481709795604859, 0.07276419550180435, 0.01210419281518885, 0.02179162370573197, 0.015251446881198456, 0.0344647783120828, 0.026474229492513195, 0.019124903050916534, 0.012513101766152042, 0.06459107835377965, 0.007098589092493057, 0.02869098473872457, 0.02960219280794263, 0.039644175209105015, 0.029475717273141657, 0.025489317253232002, 0.04627074480855039, 0.033177895937114954, 0.022223085464377488, 0.03298438453514661, 0.05882009052272354, 0.08800888926322971, 0.011078275856561959, 0.014153114120875086, 0.04597120213189295, 0.033533363470009396, 0.028939661037709032, 0.0038695919127868755, 0.02809487476146647, 0.03952993705336537, 0.07018723485193082, 0.08764472630407129, 0.037701559984790425, 0.010739253468013235, 0.08230458106845617, 0.02745573378966323, 0.04186541048277702, 0.010319141055723386, 0.05843900490020003, 0.03151140036061406, 0.06710099974381072, 0.060178130865097046, 0.04566203782867108, 0.012347215221130421, 0.023652534832113555, 0.04600885743275285, 0.010974303935654461, 0.018697188501911502, 0.04014504601114562, 0.022672017803415656, 0.015988885524815748, 0.05373943404161504, 0.02522756388810064, 0.04209418534966452, 0.07021852888699089, 0.019069302195150937, 0.04938293727380889, 0.04218714464721935, 0.026872911224407808, 0.07666537152337176, 0.018151113696928536, 0.0270986038459731, 0.04465518007054925, 0.029261167892920117, 0.04789754269378526, 0.04856123136622565, 0.05460586219227739, 0.011535982501560023, 0.02523218810425273, 0.04269548611981528, 0.02712594880722463, 0.018682747580377117, 0.018394193778346692, 0.08435530388461691, 0.07991737952189785, 0.0069434649610359755, 0.03482444936941777, 0.009096548177434929, 0.050292085989245346, 0.043133758673710484, 0.08324161757315908, 0.006479609940600182, 0.10127105297786848, 0.0454098602889904, 0.02861874450796417, 0.029892710968852043, 0.058054628382836065, 0.033302732809845886, 0.024454975434179817, 0.06631781426923615, 0.03080844147396939, 0.026140907646289895, 0.0267078982932227, 0.039488658375505886, 0.023100290447473526, 0.038335807022771666, 0.020026343608541147, 0.06113707726555211, 0.05342108915959086, 0.04633235918091876, 0.064911903281297, 0.026446954081101075, 0.051440506508307796, 0.06325740420392581, 0.012887720101779061, 0.06620067876896688, 0.013318896875716746, 0.09746649355760642, 0.03264134776379381, 0.022204269688310366, 0.017452561895229986, 0.035569460463843176, 0.01969996147922107, 0.030488817553435053, 0.022356215731373856, 0.030763111942048584, 0.033897987832980495, 0.03431624360382557, 0.07456022341336523, 0.018413696571120193, 0.007838609561856304, 0.023728084617427418, 0.05426467442885041, 0.06699563004076481, 0.04251757423792567, 0.05981225799769163, 0.02706837171821722, 0.04043178812467626, 0.03588053823581763, 0.07094170472451619, 0.09400183268423591, 0.11103969093944345, 0.04239403336708035, 0.06478306305195604, 0.0322214024407523, 0.02689833932423166, 0.05929971978600536, 0.017868763401306102, 0.013815858467881168, 0.026417522624667202, 0.04467099332915885, 0.029770401639065573, 0.005366152634711138, 0.2167050452636821, 0.17297183482774667, 0.16648775418954237, 0.10983596303101097, 0.19461052013295038, 0.11458479213927474, 0.07809816606874977, 0.09967066028288432, 0.12376043120665209, 0.19223465690655367, 0.12663528908576283, 0.09174910999302353, 0.1360873497490372, 0.09782984227474247, 0.09283644200435706, 0.14869440825922148, 0.09401241104517664, 0.09967853807445083, 0.12439111593578543, 0.09360860807022878, 0.1772228702902794, 0.159275958314538, 0.17245028567101273, 0.16461497039667197, 0.17762133319463047, 0.12015190055327755, 0.06519067260835852, 0.15353328574981007, 0.1384404684816088, 0.15070672599332674, 0.05945027992129326, 0.10036388558468648, 0.13402095277394566, 0.13544101800237382, 0.17265665531158447, 0.05697762367448636, 0.0903743641184909, 0.1149796045252255, 0.09905248095414468, 0.1528801822236606, 0.16154432802328042, 0.08103162223207099, 0.1790574389908995, 0.12857938690909318, 0.0890549256333283, 0.10721331661833183, 0.13176850149674074, 0.1169147863984108, 0.06253029964864254, 0.14160097603287014, 0.12350059300661087, 0.15690702971603188, 0.18324660563043185, 0.10088289023510047, 0.19224300288728305, 0.08902597932943276, 0.12704878832612718, 0.1638397712792669, 0.12899055198899337, 0.13465427021895135, 0.12180715958986964, 0.18117262263383183, 0.06740382313728333, 0.14660510394190038, 0.22844729732189858, 0.1003258740529418, 0.17433032978858265, 0.23317163810133934, 0.13943596077816828, 0.18750739842653275, 0.13991624143506798, 0.06361503965620484, 0.06264166081590311, 0.13454406256122248, 0.16641691513359547, 0.0913421789716397, 0.08236105553805828, 0.17452542217714445, 0.16384331323206425, 0.11648021186036722, 0.09915603218334061, 0.12003317049571446, 0.12121148726769856, 0.1201855151781014, 0.1033886114933661, 0.10870057716965675, 0.15552431105503015, 0.16365504690579005, 0.10795437863894872, 0.11905192743454661, 0.09307059086859226, 0.09909381052213055, 0.20952013294611657, 0.09441542691950287, 0.0850895873403975, 0.20830858152891907, 0.12072875031403132, 0.1911042718482869, 0.1825164340968643, 0.21265029641134398, 0.13080798089504242, 0.07582984385745865, 0.10951598627226693, 0.15961104604814733, 0.10747296482856784, 0.0790036099829844, 0.2100236602127552, 0.21121575124561787, 0.08220233941184622, 0.07569501894925322, 0.12245359990213599, 0.15332224778831005, 0.08256791372384344, 0.18874336353370122, 0.057357549002127986, 0.22486474098903791, 0.22115224520010607, 0.21751294976898602, 0.11346892094505684, 0.15419617375092848, 0.14393101100410732, 0.12671465054154396, 0.1509655871029411, 0.08899769798985549, 0.10863655060529709, 0.1212741160499198, 0.114890295746071, 0.11389249643044812, 0.15460610389709473, 0.18743985705077648, 0.1506758119378771, 0.13830830343067646, 0.10243539192846843, 0.12186878414026328, 0.1167075482330152, 0.18894397919731482, 0.21074849846107618, 0.13469458876975945, 0.13819535449147224, 0.17384375232670987, 0.14335702466113226, 0.10477159478302513, 0.12494653756065027, 0.2387542985379696, 0.09999882017395326, 0.12396267535431044, 0.16391576720135553, 0.1447883942829711, 0.17307807984096663, 0.10145637446216174, 0.17775229045322963, 0.18597358358757837, 0.1794511385794197, 0.1816110105386802, 0.09705244470387697, 0.14385513721832208, 0.17522539890238217, 0.172341720068029, 0.14499743735151632, 0.07109244806425911, 0.11698885528104645, 0.16030262250985416, 0.13483545263963087, 0.10237251887364046, 0.14736365180994782, 0.09502388962677547, 0.1621160480592932, 0.1233714542218617, 0.10098117603255169, 0.12202045028763157, 0.10953161971909658, 0.12404517164187771, 0.07891846062349421, 0.10503476459000792, 0.09476061803953988, 0.15818924377007143], [0.03267710316660149, 0.06522221770137548, 0.012125218919079219, 0.008180975431709417, 0.06241524725088051, 0.008377747194442366, 0.04013520725337522, 0.04305393920679178, 0.05187915904181344, 0.052232753818056414, 0.020624596060120633, 0.07130875145750386, 0.016160980665258, 0.0166723738491003, 0.07087549327739648, 0.010287027689628303, 0.0662073487682002, 0.07085194811224937, 0.0147575276704239, 0.01437371942613806, 0.0681149617635778, 0.015359016734042337, 0.023007950313123207, 0.022423407661595514, 0.035182715859264135, 0.02330466010607779, 0.01638424413145653, 0.019158782304397652, 0.01972189512369888, 0.019777709717995355, 0.017570470925420523, 0.028281354844304066, 0.03208421283800687, 0.05582710648221629, 0.08026964776217937, 0.022329435650525347, 0.036393469997814724, 0.008535002774026777, 0.009816405978719038, 0.04661268913852317, 0.015959472728094885, 0.030833370850554535, 0.008566336673019188, 0.050553936045616865, 0.06984680026237454, 0.03488355316221714, 0.028829036080943685, 0.037080524023622274, 0.04474521488217371, 0.031125561600284915, 0.020064370407323753, 0.02831683713676674, 0.02932677205119814, 0.03566958509119494, 0.00729108862911484, 0.04510650424552815, 0.08357211162469216, 0.027320354179080044, 0.029836480771856647, 0.040243138426116536, 0.047711953188159635, 0.030379390210977623, 0.023567963923726763, 0.019721269175144177, 0.06822343915700912, 0.009550614482057946, 0.02916259371808597, 0.017904491662713032, 0.0336683071218431, 0.05039274665926184, 0.05667444405012897, 0.04547586817560451, 0.05404061198766742, 0.03486840147525072, 0.03581365164635437, 0.04969994883452143, 0.03863547183573246, 0.021414605900645256, 0.04546620922961405, 0.043423404917120934, 0.08355740777083806, 0.05033739855779069, 0.01661602151580155, 0.06141804504607405, 0.06272562952446085, 0.10565615338938576, 0.02255850059113332, 0.09428441537810223, 0.13698364022587026, 0.046162314912570376, 0.01618794395056154, 0.023931896180978844, 0.04077484864475472, 0.05249461065977812, 0.03305238052936537, 0.011962206818030348, 0.015132596383669546, 0.07427667719977242, 0.05384782322549394, 0.023349589302337596, 0.012663631367364099, 0.07717092760971614, 0.008282418961503675, 0.0688495844868677, 0.06953793112188578, 0.048608192774866305, 0.02753429627045989, 0.05950137360819748, 0.02606499145206596, 0.007410022247183535, 0.009499253621990127, 0.028255431413916603, 0.03897245268204382, 0.023463642557284663, 0.022731764508145194, 0.03780882619321346, 0.0176974451834602, 0.05525179021060467, 0.048872163253171105, 0.10165424205894981, 0.009331875148096254, 0.04488565806033356, 0.018148684541561773, 0.007679248827376536, 0.0243375328968146, 0.035448827115552764, 0.06821545279983963, 0.012180638266727328, 0.07910997034715754, 0.013193974337939705, 0.020340893783473542, 0.05528321655999337, 0.04350137198343873, 0.027929953432508876, 0.029812806685056006, 0.04853590843932969, 0.05589531282229083, 0.04629747908828514, 0.030525726465774432, 0.02080312880155231, 0.01613452288854335, 0.012575934108878885, 0.012388228422163852, 0.05147912532889417, 0.053702905108886104, 0.05191344202363065, 0.02048963205223637, 0.03501377421032105, 0.0618719578321491, 0.021991233441180418, 0.022472630288185816, 0.031249686011246273, 0.0596144243276545, 0.022521527217967168, 0.02958329560767327, 0.03284412795411689, 0.0327923625175442, 0.007105330337903329, 0.04725188948214054, 0.006795504038953888, 0.03818605773683105, 0.0452648709262056, 0.00832294107281736, 0.08361525966652802, 0.040249553974717855, 0.029135245364159346, 0.021038975699671676, 0.027198570713933026, 0.03833013107734067, 0.014292466553992458, 0.030093496266220297, 0.013699781482240983, 0.03231030409889562, 0.016191806511155198, 0.053590736484953334, 0.010678277766731168, 0.01199659497277545, 0.023401995954502906, 0.040585483091750314, 0.01584609122281628, 0.03998458944261074, 0.004621404048521072, 0.025775835450206484, 0.0065817811992019415, 0.05261675714116011, 0.03566775304664459, 0.043447560763784816, 0.08016444090753794, 0.01665752411021718, 0.10589423097137894, 0.02057731574002121, 0.03607399196230939, 0.007219241948665253, 0.036948806805802245, 0.021448853259373988, 0.019024071050807834, 0.00794806913472712, 0.028405940659078102, 0.017580145138448904, 0.033677596266248395, 0.05739915676947151, 0.03758889263761895, 0.02038436921845589, 0.04134494698207293, 0.05267269896077258, 0.03684237180277705, 0.06179920530744961, 0.021686259091698697, 0.006997400861499565, 0.03452364122495055, 0.0417639084293374, 0.07190351454274994, 0.10352622518049819, 0.06786467055124895, 0.004437614781116801, 0.017571690592116544, 0.025072930846363306, 0.050414656555013995, 0.011201618255914321, 0.036457299787018976, 0.04210088927564876, 0.04942598692806704, 0.012226689590274223, 0.01535164105838963, 0.017171078428093876, 0.04117319280547755, 0.06117055618337222, 0.036763444609407864, 0.038270382676273584, 0.019924202035846453, 0.035962237244738, 0.08251993451267481, 0.031071278798793043, 0.031052110184516226, 0.025506570702418685, 0.060888455249369144, 0.035973578957574706, 0.02637127537413367, 0.03690833219193986, 0.008459250276376094, 0.03213697911373206, 0.02675623373527612, 0.04594499710947275, 0.04029015411755868, 0.04321041956011738, 0.038808695040643215, 0.038942661602050066, 0.003267888050426596, 0.035739769360848835, 0.0468928562477231, 0.05468162741245968, 0.05160464073664375, 0.03583660309336015, 0.0299214978170182, 0.007209513452835381, 0.02006591746716627, 0.00463767659052142, 0.04549728952614324, 0.029839887017650262, 0.04050221327426178, 0.030186564129378115, 0.049633259020213566, 0.03443043086943882, 0.06075648697359221, 0.12883813945310457, 0.07972966959433896, 0.02516305217120264, 0.014008674371455396, 0.01628454358849142, 0.02606615683596049, 0.04075071654681649, 0.05122449488512107, 0.039671767835638354, 0.03785661202190178, 0.057921377675873895, 0.020191784016788006, 0.013378653758471566, 0.048081062667604, 0.027415813878178596, 0.01520831580273807, 0.031209598162344525, 0.0322463046759367, 0.013550717516669204, 0.03557269707588213, 0.04397530833791409, 0.02236086708892669, 0.01909759540909103, 0.009973224751385195, 0.014875782753473945, 0.03130256763792463, 0.01169569352974317, 0.005274413427936712, 0.04993016219564846, 0.03298553465200322, 0.026082394178956747, 0.08171017760676996, 0.029680923226156404, 0.030202563985117843, 0.010705930613247412, 0.05373988187472735, 0.005310699360312096, 0.037236414051481655, 0.014108880423009396, 0.029189263536993946, 0.03966087056323886, 0.045879786501505544, 0.026453412038141062, 0.02348735565984888, 0.11428061846111502, 0.025238308490120938, 0.0377248167725546, 0.04931705491617322, 0.06259722355753183, 0.032687237087105, 0.014656590497387307, 0.0378398352435657, 0.045421361457556486, 0.05104902572929859, 0.017424528220934526, 0.03674365174291389, 0.06786991562694311, 0.02159992908127606, 0.016024260948012983, 0.0642583587073854, 0.0023491071063160363, 0.03746464948302933, 0.03485366030197058, 0.0036056744450304124, 0.06734761329633848, 0.03554177623508232, 0.03409238472314818, 0.08629002435398953, 0.022645334413807307, 0.054045823136610646, 0.08039969578385353, 0.045800526825977225, 0.05721678691250937, 0.06535913249743835, 0.06195985525846481, 0.041821980848908424, 0.019123535802853957, 0.045591649998511584, 0.012298113034505929, 0.06732284676815782, 0.029963930004409382, 0.005692122978091772, 0.014959994038300855, 0.022860363857554536, 0.05704547717635121, 0.019865177970911776, 0.028095957024821212, 0.006773493211117706, 0.08151948212512902, 0.12712467568261282, 0.12787976302206516, 0.08405322687966482, 0.13306218279259546, 0.09661353432706424, 0.07978950959763356, 0.08905294431107384, 0.1954049760741847, 0.08359429971980196, 0.1462689441229616, 0.28597716029201237, 0.1195651034691504, 0.21508264089269297, 0.15633704672966683, 0.11285898581679378, 0.16144604901117937, 0.10749953625989811, 0.0872342601152403, 0.08413187587367636, 0.18853019497224263, 0.06326088508857147, 0.11306341484721218, 0.07492944145841257, 0.13808625963117394, 0.12773866845028742, 0.10836742326085057, 0.12677791714668274, 0.1324140461427825, 0.12668212157274994, 0.14882252924144268, 0.12058720790914126, 0.10209152395171778, 0.1537651140242815, 0.1192235696528639, 0.15218996283199104, 0.1661985625645944, 0.17327159802828515, 0.07115450009171452, 0.1046544321413551, 0.1073258380804743, 0.08289299985127789, 0.12154930271208286, 0.1296547292066472, 0.14617750474384852, 0.11276542262307235, 0.1004815571276205, 0.09804577925907713, 0.11807647906243801, 0.10149447420345885, 0.11655746985759054, 0.17808555971298898, 0.11104241186486823, 0.09016352293214627, 0.15656436953161443, 0.12261545764548437, 0.15273683491562093, 0.09590495377779007, 0.1293109426540988, 0.1545444114931992, 0.13022384366818837, 0.15283279333795818, 0.18243982749325888, 0.05400573868038399, 0.14437284586685045, 0.13648859464696475, 0.10493398856903825, 0.09717898469950471, 0.1119301663711667, 0.08376059508217232, 0.14284135161765985, 0.08027754590979644, 0.1340874492057732, 0.11111608719719307, 0.15987186133861542, 0.1578883949135031, 0.11761628304209028, 0.1581330339291266, 0.11044719416115965, 0.1501590260969741, 0.19145231960075243, 0.11820161449057714, 0.17634133116475173, 0.16144664612199577, 0.1671441961079836, 0.18227271788886615, 0.0924643198294299, 0.13102798908948898, 0.341470223984548, 0.2291212725852217, 0.05718114346797977, 0.12822105256574495, 0.12327808780329567, 0.08638176907386098, 0.18170715895082268, 0.20130265317857265, 0.13584470562636852, 0.22424511638070854, 0.16738659595804556, 0.13308016397058964, 0.13955234310456685, 0.1413638416145529, 0.1384765665446009, 0.11012786201068334, 0.20276823453605175, 0.1216497937483447, 0.13657252942877157, 0.11163509184760706, 0.13969000428915024, 0.11148951894470624, 0.18790937614228043, 0.16061043313571385, 0.1425939170377595, 0.1487715169787407, 0.12701787427067757, 0.24066869009818348, 0.17479592694767884, 0.12166888772376946, 0.1575901923435075, 0.16891221409397467, 0.19079473774347985, 0.08685865027031728, 0.1279031860509089, 0.11153505542980773, 0.08912725746631622, 0.11066079019967999, 0.15069000689046724, 0.13317392393946648, 0.1476308996123927, 0.13677621207066945, 0.15469322779348918, 0.13740776532462665, 0.1821125836244651, 0.06701046960162264, 0.10442813392728567, 0.1185564204518284, 0.10287515725940466, 0.20930494235030242, 0.12607039511203766, 0.30492145089166506, 0.0966547689001475, 0.1296805813908577, 0.13494276973818028, 0.11180771115635123, 0.13801478275230952, 0.12130949486579214, 0.17149048431643418, 0.15953940632087843, 0.16740677558950015, 0.17685400508344173, 0.11874020844697952, 0.11637057417205401, 0.11258361595017569, 0.19962432395134652, 0.10629275494388171, 0.14538346949432576, 0.09799869571413312, 0.10834474662052733, 0.1764734826449837, 0.12295955632414136, 0.09564081366573061, 0.2696582302451134, 0.19881373244736875, 0.19462771421032293, 0.11737948789128236, 0.1020389035610216, 0.14095594707344258, 0.10624581389129162, 0.11292143817991018, 0.06579972564109735, 0.19167293847671577, 0.08341538360608475, 0.11287216975220613, 0.08811066273067679, 0.2158678551869733, 0.2081789949110576], [0.010713112058251031, 0.03604962916246482, 0.02391890053903418, 0.04086616928023951, 0.032318076717534235, 0.08061611452805144, 0.05911659675517252, 0.029185487489615167, 0.030113316274115016, 0.012776933992946786, 0.030067813715764453, 0.07477958021419388, 0.019330870659489716, 0.007291714577669544, 0.03503174181761486, 0.05551951977291277, 0.03539190820551344, 0.052501036386404715, 0.043092971933739524, 0.010044997641151505, 0.026563590858131647, 0.06105897788490568, 0.038167133395160945, 0.032550108552511246, 0.03815468227756875, 0.06805643133286919, 0.016528614331036806, 0.03537647153383919, 0.020249406906909177, 0.024653194172840034, 0.07578493840992451, 0.014626986014523675, 0.047421105937766175, 0.0718242209404707, 0.06809748270149742, 0.08397488322641168, 0.054041663716946325, 0.04634796887902277, 0.055507292571876726, 0.04360475357888, 0.024463748891970942, 0.018313539713355045, 0.024423062235915234, 0.02533181061569069, 0.01080242931909327, 0.02110724989324808, 0.08140232626880918, 0.04659593950158783, 0.018845207523554564, 0.025254394859075546, 0.030399003265691654, 0.028611874340900352, 0.037461674106972556, 0.03366376432989325, 0.05876048800668546, 0.06226940293397222, 0.08408192212560348, 0.02443596118661974, 0.009380727124932622, 0.040673129460109134, 0.07276160349803311, 0.03148765163496137, 0.008809170785493084, 0.07799165642687253, 0.01627911191566714, 0.024379425648865954, 0.04192151854346905, 0.006548969366122037, 0.01686348154076508, 0.050674616891358576, 0.03797625470906496, 0.061589965463749, 0.023535010870546103, 0.04155424789392522, 0.007356102461926639, 0.06359695669795785, 0.07145846342401845, 0.024749388386096274, 0.033800489136150906, 0.054509096313267946, 0.028779089118220975, 0.034162792909358225, 0.06090661284646817, 0.05974171071180275, 0.023750839289277792, 0.032842397689819336, 0.012205403098570449, 0.03687630194638457, 0.025608900568581054, 0.026957475347444415, 0.04365993543927159, 0.025037519800077592, 0.03745197784155607, 0.09286257238792521, 0.03770177033064621, 0.01358585205993482, 0.0324783941863903, 0.04762688186019659, 0.025450859584712555, 0.02624974975229374, 0.05024176583226238, 0.023786028115344898, 0.014473687990435531, 0.0448291598420058, 0.039268867312265296, 0.04207259097269603, 0.012341231390434717, 0.007944496647853936, 0.047214576841465065, 0.053219018038362265, 0.044623855501413345, 0.023087820670168315, 0.027831465770889605, 0.09941505614135947, 0.07373857178858348, 0.021002719877287745, 0.024262980557978153, 0.05150934727862477, 0.01487342145160905, 0.0340641576663724, 0.011489351030572184, 0.022994601832968847, 0.07265634914594037, 0.028802091455353156, 0.061934437336666245, 0.009023364782998604, 0.05972193820135934, 0.04555123984547598, 0.0035523415925646467, 0.057533153864954195, 0.030938923758055483, 0.07907809955733162, 0.027173088331307684, 0.013488746065247272, 0.008358285113769983, 0.024193166089909415, 0.03436230595356651, 0.019109739489587288, 0.024448319005646875, 0.029794045191790377, 0.009812848758883774, 0.006384935645785714, 0.021009467908048203, 0.006431183744488018, 0.016705287886517386, 0.020526719080018144, 0.055967502162924836, 0.08470089534031493, 0.02364461463210838, 0.05596868620653238, 0.03648022748529911, 0.06325951444783381, 0.015410463259156262, 0.02488945667365832, 0.03222385873751981, 0.028606266248971224, 0.05061647661828569, 0.010175976952138756, 0.06042913453919547, 0.0014322442958863185, 0.018534977920353413, 0.007757867287312235, 0.06870348232665233, 0.05509558127128652, 0.027019785218206898, 0.04468536809352892, 0.024281297610806565, 0.028685712521629672, 0.028340996376105716, 0.06592137339924063, 0.01622889014626188, 0.044146438262292316, 0.012754467698479337, 0.025549633927377205, 0.046377783707742176, 0.05345675974552121, 0.03671941786472287, 0.07015693147799798, 0.017894294977720295, 0.051416598326925717, 0.025759218127599785, 0.04904495898102011, 0.03947082647521581, 0.02795584123980786, 0.04150098289496132, 0.04224394481363041, 0.06619782892188855, 0.01603234399642263, 0.07950044010898896, 0.04306932159566453, 0.03883212146216205, 0.01563832888911877, 0.04676524755944099, 0.053372573905757496, 0.016230593269158686, 0.04312352975830436, 0.010777743366946067, 0.027577159327587912, 0.01490910560823977, 0.021250407211482525, 0.027951040604550923, 0.055354506841727665, 0.01608162429848952, 0.023035424196028283, 0.06523212431264774, 0.07876648913536753, 0.04086653908182468, 0.005295814422424883, 0.00597729513122301, 0.008228870674169489, 0.035071062921945534, 0.04682894503431661, 0.02499929622613958, 0.05044378945603967, 0.05256715283862182, 0.0019275436892972461, 0.021970253138403808, 0.012304258865437337, 0.05111004977620073, 0.030317002308687994, 0.01334748779689627, 0.05216961274189608, 0.06614975471581731, 0.0515444750365402, 0.011008791326146041, 0.011422163341194391, 0.002974497141881979, 0.04658599557088954, 0.02761864835130317, 0.05194227297657302, 0.06646696983703546, 0.018115638189816048, 0.012325828645511397, 0.028709559634860073, 0.04027056141889521, 0.025816503446549177, 0.029074072039553096, 0.04351380953033056, 0.03057342069223523, 0.056707624412540875, 0.015865862036922147, 0.021852600255182812, 0.023799966920965483, 0.02270246027702732, 0.03702154915247645, 0.018224013802994574, 0.060283358075789044, 0.038942454648869376, 0.013023258319922855, 0.058961836488119194, 0.0011964202983238334, 0.031438841218394895, 0.06161931888865573, 0.041814961404140503, 0.06486313696950674, 0.0616681801953486, 0.06539151218852826, 0.025179330226300017, 0.05259491509890982, 0.032137772999703884, 0.07769365741738252, 0.04223035375720688, 0.04876448992373688, 0.027615737436073165, 0.038581606333277056, 0.03480692959523626, 0.009101815305517187, 0.02853211254945823, 0.009010445476243538, 0.014938357252893704, 0.010995175672828086, 0.06565377954393625, 0.04525934425847871, 0.01582358591258526, 0.023389549925923347, 0.02985330844031913, 0.10474021253841263, 0.02508274924808315, 0.03920126486835735, 0.00023493016020178663, 0.03515090953026499, 0.012398477693620538, 0.016380987163367014, 0.023831137123384645, 0.049483038152434995, 0.01085724646691233, 0.075249323222254, 0.03727591496759227, 0.017076270122613226, 0.021502457525847212, 0.060870738700032234, 0.015560412712927376, 0.012229729427157767, 0.03542996044935925, 0.03675453205193792, 0.02046257716470531, 0.037902555628014464, 0.03315885963716677, 0.05200924438291362, 0.052837063891014883, 0.013083351077511907, 0.07547470541404826, 0.0261049079708755, 0.03719556624335902, 0.05545376633693065, 0.025294667608769875, 0.0205858296581677, 0.06846344377845526, 0.04481868326131787, 0.018675906251051595, 0.03291373886168003, 0.06502539504851614, 0.026478505959468226, 0.03972344845533371, 0.06540041456797294, 0.0360061147117189, 0.04098166272576366, 0.03250028372609189, 0.028171686621915017, 0.006001476422950093, 0.06620018343840327, 0.042455362754740884, 0.024061131656968167, 0.02289575963680233, 0.034774607579622946, 0.04053896273087178, 0.02452259823413832, 0.02680228929966688, 0.04691964481025934, 0.009667051939426788, 0.06505286214607102, 0.05115290265530348, 0.033727658579924276, 0.02104529455703284, 0.007515106965521616, 0.028915701966200556, 0.018993596346782785, 0.023214014612936547, 0.007514750734636826, 0.015853353243853365, 0.026269412000796626, 0.05481819954833814, 0.004109806031920016, 0.024168645530673008, 0.05652898310550621, 0.0519082987281893, 0.02947516765977655, 0.03128794860094786, 0.0347918525471219, 0.03779377967917493, 0.05134752346202731, 0.07069436513951846, 0.09302616039557116, 0.12751468404063157, 0.12912826745637826, 0.1895258365465062, 0.08362733758985996, 0.1175086402467319, 0.1251369480575834, 0.1128710298133748, 0.06561128968106848, 0.10527282181595053, 0.17914923120822224, 0.0894610220566392, 0.1704237458429166, 0.11213700420090131, 0.1648875650550638, 0.12678952009550162, 0.1593334438013179, 0.1544602188680853, 0.12222605996898242, 0.1377613634935447, 0.08283107674547605, 0.14021217769810132, 0.12576299160718918, 0.12676336935588292, 0.08506536364023175, 0.12038060756666319, 0.11172229038285357, 0.1726897813911949, 0.19489669906241552, 0.21226556705577032, 0.07437116998646941, 0.07949725099440132, 0.0797361224623663, 0.12343487010470458, 0.13123665217842373, 0.13493097679955618, 0.15989251594458306, 0.15505224067185605, 0.18235715478658676, 0.11237844053123679, 0.06936668923922948, 0.08425615634769201, 0.10601773791547332, 0.14351623611790792, 0.13146476208099298, 0.13761857258422033, 0.2783974084470953, 0.1074523509347013, 0.12911970434444292, 0.11020362044551543, 0.13978137581476144, 0.15146127050476416, 0.0782300325642739, 0.11150314392788069, 0.10388187931052276, 0.12020285853317805, 0.1385495497712067, 0.07923295481928758, 0.057672056768621714, 0.086322315835527, 0.11415545589157514, 0.06654479780367442, 0.07771093970430748, 0.21225396410695144, 0.11201011136706386, 0.11629689883972917, 0.090436768984156, 0.1659897637686559, 0.11772453651896544, 0.10825093915419919, 0.10998029421482768, 0.15732806069510324, 0.12141244219882147, 0.1772902352469308, 0.1072959757543036, 0.1661755195153611, 0.15113725646265916, 0.16813975625804492, 0.14895016167845043, 0.12511547920959337, 0.17778148102973187, 0.1361556239426136, 0.21201611044151442, 0.14748595096170902, 0.1593894636524575, 0.1115138783518757, 0.12343268522194453, 0.0759499106290085, 0.23918812668749265, 0.07776730560830661, 0.1546739845403603, 0.08591333563838686, 0.10814169501619679, 0.24106281037841523, 0.0953529519694192, 0.08335369798753943, 0.06805563744689737, 0.08934388655636992, 0.10759112491671528, 0.11336665893239634, 0.26787474166069714, 0.13470674811729363, 0.10027022061071225, 0.11941282664026533, 0.10527882685086556, 0.10780501272529364, 0.15388184918888978, 0.16820918396115303, 0.19305443577468395, 0.11838844232261181, 0.21543416274445398, 0.13258606834071024, 0.0794233110334192, 0.13769716051008019, 0.20023182992424282, 0.13008755312434264, 0.07283911255321332, 0.07909124278064285, 0.1015021823612707, 0.12039744880582605, 0.1616216538740056, 0.08967584624354329, 0.1675971182329314, 0.17526005847113474, 0.13474329401339802, 0.15230228751897812, 0.15372347911553724, 0.11947130278817245, 0.1324727801339967, 0.22476245862032684, 0.125294083197202, 0.15556798156883034, 0.1261879038065672, 0.12331742926367692, 0.1296283206237214, 0.17655330550457748, 0.13691377826035023, 0.16859128060085432, 0.11952658982149192, 0.09627246191459042, 0.09332139776753527, 0.09411932780806508, 0.17840464759085858, 0.10532516400728907, 0.16719344417963708, 0.1866393078650747, 0.16233586626393454, 0.17421674302646092, 0.14338681234845094, 0.15200397638337954, 0.0887065657547542, 0.12051087271954332, 0.12245001723723752, 0.08004943600722722, 0.10264556136514459, 0.09036469499447516, 0.1577632459146636, 0.19093727080949716, 0.1311597198780094, 0.0862500247146402, 0.07930337996887309, 0.12844765612057277, 0.06255121209791728, 0.15246761936162198, 0.11185250125293221, 0.20107372903398105, 0.07490551631365504, 0.1489709791328226, 0.11658794965062823, 0.1632747280278376, 0.12383308873644897, 0.12983000837266445, 0.1646406054496765, 0.09763502130018813, 0.11170374602079391, 0.111486526605274], [0.06364097326461758, 0.06305284625185387, 0.03389197940539036, 0.05192405091864722, 0.033884030367646895, 0.04857288520517094, 0.043810112202273946, 0.011789442472425955, 0.05552728221352611, 0.04987777929220881, 0.09570114221423864, 0.02717340724276645, 0.022698446742392013, 0.017758866173348258, 0.05498412171644824, 0.022474886417122822, 0.02042008051648736, 0.030944735410490205, 0.06258715409785509, 0.0017262898847028346, 0.019454238503905277, 0.01412474287540785, 0.04147175499903304, 0.015257457005126136, 0.04086442544524159, 0.03857379300253732, 0.03032617610214012, 0.019468411404107298, 0.06050654859947307, 0.04706105150814567, 0.013189222048302847, 0.038964771665632725, 0.06855446925120694, 0.03398633309240852, 0.031771482833262, 0.02458208879189832, 0.03095458434628589, 0.030840570107102394, 0.056621667596378496, 0.02056396217085421, 0.02291964237312121, 0.017492003439526473, 0.07478861151529209, 0.039535273731287034, 0.053092050565672774, 0.0428657644827451, 0.012432668225041457, 0.01884039331759725, 0.04632117353113634, 0.06636318112058298, 0.03991166728415659, 0.022745696528415595, 0.0753442570567131, 0.03880561449165855, 0.042463484818914106, 0.016807970590889454, 0.04388050003243344, 0.040158711706421206, 0.01269766329122441, 0.033446446526795626, 0.018025065639189312, 0.04383339952411396, 0.023817822569981217, 0.05231196599613343, 0.02429923298768699, 0.012451737603571798, 0.03373470177341785, 0.014556986645662358, 0.06343969263668571, 0.030873054971120188, 0.04759026811059032, 0.034827289038470814, 0.04478465133745756, 0.03529418898480279, 0.03280975676274725, 0.04733777165945087, 0.03250677052087017, 0.023559524644432322, 0.020885950785928538, 0.016767194028943777, 0.036504634389919896, 0.02843313803896308, 0.04809235688298941, 0.0076165411654593685, 0.04335436737164855, 0.019768586814669625, 0.023348817468753884, 0.015269523054095251, 0.056789360740887265, 0.03288828022778034, 0.03924045365835939, 0.02439861122651824, 0.02995866457266467, 0.02111772308126092, 0.018620773584448864, 0.05864591058343649, 0.020490934839472175, 0.07771408810679402, 0.035943160232688696, 0.018441840507356182, 0.03409594363932099, 0.0391631888757859, 0.09415231818067175, 0.03160685666703752, 0.055716871683086665, 0.02285341396262603, 0.04288458025881222, 0.02121549828111061, 0.026537998213565776, 0.1201023810676166, 0.01595686036827309, 0.04189042806891458, 0.0141746567595484, 0.04544342741636293, 0.047978685303990326, 0.06881278074745621, 0.0988823857956699, 0.034394414230648956, 0.014858758309856057, 0.014993834276018398, 0.040115285465227704, 0.03722411560426865, 0.023706753172778657, 0.03135628725535103, 0.04098819023264306, 0.12080425769090652, 0.08854483693305935, 0.006399028394038656, 0.022981947154871056, 0.061314392036625316, 0.08406163392854588, 0.030365541311247007, 0.0369478738201516, 0.017415206846115843, 0.04962577817163297, 0.016395836902250136, 0.08134330729288713, 0.028539800351219516, 0.10294690555227654, 0.0489724201948515, 0.06622110267302819, 0.01581293630546757, 0.028799102508596013, 0.039674889096724134, 0.06289749565933432, 0.05052997697410839, 0.020346576514254724, 0.02798095721352313, 0.01746898583535637, 0.005900653328613511, 0.060651151197297234, 0.04067381817315306, 0.054143732347126515, 0.013930464728868433, 0.04942863999998995, 0.033465187664010694, 0.0016671289465323622, 0.028538487385958433, 0.017417715729347298, 0.07704233843833208, 0.048314003739506006, 0.05097865146983947, 0.044792539307049344, 0.06354099112961974, 0.025956313890804137, 0.03937644225412181, 0.00977442501711526, 0.03558175212570599, 0.02253040754502373, 0.026860473677515984, 0.014695804732452546, 0.022152931728799428, 0.0339810201632125, 0.036662878934293985, 0.03156375612265297, 0.011779811516005014, 0.07658316700586251, 0.06004652899823018, 0.058596777862736156, 0.02528660322007324, 0.04664218844845891, 0.036728428809770515, 0.0044090900171015945, 0.020599076358069266, 0.007597215639959488, 0.04004647862166166, 0.011435223443965827, 0.05901723208704165, 0.015792395354115536, 0.025190921300756078, 0.01772550430281886, 0.010696812798934323, 0.09307830581175429, 0.027338732300060134, 0.004463100980501622, 0.054380144125648906, 0.07448604596512658, 0.010152086582300919, 0.03770837586905275, 0.051933750576738796, 0.07598421735955135, 0.04150038917682, 0.0073153683084196276, 0.03730724292940327, 0.010519352142832108, 0.01949334586970508, 0.034473324460642676, 0.016268009386424507, 0.051138093628521473, 0.022870250112776245, 0.03222187062991517, 0.019443202131826962, 0.04873348426605974, 0.029611648193427494, 0.02663245198449918, 0.06251910382083484, 0.03620630968362093, 0.01723344936700804, 0.046178284234234264, 0.026186125219932625, 0.007570943612206195, 0.019618696732712642, 0.014974497724324465, 0.015029895019584467, 0.020733882606561695, 0.013845242426863738, 0.0196854628822101, 0.03725670224853924, 0.03515634798843946, 0.06199335453233548, 0.01988046706121947, 0.01270440114395959, 0.05621136086327689, 0.03264497114079339, 0.037070848114256344, 0.024253301255937134, 0.04305178485810757, 0.028075426251494458, 0.059945610484906604, 0.06284672088388886, 0.03869894200137683, 0.01777493388258985, 0.032086553783821206, 0.01647067252945687, 0.0326475801079401, 0.014906176033296754, 0.06756220678133623, 0.02370432741008699, 0.06378897532288517, 0.05172662436962128, 0.011424468663920249, 0.054489727531160624, 0.030857146717607975, 0.011589384055696428, 0.021546189107799103, 0.02817828707130892, 0.01095265951672835, 0.026670952061457292, 0.007229749063429023, 0.014636524520548326, 0.036525377205439975, 0.04068131259243403, 0.05366393005741494, 0.028919016609766653, 0.017383512475394776, 0.08829536674810307, 0.06846856671784605, 0.021152404702401588, 0.009108530257695487, 0.012241826010202723, 0.016695971600711346, 0.04582275224051305, 0.0399707032234541, 0.05544774094596505, 0.026132115528785756, 0.016387604576136385, 0.01617103485789682, 0.04392992791586688, 0.01774435570197446, 0.036847650805222135, 0.013109652791172266, 0.046846709081104825, 0.023521033049161946, 0.032011144794523716, 0.06541715402688299, 0.025991270318627357, 0.017383453103580644, 0.04701237340590783, 0.02096944791264832, 0.07219342541481767, 0.02664380387536117, 0.021718774489792328, 0.10974254911499363, 0.012885434286934989, 0.029156256201011792, 0.05104386207780667, 0.033044580769326, 0.0202887042625142, 0.014200299446071898, 0.007437253553819443, 0.026352356121476208, 0.07716011854686908, 0.042746603555445156, 0.0016898122661846823, 0.031816602019327025, 0.02446150633373431, 0.04532331654003688, 0.037744178769311736, 0.020557773931484138, 0.042075206725192923, 0.011765964312611945, 0.002263963471965066, 0.017656342924705574, 0.03561959741637111, 0.0704530713015369, 0.0899752973179732, 0.01753023379881467, 0.026645700380738293, 0.056864135299942324, 0.050557902082800865, 0.0692408209932702, 0.05751249247363635, 0.0292199604612376, 0.05195889708452991, 0.01833849792767848, 0.03472715423309377, 0.04408110551802175, 0.030598675765629326, 0.0980877670060311, 0.012967039149121513, 0.03280695102044514, 0.06060886489493506, 0.025856540405324528, 0.024721997623730983, 0.025982756400480866, 0.046479044881250174, 0.08647603794400181, 0.03952486839677606, 0.004847758241729545, 0.04238879168406129, 0.01573550358547696, 0.0720734807795712, 0.028909096427794014, 0.010776814622139292, 0.023299321731818572, 0.010226934932039251, 0.02685388340614736, 0.024780729918607643, 0.07765469593661171, 0.04691397225750344, 0.028352307554866587, 0.014152530580759048, 0.13524954899081162, 0.16955310398978846, 0.28093958060656277, 0.11085415910929441, 0.08246909188372747, 0.11465692041175705, 0.10539334999131304, 0.11419886856206826, 0.09588045866361686, 0.15400922378259047, 0.19986204190977983, 0.1382926699838468, 0.0792522659259183, 0.0867521609844906, 0.11016967333853245, 0.07900407817214727, 0.16362696912671837, 0.12243707078908171, 0.1486946525318282, 0.15065331171665872, 0.17058744920151575, 0.09986862965992518, 0.0958055891096592, 0.1266764354492937, 0.15393477492034435, 0.06359632566039052, 0.12729259952902794, 0.14814706120107854, 0.11478344005133424, 0.10465050342359714, 0.06376111467501946, 0.11927786602505616, 0.16475905052253179, 0.12920935239110673, 0.0819555562255638, 0.05380959116986819, 0.12173876325998988, 0.13370318125401223, 0.1591866902474846, 0.1875523038740669, 0.1772301984684808, 0.10466083751193114, 0.09314328232514006, 0.13420430650668486, 0.14096475445798465, 0.17274276140545095, 0.10895595739462546, 0.13141943594174726, 0.06270361106310572, 0.1358118373900652, 0.0779978921636939, 0.18314318332288945, 0.12368894075708729, 0.0861975671723485, 0.0843636973627976, 0.0864837189604129, 0.13749611058405467, 0.08928311696009976, 0.08131328211831194, 0.1533132775553635, 0.11709721732352461, 0.10658264545989887, 0.09141535218805075, 0.1269853181604828, 0.19704141254935945, 0.11753412602203232, 0.16149612489555562, 0.08789157734385558, 0.13048817377005303, 0.16528121036078247, 0.16075953442071164, 0.16891059918063028, 0.1373441865933793, 0.13595678604074887, 0.14693464125905717, 0.14663520375532763, 0.12888889387249947, 0.12492642578269754, 0.16404391532497747, 0.05949139914342335, 0.0725889163357871, 0.09958696977368423, 0.11102356894740037, 0.09722597324954611, 0.15398793135370525, 0.12599410063454083, 0.2309558412858418, 0.16247286248419965, 0.11730535115514483, 0.20266629143485002, 0.2069381714931556, 0.12824742043656961, 0.11958256896053042, 0.07416115661284753, 0.17934809625148773, 0.18796644093734877, 0.11159266305289098, 0.13344494439661503, 0.0740258770861796, 0.09848165658435651, 0.09663416857698134, 0.1094594778759139, 0.19562271796166897, 0.19471219182014465, 0.08436644542962313, 0.0910662119942052, 0.1810641520257507, 0.15061314244355473, 0.1297622634364026, 0.20858376819108213, 0.09827859819467578, 0.07453986057745558, 0.10764146542974881, 0.18832013410116943, 0.11905488584722791, 0.17885994458837168, 0.21461846865713596, 0.06459258470152106, 0.09110286645591259, 0.13738043393407548, 0.10907922006611313, 0.12437464110553265, 0.15089717720236095, 0.09338501042553357, 0.19068956481558935, 0.13159817563635962, 0.13709295221737453, 0.09803999814071826, 0.09712876632277455, 0.12645526017461503, 0.17611871739583357, 0.13588681550962584, 0.07234601436981133, 0.09678660146892071, 0.10193948461008923, 0.07272918988019228, 0.2329507070992674, 0.08665517797427517, 0.17352708003350667, 0.16344643809965678, 0.18149375968745776, 0.07713558272059474, 0.15730049860264572, 0.1528310834297112, 0.17559123784303665, 0.1303588721368994, 0.17809477421854222, 0.2723672677363668, 0.11204327137342521, 0.08953605445900134, 0.11768290161022119, 0.1197056687836136, 0.1861173922994307, 0.1833707368267434, 0.1855173637824399, 0.1665533006723438, 0.13209237983184202, 0.13277803946818623, 0.1385216484112399, 0.15152696626526968, 0.1465696029897247, 0.11483720716621194, 0.15970640735966818, 0.07737359923443624, 0.12889633061630384, 0.15859618836215564, 0.09334986231156758, 0.1241496524640492, 0.08596520964056253, 0.18235866113432816, 0.13060379613723072, 0.10552443617156573, 0.1987343438501869, 0.15933210030198097, 0.11758378121469702, 0.12260905227490834], [0.02489451175954725, 0.011303236508475882, 0.01796605344861746, 0.0324499771398093, 0.0730452039944274, 0.0380861807747611, 0.026574215020186136, 0.0434440052402871, 0.00998627722063767, 0.04067458491772413, 0.0317269505799881, 0.014771415585918086, 0.06588668668908731, 0.016298355168796012, 0.012909015075170567, 0.009768913616426289, 0.01954304177447089, 0.028237633440377455, 0.0108218930961032, 0.05843168350734881, 0.035373421518930366, 0.01579511967221541, 0.024818761806402887, 0.030046070061091865, 0.02296359108627907, 0.03736120003408619, 0.02133943948761693, 0.022241275291889906, 0.08812429449920144, 0.0034012927000211285, 0.03955777055983033, 0.04613844405061432, 0.059072566617812426, 0.052764725272676775, 0.022150039473282437, 0.07027268276682921, 0.009222262056677468, 0.01963288489995258, 0.04789326113781758, 0.0148004009055772, 0.019203138138566698, 0.009280666958407631, 0.06147268068577562, 0.028095532940434556, 0.02490339208660381, 0.06354755256325006, 0.041239668881254535, 0.03181902099666851, 0.04011345681335245, 0.03245024176846657, 0.012775391173948134, 0.024238135998270342, 0.06185437020446573, 0.06014448231352227, 0.0388115143536457, 0.019582008344254324, 0.03698521020955273, 0.024293526508180157, 0.031155990503196205, 0.02723821242606001, 0.020128880427884202, 0.013419890027892376, 0.047883798966982534, 0.07164200714656285, 0.028316287523401634, 0.06253381446003914, 0.046010960891310654, 0.03949516213365963, 0.026291712054184506, 0.015804298554680178, 0.06539807362215859, 0.04497656478945698, 0.0026705168462025797, 0.09871046537799494, 0.028988271286445003, 0.057986028492450714, 0.018099083631698574, 0.019654709978827407, 0.002038397651631385, 0.02833543747796544, 0.06953341886401176, 0.03491346977118935, 0.08166751132479735, 0.024426626241100684, 0.008577948103525808, 0.0160248546661543, 0.028857049399188588, 0.019021402711846998, 0.021193215191098194, 0.04068284608157618, 0.01984020448955042, 0.017931409146902815, 0.046066658438316414, 0.0322410324588418, 0.05118893965014389, 0.023580861178093722, 0.05037079265873347, 0.04772621260157653, 0.0380701130655195, 0.044017838912882974, 0.13171374372073583, 0.03152075735852122, 0.06577947137079068, 0.012373962223396769, 0.021174412985731448, 0.002393155055220372, 0.027850768395832608, 0.01034664292819798, 0.04088283410029752, 0.030358284379222562, 0.044144456940037866, 0.02295561321079731, 0.02288065375094967, 0.027915841600458537, 0.028601509718490497, 0.0557080201937684, 0.00796122762507626, 0.0633367792304073, 0.014363792458815234, 0.02495766301373286, 0.04587158301313009, 0.030665575925792967, 0.035079995835466046, 0.004457575160943503, 0.02855141008538859, 0.04135469413761582, 0.029269045684486628, 0.05268878024071455, 0.10363735564585243, 0.04538297333887645, 0.048962401625301154, 0.06939721652971846, 0.02068714002546455, 0.017459393046530228, 0.059083117837352414, 0.02893193591652172, 0.028938850188361745, 0.07000888192227908, 0.025039680934111987, 0.1418374590575695, 0.07026931723313672, 0.0532115202264062, 0.0484215922520629, 0.0523299505668027, 0.023480166581326296, 0.03425306181556412, 0.03808114943759782, 0.0852813549073679, 0.05923858378082514, 0.04725452559068799, 0.042461649381688664, 0.07756289014858858, 0.09678432837660823, 0.022330636657508354, 0.04688876807423575, 0.03404244115310056, 0.053955907068614445, 0.02543612689312015, 0.06812697183340788, 0.060670231602021625, 0.024182837090588043, 0.05770354757883719, 0.028385942535740987, 0.014252461825630494, 0.03825557704216667, 0.015037511575168796, 0.015731149086994783, 0.007845115864516368, 0.09215272297816617, 0.07595659419894218, 0.07632157140012298, 0.018035632125767212, 0.04239537347374218, 0.04066352140424507, 0.07393730112484523, 0.058337265359503884, 0.05330077133008412, 0.026279881796134368, 0.008350655835654055, 0.06556673707174403, 0.01530314446426928, 0.04958756986473288, 0.024118635803461075, 0.06426947311099086, 0.031140112783759832, 0.022254316734948328, 0.023482456637014235, 0.03351018810644746, 0.006661422126593867, 0.03490201270739947, 0.02466350281611085, 0.05614849120112402, 0.048108869032668214, 0.044349971626486094, 0.030420098919421434, 0.014050221918816013, 0.05002721305936575, 0.013303296507469245, 0.03062046013240303, 0.02228703908622265, 0.025668506477294222, 0.033433513649340184, 0.010981988344740654, 0.001860171099126871, 0.11652936493711812, 0.008373217973192888, 0.059123395676059384, 0.040339663425194364, 0.03392445069870778, 0.03273359799225416, 0.04456727585888334, 0.08304078477833952, 0.022630901973960654, 0.033802918291517665, 0.010268867548022951, 0.01578880929654198, 0.04141142645052501, 0.005186910400100584, 0.020181551708706787, 0.03046121814155153, 0.037340966119830094, 0.013636537777659084, 0.017689131433144212, 0.007660953826936228, 0.014258239551314285, 0.028515288273670843, 0.051968919046755345, 0.03640768191378031, 0.01435665087774396, 0.044182526147259135, 0.046848575052406104, 0.010621759192352849, 0.03610656164320452, 0.0558871941507927, 0.07949510682374239, 0.03582305274903774, 0.037660515401512384, 0.0666230736034257, 0.005154436562276844, 0.0304389418368893, 0.03606486227363348, 0.030637562607548068, 0.040590086951851845, 0.013949300860986114, 0.028853439592889378, 0.07409539978419032, 0.021434970432892442, 0.009497058561204799, 0.05436102640149849, 0.05413214636168309, 0.047359315146292956, 0.029563577380031347, 0.04847743229142257, 0.025718628162784234, 0.023389083433098028, 0.07037234599036829, 0.032154648165617666, 0.01146722145910774, 0.006448915984947234, 0.02179014789206641, 0.044970115314104726, 0.0049857120445397285, 0.020944830662171756, 0.052969853194164376, 0.011281757482460566, 0.044874184033168216, 0.022817129302503805, 0.07007920529161181, 0.0362575322921787, 0.0047840348977063385, 0.019853563147730062, 0.011228805457774018, 0.019042447475450378, 0.06988609422530447, 0.008620563495372022, 0.1082999836653471, 0.0741617265822632, 0.04683330122913633, 0.0569989907422236, 0.03367169979693634, 0.02491742419078946, 0.02467061216676874, 0.01204152247269771, 0.056114673015794585, 0.030162812011050325, 0.015478277745257531, 0.03241023873644216, 0.03560596225517137, 0.029527933935501745, 0.04631703107484749, 0.01211576777443822, 0.07007296955479042, 0.04517976567149162, 0.041233497605259926, 0.026919121155515313, 0.003955187409051827, 0.06307099027825253, 0.01906057114579848, 0.03658413155270474, 0.030769938004336188, 0.07553014172507183, 0.07025335130414792, 0.05680540130872812, 0.09989172699195997, 0.10444407271487371, 0.09968482130872351, 0.04707592838842954, 0.03357112055112209, 0.07234264883611884, 0.053328604836549075, 0.06200824837599482, 0.05238666930901153, 0.01702689821831882, 0.05209091964310833, 0.0204078855458647, 0.03179367771372199, 0.014043700349118029, 0.026968152095962847, 0.07256427194390978, 0.06566566747746297, 0.05425436408924205, 0.014373073121532798, 0.06454710928457123, 0.06201892173183816, 0.047793669160455465, 0.031039167129035507, 0.04937197214790753, 0.016260742276374782, 0.034081399241196256, 0.025186928122171333, 0.09385461772658996, 0.021797815337777138, 0.011487955792940088, 0.033738789946905205, 0.039903945555644374, 0.028763923860554184, 0.04119979477088366, 0.04060309107548424, 0.04048256968547191, 0.05597533584971513, 0.05194472588066544, 0.041905403336776156, 0.030723047841872488, 0.03315537875252111, 0.044230379829449315, 0.019807653468368307, 0.015080233836280448, 0.0267098304216883, 0.030271767771669796, 0.0369668490519481, 0.0450162658733981, 0.08287332912108727, 0.1335735810654504, 0.1000144604061331, 0.0989542765808957, 0.10945484348173652, 0.20147125556000642, 0.11944163723715714, 0.1213290366743292, 0.2211780838136162, 0.16332911939493247, 0.15063102862664632, 0.1493297613092831, 0.1524964842413153, 0.11881175317934581, 0.16339268455547945, 0.11401894821652345, 0.12217208929359913, 0.1271595795239721, 0.09320076781191997, 0.10780507379344531, 0.11222649618451085, 0.10062758464898382, 0.13631588034331799, 0.11489400054727282, 0.09610569157770701, 0.12149911826210362, 0.14326515101960727, 0.07663132263613598, 0.05995933046298368, 0.17650880717805453, 0.08126153025243964, 0.14110647328197956, 0.14332465854074272, 0.13375181864414895, 0.11361806972750596, 0.07889262200998408, 0.13295212441257068, 0.09646004970584597, 0.19070618892354624, 0.10389692921723638, 0.1179291419684887, 0.11817162324275289, 0.10260172121758972, 0.12996813096106052, 0.1661151298987014, 0.1581307811928647, 0.19683222020311014, 0.1000419750011393, 0.10091287469757454, 0.08649258062775646, 0.09924666410578148, 0.16318088663475855, 0.10602976834135396, 0.1442151271871158, 0.17033512916948113, 0.15292910459850514, 0.06557100505701133, 0.10418107932699577, 0.22677270003727504, 0.14632125917289937, 0.12039503322115966, 0.1838850663708789, 0.12348764655845505, 0.103960080471422, 0.17881799755351885, 0.10843590780028275, 0.12449665527258601, 0.08807490393519402, 0.13620014941053732, 0.12717376090586185, 0.1432292972292219, 0.16816385782190732, 0.10027149625654731, 0.10739656857081822, 0.1231083861951317, 0.14988478938383715, 0.09981436721448388, 0.08334664800869566, 0.1055104515648314, 0.0850445054737585, 0.10628546069243125, 0.1660796289465257, 0.15657464255179676, 0.24506168865731784, 0.13202971033751965, 0.08870557509362698, 0.08763028707887445, 0.18817484618297645, 0.1243069911641734, 0.08331090956926346, 0.11713345109352044, 0.1155415807983705, 0.11250270064920187, 0.14228261874190398, 0.14665959030389786, 0.16384400533778326, 0.07988158001431397, 0.09219967081610646, 0.16812220934246266, 0.10296899865248374, 0.16894194749849184, 0.3311522033597742, 0.10728883078055722, 0.18802356001521858, 0.09787729222859655, 0.14579257182776928, 0.09464386251888104, 0.0735571790220482, 0.09280379768460989, 0.08366993601833071, 0.106227853069348, 0.16893927407051834, 0.06466705391981772, 0.09019511552261454, 0.1628174361373697, 0.15602116153708526, 0.1631429022444146, 0.15114434036825383, 0.11179071385413408, 0.07645269829247679, 0.11712857921208654, 0.21183312311768532, 0.12149368998195444, 0.14564294128545693, 0.07401204175714936, 0.14746981539896556, 0.1255534328520298, 0.14560250059834548, 0.2513965187328202, 0.16840863254453453, 0.18814554704087122, 0.09519030712544918, 0.22649049732301915, 0.15106968794550213, 0.09737261823777642, 0.14659567230514117, 0.1386247585926737, 0.07752662245184183, 0.09091744319136653, 0.16218615429741995, 0.2570279522665909, 0.1383835801056453, 0.09754679817706347, 0.1536697798541614, 0.13934727625123092, 0.09410672741276876, 0.07862996110426528, 0.11516552312033516, 0.1149141394666263, 0.1602365874818393, 0.06473244433956486, 0.12669335811265878, 0.21584166373525346, 0.16886908640818937, 0.12712179869413376, 0.15974356393728936, 0.07484184937285525, 0.10791817879570381, 0.06777740416250058, 0.17386831529438496, 0.10113807368491377, 0.12057868550930705, 0.09945116098970175, 0.13896576315164566, 0.10113525097923619, 0.10206398900066103, 0.09800442933504071, 0.12298873332994324, 0.12475680559873581, 0.17004410549998283, 0.1288662308028766, 0.1572773198464087, 0.08386690116354398, 0.13780793813722475, 0.1221619112683194, 0.13319285506648676, 0.21074016605104717], [0.07417791642780815, 0.020791631025661315, 0.0435226745903492, 0.04642917595005461, 0.023694614181295037, 0.0553603117088122, 0.040803031596754274, 0.028607104239719253, 0.05053983269525426, 0.02788481897940593, 0.04586973061252918, 0.021459477421428477, 0.020359707863203118, 0.06729791739157268, 0.018712876231542656, 0.004530290790301348, 0.034447190684399435, 0.03195889759808779, 0.05093250769589629, 0.05046385034386601, 0.04553164714681251, 0.03641716104799083, 0.06168664991855621, 0.04122082935646176, 0.03689255625275629, 0.025736178471041576, 0.023785057810268233, 0.022843702430171624, 0.0038436884143655853, 0.04273941447692258, 0.01542080074016537, 0.05991530032562358, 0.04169044005019324, 0.03053824882954359, 0.029754510348928825, 0.012947783173461045, 0.03758596136633839, 0.010665056511892803, 0.02335075638256967, 0.02558520612572985, 0.009335482409889144, 0.020091584750584195, 0.0563187899201044, 0.019160783982702663, 0.0196743179445288, 0.042155575805476735, 0.048284463717469146, 0.03868826864553349, 0.027798707796526805, 0.014726876547294003, 0.029264808233295168, 0.05773339633430753, 0.021897780509399514, 0.08327210415154696, 0.004348684285235192, 0.04171906065727983, 0.06030893884599209, 0.010191489110833831, 0.011265758474889611, 0.020855121547356248, 0.031273821501859596, 0.013838697108440101, 0.04442596754857472, 0.01895250765872853, 0.03452139527403882, 0.036816339806786606, 0.015306781411969235, 0.026910072891041636, 0.05788378683584077, 0.016636827095810856, 0.02300985699652561, 0.04679717602474349, 0.0628623136186174, 0.04107762114810092, 0.0205893190245011, 0.06676932504134518, 0.0470702761917242, 0.030244256569338695, 0.012805027887225151, 0.01868493415947471, 0.10455174943698303, 0.02519937415075089, 0.03611955898148673, 0.053616344396557124, 0.04009153334689992, 0.05205313542059489, 0.03391967720485159, 0.01450860031348254, 0.02336341784601765, 0.09274548438510724, 0.011585268740808325, 0.030642899285469736, 0.022103301981197934, 0.06208897368716342, 0.005696690791020436, 0.02786840352096728, 0.06219171067433698, 0.03670480561309627, 0.009550970712942737, 0.0698418944541897, 0.1060629826305168, 0.03499189484864473, 0.05897223164460488, 0.08321461187941687, 0.002300165859716279, 0.05175833231104272, 0.043764087171959024, 0.057720178472144265, 0.0667771010526589, 0.01188588943997664, 0.03756721344377313, 0.022189145142744695, 0.11350210130746875, 0.012077979311080915, 0.05761868998940502, 0.05148138824318137, 0.09057297810379948, 0.0035337552461507066, 0.044595852361193726, 0.03805093088054231, 0.02500059562070029, 0.022809276956000497, 0.022789119376934, 0.05131625996104308, 0.027146696711757352, 0.01675146389087396, 0.013083169569394417, 0.040113137901893685, 0.03834502152832491, 0.024007771663101654, 0.0575894790568522, 0.030515382199415138, 0.00891147435842348, 0.020146412076428533, 0.0525805165858141, 0.05235760426148772, 0.05855970270931721, 0.022249147994443774, 0.06946591141500644, 0.050219553988426924, 0.058525891309337955, 0.0465957054070064, 0.02757713557886226, 0.05240332055836916, 0.026850741789011017, 0.0632695092686585, 0.035544503945857286, 0.008489491733988481, 0.041319552809000015, 0.014197836363954204, 0.008388166099653711, 0.03753273029412542, 0.003640626632009766, 0.011264163069427013, 0.012904876859725585, 0.01770334504544735, 0.013479683381904448, 0.04611779283732176, 0.011401554536340492, 0.010149019604016627, 0.05382536032370158, 0.04818691413051315, 0.027714749265994345, 0.019495525663452487, 0.014922693271988204, 0.05002767446317843, 0.05392860281946404, 0.027123153242947798, 0.002342539311419906, 0.020712240732141902, 0.05276714764269335, 0.054813785678041835, 0.009421709791890212, 0.05315888626500964, 0.014818921518911208, 0.04396636185369321, 0.058102709374257495, 0.06560914551040956, 0.016323264189330593, 0.03641108137422374, 0.00722419864697648, 0.02874306569408093, 0.04014552437833377, 0.06698708728488002, 0.020491425081023147, 0.018387248972430825, 0.058579339512756894, 0.06827532672988516, 0.01349236096055912, 0.03298623693574752, 0.02434481866657734, 0.034680545662662814, 0.02250776143877634, 0.022741442113848667, 0.02112950584185975, 0.055068673965122016, 0.02070276838328157, 0.04375669114025576, 0.0763495202575411, 0.05003836138972214, 0.0335020355081984, 0.021508281052644764, 0.03765986400789448, 0.04364872943343861, 0.03683005299951349, 0.03379936955337014, 0.012072312695506428, 0.0491072654591075, 0.03668860558952604, 0.01739760734406965, 0.06284081762922661, 0.07215409073978662, 0.08440130855888128, 0.026817595353350043, 0.026969755134944404, 0.02527176196287785, 0.03946027186300073, 0.01710880926943251, 0.09383534054671015, 0.03893840379480805, 0.04741929764194148, 0.026888444587322216, 0.015296030024598752, 0.027292391750961542, 0.016836411386196102, 0.009196174929716756, 0.05598133070660489, 0.011546717773723816, 0.009630462786714946, 0.05024472424494369, 0.06345808772104126, 0.013420231839908021, 0.04658553416707686, 0.10556703460003648, 0.03378339344635606, 0.015166867491123932, 0.014993905522195356, 0.029937948898545334, 0.04189157818577119, 0.01649945768128548, 0.06936901661434344, 0.01711219346283802, 0.018185347484956895, 0.05399197120485561, 0.020393800855215107, 0.041075029144329686, 0.03533421915822795, 0.07231588741498333, 0.03378474033836808, 0.051135986777288575, 0.055581483590815745, 0.057719818848584376, 0.004645020035760743, 0.013556138163299432, 0.03283797703417284, 0.007510336864340518, 0.02496733553042369, 0.10223732077117477, 0.03331209998577833, 0.029562939557113817, 0.04669060531471457, 0.04061976607356753, 0.011845892345133637, 0.011611556035599538, 0.036725416114287715, 0.03224533437086003, 0.024370530054771473, 0.0181972422038338, 0.04675218236765691, 0.04001805139705539, 0.037385498373103995, 0.013550987234339118, 0.02323933414715741, 0.04144254406648023, 0.015300406575469034, 0.04812967970169016, 0.08890621111329113, 0.05347400810569525, 0.04857295984402299, 0.057264705055526326, 0.04197178441765053, 0.024702983376170908, 0.09014486321913344, 0.023507257091945837, 0.03606558830610343, 0.052971067771847756, 0.023157731829477207, 0.03394151585442679, 0.012400570125984294, 0.054333728937698264, 0.003345226199598983, 0.049508384828056605, 0.05087277625820466, 0.011142649321949907, 0.013786607671396008, 0.07994614940668855, 0.02762749305527125, 0.008460681137096668, 0.01933061281618263, 0.011881780910438724, 0.022828722073297416, 0.015105628009353365, 0.04615809781742947, 0.056085523151393445, 0.025261728126289587, 0.014337718054386122, 0.021598661917128732, 0.027180974604561925, 0.03131701025579657, 0.024536725333226577, 0.020000632220347012, 0.09878262757722821, 0.06633314237530742, 0.03308451594784856, 0.06713839380868844, 0.06305442045309714, 0.0035041357082913494, 0.008455360574381692, 0.036715838592499495, 0.014627455900024091, 0.03680184629878827, 0.032356804103723595, 0.0436860352887639, 0.01813268129314695, 0.011031458636612763, 0.02656794196393873, 0.015836756277297224, 0.0225306501212929, 0.0235609173375581, 0.03303943747388465, 0.02848559558125479, 0.027668228905115808, 0.019092173914292028, 0.04361748289582985, 0.032844022781188996, 0.014905022523765053, 0.018138470893193568, 0.03285538824275136, 0.04730256247733321, 0.03915915159242494, 0.01590956138846065, 0.010027462599932082, 0.07476734622780766, 0.02934633082311068, 0.053157522409622154, 0.01340986552116062, 0.047642942784088, 0.07976879392351423, 0.04505742241495422, 0.0371264472736844, 0.027703051322272847, 0.04062252092574324, 0.3107939814882619, 0.14170219988695212, 0.1467283530426877, 0.12273836747876235, 0.1327658122671502, 0.10434576656137194, 0.1790176768388067, 0.13036010707063334, 0.13022625925285475, 0.055023683700710535, 0.26867516871009556, 0.11766310195837702, 0.09921537007072143, 0.11132950003125838, 0.22790702059864998, 0.10424677508750133, 0.12337796815804072, 0.12137589630271707, 0.12584261090627738, 0.19570093947861875, 0.12627799968634332, 0.15008258234177316, 0.22780100628733635, 0.1162200751049178, 0.11880565993487835, 0.11336419585027865, 0.1268800909497908, 0.0932175140561802, 0.10113911862884249, 0.11108176011059966, 0.11356351551200662, 0.2076341448617833, 0.14315009862184525, 0.07955205626785755, 0.140276095696858, 0.20274231449833938, 0.11561049281486444, 0.075066485176129, 0.13627322763204575, 0.14273000402109964, 0.12202564786587443, 0.11035955457815103, 0.16307192748146399, 0.1348312592932156, 0.07241527922451496, 0.12346365356019565, 0.0883012767881155, 0.1372830913003002, 0.07644610293209553, 0.10604072668190513, 0.10159557592123747, 0.1631467563233205, 0.07772896159440279, 0.186498579702207, 0.16469450827155793, 0.0753242267029626, 0.11499879349555288, 0.2046177310070821, 0.14342468817319187, 0.0922154603259904, 0.12721869349479675, 0.09150525807802166, 0.1458680113511426, 0.11097841244190931, 0.11656455376318522, 0.0685106155329517, 0.09722913522273302, 0.11554069870284625, 0.08749085491789238, 0.14886645759854997, 0.14675216962184223, 0.2013233620673418, 0.12287285311945847, 0.14271936459200724, 0.12751906737685204, 0.14144123531877995, 0.15173382445105485, 0.0908937148217644, 0.13291650132409163, 0.1357439160346985, 0.12407981763992991, 0.157819767881717, 0.11165938340127468, 0.09781103328402553, 0.16999400247420582, 0.09379504235195261, 0.12116955380354609, 0.1495093423873186, 0.12463765484946114, 0.22335823039923394, 0.0729122654135738, 0.08557800363217082, 0.11937469297221728, 0.15523556726319448, 0.14934129640460014, 0.10305071462477956, 0.14973036838429316, 0.15005549522382872, 0.08501449386988368, 0.11935577541589737, 0.22888215684465, 0.11407176538237504, 0.16387316877288477, 0.1891368595617158, 0.11791447204138551, 0.1309813873044082, 0.18674627212541445, 0.1325855255126953, 0.1188617612102202, 0.13675597815641335, 0.13328543438443116, 0.1573725183095251, 0.1341973447373935, 0.07582152501813003, 0.13525052608123847, 0.12331061677208968, 0.12851419326450142, 0.09411159250885248, 0.13273913227021694, 0.19714719615876675, 0.10268348468733685, 0.14361186884343624, 0.11549208845411028, 0.14649324065872601, 0.11462820480976786, 0.06576231800551925, 0.0957314388028213, 0.08277667859303099, 0.10765208450279065, 0.14094072074762412, 0.14474587727870258, 0.15006616179432186, 0.10527948502983366, 0.12917355288352284, 0.15720122892941746, 0.16903487965464592, 0.13204265678567545, 0.12412503521357264, 0.14272642135620117, 0.17767823514129433, 0.143693727308086, 0.16275908212576592, 0.07920539951218025, 0.2546033023723534, 0.09505565863634859, 0.14028957140232834, 0.12094881279127938, 0.074237729289702, 0.11730590755386011, 0.11331507670027868, 0.0652331014030746, 0.12752589343913964, 0.14306187549872057, 0.10278276793126549, 0.09043429911668811, 0.09700933058879205, 0.12998087384871074, 0.10093264042266778, 0.18487822450697422, 0.15426362013178213, 0.1772382730352027, 0.1490956667278494, 0.11188607516565494, 0.11936945468187332, 0.07535095419734716, 0.13822264516992228, 0.14250106630580767, 0.08734664587037903, 0.2557089887559414, 0.09692096497331347, 0.11410277443272726, 0.1303659017596926, 0.1087175744718739, 0.10029272083193064, 0.13961902952619962, 0.14667459949851036], [0.026529813384903327, 0.04642011072220547, 0.035448752476700714, 0.04206545278429985, 0.0363369514234364, 0.032384298342679224, 0.013857970895644809, 0.011905720474065414, 0.04945277549060328, 0.004099850650943283, 0.046520391412611516, 0.028110704983451536, 0.05693780045424189, 0.023675942593919377, 0.03531961029927645, 0.026386946140389358, 0.02416445896960795, 0.031543993790234835, 0.04092622980741518, 0.022126916696184447, 0.029122414266956703, 0.06457902078649827, 0.05052990572793143, 0.009739435510709882, 0.03424476333228605, 0.019363506497549157, 0.04154967796057463, 0.011003084846639206, 0.02218578809073993, 0.04889523683648024, 0.05531200001548443, 0.010423914496121662, 0.02271382913126477, 0.025964491934116398, 0.0023656514864082313, 0.03261825043175902, 0.03696306621921914, 0.08855552385960307, 0.029765014071017504, 0.0272183890254902, 0.08585815717067037, 0.03530447218301041, 0.010486700189565974, 0.052694049065134356, 0.01945574994065932, 0.031723530763494115, 0.044237036257982254, 0.052783856567527564, 0.0307045170505132, 0.036864658285464556, 0.04064742655360273, 0.05910920072346926, 0.05917784132595573, 0.006631238344458065, 0.07048677413591317, 0.008210756333677896, 0.039976813431297026, 0.041813692543655634, 0.05570914995457445, 0.03901612658851913, 0.014462359848299196, 0.09191589390060731, 0.08542489899056298, 0.04368547210469842, 0.057303537614643574, 0.013554844705920135, 0.03841555185083832, 0.057056937632816176, 0.0362313747672098, 0.015486172500199505, 0.019980310096538494, 0.01839508774823376, 0.042810209428093264, 0.04441188116158758, 0.029510102035211663, 0.004760572853099022, 0.055307854166520495, 0.05997433287224599, 0.03251258895865508, 0.04898611303152783, 0.08648827871573822, 0.022905649284699132, 0.05071361908423049, 0.005731191752212388, 0.03865909503240671, 0.04421423748135567, 0.010837808134965599, 0.023291876506326453, 0.07589731059436287, 0.042514089960604906, 0.03676889663828271, 0.029217151326260397, 0.039718128740787506, 0.03467605036816426, 0.04845068444098745, 0.08002416057778255, 0.07886581309139729, 0.050057326443493366, 0.02543869345182819, 0.02274266178054469, 0.006136351797197546, 0.030719661952129433, 0.03420700964384845, 0.04438652091526559, 0.019625107192301323, 0.005073044166368033, 0.030772770888039043, 0.029660791092153107, 0.05722418972956283, 0.0699646957218647, 0.07231870333531074, 0.009300160421324628, 0.027018533321097493, 0.07026646738605839, 0.02824090906817998, 0.06228495495659964, 0.06593811285815068, 0.02538632072641381, 0.015928645185860138, 0.02029869908333889, 0.05894450670374291, 0.02722436691900449, 0.03959542586069022, 0.03750439467174666, 0.02937864266069872, 0.043661574101341624, 0.0851531932130456, 0.05797840854419129, 0.027953495204980885, 0.020367263350635767, 0.021039554150775075, 0.019264793223036186, 0.026673886725412946, 0.008315601868421903, 0.03255887861762728, 0.02894818004486816, 0.06337268051824399, 0.06104861665517092, 0.030656490341893265, 0.055247389911008735, 0.02154957499754216, 0.02161758965147393, 0.034402980735259395, 0.026448075360219394, 0.01619347570730107, 0.08386695544634547, 0.03233608503692916, 0.017515848856419325, 0.05783063718783004, 0.07007201282041413, 0.03777744734127607, 0.021774848623733436, 0.032591953807111294, 0.030467443700347627, 0.03995278650628669, 0.056400186980941465, 0.05380042076909116, 0.02561841193320496, 0.0720434081075447, 0.03453676409221121, 0.023249683502529348, 0.05188766108559711, 0.03423836813973529, 0.02715561775091503, 0.046703263385487456, 0.029887153767049313, 0.03950510606435793, 0.02272796131936567, 0.04394101178539651, 0.05205242635150041, 0.024951607088691423, 0.0735972940123507, 0.05139730079099536, 0.03388973345447864, 0.027336567773350647, 0.018646598627258624, 0.06196918511497123, 0.026883263972454836, 0.014001881387749953, 0.049432243020938973, 0.00974039563776127, 0.0064091962412931025, 0.02984068090362208, 0.018243979695918303, 0.04681562199922545, 0.04819212527945638, 0.012172072610285665, 0.012381661051352109, 0.054646930524281094, 0.03714678296819329, 0.016239439669464315, 0.03653367568871804, 0.03539872069710067, 0.01620049006305635, 0.013476823356800845, 0.04785514443314501, 0.027977065815191184, 0.06669959199747869, 0.07664499511676175, 0.036691669175135236, 0.04014945648876684, 0.007334116230984884, 0.08002095789249454, 0.0645055558000292, 0.021112649335658977, 0.051463742940021415, 0.017810602772182653, 0.05266925539555294, 0.007865355715953877, 0.04289100259276373, 0.0655266899349434, 0.0524216749306236, 0.06244978468332972, 0.041533735780311484, 0.030975449298109328, 0.03037423673751099, 0.023479810350441506, 0.023542167718655298, 0.016456974603767906, 0.07278088067791291, 0.0125572760922036, 0.04125689010002783, 0.025138653748269593, 0.012307865279061454, 0.025656028218301277, 0.06641382018902472, 0.04328640530418072, 0.033899409363844564, 0.032970617059618235, 0.010331945859694054, 0.02128198623125042, 0.0695283298513719, 0.051058908591845205, 0.040209255779960325, 0.04493994425450053, 0.01603206749340253, 0.012859480322471686, 0.06541857895042215, 0.04114810736583812, 0.0826412837154099, 0.026802525090585862, 0.022369267352457558, 0.05631096301866429, 0.02255018344814224, 0.014735264936462045, 0.04672313767618366, 0.020225203562793986, 0.024639788017209088, 0.04791185639000364, 0.04676969535648823, 0.011876959070962454, 0.06228835441704307, 0.0550293223267155, 0.030510649417660067, 0.03405294148251414, 0.027558777813932726, 0.009951454803480633, 0.050582163102392635, 0.030563463190836564, 0.011345001187042465, 0.04396049591845699, 0.008250422642699309, 0.02476134756579995, 0.028220084828457663, 0.021844656306451986, 0.004458042501937598, 0.023248606328187243, 0.04363842587918043, 0.0428236919189138, 0.0024779324927034652, 0.05725352958376918, 0.05538619103442345, 0.054682733424540074, 0.054405361879616976, 0.02981078465070043, 0.07670965950403895, 0.017707881052047014, 0.07335966426346983, 0.04047353159902351, 0.02520128761950348, 0.031583074014633894, 0.043566029585365734, 0.05498960767207401, 0.053987540371183834, 0.030579089852316037, 0.013139383651183119, 0.023626553726249507, 0.003139606340222859, 0.01709994929842651, 0.011361786447066282, 0.018956833319472413, 0.017038714905668582, 0.02867093402892351, 0.020250657107681036, 0.043798214090721946, 0.0005575358445639722, 0.003946104369658444, 0.04623529474650111, 0.027408996297578727, 0.027683428089533533, 0.02255654980295471, 0.04956459127632635, 0.025099911095042313, 0.02917547570541501, 0.03059385816699692, 0.007218584617865937, 0.028257760485368114, 0.052219637736145935, 0.0099953619563686, 0.005914880087532635, 0.0328807213476726, 0.06589497160166502, 0.02785302622110716, 0.02413605888640242, 0.037850695196539164, 0.019592274579086473, 0.023457696894183755, 0.05849520795579467, 0.016364419034549167, 0.05427325450416122, 0.024004061772887195, 0.015820121991315057, 0.03460954715098653, 0.03922914247959852, 0.0355634215021772, 0.034005467779934406, 0.038039137941918204, 0.05802636739930936, 0.06502639928034373, 0.02073101749244545, 0.034196566989911456, 0.04392125623832856, 0.03377348683508379, 0.025658867887354324, 0.08140612606491361, 0.023439659737050533, 0.016115754609927535, 0.04600062341030155, 0.09686614612915687, 0.017932077503896186, 0.041389255318790674, 0.04010412356417094, 0.027288132247381976, 0.044852423415120156, 0.02547122072428465, 0.024349364851202284, 0.0648400599935225, 0.02522500920375543, 0.031230602213846784, 0.033112722648573775, 0.0406358439608344, 0.031089541568819965, 0.09677308505134923, 0.11649423039385251, 0.08049555242593799, 0.15572926934276307, 0.11076973578227417, 0.12593675085476466, 0.1875326670706272, 0.11681501460926873, 0.17332768573292665, 0.12335671644125666, 0.1295761005686862, 0.11008858161845378, 0.0962115769673671, 0.09076857260827507, 0.15421752046261514, 0.09934182185679674, 0.0813052754050919, 0.08263311415378537, 0.12010804004967213, 0.09385581873357296, 0.08408368631665196, 0.2046483057950224, 0.23225993130888256, 0.11311636093471732, 0.1491343839360135, 0.07687235184546028, 0.1444306027676378, 0.11729217400508267, 0.14534161745437554, 0.20418949398611272, 0.08857794265661921, 0.22562083256031784, 0.0804615578215037, 0.1969796794333628, 0.19627717855785573, 0.14219097580228532, 0.13264549443764345, 0.23714079654642514, 0.1117154982473169, 0.08755035565367766, 0.13123509154788085, 0.13638792719159806, 0.07525229520563569, 0.16808186365025385, 0.07310181417103324, 0.14381399085479124, 0.13076331972011498, 0.11900299148900167, 0.120260818994471, 0.13372014462947845, 0.18019507080316544, 0.10456798677997929, 0.1408445316233805, 0.10193952532219035, 0.12283986274685178, 0.1637440842709371, 0.11938647234014102, 0.1403400001249143, 0.18764846585690975, 0.14290122554770537, 0.10606583926294531, 0.2986622096172401, 0.11632778575377804, 0.22627814300358295, 0.1649863461830786, 0.08419803303799459, 0.1771798375993967, 0.09744975409869637, 0.09422541675823075, 0.1085976366219776, 0.10224940547985689, 0.08606293225394827, 0.14884720077472074, 0.09276446300957884, 0.07721019443124533, 0.1620562012706484, 0.16539192013442516, 0.12358203077954905, 0.12387409939297608, 0.18131621421447822, 0.1518130094877311, 0.1363071815243789, 0.21571709827653, 0.23349804058670998, 0.11481200637561934, 0.15593862453741686, 0.04538738042382257, 0.10909720124410731, 0.1501235794275999, 0.11416980012186936, 0.10278314112552575, 0.11952517846865313, 0.12355661285775048, 0.17495314351149968, 0.08369227339114461, 0.12885415287954466, 0.13436009814696653, 0.13141647752906593, 0.19553491553025587, 0.15796528650181635, 0.10535281430929899, 0.0821830758026668, 0.08037846442312002, 0.12330278647797448, 0.1580566851688283, 0.10367659532598086, 0.13557762067232812, 0.11504701019397803, 0.11171738457466875, 0.13591065923018114, 0.14729501120746136, 0.10520659679813044, 0.05756017312939678, 0.11404926516115665, 0.07187571496303592, 0.1945898655269827, 0.24912369783435548, 0.08989870428506817, 0.0979267167193549, 0.07453631862465825, 0.1501691634101527, 0.17095438736890042, 0.16127177407698973, 0.1364987591015441, 0.10409417934715748, 0.1863022930920124, 0.15720550370003494, 0.11075866209076983, 0.09713327858064856, 0.21158349008432456, 0.10308062444840159, 0.16221875111971581, 0.06198514425860984, 0.13794441867087567, 0.11852005097482886, 0.2557894358677523, 0.21016104998333113, 0.14888276958039828, 0.12245054649455206, 0.2209371631698949, 0.08446482622197696, 0.14344201795756817, 0.08679236418434552, 0.14811986551753112, 0.1383636040346963, 0.10454524907150439, 0.11889251241726534, 0.09669747589422123, 0.1462917836116893, 0.10660816516195025, 0.11750626537416663, 0.13732167280146054, 0.16774005841995987, 0.10547931359282561, 0.1116757360952241, 0.11207558999636344, 0.18621717765927315, 0.08868791961244174, 0.2018241480525051, 0.1093594685995153, 0.16090398095548153, 0.11731613986194134, 0.15730273776820727, 0.13731670592512402, 0.22825863744531358, 0.17404820849852903, 0.10346640553325415, 0.1830334234982729, 0.08956063099737678, 0.10713888811213629, 0.11751991749874183, 0.14176936128309794, 0.1062682191176074, 0.0960451594686934, 0.1606792908694063, 0.1067757158141051], [0.029860640011195625, 0.027654235816693733, 0.029251149323369776, 0.0283907567416983, 0.04429817565583757, 0.05513249696897609, 0.030020594463816712, 0.006833722947963646, 0.05509657532508884, 0.019984301578785692, 0.0289368145833058, 0.022942997548463087, 0.017412847240588496, 0.08856522691036973, 0.057108044890420775, 0.020740595014233674, 0.010927140662845756, 0.02218359472629215, 0.024560881179890463, 0.035380400251597166, 0.027799270980592285, 0.038193983025848866, 0.013840561383403838, 0.0726228498720697, 0.024863127818597213, 0.026267780124076774, 0.012213817780970462, 0.049130922582532675, 0.08733406583113329, 0.0531002710174237, 0.021361602137663534, 0.013824167977353292, 0.04185648774728179, 0.0072133251233026385, 0.09645677916705608, 0.033781327307224274, 0.015383435513025947, 0.022154485573992133, 0.022146093792148998, 0.020463401584752967, 0.04141752648034266, 0.029834292496421506, 0.05722292765442814, 0.020888502077598656, 0.023429788748866746, 0.0638497517045055, 0.03998597026137369, 0.05964843928813934, 0.06124974800539868, 0.03527734435296484, 0.009669723671062716, 0.05317684030160308, 0.015495861980265804, 0.012929766372378384, 0.04159155035657542, 0.06767661457083055, 0.053529882071805854, 0.0257417899556458, 0.03196245312158551, 0.009857070582386638, 0.016920887299680283, 0.06627792998084, 0.03686813577743513, 0.014311529995341386, 0.0560543716086873, 0.029082726753715957, 0.02612908586992749, 0.01523720782383212, 0.03893084830737539, 0.011526838394014962, 0.04177780482651932, 0.03485302247905305, 0.0831622900441289, 0.02415952262734728, 0.038939930498600006, 0.04764568745823843, 0.02293972870601075, 0.05814897867717913, 0.029366591878767525, 0.06138949229248932, 0.025093207169058065, 0.04112574624429856, 0.022709815596629466, 0.01402836206502148, 0.034400303914610825, 0.031425090706241984, 0.02923884748348168, 0.01601894123346678, 0.05914288998714515, 0.07466315717569419, 0.008349058733853911, 0.03720037705664124, 0.005475795412036989, 0.07377956208906003, 0.043161744850554636, 0.06878287092383419, 0.019350733075823103, 0.05251350107469729, 0.0626638624817133, 0.09219748593334641, 0.023510419065132737, 0.06194097162889583, 0.049537758609013896, 0.035842977929860353, 0.0402553045590009, 0.03158755913110716, 0.11650003865361214, 0.014454073239383953, 0.023928381369582245, 0.015780617682529346, 0.03397560206108859, 0.004369436006527394, 0.04636074569342392, 0.05235170439950057, 0.033908220141061714, 0.017050580786807195, 0.007552719009774072, 0.02587788542067366, 0.034985072179032226, 0.07765185966023377, 0.029761363552617173, 0.031138335022010973, 0.041546963820500035, 0.02710446808487177, 0.01740735280327499, 0.03473825167332377, 0.032863629050552845, 0.013205644292091685, 0.024437705021617667, 0.045190001372247934, 0.05910786400948252, 0.04779294312798551, 0.03934022544750145, 0.04049290716648102, 0.07281080407223531, 0.04605281971661108, 0.03797416482120752, 0.032251814380288124, 0.06477053729551178, 0.06574809591152839, 0.03535816126636096, 0.019567273956324373, 0.06339896017951624, 0.008889723918400705, 0.04688088349731905, 0.0100550526819591, 0.021212770570335642, 0.025979358636374985, 0.01214425776353372, 0.01773500209674239, 0.007824924358698939, 0.059690196333186965, 0.03040143581373351, 0.03695393313786813, 0.050126788073352406, 0.028038963475929837, 0.042090005573949645, 0.03525695437565446, 0.041168602516076395, 0.019563470767544847, 0.03219295486009546, 0.07901051746947424, 0.0483400119867708, 0.04333352956122585, 0.044101610846285305, 0.037026268363531144, 0.0390531406737864, 0.012901471462100744, 0.03358094234551702, 0.024591868177854588, 0.009504825242662003, 0.05684313803379025, 0.03022670286840626, 0.054779231282217164, 0.0599215632038457, 0.03770974650979042, 0.017890191537195017, 0.019234369409137538, 0.03505667797955019, 0.03512778166415436, 0.019052784956459488, 0.04129622816773398, 0.015041615015694072, 0.030916762804346423, 0.09870982755507741, 0.04905870949317302, 0.06312053011996405, 0.023153194126539996, 0.053747043811849186, 0.03572511639712112, 0.005573754240426102, 0.019468823614131128, 0.026399315833779316, 0.021379532425531318, 0.050222872024668117, 0.0367290903814137, 0.04531863125573311, 0.035292777631964, 0.017069902071463208, 0.05136830359697342, 0.10398809039699179, 0.017049281392246485, 0.017429128688360964, 0.03319487627595663, 0.0789262977029596, 0.009394474244410438, 0.039091067388653755, 0.03123913479170629, 0.05228419695049524, 0.02739439083130232, 0.032012915770922384, 0.02158033468627504, 0.052352874872407744, 0.024683310949642743, 0.004823313169513962, 0.02135490160435438, 0.031382173366312466, 0.042994085632796795, 0.06497066441391196, 0.04829062820811357, 0.031054841287966286, 0.006700136366167239, 0.07906749405499015, 0.04485030299318688, 0.05020046340567725, 0.01746491462524448, 0.014668654850018876, 0.02095360920897552, 0.009474144433625042, 0.029212388010429483, 0.009179371858148702, 0.05846390035003424, 0.014332252454810908, 0.02549247583374381, 0.01697440505293863, 0.0875248359516263, 0.04914443560742906, 0.024412560210164105, 0.020659213220434527, 0.0313736747152039, 0.037909530968006165, 0.06770288744675261, 0.028363345623282448, 0.025568587106785605, 0.05437840707600117, 0.04067904967814684, 0.042489038447716405, 0.043560869326548915, 0.03282745974138379, 0.021888969732182365, 0.02606067427300981, 0.03887154095407043, 0.0543818540338959, 0.06401687487959862, 0.09383303352764674, 0.04611826102648463, 0.06832240348947899, 0.021097635052033832, 0.023137273998664956, 0.01882762668122138, 0.030871752183884382, 0.01762814979468073, 0.04777003239308085, 0.05992107465863228, 0.01879413249636335, 0.034066298444356234, 0.03642798707421337, 0.049752704932221344, 0.029855968297592232, 0.03150110359170607, 0.026877591419698935, 0.02774545636826328, 0.018253513112930313, 0.07622680041406836, 0.04341775272041559, 0.015758455032482743, 0.05029598417292748, 0.014938613399863243, 0.03542522766760417, 0.03807821138096707, 0.03205105283164552, 0.03912846823888166, 0.05181268635871155, 0.01721574808470905, 0.03442487366763609, 0.016764283113713776, 0.03594553849792906, 0.025748269965073893, 0.0486541838784303, 0.03533234640157648, 0.024206546800477163, 0.06394018006644078, 0.044289887350584776, 0.0417129029519856, 0.054988901995654614, 0.02064604964107275, 0.01535111349741263, 0.02750895468385092, 0.019085690512188842, 0.03160539103139724, 0.029953612879450833, 0.04258183828954186, 0.09931518935731479, 0.020567458322537795, 0.05513148255912321, 0.03880401314901454, 0.04978720165256943, 0.021942692742283856, 0.01255764250111367, 0.018904380866193345, 0.051415085193834136, 0.027738287645791258, 0.08061367180198431, 0.08221536728420428, 0.022985808019127165, 0.014110855808082436, 0.023970460718763725, 0.025196451361158063, 0.028975935519805977, 0.04773529479280114, 0.024204065058646456, 0.05357205302321485, 0.008639003532672567, 0.033363044394978454, 0.019519081006624868, 0.031215301249176264, 0.021218261614974056, 0.023728298355958292, 0.022149601818195412, 0.05722514646393912, 0.026149843952485492, 0.04758818500808307, 0.04256185204056757, 0.07345268462917634, 0.026930620627743856, 0.03075042672987495, 0.03610274488372462, 0.035604401624628475, 0.06708995319370713, 0.04544895747676492, 0.040985415024416785, 0.05315216876832502, 0.03727213213486331, 0.011072744099822427, 0.05502082367560693, 0.025340441581127898, 0.029718310505683933, 0.025575966175113405, 0.11454441930566515, 0.0388991166172283, 0.08089058194309473, 0.008869812308278466, 0.08456691181553261, 0.05715582054108381, 0.1424021359000887, 0.08931983927530901, 0.09941934448267732, 0.17256404885223933, 0.1032931755429932, 0.06803638062306813, 0.17454423116786139, 0.1296441847724574, 0.13948557525873184, 0.10445087842111077, 0.10300935113004275, 0.1357133819588593, 0.17480656637677125, 0.10588125059647219, 0.12796787757958683, 0.06994317937642336, 0.11346386585916791, 0.19832722283899784, 0.08056342628385339, 0.08114182988979987, 0.15679732417421682, 0.1921070787523474, 0.16870451452476637, 0.08378181965755564, 0.07850506994873285, 0.16507618421954767, 0.13333719303565367, 0.09312224095421177, 0.21532459290964262, 0.14202149132532732, 0.12869063951075077, 0.09044517603303705, 0.20901395939290524, 0.09402256871440581, 0.14504542334803514, 0.11210124540541853, 0.06276996500257935, 0.08655398126159396, 0.17336908993976458, 0.15454509002821787, 0.11376436187752656, 0.1678379438817501, 0.14769488546465123, 0.1881269280399595, 0.18563256545790605, 0.20673561521938869, 0.1404069715312549, 0.15253364081893647, 0.1265151205339602, 0.18396936756159576, 0.11181457793073994, 0.1020039590075612, 0.15085149822490557, 0.1099907707955156, 0.1681202823030097, 0.08782246176685606, 0.07567737703876835, 0.12841478788426944, 0.1341867053083011, 0.16828357854059764, 0.13792665462408746, 0.0774619241378137, 0.13913089143378393, 0.18799982486026628, 0.06987903746111052, 0.20717831860695565, 0.13470608315297536, 0.09729735513350793, 0.14653734543493815, 0.09592575766146183, 0.17468447078551563, 0.10468635042863232, 0.13188026978501252, 0.11849936922746045, 0.20613189547189645, 0.12393154416765485, 0.2001642206949847, 0.17397716588207654, 0.1761855666658708, 0.11996220930346421, 0.0822954276310546, 0.09321232326328754, 0.12007534823247365, 0.12023586247648511, 0.15271428041160107, 0.11222519339727503, 0.11187460792383977, 0.1317230939332928, 0.12974626358066285, 0.1809095274657011, 0.06169188142354999, 0.13803912858877862, 0.14259274995752744, 0.1833431611635855, 0.08040253884558167, 0.1355979631521872, 0.181287607178092, 0.12139180116355419, 0.1508717049977609, 0.12537997215986252, 0.22843435087374278, 0.10640868943716798, 0.14986370051545755, 0.1327044048479625, 0.15847053724740232, 0.07088613270648889, 0.1253528579005173, 0.09728690569422074, 0.11668697505124978, 0.11335901184273617, 0.1409032791852951, 0.18917704240552016, 0.08351630211940833, 0.0881281825048583, 0.13915291668048926, 0.13368920343262808, 0.17174876188593252, 0.16347100106733187, 0.22047656002853597, 0.09152620445404734, 0.1091552431296025, 0.08355636282690934, 0.12216355332306453, 0.11983035637864045, 0.13065510695534094, 0.12344804725476674, 0.20480386673339776, 0.09002019598015717, 0.14147812048239367, 0.19166470106158937, 0.09391948567437274, 0.15609295054205827, 0.19831450709274837, 0.08372203393706254, 0.17283042812986033, 0.17131373951477663, 0.10019127306129251, 0.15356704965233803, 0.18543432466685772, 0.10532089602202177, 0.20818036555179528, 0.14483659741069588, 0.0988769100180694, 0.08732776224081006, 0.16145047305950097, 0.11201680850769792, 0.14133424391703947, 0.1262465292321784, 0.05253750425098198, 0.13151771495384829, 0.07648826031280415, 0.10158701280930213, 0.11552095333380358, 0.10536968947521277, 0.16907494036214693, 0.18876484595239162, 0.11559035389551095, 0.09894762015236275, 0.17829502347324575, 0.16865732919956955, 0.2512845333133425, 0.2289212676031249, 0.10943083012742655, 0.1389549065913473, 0.0861553962209395, 0.09452732412942819, 0.1214522857751165, 0.12635434844664165, 0.07102114760449954, 0.14560046499328955, 0.15176714052047047, 0.13777540916843073, 0.2268141313855137, 0.050522092397191694], [0.014108957606367767, 0.042662153087024174, 0.04427331752542939, 0.03042507597378322, 0.01701134110667876, 0.030146008091313497, 0.0374344444966742, 0.04042891113619719, 0.023140766757673452, 0.04999178674604211, 0.0586490182738219, 0.053712950819837194, 0.011847195980538214, 0.052683660693998845, 0.011354845881994282, 0.041016322294516225, 0.020244543507163013, 0.03361869603395462, 0.01366737125707524, 0.059127731514828544, 0.049710632368390045, 0.007265881901340825, 0.018116394756361842, 0.02064285204479737, 0.03511408882747803, 0.031593045086732933, 0.03872915716575725, 0.07227060198783875, 0.04492064332589507, 0.030878160947135518, 0.02544424556461828, 0.06896657749478306, 0.038259906095585654, 0.05453829706779548, 0.02390602703339287, 0.007583616101848227, 0.05174567084759474, 0.020203029038384557, 0.037275962465043576, 0.017143920063972473, 0.02119038570007043, 0.007687152912175017, 0.03618896632854428, 0.008756751410796173, 0.1256490112947566, 0.030773286574653218, 0.030179232558501617, 0.018167990559179868, 0.0168464028143457, 0.03894745545195682, 0.01954965409822762, 0.004134243470616639, 0.022563559069697346, 0.05081318731286696, 0.018893699028662274, 0.08860477193125657, 0.03079961034070168, 0.0570883538041796, 0.045735757265772135, 0.0572836429678968, 0.042837934368955236, 0.02921613013105733, 0.05455601361713239, 0.048169896472245455, 0.01570688806740301, 0.0684218495818121, 0.05973316117056778, 0.011847514043828207, 0.018245224807677523, 0.04615712072700262, 0.006308205633623791, 0.006998475915419736, 0.07431897028748478, 0.04421004752761551, 0.07836950543735709, 0.030366606611226286, 0.017557105481890694, 0.030125777569732497, 0.05935184484613793, 0.08440875887338604, 0.02035261886859579, 0.02259657997637987, 0.06096354193453278, 0.017830716246472936, 0.04991416573258383, 0.032791582202272754, 0.07442139514854976, 0.009912791878118046, 0.012296616016621036, 0.037473738459604125, 0.034078610462269614, 0.007325070511017526, 0.04791533388197422, 0.02590879099443555, 0.05588821195332067, 0.015354407784928168, 0.02951529622077942, 0.04318026207121355, 0.025216262887365053, 0.04165243869647384, 0.03428823367825576, 0.03204200456717184, 0.028140160188611065, 0.0358106219874961, 0.07247789443603583, 0.04409795693520989, 0.011744140930074667, 0.06796873068170887, 0.08918889558741025, 0.023283878274794136, 0.03899488504976034, 0.05458423388855798, 0.04248485867200153, 0.028177898610010743, 0.026867484640596167, 0.06745322727199111, 0.04456515543695007, 0.03155108108850462, 0.05454359642629113, 0.014851302906338657, 0.06744691689631768, 0.012414969487248786, 0.014586750584255372, 0.010809070480588292, 0.011382015272309738, 0.030894873264644827, 0.03265443331162844, 0.02396239972274218, 0.03675618428470833, 0.053015664485948424, 0.0613218287804297, 0.015870828913258653, 0.008483869223190206, 0.048777273523488214, 0.0558228826017252, 0.08643561761294093, 0.037343832930283885, 0.05034071659403188, 0.04315384331026247, 0.05262328125536442, 0.0014619122853868508, 0.01747182889708451, 0.03335641850052135, 0.03663730155676603, 0.0138766764097714, 0.028119746462575028, 0.039117428474128246, 0.021377627438466464, 0.02817364419544382, 0.01842371853334563, 0.04032121066536222, 0.046247186072702916, 0.024680564579154764, 0.057150656889591894, 0.06100783670055015, 0.04491497077313917, 0.043089664075523615, 0.0320856038347951, 0.0794305849288191, 0.015817631767796617, 0.07281256826328379, 0.039252514618315866, 0.014590265395651971, 0.10913916863501072, 0.040726211254618, 0.029811697280300514, 0.03256529077355351, 0.03478904341214469, 0.0488943038508296, 0.017144506996763603, 0.039218275741274865, 0.009557578795855599, 0.03694945141406996, 0.03802195404257093, 0.04016470317063587, 0.018826184794306755, 0.027441567674811398, 0.015150470692398292, 0.07902733835258655, 0.020712267873542647, 0.040361400294516764, 0.010865377860942056, 0.021431679538051997, 0.045301253973905525, 0.014409417153469153, 0.041902536526322365, 0.01348867397090154, 0.06416457838245801, 0.03165267813684685, 0.06384788573320423, 0.022924549877643585, 0.03686034280274596, 0.03596504298704011, 0.021945227070578506, 0.042064058394836526, 0.07399337525878634, 0.035311366098799875, 0.04066281572782567, 0.035340940047587664, 0.04420025287462132, 0.02004292870073446, 0.04457146241994841, 0.030373120547405312, 0.09331339105431523, 0.01439220441638359, 0.015357356019584196, 0.06355884338596038, 0.015562017448246479, 0.030199256126901934, 0.028235765772738626, 0.01242129088911627, 0.052600920133824856, 0.04562707291916013, 0.09994692581572703, 0.022509880164372068, 0.007194958028516599, 0.004182187482781176, 0.003160196909448132, 0.09285225865564176, 0.020229212008416653, 0.038649995877806625, 0.03979102036516581, 0.035089047492614815, 0.027318600166056837, 0.03598608096529331, 0.05677128456799047, 0.030481516516634395, 0.047217172237911394, 0.011513828333201153, 0.01114229393923389, 0.04934997743527804, 0.030883718148938248, 0.08394852214093719, 0.058357356781406064, 0.0393925133560385, 0.009652013058907219, 0.028914918258254017, 0.01470035600609013, 0.05503792954342706, 0.034243348586772165, 0.021440536116382906, 0.04206819406577519, 0.053852159064263105, 0.010440032247320881, 0.030544647414769446, 0.022376246085124354, 0.007500180043280125, 0.03434590236949069, 0.048156461478876214, 0.03180427643071328, 0.04470015337158527, 0.03470017568075231, 0.04072280840149947, 0.028320899865190898, 0.04569014614181859, 0.050600856742156405, 0.032483544267181835, 0.0446614802681974, 0.007444181396359844, 0.024185793806931803, 0.0764234737892236, 0.017303248568038856, 0.05840049803789173, 0.04955155661861811, 0.08926820954574005, 0.045551901417119164, 0.007230205378229064, 0.05557823680075152, 0.05915494755442653, 0.055907221111868105, 0.03686502469437463, 0.06225084500121219, 0.026208494823159914, 0.030195419011371474, 0.02285023502606366, 0.06889520918152162, 0.019220646038385372, 0.13037173716085299, 0.009146730082907846, 0.021643662359565496, 0.08093674268041338, 0.023220908528726016, 0.03931191696652344, 0.06673713534006051, 0.054391777608543634, 0.016265587016407932, 0.055717302552823506, 0.023775629566184113, 0.005801126660246934, 0.038039884330438714, 0.020170196425169706, 0.023963029063971977, 0.013435197777913084, 0.0028124962700530887, 0.030110374824809175, 0.035382900653140884, 0.035100938818816624, 0.03486972801121218, 0.059704655914434364, 0.03760304009275777, 0.08133188754852329, 0.03333756201235311, 0.050799043250403235, 0.09565027244389057, 0.00890103679349912, 0.031195043586194515, 0.028588838077017238, 0.049937653222254345, 0.02784458015646253, 0.013752138092448669, 0.043860232191426415, 0.030856193375906775, 0.023147480861682976, 0.03486603678071073, 0.10128662535654646, 0.03501383527847273, 0.07665510528853961, 0.06869645270385913, 0.010016485599667897, 0.05141810467466712, 0.030049316851156097, 0.03317624031166945, 0.06286799295672349, 0.04780087520235351, 0.056476104871502945, 0.016400240594521165, 0.055712193184133084, 0.06268386569406305, 0.04091605856748564, 0.012963162169658711, 0.05274882719718984, 0.024293246612484967, 0.06553299352526665, 0.018177410321576253, 0.07628939526953868, 0.04329147056809493, 0.05324882608173149, 0.03407459014228412, 0.034811703089092455, 0.030293823552450964, 0.04513950479616012, 0.018954848604542867, 0.057127498489405425, 0.04865770547517708, 0.0875107767060399, 0.01836247056988733, 0.06179179570504597, 0.08622192657951798, 0.03475383423002703, 0.01494668287757252, 0.02139728968696935, 0.01640298017965896, 0.09673237295023032, 0.11443551443517208, 0.12223842287702219, 0.13436837627419404, 0.21789955188121113, 0.13207979979259626, 0.09803032223135233, 0.0886723268777132, 0.05816052734319653, 0.12169430564556803, 0.16455065884760448, 0.13532243722251483, 0.06554142093019825, 0.10866331881178276, 0.07690685535115854, 0.08694046802286591, 0.10531267896294594, 0.2091314545167344, 0.08467163691031081, 0.1204765388475997, 0.1409714583839689, 0.10307226489697184, 0.08648397680372, 0.11502754980964319, 0.0897355301837836, 0.13472034595906734, 0.12728713053677762, 0.18883987835475377, 0.1345929577946663, 0.08210032845714263, 0.16958604007959366, 0.09843656793236732, 0.09660499157117945, 0.15668571873434953, 0.11362243949302606, 0.17195855134299823, 0.09622906281479768, 0.14145678734140738, 0.0697413966325777, 0.12020802897002016, 0.10277678325240101, 0.06524773061807666, 0.10520901238279683, 0.11064420680382422, 0.19375799516482012, 0.07314848380961589, 0.19259566467787537, 0.07392655991550003, 0.08088062783437115, 0.12194857985845634, 0.14258665671305998, 0.10378653156970229, 0.31699907566819874, 0.147484458184668, 0.17807383462786674, 0.19712913355657033, 0.2334096139030797, 0.11651580780744553, 0.12349563970097474, 0.1279946525714227, 0.13215608069939272, 0.09744333515741996, 0.2180302512965032, 0.16264671672667774, 0.10648947581648827, 0.11699311648096357, 0.14005177201969282, 0.11964898396815572, 0.08832303062081337, 0.08441420750958578, 0.1290297441716705, 0.11089847423136234, 0.1924625225365162, 0.06810496694275311, 0.27789029851555824, 0.11729819939604827, 0.13761832831161364, 0.09218869890485491, 0.1406103420470442, 0.09390750953129359, 0.0984683098005397, 0.14687191748193332, 0.12691812962293625, 0.13766535078840597, 0.14811883414430277, 0.07064682697611195, 0.1910845943327461, 0.11706658825278282, 0.14652101988238947, 0.16361478263778345, 0.13246508554688521, 0.13883378809051855, 0.15290180034935474, 0.19112230730908258, 0.15136764624289104, 0.1514301257474082, 0.16590509616902896, 0.1550824354801859, 0.1179887851966279, 0.12132199348083564, 0.11901220599455492, 0.20428486886833394, 0.10310353179063116, 0.16780122156654084, 0.198024609791381, 0.13339356572500297, 0.10993478487112693, 0.1403799658375127, 0.16544701717793941, 0.1714377621454852, 0.12514647468924522, 0.1361297717584031, 0.09820272440889052, 0.15562424569257668, 0.09565373297248568, 0.1180028851543154, 0.07816373969295196, 0.09474229759403638, 0.08909913218979325, 0.07885845098644495, 0.23037040127175196, 0.049334330417748005, 0.12803476756172522, 0.08502784065370049, 0.1944541720939534, 0.10778994924787964, 0.19435046480170318, 0.16033511076654705, 0.18533295153507165, 0.1048126257956028, 0.10179502450461898, 0.06977627333253622, 0.15635539431657108, 0.12175705656409264, 0.12965639840279305, 0.20906178254101956, 0.24434306578976767, 0.15843673263277325, 0.15114106982946396, 0.09774731884577445, 0.13055300100573472, 0.12495693271713597, 0.11544544595692839, 0.13707110338977405, 0.11912860189165388, 0.20958762003907136, 0.2653256213026387, 0.08955632908535854, 0.1363802326044866, 0.08821605278977326, 0.08766880751188312, 0.1466372800724847, 0.0983840696779745, 0.15471116825938225, 0.16940065074179853, 0.16401490116758005, 0.1295328778879983, 0.09881625577275242, 0.1535292552517993, 0.07804086378642491, 0.14582227809088572, 0.16122211888432503, 0.14135130228740828, 0.1784373258373567, 0.18146747324083531, 0.12075646168419293, 0.154330347265516, 0.11302940667207752, 0.1710029976176364, 0.09731021337211132, 0.12492532655596733, 0.14957345037588052, 0.13791682943701744, 0.12624110095202923, 0.08837197335170847, 0.10963199540440526], [0.009497771871143153, 0.06742789755974497, 0.005804309413568782, 0.043305607845208476, 0.008046001245799874, 0.04297672870701977, 0.02959154998617513, 0.0415369418582746, 0.014172759406002504, 0.019158073235303164, 0.03518851054832339, 0.07516341390354292, 0.048148665111511946, 0.03159148784886513, 0.018465750385075808, 0.033550649149609466, 0.018710404667737227, 0.04883180399026189, 0.025201257085427642, 0.020523365420688475, 0.025595988047176173, 0.04301899126065629, 0.028003728848748972, 0.15586060658097267, 0.06757079024932214, 0.05508137953334621, 0.00527894137693303, 0.019956581726936356, 0.041063297273857255, 0.025247316042493497, 0.034926171946738443, 0.027729283486093794, 0.039357334707996676, 0.018626086513644884, 0.05082047477896724, 0.004843804927077144, 0.038364709221890995, 0.06988355650433473, 0.021616566759933318, 0.03623759014798062, 0.01034886428221528, 0.020160172766606723, 0.03557802018310342, 0.03264965981777225, 0.03251063817047647, 0.011447130885374333, 0.04673450313774603, 0.0485078917284097, 0.018671502558780566, 0.02532872328135584, 0.016146790801680515, 0.09055739215442113, 0.031708955831293545, 0.008247035056618708, 0.02575774909928441, 0.03707292103873832, 0.02793622818509383, 0.05598887940868735, 0.02650136750058404, 0.008110736031085253, 0.008836959339013057, 0.022549292870930264, 0.02180941659025848, 0.023466553472514664, 0.010735622457494693, 0.013454741282787706, 0.062330661075455804, 0.04035811618502651, 0.022506102420655743, 0.045317532029002905, 0.03457002587882536, 0.011509156619597758, 0.05234636432890381, 0.04213089748684849, 0.025105868632506047, 0.02552248743761863, 0.041065427873815806, 0.02004379722555833, 0.02962060146299856, 0.017605159331911376, 0.033742620277085474, 0.03465930412390402, 0.048918554692396095, 0.04594487836584449, 0.035293612230036936, 0.06523964248065438, 0.039465011430105994, 0.04413512708353145, 0.02027531337392117, 0.04134836679856692, 0.005670165584888309, 0.05495690906952534, 0.051734607334115675, 0.04567833623981901, 0.14994523328329834, 0.021963447432166765, 0.041248405019619634, 0.041135527326592376, 0.017620874202943275, 0.056569359331790886, 0.020069384781111563, 0.03125433397612401, 0.039882829545864036, 0.040927084761538675, 0.05955317975687129, 0.04543506786493318, 0.07660726178437471, 0.027779335621744394, 0.01609207034510161, 0.008228293071234865, 0.07131732814013958, 0.03990002362323659, 0.0269542692694813, 0.08283670858613082, 0.03960048773192933, 0.024579157520617758, 0.018661780848300884, 0.03524337349725621, 0.030673470680734942, 0.038522054707365375, 0.004532755568756589, 0.051896020637026856, 0.04379858389230711, 0.05659498759944524, 0.05098705851872053, 0.0334965122331466, 0.04799833567813039, 0.037873297198010344, 0.027512284594454935, 0.014919828157871962, 0.07729885181678192, 0.023227921188143746, 0.050808977003076246, 0.05156291761834707, 0.05786307794707162, 0.09077938845647232, 0.04566581726872495, 0.029126475299043313, 0.11312322770910603, 0.02366835487607334, 0.044010921248367856, 0.011654585333807128, 0.04307996781010713, 0.0497871168356921, 0.022562936513817737, 0.03042885541383709, 0.016120845318904946, 0.028031519946775267, 0.014873999902712447, 0.020799205172806978, 0.037099590857646296, 0.018428330875134895, 0.038115479916866334, 0.04667483955355627, 0.034130301259990246, 0.036502608962889226, 0.05259165134547012, 0.05801595188677311, 0.035525209802602015, 0.0453818944681968, 0.036939130896436315, 0.020560535569010035, 0.05621257883363536, 0.049991732463240623, 0.04103802523708769, 0.016500753683171103, 0.019436238666198084, 0.042623693722167184, 0.023070465440728834, 0.05163369221346719, 0.02258870388115091, 0.0312666426013623, 0.0658255506839071, 0.036256175222141404, 0.04195170656644872, 0.0537069729263229, 0.06230130765054907, 0.026397605925532322, 0.055729614570736885, 0.06451061088591814, 0.02378255401604942, 0.0329569785057434, 0.048162208670484166, 0.008107242423907986, 0.007138580250154648, 0.0298854540368276, 0.012798282400971013, 0.05677558308733361, 0.018062608981771127, 0.02865876450336405, 0.010055427572556903, 0.018713276567203656, 0.07596308099372046, 0.055135068616696765, 0.06447540848915066, 0.03602289827540517, 0.007390331160942358, 0.02334435610100627, 0.03961631456123931, 0.030724581331014633, 0.04530057204621179, 0.03914604229586465, 0.027588227930079614, 0.013442510689076568, 0.04966701613739133, 0.04375352577439376, 0.05263184436729976, 0.037801609973290136, 0.018443967714639645, 0.028029246854462793, 0.07350728634212698, 0.012464739182697875, 0.03473738654117499, 0.05027488512652261, 0.03607563740972962, 0.04147080165733184, 0.03200035608772721, 0.06170955726078578, 0.00823386978091938, 0.02233946100542588, 0.05173897370696068, 0.024660184779869657, 0.05215064090277467, 0.052473301267517466, 0.02705491127978478, 0.014956984735493149, 0.042779716064355204, 0.046092944884938855, 0.01055232300755701, 0.01110573107975402, 0.03496173396706581, 0.02721022116020322, 0.07077624396021877, 0.06361693955425705, 0.0192595905557807, 0.06668957003525325, 0.02082007351730551, 0.01563509227707982, 0.07121343764343432, 0.006751096042405281, 0.05290866969153285, 0.01787780996944223, 0.05970244389027357, 0.020112363189192753, 0.034305736489061794, 0.037758278726999245, 0.07494094262697867, 0.03153394129393356, 0.01721556488025401, 0.02660872700757214, 0.025254863048238412, 0.058726439119449685, 0.012820428935810924, 0.04716719813378794, 0.026983836432918906, 0.054196301847696304, 0.011968113465367683, 0.004294554578206901, 0.04696188022249511, 0.06376319777752672, 0.04026003734075597, 0.028843862071101154, 0.04449286770873836, 0.07391861427043166, 0.055459662806242704, 0.03890340495854616, 0.05751941353082657, 0.040885700910751305, 0.05898004158266953, 0.011660411405110998, 0.05890692264905997, 0.005345417876794402, 0.09313910933477537, 0.05976252816617489, 0.01825795242828982, 0.038824369199573994, 0.01008214573708496, 0.019646874595699564, 0.05302858379270349, 0.057851332505898814, 0.008696117521529751, 0.03301456577277609, 0.05024022216509495, 0.023990742130471126, 0.034182402571397166, 0.013206506879734141, 0.03511474022109594, 0.05438850028440356, 0.011684188968501985, 0.020515146665275097, 0.03366890423265951, 0.06604550459555217, 0.07417817427111523, 0.0052755389478988945, 0.03806319200832929, 0.012008425230825586, 0.03223128530329891, 0.07701815545026745, 0.10357026210320847, 0.1204660486962114, 0.022045402588056665, 0.019796944489436488, 0.020211269846186042, 0.023408177408522794, 0.03946276208651917, 0.022696557022365074, 0.0834967399548207, 0.008970496727020612, 0.017655362441603626, 0.0007406275991732919, 0.052744854374655654, 0.06495781974600894, 0.04261744441464543, 0.05332716294963445, 0.056820960116705725, 0.024750881163137298, 0.03400616667100361, 0.04702671424352697, 0.02628598182595202, 0.03925508626603654, 0.01891829422675073, 0.06665885275495903, 0.045109839245144806, 0.05930259677448443, 0.05446297289537532, 0.028634099755436182, 0.016211887755032097, 0.015618142472313983, 0.03643180722636836, 0.03628762871293085, 0.046686666418931315, 0.04425957379862666, 0.06036366269524608, 0.050620741210877895, 0.015248829432364022, 0.11643522498863083, 0.07922335354877369, 0.007429575930083436, 0.03175129641645721, 0.04678193273554955, 0.018488191234480058, 0.019039221041436707, 0.018024863775021265, 0.021928823486502682, 0.015968985789056336, 0.025822557675253068, 0.03976904261591179, 0.013333432792153741, 0.02339082387542086, 0.012450193936404372, 0.028963952591376643, 0.02141527086496353, 0.13656157787357057, 0.19219546472387655, 0.19905583374202251, 0.0872726651972958, 0.08644314935164792, 0.12653923566852296, 0.13009579053946904, 0.06070511508733034, 0.11465709683086191, 0.12256596530122416, 0.16735106786446913, 0.15172162439141954, 0.12413217340196882, 0.1742840672710112, 0.04874094815126487, 0.18285240392599786, 0.1144336416785206, 0.15184859186410904, 0.12841453004096234, 0.0716070897345032, 0.1624792678547757, 0.11412726954690047, 0.10885018057056836, 0.24217929903950008, 0.15380936807819776, 0.16614802527640546, 0.10350873933306762, 0.09724489759121623, 0.1779011610363211, 0.20529113630098955, 0.12796702262546333, 0.10483929900718586, 0.1883794516324997, 0.17051496809082373, 0.14361408086759703, 0.07225367932447366, 0.15493466412382467, 0.23060400730797223, 0.09129236093057053, 0.1287189887038299, 0.10966322837131363, 0.11831999170993056, 0.09390235266515187, 0.15422801061400346, 0.14679189106183393, 0.1044072350487113, 0.1703235397913626, 0.15498482143240316, 0.07383236568421125, 0.0795945529160755, 0.07503495365381241, 0.21995760287557328, 0.10563612303563527, 0.11175364548606531, 0.10336890005107437, 0.18240759707987309, 0.15169661359063216, 0.09581336512097291, 0.1218918679015977, 0.11585065349936485, 0.06765659778778042, 0.08614315544920308, 0.16475846698241575, 0.13840367831289768, 0.11458853765257768, 0.08714667481503316, 0.13928962791604654, 0.10743497365287372, 0.12580336444079876, 0.14684545461620602, 0.12479569922600474, 0.0805928882743631, 0.08937389816024474, 0.1232097457562174, 0.08648986648768187, 0.1481488796749285, 0.09905164635607175, 0.11995861306786537, 0.08909596343125616, 0.13895337310220512, 0.11015602121395723, 0.0641512790960925, 0.1380140906465905, 0.153143155255488, 0.14170323126018047, 0.1279542933085135, 0.2129295271422182, 0.21406477051121847, 0.1708088144659996, 0.12171352175729615, 0.13345823011228017, 0.2256804079349552, 0.1300485102193696, 0.11295347181814057, 0.24113003962806293, 0.10335615716342415, 0.16445440186985902, 0.14957514671342714, 0.12095333183450357, 0.12955008553607122, 0.13103178888559341, 0.1273519034896578, 0.22456410926367554, 0.19259867737335817, 0.14233344101480075, 0.07040353824517556, 0.21009125587131294, 0.08039073233625718, 0.09593834448605776, 0.0531175906237747, 0.1886569181723254, 0.10325131671769278, 0.1396801926727806, 0.1199932862073183, 0.1319560350051948, 0.14622004888951778, 0.13360100745090417, 0.11853504659874098, 0.1367411860930068, 0.09061478264629841, 0.10536272092057125, 0.14450427809996264, 0.17934646776744298, 0.12483075234506812, 0.1918254867196083, 0.12414810540420668, 0.11112408712506294, 0.07611696595059973, 0.11614900534706456, 0.09041475730815104, 0.21921698190271854, 0.08711825776845217, 0.054052272611962895, 0.09037844211395298, 0.15713337542755262, 0.1668289623090199, 0.12585471597101006, 0.158790900771107, 0.21711862592824868, 0.09145501255989075, 0.1172720757978303, 0.12214888339596135, 0.07083840455327715, 0.1274192277342081, 0.1305708193353244, 0.15398229951305048, 0.10794814290212733, 0.13465712006602967, 0.15285219943949155, 0.1739332103835685, 0.19409385642835073, 0.1821025548768895, 0.23982812091708183, 0.12347807921469212, 0.19816635575677666, 0.1394823725734438, 0.13617478577154024, 0.08756092722926821, 0.08869885081159216, 0.197863566290055, 0.10737442118780953, 0.1010633601940104, 0.13342822529375553, 0.11588717225406851, 0.05620461283251643, 0.15530175156891346, 0.12462845391460828, 0.1365163331585271, 0.13232062544141496, 0.12198281873549734, 0.09192526446921484, 0.13007386028766632, 0.1468042946819748, 0.15076290869287082, 0.13011662156454154, 0.1301441972276994], [0.06802561227232218, 0.033348082697817256, 0.023436711502394507, 0.05985345185867377, 0.008920352140973722, 0.06376139287437711, 0.02913674831922565, 0.06548551643001181, 0.041123198345303535, 0.009916947905107268, 0.00838876236230135, 0.03751249298719423, 0.0628932344594172, 0.02259088197856077, 0.035896497379456244, 0.028807227965444326, 0.05959825483816011, 0.006917237038058894, 0.021218231080898216, 0.053021296326603205, 0.02995650004595518, 0.01902846117237849, 0.0038920476051446584, 0.0566220679320395, 0.048949685879051685, 0.02775978872419468, 0.06847018841654062, 0.019665705638804605, 0.01981521743748869, 0.08053127729466983, 0.02023649268916675, 0.05604250403121114, 0.026269568063850914, 0.01894055526437504, 0.15545012003609113, 0.04673867952078581, 0.037747618941856284, 0.013232534634880722, 0.04601384127246482, 0.09333842899650335, 0.05832608310239656, 0.03135947297726359, 0.06514367048761674, 0.04078801900946668, 0.0513886426841574, 0.02466395913091089, 0.041127235628664494, 0.04470591413389359, 0.030879897996783257, 0.08645091179226126, 0.02622320206968912, 0.06547662083591733, 0.04143102254186358, 0.011258804339117237, 0.029860375382538353, 0.017254132810713987, 0.05174764199182391, 0.031789080638970645, 0.04413447229723845, 0.04279620446530836, 0.0776388860706772, 0.025160962283345203, 0.04876463920144098, 0.009808454396469253, 0.05884098261594772, 0.02059262349004192, 0.039105153775640895, 0.01866539574361273, 0.04431313396032367, 0.01992697554773518, 0.0656519474993859, 0.030772438405879905, 0.03352060701165881, 0.024302912343825613, 0.04614652879536152, 0.015390634769573808, 0.028803085509155477, 0.008272856706753373, 0.008507799456960388, 0.1208463404327631, 0.03305970870756677, 0.10187933926603623, 0.028040653028126274, 0.053817458783409426, 0.027105972736275623, 0.08085788334054606, 0.012603182378890259, 0.04386705486103892, 0.027497609578339115, 0.013138744980096817, 0.06636623452816691, 0.027087109462757195, 0.0593739990144968, 0.012356132867613008, 0.033342410145061355, 0.008206321259162255, 0.03682347460250769, 0.028093906152727346, 0.019607680716684887, 0.03432258451357484, 0.0468221732548305, 0.047701178052063496, 0.042299998591520956, 0.03419526081000056, 0.015890530177525113, 0.011914077480988843, 0.019362890727019737, 0.036189312381403785, 0.05033019930124283, 0.027088670093300085, 0.05580477589475257, 0.033229644410312176, 0.048294750308351855, 0.029230484539376836, 0.009263407572039535, 0.020692726065005575, 0.03621373285672494, 0.018293266783335378, 0.04321199036868555, 0.04331569766093578, 0.02264319363582347, 0.023538875127477304, 0.07258207670279912, 0.035088613230202875, 0.03141267690807581, 0.03618206902007971, 0.06094759636159454, 0.014111078876469816, 0.014305908332711883, 0.0446250836497971, 0.036074707816754065, 0.02176613114508135, 0.02406598996770169, 0.009657914617231913, 0.00871252958729331, 0.027869348380980746, 0.05373109484623585, 0.03064962017482945, 0.0989700321640287, 0.06868911095495735, 0.045110829906272035, 0.06127977317997387, 0.024839616580201045, 0.020065883540415337, 0.027245837463332073, 0.014114870190886515, 0.026381137880629728, 0.05342735882316317, 0.05510026655559029, 0.019164095233593668, 0.047644360922276974, 0.031861202126102786, 0.030819403207195655, 0.03500748758337327, 0.025517033712406243, 0.03155849747625845, 0.03992895296375666, 0.07527425938418933, 0.0958460501528212, 0.034229954305504046, 0.08780994279576199, 0.05588726539696966, 0.041257351503840516, 0.00894774544784533, 0.05063887166657618, 0.005507222185510078, 0.021255221417439834, 0.08200939797929355, 0.029967617842235734, 0.028440483180539947, 0.09076290005551917, 0.07471719570457935, 0.0380514906719327, 0.1006851787013667, 0.026992440256955366, 0.03829580059807215, 0.07422521031860795, 0.008221209165640175, 0.05185509819005217, 0.010804284264200499, 0.019782481515513997, 0.04448523758245366, 0.04637515777722001, 0.009603166171083493, 0.08333564895604338, 0.02823833572412176, 0.04406972648575902, 0.025835344667679498, 0.05535963995914374, 0.057501853044543944, 0.050514933852744956, 0.049801142154527564, 0.05252133136881249, 0.011778753849544694, 0.019147464340286593, 0.02901009636531983, 0.03681857218699796, 0.005957488269944276, 0.04257217255820121, 0.012958671116004033, 0.023221174853720834, 0.01527906664913254, 0.035328075023634095, 0.0189238310725029, 0.027738962788134813, 0.010194248203853411, 0.054509486470903666, 0.0352454362437129, 0.02589301505525197, 0.005033194228807198, 0.0623208223176854, 0.026205348117010932, 0.05891689032848392, 0.0591855359130672, 0.0326052530934768, 0.02929418201425246, 0.056089285628071854, 0.06326507164963655, 0.02717364812269807, 0.005388594756368548, 0.039320534361260276, 0.07451965380460024, 0.04376834158652595, 0.04012992825093014, 0.08436229279530899, 0.0402386363462678, 0.06877895577677659, 0.011322890275291033, 0.033877540180193524, 0.057819251370217116, 0.023340999049001505, 0.08565472558672939, 0.013692491471634378, 0.02488605212420225, 0.036299781275114844, 0.008763790363445878, 0.0453345530799457, 0.04017358858670507, 0.03022237720766238, 0.01602936183501567, 0.021788398968055844, 0.03585120177428637, 0.032794055462415726, 0.0186712854275746, 0.04577491552169834, 0.0407611999128546, 0.012900025334342249, 0.03550179695178356, 0.04743493448144623, 0.017191987484693527, 0.02189695948202695, 0.016285476574142064, 0.034511257960860214, 0.03985219029709697, 0.036987286526709795, 0.022249142905431132, 0.03141526212649686, 0.005744456263658191, 0.01640129741281271, 0.06274014338850975, 0.0009872890202262039, 0.0332479546777904, 0.02581984523151602, 0.04660653143322893, 0.035118058257337124, 0.04125101737944143, 0.01741117295542998, 0.050030045943068605, 0.014672466520486134, 0.029860029329678843, 0.025234164337494543, 0.022916276839428713, 0.03190765802615455, 0.016803807778550044, 0.04687563502894981, 0.025209331652149558, 0.08094424049236945, 0.017677616693877747, 0.013434735525931631, 0.03335665259510279, 0.03521901748276182, 0.02620976877265743, 0.02113861687082265, 0.018350051682708517, 0.019095680244000893, 0.041341757867485285, 0.06493831864957299, 0.022778237371572425, 0.030041367813412632, 0.02378649291183267, 0.002676524213581745, 0.04088503933910813, 0.023437018539490442, 0.0260985331343753, 0.05252316341336284, 0.01771573000587523, 0.01617890756045069, 0.02122507749923638, 0.0574908811332924, 0.0409967567372535, 0.057078752533665726, 0.018238627750958716, 0.06042854421372924, 0.030594431529087678, 0.00961899893757488, 0.06202525246356215, 0.023415154444852045, 0.06448925060353108, 0.0731093187683395, 0.024980989351336445, 0.011567841417023113, 0.04013852189694132, 0.03255339266200151, 0.011510087908910853, 0.011283996648022106, 0.06485198185380016, 0.012426980405247636, 0.04541083398674216, 0.09800614602863789, 0.002767610118358529, 0.06220189548496689, 0.02007966797931918, 0.03680689799200211, 0.06561472306826285, 0.023884398729673455, 0.022852184117904732, 0.041658813532974036, 0.05352683884224721, 0.03377966828910368, 0.03422683982976845, 0.025468777998217514, 0.04264600395358034, 0.007343691208266786, 0.05573997919314674, 0.026077244098165205, 0.032582172724817476, 0.0704613494287644, 0.02170191119824137, 0.017932974866458347, 0.018813177277999263, 0.023110327676736882, 0.0664559029308813, 0.029105023414428745, 0.03596950774746282, 0.043134467742804966, 0.0517811819777957, 0.02915898391178676, 0.03087367583066225, 0.025084080873057246, 0.028992546057062488, 0.04464674588026745, 0.028140928629519682, 0.15954275828387054, 0.1744319200515747, 0.15483854285308293, 0.12089967328522887, 0.11822659814996378, 0.1454193504261119, 0.10603842644819192, 0.2065110472696168, 0.17815390176006726, 0.11744351445564202, 0.11858612671494484, 0.05284216647435512, 0.1403973770460912, 0.1136045940220356, 0.09914392711860792, 0.13423827396971838, 0.1968100592494011, 0.0967802300250956, 0.0891767158838255, 0.1083728786824005, 0.14354362179126057, 0.09200846643320151, 0.1152080808367048, 0.12226128950715065, 0.16080511840326445, 0.19509327065731796, 0.19648487812706403, 0.08008079789578915, 0.09542317355849914, 0.13858259442661489, 0.12482947669923306, 0.1403976756014994, 0.23228902689048223, 0.08019107340701989, 0.27137527668050354, 0.19289358226316317, 0.18190326914191246, 0.09599099201815468, 0.09239149266587836, 0.20022009126842022, 0.11759189649352006, 0.2300131390137332, 0.14533035377306597, 0.10317907309425728, 0.08884767389723233, 0.1583633151437555, 0.12693723716906138, 0.18148890137672424, 0.13512901403009892, 0.2713119015097618, 0.15718729182013444, 0.10817440040409565, 0.13656811895115034, 0.15213283018342086, 0.18558384664356709, 0.15482163376041821, 0.13381828793457576, 0.083996107801795, 0.13681030167000635, 0.13457390453134263, 0.150206577831081, 0.12337399194283144, 0.07331935928336211, 0.12379268876143865, 0.11441490054130554, 0.14241676511509077, 0.14353400016469614, 0.0605279156672103, 0.10741296197686877, 0.09361920678722006, 0.2409902342728206, 0.08391268870660237, 0.1357837596109935, 0.06478896630661828, 0.1648097913712263, 0.11082844263208763, 0.15352595757160867, 0.10729978233575821, 0.13674494517701014, 0.34128655812570025, 0.14297362523419516, 0.155459320970944, 0.133128787790026, 0.13619033779416764, 0.21394092429961475, 0.12541077764970915, 0.13149137422442436, 0.14969960360654763, 0.08479063838188138, 0.1349836853998048, 0.11034227907657623, 0.13370383264763014, 0.18339565263262816, 0.06847488387886967, 0.19521482342055865, 0.13571749388107232, 0.1013479513515319, 0.09443336738539593, 0.14479348329561098, 0.07311666730259146, 0.1620387900620699, 0.12607675977051258, 0.14288924261927605, 0.16132806534213678, 0.1146407848490136, 0.08808768753494535, 0.13481653508331093, 0.12140940236193792, 0.10355323765959058, 0.12686878655638012, 0.1547770675803934, 0.06917448740984712, 0.11863508980189051, 0.14938240205602987, 0.0759429760011179, 0.13272098824381828, 0.09691891579755715, 0.09331834435995136, 0.17849813614572796, 0.13133543330643857, 0.10341472830623388, 0.16265876750860894, 0.14001859165728092, 0.09539968267615352, 0.13450580675687107, 0.08688940147736243, 0.1513906078679221, 0.09841668685632092, 0.12387259304523468, 0.15746285846190794, 0.1269569689674037, 0.12052742897399835, 0.10862508336348192, 0.13558864008103097, 0.07061811137412276, 0.11140493955463171, 0.13157722247498377, 0.0933066735576306, 0.14863262086042336, 0.12412906571158341, 0.13652303708451136, 0.12031993296529565, 0.20276101492345333, 0.10638027917593718, 0.15582220149891718, 0.12074599867420537, 0.11338104387479168, 0.14630611427128315, 0.17743987935994351, 0.0629500210551279, 0.11056445858308248, 0.08432051539421082, 0.09442329792571919, 0.16578359768858977, 0.054831145996493955, 0.18854912609926291, 0.12222624995878764, 0.1738768241235188, 0.19178966007062367, 0.07690991554409266, 0.113115512765944, 0.14080282886113438, 0.09536161686160735, 0.17835325534854615, 0.11557158561689512, 0.15774222489978584, 0.09022949689200946, 0.20048698623265537, 0.11036922370216676, 0.07280817135636296, 0.11632535659841128, 0.18563352897763252, 0.06833531601088387, 0.09730524649577481, 0.13583109421389444, 0.08368372384990964], [0.03300259980772223, 0.03117814806423017, 0.057496526544647555, 0.03277235930519445, 0.008323208245980953, 0.02431244236816253, 0.05481648285474096, 0.014410675835928746, 0.060506243258714676, 0.03921533429196902, 0.028572970535606146, 0.04158156571377601, 0.060231260157057216, 0.049563424196094275, 0.03833090460726193, 0.033992426336875985, 0.048117835872939656, 0.01825489562803081, 0.056373775005340576, 0.09671443926968745, 0.02531944092230073, 0.013539887249602802, 0.04010435765875237, 0.034192410962922234, 0.0401246254997594, 0.04718575606654797, 0.02647176301772041, 0.04582868942192622, 0.046681333133684735, 0.04482486471533775, 0.06798818428069353, 0.025009489518457224, 0.019601224455982447, 0.05479221844247409, 0.013093553699686058, 0.02459204290062189, 0.03297951265371271, 0.01894633807907147, 0.027593557822651098, 0.031257377205682654, 0.04258191292839391, 0.02761275357832866, 0.013013534913105624, 0.006223716573523623, 0.02487421508080193, 0.04765529551410249, 0.04300183789538486, 0.029655837786516974, 0.019244075852579305, 0.021025783282571604, 0.027385099990559474, 0.05582241441256233, 0.0087131623211982, 0.05544452129730156, 0.04357678097273622, 0.032658311139260016, 0.014604826757152165, 0.017200235077845197, 0.03600275935605168, 0.055019269830414226, 0.0334599629443671, 0.02277425437101296, 0.05788017024419137, 0.018758957240996615, 0.04921898624992796, 0.058770659246615, 0.01847766206732818, 0.06456115495945726, 0.014899768966383167, 0.07781080648835216, 0.06396540799843413, 0.03525521054065653, 0.02153656069588448, 0.0617632158100605, 0.03505915802504335, 0.04757895693182945, 0.017166303237900138, 0.05055050605109759, 0.058389342922185145, 0.0508810917048582, 0.039896617377442975, 0.030212127936205695, 0.026031500659883022, 0.034409192723355124, 0.0268261007898088, 0.053301802703312466, 0.0401247781701386, 0.05760348401963711, 0.03274538753820317, 0.035404827512268505, 0.08130760956555605, 0.01716139742971531, 0.014250131057841437, 0.062281759056661806, 0.04920069633850029, 0.0491220269884382, 0.018064402010557905, 0.05269187096772449, 0.015990717569366097, 0.04330419309969459, 0.029596506684486355, 0.050619004161230156, 0.041174756828695536, 0.007009551727346012, 0.02546390611678362, 0.02894383742074881, 0.04331440165905016, 0.059952796170754094, 0.06668649627161877, 0.020883262090917145, 0.03206943095262561, 0.008547475095838308, 0.0382563675354634, 0.030982095548616986, 0.038733194449118206, 0.029814509807952812, 0.011802371109037526, 0.02567032664748175, 0.022181216461051787, 0.02344552567228675, 0.050786151085048914, 0.059537973787103377, 0.027613021599661027, 0.036841625414256535, 0.05348299530201724, 0.03386623239410775, 0.06772144537951265, 0.041982586695147414, 0.021098272874951363, 0.07958228500293833, 0.04079597143988524, 0.05512562340923718, 0.038857407069631984, 0.060037246639175076, 0.038984771485307386, 0.02020921218874199, 0.06927860860845872, 0.019789041252806783, 0.03568580547081573, 0.02027113190186875, 0.023957941747669662, 0.023127676120826175, 0.02207181117098246, 0.007726931179474507, 0.02622549551805215, 0.03332094129707132, 0.02267322559574885, 0.02063501496533198, 0.04577649650829179, 0.009333066825222756, 0.05848949469093766, 0.04522916980619941, 0.07694113494030067, 0.004572327731044165, 0.027599092972065722, 0.08703061818544354, 0.048736883726503165, 0.051890840022159476, 0.028571755957922766, 0.05325432221538254, 0.020759439628039087, 0.025663614239809767, 0.022013238331835185, 0.05785035541547196, 0.03939679830468126, 0.03298250838582005, 0.06076871417462826, 0.054637539599622996, 0.010856031041060175, 0.009046768303960562, 0.03575083965967808, 0.027068520995921323, 0.014601167757064104, 0.065701799467206, 0.010193667208243693, 0.05642803745078189, 0.014953145923625146, 0.02421682490967214, 0.0351238461610462, 0.025958949999351586, 0.03965718272541251, 0.04498336371034384, 0.029117226866739135, 0.011748142590347146, 0.05946066150707858, 0.027248353131913712, 0.0337481299814369, 0.0575777336156794, 0.025370731384360364, 0.022878964198753238, 0.054517309979668686, 0.03587100821148072, 0.04265389531584723, 0.0382756447153432, 0.01008064956736884, 0.04150486411526799, 0.01903412863612175, 0.024395444164318696, 0.04447850990774376, 0.048281508697462935, 0.04041929629498294, 0.04878331248515418, 0.020959190159503902, 0.056962146290710995, 0.06575201105858598, 0.0416259995794722, 0.041861193387636116, 0.012715962532508587, 0.025743571110069752, 0.03262743101056133, 0.024751469792265977, 0.02199396115195538, 0.030973488331905434, 0.051330933280821354, 0.01061251330455499, 0.02998213509895972, 0.031459044598575146, 0.04989601152815989, 0.05191153194755316, 0.025512728407712917, 0.038222810586116145, 0.03762515015634043, 0.031082342312272106, 0.051551345203604014, 0.008260603212485356, 0.02775271499662527, 0.03188770570393119, 0.04191470265920673, 0.0522934555608247, 0.028926622987325703, 0.004593701160047203, 0.02956599635737283, 0.03372294954689486, 0.04318142915144563, 0.02928501839882561, 0.0682877574914268, 0.07235375645437411, 0.053919018512325625, 0.14953769158039773, 0.03809794996465955, 0.06638707233858959, 0.047613796312361956, 0.028058719022997787, 0.017512278065883687, 0.013019785068796148, 0.03703858038144452, 0.013892851836447204, 0.021259694659550275, 0.0320135094890637, 0.05457822885364294, 0.026985580267916833, 0.032428487935768704, 0.019252535487924303, 0.029637276461081843, 0.02322954119050077, 0.043487441659505875, 0.009959305453646396, 0.021669336428333606, 0.03420849563553929, 0.0614245454115527, 0.022137827539284314, 0.015051770988585693, 0.0674100588741047, 0.02896062098443508, 0.021339266461187174, 0.024773325405216644, 0.03444250540009566, 0.03932989814451762, 0.0190768763422966, 0.04350002509142671, 0.047684994991868734, 0.039139480862234316, 0.04253321107743042, 0.03577893440212522, 0.025654313221041645, 0.010361235671942788, 0.03508577695382493, 0.017691709866215075, 0.019298585963302424, 0.01763943043936576, 0.012713999869967145, 0.011091949185356498, 0.05418833923925247, 0.05580563424155116, 0.05784988722630909, 0.014702771590756518, 0.02965496586901801, 0.034726658902530155, 0.03344039060175419, 0.15255045491669858, 0.032247380153941255, 0.011313272889570465, 0.02685941007387425, 0.025904494171429957, 0.011632704275793262, 0.04006880920912538, 0.04414374787094338, 0.06831048162920134, 0.03555264975875616, 0.0511322073372347, 0.04681136758465852, 0.02118334929192705, 0.024277316306584647, 0.030320574795561175, 0.03661086583243949, 0.055955956889582534, 0.02174375136382878, 0.005835055955685675, 0.04941163251974753, 0.01585806566955788, 0.05300870271665709, 0.004100364641219909, 0.08060082713408129, 0.04032931576615997, 0.021097022674179504, 0.025866867708308355, 0.0780440800424133, 0.03911567785378013, 0.038774853106588125, 0.017201934808066914, 0.007460070990159043, 0.030211211913930516, 0.04044959966891578, 0.019132592549015368, 0.04397078250933971, 0.04491323033081634, 0.03878539754077792, 0.04125764327389853, 0.048240348763231716, 0.04484400958088892, 0.04171268242810454, 0.09331624768674374, 0.0381257393663483, 0.030533909598099332, 0.04286220556657229, 0.014347349858975835, 0.029621225715215718, 0.03548979027462857, 0.030956545312489783, 0.0225097648134189, 0.022475084888615778, 0.045092536602169275, 0.022305892181715796, 0.016255510771381, 0.0646009985357523, 0.008942317167696143, 0.023155272140034606, 0.042309762710439305, 0.021545591996982694, 0.02286549867130816, 0.03372541941436274, 0.02015504304186574, 0.13446149842015334, 0.104420140784766, 0.07775846429701362, 0.11143542613301959, 0.16382545419037342, 0.18613510206341743, 0.1753194574266672, 0.11616771934287888, 0.1984457221946546, 0.07610410771199635, 0.10737792242850576, 0.12593358888157777, 0.09132110367396049, 0.16973237294171536, 0.11906627166484084, 0.09095947165042162, 0.17500874267092772, 0.117670742262687, 0.11886337612356458, 0.20957292297056743, 0.13987954626125948, 0.10229382238217763, 0.09499102817582232, 0.14148700929113797, 0.12070033326745033, 0.09134698299957172, 0.15216827685279505, 0.10934269521385431, 0.1135732117774231, 0.1217951766614403, 0.11247709273759808, 0.05027051875367761, 0.10593980138323136, 0.20155402326158114, 0.0994338651320764, 0.11315596023840563, 0.13769531489482947, 0.12239524589053222, 0.11870586100433554, 0.14066379703581333, 0.09702334233692714, 0.1397613047489098, 0.14539801728512558, 0.15518394431897573, 0.13552308002752916, 0.13675132340618543, 0.1129935257402914, 0.18093882660780633, 0.07765324387167181, 0.08795027062296867, 0.13711337612143584, 0.17605524723018917, 0.28965321875044275, 0.12726068124175072, 0.15682591763990267, 0.15538682628955158, 0.10962419903704099, 0.07430237332092864, 0.10140158275940589, 0.1846002558512347, 0.12986131597842487, 0.05749904390956674, 0.19503775292209216, 0.12015413971883909, 0.1914535273930856, 0.11706666967698506, 0.1266986099737031, 0.12961675838700362, 0.07776501894529377, 0.09002958011946507, 0.16683304708983215, 0.07117310552192585, 0.09347739296832255, 0.21284525309290203, 0.0884166955947876, 0.0921322244352528, 0.15880702276315006, 0.15510577708482742, 0.13716251562748635, 0.13261635814394268, 0.1310161825801645, 0.07734916518841471, 0.19907563339386666, 0.139428564746465, 0.18738812554095471, 0.09666017003889595, 0.1432756276002952, 0.16311856997864588, 0.09382791058825594, 0.13710843638650008, 0.17465092401419366, 0.09234218352607318, 0.07861014109637056, 0.1307129588510309, 0.09742114706231014, 0.0758756585419178, 0.06616524567029305, 0.1318618543446064, 0.11541468117918287, 0.10392713081091642, 0.2767537795007229, 0.14224291087261268, 0.12355590718133108, 0.1579303690897567, 0.08098858275583812, 0.09218122823429958, 0.12445236050656863, 0.19988987541624478, 0.19994748303932802, 0.07580851071647235, 0.1154277633343424, 0.0672985619998404, 0.12068221638245241, 0.15854578678097042, 0.15713873585419996, 0.09525902236678771, 0.10154609036232744, 0.08335362334868737, 0.08157876572970833, 0.12348475599927561, 0.11868862621486187, 0.1297914675836052, 0.11593538895249367, 0.15029142184981278, 0.1258680966815778, 0.12011949372078691, 0.13263566925057343, 0.1984577186937843, 0.15975636110774108, 0.1978383654994624, 0.11635224015585013, 0.07872797548770905, 0.11849440235112395, 0.10389439828161683, 0.10059066555861916, 0.07926696977977242, 0.12400656299931662, 0.14978657822523797, 0.08746543021074363, 0.10917247791907617, 0.18938508124223777, 0.12669403664767742, 0.13463755111609185, 0.08036179960306201, 0.1483383130814348, 0.07946910536182777, 0.11357384281499044, 0.10432880997125592, 0.11703658343425818, 0.22124604588108404, 0.1621199157088995, 0.10963204968720675, 0.19800623506307602, 0.1314892979072673, 0.09848006881241288, 0.2079716617507594, 0.10294727196118661, 0.13210479702268327, 0.11080368288925715, 0.1703969029975789, 0.1274996069925172, 0.04793347451569779, 0.06674721158508744, 0.09218417307628052, 0.11864305580300943, 0.13471421200249875, 0.13010799059910433, 0.15668273318026746, 0.08529605197587184, 0.12152003071137837, 0.07892046230179922, 0.09768601999218975, 0.12769917771220207, 0.22420767481837953, 0.14967862330377102, 0.11021191214344331], [0.07981814377542053, 0.05129680296938334, 0.014251140378681677, 0.044029587746730874, 0.038007111089037995, 0.021710252089958106, 0.09055378234812192, 0.04014432676402586, 0.0269574821327946, 0.014233927641596113, 0.04736604282100286, 0.02186261203938297, 0.0027227462310942686, 0.01594570016355387, 0.08564671208815915, 0.037874338749263964, 0.06361196589257036, 0.025323642750403712, 0.034582551635269604, 0.050710389257541726, 0.0619713089295796, 0.07189776735114199, 0.004456604855866837, 0.08033445464181048, 0.07411846997482435, 0.016181886329182556, 0.03308764399428453, 0.012133913497174425, 0.019742015383339355, 0.03864979910265122, 0.06961911105151687, 0.036209651468587775, 0.025255237938836217, 0.03174276044592261, 0.06166349830371993, 0.049591393409562964, 0.04784778572086777, 0.01160253067168274, 0.011112832796892949, 0.04619478959856289, 0.038114567287266254, 0.1141507061464446, 0.022960861679166555, 0.005544232029933482, 0.03284731028335435, 0.01619936878393803, 0.07577313190060002, 0.0011774841883119994, 0.020279594929888844, 0.015414573485031724, 0.04205835870067988, 0.023055590256782513, 0.019812732302982892, 0.040568387401955466, 0.05250640020572713, 0.03450020801808153, 0.08664603810757399, 0.05867508758923837, 0.03899125488741057, 0.0041131957384225514, 0.029455846375120536, 0.01952255849859544, 0.019825994269922376, 0.001955852170275258, 0.08090950628476483, 0.027561929609094347, 0.029745981163744415, 0.015674494805612733, 0.020119789754971862, 0.06991440270628248, 0.01271841034758836, 0.02966669773949044, 0.05700454794402633, 0.04406480032152363, 0.01293368830478617, 0.17103792860039643, 0.0694221459063036, 0.07166839537343808, 0.03275404225236603, 0.07445073500275612, 0.058161959052085876, 0.09882218616881541, 0.08811654562928847, 0.03255909574883325, 0.13865636475384235, 0.02342960045539907, 0.005769291917593884, 0.08240632060915232, 0.0319427756060447, 0.014263532124459743, 0.0269953596538731, 0.023526836219908934, 0.010168318836284536, 0.032334035861172845, 0.051406681537628174, 0.11307343680943761, 0.019205811566540172, 0.018452900628160154, 0.006384622247423977, 0.030748638790100813, 0.058517755674464364, 0.02024593111127615, 0.09606833143958024, 0.04356153768354228, 0.070613063073584, 0.04965796787291765, 0.06450808673564877, 0.018643838686070273, 0.012114050232672265, 0.02788478335631745, 0.07287474921239273, 0.06613122392445803, 0.014549940059493695, 0.061778319999575615, 0.034684528663222275, 0.02117293717206589, 0.05259454868999975, 0.020019693965358392, 0.030596382317266295, 0.02290531001718981, 0.006580465689434537, 0.030069133466375724, 0.03317738025050078, 0.06291369907557964, 0.05296275232519422, 0.024294503598607013, 0.010031761967443993, 0.05227515547137175, 0.022287697265190736, 0.07880587809320007, 0.022435115783342292, 0.008719116465986838, 0.03381506067567638, 0.03295785042324236, 0.034191284594791274, 0.02198699429365141, 0.027879409358969758, 0.07748522503035409, 0.022884853882715106, 0.03546814500753369, 0.044957223148750405, 0.04641509634841766, 0.01816447914045836, 0.037402668701750894, 0.055856714357755015, 0.02212031963946564, 0.045979459903069904, 0.03536476680476751, 0.046368426709835014, 0.027279949115057076, 0.01949224155396223, 0.023522946517914534, 0.018042683800948516, 0.015998520722080554, 0.019164607527532747, 0.033576837208654196, 0.0386436312193317, 0.036304120506559096, 0.016609577129461935, 0.04256316500582865, 0.04945273817117725, 0.031140323129615614, 0.10248467392687287, 0.08299243237291064, 0.012243742871630405, 0.038937138326998265, 0.0317244433930942, 0.06642154870288712, 0.038137691760701795, 0.014747010377634848, 0.040926070351685793, 0.013431692296372992, 0.04260185846526708, 0.051513337064534426, 0.0359410533814558, 0.07668013644537755, 0.07890421817345278, 0.060620338922100406, 0.016027682460844517, 0.03262957178854516, 0.03460393227370722, 0.016007136420479844, 0.08526542969048023, 0.052937151198940616, 0.06681310412074838, 0.034582856976028, 0.019526261603459716, 0.06356790182845933, 0.004832766434576894, 0.051460692925112586, 0.02223793350692306, 0.040700257290154696, 0.050223394496632476, 0.024571305174114447, 0.026073223778179715, 0.02883165522611567, 0.07614017184823751, 0.04551338776946068, 0.02587836209152426, 0.0636075214881982, 0.01617951484929238, 0.00746959846998964, 0.004413795233371535, 0.029486794357321093, 0.01833212818019092, 0.0192526881583035, 0.04887262126430869, 0.013022489879014236, 0.024549047529165233, 0.03321415684851153, 0.057307527400553226, 0.02745018676588578, 0.029690571994121586, 0.0357734213050987, 0.012084566189774444, 0.024900143600202033, 0.044638759523097954, 0.033143962400832346, 0.032223214129252095, 0.04360928958547967, 0.04516478022560477, 0.024573400150984526, 0.009493260461437916, 0.03232702659443021, 0.053017048697386465, 0.007947104766831865, 0.03883223342044013, 0.03370951455352562, 0.010020214997764145, 0.020314325744818364, 0.037591732306671996, 0.035120999706642966, 0.025662735536960617, 0.04539144824125937, 0.03135094379207917, 0.04871763368802411, 0.0018421169786181832, 0.029399500827171972, 0.013327843359937626, 0.007275810565001198, 0.07907318017844643, 0.025143532415053675, 0.021186935349500606, 0.009301867785065301, 0.022186101913186054, 0.05206950847059488, 0.05500309694824474, 0.07678973342158965, 0.062078856730035374, 0.017405963502824306, 0.022078667767345905, 0.10192891981984888, 0.04047857311421207, 0.01847643222260688, 0.027042694256774018, 0.05915076099336147, 0.01666901001174535, 0.01145095527837319, 0.04678283518712435, 0.0550851487953748, 0.056264446050460847, 0.042830840285335264, 0.008240027486213615, 0.026695031572931578, 0.030678790395281146, 0.05058165420112865, 0.0894773815359388, 0.0384107410375561, 0.012600506406410463, 0.019611646753868887, 0.07925596394176994, 0.0035433556684958084, 0.026942344016528556, 0.0075432415719011, 0.029937480709382465, 0.021153675259224007, 0.02523962315171957, 0.025422569763447558, 0.005673769878090492, 0.04954289511910506, 0.012427719160249191, 0.02824161304826183, 0.06999509409070015, 0.030075026543012688, 0.02897045974220548, 0.01639879701126899, 0.029171360390526906, 0.02361898127544139, 0.05111110150547964, 0.06377482786774635, 0.016148600793842758, 0.020486828006271805, 0.03976520550038133, 0.002067787971879755, 0.04616641326408301, 0.019597428052553108, 0.02794405847920903, 0.004182135320401618, 0.01821602405314999, 0.013272671677571322, 0.01147387025412172, 0.03810459282249212, 0.02715785352380148, 0.030159775566841875, 0.024207766467173184, 0.05200672023264425, 0.07458713411220483, 0.018645769118198326, 0.0496413268015853, 0.024037460962842618, 0.016232118276613097, 0.03529493198064821, 0.03352229656385524, 0.07161465539996113, 0.026529874453055005, 0.02733142956692193, 0.035003477441413064, 0.023802548746711442, 0.020849330250972083, 0.048948671469198804, 0.009640515283016222, 0.06141196537230696, 0.06372765611324992, 0.041482268899146996, 0.04948207802538361, 0.02855757118335792, 0.08232356647827796, 0.05342642244483743, 0.02361735448773418, 0.06547218321689538, 0.03354058647528291, 0.018827906576916575, 0.03149490178163562, 0.012772617662059409, 0.04018423140847257, 0.01630718121305108, 0.05406459480790155, 0.01775540564475315, 0.07270309342337505, 0.04677755957735436, 0.03649429690891078, 0.007397628805067922, 0.03578866120161755, 0.03080806488703404, 0.049697726632335355, 0.00862852780015341, 0.04026284986840827, 0.03184984005721552, 0.04731580748089722, 0.03245488294799413, 0.0396374543197453, 0.06564951834401914, 0.19510386937430926, 0.16225562271262917, 0.10207456736160175, 0.16837674139865808, 0.09392754667039428, 0.11080944365156548, 0.2627991640142032, 0.17916799948683806, 0.29211342387965744, 0.13499592617154121, 0.10839615921889033, 0.16622484901121684, 0.0945049256884626, 0.14812119544616767, 0.12202810416264193, 0.1181890887341329, 0.11936618414308343, 0.08720944608960833, 0.12120405052389417, 0.1283578723669052, 0.13894577350999626, 0.15383144760770456, 0.0735206806233951, 0.159553180581757, 0.10934415406414441, 0.08453209618372576, 0.13990181578057154, 0.1344876627304724, 0.07540666870772839, 0.08208799947585378, 0.12380167256508555, 0.09213115234992333, 0.11181163308875901, 0.12133823760918208, 0.15167115495673247, 0.13942662413631166, 0.13834052027336188, 0.13787526238177503, 0.07635277044028044, 0.11156077869236469, 0.12531359786433832, 0.1448855876390423, 0.08309866381543023, 0.2073032097624881, 0.09733648624803339, 0.0730573090591601, 0.09639561602047511, 0.12008178074445043, 0.08979353135717766, 0.08103122868176017, 0.17357632810516016, 0.07358343154191971, 0.09856135730764695, 0.13916437035160406, 0.24568547947066172, 0.13172352819570474, 0.25193383704338757, 0.1326564188514437, 0.09583971263574702, 0.1706487616258008, 0.10987983031996659, 0.14722091518342495, 0.15183332482618944, 0.10039355792105198, 0.1965357003999608, 0.13766313876424516, 0.116713872179389, 0.08285435728196587, 0.06780898996761867, 0.12466385987188135, 0.18234158919325896, 0.22420479782990047, 0.1180484691368682, 0.12603515200316906, 0.13376226808343614, 0.20932983101478644, 0.14238517252462252, 0.14510901564998285, 0.09917816599564892, 0.1869408759687628, 0.14756977717791284, 0.23309393227100372, 0.13066623492964677, 0.1440003572830132, 0.30886498785444666, 0.09506665768900088, 0.08903604200375931, 0.14200436510145664, 0.15050670744052955, 0.1633551615689482, 0.17066968764577592, 0.10976990086159535, 0.11121108888515405, 0.1205728365374463, 0.11306875491780893, 0.1874090787023306, 0.08838088930185352, 0.14365905416863306, 0.07532489845263106, 0.08510378229298762, 0.15047031082212925, 0.09076897294393607, 0.12742760085633822, 0.17770859279802867, 0.1349671155746494, 0.16651598124631814, 0.1698604803532362, 0.1345184410789183, 0.1650493142328092, 0.09655080376459019, 0.16000988893210888, 0.1106567189895681, 0.14330698948885712, 0.15034991156842026, 0.12075191549956799, 0.1365202008081334, 0.15937657148710319, 0.07563209839697395, 0.084530976600945, 0.1046131161440696, 0.14708488248288631, 0.07370612424399171, 0.12170901628477232, 0.10290155905698027, 0.18100157752633095, 0.11762789956160954, 0.0737465445750526, 0.13096804730594158, 0.12237963958510331, 0.1391655917146376, 0.14716679523033754, 0.10608368473393576, 0.0681372991363917, 0.12636505572923593, 0.18720854446291924, 0.14770051730530603, 0.10913225436317069, 0.12499430642596313, 0.12848908746881144, 0.10865036557827677, 0.09687130299529859, 0.0953997437443052, 0.1697478842522417, 0.17313951440155506, 0.09748788098139421, 0.20227644592523575, 0.1131680313763874, 0.15187335839228971, 0.13918887903647764, 0.12674145267478057, 0.17363264651170798, 0.11935091710516385, 0.11441150786621229, 0.15978678661797727, 0.11161383334547281, 0.12343864275940827, 0.15660755150020123, 0.12125918827950954, 0.19311779737472534, 0.07456969576222555, 0.18159146873014315, 0.08558998656060014, 0.19702269855354512, 0.10444937207336936, 0.10286896902003459, 0.10203719365277461, 0.12536459655633994, 0.17663447186350822, 0.11845237389206886, 0.07794274083737816, 0.13485613438699925, 0.1155594534107617, 0.11268431054694311, 0.16245792114308902, 0.12162977696529456, 0.3068153778357165], [0.02180830209649035, 0.008881778273332332, 0.023480081764448966, 0.016897381150296757, 0.06401235583637442, 0.04144283922921334, 0.045629016921988556, 0.006229327634043459, 0.030705202370882034, 0.0586189456017954, 0.031884061970881054, 0.05942046509257384, 0.024114534059273343, 0.06517874396273068, 0.01731837820261717, 0.020797491871884892, 0.02781571018775659, 0.0480237807413297, 0.02212298458575138, 0.009741382906213403, 0.02394163315849645, 0.051801694091409445, 0.03381791730810489, 0.018409226721684848, 0.026493683091497848, 0.06829055305570364, 0.05693068940724645, 0.018551391682454517, 0.021782083503369774, 0.03167393324630601, 0.038146254872637134, 0.04348970118111797, 0.06180060308958803, 0.016660718313817467, 0.015756707804809724, 0.028272420234446014, 0.0010576255361749126, 0.04346153519249388, 0.0691139078033822, 0.015720385825261474, 0.04347359275977526, 0.03435822117275425, 0.02786181664227375, 0.02967156283557415, 0.09787985709096704, 0.04213835119402834, 0.024942161881231835, 0.010171062662266195, 0.035816138477197716, 0.02176163245790771, 0.013177331570269806, 0.04723003386918988, 0.010712531062641313, 0.007956853618712297, 0.05994517622249467, 0.007091011128587914, 0.026970026548951864, 0.03392396554616945, 0.006072388421411493, 0.043306822422891855, 0.04199105141950505, 0.017279696617541567, 0.01950715745000967, 0.02184699894860387, 0.01298505679837295, 0.10153484703706843, 0.02369014942087233, 0.018508169001766613, 0.032138017272310596, 0.022748989119593586, 0.03192480799875089, 0.030876043917877332, 0.00582532788394019, 0.04126129039962377, 0.07664079498499632, 0.03661995480901428, 0.09252736251801252, 0.02484389135081853, 0.022487269681213156, 0.06963141967675515, 0.031809233129024506, 0.031983830367348025, 0.01819423459736364, 0.01778362930885383, 0.04526942728885582, 0.05676239915192127, 0.025695669930428267, 0.03203700376408441, 0.04522796201386622, 0.04408488156540053, 0.01918371337732034, 0.036372330239308734, 0.005375107600619751, 0.028997502755373716, 0.0772510761661189, 0.010838339936786463, 0.0680525568979127, 0.025444016559049487, 0.0588368774790849, 0.030839956032910516, 0.0037773667053053422, 0.01942677140635039, 0.04998220243890371, 0.032004929413752894, 0.02584069830897663, 0.04983987293339201, 0.02824456976460559, 0.031168054855827774, 0.026340364711359143, 0.028441914889429296, 0.02792905267727162, 0.038639631255396774, 0.0342431823456926, 0.09385866858065128, 0.010820069533240582, 0.05384576726438744, 0.04049095298562731, 0.05570190998592547, 0.02557679059516106, 0.07435242206390415, 0.0020723557848084185, 0.029886227566748857, 0.039398243584270985, 0.015022778883576393, 0.04784141427704266, 0.04558096985731806, 0.04374241815613849, 0.03155829052307776, 0.035160639722432406, 0.030250614442463433, 0.030774104209350686, 0.011844723568564015, 0.007136904268658587, 0.08694513634379421, 0.03689170129863279, 0.07391172713999238, 0.0372531094056155, 0.03221983841753431, 0.025816369435882995, 0.04647043087918844, 0.0341829895041883, 0.00445289199706167, 0.046214222841496976, 0.06516170594841242, 0.013958433094168348, 0.053178584136601, 0.03632813725354416, 0.05870399996638298, 0.04006557259708643, 0.06445798370987177, 0.03364862960630229, 0.02579733313593481, 0.04661595628463796, 0.0026985028110045406, 0.045085988739239316, 0.04571499748687659, 0.11159690389675753, 0.0250506189186126, 0.043922654020466974, 0.015346602935876166, 0.01859426831028291, 0.021290459437295794, 0.053414252919277976, 0.01809636440261134, 0.029088029504886696, 0.020302714314311743, 0.02939014382926481, 0.07264642217861754, 0.01755557199274855, 0.0545130860991776, 0.11297376680054835, 0.016791935112061243, 0.028007889964750836, 0.027844478376209736, 0.019198047429589287, 0.04212489245193345, 0.05227166101602571, 0.030716038575129848, 0.009547496613647257, 0.026092436497232745, 0.13091176961149487, 0.03555379309026258, 0.07585429825953074, 0.004597879239424531, 0.05829040573111602, 0.05896438777978931, 0.050257755509976826, 0.05366098182275891, 0.04119748775182026, 0.04501307336613536, 0.029140860241438662, 0.030172620234744887, 0.01101822974825544, 0.01865243911743164, 0.02459470784690763, 0.04460032729964171, 0.029043358151933978, 0.03356034202235086, 0.06074207488979612, 0.05108017387932964, 0.006799210536493254, 0.04467809419812901, 0.04421023412474564, 0.07522274500557355, 0.056923714067254744, 0.07369450093912226, 0.03546837231676493, 0.04361567799268024, 0.06518981086888484, 0.032588815582650046, 0.04086367566404598, 0.008717304777487047, 0.0479669500408428, 0.06542075026248183, 0.06677281271134104, 0.03849963930302432, 0.016823568414630632, 0.04744223891092198, 0.019398498548460857, 0.03938497143930622, 0.011359923868440092, 0.024946204253605435, 0.0489785948635212, 0.03751216729038528, 0.04482779598661831, 0.008797726444234806, 0.0587350158020854, 0.010950488204668676, 0.0024399109949756947, 0.01688515903827335, 0.0670755003978099, 0.033432919931198866, 0.015790286806545088, 0.02760407850811524, 0.07092426637453692, 0.019432633948911513, 0.02067150827497244, 0.015595891612714954, 0.04974721219124539, 0.03071232359590275, 0.05919451293136392, 0.017194328430507864, 0.034220543024795394, 0.04148131895012089, 0.0034363146488820867, 0.05081287179408329, 0.011358000221662223, 0.030316347522394996, 0.03417554936770882, 0.0322786334769002, 0.06512297516954796, 0.10591245642197983, 0.030224582446472983, 0.07710914021091801, 0.002414163771650887, 0.05425939542640533, 0.050844708657158275, 0.02354044932872057, 0.03465019479127867, 0.0957911227430616, 0.02491296621571694, 0.03177948954648205, 0.044989307677107196, 0.032057010369109254, 0.03639774476843221, 0.026886071411094496, 0.04324318601616791, 0.017625501811770455, 0.015294479572081139, 0.04921593623501914, 0.00678785822154688, 0.06406674720346928, 0.034722954101328335, 0.04831345073346581, 0.01874325254799, 0.05615875743595617, 0.03509687778673001, 0.05517560429871082, 0.046017607141818316, 0.015835115918889642, 0.04566819553396531, 0.033040472239788087, 0.028682523407042027, 0.011525037731709225, 0.02560630686847227, 0.03853755923254149, 0.01931928806672139, 0.015415136669097202, 0.07630382770938532, 0.023970135021954775, 0.01688896901240306, 0.013485427180837308, 0.03237766566287194, 0.03854726228330817, 0.07046183118862764, 0.014291331704173769, 0.05374561549563493, 0.015128684629287039, 0.027079374163544605, 0.011861971080569285, 0.030579965162490095, 0.028835336278591837, 0.07810520926224333, 0.017068572142826657, 0.05382170980530126, 0.030005500452326875, 0.024901663518643806, 0.060235969190086634, 0.052831886668822596, 0.03549216853986893, 0.03073509523112859, 0.06075831901814256, 0.021665589218693118, 0.029127208116863455, 0.04946942673996091, 0.021406931669584343, 0.0306072728043156, 0.04789945276986275, 0.049591430728988986, 0.038730812791202746, 0.039525404439440796, 0.016081093344837427, 0.03487543449071901, 0.03566932385521276, 0.055726937750088315, 0.020687177344890575, 0.02081800059282354, 0.05318424990400672, 0.06897898111492395, 0.033557023986109664, 0.06106507112937314, 0.03259894611047847, 0.0964549064104046, 0.018751461125378097, 0.05311499862000346, 0.0416396550967225, 0.02163348433428577, 0.011615881696343422, 0.044258030131459236, 0.014978456976158279, 0.02274254473325397, 0.019793631542207937, 0.01894796486677868, 0.07023557368665934, 0.007660336360069258, 0.07456301897764206, 0.08945964463055134, 0.020528121951169202, 0.019542829732277563, 0.04646721123052495, 0.03754798036866954, 0.060735486314765046, 0.1684084018426282, 0.10349315338368927, 0.12737763353756495, 0.10793677065521479, 0.238275551370212, 0.09280244061457259, 0.1059339591967208, 0.12334408211920943, 0.12829128094017506, 0.25635039433836937, 0.07141682851527419, 0.11654151071395193, 0.128001139366201, 0.16460392384656838, 0.18878856753664358, 0.13398238484348568, 0.1101675902360252, 0.13061554836375372, 0.1236585152468511, 0.13415602195475781, 0.1418280138501099, 0.09215500285582882, 0.15158172404127462, 0.1647551693022251, 0.08490922594709055, 0.16495490287031445, 0.3427183212978499, 0.08513269467013222, 0.16028286357011112, 0.19375099268342766, 0.24837660363742284, 0.0913802312154855, 0.13584869541227818, 0.1646398997732571, 0.11664231387632233, 0.091552280554814, 0.12561283180756228, 0.25270229152270723, 0.1511163575840848, 0.08328007015266589, 0.1171666043145316, 0.10773297266236373, 0.13786066030817373, 0.14594875701836177, 0.16521775376583847, 0.10080813603209597, 0.20642310913119996, 0.08513485241149153, 0.07803768145718745, 0.07446839726929154, 0.12312859296798706, 0.12317086569964886, 0.1058482127264142, 0.031132950846638, 0.15852093882858753, 0.14461751202387468, 0.1089412806821721, 0.11805662512779236, 0.2033200870667185, 0.11631918192974158, 0.10118367123816695, 0.13781903897012981, 0.17909391703350203, 0.1198404665504183, 0.0734838293865323, 0.1578327686126743, 0.15032891769494328, 0.11428600602916308, 0.0711134419377361, 0.12295639435095446, 0.07880437853080885, 0.1373115490589823, 0.09875345057142632, 0.08895347786269017, 0.14166017142789705, 0.11693221117768969, 0.1903186911450965, 0.11850927583873272, 0.06584079058042594, 0.1359444638448102, 0.1780762637832335, 0.07799863855221442, 0.101772829624159, 0.16512866211788996, 0.1596005694674594, 0.07801691150026661, 0.1181102158235652, 0.06783457073782172, 0.1347382864249604, 0.07187510428151914, 0.12560059103582585, 0.14521139301359653, 0.11879974310951573, 0.12390357495418616, 0.09575771167874336, 0.11873286669807774, 0.1518235539219209, 0.10807380080223083, 0.10067215082900864, 0.11913077320371356, 0.09904937326375927, 0.10291747748851776, 0.08657768927514553, 0.10183631336050374, 0.13355557274605545, 0.10851796982543808, 0.17235363514295646, 0.12078816284026418, 0.13892594671675138, 0.12080625258386135, 0.06140070169099739, 0.11366766385201897, 0.21761245014412062, 0.14252480146075996, 0.12075224119637694, 0.12691903885986122, 0.15695614208068165, 0.18597534777862684, 0.23454743570515088, 0.12259531872613089, 0.13641187947775635, 0.1553265316677945, 0.09900976717472076, 0.18784811800079687, 0.11283015486385141, 0.15783826474632534, 0.1128828227519989, 0.11935378052294254, 0.13913456909358501, 0.10429951082915068, 0.13918480782636575, 0.08709350481097188, 0.11025668866932392, 0.19283262267708778, 0.11320668751639978, 0.18443622679582664, 0.1272411122918129, 0.08576108595090252, 0.13436815914298805, 0.07859399874827691, 0.09316478509988103, 0.09932329106543746, 0.12523857903267654, 0.11670609616807529, 0.12554857454129628, 0.12134780495294503, 0.08124681961323534, 0.12946838991982595, 0.2706495699073587, 0.15348966951881135, 0.16142764714147362, 0.09485876812998738, 0.1645985362785203, 0.11543984125767436, 0.14910166497741426, 0.10679075893546854, 0.20958690079195158, 0.0644396971911192, 0.06910003176225082, 0.09425883460789919, 0.09900883079639503, 0.16108721255191735, 0.11674148855464798, 0.16272796450981072, 0.14700212835201196, 0.057879247436566014, 0.1073064659056919, 0.15072006599179336, 0.0558394999243319, 0.20107918445553097, 0.20551564996795996, 0.14204175238098415, 0.1342346505927188, 0.21736420132219791, 0.11193893982895783, 0.12346506491303444], [0.01805244791986687, 0.010017543266128217, 0.03142591512628964, 0.019968776697559015, 0.04811369002397571, 0.02426290083011346, 0.02669844969308802, 0.029178702139428685, 0.015738838585093617, 0.14066439414662973, 0.03528968011960387, 0.06378888711333275, 0.023085584897281866, 0.05968638975173235, 0.029662914906761477, 0.014655297888176782, 0.03340769539188061, 0.030946964398026466, 0.011543072344336127, 0.031233343495322124, 0.008968143058674676, 0.01594622093918068, 0.03649063281981008, 0.02694438979960978, 0.031134002575916902, 0.026483040269730345, 0.07345760400806155, 0.031797616609505246, 0.021370533354846493, 0.034510660850043805, 0.04251027320112501, 0.05156853588830147, 0.03337924102587359, 0.026297822262027433, 0.038578101699905734, 0.02852134419871228, 0.022168110557166592, 0.03260212504704084, 0.012464551737398973, 0.037185042165219784, 0.02068896358832717, 0.026296164940244386, 0.03210941702127457, 0.01165325625333935, 0.006551005395262369, 0.07318718744707958, 0.00677262807896893, 0.03600140907136457, 0.06570996902883053, 0.049266029082770856, 0.028754057961383035, 0.04954341080571924, 0.032820379228464196, 0.08193107468209096, 0.01654491274218474, 0.008150262392259069, 0.029622752419007675, 0.0529090971685946, 0.010769181103179497, 0.00626734086212569, 0.022796591743826866, 0.06473874792988811, 0.055862963665276766, 0.029785526184631244, 0.02465346728318504, 0.03682574430214507, 0.06842631434223481, 0.015058685260425721, 0.03317671189350741, 0.029212001245468855, 0.018974305596202612, 0.05926535198731082, 0.016330602545557276, 0.0201738130168191, 0.010644147455293154, 0.04438756246651922, 0.03443885488169534, 0.02665840255628739, 0.004268340650014579, 0.027198275551199913, 0.05532471236905881, 0.0694091926727976, 0.03371311418179955, 0.023557846966598715, 0.020944552462814108, 0.029690633062273264, 0.02988852440778698, 0.013636486887532686, 0.03367539102743779, 0.06019766588828393, 0.023227027218256677, 0.02931707239310656, 0.08046724394495998, 0.018682257338826145, 0.03561999435935702, 0.06622951650725943, 0.015903329044314365, 0.05497914805476155, 0.0032273661511551055, 0.04397411411628127, 0.056577776558697224, 0.04803619793217097, 0.02121815474570862, 0.08322217075952462, 0.01709517919724541, 0.04105362475716642, 0.025184020599616424, 0.028644566158098832, 0.062042039419923506, 0.026183037885597775, 0.023026230046525598, 0.01118161334722702, 0.05159254924261144, 0.024259723589888642, 0.049164415071053166, 0.013422784827915686, 0.006297227785190833, 0.03333624904709203, 0.05309267142521484, 0.01837670453824103, 0.060158602627260346, 0.057184882195932527, 0.0672234549586262, 0.01092227641493082, 0.04224559026105063, 0.021115755329706838, 0.0247541194715138, 0.02771486122427242, 0.0486788825531091, 0.02786673093214631, 0.037018336289163144, 0.006764153600670397, 0.039065700356981585, 0.021267238272620097, 0.024721846649689332, 0.05861533579549619, 0.04395088446991784, 0.02870906769697155, 0.011530089424923062, 0.020573468446465473, 0.02790794175650392, 0.028931325235004936, 0.04268592895407762, 0.017049430669950585, 0.017085350617500286, 0.0471807213367096, 0.02398536304411079, 0.015831494238227606, 0.0662739605509809, 0.016580518867288317, 0.02603149726720793, 0.011555768582703812, 0.031715585118425746, 0.004665979982486793, 0.01008559184681092, 0.027900121640414, 0.025748302195487276, 0.01913071809602635, 0.015050900767424276, 0.060211711563169956, 0.038690216041037014, 0.06670588880245175, 0.053477668802120855, 0.10160166916570493, 0.016337791624079858, 0.055955939926207066, 0.039982574193605354, 0.02001344974684928, 0.029995095117815902, 0.034646907289113314, 0.018882131702931862, 0.05705990283084767, 0.06613986846059561, 0.06859971396625042, 0.08430418984166213, 0.051446901700858555, 0.02488215054784502, 0.027515132745195712, 0.0936514236299055, 0.018878762776564275, 0.01506307368565883, 0.007460646896756121, 0.02570854004339448, 0.06813781482300588, 0.017260173468717506, 0.04753740344728742, 0.021591525425070097, 0.018747571423383694, 0.054447356411921125, 0.0419029707887343, 0.01879575758773301, 0.023884505598938892, 0.042388879893613715, 0.07313715906015464, 0.019877120187239986, 0.016006664838641882, 0.019015870955107466, 0.07746220912252154, 0.030225881841033697, 0.022617224404322248, 0.03757055862141507, 0.07655670414013521, 0.06747584284416266, 0.03909454827329942, 0.017866176486547505, 0.02433699685414987, 0.004315980169589498, 0.0622777489147016, 0.04278797383553215, 0.06196322079215731, 0.018655333069286177, 0.032109501838151894, 0.05011257276471172, 0.030360567649560313, 0.015867191965558698, 0.0472768595708268, 0.021065771047558104, 0.04771914226668222, 0.03909700796274202, 0.04015743945326124, 0.02056847951774086, 0.07178175821900368, 0.018888947587194185, 0.02843198283309383, 0.0682006539510829, 0.03391166031360626, 0.01861424947024456, 0.028686893172562122, 0.014731091946097357, 0.025473015449408973, 0.007497083379088768, 0.005804835278208235, 0.04483293588938458, 0.023980039936889495, 0.005505562743305096, 0.012387905269861221, 0.049759500460433106, 0.04137463967448898, 0.02913351509986179, 0.010440402897074819, 0.01691421221143433, 0.0807789425764765, 0.02516499956670616, 0.03286672317023788, 0.00687090157797294, 0.05956101005098649, 0.062495083681174686, 0.12873046951634542, 0.010570970846207013, 0.016574832743832042, 0.05966304814709084, 0.02867141578878675, 0.07513585181108542, 0.013266154348717203, 0.03453630608107362, 0.01637562843305724, 0.06768976457949195, 0.012922787639711584, 0.03902028600818344, 0.04447861508067165, 0.050944134393440824, 0.030814147953476225, 0.050969766053770266, 0.046994555076318126, 0.05455608147063425, 0.020273830774905424, 0.02120310823167009, 0.03370702772268227, 0.0251187183894217, 0.031049104274383614, 0.06692820401596171, 0.015010929965813245, 0.032619943376630545, 0.04449264379218221, 0.030183310553963696, 0.05043447995558381, 0.040597008009042056, 0.016738235850685408, 0.05895870165633304, 0.13958352857402392, 0.03851509972342423, 0.04523846912862999, 0.037501819631350894, 0.026249098358675838, 0.09092768228479794, 0.08262342467371907, 0.05310258482183729, 0.004640590050257742, 0.03540143144450017, 0.018649850506335497, 0.008226008104559566, 0.034723931191755195, 0.024936087296477387, 0.03794595133513212, 0.04381272116942065, 0.032196927682629654, 0.04940771398001483, 0.01170521422422358, 0.055906359372394424, 0.031245882822466747, 0.050600816030055285, 0.03155335757349219, 0.06985544479851212, 0.019121618941426277, 0.026730658054085712, 0.02846371621957847, 0.04941228391336543, 0.012172299919516912, 0.034380049644304175, 0.047766334377229214, 0.012322349457203277, 0.019378936383873224, 0.027497460300635015, 0.02106578292192093, 0.03108227106609515, 0.01922052220574447, 0.06215549726039171, 0.041283444567982636, 0.04322238552517124, 0.03958160410236035, 0.07271530705371074, 0.05538385348128421, 0.035940330741660934, 0.03972000828278916, 0.07043462193437985, 0.09609394613653421, 0.034207579613264115, 0.04204714930217181, 0.00845888556380357, 0.07793695293366909, 0.06523186646934066, 0.05595499676253114, 0.009214093343221715, 0.053374310955405235, 0.03060574270784855, 0.033175280184618065, 0.013152400497347116, 0.04116022600127118, 0.03226154796513064, 0.05645141976752451, 0.034733583352395465, 0.016996890007119094, 0.024712387871529375, 0.028730709571391344, 0.025988425560561672, 0.025359806970560124, 0.013646523268627269, 0.027918623594034995, 0.07887412514537573, 0.08346768508532218, 0.01693001020300601, 0.02639147366530129, 0.11540675589016505, 0.1041745450347662, 0.16223855077156, 0.07436597240822655, 0.11871624259012085, 0.1979238609118121, 0.08169251534023456, 0.16306199372879096, 0.0746057191863656, 0.22415274062326976, 0.16115659954292433, 0.08714029658585787, 0.1733707727066108, 0.09667742518442017, 0.11666254779057843, 0.13106619061103889, 0.21696100224341663, 0.1803739190633808, 0.08301088852541787, 0.0944346905286823, 0.14105176978877612, 0.13096229332898343, 0.07425105571746826, 0.08747320622205734, 0.14294913012002194, 0.09303715266287327, 0.14506750287754194, 0.13079717861754553, 0.07557064348033496, 0.07891546828406197, 0.17385596595704556, 0.1797275466046163, 0.14372358284890652, 0.13580706050353392, 0.10014377560998712, 0.08876664324530534, 0.2136918476649693, 0.05476718728563615, 0.08874228383813586, 0.1529714044715677, 0.06618246010371617, 0.10908101139856236, 0.08576588997883455, 0.09785509056278638, 0.12724369072488376, 0.14420929178595543, 0.15212008729577065, 0.1424088262553726, 0.098862450436822, 0.1222192474773952, 0.09316320411328759, 0.12644215087805474, 0.08776225535465138, 0.10028999990650586, 0.1457119754382542, 0.12265545049948351, 0.06490794063678809, 0.1702659593096801, 0.09653869191450731, 0.10485124122351408, 0.12852393702736922, 0.13043755505766186, 0.11159705317446164, 0.11785329532410417, 0.12818283747349465, 0.1382336781493255, 0.1386111064680985, 0.10172537967030491, 0.14798767332519802, 0.14886689186096191, 0.09901374338993005, 0.20832102586116108, 0.07736775704792567, 0.22682984625654562, 0.17604171724191733, 0.08405744736748082, 0.1337579254593168, 0.11777701441730772, 0.1302171397422041, 0.08051070411290441, 0.180665594126497, 0.14425550002072537, 0.20251914433070592, 0.2900284214743546, 0.19237683713436127, 0.09476418034838778, 0.11081073286810092, 0.1460519486239978, 0.1380807634975229, 0.10707150958478451, 0.14418217752661022, 0.1492564795272691, 0.2135677028979574, 0.12155152830694403, 0.11320520152470895, 0.11466956830450467, 0.14247392490506172, 0.11897108677242484, 0.09934101440012455, 0.1383642554283142, 0.14578565077057906, 0.07143628889960901, 0.25325575896671837, 0.2460973502269813, 0.12028834037482738, 0.13664296136370727, 0.11889256670006684, 0.05354962744084852, 0.27266612169998033, 0.1509496686714036, 0.19979344201939447, 0.09987599176487752, 0.14700500534049102, 0.1005511341084327, 0.10844503409628357, 0.09096496099872248, 0.10370672228080885, 0.12095776945352554, 0.19187550832118305, 0.06572567711451224, 0.14227600981082233, 0.10469612811825105, 0.20331600228590624, 0.08337215414004666, 0.14760641806891986, 0.1129480367526412, 0.11520603166094848, 0.12075936581407275, 0.14946754463016987, 0.13385624518351896, 0.09445267849202667, 0.10642230084964208, 0.15162824440215314, 0.06877818224685532, 0.08527328712599617, 0.2739928476512432, 0.09970620873251132, 0.11781779437192849, 0.15234503522515297, 0.06629485942955528, 0.1358788087964058, 0.18456248859209673, 0.15245252874280724, 0.10017427575907537, 0.13050216516213758, 0.13619082633938107, 0.12692876905202866, 0.11527098103293351, 0.16534404270350933, 0.1584428801600422, 0.10057582599776131, 0.10897462389298848, 0.08511078477438007, 0.20933182590774127, 0.13366692034261568, 0.11862939010773386, 0.05631946166977286, 0.16460088400968484, 0.10104898203696523, 0.13542425818741322, 0.10572222912950174, 0.18273979425430298, 0.09710414228694779, 0.17921161571783678, 0.11260159034281969, 0.07548886643988745, 0.19023443066648074, 0.16167179761188372, 0.056765700224787, 0.08965804148465395, 0.06915922037192754, 0.09438673845891442, 0.15811346497918877, 0.21594648382493428, 0.15020754135080747, 0.10001617709973029], [0.006862422010661768, 0.02277823567523488, 0.007035850896500051, 0.008585176197811961, 0.031646907196513245, 0.030927561689168215, 0.055900099886847396, 0.06336919963359833, 0.028293129123215164, 0.06359888373741082, 0.028202556572588425, 0.02144749110032405, 0.020644816403676356, 0.02118173098590757, 0.05369885764749987, 0.015341247598241483, 0.034333390183746815, 0.0364897710803364, 0.08670557277011019, 0.011782856441901197, 0.03909185788195048, 0.03604981575959495, 0.05141019295634968, 0.06170705346656697, 0.03666868040870343, 0.02393339913604515, 0.0378709596448711, 0.013497756162126149, 0.010286764757308577, 0.027048368505867462, 0.027187273105872527, 0.04227860438238297, 0.06500745458262307, 0.02711553668736347, 0.03565188889790859, 0.053404302203229496, 0.020080463561628546, 0.019331939352144088, 0.004913828044664115, 0.024722269037738442, 0.06534649817539112, 0.018906146753579378, 0.02647263154254428, 0.03956208943522402, 0.00999990729282477, 0.046410706226847, 0.018464386529688324, 0.05446792280833636, 0.01551483042671212, 0.06850461728338685, 0.01248224962702287, 0.058929545006581714, 0.04150195659271308, 0.10235887353441545, 0.07398656955254929, 0.050664683138685565, 0.053751416970044374, 0.026355650408991745, 0.0700816683737295, 0.026592118166653172, 0.03897223215816276, 0.028093967220879028, 0.0323199019767344, 0.040336725368563614, 0.003852153562807611, 0.029954817279108932, 0.012390501514476324, 0.02378516976854631, 0.0526955825542765, 0.0881883210635611, 0.012684905136536275, 0.0401159911416471, 0.049779703840613365, 0.020513214536809495, 0.010040478597927307, 0.02878344870571579, 0.037746065096663575, 0.02727060059883765, 0.022825780623991574, 0.07895045354962349, 0.05991641990840435, 0.04849079603861485, 0.05551171322752323, 0.0192321556886392, 0.029216625461620942, 0.021979545675484196, 0.03157703844564302, 0.043624475199197016, 0.05561016865872911, 0.04011292416336281, 0.0538817805105022, 0.032870550107743056, 0.02906827735049384, 0.06945004048092024, 0.02527789252677134, 0.03300067616094436, 0.03216994913028819, 0.10104070390973773, 0.008209909861242133, 0.07641723805240222, 0.04507846039320741, 0.019882436509111097, 0.033255645872226784, 0.07968568695443017, 0.06993105395564012, 0.06786258744874171, 0.007580438013454633, 0.027407018367999365, 0.025379650727180497, 0.03885716958237546, 0.06442880670406989, 0.05039715374420796, 0.0840524872764945, 0.0534283969817417, 0.021025135281628797, 0.017106860177591443, 0.025819302403501103, 0.04489781740786774, 0.020862205452950935, 0.08171622335378613, 0.0462944358587265, 0.03219538401546223, 0.04691249983651297, 0.025272562634199858, 0.05374597851186991, 0.02477957301640085, 0.013255894899235239, 0.034589889991496287, 0.03008584239120994, 0.04381130303123167, 0.036329606281859536, 0.01939291081258229, 0.04119364045826452, 0.029147248648639237, 0.018065623373591473, 0.10368357066597257, 0.03472316783985921, 0.04931318048121674, 0.039922883468014855, 0.048685332028461356, 0.044905420392751694, 0.01859773732056575, 0.011097723518365195, 0.007378175206083272, 0.062499215959438255, 0.07014907404248204, 0.025252310060230748, 0.031077908085925237, 0.016177175599815588, 0.05223592596926859, 0.05016167834401131, 0.02837241254746914, 0.06793327044163432, 0.027503853796848228, 0.01091325783636421, 0.04844003822654486, 0.01673039877122002, 0.030933431017079523, 0.0329235436926995, 0.018028266628139784, 0.032300489089850865, 0.03388655451791627, 0.051169994952423234, 0.0053649830099727425, 0.028369849381436194, 0.0645178644252675, 0.03556860890239477, 0.008410023408941925, 0.01832054728376014, 0.003692053649241903, 0.02606004662811756, 0.013030695063727242, 0.005438523059378245, 0.019179854209401777, 0.021594549994915724, 0.01410471845883876, 0.06841675378382206, 0.02065760169976524, 0.07308801955410413, 0.026844356774485538, 0.016802428656124642, 0.07305870005594832, 0.031109531210469346, 0.017588988146079437, 0.04590665648824402, 0.08262609810169254, 0.10965564913515534, 0.05462451172726495, 0.04287316729979856, 0.004838654422201216, 0.04865648750481861, 0.06777762129370656, 0.022998603493241326, 0.02423889595749123, 0.04055029087300811, 0.06291488651186228, 0.025495602183842232, 0.04325307905673981, 0.04059733031317592, 0.03453514239351664, 0.0558398527625416, 0.03768638454909835, 0.017460483791572706, 0.007430121302604675, 0.06694506561117512, 0.019022239006257484, 0.005727888983009117, 0.007665643352083862, 0.04200139229318925, 0.011735206320216613, 0.01888309182998325, 0.030241287978632108, 0.01872512718130435, 0.06795517355203629, 0.05286564378600035, 0.004263802947077368, 0.0073895830760842985, 0.025030337506905198, 0.04568715380238635, 0.06169872105653797, 0.015591528632545044, 0.01738155659820352, 0.023495128278487494, 0.12441386042961053, 0.015611587824033839, 0.002678703371202573, 0.007474442361854017, 0.04664233772616301, 0.06017511138426406, 0.03669768438807555, 0.016585850456197346, 0.054003048289035044, 0.027802750168900405, 0.006757907261739352, 0.01606064908472555, 0.010625206150247582, 0.01467546055625592, 0.028849473555705378, 0.05617836031264492, 0.021242710928033506, 0.02182187110052577, 0.016676458629912565, 0.00936551352164575, 0.06215560582599469, 0.0339181674644351, 0.05626731625358973, 0.039552562803562195, 0.019259833132049868, 0.061180910627756796, 0.0013350803076588947, 0.013292205004420663, 0.023353850502254705, 0.035988228528627327, 0.023062769157279814, 0.06958534036363874, 0.08411515677081687, 0.035377438446240764, 0.02613133012450167, 0.03538169625348278, 0.05141970940998622, 0.07290484902581998, 0.03412553115880915, 0.040431319935513396, 0.009227109341216939, 0.07183725559817893, 0.030483541943665062, 0.02805830172396132, 0.016036001300173144, 0.08480991556176118, 0.05527192573728306, 0.06873364999358143, 0.0524796591406422, 0.017102827983243123, 0.019346307331163968, 0.05251464440620371, 0.020500035690409795, 0.06395269903753485, 0.018726872712639824, 0.0240432166361383, 0.034607735462486744, 0.08596767950803041, 0.03753166838682123, 0.012840740881594164, 0.08748333674988576, 0.02482329442032746, 0.025608858160142387, 0.03383974577965481, 0.08882771139698369, 0.01900314163815762, 0.03383725894881146, 0.06589666115386145, 0.02483126211778394, 0.03920356849474566, 0.056706223237727366, 0.00837733328808099, 0.014126363725933646, 0.06088008891258921, 0.054638791496732404, 0.03360734414309263, 0.03624904042642031, 0.03666133187445147, 0.011469205325868512, 0.03585178531440241, 0.061647735935236724, 0.017766584509185383, 0.05785163784665721, 0.011165807722136378, 0.034076534145112546, 0.013311350718140602, 0.0544671017809638, 0.05442536848464182, 0.015212785652173417, 0.007175185518073184, 0.03750880514936788, 0.028081131034663746, 0.02444196622153478, 0.02835972563895796, 0.025862297774957757, 0.0443385213480464, 0.01998670189641416, 0.05515346370105233, 0.023612708219193985, 0.02984206172238503, 0.02889650621052299, 0.06668640806206635, 0.02648964411179934, 0.03589640577722873, 0.027496062518496598, 0.03996536654553243, 0.013953191411149288, 0.036184935830533504, 0.03155292670375534, 0.026461447589099407, 0.025895571435934732, 0.03469859130148377, 0.03368664113804698, 0.03969922475516796, 0.010858736699447036, 0.03471768866958363, 0.017384888205145086, 0.03401669753449304, 0.04495244626221912, 0.06159998064062425, 0.026960298053121994, 0.04248729461271848, 0.0032726899579366936, 0.0318189734992172, 0.011496077008944536, 0.0227434845042548, 0.018282450935138122, 0.042911351857973, 0.005341265242480273, 0.07583271406058754, 0.07930158185107367, 0.08948847558349371, 0.1039884432352015, 0.06470174741532121, 0.13727190904319286, 0.1393103910876172, 0.18458980641194753, 0.10584512539207935, 0.16339991773877824, 0.1676928459533623, 0.08884385374507733, 0.14967565132038935, 0.0830337687262467, 0.16595796761768206, 0.10875368610556636, 0.07002676810537066, 0.08278942148068122, 0.11228440914835248, 0.16220644249447755, 0.08189950923302344, 0.13148069408323082, 0.18274184343005928, 0.15370395087770053, 0.19078886163021835, 0.15351229187633308, 0.0935788271682603, 0.063421073635774, 0.12240984796413354, 0.11379841076476233, 0.05645655967029078, 0.1356308042470898, 0.14517373432006153, 0.09331356068806988, 0.11280468944460154, 0.12944856312658104, 0.09987073311848299, 0.07556920498609543, 0.10062386627708163, 0.15743969327637128, 0.14110888886664594, 0.10050572654498474, 0.11578309855290822, 0.08998187232230391, 0.08803957940212317, 0.17740649543702602, 0.1059003717132977, 0.2320390274482114, 0.09697494921939713, 0.1829138927693878, 0.10179086508495466, 0.2775933173085962, 0.13822107096867903, 0.2482736563043935, 0.1496331071747201, 0.1477150922375066, 0.1867788689477103, 0.09044138980763299, 0.1190268759216581, 0.11913111247122288, 0.09482561490897622, 0.10116385801562242, 0.10380100472165005, 0.1022142166537898, 0.1019855367818049, 0.07805596797594003, 0.1270272923367364, 0.09735004337770597, 0.15287619243775094, 0.12081098875829152, 0.11262932885438204, 0.08811700024775096, 0.19032539507108076, 0.08625102216111762, 0.08888215026152985, 0.12017920480242797, 0.14157056409333432, 0.16947740662310803, 0.1679728366434574, 0.21844616612153395, 0.1328924676137311, 0.11534875471677099, 0.1520777331399066, 0.07773441023060254, 0.12814226107937948, 0.09411218961966888, 0.11930561810731888, 0.09816114378294774, 0.21729915695531027, 0.16628705710172653, 0.21102698280342988, 0.10826098825782537, 0.10171185646738325, 0.1005949606852872, 0.15793947502970695, 0.19361894976879868, 0.15147265632237705, 0.11134222934820823, 0.09915165563247033, 0.23632077340568813, 0.12663519409086021, 0.13104761232222828, 0.10489982433084931, 0.20539557641105993, 0.23912116885185242, 0.1034766717680863, 0.09582679332899195, 0.17263104739998067, 0.12285522477967398, 0.1429967497076307, 0.17467225715517998, 0.3039852896971362, 0.11990454739757947, 0.12950690356748445, 0.1421250221984727, 0.08520197309553623, 0.15457019582390785, 0.1287002611373152, 0.147928654349276, 0.14795230808002607, 0.18222531543246337, 0.10318459636930909, 0.15193784636046204, 0.11531120458883898, 0.17310516695891107, 0.1113615675962397, 0.1133641212114266, 0.12266015953251294, 0.08271335770509072, 0.24466778550829205, 0.13421262534601347, 0.09173766310725893, 0.07402821803199393, 0.16583652342004435, 0.1111378138884902, 0.2163817368979965, 0.1565445563090699, 0.11007718223014049, 0.12740390641348703, 0.12070907279849052, 0.1267867652433259, 0.14618367941251822, 0.11217372651611056, 0.07050326253686633, 0.23857934506876127, 0.1431769821792841, 0.19167596474289894, 0.11961617001465388, 0.13910550065338612, 0.12149436851697308, 0.12596250804407255, 0.14007990408156598, 0.21394689540777886, 0.12795049351240906, 0.09844612849078008, 0.14833844878843852, 0.08666891830840281, 0.10371438972651958, 0.08730288036167622, 0.11900566491697516, 0.09975722778056349, 0.11404960442866598, 0.14055433576660498, 0.11870712307947022, 0.12514107355049678, 0.1523694624858243, 0.15408151490347727, 0.13203710636922292, 0.09261891046272856, 0.12012412132961409, 0.16620742423193796, 0.06959933854107346, 0.15242788435092994, 0.0841244798419731, 0.13773598628384726, 0.07167153020522424], [0.02091570963550891, 0.05035766979147281, 0.05104463900040303, 0.03597171298627343, 0.05672658607363701, 0.05542410078591534, 0.043616434559226036, 0.02781178486267371, 0.036229159350373914, 0.024292483260588985, 0.03894788632169366, 0.05117079223107014, 0.035424901970795224, 0.05196902082700815, 0.02070510763275836, 0.013871833366075796, 0.015090411861560174, 0.03740991545575006, 0.04874589806422591, 0.01613146948095943, 0.027059971454686353, 0.058583851770630906, 0.03235752674351845, 0.04806450980582407, 0.023331803203161274, 0.03571276366710663, 0.02646107439483915, 0.040214175158845525, 0.039332598713891845, 0.04712528841836112, 0.02051717887765595, 0.050758107232728174, 0.015970970503985882, 0.04284257894115789, 0.06999251565762929, 0.020229673412229334, 0.037091597715126615, 0.04897951427847147, 0.009000552435671645, 0.06298377138695546, 0.008491065935231745, 0.05485141723017607, 0.048544329058911116, 0.017487409757450223, 0.060573194309004715, 0.042824353490556986, 0.02114933602777975, 0.03287938802636095, 0.03817713500133582, 0.029363379015454223, 0.03212055178093059, 0.05243615826059665, 0.06045098336679595, 0.015712085645645857, 0.09807488841137715, 0.027065265724169354, 0.059838476590812206, 0.017172800210703696, 0.02425814769230783, 0.0350033553051097, 0.04947307047301105, 0.04382755055225321, 0.04179817784045424, 0.03598716662132314, 0.06320443776037012, 0.027878591724272286, 0.02056387735397688, 0.04626914346590638, 0.03337699168228677, 0.03716954781806894, 0.07132543663361243, 0.03719593265226909, 0.04645054301779185, 0.118041439514075, 0.04731429774048073, 0.06042162315653903, 0.06211727538279124, 0.004376354095126901, 0.03623109996052725, 0.02977142283426864, 0.034829680874411545, 0.059415009671023915, 0.030195646320602725, 0.03316529214914356, 0.051874073421848674, 0.03810785657593182, 0.0508151245303452, 0.041993975905435424, 0.011141043738462031, 0.09629683489246027, 0.07117434724100999, 0.030921169889292548, 0.015795231630493487, 0.03947990188109023, 0.04517512788463916, 0.030592114331998994, 0.033303051721304655, 0.026015156447621327, 0.011383586929046681, 0.038878774137369225, 0.02606370732454317, 0.07026454034660544, 0.019499703742829815, 0.02922471020636814, 0.019318263478843228, 0.01986384464960013, 0.008292089781856962, 0.017096578675721372, 0.024297199078968594, 0.014608346657561404, 0.030342552544815198, 0.038440935845885954, 0.04715708117665989, 0.04196850030816027, 0.0722557081441794, 0.047957304665552716, 0.0398443939297327, 0.02795700153468975, 0.02319720390784953, 0.04260722228458949, 0.02837088584367718, 0.038204605491565805, 0.13509215600788593, 0.028569642321339676, 0.019990959703656178, 0.043450512391115935, 0.05854790298534291, 0.04236477493707623, 0.01074318218577121, 0.016005392585481917, 0.0109912410178887, 0.020424139852236425, 0.03753498981573752, 0.05203524245215314, 0.017197449691593647, 0.059973423635321, 0.056239883082785776, 0.03862337016367486, 0.07976420024143797, 0.02405070257373154, 0.02987609025357025, 0.029229602443852594, 0.004130928402966154, 0.018548287384744202, 0.03357048612087965, 0.0495540230934109, 0.021772237960249186, 0.033407444333923716, 0.03294886661959546, 0.020142812448154603, 0.026544798830790178, 0.047551330378545184, 0.02306838912357177, 0.03895815934187599, 0.039915416190134625, 0.08099453350795166, 0.045659992045589855, 0.03168760572693177, 0.04690351264019098, 0.0336104246920773, 0.02540153857054455, 0.021888633857348135, 0.05386984168684908, 0.02092640334740281, 0.022832157156829323, 0.07000815588980913, 0.03166307668600764, 0.0516381026910884, 0.03257853238444243, 0.015572215829576765, 0.04290200164541602, 0.03143612029297011, 0.060250001294272285, 0.016247919660859873, 0.029634565713682344, 0.10117101656006915, 0.041149556038102934, 0.04374172944309456, 0.03342463501862117, 0.020351339830085635, 0.03921031991818121, 0.02186462389571326, 0.06404386021729026, 0.02607485735123711, 0.03795801568776369, 0.013226074133334416, 0.011000737115474684, 0.07974293495395354, 0.05621953381757651, 0.04140618137483086, 0.022805685809414302, 0.024326370995757834, 0.05501156845795257, 0.02566021477936634, 0.09013033578438417, 0.018827798011313592, 0.050401581185204644, 0.032002157598201714, 0.03261399601719209, 0.022069582183446203, 0.011601872492714651, 0.04278352264580982, 0.022637773837362016, 0.015735922580850974, 0.007771634762840611, 0.05827125068753958, 0.0270901696556913, 0.03530087594741157, 0.058982789649495056, 0.01917031909605222, 0.06696586949484688, 0.058260136283934116, 0.038369642171476565, 0.018006522973467196, 0.018705917854926417, 0.0845273600092956, 0.03826228096815092, 0.013010372091749949, 0.022002992453053594, 0.03589883493259549, 0.0417233456059226, 0.03433629770630172, 0.05013304077354925, 0.05653117477361645, 0.014123923544372832, 0.06192571816167661, 0.016051646621365632, 0.022221535011859875, 0.00959868699179164, 0.09161089240972485, 0.04186452838725277, 0.041157080991459746, 0.02714089523734791, 0.07114061047988278, 0.08323992123561245, 0.02152921216163252, 0.019733479412804757, 0.05140181304886937, 0.023068436621023074, 0.05157771985977888, 0.02664092179786946, 0.02401759854650923, 0.01002470774775637, 0.05335085739248565, 0.056565094739198685, 0.017797568114474416, 0.007107626330772681, 0.037047543829040866, 0.029245100183678523, 0.05736248195171356, 0.016812993446365, 0.022025504548634802, 0.040993910282850266, 0.04725504806265235, 0.05658229560192142, 0.10880199101354394, 0.036250132867800336, 0.025911070872098207, 0.034525592013129165, 0.02297391669292535, 0.03146380452173097, 0.02917845786682197, 0.05534264604960169, 0.008415210809159492, 0.028491064573505094, 0.028307261311316063, 0.023135172236444693, 0.021520847521190132, 0.034796045893537145, 0.06824823282659054, 0.03785784695563572, 0.02070321621639388, 0.0246724374259689, 0.011993511031115693, 0.06375707060630832, 0.0474003088394446, 0.03686708065548113, 0.018545349328113452, 0.02795364787536008, 0.008687483163417449, 0.038167550694197416, 0.014086235164930778, 0.0870547876028078, 0.024700184419218982, 0.01515283199426319, 0.021689834971246973, 0.02160154060194535, 0.02359771089894431, 0.009715366177260876, 0.057557567554925165, 0.050156904850155115, 0.034612620914621015, 0.0235764540931476, 0.050179405071373494, 0.04306344887507813, 0.02520640377354409, 0.021341376705095172, 0.016142882439973097, 0.018148538656532764, 0.015920663917703286, 0.037034767014639716, 0.042301701714417765, 0.030703719771866287, 0.030157899417515312, 0.01024873202134456, 0.02593915713285761, 0.03418316931596824, 0.04245567488084946, 0.05982875318399497, 0.02466381833489452, 0.038688217755407095, 0.046721926491175375, 0.03132006705605558, 0.06677530293485948, 0.0279846891561257, 0.0001376568509710653, 0.024790292173357945, 0.01665740367025137, 0.0354674359384392, 0.03255189309961029, 0.07797778038574116, 0.010949358443862625, 0.026776805220703994, 0.04702005781499403, 0.008357667646903013, 0.022984513713579093, 0.025088218240333453, 0.02734641501280878, 0.025316964269482663, 0.04181215566183839, 0.05671998732058065, 0.01229482383600303, 0.04369281724627529, 0.038379358792943616, 0.055576645636132786, 0.07153679350657122, 0.003648671512824616, 0.022969899765614952, 0.05166226193042738, 0.1198253080781017, 0.05011178566409009, 0.020733675653381006, 0.007132330094464123, 0.026224389505971755, 0.00981519733821707, 0.05845898097114904, 0.0862649864118014, 0.050634861524615965, 0.01564255276960986, 0.024692566167297106, 0.03423666162416339, 0.10883633845618793, 0.1099738006346992, 0.13456220658762114, 0.2537881646837507, 0.07786652778408357, 0.14698782483381884, 0.14227930749101297, 0.14402532737169946, 0.05065816580983145, 0.1697119218962533, 0.11839081719517708, 0.14907141588628292, 0.175622396171093, 0.12639454486114637, 0.16697381596480096, 0.10292536206543446, 0.08547636587172747, 0.11525925594781126, 0.07401158035333667, 0.17577266453632287, 0.05908535700291395, 0.12028724114809718, 0.17094689634229454, 0.1284801715186664, 0.15412685461342335, 0.10157653622861419, 0.15735277294048242, 0.0850922471976706, 0.14918623758213861, 0.14070061434592518, 0.14745027359042848, 0.09595708562327282, 0.14601815758006914, 0.21142142878047057, 0.15926088126642363, 0.20540829215730938, 0.14649611764720508, 0.13474303617009095, 0.1151808172996555, 0.1797635361020054, 0.2898853862924235, 0.14518607008670056, 0.09915508901966469, 0.11257657275668212, 0.2236211627189602, 0.1457019466906786, 0.1875478391136442, 0.13976248539984226, 0.15597111279410975, 0.25488307593124254, 0.14951795978205545, 0.13374742173722812, 0.1528013635958944, 0.1556992916656392, 0.1386159783495324, 0.17038972409708159, 0.08828542621007987, 0.15967970022133418, 0.1457956795181547, 0.1694571862795523, 0.14289387022810324, 0.11282134747930936, 0.1647990569472313, 0.05975173267402819, 0.14654778130352497, 0.1428754005048956, 0.10409977726106133, 0.09819095861166716, 0.1712181746427502, 0.12348992643611771, 0.09141649891223226, 0.16304945440164634, 0.11361469062311308, 0.17817728407680988, 0.23894882095711573, 0.08325163953538452, 0.10714710517121212, 0.14155970753303596, 0.10448855747069631, 0.1413081610309226, 0.1817513858633382, 0.09318423191351549, 0.11171882306890828, 0.14970633467393263, 0.13479628759835446, 0.14234056563249656, 0.11704792853976999, 0.11502422498805182, 0.1700601867799248, 0.12322195938655309, 0.24708622002175876, 0.18018410567726406, 0.12766402959823608, 0.11151344408946377, 0.17372460157743522, 0.10903966147452593, 0.11240545979567937, 0.1397855013076748, 0.06920910626649857, 0.15388475331876958, 0.10569510808480637, 0.12351058104208537, 0.12095806800893374, 0.1537506612283843, 0.08890716784766742, 0.09127632036272969, 0.0920823724674327, 0.24038831942847796, 0.07791868677096707, 0.07469217811844178, 0.11637305761022226, 0.13613415509462357, 0.2091505349214588, 0.1271647092487131, 0.121772133612207, 0.14205231038587435, 0.12729563936591148, 0.10282090838466372, 0.10044044469084058, 0.10559261537023953, 0.07650655361690692, 0.091072135604918, 0.1259001371051584, 0.14273210747965745, 0.09831897102828537, 0.13211728206702641, 0.1264276709407568, 0.1582422237843275, 0.10927191044070891, 0.08017604385635682, 0.16574551830334322, 0.13252652010747365, 0.08752874431333371, 0.17445026763847896, 0.10275323808725391, 0.31146703394395964, 0.10387378438775029, 0.13790533505380154, 0.19591915634061607, 0.15236070938408375, 0.14536479621061257, 0.10358741546847991, 0.16217685836766446, 0.1474570453699146, 0.05621807835996151, 0.12296115766678538, 0.12716783050979885, 0.11114065695021834, 0.2510714461760861, 0.17825925110706262, 0.10566141882113048, 0.18647822365164757, 0.12170193237917763, 0.08912305733455078, 0.0675892871139305, 0.149161036791546, 0.1503171654684203, 0.15702347989593232, 0.09923789743334055, 0.21235681644507817, 0.2170972385044609, 0.09412259834685496, 0.09334942126380545, 0.16925332721854958, 0.21086785277085646, 0.09230337810835668, 0.10741948269839798, 0.07529376048062529, 0.12110358662903309, 0.0888622963268842, 0.1676703728735447, 0.1987069717475346, 0.09118981393320219, 0.1301882748625108, 0.06445820762642793, 0.1088761684617826, 0.16011819669178554], [0.03241332607077701, 0.03031641537589686, 0.037873823062649796, 0.021251175652391145, 0.01346515933983028, 0.027453201157706122, 0.07248315308243036, 0.031114643971834863, 0.03730688669851848, 0.02075757535307535, 0.05023069892610822, 0.01899543687302087, 0.009033446965206946, 0.012496001835513328, 0.016298755504457012, 0.03188249794766307, 0.014891114252220308, 0.05624838512656944, 0.08017907012254, 0.031120394556117908, 0.008825587940269282, 0.030887361881988387, 0.009879900741257837, 0.003640751736903829, 0.0426903055049479, 0.06836614185678107, 0.0168315428974373, 0.06347933265247516, 0.027531958717320646, 0.012011614345413233, 0.03163324150123766, 0.01592638566424804, 0.03033763655860509, 0.014264797592269523, 0.013850064266340008, 0.01150237805476146, 0.04750415523137365, 0.038939648906567266, 0.015877393739564077, 0.03197848011872598, 0.042984212948275466, 0.06388030613639525, 0.09088964361165251, 0.061697818604963164, 0.015999935467594435, 0.023849248919369917, 0.05933344976178237, 0.06069683696010283, 0.03183157050183841, 0.0278378694451281, 0.011195943158652102, 0.04424304807824748, 0.058191868875707896, 0.03356809089226382, 0.003347556755345847, 0.006341907619831285, 0.009946124062740376, 0.04096181557646819, 0.023536269553005695, 0.05613467622814434, 0.023464623040386608, 0.03239070710593036, 0.051347285974770784, 0.010741262779837208, 0.031094969848969152, 0.009516787815040775, 0.023215756751596928, 0.03896221358861242, 0.06393809017858335, 0.009756019754734422, 0.015426822738455874, 0.06535254392240729, 0.031089561924870526, 0.043181103454636674, 0.02858180506154895, 0.03695596535024898, 0.030442992690950632, 0.01474818424321711, 0.0024282944754564335, 0.02879813898886953, 0.016538232564926147, 0.03675807061206017, 0.012738651047194642, 0.02146030353781368, 0.018135441234335303, 0.05834164869572435, 0.010238088351408286, 0.01515045712169792, 0.048382074372576814, 0.02741128296059157, 0.07621346720095191, 0.024280790405880128, 0.026907418122781173, 0.02835733549935477, 0.033403814171573946, 0.1048940499978406, 0.04813642094710043, 0.06006799106087003, 0.02315598799447928, 0.04302670620381832, 0.04176291437553508, 0.008005596181776906, 0.05039147101342678, 0.03647923682417188, 0.035990023253751655, 0.029193660443914787, 0.04350632528907486, 0.012569888361862727, 0.020530026938234056, 0.016330429519127523, 0.0523908015872751, 0.054723051975348165, 0.057261970559401174, 0.028844272584787438, 0.10051772304411445, 0.026362700387835503, 0.05472263806898679, 0.040641757393521924, 0.061989432599927695, 0.06491032908005373, 0.007209241190659148, 0.08453190619392054, 0.037108079330729585, 0.007237442802371723, 0.08568838092365436, 0.01955509086006454, 0.030752981414220164, 0.022596091431166445, 0.038434449051107676, 0.026869618633229817, 0.025692779371248822, 0.038804708647408655, 0.05184135785592454, 0.03372626079778586, 0.05461668821849993, 0.045625566571418724, 0.06737119238823652, 0.0716331929766706, 0.02911386133304664, 0.019300847181252072, 0.03157263814604708, 0.053402839960264306, 0.05528143201289432, 0.05565552193937557, 0.10983882644878966, 0.005367463055465902, 0.03525837929919362, 0.03597331093624234, 0.026204133539327552, 0.019504918284448128, 0.0767635012577687, 0.02638045764927353, 0.029467215229357992, 0.04321167484990188, 0.028579857666045427, 0.014638573696304644, 0.01706623798236251, 0.04571598136265363, 0.024978455023041794, 0.00901745559115495, 0.06252827761428696, 0.013445465709082782, 0.02963083377107978, 0.05327091578926359, 0.015453138022816606, 0.0290762297809124, 0.029750625735947063, 0.03866271501673119, 0.013572665580016161, 0.02643161410066698, 0.05537511734291911, 0.033054205788565535, 0.03243171436978238, 0.0719255805015564, 0.025746018925149525, 0.03559071896597743, 0.023096278609175767, 0.05095717922917434, 0.08522473794541188, 0.03247818723320961, 0.03975316828915051, 0.038457444602889676, 0.03860069352335163, 0.012323863438463636, 0.03602234187668987, 0.012168858050634819, 0.055017973828528605, 0.04307540126943162, 0.013863702820214843, 0.04041513008996844, 0.026223213944051946, 0.03344160517943757, 0.039787081469382556, 0.03895052921559129, 0.05324841556804521, 0.04968157071354134, 0.03295939409040979, 0.07328260982675211, 0.034863841719925404, 0.05477995392201202, 0.031078902139727558, 0.06644295648272548, 0.008925006043032875, 0.03262920198696, 0.04156931137133922, 0.0010341985845505925, 0.01919510598028345, 0.028613133023359945, 0.016300429789615527, 0.04995666916615196, 0.020348763093352318, 0.016414516971313527, 0.01727386630539383, 0.017329535014661293, 0.018811496207490563, 0.03898453739072595, 0.011937083210796118, 0.030233620532921383, 0.06654168332793883, 0.006063282905545617, 0.036983412091753314, 0.060710509440728595, 0.08772449488086359, 0.08057935150074107, 0.0343152224086225, 0.044534709570663314, 0.020259211737928644, 0.06515778401600462, 0.005055379355326295, 0.06602066342851945, 0.04753306421584316, 0.025160034386707202, 0.043205235552574904, 0.017453108115919998, 0.0067109882615373605, 0.01978337887807616, 0.04586367129481264, 0.04318640959848251, 0.034062953266714296, 0.014314322166943123, 0.03753151232376695, 0.029569361891065325, 0.08495895577860729, 0.02948956617287227, 0.04452275378363473, 0.03439764405733772, 0.030857150110283067, 0.03161639008404953, 0.04342872463166714, 0.03507348868463721, 0.03971916689936604, 0.048447536038500924, 0.02067172370984086, 0.036895019334873984, 0.0226192311716399, 0.09284127995904003, 0.02594246668741107, 0.03546958350177322, 0.031876333457018645, 0.03687067010572978, 0.025189754220524004, 0.051613122424376864, 0.022942758364869014, 0.0609973194077611, 0.02149662891003702, 0.0275903924567891, 0.04193260919834886, 0.04943062810759459, 0.05408290507537978, 0.020907809791554297, 0.02588357663314257, 0.012254678311624696, 0.06415001023560762, 0.038199404520647864, 0.013390347461349197, 0.054697288000690084, 0.008454921222957117, 0.08609626189406429, 0.04164321740557041, 0.03969278545784099, 0.06573308671691588, 0.02754188738098102, 0.049458851771695275, 0.009883151772165937, 0.026082506137234823, 0.035438934074980874, 0.02479238375755293, 0.007342212001926133, 0.027820488770625422, 0.01420849360459085, 0.04985233762168458, 0.027789098044325198, 0.05770416504570416, 0.05341032420152, 0.016642581072768996, 0.06700499382402215, 0.02375014718355877, 0.06149653119168111, 0.03493380546569824, 0.04015892205227699, 0.006270784003260944, 0.03555631045518177, 0.027184626819299798, 0.03725934853511197, 0.02414481877349317, 0.02717563453396516, 0.024421991846923317, 0.029078570726726736, 0.04458508401044777, 0.02491310192272067, 0.058759415921355994, 0.0703020090503352, 0.09986558982304164, 0.06576934084296227, 0.023113321712506667, 0.012353043836940612, 0.0276068096115653, 0.04612464264833501, 0.08669697573142392, 0.008539651587073292, 0.06464009572352682, 0.022892416155497943, 0.04739301798066922, 0.025188900962738053, 0.08891429925071341, 0.009107948413916996, 0.035521077524338446, 0.023233419018132345, 0.035498889429228644, 0.09193043490605694, 0.04600806015410593, 0.016119556102369512, 0.030300703897540058, 0.059900487906166484, 0.011566181550733745, 0.033002755870776515, 0.047996211863522015, 0.1110376553343875, 0.03558864264882036, 0.026808672617854815, 0.04387576385800328, 0.05451793423188584, 0.025361443936292614, 0.02799077900791807, 0.0568422593309411, 0.06130785095904555, 0.043400304192411046, 0.02353992685675621, 0.014330493352775062, 0.09516040408717734, 0.04187673183956316, 0.10406684795660631, 0.11215098202228546, 0.10687537225229399, 0.18731364953730786, 0.09579910231488091, 0.1420367719339473, 0.08001694775053433, 0.16641189397445746, 0.08368605122502361, 0.14952105390174047, 0.19153322811637605, 0.14031910124633992, 0.12719225777047022, 0.12916417552956513, 0.13602592875914915, 0.10145077654825789, 0.06065349214311157, 0.16492915925170692, 0.11730189062654972, 0.13814670353063516, 0.1930581270051854, 0.11402363010815211, 0.13711387823734963, 0.1210857140166419, 0.09404111986181565, 0.17945819534361362, 0.1384471995489938, 0.07757803505020482, 0.14055783700730118, 0.17211473653359072, 0.07570447772741318, 0.13563178133751663, 0.1488722251462085, 0.07799042827848877, 0.11871702969074249, 0.1447459858443056, 0.10343059245496988, 0.11709104265485491, 0.12784036727888243, 0.0793236545952303, 0.11472138123852865, 0.16370918042957783, 0.0780803273831095, 0.18310029990971088, 0.13409530664128916, 0.09096201615674154, 0.11920450281883989, 0.24196314492395946, 0.1431138241397483, 0.15283125984881604, 0.12021530286542007, 0.09828684239515237, 0.18956530014319078, 0.1842613411801202, 0.1466713696718216, 0.13050828554800578, 0.09711769263127021, 0.15964791764106068, 0.10399638888026987, 0.06655423622578382, 0.34505364884223255, 0.1520547443734748, 0.16301039792597294, 0.09043419733643532, 0.10894705501518079, 0.07732588465192489, 0.11613371116774422, 0.09768935159913131, 0.11034489822174821, 0.11737829366964952, 0.1979143749922514, 0.10411893230463777, 0.13030682850096906, 0.07608993311545678, 0.15738790748374804, 0.11830072131540094, 0.1728985801871334, 0.1308699989957469, 0.11491849566144602, 0.10443622885005814, 0.1690720362322671, 0.15908391933356011, 0.11783939892692225, 0.21164569817483425, 0.1709701565227338, 0.12232701240905694, 0.12547289074531623, 0.07394039524453026, 0.08857882475214345, 0.0973474717299853, 0.08058959059417248, 0.1490882435547454, 0.23102896021945135, 0.13804234484476702, 0.05707963462918997, 0.12715292988078936, 0.1695010739245585, 0.16478297566728933, 0.12891420322869504, 0.09235806124550955, 0.09290714535330023, 0.12894686790449278, 0.13297261617013387, 0.17608283646404743, 0.08405366114207677, 0.22507876450462, 0.10270719948623862, 0.2011473500835044, 0.0840731215264116, 0.08660029127661671, 0.17360697074660233, 0.11580810935369559, 0.07421831640281848, 0.13105616186346325, 0.11665654954101358, 0.18737530122910226, 0.1089606053595032, 0.21334514341184072, 0.09320320375263691, 0.12583661265671253, 0.22096210611718042, 0.1701016588402646, 0.22939018958381244, 0.18196847635720456, 0.07639844941773585, 0.11622502841055393, 0.12764352426997252, 0.18714260442980699, 0.11919478619737284, 0.16698274548564637, 0.07416717521846294, 0.11258208246103354, 0.08064421266317368, 0.13623953158301966, 0.1317949236503669, 0.1223985707121236, 0.20984576190156595, 0.3131384556846959, 0.17574014913822922, 0.11912727196301733, 0.11677092340375696, 0.09479139638798577, 0.10974638962319919, 0.15929896065167018, 0.12661023757287435, 0.12709875564490045, 0.092180624338133, 0.18097436827208313, 0.0899284105481846, 0.15725817158818245, 0.10815511643886566, 0.15119210923356668, 0.10966263126049723, 0.13082437430109295, 0.11357763582574469, 0.14458464378757135, 0.08767224768442766, 0.08420899816389595, 0.24939462329660142, 0.19019943183021887, 0.09396598567920071, 0.1358744390308857, 0.20706697101039545, 0.08643631650401012, 0.270487264330898, 0.05850556918552943, 0.09152253357959644, 0.1399828057203974, 0.09186568230922733, 0.12350892541663987, 0.17900378044162477, 0.130570222224508, 0.05784558531429086, 0.11415238891329084, 0.24065034251127923, 0.07355084829032421, 0.2638207663382803], [0.043608461772756915, 0.05209847852321608, 0.017820801153512936, 0.0043889188673347235, 0.03474086742582066, 0.022685264503317218, 0.05871535185724497, 0.04305248035650168, 0.0130099446146882, 0.08004481518375021, 0.04650402514796172, 0.05209986612732921, 0.05800158051507814, 0.04430637914421303, 0.043489090499601195, 0.03355145660628166, 0.0292993829851704, 0.07589667277144534, 0.07160654690648828, 0.032263848198843856, 0.03303626871534756, 0.0077324663288891315, 0.030587310304066966, 0.05081613215484789, 0.025978966782401716, 0.02006919139863125, 0.03202983843428748, 0.03729287495038339, 0.03124161483719945, 0.004261445037887565, 0.0312552941031754, 0.08019180622484003, 0.04948221033971224, 0.03318508162296244, 0.04955991277737277, 0.03373922760199223, 0.009438785973803272, 0.03685267874971032, 0.07066709481711898, 0.05457085657066532, 0.038290809973009994, 0.02592394607407706, 0.01598741140748773, 0.08285061176866293, 0.03077126793297274, 0.011061784062933708, 0.07434486996914659, 0.040556821772562604, 0.029646205981927257, 0.013243582033153092, 0.03217644610309175, 0.006637093253500227, 0.04164356006575482, 0.004365416958795062, 0.044360712835831304, 0.017835640714370778, 0.024907222416784083, 0.020901173719071915, 0.020447021749402796, 0.08345352405948298, 0.03517854965424963, 0.039919399190694094, 0.019712765435022966, 0.0036758578665155384, 0.0485815399193338, 0.027875882673210332, 0.04091289659429874, 0.07216985310826983, 0.02073872395391975, 0.05677694694272109, 0.0274395592111562, 0.05926097543644054, 0.03309809682624681, 0.07179200409778527, 0.04457488902179258, 0.024416811232055937, 0.06327047957373516, 0.043872500104563575, 0.05043395069826927, 0.03595912955435259, 0.025301074675683464, 0.009560521093330212, 0.03164023719727993, 0.059823827019759586, 0.017887591051736047, 0.03150906620014991, 0.06633378019822495, 0.013236245373263955, 0.017454997835946933, 0.022908270126208663, 0.0014957516749356209, 0.03556710594732847, 0.04713705760825958, 0.028436976850831082, 0.07079773316425936, 0.040083692874759436, 0.019542870444378684, 0.011476745546263243, 0.02276962167317314, 0.06565187964588404, 0.010558347550353833, 0.022231285560077856, 0.06402539049408265, 0.017897175358874456, 0.022905162435823252, 0.018709717651030848, 0.042164009995758533, 0.036127762469862185, 0.010945619715909873, 0.042237586940505674, 0.08675845100411347, 0.04035161921222295, 0.051453955072377405, 0.044873468178723536, 0.046220343227365186, 0.10560587394450392, 0.04295752616599202, 0.06324212359530584, 0.04883346640105758, 0.07269609772733279, 0.013450420711056461, 0.027531812832291638, 0.022833889117464423, 0.05587144196033478, 0.04345972689666918, 0.016456282498048883, 0.004604556872176805, 0.03657941912700023, 0.03330772343490805, 0.04871545898328934, 0.07472282075988394, 0.018606702464499643, 0.014140375474068736, 0.02155150712600776, 0.05607995577156544, 0.02464969123580626, 0.04309540448178138, 0.07467508582132203, 0.06171926709690264, 0.04151614475995302, 0.022260223382285664, 0.05709902037467275, 0.06826806640518562, 0.0343410779855081, 0.036260402495307584, 0.007495212318774844, 0.05763061184968267, 0.01650888253269451, 0.04766024203438844, 0.07244620685066495, 0.05766857588397605, 0.006021952489390969, 0.06385893228330783, 0.019747810072398612, 0.052831805244620354, 0.007284613708699388, 0.06339886518461363, 0.00996857593833868, 0.02182426463280405, 0.04309974032055054, 0.020434400998055935, 0.09394326832677637, 0.04208828888035246, 0.05523919999333365, 0.017052012495696545, 0.024674656235479882, 0.04121448166136231, 0.01767180164876793, 0.06442027073353529, 0.03165885619819164, 0.05234430497512221, 0.04001500138214656, 0.04818384375955377, 0.03250759833359292, 0.049841864433671744, 0.06430451265935387, 0.026169993049864258, 0.07100166686411415, 0.05874703944261585, 0.012219602292004441, 0.07676773531628506, 0.047138173798365254, 0.028530864045023918, 0.01322887309028634, 0.01865831183801804, 0.020922539090471606, 0.003946548386011273, 0.06112865664597068, 0.0030577911321805523, 0.05474862256752593, 0.035870835185050964, 0.03328963369131088, 0.021359101736119816, 0.03639165830931493, 0.13150452423308576, 0.06132858020386525, 0.013401858807940568, 0.08584686634796006, 0.027291998200650727, 0.020051244147387997, 0.006781642416691673, 0.060205557250550816, 0.027357678694118346, 0.06570171804300376, 0.0546184116974473, 0.00925487160150494, 0.051930252728717666, 0.08803431397037846, 0.02868260143856917, 0.07075373016830001, 0.054196176318717856, 0.008258286863565445, 0.037266571540385485, 0.03519423399120569, 0.06723809774432864, 0.04561847588047385, 0.07149532144623143, 0.028225857465128814, 0.034875159684036455, 0.059236487107617516, 0.018664381333759854, 0.03783639846369624, 0.05113930142085467, 0.014933882314445717, 0.024306333856657147, 0.05199693236500025, 0.02741333722536053, 0.04237461369484663, 0.041581019493086, 0.04114601747798068, 0.009406909246795943, 0.013704278473077076, 0.020347087111856257, 0.003975143123950277, 0.010942128653238927, 0.052132215284343274, 0.018772095375295197, 0.0620261820565377, 0.03982542548328638, 0.044579441991767714, 0.023868468423773135, 0.01420031556127859, 0.061972313161407194, 0.019794442391555225, 0.012133203579911163, 0.08889736980199814, 0.02867970409403954, 0.03387847655851926, 0.0999554210741605, 0.0037187425519472784, 0.06335868234080927, 0.04708823362099273, 0.03947132519845452, 0.06514621499393668, 0.07553913909941912, 0.05832285327570779, 0.05206605472734996, 0.05960577979151692, 0.016602793475612998, 0.03689192860786404, 0.012549939432314463, 0.01707288423287017, 0.04940207535400987, 0.07370956441653626, 0.023789821126099144, 0.03826206722962005, 0.015141729465020555, 0.04826305593763079, 0.0879347932391933, 0.016426990141293833, 0.046439279336482286, 0.05603707575106195, 0.026890352967062166, 0.019134667169834887, 0.00691761659358495, 0.05327932283814464, 0.021364372256877165, 0.019692497594015937, 0.056844902224838734, 0.026640597797398056, 0.004077593854162842, 0.05178159249148198, 0.004524078802205622, 0.015279833393703614, 0.07125780704830374, 0.05930752972407, 0.0472522083935993, 0.07546291926077434, 0.02331084495277277, 0.0266416546156896, 0.06454786245844193, 0.15471477806568146, 0.03326983064679163, 0.04177847318351269, 0.054551331725503714, 0.06977932674012013, 0.04003246008817639, 0.034639036282896996, 0.01541866165851908, 0.033452655122216256, 0.05302950320765376, 0.009890888767716075, 0.037484737512256415, 0.03977227922795074, 0.006927827697446836, 0.025978098257577846, 0.0467224659265152, 0.030803600126611333, 0.03233555577961462, 0.036823196403150044, 0.03523897319766028, 0.009255696021552597, 0.04597527673467994, 0.041965284052171876, 0.03782389645597764, 0.026155964338353703, 0.07247604882078511, 0.06940229197165795, 0.05222409571121846, 0.026785229232960513, 0.055922152274953466, 0.027470230690336654, 0.03870310142104115, 0.048059956835848947, 0.018280432293457643, 0.0793986598561917, 0.012443164313611175, 0.030093821963029246, 0.045551619825086424, 0.030075986670064073, 0.048794145296726904, 0.047708831927073855, 0.09457100821392876, 0.023002259100654295, 0.017472539662516544, 0.09273750481328794, 0.013321133496771966, 0.05392849086118596, 0.045733433283333264, 0.0330279125565929, 0.01652994256333581, 0.020815853029489517, 0.034933042113802264, 0.028714964166283607, 0.029110780784061978, 0.04493156773969531, 0.0632333637082151, 0.06679514329880476, 0.05484633839556149, 0.042263625721846304, 0.027852763288787434, 0.013585547567345202, 0.10130373122436659, 0.14392335712909698, 0.1343983132392168, 0.08512623501675469, 0.10504786710121802, 0.19239195489457675, 0.10556208129440035, 0.14553529849009855, 0.12220091346119132, 0.12828144218240464, 0.1290738760892834, 0.2526194831090314, 0.08822821213730744, 0.08752660014267478, 0.1528456447912114, 0.1002294813681926, 0.0482870489358902, 0.22570472663002356, 0.18405328877270222, 0.10383309942803212, 0.11069023861948933, 0.1791438843522753, 0.09489230133060898, 0.09912438531007085, 0.10602104916636433, 0.20622181493256772, 0.12121105300528662, 0.1370111344648259, 0.12924540974199772, 0.11557199273790632, 0.13491265635405267, 0.1966445238462516, 0.16774015341486248, 0.1290508737521512, 0.17351027950644493, 0.0913718513080052, 0.10911838510738951, 0.1606801322528294, 0.14263761469296046, 0.09974650014191866, 0.13360787422529288, 0.08582085131534509, 0.13431249213005814, 0.11596837932510035, 0.0797610246975507, 0.1443714209433113, 0.1794320581746953, 0.12372882504548345, 0.12379092457039015, 0.1495781729796103, 0.0895165940746665, 0.07926985355360167, 0.16263261676899024, 0.10239288849490029, 0.12063404039612838, 0.1382607381258692, 0.13387688621878624, 0.11814936729414122, 0.11211206803896598, 0.17636992463043757, 0.11493856672729764, 0.16091338545084, 0.2210172845848969, 0.0663824515151126, 0.13600515201687813, 0.11963286197611264, 0.1477503353463752, 0.1814127561769315, 0.1478790127273117, 0.18388520207788261, 0.09368101454206876, 0.1572550774684974, 0.12080223565655095, 0.1339736453124455, 0.22044510314507143, 0.14440247070576462, 0.08811199944466352, 0.12602532681609901, 0.18341629366789544, 0.13948048624609197, 0.09852808195033244, 0.1044274146801659, 0.1637832493122135, 0.1450413114258221, 0.16033307516149112, 0.12272079342177936, 0.24228137784770556, 0.1067660738314901, 0.09227543603628874, 0.16287208534777164, 0.07360906659492425, 0.13567682249205454, 0.19094489754310676, 0.09196540660091809, 0.1541994714311191, 0.17691067632819923, 0.0758000018873385, 0.10343834811023303, 0.06629431660154037, 0.19924054454479898, 0.0796579145161169, 0.06422960239329509, 0.14818180219403335, 0.13447242283395358, 0.07380523785416569, 0.14403724244662694, 0.12604002388460295, 0.15471803503377096, 0.1594893711486033, 0.13237997011414596, 0.3132438457437924, 0.16607909968921117, 0.1651293406529086, 0.12393864164394991, 0.14836445025035314, 0.22396678131605896, 0.27283393698079245, 0.11914678663015366, 0.17995841135936125, 0.19311116130224296, 0.08642346505075693, 0.09495037714285509, 0.1066479001726423, 0.09395241497882775, 0.15470341938946927, 0.183050237596035, 0.13101209779935225, 0.19285938409822329, 0.08501180687120982, 0.11964588984847069, 0.23434748500585556, 0.15378507652453013, 0.11494919258568968, 0.1266454399696418, 0.0911801176677857, 0.11011267639696598, 0.16053048813981668, 0.19910922087728977, 0.13229508538331303, 0.14592861809900828, 0.12936863170138427, 0.1377783947225128, 0.096815066012953, 0.0820467716881207, 0.08424472981797797, 0.12992565466889314, 0.13842673493283136, 0.12995887574340614, 0.18955266582114355, 0.19336779681699617, 0.17331182158419065, 0.110547922684678, 0.1794633657804557, 0.21332633442112378, 0.08950037030237061, 0.0869565832295588, 0.12912172637879848, 0.05912725654031549, 0.09022855372833354, 0.1440496053546667, 0.083483433883105, 0.18389125461024897, 0.08613096896026816, 0.12428613299770014, 0.08792477806231805, 0.06420452373900584, 0.10796205965535981, 0.08343355477388416, 0.09742284339985677, 0.11904462639774595, 0.1348693793905633, 0.17025609341050896, 0.1803687893386398, 0.10787729027548007, 0.16725056325750692, 0.17508353080068315], [0.016322680649214556, 0.050816814082541635, 0.012838132762616234, 0.06091446349663394, 0.024226563583527292, 0.021682135295122862, 0.04538608102926186, 0.011497135523573628, 0.07166363884295736, 0.08493011125496455, 0.03347429360396095, 0.04229779674538544, 0.05722870198743684, 0.031366441531905105, 0.04210375947877765, 0.06796594868813242, 0.0448767013980874, 0.011017227212765386, 0.03439275521252837, 0.04417356948501297, 0.0251733404584229, 0.09740248734929732, 0.020947746666414396, 0.017385909400348152, 0.048844750438417704, 0.05052604825635042, 0.02482205948659352, 0.050485502396311076, 0.04558982473931142, 0.0452040232984083, 0.008548509013572974, 0.018167244170659354, 0.026649690166647946, 0.02242182328232697, 0.04086277660514627, 0.020987904065155556, 0.050995061839265485, 0.05754009527819497, 0.08029840407626969, 0.04805557010695338, 0.02850153436884284, 0.012912709698347109, 0.06447029912046023, 0.0455139780949269, 0.08039486461452075, 0.0327560167892703, 0.028408305353618095, 0.024963135398658257, 0.012462505106148975, 0.017402290932035873, 0.018499448130439435, 0.02964424162304827, 0.02602486458740064, 0.012181476257475359, 0.04122537214841161, 0.002923878641533, 0.05866303002195699, 0.036773324079279385, 0.013952589211320239, 0.03164671042135783, 0.05320398170234902, 0.08568701706826687, 0.052826271791543276, 0.04523195858512606, 0.02633065657157983, 0.04248704016208649, 0.04166537157392927, 0.016763031216604368, 0.030636728009475128, 0.06529526878148317, 0.04934067472017237, 0.046102983810539754, 0.03141397630263652, 0.010935664759017527, 0.04460060549899936, 0.02084444140616272, 0.03218674287199974, 0.022047036161114062, 0.018773678058226193, 0.031740460212209394, 0.028983626714242355, 0.02221431879193655, 0.018565659577559148, 0.011657649767585099, 0.011514053946094853, 0.03711198429976191, 0.018970811140856574, 0.044104138389229774, 0.031620956624725034, 0.03610802049349461, 0.05125981602551682, 0.011449634679593146, 0.008876967460050114, 0.037384894476937394, 0.01637866996627833, 0.018212928237127404, 0.01529560424387455, 0.017659869610465, 0.03928174251424415, 0.019288353655221205, 0.0066145116080796075, 0.041776892196919234, 0.025530560308003, 0.03583051663424287, 0.05338059079700282, 0.011508215152259384, 0.036469011301440854, 0.041731603377099545, 0.015205070709011384, 0.054913065529295375, 0.06836614864213125, 0.02824723471089133, 0.028991931982870613, 0.03988330791305218, 0.03380440089053341, 0.027681367039414387, 0.03428133976246629, 0.022883342445961068, 0.02270346281251737, 0.01820366284144776, 0.10128216059612376, 0.05119187092142446, 0.03327264656711902, 0.024254224063562493, 0.03956653044692107, 0.021540217999634997, 0.03262316981064422, 0.02659099519119731, 0.03588861619521465, 0.023746751115790436, 0.027759127152551497, 0.05389565994430866, 0.010450200942744101, 0.06499899325094052, 0.08843522638614688, 0.030000486078539064, 0.017925108949254667, 0.011849378318791943, 0.013114387269264885, 0.08216882656727519, 0.017417890452114598, 0.04458181347165789, 0.027455079003370235, 0.010313834911877555, 0.03992866458637374, 0.005830850310823215, 0.059461367183497975, 0.028124306217900345, 0.02155042825532811, 0.013477773305826952, 0.04107733955606818, 0.03486035744260464, 0.0034842429699243178, 0.04653204185888171, 0.01692252087273768, 0.018206217525792972, 0.09773736473705087, 0.10080110640930277, 0.020626353465818932, 0.07043485942163638, 0.005016640942942883, 0.018363306864297817, 0.040832290026758394, 0.044369798419731, 0.03586560368005719, 0.060089772034968646, 0.07491148742181913, 0.07190282243703093, 0.044294939043798616, 0.031960631255060434, 0.0351550723426044, 0.03373199102601834, 0.0617069381156138, 0.04003157459997705, 0.0342150197497436, 0.022712853737175465, 0.03177380681570087, 0.044740868865379264, 0.0344825016467699, 0.044096416660717556, 0.031030366529843638, 0.02954516533230032, 0.041239394074571986, 0.038673381587224345, 0.016149469318666627, 0.040070091640310626, 0.020371816320610896, 0.04464236593672207, 0.018412705909992968, 0.06604690916304078, 0.06692121510526963, 0.03703325388154813, 0.024429638936583484, 0.010677885912757899, 0.02383285720965692, 0.027829657475064908, 0.009085735721912767, 0.022467872061367546, 0.019170458195731044, 0.04324743364538465, 0.021186568940590535, 0.09019063040614128, 0.011304827673094613, 0.022620725645018474, 0.00620039871760777, 0.04299581928976944, 0.038099880396787605, 0.053150021204991, 0.040098006570977826, 0.03274408135829227, 0.014551113925075956, 0.055651019859526835, 0.01675466657616198, 0.05302632427109139, 0.0290203524221267, 0.06215381449354546, 0.016553258722914115, 0.05461225738482816, 0.06671513044940573, 0.04743421184165137, 0.07262735534459352, 0.030415525593395745, 0.023144569946452975, 0.02721091835493488, 0.025799066792907457, 0.032284275495580265, 0.028775560736124004, 0.04614394357694047, 0.030505353451839516, 0.056962763757577965, 0.027379929553717375, 0.012765028247875827, 0.020092441401045238, 0.019433461761634265, 0.007527914313998605, 0.013646625048880066, 0.01255252125806042, 0.04604159674740263, 0.057302173759256086, 0.019075006978320222, 0.029321794996836355, 0.011516312619538178, 0.013766162563115358, 0.013600905359323536, 0.036329188982823064, 0.05883963233126061, 0.03182444249146751, 0.026110319287649224, 0.050195815440799506, 0.01448000006244651, 0.04224179385762129, 0.02965737127565912, 0.03852597324709807, 0.027820280121107186, 0.023533630051783154, 0.0384789677336812, 0.04330440344555037, 0.0049781531644319844, 0.03825987895418491, 0.029793437902948687, 0.03928757452272943, 0.04497384047135711, 0.06848693466080086, 0.063482820322471, 0.030111643685294048, 0.04406753142497369, 0.05126266926527023, 0.01864801167643496, 0.03940357347684247, 0.03256304482264178, 0.05640319289107408, 0.02551111688704363, 0.056171089809920104, 0.023101313339014138, 0.042912356089800596, 0.0067474959900469655, 0.039412913511374166, 0.0059701179270632565, 0.01729303491967065, 0.019281128953610147, 0.03204108854489667, 0.04363638688144939, 0.02693209983408451, 0.02485253249428102, 0.023965726240671108, 0.04569086538893836, 0.004952438807647143, 0.05070742745218532, 0.011249174230865069, 0.05961586282189403, 0.007349970201695604, 0.05406051002708929, 0.07271560560911894, 0.07660556544682809, 0.07469389481203896, 0.023129655746743083, 0.07035341486334801, 0.02417620949979339, 0.02060200593301228, 0.037205774802714586, 0.015149787068367004, 0.01622690543133233, 0.02731354677650545, 0.05423400125333241, 0.014702135464176536, 0.022251536437709416, 0.01808469699296568, 0.03123216962973986, 0.05177532622058477, 0.02678336326165923, 0.0014015703782206401, 0.024349359762189642, 0.07036769124014036, 0.03206568543932267, 0.039926696834819655, 0.04150454181113413, 0.025065383840618388, 0.06983792502433062, 0.06026778569711106, 0.032799032516777515, 0.08314409173492875, 0.04178898369095155, 0.01655209673169468, 0.020178683201915452, 0.014090868710939373, 0.036421904007771184, 0.0547583256182926, 0.025291174849761382, 0.07528944499790668, 0.0777879941410252, 0.022564614191651344, 0.046895458429519615, 0.06846242597592728, 0.0795090507183756, 0.03058732726744243, 0.0197980691612299, 0.0760994122496673, 0.03709620496790324, 0.00399177147275103, 0.042782657513661046, 0.044662297902894874, 0.07356095846210207, 0.04477165060650025, 0.031920845354241986, 0.024300703712339913, 0.03899841003918222, 0.039023889029132466, 0.06205242779105902, 0.0071022217993491465, 0.034614079764911106, 0.03499890411538737, 0.06883222077574049, 0.11247067379632167, 0.11735321501536028, 0.1729306070400136, 0.09976929213319506, 0.1796239207365683, 0.09620192819940192, 0.07972888249371733, 0.14587186543004854, 0.07218820069517408, 0.18049738529537404, 0.10732983465173415, 0.08229085430502892, 0.14594369514712266, 0.15404264841760906, 0.07712762350482599, 0.15887309850326606, 0.12410086579620838, 0.11026926870856966, 0.08428217816565718, 0.10081376108740057, 0.1415124000715358, 0.14291965455881186, 0.10535097547939845, 0.15440613962709904, 0.10726885470960822, 0.1556785013526678, 0.2368674554995128, 0.10632197266178471, 0.09021623153239489, 0.17235086672008038, 0.11773126758635044, 0.11150433136416332, 0.15786398122353212, 0.11887955239840917, 0.11243265547922679, 0.14117662023220742, 0.10713370410459382, 0.20113257159079823, 0.1844864926700081, 0.1393163486250809, 0.08152231840150696, 0.10050481052270957, 0.11371058119194848, 0.13816855235823564, 0.15939563832112721, 0.11711925614093031, 0.11931597255170345, 0.05797735681491239, 0.08152257624481406, 0.12246247514017991, 0.10920110531151295, 0.11799183860421181, 0.15305235369929246, 0.15328570189220564, 0.14111164371882165, 0.06856994663498231, 0.09343813971749373, 0.13384616215314182, 0.06330779899976083, 0.06276233826896974, 0.19333145448139735, 0.14416259500597203, 0.1522144986582654, 0.13928365680788243, 0.1483423300087452, 0.10950958090169088, 0.11131356802902051, 0.039772954370294294, 0.0745284069063408, 0.1252214392381055, 0.24236966882433209, 0.10201292924050774, 0.12659080432994024, 0.1875319749649082, 0.091648666454213, 0.168989146394389, 0.10748557879456452, 0.05776886335973229, 0.08107545559427567, 0.08316260217023747, 0.11835634761622973, 0.15606632482792648, 0.15533100999891758, 0.0865379406937531, 0.10421086022896425, 0.10608665671731744, 0.156472808016198, 0.15730488193886621, 0.10557829149599586, 0.10717700820948396, 0.13522884010204247, 0.06115304997989109, 0.11768347157963685, 0.08363337655152593, 0.14968082175723144, 0.0728389700608594, 0.11586642265319824, 0.15647681137280806, 0.09189599246851035, 0.05671283895415919, 0.11642628189708505, 0.0702632579154202, 0.24493716391069548, 0.1188273730554751, 0.11137834776725088, 0.1025214030274323, 0.12973886754895958, 0.11888400358813149, 0.10159280749836139, 0.14781280128019197, 0.18985398965222494, 0.19379623739847116, 0.1221790782042912, 0.13140663877129555, 0.11929424586040632, 0.08377867125506912, 0.07900481777531759, 0.09824635421058961, 0.15840637497603893, 0.05308253750471132, 0.14429936052433082, 0.0903745608936463, 0.127931752375194, 0.1347372414810317, 0.15067887891616139, 0.10861379932612181, 0.15565809101930686, 0.1903973197830575, 0.1408573423645326, 0.09097992948123387, 0.2018544107143368, 0.21356253246111528, 0.1271382463829858, 0.12543459422886372, 0.12010592302041394, 0.12063045773122992, 0.20357787609100342, 0.10776639051203217, 0.17411078299794877, 0.18225460100386823, 0.10549427528998681, 0.18808544240891933, 0.1358012386730739, 0.08826513801302228, 0.19203870956386837, 0.14614289945789746, 0.12374806829861232, 0.12006221179451261, 0.10013616244707789, 0.13061086647212505, 0.18085517681070737, 0.143186766654253, 0.10395168699324131, 0.13464302010834217, 0.18351303919085435, 0.10969229681151253, 0.2050975909722703, 0.14868759576763424, 0.11919007716434342, 0.1521706652960607, 0.15326905064284801, 0.07840003951319627, 0.12221328993993145, 0.11618736971701894, 0.09743528773209878, 0.08759289301399674, 0.15640552448374884, 0.1309496590069362, 0.11525382766766207, 0.1621111218950578, 0.12403962122542517, 0.09903205705008336, 0.08775600604712963, 0.046777342446148396, 0.12705504441899912, 0.2210562867777688], [0.02040099841542542, 0.053047582773225646, 0.044635054721896134, 0.03339085754539285, 0.028064866550266743, 0.08031056342380387, 0.13250368061874593, 0.08183141824390207, 0.02589501503721944, 0.03465206415525504, 0.04829275880807212, 0.040658313647976944, 0.027886065787502697, 0.02724552703356104, 0.014854929676013333, 0.033778538528297625, 0.012889171318550195, 0.07561315369925328, 0.05632959898295147, 0.02952992882845657, 0.07279771513172559, 0.0504469344658511, 0.059688228581632884, 0.016648499594469155, 0.02426941137361739, 0.057393036383603296, 0.061203750116484504, 0.006058371160179377, 0.03589581545176251, 0.03513566284839596, 0.104351663030684, 0.03678143596542733, 0.019353872996621897, 0.020665535470470786, 0.0224594870648746, 0.013528163012649332, 0.03218618308060935, 0.03125073774052518, 0.03932739435029881, 0.054919050208159854, 0.024386202517364706, 0.023038155299478343, 0.08161451773984091, 0.053489940107933114, 0.030063399845468144, 0.020444355106779506, 0.05221331039709704, 0.025234203353258114, 0.03242600789027555, 0.019165783089452555, 0.014413941285705991, 0.010657229610452694, 0.017150931027052656, 0.05862624663859606, 0.00706127772407074, 0.027132740942761302, 0.008683820770654296, 0.00860459587004568, 0.010305390543570476, 0.05346934996279223, 0.010227429414434093, 0.016561638630394424, 0.05233827619148152, 0.010287924204021692, 0.08474130210067544, 0.10157861933112144, 0.055550566142691035, 0.004794063221197575, 0.028364112367853522, 0.04912451721195664, 0.1280865262129477, 0.0251457020307758, 0.06363750595067229, 0.02917933996234621, 0.04755283672628658, 0.04368204550285425, 0.040884299735937796, 0.04403719751696501, 0.03521075631890978, 0.04285262804478407, 0.04175067360379866, 0.014374961145222187, 0.021385457732581666, 0.030488569888153245, 0.05835931096225977, 0.061110105498560836, 0.06828684825450182, 0.02678194173079516, 0.051586595097822804, 0.08713955698268754, 0.041070082624043734, 0.024429906957915852, 0.07859954916472946, 0.017447678139433265, 0.022004710842988322, 0.05454155742856009, 0.008060816209763288, 0.04060334552611623, 0.11337543239018746, 0.031730767339468, 0.04490658747298377, 0.019032213471031616, 0.030870853124984672, 0.039673501492611, 0.022973166911729744, 0.03962161052705986, 0.022392753145790527, 0.07743997352996043, 0.0016432770623526136, 0.013373007498947638, 0.018189483155895556, 0.04277651337906718, 0.02439559853103544, 0.04580607384975467, 0.05844173261097499, 0.0312891835346818, 0.017876554679657732, 0.01447645980598671, 0.030478690418281724, 0.010845038773758071, 0.07923937376056399, 0.002906882399526824, 0.04181400127708912, 0.023173690973115817, 0.02721785637550056, 0.06057575238602502, 0.01244193107621478, 0.042690895830414126, 0.013993334391021302, 0.034162853977509906, 0.04178204567038587, 0.029610654139625173, 0.014864814234897494, 0.045749769013907225, 0.017062796113480414, 0.02913957441757832, 0.03985626829255905, 0.03439723354365144, 0.03505711902731231, 0.013347075586872441, 0.00958043524795877, 0.03877488024798887, 0.04345513999994312, 0.023546573107263873, 0.05810652952641249, 0.08156418401215758, 0.04576410645885127, 0.03344583245260375, 0.022950403758191636, 0.027894701841952543, 0.05182577869189637, 0.039047888812742064, 0.027628967172599266, 0.018772694182449153, 0.04285671961094652, 0.05726603498416288, 0.030113563939396824, 0.044502760749310255, 0.02927568175696901, 0.04688139579125813, 0.013190913296836828, 0.013559039748672928, 0.016084367276302407, 0.0821653049705284, 0.08317676998142685, 0.05533758757103767, 0.02416103576043887, 0.07886839830981833, 0.022302026228447045, 0.024092832813039422, 0.002664665753919897, 0.0005285885864785606, 0.023306936591065357, 0.0643628259588565, 0.011814304843678005, 0.02473154291510582, 0.0543948547648532, 0.02468643899607871, 0.024341867039246217, 0.03855603913377438, 0.02743429208307394, 0.0462777676459934, 0.08172826056501695, 0.0307941786678774, 0.028754750067102056, 0.04204371930765254, 0.03323659600157823, 0.010727636948493975, 0.03161240369081497, 0.010980398028290697, 0.0486910826127444, 0.01662296462537987, 0.004672236923527504, 0.009755454874331397, 0.045623117060001404, 0.01300297606004668, 0.040467350145003626, 0.05376264672460301, 0.020741914764844945, 0.063788459636271, 0.031564794281231504, 0.022896109082336937, 0.03913378456075277, 0.06237964451845203, 0.00611202377227268, 0.05514872752662216, 0.0664565000416977, 0.02421435504220426, 0.04545797181448766, 0.024815002722399573, 0.022542173342247094, 0.008801834973772722, 0.045759349928370545, 0.03241121582686901, 0.02346895548648068, 0.0369828658710633, 0.00945691388499524, 0.0356277839413711, 0.056552616480205736, 0.03183059001873646, 0.039576009581131597, 0.057479393535426686, 0.03366005952869143, 0.01039562891570053, 0.04593341112402933, 0.016290462110191584, 0.059451786269034655, 0.04400956078565546, 0.028961075602897575, 0.04067820150937353, 0.03716797700950077, 0.017191811065588678, 0.03284426026844552, 0.1375343392470053, 0.0534788528457284, 0.04223328163581235, 0.06508521469576017, 0.006364244144476418, 0.014903003882084574, 0.05112932695608054, 0.04915095632895827, 0.02946720165865762, 0.06962662243417331, 0.01322243973014078, 0.03159144035141383, 0.04407100213159408, 0.022277103637212088, 0.04283212610919561, 0.029845902230590582, 0.035731708364827294, 0.07376524500016655, 0.054052533847945075, 0.03723575247983847, 0.08008305063205105, 0.028587949196142808, 0.01848581975458988, 0.031134986451693943, 0.05975992259170328, 0.02101267228967377, 0.058828897907265594, 0.06064352446368762, 0.030558072230113403, 0.04844588041305542, 0.025374420918524265, 0.04972753467570458, 0.0843896581126111, 0.04958159536389368, 0.0289661340814616, 0.06230317362185035, 0.01967204824489142, 0.009145993872412612, 0.015855439739035707, 0.014117023691401949, 0.013474134661789452, 0.08713661892605679, 0.059730922005006244, 0.03727320761286786, 0.01784045322399054, 0.03922019599537764, 0.020343165179448466, 0.035065848380327225, 0.03966522675805858, 0.03817137084635241, 0.03911494503595999, 0.013833847279394311, 0.023021899296769073, 0.07300417298184973, 0.0065365542957027045, 0.0357855229771563, 0.043086430856159756, 0.09718713390507869, 0.02324108816018062, 0.03719453826280577, 0.029899937366800647, 0.10231956600078515, 0.02903381794957178, 0.056185383150087934, 0.03474136954173446, 0.006042838221349354, 0.04920102882065943, 0.024382297548332384, 0.05351299333519169, 0.04393686254375747, 0.026380182842590978, 0.006590933788434735, 0.016667155914806893, 0.04234002537227102, 0.10748935823461839, 0.04696807524721537, 0.012017748301981815, 0.050991319718637636, 0.01429738593287766, 0.04970043059438467, 0.03152611778516855, 0.04318255212690149, 0.012547824099393827, 0.025629607761012654, 0.060128624950136454, 0.029976706818810532, 0.018503716115706732, 0.039273915612804036, 0.07305525988340378, 0.10220987402967044, 0.029088741966656277, 0.003069063719262236, 0.016106450198484317, 0.058441895459379466, 0.023439077893272042, 0.024521785688453486, 0.040864808817527125, 0.04129477271011897, 0.009486078168265522, 0.03190360377941813, 0.020514434203505516, 0.04865539845611368, 0.0728169312434537, 0.024048979094784175, 0.01713662750885955, 0.02715324966369995, 0.03509240284828203, 0.04140118396441851, 0.05917073706431048, 0.02488912928051182, 0.014752716857141681, 0.07299073798848049, 0.061405288587723456, 0.012433280602895787, 0.01773186556861869, 0.03133823483117989, 0.05581425842163818, 0.006990343249136848, 0.0444018795554127, 0.14504436483340605, 0.10033865086734295, 0.10327794243182455, 0.0962274953989046, 0.09279341609882456, 0.10037062343742166, 0.22480037515716894, 0.11824322225792067, 0.11155985588473932, 0.15981926130396978, 0.17574175048087323, 0.21274227861847195, 0.11906593239733151, 0.15671921122287, 0.09781497557248388, 0.09879054608089582, 0.11735577987773077, 0.14044103398919106, 0.11477075144648552, 0.13864014776689665, 0.2162895104182618, 0.16966181887047632, 0.11424928371395383, 0.15034490397998265, 0.11692090678427901, 0.09121981196637664, 0.09981630103928701, 0.10805476789495774, 0.07419143963072981, 0.08873999038977282, 0.15958102765892232, 0.09565785168004887, 0.10099549990679536, 0.10692267971379416, 0.06777717346059424, 0.07418580779007503, 0.13574986000146183, 0.1829809455999306, 0.14010857897145407, 0.170167422454272, 0.06567066149520022, 0.11604354743446622, 0.1492455279720681, 0.15692783359970364, 0.06643388446952615, 0.11234269530645438, 0.14155212151152746, 0.1288838591426611, 0.11289941971855504, 0.13114840191389832, 0.16685148967163904, 0.1198105024439948, 0.12671657758099691, 0.16146166888730867, 0.10715337483478443, 0.10582136309572629, 0.07972593086638621, 0.21978863408522947, 0.11203837913594075, 0.1470012462564877, 0.11052135803869792, 0.10556353335934025, 0.09476239580128874, 0.09824993687548808, 0.1416377390601805, 0.3205447196960449, 0.2036728709936142, 0.10163411671029669, 0.061120202099638324, 0.10254897190523998, 0.15334348593439373, 0.10726248326578311, 0.09192151217056171, 0.09490290004760027, 0.18451841095728533, 0.12914607221526758, 0.11577465757727623, 0.1487640259521348, 0.1373688852680581, 0.1591025519051722, 0.15739325433969498, 0.12817605212330818, 0.12376505881547928, 0.1167580990919045, 0.11949475295841694, 0.11874449678829738, 0.11860861336546284, 0.10511026518153292, 0.10157996283045836, 0.196384780641113, 0.12137747050396033, 0.11202382455979075, 0.2848357558250427, 0.05090617375182254, 0.1012647222461445, 0.14338693448475429, 0.0796315059331911, 0.07402234870408263, 0.27902771319661823, 0.12364145687648229, 0.15320885101599352, 0.0720994279586843, 0.13488590850361756, 0.09861272240855865, 0.13482155624244893, 0.1501468260373388, 0.08674973182912384, 0.14598204594637665, 0.10551984248948948, 0.13748046356652463, 0.15557369483368738, 0.09870433142142636, 0.15837831076766762, 0.16895720096571104, 0.19246362176324638, 0.11518703268042632, 0.0999626542574593, 0.10373649639742714, 0.1504825787352664, 0.12266621206487928, 0.1412290438477482, 0.08962445400123085, 0.10663532691874675, 0.08877292647957802, 0.0769352927537901, 0.1916195513414485, 0.1726845023887498, 0.08197416844112532, 0.1487675950463329, 0.044379043459360085, 0.11747962608933449, 0.2096330276025193, 0.10231387987732887, 0.09514268753784043, 0.19485194289258548, 0.10269807997558798, 0.14335806960506098, 0.1515219315354313, 0.12487173586019448, 0.10257707004036222, 0.10015432004417692, 0.16044147791607039, 0.15472483395465783, 0.19801979219274862, 0.07099841668137483, 0.20845342161399977, 0.1984351777604648, 0.13624680547841958, 0.07450233080557414, 0.08897056337445974, 0.15553995807256016, 0.13320852922541754, 0.1351539162652833, 0.09408029168844223, 0.08403416683099099, 0.09844392325196948, 0.12405141416404929, 0.18917366330112728, 0.07690619038684027, 0.1317484847136906, 0.1131529611136232, 0.12063849158585072, 0.07277896042381014, 0.10705260559916496, 0.2379908109349864, 0.16964782747839177, 0.11316775996237993, 0.08920768422207662, 0.12374626339546271, 0.09554872967834983, 0.0664244731888175, 0.12329210633678095, 0.12155764869281224, 0.151802817891751, 0.1313871241041592, 0.15918033915971005], [0.06297595466354064, 0.03818719767566238, 0.06216945472572531, 0.025960079760157635, 0.01865012870569314, 0.02674840683383601, 0.012351112556643784, 0.027694347414321134, 0.037671422851937156, 0.019989921545077647, 0.034120102878659964, 0.044390758366457055, 0.02944408736324736, 0.02350789661120091, 0.027644393666248237, 0.029760674839573245, 0.03391556188996349, 0.0641383258625865, 0.04822003681744848, 0.08890432478593928, 0.022669827831642966, 0.024683545044224178, 0.025828311652211205, 0.08131754331822906, 0.07386630600584404, 0.019157163998378173, 0.00745521267942552, 0.06322202538805348, 0.01653028352718268, 0.0502164021932653, 0.06403391289391688, 0.031038922856428793, 0.046541514207742045, 0.0278136728863631, 0.10167853361261742, 0.03352940082550049, 0.05937174627823489, 0.013194946339353919, 0.013822950855163591, 0.005921184526024652, 0.057149503380060196, 0.06090932698654277, 0.06373884515570742, 0.023346792041723217, 0.024789608549326658, 0.06303900413747344, 0.030850432613598447, 0.014938153692388108, 0.074691167101264, 0.02289460951994572, 0.034277176950126886, 0.029444331635854075, 0.06920312158763409, 0.02993735178772892, 0.017874553001352718, 0.09790567534842662, 0.022918968927115202, 0.0286579366906413, 0.010635216238110192, 0.043464038986712694, 0.06684772976275001, 0.04196290917960661, 0.02323017731708075, 0.038929735509944816, 0.046243467700800726, 0.02926431968808174, 0.01676627970300615, 0.054856285718934875, 0.007410170676718865, 0.035047382049794705, 0.02781522842789335, 0.02750121768830078, 0.017256171808445027, 0.01195921702310443, 0.030479999990867715, 0.01337353336358709, 0.03857150973219957, 0.03767645758177553, 0.03816720124866281, 0.019570788767720972, 0.045271008275449276, 0.031026912786598717, 0.05388103412198169, 0.01915473653934896, 0.02656568922767682, 0.012206660932861269, 0.0541574964299798, 0.031540702895394394, 0.05454025464132428, 0.028219662440408553, 0.012338063480066401, 0.02939048988212432, 0.04079527933416622, 0.051155308061944585, 0.027024490858561227, 0.026793631192828928, 0.07506472098508052, 0.02937798448173063, 0.021073611519698585, 0.09343456383794546, 0.014283179105924708, 0.02475456560828856, 0.062415817220296176, 0.016317686631477306, 0.02994740767670529, 0.03308395615645817, 0.0778013477101922, 0.06607916671782732, 0.0354034772275814, 0.027351288590580225, 0.010809850795859737, 0.021972633099981716, 0.02460964409900563, 0.0284849374022867, 0.04776103162605848, 0.02493459451943636, 0.07396940261657749, 0.06001083805624928, 0.030326953024736474, 0.026642217799755077, 0.025112966108801107, 0.047964415712548156, 0.024300732550078204, 0.035406323681984625, 0.02740357649911727, 0.02457379879030798, 0.01843402039126626, 0.05722710743014302, 0.05410350879122104, 0.1041681193081396, 0.01522922994835036, 0.008051095347452377, 0.04071547683062298, 0.04069813686822142, 0.02247494918161205, 0.0059286657986896375, 0.05633127496444753, 0.0530431383688535, 0.040748372208327055, 0.03363546263426542, 0.0005391642968918729, 0.05458793529708471, 0.04410418249400599, 0.028822606961641992, 0.0739948476797768, 0.0239893256886197, 0.04359019221737981, 0.054376178088464906, 0.043009915854781866, 0.003945600133322711, 0.06367858446070127, 0.035933016134159904, 0.02439331865337278, 0.04107769578695297, 0.01640693603881768, 0.04308095847123435, 0.061993117045078955, 0.00831652297970972, 0.04832211901832904, 0.046744226544563255, 0.04472597162904484, 0.024815776252320836, 0.02181135380773672, 0.03692217769899538, 0.07267266112778868, 0.024957934427740316, 0.018824293377942274, 0.0411367690456765, 0.02844829311860459, 0.08203795073287827, 0.03578690379591925, 0.015476476234783019, 0.08958585214401994, 0.029108989451612746, 0.010192278755961784, 0.05886044300028256, 0.057244572921523025, 0.021499755260135447, 0.012866223264219505, 0.06620048199381147, 0.028769681230187416, 0.05065867131842034, 0.028787662408181598, 0.04333041847816535, 0.052415249203997, 0.03639928504292454, 0.018190916561122452, 0.01615569827013782, 0.04329021527831044, 0.009603955816211445, 0.030426660353051763, 0.028120630254436816, 0.016315471214641417, 0.04101917214159455, 0.059144104564828534, 0.056388438147093566, 0.061219057866505215, 0.06727129167744092, 0.04259747512904661, 0.050286562714193545, 0.04288700602150389, 0.008926384317289506, 0.0437504452254091, 0.04780738574585744, 0.02644107796783958, 0.09645113375570093, 0.02995904455227511, 0.045364374694015296, 0.023351149932880486, 0.02876152184658817, 0.1260173608149801, 0.08666741196066141, 0.013947110889213426, 0.011523690839697207, 0.025932088494300842, 0.03732642850705555, 0.06620830550257649, 0.03420625986265285, 0.04160533479547926, 0.027914493012108972, 0.03658225201070309, 0.036402542011014054, 0.030958560561495166, 0.009878944006881543, 0.06508345050471169, 0.03437309805303812, 0.0734385032472866, 0.030115239920892885, 0.018931797073621835, 0.025478326682267443, 0.044990695281220336, 0.05940200215471642, 0.032745675915586095, 0.047951391232865195, 0.04210844137040632, 0.029394666265164102, 0.11718529116894517, 0.020737059846786515, 0.04777431734172361, 0.026075546064281037, 0.03536993384893451, 0.04675003480432289, 0.032714191890720806, 0.04296431830152869, 0.006258787928215627, 0.05976921173610857, 0.06042564008384943, 0.020210665950019444, 0.01828001329808363, 0.0526169640943408, 0.06538860805864845, 0.037771618725465875, 0.05972000437655619, 0.01743344926009221, 0.0285098871349224, 0.05051609414762684, 0.009011741478129156, 0.0991355064990265, 0.028382258090589727, 0.019265794062188694, 0.052249591664544175, 0.024895327697907175, 0.014525275311565824, 0.039340103311198096, 0.025166795988168036, 0.023043810888858776, 0.019872758903407624, 0.015753840994355933, 0.017472666887832538, 0.02745336739878569, 0.05534659851608532, 0.01538473490758666, 0.03612581846703376, 0.04777985079480069, 0.019853520739291395, 0.052348345651158264, 0.01371225550039006, 0.012170592555776238, 0.03910301299765706, 0.03638507991230913, 0.020337477359654646, 0.06654188010309424, 0.021347293530457785, 0.0590282989931958, 0.041198624297976494, 0.057115400210022926, 0.06514587572642735, 0.06422796712390014, 0.05036930666704263, 0.024609852748523866, 0.006175239911369447, 0.07265956540192876, 0.01595399864683194, 0.01397643462821309, 0.020272967339094197, 0.023026676183300357, 0.03361061468188252, 0.024537273250254135, 0.010401531322193997, 0.02757237565570644, 0.06478954984673432, 0.01424027533669557, 0.040112869880561314, 0.03420300967991352, 0.03784455445462039, 0.007058050017803907, 0.024495936896918074, 0.008016953161651534, 0.01644406547503812, 0.013175653044267424, 0.02393626425016139, 0.03302689136138984, 0.05498308016519461, 0.02011224953457713, 0.030866907443851233, 0.039214557369372675, 0.057341739136193476, 0.032658199180981944, 0.1073373935318419, 0.06982428647045578, 0.04572644776531628, 0.026075049037379876, 0.016434918822986738, 0.02751627946937723, 0.046336237008550336, 0.06973088612513882, 0.06174655777535268, 0.07259293326309749, 0.028351182883073176, 0.02906072186306119, 0.06565053614654712, 0.027789293123143058, 0.041107836312481334, 0.08027594456715242, 0.009039201790333858, 0.030410348371203457, 0.02361727984888213, 0.028397562447935343, 0.024086585201855217, 0.0647834362462163, 0.034465443276401074, 0.05272649660972612, 0.047505458018609455, 0.011362392039570426, 0.024651843888152922, 0.017784068660278405, 0.03528230444395116, 0.04834269220009446, 0.0349257410770016, 0.031231263785489967, 0.02002765148478959, 0.05018892152501004, 0.08038512085165296, 0.04868721157046301, 0.18867552360253675, 0.19101895285504206, 0.12235720721738678, 0.11591679709298269, 0.10075219081980841, 0.10356910180832658, 0.12140922594283308, 0.08899245291416134, 0.1147670466452837, 0.1323718684060233, 0.09084815798061234, 0.13181088279400552, 0.19357488570468767, 0.1494754563484873, 0.12079576243247304, 0.19176812336913177, 0.11191574750202042, 0.18747983633407525, 0.13901832247419016, 0.11111900489777327, 0.1444269386785371, 0.1043181773275137, 0.13527989307684557, 0.13238865536238464, 0.10690315147595746, 0.17513884497540338, 0.07590239960700274, 0.2223295441695622, 0.17814472796661512, 0.12703715823590755, 0.13757533633283206, 0.07969962406371321, 0.2064810831631933, 0.15777224328901085, 0.18787175816084656, 0.08978661029998745, 0.0911917138312544, 0.11024577104087387, 0.11417294852435589, 0.13171406941754477, 0.2464465514889785, 0.14886500553361007, 0.08688211401126214, 0.12622056848236493, 0.09819673973002604, 0.0944901607664568, 0.119262286861028, 0.0976553705653974, 0.07148226643247263, 0.14745880956096308, 0.19345230156821863, 0.05170948796772531, 0.15059423845793518, 0.17191143387130328, 0.12524707429111004, 0.1558620450752122, 0.1357389898704631, 0.10687484299497944, 0.23923128151467868, 0.15253541858068534, 0.18352773625935825, 0.06830373020576579, 0.11282689789576189, 0.13673544568674906, 0.09853812426860843, 0.16769470513931342, 0.21180017345717975, 0.1210124593760286, 0.08516338480902569, 0.06137136862214122, 0.20340556890836783, 0.12926465299512657, 0.1410400447036539, 0.15731204726866313, 0.15943502049360955, 0.11438368793044772, 0.12591792829334736, 0.11425403345908437, 0.09654162997113806, 0.10599740900631462, 0.14723607365574154, 0.10001402614372117, 0.13379631697067193, 0.10690431177083935, 0.10248799874846425, 0.16509420610964298, 0.20031480118632317, 0.16651193717760698, 0.09055432517613683, 0.11582451633044652, 0.13212641514837742, 0.1020144559442997, 0.12284036486276559, 0.14879869909158774, 0.1506797202995845, 0.11986720083015305, 0.07300502793597323, 0.16399130171963147, 0.17220514453947544, 0.10177219180124146, 0.15281600638159684, 0.1027033861194338, 0.1896680032036134, 0.17050582143877233, 0.16912182713193552, 0.11459169962576457, 0.11732219239430768, 0.13309824014348642, 0.11997252303574767, 0.16903559890176567, 0.13063206390610763, 0.1828095205128193, 0.07226538405354534, 0.12499011307954788, 0.20009961059050901, 0.1533167109425579, 0.1791356605078493, 0.09452989577714886, 0.0867618504645569, 0.17485561088791915, 0.09454184477882725, 0.1569370345345565, 0.16910879925957747, 0.15293001383543015, 0.137244224814432, 0.16412736156157084, 0.1329753574516092, 0.13483505908932003, 0.09325498954526015, 0.08222365219678197, 0.11634868463235241, 0.15158993431500026, 0.10305713356605598, 0.10116410907357931, 0.34465885002698216, 0.15564682733799728, 0.13229190983942576, 0.10773266732160534, 0.11516386749488966, 0.08112983339067016, 0.17277121916413307, 0.10513777977653913, 0.14026122220924922, 0.1368326119014195, 0.14854637905955315, 0.09106309751846961, 0.14879477715917996, 0.14126818174762384, 0.1602385009505919, 0.1128703716344067, 0.09724985768220254, 0.12406753615609237, 0.1691474893263408, 0.17406857811978885, 0.10537607448973826, 0.11239798912512404, 0.09923737496137619, 0.08202596780444894, 0.16295378096401691, 0.09953601857913391, 0.08982295263558626, 0.09607907943427563, 0.15501488053372928, 0.12890401163271495, 0.19437548917319092, 0.16295848999704632, 0.13968296109565667, 0.14015305015657628, 0.14765692821570806, 0.10884062679750578, 0.1476049524332796, 0.12965073942073754, 0.07762969870652471, 0.10647286527923175], [0.05032645718061498, 0.05900300320770059, 0.022315871735502566, 0.10008460735636097, 0.06060504474278007, 0.020197169888498526, 0.0546328203885683, 0.006815601822121867, 0.05229267185287816, 0.02999906794035009, 0.06457400641271047, 0.06246906186320952, 0.02979898153405104, 0.08213545621505805, 0.03766418627596327, 0.02320932932863278, 0.03849181240158422, 0.05913428616310869, 0.013039567757264843, 0.026587614390466894, 0.061600781311946254, 0.015016475293253149, 0.058889423230929036, 0.01717963645101658, 0.030225315264293125, 0.08378604014537164, 0.03543708845973015, 0.004456302059614765, 0.018860097974538803, 0.04091818916744419, 0.012164043844677508, 0.0616174257759537, 0.06728003120848111, 0.021237009537539313, 0.054844092444649765, 0.01637684470707817, 0.053591282705643346, 0.025932554987126162, 0.021145032419423972, 0.05449092175279345, 0.034178100659378936, 0.01874883858753102, 0.0776650978784476, 0.03704500610807112, 0.04874435778973358, 0.030727502424269915, 0.03150901531002351, 0.05800780268119914, 0.025390868607376302, 0.057496825100055764, 0.05618027038872242, 0.0459873444799866, 0.10272536386868783, 0.032200350891798735, 0.002684817395804982, 0.023535370494105985, 0.06924384047410317, 0.015043828736192413, 0.1211056358047894, 0.06303151989621775, 0.04866834490426949, 0.03827847081369587, 0.03154328472114035, 0.04881913234878864, 0.06954197519059692, 0.04847122708867703, 0.03720984262015138, 0.052118637798620124, 0.023765214053647857, 0.048310146267924986, 0.013900617669735636, 0.059745591932109425, 0.04409537510946393, 0.01644077118752258, 0.020001650022874986, 0.08017366898379155, 0.04500091401860118, 0.014745078249169248, 0.0332040263206831, 0.014971507081229771, 0.03150458447635174, 0.047223764205617566, 0.006130904433250959, 0.02732539060525596, 0.0166736800290112, 0.02106634440964886, 0.06165667902678251, 0.03357682363795383, 0.02526584853019033, 0.01928079647145101, 0.10735735603209053, 0.040990768665713925, 0.04375760376985584, 0.01927589575227882, 0.06940691958048514, 0.027500250775899206, 0.11068356183490582, 0.02654872415587306, 0.013424497280668999, 0.06304056476801634, 0.019496436596715024, 0.028866613350276436, 0.044948130779500516, 0.057523688301444054, 0.027034768967756202, 0.05824324076196977, 0.0116635479332347, 0.019000093319586346, 0.027152605055432235, 0.07422343255685908, 0.01879507226736418, 0.00973838462959975, 0.17254245786794595, 0.0041528840998320705, 0.04169049433299473, 0.004137768460038517, 0.021828624220298867, 0.09258371485131127, 0.06138819629060371, 0.06874406550611768, 0.0225197053514421, 0.02596387785992452, 0.03238535685730832, 0.02314607290151928, 0.018812629360971705, 0.029907516602958952, 0.022984240603234087, 0.04543337831273675, 0.017100604084719504, 0.019229010678827763, 0.051644423244787116, 0.021493068297526667, 0.04381255153566599, 0.043416164948471954, 0.024080430889236074, 0.04469854185091598, 0.048343146818556955, 0.02880118561110326, 0.015362774121708103, 0.014843252088342394, 0.016723338614350984, 0.017864047582926493, 0.020115194376558065, 0.04044177955282586, 0.025745335301118236, 0.05213590990751982, 0.04988424912361162, 0.015867616049945354, 0.000594335502163241, 0.05900708120316267, 0.015215214807540178, 0.026843423788834895, 0.04350139233948929, 0.03588597330131701, 0.040616668561207395, 0.030403881932475736, 0.033007376694253514, 0.05920261463948658, 0.02247625875419804, 0.03776773750515921, 0.0017446994939486363, 0.032240723725408316, 0.018766789231449366, 0.07921304660184042, 0.1011161230770605, 0.03997001790308526, 0.029438234998711517, 0.06571441343320267, 0.06738078008805003, 0.00912365480326116, 0.07716342301240989, 0.06334246535386358, 0.04286577805344548, 0.019672099135017822, 0.012389116454869509, 0.038616734091192484, 0.023189607708315765, 0.013680973339692822, 0.05689603662384408, 0.024213459375979643, 0.02331443949203406, 0.04499788096706782, 0.024495850383703197, 0.033620762173086405, 0.07204446662217379, 0.04956057095634086, 0.05667329054059727, 0.03909512163539018, 0.030676456234816993, 0.01995634423967983, 0.05534452898427844, 0.0705689854387726, 0.01795738346741668, 0.03897346369922161, 0.02933557265039001, 0.04190958311249103, 0.006484897000648613, 0.07142521520810467, 0.025254415215126107, 0.05147452825414283, 0.06326226251465933, 0.03141984223787274, 0.03720859072304197, 0.022679452850882496, 0.02264546842447349, 0.029434435202607086, 0.013805989176034927, 0.02482399670407176, 0.04404886492661067, 0.006646662717685103, 0.021991443787036196, 0.01724210238483335, 0.09166938891368252, 0.012587098554441971, 0.044240724095808606, 0.04365724165524755, 0.008139349004652883, 0.04868370693709169, 0.05253503777618919, 0.031725420483521054, 0.11207838556064026, 0.003689143158096288, 0.038281663320958614, 0.02420867231142308, 0.024146477791613767, 0.04161482071503997, 0.02871609731976475, 0.061803351156413555, 0.009801915015227028, 0.014697397593408823, 0.034074664781136174, 0.05059767780559404, 0.02761219548327582, 0.02222600995030786, 0.044653541408479214, 0.021183064307219217, 0.04572072092975889, 0.08380089327692986, 0.02527351936857615, 0.015566176867910793, 0.021687000391206572, 0.0032172133588963853, 0.02164136721486492, 0.0593580873683095, 0.019760890531220605, 0.01897533018408077, 0.015075979421713522, 0.06412146426737309, 0.06816946169627564, 0.042235011900109906, 0.038361581175455024, 0.06072154242013182, 0.028419360385409424, 0.024204127823135684, 0.05546456861442753, 0.003740013776613133, 0.048585000447928905, 0.015709746396169066, 0.025727549201941917, 0.06172175732042108, 0.03243902897728341, 0.03548975295520254, 0.026451998988964727, 0.10309450727488313, 0.04393167175086481, 0.066527244102742, 0.04558058648503252, 0.055790394345032315, 0.0194737565637167, 0.04725663922727108, 0.10175682976841927, 0.052243342357022424, 0.02249620938008385, 0.04104061724085893, 0.051403709554246495, 0.11177861557475158, 0.0461637059093586, 0.02515993939180459, 0.02976886136457324, 0.05665197775566152, 0.012352394139660256, 0.021955167608601705, 0.02649733530623572, 0.01176903722807765, 0.02728239184112421, 0.023277910559305122, 0.006234853453601578, 0.02523071059424962, 0.07983852018203054, 0.05975901335477829, 0.04046879203191825, 0.04928612389734813, 0.07914833471711193, 0.004820252128411084, 0.015367260934518916, 0.032901450592492304, 0.036232898078326664, 0.04444553649851254, 0.051646326535514424, 0.011905058902422232, 0.009035634392473315, 0.02506418283363538, 0.06540653495384113, 0.010224835714325309, 0.013724352083435016, 0.0047361744301659715, 0.04857161634468606, 0.020940985064953566, 0.09665779516633068, 0.018842841132677028, 0.03453514239351664, 0.05202533923355596, 0.05863006679075105, 0.019226072622197013, 0.015952765409435545, 0.06985856605959789, 0.06112878556762423, 0.035256367442863326, 0.058049261170838556, 0.0335021338957761, 0.03706586766721947, 0.03927667725032993, 0.08259536046534777, 0.05838126835546323, 0.049478488575134955, 0.022881632537714074, 0.04197145193549139, 0.057077008698667796, 0.048964260811252255, 0.016155513369345238, 0.010417991733577634, 0.06178722237902028, 0.030582777690142393, 0.045233994190182, 0.022013328237725154, 0.009022168016859462, 0.03985732341451304, 0.025881736106904488, 0.05135204250525151, 0.04949861053111298, 0.05364280386960932, 0.046538219920226505, 0.012088759536189693, 0.06661876490605728, 0.01947497114140008, 0.05171873979270458, 0.012546114191146833, 0.01648555280241583, 0.029183434921183755, 0.012531459531081575, 0.014376338571310043, 0.01215450618682163, 0.08889253184731517, 0.13547429335968836, 0.2056768834590912, 0.11711605345564229, 0.13867754861712456, 0.11037840428096907, 0.1726173817047051, 0.1347784014152629, 0.16964744749878133, 0.11590185575187206, 0.2676163012427943, 0.1358658487775496, 0.11121983520154442, 0.2465511273060526, 0.122046845299857, 0.16633532808295318, 0.1153166735810893, 0.11496239687715258, 0.11503474228084087, 0.11652442520218236, 0.10993684083223343, 0.25666851869651247, 0.11542138510516711, 0.18952880852988788, 0.17788932738559587, 0.2990047883774553, 0.15238851574914797, 0.099579356610775, 0.09974401670375041, 0.21354351990989276, 0.09047110964144979, 0.11608370313686983, 0.11404070204922132, 0.07820151373744011, 0.1584248582699469, 0.07311033657086746, 0.19072801060974598, 0.08706637019557611, 0.12616666566048348, 0.11698303345058646, 0.10364028691713299, 0.1611067136483533, 0.1624768115580082, 0.11053217388689518, 0.12960668892732688, 0.1252875556903226, 0.2832390272191593, 0.10503910721412726, 0.08811895442860466, 0.17290708901626722, 0.11860239798469202, 0.28790878664169994, 0.1325404436460563, 0.11791766115597316, 0.13821839754070553, 0.12559939681419305, 0.13320775569549628, 0.06685631323073592, 0.1701583300850221, 0.11132382747850247, 0.19035073156867707, 0.19898860449237482, 0.11716678073363644, 0.1556201744824648, 0.17650287678199156, 0.14291178355259554, 0.19914306620401995, 0.17483830824494362, 0.08810893925172941, 0.1200392230280808, 0.15227879663663252, 0.3124439615224089, 0.2523354212088244, 0.08805380149611405, 0.13785919467253344, 0.14412366066660198, 0.14272251299449376, 0.13596940679209574, 0.1564575545489788, 0.131113932334951, 0.10937369069350616, 0.10782256642622606, 0.09799507912248373, 0.09625620421554361, 0.10448443197778293, 0.10141373532158987, 0.12258477429194109, 0.17657592786209925, 0.11364498721169573, 0.1459857371768781, 0.20739002153277397, 0.12292674237063952, 0.12626065633126668, 0.11724108031817845, 0.23269177813615116, 0.09278783854097128, 0.18378434463271073, 0.1142494058502572, 0.11680457874068192, 0.2005436031946114, 0.1118307677762849, 0.09590211071606193, 0.11362264305353165, 0.15399435029498168, 0.10867423644023282, 0.1592351919306176, 0.08503629520003285, 0.11914624380213873, 0.15503318740853242, 0.09734759386628866, 0.10818033080015864, 0.1596356632986239, 0.21626407892576285, 0.14497453000928673, 0.17068187413471086, 0.12665658151464804, 0.12392717440213476, 0.16536792713616574, 0.25475770980119705, 0.17976973791207584, 0.12124947165804249, 0.15125886350870132, 0.09451366521950279, 0.09197667028222765, 0.12472182033317429, 0.10101099764662129, 0.2209670865642173, 0.10494773568851606, 0.1275901235640049, 0.11935386194714478, 0.1422954159123557, 0.13371082155832223, 0.24678853313837731, 0.15980073729796068, 0.131935339687126, 0.11821350242410388, 0.13141246060175554, 0.08951946427779538, 0.17058824987283774, 0.11392943587686334, 0.11792218019919735, 0.08399715953107391, 0.07807668365005936, 0.10910052606569869, 0.15065911997641834, 0.1885272908423628, 0.11956046228962285, 0.15221591001110418, 0.11286003754607268, 0.15005920002503054, 0.14473796556038515, 0.10744847649974482, 0.116267165435212, 0.10289314522274903, 0.11288661576275315, 0.1263337752648762, 0.168363822091903, 0.0827776285420571, 0.13766004464456014, 0.13941914668040617, 0.08528624714485236, 0.1717665802155222, 0.10583532734641007, 0.19866165917898926, 0.3049983967627798, 0.10983206824000392, 0.17426179775169917, 0.18144552941833222, 0.12947377748787403, 0.09744354550327573, 0.1631830579468182, 0.18382866654012883, 0.13091106393507548, 0.06384348882628338, 0.09412253049335309, 0.1323534936777183], [0.033356069054986746, 0.02948435502392905, 0.007984793146273919, 0.059881760339651785, 0.043977486435323954, 0.03553199176011341, 0.02383166807703674, 0.02974639507010579, 0.026376298229609216, 0.10622655028211218, 0.020304400473833084, 0.03459977285404291, 0.011794770668659891, 0.04581033504967179, 0.07018519924687487, 0.05107684227238808, 0.022996511909046342, 0.050842856256557364, 0.05874687659421137, 0.015682828911979283, 0.07124235680592911, 0.06360880391938345, 0.027733285146366273, 0.0628852548875979, 0.043320491510842524, 0.026648182122569, 0.049805271040116034, 0.02460523022870932, 0.006139280948056174, 0.04950518553544368, 0.05810302150036607, 0.07278925380004303, 0.02539104502648115, 0.015928938652255704, 0.04626407820199217, 0.011060400699664439, 0.05805473016308887, 0.062532280970897, 0.019771867531484792, 0.05852921613092933, 0.04450034177196877, 0.07069043642176048, 0.059633531873779635, 0.025680077195699726, 0.02191629264104579, 0.022530546644702554, 0.009594817645847797, 0.0722441119807107, 0.018530828678714376, 0.041187452218894444, 0.03724723329235401, 0.05869705176779202, 0.018364241546286002, 0.0661496122234634, 0.01748303320657994, 0.04014479495318873, 0.06771103665232658, 0.04218650343162673, 0.06362947888140168, 0.042652243083076816, 0.07080081371324402, 0.03586182084732822, 0.01650496568929936, 0.01398219114967755, 0.027919704161052192, 0.017076570374358977, 0.011016732730370547, 0.022283456421324184, 0.044618077775729556, 0.05616187530436686, 0.07098067977598735, 0.006632627644908747, 0.05010027771017381, 0.047391118082617006, 0.054521550823535235, 0.10149380923914057, 0.02461310293126319, 0.07269896793046168, 0.012522636031332825, 0.04114061973190733, 0.04488541718040194, 0.006001148605719209, 0.03674497827887535, 0.024791864678263664, 0.03715893213770219, 0.09904895257204771, 0.015828948035570126, 0.03457279769437654, 0.0147822772352291, 0.07348633996610131, 0.09511642823261873, 0.0023069842884849224, 0.02237661079769688, 0.05878036229738167, 0.03020149189978838, 0.035972903815231154, 0.03481117383177791, 0.027150035104049102, 0.07570660154202155, 0.02441940832483981, 0.034194205688046556, 0.00406032768244456, 0.024202188909319893, 0.008556858386977442, 0.03929217838283096, 0.048610828883413754, 0.024662244133651257, 0.04113684029185346, 0.01550689835234412, 0.030333290541810647, 0.006932102043979934, 0.026329623502013937, 0.025696923523875217, 0.05855846099023308, 0.007321208798592644, 0.016945131355896592, 0.027891344789947783, 0.0079854928855119, 0.016374705625431876, 0.030006162023970058, 0.05071279466418283, 0.05357763058106814, 0.01136667698821319, 0.030984456850481883, 0.06037895008921623, 0.03760338614561728, 0.022992462751322558, 0.07184908246355397, 0.05772078236831086, 0.02159286044271929, 0.021111047993014966, 0.033043481542595794, 0.056198146393788714, 0.0633987362629601, 0.032224428706935475, 0.01526297688750284, 0.008964879305234976, 0.021952897908964326, 0.018074137291737964, 0.013165130662465734, 0.02794227223577244, 0.0034068781034355716, 0.02488009967575116, 0.025379060401714275, 0.031483380257018974, 0.026296278594860008, 0.020194666094279716, 0.03540785717112677, 0.05393065878057054, 0.05074666373963867, 0.03667845470564706, 0.003624306168473725, 0.02891171896564109, 0.02212385311057525, 0.017590713321364353, 0.015325452999344893, 0.024186886248311827, 0.028428135539538095, 0.02630515213656638, 0.031336097445871146, 0.027823435308943902, 0.06907833899770464, 0.06222132872790098, 0.040552784489201646, 0.028166833400194134, 0.06040995913956847, 0.0878961845966322, 0.08067430569125073, 0.07004189265093633, 0.041409553693873544, 0.03472560038790107, 0.07289164473435708, 0.030823294605527605, 0.026075819174626043, 0.005694821427044059, 0.016168471691863875, 0.06872283414538417, 0.02685534056009991, 0.01612148483816002, 0.05609861548457827, 0.04535481074292745, 0.006432908919772932, 0.05694970874381917, 0.05866780012313809, 0.04418128103549991, 0.06644473424447433, 0.04399562367637243, 0.037786342935370545, 0.050720865838229656, 0.0651602538834725, 0.008808609297765153, 0.0167893465009651, 0.05817608615117414, 0.05039354393790875, 0.045211253089032004, 0.027553512382188013, 0.003965044402450855, 0.05845559508140598, 0.020872252860239575, 0.04555021525759782, 0.043088466461215696, 0.03237044605027352, 0.11278350558131933, 0.026235013668026243, 0.10086971308503832, 0.018424826241763573, 0.04101238679140806, 0.012359406799077988, 0.016719241959175894, 0.010792786488309503, 0.03403680591977068, 0.05723577232233115, 0.05541219588901315, 0.028590446205011437, 0.061692973864930015, 0.0960791879998786, 0.04230002234024661, 0.07205704666141953, 0.02141355417136635, 0.030310922634920905, 0.03543867962434888, 0.016874955567930425, 0.06364952280585255, 0.028092306506420885, 0.05994674363838775, 0.06009049128208842, 0.011893033565554236, 0.029937850510967628, 0.019925157073885202, 0.060583725172494135, 0.0466113693879119, 0.037117266694882085, 0.054018637631088495, 0.004112483700737357, 0.033828773868403265, 0.01909675232933036, 0.030641443827854734, 0.036982455357377014, 0.06528669209884745, 0.026373210895274366, 0.03919181626822267, 0.016536958615428636, 0.023656341413568174, 0.07352242445839302, 0.02901309888277735, 0.040949646050908735, 0.06154866303716387, 0.04956024186685681, 0.03923400418300714, 0.04465297483173864, 0.0018582118292605238, 0.08346929999866656, 0.07446151692420244, 0.029946912346141677, 0.03674197915409293, 0.025467256383438195, 0.05737765399473054, 0.0476237131016595, 0.03639072532366429, 0.019404378054397445, 0.03933826108862247, 0.05382341632087316, 0.019974927617503063, 0.09918200650385448, 0.009194078256509133, 0.048617132473737, 0.05896089332444327, 0.04379801731556654, 0.026783778864358152, 0.02532840776257217, 0.07028967328369617, 0.009750874762955521, 0.04391031146847776, 0.034182494173624685, 0.058686276631695886, 0.04116325226745435, 0.04811079946479627, 0.03859150276652404, 0.07945702065314565, 0.06596159016979591, 0.05061347749350326, 0.014104288437270691, 0.020989086412425553, 0.01461814809590578, 0.011940239246801605, 0.04405884617673499, 0.05908103473484516, 0.04016668449289032, 0.019748315580987504, 0.06126924231648445, 0.0313697595681463, 0.06642739767474787, 0.050357432304216285, 0.04115761364144938, 0.08029005809554032, 0.02159739305664386, 0.02214367820748261, 0.024622709290789704, 0.01736584342350917, 0.03555312812594431, 0.014639396420014756, 0.01012737603325929, 0.08608117806059973, 0.04361974920279213, 0.019715818842606883, 0.09765400671000991, 0.04379726753437093, 0.03189858940563031, 0.06953032474432673, 0.0701995434771691, 0.008677716499992778, 0.010267792070018393, 0.019540746629770313, 0.05740691242473466, 0.031198555004916022, 0.08781841091279473, 0.017287179162459712, 0.020539677402536784, 0.047602926181363206, 0.02737431467643806, 0.03468334122693964, 0.012640053971803613, 0.02732059675534921, 0.03324424648391349, 0.017039866718862737, 0.0772465028400932, 0.005676289787515998, 0.023537680905844485, 0.05569957582546132, 0.011134158304360296, 0.045475627295672894, 0.07947826558457953, 0.042327272306595526, 0.03804206582052367, 0.048664280479507785, 0.024309884291142225, 0.04927235981449485, 0.018432010231273513, 0.02545955161830144, 0.027366913555722152, 0.012777298705519309, 0.007168775906653276, 0.04503038618713617, 0.04818397607388241, 0.015587250469252467, 0.05516502593777009, 0.042524844740650485, 0.04415427194908261, 0.048441544574286254, 0.05864266718604735, 0.026000467860805135, 0.050558258313685656, 0.14067644492856093, 0.0877058690946017, 0.09418978009905134, 0.200399210942643, 0.13747306753482136, 0.10348391173673527, 0.09033869353256055, 0.1402089750128133, 0.10921153439474957, 0.11467302883309977, 0.11458747913794858, 0.15147693109299454, 0.08056781640542404, 0.15772965843124048, 0.17653478149856838, 0.09645162908626453, 0.1355051938444376, 0.09523148063038077, 0.11230281780340842, 0.16203087834375246, 0.08983184144433055, 0.13357770655836376, 0.10563293392104761, 0.1700682613466467, 0.114871921017766, 0.06821122552667346, 0.3447790321494852, 0.07639892439224891, 0.194211392264281, 0.19073501309113844, 0.1259993389248848, 0.1259097315903221, 0.119356562516519, 0.08671061428529875, 0.16295653581619263, 0.08254853476371084, 0.16100593762738363, 0.18491810879537038, 0.11116235650011472, 0.19146772234567574, 0.16310099592166288, 0.13088442465024336, 0.14573649769382818, 0.09450972971639462, 0.09056043877665486, 0.14638498718185083, 0.15255246338035378, 0.15631731493132456, 0.2480444743164948, 0.13555370909827097, 0.1506345570087433, 0.1659363087798868, 0.1428358554840088, 0.1423920528697116, 0.12343284807034902, 0.12773722995604786, 0.2090189941227436, 0.0872341583349875, 0.17685358439173016, 0.10133307107857295, 0.1210153227938073, 0.10225615011794226, 0.14270911871322564, 0.10182916838675737, 0.11292769427278213, 0.0920487374865583, 0.127706234476396, 0.1299796389149768, 0.08598847660635199, 0.09292718927775111, 0.1798710703317608, 0.10034372630928244, 0.12387080171278544, 0.1699659111244338, 0.09487760426210505, 0.23186686954327992, 0.1304478823606457, 0.19656441600195, 0.08463803585618734, 0.1133857054103698, 0.3402317075857094, 0.10285330843180418, 0.09045774250158242, 0.07096878505711045, 0.11107812994824988, 0.15964220437620366, 0.09012261405587196, 0.147458660283259, 0.07222709432244301, 0.1326639370194503, 0.12897297793201037, 0.13742452513958725, 0.1600033478545291, 0.12197185360959598, 0.12607526699347155, 0.11153303339545216, 0.23976119022284234, 0.11514006448643548, 0.18719398310141905, 0.13321182690560818, 0.11896854905145508, 0.11785535807056086, 0.20947165840438434, 0.12137592344411782, 0.13822445007307188, 0.10971307355378355, 0.12336580881050654, 0.09336346693869148, 0.09378282872161695, 0.26208605085100445, 0.15356597756700857, 0.09358056421790804, 0.09998664725571871, 0.12992152917597974, 0.06829265651426145, 0.16825826918440207, 0.16115171409079007, 0.11709455746625151, 0.13004709886653082, 0.09785931105060236, 0.19043107011488505, 0.18895303085446358, 0.1617288759776524, 0.09593411721289158, 0.17298016723777565, 0.09315557059432779, 0.17580636058534893, 0.13630252677415097, 0.16317419627947466, 0.19992954257343495, 0.18928205248500618, 0.1697611699679068, 0.25942784920334816, 0.17621660285762378, 0.07788558104740721, 0.10058991238474846, 0.09279534313827753, 0.11853280743317944, 0.09984418204320328, 0.09541864772992474, 0.07972460093774966, 0.15105735217886312, 0.11902638737644468, 0.07472014054656029, 0.11684375735265867, 0.06328221144420759, 0.07743333745747805, 0.0976233844246183, 0.12204327620565891, 0.14355458691716194, 0.09299226757138968, 0.0690852871962956, 0.15571481654686586, 0.09742999515895333, 0.07138497808149882, 0.1272502453731639, 0.12224433970238481, 0.09531337980713163, 0.1140101815440825, 0.1042562202949609, 0.10684675843055759, 0.14181037193962506, 0.1490175537765026, 0.09814050274768046, 0.11396295550678458, 0.10514905702854906, 0.13981227629951068, 0.16524885781109333, 0.08501905362520899, 0.09802793378808669, 0.14056903283510888, 0.19407155976763793, 0.08753258482153926, 0.15205692925623485, 0.0502294572070241, 0.14808961642639978], [0.06149083149752446, 0.03370785892808011, 0.01639616599173418, 0.0480930150619575, 0.018839713086241057, 0.02719246220242764, 0.03999561224398868, 0.040984420970614464, 0.0161555082803326, 0.01639379281550646, 0.0029371626608605894, 0.04128415024440203, 0.05974407879901784, 0.015284279494413307, 0.027602921605908444, 0.030884661312614168, 0.018722204391711524, 0.09647828872714724, 0.03218026625524674, 0.06144822628370353, 0.013774388103878923, 0.03408056464312332, 0.042736479812966924, 0.052832351465310366, 0.05093196486788137, 0.01756815372833184, 0.03982324060052633, 0.013024042027869394, 0.01983758873705353, 0.022981775824778845, 0.057919878113482676, 0.019599020913509384, 0.0384877547621727, 0.033382857617522986, 0.01927466081854488, 0.03004927613905498, 0.06423825371478285, 0.05671957680689437, 0.010138816133673702, 0.03524898158918534, 0.05141017260029912, 0.02089132308693869, 0.039638621399977376, 0.01717436423392168, 0.012571332793283676, 0.031198378585811173, 0.034140516604696, 0.056874666163431745, 0.01155422576370516, 0.05173329436885459, 0.022874501134668077, 0.016858027815552692, 0.04658733907022646, 0.013363844731689563, 0.03281420795246959, 0.058941745066217015, 0.02061461141732122, 0.0027437184762675315, 0.07136694262070314, 0.025605348437758427, 0.019585149961390665, 0.04500128382018634, 0.018744083753387843, 0.021913890627079775, 0.07571227409477745, 0.03403340645932725, 0.028704131354710886, 0.04314785184604781, 0.028586659979607378, 0.033390606487435956, 0.05551708722487092, 0.0020101057099444525, 0.023889107762702873, 0.048537893154259236, 0.03327972708003862, 0.06784881997321333, 0.0682302312925458, 0.030425615409123044, 0.03131723077967763, 0.030772611432309662, 0.03143756217988474, 0.03038972769198673, 0.02098615514114499, 0.022652766068599055, 0.029081155945147787, 0.07116070868713514, 0.043188292533159256, 0.03893890591072185, 0.05937809058065925, 0.003959625452158174, 0.007823440063345646, 0.03937976707571319, 0.02003607040803347, 0.03018370410427451, 0.01972498924338392, 0.020280163202966963, 0.0442202459089458, 0.005740796839485743, 0.05858081193374736, 0.028670476017785922, 0.028490392823836634, 0.04004242776760033, 0.013543561516728784, 0.028828455933502743, 0.05483985160078321, 0.012652995330946786, 0.034908777701535394, 0.05742520572883742, 0.022430798604286144, 0.015130284275593502, 0.014028834495028215, 0.030165122422788824, 0.07652999021645103, 0.02297545866375523, 0.04452556970396212, 0.0331163222768477, 0.02834674696038876, 0.08389917907438108, 0.027968629928571836, 0.03737764772293823, 0.029800538771918843, 0.03901581446241055, 0.028456043684855103, 0.06778556015342474, 0.042629868390836885, 0.03280118347278663, 0.03205828262226922, 0.009892406989820302, 0.027184620033949614, 0.047988917612071545, 0.026077261061540673, 0.042326108619038544, 0.0024708250504253165, 0.042959792472954304, 0.033674990691776784, 0.08314551665846791, 0.006425384814584894, 0.018271384028983966, 0.013027342252566345, 0.04997384628014905, 0.011737788145962571, 0.02667705378761249, 0.031378862115421464, 0.012523614818097224, 0.06058206954704864, 0.05879448261111975, 0.025865985612784113, 0.022584522409098487, 0.020322858322677866, 0.0010763413343478792, 0.0028938197522490683, 0.011649969599342771, 0.05894428278718676, 0.06101808936468192, 0.04318502199436937, 0.00928381027188152, 0.023894995750327195, 0.0332260651380888, 0.02209907301169421, 0.04397856191332851, 0.016834631928109696, 0.04576902923041156, 0.01914339991552489, 0.0401056468752878, 0.08981739543378353, 0.0379095648947571, 0.0268700545919793, 0.025065070018172264, 0.027420896105468273, 0.01722602958657912, 0.011688360262529125, 0.03627944218793085, 0.050915459503552744, 0.040053308076624355, 0.011524920684418507, 0.032254209608903954, 0.04465732424120818, 0.09414719524128096, 0.020607637773667063, 0.041278416623494456, 0.018410795833915472, 0.03418264005865369, 0.026925116012405072, 0.039555276943636794, 0.03775180550292134, 0.06943869537540845, 0.037912245108080764, 0.10412855393120221, 0.04510876376714025, 0.0336619831754693, 0.024681775764163052, 0.04624808852427772, 0.0222171296232513, 0.07752622890153102, 0.039249162655323744, 0.04462777404114604, 0.032603329446698935, 0.05207549993480955, 0.023576298030093312, 0.044930716178246906, 0.05284936233822789, 0.004791580631198096, 0.07248178244169269, 0.022358987546925033, 0.004777199929646615, 0.012969034890245115, 0.08387157626982246, 0.03473944589495659, 0.029781736566552093, 0.039238200922097476, 0.026769987640104125, 0.029687362523483377, 0.036880780277507644, 0.05022517565105643, 0.05503931714754019, 0.07968350207167012, 0.026764959695615938, 0.027465626830235124, 0.01100029521954379, 0.027384306104587655, 0.005909212623789374, 0.020276634820869992, 0.011403859010897577, 0.03978333256340452, 0.02658020139538816, 0.024937306963173405, 0.012083207423399602, 0.02426737916123654, 0.0538572311135275, 0.04604429392410176, 0.0723245930192726, 0.042940956340836625, 0.04628962843811937, 0.07053552009165287, 0.0317323754674622, 0.06776360276022128, 0.005720255464049322, 0.021084958321547935, 0.040715514150049, 0.0441966498536723, 0.037300918983029466, 0.03540595048772437, 0.04137283816401448, 0.03919116487460477, 0.010322516767441161, 0.030594947215701853, 0.019501912374315516, 0.04654418085036533, 0.013873272708484104, 0.055681384301611354, 0.06307460686990193, 0.04861044890380331, 0.06893362783427749, 0.013872882550848382, 0.01464777802383261, 0.023700720996462872, 0.03423698053562215, 0.0927339560751404, 0.054164855142257044, 0.028826891910284758, 0.06998279903616224, 0.03794063501326101, 0.017504815877016102, 0.023890597147068808, 0.016371930417205607, 0.05982451234012842, 0.02089741124239351, 0.06090334230767829, 0.03248388692736626, 0.04224157672641533, 0.018797435265566622, 0.017291950959978358, 0.020330349349283745, 0.04708515985735825, 0.046764484207545004, 0.015481432933094246, 0.028013221553659866, 0.08116542255239827, 0.06092711138938155, 0.04445138547037329, 0.003110455203568563, 0.06084986017750842, 0.009078479638057095, 0.10956561432353087, 0.015940095464299833, 0.007517045031168631, 0.04057968161734087, 0.0650788296812347, 0.040895210579037666, 0.01866046618670225, 0.06623368949762412, 0.01708831581553178, 0.01837526774033904, 0.01779553759843111, 0.027454364845263104, 0.04269184238676514, 0.0523876396140882, 0.03650098047884447, 0.029942328842090707, 0.012196791641015028, 0.02858365067679967, 0.02801652093018804, 0.04864457582256623, 0.0172958203059222, 0.026038669382355044, 0.008535086742735334, 0.04452164098620415, 0.02149319552284266, 0.038736105364348204, 0.021877755244661654, 0.017169438069686294, 0.026286036108753512, 0.031127329184008495, 0.016363552206062844, 0.04109695600345731, 0.03623229418216007, 0.0426632964185306, 0.040433172336114306, 0.019051265038017715, 0.005598200584894845, 0.002516497878657122, 0.020356023418051854, 0.019359973026439548, 0.04636307306853788, 0.01413512700569949, 0.012802055055674697, 0.016470952425152063, 0.06770639547279902, 0.04028748068958521, 0.013181215335082794, 0.027127278735861182, 0.0362852402696652, 0.014505187282338738, 0.028256679918350916, 0.06680158259613173, 0.027354048531768576, 0.025741515148963248, 0.04216221187795911, 0.11476613740835871, 0.03501749597489834, 0.019276099312784414, 0.03080455686098763, 0.04138644618381347, 0.02644510337683771, 0.011155822231168193, 0.028303590436865176, 0.015257287371371473, 0.03216844617522188, 0.005124851163210613, 0.056096094726983986, 0.05584413771118436, 0.018966619490778873, 0.17270386777818203, 0.19944756557898863, 0.06448821923030273, 0.08730300928332976, 0.07947154808789492, 0.08703927629228149, 0.08220754377543926, 0.11455147606985909, 0.1003183423142348, 0.17711609601974487, 0.1834489447729928, 0.19661555040095532, 0.10546115599572659, 0.10029974366937365, 0.10861031165612595, 0.11386821844748088, 0.09379950032702514, 0.16183619307620184, 0.09929253307304212, 0.1347245935882841, 0.14517130516469479, 0.14378408103116921, 0.08305145813418285, 0.29676972116742817, 0.11748772779745714, 0.08688602237296955, 0.1528178927089487, 0.09926882505949054, 0.07864716196698801, 0.16290531999298505, 0.1432954951056412, 0.08001761271485261, 0.12863774092069694, 0.13620846824986593, 0.06941204930522613, 0.14628076420298644, 0.17497368955186435, 0.19308906820203575, 0.09974137041717768, 0.18156257670904907, 0.19030190418873513, 0.13907316167439732, 0.19428592255072935, 0.11401783541909286, 0.10001722204365901, 0.12511549278029374, 0.13059876140739235, 0.17130489141813346, 0.1896796604352338, 0.1872139320309673, 0.11484311042087418, 0.24172687903046608, 0.11146450814391885, 0.13693937260125363, 0.21073439850338868, 0.15484205766447953, 0.066923338919878, 0.15302628438387597, 0.16560232027300767, 0.14847412865076745, 0.12145461993558065, 0.18015975984079496, 0.1340689794825656, 0.2733893586056573, 0.23723687710506575, 0.106428556942514, 0.14821519968765123, 0.08999165001192264, 0.10169540199318103, 0.08493679482489824, 0.1445214721773352, 0.1406286624925477, 0.13762041819947107, 0.22112380101212434, 0.12290287150868348, 0.18849043282014982, 0.1658643569265093, 0.06440117675811052, 0.13876415682690485, 0.07925154667879854, 0.10743837311331715, 0.1795205119997263, 0.15947535261511803, 0.08544142810361725, 0.14856769862983907, 0.11171025317162275, 0.17118617493127072, 0.12565085691000732, 0.11433467056070055, 0.1513090751000813, 0.06731966443892036, 0.22636390982994012, 0.12172326552016394, 0.20017021894454956, 0.12837776701365197, 0.1386689990758896, 0.18573453570050852, 0.07850904616394214, 0.10333080709512744, 0.14327441980796202, 0.0943499957876546, 0.2619996869138309, 0.17661412938364915, 0.18562858924269676, 0.14666805842093059, 0.2030840925872326, 0.07286752281444413, 0.1554704625159502, 0.08723559004387685, 0.09569625676210437, 0.16072514626596654, 0.1279178966901132, 0.12882701147879871, 0.09991384723356792, 0.14961242542735168, 0.06477238291076251, 0.10849428895328726, 0.1419627709048135, 0.18638987839221954, 0.1502366912152086, 0.08716455421277455, 0.11158038156905345, 0.14893809732581886, 0.131521379042949, 0.1246356192444052, 0.12826343386300973, 0.13747950004679815, 0.0671244566994054, 0.13622205252093927, 0.0917696085359369, 0.13925477835748876, 0.07205943510468517, 0.07956694332616669, 0.185619537585548, 0.07061722927859851, 0.1285067700913974, 0.09552076046488114, 0.10063480426158224, 0.12587948249919073, 0.1855195758066007, 0.08676083266202893, 0.11397674333836351, 0.13790974553142274, 0.04663416477186339, 0.06974215659179858, 0.10329310768949133, 0.1415485524173294, 0.18973825871944427, 0.08081294396626097, 0.11341335571237973, 0.1525438731270177, 0.14280145375856332, 0.13771349963332924, 0.1268908932272877, 0.0999555296397635, 0.10047720771815095, 0.07456916650491101, 0.13369037051286015, 0.14690976616527351, 0.07551499003810541, 0.06638318433293275, 0.08925424529505627, 0.15554227866232395, 0.12758728728762694, 0.1980077549815178, 0.14780285395681858, 0.10172607177602393, 0.08626141731760331, 0.09434321043746811, 0.10902756319514342, 0.12003855806376253, 0.09337468990789992, 0.10745369443403822, 0.10446610474692923, 0.1281759842698063, 0.17057096080056258], [0.08912745424147163, 0.07444947292762143, 0.030833048546420674, 0.047695247656000514, 0.0351564260199666, 0.010389970781813775, 0.029412016405590942, 0.01791724981740117, 0.03918860001223428, 0.0306187196900802, 0.10233036149293184, 0.02510438094447766, 0.09116707622472729, 0.08911352391753878, 0.06362189964524337, 0.010106813029519148, 0.0059194054920226336, 0.044856986563120566, 0.035042784975043366, 0.04437200365854161, 0.02255022246390581, 0.03766012524387666, 0.017803261023280875, 0.06030332736138787, 0.007900131483828383, 0.010455203442169088, 0.024437491283086792, 0.011599643505178392, 0.06784094218164682, 0.04852143528738192, 0.10854098573327065, 0.0370442631122257, 0.038165806859199486, 0.0729727635958365, 0.03029059711843729, 0.05855962807046516, 0.04350806912407279, 0.041820257369961054, 0.04974202818370291, 0.04703837486782244, 0.047195099493754764, 0.025498582648911645, 0.03577137891469257, 0.013848775897973349, 0.05654361232050827, 0.03476636337914637, 0.021881655124681335, 0.05735547947032111, 0.0355321444304926, 0.03465823882392474, 0.010758187987708619, 0.03098965442872473, 0.05539853697908776, 0.03583278294120516, 0.03884177701547742, 0.036673406405108314, 0.045480434716280015, 0.03646632091009191, 0.010419259745893734, 0.04131360884223666, 0.05023993378771203, 0.02736298823063927, 0.021993954366605197, 0.016395080335704342, 0.02885622837181602, 0.040100354302142344, 0.032910905977977176, 0.043681421250637086, 0.007351528287732175, 0.0427622471803001, 0.003262214861544115, 0.004779475990549794, 0.006444203983327108, 0.04240612146843757, 0.05784724772508655, 0.00839749934883522, 0.037915780275527916, 0.03923963941633701, 0.01418149215169251, 0.04327599657699466, 0.035138770538781366, 0.08685020929468529, 0.029379192274063826, 0.045086884405463934, 0.026685320040477172, 0.0385729991165655, 0.03339822643569537, 0.0556585176714829, 0.03420006823060768, 0.057688653735177856, 0.02023171410629792, 0.06364266960216419, 0.022158431255125573, 0.02115710695008082, 0.05495199986866542, 0.02954666828736663, 0.041220422235450575, 0.031129493710717986, 0.10577579268387385, 0.04861478813524757, 0.040243304667196104, 0.057230690095041475, 0.05256793315389326, 0.02773401966052396, 0.021559181357068673, 0.023959522734263113, 0.007441848932233239, 0.03404848350744162, 0.050928782538643906, 0.019844869417803626, 0.03545245049255235, 0.020521750507344092, 0.057204966832484515, 0.03729709204552429, 0.024366100917437246, 0.02542936189898423, 0.06172918727887528, 0.01454742269457451, 0.012878236726724675, 0.047667502359087975, 0.02614820868309055, 0.054536200394587855, 0.03756089967542461, 0.052751982385026555, 0.050915106665343046, 0.020579817837902477, 0.0755736833172185, 0.022530053010476486, 0.04824639790292297, 0.07030986648585115, 0.007227403028602046, 0.02568326291761228, 0.09412923441933733, 0.027419966512492726, 0.034753098019531796, 0.04826185153797269, 0.16116428055933543, 0.03383940990482058, 0.08377575355448894, 0.0057543883199936575, 0.06981922459921666, 0.04999054841963308, 0.047503941492842774, 0.09530649946204253, 0.033407006678836684, 0.037416602418358834, 0.09231483856482164, 0.038096959303532324, 0.0844866411228265, 0.016818041746903743, 0.08049553206988744, 0.017758470926699892, 0.024105953983962536, 0.01714784199638026, 0.0043462542816996574, 0.033996205776929855, 0.030528009736112187, 0.03914881071874073, 0.05388888477214745, 0.05668432691267558, 0.040000758932105134, 0.07583842054009438, 0.020305321585120897, 0.03427590808964201, 0.029518763534724712, 0.04306114524868982, 0.044794391707650254, 0.08089052766029324, 0.054639222366469245, 0.05028388250086989, 0.010518972163221665, 0.007226804221448089, 0.03170073537954262, 0.029068219675017253, 0.05341791361570358, 0.054696619643696716, 0.07989907943244491, 0.031395720317959785, 0.0531716596867357, 0.03481234430468508, 0.05568344704806805, 0.0389900369170521, 0.0441967516339251, 0.010562353451470179, 0.03742308582046202, 0.03436022963640945, 0.057962829380163124, 0.01835921360179782, 0.043983063993177245, 0.07879627003733601, 0.03636629806299295, 0.04121919069439173, 0.03238734835758805, 0.05046712088265589, 0.04943633458710142, 0.05114401723923428, 0.06851121264376811, 0.04891817132011056, 0.03419768996536732, 0.05541881839079516, 0.027140886755660176, 0.04793887904712132, 0.00445797125576064, 0.030311665630766323, 0.04905683334384646, 0.03241351266790714, 0.05897851487887757, 0.04062481098143118, 0.03530722024983593, 0.04198168085089751, 0.05011621989043696, 0.07175940727548939, 0.047052963370723386, 0.016935229833636965, 0.03810273024386593, 0.05011065251060894, 0.0344855109495776, 0.009626497597699719, 0.0626955907791853, 0.02139572736008891, 0.0474584932172937, 0.0624391520395875, 0.014030932864573385, 0.06623812711664609, 0.02810818761853235, 0.022057733265683055, 0.034382180244262726, 0.031416371531252346, 0.052233198258493624, 0.03171164622264249, 0.030105798106108392, 0.09235478392136948, 0.07545002709542002, 0.011874874272117657, 0.04455551006165998, 0.017203566684786762, 0.054984902031719685, 0.007868897668751222, 0.057408547694129605, 0.055800165249300857, 0.06419334826724869, 0.030097543727606535, 0.03747253066727093, 0.03246051478864891, 0.040402197212513, 0.02584152781803693, 0.030329952149518898, 0.05805293883063963, 0.04203458622630153, 0.06415090590183224, 0.033277589694729874, 0.016697203141770194, 0.04489822792155402, 0.05556678991498692, 0.009881971121233488, 0.024539870343038013, 0.08364624836082969, 0.037212295524243794, 0.018475843593478203, 0.036805188083755117, 0.06297490293426172, 0.05063376908323594, 0.00818817553642605, 0.034928065059440475, 0.01744980873939182, 0.022609234654477665, 0.038824671147657294, 0.03269609875444855, 0.034448907377996614, 0.0448127901846809, 0.06982469359146697, 0.06629748536007744, 0.02700027564008321, 0.016255378457052366, 0.023740461096167564, 0.03051517524623445, 0.021811952614890676, 0.04993553619299616, 0.03315463914935078, 0.035219719766506126, 0.030061815466199602, 0.06944814736821822, 0.05256470671987959, 0.012559265047977013, 0.0232830911741725, 0.00509895572239267, 0.027207512109141265, 0.044071565315659554, 0.01632381889170834, 0.07608995347150735, 0.03366353362798691, 0.006537752334095005, 0.04323145075302039, 0.04497306354876075, 0.022625624667853117, 0.06054424121975899, 0.020537573943978975, 0.012871152821129985, 0.04068526505891766, 0.06091336426990373, 0.030064088558512073, 0.04158790662352528, 0.024145449811060513, 0.05518077134287783, 0.020287270857287303, 0.02539965054685516, 0.03726541463817869, 0.018676818880651678, 0.04068148561886378, 0.017337487445079854, 0.06884549292070524, 0.009926795992734177, 0.08403238906924214, 0.04447498831099697, 0.08859729447535106, 0.039605468178966215, 0.059200599390481196, 0.04042811046487518, 0.027760306107146398, 0.04386628811646785, 0.08610185302261796, 0.0014612931221823341, 0.027273189209933792, 0.030255805235356092, 0.021049557453287498, 0.026504269934126308, 0.006178218680101314, 0.027470617455297282, 0.034270228751535924, 0.06735696350889546, 0.019340711113597666, 0.05790587993604796, 0.06023712269961834, 0.027937877025189142, 0.05114193752940212, 0.053466388157435825, 0.04910715010815433, 0.019370346130537133, 0.07176831644028425, 0.021515342905851345, 0.014967415515067322, 0.0350012009564255, 0.017040696227923036, 0.052311077115259, 0.013157500536181033, 0.068318583337324, 0.014356769621372223, 0.0195811669608312, 0.037590663614017625, 0.038789913191327026, 0.02665279446435826, 0.009395441156812012, 0.2185483942074435, 0.14162619039416313, 0.10062460588025195, 0.11108177368130003, 0.1990083091493164, 0.1057491126869406, 0.11090565313185964, 0.08173613835658346, 0.09960983640381268, 0.08275599006031241, 0.21625563795013086, 0.08721687604806252, 0.1748554887516158, 0.1814243048429489, 0.1392404476978949, 0.18242948661957467, 0.08396918353225503, 0.204129321500659, 0.16745482943952084, 0.1402916070073843, 0.1896012489284788, 0.13535610613014015, 0.05549617477559617, 0.18773848031248364, 0.11530418853674616, 0.09630349132099322, 0.14691676864666597, 0.11117552686482668, 0.13685109519532748, 0.28279016273362295, 0.224319904510464, 0.08584168234041759, 0.09709477171834026, 0.10179379635623523, 0.15087093146783964, 0.1794374186013426, 0.17372981272637844, 0.13540196152670042, 0.12847904515053543, 0.15356285630592278, 0.13477105966636113, 0.19195006574903214, 0.1190837100148201, 0.10232881443308932, 0.11840493072356496, 0.22611773732517446, 0.0867332841402718, 0.16628970338829926, 0.10171223644699369, 0.07079036427395684, 0.062407254108360836, 0.16818611377051898, 0.15915483981370926, 0.11892126873135567, 0.12147389033011027, 0.2459878075335707, 0.09724685177206993, 0.1141175664961338, 0.09176162896411759, 0.08162343368998595, 0.12295118320201125, 0.13620247000030108, 0.0975908554558243, 0.19079031369515828, 0.15897726719932898, 0.1337798692818199, 0.13347135297954082, 0.137464721554092, 0.10236621528331723, 0.12774782867303916, 0.08552904733057533, 0.10404047330043145, 0.06580720309700284, 0.15585424192249775, 0.14500173926353455, 0.08809771628252097, 0.08091841544955969, 0.1620408528085266, 0.0729544906477843, 0.13070624135434628, 0.15648324388478482, 0.18800119550100394, 0.1530747724963086, 0.20449761673808098, 0.12144224345684052, 0.12805992764021668, 0.10676320362836123, 0.16314025595784187, 0.06768757291138172, 0.12203541877014296, 0.10385383545820202, 0.12369392120412417, 0.06914832988487822, 0.12374619554196085, 0.10729656607976981, 0.13202767473246368, 0.08713395906878368, 0.0767812178071056, 0.16211315750011376, 0.11495878707085337, 0.1315762453845569, 0.1392311653388398, 0.14532820960240705, 0.10712070337363652, 0.09773266927472182, 0.14587166186954292, 0.11382381511586052, 0.13328931560473783, 0.2041015422769955, 0.18721252067812852, 0.15452463898275579, 0.0703774146469576, 0.09146782330104283, 0.13647361259375299, 0.11125458976519959, 0.1414014460252864, 0.09893677716276475, 0.13006645068526268, 0.2029049593423094, 0.1715854656483446, 0.1391935609281063, 0.09064847869532448, 0.12922189171825135, 0.17636336998215743, 0.05679142688001905, 0.08883026947400399, 0.13440009100096567, 0.23856854279126438, 0.16535445143069538, 0.11591273945357118, 0.10049311936433826, 0.14054579979607038, 0.15959994521524223, 0.12432816145675522, 0.13020237482019834, 0.133967877764787, 0.2121611540871007, 0.20537690312734672, 0.18349954991468362, 0.08123362210712262, 0.0848658268472978, 0.20952229068747588, 0.16905423147337778, 0.16502259352377482, 0.15924116303878172, 0.09145852058593716, 0.13420175521501473, 0.13573689998260566, 0.13501560368708201, 0.14725484193435737, 0.2209060862660408, 0.06654821083481822, 0.0926412817622934, 0.0780099429456251, 0.140267763286829, 0.13950138512466634, 0.09245988899575812, 0.17097542195447854, 0.15831162434603485, 0.18419590326292173, 0.15035148576966353, 0.1859431987894433, 0.14286383826817783, 0.10597995030028479, 0.17268011905252934, 0.20383628936750547, 0.10025936405041388, 0.16356763802468777, 0.19742040149867535, 0.1803890096821955, 0.07018517210547413, 0.1128282006829977, 0.2106074717428003, 0.0692371501188193, 0.12999376601406507, 0.12218519859015942], [0.02928233818550195, 0.047046656387725046, 0.031137666665017605, 0.04851851758680173, 0.013431358966045082, 0.03781463784564819, 0.06139906642160245, 0.023203443037346005, 0.031100767930703502, 0.07463415658899716, 0.07667080658887114, 0.015412532790963138, 0.047403840614216666, 0.0028283004108483768, 0.07346382617418255, 0.01543255296668836, 0.012818585865066519, 0.030674074576901536, 0.0367130226721721, 0.028841924853622913, 0.05882982071489096, 0.10637637081422976, 0.0915322502010635, 0.025343416957184672, 0.049449983319001536, 0.07168617977627686, 0.03214897561286177, 0.019494272070005536, 0.09602489841303655, 0.057625251423035345, 0.010266380717179604, 0.049296223891100714, 0.04196430356906993, 0.04535054615033524, 0.04026582185178995, 0.08890089139874492, 0.030316774999456744, 0.015404666873759456, 0.0531997713925583, 0.03524313600999968, 0.02155927804830883, 0.022058840974100997, 0.06749604283166782, 0.03137829553868089, 0.011813253962567874, 0.032066421649817906, 0.04075582591550691, 0.018364177085459232, 0.06266186080340828, 0.023669354018888304, 0.017975256079807878, 0.03916955353426082, 0.06081925824816738, 0.041362320871225426, 0.021190711396879384, 0.034461202432534525, 0.01812620467639395, 0.05988925136625767, 0.02912241087428161, 0.03904163950522031, 0.017251401707263928, 0.045539192456219874, 0.01585714116559497, 0.02116508991457522, 0.019106664029615264, 0.023539574018546512, 0.019564281616892134, 0.008328217530756124, 0.0028506776475946283, 0.040393824090382884, 0.030928481104118482, 0.021207198101494993, 0.045747821618403704, 0.030394755636474917, 0.03430304270503776, 0.028077829961798022, 0.015316699897604329, 0.022407122821147953, 0.06095567771366664, 0.016661413812211583, 0.02869593125901052, 0.024734938982874155, 0.02289225161075592, 0.020952772914565036, 0.05253825742485268, 0.011319555275674378, 0.014339090391461338, 0.007087281730491668, 0.00776140669560326, 0.032094092307878394, 0.037353637761303356, 0.052086329353707175, 0.028803384064563682, 0.05716112668492964, 0.02022967001955424, 0.01729036827704736, 0.03416204991351281, 0.09933538255946976, 0.0311847094978605, 0.04088915465399623, 0.030031410312013965, 0.11789911000856332, 0.0548716884638582, 0.055755955300160816, 0.0046736533653789335, 0.029795364942401648, 0.0953399987359132, 0.032678443273263316, 0.030614075117877552, 0.0501476733812264, 0.013365900692796069, 0.024781673082283566, 0.03694604516827634, 0.01026744262448379, 0.055480317412210364, 0.023461342323571444, 0.02756646561569401, 0.009580485289916396, 0.05689882540277072, 0.11338101673339095, 0.017831335409677455, 0.005133646249305457, 0.02585877278553588, 0.018751737628398196, 0.030160949432424138, 0.06394043112439768, 0.024377232284418175, 0.0633114291621106, 0.03149182123265096, 0.01997786058512117, 0.03945609208728586, 0.028003698314673135, 0.024977601765255843, 0.05044867490817394, 0.021923413866066506, 0.019092246856806532, 0.011177542985283902, 0.08828678328011717, 0.034884906839579344, 0.046358214757804356, 0.04915869502084596, 0.06999031720416886, 0.028191065582047616, 0.04591869030679975, 0.020852583826386502, 0.05120091240054794, 0.025674343574792147, 0.024343811042074646, 0.11789942213467189, 0.049794200741286786, 0.021208804533151642, 0.07113691246403114, 0.07754819986543485, 0.017806433174493055, 0.052126457914710045, 0.027253693202510476, 0.03991675968947155, 0.054698845238557885, 0.046184910128691366, 0.040464914204286676, 0.03532177482598594, 0.04562529515741127, 0.03893768794036337, 0.04321390723011323, 0.051434219881360016, 0.060045266923095496, 0.01852964293876929, 0.050302525250507255, 0.02362686245968299, 0.03064542343573911, 0.069624172922756, 0.0417627040296793, 0.040315344730126004, 0.009737624670378864, 0.032653096597641706, 0.07031534904880182, 0.1258574572524854, 0.01605900363730533, 0.05778417789510318, 0.05140194197052291, 0.020558954582416585, 0.0388302894176117, 0.0013038027058688126, 0.03023720659049494, 0.013962064952855664, 0.04854368105796831, 0.006336865256473954, 0.044916086963244846, 0.017921721363174062, 0.02271982059547944, 0.04719615122303367, 0.03473583608865738, 0.02460296222540949, 0.037348307868731875, 0.05157708203686135, 0.023033895795898776, 0.037185754626989365, 0.02746175748429128, 0.07949856056698731, 0.03824966700215425, 0.061743619718721936, 0.008122247377676623, 0.034869527843381674, 0.012435996439307928, 0.05270004052934902, 0.04215573865388121, 0.07036846477006163, 0.0526236917690507, 0.012289252215331154, 0.02723109459371439, 0.044583933893591166, 0.06173936530415501, 0.040407893513994556, 0.01502325725076454, 0.05466061657560723, 0.020370372737358724, 0.04264074530718582, 0.04671076459011861, 0.012300899268926253, 0.03737428218924573, 0.028800652961113622, 0.021880862935047065, 0.04923861626801746, 0.09617868158966303, 0.09813493197517735, 0.018873510915519934, 0.04423875973692962, 0.04514361332569804, 0.06108905055693217, 0.06605311097311121, 0.03587375967098134, 0.01713021026392068, 0.0501924058023308, 0.09052103624812194, 0.038999661936291626, 0.03756139161331313, 0.04162883924852524, 0.032778859670673094, 0.027154381120843545, 0.022745029867759774, 0.03138633957132697, 0.04214524171714272, 0.009406135716874684, 0.041963543609849045, 0.010759638356310981, 0.03405149281024933, 0.02103379847747939, 0.05523171235940286, 0.005064021771041942, 0.01393401516335351, 0.09246294240334205, 0.018307461735925505, 0.039246716536581516, 0.04508751544303127, 0.06289231165179185, 0.018712430094767894, 0.04931028313668711, 0.07352185448897736, 0.020118408936208913, 0.047912721522152424, 0.05568177785192217, 0.032266989815980196, 0.038658511492290666, 0.03165557548137648, 0.058969354656125815, 0.040922728566718955, 0.023601607386288897, 0.012998201718021716, 0.06427046377211809, 0.004932966973033867, 0.02738445538229176, 0.036131209427756925, 0.024598994491887943, 0.018863314230527197, 0.02577839861623943, 0.03987192548811436, 0.04089139381955777, 0.039815814034747224, 0.026787782220968177, 0.020528428988265138, 0.02674695985790874, 0.05578505088176046, 0.017161263419049125, 0.010448275599628687, 0.02316643573742892, 0.05473097047901579, 0.021938441720392023, 0.008963718162184315, 0.05624648183584213, 0.07901021891406604, 0.05849164564694677, 0.04896415224564927, 0.047429075331560204, 0.016591848705762198, 0.007553288979189736, 0.06533684262207576, 0.029411191985543286, 0.04738931996481759, 0.04469811437385423, 0.048673145539526425, 0.03100706563730325, 0.04246321001223155, 0.06040960630135877, 0.028631310976509537, 0.021203267687399472, 0.018463226234806434, 0.029719016182103326, 0.02243228968498962, 0.03811466906751905, 0.05594137856470687, 0.02970955061859318, 0.04795263295194932, 0.02811245560379965, 0.04612181994265743, 0.04425277148506471, 0.01079560156046812, 0.015628412099821225, 0.05448637217549341, 0.03767837444320321, 0.027469462249428034, 0.053754466984953196, 0.020340773343507732, 0.06962282263806888, 0.014607383137834924, 0.07576700472938162, 0.033859976301235814, 0.018062685316960727, 0.04738796628745539, 0.06393857872379677, 0.022280533631731356, 0.05648600469742503, 0.02733477813723896, 0.028114296130037734, 0.03724918068785753, 0.05613136497725334, 0.04654411978221365, 0.051767702879650254, 0.032219879129635434, 0.03402104015861239, 0.06958872625338179, 0.03689923643001488, 0.044828572909214666, 0.022460121495117034, 0.029467211836682897, 0.03817490601379957, 0.04237159760668874, 0.035894047868038924, 0.04583506425842643, 0.047293632956487794, 0.025058172709707702, 0.14498928136059216, 0.047301286831498146, 0.2244230146918978, 0.09405764897486993, 0.11879443696566991, 0.07538012441779886, 0.12605522306902067, 0.1450762152671814, 0.1796918556626354, 0.13639336904244764, 0.12107616024357931, 0.17748399770685605, 0.14225938570286545, 0.15319556530032838, 0.12179514952003956, 0.17847840434738568, 0.29563561773725916, 0.1137827637472323, 0.07628552761993238, 0.14206201343664102, 0.14058505983224936, 0.08946233841457538, 0.10428628618163721, 0.15337286650070123, 0.180787486157247, 0.09158140327781439, 0.14595072476991586, 0.18875645925956114, 0.08933805115520954, 0.11360909270920924, 0.1594013651566846, 0.1255052432950054, 0.10547654516994953, 0.10048465803265572, 0.12898223314966473, 0.12325527545596872, 0.1262511568410056, 0.16074513590761594, 0.16927236691117287, 0.08937218825199775, 0.13865275494754314, 0.0977396106879626, 0.1941832194903067, 0.18639408530933516, 0.11656354953135763, 0.10564386512019805, 0.06726135113941771, 0.11790354762758527, 0.1488731750952346, 0.21774214532758507, 0.2078063299081155, 0.14085807518235274, 0.11099270917475224, 0.14279962171401295, 0.18432106583246163, 0.10806451844317572, 0.14374258182942867, 0.1456716704581465, 0.09559522289782763, 0.14032661941434654, 0.16452757508627006, 0.08786042580114943, 0.13065224353756222, 0.08210203836538962, 0.13688495409275803, 0.1914085948041507, 0.06321120275450604, 0.12818830646574497, 0.10411686955818109, 0.08298741799912282, 0.10157651587256364, 0.14565657983933175, 0.07112450884389025, 0.11865034326910973, 0.1345896872558764, 0.11193900089710951, 0.18716703169047832, 0.12780859826930932, 0.11780290731361934, 0.12969196720847062, 0.1503879502415657, 0.09999811449753386, 0.17852591536939144, 0.198665214702487, 0.11037538480013609, 0.17125691899231502, 0.19627131601529463, 0.17587824458522455, 0.06735065313322203, 0.1152607894369534, 0.15286575656916412, 0.11551114171743393, 0.12559259789330618, 0.07119061851075717, 0.11473329631345612, 0.11326975734638316, 0.11257982293942145, 0.13460869980709894, 0.07235238581363644, 0.19367815873452596, 0.13377533666789532, 0.13981976732611656, 0.09347462454544646, 0.26695228687354494, 0.14415200985968113, 0.14357482083141804, 0.11487341379480702, 0.1492449715733528, 0.12944145207958563, 0.14539687734629425, 0.16168737677591188, 0.14016271249524184, 0.10042403771408967, 0.07145996298640966, 0.14287777537746088, 0.1551074327102729, 0.16621355818850653, 0.11845960707536765, 0.09049382020852395, 0.11601272837391921, 0.1257124271775995, 0.22216546083135263, 0.11894314470035688, 0.1426814751965659, 0.07642471550830773, 0.20705699654562132, 0.06894958019256592, 0.1535400575292962, 0.18413205311766692, 0.18185208046010562, 0.06946519216788666, 0.08396891890359776, 0.13108679093420506, 0.12670308830482618, 0.08554958658558981, 0.11497625256223337, 0.19460828096738883, 0.19221111174140657, 0.20257003445710453, 0.13945774175226688, 0.1336344727980239, 0.14544692608926976, 0.1709066999277898, 0.1772411364529814, 0.11577734457595007, 0.13048868945666722, 0.24510747620037623, 0.12482780750308718, 0.11200343458248035, 0.1570241991430521, 0.18113667384854384, 0.13617558644286223, 0.17512257370565618, 0.1780815834977797, 0.18431882666690008, 0.07131150630967957, 0.11455109609024865, 0.11328803029443536, 0.18373909991766724, 0.17264134756156377, 0.11639962904155254, 0.13447646690266474, 0.08024914243391582, 0.15357279005859578, 0.09350388976080076, 0.1665056132312332, 0.08276878723076411, 0.18880201610071318, 0.07597909442016057, 0.12468523372496877, 0.20549256620662554, 0.09402248050485339, 0.11811691974954945, 0.1358176049377237, 0.15600430672722204, 0.08748894823448998, 0.2063400564449174, 0.14981017767318658], [0.0317649044362562, 0.04011409802894507, 0.025190124022109166, 0.029414228429751735, 0.05173605939905558, 0.01994455639006836, 0.049426821526139975, 0.02566102902138872, 0.056371641012706926, 0.03175371878647378, 0.05248532830072301, 0.032135601687644205, 0.028845819644629955, 0.05479655767391835, 0.062906289473176, 0.022044106586171047, 0.020128347777894566, 0.02795069115901632, 0.00788730547563838, 0.05335321530167546, 0.013085317980897213, 0.04988999292254448, 0.059207805432379246, 0.02741190042745854, 0.040235219922448905, 0.02965428733399936, 0.033798636735549996, 0.028148005749764185, 0.10241701041481324, 0.009879381661968572, 0.051037826508815796, 0.04087132614638124, 0.01429876166262797, 0.07155839806156498, 0.0037878326838836074, 0.035740427539816925, 0.03305898267509682, 0.02099729498981365, 0.03407669360084193, 0.04948145716584154, 0.05733668405030455, 0.08128331122653824, 0.04155881104192563, 0.03515578819704907, 0.0605265653825232, 0.016071178251877427, 0.023463279541049684, 0.04322268408057945, 0.01883423561230302, 0.04019274363028152, 0.022013971149655323, 0.02493888116441667, 0.04872533845316086, 0.03950247674116066, 0.02152552262746862, 0.006830897273695362, 0.02165626105852425, 0.04942570872870939, 0.036386202887765, 0.019378503817798834, 0.03788935472922666, 0.0798121794526066, 0.047801655517624955, 0.023793147644028068, 0.011827879784894841, 0.01758906108859394, 0.036435281325663836, 0.046365882203515084, 0.03873216986124005, 0.04552086183269109, 0.026760779919901063, 0.011652834713459015, 0.017321285725172077, 0.030608168470540216, 0.05902524558561189, 0.10310028160789184, 0.03698262159845658, 0.09911961520888976, 0.006091974334724779, 0.007232106124450053, 0.042293152173182795, 0.030181950091251304, 0.02370470399702234, 0.0376517724777971, 0.062236378634614606, 0.024276191634791236, 0.053636327252856324, 0.048009066709450314, 0.03635769084628139, 0.008690043784944075, 0.01875228893810085, 0.04892810846545866, 0.06837053197835173, 0.015471092059410043, 0.02092755346425942, 0.06026566866785288, 0.024581391597166657, 0.02311904006637633, 0.02065896725149027, 0.02750898352158921, 0.03532087915976133, 0.02874358816604529, 0.05686679854989052, 0.0499435496915664, 0.050993016056184254, 0.09447758072721106, 0.0009513599548621901, 0.03932267174656902, 0.006322335701302758, 0.01952680612781218, 0.00950510853103229, 0.044783111062965224, 0.04051976018984403, 0.03593049876924072, 0.0014874206431808748, 0.05682519417522209, 0.08179453308028833, 0.0635769534856081, 0.04883649605991585, 0.05524436364482556, 0.03865862684324384, 0.04730981262400746, 0.061721058429351876, 0.029245144288454736, 0.05178155856473105, 0.011426095451627458, 0.010312169956575547, 0.049572068732231855, 0.023826994667095796, 0.044088308167244704, 0.030825703404843807, 0.030303390896213905, 0.019927642208391, 0.018719883801947747, 0.06709952053747006, 0.028463363381368772, 0.050276293086686304, 0.04982284509709903, 0.036122486860092194, 0.04540872374283416, 0.0202493933362088, 0.04862821973594172, 0.003948254901583174, 0.09505193347909621, 0.03484513111678617, 0.08897119441202708, 0.029998155310750008, 0.06436691073966877, 0.0306975383178464, 0.0748472505116037, 0.01777181262150407, 0.010352682738032724, 0.06493752476360116, 0.015472900355234742, 0.007054714594102863, 0.04618091695010662, 0.03932044275903276, 0.06920572037675551, 0.04089606214048607, 0.018995716768716062, 0.03932134181793247, 0.045451888748045476, 0.018253886307190572, 0.059990040957927704, 0.053190485640828095, 0.08362925105861255, 0.014304081377174174, 0.01767974899017385, 0.029651783539780548, 0.005865911911574325, 0.050518974528781006, 0.09223826588796717, 0.05348099362371223, 0.04059713014534541, 0.06434167602232524, 0.04917004691170795, 0.022367552355197922, 0.045752686714487414, 0.047370894346386194, 0.02869517808513982, 0.05548118932970932, 0.046743968701256175, 0.0490342686618013, 0.009540768090768583, 0.012346008276966, 0.03934083952169333, 0.02171932071048234, 0.016724171516086375, 0.015300540586135216, 0.07607453037053347, 0.0430272693878838, 0.02241273600208972, 0.02394464755031679, 0.09109249844082765, 0.014060585693057095, 0.020380070699112754, 0.0017576634355853976, 0.040964536501892974, 0.045048048453671594, 0.06410439911165408, 0.017803247452580502, 0.028333758103794286, 0.020738474592300396, 0.005303130302179072, 0.061361027748457024, 0.023276794369199445, 0.028518786121691977, 0.04510242625006607, 0.02493743588482695, 0.04436605290642806, 0.02550194987894169, 0.02133311893391822, 0.03164493605228407, 0.012670819597717906, 0.007002718455623835, 0.011171465856023133, 0.06425372431320803, 0.05022551491856575, 0.07351508270949125, 0.03914701260094132, 0.01870100186871631, 0.012858068969632899, 0.03379783606422799, 0.020543024276516268, 0.03169122910393136, 0.06032483013612883, 0.020952657563611865, 0.025351332068177204, 0.09200935531407595, 0.072873012162745, 0.06333863163100821, 0.03099388170189091, 0.0301068498353873, 0.013249889864320201, 0.0496834977529943, 0.03628134887133326, 0.03085127060434648, 0.10966717065977198, 0.07019862066954374, 0.05591806410146611, 0.041821292135864496, 0.02609312690661422, 0.023507233343220184, 0.050830394960939884, 0.017767887296421186, 0.022294855809637477, 0.042984019565795145, 0.06833914973373924, 0.01811478323569255, 0.013111198154677237, 0.03072260340143527, 0.003954089878659163, 0.008380243355142218, 0.044615770756666145, 0.028449063255850757, 0.008692311788243907, 0.04157920101923602, 0.030982394104025195, 0.038219665576304705, 0.051767981079007895, 0.07970572409353086, 0.0416662638474788, 0.011333645055336612, 0.05724882733608995, 0.04808607704139181, 0.01557031593152455, 0.03729671885126403, 0.017211571701669266, 0.033056784221636396, 0.018666057315255915, 0.04626578471756407, 0.06645571294107608, 0.023277517008994306, 0.011673976168302553, 0.01786303486941116, 0.05237552776400532, 0.015991988126188517, 0.010458630892182035, 0.08975584552224193, 0.009678923757746816, 0.05597162087048803, 0.02564736332611314, 0.053554092201271226, 0.03866968696404781, 0.028425663975732665, 0.04593247813837869, 0.03862112421276314, 0.043119428014116626, 0.05332361421148692, 0.006646745838224888, 0.08709250057914428, 0.02706544892862439, 0.09189249122781412, 0.016214208344795873, 0.027007040634219135, 0.05547021741845778, 0.059906119746821265, 0.025967913446947932, 0.03799796782966171, 0.017438775759988596, 0.00973243557382375, 0.018169439231444682, 0.008467579293730003, 0.03415043339399355, 0.009831868095456489, 0.05442623022411551, 0.04545625172821539, 0.05286045977845788, 0.01776786015502044, 0.02867525290431721, 0.04467482705201421, 0.03615347894706896, 0.05918265213923795, 0.02356429474561342, 0.0076928780513948625, 0.026132483634033372, 0.0348831222924803, 0.020767266529479196, 0.027311260113492608, 0.032858187199703286, 0.02834716934843787, 0.024088110209309628, 0.05896637588739395, 0.11803382635116577, 0.041246969918055196, 0.08260312969131128, 0.05740839163107531, 0.018362864120198146, 0.029813003460211412, 0.021389242261648178, 0.03243193828633853, 0.026071907420243536, 0.018352010952574865, 0.07342301907816104, 0.017904277924182158, 0.05735492307160582, 0.00914210925943085, 0.011300513038544782, 0.026620506375495876, 0.025921308269192065, 0.04968232728008713, 0.02330635135461177, 0.01863088205988918, 0.017236543486693075, 0.06168282298105104, 0.05431776979405965, 0.033775457979312966, 0.023907862470618317, 0.08223520764814955, 0.06374670937657356, 0.07493894773402385, 0.05710249447396823, 0.07615710808230297, 0.12351093388029508, 0.0965544610683407, 0.1580948866903782, 0.10963937786540814, 0.20137699347521576, 0.119888411834836, 0.06399058843297617, 0.07014450750180654, 0.14540240062134607, 0.1577322504350117, 0.10709912596004349, 0.09066260579441275, 0.15586652340633528, 0.15927289133625372, 0.10607586122517075, 0.11873156391084194, 0.10608781701219933, 0.13885626117033617, 0.1203920476670776, 0.04129193304106593, 0.15537324201847824, 0.20283032049025806, 0.20182431090090955, 0.11569803740297045, 0.16153370216488838, 0.06588324651654277, 0.07564023403184754, 0.11905488584722791, 0.077808071992227, 0.15686105218316826, 0.181916459862675, 0.07921261912477867, 0.17662972211837769, 0.07160001939960889, 0.20672321159924778, 0.15120676558996948, 0.07354390009173326, 0.1057341984872307, 0.08832889316337449, 0.18586215456681593, 0.14046734757721424, 0.1752005916621004, 0.1299405824393034, 0.14901357756129333, 0.125639783218503, 0.08452922598059688, 0.15116015023418836, 0.11601913374449525, 0.08598025276192597, 0.153925302571484, 0.07079669500568084, 0.2100876732064145, 0.1866717418389661, 0.12527398498994963, 0.07177966154579606, 0.17520167731813022, 0.11621789022215775, 0.09613824090255157, 0.13916320327137197, 0.12232053918497902, 0.22658724284597806, 0.1051039480205093, 0.10767964659524815, 0.16637181969625608, 0.1237279972327607, 0.10842653044632503, 0.18573188941393579, 0.04185419090624366, 0.09429550264030695, 0.08921833043651921, 0.15922662881868227, 0.14913369183029446, 0.11724295307482992, 0.1306731966989381, 0.16886557159679277, 0.10968452758554902, 0.12904332844274385, 0.08302084941949163, 0.1343841589987278, 0.18827353231608868, 0.1121933836756008, 0.17664857182119573, 0.20209515493895325, 0.08593496733478137, 0.13932788372039795, 0.09957757206367594, 0.1087934821844101, 0.09395147181515183, 0.10604846198111773, 0.19817303254136018, 0.11353186185338668, 0.1771261111966201, 0.09180073293724231, 0.09634944849780627, 0.20134903783244745, 0.07750000352306025, 0.09543500720922436, 0.10045507390584264, 0.15564890365515435, 0.12636794628841536, 0.0641777283911194, 0.21566972296152795, 0.15104113519191742, 0.2472152773823057, 0.24516992856349262, 0.1264047771692276, 0.14385595146034444, 0.12121246435812541, 0.07779569551348686, 0.15557220205664635, 0.12513084124241555, 0.11964356925870691, 0.07244133496923105, 0.17538887155907495, 0.21337373687752656, 0.1148699125541108, 0.09341386851987668, 0.1308143591242177, 0.13359859186623776, 0.10759389333959136, 0.14449498217020715, 0.18342577958745615, 0.21684004659099237, 0.10185453881110464, 0.10011967404612473, 0.10696918650397233, 0.12008836253413133, 0.1127476789323347, 0.13068963081708976, 0.0843994358022298, 0.13354996804680141, 0.0744634982464569, 0.12450738969658103, 0.20899838022887707, 0.11147968697228602, 0.1799386524196182, 0.08700155653059483, 0.08793325296470098, 0.16420460598809378, 0.10912198812833854, 0.09824798947998456, 0.09395547517176185, 0.13851111754775047, 0.13190977248762334, 0.16067173198929854, 0.09612996277532407, 0.21675129421055317, 0.10154332872480154, 0.1806542490209852, 0.11435841928635325, 0.08330987819603511, 0.08693427978349583, 0.06623994559049606, 0.08564749918878078, 0.11571080743202142, 0.06964780629745551, 0.15931002077247414, 0.07328277946050678, 0.13581353372761182, 0.11384831023003374, 0.12340076693466731, 0.06748383598668234, 0.10475280614835875, 0.18730287440121174, 0.15629695888076509, 0.07543742670012371, 0.10406131789620433, 0.14105361540402683, 0.08811425218092543, 0.12384534307888576, 0.19327785021492414, 0.1823708883353642, 0.10810537303664855, 0.1303647482501609, 0.13871052541903087], [0.09924877434968948, 0.05482331230970366, 0.013638425801348473, 0.04648796422407031, 0.017029376567474434, 0.032284384061183245, 0.0357942048327199, 0.01818050953027393, 0.022813295579648445, 0.019354215656806315, 0.08351781525249992, 0.026053778660882796, 0.040922596252390316, 0.038251414229827266, 0.04329641369570579, 0.052250226094786606, 0.009422730138924505, 0.006705377625101911, 0.007931053172796965, 0.002445500639234004, 0.009558115686689104, 0.04129589229289975, 0.059973559342324734, 0.028482260581638132, 0.05357502500659653, 0.011789109142098044, 0.04670760261693171, 0.03730538035077708, 0.045758223560239585, 0.057101815938949585, 0.021119092025661042, 0.03542507499722498, 0.03532723364021097, 0.04767507480989609, 0.04971385540972863, 0.046728555778307576, 0.07515202808593001, 0.0461630070182894, 0.07840417179145984, 0.03460241235526545, 0.02109588443168572, 0.004718979928709034, 0.027738223184964488, 0.02686301139848573, 0.06282366426395518, 0.026269673236778805, 0.058208126574754715, 0.07610949528004442, 0.08997730578162841, 0.03835932843919311, 0.013726620934903622, 0.03536513999902776, 0.02191455559139805, 0.051254475954920053, 0.1197805790496724, 0.05532730098015495, 0.014659930586016603, 0.02479113355678107, 0.0769895144871303, 0.018004830028595667, 0.021651194098272493, 0.017940085913453783, 0.053776614367961884, 0.03294645103492907, 0.07826066163501569, 0.03454499472198742, 0.021902482757078748, 0.01785512315109372, 0.03548606851005128, 0.03738803270139864, 0.054676097352057695, 0.03925790897171412, 0.026569833380303214, 0.0008997360564535484, 0.010467257616775376, 0.10260035057685205, 0.015564604363005077, 0.031051007565110922, 0.05525436185832534, 0.02324511356917875, 0.024918788046176945, 0.015458986994677355, 0.06073046515562704, 0.02037142955565027, 0.0049882421319905135, 0.037567481465105496, 0.06317836844495364, 0.06486912164837122, 0.017906793592763797, 0.024584309297746847, 0.023571628012827466, 0.020323621674573848, 0.02191383295160319, 0.0872839628053563, 0.03253886183457715, 0.03530029919264572, 0.0184050079302064, 0.010137966268562844, 0.06437655272228376, 0.057593618120465956, 0.01598891775522913, 0.008773489173368683, 0.017062877537682652, 0.0478551003283688, 0.028947515080549886, 0.0017967418576258101, 0.06996939796954393, 0.03402686198907239, 0.008929407190797585, 0.05397711128794721, 0.035614335377301486, 0.018016443155439835, 0.0201007432769984, 0.00649704786649506, 0.08071308396756649, 0.03843728872016072, 0.03526789236015507, 0.052530878356524875, 0.027404065044330697, 0.07451408303209714, 0.0036001829763076133, 0.028529198241553137, 0.0444376722776464, 0.004641246532888285, 0.031198208952056508, 0.021734652209228704, 0.0065495126182213426, 0.034833402638988833, 0.03127817430400422, 0.05127645370417407, 0.009544823185673781, 0.011978612098443722, 0.016841013549960086, 0.0506597467964249, 0.006998480156263602, 0.029633486843002693, 0.0396270116658083, 0.016432104598996893, 0.02140887567241277, 0.06398278528026172, 0.030562394498182193, 0.03308646334335208, 0.038916242841098986, 0.08397843196455922, 0.04592051217332482, 0.05089299999443548, 0.02245323097200266, 0.08541257679462433, 0.03905403973268611, 0.09109385551086494, 0.044332618093384166, 0.011815137745413398, 0.05786843837371894, 0.04643443459644914, 0.0740951555115836, 0.04620268774617996, 0.03056067441190992, 0.05736367617334638, 0.026410674509991492, 0.047728791034647396, 0.017210876203275154, 0.05778682418167591, 0.07516540201114756, 0.007435577572323382, 0.03798152692615986, 0.05640307754012091, 0.0055334505325715455, 0.05598140534545694, 0.016049543162807822, 0.009998781772862588, 0.0437606368213892, 0.012195361628463226, 0.031210867022829394, 0.05705568912838187, 0.041714412692402086, 0.01311589531334383, 0.0708070562354156, 0.0037590505006457014, 0.03292256999494774, 0.015348189011482256, 0.01957262590128396, 0.06505354068108968, 0.06778321242226021, 0.034140272332089286, 0.016602783297587718, 0.010674906295857258, 0.057368344494274685, 0.0412446561136416, 0.028597862592765262, 0.03661494722057666, 0.013306807078021978, 0.07233206368982792, 0.02802410355902144, 0.029738269613257477, 0.010664004782613899, 0.02817747791829918, 0.03352336525650961, 0.04328517037044678, 0.051960559495325596, 0.0583604509010911, 0.03264312891821776, 0.026841966634882346, 0.00930326132635985, 0.07898334214197737, 0.10576569608279637, 0.043381671620798964, 0.06719929232661213, 0.01151817774267069, 0.03881711566022464, 0.004760149192796754, 0.0892968572942274, 0.009123120456933975, 0.06857284397951194, 0.03910314870466079, 0.020701502915471792, 0.012124064561378742, 0.05787478267614331, 0.0291418950073421, 0.08162500789122921, 0.046513375360518694, 0.05107731385422604, 0.04583099304831453, 0.03538835607469082, 0.07148497378719704, 0.048263941425830126, 0.06034274346062115, 0.02169880350785596, 0.024807019757905176, 0.012502132399406816, 0.016790223507476703, 0.11553208130810942, 0.015516426680343491, 0.035799395625612566, 0.0299527748887028, 0.07015049218067101, 0.025312178901263645, 0.06094402726739645, 0.05413416500336357, 0.05197326845622488, 0.03126854249941451, 0.04655022320470639, 0.021447545383125544, 0.02117472341550248, 0.040231084251510243, 0.03476467721962503, 0.012104700868284064, 0.10311411015157189, 0.027211819110172134, 0.005860187620523253, 0.021099290677479336, 0.012546116735653152, 0.04215595917776227, 0.03644693177193403, 0.016948342522872344, 0.05074011587670871, 0.038784260994621685, 0.08008630760014057, 0.008317830855958164, 0.04683450223611934, 0.015256211893366916, 0.039798755664378405, 0.0505708383529314, 0.029746065980621746, 0.05634052339675171, 0.03499873108895762, 0.033899263478815556, 0.0027884222716758294, 0.04419540474191308, 0.028872930511300052, 0.05105757187785847, 0.039057876848216565, 0.035977436429155726, 0.0057182745658792555, 0.022798057379467145, 0.08713113636310611, 0.038313055743596384, 0.03256686497479677, 0.009882849824082638, 0.052171485498547554, 0.03392137693507331, 0.008345526959081846, 0.040204037845666916, 0.03129202320373484, 0.054869927665484805, 0.01283170618782086, 0.035228303234492025, 0.06395299759294305, 0.04582518478855491, 0.009813151555135846, 0.01356815586664847, 0.07024235903684582, 0.0031167925086005455, 0.013266256128970002, 0.013459201802366545, 0.014712781678619129, 0.05215956024559481, 0.026319379319569895, 0.016692935156502893, 0.046121283899992704, 0.03550677739882043, 0.058254056610167027, 0.020721470504733067, 0.02967862638511828, 0.05104961944743991, 0.013906609982119074, 0.021386282152629325, 0.04647333161639316, 0.051174632739275694, 0.009282786532172134, 0.07647532064999853, 0.02334688194761319, 0.02534126430483801, 0.07736162309135709, 0.08904807921499014, 0.012671187702965523, 0.04570060236645596, 0.024959179539499537, 0.021664532400401573, 0.05477194381611688, 0.07273738658321754, 0.10091173475874321, 0.055205778750990114, 0.045540956647268364, 0.0469464740848967, 0.01681761596617954, 0.010960055548431618, 0.07730014103331737, 0.05913360762809004, 0.03961349185556173, 0.013149190178540136, 0.06994755592729364, 0.01766012915010963, 0.0473936863376626, 0.0929802032187581, 0.045142093407256265, 0.020326424024200866, 0.007624007595170821, 0.02242421342193016, 0.025011927155511718, 0.01913662813603878, 0.019149393076077104, 0.01678797246755234, 0.03456900807629738, 0.02976267651787826, 0.007330620927470071, 0.013011698627711406, 0.013437386901516999, 0.007827623231735612, 0.04277149221992918, 0.033004910219460726, 0.02438599386784647, 0.04619135281869343, 0.18643163543726715, 0.09774632818464722, 0.1265391135322196, 0.10726054944097996, 0.09201207623950072, 0.1281263290771416, 0.11000795130218778, 0.11556064763239451, 0.18060375244489738, 0.0794696481898427, 0.14193930716386863, 0.11545936949551105, 0.09580180288425513, 0.09107643073158604, 0.11950191828821387, 0.16014870362622396, 0.0711301067577941, 0.11515039178941931, 0.08618120769304888, 0.15724142534392221, 0.12331714427896909, 0.12587100081145763, 0.14887556353850023, 0.16450622837458337, 0.11963301125381674, 0.11081610686544861, 0.18128536801253045, 0.22692064781274113, 0.18175623060337134, 0.21764858891921385, 0.0991089486383966, 0.12392830077026572, 0.1960394877408232, 0.08090211025306157, 0.1440524687724454, 0.09516752191952296, 0.16050520592502185, 0.08814682864717074, 0.1445028396057231, 0.08982110023498535, 0.13491747395268508, 0.11901075392961502, 0.18823219596275262, 0.0941375396879656, 0.14427307407770837, 0.15651736062552246, 0.15647731348872185, 0.15282127181334154, 0.13018028171999113, 0.0924012160726956, 0.12699975738567965, 0.1395825243421963, 0.0761006200420005, 0.11481048645717756, 0.2901538690286023, 0.1851732243916818, 0.13054052953209194, 0.1503891444631985, 0.16556884135518754, 0.1100143702434642, 0.17436444652932032, 0.08533479632543665, 0.1291960666754416, 0.1577999953712736, 0.1666836201080254, 0.07499821098255259, 0.12950836920312472, 0.09426388290843793, 0.13283705844410829, 0.09712113280381475, 0.19385708841894353, 0.1303052000169243, 0.11875745680715356, 0.08717224201453583, 0.10337350730385099, 0.11170162220618554, 0.11706377911780562, 0.09435199068060943, 0.1867387675281082, 0.09542016086301633, 0.1580263003706932, 0.0644095159534897, 0.18774675843971117, 0.1555182042398623, 0.13075383380055428, 0.1080529833478587, 0.13092236832848617, 0.11416886374354362, 0.09721772904906954, 0.09391381312161684, 0.13561625645628997, 0.09825794358870812, 0.13704183138906956, 0.18608931452035904, 0.15519685005503042, 0.22303622482078417, 0.057548251269119124, 0.07828145873333726, 0.16182530937450273, 0.16639532414930208, 0.11492313684097358, 0.0686123211468969, 0.13845331993486198, 0.165745328313538, 0.0981345044981156, 0.13129603756325586, 0.16455641282456263, 0.14773441691483769, 0.07299392710306815, 0.10621777682432107, 0.12629374169877597, 0.12161256931722164, 0.15233207520629677, 0.10369646283132689, 0.24314262877617562, 0.11000261801694121, 0.14837574107306345, 0.1262688666049923, 0.09751306820128645, 0.13597453651683672, 0.07807145214506558, 0.09890572061496121, 0.15840075670608453, 0.1898336743137666, 0.10748913431806223, 0.11914544313081674, 0.10408318707985537, 0.15544033556112222, 0.11687558064503328, 0.07375571158315454, 0.11531830206513405, 0.1406002997287682, 0.1293799089533942, 0.1002856572823865, 0.0784795977441328, 0.15053973852523736, 0.1530630745525871, 0.19298028546784604, 0.07654123354171004, 0.16621843006994041, 0.10122894987996135, 0.14884547729577335, 0.09642002971044608, 0.16383689429078782, 0.18712741881608963, 0.1707111732768161, 0.09785626442836863, 0.19786750179316315, 0.16098179535142013, 0.19748216175607272, 0.18191048875451088, 0.13854494930378028, 0.12809371868414537, 0.1288366602467639, 0.12943777441978455, 0.14205129258334637, 0.14269360740269932, 0.14416495630783693, 0.08248887117952108, 0.08214273011045796, 0.09011292457580566, 0.11550887541047164, 0.15482628851064614, 0.05443738873249718, 0.17313640671116964, 0.13961379123585566, 0.09197552355804614, 0.2299098659838949, 0.10302647056856326, 0.10906284023076296, 0.14128657004662923, 0.07469738248203482, 0.11768729851714202, 0.08174717133598668, 0.12961436994373798, 0.17144035414925643], [0.04438813922128507, 0.024779822378020202, 0.07971553570990052, 0.031143827762986933, 0.018022683981273855, 0.0016647762323762955, 0.024611204729548523, 0.017326315365997807, 0.03358137660792895, 0.04493148292281798, 0.04432729498616286, 0.047438089669282944, 0.034777281007596424, 0.06397314329764672, 0.007197444011191172, 0.011132198186325175, 0.02232553916318076, 0.031428439276559014, 0.041279444604047706, 0.026815892230453234, 0.04786655739215868, 0.030897614546120167, 0.049633225093462637, 0.03212408694837775, 0.008029053985540355, 0.021227884937876036, 0.03601485763543418, 0.00726035184093884, 0.020525940461084247, 0.06157435915832009, 0.03968096537781613, 0.02177829897430326, 0.009548888458604259, 0.03255124170599239, 0.047278477876846275, 0.027252739860809276, 0.048380303396178145, 0.04260968875938228, 0.029575784225016832, 0.0025591963910431203, 0.014271360722237399, 0.024664067696513872, 0.05687473401693361, 0.021940719901717136, 0.019399745356557623, 0.011010179778427949, 0.05191383896661656, 0.04103999638131686, 0.02313753353830959, 0.03360655364979591, 0.022933347084160362, 0.0528298748124923, 0.023780428505103503, 0.02042555290141276, 0.046925266472888846, 0.03507977870426007, 0.02003490672047649, 0.03999137140012213, 0.034544655454478095, 0.01843032576808972, 0.029217266677213565, 0.03413332413349833, 0.0340211860436414, 0.02089002538871552, 0.08541097545198031, 0.017875759097348367, 0.06450156601411955, 0.02035576557474477, 0.05072367836588195, 0.04771183105185628, 0.07854717304663998, 0.01940502435900271, 0.029750734301550046, 0.15281018455113682, 0.07835908992482082, 0.027888301560389142, 0.03875986087535109, 0.04183839800368462, 0.022547945978918245, 0.0703986460076911, 0.010356845550372131, 0.038168052810111215, 0.027409259229898453, 0.010440435127488204, 0.023692956859511987, 0.02335254941135645, 0.048271269604031525, 0.019036386461396302, 0.017724768092323626, 0.012589359772391617, 0.04439432406798005, 0.01770816942942994, 0.05808525066822767, 0.09355645586869546, 0.04218404034950903, 0.06840513047895261, 0.04493467203740563, 0.01695931952313653, 0.014992489080343927, 0.04127887463463204, 0.027490306845200912, 0.011819025751070251, 0.04137581014739616, 0.016592980162905793, 0.022631304005959203, 0.0574077470228076, 0.08990745738680873, 0.005930507597180882, 0.019770922671471323, 0.02433297653416438, 0.023505481026534523, 0.02886067277618817, 0.08284633699804544, 0.0810856404049056, 0.028619304299354553, 0.03745985563312258, 0.025429612956941128, 0.004060853971168399, 0.041154583982591114, 0.038593484088778496, 0.009738453331270387, 0.0435873355849513, 0.035651430886770995, 0.037003130319395235, 0.037795323346342356, 0.06387797876128129, 0.05474349284278495, 0.08684700660939727, 0.07950058938669306, 0.0912866544510637, 0.08038155854280506, 0.03981500657807503, 0.02346075708711786, 0.06747698956834418, 0.009134682693651744, 0.01773584178382797, 0.013549312949180603, 0.0732840211795909, 0.003289728396339342, 0.051767275402588506, 0.04052230469616396, 0.031016761902719736, 0.0832219332722681, 0.003312840571327667, 0.023063983734963194, 0.010653763992844947, 0.02106548097383763, 0.028934453281440904, 0.04768226728109377, 0.05911589107875313, 0.027807175913559537, 0.03572026487173779, 0.025192912801035812, 0.02211839090367513, 0.029263206890651157, 0.026934515418750898, 0.0038698785938322544, 0.02593713509850204, 0.03859585217599358, 0.028490857620324408, 0.022841726196929812, 0.03024808011416878, 0.04990832354607327, 0.034377674771738906, 0.03605707608429449, 0.08019866621387856, 0.040898667714957676, 0.05042597112644996, 0.03995601633297546, 0.028621190626706396, 0.03695796024320381, 0.06431862618774176, 0.03923944264118161, 0.021104053993310248, 0.06941988638469151, 0.08973426810864892, 0.03894650211025562, 0.03815646003931761, 0.06883274324770484, 0.05761016758957079, 0.045679540639477115, 0.03455944751788463, 0.022809531406632493, 0.024224563601559827, 0.025694584274398427, 0.050512854142912796, 0.017975271346845796, 0.028697580099105835, 0.025869313827050582, 0.0026507808070164174, 0.06224205797272069, 0.0479427534820778, 0.04790771732638989, 0.03998928490493979, 0.07710329802440745, 0.03497831736292158, 0.023281131904306154, 0.013456909202172287, 0.03587407518976501, 0.047262430523655245, 0.03831465030089021, 0.03761862264946103, 0.03875435456367476, 0.01430469036235341, 0.08800985278295619, 0.06912384834140539, 0.038320109115115235, 0.026756040352795805, 0.020192286132701805, 0.03143659187480807, 0.026801678618150096, 0.016189699659922292, 0.03243034372904471, 0.01891885232180357, 0.05148329831925886, 0.03833117941394448, 0.010628593736328185, 0.03548698453232646, 0.011974296615725117, 0.026745226200936095, 0.054994720433439524, 0.03563248279637524, 0.07607651169278792, 0.035509257444313595, 0.06187390522765262, 0.03220090050516384, 0.04638513224199414, 0.05977893514292581, 0.06644524993108851, 0.013530062062532773, 0.05996123036103589, 0.04219623362379415, 0.04709078151998775, 0.03404124353879264, 0.00764240013502006, 0.06447872652539186, 0.054745029724602184, 0.04430095086406384, 0.06939809183989253, 0.03048720264009067, 0.05371991937447872, 0.027527963842398355, 0.030104142480662892, 0.03032092424109578, 0.010141565896836775, 0.04476192380700793, 0.04745249157505376, 0.02802752676819052, 0.06711178166525704, 0.14426433454666818, 0.03874893646155085, 0.01796475744673184, 0.06737815415752785, 0.02378880332357117, 0.05181474910516824, 0.08398533266569887, 0.020150011704702462, 0.006134793287076588, 0.03782097197004727, 0.08298011017697197, 0.010259876110857087, 0.027842142519408038, 0.04504792971004333, 0.010848244851721185, 0.04459067513900144, 0.02107283629343978, 0.037895315659365485, 0.05001204440902386, 0.0290064967370459, 0.07266284951141902, 0.015334090750132288, 0.04288596786292536, 0.029842339921742678, 0.07512001480375018, 0.017134607170841525, 0.039936728975070376, 0.020783666720879928, 0.05582447037366884, 0.05663116369396448, 0.03259858648691859, 0.03484278338562165, 0.02556255323413227, 0.031199793331325054, 0.08792616227375609, 0.05647265452093311, 0.054205373860895634, 0.035602980093764405, 0.027277547101091062, 0.01629809902182647, 0.03407392857064094, 0.03922038259250777, 0.013021307531744242, 0.055947614301528246, 0.05524827200653298, 0.011967539255108153, 0.03712305799126625, 0.019213711410494785, 0.01011766365263611, 0.03689375047438911, 0.025214249334697212, 0.02009118950393583, 0.05784881514097963, 0.010757519630715251, 0.04613521083125046, 0.0786513349573527, 0.0442798348542835, 0.06591580262673752, 0.02806682582013309, 0.05308588946770344, 0.05597910171906863, 0.049140968293483765, 0.06319871092481272, 0.07027343594069992, 0.03143852569961122, 0.03887562573488269, 0.006929505375280444, 0.02279683092742094, 0.015057474075417434, 0.03276069189554878, 0.0420552883297205, 0.009830180239597601, 0.065970689324396, 0.0033032829815056175, 0.03554497892037034, 0.01751674961165658, 0.020794463909364173, 0.05776538247508662, 0.04847524740866252, 0.014962971110695174, 0.024065341966758882, 0.07603248155542783, 0.06639300952000277, 0.02825305993402643, 0.026454037986695766, 0.01251510005178196, 0.04092791935961161, 0.03735940870163696, 0.0271679077164403, 0.05378366434680564, 0.03568402092371668, 0.03447649661185486, 0.003406640192094658, 0.01631747798195907, 0.07128328603825398, 0.043272135712738545, 0.08650058734097651, 0.02194849252035575, 0.02113732765428722, 0.05938010582966464, 0.08200437682015554, 0.03413891526205199, 0.07179213980478899, 0.12404692226222583, 0.08481380356741802, 0.1129846301461969, 0.17923316599002906, 0.11586058725203786, 0.10988678530390773, 0.12548467011323997, 0.08130869522158589, 0.09180669726005622, 0.18038306571543217, 0.0844986919047577, 0.11577355835054602, 0.16379019751080445, 0.1488677468150854, 0.09727307715054069, 0.18338961367096218, 0.10743878023432833, 0.0749169292726687, 0.11894817943019526, 0.10802498699298926, 0.08494097460061312, 0.10277577223522322, 0.17950033236827168, 0.11778132990002632, 0.15352332485573633, 0.1047756727784872, 0.148108072578907, 0.12350192293524742, 0.19185954917754444, 0.1603048209633146, 0.08764851252947535, 0.058542542558695586, 0.12700184727353708, 0.09833957135145154, 0.16400416674358503, 0.08508117350616626, 0.15607308303671225, 0.07688771387828247, 0.14749011716672353, 0.15065465521599564, 0.08880684644516025, 0.08701940200158528, 0.13975165598094463, 0.12269169784017972, 0.11175524004335914, 0.09636077324726752, 0.15997369587421417, 0.10251790857208626, 0.09016914798745088, 0.1596433985978365, 0.11400226982576506, 0.20625042196895393, 0.10683308594993182, 0.05574242191921387, 0.11705985718539783, 0.18560433840113028, 0.09480123514575617, 0.14467068202793598, 0.12814638657229288, 0.16252224626285688, 0.13793850184551307, 0.13254302207912716, 0.1662994742925678, 0.10565896930971316, 0.14495710523000785, 0.16256096347102097, 0.09647321328520775, 0.20895712529974325, 0.12217404347445283, 0.11082132479974202, 0.13593028246292047, 0.0902650724830372, 0.16965736768075398, 0.25588681921362877, 0.16051379617835793, 0.10262107303632156, 0.15916562852050575, 0.18446309678256512, 0.15637653746775218, 0.21081374638846942, 0.05524053331464529, 0.15946235188416072, 0.07211838622710534, 0.29571193935615675, 0.0836197379976511, 0.07705552237374441, 0.15810213344437735, 0.06361381150782108, 0.12066780429865633, 0.1235977727919817, 0.23647523511733326, 0.14883068523236684, 0.14066666045359202, 0.13374640393470014, 0.19435543167803968, 0.14674436646912778, 0.1790223858718361, 0.13557645359209605, 0.08477148333830492, 0.18250998801418714, 0.18935692203896387, 0.13730441087058612, 0.16058747151068278, 0.07281230363462653, 0.12879878442202294, 0.12109939328261785, 0.21919372172227927, 0.09525713603943586, 0.17865843325853348, 0.08108610180871827, 0.09639854729175568, 0.10340334927397114, 0.11714799888432026, 0.20172633044421673, 0.10977246572396585, 0.07782050275376864, 0.12304738589695521, 0.09854507246719939, 0.11865719647279807, 0.11901388876140118, 0.055384532016302855, 0.07854629773646593, 0.10096962058118411, 0.10503200295248202, 0.11147896772516624, 0.15067494341305324, 0.10509743408433028, 0.12426669975476605, 0.15894008348030703, 0.1552925913461617, 0.12036557123064995, 0.14157570738877567, 0.10815363723252501, 0.15906965652746813, 0.14637091436556407, 0.12999664300254413, 0.22435296273657254, 0.16349027146186146, 0.10425324831157923, 0.19868566574794905, 0.1088013599759766, 0.11519206741026469, 0.15130413536514553, 0.08464874313878161, 0.12435356580785342, 0.31949494459799355, 0.08821072628987686, 0.12239299315427031, 0.0622927106118628, 0.1313836635755641, 0.16602265914636, 0.1370790558201926, 0.09332844096102885, 0.0962081096534218, 0.14050455843763693, 0.1918920645756381, 0.08624884406370775, 0.11124975181051663, 0.15474064382059233, 0.13631061491157326, 0.0738465945635523, 0.14691290099705967, 0.1436506946172033, 0.11381542163767985, 0.09825707506388426, 0.14220351512942994, 0.09128064941614866, 0.16539291079555238, 0.09526186542851584, 0.12829330297453062, 0.1061027922800609, 0.29580918699502945, 0.1160127826567207, 0.14997852221131325, 0.16097923048904964, 0.20123403971748693], [0.00827788295490401, 0.05718144880873816, 0.048746478211666854, 0.024346547234537344, 0.056907144242099354, 0.0065620735736696845, 0.005060564635121929, 0.033796523098966906, 0.03807583311572671, 0.05531194573268294, 0.010863924947833377, 0.02991400339773723, 0.029973476992121766, 0.031247965924974, 0.02105061087890395, 0.04706160790686097, 0.06299253127404622, 0.05157324831400599, 0.05025593703612685, 0.015547311898054821, 0.026379621354863048, 0.017236596073157022, 0.036523297495607815, 0.06595865211316518, 0.05096374744815486, 0.03847986000723072, 0.02895794416378651, 0.04334252354289804, 0.008721474375176643, 0.045653461146035364, 0.041934841578560214, 0.06327034386673144, 0.022060403300981437, 0.018582648398088555, 0.05288882254223738, 0.032181362089301856, 0.04854510598150747, 0.046334174262093644, 0.014616499255810465, 0.01290769871723439, 0.0033290630713703907, 0.009955885637152408, 0.021926183985280137, 0.04787413323564189, 0.015028997657022305, 0.02071335183323494, 0.02529969216058297, 0.05048417586034962, 0.04027868348306843, 0.02141752020855035, 0.04922160878777504, 0.10749491543642112, 0.07575103201504264, 0.026488268382049034, 0.04524701188451477, 0.027789189646552716, 0.04962034649880869, 0.02559132651159806, 0.026887632041637386, 0.06964480717267309, 0.06780583477978196, 0.05790778661945036, 0.043297825048544576, 0.016742885511900698, 0.03889519129214542, 0.05920372065156698, 0.02810000957522009, 0.022793224513796822, 0.04926826146298221, 0.013909836416132748, 0.03011883276381663, 0.023879246952544366, 0.02278104650654963, 0.03814005306256669, 0.06341852912945406, 0.10780381850366082, 0.029581517845924412, 0.011420874972827733, 0.03575383878446051, 0.04261358015771423, 0.019324751969959055, 0.033794053231499026, 0.0396311269806964, 0.02984906081110239, 0.03596668843446033, 0.029468090539532046, 0.011371175675386829, 0.052364722093833346, 0.04785382807520883, 0.035694446614278216, 0.029412342102399895, 0.038304692799491544, 0.08384271817547934, 0.053758714614169936, 0.023417609045282006, 0.02965359522828034, 0.07115809632731335, 0.014381707479645098, 0.02135678623536868, 0.014524126891046762, 0.09335275965609721, 0.010638502043937998, 0.026003792682396512, 0.04191188673887934, 0.04012438461982778, 0.08583290209727627, 0.027254195318424275, 0.046007351085011444, 0.05004252420206155, 0.03592164727992245, 0.029612686352006028, 0.03318308333733252, 0.0024947934517902987, 0.03808894919763718, 0.03601466425295387, 0.051515918890280385, 0.044359552540949414, 0.01733476312697998, 0.01992668377767716, 0.027421147163425173, 0.03369426787165659, 0.055840270061578066, 0.05504346978185432, 0.028351274485300695, 0.025620681632842337, 0.03901401634461113, 0.025921667892751948, 0.11011579087270157, 0.07237159514001437, 0.013989236887677439, 0.053728200894381316, 0.017747314114655768, 0.0751885739820344, 0.02814007706807128, 0.008665518136695027, 0.033100220640855174, 0.045319235151899714, 0.040459994825401475, 0.02184794211227979, 0.050875330942549875, 0.025345167577532784, 0.03904280997812748, 0.029098743572831154, 0.01966590071762247, 0.025358572036826184, 0.02896554714867047, 0.039679889899811575, 0.06290019622870854, 0.013980142822090005, 0.013007693574763834, 0.012213345350963729, 0.0313584110699594, 0.03870068583637476, 0.019400245776133876, 0.061282792660806856, 0.007694904326594302, 0.032992930683706484, 0.06123836897313595, 0.03642640269494482, 0.010479457676410675, 0.01790498020792646, 0.06579879604812179, 0.03608688412766371, 0.06484601753098623, 0.06408396163689238, 0.06304865290543862, 0.06328807398676872, 0.013258760013351483, 0.06027415035558598, 0.047206509060093334, 0.0885348217561841, 0.007875024839969618, 0.03691450686060956, 0.009584324101784399, 0.02295612041572375, 0.07358814057494913, 0.050763386235173256, 0.03702134559197085, 0.04550130306077855, 0.04618859796651772, 0.021057038301868097, 0.00913559362691428, 0.037929534180355925, 0.009048734359177095, 0.011326904658095112, 0.022345442291615263, 0.008839552190953066, 0.049649442080408335, 0.059411060597215376, 0.04053425030516727, 0.017944689773555313, 0.03628297396270292, 0.036864132420825105, 0.029208001281533922, 0.011835020517797341, 0.040891953610948155, 0.006361149176622608, 0.06053335073270968, 0.03459833096712828, 0.059334718622267246, 0.029304278615329946, 0.06925235608858721, 0.017710700365049497, 0.014580423245206475, 0.053978580316262584, 0.015770476976675645, 0.023922856398192898, 0.030455009546130896, 0.019390245866296545, 0.08094694784709386, 0.07612096252185957, 0.03303044009953737, 0.04217663413978048, 0.0818008773827127, 0.05723499200705971, 0.03543546336836048, 0.020271871505039077, 0.014567805886534708, 0.015370663787637438, 0.05801340738045318, 0.01864122971892357, 0.06137115827628544, 0.09622186355824981, 0.031428832826869826, 0.013713294507137366, 0.02169703592413238, 0.01916630386507937, 0.05589154016758714, 0.06464943915073361, 0.01717435066322131, 0.023040362234626497, 0.05135786094303642, 0.021943364491952316, 0.08472422337425606, 0.09737791759627205, 0.010316802654415369, 0.018679392224709903, 0.055446288881025145, 0.03807324789730566, 0.017963680272389735, 0.009108481063906635, 0.04251280752941966, 0.04256120064694967, 0.016499852927933847, 0.04110581427812576, 0.05170157624940787, 0.018941715559256927, 0.026163156809551374, 0.04129301191174558, 0.01790713794928576, 0.03789305953042848, 0.04705563001334667, 0.03981660792071905, 0.06352214142680168, 0.04313495968069349, 0.018020265003932372, 0.031189476206366504, 0.03681965784302779, 0.055133667441883256, 0.05482341069728136, 0.055551444845540185, 0.08278495672025851, 0.03418169689497777, 0.03297139398221459, 0.0491702708282641, 0.08224909047463111, 0.03693812666460872, 0.05777581834367343, 0.09943144954741001, 0.046586107529167614, 0.05028620309063366, 0.010637485089578798, 0.03458851256540843, 0.019866816632981812, 0.058358048887125084, 0.00853548538205879, 0.04744212355996881, 0.031960224134049246, 0.05559666581185801, 0.06677713497940983, 0.03265855201919164, 0.036428716499358416, 0.05276304929118071, 0.05500232681099858, 0.06899159508092062, 0.0365021713078022, 0.06476462725549936, 0.038411270294870646, 0.059147361532918045, 0.07022937866193907, 0.02658386548448886, 0.008068714357380356, 0.017035403654777577, 0.0173641962797514, 0.0755689674988389, 0.052749251281576495, 0.02030952850223652, 0.03910695528611541, 0.02832849436838712, 0.033294254514787874, 0.07477408408054284, 0.012649019963906279, 0.031234547894980227, 0.06260255005742822, 0.04893545021436044, 0.02184243919327855, 0.0798910523631743, 0.09473945453230824, 0.01939846801438502, 0.020284894288384488, 0.050776858547968526, 0.05672057764604688, 0.013925974523382527, 0.056107829990131516, 0.038379708238478215, 0.031133693842483417, 0.028505805746785233, 0.024829389361132468, 0.04132360366306134, 0.018743905637945448, 0.07698677320565496, 0.023994725131030594, 0.010172742884606123, 0.01756260500821684, 0.0608171887163605, 0.037072164472192526, 0.03306626335584691, 0.05701775223548923, 0.00987339613493532, 0.02534382407819586, 0.007448403580513383, 0.027579819184861014, 0.031513201871088574, 0.011841643019579351, 0.038194016952599795, 0.029970002892826284, 0.05464562773704529, 0.08004842499004942, 0.0673019275335329, 0.03589497746101447, 0.11998905214880194, 0.018172747089660594, 0.05480799098898258, 0.015455046402556556, 0.020759208926132748, 0.03863647946023515, 0.06989059969782829, 0.01682453532703221, 0.0421367159246334, 0.0352272141857871, 0.05878595342593534, 0.03373906136091266, 0.10187984138195004, 0.1307889140610184, 0.15095010293381556, 0.16219102617885384, 0.13918003093983444, 0.07497886594917093, 0.07470114835138832, 0.10962113205875669, 0.06917948142758437, 0.1447047580565725, 0.12645280387784752, 0.15197789349726268, 0.13091483658977918, 0.08690887543239764, 0.0954148547191705, 0.09711780119687319, 0.12951860151120595, 0.1535687188484839, 0.13427393777029856, 0.0902209405654243, 0.0717404829338193, 0.1030642513984016, 0.2644253953226975, 0.11503677788589682, 0.09042239761246101, 0.14238188841513225, 0.13123689645103045, 0.10845148017896072, 0.14404626696237496, 0.086637597131942, 0.0892420791621719, 0.1398199980280229, 0.12748125940561295, 0.15077797217028482, 0.10994881018996239, 0.12188972373093877, 0.1314835710717099, 0.12075353041291237, 0.1023212962650827, 0.2567412576505116, 0.06228362502796309, 0.13381644231932505, 0.16427479365042277, 0.15395948716572352, 0.12450688758066722, 0.1327524044151817, 0.11762669176927634, 0.25932243200285093, 0.13351073515202316, 0.10148190773491349, 0.05890040871288095, 0.14902561477252416, 0.18906023938741, 0.12240550534001418, 0.12488223958228316, 0.09179451755647149, 0.12526063142078264, 0.19815073588064738, 0.1390007348465068, 0.15530244367463247, 0.14426464667277678, 0.1674015780112573, 0.21496909484267235, 0.08445263973304204, 0.12627175716417177, 0.08290530847651617, 0.09578654263168573, 0.10647177962320191, 0.12807010566549643, 0.19375234975346498, 0.12624400508190903, 0.10769932411078896, 0.08864488692155906, 0.09227253190640892, 0.13470061416072504, 0.19266194397849695, 0.08836480123656136, 0.1302131906683956, 0.09398066239165408, 0.1854338361216443, 0.10627226318631854, 0.09790781951908555, 0.09229742057089295, 0.1213536403541054, 0.13841108791530132, 0.23448862028973444, 0.07877414979572807, 0.11671434715390205, 0.1089056304522923, 0.3006619880242007, 0.10803454076605183, 0.12738254613109998, 0.1905839711959873, 0.13757924469453947, 0.11263002774545125, 0.08910927628832203, 0.1851603322263275, 0.07484503170209271, 0.20805702145610536, 0.10087846618677888, 0.16127809802336351, 0.0802777698263526, 0.16952452409480298, 0.14619410171040467, 0.14735488513750689, 0.1623126875076975, 0.11320163243051086, 0.1610004279230322, 0.16223434385444435, 0.08928659784474544, 0.13032958656549454, 0.1856357002896922, 0.13571612324033464, 0.1567163070929902, 0.1247520422829049, 0.10731222666800022, 0.11171259411743709, 0.15473304422838347, 0.24481665609138353, 0.07776953120316778, 0.10313344161425318, 0.14374596093382153, 0.1376099687601839, 0.17333444394171238, 0.10772049440337078, 0.07125955088330166, 0.14029318120862755, 0.15690895675548486, 0.16006923360483988, 0.08791103772819042, 0.10787849128246307, 0.09901003180337803, 0.10539976893258945, 0.14651587658694812, 0.12108017717088972, 0.17852968802409513, 0.1358188670128584, 0.10240038630685636, 0.23464099211352213, 0.21572146804205009, 0.12630440826926911, 0.14389263306345257, 0.07998851713325296, 0.11514765050794397, 0.2112053425184318, 0.0769523104120578, 0.14138134781803402, 0.18716579675674438, 0.23388431700212614, 0.12017118451850754, 0.11137812385069472, 0.12654481322637626, 0.10476326915834631, 0.08627664364342179, 0.15601976375494683, 0.07454089195068393, 0.1421065389045647, 0.23632886154311045, 0.13118046947887965, 0.11214144860527345, 0.20596722859357083, 0.21298807114362717, 0.13553894417626516, 0.17926851766450064, 0.1973595776196037, 0.11438398648585592, 0.08451234402933291, 0.0794393244598593, 0.16384424961038999, 0.11152170186064073, 0.1740458607673645, 0.05609735001676849, 0.09722739138773509, 0.10413235372730664, 0.11128316966018506, 0.10251465160399675], [0.08190781450165169, 0.037538301066628525, 0.028337970109922544, 0.06370820929961545, 0.04204141907393932, 0.022885881863268356, 0.020817108319274018, 0.015977755854172365, 0.05372682007561837, 0.03990449856168457, 0.024462437623047402, 0.03995932758386646, 0.024717931502631733, 0.05422802675249321, 0.01940174024951245, 0.033782355287777524, 0.07507786420839173, 0.06655011073287044, 0.06827272115541355, 0.024354481005242894, 0.01918791520542332, 0.01855898618565074, 0.03133808894615088, 0.02320487135356026, 0.0159787940127509, 0.07636590687824146, 0.03759381540917924, 0.036899450168545754, 0.0782817437180451, 0.025131793759231056, 0.08418456411787442, 0.03190828227837171, 0.045913407911679575, 0.041973494325897524, 0.05533597605036838, 0.06696645303496293, 0.029227750043251684, 0.044701344200542996, 0.037854328751564026, 0.018410035874694586, 0.03986770160762327, 0.048318210656621625, 0.0476404797019703, 0.03108499538419502, 0.0886506883959685, 0.05640235829300114, 0.017523394165826694, 0.007857704385449844, 0.045783722906240394, 0.042761399011526785, 0.020686436045382704, 0.019680367084220052, 0.03398357145488262, 0.04010769944371922, 0.04583503033167549, 0.0352053246460855, 0.021947883535176516, 0.028582839827452387, 0.02995596400329045, 0.05307464614244444, 0.024210197318877493, 0.030104339255818298, 0.030254051222332885, 0.04052863882056304, 0.011290470720268786, 0.007150341806534145, 0.05377433788297432, 0.04364272439852357, 0.03637899345319186, 0.03388931954811726, 0.037824035555656464, 0.02148970276383417, 0.05946222213762147, 0.039784425004784546, 0.032574732588338, 0.012687636239986335, 0.0377782344418977, 0.03134996670165232, 0.04489981569349766, 0.02344627375714481, 0.027512861349220787, 0.03913228160568646, 0.04595363146758505, 0.04215763515925833, 0.04662431583606771, 0.008159228384361734, 0.1282223689236811, 0.038549403061292, 0.06033997503774507, 0.01966758518080626, 0.02257516371485378, 0.010765209128814084, 0.07249017591987338, 0.02412065105246646, 0.028124842260565077, 0.01866506495779114, 0.0620243703680379, 0.018852064119918004, 0.04458218327324305, 0.001400402555840888, 0.020939650047304373, 0.012819533269586307, 0.05489992230598416, 0.012622669056457068, 0.015713693773640052, 0.02955292777291366, 0.022991109073960354, 0.04176470570798431, 0.05179146517600332, 0.042045463142650466, 0.06760618263589484, 0.035552100145391057, 0.06062994697796447, 0.05502879985475114, 0.03969099073271666, 0.03862715299640383, 0.013565346731671264, 0.030083009507507086, 0.02341944957152009, 0.07000662240066699, 0.04207605150129114, 0.008358916999506099, 0.0772536885259407, 0.030954360429729735, 0.07179455538945538, 0.013706727984494396, 0.050555055628397634, 0.009905369553182806, 0.016138561868241856, 0.050812753050455024, 0.06233338200088058, 0.030891962349414825, 0.051263497077992985, 0.0313544450327754, 0.03590674325823784, 0.009780464826950004, 0.014331611239218285, 0.013300913153216243, 0.02775980738390769, 0.056442860048264265, 0.09650994238576718, 0.03275768259274108, 0.023680069783170308, 0.06467252969741821, 0.03355102573654481, 0.05527273319395525, 0.022167521928037916, 0.05338749149814248, 0.007393917218515915, 0.003984767719105418, 0.07905446618263211, 0.056407895138753314, 0.01630258753097483, 0.04278515112985458, 0.03690292426784124, 0.026885554028142775, 0.017207186669111252, 0.10341112528528486, 0.04093437222763896, 0.02584469996924911, 0.07935506398124353, 0.0550646672158369, 0.030966238185231174, 0.03128409112936684, 0.060816021636128426, 0.031262479789022884, 0.04140952994514789, 0.0268127472206418, 0.03190148675015994, 0.030705002203051533, 0.04864864024732794, 0.02137106770117368, 0.0526793146772044, 0.021517943391310315, 0.03704814433253237, 0.029027660244277546, 0.06570570782891341, 0.06094597466289997, 0.022778956618692194, 0.06779410969465971, 0.08593253817941461, 0.039455135352909565, 0.07829948740878276, 0.0021950571806103525, 0.015595837329913462, 0.022141030224572335, 0.04650053747796586, 0.018807051803118417, 0.02427328920124897, 0.04377734235354832, 0.018317587174741284, 0.08727780849273716, 0.05535730579867959, 0.04858779601220574, 0.016037259982632737, 0.022965294209175875, 0.03424675143989069, 0.02887634014976876, 0.040635674327079735, 0.009583190948303257, 0.0037147408916747993, 0.03981581064207213, 0.04242918826639652, 0.0262889283642705, 0.02684624140549983, 0.03963447215833834, 0.03965300294969763, 0.01039913694174694, 0.011194693806049014, 0.05479519381853087, 0.015934375414092625, 0.042977044225803444, 0.030883612976010357, 0.03174337452011449, 0.030770491010376384, 0.07118295106504645, 0.00227708019000212, 0.021766232925334146, 0.03655265770586474, 0.012573024041817656, 0.04230888740026525, 0.02521364713486816, 0.04979130339675716, 0.03297282908377903, 0.02924730542248913, 0.03800026127802474, 0.011303492655445422, 0.061954264129911146, 0.06908631178417377, 0.04178982846704977, 0.044516039679625204, 0.04718439221116049, 0.022145332136590565, 0.02741808188147843, 0.026901930470817854, 0.01073102283823703, 0.0253001773131213, 0.043713129192058525, 0.056582309172621796, 0.032558193297258446, 0.0388757716199117, 0.013959182875363954, 0.03370697683255587, 0.04299084562808275, 0.024681904685816596, 0.03638321394100785, 0.03530487251867141, 0.033122354453163486, 0.01066806581470051, 0.04544602620548435, 0.020420616559152092, 0.017504561426384107, 0.042506680358201265, 0.10846352417554174, 0.022371888193967085, 0.04430189063506467, 0.0985736862889358, 0.001976998714131436, 0.045752951343144686, 0.07657711447349616, 0.040010394129369936, 0.0044250724853814715, 0.04811738125447716, 0.08623851676072393, 0.06323187771652426, 0.011092037394908922, 0.017457074153103998, 0.08656241545187575, 0.029135431961289475, 0.03647646161594561, 0.056123666997466765, 0.025889520599905933, 0.02324124252689736, 0.023942421955455626, 0.059565827649618895, 0.01713456306606531, 0.007617274831448282, 0.04620489637766566, 0.026541026176086495, 0.030495935385780673, 0.025279873849025795, 0.0258768862778587, 0.018451881129294634, 0.06983245603208031, 0.021329269944024936, 0.021804522656436478, 0.08375193697533437, 0.01732548076792487, 0.03762208317805614, 0.0031536055778685424, 0.006402180613284665, 0.0607463021629623, 0.005208590442115175, 0.03475297249055334, 0.04283109134329217, 0.07286691213292734, 0.015379861329815217, 0.014274744915642908, 0.05842362251132727, 0.016859152487346103, 0.026884385251573155, 0.03224780084565282, 0.043250157963484526, 0.025143347514261092, 0.03995772624122245, 0.022084957786968777, 0.04867327446117997, 0.0466927494853735, 0.02010229372951601, 0.018027518543281724, 0.06642985397151538, 0.04095791060743587, 0.08903924468904734, 0.020165943706940328, 0.01786696189083159, 0.0882493145763874, 0.06325822523129837, 0.006439066625067166, 0.09596966566251856, 0.033901729953608344, 0.005852680902795068, 0.014545904472470284, 0.009464437990183277, 0.034153737859534364, 0.059890669504446645, 0.050700676028749773, 0.08071434604270117, 0.02359147516212293, 0.046408093867025206, 0.06383356864431075, 0.035377217922359705, 0.005828806648163923, 0.017627800349146128, 0.020305981460426534, 0.029919248473431383, 0.04472449581537928, 0.07685785833746195, 0.057674641987042766, 0.013228688189493758, 0.029632367260221924, 0.05682080066097634, 0.032421604198004515, 0.015667634816574197, 0.02147423046907144, 0.03824925309579287, 0.016588260951851095, 0.006960037330697689, 0.05387098501835551, 0.058681404750261984, 0.033867738741849146, 0.007304605046686317, 0.03811712197161146, 0.19273472364459718, 0.13849471057099955, 0.09682958666235209, 0.2113981686000313, 0.17971219814249448, 0.1315307699676071, 0.15015248501939432, 0.1477436992738928, 0.06462556150342737, 0.10360722190567426, 0.1542511893702405, 0.1118253462814859, 0.10753310338727065, 0.10430740897676774, 0.1003854629982795, 0.2015012875199318, 0.20785290455179556, 0.1690089324755328, 0.13212971282856806, 0.13125204135264668, 0.11411316958921296, 0.1069453020713159, 0.14456588907965592, 0.15948572063020297, 0.13879759503262384, 0.20269369067890303, 0.11181733278291565, 0.08441348826246602, 0.19438919558056764, 0.11214802360960416, 0.11597379403454916, 0.10057254867362124, 0.0831030471516507, 0.1682221982628107, 0.12433844804763794, 0.19091828539967537, 0.11034964796687875, 0.07905217951961926, 0.14554790567074502, 0.14181578664907388, 0.11559245735406876, 0.11944904683956079, 0.10999505913683347, 0.08211804500647954, 0.1282173613352435, 0.15056161449423858, 0.09860813551183258, 0.09444987614239965, 0.08694352143044982, 0.2007259934076241, 0.1110608544466751, 0.1595395148864814, 0.1301950602126973, 0.1143720985523292, 0.25275060321603504, 0.13792875808264526, 0.08573438559791871, 0.07486644626728126, 0.09866021307451384, 0.0852981757904802, 0.10655705111899547, 0.10361504541443926, 0.15748830352510723, 0.18552655114659242, 0.1507410734359707, 0.0669223889708519, 0.12094148461307798, 0.17451832470084938, 0.12247836643031665, 0.059320632235280106, 0.08326768688857555, 0.13234022153275354, 0.18847991552736076, 0.09792737489832298, 0.15390505508652755, 0.08249064894126994, 0.1857646626553365, 0.22905116634709494, 0.09746574038373572, 0.18233772154365266, 0.28655937047941343, 0.12299218028783798, 0.17363271436520986, 0.20119921730032989, 0.17165099856044563, 0.14645832324666636, 0.16980687608676298, 0.18443014712205955, 0.18559369897203787, 0.05974956136196852, 0.12103962791817528, 0.18443146347999573, 0.18759891922984803, 0.09658804855176381, 0.16217650552945478, 0.11661616313670363, 0.20991661452821322, 0.12644634422447, 0.1429311760834285, 0.10498262595917497, 0.1394689375800746, 0.0922730950904744, 0.13192007264920644, 0.1347830697361912, 0.06500465223299605, 0.09837135393172503, 0.14989750513008662, 0.1584549852247749, 0.12413722170250756, 0.21169232710131577, 0.1832764068884509, 0.09017571620643139, 0.16069643066397735, 0.09438656882515975, 0.12081085305128779, 0.27868369594216347, 0.10259468480944633, 0.12124206205563885, 0.15901272743940353, 0.21359386720827647, 0.1308952947812421, 0.08296802546828985, 0.17593851206558092, 0.11800578928419522, 0.144475874624082, 0.21479258074292115, 0.14440703046108994, 0.08127748261072806, 0.07841139818940844, 0.11003524876598801, 0.15326274026717457, 0.0979177804131593, 0.13601646998098918, 0.1301275866904429, 0.1527600001011576, 0.11858867800661496, 0.2514350323804787, 0.08944468293339014, 0.09590367813195501, 0.1653772909194231, 0.1890373049037797, 0.16774366822625908, 0.14543597453406878, 0.14891341222184046, 0.10435884871653148, 0.17735627027494566, 0.14120544439979962, 0.12565476527171476, 0.1515695239816393, 0.13467554907713616, 0.20072802901268005, 0.14022977889648505, 0.09408092951135975, 0.1294932243015085, 0.18674851129097597, 0.09336626250296831, 0.09689178796751158, 0.20655104012361594, 0.137989039133702, 0.12638515393648828, 0.21837466210126877, 0.18124275601335935, 0.08891544597489492, 0.11194921284914017, 0.1224715132266283, 0.10508398552026067, 0.114969507924148, 0.16186611647052424, 0.11211891445730414, 0.11221024527081422, 0.09576583374291658, 0.11216157395392656, 0.09631276689469814, 0.10725259701056139, 0.11106119371418442, 0.10167612481330122], [0.02158003782720438, 0.020518727633836012, 0.05745936318167618, 0.031586202061069865, 0.0483541187298085, 0.07560846502227442, 0.027403946300702434, 0.035459290125540326, 0.029479218513837883, 0.042829350900969336, 0.012527782719449272, 0.08954571679766689, 0.02732271378460739, 0.024994276763339127, 0.10688630345144443, 0.06103581269936902, 0.03462512292233961, 0.041219669061579874, 0.012973818562126585, 0.04382288223132491, 0.036024089104362896, 0.025935776332127194, 0.08496272843331099, 0.022134221125660197, 0.0011824136392013834, 0.04830913185807211, 0.051150222441979816, 0.034382512726421864, 0.01927955475236688, 0.029692258153642927, 0.011020876034828169, 0.031041406294597045, 0.051705518537866216, 0.06322425776826483, 0.014682240817429764, 0.03753136643873794, 0.02389817638322711, 0.028485605759280067, 0.04347462074032851, 0.040208899549075534, 0.015828559574271952, 0.06522182415106467, 0.03165419805528862, 0.011833443772047758, 0.038263590540736914, 0.027297414606437087, 0.03330263102959309, 0.027519828207524757, 0.016639639623463154, 0.04246536436091576, 0.03475483167650444, 0.0037002393260731226, 0.05188230065894978, 0.0429729492669659, 0.054114233037190776, 0.03321640958477344, 0.03261634374835661, 0.019145657740799443, 0.008416558549340283, 0.0465402826666832, 0.06310435384511948, 0.04091775829770735, 0.0185325979587755, 0.04908501968852111, 0.03423275326245597, 0.04750336813075202, 0.01246195040377123, 0.013043863732101662, 0.06532245089433023, 0.01080664641423417, 0.06850742641836405, 0.08815474036548819, 0.02189186029136181, 0.03684268053621054, 0.027008742060778395, 0.01861052431299218, 0.02086795773357153, 0.058818014205566475, 0.02662437911411481, 0.020484710977013623, 0.025628618796222975, 0.02349251931134079, 0.049018879487578354, 0.05821763285036598, 0.11688684432634286, 0.02733429298470063, 0.01311520575213113, 0.019308344993208135, 0.10283081499593598, 0.026767589018813202, 0.048539467355502505, 0.03629645984619856, 0.037929998976843696, 0.039440132943647246, 0.015662364295816848, 0.0022593371353910436, 0.06606603706521647, 0.0284504983574152, 0.06495294107922486, 0.014840264837922794, 0.023305007855274847, 0.042054480873048306, 0.024337174969592264, 0.025609467145321623, 0.09103738104126283, 0.025506192419145788, 0.02976073251504983, 0.06917488774550812, 0.050095395650714636, 0.043364742172083685, 0.007998863418054367, 0.07179732381233148, 0.043434278440794775, 0.04444890881755522, 0.02967032790184021, 0.008146016459379877, 0.02304658100807241, 0.044088650827429125, 0.031864493020943234, 0.012639439049442964, 0.03907095221802592, 0.03822352983323591, 0.030125115998089314, 0.03473707441506641, 0.07150480058044195, 0.05201719681333218, 0.026442066932629262, 0.033092403917440345, 0.016153041805539812, 0.022278224916330407, 0.015837619713108455, 0.010973991809545882, 0.038469430923994095, 0.09721892327070236, 0.0415473302294101, 0.029053634564791406, 0.05438281076827219, 0.059839202623282156, 0.010470671496087951, 0.034134810125189166, 0.04726056115967887, 0.01790119567885995, 0.007018571578165782, 0.0943741991317698, 0.005363973689132503, 0.02486472237589104, 0.027207671564870646, 0.010110422835818358, 0.05403873244566577, 0.0396599952530648, 0.04409066268375941, 0.0435622297892613, 0.04906360512333257, 0.028150305983477404, 0.054017663933336735, 0.007876943397734846, 0.06219827210796731, 0.04055888791169439, 0.07252673538667814, 0.0869428836075323, 0.015804434261683906, 0.01581715340060847, 0.011720802718108254, 0.054575039739055295, 0.13577024319342204, 0.022773921888853823, 0.04295986371913126, 0.02407232069942568, 0.0192039388098887, 0.018133739807776043, 0.06254100014588662, 0.01899377446222518, 0.030544260649808815, 0.01982050322528396, 0.01761805488994079, 0.03629294164212687, 0.04997907778514283, 0.01827133313885757, 0.027717024054644362, 0.025897184652941566, 0.018867305712774396, 0.06738949926303965, 0.03643943056730287, 0.03775589706908379, 0.043996794149279594, 0.046150301450065205, 0.05336145610947694, 0.06130853627941438, 0.012061391674381281, 0.06214813515543938, 0.03582050824271781, 0.01941805562403585, 0.06469762870775801, 0.055450275274259705, 0.027898086035358052, 0.03360873513988086, 0.025460925651714206, 0.07097341266593762, 0.05609568082062261, 0.028380809418324913, 0.03395513405225106, 0.05829497905714171, 0.059425689812217436, 0.021678247289466004, 0.04470082172857864, 0.04710385010444692, 0.016587579024157355, 0.036253142170608044, 0.021507436276546547, 0.020959054452500174, 0.06433586097721543, 0.07057597434946469, 0.016995848455865468, 0.09457404126546212, 0.0476069973914751, 0.019151513498010378, 0.018265099098373736, 0.0517301765004439, 0.025471303844824433, 0.03709755864526544, 0.013842277228832245, 0.04039688767599208, 0.04663227844451155, 0.027159980731084943, 0.058078933507204056, 0.08067043125629425, 0.051386369591844935, 0.07019020004996232, 0.03811436372676066, 0.027164835649143373, 0.02342920351241316, 0.03426335519179702, 0.026217582103397166, 0.027146177632468085, 0.039982913461114676, 0.06351694384855883, 0.04234299396297761, 0.013472539256326854, 0.0032745120365039577, 0.013338314003444143, 0.017700133878471594, 0.007363849635502058, 0.05148407184918012, 0.02025123216610934, 0.04037286414365683, 0.03157348631482039, 0.04957740541015353, 0.033154825746480904, 0.019436508383867995, 0.07674617147339241, 0.021389157444770848, 0.03352354506828955, 0.047689619208020825, 0.05230733499463115, 0.029745445121079683, 0.034071411205721755, 0.01414307689161173, 0.03652448153921536, 0.016225231146173816, 0.04285590197624905, 0.0544026375615171, 0.04637094068207911, 0.04734891998980727, 0.013708375976420939, 0.03555301616766623, 0.012648827429594738, 0.04012192153771009, 0.02244400798476168, 0.004387962557042816, 0.02152443357876369, 0.03604506262178932, 0.026565724850765297, 0.02638548389742417, 0.01892422292647617, 0.08714407602591173, 0.0315169541697417, 0.02182593382894993, 0.0629373120942286, 0.015295617814574922, 0.026936942877780114, 0.0830671051517129, 0.05501503577189786, 0.01673062438411372, 0.02198505537983562, 0.06430602579244546, 0.02276920946314931, 0.018802685430273414, 0.042834283850554905, 0.08456522226333618, 0.06152953513498817, 0.042277813889086246, 0.03904863180858748, 0.0500627309749169, 0.03689454436036093, 0.03516022242339594, 0.03229373088106513, 0.02486385215472962, 0.0498661831287401, 0.019479091545300822, 0.0778764004686049, 0.036699282338044474, 0.038697177810328345, 0.09257230867764779, 0.024144510040059686, 0.05412348825484514, 0.02564023870841733, 0.011059077556378074, 0.05022231901862791, 0.04026846813836268, 0.02313301958409803, 0.02116905595175922, 0.08698929540280785, 0.04726271890103817, 0.05190640900816236, 0.034721549533839734, 0.013912503058756036, 0.10157453455030918, 0.012450254156387277, 0.029367297555186918, 0.0812253982626966, 0.02462864138319024, 0.03264223325199314, 0.012392822952408875, 0.01971702663494008, 0.031465717990483554, 0.027514311717823148, 0.017571836477145553, 0.02728108057220067, 0.05824663343706301, 0.011936419942815388, 0.00457869578219418, 0.009573721992118018, 0.028351355909502933, 0.038274033194673915, 0.03399239580280014, 0.08362774471087114, 0.01455742769342448, 0.027570818417838643, 0.03855760994234255, 0.04432570382154413, 0.09161274481032576, 0.017737862121845995, 0.07056201688413109, 0.05216216921274151, 0.010170696253356124, 0.06663689536175557, 0.018817268844161714, 0.03252614608832768, 0.0596334504495774, 0.03310243945036616, 0.03660435189626046, 0.027342226755406176, 0.13434356903391226, 0.11170561877744538, 0.11748410442045756, 0.12448977492749691, 0.08254853476371084, 0.17073224857449532, 0.11409942246973515, 0.18308411006416592, 0.11585538967379502, 0.19138232192822865, 0.1704131064138242, 0.13552958039300783, 0.23761935372437748, 0.10705558436789683, 0.19296565625284398, 0.1264149687652077, 0.16903430968523026, 0.14080244888152393, 0.11347207613289356, 0.10306562203913927, 0.12964465974697045, 0.12186651783330099, 0.14658077167613165, 0.09890857724738972, 0.11765447099293981, 0.21009272150695324, 0.19518675921218737, 0.11608549446931907, 0.06986389934484448, 0.08406488411128521, 0.05173241566600544, 0.10703253453331334, 0.13305963150092534, 0.22374707167702063, 0.17004478403500148, 0.08461327611335687, 0.08262660700295653, 0.1181624358786004, 0.12163664373968329, 0.11019541695713997, 0.10324993250625474, 0.09515794779040984, 0.242084765540702, 0.1398048802678074, 0.20047197703804287, 0.10246860621763126, 0.17490688099392823, 0.08112079530422177, 0.19540976653141634, 0.1778782129819904, 0.11845492518373898, 0.10655086966497557, 0.17455116579575197, 0.05775950636182513, 0.0922373023682407, 0.09400444504405771, 0.24356869448508534, 0.0968012171132224, 0.09685630737138645, 0.2113253210804292, 0.22050820690180573, 0.10574456650231566, 0.13528182011629852, 0.18464871682226658, 0.09836130482809884, 0.09655340255371161, 0.11138140796018497, 0.15140899616692746, 0.11259703737284456, 0.23102480758513722, 0.13097047646130833, 0.16081651779157774, 0.0703068266489676, 0.17681703849562577, 0.13224894500204495, 0.08617311277027641, 0.11388561608535902, 0.20584799642009394, 0.06586973009897129, 0.09508409603898015, 0.0802879546369825, 0.26747280465705053, 0.1292056475899049, 0.2104574205087764, 0.18640384264290333, 0.122051866458995, 0.08062916275646005, 0.11213315690734557, 0.201370452397636, 0.16840119580073015, 0.22578682936728, 0.1257713240172182, 0.15732183174363204, 0.17446624035281794, 0.07364890338586909, 0.1294941199677331, 0.1532865704170295, 0.16150122747889586, 0.20235401604856762, 0.05135688045993447, 0.056576209142804146, 0.24639639418040002, 0.05763736327311822, 0.11597577535680362, 0.14560510617281708, 0.11959395477814333, 0.07500925074730601, 0.12049956832613264, 0.18007933987038477, 0.15799951180815697, 0.10041281474488122, 0.14857901659395012, 0.16952680397246564, 0.08319827275616781, 0.11945702641138009, 0.12920422266636575, 0.18567823086466106, 0.09771574661135674, 0.12256088985928468, 0.1293072107114962, 0.08026919992906706, 0.10799777773874146, 0.1442677950752633, 0.21155220961996488, 0.14192991623921053, 0.12523788692695753, 0.17763623382364, 0.16053267302257673, 0.1745099922908204, 0.12120272059525762, 0.0963028942101768, 0.12526206991502217, 0.16131936652319773, 0.16581069837723458, 0.1496132125279733, 0.15046554750629834, 0.11274619972599403, 0.151300986962659, 0.1527599458183561, 0.21229979236211094, 0.22556846322757856, 0.07781639083155564, 0.08113815901534897, 0.20046490670314857, 0.06714205789778914, 0.08532116455691201, 0.171825626332845, 0.13762514080320085, 0.2043165293123041, 0.10995702724903822, 0.1229284115667854, 0.0877168613619038, 0.18571764017854417, 0.14668806163328035, 0.12215412168630532, 0.11342800528343235, 0.24555707350373268, 0.22227564134768077, 0.1543089055589267, 0.193277008831501, 0.10412053364728178, 0.09004326617079121, 0.11008531107966389, 0.10386181503002133, 0.22664669608431204, 0.08862502620156322, 0.1357253241751875, 0.21153550408780575, 0.06826911134911434, 0.1540440461997475, 0.18764812658940042, 0.1165707420025553, 0.14053852590067045, 0.1365422396255391, 0.1729781994862216, 0.18066608267171042], [0.06555064900645188, 0.08891530348254101, 0.07881233096122742, 0.006156796481393809, 0.041008970367589166, 0.0441744108684361, 0.015099836712969201, 0.02637709890093122, 0.03191673003935388, 0.021975218318402767, 0.01905265773114349, 0.04277424028675471, 0.04453420066939933, 0.017471689797405685, 0.04114822271679129, 0.09722443976040397, 0.03818596613460353, 0.020268056441896727, 0.048912644652383666, 0.03734956994386656, 0.015744938614911268, 0.049017966857978275, 0.04931576909231288, 0.031808856542089155, 0.0008681998692087031, 0.03548506088554859, 0.027203775077526058, 0.023416749002145867, 0.0311652796476015, 0.020767939975485206, 0.07443642469921283, 0.011976743582636118, 0.011980705378976251, 0.07223216297903232, 0.03588764249746289, 0.043306581542960236, 0.09203203195439917, 0.04969804554379412, 0.06076764887464898, 0.05823152246219771, 0.038321249053946564, 0.015672330278903246, 0.030856291763484478, 0.0456704618409276, 0.02806425077973732, 0.07915161882660218, 0.05802183478538479, 0.0666706185521824, 0.02059007389470935, 0.038119540948952944, 0.05887027497270277, 0.02384915222812976, 0.016741762536444833, 0.05093851273081132, 0.02282525984836476, 0.09505996054836682, 0.02598122800035136, 0.042184742633253336, 0.023798416468447874, 0.007812005900112646, 0.05192552333963769, 0.0813878056194101, 0.032472005779189725, 0.05777165213865893, 0.060716534831694195, 0.014712659542315772, 0.015941842691972852, 0.02891051795865808, 0.057332382138286314, 0.029293815605342388, 0.02392356377094984, 0.016834401226203357, 0.004527076654734888, 0.0962766891877566, 0.025219653866120746, 0.018714428380397812, 0.0698200591972896, 0.03805587061547807, 0.03430774834539209, 0.032509002901081524, 0.012381918894659196, 0.031736965756863356, 0.01823550818621048, 0.027509361804862107, 0.03225049462967685, 0.08996829483658075, 0.03071036602237395, 0.01475778890640608, 0.013522178333784853, 0.022677664911108356, 0.020650726443688785, 0.012550123484938272, 0.0352843434416822, 0.05529441238780107, 0.028417467272707393, 0.037763822358101606, 0.011518338046568845, 0.026391219214669297, 0.035326935084802766, 0.1169636816318546, 0.05606751483199852, 0.01875054001409028, 0.03558533479060445, 0.016608613609735454, 0.07586012008999075, 0.04079465168927397, 0.060433076827653816, 0.025608484965882132, 0.057453744911721776, 0.03756310830691031, 0.0515323292597064, 0.00861048894668264, 0.01757514603169901, 0.055633591687572856, 0.023191977491868392, 0.019681481577988182, 0.033163717947900295, 0.03510557999834418, 0.0468450127435582, 0.02980179406170334, 0.057642594778112004, 0.05205109981553895, 0.008643483560133194, 0.05933038278349808, 0.07187440539044992, 0.0635624939043607, 0.08884413194443498, 0.027904691573764597, 0.07256672824067728, 0.032986165689570565, 0.023724191522757922, 0.050378236187888045, 0.022470421656700115, 0.02018956351093948, 0.013724478460582239, 0.026437351114249656, 0.04353208587105785, 0.01635034112924976, 0.04182672380868878, 0.024262994128678526, 0.03081777811582599, 0.050018222470368655, 0.034883356387061734, 0.02291052625514567, 0.050036729513002295, 0.011912504127914352, 0.0488241704713021, 0.08464758962924991, 0.08153970925403492, 0.03607909793832472, 0.04493946927998747, 0.031998286555920324, 0.01707949486028935, 0.048555144907108376, 0.05963750130363873, 0.06203488766082695, 0.03951329258935792, 0.01036469535236912, 0.026170451061001847, 0.05207356271733131, 0.06383567210286856, 0.0805438437632152, 0.02286596007512084, 0.03865556665030973, 0.018751232119809304, 0.001905540282937831, 0.05286394066310354, 0.03989510763702648, 0.03200802353343793, 0.0044169847720435685, 0.06763690670153924, 0.02591952881110566, 0.06711208022066525, 0.024328730601285185, 0.036138412076979876, 0.07444997504353523, 0.07056746552033083, 0.010706509912519582, 0.07877665358994689, 0.030809191255164996, 0.039814786054193974, 0.020587968739813993, 0.044506109319627285, 0.02113522419572941, 0.062418008888406415, 0.05497668497264385, 0.009658080858311482, 0.026917200901412537, 0.08862968095179115, 0.035543937369116714, 0.02077052180123116, 0.1213386854422944, 0.04737898248380848, 0.01787913141639105, 0.06447521849934544, 0.02128979786565261, 0.02801891276612878, 0.03377626543598516, 0.07680809457919427, 0.03746480215340853, 0.03517987619021109, 0.0598875753847616, 0.07552646406527076, 0.02660362612056945, 0.05241263345150011, 0.04018116443018828, 0.0061689197817551234, 0.019874787723113383, 0.05834081409765141, 0.026903404588145868, 0.02006604299614472, 0.009092814538494816, 0.0597558445962412, 0.014924269169569016, 0.03602091016780053, 0.023150921034227525, 0.02387481781521014, 0.034451322962663004, 0.022740636353514025, 0.033377938238637786, 0.021195055717336278, 0.03410663395853979, 0.026340329088270664, 0.02245437430350908, 0.028862596422966038, 0.050670281052589417, 0.06138305299516235, 0.012616906597811197, 0.0727532778733543, 0.018520087469369173, 0.022407472266682556, 0.02067310283226626, 0.02376181459320443, 0.020089825648548346, 0.043330275985811434, 0.030669782842908586, 0.05749230605683156, 0.023281347339174578, 0.02837520811174597, 0.02262124133163265, 0.06799133946853024, 0.07309439099792923, 0.028745895185108696, 0.020471951125987937, 0.06020739608045135, 0.042100163243178806, 0.04670580789180739, 0.04622214134516461, 0.0430272659952087, 0.03510381919997079, 0.05448446209941592, 0.02010736577878041, 0.019025294110178947, 0.02675832192679601, 0.03395968023687601, 0.028764883987605572, 0.010840623207124216, 0.010746069352275558, 0.050881037422056706, 0.008785184572583862, 0.027759576682001352, 0.06145575123706034, 0.019350863693814193, 0.022966415488294194, 0.033716764700199874, 0.0444149345691715, 0.08204063094620194, 0.038344390490757566, 0.015342365484684706, 0.028486206262771572, 0.005751272572004902, 0.05320185449506555, 0.022013675986922214, 0.00824831155062254, 0.031466396525502205, 0.031188946949051957, 0.03212257720796125, 0.017842951929196715, 0.022891878416495662, 0.03910344047471881, 0.014340693430442895, 0.041016753164253066, 0.03153285563790372, 0.03400205135611551, 0.04752914906878557, 0.03176604098241244, 0.027608146325552037, 0.010857358425190406, 0.03318602139396327, 0.018071562251342193, 0.016641795668484907, 0.01043410609210176, 0.030055206535117965, 0.022712595893868377, 0.03485826416207211, 0.02149929555266031, 0.05280428725693907, 0.06556917301246099, 0.02721216855570674, 0.038573426593627246, 0.062472597030656676, 0.031171634128051143, 0.11901414660470826, 0.007791660875747246, 0.055797861622912545, 0.040655765748981915, 0.021924623354737247, 0.02372441204663898, 0.010066494478711059, 0.019816671198766147, 0.012524087248103959, 0.04666205256112984, 0.01432874273242695, 0.017735975794494152, 0.017627021730212227, 0.04740550641768745, 0.057645777107349465, 0.13434521108865738, 0.023519316355564764, 0.016787536508802856, 0.02643867765021111, 0.019020993894498264, 0.02210242667102388, 0.01284386299084872, 0.03136792073824576, 0.09062890974538666, 0.01654538093134761, 0.024237311578222683, 0.041164897714874575, 0.03997934775959168, 0.023889343553621854, 0.02488520904444158, 0.0380253806444151, 0.026038572691114883, 0.03431078139692545, 0.035165053592728715, 0.0290132244117558, 0.013025822334124573, 0.009740172569373888, 0.03655654910419669, 0.04282809221850974, 0.06523552377309118, 0.02870776830241084, 0.016964201582595706, 0.024885838385671377, 0.03597929222243173, 0.060454457466091426, 0.04108766007370182, 0.0651345034795148, 0.05598163265468819, 0.01846812865031617, 0.07420264902923789, 0.23422765572156223, 0.1128455168966736, 0.18327308206685952, 0.0649404696055821, 0.15998809438730988, 0.07222891279629298, 0.15699727487351212, 0.15202611019568785, 0.07899221059467111, 0.16444586589932442, 0.09670591008450304, 0.2032772579363414, 0.23444391840270587, 0.17303340509533882, 0.19007863902619906, 0.21814507299235888, 0.09491223668945686, 0.1802051266921418, 0.0944371468254498, 0.1423463060387543, 0.10146279340343815, 0.16324584957744392, 0.15015005586402758, 0.12915572098323277, 0.04944254318252206, 0.149394086429051, 0.1199660769530705, 0.06463799226496901, 0.09879938739218883, 0.0875490325103913, 0.12542341197175638, 0.21248720373426164, 0.11885284526007515, 0.17300607370478766, 0.12229209499699728, 0.12448241960789476, 0.15198484169585363, 0.11540188400873116, 0.13062356864767416, 0.15526821836829185, 0.13147548293428762, 0.1955189292452165, 0.11748459296567099, 0.13014824129641056, 0.162422189489007, 0.12153007302965436, 0.22255667698170456, 0.10187479986676148, 0.08162585606000253, 0.14407963731459209, 0.13916316255927086, 0.09261584348444428, 0.13508778624236584, 0.14132597936051233, 0.07381523267499038, 0.1827258300036192, 0.07900830544531345, 0.06163151216294084, 0.1700615981327636, 0.08457984469298806, 0.1576080106730972, 0.15665126272610255, 0.06980678026697465, 0.1229065763098853, 0.21083748154342175, 0.14813680175159658, 0.12000129292053835, 0.07891351410320827, 0.1999418240572725, 0.14626981264778546, 0.125218182270016, 0.07602682257337229, 0.16085155733994075, 0.13590065762400627, 0.06864957271942071, 0.11000620746718985, 0.12674081485186303, 0.10702405284558024, 0.06771437504461833, 0.13123374804854393, 0.12779516327594007, 0.1244398754622255, 0.109065025113523, 0.09115538506635598, 0.21669602074793406, 0.17264824147735322, 0.13461080326565675, 0.12668814696371555, 0.1878533698618412, 0.09775860966848475, 0.14771938057882444, 0.0913997119558709, 0.10251022755567517, 0.15002439117857388, 0.12067825373794351, 0.11651127519352095, 0.11725025411163058, 0.08926179060446364, 0.1681742122662919, 0.18837235415620462, 0.1059772361602102, 0.1068417304860694, 0.10371244911636625, 0.09701202437281609, 0.14568528187062058, 0.15360043357525552, 0.2687631611313139, 0.1364522251699652, 0.11665462250156061, 0.16572455157126698, 0.12794041048203195, 0.10771769205374376, 0.09294105853353228, 0.09874112159013748, 0.08204622207475559, 0.1162022974874292, 0.1587935063455786, 0.11734197847545147, 0.11496759445539542, 0.07135937695524522, 0.16939115125153745, 0.15991125708179815, 0.11325829688991819, 0.12774849363735744, 0.1564496699720621, 0.14492210639374598, 0.24340991729072162, 0.14438400098255702, 0.15323691522436483, 0.18042008658604963, 0.1897549099688019, 0.1214140842535666, 0.09368991013616323, 0.08128837309777737, 0.0978332349498357, 0.11975384476993765, 0.13883623081658567, 0.15193021962685244, 0.0942427126158561, 0.09945120848715305, 0.1918269930673497, 0.20984287134238652, 0.16172912025025912, 0.12496864423155785, 0.18997798514153275, 0.12946362660399505, 0.11657228906239782, 0.11668686648564679, 0.1525053187672581, 0.21738231820719583, 0.16934415591614588, 0.1353917292186192, 0.09189561927425009, 0.17376749856131418, 0.12968618609011173, 0.13130135727780207, 0.16017570931996616, 0.08077139048171894, 0.14010890466826303, 0.2147251343620675, 0.15933295525610447, 0.126445543553148, 0.09754377869623047, 0.11693882010877132, 0.13978072442114353, 0.14421709493866988, 0.10369123132633311, 0.07785475520151001, 0.16554653112377438, 0.18623958288558892, 0.13296884351543017, 0.10753467080316373, 0.14089206978678703, 0.1259772458246776, 0.08156884554773569, 0.17568376287817955]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03725887356059892, 0.027482011754597937, 0.015502185926639607, 0.012514150950924625, 0.020357234603060142, 0.0386487032685961, 0.024281940522736738, 0.04096811916679144, 0.05533137558294194, 0.026425980563674654, 0.037079326409314356, 0.05158244585618377, 0.03539632886115994, 0.006896177855586367, 0.04165266600570508, 0.008115268645009823, 0.09759424813091755, 0.04510831254135285, 0.045378403405525854, 0.050270986942840476, 0.0253398376849613, 0.022320981104192988, 0.02765968954190612, 0.11738982876496655, 0.09382774095450129, 0.019232130243576, 0.06443441818867411, 0.0179984127836568, 0.04918617229642613, 0.049235030210443904, 0.02808184010375823, 0.027138839276241403, 0.04075204308277794, 0.006024519048099006, 0.036716941211904795, 0.04119846144957202, 0.013926124649255403, 0.06017087732574769, 0.07615189014800958, 0.046348152083477805, 0.02481774739655001, 0.012090289632656744, 0.025978384938623224, 0.01843913484896932, 0.061870492196508815, 0.014812400797381997, 0.023666188653026308, 0.04832517242591296, 0.03290237340011767, 0.007941976738428431, 0.010002554427566273, 0.015008346443729741, 0.019388067768886685, 0.010970105500226575, 0.0020354443279627177, 0.04212471942550369, 0.011591256812347897, 0.01094659002098654, 0.016041678941941688, 0.004748158630848463, 0.044472996810717244, 0.0186165395259325, 0.041147120097385984, 0.018760358415810124, 0.06071208364197186, 0.023710766707413962, 0.03339614672586322, 0.05006913634549294, 0.08571985816316945, 0.05075308946626527, 0.025015654009101645, 0.05596091019521866, 0.06470505188086204, 0.06691112528954234, 0.01871582955521132, 0.027483414625748992, 0.016982201420302902, 0.047222322318702936, 0.019917660958266685, 0.0694248600463782, 0.02225204703531095, 0.02568779044252421, 0.02894164914531367, 0.04950593870931438, 0.08820379844733647, 0.034241669212601016, 0.06399537889020783, 0.0306487414719803, 0.046128221920558383, 0.015995243397940482, 0.010616465771038617, 0.03260822846953358, 0.02985277579032949, 0.023613985561366593, 0.034282469523272345, 0.027189614051686864, 0.059766897931694984, 0.023899670856605684, 0.004366536965660218, 0.013054526909919721, 0.028046186481203352, 0.036402935561324866, 0.049317248298653533, 0.021046312359560813, 0.023051932953031998, 0.056639736983925104, 0.0824107446574739, 0.07632901492927756, 0.03314165538176894, 0.06804110322679792, 0.04821012681350112, 0.06412976275065116, 0.02928270798708711, 0.0344205988970186, 0.023469011465619718, 0.04800377074362976, 0.01317408902104944, 0.01169723634874182, 0.023023644828104546, 0.027333399014813558, 0.022165935852431824, 0.05881933056350265, 0.03454496079523649, 0.02315459360501596, 0.04090889323768871, 0.05937948836279767, 0.021989362380866493, 0.020335070256675993, 0.013805257206383561, 0.023497662606782148, 0.01741654864911522, 0.07111346229378666, 0.09844863907034908, 0.048162595435444794, 0.038825376824076684, 0.01328054946913783, 0.009709575729045485, 0.04399441249136414, 0.019324643404356072, 0.028008281818724105, 0.010939219434346472, 0.029654490894504955, 0.04451987000980547, 0.03453845703708274, 0.04859107333634581, 0.04986774715195809, 0.05170889764225908, 0.029186189773359468, 0.024639123052890812, 0.016109523962118795, 0.012137578434443899, 0.04536175215616822, 0.016757194119106446, 0.025370655049170767, 0.016152098641863892, 0.1275965017931802, 0.016135267580726316, 0.019161671167239547, 0.026239022113648907, 0.07303330249020032, 0.01877179173087435, 0.07584597942020212, 0.028015509913010255, 0.04567719969366278, 0.04047107190958091, 0.016473179716350775, 0.019403378911582485, 0.03425894132150071, 0.053718511414315016, 0.017516123663101877, 0.036531999707221985, 0.05097259893747313, 0.06235642505011388, 0.0403081183321774, 0.03186008593599711, 0.02026327107367771, 0.012015478602344436, 0.012541587514403676, 0.03837756406781929, 0.026817739542041506, 0.04401914509279387, 0.08993329600031887, 0.02422652965677636, 0.03780386610222714, 0.04988146713003516, 0.0342904728438173, 0.006046157105759318, 0.0233233554421791, 0.06636164084609066, 0.08707279592220273, 0.02498078239815576, 0.025956702352102314, 0.03618973985846553, 0.06603506194161517, 0.03462781670636364, 0.05243676554943834, 0.04812447873077222, 0.019895228590550165, 0.057950744671480994, 0.038910933304578066, 0.035049872273313146, 0.04001038055866957, 0.046747894026339054, 0.02496651280671358, 0.06460433692804404, 0.03470943429108177, 0.021010229563606635, 0.026856059807219675, 0.008796296431683004, 0.00533014235718708, 0.04147320367129786, 0.030262424344463006, 0.023173160019463727, 0.030177461582102945, 0.062116047234407494, 0.02792560063036425, 0.0256454261086349, 0.05378547264263034, 0.029614844093365327, 0.0523114299534687, 0.04957155643829277, 0.03845106976638947, 0.026318018856857504, 0.03177144890651107, 0.053057397782270393, 0.0436911039453532, 0.018360350147954056, 0.011896659487060137, 0.028623741918376515, 0.06073637519563947, 0.05186251797048109, 0.015933020040392876, 0.02587416535243392, 0.03144709898957184, 0.03571201727858611, 0.009959609946236014, 0.025777733651921153, 0.01979688342128481, 0.03472981069769178, 0.027944664071713175, 0.03638421817283545, 0.04192839549588306, 0.061774072370358875, 0.06866068712302617, 0.0669441224474992, 0.05645605755437698, 0.057445826408054144, 0.03380045860207506, 0.04423378607524293, 0.041576184931078126, 0.009039180586114526, 0.03853374247306159, 0.030032404365816286, 0.021573449252173305, 0.042115596522177966, 0.03130112575101001, 0.03359667078724929, 0.004434940504974553, 0.030169030784496238, 0.04642186473522868, 0.011483555493344153, 0.040988203803343434, 0.025382765202916095, 0.04009881402765002, 0.066438172810844, 0.050844104760991674, 0.03236459707841277, 0.007536372253006058, 0.017864078117002333, 0.043477904849818776, 0.022733772971800396, 0.1259951184370688, 0.011566040754717375, 0.009288275880473, 0.019307881893057908, 0.022501283125685792, 0.019785475551283786, 0.05001490782680256, 0.042524671714220724, 0.011163839970582297, 0.09488953969308309, 0.05610936687194875, 0.010159267179135765, 0.11668559083981173, 0.04597444552928209, 0.017163738375529647, 0.025530719763732383, 0.0320267680633281, 0.04247374766107116, 0.01959560957870313, 0.022201139945536852, 0.06240634487143584, 0.06181222639445748, 0.012195069858405207, 0.05194210334281836, 0.014724856209275978, 0.04455676535144448, 0.015951810371396796, 0.0074989094864577055, 0.01618612547671156, 0.044873305330319066, 0.004877495038921812, 0.043320589898420234, 0.021317999477365186, 0.053413835620241504, 0.03683203771444304, 0.04426498511540038, 0.008469775202684104, 0.09219454109136548, 0.05712770883526121, 0.028547830813165222, 0.050582071500165124, 0.03615807602182031, 0.0356630236575646, 0.018096276193058917, 0.02454246743582189, 0.02597751302112426, 0.015111446447138275, 0.07222089251237256, 0.013509435446134635, 0.029159553881202425, 0.050468033512255976, 0.03408994199708104, 0.05424210635413017, 0.03578295132943562, 0.06792315348450627, 0.0019222494198142418, 0.018494839181325266, 0.04676842310332826, 0.05096171184309891, 0.061692376754113605, 0.018433499615639448, 0.005679908499587327, 0.022748760114024793, 0.02266562939621508, 0.043855126215411086, 0.0032872623456309414, 0.06712969498974936, 0.04432070641113179, 0.07039543653705291, 0.053645321234528504, 0.03994440659880638, 0.025314799742773175, 0.008432412520051003, 0.025492146744259765, 0.02191867769163634, 0.049966891296207905, 0.034362777535404475, 0.026041198621637056, 0.005676638384881828, 0.02085940819233656, 0.04735177322956068, 0.1327702227447714, 0.08119170899902071, 0.1443756278604269, 0.14299395414335386, 0.1624211309743779, 0.15114383825234004, 0.14404994462217602, 0.12722812513155596, 0.18022755905985832, 0.12221128147627626, 0.20102205180696078, 0.12577717298907892, 0.12449352044079985, 0.16321239780102456, 0.08982246409037284, 0.12254563639206545, 0.2019865486238684, 0.11928243935108185, 0.11112705232309443, 0.17359954757349833, 0.1943424716591835, 0.1102041904149311, 0.11986812363777842, 0.24462017949138368, 0.22797419556549617, 0.09862311077969414, 0.11104828797812973, 0.04482832524393286, 0.1498060386095728, 0.11098377286855664, 0.14893694381628717, 0.09717762762946741, 0.07417417769985539, 0.10416870963360582, 0.12559472849326475, 0.0873124748468399, 0.12278678773769311, 0.14212192807878765, 0.11611450862671648, 0.14122886742864335, 0.08731338408376489, 0.12489929795265198, 0.13003644586673804, 0.13215841485985688, 0.1009413595976574, 0.12386069154100758, 0.11531007822070803, 0.2893439696303436, 0.12320743873715401, 0.1755622915391411, 0.12474141642451286, 0.0749737565804805, 0.08716111404023, 0.12163920860205378, 0.18238998231078896, 0.10613144681389843, 0.10134899629546062, 0.11540762441498892, 0.07950095579560314, 0.05271015748647707, 0.17532350149537834, 0.07271811618868794, 0.10417816841176578, 0.24765344815594809, 0.06580579852951424, 0.08242693450301886, 0.15055695974401065, 0.20512334816157818, 0.2588268300252301, 0.19894585678619997, 0.07877978842173304, 0.17807608736412867, 0.16196848026343755, 0.15038980942751679, 0.07034776945199285, 0.138318074334945, 0.1132284684904984, 0.07182560515190874, 0.15083699114620686, 0.1170960638139929, 0.09377693903765508, 0.0983701122126409, 0.10571720118501357, 0.2699679136276245, 0.15211718316589082, 0.13394293481750147, 0.18220267950424127, 0.12176656962505408, 0.13526082624282154, 0.09084462959851537, 0.1044649648080979, 0.13563517401260988, 0.15419964785022394, 0.0887261482753924, 0.17961400055459567, 0.2285693793424538, 0.20682026924831526, 0.11056274867483548, 0.10963509630944047, 0.09391490556299686, 0.13062175017382416, 0.14196072172905716, 0.13997838167207582, 0.12343990483454295, 0.12519802977996214, 0.18095503002405167, 0.13307754482541764, 0.26308710713471684, 0.10158241234187569, 0.1722332766013486, 0.134840188814061, 0.13482239762587206, 0.13029043509491853, 0.08830185354288135, 0.07835114427975245, 0.12563563058418886, 0.18331055077058928, 0.08062956987747125, 0.1284506552453552, 0.048475810592728, 0.10302075051835605, 0.1925643706428153, 0.10418412594922952, 0.09841093966471297, 0.13848120772412845, 0.1528043762913772, 0.04764169088697859, 0.14628968015313148, 0.2418154685625008, 0.11643392220139503, 0.10542501722063337, 0.1570497934839555, 0.15482076523559435, 0.10580537681068693, 0.06932622819606747, 0.14389966268624577, 0.10910052606569869, 0.0849823991635016, 0.13950826546975545, 0.19826155421989305, 0.09288425836712122, 0.13931090677423136, 0.07033054144786936, 0.15947429410048894, 0.13651887087949685, 0.12059301616890089, 0.16443391011229583, 0.08038657291659287, 0.12142130386616502, 0.1062806566644992, 0.14169084121073994, 0.1266060849385602, 0.07475488832486527, 0.11629137556467738, 0.2710988957967077, 0.20326222160032817, 0.148339412308165, 0.11718736748610224, 0.17800486832857132, 0.15351819513099535, 0.12440468663615839, 0.10084302630275488, 0.08632405288517475, 0.1456521422203098, 0.11317246221005917, 0.10778488059129034, 0.11291602347046137, 0.09729895647615194, 0.14826030869569096, 0.11484857941312449, 0.17103640868195466, 0.15098911869738782, 0.13980686159006186, 0.09619015561682837, 0.11491054323102746, 0.10005530142890555], [0.0407754084361451, 0.050251190683671405, 0.018647345015779138, 0.03510452148371509, 0.05444128691617932, 0.013278795456114625, 0.046441932408405204, 0.029812070474560772, 0.011609800326238786, 0.02920248479183231, 0.0335592156542199, 0.02843507525644132, 0.04389004023479564, 0.02499127933489425, 0.08431386575102806, 0.04399554564484528, 0.03367087537688868, 0.03895902447402477, 0.04615528868245227, 0.018207903685314313, 0.040286032017320395, 0.031037721849445785, 0.026428996651832546, 0.02912090452654021, 0.028351043783394352, 0.04045463779142924, 0.06633391590522868, 0.004149767927758927, 0.03234300948679447, 0.05874929217887776, 0.06799764984420367, 0.0551424307216491, 0.028538304181503396, 0.06940749633525099, 0.04379956776808415, 0.018050169738541757, 0.04011812174160566, 0.05566071951761842, 0.06311748349773032, 0.026779970586565987, 0.01684262167795428, 0.02143760145242725, 0.04620317629139338, 0.08063223652009453, 0.011199399446403342, 0.02565543619649751, 0.04679538469229426, 0.020490361477381418, 0.05005933829982366, 0.022104085689144473, 0.06234919186681509, 0.034661651855068545, 0.0714482446866376, 0.009962696432402092, 0.015311831408845527, 0.0696860213897058, 0.05040464477081384, 0.016779349983802865, 0.025927216612866948, 0.0786894957668015, 0.04196912795305252, 0.04482988926715084, 0.025293721052418863, 0.01739799919804292, 0.022190310526639223, 0.011998533038422465, 0.054086094189967425, 0.027716584703219787, 0.0270743309520185, 0.02880117204040289, 0.04613587918824383, 0.04715591409642782, 0.0668589798733592, 0.03876324337241905, 0.03675236752522843, 0.02395713938001011, 0.011271241886009063, 0.04401536565274, 0.0389419389622552, 0.018879134274486984, 0.009622246575807887, 0.03755131197561111, 0.033928667793848684, 0.0525790611281991, 0.014623218448832631, 0.0888917651027441, 0.016346907742055397, 0.045387142936566045, 0.06343948229082993, 0.02284822995508356, 0.004783145592747522, 0.0444839110464922, 0.04988546030861991, 0.022909148829057813, 0.015624520701489278, 0.047606607233839374, 0.01786220875302596, 0.07129288052341767, 0.03271639034418123, 0.0025580918632580763, 0.0359189602812486, 0.07488440030387469, 0.015136798211772527, 0.03567731699773243, 0.056217206442462545, 0.03841457136773637, 0.045396625463451655, 0.03163952473551035, 0.0377694983035326, 0.021851138012217622, 0.029112097141998153, 0.013087733565563602, 0.008784748613834381, 0.046212407760322094, 0.085200982434409, 0.034828612181757174, 0.054800893512687514, 0.04183274241430419, 0.0287844495448683, 0.0058448289803761455, 0.03031570969947747, 0.04649451547967536, 0.014339891062783343, 0.04173441590475185, 0.06277072496180024, 0.0986078708831753, 0.05004186602309346, 0.02183281078136393, 0.005568154206100319, 0.05484858434647322, 0.015583560935088565, 0.050960972239928584, 0.04905435669102839, 0.05134375419999872, 0.02409210678056947, 0.03960603475570679, 0.014932833977841904, 0.009012302965857089, 0.06334894536329166, 0.06440666610641138, 0.027322330412321856, 0.04285489095907126, 0.08224708879632608, 0.07596852284457002, 0.02219286181830934, 0.009140937090186136, 0.05656016857496329, 0.04103215251650129, 0.03963520836883357, 0.06865132333976881, 0.040794970600732734, 0.011776768286446375, 0.028592176469308988, 0.058222382595496516, 0.061741353411759646, 0.0675990240914481, 0.04953129217028618, 0.018708131575424756, 0.0519127668812871, 0.014547244579132115, 0.04172672810299056, 0.08990040062261478, 0.012684524308757057, 0.03884029780913677, 0.025002015455226814, 0.03919585355158363, 0.04412893205881119, 0.024954121060935513, 0.035870682514671764, 0.035970284670059166, 0.04642269933330161, 0.035134054720401764, 0.02867003157734871, 0.04171554584588323, 0.01393763005866536, 0.02096364474190133, 0.04027534169810159, 0.022617224404322248, 0.014422032815803374, 0.03209033322387508, 0.047811572306922505, 0.03308796290574329, 0.07521885021456651, 0.06230904973511185, 0.007740062528422901, 0.03461366585854973, 0.018121768753709536, 0.027477043181923882, 0.009075231151655316, 0.050834489919777424, 0.028404088258477192, 0.03627165599859186, 0.027672651257099848, 0.061700980578150065, 0.03350813214534095, 0.04730423167347908, 0.053961091076156924, 0.04973634545292173, 0.04511883322681699, 0.011170306409310018, 0.022394580101328235, 0.024619099484490495, 0.02256899413519672, 0.028557856168065752, 0.05027460353448987, 0.02979306470868843, 0.046081321580069404, 0.02788412008833672, 0.004474629714552845, 0.061877840730760775, 0.06078090744891337, 0.046263745719833035, 0.020084958856127093, 0.03501985388408814, 0.04499128899936165, 0.04037265040512596, 0.024276812494333302, 0.056053855922073126, 0.01306571764871478, 0.07151569785284144, 0.0381326163187623, 0.03157739467652781, 0.07476657948323659, 0.025158913107588887, 0.05090807704254985, 0.05668067978695035, 0.020703005870538096, 0.013804267393425107, 0.00760904759434717, 0.04875542808856283, 0.054866894613951445, 0.04864994981991393, 0.04492236341216734, 0.030096831265836954, 0.00852586460366313, 0.038163228426128626, 0.011456607475078531, 0.048772113264671395, 0.08382116111793689, 0.059423091023096015, 0.05154965904408267, 0.03780489408278039, 0.05536673404276371, 0.041127367942993126, 0.032922705701951466, 0.013674975938296743, 0.01956360986722367, 0.029670280404388905, 0.018899997529972876, 0.0304794571628528, 0.011011756524177534, 0.04072243181456413, 0.027241404933322753, 0.009066708751821091, 0.01117677369620651, 0.023044881277850697, 0.02391460201969104, 0.0083819346036762, 0.09794547821262053, 0.04904483345204166, 0.03406675306281873, 0.005813420018447297, 0.023493292841262052, 0.06495186899389539, 0.07765955424734525, 0.03906152058126671, 0.04974215371268136, 0.09383424131997994, 0.034707785450986454, 0.046516686611409695, 0.0053762462671979195, 0.03513891303113528, 0.009951693138905933, 0.008174574301977242, 0.03611370322427579, 0.021496908805732216, 0.06921534200331994, 0.039139426579432826, 0.013780652678438594, 0.023535562180248753, 0.045068625028112104, 0.0180125704168209, 0.01434020827790456, 0.02425287547521293, 0.03944989027721541, 0.05427248775959015, 0.019213923452688113, 0.006460156341615532, 0.04244680642815573, 0.007534997371424521, 0.016026915716273443, 0.03962794465145894, 0.014021450337687773, 0.03763739771342703, 0.02192800076279257, 0.05781274421938828, 0.009844933287240565, 0.04333750577643514, 0.038153817145419974, 0.030114727626953806, 0.05941972548940352, 0.09754443687519856, 0.06119195039251021, 0.057498453584100516, 0.021882910414465835, 0.031195627126310552, 0.016234761170510734, 0.016310857176514607, 0.023155105898955038, 0.02684831093730671, 0.01622264423141522, 0.01505324340957616, 0.029091276294950928, 0.018537922762334347, 0.06047685590705701, 0.01744257046708039, 0.038717048708349466, 0.03524790271850569, 0.059229898532586436, 0.016803531275529946, 0.03523872892505356, 0.06662042731685297, 0.08082648752523319, 0.04207889795569437, 0.03350383362599781, 0.01993150307264711, 0.04390577546187809, 0.03237094816618732, 0.059364010979022296, 0.01806021205681775, 0.01880450899313603, 0.03849383443593979, 0.03248166133250509, 0.054349515054907115, 0.032414364229355536, 0.043787360923098664, 0.021107224448184882, 0.0859854096280677, 0.014840264837922794, 0.03177337933863912, 0.02921706311670797, 0.061665527123425684, 0.026878327630194168, 0.06634731697184698, 0.030649263943944658, 0.019926183358100907, 0.009590826163600599, 0.03218894132546016, 0.021345091684322273, 0.03993202672739114, 0.02725642260962299, 0.018632254396964396, 0.12203529663383961, 0.14337622720216, 0.09561194200068712, 0.1550309753843716, 0.14817648247948714, 0.08825560459601027, 0.3055868223309517, 0.11759104153939656, 0.0923611553651946, 0.11117357946932316, 0.09291861938046557, 0.12105492209749562, 0.10101899078914098, 0.08242105160440717, 0.2056470550596714, 0.11493719608655997, 0.12712095731071063, 0.21295730636588164, 0.08276390177862984, 0.14309235529175826, 0.1379963265998023, 0.127382437565497, 0.1318773656551327, 0.08891965289201055, 0.09728332302932229, 0.16517097556165286, 0.15975771817777837, 0.1774706577083894, 0.1415080710181168, 0.08722294215112925, 0.14184957769300255, 0.13662363668637617, 0.14646232660327638, 0.1707262367542301, 0.11921354090528828, 0.20514119363256864, 0.09905706785087075, 0.10912264630730663, 0.11612502591950552, 0.08557165932974645, 0.1061544491510306, 0.08839740484420743, 0.11467661149799824, 0.17724903460059846, 0.11628678866795131, 0.06457290040063006, 0.25393421256116455, 0.06719328729169709, 0.10111945468400206, 0.215397087591035, 0.10555701942316123, 0.11476555386824266, 0.13154660697494233, 0.13945975021592208, 0.11359295714646578, 0.137731792937432, 0.2718078020427908, 0.14813225556697163, 0.07223130123955862, 0.16324796660670213, 0.09721384104341269, 0.15198835650725023, 0.19105312387858117, 0.18854681908019952, 0.17761761482272828, 0.10382290104670183, 0.15550744267446653, 0.1480312217026949, 0.1311524731240102, 0.10064038860478572, 0.12335696071386337, 0.11469904386571475, 0.1461652639721121, 0.21114020315664156, 0.08837307936378888, 0.08996881052319493, 0.12139794869082314, 0.12295369378158025, 0.10175267034875494, 0.07871148708675589, 0.07381464234952416, 0.1454290806182793, 0.1459474406604256, 0.1507198488605874, 0.06857067945280246, 0.17045391350984573, 0.06265168956347875, 0.13094537066561834, 0.1862152913319213, 0.11850736236998013, 0.08354777935892344, 0.14984909844185623, 0.08456362092069217, 0.12420067829745156, 0.08337453579796211, 0.1504217412854944, 0.10424490911620003, 0.1552483101508447, 0.09218206961772271, 0.1533616435314928, 0.182415671646595, 0.15728101107691014, 0.1224436525787626, 0.1221476484622274, 0.1153496503829956, 0.10751603823155165, 0.10080610042704002, 0.10783015923308474, 0.22186268493533134, 0.09356205378259931, 0.0866272494729076, 0.12776997605604784, 0.14507226619337285, 0.17877291568687984, 0.1557357832789421, 0.11856639491660254, 0.13230596908501216, 0.1516443799648966, 0.10949227825871535, 0.10667341987469367, 0.09947259591094085, 0.14158314413258008, 0.10214127413928509, 0.12849229015409946, 0.19959018006920815, 0.15325235868138926, 0.1740326971880027, 0.1492392040256943, 0.12038509946848665, 0.13462460466793605, 0.13913219422101974, 0.07711616304836102, 0.1646774634718895, 0.16790840295808657, 0.12007503610636507, 0.1022867588326335, 0.08656736875751189, 0.10921569381441389, 0.12832864107830183, 0.14715949419353688, 0.08200812911880867, 0.1652734750615699, 0.17629182524979115, 0.1536778137087822, 0.2017777091158288, 0.189982287053551, 0.19413283147982188, 0.12220703384705953, 0.15534042806497642, 0.20074708227600369, 0.14338542813701288, 0.14030413276382855, 0.10152168345770665, 0.16818439029157162, 0.08372031045811516, 0.1827990710735321, 0.10051264760217496, 0.15386190025934152, 0.08726591377386025, 0.13798981266362326, 0.06853283755481243, 0.16340170907122747, 0.07706287769334656, 0.07099574325340134, 0.11701938935688563, 0.1960656520511423, 0.10899276791938714, 0.15253621925200733, 0.08491896970995835, 0.12590081564017705, 0.1008878910381879, 0.0933139067409294, 0.0885825634800962, 0.24319208040833473, 0.06954086917851653, 0.11587451079062053], [0.019229804564799582, 0.05088943090023739, 0.04394068269591246, 0.03481353174096771, 0.07483226845839194, 0.002766393420253215, 0.015820832756747092, 0.027255509980022907, 0.08245717680880002, 0.045452302654406855, 0.04281740868464112, 0.023928401725632802, 0.013174887996033897, 0.03485481720417738, 0.037566249924046655, 0.00753245032059827, 0.024617158874337162, 0.010704105354047247, 0.018144838944343582, 0.03607221080788544, 0.05197111410754068, 0.1377672396068062, 0.009698629262857139, 0.04792510817891785, 0.022392988936709504, 0.04536689884428467, 0.07652935917888369, 0.009845885780772992, 0.014333875849843025, 0.022572615815858756, 0.03142655294920717, 0.03476724547467061, 0.016902229283005, 0.03039097280374595, 0.05338636513001152, 0.032621704175003936, 0.03375116303297026, 0.027610392276463763, 0.06163172929414681, 0.08210753449904067, 0.05106888644929443, 0.034840757958590984, 0.052808962363217554, 0.021938970977706567, 0.025338609536577548, 0.06228139264775174, 0.07762385652001415, 0.06445275899022818, 0.0538327834968056, 0.018120123306289315, 0.034049274000738344, 0.038736729616565366, 0.01501720811107329, 0.016525837426472987, 0.09493886240358863, 0.03408181993290782, 0.03298399777018598, 0.05079847667366266, 0.021951120147215467, 0.045988911895879676, 0.015391489723697305, 0.012942836653175098, 0.03256299053984029, 0.05494312123794641, 0.06391017524791615, 0.030936199439955608, 0.03924049097778542, 0.06391754413821868, 0.08218579672809158, 0.059987910357969146, 0.05438937559457762, 0.01782982058024832, 0.01522283984481224, 0.04591140962604966, 0.03414652842496123, 0.03577240010989564, 0.01837597002408334, 0.04251918236591986, 0.028960563308958496, 0.08117199755672898, 0.10120284663779394, 0.013184066878498664, 0.058992479129561355, 0.033822242968848774, 0.062037343957594464, 0.03487156344843762, 0.049210209399461746, 0.055924754456749985, 0.03588554243158017, 0.05107023334130645, 0.10127730228539024, 0.018932945494140898, 0.028892479105187312, 0.0028118851644519183, 0.05982136393764189, 0.02104487725799637, 0.01963325639787529, 0.06939254820879016, 0.01840744387092335, 0.09375002833881549, 0.052227389998734, 0.028176858755094663, 0.017720406808491265, 0.049335826587464125, 0.01857625659821289, 0.019384503763701235, 0.008427235297858715, 0.044351844383137565, 0.07099724960114275, 0.05317134077527693, 0.006941673628586743, 0.035809943452477455, 0.03085674298927188, 0.003177269486643906, 0.012428468093276024, 0.046444137647215805, 0.0800553121204887, 0.03344725737614291, 0.04190910813797798, 0.08099591093403952, 0.0073221366952306455, 0.008257347092564617, 0.03858385906953897, 0.09032778947481088, 0.08229936313416276, 0.027705938488777195, 0.041660140068935494, 0.028812283051333258, 0.05676648732540863, 0.05375995972592916, 0.03859019319393805, 0.01895527947427971, 0.07546637300401926, 0.035425631395940266, 0.052459750923195055, 0.1421801463833877, 0.03986210369371942, 0.029033872232373272, 0.09565108668591295, 0.07283631698893649, 0.01125626068096608, 0.0355558422660189, 0.032340336058820994, 0.022569391078182628, 0.025948422528537254, 0.049353020664836676, 0.022168315814009736, 0.03150817392660039, 0.05419666825660637, 0.05927283622856651, 0.023927253305113742, 0.08075570953743798, 0.03564555138083441, 0.03188808907621673, 0.05860487957085882, 0.028258330454783778, 0.04082081599959305, 0.05831009003200701, 0.008322274412161537, 0.031478335349155326, 0.05929987584905965, 0.022103653123070086, 0.026599649905360172, 0.0250347293248134, 0.004682105791289359, 0.028100116444485526, 0.037611386073487144, 0.04594791820272803, 0.03730746006060924, 0.05936614836433104, 0.01835180739206927, 0.016840872753943716, 0.0689528507313558, 0.029087099911911145, 0.021785279403307607, 0.03102339118985193, 0.006215219194668212, 0.03162882084559117, 0.013997288553842475, 0.03562136160741959, 0.030735332718385116, 0.04688896484939115, 0.022330372028851082, 0.02426126386438097, 0.08878055321318762, 0.01217559166252613, 0.022972291601555686, 0.05339121665539486, 0.022954948246479034, 0.024110522220975587, 0.031760069874248335, 0.06203532192323889, 0.03612996092332261, 0.01743620411226792, 0.05491553878943835, 0.028165802026965787, 0.04957531891497118, 0.0585365103823798, 0.05608450534886547, 0.08275681787303515, 0.04947722310732518, 0.0020822787233295715, 0.04087492577465517, 0.027259576101122156, 0.01751461561902293, 0.017779965219753127, 0.04594699878777776, 0.006537974554313613, 0.023230469087138772, 0.0681496009762798, 0.030968728408749615, 0.03206554973231895, 0.061813244196985445, 0.03458344390881913, 0.014015178977777916, 0.035563696308859756, 0.07022862548806838, 0.019478563984323825, 0.05682362675932901, 0.017500515661335418, 0.05244215311748641, 0.031527664845011065, 0.0507947447310601, 0.06146542036107608, 0.0849979172593781, 0.03602426213079265, 0.03614278184249997, 0.0720540475366371, 0.011900465220345982, 0.040323853559259853, 0.10862929706594773, 0.02495665878190526, 0.03840972662770322, 0.028515016859663383, 0.010863428769100989, 0.017226516435455, 0.021610895903514962, 0.04380887048318982, 0.02693614729547075, 0.05122702242806554, 0.041736729709165435, 0.04120817807103906, 0.03671274447281446, 0.053112311621329615, 0.0854575229542596, 0.010607946763879486, 0.013531742284872701, 0.03653558237212045, 0.041932527774146626, 0.0385916757929538, 0.014525801176205277, 0.008373857492447963, 0.03354999436331647, 0.03552025310429079, 0.03491927803094898, 0.05577823160482304, 0.0610368779993483, 0.05822860476161752, 0.016905499821794883, 0.013332185135888202, 0.05911228127245392, 0.05649788584560156, 0.024553519074938128, 0.058341289072164466, 0.04174053629062005, 0.05054170545190573, 0.06906218986426081, 0.0641239680615919, 0.02377251678678606, 0.0468775451050273, 0.0592768599412271, 0.03784146033493536, 0.009869387689312654, 0.010470249108038843, 0.029450384168220416, 0.04593738394656351, 0.01763825148477086, 0.014851716812700033, 0.024774027688960944, 0.06235860314752374, 0.06865478386836392, 0.03638549381867051, 0.04977702023461461, 0.04481691907026938, 0.03494805130841477, 0.03808064732168402, 0.05490416993520089, 0.07343471023653235, 0.019001068713675653, 0.005657279780799789, 0.011247457537267889, 0.03379475212256823, 0.011646598976637636, 0.05408135123018708, 0.016390079532616904, 0.02407501787612481, 0.019454165561390773, 0.0746697796774762, 0.04320794290729931, 0.011304375599138439, 0.021258877024852803, 0.07245329075625964, 0.031661421060562134, 0.014678117020853927, 0.036884074565023184, 0.05047739051016314, 0.06443454032497746, 0.010623508116363414, 0.06630630631531988, 0.039637851262731214, 0.02030395094438323, 0.10389202340905156, 0.02405026152596942, 0.019048435546989952, 0.031817385727273564, 0.05809066537767649, 0.022944951729316796, 0.026974148649190153, 0.00727115581477327, 0.024674272863194346, 0.01949360371301217, 0.023448392482740537, 0.0359809614185776, 0.04364420699753931, 0.022406802213351642, 0.011500890366733074, 0.021904557377898266, 0.06316639908722468, 0.05032696608187897, 0.043864459464592595, 0.04047090566850134, 0.02578831710187452, 0.028145922647256936, 0.027027837732540708, 0.020415880384721925, 0.008793768888738538, 0.020208457318533744, 0.025781833699771335, 0.012855296305912946, 0.025945335194202404, 0.0447946190168815, 0.07805175427347422, 0.02952633598553283, 0.025780086472098316, 0.08138191593544823, 0.03924161395324128, 0.013654613102387105, 0.04620549688115716, 0.05658411746844649, 0.049994521242167266, 0.019184698949434927, 0.05736636995737042, 0.05798043736389705, 0.06564025634101459, 0.15252336779875414, 0.13488605778132165, 0.12949345500341483, 0.20032355428806373, 0.11818648315966129, 0.08083496242761612, 0.1581543263580118, 0.09018024882035595, 0.09428661383156266, 0.11607128594602857, 0.07820401074630873, 0.12297277418630463, 0.1478852281080825, 0.0668955732669149, 0.12180444544979505, 0.09340688639453479, 0.10988126881420612, 0.14219146434749874, 0.2233043411480529, 0.2508644387125969, 0.12170886700706822, 0.2799230265830244, 0.13937954737671784, 0.06653578007327658, 0.1414146910288504, 0.07723922894469329, 0.07723306784672396, 0.12296379038265773, 0.09437694041324513, 0.0728359098679253, 0.1387890183499881, 0.14978748746216297, 0.13385346318994248, 0.12089937472982065, 0.14497758341687067, 0.0905384745981012, 0.16461385759924138, 0.13285465964249202, 0.17520493428621972, 0.13786511149789604, 0.12442166358232498, 0.12236159055360726, 0.12779848809753144, 0.2013025310422693, 0.18563617526420526, 0.12750032623963697, 0.16858784721365996, 0.1249866389802524, 0.1184564722435815, 0.17508087094341004, 0.04869156776528273, 0.07418597063847951, 0.21579194068908691, 0.0846946324620928, 0.0864744840988091, 0.21520348797951425, 0.22963758345161164, 0.14463777307953152, 0.10232652777007648, 0.1432177485632045, 0.12727513403764792, 0.2018273507377931, 0.19162552244961262, 0.09598086827567645, 0.15118669452411787, 0.12816458488149302, 0.17784770604755196, 0.11965882272592612, 0.14326395679797443, 0.1486757214048079, 0.2246545579816614, 0.09394013349499021, 0.09226950564022575, 0.08795851482344524, 0.10373271695737328, 0.09736129348831517, 0.07297696372760193, 0.13256742219839776, 0.21476656571030617, 0.1648232942180974, 0.1488213078784091, 0.09563336335122585, 0.10703826136887074, 0.17854992193835123, 0.1759248599410057, 0.23733382618853024, 0.11866718450827257, 0.08704048408461468, 0.16967891795294626, 0.09360878448933363, 0.08571683189698628, 0.15335198119282722, 0.10545503560985837, 0.1271552640412535, 0.11877752787300519, 0.10311904988650765, 0.05650490868304457, 0.111245945229062, 0.0903359047536339, 0.10808675403573684, 0.14894448912569455, 0.08885920899254934, 0.1977619488856622, 0.11924347787031106, 0.141793123579451, 0.13363596557506494, 0.15423941000231675, 0.10567480631704841, 0.13646253890224866, 0.09322820098272391, 0.09481069392391614, 0.08755045743393046, 0.10592338762113027, 0.1469514010740178, 0.23335807238306316, 0.0876913077331015, 0.10228480465177979, 0.14368941182536737, 0.16086590157023498, 0.09743531487349953, 0.10174728278070688, 0.18155596777796745, 0.11729864722916059, 0.1522743861590113, 0.14371406978794507, 0.10959905931460005, 0.09965469435389553, 0.06983915317271437, 0.16155514387147768, 0.09819884997393404, 0.1996473262884787, 0.1863484741853816, 0.1157864640866007, 0.2826765759715012, 0.15199959304715904, 0.1168312451669148, 0.1700651672269617, 0.2119375496570553, 0.08320739905216865, 0.1478865308953183, 0.0738844025347914, 0.16301175499601023, 0.07489931450358459, 0.10236804054251739, 0.11068232690117188, 0.20747363061777183, 0.11051492552672114, 0.13064444038484777, 0.11314913417611804, 0.15105249386812958, 0.11932738551071712, 0.09081799709903342, 0.16060268426580088, 0.10960818561060087, 0.11742797600371496, 0.14951624987380846, 0.10931825438248259, 0.13270635902881622, 0.12626683099993638, 0.1250916083476373, 0.14040987566113472, 0.11337880470923015, 0.13140513242355414, 0.11776710780603544, 0.0801451772983585, 0.14977418817579746, 0.13829797612769262, 0.17022332016910824, 0.13170219505471842, 0.0863899454208357, 0.23652449675968715, 0.1038021853725825, 0.12334326787718705, 0.16704643278249673], [0.036913858859666755, 0.03579586045816541, 0.014198800731849457, 0.058173609498356066, 0.060576396994292736, 0.031043757418436662, 0.02321336661199374, 0.02083949318953923, 0.036657457439494986, 0.02208310877904296, 0.03265095242698278, 0.03210666895444904, 0.03080459078773856, 0.0515313725253301, 0.02136676918183054, 0.019010105103786503, 0.02949389861896634, 0.039267625593181164, 0.02148448143686567, 0.030884199908801487, 0.04066659177520445, 0.04156787287709968, 0.0090554968088067, 0.009719702864198812, 0.028924163297883103, 0.06391544067966086, 0.05307430008958493, 0.0268001722704087, 0.04043688052999122, 0.04249525722116232, 0.02729474626747625, 0.047846516860382896, 0.015837027691304684, 0.05092568502628377, 0.055349360153611214, 0.019961869211069176, 0.03315421845763922, 0.03068620339035988, 0.01469674619979092, 0.03424736551408257, 0.05315512718100633, 0.007929116803487497, 0.03352874603920749, 0.07198525087109633, 0.04300665549401726, 0.037474186292716434, 0.012870308893200542, 0.031121303793042898, 0.05371063362274851, 0.022255178474422013, 0.1122347471703376, 0.028381510005731667, 0.024021634133532643, 0.03456237878916519, 0.04074137651228479, 0.02926140877285174, 0.0382366391297962, 0.04462478509438889, 0.011553370809581662, 0.054244813708854575, 0.025300385962639536, 0.09581605211964675, 0.03547326794692448, 0.03555650044498699, 0.06514160774116005, 0.013724105266321982, 0.04442772495427302, 0.026075973541342785, 0.06562621066612856, 0.05940109970314162, 0.016701769682445695, 0.035610796817179234, 0.028167732459093844, 0.024698818867493953, 0.03376427572220564, 0.030557810994131223, 0.012247627484612167, 0.02481800693619464, 0.028896343362118517, 0.03148118858890874, 0.033607815724930594, 0.06544601212122611, 0.0562917808336871, 0.029746330609279018, 0.04182565172335931, 0.01978982496075332, 0.058454034450863085, 0.06068660465202161, 0.05794440036905663, 0.0365989100454109, 0.051922544570905824, 0.02517550328879484, 0.053023487994713445, 0.014622187075604285, 0.03317736667980041, 0.03281542592282806, 0.02408999653666147, 0.014729772195486086, 0.03239458832623703, 0.045838087131934505, 0.07984931567417723, 0.03319405185590897, 0.012610101739742925, 0.011126707989855536, 0.026091132013659393, 0.009119374095462263, 0.008145186950319579, 0.023143565714625374, 0.03543660669986691, 0.02269066055305302, 0.0027550082387668745, 0.02966583939269185, 0.01347531276821558, 0.05481322588665145, 0.03608478745445609, 0.01565165870956012, 0.05640266363375953, 0.018100342314158167, 0.017451498291588256, 0.03198221206132855, 0.03611398820898362, 0.09349690085010869, 0.08926960732787848, 0.041954807471483946, 0.023941862164065242, 0.03267107777563589, 0.04809919651597738, 0.025582084864644066, 0.024665865814313293, 0.012948205561510153, 0.03444560630513089, 0.017102074809372425, 0.152683895613466, 0.06369034347257443, 0.019446691498160362, 0.00943617191764393, 0.026658926724589298, 0.0785898393286126, 0.027028989545734863, 0.01284421413272087, 0.03591486192973597, 0.05952103076768773, 0.05205620239887919, 0.023944464345861758, 0.020570311562291214, 0.027051030059478114, 0.0818176439830235, 0.061181860576782904, 0.016029422903167348, 0.07828354183584452, 0.04291157238185406, 0.019855412155655876, 0.015980522580710903, 0.04403431713581085, 0.05498863397432225, 0.0439209339341947, 0.017401561506890824, 0.00305367009215323, 0.046759174671024084, 0.046080201997288635, 0.009524324642760413, 0.07015909600470747, 0.07100976178688662, 0.011143103940412402, 0.04552101789574538, 0.031065168590950112, 0.07892071335975613, 0.01804384239949286, 0.040803822090051005, 0.07746541180780955, 0.025378315709531307, 0.051241285234157524, 0.02476574616905834, 0.06918138132563659, 0.07071779495371239, 0.011360998498275876, 0.016274195929457034, 0.03513515394713197, 0.06836143282375165, 0.015459694367434298, 0.08030724538756268, 0.044422507019979615, 0.024323755243260945, 0.01673618158591645, 0.016170631129560725, 0.003685907818310495, 0.06897897432957377, 0.06514078671378748, 0.0642208628622549, 0.049796650252704105, 0.04284605643312846, 0.03628044981243355, 0.0335544930504901, 0.040380205892558606, 0.0054170130752027035, 0.025298072158225944, 0.03365189675241709, 0.059750457028193135, 0.029921260329761674, 0.014214203476772776, 0.048308592422732284, 0.030642950175596134, 0.03770929528400302, 0.02017849830112287, 0.013908060350721436, 0.04400757607072592, 0.022479695534067493, 0.07196534943899938, 0.03387979630913053, 0.027809457487559745, 0.055598830338567495, 0.022153559373691678, 0.04163240155737315, 0.01469512959010899, 0.013727494548740131, 0.04664772529421108, 0.007996566577016242, 0.028649987652897835, 0.02455236895808152, 0.09485948059175696, 0.03187074572114008, 0.015578556739326035, 0.04854902791391526, 0.02523613378538617, 0.04080242770058768, 0.0232449625951371, 0.026858865549521785, 0.02280592329667083, 0.0577905425535781, 0.02682714573373752, 0.029364732692816427, 0.03206111889864717, 0.06771217659115791, 0.0640512223222426, 0.036327523179352283, 0.029091266116925647, 0.009943858603946865, 0.029982606680797677, 0.05695897074682372, 0.02729500411078334, 0.011993254884146154, 0.045986869505473545, 0.07893567505691733, 0.017670875448467474, 0.04605524887197784, 0.00935981806833297, 0.0989223922203694, 0.026770523682768856, 0.01903344501209046, 0.013111570500768721, 0.022785977759797658, 0.04182363647435393, 0.026000874981816326, 0.036420387482004504, 0.04906309961474367, 0.018566780856677463, 0.035273161184574874, 0.06962896337998764, 0.047502842266112566, 0.007004496641457081, 0.04454948467069438, 0.02182457166989999, 0.04080595947535975, 0.06756099220365286, 0.028569204666252648, 0.05594636579709394, 0.061180293160889826, 0.0371625453366765, 0.06779670169843094, 0.03432365320622921, 0.036710932784314664, 0.01806678536481091, 0.019349886603387337, 0.028349125225629126, 0.050410856758909564, 0.022060669625976255, 0.03691798435258014, 0.0361760538071394, 0.0676851708974157, 0.02536058219681893, 0.06791361328214407, 0.02581875109379845, 0.07771828823855945, 0.0330914234343384, 0.018033898468794565, 0.05996287241578102, 0.04924035671034029, 0.004332257800602487, 0.009085697554317968, 0.030032319548938955, 0.09107662750674145, 0.03061313195420163, 0.14354371678616318, 0.036398067072566063, 0.009888407025885369, 0.03362389361219747, 0.006898193104591752, 0.022533192931275283, 0.08049040913049664, 0.05663699909512486, 0.012642891096350337, 0.02754963455455644, 0.06997188819306237, 0.0121335869521967, 0.024387081220213856, 0.008698870677367916, 0.02324488795628505, 0.035141759485538514, 0.06465142725833825, 0.015636354352214506, 0.01668430758374078, 0.03611881259296622, 0.015259828485016311, 0.06624976399221591, 0.013928380778192409, 0.03920240480718868, 0.03547156821670277, 0.022178354739610637, 0.05350121057459286, 0.021430958594594682, 0.008024380575599415, 0.028617757239512036, 0.06987887461270605, 0.07224234778966222, 0.0336338171868452, 0.045354440941342285, 0.012185558493781303, 0.04436843117166843, 0.018940285546705127, 0.02370402715834124, 0.007761950371786952, 0.005854841612745076, 0.04339151377124446, 0.05186494034049766, 0.04285655676254204, 0.02520198142156005, 0.0645610871059554, 0.03853972715192607, 0.03226090335686292, 0.03472526451306684, 0.01689477727216269, 0.012427701348704951, 0.03362939313852361, 0.05108156148344278, 0.003805595458418663, 0.06504436010228735, 0.018615847420213476, 0.03392971952312759, 0.002532771692910631, 0.033442701013492684, 0.03769423859193921, 0.038128935266286135, 0.11551462938742978, 0.11870518246931688, 0.13686717647526944, 0.0911364946514368, 0.1368575141366039, 0.09204433379428727, 0.11208508270127432, 0.0819247846624681, 0.08393818126725298, 0.10771051315324646, 0.1963810079864093, 0.15266150395785058, 0.21192437250699314, 0.17794731498828956, 0.12612146165754112, 0.1376778358327491, 0.10730175008731228, 0.10657124607158558, 0.0843861365158643, 0.2501647605427674, 0.08274142869881221, 0.15252171217330865, 0.16312159624482903, 0.05642221901299698, 0.13218087436897413, 0.21630864510578768, 0.19361401003386292, 0.1405840963125229, 0.07471505153392043, 0.12811582535505295, 0.11506269792360918, 0.212094033403056, 0.11777378459061895, 0.1326423188937562, 0.13754216954112053, 0.1042353417724371, 0.1278876747403826, 0.1341262071260384, 0.08671599506799664, 0.07880218686269862, 0.12545397318899632, 0.07339094472782952, 0.08140325586178473, 0.2092888882117612, 0.1020768065271633, 0.11477852745779923, 0.08670661092868873, 0.07452600489237479, 0.1273970396390983, 0.13836086275322096, 0.24953809274094446, 0.09141102991998196, 0.22287451635513986, 0.08669648040086031, 0.13767147117427417, 0.12335466726550035, 0.1717052406498364, 0.08153804684323923, 0.1175029134111745, 0.12332865223288536, 0.1346013851995979, 0.19967897316174849, 0.1519354579171964, 0.11847046363566603, 0.14117277972400188, 0.12123994502638068, 0.20187297543244703, 0.10794276211942945, 0.12021851912140846, 0.13621203734406404, 0.16305075718888215, 0.05960734720741, 0.08033929259649344, 0.07309443171003036, 0.11806099489331245, 0.10954830489520516, 0.10091911043439593, 0.19479001978678362, 0.11341739299574069, 0.10969789472541638, 0.10628301796636411, 0.27443690810884747, 0.18008281396968023, 0.0914766239002347, 0.11469441625688757, 0.07186951315296547, 0.1635338334100587, 0.1452630159578153, 0.11924125227544989, 0.054684083709227185, 0.17309008991079672, 0.1277617114995207, 0.13519048930278846, 0.06797206907400064, 0.09836693666875362, 0.16786424389907292, 0.17338352916496141, 0.11501027430806841, 0.154881480549063, 0.18551954866519996, 0.17284845001995564, 0.10167275249425854, 0.1331840476819447, 0.06068440619856119, 0.10564835023667131, 0.09908503027898924, 0.10372999603194849, 0.14154681536768163, 0.10624786985239812, 0.11842650813715798, 0.2197653196219887, 0.10950826454375472, 0.11400563535945756, 0.12204361547316823, 0.1528276771839176, 0.10053589421191386, 0.16790464387408324, 0.15355889366141387, 0.07742256910673209, 0.1716904757278306, 0.09038919689399855, 0.18257340389703, 0.17241706459649972, 0.13999587430485658, 0.10965679585933685, 0.10361068921961955, 0.1429198852607182, 0.06623818139944758, 0.12244905371751104, 0.07364314262356077, 0.09959748028112309, 0.09099843313119241, 0.2651494736117976, 0.10392206215432712, 0.11531329447669642, 0.07936176790722779, 0.1845467872917652, 0.1510857149426426, 0.08376043901911803, 0.1095072670972773, 0.1061774989856141, 0.13650625012815, 0.0810451250789421, 0.10108533794326441, 0.10339972589697156, 0.1207202279141971, 0.14751014752047403, 0.1846518652247531, 0.1074305156778012, 0.13832734312329972, 0.04842060498361077, 0.15193122385868005, 0.17082941478916577, 0.19825533883912222, 0.08370948103921753, 0.18334780234311307, 0.09285673698676483, 0.1518563950168235, 0.08232209405728749, 0.1408207421856267, 0.12917595489748887, 0.12370727477329117, 0.10341789027942078, 0.06900016497820616, 0.1396376078150102, 0.07361223535346133, 0.19162098983568804, 0.13108311327440397, 0.16531546280852386, 0.21616597633276666, 0.09378519002348185, 0.13482876228434698, 0.04504455399832555, 0.16137225154255116, 0.15166093621935162, 0.08690960146486759], [0.028227996546775103, 0.03995983987780554, 0.03609923007232802, 0.039888478349894285, 0.0061601196066476405, 0.02785154022941632, 0.03257321945524641, 0.028358909700598036, 0.04464045925331967, 0.03641262843406626, 0.014612509469900812, 0.07038596418819257, 0.011384120427205094, 0.029980805170323168, 0.03417915578133293, 0.04265451956806438, 0.036231429050011296, 0.06362213034714971, 0.09851556297923837, 0.015584183490968176, 0.011929341974402112, 0.023255708893494945, 0.022501742833160927, 0.012335218722000718, 0.021097833523526788, 0.006880992665953402, 0.0241736955275493, 0.0055712054932623035, 0.05415201386702912, 0.028049161857260124, 0.03232147617797766, 0.04908621730282903, 0.02791664905713073, 0.11318090318569116, 0.028501388483813832, 0.014704902190715075, 0.08819865515189511, 0.007257881125302187, 0.02534070112077253, 0.03430200454645923, 0.05602145248225757, 0.02739676909654268, 0.007751199832585241, 0.035331104682492356, 0.02486504298368735, 0.01812377043201455, 0.021314460917242935, 0.012843032633619649, 0.013073681953496166, 0.05445784995598452, 0.051595460157841444, 0.06295622286519834, 0.02657461365950959, 0.03167282384155052, 0.06030729679124696, 0.03771066253206559, 0.03307237356368985, 0.0311296870931983, 0.01111169794707426, 0.03968512819015554, 0.05353532052998032, 0.033143908118030856, 0.05756706025983606, 0.022327216841014366, 0.028617404401302338, 0.057924519293010235, 0.028064422109829526, 0.040486386444951804, 0.026735285662912896, 0.014234665548428893, 0.013065923753726696, 0.050402290254299126, 0.008346253839720572, 0.04071328855518784, 0.03807616559788585, 0.05475691087277872, 0.04184952597799046, 0.02398878794961742, 0.027839206159114838, 0.033410938789269755, 0.02672276838815638, 0.03837080585903355, 0.07221779839268752, 0.047309836372733116, 0.047867897498820505, 0.04402559456814613, 0.03950913995504379, 0.03395391947456768, 0.025035194121301174, 0.03480950802830713, 0.039953210590673346, 0.029629554732569625, 0.03683301819754498, 0.02483035796987159, 0.030240307495530163, 0.051804669467466216, 0.025054637542260543, 0.01846609134892268, 0.07023581117391586, 0.019683350941964557, 0.025189859393451895, 0.016363706572779586, 0.028267928332622563, 0.05045542633160949, 0.04165981097945145, 0.06658144548003163, 0.02266880833277745, 0.009301304600999823, 0.045623252767005136, 0.02499364402943424, 0.08952177129685879, 0.013610590598545969, 0.06558942728276763, 0.052563654990600686, 0.03245271842128464, 0.05076857702806592, 0.03017477797610419, 0.020780952580805336, 0.006044887397105673, 0.044481302079345496, 0.021557291637041738, 0.046516818925738335, 0.028463298920542, 0.03130076612745013, 0.03200174029916525, 0.05683300072061164, 0.016438827184694152, 0.04111552072156753, 0.06553113433931555, 0.04487963266936796, 0.03220216936564871, 0.02514719480781683, 0.040818692184984684, 0.04443984019703098, 0.06450626826179878, 0.055545796041509936, 0.031199023194078888, 0.06409000059855835, 0.040398872390921624, 0.04790475891370859, 0.0777254942804575, 0.048519369148250134, 0.0525405033757644, 0.018780334486759136, 0.034651402583611865, 0.04385751805135182, 0.06099998605038438, 0.02516419380637152, 0.032029699334608655, 0.03507315280980297, 0.0034964086787242976, 0.058560951213751516, 0.01742200067799006, 0.044252934333469184, 0.07382826733269862, 0.029543475780103887, 0.0011142018920509145, 0.006851545942481607, 0.0215183030148702, 0.020542701972382407, 0.00710096608548026, 0.030344764568975995, 0.001094566360864389, 0.04087718529626727, 0.014106121329989816, 0.028304696448945572, 0.020733205767880594, 0.05507903519485678, 0.0206679629295, 0.03874933679721185, 0.02946743575323905, 0.023707458849198053, 0.02648463482702417, 0.038147398204143555, 0.01918724175941731, 0.02765988970973662, 0.03440786279471857, 0.039498185007167716, 0.008030821569263935, 0.028795906608658176, 0.027917473477178385, 0.0926033787961517, 0.024351000120597224, 0.079579543721463, 0.024544930517939583, 0.021307176843817745, 0.039226733680282316, 0.051754793750920465, 0.0686866750142404, 0.018535527533718517, 0.012423440996956612, 0.04550787806510925, 0.03914102113672665, 0.03992101749671357, 0.018370467105082104, 0.10331143492034503, 0.025628184533811042, 0.020233875240332315, 0.010872851076003696, 0.022274016302877238, 0.031320158658283095, 0.05030051000150187, 0.03209797352818506, 0.07820394967815705, 0.041927737316914966, 0.049800039535122256, 0.060236478091350625, 0.08458577508905105, 0.04942246533132025, 0.04858400978680168, 0.07116024728332247, 0.051188875189317126, 0.023690643055098395, 0.018042660052222863, 0.004944951173716358, 0.05789596653942551, 0.062058690669281144, 0.026325367391109467, 0.009871143398673406, 0.01388533366844058, 0.06096483115106821, 0.041018792161984105, 0.00890246341337583, 0.01693336046966059, 0.04516540787049702, 0.08013609849980899, 0.032703942619264126, 0.07799337312046971, 0.030277572638754333, 0.060045619761305194, 0.03980579546519688, 0.04235738229804805, 0.024124532272773128, 0.017049903948126093, 0.08174614674810853, 0.03643210917445166, 0.023125764348411133, 0.021931352725784694, 0.018512476002797484, 0.01728136242101235, 0.026290326146408916, 0.03359226370230317, 0.049209174633558304, 0.0442632718144783, 0.020090142863669565, 0.030884562925036465, 0.029717235027679374, 0.03000511708004134, 0.0242901660635003, 0.09420407004654408, 0.06172860373875924, 0.03983960686517613, 0.0725870028670345, 0.015018575359135866, 0.031032782114510025, 0.037586734896259646, 0.01258463632049305, 0.015549878456762858, 0.04174491962684052, 0.039877574292144606, 0.028718791103788784, 0.05935853520142181, 0.0489192026933389, 0.008092197606207004, 0.024955047261235968, 0.07313855684229306, 0.02007947798951396, 0.07005931743021522, 0.009809628262051513, 0.06407549351985965, 0.029222874769142697, 0.025983685993456414, 0.04083497024008206, 0.06053236685693264, 0.06370931531169585, 0.03692451185945954, 0.02186619470428143, 0.05662193561771086, 0.06543108435081584, 0.03691727867616074, 0.008876577302414392, 0.02587843164136367, 0.03350351810721414, 0.03920743953702705, 0.012529327234785472, 0.025167333727170314, 0.07599535211920738, 0.016600450833461115, 0.06366053542920522, 0.039876956825277636, 0.04869954055175185, 0.02482976594806782, 0.07679976216916527, 0.005297916608729533, 0.024502800278631703, 0.023158912480409657, 0.029626484361610243, 0.0834899071071829, 0.05952578729816845, 0.015947287935497503, 0.03481951981250729, 0.03456784099606531, 0.05263799189456871, 0.03668970481625625, 0.10129497812262603, 0.005782569999740059, 0.029132524438734566, 0.029625052652720894, 0.1375953531158822, 0.04179220673229013, 0.029178498578923087, 0.02455240797384509, 0.02553585627382355, 0.01762578170746565, 0.043758458723979335, 0.03982528638360756, 0.058197215731654844, 0.05256783476631556, 0.034250368031540086, 0.017686897356595312, 0.017443296499550343, 0.024575157556682825, 0.04480998444237879, 0.02353708549136562, 0.049537361666027985, 0.03070631856098771, 0.038900249770709446, 0.04210326414821403, 0.07594665366091899, 0.009119532703022872, 0.029734503743903976, 0.024068612505548766, 0.02205563659247543, 0.021070968625800948, 0.016930249386600087, 0.03185227260525737, 0.042192674707621336, 0.04151897085830569, 0.02882743134562458, 0.03864332587857332, 0.026294007198885083, 0.03755501677681293, 0.0034357262317956027, 0.01910168697525348, 0.04898604178535087, 0.02463669729019914, 0.04121428827888199, 0.048909160375062904, 0.0379173985815474, 0.030928681271948984, 0.03660828400669353, 0.043519672072891674, 0.07078176044992038, 0.0992116652695196, 0.1256423887929746, 0.19360905672822679, 0.1089844015826072, 0.20009290666452476, 0.11601119488477707, 0.17351946687059744, 0.08476483369512217, 0.09800306547965322, 0.05248831385480506, 0.16909070951598032, 0.16427355871668883, 0.0979951944734369, 0.07315062119492463, 0.13037039366151604, 0.08658299541899137, 0.13355702481099538, 0.1990838572382927, 0.2768268170101302, 0.12975180042641504, 0.11203500681689807, 0.06167316742773567, 0.13597475364804268, 0.10987656656652689, 0.12296784802206925, 0.1044332840080772, 0.15118985649730476, 0.15931284347815172, 0.17838239164224692, 0.14926091714629106, 0.13655027348015988, 0.15844985550003393, 0.19612564811749117, 0.1307786681822368, 0.08562077169439622, 0.16038201110703604, 0.057842803320714405, 0.1071811540584479, 0.19491094829780714, 0.20162217531885418, 0.1142750544739621, 0.05267620698681899, 0.06833247294915573, 0.19987988738077028, 0.08815757664186613, 0.15241626783141068, 0.08405716238277298, 0.12209667691162654, 0.19992716770086968, 0.15793978715581553, 0.14280424932284014, 0.06166696561766522, 0.17225851810404233, 0.28303028270602226, 0.1609419517751251, 0.07282901595213584, 0.13655282477183, 0.18170863815716334, 0.16556664290172712, 0.14308919331857137, 0.15457205500985893, 0.10939881684524672, 0.12231648154556751, 0.09049241564103536, 0.1544047011328595, 0.08797925085361515, 0.14562901774687426, 0.19092531502246857, 0.12996942017759594, 0.11492566099124295, 0.14811222521322115, 0.13098022022417613, 0.14254514394061907, 0.12396035476454667, 0.10399880446493626, 0.21244442888668605, 0.1394414569118193, 0.09964889966483627, 0.10640259619270052, 0.10275137211595263, 0.16639213503471442, 0.19517692045441695, 0.1322115170104163, 0.09655825407909495, 0.15471969065921648, 0.13255187017577036, 0.23286974430084229, 0.14031227518405232, 0.19813720589237555, 0.07033198672745909, 0.13456403863217148, 0.11999940659318652, 0.1794039803956236, 0.09513814813856568, 0.12922723857419832, 0.12465586672936167, 0.18046069012156554, 0.12861494214407035, 0.06972391078514711, 0.1439255148704563, 0.06885210863713707, 0.18699095185313905, 0.11042964046022721, 0.12194490219865527, 0.09097165135400635, 0.09705988144768135, 0.1259961226688964, 0.09314788957791668, 0.09047328773885965, 0.15689375757106713, 0.0649315807968378, 0.2645217744367463, 0.11587580000715596, 0.1279570481606892, 0.12334332215998854, 0.1138882895133325, 0.13476675775434288, 0.05257522401266864, 0.1608851176819631, 0.08946923911571503, 0.21501549306724752, 0.08488589791314942, 0.1614266971924475, 0.19362824569855416, 0.16555632916944368, 0.11815749614366464, 0.13042193518153258, 0.25216798590762274, 0.10606888588517904, 0.08764239214360714, 0.09238850032644612, 0.15645011780517443, 0.10746582664017167, 0.13349188544920512, 0.15714193853948796, 0.0613634501184736, 0.1740978636911937, 0.17181761961962494, 0.17225277769778455, 0.14271337991314276, 0.18661398493817874, 0.09646817855536938, 0.11309238829250846, 0.13873489839690073, 0.10176784239177193, 0.1749644207635096, 0.056455168673502545, 0.12298553064465523, 0.18514593371323176, 0.10160945874771901, 0.1618153756218297, 0.09513362909534148, 0.14636161843580858, 0.13388787848608835, 0.13621625783188002, 0.09281420641179595, 0.10484657290258578, 0.0656739863167916, 0.11648968420922756, 0.1392881351390055, 0.14451027634952748, 0.09956189111939498, 0.11445209783102785, 0.11232947744429111, 0.10355268804622547, 0.20459400942283018, 0.15538499424500124, 0.14237203608666146, 0.1373163123748132, 0.10726316180080175, 0.135170133252229, 0.15408459545246192, 0.08061154120202575, 0.10653305133538586, 0.13219554429607733], [0.018415715212800672, 0.010894392018339463, 0.027411400007882288, 0.004280251060013792, 0.06554113594549042, 0.057817677168973854, 0.02232890130419816, 0.06673754924642188, 0.04835258184799126, 0.004148018155579588, 0.016189402800851634, 0.01927110190237207, 0.027869294098179256, 0.04701437169153776, 0.03168154640921524, 0.05425806549776878, 0.04434396319889596, 0.039556247248713455, 0.04357566138995545, 0.04842128351862941, 0.0223374678088086, 0.020906003192067146, 0.0180914399347135, 0.021740063526002423, 0.02456454696532871, 0.04887054833982672, 0.03197680752990501, 0.026221914549491236, 0.0423915974263634, 0.013884185247921517, 0.020036365570766584, 0.018216307341520275, 0.04202623685289707, 0.03432524097817285, 0.023176126913832765, 0.021950048061886003, 0.01994518912397325, 0.020157253369688988, 0.013951987011491187, 0.03544971938910229, 0.025025223049202135, 0.05717214609363249, 0.05056483671069145, 0.06302615946957044, 0.04361601047483938, 0.04277010800849114, 0.05229004592235599, 0.012131339304947426, 0.03534481108986905, 0.02036283421330154, 0.020042655590389456, 0.054148994386196136, 0.004704009325775717, 0.11174014263919421, 0.026112024106883576, 0.0356928961617606, 0.10169214502509151, 0.016700093700949634, 0.046578684356063604, 0.03228364445801292, 0.026255327310147028, 0.0523735769758267, 0.009990453603677452, 0.07122765973742519, 0.022078472688528042, 0.01504939781235797, 0.005283783572459859, 0.0078675160018195, 0.05983508391571896, 0.014844636299780436, 0.025622574745544364, 0.013287588421787535, 0.02805445951941822, 0.01111761901328074, 0.03364176283191357, 0.076361523542021, 0.022845972129809003, 0.03031841366152678, 0.021781779858948927, 0.053250013518014123, 0.053953308279493024, 0.026664811319538524, 0.03205684073535459, 0.02351026639475354, 0.021349734560187374, 0.05508101312443614, 0.05348420309435044, 0.030443036795726845, 0.04226390392120395, 0.04883779545447656, 0.06397707880075489, 0.03395582615797009, 0.03251512667962483, 0.04226090818909662, 0.030474714203072444, 0.029041044347520386, 0.05501438777095505, 0.02992850708376084, 0.00607669457427359, 0.0879557328298688, 0.027563340961933136, 0.05417623417451978, 0.0465330494833844, 0.010943003963412983, 0.01866429142786988, 0.06144879625311919, 0.016445454775488803, 0.06041854939290455, 0.01643133276541318, 0.02423501473718456, 0.04802731930145195, 0.031708599600408754, 0.07402382791042328, 0.02615026803687215, 0.006691973165808511, 0.024529305552797656, 0.06310833006032876, 0.044837475288659334, 0.045456747058779, 0.023489886595468436, 0.03996640809678605, 0.025733208183997443, 0.0018190614188954765, 0.005537062883377075, 0.03870726762605565, 0.10794530662574939, 0.014843224946941649, 0.0450988503705178, 0.04926297567518694, 0.03596371305840356, 0.002118598370413695, 0.03276579447888902, 0.0750316424029214, 0.05740909730749471, 0.04443200651024069, 0.042053225583263805, 0.03243122582456895, 0.02178985781834594, 0.03561924457816141, 0.053546702954918146, 0.021245024732447097, 0.030870177982641116, 0.013362740415946713, 0.06615315417626075, 0.07601609493472747, 0.0012440048989706806, 0.09648202745509998, 0.06372417522860424, 0.022849303736750568, 0.0723374444725258, 0.01995279041251966, 0.07677396426775626, 0.040047245366232734, 0.05026326521432825, 0.033512332277106385, 0.02351276679629726, 0.012477299714061831, 0.01067869336943009, 0.026336824454899346, 0.04271813561873777, 0.03050265966781548, 0.036295384368194, 0.0751159368082881, 0.05037651610161577, 0.061142838027860434, 0.04290633409151009, 0.07888366534773793, 0.04058186650010092, 0.040576913194464784, 0.06257903203368187, 0.03722908587328025, 0.02075670343557639, 0.028512055054306984, 0.023548091329368095, 0.02590754927535142, 0.039831993702266894, 0.013404048779713256, 0.026242292652438794, 0.059556647070816586, 0.042564691709620614, 0.04406989611951368, 0.06226717733911105, 0.08805955547307219, 0.0542960566734629, 0.03548171231523156, 0.024385839501129727, 0.02411637967452407, 0.05757031722792557, 0.03590775766809072, 0.025625331294057623, 0.017966726894623468, 0.0647698791165437, 0.032050574464457374, 0.02397299843973347, 0.01833917646269713, 0.023142179806849787, 0.014981067639642527, 0.03945007348167045, 0.009799139807000756, 0.015146999985777905, 0.026099869848362038, 0.013167846498877873, 0.027036770646061217, 0.0726659707725048, 0.06422009611768381, 0.03546612297317811, 0.05688050834994231, 0.034143525907503705, 0.03159202728420496, 0.029568381407963376, 0.05229128424876502, 0.025814345705189874, 0.03699849592521787, 0.04452536614345653, 0.03446754673495889, 0.03142119591523494, 0.050562265062970776, 0.065399179634239, 0.015211676247417927, 0.04809372413105198, 0.005486503966884422, 0.07883463440729038, 0.020145638546507274, 0.047204039192625454, 0.0725685263584767, 0.04727583159027355, 0.07196211282696043, 0.05011132086760231, 0.05582851104970489, 0.05205883850742664, 0.03620890508006726, 0.0651985164731741, 0.0804845533732857, 0.012885622580402663, 0.03658313749890242, 0.03473564949152725, 0.05309772990377886, 0.028456784984362975, 0.03391214546614459, 0.014349268416741064, 0.017943537960361158, 0.053265127885554514, 0.0791545704539333, 0.08386633119412831, 0.04620593792891928, 0.039084539881774356, 0.02640496294147202, 0.0229788377681481, 0.07212647436452763, 0.011467603983224502, 0.041765577625483274, 0.02885847432272775, 0.06572487644319024, 0.04026620522407549, 0.03518843251679625, 0.03917765184970839, 0.012807306068550264, 0.026091291469388773, 0.004250351838501436, 0.031903539318591356, 0.049884337333164046, 0.04365406950403537, 0.03515389169167195, 0.01697379437142185, 0.03872558128620897, 0.03661385138652154, 0.03757849408845816, 0.05241559525685651, 0.011112206000169473, 0.09370014922959463, 0.07100508668060813, 0.027784767294568673, 0.07481207525623695, 0.04601744090073875, 0.01063981925004295, 0.01725885202176869, 0.0197936010081321, 0.061173243182046075, 0.049485714973083565, 0.05072499472381813, 0.03780842925022755, 0.02399471156033022, 0.016121070931798646, 0.026979546395263503, 0.0588225671755416, 0.06475999286132199, 0.049368884813572676, 0.03601409089086311, 0.06277690641582012, 0.05260365462995001, 0.046836812647857835, 0.042908797173627784, 0.007831691897341182, 0.00805221832290824, 0.030827891680278947, 0.011244866381665426, 0.02084830735943147, 0.028216588676774075, 0.062012801345969946, 0.01670374591568751, 0.051209166779049804, 0.03105034938614283, 0.04797364039612668, 0.07002467821751322, 0.027878035325556993, 0.051799427784447155, 0.028356058157182167, 0.008330954571387597, 0.004988968588544854, 0.053461095584290366, 0.0694337420697723, 0.04206845530175737, 0.03278646944090724, 0.03562052361667156, 0.07959147915244102, 0.021669899612399082, 0.009818642599774259, 0.018994137478460158, 0.025283064659950987, 0.08490590112549917, 0.0022553401400468177, 0.0177460927516222, 0.07212154820029225, 0.02513019411292459, 0.006655393342953175, 0.011994732394149261, 0.03292760133211102, 0.0275481960603169, 0.013873611127824655, 0.021912855861176337, 0.04202455408605082, 0.058843452483415604, 0.0544315058338855, 0.029698890833450214, 0.04099109436252287, 0.023299012998385087, 0.06293118492301021, 0.04558281547256878, 0.011194804067989545, 0.05135062097438744, 0.03321517804371459, 0.03302042152998703, 0.046366635377385786, 0.041623828267412524, 0.050245592769767554, 0.029022591587688242, 0.09323575986283165, 0.03357785840385726, 0.05859261844307184, 0.035612466013325114, 0.016718081664294004, 0.019742203676807027, 0.14641725830733776, 0.11300985807819025, 0.11567643284797668, 0.09913193740482841, 0.15430864771561964, 0.13250382989645004, 0.12981661409139633, 0.17597333448273794, 0.15530747840447084, 0.08276922827852623, 0.1025081037410668, 0.08778475557586976, 0.21413099552903855, 0.1656966773527009, 0.10018689651042223, 0.16514413271631512, 0.1096843375957438, 0.21989327775580542, 0.11143419119928565, 0.1551764125802687, 0.1194333183978285, 0.10405278871101992, 0.10917779084827219, 0.1300157912607704, 0.18125524105770247, 0.22878721622484072, 0.09234318775790078, 0.16502700400139603, 0.14881446824542113, 0.10432400594332389, 0.11047016935689108, 0.0836129119353635, 0.17575973165886744, 0.09848453357283558, 0.17416919129235403, 0.12700012379458972, 0.11124846259398119, 0.1438075312014137, 0.11072758518691574, 0.11341002410543816, 0.2135117237589189, 0.1504489505397422, 0.13453005759843759, 0.12730037554034165, 0.12973898968526296, 0.1504165165658508, 0.14416594696896418, 0.07544257678091526, 0.1489025013787406, 0.0859761747664639, 0.17579186707735062, 0.17204619092600687, 0.1592715342662164, 0.13902246153780393, 0.21075380460492202, 0.10205796360969543, 0.2183244369391884, 0.0997303102963737, 0.12557925789483956, 0.09672338236123323, 0.10224449288632188, 0.1625253946653434, 0.1355357686323779, 0.10087853404028074, 0.11151345766016416, 0.1567297556570598, 0.09815857213522707, 0.12733986627842697, 0.13432132665600094, 0.13942694983312062, 0.10950212380183594, 0.12447334080934525, 0.1512064127517598, 0.08363362760948283, 0.11064156730260168, 0.14234359189867973, 0.12908474622028215, 0.09730846953711339, 0.11822543106973171, 0.14404949678906373, 0.10909942683896848, 0.13995946411575588, 0.09041588367628199, 0.11112741194665432, 0.1681766685630594, 0.15609513542481832, 0.1213239205202886, 0.11586393921502999, 0.14111321792006493, 0.12052955957395689, 0.18319536266582354, 0.09734124277851411, 0.13532452711037227, 0.17460747063159943, 0.13413004763424397, 0.10324375783758503, 0.11727641842194966, 0.17390997734452995, 0.12585300606276306, 0.13582806794771127, 0.1325754831944193, 0.14799924913261617, 0.09363547127161707, 0.15340291203132697, 0.24198626939739498, 0.10248839908412524, 0.20736270371292317, 0.113034081778356, 0.0832490339609129, 0.17245765456131526, 0.20343679508992604, 0.16504476804818424, 0.11268535549087183, 0.17136871442198753, 0.09110114297696523, 0.13094427143888815, 0.19745046060000146, 0.14276266869689735, 0.15018938375370844, 0.10017240978777409, 0.1416041108646563, 0.155489339360169, 0.10545546308692012, 0.16365022930715764, 0.1818499770015478, 0.15145699573414667, 0.14371192561728613, 0.13135303450482233, 0.12209766757275377, 0.0971175433535661, 0.09338158382368938, 0.15732974346194947, 0.09110116333301578, 0.1870630258428199, 0.10805425899369375, 0.1633840264486415, 0.12203784792550973, 0.16925951545791967, 0.14038776899022715, 0.15181988983282022, 0.10934254593615021, 0.1388641321765525, 0.11586239215518747, 0.15651627496949264, 0.11968346711780344, 0.15539810354156153, 0.25559304069195476, 0.13122001449976647, 0.09496736765972205, 0.17940159195235797, 0.23642214653747423, 0.1373960402395044, 0.11375939500119005, 0.13210551626980305, 0.11083473265171051, 0.1005923008280141, 0.16583204508892127, 0.11038259762738432, 0.11799953319132328, 0.2129521087876388, 0.11156364889549357, 0.115767044414367, 0.15427679728184426, 0.18817264772951603, 0.14992270592067922, 0.151731938123703, 0.164815056802971, 0.1862517422331231, 0.18202038428613118, 0.10671475622802973, 0.16144037645842346, 0.11685572671038763, 0.09571834307696138, 0.10451613313385419, 0.10610047847564731, 0.08475108657564435], [0.034649794455617666, 0.07265731266566686, 0.02396177377418748, 0.03952099735449467, 0.018795289398570145, 0.047301208799971003, 0.02672393207571336, 0.03696069473932896, 0.03862710210627743, 0.033947680345071216, 0.05573610136551516, 0.07747427347515311, 0.00736981480648475, 0.012902175442182591, 0.06594840623438358, 0.04556118038349918, 0.06501738833529608, 0.02778762562333473, 0.05848253970699651, 0.01013737594309662, 0.024075309646182826, 0.015625516451629143, 0.044889223761856556, 0.04844632146081754, 0.06576024847371237, 0.02270679611579648, 0.026040123143632497, 0.006363116080007915, 0.04250773208748017, 0.030110958364925215, 0.014720951240243656, 0.011684707199622477, 0.03185857280290552, 0.05721797434879201, 0.0906339648312756, 0.09370550287089177, 0.029431032349488566, 0.03417693018647177, 0.02619520910749478, 0.024271182350016067, 0.008042618748731911, 0.08800985956830637, 0.033702963297920566, 0.06018234456756285, 0.03758101145337735, 0.07271053016717945, 0.06396209674754313, 0.03407945523836783, 0.05344578104891947, 0.04331225748839123, 0.05312562447839549, 0.030630037654191256, 0.019983334666384116, 0.09942950215190649, 0.047358694286750894, 0.028364103886165788, 0.06515768902110201, 0.05391313561371394, 0.07294860096382243, 0.04661599699673908, 0.0447302565776876, 0.025281098604734455, 0.0326954711095563, 0.05283280947644796, 0.04075079457834363, 0.05527301139331289, 0.059859592600592544, 0.011400049036767865, 0.021323080008317317, 0.008833999229994203, 0.029003996335502182, 0.042932837669338496, 0.02616182348823973, 0.030459833930113485, 0.050140009328190766, 0.018025048675813844, 0.027185178129002452, 0.011473050923086703, 0.039295822115881104, 0.014341322771672691, 0.023015230993873308, 0.023927044655595506, 0.05387591796794108, 0.03339275065809488, 0.064961605971413, 0.04674992284604481, 0.07462372072041035, 0.09703662805259228, 0.021122223464772105, 0.03895028155030949, 0.04632948897778988, 0.007715969446248242, 0.01457477783385132, 0.028908740196909224, 0.06094653106161526, 0.02225781458296946, 0.014603015068652374, 0.053450564720800946, 0.038309561288250346, 0.053235387695687156, 0.031276942762945376, 0.023896666642810618, 0.05190119785921914, 0.07151801844260522, 0.03892134203176413, 0.028105107069547688, 0.016125303293977464, 0.04089038958773017, 0.030538981647363732, 0.01989709965086409, 0.06529195753059217, 0.057031512925667424, 0.057869781873055866, 0.02301111228631011, 0.04051529882209642, 0.03631665983370372, 0.038652577703552585, 0.013123661994801035, 0.01920118395771299, 0.07316320123417036, 0.025437843586717333, 0.01471373502032033, 0.004807622895376491, 0.029684343042650392, 0.032526312329407246, 0.01093023647886834, 0.0330204859908138, 0.039240260275879076, 0.019172907707148364, 0.001791711792715692, 0.0528335897917194, 0.003337909683718213, 0.018263341692675437, 0.038883842793958526, 0.03277686817039337, 0.035787436445908885, 0.015458230428131563, 0.024646200173135315, 0.06384770931409937, 0.03468975677554097, 0.012823584971816411, 0.02822944861171501, 0.040529113795076094, 0.05118855967053345, 0.06979569300476994, 0.053425360537533245, 0.06919481631900583, 0.010471689298615923, 0.005958856790260012, 0.014012230743121887, 0.02479973398814244, 0.026128174936664954, 0.009299873740279248, 0.014904801999883992, 0.031743717180298905, 0.03852015480931316, 0.01316525534327541, 0.04157090253595795, 0.019542166464296833, 0.038641242776066065, 0.06036268560481923, 0.009011195257439144, 0.011327069202837135, 0.02541385398113302, 0.06868653252188649, 0.020160069290016378, 0.016355589597619007, 0.045265128769512684, 0.05624881938898137, 0.033412302644657235, 0.035799300630709956, 0.00922941551211157, 0.03726654779165983, 0.019726921371849518, 0.04733791754447988, 0.07283558417111635, 0.05090250627004674, 0.021639060195801512, 0.03810202456744654, 0.017110799073374698, 0.07469619504575219, 0.04058238557939019, 0.0358625808065491, 0.02146856300532818, 0.010589489763203477, 0.04313950586531844, 0.04931215250066348, 0.029258596245199442, 0.018177013378590345, 0.017210151867142746, 0.06597174783902508, 0.015369471262342163, 0.09389484806784562, 0.007991771030771946, 0.009197190187738409, 0.03603545456592526, 0.027625306476173655, 0.0347709672392479, 0.049966480782521625, 0.02871294891727822, 0.0257221853826195, 0.05123217590153217, 0.01436775510332414, 0.026687716965430548, 0.06641333842916147, 0.10118686035275459, 0.09731742619935956, 0.0166386625330363, 0.025416773378050754, 0.02204816592192011, 0.053283750279141326, 0.056090965002243004, 0.07340976050389664, 0.04431740194559097, 0.03349675311307822, 0.07581654457109314, 0.06292051835251705, 0.06274984643927642, 0.04597152443602681, 0.06670332394008126, 0.008455117998112525, 0.006885065996487225, 0.023941010602616837, 0.02099260122382215, 0.0502907051704824, 0.028292228367977908, 0.016271719276638966, 0.030254153002585684, 0.0012562593474285677, 0.027261209674179554, 0.05048798244180424, 0.02644539175422064, 0.018489276890509894, 0.026588367564337592, 0.029213334566780498, 0.03531999706423708, 0.03429962628121887, 0.05003884654226048, 0.012286490577805256, 0.022543019814682857, 0.08235424983182124, 0.024763032028983747, 0.012636580720676907, 0.04798762161018593, 0.015433519879089934, 0.023512006837076375, 0.025581650602232133, 0.0348894462388541, 0.01925180267010416, 0.04296770079859665, 0.043210568837821484, 0.07820857050163404, 0.02769246617598193, 0.023658811281036054, 0.023474337965516106, 0.019324064953252673, 0.012517530903486269, 0.027010414649599364, 0.03049463259854487, 0.012268478865735233, 0.006023743397755814, 0.024394366989976594, 0.06826254313013383, 0.061836911498435905, 0.0438779589187886, 0.02650882290410144, 0.022291122170697366, 0.03602866921573877, 0.03208906436339021, 0.03313340778861727, 0.010634361283986695, 0.04523784487641283, 0.04410340217873454, 0.025159673066809773, 0.045205343049019575, 0.01649861629786236, 0.04404920419412, 0.06301906877862555, 0.021172530051054697, 0.017541987721675208, 0.012311475085360664, 0.05498073921938028, 0.061507604883185456, 0.03368199995851942, 0.050283119148973904, 0.005977419812032687, 0.07135885448328086, 0.06680766905524901, 0.031068992135780196, 0.0338791075960866, 0.054387719969132116, 0.017300380061247518, 0.012852679705247283, 0.015335739590227604, 0.04693813488951751, 0.014567134136866246, 0.026243503837447082, 0.01235184452629515, 0.08833157337669816, 0.05847269416387592, 0.028274103001292263, 0.04754764593339392, 0.014603069351453866, 0.030929448016520058, 0.09833389879869563, 0.018940641777589917, 0.05139444076589175, 0.07567813021263906, 0.017614004035879458, 0.03385705520798053, 0.02031077361399574, 0.0819755322965128, 0.006016400376600879, 0.10047022559280906, 0.015105592386264886, 0.011608693465989615, 0.020472626268331493, 0.09800879231521062, 0.04019082337617874, 0.02095544634253851, 0.05928057831312929, 0.06036002574754613, 0.03939761933205383, 0.029872734897903035, 0.019902573732127036, 0.056683197151869535, 0.0296884549648634, 0.01676132300469492, 0.024135992729238102, 0.02544745842793158, 0.009232711495964654, 0.04006368966240968, 0.03009897204382079, 0.05495861219242215, 0.035477522361491404, 0.02048516389913857, 0.03563710701252733, 0.028763414959290197, 0.030006742171411003, 0.0060995260053979495, 0.04020564936633621, 0.02499128781658198, 0.0244488329959235, 0.02265647765515106, 0.0760384119514908, 0.04862518668440836, 0.022400337470961467, 0.05687134134184037, 0.022051029339698807, 0.015945605168651258, 0.048392612021416426, 0.07054310611316136, 0.10002943567399468, 0.15645583107003144, 0.12313845886715821, 0.08158403794680323, 0.09108002696718488, 0.09709306181009326, 0.14192383656544344, 0.13896722878728593, 0.10587831932519164, 0.128855292818376, 0.18870254286697932, 0.10378209395068032, 0.09831712541303464, 0.12332017054515225, 0.20317584409245423, 0.09566326638949768, 0.2487341644508498, 0.11209338796990258, 0.131209917898689, 0.10839080557759319, 0.11162549057709319, 0.1383824808789151, 0.13431418846760476, 0.1104036932811141, 0.20616688073745795, 0.15617277340165206, 0.09757581911981106, 0.10559281214539494, 0.15325442142784595, 0.187100033142737, 0.15054227624620709, 0.11012102916304554, 0.0901728460033025, 0.07573183625936508, 0.16229007872087614, 0.28451573156884735, 0.14886025578847953, 0.15314243600836822, 0.04898956338209765, 0.238883410181318, 0.146992561008249, 0.20145723702652113, 0.125907071733049, 0.14050564409366675, 0.10159867682627269, 0.18581433141870157, 0.12365170275526387, 0.10724393211837326, 0.14638911267476423, 0.10031401326081582, 0.17380321664469583, 0.10063945901181016, 0.2725101672112942, 0.27245971134730745, 0.14330325754625456, 0.05608522120331015, 0.14743651290025028, 0.08494857419282198, 0.10475988326860325, 0.08090034606201307, 0.05585948956598129, 0.14185881933995656, 0.14986159705689975, 0.1452122208263193, 0.12410412276429789, 0.10263410090867962, 0.16310181016368525, 0.1512795995388712, 0.1003632206203682, 0.17014037604842866, 0.06673520151525736, 0.16351423731872014, 0.14854494056531362, 0.14107123017311096, 0.10562012996524572, 0.12217348707573754, 0.06335895375481673, 0.09466594883373805, 0.11339597843055214, 0.09386727240468774, 0.08409704667116914, 0.10022007008748395, 0.0948588088420885, 0.10789513574647051, 0.131236625037023, 0.11320885204310928, 0.1670738455972501, 0.16386012732982635, 0.1452068468289716, 0.13081924457635197, 0.1067771203815937, 0.1254060279045786, 0.1676616333425045, 0.10479104159665958, 0.11425621834184442, 0.09765268356672355, 0.12478172140462057, 0.20885029674640723, 0.0725791182901178, 0.15408494829067163, 0.13071469590067863, 0.14057747381074087, 0.1042975362922464, 0.175688946885722, 0.12436488377196447, 0.09097952236022268, 0.129389544150659, 0.11703583704573767, 0.1462972526039396, 0.05996701826474496, 0.1824068778327533, 0.08835587850106613, 0.13887283099549158, 0.07400228442358119, 0.13720214207257542, 0.11034860980830022, 0.09766189807227679, 0.08881354358579431, 0.1283272432961634, 0.15469648476157868, 0.08723291661590338, 0.13891883566975594, 0.13954105228185654, 0.13124688448650496, 0.09575296193361282, 0.10638176516762801, 0.14122711680829525, 0.09674853565437452, 0.2730792138193335, 0.0982316503567355, 0.14162901309984072, 0.10267153568565845, 0.10562899841793946, 0.13708334416151047, 0.05141550927822079, 0.11550717907292501, 0.08017366898379155, 0.09531012962439231, 0.11642419200922761, 0.039795929566025734, 0.08125165078256812, 0.14525686843054636, 0.1958141734025308, 0.14329578009034905, 0.11247760163886206, 0.10370922607502767, 0.1567222646304539, 0.12876215710171632, 0.06236716625945909, 0.18263985961675644, 0.08977084114615407, 0.0927404835820198, 0.11657796161515371, 0.0961205107825143, 0.148820357929383, 0.10634780448994466, 0.09334502435688462, 0.13056592031248979, 0.09099485725164413, 0.09836602064647845, 0.10829826018639974, 0.0871082968743784, 0.16325035504996777, 0.07045746820845775, 0.11340836847999267, 0.12281732181353228, 0.09157765776451145, 0.2046900221279689, 0.20868980964379652, 0.1320950532598155, 0.10195298745696034, 0.11152854827897889, 0.16881089524499007, 0.06604728235730103, 0.12489819872592177, 0.20237568845706327], [0.0021263088606896675, 0.03151506784238985, 0.04084290231445006, 0.07661480709378209, 0.0349341786599585, 0.006185132951941341, 0.04808942221903375, 0.02499927078107638, 0.039866965397128036, 0.05284642428159714, 0.006334828379164849, 0.007534851486395512, 0.036619032001388926, 0.04056072334891983, 0.016467483414869224, 0.05656966467254928, 0.058244156784244945, 0.04646276004080262, 0.04991693415545991, 0.06403114447104079, 0.0381808601585882, 0.026815459664378847, 0.0016088294297722833, 0.04040457887042846, 0.06088137812912464, 0.026081863225304654, 0.048714488678212674, 0.006392327860729503, 0.021303360084337846, 0.04254843740324889, 0.09850195156676428, 0.053081234717475514, 0.01918592200880604, 0.019915194483473897, 0.022607319489387528, 0.07438923937401601, 0.04863564630172082, 0.018234285126839365, 0.02302544633857906, 0.1292942642633404, 0.030128987040370703, 0.012636310154838222, 0.0687359773686954, 0.009767685468042535, 0.11981373227068357, 0.04613506494622145, 0.04206640951867614, 0.019447880630780543, 0.058155648676412444, 0.020211273238861134, 0.062248700830553255, 0.03887413974319186, 0.03991210154656853, 0.034958392182098966, 0.05842447068010058, 0.06034595971660955, 0.018672155648736016, 0.010750719013490846, 0.02726035811273115, 0.10520011000335217, 0.05371766324554171, 0.03498455988509314, 0.04242340375536254, 0.04798591170193894, 0.052166901994496584, 0.06644357394959245, 0.038116514682769775, 0.025528860577781285, 0.10372071367289339, 0.03449890183817063, 0.03578432536284838, 0.021311975782737136, 0.08585932425090245, 0.014822814613580704, 0.003897871556026595, 0.03153165463092072, 0.02685593767091632, 0.04620780050754547, 0.03560409289119499, 0.031369661180568595, 0.018681795935013464, 0.06507564735199724, 0.022666667554793612, 0.012277270135070597, 0.01230542509750064, 0.06091734727046319, 0.06237260132495846, 0.06215481872537306, 0.005489647704442697, 0.07699336856603622, 0.06809168122708797, 0.06399685809654848, 0.03077065385878086, 0.040989085898867676, 0.013650926112729524, 0.018802688822948506, 0.03066851058974862, 0.03980753251484462, 0.017629988624581268, 0.023415076413324902, 0.014998986053147485, 0.01692188813883279, 0.01039641092730952, 0.02940486464649439, 0.05172015453821846, 0.022410841193050146, 0.014636212394439747, 0.03371652042759316, 0.06625207779662949, 0.011777869209514132, 0.038732495558048995, 0.015909289974453192, 0.016034995372008, 0.03275687513606889, 0.024971917338137115, 0.022227032841848474, 0.0421597589738667, 0.0690562187560967, 0.02251766126469842, 0.0273477619048208, 0.035646925414247174, 0.027698260865041187, 0.01888129031950874, 0.044976656391684494, 0.0368209097401372, 0.02334944172097104, 0.07606645580381155, 0.096622294214155, 0.03357406200042792, 0.028707937936165502, 0.07190396916121244, 0.02026252298881965, 0.085887761653534, 0.026554216896849017, 0.06919261108019523, 0.010861007247253187, 0.04701366262244327, 0.06173673937363284, 0.08306371247661964, 0.011337754433043301, 0.015718072020847882, 0.07196649616318089, 0.03897211002185941, 0.012298811925575137, 0.05022424945075597, 0.02738582093401679, 0.04433554597198963, 0.05264307751453348, 0.0068557944198671195, 0.03253236825444868, 0.04000611596607736, 0.05161704096410956, 0.011032915790565312, 0.06016180531254836, 0.05248823582327791, 0.03389352985790797, 0.04392820443691952, 0.04243737139872142, 0.03532989010480898, 0.08487097692808934, 0.005809962882527283, 0.030260256425078427, 0.0732224712680493, 0.02098579382124756, 0.06124985657100167, 0.019218235542731624, 0.08298675982015473, 0.03182746197230049, 0.03182806586846709, 0.05406879833234208, 0.03906697600281664, 0.030189380049705505, 0.017874924499275427, 0.022147522108363252, 0.047965216383870156, 0.02485269364634795, 0.04392044199630618, 0.08719417226633855, 0.021404353236513476, 0.04542245050626142, 0.055418373950357945, 0.04266059924183147, 0.01454491211500551, 0.09981900160866124, 0.01924788921938411, 0.03909482307998197, 0.02449587413242885, 0.03010242578706571, 0.030050921586475203, 0.016005412941532474, 0.03178315702825785, 0.05201580920921905, 0.11181976872363261, 0.03192381394494857, 0.056818432573761256, 0.10370227109108653, 0.037538039830646346, 0.049173690644758086, 0.05541676582236375, 0.04047242897961821, 0.019385350236136998, 0.03643368676837001, 0.027567198433514153, 0.016063200376395668, 0.02280207769945264, 0.044140731782785485, 0.04728277639618941, 0.08357288515461342, 0.01796703053904431, 0.06275821277605635, 0.028304681181907654, 0.048898239353937764, 0.03430936325873647, 0.017836156400984952, 0.01730717219678419, 0.10969650372862816, 0.04124995207946215, 0.02255621732079557, 0.04429302218237093, 0.04394754947030118, 0.026913945629660572, 0.022573333366640976, 0.018247750654284443, 0.0673427414149046, 0.004199890037333327, 0.037702384404838085, 0.09569451292710644, 0.035056589769997766, 0.006759237190375903, 0.03988985238330705, 0.03569438893880163, 0.04751302368406739, 0.03102715705920543, 0.06447094372872796, 0.02036772814712354, 0.0501878901517817, 0.00605032331077382, 0.02611087229368942, 0.07257564419082232, 0.0389308958048267, 0.020624855599765266, 0.046033729133861404, 0.08434625901281834, 0.04062452938939844, 0.0695355087518692, 0.027748041586684327, 0.04371398075350693, 0.03494740330747195, 0.024165698992354528, 0.0231889614037105, 0.044157939430858405, 0.05705649658505406, 0.012511600507423282, 0.005617839508756463, 0.044695973595870395, 0.020304403866508176, 0.03739732863115413, 0.06373461788254124, 0.026615402095818093, 0.07556372242314474, 0.13816442686532224, 0.02591625657597823, 0.02160190192184278, 0.019723543963794197, 0.04325261765292712, 0.06918819381722383, 0.03770565155095287, 0.050436203434531174, 0.02421150858780103, 0.06075631733983755, 0.0632086650335363, 0.06330109507377658, 0.0617182832211256, 0.06575340205537421, 0.05188153052170362, 0.03382158478988068, 0.04635496118238994, 0.02955398289486766, 0.061976153669612746, 0.0352880618135844, 0.023552851252523915, 0.04641220239656312, 0.04045057336666754, 0.00710082020045125, 0.044355494901537895, 0.01689621407006468, 0.04881299160686987, 0.012729411944746971, 0.02288994798436761, 0.034616922826639245, 0.024847282329574227, 0.020851487992331386, 0.013091845487776612, 0.04640820582530328, 0.028454025043174624, 0.03390214725264481, 0.04929609836212226, 0.023272477190143297, 0.052685815042683055, 0.04955788056499191, 0.04043837669970734, 0.055367229373327324, 0.03521604210670505, 0.10948967946959393, 0.019914856912302117, 0.028488387752856528, 0.01876005986040192, 0.041231305937149694, 0.0760083935622658, 0.01325448100189013, 0.019997667022315518, 0.04046249522694519, 0.006330133340920189, 0.03796246009213584, 0.08040380770606653, 0.026647571441052214, 0.027482770017481277, 0.006823972399745668, 0.015035228304831045, 0.0074926194668348345, 0.0692799249663949, 0.032039147934743335, 0.04302281141281128, 0.030376815170581852, 0.05919485219887324, 0.012750924049344445, 0.05401015933603048, 0.05998127428548677, 0.053831484102244885, 0.01643857273406216, 0.01162634470633098, 0.019563324882515838, 0.062463430022554736, 0.02730129921941885, 0.08484970485525471, 0.023681688089189783, 0.027797757847500697, 0.07200671971908637, 0.029339918667184453, 0.02156435009757323, 0.07167754202548947, 0.016072896641812155, 0.013978183552223657, 0.03708811683048095, 0.01425817678682506, 0.01109692793605583, 0.03955781127193144, 0.017210523365065455, 0.033131521461265426, 0.06576827554298298, 0.049288346099534204, 0.03460383049345442, 0.1908430087247065, 0.15343084053269454, 0.07268386374094657, 0.2004150886620794, 0.2925551230353968, 0.1668696336980377, 0.10160661568599087, 0.1930936143866607, 0.21331101310040268, 0.09492155297526292, 0.12125475066048758, 0.12374044156500272, 0.15569621111665452, 0.15197033461715492, 0.12772893825811998, 0.15257515359137738, 0.22665555775165558, 0.18426276610365935, 0.15487371810844966, 0.17853670407618794, 0.12236024705427033, 0.13104932223047527, 0.16986575935568127, 0.07628459802695683, 0.14974072282867773, 0.1621196578655924, 0.08998732095850365, 0.06501740190599646, 0.07994233603988375, 0.12762144474046572, 0.23356858108724865, 0.12382018300039427, 0.12573215897594178, 0.1710542677236455, 0.13293240618492874, 0.16797859062041554, 0.2417071743735245, 0.07050838547625712, 0.10887075375233378, 0.3054033736033099, 0.12645188107022218, 0.13542657877717698, 0.2071716282516718, 0.06960471932377134, 0.17562196190868104, 0.13874371935214314, 0.10773159523627587, 0.1207845394632646, 0.1964310703000852, 0.09392440505325794, 0.21011140836136682, 0.1176522725394794, 0.08496898452618293, 0.07667961397341319, 0.09465967917016574, 0.18466638587415218, 0.05880911861147199, 0.2225761916488409, 0.11192774400115013, 0.21047464172754968, 0.19886298051902226, 0.047400000106011114, 0.17632370282496723, 0.16338193656078406, 0.09183549428624765, 0.1215936110488006, 0.23021146122898373, 0.1767914577254227, 0.18847737780639104, 0.14207315498164722, 0.12832173359181198, 0.22960091541920388, 0.14717071716274532, 0.12682621526931012, 0.1149985763643469, 0.13681475285972866, 0.0708507267492158, 0.10809024170573268, 0.06937529984861612, 0.12822954782417842, 0.0980812394991517, 0.18533574709934847, 0.10587188681321484, 0.10708400819982801, 0.2750200411038739, 0.16213116581950868, 0.10215524517531906, 0.1165257551308189, 0.11809329316020012, 0.1967444991958993, 0.12125275576753275, 0.16046681441366673, 0.05614955989377839, 0.21782503516546317, 0.12640107236802578, 0.08983176002012831, 0.1899726382855858, 0.10795060598424502, 0.06333433650434017, 0.08685877919197083, 0.12370424850710801, 0.06190701773656266, 0.10933818974133049, 0.1556949219001191, 0.11039532694433417, 0.10576004388609103, 0.0852028416203601, 0.09713559238506214, 0.11583717779389449, 0.071855196064072, 0.16847028423632893, 0.07260235811450652, 0.06148424970784357, 0.1816491170653275, 0.11919845028647355, 0.10809255551014628, 0.15650473987417562, 0.16714220121502876, 0.09694348555058241, 0.1220666720931019, 0.09745433421007224, 0.13685553281434945, 0.12823254694896086, 0.13428316584655217, 0.1878848945988076, 0.13152481243014336, 0.15801597306770937, 0.13564220363540308, 0.14474148037178175, 0.13088598528078624, 0.11388811309422765, 0.18276401795446873, 0.17123630509844848, 0.09633175230451993, 0.15383650947894367, 0.132205030215638, 0.13172648660838604, 0.1523946225643158, 0.1690501602632659, 0.08038050002817597, 0.08132088849587099, 0.13756177920315946, 0.08467886330825941, 0.07157100524221148, 0.18132703006267548, 0.12226571355547224, 0.10936510722552027, 0.1292362223778452, 0.1738712601363659, 0.20532526661242756, 0.1192289979330131, 0.1198659794671195, 0.15247239624815329, 0.17738509444253786, 0.09390882588922977, 0.15865211321839265, 0.10833721488182034, 0.08006944600492716, 0.18796000842537197, 0.1572547789130892, 0.09553245162325245, 0.20732252086911881, 0.1258252811219011, 0.14598755565072807, 0.2170200212193387, 0.07143663495246853, 0.18499476968177728, 0.12848543695041112, 0.07232083393526928, 0.1569140457681247, 0.15585443191230297, 0.12428902355687958, 0.10905728981431041, 0.12511021377784864, 0.09398970726345267, 0.15284723256315502], [0.07094259360539061, 0.007447911642624864, 0.07840271972651992, 0.02716009777837566, 0.04187221618901406, 0.04998031271887677, 0.017682347779295275, 0.005955297874087202, 0.029748932791075537, 0.008468664101591068, 0.018431297769503932, 0.0301117692142725, 0.03200823387929371, 0.021757284744775722, 0.0544437025008457, 0.03759377469707813, 0.04072348693651812, 0.01829405388395701, 0.017596401141158173, 0.01951762554900987, 0.018273755508874143, 0.05293022674907531, 0.05388525800247278, 0.06733939623726265, 0.021417815371283462, 0.05859774138246264, 0.07982075613524232, 0.004101256914769432, 0.037352623351450474, 0.01640356202343745, 0.04493776276441557, 0.03526449289971164, 0.1146912407130003, 0.04972727683239749, 0.10840407772255795, 0.04428015037306717, 0.08009659419102327, 0.018009701910029565, 0.04731180751696229, 0.007771387945727578, 0.05034380392836673, 0.005040661506687424, 0.0460952315479517, 0.03297903767919966, 0.042030759288796356, 0.019816896811659847, 0.00978793210483023, 0.02069486684298941, 0.03265820596633213, 0.05738501609968288, 0.0705005144700408, 0.020331757309447442, 0.03815379339669432, 0.052468300464430025, 0.027215746131592562, 0.05008116677137358, 0.05398315364228828, 0.03804012181769524, 0.012180025888872998, 0.021098310194377388, 0.03204721910879016, 0.019529204749103104, 0.02245016908273101, 0.03463393369955676, 0.04233391855710319, 0.02156750189273485, 0.038637687252568345, 0.02767363004386425, 0.016236011371282593, 0.00660660582694358, 0.047088505035000186, 0.030472325759806802, 0.02398700000984328, 0.050751206531588516, 0.02915654457839472, 0.02060778026602098, 0.015941774838470986, 0.03505261694746358, 0.05966998277498143, 0.020069359336048365, 0.05400592867018921, 0.019719080899709036, 0.05375792412087321, 0.05750352902604001, 0.053004699360047064, 0.016437761884714876, 0.09259327540972404, 0.01631227701104113, 0.008835061137298388, 0.03558469696768692, 0.009591823610078012, 0.051843447743781974, 0.044791436687644036, 0.041756132418023686, 0.023926534057993974, 0.009566744107619991, 0.05604952686865415, 0.03754092699715069, 0.015216085028701594, 0.015293256512710025, 0.04152595637632268, 0.01820840240855302, 0.057589981172766, 0.02932500446747456, 0.02975146033402, 0.041359362458544116, 0.05133943193192993, 0.06628216403935637, 0.0645802082227809, 0.04044174562607493, 0.00873595176796828, 0.022213389198961, 0.032365930399724414, 0.04813189172585096, 0.12380491596247468, 0.028618846288216964, 0.040918423262025626, 0.05190188317958798, 0.048356354502694945, 0.03511541536343949, 0.08508240165455, 0.0316457740430321, 0.07301500918609755, 0.08433899190276861, 0.015173072693869472, 0.024054556652637463, 0.054146931639739444, 0.037197035271674395, 0.05751163073416267, 0.05160723613309009, 0.039070663840643, 0.061559628163065226, 0.07316907734743186, 0.007812189952736455, 0.05440252560323902, 0.06386258280170815, 0.023212043468707373, 0.013623305496626666, 0.04203190601297787, 0.04020127960081611, 0.04121485824829765, 0.002973804187994184, 0.018097692634910345, 0.033610770744936805, 0.01674139782387231, 0.012909350101836026, 0.035048074155513725, 0.03654051532170602, 0.08263544831424952, 0.0673765731709344, 0.0027630191928307924, 0.004502994598754282, 0.027098030483882343, 0.021461436691294824, 0.060103037394583225, 0.03098875197714993, 0.06162784807384014, 0.035147652562175474, 0.011868876022552806, 0.03720470950273531, 0.042099657734589915, 0.04025764889749033, 0.06344986387661525, 0.01325154718610325, 0.02561340943377997, 0.017459181004336903, 0.04692437080666423, 0.012785270643819655, 0.019768501997792294, 0.03548063344455191, 0.03141477018860834, 0.04355332740981664, 0.04316783130967191, 0.021280381495931318, 0.031603542023471425, 0.017509745433926582, 0.0687843637008752, 0.04505069813291941, 0.04262178025341459, 0.047830764669924974, 0.014598928591502565, 0.04632458316960505, 0.007803846516513399, 0.041807205748877356, 0.03265326623139637, 0.01223089565922107, 0.018629443565649644, 0.05650432853560362, 0.0697546484214919, 0.02439999713429383, 0.033995791870568476, 0.029481271082269292, 0.06394980169300522, 0.015187247290409036, 0.04326807128797684, 0.026254019433898584, 0.003154639495603208, 0.039257301682872434, 0.03636708177093949, 0.037590826462422094, 0.01403530263009348, 0.023365115879901817, 0.026108848562996303, 0.035056776367127895, 0.03920900356024504, 0.02665935759432614, 0.02658999604838235, 0.03860112100041338, 0.008696768915147653, 0.03315189108252525, 0.043633584531822374, 0.020474738208577037, 0.0686992754095367, 0.0476435466802546, 0.039171789307147264, 0.05479474598541856, 0.02666853478045336, 0.017008291091769934, 0.07926092403275625, 0.0019571784941945225, 0.06399236619472504, 0.02278389296095286, 0.014624560251832008, 0.0437848842702806, 0.03438954913456525, 0.04794601384284241, 0.020907263570864285, 0.010170004995805877, 0.06981712114065886, 0.01042608156733747, 0.0277054584252515, 0.022745633763926368, 0.06056524866393634, 0.019332938494959047, 0.016325252296935235, 0.032743450320724926, 0.021123030921444297, 0.04300925089046359, 0.019983027629288178, 0.012559816357679665, 0.03461763189573373, 0.04440044445384826, 0.02479140836346362, 0.03326966440571206, 0.018096383062324355, 0.02472360066271254, 0.008864071053851928, 0.028063994632767778, 0.027046746807172894, 0.0279732168252979, 0.012785793115784014, 0.031083960618291582, 0.030738325057817355, 0.08201166428625584, 0.02826234738209418, 0.010745574869880719, 0.0338964814852391, 0.07650065714759485, 0.03054986534906285, 0.07897414120712451, 0.03555523497717721, 0.062233881625745974, 0.01275361783336848, 0.02841436636767217, 0.002811784020325701, 0.035469430831394026, 0.015670377794387083, 0.037298615356641154, 0.04691251340721335, 0.06535257784915821, 0.04245453154934304, 0.030354386195540428, 0.025057592562266758, 0.07284763495304755, 0.06667579577437469, 0.04018189724800842, 0.022267346303643923, 0.05473128939047456, 0.01859291293658316, 0.006372862387382026, 0.045268738575811894, 0.04341602584879313, 0.058523346803018024, 0.03283513057976961, 0.012477324310956257, 0.019978796963446906, 0.05456510598638228, 0.013295311846637299, 0.015015801847247141, 0.029845223695571934, 0.02529696105713291, 0.013224396455500807, 0.0709896432235837, 0.04821171797811985, 0.0119580261941467, 0.05560648760625294, 0.04321340850687452, 0.028347121850986565, 0.03128260853035109, 0.03120400703379086, 0.045526252793414254, 0.006981659697235695, 0.08426940813660622, 0.019213127870378748, 0.029748254256056886, 0.041268903562533, 0.06216254045388528, 0.05393668756421123, 0.02546454393970115, 0.024404151464945505, 0.04005879742492523, 0.04152203444391489, 0.03189046734145709, 0.04766600958204695, 0.0563933914527297, 0.04133398185617157, 0.01674176423278238, 0.02327907085418701, 0.08422881138644048, 0.02247506962157786, 0.05483704246580601, 0.01179031269358737, 0.03715231302859528, 0.015183416960228766, 0.07320760456579072, 0.013145996823108621, 0.010953355863291239, 0.06749318619923932, 0.0210405702569655, 0.03455594288451331, 0.057015838766736646, 0.028809501057756797, 0.031166087104273692, 0.07144494022109679, 0.017738191211330037, 0.02053843398711511, 0.013798535468855073, 0.02104651083105377, 0.039489839026438336, 0.038180045916565826, 0.04680118277402861, 0.03780011719624911, 0.05243807172934924, 0.08144878556153604, 0.017773279953481894, 0.01381868711074016, 0.024447414857734526, 0.03580226922141654, 0.056638912563877444, 0.06961723829486541, 0.030568569166851894, 0.0163304142520896, 0.09825324812637908, 0.16228205843695573, 0.11436117413852896, 0.15121165104210377, 0.15403157472610474, 0.1599975260240691, 0.08298844258700099, 0.12749706927154744, 0.08685404980289084, 0.136485256254673, 0.10518430013741766, 0.14771889203361102, 0.19301748275756836, 0.1083397933148912, 0.15966906079224177, 0.08842935027288538, 0.1627819894679955, 0.12534780959997857, 0.17644851255629743, 0.10700149155621018, 0.1381740892039878, 0.17589113675057888, 0.1232415826192924, 0.13103089321936878, 0.10028707542057548, 0.07614410735134568, 0.1316869551581996, 0.1292948206620557, 0.17808326626462595, 0.13799790080104554, 0.10482504977179424, 0.12833747560424463, 0.24415782572967665, 0.1996634075684207, 0.15100924404604094, 0.15000377728470735, 0.24894187759075845, 0.13718394376337528, 0.13454612530767918, 0.12411065027117729, 0.09922503240938697, 0.05280389031395316, 0.19304032224629605, 0.14703549870422908, 0.1661850190056222, 0.08651553546743733, 0.0812575336811798, 0.10716016018497092, 0.09848961580012526, 0.12838653368609293, 0.14978687678064617, 0.06296087083007608, 0.12182683710541044, 0.1339134592562914, 0.0654985782291208, 0.10581511378820453, 0.14862498055611337, 0.09648567118815013, 0.08464324021978037, 0.10261424018868379, 0.11898293399385043, 0.09666850244892494, 0.12371419583048139, 0.10112034356487648, 0.13411787471600942, 0.18374161049723625, 0.13618641586175986, 0.07031847030988761, 0.09851491837097065, 0.14244945693228925, 0.05776082950511149, 0.08472627255001239, 0.14081737665193422, 0.21472940913268498, 0.10118180526686565, 0.1274861991405487, 0.08007648919842072, 0.10846368702394621, 0.1657925272094352, 0.15153540724090167, 0.10331309733114072, 0.12087306114179747, 0.1071923023888043, 0.16751839460006782, 0.1805872233318431, 0.14227026940456458, 0.1621508297643491, 0.059481105767190456, 0.13338121638766356, 0.10912531294992991, 0.09275320611361947, 0.16224188916385174, 0.19466791062482766, 0.16087398970765726, 0.10490659611033541, 0.13838952407240868, 0.09211780556610652, 0.1523150982601302, 0.1529479000185217, 0.15755348359899862, 0.11758125706442765, 0.09974784364125558, 0.11193762347102165, 0.06113519772355046, 0.13459876605442592, 0.12180631820644651, 0.22278033569455147, 0.16108932958117553, 0.0731788957491517, 0.1225092669150659, 0.2224737192903246, 0.10131591092795134, 0.09256232742752347, 0.10286507422902755, 0.28444139127220425, 0.11409870322261538, 0.15486914478242397, 0.09560877324215003, 0.0708518870440977, 0.13039023402546132, 0.12234939049397196, 0.09504927362182311, 0.09968450239726476, 0.13157229631074838, 0.07327645551413298, 0.1161472818681172, 0.1733057690518243, 0.17832983231970242, 0.148867950375591, 0.10796074329742364, 0.2175098420786006, 0.26242092145340784, 0.12987537522401127, 0.09460993576794863, 0.14374634091343197, 0.1870852546500308, 0.14561778120696545, 0.1603638127978359, 0.07804462287042822, 0.10661096072622708, 0.13490554530705723, 0.07260343019983598, 0.14044393811907085, 0.0837386173329183, 0.11481641685324055, 0.08444399519690446, 0.07901501615664788, 0.13892739878169127, 0.20108759828976222, 0.13817185003842625, 0.0735322292894125, 0.11584561876952648, 0.18276019101696356, 0.10111066765551056, 0.14778257933046135, 0.1277052845273699, 0.15446044956999166, 0.1561247466930321, 0.04703815434394138, 0.18965143337845802, 0.19091395634625638, 0.07543014601937362, 0.1524929694299187, 0.07084960716643504, 0.16221567057073116, 0.12195555519844804, 0.16279121754424913, 0.10001666564494371, 0.08287659965987716, 0.11650514123695237, 0.15773671519543442, 0.15965486583965166, 0.1499317032950265, 0.1134417320468596, 0.14887465430157526, 0.12825630924531392], [0.02140260091982782, 0.010337575155842518, 0.02371468355080911, 0.07905383514506475, 0.011149827374278434, 0.010392192135831075, 0.024797661063660468, 0.016274370652224337, 0.08034335702125515, 0.02414711900720639, 0.04945600192461695, 0.04439667858449476, 0.02928097772278956, 0.036726226963635, 0.020152871729806066, 0.06884275163922991, 0.04245738818177155, 0.009906309324183633, 0.013451603058326458, 0.09468257294169494, 0.047355946219925366, 0.017697945603036454, 0.013157460672248687, 0.02394283246914191, 0.017678656548793827, 0.03494233465088265, 0.015024063011099185, 0.024795403238385916, 0.010353156016208231, 0.09115766494401864, 0.0931323171992387, 0.030341483852160827, 0.015499683828758342, 0.006518600683193654, 0.03578213030206306, 0.002816075542276459, 0.021071674302220345, 0.04696336621418595, 0.0031636402626255794, 0.015338012682540076, 0.08178278763911553, 0.02471380940239344, 0.03346404433250427, 0.029417281837335656, 0.01085051115868347, 0.06370318814047746, 0.026454227976500988, 0.022809629794210196, 0.0773039408294218, 0.012724232178048363, 0.022170358204415867, 0.020438616396859288, 0.025069029270006076, 0.03800621542281338, 0.03282984479197434, 0.0360790606188987, 0.015678893408871124, 0.02045020238230271, 0.04044485331646033, 0.016649339281554733, 0.012190545726168369, 0.0392487317855869, 0.04872730281203985, 0.012987468142195471, 0.032194478171212335, 0.03741930977308324, 0.0249888433941773, 0.01329345435702375, 0.025587894820741246, 0.05931639139141355, 0.025727418583950827, 0.024434000220415846, 0.05032617558858224, 0.07265757050897394, 0.015584573648603899, 0.06941893643566541, 0.030424831701176505, 0.059596097096800804, 0.08546644568975482, 0.06611379914517913, 0.009040401100979319, 0.06281143706291914, 0.03109998761543206, 0.01895750846181597, 0.05332783130662782, 0.05220462175618325, 0.027769625785627534, 0.07013783750257321, 0.00704925790029977, 0.07841734894152198, 0.01657421697330262, 0.04904474184981414, 0.06583740469068289, 0.06983375203396593, 0.01680080865376762, 0.06102144132767405, 0.1212988690074001, 0.054326315942619524, 0.021725112006866505, 0.015726204263046384, 0.057355004495808055, 0.01769442400628967, 0.0186267056768494, 0.05773849891764777, 0.02611048722506634, 0.03099675869036998, 0.015214987498308932, 0.009327611403672822, 0.055630256687956195, 0.048804981500974724, 0.05135797629398959, 0.06261194098208632, 0.03544492893187063, 0.01053540882587965, 0.041588866750576665, 0.029650473967194557, 0.04000646201893687, 0.06631873029151134, 0.061501878047628064, 0.04127147521025368, 0.07481506081031901, 0.04278741404414177, 0.022520955552213957, 0.02095353796279856, 0.03185825049877167, 0.009176962210663726, 0.033639734012207816, 0.03162560458960278, 0.025605060060375502, 0.0669019039986389, 0.013007657951675355, 0.03986478051436799, 0.04065601680693882, 0.02772304435659732, 0.040588960583720884, 0.008926089154556394, 0.015787818635414754, 0.08980624710342713, 0.002191821204697979, 0.0336169963037329, 0.04505498308156218, 0.03397451301238366, 0.02372220002247819, 0.025791248373155082, 0.04385536370266761, 0.011456683810268129, 0.018249209504574537, 0.02789804362691939, 0.011006747239402362, 0.01305993992303099, 0.04565362060176475, 0.07464596309832164, 0.033401680178940296, 0.009671680396422744, 0.0961997297459415, 0.020579709272299494, 0.02206501903544579, 0.0924554378060358, 0.022086367443470017, 0.013725287613591977, 0.04981249404538955, 0.07302636786230973, 0.04337410256266594, 0.027935690446091548, 0.046427924052945206, 0.06440539046057633, 0.030016346834599972, 0.03882248965757234, 0.030462300404906273, 0.035529009598706446, 0.06925982675914254, 0.019109758149300302, 0.09733425386782203, 0.008484599496504026, 0.01627743084515844, 0.02337553648145071, 0.026832484107996737, 0.0032456781149708797, 0.05745107826909848, 0.02677482389844954, 0.036999649434749565, 0.042482527904212475, 0.03426259183990104, 0.04991861352963107, 0.046303887851536274, 0.044123052552874596, 0.002395776956940868, 0.03578089536832912, 0.02110412354314966, 0.07025879994034767, 0.027800185306529914, 0.029397516112242426, 0.0695164826299463, 0.03507322066330484, 0.05693026871553489, 0.05191890423053077, 0.03734330367296934, 0.05317222626347627, 0.05748110344367368, 0.023053240829280446, 0.036003773765904565, 0.026183670619502664, 0.03838041052222252, 0.031137887188898664, 0.02610747792225863, 0.0490672522490578, 0.055169466949467144, 0.004365845284025584, 0.045039502305111716, 0.01862381851034505, 0.056024200549083095, 0.05978452627147947, 0.03327930638832705, 0.018351193317877393, 0.002805741029858057, 0.011318116781434842, 0.013100844558461435, 0.04727197072601744, 0.0179382199421525, 0.06040156566138778, 0.015337184869817324, 0.018159619133387293, 0.05579189730009862, 0.039083511901221106, 0.08271984449986901, 0.022929691476747394, 0.024441089215023176, 0.02427328411223633, 0.02414205713596727, 0.021382521372288465, 0.06381129233964852, 0.02406955566922469, 0.008094931254163384, 0.026469440731619085, 0.014076447297286774, 0.026122465064483028, 0.024742161988147666, 0.02523733309603163, 0.06858528152640377, 0.005871306689056967, 0.02499342180921563, 0.023007446500871862, 0.04297765829999532, 0.03974433037053261, 0.016934766733486737, 0.026087072677910328, 0.020865267342222587, 0.02210297458805144, 0.09132708156747477, 0.006426071831291276, 0.034775062198085446, 0.025768190056883862, 0.012674423466835703, 0.014659727025511009, 0.01788720428677542, 0.022385811732549752, 0.017549122517396296, 0.04207636023472462, 0.023719947286216275, 0.05308180129421609, 0.021209276114989604, 0.053737646101840904, 0.009530927636660635, 0.06621916206287486, 0.031629526522010565, 0.05553749755823186, 0.03897092937092696, 0.028286430286243558, 0.04281429760158062, 0.013909290195442736, 0.03154855354556015, 0.0368223651977522, 0.05181556673986571, 0.017596596219976033, 0.03048656481717314, 0.09118777832814626, 0.01015726465266198, 0.03199074463918805, 0.0410279795261366, 0.052342903800308704, 0.07676035964063235, 0.013599177639532303, 0.049174722017986436, 0.021819889778271317, 0.029041909479669163, 0.07887324304985148, 0.024089324786993008, 0.010421140136064162, 0.0819716714322567, 0.014692666507991297, 0.045823854859918356, 0.03613280737772584, 0.07845529940511499, 0.0437578242937369, 0.005932893920024591, 0.0069833064169090775, 0.10223923423992735, 0.04354608065581747, 0.031435662281832526, 0.041421041291739256, 0.020247379783540964, 0.04055108815165503, 0.02575606633243816, 0.08572624996304512, 0.041762062814086676, 0.015403842453711798, 0.04454443637015564, 0.022902103939226696, 0.02804573016640331, 0.02911389186712248, 0.029342358000576496, 0.031205730512738228, 0.005719319085723588, 0.042388747579285076, 0.00854294078557619, 0.08267207563455616, 0.02717400435358286, 0.016527735628187656, 0.024689314288220236, 0.040519560022013526, 0.018878355655553083, 0.014908691701878394, 0.04957804662574615, 0.001880334403332589, 0.04225512367806264, 0.014677541962425624, 0.03665692139683025, 0.017621396674907634, 0.0195391707321895, 0.04306496540084481, 0.05534189287573099, 0.026601561677775214, 0.012952370070187109, 0.027767527416082363, 0.033931453180100234, 0.02320315465996308, 0.03670493114207472, 0.030074073201311485, 0.02124882792122662, 0.029747236453528916, 0.012499861003431891, 0.026290909686524953, 0.028674387772168432, 0.03592383894803269, 0.052140659652650356, 0.019253648285354887, 0.06525041761675052, 0.02986571206046002, 0.06360666653407471, 0.010000277094409933, 0.024914638804537908, 0.02040853863582015, 0.15311092484210218, 0.13952114406440938, 0.15042934087770327, 0.16586168349853583, 0.13208733153130325, 0.13250647618302278, 0.15634043940476008, 0.15776737140757696, 0.16125345363148622, 0.1187815855124167, 0.08083716766642672, 0.2576960649873529, 0.10197252926549741, 0.1645231374672481, 0.11911622541291372, 0.10280904759253774, 0.12048993312886783, 0.10233684150235993, 0.19920517929962703, 0.1153016643864768, 0.2234460599720478, 0.11006247159093618, 0.16297815394188675, 0.05758567247539759, 0.11484547172273908, 0.09500731980162007, 0.09227654883371932, 0.11283326933958701, 0.07631693022059542, 0.148837931986366, 0.17920158697026117, 0.09543295124811785, 0.1151621440159423, 0.0982997752726078, 0.09809617405491215, 0.08576018349932772, 0.08330396815602269, 0.09535313517387424, 0.11161126848310232, 0.10417109129152127, 0.13899480445044382, 0.10532531328499317, 0.09944921359419823, 0.3117859182613236, 0.15202906860836915, 0.13792719745210238, 0.12487284865762506, 0.13801141721861704, 0.17091786861419678, 0.13551313270415577, 0.10128939377942256, 0.11717888579836913, 0.053484481293708086, 0.10408297673399959, 0.1366502216884068, 0.1322802933199065, 0.10526386515370437, 0.07968885571296726, 0.08258064304079328, 0.12290597919906888, 0.08847996219992638, 0.07560707402548619, 0.12680412216910295, 0.07895494545144693, 0.15986390890819685, 0.08519539809120552, 0.15050734526344708, 0.09371735009231738, 0.12003527395427227, 0.11252604903919355, 0.0903028736689261, 0.1541442929634026, 0.14356837474874087, 0.11046257655003242, 0.20934764934437616, 0.10844645223447255, 0.09760528789567095, 0.14032355243606226, 0.13823753222823143, 0.12042697864983763, 0.07329121365078858, 0.10065948936556067, 0.09427561477891036, 0.08811029632176672, 0.12742697660412106, 0.16703382560185023, 0.07572234355445419, 0.26519156992435455, 0.09026738628745079, 0.14868333456771715, 0.12584171524005278, 0.11053916958293744, 0.23865572097046034, 0.11235575032021318, 0.04627050732129386, 0.10212724882044963, 0.17375848761626653, 0.07735954677420002, 0.286771154829434, 0.17175421730748244, 0.18805344269743987, 0.10080066536154066, 0.08129313641360827, 0.22109484113752842, 0.1914572457649878, 0.10069099374647651, 0.128239902268563, 0.08307259450001375, 0.12935488458190644, 0.14705551548727921, 0.11518817261925765, 0.13526861582483563, 0.11204554446573768, 0.09599015063473157, 0.09886129014194012, 0.11266728610332523, 0.11346118564584426, 0.10735413977610213, 0.2033641647015299, 0.16993895971349307, 0.140931438388569, 0.12641042258058274, 0.09067119604774884, 0.06601035648158618, 0.09841255457805735, 0.11976361567420618, 0.14714867834533962, 0.1328231349055256, 0.12280763233346598, 0.16991553668464932, 0.11473873816430569, 0.060004276622618945, 0.1647444755903312, 0.0763481224754027, 0.19764560727136476, 0.14681103932006018, 0.09155430258916956, 0.14198748315019266, 0.11632644225444112, 0.17706243747047015, 0.08671115032796349, 0.11268958954938821, 0.10452979204377957, 0.10967375923480306, 0.1254084977720465, 0.0882616639137268, 0.16074149895991596, 0.07837470301559993, 0.11453809535929135, 0.10750814008393458, 0.09929830740605082, 0.11985612713864871, 0.11387834218995911, 0.12085749554846968, 0.11405010654457978, 0.1826872756438596, 0.07011577832911696, 0.10755348657923085, 0.13290339202753135, 0.12360168115368911, 0.17167679646185466, 0.0981447978743485, 0.10505066266549484, 0.13575638750834124, 0.0860608627221414, 0.1397901696286031, 0.12100190137113843, 0.13913239778152534, 0.14322300042424882, 0.2066773154905864, 0.17280545804117406, 0.12446233497134276, 0.11944102655564036, 0.06929561269602605, 0.12893002666532993, 0.12015450612774917], [0.03171841460945351, 0.027506920775132518, 0.038747182448527644, 0.039078721443989446, 0.01800788682885468, 0.07642028467463595, 0.05512573876019035, 0.03384696199957814, 0.023156593586983423, 0.04441169795713254, 0.010557222878560424, 0.04736087916951094, 0.006789267878048122, 0.047250359385673485, 0.023973870357232432, 0.022108943999878, 0.020229758229106665, 0.052785529156348536, 0.025048026914841363, 0.014961970271542668, 0.038679237344435284, 0.03918588926483478, 0.0788119374109166, 0.022455191938206553, 0.10144011676311493, 0.0786629854036229, 0.016226822310792546, 0.04460037140441792, 0.04449775655354772, 0.0044037567318550176, 0.05028735660016537, 0.04665829686980162, 0.04011095301913364, 0.08395908014582736, 0.05865629895457199, 0.027893853673179234, 0.024188786146364043, 0.051003238186240196, 0.04939339689112135, 0.014459869624780757, 0.0225903154018202, 0.028710716537066867, 0.004471913454056318, 0.05335986494485821, 0.02789532270149461, 0.012979881272518208, 0.04468506953812071, 0.04367868675451193, 0.07289195007511548, 0.008017179622714008, 0.029386612054492747, 0.0607468517763274, 0.05082571306931121, 0.03417562061388578, 0.02794617211579212, 0.013887146205109144, 0.025558103740747486, 0.030700754573834792, 0.030205464722322564, 0.08599786753101007, 0.03379505067797644, 0.051744636081691296, 0.02616335867371942, 0.035544724469738345, 0.027049091145662323, 0.01747449723604534, 0.06587085646710225, 0.057457463283623965, 0.11251512462539331, 0.06712457205035857, 0.039771217320646556, 0.01751005247102252, 0.042679408232548406, 0.033672361368579526, 0.0624481358432344, 0.05314428758408342, 0.0451985034160316, 0.028746963877763067, 0.017530464500721012, 0.10145421672080245, 0.01778666066404964, 0.008984678108910365, 0.06900576289211001, 0.030554214758532386, 0.04003410214292152, 0.053766700971339426, 0.011679620731488934, 0.05339272978848644, 0.0025063790131493336, 0.03266378352418542, 0.02960646418588502, 0.005059810188998069, 0.026575181932587708, 0.03354467464877026, 0.05938716259385858, 0.030158991858895336, 0.06393666525504418, 0.01655674130389733, 0.035061118991247246, 0.04080225806683302, 0.01327545112664146, 0.030035624014479772, 0.06681973340788058, 0.03737738987963114, 0.047664136825395484, 0.02038873389496335, 0.09091414551117591, 0.03766533639281988, 0.051753721665591, 0.05934475415519305, 0.0431634717221771, 0.01881251740269363, 0.009514181392400392, 0.039703964322273216, 0.02112507331185043, 0.02946839588029044, 0.06198288473699774, 0.03161929082125425, 0.0127550758354898, 0.010452502024626093, 0.04842011983107243, 0.055686344392597675, 0.07254215170230184, 0.019840832134442668, 0.02646835507558925, 0.06353052133428198, 0.005819728273698794, 0.03225246238123093, 0.03515176109171339, 0.04351203855393188, 0.040165534376033714, 0.028594629373401403, 0.08234138480786767, 0.03290766936593822, 0.007186409335450402, 0.03442749620548316, 0.017104498875726546, 0.014103424153290689, 0.024240348022431135, 0.08525517702634845, 0.03505770596010344, 0.08704360534570046, 0.04862751405952232, 0.07548394027565207, 0.09916150796094111, 0.044797852236245356, 0.019726054543363195, 0.04163113948223846, 0.005244566368803914, 0.016094055060031157, 0.05007570456447346, 0.05783650651574135, 0.0063774539490363425, 0.02553960009078894, 0.025410166143306663, 0.05219645219455872, 0.05499502916687301, 0.058302191884389946, 0.013855660483906311, 0.017782647129414336, 0.040404429592724354, 0.034316762683114836, 0.03226202633231878, 0.05314679477097733, 0.033561648202261755, 0.019029894577605382, 0.0486244606519384, 0.042977831326425076, 0.061217727937868664, 0.048360150906124284, 0.08080832314278398, 0.03417649592405983, 0.03246608216847692, 0.039402175694704056, 0.04480569949373603, 0.016608959662594965, 0.008434990104953093, 0.0031720604581226197, 0.06402008435023682, 0.07891890845660653, 0.06037236151418515, 0.07362693920731544, 0.03580890190122383, 0.010430403835406261, 0.042742372889603884, 0.04078566449295197, 0.05008232706625547, 0.06548458683703627, 0.02281482906879059, 0.021748852250831466, 0.026011931709945202, 0.019058157257469635, 0.04306241410917469, 0.02090724660748882, 0.019266861058505516, 0.023207975651270578, 0.02592925221792289, 0.020608881189088737, 0.0346607697595443, 0.046369254522557767, 0.08720787867371525, 0.061342245899140835, 0.0453708004206419, 0.07060009626937763, 0.017445939393447976, 0.00824781452372138, 0.08151063402848584, 0.030714440625160933, 0.010999443658095385, 0.02298826601223222, 0.03139718595360007, 0.020394343683230023, 0.02477224144552435, 0.03865498650286879, 0.07704189739056996, 0.019350821285375526, 0.05941737775823899, 0.02211866571035768, 0.031246863305568695, 0.03751110877575619, 0.05577796358349068, 0.021767805430239866, 0.04434766460742269, 0.0750899285610233, 0.06648499172713075, 0.03124521446547338, 0.07067645181502615, 0.07764773416732039, 0.0735545666622264, 0.01867308184903647, 0.012891844746523669, 0.03292374386053, 0.03981273687843766, 0.04793430232842054, 0.024388652028782026, 0.05267526721581817, 0.0128289623618392, 0.04206370555662683, 0.0519743134001536, 0.01388862625961857, 0.03611041911478553, 0.06303510256111622, 0.024547531003398553, 0.023337083901943903, 0.05521991263542857, 0.029450234890516316, 0.0366972094135625, 0.044556246272155216, 0.02442728272373123, 0.055645316772695096, 0.041411965885864835, 0.06214254402688571, 0.08017575887164899, 0.03666921645136816, 0.06433708912559918, 0.007921847148931451, 0.04731746989169291, 0.02717480841757996, 0.03255071923402803, 0.011517077667771705, 0.041526590806565115, 0.04039665697408574, 0.06455120763608388, 0.013885525354583348, 0.015543551117713963, 0.04130612460098096, 0.03079082670488528, 0.0166463181043842, 0.04513115203008056, 0.014518121856131723, 0.0864947180130652, 0.031836055618311675, 0.007952025842054613, 0.046166796636368544, 0.0008132844928435848, 0.05364278690623386, 0.048189967538097074, 0.02919678170500057, 0.03349269208099161, 0.022004045878670046, 0.006628701047572706, 0.02967476552086217, 0.02332022400306804, 0.06467056873121432, 0.01868035065542374, 0.06132182199507952, 0.10555134687040534, 0.03480822220444679, 0.026655837693916898, 0.047441685904881785, 0.02023790404200554, 0.026181383956489817, 0.03759916565780129, 0.011815604238238717, 0.059844291635922024, 0.011028071898700935, 0.12954468439732278, 0.04593218297564557, 0.02440074861182698, 0.03414110014481204, 0.031443909874984195, 0.01613559158119772, 0.06109217181801796, 0.014317523155893599, 0.04118705188323345, 0.042289070785045624, 0.05586075842646616, 0.03145253744774631, 0.0639445430466107, 0.02612671099736222, 0.012478482909500599, 0.04667108725490315, 0.03214723517053893, 0.03157103680340307, 0.07159998547285795, 0.008153169914813978, 0.024612429485257183, 0.027621511769081866, 0.05072450278592961, 0.015875132521614432, 0.038726120721548796, 0.011621119138518614, 0.02913907230166452, 0.12793840201837675, 0.0320330920097019, 0.04706307354250124, 0.006089876813348383, 0.07893465725438935, 0.05046945843579514, 0.05285026818247778, 0.06409221940806933, 0.051878914769206724, 0.0349454219852175, 0.045735984575003386, 0.04984568797850183, 0.02396640138301466, 0.029999115437801396, 0.04298110865056515, 0.06941443774849176, 0.01055597182961979, 0.018246982213375822, 0.014828609302639961, 0.013317962193728557, 0.03990119070346866, 0.043555539433977435, 0.05014771409332752, 0.05110915071730103, 0.030751050982092108, 0.0350330785316016, 0.05699135043791362, 0.00973279689372118, 0.02633842240486826, 0.09370415937155485, 0.08944085599588496, 0.173711166584066, 0.15524180978536606, 0.16170324092464788, 0.1752567607909441, 0.2186898687588317, 0.11245261797947542, 0.09994523626353059, 0.13522586811866077, 0.17090147520814622, 0.1165584876601185, 0.10317831992038659, 0.15494596851723536, 0.22780100628733635, 0.11661164409347943, 0.10632125341466495, 0.177956135943532, 0.1326629870704242, 0.12290593848696776, 0.12440373668713228, 0.10669919063470193, 0.16263444881354058, 0.08238686701016766, 0.19243151348616394, 0.15039434204144136, 0.04105020494067243, 0.09066833262997014, 0.0893969072827271, 0.07005517836660147, 0.20138198749295302, 0.15775200937475475, 0.10399766452610493, 0.16081400721200875, 0.1500056636120592, 0.14229221322706767, 0.13415694476238318, 0.11602448060044221, 0.16935109054403646, 0.08330189183886562, 0.2162217926234007, 0.05633474227839282, 0.07605481892824173, 0.1294476403189557, 0.16193288431635924, 0.13720344485981123, 0.13526378465550287, 0.2549116015434265, 0.22590825999421732, 0.11633877802108016, 0.07449429695095335, 0.21535811253956386, 0.16083915371979984, 0.19718292781284877, 0.0985956165407385, 0.10862802820546286, 0.1318786684423685, 0.10032530408352613, 0.11749232826488358, 0.16910148465207644, 0.06780717827911888, 0.1835884651435273, 0.21636283291237696, 0.12260310830814497, 0.14312929473817348, 0.22144591515617712, 0.1423935049346515, 0.12223481307072298, 0.21236852795950004, 0.1786037433360304, 0.19279178843966552, 0.18595450318285398, 0.09696074748145682, 0.16191514741097177, 0.1547663060149976, 0.1383474413305521, 0.1553444992750883, 0.14590837061405182, 0.10468763285981757, 0.21268927146281513, 0.11129330697336368, 0.09873066536550011, 0.155646162373679, 0.06584965903311968, 0.12404173825468336, 0.19374358308102402, 0.14041600961770329, 0.1844959378774677, 0.04855850365545068, 0.13850180804729462, 0.16042657728706086, 0.09555931482464075, 0.070164754986763, 0.1339696283851351, 0.15649175271391869, 0.16624635857130798, 0.17530656526131289, 0.17070697993040085, 0.1086499991693667, 0.1484557810638632, 0.10312341286667756, 0.09826198087206908, 0.11485495764229979, 0.0912041717341968, 0.09476544242352247, 0.13366154634526797, 0.19915602622287615, 0.1971917894801923, 0.1426002545548337, 0.1421632237200226, 0.24617228763444082, 0.1079930347789611, 0.11647035953189645, 0.11066636097218309, 0.08705687070531504, 0.08006371916936976, 0.13546860723623208, 0.08646810586963381, 0.14615765080920287, 0.14840217679738998, 0.20640199312141963, 0.1506366061844996, 0.1117316677368113, 0.1831864874277796, 0.18130987669740403, 0.11064176407775708, 0.15337612346879073, 0.11024366079696588, 0.09258024075201579, 0.12045569425182683, 0.11594382992812566, 0.07476083907697882, 0.12908132640378817, 0.0975980411416718, 0.03727488698703902, 0.11884691486401217, 0.09915400336363486, 0.12930407587971005, 0.13331923899906023, 0.1738286345664944, 0.11642514195825372, 0.20896449419004576, 0.14168843919677393, 0.1164383055376155, 0.17171345092356205, 0.11681870583977018, 0.11256771787468876, 0.2293245888182095, 0.15603637429220335, 0.11901454015501908, 0.08257587972496237, 0.15834119490214757, 0.10210995296282427, 0.12578139347689493, 0.12285090929695539, 0.16997626556881837, 0.14037425257265568, 0.18306587104286465, 0.1358624832438571, 0.1259768387036664, 0.23441995254584722, 0.09433741574840886, 0.14196534933788435, 0.22015251884503023, 0.12065632348614079, 0.07743439597210713, 0.07984852178820542, 0.09611310118011065, 0.20114842216883386, 0.17066446292613233, 0.18179353645869664, 0.08532335622502224, 0.14987731192793163, 0.14756590952830656, 0.12289375199803285, 0.10323154420724936], [0.011646744013497872, 0.013657565577886999, 0.06476422013448817, 0.004627253020381821, 0.028818145593894378, 0.04169714736885258, 0.041344339693231244, 0.03877649516133325, 0.06218855548650026, 0.07564885821193457, 0.007197617885789701, 0.041096891542630534, 0.019510027653138553, 0.05193046985992363, 0.027477830282545516, 0.03760038023548467, 0.014516997184338314, 0.024888036839131798, 0.02927064702713064, 0.03682689781167677, 0.051320086898548264, 0.021954911461632167, 0.035871998872607946, 0.06982456466981343, 0.026335170525791388, 0.027906326843159537, 0.03084778632702572, 0.030739393750471727, 0.022382871979581456, 0.03518203393157039, 0.023849055536889603, 0.003846159130002239, 0.02538268717138895, 0.06672221435500042, 0.02867268804194672, 0.04445970091702683, 0.04927717741312725, 0.03477788829643812, 0.060763021265821796, 0.019609137870637432, 0.0548027560913137, 0.02378807559476367, 0.021004857262596488, 0.07617645311568465, 0.020022754158292497, 0.052848422567227056, 0.04990648810884782, 0.018206639913842082, 0.03529722882168634, 0.04607780337599771, 0.044536188777003965, 0.07501555433762924, 0.028077801124059727, 0.044770649767347744, 0.03399458068556019, 0.06595882174691983, 0.037133612603481324, 0.051012072712183, 0.022493325606254593, 0.023493811920551316, 0.014228619801412736, 0.0381654472356396, 0.02209216382886682, 0.036887368852538724, 0.018373286418084587, 0.04851711641198822, 0.005582247378437647, 0.026343793009540865, 0.05788500141352415, 0.014956791353012835, 0.03365982882678509, 0.009171271846363587, 0.035299617264951975, 0.05641668216724481, 0.04239131583433066, 0.023503777903637717, 0.02710300075289394, 0.06919133543436017, 0.08897390855210167, 0.07328526289867503, 0.033095844089984894, 0.029700943401881626, 0.03842206239434225, 0.015247105953416653, 0.03353974848453488, 0.04967613225536687, 0.03610658199925508, 0.026212696651262895, 0.022896078548261097, 0.054435773819152794, 0.034274194788719924, 0.05351917818188667, 0.09297244077814476, 0.06326032868985619, 0.013274484214239886, 0.013716939936525055, 0.03717252319412572, 0.06524287230734314, 0.05197271205750959, 0.023719150007569363, 0.06058113995407309, 0.017257569590583444, 0.021722603123635054, 0.024660184779869657, 0.021140448915373002, 0.027081676093595367, 0.003518460854788178, 0.03697135452447193, 0.03028274646827153, 0.049489005867924006, 0.030811030085065534, 0.015377464404861842, 0.04997164782668863, 0.011791685030662587, 0.025666101070653115, 0.046637706724660735, 0.03755797518949423, 0.013414251401887407, 0.036688374887619696, 0.07605682739189693, 0.014091433591342397, 0.01152124217644866, 0.03545121216614332, 0.05532370474455612, 0.016736268099131327, 0.004667533827679498, 0.024996677080967596, 0.0672612561445151, 0.020783106929489543, 0.1561542358249426, 0.020489226627562727, 0.045907141640782356, 0.03376987702878458, 0.004903434584515968, 0.05081299053771155, 0.03848403299759541, 0.018735681793519428, 0.023047724339578832, 0.04931370634585619, 0.022702575627980486, 0.04024009858923299, 0.014103571734657245, 0.0036264974124995725, 0.011121356044895947, 0.05234806066645043, 0.04523990423019443, 0.027311974271599735, 0.036445062407957654, 0.0506272653250822, 0.06672286574861833, 0.011229387301552509, 0.009578880554597293, 0.041159730670707564, 0.03539672241147075, 0.09573151344167334, 0.05859025035585676, 0.05853505153208971, 0.07016223083649363, 0.015409688032897455, 0.06698942144534417, 0.03943260120494025, 0.03320718490119491, 0.009297399631967502, 0.01405127449626369, 0.03175126588238137, 0.05050755139174206, 0.06649575329252652, 0.028625217732042074, 0.014855645530458008, 0.02369321639915662, 0.06307462722595249, 0.04933078167960048, 0.05859898988689695, 0.03338523588276335, 0.04035714927262493, 0.03969138089035239, 0.06712140329182148, 0.061719742071415694, 0.02522940102166363, 0.062437896749803, 0.08064790389367513, 0.09008889086544514, 0.004814348873748843, 0.05582170534346785, 0.02980384323745966, 0.044721021716083796, 0.02040799580780523, 0.052555909513362815, 0.04141828304688845, 0.01678147379841123, 0.044220965156065564, 0.07037301774003676, 0.007151997431979648, 0.025103210471570492, 0.02330930807095553, 0.057236810480909686, 0.037910263785826306, 0.04763252727155175, 0.023056777693065147, 0.030066161482994045, 0.051412533902164013, 0.022218362860647694, 0.04063375068030187, 0.09337310213595629, 0.022451711053560888, 0.0220315299396004, 0.03717453844313111, 0.019913533769015754, 0.035563937188791375, 0.023620586010760496, 0.038678993071828566, 0.025185406507392014, 0.01156831469519862, 0.03870742708178503, 0.017722785073731626, 0.008502945387070733, 0.04456600360572338, 0.046871573996863196, 0.06247641718281167, 0.04625004270513143, 0.03219765032242451, 0.03572242600577218, 0.0328087796723204, 0.027494647772982717, 0.048654384046260796, 0.01721048604563943, 0.08516382585678782, 0.051883915572294166, 0.031357837707868645, 0.018408325966447592, 0.0327695705262678, 0.04518894625029393, 0.04512393581015723, 0.02356192665839834, 0.036108743133289475, 0.0033895953924262096, 0.036859246968690834, 0.02838346757926047, 0.05373062326439789, 0.062112457784158845, 0.024341962034148828, 0.03799639023574335, 0.014877150001536523, 0.02209560739408646, 0.027430940120081817, 0.03267341532877513, 0.030061767968748297, 0.006218912545591593, 0.04077719637591924, 0.05038329805912716, 0.06756009653742824, 0.028906782623380423, 0.04498252571959581, 0.02114403497294656, 0.09486520742731434, 0.06107118472989116, 0.10581319353410176, 0.05194089215781007, 0.028051621546702724, 0.03920109523460269, 0.008517516078427434, 0.028422003279307058, 0.0059249745681881905, 0.0067352378308506945, 0.029777438047208955, 0.03134188534958022, 0.016544527673561658, 0.027867658828784312, 0.018711346135075604, 0.0562057833054236, 0.019120645243674517, 0.007636246670569692, 0.025477978933070387, 0.03447128546291164, 0.02975189798910703, 0.06627223028668336, 0.07679360107119594, 0.06225729786923953, 0.04703411706058042, 0.05489640749458756, 0.04457827491153564, 0.051309366045253615, 0.055356135325772424, 0.05640973736132894, 0.011686455275464271, 0.02161933687914695, 0.0231570838285344, 0.04328492270516498, 0.020260641750480448, 0.011452316589254354, 0.03425671233396445, 0.014086079101876488, 0.04301479791424104, 0.01838446019350418, 0.020978151820600033, 0.010466199950315058, 0.01785967272839376, 0.0422189475835434, 0.05918134256665196, 0.030653847447995628, 0.05602409537615521, 0.05496371477576239, 0.0229162072895893, 0.01829929047796343, 0.0214840641378292, 0.03992350432755692, 0.07825073466769286, 0.03405229687424643, 0.03792262330119099, 0.03568042468811784, 0.03889470274693199, 0.030352879847799028, 0.06743698992899486, 0.008460029743478766, 0.013821860958289887, 0.05800419287489993, 0.08647396841219493, 0.009238803892263343, 0.03271129793886628, 0.04906796471082738, 0.025094720302149653, 0.041234376308109076, 0.04299755973209228, 0.06555180251598358, 0.035804240365645716, 0.034957666149629016, 0.0652678423960294, 0.03968788304233125, 0.03883617910157357, 0.04792388342320919, 0.08641721574323517, 0.01760014326178602, 0.03400474853281464, 0.03141948600698795, 0.03494465524064643, 0.09200632226254259, 0.029639746328549724, 0.024498109905315296, 0.01889946318364569, 0.02312903319086347, 0.01426439216759588, 0.021447141654789448, 0.03546376506398831, 0.09249537637723343, 0.08015488034912518, 0.02337659669241735, 0.0357126279601029, 0.021513027405100207, 0.06863964575209788, 0.024671014198767285, 0.028000661870464683, 0.03314837966380375, 0.11967066994735173, 0.1463658796357257, 0.18711489305964538, 0.10393138522548334, 0.12635438915874275, 0.10973569591130529, 0.13201288266905717, 0.09789941247020449, 0.15273925050028733, 0.1076600980013609, 0.20251325464674405, 0.11898548528552055, 0.15191408406410897, 0.12181577698460647, 0.13026376866868564, 0.172117912077478, 0.09721310822559254, 0.10175434633025102, 0.12625832217080252, 0.12082492586757455, 0.10423942655324936, 0.10250532853284053, 0.184243468567729, 0.18018090299197606, 0.17382446836147988, 0.1261585775230612, 0.09045250421123845, 0.21906174666115216, 0.1170079085443701, 0.1586522760667971, 0.14471778592893056, 0.08572830592415162, 0.13704052860183374, 0.16563065589538642, 0.18752259761095047, 0.09725614770182542, 0.09941003498222147, 0.08440955954470805, 0.1139613405934402, 0.11657019917454038, 0.22899055959922926, 0.11811389348336629, 0.10341104386108262, 0.18509184090154512, 0.1286985512290682, 0.15827703263078416, 0.1274960921811206, 0.1256193457437413, 0.10886875885937895, 0.14509665274194308, 0.16899491394204752, 0.1982585008123091, 0.21694504309977802, 0.07446999182658535, 0.08719116635620594, 0.12584740136350903, 0.1962037474981376, 0.12573358389948094, 0.16033927697156156, 0.1125760299286672, 0.10824765504470893, 0.21138340367802552, 0.19621019358081476, 0.22606098465621471, 0.16725696862808295, 0.12560832633503846, 0.08885865259383406, 0.1004542393077697, 0.13513953132288797, 0.07245574705302715, 0.11020081809588841, 0.11089289667350904, 0.07329566484051091, 0.19642998464405537, 0.10567337460815907, 0.11030109200094428, 0.18909264621990068, 0.09131909521030528, 0.20886278179075035, 0.1362489496490785, 0.19816806566502365, 0.11883533905659403, 0.0999059219445501, 0.147380031645298, 0.05542503377156598, 0.11672292383653776, 0.09589350010667529, 0.11213880910405091, 0.1815903830741133, 0.09825026935764722, 0.1081359206831881, 0.138632046058774, 0.19523052472089017, 0.14843150308089598, 0.10489294398576021, 0.07226600830576249, 0.2078230082988739, 0.1285132026033742, 0.12954154956553662, 0.17807650805584022, 0.14726198012275354, 0.1455548402986356, 0.1261993981897831, 0.08385229230459247, 0.13511984023664678, 0.17081057865704807, 0.16075591104371206, 0.15091837463634356, 0.12836845751319612, 0.17466794167246136, 0.05938123219779559, 0.10429736665849175, 0.11170858397547688, 0.08537819542522941, 0.10720416996628046, 0.1400491800159216, 0.09877257168825183, 0.10227055541638817, 0.10370916500687599, 0.13183175453117915, 0.08144744206219912, 0.12314459282372679, 0.08788797432290656, 0.12857317152832234, 0.10759752350194113, 0.08109701265181814, 0.12033646207834993, 0.14834329352847167, 0.1258809074227299, 0.17377253329115255, 0.17212730300213608, 0.08833393467856304, 0.17738034469740732, 0.1207298223993608, 0.15481662617198058, 0.10076179887567248, 0.11000738133277212, 0.06300747940050704, 0.20614044501313142, 0.11445952100413186, 0.21998513782663004, 0.10399338297013726, 0.09877650719136, 0.09764766240758554, 0.13824077562562057, 0.12598799381937298, 0.10382891286696706, 0.13352734568927968, 0.12517035912190164, 0.12035698097731386, 0.13803241109209402, 0.12735644967428275, 0.12540966485227856, 0.10756265358733279, 0.2675256218229021, 0.08734463062137365, 0.1530709048467023, 0.13221135416201182, 0.09289090801030397, 0.15248479986829416, 0.07612613295870167, 0.09891428372689656, 0.05772390362939664, 0.09979170414486102, 0.06348079150276524, 0.13434910587966442, 0.18075665352599962, 0.12944715177374227, 0.12473248690366745, 0.1001204950734973, 0.19254552093999727, 0.1662050357886723, 0.1257635344352041, 0.1244944975312267, 0.08319354336708784, 0.12455203730080809], [0.11719651413815362, 0.012775861059448548, 0.03047572522025023, 0.0422276837219085, 0.05451867383505617, 0.11048988758453301, 0.03887677245906421, 0.04117014618324382, 0.017501716668318425, 0.016836606465013962, 0.06458225061318704, 0.01947878790087998, 0.09303460137120315, 0.004119126558569925, 0.026766286231577396, 0.041678399446287324, 0.03637786029971071, 0.011822257274096566, 0.023487111387242163, 0.06501337819333587, 0.025282241936240877, 0.02283426231172468, 0.04423578775354794, 0.02523765879284058, 0.018806877080351114, 0.053143544588238, 0.05199569743126631, 0.019152463447036486, 0.05600660952872463, 0.014676765039829271, 0.029659691865422895, 0.05187336774542928, 0.02100365625561348, 0.050468386350465674, 0.031949292934898815, 0.02327431771638138, 0.016293610512678112, 0.04902046725952199, 0.027046488963865807, 0.049643121526709626, 0.018471987818234732, 0.01982369233987161, 0.05026176565193704, 0.04384686505155904, 0.02167416420499129, 0.02263756688418133, 0.04060448546494756, 0.010954005560571594, 0.066935491482062, 0.06654886901378632, 0.046495251690170596, 0.05148883855768612, 0.044897678308188915, 0.015799333374681215, 0.02747674293017813, 0.019360617634707263, 0.024754351869757687, 0.0649646118815456, 0.03449465760162898, 0.060686468945017884, 0.019394824281334877, 0.012359309259669056, 0.04581600420975259, 0.05059729782598359, 0.04005846833544118, 0.05586621384801609, 0.020220550508903604, 0.02161081787198782, 0.012536707151282047, 0.02447907530170466, 0.038301812418337376, 0.040248783837471686, 0.018297483878476278, 0.038498278840311935, 0.02479635488374957, 0.04516335530206561, 0.04740420023777655, 0.035717262354280264, 0.010182968407337154, 0.05825312701719148, 0.008940526683415686, 0.013204801212331014, 0.02624715435584741, 0.028557706890361648, 0.028845911246857474, 0.06860065034457616, 0.06861244328320026, 0.03583308488928846, 0.00421239246913631, 0.023374715454078147, 0.06163929495960474, 0.04944516572036913, 0.0855403042265347, 0.032470730133354664, 0.008078435219691267, 0.04375508640493665, 0.06301326051886592, 0.02821619851913835, 0.03704552518736039, 0.01217051876509296, 0.006652921779147748, 0.04986735020897218, 0.02768999970118914, 0.11107278987765312, 0.026212796735178148, 0.04308104668078678, 0.05525357475770371, 0.03552797144012792, 0.03895011530922992, 0.00973272479937545, 0.026572486452226127, 0.0038458236792523947, 0.022645531188962714, 0.04822114282952888, 0.08162238196070705, 0.059342033229768276, 0.0746492472078119, 0.008548424196695643, 0.01721562085939305, 0.024296649465603486, 0.021449543668755462, 0.04137595263975007, 0.00835132843349129, 0.051646289216088395, 0.03726561480600919, 0.03715886428420033, 0.0046260668563523465, 0.021252103549029146, 0.031214035781366483, 0.013159968707311367, 0.020479506613420587, 0.026163869271320955, 0.034663036066506586, 0.019356680435261557, 0.05408463194700224, 0.025532153168959276, 0.006130011311532664, 0.05475914664566517, 0.02107677688556058, 0.043408979262624464, 0.025027236601869975, 0.016071866964921355, 0.057353131739156585, 0.024580714758485556, 0.017258887644857168, 0.040978086846215386, 0.05860759371093341, 0.014045416194546436, 0.06587476482880966, 0.021075343480333686, 0.021700521897790686, 0.03290554215865476, 0.019646667642518878, 0.049827893397637775, 0.02523945351796491, 0.06354780362120696, 0.09123727067240647, 0.016883705276995897, 0.01671553885431162, 0.051952383148350885, 0.0469642958071615, 0.014783213613554835, 0.03132355811872652, 0.006491326119950307, 0.017936165677383542, 0.013538667582906783, 0.03345691632213337, 0.04393770731985569, 0.03659099154174328, 0.057512987804199965, 0.0279836340341717, 0.03762206621468067, 0.04332724632695317, 0.042811010099415264, 0.05418746392907841, 0.019833034070740854, 0.07144067902117968, 0.04012601649654763, 0.0432938997234617, 0.057375469111970494, 0.03081366280093789, 0.04527408543175884, 0.05789122357964516, 0.06090070280645575, 0.011641388675863189, 0.009008650751119214, 0.032539689647299905, 0.06639089927609478, 0.07118015550076962, 0.04591913813991206, 0.09015339240431786, 0.07061971271676676, 0.024562691172052706, 0.04269737244716712, 0.003997136140242219, 0.024222963955253363, 0.03295285640550511, 0.0284499199063118, 0.054719849290060144, 0.012274463544599712, 0.10430574656597205, 0.04709035065025091, 0.003414950125651168, 0.014263023223195757, 0.051452611573040485, 0.016145937543894564, 0.03704670923096793, 0.04586060092385326, 0.031077958976051638, 0.05403643899730273, 0.06353253658328738, 0.032433824613690376, 0.008427251413065408, 0.08994735524590526, 0.009950051084160805, 0.04991760590512838, 0.006936981134848403, 0.0043923734587484175, 0.04867980536073446, 0.062162798297192366, 0.04091225537870612, 0.02651169310723032, 0.019582247527848397, 0.012213259685917624, 0.05542135950444, 0.09477201064250299, 0.04963712327714477, 0.022654618469199965, 0.05956011438476188, 0.04365729593804904, 0.03851527274985399, 0.010393273551017046, 0.0022986775355613126, 0.04795575421303511, 0.028218568302690983, 0.0254145664429026, 0.0223687448804932, 0.014694618992507458, 0.05495442563135709, 0.03033229648800833, 0.06043697161866086, 0.07798372435250453, 0.03841361463336008, 0.005259134939738682, 0.014829983336052724, 0.039531307694103034, 0.011950881220400333, 0.016759402750592147, 0.03444912111652749, 0.022850694733538797, 0.04747140573869858, 0.07059477655483143, 0.025961250233064805, 0.022478363909093396, 0.019090804969891906, 0.025370441310639893, 0.00985591028750475, 0.05391874370564308, 0.0140375392511487, 0.024224670470825264, 0.028081746805193167, 0.039950533770024776, 0.037190412769892385, 0.022760748131466762, 0.025269833227087344, 0.018071009245301996, 0.04033367535365479, 0.0519761216959783, 0.03967780340462923, 0.03278963141409414, 0.007726781053601631, 0.04258519025253398, 0.043701176797705035, 0.014691721647977829, 0.04930147235946996, 0.023536919250286052, 0.03531805984675884, 0.016872027689324956, 0.0472133520857564, 0.04105646103354437, 0.03479207646367805, 0.033380632022661824, 0.027058222530675784, 0.04564695738788162, 0.051858789420553615, 0.02903649477022035, 0.052085674567414184, 0.016795393944318806, 0.03324300137215427, 0.03282045725999134, 0.043651396076061895, 0.032279298441218476, 0.06677085174513714, 0.03897718885647399, 0.0514451239391097, 0.04680237699566143, 0.09666514370058264, 0.04650622360142214, 0.030106788767235618, 0.0483886086648064, 0.08727404262338366, 0.04496694655556764, 0.02492733419473682, 0.043599091204149384, 0.013669992946753544, 0.030523707824093953, 0.03431490010448864, 0.019922378472983837, 0.028774936483906846, 0.022030478210321496, 0.04340822608875377, 0.03139830553638084, 0.014222489237519247, 0.01740132910864694, 0.03059033996292523, 0.011174449713767638, 0.04259500865425382, 0.025472783051165085, 0.008828189273897027, 0.03121445308040295, 0.019371901672067385, 0.009067522145674696, 0.03891079420489924, 0.012617555446922779, 0.0196742924994656, 0.01573103034336652, 0.11792009031133992, 0.0332818441092968, 0.01861082117206284, 0.028955236809062104, 0.018736419700352207, 0.041214342561683485, 0.02682203466870955, 0.056929929448025565, 0.06835560420794146, 0.03804629309368985, 0.03414165654352733, 0.015961737338719622, 0.03700295050761529, 0.06565696187317371, 0.011640600727072783, 0.03645229559125645, 0.05156087183526584, 0.11455813928374223, 0.006117017790009933, 0.037472228719187636, 0.02175174789902355, 0.04264240093263132, 0.030908528781895126, 0.020210509886965156, 0.05965456645935774, 0.019467575109696815, 0.31936005183628624, 0.1593181360512972, 0.15512002632021904, 0.130176129085677, 0.16405158277068818, 0.22009850745754583, 0.13364119029470853, 0.09327683158751045, 0.07817066075014216, 0.08729663783950464, 0.12336179188319615, 0.18143353291920253, 0.19004307022052153, 0.07245966898543493, 0.15223207271524838, 0.18657874182931014, 0.1424970222370965, 0.16741742858929293, 0.12404684083802359, 0.12260845516409193, 0.1978351899555751, 0.17151469444589956, 0.1264678809259619, 0.07091201203210012, 0.29109437284725054, 0.13095742144754954, 0.14488637473966393, 0.13015934212931565, 0.1405603882989713, 0.067127462609538, 0.07547638818089451, 0.15498606993683747, 0.08244585205933877, 0.14901458179312094, 0.19068020103233202, 0.13871988920228823, 0.07157931051083974, 0.2293554757322584, 0.0765570637636951, 0.18028992999877247, 0.08311494865587779, 0.08832298312336206, 0.14355472262416566, 0.13670949850763592, 0.09887897954987628, 0.11631995545966284, 0.14921920081334455, 0.11042316723614931, 0.14485186444861547, 0.19847747763352735, 0.1309815365821123, 0.11200937854924373, 0.11659818195870944, 0.16097144090703555, 0.1127159031374114, 0.10451263867850814, 0.16299829286124023, 0.12989345139690808, 0.17045917894159043, 0.14219473488628864, 0.07038723304867744, 0.12804432133478777, 0.1474220058215516, 0.11982745224876062, 0.15883484269891465, 0.1606281293290002, 0.11448910513094493, 0.10657822141157729, 0.11200105970991509, 0.1648489564125027, 0.1518844049423933, 0.15959892741271428, 0.0886721776000091, 0.09693809119718415, 0.11172582555030074, 0.15223089206431592, 0.1018766929794635, 0.08441753911652736, 0.12283577796603952, 0.12369293054299695, 0.07059114639248167, 0.1543044950813055, 0.1706410398972886, 0.0910966850018927, 0.12208913160221917, 0.1373991072177887, 0.05624770998422589, 0.05593080359644123, 0.06503059941210917, 0.1420227669711624, 0.13109402411750384, 0.19425342072333607, 0.1619431030537401, 0.12699895671435765, 0.0772732167637774, 0.14027563429304532, 0.13819057760494097, 0.12793598643371037, 0.15945399233273097, 0.06987823678978852, 0.19918909801968507, 0.2140395561499255, 0.16177982038685254, 0.18011790780084475, 0.1260808174099241, 0.1327773473624672, 0.11020032276532479, 0.21657198454652513, 0.09828152268060616, 0.10216784557061535, 0.13707262330821582, 0.10355679996843849, 0.07248225741620574, 0.1773046473307269, 0.09979294586394515, 0.1329959984868765, 0.17386271059513092, 0.13736182850386414, 0.0921457815649254, 0.19899779185652733, 0.15965740356062139, 0.12761183668460163, 0.14349171386233397, 0.1678863369992801, 0.2674836612173489, 0.13387947822255747, 0.16568815495286668, 0.11867109286998, 0.2951958456209728, 0.1356111674436501, 0.0995322119976793, 0.10356919001787901, 0.18461462722292968, 0.15276123503489153, 0.10769646747836045, 0.11366384369986397, 0.0655088716053537, 0.12377111134784562, 0.0920828745833465, 0.14582792350224086, 0.19559386665267603, 0.12603830040565558, 0.1765576616993972, 0.07914598698594741, 0.09059612293328557, 0.0903781774852957, 0.10905317110674721, 0.0720258883333632, 0.1561419271997043, 0.11808877411697592, 0.18739431378032478, 0.11771122366189957, 0.07023906814200537, 0.12258528997855526, 0.09267548671258347, 0.09990294317581824, 0.1340551780802863, 0.11108663877738373, 0.17402219346591405, 0.13568719050713948, 0.10094038929258074, 0.10782924999615975, 0.08672748266586236, 0.16344669594296388, 0.08518982731870242, 0.15235829379941734, 0.08615386951714754, 0.20770891942083836, 0.13054488572691167, 0.1918438614479133, 0.09878668521663972, 0.09774350547896964, 0.0765163516625762, 0.09711246112627642, 0.13865048864058085, 0.10746241360902786], [0.02083500468039087, 0.0694469463612352, 0.06698219504739557, 0.02236518935699548, 0.017300071327814033, 0.02419436370421733, 0.08070182028625693, 0.005159429731845323, 0.03186640648969582, 0.049729044416121075, 0.05074448224955371, 0.0833241884995784, 0.04995455552956887, 0.017831445671617985, 0.031217906823647872, 0.06966434219585997, 0.054753172144825966, 0.02355900386880551, 0.06759797236216919, 0.04131546463551266, 0.062358942415033064, 0.0362309235414224, 0.028465758609984602, 0.017162705305963755, 0.039041788782924414, 0.07668038071798426, 0.04649062408134341, 0.0220267852834825, 0.033425751208726845, 0.024451905063220432, 0.048739424840148, 0.04686183701934559, 0.08140518290123769, 0.045487525407224894, 0.014678078005090356, 0.0369943636469543, 0.023208450625783632, 0.03404872438737324, 0.031000826507806778, 0.04163525479712656, 0.02558332828006574, 0.07535613141953945, 0.006134556223904448, 0.022140517930633256, 0.031118769464748244, 0.0420609608824764, 0.0502905999975545, 0.09540997605238642, 0.09910592237221343, 0.02673875636953328, 0.0687391325565321, 0.029263308670903956, 0.05560042489586132, 0.01798555624139096, 0.018578215868079236, 0.046539604131664546, 0.0158783623483032, 0.022555023099162748, 0.03619478476632919, 0.03131193481385708, 0.02018874078722937, 0.03604448586702347, 0.018513761826657822, 0.05126997030207089, 0.025567328424326012, 0.026966879842802882, 0.06296133901923895, 0.014362898488928164, 0.055051164368965795, 0.06514265947043896, 0.00860850338358432, 0.025323702122217844, 0.065229586591678, 0.033285484449671845, 0.008479770871677568, 0.032491774896958044, 0.023092980928985134, 0.02199548446307225, 0.04908312996849418, 0.041499632610274215, 0.03610336574326668, 0.020385521031650047, 0.0065458023039224955, 0.057282265541808944, 0.10484491727714028, 0.03068909394953932, 0.023883771084781204, 0.033937373398137946, 0.03775292508570211, 0.018713744756366526, 0.01649933384864458, 0.0034567779927913633, 0.017263074205922227, 0.027636602387896607, 0.011111721695799912, 0.07442575812871967, 0.040990466717630625, 0.04333859482514007, 0.01148790235830737, 0.06734755901353699, 0.014402053352179272, 0.024678284701492106, 0.048885068989225795, 0.03398013806768826, 0.04174807481467724, 0.08509016409516335, 0.04832844975005303, 0.042653328739106655, 0.0454018739318209, 0.020986721717885563, 0.14699074253439903, 0.05772391041474683, 0.02522300582911287, 0.02291908597440592, 0.039889547042548656, 0.013542766782588192, 0.04166762091751609, 0.015418719333995665, 0.08779817021318845, 0.003688369628175029, 0.028000278498179147, 0.07042030484548636, 0.06918350514024496, 0.02416280673683754, 0.04201817924955061, 0.04724769952840038, 0.06566050382597105, 0.008578196616976388, 0.019517781612064158, 0.025414691971881048, 0.017506668277617012, 0.015214020585907357, 0.016392473064895188, 0.018657769010003124, 0.051850745387907536, 0.016372875277219073, 0.013026043706174408, 0.05966729577630758, 0.01840521827606218, 0.04861396371519991, 0.03694674405934555, 0.03466608268874032, 0.057436103001236916, 0.01192558543490512, 0.02818170519146536, 0.029727572508688484, 0.046376250218600035, 0.02363449937131788, 0.0034475679401241776, 0.013189805588418884, 0.027606606051059704, 0.02450262725220195, 0.019615483869399344, 0.043392538359122615, 0.027665217905970554, 0.009997974316190397, 0.030944748981190578, 0.012490043449880821, 0.014037951461172529, 0.014622197253629565, 0.0026099866455686943, 0.013790245467264737, 0.04684584055628095, 0.04716590213190232, 0.03615485976583191, 0.06830546047006335, 0.029577561986765692, 0.03814871456207974, 0.06036511476018599, 0.061376484776181836, 0.0677105277510626, 0.024423508372689997, 0.08152651174792222, 0.08187261210488421, 0.06692969000765256, 0.03714028260271464, 0.03915602693866406, 0.0015093111370723428, 0.016685956423836093, 0.01903600139277322, 0.05963041739804404, 0.03867010426308427, 0.044967906682619026, 0.005791163221666855, 0.008434294606558979, 0.0691488455714924, 0.05622637684323958, 0.04912906678925667, 0.020614563919869915, 0.01600649011587458, 0.06031123907970531, 0.021670133706980517, 0.060853307135403156, 0.0335960160009563, 0.01726405638536172, 0.007500810232678694, 0.014761078104908978, 0.039129265517528565, 0.047196069798831425, 0.029176137277058194, 0.026795263069548776, 0.04474415976021971, 0.057356911179210456, 0.02883272391877004, 0.05558243353984185, 0.019928760094834224, 0.07487475153590951, 0.01815596522231187, 0.025963731974895512, 0.04565895727968641, 0.03656807741416352, 0.051659476544175825, 0.04610188119113445, 0.028948807689760412, 0.018201296450570226, 0.027526437138606395, 0.041545355692505836, 0.03963980883626001, 0.05869859204228435, 0.004774488334078342, 0.017318780234615718, 0.03910276533237525, 0.06883908076477901, 0.07921588287821837, 0.05989016738853284, 0.023447142281968678, 0.09557611535170249, 0.02068621552150164, 0.024240780588505522, 0.05893466794597251, 0.026256097447393194, 0.013343981467187405, 0.032343559100159576, 0.03188451998201864, 0.026231934815379124, 0.06610496461923633, 0.027081250312871168, 0.0033055528931851897, 0.007985206204466522, 0.04471439921430179, 0.029080826855663742, 0.022715874914345995, 0.04415624309331179, 0.035045495722442865, 0.023240216242681657, 0.12176145347101347, 0.04576769930177501, 0.03632356732019356, 0.03549356971468244, 0.04514485165210707, 0.02732190802427275, 0.010614325841223555, 0.0668773071042129, 0.03275371655555708, 0.020837540705023066, 0.049918623707656345, 0.039819406877670965, 0.030626889251704727, 0.04003260936588049, 0.04368365363084844, 0.05871090745287282, 0.03410493762099317, 0.016223285447007844, 0.01010428209389959, 0.051739882943885665, 0.025473205439214195, 0.02759304383237447, 0.03588745590033276, 0.0517859520789768, 0.010770732403865882, 0.0612571711785027, 0.009403663304900485, 0.08145443097289119, 0.02371010683210833, 0.05176316348037549, 0.05713486737970795, 0.027009066061249802, 0.05883448225046907, 0.02855537612257259, 0.07918473812086241, 0.023059595309730088, 0.05356487751539264, 0.05131824128329754, 0.036739743381206474, 0.11862611956894398, 0.009369174218071359, 0.09053885457771164, 0.03523842019162007, 0.029141226650348732, 0.06135428311037166, 0.03081732689003859, 0.03253129277644413, 0.029885657597333193, 0.03400884688432727, 0.06961625441908836, 0.034541211889258454, 0.02779061796276697, 0.045921339986047575, 0.04985093305419598, 0.021700162274230803, 0.061995573341846466, 0.0149092158701803, 0.007836316961662045, 0.021514545627204434, 0.026737562147900462, 0.011050195532983966, 0.024443735501595905, 0.00801141801223691, 0.01844948759701635, 0.06355140664215599, 0.02935399826882141, 0.04332588925691588, 0.0024276615295093507, 0.04917816219053098, 0.036301894911697934, 0.061381363442965915, 0.03918349064354386, 0.1060400345761861, 0.046507054806819985, 0.053038361482322216, 0.01994299915220056, 0.04985131981915661, 0.008079569221341183, 0.04779236637321966, 0.08356342637645346, 0.022764666671199456, 0.0538673752120563, 0.0104247236491314, 0.057169744079666476, 0.03229852133829679, 0.039033296917166026, 0.012391133400212442, 0.02720990733775709, 0.03238525507705552, 0.016138020736564482, 0.01949215164807226, 0.06021920937512602, 0.023278032695608478, 0.006533936422783881, 0.05707364995032549, 0.017715938655393462, 0.038445017234023125, 0.0304840745936547, 0.04260208238182323, 0.03235403568084751, 0.06108985122825418, 0.12561796153230326, 0.04134909961638706, 0.0212263480560588, 0.021192328006561314, 0.0423630819922047, 0.00952658586071006, 0.13417856288807734, 0.1249867882579565, 0.17098680777209146, 0.08281316342098372, 0.0788384952715465, 0.0989850481439914, 0.1844209868993078, 0.06323805917054415, 0.12562313196914537, 0.2158527374267578, 0.1445178488003356, 0.15117346309125423, 0.1264194878084319, 0.08841489069163799, 0.13634302174406393, 0.1420340035110712, 0.25089559704065323, 0.11583299801817962, 0.11791979175593172, 0.07740972443882908, 0.1824964987380164, 0.10003839233624083, 0.11028404041592564, 0.08652728769396033, 0.11016042490622827, 0.19636085549635546, 0.10524278307067496, 0.12089108303189278, 0.12395352870225906, 0.0760012621592198, 0.16032543485718115, 0.14750314503908157, 0.2575661391019821, 0.10356359210397516, 0.11247837516878333, 0.16518523836774485, 0.10715435871056148, 0.12456494303686277, 0.1484652262713228, 0.11910361823226724, 0.21166833410305635, 0.15312761680356093, 0.10578073241880961, 0.128543031002794, 0.1390789427927562, 0.12870207961116517, 0.151185825999294, 0.1998412651675088, 0.2144029252231121, 0.1465521374983447, 0.13267005740531854, 0.07965408757861171, 0.17790169029363564, 0.08426816641752209, 0.09295922970133168, 0.10424031543412379, 0.06477332607443843, 0.14474741076784475, 0.15352898383779184, 0.13754297021244252, 0.13792665462408746, 0.13577841275504657, 0.10687877171273742, 0.136385850874441, 0.09932591699595962, 0.08280276826449803, 0.12561557308903762, 0.1840984656342438, 0.11911640183201858, 0.21945064222174032, 0.16122008327926907, 0.11896936329347746, 0.1406246998480388, 0.15026456543377467, 0.08544518040227038, 0.09592994422252689, 0.09465373520340238, 0.082663519307971, 0.08959286141076259, 0.20153646277529852, 0.07226431875356606, 0.11398571357131004, 0.14307117142847606, 0.2137750360582556, 0.23523720726370811, 0.08823921797530991, 0.10212144056068999, 0.11431143752166203, 0.10768992640078068, 0.1314664041357381, 0.12751220060246332, 0.08576487217630659, 0.11638335777180535, 0.15411667658814363, 0.1183553569551025, 0.15846687315830163, 0.1983443626335689, 0.11235300903873784, 0.0965096370450088, 0.13620374564613613, 0.09738204987453562, 0.11464500533682959, 0.13084204335297855, 0.2202985802931445, 0.08420529336269413, 0.17354443695928368, 0.14464181714824267, 0.24592749934111321, 0.16258767060935497, 0.10202502751989023, 0.206469792340483, 0.07812708523124456, 0.10758580520216908, 0.11456272618046828, 0.1656411460467747, 0.08784424274095468, 0.26671957650354927, 0.18582688431654656, 0.15919996239244938, 0.11535207953836236, 0.10227416522268738, 0.12285781678344522, 0.16540619651121752, 0.10231418521808726, 0.1649280735956771, 0.16442996103848728, 0.14505078377468245, 0.07663561097745385, 0.06966479002897229, 0.12243483162352017, 0.06571310386061668, 0.07684461333389793, 0.11764476794217314, 0.09214278922549315, 0.1297982529337917, 0.11231860731329237, 0.06765638744192463, 0.10116163242076125, 0.13070976973644324, 0.08828232530504465, 0.07597915548831224, 0.31155589489000185, 0.11722886668784277, 0.20659962323095116, 0.15512218406157835, 0.10821619816124439, 0.1984325721859932, 0.15522289222904614, 0.23348837824804441, 0.11314013680177075, 0.12425817735493183, 0.04753087254773293, 0.1784030869603157, 0.17219706997275352, 0.07785793074539729, 0.1628696426217045, 0.08674389642796346, 0.10802800647382226, 0.11044624421213355, 0.10945774761161634, 0.15184574201703072, 0.07697402353265456, 0.11394345441034862, 0.1501296998134681, 0.06496478830065046, 0.12272058986127377, 0.0855768026251878, 0.11149216523127896, 0.09980920356299196, 0.14746350502329214, 0.15699244370417936, 0.1498517311577286, 0.1743307097681931, 0.11796703136393002, 0.09086881937193018, 0.07881413586437702], [0.044049380613224845, 0.04794896886284862, 0.030644941675875868, 0.040545697190931866, 0.0354500145518354, 0.04758129448496869, 0.03798787122858422, 0.01599021884612739, 0.01057325750921986, 0.09087515010365418, 0.08180182054638863, 0.02520687535538205, 0.06323153166366474, 0.06586755200156144, 0.011189837191653038, 0.03319517143868974, 0.027245038488347615, 0.035567173800830326, 0.10197662083165986, 0.06273538685802903, 0.03434367338195443, 0.06563806467290435, 0.010669727377327425, 0.028859621046909263, 0.020875760886285986, 0.014275864498423678, 0.10009190839316164, 0.030514418679688658, 0.01420391518955252, 0.015045767650008202, 0.03474651283717581, 0.07090683480990784, 0.04944203767393317, 0.05496831524318882, 0.035019789423261366, 0.026736522292984382, 0.07555785309523344, 0.04483034049293824, 0.015403581217729619, 0.03493441953989012, 0.033268270016248734, 0.046068605833819935, 0.015851928320314203, 0.02711249515414238, 0.03841353999450803, 0.05491595269579973, 0.047729106553431065, 0.0373433749191463, 0.06710319141192095, 0.03730615388069834, 0.01914832947243537, 0.012604108579190714, 0.02657670185102948, 0.03856102636616145, 0.018892140094456927, 0.03898954837183867, 0.0231042191652315, 0.022853641271857277, 0.038275509008339474, 0.04842212490205254, 0.020002879867596284, 0.015641657103385245, 0.017948979811210717, 0.0021031146253725247, 0.06299927591213159, 0.015845723117568662, 0.04711206716352275, 0.03707272426358291, 0.019610593328252435, 0.035022537490086894, 0.0320552292146853, 0.03597471211105585, 0.0166995831033481, 0.025996512001646415, 0.06504242627748422, 0.040508170811725516, 0.0238661274779588, 0.031854637299797366, 0.02715972119144031, 0.07195094414055347, 0.04904377493741257, 0.05302605964243412, 0.07174124967839036, 0.018397438872073377, 0.003482687852478453, 0.02829935637834881, 0.03440175258687564, 0.028271677238600593, 0.06604346220514604, 0.029040660975234847, 0.02853818204520004, 0.06407916439431054, 0.01705473511745887, 0.03163019487900393, 0.0482672187499702, 0.06277729996613093, 0.01601300574839115, 0.024906431923487356, 0.02981000772810408, 0.02308576301272426, 0.020810477335804274, 0.014642327691295316, 0.03181603204991136, 0.04874819490526404, 0.06232747874621834, 0.03983191227806466, 0.04187143587374261, 0.022633979130270224, 0.035492945462465286, 0.028551182776157345, 0.06538409580077444, 0.042438653829906664, 0.05195806248645697, 0.011892020852038903, 0.017025273126949157, 0.035866177042147944, 0.03475326086793627, 0.03975009113284094, 0.014770202704572251, 0.036915802862495184, 0.02367989336406546, 0.05413378502375313, 0.04984333346198712, 0.022477344410227876, 0.047799915075302124, 0.04838322788210852, 0.017757731323529567, 0.05192402716992157, 0.013706781419127114, 0.04427242185920477, 0.0728680385010583, 0.06481716622199331, 0.12132269915725503, 0.01610864695560719, 0.009325747976877859, 0.034105643297412565, 0.050920602798994095, 0.030366721962179457, 0.0665504839271307, 0.025132674158417752, 0.028105760159503137, 0.03610769479668566, 0.034582049519355805, 0.038131795291389735, 0.0410008211620152, 0.03993510049102562, 0.05460608610883355, 0.05438018823042512, 0.03174393091882978, 0.03634098870679736, 0.020082487292321663, 0.042563137864427905, 0.035636991661574156, 0.041463585437408516, 0.022349406632461717, 0.03635924808414919, 0.008993623744962471, 0.065282200197024, 0.04115983923631055, 0.03703202912583947, 0.023264872508921793, 0.11964812901403223, 0.036735706097845516, 0.038668496135090075, 0.051388649469507594, 0.05651512063507523, 0.00963312603666314, 0.049608326250953336, 0.03671468508296779, 0.03009002555959991, 0.05736075168741601, 0.03690492594614625, 0.10459542673613344, 0.06653195313577141, 0.09051240528268473, 0.0328071206541998, 0.018726472376978824, 0.019370924581640532, 0.029241229141397134, 0.06731993585292782, 0.03382033628544637, 0.021138464200443456, 0.033816017410052676, 0.01397164332281266, 0.04160055112359779, 0.04338046382846577, 0.017505587710599815, 0.028209421650639603, 0.009612035471946001, 0.05587801017931529, 0.0552547350525856, 0.02919662224927119, 0.02432028792931565, 0.017493236676922867, 0.08029486212347235, 0.016830718477389643, 0.056590166608137746, 0.013342243569370891, 0.029372125331844603, 0.035905593141381226, 0.061283111572265625, 0.03881844558886119, 0.08999335313481943, 0.04298917982461197, 0.02356115143213953, 0.035222410157855065, 0.026654675702697465, 0.010710844903119972, 0.0581186210204448, 0.05015865886317832, 0.05182950724182384, 0.032551791319357495, 0.007249749731272459, 0.021931137290916274, 0.048541747233165164, 0.01657978944214327, 0.08458532047058855, 0.05128829753292458, 0.035906570231808085, 0.029849892016500235, 0.03936684098360794, 0.022805363505280445, 0.04499124489458544, 0.05690640803160412, 0.03993236938757556, 0.039294078280883174, 0.029783100421939577, 0.04948829679882952, 0.08407552354037762, 0.06330384314060211, 0.020040969430868114, 0.08396706650299685, 0.0889610435281481, 0.03427057480439544, 0.04421506868675351, 0.029410313282694136, 0.1387622162167515, 0.04386650864034891, 0.02573657880670258, 0.011436063131051404, 0.03698067081027797, 0.04106064420193434, 0.03415242828694837, 0.032992299646139145, 0.04879926484344261, 0.031928231207919974, 0.027047328650951385, 0.08540328765021903, 0.008320221843730127, 0.02147299892801259, 0.012364857979784054, 0.07265839832169668, 0.04824511207906263, 0.03071363316848874, 0.00785853898352278, 0.07945803845567362, 0.04229710463966642, 0.012846614450349339, 0.058782764311347685, 0.0726094963029027, 0.015067054989880748, 0.03177747090480157, 0.033681450345154317, 0.014838166468377625, 0.04188258420409901, 0.009477903517628354, 0.01760883190269981, 0.02898009493947029, 0.02092503440300269, 0.08220890763082675, 0.033522021757172685, 0.01334589917678386, 0.043522430317742486, 0.00644536639863093, 0.02368451588388, 0.03246857239199536, 0.04819283095587577, 0.02772647774379168, 0.01840558977398489, 0.046559529312487156, 0.01300808203606201, 0.0736509050641741, 0.03448578575626016, 0.027593011601961086, 0.004718418016896716, 0.038677924379174194, 0.06455473601818085, 0.04514832575140255, 0.05766717131648745, 0.016234369316537465, 0.026492996074791466, 0.010954379603000624, 0.04806143943486469, 0.025134887878916094, 0.010639824339055588, 0.01741884209747825, 0.03941589228010603, 0.025500677625781724, 0.0034080585423258264, 0.018327588780916164, 0.032013889468674145, 0.04595502246437328, 0.05476829669039164, 0.02103040919506124, 0.04932406418291586, 0.04542887962556311, 0.0102901548878955, 0.08690443102802549, 0.004133843983124409, 0.035980557690241506, 0.0033281701616942883, 0.02899296335609896, 0.06808714182781321, 0.013565613904834857, 0.03223698499745556, 0.022867308663470403, 0.026147603090586405, 0.010190442470567567, 0.03896598285064101, 0.03488552091377122, 0.033769035645361455, 0.008282224730854588, 0.04831133709688272, 0.039717490917869976, 0.04653560756040471, 0.006167047449188041, 0.05093183594622782, 0.013544697214716246, 0.04884497435497386, 0.0049966703850909, 0.025447812962478826, 0.06022431195846625, 0.05317501164972782, 0.04571391522352185, 0.04377589028860841, 0.05325199144759348, 0.021900603215077093, 0.05418344021641782, 0.038677741174719164, 0.044799029494502714, 0.012518305281576301, 0.03263952250459364, 0.05643300771979349, 0.053366524766066244, 0.009392905980348587, 0.011713080989596034, 0.040457823513341803, 0.07703971250780992, 0.00912233250814357, 0.040281356911041906, 0.03215093318639057, 0.028918609488755465, 0.09247763947184597, 0.08139904215931892, 0.13729816834841455, 0.1399925494832652, 0.09780019707977772, 0.12058803572186402, 0.0920950746429818, 0.120236622435706, 0.07103482687047549, 0.21674229683620588, 0.16348336397537164, 0.08732772831405912, 0.11784925125539303, 0.0929644883477262, 0.13625912767435822, 0.11725261541349546, 0.12165732548705169, 0.09169919695705175, 0.16243449811424526, 0.12474962669823851, 0.09399955959192344, 0.10621636547148228, 0.07471692429057189, 0.23344527770365986, 0.10906298950846706, 0.13360659857945784, 0.2651737651654652, 0.09361227894467966, 0.08377945157034056, 0.12423007243445941, 0.11623042954930238, 0.1380591318011284, 0.1467880776950291, 0.11791012941726617, 0.115163297525474, 0.11233649349638394, 0.11848293510930878, 0.08341722243598529, 0.12283516728452273, 0.15983868097620352, 0.11546068585344724, 0.23304838900055203, 0.2033058921141284, 0.11158576235175133, 0.1197421739676169, 0.122654704110963, 0.10542403334485632, 0.18934382631310395, 0.10973161791584321, 0.1391916610300541, 0.09886164298014981, 0.10227164107241801, 0.18517873409603322, 0.11902717447706632, 0.1532342689377921, 0.2334919609129429, 0.1294153013399669, 0.10737567647759404, 0.197135525356446, 0.08488281057881457, 0.27659117536885397, 0.11388987728527614, 0.07481518973197256, 0.08049175941518374, 0.12561835508261407, 0.14956551151616232, 0.10595934319176845, 0.1784970233482974, 0.14267478484128202, 0.09534407673137528, 0.16519481928220817, 0.17026032746902534, 0.13952818725790295, 0.1385529695877007, 0.18117373543126242, 0.15608759011541093, 0.15212299142565044, 0.10684516387326376, 0.08691865312201635, 0.13685079663991928, 0.11362636142543384, 0.1456189075750964, 0.23317883057253702, 0.09489049642745938, 0.060537761210330894, 0.10806540732405015, 0.10380472309355225, 0.09079623648098537, 0.1982872299849987, 0.11098833262388196, 0.16547871833401068, 0.12831612889255795, 0.10995486950767891, 0.19889701583555766, 0.1045850587210485, 0.15822631892349037, 0.11007792861866099, 0.13738039322197437, 0.14825388975441456, 0.07435080036520958, 0.1426374382738556, 0.12582665176263877, 0.14125268400779792, 0.12157271217022624, 0.06913617053734404, 0.12192626962704317, 0.09895779817764248, 0.10234056665961232, 0.15639858985585825, 0.1768818793020078, 0.16043237197612012, 0.1031737398090107, 0.17410557184900555, 0.182967605601464, 0.10871977292533432, 0.08468589971640281, 0.16397387694035256, 0.10575576233012335, 0.043505701036857705, 0.0856031569253121, 0.0815847029111215, 0.1207632470343794, 0.11345121118107013, 0.05313065242288368, 0.09347190362002168, 0.06758603014584098, 0.08897729444184474, 0.14201474668724196, 0.12368006551904337, 0.16975251186106885, 0.15618733476315225, 0.20956104860774108, 0.2678999831633908, 0.20886469525950296, 0.09248596509652478, 0.1262405581240143, 0.15144896187952586, 0.1322650941354888, 0.13445445522665977, 0.12234778915132795, 0.09538828328784023, 0.1046411260696394, 0.09087225954447474, 0.09597502608916589, 0.15282207248466356, 0.13122038090867655, 0.09257983363100461, 0.14690177302275384, 0.18270843236574105, 0.11858676453786236, 0.19213647288935526, 0.10401617496141366, 0.11276184674352407, 0.07510531773524624, 0.08635353523173503, 0.17884090489574841, 0.1319121066480875, 0.15558110443609102, 0.1678436707173075, 0.1419328475104911, 0.08682711874800068, 0.2256927979843957, 0.10716376320591994, 0.09130879504872219, 0.08019266796431371, 0.11220080006335463, 0.16762075839298113, 0.0903098015114665, 0.16345976452742303, 0.09601851339851107, 0.12525774086160318, 0.1740083513515336, 0.22413732430764607, 0.16751539547528538, 0.17373988218605518, 0.1300812563193696], [0.03341189552364605, 0.04363430038626705, 0.04094654853854861, 0.02660423849842378, 0.04411122229482446, 0.023080180365858332, 0.037146732078066895, 0.03884683210136635, 0.018750909815675447, 0.05306696851870843, 0.048281674938542504, 0.06252333109400102, 0.03996013164786356, 0.04745803859883121, 0.008205590985848435, 0.06637282310319798, 0.034222117226038656, 0.07758650316723756, 0.017944398003497293, 0.027573693709980165, 0.03960317473060318, 0.022642964630254676, 0.02426550810092262, 0.02081452140451542, 0.04099311300420335, 0.018562246546415345, 0.04013699519314936, 0.02315241381126855, 0.039027946668543985, 0.04709478826927287, 0.039954418383006535, 0.017152303364127874, 0.03676814007173691, 0.012326453745897328, 0.04975740039455039, 0.03425354357542736, 0.014033690261255418, 0.01629003632946738, 0.018512148609650985, 0.0630837535219533, 0.04758282458143575, 0.06733016137565885, 0.0027626413336422828, 0.03332031025950398, 0.06630254044596638, 0.0008942977043001779, 0.007397478679195046, 0.05283648713624903, 0.024964417829843502, 0.02253060771285423, 0.010134684703578907, 0.022613631561398506, 0.020281613571569324, 0.021323738187285404, 0.06633521869246449, 0.03168431143941624, 0.03491995317329254, 0.025436732485624294, 0.023961790737562945, 0.028378288660730635, 0.03386537743998425, 0.03511942211272461, 0.047882285833890946, 0.03424372856638261, 0.032028389762022665, 0.05852460887815271, 0.05487039585464767, 0.07645640309367861, 0.006162491086537817, 0.06151639869702714, 0.0324942583351263, 0.0387953482568264, 0.040951983604047976, 0.01528836936423821, 0.01560842415450939, 0.015499069754566466, 0.05744321404823235, 0.028397055243008902, 0.056144979782402515, 0.05333787362490382, 0.13498145980494364, 0.019504675708178962, 0.037152007687836885, 0.04217741784772702, 0.03768314115170922, 0.015561204902561647, 0.10796526234064784, 0.033110663294792175, 0.05437870563140937, 0.007096449162677995, 0.05745891534856387, 0.04457768119339432, 0.03780876512506178, 0.010759576439990528, 0.038038876705936024, 0.0701888022678239, 0.04101767257920333, 0.024714038407962238, 0.08064999378153256, 0.014179873845673032, 0.04046077174799783, 0.029228723741003444, 0.02896704671106168, 0.03223133958610041, 0.03557917369263513, 0.040790254782353125, 0.0715077386370727, 0.02455510006153158, 0.04121897017051067, 0.03470392458673034, 0.012044593691825867, 0.06534495111554861, 0.10810987850917236, 0.03595525511939611, 0.03678654533411775, 0.005208139216327774, 0.05898918144937072, 0.027249566013259546, 0.00543832840464477, 0.006286545099490988, 0.026461138855665922, 0.04673357354477048, 0.00849050359933504, 0.017877541948109865, 0.07852405535855464, 0.016948247527969734, 0.03924182090642197, 0.038574834553790946, 0.049707656992333274, 0.006416408644456948, 0.03278383672503488, 0.016716515944738473, 0.04092238251385944, 0.048256474147949896, 0.07386679455105748, 0.04523975495249033, 0.05745612656963723, 0.03255430529160159, 0.058108748335923464, 0.02051854782205607, 0.09216094682259218, 0.07850031341825213, 0.04683584912813135, 0.014153196393246097, 0.07451259704040629, 0.019358812731557658, 0.04082343514476504, 0.0406060223467648, 0.03865785670599767, 0.07347576160516057, 0.02493169208589409, 0.01683450979180634, 0.0703937809116074, 0.02482728590257466, 0.033946123107203414, 0.033523911477199624, 0.02035476134291717, 0.008648611588536628, 0.01881182529697461, 0.03228908630886248, 0.07635450748992817, 0.03283179558015295, 0.010483316844329238, 0.020189441374636123, 0.03313440862776978, 0.044778751475470405, 0.030598845399383987, 0.03913389651903084, 0.06126495397516659, 0.0311698495809521, 0.020646717998066118, 0.03508470826117056, 0.06752984066094671, 0.03398060625685113, 0.03458776617688792, 0.05224051625866975, 0.025480942434764335, 0.035442543881280084, 0.03426169278100133, 0.029035646601447036, 0.06759681885263749, 0.009797839564271271, 0.042637203354388475, 0.02282244901705001, 0.025091999376724874, 0.019889942802754895, 0.057570805773139, 0.005614280168499265, 0.03710381473813738, 0.06117254429097686, 0.03703928605786391, 0.035081787167915275, 0.015355423891118594, 0.051674407707261186, 0.018419839009376507, 0.006631754031072238, 0.05940029224646943, 0.08674465638718434, 0.04234475136867591, 0.00914253419198628, 0.03785097339589681, 0.026480319344305565, 0.06831917366279022, 0.017238899699545333, 0.03688334853255323, 0.030237237124570777, 0.0264797748199531, 0.048402807010071616, 0.005523565125518611, 0.040284369606524706, 0.07264022715389729, 0.04612908026735697, 0.023794871122975434, 0.01655922643840313, 0.03767929046547838, 0.006440056013941232, 0.05002122498782618, 0.03433240970064487, 0.041041292383202484, 0.04123912944591471, 0.03259093939725842, 0.008661594507949693, 0.023532803935397948, 0.0673713009538395, 0.0019828593483128187, 0.0583881622712527, 0.024870350823870728, 0.07607085949608258, 0.029686853622219393, 0.0534192096175892, 0.06311177701822349, 0.016785409301519394, 0.024226285384169648, 0.00873939024417528, 0.014748871259923493, 0.001901762539221506, 0.041965314586247714, 0.020224475833986486, 0.03707786416634917, 0.030913804391665117, 0.09147774348301546, 0.022535348976297036, 0.055574135056563785, 0.0426528537645936, 0.06648056089345898, 0.031699439377657006, 0.003411970296708335, 0.020835869812539647, 0.050434300143803866, 0.031902843820197244, 0.004356897527551544, 0.01779982085073633, 0.09788551607302257, 0.026929794511358653, 0.03264075404565249, 0.09883858636021614, 0.08108804920422179, 0.04563221621460148, 0.02579358931896942, 0.040914925414004495, 0.008011105886128331, 0.0775885862697448, 0.0477079566168998, 0.07741659799856798, 0.06818303918199879, 0.02508665421711547, 0.08885810976581913, 0.018166826871622885, 0.009591061106350805, 0.0164516803342849, 0.030145234561392238, 0.023772771237418056, 0.039809381522770436, 0.06542887232665505, 0.04303246357345155, 0.023948900268546174, 0.028838063989366804, 0.028088092803955078, 0.08460334236068384, 0.02728735362844808, 0.0151580719809447, 0.03944234836048313, 0.06131032082651343, 0.052506634300308566, 0.052275274215000014, 0.03976321739277669, 0.013931343431717582, 0.020588930563202927, 0.03036083567089268, 0.016629554896748493, 0.021261626788015877, 0.03103027832029121, 0.054676246629761796, 0.0640378687530756, 0.047995709747608216, 0.008064160539236451, 0.020851124976096407, 0.01884969094369028, 0.030631415080279112, 0.035585660487413406, 0.06376026650624615, 0.034142257047018836, 0.020343792824340717, 0.03840757567169411, 0.04901526289592896, 0.014918070752173662, 0.03248448743085776, 0.0798772916729961, 0.004130685402612601, 0.037383890245109797, 0.01497278781607747, 0.04844918827127133, 0.07928778723414455, 0.01647291169501841, 0.016010705514677932, 0.05169899442366191, 0.0167623883046742, 0.04835815601316946, 0.026596289460680315, 0.023902707300814133, 0.003668513997191829, 0.03509217893172588, 0.013290107483044267, 0.027015781861596873, 0.030114116945437024, 0.05721270213169711, 0.03431176527270249, 0.006803266903651612, 0.035673188112143955, 0.03151949867606163, 0.023442302630948167, 0.029628916909652095, 0.051024092960038354, 0.037641472316214016, 0.1126136886222022, 0.048346536100975106, 0.07493660000285932, 0.02476768847554922, 0.048583032696374824, 0.01087470178026706, 0.012110875536953765, 0.019414479744487574, 0.038030791961188824, 0.044822493235447576, 0.006805907677127314, 0.05792359648538487, 0.05611549065049205, 0.027392183896154165, 0.010608262282663157, 0.029380332212895155, 0.030630454953227724, 0.012973369880845504, 0.11920903543276445, 0.18721371489976132, 0.15310000042830194, 0.05719897536826985, 0.14547067481492246, 0.08049542350428444, 0.08846160782767193, 0.11413613121424403, 0.14404680979038986, 0.0776528435360108, 0.1232917263571705, 0.1969711570335286, 0.12534875954900468, 0.21299888699182443, 0.12297079286405019, 0.1514785731477397, 0.1215278474347932, 0.15928541709269795, 0.08023230798010315, 0.07930730190128088, 0.12718140121017182, 0.1680972392537764, 0.16540432375456604, 0.11636560729571752, 0.11949719568448407, 0.09292290772178344, 0.10617614870092698, 0.09393848465489489, 0.10433754271694592, 0.10629644617438316, 0.16938779928854533, 0.10461535530963115, 0.11853499231593949, 0.11563194809215409, 0.17995282023080758, 0.11122569774410554, 0.07263754694057362, 0.15614521130919456, 0.1072772414024387, 0.20531880695905003, 0.08269758176590715, 0.12002139112779073, 0.0922589340646352, 0.11359850077756814, 0.23242989076035364, 0.06729736777820758, 0.09672971309295722, 0.16311406450612204, 0.11000362903411899, 0.08968187841985907, 0.11061531478273016, 0.12143857936773982, 0.09519185418529169, 0.08629389878894601, 0.15722067574305193, 0.08798440771975688, 0.07465698929237467, 0.08376560267060995, 0.14628906947161469, 0.12515625916421413, 0.09269606667969908, 0.1113560443211879, 0.13286057646785462, 0.10050280884440456, 0.17526763092194284, 0.15737071340637548, 0.13837150218231337, 0.19191879885537283, 0.2605869227222034, 0.09786997762109552, 0.2006220282720668, 0.1065416212326714, 0.15744337093617233, 0.096496982366911, 0.1080362099621977, 0.08838767465204, 0.185026633686253, 0.11058139481714793, 0.12975228897162847, 0.2541757438864027, 0.22163142663027557, 0.1558505099798952, 0.1363667297576155, 0.1169473153672048, 0.1664407452834504, 0.13727097266486712, 0.21074570289679936, 0.20200455694326333, 0.11446014525634901, 0.13866990831281456, 0.1707740734730448, 0.13103063537606172, 0.13651976654572145, 0.07479304234896388, 0.07005459482648543, 0.11898541743201868, 0.11512924863823823, 0.11069204352263894, 0.14821875521114894, 0.08336291249309268, 0.12681434090648377, 0.13069915744875157, 0.10409178411854164, 0.1460868931774582, 0.16634277839745792, 0.18744774162769318, 0.2441350540944508, 0.05360126056309257, 0.23103020872388566, 0.11918078123458795, 0.08587347170604126, 0.15520696022680827, 0.17189065712903226, 0.11238234210759401, 0.14668337974165166, 0.1374240501650742, 0.10931803046592645, 0.18361566082707473, 0.11241314759744064, 0.07088661446635212, 0.11348939234656946, 0.16442472274814332, 0.23245657075728687, 0.17524549710963452, 0.19144923905176775, 0.19793549100203173, 0.08627871996057884, 0.14542438515595027, 0.12017019385738031, 0.10863606884543385, 0.13494661024638585, 0.1067863552431975, 0.12771128277693475, 0.08764633443206549, 0.2264727061348302, 0.12617885214941843, 0.1644710259778159, 0.1026189017242619, 0.15830023852842195, 0.11963416476334844, 0.1849049994988101, 0.0980727578114186, 0.1795196027628013, 0.0686692570203117, 0.09979082204933677, 0.13396485149860382, 0.11360958803977285, 0.11678790034992353, 0.10636914441628115, 0.15504948581968034, 0.13583021211837018, 0.06411638204008341, 0.11665128410926887, 0.11412045705531325, 0.10980358333992106, 0.16547244867043837, 0.10738478920289449, 0.23768994850771769, 0.10761543004108326, 0.08221961491342102, 0.213602036769901, 0.10736678766884974, 0.12263764574059419, 0.17206285574606486, 0.12777289375662804, 0.09792871161230973, 0.16352803872099944, 0.16684602067938872, 0.19436142992760452, 0.13157321911837372, 0.11371994497520582, 0.06773730274289846, 0.2107191857482706, 0.12647588763918194, 0.10136574253972087, 0.16196922665195806], [0.06205433447446142, 0.01784510967055602, 0.011313985351340046, 0.040502084352608235, 0.029198688388402973, 0.04131154270310487, 0.01156626467127353, 0.0760367631113955, 0.03682839398139289, 0.028778271483523504, 0.03663820740101593, 0.03277886984869838, 0.01237031424950276, 0.03204283577256969, 0.021188772483063594, 0.03284753080723541, 0.05117324852783765, 0.03284106436850769, 0.05164331044735653, 0.011022277209641678, 0.06608667810048376, 0.04754920317126172, 0.016387499403208494, 0.016200980304607322, 0.046721743286720345, 0.08045030092554432, 0.05894364496426923, 0.034997713286429644, 0.023873420033071722, 0.06016366449849946, 0.05621640916381564, 0.0599595204527889, 0.0501631371943014, 0.0325017391837069, 0.03635556024632283, 0.06216467783919402, 0.02999361591147525, 0.0027814229709162775, 0.054348449754927836, 0.04901279302846108, 0.04891406279057264, 0.016683155770546625, 0.06251315985407148, 0.017546221780191575, 0.032022907199071984, 0.060793250000902584, 0.04558206229869809, 0.022173640617568578, 0.029299579760325805, 0.0276206398515829, 0.03199229169903057, 0.017634684086910317, 0.06630195012050015, 0.0055458757810161585, 0.014025409589521587, 0.03042261628434062, 0.008094999107665249, 0.06773424933531455, 0.032607220845030885, 0.03481429848553879, 0.034405342037124295, 0.06739789274122034, 0.11110476244773183, 0.012008739053271711, 0.03731148377326982, 0.01889072704528059, 0.03714967013469764, 0.009403606477592672, 0.013910943276381918, 0.07637599669396877, 0.012752996973826416, 0.09123360658330576, 0.026458334809701358, 0.07521909448717322, 0.02803824083613498, 0.01655327059727694, 0.021501644980162382, 0.03348544532699244, 0.03717102363173451, 0.0215403927224023, 0.03187211636187775, 0.08962720206805638, 0.028627701170210327, 0.027741683713559593, 0.05247004769210305, 0.08013743521379572, 0.01127566338982433, 0.007831708860716649, 0.07494386032755886, 0.011449320008978248, 0.013881172552438719, 0.01676922624132463, 0.03947192570194602, 0.05581485892512968, 0.03185553975137217, 0.01487870215039168, 0.04141959261947444, 0.03374171782551067, 0.037549354402082305, 0.06038770319095679, 0.0869003598179136, 0.030741161334195306, 0.032922295188265185, 0.004065449773666582, 0.03792082857606666, 0.04852017321224723, 0.011500673235527106, 0.01832846918010286, 0.05833672931683915, 0.027656039023505788, 0.03728470199608377, 0.023246703037459935, 0.009749471891804464, 0.04311524823840175, 0.011139667160542948, 0.05850040553403752, 0.056646115213100395, 0.0345322009442108, 0.03236661572009325, 0.08751828130334616, 0.028664993454835246, 0.04499735849510346, 0.03602329182571598, 0.0837187837543232, 0.00722828003511365, 0.03463995909052236, 0.029500317560242753, 0.03792133069198046, 0.025279351377061436, 0.0420960004308394, 0.021306549198925495, 0.04149261995085648, 0.03862203684236322, 0.06304334676159279, 0.10238828802747385, 0.03858155205047556, 0.013193580787628889, 0.04386037129110523, 0.02274678896979562, 0.027875061645837765, 0.0054720689825314495, 0.00983323619168784, 0.08018692755805594, 0.06676212578479733, 0.016137416840397885, 0.08974643424153328, 0.01877326754453991, 0.06950082882706608, 0.04580733592488936, 0.03191166816811476, 0.01611144421622157, 0.047795277288449664, 0.036493513200964244, 0.01640225584352655, 0.019230340607464314, 0.07394167767571551, 0.024177875303264176, 0.015654632389279347, 0.03346863801458052, 0.03730644904343145, 0.010739714871825916, 0.014186872934390391, 0.037325332673000436, 0.018138713469462733, 0.012904443445482423, 0.0872513795537608, 0.002434813924732485, 0.09129356193755354, 0.02168515816863094, 0.031537130408521206, 0.015253445166828377, 0.03762831552220242, 0.017063155737040297, 0.015169886971956916, 0.014323865761980414, 0.057687846278505664, 0.00868732201135052, 0.028299534493791204, 0.05799453732158456, 0.06751536072364875, 0.00971549509891442, 0.0683430852368474, 0.10913177260330745, 0.03888465364330581, 0.030822361619876962, 0.03885425527447036, 0.02002856581072722, 0.003515100834192708, 0.04995940366227712, 0.037093562074005604, 0.010021474528392511, 0.022405139802555953, 0.029219319245644977, 0.060223585925996304, 0.053313439578882287, 0.08236163907817431, 0.03667308410097446, 0.009782803228258021, 0.03726924157568386, 0.030900155659765005, 0.03865368710830808, 0.04102241214630859, 0.09469030824090753, 0.030655380937137773, 0.064048508182168, 0.037714034851108275, 0.02349021568495248, 0.01662302908620664, 0.02818103683447199, 0.02008096907021744, 0.008371764211915433, 0.07107700460723468, 0.0072487073318500605, 0.1284870518637555, 0.004284458825298185, 0.04251484991982579, 0.023872183403000236, 0.05276287626475096, 0.033722362614103725, 0.06387665561799492, 0.03378135444862502, 0.015392643233229007, 0.06524391725127186, 0.05013021467519658, 0.005508488925573016, 0.030150052160024643, 0.02636762146305825, 0.032964703626930714, 0.11056392932576792, 0.06123384992991175, 0.01830658981842654, 0.06472284985440117, 0.029021526287708963, 0.025204670116571442, 0.014445901981421878, 0.06319653282740287, 0.00861709872593305, 0.02508332091383636, 0.06404289669756379, 0.06339861412665673, 0.03798308077135256, 0.0187580361297088, 0.044132104210023365, 0.004868219465216888, 0.0194802331804697, 0.05369329366034695, 0.049196961003222635, 0.00989840948022902, 0.03511986994583692, 0.053627000789025, 0.026620407987918173, 0.02834038230191384, 0.016721413271235566, 0.09474830262895141, 0.025294613325968385, 0.0445116224166538, 0.06641254454318966, 0.051830504688301256, 0.023492230933957865, 0.04715155790160809, 0.029474166820624044, 0.01473818433337978, 0.06677893988255944, 0.05038867544914995, 0.024326571163588336, 0.027265808445268443, 0.03149581441123571, 0.05071369372308254, 0.009926321866389896, 0.03817937755957246, 0.08441666380635329, 0.018392275220581462, 0.028250496767993485, 0.018207455852202008, 0.01225172498795603, 0.08061380072363786, 0.11293200297015053, 0.038882512865321975, 0.07994302136025258, 0.022572887229866216, 0.035766893798219304, 0.04183757358363696, 0.035673822542386394, 0.015455780916714242, 0.04783640668860503, 0.020643064086990695, 0.02149736342419471, 0.011284201056696475, 0.003945354164378452, 0.04227089622457113, 0.062035735829600265, 0.020386496425739357, 0.017458951998768107, 0.03942201605864933, 0.03091621319098132, 0.029294561993862902, 0.03202527867896216, 0.051638866042984385, 0.07712625286408833, 0.016705062273623686, 0.05981630885175296, 0.04563812625461391, 0.03965655168784516, 0.006211748063963438, 0.02941986027040652, 0.013528541295922228, 0.005762966274882534, 0.022382295224815607, 0.028458006347396543, 0.054155426898172924, 0.037007228670907874, 0.034811519884637425, 0.014925437946138638, 0.07345064902412039, 0.027626924782193134, 0.0366660850122571, 0.013335888240752476, 0.022658966182331954, 0.06168075344924416, 0.022215619882834808, 0.03887641622817942, 0.026296042803941027, 0.013968045390876276, 0.02484813898003527, 0.006968543615325221, 0.054119339013206105, 0.05731531698256731, 0.024265930488971726, 0.043981734064540694, 0.023921536647581627, 0.03233032427462084, 0.04140863088624818, 0.011140478009890233, 0.037944329636437554, 0.02555259403639606, 0.015782758460513184, 0.04272829668064203, 0.0250009416735598, 0.030002382583916187, 0.026362076135618345, 0.04664381014715348, 0.029511554100151573, 0.0427989423541086, 0.06642342824488878, 0.024057296237775257, 0.016010856488719583, 0.01685951550358108, 0.010691156361385115, 0.1039768402863826, 0.07066094728985003, 0.03585353593475052, 0.042323472510491095, 0.10662196656422955, 0.13434799308223383, 0.1487483246518033, 0.1944791150412389, 0.06917260108249527, 0.12835542964083807, 0.2095013918089015, 0.132557461304324, 0.13515930383333138, 0.21395159087010793, 0.1390747765877417, 0.1430795309799058, 0.09539439010300807, 0.1910992506891489, 0.18601193438683236, 0.10820780468306371, 0.14428663120738097, 0.105077193384724, 0.1259618837918554, 0.22327762043901853, 0.11305010877549648, 0.11005069222301245, 0.12128347983317715, 0.12203631443636757, 0.12224894016981125, 0.11358276555048567, 0.13720538546996458, 0.1513316160334008, 0.1918916031718254, 0.18114481626876763, 0.16082740149327687, 0.15805739084524767, 0.14738425213311399, 0.11386736349335738, 0.14391073637775012, 0.19381253580961907, 0.11264434483434473, 0.2823465365384306, 0.058019758468227725, 0.15389797118093285, 0.08561503807348864, 0.11258132928716284, 0.10831666205610548, 0.1349782028368541, 0.14042284925069126, 0.11641889943608216, 0.17189521688435758, 0.09246619258608137, 0.10002808538930756, 0.08240330112831933, 0.19173639507165977, 0.07847797604543821, 0.15848740562796593, 0.16566460978771957, 0.14352963039917604, 0.0791804769209453, 0.10378152398126465, 0.241911169141531, 0.06809960651610579, 0.1562850980886391, 0.06844445836863347, 0.15763790692601884, 0.19217102389250482, 0.10773584286549262, 0.12857389077544212, 0.09212900139391422, 0.14335948095789977, 0.10387245445911374, 0.08429428323038987, 0.1593342987554414, 0.11375853326171637, 0.14892686078591005, 0.10674081875809602, 0.12798199110797473, 0.15646660620612757, 0.0998908109696848, 0.1253383101097175, 0.20548054256609508, 0.12906345379139694, 0.13594336461808, 0.17378978165132658, 0.18466137828571455, 0.12341174563126904, 0.13909463052238735, 0.11405435417379652, 0.1401828649852957, 0.22526169754564762, 0.08537385958646025, 0.1842498467969043, 0.07902367426348583, 0.12059767091912882, 0.09004624493952308, 0.11949062746550355, 0.10822843214763062, 0.1219373568892479, 0.07193723094782659, 0.12429025849061352, 0.12616148165294103, 0.10391096132142202, 0.09703413782907383, 0.20851051355046885, 0.1612074218158211, 0.12447815840797764, 0.09645143909645931, 0.09390932800514357, 0.07255720839436565, 0.1171656950776066, 0.07168969458767346, 0.12871182337403297, 0.06166019383817911, 0.13230284782392637, 0.09240185389561312, 0.04944055507491742, 0.2621564013617379, 0.10358886074806962, 0.09550020763916628, 0.08863563170390469, 0.11599486933222838, 0.07358888017811946, 0.1735396600727524, 0.09125350801540272, 0.09686231919165168, 0.15408099921686308, 0.19246868363448552, 0.20938323172075407, 0.07807717219527278, 0.06283659714141063, 0.06543991209140845, 0.1384318239454712, 0.11806384474039078, 0.1063893511891365, 0.1388570482709578, 0.10520437798861947, 0.1521525891231639, 0.19316608192665236, 0.12286068020122391, 0.10667138426963772, 0.1624779107847384, 0.09991722633796078, 0.11202115791716746, 0.06440649647265673, 0.11992825541113104, 0.16326000381793293, 0.18093836520399365, 0.08869483388428177, 0.17242378209318432, 0.1011279702984861, 0.14439715099121841, 0.149235336376088, 0.20755759254097939, 0.1742447122399296, 0.11749785153993539, 0.11030963475682906, 0.04661697069449084, 0.18180591293743678, 0.2006158943154982, 0.13685081021061965, 0.11892671058220522, 0.10927056694137198, 0.13779467956296035, 0.09626355274979558, 0.10007083309548241, 0.14063160733452865, 0.13767551524298532, 0.11767908824341637, 0.13731845654547215, 0.14425088598259858, 0.1599784456193447, 0.1254394253981965, 0.06753666672323431, 0.08807421861482517, 0.06681606931877987, 0.12271767216069357, 0.11051693399037633, 0.08160259587956326, 0.10946351515927485], [0.05073244843099799, 0.13213858806661197, 0.023147496128720895, 0.03510987851768732, 0.022794040452156748, 0.04608917901558535, 0.039799932922635756, 0.030694047255175452, 0.02316553837486676, 0.02801781184306102, 0.04056109654318009, 0.0389631296108876, 0.04550442771453943, 0.01198404886028064, 0.053107897751033306, 0.055852334414209635, 0.057354515950594626, 0.05962500947394541, 0.01108749205845275, 0.03794752214370029, 0.024118902128455893, 0.03394384662221585, 0.06940039885895592, 0.023650146388847913, 0.04730563624096768, 0.02767439339576023, 0.0649781757965684, 0.057832537085882256, 0.04232831046517406, 0.01775544635685427, 0.02003547329721706, 0.05703088188810008, 0.022467922951493944, 0.035279451204197745, 0.02412714802527002, 0.008740420769234853, 0.07494794510837112, 0.01966023495021675, 0.006657224963419139, 0.011051602644978889, 0.019710872322320938, 0.04641724730442677, 0.045759010660861216, 0.016251351351716688, 0.0416489442411278, 0.03699499468452164, 0.047365896935973845, 0.001175922285515948, 0.06885494491351501, 0.017673872876912355, 0.02530836214178375, 0.027528264094144106, 0.03158368130347558, 0.03577599973816957, 0.04258545148851616, 0.01582418811241431, 0.018518513268125907, 0.047819880968225856, 0.009163513646594115, 0.03429081889667681, 0.0341063286177814, 0.02268435017737959, 0.019091232446953654, 0.04504396028018423, 0.03268361710278051, 0.0029733843444513953, 0.06767087416457278, 0.0021114570013846135, 0.01253285222420735, 0.005656407015132052, 0.10591009512011494, 0.023077140528974787, 0.03307937604508229, 0.009474690654315054, 0.038315484898963144, 0.05001454481056758, 0.06428539832787854, 0.009895860733065222, 0.02968708093145064, 0.09505409122045551, 0.01700223855940359, 0.03542091557756066, 0.049808025892291746, 0.02338998418833528, 0.037006614596715996, 0.014692410361021757, 0.08253169352454798, 0.09574400527136666, 0.030676340883863822, 0.04089101044727223, 0.04809868082936321, 0.016140935044469576, 0.03470994658502085, 0.02847208934170859, 0.10301990913493292, 0.08063306433281728, 0.03500680565567953, 0.02003564971632191, 0.06708288285881281, 0.030345290433615446, 0.0569351813090699, 0.007545397616922855, 0.03286271302827767, 0.02006809556457613, 0.009766516691472913, 0.0032571099457397524, 0.048988464155367444, 0.030271034953849654, 0.01792222517542541, 0.009743710281327367, 0.01023455657663622, 0.023335589428565333, 0.033960263776992045, 0.07656711965267148, 0.03733853017911315, 0.03799706198541181, 0.05921489612332412, 0.06538691172110182, 0.014467328420973249, 0.02252976463309356, 0.015908938832581043, 0.033681267140699286, 0.078625984889056, 0.03027947592948164, 0.004578337854971843, 0.052386737162513394, 0.013696011372043617, 0.01829794867496405, 0.024882104746731262, 0.009274517734801131, 0.051154032416109524, 0.04359749325418046, 0.07399408093520574, 0.04235862062445708, 0.02468907001561352, 0.0771308329754642, 0.04098493326455355, 0.03749241174331733, 0.09068360645323992, 0.035201721625136476, 0.02010669742178704, 0.05395536084792443, 0.008443325907657189, 0.008221908904878157, 0.034384015681488175, 0.021807118052882806, 0.03115974280184933, 0.010099576453545263, 0.05126722562792046, 0.0761044809062566, 0.0198045457779829, 0.021761306761098758, 0.026236474214653884, 0.025468465872108936, 0.004388123709109745, 0.06200431965823684, 0.014728449052199721, 0.047013713512569666, 0.009140642775621797, 0.026748389870460545, 0.036839868008558235, 0.03959577530622482, 0.035321768040635755, 0.024347643068592464, 0.008174267264881303, 0.13162841115679058, 0.0067527075630745715, 0.018142518354579806, 0.02196603434692536, 0.007483757799491286, 0.06013336790991681, 0.04968444770202041, 0.02135547835912023, 0.048210025033248324, 0.010773127632481711, 0.010849217701304172, 0.04385771143383213, 0.034498762738491805, 0.029706161336175034, 0.02879615088126489, 0.05302405796412911, 0.07461622969380446, 0.006843847962695041, 0.013138765336147376, 0.02929623458268387, 0.050433567325983725, 0.015999248450888053, 0.032771212581012926, 0.02465419501199254, 0.029266043167029108, 0.025204968671979647, 0.03429135154666645, 0.054524261570934734, 0.038032087963074446, 0.03118851947199021, 0.02913694509438106, 0.040827899905187745, 0.026531655607478957, 0.03234321304730006, 0.04260274734614151, 0.022188702398645024, 0.02575669058465532, 0.01584512261407716, 0.05319060777713146, 0.025482046750507185, 0.04535665975085326, 0.06051021268857377, 0.033653050261948786, 0.04335211802806173, 0.056875175064695735, 0.03301428757341845, 0.05161782806473119, 0.019553784680153643, 0.04777918243780732, 0.030333205724933317, 0.005649632691139621, 0.033342986899827204, 0.0448070701344737, 0.020254005677998066, 0.03188041823783091, 0.030645901802927256, 0.019568946545145342, 0.054763163572975566, 0.01634557102806866, 0.19955762395901339, 0.02383367484435439, 0.016153810246448432, 0.01621253745231245, 0.04850392908390079, 0.04668487508648208, 0.0701841339468956, 0.03997637577621, 0.027747162883835177, 0.025301434299243346, 0.06332894215094191, 0.010487217572517693, 0.010255347737776381, 0.018805694733081118, 0.05291698853086148, 0.037634870170482566, 0.02019995866742517, 0.07647758695696082, 0.019328789253320013, 0.010913231543132236, 0.015094069165310689, 0.04439690250105091, 0.07732087027813707, 0.03590582723596266, 0.015587241987564733, 0.039254044714782915, 0.0921364924205201, 0.008852563948104424, 0.043154952715017965, 0.011202636906611068, 0.014629099651106765, 0.043628156251673184, 0.03293970300416861, 0.0670505031677229, 0.07168275995978288, 0.025704009125807455, 0.06381063416068043, 0.00742238515522331, 0.03043988160789013, 0.044590027138058624, 0.04453467225123729, 0.028006459952199032, 0.04755190713331103, 0.01529902745304363, 0.04126742096351726, 0.028481643114771162, 0.14443252980709076, 0.06679437655423369, 0.011658371559211185, 0.03882686960111771, 0.05591702933556267, 0.027489306006048406, 0.02835593432454126, 0.004945728520397097, 0.03310337922136698, 0.006989126126947147, 0.028679663381938423, 0.006582169236415731, 0.042341843846121004, 0.034920882766268084, 0.0013898212263094528, 0.024922065370317017, 0.018451053316571882, 0.027940119583425776, 0.02517729122856898, 0.04518661887517997, 0.01555502344854176, 0.032432660926133394, 0.02875372887189899, 0.06588696488844496, 0.029227570231471742, 0.03932448343506881, 0.0192690289778901, 0.02483323835102575, 0.014622455096936651, 0.01383267086930573, 0.03013047981741173, 0.018623650572927933, 0.0333521267665284, 0.017846631285335337, 0.0421544867567718, 0.035804315004497766, 0.018673913054434315, 0.033932616867657216, 0.008124171872623265, 0.030075979884713888, 0.02794258775455611, 0.032107615510800054, 0.013863976778728622, 0.040315178489046435, 0.049905137824160714, 0.021430168101297956, 0.028668990026095083, 0.03241924289613962, 0.009596569962533457, 0.03975319882322635, 0.07249470853379794, 0.056211669596710374, 0.00552174071448722, 0.013581091288610228, 0.024801754326160465, 0.031873548070767095, 0.03103150307599987, 0.0641551399603486, 0.011078223270098013, 0.05774255655705929, 0.010041208871241127, 0.07419911386179072, 0.03176588491935815, 0.03382887225598097, 0.021527683761503016, 0.03819272095071418, 0.01948663515837065, 0.01657848835124501, 0.026004842715337873, 0.05320322513580322, 0.03393928686689053, 0.09131112920918635, 0.03147008436332856, 0.025390637905469964, 0.04391977363931281, 0.05842250971389668, 0.024472485030336038, 0.03214265166648796, 0.027278237510472536, 0.023640726626451527, 0.02770407421381346, 0.05149117271815028, 0.12802951570068086, 0.15652379313749926, 0.1691764084888356, 0.1780384150998933, 0.11667761126799242, 0.13195470507655824, 0.07848630845546722, 0.15750055786754402, 0.05862881828631673, 0.09734106635940926, 0.09762653282710484, 0.11074036200131689, 0.07552008583609547, 0.10651507694274187, 0.15973440371453762, 0.2596134692430496, 0.17904792592993804, 0.13098429143428802, 0.10573732653366667, 0.0683639162619199, 0.06986756343394518, 0.2103739199893815, 0.2025923989713192, 0.1527432809982981, 0.11223445540027958, 0.20609157692108834, 0.11309901079429047, 0.13969590754381248, 0.12427583283611707, 0.18376621417701244, 0.08547099187437977, 0.1323348611061062, 0.12033772415348462, 0.0891029659126486, 0.06382704113743135, 0.12255778216889926, 0.1366380623408726, 0.11175760134522404, 0.10867566814912216, 0.049629574575062306, 0.06790477197085108, 0.29862923281533377, 0.12833472075206892, 0.07458697126380034, 0.14842170503522667, 0.08859574063015835, 0.09544430313897984, 0.12426311708986759, 0.3652937241962978, 0.1282267386892012, 0.09080845011132103, 0.13679998793772288, 0.11141514472131218, 0.11040299439004489, 0.20111639531595366, 0.20226488368851797, 0.11122157903654234, 0.1257502351488386, 0.1319799330085516, 0.10077410750091076, 0.1088099909414138, 0.13568967394530773, 0.1268315485545567, 0.1351893222225564, 0.13851187750697136, 0.1543187985994986, 0.13935559509055956, 0.1304766522454364, 0.0778205298951694, 0.13186745904386044, 0.28465947242719786, 0.13554340893668787, 0.17169036716222763, 0.15161893490169728, 0.2071461153349706, 0.12637516590101378, 0.18653801615749085, 0.1515718310007027, 0.11824916622468404, 0.12166219736848559, 0.11226245175514903, 0.20023223704525403, 0.21579869889787265, 0.12257937315319266, 0.22845856100320816, 0.12633277103304863, 0.35474747153265135, 0.2626333029142448, 0.12543709123773233, 0.26786453649401665, 0.10588742526514189, 0.07561683135905437, 0.1804260712649141, 0.07783728971013001, 0.2030491887458733, 0.14167009160986968, 0.07092689909040928, 0.12882505729794502, 0.14088864997029305, 0.16770849297089235, 0.19302563874849252, 0.10835945725973163, 0.12653863855770656, 0.12645431022558892, 0.14076955350381987, 0.0868088932973998, 0.10922304913401604, 0.07609265404088156, 0.19573452696204185, 0.06760987386639629, 0.16628761350044183, 0.11935569399169513, 0.1689861472696066, 0.16506607404776982, 0.11144579414810453, 0.17559317845318997, 0.14153305467750343, 0.17055561233844074, 0.11998864502779075, 0.12188819024179663, 0.12010391455675874, 0.18773968810481684, 0.16423714852758817, 0.14574393443763256, 0.10227305242525679, 0.10613919568381139, 0.07740262696253401, 0.09855183067598514, 0.09633386254842792, 0.07071650573717696, 0.14811929554811545, 0.11586445490164415, 0.11795935034751892, 0.1487408879079989, 0.09802540285246712, 0.24675213651997702, 0.18849588824169977, 0.13297820729868753, 0.23838837817311287, 0.0658934720392738, 0.18334602458136423, 0.14287100359797478, 0.14730866333203657, 0.1372496395238808, 0.13571646250784397, 0.11967399476894311, 0.11125455583844866, 0.19313356652855873, 0.12877046237034456, 0.1685570960066148, 0.18927263441894734, 0.14495333257530416, 0.092385148363454, 0.1494582894125155, 0.07218594117356197, 0.20305429132921354, 0.14299869031778403, 0.124296243169478, 0.09661288971879653, 0.08965874716107335, 0.19318071114165442, 0.14659958066684858, 0.1657228280923196, 0.11782224556165082, 0.09131290018558502, 0.2678901308349201, 0.11436350829899311, 0.0704732509329915, 0.08464230384145464, 0.193533345790846, 0.19619590363332204, 0.1341759166015046, 0.10407804378441401, 0.12656047381460667, 0.09047761679227863, 0.14928044538412774], [0.029693438804575374, 0.018024410852896314, 0.027487804747319648, 0.025743881539840783, 0.050297548196145465, 0.024360462291432277, 0.03457364247047475, 0.058697011055690904, 0.0318176707119814, 0.02151498497862901, 0.01931342382782272, 0.07434002522911344, 0.04114572570792266, 0.01730582021575953, 0.018286359296845536, 0.04917319531419447, 0.026144561557365314, 0.04678728298417159, 0.021091041387990117, 0.02520192035340837, 0.022734492218920162, 0.008910580388536411, 0.03357226048995342, 0.03663230075367859, 0.027793978407446827, 0.0881652712289776, 0.03847862507349678, 0.026786448899656534, 0.014443425328603812, 0.021807737216087322, 0.014888674918828266, 0.07910772439624582, 0.03647595610735672, 0.07531729207507201, 0.01906339724415115, 0.044890869209276776, 0.03629142850903528, 0.017817539096410786, 0.0794719552089061, 0.028197196145941104, 0.06675424120788064, 0.05111885716074279, 0.04729384330234357, 0.029599885788879225, 0.05623882117548159, 0.037126016403947554, 0.07272688964647905, 0.06491427136851208, 0.061408789828419685, 0.06661527045071125, 0.06421139729874474, 0.01929211273922452, 0.031724914974932156, 0.03560978240732636, 0.06411875691264868, 0.05206913188365953, 0.04319092185635652, 0.032485569694212506, 0.026252494426444173, 0.02322178383890007, 0.029678399075887034, 0.07458997038858277, 0.08633600867220334, 0.052767978848091195, 0.034297007136046886, 0.025727659463882446, 0.05332470326019185, 0.031055628388587917, 0.020424579203661, 0.06562671278204237, 0.03573853781978999, 0.04807037574106029, 0.015172187205670136, 0.008698536498871232, 0.010881327674724162, 0.04165122411879046, 0.05389813659712672, 0.05951233873409884, 0.04297517825450216, 0.02998820798737662, 0.02399231124270175, 0.05366029650239008, 0.050320184124367576, 0.049745580314525535, 0.029281330560999255, 0.04973464911537511, 0.03855358622968197, 0.02495000065703477, 0.04727980102013264, 0.01702870142513088, 0.01941226772032678, 0.028968105225690773, 0.03944645689002105, 0.053328866072531254, 0.039832787588238716, 0.03983008023351431, 0.022078716961134757, 0.07221679416085992, 0.03158009185322693, 0.01406029477116785, 0.0023014663144879577, 0.03954959421285561, 0.03681782240580235, 0.04574933475149529, 0.026586216608328477, 0.02917077685041087, 0.03867713388587747, 0.03288391385493534, 0.07411978633276053, 0.0655631408361452, 0.028501456337315694, 0.018136443769825355, 0.07442188369376318, 0.050630189811012576, 0.015491733094677329, 0.031533405251268826, 0.018189724035827175, 0.05120235428746257, 0.10687622720641748, 0.016932478374136344, 0.05430322200325983, 0.015899463091045618, 0.051025012374988625, 0.03529983778883304, 0.02096263033204845, 0.0798898513561913, 0.027618795932669724, 0.0167796570208988, 0.02124103155386235, 0.01884321602327483, 0.006266475729976914, 0.07115912091519151, 0.02736880666842418, 0.02481587803257363, 0.03380166639440826, 0.016042108115340983, 0.044864545443228314, 0.010947768127412667, 0.020676425957520093, 0.03367619848410998, 0.03375666595197149, 0.051324860392404456, 0.017292149431471313, 0.03041793100003685, 0.02860086171754769, 0.05214552814140916, 0.01771475970079856, 0.04560022328847221, 0.039475623717797656, 0.02454114768521062, 0.08657673254076924, 0.0537671182703759, 0.044786798900791576, 0.028320178921733583, 0.031483380257018974, 0.04443150439432689, 0.012175307525987071, 0.0448085764822151, 0.017156057359118546, 0.07401857604937893, 0.042341697961091995, 0.025921710301190615, 0.03041151545143553, 0.036238360285226784, 0.07738605713737862, 0.08266811977539744, 0.07670208705323082, 0.01933406655942755, 0.04062952340713569, 0.02584277292979615, 0.04340164769174797, 0.021153746505400965, 0.04893001854153616, 0.017690854912091578, 0.028507084785295383, 0.0316502930862563, 0.02186804880121989, 0.022560371651447246, 0.020457871524350982, 0.03805909365681665, 0.0559640552050301, 0.012167603609019091, 0.03844495616587145, 0.05547987636444824, 0.010272836129713272, 0.01753720744246883, 0.030571188312023878, 0.055709112635148425, 0.07640830174620662, 0.02602182644685464, 0.030694983633501188, 0.028429467164512192, 0.027230609441176057, 0.03755866050986307, 0.03497697047090956, 0.052887797954359224, 0.030258142788495337, 0.00890900703546192, 0.058962827149246416, 0.09079223990972553, 0.01875861966982484, 0.0299343492702714, 0.023671557561361363, 0.008975028492776411, 0.011544336115808358, 0.036701752205512354, 0.027994285337626934, 0.05713486059435776, 0.02313972690275737, 0.07344399938093764, 0.032233575358986855, 0.03721165091597608, 0.05964777432382107, 0.012799949900779341, 0.057736789009400775, 0.04017239097239716, 0.026764064029391323, 0.02843860363853829, 0.026368581590109637, 0.04920381081423589, 0.03769812320492097, 0.08887377713939973, 0.03512722187276397, 0.02841694649708058, 0.01918012901608433, 0.02707611210644245, 0.03590152871661952, 0.04556356882676482, 0.08628679452730076, 0.08179738971271686, 0.014583632715844681, 0.03990096000156232, 0.056831287419689555, 0.05104561948350497, 0.01468291595977332, 0.08229683219854321, 0.01195210767244654, 0.020018221544367925, 0.03896299729655896, 0.04697453150791781, 0.03529511857777834, 0.03825048802952681, 0.04891697031312755, 0.03434945110763822, 0.0193528178746679, 0.030398280625896792, 0.03378985649240868, 0.08007242477365903, 0.014239976781287363, 0.010647055826016834, 0.018815991501989107, 0.03447636429752622, 0.08856623114219733, 0.02759058753560696, 0.03559492588309305, 0.08084452298602887, 0.062364221417478154, 0.055740091151424816, 0.06319259053894452, 0.012662366747723093, 0.016038959712854454, 0.0662002648626055, 0.02869165309571794, 0.02847790438681841, 0.03643993268321667, 0.007192861355308975, 0.04745374347216316, 0.06094444117375782, 0.05064298358878919, 0.0476340064778924, 0.02081343574848558, 0.048318902762340646, 0.012290730573503035, 0.0339121420734695, 0.024214061575808694, 0.018694616854190826, 0.04492309622998748, 0.02021960395255259, 0.007172592666133174, 0.04318899481690355, 0.050060786972088475, 0.03501583356410265, 0.03068897859858615, 0.056670915668032, 0.0198248017446271, 0.06991857569664717, 0.031450138826455386, 0.022279375033187013, 0.06378189820264067, 0.01911517625142421, 0.06854336163295166, 0.019168792392260263, 0.026058100928951587, 0.017688089881890585, 0.05356018205306359, 0.04231448870684419, 0.02016774352107729, 0.038093858398497105, 0.017589532670431902, 0.015306474374873298, 0.021440963593444655, 0.039042647129723, 0.035340811125934124, 0.022983253334781954, 0.030910567779626166, 0.02096495431448732, 0.034818688607109446, 0.044866116251796484, 0.024448585330641696, 0.04891695674242718, 0.08950084527688366, 0.012789639561170978, 0.05934080508138452, 0.03331057667466147, 0.03850608877837658, 0.053174702916294336, 0.02915033937564918, 0.047032152701701434, 0.035721591407699246, 0.04814528600711908, 0.04355839606640594, 0.04175664810463786, 0.02961338185040014, 0.04264123385239925, 0.03703184252870934, 0.0572506593806403, 0.0192303219477513, 0.01353304592027728, 0.03455095565212624, 0.01639612527963306, 0.05058264146958079, 0.03498510271310806, 0.03897841700485774, 0.028039338366527642, 0.015997496134202396, 0.04944626833977444, 0.07105166810963835, 0.046349831457648955, 0.04576672221134816, 0.033494340921086926, 0.027127821563876102, 0.02902116666414908, 0.026525597986099974, 0.019626757728734186, 0.047570733087403436, 0.017333551941971694, 0.014101153605484536, 0.03953987419871347, 0.04950819483825138, 0.04372000953714762, 0.039020068876977475, 0.016869342386988655, 0.2493697346321174, 0.07960369956812688, 0.06749070954642125, 0.13786372728645802, 0.1550566918615784, 0.09714976019625153, 0.09523936520729746, 0.1301045843533107, 0.06710061297885009, 0.14058717686150754, 0.05048557024981294, 0.1839568553758519, 0.19618413783609867, 0.09389852572764669, 0.17737624634589466, 0.17321120841162546, 0.16876262426376343, 0.09803090577146836, 0.09991130272724799, 0.08859698234924249, 0.11273826086627585, 0.054686061638806543, 0.23010503979665892, 0.22093951090105943, 0.08790712258113281, 0.18341648365770066, 0.1377446986734867, 0.11071484229926552, 0.15599731781652995, 0.1045491099357605, 0.06952286764447178, 0.17069473915866443, 0.11617098988166877, 0.11301315575838089, 0.13768441762242997, 0.12473164552024432, 0.16114525443741254, 0.12899447392140115, 0.17398771031626634, 0.09027723861592156, 0.13597035674112185, 0.10544409084000758, 0.1285319844526904, 0.14635500950472696, 0.1419586589826005, 0.11528414461229529, 0.11335083549576146, 0.21569729862468584, 0.12281873316637107, 0.1404397040605545, 0.13047686937664235, 0.20414595917931624, 0.18223089299031667, 0.22845524975231715, 0.2284548697727067, 0.11366967231567417, 0.084279660800738, 0.16479908408863203, 0.07018875477037259, 0.11259145302964108, 0.11295239973281111, 0.12996430402355535, 0.18192234954663686, 0.1839341651648283, 0.1705728064158133, 0.09324069959776742, 0.17879806219467095, 0.105261741339096, 0.10884273704141378, 0.14491443894803524, 0.08900141636175768, 0.20213024877011776, 0.15663801772253855, 0.05567905692649739, 0.04426733284656491, 0.14612532540091447, 0.21662751585245132, 0.11531313162829195, 0.16768178583255836, 0.17868697244141782, 0.10696394142827817, 0.17640914395451546, 0.14217930499996456, 0.09676330057638032, 0.10574751812964678, 0.17887249748621667, 0.1076375502826912, 0.10437541175633669, 0.09630499766873461, 0.08098193989800555, 0.11203764631812062, 0.3055279797741345, 0.1622154534395252, 0.11597200270209994, 0.10488305094518832, 0.1695516383541482, 0.20210614720625536, 0.12565073477370398, 0.06019119266420603, 0.07879405122782503, 0.15048709777849062, 0.0979545298697693, 0.12700031378439494, 0.12384884431958199, 0.08747763705572911, 0.1336116197385958, 0.0935512650758028, 0.12325500404196126, 0.122622175142169, 0.1289625692048243, 0.11083036288619041, 0.10239379094647509, 0.2350823384310518, 0.13487632758915424, 0.13068019918033055, 0.09892581203686339, 0.09527836061481919, 0.19258931359010084, 0.1741883395505803, 0.16324473678001336, 0.16336251688855036, 0.10907801905913012, 0.1671205423772335, 0.07466946755136762, 0.07151563678468977, 0.17193230560847692, 0.10504911560565233, 0.10483117694301264, 0.14035388295139584, 0.08725549826132399, 0.05650488493431892, 0.157039805448481, 0.12729569364871296, 0.06725124096763985, 0.15614987963012286, 0.10511443138654743, 0.12592535146645137, 0.11752370372414589, 0.12452317242111478, 0.12433740310370922, 0.09290850242333752, 0.14046858251094818, 0.12027432184134211, 0.09967948802347694, 0.14628943588052476, 0.11151630072189228, 0.0720193540411336, 0.12611891036587103, 0.11330752460552113, 0.13252045400440693, 0.14037068347845758, 0.12006073258817196, 0.13726150031600678, 0.1289785283484629, 0.08356303961149283, 0.21156926799033368, 0.08710330964199134, 0.13615217698471888, 0.21528397580342634, 0.16232625820807048, 0.12006320245563984, 0.1229034143366984, 0.11103968415409327, 0.20092674477824143, 0.1485757189137595, 0.2130576888365405, 0.10983488416033131, 0.12218241659658295, 0.11819952460271971, 0.1387874305780445, 0.09242166711815766, 0.18420572844999178, 0.14080715791455337, 0.1849904406283583, 0.15000752279801027, 0.07109206808464867], [0.05769569014332124, 0.0431930388856147, 0.02486744330131582, 0.008306284734447087, 0.007760125112586788, 0.05281455349177122, 0.0302172440902463, 0.04444644234276243, 0.004025563788932881, 0.05145937656717641, 0.04197746714843171, 0.012038683651813438, 0.05113277391397527, 0.04820880367021475, 0.016941965990034596, 0.04460599645972252, 0.07357657155288116, 0.023105016443878412, 0.012393676210194826, 0.05728637067867177, 0.09148181469312736, 0.04223713232204318, 0.08535456883588008, 0.036028706535164795, 0.033196962771138976, 0.02215919460702155, 0.03858155544315066, 0.030391556343861988, 0.02081774783852909, 0.061649031937122345, 0.031806376496596, 0.0434635334781238, 0.013082809097665762, 0.01754414546303451, 0.01862694994945611, 0.0378223120767091, 0.10744078869798354, 0.019201267078252773, 0.023859411677611724, 0.014292680292523332, 0.04188330684389387, 0.024866374608661448, 0.060245740094355175, 0.06533465095396553, 0.03732083737850189, 0.030261471002761806, 0.0513547600380012, 0.08079891864742551, 0.03887575465653624, 0.007375331296186362, 0.036792200923498185, 0.04865579539909959, 0.037552312814763615, 0.040010299134467325, 0.018343792197161486, 0.07420171265091215, 0.012204531181071485, 0.0039686592977627045, 0.014317524852231145, 0.027556112867646983, 0.02171311211506171, 0.02856664319655725, 0.04050546006432601, 0.0221433830447495, 0.03514301816799811, 0.04343194088765553, 0.004304960760886648, 0.07025618079517569, 0.048989699089101384, 0.023367395757564476, 0.03951728576794267, 0.013859557819419673, 0.0185903090584491, 0.05848521992032017, 0.03989965382165142, 0.035634874632315974, 0.055125504665608914, 0.06955161717321191, 0.07757267462355749, 0.022886229612465416, 0.02363882672839931, 0.06605572333293301, 0.010363537601993551, 0.008834980561264923, 0.03946766110935381, 0.003298228319701073, 0.02924930370811905, 0.02570566814392805, 0.023782665974327495, 0.018376595972638046, 0.04126544303393789, 0.018888206287686313, 0.02921977386410747, 0.045574181114456484, 0.016509398219308684, 0.03453980053641966, 0.03200705662103636, 0.08283527009189129, 0.01600250881165266, 0.025172945211774538, 0.058922868221998215, 0.05978705720709903, 0.010956628946587443, 0.01626461331865617, 0.04986992185669286, 0.03248568165249058, 0.01033907980724637, 0.040037053770252636, 0.03254167775490454, 0.047361058981290886, 0.07832862370248352, 0.04281688282000167, 0.060458128340542316, 0.04654195525550416, 0.011225684196688235, 0.009124921119239713, 0.0866307642843042, 0.03820166064958487, 0.03463881236634084, 0.04679914716897266, 0.047427467203566005, 0.04936376865953207, 0.02175725929971252, 0.010846317812268223, 0.018812926220042363, 0.007929171086288989, 0.02383477576742215, 0.023163592675700784, 0.042735414512987645, 0.026652536621051173, 0.017083153860377412, 0.01772472568388496, 0.034894189198634455, 0.07039893777774912, 0.06733248196542263, 0.002908493496111727, 0.006882613516479198, 0.008239192039971905, 0.018904933872233545, 0.055392501410096884, 0.057521103083023, 0.10676636560154812, 0.02348529630606728, 0.0020752940534813596, 0.04745687830394932, 0.051754305205707035, 0.013264883791894784, 0.024151934909501245, 0.032380074462188144, 0.028861775395593474, 0.026678275150646056, 0.02712470030279032, 0.03579488676041365, 0.10073032163615737, 0.029875262440847497, 0.04666624930022018, 0.03161004917430026, 0.009534435662707048, 0.007188653590024582, 0.07311763082231794, 0.05265699087509087, 0.01849782812808241, 0.04282487256984625, 0.04988238654498543, 0.03529208213356989, 0.06399617956152984, 0.05226396642891424, 0.062498822409127436, 0.07774648815393448, 0.05184678274339863, 0.024648664951590554, 0.01566275954246521, 0.06645784354103462, 0.012745612816485976, 0.14831343798765115, 0.07578967458435468, 0.026798482718212262, 0.036387987434864044, 0.010893418320587702, 0.08688104192593268, 0.10566507612488099, 0.016071524304736937, 0.012839709508365818, 0.06216011129851852, 0.02314348768309823, 0.03198438337338822, 0.0687650933063456, 0.04969359774674688, 0.02272682138053434, 0.020056155044585466, 0.023359489128259674, 0.01636950295817639, 0.07775235748184578, 0.02969039896769183, 0.0013637737512388931, 0.017826597538909743, 0.04845880650516067, 0.04323420221252101, 0.09507655072957277, 0.045369260146149566, 0.015579403211761798, 0.03425332983689649, 0.03330404916778207, 0.059898228384554386, 0.015049518252323781, 0.0265485545221184, 0.04408122765432511, 0.013323031698486634, 0.04789731199187892, 0.026962776402277604, 0.04103952140680381, 0.02947307437924402, 0.07063116638788156, 0.01987552732628371, 0.03995163638943008, 0.054860231400068314, 0.027875173604115844, 0.06714245144809995, 0.03625729480492217, 0.057891481422952244, 0.025511440887515033, 0.00965621234250388, 0.03369715503816094, 0.03396648933578815, 0.03152450965717435, 0.021909437741019895, 0.05819213350436517, 0.03545933083764144, 0.007441662335103112, 0.04077301660020437, 0.012724599435127206, 0.03403441069115486, 0.033036075332867246, 0.09102686374847378, 0.030363298753010373, 0.042674203868955374, 0.007907220478435712, 0.01697789950828467, 0.040289326304835935, 0.06371910657201495, 0.04105118203109928, 0.01941310062206217, 0.03311805932649544, 0.04549969154010926, 0.04613189618768437, 0.0207358622324786, 0.07351122184523515, 0.02009397997920002, 0.06393523354615484, 0.04500745509618095, 0.0363204867712089, 0.05564259584727032, 0.022810082716335143, 0.03301582445523568, 0.032655807345041206, 0.034584013878234794, 0.010617656599996346, 0.08249755642775979, 0.037402407465768714, 0.006444344779343477, 0.0246051165740937, 0.028558436315506697, 0.020358954689332416, 0.02247118840127119, 0.0391009332878249, 0.0119917502327423, 0.0691214802541903, 0.017646994408486143, 0.027836921192439537, 0.06453202545110669, 0.04002382233738899, 0.02225469671455877, 0.12387723422476224, 0.02712733471500022, 0.021452680196879164, 0.02638123287553234, 0.04921050795486995, 0.06734848860651255, 0.01478278444015554, 0.03477677549900753, 0.02238067182978349, 0.02832935271518571, 0.02706816646137408, 0.0803283206852419, 0.00277227525865393, 0.04792249581909605, 0.03737359008352671, 0.03568962901564581, 0.021721571750406708, 0.010062657363180603, 0.06455983181617089, 0.034736087146614275, 0.028080779892791594, 0.02257918064216418, 0.024620526104367206, 0.04020613791154964, 0.0024280930353727725, 0.09872759838721581, 0.017836802705590214, 0.02938768413982221, 0.07025244885257312, 0.04706666299274989, 0.0398166825595711, 0.036490432651979585, 0.02723154751583934, 0.03737293190455862, 0.01583898696117103, 0.0295067704282701, 0.049969099927693605, 0.03923862161380904, 0.03670026621382151, 0.05077032086306384, 0.03548753075301647, 0.037007903813251426, 0.024551086526896273, 0.019380556386230246, 0.004998287418857217, 0.03480163023674062, 0.025069349877802388, 0.029991068012480224, 0.03882520719032202, 0.028001308175069944, 0.09517375765634434, 0.062266810930200985, 0.00573719890754936, 0.024502625555864403, 0.024645184066944888, 0.011498691065103879, 0.04958905924909881, 0.08355799809630428, 0.07124994961278779, 0.039689070478613885, 0.008836381736078432, 0.010580722242593765, 0.029891194443085363, 0.09107307876859393, 0.06491695158183575, 0.03533755415784461, 0.01788800156542233, 0.032097098218011, 0.03172267580937062, 0.06115298212638923, 0.04440968270812716, 0.029555964217122112, 0.04974531229319317, 0.05505621945485473, 0.013891199603676796, 0.003542620730253735, 0.044538227774735005, 0.06675429549068213, 0.014923073251598647, 0.07443639755781208, 0.07998436449893884, 0.11807955961142268, 0.16822599805891514, 0.23773201767887386, 0.18866261786648206, 0.1495272149997098, 0.04916636246655669, 0.12529732659459114, 0.13829543840672287, 0.12479629633682114, 0.13842220231890678, 0.10692649308059897, 0.11087756856743779, 0.1197785163032157, 0.13689811767211982, 0.09915610003684248, 0.16445969444300446, 0.09101644145058733, 0.1119597437126296, 0.1530951014054673, 0.14079999258475645, 0.11129735104207482, 0.20936031080782413, 0.1106633889888014, 0.10315237274127347, 0.09933072780924183, 0.11059990525245667, 0.0902724481586899, 0.09782233767743621, 0.10303354090345757, 0.10104559614722218, 0.16876086007271493, 0.13091513514518738, 0.09219741807984454, 0.09433150570839643, 0.06931030976452998, 0.16493356972932816, 0.07265952468982764, 0.10762855969369411, 0.22975309725318635, 0.18823484224932535, 0.19015079444008215, 0.11695855190711361, 0.13199389725923538, 0.18073618890983717, 0.08512689319572278, 0.13160449958273343, 0.12730553240648337, 0.12601943713213715, 0.15595224952059134, 0.1204003393650055, 0.09860126873744385, 0.10002526946898017, 0.16788595701966966, 0.10904821780111108, 0.10986015280442578, 0.09831815678626299, 0.1788681684327977, 0.06596031452396087, 0.1568234884845359, 0.09756800239639622, 0.14657811181885855, 0.11748717139874186, 0.14529592490621976, 0.11788600071200303, 0.10065028164535761, 0.11052075414253132, 0.12716460068311009, 0.11553343837814671, 0.057771340012550354, 0.15255755239299365, 0.07978628655629498, 0.09634107537567616, 0.15926256403326988, 0.11606325209140778, 0.15114013345113822, 0.14240993905280316, 0.1601688696869782, 0.12654987509761537, 0.06531510236007826, 0.07759740043963705, 0.12688420287200383, 0.09478687055941139, 0.1148093193769455, 0.1296756552266223, 0.11588582875473158, 0.12023735525352613, 0.12942698571298802, 0.09435422984617096, 0.10956268983760051, 0.15259219839104585, 0.0634753428665655, 0.1353673833821501, 0.127018254250288, 0.07736178593976156, 0.09795806503721646, 0.22825234064034053, 0.1340246440044471, 0.09870959006782089, 0.08827566887651171, 0.12602228697921547, 0.19706514770431177, 0.08033316542527505, 0.23645471621836933, 0.13530144334903785, 0.1656693595328501, 0.17560802479939802, 0.08775403829557554, 0.17786981271845953, 0.10256691237113305, 0.2756316182868821, 0.14730966756386416, 0.16271424453173364, 0.11746026069990226, 0.1334531953824418, 0.18137673953814165, 0.13540812262466975, 0.11174522486648389, 0.21111049689352512, 0.1152285590235676, 0.14969055194939884, 0.282607799662011, 0.1447891949542931, 0.09765326710683958, 0.20261891611984797, 0.059947035408445766, 0.07188399309026343, 0.12363478009189878, 0.10643062647432089, 0.14141642807849816, 0.10435209050774574, 0.06411294186753885, 0.09649468213319778, 0.18574119891439164, 0.11657456894006048, 0.08365238910274846, 0.10015441503907953, 0.104077351678695, 0.10026385595223733, 0.10251953027078084, 0.12465175480714866, 0.16837176095162118, 0.18946171498724393, 0.12279398020889078, 0.11792459578386374, 0.1505312296961035, 0.16637735654200825, 0.15187027784330503, 0.10411557355629546, 0.07683742764805045, 0.0842834198847413, 0.08433522603341512, 0.10603665547179324, 0.2224123254418373, 0.1527066808193922, 0.18523273191281728, 0.0993216082985912, 0.06405404502792017, 0.09778036350118262, 0.2107766440936497, 0.13673583923705987, 0.13138857616909913, 0.10948923163648162, 0.06621230885918651, 0.101027214633567, 0.1607675411339317, 0.10796030224966151, 0.08574438041874341, 0.12805619569761412, 0.14957072266510554, 0.15370055820260728, 0.07435774177845035, 0.1777582751320941, 0.1054277110046574, 0.2086922252284629, 0.16861677994685514], [0.04242153099871107, 0.019703269337436984, 0.07739446418625967, 0.01866646952527974, 0.032322398985603025, 0.018417040052424585, 0.04947076684662274, 0.04397177995581712, 0.007048392344066607, 0.054400517139583826, 0.033000340286110125, 0.05374695220962167, 0.051812316557126384, 0.01782582570532603, 0.042438599547105174, 0.05377119626583798, 0.03564521211332508, 0.03553571691736579, 0.033251890180898566, 0.05124626228851931, 0.02075073402374983, 0.018181545992514918, 0.032877213321626186, 0.004865181748755276, 0.0427334297980581, 0.04039643645020468, 0.049032368763749085, 0.014755381803427423, 0.026842175284400582, 0.03643730336001941, 0.033269318352852545, 0.07740851664649588, 0.06265660215701375, 0.00895100665677871, 0.04472943555031504, 0.033653518451111655, 0.044741727212177854, 0.027650721005297134, 0.021537246016253318, 0.02681528833428664, 0.04675366835934775, 0.03620183135249785, 0.007698847463221422, 0.026710174778210263, 0.034364280490470786, 0.07921149954199791, 0.033815097995102406, 0.027275598009249995, 0.04477773028026734, 0.01908278638230903, 0.05276454546089683, 0.015315278366740261, 0.026049805838348608, 0.049401773405926566, 0.009100931513655399, 0.10846525443983929, 0.041117077959435325, 0.021731206947671514, 0.015275012402396117, 0.08076982985117606, 0.06031685734965971, 0.026052799874118397, 0.03597755856545908, 0.027109843778557012, 0.02375364163890481, 0.004512543282804212, 0.06144137308001518, 0.030587378157568828, 0.0015195678300057936, 0.05338739989591496, 0.05838411820254155, 0.0489228701751147, 0.06901170685887337, 0.026961095331768905, 0.038603991203542264, 0.026541263663343022, 0.03499289229512215, 0.04612658665116344, 0.02708751997644348, 0.048697847606880326, 0.046886162499764135, 0.04785708165062325, 0.019563653971999884, 0.015353249186383826, 0.01238437943227057, 0.02367533021606505, 0.08821525211845126, 0.03889246018869536, 0.05088386691308447, 0.027123823296278715, 0.016138305721272315, 0.02180149469391576, 0.06447599881461688, 0.03378118481487036, 0.022090470883995295, 0.07290200596409184, 0.03801277007109352, 0.009296375044089342, 0.04713442828506231, 0.056325073154377084, 0.10982239911598818, 0.1217100340873003, 0.008920000150932797, 0.031487146126372476, 0.021362687793693373, 0.013732562357160662, 0.03864234878814646, 0.016946591902524233, 0.14069830732686178, 0.059751325553017, 0.02073629988756563, 0.021909434348344803, 0.06169285851397684, 0.02597243418650968, 0.05500614696315356, 0.03488736313634685, 0.030682393416230167, 0.026850382165451134, 0.049308759825570245, 0.03712745489818709, 0.011443400639109313, 0.055043554598731656, 0.03541841178334185, 0.05123179592192173, 0.05288700406838741, 0.03126815912712898, 0.03169343773541706, 0.027482105053163, 0.09644360201699392, 0.029635067829596143, 0.06044505297073296, 0.04840891382523945, 0.014750185921522123, 0.042114755138754845, 0.036725456826388836, 0.02285909838974476, 0.04849726247734257, 0.008124682470224798, 0.03137466198365603, 0.044829526250915866, 0.05748136128698077, 0.018416510795110037, 0.06394967277135168, 0.0184115099920226, 0.046289933778877766, 0.06862429728997604, 0.02487318540391113, 0.02096407730797572, 0.025574865252045647, 0.003114077732399372, 0.0624238375042166, 0.015632315372516, 0.027816895927701677, 0.012794566573575139, 0.10250943366970335, 0.04999956615003092, 0.017976879474839995, 0.036879789616380415, 0.006616286825322146, 0.03391201654449105, 0.028007408204887594, 0.04812287738812821, 0.01999041178662862, 0.015707653115636537, 0.025058104856205837, 0.07639488710888795, 0.005763942093056227, 0.0388660821398454, 0.010884326799506587, 0.012289606749878397, 0.022019277293501154, 0.010786651683572148, 0.008773925132118165, 0.02261633552344782, 0.018848891968705823, 0.041992832573929, 0.05984895317150014, 0.014516059109675033, 0.04120577605707305, 0.03830535776380982, 0.03546093896563564, 0.009843787411227822, 0.009136702183500996, 0.04595693593312587, 0.006379114239410098, 0.05059618163587792, 0.006565628673083016, 0.04039302681173597, 0.024926452099212577, 0.03577769607571619, 0.03143571995730911, 0.020775495462917855, 0.04499780972089086, 0.01711845294838505, 0.053907717511590035, 0.03345666865685156, 0.02860526540981872, 0.028434043883212974, 0.038072867917695215, 0.08296520276261227, 0.03839257326243179, 0.010729309537314942, 0.01866982827362205, 0.004571330708651138, 0.01903103451643671, 0.00922108140574502, 0.059751298411616256, 0.014132444247869509, 0.04568377130531839, 0.008873975968786647, 0.06661972164043359, 0.031259043009153435, 0.006628177727439574, 0.03945559675672224, 0.06730400385068995, 0.016151474389646734, 0.03970958259222763, 0.03413146494754723, 0.032896015526992936, 0.029545667448214123, 0.02156519148099635, 0.032774788460561206, 0.04889955910454903, 0.0107931011589244, 0.0278482103188123, 0.0329974904390318, 0.10794779006391764, 0.020709904875340204, 0.013766326259688606, 0.025904870758365308, 0.026533158562545265, 0.0638301284717662, 0.016094207730410353, 0.023851008021405766, 0.035399443336895535, 0.031573774692203314, 0.07751964032649994, 0.04628953683589186, 0.04675701692966478, 0.05039703839325479, 0.014615350835291403, 0.020062446760545884, 0.061235553052808554, 0.07994545051561934, 0.002733529848878139, 0.04816893973786916, 0.03480696012931211, 0.07384339187826429, 0.016948189852493148, 0.044125746336898634, 0.027214770737503256, 0.023365838519696678, 0.010590644120903952, 0.03833891810583217, 0.01990154235889869, 0.02262879003371511, 0.009675441176763602, 0.054869890346058776, 0.026887221527951102, 0.0861655810315694, 0.02332686516456306, 0.023192834142329435, 0.0653292430298669, 0.025253882565136467, 0.04787956151579108, 0.10559193004987069, 0.008653085678815842, 0.022835439569982033, 0.05860252505434411, 0.004649204052319484, 0.010363504523411393, 0.055826516156750064, 0.037469918307449133, 0.011149602609553506, 0.11156188470444509, 0.04297620623505541, 0.01063310429786465, 0.05319512342768056, 0.019036861435909356, 0.029090051539242268, 0.030157641574208225, 0.06072040926665068, 0.04287546753351178, 0.03297748722668205, 0.011152917253119605, 0.05183049790295107, 0.11979987658560276, 0.016444143506565263, 0.02695082061524902, 0.06827403751334973, 0.09182784719658749, 0.07685595843940973, 0.060186585411429405, 0.04075689800083637, 0.01602599799766072, 0.040471214401934824, 0.039350389902080805, 0.04966573031353099, 0.020548091236768023, 0.04690809275156685, 0.027544935699552298, 0.060015207821769376, 0.06494996231049299, 0.015852440614253283, 0.12438441200980119, 0.06021017128867762, 0.03886652658028262, 0.006425343678399388, 0.014420716457867196, 0.08943377887564045, 0.039773015438445976, 0.05036395981109568, 0.0548641024423497, 0.008048084348307123, 0.01467320612365646, 0.022520095509077822, 0.03307392401620746, 0.011914191135604466, 0.04282418046412723, 0.07525530790111848, 0.02825145859138242, 0.05733707081526518, 0.03038961234103356, 0.029686144553124905, 0.03820424586800592, 0.0046471061068587005, 0.04583166140530791, 0.034408090103949816, 0.04356727808980005, 0.031520686112344265, 0.09599046276084014, 0.06054614790316139, 0.007913390058092773, 0.017941487088267292, 0.03904122220618384, 0.01422088365403137, 0.07714743672737054, 0.030910557601600885, 0.03770091537652271, 0.016469193323116218, 0.039575256407260895, 0.07612226530909538, 0.03516158627878342, 0.0128857803397945, 0.02279541957458215, 0.031328446963535886, 0.02451990105743919, 0.0514951760747603, 0.015072038829592722, 0.001727531073681478, 0.03718916087278298, 0.017202596379710094, 0.12179725297859736, 0.13976206470813068, 0.1577660007668393, 0.1176451886338847, 0.1637655259775264, 0.1750551544662033, 0.06743357011250087, 0.1560161810900484, 0.22055840492248535, 0.09694004537803785, 0.14796435886195727, 0.13638418167829514, 0.13435897177883557, 0.12268044772957053, 0.11907274488891874, 0.09821541979908943, 0.11493982880243234, 0.08104894523109708, 0.16648052100624355, 0.12431460432708263, 0.11163758207112551, 0.05664512115929808, 0.08905215042510203, 0.12972550040909223, 0.10051602670656783, 0.10181943819458995, 0.1531920369182314, 0.08303212667150156, 0.10157039548669543, 0.1765824282275779, 0.11016486931060042, 0.2626462493624006, 0.12331789066748959, 0.23351150272147997, 0.13363084942102432, 0.08918103136654411, 0.14771665286804947, 0.11510186296488557, 0.18989981790738447, 0.08168466469006878, 0.16578883597893374, 0.07923851880644049, 0.08751723635941744, 0.06898235343396664, 0.08769049349107913, 0.1526952814310789, 0.09923101708825145, 0.05971613672694989, 0.09683909293796335, 0.1718487236648798, 0.14014610195798533, 0.10662335756101779, 0.08507445600948163, 0.16594160135303224, 0.10722314859075205, 0.10921833331563643, 0.2508073332054274, 0.09703220400427069, 0.10759188487593617, 0.2240872077111687, 0.1584126174982105, 0.17154423786061151, 0.1700777608369078, 0.11788046386625085, 0.09230344596185855, 0.0730726168091808, 0.20649147831967898, 0.13446157984435558, 0.0646236412493246, 0.11214621192110436, 0.12477961794606277, 0.24703782690422876, 0.15497739825929913, 0.11400539108685084, 0.08149451203644276, 0.07814246762011733, 0.12353418049003397, 0.1429068302469594, 0.08061703733567681, 0.07755227107554674, 0.12189536914229393, 0.152852579419102, 0.08072242060942308, 0.17231608501502446, 0.07039498870394059, 0.16778015983956202, 0.21483087725937366, 0.1293853779456445, 0.20408193261495658, 0.12703354842960835, 0.11619289299207074, 0.12192944517093045, 0.2378806168479579, 0.11897271525646959, 0.09581127523311547, 0.24678907596639224, 0.11956979893147945, 0.08332425635308027, 0.1363267640450171, 0.18824428745678493, 0.17941194639674254, 0.1894540882536343, 0.08033150979982955, 0.13558127119072846, 0.1466075602386679, 0.17986872260059628, 0.0845401571797473, 0.08102454511182648, 0.21701627570603574, 0.13074653276375361, 0.24744166380592755, 0.07625377218105964, 0.15707293152809143, 0.13263398648372718, 0.16932755894958973, 0.18046860183988297, 0.16151705091553076, 0.15866847948304244, 0.1514077883745943, 0.16410129224615438, 0.10099286719092301, 0.09160357780222382, 0.09711217614156858, 0.14047204303954328, 0.08003675418772868, 0.08925788902810641, 0.24620094895362854, 0.08228262367525271, 0.23535945213266782, 0.11487671147499766, 0.1153410194175584, 0.11960339998560292, 0.12160549898232732, 0.21345434683774198, 0.09441078573997531, 0.12124206205563885, 0.16868926105754717, 0.1267371100506612, 0.11804993477250848, 0.13843698081161293, 0.15187774172851018, 0.07965853198298387, 0.24019615831119673, 0.14048953567232403, 0.10998186163072075, 0.11065409984439611, 0.1626871574137892, 0.09705424960702658, 0.10986189663942371, 0.05061982518860272, 0.16775843314826488, 0.05576726308624659, 0.10670248831489257, 0.11578906966107232, 0.16951684307839188, 0.12211520091763564, 0.07913642642753464, 0.15417682193219662, 0.12155185400375298, 0.1111931416339108, 0.12221419917685644, 0.20000382858727658, 0.16000562773219176, 0.09069302451929875, 0.12620098596172674, 0.18135953189006873, 0.050963913689234426, 0.07393819679106985, 0.08861031556235892, 0.14699644222855568, 0.12227062614900724, 0.07629951222666673, 0.0979576918429562, 0.16298838624996798, 0.10164551609860999, 0.0667421090017472], [0.024353047600015998, 0.050799494476190636, 0.0012118075641670398, 0.02953951313559498, 0.027407717259068574, 0.05321354226076177, 0.005038669582323304, 0.02272944731105651, 0.051875237109405656, 0.06420381127723626, 0.03380837710574269, 0.05031115282326937, 0.03544410111914788, 0.026477920723014643, 0.028270642472697154, 0.021497794293931553, 0.0931847815268806, 0.02471391118264624, 0.002958345251889633, 0.004940004229346024, 0.09062671129192625, 0.08577085006982088, 0.062420438043773174, 0.021224215759762695, 0.027665358701986924, 0.06562082988343068, 0.029381723209683384, 0.034239837168050666, 0.01579420025726514, 0.02973358432895371, 0.013544631057551928, 0.06455142476728984, 0.020011505744020854, 0.06592630634882621, 0.06672642805746623, 0.028974938073328564, 0.008771378081291914, 0.007223631222067135, 0.032711331865617206, 0.03251937770151666, 0.08706805974777256, 0.012335500314033456, 0.004126733784297747, 0.0231738758739084, 0.01106262459818806, 0.008291284869691091, 0.027851977884503346, 0.019111770005630593, 0.07780033669301442, 0.022593568977234618, 0.03732224194599049, 0.057464296131261756, 0.14388485705213888, 0.03991819479103599, 0.043584441633096764, 0.0382802146486938, 0.08375328726002149, 0.055580177410904846, 0.025208970332252126, 0.00908289011567831, 0.06760203000158072, 0.03216570828642164, 0.03567928474928651, 0.0035024626953859945, 0.06430580866123949, 0.03009501618466207, 0.030610845291188786, 0.039230306167155504, 0.013040592345143003, 0.054753993172198534, 0.008423489784555776, 0.012241954931856265, 0.02009651261115713, 0.04426865938252636, 0.13456507000539983, 0.007741374645515212, 0.015586629609710403, 0.006239801246140684, 0.08584627602249384, 0.012422506314968424, 0.010379860610035914, 0.0276468703190663, 0.06001176764922483, 0.018027528721307005, 0.02624839268225644, 0.056636880351496596, 0.029858003902648176, 0.029535245150327682, 0.028444976778700948, 0.008991069060617259, 0.026392505038529634, 0.05205836692558868, 0.07568034223679986, 0.0417012525057154, 0.0282102257146367, 0.02134548862730818, 0.06747923551925591, 0.03457896557769605, 0.03781428500743849, 0.02123291797137686, 0.022959260336522545, 0.019694597659898654, 0.018270008299233656, 0.04582244350707956, 0.0184125396689134, 0.029027785773255994, 0.050684418329702954, 0.017845040120716606, 0.024805116467177868, 0.021760007366538048, 0.0563748165565942, 0.07532470167747565, 0.04162537532725504, 0.02395439300952213, 0.05959024812494006, 0.017279331904969046, 0.036419678412910016, 0.03519541464213814, 0.0019511465299209313, 0.04324003422100629, 0.0304972279949912, 0.04475267876737884, 0.05112175789794751, 0.03390387751694236, 0.02619949066346245, 0.013015285533453737, 0.013887795902389501, 0.0200306353425341, 0.05352750041389039, 0.03243680338242224, 0.03818882955238223, 0.04377620580739208, 0.012281666193822665, 0.04220813852069633, 0.04085765027308038, 0.03177167960841741, 0.019852413030873452, 0.01852965820580721, 0.017785368054839115, 0.056294790136494806, 0.007375981841635491, 0.005406867704420749, 0.020437333965674043, 0.0489023852029017, 0.03047821205109358, 0.03885121883026191, 0.0405412120744586, 0.03337499339665685, 0.03418004126953227, 0.02418318823246019, 0.012073177827655204, 0.034903410489537885, 0.04292029834219387, 0.06433956577841725, 0.0535176073733185, 0.03631428156846336, 0.03197521636528628, 0.026790747418999672, 0.044124701392969916, 0.04228263148771865, 0.0760129668882915, 0.03841947039057102, 0.029694612670157636, 0.01725028551715825, 0.06563549981053386, 0.012306258847404803, 0.002701949980941468, 0.002382647940456601, 0.049459279248757024, 0.010394254882287766, 0.06874915451875754, 0.042276066661413224, 0.0477182466004576, 0.04559914781046765, 0.0379196072130331, 0.03881407921601619, 0.048288144769945314, 0.005194205075635442, 0.047830639140946526, 0.0014519807591568679, 0.05032307129087193, 0.019900957122445107, 0.01161648559251002, 0.0022449536772910506, 0.01671024288849107, 0.032560191582888365, 0.02539760815644903, 0.03543527337855526, 0.008627167337441018, 0.06823381395744425, 0.06730158826602356, 0.044052783466343365, 0.04678470455110073, 0.047144677556518993, 0.028250947993780886, 0.0369425507129303, 0.03693203002746616, 0.019024652894586325, 0.08355940944914307, 0.034758217566247494, 0.02460193424485624, 0.024788214159863334, 0.11744586218680654, 0.017464941766645228, 0.06591623010379927, 0.008657067831206535, 0.03396860636504633, 0.0501131359487772, 0.018235028122684786, 0.017511808180383275, 0.01999105978757143, 0.004670291648445917, 0.020952506589570215, 0.05234818958810397, 0.03168394842318126, 0.039565400686115026, 0.029391307516821792, 0.02156356130061405, 0.015241947390937378, 0.07234753428825311, 0.03642665036022663, 0.04537332796358636, 0.05398165747257216, 0.012981744699313172, 0.06435684806534223, 0.03168012827102627, 0.04171331685834697, 0.04704174379419003, 0.03518324172390359, 0.04602678432794554, 0.03306904195674828, 0.025919917272403836, 0.0289871177769133, 0.06470811207379613, 0.017323182230549197, 0.03632044605910778, 0.028944868793977157, 0.04306885679917676, 0.021810330916196108, 0.027727329305240085, 0.019260226682360684, 0.0358742821429457, 0.036285959516784975, 0.02397189921300326, 0.011568929617559271, 0.034397216580275974, 0.031635100687188764, 0.03396988879623158, 0.04577017595459308, 0.03016817243769765, 0.02289838726366205, 0.028747530454503636, 0.052949368221951384, 0.04475443956575223, 0.013124335440807045, 0.028707418856876235, 0.03196944881762777, 0.0075954819829868415, 0.02183385063628001, 0.024271801513220583, 0.026197819770979028, 0.06257131709051983, 0.029949022590049675, 0.0842450148026858, 0.04096924553492239, 0.027152966375329664, 0.07256819387631756, 0.00645241468113714, 0.03145888853552086, 0.07210917850690228, 0.03628635306709579, 0.007709144232129412, 0.03851134063942092, 0.04083302962992873, 0.021326320013031363, 0.033363997736679654, 0.023631418822333217, 0.09659145479755742, 0.022985687579161355, 0.015528770928670253, 0.0018731211519999696, 0.011578091536648571, 0.04364182533962386, 0.032997541329158206, 0.027771308552473783, 0.019621643271031122, 0.01924644733246948, 0.12019090274614946, 0.02187262212724558, 0.019296346797740886, 0.042461629025638103, 0.028877819356109415, 0.05545206321403384, 0.031365318556449244, 0.03321806521021894, 0.05691113402800901, 0.012560435520884181, 0.06887807617230074, 0.028873527622116462, 0.023865348859024898, 0.0338766987967704, 0.03534091629886201, 0.04196932812088302, 0.09160505700856447, 0.03482710922669087, 0.05165215515132461, 0.031619443491633446, 0.044989996390151124, 0.018739771663344333, 0.0166285472722458, 0.040663548545645814, 0.011508190555364957, 0.060728687393878183, 0.03774919992844973, 0.009182911266439726, 0.04106476630217262, 0.02399967674032918, 0.025486922024616172, 0.015070846304297447, 0.06537772435694933, 0.01179716589727572, 0.04998251795768738, 0.017453491488205533, 0.024633828783407807, 0.027584582500691925, 0.02842797269113362, 0.0357951581744211, 0.06464886918131794, 0.02600597247614392, 0.03872908591958029, 0.013254056069334703, 0.07115619642926113, 0.07432691593255315, 0.026180481504915015, 0.01378256275451609, 0.021351992385461926, 0.036480461579880545, 0.04259010963141918, 0.049324922529714446, 0.05826812942645379, 0.02568704235766615, 0.011150088610260614, 0.02678013513130801, 0.08098700855459486, 0.04567560852904405, 0.018013852848006145, 0.0384219877554902, 0.017611725854554346, 0.03973239833222968, 0.020977122143709233, 0.032821478455194404, 0.047912378861968, 0.18241196684539318, 0.07859137281775475, 0.13138860331049987, 0.06985606905072927, 0.09291703160852194, 0.13856639101036958, 0.07430519602660622, 0.09738422797194549, 0.12173444777727127, 0.2282127413366522, 0.2530326837939875, 0.14752023055085114, 0.14130696680928978, 0.16378681840641157, 0.09597012706633125, 0.08343681174197368, 0.1416746920772961, 0.10317344803895269, 0.11612111755779811, 0.12328491386558328, 0.14780710158603533, 0.1873357290668147, 0.18971247438873562, 0.13352323376706668, 0.13645115308463573, 0.10474002254860741, 0.22103948625070707, 0.0762315501591989, 0.13494743805910858, 0.06992553068058831, 0.09580198608871017, 0.11455043112593037, 0.1122979527073247, 0.1238975359925202, 0.16097674705088139, 0.059591476273323805, 0.12729067248957499, 0.10697502869048289, 0.0687743756654007, 0.09743274322577886, 0.14404782759291784, 0.10736602092427866, 0.09645876048931054, 0.11005008832684585, 0.12139794869082314, 0.08457136300525495, 0.18954822820212158, 0.146226060709783, 0.10872964560985565, 0.1275980488530227, 0.20098281891218253, 0.12172581681183406, 0.1849774263267006, 0.08908954448997974, 0.11799994031233446, 0.16204533113964967, 0.13687560388020106, 0.23169853857585362, 0.2895423189869949, 0.14086168498865195, 0.11918809584208898, 0.10583042832357542, 0.10990790131368808, 0.12967587235782826, 0.15025171398052148, 0.08538166952452489, 0.0955277561609234, 0.12174134169306074, 0.08101267753435032, 0.15205222022320541, 0.10774844326078892, 0.1053279052887644, 0.08331519791058131, 0.14188197095479282, 0.2386372648179531, 0.12995366459446295, 0.1065944858959743, 0.07954368314572743, 0.179800489119121, 0.14191656267004354, 0.09659222154212849, 0.09403510125620024, 0.16299082897603512, 0.09955752135387488, 0.094054195231625, 0.17005364570234502, 0.10434626867728573, 0.17691086631800446, 0.13072566102657998, 0.10544941733990397, 0.12984667319272244, 0.12339459226599761, 0.1608864204691989, 0.11012397400502648, 0.12368064905915942, 0.13556612628911222, 0.15530990755983762, 0.1507751630353076, 0.08308849257550069, 0.08676256292632648, 0.07366342403526817, 0.08424760680645704, 0.1504792267722743, 0.22075617073902062, 0.1448086689093283, 0.1577619295567274, 0.09845435912055628, 0.06437208117651087, 0.17343983400080884, 0.16272815449961595, 0.126004658639431, 0.18053455544369562, 0.11221295941088881, 0.17581127317888395, 0.14506139606237411, 0.11874600313603878, 0.13718014396727085, 0.12767287769487926, 0.1289201471954584, 0.11585247197321483, 0.10336327499576978, 0.1462824469698327, 0.09747018478810787, 0.10470108820923738, 0.08755238447338343, 0.16450373136571475, 0.062270536087453365, 0.13460046239197254, 0.15902210479336126, 0.20209404214152268, 0.21307105597640785, 0.0790036642657859, 0.1236437096127442, 0.0739460474412356, 0.10818197285490376, 0.13067106609897955, 0.1820040587335825, 0.083913075471563, 0.06082525649773223, 0.10961049941501447, 0.15460944228938647, 0.10967635802392449, 0.07837230100163392, 0.11199827771633863, 0.11636195677731719, 0.1499226652085781, 0.09042121017617838, 0.09069915847586733, 0.10824016401810305, 0.12332367178584848, 0.14238435828260013, 0.127660351938435, 0.22812279473458016, 0.17621416013155664, 0.13065745468650544, 0.128686500447137, 0.1136996771341988, 0.14823425295097487, 0.08983329350927047, 0.08161243463733367, 0.12589158756392343, 0.21081863184060368, 0.11013428773730993, 0.11150652303227357, 0.13835449809474604, 0.1056448422106249, 0.10004325064697436, 0.12125088301088129, 0.14427669745470795, 0.08393673598766327, 0.12334286075617586, 0.08298947396022932, 0.12846721149981022, 0.10247533049966608, 0.16998372945402349, 0.10023654491773673], [0.008437009594802345, 0.04318878107837268, 0.008681814003336643, 0.07780839768903595, 0.03960568531017218, 0.02100246542665575, 0.005917497536367071, 0.018199493243758167, 0.023502378425161754, 0.03785476640665105, 0.016122972526188408, 0.03612987271377018, 0.041946950035967996, 0.01665203136924122, 0.05717459560504981, 0.02862538058044655, 0.023967459897643754, 0.06439844904733555, 0.02491320200663592, 0.0648992011057479, 0.055153083721441884, 0.04027118906378746, 0.03913865644218666, 0.049141236314816136, 0.04657284216955304, 0.02019471359173102, 0.01244025509471872, 0.010361356111908597, 0.008553385135850735, 0.03379812104893582, 0.032722724468580315, 0.02436114421912602, 0.034742716433746476, 0.08025524924908366, 0.05605689575895667, 0.018177832709625363, 0.05375593262059348, 0.013423468451946974, 0.05495000497571059, 0.03831789030560425, 0.041984401776322296, 0.03718295227736235, 0.014915824801261936, 0.049882145665053806, 0.04068651695602706, 0.02686027011701039, 0.021577187980126058, 0.043583617213049104, 0.00994647350827498, 0.02550952911509999, 0.06617148819246463, 0.022273364909259335, 0.034785216474639516, 0.04348704810919506, 0.007045755811434771, 0.03311847662553191, 0.045622971174972396, 0.018605844117701054, 0.030410104098596742, 0.08130215414400611, 0.040393471252173185, 0.03353306830727628, 0.01416075527335384, 0.013208710422207202, 0.02355201156543834, 0.018730167000155364, 0.017549088590645363, 0.02974884118884802, 0.047156148191009245, 0.0320941906954561, 0.016564318843718086, 0.02332820018221225, 0.01252037481338318, 0.07078455601419721, 0.02196957460338516, 0.01216630166995206, 0.04205324933198946, 0.0021677565361772266, 0.04585653989176665, 0.026706103568098376, 0.03908753900655678, 0.0236112459762288, 0.03604254186419504, 0.015188297323350395, 0.03429618271599923, 0.010092407731073243, 0.009401874516957572, 0.03282328335834401, 0.0504307717617069, 0.017864444525912404, 0.011906091123819351, 0.02781970675901643, 0.013354827001291727, 0.02570286749063858, 0.015400210595024484, 0.01211869141219982, 0.022767306172422, 0.04383974721921342, 0.02498070097395352, 0.023315226592655693, 0.07229436428419181, 0.07334382725613457, 0.008314874139614403, 0.04106814879924059, 0.12919935078493186, 0.030111046574477638, 0.009174589034436005, 0.059004733471998146, 0.019123958190903068, 0.05633763623024736, 0.01883044938689896, 0.03561268314453108, 0.024809857730620673, 0.03879353656832661, 0.04890958785212465, 0.03545778377779892, 0.048154045894209824, 0.01593323886793639, 0.019019044802657196, 0.029673818964511156, 0.026096538241420473, 0.008997177572122641, 0.059525400533207824, 0.03023517777078918, 0.03847655214901481, 0.03423898899927735, 0.03363433626613446, 0.03576200495340994, 0.038343026635370085, 0.04460953841251986, 0.02931919620771493, 0.004674974812327751, 0.03990431535722954, 0.015530399412715008, 0.05746730204139437, 0.03592591526518975, 0.014622327871620655, 0.027071542173091854, 0.026097471227071116, 0.05839259989027466, 0.03675810114613601, 0.05072883523202368, 0.03147968563384243, 0.02864596733291234, 0.09886386857501098, 0.057666017806955745, 0.03200803031878812, 0.045838222838938236, 0.03658664891762393, 0.03259174006858042, 0.08832199246223484, 0.03779748448037675, 0.03697485915784325, 0.018275316139417033, 0.03530662653169461, 0.034770828139569075, 0.03543971099757722, 0.0396694370678493, 0.02788960774030004, 0.05775716541601079, 0.045981051067688634, 0.028375655944858278, 0.06540835342769112, 0.017819666303694248, 0.05591797249923859, 0.050431792956909964, 0.061678419288780005, 0.025232096502025212, 0.03344509284943342, 0.040836466409798176, 0.09137206165386097, 0.05650295450219086, 0.018183474728305424, 0.01403708293634866, 0.031446902214416435, 0.01134038036356547, 0.031186490652284453, 0.036715763953647444, 0.0034533034694114967, 0.06415066162922553, 0.030050779094121287, 0.01731679043067353, 0.06295065887804542, 0.06064802315086126, 0.022934344530637776, 0.039508600519703965, 0.04056679963001183, 0.01918339785853667, 0.0544718684894698, 0.023148100024887493, 0.0739779860845634, 0.016029168452535356, 0.03670565038919449, 0.05070620948182685, 0.05701980819659574, 0.031561167511556826, 0.02994342128347073, 0.03306484521765794, 0.05836278506155525, 0.07707291322627238, 0.042234950831958225, 0.017199451369898658, 0.05529882965077247, 0.01560964891021805, 0.01628273698900427, 0.020913168521864072, 0.04271516702803118, 0.03539305492969496, 0.039185407504971535, 0.044709632505795786, 0.049890230409801006, 0.047010632963585, 0.05123282729515007, 0.016861361118831804, 0.002417324048500242, 0.04239642859569617, 0.005208089598454535, 0.025519642679552947, 0.046907675452530384, 0.060338584040956836, 0.02639209452484335, 0.013802786490746906, 0.02854102510692818, 0.037390828265675476, 0.03203144995495677, 0.041821007151156664, 0.015741259258772646, 0.03945644153282046, 0.027494715626484582, 0.05114116060680576, 0.014061027588987989, 0.05706399439701012, 0.035626850955720456, 0.07435533976448433, 0.08939657480056797, 0.02474348004242139, 0.004117013346071222, 0.03880905805687819, 0.053515866930995665, 0.034294045330690484, 0.016149325129975165, 0.061167869184698374, 0.0219171916999455, 0.0407290203895952, 0.07085644001407282, 0.017535178622763072, 0.03155722861577358, 0.042326658232403655, 0.03683602750035269, 0.09827716648578644, 0.006254645896011165, 0.042878212207662206, 0.007243698047074888, 0.06269419978239707, 0.06002687183873994, 0.016522573673033288, 0.01551865566787975, 0.025290978074605976, 0.01455498836003244, 0.03308848877038274, 0.028381079135994827, 0.02769404207356274, 0.018665182005081857, 0.042312358106885634, 0.023301811955337013, 0.01763432107067534, 0.05163961582417999, 0.06594607207391943, 0.04298457935718553, 0.026365925125511627, 0.009882400294632783, 0.007633856530966503, 0.03827143440555249, 0.06518997371728931, 0.014716264259602343, 0.0503886008102979, 0.04210497405646103, 0.047189769601183276, 0.05954011117241212, 0.03656523435243538, 0.07091120457542793, 0.052262066530862024, 0.04843453870021871, 0.02401251462288201, 0.03147420646356685, 0.007619424939288625, 0.047750470228493214, 0.04947217141411134, 0.017846537986770272, 0.05662822224465864, 0.013580874157404261, 0.027513655235192606, 0.046741848279322894, 0.009737930859306028, 0.014020474943598467, 0.030457818681108098, 0.014722382949133004, 0.023623897261651497, 0.05107027744608266, 0.02242182837133961, 0.018196673930755684, 0.038606091269424984, 0.08702216363911118, 0.050630915843482525, 0.039502296929380724, 0.07718880700745753, 0.02800105033176286, 0.030533339628683667, 0.02790654058169041, 0.030558045088712658, 0.05852716016982283, 0.06202996828194175, 0.0510836615493255, 0.015397362444283707, 0.03858784207009843, 0.020758596548278416, 0.03045028354972601, 0.03379912867343851, 0.02642610778899065, 0.02681687780256782, 0.0482078265797879, 0.07246124318667821, 0.015898675990423987, 0.050972649827599525, 0.05287506863740938, 0.01073017466946372, 0.0404358864761889, 0.011816648333998663, 0.04510803094932011, 0.011950048318664943, 0.024084888864308596, 0.03922624513506889, 0.05264922504180244, 0.019257911181609546, 0.05664449351440583, 0.020107567642948458, 0.028735072551561252, 0.032391015839363844, 0.021973927405529788, 0.014240560321403401, 0.04245943396485277, 0.014089823767010654, 0.028595514861600738, 0.03761941992810794, 0.016082564069490348, 0.03374377717929227, 0.050063070242426226, 0.028577964553343396, 0.07645420464021818, 0.03573876852169633, 0.02936070558748075, 0.02266674897899585, 0.1422217134386301, 0.14154016572449887, 0.11182874574192933, 0.17651218628244741, 0.11229802056082658, 0.10887392929622106, 0.09508434031158686, 0.11376897591565337, 0.16858304318572792, 0.11692059465817042, 0.12120346698377814, 0.14429067527609213, 0.1375800860779626, 0.07129313836672477, 0.18066150934568473, 0.12325908882277352, 0.17697004814233097, 0.13861977814563683, 0.14411850380046026, 0.16305442127798284, 0.09382594962205205, 0.1453177330217191, 0.12583089939185552, 0.1699115333280393, 0.09641006203102213, 0.12765466581497872, 0.11031409951725177, 0.12918168173304626, 0.09984140683497701, 0.053049771048660786, 0.14263020509055682, 0.09821476840547153, 0.18560308989669594, 0.23137921999607766, 0.15570326788084848, 0.07256986985781363, 0.12677684506135328, 0.1253935428602355, 0.15134460319365772, 0.09472164298806872, 0.16533641596989973, 0.12193237644221101, 0.07724883021520716, 0.1714013655270849, 0.13264006615749427, 0.1271825818611043, 0.050677873859448094, 0.1850546028997217, 0.08889867937458412, 0.209867122183953, 0.2207539180027587, 0.12401252053678036, 0.16844014371080057, 0.2205775124686105, 0.088082435673901, 0.10016329027712345, 0.1484448973621641, 0.15848992977823528, 0.16720550853226865, 0.11803694761225156, 0.09108723300908293, 0.09422783234289714, 0.11718841243003096, 0.12666874086218222, 0.08391884980457169, 0.11674568190106324, 0.07468454459948198, 0.09795544589204447, 0.16668952336268766, 0.1029919602775148, 0.12059411539563111, 0.13569492580635206, 0.12959116404610022, 0.17859482738588536, 0.10881845905844655, 0.1365289403391736, 0.08478284879986729, 0.1315405001597745, 0.09010895514594656, 0.15412613536630357, 0.2072228712162801, 0.07993224622415644, 0.09779000548379761, 0.13223808844174656, 0.11858918012252875, 0.1415381979729448, 0.08977731437023197, 0.10993919534874813, 0.15002888308039733, 0.09467433552656855, 0.10395679636193172, 0.12556561934096472, 0.11210849894476788, 0.16590918094984122, 0.08533274714968034, 0.15073975707803453, 0.16273637834404195, 0.12912927168820584, 0.09545214700379542, 0.13770480081439018, 0.16325081645378045, 0.18807294379387582, 0.11529649394963469, 0.15382087603211403, 0.21284958214632102, 0.10793668244566236, 0.13530828298202582, 0.10739527935428278, 0.12426075578800269, 0.09403966101152555, 0.11689938365348748, 0.1218803192355803, 0.0923464447259903, 0.11108643521687814, 0.16046218680483954, 0.11884018379662718, 0.10695818066596985, 0.11312428622373513, 0.09038372111639806, 0.10252244118601084, 0.16399412442530903, 0.10277244741363184, 0.15550898973430904, 0.10718332537050758, 0.04922291836036103, 0.17393152761672223, 0.1450650194393737, 0.12289455266935484, 0.15534065876688274, 0.14802466705441475, 0.169624621580754, 0.08101702015846968, 0.1128970787727407, 0.19947075790592603, 0.1665603710072381, 0.10862858460417815, 0.16378166154026985, 0.06732040404209069, 0.13667367185865129, 0.17883923569960253, 0.1321724469640425, 0.1703050293560539, 0.07376743666827679, 0.07109688568328108, 0.16612625787300722, 0.2015361777905907, 0.15010344050824642, 0.13136607594788074, 0.1671626115483897, 0.06594917297895465, 0.16547514923981257, 0.10383390688470431, 0.12971207898642334, 0.064341594598123, 0.0671523716300726, 0.09245418251625129, 0.12024232212986265, 0.0998956828511187, 0.2220738043210336, 0.11046831695629017, 0.13154910398381098, 0.10712096800229379, 0.23872699428881916, 0.07547467827264752, 0.11590912964727197, 0.08947922036583934, 0.15778197348117828, 0.08729621714779309, 0.13303661559309277, 0.11414478932108198, 0.24279692875487463, 0.1840049092258726, 0.12150168312447411, 0.14230913589043276, 0.09881664253771305, 0.10079300470118012], [0.063072062363582, 0.0720805578998157, 0.029951417818665504, 0.016089464770630002, 0.03806325646915606, 0.009148431509467108, 0.021856233810207674, 0.05430685895095978, 0.025854180799797177, 0.015835646872541735, 0.012745684062662934, 0.03001561401677983, 0.03537842232201781, 0.0594267144000956, 0.023217324167490005, 0.021626157852421914, 0.07178671830998999, 0.03378687433100172, 0.03713167538600309, 0.04684851059157934, 0.04967269208282232, 0.023059490136802197, 0.04566854497949992, 0.05313349887728691, 0.020303903446931924, 0.013771764717863073, 0.02050659542770258, 0.07051420730671712, 0.09601195875023093, 0.06470041748668466, 0.005389277532231063, 0.04312157557745065, 0.05580548835652215, 0.008408636652997561, 0.03624514224273818, 0.038431514387152026, 0.04933516501582094, 0.10608528607657977, 0.017208725247266035, 0.026867084304935167, 0.010601520189084113, 0.0432663342383291, 0.0325979283079505, 0.039715061762503216, 0.00995132842633341, 0.01065128734002688, 0.04997464355879596, 0.009691564016975462, 0.01697320065328053, 0.01684028751749013, 0.02867059815408928, 0.03733309172093868, 0.06464242309864078, 0.031128699824746166, 0.019955423128392016, 0.007434413036597627, 0.03421257023832627, 0.03736708971804806, 0.026008878302361284, 0.02230155803928418, 0.07726169523916074, 0.039749290461518934, 0.08473166690341064, 0.03812157655400889, 0.04170785804412194, 0.022727152166355933, 0.035454645553337674, 0.05768764271800007, 0.03374690183305314, 0.046757814208311696, 0.04092409581478153, 0.02379770570301584, 0.010095174457611782, 0.013227344690156835, 0.026460241493103758, 0.023658124264329672, 0.04929558267550809, 0.05545154752741967, 0.027570804847138267, 0.017830887576565146, 0.0519254690568362, 0.08747793561113731, 0.05959062131920031, 0.04826540366879531, 0.07746978835867983, 0.050573935865291526, 0.025050335630242313, 0.03208074213138648, 0.03596365199025188, 0.046301753858902624, 0.053393577957259755, 0.004007166160071003, 0.06772391524698053, 0.0782871652128441, 0.04089502398190754, 0.046846033938761265, 0.05456155724823475, 0.034655256662517786, 0.06057962003563132, 0.0214476420743657, 0.01181352198390024, 0.07729578483849764, 0.09651353862136602, 0.015917851390050988, 0.007552828423545829, 0.0872807465493679, 0.024167844859351004, 0.058881545439362526, 0.053207255633813996, 0.03684209021074431, 0.005525540510591651, 0.06410424983394997, 0.06375992723873683, 0.029871829053653137, 0.06845582383019583, 0.009320645393537623, 0.054834664200565646, 0.06721817595618111, 0.01660678326152265, 0.03331748416115131, 0.036221644575042386, 0.007961629657074809, 0.02836804447828659, 0.03285976140094655, 0.03887835005298257, 0.07036292113895927, 0.010686085160289491, 0.029162203560450246, 0.06841292006096669, 0.023911614769271443, 0.042777266552937884, 0.04239221150055528, 0.02300178412614124, 0.012729591756526912, 0.050869566787566455, 0.00463671943206074, 0.04073345800861716, 0.03282180415200336, 0.02596658012563629, 0.05208166442545397, 0.04312120238319039, 0.03617654913770301, 0.015291907924360462, 0.024154616819162453, 0.018991723590131317, 0.021437796531245112, 0.005320610636512616, 0.0798306627465146, 0.03582356504297682, 0.02785315005374806, 0.01908888980480177, 0.030427518699850355, 0.09391457986618791, 0.03880724297570331, 0.04716203108962093, 0.034392901097557375, 0.040522772885326824, 0.03660296089947224, 0.007321213887605284, 0.009175688261166215, 0.028897371342671768, 0.05958838215363877, 0.05977141697491918, 0.05276859292228307, 0.032148249580391815, 0.020597324041383605, 0.05012888474656003, 0.045611405545579534, 0.08213657579783883, 0.016551726930109516, 0.018072288283812146, 0.09549545789403574, 0.02700744945156787, 0.028762882309300557, 0.0760762674201812, 0.03368381503969431, 0.08133251180074044, 0.06147901141749961, 0.004035496693437121, 0.022664061980322003, 0.008738894065442895, 0.023973373330331275, 0.034213102888315916, 0.024785377883485386, 0.03721317761976804, 0.074531216041318, 0.03205379072044577, 0.027933324055214013, 0.04653788743806737, 0.03329082112759352, 0.008464058545151991, 0.05970384845776217, 0.0908516456506082, 0.06863962539604732, 0.06261850241571665, 0.014010009389104587, 0.032485976815223694, 0.008136451660123254, 0.02233807509765029, 0.06131262106022664, 0.02276460899572287, 0.038127062509634664, 0.022751922087211694, 0.03986766428819724, 0.019848745549097657, 0.01364773784631065, 0.02342346989150558, 0.025783178895445805, 0.03446074442139693, 0.017715594298871498, 0.04602021271628993, 0.04309962496959737, 0.08813037417296853, 0.014109134025472616, 0.019824165618047118, 0.05322739116049238, 0.016248226697955812, 0.0887587247416377, 0.012339811555908194, 0.007918367960623332, 0.0361332789595638, 0.08987433809254851, 0.04213644111795085, 0.040143027369465144, 0.008311554407035666, 0.06181368524474757, 0.04004783908437405, 0.03680704726970621, 0.08031459392181464, 0.031107444715287005, 0.0237349971929299, 0.0548368456906506, 0.01622943127793925, 0.01739762770012021, 0.0121885839117957, 0.053771939261683395, 0.027367313891383152, 0.024085228131817918, 0.028335807279550602, 0.006152142579334655, 0.02663332050932305, 0.01999674421469016, 0.0216509905377669, 0.023758138629740903, 0.04726699027898056, 0.01832086280254381, 0.05976374952920845, 0.03124030526461346, 0.006426487433990198, 0.006029510097245553, 0.06196963973343372, 0.004253990906623325, 0.03559627616778016, 0.025064888510054777, 0.01593386990550373, 0.006250083172095141, 0.011726931585664195, 0.024811939136790376, 0.026509874633380344, 0.0310461492543774, 0.058702751461948664, 0.05295465400974665, 0.04833411891013384, 0.030920026557786123, 0.011187531020758408, 0.02522512964372124, 0.028241979457171898, 0.03422332162569676, 0.0748306806864483, 0.07987896765449218, 0.003591285685875586, 0.06763983118746962, 0.021386433126670972, 0.016840134847110937, 0.0045285838506450606, 0.07266598434320518, 0.06662219829325165, 0.02477818201961262, 0.05165424843185714, 0.007857714563475122, 0.1120661651449544, 0.03657975500183446, 0.01899506028608552, 0.05074907932430506, 0.05332707134740693, 0.015146346895822456, 0.05680960822584374, 0.06518554288361754, 0.06616418037031378, 0.09298991305487496, 0.02830251326252307, 0.014251114933618476, 0.0321792348820184, 0.020946162287145853, 0.05041830028806414, 0.08281349590314285, 0.022000587046412483, 0.019833580291430866, 0.010698191073190953, 0.024603664509153793, 0.019940235818337117, 0.027784672299666063, 0.03021997180102127, 0.004674142758761133, 0.06445598203156676, 0.025754917911919098, 0.051532302118305645, 0.047831080188708644, 0.007999094968129481, 0.01369853552231299, 0.04491174773180059, 0.020314620907551477, 0.09132467955350876, 0.03648591360875538, 0.0387225550200258, 0.04543397203087807, 0.06723777883286987, 0.006732448627839663, 0.044308201010738096, 0.031380921469203064, 0.010629708230096315, 0.03605851797120912, 0.0076228998867528775, 0.07118961427892957, 0.027053574565798044, 0.014911573779370104, 0.02795562580493944, 0.04218278845239963, 0.03211514385683196, 0.027911990914227705, 0.05037809369553413, 0.025681690412706563, 0.03618122763665659, 0.05054267914965749, 0.02810253033281437, 0.04731303905802114, 0.017308739612677267, 0.014788395924759763, 0.02973299061081239, 0.03222367553306477, 0.007168795414535063, 0.05598440107756427, 0.08139617195619003, 0.023562656083543385, 0.04037207365036011, 0.027536644001624415, 0.13283791339823178, 0.04714104060881904, 0.001026931156437578, 0.048374386570815525, 0.05710607035351651, 0.006609414113752011, 0.19814164351139749, 0.1870821062475443, 0.1458265528615032, 0.1838507324989353, 0.08828733289348227, 0.1711830808115857, 0.16835219200168336, 0.1022254056962473, 0.17058036529592105, 0.14186179132333823, 0.11789476738444396, 0.16290435647325857, 0.15574060087757452, 0.1490865879292999, 0.11755659910184996, 0.09655967900263411, 0.1930743304214307, 0.29330384571637425, 0.0989235525152513, 0.11969829989331109, 0.08836277241685561, 0.058814512964870246, 0.11108079659087317, 0.16602928164814199, 0.10781705672187464, 0.0883652354989733, 0.07745146791317634, 0.2266944106668234, 0.21306542413575308, 0.1826337528015886, 0.11160463241061994, 0.10260681701557976, 0.09867645720286028, 0.10259925813547202, 0.09702285379171371, 0.17413202114403248, 0.15378502224172863, 0.15657365189066955, 0.12287430518439837, 0.1117953753897122, 0.07453952130994626, 0.16498327920479433, 0.11260940028088433, 0.09771820290812425, 0.07207189300762755, 0.18346484963382992, 0.10557623553488936, 0.06640943685280425, 0.08982386865786143, 0.09863783498959881, 0.12745071175907338, 0.12376896717718669, 0.20298174236501965, 0.15424738957413606, 0.17736285206462654, 0.10978852664785725, 0.11870048700698785, 0.11913801995771271, 0.07614340167492628, 0.0996585755742022, 0.22202645614743233, 0.10754932715956654, 0.09108532632568053, 0.21504214592278004, 0.09568810077118022, 0.09045631079269306, 0.14820678585341998, 0.18239429779350758, 0.1301852214549269, 0.12545496385012353, 0.1303054035774299, 0.13292316453797476, 0.06425512209534645, 0.09973755026502268, 0.19731406149055275, 0.11094862475459065, 0.07361992315522262, 0.13247311940150602, 0.09147896484604903, 0.09853714717818157, 0.14534140032316956, 0.12021496359791074, 0.1380848754197359, 0.12072558834084443, 0.14665277781231062, 0.12968660678182328, 0.10319472011178732, 0.11995437900934901, 0.10360476560890675, 0.11806364117988519, 0.1076104903061475, 0.08009835838207177, 0.17329313472977706, 0.19357628348682607, 0.1197778649095978, 0.15259565891964094, 0.11964268716318266, 0.1515795662999153, 0.17537771644336836, 0.12296073697507381, 0.14448042080870696, 0.09964960534125566, 0.18954991096896784, 0.1585267742297479, 0.1342809945344925, 0.19785868083792074, 0.12286960972206933, 0.18807115246142658, 0.16957499352949007, 0.1531499270349741, 0.1488161510122674, 0.15253555428768906, 0.205855093896389, 0.17198590987495013, 0.1041283028732453, 0.1634144519588777, 0.16359290666878223, 0.17953192495873996, 0.1294348838606051, 0.14448202215135098, 0.09546233181442533, 0.11728122244988169, 0.056034137694431205, 0.26054688915610313, 0.14241215107696398, 0.32370202456201824, 0.15027662978640624, 0.14089783733444555, 0.13148567453026772, 0.10769485256501607, 0.1699807167585407, 0.13991922698915005, 0.08948140524859939, 0.0567205640753465, 0.18552626616188458, 0.10388749758047716, 0.1307357440569571, 0.13934646200920853, 0.1252453236707619, 0.16293379132236752, 0.15347126764910562, 0.20277073154492037, 0.10690753481217793, 0.09358700351523501, 0.0976845882833004, 0.14051290441836628, 0.06767027705375638, 0.20797931562576974, 0.07476664055138826, 0.12661553014601978, 0.08299884452883687, 0.12029777201158659, 0.2512682213314942, 0.05869859204228435, 0.2263458879398448, 0.08317841203617198, 0.13323800478662762, 0.14458438594426426, 0.09097631967493466, 0.15542680557285035, 0.1375166701951197, 0.11109329520591668, 0.10452137142419815, 0.1553476612482752, 0.10681662469037942, 0.10551062798393623, 0.18529153375753335, 0.12121767550706863, 0.15322280169597693, 0.08174084738961288, 0.22381877925779137, 0.25775759454284397, 0.10311618646872894, 0.11462079520736422, 0.16868525770093712, 0.10019668098539114], [0.008479146619460412, 0.023327760830787674, 0.07542218680360488, 0.027777432331017086, 0.038889196435255666, 0.005148441281302699, 0.03733253532222339, 0.04532286531424948, 0.056269307753869464, 0.04296998067625931, 0.04780150963259595, 0.032576747837343385, 0.009755552413740327, 0.010201022527845842, 0.02092122782154807, 0.05569317724023547, 0.013086666569246777, 0.004888885097378599, 0.08777683028685195, 0.019169107911043932, 0.03430741586323295, 0.0378513296267816, 0.031857198769492764, 0.049346957954445055, 0.02136138839913266, 0.03846210953114288, 0.007649925936545644, 0.026478341414726207, 0.017840232700109482, 0.040440256241708994, 0.007952053831624133, 0.1047779323000993, 0.025414191552304795, 0.028887206888092414, 0.04347514660496797, 0.05458665965124965, 0.028446605262745703, 0.027787478041968176, 0.029679511873317615, 0.03009631557922278, 0.04986694648063608, 0.03447945163186107, 0.07894094048866204, 0.054792011489293406, 0.03496713510581425, 0.10369154345244169, 0.05130161717534065, 0.01976121453169201, 0.09426141304097005, 0.009451739207309271, 0.05491536915568369, 0.013714114686341157, 0.019682565537680472, 0.029455103379275118, 0.010145327525346406, 0.02976326345066939, 0.02400813976834927, 0.027271609919677888, 0.0041582220500069, 0.05845802423677274, 0.05652471172756382, 0.02850169382457222, 0.019661736208945513, 0.04423297522589564, 0.019269799115136266, 0.043544238433241844, 0.05862260290554591, 0.017172130157372782, 0.040381742774375846, 0.04465600109792181, 0.037012110730367045, 0.03770442000989403, 0.007050692577779825, 0.018021515204704235, 0.034618629342211146, 0.003837300855333784, 0.03118337956922395, 0.007134704967029393, 0.06789819018117019, 0.04472496400454214, 0.03238987250785742, 0.020682352960907986, 0.05114792899361678, 0.03218533830451114, 0.023681584612599442, 0.024137590679207017, 0.036158744378813674, 0.0699307554002319, 0.025754517576258098, 0.06227435623960836, 0.024106829294136593, 0.043903159709381204, 0.00994671693271292, 0.012653654358083648, 0.01818471135837691, 0.034361152444034815, 0.03582957686324205, 0.032446916946875196, 0.07235051305698496, 0.046585998963564634, 0.011315698652262134, 0.021387489944962517, 0.03310361670862351, 0.03708631192733135, 0.07159199911568846, 0.03491255374891417, 0.058411212105836184, 0.06397538246320826, 0.019850645447149873, 0.07523661426135472, 0.057858029646532874, 0.022035723286015645, 0.048288355115801096, 0.08701899488057409, 0.012918506931912686, 0.04739660403824278, 0.02924202981271914, 0.05318745598196983, 0.05549459718167782, 0.025993338154096688, 0.06570403863276754, 0.029174946448100463, 0.02724242952120091, 0.021903895806255083, 0.030951317200171094, 0.06297277233430318, 0.07342596392014197, 0.02230142742129309, 0.00911116721441171, 0.03940248442813754, 0.031737678218632936, 0.03176394430920482, 0.04384976239608867, 0.047825265143598826, 0.021892503203291978, 0.03304405829736164, 0.03604227723553777, 0.03426033231828894, 0.008694617110969765, 0.04888889253405588, 0.030651872911091362, 0.022669698909989426, 0.023033290203394632, 0.1331892724015883, 0.02063739492690989, 0.06149369491530316, 0.014661121414974332, 0.034089684153773954, 0.0413583650120667, 0.020190211511882286, 0.04209974255146725, 0.05321540144671287, 0.034506447147578, 0.040745566466024945, 0.012842449093503612, 0.030845397883760076, 0.014691195783338376, 0.017841720388137867, 0.014607462865699614, 0.004760917209620986, 0.02687676021430109, 0.05385978579787271, 0.023227522548820292, 0.04259633519021528, 0.045428540358053784, 0.020636020893497125, 0.022665592076789056, 0.012764323419625205, 0.006363888337676014, 0.025970547859157835, 0.02645860961638391, 0.011776920108656799, 0.007837093884258397, 0.06889661374901022, 0.043770041316747665, 0.04842926309044872, 0.06958494002797774, 0.05023183207958937, 0.036086704315883775, 0.011666783697104879, 0.05191287544689008, 0.0109810494219086, 0.021139578694211583, 0.0404249417063381, 0.03801516529970935, 0.021631005985130156, 0.08070055821112224, 0.03031240523393665, 0.04064095672219992, 0.019263783902195946, 0.034029107939984114, 0.007654306728259793, 0.02308672822878829, 0.029850302530186515, 0.038738877179899385, 0.042878439516893456, 0.03893031565738576, 0.04519706492179206, 0.040377983690372536, 0.06926686316728592, 0.01231625790907336, 0.029446574194090705, 0.032504032632069926, 0.033616494187819104, 0.03587599205119269, 0.04317728330248168, 0.04729625888700996, 0.04616539885423013, 0.01676206260786525, 0.0031808207692977574, 0.018230897540758764, 0.019716697545456033, 0.03303249945331897, 0.022333659531016434, 0.029117243830114603, 0.06728081152375255, 0.11020246015063354, 0.028158467063414197, 0.020590202816362892, 0.04043016642598169, 0.09914327572499003, 0.019790773213441883, 0.04864021623507142, 0.007835930196701415, 0.03560826248888459, 0.04228423283036266, 0.0966278649866581, 0.03088809469980853, 0.03667268715798855, 0.012764029105060866, 0.06297357979097537, 0.04072307303015675, 0.03013485636828201, 0.043679891154170036, 0.033706793628100834, 0.040787974904690466, 0.08923333284578153, 0.027848815911316445, 0.018899705759914856, 0.04992983649883952, 0.06256439603332963, 0.02425209346360394, 0.037412154621311595, 0.03222980270428317, 0.0382405033867274, 0.027460687095299363, 0.02146456473773079, 0.03717031795531511, 0.03897086151742509, 0.00225625976703928, 0.04527199215122631, 0.02760788000055722, 0.012835451701123799, 0.04618853011301585, 0.03585432982072234, 0.007702125635530267, 0.025769007691581334, 0.020648432995325754, 0.05404226082776274, 0.03612626290747097, 0.039937977479504685, 0.04196384895060744, 0.025451326077537875, 0.11667164015982832, 0.029680777341127396, 0.02262717003135809, 0.024005055826689516, 0.019853951609028236, 0.035135323580886633, 0.013917520825218941, 0.028519797138869762, 0.03521649333249245, 0.017094563426715986, 0.010142653249204159, 0.06242563562201602, 0.02535439226111131, 0.04378389360915337, 0.01648133061826229, 0.0134817410393485, 0.001759077757014893, 0.0512683078912752, 0.029916228992598395, 0.05201313238857048, 0.023174727435356805, 0.03249505561377321, 0.023236713305647885, 0.016340427732627307, 0.027683697807203447, 0.06550797593912908, 0.021430463264031068, 0.002492142924373703, 0.0744115292493786, 0.05026149084525449, 0.016210830936740552, 0.05322413758507796, 0.025293112067239623, 0.05091937465061035, 0.04567600207935486, 0.027483874333224127, 0.0693795271217823, 0.04356728826782533, 0.00436736096162349, 0.028495186673743383, 0.03275105669828398, 0.03973631687196238, 0.036080197165054936, 0.038422662897833755, 0.010138851756762182, 0.024851948954164982, 0.03143062076664396, 0.007693313161975571, 0.05397672452298658, 0.04906832094171217, 0.0340609448030591, 0.0677751921383398, 0.026118650001340678, 0.01309982590776469, 0.03551063487040145, 0.021747091452458074, 0.047535279632679055, 0.02935645795826401, 0.03164248654086675, 0.07852906973234244, 0.08159071473138672, 0.052318530822438855, 0.0037307097892543034, 0.012334804815639342, 0.05143118343715157, 0.03309143361236368, 0.06363838804619652, 0.00879679769942803, 0.012238620780408382, 0.028963107815278426, 0.02025038908634867, 0.0770448422325509, 0.013549410488589533, 0.019801080160375153, 0.01837145776620933, 0.0172338446136564, 0.01198888851130115, 0.07534744617130075, 0.04789450624957681, 0.036590479247804196, 0.03656693747533219, 0.03329849535865443, 0.0182248297413545, 0.017339385646794523, 0.015417552253763591, 0.015856822254136205, 0.02178994263522327, 0.03214015465761934, 0.05051252505342875, 0.12534148565360478, 0.16935665453118937, 0.10139221897614853, 0.0889639612287283, 0.11730369552969933, 0.06481419423861162, 0.13480065736387456, 0.1890495592462165, 0.12785688282123633, 0.10948679569576468, 0.13212524806814535, 0.09312717390379735, 0.061700892368597646, 0.11911576400910105, 0.16006350676928247, 0.09696872026792594, 0.07504256681672164, 0.13403848611882754, 0.19512144343129226, 0.11403937212058476, 0.13160705087440355, 0.1446216782288892, 0.1512580221252782, 0.1612935143389872, 0.0620773368115936, 0.13250051864555903, 0.07910292715366397, 0.07450233080557414, 0.0931481406358736, 0.14269771932491235, 0.06940933516515152, 0.1253262186156852, 0.10687805246561766, 0.10442218996052231, 0.10415409398930413, 0.10772916608090911, 0.17766022682189941, 0.1101344505857144, 0.11480261545096125, 0.1259991760764803, 0.17131881495671614, 0.12687680684030056, 0.14284098520874977, 0.16671201001320565, 0.1637107003480196, 0.21471936681440898, 0.08815168017255408, 0.08086453298372881, 0.1813394743949175, 0.14228153308587416, 0.16307514373745235, 0.0853469285315701, 0.10443386076284306, 0.19265468365379743, 0.1711558172745364, 0.175005987818752, 0.176376126440508, 0.14043200947344303, 0.09142769474003996, 0.09540095832198858, 0.13354368481252873, 0.08416829284812723, 0.12362063942211014, 0.11702238848166806, 0.11537932950471129, 0.15319464249270304, 0.13395508059433528, 0.12432221748999187, 0.12336418032646179, 0.1335869346346174, 0.08238948615533964, 0.09434639955205576, 0.10006976101015295, 0.10089785871761185, 0.154445616794484, 0.1285891713840621, 0.11966338248125144, 0.2037756419075387, 0.12066643365791865, 0.09737081333462681, 0.07383493733193193, 0.07439586866114821, 0.14073768949934415, 0.09566618409007788, 0.05687419118891869, 0.1248319601374013, 0.09479558973440103, 0.16360483531441006, 0.056911938092006106, 0.2106709283377443, 0.09047510621270963, 0.07792448824537651, 0.1014802928215691, 0.07166129111179284, 0.13952623307704926, 0.11274163997066872, 0.10497319432241575, 0.10491273685225419, 0.14447816807244504, 0.09870830763663564, 0.09113636572978326, 0.11301998860601868, 0.12581442456160272, 0.14633367636374064, 0.1945733499846288, 0.22193408038999352, 0.14241909927555493, 0.16168770247272082, 0.10051698344094412, 0.1620254229222025, 0.09128915824528251, 0.09310704855514423, 0.20120071007737092, 0.16484040687126772, 0.17497884641800607, 0.14764597666050705, 0.1165588947811297, 0.1411906387656927, 0.20269062370061874, 0.0740720581795488, 0.1890684768025364, 0.09206530052636351, 0.10658024344593287, 0.14644590605582508, 0.12741514295339584, 0.17763266472944192, 0.14326232831392968, 0.11737689588751112, 0.07325860325779233, 0.05704163666814566, 0.1455149288688387, 0.18533105163701943, 0.13469856498496874, 0.1754533459565469, 0.0880823881764497, 0.12466924743992941, 0.13062137019421372, 0.11051605189485209, 0.1978793897266899, 0.13829511270991393, 0.1161422064261777, 0.13644050008484296, 0.1275976010199104, 0.2498226160449641, 0.1783475149422884, 0.1539763691169875, 0.0974858318056379, 0.19865886361471244, 0.11196132469922304, 0.15306245030036994, 0.10952630000455038, 0.09668290774737086, 0.10891149299485342, 0.12688329363507883, 0.08507045265287161, 0.11995702529592173, 0.09140156435647181, 0.07803059755159275, 0.17416843133313314, 0.10871996291513954, 0.1534458632980074, 0.08933461098266499, 0.09039081859269313, 0.08618393540382385, 0.21138780058494636, 0.21165778966886656, 0.13145970020975384, 0.12282212584146432, 0.10662277402090174, 0.10618590603449515, 0.10713058284350804, 0.10660948830523662, 0.09772626390414578, 0.12732400212969097, 0.1698363380772727, 0.1756493475820337], [0.010291916534437664, 0.01984891857552741, 0.049046628177165985, 0.08743379012282405, 0.09788667636790446, 0.040563596944723807, 0.02073685628628092, 0.031940183602273464, 0.04310424240039928, 0.044778530951589346, 0.014267998581219996, 0.017182973146970783, 0.02446041558869183, 0.032004875130951405, 0.035574074501969984, 0.07974261604249477, 0.07856657236282315, 0.03593850548246077, 0.047422924411616156, 0.05728183127939701, 0.04126787218930466, 0.052432870758431296, 0.04030353482812643, 0.020029973770890917, 0.032894288655370474, 0.020216704911685417, 0.036041581737143655, 0.01078378317678081, 0.03525637422821351, 0.06932031815605504, 0.01605526151667748, 0.01191602657282991, 0.04072594662596073, 0.09404299261846713, 0.027800948658425893, 0.02088555384294263, 0.025510043105376617, 0.046370828723801036, 0.01377636772979583, 0.032209572182702165, 0.025459536351263523, 0.01115767632810665, 0.04058098101190158, 0.07867705821990967, 0.019850833740617548, 0.03324527785714183, 0.009279819637803095, 0.025204678598259176, 0.04835984556536589, 0.05745679831930569, 0.03556477178686431, 0.044010995887219906, 0.045273678310747655, 0.03313172502177102, 0.014594312857038208, 0.04145268137965884, 0.02383513030196939, 0.0385194830596447, 0.02581121087340372, 0.08586667957050459, 0.006727335018305374, 0.018534022882314663, 0.036439400033227036, 0.0870946990326047, 0.06425443677497761, 0.023565974119784575, 0.06222586812717574, 0.04361605457961559, 0.05592904279806784, 0.001995673058055607, 0.010839959939143487, 0.03296770953706332, 0.05053690820932388, 0.06607432876314435, 0.04050553809585316, 0.03544749718691621, 0.10186105953263384, 0.04545667241992695, 0.058242860782359324, 0.07116883075130837, 0.030304581725171635, 0.06905224254088742, 0.0490986277083201, 0.03878257144242525, 0.06411230404462133, 0.03665931662544608, 0.0475383194695626, 0.04034809761547616, 0.004924719803966582, 0.014800317785037416, 0.010385705341052796, 0.018185934417748024, 0.02808382312235023, 0.056905681999134164, 0.03458755922370723, 0.04921082008097853, 0.07180485555103847, 0.04325513841052141, 0.02031293135535504, 0.04963521998641746, 0.07182733541620628, 0.03326498929943357, 0.05819483407373939, 0.04316173127985426, 0.03074378047936729, 0.06266953503446919, 0.013164218032865651, 0.007593455707787403, 0.06923653943730251, 0.032710263172962835, 0.04118221392855048, 0.05599701165088585, 0.04598835549716439, 0.023316458133714538, 0.018619918630325367, 0.019022674965006963, 0.049469548876264265, 0.017196791512625556, 0.030685518069991043, 0.024354815183739578, 0.06971249782613345, 0.043153476901352406, 0.014149813896178134, 0.062210797864411554, 0.054492445063910315, 0.02498311486228236, 0.023977103576596295, 0.09827751932399613, 0.03102302478094186, 0.05339907069823571, 0.04038837206150804, 0.015095114109239407, 0.014455411649708236, 0.041287763443376334, 0.0021374781832232004, 0.05319117774654712, 0.03203346520396216, 0.041382483539304564, 0.03618109192965286, 0.03925481145935399, 0.0672419857499855, 0.04848933379564967, 0.012854231005933667, 0.05410013647217836, 0.018600380214463388, 0.023683476028963923, 0.05879828240722418, 0.048958832531103065, 0.03953274618834257, 0.022879778440775614, 0.01010156625748745, 0.014697604546589511, 0.01944942769062306, 0.04768597886764577, 0.08891369535454682, 0.0275369781801211, 0.022193967830389738, 0.04045709069552166, 0.025877322236608182, 0.0066853264912164635, 0.07383640296757221, 0.011246104708074458, 0.02140869925330792, 0.005021876688780529, 0.03092717831688268, 0.026859997006665384, 0.03923265389832003, 0.03083277034706303, 0.03365335560270718, 0.027084950025060346, 0.040512506650494676, 0.024300927628896067, 0.023334936338609884, 0.024843596188085418, 0.08130909555724689, 0.06573552944298301, 0.03004468584965382, 0.05685770957331572, 0.01869150068211768, 0.03832448227331042, 0.060560268216899464, 0.04844923916139773, 0.03630203740405185, 0.009960375842638314, 0.009233920136466622, 0.015517527603411248, 0.04672272376982229, 0.020581147766539028, 0.034266622337911806, 0.06897242646664381, 0.04879997730521219, 0.03078968676605395, 0.07281068872128214, 0.04971936172140496, 0.02317229997632759, 0.013966584844248635, 0.04202369573925223, 0.06374580692499876, 0.044461824731635194, 0.05000024129237447, 0.012161076950308467, 0.03983387663694365, 0.029156748138900315, 0.07100824186844484, 0.042243744645799906, 0.03423456155828067, 0.028645387185471397, 0.00931100086641631, 0.03608769836968609, 0.06171167429004397, 0.02812612978076296, 0.010522446262517145, 0.03611558276627745, 0.01347122120205313, 0.013979792528386627, 0.013228535519114562, 0.07578065006860665, 0.0594943372000541, 0.02804258854926697, 0.0048179463816008395, 0.0260370086678969, 0.016687196446582675, 0.0546088714950851, 0.06565670402986662, 0.05268436976309333, 0.02742634983068066, 0.03352484107017517, 0.044271885816540034, 0.049549653327890804, 0.03696635372138449, 0.013517242839692958, 0.08679763640144042, 0.07155833699341331, 0.025545328622683883, 0.030836593891893114, 0.06113890252475228, 0.02751916493954403, 0.012654155625828674, 0.06948944300945316, 0.008675883607273656, 0.03227927129981773, 0.032238141899662356, 0.03619579578350697, 0.06831123480307204, 0.03638840134122542, 0.027857016007016813, 0.029014394884662967, 0.023152651298525076, 0.030650451380227293, 0.05394168836729867, 0.09413808251598052, 0.07237237545528583, 0.04838757050622787, 0.019620211562141776, 0.023311589644955735, 0.014965312056509512, 0.019480134792891995, 0.03279004192778042, 0.04910096186878426, 0.07895831777048962, 0.06856557008411203, 0.06041382000382457, 0.036779403753046475, 0.02710758425694491, 0.06043100729584694, 0.04328156734949776, 0.06151025116975818, 0.04230476530002696, 0.03444622037932277, 0.056513163061546426, 0.04381323346335973, 0.04282153078487941, 0.040243884814637046, 0.027980745171329806, 0.027726170706695745, 0.04186548851430416, 0.021555722524811114, 0.04754864337987133, 0.0101738336296486, 0.02649521827697754, 0.026248984704060212, 0.03997321719569819, 0.04420788300090602, 0.02399000761631344, 0.02693567062462015, 0.07538128471268074, 0.06152442576629775, 0.04089069153581347, 0.017512712328295623, 0.02959110215306282, 0.027225971654323593, 0.004194569474618349, 0.04639272165617772, 0.03487597392605884, 0.047808071066226275, 0.06899841435785804, 0.07028725769902978, 0.025302579327087318, 0.024411484732159545, 0.054166707542857954, 0.029552062640764883, 0.021794514264911413, 0.10246741878134863, 0.047016665139900785, 0.01858224636609001, 0.03660666570067406, 0.09246942241277013, 0.01872233161702752, 0.0776898440505777, 0.022681215345593433, 0.003294669827612649, 0.037766682383205206, 0.04636314770738993, 0.07633086732987847, 0.004993754380848259, 0.06299999515925135, 0.04354781431279012, 0.016092036418350678, 0.017249924197260822, 0.09288349840790033, 0.11639197516654219, 0.052101562464875836, 0.03926031437835523, 0.03681374780301537, 0.07012368326208421, 0.04223451656954629, 0.015681556658819318, 0.014938314844455038, 0.02149370781678174, 0.019830959449921335, 0.06121937677796398, 0.10011356044560671, 0.014613958142165626, 0.06151194750730481, 0.02713175367430917, 0.04688534486506667, 0.027071070591253892, 0.031213523487427404, 0.020997057502557124, 0.01711483296406056, 0.05840254721364804, 0.03373992649306144, 0.010595650861172803, 0.045043037472558875, 0.02478238893672824, 0.04458315357831972, 0.05179245922980564, 0.021454030481566275, 0.008143413429414588, 0.01728007659715201, 0.023461074302239076, 0.012039928763572658, 0.09289309289306402, 0.14877007848450116, 0.1427607009453433, 0.149451612627932, 0.23415480820196016, 0.08101297608975853, 0.11486224510840007, 0.08297597111335822, 0.13497778214514256, 0.07627071520047528, 0.06895785831979342, 0.12538864383740084, 0.1168346107006073, 0.1399691400251218, 0.14088955920721802, 0.14899159302668913, 0.2276866595659937, 0.16350320433931692, 0.10888027359864541, 0.08947648586971418, 0.09816178839121546, 0.10191143397241831, 0.09674821674291577, 0.15661458112299442, 0.16533580528838293, 0.14876128467065947, 0.09721740335226059, 0.1865383554250002, 0.0901965404461537, 0.1799985942031656, 0.10191591230354138, 0.05454906202586634, 0.16581816226243973, 0.27275891814913067, 0.14887782984546252, 0.10320364963263273, 0.10712364821561746, 0.1001756599705134, 0.11634998741958823, 0.08301463403872081, 0.13721772123660358, 0.10824559908360243, 0.06846446836633341, 0.12959275181804383, 0.10326562702123608, 0.11293820478022099, 0.1525388112557786, 0.15881724150053092, 0.12237034365534782, 0.17025084154946463, 0.16410549916327, 0.10217880391116653, 0.14207333140075207, 0.14712879726929323, 0.1211962066590786, 0.18117868873689855, 0.12260221264192037, 0.11341933360589401, 0.21322588409696305, 0.23690328214849743, 0.10722696874290705, 0.12491390002625329, 0.25963824934193064, 0.2301632852426597, 0.15669916729841912, 0.1709708214870521, 0.10759959303374801, 0.1480168096188988, 0.19064928697688238, 0.1088804364470499, 0.08691207133233547, 0.07552572446210043, 0.14615571019904955, 0.17307946405240468, 0.1051974365753787, 0.15145490584628923, 0.15298967063426971, 0.12379479221999645, 0.1646058237446206, 0.16487484930881433, 0.0868711421000106, 0.15806663249220165, 0.1679678154843194, 0.1456485188433102, 0.14775613003543445, 0.12260020417826516, 0.1721581220626831, 0.1396383542035307, 0.15020874914314064, 0.07049013966960566, 0.12743750746761048, 0.13913184138281004, 0.18118824250996113, 0.14553730695375375, 0.18798377072172506, 0.12874199104096207, 0.14023676780717714, 0.13087519657398972, 0.09827409272215196, 0.09434555816863265, 0.27023180946707726, 0.19900837700281823, 0.15120567993393966, 0.12966399799500192, 0.07993230729230813, 0.14613451276506695, 0.11121195062462773, 0.10339931199061018, 0.19815361286912644, 0.18218399264982768, 0.13291479141584464, 0.11254665614770991, 0.2125083061733416, 0.0829560561105609, 0.06903942501438515, 0.0888763012896691, 0.09675695627395596, 0.10080941167793103, 0.12061045451888017, 0.105790279406522, 0.19574731056179318, 0.1333670485764742, 0.053674508418355665, 0.20871723602925027, 0.1410363670438528, 0.09381818039608852, 0.18819275950746878, 0.16527385504118033, 0.10716124584100076, 0.17810132886682237, 0.15008696567799362, 0.15851692190127714, 0.17414423477436813, 0.09919949913663523, 0.09790916980377265, 0.10565990568803889, 0.13999020175210067, 0.1852492881672723, 0.1716372107288667, 0.15457299138818467, 0.14084572584501334, 0.09926687766398702, 0.11961475866181509, 0.1565179034535374, 0.17426593681531294, 0.10945962036826781, 0.0881820446146386, 0.1857933375452246, 0.13691060271646294, 0.1383885062698807, 0.053756370275680504, 0.06369178875216416, 0.07199067915124552, 0.19852219309125627, 0.18608972164137022, 0.11284734894122396, 0.0823721902977143, 0.16777093176330837, 0.11081888885902506, 0.10790110006928444, 0.1009420652740768, 0.07639416786176817, 0.1165487031851496, 0.10859446107809033, 0.10031108877488545, 0.08975923819733517, 0.08955582696944475, 0.07546763507915394, 0.12026065614606653, 0.16261506985340798, 0.16822363675705024, 0.09651754197797605, 0.1339098901620933, 0.09183499217033386, 0.15399169043770858, 0.148855397477746], [0.015190773976168461, 0.032332950205143006, 0.012569354863704314, 0.04830046357320888, 0.02804730606398412, 0.022131807237331356, 0.050885973764317374, 0.011769471490489585, 0.03318815877927201, 0.02488601141210113, 0.03670670211847339, 0.05004690075293183, 0.03053075780293771, 0.030685446823814085, 0.057877646093922, 0.04776754216956241, 0.017463486309030225, 0.009838868880511394, 0.006204315561002919, 0.02452270171072866, 0.06632953256900821, 0.024348828808537552, 0.02791839967747884, 0.007524915189216179, 0.039776401328189034, 0.028366539826882736, 0.05499246769717761, 0.0816788360742586, 0.027731936558016708, 0.026106541543932896, 0.030931195244193077, 0.04541021991255028, 0.0357175473389881, 0.029617887322923968, 0.010039924743718334, 0.028459702684943165, 0.045743957361472506, 0.021511707654488937, 0.04580195174951639, 0.014845447149127722, 0.04007239865937403, 0.04965931137225457, 0.016207531560212374, 0.06092438367860658, 0.0327231824797179, 0.08660316147974559, 0.027880413590797355, 0.03530172750885997, 0.014595303518165435, 0.0206345790065825, 0.03720418024542076, 0.014547202170693448, 0.02251946447151048, 0.014170357392036488, 0.06484314732785736, 0.022379021293350627, 0.10228494035878352, 0.01692092461910631, 0.015114381111093929, 0.06844697573355266, 0.00735654605419508, 0.019780886958220174, 0.03735786164179444, 0.019724076613783836, 0.05176951117547495, 0.025511250897709812, 0.04358168338824596, 0.015252527448215654, 0.03812136620815311, 0.05248447334659951, 0.011884757134664272, 0.032149202922093015, 0.03744049024369035, 0.044067212513514926, 0.012689987363825952, 0.020237337465264967, 0.061296091947172365, 0.023472470297877277, 0.055043418891727924, 0.05698033102921077, 0.019694699440151453, 0.013324072401571487, 0.03716406525511827, 0.03899448471409934, 0.05886578307087932, 0.023887670964800885, 0.009684422435904188, 0.01836633652315608, 0.012356957287660666, 0.00671369519217738, 0.025854308025113175, 0.03953450698671596, 0.03867820936388203, 0.024287121137604117, 0.03446744156203099, 0.08279939594545535, 0.0297773159109056, 0.03728885802307299, 0.06757806414472205, 0.018576102231496146, 0.049063744223011393, 0.022622998737330948, 0.03058017890102097, 0.027231006384161965, 0.022339993655415516, 0.04422831708299262, 0.044684862584940026, 0.07020871048527104, 0.04511776453416262, 0.011648840686705495, 0.06521975461925779, 0.011472623446024954, 0.014263672920476114, 0.008573294201466655, 0.006913860054087958, 0.02456229762174189, 0.0667647992127708, 0.023589068059144274, 0.02360098483040929, 0.03009509082351412, 0.02789423704546477, 0.01977576401882938, 0.05596135463565588, 0.05532313816781555, 0.07912348676472902, 0.049930654133536985, 0.04323426328067269, 0.013476023533647614, 0.02820804761722684, 0.016011134688077227, 0.02710740783784006, 0.041233833480094156, 0.0472149093236242, 0.0296263045498303, 0.0316418588959745, 0.018826369695099335, 0.005795335787947157, 0.03858932466911418, 0.01868535654752382, 0.0351745496903147, 0.06934931874275208, 0.029579356711890017, 0.010801964522605496, 0.041750123990433555, 0.006944415758230856, 0.012510776935544397, 0.02441679426868047, 0.022339974995702505, 0.02824975037947297, 0.05489644142133849, 0.038330154826066325, 0.06716328925852265, 0.08738199075950043, 0.038645826280117035, 0.06740267641310181, 0.039580135074044974, 0.04471687925979495, 0.027951008374137536, 0.0283059381680297, 0.031035163772425482, 0.04630684626421758, 0.029599702584424188, 0.020075705334810273, 0.0466237187252513, 0.06344600979770933, 0.03112504252099565, 0.03134707614247288, 0.08309938984790019, 0.06632922722824983, 0.11048015060701541, 0.03387121623381972, 0.019485089794865677, 0.038923187647014856, 0.002509083399283034, 0.0300157802578594, 0.03265281839828406, 0.05181597046820181, 0.027404268604836295, 0.05242464352133019, 0.049539946884449036, 0.05872559095067637, 0.022042225347831845, 0.08286433174674, 0.022879613896033595, 0.07217770375843559, 0.05528247695682304, 0.024551753187552094, 0.040548574179410934, 0.021117760400686945, 0.006738149170165083, 0.04198466640497957, 0.04084343835711479, 0.07222912992749896, 0.04316646745428443, 0.013332834833168557, 0.01902909390628338, 0.04278646409511566, 0.06190226799143212, 0.03204801638743707, 0.014991590021444219, 0.046521572063543966, 0.027800801077059338, 0.026980284302096282, 0.028339517169765065, 0.02314148091578058, 0.017693930372063602, 0.03744808305054903, 0.013390956446528435, 0.0373727419147534, 0.08847546351275273, 0.013671084539964795, 0.037862369391535006, 0.06582859052079064, 0.03837224096059799, 0.030906574601041417, 0.00959181597655905, 0.042155497773949585, 0.035141783234264166, 0.08109195078057901, 0.03533440914803317, 0.0931969340890646, 0.05617651130471911, 0.020549244746299725, 0.03356558709804501, 0.014879433271874274, 0.07074003054627351, 0.013719567563384771, 0.040266856617693386, 0.029763609503528903, 0.03519641887396574, 0.03917585712458406, 0.026494997753096477, 0.018703734668503915, 0.04371434376974191, 0.019196100034085766, 0.014446337940171361, 0.033971021949712715, 0.042880794033408165, 0.009074164155338491, 0.02714336340847824, 0.049558257151927264, 0.02990290256483214, 0.030828987514334064, 0.010868561886517065, 0.04915780953264662, 0.014408250073237079, 0.03552776109427214, 0.0339179639039295, 0.03337489500907915, 0.043688291417700906, 0.015752970773194517, 0.038169884854661565, 0.02901500217350466, 0.09811505768448114, 0.023430826907445277, 0.022340482200628946, 0.02767407109162637, 0.02294050732494465, 0.039994350168854, 0.04435713356360793, 0.0189690656095211, 0.06545185430773667, 0.024110754619219472, 0.02893276372924447, 0.07039504977209227, 0.027545168097796183, 0.015437989728525281, 0.0385727480586086, 0.034963331917034726, 0.01713381158853216, 0.014196217209765953, 0.056581461003848484, 0.04053567522870643, 0.022544573659875562, 0.04578011649261628, 0.02665784106855946, 0.03362780536657997, 0.051563284027257135, 0.019367023005283306, 0.024097204274897064, 0.012541179545223713, 0.05868341999926737, 0.03094930195116571, 0.06593686435371637, 0.026175501057878137, 0.031593998428434134, 0.05248486011156014, 0.03317760755973203, 0.04428230472175138, 0.04346530445452247, 0.010670617106370628, 0.02503234936323549, 0.016558607275198613, 0.04600534601403134, 0.02093146012962929, 0.04463942109474114, 0.03411091551450746, 0.02228591780710433, 0.027010558838290826, 0.02805624745919236, 0.03780936902122838, 0.03806796550218548, 0.020962949243507216, 0.028490586206316948, 0.0325779963417777, 0.04676894557529262, 0.03693281712808779, 0.017614041355305483, 0.07498884041394506, 0.07367136968033654, 0.04581542066963656, 0.025012972099440436, 0.07035006290035588, 0.03868927627003618, 0.035378619097173214, 0.021231842493372302, 0.009316507178092641, 0.021567775003079857, 0.015526034736207553, 0.02083281979763082, 0.007559327092686934, 0.0695787314325571, 0.021423357306048274, 0.016612951144842163, 0.03793786998306002, 0.032815660017409494, 0.03344338294118643, 0.01590450121355908, 0.05572336187054004, 0.04093100669394646, 0.041491944808512926, 0.027586287319926277, 0.022266913737569536, 0.05073819901528103, 0.014340683252417614, 0.035108185572815795, 0.03511697260130729, 0.0774684516446931, 0.034205822207565816, 0.04053178043769939, 0.03696131220619593, 0.07284534150468451, 0.055616957401590686, 0.01735392156323152, 0.04483994854880231, 0.05872065121574061, 0.03466829132022602, 0.05376819035570536, 0.043288115212427716, 0.014824585589979376, 0.026029580405780246, 0.032621924698884995, 0.14021521753498487, 0.1034113084897399, 0.14329843994762215, 0.22058832831680775, 0.18730671490941728, 0.13297979507063115, 0.12157093440847737, 0.10376378707587719, 0.16552882135978766, 0.1449369934520551, 0.09867745464933769, 0.17185719178191253, 0.10723677357392651, 0.06873303252671446, 0.21527358064694063, 0.07762628567538091, 0.19257268948214395, 0.0833641067147255, 0.11610472415174757, 0.13157296127506665, 0.1410177480429411, 0.11339789189930473, 0.1622195653617382, 0.1053685766777822, 0.13920072625790322, 0.1483283657580614, 0.19494411508951867, 0.08486936201474496, 0.1300971611802067, 0.19406036393983023, 0.11550460063985415, 0.07307700693075146, 0.09017258137464523, 0.12855649313756398, 0.08381871839186975, 0.2806497375879969, 0.1495043212281806, 0.22675237112811633, 0.1138810563300337, 0.0825753640383482, 0.10306875008557524, 0.08714880541499172, 0.14827321443174565, 0.09641017059662513, 0.17508544426943573, 0.15485273780567305, 0.23417226012263978, 0.21697500720620155, 0.09955277839409453, 0.1351119420890297, 0.1446826106735638, 0.13866713988993848, 0.09585312048771552, 0.08039722591638565, 0.13555301699255193, 0.08403880122516837, 0.29523826763033867, 0.1300526899950845, 0.03803780801328165, 0.09633083628224474, 0.07136301390294518, 0.1292632280715874, 0.09970905857958964, 0.10201086649405104, 0.13779241325599806, 0.14635410026780196, 0.122162915500147, 0.1645118873566389, 0.2305891066789627, 0.18392180225678853, 0.09646834140377385, 0.11937405514929976, 0.10320449780140604, 0.1180269324353763, 0.08812759217939206, 0.07614275028130837, 0.14985209756663867, 0.2288637278335435, 0.11768363442804132, 0.09342639427632093, 0.11688775356326785, 0.13936574597443852, 0.13699218976710523, 0.11689699521022183, 0.1500312036701611, 0.26731256182704655, 0.14586185025317328, 0.12555306644311973, 0.10319343768060207, 0.07446699948715312, 0.17531229209687027, 0.0894350613068257, 0.12195851361112935, 0.15600911075515406, 0.10878175709928785, 0.15104778483510017, 0.10504456942102738, 0.14280605422598974, 0.14082051148372038, 0.13096366396972112, 0.22047917917370796, 0.12475938403180667, 0.10579147362815482, 0.09697350393980742, 0.07606420985289983, 0.11008589461977993, 0.0827539815966572, 0.14095726343137877, 0.17207211096371922, 0.12567573200379098, 0.13870264084211417, 0.08084583255861487, 0.13841452130249568, 0.13247351295181684, 0.13210376564945492, 0.056897865275719335, 0.18300934907581123, 0.08752947713115386, 0.08738708655749049, 0.10387338405208928, 0.15660904427724226, 0.12345025927892753, 0.16232582394565853, 0.0967321829604251, 0.18816256469913892, 0.13751510956457683, 0.1958294811525515, 0.084729678795806, 0.07922288535961083, 0.1286315391106265, 0.14769659537289823, 0.07661932613700628, 0.18506279960274696, 0.13352373588298047, 0.11842413326459271, 0.09094483565006937, 0.1184854864009789, 0.11647462073181357, 0.09984152897128037, 0.11214783361979894, 0.08990831912628242, 0.12999616802803107, 0.07499253164444651, 0.10462017290826355, 0.055299056960003715, 0.15393142295735224, 0.13841962388583592, 0.1674167907663754, 0.09509231309805598, 0.1942166169839246, 0.07308654034776346, 0.1456443662089961, 0.17622843650834902, 0.11630603192108017, 0.18426561595073768, 0.12702455105526106, 0.11795217144702162, 0.19112647351409706, 0.13228813718472207, 0.14084523729979992, 0.10019327473959752, 0.11030784342437983, 0.11804606712290219, 0.10683681110718421, 0.15924436572406972, 0.14946248275893076, 0.18272268160113267, 0.2470113911799022, 0.22793511194842203, 0.21144874660032137, 0.1287932340055704, 0.11067690540637289, 0.1645008950893368, 0.14822076367480413, 0.0959759217553905, 0.14451206768197672], [0.03255737566256097, 0.0332170813344419, 0.048832852326865704, 0.018132418360827223, 0.03022587505568351, 0.05548765916111214, 0.013814122266402202, 0.03054061352408358, 0.01924997571456645, 0.0518256633409432, 0.019123081184391464, 0.019764551227646213, 0.034754458482244184, 0.020916113363845006, 0.051781582313456705, 0.02426938762489174, 0.01752323640643486, 0.0796448595023581, 0.07115384869809661, 0.020711389170693498, 0.01666820085873561, 0.10617853714419262, 0.005916922902023154, 0.03636510384136012, 0.018571013218856285, 0.08008437377533742, 0.015874850929581692, 0.024044868868908713, 0.012430287415294774, 0.055532849593354125, 0.026100589095481803, 0.010668241385636585, 0.02015905318382595, 0.03853352873453072, 0.029918719216116836, 0.01969335594081453, 0.03203571115487388, 0.02354452902052019, 0.03724114344056163, 0.02749481231772474, 0.04737318779474922, 0.024628466660422937, 0.04644781869969197, 0.009319664910435677, 0.06642436462321452, 0.054448665984507115, 0.022261689017925943, 0.05808139658932175, 0.06120237947574683, 0.043937673393104754, 0.013956399185449948, 0.03246110511411514, 0.03517403739637562, 0.02548963955736586, 0.031990395193653445, 0.02095019448149417, 0.03327467877949987, 0.02521364374219307, 0.04166407557204366, 0.03173018379935196, 0.054968172750834904, 0.029103771517319337, 0.027068107089559947, 0.02044802937390549, 0.024776046330641423, 0.025742046102615337, 0.01867807417043618, 0.027180818541507636, 0.0354711984151176, 0.05617956471230302, 0.03707093971648386, 0.00461279767997829, 0.014499799714290669, 0.07302424404770136, 0.03797363556389298, 0.05257979394601924, 0.02918646458004202, 0.010763200665158885, 0.02470243545914335, 0.03479405439325741, 0.046685953957161734, 0.038515693441565545, 0.025525171043617383, 0.01842156588099897, 0.01503764049682234, 0.09235960830535207, 0.004576842533424497, 0.0042271858047960055, 0.025186899284433042, 0.0418463911462043, 0.06746483700616018, 0.02205726846919528, 0.002232127881143242, 0.037729247606226375, 0.07562261247741324, 0.05047081211315734, 0.016515381201835613, 0.039821452660752196, 0.012525997324181455, 0.023056502886382595, 0.04308175574988127, 0.04078780187826071, 0.03949270583689213, 0.029031242909176008, 0.048209855399493656, 0.030466497143996612, 0.0702885062034641, 0.09002584139151232, 0.013035710285683828, 0.04305341334215232, 0.013673405129728573, 0.036544179410806725, 0.05320207501894661, 0.02624353946053556, 0.01860344040739749, 0.0748709449544549, 0.03780729609674641, 0.05395301650943501, 0.01324450399260968, 0.06308669157858406, 0.016397227899038365, 0.0512273413395243, 0.04831653467512556, 0.08851028592990977, 0.027669401074360524, 0.027486454462632537, 0.01790795728032078, 0.04470707442877548, 0.015969082480296493, 0.036549400737775226, 0.06851423212460109, 0.021879929949396422, 0.015269853839916843, 0.033334813945527585, 0.07698332624776022, 0.025371813647715107, 0.03584626203935061, 0.0446662503693785, 0.04201275096940143, 0.01189248649669545, 0.018062938071255173, 0.030532382894307375, 0.034431251896811385, 0.04203543100239975, 0.035797651790614636, 0.054982601798006465, 0.05234086140990257, 0.05863098959837641, 0.024798059702983925, 0.018285085347348025, 0.05040231400302478, 0.015225567555587207, 0.03571279080850737, 0.028258754539170435, 0.005539045477884689, 0.07663965504616499, 0.051464994837130816, 0.015855826503996338, 0.02498348127119243, 0.03422654127436025, 0.02264462534471282, 0.005245766527618149, 0.011023301797519838, 0.009641715441830456, 0.0167678352445364, 0.028533931023308208, 0.03444252236347113, 0.021350542016859566, 0.014609449276966708, 0.04226236703938671, 0.053732092292713265, 0.017299654028777565, 0.050135483499616385, 0.022686490955363427, 0.0411226114125124, 0.030892016632216315, 0.04218942452488201, 0.015209940894107734, 0.052044314465352466, 0.042311129958501885, 0.043806984155837975, 0.012188811221026948, 0.07130934856832027, 0.014429303318528193, 0.02409922800559018, 0.0042268961551599205, 0.0433036367009793, 0.0072244335897266865, 0.04601747143481459, 0.04646971841741886, 0.05049282718183739, 0.036439227006797276, 0.03009597970438855, 0.013836293398136539, 0.011798519574637924, 0.012309604873215514, 0.04755146269287382, 0.07673940647925649, 0.021615068893879652, 0.075172913393804, 0.024456396965043883, 0.05108183629012533, 0.01119871242969696, 0.019323279548968588, 0.030956467280962637, 0.045764998732400794, 0.04175861585619194, 0.03149605529116733, 0.0416351869436247, 0.0407393646559545, 0.028069599332021813, 0.0069170046398150066, 0.02144230709278158, 0.02864022014130439, 0.017010448833129237, 0.036368031719965596, 0.059335241094231606, 0.016525130053716044, 0.026546613911965063, 0.03495324210130742, 0.02731755522212812, 0.011154149642347224, 0.04801801997902138, 0.041387867714677534, 0.05062321786369596, 0.029886563441583087, 0.026079954845564704, 0.01163270851663713, 0.03965628705918789, 0.0069490870477498645, 0.012723445925595505, 0.022633237830762352, 0.047248493414372206, 0.059441988223365376, 0.07592634510781084, 0.024143466792468513, 0.03549351543188095, 0.025359455828687975, 0.03513115398319704, 0.025760408956557512, 0.04173815802537969, 0.008994239515491893, 0.0446858261046665, 0.022026252633492862, 0.01828479188095246, 0.03955706827608602, 0.062033211679330895, 0.002413364584624235, 0.024910292787743465, 0.06321877520531416, 0.03562710201367736, 0.04485359388802733, 0.044042571514312706, 0.026936461117916873, 0.007584929915278086, 0.08141390207622733, 0.044874815070735555, 0.009796872651869697, 0.014851667618911182, 0.07055882776954345, 0.04051446761669857, 0.026999174717015455, 0.05850899578737361, 0.022788942957829152, 0.008743257893781577, 0.06168341330651726, 0.010009155725128949, 0.061303766178233285, 0.07614683506212064, 0.0550446843595377, 0.08979973316724811, 0.017616344981693795, 0.026074882796300308, 0.02916417470467942, 0.052205385108079226, 0.0439794202601271, 0.0819645943120122, 0.03672037799177425, 0.051601556794984, 0.051121842714824846, 0.025370843342638442, 0.015987348642998507, 0.07615397325051682, 0.05294847594840186, 0.002524926767884088, 0.022110867646655867, 0.046116903956447325, 0.017961877065577676, 0.045561889452593665, 0.02832318652820374, 0.01831146509253553, 0.0765100277162024, 0.05251188276867781, 0.04093905411926763, 0.030746409802564552, 0.03315962638173785, 0.01584053911002619, 0.03176136587613395, 0.02160588152972715, 0.03854601377887385, 0.055147207608180385, 0.05689509685284325, 0.019271151096160923, 0.04669244075194001, 0.014219814961377, 0.015335383359342813, 0.11893595222915922, 0.06416174889143024, 0.013411829880039607, 0.0066868650693712485, 0.08382026545171227, 0.040136130061000586, 0.03935228980013302, 0.09359623159148864, 0.06383451180798666, 0.06258623807557992, 0.03415765639926706, 0.04203348699957132, 0.010629090763229345, 0.038202267938426564, 0.06397151481360197, 0.028226142449836646, 0.035008040589413474, 0.022304911698613848, 0.015383708623370953, 0.02388470746310694, 0.012637815654410847, 0.09231776983610221, 0.053022884098546844, 0.03700145433789917, 0.037231891615582366, 0.045314909491155825, 0.044941359000014405, 0.031116319953330925, 0.06190382183662482, 0.039885954199624915, 0.007907896468948041, 0.06432119105011225, 0.0308408686625106, 0.05586046326373305, 0.06594364970390286, 0.03622282522597483, 0.02326027543417045, 0.029282833516065563, 0.060892818229539056, 0.06965477485209703, 0.03806002664246729, 0.017215273110195994, 0.044417038027729304, 0.04755173071420618, 0.04575009471071618, 0.026012964779511094, 0.1757522134908608, 0.18212671072355338, 0.170669945489083, 0.097487690991589, 0.09301144297101668, 0.10542880344603743, 0.13469158964497702, 0.09899415408394166, 0.08827414217271976, 0.07506608484046799, 0.16430570770587238, 0.06909609625914268, 0.19090181056942257, 0.14708020059125765, 0.1438485418579408, 0.1984363312699965, 0.19804207528276102, 0.13242897391319275, 0.1263134056436164, 0.11280503549746104, 0.09613429182874304, 0.14501769840717316, 0.06654946612460272, 0.1052143524533936, 0.1261920700115817, 0.20846643591565744, 0.14581512633178914, 0.12481145480913775, 0.09603016384478126, 0.18205033482185431, 0.10071953971471105, 0.07661070874226944, 0.08262869689081397, 0.08810937351414136, 0.08381709669317518, 0.11137262771704368, 0.11951269342431001, 0.08385131521416561, 0.0919967277773789, 0.08587180250989539, 0.11397207501743521, 0.10887038055807352, 0.09883432516029902, 0.11979607678949833, 0.18732225336134434, 0.15191915950604848, 0.08040224707552365, 0.14608322908835752, 0.1796039039535182, 0.1408710487719093, 0.09608367990170207, 0.13353639734642847, 0.09239424751805407, 0.06822029753987278, 0.1210667828896216, 0.10986997120614563, 0.12485948151775769, 0.1398433803447655, 0.1993900800922087, 0.18078068723636015, 0.1257587168365717, 0.12804806684809072, 0.1934710969882352, 0.19264293142727443, 0.10939701872744731, 0.0589560621551105, 0.1428710985928774, 0.15101581226502145, 0.06327752955257893, 0.163375748321414, 0.13913368699806078, 0.09816642957074301, 0.14472602334405693, 0.26685881188937594, 0.125851838982531, 0.10902933417154209, 0.07844573884670224, 0.11757274823529379, 0.07383116467722825, 0.18371354628886494, 0.0932306165673903, 0.1602224875241518, 0.09139281125473124, 0.14510616580290453, 0.08106903665299926, 0.13328052179089614, 0.08245163996304784, 0.08095448637115103, 0.12333042999463421, 0.12143087120992796, 0.10587570696536984, 0.15496162910546574, 0.14490274100431375, 0.14326648094824382, 0.14326232831392968, 0.15473315279398644, 0.0979830961940544, 0.09899110746170793, 0.17941827034311636, 0.1733702163078955, 0.19742601976862975, 0.1739077517496688, 0.10752507631800004, 0.13809959962964058, 0.1103368711524776, 0.17209005142961228, 0.23173384953822407, 0.21729355225605623, 0.13564311287232808, 0.10896888348673071, 0.13358204918248312, 0.07949144951999187, 0.13602754367249353, 0.142195549128311, 0.11234893782862596, 0.17932163338576043, 0.17061953033719743, 0.16335394020591462, 0.10603402275592089, 0.16902367025613785, 0.12207258891846452, 0.14942823031118938, 0.11134526239974157, 0.27316074658717426, 0.16247858931975706, 0.18047542790217058, 0.12461801804602146, 0.14861520965184483, 0.10845502891710826, 0.17735271475144795, 0.15652270748146943, 0.12911688163876534, 0.11446439288556576, 0.16917890549770423, 0.15752799782369817, 0.15197561361960002, 0.06028662182922874, 0.2502039527254445, 0.13353067051087106, 0.1853244427059378, 0.11096389179251023, 0.10015286119388682, 0.106370630407972, 0.12039823590644769, 0.12193598624851022, 0.16840228145676, 0.15776100674910204, 0.21692406279700144, 0.07450509922845022, 0.11012533786041395, 0.1167316905089787, 0.13999744850609983, 0.11591415080640997, 0.06585581334573881, 0.08839497568884067, 0.1481890489480325, 0.12663967242198332, 0.18692361403788837, 0.1834946780332497, 0.1631196963467768, 0.09616901925099747, 0.16722711308726243, 0.1333000228873321, 0.1711592370910304, 0.11538668482431344, 0.10290862939187459, 0.17152386823935167, 0.09196935567472662, 0.1528666793767895, 0.12319570008133139, 0.1415596261088337, 0.16572723856994084, 0.12052612618676253, 0.13443990743585996, 0.10946331159876925, 0.08860377448477916], [0.031509575101413896, 0.007994861757781888, 0.032856911553868225, 0.04696539503389171, 0.049396738676088195, 0.009188684751279652, 0.028698323094951253, 0.0508413838355669, 0.010843288153409958, 0.016814206327710832, 0.03259198094851204, 0.003696917897156839, 0.05967946190919195, 0.02896852931007743, 0.010099322851082044, 0.023205285259921635, 0.005869366502988019, 0.03825705964118242, 0.042043570029948435, 0.06800351917211499, 0.023801963510257856, 0.048225495631673505, 0.01471297675743699, 0.007946159906818398, 0.031742950435727835, 0.060500496067106724, 0.048263415561190674, 0.04517749257917915, 0.0440198846959642, 0.01709203079475888, 0.05187584100557225, 0.0678467775828072, 0.04925933872748699, 0.04479281411373189, 0.003549597766582987, 0.0683437909132668, 0.04668729067114847, 0.03140514177669372, 0.033834476955235004, 0.08473937506122248, 0.03357617563701101, 0.04546290137139814, 0.02728320438680904, 0.02323594656107681, 0.011732554944631244, 0.03619835725320237, 0.0825768228886383, 0.04500102597687926, 0.03222559917984264, 0.020815488316916993, 0.038600910654557605, 0.01795296281177018, 0.03315023206440466, 0.03653543309441634, 0.05792112661791699, 0.08073561133018561, 0.02409030357375741, 0.020541353384032845, 0.016268365617309297, 0.05074455349573067, 0.04036323573174221, 0.03294121952993529, 0.02727424263555024, 0.03944640939256974, 0.09252602580402579, 0.03389429999515414, 0.020533528178930283, 0.049441002908029726, 0.04524173966741987, 0.050978298631629775, 0.011995270981320312, 0.05993613135069609, 0.02764687710441649, 0.04368921083265117, 0.012028916988388767, 0.07362915123147623, 0.014329222795952643, 0.02876555573727403, 0.02097126469016075, 0.03614760283380747, 0.010139034113048442, 0.0385912720646177, 0.023580141930973957, 0.01533182613950755, 0.013741642852047724, 0.030519945347415547, 0.010793145263700612, 0.028695269687367336, 0.020467243789296066, 0.06383990616138492, 0.030723980827523128, 0.039670180063694715, 0.029611190182289908, 0.08979948210929121, 0.0686355677566358, 0.03286227537319064, 0.02975512103044561, 0.017906588335920657, 0.01892221955183361, 0.04741423577070236, 0.03957127679937652, 0.09138643981090613, 0.02459181728772819, 0.03424713481217623, 0.030844349547156265, 0.13266346204493726, 0.02863326176468815, 0.03263037245986717, 0.05002842763704913, 0.08601556372429643, 0.03339741897902318, 0.027818753417315226, 0.02423849731816777, 0.039657735731452703, 0.07264556722449404, 0.034279751990522654, 0.030904182765100683, 0.0671715470296996, 0.04271288715036852, 0.041294426657259464, 0.025902475529749478, 0.006193106586579233, 0.0326478786633483, 0.03371294794071998, 0.08376290888658591, 0.005520309005597872, 0.014366898452863097, 0.02989752178213426, 0.008025887771509588, 0.011057443135151905, 0.04156097896131022, 0.020306548037167107, 0.03613630861842206, 0.032735070413244624, 0.011723724659532309, 0.06524270267358848, 0.023680828046053648, 0.03370077841516052, 0.027039898692497184, 0.027775123615616133, 0.045133109603609355, 0.01909990412449198, 0.06315581394093377, 0.02964007881070886, 0.031455882625388246, 0.026522690463545065, 0.006672290561255068, 0.03418832957478506, 0.025520787707396915, 0.025054927615981017, 0.09697845724544354, 0.06137774685131652, 0.03911870072728821, 0.008432666970682996, 0.051045422708349567, 0.019271758385002613, 0.017857847469193593, 0.024575695295685103, 0.00518273062438571, 0.022800727414765527, 0.02724329804602478, 0.023138700618541667, 0.016457071295008063, 0.03269705888149994, 0.040810990812523026, 0.049189812636801174, 0.03198897705546447, 0.05887476008917604, 0.08621256958161082, 0.027057374361902475, 0.07976852250950676, 0.04388212173112801, 0.057168563428734026, 0.010272926035603243, 0.03393839120066591, 0.03303677761661155, 0.06921252608299255, 0.05482331909505384, 0.04322350510795202, 0.054979850338505845, 0.014920333666460854, 0.03854504347379718, 0.045789185113140514, 0.03151798554297004, 0.012434304342605174, 0.031999131332018545, 0.08167967745768172, 0.04955290011795504, 0.022190112055146267, 0.029012036975473166, 0.03974355344793626, 0.033848268179489036, 0.009052819139989359, 0.033745113893279007, 0.03114025866878884, 0.024765997227015238, 0.04574381486911859, 0.016212206666490862, 0.03635184187442064, 0.031101042737386057, 0.029954328733895506, 0.03253571682476571, 0.0713074758116688, 0.03241064925012844, 0.010562343273444899, 0.03509767506537693, 0.030466615887624875, 0.05679881951904722, 0.03908838038997991, 0.044751070639384646, 0.00915553153026849, 0.015555232098059995, 0.06735965050756931, 0.020126071292907, 0.0427518520238144, 0.04101625104833927, 0.01695707017954971, 0.03048095333256892, 0.039389938315642734, 0.03175366450367229, 0.016554103499012332, 0.1328037152332919, 0.04850462118961981, 0.013906470882440252, 0.11656823142298631, 0.008679111737624874, 0.05736744204269988, 0.013167731147924704, 0.050467409260038815, 0.03935262567496725, 0.07647810942892518, 0.060320046464247365, 0.026535302733204195, 0.06503555950309549, 0.0417563766906304, 0.023928191379777024, 0.054155128342764716, 0.03380609044272985, 0.022307222110352347, 0.05372502195781895, 0.04300274373963475, 0.07603336365095206, 0.03984923866976585, 0.008456419937179556, 0.011604017511542355, 0.03730310047311442, 0.04233611701056361, 0.03739795966872147, 0.05775683293385165, 0.021976950279037868, 0.04300242822085108, 0.07082545810512134, 0.053183808856244595, 0.058540113403328826, 0.02177405813043671, 0.023987027151244025, 0.03997456408771021, 0.0343620616809598, 0.0174957302931164, 0.01849656774928527, 0.04557262387658868, 0.023580471020458, 0.03692883412752833, 0.04103432382856097, 0.06385410789932523, 0.05224754927413804, 0.025184850108676722, 0.002150620346323454, 0.03426031535491347, 0.026503723713436296, 0.01996129924165351, 0.00463780339175303, 0.04428414355165192, 0.0434507295223219, 0.02077099507940667, 0.038510906377008984, 0.03544582459809525, 0.07358878518321685, 0.013823518280072935, 0.023429863387718797, 0.038073190221829076, 0.10469085590115615, 0.002827974926081619, 0.04411358020401426, 0.0683309326746634, 0.013246375901092376, 0.10141855970557247, 0.010617616736064, 0.03570909957800593, 0.00968739781196096, 0.012525351019576192, 0.0634083171774234, 0.006746420936126794, 0.04120296013674565, 0.015430647979623504, 0.028594456346971647, 0.101097293730293, 0.01829114805773965, 0.024156253784894943, 0.06068883024688278, 0.03871842274176223, 0.027510803691776733, 0.006524830058749233, 0.05180414699550186, 0.0229226109638278, 0.02091411338187754, 0.02095081364469869, 0.029143106192350388, 0.02354896324686706, 0.03583397716283798, 0.08970475862068789, 0.048306278618318696, 0.0903027718886733, 0.0728488088186298, 0.025840778036841323, 0.04467979732102581, 0.01847303276216345, 0.018761391485376016, 0.04555222711392811, 0.014343789246465479, 0.025204899122140238, 0.054749620014003346, 0.03008447853582246, 0.023644300809662257, 0.02051156569671418, 0.0352214907429048, 0.0400127215044839, 0.044980829382049184, 0.019989309167223315, 0.021494474561352814, 0.008377698848822286, 0.03849079120638115, 0.03642803457166467, 0.025077916382412826, 0.013797795865684748, 0.05571620671876839, 0.010711302914257561, 0.020165633277169297, 0.002560706767586193, 0.01675556563506169, 0.018960176800776805, 0.049075920533921034, 0.045924420535032234, 0.0469562653452158, 0.06061073086623635, 0.03118115397436278, 0.01672037341631949, 0.06237701180257967, 0.02716791450179049, 0.004885335086977908, 0.025266284488939812, 0.010945768145445203, 0.13617614284157753, 0.09313047836933817, 0.16489698312112264, 0.11076648559953485, 0.1157349089958838, 0.11907600185700826, 0.1399977199201073, 0.11024720274976321, 0.06770545909447329, 0.1487098652869463, 0.1894710651998009, 0.11509864670889718, 0.1302799042314291, 0.12656860266413006, 0.12195145684693541, 0.1672352690781866, 0.17881167360714503, 0.1512964272073337, 0.14070997812918254, 0.06455422033156667, 0.11350581967937094, 0.20169758770082677, 0.0728192925453186, 0.08588883373886347, 0.1285323780030012, 0.11365661730191537, 0.14566818278815064, 0.12714173405298165, 0.08139313890465669, 0.10079827691827502, 0.09302052855491638, 0.11635271513036319, 0.19599326593535288, 0.10580419615975448, 0.10551492311060429, 0.12147838223193373, 0.11926156761390821, 0.1511628915156637, 0.08663911026503358, 0.1977843948240791, 0.1134191368307386, 0.1187418776431254, 0.15143444123012678, 0.13594944429184708, 0.07403374809239592, 0.17513003759086132, 0.14341765855039867, 0.16859501254345688, 0.17239262376512798, 0.10670056806078979, 0.18411101853208883, 0.1121586901800973, 0.10394144111445972, 0.15787671054048197, 0.16116463339754514, 0.16059055205966744, 0.11414701491594315, 0.17262393635298523, 0.11250616796314716, 0.12996514540697846, 0.14277258887887, 0.14529353646295412, 0.1481685164783682, 0.13580943537609919, 0.15239405259490013, 0.16085227658706053, 0.11539037605481488, 0.11431412452033587, 0.15109245958072798, 0.18868768295007093, 0.18891999976975576, 0.15114900868918213, 0.08706495884273734, 0.057168956979044845, 0.09817343883748565, 0.13868730595069273, 0.10417787664170776, 0.10343095207852976, 0.1177702969206231, 0.14470934495329857, 0.08460797675486122, 0.09738469616110836, 0.14275755254285677, 0.11619460290031773, 0.17127306812575885, 0.10717841956232275, 0.08071962504514626, 0.11038924727056708, 0.11841837928763457, 0.12756097369960376, 0.08846747715558324, 0.10576218127139977, 0.2183877578271287, 0.16019549540110997, 0.14399263555450098, 0.14239874322499546, 0.10044598153659276, 0.14959160797297955, 0.07423330524138042, 0.1830211691558361, 0.10058876566056695, 0.14949806513530867, 0.12957895041576453, 0.06570034740226609, 0.2003110149609191, 0.17848939661468777, 0.05794353184423276, 0.11294223527823176, 0.17913658331547463, 0.20892268286219665, 0.14513656417173998, 0.054911830595561435, 0.08529329033834593, 0.0780786174748625, 0.18819604361695902, 0.09114680159837008, 0.1594083947794778, 0.1531073964600052, 0.16959729019020284, 0.15325227725718701, 0.15173643002552645, 0.13186137937009335, 0.07095583860895463, 0.13561465511364595, 0.12558849954179355, 0.15291078415300163, 0.12212225768182959, 0.13450146413275174, 0.11298135282205683, 0.10009898551340614, 0.11160183006099292, 0.19458913270916256, 0.09730318374931812, 0.10025850909629039, 0.13422489325915063, 0.1448047198355198, 0.14963010804993765, 0.15388541828308785, 0.12555297144821712, 0.08632310972149883, 0.09493149351328611, 0.1598918509802648, 0.20764721344624246, 0.11439849356455462, 0.10871614954833474, 0.08828502587441887, 0.12855310046247073, 0.14389331159847124, 0.12476758073483195, 0.10709612004991088, 0.2938057173575674, 0.12951136832790716, 0.10764377923416239, 0.08507347891905478, 0.10083404249910798, 0.09764528074967009, 0.12265342846512794, 0.23766763827630452, 0.10998155628996235, 0.14614173237766537, 0.1200618182442018, 0.11842796020209789, 0.13099620650921548, 0.07676863098250968, 0.12593164827142442, 0.12079283116119248, 0.1718719567039183, 0.07691868900188378, 0.19352266564965248, 0.0868307285542999, 0.16244797381971562, 0.1459442244044372, 0.11629258335701056, 0.12244762879397188, 0.14189419815582888, 0.17205749531941755], [0.03475472650357655, 0.04841660162700074, 0.03772094573027321, 0.03869409726134368, 0.011535192008263298, 0.08842844782131058, 0.008226417770077075, 0.012677536246233752, 0.018659385619685054, 0.030687987937458923, 0.043474736091281684, 0.0353801831203912, 0.04219687144671168, 0.032315484713763, 0.07065377517470292, 0.024800326009946208, 0.02576970827898809, 0.01895552544322397, 0.030786660499870777, 0.035234837526721616, 0.04087355174124241, 0.025412744576377527, 0.07328016710068498, 0.05382104484098298, 0.0755616393206375, 0.044653280172497034, 0.02387925034521946, 0.026464602776936123, 0.09011521802416869, 0.03350293117442301, 0.02969903332580413, 0.032655508789633, 0.06315525754221848, 0.13030961049454554, 0.03095896428983126, 0.04269167614568557, 0.021860754549769417, 0.05742232195500817, 0.007602040023942078, 0.02677579420352621, 0.04876812347876174, 0.06254369392991066, 0.01526075807799186, 0.022339752775483897, 0.04312332959047385, 0.015846786721210395, 0.07095775886305741, 0.025834959599056413, 0.06971196856881891, 0.03211292843999607, 0.04047585558146238, 0.05807839746453932, 0.031076995456325154, 0.013859307609631546, 0.0199686342052051, 0.008977598444159542, 0.032364267988928726, 0.05078140812526856, 0.03996717484135713, 0.02694158236097012, 0.046905395574867725, 0.0022961353617055075, 0.040218724736145565, 0.020437559578567743, 0.052760772806193144, 0.06323527717696768, 0.029911380859890153, 0.002627691108500585, 0.03746018811528172, 0.04259181275431599, 0.028163148955042874, 0.01371321308293513, 0.04559871354805572, 0.01975135881054614, 0.031116306382630552, 0.05645478530121701, 0.021097568894869516, 0.014096726164487856, 0.007566265961421388, 0.06381138733455113, 0.07177571247198752, 0.02873913697632296, 0.06499420957905905, 0.0242850210717214, 0.02774443686939776, 0.04399897563936455, 0.004032740144923861, 0.026215381953599196, 0.0403370341019971, 0.06054819029356752, 0.021448451227375438, 0.02770081046037376, 0.017879117845690677, 0.03303211947370853, 0.054328042814241986, 0.011564224825373717, 0.02453038272713976, 0.009992308548784681, 0.03390331772555198, 0.01580864966048726, 0.05819196387061051, 0.02714700374885329, 0.019694587481873374, 0.04361537604459694, 0.008121104894338973, 0.024502523775611604, 0.03310739614867738, 0.04835869884118438, 0.02527876105159521, 0.04211278060185058, 0.08791248300778014, 0.0493185171591384, 0.025059029360168746, 0.028088515192004185, 0.010484226929423, 0.021287741904546107, 0.03163136195923601, 0.06553270854055882, 0.0029521650701229063, 0.07285198436251708, 0.03448196221143007, 0.024131712869607976, 0.02078547332036708, 0.06373119806604725, 0.03575239350487079, 0.037316932409469566, 0.05841822815792901, 0.01161668830484684, 0.005374411254056862, 0.046411551002945216, 0.028694187424012592, 0.07833446588899408, 0.02237661419037197, 0.00792578689288348, 0.041891276237687895, 0.024777281264375364, 0.03966462964724217, 0.04294886466647897, 0.09997499002409832, 0.00988277348889304, 0.031122779606708458, 0.027297977790502564, 0.032458272230412276, 0.027068716074739183, 0.009453624686492341, 0.013071514882280358, 0.00800496684054711, 0.051438749102609496, 0.015419306266786796, 0.018628188275865147, 0.0022331450475446346, 0.04134384096999254, 0.016011199148904, 0.019502411097554222, 0.0691694798214095, 0.037582745110349994, 0.01911080818224166, 0.0325564053574843, 0.041108660732528994, 0.030890171016965593, 0.024992510875953094, 0.03679973605488028, 0.03493796827803765, 0.05546085024252534, 0.015740105749240944, 0.08133179933897086, 0.027840378328359554, 0.01857008701855583, 0.05231053428724408, 0.035676071885973215, 0.048563914972224405, 0.038659892311053615, 0.035557016131601164, 0.07988787003393684, 0.017782390982444798, 0.022322563787123988, 0.03526625369808503, 0.013191522282016064, 0.0024069812664363, 0.017953644739463925, 0.015473807895822185, 0.0653520350211433, 0.052787486729877334, 0.015320762626028486, 0.03631105852712478, 0.0365315416960844, 0.029342493707580224, 0.022929642282958542, 0.04144268316615905, 0.03576774196699262, 0.04338087773482714, 0.03277662729046174, 0.011176970471361918, 0.02046377138633813, 0.06521063510860715, 0.048049269909305234, 0.04154524712690285, 0.039064855580883365, 0.01805987618198352, 0.09484957398048469, 0.04687172666724239, 0.013588890200480819, 0.06547384562769107, 0.026184800380308713, 0.07721074404461042, 0.057128794491291046, 0.03623270130317126, 0.028379489667713642, 0.02963092876598239, 0.0752675961703062, 0.062143758604569097, 0.015329508942418864, 0.040848232207021544, 0.007780388712749949, 0.06168257870844432, 0.04657573951408267, 0.010092794496033872, 0.037209103016981056, 0.07768742168056113, 0.03413335466757417, 0.04386979953518935, 0.029736719160739864, 0.08334922644176654, 0.022679427405819297, 0.03693905286490917, 0.028882497855062996, 0.025028098341343657, 0.006942564629883106, 0.018191683305693523, 0.05321487558207341, 0.022794924244018536, 0.031251239856438975, 0.011154886701011231, 0.020736296494890536, 0.013251592987217009, 0.05510138613837106, 0.02853367996535131, 0.019284263785396303, 0.02810235900272216, 0.029309649220002548, 0.045313359038638215, 0.02885296122570123, 0.01940188104552882, 0.024183447772104825, 0.022768870195639983, 0.06006495122398649, 0.0583497571891972, 0.012896663193324847, 0.028380653355270624, 0.01785681100695261, 0.030472430932734693, 0.009671006102247961, 0.019176610812012638, 0.029476836855922426, 0.026691962898309742, 0.053442703892609904, 0.03762365398662431, 0.03776615312589066, 0.04931628477892705, 0.04076060280203819, 0.02043454349040985, 0.06130223947444132, 0.002399136553451951, 0.020253070996009877, 0.011550160490774682, 0.03725315011771662, 0.04178165551275015, 0.031086807072694813, 0.02321012830361724, 0.05265580004613314, 0.045352642823542864, 0.025537625553884676, 0.03673674425642405, 0.031184756995311806, 0.02613679233140179, 0.03009822904797537, 0.023804173838081102, 0.020475954482597963, 0.048016062405492575, 0.06633338664791413, 0.031639199038701396, 0.016655172986377562, 0.038727074063249996, 0.010149475918816668, 0.01864599303475448, 0.02931382560304233, 0.10110726140971694, 0.08571624157152005, 0.052731086899127276, 0.03767787232728941, 0.004396055359393358, 0.05806533566543034, 0.04069786884688905, 0.0303276417377804, 0.037150942387857606, 0.024321941858423606, 0.007871923086765622, 0.029873508427824293, 0.04106932945017304, 0.053263373872531314, 0.04754460270383528, 0.019798444051827704, 0.08849464569772993, 0.028588475060782263, 0.048592817171343734, 0.04256872560030647, 0.04323247873357364, 0.017157455141256963, 0.011291765025816858, 0.013280871773271688, 0.05037379178351589, 0.02293748445143657, 0.018863463508231298, 0.013713587973532932, 0.10255525513951268, 0.02314785405594323, 0.024897977377154996, 0.032516921404749155, 0.039215717664254565, 0.054095356192971976, 0.06339156414781298, 0.02668592902565641, 0.057024177962115834, 0.003327158720432115, 0.05815446124012981, 0.00934409471561334, 0.05053746460803917, 0.03646320304168122, 0.05961149984172412, 0.03230907595051186, 0.047048152557441165, 0.06079177757991212, 0.039697338427816115, 0.05531549447083047, 0.03174492157995701, 0.02655982498877815, 0.05589456982644541, 0.03208549866186721, 0.028530056588351727, 0.039464899471827915, 0.04360431592379298, 0.07344184842492853, 0.07084776155118432, 0.05095997818612626, 0.1120850487745234, 0.029891991721732274, 0.026295990217477083, 0.029327674502772943, 0.05772460252046585, 0.04203378216230443, 0.023845505102404525, 0.03859979107177683, 0.11517118210239069, 0.12720759266189166, 0.10224907978304795, 0.13397462240287236, 0.11709364822932652, 0.14240284157650812, 0.10033514284129653, 0.09044347291014024, 0.11802197912974016, 0.09496666876865284, 0.09224807071898665, 0.07666955808443682, 0.11932107513504368, 0.11296170244791678, 0.09237938760114567, 0.19913895428180695, 0.10810415845896516, 0.052785603795200586, 0.09882771622921739, 0.12470556263412748, 0.16709806929741586, 0.07237754589212791, 0.19157710219068186, 0.17314586548932961, 0.15344621613621712, 0.12322510778903961, 0.15478542713182314, 0.061314168120069165, 0.1219353484255927, 0.11401119934661047, 0.08949097937771253, 0.128480483644775, 0.1334978294159685, 0.19079161648239407, 0.13836352261049406, 0.07818782768611397, 0.11709287469940526, 0.11554688694221632, 0.21318046296281473, 0.1220484059303999, 0.11094596489731755, 0.15918246975966863, 0.14200205808239325, 0.11203500681689807, 0.15642626051391872, 0.08257470585938011, 0.197135525356446, 0.13349398890776293, 0.12330499850213528, 0.10214887373149395, 0.1687999436897891, 0.05995742377958127, 0.16805392157818588, 0.08255852958453552, 0.0581829325695123, 0.1503917228962694, 0.10141499739672456, 0.17623929306864738, 0.12156606252704348, 0.12451413433466639, 0.10709208955190011, 0.09808951762637921, 0.2622654012271336, 0.07032993755170278, 0.10206294405673232, 0.22759964423520224, 0.15184609485524042, 0.06076779815235308, 0.19746286422014236, 0.14037060205425533, 0.12566862095679554, 0.12081826265369143, 0.23045410535165242, 0.11187855021229812, 0.1168302409350872, 0.11009213714195148, 0.09769122435578279, 0.10873027664742299, 0.12416052259504795, 0.16080149502626487, 0.16997929183500154, 0.13630016547228607, 0.12674963580710547, 0.0979758155133043, 0.08712329928364072, 0.1271021076078926, 0.12192902447921888, 0.1500617377460003, 0.13708510835255894, 0.10421759808169943, 0.09963450793709074, 0.14320571135197366, 0.11818104130881173, 0.1819679063877889, 0.2669087792081492, 0.06646107336772339, 0.13222683833113738, 0.09802699740976095, 0.10117085371166468, 0.1284976912928479, 0.14752911935959542, 0.13180626875587872, 0.07195654205445733, 0.24732457580310957, 0.14377265450145515, 0.11580029263028077, 0.07275968324393034, 0.06609583153788533, 0.07663524456854377, 0.09147484613848583, 0.18168402090668678, 0.20311654013182434, 0.09335052727588586, 0.08101127975221191, 0.061216418365282674, 0.10455637704581022, 0.1337790957518986, 0.14015866842653069, 0.0639351996194039, 0.1528545878827572, 0.07146780006587505, 0.0754655451912965, 0.11386937195701258, 0.14841920802635805, 0.17704385918165955, 0.0375243571719953, 0.0976180647100721, 0.07969529501029424, 0.08288931540612664, 0.22090139080371174, 0.1365706973842212, 0.13840248409126485, 0.14643332601657935, 0.12863862301622117, 0.14438689154173645, 0.1378514322319201, 0.09718689641782216, 0.09262075607797929, 0.18007950271878922, 0.09320406549211059, 0.12033758844648089, 0.10475142872227089, 0.14614488078015192, 0.10930240380444697, 0.19255586181368145, 0.11930749086397034, 0.11039996133851153, 0.16268160699733666, 0.10124882417065756, 0.06694621912070683, 0.14134697323398931, 0.09659653702484709, 0.18200050321008476, 0.07332434651574918, 0.14540290273725986, 0.176245901999729, 0.09651935366647584, 0.08978175198925392, 0.19666599269424165, 0.07892108655401639, 0.12806311675480433, 0.16881925479641982, 0.0891076410189271, 0.13644003868103027, 0.09918961288141352, 0.17819122118609293, 0.16628122170056614, 0.11415450594254903, 0.16969883974109376, 0.11925852777702467, 0.15980099514126778, 0.15322164818644524, 0.13899749144911766, 0.16306215657719544, 0.06932463363877364, 0.07304447796195745], [0.04569912316011531, 0.04065132812995996, 0.035264000961823125, 0.02648081467486918, 0.010251972026058605, 0.029962885060480664, 0.0539374543087823, 0.007016731900096471, 0.024035247242344276, 0.02656319221880819, 0.025889481584142362, 0.020533607906794975, 0.014646962085472686, 0.03993451016555939, 0.027839889783146124, 0.050742548424750566, 0.00528871694612982, 0.051870748600257297, 0.027826353009524088, 0.022574497054197958, 0.017022674337827733, 0.0486869130150548, 0.04026821708040578, 0.011495227992002453, 0.0792128633973854, 0.03609606470646603, 0.021275462117046118, 0.038290871041161675, 0.01954123517498374, 0.014887957368046045, 0.037019462657294104, 0.010727545346266456, 0.013451452084284807, 0.04386449678401862, 0.024027381325140595, 0.02148783509619534, 0.02954269207215735, 0.06700099046741213, 0.04175148106047085, 0.00497015450881528, 0.040961995388248136, 0.025878932060939924, 0.02431815054400691, 0.015016763670636075, 0.03289801720529795, 0.015924755483865738, 0.044886451946305375, 0.07721735976104226, 0.030122819157051187, 0.030363872115101134, 0.0355272759417338, 0.03576020683561053, 0.045080730092844794, 0.03660468098574451, 0.03167437429406813, 0.02892399366412844, 0.034282001334109476, 0.020167833426967263, 0.07068403783653464, 0.057097100120569975, 0.031357946273471625, 0.03235228845317449, 0.03411416908992188, 0.011262173265484827, 0.05037608523187893, 0.03424975395734821, 0.03944164268406374, 0.031550897884049585, 0.01016117216620062, 0.020189914652811627, 0.018260914233646224, 0.02649099100381136, 0.01870132756552526, 0.08810216747224331, 0.006863752787467092, 0.017825150562982475, 0.055798102502844164, 0.028232893873272196, 0.038039511136178455, 0.10493866367531673, 0.011861866755810167, 0.022301103420821682, 0.02335145527363888, 0.025131391727232506, 0.04675976499649031, 0.02956629152010594, 0.021383786840098243, 0.024481931934133172, 0.0074213062845436585, 0.024219491552295427, 0.01842614259969975, 0.0637474421943937, 0.015162065159529448, 0.016134797695225904, 0.04225923899295075, 0.030246041116437743, 0.08404394452060972, 0.06652165297418833, 0.04153751182769026, 0.03125068345772369, 0.057670977897942066, 0.06986712238618306, 0.018596363287152987, 0.048661043867468834, 0.00791903377311038, 0.08094056961791855, 0.01065800229220518, 0.013042120745272508, 0.0457096200968538, 0.04827087605372071, 0.019591887814125845, 0.011282955096768481, 0.030829571054450104, 0.04322432613532458, 0.06400628294795752, 0.05363957065024546, 0.03389706502535513, 0.006529001776860761, 0.018771237028496604, 0.06198301365865128, 0.05225226848519274, 0.01703779209804322, 0.016927503016112105, 0.03180558939597436, 0.07552246070866074, 0.03605422284454107, 0.03722209356991308, 0.03155586815306118, 0.05299034495172756, 0.09816511321280684, 0.014775551256856747, 0.010573955552120293, 0.016303072683513165, 0.02250535094312259, 0.015130050181012069, 0.033087369187601974, 0.0285538154920297, 0.02464390333209719, 0.03437734907492995, 0.03660686926117965, 0.06832826603204012, 0.0835313316700714, 0.003478938098331647, 0.037370526497917514, 0.033006592986306975, 0.023311248681108867, 0.0656089215938534, 0.05308584875560232, 0.029409091919660568, 0.0583060798900468, 0.07762893874730382, 0.015546244901737996, 0.03256103975166168, 0.03381200048274227, 0.06361705490521022, 0.060553550720214844, 0.03856222737314446, 0.019557241816073656, 0.09058464890612022, 0.03773690487391182, 0.014305792981758714, 0.03367689737517919, 0.03660184810204165, 0.04105323799220579, 0.0415966325838651, 0.0432483632383602, 0.049045260929103406, 0.013969790922211749, 0.017800385731139352, 0.0497558397640075, 0.03883962945214339, 0.02050605259968766, 0.015189690016476172, 0.08601576728480202, 0.07047728821635246, 0.06911995355039835, 0.03175532352179289, 0.05622769659385085, 0.046574826884482584, 0.06404753109174115, 0.028296562510409524, 0.01733719906769693, 0.03899115989250796, 0.052086651657841036, 0.02964640614975776, 0.03125671902671456, 0.021496321872941086, 0.061188449151813984, 0.011070342934025186, 0.023724585073068738, 0.04838332626968622, 0.049597208454672775, 0.013999328399742288, 0.005722508624395621, 0.02720075050768043, 0.035869915770100694, 0.03245998892400946, 0.06003928224423102, 0.09209206873284918, 0.0005813161645034727, 0.01947486087945955, 0.033554689825645516, 0.019917869607784917, 0.0425751411489078, 0.03998768695497087, 0.07366689813456365, 0.02300171966531447, 0.0288641706242093, 0.016751263723043457, 0.03369083448446222, 0.027300357752080475, 0.008266638781476234, 0.03858093797628369, 0.021771800305162157, 0.04868422940905605, 0.01491345332137176, 0.02550188372177737, 0.01846314311426665, 0.018583749321156313, 0.06969763112387486, 0.056417659257671664, 0.012855917165455009, 0.016952914152560488, 0.04177316703966685, 0.022802500087501745, 0.011428707811449255, 0.03282433508762291, 0.01540245145692357, 0.03715416542919619, 0.015003966500184365, 0.10619508661329746, 0.04138307725744588, 0.007055501694724495, 0.0646327268332243, 0.03039840276220015, 0.036124549606548886, 0.04342388667698417, 0.04909860735226955, 0.06192096841654607, 0.017584591239158596, 0.09336626250296831, 0.009246244028742825, 0.0367673461857651, 0.0124918364786676, 0.06157226248511246, 0.03711596730032137, 0.04426656610199383, 0.05060275664020862, 0.03971970633470586, 0.03695795006517853, 0.03924745613975184, 0.03659554111904331, 0.025072976647477065, 0.01944382638404412, 0.020012352216456617, 0.053033608344516585, 0.04094481488157596, 0.044210980513266156, 0.019701632371704494, 0.06010582617350987, 0.018752516247332096, 0.05819986880357776, 0.018263326425637518, 0.04810175120032259, 0.006160097554259534, 0.0194798073997455, 0.039390928976769955, 0.06847530457058124, 0.03508725955284067, 0.014779351052961178, 0.06346745828964881, 0.018346121268612996, 0.0250473806102361, 0.08883746873055186, 0.023715319677389095, 0.02789470862730273, 0.04279428081853049, 0.03808396535792521, 0.024977413471788168, 0.02475217037967273, 0.011461156204209795, 0.0635268504598311, 0.014104559003109378, 0.02085488406009972, 0.055386645652885945, 0.020692729457680668, 0.03822549758478999, 0.008677038813142903, 0.017167222652850405, 0.01660965516098908, 0.06408065717135157, 0.026005302422813008, 0.028268605171303664, 0.043376487613256486, 0.04098561858492238, 0.083615877133395, 0.042256860727710385, 0.029940228776207993, 0.02481041243299842, 0.006143955630250275, 0.03425355375345264, 0.016250967979431152, 0.015584180098293083, 0.03290696029684373, 0.09788040670433215, 0.04205435534406986, 0.021397683237280165, 0.05241745105013251, 0.009440118446946144, 0.024996125771264945, 0.03157513176224061, 0.08833511532949549, 0.07133013209594147, 0.0760928372453366, 0.021639847296423147, 0.025243602759603943, 0.023345316228057657, 0.020513776024537425, 0.003816100028676114, 0.04161921762196081, 0.07299230540437357, 0.04569778983880367, 0.05867623431341989, 0.03125863928081734, 0.030974272039851973, 0.03599184512027672, 0.04212670074775815, 0.04341688758826681, 0.03205167708386268, 0.0168471305431532, 0.01859288240250732, 0.021581265975588133, 0.015383399889937468, 0.04339877748861909, 0.07602402022374527, 0.04608540636088167, 0.018281646871141026, 0.035329289601317475, 0.0539155681617558, 0.019963485820751106, 0.043740480938660245, 0.03405770819102015, 0.043300590078745566, 0.04581205513594406, 0.03871759492903948, 0.013953852134623697, 0.014762002608871885, 0.09867250134370156, 0.04781306169128843, 0.08383247229669775, 0.0666057031069483, 0.08727585431188345, 0.05365611333400011, 0.10839766556663172, 0.16525096126965114, 0.1352851992206914, 0.13662179107112543, 0.0892697430348822, 0.14967151225677558, 0.09236428341163055, 0.10130185168236494, 0.18771226171936306, 0.11577279839132514, 0.14077941940299102, 0.12637915568692343, 0.1254634726792574, 0.15637101419270039, 0.10789001959242991, 0.07810589458261218, 0.13357303823743547, 0.1111204433920128, 0.13072647526860237, 0.16756235009857587, 0.17402089067867824, 0.12859089486300945, 0.16016793330865248, 0.18488639406859875, 0.22512582769351347, 0.052724932586508136, 0.12740079872310162, 0.15692081754761084, 0.21497270464897156, 0.08571528483714376, 0.20706261481557572, 0.09500451066664287, 0.10711636753486735, 0.06261956771569592, 0.09029244458568947, 0.11212016974708863, 0.10584817879966327, 0.17235854773649148, 0.0887224299034902, 0.0904243653640151, 0.1344408438141857, 0.0834150036264743, 0.1754473748483828, 0.08828231851969447, 0.18272722778575762, 0.2276574011359896, 0.16779214276799134, 0.09468986719314541, 0.088393096146839, 0.07240486371197871, 0.14011562216494763, 0.10379141023648636, 0.18832124689860003, 0.19548171838479383, 0.07703420958880867, 0.11858015560678073, 0.1632923020848206, 0.08851313577698809, 0.1798480408532279, 0.12927541456052236, 0.13762606361082622, 0.1195743451161044, 0.12044900389654295, 0.16523580279733452, 0.10261882708540984, 0.14598941483667918, 0.059630329188491614, 0.18244206665882043, 0.10494627683822598, 0.11664563869791371, 0.07407253315406186, 0.07319579127111606, 0.2594936399587563, 0.10916905810258218, 0.09986778149115187, 0.1129111855157784, 0.11578236573508807, 0.08114132098853588, 0.18221402460975306, 0.14158553257584572, 0.15674226784280368, 0.1876754444092512, 0.12245397988174643, 0.09366778310920511, 0.1330530225698437, 0.08338239323347807, 0.1571873053908348, 0.09253380181533949, 0.07052399856703621, 0.12805718635874136, 0.14755708857306413, 0.10980112704315356, 0.11526553918208395, 0.21357448824814387, 0.12495803194386618, 0.20146195963025093, 0.13059549086860248, 0.10796753543296031, 0.1413927607770477, 0.13905853245939526, 0.1855060322476285, 0.11239637421177966, 0.1354279222765139, 0.15593289770185947, 0.14107608848384448, 0.07571544285331454, 0.09979473719639437, 0.16272557606654509, 0.17629809491336346, 0.1080621232145599, 0.12717870064079762, 0.1486319966082062, 0.08403266048324959, 0.15118722378143243, 0.25223616510629654, 0.1548409177256482, 0.15250681154429913, 0.1236435060522386, 0.11733351035841874, 0.12348662875592709, 0.1180443979267563, 0.0826908303424716, 0.13545125031045505, 0.09055917670152017, 0.08614496035235268, 0.07186434271612338, 0.0838707552424499, 0.24928521631019457, 0.15159190206655435, 0.1209856029599905, 0.10017966332712344, 0.08407984580844641, 0.0991535826719233, 0.10312483100486652, 0.18156932134713444, 0.15222013049892016, 0.1607020760753325, 0.149631940094488, 0.14315767107265337, 0.08750120257692677, 0.1704188875321831, 0.19873442527438911, 0.13532463567597525, 0.19188907902155602, 0.07997889550668852, 0.1396315824240446, 0.2039722270731415, 0.14218082491840633, 0.1314073715891157, 0.12729405159396784, 0.06722580268979073, 0.13817296283585684, 0.1588282880506345, 0.1541869185332741, 0.10614293441176414, 0.1420192521597658, 0.11820309369691781, 0.22340833342501096, 0.09365547448396683, 0.11326537401016269, 0.17347061234925473, 0.141227035384093, 0.17062119953334332, 0.10116121172904968, 0.08899921790829726, 0.171964400314859, 0.09099674357899598, 0.10806320887058973, 0.14510539227298327, 0.10929118083523852, 0.11689508174146925, 0.11130003125539847, 0.16583178724561418, 0.12173275143972465, 0.18937626028699533], [0.016974934310253178, 0.03524600960580366, 0.1453039316194398, 0.0285132526686149, 0.026368001442668692, 0.07264370803854295, 0.03271546075120568, 0.061650416148560386, 0.10061562207660504, 0.04794456856325269, 0.05611679683040295, 0.09058568706469876, 0.035121111664921045, 0.10686965220208679, 0.013654563908598252, 0.03496758633160165, 0.013517452337379967, 0.021422517618962696, 0.013480949697883, 0.029746242399726595, 0.03617903936122145, 0.014096972133432115, 0.02487400982395879, 0.007848575544942702, 0.10594725848308631, 0.044790992247206826, 0.07886283432266541, 0.01841004266004477, 0.048272972726928334, 0.039868929756007025, 0.05867183740649905, 0.014346023323014379, 0.045619581892554245, 0.045922313683799336, 0.0634347257603492, 0.051633458118885756, 0.07870562454419476, 0.04191716234864933, 0.04140433236690504, 0.057899189580764086, 0.004723023149251405, 0.02164717886729964, 0.026746111689135432, 0.0480135891453496, 0.03332794038578868, 0.020626428104670982, 0.02961507479527167, 0.03643088781141809, 0.02232138143985399, 0.058742581467543326, 0.03553816303610802, 0.018139385219131197, 0.03318040990935905, 0.03604460461065173, 0.021633290951805453, 0.05704794704381909, 0.07445708609053067, 0.09524315821805171, 0.029939553633864437, 0.034074142309171815, 0.011380226484366825, 0.06476389443767921, 0.03092539376978363, 0.03880677478654044, 0.005005861141918493, 0.10008960137409822, 0.016081420737983923, 0.061411103632833274, 0.0368387348550771, 0.10264113053147282, 0.04110432828643492, 0.030939453015370027, 0.026766372744792273, 0.10755362907158476, 0.030536715340401446, 0.04533787450886198, 0.019005860867244855, 0.05233934488413589, 0.01921932289509901, 0.07367147824593953, 0.030700822427336658, 0.04411156495500888, 0.011306665654826378, 0.051871939429215023, 0.03849631787410804, 0.04618226723479373, 0.037195539101958275, 0.027639949261876087, 0.02020314269300018, 0.0691287609349404, 0.05496002693793603, 0.0112034367297643, 0.0807875260444624, 0.05762720560388906, 0.024062899240691746, 0.038096436831567965, 0.029783789134983505, 0.021184112643823028, 0.08155033511242696, 0.06320398314190762, 0.03741930638040815, 0.016194347624800036, 0.010456608857826462, 0.07368477753230504, 0.02849710692784616, 0.006188839449480708, 0.019191082267622863, 0.02703518626679267, 0.011170007005733038, 0.06632335111498833, 0.020533823341663395, 0.024122242217085192, 0.04329462575593165, 0.011926544713787735, 0.043387222037251504, 0.014664880498977644, 0.05284181363614542, 0.01254991568358881, 0.03505704438846026, 0.014691519783809781, 0.0054442265702943715, 0.011731146984467549, 0.03266776313206979, 0.02618071051048381, 0.06924299230532986, 0.03991347897265639, 0.054188614045935016, 0.030160141975751946, 0.004221104858775756, 0.0697572539959635, 0.0158961586255048, 0.02113009107831333, 0.0434489721166236, 0.03275460543643151, 0.055265181099197695, 0.013538455540713455, 0.04369305134085672, 0.042416991599436314, 0.039772866160741875, 0.00832745841970401, 0.061489881548498354, 0.01651166961528361, 0.0442585492107485, 0.055494834668934345, 0.006090642285666296, 0.032286765719098706, 0.009228597029245325, 0.0511653910923217, 0.017891392544178025, 0.030644388669835668, 0.057520621323159764, 0.049465827111686976, 0.017651236948690245, 0.0302553506168936, 0.021120515252862657, 0.013217656906428081, 0.03561651686738644, 0.03908651102600353, 0.08343050136630024, 0.03450180257537535, 0.05412713877324547, 0.04265784099698067, 0.04271914663591555, 0.05784103234431573, 0.012426760729535349, 0.01905165519565344, 0.0035608449086014715, 0.06396698219967739, 0.02779575956187078, 0.04923564089196069, 0.05274348373391798, 0.02138423128053546, 0.04244904559371727, 0.08998371115220444, 0.0838376698749406, 0.04985545549009528, 0.004987728565798274, 0.02500162020857845, 0.050522672544632635, 0.005874647201770651, 0.02498828529912446, 0.06847478209861688, 0.024928039871156216, 0.03295627961467419, 0.04327465647033282, 0.08425790018268994, 0.029794686407383, 0.013900914528806294, 0.012418430015843893, 0.07087175454944372, 0.020761629599811773, 0.037323086722088714, 0.045531005931219885, 0.054327910499913354, 0.08242822371955429, 0.04431099657501493, 0.04388077823179109, 0.0043544950895011425, 0.04888741672039032, 0.024864970041172843, 0.0444883283094636, 0.041423307598701546, 0.025943498060639416, 0.020112909409882765, 0.0058372056394416305, 0.007573972422895687, 0.03038177526156817, 0.03683137275012476, 0.03586059269894447, 0.016096976153286438, 0.03890441936839904, 0.05513927892648748, 0.026636887907183597, 0.09142831220690693, 0.04690592822485736, 0.02602868982856827, 0.03730911907872983, 0.015747676503711512, 0.04199045091601355, 0.09045437018253974, 0.004289566073566675, 0.04515751650823014, 0.02706277210797582, 0.06879173937652792, 0.03391741768323949, 0.03836240220282759, 0.02092967727886779, 0.038010425732604096, 0.02637373506357627, 0.012788357129985732, 0.042171558697841, 0.003792966649468456, 0.03483077670846667, 0.061211139362837584, 0.025674111176548258, 0.04155803072665419, 0.029316634738019536, 0.020503699779510498, 0.031697471626102924, 0.017249562877363393, 0.022030893813020418, 0.05277563272310155, 0.017035193308921795, 0.02598901927870299, 0.06534413008817605, 0.07205360648887497, 0.013144457396785063, 0.05485573271289468, 0.0382806658744812, 0.03244509508035012, 0.09830860301320042, 0.008552350369947297, 0.01107214020365583, 0.02840116377254682, 0.021056162991694043, 0.022877123672515154, 0.031966449692845345, 0.03171796338366611, 0.02027167133720858, 0.020210822013073733, 0.01936220201397581, 0.007970019742580397, 0.04431529509435807, 0.04292573680036834, 0.013421425213372069, 0.02186829985917679, 0.0199822133872658, 0.013482478098012507, 0.023339535109698772, 0.018199907150119543, 0.03164167229884437, 0.008948353584855795, 0.029788939215775048, 0.023497874648975473, 0.01125818772041904, 0.05035880294495395, 0.007324075609046433, 0.033944050182721446, 0.025179937515141707, 0.019884826648714285, 0.03219319574002709, 0.02954913136948432, 0.027796003834477494, 0.027342827258897678, 0.031098447340939726, 0.10600348189473152, 0.044823840127459595, 0.021236039232462645, 0.01590666065125593, 0.03795984773231404, 0.018211533847664083, 0.05221506101744516, 0.013010873359494975, 0.028329169510730674, 0.01573036198637315, 0.08244851191661187, 0.02404476878499346, 0.013039102112608296, 0.006789329794368574, 0.020211617595383098, 0.02871796329106603, 0.08949939321194376, 0.00043794031028353075, 0.06328531913459301, 0.07351126934268645, 0.14123766124248505, 0.019734432754505957, 0.007454313620525811, 0.0031786254964702365, 0.021870493223624568, 0.006125504142671291, 0.044291400483676364, 0.024517342980418886, 0.0645240798060383, 0.017471659263329845, 0.02006869776440518, 0.023947622926373566, 0.006922119097518069, 0.032041838326092274, 0.08773579927427427, 0.03691062903297799, 0.05335492181724735, 0.030846449613038982, 0.037791842461696694, 0.057707435584494045, 0.012472865487714964, 0.044870136571781974, 0.030805669658418213, 0.04410422999145729, 0.012811634273800467, 0.03578350094280072, 0.012102419294283857, 0.034216037552271567, 0.04266586806625128, 0.06180367685322251, 0.01269592878608299, 0.04310805915987917, 0.023440326397706355, 0.072665577222194, 0.034585588079478057, 0.058749936787145476, 0.029653781825410466, 0.01368760347499379, 0.051323418505489826, 0.05347190125446234, 0.03406633576378226, 0.022847824530409913, 0.06067821117384093, 0.08619660365262202, 0.022834650773022856, 0.008878906373865902, 0.07160773434277092, 0.037276617251336575, 0.1352423293782132, 0.21301585036729062, 0.08862007289592709, 0.06005955008523805, 0.12268721950905663, 0.09262387733906507, 0.177600393603955, 0.19871845256005014, 0.14462269603141717, 0.11359928787818976, 0.13614309818616935, 0.1001257130077907, 0.2413253491478307, 0.09033477838550295, 0.08496222631739718, 0.2548090884728091, 0.10363346764019557, 0.172894346128617, 0.15562184367861065, 0.09818165589656148, 0.14809727030141012, 0.11253547389060259, 0.07855584472417831, 0.20612479799560138, 0.20569088842187608, 0.16878019832074642, 0.07682643538074833, 0.1579731303666319, 0.16727906172829016, 0.13578764083130018, 0.0919858372903296, 0.10460588296077081, 0.13900362540568623, 0.12029843697590487, 0.12870521444295133, 0.16793683357536793, 0.144521865727646, 0.12173242574291569, 0.08150198270699807, 0.1187874616256782, 0.13377214755330766, 0.10927490278014115, 0.20417216420173645, 0.10938859132251569, 0.11753912003976957, 0.10454134070979697, 0.1317511445709637, 0.14233230107596942, 0.14362480172089168, 0.06891493419451372, 0.08485913649201393, 0.15482794413609163, 0.08237397484481335, 0.149349696668131, 0.09727383032441139, 0.21640810476882116, 0.16513969509729318, 0.08288343929286514, 0.15615658355610712, 0.11584492666380745, 0.24072959540145739, 0.14443941015217984, 0.14173962787858077, 0.061284380432750495, 0.2739080307739121, 0.1071935033957873, 0.12420609300690037, 0.2149191139531987, 0.1626400128006935, 0.11587525717914104, 0.13784772743071827, 0.08441248403063842, 0.31360140655721935, 0.1465123210634504, 0.1258162973182542, 0.0627293207549623, 0.13204945570656232, 0.14771144171910627, 0.12366321070918015, 0.14006013157112257, 0.11933186384184019, 0.12139182830495493, 0.15003303571471147, 0.10046401699738843, 0.09247500675597362, 0.12587550628398145, 0.15599913629037993, 0.1468263334993805, 0.17639272340706416, 0.17584275720374926, 0.05493458187473672, 0.14151895471981593, 0.09352635605526821, 0.11884592420288495, 0.13003047475857393, 0.08994802699557372, 0.10353170774344887, 0.10645506052034241, 0.13032601747129643, 0.14524279561425957, 0.1388962540243353, 0.07133568251239401, 0.1481020471879414, 0.17934150089110645, 0.13310707466942923, 0.1628190917628152, 0.09597333653696946, 0.09315250361604349, 0.12122033536434174, 0.19059264287352562, 0.09414114270891462, 0.13390222271638258, 0.07007036398031882, 0.14033253623970918, 0.09504088692899261, 0.07806173552359853, 0.07068095728754997, 0.1824596949986049, 0.2062957209667989, 0.08034264455948557, 0.09023599047213793, 0.12533551454544067, 0.13138272719723837, 0.1613594815135002, 0.19847949966788292, 0.18745938528861317, 0.13483710826507636, 0.10826258281511919, 0.22899511935455458, 0.09299201651343278, 0.07357602872486625, 0.07436512423945324, 0.10476974238242422, 0.13353679089673928, 0.10202004028750317, 0.19872681211147988, 0.1261213802333389, 0.09941648106489863, 0.054820706735232046, 0.15488682740500995, 0.06885719764977694, 0.14337024252329553, 0.20618320629000664, 0.11172127936567579, 0.18826595986528055, 0.12370245717465878, 0.11567701638809272, 0.09461811890027352, 0.10640945618173905, 0.1028518427961639, 0.20707641621785505, 0.13034804271800177, 0.10091678984463215, 0.11243120341428689, 0.14433974692864077, 0.1330139253820692, 0.11912910400756768, 0.22355824895203114, 0.1588695701211691, 0.14831512075449738, 0.11560236396534102, 0.1493274135781186, 0.17926494857030256, 0.09328955411911011, 0.09616114824478116, 0.12485315757138388, 0.21464442940694944, 0.10520166384854487, 0.08323748529489551, 0.097307363525033, 0.1218952334352902, 0.19453065656125546, 0.1847211436501571, 0.13648084577705177, 0.21552508643695287], [0.02342345462446766, 0.04822986878986869, 0.04391888136576329, 0.006092099439618843, 0.05787790393722909, 0.03160762680428369, 0.022396111894132834, 0.010214148787781596, 0.04247658733012421, 0.035460518273924074, 0.015462372884420412, 0.06730063831699745, 0.04988224744530661, 0.019075205449813178, 0.022631855315661857, 0.04073437063821724, 0.04543552926874586, 0.016502263423587595, 0.039909390799169026, 0.009130283242224582, 0.05782168052558388, 0.021863746889201657, 0.08027285044746739, 0.013788800187675017, 0.020293296248252903, 0.060588312069220204, 0.029957039481295005, 0.03320329011018787, 0.030854720954916308, 0.07070492992975883, 0.00623735979232671, 0.04127705616078206, 0.03228274200643812, 0.028851007044847523, 0.06471578630485705, 0.06041142477520874, 0.043707765372736115, 0.038308472239545414, 0.03758373577147722, 0.03214973217940756, 0.016835113687972938, 0.02887899661436677, 0.013665166866433407, 0.049365668557584286, 0.05174706184438296, 0.021378290706447194, 0.05583986294056688, 0.09286409909171717, 0.05675047729164362, 0.04493547610140272, 0.0318006496610386, 0.05604231743408101, 0.06979191356471606, 0.021251055212425332, 0.018554102429854016, 0.04141657313864146, 0.03995082554008279, 0.007813609787262976, 0.01837074530443975, 0.017399044141971638, 0.030283540354243348, 0.042454131213682036, 0.04794506050114121, 0.010219755183373178, 0.029135771228798797, 0.06383964831807784, 0.02297232552830662, 0.08837719128600188, 0.01654893815118287, 0.041372118916894705, 0.04429430800623127, 0.018466593464836478, 0.02656571806541511, 0.03973908529483846, 0.04597734287381172, 0.09513807349971362, 0.02547704255474465, 0.033376649022102356, 0.023798991526876177, 0.046770920112196884, 0.030699407681822777, 0.04079490613990596, 0.07328298302101237, 0.059136993517833095, 0.04891327568995101, 0.0990798327007464, 0.02025197516195476, 0.025665700734992112, 0.014582601342616337, 0.056806385184505155, 0.03275266821895327, 0.030682295028652464, 0.04195993041087474, 0.025189275853335857, 0.025982395080583434, 0.01717193847123001, 0.12384950928390026, 0.06880865525454283, 0.02434679489981915, 0.062417052154030116, 0.07564275139676672, 0.028200709261000156, 0.047409428350095234, 0.04757510285292353, 0.06973779361162867, 0.026964851023097123, 0.01819018883231495, 0.01866508022482906, 0.016082350330959474, 0.020217327467565025, 0.02117610253792788, 0.02923560408609254, 0.08959050010889769, 0.03302406526303717, 0.030899246422840015, 0.050993806549480984, 0.03577674273401499, 0.03429246773677213, 0.007833474748102682, 0.030968246648886373, 0.030517852066883018, 0.02062056047309722, 0.0650378665221589, 0.024970300728455186, 0.025994618888944387, 0.06305657140910625, 0.04658754263073206, 0.05376462126150727, 0.028912438212760856, 0.04545728310144373, 0.051255856773683, 0.07300923485308886, 0.060573343586708815, 0.048794247076979706, 0.024377127111490284, 0.048386060765811374, 0.024570446827315857, 0.02124480590490358, 0.018330962796296393, 0.041694914988641224, 0.029449949905808483, 0.042911677554781945, 0.010059379190871758, 0.0033761574304662645, 0.030146652699581215, 0.05424250329711607, 0.04313803683700306, 0.015553357645070978, 0.046188089065253735, 0.01685539849235543, 0.03185365003134523, 0.06485001410224608, 0.019302708063540713, 0.05048775852524808, 0.007256071133139942, 0.0587064494778003, 0.016541299543210437, 0.04289046994277409, 0.03555030881294182, 0.054981848624135764, 0.033604243238057406, 0.011668318034415799, 0.022881228809377978, 0.020246853918901513, 0.07165335225207464, 0.012493400501885583, 0.035682711351130686, 0.02094755837294672, 0.012834627281076141, 0.009365955417576646, 0.024747123775471534, 0.021412889207048074, 0.03045364229806832, 0.012781816900574734, 0.06651621790868895, 0.017678627711055533, 0.021651840402877758, 0.00957007656273033, 0.028234223801908747, 0.050860029977879355, 0.02625258093965905, 0.018736550318343297, 0.05705546521182571, 0.029314490567360605, 0.024767335637339523, 0.046894657758197615, 0.08785022741981915, 0.05960932174431426, 0.02656197764112481, 0.042006209891821654, 0.016724507390920604, 0.08697588755083935, 0.020165523015228764, 0.028564957037035908, 0.030582706443965435, 0.043260051004056416, 0.06929204360182796, 0.015295582191486443, 0.05502943428499358, 0.0324620788118669, 0.008531504926005644, 0.09886891009019953, 0.046139095444232225, 0.03261649641873581, 0.007267534982280007, 0.043355548022581, 0.0020676187622094794, 0.05828281292425735, 0.056464688519814184, 0.028942042695624486, 0.03172066734571542, 0.04453544578115855, 0.023624034664992775, 0.012230211187021008, 0.014453484610255276, 0.03826262362833534, 0.003362417096338634, 0.03378622293738382, 0.01867129560559988, 0.013388548495381005, 0.02070874797313341, 0.014780049944030387, 0.04117595444300345, 0.07103336123483521, 0.01801030750253371, 0.02613003072994096, 0.029514281810926538, 0.026831846285079206, 0.047566746694168875, 0.02215600718877145, 0.01003499433863908, 0.04600472515448928, 0.05070133760039296, 0.019659705692902207, 0.05313356673078878, 0.03387175906183464, 0.0726095980831555, 0.024940601250688945, 0.025787272157945802, 0.015253260266035795, 0.03110395704529115, 0.07708445510693959, 0.05158942458885057, 0.05034241632425359, 0.016036969908912267, 0.10767056101134845, 0.041729489740516455, 0.03925313887053302, 0.013880321839159089, 0.04325851072956409, 0.0018735221237875521, 0.017224407887884548, 0.049304983778191466, 0.052829671251986704, 0.010640016025198358, 0.031594975518860986, 0.047260540803628306, 0.04370981454849243, 0.04545747309124895, 0.0923380580331598, 0.012079275312966533, 0.004539307672530413, 0.04105430668486016, 0.04805004683190158, 0.033314237371087074, 0.019178510710064853, 0.01866406242230109, 0.004787046745020364, 0.018643675837665796, 0.03339613315516284, 0.11445726826786995, 0.03767386897067938, 0.05111422276656542, 0.037237387749233415, 0.030539697501808405, 0.0515637047189687, 0.046574470653597794, 0.024911975554589714, 0.04372722914974604, 0.020615060946771076, 0.029333682930363075, 0.07113725851689066, 0.016096655545490127, 0.0587336112345968, 0.05391060467809439, 0.013157397059590688, 0.02377867279574275, 0.05054238737959947, 0.10227290314755269, 0.035116019259606085, 0.05017877064113106, 0.010370968408616526, 0.030910286187593426, 0.03840197775779026, 0.029190057422965765, 0.033680140772568326, 0.03943277083869491, 0.03735652153513261, 0.024785798575196947, 0.008548428437539508, 0.010984152871450143, 0.022856474155560136, 0.03783164532589061, 0.029607661800192933, 0.021761530677654913, 0.03179066501823919, 0.027135480527899096, 0.06879377498158387, 0.023637625721416304, 0.018139617617375085, 0.03783905832096934, 0.017049934482201934, 0.017597398587635586, 0.017658977336915474, 0.0260098503037755, 0.06735371332615614, 0.03156623277547104, 0.01580481763396944, 0.017207010250006403, 0.02266384145644094, 0.025391061989856616, 0.048313498230917115, 0.014265347205634629, 0.017930560978129506, 0.020907207591725246, 0.046474145858415535, 0.007912040621574436, 0.0872987684394632, 0.05616429767438343, 0.03201413034860577, 0.028689658202763115, 0.03524166698168431, 0.08181298923279558, 0.03143313813156315, 0.0724603950179049, 0.0026567915670706755, 0.02617449512971299, 0.03735616530424782, 0.03440025641715952, 0.03787272383591958, 0.02378777025400528, 0.06661532473351274, 0.03894070402852126, 0.028176984284073114, 0.02512904569240553, 0.05522922892123461, 0.015173366160265036, 0.01989451952145568, 0.02952737414411136, 0.0341673255232828, 0.07105625500636441, 0.0494522598039891, 0.07030959507184369, 0.11056349506335598, 0.0963182087455477, 0.11770690817918096, 0.0842564616884504, 0.05805291847458907, 0.10930055818919625, 0.2276439390012196, 0.15664321530078137, 0.09644934242325169, 0.1799688200865473, 0.0815706979483366, 0.08659983665815421, 0.09226413842822824, 0.08116346158619438, 0.2162687743880919, 0.14243493628289017, 0.05565694686291473, 0.07111530790903739, 0.18242783099412918, 0.16687375919095107, 0.08872350198881966, 0.12120159422712666, 0.07499705068767071, 0.17040128633379936, 0.20612752570637635, 0.13636751685823711, 0.14165801368653774, 0.21010823281747953, 0.13509309238621167, 0.12065685274345533, 0.11901572080595152, 0.12480332595961434, 0.09868763945996761, 0.1367094035127333, 0.1589904986321926, 0.12693966632442816, 0.1078370599342244, 0.10606478753366641, 0.14662837769304002, 0.056737802257495265, 0.10212975261466843, 0.10358959356588976, 0.14009954088500567, 0.1795429443674428, 0.13083301883723053, 0.15243006923368999, 0.164543764931815, 0.11729727658842291, 0.16933021880686283, 0.10552539969129221, 0.1406649641160454, 0.09315719229302236, 0.09400909979428564, 0.1183281069887536, 0.16343754929091248, 0.10444713290780783, 0.11206543911248446, 0.0913846959759082, 0.06715127240334239, 0.14330380037426949, 0.20721950568258762, 0.23221305810979434, 0.16051663245473588, 0.0660621083474585, 0.20131645458085196, 0.0935711936493005, 0.18337396665343217, 0.10888362556163754, 0.15853818718876156, 0.1709587164223194, 0.11357596662959882, 0.07542424276471138, 0.09656330916498389, 0.09161228340651308, 0.15399943930762156, 0.1108545662303056, 0.08856935240328312, 0.11134000375334706, 0.10954856952386242, 0.1369880507034915, 0.1625663781804698, 0.10568931339574711, 0.2186467003609453, 0.12698056841535227, 0.215244485065341, 0.10294691912297692, 0.10414303386850016, 0.09972817969641515, 0.10773082170635462, 0.09673073768083539, 0.14990131849689142, 0.07941665460488626, 0.14284832695765154, 0.12219589230205331, 0.14115532780332224, 0.20055528756763252, 0.25624505856207436, 0.12763422834021704, 0.11089979737464871, 0.08625201282224484, 0.09877757249133927, 0.15530838764139585, 0.130879389920405, 0.2199021258524486, 0.14722542065594876, 0.0821863327707563, 0.12172508399401392, 0.22768581818257058, 0.1293560109500374, 0.0877017028895872, 0.11043910602373735, 0.2037726834948574, 0.1386782678642443, 0.17297290691307612, 0.12988180773598806, 0.20101762775863918, 0.18736147268542222, 0.07511764671653509, 0.10031157053474869, 0.2712003232112953, 0.21388096894536698, 0.15123158640095166, 0.08498829563281365, 0.1064144501994763, 0.18965996934899262, 0.09382815486086266, 0.10226031632295676, 0.11268044289733682, 0.18336779198476247, 0.20297522842884064, 0.1401235203125647, 0.08259076678327151, 0.14644107488649233, 0.08898074139973947, 0.1100718489448939, 0.10166731742875916, 0.16250027529895306, 0.06950514430978469, 0.21575384773314, 0.08101419066744191, 0.09251740162393876, 0.09317363998187439, 0.10610280585076128, 0.11782202843044486, 0.15551673860422202, 0.16994269165609563, 0.21387867549700396, 0.12674863157527788, 0.127493486606649, 0.07012506747352225, 0.2006475276180676, 0.1801833321473428, 0.10418486555239984, 0.15342645719647408, 0.20305419633431093, 0.15537644470376627, 0.09855364914983511, 0.2640667217118399, 0.11904478924615042, 0.09919902416212217, 0.144318142373647, 0.10308410533304725, 0.11701736732253007, 0.1891835970538003, 0.1290099580905267, 0.0906902357403721, 0.10598111738051687, 0.1064588874578476, 0.08827420324087143, 0.1623192692973784, 0.10921517134244953, 0.1466329510190657, 0.10473679272191865, 0.22108078189194202, 0.1054908147613917], [0.013701319212226995, 0.006856591698514032, 0.04984376772439905, 0.02924386864261968, 0.05847432943327086, 0.0320557856134006, 0.017932102948959385, 0.024166197715593234, 0.014338337217590638, 0.0059058636293879575, 0.0247367235299732, 0.032350911027086635, 0.019900985960183398, 0.010566851290475045, 0.031589716872466464, 0.034861375245132616, 0.02551962062716484, 0.027121825010648797, 0.03384917063106384, 0.04675360729119607, 0.03118356955902917, 0.010576415241562893, 0.019734554890809313, 0.011730078291813177, 0.04346932816718306, 0.03461397459198322, 0.020673750833209072, 0.031025888198720555, 0.018618829581620436, 0.007393976590330047, 0.03627532008769257, 0.04507904393332345, 0.04844559882102268, 0.03690393528501902, 0.027477268794817582, 0.03602842494313206, 0.019548054451921155, 0.09099431442362921, 0.08628152909555606, 0.02565185522793659, 0.014571463190285223, 0.004382776853162795, 0.015099960545610105, 0.016687968280166388, 0.07804732343980245, 0.05029499011912516, 0.035899571143090725, 0.025592895623828684, 0.016362909294132675, 0.04251339446221079, 0.019669602126149193, 0.033574703216020546, 0.016221472062170506, 0.03388877672010234, 0.03952510927670768, 0.02821103317130889, 0.010990207100154033, 0.0481169096726392, 0.013101399260839182, 0.0888274535536766, 0.0305148495494255, 0.04515198305515306, 0.040338228323629925, 0.04244508294920836, 0.04123790129753096, 0.046709617865937095, 0.020135999956567372, 0.00915421177965722, 0.028870257083326578, 0.023453201599685208, 0.04733482003211975, 0.014946626898433481, 0.039184043649584055, 0.05194713467998164, 0.01505266665481031, 0.03981484712234565, 0.06714263465255499, 0.032406771422496865, 0.01036796419482146, 0.04757883818820119, 0.014522820711135864, 0.10568232448505503, 0.020359159946175556, 0.027555405494890044, 0.015482496536735977, 0.036327842090811045, 0.01811174170247146, 0.03547062166035175, 0.021578297384881547, 0.05295431813491242, 0.023039134086242745, 0.020673623607893075, 0.025184125772544315, 0.03625991055741906, 0.05639619380235672, 0.014818348156820451, 0.033099925478122065, 0.03643210917445166, 0.025829168302672248, 0.019326287155438746, 0.04697512183338404, 0.049092459825000594, 0.05361031222024134, 0.029611146077513695, 0.02876703833628978, 0.03537359793803521, 0.04536122968420386, 0.017879233196643845, 0.016034496648769294, 0.006480616716934102, 0.05825907098395484, 0.05881487258843013, 0.007758633183714534, 0.09715682374579565, 0.028978758225483552, 0.01470297175858702, 0.014984602807089686, 0.007329758339827614, 0.04398151693333473, 0.05173975062955703, 0.045455410344792266, 0.036530632459159405, 0.04896746688921537, 0.03294766561261245, 0.037858240505946536, 0.0510040388575622, 0.028752300555684736, 0.015049698064103723, 0.059887222546551905, 0.06063797404723508, 0.01969538306418274, 0.061221561660724025, 0.02817337617411145, 0.020428672466160994, 0.046280878729053905, 0.009583552268200686, 0.04021993592115385, 0.014671620048050369, 0.06704998748110873, 0.020673333534172604, 0.047949409910610745, 0.014701221138238907, 0.007558740159895803, 0.011230749460602445, 0.010818290075154176, 0.034531725969697745, 0.06133333673434598, 0.009542538218998482, 0.028998652872230326, 0.06855153119457619, 0.040691778995096684, 0.05893169596259083, 0.01808180643378624, 0.08684086586747851, 0.054346074882362566, 0.04514782363548875, 0.09168950069163527, 0.06197470160467284, 0.05186153070202895, 0.029473386505352597, 0.023663635665018643, 0.0005025830427517316, 0.026574547502345273, 0.018098440719768405, 0.03894667174401028, 0.015282723952883055, 0.0212634724032666, 0.05517284605386002, 0.01720416040292808, 0.05180059825735433, 0.022046576453638927, 0.011168524406717291, 0.04235259862616658, 0.02657758564289127, 0.024122768081724644, 0.021499524558229104, 0.02411793521605432, 0.025950298677863817, 0.04824895937261837, 0.06376357775713716, 0.06718253251165152, 0.027576460436518704, 0.016303171071090868, 0.029939791121120964, 0.041916846829865656, 0.04264585128320115, 0.0339468830664243, 0.026191193876521926, 0.056964052974113395, 0.06385412825537579, 0.03231570863031915, 0.018357183085754514, 0.01318916691733258, 0.016256604909098575, 0.033318318759224246, 0.040245601508234224, 0.04928788808839662, 0.00942997434841735, 0.03895603213459253, 0.09294419336531844, 0.03486839129722544, 0.07536506772573505, 0.09539227985910007, 0.05870762334338256, 0.048825951625726054, 0.03189987183681556, 0.03262479150933879, 0.06667421478778124, 0.03266994122947965, 0.043310618826321194, 0.014912762911990285, 0.026588228464658772, 0.026037417485245636, 0.03910701635426708, 0.082551160694233, 0.06839808728545904, 0.01870101543941668, 0.03417041964296784, 0.04709025226267321, 0.003942433919291943, 0.02792922400736383, 0.0571630537243826, 0.05649471030171428, 0.044682915189436505, 0.03916319566113608, 0.046838532734130106, 0.02724115048269076, 0.031091689132153988, 0.018588733160868287, 0.04067338051806603, 0.00833081207903368, 0.06705198237406355, 0.009605711525572198, 0.030606231253061975, 0.035489837772079875, 0.036489231644996574, 0.004905775106245918, 0.04133794450068048, 0.03985814104921051, 0.03596311255491205, 0.03988979470783046, 0.03196133693147983, 0.023406971312527145, 0.010922927808548723, 0.0432203499201153, 0.043911994235324006, 0.02735679829493165, 0.010443451215646096, 0.04961675365588494, 0.022835419213931476, 0.028746139457715408, 0.025682608131319284, 0.022625787516257594, 0.021563568085964237, 0.025982683457966362, 0.08409262262284756, 0.014123002433085015, 0.014550304772066218, 0.010459030379674264, 0.08916149634335722, 0.01175620443453746, 0.013915628560685685, 0.02481374064726489, 0.028573309803115468, 0.027722389570304325, 0.03345205122604966, 0.029828558875513927, 0.059255506444190226, 0.04843892203643918, 0.004402482358273119, 0.07620789642844882, 0.0404761982416468, 0.04284837023754205, 0.013685814687050879, 0.041959652211517096, 0.025985200822885548, 0.04566088092646428, 0.04419748784442033, 0.031381762852626185, 0.0404826239682734, 0.02507166368221598, 0.009461165755055845, 0.08263984522117035, 0.020731436487819468, 0.013801566824050886, 0.008797683187627366, 0.10593909570681197, 0.07427052967250347, 0.014285177391554629, 0.06789656169712543, 0.020148680079728365, 0.025807241443544626, 0.01965066760645381, 0.02123875167619969, 0.036677077279559205, 0.05843372589775494, 0.04625528778082558, 0.08341220806219748, 0.06504096064184393, 0.01946334444385554, 0.054406970007611175, 0.06894117992903505, 0.02816224650346807, 0.043217601853289773, 0.0233625136981053, 0.0738453935565693, 0.08943045405404908, 0.017814349981823137, 0.02846960929621543, 0.03841792333072849, 0.06569248318139996, 0.03740455163642764, 0.038010887136416774, 0.05230181171957936, 0.022506387405363575, 0.0368649873749486, 0.03160680238423603, 0.019411539991519282, 0.046641014582876644, 0.048181289075208564, 0.015448544340740358, 0.03765259689784475, 0.007128962864434081, 0.01420862931159458, 0.06504255519913775, 0.031971107835748365, 0.028517327271401882, 0.06475459850792374, 0.01441128142843289, 0.03699220929827009, 0.05958323207284723, 0.08508368408573524, 0.11004033099327769, 0.013858821608924439, 0.0756564713748438, 0.056681548311774216, 0.05732954586190837, 0.037817921955138445, 0.05762425397655793, 0.016401762209300483, 0.0080385195490505, 0.046830051046397, 0.023558796915624822, 0.013463316269085875, 0.019500979388664876, 0.05578211621780481, 0.025726034372512783, 0.016582132084295154, 0.0024028072158606456, 0.011797675646708479, 0.00609580212039873, 0.06168825126120022, 0.23832489443676813, 0.06569172322217907, 0.17375760552074226, 0.13478411468011992, 0.17685659708721296, 0.08802927924054009, 0.10234899406454392, 0.1171228252351284, 0.12455932476690837, 0.11563916770475251, 0.10483829477535826, 0.09259259687470538, 0.14833874734384672, 0.1019533063684191, 0.22506642873798097, 0.06797446430261646, 0.12115341824080263, 0.12294127659073897, 0.15134631310190472, 0.10127996892801353, 0.12065800625298705, 0.09164222715688602, 0.13249157555401325, 0.162695991939732, 0.10671047467206206, 0.10222770592996053, 0.15968387999704906, 0.09105076175183058, 0.10062260420194694, 0.08831375504710845, 0.14887234728251184, 0.1794624701142311, 0.1512640339455434, 0.14088930136391095, 0.1384295847799097, 0.18928468520087854, 0.08546599785664252, 0.20342614209013327, 0.18807823636702128, 0.12260507605969906, 0.08174462004431657, 0.07771944174809114, 0.094733951613307, 0.15665188697831972, 0.1376250593789986, 0.18280990049242973, 0.20328848090554985, 0.08065372572413512, 0.0856946777286274, 0.12991258608443396, 0.17234169292662824, 0.09884710197470017, 0.13408522361091205, 0.14940566223646912, 0.1133440365748746, 0.13614008549068654, 0.08225827105343342, 0.0925409739304866, 0.1625949309340545, 0.16994881204196385, 0.12886880923594746, 0.20827261917293072, 0.15074376043464455, 0.15500776948673384, 0.12643892105136598, 0.09154579376003572, 0.14583170972764492, 0.08750198289219822, 0.1028335155653102, 0.14804469740816525, 0.08765067027083465, 0.14497172087430954, 0.11420680742178645, 0.13417111257357256, 0.08464305022997515, 0.13042886980942317, 0.10350604554904358, 0.07461010252258607, 0.0547210265483175, 0.15110228476779802, 0.08092572327171053, 0.1690192190664155, 0.11052991436528307, 0.13589695282280445, 0.0878656640914934, 0.15403875362660202, 0.07377919568014996, 0.08238907903432846, 0.14899080592606748, 0.09001220962298767, 0.12224937443222318, 0.1208615531878812, 0.09038284580622401, 0.131432816652315, 0.128558786585927, 0.10007769308452096, 0.09984061294900519, 0.1065174178885562, 0.10640016703733376, 0.09172413311898708, 0.17587634468717234, 0.2894429000360625, 0.15406885344002927, 0.07884716016373464, 0.093478973954916, 0.12127455031233174, 0.2151583382593734, 0.1064966886437365, 0.09390355367213488, 0.0851817527519805, 0.32072843983769417, 0.16764183369066032, 0.1367775827114071, 0.16061526430504663, 0.165522429559912, 0.06205558976424592, 0.05678814955587898, 0.15945591937218392, 0.14555231614836625, 0.20290979051164218, 0.11663280081536088, 0.173716879848923, 0.12735796959272452, 0.1301637390362365, 0.14045516108827932, 0.1574372234089034, 0.11141194203602416, 0.1239087318203279, 0.14014188147016934, 0.14929873868823051, 0.19290487308587345, 0.09125576075166464, 0.08362322566764695, 0.1183296540485961, 0.20168833248317242, 0.07124197682631866, 0.09324591074671064, 0.08657541618283306, 0.14220456007335866, 0.24331036263278552, 0.09938087154711996, 0.12869551139218466, 0.12469356613499777, 0.142168149884258, 0.08126193737345082, 0.13322828816516058, 0.0898966822507126, 0.11210047866084746, 0.21629154602331774, 0.08843891083129815, 0.07098766190132924, 0.14909289830497333, 0.11632034900997366, 0.13071920137320245, 0.18851525363113197, 0.15001618090484822, 0.20526503984417233, 0.10066797105329377, 0.17315950404320443, 0.21075018122792244, 0.12241515410797936, 0.1511925027838775, 0.06322710082999297, 0.04767510534397193, 0.17528762056359223, 0.10835693310946226, 0.10473804801170315, 0.11729354464582034, 0.15614331141114235, 0.10449735128453799, 0.07098170436386551, 0.140970589859145, 0.15583231167069503, 0.10570390189864806, 0.08897637163421937, 0.12826734222471714], [0.05103827094925301, 0.042974855950368304, 0.04622901490490351, 0.03745280904695392, 0.034233845703835995, 0.02843993017449975, 0.026543189006458436, 0.05497004890016147, 0.06243810709565878, 0.03458961518481374, 0.04383920778387359, 0.06306596911911454, 0.04272662069914596, 0.0761212000091161, 0.0627436310585056, 0.02582418276662273, 0.02126712292166693, 0.028870854194142988, 0.016092882890786444, 0.005425356087341372, 0.026320251237068857, 0.05486276572836297, 0.05898432992398739, 0.02330146250980241, 0.015689431057710732, 0.043497117568871806, 0.015350524868283952, 0.04395222457657967, 0.02618624226722334, 0.041821136072810204, 0.0688086145424417, 0.029774934252990142, 0.04043038694986275, 0.03919398758028235, 0.03084349798570786, 0.046482678436275036, 0.03285015334508248, 0.04630025090383632, 0.049669669209314246, 0.016308119287714362, 0.0596058883571199, 0.03580054574246917, 0.005244130834138819, 0.02034984535670706, 0.023144780292308757, 0.01868907661576356, 0.005327642803812134, 0.03274613731939878, 0.009549985988996923, 0.04962111324337976, 0.066247911591615, 0.050002605986914465, 0.012900549502644156, 0.03719852804871542, 0.014086585458634155, 0.027573422295972705, 0.05213621524827821, 0.05533976227577243, 0.020066628232598305, 0.04025977610477379, 0.013679420342668891, 0.02449298357324941, 0.04825086944869586, 0.03723735721515758, 0.021451294289103577, 0.08552921696433, 0.06325448650334563, 0.025699971842446497, 0.04641209043828504, 0.03485960766140904, 0.023329116204487424, 0.04095311336485403, 0.029821695493800298, 0.01924461019890649, 0.03507691867915647, 0.036989159283361266, 0.014208728547341056, 0.04323109791481069, 0.029270728451332877, 0.050640907271632125, 0.034488944336771965, 0.01342003676109016, 0.02977018111518451, 0.019231665447088223, 0.03787849138357809, 0.03076436723183308, 0.010004736765820001, 0.0640268697004233, 0.013539723553029554, 0.05366703774780035, 0.046034441595630984, 0.021291461972785846, 0.02289594284125737, 0.05554956530353852, 0.005843247569698308, 0.07564323994198016, 0.016768815727638345, 0.05009482568129897, 0.003871852282567748, 0.06202699629856007, 0.008414409289668714, 0.03644773583593113, 0.040429725378219566, 0.08450979273766279, 0.02073309720227761, 0.024251789819183092, 0.07564259533371244, 0.0794105613604188, 0.012602174754387565, 0.07181278084005628, 0.06604139267333917, 0.02425921299228711, 0.014529940239819033, 0.07336936052888632, 0.047275899443775415, 0.07072719944907085, 0.052211878688207695, 0.02121654661771442, 0.030244578873472552, 0.01703575479664973, 0.050995228080345054, 0.034885432704218795, 0.030658125611288205, 0.02094985860665994, 0.019976366111742597, 0.06429894188685076, 0.04669964340116296, 0.019864706389073814, 0.006853741851435708, 0.037722960979278596, 0.03593736215095435, 0.06171032400535686, 0.0740860156448824, 0.0056149302898640075, 0.09827840820487056, 0.006054231672481234, 0.03508511198950665, 0.0045898627722635865, 0.015190321054043514, 0.007207488025804716, 0.04521910373919776, 0.06797397575740304, 0.07684075246964182, 0.03425168438947626, 0.12664176230984076, 0.03647715372166463, 0.036347054809864075, 0.033438005551163635, 0.02188656262920371, 0.02813871151634625, 0.009557175067519503, 0.0674832524465663, 0.06640867689358336, 0.07896569344614233, 0.01056068595166185, 0.022723823952089463, 0.03479972694601331, 0.030794310982206037, 0.08264450675674848, 0.01695962486389492, 0.06056606290595872, 0.0024055694895131247, 0.0195114339169647, 0.0447056562905865, 0.05101554681147848, 0.010570780008233019, 0.04250633091266666, 0.07298107564981494, 0.011442537203298082, 0.0299035268170493, 0.0439566282688507, 0.03417453495785594, 0.07399471197277308, 0.02771606732026807, 0.010354054226939167, 0.029916076322219202, 0.03309880928801639, 0.025458808622456024, 0.01306210529790925, 0.06504060101828404, 0.0033396620004038724, 0.01225645437703601, 0.012917336459005517, 0.034856153918164115, 0.02978919366640704, 0.030408655426331928, 0.03085162004988108, 0.05010717162596328, 0.031748677271285226, 0.03757858908336077, 0.07708514042730842, 0.020777926314622164, 0.03958476268287216, 0.025265093659982085, 0.016606323554047515, 0.03276234752099429, 0.043551234129284105, 0.09142434956239802, 0.020826266845688224, 0.05077139294839331, 0.03218778442325337, 0.0683745149789112, 0.058882162906229496, 0.03360714397526213, 0.03097564946593983, 0.039036757445761135, 0.0188921027750309, 0.013321012208637382, 0.04795925884640642, 0.01180524385667273, 0.05196560440318925, 0.04230265166344387, 0.04381562529930046, 0.044000271641250165, 0.00546175058531974, 0.015398276770221335, 0.043893809496824227, 0.015764704340004494, 0.0781768693455628, 0.019374447874724865, 0.004570535126341773, 0.01249265665787139, 0.017108373310683028, 0.01812771102413535, 0.0468243818863162, 0.07535649104309933, 0.018938716434474503, 0.024386076988386254, 0.007720898154989949, 0.026473053930593387, 0.05036192759871483, 0.0747736973155822, 0.029601381958595345, 0.035751161963811944, 0.03527240122535399, 0.021245431853458285, 0.020469386263617446, 0.044515127050025124, 0.04987132642418146, 0.020033605629578233, 0.00807823590002954, 0.01294249399299068, 0.058076517922537665, 0.01329776390256094, 0.018052739689924886, 0.03043706908023783, 0.030002799882952656, 0.04134352545120886, 0.017054487452177063, 0.004221280429711831, 0.024298737657123377, 0.04540226748213172, 0.022200169640460184, 0.05049620967890535, 0.02364005148410797, 0.04103619658521243, 0.038056959664183, 0.010948638348574085, 0.05193012041438903, 0.06171782181731292, 0.08166147914848157, 0.015067187304209386, 0.013816402144064861, 0.061481488070317676, 0.04166909333850656, 0.05571351632741945, 0.010471836031813706, 0.023599198586972694, 0.038585436663457325, 0.08931101832006659, 0.03375760233029723, 0.04919102042913437, 0.0163062431383878, 0.021223742481587187, 0.06866275665483304, 0.058923539971666675, 0.04607499424102051, 0.04764429306877511, 0.032955224492720196, 0.02348509444189923, 0.045975911164922376, 0.038635719501014264, 0.03196592382820589, 0.030515578974570547, 0.010039035862843906, 0.046245913819542954, 0.07626262027770281, 0.0353528720858906, 0.032310891031686745, 0.038056009715156894, 0.03444912111652749, 0.05954896605440548, 0.025177920569798777, 0.04747252192880426, 0.015738412804369415, 0.050374680664390326, 0.02347083163580724, 0.04673641321382352, 0.03422390177313771, 0.017519392505554215, 0.03635712426954082, 0.008689522161148489, 0.038128765632531474, 0.06496311910450459, 0.031077467038163116, 0.013627281711835946, 0.03490427222901157, 0.09592923854610749, 0.021462449404810156, 0.027949639429737414, 0.049597866633640866, 0.015048074669071605, 0.005386675774518932, 0.05950374848076275, 0.028909683360585144, 0.024192996456154754, 0.02548253020670797, 0.037757664652807374, 0.09091521759650537, 0.054324880841055086, 0.052793532476893494, 0.05391727128465261, 0.04251342838896172, 0.042160532503787956, 0.017084012207176005, 0.038104857451149395, 0.0558974841343505, 0.02653514327747481, 0.03520167073501008, 0.056703488741602213, 0.07043841494513409, 0.04384783196396061, 0.05676691819514547, 0.02176406839862466, 0.014847593016124197, 0.03358942064057503, 0.012445409416354128, 0.013304011513745146, 0.04437888400363071, 0.014077126680474197, 0.04595572814079268, 0.025185677921399474, 0.019667413850714053, 0.022972744523680637, 0.016248995138864433, 0.017526812285983136, 0.008939512273562806, 0.046340932470879385, 0.08052869207624878, 0.03748381131195596, 0.051227276878697534, 0.02538864979786532, 0.16958947346678802, 0.17814748281879084, 0.07379480198557888, 0.1496743621038539, 0.09616211176450763, 0.09823373345924274, 0.11662160498755318, 0.07994180678256921, 0.2272940727749041, 0.0909187188372016, 0.14908775500953197, 0.10979665549738066, 0.11376774776726961, 0.16826449813587324, 0.17238305642136506, 0.09106802368270499, 0.10877362824976444, 0.15597191346543177, 0.1310251663838114, 0.10981148148753814, 0.07911457759993416, 0.19311800093523093, 0.11231950297951698, 0.0941421062286411, 0.1623467228242329, 0.15158274184380258, 0.13588243217340537, 0.10470002969460827, 0.1286702970308917, 0.11651039309799671, 0.1217750513127872, 0.10128688319985356, 0.1217969815645899, 0.10971183862004961, 0.10752865219754831, 0.16147226760429995, 0.1589707261217492, 0.13376621715724468, 0.142264936119318, 0.1235458105802536, 0.1665557569691113, 0.08321688497172934, 0.11764867630388055, 0.17133307776280812, 0.11710891526724611, 0.06529062081660543, 0.03908466201807771, 0.09576008655130863, 0.19235977876399243, 0.1535578758588859, 0.1529366634786129, 0.12348698159413678, 0.1617555424038853, 0.1539803453321968, 0.10023824125528336, 0.17959326452442578, 0.07591633671628577, 0.16023746957736357, 0.14690097235143185, 0.0930619870445558, 0.1265557376401765, 0.1449291631579399, 0.11580999568104744, 0.09899028643433537, 0.07680515652256352, 0.2358671591750213, 0.13513472729495593, 0.10419421576495681, 0.06056121816592557, 0.16598445762481007, 0.13346200276698383, 0.15237603070480482, 0.09559370297938585, 0.1076470904850534, 0.07126637016023908, 0.10326056514999696, 0.14547819298292908, 0.0965122969022819, 0.0956081354192325, 0.11691911545182977, 0.12261122358696801, 0.08004991098174027, 0.12817156022148474, 0.0949019297425236, 0.16539831193430082, 0.08176529500633478, 0.11900071161133902, 0.11613303263272558, 0.11724553150790078, 0.13862332009843417, 0.07625580778611557, 0.05932216572442225, 0.15285872694637093, 0.1785257796623877, 0.05584856175950595, 0.12509876010673388, 0.05151860588895423, 0.10943387674966029, 0.09633445287389414, 0.19203204634998525, 0.11367202004683868, 0.11681988649070263, 0.12743545829185418, 0.19024960270949773, 0.09429222531616688, 0.09003618905054671, 0.13937318271824292, 0.15796436369419098, 0.0822138541511127, 0.12990470150751726, 0.10610107558646373, 0.1371236898537193, 0.11900076589414052, 0.15215447545051575, 0.16344810729580267, 0.1499904372862407, 0.09977989085018635, 0.16406952323658125, 0.14678141448114598, 0.1614899095147848, 0.09630162534969193, 0.11606209858187608, 0.16352563670703343, 0.19467735583228724, 0.1131307730185134, 0.2200728181217398, 0.06971195499811854, 0.23910192559872354, 0.17385752658758843, 0.16084892462406838, 0.13184224468256744, 0.21496980051909173, 0.09922660661063024, 0.14217925071716309, 0.15973433586103575, 0.15728863781051977, 0.07661400642246008, 0.1257340181618929, 0.08300360105931759, 0.08639229315200023, 0.09705661090889148, 0.11110391427895852, 0.18661881610751152, 0.30092246404715944, 0.1852414578731571, 0.15268924246941293, 0.12347123958170414, 0.13973619895321981, 0.12623024439173086, 0.12082820997706481, 0.1270755361765623, 0.23206972437245504, 0.13970174294497284, 0.17149581760168076, 0.16564599078680786, 0.10401623602956533, 0.1193237757044179, 0.14291875889258726, 0.19508488396448748, 0.08348383421876601, 0.14270519678081783, 0.12605374386268003, 0.14803118099059376, 0.12881133731986794, 0.09261852369776793, 0.139494423355375, 0.15514381575797284, 0.12829611210950784, 0.058040453786296506, 0.12255067112190382, 0.10287115390279464, 0.1977314826633249, 0.15413814543613366, 0.06220015843531915, 0.11305888223328761, 0.14029694029263087], [0.08753116668335029, 0.02428568773237722, 0.04614162977252688, 0.023149679315143397, 0.08037317863532475, 0.04719202573012028, 0.043781786757920466, 0.0318729950647269, 0.09096566667514187, 0.04073778706203614, 0.06771162019244262, 0.06293827561395508, 0.014119179736423706, 0.03515184251591563, 0.049683507931019576, 0.02070986246690154, 0.026810983029593314, 0.03920357867277094, 0.06625897171241896, 0.049991043750196695, 0.07896425495190279, 0.040260010199355226, 0.014436585695615836, 0.052973615670842786, 0.11053241815950189, 0.03555329775969897, 0.042138269769826105, 0.02708677019524787, 0.02207363982285772, 0.023830619740432928, 0.021453871025836894, 0.049201262915240865, 0.005044739926233888, 0.028581933983202492, 0.035128032722111256, 0.033138289848076444, 0.06964958405920438, 0.027175195182540586, 0.0341951895638236, 0.020262650214135647, 0.050887249410152435, 0.01822616475900369, 0.022646250436082482, 0.01568461854809097, 0.04270828329026699, 0.022518617999074713, 0.0268635270850999, 0.06941269391349383, 0.05557656760460564, 0.008607427905579763, 0.011462831337537085, 0.013556549525154489, 0.035455266412879737, 0.02919002010353974, 0.007771551642300827, 0.05518036422186664, 0.0342536724970809, 0.024193452770954797, 0.03893940802663565, 0.07143094882901226, 0.04369625402614474, 0.004737940741636391, 0.02671804748076413, 0.03533487055184586, 0.02673472587152251, 0.02228607556649617, 0.04350544658622571, 0.009410990634933114, 0.055800043112997494, 0.029683464339801242, 0.03904617890449507, 0.01065935766590493, 0.05375616332249982, 0.0423433501938624, 0.03776999024142112, 0.04939347152997341, 0.03393555831696306, 0.04204356663727334, 0.06121149220104728, 0.029462926888040135, 0.01796624852743532, 0.027518571221402714, 0.06470849883875676, 0.03661651463646974, 0.04318799737042614, 0.07289984822273254, 0.04766699345782399, 0.016104875997241055, 0.038037886044808795, 0.06145170038299901, 0.11931080211486135, 0.02061584295838007, 0.011044111618373011, 0.03347715023638947, 0.024739724351093173, 0.017474492147032703, 0.014356306521221995, 0.03848674713767, 0.04656173794397286, 0.03274250376437392, 0.051810633790280135, 0.025303698909868087, 0.032931326489363394, 0.04135700794202941, 0.06273512222937175, 0.023088163330352733, 0.011415960682955171, 0.02144579645911498, 0.016310477196904163, 0.016458696386377727, 0.11663493141531944, 0.0197684002175395, 0.028604753115879636, 0.03978148355547871, 0.060771007622991285, 0.03168820283774819, 0.004913842887617648, 0.04394531369741474, 0.011565258743108382, 0.0387054355815053, 0.028421080471681695, 0.03046486187460167, 0.05159015062132052, 0.034237421583384275, 0.03251503507739731, 0.003978393306689603, 0.049587518974606476, 0.07020247474844966, 0.06184475536325148, 0.07090726228696959, 0.016807546506502798, 0.03584764964346375, 0.009363583089517695, 0.05169394612312317, 0.029181697871536016, 0.012390171576823508, 0.016630319944982017, 0.03154340346476861, 0.03752930708495634, 0.045312256419232914, 0.027941602182441523, 0.019349209764706235, 0.03332092772637095, 0.023450411124421016, 0.025960010210318223, 0.02737385836163802, 0.031066630833915303, 0.03442115868840899, 0.0372196745925716, 0.05105265589164836, 0.05410040110083563, 0.010578624721217369, 0.011061918073599892, 0.03747454930895141, 0.020280005443575125, 0.08428339274334055, 0.027347799224246825, 0.024362521645213877, 0.044725846100066385, 0.01822234969586134, 0.01642381799008165, 0.06438266632280179, 0.049609428870358636, 0.01540393235960177, 0.07265115835304771, 0.013815585357536162, 0.04748422326520085, 0.04960524909464376, 0.04561985330656171, 0.031194205595446483, 0.051952851337513754, 0.020302310585975647, 0.04941607692411967, 0.05461513776598232, 0.060501249240977426, 0.016188688642744507, 0.0438565748876759, 0.02700975307795618, 0.03931745720495071, 0.016040379547380974, 0.06802418056343283, 0.018110664528129355, 0.02011457860602864, 0.00813261030374893, 0.08034180317606245, 0.019978506889726435, 0.019276084045746496, 0.04885762564039656, 0.021210650148402368, 0.005131585623270699, 0.02102310476558549, 0.06363196910492011, 0.09601825555520398, 0.05910130257585219, 0.037225394642778804, 0.013777114118316343, 0.01537204291006284, 0.09296777245721646, 0.018965452410546795, 0.04909695851217423, 0.10261413840843098, 0.05334610764735511, 0.008462581883317657, 0.02849139366298914, 0.019220515420394282, 0.024242690664583018, 0.02827681544502931, 0.06170948940728392, 0.052691650443843434, 0.014770363856639181, 0.030154242113764797, 0.02511757505791528, 0.058210501447319984, 0.04173838194193585, 0.0324604706838727, 0.060691578313708305, 0.08102301162268434, 0.027335153027836765, 0.024497319412018572, 0.022477626002260616, 0.060126243292221, 0.04452968841152532, 0.02867010621620076, 0.049395463030253134, 0.076401183913861, 0.028415518180866326, 0.04379937099292874, 0.01447850389273039, 0.032448955944606235, 0.028102910312424813, 0.04431174296353545, 0.03111199089991195, 0.07246600650250912, 0.04406721590619002, 0.02756974972518427, 0.01914184946300728, 0.013400215905026665, 0.029143957753798792, 0.023701993249622837, 0.02695838628070695, 0.045319906901568174, 0.046778557023831775, 0.02965712361037731, 0.020606652201552476, 0.057877618952521255, 0.054548861858035834, 0.029450482555798123, 0.02247265403691147, 0.0024463371456866817, 0.05582599029211061, 0.05911046279860394, 0.05858526312346969, 0.006532677740324289, 0.03383328951895237, 0.05509246001020074, 0.04785677970253995, 0.0284053656006498, 0.059624961976494105, 0.05048426067722695, 0.06791458358722073, 0.01572561733025525, 0.033069615318839035, 0.03000866242551378, 0.04522488825023174, 0.05192251403682998, 0.018423891559775387, 0.12233486984457288, 0.049823720407273085, 0.01920026115008763, 0.02622324787080288, 0.05643462941848806, 0.04146533266508153, 0.021693846809544733, 0.0394291610323957, 0.04079065851068922, 0.09150831148560558, 0.02136440109461546, 0.021073294304577366, 0.058682157924132686, 0.012557028426921793, 0.041142353388879976, 0.0420945958633508, 0.02759270795754024, 0.03490048600360751, 0.06579676722841603, 0.028901598615837947, 0.04620851296931505, 0.016004992249820913, 0.018017254004787122, 0.006855541665572673, 0.0251135733976428, 0.05380419342379485, 0.042719852312334945, 0.024429148695032512, 0.030169906094670296, 0.03404014091938734, 0.10345075173037392, 0.02796837717427739, 0.03163032380065747, 0.05703504130776439, 0.020642185384141545, 0.0035943424861345974, 0.011977620589147722, 0.044847395470631976, 0.010336246923543513, 0.042251527442463806, 0.06226762517222336, 0.08145026476787669, 0.0318139014499528, 0.037436171368296654, 0.027870184675391232, 0.035566010113273344, 0.06382075111780848, 0.03027651073145015, 0.05322244803288153, 0.048454457095691135, 0.04159155374925051, 0.021480355943952287, 0.010883353101754827, 0.016159487888216972, 0.02588260463172836, 0.03499780149598207, 0.03807729875136699, 0.030624690798244307, 0.06672975966440779, 0.023508997534268668, 0.015980607397588234, 0.04146411469472306, 0.015040744794532657, 0.04461804724165371, 0.03723441915852683, 0.012513296844969903, 0.006498372282034585, 0.03651663428172469, 0.02941348882658141, 0.022306168684735894, 0.023710822686553, 0.07951695565134287, 0.02199652771066342, 0.02866663211690528, 0.011234881738866014, 0.017972260347700546, 0.022291536077058742, 0.03345943368705256, 0.0628066873177886, 0.04470764779086624, 0.056353025404470306, 0.02104088238307408, 0.05498612000207816, 0.07132287855659213, 0.008732884789683988, 0.0344453484618238, 0.10304720659873315, 0.08705917772437845, 0.1480741865400757, 0.14100777357816696, 0.2243258213358266, 0.16863982299608843, 0.16477773737694534, 0.07574564444699458, 0.16469157700027737, 0.23155580194933073, 0.2168931487415518, 0.13394144204046043, 0.19033234326967172, 0.16958386876753398, 0.10059648738907916, 0.1433171403727361, 0.18087344297340938, 0.12776635267904826, 0.09253122338226863, 0.11838852374681405, 0.09799383061804942, 0.2043723998857396, 0.16176892311445304, 0.0950471158804638, 0.2488327148769583, 0.1897708691124405, 0.13222681118973664, 0.10939986178917543, 0.10898301058581897, 0.09599825234285422, 0.05272070870601705, 0.1060189592785069, 0.12280217691191606, 0.11954930717391626, 0.09541247984660522, 0.07812905976814882, 0.12398608481245381, 0.11088974148567234, 0.1051137867782797, 0.09543989944670882, 0.18669626409454004, 0.16514824463852815, 0.19375270259167465, 0.08053597275699888, 0.1285172738134861, 0.1301106233149767, 0.11805843003094196, 0.17449122401220457, 0.1529169859630721, 0.18123116663524083, 0.16226277447172574, 0.09968981532646076, 0.22299309713499887, 0.23374529874750546, 0.10455060271280152, 0.13736284630639212, 0.15047748972262653, 0.12924447336367198, 0.09080130513757467, 0.13182372067655834, 0.12643109075725079, 0.08229485087628875, 0.0848154184807624, 0.10507063873644386, 0.12033188875232424, 0.09240614902228117, 0.06049189902842045, 0.09307074014629636, 0.1433383242360183, 0.1214300026851041, 0.1397830450109073, 0.12978732851999147, 0.132744628403868, 0.16325958312622138, 0.14774615557066031, 0.09754126133131129, 0.22058881686202117, 0.16359520011714526, 0.09559772669204644, 0.1738334521651268, 0.08040891707475696, 0.08276365750602313, 0.1266987185393061, 0.1569373466606651, 0.06797429466886179, 0.2283397088093417, 0.07760884732540164, 0.12621717580727168, 0.10743078030645847, 0.16191254183650017, 0.3347624982041972, 0.1518717027668442, 0.14156790423606122, 0.11349246611020394, 0.1562798869396959, 0.08795981761068106, 0.13210025083805832, 0.10499030019023589, 0.22503133490681648, 0.18122325491692337, 0.11895045930785791, 0.09985871626330273, 0.10622666563306536, 0.13085747323930264, 0.11765813508204051, 0.11285203761820282, 0.06574515106954745, 0.16370144513036522, 0.1406320280262402, 0.06505428706961018, 0.23093985500080244, 0.09018112413053002, 0.09370461399001734, 0.11400951657976423, 0.1546004991978407, 0.1361205843942506, 0.11016306440745081, 0.1255571919360331, 0.07706017033862216, 0.18088785505720548, 0.16410518703716143, 0.10082037680383239, 0.09557363869888441, 0.16411612502166203, 0.12274637419198241, 0.05376225317429219, 0.09264697467109986, 0.13479213496404036, 0.1544428076595068, 0.16577392177922384, 0.143355559025492, 0.2090718520006963, 0.07676538079977036, 0.11338664178869554, 0.10316584166139364, 0.06308010300355298, 0.09872090803193194, 0.14755698000746115, 0.10244089484746967, 0.11004400865307876, 0.12489817158452102, 0.18104967208845274, 0.13358735532632895, 0.10763271911335842, 0.09782007815582411, 0.08460604293005806, 0.1154951418616942, 0.07603843909289155, 0.12310253722327096, 0.13210486487618514, 0.10987474809267692, 0.16234464650707586, 0.06055945397487708, 0.12408789220665183, 0.16174950344221933, 0.13078819481389864, 0.08848222850688867, 0.08684947647686515, 0.0830478211864829, 0.11830821234200682, 0.06424900849482842, 0.29159814438649584, 0.12984846452517168, 0.06086296268871852, 0.15735621989837714, 0.09173604819391455, 0.1543155959142106, 0.12501847584332737, 0.08649078250995704, 0.13028184484158242, 0.18643961500908646, 0.07847369448947054, 0.12055923869567257, 0.16133660131267138, 0.13829059366668972, 0.09155511004584176], [0.03285893698089889, 0.0854732853227428, 0.025967604713514447, 0.08729311624275786, 0.031884340170238695, 0.02749390816981239, 0.07418702236775841, 0.025821163285789744, 0.1157805472612381, 0.017412641983745352, 0.012245747094441737, 0.006797649481865976, 0.009378685582695263, 0.03635764674150518, 0.01448020531928965, 0.04566713023398604, 0.04389564832672477, 0.04349026097250836, 0.03262988391465374, 0.040292447565921714, 0.019823068087654452, 0.06435493459658963, 0.03282242840422051, 0.05101031869915979, 0.030009829505745853, 0.044635638262012174, 0.019359053611489277, 0.030512651095965078, 0.05901069100946188, 0.035741421593619246, 0.027018419666481868, 0.032657096561576636, 0.008972545902776932, 0.07062467280775309, 0.0342410246043333, 0.008289579202287962, 0.03459270251914859, 0.02365070109122566, 0.008014753011853566, 0.024714435350948145, 0.023080482313941632, 0.04999131516420415, 0.014925987559503742, 0.03622248595846551, 0.016905223318774785, 0.013339401355811527, 0.05930539233876126, 0.040895261469164064, 0.008327885896765759, 0.01916374239538397, 0.034210907827530584, 0.053735138914946995, 0.05195751965844205, 0.06097215932926961, 0.038073278431381495, 0.024220987722011547, 0.046730903509472094, 0.07898121832736901, 0.01782753222089793, 0.0437473341423486, 0.022599716504503573, 0.0071597895585000515, 0.03479404082255704, 0.028042364632710814, 0.036392906813749244, 0.037193795266960344, 0.029943601095250676, 0.034535678436181376, 0.04399284507547106, 0.013658814082321311, 0.078268641206835, 0.005332107140150453, 0.06520395153867346, 0.01613603432529739, 0.04998639239264386, 0.02817721837865455, 0.011303122005691486, 0.028568122402897904, 0.01746797312184104, 0.07085500830518347, 0.011779256813627268, 0.07964437095714466, 0.059190706349909306, 0.03490889644516366, 0.035401088784315755, 0.020773078181913922, 0.07955791202506848, 0.009314368096446353, 0.04038252987499748, 0.04626062785142234, 0.022595930279099515, 0.009925909656366068, 0.025104776191126024, 0.001108770431268827, 0.052991664702338834, 0.07575915407921587, 0.012374048736611647, 0.029794353925223862, 0.04840485957850303, 0.05430531867646745, 0.03767635580152273, 0.012199921383788543, 0.015270250782902752, 0.01361389591225556, 0.04066975374839135, 0.047183109779975245, 0.042165940427886586, 0.036630024268691025, 0.05667240844507303, 0.03765699719744069, 0.04261476759399686, 0.04337831626513174, 0.015068610531411, 0.03558433734412704, 0.02600364340469241, 0.014215166996499258, 0.03471918823197484, 0.041587893052824905, 0.019074871271316494, 0.06559754256159067, 0.039174354169517756, 0.06315204128623009, 0.08738510523523603, 0.011463148552658302, 0.07363132254353591, 0.020091786614752243, 0.04009504137294633, 0.049841175720627816, 0.02090679368536387, 0.02999709340344582, 0.06218620775533574, 0.040178535106991015, 0.03750458466155188, 0.017151188870359744, 0.009199051918195826, 0.0361794634456081, 0.03227463012029018, 0.024328966392204165, 0.044039596138255935, 0.018540738682661737, 0.0034276841075292653, 0.03870009211823344, 0.02655905654786953, 0.026878805997382318, 0.03764222888275981, 0.04876255609893373, 0.019515793504459516, 0.05387618259659835, 0.02011999161913991, 0.0777869899091976, 0.0527653664882694, 0.009402735408262482, 0.0297654177993536, 0.019616055535152555, 0.039594323241284916, 0.0666952697294099, 0.034836021784160814, 0.07472121263188974, 0.04178915671738131, 0.05270811848874603, 0.03690956034032362, 0.039526785258203745, 0.05692228914371558, 0.03901381278410554, 0.04735995636188558, 0.0370873874053359, 0.003916247556584754, 0.016761984576338103, 0.022641127496691685, 0.05655400747699397, 0.01388769581847425, 0.022947450434522967, 0.04217648486207638, 0.03938375007627266, 0.05545500127066459, 0.02427532819898001, 0.02830348696027483, 0.07947855056928736, 0.020010913722217083, 0.10416537124131407, 0.014823681442067027, 0.06982015419219222, 0.009304489474743605, 0.04796539280297501, 0.04325663458023753, 0.022783750468598943, 0.03155094877417598, 0.032498773985675404, 0.013603213226555713, 0.050630878524056504, 0.04717430918078337, 0.03377140373257654, 0.005097961244505963, 0.025460574509842054, 0.0349062637292913, 0.03563981775992683, 0.019698448346129487, 0.010700655851646193, 0.011965941305139234, 0.019810793389167105, 0.03263966838962265, 0.00928382299441312, 0.05187370362026351, 0.012920002253460032, 0.017976582615769336, 0.005296435281966946, 0.018669007246249487, 0.023930354210148965, 0.013878840088312114, 0.05045348572145615, 0.02693173851418708, 0.07782273513398, 0.006048228757988129, 0.04970068843769176, 0.03248937288299203, 0.013601455820857413, 0.05071318142914346, 0.046866742827530415, 0.029139106228415455, 0.020959017133074145, 0.00787208423883255, 0.08023211799029793, 0.039678841563207765, 0.010871018183284571, 0.05063048836642078, 0.05920429062098265, 0.022065032606146166, 0.017628078548503772, 0.04245192936754652, 0.034720772611243386, 0.010887224144036216, 0.016239198789532696, 0.028687093340392624, 0.07748301979154348, 0.013822796488446849, 0.00928072548205299, 0.0308457371512694, 0.031402176578662226, 0.03045140313250678, 0.038014500335391076, 0.009877346905081399, 0.01576508771229003, 0.01457020959683827, 0.023233780338029777, 0.03910039045980998, 0.019122594335515584, 0.04778875656692045, 0.018935015025947775, 0.03041496580200536, 0.04770941885986498, 0.07888623021010842, 0.024370416400155852, 0.027615445666015148, 0.044078713682081015, 0.033243937750480006, 0.044150797849787135, 0.009580457300346876, 0.07864302290337426, 0.007941688361045505, 0.06806428876838513, 0.005716134636064193, 0.013616844146911587, 0.04199340254334467, 0.010580583142914941, 0.04055480652355722, 0.020969203640041605, 0.04487362763445292, 0.049616142974368165, 0.039331906608172824, 0.06852633718933378, 0.035990186102156124, 0.023039982255016054, 0.019189938936116438, 0.04840789941538658, 0.03269418189302087, 0.03838240202250225, 0.019581299275159836, 0.005821408920123109, 0.03484753652342728, 0.09108015588883843, 0.06315738135682684, 0.07247217438582863, 0.04914339405617543, 0.02000122593848833, 0.020349470466109257, 0.0181485691906086, 0.023369975886972885, 0.02851359872147441, 0.03500795237986105, 0.017206511526767696, 0.019278433473248566, 0.035092209465801716, 0.06086269806006125, 0.022609697754627893, 0.006953360546114189, 0.01847462053410709, 0.039073893667331765, 0.01826472590411348, 0.018518204534692422, 0.017190031607502272, 0.0447965765904103, 0.06662153332893338, 0.06282386103911058, 0.023204316651182513, 0.014448453273091997, 0.03985522334863033, 0.041435555155788145, 0.03360410074570349, 0.04664071602746844, 0.0354409798580621, 0.039547382188694816, 0.01767910098923104, 0.023872107067810636, 0.02991526886554701, 0.0497456990581538, 0.05010407750627824, 0.027758521560047354, 0.03703830896743706, 0.017241434027839984, 0.03196469567982214, 0.025075261614152362, 0.013992546442230898, 0.022316685977524946, 0.029169664052980285, 0.012485247903636523, 0.08385470788925886, 0.04237016250512429, 0.029223451523908546, 0.04959043328251157, 0.0229996212957693, 0.04758673633581825, 0.06011132230716092, 0.015411060369972671, 0.05004263276766453, 0.013345436076633632, 0.04529743721442563, 0.06782851142010518, 0.03331780646528516, 0.046460022152002366, 0.04023885687014886, 0.040984332761062045, 0.050145288330635855, 0.03870526594775064, 0.02406787290237844, 0.014602321266595806, 0.03838181169703603, 0.04456784582829901, 0.003333455737447366, 0.04619655039693628, 0.03344733540767005, 0.04724793701565691, 0.044994583286877186, 0.068665592931211, 0.21006672004503862, 0.09351976748023715, 0.14456381276249886, 0.045381416101008654, 0.13458913085716112, 0.13562092477721827, 0.14985306108636515, 0.2161314660417182, 0.04926757953528847, 0.12040126217263085, 0.10431699667658124, 0.18342522318874085, 0.09364195806639534, 0.08633819355496339, 0.1024920360318252, 0.15798565612307616, 0.11667987757495471, 0.14625731403274195, 0.1251147056796721, 0.1705535767333848, 0.07278939629239695, 0.14171381640647138, 0.11896318862480776, 0.07516868612063782, 0.12981782188372953, 0.10352098010480404, 0.14852860144206456, 0.1517835474972214, 0.07886107013161693, 0.11681239546409675, 0.1582634076476097, 0.0815206967028124, 0.1192544022841113, 0.10685082964066948, 0.26392243802547455, 0.10571491452200071, 0.12928533474249498, 0.04978428395198924, 0.08984153770974704, 0.11045979455645595, 0.23792195320129395, 0.135873068390148, 0.12465792947581836, 0.08728714513459376, 0.10462417626487357, 0.11999209198568549, 0.1277382206171751, 0.13040665457291262, 0.15595017320343427, 0.14011608356876032, 0.1071463180705905, 0.17205372266471386, 0.1414068200226341, 0.1037732187126364, 0.10475990362465382, 0.10463019487048898, 0.1832344327121973, 0.11228312671716724, 0.19061158757124627, 0.08790711579578263, 0.1262878520148141, 0.09094117156096868, 0.12602155416139535, 0.13103619936321462, 0.11705905651407582, 0.11214184215558426, 0.10054458624550275, 0.09518323679055486, 0.1103890844221626, 0.12021718919277191, 0.13882232084870338, 0.16519195586442947, 0.1358897060688053, 0.12443155662289687, 0.09999048097857408, 0.10342831936265741, 0.17398942022451333, 0.06231495977512427, 0.13755351464663232, 0.11863179212169987, 0.11193073634058237, 0.1726060908819948, 0.16514337275709423, 0.17539279349148273, 0.10275785212538072, 0.10720928612032107, 0.09914696695549147, 0.15894613601267338, 0.15507691220513412, 0.12040500768593379, 0.11840901550437723, 0.07248294273657457, 0.15902327187359333, 0.22333305675004209, 0.20878451956169947, 0.14187196934861795, 0.2559707947075367, 0.18237158044108323, 0.14871207731110708, 0.12304444105497428, 0.09763067867606878, 0.14263420844716684, 0.10799656316105809, 0.16580375017864363, 0.17874863770391258, 0.12911447962479933, 0.16613939431096825, 0.1014503762125969, 0.21707977301308087, 0.08413169945457152, 0.17938488642019884, 0.06836172459380967, 0.14563808297472342, 0.12938702000038965, 0.1389095668814012, 0.15139915740915708, 0.08271042643381016, 0.08165322137730462, 0.11426613852381706, 0.12443030811846256, 0.14569159224629402, 0.1002020210559879, 0.08757781596588236, 0.13529285309570177, 0.11460471392742225, 0.1927515920251608, 0.22285576164722443, 0.09004412791026489, 0.08894785959273577, 0.2362390235066414, 0.1135233665949532, 0.09980208573064633, 0.08820818856890712, 0.07931925090295927, 0.13588259502180985, 0.09004199052495615, 0.08231047753776823, 0.14407236341919216, 0.09760617677654539, 0.10003124057714428, 0.1696636373443263, 0.10030153500182287, 0.1520301406936986, 0.12263273314705916, 0.11038066380258117, 0.13131707214883395, 0.0990291800616043, 0.06671110673674516, 0.16187539882957935, 0.19620076194405556, 0.08757635711559228, 0.0925450926380498, 0.13872689168368066, 0.16670107202870504, 0.12223072828991072, 0.0686332064547709, 0.17386870884469577, 0.1204200168805463, 0.18400860045637402, 0.20078311248549394, 0.165033952199987, 0.10288469746176686, 0.11925138958862849, 0.1303093662219388, 0.24141130596399307, 0.11034919334841625, 0.12177093939057418, 0.07733347067343337, 0.10160125525934355, 0.12580753064581326, 0.09204663402800049, 0.0977729471134288, 0.08622739557176828, 0.14220176450908184, 0.20817020109721593], [0.015886150233979737, 0.11019388346799783, 0.03548340526010309, 0.04219870349126203, 0.03067271750686424, 0.01625873550905713, 0.04229153386716332, 0.03390240848862699, 0.03040823812729546, 0.06428318630371775, 0.04269716888666153, 0.056165033884878666, 0.04486732065145459, 0.0057121384888887405, 0.03562940224739058, 0.002356424046281193, 0.06513987069151231, 0.0204215919532414, 0.021679368568584323, 0.06548403043832098, 0.05373477929138711, 0.07406208371477467, 0.04944207499335919, 0.038884009035038095, 0.00930171596285488, 0.03413493904684271, 0.049756579367177825, 0.02277375225509916, 0.021222875653100864, 0.026625016937032342, 0.03903605516201683, 0.024333197058045437, 0.06324504129588604, 0.0356157840495663, 0.023134836361610463, 0.026759309195248143, 0.04346022901258298, 0.09220102788614375, 0.026565996264772754, 0.05363945529929229, 0.03841082246175834, 0.036177658542458496, 0.00499617971945554, 0.017079428703125035, 0.0454315971583128, 0.030454602425119708, 0.015169305128178425, 0.03831447048911026, 0.010028250548722488, 0.048299198105399094, 0.0473322348136987, 0.02348233450071088, 0.04584786142887814, 0.02707545053479927, 0.03244176347340856, 0.00546748420622732, 0.02083963228921805, 0.020221620897895524, 0.05711865039276225, 0.02720983269890504, 0.07125063493315663, 0.01808950610991035, 0.04612647130021027, 0.009712038811163178, 0.09098740693713937, 0.03750478482938238, 0.0292407439888588, 0.026015490626118014, 0.02011634618975222, 0.009374443042491163, 0.02307842974551022, 0.07502881291189364, 0.006991516690634723, 0.06169097897197519, 0.026471710431256464, 0.07417755001889807, 0.021034650038927794, 0.0528269638972623, 0.036446582326399427, 0.017354084411635995, 0.0222506916616112, 0.03846539703330823, 0.03267507773957082, 0.028424032099012817, 0.05599392770922609, 0.015707403754017184, 0.03718221606686711, 0.026255077948527675, 0.05721305496990681, 0.049436158167996576, 0.02786073268258146, 0.06311407046658651, 0.022586476589952196, 0.02294788639327245, 0.0862812033987471, 0.08377394186598913, 0.037784120733184476, 0.03779747090967638, 0.018909381669280783, 0.1354555929345744, 0.07253264542669058, 0.05889082779841764, 0.02384175789276404, 0.03618014876597694, 0.004568848966820431, 0.0023274578104194787, 0.023366798646748066, 0.03170521031799061, 0.02258486337294536, 0.02472289159361805, 0.07835839103375163, 0.03905049777988877, 0.01620772833536778, 0.014952369001028793, 0.02836692489550582, 0.025449860441897596, 0.05302585608192852, 0.03535700097147908, 0.053015237008886676, 0.028500587812491825, 0.03691568751154201, 0.03619201295077801, 0.008631030746203448, 0.017752886583496417, 0.049361814478678365, 0.029955214222094843, 0.028363123403063843, 0.06142960049744163, 0.041038992149489265, 0.013008482371723014, 0.09127216094306537, 0.05756250050451074, 0.013896403967269828, 0.017368213207061802, 0.005857365763014448, 0.03745579120836087, 0.006686893058940768, 0.04060651767732842, 0.026525146760312573, 0.04789175818275128, 0.014800981053018143, 0.014364828921056219, 0.02795483191896762, 0.014314995612949133, 0.04525163610066686, 0.021491853719843284, 0.013334523537196219, 0.03158896030592067, 0.014850118862731116, 0.08735814703894512, 0.026418404720191444, 0.1011977508398039, 0.04568715040971126, 0.03608384768345526, 0.03080975783190557, 0.039911823347210884, 0.036105146897690635, 0.052635918970086744, 0.013576096422704203, 0.011182387725317051, 0.0723517479907189, 0.033599021911088905, 0.04055213648825884, 0.03777635829257114, 0.00620003103644454, 0.007501342882668334, 0.03945506410673261, 0.01735919886933906, 0.03672664086999638, 0.04326426809919732, 0.017370335325332623, 0.03300875072766628, 0.06013804980154548, 0.06164675884480987, 0.04030585202521511, 0.07119417403425489, 0.008517112350091338, 0.07637141658259289, 0.07850197582904782, 0.10401098416852099, 0.01892121023099337, 0.03156155427651746, 0.04058297251218131, 0.07922642731240817, 0.029113583133688996, 0.010532768476488335, 0.02024156813110624, 0.04530629548909409, 0.053448335733264685, 0.04701985086181334, 0.028404578500028168, 0.010458887039151574, 0.02286313906578081, 0.026685817067378333, 0.021204617972086583, 0.03349038166925311, 0.024208058237231204, 0.05880365640457187, 0.03181590312825782, 0.06000814427222524, 0.06041540777576821, 0.006799707987478801, 0.03175177139097026, 0.03665848881272333, 0.014245272747107914, 0.07423355629933731, 0.040494678142879686, 0.018518029811925123, 0.03607359841199858, 0.047840230233435116, 0.02264421313468899, 0.03418660609583769, 0.02972510942657079, 0.045972111368817944, 0.033910764647381644, 0.04707659674542291, 0.03825723945296236, 0.049396945629268885, 0.03985004273376294, 0.03133038078833904, 0.05029613005795649, 0.03958228603005409, 0.02091859171300062, 0.05122144826288734, 0.021187959937378764, 0.10536503472498485, 0.011717428702728024, 0.06065426567303283, 0.04107625050736325, 0.012360444109487747, 0.023033712591443743, 0.03368044611332672, 0.04599503906709807, 0.03407983521797827, 0.06154250193919454, 0.026693608345729963, 0.00672239952421348, 0.038174526034189124, 0.015615606447681785, 0.03241882559710315, 0.03144960617646575, 0.03657178560804043, 0.04261740030986922, 0.008858769999018737, 0.029780050407030752, 0.028606727652783905, 0.01305715792945453, 0.0360818697538759, 0.045428092524941475, 0.056398918120456595, 0.026520948324884688, 0.021328844163300734, 0.05405255759667073, 0.05217750071148787, 0.014295067039451428, 0.010997128157344247, 0.016875125201685087, 0.039331197539078336, 0.028736131066190343, 0.023656544974073768, 0.06260605129812445, 0.026609069667756557, 0.07524443777011973, 0.03706362510898283, 0.03807833690994552, 0.03589642274060419, 0.009626530676281877, 0.05609537208718913, 0.022620442356648188, 0.039308466615953615, 0.03271768634606685, 0.05399291776120663, 0.03395565313154033, 0.02443025470711291, 0.09359786007553339, 0.061753458476492336, 0.059650237405938764, 0.06788229210568325, 0.023960326798260212, 0.00958356838340738, 0.019832414907536337, 0.04241667268797755, 0.022695162632901753, 0.001249301288875618, 0.01321036265497761, 0.009886644531174429, 0.043652692077947516, 0.007844472952586199, 0.04629139941451805, 0.043665014273886166, 0.041873820924333165, 0.005596703142925564, 0.03995717323518225, 0.04134133717577372, 0.0141600351780653, 0.030481445270457437, 0.1004133779289467, 0.004969813120884022, 0.02428345026315323, 0.011052790929430296, 0.024984388811779872, 0.03426977413307343, 0.039301118081701655, 0.03728482073971203, 0.07425238564610481, 0.04844391266150134, 0.011008254435312535, 0.06985453556158713, 0.024367245945281217, 0.01686830592474767, 0.043925405479967594, 0.02236144893270518, 0.04880740047831621, 0.06962424077625785, 0.013072050924945091, 0.04514509931738887, 0.06248652056923934, 0.073014079593122, 0.032635485221232684, 0.013597589867588664, 0.07241139800420829, 0.009931989330133157, 0.016384084675727145, 0.012813072768040001, 0.0609912940167955, 0.08850726644907679, 0.012097944355835872, 0.0417939302112375, 0.010670433901915593, 0.032771626487374306, 0.01178466049688203, 0.014173576192531203, 0.01390194335752832, 0.03664154918598277, 0.11934991287333624, 0.012316676056278604, 0.06993421592882701, 0.049420850417975865, 0.03159525032554354, 0.04047673089163644, 0.01957248680160514, 0.009685239222432886, 0.027694220189005136, 0.06622405430035931, 0.023021587170660496, 0.040788368455001285, 0.01413019999329533, 0.0224913900851139, 0.05785049790782588, 0.02497593087277242, 0.0326768962134208, 0.030496953188308647, 0.1292201139565025, 0.21882237307727337, 0.2180911973118782, 0.2849594120468412, 0.16812796331942081, 0.10964948803718601, 0.16274582355150155, 0.1501221137919596, 0.09900997073522635, 0.10115612950176, 0.1735796664974519, 0.10362065689904348, 0.17599894239434175, 0.109939663537911, 0.0790097371542028, 0.11815867679459707, 0.0961538947054318, 0.08738214003720454, 0.09733569236206156, 0.10586244160575525, 0.15918321614818914, 0.1854036006012133, 0.11069143962647233, 0.2388305387326649, 0.1222110100622688, 0.08839678737734045, 0.08676478852118764, 0.13943115675023623, 0.12032198214105197, 0.12138705141842365, 0.16978584150118486, 0.14741545117327146, 0.11176834255456924, 0.1761221100709268, 0.12371194309421948, 0.08364440274557897, 0.11367752975119011, 0.19322655296751431, 0.14287777537746088, 0.1785452129053218, 0.17748147355658667, 0.117836915488754, 0.09807036258280277, 0.127718787374241, 0.1520015743694135, 0.08133773652038404, 0.11017194643084492, 0.11558674408921174, 0.09954408636050564, 0.14282615243324212, 0.12439551284270627, 0.08090719926570143, 0.10884351735668522, 0.12157436779567174, 0.13412447007639067, 0.07531340406941515, 0.10709414551300661, 0.09539268019476108, 0.10657362094415085, 0.10115364606359176, 0.12065351435116359, 0.13954140512006624, 0.13831975710179123, 0.16401505044528417, 0.1816895306110382, 0.11623876195933137, 0.0657059181747692, 0.0786631889641285, 0.11693138336496693, 0.08454385519559894, 0.11321781549070563, 0.14633094865296567, 0.19035040587186813, 0.20188145712018013, 0.18208086889769348, 0.17460721278829233, 0.24013880853142056, 0.14392016801450933, 0.07649723054575068, 0.1423605824155467, 0.08369918766298465, 0.0911753543519548, 0.10307238703327519, 0.08451480032610041, 0.15138957649469376, 0.16164848314864294, 0.19005505314895085, 0.10645028363381114, 0.24344699244414056, 0.07590900175273418, 0.07667526456394366, 0.11181358726961271, 0.12387487292289734, 0.11626962173197951, 0.18392168012048515, 0.18230374050991877, 0.08103219898683683, 0.1958607073341097, 0.17357296257146768, 0.3052407423300402, 0.2387440933712891, 0.146089105201619, 0.1527714537722724, 0.09487267131251947, 0.11482876619057995, 0.0855501429843051, 0.2097747057144131, 0.14925438963941165, 0.10143997427076101, 0.08996855946523802, 0.06978794413485698, 0.1283765456506184, 0.1138228787375348, 0.08453259151428938, 0.14120594651571342, 0.16349466836878232, 0.11174088224236454, 0.1512086247759206, 0.09334838310522692, 0.0635685192953263, 0.1307984406926802, 0.1879989699061428, 0.07274900310273681, 0.08935424778610468, 0.13422042849872792, 0.11143030997897897, 0.14653940818139485, 0.1493344432009118, 0.16363174601324967, 0.10329597789262022, 0.08098223845341376, 0.21536544071776526, 0.11783502916140215, 0.1798710296196597, 0.12952526472508907, 0.11507341877690383, 0.1125141746763672, 0.15356681895043167, 0.06468671107930796, 0.17892527393996716, 0.13077604903706483, 0.11975202629608767, 0.10665476016168084, 0.08244574349373579, 0.09927541363452162, 0.12652343937328883, 0.06338629193071808, 0.0979180314711162, 0.20508706010878086, 0.26762949196355684, 0.1367070014987673, 0.288125320736851, 0.15178224470998558, 0.14978181490940706, 0.054702472008232556, 0.07488571666181087, 0.11385196074843407, 0.10668477855090584, 0.15076664063547338, 0.07480323394494397, 0.18958318632628235, 0.2308349534869194, 0.1020422623093639, 0.10873405608747687, 0.0771647190142955, 0.07289289323879139, 0.11814469897321292, 0.13463342562317848, 0.11707703769207001, 0.1386735045484134, 0.12441615387797356, 0.06655916239001922, 0.13698981489453996, 0.18223792261310987, 0.17402825956898077, 0.17240103759935924], [0.0186031096215759, 0.06487185614449636, 0.08416315633803606, 0.021983688131773045, 0.07785022937293563, 0.013219622961644615, 0.04991311061062983, 0.012950078318161624, 0.035102044830897024, 0.022853157815656493, 0.029037417577845708, 0.04778676167396562, 0.021272174614880766, 0.021642332430928946, 0.0424372322990426, 0.021633131496076072, 0.0162531528621912, 0.03641841633777533, 0.022339673047619205, 0.06349670314895255, 0.023233044127534543, 0.042427756557507176, 0.043181049171835184, 0.0684303380548954, 0.04709008602159364, 0.040868941095790694, 0.015133982291445136, 0.021283741940611174, 0.03378339683903115, 0.031919851300439665, 0.01953410037926265, 0.03909863305411168, 0.02108691250240164, 0.011931224909078861, 0.019593417910592895, 0.052702948051903925, 0.07491396407463721, 0.018919827715892876, 0.016928268064345633, 0.021673765565667833, 0.02851665552173342, 0.028386264839874845, 0.053865305680249415, 0.020723977691626976, 0.021838349323453646, 0.022090783010103872, 0.09809953958860465, 0.05571471733440246, 0.028408441060621823, 0.022053231185834323, 0.04805128176563552, 0.10254944009440285, 0.0644479278208954, 0.021701482024842074, 0.024125273572281003, 0.0433303981221148, 0.02834432798304728, 0.054659839653010876, 0.03056959036205496, 0.05238285254953163, 0.04586711146735719, 0.023393867104979496, 0.05218044216079371, 0.030957614005144154, 0.012436700419389775, 0.012813848842467581, 0.04794589849188924, 0.09647984935769013, 0.07651450604732547, 0.04495149292051792, 0.05115576607308217, 0.04084004568202155, 0.008081246899174792, 0.010796694850016917, 0.04178513639739581, 0.051240335285131416, 0.05517247285959976, 0.049061837539608986, 0.018210595773000802, 0.051998011235679896, 0.016930585261434317, 0.030278549729181186, 0.08489532954990864, 0.035898356565407345, 0.04440640199131199, 0.11283222439565829, 0.026690587168559432, 0.030952586060655967, 0.020706084723185216, 0.0696744184408869, 0.0435561094033931, 0.06274329857634646, 0.05209981184452772, 0.02525757549197546, 0.030202943964728286, 0.034483987638460736, 0.0076819706009700894, 0.03380085215238588, 0.05242230596819094, 0.015721676738134453, 0.029401030923639025, 0.039286129243139706, 0.02943476089941604, 0.025765789739255394, 0.018456871754356792, 0.11619397864810058, 0.0502679606766573, 0.04885213629209569, 0.07148424775472709, 0.06758360099047422, 0.03311304156003254, 0.02155403297261468, 0.01551796865117337, 0.031849266695124764, 0.04972820303269795, 0.03853334553007569, 0.02916558605751821, 0.018729658098891377, 0.06126344084207501, 0.0011109017733750598, 0.03167778393253684, 0.01762208708428911, 0.021930937123085772, 0.013144562569712954, 0.05816052734319653, 0.008872880134731531, 0.05280191916972399, 0.03158624277317098, 0.04882953429062452, 0.023760086025244424, 0.05918983782508543, 0.059509801013129096, 0.030487630117152418, 0.0510601163841784, 0.03960533247196248, 0.024195140626813685, 0.028433743631467223, 0.03734023669468505, 0.08759069456053631, 0.0443396782502532, 0.04429917649499007, 0.03615950773070965, 0.02059478123140122, 0.0315532998980156, 0.056094768191022534, 0.019149026667167033, 0.05971112235316208, 0.02189264739198344, 0.009514058407928263, 0.045043688866176775, 0.005603955410021756, 0.040443116266812594, 0.05296600929328373, 0.04540415041680847, 0.02023818563403828, 0.07144155433135373, 0.010902036563493311, 0.031091980902212005, 0.043232326063194444, 0.01862890413030982, 0.06380418129265308, 0.030005622588630234, 0.011821683912005807, 0.04586621240845748, 0.06249797424035413, 0.021974907888631736, 0.030885770717369657, 0.05998644472232886, 0.03495046350040606, 0.05159408612442868, 0.09387627656438521, 0.03562067289437566, 0.022321513754182627, 0.026092726570953215, 0.03860070030870182, 0.023145889697064246, 0.038795823231339455, 0.03293966229206749, 0.014042578221830939, 0.028609696243490492, 0.030233569642794982, 0.020229907506810765, 0.04151873676372426, 0.030427905464810983, 0.028592437705291168, 0.024183905783242414, 0.04871165579450982, 0.055325475720954795, 0.005105859392123031, 0.035205015912652016, 0.017310687008180788, 0.06189859711698123, 0.060556115582585335, 0.05128580052405596, 0.029766191329274858, 0.06481559880610023, 0.040599891782871315, 0.02618246791618211, 0.03872247698849865, 0.021074625929551463, 0.035873213450291326, 0.042481235295001946, 0.06065896113536187, 0.026392303174361587, 0.02769718538703663, 0.03899929213470646, 0.03188581259122916, 0.01439120018455599, 0.055737821451787434, 0.016050750955141017, 0.04721192376954215, 0.10370190468217645, 0.0811668135491865, 0.04564861301332712, 0.014112116186879575, 0.038234464425061426, 0.01308333665864276, 0.0181226661162717, 0.04028733819723129, 0.01327522551374776, 0.00873741231459592, 0.013109830906614661, 0.035559038165956736, 0.029359155134963136, 0.02937552479228803, 0.020121450469430004, 0.04825896776414343, 0.052281394600868225, 0.074608134771032, 0.03885048601244177, 0.03220142976247838, 0.06021844941590514, 0.02950495873977031, 0.04807655380240508, 0.011539845910322453, 0.03595599132989134, 0.011657653160260191, 0.030875202534454207, 0.008283133119610804, 0.0037654079496860504, 0.011515683278308382, 0.008809857802199466, 0.06348628085106611, 0.02461373566516808, 0.010853831739430981, 0.03899115989250796, 0.02823655117702271, 0.038443633022585084, 0.051373236546558995, 0.013396413564415914, 0.0367800449686391, 0.06600260761167322, 0.046369532721915414, 0.04238251523513879, 0.054507203200565915, 0.0621371768148882, 0.012678318257842745, 0.048603690695017576, 0.011072939178640289, 0.02678992469528956, 0.026149786277008907, 0.013957793574913271, 0.02982745964878372, 0.026378734170326164, 0.0834907213492053, 0.11958384460636548, 0.07596324384212494, 0.024137175076508095, 0.009902948879503777, 0.07170885641660009, 0.055319470686039755, 0.031242795488131896, 0.026057419001257846, 0.026533178918595825, 0.05282278751422252, 0.038563458914203305, 0.03414948344496744, 0.08496485224791936, 0.022136195662564466, 0.021237233454095464, 0.005170530564750412, 0.034254425670951605, 0.03488676941820553, 0.03818396106362343, 0.022663581916796308, 0.030389530916831324, 0.022590050773162926, 0.06254334787705115, 0.033244232913213115, 0.03824093425646424, 0.01865315666821386, 0.025970035565218756, 0.034456371263201745, 0.016732620973406092, 0.061775958697710714, 0.017929656830217158, 0.03052830829152039, 0.02625551729995225, 0.029277802178902284, 0.020955122342067103, 0.037254205239670615, 0.022437880813543285, 0.04060452278437359, 0.06268028302916459, 0.041975628318531175, 0.054357989957290034, 0.08753217091517788, 0.030589257699570487, 0.015434669995946544, 0.07835898814456803, 0.06825163907238416, 0.03505550411396793, 0.054607738341603956, 0.02680015530703323, 0.10102884990296193, 0.06218633667698928, 0.014559030732406037, 0.013009085419720836, 0.018326969617711644, 0.02216923692529755, 0.0366296375037304, 0.026140795688011816, 0.05926784899617944, 0.027692484835694944, 0.020497034869289825, 0.009417640278115869, 0.03142648170303021, 0.03913189823340092, 0.059633979706891944, 0.013770078558341732, 0.02203054097481072, 0.07934212431843791, 0.05433237186766096, 0.029385533183813095, 0.054621393858854256, 0.020974781197894896, 0.04754743558753814, 0.017602463851549795, 0.0338217272822346, 0.0334489197869386, 0.035448230004736354, 0.023185299010947347, 0.029704163050545112, 0.04863011963399393, 0.027681249992123673, 0.027870401806597198, 0.04765690364209669, 0.031200807741177932, 0.05511972354725003, 0.0034488881148198353, 0.06822163425385952, 0.04217522957229188, 0.14264985546469688, 0.12141997393752847, 0.2684726395777294, 0.1095072670972773, 0.1460692784083741, 0.1575627252459526, 0.10725583362260036, 0.08928197702126843, 0.10759746921913964, 0.15445435632552418, 0.18359793749238762, 0.15574213436671666, 0.10994530894926616, 0.1518820979233299, 0.1565757824906281, 0.10253048182598182, 0.21295566431113652, 0.11855506338179111, 0.062180250217872005, 0.1424320592944111, 0.09505427442491055, 0.14413432723709516, 0.16746404394507408, 0.14834067438329968, 0.1303786989301443, 0.11548442100839955, 0.09276681074074336, 0.13537217383938177, 0.12452307742621217, 0.12767138491783822, 0.08893578845475401, 0.05943226481654814, 0.11038567139101879, 0.08085737443928208, 0.10726537382496254, 0.19435792868690832, 0.21758982778659888, 0.0984340166406972, 0.06828803569078445, 0.1307972464710474, 0.06718692941857235, 0.13225350475737027, 0.14617052940385683, 0.1320795826613903, 0.11093677753316504, 0.10660338827541896, 0.16731064074805804, 0.10377441293426923, 0.07832660845347814, 0.10973128543368407, 0.12312235044581549, 0.19606525850083145, 0.12955575808882713, 0.06802608046148505, 0.09679865903620209, 0.12027228623628616, 0.12932572114680493, 0.09081737284681626, 0.152463398873806, 0.16286344081163406, 0.10700331003006015, 0.11418271942862443, 0.07028996505375419, 0.15806653749729904, 0.14894666043775423, 0.125876035541296, 0.12465016703520503, 0.24362498575023242, 0.15072112450642244, 0.1437656655907631, 0.1153115981391498, 0.12731493690184184, 0.08752737367259604, 0.1072907035372087, 0.21755765165601457, 0.16332165550972733, 0.14807709066995553, 0.1435169010822262, 0.11497842387429305, 0.09022117126733065, 0.1024536309497697, 0.14246947371533938, 0.1408917848020792, 0.13373800367116928, 0.18185469960527761, 0.1280851284308093, 0.11311803013086319, 0.07268638110586575, 0.13622946212334291, 0.17538429823304924, 0.12907820514270238, 0.12269072074975286, 0.12051729166081973, 0.2433515904205186, 0.10371926839330367, 0.0869381135063512, 0.09859834425151348, 0.08459334753985916, 0.0796062033623457, 0.11414776130446366, 0.12743604183197021, 0.2604821297739233, 0.08880452585539647, 0.13224415454481328, 0.11940762906202249, 0.11605536751449108, 0.2088032199868134, 0.18300643137523107, 0.13239297084510326, 0.14647418739540236, 0.08909148510013308, 0.09758185808147703, 0.06754592194088868, 0.08454295274402414, 0.18926275494907582, 0.2645755686930248, 0.11111664359590837, 0.11055512872657605, 0.11867315561643668, 0.1471382017646517, 0.13504008523055486, 0.09734181953327996, 0.093966942413577, 0.11286514012941293, 0.1293997357466391, 0.10925988680017845, 0.09721377997526101, 0.13400550931692123, 0.10169929678418807, 0.1453682024564062, 0.17197213561407157, 0.11607086525431701, 0.09913305020225899, 0.11200655584356614, 0.14921789802610874, 0.0771228534036449, 0.11286622578544275, 0.17828352909002984, 0.23936565858977182, 0.14853814164442675, 0.17344013255621704, 0.11571713137839522, 0.08480550508413996, 0.14432770971740994, 0.15246282890439034, 0.11662646329828671, 0.15481125217463287, 0.10824464913457632, 0.10914456298840897, 0.19539439092789376, 0.12561245182795183, 0.15707884835345404, 0.1125380794650742, 0.12148503187511649, 0.12070296598332268, 0.24191996295537266, 0.09651813230344228, 0.13676912816507475, 0.13457755504974298, 0.10573910429541554, 0.17080334547374929, 0.06962176412343979, 0.1458809170871973, 0.1575838548264333, 0.13903372521911347, 0.09256694825100047, 0.1250877949808325, 0.11224450450390577, 0.10166015888431243, 0.11265054664441518, 0.1845156153930085, 0.05611913777621729, 0.14610211950327667, 0.1129332786159856, 0.15800135742340768, 0.15877074828105314], [0.03359095752239227, 0.009189326815041048, 0.056668513654065986, 0.02595977102672415, 0.021372870907985737, 0.08307735103049449, 0.00327616384518998, 0.08216438216290303, 0.023931548431781784, 0.014556628718440021, 0.02943565317296556, 0.021436179921563183, 0.03113471843036158, 0.03684265339480979, 0.05211484478786588, 0.0164476379619113, 0.049897107362215004, 0.028074374522215555, 0.07182821751173053, 0.03935337206348777, 0.010020416013763418, 0.02744299259835056, 0.07946223180208888, 0.04103752312117389, 0.023575432897944535, 0.03237948413672192, 0.013646773478415395, 0.017353336326777935, 0.00966226402670145, 0.02831214845978788, 0.03345160000026226, 0.03395973791235259, 0.011386032199620135, 0.06068876239338091, 0.06050434336066246, 0.064155044965446, 0.045941729963357957, 0.0369258350027459, 0.08285912738314696, 0.06268069693552596, 0.05267837829887867, 0.014576277396242534, 0.027090108587539623, 0.022065154742449522, 0.027889812997143184, 0.04359876550734043, 0.03054874237360699, 0.10660876905811684, 0.010322236871745969, 0.02535446689996336, 0.03866508988929646, 0.0310221019733165, 0.06425823657108204, 0.008046337968802877, 0.054710105527192354, 0.011163401467326497, 0.055905019265732596, 0.039684917844299755, 0.03233507062707629, 0.05378372880763241, 0.02250085904129914, 0.05808807337390525, 0.03239649500963943, 0.012343535864991801, 0.01669674682697015, 0.06604363862425089, 0.04742113986451711, 0.06288275109337908, 0.022921801810818057, 0.04954263388312288, 0.004919674047934157, 0.02041311196184584, 0.03197798478816237, 0.03090877305450184, 0.0176270353009126, 0.03214381196136985, 0.020979566566113914, 0.04948944691568613, 0.06447135084973914, 0.05371397201504026, 0.04627031733148864, 0.07171587246869292, 0.0658561254718474, 0.01496150717139244, 0.014423479791730642, 0.02657554155614759, 0.03397977165877819, 0.014574594629396285, 0.03696011119921293, 0.06048402123685394, 0.015915213585165993, 0.05820119873221431, 0.0563800887736891, 0.018447238253429532, 0.045203863842678924, 0.032566922650273354, 0.03971605242363044, 0.07384873873421124, 0.03526372615514057, 0.02900287675272141, 0.024656235706061125, 0.05559166840144566, 0.0167124600016645, 0.026055933009567003, 0.029434268961527517, 0.03909201733767986, 0.021603029986311282, 0.04795533352132354, 0.025954576841156398, 0.025588615764198557, 0.012419045786373317, 0.04452804974945528, 0.022983511178089038, 0.060500699627612314, 0.04046473778518183, 0.020470188631277, 0.0301429953958307, 0.03664930823392101, 0.01906753291508981, 0.060644006223550866, 0.07015579153916665, 0.04286560841969081, 0.03343939654795187, 0.009129192497182106, 0.03698039261092033, 0.017236613036532487, 0.043978293891996145, 0.02372017459544752, 0.038477247647408924, 0.04526317798133407, 0.06033455354294606, 0.03602245383496795, 0.04832563043705054, 0.05838630987065179, 0.06248099050883736, 0.05140258657879063, 0.014089467536125864, 0.019036064157262444, 0.06607614045164414, 0.019198449461587837, 0.07377924996295146, 0.0721681567707232, 0.02282097829239709, 0.0991782813466021, 0.06800417735108308, 0.0392648469922798, 0.022125121971060122, 0.015139680289264237, 0.05498865093769772, 0.01945749038298215, 0.014790923467704227, 0.01946803990618459, 0.023911382371027554, 0.02317873588097947, 0.05753436844263758, 0.028122182403291975, 0.02639312929074679, 0.06921861932746001, 0.05499504952292357, 0.028824472932943275, 0.09163596427866391, 0.02886549037482057, 0.061915689414100986, 0.07951004137950284, 0.02839393398192312, 0.06545307567077023, 0.013737503788433969, 0.10651132464408875, 0.0212688430079392, 0.02936998794653586, 0.037413182601864846, 0.025406498661530868, 0.02755251832838569, 0.03063554396586759, 0.030455884856304953, 0.029929216152855327, 0.04447744121508939, 0.020380408270284534, 0.05203758000529238, 0.02948218710454447, 0.016053497325628996, 0.02771247278100678, 0.08987645512180668, 0.06190025952777692, 0.030793639232537577, 0.020961604047832743, 0.022009282472676465, 0.06652796334986176, 0.03338727488049439, 0.058364929232214174, 0.04354012990370393, 0.0034885569683475687, 0.019228305002408366, 0.05429789889603853, 0.030745961969452243, 0.030464403863464082, 0.0058136172176870915, 0.04813242776851569, 0.014161594112270644, 0.1504866499453783, 0.03920333440016423, 0.03795686896358218, 0.01478441122786275, 0.024387624048228775, 0.019758676810722266, 0.05485409065814955, 0.01631438555861158, 0.012623018501991672, 0.02558101447565215, 0.0664462609482663, 0.05802522746047803, 0.03815888240933418, 0.00585418428194576, 0.04663464313905154, 0.03323037722813232, 0.04293473078204053, 0.03700491825916937, 0.049473911856434176, 0.03931925532275012, 0.003954129318507122, 0.0612472781379308, 0.03840731782838702, 0.07704442832618952, 0.06848729428436075, 0.008596360151256834, 0.036195843280958276, 0.056116281143788777, 0.01261504486735378, 0.0058534361970877, 0.0338635453954339, 0.05282524720366512, 0.005047390453650483, 0.03960701184613364, 0.045285352505743504, 0.03247111011296511, 0.0767202717917306, 0.030039247391479354, 0.017232333176902363, 0.0366248165124229, 0.04133118289921965, 0.028439585817977786, 0.047394670213439634, 0.04848834313452244, 0.06694579842899527, 0.02770658309704491, 0.04476678551041654, 0.029363680963537524, 0.0234192171732762, 0.02686139987781644, 0.09147577573146139, 0.03154735932392733, 0.053123816182570796, 0.029605266571577107, 0.05937528144568205, 0.016774640950773443, 0.05347666457029326, 0.04268565075471997, 0.015942217582570653, 0.12288859513189111, 0.04411126979227577, 0.04331628120105181, 0.029826709867588112, 0.025794932818306342, 0.01884103114051478, 0.05042227650327342, 0.03327622583934239, 0.02502524170891515, 0.006979714846238494, 0.023880120566380874, 0.04642046356041517, 0.008555862636837577, 0.02539423244473125, 0.013595064020981746, 0.04145213855164392, 0.03415304575381534, 0.032324753502117734, 0.025836472732148, 0.011327410166684006, 0.046721200458705425, 0.02034964009986392, 0.011721213231794536, 0.04630983181829963, 0.062113801283495765, 0.02325669446560953, 0.0671387127201472, 0.024193836143240333, 0.031232871913484166, 0.04255428298243454, 0.04189722020445125, 0.016544237599841187, 0.008117917476088872, 0.04862593307292887, 0.02384072482319815, 0.025296233328325406, 0.009767062063994152, 0.04921486075701458, 0.048145496352974854, 0.051052119848983626, 0.018258849790851985, 0.01987785130872258, 0.05321213090792298, 0.014695046469569206, 0.014721585670486093, 0.03951856141377773, 0.07090457528829575, 0.01499864848197571, 0.015044235857203603, 0.03148396718981011, 0.034744470446769676, 0.02280613194618906, 0.013948624870473785, 0.01501867374671357, 0.031476632226258516, 0.025470226670482328, 0.009278047813235648, 0.04858131261010255, 0.037251979644809446, 0.03761205103780542, 0.025609864088307534, 0.05773539801261254, 0.04237951271768127, 0.0973178536764213, 0.06165500304528645, 0.013308941070655627, 0.057825758521045954, 0.060910439783973355, 0.03507173127893891, 0.03968880245728152, 0.025570590481428162, 0.06433219010276453, 0.017596306146255562, 0.09936740941234998, 0.01981530395070357, 0.00569404916937596, 0.03176643792539835, 0.07353500449763876, 0.0637003518640995, 0.05407767017771091, 0.023329470739034668, 0.027477920188435485, 0.06753395258315972, 0.015889754951266304, 0.061431853233703544, 0.03975289348246796, 0.04450990233038153, 0.09671287185379437, 0.010981935758276709, 0.014476315617295248, 0.07731261250696012, 0.10409521072038583, 0.023321134936330572, 0.017975724268970743, 0.12687399770532334, 0.1182557073022638, 0.13250316493213177, 0.11677517103297369, 0.11801790791962828, 0.15489674758698257, 0.13588545843958855, 0.1301531403192452, 0.14444483843232903, 0.14844793719904764, 0.12737618147262506, 0.11360960161047322, 0.09042769697095666, 0.12295735787068095, 0.15656407097620623, 0.12818574160337448, 0.10644946939178876, 0.12145877256989479, 0.12320955576641218, 0.09313112976295607, 0.190136599487492, 0.15324422983186586, 0.1688504402658769, 0.24684509581753186, 0.13972018552677973, 0.13232123612293176, 0.1040991869355951, 0.11459072253533772, 0.19824218883046082, 0.11671913761113371, 0.11003552696534566, 0.12126445371125426, 0.12014005333185196, 0.21112714814288275, 0.10950961482844182, 0.092029806359538, 0.10272190334009272, 0.1398723130779607, 0.10660359862127475, 0.11208538804203272, 0.11124292574822903, 0.10952023390148367, 0.1318643649241754, 0.11134307751698153, 0.09163719921239785, 0.19204601060066903, 0.221943376319749, 0.18476579125438417, 0.055506824382713864, 0.1212676428258419, 0.10318542418203183, 0.17122954688966274, 0.14628757669457368, 0.11457835962729794, 0.2095701274062906, 0.06310480167823178, 0.1628971097192594, 0.11466940545610019, 0.12331763282418251, 0.10786785185337067, 0.12367526149111134, 0.14256678920771393, 0.12648812841091836, 0.16045629712087767, 0.1434999241360596, 0.23743308229105814, 0.10369890555739403, 0.16484899712460382, 0.15834530682436057, 0.1723090282508305, 0.08728789152311427, 0.13422281694199356, 0.08497141368154969, 0.18488462987755025, 0.0844646498028721, 0.1044598418687071, 0.08092874275254351, 0.10901808406093291, 0.1878097943429436, 0.20463503365005764, 0.17761890403926373, 0.20359682078872407, 0.1116486286212291, 0.09191227730895792, 0.09779221750795841, 0.13137951094124997, 0.12523581060980046, 0.14433992334774562, 0.10571936571172305, 0.12560436369052955, 0.14623262892876351, 0.1353206051779645, 0.11128027231565543, 0.10024791716464929, 0.1925178909940379, 0.07468909756945712, 0.10864040468420301, 0.12715921311506204, 0.15078794663505896, 0.14477817554559025, 0.18206421764833586, 0.1353861109486648, 0.15225350085113729, 0.1283970916909831, 0.15881808288395405, 0.12180487971220698, 0.16704179160296917, 0.1279562474893672, 0.16298082736986025, 0.1599316538444587, 0.1247688020978655, 0.16007957447852406, 0.089077364786395, 0.10906408873519727, 0.1293125439967428, 0.19164870120584965, 0.10859572315322501, 0.10186114095683609, 0.1100533249388848, 0.15630100294947624, 0.17159538583031722, 0.22491478973201343, 0.1581043183271374, 0.11005010189754622, 0.12282132517014231, 0.054447207134217024, 0.0958253616201026, 0.12563971536500113, 0.17086490217064107, 0.09717387533081429, 0.15237650567931788, 0.10793846020741121, 0.098026671712952, 0.15611937269568443, 0.13553884918136255, 0.12698303828282015, 0.07059806744967188, 0.11694808889712606, 0.11636271673653807, 0.1579212767205068, 0.1257619330925601, 0.1655054526137454, 0.10803115487630878, 0.13854185518409523, 0.11865442804992199, 0.21984788376305783, 0.17568475353930676, 0.07089960841195923, 0.18707475092794212, 0.1862084245575326, 0.10418199534927096, 0.11441940601382937, 0.08294203757707562, 0.31785351410508156, 0.22964385311518395, 0.1824052900608097, 0.06437217617141348, 0.09902523098779575, 0.08845353326095001, 0.13291006881211484, 0.13295953401497432, 0.1361162146287305, 0.1272306085697242, 0.16903449967503548, 0.1271733809262514, 0.14893418896411145, 0.1506232526153326, 0.25448404305747574, 0.18568668541099342, 0.12789536932749407, 0.08512145813022341, 0.125325811494674, 0.12486325417246137, 0.19863476205085004, 0.15786604396998882, 0.08445223261203084], [0.011874022710669254, 0.03727561301950898, 0.05706256947347096, 0.04313462719853435, 0.04798975221014448, 0.026855516979204755, 0.041750782169401646, 0.024952092241229754, 0.03357063879125884, 0.09681113729519503, 0.05032113068071859, 0.05439700572086232, 0.018859014014846513, 0.02450682908030493, 0.0509243177782212, 0.010124767066112586, 0.011537817090616694, 0.021092729243849005, 0.039882700624210496, 0.03039470813902361, 0.02205155011532562, 0.014837021440533655, 0.03809975826048425, 0.043242280171918016, 0.11407502235046454, 0.05113342870026827, 0.022771599602752497, 0.02219359463612948, 0.02371751643451197, 0.01444403940279569, 0.03732939709776214, 0.049983990378677845, 0.024796137752543603, 0.03590389680383461, 0.009487144316413572, 0.017001276736014655, 0.028994015085377862, 0.06099928715931518, 0.030242214178932563, 0.028022403828799725, 0.03937640832737088, 0.06057530455291271, 0.02053669693746737, 0.01934061272601996, 0.01258710618796093, 0.013455361294160997, 0.0067083381582051516, 0.038577633510742865, 0.012355540845809239, 0.024685931791152273, 0.06238111015409231, 0.025813070059354817, 0.027924523456022143, 0.03115829752225961, 0.038586261083504984, 0.012889502104371786, 0.023262385678078448, 0.03902301371895841, 0.06339436649744, 0.01721797537590776, 0.05853015250925507, 0.025754644801574092, 0.06613795499184302, 0.02111324983915048, 0.025340970838442445, 0.01740559539757669, 0.027201797147946696, 0.07197523569422108, 0.034075109221573384, 0.018698474325771843, 0.03634385551725115, 0.01553953079772847, 0.026246307883411646, 0.029445966905249015, 0.005517377310232925, 0.023457420391163657, 0.00781259368107255, 0.023058156815490553, 0.02593363555414336, 0.046976984412010224, 0.052830227650702, 0.041459873850856505, 0.08519658552748816, 0.039643201511353254, 0.017691748881978647, 0.061038587907595296, 0.019718626281246543, 0.011195393545286996, 0.029774768011910573, 0.0032093756433044162, 0.040970490646681616, 0.04675172435651932, 0.030408506148627827, 0.049622351569788795, 0.037942996315125904, 0.010252374058057154, 0.013103858102113008, 0.044534879204417975, 0.025746678800455162, 0.04671062209776469, 0.04544725435386811, 0.059871195549411435, 0.01564371306449175, 0.05310309372310128, 0.0864864398858377, 0.02757850113058729, 0.022722877395738448, 0.048566218598612716, 0.0372922676615417, 0.11828031098203999, 0.04192208851288472, 0.02501097211747297, 0.009941708496106523, 0.02572172737148191, 0.08428840711712837, 0.020532909015725766, 0.023586854338645935, 0.004835635365452617, 0.06379127555659839, 0.020284885806696754, 0.09134133080286638, 0.02943660651466676, 0.02777753071859479, 0.0482310222994004, 0.06390493695757218, 0.05173639188121472, 0.05480973143130541, 0.050013700034469366, 0.023417863495913998, 0.04250874310465796, 0.04129692705880318, 0.020535696098314862, 0.023842122605336562, 0.022554302155705433, 0.024390931906444684, 0.08831333435539689, 0.035494903035994084, 0.036586564100746594, 0.018190287219892656, 0.006806326248416943, 0.026274719840980003, 0.004940373606846801, 0.06230191833206585, 0.03339614672586322, 0.0678836763171213, 0.07706715246396405, 0.03948356597019093, 0.02375861021157886, 0.0366708042233118, 0.07671661448798009, 0.029800640552171638, 0.019689225358888507, 0.012262992061940687, 0.031094420235604048, 0.0259645903216941, 0.05889457331172057, 0.030886571388691664, 0.030071216568882977, 0.060023228105689795, 0.03367945884487458, 0.07464436175567762, 0.044398167968860695, 0.013492377075765814, 0.030623381225658313, 0.01296632075017052, 0.02724896720610559, 0.01185122732671776, 0.060492923616298606, 0.035789865601275644, 0.04891439527273178, 0.050869739813996215, 0.037371123608733924, 0.043714119853185754, 0.056635753983365636, 0.03476699102403862, 0.012450484010124845, 0.027414706169760654, 0.035028430566723855, 0.016467413865029812, 0.0551248091672148, 0.06640030377145324, 0.08630641097468988, 0.07953041778611285, 0.015684035007974932, 0.0338380935468844, 0.054780876729637384, 0.054358305476073704, 0.04704020691237279, 0.01727647357620299, 0.01771819987334311, 0.03537069720083049, 0.023090030997991562, 0.022591774252110293, 0.03796622256881424, 0.02010449387931398, 0.022704475526032702, 0.057614347365285666, 0.03187226903225694, 0.047493129037320614, 0.0353315830496805, 0.01958926866895386, 0.022310529968568256, 0.035749031363853385, 0.07331907429865428, 0.010695283550636044, 0.026954496578712548, 0.002873725361756182, 0.05206972560180085, 0.03504670012210097, 0.048965041126523695, 0.016190284896375876, 0.01546193183665829, 0.05570097700027483, 0.01592180724920971, 0.05611432017758489, 0.031561170904231925, 0.03166373486497572, 0.06527761330029794, 0.023479069050933634, 0.027915213955566287, 0.007449870064322437, 0.014788121118077209, 0.03776107429127608, 0.03273712976702622, 0.058488571883312294, 0.014573354606649705, 0.0673424428594964, 0.012460363479996366, 0.05076067548777376, 0.04165883728169969, 0.026128697408629314, 0.0142359174455383, 0.04431197027276669, 0.030626980853932242, 0.0730437519294875, 0.027996427811948315, 0.030280035720872026, 0.11377521165247474, 0.018121602512629967, 0.04694074385666421, 0.02050718236049371, 0.023465004716334597, 0.019824257220274637, 0.031024714333138297, 0.026172103293772255, 0.028340760585186735, 0.03066310945100018, 0.027922141798106686, 0.027035181177780032, 0.03810293719704662, 0.0392510930874518, 0.010936073576366263, 0.030718800212655748, 0.006673763830414308, 0.020085633998470645, 0.016049475309305956, 0.014428702815036689, 0.012471535559078413, 0.038042764711592875, 0.048163178975560834, 0.03321750881150365, 0.030437438881822994, 0.04339271817090256, 0.05504871146487338, 0.04780914654423084, 0.02781028699662004, 0.02672114160044917, 0.03855188649946025, 0.011078090107600604, 0.042392133469028134, 0.040395116699593406, 0.014833045225324375, 0.006504240337692733, 0.0796428442533527, 0.08452875100608383, 0.018286681600979397, 0.015484046989253588, 0.017234892950260212, 0.0227065857699407, 0.049165890884718726, 0.05786653169031654, 0.012209744874521025, 0.04983131321413176, 0.02651150820643774, 0.015273080273930515, 0.07909164311630384, 0.02483487531675824, 0.00862983482823308, 0.021319080044382384, 0.005333062178189201, 0.0672920819904123, 0.026002265978604555, 0.01660719038253384, 0.07712515363735811, 0.04774256868820105, 0.012010024877132049, 0.0070579673213485095, 0.06204126589000225, 0.01512991956302098, 0.09505403693765402, 0.017329899727233818, 0.00783795562373208, 0.03642582254750388, 0.08131061547568866, 0.030669511428901126, 0.05904996461634125, 0.035885779918836694, 0.05692678104553904, 0.015138911848355616, 0.03739672812766262, 0.03610555062602673, 0.04162352292665413, 0.037910335032003264, 0.030740984915090457, 0.003775559681733804, 0.03234298573806882, 0.010564033673810107, 0.015489987563341856, 0.037658778351864645, 0.0378503728924053, 0.04931305495223828, 0.0713598383590579, 0.04921199733923588, 0.08665920847228595, 0.05917638247566564, 0.010832205132049109, 0.016109654580109885, 0.011148164963482745, 0.018242580217442343, 0.08118713567299501, 0.00236595025385863, 0.0460678696233247, 0.0599448098135846, 0.028999161773494313, 0.03287743045283215, 0.028981730208865235, 0.11410187876650266, 0.026617965261851038, 0.030088522604533603, 0.028005323406042795, 0.044787677603640726, 0.08699536829122476, 0.015186740085482597, 0.05572357221639582, 0.02813261657554124, 0.025993962406313846, 0.08781366795301437, 0.01934023105007197, 0.03501938230225018, 0.029991851720426763, 0.05108146309586508, 0.04356486589780875, 0.1623431673007352, 0.11853377095290593, 0.11309694804783378, 0.1598723227424281, 0.14018072081463678, 0.19186321326664516, 0.13892923082624162, 0.09530526452830859, 0.13086204656532832, 0.1160099735217435, 0.14104512014559337, 0.15309107090745652, 0.079461363277265, 0.08085165438907486, 0.12526597827672958, 0.08710024944905724, 0.08702529168554715, 0.1060762887022325, 0.14345923917634146, 0.09797158824013812, 0.13696560476507458, 0.11238658973681075, 0.17796440050005913, 0.09367518592625856, 0.21443085372447968, 0.1100250096725566, 0.11965203737573964, 0.32090067916682785, 0.06749913016600267, 0.08603411487170629, 0.11819995886513165, 0.13332183100283146, 0.09881709037082535, 0.10343059924032007, 0.18513217302305357, 0.09204418451658317, 0.09899074105279786, 0.08890329341271094, 0.16848833326782497, 0.1037889335836683, 0.09533127277557339, 0.07962599622883967, 0.14800196327269077, 0.11991931231958525, 0.09624019078910351, 0.07854227402380534, 0.09410011169633695, 0.10063688736408949, 0.07579118093209607, 0.10877733305096626, 0.11739067014838968, 0.08037900046578475, 0.10132638750863926, 0.12094513513147831, 0.0907979260331818, 0.08059306469346796, 0.09159016316490513, 0.13583223415272577, 0.21987050612057957, 0.05442942612405334, 0.0960510287966047, 0.17273592177246297, 0.10085236972996167, 0.10528796671756677, 0.057432920671999454, 0.06738320924341679, 0.10848100323762212, 0.16189358356807912, 0.12108618899115495, 0.07009213138371706, 0.18298260122537613, 0.0808353763339775, 0.11369576877249138, 0.1380466196153845, 0.1674486683415515, 0.08244577063513653, 0.07991568318435124, 0.1348123960196972, 0.06171636975237301, 0.18812173046171665, 0.19212029661451066, 0.1716317960194179, 0.18303239212504455, 0.11557630822062492, 0.16258950265390532, 0.11411333243761744, 0.19278946784990175, 0.24521946161985397, 0.20361758396029472, 0.08474341912993363, 0.11273156372564179, 0.11556541094822542, 0.07258897061858859, 0.11120466994387762, 0.14771159099681036, 0.10051149409264326, 0.09622147679328918, 0.1242851016244718, 0.2290196551808289, 0.11636183464101382, 0.0915261230298451, 0.21674885148448603, 0.0663476630247065, 0.12726564811808722, 0.20964609618697846, 0.26581443793007303, 0.11871012220425264, 0.09421745075711183, 0.06317283838455166, 0.14507916010916233, 0.14148501439818315, 0.10586401580699853, 0.12550503973449978, 0.19987926312855311, 0.1697397418320179, 0.09210911353251763, 0.07078824045934848, 0.13705438428691455, 0.10349923305745636, 0.12447917621050562, 0.14529702413294995, 0.10548447045896735, 0.09944873861968517, 0.14286534461591924, 0.15202590663518223, 0.25619978670563015, 0.10953976213932037, 0.15442933195403644, 0.12326412355261189, 0.13038832055670874, 0.08997298351355962, 0.15333459712564945, 0.11335882185293095, 0.1758339498192072, 0.14795038104057312, 0.20615428712751183, 0.07731038012674876, 0.1682178284972906, 0.10189132219446556, 0.11052441823163203, 0.12454669044486114, 0.12104399768369538, 0.2005008283470358, 0.15155528831694806, 0.1426188192729439, 0.1710082766200815, 0.07796638778277806, 0.11087091892425503, 0.1496532189526728, 0.09725974393742425, 0.15940234224711144, 0.09747971820511989, 0.12286855120744024, 0.14405472150870732, 0.17290056150938782, 0.09833392594009638, 0.1701419231082712, 0.11595733277499676, 0.13769824616611004, 0.15601124135511263, 0.14220522503767694, 0.12410845181771687, 0.13519811603639806, 0.11686320416629314, 0.16209851471441133, 0.14992023605321134, 0.09811526803033692, 0.15754223348838942, 0.11135764566383191, 0.10145768403474774, 0.20712717063724995, 0.10154092671083552, 0.12912467122077942, 0.1020719346457294, 0.19894741741674288, 0.07302116349871669], [0.049430003855377436, 0.016627420904114842, 0.016743331648675457, 0.02815390221907624, 0.04511105043015309, 0.014723848584773285, 0.01674493638399456, 0.0208761544365968, 0.033079847626920254, 0.08336775044777564, 0.020831944487456764, 0.015541337397215622, 0.027497640112414956, 0.06042335342083659, 0.08177037044827427, 0.09038066770881414, 0.02200736221857369, 0.014299430019621338, 0.04663001892289945, 0.026240518283365027, 0.05203923563073788, 0.01215377845801413, 0.049552102839308124, 0.061373431368597915, 0.04300850450194307, 0.04516543161922267, 0.07922298713986363, 0.09591436505849872, 0.03294475469738245, 0.03125600317226989, 0.01428914682141372, 0.010483928374014795, 0.0545325634468879, 0.03591422749949353, 0.012797982997394033, 0.07357450880642448, 0.014247254069362367, 0.026476490710462843, 0.015472247265279293, 0.06180783627288682, 0.10641208211226122, 0.02314625440963677, 0.019813025769378458, 0.035587774123996496, 0.02227974313843463, 0.02273434124487851, 0.05108904233202338, 0.03341451806149312, 0.047123992416475496, 0.03742196963035634, 0.038516874092497995, 0.021731050884617225, 0.01929263351485133, 0.03629591701818364, 0.012097840031076754, 0.01585413355912481, 0.00954921924442585, 0.01588224356860987, 0.028823777434549162, 0.021143956941419413, 0.03085886680388025, 0.09691013555441584, 0.019597662147134542, 0.019810708572289774, 0.03863139723294547, 0.12449400898601327, 0.029427571820893457, 0.011158933314228696, 0.0132593664540244, 0.04516714831281986, 0.006733378644899598, 0.02409927041402885, 0.05438177939504385, 0.0504497978836298, 0.014225216948294213, 0.03391994183350887, 0.030924470962158272, 0.00880994092273925, 0.04191900117854987, 0.10477354217852865, 0.041403636868510924, 0.08719814848154783, 0.021787594904058745, 0.043266934741820605, 0.02976627953882728, 0.016323761216231754, 0.04517169110476971, 0.07036041055939027, 0.019506930140778422, 0.02313812216743827, 0.07299593556672335, 0.04758286529353686, 0.0315296020624893, 0.05015955452940293, 0.03422291450468557, 0.03600462532735296, 0.04313685279339552, 0.02670748608319887, 0.0264343655601676, 0.012269639160617121, 0.029701984953135252, 0.08032745894576822, 0.04221518849954009, 0.032066648959049156, 0.007354554553915347, 0.08115558379462787, 0.021861005607726317, 0.06794659008405038, 0.06219377342079367, 0.024486744443752935, 0.01693655806593597, 0.05373211943411401, 0.06323424580373935, 0.05757298387054886, 0.035680763955627165, 0.03568768162014229, 0.05809675183679376, 0.04143350598003183, 0.028170594180534993, 0.021386190550401807, 0.0722760981214898, 0.060666452161967754, 0.02772006898054055, 0.039083864739430804, 0.05971493571996689, 0.040274490136653185, 0.004068199536829654, 0.03867773438936897, 0.034238636161067655, 0.03221324644982815, 0.0051152252958023125, 0.012528114353439637, 0.021948234677048664, 0.012202832299018545, 0.04973574494943023, 0.01084769269384976, 0.07566388097724744, 0.007599306375985699, 0.05366367221410785, 0.025022225620757257, 0.015427942321236645, 0.02871383779815265, 0.03752501195828829, 0.03444014409823077, 0.01289679974849735, 0.020047990571973578, 0.0719343132472464, 0.03253761333014284, 0.027220112504437566, 0.037997574279350896, 0.04189176817557641, 0.011374776151829531, 0.06518257768558604, 0.023301991767116954, 0.03585462837613054, 0.04981072646166597, 0.10968888378036873, 0.06253042857029609, 0.024730630285505737, 0.04656020784750581, 0.029585612804761956, 0.05408509674349001, 0.07008618063160352, 0.041770758240350654, 0.027656921119030033, 0.02226672205142677, 0.028832072525152137, 0.016792028410626308, 0.007181875873357058, 0.013224097051923829, 0.03368147070120488, 0.1096347773979817, 0.03958520373063428, 0.08171256605003561, 0.05216811317950487, 0.04446297484849181, 0.022958546178415418, 0.03784804890996643, 0.01632612930344684, 0.020984670845791698, 0.04268804259066071, 0.04943792575172015, 0.03980828229604023, 0.030521743465214968, 0.05655053337769849, 0.013741071186294513, 0.0508610104609813, 0.06325589107083422, 0.04469455545768142, 0.020962978081245507, 0.018519624369218946, 0.025625229513804828, 0.026116568595170975, 0.036416088962661367, 0.026390956282349567, 0.018126918834501078, 0.05307251214981079, 0.02498292487247714, 0.0073938595430393305, 0.026335608180878416, 0.061771453225186894, 0.028607260302773545, 0.006110609026758799, 0.03346401719110353, 0.03337517660111189, 0.07644648969705616, 0.011157491427314068, 0.015747388126328588, 0.007755991986154446, 0.025579494557210376, 0.04392395341502769, 0.014412353513762355, 0.027875674023692096, 0.02974390484658735, 0.0665622293683035, 0.041746198665350676, 0.02300953129971666, 0.017960039932014685, 0.007652896223589778, 0.1007775476734553, 0.018394723035661236, 0.06165347634149449, 0.05338036009509649, 0.03532315903742399, 0.03148756003273385, 0.01108949288858899, 0.03273872093164495, 0.05070241307839751, 0.046484306920319796, 0.028334002376400998, 0.024777045473456383, 0.039082103941057406, 0.024065341966758882, 0.03319960566503661, 0.06777546355234725, 0.0404842320962676, 0.025757978104853203, 0.0846494013177497, 0.04965609511626618, 0.021430305504639233, 0.05797414055892399, 0.06633557831602437, 0.05141039312418018, 0.02963718485885433, 0.02546636919890131, 0.04578016399006758, 0.00936618187863912, 0.013519097784800189, 0.02173405509841229, 0.029814516593303, 0.048441208699452024, 0.06009323934891394, 0.02911350510216185, 0.055547699332237244, 0.03003308968618512, 0.02428560970085008, 0.03367006113486631, 0.05144977529666253, 0.046056388810809167, 0.04451444512233138, 0.0902562854545457, 0.016556305345147848, 0.039055858206536086, 0.036038755638790984, 0.06467691981898886, 0.04444952628442219, 0.05245291468288217, 0.14847346368644918, 0.028357754494728785, 0.027931290146495615, 0.08753856271505356, 0.031290415075740645, 0.09176058402018887, 0.04319538661677923, 0.01448567261520241, 0.033704082880701335, 0.013356019526587, 0.02891370707324573, 0.010349452063175184, 0.04217855778655835, 0.02709494823856013, 0.036945977314774475, 0.04324467879320894, 0.025640432090897645, 0.02747315856894212, 0.024383617298943654, 0.027014311136943952, 0.058076422927635055, 0.04769621117572699, 0.061334368107574325, 0.05131412596840944, 0.03540592673899872, 0.03540240174957684, 0.01624411647208035, 0.05632929703486817, 0.015464771505711334, 0.02843732968904078, 0.045727489316569905, 0.026309443870559335, 0.04114750007699643, 0.040881304003830464, 0.06026670004108122, 0.036353561960692914, 0.00956197570277644, 0.03225337840350611, 0.11336420263562884, 0.03311521626476731, 0.015046229053820883, 0.0751146272357021, 0.04445650501708899, 0.06837244544710432, 0.013273920182005634, 0.07964335993996688, 0.026776286141414727, 0.021447504671024423, 0.019331800252465264, 0.0025787148749389288, 0.017085275978648236, 0.02849880326539278, 0.08563362314764943, 0.013345082390255161, 0.04504330549389124, 0.0287424787612898, 0.02517860080115497, 0.012091651791706681, 0.007773776388993221, 0.030899368559143374, 0.03168958704918623, 0.050363433946456225, 0.03318025045362966, 0.02733904612250626, 0.05427400089268174, 0.022759994957596064, 0.023262180421235304, 0.030050151449229037, 0.06592489499598742, 0.021916826987372975, 0.02925514928730471, 0.07403012471539633, 0.03977100358211568, 0.020031536097771356, 0.042960878128984144, 0.07500564772635698, 0.10122958770287888, 0.058876510709524155, 0.01316543176238026, 0.03348887871418681, 0.02486908874873604, 0.03638449976486819, 0.04917334798457367, 0.04917486451034035, 0.06359118236494915, 0.1037462605163455, 0.14150545187294483, 0.10559687657015664, 0.11190404277294874, 0.11001450595046793, 0.12097832906459059, 0.16493787164134638, 0.09990036474274737, 0.10933114654783692, 0.1751354251589094, 0.1386550348252058, 0.19387782444911345, 0.10326044301369361, 0.1949116811156273, 0.18784875582371438, 0.16003605324242795, 0.08810104788946253, 0.06735084312302725, 0.12119824226413455, 0.08527225575276784, 0.1713586449623108, 0.07358550785907678, 0.17181042714842729, 0.1517498650188957, 0.09602943781231131, 0.1590352819434234, 0.1281316623623882, 0.18426271182085785, 0.14155714267066546, 0.14125747446502956, 0.07139380582209144, 0.1227443657283272, 0.12703909884606088, 0.1294549142143556, 0.09182660547750336, 0.10858015755989722, 0.08987114219261066, 0.15380418407065527, 0.09287788692329611, 0.1319895682058164, 0.14648208554301942, 0.227126148928489, 0.136142066812941, 0.15387514526290552, 0.12184780383748667, 0.0895999860284584, 0.1280040434960808, 0.10845370577382189, 0.0949645381686943, 0.0730626762711576, 0.12197637265282017, 0.16259449667164258, 0.09789719366069351, 0.09195960512650864, 0.09693099372088909, 0.19942756236663886, 0.11505006360156195, 0.13102956329073223, 0.1394272076764277, 0.12965012873922074, 0.1058369694011552, 0.1781113033315965, 0.12641965065683636, 0.14754978753626347, 0.14301585725375585, 0.23933422884770802, 0.14730204083025455, 0.07201802411249705, 0.12446697615087032, 0.1666066606662103, 0.04697489452415279, 0.08317812705146414, 0.11738123851163046, 0.1265642193279096, 0.13920890939022812, 0.16396318322845868, 0.06299219200653688, 0.1665552548531975, 0.1416386482971055, 0.25647405056016787, 0.14301451375441893, 0.161835908091494, 0.21561245460595402, 0.13304270883756025, 0.1407854040818555, 0.11618762756032602, 0.10101363714784384, 0.13350704392152174, 0.1022480009123683, 0.1857915869248765, 0.13610728510788508, 0.2303025477698871, 0.14517188870481082, 0.0714858490973711, 0.1373827273824385, 0.08769375724451882, 0.1508784903479474, 0.15266955138317176, 0.09722068067640066, 0.14341251525495732, 0.08202347079558031, 0.12712481138961657, 0.11053473196391549, 0.1293613306645836, 0.10622256049620253, 0.10158748099846499, 0.1331307284001793, 0.14941965362855367, 0.1118189205548593, 0.1704655843121665, 0.0718787412292191, 0.10811116772570781, 0.09796804628734078, 0.18899144950721944, 0.08103299287280866, 0.15865337529352733, 0.11219398757176739, 0.13590755153979572, 0.10211612084614378, 0.09917796243514333, 0.16404557095042296, 0.10751769385699715, 0.11554745691163198, 0.17279833342347825, 0.15438209234603814, 0.14982509187289647, 0.07610745967498847, 0.15463009689535412, 0.1141903597329344, 0.18278027565351554, 0.07634800712444953, 0.17257462042782987, 0.1651243602058717, 0.10078323379691158, 0.19234295109552996, 0.1260711143591574, 0.15391600664172853, 0.12595346995762416, 0.15892956618751797, 0.09170864894986153, 0.07709225825965405, 0.11170209039534841, 0.12700806265430792, 0.15853837717856678, 0.10463645774871111, 0.12752784761999333, 0.13506497389503888, 0.13857711186366423, 0.107786760133292, 0.14082671329379082, 0.08550284230815512, 0.09199392542775188, 0.14783372730016708, 0.1224372743495873, 0.13509476158235753, 0.16854819362717016, 0.13602917215653829, 0.1299671267292329, 0.06694615805255515, 0.11438284654702459, 0.059730955931757174, 0.11236314635191645, 0.14566264594239847, 0.16904167857553276, 0.08191307314804622, 0.0912117984678064, 0.12778763153723308, 0.1796432047017983, 0.11523799066032682, 0.09145722458405153, 0.08480190206319094, 0.2599701615316527, 0.15105375594326428, 0.23692138546279498, 0.15076012669929437, 0.15035869181156158], [0.023478244630885974, 0.018639027872788053, 0.026962045280795013, 0.01948082011326083, 0.02688289077819458, 0.027335102137710367, 0.0708652406132647, 0.02497769336748336, 0.02238592877984047, 0.010024879926017352, 0.00944258492173893, 0.03331580478698015, 0.07424859942070075, 0.039992674187357934, 0.01485491610531296, 0.028099239437973926, 0.07207174372992345, 0.08196848910301924, 0.03849279288468616, 0.006742530810048005, 0.006624670973646322, 0.03268186987510749, 0.04677653159680111, 0.014625125132235033, 0.03791242152718561, 0.07171526857252632, 0.043466468142079454, 0.04336891516244837, 0.029464748754565204, 0.03189374805827226, 0.04293806238898209, 0.022231185476162603, 0.006228639345083917, 0.02523768593424133, 0.06110644819481032, 0.08699888988797154, 0.08319188095629215, 0.012024660029315522, 0.052987043878861835, 0.019099330762401223, 0.09169783310166427, 0.029344335930155854, 0.014832755151603903, 0.024313409280564104, 0.0370602765386658, 0.03765139249818666, 0.026537082191290598, 0.036232677554445605, 0.03316853893920779, 0.031179420317390134, 0.0321578440655555, 0.020425819226407578, 0.00848166992156101, 0.08221256493457726, 0.02913025813177228, 0.07594189713043825, 0.04815568794895496, 0.017100480252078602, 0.02895727241411805, 0.04948788628514324, 0.08880804745214325, 0.023350747900881937, 0.066897541018469, 0.008932482650769609, 0.024172000886340226, 0.008923537014717502, 0.011975152418017387, 0.025952320712219392, 0.019259130848305564, 0.04211987468547054, 0.05083514470607042, 0.006935976903020803, 0.005925901616657419, 0.04841824707442096, 0.009499585255980492, 0.04386822872662118, 0.04752982760380421, 0.08640385538871799, 0.027135704444455247, 0.09975110739469528, 0.02177882823161781, 0.03250584092789462, 0.08586926478892565, 0.11118543347609894, 0.13743672519922256, 0.01344232918095908, 0.05719911107527358, 0.0468068112220083, 0.10922340197222573, 0.05041147083310144, 0.08224012702703476, 0.017678246035107543, 0.09431914280035666, 0.04716314388705151, 0.09155682673943893, 0.06016433624816792, 0.11706270703247615, 0.04696399725175329, 0.07284934486129455, 0.07294050604104996, 0.06583328598311969, 0.051736741326749325, 0.031623894681355784, 0.02450457464770547, 0.07594326777117592, 0.0175816514861903, 0.04204900509544781, 0.05019203260807054, 0.06457569596490689, 0.03387063269370368, 0.04849449744714158, 0.03597880706989339, 0.037748701205211024, 0.04468967000554715, 0.032663383188524416, 0.03096189895378692, 0.04607927579698818, 0.029112304095178843, 0.04258110547172172, 0.02685402420216373, 0.05634676252624818, 0.010176173727294164, 0.018398816298161234, 0.038674321358225176, 0.01562553002232952, 0.04017746641433664, 0.02231001088927899, 0.05399806444932308, 0.02266328505772565, 0.04990547030631985, 0.026070004129516225, 0.09673721769026347, 0.006402368058583566, 0.02802902802691928, 0.013185049057938159, 0.05637484709067004, 0.0392828213849238, 0.09136468597820827, 0.02132652696621205, 0.01874666897180889, 0.06010043182011161, 0.02596241731329688, 0.05097476007150752, 0.02973410001556788, 0.04532477878300207, 0.014388282483975803, 0.011676771732579385, 0.012322652253455349, 0.052519353439233134, 0.07091602217406034, 0.039404845730002434, 0.04031735997913139, 0.06263908238283225, 0.04744416255769985, 0.04160443912925465, 0.012113161351797836, 0.018881822969498377, 0.04974205193242856, 0.05595743948859828, 0.06625055109283753, 0.0411914895022554, 0.017975486781714217, 0.03791419589625938, 0.045167742030961175, 0.046394886182887216, 0.034592543063419204, 0.02375168406537601, 0.03752302385068365, 0.041742850095033646, 0.03001984128994601, 0.034597727070961676, 0.013284200835706932, 0.08599016615854842, 0.024174043276746358, 0.010440428342138017, 0.03608379679332886, 0.06290825043937989, 0.06909935322723218, 0.02081157316985939, 0.023940147166805606, 0.026293444014819603, 0.03956894263891237, 0.06409553744431053, 0.04452239416007485, 0.06518954624022756, 0.04283464686678989, 0.0340182717357363, 0.008750817622058094, 0.016441415795790296, 0.024833662435412407, 0.020487194415181875, 0.013058928905853202, 0.05777532979846001, 0.0522382295956569, 0.023403047683781812, 0.017755468409242373, 0.08396636761192765, 0.03739744737478239, 0.052661435279463015, 0.05702864272253854, 0.034271110847060166, 0.03651350623528872, 0.08503409674657242, 0.01739726129121014, 0.02290904874514256, 0.06922194414905139, 0.026739818276837468, 0.02590466889419726, 0.038584388326853514, 0.07923482079058886, 0.03987929777109197, 0.0862098690122366, 0.05939853484077113, 0.026624772664425627, 0.07442537136375904, 0.03472275732617293, 0.013080353649067027, 0.04576493766424911, 0.010886362404562533, 0.047987499473882575, 0.02763907904071467, 0.05097595429314034, 0.06627392662422997, 0.03952296171337366, 0.018034361568944793, 0.04992390610277653, 0.019963451894000173, 0.025422016757407358, 0.059517522741641314, 0.0454448998373534, 0.021953138788895946, 0.04679046192073396, 0.014893660454877784, 0.08985016188983407, 0.1305110811122826, 0.02130286136109914, 0.016360503887491565, 0.015795920343537415, 0.09560036619326898, 0.036994017594094784, 0.038028325486396036, 0.037201632346425734, 0.025991753774828145, 0.02936742647684046, 0.010531609877943993, 0.017445327015593648, 0.02076437257762466, 0.024575072739805495, 0.013903132490148502, 0.04691928179402437, 0.021105195628479123, 0.05703320247786386, 0.06350548339209386, 0.10768035227166754, 0.05677736424175756, 0.03133867248626692, 0.10869691986590624, 0.03798364056274295, 0.14629593624600343, 0.2064953866813864, 0.03375613669465695, 0.004366758761794439, 0.057522046246698925, 0.08472062035330705, 0.08599357918969222, 0.05553977404321943, 0.11811515555850097, 0.06833165870713336, 0.04540439808209028, 0.07456869831574814, 0.12423749560756342, 0.05529698742819684, 0.05542857911703842, 0.02809083747810551, 0.15166143833526544, 0.16261656263044902, 0.004460495406030012, 0.024460975380082215, 0.0048954138765111566, 0.04447066265025309, 0.048589078443390984, 0.031001420225948095, 0.01743289625405201, 0.032211645107184134, 0.03599643201700278, 0.014582194221605147, 0.028727601881005933, 0.07620660042656319, 0.07738892055515732, 0.058078051411679814, 0.019942902460960404, 0.03695504254262362, 0.041600279709590335, 0.054068794939666986, 0.025832720433494875, 0.030907717932547842, 0.01217862980307213, 0.022458515063460385, 0.03229797851028187, 0.039356842770108154, 0.016791639949328134, 0.03490990406966635, 0.03529346973768302, 0.10164181129740817, 0.025807031097688844, 0.02289776810045753, 0.04822445408041988, 0.059993257213916094, 0.06576181588960545, 0.02425830714803721, 0.03681160702503153, 0.021163729451862828, 0.054042779907052, 0.01640442037023604, 0.021695071565253393, 0.04079135740175843, 0.03183716841574226, 0.07960751972028188, 0.03418708107035075, 0.025702385730775337, 0.03254614590800234, 0.02027312170581094, 0.03676058119162917, 0.02470277642299022, 0.057777568964021545, 0.023390187748840878, 0.037625272292643785, 0.06489933681275163, 0.06633101177534886, 0.05191549119938697, 0.007426291820593178, 0.0653945520254118, 0.02053020505367645, 0.03813281987926789, 0.04288834612816572, 0.09546285428638969, 0.01825271244160831, 0.010179940444816436, 0.09268286238823618, 0.06529717546488557, 0.047161871633891544, 0.01763106070991073, 0.028060422145894597, 0.01274556023002203, 0.028669851765568768, 0.005094332354409354, 0.014484715880826116, 0.04019192260290895, 0.07176060149712221, 0.031129659951797554, 0.042260076983698776, 0.01929198212123343, 0.09425962849387101, 0.09607496751206261, 0.09918673589293446, 0.2608980717403548, 0.14280529426676886, 0.12498916313052177, 0.17755300471825258, 0.084816931613854, 0.13609847772334302, 0.08397375007293054, 0.184445373447878, 0.09698254881160599, 0.14531994504587992, 0.1555457120495183, 0.19199721036212786, 0.07420397895787444, 0.09323585485773427, 0.15655583356107983, 0.16066673797156128, 0.11911271060151712, 0.15167724820119993, 0.15875375776418618, 0.14005899163229124, 0.10654310043901205, 0.08838654828390904, 0.12373713031411171, 0.17749680844800814, 0.13456850339259419, 0.0627218975818583, 0.15667562213327202, 0.088153824343213, 0.12689317310495035, 0.10093597202960934, 0.1845760185803686, 0.11558552272617817, 0.13224787291671547, 0.21966222301125526, 0.09279321932366916, 0.15872493359659398, 0.09978080687246152, 0.1787143445440701, 0.08852081000804901, 0.09388811021511044, 0.13677086521472248, 0.11492809014660971, 0.12951917148062161, 0.17213475331664085, 0.1091791886304106, 0.10089287148522479, 0.19320143360112393, 0.13442896945135935, 0.11852200515568256, 0.09112457957650934, 0.18251439849180834, 0.0795188012665936, 0.17772764606135233, 0.09133104421198368, 0.23194283832396778, 0.21117962604122503, 0.12887765733259066, 0.2122021783143282, 0.14056583014982088, 0.13767886720597744, 0.09730671891676528, 0.16288718953728676, 0.13534472031252726, 0.09299253220004694, 0.08524125348776579, 0.0876788023327078, 0.14185430029673235, 0.11338141706905194, 0.13422300693179878, 0.09897172171622515, 0.17489284888974257, 0.14690102663423332, 0.15195837883012636, 0.10269132855215243, 0.15181978126721724, 0.1636473387479782, 0.1278538836964539, 0.2702503470437867, 0.21084599037255558, 0.2566943573100226, 0.39957236338938984, 0.2865272079195295, 0.10187666583806276, 0.12132272629865579, 0.2950820688690458, 0.2999315857887268, 0.2918756109263216, 0.2657038910048348, 0.16641354959990295, 0.20769319097910607, 0.1457982308098248, 0.31782007589936256, 0.16058983281254768, 0.24924580699631146, 0.1482178188328232, 0.23305517435073853, 0.22001162783375808, 0.14275673830083438, 0.11132475028612784, 0.11974225539181914, 0.1039160978315132, 0.08959137541907174, 0.14275425486266613, 0.10235254958804164, 0.11437105360840048, 0.12699077358203276, 0.1504416223615408, 0.11484623168195997, 0.10653231851756573, 0.11243766306766442, 0.15020203164645604, 0.07701786368020944, 0.12050567514130048, 0.14659678510257176, 0.09207632672041655, 0.10932635609060526, 0.09861197602003813, 0.17744853746678146, 0.11535786065672125, 0.11443849998925414, 0.1496217077864068, 0.14411640034190246, 0.15810807741114072, 0.10306970681995153, 0.11416344903409481, 0.10998802951404027, 0.15464388472693308, 0.12691229422177586, 0.20415483441736015, 0.11109347162502152, 0.1492885063801493, 0.11862420610019139, 0.08932224807462522, 0.16374480351805687, 0.12323899061552115, 0.09667583062712636, 0.09940657445362636, 0.1320902763732842, 0.1646701760057892, 0.22275859543255397, 0.09873795961695057, 0.10653349238314799, 0.09520342320735965, 0.06621367949992418, 0.07211903762072325, 0.13669622636267117, 0.13960285325135502, 0.14669423630195005, 0.2062405424990824, 0.15523526870778628, 0.13965524972549506, 0.1059492194492902, 0.12639409702803406, 0.07556816004216671, 0.14276028025363172, 0.13333274184593133, 0.2667473150151116, 0.16216936734105858, 0.10951232218316623, 0.11908833762364728, 0.13526674306818418, 0.12727361411920615, 0.14480020079229558, 0.12252002848046166, 0.15081013473016874, 0.13511699038956845, 0.07812960259616375, 0.09212758325572525, 0.11229934370411293, 0.17508005670138768, 0.09841685649007559, 0.12119869009724685, 0.16053979764027254], [0.01001160014753363, 0.010646751333427216, 0.022827992648152367, 0.04260499668972833, 0.026631395166207637, 0.02572119132881718, 0.028909191422696625, 0.04767867104549493, 0.05442371625187142, 0.02440933886516307, 0.012527996457980146, 0.03520855786544936, 0.040708732192537615, 0.02939597923042519, 0.018162860834438885, 0.02804853760504297, 0.03794759338987725, 0.011895068322441407, 0.03381118963339499, 0.029322185154472078, 0.021622682056788887, 0.05298707441293767, 0.006106768518553248, 0.05685622697429998, 0.07260155065783433, 0.05404433375224471, 0.009656330237963369, 0.02030199845986707, 0.06451903150549956, 0.02295329262103353, 0.04938676421131406, 0.014975176259343113, 0.03418289450928569, 0.04003511994544949, 0.03935392167685287, 0.02311369829944202, 0.08455466425844602, 0.05913373654974358, 0.02782854637397187, 0.03154404128768614, 0.05460486474579998, 0.038577714934945107, 0.05878446064889431, 0.030893458519130945, 0.047478113057357926, 0.010319664375856519, 0.02050455642997154, 0.002871460115004863, 0.08019678667187691, 0.035658657284719605, 0.03490861485313092, 0.08443063484238726, 0.06233194350664105, 0.02701802272349596, 0.01214027900381812, 0.026708804137472595, 0.022085851756855845, 0.025375024814690863, 0.02753861344951604, 0.04172825141410742, 0.044086852709629705, 0.006103416555561125, 0.016702991045479263, 0.037958093719290834, 0.1227902075541871, 0.08191226569137403, 0.04372698487713933, 0.05277248092793992, 0.0367022814628269, 0.026386617050905312, 0.05348077309983117, 0.05352873195494924, 0.03353900209601436, 0.13659520606909478, 0.03785502764263323, 0.3431339104260717, 0.4338182700531823, 1.0191291996410914, 1.9811309618609292, 3.4993355870246887, 4.749374270439148, 4.438136228493281, 3.5097281379359107, 3.493924460240773, 4.038683422974177, 5.272203632763453, 2.38197905250958, 3.671806812286377, 2.719718175274985, 2.5910705413137163, 2.0700650811195374, 1.8506709337234497, 0.532628493649619, 0.6761739339147295, 1.9928853596959795, 3.1002931594848633, 2.876345987830843, 1.3950827632631575, 1.311194664665631, 2.090594402381352, 1.2049650677612849, 0.14154672037277902, 0.01932805304282478, 0.06477064586111478, 0.044927272613027265, 0.08108912128955126, 0.06580555425690753, 0.05706199950405529, 0.03686226984219892, 0.02587614837102592, 0.02800480941576617, 0.07601718737610749, 0.04864982429093548, 0.035916297031300407, 0.005981298063748649, 0.01942432698394571, 0.02561002184769937, 0.08902865954275642, 0.026348686943362867, 0.06245151494762727, 0.03399299969896674, 0.03924283531627484, 0.037520618444042544, 0.013134459183285279, 0.049843102760080776, 0.04318371920713356, 0.02142739119673414, 0.0444216588512063, 0.03118764076914106, 0.02357531415431627, 0.039497581111001115, 0.0341741549782455, 0.02848013337435467, 0.05147188536024519, 0.021873923218143836, 0.09608733720545258, 0.008247379413140672, 0.061257931137723584, 0.04050311911851168, 0.02828824706375599, 0.015658656101939932, 0.04082905341471944, 0.038838852529547045, 0.02513586836201804, 0.03543805876480682, 0.03533599013462663, 0.042391268336879354, 0.048019315980906994, 0.054174598905124834, 0.05946116362299238, 0.05698075172092233, 0.017764911920364414, 0.02493581418613238, 0.02636201337112912, 0.014223648684232362, 0.0889081788648452, 0.0605793757630246, 0.04593627793448312, 0.014232843681903822, 0.012701430856915457, 0.010188712206270014, 0.031937265901693275, 0.035032026802322695, 0.04165990597435406, 0.02238846819714776, 0.02065330487675965, 0.04191634471395186, 0.03280872538951891, 0.03688872252990093, 0.02416083219993327, 0.040902094316801856, 0.010211019893176854, 0.01554524915159813, 0.02004394480692489, 0.0677155964076519, 0.013063915290071495, 0.0409023216260331, 0.060111471584865024, 0.04276875772380403, 0.021238532848656178, 0.019026110048538873, 0.03465225753773536, 0.06520752741822175, 0.022083909450364963, 0.020215671842119524, 0.020590245224801556, 0.03099626675248146, 0.04316555143200925, 0.031294136840317927, 0.029184540933264152, 0.031887468216674666, 0.11338368337601423, 0.03232018356876714, 0.04899630123483283, 0.04074013140052557, 0.012209496361070445, 0.03189709662858929, 0.05232369786660586, 0.003890568822888391, 0.03105923140953694, 0.031305173212396245, 0.02502645967927362, 0.0778157055111868, 0.024454909277015498, 0.03702912160328456, 0.04468516792569842, 0.018472654478890554, 0.03793365628059421, 0.03276111597993544, 0.010748980267505561, 0.019750609029350535, 0.016848287445359995, 0.025969372297238027, 0.08612226335597889, 0.04477578288476382, 0.038962881945605786, 0.02884495790515627, 0.0331277691626123, 0.07417522264378411, 0.051955975991274626, 0.006054866526808057, 0.07074864115566015, 0.01405183513582285, 0.06721464757408414, 0.059770487381943634, 0.058783212144459994, 0.020696274803153107, 0.054827458158667595, 0.016653742973825762, 0.03973402342359934, 0.023535224609076977, 0.034484323513294966, 0.02618941611477307, 0.02651428002198892, 0.04779400842796479, 0.030953033893768276, 0.02675468328275851, 0.029229656726654087, 0.032632218075117896, 0.038941626836146624, 0.05601759161800146, 0.06889119225421123, 0.04582286419879113, 0.03346645313182047, 0.037386054771819284, 0.037766136162515195, 0.0688108265666025, 0.03410402838406818, 0.09829127322882414, 0.17453156970441341, 0.048434589590345106, 0.30585066388760296, 0.5522779992648533, 1.6003270127943583, 3.4964438336236134, 4.523143529891968, 7.02854278257915, 6.322310073035104, 5.6783141153199335, 5.666740587779453, 6.61185497045517, 7.3522571836199075, 4.401444094521659, 4.393895745277405, 4.184132235390799, 3.2444040094103133, 2.4001051655837466, 2.3194348428930556, 0.7546995974012783, 0.8875485573496137, 2.5941690036228726, 4.289984566824777, 3.31848874262401, 2.4168941846915653, 2.6057846546173096, 3.2614003888198306, 2.043500597987856, 0.3561615113701139, 0.10688333146806274, 0.045219052849071364, 0.06297110992350749, 0.05805462159748588, 0.06369428576103278, 0.014468408987990447, 0.02660770241969398, 0.039956382741885524, 0.06313965123678957, 0.03734269638412765, 0.028413540251286964, 0.05123324120151145, 0.05936211786632027, 0.03570548977170672, 0.055238935364676375, 0.02595223080632942, 0.034836771565356424, 0.04399709949003799, 0.06845851761421987, 0.04560889157333544, 0.05828047876379319, 0.030305345077067614, 0.02851201773488096, 0.06445588025131396, 0.02812552758093391, 0.05436350983966674, 0.03228423139080405, 0.04495671085481133, 0.016648314693676572, 0.004238906649074384, 0.03900111060855644, 0.05821459301348243, 0.014665447075718215, 0.02781839549009289, 0.024871049714939933, 0.0312459574613188, 0.020534581604546735, 0.030039003118872643, 0.008355621015653014, 0.036106140951492956, 0.021815328326608454, 0.03713804682982819, 0.03905021618785603, 0.015964000253006816, 0.02103922506129103, 0.025356499112344215, 0.03465784527361393, 0.015252274693921208, 0.07482399033116442, 0.012114790684011365, 0.028028059418180158, 0.00818486004469118, 0.029175126259880405, 0.07511323623891387, 0.006217348946457995, 0.011579332407563925, 0.0619904368317553, 0.01963728180687342, 0.01956794909866793, 0.04144724292148437, 0.09194519304271255, 0.022006514049800377, 0.016451371600851417, 0.02064412260161979, 0.03435935771891049, 0.044070951241467676, 0.020620372179629545, 0.016029309248551726, 0.04888890949743135, 0.05537799093872309, 0.03900317335501313, 0.030799596770001308, 0.004835204919800162, 0.03670409315132669, 0.12715769319662026, 0.12704648130706378, 0.11076653988233634, 0.15084967975105557, 0.16509512891726835, 0.07937271946242877, 0.12854831000523909, 0.10009248514792748, 0.2045471497944423, 0.08368909784725734, 0.08736479668212788, 0.07029657398483583, 0.10983335745653935, 0.12578158346670015, 0.1502033072922911, 0.16237566912812845, 0.18727570585906506, 0.13198228073971613, 0.06586826446333102, 0.07239998504519463, 0.05786908298198666, 0.1287828931318862, 0.07688826349164758, 0.14817484042474202, 0.06496566361082451, 0.24637896940112114, 0.13752908738596098, 0.11376502684184484, 0.10379307264728205, 0.1133311308388199, 0.13800429260092123, 0.10100780853203364, 0.10981407349130937, 0.16511376148888043, 0.06961218320897647, 0.16336584171014173, 0.17666941641696862, 0.14951831262026513, 0.08707921486347914, 0.14520470265831265, 0.20834535812692984, 0.1599212179758719, 0.12945138583225863, 0.11696594793881689, 0.14623770437070302, 0.3078409156629017, 0.1253019677741187, 0.13794926341090882, 0.19526652778897965, 0.13894770054944924, 0.16592519437628134, 0.13737906329333782, 0.12644634422447, 0.10457209191684212, 0.10977554627295051, 0.09663574956357479, 0.1564603772546564, 0.10759997301335845, 0.17563013147030557, 0.13218589552811214, 0.09577759275478975, 0.14221043618662016, 0.11373766830989293, 0.09338595358920948, 0.25410300493240356, 0.12906802711742266, 0.12796289713254996, 0.12251116681311812, 0.08504894309278045, 0.20021949415760382, 0.23378427379897662, 0.13393342175654002, 0.19453005945043905, 0.24555829486676625, 0.2417761135314192, 0.5191309664930616, 0.9248069695064, 2.279731099094663, 4.711731536047799, 5.917778134346008, 8.254674451691763, 7.934618711471558, 7.700794458389282, 7.966877460479736, 8.21776214667729, 8.511959297316414, 5.719525183950152, 6.051761984825134, 6.770325575556074, 5.5111695528030396, 4.1431430748530795, 3.660068699291774, 1.529317400285176, 1.9702783099242618, 4.044173802648272, 6.088079350335257, 4.727112242153712, 4.118350599493299, 4.0998692597661694, 4.579750503812518, 3.1054680475166867, 0.5735575088432857, 0.2446477280131408, 0.17841858470014163, 0.2353193371423653, 0.16794614307582378, 0.12768191578132765, 0.13008232840469905, 0.12848209855811937, 0.1616598961076566, 0.1345804998917239, 0.1852387030209814, 0.1492435737912144, 0.14302367397717067, 0.17986592703631946, 0.08134762956095593, 0.09406986939055578, 0.15883112432701246, 0.1008080749639443, 0.19190529600850173, 0.23348810683403695, 0.1863395853766373, 0.09937262734664337, 0.1406605536384242, 0.12107518315315247, 0.16614555540893758, 0.10870314203202724, 0.10790890322199889, 0.13843783576573643, 0.13042732274958066, 0.09541070887020656, 0.16234422581536428, 0.16407914486314568, 0.0765881406675492, 0.09979598570082869, 0.14615119115582534, 0.18001673822956427, 0.08597404416650534, 0.12012062008891787, 0.1642646427665438, 0.07914184792233364, 0.06902706889169556, 0.14336136728525162, 0.17993235561464513, 0.0891887666657567, 0.1027626832947135, 0.18094139147017682, 0.14986676749374184, 0.14477377863866941, 0.12243306743247168, 0.23235403054526874, 0.10288047018860068, 0.10483496995376688, 0.13232262033436978, 0.06373661956084625, 0.21812717323856695, 0.13411307068807737, 0.08733719387756926, 0.1913571482790368, 0.07856518136603491, 0.06169300779168095, 0.21511332424623625, 0.246909393795899, 0.133308097454054, 0.09053746358092342, 0.07371804610426937, 0.1541546338370868, 0.10837166410471712, 0.1015535881742835, 0.07609587029686996, 0.15989016821341856, 0.18402943148144654, 0.11853302456438541, 0.12971803652388708, 0.16684420220553875, 0.08605673722922802], [0.01758057770452329, 0.03359794643308435, 0.05372045880981854, 0.043527980734195025, 0.010663526415425752, 0.044820484771792374, 0.03631607968626278, 0.022692334838211536, 0.04937470664403268, 0.05882105404245002, 0.07234247920236417, 0.03197996611041682, 0.03724349456440125, 0.04160539925630603, 0.017223826044106057, 0.02935702114232949, 0.07187263441405126, 0.05301028031057545, 0.048602211488676925, 0.07768991868942976, 0.040763452649116516, 0.019758208621559397, 0.055784708221576045, 0.02521138930959361, 0.01628044693331633, 0.03569538638527904, 0.09013747397278037, 0.06612508996788945, 0.061270219406911304, 0.008459359690147852, 0.044019314726548534, 0.011469739672195698, 0.021009115069838505, 0.033156603508229764, 0.0032757722032589038, 0.02838894335686096, 0.02088877688428121, 0.009313345204905739, 0.04114423293088164, 0.007315769492249403, 0.004485730123373547, 0.04773752038766231, 0.02744093324456896, 0.0235514025802591, 0.03317126664998276, 0.05604863798777972, 0.05423518868961504, 0.030410117669297115, 0.022310490952804685, 0.03546841302886605, 0.03492837379287396, 0.02194990048051945, 0.056616727861442735, 0.005529515453547771, 0.1045210457273892, 0.027292064357815043, 0.057046929241291115, 0.059636001741247516, 0.035981209083859406, 0.019978856335261037, 0.013826685342272478, 0.07049319986253977, 0.059579710476100445, 0.03903182449617556, 0.02829876944555768, 0.019547112984582782, 0.07653496387813773, 0.06442485763026135, 0.04224871491481151, 0.08608143590390682, 0.07303633554173367, 0.30404364370873993, 0.8199980077998978, 1.482958476458277, 4.376121384756906, 7.878440788813999, 14.815145322254725, 22.235826628548757, 21.32942717415946, 35.15925713947841, 49.79077025822231, 37.69327558789934, 47.17508268356323, 51.81142452784947, 49.35579913003104, 49.0811368397304, 37.618596349443706, 34.984659331185476, 35.158624853406636, 33.721987519945415, 26.176464455468313, 25.327545710972377, 13.738284843308584, 11.849273749760219, 16.26028377669198, 27.672533205577306, 26.911743674959453, 24.67779881613595, 30.863481249128068, 24.03757095336914, 22.810503448758805, 15.622790030070714, 6.068256139755249, 1.1039826635803496, 0.07438955828547478, 0.04985272099397012, 0.057655039110354016, 0.05008320576910462, 0.044044400166187964, 0.03466014550732715, 0.038907805258142095, 0.05472587128835065, 0.024850233956905346, 0.0439979985489377, 0.024779941121648465, 0.031795011035033634, 0.031592074781656265, 0.024916095958490456, 0.06462416372128896, 0.01812882042889084, 0.054990910459309816, 0.05045924987643957, 0.029060341883450747, 0.029194620570966175, 0.02211204490491322, 0.027825973029913645, 0.08137859111385685, 0.01862546395776527, 0.04571464464866689, 0.01890720526820847, 0.06756713973092181, 0.016455844842961857, 0.0790827814489603, 0.03144565370998212, 0.028323420622785176, 0.03638476100085037, 0.04380604777751224, 0.06226854119449854, 0.015343496941828301, 0.0047056115165885004, 0.04647900756182415, 0.06324190646409988, 0.027130131975614598, 0.02849296447155731, 0.03803082588793976, 0.06540589034557343, 0.01638590993492731, 0.02232580379183803, 0.01576368314480143, 0.10024330991187266, 0.020967227406799793, 0.03024949485968266, 0.02544667641632259, 0.06065852687294994, 0.08814058612499918, 0.03904376671250377, 0.017729689167546372, 0.026219675383929695, 0.02336728888829904, 0.05407452177522438, 0.03865275072998234, 0.0338920133321413, 0.054891966482890506, 0.05577070665146623, 0.043914928899279664, 0.014672298583069017, 0.032884185268942795, 0.09624920851950135, 0.040825447001095326, 0.023574191178860407, 0.036706912464329174, 0.04465720549757991, 0.03683754741879446, 0.09519791350300823, 0.01982876947814865, 0.0664467630641801, 0.029864083576415266, 0.031652101382080994, 0.047623526504529376, 0.08516186489058392, 0.02120323884966118, 0.038210759804184945, 0.011831729622956897, 0.04744921764358878, 0.04332923782723291, 0.027282705663570335, 0.07956384920648166, 0.04643576791776078, 0.05847198848745652, 0.04101298390222447, 0.028521130460181406, 0.03619385856602873, 0.04372435894661716, 0.08282640163919755, 0.030083294492214918, 0.039525214449635575, 0.049151370235319645, 0.039298838204039, 0.04487961570599249, 0.012389513397855418, 0.04978287938450064, 0.03555291438741343, 0.04745827947876283, 0.020025230811110566, 0.02715604013896414, 0.03140326223469206, 0.06508176773786545, 0.06343997762139354, 0.0551304817199707, 0.06590737522180591, 0.04393191941614662, 0.008087878730813307, 0.08979088507060494, 0.03908444827954684, 0.015919037129996077, 0.05846333716596876, 0.0500558540225029, 0.06330347673169204, 0.04100889912141221, 0.0417299681077046, 0.049093396203326325, 0.025211116199248602, 0.06947632692754269, 0.04572480571057115, 0.02730344339007778, 0.05924330638455493, 0.009419993098293031, 0.01973412062839738, 0.04938393811296139, 0.023853747606543556, 0.07948748009013278, 0.05466398889464991, 0.058061739429831505, 0.004939437652605453, 0.023722015121685605, 0.0013153038744349033, 0.02655720414726862, 0.03969181515276432, 0.072887675304498, 0.00702226280866723, 0.012709933748867894, 0.023267305056963648, 0.06366522410618407, 0.06371324402945382, 0.04881234021325197, 0.15955049358308315, 0.2466681067432676, 0.6665245145559311, 1.5250320988042014, 2.5614319145679474, 6.002648208822523, 11.361077683312551, 19.183118207114084, 27.162116800035747, 28.878789118358068, 44.44589281082153, 58.35955279214041, 44.387232644217356, 56.86159413201468, 62.79986163548061, 59.722803252083914, 58.71796866825649, 45.8373738016401, 42.887662002018516, 39.879915373665945, 37.890250069754465, 30.358927386147634, 28.463997295924596, 16.193160704204015, 14.203224420547485, 20.857609748840332, 32.577209268297466, 31.833123207092285, 29.121811049325125, 37.95020260129656, 30.770222527640207, 29.636752469199045, 21.22181694848197, 9.765472514288765, 2.018752417394093, 0.22891901486686297, 0.06490395085087844, 0.15484911442867347, 0.022511228752721633, 0.08882201848817722, 0.03902007905500276, 0.02449298187691186, 0.03704650567046233, 0.03370003202664001, 0.07223941651838166, 0.05237233525674258, 0.04426568400646959, 0.0325185566741441, 0.06498179238821779, 0.09880905651620456, 0.022974581657243625, 0.07162609550037555, 0.015269813127815723, 0.013094639355715896, 0.06978037168404885, 0.06636420570846115, 0.006725820612960628, 0.02662941045127809, 0.05423217938680734, 0.07692508080175944, 0.020252465403505733, 0.03929475342322673, 0.057283520831593444, 0.028526392499251024, 0.009574886527843773, 0.03915072758016842, 0.05596171425921576, 0.023016613508973802, 0.056217264117939134, 0.035935275655772, 0.007362065088403012, 0.02001560918454613, 0.013690942715454315, 0.03958129197625177, 0.028908903045313697, 0.03501854431150215, 0.034837202435093265, 0.04444613360932895, 0.03986413590610027, 0.008905531239828892, 0.04174409520679286, 0.03158556084547724, 0.004015057098253497, 0.02873286392007555, 0.017519709720675434, 0.04315335476504905, 0.04911106525521193, 0.06354958816830601, 0.033179188546325476, 0.0558255933491247, 0.016176352876105478, 0.03707841717238937, 0.047133685289216895, 0.10283450622643743, 0.04082895841981683, 0.06816952276442732, 0.009120153562564935, 0.049322228745690415, 0.049270052795431445, 0.029785692425710813, 0.024619610082092028, 0.06826288239764315, 0.09129698175404753, 0.03235649197761502, 0.07863889062511069, 0.06051303539425135, 0.0760248616071684, 0.15784373373857566, 0.09836149481790406, 0.16338565493268625, 0.1468734374003751, 0.11155419011733361, 0.10719036856400115, 0.2063930228884731, 0.16261622336293968, 0.13386943590428146, 0.14962820815188543, 0.13904588456664765, 0.12325309057320867, 0.08078884240239859, 0.1419934813997575, 0.1063778093084693, 0.12911188762102807, 0.19617459763373646, 0.3239205942622253, 0.10997071330036436, 0.17273710242339543, 0.15371805083538803, 0.12088526120143277, 0.2044986073992082, 0.16166870349219867, 0.08111654088965484, 0.18488373421132565, 0.1362551243177482, 0.08460511333708252, 0.12655144929885864, 0.09932644625327416, 0.08288344607821532, 0.1454625188239983, 0.08068197992231164, 0.12118339591792651, 0.062331617809832096, 0.0871270244408931, 0.24768164807132312, 0.09149062207766942, 0.12070288455912045, 0.16821644428585256, 0.12713501655629703, 0.2521669002515929, 0.07454475960029022, 0.155876009325896, 0.1431768193308796, 0.1251008499945913, 0.1568945311009884, 0.14895283510642393, 0.10554293982152428, 0.18579155978347572, 0.07226160461349146, 0.16934621866260255, 0.10708296325589929, 0.1457181501069239, 0.23415646382740565, 0.16775930167308875, 0.1529858029846634, 0.09964558162859508, 0.11889848352542945, 0.10542537684419326, 0.14343549045068876, 0.2265479556683983, 0.09216610368873392, 0.12605618658874715, 0.07720316480845213, 0.08426774572581053, 0.14287928172520228, 0.15092606922345503, 0.22193113554801258, 0.33601249541555134, 0.49506463216883795, 0.8939554478440965, 2.12440824508667, 3.330835908651352, 7.828133225440979, 13.382620453834534, 21.903174672807964, 32.43935700825283, 35.68131698880877, 52.244821889059885, 65.18397617340088, 53.24208641052246, 64.34482138497489, 72.08676133837018, 67.21706077030727, 67.32543877192906, 53.56511163711548, 50.32513189315796, 48.54109157834734, 46.31277649743216, 39.03172097887312, 37.36190904889788, 23.983659880501882, 21.283760138920375, 29.392724786485942, 40.06104448863438, 41.124389852796284, 39.11575944083077, 47.2967769077846, 42.62314060756138, 36.254592009953086, 25.565524986812047, 11.632959825651985, 2.4483584506171088, 0.3809041551181248, 0.12530324341995375, 0.2489749900996685, 0.09823770967445203, 0.20780832480107034, 0.17920844017394952, 0.28665976652077263, 0.16291213248457226, 0.15952595775680883, 0.21149583693061555, 0.30157024785876274, 0.14616588822432927, 0.09714096638240985, 0.10482011003685848, 0.1756490354559251, 0.11743691909526076, 0.17203658287014278, 0.13594987855425902, 0.12467749842575618, 0.1405178170119013, 0.15732941776514053, 0.13667654884713037, 0.2575966188950198, 0.11585220055920736, 0.17592844260590418, 0.10016695436622415, 0.18643072620034218, 0.13775954501969473, 0.21645150386861392, 0.10006273817270994, 0.13820764954601014, 0.14407761528023652, 0.08731250877359084, 0.19683376726295265, 0.10603985137173108, 0.09650019183754921, 0.12202237732708454, 0.14267791967306817, 0.12313934096268245, 0.13259433289723738, 0.12649070684398922, 0.2926350544605936, 0.12773021390395506, 0.12491005951804773, 0.1066487483414156, 0.23312764189073018, 0.1072736790935908, 0.1243490603353296, 0.07463803102395364, 0.10827970903898988, 0.16214894343699726, 0.11865943563835961, 0.10548530505704028, 0.15956641201462063, 0.10183719545602798, 0.09454372432082891, 0.15595699926572187, 0.11578498488026005, 0.20621638665241854, 0.1467960708375488, 0.15854322191859993, 0.12742340750992298, 0.134775239442076, 0.17276138040636266, 0.1220997574606112, 0.11969688854047231, 0.13781027229768888, 0.15727050735482148, 0.11180086473801307, 0.14334261257733616, 0.11744097673467227, 0.17198965538825306], [0.05598612794918673, 0.06296908110380173, 0.04302364940355931, 0.003048007293338222, 0.0670535701460072, 0.06695212237536907, 0.026669669630272046, 0.005196150350717029, 0.033811206596770456, 0.031319856710199795, 0.02391124327134873, 0.02320917835459113, 0.009648416823308383, 0.05920021941087075, 0.06345476968480007, 0.06333847556795393, 0.01882017127770398, 0.0702563232875296, 0.040882711963994164, 0.027219712168776562, 0.03678476078701871, 0.03707211697474122, 0.037530850752123764, 0.013972190391671444, 0.04146170589540686, 0.03057641303166747, 0.04935939210866179, 0.01881053438410163, 0.030814650069390024, 0.05191439197265676, 0.07376272763524737, 0.04317187198570796, 0.06071131689740079, 0.018073640264836804, 0.07219520317656652, 0.021793579582923224, 0.042608993260988166, 0.03713897981547883, 0.04475083315212812, 0.04484620464167424, 0.05714709458074399, 0.059227109753659794, 0.05237116139116032, 0.01475310362210231, 0.027372384244310002, 0.04741673617224608, 0.008166431881753462, 0.024425476124244075, 0.0153230153622904, 0.04535327046843512, 0.03768686970163669, 0.04205535279054727, 0.07561719098261424, 0.03435024499361004, 0.03439807831974966, 0.05186759001974549, 0.015896465662600737, 0.024819596404475824, 0.028000839985907078, 0.017417240754834244, 0.0068352466831648985, 0.028616651227431636, 0.06694660588566746, 0.06211544333824089, 0.3034158359680857, 0.2882880877171244, 0.6832238584756851, 0.5902406222053936, 1.908188773053033, 2.4242870679923465, 6.171155486788068, 12.390878881726946, 21.969559499195643, 27.444123336247035, 33.777496678488596, 52.832906995500835, 63.951442173549104, 62.02514444078718, 64.91730431147984, 57.28843934195382, 71.49237768990653, 75.83092321668352, 76.93588829040527, 74.34406430380685, 68.29434422084263, 77.99455056871686, 80.93351350511823, 76.97219262804303, 69.48528630392892, 65.21199825831822, 61.77261216299874, 56.747866017477854, 49.76150791985648, 42.91841472898211, 45.595458371298655, 53.66873012270246, 49.45363324029105, 51.23389026096889, 60.48069190979004, 59.098584038870676, 66.67888110024589, 55.2659090587071, 42.953339849199565, 23.3141644682203, 7.043139210769108, 0.13406363262661866, 0.18552904815546103, 0.005361615355858313, 0.048243358066039424, 0.04478575395686286, 0.028774397048567022, 0.022215826836015497, 0.032031365138079436, 0.049010988125311475, 0.027983291373987283, 0.02245744128179337, 0.02006635851492839, 0.10244581422635488, 0.0257970888633281, 0.030970204222415174, 0.041847911064646075, 0.020756187748962214, 0.029854190535843372, 0.021794614348826662, 0.03933162840881518, 0.024925749815468277, 0.028113471709990075, 0.019483010085033517, 0.010668327898851462, 0.02202352661905544, 0.04769372773755874, 0.019867356068321636, 0.022569940691547732, 0.040446000040641854, 0.09256186602371079, 0.039907898022128005, 0.03961649437301925, 0.10883508316640343, 0.05624385590531996, 0.06811261403241328, 0.03294473434133189, 0.04512618515374405, 0.06929514450686318, 0.0511103686876595, 0.04256198435489621, 0.034926141412662606, 0.04687786401648607, 0.01918904496622937, 0.007963710215075739, 0.021198044664093425, 0.07302545184003455, 0.0972308994137815, 0.023230104374566247, 0.004586481971533171, 0.015398168204618352, 0.05121938551643065, 0.032205331338835616, 0.009710309395034398, 0.0469336735217699, 0.07717915145414216, 0.04235179116949439, 0.01434840158825474, 0.003600409861454474, 0.1380404992295163, 0.0569489419992481, 0.026563122668968778, 0.03600464229072843, 0.05703673764531102, 0.022616783356560127, 0.026593122398480773, 0.040856093035212586, 0.01391796865833125, 0.045195612856852155, 0.04268442599901131, 0.07502088762287583, 0.025935669462861757, 0.03023276218612279, 0.019127433986536095, 0.01820357463189534, 0.046948645396956375, 0.0322765232329922, 0.031150850600429943, 0.043393471344773255, 0.05329617764800787, 0.0338126383056598, 0.02944332401135138, 0.07058727195752518, 0.011187345271797051, 0.024321862130558917, 0.0408511159808508, 0.058406089166445394, 0.06249746533909014, 0.1095928642898798, 0.04460317036136985, 0.016055475255208354, 0.06820895921971117, 0.03267808025702834, 0.04943585961258837, 0.04238085960969329, 0.02985135086679033, 0.03387568099424243, 0.032244448882660696, 0.03149298152753285, 0.05247221900416272, 0.04601288114541343, 0.06104551575013569, 0.0632849255842822, 0.02108367589036269, 0.04152001580223441, 0.01912771557856883, 0.028089914670480148, 0.028597536895956312, 0.06156362473432507, 0.02887529520584004, 0.04853698731000934, 0.023925207522032515, 0.028294299596122334, 0.03395063875775252, 0.032295647742492814, 0.010500873089767992, 0.017511670777041997, 0.010089197412266262, 0.05845450942537614, 0.03344177142051714, 0.024428992631978223, 0.07962064258754253, 0.03256997266518218, 0.012685141775624027, 0.03386284989703979, 0.05940212429101978, 0.019041755369731357, 0.036537312636418004, 0.04205450462177396, 0.044072057253548076, 0.028765277537916387, 0.031855400651693344, 0.026879784784146717, 0.09867188387683459, 0.06099025585821696, 0.008942140748591294, 0.18687444739043713, 0.2838994046407086, 0.7170910611748695, 0.8836941527468818, 2.13096929873739, 3.2999181619712283, 7.846795218331473, 14.203202707426888, 24.674151011875697, 32.73185185023716, 41.20673990249634, 63.87395586286272, 74.98838465554374, 74.80862780979702, 76.82809393746513, 70.14603219713483, 83.5748781476702, 88.28084441593715, 87.30305916922433, 84.3399303981236, 78.57362038748605, 87.71976348331997, 91.51306302206856, 85.92935167040143, 78.88781097957066, 74.38812977927071, 71.7699373790196, 66.33946854727608, 58.49142265319824, 49.90989364896502, 54.821450165339876, 64.03718989236015, 60.30521515437535, 61.796437535967144, 69.4407205581665, 70.06407819475446, 76.58996527535575, 66.45384284428188, 57.02619695663452, 31.715104579925537, 11.926595040730067, 1.0764559635094233, 0.031346984540245364, 0.07068276897604976, 0.01549791794137231, 0.03054020640307239, 0.024104702086853128, 0.05428193296704974, 0.06357445647673947, 0.03525358884196196, 0.04222135638285961, 0.017469581249835234, 0.04071880843756454, 0.042525329893188815, 0.026921194079997282, 0.034317766914942434, 0.007346073714351016, 0.028701705592019216, 0.06990332222942795, 0.05228013591840863, 0.05177330757890429, 0.03560646776376026, 0.013664388247499508, 0.05896145650850875, 0.05950068150247846, 0.017903699473078762, 0.021852325448500257, 0.06433312648109027, 0.012196013022081127, 0.04376258082421763, 0.09148039655493838, 0.0021282855180158678, 0.04251453440104212, 0.11601416686815874, 0.02368327246845833, 0.0334252728415387, 0.016886677260377576, 0.08358304282384259, 0.024609956225114207, 0.05166337133518287, 0.08588124093200479, 0.0411879746908588, 0.03728399971233947, 0.03909842949360609, 0.04672375514305063, 0.05682447153542723, 0.025128535094804, 0.020652928289824297, 0.05133371188172272, 0.013294741029052861, 0.01034799830189773, 0.0039054478235941914, 0.07476022839546204, 0.03067043423652649, 0.08444105035492352, 0.03840321947687438, 0.024508578004315495, 0.07348938658833504, 0.050710311226014576, 0.04393896600231528, 0.08891113049217633, 0.02403456361831299, 0.027986940196050063, 0.0505962393113545, 0.045284528085695844, 0.02199167788161763, 0.05497010996831315, 0.04688235252563443, 0.029810570912169557, 0.05031429444040571, 0.018389460996591618, 0.030589379835873842, 0.1682012586721352, 0.1845908106437751, 0.11322242274348225, 0.07592207033719335, 0.1364433906440224, 0.1371864407722439, 0.14804408672664846, 0.10373040993830987, 0.12562192417681217, 0.14685453341475554, 0.1386684426771743, 0.11316723070506539, 0.07457740392003741, 0.17249360334660324, 0.2293872040297304, 0.13660486840776034, 0.14149946719408035, 0.16924255208245345, 0.13132323324680328, 0.17525099324328558, 0.2529647488679205, 0.24939454187239918, 0.2128794512578419, 0.11017758505684988, 0.12057625635394029, 0.14870044722088746, 0.13542564239885124, 0.09090971467750412, 0.08953323853867394, 0.18088249463055814, 0.15000586717256478, 0.11333250826490776, 0.11372476257383823, 0.11395718795912606, 0.16239047476223537, 0.0701334745224033, 0.13188884646764823, 0.2101473978587559, 0.13004456114556107, 0.10718228042657886, 0.18425288663378783, 0.12348448458526816, 0.16816997820777552, 0.08871134264128548, 0.07879038035337414, 0.1445764470845461, 0.09747113473713398, 0.09041094394134623, 0.08597033257995333, 0.13440456933208875, 0.20892192290297576, 0.0648052240056651, 0.11732732211904866, 0.16322872335357325, 0.09163364368890013, 0.1832834772233452, 0.1441398233707462, 0.0984172025429351, 0.10996398901832954, 0.10641719148095165, 0.14935558635209287, 0.2480560636946133, 0.2134488099919898, 0.22288890129753522, 0.4081611782312393, 0.6301388612815312, 1.2827825035367693, 1.2952043626989638, 3.2666382449013844, 5.651326009205409, 11.254236102104187, 18.958517687661306, 30.675834723881312, 39.713599818093435, 49.696695123400005, 73.87697860172817, 84.86388710566929, 84.88046550750732, 87.40458624703544, 80.84608432224819, 93.6354319708688, 98.82137284960065, 97.68427235739571, 97.87653596060616, 91.56277738298688, 98.33474881308419, 104.74904087611607, 99.85212421417236, 89.5120096206665, 86.27130726405552, 84.8316822052002, 77.2511489050729, 68.91875798361642, 62.400597299848286, 66.81916522979736, 74.54235199519566, 71.9989013671875, 73.8771870476859, 80.74587740216936, 79.35899611881801, 86.11769648960659, 76.96880885532924, 64.30479281289237, 35.62060362952096, 13.83990398475102, 1.326323281441416, 0.2659567945769855, 0.20894837219800266, 0.1304716853690999, 0.09115695248224906, 0.14307412984115736, 0.10936342445867402, 0.1469089790646519, 0.12544588505157403, 0.13200822791882924, 0.1092682463516082, 0.10396878607571125, 0.1363818339471306, 0.08461687913430588, 0.07774724811315536, 0.1185749444578375, 0.17153963739318506, 0.12202722206711769, 0.11150182078459434, 0.08599883105073657, 0.10940322732286793, 0.09811967172260795, 0.08500551006623677, 0.1268402880855969, 0.10803443220044885, 0.22816375110830578, 0.1383001881518534, 0.1443662912185703, 0.1837340109050274, 0.1589596252888441, 0.1000964477924364, 0.12798000978572027, 0.24039724894932338, 0.10273720430476324, 0.15365668412830147, 0.11672805356127874, 0.16819375407482895, 0.17225279126848492, 0.1495835876890591, 0.19185014468218597, 0.1350792231304305, 0.11738573041345392, 0.1346165029598134, 0.1279383205941745, 0.12790575091327938, 0.1329485960304737, 0.16652645782700606, 0.18712721525558404, 0.10727300055857215, 0.07114549593201705, 0.09532849078199693, 0.33370216510125567, 0.12550209489251885, 0.16376157690371784, 0.15084136091172695, 0.13096846799765313, 0.14062989742628165, 0.17964145408145019, 0.20148007651524885, 0.15539853780397347, 0.11071743430303675, 0.15952920115419797, 0.10359382083905594, 0.13667011633515358, 0.15550624845283373, 0.15705697238445282, 0.07917213094021593, 0.13775712943502835, 0.10761298052966595, 0.13877822964319161, 0.07551348369036402], [0.04038701838414584, 0.06603510943906647, 0.038968140592000315, 0.05253582826948591, 0.05552726185747555, 0.006732374413071999, 0.01933014632335731, 0.05564799020066857, 0.06057280754404409, 0.00822064682974347, 0.038724152969994714, 0.04863478456224714, 0.03766037630183356, 0.023840215921934162, 0.0164081048153873, 0.03835934540256858, 0.022957469004073312, 0.04454567808923977, 0.1353711967489549, 0.044035032990255525, 0.07254005502909422, 0.04174911975860596, 0.0522850722606693, 0.06028322236878531, 0.023335611480953436, 0.02990094499130334, 0.03317032348630684, 0.024184711543577056, 0.011865379022700446, 0.038746748186115704, 0.0037381414440460503, 0.014326277953971709, 0.06046988056706531, 0.036883962606745105, 0.08495768691812243, 0.042593522662562985, 0.00919034970658166, 0.048444187468183894, 0.02385496048788939, 0.00176873362839355, 0.013936926078583513, 0.0176694573102785, 0.03705222911334463, 0.01935188488901726, 0.017045149113982916, 0.08310276216694287, 0.054065558327628035, 0.025354609392317276, 0.01179985374411834, 0.03469534790409463, 0.014246253230209862, 0.07993644635592188, 0.007800076406316033, 0.00436933889120285, 0.040100476438445706, 0.028355637465470603, 0.05847377303455557, 0.03835745568254164, 0.17519523123545305, 0.47640768757888247, 1.0390665126698357, 2.402693803821291, 3.4898363138948167, 2.2089643478393555, 2.691242069005966, 5.727648496627808, 7.148360558918544, 10.00623367513929, 19.644961493355886, 25.40892822401864, 35.812901973724365, 40.72328771863665, 55.44925117492676, 62.828766141619, 60.71642344338553, 68.77734824589321, 72.96775817871094, 72.21624796731132, 74.48608548300606, 53.03020804268973, 60.177854674203054, 68.49700232914516, 71.61918231419155, 54.670570032937185, 52.105249949863975, 61.068440028599326, 69.26809256417411, 54.27285514559065, 57.21447229385376, 64.30203437805176, 60.288344928196494, 60.02297932761056, 61.43101787567139, 64.57067258017403, 64.13693823133195, 62.167519978114534, 59.89446544647217, 64.51772035871232, 64.25946276528495, 59.16796875, 60.12467316218785, 64.061432157244, 70.46152905055455, 59.97747557503836, 46.283677441733225, 25.745128972189768, 5.7424668329102655, 1.3885704555681773, 0.11209218017756939, 0.027380450329344188, 0.10120762352432523, 0.01667865877971053, 0.059658250904509, 0.04712361582954015, 0.053739142271557024, 0.06123106793633529, 0.012517051688129348, 0.03722127593521561, 0.016330840032813803, 0.03110120558579053, 0.045700154533343654, 0.030509248242846558, 0.007731577448014702, 0.0432032813717212, 0.013982091913931072, 0.01643908842067633, 0.018606503993006687, 0.01447524522830333, 0.012179308338090777, 0.03253811205338154, 0.010534003410222275, 0.014982375515890973, 0.04883932555094361, 0.047304238458829265, 0.0866158636552947, 0.0421319967135787, 0.005190237342113895, 0.05090279464742967, 0.05072889630017536, 0.038659987305956225, 0.012189594928973486, 0.07616707576172692, 0.018915795521544557, 0.07761798719210283, 0.03464126527043326, 0.024496535704072033, 0.08365204304988895, 0.015568110692713941, 0.03653774689882994, 0.02302777541003057, 0.03215194420356836, 0.04585658399654286, 0.044881495247994146, 0.06253336662692682, 0.01494640128553978, 0.039309586198734384, 0.01986877929552325, 0.0664072519700442, 0.00424413985040571, 0.033259333710053136, 0.07277539811496224, 0.030731461676103727, 0.04840226757473179, 0.08138448079781872, 0.0690418134576508, 0.03386395251644509, 0.031196834918643748, 0.03721266532582896, 0.0309151682470526, 0.018925452771197473, 0.04964825803680079, 0.006961409667772906, 0.03508526126721075, 0.06198056414723396, 0.04973687810291137, 0.03129664063453674, 0.030239893589168787, 0.0725829859397241, 0.09469055251351424, 0.039414148445108106, 0.05062703462317586, 0.019964259350672364, 0.0228404013573059, 0.07259896543941327, 0.03336356008159263, 0.01685256900132767, 0.00869986812384533, 0.0037213926552794874, 0.03271780848237021, 0.029098947133336748, 0.056089343303548436, 0.036721073490168364, 0.021310854503618817, 0.028315081427405988, 0.02814598032273352, 0.030398711495633637, 0.010250720977117973, 0.01989318959281913, 0.0170556494433965, 0.07563773023762874, 0.04225522545831544, 0.03434489813766309, 0.05839003502790417, 0.04844909327636872, 0.027361475097547685, 0.03232929629406758, 0.015662276086264422, 0.02588092695389475, 0.012211493798531592, 0.04719566946317043, 0.0069598223199136555, 0.02698441658035985, 0.07728184094386441, 0.031091119162738323, 0.0178236560896039, 0.08440254349261522, 0.03523351099076016, 0.02012703481263348, 0.027596344905240194, 0.03727166733837553, 0.021662754638652717, 0.04174363041030509, 0.05212558260453599, 0.03765631866242204, 0.030361500635210956, 0.0047697101752938965, 0.035541362328720946, 0.026711028035996214, 0.0324163421589349, 0.11135939628418003, 0.026470158282401304, 0.006030912120227835, 0.06469735729375056, 0.12858440806823118, 0.19018330983817577, 0.5885498215045247, 1.157256999186107, 2.5208922156265805, 3.8418578931263516, 2.7151141251836504, 3.117931595870427, 6.545990824699402, 7.595823679651533, 12.269639764513288, 21.62332555225917, 30.51538692201887, 41.55694648197719, 48.21041291100638, 63.15799263545445, 74.13701493399483, 71.0234020778111, 79.0647051674979, 82.65374156406948, 81.06460516793388, 83.53668390001569, 61.88812596457345, 68.81224904741559, 78.50699411119733, 80.50030721936906, 67.58933135441372, 65.02819061279297, 70.49727753230503, 77.24411732809884, 65.25818293435233, 69.5304148537772, 75.12232507978166, 69.45274094172886, 68.30257088797433, 71.6704808643886, 72.1870516368321, 72.11407470703125, 70.30948856898716, 67.16690172467912, 71.843720299857, 72.62959630148751, 67.12234987531389, 68.00897475651333, 71.05042362213135, 78.46299116952079, 73.01433890206474, 59.13501344408308, 34.71977315630232, 9.953133804457527, 2.908710479736328, 0.26395606622099876, 0.057548665175480504, 0.033174547366797924, 0.010328811027907898, 0.05991087627730199, 0.07801718291427408, 0.02154357165896467, 0.039239249258701286, 0.05513206270656415, 0.017415145777964165, 0.02313467181686844, 0.04919202466096197, 0.03800250383626137, 0.019968942938638583, 0.04125261872208544, 0.07449329950447593, 0.03075794150520648, 0.04145552783406206, 0.013957881784465696, 0.02792505780234933, 0.029542437621525357, 0.033782450282680135, 0.03351861551137907, 0.07449397125414439, 0.041290501332176585, 0.05301541342799153, 0.08007933226014886, 0.036792804819664786, 0.06853237615099975, 0.014969875204509922, 0.0245416345340865, 0.07670155779591628, 0.05351681348734668, 0.031637499308479686, 0.0037899827917239493, 0.03150641652090209, 0.03058133241055267, 0.06213533798498767, 0.03440037176811269, 0.02850874719609107, 0.0032717529434843785, 0.01574727107903787, 0.030334169244659797, 0.03532793253128018, 0.012734841073064931, 0.04551892461521285, 0.03335155340443764, 0.06922630034387112, 0.02890841450010027, 0.039177027597491226, 0.013734519930689462, 0.021884854417294264, 0.08888075926474162, 0.02673320595308074, 0.03647672963727798, 0.07199372577347926, 0.07081326483083622, 0.004216280474793166, 0.025192118915063993, 0.06800934100257498, 0.06976907407598835, 0.03508196358702012, 0.03281909340460386, 0.04152404969292028, 0.05332264390641025, 0.05886050406843424, 0.05388723932472723, 0.045536742944802554, 0.09686829708516598, 0.23278633877635002, 0.09904028767985956, 0.19651311875454017, 0.11855775038046495, 0.09121922842626061, 0.10125250861580883, 0.15070937227989945, 0.15120649417596205, 0.0906273830415947, 0.08837790374777146, 0.1089976601568716, 0.19217852848981107, 0.051244338641741445, 0.08220497212771859, 0.15014276839792728, 0.09232797500278268, 0.08291606325656176, 0.3159695751965046, 0.11286097392439842, 0.2061018363705703, 0.07776454397078071, 0.11790449757661138, 0.12618210911750793, 0.09118296072951385, 0.14945907651313714, 0.1631493754684925, 0.13575496258480207, 0.21221407981855528, 0.07832619454711676, 0.13783274537750653, 0.08537778151886803, 0.08706616663507052, 0.24085175884621485, 0.12749690642314299, 0.10189302531736237, 0.15950425820691244, 0.16656398081353732, 0.11988492416484015, 0.20002829656004906, 0.06986445574355976, 0.15246934284056934, 0.07774595211126975, 0.14430725867194788, 0.09460796123104435, 0.18018261290022305, 0.10988918053252356, 0.09042561386844941, 0.08897436995591436, 0.08628991578838655, 0.12902499442653997, 0.1828636404659067, 0.12535820475646428, 0.15756406874528953, 0.154477453657559, 0.1241703884942191, 0.12660315366727964, 0.20200409553945065, 0.3335926224078451, 1.1725241456712996, 2.1782646008900235, 4.176279902458191, 5.796704471111298, 4.537436842918396, 5.5442885756492615, 9.534020202500479, 11.003392236573355, 17.535841022218975, 28.24931880405971, 38.747355529240195, 50.8924731527056, 56.014976978302, 72.27115263257707, 81.49273232051304, 83.15632561274937, 89.04484054020473, 95.16118689945766, 93.69948046548026, 93.96644415174211, 72.02124677385602, 79.33353097098214, 89.67787701742989, 92.8839773450579, 77.74361637660435, 74.46067592075893, 80.90906279427665, 87.15222767421177, 74.82567868913922, 78.71730913434709, 84.05654811859131, 79.58761269705636, 80.48951666695731, 81.91312612806047, 84.54005241394043, 82.80334322793144, 81.47160979679653, 78.49767657688686, 81.72239112854004, 82.71427427019391, 79.2123613357544, 77.82903058188302, 81.61818204607282, 88.83055809565953, 83.66054248809814, 68.06470625741142, 38.88398838043213, 11.263757739748273, 4.482181293623788, 0.7481426149606705, 0.12743824028543063, 0.15145513654819556, 0.1111979049497417, 0.18516447128994123, 0.13921805604227952, 0.1577252886657204, 0.1333968091223921, 0.16498717399580137, 0.09601620637944766, 0.17548918617623194, 0.16821934841573238, 0.12375522005770888, 0.09390630852431059, 0.11773194612136909, 0.1705828487340893, 0.08556587142603737, 0.09823564014264516, 0.08133697656116315, 0.12834609299898148, 0.14729412911193712, 0.09094026910939387, 0.10136931163391896, 0.1623763476631471, 0.12338039731340748, 0.1306831847344126, 0.15146956220269203, 0.11749014338212353, 0.10653546692005225, 0.09919553649212633, 0.13491955026984215, 0.22196761359061512, 0.10907824976103646, 0.11911640183201858, 0.1832441629043647, 0.10187829432210752, 0.104870158779834, 0.17410878810499394, 0.21382209924714907, 0.12810111471584865, 0.09536971856973, 0.14485632920903818, 0.16302263869770936, 0.14228601141699723, 0.11483161603765828, 0.17377437890640327, 0.11376109812408686, 0.17269575249935898, 0.159516431125147, 0.14976208311106476, 0.08426129964313336, 0.1365207572068487, 0.2299987812127386, 0.11892364360392094, 0.1439153639865773, 0.20918656513094902, 0.16554719608809265, 0.06635248740868908, 0.0919159006859575, 0.32341296864407404, 0.1370755952915975, 0.08097286788480622, 0.08951862967972245, 0.10250104697687284, 0.1629862692207098, 0.18598775139876775, 0.17860201985708304, 0.07670037035963365], [0.07250770247940506, 0.03958510195038148, 0.037378088770700355, 0.015181496706125992, 0.05269826276760016, 0.02005614317022264, 0.0045207726403272575, 0.042997247605983696, 0.09865342772432736, 0.025627514480480125, 0.038790696899273565, 0.03351617278531194, 0.047686474198209386, 0.014671426665570055, 0.03584985488227435, 0.02359311721686806, 0.011603009887039661, 0.04205963773919003, 0.040821090806275606, 0.05232953666044133, 0.08193760218897037, 0.02141579842594053, 0.014478892354028565, 0.058264641756457944, 0.016012712281995585, 0.05055270789723311, 0.04250757602442588, 0.02297191840729543, 0.07100190435137067, 0.09101581041302, 0.021047540507944565, 0.028478138481399844, 0.006595516020232546, 0.036845727158444266, 0.07048589882573911, 0.0475385196373931, 0.02697353627133582, 0.010545032996950405, 0.0431485100250159, 0.024338715244084597, 0.053210824728012085, 0.0723053633368441, 0.037423621863126755, 0.07302053246114935, 0.014633674673470003, 0.03203015734574624, 0.051371533423662186, 0.03787506478173392, 0.025180856930091977, 0.02012774727440306, 0.04218103443937642, 0.037165622492986064, 0.04911415258954678, 0.022915577948359505, 0.0474633650987276, 0.055371738238526244, 0.16312770305999688, 1.0537352455513818, 3.2676222835268294, 13.039019005639211, 13.6834522656032, 17.88609450204032, 22.165587288992747, 22.3940075806209, 23.90014774458749, 26.901988404137747, 36.89557375226702, 40.31757892881121, 46.75324365070888, 59.237138066973, 61.869206019810264, 69.72731290544782, 57.78462757383074, 62.17139707292829, 61.335813658578054, 55.97982256753104, 47.25516414642334, 45.949920722416465, 47.79482725688389, 35.373404094151084, 41.09400538035801, 34.83276128768921, 34.927187306540354, 17.83110645839146, 23.88060072490147, 26.432806083134242, 41.616648878370015, 29.78510693141392, 28.120090995516094, 34.50741536276681, 32.55894940240042, 44.84030730383736, 46.1974641936166, 46.519415923527305, 39.07305581229073, 44.38567624773298, 45.94327824456351, 48.456500734601704, 47.051189354487825, 42.253030913216726, 42.195663111550466, 50.338917119162424, 56.899767535073416, 64.37438596997941, 60.53202520098005, 60.06902503967285, 45.55988359451294, 23.794448273522512, 10.875211000442505, 2.6821425344262804, 0.574921147099563, 0.1021312250356589, 0.016133927474064485, 0.10601038259587117, 0.005227768810332886, 0.07095064781606197, 0.020149728416332176, 0.032509810357753716, 0.03620685251163585, 0.01682498655281961, 0.04704699904790946, 0.03059575127969895, 0.013682200639907802, 0.01682669815740415, 0.011674187362327107, 0.07222858709948403, 0.052881216164678335, 0.031060378133718456, 0.023604876228741238, 0.010264401091262698, 0.016478273818003278, 0.03844062711245247, 0.08654311113059521, 0.011655603984503873, 0.03436511169586863, 0.06083187221416405, 0.02469872896160398, 0.015942948704053248, 0.018651531576844196, 0.020594874529966285, 0.032529959455132484, 0.05814851727336645, 0.04006203403696418, 0.06819928331034524, 0.03307216661050916, 0.046296837872692516, 0.05704175880444901, 0.08125473811690297, 0.007030862391859825, 0.01883919400695179, 0.0471074768741216, 0.04009016949151244, 0.09283524099737406, 0.04851173223661525, 0.014680551265233328, 0.08443818693714482, 0.04787173800702606, 0.05250286843095507, 0.03039413138425776, 0.020579714361312132, 0.05365444413785424, 0.02765240886115602, 0.035721133396561654, 0.043288057536951134, 0.028426062615056123, 0.03917437791824341, 0.01897882972843945, 0.04126199607604316, 0.02637951448559761, 0.021451175545475314, 0.016529253850291883, 0.0378495688284082, 0.04191266366147569, 0.03909743883247886, 0.07740727492741176, 0.041221765734787495, 0.023939570412039757, 0.01881532823400838, 0.03567210245611412, 0.1133784790124212, 0.042789873733584366, 0.0530023210948067, 0.046115594383861334, 0.04989011166617274, 0.020406604811017002, 0.07342225911894015, 0.06629571438367877, 0.04221714607306889, 0.04323669243603945, 0.022979908157140017, 0.04266149830073118, 0.0181071293606822, 0.0149888131168804, 0.01808365374537451, 0.04999011754989624, 0.039468041088964255, 0.11665004917553493, 0.03932349955929177, 0.017276117345318198, 0.07285903434136085, 0.0239275501641844, 0.013691353229140597, 0.06281117921961205, 0.035182922812444825, 0.03389444927285824, 0.04518187591539962, 0.01795668457634747, 0.012397949284474765, 0.051566035486757755, 0.04078009711312396, 0.04696677924532976, 0.014647023153624364, 0.007472809636965394, 0.027098346002666012, 0.014366976484390242, 0.015656133648008108, 0.13592120366437094, 0.014768974556188499, 0.042222570960542986, 0.021431211348889128, 0.0958868165367416, 0.02191102212028844, 0.0442657790013722, 0.017741853604093194, 0.0354164779585387, 0.0198175465089402, 0.03678243001922965, 0.04602626524865627, 0.06890946520226342, 0.07385356990354401, 0.02578336209990084, 0.08232095411845616, 0.2842797642307622, 1.971172021968024, 3.8513282878058295, 14.853674820491246, 15.863567692892891, 20.4719169821058, 25.65576819011143, 24.56437121118818, 26.63783700125558, 30.07285267966134, 40.64371000017439, 46.407209464481895, 56.605768408094136, 68.05367251804897, 70.1041623524257, 79.09747982025146, 67.24612508501325, 71.2298469543457, 71.1327736718314, 66.91552979605538, 56.49736956187657, 56.670741013118196, 56.59543643678938, 44.222407477242605, 48.53604023797171, 42.10410322461809, 41.167058740343364, 26.337744304112025, 30.754391057150706, 37.28696230479649, 57.398182664598735, 38.32912608555385, 36.54533243179321, 44.43578665597098, 41.565326009477886, 53.04885005950928, 54.86442129952567, 55.112989630017964, 47.69614199229649, 52.43442780630929, 53.22801283427647, 59.81748635428292, 56.22624737875802, 52.33409581865583, 50.5036415372576, 58.028297424316406, 66.6053969519479, 70.75907175881522, 70.06771210261753, 71.097414289202, 58.30362674168178, 30.780863693782262, 14.327600649424962, 4.1407824243818006, 0.710919160928045, 0.10725324161882911, 0.00825473727724914, 0.0885231780952641, 0.024822040826880505, 0.06601764394768647, 0.08579287531652621, 0.04832109782312598, 0.08039491211197206, 0.07127828523516655, 0.05269627465999552, 0.026370810577645898, 0.05933915624128921, 0.033839094386036904, 0.009988099935331514, 0.03972436108493379, 0.06555819431585924, 0.04724901249366147, 0.040249662540320835, 0.07364440469869546, 0.06405386860881533, 0.09960875074778285, 0.027397021850837127, 0.03869530166100178, 0.038573392666876316, 0.043398770703268905, 0.05317504218380366, 0.1240111906081438, 0.02272062635581408, 0.050789594650268555, 0.060307337503348074, 0.052321713151676316, 0.059930906631052494, 0.017637505096250346, 0.015085592566590224, 0.047269256585942845, 0.02244339560690735, 0.12434825966400759, 0.03994179763165968, 0.019938992402915443, 0.05320489772462419, 0.03588517262999501, 0.029970766244722263, 0.025824309991938726, 0.0437447217825268, 0.03145811839827469, 0.02550732726896448, 0.00831932108849287, 0.007899588655813463, 0.046050909640533585, 0.08007285225072078, 0.0729576051235199, 0.015602524292522242, 0.04710478987544775, 0.013892364987571324, 0.04222453531942197, 0.10255727038851806, 0.00290936668586385, 0.05336030259994524, 0.04419356591201254, 0.04258844722062349, 0.02793428927127804, 0.030279679489987235, 0.016866942069360187, 0.07654219027608633, 0.04333945317193866, 0.13791530951857567, 0.10401985262121473, 0.1603026632219553, 0.2014918558831726, 0.2624402461307389, 0.13614550020013536, 0.1503450803990875, 0.1969912959528821, 0.16287987492978573, 0.13027827574738435, 0.13109888242823736, 0.16573863795825414, 0.08777699992060661, 0.12502024003437587, 0.2021926332797323, 0.21927171253732272, 0.04455732175015977, 0.123569002907191, 0.12678011560014316, 0.10383845985467945, 0.19640121475926467, 0.08262427962784256, 0.1876003984361887, 0.1409586612135172, 0.1295238940843514, 0.10084865814340965, 0.13485522515007428, 0.16547265223094396, 0.15982639949236596, 0.16859427972563676, 0.14134780104671205, 0.05811976095927613, 0.08033294150871889, 0.12285088215555463, 0.16209372425717966, 0.16695800609886646, 0.10204567534050771, 0.14131232723593712, 0.1126460140304906, 0.1083508398649948, 0.25267884135246277, 0.10678345111331769, 0.17216804224465573, 0.1985834783741406, 0.1384931227990559, 0.1621958166360855, 0.16551792408738816, 0.12080302275717258, 0.12779229985816137, 0.12721551795090946, 0.2137130315282515, 0.17813578487506934, 0.1721211690455675, 0.13055448021207536, 0.13841468415090016, 0.23133465381605284, 1.3309506731373923, 3.734261129583631, 7.499443479946681, 19.552369798932755, 22.98358654975891, 28.591736452920095, 34.77783925192696, 33.94649076461792, 37.04925748280117, 41.17566408429827, 50.11502531596592, 56.514090401785715, 64.99876499176025, 78.92013399941581, 78.94174289703369, 89.93977546691895, 78.97724124363491, 80.82216167449951, 79.0119127546038, 75.68661608014787, 65.68717861175537, 64.38413429260254, 68.36706406729562, 54.365377358027864, 58.61165428161621, 52.75063337598528, 53.610205445970806, 33.082030636923655, 37.935295241219656, 43.63875184740339, 59.35822432381766, 45.44064555849348, 42.68869686126709, 52.257484980991904, 49.78792497089931, 62.78220626286098, 64.01847839355469, 65.16044957297188, 58.86552061353411, 63.84390490395682, 64.50522749764579, 65.62754222324916, 63.66327258518764, 61.64593260628836, 59.610485621861045, 70.14185632978166, 75.70099885123116, 84.07662841251918, 83.11806883130754, 79.46811757768903, 66.02112293243408, 36.49838692801339, 16.825217485427856, 5.630161796297346, 1.31642980660711, 0.24487867419208798, 0.10738805974168436, 0.22644571401178837, 0.12121506993259702, 0.18832700087555818, 0.16508659294673375, 0.10870067894990955, 0.102213205636612, 0.2177137147103037, 0.1566492814038481, 0.12302529279674802, 0.10481178441217967, 0.15719143088374818, 0.14710169658064842, 0.17982307076454163, 0.19521759184343473, 0.13101224707705633, 0.1456945642296757, 0.2070194057055882, 0.1640047367130007, 0.1429374593177012, 0.1841656948838915, 0.1480614436524255, 0.13177026568778924, 0.14983275931860718, 0.15759920328855515, 0.20833978056907654, 0.09872212939496551, 0.19351046559001717, 0.14856887928077153, 0.17289061418601445, 0.09320062531956605, 0.13172990642488003, 0.07818267081997224, 0.10898220312914678, 0.11483293239559446, 0.24797425951276506, 0.06377819340143885, 0.18469605142516748, 0.12665360953126634, 0.12218057098133223, 0.2478604827608381, 0.14926097142909253, 0.15662303566932678, 0.13842085881956986, 0.17052070849708148, 0.14914511836000852, 0.0802365488239697, 0.10864054039120674, 0.1722735408693552, 0.17080573391701492, 0.11014874731855732, 0.11436852945813111, 0.12443610280752182, 0.0953020957697715, 0.10515669054750885, 0.13203492148646287, 0.0998199786990881, 0.20149577781558037, 0.105631129017898, 0.12595238430159433, 0.10847163945436478, 0.10911259720368044, 0.12740795048219816, 0.16756225510367326], [0.04523084578769548, 0.015398466760026557, 0.02603836913060929, 0.028403694708166376, 0.05455314002132841, 0.044849074844803126, 0.05034772925344961, 0.020953787324417914, 0.059237213140087466, 0.005652236145189298, 0.05638468924111553, 0.041728631393717866, 0.07583202195486852, 0.0330198312045208, 0.05263364248509918, 0.038923353888094425, 0.015033537056297064, 0.023919093921514492, 0.05202975310385227, 0.054187660704233816, 0.08575176966509648, 0.05921110311256988, 0.036626679091049094, 0.055076531400637965, 0.03632302109950355, 0.01489646958985499, 0.011145274404303303, 0.06163622119597026, 0.041140935250691006, 0.014311479105214988, 0.0647121968546084, 0.07156805361488036, 0.029573321142899137, 0.018136248691007495, 0.08194856731487171, 0.010697169877987887, 0.037995901690529924, 0.014401719173682588, 0.08435839121895176, 0.06168005455817495, 0.04026417301169463, 0.05406164996592062, 0.08590057918003627, 0.014224100758188536, 0.009796582578149225, 0.07943940588406154, 0.02447628991545311, 0.1245519830180066, 0.06716714333742857, 0.08218642098030873, 0.012678208844070988, 0.039091440582914014, 0.03895465470850468, 0.15593771530049189, 1.0050093744482314, 7.990938203675406, 14.044490218162537, 24.41065447671073, 30.913074016571045, 44.2872758592878, 40.05068472453526, 47.17209495816912, 45.21556908743722, 48.88610437938145, 53.655514648982454, 53.37473794392177, 58.713229996817454, 59.94233158656529, 62.039339610508506, 52.48957218442644, 52.278392110552105, 44.461276122501914, 35.88262019838606, 36.70053781781878, 24.651664904185704, 30.56497621536255, 19.712534461702617, 23.280658517565044, 31.31322077342442, 20.641103880746023, 32.467326981680735, 41.65497514179775, 44.64271443230765, 42.740787506103516, 58.62759344918387, 25.472731794629777, 10.252401403018407, 18.52896441732134, 15.777608054024832, 16.938808373042516, 20.79026780809675, 22.13689817701067, 23.143442017691477, 27.06626292637416, 27.918383053370885, 32.32498618534633, 31.83242491313389, 24.986121654510498, 32.61335727146694, 24.49883927617754, 21.74746033123561, 44.56786496298653, 37.3378335407802, 39.35353027071272, 49.518529415130615, 61.77071530478341, 61.24741867610386, 54.161023889269146, 39.27451883043562, 26.15848078046526, 11.1630905015128, 5.841647590909686, 0.620090626180172, 0.31992809421249796, 0.15768213383853436, 0.015703507266672592, 0.053886207951498885, 0.017915175196581652, 0.01031251176859119, 0.011984394913140153, 0.04828854510560632, 0.02979612150894744, 0.03232087567448616, 0.10857376576002155, 0.04624057374894619, 0.02811206374982638, 0.02122004276939801, 0.0260882906482688, 0.048842361995152066, 0.01561315354358937, 0.031244396830775907, 0.04351017936798079, 0.0031236779427022804, 0.03817509261092969, 0.048990784745131216, 0.026831727541450943, 0.021975415093558173, 0.023482136029217924, 0.05738251230546406, 0.005841365059105945, 0.03383117248969419, 0.050873685495129654, 0.028939644074333564, 0.05579393290515457, 0.024285587648461972, 0.0009028564693705578, 0.021540379151701927, 0.005942506216732519, 0.04298481684444206, 0.0838941986273442, 0.02815127289587898, 0.01074375894053706, 0.059776757045515945, 0.025340936911691512, 0.09183506002383572, 0.02293007993804557, 0.10385900589504413, 0.016525934117713144, 0.019176347879692912, 0.017603330680036118, 0.04436720980863486, 0.031352036233459196, 0.03325862464095865, 0.037642778496124914, 0.004408371194066214, 0.02073326683603227, 0.02986166120639869, 0.03719548821183188, 0.053093153185078075, 0.04272599644692881, 0.01265844566348408, 0.006587706082167902, 0.07344451506755181, 0.051898931552256854, 0.02914437505283526, 0.03583187031160508, 0.07183956261724234, 0.021328574445630823, 0.019007005895088826, 0.054036147227244716, 0.03682438723210778, 0.005380283126474491, 0.03183186227189643, 0.08688875008374453, 0.0334607161182378, 0.013662444244671081, 0.06855229115379707, 0.056151469969855886, 0.03886656050703355, 0.02510379740436162, 0.00673292572277465, 0.02649371532191123, 0.04714100668206811, 0.040489212543304474, 0.08036604044692856, 0.008555968657934239, 0.08182279406381504, 0.04594003362581134, 0.0391902454596545, 0.047146516386419535, 0.026595666904800704, 0.06963494127350194, 0.04939540196210146, 0.04661635662029896, 0.04309990316895502, 0.03053605037608317, 0.04219977557659149, 0.03414677609024303, 0.02355279527338488, 0.05762240836130721, 0.059947110047297816, 0.02144608653283545, 0.01812929709974144, 0.0564562475441822, 0.016799831563340764, 0.05619746107341988, 0.020656924861084138, 0.02917006778131638, 0.05512444954365492, 0.023850017360278537, 0.057223904744854996, 0.0834078790087785, 0.11379656514951161, 0.03701456363445946, 0.017768998397514224, 0.05056820563705904, 0.025988323780308877, 0.005879109841771424, 0.090530644303986, 0.03282783293564405, 1.8752888355936324, 10.162190335137502, 17.452026639665874, 29.377522127968923, 35.94335787636893, 48.952789715358186, 47.663732119968955, 54.206489426749094, 52.46950578689575, 55.13749245234898, 62.08329391479492, 63.099113600594656, 68.19055897848946, 70.44145570482526, 71.30512373788017, 62.21242618560791, 61.054397719247, 53.0260078566415, 42.62321008954729, 45.42109680175781, 34.533679553440635, 38.329101766858784, 31.61940704073225, 34.50532742909023, 41.709560189928325, 29.55011190686907, 36.664125783102854, 44.87090369633266, 46.2673213822501, 43.6674861226763, 58.14716720581055, 29.631784507206508, 20.403485911233084, 28.827049357550486, 27.38854816981724, 25.460315363747732, 29.04114941188267, 32.339855330330984, 33.4965705871582, 39.816777093069895, 35.65237774167742, 43.00460018430437, 43.613404818943565, 34.76120873859951, 42.33594724110195, 37.18085983821324, 28.27089122363499, 51.66032552719116, 44.491660594940186, 48.46755879265921, 57.24658686774117, 67.86207594190324, 70.85479709080288, 64.47152178628104, 49.20274421146938, 33.544183118002756, 14.734457629067556, 7.935344798224313, 1.298902649964605, 0.2450117484799453, 0.06635096070489713, 0.023665798495390584, 0.08702105084168059, 0.04154089432475822, 0.06632248937551465, 0.05277704407594033, 0.014636164896988442, 0.011405303442318524, 0.05379366595298052, 0.060837347991764545, 0.05772180695618902, 0.02038942600068237, 0.04980564423437629, 0.040302679874002934, 0.052846512491149564, 0.015355764854965466, 0.09061463336859431, 0.0585643235327942, 0.03489424687411104, 0.05471664660477212, 0.01713230524079076, 0.056827450304159095, 0.05199380771123937, 0.006017010209948889, 0.024773428881806985, 0.017777361341619065, 0.03884019263620887, 0.011396096570284238, 0.014271526963316968, 0.025239645204107677, 0.013847587613521941, 0.03193595972178238, 0.00794599621024515, 0.03810215348910008, 0.044277297133313756, 0.05826578848063946, 0.10095356644264289, 0.05170760842572365, 0.050176056501056464, 0.03976026915812066, 0.04376631955217038, 0.05597849782290203, 0.019382405394156064, 0.04668362658204777, 0.034707351188574515, 0.01750237145461142, 0.012859546479636004, 0.016545584491853203, 0.018538682721555233, 0.06936546787619591, 0.05179906476821218, 0.028942992644650594, 0.06332292354532651, 0.050391080855791054, 0.03880701566647206, 0.05046379606106451, 0.03605534242732184, 0.03723960655874439, 0.03613202706245439, 0.023938759562692473, 0.03936542963076915, 0.003135564179891454, 0.1890613114727395, 0.1417867046381746, 0.13806669068123611, 0.09279030840843916, 0.11533303984573909, 0.10018660474036421, 0.10978305765560695, 0.14536015503108501, 0.16566132567822933, 0.12055469251104764, 0.1625755519739219, 0.1317520538078887, 0.1367110184260777, 0.12163965643516608, 0.09798071453613894, 0.1578156966716051, 0.13876396683709963, 0.13150612557572977, 0.1267035768500396, 0.1838244731937136, 0.2478557058743068, 0.15371297539344855, 0.10419762879610062, 0.1616340982062476, 0.12500839281295026, 0.10305898596665689, 0.1367707566491195, 0.16362200225038187, 0.11323806976101228, 0.07005574155066695, 0.094363546131977, 0.12148015999368258, 0.07921917377305882, 0.09813561051019601, 0.11055240101580109, 0.1350765089903559, 0.0866714831707733, 0.08942284089113985, 0.13521856708186014, 0.14653649048081466, 0.0953444159988846, 0.1383605506271124, 0.14492397915039743, 0.10039415503186838, 0.2247400398233107, 0.1720654477498361, 0.12287241885704653, 0.1658676681774003, 0.12987457455268928, 0.1575449611991644, 0.10617907997220755, 0.12511687699173177, 0.22748562321066856, 0.365652750645365, 2.9337884826319556, 13.781854391098022, 23.32452596936907, 38.22759553364345, 47.60065984725952, 60.066780771527974, 58.231441906520296, 65.0343884059361, 62.61636665889195, 65.05467019762311, 71.97741753714425, 72.73691122872489, 78.5997873033796, 78.79574734824044, 80.3175070626395, 71.41796943119594, 71.91628033774239, 62.13316113608224, 53.68771260125296, 54.43780190604073, 40.772088391440256, 45.54629291806902, 35.26569659369332, 37.61970458711897, 50.43245029449463, 36.705088887895855, 48.90231800079346, 58.63532679421561, 59.53019223894392, 57.31630161830357, 72.57715129852295, 38.17671734946114, 21.30117232458932, 30.725208623068674, 26.545648302350724, 29.519873346601212, 33.06749847957066, 36.399666922433035, 37.40445286887032, 42.73977306910923, 42.58411257607596, 48.04214143753052, 47.45349700110299, 38.9974559375218, 48.1145520891462, 38.938608169555664, 37.89392566680908, 58.5012196132115, 53.931715965270996, 58.42565795353481, 67.04688549041748, 80.29272978646415, 80.378005027771, 76.62237862178257, 55.836898122514995, 38.439223766326904, 18.185223136629375, 9.477960399218968, 1.6900505125522614, 0.437122219907386, 0.4084018681730543, 0.13036174912537846, 0.15159932523965836, 0.11299232473330838, 0.13288843711572035, 0.08620565530977078, 0.12281667041991438, 0.17121828320835317, 0.17586444318294525, 0.21387065521308354, 0.11039821750351361, 0.15890642814338207, 0.16211155615746975, 0.16593883293015615, 0.12359678213085447, 0.1439757671739374, 0.13524948113730975, 0.1314690097102097, 0.0881858579814434, 0.1722892557403871, 0.18302967798496994, 0.1740792989730835, 0.13748051784932613, 0.09858600848487445, 0.18957866728305817, 0.12282743198531014, 0.127144475334457, 0.10952780635229178, 0.06092943876449551, 0.154456568349685, 0.05112645336027656, 0.14196829417986528, 0.1006671025284699, 0.12440522946417332, 0.13213960586913995, 0.13666622154414654, 0.12015666386910848, 0.05927775560745171, 0.12710507959127426, 0.0836703431393419, 0.1894347092935017, 0.15139979523207459, 0.1419520229101181, 0.1344431915453502, 0.11327960288950376, 0.05407023343390652, 0.0679467325764043, 0.15340045573455946, 0.09333943322833095, 0.14725750179163047, 0.1269250778215272, 0.10532010213604995, 0.09906510170549154, 0.14099940045603684, 0.14178267414016382, 0.1463904833155019, 0.17604242291833672, 0.1383679195174149, 0.1761776820889541, 0.10412838429744754, 0.13253501536590712, 0.10275893099606037], [0.011984911447923099, 0.02242613028335784, 0.015843329585290382, 0.023031327540853193, 0.0697045928931662, 0.031727703753858805, 0.019111447701496736, 0.031746668807630024, 0.019740900889571224, 0.09442582207598857, 0.06719691066869668, 0.043875533156096935, 0.017108073058937277, 0.0433546930684575, 0.0030481777752616574, 0.04549316064055477, 0.02894808165729046, 0.029428657476923296, 0.0210280207517956, 0.11061687541327306, 0.0473638138334666, 0.05083790295092123, 0.02614176768942603, 0.04422329931652971, 0.019581557118466923, 0.03529057917850358, 0.02543627447448671, 0.03786843888727682, 0.020569960420419062, 0.025252561118187647, 0.05101493952263679, 0.03887980551059757, 0.05344411863812378, 0.01544251894977476, 0.04659694034074034, 0.046755469869822264, 0.02128588780760765, 0.0039377728077982154, 0.02714199955309076, 0.03658161758046065, 0.034134077307369025, 0.03339712381629007, 0.04878190452499049, 0.03797582723200321, 0.02336503954471222, 0.06485996821096965, 0.07853656754429851, 0.03661574449922357, 0.028910687592412745, 0.09479722500379596, 0.07307974821222679, 0.18103245086967945, 3.1518312054021016, 13.178134969302587, 29.67923375538417, 41.86470651626587, 50.22604015895298, 56.194285665239605, 60.616320746285574, 60.79267297472273, 60.05386407034737, 60.81822150094168, 54.782116413116455, 62.641790117536274, 52.98736892427717, 55.16065079825265, 60.70559120178223, 46.100707054138184, 47.343114444187705, 38.20882497514997, 31.211579050336564, 31.881566047668457, 26.543893882206508, 21.623864037649973, 16.685134853635514, 15.95279472214835, 17.33892560005188, 13.360261150768824, 19.338825600487844, 24.687790325709752, 30.189043930598668, 24.159466675349645, 28.65795452254159, 26.667207036699565, 60.74476514543806, 32.666656902858186, 16.94429918697902, 28.928077902112687, 14.745275974273682, 25.170391355242046, 15.64001635142735, 14.130814637456622, 11.848278420312063, 12.433847410338265, 13.715770074299403, 10.1116578238351, 12.1207355260849, 14.523532901491437, 14.785848242895943, 10.076965468270437, 27.029022318976267, 48.51971891948155, 49.22933496747698, 30.21997731072562, 27.43462688582284, 35.75611087254116, 33.89652974264962, 47.89686502729143, 56.96319416591099, 53.972283022744314, 44.798548630305696, 34.2697730745588, 17.930773156029836, 5.792757025786808, 1.6008985021284647, 0.1841166503727436, 0.2107823844999075, 0.11628590657242707, 0.021307743420558314, 0.07343352280024971, 0.05572263244539499, 0.07868685626557895, 0.027158618572035005, 0.01878025645523199, 0.03301962764401521, 0.02772696628900511, 0.097574034572712, 0.026148687050278698, 0.047588931396603584, 0.014209069511187928, 0.0647367462515831, 0.01291597175544926, 0.02528408924782915, 0.05673611270529883, 0.0033162567831043687, 0.016258058670376028, 0.05223440944350191, 0.01669827861977475, 0.012685017942983125, 0.02148198103532195, 0.050115412433764765, 0.03171202280957784, 0.06543395455394473, 0.019940507232344577, 0.05379626134942685, 0.04287512826600245, 0.04295347531193069, 0.03429682053891676, 0.030977298306035142, 0.03836650394701532, 0.04641977824004633, 0.04523097810202411, 0.00790045633246856, 0.07329890145254986, 0.039930364316595454, 0.01540207486998822, 0.1233522245394332, 0.020014129978205477, 0.0701771043241024, 0.07327124436518975, 0.026430038203086172, 0.052071384619921446, 0.0137350653032107, 0.009807210981047578, 0.02470938365773431, 0.01997452897817961, 0.04025391356221267, 0.03837311627077205, 0.15802657178470067, 0.053208242902266126, 0.00262490169344736, 0.055597144179046154, 0.030147667109434093, 0.04801573331600853, 0.055274884149964364, 0.04927043616771698, 0.0342523188197187, 0.03268097420888288, 0.05298465543559619, 0.04536620334589055, 0.017103922120960693, 0.018923021919493164, 0.010868443991057575, 0.07541679245020662, 0.017429854720830917, 0.024484510367204036, 0.041693272933896096, 0.06593710862632308, 0.009112157875538936, 0.05384087502690298, 0.013324952800758183, 0.013734100935315447, 0.07029526441224984, 0.049282581944550784, 0.014491063575925571, 0.05057753888624055, 0.03883723083085247, 0.008879824092478623, 0.01021239223025207, 0.024199247460014055, 0.01877529636424567, 0.005328551192568349, 0.06825936080089637, 0.08487458673438855, 0.04464770939999393, 0.040978059704814634, 0.0375979035826666, 0.06298200719590698, 0.07632934062608651, 0.02923257781990937, 0.02801962522789836, 0.05594150748636041, 0.017160250705533793, 0.03807168387408767, 0.01238620384330196, 0.047015470918267965, 0.016799215792811344, 0.0683521708207471, 0.028741637377866676, 0.05615577527454921, 0.029180306874747788, 0.038940246017383676, 0.06570610137922422, 0.10558034745710236, 0.05038406141102314, 0.06755200840000596, 0.011725994359169687, 0.14812773652374744, 5.866141727992466, 17.945433855056763, 37.450668811798096, 51.2384170123509, 60.060145241873606, 64.5650862285069, 69.38736534118652, 68.9645744051252, 67.91439587729317, 67.8919323512486, 63.286103521074565, 71.98846517290387, 60.31026649475098, 64.66006810324532, 67.89637225014823, 56.25173337118966, 55.23194626399449, 46.24658795765468, 40.564059325626914, 44.18356704711914, 37.38161761420113, 30.84361982345581, 25.937022583825247, 23.80935910769871, 25.099295650209697, 22.67282141957964, 31.183303356170654, 32.13567556653704, 38.35023123877389, 29.535176753997803, 39.50558464867728, 40.542631081172395, 62.50536918640137, 39.41228076389858, 22.755727325166973, 32.965005602155415, 17.174383572169713, 28.394279071262904, 19.832962376730784, 22.28153361592974, 20.29238247871399, 21.39721553666251, 22.97368884086609, 24.228609936577932, 17.512345688683645, 19.123014552252634, 26.006136315209524, 19.441841329847062, 26.89048739842006, 55.585901396615164, 54.39319447108677, 39.74697549002511, 35.28014537266323, 43.76800223759243, 42.777171748025076, 59.709212575639995, 65.34515353611538, 63.48555156162807, 54.197870186397004, 43.440898418426514, 25.34325906208583, 9.32061323097774, 3.2234884117330824, 0.8748662493058613, 0.47310941027743475, 0.023110889164464812, 0.01932799706368574, 0.018586639880335758, 0.039527443437171836, 0.03851787153897541, 0.014498159355883087, 0.09299359750002623, 0.05238094247345414, 0.011579558020457625, 0.013052085032021361, 0.034127210532980304, 0.012048094084353318, 0.027461955955784236, 0.020500381743269305, 0.041452243724571805, 0.0528710449247488, 0.01860554895496794, 0.021919198467263153, 0.011646824589531337, 0.03240792153935347, 0.03940970743341105, 0.020639167599646107, 0.004778084569677178, 0.030026263623897518, 0.006782651313447526, 0.054199633454637866, 0.03922000939824751, 0.02696321066468954, 0.017506454539086138, 0.03172264866796987, 0.02354546370250838, 0.0507613065253411, 0.07464879258934941, 0.035175791409398825, 0.029112042859196663, 0.014984886095459973, 0.05269028998113104, 0.05758203552769763, 0.03327771183103323, 0.059438955171832016, 0.024424909547503506, 0.023386092790003334, 0.038558515786592445, 0.01754614883767707, 0.04548104200512171, 0.018611099371420484, 0.04806645720132759, 0.02858868201396295, 0.013895696594512888, 0.10492925239460808, 0.0016956281594632725, 0.08519649053258554, 0.05230554026950683, 0.020321580980505263, 0.0660414740975414, 0.06538778703127589, 0.03139625975329961, 0.015025996835902333, 0.040748056689543385, 0.13914397358894348, 0.17641929483839444, 0.18714738131633826, 0.19110786808388575, 0.14414423384836741, 0.1355392834437745, 0.12067993650478975, 0.13471546050693306, 0.1268569529056549, 0.12923284327345236, 0.11810230410524777, 0.11355943751654454, 0.0925279799848795, 0.11393843325121061, 0.15724887565842696, 0.12478337703006608, 0.09417168357010398, 0.08559949962156159, 0.1128613403333085, 0.1793719535427434, 0.12962384229259832, 0.1429378121559109, 0.09361400242362704, 0.1380196546337434, 0.09274724857615572, 0.08102636358567647, 0.14760879294148513, 0.10919153796775, 0.121786287852696, 0.08587382454425097, 0.12115050054022244, 0.12927956719483646, 0.1680057184504611, 0.1534939714308296, 0.09708837991846458, 0.17747379254017556, 0.06628819621567215, 0.11108606880796806, 0.07811417270983968, 0.11941441441220896, 0.08803497893469674, 0.08864046965858766, 0.11502699341092791, 0.16551849405680383, 0.11368962803057261, 0.13275905405836447, 0.14730756410530635, 0.18827531007783754, 0.08367011243743555, 0.12276759876736573, 0.15085808001458645, 0.6737529752509934, 8.208686930792672, 24.450207097189768, 46.21826710019793, 61.12825012207031, 68.23053891318185, 73.61477443150112, 78.93416241237095, 78.21168872288295, 78.78160081590924, 78.0282632282802, 72.22560719081334, 80.55716432843889, 70.2768667766026, 72.08690725054059, 77.98754678453717, 64.31402696881975, 65.6327325275966, 55.87876101902553, 46.741386549813406, 46.930408818381174, 42.57917588097708, 35.96656138556344, 29.178216525486537, 27.683539152145386, 29.13201447895595, 24.74864959716797, 33.73272943496704, 37.83668293271746, 46.60536514009748, 40.480632305145264, 42.1327680179051, 39.334506102970664, 71.29573672158378, 45.71260152544294, 29.42540216445923, 40.62452254976545, 23.310504504612513, 38.46696444920131, 27.08080898012434, 24.317230735506328, 21.833942822047643, 22.62311053276062, 22.96309631211417, 19.736818415778025, 20.986438035964966, 24.398707049233572, 25.784599951335363, 18.45922187396458, 42.21743181773594, 61.92506953648159, 62.17921379634312, 46.28445216587612, 45.655834742954795, 57.43678685597011, 53.859298365456716, 69.54706273760114, 75.34254823412213, 73.356002671378, 62.177879742213655, 49.592215061187744, 30.972929273332866, 11.740454537527901, 4.68628853559494, 1.6510801294020243, 0.5330842520509447, 0.15334610507956573, 0.18791432944791658, 0.13789369139288152, 0.1915828018848385, 0.1615306758987052, 0.09812101522194487, 0.17541526657130035, 0.13770170669470513, 0.07990941352077893, 0.12468253315559455, 0.06649248275373663, 0.1520786288061312, 0.13426530680486135, 0.12339106388390064, 0.14692135554339203, 0.11257463893187897, 0.09019322240991251, 0.13232077471911907, 0.09278291916208607, 0.1275666191109589, 0.12989114437784466, 0.07153977227530309, 0.12524919132036821, 0.09818343365831034, 0.1418752670288086, 0.14489811339548656, 0.09647287401769843, 0.17815733514726162, 0.11435752362012863, 0.09354225413075515, 0.10760973034692661, 0.13983116671442986, 0.11748000606894493, 0.10125170794448682, 0.13833111577800342, 0.07026735626693283, 0.1398926419871194, 0.15301340578922204, 0.06809795089066029, 0.1798427618507828, 0.15005987856004918, 0.13642219321003982, 0.1143799831292459, 0.11806072347930499, 0.16265103220939636, 0.08387949477349009, 0.09943969374788658, 0.08911917611424412, 0.09637796732464007, 0.13737306504377297, 0.12366452706711632, 0.1886787669999259, 0.10780044618461813, 0.09291784585054431, 0.15534969685333117, 0.18463940732181072, 0.22206993667142733, 0.18842853685574873, 0.13862957619130611], [0.04524128844163247, 0.029834248391645293, 0.027473282401583025, 0.01480647549033165, 0.022431468657617058, 0.03983869084290095, 0.07982627262494393, 0.04313794184210045, 0.02587421115354768, 0.029554580005684068, 0.036610380679901154, 0.0007064327208874081, 0.052251891898257394, 0.020337002385141592, 0.027063554119584814, 0.01337765037481274, 0.06677883131695644, 0.062395949714950154, 0.03669973017115678, 0.034426495366330655, 0.021402633150241206, 0.057778939604759216, 0.029012654442340136, 0.03619019447692803, 0.04009205921153937, 0.011170181728500341, 0.03230592076267515, 0.027677482426432625, 0.05915072028126035, 0.08709217488233532, 0.06003812873469932, 0.07645838441593306, 0.029054157036755766, 0.022474143421277404, 0.06707301695964166, 0.008674498547666838, 0.04773634312940495, 0.04575933296499508, 0.11004853448165314, 0.05177625581356032, 0.07758320548704692, 0.03513970352443201, 0.02063876047863492, 0.05852549775902714, 0.0072323961981705254, 0.033158255741000175, 0.014743305576433028, 0.11837527874325003, 0.04419641236641577, 0.21453278325498104, 2.734121573822839, 13.863967333521162, 37.59576456887381, 53.50451292310442, 58.566456249782014, 67.70820808410645, 61.12605449131557, 62.13518306187221, 48.03259808676583, 48.717957973480225, 43.82876770836966, 48.70099742071969, 47.504569734845845, 49.60009431838989, 45.63960722514561, 44.48008142198835, 36.959010805402485, 25.52080638068063, 32.0474716595241, 23.06248160770961, 15.749422686440603, 7.986530440194266, 12.670882599694387, 12.672156725611005, 14.95523316519601, 15.188148941312518, 25.50956072126116, 21.922587939671107, 22.90026375225612, 32.51622492926461, 36.837677887507844, 27.18537242071969, 24.776636941092356, 33.5583678654262, 46.724895000457764, 32.78254590715681, 37.7471866607666, 55.77362782614571, 63.28918852124895, 47.062956128801616, 35.379313537052695, 27.68746488434928, 27.672788551875524, 29.570814064570836, 22.077286107199534, 25.513491664613994, 40.22130816323416, 34.04276500429426, 22.848815815789358, 23.478456360953196, 32.95396491459438, 18.619233676365443, 36.87052549634661, 54.926427023751394, 35.888661657060894, 39.730588163648335, 47.46805695125035, 59.82824911390032, 45.144617557525635, 52.72039828981672, 56.81464515413557, 60.28769874572754, 49.067671230861116, 42.66856445584978, 33.88522154944283, 16.114265646253312, 13.33190815789359, 6.460404217243195, 2.1047708988189697, 0.255521007414375, 0.01360758044756949, 0.059280483318226676, 0.030187266413122416, 0.05539643691320505, 0.012689341907389462, 0.04270714335143566, 0.042990903303559334, 0.06327061528073889, 0.031628332300377746, 0.06374133537922587, 0.10101318252938134, 0.03916408793468561, 0.029161155223846436, 0.0689421095220106, 0.048600616931383095, 0.048396235398416004, 0.011144750236001397, 0.029132134281098843, 0.0962197126022407, 0.05677526756854994, 0.03734813823497721, 0.05057482813884105, 0.03259762975254229, 0.02466816604802651, 0.02898503467440605, 0.030549305557672466, 0.021990777126380374, 0.04252284306234547, 0.012670560906242048, 0.040687198883720806, 0.061651949637702534, 0.03944288440314787, 0.040914548827069144, 0.021798761894128153, 0.06141845216708524, 0.03596528386697173, 0.08975019332553659, 0.00841146444768778, 0.06636981040771518, 0.022997614528451647, 0.05239712892632399, 0.03559744664068733, 0.017882951568546038, 0.030612758759941374, 0.013708152908033558, 0.037214806103812795, 0.016931747252653753, 0.043181388439344506, 0.031914765680474896, 0.02097927818873099, 0.02239149107065584, 0.06647927846227374, 0.020826582364471893, 0.046982823205845695, 0.0358112258836627, 0.025036218709179332, 0.05881824490747281, 0.035972978454083204, 0.014188885638889457, 0.025372431114582077, 0.039384197909384966, 0.01835798206073897, 0.08635358272918633, 0.0258788692964507, 0.019041762155081545, 0.03299923088135464, 0.02141680774678077, 0.03909598337486386, 0.028977513113724332, 0.014709163390632187, 0.059024207427033355, 0.03722425131127238, 0.004113526100159756, 0.01737203335921679, 0.012267568780641471, 0.020440304252718176, 0.014986816527588027, 0.04824868117326072, 0.02278562492158796, 0.023222945830119506, 0.03491221787407994, 0.025681167940742204, 0.02886444203821676, 0.002864658225527299, 0.10167595517954656, 0.05748650458242212, 0.05823593293981893, 0.05229924346453377, 0.018742345007402555, 0.08074215919311557, 0.06618132016488484, 0.029520242741065364, 0.03561855586511748, 0.05116775917953678, 0.010192042965042804, 0.06874408586216824, 0.017301698115521243, 0.037116971532148976, 0.010049757564307323, 0.05096338103924479, 0.02268145961820015, 0.0243058045993426, 0.021005668111943772, 0.08894331340811082, 0.038603414448776414, 0.43566518809114185, 5.447460651397705, 20.27053734234401, 46.77864279065813, 62.44075788770403, 66.64103426252092, 75.00487273080009, 68.49786390577043, 69.95162854875836, 54.70792702266148, 58.01046139853341, 52.05180440630232, 57.758099351610454, 54.8005256652832, 58.75056266784668, 53.224820137023926, 52.857055459703716, 46.87652553830828, 33.41814974376133, 41.69254405157906, 33.194289207458496, 21.917800630841935, 14.3213255575725, 21.043758937290736, 24.400616066796438, 20.371505090168544, 19.110645021711075, 32.56775624411446, 22.744321857179912, 28.28825303486415, 34.60418292454311, 40.81882892336164, 28.963491133281163, 28.887479577745708, 30.95814003263201, 51.29426663262503, 28.786383288247244, 33.60131120681763, 48.97350229535784, 40.455507619040354, 33.0249650818961, 23.00477508136204, 19.872539315904888, 22.958076238632202, 28.006717239107402, 20.479313339505875, 14.15850841999054, 28.104322058813914, 23.637651750019618, 15.262644052505493, 12.69556086403983, 36.288342884608674, 32.62136854444231, 46.74465915134975, 56.073307105473106, 42.87336608341762, 47.06377254213606, 51.19169037682669, 62.591804776872905, 51.13961362838745, 61.166110856192454, 65.30164391653878, 68.81682096208844, 59.72240720476423, 54.887864521571565, 42.1082512991769, 22.366058451788767, 18.506217752184185, 9.064712813922338, 2.658885393823896, 0.3371512128838471, 0.09310143707054001, 0.039874408926282606, 0.031176271914903606, 0.05160660170284765, 0.0744710774826152, 0.06838761749012129, 0.049583217062588246, 0.06289478151925973, 0.0507049304433167, 0.06519113401217119, 0.05634804156475833, 0.06061447637953928, 0.04146810448063271, 0.023463941112692868, 0.05542625852727464, 0.0228114092522966, 0.07061640825122595, 0.004324669234587678, 0.018684890054698502, 0.024437895011422888, 0.038437217473983765, 0.02038999936277313, 0.05784051665770156, 0.05984869532819305, 0.053277066709207635, 0.04847614986023732, 0.04966536390462092, 0.035844060193215094, 0.026796935658369745, 0.02596784898612116, 0.028616461237626414, 0.04277666944212147, 0.0204535458636071, 0.0354125628114811, 0.0272983357177249, 0.03701048903167248, 0.04094610409811139, 0.005764859387584562, 0.02071000835193055, 0.028858470930052654, 0.03997889653380428, 0.02192167512008122, 0.02341568879117923, 0.01619469028498445, 0.035258145204612186, 0.018472227001828805, 0.04205263186512249, 0.04960352561569639, 0.03256779796044741, 0.03056519345513412, 0.020538783432649713, 0.013944411168007978, 0.018463626570467438, 0.023457449228901948, 0.05757168786866324, 0.02442790358327329, 0.13006571786744253, 0.12330737337470055, 0.10413662849792413, 0.13149214775434562, 0.13061875104904175, 0.1404920191104923, 0.1602624939488513, 0.138115260217871, 0.1230818826173033, 0.1154378599354199, 0.0988725945353508, 0.13777139224112034, 0.11128623663846936, 0.07898678231452193, 0.12383464936699186, 0.10711239810500826, 0.11800767561154706, 0.16331896851105349, 0.12316137978008815, 0.11256655079445668, 0.12075408681162766, 0.10105259184326444, 0.08148961301360812, 0.1262129553194557, 0.14240654637770994, 0.15213927626609802, 0.16345388841416153, 0.1269329081156424, 0.21715424901672772, 0.16296727024018764, 0.1594684858407293, 0.16949033950056347, 0.08212113912616457, 0.2090051927204643, 0.20497203485241958, 0.08092832884618215, 0.1208823842129537, 0.152804986972894, 0.18456041227493966, 0.13803284535450594, 0.23285905058894837, 0.13795201826308454, 0.08828944313739027, 0.14301383521940025, 0.05909384547599724, 0.1828880812972784, 0.1332346121115344, 0.2525300250521728, 0.09872199368796178, 0.7872952254755157, 7.621031744139535, 27.75350751195635, 57.16499069758824, 72.1111981528146, 76.45120974949428, 84.38636520930699, 77.8023772920881, 78.30466951642717, 64.63342176164899, 66.24358340672084, 61.5157858984811, 64.34131949288505, 61.7930120740618, 64.62121377672467, 61.38015706198556, 59.945562498910085, 52.926575660705566, 41.964156082698274, 46.6926657812936, 35.97226585660662, 26.579986299787247, 15.37327674457005, 20.3767283984593, 23.444337231772288, 24.711723395756312, 27.930531978607178, 38.828691141945974, 34.547033991132466, 35.62376158578055, 46.97121558870588, 54.249752385275706, 45.47850281851632, 41.09919221060616, 49.469179834638325, 61.527236529758994, 44.728024414607454, 52.53096955163138, 69.32076685769218, 81.72844300951276, 62.31933811732701, 51.09946346282959, 40.9058655330113, 41.78396150044033, 43.311849525996614, 33.93510266712734, 38.91603347233364, 53.749020031520296, 48.33025891440255, 35.694476876940044, 39.33422817502703, 44.43948309762137, 29.37641041619437, 48.82576274871826, 67.89934607914516, 54.13513490131923, 55.527255126408164, 62.66327394757952, 77.81701019832066, 63.74836022513253, 72.99826771872384, 75.3508860724313, 78.4636651447841, 68.56148161206926, 62.16855525970459, 48.44123206819807, 28.899116073335918, 22.18429183959961, 10.340464609009878, 3.25369570510728, 0.6358852929302624, 0.13793289714625903, 0.12076165926243577, 0.061173433171851296, 0.10295756533741951, 0.2215531644012247, 0.22579719738236495, 0.14314753375947475, 0.1648047294999872, 0.12043571818087782, 0.18352236226201057, 0.1580714365201337, 0.13200791579272064, 0.08285541579659496, 0.15361804834433965, 0.12168224129293646, 0.13579996302723885, 0.11808563928518977, 0.10235590155103377, 0.18849430046975613, 0.1461523175239563, 0.11011997743376664, 0.16743436482335838, 0.11229964904487133, 0.11664177104830742, 0.12327803352049418, 0.10880579080964838, 0.12099947221577168, 0.08299570291170053, 0.09399976993777923, 0.10254914153899465, 0.10067312113408532, 0.11214153681482587, 0.10364005621522665, 0.11666603546057429, 0.08003703238708632, 0.21675577254167624, 0.1183175082717623, 0.16402068228593894, 0.09825700721038239, 0.1376938492591892, 0.17873771329011234, 0.12378423421510629, 0.13057285494038037, 0.06760681367346219, 0.1828120175216879, 0.06058185241584267, 0.15519698576203414, 0.14707868067281588, 0.11439204748187747, 0.1366750153579882, 0.12220925944192068, 0.1657250943992819, 0.13350396337253706, 0.12850656653089182, 0.1846360553588186, 0.12803157844713756], [0.05924929106341941, 0.024749692030517117, 0.030168033338018825, 0.038638342038861344, 0.016240164005596722, 0.030793669766613414, 0.016033767223624245, 0.05685553147590586, 0.034381359216890166, 0.04545787681958505, 0.0922382048198155, 0.041397859142827134, 0.052168367630136867, 0.05646273433896048, 0.009498282468744686, 0.07064866580601249, 0.0013500463516850556, 0.03495285872902189, 0.026518359713788544, 0.02384501146817846, 0.06323308550885745, 0.045516821156655035, 0.06129966104137046, 0.05009981630636113, 0.014744633808732033, 0.023822117696649263, 0.031533965042659214, 0.04048821509682706, 0.02055030326092882, 0.02339258128111916, 0.01367843646689185, 0.05839251168072224, 0.015059175501976694, 0.04635391623846122, 0.03266752225213817, 0.023882938183045814, 0.01840443117544055, 0.04836428318438785, 0.06399935510541711, 0.05731427203863859, 0.06621066001909119, 0.019324577247191752, 0.022654498029234152, 0.05175695827762995, 0.04187499478991542, 0.03873586787709168, 0.05823819924678121, 0.10867093876004219, 2.4470682569912503, 13.638426201684133, 40.50260598318917, 59.59631129673549, 59.66051959991455, 60.547728129795615, 60.100243295942036, 52.3746211869376, 56.264705657958984, 44.65922335215977, 44.95669310433524, 30.62006848199027, 31.811899934496196, 32.83865261077881, 29.05465497289385, 30.473319053649902, 25.827161141804286, 23.04370062691825, 17.28839135169983, 18.628070047923497, 15.662983621869769, 12.700210945946829, 21.676180498940603, 39.458420276641846, 25.692916733878, 24.794813428606304, 32.48699038369315, 39.39185306004116, 46.59429318564278, 53.47602530888149, 43.30365065165928, 40.60231263296944, 36.559551920209614, 36.52529730115618, 34.69597905022757, 42.48481239591326, 28.336117437907628, 50.26842417035784, 45.56072432654244, 36.26891572134835, 41.71759230749947, 33.86791706085205, 36.084896155766074, 48.95389447893415, 50.44025659561157, 48.31094987051827, 53.55563082013811, 82.10297870635986, 52.44537469318935, 41.64660603659493, 52.16148519515991, 57.058287211826865, 23.530475786754064, 16.821307386670792, 11.260721376964025, 29.445597103663854, 37.19381822858538, 34.44218567439488, 40.69721112932478, 50.16841179983956, 55.96485267366682, 43.07891116823469, 57.09740209579468, 53.211312838963096, 54.875781604221885, 53.723527090890066, 59.197908537728445, 49.21553584507534, 46.91550840650286, 35.13738073621477, 16.103978838239396, 10.33217019694192, 2.3476640709808896, 0.33893285585301264, 0.038826431946030686, 0.09120330999472312, 0.09407088040773358, 0.02037340578889208, 0.014433432204116668, 0.034483034296759536, 0.0401973678464336, 0.01598084488484476, 0.025590454594099095, 0.03533217337514673, 0.01062951993662864, 0.04899693905775036, 0.043746187418167076, 0.007965319191238709, 0.015341612310814006, 0.037430468281464915, 0.00585842682214986, 0.02609688090160489, 0.04203372448682785, 0.01797826198994049, 0.07147554215043783, 0.038731749169528484, 0.06008563297135489, 0.027562708228028247, 0.03487756169800248, 0.06422007576163326, 0.02289589704014361, 0.052313384134322405, 0.07481727283447981, 0.013095750456808932, 0.03550168499350548, 0.04836768603750637, 0.04627918239150729, 0.021103719814813564, 0.0301726643395211, 0.01637124170416168, 0.023837788462904946, 0.029079995650265898, 0.028106840726520334, 0.07772955870521919, 0.027079620132488862, 0.03275717369147709, 0.020745044507618462, 0.011506080311456961, 0.0362032087785857, 0.02601761444072638, 0.07574750363294568, 0.06449928613645689, 0.043006360331284146, 0.0709070044436625, 0.01997843225087438, 0.044741655966000896, 0.05490892307300653, 0.027274081483483315, 0.030500237297798907, 0.01955774223564991, 0.03432360231610281, 0.03706532483920455, 0.032791192044637034, 0.10178908732320581, 0.03615171475602048, 0.034512492894594154, 0.023508973785543015, 0.051894972300423045, 0.07093005427824599, 0.08303066103586129, 0.01583267828183515, 0.03260497489411916, 0.05565833107435277, 0.04828904043616993, 0.03905580731640969, 0.03647909772449306, 0.06636915222874709, 0.03614717535674572, 0.058126464885260375, 0.05210034449451736, 0.008831038272806575, 0.0668354822056634, 0.04310635603698237, 0.030703689237790446, 0.045610547198780944, 0.0260975797926741, 0.02511772433561938, 0.012257121037691832, 0.05572861712425947, 0.0457914514201028, 0.058260584117046425, 0.034210317502064366, 0.013455476645114166, 0.04156179998868278, 0.03948665330452578, 0.04092947659747941, 0.10548106421317373, 0.023768579587340355, 0.022289534398753728, 0.07527950445988349, 0.032681662921926806, 0.05716895019369466, 0.06545613586370434, 0.062015081223632605, 0.058877148532441685, 0.2773960807493755, 4.364597363131387, 19.009147473743983, 48.70073338917324, 67.14230510166713, 69.4198134286063, 67.6691175188337, 69.07896259852818, 64.18542970929826, 62.21994413648333, 53.311009066445486, 51.49052545002529, 40.04891640799386, 41.674711499895366, 39.40481492451259, 38.62260062353951, 38.57382426943098, 34.12086623055594, 31.231798308236257, 25.977629593440465, 24.15193656512669, 27.230679886681692, 20.831057207924978, 29.073290041514806, 34.17168535505022, 23.211190428052628, 24.276331901550293, 26.824710539409093, 32.7282109941755, 35.743871620723176, 37.79558433805193, 39.47982767650059, 35.20320102146694, 30.271928991590226, 35.929419789995464, 30.38710927963257, 32.531288623809814, 31.38281740461077, 34.47572462899344, 23.667000940867833, 23.520482540130615, 32.0234169960022, 33.92153630937849, 34.776341915130615, 31.17933940887451, 28.755918911525182, 28.123617206301006, 31.883452483585902, 64.12101990836007, 60.80095522744315, 51.64860739026751, 47.40878186907087, 52.26203605106899, 39.13807705470494, 17.72719267436436, 22.834605012621196, 43.78176314490182, 51.196401255471365, 46.857768876211985, 51.27305725642613, 59.927872385297505, 64.09904970441545, 49.94044140407017, 63.30949115753174, 61.15010220663888, 63.06020368848528, 63.50034427642822, 67.6521361214774, 60.353776114327566, 57.37451710019793, 46.71527869360787, 23.0779778276171, 15.486718245915004, 3.5264511491571153, 0.6151881835290364, 0.05194185567753656, 0.03089545341208577, 0.04029725159385374, 0.01023713925055095, 0.021098547681633915, 0.02084582731393831, 0.039904471420283825, 0.06259944236704282, 0.033743186853826046, 0.04115861448060189, 0.04679794616198965, 0.023419291812128255, 0.04549745237454772, 0.012129672653307872, 0.04372337167816503, 0.038726419276957, 0.019254676265908138, 0.03918083417894585, 0.08510527507002864, 0.039998740290424654, 0.040270714089274406, 0.07081122922578029, 0.040067224829856835, 0.013411012245342135, 0.04172237869352102, 0.027338409995926276, 0.10744496847369842, 0.024524961232340763, 0.02077922740552042, 0.0169308939948678, 0.014079075772315264, 0.06854085783873286, 0.03269409368346844, 0.028907549367951493, 0.055796867569110224, 0.01148991845548153, 0.04735957977495023, 0.06132898732487645, 0.015172780923811453, 0.03677416207002742, 0.035641330893018415, 0.05966798109667642, 0.01770342986232468, 0.03287347120099834, 0.03930752345227769, 0.009197826314318393, 0.040090556256473064, 0.06121582125446626, 0.06845377465443951, 0.02884681709110737, 0.02287771739065647, 0.022424099767314534, 0.016616479526939135, 0.017033381620422006, 0.1645026049975838, 0.19202527457049914, 0.1668783189462764, 0.1562506285096918, 0.08936299410249506, 0.16695478984287807, 0.162348690575787, 0.20398134658379213, 0.12275613152555057, 0.16867731884121895, 0.1972619771425213, 0.15029139470841202, 0.10932503973266908, 0.19929496305329458, 0.1601238828152418, 0.09202960279903241, 0.14837000066680567, 0.11899186351469584, 0.12121205723711423, 0.10361518790679318, 0.12626000493764877, 0.21060816384851933, 0.15397761762142181, 0.24060933185475214, 0.09566776507667132, 0.11231589995856796, 0.09730817776705537, 0.20316793237413677, 0.10919598915747233, 0.08815666061959096, 0.1300511157938412, 0.09556635801813432, 0.1286611096667392, 0.09632753181670393, 0.10067092946597508, 0.08246903760092598, 0.2410957600389208, 0.11962682301444666, 0.19944187945553235, 0.17826549362923416, 0.17086617781647614, 0.17174637344266686, 0.22619990791593278, 0.15982063194470747, 0.12143372105700628, 0.15495561728520052, 0.16435407368200167, 0.9078932085207531, 7.3999583039964945, 24.22626144545419, 59.23392799922398, 76.30519335610526, 77.2798797062465, 76.71272604806083, 76.2619686126709, 69.43131964547294, 73.77850178309849, 62.17894976479666, 60.761927195957725, 46.60846056256975, 47.22946970803397, 49.746346950531006, 43.814409255981445, 43.707896845681326, 39.830128056662424, 35.237556389399934, 28.60609143120902, 31.616669450487407, 25.059084687914165, 20.028036526271276, 32.082730293273926, 52.647202491760254, 35.69534192766462, 37.195280824388774, 46.19120734078543, 55.01761865615845, 59.522042001996724, 70.72840935843331, 58.21755940573556, 53.9601479939052, 48.97538178307669, 50.73857750211443, 46.867697851998464, 56.54088265555245, 35.266231604984824, 61.650136266435894, 56.24401044845581, 46.06176240103585, 52.32249232700893, 45.40337194715227, 45.54742547443935, 62.295054163251606, 67.45561327253068, 64.64574786594936, 68.04601560320172, 98.58325808388847, 63.747095652988975, 54.72532878603254, 65.39323507036481, 73.46588148389543, 35.22351408004761, 28.009515626089915, 21.876328570502146, 43.35547031675066, 52.06546456473214, 49.22648968015398, 55.673410483769004, 64.07581492832729, 70.87731620243618, 59.09686088562012, 73.57154273986816, 68.94086715153286, 73.12921346936906, 72.15538869585309, 76.28396660940987, 67.83373423985073, 66.26481710161481, 52.79863500595093, 27.712163993290492, 17.332258803503855, 5.0031494072505405, 0.8587313922388213, 0.2203333077153989, 0.3089227176138333, 0.13622834932591232, 0.08824624759810311, 0.10056069466684546, 0.07390140662235872, 0.18221895077398845, 0.12631343278501714, 0.08316048514097929, 0.13749707410378115, 0.21943798075829232, 0.1190525381160634, 0.15199341837848934, 0.09712685285402195, 0.277724735971008, 0.11997184450072901, 0.13146981038153172, 0.13176759225981577, 0.11627745202609471, 0.09677011306796755, 0.20275421600256646, 0.18686174521488802, 0.14820860432726995, 0.1075534119403788, 0.16851045350943292, 0.14423975800829275, 0.1939748413860798, 0.21790422020213945, 0.25429945439100266, 0.1169707112546478, 0.06594902370125055, 0.1328321322798729, 0.1068893229322774, 0.11921215669385024, 0.13601452937083586, 0.06656697232808385, 0.1426639554223844, 0.16194825991988182, 0.1629174929112196, 0.15330471444342816, 0.10157882967697722, 0.17363222581999643, 0.0579820183504905, 0.07699245254376105, 0.10211334563791752, 0.1254427230783871, 0.16564067107226166, 0.16370342645261968, 0.16368643593575272, 0.14403478614985943, 0.1571525236857789, 0.16202649500753197, 0.15789446101656981, 0.08139778686953442], [0.0541600036168737, 0.08766574731894902, 0.034562667166548114, 0.056519751636577506, 0.034967973096562285, 0.01151044074712055, 0.017419468046032956, 0.04587094519021256, 0.0552688926857497, 0.06985127859349761, 0.05341729614883661, 0.029950505189065422, 0.06916781062526361, 0.07274578006139823, 0.027236439753323793, 0.04371596886111157, 0.05929288015301738, 0.021438302039834004, 0.017454952034833174, 0.03829302199717079, 0.04581407717029963, 0.04936683903049145, 0.031043109417493855, 0.07666608398514134, 0.04260705604350992, 0.03128802323979991, 0.03152899816632271, 0.058028382648314746, 0.028440466217164482, 0.03668986427198563, 0.020780640454696755, 0.04693876253440976, 0.02438896076221551, 0.0583739537479622, 0.047222712476338656, 0.06395888049155474, 0.008424959661039923, 0.07332826166280679, 0.013607867128614868, 0.06007497997156211, 0.03082740992041571, 0.0407993573296283, 0.010665069234424403, 0.057322020908551555, 0.05377793072589806, 0.49131135642528534, 2.009483737604959, 13.071118814604622, 30.043889113834926, 55.13047824587141, 59.44603565761021, 66.55048533848354, 55.59446505137852, 55.92350394385201, 51.424225739070344, 53.360299587249756, 42.90688419342041, 31.405902794429235, 29.253104209899902, 20.68041331427438, 15.684523037501744, 17.86744032587324, 15.192833764212471, 17.05708408355713, 13.190584404127938, 11.752013734408788, 12.41018271446228, 20.712779760360718, 17.743383714130946, 25.344188383647374, 26.879015922546387, 48.949315616062705, 77.57638018471854, 71.74876621791294, 56.75578348977225, 48.38224533626011, 51.79677772521973, 39.399902548108784, 31.322757175990514, 24.097177812031337, 18.38230357851301, 9.821178827966962, 10.434911472456795, 13.259831019810267, 6.295547783374786, 5.836132024015699, 12.733841964176722, 13.3131080695561, 5.542855075427464, 8.394936868122645, 11.366079517773219, 13.601822222982134, 20.899849585124425, 26.91196254321507, 29.677972657339915, 26.585230452673777, 23.321145670754568, 24.142646823610576, 27.313771656581334, 30.73677042552403, 34.096731662750244, 54.17218269620623, 28.739168541772024, 16.87771807398115, 11.752232602664403, 10.612282480512347, 5.702485595430646, 18.128002984183176, 22.038817405700684, 26.747634172439575, 22.159660475594656, 36.85624347414289, 33.2040479523795, 42.1356897354126, 48.88208484649658, 44.61367791039603, 56.85674428939819, 55.97626856395176, 58.06902081625802, 43.53482069287981, 25.873241594859532, 7.8709341287612915, 3.172602410827364, 0.07795512410146849, 0.03295662227485861, 0.08662344289145299, 0.03547942904489381, 0.040019042058182616, 0.03201169101521373, 0.05668167723342776, 0.025146799561168467, 0.08538052280034338, 0.09607198874333076, 0.052352277761591334, 0.22187081378485474, 0.028675018809735775, 0.1247445105441979, 0.02506353992170521, 0.022949591212506806, 0.06933236893798624, 0.058676044323614666, 0.047641477148447714, 0.021541875321418047, 0.03990908885108573, 0.029702208869691406, 0.06051975967628615, 0.0411778339850051, 0.01443610223941505, 0.022896616287263374, 0.025574162968301346, 0.03415023661883814, 0.07904620841145515, 0.037526830432138274, 0.04469975642859936, 0.021003130390974026, 0.0516018553503922, 0.03263430796297533, 0.028738190419971943, 0.0341703857162169, 0.05820052019719567, 0.08480100639696632, 0.06657058213438306, 0.018394602595695426, 0.02059701021893748, 0.04592138409082379, 0.031237933784723282, 0.047204619340066395, 0.05360322831464665, 0.022154305762212192, 0.0612241875912462, 0.03395061840170196, 0.012486567654247795, 0.035755935457668135, 0.007774593175521919, 0.07040752803108521, 0.03813756283904825, 0.012869594735093415, 0.04613646951371005, 0.02652794062825186, 0.03482095152139664, 0.03483724653986948, 0.05456264290426459, 0.0456539429058986, 0.00973891219057675, 0.031036568339914083, 0.013665657956153154, 0.062018657103180885, 0.05337340511115534, 0.08539965748786926, 0.03961675560900143, 0.0652616134445582, 0.036115358849721294, 0.10679943061300687, 0.002597928442160732, 0.03845742763951421, 0.03145949582436255, 0.043518104656998596, 0.030560111227844442, 0.006462525276999388, 0.04576110394139375, 0.03064162363963468, 0.026701038304184164, 0.06101140579474824, 0.06894303232963596, 0.03891459400100367, 0.11387872216956955, 0.035897644103637764, 0.03392920044383832, 0.009702996483870914, 0.015127190155908465, 0.04252972001475947, 0.0383490927384368, 0.007110543183184096, 0.05115477201927986, 0.06827623596681015, 0.06703585359667029, 0.018980768642255237, 0.017229591895427023, 0.04602995647915772, 0.006663109134283981, 0.15154935792088509, 0.4990842736193112, 3.5073381747518266, 17.528984887259348, 39.1692327771868, 65.52532032557896, 67.72936534881592, 74.4919011252267, 63.819231850760325, 61.880330085754395, 58.966172218322754, 60.05844293321882, 54.58235222952706, 38.443288462502615, 38.41485643386841, 25.080023084368023, 22.890168019703456, 24.74571919441223, 22.741240331104823, 26.178609711783274, 20.688702515193395, 21.229788269315446, 22.47733211517334, 33.58602169581822, 20.701989207948955, 24.090153183255875, 26.347867829459055, 48.786689553942, 64.22420760563442, 46.77455030168806, 47.38047143391201, 37.2321583884103, 37.77197435923985, 32.70206839697701, 25.56986587388175, 18.316544089998516, 16.178781407220022, 9.235363176890782, 6.5560778720038275, 7.064078910010202, 4.3462875570569715, 4.914546413081033, 7.33335634640285, 9.128549388476781, 5.51649317571095, 7.015648663043976, 10.582421728542872, 15.059619426727295, 17.308817318507604, 22.785818236214773, 29.61520610536848, 30.585053035191127, 21.50552579334804, 25.289702347346715, 33.06100191388811, 38.680520806993755, 32.19713238307408, 48.01665544509888, 28.65537326676505, 25.381180592945643, 20.684795890535625, 21.551908493041992, 14.818449190684728, 29.139089482171194, 35.22408383233206, 38.25128541673933, 33.82244457517351, 47.76875066757202, 38.10826717104231, 49.82120336805071, 56.324560914720806, 52.47151034218924, 62.14324992043631, 65.18647057669503, 69.52279267992292, 54.61523110525948, 35.339225905282156, 12.084554518972125, 4.378631855760302, 0.506970858999661, 0.012738948754434074, 0.06962891588253634, 0.02531024338012295, 0.056094730871596506, 0.015392193703779151, 0.02010478395303445, 0.03198459032656891, 0.060730539794479094, 0.020530825913218514, 0.029981137652482306, 0.06880212774766342, 0.04105475791064756, 0.12858600941087517, 0.010808572605518358, 0.026358624088710973, 0.01622375363617071, 0.06782352418771811, 0.015019776366118873, 0.010218033400763358, 0.024291699552642446, 0.01576637353615037, 0.016554854976545488, 0.003941287195110428, 0.026113601700801934, 0.010746793688407965, 0.028325003305716173, 0.037850488243358474, 0.039986770932695696, 0.05027286987751722, 0.03017530044806855, 0.01963653032934027, 0.07406667739685092, 0.0421908833751721, 0.012792159470596483, 0.04740224266424775, 0.007538045689995799, 0.0727925854069846, 0.026471678200843077, 0.024926687890131558, 0.01486899740328746, 0.01527959421010954, 0.01684281845310969, 0.03684708422848156, 0.056323149507599216, 0.04284208021791918, 0.00858600061785962, 0.049980584132884226, 0.03987176263970988, 0.025041289062106183, 0.018892743990623524, 0.07251735803272043, 0.04185386520943471, 0.1169729232788086, 0.24560196538056644, 0.07479848419981343, 0.12730011769703456, 0.09198877534696034, 0.11361230217984744, 0.1343546970082181, 0.13393781866346086, 0.20181292508329662, 0.16654935159853526, 0.17546224833599158, 0.12074517086148262, 0.19671317801943847, 0.1792036225753171, 0.19372184281902655, 0.11694571402456079, 0.18257504595177515, 0.11509901311780725, 0.16408564522862434, 0.14946599757032736, 0.1115767921188048, 0.24730848095246724, 0.10192008529390607, 0.1916233239961522, 0.0858253567878689, 0.11729210615158081, 0.10884896599288497, 0.24480740087372915, 0.19997910277119704, 0.24481025072080748, 0.08246549564812865, 0.17524618921535356, 0.13127303522612366, 0.22527201127793106, 0.20663991464035852, 0.176313579082489, 0.07044235044824225, 0.16985484851258142, 0.10195616300084762, 0.13621262088418007, 0.09411948387111936, 0.11121237810168948, 0.21499725404594625, 0.2414179284657751, 0.26507212061967167, 1.0371902819190706, 5.021106592246464, 23.67088498388018, 50.440850666591096, 76.58729716709682, 76.58034896850586, 83.80858775547573, 72.34455340249198, 74.64902768816266, 66.94867270333427, 68.04584884643555, 59.148173332214355, 46.88946655818394, 45.020269121442524, 32.721512930733816, 26.19236019679478, 28.553900037493023, 26.288368667875016, 27.96871406691415, 22.762246472494944, 20.30983461652483, 20.355201142174856, 32.35214669363839, 26.38456300326756, 35.909544467926025, 39.64070974077497, 63.59673663548061, 91.58680425371442, 88.69586031777519, 72.9175921848842, 60.753679684230256, 64.95759691510881, 51.442749636513845, 39.41734947477068, 32.2658292225429, 24.836808340890066, 13.948730145181928, 15.299618891307286, 17.1230502809797, 8.709861363683428, 7.843484401702881, 16.7777612890516, 16.298436335154943, 7.7736645596367975, 10.542397499084473, 15.691347905567714, 18.48368648120335, 28.67267254420689, 34.74227837153843, 36.55975341796875, 32.2501471383231, 31.72856671469552, 33.702101775578086, 37.83079086031233, 40.62372350692749, 47.999691418239046, 72.73336069924491, 41.12717955453055, 29.372509002685547, 22.71760082244873, 22.57601043156215, 16.346531765801565, 29.687668868473597, 34.28987768718174, 40.0065358706883, 35.01656893321446, 50.15398733956473, 49.81536340713501, 59.00126756940569, 65.56062412261963, 62.99341760362898, 71.82652350834438, 73.24782616751534, 78.5840287889753, 62.464034352983745, 39.04025336674282, 14.650750943592616, 5.433324541364398, 0.8127566277980804, 0.10938972447599683, 0.17724386416375637, 0.11889411375990935, 0.10352201826338257, 0.14710822408752783, 0.16683873321328843, 0.10292280398841415, 0.2110714947006532, 0.15337019307272776, 0.15754141924636705, 0.39584457342113766, 0.19569587760737964, 0.23977125968251908, 0.24421153856175287, 0.12765792278306826, 0.1460268563990082, 0.1481342911720276, 0.14737990950899466, 0.06936355440744332, 0.13692155427166394, 0.12258884550205298, 0.17146080519471849, 0.17021508275398187, 0.05353894051430481, 0.15073799288698606, 0.08325327480477945, 0.08710478884833199, 0.25568681423153194, 0.13269134983420372, 0.11479414733392851, 0.0896015330883009, 0.17889111648712838, 0.07964863894241196, 0.11231104843318462, 0.09047406126878091, 0.09158286891345467, 0.176114076216306, 0.15601825740720543, 0.1118937222553151, 0.10379272659442254, 0.11750389050160136, 0.12497215904295444, 0.14068202248641423, 0.1600741326276745, 0.12761256950242178, 0.15493475911872728, 0.163132656365633, 0.11990988068282604, 0.1638219936617783, 0.12627744328762802, 0.15022191272250243, 0.21876543041850838], [0.07925584859081677, 0.031057019385376146, 0.02645412619624819, 0.03888773758496557, 0.022363269102892706, 0.04391095268407038, 0.018049832167369977, 0.05003403572897826, 0.025678367287452732, 0.03222415050757783, 0.0376300864986011, 0.018159591991986548, 0.02300473066445972, 0.03965225995385221, 0.0028843170813550906, 0.023942588196535195, 0.04017103050968476, 0.0029459426919597066, 0.022665295217718397, 0.04091996692919305, 0.009100610905859088, 0.04814219528010913, 0.03396879635485155, 0.034788710929985554, 0.05996242458266871, 0.060179813631943295, 0.036424336555813036, 0.04122284799814224, 0.02298544839556728, 0.015693695650302937, 0.048565808084926436, 0.03894116882500904, 0.060503271275333, 0.04151428218132683, 0.046351649931498935, 0.015142116229981184, 0.06399144338709967, 0.05350439290383032, 0.024387047293462923, 0.06907432885574442, 0.04324753203296235, 0.03024704534826534, 0.032977952023169825, 0.07797085932855095, 0.9526861820902143, 10.832401411873953, 28.76501410348075, 48.46393183299473, 59.21736349378313, 66.05621828351701, 64.29081303732735, 55.15517214366368, 46.567883082798545, 48.110706261226106, 44.47689914703369, 63.007591928754536, 22.59996782030378, 16.754569939204625, 16.419932535716466, 15.245648758752004, 21.631941318511963, 16.30434925215585, 14.002961703709193, 10.79841777256557, 15.114110674176898, 18.581433738980973, 21.915896824428014, 18.270067589623586, 39.9836346081325, 48.31813430786133, 58.1050055367606, 38.45074735369001, 36.057172843388145, 38.160830293382915, 25.468707050595963, 16.92160984448024, 10.479661345481873, 8.357726659093585, 9.312197225434439, 6.6298490677561075, 1.747032797762326, 1.0782128806625093, 1.218205294438771, 0.9452348904950278, 0.4797545479876654, 0.40125920144574984, 0.14159348500626429, 0.13386155132736477, 0.5207425143037523, 1.5354716586215156, 2.9235214335577826, 2.299645721912384, 2.206714000020708, 3.2409529260226657, 2.639929622411728, 5.823863676616123, 14.554395062582833, 20.384063959121704, 12.018147110939026, 18.80662832941328, 29.041946717670985, 30.967575686318533, 51.46029731205532, 50.831742422921316, 48.30620425088065, 34.00626611709595, 33.04641417094639, 21.126960141318186, 14.921319007873535, 13.92442274093628, 12.962152821677071, 20.55062791279384, 21.644411597933086, 36.181608131953645, 30.733007975987025, 36.72792066846575, 47.953993116106304, 49.283072335379465, 55.18462208339146, 54.825355052948, 58.467798777988975, 44.20775025231497, 26.82348244530814, 15.101730721337454, 3.3995915906769887, 0.6551606814776147, 0.05077366604070578, 0.06420970774654831, 0.055022428410926034, 0.022123142345143215, 0.04593683094052332, 0.02068576599205179, 0.10170704565410103, 0.05295894235106451, 0.09854863477604729, 0.048931504533227, 0.03795391733625105, 0.024283100817618624, 0.0400927479245833, 0.055661197884806564, 0.04233499742778284, 0.07231711556336709, 0.04718138290835278, 0.01600440701336733, 0.06759744989020483, 0.05485077601458345, 0.01930669954578791, 0.012861996839222099, 0.05039889418653079, 0.011963619867206683, 0.013710846692057592, 0.031139254436961243, 0.027634663474080817, 0.04888518773285406, 0.046611756152872524, 0.019056488061323762, 0.024113855524254695, 0.05707096295165164, 0.043436575281832895, 0.08999436415199723, 0.0036525942934011774, 0.056912850721606185, 0.07566128897347621, 0.016314173516418253, 0.012617515582990433, 0.09549083028520856, 0.019276006014219353, 0.04970780287736228, 0.042347984588039775, 0.05982353524970157, 0.036922367688800604, 0.04047050194016524, 0.05869576255125659, 0.061084863995867114, 0.044381703316633186, 0.033525353364114246, 0.040853355146412335, 0.025692056731453965, 0.028404303693345616, 0.02561853576584586, 0.005545157806149551, 0.05967267655900546, 0.031080540801797594, 0.02009497064032725, 0.0636429206601211, 0.05969293082931212, 0.053917054153446636, 0.05120049849418657, 0.06191290742052453, 0.024754838718633567, 0.0016597556033437805, 0.03434722890545215, 0.06297457723745278, 0.03634433727711439, 0.019531688187271357, 0.05490268733618515, 0.02442520301389907, 0.05208704860082694, 0.003821060967831207, 0.012154134688898921, 0.05182256922125816, 0.017353019111656716, 0.07294099458626338, 0.09842223048742328, 0.03468091207157288, 0.05460589611902833, 0.03135251799332244, 0.03400370019621082, 0.002538568290349628, 0.028827770613133907, 0.026709241792559624, 0.03465582323925836, 0.0361896075441369, 0.02551338658668101, 0.06835381287549223, 0.04319550875308258, 0.009093420979167734, 0.018948088699419583, 0.07645438105932303, 0.22561448147254332, 1.5318256999765123, 16.42005065509251, 36.16246584483555, 56.76009137289864, 68.89874022347587, 72.4750336238316, 75.15369619641984, 62.44569110870361, 53.24087047576904, 53.68790020261492, 53.25932489122663, 70.92322295052665, 32.18855830601284, 29.030296325683594, 25.79802213396345, 22.57379048211234, 26.581389835902623, 21.284376791545323, 20.31535496030535, 15.148957627160208, 21.071659428732737, 22.38936792101179, 21.788070814950125, 24.552760771342687, 33.44174930027553, 39.60020521708897, 41.82172843388149, 30.541612897600444, 31.68257658822196, 33.685902050563264, 19.49188573019845, 13.814149618148804, 9.008367265973773, 6.556898627962385, 5.422774570328849, 3.7990265914372037, 1.0840216832501548, 0.5434309882777077, 0.5614562439067023, 0.41624931565352846, 0.31983052087681635, 0.13605410153312342, 0.011576619963826877, 0.04226758497368012, 0.28274152534348623, 0.572767476950373, 1.1979856022766657, 1.602707096508571, 1.9913910627365112, 2.8107191664831976, 2.467568265540259, 4.0688789912632535, 9.744604468345642, 13.578789813177925, 9.444886105401174, 12.446789298738752, 23.047640255519322, 29.663843495505198, 37.88042531694685, 41.296149321964805, 39.109193393162315, 30.75215026310512, 35.02439260482788, 25.799321447099956, 23.844147000994, 24.36229501451765, 21.339550699506486, 27.233485221862793, 33.434599603925435, 45.42428255081177, 40.038514954703196, 45.0689377784729, 57.75271102360317, 57.03484051568167, 61.94418403080532, 61.52870259966169, 66.333388873509, 56.38973501750401, 36.51014675412859, 20.718181984765188, 4.486617284161704, 0.8858899463500295, 0.07362818092639957, 0.027391666513202444, 0.018972110535417284, 0.01215762659973864, 0.08057804871350527, 0.01519987652344363, 0.054997251369059086, 0.0495891169245754, 0.10280513923083033, 0.05188419037897672, 0.03813589025022728, 0.02677657112612256, 0.030444770452699492, 0.07817072860364403, 0.009902075265667267, 0.013526308915710874, 0.04457951323794467, 0.015157973593366998, 0.04364122483613236, 0.05523243499919772, 0.022761684509792497, 0.02933408665869917, 0.05619922187179327, 0.03739794949069619, 0.014814122579991817, 0.05139212356880307, 0.07461734249123506, 0.013511527878498393, 0.024414594118882502, 0.019761077128350735, 0.018121595727279782, 0.04762546032933252, 0.001505595733760856, 0.0555815582296678, 0.031733746108199866, 0.05068966340539711, 0.07373315029378448, 0.05297774116375616, 0.03255359282983201, 0.05152228354875531, 0.03322020598820277, 0.021888854381229197, 0.036412085606051345, 0.0803741082283003, 0.04370341935594167, 0.012021081605260926, 0.021551459628556455, 0.044770147651433945, 0.016186742943578532, 0.04392023504312549, 0.24022633954882622, 0.11902634666434356, 0.09458075876214675, 0.16089965190206254, 0.08569612979356732, 0.12951432674058846, 0.13680347560771874, 0.12355939485132694, 0.18114227854779788, 0.1325014414531844, 0.11670032862041678, 0.059935954931591234, 0.19116086166884216, 0.1458732360707862, 0.13314104213246278, 0.0904989635039653, 0.14922826604119369, 0.12048735469579697, 0.12230942478137356, 0.115361999720335, 0.10307502653449774, 0.13739947362669877, 0.08501984072583062, 0.10348558093288115, 0.12112394267959253, 0.15691674633749894, 0.15521940455905028, 0.257120884422745, 0.14741545117327146, 0.097918133251369, 0.1657215795878853, 0.14832628944090434, 0.1300731546112469, 0.22411434911191463, 0.12426741900188581, 0.11197330762765237, 0.14344497637024947, 0.11396162557814803, 0.1467719692736864, 0.17354424696947846, 0.11070081698043005, 0.1256708058395556, 0.13408371726317064, 0.50008774548769, 3.0482954468045915, 21.80001129422869, 45.71183027539934, 64.99656936100551, 75.47905254364014, 80.0708668572562, 80.77339921678815, 70.59915896824428, 60.974361419677734, 62.51608330862862, 60.87805938720703, 74.90684754507882, 34.636349609919954, 28.48963267462594, 27.548975127083914, 26.092931474958146, 32.38099561418806, 27.094859974724905, 24.09792821747916, 19.615158932549612, 24.333751814705984, 27.594880138124736, 31.243638038635254, 26.174741302217754, 56.14689200265067, 63.18263789585659, 72.9875397000994, 52.084971632276265, 45.87323692866734, 47.849933419908794, 32.57868228639875, 22.279238973345073, 13.93324261052268, 11.067394699369158, 12.140573501586914, 9.16824357850211, 2.4500989743641446, 1.924379595688411, 1.9774340859481265, 1.6979372607810157, 0.9781592552150998, 0.9142068411622728, 0.3495837928993361, 0.29419405651944025, 0.8123878304447446, 2.424615804638181, 3.676328786781856, 3.107100874185562, 3.3454874881676266, 4.108764691012246, 3.702871773924146, 8.34491765499115, 18.821980374200002, 26.440912893840245, 16.956620080130442, 24.65155373300825, 40.32604530879429, 40.130363191877095, 64.69933932168144, 65.80673626491001, 63.50162969316755, 49.30618551799229, 45.90156473432268, 32.6459721156529, 24.754270689828054, 22.243306364331925, 23.59822940826416, 31.56843852996826, 35.72828681128365, 50.77286686216082, 45.444713728768484, 51.017259325299946, 65.7079050881522, 64.19867992401123, 71.4879377910069, 71.88931437901088, 75.5812258039202, 62.78144196101597, 41.564339365277974, 23.52824194090707, 5.160089237349374, 0.8817207557814462, 0.28371660730668474, 0.11814549964453493, 0.1769856001649584, 0.1627174743584224, 0.15590194293430873, 0.10474085714668036, 0.1799669744712966, 0.1479784995317459, 0.20587601991636412, 0.12418435274490289, 0.13996185255902155, 0.10713900346308947, 0.17950839336429322, 0.15389867685735226, 0.17043754724519594, 0.1279697096241372, 0.210597890828337, 0.05073326945837055, 0.16382504706936224, 0.08633353880473546, 0.14467136056295463, 0.1418956909328699, 0.1536119415291718, 0.1596084947564772, 0.19150486535259656, 0.28643110021948814, 0.11648280386413846, 0.10002224998814718, 0.08760854681687695, 0.16251122685415403, 0.06756214571318456, 0.20138859642403467, 0.11583990550466947, 0.1303900440356561, 0.06953154610736029, 0.19867111795714923, 0.19347348543150084, 0.1394312246037381, 0.11607203233454909, 0.1939457186630794, 0.06934332727853741, 0.16722051772688115, 0.10922933236828872, 0.18822365999221802, 0.10592033421354634, 0.10498073284647294, 0.1751733281250511, 0.1546922642737627, 0.15012279232697828, 0.15565092568950994], [0.033319306027676375, 0.05406431321586881, 0.039736930946154256, 0.05662075157410332, 0.04562959028407931, 0.020156306813337972, 0.045476268511265516, 0.021499745082110167, 0.06766209392143147, 0.03507666422852448, 0.011170228377782872, 0.029586912199322666, 0.039662549937410016, 0.026261498586141636, 0.046725427731871605, 0.05733152718416282, 0.006481315183918923, 0.025873137371880666, 0.03415240114554763, 0.017773892331336225, 0.048211575485765934, 0.07306295447051525, 0.04238911738087024, 0.04294580786621996, 0.04904724903670805, 0.06603878031351737, 0.09673493781260081, 0.028745610200400864, 0.038881074371082444, 0.01808722792858524, 0.009942326811142266, 0.02461690442370517, 0.05105506129828947, 0.06230301755879607, 0.051180559742663584, 0.04124405221747501, 0.06859312539121934, 0.04656346481559532, 0.02154761572767581, 0.03544232335739902, 0.0722316676484687, 0.03188373288139701, 1.6555040691580092, 7.470330527850559, 22.414240734917776, 55.77435391289847, 60.328950200762065, 56.76068196977888, 59.65088939666748, 54.96729980196272, 34.228882925851, 41.13115045002529, 47.90750619343349, 38.74784885134016, 20.074733631951467, 11.839224049023219, 17.054403815950664, 9.317730597087316, 16.434898955481394, 12.724430629185267, 15.962444032941546, 22.226258959089005, 39.884786060878206, 41.99695158004761, 40.41252258845738, 52.26611116954258, 61.48162160600935, 59.619525228227886, 41.69552135467529, 33.30966404506138, 23.01503930773054, 17.32882639339992, 9.49037161895207, 2.099778401000159, 2.058970327888216, 0.5414876097014972, 0.4513438253530434, 0.2552640326321125, 0.050386653414794376, 0.05808822265160935, 0.025918005499988794, 0.01550865066902978, 0.05555194356877889, 0.07910716121218034, 0.07040538386042629, 0.01733043576989855, 0.0738739123834031, 0.08881828654557467, 0.0790518606081605, 0.0707900317917977, 0.06157790789646762, 0.19346310384571552, 0.17030873415725573, 0.3007324742419379, 0.8270339816808701, 0.9191118351050785, 0.22190951742231846, 0.5236681401729584, 1.160971462726593, 1.9725872831685203, 1.568125152162143, 7.211922245366233, 15.12366271018982, 21.971404245921544, 32.04847567422049, 43.297411169324604, 44.550657749176025, 44.507162025996614, 45.0168262890407, 29.271416187286377, 38.84234435217721, 36.641641412462505, 9.968047244208199, 19.987910679408483, 20.37997841835022, 17.154713221958705, 23.515818561826432, 41.2486583845956, 38.817938804626465, 46.20548241479056, 48.50385965619768, 58.9569866997855, 56.07161174501692, 44.85048988887242, 26.05332326889038, 15.181126049586705, 6.971953613417489, 1.0054339745215006, 0.2650487518736294, 0.1592201284532036, 0.023372206570846692, 0.08307631965726614, 0.07382577032382999, 0.0546654036401638, 0.06570542962955576, 0.0635431217295783, 0.12188633105584554, 0.0613043090062482, 0.008437250474733966, 0.012673231789709201, 0.03007148459021534, 0.019458382656531673, 0.03820154869130679, 0.06493728049099445, 0.03759791715336697, 0.03007742516430361, 0.00963624136056751, 0.042864271705704074, 0.07851957024208137, 0.029606586322188377, 0.03162234422883817, 0.04076403958190765, 0.0988041167812688, 0.06417831871658564, 0.04751636886170932, 0.004926649387925863, 0.014698191479380642, 0.02733322429204626, 0.017170394804062586, 0.01731273448759956, 0.0496949446387589, 0.0515590330053653, 0.00670405024097168, 0.03531649582354086, 0.04087201825210026, 0.01863498380407691, 0.08262148406356573, 0.023547821611698185, 0.05298124240445239, 0.025294150225818157, 0.017058660442541753, 0.05529431060754827, 0.02470531584029751, 0.003400392156826066, 0.01952705209675644, 0.05768119663532291, 0.017120196783382977, 0.03594393376260996, 0.007615696389361152, 0.093762018052595, 0.03355207068047353, 0.008192422317474015, 0.07373125039573226, 0.049551824639950476, 0.015173456066155007, 0.04823277291974851, 0.011985366914554365, 0.0731780475803784, 0.019631429442337582, 0.042786562482693365, 0.03535253281838127, 0.03374498157895037, 0.04486191272735596, 0.031234690387334143, 0.004201101646426001, 0.034776704252830574, 0.04944782218496714, 0.08884312771260738, 0.02082333727074521, 0.05226899776607752, 0.022591513016128113, 0.018660540825554302, 0.031530151675854406, 0.05512727564200759, 0.026845181194533194, 0.01273007012371506, 0.013211634908137577, 0.02998669146160994, 0.0660399609644498, 0.03450115457443254, 0.050681297068617175, 0.02190473549334066, 0.04617122407736523, 0.08042900849665914, 0.028189108008518815, 0.01735942787490785, 0.026771604249786054, 0.07304560433008842, 2.212621054479054, 9.607460924557277, 29.055222988128662, 65.80431134360177, 69.0967777797154, 65.48836285727364, 67.52296216147286, 64.65482916150773, 42.85986573355538, 47.72747489384243, 55.3861927986145, 50.29342726298741, 29.110082490103586, 22.40782059941973, 19.430566140583583, 13.507924267223903, 24.195656367710658, 14.020928008215767, 21.833816017423356, 24.09813666343689, 33.40593828473772, 31.585968835013254, 32.31326804842268, 39.788827964237754, 40.7051112311227, 38.74397523062569, 33.418187958853586, 27.952491760253906, 21.77862995011466, 15.775667769568306, 7.14960081236703, 1.9151486967291151, 1.5997375015701567, 0.6849873438477516, 0.4166361620383603, 0.28303275257349014, 0.06565327064267226, 0.03579040503661547, 0.022117685227255737, 0.05298948321225388, 0.062130377894001346, 0.13310072358165467, 0.04763197087283645, 0.09159636497497559, 0.08532440795430116, 0.012203893358153957, 0.10557971641953502, 0.03539671901879566, 0.06055260755653892, 0.07846359110304288, 0.05451134226417967, 0.19990252330899239, 0.5093727644000734, 0.7458560062306268, 0.12432795789624963, 0.3737356226359095, 0.5670480238539832, 1.5723435772316796, 1.1872175229447228, 4.55985129731042, 11.071995275361196, 17.511914900371007, 24.578191178185598, 35.0791791507176, 37.275862557547434, 37.92215272358486, 34.711727142333984, 28.0227050440652, 42.603626591818674, 35.78191300800869, 16.73027903693063, 30.166427544185094, 32.37197685241699, 26.339889560426982, 31.182681492396764, 45.75066723142351, 46.971354552677695, 52.592270033700125, 55.71662480490548, 66.4285444532122, 67.70595686776298, 55.46317883900234, 38.36510385785784, 23.19073666845049, 11.639183674539838, 2.0730300077370236, 0.5515060978276389, 0.17823223184262002, 0.14663434880120413, 0.06455612701496907, 0.05310947873762675, 0.024371717491054108, 0.06624719234449522, 0.015285583977986659, 0.007858307433447667, 0.11718626825937203, 0.014335463621786662, 0.013170114502177706, 0.046749559829809835, 0.012574400619736739, 0.018480863056278655, 0.07042996039880173, 0.043661309472684345, 0.055280125832983425, 0.052355178498796055, 0.03104118237804089, 0.012326719222723373, 0.016451943266604627, 0.0271984316142542, 0.06832238991877862, 0.015133721055462956, 0.04111722384446433, 0.0467157416444804, 0.03068391333467194, 0.011391816710654114, 0.03297696475471769, 0.03217735534001674, 0.08165842574089766, 0.02157693522583161, 0.02052203379571438, 0.026483053840430718, 0.032111808857215304, 0.005970445320209754, 0.018357759840520363, 0.05071866738476923, 0.005613591879539723, 0.011301616506118859, 0.03566546977630683, 0.033347146319491525, 0.02576533003178026, 0.02947562567091414, 0.04006405607131975, 0.02178938114749534, 0.020942013045506816, 0.0939518925068634, 0.18356038736445562, 0.12788688763976097, 0.1873951551637479, 0.09842695309115307, 0.11975702031382493, 0.19860110671392509, 0.12617441453039646, 0.19525557623377868, 0.15821462097976888, 0.17809055373072624, 0.10618957012359585, 0.141068502462336, 0.08708521311304399, 0.1814479042908975, 0.13116364181041718, 0.12594538182020187, 0.11659660775746618, 0.13554825367672102, 0.09101538293595825, 0.1711390438888754, 0.15185757566775593, 0.06209656649402209, 0.09087236811007772, 0.13426164271576063, 0.0937338520639709, 0.16252804095191614, 0.10129045229405165, 0.0780327824343528, 0.09716396193419184, 0.12074084180806365, 0.09086225115294967, 0.11453388844217573, 0.07371534553489514, 0.13816361262329988, 0.13182792759367398, 0.14376723979200634, 0.1718811033559697, 0.17210706908787998, 0.13121149209993227, 0.14676876658839838, 0.22930086723395757, 3.4599712193012238, 13.997679335730416, 38.52226516178676, 77.20529774257115, 79.33849198477608, 74.14459541865757, 77.0126519884382, 73.31133965083531, 48.6036878994533, 57.88321556363787, 62.932454109191895, 52.53976944514683, 32.98069116047451, 21.829817329134258, 28.47241156441825, 16.5601350239345, 25.947415351867676, 22.11202015195574, 25.610504150390625, 33.483341217041016, 53.25879682813372, 56.9278347832816, 54.69952665056501, 67.09551593235561, 75.98103209904262, 74.23071139199394, 53.623830863407676, 43.20812334333147, 30.726299490247452, 22.876012802124023, 12.598257422447205, 2.9707989309515273, 3.2811808245522633, 1.1715568261487144, 0.9490588967289243, 0.6923915179712432, 0.3577079198190144, 0.15224664764744894, 0.17995173457477773, 0.14476366846689157, 0.14417684424136365, 0.2151118314691952, 0.11383332817682199, 0.15113686291234835, 0.29871879943779533, 0.357667262000697, 0.24367728722946985, 0.19552909369979585, 0.1802055880959545, 0.350696753178324, 0.5880097619124821, 0.75599462219647, 1.5338697731494904, 1.6406001831804002, 0.4876195288130215, 1.1374688552958625, 1.995527412210192, 2.986023953982762, 2.298443683556148, 9.556089418275015, 20.44858145713806, 27.26292995044163, 40.17369563238961, 54.75784635543823, 56.003248419080464, 58.02109909057617, 57.72746474402291, 41.07128129686628, 51.68293496540615, 48.521313531058176, 19.677479062761577, 31.210231099809917, 32.06651667186192, 28.01611294065203, 35.27835621152605, 55.21868562698364, 54.62124824523926, 59.95767320905413, 65.26595102037702, 74.21132591792515, 78.51676327841622, 64.94304043906075, 44.66973945072719, 26.364432334899902, 13.930242725781032, 2.454130015202931, 0.7218294611998967, 0.2868681310542992, 0.3126308572079454, 0.18315859963851316, 0.15286233675267014, 0.1511681162353073, 0.1492408053683383, 0.17692614692662442, 0.20881410368851253, 0.19863364925341948, 0.18142895959317684, 0.13762930700821535, 0.10790935784046139, 0.10707278523061957, 0.0970191489905119, 0.10737917771829025, 0.1937959117016622, 0.11012685099350554, 0.12033908122352191, 0.11525978520512581, 0.20912549697927066, 0.1615000061158623, 0.12164219415613584, 0.25709385158760206, 0.18423414549657277, 0.13818797203046934, 0.10533238361988749, 0.07981821162892239, 0.09666338629488434, 0.133593652131302, 0.12394237358655248, 0.23886435691799435, 0.16674937015133245, 0.15518654989344732, 0.16246356655444416, 0.16070180466132505, 0.1349249921206917, 0.07593929155596665, 0.2002177435372557, 0.08417351078242064, 0.07894165973578181, 0.19960319437086582, 0.11360406476472105, 0.08799576639596905, 0.10680783087653772, 0.1160839745508773, 0.16706092629049504, 0.15829938357429846], [0.037644298414566686, 0.059577912358301024, 0.03621966664546302, 0.028205855949116603, 0.04185057092191918, 0.0069655287994204885, 0.07401980419776269, 0.05111592588946223, 0.06621874815651349, 0.022816131856026392, 0.011864479963800736, 0.023806981276720762, 0.09882055768477065, 0.0745319217177374, 0.08324408744062696, 0.030460977261619906, 0.0185347845378731, 0.10104416443833283, 0.07635799515992403, 0.007633688593549388, 0.07024455070495605, 0.042507338537169356, 0.04990281044904675, 0.03991398108857019, 0.03748495464346238, 0.033928986705307446, 0.0494671231135726, 0.02190718670109553, 0.02980241152857031, 0.03378285401101623, 0.028399252000131776, 0.06030397196965558, 0.0534903472289443, 0.09106087192360844, 0.03676686442590185, 0.061816426526222906, 0.016969322825648954, 0.08930575288832188, 0.045021819682525735, 0.051559222995170524, 0.03151319169306329, 1.3256788360221046, 16.283883333206177, 42.70826646259853, 58.84157712118966, 60.728193691798616, 61.72219603402274, 57.335687092372346, 49.92628444944109, 47.11555051803589, 71.08484499795097, 64.63017000470842, 40.63882541656494, 19.88968399592808, 19.754498107092722, 17.944395099367412, 21.751462493624004, 39.351084504808696, 35.92299270629883, 37.956303119659424, 40.10772943496704, 41.15822063173567, 44.17648335865566, 50.49148218972342, 50.16885301045009, 50.30447837284633, 37.98581559317452, 32.47648818152291, 11.142117364065987, 6.881004733698709, 2.49760684796742, 0.4663630351424217, 0.06562219373881817, 0.22982716613582202, 0.02866771098758493, 0.0713893071349178, 0.04297642336626138, 0.08098664214568478, 0.019732607495305792, 0.05460722265498979, 0.05894908681511879, 0.07625194013650928, 0.16186053891267094, 0.010440821892448833, 0.02666010907185929, 0.0351515575312078, 0.037360877729952335, 0.05599450107131686, 0.047877196821251085, 0.007853733259253204, 0.13261285690324648, 0.07210884602474314, 0.03330936209697809, 0.09633911440947227, 0.1093008363885539, 0.03286140684836677, 0.050729320384562016, 0.1094647975904601, 0.051641240915549655, 0.08408485339688403, 0.15621807239949703, 0.07648049108684063, 0.6516854965261051, 1.0255143770149775, 3.2198642747742787, 7.2977164302553446, 22.91117937224252, 26.901965822492325, 44.2906631061009, 54.15865455354963, 41.87968683242798, 62.59855842590332, 57.33560371398926, 27.355646712439402, 13.59990017754691, 16.286134549549647, 19.82977315357753, 17.037165335246495, 19.547254187720164, 28.25486867768424, 37.19219582421439, 44.80479506083897, 42.3810202053615, 54.115002495901926, 62.472497258867534, 56.28733941486904, 43.326659611293245, 26.888508898871287, 15.861182723726545, 7.342914462089539, 0.7295548266598156, 0.12880299133913858, 0.0303102203511766, 0.035524314136377404, 0.05659698249240007, 0.05140377740774836, 0.05088147507714374, 0.02283885090478829, 0.015007941019056099, 0.02035599118763847, 0.04449955467134714, 0.07286104280501604, 0.04519072401204279, 0.030374192632734776, 0.0193631841934153, 0.06567832894091095, 0.039565848519227335, 0.060332355089485645, 0.027138047086607133, 0.05075068405962416, 0.03456852970910924, 0.025640406645834446, 0.08699186705052853, 0.029487503426415578, 0.04097996638821704, 0.02806344671574022, 0.03832246023895485, 0.01859203932274665, 0.02398174984513649, 0.03605265882132309, 0.068891402600067, 0.058106468458260806, 0.06375275512358972, 0.01910125440917909, 0.007191060693003237, 0.02867524272629193, 0.021855153243190477, 0.03205698322770851, 0.021137183465595757, 0.08048953382032258, 0.011062248011252709, 0.050067633390426636, 0.07143535930663347, 0.05950388418776648, 0.053064661499645026, 0.04968834249302745, 0.002957948308903724, 0.03467781116653766, 0.0855652539591704, 0.029822547055248703, 0.03641623824036547, 0.07574990564691168, 0.13933958166411944, 0.016775584114449363, 0.028799109293946197, 0.04019822958590729, 0.042049710771867206, 0.011253517703153193, 0.0421423918700644, 0.03196279578176992, 0.07619970651077372, 0.04697350013468947, 0.10209783432739121, 0.03739209373348525, 0.07373829358922583, 0.02846724120900035, 0.023965174930968454, 0.03832842795444386, 0.03953796072996088, 0.037227996824575324, 0.05553238818954144, 0.023816100787371397, 0.01566072054473417, 0.02510059641541115, 0.050420474992798905, 0.03523229302040168, 0.047684937316392145, 0.03462319588288665, 0.005376437953340688, 0.04433084711698549, 0.01628462501269366, 0.08145509593720947, 0.010144707513973117, 0.02638449493263449, 0.034014197132949314, 0.05376477053921137, 0.06599464839590446, 2.0055768958159854, 22.632900544575282, 52.52016857692173, 68.4381024496896, 69.21339634486607, 68.5987309047154, 68.08828149523053, 56.792397022247314, 56.4729813848223, 66.35793685913086, 69.66975402832031, 52.802088260650635, 30.32422808238438, 29.26366547175816, 23.53821607998439, 30.72901623589652, 25.749148505074636, 30.089038508278982, 31.940962723323278, 28.255803210394724, 33.822875363486155, 40.589427198682515, 42.73583344050816, 38.485151359013145, 35.433380944388254, 31.92588860648019, 23.44948410987854, 10.856660178729467, 5.317961863109043, 1.945622410093035, 0.6908693739346096, 0.16466457130653517, 0.22834785122956547, 0.04973542943064656, 0.047153624040739875, 0.05071038586486663, 0.130448330193758, 0.039619330649397204, 0.0846169673438583, 0.011537952797620423, 0.03376619258363332, 0.09090427282665457, 0.06569676473736763, 0.17100086701767786, 0.2007180138358048, 0.05514083616435528, 0.027488137229478786, 0.17187977342733315, 0.13636051437684468, 0.044455565246088166, 0.08474234025925398, 0.057145533950201104, 0.051668629981577396, 0.03025697570826326, 0.02746114001742431, 0.14751051392938408, 0.10893652415169136, 0.03662075887301138, 0.0691124964505434, 0.09138931001403502, 0.10620974975505046, 0.4528300884578909, 0.9859862923622131, 2.254475917134966, 5.944502643176487, 14.033210686274938, 22.36065101623535, 34.63172558375767, 39.42442968913487, 35.39584330150059, 57.03777960368565, 49.756602491651265, 30.40337153843471, 19.061342341559275, 20.333581822259085, 24.85481286048889, 26.276996203831263, 29.469439847128733, 36.269374302455354, 46.28425414221627, 50.68625756672451, 51.85852984019688, 64.65748337336949, 73.3130350112915, 68.22971207754952, 54.62260661806379, 37.02893400192261, 22.870523725237163, 10.063280991145543, 1.5916813910007477, 0.2352344931236335, 0.04845320519858173, 0.019529416791296432, 0.013302953847284828, 0.04388809283929212, 0.01862970819430692, 0.06492061567093645, 0.00795376967705254, 0.026107309984841516, 0.021420212296236838, 0.04095465024667127, 0.05214941953974111, 0.02606244016039584, 0.034176377180431566, 0.04316051330949579, 0.056764139594244103, 0.021059475938922594, 0.03657577200127499, 0.046044341421553066, 0.01891695920910154, 0.025334548504490937, 0.05887978124831404, 0.02873157470354012, 0.05115498915048582, 0.026399397257981554, 0.01848614714773638, 0.0232976270906095, 0.03974982311150857, 0.028002096972029124, 0.040744521522096226, 0.018848350837028453, 0.01746115893391626, 0.11047918708728892, 0.03607615309634379, 0.0049244530548873755, 0.03215283986979297, 0.007350392589744712, 0.021183369647977606, 0.0736867520692093, 0.0061734146521692825, 0.03261224200416889, 0.05770407683615174, 0.03487780936328428, 0.01915236675579633, 0.07333300462258713, 0.09493236882346016, 0.20289535128644534, 0.1378181025918041, 0.14258139128131525, 0.16555627488664218, 0.1291197179151433, 0.24475007823535375, 0.14504285848566464, 0.12152076352919851, 0.07684973627328873, 0.08853198547980615, 0.08475263363548688, 0.12095395608672074, 0.1660536817674126, 0.12977773403482779, 0.0824587442246931, 0.1411040984094143, 0.1756611948034593, 0.16635672907744134, 0.11550057014184338, 0.16022427885660104, 0.10413299155022417, 0.1396732444741896, 0.10735906594033752, 0.18128923566213676, 0.10479107552341052, 0.08938938911472048, 0.16613293465759071, 0.11732591076620988, 0.08886454906314611, 0.1461532674729824, 0.15203403548470565, 0.11150664516857692, 0.23536528753382818, 0.11936558703226702, 0.2761124553424971, 0.17255140095949173, 0.14322932437062263, 0.1401309027735676, 0.20520247891545296, 0.1656481349574668, 3.0011938256876807, 29.074010917118617, 61.11207471575056, 78.32737622942243, 76.80591528756278, 78.16665744781494, 76.8133568082537, 67.08370399475098, 63.1447354725429, 82.56406811305455, 74.02241134643555, 52.66969381059919, 30.70694875717163, 29.204286166599818, 26.919482231140137, 33.61876160757882, 53.04586580821446, 50.91820928028652, 54.28608104160854, 53.826308318546836, 56.20711898803711, 59.98548684801374, 64.50580419812883, 64.94379084450858, 63.34200872693743, 48.722040040152415, 41.575032642909456, 16.923567499433243, 9.608252150671822, 3.5937420640672957, 1.0814176286969865, 0.22704243127788815, 0.46701160605464664, 0.2423675517950739, 0.18635137831526144, 0.20523648709058762, 0.24812549139772141, 0.12149351356284958, 0.20948077791503497, 0.20023131423762866, 0.1579540499619075, 0.3121330024940627, 0.17069145504917416, 0.43087329236524446, 0.26861857888954027, 0.08210249298385211, 0.08058518011655126, 0.36249824134366854, 0.20394934687231267, 0.2929706578808171, 0.18529188659574303, 0.17479326709040574, 0.17016434190528734, 0.15952659557972634, 0.08162945229560137, 0.34836837383253233, 0.2847798988223076, 0.14831898840410368, 0.1356265294764723, 0.6089566264833722, 0.29028528769101414, 0.9259143386568341, 1.8907110137598855, 5.07303352015359, 9.684942892619542, 27.972169058663503, 34.692536217825754, 55.878986835479736, 67.84571293422154, 51.95063516071865, 74.18022578103202, 69.67837674277169, 38.949183327811106, 21.819956098284038, 26.527523926326207, 30.258373056139263, 29.6718339238848, 32.279795101710725, 41.98080049242292, 52.01626437050955, 59.226806095668245, 61.335660798209055, 75.27370548248291, 83.83631106785366, 77.04218878064836, 64.75748184749058, 46.17848171506609, 27.418644292013987, 11.325137257575989, 1.8550074781690324, 0.3048258317368371, 0.15882842375763825, 0.22642242668994836, 0.11206178859408412, 0.1209076935691493, 0.15328856530998433, 0.09803159787718739, 0.12084331416657992, 0.06974973582795688, 0.10590257695210831, 0.15849819433476242, 0.10910645646176168, 0.12543852973197187, 0.11953664571046829, 0.13456942620021956, 0.11129572934338025, 0.1623558694762843, 0.13864603745085852, 0.168800486517804, 0.18104391811149462, 0.11508977147085325, 0.13808107562363148, 0.11914713946836335, 0.17680611408182553, 0.09403894176440579, 0.11265585957361118, 0.1695882656744548, 0.09044673666357994, 0.19227082282304764, 0.11561374978295394, 0.1374519650957414, 0.19839622985039437, 0.13041490555873939, 0.11070610955357552, 0.10322405318064348, 0.13135082248066152, 0.10206466753567968, 0.09864067805132695, 0.1713446264288255, 0.1143284687506301, 0.17084700241684914, 0.1874537127358573, 0.15432793168084963, 0.1006240766229374, 0.21768195927143097], [0.011541733085843069, 0.009784307879661875, 0.03434830438345671, 0.0033610693561578436, 0.005202244867437652, 0.034055319747754505, 0.020273730690990175, 0.015228659978934696, 0.014924857798697693, 0.024980212428740094, 0.030590170329170566, 0.07236560367579971, 0.046446980708943944, 0.018664941125150238, 0.024118354211428335, 0.08454535475799016, 0.05072710157505103, 0.07002804375120572, 0.03592368627765349, 0.017482123969654952, 0.04079934036625283, 0.07405126108122723, 0.025607867499015162, 0.039348914088415246, 0.06215080858341285, 0.02283615542442671, 0.04021476887698684, 0.055600513105413744, 0.01655833246851606, 0.04315590266404407, 0.037763517017343214, 0.023222766018339565, 0.015576378641916173, 0.04323385955233659, 0.041931757636900456, 0.09138647373765707, 0.04953037954068609, 0.037114501664681096, 0.054050253970282416, 0.3628479040094784, 1.9838166577475411, 15.810089145387922, 51.988509791237966, 63.145513670785085, 61.57631165640694, 56.329858916146414, 53.95033713749477, 38.97479438781738, 35.45752246039254, 36.98504570552281, 58.17656850814819, 40.56910024370466, 18.516481978552683, 22.517631667000906, 16.761365277426584, 46.278282165527344, 16.19674597467695, 41.58301264899117, 65.51169490814209, 42.294337953839985, 45.270741258348735, 31.723365988050187, 20.405537366867065, 14.501279558454241, 14.167520233563014, 10.49060388973781, 5.1956683567592075, 1.2784458505255836, 0.17945174926093646, 0.11174555734864303, 0.11988431348332337, 0.07406275546444313, 0.048447539431176016, 0.03335344312446458, 0.007283160795590707, 0.014735921419092586, 0.023568666207471063, 0.060685647917645316, 0.037394197192043066, 0.025210719256262695, 0.07619505854589598, 0.012939988502434321, 0.024493219364168387, 0.06049540705446686, 0.035982949526182244, 0.04144744987466505, 0.12786107616765158, 0.07130022905766964, 0.06603940456573452, 0.13006733278078692, 0.0957556353615863, 0.026592615193554332, 0.043641855873699696, 0.1435341223009995, 0.04630661216963615, 0.08497826688523803, 0.013972352391907146, 0.0743382881794657, 0.05140994189839278, 0.07774519215204886, 0.026778849307447672, 0.047366836706974676, 0.06151002725320203, 0.15199860238603183, 0.09597062239689486, 0.1186670216598681, 0.6068213039210865, 1.42580617751394, 4.043380839484079, 14.329342910221644, 31.24557658604213, 30.70971414021083, 38.85717528206961, 51.201598508017405, 49.47278594970703, 37.776403835841585, 25.72408287865775, 14.426661985261099, 16.015224286488124, 17.503052473068237, 24.520788635526383, 31.905606814793178, 35.61479146139962, 52.60891096932547, 48.69663742610386, 57.71586125237601, 63.79925577981131, 66.6388942173549, 55.73325184413365, 38.41085427148001, 21.107559033802577, 2.3511153714997426, 0.5090901138527053, 0.07088029730532851, 0.07532193325459957, 0.0769201342814735, 0.08222224084394318, 0.021086116920092275, 0.016140660237787024, 0.012155500240623951, 0.016739774428840195, 0.016928717593795488, 0.042764913822923384, 0.05155194570709552, 0.09056596883705684, 0.058371049618082385, 0.039960223250091076, 0.0331161729991436, 0.06638811728251831, 0.07704665392105069, 0.014122055028565228, 0.022304462169163992, 0.06606662060533251, 0.05669486456151519, 0.03177574064050402, 0.0669145043939352, 0.03279717333082642, 0.042233675186123164, 0.03462536719494632, 0.04483222682029009, 0.021259796439803073, 0.06622714842004435, 0.0752087603988392, 0.02585301880857774, 0.03685310622677207, 0.023598537015329515, 0.025048781785049608, 0.06154079881629773, 0.026917297592652694, 0.019766573262001787, 0.021250302038554634, 0.02058345478560243, 0.03117689277444567, 0.04006794407697661, 0.06999953849507229, 0.06424025539308786, 0.008991667867771216, 0.02632689070222633, 0.0695323942761336, 0.0871290871873498, 0.03988191352358886, 0.031137100088277032, 0.02707938434156988, 0.015685868748862828, 0.03424312806289111, 0.05980205961636134, 0.02229440797652517, 0.026392688242984668, 0.057595185536359034, 0.01121067245756941, 0.06837156335158007, 0.10391197233859982, 0.0421402273433549, 0.045110066554376056, 0.06601009185292891, 0.02386602060869336, 0.051809232615466626, 0.015254695367600237, 0.046350041803504737, 0.049365064661417685, 0.034177198207804134, 0.003457344357489741, 0.05634817387908697, 0.07388288940169982, 0.03752491696338568, 0.03990627632343343, 0.04016706786517586, 0.05279753922617861, 0.04884074368913259, 0.05265164062646883, 0.047699288332036564, 0.061414197752518315, 0.0468375861777791, 0.010590216643842203, 0.05549324011164052, 0.4996640682220459, 3.3922406136989594, 23.416728564671107, 61.83211653573172, 69.5259541102818, 68.48095893859863, 62.963727951049805, 62.13541235242571, 45.833666937691824, 47.793288230895996, 44.086611883980886, 63.2009950365339, 50.48709092821394, 29.568413461957658, 28.126851592745098, 21.75235186304365, 37.576045581272666, 19.581057173865183, 40.69026640483311, 54.28915214538574, 38.22964872632708, 34.9929450580052, 26.299887044089182, 18.06172932897295, 13.59370412145342, 12.0664153780256, 9.466263106891088, 4.7415119494710645, 1.4062114975282123, 0.1472007626933711, 0.2132641670427152, 0.10237962313528572, 0.07583546891276326, 0.07763078436255455, 0.013419930739993495, 0.04985681934548276, 0.04095404635050467, 0.068225508688816, 0.18496709902371677, 0.15054461040667125, 0.02327945931548519, 0.07089834633682456, 0.15720074038420404, 0.12979145401290484, 0.11707908686782632, 0.09163183878575053, 0.10646820374365364, 0.2077838568282979, 0.32710091503603117, 0.4265188345951693, 0.36260053728307995, 0.21774059826774256, 0.06702162471732923, 0.2819519819957869, 0.21610238403081894, 0.2040076737425157, 0.17480765203280108, 0.08713051211088896, 0.15021569734173162, 0.2013124240828412, 0.20697730939303124, 0.026706593809649348, 0.1695081578301532, 0.0861664427710431, 0.47283207944461275, 0.02031374899005251, 0.09685341681220702, 0.418618515666042, 0.7966247562851224, 3.1786925068923404, 9.189430373055593, 20.16404751368931, 29.333209991455078, 39.121047019958496, 43.9112879889352, 36.39223582404, 33.23035730634417, 29.756105150495255, 24.268721887043544, 22.899414334978374, 26.119787999561854, 34.26797696522304, 44.118476322719026, 47.11247941425869, 58.768634932381765, 54.13891124725342, 62.88423361097063, 70.59532356262207, 75.44777175358364, 65.08661801474435, 45.673114912850515, 26.79768030984061, 3.446390748023987, 0.4684531944138663, 0.17639352407838615, 0.001038806897538182, 0.02010334376245737, 0.1240439774202449, 0.0897219255566597, 0.020482561717342054, 0.02238763529541237, 0.05052730015345982, 0.039974923711270094, 0.021729352850733057, 0.02585682030101972, 0.022429597597303133, 0.03225697463910494, 0.02523493447474071, 0.056396054702677896, 0.020421900686674883, 0.05729028582572937, 0.053283750279141326, 0.010220099539895142, 0.0025551841286609745, 0.037915329049740515, 0.058884402071791034, 0.04716582070770008, 0.07761293210621391, 0.006411702580018235, 0.059952870809606144, 0.04346700757741928, 0.05701440027249711, 0.04264633982841458, 0.023532001567738395, 0.04167346649670175, 0.02965886744537524, 0.026706782103117024, 0.028962619270065, 0.04734963584425194, 0.03652383014559746, 0.06209451731826578, 0.012125743087381124, 0.034491916320153644, 0.05770027704004731, 0.07187131805611507, 0.04911801345380289, 0.052095744027090926, 0.2184267057371991, 0.20289581269025803, 0.11368464758353573, 0.12868170998990536, 0.08805655634828977, 0.12796514986881188, 0.1459410624312503, 0.06892888487449714, 0.08210736486528601, 0.14216034673154354, 0.10650012881628104, 0.17226428565170082, 0.15808191310082162, 0.13692072645894118, 0.1812129140432392, 0.13557509652205876, 0.10469925616468702, 0.1408619021198579, 0.13980060549718992, 0.0894620737859181, 0.12295556653823171, 0.16771848100636685, 0.07896057729210172, 0.1684718177254711, 0.19875391280012472, 0.1084101777523756, 0.16353324986994267, 0.13628994673490524, 0.14132526011339255, 0.1085530093738011, 0.11069290526211262, 0.10588830736066614, 0.1512510874973876, 0.15201746565955027, 0.08345240447670221, 0.1991569490305015, 0.15498251441333974, 0.1400560467903103, 0.07916364925248282, 0.7792390606233052, 5.969597365174975, 28.480023315974645, 71.20545182909284, 77.48956939152309, 75.95828369685582, 71.47850908551897, 70.82521166120256, 53.70576402119228, 50.86382572991507, 50.644252232142854, 68.10920946938651, 49.76176152910505, 28.206875732966832, 31.999664579119, 25.509710107530864, 59.175570079258506, 24.43750752721514, 56.00685453414917, 80.60685089656285, 54.71931512015206, 57.49325139181954, 39.553277083805625, 25.80288587297712, 19.352506603513444, 19.283147948128835, 14.235934802464076, 7.362164446285792, 2.0554347804614475, 0.32672074543578283, 0.38212280401161736, 0.3317167173538889, 0.3180500721292836, 0.12695878744125366, 0.13144755443292006, 0.23130862521273748, 0.18491782381066255, 0.12920780533126422, 0.297898070620639, 0.275124834052154, 0.11119826457330159, 0.3120761684009007, 0.29847881517239977, 0.13870637278471673, 0.43368842559201376, 0.1689495335200003, 0.2664053333657128, 0.20654045497732504, 0.4390002691320011, 0.2864292546042374, 0.34648579199399265, 0.23357045384390013, 0.19390104391745158, 0.3384141836847578, 0.3661603219807148, 0.28938826439636095, 0.22087115528328077, 0.1895802550550018, 0.21064217202365398, 0.21667622109608992, 0.31998118279235704, 0.22677871185754025, 0.2021995136248214, 0.41957161309463636, 0.5707742667623928, 0.38331072883946554, 0.38208046342645374, 1.0363175230366843, 2.427110425063542, 5.103332442896707, 18.158590691430227, 37.95553534371512, 37.62179252079555, 49.15708065032959, 64.60209928240094, 63.279912676130024, 50.61405883516584, 37.94514431272234, 25.51414826938084, 26.30527537209647, 27.03870984486171, 36.304292474474224, 46.56979383741106, 51.99531902585711, 65.92423030308315, 63.67074189867292, 71.76649802071708, 77.81086799076625, 83.21491282326835, 74.8260747364589, 56.36602776391165, 32.43274232319423, 4.652844250202179, 0.6467976016657693, 0.20405271489705357, 0.20501436186688288, 0.12945728908692086, 0.23617936670780182, 0.1608523851526635, 0.08503820866878543, 0.16926282670881065, 0.09756625177604811, 0.2278178068143981, 0.1006229773962072, 0.09787600301206112, 0.14274122699030808, 0.1001297774325524, 0.10984090276594673, 0.09782161843031645, 0.11537069853927408, 0.09288593434861728, 0.10931529596980129, 0.10704777442983218, 0.08662799586142812, 0.1372204760887793, 0.16152925097516604, 0.11116070087466921, 0.21638495315398487, 0.13323457139943326, 0.19554802482681616, 0.10116108280739614, 0.14935444641326154, 0.13280785429690564, 0.238412615443979, 0.09469195029565267, 0.08447998469429356, 0.14954777461077484, 0.10922313734356846, 0.09567961908344712, 0.14845415257981845, 0.13400948553213052, 0.10011313975389514, 0.11229519785514899, 0.12930942273565701, 0.13357530454439775, 0.23403321472661837, 0.20331328814583166], [0.04197769445766296, 0.020046816706391316, 0.03136857891721385, 0.05552558587597949, 0.029122068214097192, 0.022247880830296447, 0.016117103198277097, 0.035099072847515345, 0.041075975700680695, 0.02147177077962884, 0.012221797352789767, 0.01908239283199821, 0.0034196154779887623, 0.06330396527690546, 0.06595678614186389, 0.04938786343804427, 0.00889942272832351, 0.041680272202938795, 0.03962865711322852, 0.0436662017101688, 0.06188708237771477, 0.037171179694788795, 0.03467249484466655, 0.020539685884224515, 0.02171111891844443, 0.024714033318949596, 0.054499518791479726, 0.029858536552637815, 0.043015581622187576, 0.053051620056586604, 0.0177284457521247, 0.026084835208686333, 0.05835737713745662, 0.04202896456367203, 0.031827061636639495, 0.028273855336010456, 0.04465306982664125, 0.006611173215787858, 0.37617311041269985, 6.029141690049853, 25.21874213218689, 57.253983225141255, 63.146806035723, 62.972003255571636, 54.76627452032906, 42.08647911889212, 38.854726042066304, 39.00477933883667, 21.142775978360856, 27.198490619659424, 30.526048932756694, 17.076684951782227, 19.79089277131217, 20.589146988732473, 43.98705809456961, 70.07701574053083, 47.3156030518668, 34.488248756953645, 28.899691036769322, 21.004362651279994, 11.095413310187203, 5.370092025824955, 5.157071113586426, 2.929732905966895, 0.6633793147546905, 0.4235773852893284, 0.24313223361968994, 0.0416149530293686, 0.028483363201043436, 0.1312945040741137, 0.046060934995434115, 0.09424092128340687, 0.08636017808956759, 0.11688061537487165, 0.018640800545524274, 0.04756828696866121, 0.1151668666196721, 0.09066472960902111, 0.16522303276828357, 0.11624580515282494, 0.06812096001314265, 0.04236926344622459, 0.10525634698569775, 0.07681070693901607, 0.30910326221159523, 0.1825422319982733, 0.1192052492073604, 0.29430302924343515, 0.23995587549039296, 0.43848599387066706, 0.05110470631292888, 0.20786838872092112, 0.1931948789528438, 0.17683386616408825, 0.10470832139253616, 0.02762570172282202, 0.11575939053935663, 0.026726600414674197, 0.06934908804084573, 0.05731236535523619, 0.41473444551229477, 0.1627662745969636, 0.03158271439107401, 0.11040220728942327, 0.041311661446733136, 0.11764702067843505, 0.12001797131129674, 0.1479333226702043, 0.45438461218561443, 0.4264077991247177, 1.829448095389775, 3.3955514303275516, 11.765567064285278, 26.473955052239553, 46.035338401794434, 51.92480523245675, 47.92743362699236, 35.96204853057861, 22.078936304364884, 17.027536869049072, 20.287814038140432, 13.802537441253662, 19.82634769167219, 39.07189198902675, 47.38871547154018, 49.426156588963096, 48.269844327654155, 54.531394141060964, 60.929753984723774, 58.37139252253941, 52.442463397979736, 24.104341404778616, 4.8295517052922925, 0.6905829778739384, 0.20502824469336442, 0.13540713196354254, 0.05011145318193095, 0.027848600476448025, 0.010973811149597168, 0.0232636901616518, 0.017931471911392043, 0.06665109709969588, 0.006999260047450662, 0.025601121164592247, 0.061999895609915257, 0.03210408373602799, 0.02551151213369199, 0.05913303765867438, 0.007537726778537035, 0.01796108148326831, 0.010720028026428605, 0.02572390716522932, 0.03521705312388284, 0.0274664410722575, 0.020215106961716498, 0.06332142398293529, 0.031574748389955075, 0.03652864774422986, 0.037722268873559575, 0.03847346481467996, 0.05718091276607343, 0.03632053087598511, 0.07810296331133161, 0.026634348489876305, 0.02595465148000845, 0.042724300109382184, 0.028966357998017753, 0.026378242232437645, 0.013548240863851138, 0.05038666359281965, 0.08252918294497899, 0.014124906571981097, 0.05183308990672231, 0.026892302058903233, 0.02560389637281852, 0.026984503093574728, 0.03575545369780489, 0.017312476644292474, 0.01051656506024301, 0.03224757353642157, 0.018925746237593036, 0.030940474210573093, 0.0385017631176327, 0.04080663122502821, 0.03846238433782544, 0.01855735939794353, 0.03356616385281086, 0.010272201699470835, 0.021210572116875222, 0.03445885470137, 0.0207623946480453, 0.020227846456691623, 0.034876153737838776, 0.09018242691776582, 0.029928825995219604, 0.08737298659980297, 0.02000097488053143, 0.004455819451582751, 0.0491470751086516, 0.029930512154740945, 0.031595854221710136, 0.0221943376319749, 0.010933178776342953, 0.02112690026738814, 0.051106602818306, 0.026832714809903076, 0.03218715338568602, 0.017002219899690578, 0.03871405636891723, 0.07080291717180184, 0.02021425879294319, 0.0695506197267345, 0.05902488596205201, 0.055833494889416864, 0.5998575804488999, 9.793089866638184, 37.27921158926827, 70.05745656149728, 72.28985718318394, 70.94711085728237, 63.92952060699463, 50.15886150087629, 50.02158941541399, 48.58995825903756, 29.312830924987793, 33.829743657793315, 32.47501516342163, 25.559136118207658, 22.115336179733276, 25.041083642414637, 31.230763026646205, 58.019560064588276, 28.753787551607402, 27.485904591424124, 24.953437328338623, 16.65699986049107, 7.767036846705845, 4.153386890888214, 3.310026705265045, 2.011774471827916, 0.8149595867310251, 0.2786664611526898, 0.15322107821702957, 0.12689417733677796, 0.2087814932955163, 0.07372717240027019, 0.088953762847398, 0.23447423534733908, 0.2065594539578472, 0.3716901923928942, 0.16817991196044854, 0.2213315005813326, 0.7098624919142041, 0.24643078233514512, 0.43453187176159447, 0.5523532895105225, 0.12791956588625908, 0.1195276076240199, 0.3143108827727181, 0.15746574902108737, 0.2786821760237217, 0.11786316122327532, 0.2640671559742519, 0.5371805408171245, 1.2965672952788216, 0.9912247998373849, 0.3618654938680785, 0.7169341295957565, 0.5212317651935986, 0.3682086020708084, 0.24643754054393086, 0.017496951656149964, 0.6648064096059118, 0.32931467624647276, 0.1782340638871704, 0.33356393394725664, 0.7528525165149144, 0.8063462089215006, 0.1398296875080892, 0.1221001102988209, 0.08610617529068675, 0.18726752272674016, 0.1287037352366107, 0.04187647060358098, 0.24618718826345035, 0.36391597241163254, 1.398666079555239, 3.158715784549713, 8.805166329656329, 20.087070158549718, 38.98495265415737, 46.125123023986816, 45.49178082602364, 32.17682974679129, 24.45515421458653, 21.911585467202322, 26.557444606508525, 21.61613937786647, 28.03341395514352, 46.7824330329895, 57.16516440255301, 59.066212381635395, 57.013276781354634, 61.22669219970703, 67.48483044760567, 66.7727165222168, 61.68311241694859, 32.46994992664882, 6.991512792451041, 0.8879814084087099, 0.18275005370378494, 0.07748012244701385, 0.06866816457893167, 0.01928299492491143, 0.018820425728335977, 0.020678196933918765, 0.05152406470317926, 0.026880809372024875, 0.03421050749186959, 0.02015424576321883, 0.08192426219050374, 0.019211670716426203, 0.022635724661605697, 0.004564552991983614, 0.04656624002382159, 0.026341251895896027, 0.03901025726060782, 0.025424990437126586, 0.022797675703519156, 0.051833873614668846, 0.016000206881601895, 0.046189452920641215, 0.038221219421497414, 0.046906236958290846, 0.02213365794159472, 0.04568352024736149, 0.04800256634397166, 0.023659460978316407, 0.04011759248429111, 0.06907766724803618, 0.05082838649728468, 0.04248401728857841, 0.016944498621991703, 0.03795265865379146, 0.005953425541520119, 0.023919014193649803, 0.09496310645980494, 0.024011819124487892, 0.01612984269325222, 0.01714306850252407, 0.031237540234412466, 0.042456838568406444, 0.11074831443173544, 0.07549507503530808, 0.0946746137259262, 0.2156103511473962, 0.16192183776625566, 0.07268878311983176, 0.1878286169043609, 0.11192388992224421, 0.13484312008534158, 0.14226808452180453, 0.10944202595523425, 0.10551142186990806, 0.11073525263262646, 0.13800216200096266, 0.09520583200667586, 0.07624047968004431, 0.14698299366448606, 0.1961838257099901, 0.13006411652479852, 0.15906281689448015, 0.20396757232291357, 0.1440066269465855, 0.1669255042714732, 0.11897575509335313, 0.14798647910356522, 0.11548805795609951, 0.10529609556709017, 0.10046431555279664, 0.12063076985733849, 0.24006748093026026, 0.09729396924376488, 0.11007398633020264, 0.12287818640470505, 0.15481046507401125, 0.10771233162709645, 0.14513040307377065, 0.1282480854008879, 0.13093280419707298, 0.7333788328937122, 12.607651386942182, 45.80488402502877, 83.536440713065, 78.66331468309674, 79.53611264910016, 71.57495008196149, 59.782675879342214, 55.23135566711426, 55.198723452431814, 32.3985641343253, 39.13404362542288, 39.69230358941214, 24.689372777938843, 29.29504701069423, 30.3555714062282, 56.99875157220023, 81.97615323747907, 62.350146429879324, 44.0783817427499, 37.17380394254412, 26.768032346452983, 13.817373582295009, 7.029303176062448, 6.968822147165026, 4.127178285803113, 1.48727428487369, 0.7713281022650855, 0.4866322875022888, 0.2201565629137414, 0.5723419540694782, 0.4076452744858605, 0.3332360658262457, 0.3127294619168554, 0.23876887347017015, 0.35318504965731073, 0.20922160467931203, 0.21651186634387287, 0.41884900044117657, 0.2468548124389989, 0.2939692171556609, 0.7808513141104153, 0.31908122822642326, 0.4325050876608917, 0.48952018682445797, 0.35237276181578636, 0.9360271160091672, 0.6693150305322239, 0.6443592725055558, 1.1194971225091388, 1.4105747491121292, 0.7888518390910966, 0.21426981022315367, 0.34340893423983027, 0.3754744907574994, 0.28790208271571566, 0.22805331274867058, 0.1058904379606247, 0.4754670209118298, 0.35143144375511576, 0.19722973315843514, 0.34707579176340786, 1.7799376206738609, 0.7260363783155168, 0.16574756747909955, 0.2598493280155318, 0.22079050461096422, 0.340378216866936, 0.24536575376987457, 0.32925404235720634, 0.8452733286789486, 0.6893697029777935, 2.8799310411725725, 4.637424026216779, 15.20946775163923, 33.756700720105854, 58.52507972717285, 64.55411502293178, 63.313396045139854, 47.107441970280235, 32.75488860266549, 26.188010624476842, 30.07000044413975, 24.5276551927839, 31.565808636801584, 53.662831102098735, 63.72854396275112, 68.60483837127686, 66.57968861716134, 70.10213347843715, 76.80284418378557, 76.68833092280796, 71.74359675816127, 43.42603274754116, 10.758658443178449, 1.6486274152994156, 0.37557542962687357, 0.25140856951475143, 0.13943354519350187, 0.12283314525016717, 0.05336251801678112, 0.07904626269425664, 0.12221048080495425, 0.1457299023334469, 0.11008557570832116, 0.16644248233309814, 0.13116741446512087, 0.13278884174568312, 0.09176443809909479, 0.11639006169778959, 0.13506934366055898, 0.14269420451351575, 0.12264109269848891, 0.10780626122972795, 0.09066219188805137, 0.11758737745029585, 0.08874043143753495, 0.1752975271748645, 0.11588886859161512, 0.11077861780566828, 0.07938675835196461, 0.10412982279168707, 0.1296490973659924, 0.25490997305938173, 0.19345474429428577, 0.13106665201485157, 0.11461388772087437, 0.14922521263360977, 0.06093218683132103, 0.05676001410133072, 0.21178703701921872, 0.16304929155324185, 0.16935320757329464, 0.07872321217187814, 0.08769725169986486, 0.1013310897563185, 0.11297069982226406, 0.12949212507477828], [0.020477226735757928, 0.008073305494950285, 0.024097704694473317, 0.016638282553425858, 0.023350613890215755, 0.01841356764946665, 0.038209976096238406, 0.009689717553555965, 0.11267997470817395, 0.008462456354339207, 0.014997576396646244, 0.01556212262117437, 0.02696583659521171, 0.042894096712448766, 0.019046103082863346, 0.043989238661846945, 0.020184779839058007, 0.05288371656622205, 0.0022270524392037517, 0.07600991348070757, 0.05444551758202059, 0.04959152911656669, 0.04742366401478648, 0.007217691496147641, 0.030534323504460708, 0.07500230933406524, 0.05738188126789672, 0.01773759749318872, 0.022973431540387015, 0.020064416208437512, 0.04945401381701231, 0.02216996974311769, 0.04438325037647571, 0.02029195105257843, 0.05354173607858164, 0.07050772051193885, 0.06143566660050835, 0.18838432351393358, 11.238879714693342, 40.20110974993025, 63.10146903991699, 61.687336921691895, 59.77455343518938, 53.71795463562012, 43.59950494766235, 32.806020396096365, 21.54806787627084, 23.02157061440604, 21.765398842947825, 21.880471433912003, 20.390788078308105, 20.329946177346365, 35.231831073760986, 45.37471757616316, 64.09488078526088, 34.44665684018816, 27.947435208729335, 17.28549221583775, 5.879699834755488, 2.218591945511954, 1.2483605848891395, 0.5406161536063466, 0.13409852289727756, 0.07578793074935675, 0.017105297850711004, 0.10870021076074668, 0.036157007329165936, 0.030283323223037378, 0.07786757272801229, 0.06833362645868744, 0.10751724602388484, 0.059110727427261214, 0.2652864562613623, 0.12877446572695458, 0.054761382418551614, 0.13434498038675102, 0.32030848094395226, 0.4802662176745278, 0.5381762502448899, 0.06782743254942553, 0.15783378641520227, 0.17844679818621703, 0.05194457321028624, 0.17330129072070122, 0.11535225595746722, 0.15076114450182232, 0.2164763653916972, 0.37800732627511024, 1.5599656871386935, 0.9628114444868905, 0.479781200843198, 0.5523528009653091, 0.6344830053193229, 0.1972830252987998, 0.4986039251089096, 0.292468786239624, 0.27095192511166843, 0.27336096870047705, 0.31202071851917673, 0.413415509143046, 1.1991683159555708, 0.4497796935694558, 0.11582370208842413, 0.23226706949727877, 0.08165938926062413, 0.058340630893196375, 0.031211460740970712, 0.022001530210088407, 0.07201768484498773, 0.02010431746020913, 0.08375503788036959, 0.219358320747103, 1.8885340562888553, 3.9030311363083974, 7.015491460050855, 20.596169880458287, 37.93239436830793, 49.83621495110648, 43.97352647781372, 37.0641370500837, 28.512278590883525, 19.313601902553014, 22.43803484099252, 25.494410174233572, 30.476751463753835, 37.58719744001116, 36.695990221840994, 38.17144019263131, 44.949178627559114, 51.854684012276785, 59.722650391714915, 49.24062926428658, 31.20715652193342, 12.37305154119219, 2.021831337894712, 0.08201497553714684, 0.09873777641249554, 0.027833151930410947, 0.015322084072977304, 0.036292802542448044, 0.026692773747657026, 0.05106950052348631, 0.03589130997923868, 0.04720526394833412, 0.05819796212017536, 0.019258769528408135, 0.01819704712501594, 0.009501698044394808, 0.009749498185036438, 0.028023177358720983, 0.04934853554836341, 0.01998825234893177, 0.06787495714213167, 0.07241740982447352, 0.019559123054412857, 0.02904223178380302, 0.017306793913511292, 0.041530295607766936, 0.05387825212840523, 0.06173880212008953, 0.06114336049982479, 0.024640631096969758, 0.07685423496046237, 0.02217544721705573, 0.016383131334025944, 0.0558267502513315, 0.030539795889386108, 0.04341329474534307, 0.05454328769285764, 0.018134314866204346, 0.030673911728497063, 0.019003190831946473, 0.03784702432208827, 0.06356562195079667, 0.02392460871487856, 0.02912413774590407, 0.017100889069427336, 0.03135296243375965, 0.035179869404860904, 0.01458637060464493, 0.020629503564643006, 0.06068783958575555, 0.032590664590575864, 0.04127288656309247, 0.053430754890931506, 0.045818579250148365, 0.0032617004471831024, 0.021350864320993423, 0.008631219887839896, 0.018467265214504938, 0.05266808831532087, 0.04065568771745477, 0.01590950201664652, 0.01793941416378532, 0.005195858156574624, 0.10793546786797897, 0.02179722161963582, 0.04583534924313426, 0.0643998264734234, 0.07096419816038438, 0.03670606429555586, 0.0071639320147889, 0.07535751563097749, 0.03826502564230135, 0.05808281472751072, 0.021738000779545734, 0.012394257205804544, 0.02009972038545779, 0.013110677379050424, 0.02028643965188946, 0.01962676621042192, 0.08108166418969631, 0.020491075635488545, 1.0154954003436225, 17.324165889195033, 51.47845990317208, 73.58758613041469, 69.3237476348877, 68.36209610530308, 59.460995129176546, 51.30333750588553, 43.4798708643232, 33.212465694972444, 38.762575558253694, 24.46891164779663, 23.315653119768413, 28.67247452054705, 27.267201355525426, 32.13508496965681, 30.229173251560756, 49.576626777648926, 31.727917058127268, 23.214105197361537, 15.731713465281896, 5.466755364622388, 2.008259117603302, 0.9390119101319994, 0.3616444543004036, 0.09847932920924254, 0.020405312201806476, 0.07237160192536456, 0.11835826108498232, 0.11790065706840583, 0.41437604331544464, 0.3756599479487964, 0.3512617014348507, 0.7745166197419167, 0.7177340409585408, 0.8386578836611339, 0.5994226666433471, 0.872366472014359, 1.0957549107926232, 1.8831565848418643, 4.0273305007389615, 2.1468795878546576, 0.7688813049878392, 0.33020966393607004, 0.4215186286185469, 0.3309977687895298, 0.44439082273415154, 0.33009903558662956, 0.0501240298285016, 0.20075935018914087, 1.1286995772804533, 2.5036090058939795, 2.2267374055726186, 3.1572816329342976, 2.1641471641404286, 2.7933213114738464, 2.60909286567143, 2.63066810795239, 2.076727100781032, 1.6858296990394592, 1.5035353494541985, 1.1678324831383569, 2.5998467675277164, 3.347649029323033, 3.463550844362804, 1.315436214208603, 0.4681534990668297, 0.5283741876482964, 0.25404956351433483, 0.491437129676342, 0.061534875205584934, 0.08219516051134892, 0.08642562279211623, 0.04747929031561528, 0.04298491523201976, 1.1716647403580802, 2.187477260828018, 6.2508591413497925, 17.22407361439296, 33.46007864815848, 37.82769891193935, 37.14259263447353, 29.748806067875453, 34.912644726889475, 24.440238169261388, 28.894401720591954, 34.650440556662424, 40.490255560193745, 46.385996614183696, 42.0501435143607, 49.44158158983503, 54.60227966308594, 58.89740589686802, 68.52100140707833, 57.146414688655305, 37.43709203175136, 15.699380023138863, 2.0613357552460263, 0.17279343440064363, 0.1453169323503971, 0.04402225278317928, 0.006974716163572988, 0.03851211077666708, 0.005458325679813112, 0.012408363948842245, 0.025833828141912818, 0.05314194324559399, 0.08319069352000952, 0.038178213872015476, 0.019885228680712835, 0.07061948201486043, 0.030879185535013676, 0.023800036470804895, 0.04346448342714991, 0.03264493042869227, 0.046270497143268585, 0.04988511425576039, 0.0344883234772299, 0.018126106288816248, 0.08574086560734681, 0.0524019431322813, 0.02112499188764819, 0.07153851020016841, 0.018327369953372648, 0.07766839555863823, 0.026874890850324715, 0.04614959577364581, 0.047042761596718004, 0.020259121832038676, 0.04967107377680285, 0.02481652603351644, 0.07170027973396437, 0.020100203841658573, 0.023065349286688224, 0.005351263455980058, 0.05428007038842354, 0.023327355406114032, 0.018666357567001666, 0.035544503945857286, 0.2222910983754056, 0.10365980836961951, 0.07638458016195468, 0.08555199538490602, 0.07848530422363963, 0.12164925092032977, 0.10720085871538945, 0.09545772456164871, 0.15923561262232916, 0.1969255187681743, 0.06800087967089244, 0.15726578475109168, 0.09890483851943697, 0.12010923427130495, 0.1139763497880527, 0.18988140246697835, 0.10356646230710403, 0.12346539060984339, 0.11442963832191058, 0.24224962240883283, 0.13353980359222206, 0.15519486873277596, 0.12122473227126257, 0.17209478760404245, 0.1634967446859394, 0.11046668168689523, 0.14923084447426455, 0.07887033891997167, 0.12131018697151116, 0.12529440889401094, 0.14266935656113283, 0.14416935321475777, 0.14137183475707257, 0.07258708429123674, 0.15879805253020354, 0.18680550823254244, 0.09483151816363845, 1.2506179894719804, 21.33113295691354, 63.581269945417134, 85.0256689616612, 78.12947068895612, 76.31408705030168, 68.36571611676897, 57.66244350160871, 49.486456530434744, 33.396936893463135, 34.43006454195295, 32.643925871167866, 32.21359266553606, 30.587519645690918, 29.197577680860245, 48.77487761633736, 61.50311933244978, 77.83367892674038, 43.72712598528181, 35.74573373794556, 22.982850040708268, 8.341916901724678, 2.987787276506424, 1.959978039775576, 0.941359858427729, 0.29999626374670435, 0.155263020790049, 0.19813002699187823, 0.39939607999154497, 0.1765970303011792, 0.32967997235911234, 0.1987966876477003, 0.38041086015956743, 0.7987187153526715, 0.6318987639886993, 0.8471979796886444, 0.2932080365717411, 0.5183757298759052, 0.5632415509649685, 1.0508874612195152, 3.2228517830371857, 1.9644012195723397, 0.30695537318076405, 0.5638834993754114, 0.6596202307513782, 0.5963549826826368, 0.6675788494093078, 0.3501597877059664, 0.2789672150143555, 0.6786834278276989, 1.9220769192491258, 4.398388624191284, 3.872213704245431, 3.163600368159158, 0.9904948047229222, 1.9852382157530104, 1.8435789942741394, 1.9670804015227725, 2.007891080209187, 1.1165801818881715, 1.159175570522036, 0.9717038358960832, 2.9762738943099976, 4.458677274840219, 6.7404617837497165, 1.0724788797753197, 0.3904833325317928, 0.45349665411881035, 0.16705785931221076, 0.4179478245122092, 0.1312636443014656, 0.11405390634068421, 0.12888470052608422, 0.20631406855370316, 0.5059095759476934, 2.7364090510777066, 5.204990233693804, 9.590106061526708, 26.459966591426305, 48.232782636369976, 64.51496192387172, 58.719337463378906, 49.6880897794451, 41.45213638033186, 31.66600513458252, 34.12350307192121, 36.68363979884556, 43.05249064309256, 51.143914563315256, 49.69420419420515, 53.409590108054026, 60.943018095833914, 68.94232627323696, 78.44534969329834, 66.96118640899658, 47.751731055123464, 20.658095700400217, 3.6939216256141663, 0.595635355583259, 0.18589331289487226, 0.1982085606349366, 0.13657214944916113, 0.10991092079452106, 0.10736357819821153, 0.1361689232289791, 0.14499485891844544, 0.27453551281775745, 0.20928800611623696, 0.10098430407898766, 0.1442086539630379, 0.13725618060146058, 0.08090694820774452, 0.0945492543812309, 0.13385929859110288, 0.09820412897637912, 0.12818936498037406, 0.1561244481376239, 0.11330240166613034, 0.08934483650539603, 0.15190211470638001, 0.15935460052319936, 0.08285175849284444, 0.1266941452132804, 0.14713324845901557, 0.1427681648305484, 0.16331225101436886, 0.22241402177938394, 0.12223983422986098, 0.11059118607746703, 0.1313390295420374, 0.1443621657256569, 0.18401359447411128, 0.10864872352353164, 0.0804202961070197, 0.100804607649999, 0.16422535558896406, 0.1124222060399396, 0.10068363842687436, 0.08784482628107071], [0.11218899355403014, 0.0017032277516721348, 0.0568841792243932, 0.027327712891357284, 0.02726711462517934, 0.006485776975750923, 0.08516405655869416, 0.06173571478575468, 0.019335148822782294, 0.02039269314679716, 0.028151093084099035, 0.008381951567051666, 0.0485909783414432, 0.04517010672550116, 0.040414064789989164, 0.0240889278440071, 0.02527750576181071, 0.0055808292402486715, 0.01699584336685283, 0.029229534590350728, 0.024056293702285205, 0.008726718602702022, 0.01734958402812481, 0.01821632939390838, 0.015350434962393982, 0.051275751420429776, 0.03517591693837728, 0.051118921621569564, 0.030219829308667352, 0.0864855849317142, 0.020263254110302244, 0.03270596804629479, 0.02949274850210973, 0.04734562909496682, 0.026288092069860016, 0.12088766321539879, 1.8356962629726954, 17.128657477242605, 53.2063170841762, 61.58261367252895, 61.141604559762136, 53.779804025377544, 42.59727593830654, 49.60432229723249, 32.547898292541504, 21.518848964146205, 16.201566287449428, 16.62336710521153, 22.875932897840226, 18.62465500831604, 13.429940291813441, 41.29907103947231, 47.892664841243196, 49.89165115356445, 24.239768743515015, 10.109861714499337, 2.732926049402782, 0.20575055879141602, 0.04832236668361085, 0.03954403701105288, 0.04142260192228215, 0.012868589655097042, 0.10818659367838077, 0.12578370049595833, 0.04286398332832115, 0.053039145190268755, 0.0470494892714279, 0.18883412437779562, 0.12215671369007655, 0.5155232229403087, 0.687947656427111, 0.940290487238339, 0.3838954360357353, 1.043213610138212, 0.7885392244373048, 1.2425932543618339, 2.951661854982376, 2.600309256996427, 2.2189360984734128, 1.6856916035924638, 0.10547545272856951, 0.055307382584682534, 0.4782567769289017, 0.15362602791615895, 0.21014875492879323, 0.3904431089758873, 0.4772351203220231, 0.976361843092101, 1.8144681049244744, 1.6145320619855608, 2.1925118821007863, 4.809887434755053, 3.186023507799421, 1.5955361213002885, 1.6044598881687437, 1.897982737847737, 3.18148872256279, 0.9367264956235886, 0.8087359549743789, 1.2026618484939848, 0.895883138690676, 1.616795003414154, 0.8667712722505841, 0.3293357108320509, 0.10859387753797428, 0.3645925261080265, 0.26946148223110605, 0.1454449990498168, 0.14427204270448002, 0.1378417970346553, 0.10855788804058518, 0.011455591368888105, 0.024793873141918863, 0.0433895358416651, 0.6159965630088533, 2.241491688149316, 6.45763145174299, 17.553711788994924, 34.380287647247314, 46.90669114249093, 32.05655642918178, 36.37089095796858, 30.99439573287964, 31.445354666028702, 31.317087445940288, 36.41103070122855, 48.343898228236604, 18.434456757136754, 36.300582136426655, 45.69502258300781, 57.912992068699424, 55.92738103866577, 54.27471726281302, 33.47520835059029, 15.519777774810791, 6.771553235394614, 1.6919064415352685, 0.055624156658138545, 0.019350500677579215, 0.04636267612555197, 0.02706856679703508, 0.0601807635809694, 0.0855865938855069, 0.043921388552657196, 0.06727614320282425, 0.04712080330188785, 0.03643908112176827, 0.015564103943428822, 0.030864250979253223, 0.017013264753456627, 0.06324153326983963, 0.013240150342296277, 0.04016841136451278, 0.00582394324841776, 0.06090774599994932, 0.048033592357699356, 0.03325000385354672, 0.03784804551729134, 0.061463432253471444, 0.06092810205050877, 0.01847247127443552, 0.023650631541386247, 0.02131767717323133, 0.03270168309765203, 0.033453048672527075, 0.01814810948313347, 0.034602687161948, 0.0236561276750373, 0.05843305414808648, 0.025735038532210246, 0.05433495708608201, 0.049058600927570035, 0.017992197402885983, 0.02254612580873072, 0.01197364182943212, 0.05984820678297963, 0.042304789048752615, 0.011925495529015149, 0.04432644681738956, 0.03913493807028447, 0.021206575545615385, 0.04048630502074957, 0.05772972545985665, 0.017413088120520115, 0.10494584257581405, 0.024228958812143122, 0.02547312740768705, 0.025114776100963354, 0.10298348537513188, 0.0157258700845497, 0.03015960593308721, 0.05561220087110996, 0.05765973457268306, 0.0356501247068601, 0.042157441776778014, 0.026009114093280265, 0.025543260787214552, 0.049785990467561145, 0.03318810110379543, 0.006349511452884014, 0.05300587661830442, 0.10422238175358091, 0.019922475164223994, 0.06467818867947374, 0.025412059256008694, 0.027922956040129066, 0.044826008046844175, 0.05016560706176928, 0.030937766855848686, 0.023749940230378082, 0.0875752375328115, 0.12294127659073897, 3.8079619748251776, 26.744299037115915, 64.88671139308384, 70.88793304988316, 68.68743160792759, 63.453311920166016, 51.80554287774222, 59.174256869724815, 42.488453251974924, 34.72214249202183, 23.945175545556204, 21.626968145370483, 18.856511184147426, 20.898055212838308, 22.545082262584142, 31.428720678601945, 38.598198550088064, 40.4818343435015, 22.777893815721782, 8.679019178662982, 2.7888193130493164, 0.1906727235764265, 0.10052022005298308, 0.05780249834060669, 0.03458135402096169, 0.03516594925895333, 0.3121020070144108, 0.5038307074989591, 0.4260420687496662, 0.34671380690165926, 0.9616079947778157, 1.2063662154333932, 1.3911904692649841, 1.50716013780662, 2.049426542861121, 2.5313640194279805, 2.922252518790109, 3.662688170160566, 4.705094703606196, 3.424064883163997, 5.905735603400639, 6.25522825547627, 5.117832464831216, 3.6919639706611633, 0.8363656838025365, 0.9083632432988712, 0.9477702230215073, 0.5049664665545736, 0.14318300757024968, 0.5062305501529148, 0.3613226929945605, 1.6653592203344618, 2.7075451484748294, 2.558748607124601, 4.40802230153765, 6.714967974594661, 5.144219986030033, 4.962550214358738, 3.5191092916897366, 4.230246126651764, 6.6946388483047485, 4.701398261955806, 4.400507824761527, 3.074017026594707, 3.8403627276420593, 3.537783009665353, 3.4839468470641544, 1.847996311528342, 1.6488767904894692, 1.347558496253831, 1.3341303425175803, 1.223694371325629, 0.9491487890481949, 0.6147641805665833, 0.46662988939455574, 0.07344293408095837, 0.058776779632483206, 0.05920441954263619, 0.2585713751614094, 1.27095319543566, 4.673714467457362, 15.790357998439244, 32.573495456150596, 40.52291556767055, 31.106890542166575, 30.302442005702428, 27.157680375235422, 29.71507603781564, 38.24312823159354, 47.04814256940569, 52.1760243007115, 25.0326189994812, 42.04732254573277, 53.054002148764475, 62.840279306684224, 66.05041653769356, 64.38382857186454, 42.05138029370989, 19.492043801716395, 7.733870489256723, 1.9813109636306763, 0.12563592913959706, 0.05764163125838552, 0.013572467108523207, 0.03717453165778092, 0.004571796777392072, 0.03630558614219938, 0.037690761099968634, 0.0377993708077286, 0.07999071558671338, 0.03544055238100035, 0.030882856409464563, 0.02482730625862522, 0.032459860002355914, 0.027022402667041336, 0.019702375367549912, 0.013924980469580208, 0.02332017820195428, 0.033800037910363505, 0.019890509379495467, 0.03141089914632695, 0.02630281458342714, 0.04381331828023706, 0.01993311968232904, 0.011976206691802611, 0.03186743786292417, 0.017426085458802323, 0.05288604733401111, 0.06262797476457697, 0.08035092947206326, 0.019103993994316885, 0.062186424886541705, 0.04536844590412719, 0.028510182297655513, 0.04991431161761284, 0.02934237157127687, 0.05892780117158379, 0.02496562053316406, 0.020255478098988533, 0.04344261424349887, 0.3016089786376272, 0.1379247682967356, 0.14826105508421147, 0.13477091038865702, 0.09175446363432066, 0.11187123560479709, 0.16156224134777272, 0.12668437430901186, 0.25706299181495396, 0.1191942569400583, 0.05654772763539638, 0.16290411220065185, 0.15874514036944934, 0.13216311032218592, 0.09578923641570977, 0.19331348687410355, 0.17172293684312276, 0.07513670676520892, 0.09694375696458987, 0.14404803115342343, 0.11950106333409037, 0.11451463161834649, 0.15359457103269442, 0.09483381161200148, 0.16756159013935498, 0.19017894007265568, 0.09161703315164361, 0.10599795183432953, 0.11092822120657989, 0.1986145552779947, 0.13058672419616155, 0.2088486004088606, 0.11813857858734471, 0.15003982106489794, 0.17064631889973367, 0.17795696375625475, 4.574060363428933, 35.428322655814036, 79.03332710266113, 80.51878247942243, 76.30033656529018, 72.32457038334438, 58.63404137747628, 65.52752985273088, 45.94901398250035, 32.49521705082485, 25.450207471847534, 26.071560553142003, 32.31888566698347, 27.114803041730607, 22.62848322732108, 56.2405606678554, 60.711094175066265, 61.12506784711565, 29.9943345614842, 12.146348323140826, 4.228415276323046, 0.38209357272301403, 0.4245114837374006, 0.15658829467637198, 0.06846005110336201, 0.14365925772913865, 0.33072931319475174, 0.4283604057771819, 0.34357066984687534, 0.4263657299535615, 0.7232884743383953, 0.8850061137761388, 1.1437812937157494, 1.371973271880831, 2.0608713115964616, 2.6928890092032294, 2.565061696938106, 4.774264454841614, 6.200319681848798, 4.909054296357291, 5.859610421316964, 6.024925002029963, 9.193324838365827, 4.82516565493175, 0.41919323482683724, 0.6976075523665973, 2.1051610835960934, 1.3154724751199995, 1.6162099433796746, 1.0591026203972953, 1.0018189570733478, 2.8656620468412126, 4.795854679175785, 6.625282364232199, 6.350096353462764, 10.143137506076268, 6.650463938713074, 5.4680147256169995, 6.82719658102308, 5.36834238256727, 8.36714059965951, 4.492140233516693, 4.546471672398703, 5.205407994134085, 6.0955056718417575, 10.877305882317678, 4.008962503501347, 2.2443354555538724, 1.481248893908092, 1.418959379196167, 1.1599073026861464, 0.7509987588439668, 0.7562817239335605, 0.3948989398777485, 0.35089540109038353, 0.2355709650686809, 0.1151845356715577, 0.2736558871609824, 1.1358325545276915, 3.0267202045236314, 8.751924889428274, 23.149354934692383, 45.27775893892561, 62.37966237749372, 44.18547085353306, 49.369431495666504, 44.02335895810808, 44.667116505759104, 46.35302741186959, 49.163952418736045, 62.41516072409493, 28.858613286699565, 49.713089397975374, 63.0621144430978, 72.6339806147984, 74.03095068250383, 73.56230163574219, 52.10279723576137, 26.33637203489031, 10.407274144036428, 2.3365449990545, 0.23271924523370607, 0.16902361597333634, 0.0979605552607349, 0.12474175569202219, 0.18548710112060818, 0.1832298051033701, 0.1752870370234762, 0.1468358872724431, 0.1368924451193639, 0.18314304761588573, 0.11648330598005227, 0.11419240890869073, 0.16924111358821392, 0.10784463238503252, 0.06379410504762616, 0.1043611421648945, 0.11600739508867264, 0.13763253683490412, 0.1053684206147279, 0.09194342885166407, 0.08690059730517012, 0.10506054892071656, 0.08895330822893552, 0.06972294048007045, 0.14273345097899437, 0.0948122206277081, 0.17030602001718112, 0.17393521884722368, 0.15037204538072857, 0.06185416664396014, 0.15748172173542635, 0.11467415520123073, 0.09617790805974177, 0.20273495917873724, 0.17686563517366136, 0.12309339057121958, 0.09913085174879857, 0.0873086139825838, 0.12144592111664158], [0.015076193160244396, 0.016328841747183884, 0.027662493587870682, 0.05731464523289885, 0.01952322685558881, 0.03075775151540126, 0.0291907427433346, 0.0315134902484715, 0.04694645372884614, 0.030010613213692392, 0.03222005554874029, 0.026974871288985014, 0.02231575468821185, 0.0067900693975389, 0.06921515201351472, 0.02772491711324879, 0.024528177488329153, 0.025729864702693055, 0.048174178028213124, 0.03561119715284024, 0.044911876653454134, 0.037731754793120284, 0.03542163482468043, 0.046399992158902545, 0.01996919060392039, 0.0360182638812278, 0.052041783529732905, 0.022375084093904922, 0.0030078081222849763, 0.04898007067718676, 0.07989332545548677, 0.06071021088532039, 0.039999110092009814, 0.030417747795581818, 0.058733265181737285, 3.5595367337976183, 32.05585813522339, 66.61340127672467, 63.977324213300435, 63.910961968558176, 59.02107688358852, 48.10666935784476, 46.795186451503206, 35.220349175589426, 19.270703724452428, 13.43940373829433, 21.568723133632115, 22.51952157701765, 19.741772481373378, 19.520475830350602, 33.51491035733904, 48.72567047391619, 28.790993418012345, 8.959854074886866, 2.523441335984639, 0.3167607198868479, 0.059754589306456704, 0.11848615136529718, 0.11593067991946425, 0.1060229219230158, 0.18180729714887484, 0.10841408611408301, 0.15339592312063488, 0.1420853143291814, 0.20289545985204832, 0.26783364957996775, 0.901337420301778, 1.3201886734792163, 1.4872958894286836, 1.322222215788705, 2.745729842356273, 1.5450353111539568, 2.3064899146556854, 3.525737221751894, 3.4613749725478034, 3.7573030931609015, 7.904326302664621, 8.705772348812648, 4.291449333940234, 3.47245973774365, 0.43361066547887667, 0.18107329867780209, 0.12071007703031812, 0.1993866874171155, 0.3447939599198954, 0.13232081543122018, 0.3280343349490847, 0.7961184605956078, 2.2790949046611786, 1.9939953344208854, 4.925763845443726, 8.348799092429024, 5.856145875794547, 7.123476454189845, 3.9403295006070818, 3.829275574002947, 3.602307890142713, 4.422249172415052, 3.183791399002075, 3.4751267603465488, 4.112816793578012, 1.7157718752111708, 2.5074372461863925, 1.9027665725776126, 1.5026009253093173, 2.109390365225928, 1.5221913712365287, 0.9688928553036281, 0.6246045125382287, 0.40042226921234814, 0.299426050058433, 0.07178177857505423, 0.07741661835461855, 0.09717152759964977, 0.04469915931778295, 0.06537338173282997, 0.4188395280923162, 2.243766788925443, 7.098256230354309, 19.89690317426409, 42.901923179626465, 55.501779556274414, 49.65218496322632, 77.57626206534249, 63.51917389460972, 42.63480315889631, 50.936385767800466, 27.536207812173025, 25.301368372780935, 33.14991453715733, 44.28470155170986, 47.99074213845389, 55.39310278211321, 59.258628845214844, 45.86400624683925, 22.717010225568497, 7.571148020880563, 2.235864515815462, 0.07838106088872467, 0.07618840890271322, 0.031372368535293, 0.042700168011443954, 0.021032970664756637, 0.015581338732902492, 0.041867910884320736, 0.021849852188357284, 0.02252037710111056, 0.0610468185373715, 0.01407321322975414, 0.036152349186262915, 0.06218505424580403, 0.054691846149840524, 0.016141754375504594, 0.03845008589061243, 0.043427615226911645, 0.019435037659215074, 0.01979614551445203, 0.026822687758665, 0.025161169236525893, 0.056239822014634094, 0.007347675056995026, 0.03053099529019424, 0.04886197844254119, 0.05638239240007741, 0.11537295127553598, 0.07183768986059086, 0.04109588731080294, 0.03024010732769966, 0.11336284556559154, 0.07797994491245065, 0.021948390740102956, 0.03247702354565263, 0.03296443560559835, 0.025007180803056275, 0.056530126437012634, 0.030826554966292212, 0.02610562552165772, 0.023568827359537994, 0.049296257817851644, 0.03494830236637166, 0.01649864513560065, 0.027323782477261763, 0.024709214023979645, 0.028848170768469572, 0.03877157238977296, 0.034043591269957166, 0.03779574743072901, 0.005791927845815995, 0.03818213580442326, 0.012506966113245912, 0.029455652992640222, 0.09577512288732187, 0.023553765578461543, 0.04955700186214276, 0.04226708625044141, 0.01713343500159681, 0.060523301629083495, 0.003156179346011153, 0.047488660884222815, 0.023031727876514196, 0.021441031446946517, 0.028722580721867935, 0.029670629849923507, 0.02098026206450803, 0.030870228872767518, 0.0213719599747232, 0.09788029813872916, 0.07762266908373151, 0.06890517686094556, 0.04082557253007378, 0.04661617002316883, 5.432665765285492, 43.638480867658345, 76.74292291913713, 72.3018011365618, 70.25548022133964, 66.97160870688302, 56.5027300970895, 57.343781743730815, 47.73260613850185, 29.760708332061768, 19.113181114196777, 32.09271832874843, 20.21742878641401, 22.0087890284402, 24.041199650083268, 31.959087099347794, 41.23406369345528, 26.182683093207224, 9.21664994103568, 2.3836457516465868, 0.27431265477623257, 0.08112421512071576, 0.12959040408687933, 0.17271259373852185, 0.15303045058889048, 0.23555894142815045, 0.6895674552236284, 0.6792894410235542, 0.712017899113042, 1.4821697473526, 1.7425402445452554, 2.4483202355248586, 3.627151825598308, 3.889326248850141, 5.503404072352818, 5.90849186692919, 6.9168661236763, 4.8810296058654785, 7.540958966527667, 7.933547820363726, 5.91621435540063, 9.354478750910078, 10.758511662483215, 7.613889864512852, 5.035291773932321, 2.19890205349241, 0.21693293803504535, 0.1415848268994263, 0.23194948796715054, 0.4993551990815571, 0.49063054152897423, 0.8362432218023709, 1.0023629793098994, 1.4086958042212894, 3.220985757453101, 4.258636031832014, 8.087776115962438, 6.530366497380393, 8.333145669528417, 7.778854863984244, 7.341602121080671, 7.101184896060398, 7.158873183386667, 5.908899639333997, 5.286688455513545, 4.91064760514668, 4.06748240334647, 3.1672160370009284, 3.233430849654334, 2.6687427163124084, 3.091202744415828, 3.659857213497162, 3.6789912496294295, 3.082961529493332, 1.1459262243338992, 0.8784901691334588, 0.3113822170666286, 0.5079554947359222, 0.2952778126512255, 0.005378894250108195, 0.04732436041480728, 0.2978784202464989, 1.4320890860898154, 6.1594099913324625, 17.107399463653564, 29.92556824002947, 45.19742039271763, 43.83019208908081, 69.80845396859306, 64.48693983895438, 43.788297925676616, 51.888316767556326, 28.095060110092163, 32.46038573128836, 39.6574444770813, 51.39222581045968, 54.96965871538435, 64.682615007673, 71.04163415091378, 57.29498454502651, 30.116685390472412, 10.346907326153346, 2.4772514488015855, 0.11109303736260959, 0.05088639784870403, 0.0178544056003115, 0.04541826055252126, 0.01269105775281787, 0.03348555728527052, 0.04602586830567036, 0.018665200664794872, 0.03615199974072831, 0.09382900981498615, 0.0362221365129309, 0.016010367943506156, 0.03657950733655265, 0.032598820581500015, 0.022644803460155214, 0.03324063667761428, 0.04858254754383649, 0.040246748232415745, 0.06582509606544461, 0.008742504719910877, 0.004056172079539725, 0.04506240964734128, 0.007324006907375795, 0.05774368292519024, 0.05361779306882194, 0.030361867044121027, 0.051783991112772904, 0.013169788805368756, 0.035275033941226344, 0.023448920043717538, 0.02445273966129337, 0.05944959460092442, 0.025615495928962315, 0.00873643861684416, 0.05470194275091801, 0.03303221446861114, 0.060984949714371135, 0.04126306137602244, 0.10157545057258435, 0.20409524547202246, 0.10262033343315125, 0.14878845321280615, 0.1254725514778069, 0.090267284507198, 0.13741920542504105, 0.13603348763925688, 0.19991128998143332, 0.12375768992517676, 0.1509593581514699, 0.10786639978843075, 0.07924423207129751, 0.17016383978937352, 0.11912971468908445, 0.17225975303777627, 0.11997858913881437, 0.19935069791972637, 0.1578470721308674, 0.0821470795199275, 0.14567792655101844, 0.13463704900017806, 0.09376436578375952, 0.09910647877092872, 0.1812164288546358, 0.15554101658718927, 0.11994079473827567, 0.1782629151961633, 0.14057550605918678, 0.09060123908732619, 0.2533795508955206, 0.2037386888904231, 0.12141933611461095, 0.18161088840237685, 0.18192967772483826, 7.141061042036329, 54.187566007886616, 89.22978769029889, 78.81400026593889, 79.52534294128418, 76.42896856580461, 62.156236103602815, 59.97970594678606, 49.23549801962716, 31.38933481488909, 20.331907306398662, 29.493331227983745, 33.805887017931255, 30.505412782941544, 31.568455900464738, 46.41263600758144, 61.84005832672119, 36.439636434827534, 11.91983357497624, 3.851613163948059, 0.7582810680781091, 0.2882609191749777, 0.5536373491798128, 0.29735839100820677, 0.1870277284511498, 0.35663434171250885, 0.4709864099110876, 0.5097793968660491, 0.4267466595130307, 1.5598206434931075, 2.2669381627014706, 2.572303891181946, 5.437776599611555, 4.682252500738416, 6.921571356909616, 9.142624701772418, 9.336624486105782, 9.16372811794281, 9.830231462206159, 10.88386845588684, 11.294577343123299, 17.032009771892003, 19.477577652250016, 14.8794960635049, 12.006752065249852, 5.129606187343597, 1.420622929930687, 0.6358509319169181, 1.5493452570268085, 0.8539022856525013, 0.5643589624336788, 1.4528423781905855, 4.58585319348744, 5.8343068190983365, 6.878727027348109, 14.669806378228323, 20.10625239780971, 14.637712648936681, 16.121321541922434, 13.671303340366908, 11.427756939615522, 13.048287034034729, 11.392966440745763, 10.955173475401741, 9.320237159729004, 8.164202826363699, 6.953589958803994, 8.985873341560364, 6.154649606772831, 4.809308128697531, 6.406034129006522, 5.628231934138706, 3.2161845522267476, 2.558682599237987, 0.857962367790086, 0.61746133012431, 0.17890665493905544, 0.3943888715335301, 0.15001737512648106, 0.14090911458645547, 0.2676345131226948, 0.8511575843606676, 2.929570491824831, 9.884097371782575, 26.165293489183696, 53.3155323437282, 64.71256174360002, 57.01722683225359, 84.73793016161237, 71.50141729627336, 51.81272036688668, 63.120680809020996, 36.11426271711077, 37.704656737191335, 48.04864495141165, 60.07466697692871, 64.81759766169957, 72.84935392652238, 79.66722515651158, 66.06503554752895, 38.23942831584385, 14.375081164496285, 3.2747489639690945, 0.2688112014106342, 0.1550471923713173, 0.14120373449155263, 0.15532414322452887, 0.0717798379649009, 0.08620233048817941, 0.15917894137757166, 0.10178245803607361, 0.13453313814742224, 0.15904619278652327, 0.1550361051091126, 0.10931327393544571, 0.13678922637232713, 0.12110882491937705, 0.13842001743614674, 0.13766380372856343, 0.08915713336318731, 0.09973591499562774, 0.2096775123583419, 0.09496630914509296, 0.08248642845345394, 0.13142475565629347, 0.0666106224858335, 0.11717440746724606, 0.1721401951674904, 0.1113388773852161, 0.28149573504924774, 0.08876422766063895, 0.14087670775396482, 0.11497152995850358, 0.20346734273646558, 0.23096610073532375, 0.11362705353115286, 0.09349006121712071, 0.09969480934419803, 0.1114629271573254, 0.16552778998655931, 0.0832221300474235], [0.04512180181752358, 0.03473782080358692, 0.018214027463857616, 0.03701333548607571, 0.04586584599954741, 0.011476367262990346, 0.01565644407777914, 0.055680712551942894, 0.05733075365424156, 0.030308663113308803, 0.0528260105555611, 0.032883157288389545, 0.0712154528924397, 0.05514323139297111, 0.0949319481317486, 0.06574166339955159, 0.04470116099608796, 0.04292476988796677, 0.007641321264340409, 0.028092014736362865, 0.011533343000337481, 0.022203170461580157, 0.015486895139994366, 0.022249804477074316, 0.03502342976363642, 0.04596454570336001, 0.0006317517254501581, 0.03454408548506243, 0.05600867566785642, 0.01519596646539867, 0.02669731993228197, 0.019159979918705564, 0.0730819059535861, 0.08076241346342222, 6.067811455045428, 39.61241667611258, 65.19245297568185, 66.67017500741142, 53.15260056086949, 44.383088043757844, 43.55194452830723, 52.11387613841465, 26.41942732674735, 15.776890652520315, 26.696368626185826, 28.69819154058184, 25.33709600993565, 29.09468354497637, 21.72660183906555, 35.294368335178916, 37.78074993406023, 18.191297599247523, 4.101626285484858, 0.97569340467453, 0.07133838986711842, 0.07810831695262875, 0.0675628785310047, 0.05074189703113266, 0.06414914171078376, 0.10898501226412398, 0.11689899010317666, 0.40066548330443247, 0.5768900385924748, 1.635980173945427, 1.150637862937791, 1.6153875589370728, 3.2467207993779863, 3.4065886437892914, 3.770319674696241, 3.7401093414851596, 3.5996918933732167, 6.083247312477656, 2.8915008774825504, 7.061290945325579, 6.618328085967472, 3.152331692831857, 6.344734949725015, 5.392656735011509, 5.007824242115021, 3.1832390172140936, 2.235524054084505, 1.4893324715750558, 1.429166500057493, 0.9990077593496868, 0.17602849937975407, 0.40793088344591005, 2.7482264169624875, 4.799072563648224, 4.290574295180185, 3.775498688220978, 3.8401855485779897, 5.219854601791926, 3.9209878870419095, 3.165191722767694, 2.8071015434605733, 6.390752868992942, 9.28546403135572, 6.113870629242488, 5.240714831011636, 3.177653751202992, 3.686834897313799, 1.4318634867668152, 4.314873882702418, 2.6843935336385454, 2.8196393506867543, 0.8613138422369957, 2.2160030901432037, 4.265952050685883, 2.332524814776012, 2.2953124344348907, 1.3048966654709406, 0.1906862264232976, 0.24543976836970874, 0.07253314075725419, 0.23847726626055582, 0.06705859809049539, 0.08432179104004588, 0.1725877704364913, 1.3214301211493356, 4.6929188541003635, 14.736340590885707, 25.753115926470073, 37.284978594098774, 45.31138127190726, 47.35819203513009, 36.5301262991769, 55.65532432283674, 36.1882506098066, 17.674247401101248, 27.5736950806209, 31.749261924198695, 44.924140793936594, 48.2243892124721, 59.60723386492048, 55.12431519372122, 55.768941266196116, 27.400169031960623, 10.210489869117737, 2.0540586028780257, 0.33681468665599823, 0.040829711593687534, 0.024838427447580864, 0.11929655287946973, 0.02360765652598015, 0.06806553048746926, 0.040805766092879434, 0.074007807698633, 0.06268581987491675, 0.0642074550102864, 0.05258985662034579, 0.012962156241493565, 0.045578486419149807, 0.03759003596912537, 0.03860481562358992, 0.039608124643564224, 0.03156388843698161, 0.01143598001051162, 0.011205264533470784, 0.048297294814671786, 0.0307893101791186, 0.0072628259492505875, 0.0633034903023924, 0.033044716476329734, 0.016528860299981067, 0.025993268604257276, 0.030037394990878444, 0.04034894917692457, 0.056483796065939326, 0.0597056940730129, 0.01222201278765819, 0.020167251583188772, 0.03553258887092982, 0.034153948205390146, 0.03800641559064388, 0.017009059532678554, 0.034826074460787435, 0.01053864458974983, 0.040873541563217125, 0.023585298797115684, 0.02599949755572847, 0.013247491243029279, 0.030123283953538964, 0.011448556657082267, 0.07963610640061752, 0.033608718176505396, 0.05686673069638865, 0.049114196694322994, 0.01827790983952582, 0.03857729424323354, 0.013777572129453932, 0.07701982464641333, 0.07953925231205565, 0.024548784596845508, 0.03004789532029203, 0.01844294651943658, 0.011016296771621066, 0.04701429366001061, 0.043938406210924895, 0.020117794862017035, 0.07339243071952037, 0.020560766270916377, 0.035933002563459535, 0.029710588777171712, 0.03873483311118824, 0.10030456805335623, 0.06587755360773631, 0.05734698421188763, 0.02477760865752186, 0.07672874669411353, 0.07436940579542092, 9.730542182922363, 51.45240763255528, 73.85834353310722, 74.2786956514631, 62.70831911904471, 56.064364773886545, 55.747853483472554, 60.20130484444754, 40.70389182226998, 28.672992161342076, 36.66102341243199, 26.514303241457256, 23.61313155719212, 30.40369462966919, 25.502817494528635, 37.75850180217198, 30.677693367004395, 16.61877260889326, 3.9985923171043396, 0.5633510393755776, 0.05953959548579795, 0.1858159870441471, 0.01351045155232506, 0.10298163297453097, 0.18198153137096337, 0.4988778904080391, 0.5181798775281224, 1.6245623294796263, 2.6837169528007507, 3.6874337451798573, 3.436329105070659, 4.7517275384494235, 5.513987481594086, 6.067983857222965, 6.160031420843942, 8.029121160507202, 7.156384425503867, 7.34396277155195, 8.48505413532257, 11.304391673633031, 7.986209954534258, 7.448414172445025, 7.248798506600516, 9.860328452927725, 7.270486005714961, 3.3321942814758847, 2.735634978328432, 1.5559595078229904, 0.4969385287591389, 0.9398791321686336, 0.045932539206530364, 0.18561816694481031, 1.96354398557118, 4.34450056723186, 5.1701350297246655, 4.953368169920785, 3.9948012062481473, 4.363868236541748, 4.486424905913217, 5.692270874977112, 5.158472912652152, 6.13475387437003, 6.817437401839665, 6.887578163828168, 5.823799405779157, 5.812226746763502, 5.210716417857578, 3.1171251705714633, 5.582725575992039, 5.784540780952998, 5.824227154254913, 5.810768493584224, 6.005673715046473, 6.238019738878522, 4.369410293442862, 4.993551339421954, 3.786104244845254, 1.5771267605679375, 1.0140941441059113, 1.0060137148414339, 0.6007003752248627, 0.22458203615886824, 0.03953882925478475, 0.1505348937852042, 0.7348194984453065, 2.9910707346030643, 13.156268119812012, 27.148602553776332, 44.26861299787249, 55.0096629687718, 51.021869455065044, 35.80249357223511, 58.03294229507446, 30.711628368922643, 24.588722910199845, 36.59349734442574, 38.7948499407087, 52.90019335065569, 55.649873461042134, 66.24355561392647, 63.08969184330532, 65.86078630174909, 38.54455150876726, 17.7258551461356, 2.3206755306039537, 0.38025059018816265, 0.05932361100401197, 0.08254786301404238, 0.036591995773570876, 0.05531974210004721, 0.025795424756194864, 0.02249074208417109, 0.052004915329494646, 0.05708570073225668, 0.03764077003246971, 0.04509933213038104, 0.009254651925792652, 0.02470269499878798, 0.011178493782478784, 0.08197206498256751, 0.024650749750435352, 0.014622373672734414, 0.033975347610456605, 0.02888827897342188, 0.043487740214914083, 0.03246464706691248, 0.017644483828917146, 0.06574506285999503, 0.017458646658009717, 0.026789519270615916, 0.024775998833190118, 0.04282654855134232, 0.028220033938331262, 0.05169980866568429, 0.018460033727543693, 0.05111116596630641, 0.04045046140838947, 0.046205228859824796, 0.016423448188496486, 0.02408909747776176, 0.023724897199177315, 0.030957498654190983, 0.11720925702580384, 0.11853470733123166, 0.10283409910542624, 0.15954562170164927, 0.08305193310869591, 0.15412510399307522, 0.11740444440926824, 0.1494347442473684, 0.18268785918397562, 0.1348859356450183, 0.1315028550369399, 0.11404102774603025, 0.21961490197905473, 0.08978543643440519, 0.14450593372540815, 0.1405692771077156, 0.15672565730554716, 0.17763715663126536, 0.09999398221927029, 0.06385273047323738, 0.12079692951270513, 0.11054865550249815, 0.14908133606825555, 0.17893416274871143, 0.12016130504863602, 0.16510148000504288, 0.0825396663110171, 0.13424166664481163, 0.17885121862803185, 0.14122903027704783, 0.2242783238845212, 0.16494616333927425, 0.14661205214049133, 0.197869388120515, 12.482058354786464, 62.97369166782924, 84.74578162602016, 83.2356948852539, 72.10355513436454, 63.408565521240234, 59.64621325901577, 66.93704141889299, 38.80854484013149, 24.996184383119854, 40.16950934273856, 38.80775274549212, 32.865462235042024, 41.22148050580706, 31.286341667175293, 48.2095548084804, 50.21952274867466, 22.45794837815421, 5.531770093100412, 1.8319969986166273, 0.31855701921241625, 0.2117372868316514, 0.22784668526479177, 0.2049219318266426, 0.15228098151939257, 0.3522276910287993, 0.355559840798378, 1.890968097107751, 2.6910781349454607, 6.080611339637211, 5.472398170403071, 6.496613885675158, 10.431507723672048, 9.985460298401968, 11.875520569937569, 13.584601981299263, 13.611582704952784, 15.362461873463221, 12.815532803535461, 18.935562576566422, 15.967771564211164, 14.260190095220294, 17.34141652924674, 19.49962428637913, 16.135541030338832, 13.69311113016946, 11.89695315701621, 7.61972895690373, 3.784728935786656, 1.862978799002511, 0.6138991841248104, 1.04265210883958, 1.50608349272183, 2.907140621117183, 4.022549271583557, 7.996697391782488, 12.119926060949053, 15.602054868425641, 14.059946485928126, 12.494849119867597, 11.102611643927437, 16.63823972429548, 18.555100066321238, 13.743573290961129, 14.531930668013436, 9.040550453322274, 9.881352833339147, 5.650931264672961, 12.470974240984235, 11.081264172281537, 10.568797179630824, 6.122469459261213, 7.865911449704852, 11.931463990892683, 7.251791443143572, 6.959546736308506, 4.808829137257167, 1.7575217549289976, 0.5644776789205415, 0.42657043039798737, 0.399317451353584, 0.21240497886070184, 0.1925301453364747, 0.3937104179390839, 2.0143628929342543, 6.321372934750148, 18.09883097239903, 32.504378250667024, 46.26454210281372, 55.83286816733224, 56.687145709991455, 51.69151946476528, 67.47432477133614, 47.32973916190011, 30.286287443978445, 41.59584249768938, 45.49720736912319, 61.399674551827566, 63.95784841264997, 74.18714618682861, 73.02282265254429, 76.9118961606707, 47.97148520605904, 21.57623413630894, 3.941222778388432, 0.5819298710141863, 0.10906481476766722, 0.1662733099822487, 0.20354229371462548, 0.12105505780449935, 0.13594628231866018, 0.13406397189412797, 0.2618521734007767, 0.17458332835563592, 0.11085304631186382, 0.13643162484679902, 0.09130983999265091, 0.11757466170404639, 0.08358389777796608, 0.09377979567008358, 0.10538119742912905, 0.11750630608626775, 0.09907016357673065, 0.10007926728576422, 0.16494054506931985, 0.11906866010810647, 0.06966584854360137, 0.1137676052749157, 0.1034712502732873, 0.11572664443935667, 0.0960782855483038, 0.13625771632151945, 0.11551072102572237, 0.10642581566103868, 0.17432838917842933, 0.11433388346007892, 0.14301505658243382, 0.19902344048023224, 0.09972196431564433, 0.0686607210497771, 0.12967222183942795, 0.12963571665542467], [0.15611272305250168, 0.05143473556797419, 0.041338504292070866, 0.02468068671545812, 0.012551965707513903, 0.02727530454285443, 0.030434131023607085, 0.15589418049369538, 0.08175446558743715, 0.23462837136217526, 0.09357439633458853, 0.07558084186166525, 0.04004381876438856, 0.0265642151103488, 0.07100780760603291, 0.10318296788526432, 0.039598187498216114, 0.06213697325438261, 0.04580949705892375, 0.0623608830251864, 0.03038724764649357, 0.07520065190536634, 0.07403230959815638, 0.09721063157277447, 0.14784704015723296, 0.10002254175820521, 0.03506956335955432, 0.03330224087195737, 0.024850486711199795, 0.039281827331121476, 0.08244250009634665, 0.07516698299774102, 0.08043331719402756, 4.712776805673327, 26.42579882485526, 65.71747970581055, 62.63410540989467, 53.08777386801583, 42.35531881877354, 39.27006156103951, 48.41402292251587, 33.6472943850926, 19.266593864985875, 18.064122983387538, 23.616240876061575, 40.36967999594552, 53.365667070661274, 35.754641328539165, 39.30821064540318, 32.96184417179653, 10.765397327286856, 2.163504890033177, 0.34216346964240074, 0.16419050603040627, 0.0427769578195044, 0.06729041279426642, 0.05995141874466624, 0.24261714411633356, 0.19964313294206346, 0.29571750334330965, 0.7455631505165781, 3.2047284926686967, 3.1176200125898634, 1.3178958765098026, 1.7514063630785262, 2.093973398208618, 3.6760261058807373, 5.219061638627734, 5.5512641327721735, 7.155630545956748, 4.923348912170955, 4.97623165164675, 4.873903359685626, 7.936646716935294, 7.2340400985309055, 4.026230948311942, 6.413181219782148, 8.30122651372637, 4.9175350069999695, 0.7323428999100412, 3.0377823880740573, 1.665771335363388, 0.5275888783591134, 0.38076638536793844, 0.6349514116133962, 6.5049130746296475, 21.928113494600566, 26.72557364191328, 25.157525028501237, 23.88248368671962, 8.414805241993495, 4.498016672474997, 3.212596024785723, 4.781259553773062, 5.55370512178966, 5.80632164648601, 4.004165640899113, 5.754464634827205, 4.3886051263128, 4.1244328788348605, 2.124068000486919, 2.4635137745312283, 3.1648708028452734, 6.492411094052451, 4.742312729358673, 3.264110186270305, 3.8392844540732245, 6.274325813565936, 6.015136727264949, 3.1247058723654066, 2.8122903278895786, 1.743023795740945, 1.1256303191184998, 1.3014005273580551, 0.1159055062702724, 0.06964453575866562, 0.2652847192117146, 0.06492071066583906, 0.029710205404886177, 0.00857270896501307, 0.35090973174997736, 2.220797347170966, 10.591046180043902, 20.105493307113647, 33.058722904750276, 28.993278060640606, 25.427466017859324, 38.74417325428554, 16.537603752953665, 14.810170412063599, 26.807555437088013, 31.680770056588308, 48.13404873439244, 47.843099866594585, 53.10694394792829, 54.38801458903721, 52.85106611251831, 47.49695798328945, 16.635163409369333, 3.279559940099716, 0.2760660706886223, 0.034206873936844726, 0.034874728814299615, 0.02324097789824009, 0.00845602638686874, 0.10479442070105247, 0.04193548279415284, 0.08030768643532481, 0.09399309315319572, 0.05784193479589053, 0.10768400279006787, 0.09623932904962983, 0.08544262232525007, 0.04576264421588608, 0.04216651039730225, 0.013194961606391838, 0.09889094890760523, 0.06264040552611862, 0.16994037106633186, 0.19548595244331018, 0.27808435953089167, 0.026707258773967624, 0.06175360096884625, 0.05339432095310517, 0.06773279727037464, 0.029250701490257467, 0.025308445262323533, 0.11917832493782043, 0.0181860209309629, 0.03261680854484439, 0.0333090499708695, 0.11779674621565, 0.10356382959123168, 0.14509393860186848, 0.14709491123046192, 0.10336881862687212, 0.08467518564845834, 0.01477311022712716, 0.024539422509925704, 0.036681413118328364, 0.09208039114517824, 0.026087072677910328, 0.02493418230941253, 0.07754743990621396, 0.13020869876657212, 0.19929925139461244, 0.13042588425534113, 0.014363895935405577, 0.021026600917269076, 0.051726285102111955, 0.0315445637596505, 0.056237097696534226, 0.06619430732514177, 0.016097439253436666, 0.06137381813355854, 0.04050969751551747, 0.0503680649479585, 0.14181157973195824, 0.06281497901571648, 0.07822480105928012, 0.06868315341749362, 0.03637740907392331, 0.03294896500717316, 0.029660258442163467, 0.07393635117581912, 0.025501980413017527, 0.08362254034727812, 0.08033469891441719, 0.07081535471869366, 7.63857855115618, 43.00973490306309, 75.02703053610665, 71.89419896262032, 61.88313020978655, 50.333754607609336, 50.52137681416103, 52.31558581760952, 42.78034707478115, 25.362743547984532, 21.45588265146528, 27.245403119495936, 38.142573901585166, 37.84323855808803, 37.826507295881, 38.47423573902675, 33.108965328761506, 12.618851014545985, 2.484470627137593, 0.49028937412159784, 0.07447641755321197, 0.029330144370240823, 0.20297119793082985, 0.4995224986757551, 0.8430778607726097, 1.5117193503039223, 2.3171299951417104, 3.3119272547108785, 5.112362061228071, 5.376688471862248, 5.814153569085257, 4.407776943274906, 5.465311007840293, 4.347318061760493, 6.5932581169264655, 8.31205267565591, 13.166229231016976, 11.126368403434753, 8.318757687296186, 8.78702197756086, 9.898851002965655, 7.678417784827096, 5.824380448886326, 6.565715891974313, 6.646755337715149, 4.819941912378583, 2.6548617354461124, 2.6391861651624953, 1.1077381649187632, 0.1967505517282656, 0.32845860932554516, 1.1780792304447718, 7.787408096449716, 23.417982714516775, 30.974093096596853, 27.329033374786377, 22.560880729130336, 7.005182504653931, 3.598076654332025, 3.9582007016454424, 6.100363765444074, 7.586509619440351, 6.386704240526472, 5.1769121289253235, 4.293254997049059, 5.556625970772334, 6.033484314169202, 5.347903387887137, 5.579127711909158, 5.579494229384831, 8.11223464352744, 5.876777682985578, 7.595825416701181, 7.818080050604684, 6.313114132199969, 8.168026941163198, 3.896100308213915, 5.005418862615313, 4.806883207389286, 5.379946742738996, 3.3976675910609107, 1.9136422404221125, 0.5961036533117294, 0.436116522444146, 0.3088263656411852, 0.04378282152382391, 0.019604674806552272, 0.33871225054774967, 2.760359057358333, 11.215035234178815, 21.679046630859375, 31.696545941489084, 31.6396575655256, 38.033660888671875, 39.20155579703194, 20.853927203587123, 23.15608079092843, 36.2161545753479, 41.89265217099871, 54.42668826239449, 55.84069183894566, 59.481540952410015, 62.380829674857004, 61.68996334075928, 60.58718000139509, 29.474432127816335, 6.722402112824576, 0.5950873707021985, 0.05893449831221785, 0.06778370775282383, 0.05024035447942359, 0.011844861820074064, 0.028017859340512326, 0.05954995671553271, 0.015538048198712724, 0.06405278973813568, 0.05709117650985718, 0.021984868782705495, 0.08686603273132018, 0.06597767144973789, 0.06258223471896988, 0.04270443260403616, 0.01777639951823013, 0.07763047902179615, 0.11129980733884232, 0.10902763783399548, 0.17267528788319655, 0.038776834428842576, 0.030867562230144228, 0.022336651870448674, 0.03045059906850968, 0.02427949440399451, 0.03375879315925496, 0.08503729264651026, 0.07678119745105505, 0.0429750561181988, 0.012031043347503458, 0.011297921882942319, 0.06664904792393957, 0.10606861447117158, 0.08151716153536524, 0.018310554159272994, 0.012007731428769017, 0.20874897789742264, 0.12517326325178146, 0.09493786495711122, 0.1841714352901493, 0.103807661150183, 0.1595687868871859, 0.14190144490982803, 0.2734244524368218, 0.1908185678933348, 0.2699504074241434, 0.19798031502536365, 0.09463553010885205, 0.14120061323046684, 0.08325494400092534, 0.11660105894718852, 0.2978115981178624, 0.1402176466903516, 0.1268590156521116, 0.15050214768520423, 0.1681281125971249, 0.14273620583117008, 0.21540077882153646, 0.18057099277419703, 0.1434625368565321, 0.13484956616801874, 0.1468776036053896, 0.10313641359763485, 0.1679809654929808, 0.19054951518774033, 0.10615402845931904, 0.1600880425955568, 0.14674102807683603, 0.1630967211510454, 9.705027529171534, 59.09515162876674, 87.60604231698173, 81.062666620527, 71.82949038914272, 56.967606272016255, 53.48633990968977, 62.87945325034005, 44.75917318889073, 28.39261324065072, 26.488681759153092, 34.868148463112966, 55.2421601159232, 70.81474072592599, 48.3420604297093, 53.18119587217058, 43.26153761999947, 15.176330055509295, 3.148874964032854, 1.0021444367510932, 0.21153580264321395, 0.2709955684840679, 0.28900063091090744, 0.6325765390481267, 0.9711007539715085, 1.3156469400439943, 1.9430622160434723, 3.4180147392409186, 10.008860962731497, 9.70892025743212, 7.877482805933271, 6.705667810780661, 9.618009158543178, 10.839473809514727, 14.823764562606812, 16.368559292384557, 14.766424553734915, 14.32832326207842, 12.741894057818822, 15.261914491653442, 18.40003364426749, 16.45570707321167, 12.156237346785408, 14.291924255234854, 14.608022996357509, 12.660419481141226, 5.923376645360674, 4.602499774524143, 2.6557841088090623, 1.1026590317487717, 1.0422868941511427, 2.480880145515714, 6.251561777932303, 15.491359642573766, 19.743551220212662, 17.834634406226023, 19.522289310182842, 10.580631698880877, 12.04555080618177, 10.18364029271262, 16.085781506129674, 15.172079495021276, 18.458888360432216, 15.039850064686366, 13.111727561269488, 12.131823113986425, 11.056062187467303, 10.309348838669912, 9.60271964754377, 6.0381300534520825, 11.064802152769905, 10.448651535170418, 8.337723663875035, 12.89132114819118, 13.18555564539773, 12.144479257719857, 8.200653944696699, 7.9800616673060825, 5.520933074610574, 5.0168373584747314, 3.495966144970485, 1.144225544163159, 0.40098271199635094, 0.35680801953588215, 0.27751932985016275, 0.09429194033145905, 0.09931693319231272, 0.9405379082475389, 4.775829970836639, 15.525574309485298, 28.69437871660505, 43.48307050977434, 43.09152562277657, 38.299954073769705, 48.54213033403669, 28.465887205941335, 24.454356908798218, 39.28790800912039, 45.915245737348286, 62.344428062438965, 65.12407575334821, 68.19818810054234, 68.00688334873745, 72.49999850136894, 69.67370755331856, 36.10205473218645, 8.004418577466692, 0.7734514283282417, 0.14972038034881863, 0.18673020441617283, 0.1741835219519479, 0.16970839351415634, 0.20585798445556844, 0.14061768379594597, 0.15120166300662927, 0.297164682831083, 0.19069735439760344, 0.2512638787073748, 0.1828133745917252, 0.13866441217916353, 0.1014323000397001, 0.19056936912238598, 0.19082909875682422, 0.1952405534684658, 0.18344561995140143, 0.2019235805741378, 0.19543400380228246, 0.29366650911314146, 0.1085984915761011, 0.11953380943409034, 0.14327904741678918, 0.12467601921941553, 0.14076458662748337, 0.16140292132539408, 0.23523693584970065, 0.13769583058144363, 0.12443469145468303, 0.09553815810275929, 0.18133256690842764, 0.2757540260042463, 0.22419966810515948, 0.17566503531166486, 0.15769277326762676], [0.34009985466088566, 0.11199050170502492, 0.04257387228842292, 0.02457577671988734, 0.05446545294086848, 0.0910430196672678, 0.048989716052476845, 0.12894871351974352, 0.16400548310152122, 0.27820627870304243, 0.10685218671070677, 0.10043678738709007, 0.049739670274513106, 0.02243170444853604, 0.14400159221674713, 0.1879151165485382, 0.14509262224393232, 0.08869579740400825, 0.07818487605878285, 0.04418081963168723, 0.06099737369056259, 0.06881417174424444, 0.24465196207165718, 0.30063992206539425, 0.10969064797141723, 0.06546537751065833, 0.03401928614558918, 0.1294103751757315, 0.06425649952143431, 0.1283309209559645, 0.1259945756090539, 0.05790400717939649, 5.721909718854087, 37.08155618395124, 51.079727104731965, 59.598284585135325, 55.63490009307861, 42.11895152500698, 36.15713657651629, 53.28584963934762, 102.97897338867188, 42.9224203654698, 20.531146900994436, 33.57263251713344, 41.63577379499163, 40.079717772347585, 35.41345698492867, 38.12939664295742, 18.284763029643468, 9.112652778625488, 0.7620164304971695, 0.0788946169029389, 0.16654162987002305, 0.061884313954838684, 0.05657529990587916, 0.16409994874681744, 0.17017597199550696, 0.09571353226367917, 0.6934698458228792, 0.9336093600307191, 1.754619144967624, 2.1191469388348714, 2.78008542742048, 3.17955191220556, 3.936303888048444, 3.935990784849439, 2.137080890791757, 3.6656906604766846, 7.4604571376528055, 15.357756205967494, 6.880239129066467, 2.9148073068686893, 5.752538246767862, 7.525532228606088, 5.9023726752826144, 5.056078178542001, 4.371815238680158, 3.693448713847569, 2.817527098315103, 2.3313453580651964, 1.8771754886422838, 2.4289757992540086, 1.0084593721798487, 1.4900839626789093, 14.264755930219378, 38.17522348676409, 52.475081716264995, 55.06122555051531, 56.00423853737967, 52.9564459664481, 29.348704474312918, 8.862146769251142, 2.867137236254556, 3.198647516114371, 2.226776272058487, 2.814757589782987, 3.2767795750073025, 4.795209799494062, 3.6513752000672475, 5.00554393018995, 5.582473269530705, 5.235805060182299, 4.597874445574624, 6.522382148674556, 6.6014222502708435, 11.113832984651838, 7.98891019821167, 3.008053000484194, 4.427663556167057, 5.268807700702122, 5.825656311852591, 3.146291102681841, 4.355940341949463, 3.6364248480115617, 1.1374297716787882, 0.8237524234822818, 0.09912768977561168, 0.0804557359910437, 0.13856882016573632, 0.16258924481059822, 0.06439173833600112, 0.35857226486716953, 3.520840044532503, 13.903363619531904, 30.142345087868826, 41.48250000817435, 30.798578126089915, 32.98954316547939, 28.430649416787283, 20.257059574127197, 17.86588740348816, 24.848694971629552, 29.51640966960362, 32.512459005628315, 47.3675651550293, 48.94610207421439, 55.64534323556082, 61.602631432669504, 51.8622019631522, 33.0530948638916, 12.835319536072866, 0.14489139589880193, 0.09707977609442812, 0.09472442498164517, 0.1323835120669433, 0.16359473871333258, 0.028237814948494946, 0.012179216735863259, 0.005466597021690437, 0.11777451740843908, 0.15496454680604593, 0.13588927180639335, 0.2062703844692026, 0.14735405732478413, 0.07194117323628493, 0.07256170029618911, 0.030932796586837088, 0.17460193378584726, 0.28537220561078613, 0.46224020208631245, 0.3856360140655722, 0.10866804820086275, 0.029506902742598737, 0.115984121337533, 0.10139507560857705, 0.10589302996439592, 0.086428852618805, 0.18830106726714543, 0.02203467664574938, 0.02010273647361568, 0.014506841211446693, 0.27581726546798435, 0.146456599767719, 0.2753295616379806, 0.2654452605971268, 0.16322708129882812, 0.2538822367787361, 0.10175967961549759, 0.030528216689292873, 0.02971597295254469, 0.019906531287623302, 0.04058006498962641, 0.07779359884027924, 0.059579113365284035, 0.07635616990072386, 0.1377246683197362, 0.08465607810233321, 0.036879694621477804, 0.045446613138275485, 0.04025561668510948, 0.08453179762831756, 0.021520058724230955, 0.034684345458767245, 0.026105438924527595, 0.06693935913166829, 0.018556994685371007, 0.045211819665772576, 0.019646884773724844, 0.10122791172138282, 0.1309217033641679, 0.058548866505069394, 0.07994019186922482, 0.07370075024664402, 0.07514822828982558, 0.006715296958905778, 0.03871931501531175, 0.11903387840305056, 0.04279040638357401, 8.459457840238299, 45.77463156836373, 60.769424302237375, 69.43309838431222, 63.934182848249165, 49.82907567705427, 44.720009667532786, 62.58890042986189, 100.60065364837646, 46.762505599430625, 24.494732890810283, 26.323271206447057, 31.771058423178538, 34.04215356281826, 35.613766602107454, 35.2242088999067, 21.702620131628855, 9.102534464427404, 0.8045617161052567, 0.05322596623695322, 0.08000713613416467, 0.034215905237942934, 0.1900446308510644, 0.9989304606403623, 1.1629304204668318, 1.4479939469269343, 2.436661158289228, 4.503514000347682, 5.386789415563856, 5.371912019593375, 6.747765643256051, 6.278143848691668, 5.766899738992963, 7.512330651283264, 7.233169836657388, 9.110808031899587, 10.169067314692906, 14.625044345855713, 9.726410610335213, 6.036863744258881, 7.421671424593244, 7.597090857369559, 5.160198671477182, 4.15345333303724, 2.711828712906156, 1.817977813737733, 1.0307986991746085, 1.1744506422962462, 0.357881136238575, 0.9122744819947651, 0.24371072543518885, 2.7981437955583846, 16.27297466141837, 44.503159863608225, 60.545157296316965, 66.0458654676165, 63.544826643807546, 57.387086391448975, 31.577134200504847, 10.44007658958435, 4.905124655791691, 5.0382382443972995, 4.92594449860709, 5.689911527293069, 2.8321962654590607, 4.725064260619027, 2.372408777475357, 4.946580648422241, 5.990885777132852, 8.387418917247228, 6.080156666891916, 6.843354182583945, 5.813447458403451, 7.172796939100538, 8.838740025247846, 4.740118835653577, 9.26827245099204, 7.174744171755655, 6.173880049160548, 6.741950001035418, 6.299054018088749, 6.8660934652600965, 4.421824898038592, 3.8314577426229204, 0.7620104051062039, 0.6800494002444404, 0.38190371862479616, 0.10217870891626392, 0.07263167082731213, 0.24294843205383845, 1.7410991447312492, 10.149027841431753, 25.82804008892604, 39.00181940623692, 33.545006479535786, 37.394708020346506, 23.64142288480486, 21.402883529663086, 24.81609923498971, 30.060123579842703, 35.359976700374055, 39.0265793119158, 51.838699681418284, 54.850271293095176, 63.89854553767613, 68.26871231624058, 66.94699123927525, 46.1710193497794, 18.67783304623195, 0.7906565251094955, 0.056742989657712836, 0.040736253572893996, 0.06932799238711596, 0.04502563983468073, 0.08351715707353183, 0.04101600677573255, 0.005310084862035832, 0.08503510097840003, 0.031097449894462312, 0.04813298416723098, 0.08401889300772122, 0.14666370222611086, 0.08436817569392067, 0.0981861681544355, 0.0321207451634109, 0.061020966353160996, 0.1962799062686307, 0.2331141797559602, 0.29628782559718403, 0.13229956371443613, 0.026343776046165397, 0.10032543300517968, 0.08900199990187373, 0.04627086015950356, 0.1033155197011573, 0.09989134701234953, 0.03475993425984468, 0.019247329427993724, 0.039873849134892225, 0.16968188993632793, 0.0912891650306327, 0.099235366497721, 0.15053583016352995, 0.06724361423403025, 0.5015658661723137, 0.35643987357616425, 0.13159573291029247, 0.1668093797883817, 0.10398180716271911, 0.20388062484562397, 0.16883973298328264, 0.22487813527030603, 0.28338673072201864, 0.47981116494962145, 0.2050346772053412, 0.1858107623245035, 0.14624963301633084, 0.12308475960578237, 0.3064585498401097, 0.331839667899268, 0.3074853904545307, 0.287533909614597, 0.1681285197181361, 0.12311266096574919, 0.11042820875133787, 0.2215519566088915, 0.2805198388440268, 0.36612332825149807, 0.19441583486539976, 0.31140300737959997, 0.16426468347864492, 0.2261217813938856, 0.13147390873304435, 0.20391883993787424, 0.18307417631149292, 0.12214055098593235, 12.820688366889954, 57.940614632197786, 73.34518432617188, 77.35340554373605, 73.72791194915771, 56.99483626229422, 51.97571815763201, 65.69517598833356, 105.5814767565046, 52.228809765407014, 31.029133251735143, 47.574430397578645, 57.60918208530971, 56.53230857849121, 49.6102352142334, 49.48373631068638, 26.601553508213588, 12.379781740052358, 1.5069463721343448, 0.2422387387071337, 0.2705105245113373, 0.20349539337413652, 0.2565763464995793, 0.8588158019951412, 1.0036359110048838, 1.2848401474101203, 4.466105333396366, 5.227323915277209, 8.052561776978628, 9.546116147722516, 10.642836315291268, 12.21067474569593, 14.556218096188136, 12.239668709891182, 11.443063821111407, 13.164210779326302, 19.353290012904576, 24.65246742112296, 15.610048770904541, 13.77592670917511, 16.088937725339616, 16.378802674157278, 13.705531903675624, 15.685679912567139, 13.176907743726458, 14.647214310509817, 11.418538417134966, 5.655476255076272, 5.719593363148825, 5.682904703276498, 2.1362540551594327, 3.335723097835268, 18.195666279111588, 41.17496231624058, 49.24257823399135, 53.05431134360177, 50.93912335804531, 47.82529163360596, 31.716918059757777, 14.72384078162057, 9.977372595242091, 9.450832026345388, 10.2778274672372, 11.29533382824489, 13.375098160334996, 15.454362222126552, 11.03486236504146, 13.758247886385236, 12.108800257955279, 12.378468530518667, 12.654629894665309, 13.585528697286334, 14.17142425264631, 18.603046110698156, 16.336368288312638, 11.33204550402505, 14.71081464631217, 12.949402008737836, 14.795091084071569, 10.45397298676627, 10.57114393370492, 9.134122712271553, 5.403302678040095, 3.3317535051277707, 0.601904747741563, 0.3975171351007053, 0.30550900793501307, 0.5539724911962236, 0.316982058009931, 0.6492013526814324, 4.245926473821912, 16.826739140919276, 40.11493124280657, 53.05162933894566, 40.72382272992815, 43.1190995488848, 38.55202777045113, 29.644603933606827, 24.706840549196514, 34.88769721984863, 42.694224153246196, 46.73132903235299, 62.95367390768868, 66.86166041237968, 71.69373648507255, 79.25317505427769, 77.07802064078194, 55.38456344604492, 21.73699460710798, 1.1849846541881561, 0.2101823424122163, 0.2018645480275154, 0.18601038732698985, 0.16933783196977206, 0.1811346382434879, 0.16741489086832317, 0.06286824401468039, 0.13505832425185613, 0.25912780101810184, 0.29360913219196455, 0.2724843014563833, 0.3139471065785204, 0.16408378604267324, 0.1757013505058629, 0.15567209598209175, 0.2378610750394208, 0.47821085367883953, 0.5717829497797149, 0.5354008791702134, 0.27036824928862707, 0.1454695484467915, 0.20873989909887314, 0.1928054541349411, 0.22297671729964869, 0.2637400206710611, 0.32188056515795843, 0.14097263903490134, 0.14720464391367777, 0.12665605225733348, 0.3121651107711451, 0.2787498938185828, 0.3064539629433836, 0.39785851963928764, 0.32882716240627424], [0.37282937126500265, 0.0977003506517836, 0.10180739419800894, 0.05068059139219778, 0.12474461910980088, 0.032879713723169904, 0.06574757343956403, 0.09034406752990824, 0.11221791950187512, 0.22606292526636804, 0.1204970306051629, 0.14057542463498457, 0.051523752577070675, 0.020335511304438114, 0.09707761156771864, 0.23585793109876768, 0.143615098670125, 0.18317465377705439, 0.18457269375877722, 0.11117032250123364, 0.048918778608952246, 0.11733959003218583, 0.11828150520367281, 0.2802951894700527, 0.14883156732789107, 0.07343393670661108, 0.06604728235730103, 0.12460488160806042, 0.035662524934325895, 0.11935143279177801, 0.040164971191968234, 0.9591160884925297, 25.18673872947693, 52.285878794533865, 59.930074964250835, 53.34922415869576, 48.09715032577515, 44.070780413491384, 26.518626758030482, 25.559539113725933, 43.58028623035976, 35.893011229378835, 22.783556597573416, 36.66560227530343, 38.72549649647304, 40.9406794820513, 40.139982972826274, 21.76776991571699, 5.647713814462934, 0.4750075712800026, 0.011782561279168087, 0.2632976158389023, 0.04170031273471458, 0.06384306813457183, 0.11550747762833323, 0.5377754803214754, 0.7290762151990617, 1.0354396615709578, 2.2775797631059373, 4.031555439744677, 4.420021406241825, 3.5168776171548024, 4.394286147185734, 3.982029982975551, 2.534990110567638, 3.292252561875752, 1.7105434643370765, 5.021395376750401, 5.1447063599314005, 17.859340463365825, 10.9915030002594, 8.271867769105093, 4.999859869480133, 4.377287379332951, 4.596029264586313, 2.3596514505999426, 2.727300831249782, 2.520121616976602, 3.5148858726024628, 5.29408437865121, 9.890689475195748, 6.335827359131404, 15.471128225326538, 22.928414378847393, 40.30723653520857, 51.33265890393938, 51.88148321424212, 52.185685770852224, 57.77748482567923, 61.11468723842076, 46.967143944331575, 24.995216846466064, 10.627340963908605, 10.064450894083295, 6.4330682669367105, 5.275200477668217, 4.083633925233569, 5.037869989871979, 4.677236769880567, 5.080363869667053, 2.3914366364479065, 5.180038384028843, 5.121521958283015, 10.56045413017273, 4.48876862015043, 9.368217945098877, 8.520174673625402, 3.167575389146805, 8.661580068724495, 4.961315606321607, 3.903129279613495, 6.744354512010302, 7.065459430217743, 5.075664281845093, 3.45072403550148, 1.6377690093857902, 1.4649891321148192, 0.5908768709216798, 0.08505398460796901, 0.05936823146683829, 0.03533176964681063, 0.08674793371132442, 0.2200391356434141, 1.1522114127874374, 5.4277503490448, 20.711655889238628, 36.51726518358503, 30.683547224317277, 26.916261741093226, 22.237520251955303, 27.69756235395159, 46.391329356602256, 46.33819995607649, 28.137716838291713, 32.52657774516514, 35.75186204910278, 43.74555608204433, 49.94359936032976, 57.539099080221995, 54.371682848249165, 52.266653129032676, 21.42874472481864, 1.215967214533261, 0.07965442006077085, 0.050252652926636596, 0.07622320417846952, 0.0780397102768932, 0.012141538534446486, 0.05859580755765949, 0.10175223608634301, 0.14695475303700992, 0.11234830000570842, 0.1603241999234472, 0.18219484921012605, 0.07595539319195918, 0.16578004216509207, 0.07595725237791028, 0.03748765182016151, 0.15486493786530836, 0.31722844764590263, 0.3423524552157947, 0.0619991695774453, 0.023237480050218955, 0.08101123904011079, 0.07468387284981352, 0.14985003482018197, 0.14235870965889522, 0.1788699733359473, 0.11517141280429703, 0.0698397367128304, 0.020652885881385634, 0.06629150746656315, 0.03689377422311476, 0.10983406991830894, 0.31371024357421057, 0.11438950976090771, 0.206696002345, 0.16666599176824093, 0.07045882527849504, 0.024040283668520193, 0.056688808636473756, 0.039818585850298405, 0.04756612583462681, 0.10302223651004688, 0.08884871205581085, 0.12048508838883468, 0.117758395416396, 0.022923801792785525, 0.03603296094973173, 0.03405532992577978, 0.14943893759378366, 0.06415371503680944, 0.0662829986374293, 0.07299416459032468, 0.07396525676761355, 0.053263295841004164, 0.01674268364773265, 0.07400096806564502, 0.09912880935839244, 0.06318743367280279, 0.07421287455196891, 0.08445960828768355, 0.00898970605339855, 0.10502544830420188, 0.1345995802964483, 0.10399742025349822, 0.042666611062096696, 2.485792739050729, 34.05808925628662, 62.26594121115548, 72.66881888253349, 61.03030136653355, 58.868758474077495, 54.477027961185996, 36.43937240328108, 36.412649631500244, 50.401892117091585, 39.67197663443429, 25.6583286012922, 31.698963914598735, 35.990032400403706, 43.963736465999055, 37.18243360519409, 19.63313913345337, 5.27153400012425, 0.7536281091826302, 0.06396586940224681, 0.01411667000502348, 0.07390449395669357, 0.4579210824200085, 1.3444825070244926, 2.281683542898723, 3.938430905342102, 3.211254805326462, 4.523810122694288, 6.642453100000109, 7.529824478285653, 7.602619017873492, 7.762913090842111, 6.442779242992401, 7.004164159297943, 8.371536203793116, 7.355415139879499, 6.442450940608978, 9.015825288636343, 5.919682809284755, 6.505384249346597, 7.345568673951285, 2.5281513461044858, 3.3057125253336768, 4.121128141880035, 1.201630366700036, 0.7410116461770875, 0.640930770763329, 1.7444840031010764, 5.41101257290159, 8.242383088384356, 8.428999543190002, 17.607219866343907, 26.169099364961895, 44.64983980996268, 62.369705608912874, 62.659834589277, 61.026660510471885, 67.37274905613491, 70.74880232129777, 51.51834603718349, 28.921506643295288, 12.676567094666616, 11.045125722885132, 7.013278458799634, 6.179815113544464, 5.513793800558362, 6.782078887735095, 3.71497814144407, 3.748723804950714, 4.792700631277902, 4.823417314461299, 7.41110668863569, 14.268520985330854, 6.318158524377005, 6.876510117735181, 10.624704991068159, 5.9717565178871155, 9.075128163610186, 6.2394015618733, 6.443590445177896, 6.055940892015185, 8.06826036317008, 7.714310441698347, 7.34969242981502, 4.899908295699528, 3.145289476428713, 2.30330633691379, 0.912582699741636, 0.2546300095106874, 0.21551500340657576, 0.14438423168446335, 0.17753614990838937, 0.45700847996132715, 4.163160834993635, 19.619221891675675, 30.742492267063685, 38.752990518297466, 32.30773033414568, 22.21895640236991, 29.802658081054688, 49.441730976104736, 48.571278027125764, 35.534807273319785, 45.412977831704275, 45.82854264123099, 49.442981651851106, 55.456553731645855, 63.21785136631557, 61.951305934361045, 62.29940373556954, 30.394710608891078, 2.9247527846268246, 0.10446562298706599, 0.09389688367290155, 0.048662763953741105, 0.0624897028984768, 0.08052268704133374, 0.0317571250322674, 0.03992845763319305, 0.07208646793982812, 0.09565393653299127, 0.12301584758928844, 0.0923929243747677, 0.041366022279752154, 0.045548535883426666, 0.007181689276226929, 0.06664091228906598, 0.1401199105062655, 0.16712436931473867, 0.13211243732699327, 0.033301083969750574, 0.03848778868892363, 0.07956131148551192, 0.1126695591956377, 0.1302661028291498, 0.09297562310738222, 0.14260735203112873, 0.04921934926616294, 0.022583299349727373, 0.12335044677768435, 0.09970623587391206, 0.07393987955791609, 0.15088424432490552, 0.12133838688688618, 0.022927284373768737, 0.5405687104378427, 0.435528531138386, 0.23582490001405987, 0.19980428500899247, 0.23712603162441934, 0.18903020742748464, 0.15451435239187308, 0.37145642350826946, 0.31046125505651745, 0.42452771429504665, 0.3623008147946426, 0.22758170376930917, 0.19350837570215973, 0.0818417930443372, 0.33085256229553905, 0.3255943501634257, 0.3272621620978628, 0.3117103837430477, 0.31293125823140144, 0.15774103067815304, 0.29611496201583315, 0.2228746520621436, 0.3345306020762239, 0.3408794371145112, 0.23070741604481423, 0.16470364135290894, 0.2128958310931921, 0.1994299100978034, 0.24579179233738355, 0.22464664626334394, 0.21403225511312485, 5.178495015416827, 42.75385011945452, 73.61997863224575, 80.96323789869035, 71.74821036202567, 63.71460587637765, 60.36354528154646, 37.99159302030291, 37.56834350313459, 53.32316493988037, 44.5399158341544, 33.18485007967268, 53.36104999269758, 54.35717153549194, 53.49842282703945, 51.09717403139387, 29.182847499847412, 7.88731016431536, 1.064401924610138, 0.20591479140732968, 0.3422042360263211, 0.11888891618166651, 0.2621484489313194, 1.0442867811237062, 1.0735153555870056, 3.4983899806227003, 5.589998168604715, 8.787780199732099, 12.365420682089669, 12.20497635432652, 13.163195473807198, 13.937974333763123, 14.163264461926051, 11.026925785200936, 11.649238586425781, 9.432701570647103, 12.885892868041992, 14.554453253746033, 29.752693584987096, 22.041558470044816, 13.404258012771606, 11.297052638871328, 11.91177887575967, 12.815913217408315, 9.321245517049517, 10.393814614840917, 7.173218607902527, 8.806736622537885, 12.485699210848127, 17.754257644925797, 11.706002763339452, 19.045686313084193, 27.461460828781128, 49.61988278797695, 59.676361492701936, 60.097366741725374, 59.327179772513254, 64.96056379590715, 67.92389406476701, 53.71106202261788, 35.63292278562273, 17.218094689505442, 14.773871285574776, 10.52394916330065, 10.042971406664167, 8.168822509901863, 10.303918821471077, 9.266524110521589, 8.899092078208923, 9.171314682279315, 10.665358032499041, 13.630803159305028, 20.13205279622759, 13.455160515648977, 15.359925780977521, 19.16195399420602, 10.189357791628156, 20.57638488497053, 14.608700445720128, 12.77090539251055, 18.50326303073338, 15.537598167146955, 14.129994750022888, 10.26286712714604, 6.385684592383249, 4.510473924023764, 2.264489791222981, 0.472068863255637, 0.24014572958861077, 0.26465696575386183, 0.22307544414486202, 0.408787656043257, 1.4127827563456126, 6.699033149651118, 26.77665158680507, 46.93367794581822, 39.58770540782383, 38.34385279246739, 29.8626001902989, 34.36295883996146, 55.92058917454311, 57.734065532684326, 40.32547208241054, 47.12039688655308, 53.2850992338998, 59.14364310673305, 67.80803980146135, 71.04469830649239, 70.48675101143974, 73.52912398747036, 36.029029164995464, 3.8512314472879683, 0.20664560076381477, 0.18012854722993715, 0.35144832570637974, 0.2759053393134049, 0.18555314971932343, 0.13300329952367715, 0.24938724083559854, 0.3357881174555847, 0.30066557068909916, 0.34091781505516594, 0.28977521934679573, 0.1711945751948016, 0.24704265807356152, 0.15477360705179827, 0.20107547965432915, 0.389599934220314, 0.5296682896358627, 0.5436874745147569, 0.153111318392413, 0.15604039121951374, 0.2392060128705842, 0.2528628600495202, 0.2208284211478063, 0.2284840467785086, 0.40065842654023853, 0.18538669150854858, 0.11006881589336054, 0.16723533693168843, 0.2722817180412156, 0.22492012301726, 0.41652138105460573, 0.34122923548732487, 0.4536201203508036], [0.29973508204732624, 0.017371656772281443, 0.06301938090473413, 0.07132286498589174, 0.007669076739278222, 0.04676328659323709, 0.04497891930597169, 0.1406221349856683, 0.056862825727356334, 0.1406106948852539, 0.10974631498434714, 0.11705446961734976, 0.024883570382371545, 0.021379498498780385, 0.047579689749649594, 0.22297745011746883, 0.10944724388952766, 0.050308452253895145, 0.024713833151119094, 0.037559851338820796, 0.06743065919727087, 0.06089929145361696, 0.18798561633697577, 0.12482613830694131, 0.15066081631396497, 0.03597094624170235, 0.03521503108952727, 0.0921373473746436, 0.1161997869078602, 0.04200866958126426, 1.0132365844079425, 16.952327830450876, 57.92181280681065, 65.59918662479946, 52.1592617716108, 45.31674528121948, 36.5853853225708, 30.63776206970215, 23.48384816305978, 22.579185758318218, 25.04127992902483, 26.911161763327463, 39.717303207942415, 26.138758318764822, 45.188179288591655, 29.402667658669607, 17.422884157725743, 4.3384009173938205, 0.31049575177686556, 0.059047867943133624, 0.03177223939980779, 0.03554632920505745, 0.11214148253202438, 0.5268691969769341, 1.078890547156334, 4.079250480447497, 3.272747014250074, 2.4337848212037767, 1.5442340970039368, 4.220899062497275, 4.667491921356746, 3.618053593805858, 6.0611542122704645, 5.446771911212376, 3.914189943245479, 6.484632151467459, 7.126033825533731, 6.798509206090655, 5.816527247428894, 3.4662580362388065, 4.907387597220285, 1.182078787258693, 2.212258662496294, 5.2280100498880655, 6.434030592441559, 5.44494366645813, 5.322558965001788, 6.492481444563184, 15.721357175282069, 22.36033661024911, 24.432798385620117, 19.5848092011043, 38.78373977116176, 55.75802912030901, 51.70631217956543, 39.26068844114031, 41.38196652276175, 43.812908445085796, 51.78398609161377, 42.05032764162336, 46.2810822895595, 39.18908725466047, 23.95988835607256, 28.850398778915405, 26.326922484806605, 26.041388000760758, 21.867283752986364, 24.841029371534074, 10.600131818226405, 9.219760128429957, 5.947056106158665, 9.798081278800964, 9.191847477640424, 12.054926531655447, 5.570769029004233, 4.508477619716099, 6.166135847568512, 2.1797371847288947, 7.882840735571725, 8.605125086648123, 4.276264914444514, 5.528670762266431, 5.162311792373657, 5.13114868743079, 5.249767030988421, 6.834485241344996, 1.9713472468512399, 2.085536982331957, 1.2223079885755266, 0.05591511586681008, 0.1567760317453316, 0.03831934237054416, 0.09676843708647148, 0.085099975711533, 0.7976334935852459, 3.654758104256221, 17.474276508603776, 25.523675986698695, 26.436929838997976, 36.960622787475586, 28.87213100705828, 16.53565652029855, 16.618176800864084, 21.643195663179668, 15.199742010661534, 24.22074110167367, 37.488414900643484, 34.19464567729405, 40.25699758529663, 54.56819180079869, 55.440826484135215, 51.35258286339896, 20.928123542240687, 0.7162387669086456, 0.19349447930497782, 0.03953124323327627, 0.04138966243980186, 0.13495847103851183, 0.04155854641326836, 0.09014024239565645, 0.08167608800743308, 0.14479747308152063, 0.0661571371768202, 0.06152422899114234, 0.07238360520984445, 0.04209364591432469, 0.07628166675567627, 0.08984491002878972, 0.17802788423640387, 0.17082820699683257, 0.21242460209344113, 0.051709857769310474, 0.06295397012893643, 0.10300015019518988, 0.041834330186247826, 0.1356094575354031, 0.1662289745041302, 0.052360264118760824, 0.0788609344246132, 0.030978231291685785, 0.07350451791925089, 0.029436450451612473, 0.0827491165005735, 0.0795821560812848, 0.2803228465574128, 0.30469699150749613, 0.2398794453058924, 0.10650865121611527, 0.02993974701634475, 0.10161309569541897, 0.11391889144267354, 0.07563334690140826, 0.029409142809786966, 0.07029972917267255, 0.0693041690226112, 0.18110144431037561, 0.12015291835580554, 0.09351189647402082, 0.030386392692370073, 0.05240114585363439, 0.06361934835357325, 0.08053278364241123, 0.0602284578074302, 0.037072832829185894, 0.05144901194476655, 0.028086445660197308, 0.061078675756497045, 0.04165042684014354, 0.05115518592564123, 0.11511415801942348, 0.0657036043703556, 0.01824477018921503, 0.07483968484614577, 0.030766725141022886, 0.06663898524961301, 0.05663445119612983, 1.754024965422494, 23.41674940926688, 67.09602315085274, 74.575758934021, 61.24951008387974, 57.199186256953645, 47.21908562523978, 40.41349186216082, 30.795809268951416, 27.402882303510392, 27.73695863996233, 25.854547466550553, 30.552441665104457, 26.423052549362183, 47.947253363473074, 38.43381459372384, 20.628412996019634, 3.867411196231842, 0.3502243842397417, 0.03414523920842579, 0.04089767026848026, 0.200888706105096, 0.15842815595013754, 2.01620677113533, 4.779951989650726, 6.2012985093253, 6.862636736461094, 6.646793118544987, 7.0892075044768195, 7.783110635621207, 7.440449799810137, 8.044523579733712, 10.278378111975533, 7.406716295651027, 7.264437164579119, 8.486165847097125, 5.720407170908792, 7.5574279342378885, 7.213439992495945, 5.4148953131267, 5.330068230628967, 0.6812592010412897, 0.7844660601445607, 2.6220840428556715, 5.246349385806492, 5.088906679834638, 6.9326671957969666, 8.298407282148089, 18.360837118966238, 24.873046670641216, 29.19789034979684, 24.104789563587733, 47.171045780181885, 60.44563824789864, 56.34373099463326, 49.48166227340698, 48.72636181967599, 50.70075845718384, 58.58309023720877, 51.83406523295811, 53.93030548095703, 45.06126349312918, 28.49369215965271, 32.380321638924734, 28.44410112925938, 26.360008069447108, 24.492240224565776, 26.51732223374503, 13.145963072776794, 9.260191696030752, 6.592348337173462, 8.710288677896772, 8.179759843008858, 8.633086374827794, 6.420873309884753, 4.734741364206586, 7.596664411681039, 3.650241340909685, 5.683954315526145, 7.223547450133732, 5.760688483715057, 6.026232131889888, 6.100018961088998, 8.013055188315255, 7.8516285589763095, 8.481037208012172, 5.421161719730922, 5.7774201801845, 3.4971254084791457, 1.321181288787297, 1.2164095107998167, 0.3063875479357583, 0.057456961167710166, 0.08208109877471413, 0.3321032380419118, 2.6721562360014235, 13.707107407706124, 27.163211141313823, 26.91142405782427, 28.49779507092067, 21.135152067456925, 20.514653614589147, 26.27898165157863, 26.08123070853097, 20.842210803713115, 28.989541666848318, 45.56087023871285, 46.90420021329607, 48.182884148189, 61.23689215523856, 61.46580055781773, 60.22198268345424, 28.592945439474924, 2.040075136082513, 0.24938417385731423, 0.04304000888285892, 0.05242002269785319, 0.05325724670131292, 0.02522487858576434, 0.13807648872690542, 0.09113969055137464, 0.08856500299381358, 0.09332755208015442, 0.01691905016611729, 0.017896462897104875, 0.020763069790388857, 0.03547793626785278, 0.06407932045736484, 0.12730330681162222, 0.014078739897481032, 0.17950395574527128, 0.06721608606832367, 0.03261973303077476, 0.10459867691887276, 0.08578043776963439, 0.16152843673314365, 0.13897516764700413, 0.04751352919265628, 0.053770107217133045, 0.02903135147477899, 0.007118532084859908, 0.04839198776919927, 0.13679252405251774, 0.05600022451419916, 0.13174434565007687, 0.12942292807357653, 0.5632200006927762, 0.24443252384662628, 0.1592395074133362, 0.2512439840606281, 0.16689776575991086, 0.20506778971425124, 0.16674096988780157, 0.23795161875230925, 0.2350779686655317, 0.44632961441363606, 0.3494415176766259, 0.3014736787549087, 0.1306573325502021, 0.15351702805076325, 0.11762195559484617, 0.3573911796723093, 0.20042281039059162, 0.1774468682706356, 0.17968559956976346, 0.15910199550645693, 0.09734879487327167, 0.24670463906867163, 0.2795931499983583, 0.33198335447481697, 0.24606575763651303, 0.1401719812835966, 0.1993991724614586, 0.17491393775812217, 0.2675601728260517, 0.15576463458793505, 2.4911849754197255, 30.925719738006592, 78.46978650774274, 83.23522240774972, 66.27192510877336, 62.555257252284456, 51.976906299591064, 43.588898522513254, 34.96116399765015, 32.438839367457796, 33.00484657287598, 38.050260135105674, 55.79522630146572, 37.948184149605886, 54.70359134674072, 39.55301652635847, 22.98175917352949, 5.980462176459176, 0.5812058470078877, 0.10907204116561584, 0.20977679560227053, 0.17234796259020055, 0.1619328978870596, 1.2832812539168765, 4.733643114566803, 10.92437037399837, 11.09188709940229, 8.834062150546483, 10.20920010975429, 14.061885901859828, 14.9268410887037, 13.14806490285056, 15.664930854524885, 14.433968884604317, 11.170831663267952, 15.015706811632429, 18.41512165750776, 18.325753927230835, 14.755138942173549, 12.113075137138367, 13.425241572516304, 5.550909340381622, 9.03920945099422, 10.103017738887242, 12.489370465278625, 11.15928202016013, 8.160908511706761, 8.988094159534999, 21.014352423804148, 24.933879886354717, 31.964715140206472, 26.63961226599557, 53.434798172542024, 62.74174690246582, 60.24323722294399, 50.71667330605643, 53.60763461249215, 54.835350036621094, 61.782631465366904, 56.036064761025564, 57.1559510912214, 50.18484428950718, 32.50417675290789, 34.86309364863804, 31.889393193381174, 30.275104318346294, 27.81992186818804, 30.610247203281947, 15.568451642990112, 16.14192295074463, 13.167388711656843, 16.254687002726964, 18.442511456353323, 21.632768154144287, 13.594571777752467, 12.498955505234854, 14.229460818426949, 8.784372976848058, 17.084463460104807, 18.53934850011553, 11.4408985887255, 14.98968928200858, 14.452971339225769, 16.95996216365269, 15.261287416730609, 15.890643085752215, 7.306694371359689, 6.2728137118475775, 4.573518838201251, 0.7542321139148304, 0.8079566710761615, 0.20033407158085278, 0.22122324710445745, 0.27953056192823816, 1.1323502042463847, 4.835558422974177, 22.435563019343785, 34.81566177095686, 36.063579082489014, 52.23364571162632, 41.11811910356794, 23.16426750591823, 27.829479115349905, 34.26207447052002, 27.592345782688685, 36.89478513172695, 51.737349782671245, 49.664101123809814, 57.710490294865195, 69.28359399523053, 69.86126722608293, 68.71919877188546, 37.63060283660889, 2.692464951957975, 0.5024245115263122, 0.14076780288347177, 0.17598622664809227, 0.2053688692727259, 0.10736129153519869, 0.3404556241418634, 0.24783469843012945, 0.2566714771091938, 0.34975396948201315, 0.1410811503550836, 0.08504795921700341, 0.2105825695076159, 0.25878750213554924, 0.19856465581272328, 0.5768539948122842, 0.5242887011596135, 0.6045684590935707, 0.2648827279252665, 0.18306371330150537, 0.29866674223116463, 0.19200314075819083, 0.3199590625507491, 0.24125030317476817, 0.26604557409882545, 0.26305000483989716, 0.09815331348883254, 0.13941549616200583, 0.1949761826545, 0.2647599130868912, 0.29619041510990685, 0.4316474736801216, 0.37856361642479897], [0.10758889932185411, 0.00904950195191694, 0.09182148253811256, 0.130891834252647, 0.10697764105030469, 0.04784102411940694, 0.038006327381091456, 0.04227250095989023, 0.056669460210416994, 0.0514597836881876, 0.05190933010141764, 0.05008431178118501, 0.018960819712706974, 0.0113449460560722, 0.05925508575247867, 0.03595024413828339, 0.008155744107040976, 0.04341094022882836, 0.08704155616994415, 0.0345511761760073, 0.07982429130268948, 0.03467266447842121, 0.015071909907939178, 0.04639455030805298, 0.03367614420130849, 0.048191748692521026, 0.04595030325331858, 0.028748823063714162, 0.1776227309767689, 0.4931466579437256, 9.867006540298462, 40.0572646686009, 67.62742137908936, 54.427556787218364, 57.77210691996983, 40.9962546484811, 31.208855356488908, 25.638694729123795, 26.62238768168858, 24.05609311376299, 24.05074300084795, 55.92439331327166, 39.229341643197195, 39.83090625490461, 36.02657992499215, 10.948241778782435, 2.21419894695282, 0.07677992180521999, 0.05307449007939015, 0.08501678053289652, 0.02362992095627955, 0.23834546761853354, 0.7190207062023026, 3.634984616722379, 4.979687077658517, 6.098298413412912, 5.143136067049844, 2.377844874347959, 3.1373976256166185, 4.999088619436536, 4.670131802558899, 6.196785654340472, 5.1941119602748325, 3.950171623911176, 5.114975018160684, 5.451393331800189, 7.889609149524143, 4.392962081091745, 7.60577176298414, 1.714954484786306, 3.315867317574365, 6.404525935649872, 5.157434156962803, 15.202524764197213, 28.52565908432007, 35.6326448576791, 40.85618591308594, 42.143370968954905, 48.96359069006783, 50.01624277659825, 49.84656081880842, 28.79369626726423, 35.269215856279644, 49.59112071990967, 42.18055772781372, 23.639569452830724, 35.59080627986363, 45.90113047191075, 43.580786500658306, 39.11524527413504, 47.223799977983745, 61.89471285683768, 32.62677424294608, 35.37135090146746, 53.653107098170686, 41.20495074135916, 38.82847227369036, 34.17176873343331, 26.505623204367502, 17.33527258464268, 22.96884594644819, 24.345134701047623, 21.116803612027848, 22.769821746008738, 17.552311726978846, 13.016962817737035, 14.475447024617877, 8.858942781175886, 6.40364134311676, 3.473223171063832, 3.6767183201653615, 3.945356522287641, 4.379131691796439, 4.371496490069798, 7.179151500974383, 5.520339872155871, 3.542739029441561, 3.5923276713916232, 2.9076052818979536, 1.5856918266841342, 1.2923653721809387, 0.3648102544248104, 0.0795103602909616, 0.016134339684088315, 0.12391106598079205, 0.139263300757323, 1.7970218296561922, 13.34208813735417, 34.54086399078369, 44.63197251728603, 46.14644704546247, 32.624887807028635, 13.658160822732107, 13.85834971496037, 23.088742324284144, 36.975738593510215, 21.709186179297312, 19.098346710205078, 36.582738058907644, 42.86979470934187, 52.59392717906407, 56.51443086351667, 50.29705422265189, 23.761915070669993, 1.0248209685087204, 0.19747859266187462, 0.2108232051666294, 0.0678570166762386, 0.022431024217179844, 0.05425076446096812, 0.04754727952448385, 0.11403410668884005, 0.028835125932736055, 0.09566304925829172, 0.05610343647588577, 0.05162897300241249, 0.009346209200365203, 0.027996098722464273, 0.009079119157312172, 0.19115651904472283, 0.111628394706973, 0.01591134423922215, 0.09793506270008427, 0.09668560153139488, 0.054427210707217455, 0.014781072835570999, 0.007875532893064831, 0.05264953377523592, 0.1751539355942181, 0.0332667331344315, 0.0051594564491616824, 0.04983486195227929, 0.06594774127006531, 0.13573362944381578, 0.08283418443586145, 0.11743345856666565, 0.1328825881438596, 0.0807375722963895, 0.05303345228146229, 0.07310443331620523, 0.08182206803134509, 0.01212851405476353, 0.024537682067602873, 0.03246255039370485, 0.06948573142290115, 0.047033167111554315, 0.017306983903316513, 0.011911338744019824, 0.03136592245261584, 0.031816266144492795, 0.018127152929082513, 0.021183810695739727, 0.018482618765639405, 0.07260695858193295, 0.07249505458665745, 0.02034072923873152, 0.038661222239690166, 0.05351024866104126, 0.08952202914016587, 0.041141990372645, 0.07507206273398229, 0.013275487597898712, 0.05400560297338026, 0.05533438488574965, 0.05271474777587822, 0.8603857148970876, 12.627561450004578, 47.816561222076416, 76.02146366664341, 62.56135777064732, 66.7374335697719, 49.6510454586574, 39.075056893484934, 35.89721488952637, 35.55631194795881, 27.98169677598136, 30.656001091003418, 52.36458798817226, 33.150897707257954, 41.01405940737043, 41.999734333583284, 14.096086672374181, 2.9661870641367774, 0.0940115764471037, 0.01677832709226225, 0.07335280427443129, 0.47785551846027374, 1.5089652580874306, 2.9429062562329427, 4.168914377689362, 10.252327578408376, 9.68261524609157, 8.051616821970258, 8.737069640840803, 9.338974714279175, 6.4028909376689365, 10.44685889993395, 8.32978274141039, 9.712126851081848, 10.027932030814034, 6.885506297860827, 7.058715334960392, 7.064393750258854, 6.217672373567309, 5.73645099571773, 2.5126694568565915, 3.6589031389781406, 5.790816307067871, 7.2324480925287515, 14.722815922328405, 29.253965786525182, 37.87817062650408, 44.23803397587368, 45.447896003723145, 51.101964814322336, 50.964922019413535, 54.61148950031826, 32.98245252881731, 38.87572002410889, 56.172419684273855, 46.62100900922503, 30.269104548863, 41.8599157333374, 51.58232504980904, 53.13874237877982, 45.251626764025005, 52.01802921295166, 65.82476684025356, 35.15342065266201, 38.639342308044434, 56.75593982424055, 44.52864238194057, 42.39334283556257, 38.43249443599156, 28.68882884298052, 20.60954863684518, 21.86869250025068, 20.092750310897827, 16.87754089491708, 15.27132408959525, 13.160621166229248, 13.78535975728716, 13.002022453716823, 7.621423448835101, 5.38101589679718, 4.37986125264849, 3.34810956461089, 4.095650400434222, 7.683562057358878, 10.52814587524959, 8.432904430798121, 7.425035221236093, 8.559332115309578, 11.451559730938502, 7.295497349330357, 4.668494633265904, 2.4697971173695157, 2.3356128547872816, 0.29879275975482805, 0.16674850162650856, 0.21087870933115482, 0.031715564762375185, 1.7387853946004594, 10.712239265441895, 27.902278866086686, 39.967914308820454, 42.564626353127615, 27.301400388990128, 22.393220697130474, 27.881404740469797, 32.88847814287458, 45.01996340070452, 30.410208565848215, 27.426520075116837, 44.48491736820766, 51.24305146081107, 60.004413740975515, 63.31231907435826, 61.54403032575335, 31.781449454171316, 1.7120698967150279, 0.1510783324816397, 0.13277136268360273, 0.03146088342847569, 0.07826046485986028, 0.027838307100215127, 0.05005775731323021, 0.10467909010393278, 0.03918172984517046, 0.05066374336768474, 0.009353921599020916, 0.03820903293256249, 0.05338955085192408, 0.01906268478238157, 0.07335403242281505, 0.0998800222628883, 0.06322691762553793, 0.11267114018223115, 0.08347071813685553, 0.026208535535261035, 0.054997376898037534, 0.06036143031503473, 0.024338905233889818, 0.019124891176553707, 0.06363747202392135, 0.028619423042982817, 0.05813315524054425, 0.08658912937555995, 0.009068830870091915, 0.03939599424068417, 0.07229456105934721, 0.05317478773317166, 0.3235708773136139, 0.29609132185578346, 0.16032698191702366, 0.24350515646593912, 0.503764808177948, 0.14094870031944343, 0.07373025294925485, 0.1438285657869918, 0.2347626398716654, 0.14317361664559158, 0.1893800465123994, 0.1804306853030409, 0.13924004057688372, 0.15551582936729702, 0.14474837428757123, 0.29152589397771017, 0.2226015959999391, 0.2009088857365506, 0.16725673792617662, 0.17497685152505124, 0.11522688982742173, 0.2551593482494354, 0.17043773723500116, 0.20035596112055437, 0.131735036149621, 0.1815307398459741, 0.23122011710490498, 0.13363169080444745, 0.22902779760105269, 1.1929380616971423, 17.789676087243215, 59.32656833103725, 85.54689502716064, 70.83603695460728, 75.45159326280866, 56.795277050563264, 43.997626304626465, 38.95475925718035, 37.89330380303519, 33.27725069863455, 34.550581046513145, 70.22579056876046, 54.50598110471453, 51.77248682294573, 45.80544682911464, 16.452767985207693, 3.8740536740847995, 0.1824204349624259, 0.2290601230093411, 0.2090225089341402, 0.3463378170771258, 0.9369896586452211, 3.907791086605617, 8.552820784705025, 13.009211233683995, 13.760327134813581, 14.034835696220398, 11.540971755981445, 13.259845784732274, 10.249478816986084, 17.53944366318839, 16.200353826795304, 17.108122076307023, 12.477971945490156, 11.173959221158709, 13.715317572866168, 17.954447405678884, 13.038548265184675, 16.569492510386876, 7.089853252683367, 8.55457259927477, 12.171568546976362, 8.333643334252493, 20.62738813672747, 35.52367278507778, 43.1855833871024, 46.943554810115266, 47.01497881753104, 51.66024562290737, 52.014954635075156, 56.72606257029942, 35.660906655447825, 46.37552220480782, 61.8325959614345, 50.678347042628694, 32.7460435458592, 45.26559959139143, 54.411892073495046, 57.500091893332346, 50.93456186567034, 57.695030553000315, 70.0794962474278, 40.12008680616106, 41.31100804465157, 56.65532643454415, 50.67386892863682, 49.36108323505947, 42.470110007694785, 33.88228246143886, 21.45724970953805, 29.893328598567418, 29.865136282784597, 27.37999667440142, 28.272489309310913, 24.54818364552089, 19.128545318331035, 22.31818015234811, 19.18474929673331, 13.78938797542027, 9.024899635996137, 9.578006642205374, 8.754012823104858, 12.243765541485377, 12.10938651221139, 16.394816534859793, 13.378750307219368, 11.010677422795977, 12.390746865953718, 11.053538254329137, 6.540751448699406, 2.5283304793494086, 1.2647508425371987, 0.25251539583717075, 0.11469993953193937, 0.2971059488398688, 0.4715880804828235, 2.838986392532076, 16.8458206312997, 42.437818254743306, 59.912238938467844, 63.82503359658377, 46.860127789633616, 23.797394309725078, 25.257827486310685, 33.994391645704, 48.21496398108346, 34.74467897415161, 31.21417072841099, 49.13689613342285, 60.07691819327218, 69.05952848706926, 72.25538716997418, 71.14873368399483, 40.39536401203701, 2.0015901497432163, 0.3273832398865904, 0.30098586635930197, 0.19281507576150553, 0.13141460477241448, 0.1265900715121201, 0.1759455959711756, 0.2070146288190569, 0.13112500602645533, 0.22577606780188425, 0.165835492046816, 0.12633241819483892, 0.21138649779771054, 0.08868681360036135, 0.20458186364599637, 0.5042124784418515, 0.3438142639185701, 0.14141129835375718, 0.16743869387677737, 0.23029777088335582, 0.18026661553553172, 0.15485777253551142, 0.2605407823409353, 0.3449031769164971, 0.3026336750813893, 0.1924206433551652, 0.10417581389525107, 0.1929796612156289, 0.16301556836281503, 0.1762574099536453, 0.28718701537166325, 0.293440936931542], [0.03805345842348678, 0.012607517369490649, 0.02370337237204824, 0.06935297604650259, 0.08511408923992089, 0.03605459603880133, 0.05764292047492095, 0.014891480661130376, 0.025410671651895558, 0.04437187473688807, 0.07791682079966579, 0.020653316751122475, 0.014214900671504438, 0.05270640518782394, 0.02360489488845425, 0.06363372651061841, 0.01655053610115179, 0.022610344059233154, 0.019343267494280423, 0.022845520904021602, 0.09734158204602343, 0.04598630971408316, 0.01396723963054163, 0.0861928988514202, 0.034991240062351735, 0.03349180320011718, 0.07445184101483651, 0.06084072709615741, 0.03770667953150613, 4.102347595351083, 32.01059409550258, 59.42549678257534, 64.90306050436837, 53.530207361493794, 40.557819843292236, 30.746713297707693, 23.419966425214493, 17.778166396277292, 21.246866941452026, 27.178922755377634, 24.411679336002894, 25.687472820281982, 43.75331374577114, 29.46445451463972, 9.058365634509496, 2.6520781133856093, 0.17318659116114887, 0.011202805692196956, 0.0061177289795263535, 0.09329104011080094, 0.2359993920794555, 1.5660860730069024, 2.375581932919366, 4.360980825764792, 7.065484617437635, 4.895441038267953, 4.491839723927634, 6.818039723805018, 6.151675777775901, 5.749462800366538, 5.577150080885206, 4.576579519680568, 9.029266578810555, 8.008702141898018, 7.646028757095337, 8.010552968297686, 2.9854761319501057, 6.258713211332049, 7.225348336356027, 9.080887351717267, 13.64910992554256, 14.736179045268468, 31.57774911608015, 45.45324264253889, 54.51590313230242, 57.3766884122576, 58.5634685243879, 54.81375503540039, 57.83859770638602, 56.368372780936106, 62.971878187997, 44.42519760131836, 39.98797723225185, 54.519988673073904, 46.562491280691965, 28.91952814374651, 31.268342358725413, 42.95093577248709, 40.49109281812395, 36.83245284216744, 54.02667004721505, 52.54353189468384, 33.0245794568743, 52.602466515132356, 54.93094335283552, 46.59787845611572, 48.812446526118684, 46.84677335194179, 43.8016801561628, 38.40958275113787, 33.57003389086042, 34.2558627809797, 29.855231625693186, 21.87623998097011, 27.024413926260813, 25.02018346105303, 24.545491218566895, 17.803817408425466, 16.176365171160015, 12.118726628167288, 4.565703417573657, 4.480102913720267, 4.073302822453635, 7.0187141214098245, 4.441002794674464, 6.041007910455976, 4.352004621710096, 8.163871049880981, 4.423455553395407, 2.7344440136637007, 4.055856764316559, 3.186887038605554, 0.48096608583416256, 0.0923726429630603, 0.13331527635455132, 0.046430499093340974, 0.07660294630165611, 0.5188523328730038, 6.8062838060515265, 23.43150564602443, 39.01986040387835, 51.69313492093767, 32.34889146259853, 15.701184817722865, 10.084187252180916, 15.45378725869315, 27.963869435446604, 32.86277675628662, 23.076374530792236, 37.08532905578613, 37.26315777642386, 53.05706977844238, 50.60846553530012, 39.588125773838584, 18.796416214534215, 0.17160158764038766, 0.057943579341684065, 0.08744174255324261, 0.07713412387030465, 0.03533676366454788, 0.0559265525745494, 0.019907781488395164, 0.01711642412867929, 0.03483570965805224, 0.042943181935697794, 0.07795168392892395, 0.10627883819064923, 0.0844555167215211, 0.047697564853089194, 0.07476160582154989, 0.044367674605122635, 0.038669734461499114, 0.04172335239127278, 0.029184289875307252, 0.01688166458292731, 0.035050174221396446, 0.021874028391071727, 0.10362020906593118, 0.1425869281270674, 0.05397253456924643, 0.09539853595197201, 0.06232570776981967, 0.06435614917427301, 0.03573192888870835, 0.1017663971121822, 0.08127175577517066, 0.04216679538201008, 0.024970304121130278, 0.012704653898254037, 0.044618182948657444, 0.033306441003722806, 0.020666902718533362, 0.058588716866714616, 0.01262162411252835, 0.06556618067302875, 0.053612364788672755, 0.10497862938791513, 0.061048799859625955, 0.07317669051034109, 0.0200127627301429, 0.022855144226923585, 0.05929508539182799, 0.02654974874375122, 0.03359770555315273, 0.0017850354322165782, 0.021552789557193006, 0.12375868058630399, 0.09787372313439846, 0.04128414345905185, 0.027369573412995254, 0.02884568054495113, 0.021815860976598093, 0.08102028391190938, 0.05238764639943838, 0.05840110193405833, 5.527973336832864, 36.86458478655134, 69.5548655646188, 73.367995262146, 61.84354632241385, 49.61962570462908, 42.26443985530308, 31.397762979779923, 25.972948244639806, 27.006735971995763, 29.715284483773367, 31.466220106397355, 37.73408930642264, 42.875082288469585, 32.92782231739589, 10.57620222227914, 2.149475391421999, 0.2826118708721229, 0.03291004423850349, 0.16507713416857378, 0.17623318625347956, 1.8941514577184404, 4.259950544152941, 5.610646477767399, 7.513722896575928, 9.251805220331464, 7.674028260367257, 7.555384295327323, 10.623196363449097, 9.067995837756566, 7.209823455129351, 9.992827125958033, 8.670520663261414, 9.915752496038165, 7.243123999663761, 7.311732683862958, 4.249525206429618, 3.9941463385309492, 5.487298582281385, 8.309567826134817, 8.063158648354666, 13.684741156441824, 17.46688536235264, 33.321955408368794, 47.14083848680769, 57.38427584511893, 61.543154852730886, 62.9708012172154, 54.90212917327881, 58.989782197134836, 54.40980413981846, 65.26045499529157, 46.801231384277344, 44.114505427224294, 57.66461133956909, 47.995883805411204, 34.980834347861155, 38.356283119746614, 48.159378392355784, 47.90007162094116, 43.760539872305735, 60.11114501953125, 55.32948160171509, 37.37897729873657, 56.05742004939488, 57.87163291658674, 49.30862780979702, 53.280798298971995, 51.84345572335379, 48.962524141584126, 41.050471442086355, 37.24400854110718, 36.743925843920024, 31.438858100346156, 24.41226645878383, 28.721626077379497, 26.131431443350657, 24.178980691092356, 19.590056828090123, 18.478225197110856, 10.742243324007307, 4.3476077147892545, 2.9136269816330502, 4.72792648417609, 9.094376410756793, 6.797535589763096, 11.701678378241402, 8.604261772973196, 11.21567794254848, 10.990272300583975, 7.401793496949332, 5.859086266585758, 5.0107685412679395, 2.7861946310315813, 0.7024356818624905, 0.28167247985090527, 0.006194421672262251, 0.03740858552711351, 0.41505471404109684, 6.438715415341513, 23.495734793799265, 39.42443316323416, 45.79375648498535, 28.13924023083278, 12.825960312570844, 11.194049068859645, 25.99238235609872, 36.36020115443638, 36.250860827309744, 34.0069122995649, 47.92204529898507, 44.88855906895229, 59.95727021353585, 59.85898099626814, 49.94191094807216, 24.337146009717667, 0.4055343520428453, 0.08757409080862999, 0.026834998080240827, 0.06378298385867051, 0.12024541624954768, 0.05344413899417434, 0.01521947091844465, 0.0411431981649782, 0.03003136281456266, 0.049487506305532794, 0.02757547825707921, 0.04556717524038894, 0.02168535833646144, 0.04694769544793027, 0.04861654554094587, 0.06305594037153892, 0.050330677668430975, 0.026810372348076532, 0.03354592654587967, 0.020169824927246997, 0.09837564227304288, 0.006367715699265578, 0.05753894855401345, 0.0350693733697491, 0.02228070156914847, 0.06540055027497665, 0.04696522879281214, 0.03974501908357654, 0.020588474248402884, 0.028454199765941927, 0.06622423750481435, 0.17904073345874036, 0.18324596780751432, 0.13416045957377978, 0.22669507563114166, 0.1479451698916299, 0.11084101588598319, 0.26309348536389215, 0.13135659002832004, 0.1168695552540677, 0.2436818198433944, 0.2627400229019778, 0.14165392890572548, 0.1094364755387817, 0.12914791783051832, 0.10969768437956061, 0.12448651795940739, 0.12350295430847577, 0.1286066233047417, 0.10816440558327095, 0.16995371106479848, 0.24064306861587934, 0.2103909376476492, 0.1663088516465255, 0.15470454575760023, 0.08780472486146859, 0.14304390789142676, 0.16893183732671396, 0.1104144887732608, 0.20509243410612854, 8.327281389917646, 47.60783386230469, 79.2360269001552, 80.72230911254883, 71.60293742588588, 54.03158589771816, 43.4974741254534, 34.941747256687705, 25.851049048560007, 33.03379624230521, 39.82631696973528, 36.05084303447178, 38.44198567526681, 58.43236296517508, 37.12090730667114, 12.165549669946943, 3.0655916844095503, 0.47757563633578165, 0.04660241611834083, 0.23395168195877755, 0.17629595074270452, 1.763590355004583, 4.374442092009953, 6.965417529855456, 11.833182590348379, 17.510139635631017, 14.40945998259953, 14.940909453800746, 16.927027702331543, 14.822995049612862, 16.019387994493755, 14.647844859531947, 14.976723943437849, 17.95112442970276, 16.61079260281154, 14.775415522711617, 18.267218828201294, 10.195136955806188, 14.745574746813093, 14.212265763963972, 14.460537927491323, 19.385741574423655, 23.031105279922485, 38.4994021143232, 52.90657179696219, 61.59826101575579, 66.21431759425572, 67.73173468453544, 61.27031993865967, 58.574801036289756, 54.03661639349801, 66.64115933009556, 48.3482860156468, 47.22242076056344, 62.33251190185547, 52.01436056409563, 39.690986905779155, 42.838277680533274, 51.949113505227224, 56.698241983141216, 47.889774390629356, 63.54475021362305, 59.62862736838204, 38.58685908998762, 56.265195505959646, 60.5611937386649, 55.60837534495762, 57.815741607121055, 52.836037158966064, 48.36087615149361, 44.06270660672869, 41.87043878010341, 42.004691873277935, 37.20600536891392, 29.66975293840681, 35.6020519392831, 31.744196687425884, 30.386268547603063, 25.27374059813363, 22.655509982790264, 17.66226175853184, 9.291801656995501, 9.769817743982587, 9.365533334868294, 15.192903246198382, 13.862818275179182, 17.144815513065883, 13.989716700145177, 17.828474828175136, 14.871538639068604, 12.545734252248492, 11.831009541239057, 7.412128073828561, 1.681809731892177, 0.45011849967496737, 0.3317308580236775, 0.12043119913765363, 0.19473452919295856, 0.7539203677858625, 9.210214172090803, 30.18413155419486, 49.67970330374581, 64.69184221540178, 45.25752231052944, 22.98189640045166, 16.94218519755772, 25.877473047801427, 40.40490736280169, 44.19317987986973, 37.412123680114746, 51.64542164121355, 52.113355023520334, 70.34160314287458, 68.06882653917584, 62.77083900996617, 32.09556361607143, 0.5048942161457879, 0.31865261122584343, 0.14712110268218176, 0.1347712767975671, 0.17888024635612965, 0.1579243436987911, 0.05235591470929129, 0.15899329419646943, 0.11105769247348819, 0.1250450201332569, 0.20715424418449402, 0.12947156546371325, 0.11522196366318635, 0.16602584826094763, 0.30444682921682087, 0.308006478207452, 0.2113844079098531, 0.1688677700502532, 0.0777205681162221, 0.09011083468794823, 0.18828818867249147, 0.12080079716231142, 0.24686520759548458, 0.24860415714127676, 0.1420632755117757, 0.14621073938906193, 0.17670503950544766, 0.17178564704954624, 0.17263290658593178, 0.22363054007291794, 0.17659248411655426], [0.03966069414413401, 0.08409509927566562, 0.013400305810916637, 0.03997426213962691, 0.0205700927347477, 0.028302447105358754, 0.061167964179600985, 0.12401660531759262, 0.05324015440419316, 0.07046819584710257, 0.08095030659543616, 0.046170728746801615, 0.06808088573494128, 0.04314418436427202, 0.04165565495246223, 0.04025311967624085, 0.02993473264255694, 0.04107796720096043, 0.06286852221403803, 0.01769130104886634, 0.08032553190631525, 0.02921417255752853, 0.016806484599198614, 0.06028307309108121, 0.02710778103210032, 0.1072006890816348, 0.0355872211179563, 0.13028639102620737, 1.5774849184921809, 23.360147646495275, 55.97374636786324, 63.57143129621233, 55.618950503213064, 51.191238743918284, 50.26818445750645, 30.183606965201243, 22.984748635973247, 23.767447573798044, 26.623513289860316, 45.39572198050362, 19.217044523784093, 28.220462935311453, 27.418091910226003, 8.189698372568403, 1.419254134808268, 0.08491679161254849, 0.29476239745106014, 0.1272977835365704, 0.11691778552319322, 0.8549699740750449, 1.24693392430033, 4.97519940989358, 4.113396533897944, 3.67099951846259, 7.63632299218859, 8.579555715833392, 7.10721332686288, 10.1894576719829, 8.328511221068245, 5.550208440848759, 9.846551043646675, 7.633745210511344, 8.854620133127485, 11.07836069379534, 6.887316303593772, 5.021610336644309, 6.726978370121547, 9.498396788324628, 17.236359766551427, 20.13553558077131, 29.720384461539133, 36.06034122194563, 42.93944345201765, 54.574302741459434, 58.017225469861714, 58.78886113848005, 61.35893726348877, 53.13803366252354, 63.22401441846575, 59.52352891649519, 58.05561774117606, 61.75792367117745, 54.11281033924648, 55.58342088971819, 58.97186279296875, 40.52029609680176, 29.895312309265137, 35.49260738917759, 41.2698712348938, 24.332730429513113, 49.12167957850865, 47.88879816872733, 44.05441393171038, 59.649333000183105, 52.19918612071446, 63.66525282178606, 55.726595469883506, 52.51869208472115, 51.87060233524868, 47.811398710523335, 53.36695943559919, 52.59212759562901, 47.26330048697335, 43.10100991385323, 41.24739728655134, 46.36161538532802, 40.03705930709839, 35.40661995751517, 32.53179931640625, 29.31991113935198, 21.652765069689067, 12.388017960957118, 10.82965166228158, 13.402280381747655, 5.089898535183497, 4.488030808312552, 10.139435853276934, 16.15784822191511, 7.768316183771406, 5.053578129836491, 2.1752097819532668, 5.528759351798466, 4.12636056968144, 1.3727513615574156, 0.1668003959847348, 0.08177812610353742, 0.012886635293917996, 0.05326390652252095, 0.48368245150361744, 4.144239587443216, 20.782037666865758, 31.505324568067277, 52.049014704568044, 62.70140566144671, 60.128633635384695, 33.50621121270316, 30.38614695412772, 27.73639930997576, 16.711802039827617, 21.930896248136246, 36.90742737906319, 44.302033833095, 50.86538907459804, 52.581879002707346, 40.48441907337734, 8.30032411643437, 0.05862410246793713, 0.04629104318363326, 0.09319914611322538, 0.04422224758725081, 0.018422198614903858, 0.05439323985150882, 0.00880521153365927, 0.07841464158679758, 0.02866217414183276, 0.04617973290649908, 0.03136165446734854, 0.07275641949049064, 0.0697440022070493, 0.028329334055472697, 0.04393903724849224, 0.01613380873043622, 0.08247625042817422, 0.04978247904883964, 0.044865447894803116, 0.030165583826601505, 0.042898710750575574, 0.02270348316856793, 0.08549904251205069, 0.019892792649833218, 0.04262993624433875, 0.010771689138242176, 0.027112561311306696, 0.005463066943255919, 0.05970633868128061, 0.09569497433091913, 0.04992611812693732, 0.04861462528684309, 0.01777693216821977, 0.015324146819433995, 0.0696697501199586, 0.09797946603170463, 0.018208787477176105, 0.0761670825470771, 0.03379896582503404, 0.03876113991386124, 0.039154690224677324, 0.07155947014689445, 0.02196665351012988, 0.08802598834569965, 0.10016384667583875, 0.0541851094125637, 0.030115409554647546, 0.03210876562765666, 0.0607675878064973, 0.09068474639207125, 0.060407278926244805, 0.03154224316988673, 0.01627217559143901, 0.04185486604858722, 0.03187802640189018, 0.06395057522292648, 0.08016918386731829, 0.06879204471728631, 1.8769303475107466, 27.06938440459115, 65.83790588378906, 71.94838101523263, 63.91399138314383, 58.60510213034493, 54.952642577035085, 34.60481521061489, 24.98831033706665, 24.275974069322857, 23.0106098311288, 42.49640893936157, 26.4336450781141, 29.697941780090332, 32.9115218435015, 9.880989789962769, 1.2966202752930778, 0.09314425941556692, 0.18910705830369676, 0.20887876807578973, 0.2648346876459462, 2.661362426621573, 5.229604661464691, 5.807744290147509, 6.925298196928842, 6.94653753723417, 7.831963419914246, 11.445007579667227, 11.605695962905884, 12.242337686674935, 13.899763584136963, 11.633792740958077, 8.18726737158639, 7.3782034942082, 9.056612082890101, 8.050233261925833, 7.2464682544980725, 3.4423186693872725, 5.9291801282337735, 8.76519855431148, 16.532486404691422, 22.317759786333355, 33.328420707157676, 43.029460838862825, 48.562756061553955, 58.257091181618826, 62.549865450177876, 62.73431927817208, 64.7737614767892, 56.786616121019634, 63.529526710510254, 59.24919319152832, 60.874786785670686, 65.04577650342668, 58.286221504211426, 58.109219619206016, 59.13149765559605, 45.11342709405081, 37.762667247227256, 42.05975634711129, 46.04636171885899, 32.04159000941685, 52.12515306472778, 51.50836494990757, 48.32795558656965, 59.59562342507498, 55.951182092939106, 65.23817907060895, 59.651278495788574, 54.892495495932444, 54.76391560690743, 47.90559891292027, 53.699979645865305, 51.83881780079433, 49.59925706045968, 47.09790556771414, 46.079792976379395, 49.26168578011649, 43.42871127809797, 39.59505312783377, 37.4956306048802, 30.659773962838308, 23.573269741875784, 14.936877761568342, 12.268056443759374, 8.060269934790474, 6.105439858777182, 7.38338337625776, 5.099952144282205, 4.872531958988734, 12.057499970708575, 8.502211843218122, 8.074346116610936, 9.262439438274928, 7.003538387162345, 3.181849377495902, 0.8445756318313735, 0.5618205357875142, 0.05826947292579072, 0.05248041570718799, 0.2746426670679024, 4.070683351584843, 20.849059990474156, 34.67049305779593, 42.87669079644339, 43.99433633259365, 42.733446734292166, 28.84661374773298, 33.45027821404593, 34.65079491479056, 21.763882398605347, 30.676675455910818, 44.992948804582866, 52.448876585279194, 60.404935700552805, 60.441226141793386, 51.93636703491211, 11.676152433667864, 0.056531347800046206, 0.11375613124775034, 0.07980625584189381, 0.03527034526424749, 0.019803690823859403, 0.058163132917668135, 0.020562861247786453, 0.04244368177439485, 0.08272255185459342, 0.032833078011338196, 0.08253382412450654, 0.007960460032336414, 0.017844368371048143, 0.03161925689450332, 0.024123378763241426, 0.09551810739295823, 0.056156219714986425, 0.09610187142555203, 0.0606102491063731, 0.06220859941095114, 0.021810342790558934, 0.04251204417752368, 0.05791385950786727, 0.06386594155005046, 0.010322683856689503, 0.017348710414288298, 0.007772382847698671, 0.038727969729474614, 0.03669581502409918, 0.04636133601889014, 0.16071506323558943, 0.14381195524973528, 0.08073962147214583, 0.12622105702757835, 0.19591956346162728, 0.16571152369890893, 0.12377784241523061, 0.25430803107363836, 0.1806503813713789, 0.18580913384045872, 0.13336788995989732, 0.16994449655924523, 0.09642784643386092, 0.10732486777539764, 0.1820064607475485, 0.10358958678053957, 0.14460618048906326, 0.10440579655447177, 0.2467101759144238, 0.23028335879955972, 0.1465162837079593, 0.16798958288771765, 0.15994442387350968, 0.1659709954900401, 0.1461828923118966, 0.16036781615444592, 0.18131212943366595, 0.26611912729484694, 3.1764328224318366, 33.792622906821116, 73.6669692993164, 80.84497955867222, 71.346896307809, 67.28133160727364, 65.581698008946, 43.69993073599679, 33.07180636269705, 33.42917653492519, 40.01133707591465, 63.13013730730329, 29.881384645189556, 40.63657072612217, 36.39619977133614, 10.94126752444676, 2.168059434209551, 0.4278361696217741, 0.4206135986106736, 0.37745301744767595, 0.21740473700421198, 2.5787513852119446, 6.668946581227439, 12.904611315046038, 17.626198870795115, 12.648496372359139, 18.38802194595337, 19.161351237978252, 13.612764767238072, 20.085958446775162, 17.6364700453622, 13.806080154010228, 16.363693816321238, 15.15286077771868, 18.890102250235422, 20.367930241993495, 14.75780531338283, 10.189754707472664, 12.956267697470528, 15.189434358051844, 25.382955857685634, 30.00223813738142, 40.10153859002249, 45.73692716870989, 51.85799830300467, 59.75185367039272, 61.90601062774658, 62.793775013514924, 66.12244851248605, 57.10815095901489, 65.53469344547817, 62.09165954589844, 63.027192796979634, 62.95163113730294, 58.504200390407014, 60.58589458465576, 60.63720703125, 48.87005751473563, 42.61118623188564, 46.387813568115234, 52.78436688014439, 37.01055601664952, 56.800415243421284, 56.44989252090454, 47.89794199807303, 62.18763501303536, 58.60747146606445, 66.3256277356829, 56.16496079308646, 53.99416984830584, 55.65321207046509, 49.64517423084804, 56.035158021109446, 54.006412574223106, 49.622116633823936, 47.57641758237566, 47.65103428704398, 53.149821281433105, 48.84539835793631, 44.72195168903896, 41.86442858832223, 37.82118844985962, 26.60870667866298, 17.709705795560563, 19.550693546022686, 22.338468892233713, 14.629329647336688, 15.571831941604614, 21.88872241973877, 27.42649401937212, 19.464419501168386, 9.307534984179906, 9.640194756644112, 15.40907907485962, 8.915614894458226, 2.174719499690192, 0.6876007893255779, 0.33374124871832983, 0.24093098459499224, 0.18277889144207748, 0.7518507816961834, 5.8072570477213175, 28.669316564287456, 44.17012575694493, 66.36501012529645, 82.14573097229004, 75.49618680136544, 46.549602372305735, 41.318241119384766, 41.45151104245867, 26.02125906944275, 32.92952115195138, 51.076193945748464, 59.28875623430525, 68.11781133924211, 70.46889414106096, 62.414924485342844, 17.575171300343104, 0.1949164987142597, 0.30341314896941185, 0.20893089313592228, 0.13873305278165, 0.19997212743120535, 0.15395616234413215, 0.07654457193400178, 0.16414157008486135, 0.23089743299143656, 0.1084703230964286, 0.10928914523018257, 0.19964367577007838, 0.20309710688889027, 0.08455783980233328, 0.1493174119719437, 0.18210393908832753, 0.23622632133109228, 0.18619340179221971, 0.1609245812786477, 0.11433159001171589, 0.2737591601908207, 0.0808354170460786, 0.14447982369789056, 0.16623296429003986, 0.139368527968015, 0.10577649157494307, 0.09561901912093163, 0.21012298416878494, 0.20186195602374418, 0.14279527908989362], [0.03729681384616664, 0.07944718868072544, 0.0325662000104785, 0.06039744695382459, 0.06667528008776051, 0.04952672562961068, 0.04345726381455149, 0.05051855044439435, 0.10893632059118577, 0.0326124862767756, 0.036029361321457794, 0.02378307648801378, 0.02497437872391726, 0.02837522337878389, 0.036899921750383716, 0.04806736304557749, 0.06168817662234817, 0.06699483615479299, 0.024061121478942887, 0.023986733684848462, 0.027117382302614193, 0.026321979805028865, 0.06151544874800103, 0.022177576120676737, 0.04779646811740739, 0.09798559320292302, 0.053298243787139654, 0.29483394218342646, 4.6972558328083585, 45.53043712888445, 69.9156299318586, 62.32673794882638, 62.9582736151559, 45.674452441079275, 38.901244231632774, 41.8835118157523, 22.909883533205303, 30.300430502210343, 39.30881513868059, 33.832495144435335, 31.48362534386771, 33.60767228262765, 7.753308943339756, 1.3078768998384476, 0.0449722900188395, 0.09584425203502178, 0.10283298630799566, 0.041368359832891395, 1.3099592966692788, 1.9335371043000902, 4.263919268335615, 4.158248024327414, 6.382826277187892, 7.722203595297677, 7.613306215831211, 7.660669480051313, 5.680528853620801, 10.072053091866628, 7.2829984085900445, 7.452818461826869, 8.554832288197108, 5.223519776548658, 7.562045880726405, 4.41810804605484, 9.552657876695905, 6.7899029936109265, 14.607397658484322, 20.21882537433079, 31.856938157762798, 35.161383288247244, 49.69555214473179, 54.59719705581665, 61.59114606039864, 57.17821659360613, 60.53020477294922, 59.715799467904226, 60.27179431915283, 63.38755416870117, 58.256448473249165, 50.83702652794974, 60.259593282427105, 60.51487009865897, 66.72370392935616, 63.03050708770752, 61.32172271183559, 49.24301597050258, 33.93565852301461, 34.56296968460083, 36.09397745132446, 34.998541831970215, 53.765150274549214, 53.71628359385899, 57.09805522646223, 59.81194864000593, 57.34130818503243, 60.434528078351704, 54.829596928187776, 48.61711181913103, 53.91390425818307, 55.30248090199062, 58.82960537501744, 60.200227873665945, 62.36451530456543, 55.11262137549264, 57.992427349090576, 59.23404611860003, 59.50849996294294, 54.02471760341099, 46.82161739894322, 40.92257942472185, 35.84826830455235, 31.899513244628906, 30.945716653551372, 22.02426961490086, 7.7128148419516425, 11.959191645894732, 9.478765521730695, 6.818154803344181, 7.676020656313215, 5.98091641494206, 4.412587268011911, 4.658743705068316, 5.6540679420743665, 3.1553126871585846, 1.6036204589264733, 0.20867834240198135, 0.04029837456930961, 0.06898225843906403, 0.03671985551980989, 0.25078437158039635, 2.4447343136583055, 16.9872043132782, 31.71621629170009, 37.971113204956055, 31.330896990639822, 40.77679579598563, 65.51557895115444, 58.50253282274519, 38.42121750967843, 29.381409645080566, 25.884230170931133, 30.093877928597585, 47.16090488433838, 53.90317971365792, 50.598581722804475, 32.059481620788574, 1.31585017485278, 0.019798121747693846, 0.09098268433340959, 0.0293191113908376, 0.05760416255465575, 0.05877703747579029, 0.05526391902406301, 0.07828529924154282, 0.07160372420081071, 0.036925512698612044, 0.07308449795735733, 0.05964431379522596, 0.022333311781819378, 0.012634752916970422, 0.020665883219667842, 0.05053708462842873, 0.030148138691272055, 0.12902439731572354, 0.08368428024862494, 0.00436611203310479, 0.04549148465905871, 0.028653957082756927, 0.052211149263062646, 0.009758831434217947, 0.03239071728395564, 0.055266114084848335, 0.046540038394076486, 0.029769868989075934, 0.0538427206421537, 0.09173108810292822, 0.035011501118008576, 0.05455327572833214, 0.06148587140653815, 0.033036129615668736, 0.06820208565997225, 0.02385986120706158, 0.0230908147059381, 0.03742050738739116, 0.04892329086682626, 0.03265673015266657, 0.024840480016012276, 0.031996776815503836, 0.04091091527204428, 0.08693892096302339, 0.03432731390265482, 0.02873668067955545, 0.023414177354425192, 0.06634712019669158, 0.034279236303908486, 0.015532988023811152, 0.02440724558463054, 0.0336951160404299, 0.04496003567640271, 0.05605188477784395, 0.0654482241453869, 0.06260069765682731, 0.051529119789068184, 0.42009614780545235, 7.793442606925964, 54.64155435562134, 78.78872271946499, 70.41869340624127, 69.24330833980015, 53.39761141368321, 45.47500787462507, 45.40441070284162, 28.836658716201782, 32.7452757699149, 38.140722206660676, 37.057220118386404, 27.127127408981323, 31.45731598990304, 9.496939403670174, 1.2801171094179153, 0.09363128471055202, 0.16962239598589285, 0.18631940574518271, 0.8862067950623376, 1.6284958784069334, 4.619966242994581, 5.804468648774283, 7.155029961041041, 9.09960753577096, 10.473031895501272, 6.107484800474984, 9.82440105506352, 10.01171406677791, 10.641503129686628, 10.307707326752798, 9.299383878707886, 5.29270429270608, 6.049062609672546, 7.857124584061759, 5.084711704935346, 7.149833142757416, 8.94298905985696, 16.005031279155187, 20.96124039377485, 30.809170654841832, 38.94820015771048, 51.5018127986363, 56.19630411693028, 61.96996879577637, 58.99509062085833, 61.98288549695696, 61.27577427455357, 61.55283369336809, 62.98503112792969, 60.304958071027485, 54.16515111923218, 61.2520809173584, 61.43060098375593, 66.9913693836757, 63.97616386413574, 57.442432267325266, 52.01822028841291, 39.23931230817522, 41.29041705812727, 40.97569145475115, 40.697172914232524, 56.20156390326363, 56.418913977486746, 60.740936688014436, 60.832645961216514, 57.86537953785488, 59.73787389482771, 56.454645088740754, 51.04151201248169, 54.81255299704415, 56.1565534727914, 59.85771642412458, 62.08132062639509, 60.4354521887643, 55.83475112915039, 55.44028105054583, 60.45025879996163, 61.045768056597026, 57.88104772567749, 52.42692722593035, 46.97605848312378, 42.28426306588309, 33.67461470195225, 30.175168378012522, 21.091229030064174, 12.299775838851929, 12.644229309899465, 9.728832926068987, 8.382590787751333, 6.069380879402161, 5.606770685740879, 7.730139306613377, 9.817186219351631, 8.653680835451398, 8.531605328832354, 3.848052646432604, 1.3829858409506934, 0.42064299274768147, 0.1261618887739522, 0.03618222169045891, 0.062213810559894354, 2.096005529165268, 16.00742667061942, 35.9878819329398, 42.463971274239675, 33.764211722782676, 33.71687364578247, 55.032161235809326, 57.46445458275931, 40.493222440992085, 35.49204805919102, 35.248524120875764, 38.80283342088972, 55.13738475527082, 61.879781178065706, 59.67796652657645, 37.93554537636893, 1.85264595917293, 0.03601444372907281, 0.02173174299033625, 0.057239762108240805, 0.03638589076165642, 0.0680830366909504, 0.021772709542087147, 0.0696014284289309, 0.14525245795292513, 0.007209100394642779, 0.09060854012412684, 0.045421975531748364, 0.017114252816619616, 0.0335364236629435, 0.018500175859246935, 0.058625133841165473, 0.057584885374775956, 0.11082223403666701, 0.07556079793721437, 0.003954254423401186, 0.005346737203321287, 0.0196887011905866, 0.03331853589043021, 0.033116593690855164, 0.05125494414408292, 0.017370655933128934, 0.06256795155682734, 0.042684850083397965, 0.04977152070828846, 0.0704491018716778, 0.11543306947818824, 0.11584709797586713, 0.18851236307195254, 0.15552524743335588, 0.19396744535437652, 0.21907752938568592, 0.10154798347502947, 0.21326333922999247, 0.23276986394609722, 0.12312057268406663, 0.13022893268082822, 0.13428682993565286, 0.1311185056609767, 0.1651334932872227, 0.13298506050237588, 0.11792393081954547, 0.0895568515573229, 0.14055273442396096, 0.10310733837208577, 0.08397769914673907, 0.06699535184140716, 0.17802552293453897, 0.1432319435157946, 0.0943736902305058, 0.16847329693181173, 0.22295775903122766, 0.23181804216333798, 0.6498621915067945, 12.12757863317217, 64.43126392364502, 86.98843084062848, 78.9068351473127, 78.86213043757847, 61.368032455444336, 51.84634617396763, 51.00969621113369, 34.12261370250157, 43.87044300351824, 55.382965360369, 45.16273845945086, 42.022503580365864, 41.52709354673113, 10.478140558515276, 2.0012540306363786, 0.16010598306144985, 0.20918348458196434, 0.1520111688545772, 0.9541040488651821, 2.769538713353021, 7.34033841746194, 10.611010091645376, 12.51429625919887, 14.56328615120479, 18.39903657776969, 15.228255680629186, 14.236078977584839, 15.45150477545602, 19.85831982748849, 16.906829289027623, 15.407915251595632, 17.687247480664933, 15.025300536836896, 13.64531968321119, 11.229456220354352, 18.643288339887345, 13.038653356688362, 21.136116130011423, 26.49606943130493, 37.03233514513288, 41.1548889705113, 54.07764550617763, 57.44602796009609, 66.09767123631069, 61.870553970336914, 66.70777865818569, 63.58879484449114, 63.666343688964844, 63.19397040775844, 62.132396834237234, 55.5032491002764, 63.424122537885395, 63.03856004987444, 64.08248519897461, 62.365230969020296, 61.77282060895647, 55.39319658279419, 44.717581272125244, 46.55223573957171, 45.12329701014927, 46.20764677865164, 59.635575566973, 59.10374655042376, 60.78288991110665, 63.873830795288086, 59.878067697797505, 59.137514795575825, 55.56940637316023, 52.10400969641549, 56.853450843266074, 59.01375348227364, 60.70180443355015, 64.23515796661377, 64.02207061222622, 55.348113196236746, 55.54745701381138, 62.62365531921387, 65.22244140080043, 60.1237073625837, 55.00054693222046, 51.19224623271397, 45.61702210562569, 37.49034649985177, 35.98993165152413, 27.89601853915623, 14.938713823046003, 18.20080099787031, 17.141907691955566, 17.979226418903895, 19.391699654715403, 17.505262000220164, 15.445638758795601, 13.242668100765773, 16.24320684160505, 10.807925513812474, 3.7859192490577698, 0.703624638063567, 0.21894368156790733, 0.1864103837204831, 0.11801796220242977, 0.5066075984920774, 3.471045127936772, 21.744538613728114, 44.18848984582083, 50.23642076764788, 42.699890409197124, 53.383426666259766, 76.96533475603376, 70.32239832196916, 51.79358502796718, 40.09832852227347, 37.68245376859392, 44.2905832018171, 62.99318831307547, 71.09840093340192, 68.71853174482072, 44.51393304552351, 3.450496916260038, 0.14980196739946092, 0.10172630247793027, 0.16285295066024574, 0.10947057870881897, 0.1470059688602175, 0.1014369208631771, 0.23427811158554895, 0.24052679485508374, 0.1959693000784942, 0.2557806691953114, 0.1412173051919256, 0.07722626214048692, 0.16854291462472507, 0.1676266345062426, 0.14868995706949914, 0.10462408126997096, 0.23331964015960693, 0.23719385798488343, 0.1028998898608344, 0.11960554415626184, 0.08507245433117662, 0.16151509673467704, 0.22830722055264882, 0.09195710133228983, 0.1745984868279525, 0.13298613258770534, 0.1312627350645406, 0.13120343110391072, 0.17317109342132295], [0.050402795762888024, 0.028546924968915324, 0.06225496370877538, 0.02906238766653197, 0.018868109776771495, 0.0346909408191485, 0.01991770845571799, 0.028971443617982522, 0.037720813415944576, 0.011007527554673808, 0.07706661642129932, 0.06391812767833471, 0.06419233725007091, 0.06568185053765774, 0.010294505993702581, 0.06441261685852494, 0.029131225044173852, 0.0512586693013353, 0.032724685434784205, 0.033791596934731515, 0.07282570470124483, 0.06288385710545949, 0.023467662877270153, 0.03389312612957188, 0.04315339208447507, 0.038822499835597615, 0.07216200245810406, 2.2015690760953084, 30.443017959594727, 63.38308647700718, 66.04464953286308, 59.374712399074006, 43.55303192138672, 36.38252919060843, 33.13402053288051, 25.176087141036987, 19.052132504326956, 35.59004545211792, 31.71635525567191, 30.346052374158585, 43.06857224873134, 10.890162655285426, 1.0299957479749406, 0.03587997844442725, 0.08336900573756013, 0.05595123767852783, 0.10030075468655143, 0.5728804394602776, 2.335944197007588, 3.7879528999328613, 6.020616250378745, 3.8072953820228577, 3.7305529628481184, 6.993725793702262, 5.674806577818734, 10.673120038849966, 15.483890329088483, 9.044478791100637, 14.144186445644923, 13.594262582915169, 5.086810060909816, 5.9451431802340915, 11.402824197496686, 13.442061424255371, 19.58777608190264, 22.68090217454093, 32.544236591884065, 39.490646021706716, 50.333403723580496, 54.72780234473092, 58.22143302645002, 55.93180356706892, 57.46454838344029, 55.35797963823591, 57.420812947409495, 55.78002711704799, 59.577370507376536, 56.24100535256522, 54.63147251946585, 58.182203497205464, 58.22200625283377, 53.8140412739345, 57.11127070018223, 58.44400814601353, 61.01530715397426, 57.07981620516096, 38.673214776175364, 32.97979484285627, 30.35493564605713, 42.248073373522075, 54.89834240504673, 52.57646288190569, 59.18594373975481, 56.982002939496724, 56.23696844918387, 58.37538078853062, 55.23832123620169, 52.95233263288225, 57.57927009037563, 56.773866176605225, 58.03193828037807, 57.23615762165615, 59.2224634715489, 56.99435683659145, 59.67686871119908, 56.88904299054827, 58.06308358056204, 56.7262293270656, 59.40475640978132, 55.229476179395405, 51.666940212249756, 43.551451206207275, 44.20839296068464, 33.08791923522949, 32.0658392224993, 28.37323818887983, 14.224775995526995, 4.034003811223166, 4.204807903085436, 10.107197080339704, 7.597879477909633, 6.677228833947863, 7.905404141971043, 7.460710746901376, 1.8792360637869154, 1.6709601197923933, 0.4299134910106659, 0.13103755643325193, 0.03414190420880914, 0.0675960113959653, 0.2961020427090781, 2.584893375635147, 15.59781299318586, 38.562182562691824, 42.926644870213096, 53.09080328260149, 85.73757444109235, 76.85251685551235, 59.70814255305699, 19.482338905334473, 14.52189312662397, 25.917845555714198, 39.45598840713501, 48.04812036241804, 56.83526393345424, 46.80024126597813, 9.896858607019697, 0.09208474055464778, 0.02411732792721263, 0.020881430046366792, 0.04807109498818006, 0.05081117884921176, 0.05716514361224004, 0.017590925363557677, 0.017299966154886142, 0.0907147851373468, 0.016458911821246147, 0.06536301371774503, 0.05367813179535525, 0.04163072557587709, 0.04503763972648552, 0.020507730277521268, 0.036971832891660075, 0.015170149904276644, 0.049817786618535004, 0.02734793832392565, 0.025316392603729452, 0.04840289521962404, 0.033882235642522573, 0.06093786616942712, 0.04198452391262565, 0.06419962471617119, 0.047170702767159255, 0.0359524968745453, 0.04952167732907193, 0.03872063137324793, 0.04265841096639633, 0.06652857403137855, 0.06654167654258863, 0.029909572564065456, 0.011355307285806962, 0.01655578287318349, 0.04548748130244868, 0.03448768565431237, 0.03409574007881539, 0.024993559212556908, 0.07112823400114264, 0.054208685111786635, 0.028996359423867295, 0.018021871435589025, 0.01257552020251751, 0.058072833477386405, 0.11442296153732709, 0.029142855134393488, 0.006388158687124295, 0.035138841784958325, 0.01279623237704592, 0.021105334728157947, 0.01791384187527001, 0.007494894255484853, 0.05511173379740544, 0.0075593440560624, 0.13023906999400683, 2.4436273787702834, 37.41975627626692, 72.0540909085955, 73.37644427163261, 65.51195893968854, 54.556039401463096, 42.071415424346924, 41.94399241038731, 31.902000699724468, 26.219774314335414, 32.83695725032261, 35.343676226479666, 31.175194808415004, 35.73613132749285, 13.10045063495636, 1.4051880495888847, 0.04584060788952878, 0.1017568636951702, 0.4164203336196286, 0.7656538124595369, 2.4139579193932668, 4.785209170409611, 7.379971810749598, 10.506677678653173, 9.802583711487905, 7.931895017623901, 11.999219349452428, 7.321732878684998, 9.220879656927925, 11.379216824259077, 6.6263749684606275, 8.65710369178227, 8.82457091127123, 3.9822853292737688, 5.373965212277003, 7.418637667383466, 12.398052028247289, 19.66727215903146, 25.135440179279872, 32.07656724112374, 40.55244888578142, 50.85686363492693, 55.99575131280081, 60.93625055040632, 59.37257235390799, 57.94266087668282, 58.727105549403596, 59.39186750139509, 57.78677109309605, 61.182953289576936, 60.1718236378261, 58.08933734893799, 59.1133211680821, 58.68937683105469, 58.03650324685233, 56.131567750658306, 59.474287033081055, 58.785991532461985, 58.1308319909232, 42.421823501586914, 39.04644421168736, 36.62301329204014, 46.42607034955706, 55.044918128422324, 57.460747718811035, 59.848079272678916, 57.73816844395229, 57.85901151384626, 57.847755432128906, 55.911323751722065, 55.00854083469936, 59.80174173627581, 57.942535809108186, 59.46709564753941, 58.68188667297363, 60.72890240805489, 58.781454358782085, 58.95779963902065, 59.45991815839495, 59.06826210021973, 58.04856531960623, 59.743925775800435, 57.919596331460134, 53.46075316837856, 47.86400352205549, 46.059563296181814, 34.50793647766113, 30.423566477639334, 25.275215353284562, 17.511577912739344, 8.530295593397957, 8.954417109489441, 12.401044964790344, 13.041064381599426, 11.741904973983765, 8.848633391516548, 13.926396897860936, 9.549122980662755, 6.008519870894296, 1.9685664474964142, 0.4384773357638291, 0.044448284565338066, 0.09039832997534956, 0.2272948870169265, 2.489339577300208, 15.464457954679217, 35.893980503082275, 38.19591869626726, 50.69014160973685, 79.79569040025983, 73.82790347508022, 63.507959502083914, 29.39238085065569, 19.608792645590647, 31.909390108925955, 46.62783561434065, 55.60245895385742, 64.49629211425781, 54.542653696877615, 12.301047359194074, 0.10766560092036213, 0.045519484406603236, 0.0036209257918276955, 0.007337195083632001, 0.028491973810430084, 0.036729107344789166, 0.026303750961752873, 0.059241046862942834, 0.04244542900206787, 0.03910699260554143, 0.025399282441607544, 0.04231705017653959, 0.03317928693390318, 0.0025017378336217788, 0.0534496317351503, 0.046650710848293135, 0.03479430205853922, 0.018451821757480502, 0.047665558356259546, 0.026597068079614213, 0.04296846075781754, 0.011964060066800033, 0.060940912791660855, 0.022202524156974893, 0.030710759572684765, 0.021552479127421975, 0.023834852102611746, 0.054882779118738005, 0.08963118506861584, 0.26161973444478853, 0.18056755938700267, 0.17809971395347798, 0.2314879484474659, 0.2059091188545738, 0.1412082535347768, 0.1992216677005802, 0.125504429052983, 0.192393637661423, 0.08906579576432705, 0.1498005831880229, 0.12964517543358461, 0.1350621104772602, 0.1174648068845272, 0.1679302110735859, 0.10895882081240416, 0.17384240882737295, 0.1805748197117022, 0.07821760858808245, 0.06338196966264929, 0.12786961213818618, 0.16228410761271203, 0.14289365309689725, 0.08903279860637017, 0.15717415538217339, 0.14276835482035363, 0.3682928761201245, 4.2532294648034235, 47.1779522895813, 83.67206260136196, 80.86143289293561, 75.09508119310651, 60.361731801714214, 48.96321548734392, 46.23125328336443, 33.81425959723336, 28.76842393193926, 49.613928181784495, 43.21246944155012, 41.2467372076852, 53.6348055430821, 14.552325367927551, 1.6924645773002078, 0.2878353148698807, 0.15961485941495213, 0.4501087287706988, 0.40529797758374897, 2.869475087949208, 8.274637494768415, 12.748933451516287, 14.519574165344238, 13.864695157323565, 14.763426406042916, 14.397714052881513, 12.10468258176531, 16.802184207098826, 24.99986171722412, 15.923461164746966, 23.630736555371964, 21.909507955823624, 12.401348079953875, 15.383365528924124, 18.895608697618755, 20.259958709989274, 26.391752651759557, 28.512549570628575, 37.515564986637656, 43.13361780984061, 53.27498960494995, 56.44091197422573, 63.60032885415213, 62.40908799852644, 63.23968955448696, 61.820068359375, 63.10529749734061, 58.69618606567383, 64.77248300824846, 62.273848261152, 61.84479699816023, 59.79633603777204, 59.659880365644185, 59.246796063014436, 55.008672850472585, 58.55164269038609, 59.83118125370571, 59.32579708099365, 48.675629547664094, 43.82027006149292, 42.477753026144846, 50.95720951897757, 58.327389580862864, 58.59467288425991, 59.934500966753276, 60.85466480255127, 56.74894993645804, 57.333199637276785, 57.355635370527, 56.348271642412456, 61.5048702784947, 61.586921555655344, 61.6094754082816, 61.867580141339985, 64.04132407052177, 60.98481151035854, 62.61123194013323, 60.248490061078755, 62.98947102682931, 62.11831283569336, 61.63970702035086, 60.8791572025844, 58.28090613228934, 50.35096182141985, 50.58186435699463, 37.54641498838152, 35.56303085599627, 33.4247088432312, 17.24086914743696, 9.223958577428546, 12.861416101455688, 21.192153351647512, 20.31381072316851, 16.861356803349086, 17.350635051727295, 13.247971313340322, 8.300864338874817, 5.43428122145789, 1.2145944024835313, 0.6077049736465726, 0.1994173979120595, 0.15920951616551193, 0.6878018528223038, 4.028204236711774, 20.29901453426906, 51.24924577985491, 53.24686329705374, 58.59965474264962, 86.99198831830705, 82.40875502995083, 67.65775026593889, 30.82620416368757, 26.999546323503765, 40.3759194782802, 54.93127339226859, 64.46619946616036, 72.6240724836077, 63.33106531415667, 15.940744808741979, 0.25961743188755854, 0.16593482957354613, 0.09161051243011441, 0.11600386670657567, 0.1309691872447729, 0.11794355405228478, 0.07791021186858416, 0.14805824096713746, 0.19638722336718015, 0.10727633216551372, 0.1617094563054187, 0.130942846515349, 0.14632923874471868, 0.1214585690093892, 0.1953907132680927, 0.12282063306442328, 0.07278599004660334, 0.18067886627146176, 0.11249394076211111, 0.12436298387391226, 0.14493115805089474, 0.11260336810456854, 0.12928772318576062, 0.1347337266696351, 0.13848557748964854, 0.1524786116289241, 0.14201153043125356, 0.18323326563196524, 0.165539786485689], [0.040786889248660634, 0.043571776776973686, 0.026958062280235544, 0.06419288007808582, 0.06545027332114321, 0.027351385281820382, 0.03169029951095581, 0.048601051193795035, 0.03887732207242932, 0.04123043401965073, 0.04020085212375436, 0.059705422659005435, 0.06854522081890277, 0.03670138240392719, 0.06463746979300465, 0.0723298652363675, 0.012136013563057142, 0.05456244273643408, 0.04006435801940305, 0.016847369726747274, 0.03807349895526256, 0.009848087626908506, 0.06426972416894776, 0.038714857040239234, 0.06112976265805108, 0.026331542059779167, 0.27083608561328476, 13.640105060168676, 56.613484382629395, 64.55373982020787, 59.70417513166155, 46.72149733134678, 48.62973322187151, 34.370487213134766, 13.941639508519854, 18.943110057285853, 24.29960662978036, 37.99576193945748, 38.795763628823416, 38.118213517325266, 18.722315413611277, 1.5361958997590202, 0.19647370944065706, 0.04086283088794776, 0.11567778991801397, 0.10221112253410475, 0.5299032256007195, 1.0829967153923852, 0.9287584317581994, 3.9535927431924, 7.42918416431972, 7.025634092944009, 7.553328497069223, 10.819209388324193, 3.36169524703707, 7.111679715769632, 6.570394200938089, 10.43049328667777, 11.778574960572378, 9.182624612535749, 8.684720175606863, 14.253919345991951, 30.302181448255265, 32.28259869984218, 36.536501271384104, 44.120338439941406, 47.63508817127773, 57.52872541972569, 55.454778466905864, 55.253579480307444, 55.478395393916536, 53.410413469587056, 57.04156289781843, 54.500790800367085, 54.492866379874094, 52.19332184110369, 55.96441841125488, 59.01222487858364, 57.07572371619088, 56.454415798187256, 56.23160096577236, 54.15090036392212, 55.59395783288138, 60.06382083892822, 59.224937030247276, 58.28328936440604, 49.11776079450335, 28.977661984307424, 27.985372373035975, 43.174810205187114, 56.01609563827515, 54.192683356148855, 56.368070534297395, 50.71759046827044, 55.47053698131016, 53.95181710379464, 53.39090640204293, 53.59473180770874, 55.35219178880964, 54.05644307817732, 52.776293073381694, 55.18305179050991, 58.07179314749581, 56.03940337044852, 58.11107131413051, 55.679722922188894, 54.565693923405235, 48.27671609606062, 49.35345411300659, 54.473494802202495, 57.10217203412737, 51.71980210712978, 48.60678679602486, 49.64494146619524, 42.1812629699707, 43.23205641337803, 36.922213145664756, 27.329908847808838, 17.28605501992362, 10.098532676696777, 5.4377622689519605, 11.220303705760411, 4.395933738776615, 13.935549412454877, 7.294137239456177, 4.1837891680853705, 2.4859236691679274, 0.9027437791228294, 0.04472366460998144, 0.06783761057470526, 0.04778206281896148, 0.28248341062239235, 4.290494825158801, 24.28714677265712, 48.77315098898751, 61.989826747349326, 75.68367004394531, 78.84621906280518, 50.677645274571006, 21.814772742135183, 17.619818687438965, 20.486346653529576, 32.73524604524885, 46.50234419958932, 51.55440718787057, 56.08327429635184, 20.890434776033672, 0.9793325236865452, 0.08224682416766882, 0.03259428118222526, 0.036356690007128885, 0.04959424664931638, 0.04668884790901627, 0.051499040331691504, 0.01009290390980563, 0.024237881547638347, 0.039525397654090605, 0.04568107412861926, 0.06514200129147087, 0.02368508415695812, 0.054307103223566494, 0.032262742186763456, 0.042053412180393934, 0.012422721749836845, 0.09497711820794003, 0.08585285781217472, 0.056918105975325615, 0.0137340865164463, 0.042627829393105846, 0.0664292907874499, 0.030304649578673497, 0.02073610480874777, 0.06293434011084692, 0.022658418265304396, 0.02489894937856921, 0.021928163611197045, 0.07768248873097555, 0.01864002871194056, 0.055035951613847695, 0.02937913459858724, 0.033888946353857, 0.015644795327846493, 0.015569890150800347, 0.02119797172157892, 0.03699486915554319, 0.024904825491830707, 0.06410811069820609, 0.05524294889931168, 0.05737654798265014, 0.004136222672449159, 0.06770214784358229, 0.03178243778113808, 0.011380740474643452, 0.056367484985717704, 0.007227350442138101, 0.02875711476164205, 0.04839903774804302, 0.030004041602036784, 0.06795500391828162, 0.028918663771556954, 0.024702898559293578, 0.05028371286711522, 0.16421103850007057, 16.558809655053274, 64.32762459346226, 73.3810648236956, 67.60923099517822, 54.78549671173096, 54.30467789513724, 43.03430025918143, 26.29688194819859, 28.680636916841777, 26.6809401512146, 39.9544278553554, 37.68578542981829, 33.00514187131609, 17.454891034535, 2.1803594827651978, 0.07037860208324023, 0.01546331265542124, 0.11790229912315096, 0.341777790337801, 4.000758418015071, 5.5573559658867975, 6.009965530463627, 7.948586327689035, 9.697516526494708, 7.829812083925519, 13.207098535129003, 12.92547675541469, 10.62518789087023, 9.526328546660286, 9.182773998805455, 6.914511118616376, 8.751487152917043, 8.419321571077619, 8.54284577710288, 14.201491713523865, 25.915401526859828, 30.895265783582413, 35.217236382620676, 44.681068488529746, 47.72606093542916, 56.118327958243235, 54.373440742492676, 57.22771903446743, 58.08998005730765, 56.26664073126656, 58.46857697623116, 56.27272040503365, 55.49868760790144, 54.8122090612139, 57.60122292382376, 59.695872034345356, 58.594978604997905, 57.99848965236119, 56.427977902548655, 55.92555366243635, 55.716322558266775, 58.52120263235909, 58.33355263301304, 58.00174488340105, 50.68511111395699, 34.37536137444632, 33.48541872841971, 45.45976005281721, 56.18365839549473, 56.198812416621614, 57.77553585597447, 53.89863906587873, 55.37221997124808, 53.55065243584769, 54.63573523930141, 54.85011843272618, 56.92931127548218, 56.23419611794608, 53.75943538120815, 58.01215328489031, 58.9281655720302, 57.73999582018171, 59.309343746730256, 57.69686835152762, 56.976343631744385, 52.31193801334926, 52.16017198562622, 56.775881154196604, 59.603996004377095, 53.03526633126395, 51.56385326385498, 50.5630555834089, 41.490490436553955, 42.5168331691197, 33.705242361341206, 26.934783901487076, 15.734357254845754, 10.254281759262085, 7.040258748190744, 12.99926575592586, 9.809538858277456, 14.654963288988386, 11.49323068346296, 9.197406036513192, 7.871338861329215, 2.991473947252546, 0.48688453968082157, 0.21286227075116976, 0.06792699399271182, 0.14550324449581759, 4.470344603061676, 22.239055803843907, 52.094799859183176, 65.36151654379708, 79.24296815054757, 85.33596856253487, 56.0911466053554, 25.509850808552333, 27.199079479490006, 29.259982926504954, 37.589337485177175, 52.45026969909668, 59.17690413338797, 63.107173510960166, 25.49328456606184, 1.2237051193203246, 0.09330078387366873, 0.03713645566520946, 0.01828328044419842, 0.01260547837175961, 0.016379280647795116, 0.01847190978670759, 0.06586502106594187, 0.005115506887835051, 0.029821641210998808, 0.03320368366049869, 0.0201537572180054, 0.04398723698354193, 0.02766523147667093, 0.03835874829175217, 0.021313819701650312, 0.06215425554130759, 0.09172601266098873, 0.04281090831916247, 0.008203929423221519, 0.06928182486444712, 0.03480002210874643, 0.05057468225381204, 0.016747550440153906, 0.04374117982972946, 0.053374792715268474, 0.07272731033819062, 0.037964940137628994, 0.021846196580944315, 0.18650567717850208, 0.07781456557235547, 0.15282515303364821, 0.15207188416804585, 0.1656983872609479, 0.07586896818663393, 0.22679855222148554, 0.12267567084303924, 0.10221085790544748, 0.1128573709034494, 0.17611499902393135, 0.1695490192089762, 0.19754107216639177, 0.11585396475025586, 0.1923800398196493, 0.09295877508286919, 0.1385422758758068, 0.19510268872337683, 0.09284106961318425, 0.11800691565232617, 0.32945735859019415, 0.06995523694370474, 0.16135610240910733, 0.10150129348039627, 0.09477611577936582, 0.17316909852836812, 0.5826905359114919, 22.162775005613053, 73.53603744506836, 80.49184431348527, 77.8673221043178, 62.35469055175781, 60.58948680332729, 47.324017320360454, 23.102461542401993, 27.669675758906774, 35.92958654676165, 49.5334506716047, 51.982437065669465, 49.38868842806135, 23.15436805997576, 2.1839610380785803, 0.4416229969688824, 0.1326807104051113, 0.26724934950470924, 0.17021490633487701, 4.424592452389853, 4.776846144880567, 8.753595062664576, 13.285253609929766, 16.081706387656077, 13.345355527741567, 14.21470718724387, 20.24960241998945, 10.359229956354413, 16.898133618491038, 13.10608388696398, 18.852583714893886, 19.4876195362636, 15.682709557669503, 14.706042970929827, 18.1295576436179, 35.6255646433149, 37.62177862439837, 39.777759483882356, 49.343698842184885, 50.206772804260254, 60.55230004446847, 56.85231828689575, 59.157817431858604, 59.22727162497384, 58.362283434186665, 61.52295643942696, 59.75297927856445, 59.41189220973423, 56.478699752262656, 58.2631812776838, 62.816252435956685, 59.46245425088065, 58.925379344395225, 59.38960933685303, 57.092048508780344, 55.61664717538016, 59.86105850764683, 59.22802897862026, 58.308087485177175, 54.91972896030971, 38.93294538770403, 39.83674274172102, 51.091671058109824, 57.74990047727312, 55.40939283370972, 57.0459645816258, 56.101040840148926, 55.384608609335764, 54.093331064496724, 55.220717975071494, 56.299512658800396, 59.022494316101074, 59.5454991204398, 56.251431124550955, 59.57425076620919, 61.82047135489327, 60.703617913382395, 61.47110203334263, 59.15127917698452, 59.68608897072928, 51.95203522273472, 55.00009529931204, 59.29296684265137, 60.95378085545131, 54.34603704724993, 53.966262408665244, 55.30114337376186, 44.33436727523804, 45.57965121950422, 41.01971524102347, 32.74944468906948, 24.275140285491943, 16.106261321476527, 13.1057607957295, 21.318400382995605, 17.241887058530533, 26.025617327008927, 18.034679991858347, 13.537004215376717, 6.156191672597613, 2.4654212721756528, 0.2161104857389416, 0.3470809486295496, 0.21248136833310127, 0.49642609911305563, 6.249663616929736, 30.392601830618723, 58.221571990421836, 69.98431287493024, 81.33240263802665, 83.5463557924543, 58.436698641095845, 32.115056787218364, 26.655271768569946, 33.10719353812081, 46.078146253313335, 63.14528438023159, 67.48221097673688, 71.47985703604562, 32.525122097560335, 1.9890497369425637, 0.1853257454931736, 0.15089290243174347, 0.12166313374681131, 0.12915101195020334, 0.11088643702013151, 0.11127573970173087, 0.19597714394330978, 0.07378968583153826, 0.14734389287020477, 0.12604455649852753, 0.1672695350966283, 0.09930942180965628, 0.11904983754668917, 0.13375412566321238, 0.08435021487197705, 0.11328833563519375, 0.22896444957171166, 0.09507773138050522, 0.0926106119794505, 0.14459773951343127, 0.10628108414156096, 0.10680692163961274, 0.10225794145039149, 0.07977345545909234, 0.154186877821173, 0.22195963401879582, 0.19864514363663538, 0.10726242219763142], [0.04920148683179702, 0.10804353814039912, 0.03509862162172794, 0.028980196719723086, 0.0031805118238220787, 0.026765348156914115, 0.010059678594448736, 0.05729356314986944, 0.07313166971185378, 0.06816861352750234, 0.06071268075278827, 0.06342981995216437, 0.005127555549344314, 0.008836226521192916, 0.0633867804759315, 0.050121485322181664, 0.030428092061941112, 0.022217811550945044, 0.05982092288987977, 0.0555798517140959, 0.04084997943469456, 0.03576535352372697, 0.03683107080204146, 0.030869954066084962, 0.014431028493813105, 0.036111416561262946, 1.8707047615732466, 25.191937719072612, 62.94425215039934, 59.585472106933594, 55.54261064529419, 38.1878205708095, 36.99538809912545, 21.43537504332406, 17.834290470395768, 21.13493319920131, 45.55706262588501, 42.6553316116333, 35.13107524599348, 18.862382411956787, 3.218179336615971, 0.1475644303219659, 0.061678229298974784, 0.03581719359915171, 0.13288351095148496, 1.187576983656202, 4.820065242903573, 5.870357547487531, 5.4115875363349915, 7.172931560448237, 11.541100297655378, 7.978712848254612, 6.814288565090724, 13.026092750685555, 11.900738188198634, 7.980939745903015, 14.795426334653582, 16.5329258782523, 21.13537093571254, 37.516843455178396, 35.4623236656189, 46.42301661627633, 47.041850975581575, 49.35473952974592, 53.96948637281145, 54.64948572431292, 53.200748103005544, 55.082497460501536, 53.25846331460135, 59.04711873190743, 55.59419754573277, 54.04667738505772, 49.27722542626517, 51.855764457157676, 48.82262216295515, 51.845404693058555, 55.699223041534424, 59.38402993338448, 56.68348053523472, 56.72399548121861, 55.4086354800633, 52.23978444508144, 53.130654675619944, 54.88835089547293, 56.49666779381888, 58.18748412813459, 50.68858868735177, 31.19276680265154, 27.8244104044778, 49.27293143953596, 56.80874613353184, 51.314044679914204, 51.90049001148769, 50.58375774111067, 55.912949630192344, 54.46788413184029, 53.113711493355886, 53.323105880192344, 57.003320012773784, 52.93272481645857, 53.16494403566633, 51.667565550122944, 50.68277999332973, 52.76609311785017, 51.75382743562971, 53.511547974177766, 50.2241849899292, 47.38548455919538, 49.51304381234305, 53.61077867235456, 56.331738403865266, 57.14129386629377, 53.95933852876936, 49.82701553617205, 47.162881646837505, 49.73210661751883, 53.92217261450631, 43.39122574669974, 32.814021246773855, 28.2284186226981, 19.150051730019705, 15.021173306873866, 6.391284840447562, 15.798888649259295, 15.271133014133998, 11.685422199113027, 6.890153339930943, 1.0804361956460136, 0.5617308063166482, 0.019215665591348494, 0.13722393661737442, 0.04285537950428469, 0.19416952665363038, 3.0816335550376346, 13.631294744355337, 29.471173422677175, 36.38918556485857, 29.10955616406032, 32.66640329360962, 26.245472226824077, 13.375689625740051, 21.923003094536917, 32.013467175619944, 44.11571788787842, 52.47110734667097, 49.164629868098665, 34.602452823093955, 1.994524048907416, 0.04515996941232255, 0.04327029688283801, 0.016225478811455623, 0.018511943352807845, 0.024055197868230085, 0.08572559856942721, 0.05152697561840926, 0.040743133917983086, 0.04603430588862725, 0.05479200131126812, 0.062090588600507805, 0.041084080801478455, 0.04019030768956457, 0.07992309957210507, 0.09946768331740584, 0.054208108357020786, 0.02830962261318096, 0.053303353155830076, 0.06813625419246298, 0.016690370294132402, 0.03467243716918996, 0.020357020864529268, 0.03431317662554128, 0.060092859369303496, 0.07894482849431889, 0.03763420859883938, 0.06121323603604521, 0.024523135973140597, 0.04802991130522319, 0.027755678498319218, 0.03140865658809032, 0.04727150592952967, 0.05382156731294734, 0.030328517047954456, 0.014475891532908593, 0.0469438142276236, 0.058479404875210354, 0.04244150367698499, 0.021327841627810682, 0.07309858434434448, 0.024982244641120945, 0.03468631999567151, 0.007450103310735098, 0.052920686546713114, 0.03991555189713836, 0.04765563817428691, 0.04745110057826553, 0.02014033749167408, 0.06551762470709425, 0.007441451141078557, 0.03340444860181638, 0.0308709413345371, 0.017895097345379845, 0.02606024170693542, 2.209774681500026, 31.863177640097483, 71.58466366359166, 68.5053471156529, 62.4726779120309, 44.69545125961304, 43.35975388118199, 29.23143972669329, 22.094031265803746, 21.297825029918126, 37.90306602205549, 41.61442198072161, 40.5077337537493, 17.410537208829606, 4.113490768841334, 0.12235103254871708, 0.03811100158574326, 0.04683438688516617, 0.9823253516639981, 2.6702724056584493, 5.7645551562309265, 7.84768545627594, 9.42180071558271, 9.848216874258858, 14.914631366729736, 13.70769453048706, 9.993447252682277, 11.257999420166016, 10.053821018763951, 13.018150091171265, 17.589460270745413, 16.719314779554093, 20.552740165165492, 32.08847992760794, 35.81995439529419, 45.053721223558696, 47.2282954624721, 49.67761884416853, 54.49646554674421, 53.8988162449428, 53.52610445022583, 55.1430127961295, 54.96306834902082, 57.76448474611555, 58.49311106545584, 56.52125399453299, 53.43148388181414, 54.70040907178606, 51.721650327954976, 53.7271922656468, 57.010591302599224, 60.304374422345845, 55.907001972198486, 57.11666597638811, 55.37952252796718, 54.439125537872314, 52.160835538591655, 55.2208708354405, 55.90424701145717, 58.13824571881975, 51.9484395299639, 36.03427505493164, 33.31500026157924, 50.1398686000279, 57.35164015633719, 53.73765277862549, 51.90049695968628, 51.57423039845058, 55.082229954855784, 54.39265251159668, 53.21767044067383, 55.02275684901646, 57.180502550942556, 55.917455536978586, 56.54506547110421, 53.10671813147408, 52.27147517885481, 55.05625411442348, 55.18756464549473, 55.226867130824495, 51.67917946406773, 49.02505792890276, 51.73285429818289, 55.94979592732021, 57.68269402640206, 56.82016202381679, 52.53834506443569, 51.15399292537144, 49.524480547223774, 50.872208731515066, 52.3249693598066, 45.24602999005999, 34.37134878976004, 26.059276138033184, 17.152797256197246, 6.667997717857361, 7.261184539113726, 16.115307876041957, 15.088574307305471, 9.519031201090131, 11.020695856639318, 5.97395475421633, 1.8439919778278895, 0.22637739910611085, 0.35303674904363497, 0.09140178148767777, 0.2281181535550526, 3.9303379910332814, 16.956449849264963, 38.36902959006173, 49.60749067578997, 38.94421189171927, 33.19831221444266, 29.57372883387974, 16.552111591611588, 26.204769679478236, 41.10843678883144, 50.33445984976632, 57.807827608925955, 59.382299831935335, 40.31507410321917, 3.1659403911658694, 0.03368673613294959, 0.019789012415068488, 0.0008473198093789895, 0.06702896646623101, 0.06706591269799642, 0.048976046964526176, 0.01651990533407245, 0.038822818747056384, 0.012731198188183563, 0.033543965579675775, 0.009936809473271881, 0.034526304474898746, 0.03547764789046986, 0.03731316654011607, 0.02715097487504993, 0.016105254280513952, 0.051222153939306736, 0.029489698487200906, 0.02770854575958635, 0.05940401740372181, 0.026127508276009133, 0.028887342595096146, 0.02033432386815548, 0.028906711377203465, 0.024520075780206492, 0.04153150000742503, 0.04194493478696261, 0.012323386767613036, 0.11412923729845456, 0.22944202965923718, 0.14151797762938909, 0.08561686333268881, 0.09088061909590449, 0.10692801299904074, 0.15419689299804823, 0.19097938069275447, 0.11578585340508393, 0.12882152891584805, 0.1340935831623418, 0.192854498646089, 0.1686892339161464, 0.07218478087868009, 0.12514453407909187, 0.14241604586797102, 0.10235439520329237, 0.13810312801173755, 0.07544670227382864, 0.15883942959564074, 0.09733440314552613, 0.13238957817001, 0.16648539288767747, 0.18705462557928904, 0.16797370516828128, 0.12288365539695535, 3.7891888107572282, 40.96936164583479, 80.88500813075474, 75.55375957489014, 71.44853455679757, 51.53548376900809, 49.626087529318674, 29.456179210117885, 29.50596305302211, 29.665604863848003, 58.68736185346331, 55.60526950018746, 46.997010775974815, 23.88419120652335, 4.632403952734811, 0.34400164814932005, 0.18307395918028696, 0.16438880110425608, 1.1623588225671222, 4.3173404932022095, 8.33306576524462, 13.25178587436676, 12.273167712347847, 15.890964439937047, 23.88929292133876, 26.54133173397609, 18.028711489268712, 23.36479425430298, 19.670317207063945, 15.681022882461548, 26.658929995128087, 21.96393666948591, 25.905882494790212, 41.71382638386318, 39.81106914792742, 50.431699889046804, 49.041969844273154, 52.628980840955464, 57.046454429626465, 56.655423709324424, 54.539019789014546, 55.40862853186471, 55.40482439313616, 60.060847009931294, 61.69369452340262, 60.79438917977469, 55.64586782455444, 55.903312478746685, 53.98783656529018, 56.82688093185425, 60.168363434927805, 63.53049945831299, 59.506478037152974, 58.391292163303916, 57.766187054770334, 57.05315249306815, 53.981673513139995, 55.525403431483674, 55.909187180655344, 57.96939059666225, 53.717617647988455, 41.36877189363752, 39.84709208352225, 51.88828897476196, 58.67823192051479, 55.35533932277134, 54.71145323344639, 52.78392219543457, 56.74362414223807, 53.78449058532715, 53.53897251401629, 55.9843875340053, 57.63873277391706, 57.994466645377024, 58.4607116154262, 55.36170734677996, 54.83136177062988, 56.9551933152335, 55.37906742095947, 56.38378388541085, 54.52136789049421, 51.7119471686227, 53.73768751961844, 59.0615223475865, 60.69298716953823, 56.87602206638881, 53.83451761518206, 51.789624554770334, 50.03158439908709, 53.21350499561855, 56.91880212511335, 46.90861231940133, 37.681161403656006, 37.29070043563843, 28.69480081966945, 23.939125401633127, 15.430394411087036, 30.39206334522792, 26.086705889020646, 21.92071192605155, 17.359879629952566, 4.68997151511056, 2.0887255540915897, 0.39106280143771854, 0.39981821019734654, 0.12415669565754277, 0.43348090244191034, 4.602640475545611, 20.794976949691772, 40.891573088509695, 48.4391302381243, 38.25492279870169, 45.02601180757795, 35.39226150512695, 20.79024175235203, 33.73707900728498, 47.3497326033456, 57.95679003851754, 66.50546101161412, 65.760634967259, 48.77429396765572, 5.331149109772273, 0.3908468373119831, 0.14752367750874587, 0.18928366739835056, 0.1372918715434415, 0.185032455516713, 0.14693631045520306, 0.19995710466589245, 0.11468620598316193, 0.15233135595917702, 0.11951809456305844, 0.09358195521469627, 0.16853169165551662, 0.1491243416177375, 0.16320973794375146, 0.1635487883218697, 0.15864663065544196, 0.1735728540058647, 0.14354706874915532, 0.1461091355553695, 0.18640275698687347, 0.12592592143586703, 0.19283520111015864, 0.09201426112226077, 0.24357154433216366, 0.1181271384869303, 0.10548728637929473, 0.14996131456324033, 0.18128131037311895], [0.0596277778968215, 0.02637794876604208, 0.030447006225585938, 0.026878174959814975, 0.03744537569582462, 0.029894085002264807, 0.03978479480636971, 0.1213169451802969, 0.033573827905846496, 0.04535559445087399, 0.022366928102980767, 0.019889707011835914, 0.029850930175078765, 0.07695563523364918, 0.016785422872219766, 0.036051776725798845, 0.08240268366145236, 0.03558231870244656, 0.03115364955738187, 0.015539547761103936, 0.05340198500614081, 0.01950491658811058, 0.024620008721415485, 0.03853747780833926, 0.049774462157594304, 0.06636441605431692, 6.0870866264615735, 33.87614720208304, 60.241124970572336, 58.02340241840908, 47.95892286300659, 43.1875045640128, 29.506511960710796, 18.681772674833024, 26.22033017022269, 36.670368739536826, 51.234098706926616, 45.88422550473894, 19.300968340465, 5.334639276776995, 0.12864588334092072, 0.050863022317311594, 0.06180492535765682, 0.08621476803507123, 0.69774336793593, 2.3588923599038805, 5.314231548990522, 9.592604807444982, 6.72428377185549, 6.344101360866001, 9.360023413385663, 9.275846855981008, 15.868478332247053, 13.7352762733187, 21.124837466648646, 29.912196431841167, 39.95682150976998, 38.46620709555489, 51.446025712149485, 55.25121361868722, 55.32012932641165, 59.48397977011544, 63.336387634277344, 53.30830274309431, 53.10792016983032, 51.932083470480784, 51.51415627343314, 54.826140199388774, 50.842956815447124, 56.34409924915859, 55.8832426071167, 52.83864273343767, 49.7848573412214, 46.38680607931954, 47.69830288205828, 48.281336648123606, 53.662608759743826, 55.570313113076345, 56.61057308741978, 51.77700662612915, 56.44428185054234, 52.60998099190848, 55.32930442265102, 57.727496010916575, 54.69054957798549, 53.327934878213064, 56.50108684812273, 32.12176527295794, 35.39648600987026, 56.09909881864275, 51.429791246141704, 54.800928660801475, 56.19699893678938, 52.18539047241211, 52.906603063855854, 53.726726736341206, 50.361064502171104, 51.17114455359322, 52.46911668777466, 55.67717293330601, 52.95968035289219, 50.912407534463064, 49.24017415727888, 48.04677241189139, 50.515394415174214, 52.21774475915091, 46.72852543422154, 47.451600142887656, 46.58316911969866, 53.32747629710606, 55.781375067574636, 53.445116247449604, 50.49313933508736, 54.49546848024641, 52.77201993124825, 56.59594365528652, 52.37735530308315, 56.64363261631557, 47.221826689583914, 30.661323411124094, 28.342171055930002, 20.50605869293213, 8.703294447490148, 7.818310209683009, 8.117454477718898, 6.659495294094086, 14.198364155633108, 8.099075623920985, 2.320679873228073, 0.16814864506678923, 0.2071434147655964, 0.015474522053929312, 0.05899316444993019, 0.25059807300567627, 3.8941604580198015, 15.887099504470825, 35.37713875089373, 39.75004659380232, 40.36838068280901, 34.80973843165806, 26.8077551977975, 21.80658429009574, 28.24412328856332, 37.570789269038606, 44.07619653429304, 52.90084300722395, 38.953032629830496, 12.344657727650233, 0.1252313865614789, 0.10048626616064991, 0.038240808727485795, 0.07853128175650324, 0.03323722364647048, 0.02978249991844807, 0.05060593557677098, 0.08607173285314015, 0.01582951970132334, 0.019431451601641517, 0.029177636839449406, 0.04360791215939181, 0.09147103955703122, 0.05807467909263713, 0.06326034904590674, 0.029832094042961086, 0.025751876378698007, 0.02658677809605641, 0.029619322424488406, 0.10410275602979319, 0.012508916901424527, 0.036349209158548286, 0.03832305395709617, 0.025106618413701653, 0.056808291867907555, 0.04597259991403137, 0.042938394871141226, 0.10919589416256972, 0.057742753332214694, 0.014893249941191502, 0.04311822700713362, 0.04058530667264547, 0.038346334493585994, 0.04439833081726517, 0.006976305207769785, 0.11896966184888567, 0.12139883078634739, 0.045798280875065496, 0.009720633305343134, 0.02445936555575047, 0.028375365871137807, 0.015361040464735456, 0.019832484457375746, 0.005855618111257042, 0.044183754295642884, 0.03158907226419874, 0.004386481654364616, 0.03454485562230859, 0.02430607601335006, 0.022443261596241167, 0.0508461505440729, 0.03345597315845745, 0.08373331118907247, 0.1276456955820322, 7.28584543296269, 46.165947164808, 70.9586935043335, 65.12520136151994, 56.2174266406468, 48.29784904207502, 36.59569992337908, 24.357415642057145, 28.82808463914054, 34.63951798847744, 47.2907840864999, 43.04468434197562, 18.956591299601964, 4.695306863103594, 0.17979503369757108, 0.07161695563367435, 0.07428932509252004, 0.7624816883887563, 2.476519065243857, 5.731272850717817, 10.127790672438485, 9.978228960718427, 11.719082747186933, 10.4752596616745, 16.27083809035165, 13.796264954975673, 15.11303891454424, 6.6646013515336175, 10.5254100220544, 19.863402434757777, 33.57794788905552, 35.75170224053519, 48.39381061281477, 55.5861028943743, 59.217759541102815, 61.03679098401751, 63.81753649030413, 53.86128555025373, 54.664806502205984, 50.720658097948345, 52.72993469238281, 52.40558235985892, 52.786086559295654, 56.19070386886597, 58.4010682787214, 54.24448217664446, 51.95064558301653, 48.37745107923235, 49.90513065883091, 50.527949810028076, 56.175772190093994, 57.7942647252764, 58.00836999075753, 54.43388659613473, 59.03008869716099, 53.82747909000942, 58.448684283665244, 57.26650387900216, 55.7259875025068, 54.16203832626343, 54.28706073760986, 38.2967266355242, 39.12332255499703, 53.80240651539394, 53.93015956878662, 55.64718450818743, 56.717835903167725, 52.006248542240684, 52.609591892787385, 51.76083469390869, 50.56553609030587, 52.55115754263741, 54.66590779168265, 55.58091606412615, 55.16890525817871, 52.54818718773978, 51.06377056666783, 50.17251123700823, 51.82681826182774, 53.42183978216988, 49.99764592306954, 48.22296483176095, 50.00504575456892, 53.56088713237217, 58.11756787981306, 53.54085200173514, 51.36017377035958, 53.030882017953054, 53.86846651349749, 58.51357351030622, 55.85386214937483, 56.9523515020098, 50.17800726209368, 37.4764917918614, 30.9800511768886, 17.311742510114396, 9.319986156054906, 7.61462984766279, 11.16859781742096, 11.036602020263672, 9.485275983810425, 6.491100055830819, 7.765741007668631, 3.072127116577966, 0.35354711594326155, 0.02962913064818297, 0.07345184324575321, 0.40727056030716213, 4.109227180480957, 17.138527393341064, 33.275315625326975, 35.9209429877145, 37.071293694632395, 28.702021735055105, 27.196953330721172, 27.301367385046824, 32.52373940604073, 43.162171431950156, 50.66261632101876, 61.748349053519114, 46.90239020756313, 14.693426779338292, 0.3214983328112534, 0.07655737588980369, 0.0357709650083312, 0.03776862299335854, 0.04391928170142429, 0.053334012760647705, 0.033919239549764564, 0.023275330429896712, 0.018504984976191605, 0.031033419937427555, 0.045289542459483655, 0.01633443626841264, 0.06398497694837195, 0.048463138951254744, 0.013704506630477096, 0.08716519203569208, 0.016515961349276558, 0.006503390048497489, 0.03669350800503578, 0.07167328082557235, 0.050329317205718586, 0.03890000210542764, 0.040704165651862106, 0.02488804532081953, 0.0360487368889153, 0.03117294709331223, 0.03698018226506455, 0.039450982718595436, 0.08232106946940933, 0.08362082365368094, 0.14220948623759405, 0.10677530869309391, 0.18992815352976322, 0.16780413926712104, 0.08295187633484602, 0.2786751464009285, 0.1830119410795825, 0.2046634235552379, 0.1045455476269126, 0.12726578382509096, 0.196676374280027, 0.19504985798682484, 0.15013398815478596, 0.11838138555841786, 0.16469051848564828, 0.14507821016013622, 0.14146560829664978, 0.1472202366484063, 0.13059319742023945, 0.09450280187385422, 0.07301443921668188, 0.16695058292576245, 0.17945329632077897, 0.22565819269844464, 9.987226009368896, 61.347708974565776, 80.31921631949288, 74.31756387438092, 64.28247519901821, 57.118187631879536, 41.367410046713694, 27.940817049571447, 35.049385275159565, 49.84829786845616, 63.46717357635498, 58.61701829092843, 24.884207214627946, 7.187655661787305, 0.4596861962761198, 0.26644599118403023, 0.224659782701305, 0.5830137357115746, 1.5839457660913467, 8.747241803577968, 16.04723811149597, 18.486566509519303, 16.222042628696986, 16.769677059991018, 17.04507064819336, 17.066940103258403, 26.773841040475027, 19.337957075663976, 28.43289542198181, 37.59870713097708, 44.72226783207485, 44.42769200461251, 55.481251103537424, 59.28508758544922, 60.81844384329659, 62.06245626722063, 66.38071305411202, 54.97225039345877, 54.29775054114205, 53.27393000466483, 52.24864687238421, 54.973257882254465, 53.00744227000645, 58.47532367706299, 61.47620895930699, 57.56787504468645, 54.240205560411724, 50.44167055402483, 53.36867216655186, 52.78935916083199, 59.25568975721087, 59.752534593854634, 60.60819135393415, 56.677918502262656, 60.386919021606445, 57.00477566037859, 59.76711886269705, 59.33439895084926, 53.42851005281721, 54.576533113207134, 54.46500410352434, 44.07630770547049, 43.330682618277415, 56.66583558491298, 55.650345938546316, 56.89031451089041, 57.10710178102766, 53.138113566807334, 53.210284505571636, 52.3301978792463, 51.44005026136126, 53.46308428900582, 54.445170470646445, 57.09566157204764, 56.55341720581055, 55.28899097442627, 53.226525919778005, 52.64052874701363, 55.26850421088082, 57.506821223667686, 51.19296884536743, 52.39026853016445, 52.35316514968872, 56.64309760502407, 60.12444387163435, 54.70348364966256, 50.39029557364327, 54.71869673047747, 53.23605190004621, 61.50029836382185, 57.539338793073384, 61.345874650137766, 52.99590826034546, 37.09399693352835, 33.329921518053325, 30.17508499962943, 16.0965598991939, 14.938505377088275, 18.596594708306448, 15.07989774431501, 23.39139369555882, 17.04349340711321, 7.14481828042439, 1.8958429098129272, 0.44127241149544716, 0.14475321902760438, 0.3864616554762636, 0.6068426370620728, 5.492550117628915, 21.490173748561315, 50.39310959407261, 53.60725246156965, 53.09234925678798, 48.47130734579903, 38.745444774627686, 31.592632157461985, 39.372606549944194, 49.47385944638933, 59.175966126578196, 67.62756729125977, 55.29167297908238, 19.08293386868068, 0.77229976441179, 0.28181396797299385, 0.12114594078489713, 0.16570097926471913, 0.16706017990197453, 0.14593241789511271, 0.1399347518703767, 0.10950732816542898, 0.11271021701395512, 0.1115654945107443, 0.13360302948525973, 0.12552922272256442, 0.22817094357950346, 0.19074679245906218, 0.13813690548496588, 0.18769172924969876, 0.10279549046286515, 0.07124952213572604, 0.12065888834851128, 0.20947586532149995, 0.10384086186864547, 0.1363805854426963, 0.11338008035506521, 0.0967221474274993, 0.13759964145720005, 0.16620351587023052, 0.12427383794316224, 0.15657732955047063], [0.06924047494041068, 0.025644647489700998, 0.042111630484993966, 0.016846170416101813, 0.0426201721254204, 0.007570583988646311, 0.055314826113837104, 0.053098503433700116, 0.059785421937704086, 0.07142086579863514, 0.03836168634838291, 0.053425360537533245, 0.022412383163880025, 0.04961900639214686, 0.023381278584046022, 0.06357095523604325, 0.04658009910157748, 0.03660898289776274, 0.04341976118407079, 0.06297860095011336, 0.08380307137433972, 0.03890207163723452, 0.06841136621577398, 0.05928700403975589, 0.05493226807032313, 1.365587443113327, 18.132917097636632, 56.733330386025564, 61.973790305001394, 49.90105206625802, 37.0990343775068, 32.91749382019043, 15.811622960226876, 17.71306698662894, 32.26450559071132, 34.49083696092878, 38.74696295601981, 27.367887701307023, 9.402185950960432, 0.30853375419974327, 0.06108528468757868, 0.03555915351690991, 0.12395427509077958, 0.6835386987243379, 1.3909276319401604, 2.342281388384955, 3.600320271083287, 4.9285635352134705, 9.548724327768598, 9.952946203095571, 17.814171961375646, 11.37695518561772, 11.524541003363472, 18.86376162937709, 24.84654450416565, 48.61480154309954, 54.52671800340925, 57.98958900996617, 58.26870162146432, 56.17060273034232, 59.33694199153355, 56.79134784426008, 55.97048418862479, 59.17156791687012, 55.43207522800991, 52.57903718948364, 55.465968540736604, 52.098270484379356, 52.49877159936087, 55.38484832218715, 56.822350706372944, 52.88039445877075, 46.2697046143668, 42.17606919152396, 43.01120097296578, 47.930344922201975, 52.63314281191145, 55.09571293422154, 53.66556174414498, 55.15509918757847, 57.245819091796875, 54.544581821986604, 56.06883941377912, 53.25200843811035, 57.801508222307476, 53.13928781236921, 55.33867406845093, 37.321182182856965, 42.46813324519566, 55.81097091947283, 53.619783537728445, 55.19037519182478, 55.03871686117989, 55.90274967466082, 55.51949051448277, 54.36313656398228, 52.045523234776084, 49.96238728931972, 51.06872115816389, 52.77247156415667, 54.815394810267854, 51.97438062940325, 51.70680202756609, 48.3104704448155, 47.639000007084434, 47.96202870777675, 45.81009864807129, 46.931892258780344, 49.99172953196934, 52.00981296811785, 54.225885323115754, 54.34192371368408, 52.276120049612864, 48.69434452056885, 55.30839729309082, 57.223293031964985, 54.5524263381958, 51.51585858208792, 56.18447480882917, 50.884899616241455, 43.161090987069265, 24.69352432659694, 18.695752450398036, 15.455138683319092, 11.032043133463178, 6.897037701947348, 6.538379507405417, 6.943618859563555, 3.5376800894737244, 0.7887555956840515, 0.5326373417462621, 0.14517460284488543, 0.025284257185246264, 0.01998226936640484, 0.060198683690811904, 3.2803657140050615, 22.560114690235682, 43.33790874481201, 43.40950298309326, 38.5889504977635, 16.42026604924883, 34.63931996481759, 54.55722059522356, 38.47960669653756, 39.01125158582415, 47.66274894986834, 56.10779101508004, 29.933829648154124, 1.2665344668286187, 0.03862267127260566, 0.04128034705562251, 0.013936122014586414, 0.03212519296045814, 0.01265361619048885, 0.013646134807329093, 0.031392426030444245, 0.04019248239429934, 0.023059033822002153, 0.09163932302700621, 0.094478014989623, 0.03475146275013685, 0.014014326568160738, 0.03164163837209344, 0.009643401601351798, 0.04674629268369504, 0.061615037332688055, 0.05854102264025381, 0.012251446788598384, 0.06236114086849349, 0.09123969304242305, 0.03244834187041436, 0.007483386301568576, 0.056713500525802374, 0.02076481532172433, 0.03800057340413332, 0.02669620543851384, 0.03714919176750949, 0.02544218112182404, 0.022066998661362698, 0.041503768281212876, 0.05042794905602932, 0.07037658004888467, 0.049917198784117184, 0.040312243825090785, 0.08642034378967114, 0.14305806213191577, 0.05052654019423893, 0.049838105349668434, 0.046959885329540284, 0.013089224646267082, 0.12244543034051146, 0.06508735886641911, 0.07502595627946512, 0.007776282727718353, 0.047395718550043445, 0.07023179424660546, 0.018418395426124334, 0.02515724051876792, 0.05271464599562543, 0.0068458487928312805, 0.04866099637001753, 1.6579452753067017, 24.71841277394976, 68.4002764565604, 68.24483830588204, 58.26566525868007, 46.13890824999128, 40.84512438092913, 24.680562462125504, 22.17948716027396, 24.26596518925258, 31.30680411202567, 37.58923326219831, 26.030025959014893, 8.524499927248273, 0.38539269140788485, 0.08050405446972166, 0.11950554166521345, 0.6216066905430385, 1.8324838067804063, 7.224421186106546, 7.82207179069519, 9.140918919018336, 10.871824622154236, 15.643269845417567, 8.209319216864449, 14.028194955417089, 8.250183309827532, 10.878949131284442, 12.995512860161917, 24.923174449375697, 40.416424001966206, 52.93417004176548, 57.22160114560808, 60.43579265049526, 57.72108629771641, 60.42118058885847, 57.95573738643101, 58.05749722889492, 58.32709775652204, 55.756344182150706, 52.200144972120015, 54.616426195417134, 53.36686910901751, 53.9154953956604, 55.66332169941494, 59.42995057787214, 54.800793170928955, 49.43421997342791, 44.11163582120623, 45.70530939102173, 49.70266710008894, 55.8456563268389, 56.94631699153355, 55.880254881722585, 56.73644665309361, 59.2396046774728, 57.39963831220354, 57.405179500579834, 55.14887012754168, 57.92160088675362, 51.97037499291556, 54.56605175563267, 42.4714857510158, 45.21077830450875, 55.715586049216135, 55.33755193437849, 55.584615979875835, 57.33909865788051, 56.08090843473162, 55.57723004477364, 55.11820077896118, 53.49818658828735, 51.45760488510132, 51.86976507731846, 52.43338210242135, 56.971736976078574, 54.06995732443673, 53.39758709498814, 49.87215450831822, 50.77553497041975, 49.73870393208095, 47.827699184417725, 49.30550112043108, 52.018616335732595, 52.23714412961687, 55.60423421859741, 53.472137791769846, 52.636801038469585, 49.548455306461875, 55.308195795331685, 58.743225370134624, 57.7592180115836, 55.14891529083252, 60.47974695478167, 53.0785744530814, 40.93462412697928, 28.121002946581157, 19.37419366836548, 11.800665889467512, 10.92149121420724, 8.237056425639562, 11.333464673587255, 11.793990407671247, 9.215344548225403, 3.8572737744876315, 2.5049130959170203, 0.7793800330587796, 0.08334505345140185, 0.06197994668036699, 0.09110732443098511, 3.544542738369533, 22.858159405844553, 47.666271686553955, 45.205535888671875, 41.663382462092805, 21.23015652384077, 28.452082872390747, 55.17130238669259, 45.53542940957205, 44.73761987686157, 54.33502762658255, 63.25612899235317, 37.10032674244472, 1.7386236318520136, 0.03257615751187716, 0.036559086825166426, 0.04302344584305372, 0.053261110958244116, 0.03663312856640134, 0.05044128566182085, 0.0061809014379312945, 0.011073141042808337, 0.03789653702239905, 0.04506934427523187, 0.07731378637254238, 0.02323787529686732, 0.03211716928386262, 0.03206319521580424, 0.038477047479578426, 0.023337531735056212, 0.10223772789218596, 0.027964553629447306, 0.032711196158613474, 0.02440517096381102, 0.056531883842710934, 0.0937208513330136, 0.030672680187438215, 0.023880944986428534, 0.054331859573721886, 0.043924771049725156, 0.0186994005260723, 0.13287070021033287, 0.10974385190222945, 0.0862599177552121, 0.16075352260044642, 0.13366021641663142, 0.13798054387526854, 0.10047545031245265, 0.14292125590145588, 0.20786420894520624, 0.17313636599906854, 0.15352797960596426, 0.15587672857301577, 0.07843324023165874, 0.17968619668057986, 0.21228713089866297, 0.1737077331968716, 0.1681774692343814, 0.13515232849333966, 0.10796749472085919, 0.14277652438197816, 0.1979542864220483, 0.12687098500984056, 0.18762756697833538, 0.1349935648696763, 0.15055811325354235, 2.70223976458822, 34.50361122403826, 78.06448418753487, 78.82479081835065, 66.60194369724819, 52.75178330285208, 45.3188019480024, 26.168515716280254, 27.197090557643346, 44.66982977730887, 43.83188744953701, 49.3117162840707, 34.739742279052734, 11.157285281590053, 0.6974910614745957, 0.1883018815091678, 0.18642004605914864, 0.42494216348443714, 1.954005628824234, 7.977399638720921, 12.205199565206255, 12.189404572759356, 14.770315544945852, 20.508500984736852, 19.683336394173757, 29.789331436157227, 21.02750883783613, 20.3556684085301, 25.896406888961792, 29.013309717178345, 54.1535267829895, 61.62765189579555, 62.67670481545584, 62.76757335662842, 60.75543063027518, 64.59739535195487, 61.63380799974714, 60.89435291290283, 61.3017257962908, 57.481352601732524, 53.468232904161724, 54.8049099785941, 53.201415130070274, 54.30195072719029, 56.93106916972569, 62.82390240260533, 58.447732380458284, 50.71501268659319, 46.41874347414289, 47.58863946369716, 52.78994975771223, 57.16954524176461, 61.18807411193848, 57.76502323150635, 59.48446614401681, 60.53658321925572, 59.37627574375698, 59.74486378261021, 57.1224434035165, 58.90927342006138, 51.9224636895316, 55.420478684561594, 45.8970935685294, 47.18818003790719, 57.234114851270405, 58.131036962781636, 59.12889208112444, 58.55766677856445, 58.48398808070591, 58.83420508248465, 55.84919990812029, 55.63840198516846, 51.064548764910015, 52.21364879608154, 53.568220955984934, 57.65862546648298, 55.84412772314889, 56.57266024180821, 52.292764459337505, 52.88655751092093, 51.28002977371216, 50.321998255593435, 52.464312008449006, 54.407962867191856, 54.21160677501133, 56.4033465385437, 54.499373367854524, 52.022423948560444, 48.46293476649693, 56.665363107408794, 61.67421872275216, 59.45044081551688, 56.559007031576975, 62.4948913029262, 55.236695357731406, 48.734070846012656, 30.485353333609446, 25.533321823392594, 22.479788303375244, 22.519882883344376, 15.38567406790597, 17.12811378070286, 15.645580121449061, 12.816314475876943, 3.3062822776181355, 1.6360296798603875, 0.5272834290351186, 0.2320769711264542, 0.18683606944978237, 0.33742954794849667, 4.528862765857151, 29.60838644845145, 55.714967659541536, 58.20133188792637, 51.50133684703282, 25.053828375680105, 45.64179590770176, 66.18263380868095, 52.55138683319092, 52.978179931640625, 62.95308331080845, 71.64854540143693, 43.97409970419747, 2.6634846670286993, 0.09895905346742698, 0.09133191952215773, 0.12890311596649034, 0.19753124697932176, 0.13665061523871763, 0.15137361735105515, 0.09290388159986053, 0.09371911428336586, 0.10652936010488442, 0.14750918400074753, 0.22133722741689, 0.11534931111548628, 0.09841026112969432, 0.2637109522308622, 0.09730688855051994, 0.059301660396158695, 0.15545322772647652, 0.13439493413482392, 0.12176886307341711, 0.19907697689320358, 0.16046202395643505, 0.20167632241334232, 0.053739478146391254, 0.11092205332326037, 0.17419056514544146, 0.16445548752588884, 0.07732460900608983], [0.03334857802838087, 0.10558414046785661, 0.0275624554737338, 0.040254412285451374, 0.021021868135514002, 0.044017876232309, 0.08006554442856993, 0.050984005111136606, 0.03161769965663552, 0.039830687522355995, 0.023083503491112163, 0.016563977879871215, 0.04012045590206981, 0.028545920737087727, 0.03129641332530549, 0.046721366699784994, 0.019856036407873034, 0.028547634038009813, 0.04019760533369013, 0.016276803200266192, 0.0152173878159374, 0.040623742288776805, 0.053610960221184153, 0.020640775727640306, 0.06201501337013074, 5.252367828573499, 43.60355574744088, 62.64018508366176, 56.624966280800955, 45.07765776770455, 44.417228017534526, 29.94380031313215, 21.61284245763506, 28.431026356560842, 48.43967914581299, 64.42947128840855, 37.76357398714338, 12.121472903660365, 0.7854885852762631, 0.04931075132584997, 0.05621465515079243, 0.13567055282848223, 0.37908565412674633, 1.2034272359950202, 5.598502329417637, 5.758566243307931, 10.838569675173078, 8.812088472502571, 12.503871355737958, 5.174105056694575, 16.30001531328474, 22.69256819997515, 40.29960741315569, 26.753967455455236, 45.43542398725237, 47.223952838352744, 59.512522969927105, 55.200988565172466, 54.9776109286717, 51.54212972096035, 53.91945586885725, 53.46536677224295, 53.6442585672651, 54.65603787558419, 54.263249261038645, 50.38903100149972, 54.43601969310215, 52.718779359545024, 52.14277369635445, 53.14096927642822, 55.22957345417568, 49.09217752729143, 49.428685733250205, 42.41064037595476, 41.0350638117109, 40.98105893816267, 50.96124989645821, 54.291462421417236, 55.856304441179546, 52.12480912889753, 53.86940452030727, 52.544157232557026, 57.518254484449116, 54.85209172112601, 57.172140393938335, 50.79085922241211, 55.39057016372681, 38.970524719783235, 45.66722284044538, 56.67784902027675, 50.186063698359895, 51.381754875183105, 51.92174802507673, 55.46577051707676, 53.605154105595176, 54.83289384841919, 52.903757776532856, 53.00807803017752, 50.2926664352417, 51.396578856876914, 53.45992980684553, 54.22584710802351, 52.00865261895316, 51.52461331231253, 49.96991218839373, 48.24144009181431, 47.98982845033918, 48.64694390978132, 49.582407678876606, 53.70546872275216, 54.73351723807198, 50.88960007258824, 50.74345513752529, 51.8441435950143, 55.360804080963135, 56.25414439610073, 54.724182333265034, 53.066227504185264, 55.76884746551514, 55.86993680681501, 51.96649789810181, 43.92703608104161, 33.42711639404297, 16.640595163617814, 15.278677020754133, 9.601466366222926, 7.955154112407139, 3.6191214450768063, 12.828044772148132, 10.21613962309701, 1.894428300006049, 0.635500753564494, 0.15433188075465815, 0.07059410480516297, 0.09171552929495062, 0.10032814035990409, 2.445137743438993, 17.858979157039098, 43.232032094682964, 31.78500345775059, 41.846370220184326, 81.37655844007219, 60.20053359440395, 25.795694487435476, 26.994571413312638, 49.229390553065706, 53.02831813267299, 45.730541774204795, 5.8055794920240125, 0.10323646358613457, 0.09295207115688495, 0.02847210630508406, 0.008897071604483893, 0.0008387397870787286, 0.030865183964903866, 0.02176750178581902, 0.030815813756947006, 0.0283379175234586, 0.06356794254056045, 0.012735678215644189, 0.03323809556396944, 0.051122887658753564, 0.020116203697398305, 0.04976835873510156, 0.014355785745595182, 0.01958583019274686, 0.03376036736049822, 0.120691661589912, 0.01867653559228139, 0.02782028860279492, 0.001756668957698691, 0.042830304242670536, 0.02070772847426789, 0.05340391883094396, 0.04388109375057476, 0.07810760449085917, 0.06581343204847404, 0.03920869143413646, 0.032391504384577274, 0.017823818938008378, 0.05187438894063234, 0.010682738286310008, 0.06484941020607948, 0.08168765024415084, 0.04492534218089921, 0.025132938787075024, 0.0662604102066585, 0.05097364727407694, 0.07117919876639332, 0.08517113367893867, 0.022858175582119396, 0.004640929741851453, 0.02707938094889479, 0.025717001375077025, 0.0087262648324083, 0.020066039603469626, 0.004632756787551833, 0.03821752819099596, 0.04460012034646102, 0.017689881214339818, 0.029645167823348726, 7.5999622004372736, 53.269906997680664, 71.53255912235805, 65.56773212977818, 51.068547453199116, 49.92602389199393, 40.24167333330427, 19.855797631399973, 23.69002727099827, 47.1990852355957, 48.71604027066912, 37.57560089656285, 11.892540182386126, 0.8907245897821018, 0.016368371501032795, 0.06981408130377531, 0.15482552855142526, 1.9436423906258173, 4.830338154520307, 7.767026424407959, 12.166046466146197, 10.470902272633143, 10.283672639301844, 12.680399026189532, 11.787454758371625, 11.268829924719673, 16.193796464375087, 31.529542514256068, 29.172439098358154, 43.8582558631897, 49.230220862797324, 61.23444638933454, 58.097470215388704, 55.89682286126273, 53.78427866527012, 56.153159277779714, 55.10797650473458, 54.87390559060233, 57.77071728025164, 55.44239330291748, 53.07026093346732, 53.06759977340698, 52.48195348467146, 51.94363137653896, 54.18336929593767, 56.62547697339739, 53.14617000307356, 50.87712805611746, 44.545641149793354, 43.48874371392386, 43.609899452754426, 54.13441923686436, 56.631799834115164, 58.17857306344168, 54.8780779838562, 56.35565062931606, 56.0471818787711, 59.45061452048165, 55.36263493129185, 58.05412040437971, 51.96174880436489, 56.02058070046561, 41.6734538759504, 47.41068567548479, 58.16161945887974, 52.71297761372158, 54.057349818093435, 53.92936747414725, 57.254205567496165, 54.87456914356777, 56.00951222011021, 54.094342027391704, 53.14979001453945, 50.22032526561192, 50.45841918672834, 54.24724408558437, 56.25397416523525, 54.42442314965384, 54.259674412863596, 51.04192543029785, 50.29282971790859, 51.105084555489675, 50.506785597120015, 49.386822836739675, 55.62003442219326, 57.018282958439414, 50.879935128348215, 50.646896021706716, 50.89256695338658, 55.55659736905779, 58.96409470694405, 54.896449020930696, 55.16570561272757, 57.06948075975691, 57.29730176925659, 53.52213702883039, 46.44008834021432, 30.968204498291016, 15.782350199563162, 9.729567698069982, 8.069815891129629, 13.57115808555058, 8.518699049949646, 11.63467081955501, 7.662793023245675, 4.176034109933036, 2.329705148935318, 0.3791314416698047, 0.1447029395827225, 0.0186885541437992, 0.09283427069229738, 2.992982574871608, 19.780977691922867, 44.84559835706438, 31.908973217010498, 29.597460406167166, 66.41582924979073, 62.73495156424386, 34.16575506755284, 31.954331057412283, 54.54005854470389, 59.459007944379536, 52.705435344151084, 8.116968972342354, 0.15159203777355806, 0.008432341273874044, 0.02247853354284806, 0.033900966601712365, 0.0872770349628159, 0.07117578573524952, 0.052156221853303056, 0.011511963210068643, 0.026647454393761497, 0.07054648521755423, 0.03309677368296044, 0.02557444795300918, 0.02103913515540106, 0.023383339634165168, 0.04324408168239253, 0.036255951305585246, 0.026337810027013932, 0.025874248472973704, 0.11415192750947815, 0.04549774414460574, 0.03327182214707136, 0.010887313201757414, 0.017056696083662764, 0.028329020233026574, 0.034183742678059, 0.03604346127914531, 0.04962457377197487, 0.23321321872728212, 0.23829303043229239, 0.1194597269807543, 0.13690871638911112, 0.13981934663440498, 0.09697135976914849, 0.20300406616713318, 0.2348945742206914, 0.09360547323844262, 0.1151192741734641, 0.20120438773717197, 0.06458920559712819, 0.2602744166340147, 0.16001614502498082, 0.1103785399879728, 0.10318013160888638, 0.11802602319845132, 0.11807972245982715, 0.09320669820798294, 0.11691184155642986, 0.09464211189853293, 0.15360035215105328, 0.14683605012084755, 0.08074261381157807, 0.2092878296971321, 10.364465423992701, 63.63137340545654, 79.92960303170341, 72.45676680973598, 60.12036527906145, 57.47425501687186, 42.96603768212454, 31.577068192618235, 39.37726184300014, 63.5484744480678, 78.57710143498012, 47.00653328214373, 15.87408379146031, 1.3433647155761719, 0.29281874746084213, 0.15457733401230403, 0.29261673401509014, 1.15837924182415, 5.536659453596387, 16.64163739340646, 16.151631321225846, 17.99013682774135, 17.35694749014718, 19.59562233516148, 18.302574736731394, 23.250822952815465, 32.18791907174246, 48.8554801940918, 31.1426841872079, 46.649322918483186, 52.12504884174892, 63.530700956072124, 60.677694184439524, 59.627251625061035, 55.92346920285906, 58.934933117457796, 57.27394887379238, 57.47327184677124, 59.45023931775774, 56.55986166000366, 53.786099093300955, 54.856684480394634, 52.4215076310294, 53.17987224033901, 56.05913972854614, 60.398279326302664, 54.68414681298392, 53.8264924458095, 47.13124997275216, 46.36920281818935, 46.32157639094761, 55.21912336349487, 58.466763496398926, 61.18551022665841, 55.840893336704795, 57.84295770100185, 57.064248766217915, 61.10654394967215, 58.05478048324585, 59.63046169281006, 52.002503463200156, 55.0726066998073, 44.65698603221348, 48.94144678115845, 57.81772879191807, 55.064119475228445, 57.02478299822126, 55.85998351233346, 59.90233080727713, 58.0482839175633, 57.31052419117519, 56.42677933829171, 53.877408845084055, 51.969951152801514, 51.37122140611921, 56.03661366871425, 57.09413296835763, 56.111595153808594, 56.18740347453526, 53.599091802324565, 52.69637836728777, 53.40721729823521, 52.566999435424805, 53.272429193769185, 57.20038134711129, 60.31557491847447, 52.17407533100673, 51.58144957678658, 51.2484050478254, 58.175369943891255, 61.491300446646555, 58.38736643110003, 57.39450011934553, 60.04507459912981, 61.09625366755894, 55.98566252844674, 48.08489717755999, 38.121340206691194, 21.407677786690847, 24.331101076943533, 21.366912705557688, 14.551156333514623, 10.944077202251979, 26.294985089983257, 20.30201963015965, 4.072584118161883, 1.7188279969351632, 0.41282141102211817, 0.23985376954078674, 0.21974993044776575, 0.31333428089107784, 3.8494435889380316, 25.19789579936436, 56.648583207811626, 43.52711514064244, 51.62057488305228, 88.68687629699707, 67.09233365740094, 38.997372559138704, 37.360328333718435, 64.10873549325126, 65.39824472154889, 60.680952889578684, 10.655890243394033, 0.34669708779879976, 0.11603203948054995, 0.08549543270575148, 0.19427377677389554, 0.16407147741743497, 0.13209035779748643, 0.12853598780930042, 0.131987261186753, 0.12847653457096644, 0.1728252712637186, 0.08895003090479545, 0.09934452921152115, 0.09695847438914434, 0.2203512346105916, 0.14561270576502594, 0.12275387878928866, 0.10805307155741112, 0.10470087786338159, 0.3053566361112254, 0.10236414575151034, 0.09296007787010499, 0.06361056132508175, 0.2227559627166816, 0.0983365247292178, 0.14027894554393633, 0.11861782787101609, 0.20871483401528426], [0.012512851556363915, 0.01092187438293227, 0.05656569524269019, 0.0036915409312184367, 0.06117923464626074, 0.009848963785251337, 0.01793566525780729, 0.06036963380341019, 0.031221299498741115, 0.043133592432630916, 0.04228346947846668, 0.016675293246018033, 0.019178495443026935, 0.03134990224082555, 0.007710281626454422, 0.00733031049769904, 0.02321521901259465, 0.017239973481212343, 0.07987731881439686, 0.05195997595520956, 0.003046759212988296, 0.02882472738357527, 0.0249538767883288, 0.02238336391746998, 0.48229970570121494, 23.82571690423148, 57.009632451193674, 63.31123515537807, 50.20677627835955, 40.37293522698538, 29.547044277191162, 11.629314626966204, 24.780527932303293, 35.88244996752058, 34.14716168812343, 37.224404198782786, 15.020961386816841, 1.7368286081722804, 0.049793864866452556, 0.03375456588608878, 0.05231754694666181, 0.06941967603883573, 3.053507898535047, 3.2453502672059193, 7.140184700489044, 5.2162376301629205, 8.279280628476824, 9.599947316305977, 18.538488660539898, 5.487668573856354, 20.509847198213848, 34.98101500102452, 42.71416548320225, 44.870097705296104, 55.771272386823384, 54.41696078436715, 58.96224648611886, 54.1933399609157, 51.25375863483974, 48.18540634427752, 49.79955972943987, 49.2868834223066, 50.297036852155415, 52.53250510351998, 56.03928872517177, 52.04510634286063, 53.66930682318551, 51.45739296504429, 52.09876728057861, 52.6429397719247, 54.89635174615042, 51.081742082323345, 47.33129555838448, 43.49923549379621, 42.21050793784005, 40.052876881190706, 43.88418654033116, 47.56941032409668, 50.380224159785676, 50.84396777834211, 51.673551423209055, 49.182552746364046, 52.4375718661717, 54.48795052937099, 54.88481426239014, 50.65829106739589, 55.82027803148542, 35.4228961127145, 45.795858315059114, 56.8944764818464, 50.46903256007603, 51.10258667809622, 50.46187938962664, 52.59324278150286, 51.856688567570274, 52.842926297869, 52.111708300454275, 52.46489565713065, 50.49731867653983, 49.98764746529715, 52.246520723615376, 54.165269238608225, 53.34576742989676, 52.27605751582554, 52.501262528555735, 52.026547704424175, 51.43047564370291, 51.65066753114973, 51.38940484183175, 52.497694628579275, 53.18562534877232, 49.75437906810215, 49.84477513177054, 50.05038969857352, 52.98674011230469, 53.195509161267964, 50.30511065891811, 51.83310638155256, 58.125787598746165, 54.89894689832415, 56.894149916512625, 59.19342694963728, 51.602547781808035, 39.231210708618164, 29.03983793939863, 10.740733827863421, 15.972458124160767, 13.99531260558537, 7.138376866068159, 5.421481771128518, 6.781034486634391, 2.3780035972595215, 0.1271564175507852, 0.08319859845297677, 0.023773110504927378, 0.02801959469382252, 0.48228010960987633, 6.964300606931959, 30.42165572302682, 47.77096019472395, 58.642476490565706, 78.52614334651402, 75.52366692679269, 32.565949712480815, 30.441742965153285, 40.3401814188276, 49.47923387799944, 46.52850416728428, 14.481254850115095, 0.49116642134530203, 0.004270941135473549, 0.10200102095093046, 0.029898162997726883, 0.026666617919025675, 0.015373276147459234, 0.031666045276714225, 0.04152240763817515, 0.06521324068307877, 0.027402395848184824, 0.06812730431556702, 0.09522870542215449, 0.07732471078634262, 0.032675576462809525, 0.013391059074950005, 0.005064873756574733, 0.0483428720118744, 0.05127369545932327, 0.01055416523013264, 0.039466524563197575, 0.008371909248775669, 0.015005681497443999, 0.06331083883664437, 0.04849786637350917, 0.030440722991313254, 0.0033799143940476434, 0.033937519283166954, 0.017801362821566205, 0.025542110670357943, 0.034427024623645205, 0.03954101074486971, 0.08916231737072979, 0.01850955660587975, 0.03259615054620164, 0.034065782757742066, 0.031101775555206195, 0.056870608524020226, 0.028895912492381673, 0.01999126504441457, 0.01864155032671988, 0.03561084092195545, 0.058810007492346425, 0.05162776521007929, 0.032672061651412926, 0.04210580865453396, 0.0044822628094282535, 0.02408528241461941, 0.06567465806646006, 0.015325096768460103, 0.0390247236272054, 0.09076060660715614, 0.7566241941281727, 29.37086922781808, 66.97220625196184, 69.40239429473877, 58.30001367841448, 47.263168471200125, 36.984639235905235, 19.767315796443395, 28.982162679944718, 40.89070456368582, 38.34554467882429, 39.88351801463536, 16.699484620775493, 1.8925994038581848, 0.25614441824810846, 0.02901064258600984, 0.2895280697516033, 1.0499890808548247, 5.156308114528656, 8.532856873103551, 12.385441916329519, 9.289736304964338, 11.772146139826093, 11.375019243785314, 8.843852162361145, 7.2050847836903165, 14.664409364972796, 28.97920969554356, 38.21364007677351, 45.79805047171456, 55.668070793151855, 56.29996081760952, 59.598395756312776, 57.032964502062114, 53.56405898502895, 50.362686906542095, 50.96486643382481, 50.32884917940412, 52.957411766052246, 54.919600418635774, 56.50675310407366, 51.96677930014474, 53.637491021837505, 50.471196923937114, 53.220821448734824, 55.453440938677105, 56.58094596862793, 52.446399552481516, 50.2462420463562, 45.643255029405864, 43.27247755868094, 40.95589256286621, 45.87215648378645, 49.90492221287319, 52.81114871161324, 53.03903225490025, 52.807928221566335, 50.78456762858799, 55.01741368430001, 55.82242155075073, 54.47507899148123, 51.536647592272075, 55.07050486973354, 37.94254568644932, 46.14824315479824, 57.968216351100374, 52.084113529750276, 51.933608600071494, 54.12282269341605, 53.96179819107056, 53.89860779898507, 55.58217021397182, 54.540072441101074, 53.46752766200474, 50.58010298865182, 50.27441699164254, 51.399427618299214, 55.35503012793404, 54.1504556792123, 55.74088791438511, 53.66133376530239, 54.43794434411185, 51.64874982833862, 52.633559703826904, 53.07553461619786, 53.90598331178938, 55.075035095214844, 50.61799151556832, 51.07365437916347, 48.930503368377686, 54.24992956433977, 55.61558757509504, 53.449823651994976, 54.680714402879985, 59.44522966657366, 56.370540618896484, 56.83853653499058, 57.99553666796003, 53.31895433153425, 36.33764730181013, 23.265257835388184, 10.162130406924657, 7.371429869106837, 10.189307417188372, 11.422299998147146, 10.78610382761274, 7.8200272832598, 4.81965616771153, 1.201618098786899, 0.3167397124426705, 0.030616894430880035, 0.014397615733157312, 0.5964289701410702, 6.944947702544076, 33.63598966598511, 42.54932641983032, 49.36069066183907, 76.71508148738316, 74.53044973100934, 36.12682506016323, 32.8368877683367, 49.56927210944039, 53.40589019230434, 56.83882141113281, 20.16337874957493, 0.6217812640326363, 0.05223274024735604, 0.01677299041434058, 0.014994553523138165, 0.028760334410305535, 0.036471664373363764, 0.018451007515458123, 0.04618581597294126, 0.0386328391198601, 0.054900811186858585, 0.020904498540663292, 0.003644363663624972, 0.057579436738576205, 0.01667622962434377, 0.0251482889455344, 0.023358596854710152, 0.018570439856765524, 0.02179202573773052, 0.04775836159076009, 0.019546183391607234, 0.049016080530626435, 0.0741251806861588, 0.011435245496353932, 0.014551480333986027, 0.027571792115590403, 0.04404048162645527, 0.025833724665322473, 0.11690257276807513, 0.16041574786816323, 0.13502016344240733, 0.17159868351050786, 0.1257825062743255, 0.12281919457018375, 0.1151646545955113, 0.12906084821692534, 0.09672999807766505, 0.12477283259587628, 0.0967213399708271, 0.08960649317928723, 0.1327405571937561, 0.1278531373079334, 0.13150362856686115, 0.12660430717681134, 0.09411588763552052, 0.18798712268471718, 0.19210273612822804, 0.13104712377701486, 0.1070963100397161, 0.12522145280880587, 0.08933236503175326, 0.11954187043011189, 1.3254635504313876, 36.98181479317801, 74.21780858721051, 78.05259581974575, 67.14780807495117, 54.100036076136995, 42.11935452052525, 19.369461945125035, 36.40425968170166, 48.24846472058977, 43.66243825639997, 48.458088397979736, 19.55615656716483, 2.4582761355808804, 0.3471059187182358, 0.207368118422372, 0.3559821881353855, 1.0797054405723299, 7.059144386223384, 11.780255556106567, 19.478576455797466, 16.429654802594865, 20.83032591002328, 18.21901570047651, 27.22652312687465, 15.951297385351998, 27.404195513044083, 41.80690792628697, 46.582265853881836, 45.652457918439595, 56.54904678889683, 58.77859170096261, 63.708123207092285, 58.384371757507324, 56.351495606558665, 53.10203504562378, 53.82634653363909, 52.700300625392366, 55.28739288875035, 58.27456242697579, 58.071866103581016, 53.618206296648296, 53.1638879094805, 50.40601587295532, 54.96787997654506, 56.33800220489502, 58.14223745891026, 55.5914877482823, 52.705223424094065, 48.790264402117046, 46.488013539995464, 44.01419081006731, 48.9913661139352, 52.45351798193795, 54.914243357522146, 55.48253999437605, 55.30988073348999, 53.231104782649446, 56.53197853905814, 59.53743226187569, 56.751253264290945, 52.642651421683176, 55.57992247172764, 41.141162804194856, 50.49200330461775, 62.33837618146624, 54.9707669530596, 55.48968274252755, 56.345391614096506, 55.228222029549734, 56.43307440621512, 57.19333587374006, 56.09233822141375, 55.41225896562849, 50.92946188790457, 50.417765276772634, 53.54559414727347, 57.18864931379046, 55.28406817572457, 56.06358657564436, 55.96938637324742, 56.40851599829537, 54.33970029013497, 55.696471554892405, 55.542468207223074, 56.26963540485927, 56.24131107330322, 51.931305272238596, 51.10212809698922, 50.27590390614101, 55.781124932425364, 57.032613618033274, 55.634267807006836, 56.21296937125069, 62.407059124537874, 59.22329030718122, 58.11887066704886, 60.28670515332903, 56.21683256966727, 43.122049059186665, 34.42483949661255, 17.20044800213405, 23.46629180227007, 25.41200453894479, 15.508928162711006, 14.82728556224278, 15.724266733442034, 6.0372693453516275, 0.942735818879945, 0.37085700567279545, 0.10475256187575203, 0.2378253840974399, 0.6783271698015076, 9.591674617358617, 39.35172373907906, 64.07220881325858, 66.78418104989188, 81.75586060115269, 76.81452410561698, 42.23839453288487, 42.83829157693045, 57.30991622379848, 62.38916751316616, 64.85830020904541, 27.803069012505667, 0.8591547438076564, 0.11501814531428473, 0.18327929744763033, 0.10420191035206829, 0.08430442054356847, 0.1278020164796284, 0.09522717193301235, 0.13411947605865343, 0.17843887289719923, 0.1112018743796008, 0.17593889204519136, 0.12143920361995697, 0.15484288547720226, 0.19060995908720152, 0.08808041363954544, 0.06941715867391654, 0.09325585807008402, 0.10822831679667745, 0.10513747443578073, 0.07851241169763462, 0.10233777788068567, 0.14138279988297395, 0.11172915037189211, 0.13433378455894335, 0.09049332487796034, 0.07336201199463435, 0.12521453175161565], [0.03676497809855001, 0.037958416023424695, 0.008561708216023232, 0.016997923076684986, 0.0558886530010828, 0.07287635734038693, 0.03921668118398104, 0.04373752252597894, 0.04231411890525903, 0.014531609435964907, 0.03503863573340433, 0.04163880692794919, 0.047450907195785215, 0.017882822646892498, 0.06309562788477965, 0.04758509767374822, 0.08311625822846379, 0.008432805222193045, 0.03238173348030873, 0.02935975224577955, 0.01205597017958228, 0.0197558218746313, 0.023040218045935035, 0.025315802278263227, 1.7748418769666126, 46.408977781023296, 69.79756614140102, 58.38952037266323, 46.4350265775408, 42.769170897347585, 31.44335011073521, 20.434389761516027, 22.75413966178894, 31.969186305999756, 57.524796213422505, 21.965123074395315, 5.62658303976059, 0.22468545846641064, 0.020474940072745085, 0.013596847719912018, 0.36572690095220295, 0.46517245045730043, 4.453240743705204, 4.602962698255267, 5.272897584097726, 12.20930768762316, 9.596915296145848, 10.667517185211182, 12.042497072901044, 29.71098702294486, 37.877350739070344, 50.782552650996614, 60.44472803388323, 56.95253562927246, 54.41245487758091, 52.08887651988438, 54.10457672391619, 54.625448431287495, 50.14490256990705, 45.24788515908377, 45.477662086486816, 45.030771323612754, 50.93045548030308, 51.610308919634136, 55.20562301363264, 51.40439905439104, 53.14979696273804, 51.391537938799175, 51.36018419265747, 52.39508363178798, 52.893189566476, 49.61365025384085, 47.186446462358745, 43.84746183667864, 39.60034418106079, 40.48760829653059, 41.277489934648784, 40.614089829581125, 43.728949887411936, 42.99980245317732, 45.70738690240042, 48.49421903065273, 57.10094220297677, 54.37707117625645, 54.504459449223106, 47.54002291815621, 56.439511912209646, 27.730343954903738, 43.35671751839774, 55.78829894747053, 49.13882425853184, 48.40124865940639, 45.98660026277815, 51.88868849618094, 47.994914531707764, 51.70588139125279, 51.0362800189427, 53.146486146109446, 49.76479441779, 53.084758349827354, 48.48577002116612, 51.0300474848066, 51.06969390596662, 53.55917092732021, 52.16475084849766, 53.29563617706299, 51.84011363983154, 53.2631915637425, 50.96869836534773, 52.781789098467144, 52.26775789260864, 49.87700435093471, 49.052062102726524, 51.382560866219656, 52.58796909877232, 54.73622008732387, 47.807445185525076, 52.29886845179966, 56.82479994637625, 54.0828149659293, 57.021850858415874, 59.26893302372524, 57.093660490853445, 52.34039783477783, 39.22043057850429, 30.806245463235037, 28.754768984658376, 9.32992034299033, 11.377697774342128, 5.459711628300803, 5.320889660290309, 5.722750450883593, 1.3121281117200851, 0.2586922901017325, 0.07628559547343425, 0.07274969520845584, 0.026111315037789087, 0.29721473157405853, 9.016485367502485, 36.17290551321847, 42.162468092782156, 52.575128827776226, 32.517423493521555, 19.75316231591361, 32.715732029506135, 40.317995820726665, 49.56927558353969, 49.60169587816511, 37.39871365683419, 3.940233962876456, 0.11649626599890844, 0.05113394438688244, 0.07897505722939968, 0.005887854037739868, 0.0474765185000641, 0.04736944567412138, 0.04277633356728724, 0.027202026153515493, 0.04074353764631918, 0.026079361127423387, 0.04105793345453484, 0.03583455052492874, 0.08180127093302351, 0.03558413717629654, 0.026892201974987984, 0.011378325738145836, 0.007382465243738676, 0.06661166742976223, 0.07572091184556484, 0.043536696516509564, 0.017916182821084346, 0.03254594913284693, 0.04552169982343912, 0.0414121830170708, 0.00786798249464482, 0.06200453678944281, 0.056316638964095285, 0.013903886512187975, 0.03198914329654404, 0.07672204955347947, 0.05191604081275208, 0.030282960206802403, 0.02439716085791588, 0.05133891624531575, 0.08023967687040567, 0.04519079186554466, 0.030165499009724175, 0.012955391247357641, 0.04556012526154518, 0.014314943026485187, 0.059314905399722714, 0.04738137771242431, 0.06361888016441039, 0.04305862109842045, 0.031314659131956954, 0.015542906509446246, 0.025415825125362192, 0.019122938692037548, 0.012652246397919953, 0.1132349959973778, 3.4903061858245303, 53.6789231300354, 76.15300696236747, 67.34197548457554, 53.85857922690255, 47.57786628178188, 33.75024931771414, 17.949045181274414, 22.56921509334019, 30.357061794825963, 45.6072598866054, 22.59616368157523, 5.644914124693189, 0.20039918380124228, 0.05049184669873544, 0.042776723724922965, 1.0543390874351775, 2.7635072427136556, 6.381971648761204, 10.797347749982562, 11.126566427094595, 16.956592287336075, 7.077839383057185, 9.56493968623025, 11.76653460093907, 23.519207545689174, 35.96151351928711, 49.789272921425955, 57.84857531956264, 56.664685658046174, 53.181647505079, 53.82517923627581, 56.71216269901821, 57.14058167593819, 52.389115129198345, 46.90019110270909, 46.94905430930001, 47.66555602209908, 51.381376198359895, 54.282721587589805, 56.80443825040545, 53.505940777914866, 52.41703993933541, 52.40507514136178, 51.532892090933665, 53.86986310141427, 56.16885873249599, 51.02798386982509, 48.74282905033657, 44.473077637808665, 42.332195213862825, 43.165103571755544, 42.63830852508545, 41.603443826947895, 46.33828680855887, 44.88551575796944, 47.635049956185476, 50.43652541296822, 57.68474721908569, 56.2529354095459, 54.5351357460022, 47.6487900188991, 55.883058479854036, 30.12597860608782, 45.18728297097342, 58.128153460366384, 50.88530955995832, 50.341859681265696, 48.40929119927542, 54.1994126864842, 50.87691961015974, 52.15923397881644, 53.21059717450823, 56.08315617697579, 50.29283319200788, 52.68467065266201, 49.548232964106965, 52.31240006855556, 51.373837402888704, 53.47767898014614, 52.30822420120239, 53.26303175517491, 53.219553402491975, 55.24246236256191, 53.03550257001604, 54.0071108681815, 53.74089758736746, 50.53460965837751, 50.275563444410054, 50.10852180208479, 54.54110772269112, 55.85025256020682, 48.93882731028965, 53.05915771211897, 58.672576086861746, 57.23294407980782, 59.27648571559361, 58.815187862941194, 59.02376583644322, 55.076337882450645, 41.89449691772461, 25.646210942949565, 13.690573300634112, 6.185988587992532, 5.199686586856842, 9.804387637547084, 9.636598195348467, 6.86194235086441, 4.00003102847508, 1.0111202065433775, 0.31047224732381956, 0.08109796938619443, 0.017479258855538707, 0.3109733590057918, 11.25519755908421, 35.48409932000296, 43.642465659550254, 63.24170453207833, 39.64905800138201, 26.583503825323923, 40.85130827767508, 46.83431870596749, 54.67479453768049, 56.58308948789324, 44.540607179914204, 5.610003335135324, 0.17051529378763267, 0.05488715906228338, 0.035941043203430514, 0.022060869793806757, 0.015016305659498488, 0.06758277996310166, 0.01406955422966608, 0.03778469409527523, 0.038191526729081354, 0.057507939503661225, 0.03412293915503791, 0.044585419885282, 0.017145248296271478, 0.037804005201905966, 0.029010449203529527, 0.06147257890552282, 0.03422212401138885, 0.03509868947522981, 0.0706896832478898, 0.01522122323513031, 0.04422284469806722, 0.08947013478193964, 0.0012948891942089955, 0.0043264291847922975, 0.04145754647574254, 0.0470261985569128, 0.1984407010355166, 0.12589568591543607, 0.14869347188089574, 0.10610251408070326, 0.139463712860431, 0.18376686557063035, 0.11073419411799737, 0.21761525927909783, 0.14635188824364118, 0.141351546560015, 0.1662208592253072, 0.11677272830690656, 0.13488259725272655, 0.07956984067069632, 0.14984708997820104, 0.1439212265291384, 0.17839533809040273, 0.07214132749608584, 0.11745941931647913, 0.12230930264507021, 0.12408486594046865, 0.1589748380439622, 0.09052158586148705, 0.2785696749176298, 6.0257791961942395, 64.9955062866211, 83.61542088644845, 76.92381926945278, 62.61032172611782, 56.19264241627285, 41.050891808101106, 31.588480608803884, 33.81841114589146, 43.816809858594624, 68.79931844983781, 30.720226764678955, 7.476903523717608, 0.5679071034703935, 0.14790785046560423, 0.1223718635737896, 0.8915592421378408, 2.725505156176431, 11.66247056211744, 17.24985490526472, 12.384010587419782, 17.965415137154714, 16.544234071459087, 21.849729129246303, 21.521091495241436, 35.09044565473284, 41.17427791867937, 53.41747283935547, 62.71552440098354, 57.3059036391122, 55.57561806270054, 55.32675790786743, 58.671624183654785, 58.94201333182198, 56.80634205681937, 49.37394782475063, 48.939119134630474, 49.807379926954, 54.97639846801758, 55.59480551310948, 58.352340562003, 54.52251434326172, 53.42824602127075, 52.866984435490195, 52.4700790132795, 56.422377654484336, 58.64092704227993, 54.42955786841256, 51.14136804853167, 47.43463264192854, 44.42266150883266, 45.35407795224871, 45.504433495657786, 43.54725102015904, 48.09942933491298, 46.13919660023281, 50.87922293799264, 53.28097895213536, 61.128493309020996, 59.910960469927105, 55.77918985911778, 47.48659821919033, 56.795054708208355, 33.716790267399375, 48.13871792384556, 60.907498904636924, 54.024078369140625, 52.57504892349243, 50.999628271375386, 55.90379537854876, 53.132506370544434, 55.851930550166536, 56.07091692515782, 55.960826192583355, 51.793508597782676, 53.60479974746704, 49.29441179547991, 51.94781766619001, 52.857819761548726, 54.98401369367327, 54.840811320713584, 55.59643139157976, 53.847145966121126, 57.21044928686959, 54.804882185799734, 56.38634777069092, 55.36738749912807, 50.443602153233115, 49.61574166161673, 50.80438041687012, 56.021212986537385, 59.15556621551514, 51.69160284314837, 56.08135659354073, 62.31844179970877, 58.985724449157715, 60.63548387799944, 64.05437973567417, 61.874250411987305, 58.06146117619106, 44.68729060036795, 34.310048307691304, 35.66234145845686, 16.575130973543438, 19.874196461268834, 14.435063225882393, 15.353338888713292, 13.098911608968463, 3.3573795471872603, 0.6739365054028374, 0.429448450250285, 0.19660762511193752, 0.16626883165112563, 0.6447682391319955, 13.48328595502036, 48.439727783203125, 52.67984165464129, 59.63017681666783, 39.42689282553536, 28.455470119203838, 45.73343917301723, 52.094824177878245, 64.42375292096818, 64.16835798536027, 55.99519893101284, 7.732609391212463, 0.2497240656188556, 0.13266986741551332, 0.16176139137574605, 0.062444702456040044, 0.11489585973322392, 0.1293079163879156, 0.14358987073813165, 0.09510343428701162, 0.293163497533117, 0.09739715406405074, 0.1621939167380333, 0.15744134890181677, 0.107312837349517, 0.17130495927163533, 0.13529023395052978, 0.1070805476712329, 0.11081992023225341, 0.15618577413260937, 0.17746806570461818, 0.11720723499144826, 0.13801354781857558, 0.14090124358023914, 0.11187966300972871, 0.10220581639025893, 0.144790063479117, 0.11780372155564171], [0.05422867475343602, 0.056858113301651816, 0.0229821015215878, 0.033892434023852856, 0.07431945883269821, 0.04591683790619884, 0.02794158521906606, 0.038771799699004204, 0.02130722434126905, 0.06727576322321381, 0.03870902842442904, 0.039705348533711264, 0.047649280301162174, 0.03400639058755977, 0.01926075424333768, 0.01469471738008516, 0.04239634717149394, 0.019381655612960458, 0.08276968289698873, 0.0668552207893559, 0.05884177650191954, 0.01466243268389787, 0.029453502036631107, 0.05162480679739799, 12.897446853773934, 56.909748622349326, 64.3464194706508, 53.69531045641218, 45.765710081372944, 38.62781177248274, 19.37095407077244, 38.66480050768171, 62.138247217450825, 60.847139903477256, 37.75092131750924, 9.44290326322828, 0.4751297075833593, 0.042302895936050584, 0.126893050968647, 0.13467199355363846, 0.7580806559750012, 2.3093857935496738, 5.546364784240723, 9.657673818724495, 14.589144740785871, 12.756132653781346, 10.614558015550886, 23.253671714237758, 25.88388623510088, 40.27505942753383, 52.304562500544954, 57.730702604566304, 55.001933097839355, 57.2934559413365, 53.79725790023804, 51.504105704171316, 54.78560093470982, 53.06194393975394, 48.429427078792024, 41.17645270483834, 42.31065232413155, 44.88778781890869, 50.365705898829866, 53.716724804469514, 54.79411595208304, 51.2752320425851, 53.701470034463064, 50.243157046181814, 53.67075204849243, 52.768302645002095, 51.24388524464199, 48.28580433981759, 43.798991203308105, 41.399705273764475, 40.74211038861956, 39.44387422289167, 41.610722064971924, 39.35389157703945, 41.261446544102256, 39.22210162026541, 48.02627870014736, 51.22498614447457, 55.757466316223145, 50.04119028363909, 54.1572927066258, 47.24993562698364, 54.16220508302961, 28.094252382005962, 40.744010720934185, 57.10433292388916, 47.621945653642925, 48.259717328207834, 42.19557973316738, 45.925841740199495, 43.62725257873535, 48.65277692249843, 49.39673791612898, 53.66681589399065, 51.93566179275513, 51.19378178460257, 47.39008774076189, 49.816089493887766, 48.82635334559849, 50.68411404745919, 49.1539956501552, 50.895499093191965, 50.12604168483189, 52.81229516438076, 50.74564382008144, 51.388581480298726, 50.995382922036306, 50.79738705498831, 50.135737895965576, 47.83881630216326, 54.8002929006304, 53.71597787312099, 48.97006641115461, 44.798968996320454, 53.562130859919954, 54.671032088143484, 54.70351491655622, 54.33166817256382, 55.40435191563198, 56.5647497177124, 56.421957288469585, 43.5030118397304, 27.877692665372575, 21.865183659962245, 14.167930177279882, 8.887530275753566, 4.630285620689392, 4.698393600327628, 3.219811511891229, 1.8030901040349687, 0.09873451265905585, 0.09321658446320466, 0.04744295137269156, 0.1738148738763162, 1.4114916941949298, 21.670844282422745, 37.442219802311485, 21.028610127312795, 17.806112051010132, 20.46442334992545, 23.91558837890625, 33.47865465709141, 40.84486034938267, 51.57620021275112, 49.86359780175345, 20.870352745056152, 0.1596707028469869, 0.022376505624768988, 0.03814151191285678, 0.048988185956009796, 0.04380092144544635, 0.017374024859496524, 0.16417405834155424, 0.02674861209067915, 0.02552746279564287, 0.009668856842576392, 0.055115615017712116, 0.007013054240295398, 0.028703293363962854, 0.046687992954892774, 0.011387865940508033, 0.03614406766636031, 0.012238468958197959, 0.07722830453089305, 0.0033603956981096417, 0.05628613202965685, 0.03481841719310198, 0.024810643134904758, 0.033012452136193, 0.05546710294272218, 0.08135049976408482, 0.05077409012509244, 0.023397814482450485, 0.04286247019522956, 0.05261865703921233, 0.005254293168296239, 0.061605890680636675, 0.018489897750051956, 0.0413551555414285, 0.03466969928038972, 0.029342432639428546, 0.03649266503219094, 0.011838703266611057, 0.024707622859360914, 0.021662639287699546, 0.038501929358712265, 0.023617313775633062, 0.03164294794467943, 0.026938001392409205, 0.06434625613370112, 0.062411047119115076, 0.12312456246997629, 0.031618809061391015, 0.028592027191604887, 0.03953567745962313, 0.035425651751990826, 16.931075028010778, 65.73990849086216, 68.90310369219098, 62.41623074667794, 52.15513106754848, 47.13439403261457, 28.76294527735029, 42.69380726133074, 61.27276570456368, 49.927795682634624, 36.68643992287772, 10.573662655694143, 0.5544134303927422, 0.022840640540899973, 0.11708233026521546, 0.4215535324599062, 2.3656996403421675, 6.094975003174373, 7.917619075093951, 9.025830694607325, 13.75285347870418, 10.468340992927551, 7.330683895519801, 18.124336072376796, 26.248315777097428, 41.02885212217058, 52.0641131401062, 57.835842745644705, 56.96859291621617, 57.425304957798545, 54.05179820741926, 53.45591722215925, 55.27194356918335, 56.19186421803066, 51.46263190678188, 44.15427344185965, 44.3615277835301, 45.88941580908639, 52.18130840573992, 55.000473976135254, 56.103371960776194, 51.5520031111581, 53.013810294015066, 51.012663091932026, 54.085132190159385, 55.76064164297921, 53.23409250804356, 50.80038867677961, 47.204324177333284, 44.19628572463989, 43.4215407371521, 41.344703333718435, 43.59373099463326, 41.12750611986433, 41.5637765611921, 42.28701455252511, 49.90110765184675, 52.49047545024327, 56.21850708552769, 52.623474393572124, 55.4442206791469, 46.60295411518642, 54.09386954988752, 29.21987792423793, 42.54555007389614, 59.99549920218331, 50.22557462964739, 51.08501468385969, 44.66740138190133, 47.35822330202375, 45.663561139787944, 51.400490692683626, 51.679259368351524, 55.50260986600603, 52.194277218409944, 51.658199378422324, 48.32677091870989, 50.56470578057425, 49.43378571101597, 51.51883241108486, 50.02236761365618, 51.71286085673741, 50.803074155535015, 54.83582598822457, 52.63121121270316, 52.29685694830758, 51.52475575038365, 51.31606660570417, 48.64232335771833, 48.805005005427766, 54.64972196306501, 56.641020093645366, 50.84504474912371, 47.80953311920166, 56.1824494089399, 56.59699978147234, 56.12524488994053, 56.226615633283345, 55.14643130983625, 59.065017291477744, 56.45508629935128, 48.0272410256522, 28.580407415117534, 18.301942450659617, 5.881070801189967, 8.610879063606262, 9.10069579737527, 10.918969886643545, 7.454229814665658, 3.8578009690557207, 0.5974205540759223, 0.11089301202446222, 0.0852689580725772, 0.12012683546968869, 2.080968107495989, 23.10311119897025, 38.67307928630284, 29.52259704044887, 20.622015442167008, 21.365208659853252, 30.739181450435094, 42.900352886744905, 49.942324365888325, 57.735257148742676, 58.254211153302876, 25.70008032662528, 0.3689943999052048, 0.06159403667386089, 0.07330522539892367, 0.03987206458779318, 0.026510838153106824, 0.05505886574142745, 0.05025228651772652, 0.05563722863527281, 0.08429388968007905, 0.02136129849324269, 0.049880836092467816, 0.03373546512531383, 0.0577022380062512, 0.07383599584656102, 0.027977924161989774, 0.03039697783866099, 0.04475118938301291, 0.06510479721639838, 0.04774170355605228, 0.04036234345819269, 0.03309847680585725, 0.022528210787900856, 0.00472162027810035, 0.04624962879877005, 0.04614762123674154, 0.01201374494537179, 0.15178672304110868, 0.12160900022302355, 0.11146440636366606, 0.10083608488951411, 0.13921121640929154, 0.14323258133871214, 0.20034659733729704, 0.13830473433647836, 0.1855052180056061, 0.16339258956057684, 0.11143362122986998, 0.1303120260792119, 0.19963535693074974, 0.09641553102327244, 0.11851923673280648, 0.13560628199151584, 0.12486892672521727, 0.15255057705300196, 0.17443305999040604, 0.18893389616693768, 0.15251990727015904, 0.12006789791796889, 0.15717225548412117, 0.22532945605260984, 24.151391131537302, 75.1341300691877, 77.31516960689, 68.82281030927385, 59.308252879551475, 50.97912413733346, 29.311201572418213, 50.31671415056501, 73.69813891819545, 75.87883104596818, 46.60469811303275, 12.592493891716003, 0.888645775616169, 0.09700773603149823, 0.29892857532416073, 0.5207659644739968, 2.6042751584734236, 10.005486743790762, 13.693696515900747, 16.320239782333374, 25.456813471657888, 22.065720830644878, 19.352407591683523, 29.912846088409424, 29.95535169328962, 43.53462961741856, 56.04176575796944, 61.41657951899937, 58.05327272415161, 59.33177947998047, 54.636398792266846, 53.780259132385254, 57.60374511991228, 58.438824789864675, 52.93727936063494, 46.126398018428254, 45.85488326208932, 49.22645493916103, 55.41449628557478, 56.97196626663208, 57.67770869391305, 51.828273909432546, 53.536846365247456, 51.756627559661865, 56.576568603515625, 57.80137620653425, 55.20120743342808, 53.14124720437186, 48.5365891456604, 46.76827260426113, 45.48269605636597, 44.04454401561192, 46.21730824879238, 43.56207152775356, 44.85487767628261, 44.14944444383894, 51.93978554861886, 54.99624252319336, 59.251486097063335, 53.127267428806846, 54.36892441340855, 46.440112658909385, 53.538465295519146, 33.29270349230085, 45.069764614105225, 61.447325297764365, 53.14565931047712, 52.69481154850551, 47.377091135297505, 48.6687126159668, 47.97262471062796, 53.38703972952706, 53.96707534790039, 58.05787590571812, 53.7244998386928, 51.8788081577846, 48.83876977648054, 51.56080647877285, 48.904888834272114, 51.48764194761004, 50.1957494871957, 52.708756583077566, 50.509144510541645, 57.114181995391846, 53.8703043120248, 53.974033968789236, 52.61870445523943, 51.54370696204049, 49.56179237365723, 48.56126914705549, 58.06649514607021, 59.48266656058175, 54.46114437920706, 49.54339354378836, 57.34712382725307, 58.62939303261893, 59.47136878967285, 58.508445739746094, 59.67087936401367, 61.545683997017996, 60.58116980961391, 50.44251823425293, 31.51986367361886, 28.305541890008108, 22.37828380720956, 18.26681583268302, 13.3861049754279, 17.88120470728193, 9.398074354444232, 4.681295820644923, 0.44393780561430113, 0.2568075640925339, 0.26116698873894556, 0.26490726375154083, 2.2720422659601485, 30.084862640925817, 50.71159069878714, 29.29662425177438, 26.75161896433149, 29.101108891623362, 34.108488014766145, 47.235094274793354, 55.42584269387381, 65.00947216578892, 65.1084075655256, 31.248439243861608, 0.5582999704139573, 0.15751235080616816, 0.09533936769834586, 0.13212754151650838, 0.1597866237695728, 0.1035493632246341, 0.3423283536519323, 0.10231095539139849, 0.11671136159982, 0.08879869723958628, 0.13774334160344942, 0.16202132457068988, 0.1327224267380578, 0.1940892016781228, 0.1115300003439188, 0.11067582653569323, 0.08895265683531761, 0.15600726513990334, 0.14880674651690892, 0.08885116156722818, 0.16487806556480272, 0.06986506642507655, 0.0916192044637033, 0.10795596641089235, 0.16204495116003922, 0.24304942520601408], [0.0194348493657474, 0.022223234742081592, 0.06766632797994784, 0.04606964399239846, 0.14364044873842172, 0.003386196568109361, 0.010106817270363016, 0.019059974034982066, 0.015377199776204569, 0.03149083396419883, 0.02539888210594654, 0.05937689635902643, 0.011655099324083753, 0.06698560129318919, 0.037012090374316485, 0.012517927846472179, 0.05808715056627989, 0.009284346314546253, 0.009446927545858281, 0.026907599630898664, 0.04469636714618121, 0.006726992358120957, 0.029328441247344017, 0.8382351834859166, 30.654052121298655, 55.215624945504324, 57.82136617388044, 47.30594505582537, 46.48538017272949, 24.830822467803955, 18.64103886059352, 19.988984176090785, 28.93715398652213, 35.891750131334575, 16.064222982951573, 1.8185638508626392, 0.10443737557423965, 0.029573938609766107, 0.08866339735686779, 0.4053976950900895, 2.44768208691052, 3.8139139754431586, 3.8251057863235474, 6.3178428156035285, 12.235490236963544, 23.471855572291783, 17.742256368909562, 33.55758619308472, 47.78502334867205, 61.03804860796247, 59.64002936226981, 57.1030718258449, 56.432112080710276, 56.272911480494905, 56.519551685878206, 53.84468630381993, 54.86935452052525, 53.24921178817749, 49.75099182128906, 42.08775411333357, 38.03269508906773, 43.76183571134295, 51.155917576381135, 52.75875582013811, 51.89838123321533, 53.27796343394688, 50.99629661015102, 52.54995550428118, 52.990269797188894, 49.82584823880877, 48.8883764403207, 45.57632998057774, 44.04292161124093, 41.09867804391043, 39.16939953395298, 38.09999534061977, 39.915698596409385, 37.25033835002354, 38.664237703595845, 44.2378637450082, 52.19984967367989, 50.55971349988665, 54.365078585488455, 49.672136715480256, 54.702076639447895, 47.32349273136684, 52.46221365247454, 29.0654159954616, 37.102035999298096, 57.98305422919137, 50.40903486524309, 47.560068471091135, 41.48067610604422, 43.104845319475444, 40.39882074083601, 47.07018225533621, 50.304419313158306, 54.257819243839805, 50.945380210876465, 49.8461925642831, 48.93962982722691, 49.694895539964946, 47.889336654118125, 49.723536014556885, 49.13374859946114, 49.90448447636196, 47.734982422419954, 48.603795596531455, 46.852564675467356, 52.276241643088206, 48.62917389188494, 49.88401855741228, 49.9540251323155, 49.701472009931294, 53.03200415202549, 53.1562796320234, 47.51206684112549, 44.13766029902867, 41.88517590931484, 48.28514078685215, 49.73903744561331, 51.19727325439453, 51.984076840536936, 54.45822613579886, 55.61987461362566, 57.625211579459055, 45.703548022678916, 29.088084493364605, 13.100778068814959, 9.873565639768328, 6.723054809229715, 6.690996255193438, 6.364385323865073, 2.281470754316875, 0.40123765117355753, 0.035343260637351444, 0.053192639989512305, 0.02637255610898137, 0.012889861727931669, 3.9723333375794545, 33.2969696862357, 38.73318815231323, 20.83059515271868, 15.978812251772199, 24.344735179628643, 31.613115446908132, 32.96682950428554, 45.171809332711355, 48.37430007117135, 45.53630140849522, 5.833175565515246, 0.16195406817964145, 0.021874170883425643, 0.052722422006939135, 0.031055825163743327, 0.01684771408326924, 0.08222320436366967, 0.03542041006897177, 0.06565130289111819, 0.020780536978106414, 0.034208644913243394, 0.06120065599679947, 0.07408175444496529, 0.0787937119603157, 0.03792361396231821, 0.039315581055624146, 0.0377513271357332, 0.020964764324682097, 0.014810643391683698, 0.023112955303596597, 0.03325655171647668, 0.1003104577373181, 0.044096019717731645, 0.03480852415253009, 0.032522118982992, 0.03593243598671896, 0.0437906586032893, 0.015081714738958647, 0.021184519764834216, 0.04106957033010466, 0.051724225748330355, 0.0425773497803935, 0.034485032582389455, 0.02833862659255309, 0.0473805804337774, 0.038572809126760275, 0.06309519362236772, 0.019340085165042962, 0.06955434488398687, 0.007220698254449027, 0.014648493878277285, 0.03406267846003175, 0.039747458416968584, 0.03826659645086952, 0.03513242284368191, 0.010390607756562531, 0.023466346519333974, 0.04043157099347029, 0.02935419504397682, 1.4508114414555686, 38.02604218891689, 65.08783394949776, 64.57366030556815, 54.7444224357605, 53.18330465044294, 31.33851569039481, 19.41559624671936, 24.296822139195033, 36.31746973310198, 41.40932852881295, 17.75178929737636, 2.1331293199743544, 0.0850663407306586, 0.12065586208232812, 0.17308957422418253, 1.342775421483176, 4.292478535856519, 10.065975155149188, 11.423787781170436, 14.321329031671796, 11.09193399974278, 9.48098633970533, 14.450384872300283, 31.88109357016427, 46.658369473048616, 58.77590274810791, 61.33088043757847, 57.02422366823469, 58.42642225537981, 57.186373778751914, 54.975245067051475, 53.43478080204555, 56.405434472220286, 56.5342367036002, 51.92458289010184, 44.415768895830425, 40.81564317430769, 45.28274427141462, 53.64969205856323, 55.03244958605085, 52.48885651997158, 53.04654673167637, 52.18550859178816, 52.56243099485125, 54.26511137826102, 51.994321959359304, 50.818982056209016, 46.747629506247385, 46.30619307926723, 42.414319447108674, 41.02206720624651, 40.384771483285085, 41.65214722497122, 38.478352546691895, 40.39638539722988, 45.50047649656023, 54.661179542541504, 53.421096324920654, 55.736937863486155, 51.05350112915039, 54.78488179615566, 46.737829072134836, 52.268008027757915, 31.135579654148646, 39.89636870792934, 59.56131322043282, 50.89577007293701, 49.365634305136545, 42.980719225747244, 45.231973784310476, 43.003349508558, 47.93537194388253, 51.93911852155413, 54.697341442108154, 51.09901530402047, 50.14358588627407, 49.02267817088536, 49.92473152705601, 49.08754307883126, 49.75646005358015, 49.70058611461094, 49.44830397197178, 47.572519642966135, 48.816236768450054, 49.670326709747314, 52.61837788990566, 50.40971231460571, 50.217295851026265, 49.487554345812114, 49.66222163609096, 54.3017909186227, 54.14579691205706, 50.055507046835764, 44.67059407915388, 44.54430014746529, 50.49955947058541, 52.28526387895857, 53.95379039219448, 54.41780499049595, 57.80793183190482, 57.87430797304426, 56.59973737171718, 49.6102352142334, 30.11454881940569, 13.43557788644518, 7.111185525144849, 10.555059722491674, 9.521108712468829, 8.51985158239092, 5.879256018570491, 1.4621274513857705, 0.39178180428487913, 0.11075291489916188, 0.045693796660218916, 0.005311480099667928, 5.167694040707179, 32.9619379724775, 37.87656559262957, 24.982836893626622, 17.355033261435374, 27.72567650250026, 37.16624777657645, 37.60478333064488, 51.145957333701, 54.33519785744803, 52.47858360835484, 8.084041459219796, 0.20933283013956888, 0.03829943754577211, 0.049089314815189154, 0.019028622324445417, 0.024162738883335675, 0.0278778317650514, 0.05931536001818521, 0.03825958379145179, 0.029036158895386115, 0.010808581935374864, 0.026001417809831243, 0.04212893991331969, 0.04636161421824779, 0.042307031606989245, 0.01001889948799674, 0.015219571002359902, 0.06609154998191766, 0.007521611571844135, 0.01159423982192363, 0.0067727497911879, 0.04490489452811224, 0.0688968715923173, 0.018234263074451258, 0.023338405348892723, 0.05993211442338569, 0.08648710485015597, 0.104181269316801, 0.1153638589062861, 0.14585841686597892, 0.20749761004533085, 0.1166227584970849, 0.10940002463757992, 0.13298377128584044, 0.15360645896622113, 0.09879484799291406, 0.10533336749566452, 0.1512439628796918, 0.11495308737669672, 0.15498099449489797, 0.11710735463670321, 0.1413167512842587, 0.11153272126934358, 0.1098033662087151, 0.17373232330594743, 0.09460123016365937, 0.09381911677441426, 0.10654992650129966, 0.09227196872234344, 2.471143765108926, 45.188933168138774, 70.76672172546387, 72.58148002624512, 61.43128885541643, 58.5228910446167, 35.48428692136492, 25.884874616350444, 28.76653402192252, 40.338242871420725, 47.71550662176949, 20.834962095533097, 2.696813655751092, 0.2615067719348839, 0.26763584305133137, 0.22234789175646646, 1.1565975717135837, 7.401596341814313, 13.00758101258959, 12.31124644620078, 17.026862893785747, 20.243305615016393, 33.63854660306658, 23.138194390705653, 38.53327805655343, 49.31866795676095, 62.734840393066406, 63.849456514631, 60.54203060695103, 61.17968763623919, 60.76515810830252, 58.19674260275704, 54.144146714891704, 57.635053702763145, 58.86338751656668, 54.69246728079659, 47.07020309993199, 42.94865676334926, 47.50764431272234, 55.85840974535261, 57.55571222305298, 53.535446303231375, 54.67723682948521, 51.971333844321116, 52.6952041217259, 56.89384419577462, 54.27424478530884, 53.72305808748518, 49.56361280168806, 48.76112713132586, 45.550454889025005, 43.45847736086164, 42.66006333487374, 45.21169546672276, 41.861117771693635, 41.499908719744, 48.523616858891074, 57.188597202301025, 55.72147117342268, 57.4475530896868, 51.92936325073242, 54.65850796018328, 48.28187165941511, 52.06828900745937, 34.50812060492379, 42.14669220788138, 62.4060446875436, 54.17248841694423, 50.989612443106516, 46.18988718305315, 46.69037287575858, 44.58992896761213, 50.659920419965474, 54.94619117464338, 56.55401127679007, 52.863572869982036, 51.09629161017281, 47.83737455095564, 49.99707964488438, 50.09899582181658, 50.49705811909267, 49.393399306706016, 50.841174602508545, 47.7239556312561, 49.91464621680123, 48.96017565046038, 54.55392367499215, 51.01870455060686, 50.98061800003052, 49.5965507371085, 50.09616790499006, 56.31094591958182, 57.43588011605399, 51.770860944475444, 48.27794940131051, 45.91711827686855, 53.10940361022949, 54.04189355032784, 56.292609623500276, 56.25651373182024, 59.305320739746094, 60.84105328151158, 59.62627192905971, 51.68275431224278, 33.787630626133506, 19.491527897971018, 14.904711076191493, 15.04928571837289, 14.492981672286987, 18.244138649531774, 6.488348569188799, 0.9535641521215439, 0.2612496885870184, 0.11424959584006242, 0.1447548203702484, 0.16644103026815824, 5.929768553801945, 44.96273456301008, 52.507317883627756, 31.43633590425764, 25.70814197404044, 32.532841546194895, 42.48027869633266, 45.34335688182286, 59.42915848323277, 63.33974361419678, 60.277978215898784, 9.889636823109218, 0.3469039052724838, 0.1417822398777519, 0.1921184238578592, 0.12498316488095693, 0.12200682530445711, 0.14889072201081685, 0.12985351282571042, 0.14583637804857322, 0.09982054188315358, 0.12047667455460344, 0.14560989663004875, 0.12461188408945288, 0.15179216489195824, 0.13589163310825825, 0.09141624106892518, 0.07602693792432547, 0.1235500310680696, 0.09044147123183523, 0.21701756492257118, 0.09445704147219658, 0.17971407089914593, 0.13594225182064942, 0.08882617112249136, 0.07214334274509124, 0.17413636376815184], [0.027160696585529616, 0.03875510434487036, 0.07189502606966666, 0.04965981009549328, 0.03211185635466661, 0.06360368776534285, 0.023413973793919598, 0.03502599462600691, 0.06772554373102528, 0.017576404714158604, 0.021915848200608577, 0.018090327137282917, 0.04937847251338618, 0.04449531043480549, 0.03302261998344745, 0.03171680308878422, 0.04704363690689206, 0.048960834209408076, 0.04596854566729494, 0.045132291968911886, 0.03343734397952046, 0.08121788688004017, 0.03736549855342933, 2.3269156643322537, 38.476209027426584, 63.60198252541678, 51.96839823041643, 50.68999917166573, 35.498655796051025, 27.434083189283097, 29.935643127986364, 39.25020708356585, 46.50956685202462, 25.63667801448277, 5.58111663375582, 0.13025920891336032, 0.06164552391107593, 0.05775167606770992, 0.3572205959686211, 0.985446287052972, 2.4583614681448256, 6.858206391334534, 7.568645800862994, 8.354598232678004, 14.434603776250567, 16.384415081569127, 26.458629063197545, 52.59610891342163, 54.761775561741416, 52.67504044941494, 55.21799080712454, 52.730546133858816, 48.362568037850515, 52.69007287706648, 55.31531422478812, 52.26196656908308, 54.100543294634136, 53.53400107792446, 50.45588309424264, 44.19321462086269, 38.448246002197266, 43.24457359313965, 49.21103688648769, 52.46211985179356, 53.17696789332798, 52.84516361781529, 52.11652340207781, 51.209984983716694, 52.02175692149571, 49.44494104385376, 45.04843711853027, 43.958181381225586, 43.60591466086251, 39.97111048017229, 39.68076263155256, 39.29691634859358, 40.66357837404524, 36.12554659162249, 41.54130956104824, 49.65844529015677, 52.51068775994437, 49.77425786427089, 52.11583553041731, 50.22240277699062, 51.70465850830078, 46.24253715787615, 53.179740224565776, 32.58338621684483, 36.591089793613975, 56.61852182660784, 48.66169840948922, 48.462632519858225, 39.90854890005929, 42.17860180991036, 40.7606794493539, 45.54420498439244, 49.07030112402779, 52.37025077002389, 52.166022368839805, 50.600169386182515, 48.485603264399934, 49.335166454315186, 47.669349738529746, 49.742365632738384, 47.57333605630057, 48.47201606205532, 48.75669765472412, 48.613745416913716, 47.95117909567696, 49.3967935017177, 50.04469217572893, 46.574410915374756, 47.195777893066406, 48.29812349591936, 51.983031136649, 52.48634474618094, 50.18304123197283, 46.94190113885062, 42.17199754714966, 39.42692756652832, 42.77425003051758, 47.81765903745379, 49.42460714067732, 54.336677823747905, 52.82065732138497, 55.71052776064192, 55.4684282030378, 47.84320408957345, 18.993180513381958, 11.304574063846044, 9.876689723559789, 7.195848456450871, 7.0921822019985745, 3.558596772806985, 2.330226698092052, 0.21520232089928218, 0.20045113244227, 0.09063032109822546, 0.05647732623453651, 0.3382355932678495, 12.906230245317731, 40.65943724768502, 42.680623054504395, 27.61353084019252, 16.840519155774796, 44.66918706893921, 31.496055671146937, 40.18427079064505, 47.535833154405864, 48.36262362343924, 19.201918295451573, 0.6785278533186231, 0.053509583696722984, 0.06146289621080671, 0.05927136380757604, 0.015290922352245875, 0.1198054270020553, 0.0190416841235544, 0.03537668866504516, 0.02635944850875863, 0.10712482886654989, 0.03990470890754035, 0.07675282111657517, 0.018424534471705556, 0.07786736238215651, 0.038181073897119076, 0.04739002224856189, 0.058208072291953225, 0.013591281188252782, 0.009024146794607597, 0.01672123515579317, 0.05536817932235343, 0.024796884141064117, 0.03457573575100728, 0.043325583916157484, 0.03539808626685824, 0.02631356766713517, 0.03433189740670579, 0.05700033424156053, 0.017986838672576205, 0.0657987892627716, 0.030287777805434804, 0.023639895421053683, 0.01700349724186318, 0.04204798050756965, 0.029529857582279613, 0.026913638592564633, 0.02235068567097187, 0.01731375907547772, 0.043938412996275086, 0.05743708687701395, 0.04893118901444333, 0.029893878049084117, 0.03499485326132604, 0.003975981962867081, 0.0704657191942845, 0.04345221212133765, 0.09857838853661503, 0.009548487274774482, 3.5065460801124573, 48.08461924961635, 70.9912805557251, 58.56322533743722, 55.623383453914094, 43.172291483197895, 33.922887734004426, 34.88096441541399, 30.200428553989955, 41.435908862522666, 28.69751409121922, 5.687182188034058, 0.1715983578136989, 0.08392927210245814, 0.033048441633582115, 1.5714031819786345, 3.940393337181636, 7.716593793460301, 10.760277373450142, 10.346074410847255, 10.38542900766645, 9.953136410032, 13.067155735833303, 28.902392148971558, 50.49330609185355, 55.82543012074062, 54.670403276171, 57.46682391847883, 53.99021979740688, 51.65912348883492, 55.191136019570486, 57.643999508449006, 52.00500134059361, 56.21199662344796, 55.76682553972517, 53.43023320606777, 45.48174067905971, 40.42196519034249, 43.97478410175869, 52.908291476113455, 55.22948660169329, 53.07633365903582, 52.833164078848704, 51.04229021072388, 51.484355449676514, 54.23450108936855, 51.268433230263845, 48.26382718767439, 46.95347683770316, 46.6471620287214, 41.66836779458182, 41.32530396325247, 40.39736161913191, 42.79762724467686, 38.827575956072124, 42.95767552512032, 50.628629207611084, 55.29844747270857, 53.16509689603533, 53.85579994746617, 52.285656452178955, 51.863001005990164, 48.27237694604056, 51.76333257130214, 34.19836643763951, 38.887896742139546, 57.092031138283865, 50.93485369001116, 50.7268419946943, 41.64297907693045, 43.64102390834263, 42.86920758656093, 48.287048067365376, 51.385836941855295, 54.02068764822823, 52.14690440041678, 49.76138285228184, 48.147340638296946, 49.36070455823626, 47.33636426925659, 49.69309248243059, 48.83861691611153, 48.88177217755999, 47.77817242486136, 49.323458739689414, 48.23823697226388, 49.59166962759835, 51.52338000706264, 48.94707134791783, 48.26507786342076, 49.47022206442696, 53.73684678758894, 53.72301639829363, 52.797474656786235, 48.95257084710257, 44.402949469430105, 41.66763823372977, 45.054190226963584, 48.90147032056536, 52.33874763761248, 55.751258100782124, 56.17520591190883, 57.59888138089861, 56.62836047581264, 45.54794658933367, 20.226378066199167, 10.572986943381173, 7.483361874307905, 6.966345114367349, 7.812903642654419, 8.873900515692574, 5.827219656535557, 1.1520835225071226, 0.2975006933723177, 0.15358877634363516, 0.016096436717946614, 0.3978714389460427, 14.722508464540754, 39.4072711127145, 36.93494919368199, 27.188811779022217, 22.089389869144984, 49.455467564719065, 34.41321516036987, 47.5278913634164, 53.38651166643415, 55.16071680613926, 23.042991910661968, 0.713604096855436, 0.03147361274542553, 0.015453848788248641, 0.026705396195341433, 0.0783429882888283, 0.06916240948651518, 0.005916013665098164, 0.02664175978861749, 0.0253352202541594, 0.05280207184010318, 0.05674920503848365, 0.04589973543105381, 0.037416683842561076, 0.04102237821955766, 0.017470091847436767, 0.014117025387739497, 0.013738827779889107, 0.026040043415767804, 0.08225166212235178, 0.041691325538392575, 0.031790000053920915, 0.00887103027863694, 0.05610003362276724, 0.044785580930433104, 0.04672841667862875, 0.1008346328245742, 0.09754305266376052, 0.18745463554348263, 0.18003100103565625, 0.16189563274383545, 0.14219697405185017, 0.09386840555816889, 0.15516315400600433, 0.1234852174030883, 0.12426961745534625, 0.12575037085584231, 0.1935674353901829, 0.11134087906352111, 0.12011801451444626, 0.10681017860770226, 0.10683533190084354, 0.12749535936330045, 0.11265216834310975, 0.1928186041436025, 0.21759765808071407, 0.11821431666612625, 0.1850498802959919, 0.10583226715347596, 5.881700047424861, 56.59425524302891, 78.38014779772077, 66.55880233219692, 64.60541357312883, 48.56051526750837, 38.1330166544233, 41.0441346849714, 52.444520064762656, 60.18688038417271, 34.405738898685996, 7.947934934071132, 0.24108286787356648, 0.30623077920504976, 0.20396070554852486, 1.5116787467684065, 4.46113042320524, 8.938699415751866, 15.676437071391515, 18.004491806030273, 16.111376932689122, 22.017816475459508, 22.219821453094482, 31.376046385083878, 56.00809826169695, 56.09614930834089, 56.61921317236764, 61.122344153267996, 57.43550491333008, 53.005173683166504, 57.450731890542166, 58.5234260559082, 53.01468924113682, 57.72630092075893, 58.78356661115374, 55.59804684775216, 49.753437587193076, 42.625819138118196, 47.58593314034598, 54.35481609616961, 56.80700213568551, 53.65719958714077, 53.64634650094168, 51.1169763973781, 53.806620597839355, 55.25208909170968, 54.0556822504316, 49.105549335479736, 49.46341977800642, 48.932862281799316, 43.748165130615234, 42.94657230377197, 43.210767132895334, 45.43216528211321, 41.147329330444336, 46.60590362548828, 54.43405335290091, 56.09788983208792, 55.28931753976004, 55.6259195463998, 54.94122668675014, 52.54797874178205, 49.43236133030483, 51.9846396446228, 36.799091066632954, 41.55226687022618, 58.92963859013149, 54.31278644289289, 53.935256072453086, 43.291383607046946, 46.29179641178676, 45.81359011786324, 50.11991337367466, 53.379876136779785, 55.09909323283604, 53.100770473480225, 50.860956123897004, 49.18962948662894, 49.709087235586985, 48.270223004477366, 50.727620192936485, 49.485223225184846, 49.54110063825335, 48.81547941480364, 49.4058643749782, 49.27094772883824, 50.90039757319859, 51.4784494808742, 50.41617413929531, 48.01283393587385, 50.2324081829616, 55.71149008614676, 55.93049035753523, 54.6659494808742, 51.5846665927342, 47.05974606105259, 44.22637837273734, 46.8285482270377, 50.73410286222185, 54.2419947215489, 58.110505035945344, 57.253347464970176, 59.109325953892295, 59.13013580867222, 51.96614701407296, 22.293786764144897, 16.606832129614695, 19.611243622643606, 16.634247984204972, 16.30458722795759, 12.902191604886736, 6.944744033472879, 1.2049759243215834, 0.6266344179000173, 0.19217099675110408, 0.23805899013366016, 0.7216547791446958, 17.07383097921099, 53.51827730451311, 53.71061386380877, 38.823108264378135, 22.832451071058, 53.894060203007285, 43.468357699257986, 53.49349308013916, 59.819549969264436, 63.013171332223074, 29.231967789786204, 0.9926313757896423, 0.1424275945339884, 0.09862104124788727, 0.15457300495888504, 0.13444819913378783, 0.17469525949231215, 0.10768950570906911, 0.10739900451153517, 0.12644571997225285, 0.19078112633100577, 0.10534629358776978, 0.17543908315045492, 0.08236317935266665, 0.1519151290080377, 0.13841965102723666, 0.1391051478151764, 0.1495482631559883, 0.09241239154445273, 0.13210052225206578, 0.09392856447292225, 0.10307824279048614, 0.10535734692322356, 0.14416285284927913, 0.11804153450897761, 0.16028982533940248], [0.011210396802718086, 0.013025261694565415, 0.018451830239168236, 0.01564832031726837, 0.07352788666529314, 0.03364705201238394, 0.025067790943597044, 0.031118046824953387, 0.00803986728923129, 0.027961315321070806, 0.06335925231022493, 0.019106446898409297, 0.0431853069790772, 0.019625918041648607, 0.022260406586740698, 0.0364062332415155, 0.02721876052341291, 0.03913510091868894, 0.05667215060176594, 0.032120005560240576, 0.07698878166931016, 0.002535718655313498, 0.11420682099248682, 8.857594830649239, 53.227074827466694, 56.088210991450715, 50.834931646074565, 41.158175468444824, 19.864538465227398, 13.281982745443072, 19.76458168029785, 46.80504594530378, 42.76699611118862, 10.65332201548985, 0.8196579803313527, 0.03224478815017002, 0.09293518242027078, 0.03032511080216084, 0.6695422583392688, 3.242844355957849, 5.316062833581652, 11.82050039087023, 16.68261613164629, 13.749076264245168, 18.924707753317698, 28.421073062079294, 48.47198826926095, 53.3652606010437, 58.22879811695644, 55.84907831464495, 55.72884668622698, 50.10776097433907, 49.83718769890921, 52.074938433510916, 54.728142806461875, 52.8286303792681, 52.067316259656636, 52.3893062046596, 51.54994297027588, 42.69254616328648, 38.28789894921439, 40.40995870317732, 50.474730082920615, 49.189386299678254, 52.16253089904785, 49.70745440891811, 51.031423228127615, 51.50755548477173, 51.231500080653596, 48.15386847087315, 46.69903380530221, 39.909010955265586, 43.32106978552682, 38.063656261989046, 40.00263793127877, 37.6431999206543, 40.63113376072475, 36.291827406202046, 44.45711415154593, 49.21855136326381, 53.125808307102744, 50.50626795632498, 54.4581184387207, 47.71604858125959, 53.700208936418804, 45.39302955354963, 51.39042970112392, 31.7003743989127, 35.08552285603115, 56.87485824312483, 48.285880770002095, 46.5958183152335, 38.51555667604719, 40.62298352377755, 39.61090544291905, 45.37830979483468, 47.51441533224923, 52.20786442075457, 51.45317193440029, 50.11636284419468, 45.75026076180594, 49.07048525129046, 49.04143830708095, 48.936419759477886, 46.882619108472554, 47.7634630884443, 48.27225882666451, 47.520706926073345, 46.72317879540579, 48.73187868935721, 49.54693712506975, 45.45849895477295, 48.45916189466204, 47.57397181647164, 50.109119347163606, 52.901089668273926, 53.28605808530535, 52.1190629686628, 51.981624126434326, 46.920959268297466, 40.19226816722325, 42.81852395193917, 47.099673884255544, 49.50991364887783, 51.94008779525757, 55.21601751872471, 57.34759283065796, 52.173748765672954, 38.661406312670024, 20.97116068431309, 12.359139510563441, 4.848735681601933, 3.972399345466069, 7.941222974232264, 4.513349175453186, 1.9217668558870042, 0.2371092310973576, 0.06591585012418882, 0.02401171055888491, 0.05724305300308125, 1.45812865453107, 26.55722921235221, 41.517115933554514, 28.436022111347743, 15.27696428980146, 16.37645070893424, 39.18172563825335, 37.92982700892857, 50.28758035387312, 49.36091300419399, 27.27342520441328, 2.2438588525567735, 0.163685499557427, 0.06425517637814794, 0.027760840453473584, 0.04136329796165228, 0.10618097308490958, 0.02469850504504783, 0.003616880450863391, 0.026811074631820832, 0.051949692757001946, 0.03343010401087148, 0.008547849986436111, 0.06807284509497029, 0.04419657521482025, 0.048496380381818326, 0.06284084477062736, 0.04798796087769525, 0.045388995337166956, 0.02140964750599648, 0.015520114518169845, 0.025424384844622443, 0.023780379311314652, 0.04378546441772154, 0.047801411245018244, 0.04014150066567319, 0.008863417115727705, 0.03406934506658997, 0.03753395504983408, 0.008738353781934296, 0.0629045320674777, 0.05558272870257497, 0.04834180671189513, 0.01680223866631942, 0.0572723996426378, 0.04418184421956539, 0.04264912860734122, 0.02848669820066009, 0.0781878073300634, 0.064372922559934, 0.0659600431099534, 0.03975601474355374, 0.03660622465291193, 0.055739042814821005, 0.03972401163939919, 0.05335130861827305, 0.07173312082886696, 0.022018213689859425, 0.1107067677325436, 12.934652720178876, 63.116247858319966, 63.101211956569124, 57.557911327907014, 49.866870403289795, 29.929497446332658, 21.220072950635636, 22.239686352866038, 47.0538261958531, 45.324628012520925, 12.565235240118843, 0.9816803634166718, 0.09085874312690326, 0.14550195527928217, 0.4625281723482268, 1.345708212682179, 7.323240637779236, 10.508414728300911, 10.682274290493556, 9.043042251041957, 8.917800102915082, 17.844931636537822, 29.683274132864817, 51.66292762756348, 55.6608898299081, 60.570573806762695, 57.81624187741961, 57.33837604522705, 52.74318838119507, 53.71529694965908, 53.10067319869995, 57.803085463387625, 52.12618139811924, 52.41045304707119, 54.62865502493722, 53.81318317140852, 45.42236484800066, 39.6118608202253, 42.77278743471418, 52.23427104949951, 51.13384314945766, 52.85920592716762, 49.08809198651995, 51.761505195072715, 51.83337736129761, 53.470154081072124, 50.45389243534633, 48.34208127430507, 42.61807189668928, 45.3527786391122, 40.36747394289289, 42.11779464994158, 40.12665285382952, 41.13031666619437, 37.83328526360648, 46.80991315841675, 50.495765754154746, 53.97608021327427, 51.18787234170096, 55.09908628463745, 49.63417175837925, 55.14025436128889, 46.41414029257638, 50.54260703495571, 33.49153661727905, 38.03481081553868, 57.441831248147146, 49.58595820835659, 49.26330818448748, 41.02456855773926, 40.8366128376552, 41.64800262451172, 47.320220129830496, 49.415824617658345, 54.438395977020264, 52.49116679600307, 50.873792920793804, 46.2302006312779, 48.65625449589321, 48.04519864491054, 50.59521879468645, 48.22456291743687, 49.29238986968994, 48.4463528905596, 48.00094904218401, 46.459192412240164, 48.46362263815743, 48.9259592464992, 46.71829768589565, 49.23434114456177, 47.358928544180735, 49.77475118637085, 55.155144350869314, 54.204088824135916, 54.53572634288243, 52.29439728600638, 48.2492880821228, 41.698352745601106, 43.683578150612966, 47.983168601989746, 52.25932625361851, 54.12164149965559, 56.237274169921875, 58.498627935137065, 53.73683636529105, 39.28747374670846, 17.379942553383962, 10.215899910245623, 9.150501353400093, 8.611039740698677, 7.132125658648355, 6.812802519117083, 4.669889918395451, 0.35677797400525635, 0.24108053371310234, 0.045121890027076006, 0.0648312797503812, 1.8072281905582972, 29.124510424477712, 46.51399632862636, 31.435953753335134, 20.148964711597987, 26.520358596529277, 46.804535252707346, 43.35406330653599, 56.65731361934117, 56.28442464556013, 34.53170279094151, 3.1688983695847646, 0.2323044974889074, 0.05222675556849156, 0.04029191491593208, 0.018876540574378202, 0.028773616733295575, 0.061142315555896075, 0.06326111579047781, 0.02789457461663655, 0.06725441651152712, 0.02519430379782404, 0.00361641650254439, 0.04972869497058647, 0.032420430332422256, 0.00781632138283125, 0.03718457058338182, 0.024859548546373844, 0.03087667834811977, 0.03140185766720346, 0.031431071992431364, 0.011870509595610201, 0.02784403393577252, 0.08095243041004453, 0.010201369428874126, 0.018243647213759165, 0.1146944569689887, 0.16767202849899018, 0.07627275759088141, 0.12507734554154532, 0.18301578158778803, 0.11193274480423757, 0.09639660668160234, 0.1670175271907023, 0.07776355330965348, 0.12267154535012585, 0.13393093831837177, 0.11284790533993926, 0.19679395082805837, 0.20895587679530891, 0.10155023621129138, 0.15826574180807385, 0.11555584360446249, 0.1276454920215266, 0.18188832780080183, 0.1734110369746174, 0.18554682577294962, 0.08449789123343569, 0.26820632815361023, 16.868881702423096, 71.24381978171212, 69.2925363268171, 66.18476690564836, 54.38642692565918, 30.39680896486555, 19.918505123683385, 28.43270434652056, 55.8543450491769, 52.89654554639544, 15.929097890853882, 1.2173316670315606, 0.11925111817462103, 0.25664113302315983, 0.4987119478838784, 1.6129759911979948, 11.23882326057979, 13.818937795502798, 23.65816978045872, 24.555234330041067, 22.00986773627145, 23.934553486960276, 32.2996426309858, 53.114256926945274, 57.26135178974697, 63.72718211582729, 59.519186292375835, 59.71149853297642, 55.01595456259591, 56.8111571584429, 56.26949296678816, 59.67181737082345, 53.75498506001064, 54.089224679129465, 56.562727791922434, 57.56148270198277, 47.2577280317034, 43.1885016305106, 43.92486824308123, 54.90566233226231, 52.81727702277047, 54.00721509116036, 49.849204608372276, 50.78775685174124, 53.703450271061485, 54.75585222244263, 53.34571531840733, 51.099880354745046, 45.0889242717198, 49.30289554595947, 41.95866353171212, 46.0415153503418, 41.9726676259722, 45.021280084337505, 40.62887907028198, 49.02694436482021, 51.511529854365754, 56.60857548032488, 52.6553179877145, 56.56906107493809, 50.23230395998274, 56.501389094761436, 47.184028489249094, 50.34342997414725, 34.7152533531189, 41.875636032649446, 59.81963334764753, 53.90387453351702, 51.04036208561489, 43.29276629856655, 43.354897090366904, 44.33917542866298, 50.773078782217844, 51.390269892556326, 55.6216151373727, 53.741696630205425, 53.613464151109966, 47.503138405936106, 49.387885911124094, 50.01941810335432, 52.15366152354649, 50.41814047949654, 49.67530509403774, 49.07163865225655, 48.45621933255877, 47.70292690822056, 49.574233123234336, 50.07485083171299, 46.604583467756, 51.97744131088257, 47.03240837369646, 52.28346429552351, 57.31957074574062, 56.57535266876221, 57.3844564982823, 56.248481614249094, 50.07426718303135, 45.07801559993199, 46.266167981284006, 49.76722976139614, 54.80912058694022, 58.21958480562483, 59.34600939069475, 62.392294202532085, 53.34625727789742, 42.843433243887766, 25.375910384314402, 23.155318226133073, 14.312397990907941, 16.557979345321655, 16.446677889142716, 11.741046871457781, 5.40210063968386, 0.28145952842065264, 0.34240589663386345, 0.14285508516643727, 0.17685678707701818, 2.378674532685961, 36.134273529052734, 54.743887424468994, 38.96659551348005, 23.412073271615164, 24.291772535869054, 50.29510177884783, 48.68419667652675, 63.252154622759136, 63.754266193934846, 45.8086325781686, 4.754465997219086, 0.29958870847310337, 0.18241549522749015, 0.1896514876612595, 0.16157703341117927, 0.16545639453189714, 0.17549982560532434, 0.12922999342637403, 0.0856771579544459, 0.3011649181800229, 0.15419586162481988, 0.06491944180535418, 0.14616283481674536, 0.15854136273264885, 0.12016785969691617, 0.13329363108745643, 0.10811012278177909, 0.07904348748603038, 0.10573640372604132, 0.07149996941110917, 0.09235695523342916, 0.09996959567070007, 0.17087651869016035, 0.09185260693941798, 0.08223249350807496], [0.0504549174303455, 0.023041547974571586, 0.005954245296639523, 0.047101865389517376, 0.047261283799473724, 0.025862891493099074, 0.032614650803485086, 0.01672170843396868, 0.017266721331647465, 0.052262107242963145, 0.03900054403181587, 0.054193027916231325, 0.039874466601759195, 0.0356282860572849, 0.030521499192608253, 0.007559736758204443, 0.08105229040873901, 0.0375663279555738, 0.03496582892590335, 0.03747700899839401, 0.01236586136344288, 0.017977042323244468, 0.16025322516049656, 22.552577631814138, 59.3174592426845, 55.71020119530814, 46.51709869929722, 29.002517427716935, 17.623768738337926, 22.281167098454066, 39.36423397064209, 36.44387136186872, 25.232942513057164, 3.758228506360735, 0.036795067733951976, 0.045679706880556684, 0.00904461819612022, 0.10671500050063644, 2.3070894139153615, 5.297857250486102, 7.174973896571568, 5.795082066740308, 6.311196429388864, 20.58725186756679, 34.25698838915144, 40.642018113817485, 58.01094429833548, 55.42594344275338, 57.78377989360264, 53.47453492028372, 53.83383321762085, 46.18034035818917, 45.00489970615932, 52.853796754564556, 53.35941021783011, 52.10671949386597, 51.104844842638286, 51.715362208230154, 50.452315194266184, 43.04077598026821, 38.6961646761213, 39.20027038029262, 49.580020972660606, 50.251150948660715, 52.25976051603045, 49.01525402069092, 53.11990928649902, 50.23732055936541, 51.50206988198416, 46.477698939187185, 42.951290130615234, 40.71297311782837, 39.10648359571184, 37.26463079452515, 39.52242360796247, 37.3861026763916, 39.39207192829677, 36.39681468691145, 43.88242864608765, 50.504589966365266, 51.244225706372944, 51.906416824885774, 52.82435028893607, 49.44118554251534, 53.702328136989046, 47.61623076030186, 53.59516954421997, 34.85079533713204, 34.70730113983154, 54.5398188318525, 46.722272055489675, 49.31357145309448, 38.949482100350515, 40.03157717841012, 38.267988886152, 43.79773357936314, 43.329772404261995, 49.88469253267561, 51.69597673416138, 51.525388036455425, 50.727099078042166, 53.24398674283709, 49.82994072777884, 51.57103770119803, 50.510985783168245, 50.202836649758474, 49.246962547302246, 49.45583929334368, 47.90874992098127, 48.36272437231881, 47.70541436331612, 46.399562971932546, 42.89327267238072, 46.907174042293, 46.197127205984934, 48.7104434967041, 52.39150183541434, 52.81475830078125, 51.606706278664724, 54.85740014484951, 46.537095614842, 41.36981412342617, 42.77288123539516, 50.62537397657122, 51.50554745537894, 55.43642827442714, 52.9676707812718, 49.56565209797451, 46.46611629213606, 35.92691496440342, 13.94608461856842, 8.877959132194519, 6.3496473261288235, 9.258713466780526, 7.545535223824637, 1.9822452792099543, 0.07045782104666744, 0.22285870648920536, 0.06126627033310277, 0.029554841241666248, 0.08163847681134939, 7.392969284738813, 33.25005544934954, 39.6348419870649, 25.263082061495098, 17.784982579095022, 30.936854226248606, 31.563008512769425, 43.43799754551479, 45.656651156289236, 37.58456754684448, 11.403523359979902, 0.00580476488020005, 0.03009222062038524, 0.027415963155882697, 0.013154964511548834, 0.06419722270220518, 0.08627775644085237, 0.0573907768619912, 0.018380531475746205, 0.036089659335889986, 0.029605402278580835, 0.02893642781834517, 0.018200960575735996, 0.01400951829938484, 0.01160983510115849, 0.05608330434188247, 0.06962747060294662, 0.04935555838580642, 0.033117248477148156, 0.02496124567863132, 0.018505185144022107, 0.01303537525901837, 0.030558598094752858, 0.009608893854809659, 0.04221836743610246, 0.015903208604348556, 0.017911098897457123, 0.031748114087219746, 0.021810865262523293, 0.07632068251924855, 0.04971852033798184, 0.01763884011389954, 0.07149889054042952, 0.03948749129527381, 0.020964847445221882, 0.07677403212125812, 0.038101396922554286, 0.017389622683237706, 0.030843928855444704, 0.052185310649552515, 0.022106329943718653, 0.033174489691321335, 0.06090771885854857, 0.025860472515757595, 0.06487486883997917, 0.032755626631634574, 0.03515844126897199, 0.34045624839408056, 31.232670307159424, 66.06731455666679, 61.515799794878276, 52.82369021006993, 33.085400513240266, 17.497452225003922, 19.89804788998195, 33.98711340767996, 38.53500120980399, 29.862732206072124, 3.6802058815956116, 0.11752523721328803, 0.03193928115069866, 0.018944950474958335, 0.7967808736222131, 4.410198824746268, 8.898870604378835, 10.208491393498011, 11.782813361712865, 8.422925080571856, 12.6428587777274, 28.272489309310913, 45.05616698946272, 60.728819029671804, 57.59843669618879, 58.73768070765904, 57.06962319782802, 55.04313938958304, 49.47379691260201, 46.812192167554585, 53.90307201657976, 55.795695304870605, 53.79673331124442, 53.04542459760393, 54.58210209437779, 52.86496598379952, 45.95221710205078, 39.457888739449636, 41.7788267816816, 50.81844009671892, 52.853779384068076, 53.1501339503697, 49.234441893441335, 52.5279575075422, 53.786151204790386, 53.952647413526265, 48.29187706538609, 45.86498941693987, 42.72928128923689, 41.76486437661307, 39.47358819416591, 41.27346345356533, 39.7648914200919, 41.558697428022114, 37.653368609292166, 45.593262740543906, 51.85975272314889, 52.6456287247794, 52.58470344543457, 55.38260405404227, 53.190655844552175, 54.73279462541853, 48.77271325247628, 52.076797076633994, 35.414916106632774, 37.89597538539341, 56.61517626898629, 48.926192011152, 51.351012570517405, 41.308266980307444, 42.213763168879915, 39.765419483184814, 44.24807412283761, 44.47941092082432, 52.39921086175101, 53.993756430489675, 52.891237122671946, 52.00524800164359, 53.378229413713726, 52.223494393484934, 52.45872218268258, 52.183893135615754, 52.38936179024832, 49.76985270636422, 49.23662710189819, 47.57679973329817, 49.004248074122835, 48.84182698386056, 48.075214862823486, 46.85374934332711, 48.42139148712158, 46.46210718154907, 50.58141967228481, 53.98854528154646, 55.1925082887922, 55.0167362349374, 54.97541182381766, 47.884038652692524, 43.503112588609966, 45.81039047241211, 51.87808207103184, 53.05562455313546, 56.32119451250349, 55.93774080276489, 52.094508034842356, 49.576171670641216, 33.982749938964844, 12.667284301349095, 8.776016899517604, 7.946380274636405, 9.873559560094561, 9.611945118222918, 6.504097095557621, 3.880434725965772, 0.4452706112393311, 0.23168054382715905, 0.08790699365947928, 0.020855859454189028, 9.595045362200056, 34.71788672038487, 31.713912963867188, 23.9930225781032, 16.727068969181605, 35.74370486395699, 38.28035320554461, 47.4670147214617, 51.87228727340698, 45.08518614087786, 14.167745181492396, 0.18099876839135373, 0.03283462507118072, 0.020640019161094512, 0.06817991792091302, 0.04302981389420373, 0.07745657728186675, 0.030400974409920827, 0.028333712302680527, 0.030431274391178573, 0.0623940701729485, 0.04818211688793131, 0.03490156148161207, 0.02431191989619817, 0.024660798854061534, 0.010924735256204647, 0.05343935192961778, 0.02669315711994256, 0.042019627921815426, 0.05886355747601815, 0.03013532455744488, 0.03620934273515429, 0.02133484241286559, 0.026643003204039166, 0.04707966711638229, 0.1006181597975748, 0.07393943851015397, 0.10624864338231937, 0.16559904973421777, 0.1676535994878837, 0.05797006256346192, 0.1675984210201672, 0.1340267474630049, 0.09040248260966369, 0.0921418189204165, 0.20730141843003885, 0.1397692028965269, 0.0884242205481444, 0.08148999299321856, 0.10680258580084358, 0.1327859511865037, 0.14989005481558187, 0.18994073356900895, 0.09869686075087104, 0.12072299633707319, 0.17236531951597758, 0.10792206001601048, 0.8302875299538884, 39.85108034951346, 75.32055718558175, 70.91991560799735, 60.84647287641253, 41.059663908822195, 26.518762247903005, 29.6392433983939, 52.93593488420759, 49.18347685677664, 35.46312270845686, 5.4228792275701245, 0.3645218770418848, 0.14544924667903356, 0.1704932821116277, 0.4832297872219767, 6.21477758032935, 13.476658242089407, 17.414482048579625, 15.086759090423584, 16.964534078325542, 27.43920053754534, 38.49333981105259, 45.698976108006065, 63.14194924490792, 59.453081130981445, 60.11006110055106, 58.31620992933001, 59.063544273376465, 51.209050451006206, 50.24254560470581, 55.84207105636597, 55.36307961600167, 54.198394775390625, 52.86273908615112, 56.85276991980416, 55.723903042929514, 48.09788336072649, 43.0483912059239, 45.35393551417759, 54.27646820885794, 54.19168628965105, 52.53655242919922, 50.25996126447405, 52.54462971006121, 55.351295471191406, 57.30240174702236, 50.54085956301008, 48.39550597327096, 44.83731263024466, 43.67803348813738, 43.040334769657676, 44.00296252114432, 41.713864598955425, 44.211182662418906, 40.89859076908657, 47.04723235539028, 54.88132626669747, 53.74907561710903, 55.467823709760395, 57.673807280404226, 54.40017393657139, 56.6244660105024, 50.82227202824184, 51.375306946890696, 38.95109060832432, 41.40367616925921, 58.558500562395366, 51.267634187425884, 53.252876962934224, 45.048652512686594, 44.26370062146868, 42.60582569667271, 47.04243115016392, 46.928136757441926, 54.30016851425171, 54.817100593021934, 54.8418014390128, 53.563239097595215, 56.35682487487793, 54.06433970587594, 55.071811131068635, 54.35516003199986, 53.0636636189052, 51.47247403008597, 52.19956827163696, 48.513250146593364, 50.13524457386562, 50.40453590665545, 49.3471416745867, 49.42796312059675, 49.39939560209002, 45.970692362104145, 50.92457730429513, 56.371937206813264, 57.0059985433306, 56.385590417044504, 58.36147049495152, 50.32893255778721, 45.28633649008614, 47.35658005305699, 54.65924794333321, 53.953665324619834, 60.38367421286446, 56.76769617625645, 55.51091643742153, 49.31581572123936, 39.52641882215227, 19.5305472442082, 17.161491189684185, 12.280949694769722, 22.49520288194929, 17.057509660720825, 9.847503815378461, 2.8842002749443054, 0.37389697826334406, 0.47293885371514727, 0.20351817858006271, 0.12478568404912949, 10.505453927176339, 45.1657782963344, 52.1398936680385, 33.149098123822895, 24.603625059127808, 40.74263150351388, 42.25853041240147, 56.226150103977744, 55.83264235087803, 56.29416254588536, 19.878592933927262, 0.3813079648784229, 0.10670660702245575, 0.141303954113807, 0.12941326573491096, 0.1371286024472543, 0.15666028724185058, 0.28122236686093466, 0.08436874566333634, 0.1419390628912619, 0.11569441402597086, 0.1200255709035056, 0.1456131943102394, 0.10251944206122841, 0.12662407968725475, 0.15619133811976227, 0.12368435386036124, 0.11088370930935655, 0.09760445329759802, 0.14866335849676812, 0.13105545618704387, 0.18216458654829434, 0.1980931418282645, 0.16274543000119074, 0.22517759991543634], [0.027468763358358825, 0.037556726685059924, 0.024915856774896383, 0.04252599485750709, 0.0363530700228044, 0.014897059915321214, 0.0469375377787011, 0.029421563393303325, 0.04305014958871262, 0.04518091918102332, 0.04630564186455948, 0.03265599733484643, 0.061998938875538964, 0.041301686981959004, 0.03127814716260348, 0.08365104560341154, 0.037344508072627444, 0.010213585603716118, 0.04237320912735803, 0.02772372798062861, 0.028865283421639885, 0.014593037211203148, 3.587391193423952, 40.950184617723735, 58.51911122458321, 47.10548605237688, 39.1906019619533, 28.2710770879473, 28.568842138562882, 27.591807297297887, 37.04174995422363, 42.35797650473458, 11.609758053507123, 0.5138360591871398, 0.0264435783693833, 0.022834872993241464, 0.157474067860416, 0.9867668790476662, 2.241832801273891, 7.977404849869864, 12.04559336389814, 8.776018636567251, 9.391373685428075, 23.0311313356672, 45.98663847787039, 54.06746639524187, 56.64430659157889, 52.50079352515084, 55.55721228463309, 54.99579783848354, 52.86724499293736, 45.770278521946494, 47.16561228888375, 51.7648264339992, 56.27751466206142, 52.57098422731672, 52.05909654072353, 51.74711200169155, 52.45676279067993, 43.10658931732178, 37.337843963078086, 38.91165263312203, 48.21496398108346, 50.02205841881888, 53.20149156025478, 48.49880831582205, 52.03594166891915, 50.17735065732683, 49.59275702067784, 43.631782804216655, 39.41051592145647, 37.858753885541645, 39.51315818514143, 37.00128017153059, 38.1938133920942, 37.391911370413645, 38.978150367736816, 36.51468045370919, 44.08657019478934, 46.65806722640991, 52.75563260487148, 50.05258532932827, 52.18934747150966, 49.27893468311855, 55.946815150124685, 46.52512386866978, 53.70881428037371, 31.89656720842634, 29.31060402733939, 59.02284172603062, 45.85018975394112, 50.5159398487636, 43.52520786012922, 40.76334408351353, 35.983264854976106, 39.61585603441511, 39.12454196384975, 46.04514231000628, 46.65919630868094, 49.3778144972665, 50.37277569089617, 50.26090621948242, 48.183731828417095, 50.82689952850342, 50.34100157873971, 51.885794571467805, 50.98160464423043, 49.05590098244803, 48.291050229753765, 50.30520098549979, 50.76494244166783, 45.37566253117153, 44.096780572618755, 47.212463991982595, 45.4859756061009, 47.61248220716204, 47.82029587881905, 49.36425856181553, 49.22176143101284, 51.0149108341762, 52.315797737666536, 44.06966870171683, 40.31891993113926, 46.674166202545166, 50.40610619953701, 53.583364554813926, 56.04698385511126, 52.58761821474348, 48.4234551021031, 40.02076925550188, 31.838977064405167, 17.672656263623917, 5.779178074428013, 3.3660482934543063, 4.9253942881311685, 5.729705597673144, 2.727447611945016, 0.5920622444578579, 0.0678741361147591, 0.033993956433343034, 0.16983362393719809, 1.526270289506231, 22.206222091402324, 47.84589999062674, 38.27530186516898, 27.217553002493723, 25.058476720537456, 26.126852580479213, 40.16036898749215, 46.06429154532296, 49.4254652432033, 27.201209102358135, 1.3974359227078301, 0.04537909211856978, 0.024210282135754824, 0.0340739455340164, 0.0498207518165665, 0.014652064668812921, 0.04681793241096394, 0.01721305599702256, 0.03737285387303148, 0.05183712379740817, 0.0410989203623363, 0.06036689252193485, 0.02294618496671319, 0.02839186614645379, 0.042629753039883714, 0.0262085779436997, 0.06233505119702645, 0.047355742659419775, 0.10012029829834189, 0.11920978182128497, 0.07099691711898361, 0.03021054694961224, 0.0576106154226831, 0.058190613585923395, 0.029082306062004397, 0.007254452827120466, 0.002911313869325178, 0.0426924157488559, 0.04260144116623061, 0.0466374217399529, 0.021680717156933885, 0.0907170514443091, 0.026642767413120185, 0.011149546630414469, 0.08078056427517108, 0.04306430043652654, 0.01157503473638956, 0.03292302800608533, 0.0654472199135593, 0.06930703244038991, 0.013214839289763143, 0.05474759119429758, 0.058103381123925955, 0.008172760917139905, 0.1325439584574529, 0.03246902361778276, 5.2047057918139865, 51.40522589002337, 64.8600025177002, 54.11513103757586, 44.4946413721357, 36.6356520652771, 34.704831055232454, 30.19554397038051, 40.13517829350063, 44.327016081128804, 14.074726172855922, 0.6507897760186876, 0.0612699683489544, 0.018243480972679596, 0.6194917783141136, 2.525943556002208, 5.690896434443338, 9.650898456573486, 9.00890748841422, 8.940712656293597, 7.083499125071934, 24.639510767800466, 43.064455441066194, 59.81993212018694, 57.97154106412615, 56.831227030072895, 55.45466034752982, 56.577899183545796, 55.1919698034014, 47.43410805293492, 48.99172394616263, 56.06128672191075, 56.12167698996407, 52.25494541440691, 52.49383837836129, 54.29031944274902, 53.169741766793386, 44.93537255695888, 39.48882906777518, 42.15196936471121, 48.03564139774868, 52.13745832443237, 53.33587319510323, 48.2494409424918, 51.86697537558419, 53.05145215988159, 50.801531655447825, 45.88461807795933, 41.88853883743286, 39.828404903411865, 42.08352960859026, 40.74271488189697, 39.74966444287981, 39.295662198747905, 41.33492374420166, 39.13975851876395, 45.09786312920706, 49.85073668616158, 55.07881838934762, 50.81283984865461, 53.31457001822335, 50.09046343394688, 56.80089814322335, 47.41872821535383, 53.0373021534511, 33.09776135853359, 31.566875185285294, 60.41096673692976, 47.93459027154105, 53.32424885886056, 44.99010699135916, 42.96355022702898, 37.543382099696565, 42.38944837025234, 42.17620815549578, 47.54905905042376, 47.89801148005894, 51.98383712768555, 50.3480817931039, 52.67221253258841, 50.435747214726035, 53.18484715053013, 51.148868628910606, 53.46995258331299, 52.40625286102295, 51.81440877914429, 49.63187885284424, 51.17834636143276, 49.856924057006836, 47.24583966391427, 45.23398528780256, 48.326149054935996, 45.899466378348215, 47.95154735020229, 47.927291188921245, 51.54896674837385, 49.81238610403878, 54.805097579956055, 54.09154190335955, 45.55096558162144, 41.4802314213344, 48.708140168871196, 51.480547836848665, 57.1818539755685, 56.57233715057373, 54.49320336750576, 49.217394488198416, 45.666795526232036, 27.74611462865557, 15.827332837241036, 6.391006478241511, 9.506171822547913, 11.216328467641558, 8.701276864324297, 5.650177385125842, 2.99586911712374, 0.11261370219290257, 0.12759818456002645, 0.09905669465661049, 1.5786281142915999, 23.28146277155195, 45.77067804336548, 27.857384817940847, 26.640991483415874, 30.982020991189138, 29.18644666671753, 47.35092074530465, 49.68798208236694, 57.35449586595808, 33.073703220912385, 2.3177522931780135, 0.024077825314764465, 0.06686180936438696, 0.0588926530576178, 0.05938539161745991, 0.013506805274768599, 0.034232237575841803, 0.013372977813040572, 0.01551077448363815, 0.0558054646077965, 0.056543432508728335, 0.010672297328710556, 0.020732666332540766, 0.021641845582053065, 0.022666560685528175, 0.049817379497523816, 0.023956092739743844, 0.033761273204748116, 0.03898589785343834, 0.050169562920928, 0.08189759576427084, 0.046152262416269095, 0.07340462399380547, 0.04916048974597028, 0.10374875073986393, 0.19919753899531706, 0.05923656853181975, 0.11401250213384628, 0.11203465397868838, 0.12336134405008384, 0.09006377828440496, 0.13938736410013267, 0.092673613955932, 0.07955897732504777, 0.1455283367208072, 0.1276680736669472, 0.21851682875837597, 0.08682893043650047, 0.16068086507064955, 0.21752779611519404, 0.08778638405991451, 0.18758091091045312, 0.11582208717507975, 0.08783351510230984, 0.17285482824913093, 0.11997162736952305, 7.667140858513968, 61.3204789842878, 71.69030407496861, 61.36460699353899, 52.929625919886995, 42.31306682314192, 40.897232396262034, 39.313171659197124, 47.40408141272408, 56.63831377029419, 16.443165574754985, 0.9903670230082103, 0.14604639820754528, 0.16066686010786466, 0.54483555576631, 2.5544630885124207, 7.977172953741891, 18.560818433761597, 18.180691174098424, 16.51557101522173, 16.670170170920237, 27.823229210717336, 50.517152309417725, 58.703523363385884, 63.20742906842913, 55.687491008213584, 60.857902663094656, 58.77256761278425, 57.200207642146516, 49.52586671284267, 51.80393436976841, 57.59180464063372, 58.66597529820034, 52.39930118833269, 53.14028835296631, 56.62054027829851, 57.12592445101057, 46.89851311274937, 41.40668821334839, 43.881407260894775, 51.77542243685041, 54.391481740134104, 54.93071753638131, 49.253935064588276, 53.84021166392735, 55.43024785178048, 53.99534409386771, 47.55263042449951, 43.88988406317574, 42.23742873328072, 44.469047682625906, 43.001893860953196, 42.981070109776084, 40.95077174050467, 43.185204710279194, 41.19210352216448, 48.47773790359497, 51.457524980817524, 58.23891469410488, 52.35874455315726, 54.26571239743914, 54.515135356358115, 59.67804295676095, 48.56922483444214, 52.364813804626465, 35.818533488682334, 35.05140372685024, 62.12137699127197, 50.626450947352815, 55.028610706329346, 48.47377395629883, 44.92024632862636, 39.596154417310444, 44.34902102606637, 45.441805907658164, 50.56573411396572, 50.33122198922293, 53.57717023577009, 53.659753050122944, 53.77008696964809, 52.91803979873657, 54.72664894376482, 54.37179749352591, 55.40752724238804, 54.033277784075054, 52.57816866465977, 50.50414875575474, 53.15883656910488, 51.92595515932356, 47.97824927738735, 45.79741471154349, 48.095562662397114, 46.49002504348755, 47.51481832776751, 48.27038976124355, 51.31769943237305, 52.25297907420567, 56.013229506356375, 57.124781472342356, 47.34748486110142, 44.754479680742534, 49.8291277885437, 55.42978927067348, 59.05392101832798, 60.71431813921247, 53.94505998066494, 55.56763458251953, 43.833395208631245, 38.96211739948818, 27.12502384185791, 16.464949914387294, 8.693051065717425, 12.455228754452296, 14.888292482921056, 7.6810581002916605, 3.1500552892684937, 0.21724503700222286, 0.18637898111982004, 0.31209953714694294, 2.5319936999252866, 29.310631820133754, 61.95085430145264, 53.06580713817051, 36.11774723870413, 33.70305715288435, 37.57241514750889, 53.47548334939139, 59.530984333583284, 62.602095058986116, 41.76989834649222, 3.560541182756424, 0.11299563598419939, 0.14497514069080353, 0.1334395975406681, 0.17789030447602272, 0.11107565329543181, 0.1388792363660676, 0.08105081798774855, 0.08777562249451876, 0.1810710866536413, 0.09028045487190996, 0.14635404598500046, 0.13847496520195687, 0.17884782595293863, 0.07633166800120048, 0.11742416263691016, 0.15888756486986363, 0.12111403606832027, 0.12285127570586545, 0.17164179762559278, 0.18875005388898508, 0.2715392921652113, 0.18772443463759764, 0.1435872923050608], [0.026926098191844564, 0.056335400457360914, 0.057246947794088295, 0.01579255311350737, 0.06638796800481421, 0.011717589854794954, 0.01186148592803095, 0.04182075270052467, 0.05755416809448174, 0.05523086419062955, 0.024974919855594635, 0.01619035274987774, 0.03442251236577119, 0.011902789202784854, 0.044883089805287976, 0.03751507820561528, 0.02413887480672981, 0.007810836275374251, 0.09759978497666971, 0.04391457266839487, 0.07868634736431496, 0.08283759068165507, 8.642098188400269, 47.81839902060372, 54.14112772260393, 47.80447483062744, 37.86910670144217, 20.20273855754307, 10.756850174495153, 23.938734565462383, 43.15359388078962, 28.605519941874913, 4.841399252414703, 0.10676997540784733, 0.08258165405797106, 0.045329881366342306, 0.03613563347607851, 2.9271635924066817, 4.760531774588993, 6.288497098854609, 6.672329485416412, 10.230888043131147, 15.729576894215175, 35.11152648925781, 46.52924067633492, 56.1391065461295, 51.32328578404018, 51.74843910762242, 51.25134760992867, 50.440791606903076, 46.64821120670864, 42.571056910923545, 46.326294217790874, 53.4642550604684, 53.93415478297642, 51.64371238436018, 50.45269039699009, 50.559154169900076, 50.46430778503418, 42.789998122623985, 37.72875656400408, 38.67543819972447, 47.57427058901106, 49.84654344831194, 51.17866597856794, 48.68226507731846, 50.60465097427368, 52.1904696055821, 48.559351444244385, 41.53808907100132, 38.58738715308053, 38.04312433515276, 36.93557105745588, 36.7735390663147, 38.92742156982422, 38.42418786457607, 38.89798552649361, 38.685262952532085, 44.71766117640904, 48.77716704777309, 48.85463598796299, 47.785054615565706, 48.48781973975045, 47.327421937670024, 54.03010940551758, 48.23227889197213, 54.02864333561489, 31.715907096862793, 25.018811191831315, 55.23643480028425, 46.7378568649292, 51.62717914581299, 44.50646373203823, 47.13818080084664, 38.97366877964565, 40.395826067243306, 37.62664583751133, 38.658970969063894, 41.104351248059956, 45.140080383845735, 45.68013606752668, 47.29237174987793, 47.18277086530413, 46.337015288216726, 44.61487994875227, 48.168331146240234, 48.12642656053816, 48.782812459128245, 47.47307702473232, 50.19466209411621, 50.3096513066973, 47.70348971230643, 45.458624022347585, 48.0360061781747, 50.09028972898211, 51.980713912418906, 50.02621691567557, 45.64062861033848, 52.26642731257847, 54.901045254298616, 49.293241024017334, 46.89202349526541, 37.53263323647635, 41.62547656467983, 48.44080127988543, 52.900822162628174, 53.19272640773228, 56.395109449114116, 51.54579836981637, 47.60196263449532, 38.11513199125017, 24.262477193559917, 11.423749566078186, 11.874847463199071, 13.655303376061575, 4.403436924730029, 7.479855639593942, 2.0848664811679294, 0.566213914326259, 0.04599247081205249, 0.042606726954025884, 0.06690147652157716, 5.73587212392262, 27.109617948532104, 45.760109833308626, 19.76365062168666, 20.802138805389404, 40.543437072208945, 26.28258602959769, 48.81107078279768, 43.26679045813424, 42.61750561850411, 5.578733835901533, 0.03109313441174371, 0.031003367621451616, 0.036706691940448115, 0.03375064395368099, 0.07266655431262084, 0.04958023490118129, 0.1000062772738082, 0.04056136795718755, 0.04033662358831082, 0.030607466186795915, 0.07186308742633887, 0.03558447305113077, 0.02772469658936773, 0.03496007834162031, 0.04871401709637471, 0.063010607446943, 0.029413003674043075, 0.027670254332146475, 0.021263497848329798, 0.06757127879453556, 0.03785439660506589, 0.03513716580346227, 0.01028779782687447, 0.05905291624367237, 0.04527236195281148, 0.020128190018502728, 0.039768839055406194, 0.02142735557364566, 0.03126230676259313, 0.02320171955839864, 0.05824328825942107, 0.09277916007808276, 0.07745280462716307, 0.011221184661345822, 0.014474977206970965, 0.0376468497062368, 0.014614828363327044, 0.04380394092627934, 0.03454879791076694, 0.006573138783486294, 0.03887867235711642, 0.07769558445683547, 0.02954639687335917, 0.07153663744351693, 0.14732528743999346, 10.910232526915413, 56.40737301962716, 61.19883687155587, 55.85391773496355, 44.44603872299194, 27.514958483832224, 16.77806179864066, 25.278258664267405, 45.08439057213919, 32.99775941031319, 5.012968948909214, 0.014752976396786315, 0.0771091469962682, 0.05235884598057185, 0.9723443729536874, 3.640792007957186, 9.04279385294233, 10.707326020513262, 11.530288032123021, 8.698902317455836, 16.94871129308428, 38.69226326261248, 51.590909549168174, 57.52985797609602, 54.48406648635864, 54.08186306272234, 53.59083734239851, 53.133451325552805, 49.96904713766915, 44.332314082554404, 49.60219267436436, 56.3487024307251, 56.02380813871111, 52.534593037196565, 50.73103175844465, 52.545373167310444, 53.086252212524414, 44.585787841251914, 38.97228261402675, 40.27930130277361, 48.89680807931082, 51.45591994694301, 52.31046846934727, 47.729392596653526, 51.35630014964512, 54.349677903311594, 51.70228222438267, 43.37878499712263, 40.77236631938389, 40.99173831939697, 38.69346530096871, 38.51861735752651, 39.86607803617205, 40.158805642809185, 40.34267929622105, 39.79556424277169, 46.49394382749285, 50.48581940787179, 50.820611408778596, 49.971214975629536, 49.52612379619053, 49.931492124285015, 55.68775503976004, 48.76796415873936, 54.315058503832134, 32.74564749853951, 27.039350816181727, 57.4595422063555, 47.09541811261858, 53.6364209992545, 48.55747195652553, 49.204658440181184, 39.231787409101216, 41.44530630111694, 39.3752190726144, 40.394881112234934, 43.15930182593209, 46.30946568080357, 47.75899887084961, 49.13104575020926, 47.80695881162371, 48.920720304761616, 46.98806149618966, 50.03005926949637, 50.29816593442644, 50.16605636051723, 49.14570644923619, 51.316024916512625, 51.634019647325786, 48.09645898001534, 47.34332289014544, 48.61932482038225, 51.91395909445626, 53.430427755628315, 52.652107919965474, 45.20170048304966, 54.080977167402, 56.387786047799246, 51.78090109143938, 49.17047330311367, 40.57453373500279, 43.98818022864205, 50.382075854710166, 55.52048410688128, 55.186178479875835, 57.43792288643973, 52.79603637967791, 48.67868675504412, 41.751072202410015, 19.369861466544016, 10.154443093708583, 7.553600345339094, 10.85546943119594, 12.33159077167511, 6.567391276359558, 5.895824432373047, 1.6799965777567454, 0.08534546968128, 0.08114094100892544, 0.08217896388045379, 6.284651270934513, 32.798662253788535, 42.38381685529436, 22.2757214478084, 27.509561470576696, 45.70962422234671, 32.01523201806204, 53.90144961220877, 49.35430874143328, 50.38978835514614, 8.351497599056788, 0.004888928353986037, 0.03824628111241119, 0.02219918237200805, 0.038330941926687956, 0.09242137534809963, 0.02141187310085765, 0.024462486816836253, 0.066065365315548, 0.024013652865375792, 0.046657536910580735, 0.02891345601528883, 0.02631298582335668, 0.03265019246776189, 0.07942914643457957, 0.02868368030924882, 0.06549723472978387, 0.031156000681221485, 0.011626646654414279, 0.054390115197747946, 0.024803908674844673, 0.041083989199250937, 0.04083752492442727, 0.054518897751612325, 0.11649982152240616, 0.1718023797231061, 0.19489327924592154, 0.10837819161159651, 0.09487638289907149, 0.10722914005496673, 0.16898035258054733, 0.1554263305983373, 0.1783391825322594, 0.1854872503983123, 0.05280813455049481, 0.09420392076883997, 0.09797399025410414, 0.10251927242747375, 0.11693915937628065, 0.1457119890089546, 0.08995912782847881, 0.13731600024870463, 0.150388289509075, 0.1558626014739275, 0.1542707583201783, 0.2653518398957593, 15.881975208009992, 65.5236736025129, 68.94949681418282, 63.70679610116141, 52.136926787240164, 31.240987300872803, 17.966151646205358, 32.124009541102815, 56.199910231998985, 39.08122341973441, 6.38425977740969, 0.31258439112986836, 0.22251984610089234, 0.1892784291080066, 0.683398214834077, 4.519489211695535, 16.68805135999407, 18.77748237337385, 15.830744402749197, 19.54989971433367, 22.22555024283273, 40.57009383610317, 51.19673129490444, 61.65944685254778, 55.47100945881435, 56.546375206538606, 54.96094914845058, 54.80064378465925, 52.54164545876639, 46.8672879082816, 51.65562507084438, 59.056582178388325, 57.00540794645037, 52.19812304633004, 52.35100078582764, 55.28046900885445, 55.00063725880214, 47.71551356996809, 41.83166435786656, 42.378536224365234, 52.526977811540874, 54.46897847311837, 53.18789740971157, 47.94347006934029, 52.52750587463379, 57.92862204142979, 53.996671199798584, 45.782576833452495, 42.800760882241384, 43.160291944231304, 41.73850985935756, 41.49950572422573, 42.95101220267159, 42.847685541425435, 43.05239684241158, 43.13502482005528, 48.996094363076345, 53.9346342086792, 53.20118931361607, 51.297184876033235, 52.363260882241384, 52.408504077366416, 57.831135341099326, 50.99149193082537, 54.01273890904018, 35.49533455712454, 30.84948410306658, 59.41564423697335, 51.7615955216544, 54.45469645091465, 49.94108063834054, 51.260216985430034, 42.51634332111904, 44.42091056278774, 41.353072438921245, 41.976694107055664, 44.77001585279192, 47.610026018960134, 50.590719836098806, 50.6025595664978, 50.057007857731406, 51.43388026101248, 48.82521384102957, 53.28685017994472, 50.96316759926932, 51.38566323689052, 49.70063475200108, 53.13443796975272, 53.93662486757551, 49.59599140712193, 47.91168900898525, 49.56923042024885, 54.172471046447754, 56.04143571853638, 54.24340173176357, 45.672180380140034, 54.62712294714791, 59.31919629233224, 53.74705369131905, 50.990804059164866, 42.028402600969585, 45.758112226213726, 53.28162513460432, 56.55857276916504, 58.817452975681846, 59.64949975694929, 53.54525715964181, 51.37069681712559, 42.1624298776899, 25.940437623432704, 22.0743887083871, 19.86298554284232, 25.011996746063232, 18.788566487176077, 18.925939321517944, 4.407280147075653, 1.529736789209502, 0.13471965385334833, 0.18470666371285915, 0.1527795283389943, 7.839232104165213, 39.677309376852854, 58.53439726148333, 28.693789856774465, 28.300481864384242, 50.00297519138881, 36.7125894682748, 60.70093590872628, 55.617383684430806, 57.872880118233816, 12.578529749597822, 0.1937856658228806, 0.20430270076862403, 0.1345836075821093, 0.15479439736476966, 0.2372960453586919, 0.13114680057125433, 0.14260695848081792, 0.14967730694583484, 0.13840560535235064, 0.17692340564514908, 0.21609820425510406, 0.07065913560135023, 0.1662254189806325, 0.08779114737574543, 0.1495782272624118, 0.12795341121298925, 0.16826782295746462, 0.13125372411949293, 0.15553957809294972, 0.12190835630255085, 0.11694166995584965, 0.17028512113860675, 0.11450552567839622], [0.060497578366526535, 0.06311964123908963, 0.052015079784074, 0.06589597583349262, 0.014213153443831419, 0.028999612999281714, 0.08934761849897248, 0.014710413591404046, 0.07425784785300493, 0.02897701778316072, 0.07457914096968514, 0.03013767907395959, 0.06857937827174153, 0.03683526414845671, 0.035055555004094324, 0.009980301871629698, 0.07663553633860179, 0.032183943915047815, 0.04673396709508129, 0.030911979132464955, 0.07054681769971337, 0.42253271277461735, 17.46279808453151, 60.28639248439244, 54.52792698996407, 47.06676026753017, 37.18157202856881, 21.08504339626857, 22.49103569984436, 39.20787518365042, 45.02249949319022, 19.04422719138009, 0.8128939632858548, 0.09540801508618252, 0.1013971519257341, 0.13192829649363244, 1.8748013760362352, 4.4898204037121365, 5.371292327131544, 8.217391286577497, 5.398099780082703, 12.273712277412415, 23.85334120477949, 50.874386991773335, 53.74041468756539, 55.64928981236049, 49.650715419224326, 48.39998756136213, 44.4718964440482, 43.92163733073643, 42.232304436819895, 42.58552653448922, 52.3939927646092, 53.70528112139021, 54.121842997414724, 50.74570982796805, 50.59576422827584, 51.73907988412039, 50.60611704417637, 41.29196650641305, 35.67758233206612, 38.962225096566335, 46.98352779660906, 50.26964357921055, 49.83371707371303, 48.96121788024902, 51.53359733309065, 49.91484076636178, 47.82454817635672, 38.56231457846505, 36.64143296650478, 35.99497604370117, 36.59385517665318, 35.63111277988979, 37.92371259416853, 38.10770436695644, 40.45204741614205, 37.36874607631138, 41.215981006622314, 41.96463203430176, 46.983764035361155, 44.48331233433315, 47.285447869982036, 47.5345790045602, 52.73169953482491, 49.55510125841413, 55.672434261866975, 29.918088504246303, 24.461807114737375, 54.933295318058555, 44.8061534336635, 51.81197343553816, 45.03954689843314, 47.130339758736746, 39.08120952333723, 37.81166941779, 39.22152839388166, 37.445985725947786, 35.23734794344221, 41.38672603879656, 40.36417702266148, 43.54624353136335, 40.60088130405971, 43.21527998788016, 41.94924177442278, 44.27149302618844, 45.188874108450754, 45.40906599589756, 44.66749518258231, 46.52196591241019, 48.0833546774728, 46.78094264439174, 45.24012054715838, 51.62967702320644, 46.26846088681902, 48.538583278656006, 49.9129821232387, 51.76928717749459, 46.96861348833357, 52.525410992758616, 52.011258193424766, 49.23523398808071, 41.45165000643049, 39.48930849347796, 43.3007185118539, 50.75256769997733, 52.74421671458653, 55.33652360098702, 53.54690040860857, 49.56324107306344, 43.78928109577724, 40.66786888667515, 18.034202303205216, 12.942809905324664, 9.18038989816393, 6.534604029996054, 3.618054462330682, 5.917298708643232, 1.3847160509654453, 0.2975227864725249, 0.043209262657910585, 0.03871453134343028, 0.6256636785609382, 17.403227703911917, 37.09140525545393, 37.25363179615566, 16.691052981785365, 14.7318503175463, 29.073364734649658, 39.54153462818691, 48.177662576947895, 44.45058284487043, 24.107640062059673, 0.9123926013708115, 0.025586678546720316, 0.10554789312716041, 0.026295864688498632, 0.010595185216516256, 0.05202239099889994, 0.004619002458639443, 0.040933836184974225, 0.0264698597269931, 0.027823633780436854, 0.06628155335783958, 0.05722409473466022, 0.02129194712532418, 0.037257197579102855, 0.06805331685713359, 0.02945283367963774, 0.05224177833380444, 0.006459676278089839, 0.011376649756649775, 0.06148246516074453, 0.07429888565093279, 0.021708420045407753, 0.024791674688458443, 0.017391224025881717, 0.037474525560225756, 0.07393687364778348, 0.045363889541476965, 0.019026639305853417, 0.024331997747399976, 0.05224930667983634, 0.03237698712785329, 0.01121717960839825, 0.006531940681660282, 0.042462772357144525, 0.07466564061386244, 0.051637424156069756, 0.021262298537684337, 0.020271924091503024, 0.01581998967698642, 0.02668139980440693, 0.09094022839729275, 0.04249953877712999, 0.029509474390319416, 0.02808920051237302, 0.5194144312824521, 24.22999610219683, 68.65082849775041, 59.3703419821603, 53.85885715484619, 44.998479570661274, 28.256041186196462, 24.406674895967754, 33.677147320338655, 42.373040199279785, 20.494969367980957, 1.164110202874456, 0.053199920670262406, 0.058581884019076824, 0.4011649936437607, 2.7411752981798987, 6.28351046357836, 6.878522489752088, 8.695680090359279, 6.371781247002738, 10.435084308896746, 28.785990715026855, 47.62788636343819, 55.94995920998709, 57.67341818128313, 52.67002732413155, 51.215890952519004, 48.29285676138741, 46.50900404793875, 44.40004859651838, 44.328172956194194, 54.373833315713064, 55.90356261389596, 54.702083587646484, 51.28213855198452, 50.96948003768921, 52.33997746876308, 52.88661657060896, 43.563026905059814, 38.20346096583775, 40.42104107992989, 49.97975778579712, 52.35491262163435, 50.40564414433071, 48.10218776975359, 53.8664584841047, 50.789063113076345, 49.44698034014021, 40.81965228489467, 38.18970353262765, 38.66894163404192, 37.37429073878697, 37.70488255364554, 40.50044856752668, 41.3746292250497, 41.77493231637137, 39.72007206508091, 42.73700768607003, 43.381130014147075, 48.93890374047415, 46.38273096084595, 49.37369074140276, 49.41525486537388, 55.31762102672032, 50.54779039110456, 55.335877418518066, 31.648075308118546, 26.603677919932775, 56.486672810145784, 47.34946857179914, 53.67519542149135, 46.59224346705845, 49.945666449410574, 40.94904511315482, 39.01031010491507, 40.25850534439087, 39.49627406256539, 36.751919746398926, 43.04048763002668, 43.25007309232439, 44.358178751809255, 42.66067130225045, 45.514654295785085, 43.28643648965018, 46.069064957754954, 46.58846364702497, 46.974613257816856, 48.011652742113384, 48.13904448917934, 50.01646164485386, 48.90868255070278, 46.88894196919033, 51.77227142878941, 49.11152131216866, 50.10202176230294, 51.830528599875315, 53.66598558425903, 47.62928295135498, 52.88001230784825, 54.80104330607823, 50.399894509996685, 43.030155658721924, 41.416752679007395, 46.46333006450108, 51.681913580213276, 54.97433485303606, 54.976061480385916, 54.94444717679705, 50.27147790363857, 46.43735769816807, 41.45557573863438, 13.988559825079781, 10.53039448601859, 7.27122859443937, 10.242062483515058, 7.460666452135358, 6.9292013474873135, 5.633961592401777, 0.45949930059058325, 0.20695105008780956, 0.07198027042405945, 0.7123424017003605, 20.53019326073783, 42.09650536945888, 36.00332430430821, 21.91189292498997, 19.924016782215663, 32.62977933883667, 47.077404907771516, 53.49721384048462, 51.73307316643851, 28.923448664801462, 1.0959604254790714, 0.08641366700508765, 0.04301959854949798, 0.053670508454420736, 0.012850254790724387, 0.05464236059093049, 0.023355989583900998, 0.037281014158257415, 0.03504804701411298, 0.021868391461404305, 0.041811222676187754, 0.03922185840617333, 0.045199073385447264, 0.07901238344077553, 0.01026667163906885, 0.017109584495691315, 0.05848326573946646, 0.02161029031101082, 0.05294430635071226, 0.028043821786663363, 0.03439483492236052, 0.04306979996285268, 0.034992943185248544, 0.14283517694899014, 0.10014530909912926, 0.29801798132913454, 0.13594058262450354, 0.09246699325740337, 0.12503826192447118, 0.14121277257800102, 0.10749281197786331, 0.10973189611520086, 0.17299863696098328, 0.17740462268037455, 0.16002249611275537, 0.14238346261637552, 0.11376115240688835, 0.09589879946517092, 0.10814960673451424, 0.18288981834692614, 0.18194995235119546, 0.1271009405276605, 0.08455279150179454, 0.10683965416891233, 0.8533684142998287, 30.513431004115514, 76.87104770115444, 66.43446431841168, 60.94001647404262, 49.484451975141255, 30.851162093026296, 31.240591253553117, 52.68065111977713, 56.334875515529085, 25.592433622905187, 1.4479548633098602, 0.20156767538615636, 0.30849317780562807, 0.4719901531934738, 4.6224172200475415, 12.73368215560913, 12.698049187660217, 14.272525753293719, 13.849434307643346, 18.793055023465836, 28.613388776779175, 53.15045356750488, 56.377513136182515, 59.4458133152553, 53.58545248849051, 52.453549248831614, 49.64040081841605, 49.312174865177695, 45.94927453994751, 46.388240882328574, 57.04311582020351, 58.41946710859026, 56.311310700007844, 51.93724945613316, 52.05047730037144, 55.20529644829886, 56.26348277500698, 45.42019353594099, 40.2583281653268, 43.26088101523263, 51.983413287571494, 55.03754956381661, 50.667740617479595, 48.15132195608956, 55.156381130218506, 53.174105235508506, 51.480763231004985, 42.833365304129465, 39.391120025089805, 40.78599173682076, 39.81273324148995, 39.90745455878121, 42.25537593024117, 43.13341978618077, 43.898402554648264, 41.60463196890694, 44.22495746612549, 46.94278008597237, 50.81264182499477, 48.880115032196045, 50.35838597161429, 52.64743525641305, 57.23616109575544, 53.22488614491054, 55.49171161651611, 33.51641811643328, 29.500022343226842, 57.55593803950718, 50.227961335863384, 56.18536417824881, 49.39738757269723, 52.76868827002389, 42.55370725904192, 42.30957882744925, 42.88321515492031, 42.50459739140102, 38.276604652404785, 45.13699190957205, 44.70764534814017, 47.449567794799805, 45.67373330252511, 47.938797405787874, 45.286603995731895, 49.194875376565115, 48.28192029680525, 48.92618158885411, 49.28079332624163, 51.440821511404856, 50.85768004826137, 50.79769277572632, 47.99632849012102, 54.004793643951416, 50.97911718913487, 53.263208934238975, 54.29075370516096, 56.10516112191336, 48.004287651606965, 55.04869794845581, 55.64324140548706, 53.08896548407418, 45.16190814971924, 44.074390002659385, 48.10788876669747, 56.13930804388863, 56.44936793191092, 58.77662536076137, 55.932786737169536, 53.11617462975638, 49.017522607530864, 46.236290727342876, 22.451589039393834, 24.53222015925816, 23.922750234603882, 17.125306708472117, 14.527716585568019, 13.282212904521398, 4.172933042049408, 0.4606051498225757, 0.3813424887401717, 0.1396175231784582, 1.1155274212360382, 24.176934446607316, 49.82450376238142, 50.25941583088466, 26.841471331460134, 24.211652857916697, 42.897625718797954, 52.822015694209504, 60.0417811529977, 57.4037446975708, 36.462221554347444, 1.3748537344591958, 0.16341924241610936, 0.14463439397513866, 0.13257361043776783, 0.13993267555321964, 0.1988587464605059, 0.12318784264581543, 0.20840760692954063, 0.13428278586694173, 0.1145665802593742, 0.1644240849252258, 0.16968847172600882, 0.06252215722841875, 0.18543193622359208, 0.14189801152263368, 0.07299102297318832, 0.13759437602545532, 0.1280369253030845, 0.10581484915954725, 0.10790984638567482, 0.11389533270682607, 0.1496129682553666, 0.13266228139400482], [0.05378473303946001, 0.008830482722260058, 0.024178221356123686, 0.010924345098568924, 0.04525747150182724, 0.06187671436262982, 0.0333524287146117, 0.026170401867212992, 0.1207678203604051, 0.02126864453644625, 0.017282307281025817, 0.021005584991403987, 0.009577414918957012, 0.029370883612760475, 0.025709130368860703, 0.043331924825906754, 0.027546308036627512, 0.057217295813773356, 0.0331716466295932, 0.03999788872897625, 0.02948163409850427, 3.4189785846642087, 42.37342929840088, 57.32785994665963, 51.003752027239116, 41.201876163482666, 31.502795423780167, 13.475737605776105, 17.25885455948966, 36.42949901308332, 40.37711456843785, 8.817595788410731, 0.1847194880247116, 0.05495173524000815, 0.023784699883045893, 0.06199988882456507, 2.075412154197693, 2.855252125433513, 7.925618188721793, 7.776522874832153, 11.889751349176679, 21.47252185004098, 42.328252111162456, 53.71211467470442, 57.01113673618862, 52.24485663005284, 53.43616696766445, 48.1188634463719, 43.07416902269636, 39.80011878694807, 41.726718766348704, 47.59855801718575, 51.38061537061419, 51.234251567295615, 52.734728949410574, 50.08677394049508, 51.428821972438264, 51.669563157217844, 49.663972582135884, 40.963021414620535, 37.372984477451865, 38.66072538920811, 44.65898363930838, 50.024274894169395, 49.20467928477696, 48.45660148348127, 50.62770162309919, 48.7102107320513, 44.61404269082205, 35.94190917696272, 37.77149493353707, 36.02315098898751, 36.656555720738, 34.569928305489675, 37.554280349186485, 38.270080293927876, 41.44552516937256, 36.890553678785054, 39.198067801339285, 39.896646635872976, 40.77295691626412, 41.065059185028076, 44.95404931477138, 49.36485958099365, 53.01842042378017, 47.71000712258475, 55.65559877668108, 32.72848197392055, 23.975740671157837, 54.32379238946097, 44.14640808105469, 52.56958416530064, 43.99587535858154, 45.08441489083426, 39.91244683946882, 38.45547560283116, 37.05907876150948, 38.642336981637136, 34.95421232495989, 37.592544078826904, 37.99411521639143, 38.059007917131694, 38.73457779203142, 40.052824769701274, 39.75347205570766, 40.91927555629185, 40.750767844063894, 42.29342426572527, 41.21824959346226, 45.97649410792759, 48.99128968375069, 48.1414589881897, 47.22823987688337, 48.912691661289756, 44.405746119362966, 45.77033410753523, 47.59384019034249, 49.86922584261213, 49.1377021244594, 48.90188373838152, 52.06423125948225, 49.12514672960554, 44.76174054827009, 39.97900710787092, 39.628446170261924, 44.466191973005024, 50.30877930777413, 52.940096855163574, 53.372733388628276, 53.115458965301514, 45.31905208315168, 42.0905750819615, 26.594275270189556, 14.390553934233528, 7.010136135986873, 12.807753426688057, 3.1337352735655646, 9.617943150656563, 5.104397688593183, 0.567265969301973, 0.08391920942813158, 0.03427323126899345, 0.020385242832292403, 5.121636169297354, 35.23178938456944, 32.07907554081508, 21.960898569652013, 18.776195219584874, 22.304641587393625, 29.040039437157766, 38.5651980808803, 47.74028042384556, 31.913256781441824, 3.2950631082057953, 0.018178862386516163, 0.07153988762625627, 0.08710562344640493, 0.002647679477896807, 0.05809923527496202, 0.04208977147936821, 0.019311045562582355, 0.08207661365824086, 0.008686706240821098, 0.029738686912293946, 0.0035702566133945113, 0.05560140537896326, 0.045985654927790165, 0.02339518685559077, 0.04264706586088453, 0.0558122397799577, 0.0354057367491935, 0.011702388974039682, 0.048764591703989675, 0.016636252037382553, 0.06375645313944135, 0.06660629343241453, 0.03464761296553271, 0.04231505189090967, 0.02340465072276337, 0.011034115949379546, 0.04244465547214661, 0.03479055315256119, 0.03385069054950561, 0.05588061236111181, 0.05779514980635472, 0.0608038351471935, 0.07153096489076104, 0.02087223420052656, 0.007026848857224519, 0.033285525161772966, 0.009044576635850328, 0.04247273325121828, 0.02822954360661762, 0.030852838020239557, 0.07118245573448283, 0.08576151342796427, 0.02993543153362615, 4.640110373497009, 49.594421114240376, 62.850715500967844, 57.24727821350098, 45.28687844957624, 38.69263846533639, 17.50169931139265, 21.12916272027152, 38.78157540730068, 42.41798462186541, 9.65906172139304, 0.21308362244495324, 0.03348921798169613, 0.16198553863380635, 0.8597740562898772, 4.0429704615048, 7.4491715260914395, 7.196778212274824, 4.98544670002801, 8.270989690508161, 20.10392996243068, 39.27978209086827, 53.53476537976946, 57.47202811922346, 54.948293004717144, 55.02101979936872, 49.76024334771292, 46.11566999980381, 41.8011200768607, 42.37849453517369, 51.61335570471627, 52.59657096862793, 53.20008455004011, 53.56542778015137, 51.1009156363351, 52.605450766427175, 51.68129171643938, 51.39669002805437, 43.31977047239031, 39.32788099561419, 41.234862736293245, 48.00512490953718, 51.27712542670113, 50.44825397218977, 48.104772499629426, 51.89392743791853, 51.38597590582711, 47.33791371754238, 36.963829381125315, 37.30054603304182, 36.856726373944966, 39.61228813443865, 37.20877422605242, 39.98508678163801, 40.619148118155344, 43.600981439862935, 38.14845902579171, 40.68780326843262, 41.8049624306815, 43.67872135979788, 42.6393472807748, 47.415094307490754, 52.591078417641775, 54.18575947625296, 49.135037490299766, 56.308215277535574, 33.41853884288243, 25.113372700554983, 55.207394804273335, 47.21205404826573, 53.390895979745046, 47.837423188345774, 47.09503596169608, 41.72603089468819, 39.904612745557515, 38.57643679210118, 40.17530761446272, 37.39485740661621, 40.615743500845774, 39.45267759050642, 40.39633328574044, 41.77497400556292, 41.31668472290039, 41.8821291242327, 41.91808257784162, 41.86270890917097, 45.72302382332938, 44.3778213092259, 48.45569821766445, 49.96988786969866, 48.638175283159526, 49.056429045540945, 50.68291548320225, 46.169754777635845, 47.19488852364676, 49.40600333895002, 52.96466221128191, 49.84152684892927, 49.00800010136196, 53.52422843660627, 51.245830740247456, 46.20082712173462, 40.73663173403059, 41.160173075539724, 46.41549171720232, 51.927890232631135, 54.5378212247576, 55.03237315586635, 54.893732275281636, 47.38164567947388, 44.1196470941816, 29.171310016087123, 12.107421909059797, 3.5125784192766463, 10.634025999477931, 10.081358466829572, 10.104378717286245, 6.4893868906157355, 2.1967174964291707, 0.15675730417881692, 0.11339692837957825, 0.045581217522599866, 6.019907968384879, 40.09886353356497, 36.947973591940745, 20.916158744267054, 22.361748831612722, 31.526926517486572, 35.00338472638811, 43.10500512804304, 53.208088874816895, 39.726617268153596, 4.469061357634408, 0.06447188689240388, 0.05432002931567175, 0.04349527534629617, 0.029454662331512997, 0.05951920550848756, 0.10139787117285387, 0.043041101324238946, 0.10835533176681825, 0.02496181395170944, 0.0766364862876279, 0.03446861882028835, 0.028147610503115823, 0.01818254852800497, 0.06455440353602171, 0.023902440975819315, 0.09254662612719194, 0.017949858514059867, 0.031997207685240676, 0.056798415790711126, 0.009176831592672637, 0.043145358229854276, 0.014463124896532722, 0.18482818933469908, 0.1179826512400593, 0.12739465119583265, 0.10329670392509017, 0.09495214811925377, 0.1529013253748417, 0.16203705301242216, 0.12237361419413771, 0.2708725093730858, 0.11374949517526797, 0.17320519659136022, 0.09625775806073632, 0.10705979807036263, 0.2030322253704071, 0.16555756410317762, 0.10238581816000597, 0.11114520313484327, 0.10823927513722863, 0.2537843648876463, 0.16218710424644606, 0.18001527259392397, 6.390910940510886, 57.84383317402431, 68.9638170514788, 66.48520701272147, 52.195163113730295, 43.769207750047954, 20.906267983572825, 25.056793519428798, 48.56961393356323, 51.3341041292463, 11.736819761140005, 0.6738155090383121, 0.17300995492509433, 0.27228326510105816, 1.077753213899476, 4.698073548930032, 10.33392288003649, 19.92134346280779, 20.386808497565134, 20.09605244227818, 28.286945036479406, 47.06730917521885, 54.74697937284197, 59.35069942474365, 56.34358160836356, 58.337165696280344, 53.12209449495588, 47.30709498269217, 43.8685530935015, 45.69627325875418, 54.006891999925884, 55.11662353788103, 54.862163134983604, 53.980996063777376, 52.09271192550659, 54.208563464028494, 55.27615417752947, 52.99438313075474, 44.44747700010027, 41.99100044795445, 43.13032783780779, 48.95376941135952, 54.36414752687727, 51.0403481892177, 48.81349570410592, 53.11074113845825, 52.83842733928135, 51.104810101645334, 39.003042289188926, 40.42156219482422, 39.564682551792686, 41.32942771911621, 38.65009464536394, 42.37926925931658, 42.700338568006245, 46.31415571485247, 40.785147530691965, 43.108962127140586, 43.499673230307444, 46.387949057987754, 45.06662055424282, 48.96465029035296, 55.77198805127825, 55.96882356916155, 50.513883181980674, 55.17592988695417, 36.05929204395839, 29.001872982297623, 55.72999313899449, 49.222591740744456, 56.37755829947335, 48.379375730242046, 48.19421666009085, 44.727100304194856, 41.304553168160574, 40.74065126691546, 42.32381221226284, 39.58734062739781, 40.8881893157959, 40.86996766499111, 41.58376652853829, 44.192085538591655, 44.473661286490305, 43.838196413857595, 45.46623229980469, 45.0250494820731, 46.47900867462158, 45.62833724703108, 51.27609361921038, 53.10143402644566, 50.82705238887242, 50.5294679914202, 52.555138860430034, 49.03591448920113, 49.73244707924979, 51.86413703645979, 54.80289152690342, 51.09245273045131, 49.89352369308472, 55.90653991699219, 54.000513553619385, 50.73211567742484, 43.963660035814556, 43.00852939060756, 47.708607060568674, 54.764252594539094, 57.30987800870623, 58.10364368983677, 57.16297224589756, 48.5166061265128, 46.135524477277485, 32.11206906182425, 17.271569762911113, 11.075975724628993, 20.190540994916642, 11.527818816048757, 20.370745999472483, 10.028677225112915, 2.5172891403947557, 0.30817586768950733, 0.3179891125432083, 0.10233873461506196, 7.883671913828168, 46.6370975630624, 44.452976499285015, 31.83511734008789, 27.96850562095642, 33.59796564919608, 39.53453779220581, 50.55002771105085, 60.86097376687186, 47.01556594031197, 6.504526146820613, 0.2076344434171915, 0.13735097194356577, 0.16143485318337167, 0.08870573115668126, 0.17932417110673018, 0.20289197218205246, 0.1184542059366192, 0.15650543197989464, 0.10025162875120129, 0.1395862020019974, 0.11279147158243827, 0.11656998204333441, 0.18919104736830505, 0.13116077839263848, 0.07490082085132599, 0.1536464246788195, 0.14947770908474922, 0.09625158339206662, 0.1375775212155921, 0.10746550094336271, 0.13353257040892327, 0.08994258514472417], [0.018991058625813042, 0.03083508075880153, 0.02729968600241201, 0.011164315793264126, 0.040997068863362074, 0.015376056444698145, 0.02268504397943616, 0.005193875137982624, 0.06349500002605574, 0.03704443953133055, 0.017089516822514788, 0.059413265836025984, 0.010318157179946346, 0.02158687576385481, 0.04670491222558277, 0.02762280437829239, 0.03736806680847492, 0.02972750465518662, 0.028708043109093393, 0.0294987399663244, 0.04584397681589637, 9.429243104798452, 55.26019763946533, 53.31003284454346, 47.79406990323748, 31.98185634613037, 31.11245952333723, 25.852817365101405, 41.372503076280864, 37.93267229625157, 26.20697225843157, 2.0240786458764757, 0.03437311840908868, 0.018799867813608477, 0.05572969260226403, 0.43643909799201147, 2.9353644209248677, 6.344747109072549, 3.6170673838683536, 6.700243873255594, 14.180333580289568, 30.26455695288522, 48.34271356037685, 55.04229865755354, 56.293415614536826, 56.14909110750471, 51.86856998716082, 47.56318473815918, 40.08148608888899, 39.07824959073748, 46.70540877750942, 51.1285069329398, 53.16338416508266, 52.00102349690029, 50.54808916364397, 49.57274273463658, 48.79333897999355, 52.17274475097656, 47.74783311571394, 41.49914789199829, 37.38124935967581, 39.55340909957886, 46.81309543337141, 48.0817357472011, 50.96317107336861, 48.540820598602295, 50.26784399577549, 48.56526436124529, 39.11708307266235, 35.418084485190256, 36.413747446877615, 37.11354569026402, 36.46921491622925, 37.145761013031006, 38.78878763743809, 38.92188385554722, 38.627294131687705, 38.0952844619751, 40.4177302633013, 37.26618024281093, 38.22362116404942, 39.37625782830374, 41.06199502944946, 44.57938160215105, 50.189777510506765, 47.55336345945086, 52.20089537756783, 33.97180305208479, 24.219108275004796, 57.118795599256245, 46.87893656321934, 48.350109917776926, 42.96020466940743, 43.28371626990182, 40.022596631731304, 38.947758947099956, 36.94112614222935, 39.49697583062308, 36.54507187434605, 36.04878289358956, 35.68318258013044, 38.372732979910715, 37.16419110979353, 37.29826354980469, 36.606379304613384, 35.63284982953753, 38.66314683641706, 38.6878650529044, 39.108783449445454, 44.37177637645176, 47.85878195081438, 46.873676776885986, 47.05562925338745, 50.53581517083304, 45.316575050354004, 40.92089796066284, 44.352106026240754, 48.73385892595564, 49.43673174721854, 50.018626008714946, 50.091797488076345, 50.2178030695234, 46.67491660799299, 43.1272428376334, 38.89449405670166, 42.63056823185512, 45.72534799575806, 51.58653218405587, 50.471513066973, 53.318210874285015, 47.271992683410645, 46.79970278058733, 41.52180944170271, 26.003197227205547, 8.3090432371412, 4.5528244972229, 5.811592289379664, 4.479012046541486, 9.686159695897784, 1.2146135100296565, 0.20383855567446776, 0.061657018294291835, 0.08547477809978382, 0.502876415848732, 18.56090702329363, 40.27827991758074, 36.87978744506836, 16.60262152126857, 24.34175613948277, 22.5297805922372, 44.99229914801461, 43.09128243582589, 37.241750376565115, 9.735771570886884, 0.05096947428371225, 0.06259186313088451, 0.022111249322603856, 0.022096976338486587, 0.01979066973685154, 0.053463952216718874, 0.034863393886813095, 0.029994423368147442, 0.025132056691550782, 0.034381447426442585, 0.01968602436993803, 0.00890833358945591, 0.015116895083338022, 0.04948050043146525, 0.02853174614054816, 0.044938366660582166, 0.03393442177080682, 0.02840518918154495, 0.045918999040233235, 0.02430612181446382, 0.032941823426101885, 0.05176026952852096, 0.03127970779314637, 0.028355737549385855, 0.03599829459562898, 0.04206535439672215, 0.0067465227163795915, 0.046154019821967394, 0.018030806045447077, 0.020106731348537972, 0.029692454928798333, 0.1284673743482147, 0.04287115205079317, 0.03603350377774664, 0.03343554925439613, 0.02721000911800989, 0.027905380286808525, 0.04610088713733213, 0.053562339794422896, 0.015744205797091126, 0.034281845271055184, 0.004596254148054868, 0.04428824529583965, 12.755593299865723, 64.28612995147705, 59.838115555899485, 54.48093284879412, 36.201994146619526, 38.279244967869346, 28.240697826657975, 31.633574417659215, 37.4392911366054, 31.044155257088796, 2.231677791901997, 0.03205570758187345, 0.04185366164892912, 0.44408086793763296, 2.1133273882525305, 3.9226993152073453, 8.168853776795522, 5.7525951351438245, 8.882775102342878, 16.491372176579066, 32.78087486539568, 48.34418657847813, 54.83132355553763, 56.521823746817454, 58.41215065547398, 54.304959297180176, 50.43354116167341, 42.06290735517229, 41.208529063633506, 48.51940972464425, 53.33178070613316, 55.23857137135097, 53.034439495631624, 49.2510724067688, 50.42766298566546, 50.22662728173392, 53.22893694468907, 49.120484488351, 43.59751081466675, 39.39493111201695, 41.98507363455636, 48.26912866319929, 51.05710029602051, 51.243478775024414, 50.562061991010395, 51.689191818237305, 50.963893686022075, 41.02057681764875, 36.72012826374599, 37.902916635785786, 38.08625875200544, 39.662568773542134, 41.00210155759539, 40.43734850202288, 40.327198709760395, 40.488032136644634, 39.07537998471941, 40.873479979378835, 39.610276630946565, 40.87597785677229, 40.64783723013741, 42.782952649252756, 46.90531192507063, 50.840959208352224, 49.07453257696969, 53.75750725609915, 34.28160585675921, 25.57007953098842, 58.41499246869768, 47.64485386439732, 50.06140954153878, 44.13201836177281, 45.116842133658274, 42.36031804765974, 40.4695395060948, 38.270198413303916, 40.428433963230674, 37.78888627461025, 37.85830920083182, 37.7863119670323, 39.80254718235561, 38.296677998134065, 38.628478799547466, 38.64819778714861, 38.149202483040945, 40.379935537065776, 40.46316105978829, 40.49330929347447, 46.558169501168386, 50.235500131334575, 49.531793526240754, 48.125703947884695, 52.271773951394216, 48.092286586761475, 42.81845446995327, 47.054774624960764, 51.68271262305123, 50.9897757257734, 50.73805638722011, 51.79120526994978, 53.80693326677595, 49.47192784718105, 44.88945538657052, 40.88090065547398, 44.13377973011562, 46.73317377907889, 53.95379386629377, 53.39664561407906, 54.223203318459646, 48.665245464869905, 49.32534517560686, 42.06833389827183, 24.88837787083217, 8.189119066510882, 6.221459576061793, 11.698516079357692, 10.805033326148987, 11.504697816712515, 4.7035335302352905, 1.0853409724576133, 0.1537878042353051, 0.044476477695362907, 1.0699020751885004, 18.8565285546439, 40.099527086530415, 36.16431059156145, 21.84465868132455, 26.63496913228716, 29.040086337498256, 50.712865693228586, 49.4326878956386, 43.3625123160226, 12.010281750134059, 0.0652352591444339, 0.02806103282741138, 0.026660412716280137, 0.023851505048306923, 0.05334206357864397, 0.046021349262446165, 0.0289118139605437, 0.02793135630365993, 0.056890330144337246, 0.017186196188309362, 0.05028214205854705, 0.04669705818274191, 0.0875840720587543, 0.009437551888238107, 0.0196424149242895, 0.036952691418784, 0.07170145359954663, 0.06919139650251184, 0.041778693707393746, 0.024949115168835436, 0.03717607193227325, 0.06284957073096718, 0.12390654693756785, 0.10224858445248433, 0.1297438344252961, 0.10111095942556858, 0.11040112841874361, 0.07326451329780476, 0.15348627684371813, 0.08660981790827853, 0.11538717336952686, 0.1818822074149336, 0.1389213733907257, 0.11909206956624985, 0.1390675434044429, 0.13822571214820656, 0.15567958700869763, 0.1540825462767056, 0.1164790176387344, 0.1218348438186305, 0.054225804550307136, 0.13489630366010325, 0.12576536647975445, 16.991849184036255, 71.9718450818743, 67.6939364842006, 62.71873446873256, 44.085993494306294, 41.6238055229187, 34.51534325735909, 53.57446043831961, 48.48367861339024, 36.110270977020264, 3.33849173784256, 0.10711140065853085, 0.08865509208823953, 0.25568990835121697, 2.0497192357267653, 9.526436243738447, 16.4474595614842, 10.66427150794438, 13.669404745101929, 20.669601917266846, 36.574059758867534, 51.450243268694194, 55.27509110314505, 58.04932614735195, 59.37662315368652, 55.97649090630667, 52.201774324689595, 44.85933494567871, 42.94942453929356, 51.38253654752459, 55.95713669913155, 57.30103642599923, 54.95890637806484, 50.37371369770595, 51.73348658425467, 51.04133135931832, 55.87884439740862, 53.518603869846885, 45.840389319828574, 40.63374628339495, 44.291705335889546, 51.082541125161306, 51.832345553806846, 52.59481654848371, 51.0586427961077, 54.087508474077495, 53.654163224356516, 42.94386945452009, 39.390897682734895, 40.61588246481759, 41.353294781276155, 41.27547148295811, 42.68608781269619, 43.911426952907014, 43.21187884466988, 41.85981151035854, 42.456338678087505, 41.90125404085432, 41.19632455280849, 42.63799933024815, 42.533866677965435, 45.38050195149013, 49.581452301570344, 52.11977515901838, 51.526134967803955, 53.53940330232893, 35.82988337108067, 29.04260332243783, 59.0031018938337, 51.038541657584055, 50.418039730616975, 46.400667735508506, 47.74083627973284, 45.089942182813374, 43.24562624522618, 41.296458516802105, 43.50280686787197, 40.02772787639073, 40.06950044631958, 39.21318013327462, 41.65909194946289, 42.194332531520296, 40.467135429382324, 41.10953113010952, 39.21390969412667, 42.27068281173706, 41.3920761517116, 43.05416168485369, 48.52592713492257, 51.998952933720176, 50.70633438655308, 48.58880833217076, 54.52765253611973, 50.61249201638358, 46.00424868719918, 49.5136205128261, 53.14919246946062, 53.339229175022666, 51.10324675696236, 52.60356433050973, 55.081698417663574, 52.184039047786165, 47.84145661762783, 43.28118365151541, 46.76826218196324, 49.73503180912563, 56.88910552433559, 57.44560064588274, 56.24285357339041, 51.41316073281424, 51.73808976582119, 40.95661517551967, 29.962049756731304, 13.051950471741812, 12.18391375882285, 14.051087532724653, 13.491069674491882, 20.605730601719447, 4.746581094605582, 0.9626317684139524, 0.20656068889158113, 0.17515499410884722, 1.242659479379654, 25.81832824434553, 52.758269446236746, 50.09674807957241, 24.332747800009592, 34.15009730202811, 34.90612036841256, 57.42662858963013, 55.45548023496355, 51.310039043426514, 16.952649184635707, 0.21881423065704958, 0.11699645487325532, 0.1540042297648532, 0.1244798411748239, 0.15615047674093926, 0.09506777048643146, 0.07587221158402306, 0.139097928202578, 0.18040841578372888, 0.09621245906289135, 0.0900139534579856, 0.11780091242066451, 0.13934252650610038, 0.17606581880577973, 0.14484601547675474, 0.13318035645144327, 0.08997588764343943, 0.1835660192051104, 0.1466934492013284, 0.11737344892961638, 0.10702344894941364, 0.12548454797693662], [0.04431465727144054, 0.06563884498817579, 0.0302401887519019, 0.01371265244337597, 0.048894755076617, 0.028931169171950648, 0.03663396994982447, 0.01649921340867877, 0.041652302989470105, 0.058207712668393335, 0.04246407175170524, 0.06914329515503985, 0.013880882478718246, 0.0627446827877845, 0.030991113279014826, 0.04771830088325909, 0.016870400901617746, 0.041354178451001644, 0.043484992148088555, 0.04969741789890187, 0.3044348598590919, 16.637975692749023, 50.46603441238403, 49.35904393877302, 45.188050746917725, 30.112231595175608, 18.07158534867423, 18.60058123724801, 37.12882130486624, 39.143830163138254, 17.5233724798475, 0.37366424075194765, 0.15269635351640837, 0.03686478042176791, 0.3135096143398966, 1.542749896645546, 4.588760146072932, 5.380757510662079, 4.07415006841932, 8.531517607825142, 27.130179405212402, 44.685612610408235, 54.580316407339915, 54.12943043027605, 53.876509053366526, 53.30329309191023, 53.73348733357021, 47.635126386369976, 39.222087723868235, 43.60944087164742, 51.565802233559744, 51.93676308223179, 52.68457337788173, 49.85044138772147, 49.87052515574864, 46.9029495375497, 50.07917955943516, 50.75364467075893, 46.40348175593785, 40.79116119657244, 38.42006410871233, 40.996747970581055, 45.411786215645925, 48.934891155787874, 49.477041721343994, 49.67716373716082, 50.13663421358381, 42.75283568246024, 37.13392128263201, 37.058394363948274, 36.817149434770855, 38.64350427900042, 38.48252493994576, 39.03513254438128, 40.07708787918091, 37.86345781598772, 39.22529779161726, 38.85755395889282, 36.000166348048616, 37.24644388471331, 39.092326641082764, 38.16455452782767, 40.06427192687988, 42.033419200352256, 52.01397841317313, 48.084449018750874, 53.8731495993478, 37.0239382471357, 25.904741253171647, 55.593638215746196, 46.02985627310616, 48.37421669278826, 41.293029580797466, 42.950828075408936, 40.42361886160714, 42.75681700025286, 40.29505634307861, 38.340541975838796, 38.44668960571289, 37.392338684626985, 36.56122991016933, 38.47206790106637, 39.27687079565865, 39.36485583441598, 36.1312267439706, 36.581709725516184, 35.997661522456575, 36.72545405796596, 37.94299037115914, 42.43718944277082, 48.44148915154593, 47.59608793258667, 49.15590640476772, 47.67052745819092, 45.8535908971514, 37.72253792626517, 41.502142565590994, 48.09282159805298, 50.10277564185006, 47.592078821999685, 48.261714935302734, 51.97563130514962, 50.40355968475342, 46.72349493844168, 44.80348185130528, 40.962000029427664, 43.019969599587576, 47.28616006033761, 53.514368942805696, 52.460195200783865, 52.35704224450247, 44.20673928941999, 49.98619876589094, 35.73695468902588, 11.929163268634252, 5.279415428638458, 14.169662015778677, 9.47793173789978, 5.074912573610034, 2.711556864636285, 0.7021595452513013, 0.21081137151590415, 0.004400632502178529, 0.10336023515888623, 9.614869441304888, 34.77590070452009, 27.981120075498307, 23.3121303830828, 41.71686969484602, 29.904977253505162, 29.969567707606725, 45.1986780166626, 41.07210118430001, 20.550761665616715, 0.28987292838948114, 0.011047563665280384, 0.03910858377016016, 0.028424566445340003, 0.022545927337237766, 0.03472801936524255, 0.032305676490068436, 0.08415689345981393, 0.05863333732954093, 0.02493161744704204, 0.10263577689017568, 0.06361305833395038, 0.060389168826597076, 0.0739864609869463, 0.0327203733447407, 0.02831817215441593, 0.03577345523184963, 0.030337782443634102, 0.04796300096703427, 0.03586588187941483, 0.07908095618976013, 0.05752189696899482, 0.04600564117676445, 0.06668408068695239, 0.006342502610225762, 0.030073153786361217, 0.024030453392437527, 0.02306398543130074, 0.05836839654615947, 0.04542909675676908, 0.039110449741461446, 0.020348542569471256, 0.07866024412214756, 0.037751157501978536, 0.04334162109132324, 0.07912240789404937, 0.04039960181606667, 0.012656958823624467, 0.017202979751995633, 0.033286403864622116, 0.05881902522274426, 0.032358520797320774, 0.4194879632975374, 21.606576919555664, 59.81199727739607, 55.566383906773154, 51.61768443243844, 37.297419343675884, 24.578401361192974, 23.20272057397025, 41.73761354173933, 42.2797224181039, 18.46621002469744, 0.5383244965757642, 0.053164205979555845, 0.05071339177499924, 0.7717747954385621, 3.4262626852308, 6.269545887197767, 12.131502628326416, 7.379697356905256, 9.566909500530787, 26.55007951600211, 47.359880447387695, 54.630770751408164, 55.87368188585554, 54.23082201821463, 53.36558716637747, 54.926642417907715, 49.80312762941633, 41.776353222983225, 46.793626580919536, 53.259832109723774, 54.13566296441214, 53.73312602724348, 50.12287678037371, 49.236380440848215, 46.98741878782, 53.104553767613, 53.10789237703596, 48.9285682950701, 43.472894872937886, 39.43703024727957, 42.06879595347813, 47.36443151746477, 50.594388484954834, 52.41992344175066, 51.894097668784006, 52.21992301940918, 44.064186573028564, 38.128889424460276, 38.274752957480295, 39.029455866132466, 39.73807137353079, 40.00755030768258, 41.07258755820138, 42.11396966661726, 41.02437053407942, 41.36963694436209, 40.031525066920686, 38.34921680177961, 38.219320229121614, 41.41937214987618, 40.76070376804897, 42.28865432739258, 44.69569444656372, 55.119190897260395, 49.63656193869454, 55.96674953188215, 37.65774597440447, 27.981913907187327, 56.85623359680176, 48.12980685915266, 50.37463780811855, 42.618857043130056, 44.80996104649135, 42.117259638650076, 45.46826812199184, 41.32854182379586, 39.78486054284232, 39.70991032464163, 38.72140400750296, 38.05721180779593, 39.50667551585606, 40.2361147744315, 40.92429562977382, 37.78341109412057, 38.19246891566685, 37.39350250789097, 39.05080073220389, 39.239597184317454, 44.690559727805, 50.198403699057444, 50.52774483816964, 51.100189549582346, 50.57379402433123, 47.6423316683088, 40.88399607794625, 43.96150262015206, 50.94620704650879, 51.45310245241438, 49.68844761167254, 49.6480473109654, 54.61062444959368, 51.6861207144601, 49.147266319819856, 46.153152057102744, 43.183815070560996, 43.28407757622855, 48.38855430058071, 53.52057021004813, 53.177614075796946, 53.74544518334525, 45.37904977798462, 51.9293007169451, 35.43013266154698, 16.051516464778356, 5.1995623878070285, 4.927463982786451, 10.288812569209508, 7.106317443507058, 6.41935339144298, 1.9772293312208993, 0.41197989189199036, 0.029633948246815374, 0.058425284922122955, 9.467142922537667, 36.78042125701904, 32.302856172834126, 24.05057798113142, 45.67337547029768, 33.21686043058123, 36.735772132873535, 48.79243571417672, 47.96344614028931, 23.97593174661909, 0.6587424778512546, 0.04412683199292847, 0.040702740728322945, 0.04838349251076579, 0.041533739172986577, 0.05355635511555842, 0.03882180094452841, 0.0647327293242727, 0.017061315210802213, 0.003626697580330074, 0.024562239946265305, 0.062480468036873, 0.0769662203799401, 0.043358567503413985, 0.026986587892419527, 0.01910583452055497, 0.024692527151533535, 0.022389786251421486, 0.04138838340129171, 0.029429193519588028, 0.034790997592998404, 0.03253282965826137, 0.10651803535542317, 0.16350975898759706, 0.12979576949562344, 0.0855783564703805, 0.11534988108490195, 0.1427008948687996, 0.1541906911879778, 0.13157712748008116, 0.13488003239035606, 0.14028767150427612, 0.24754178843327931, 0.19047525631529943, 0.10250354398574148, 0.18833093637866632, 0.13627542608550616, 0.11295727839959518, 0.10233659044440303, 0.12216777381088052, 0.21871620948825563, 0.11805837574814047, 0.5996238387056759, 26.717015198298864, 66.6588911328997, 63.903312001909526, 59.47000694274902, 43.93259116581508, 27.728777136121476, 27.601414918899536, 48.28078079223633, 50.001800945826936, 22.842760460717336, 0.6677081510424614, 0.29657042186175075, 0.15971887883331093, 0.6984299910920007, 3.2056732305458615, 12.881814275469099, 12.866178223064967, 12.052083849906921, 14.186425413404192, 30.75525263377598, 47.313650608062744, 55.95462839944022, 56.082895619528635, 54.07339668273926, 55.90423658915928, 59.213257108415874, 53.12220566613333, 43.63503803525652, 49.07112448556082, 56.72171299798148, 57.48717171805245, 55.90669625146048, 48.5372040612357, 51.0474214553833, 48.71525165012905, 53.61761917386736, 55.585182258060996, 50.487205573490684, 45.16680662972586, 42.45052650996617, 45.032900946480886, 49.272438117435996, 53.32800088609968, 53.381307465689524, 53.90073047365461, 55.55877562931606, 47.360154901232036, 40.874963419778005, 40.39504439490182, 40.65764461244856, 43.089934485299246, 41.67290496826172, 43.7690931047712, 44.722316469464985, 43.325940472739084, 43.584052153996055, 42.050800119127544, 39.267098154340474, 41.38459989002773, 43.376978465488975, 42.132952145167756, 44.07812465940203, 47.89683723449707, 57.5892060143607, 52.82978030613491, 58.31130450112479, 39.499775954655235, 29.97501162120274, 58.849782943725586, 49.38186182294573, 53.14000000272478, 45.50935282026018, 47.02909060886928, 44.20324434552874, 47.59388535363333, 43.286724839891704, 43.038295473371235, 41.29441922051566, 40.909495966775076, 40.43311357498169, 42.23854739325387, 42.586141450064524, 43.348067011152, 40.137033462524414, 39.379210812704905, 39.43540089470999, 40.4852910723005, 42.163419995989116, 46.0418175969805, 54.41931969778878, 51.27766738619123, 52.040121010371614, 51.97440842219761, 50.28351565769741, 41.97941085270473, 45.87276097706386, 53.27882848467146, 54.542490414210725, 51.14002704620361, 49.89772735323225, 57.13418238503592, 55.35824366978237, 50.96974059513637, 48.993506159101216, 46.67141819000244, 45.973040853227886, 52.21379818235125, 55.462324210575645, 55.97913122177124, 54.63346665246146, 45.69685690743582, 54.72690602711269, 35.082500389644075, 16.61657871518816, 10.200403690338135, 21.472853626523698, 16.525145632880076, 13.968906845365252, 9.676096967288426, 2.115084631102426, 0.6666237435170582, 0.11992524271564824, 0.36621721035667826, 12.61652249949319, 45.128872939518516, 38.73223277500698, 33.55682536533901, 47.127431937626426, 39.74709708350045, 41.16863945552281, 57.10994359425136, 54.06826891217913, 29.697705541338237, 1.0026935615709849, 0.07457575507994209, 0.1441466630037342, 0.09901269844600133, 0.14341616577335767, 0.09524409459637743, 0.12275367522878305, 0.1944513629589762, 0.20162129322332994, 0.13904426965330327, 0.1843116477664028, 0.1199362078415496, 0.18653555986072334, 0.16749991130615982, 0.12219515948423318, 0.1240002933357443, 0.09739670623093843, 0.16212864166923932, 0.13900431751140527, 0.12476733646222524, 0.2126683590135404, 0.12250624064888273], [0.02311053462991757, 0.0563069935888052, 0.04118066008335777, 0.06985324634505169, 0.04875532630831003, 0.01843065146489867, 0.05416275168369923, 0.039832821514989646, 0.04958700328799231, 0.02200919426312404, 0.025765185843088796, 0.028180227681462253, 0.017925234478233115, 0.04628090587045465, 0.04009630344808102, 0.04343275512967791, 0.049126210156828165, 0.007910326472483575, 0.05898807543729033, 0.017461613552378755, 0.4815756816949163, 24.073930876595632, 49.14174945013863, 47.54757561002459, 36.44997535433088, 21.072434152875626, 18.577989169529506, 26.255343879972184, 32.27681432451521, 29.862447329929896, 7.774567825453622, 0.03406485316476651, 0.06636040591235672, 0.0946975482095565, 2.797156934227262, 4.823666146823338, 1.01319391812597, 9.618080377578735, 7.223502721105303, 18.946566786084855, 38.14083685193743, 52.38818407058716, 53.41359921864101, 56.29986354282924, 54.96327679497855, 55.631155014038086, 53.28052731922695, 46.91369145257132, 37.748072556086946, 48.59653125490461, 53.45544127055577, 52.29903520856585, 50.61051525388445, 49.44891888754708, 49.77809674399239, 51.53008849280221, 52.34181874138968, 50.41170644760132, 44.291111264910015, 40.25910636356899, 36.11606577464512, 38.81024020058768, 41.02196645736694, 44.62833513532366, 45.060811860220774, 43.52226529802595, 39.31446402413504, 36.05937194824219, 36.531046935490195, 35.64167056764875, 36.49828617913382, 37.27208621161324, 40.05217858723232, 40.060182912009104, 39.54266718455723, 37.56124244417463, 37.41880784715925, 35.104119709559846, 35.5565516608102, 36.72594390596662, 39.11491870880127, 38.64147193091256, 40.111213956560405, 39.62125825881958, 49.27035713195801, 46.20438459941319, 52.52360098702567, 37.42523145675659, 25.523505755833217, 56.22324923106602, 47.095001220703125, 48.64917080742972, 44.17277302060808, 46.081481388636995, 42.354578835623606, 46.934327602386475, 44.33982855933053, 42.88223198481968, 37.14015729086739, 38.08627264840262, 34.28821359361921, 37.846952370234895, 38.664494786943706, 40.00972856794085, 37.290234906332834, 38.68701042447771, 35.88860259737287, 37.1871132169451, 36.267154353005544, 41.182174546378, 46.37680067334856, 48.915453570229666, 48.056433882032124, 50.34442356654576, 43.89319140570504, 37.73224803379604, 37.56273283277239, 46.827453885759624, 48.80072144099644, 51.033910683223176, 46.97015598842076, 50.21989100319998, 49.443787642887656, 49.45995610100882, 47.56617941175188, 45.128890310014995, 40.948864459991455, 42.82483639035906, 47.90756525312151, 51.27534668786185, 51.269847188677105, 51.48119054521833, 45.14116777692522, 48.58337484087263, 30.32193865094866, 9.89907681941986, 7.663982033729553, 11.652441705976214, 9.375072343008858, 6.5165599925177435, 2.0659293830394745, 0.25108338839241434, 0.05038189688431365, 0.1237354746886662, 0.7298374772071838, 27.595074687685283, 39.696569783346995, 26.141494171960012, 23.93050616128104, 39.68950693947928, 37.35214682987758, 43.78044646126883, 44.23926380702427, 32.693497794015066, 2.376959413290024, 0.05937743918704135, 0.060688864173633714, 0.07335697726479598, 0.12331536651722022, 0.04966245298939092, 0.02601060178130865, 0.023018605009253536, 0.05313240643590689, 0.04290930607489177, 0.07059191992240292, 0.041578067865754874, 0.03972310579514929, 0.0172131119761616, 0.10270518423723322, 0.05993043165653944, 0.05845972735966955, 0.09379409240292651, 0.09357168897986412, 0.01667208207904228, 0.03432706623737301, 0.03206400267247643, 0.05644054285117558, 0.04734181233548692, 0.08520854131451674, 0.08130707352289132, 0.041361696619008265, 0.04054298305085727, 0.018471260089427233, 0.04937811628250139, 0.04993831479389753, 0.008037662050420684, 0.002651700434008879, 0.033265708546553335, 0.006767925831289696, 0.009107995911368301, 0.030299496105206863, 0.00793728806144957, 0.06773894479764359, 0.028728704500411237, 0.013488763876791512, 0.05691830953583121, 1.1179917518581663, 32.49305616106306, 56.97975172315325, 56.33224562236241, 43.58958292007446, 29.730132784162247, 22.783386366707937, 23.22161967413766, 31.96281828199114, 33.56468725204468, 8.326816729136876, 0.011575251019426754, 0.09183363510029656, 0.06946211840425219, 2.110086270741054, 5.311728460448129, 7.88096124785287, 8.988854987280709, 9.155130590711321, 16.912167242595128, 39.24865763528006, 53.954242025102886, 55.727238178253174, 55.47095387322562, 55.7658771106175, 56.18503066471645, 55.416653701237266, 48.28232329232352, 39.433823653629844, 49.98351328713553, 55.331527846200125, 53.05445030757359, 50.91523545128958, 49.39125231334141, 49.142920221601216, 50.94128772190639, 53.823306696755544, 52.13788216454642, 47.60629136221749, 41.78561864580427, 38.4775013923645, 39.78811577388218, 43.33145734242031, 47.34195409502302, 47.798544543130056, 46.20126485824585, 42.5611765725272, 38.04108851296561, 37.982139996119905, 37.48230395998274, 38.24813093457903, 39.267817292894634, 41.74397809164864, 42.140153953007285, 42.51973404203142, 39.1932874407087, 37.77803666251046, 37.5242953981672, 37.54842301777431, 38.21004785810198, 41.99821615219116, 39.82539285932268, 41.9380829674857, 40.80575588771275, 50.4776656968253, 48.59660073689052, 54.02881704057966, 39.2706104687282, 27.533758572169713, 57.229431765420095, 49.67308861868722, 50.585331508091514, 45.680671078818186, 48.17205885478428, 45.522439752306255, 47.34146424702236, 46.02868897574288, 44.78164366313389, 39.22593355178833, 39.50813116346087, 35.64366470064436, 39.14017193658011, 40.9950977734157, 41.088537148066926, 39.03220040457589, 40.31632130486624, 37.94529022489275, 38.40253727776663, 37.38300377982003, 43.19535950251988, 47.78066682815552, 50.12800107683454, 50.336207321711946, 51.70648241043091, 47.179244654519216, 39.55527469090053, 39.348058564322336, 49.242081437792095, 50.763122013636995, 52.616185733250205, 48.62363965170724, 52.19645895276751, 50.696363721575054, 51.51822096960885, 49.745436736515586, 46.35046700068882, 42.50208909170968, 46.11106334413801, 50.2986592565264, 53.85951375961304, 54.01522289003645, 52.256164823259624, 47.082515307835166, 46.84186097553798, 29.27820110321045, 13.49863452570779, 6.141283443995884, 5.876881905964442, 10.913623247827802, 11.875618713242666, 4.323399756635938, 1.2038674695151192, 0.1117911074044449, 0.052192062072988064, 1.3573769522564751, 24.742170401981898, 37.27953815460205, 27.72811358315604, 26.145871537072317, 38.67255122320992, 39.149472100394114, 50.88950627190726, 47.25437899998256, 38.531527110508506, 3.3887771538325717, 0.13062557711132936, 0.024344754205750566, 0.014863256997029697, 0.05757919246596949, 0.04488700495234557, 0.035533389542251825, 0.05709184147417545, 0.01539389173766332, 0.036032713284449916, 0.058150885360581536, 0.04287230895299997, 0.046105660631188324, 0.023996124609506557, 0.04096792917698622, 0.030421106543924128, 0.039290007070771286, 0.054550459808004756, 0.039877645538321564, 0.05631707661918231, 0.025776709064042995, 0.05976896067815168, 0.10559254751673766, 0.1344631269041981, 0.2556238461818014, 0.18603303682591232, 0.11080690593059574, 0.26331075227686335, 0.11226605477609805, 0.15832229091652802, 0.1306714325078896, 0.10395508645368473, 0.09873522512082543, 0.1029531005769968, 0.0891260632446834, 0.11348230165562459, 0.16566019931009837, 0.10862387557114873, 0.22578498375202927, 0.11632672723914896, 0.11945040390959807, 0.16536912135779858, 1.871997126511165, 39.13450568062918, 63.358503750392366, 63.10465131487165, 50.01692370006016, 32.42858035223824, 25.627334424427577, 36.37258979252407, 44.31457533155169, 40.450887066977366, 10.547682472637721, 0.11682895171855177, 0.23556998797825404, 0.17018431797623634, 5.799309177058084, 11.384725877216884, 9.379524401256017, 18.601253475461686, 12.959115590367999, 23.994889906474523, 41.335003648485454, 56.747695786612375, 56.26908649717058, 57.01118884767805, 56.94331884384155, 59.52737127031599, 58.46704837254116, 49.78643110820225, 41.68923323495047, 53.213980947222026, 57.32367365700858, 56.11002138682774, 51.166673387799946, 50.42210095269339, 49.78707034247262, 52.72985826219831, 56.589311599731445, 55.07597310202462, 49.64799519947597, 44.67109087535313, 39.57347549710955, 42.84670237132481, 45.16897794178554, 50.119135175432476, 50.11729390280587, 48.69447653634207, 43.98655782427107, 39.67782006944929, 40.23389482498169, 38.28894465310233, 39.155596937452046, 41.07390424183437, 44.38713189533779, 43.94401747839791, 43.26393127441406, 40.61267934526716, 40.48640973227364, 39.45065219061715, 39.222737380436485, 40.34150505065918, 42.010858399527415, 42.60470356260027, 43.157738481249126, 43.137870107378276, 52.58887931278774, 51.09497492653983, 55.35561030251639, 41.1439768246242, 29.689284324645996, 58.95893914358956, 52.34437567847115, 53.23715666362217, 48.56908239637102, 50.150141511644634, 47.13689538410732, 49.62871742248535, 49.08149814605713, 47.59476082665579, 40.57091719763619, 41.32524837766375, 38.175563948495046, 42.07353115081787, 43.02735900878906, 44.10998214994158, 40.59797695704869, 42.265284061431885, 39.46874877384731, 41.624708788735525, 39.22353989737374, 46.09653466088431, 50.40942396436419, 52.449057238442556, 51.96018545968192, 54.6532655443464, 48.80765574319022, 41.04912349155971, 41.27819170270647, 52.61763095855713, 52.6429362978254, 55.28573226928711, 49.723529066358296, 53.210652760096956, 52.98278658730643, 53.20919016429356, 52.09660986491612, 49.6487386567252, 44.50483437946865, 48.23981768744332, 53.13711302621024, 55.96276821408953, 55.17406776973179, 53.473107065473286, 49.27399798801967, 51.06606694630214, 30.98650257928031, 16.84541242463248, 14.291011435644966, 23.576118503298076, 19.07676907948085, 15.249737773622785, 5.625388818127768, 1.011189688529287, 0.2791462939764772, 0.2543352538985865, 1.5206898003816605, 35.88545158931187, 52.50335046223232, 37.88619579587664, 32.669641154153005, 47.52748836789812, 48.009568282536094, 56.63357857295445, 56.55285440172468, 46.48012386049543, 5.061809139592307, 0.2216329194073166, 0.1710891987064055, 0.14354147762060165, 0.15811387210019998, 0.14244994547750267, 0.14151462566639694, 0.07415344845503569, 0.10164429473557643, 0.14914914885801928, 0.10999967317496027, 0.21543532982468605, 0.09018355328589678, 0.15109535013990744, 0.1585664413869381, 0.09808670170605183, 0.1820017517145191, 0.24369663904820169, 0.14176325446793012, 0.10965796972491912, 0.10785082740975277, 0.09417652152478695], [0.05174871746982847, 0.06691692676395178, 0.012354893693035203, 0.03155564084382994, 0.029714079839842658, 0.050062619016638825, 0.03993338379742844, 0.01228425226041249, 0.04232611879706383, 0.06493147223123483, 0.08053435105830431, 0.07900767440774611, 0.02059804498484092, 0.010135180882311292, 0.06425306613423995, 0.012765024855200733, 0.018123280190463577, 0.029020871501415968, 0.05885696890098708, 0.01001269682975752, 2.140926718711853, 41.8117230279105, 55.361446789332796, 44.404964447021484, 39.860707078661235, 26.342439549309866, 19.207426479884557, 31.391068390437535, 44.526071548461914, 25.635029554367065, 2.058371045759746, 0.028905289846339395, 0.024141622873555337, 0.01728227505061243, 1.382312299949782, 3.714377990790776, 4.47849657705852, 11.690858295985631, 17.204349415642874, 28.48936516898019, 49.27545363562447, 53.0947185925075, 54.87743527548653, 55.10664245060512, 52.22154194968087, 51.383693422589985, 50.96007217679705, 43.549623829977854, 37.548346587589805, 48.673916816711426, 51.98780107498169, 50.831030232565745, 49.47460985183716, 48.75828531810215, 48.666739327566965, 51.42393738882882, 48.60390329360962, 47.39834220068795, 43.29800871440342, 35.9718976020813, 36.17750174658639, 35.476848874773296, 35.48811885288784, 35.296254771096365, 36.13465220587594, 36.57793337958199, 35.83784948076521, 37.46840408870152, 37.86692844118391, 35.855477060590474, 36.94220658711025, 37.25258261816842, 39.055240631103516, 40.28772599356515, 39.10850204740252, 37.27754054750715, 36.08354125704084, 35.67484474182129, 38.834951468876426, 43.65126207896641, 46.70208406448364, 44.46876628058297, 44.07014812741961, 41.20287322998047, 45.92308677945818, 46.68806259972708, 51.62942688805716, 38.93006188528878, 23.359324284962245, 54.09268488202776, 46.74995020457676, 50.750337328229634, 46.920066424778526, 50.45803356170654, 47.881551197596956, 51.294165883745464, 47.27939598900931, 46.30809688568115, 40.591039180755615, 36.429283618927, 35.5877560206822, 36.697602203914094, 38.523929255349294, 40.71877833775112, 39.41046033586775, 38.690776348114014, 36.5767000743321, 37.04371282032558, 36.49960286276681, 38.36681658881051, 40.42059292112078, 46.952788966042654, 47.13715246745518, 45.16726173673357, 39.12071350642613, 37.24035726274763, 35.80788884844099, 42.11757230758667, 48.52053880691528, 49.82485464641026, 50.511433941977366, 49.18537024089268, 50.730194500514436, 49.56746210370745, 47.95422240665981, 44.170903955187114, 41.35659864970616, 41.97350835800171, 46.947275570460725, 49.863893100193565, 52.6433219228472, 47.60081270762852, 50.998169149671284, 42.57919325147356, 34.78163644245693, 20.21408322879246, 8.029114212308611, 7.24582120350429, 4.756294676235743, 5.449128653321948, 3.475370381559644, 0.2158970593341759, 0.046055170840450695, 0.04567922172801835, 0.134788593011243, 11.523008925574166, 35.44747536523001, 27.328989948545182, 16.60801158632551, 18.806991372789653, 37.21088647842407, 44.16716235024588, 45.05911302566528, 35.08945206233433, 8.803314634731837, 0.16645021763231072, 0.04464513096692307, 0.046369722711720636, 0.05937570213739361, 0.06676272289561373, 0.014486994062151228, 0.016514297242143323, 0.030514405108988285, 0.02251226351862507, 0.0674600126221776, 0.026542904021750604, 0.020730554392295222, 0.015826961624303033, 0.020728561195677946, 0.04027337394654751, 0.05382644258705633, 0.01793476959158267, 0.02284844878262707, 0.13063863212508814, 0.023041093356109092, 0.040182172054690976, 0.011144019962687577, 0.012255411129444838, 0.06779788234936339, 0.05104127007403544, 0.016414890165573785, 0.009433933600251163, 0.012394481122360697, 0.02353138749354652, 0.01382858439215592, 0.03780909760722092, 0.04008972844375031, 0.07520502845623664, 0.04673949715548328, 0.03668700763955712, 0.03600479156843253, 0.04061965411528945, 0.09499693821583476, 0.03455173936007278, 0.04001704716522779, 0.07264845778367349, 3.227613470384053, 50.94399751935686, 60.71949454716274, 49.9465697152274, 44.44256114959717, 30.211243425096782, 24.02065556389945, 32.921051297869, 41.81788260596139, 27.26733684539795, 2.6812462168080464, 0.070525810255536, 0.03341523730861289, 0.4247059247323445, 2.9143574110099246, 7.786232982363019, 8.306938801492963, 4.23732590675354, 9.205809882708959, 27.785047122410365, 51.89230155944824, 55.36887093952724, 55.93394013813564, 56.00662176949637, 54.46078307288033, 53.953547205243794, 52.890868868146626, 45.31292029789516, 38.513322830200195, 51.51100526537214, 53.95583316258022, 51.68876450402396, 49.5894774709429, 48.78422294344221, 48.66297687802996, 53.2272242137364, 50.734148025512695, 48.622833660670686, 45.29634537015642, 37.75823777062552, 37.0426983833313, 37.156888553074424, 37.06685726983206, 36.75229842322213, 39.06566987718855, 38.82243428911482, 37.59117875780378, 38.65588249479021, 39.604342869349885, 36.50633914130074, 38.2953439440046, 38.69390998567854, 41.46511214120047, 42.895318916865754, 40.62561689104353, 39.095654828207834, 36.42473602294922, 37.80170570101057, 40.76508808135986, 44.60643093926566, 47.0834116254534, 46.60779006140572, 46.482243061065674, 42.87697914668492, 47.44840397153582, 49.00825023651123, 53.30741337367466, 39.47545378548758, 23.95173290797642, 54.13092776707241, 48.10902827126639, 51.589273248400005, 49.16447005953108, 53.66603422164917, 49.58220965521676, 52.80378014700753, 48.59203577041626, 48.3304569380624, 41.36210857118879, 38.85838079452515, 37.18574789592198, 38.8464229447501, 40.84459284373692, 43.14259835651943, 41.43137168884277, 39.348298277173726, 37.9504840033395, 38.704533781324116, 36.69143567766462, 40.31868369238717, 41.64864533288138, 48.73653398241316, 50.165604727608816, 47.36239569527762, 41.20571851730347, 38.95312295641218, 37.65039478029524, 43.60773856299264, 51.22444418498448, 52.26977287020002, 51.60729340144566, 51.02002470833914, 52.2372796194894, 51.56731694085257, 49.11430753980364, 46.718214307512554, 43.109458923339844, 42.76387289592198, 49.11561380113874, 52.41127988270351, 54.63445329666138, 48.437042304447715, 49.53424276624407, 44.37370102746146, 35.09595905031477, 22.677250896181377, 9.364440730639867, 5.316318614142282, 7.437415174075535, 14.769282000405447, 7.193137790475573, 1.7190062616552626, 0.14686487428843975, 0.03236130279089723, 0.08980881875114781, 13.27155523640769, 37.25347546168736, 28.026823588779994, 24.243800435747417, 24.73379955972944, 42.91176182883126, 48.741540159497944, 52.562538691929404, 42.0718218939645, 10.699412890842982, 0.17806890846363135, 0.04340535249294979, 0.05626337057245629, 0.03712272550910711, 0.05745888820716313, 0.048374854759978395, 0.02450562807332192, 0.04708484094589949, 0.08999212498643569, 0.04665769636631012, 0.02941850320036922, 0.04460134170949459, 0.06045157369226217, 0.025585409686235443, 0.024482281379667774, 0.01165052514988929, 0.06277808028140239, 0.028468014738921608, 0.09249476569571666, 0.04610273275258286, 0.04679848899000457, 0.10544002641524587, 0.12382211003984724, 0.12394440919160843, 0.12995643301733903, 0.09423439377652747, 0.1398201880178281, 0.16052979603409767, 0.08291626681706735, 0.12447609566152096, 0.13148655662579195, 0.10170392439301525, 0.20914393956107752, 0.11653961081589971, 0.1556336773293359, 0.12175837292202882, 0.11069113428571395, 0.13880375613059315, 0.1674507718001093, 0.2142976980124201, 0.13657509429114206, 5.020205497741699, 59.82263496943882, 67.94245270320347, 56.91727352142334, 52.4560158593314, 37.715040819985525, 29.053861141204834, 43.39206995282854, 56.33707114628383, 34.54112802233015, 3.192262338740485, 0.15806216773177895, 0.2838723175227642, 0.3129480858998639, 3.2529112100601196, 9.20540862424033, 14.230972051620483, 23.600147111075266, 23.439659357070923, 31.106570925031388, 53.638967514038086, 56.92323507581438, 56.625463077000205, 58.813200678144185, 57.00861801419939, 57.28409671783447, 54.700266633714946, 47.92869472503662, 42.03607341221401, 54.38538122177124, 56.77882719039917, 53.62622104372297, 50.666309288569856, 47.76664883749825, 49.35450676509312, 55.73604849406651, 53.06941672733852, 51.777687549591064, 47.75115088054112, 39.46905102048601, 38.991199084690635, 39.45037773677281, 38.360497202192036, 38.8965368270874, 40.56380919047764, 40.72481632232666, 39.88387584686279, 42.02379594530378, 40.53681196485247, 38.78625154495239, 40.26868098122733, 41.019402572086875, 43.87927416392735, 45.87728772844587, 42.98201159068516, 41.3520302091326, 39.07526881354195, 40.57997070040022, 41.75847550800869, 48.64123249053955, 50.636619635990684, 48.78569943564278, 47.57632030759539, 47.10926934650966, 49.30696024213518, 51.858533314296174, 55.160709857940674, 40.93735129492623, 26.401514870779856, 55.29622057506016, 51.524060930524556, 53.2807149205889, 52.65343849999564, 54.897074358803884, 51.77231311798096, 54.493561199733186, 50.59796680722918, 50.461552824292866, 43.26594625200544, 39.437898772103445, 38.969659669058665, 40.101566382816856, 42.62409945896694, 45.45754010336739, 43.83506972449166, 41.975870745522634, 40.089664118630544, 40.37940747397286, 38.3485324042184, 41.99980728966849, 43.754880564553396, 50.98632941927229, 51.708306312561035, 50.014234747205464, 42.50149849482945, 41.19128016063145, 38.81240803854806, 45.6228620665414, 53.05886936187744, 54.5244494165693, 54.52617604391915, 52.8339388029916, 56.35057497024536, 55.26218829836164, 51.724308013916016, 48.51287146977016, 45.02660935265677, 46.03333732060024, 51.793098654065815, 55.7714078766959, 56.70043761389596, 49.7819356237139, 51.499825613839285, 46.39765569141933, 40.48208795275007, 25.604200397218975, 11.76236047063555, 16.736867666244507, 11.022163663591657, 11.549679585865565, 8.746875286102295, 1.924901579107557, 0.25591499198760304, 0.14905644740377152, 0.31380458708320347, 16.298196622303553, 49.35200888769967, 37.726821490696494, 27.957418033054896, 27.901566675731114, 49.15777894428798, 56.48621422903878, 58.20452805927822, 49.884647369384766, 13.76902367387499, 0.44425929550613674, 0.07235370895692281, 0.15758901169257505, 0.1505723489182336, 0.23687269378985676, 0.09393841001604285, 0.08197665187929358, 0.18153634454522813, 0.13553088318024362, 0.1732465736567974, 0.11297326468463455, 0.201405600511602, 0.1269068523709263, 0.08349900626178298, 0.09218067862093449, 0.16256683958428247, 0.12498129212430545, 0.0970160820122276, 0.2968387688909258, 0.19016975270850317, 0.10691474085407597], [0.03753577691635915, 0.04412644522796784, 0.06022435945591756, 0.06582348793745041, 0.019154258172160814, 0.026256072002329996, 0.010292278702503868, 0.03191112194742475, 0.005660053716772901, 0.04328433237969875, 0.03270699602684804, 0.023581602477601597, 0.0361963827162981, 0.027052130982545868, 0.04989038986553039, 0.04161823374618377, 0.042270048055797815, 0.027483738626220396, 0.05177292759929385, 0.07260568972144808, 7.426222494670323, 50.2434731892177, 53.93476275035313, 46.24133859361921, 34.66942303521292, 20.363334008625575, 19.602593115397863, 37.02368811198643, 38.12276806150164, 13.26652647767748, 0.42905430282865253, 0.004045511446227985, 0.06783563603780099, 0.5044325409190995, 1.874314785003662, 6.511223775999887, 8.765037877219063, 5.790565303393772, 23.02638050488063, 43.66643347058977, 52.92364699499947, 54.061577796936035, 53.23018067223685, 50.89163589477539, 51.97502333777291, 48.060248443058555, 45.52605281557356, 35.80064187731062, 38.72978006090437, 49.24792834690639, 52.05793619155884, 49.91299949373518, 50.511527742658345, 49.48640789304461, 46.122677258082796, 49.542823791503906, 48.2250770841326, 44.68745388303484, 38.16763257980347, 37.15626321520124, 34.71039308820452, 36.06679262433733, 35.447391986846924, 35.46642657688686, 36.96018852506365, 38.51202351706368, 41.41363293784005, 42.3681834084647, 44.14829451697213, 40.7471513066973, 39.35565989358084, 36.67336688722883, 39.5818897656032, 38.49905817849295, 36.91398300443377, 35.622573443821494, 35.90075847080776, 38.45366907119751, 46.02642386300223, 48.98256622041975, 51.261307852608816, 48.11327709470476, 50.15267065593174, 46.95740951810564, 49.000989368983674, 45.591873100825715, 52.93561526707241, 37.12007352284023, 18.43670276233128, 50.37250471115112, 45.23648663929531, 50.44258771623884, 48.00293622698103, 49.64011594227382, 46.18224763870239, 50.581628118242534, 48.324252196720664, 49.627706459590364, 43.88506896155221, 37.30388811656407, 36.78484378542219, 36.22957502092634, 38.92576095036098, 41.966455936431885, 41.00418949127197, 39.24239036015102, 36.756585461752756, 37.55735840116228, 36.429756096431184, 37.3731130191258, 35.34653193610055, 36.27132327216012, 35.98714542388916, 37.174582140786306, 35.34705305099487, 35.46282046181815, 34.438523973737446, 35.62030138288225, 40.93421418326241, 46.7002705846514, 48.72054270335606, 49.180853911808555, 47.9603785106114, 46.08611931119646, 45.42590842928205, 44.59076622554234, 42.26569400514875, 41.9622175352914, 48.754839011601035, 49.41303491592407, 54.48260389055525, 51.956127711704795, 42.37551375797817, 51.55025563921247, 42.48772021702358, 30.60099220275879, 13.34195785863059, 5.4607152087347846, 10.075440338679723, 20.737643889018468, 6.615085882799966, 1.6012417865650994, 0.20074352675250598, 0.04954156858314361, 0.04821074767304318, 2.865152657032013, 29.497076307024273, 38.99569109507969, 19.175984144210815, 19.234057188034058, 34.37560108729771, 40.25600051879883, 44.48332275663103, 37.576834201812744, 19.864050354276383, 0.7469930137906755, 0.06640284149242298, 0.03159397467970848, 0.03290894501177328, 0.050133383433733664, 0.020432764032323445, 0.053309063028012, 0.02484782855026424, 0.007852762954176536, 0.012122327511731004, 0.01767756919642644, 0.018006911434765373, 0.019910025742969344, 0.032916531033281765, 0.07163998511220727, 0.07049440765487296, 0.041165606783969064, 0.020648907969838808, 0.053141417380954535, 0.045609800810260434, 0.00955690534984959, 0.021300620499200056, 0.01610119324842734, 0.11335731550518956, 0.038513094652444124, 0.0069605381743583295, 0.034220865328929255, 0.02833859096946461, 0.03524741417329226, 0.06159681188208716, 0.031858416739851236, 0.04391929866479976, 0.026330875399123346, 0.003408463330872889, 0.06276651125933443, 0.01188340684997716, 0.0335438502287226, 0.030926754232496023, 0.0518256633409432, 0.00873932832785483, 0.05935890839568206, 11.230225733348302, 58.216419901166645, 60.33351516723633, 52.78057663781302, 42.33455760138375, 32.168429374694824, 21.380520752498082, 35.517718178885325, 40.006931918007986, 15.855624164853777, 0.43959542576755795, 0.04543789057061076, 0.04259635893894093, 0.9775607330458504, 2.8379276607717787, 6.991075490202222, 7.426316295351301, 4.187684501920428, 22.36891242436, 45.65692561013358, 55.62882041931152, 56.45308869225638, 54.90732989992414, 51.80660942622593, 54.72313315527779, 50.41080665588379, 47.890066214970176, 38.24479579925537, 39.987765312194824, 51.58076170512608, 53.446530205862864, 51.22014672415597, 50.51554727554321, 49.301808152879985, 46.77252837589809, 50.86338799340384, 50.264560971941265, 46.81967537743704, 39.02165303911482, 37.833834171295166, 35.72626835959298, 37.64121273585728, 36.818427903311594, 37.121105330330984, 38.38297809873308, 39.41731473377773, 42.501727785382954, 44.13569048472813, 46.629788058144705, 42.93501744951521, 41.34556491034371, 38.56728948865618, 41.20111880983625, 40.18637262071882, 38.78114114488874, 37.07530280521938, 38.90794576917376, 40.30936615807669, 48.39513077054705, 50.1377146584647, 52.400374685014995, 50.095080511910574, 51.75021437236241, 48.05299799782889, 50.31541831152779, 47.51842791693551, 54.42367969240461, 38.35557440349034, 20.059395483561925, 50.776063033512656, 47.08345331464495, 52.93455566678728, 48.571632385253906, 51.88681248256138, 47.13231652123587, 50.63551834651402, 50.82427658353533, 51.209283215659006, 45.192483697618755, 40.49624490737915, 37.22221899032593, 38.54019498825073, 40.291995661599294, 44.06263017654419, 42.817106519426616, 40.98966428211757, 40.77667072841099, 39.504372188023154, 38.469083649771555, 39.11011750357491, 36.526836327144075, 37.21869625364031, 39.36651297977993, 39.23070001602173, 37.972614015851704, 36.600719996861045, 36.1392171723502, 37.51156629834856, 43.51060274669102, 49.607306548527305, 50.54800231116158, 51.36780636651175, 51.31440946034023, 48.70136914934431, 47.706581660679404, 47.68505266734532, 43.501055921827046, 42.71830313546317, 49.36001321247646, 51.136341026851106, 55.753915786743164, 53.27179690769741, 44.13596841267177, 51.447655064719065, 45.09232194083077, 30.642827306474956, 14.442600284303937, 4.44815639938627, 5.3237314735140115, 13.30686685017177, 6.068909704685211, 3.9421073709215437, 0.6767208874225616, 0.029096612972872596, 0.043564292535717995, 3.155069500207901, 31.5096880367824, 40.54303060259138, 21.30242473738534, 23.464349780763897, 38.856028829302105, 46.14555072784424, 48.526378767830984, 45.47695337023054, 23.992261750357493, 1.0722049687589918, 0.037662140492882044, 0.006518529437016696, 0.011843094236350485, 0.03861882397904992, 0.0214750769415072, 0.09584054723381996, 0.024333348032087088, 0.03167499515361019, 0.03656764315175159, 0.04542336652853659, 0.06874076104057686, 0.03218955879232713, 0.027617250569164753, 0.0498746173190219, 0.037003225314297845, 0.04092331210683499, 0.06997986097953149, 0.07297416816332511, 0.0405815238399165, 0.08080435371292488, 0.18844946287572384, 0.12083054413752896, 0.192684322063412, 0.1495201853769166, 0.08305161419723715, 0.14193482883274555, 0.12739052570291928, 0.07451510761997529, 0.10835153197071382, 0.1303278359451464, 0.11158935180199997, 0.10894913133233786, 0.11719047517648765, 0.10955352282949857, 0.18447132062699112, 0.08864019145923001, 0.1300246122160128, 0.12135723658970424, 0.11651321580367428, 0.16716639777379377, 14.911956310272217, 67.7410591670445, 66.93141337803432, 61.59564849308559, 44.117079734802246, 32.74245827538626, 29.36327484675816, 47.47281994138445, 48.904878411974224, 20.276816776820592, 0.5940524148089545, 0.1837248099701745, 0.23039504566362926, 1.0718307431255067, 6.158340837274279, 14.447493553161621, 18.925062111445836, 14.312621201787676, 26.59278314454215, 45.70033795492989, 57.737869671412874, 58.336505617414204, 58.27276979173933, 54.261755398341585, 58.40334728785923, 51.72772305352347, 49.8851580619812, 39.532550607408794, 42.95587246758597, 53.71094390324184, 55.99961451121739, 53.487330027988975, 51.89098834991455, 50.088219165802, 47.40751034872872, 53.39820201056344, 53.68539537702288, 49.53412117276873, 42.07822813306536, 40.420064858027864, 37.821320465632844, 39.834904943193706, 39.26410000664847, 38.79002789088658, 40.65266970225743, 42.276835441589355, 44.520856925419395, 46.67118195125035, 49.14770405633109, 45.420283862522666, 43.168740953717915, 41.51333958762032, 43.250813075474326, 42.48307882036482, 40.84943921225411, 39.44349207196917, 38.76245743887765, 43.09740727288382, 49.140422344207764, 52.1278315952846, 54.635530267442974, 51.284375871930806, 53.3520381791251, 50.938126291547505, 52.781017848423545, 51.40507302965437, 55.51121868406023, 40.22379214423043, 22.905264718191965, 50.679583821977886, 47.72047110966274, 54.5772522517613, 51.17953102929251, 53.2204566683088, 49.45684330804007, 53.00163010188511, 51.772910663059776, 53.86263697487967, 47.73588221413748, 42.38059983934675, 39.47602006367275, 39.596574783325195, 42.2787253516061, 45.99747766767229, 45.511711733681814, 42.688898359026226, 41.57659598759243, 41.0606575012207, 40.44024590083531, 40.30900137765067, 39.35149792262486, 39.52456712722778, 39.979653290339876, 40.80300440107073, 39.717209407261436, 39.30363525663103, 38.71965306145804, 40.05852229254586, 45.13116237095424, 51.579927921295166, 53.050587109157014, 53.44367102214268, 52.594851289476665, 50.754290853227886, 49.947563307625906, 50.54168292454311, 45.49064826965332, 45.17368534633091, 51.742168358394075, 54.129638876233784, 58.38802650996617, 56.86210829871041, 49.3602876663208, 52.260590825762065, 45.818300996507915, 32.930129119328086, 17.57884863444737, 9.145611558641706, 19.983752182551793, 32.097425733293804, 13.985579916409083, 4.3915398716926575, 0.6058330312371254, 0.23645631756101335, 0.10170449436243091, 4.338624996798379, 40.1625576700483, 49.195750849587576, 26.839663062776836, 28.457757813589915, 45.94731862204415, 53.007730620247976, 56.378395557403564, 52.618499483381, 28.141036340168544, 2.0122363099030087, 0.10734394818012204, 0.14318133837410382, 0.10936001142753021, 0.11259186693600245, 0.09425248352012464, 0.18947405075388296, 0.15200329784836086, 0.07501887915922062, 0.13807385601103306, 0.11937098817101546, 0.11987139417656831, 0.07844481603907687, 0.08087414782494307, 0.1897355852914708, 0.10996162771646466, 0.12023856304585934, 0.13360346374767168, 0.19495478166001184, 0.10027698560484818, 0.09675843548029661], [0.052654459939471314, 0.01059405121486634, 0.03360740521124431, 0.05226853296958974, 0.029002622302089418, 0.034300633905721564, 0.10295294451394252, 0.024590545034568225, 0.03579536512760179, 0.017928825624819313, 0.06941894322101559, 0.10776803256677729, 0.05493083296875868, 0.05175932636484504, 0.028910246544650624, 0.009332221200955766, 0.08208293081926447, 0.003329841902346483, 0.04489064190004553, 0.07077709212899208, 22.485998255865915, 53.65357262747628, 48.97291169847761, 39.02643339974539, 25.34891836983817, 9.607132622173854, 30.690818514142716, 43.306079047066824, 31.7249710219247, 6.7060512644904, 0.182723821539964, 0.15878319261329515, 0.11167295410164765, 1.154325076511928, 2.6715122248445238, 7.879638484546116, 6.379191500799997, 7.196324842316764, 30.34860236304147, 50.77603524071829, 54.987637179238455, 52.754211698259624, 49.743182046072825, 46.85728945050921, 43.98816633224487, 41.45579808098929, 37.248326846531455, 36.80753312792097, 38.3722813470023, 45.98373760495867, 50.9906963620867, 49.96687582560948, 48.42287492752075, 49.53192901611328, 47.67216723305838, 47.840424810137065, 47.367964676448274, 44.847408362797324, 44.70792327608381, 43.26347616740635, 39.50584520612444, 36.72782686778477, 36.063099656786235, 36.01390641076224, 39.541117736271445, 43.52306086676461, 47.89481183460781, 47.190389565059114, 49.80116823741368, 46.17692879268101, 43.181244237082346, 38.55667264120919, 37.887925897325786, 37.50878701891218, 35.69488334655762, 36.52085740225655, 35.53843770708357, 43.78975357328142, 50.46821962084089, 49.26493058885847, 49.63604777199881, 47.949699129377095, 50.98245232445853, 47.64550699506487, 50.92563343048096, 48.230868407658164, 54.54521063395909, 32.44247327532087, 19.725319147109985, 50.41268266950335, 40.543079239981516, 46.75920867919922, 43.73611000605992, 47.04292794636318, 45.58253819601876, 49.63288981573922, 47.74860783985683, 50.09712675639561, 43.85567808151245, 38.07158415658133, 36.445191519601, 36.353068828582764, 39.911995206560405, 42.35143477576119, 41.26277017593384, 42.27827719279698, 41.417044503348215, 39.35855381829398, 37.339310032980784, 35.301427704947336, 35.662688868386404, 35.437393529074534, 32.77116823196411, 33.9272894178118, 34.155864306858604, 33.100613594055176, 33.561862809317454, 35.01537036895752, 36.10414613996233, 35.839048045022146, 39.147380692618235, 38.72448900767735, 39.312546321323936, 39.25228112084525, 39.488637992313926, 37.73284905297415, 41.539558615003315, 43.22004297801426, 47.97062015533447, 50.34735223225185, 50.22205536706107, 43.52859163284302, 45.68034451348441, 46.235345772334504, 47.06871271133423, 31.908945424216135, 18.11815217563084, 3.8522510954311917, 2.5894728899002075, 19.592247247695923, 6.559656194278172, 2.862927713564464, 0.02001525804267398, 0.026906162832996676, 0.10145943465509585, 0.5526986366936139, 15.570155688694545, 29.975661277770996, 29.74641588756016, 16.63448943410601, 25.00628011567252, 36.36575623920986, 42.49975102288382, 44.54697172982352, 27.49926597731454, 3.5914309195109775, 0.09380286586071764, 0.003950378292107156, 0.022919382833476578, 0.09172401098268372, 0.018173944703968506, 0.03593153353514416, 0.05391708129484739, 0.06100668319101844, 0.013339593041954296, 0.037536536875580034, 0.02486212189043207, 0.035508582301970036, 0.09562056618077414, 0.05813560475196157, 0.03891941838498626, 0.05960138288459607, 0.0296632541742708, 0.002773188524380592, 0.026649316972387687, 0.011506938658255552, 0.06315316086901085, 0.025788746275273815, 0.006166221332802836, 0.02607790397347084, 0.06056982198996203, 0.010183400973411543, 0.025934817901413356, 0.01845821695003126, 0.04768435038360102, 0.022931905197245733, 0.045519107819667885, 0.013693071619075323, 0.027434280208711113, 0.0150026942470244, 0.03671570288549576, 0.02013694990559348, 0.030247374437749386, 0.0265225717199168, 0.03833188848303897, 0.08816980384290218, 28.90035285268511, 59.10029329572405, 53.07661158697945, 46.98364591598511, 30.33554322378976, 15.373328856059484, 26.94054569516863, 40.16912719181606, 36.29002087456839, 7.660903981753758, 0.06890102422663144, 0.03447847793410931, 0.5573777598994119, 1.860668522971017, 4.922042216573443, 7.0245488711765836, 6.4923576797757825, 8.107542872428894, 31.530598640441895, 50.69444601876395, 56.86399820872715, 54.75673464366368, 52.71528788975307, 49.550188882010325, 46.334593841007774, 43.87856544767107, 39.68808603286743, 37.47737768718174, 40.022433349064414, 48.42891986029488, 52.659712723323274, 51.129858357565745, 48.76672043119158, 49.72445317677089, 45.931184904915945, 50.22346237727574, 50.902735642024446, 48.27602127620152, 47.04683630807059, 44.40136875425066, 40.182825565338135, 37.641723428453716, 36.41887174333845, 37.583042417253765, 41.027559757232666, 45.36840166364397, 48.176967757088796, 48.62564768110003, 49.94512448992048, 48.4090063231332, 43.469789028167725, 40.32102176121303, 39.63900048392159, 39.239993231637136, 37.836088861737935, 37.82013232367379, 36.51307541983468, 44.49124717712402, 51.04269668034145, 49.87297439575195, 51.472453185490195, 48.75136491230556, 53.769951479775564, 50.16434710366385, 52.77233954838344, 49.467265605926514, 55.514703205653596, 33.961391176496235, 20.6830119405474, 50.67484515053885, 41.69061592647007, 46.658748149871826, 44.393294947487966, 48.633089201790945, 46.1116852079119, 50.92971897125244, 49.06923457554409, 51.65105663027082, 46.24983971459525, 39.90820149012974, 38.401029518672395, 38.88850123541695, 41.63453006744385, 44.015531812395366, 43.40827315194266, 44.52342775889805, 42.307730606624055, 41.35966280528477, 38.900705746241975, 36.74832057952881, 36.989520345415386, 36.73182903017317, 35.52030985695975, 36.31041036333357, 36.4627183505467, 35.61975942339216, 36.63122953687395, 36.5327353477478, 39.24931076594761, 37.777244567871094, 40.50956112997872, 40.65303795678275, 41.02804960523333, 41.050787585122244, 39.7794166292463, 40.44604764665876, 42.169464928763254, 45.960666111537385, 50.19239003317696, 52.239794867379324, 53.42473718098232, 47.34653990609305, 49.02827841894967, 47.753242288317, 46.25211524963379, 33.296059472220286, 18.42817211151123, 6.74137590612684, 3.774482948439462, 13.505301322255816, 10.485898222242083, 5.099458822182246, 1.4022090094430106, 0.08090168277599982, 0.08883014733770064, 0.6656331909554345, 18.55534499032157, 33.14126402991158, 34.85316467285156, 24.81401651246207, 31.91463599886213, 42.87324448994228, 49.13600328990391, 50.7451366015843, 34.57591765267508, 4.2617210320064, 0.08081973610179764, 0.01648831783261682, 0.00669154484057799, 0.014433016601417745, 0.040263586078903506, 0.004637126553071929, 0.01130917962707047, 0.05518800113350153, 0.017088490538299084, 0.019955131358333995, 0.04716257391763585, 0.050452895395989926, 0.07274185812899045, 0.056308466009795666, 0.058121077317212305, 0.02556204772554338, 0.016313825767221193, 0.0493224865889975, 0.03535514517820307, 0.04468973785904901, 0.19441191293299198, 0.14141600738678659, 0.06319387975547995, 0.08371963192309652, 0.24425719039780752, 0.1660934439195054, 0.15679847768374852, 0.10421584067600113, 0.14284557210547583, 0.06727490148374013, 0.17263571572090897, 0.22438527457416058, 0.22017070358353003, 0.26471100428274696, 0.1027746797938432, 0.12087538173156125, 0.11852279225630419, 0.15214899288756506, 0.2570571835551943, 0.4457275910036904, 36.806344985961914, 69.70891407557896, 61.7553528376988, 52.75216545377459, 35.98798268181937, 16.933037894112722, 41.055307388305664, 54.966747420174734, 42.70076240812029, 9.787487012999398, 0.3061750036265169, 0.36845702731183594, 0.5576298492295402, 1.882284368787493, 9.997197542871747, 16.242838587079728, 12.892953974860054, 10.412787539618355, 31.142003263745988, 55.72236401694161, 58.283570766448975, 56.60788066046578, 54.868666648864746, 51.49227292197091, 47.17055940628052, 45.456094878060476, 40.78444576263428, 41.32246215002877, 42.442556926182334, 50.09770693097796, 54.95687402997698, 53.22003282819475, 49.19547986984253, 50.18626519611904, 46.07257032394409, 52.30009480885097, 54.287345613752095, 49.94028159550258, 49.69927290507725, 48.447197096688406, 43.13173137392317, 40.65618896484375, 38.46814911706107, 39.53323500497, 43.52101114818028, 48.55571753638131, 50.37019443511963, 50.551410402570454, 53.962711879185264, 50.780471665518625, 45.250591482434956, 43.86208084651402, 41.938423429216655, 40.873035294669016, 39.742361886160715, 40.280214990888325, 38.65526063101632, 47.97476475579398, 52.26458951405117, 51.626112597329275, 54.120283126831055, 49.98904405321394, 56.646300724574495, 51.530147552490234, 55.8336637360709, 52.612610885075156, 56.90468338557652, 35.06473731994629, 23.591222149985178, 51.175820691244944, 42.505038602011545, 47.37358924320766, 44.91222810745239, 48.22356932503836, 47.79055411475045, 52.54803432737078, 50.89627729143415, 55.17409208842686, 48.46621431623186, 40.806558404650005, 39.592808859688894, 41.83812270845686, 44.99156263896397, 46.95037794113159, 45.56193331309727, 45.9297639983041, 45.85542522157942, 42.63305916104998, 40.85840933663504, 38.274210997990195, 39.1590119770595, 39.04674645832607, 36.10840885979788, 37.320925099509104, 38.02952323641096, 36.54117046083723, 39.17183835165841, 38.66136462347848, 41.134225027901785, 39.19448600496565, 43.24792957305908, 41.94888046809605, 42.55882808140346, 44.01140110833304, 42.34148495537894, 41.7641521862575, 45.25411769321987, 48.52877937044416, 51.869879722595215, 53.635510785239084, 53.56831128256661, 47.131170068468364, 49.19928748267037, 47.58064208711897, 47.90070390701294, 34.18419211251395, 20.565479687282018, 8.566104003361293, 12.292755552700587, 34.544067110334126, 15.091284104755946, 6.1253885711942395, 1.3841396761792046, 0.19410362733261927, 0.21540447005203792, 1.0786308582339967, 21.780827317919048, 42.511649812970845, 39.38327898297991, 24.789202758244105, 36.64217642375401, 50.43014349256243, 56.74931819098336, 59.14386544908796, 39.67524576187134, 6.006652542522975, 0.22023288453263895, 0.18746024024273666, 0.12940770174775804, 0.19466691996370042, 0.11241320866559233, 0.13746534580630915, 0.086153740595494, 0.15118574457509176, 0.08118090672152382, 0.1435697725308793, 0.12045132448630673, 0.16640443008925232, 0.3331689180008003, 0.13591216557792254, 0.16044746259493486, 0.18486553590212548, 0.10984521146331515, 0.1216858918113368, 0.06870919559150934, 0.09099160028355462], [0.040815197729638646, 0.024745751438396316, 0.05024994896458728, 0.02743974750462387, 0.02435803143972797, 0.017335960741287897, 0.006905647235855992, 0.02418528829834291, 0.05688399601993816, 0.03962662150817258, 0.04998209048062563, 0.02763066011747079, 0.015788083264072026, 0.11745946002858025, 0.021553854857172285, 0.038019436677651744, 0.022100908448919654, 0.12230399650122438, 0.03608173743954726, 0.9994993443999971, 33.19023493358067, 48.87647417613438, 43.46320908410208, 33.453453540802, 22.204387766974314, 24.777957098824636, 28.647546121052333, 32.917205469948904, 23.851032665797643, 2.0705269191946303, 0.05810445320925542, 0.03515221910285098, 0.049348884993898015, 1.5697038045951297, 1.426934391260147, 3.301285220044, 7.16777469430651, 15.014789649418422, 44.56978266579764, 56.03313609531948, 53.62618630273001, 49.11489118848528, 43.88932820728847, 42.438707624162944, 40.0025371823992, 39.37933240618025, 37.7856935773577, 37.30558695111956, 37.41775172097342, 43.59455435616629, 48.38214806147984, 50.08115632193429, 50.70281512396676, 49.546124185834614, 50.66680955886841, 47.84512526648385, 48.33545964104788, 46.955953870500835, 48.563193798065186, 46.24599041257586, 48.35110003607613, 42.865007400512695, 37.957317556653706, 37.16377074377877, 43.072296483176096, 45.99936410358974, 47.59710584368025, 46.557464259011404, 48.98702348981585, 46.92801863806588, 44.56660386494228, 38.113829204014365, 41.84078734261649, 37.14936017990112, 38.69433729989188, 35.75251170567104, 38.50038528442383, 43.591917514801025, 52.01585790089199, 42.38858331952776, 44.22660766329084, 46.15905802590506, 49.03567477634975, 46.951364585331504, 50.08860131672451, 46.09588153021676, 51.433112485068186, 28.562646082469396, 19.935694966997417, 51.56323140008109, 42.074719292776926, 51.42299590791975, 45.166097913469585, 50.26689556666783, 46.473464012145996, 51.068151405879426, 44.820654324122835, 46.10672072001866, 38.217016901288716, 37.60033995764596, 35.77424567086356, 37.11859703063965, 39.05492101396833, 42.29496676581246, 42.45560564313616, 44.79407399041312, 43.5913199697222, 40.39220258167812, 36.19880839756557, 35.03522137233189, 33.121020453316824, 34.997805322919575, 36.814672401973176, 38.52144874845232, 36.4420439856393, 35.2064562525068, 34.75085244859968, 35.41479451315743, 36.70763192858015, 37.60367856706892, 39.0701653616769, 40.285832609449116, 41.798500605991904, 42.1679675919669, 39.258753367832725, 41.71620961597988, 44.62614645276751, 46.936832427978516, 48.50350182397025, 51.06815487997872, 48.92847449438912, 48.826999528067454, 43.613432611737935, 48.67330537523542, 49.06419365746634, 40.29474367414202, 27.0912503855569, 6.053415221827371, 1.8307189643383026, 2.02501317858696, 5.240194150379725, 6.443705090454646, 0.992139573608126, 0.03614365375999894, 0.054099661497665305, 0.034909676760435104, 7.458881633622306, 37.053429876055034, 26.49311818395342, 13.648310882704598, 21.42304025377546, 34.773177010672434, 42.45968076160976, 43.32996347972325, 36.400629247937886, 12.166035175323486, 0.02752014372630843, 0.025777564018166492, 0.006836709350214473, 0.025064598436334302, 0.019437090227646486, 0.030031881893851926, 0.02285607042722404, 0.029487008095851967, 0.03408058499917388, 0.04432240274867841, 0.01302421759880547, 0.014768584398552775, 0.035501416972173114, 0.00566665713475751, 0.06838717644235917, 0.02852854345526014, 0.04388135498655694, 0.023803320580295155, 0.00911758785202567, 0.049085430202207396, 0.014939970469900539, 0.07666456406669957, 0.005687321070581675, 0.03337368382407086, 0.06004287847982986, 0.052991929330996106, 0.025791808164545467, 0.020756923959457448, 0.035645503883383105, 0.025966135685199072, 0.015850611962378025, 0.0348027464268463, 0.029107303292091404, 0.029844806396535466, 0.010097864848960723, 0.027937890595889518, 0.04041501473901527, 0.05827659075813634, 0.03487150916563613, 1.6380620279482432, 41.48097487858364, 55.783928530556814, 50.003524099077495, 40.1777012688773, 28.90048313140869, 21.947078602654592, 31.931051118033274, 36.73191588265555, 27.74719681058611, 2.4610195883682797, 0.06645036608512912, 0.01353294074734939, 0.49413346499204636, 3.062005328280585, 4.640040022986276, 4.90422442981175, 3.5400548534733907, 16.28346644129072, 45.38089452471052, 59.02525969914028, 55.27597005026681, 52.54568583624703, 47.664565903799875, 44.43735694885254, 43.085466793605256, 42.08476638793945, 40.35640893663679, 39.97118691035679, 39.069550446101594, 46.49307530266898, 52.290405545915874, 52.596859318869456, 50.93723692212786, 49.3367714881897, 51.119627135140554, 47.96803889955793, 50.75369330814907, 49.46382277352469, 50.47592517307827, 48.89921563012259, 50.78117343357631, 43.57119798660278, 38.63609055110386, 38.02765417098999, 44.156806060246055, 46.344078132084434, 50.26734372547695, 48.612327984401155, 50.56131158556257, 47.569028173174175, 45.96462658473423, 40.147316796439036, 43.765205587659565, 39.13797630582537, 40.371667180742534, 36.72786855697632, 39.14159631729126, 46.91224275316511, 52.92565849849156, 45.588107177189414, 47.93921429770333, 45.43859583990914, 48.839287417275564, 47.57855415344238, 51.31383970805577, 46.40975250516619, 51.69662986482893, 29.531952789851598, 21.546900578907557, 52.23168631962368, 43.708435331072124, 51.609047821589876, 47.761576652526855, 52.188412938799175, 49.31186219624111, 52.332337924412315, 47.04603031703404, 47.81249305180141, 40.220745359148296, 39.13486351285662, 36.52311904089791, 37.89469691685268, 39.679498059409006, 44.70744732448033, 44.205728326525005, 47.71734094619751, 45.796202250889365, 42.54568903786795, 38.432397161211284, 36.306925841740195, 34.60806001935686, 36.37611600330898, 38.28088126863752, 38.207890442439485, 38.03443561281477, 35.5544741494315, 36.46860000065395, 37.312291962759836, 38.21490464891706, 39.39265210287911, 39.41800955363682, 41.46989597593035, 43.32190009525844, 42.99668966020857, 41.37573398862566, 43.741262095315115, 46.87211690630232, 48.61324167251587, 49.778656073978965, 53.00299889700753, 49.64997543607439, 48.108604431152344, 45.246217591421946, 49.63923699515206, 49.81800372259957, 40.848661014011924, 25.316878489085607, 8.29692210469927, 5.553148397377559, 5.624383066381727, 9.28580709866115, 7.658125570842198, 2.0560373195580075, 0.25130301660725046, 0.05890740440892322, 0.0390106168841677, 8.69250910622733, 38.54724393572126, 26.753336906433105, 16.92869179589408, 27.681518963405065, 41.58672646113804, 47.39757095064436, 49.577801023210796, 44.33652816499983, 15.038615022386823, 0.28752460011414116, 0.02022853008072291, 0.0532313504123262, 0.028730553508337055, 0.030449533768530403, 0.07588114789021866, 0.021986882335373333, 0.01765537092329136, 0.0529725028734122, 0.07310283197356121, 0.009156886055799467, 0.027013378151293312, 0.022324280480721166, 0.032957674004137516, 0.02032000169024936, 0.027401205019227097, 0.051674143078603914, 0.0385788209470255, 0.010672111579749202, 0.027258202067709396, 0.15081857570580073, 0.1157497689127922, 0.089414332062006, 0.10447052879525082, 0.07596305385231972, 0.10222022847405501, 0.14013871949698242, 0.10346303321421146, 0.11147394656602826, 0.08561020011880568, 0.10011250193097762, 0.1307960929615157, 0.13000116204576834, 0.14708571029560907, 0.1315673022930111, 0.19465119152196816, 0.10017237586102315, 0.20583970472216606, 0.2099392233150346, 2.8207831978797913, 51.55234357288906, 61.63348838261196, 56.79217120579311, 45.90282930646624, 31.673985140664236, 34.71666383743286, 39.80107763835362, 44.73178686414446, 34.108814580099924, 3.1173937618732452, 0.13377039693295956, 0.15813992784491607, 0.49856071599892204, 4.820028764860971, 10.186899866376605, 12.174762112753731, 11.716664774077278, 17.949545451572963, 47.61531707218715, 61.003071376255576, 57.66582727432251, 53.49755082811628, 49.054730210985454, 47.69070502689907, 44.90120826448713, 43.705701214926584, 41.989968640463694, 41.88369941711426, 40.565716470990864, 48.442128385816304, 53.233342102595735, 55.100743430001394, 51.30178805759975, 50.572703157152446, 49.860474586486816, 49.2101058278765, 52.96152509961809, 51.41759020941598, 52.75988837650844, 50.11563328334263, 53.33046402250017, 46.691213607788086, 40.801833629608154, 40.02584491457258, 47.49410227366856, 49.1210994039263, 51.689104965754915, 51.67435394014631, 51.413480349949424, 49.91565717969622, 47.89110149656023, 41.956895215170725, 46.017759459359304, 40.4030556678772, 42.64416585649763, 39.51470415932791, 40.985231331416536, 48.68039601189749, 55.423188482012065, 48.25877237319946, 49.24901226588658, 46.20366546085903, 48.76423297609602, 48.48595067432949, 51.24291944503784, 48.53238548551287, 51.53811018807547, 31.08118220738002, 23.54199763706752, 52.497857911246165, 44.19754334858486, 53.15048483439854, 49.07359804425921, 52.868408816201345, 52.475964137486045, 55.30899483816964, 49.07419211523873, 49.04083381380354, 42.44443988800049, 41.96091474805559, 38.51121057782854, 40.383211612701416, 41.698026180267334, 46.332717827388215, 46.3847667830331, 50.129355975559776, 48.058500971112935, 44.92107663835798, 40.04945141928536, 38.418670994894846, 36.51111255373274, 37.81395190102713, 41.35253047943115, 41.62152998788016, 39.82871757234846, 38.29084151131766, 38.99823413576399, 40.01271281923567, 40.561547551836284, 40.81642484664917, 43.72809873308454, 44.0061308997018, 45.39967897960118, 46.9026438168117, 43.38433313369751, 46.80266618728638, 49.454213414873394, 50.75872727802822, 52.376587527138845, 54.72928925922939, 51.14094768251692, 49.85576718194144, 44.87289782932827, 49.69714675630842, 49.63392857142857, 42.79439285823277, 30.686104161398752, 8.143225346292768, 5.699718475341797, 9.749537689345223, 11.166298832212176, 12.25591880934579, 2.9248385514531816, 0.22108740439372404, 0.07186095004103013, 0.2558140531182289, 10.887772474970136, 48.10956328255789, 35.57585375649588, 22.704060520444596, 31.24553837094988, 48.19069044930594, 54.458333832877024, 55.826152733394075, 54.443113803863525, 18.74736019543239, 0.6215413340500423, 0.08863138407468796, 0.10121955216995307, 0.08610772913587944, 0.18694231446300233, 0.13048490323126316, 0.10902824851551227, 0.10028810000845365, 0.2048638356583459, 0.1584698994244848, 0.10420174750366382, 0.10402899927326612, 0.16109014382319792, 0.12318417855671474, 0.16154491156339645, 0.0916045413219503, 0.07146773221237318, 0.11637908300118786, 0.10659767501056194, 0.15295649027185781], [0.034072157594242265, 0.03092979746205466, 0.01661445070723338, 0.09591874839471919, 0.04940327296831778, 0.07719422850225653, 0.06009796873799392, 0.03858878184109926, 0.01653221226297319, 0.10023086557963065, 0.04532746917435101, 0.03291725706575172, 0.013687730700309788, 0.03979790749560509, 0.03630823242877211, 0.03733029276398676, 0.07019767750586782, 0.04698676549430404, 0.05405252706259489, 5.532419749668666, 44.87784147262573, 49.00631863730294, 49.28954458236694, 30.443810054234095, 18.186008283070155, 17.000496217182704, 22.262801272528513, 34.749362060001914, 19.45452700342451, 0.3268841638096741, 0.11741971144718782, 0.025016154428677898, 0.93389792740345, 2.0958155393600464, 3.2891373804637363, 3.2703577024596076, 8.529936892645699, 25.243203265326365, 49.689038208552766, 53.506847517830984, 49.922223227364675, 45.858235767909456, 42.07240901674543, 44.45962592533657, 44.94381809234619, 47.666434969220845, 45.57333878108433, 42.2082428250994, 37.883843830653596, 38.39686059951782, 45.847132546561106, 49.940187794821604, 48.554685728890554, 47.723021098545615, 46.711759431021555, 45.885455335889546, 46.74450976508004, 49.7894674709865, 49.60364137377058, 49.28092186791556, 48.509039538247244, 47.40848657063076, 39.43505348478045, 37.85353578839983, 41.318696226392476, 45.561433042798726, 49.38063893999372, 47.28141444069998, 49.71232162203108, 46.39561292103359, 42.90772492544991, 40.58696058818272, 38.488781792776926, 35.025146484375, 37.38313579559326, 36.33069562911987, 37.909517424447195, 43.98610619136265, 50.91273757389614, 46.44142239434378, 49.798691204616, 46.82016175133841, 50.34203338623047, 44.30144671031407, 51.61032976422991, 43.326472009931294, 48.17746802738735, 27.12662192753383, 22.83604850087847, 52.93990230560303, 44.02217776434762, 51.81128208977835, 46.42289849690029, 49.408991064344136, 44.37343004771641, 46.03747844696045, 39.48044606617519, 37.814042227608816, 36.82546295438494, 41.74366889681135, 37.392724309648784, 36.71722044263567, 36.28088051932198, 42.21208865301949, 42.6558700970241, 49.05333014896938, 45.82957444872175, 44.18599891662598, 37.90879828589303, 34.81268794195992, 35.34975242614746, 41.55205842426845, 46.27282782963344, 48.152166162218364, 43.258994579315186, 40.281740120479036, 36.190741539001465, 36.833133765629356, 39.72044726780483, 44.61536979675293, 45.76428917476109, 47.714662415640696, 49.70869813646589, 48.6228996685573, 49.572853905814036, 49.39081457683018, 47.900391238076345, 50.616223199026926, 50.25787680489676, 48.8570157459804, 46.83309234891619, 45.996692521231516, 46.82045357567923, 44.97863898958479, 45.71122925622122, 42.490304946899414, 31.843611512865337, 18.267594030925206, 4.743906038148062, 7.475152577672686, 11.288263167653765, 7.77901554107666, 0.8579200814877237, 0.06816281205309288, 0.0408645713302706, 0.031561788371098895, 1.3815890359027045, 28.632218394960674, 52.79947573798043, 21.015912294387817, 17.078175340379985, 34.23115151269095, 40.78171164648873, 48.941547530038015, 40.89575937816075, 19.560853549412318, 0.8997251668146679, 0.028794600428747277, 0.03139113002855863, 0.06865694160972323, 0.030374776172850813, 0.012645573006011546, 0.008049416821449995, 0.013631632817643029, 0.03805274935439229, 0.059793408294873576, 0.03336104950202363, 0.034315035811492374, 0.01333325806938644, 0.011444616064961468, 0.04587744216301611, 0.002814955747453496, 0.010872894332611134, 0.020225108567891375, 0.020161813125014305, 0.05758128235382693, 0.05960812073733125, 0.09600080363452435, 0.016997943432735543, 0.024930545361712575, 0.044569304678589106, 0.010456914198584855, 0.018100569623389413, 0.0535605314985982, 0.009497380865338658, 0.048193953931331635, 0.02242807937519891, 0.003065850219822356, 0.0435132836656911, 0.018150280795193145, 0.025085083408547298, 0.056807134965700765, 0.0783392224194748, 0.06749557464250497, 0.0875935647636652, 7.7741222722189764, 52.44882099969046, 52.505309854234966, 56.25720507758004, 35.322102069854736, 27.152425800051006, 19.991872889654978, 22.811872243881226, 37.15617288861956, 22.124360152653285, 0.3343305428113256, 0.06555035723639385, 0.11399515877876963, 1.8375123483794076, 5.523724513394492, 6.393133495535169, 4.238188351903643, 6.164410523005894, 25.890773636954172, 50.91924108777727, 55.50506952830723, 54.2300820350647, 47.51783732005528, 43.86619765417916, 45.71422740391323, 47.311336857931956, 49.01894004004342, 47.70514685767037, 43.549377168927876, 39.94536740439278, 42.414482729775564, 48.668445110321045, 51.35651554380144, 49.39845412118094, 47.77300296510969, 48.19585643495832, 46.15433325086321, 48.86955377033779, 50.8804041317531, 51.17232574735369, 51.165940352848594, 51.402960777282715, 49.218954358782085, 41.55846118927002, 39.17096635273525, 43.28371279580252, 48.53456721987043, 50.826715401240754, 49.152995109558105, 51.550207001822336, 47.78863293784005, 44.99389375959124, 42.56613758632115, 40.9870274407523, 36.64708880015782, 38.41856677191598, 37.37464509691511, 39.633483614240376, 46.22148411614554, 52.888645444597515, 48.55235808236258, 51.80479942049299, 47.569014276777, 50.941228662218364, 45.85855538504464, 50.72463941574097, 43.701473236083984, 49.22320665631975, 28.616840294429235, 23.900759186063492, 53.01248666218349, 45.62258761269705, 54.78846011843, 48.538770880017964, 50.787218366350444, 45.97289841515677, 48.79822356360299, 42.094045707157676, 41.09353985105242, 37.66154316493443, 43.46119063241141, 39.05245440346854, 37.300876072474885, 38.18094532830374, 44.10267611912319, 45.655991077423096, 48.71837486539568, 48.73730870655605, 45.79763010569981, 39.630652223314556, 35.9721268926348, 36.450371401650564, 42.358212743486675, 47.94981377465384, 49.09845869881766, 44.20844507217407, 41.207302706582205, 38.037940979003906, 38.50928245271955, 41.4866098676409, 47.024727140154155, 47.02280248914446, 48.80069017410278, 51.476312909807476, 49.91627556937081, 50.990143980298726, 50.54830455780029, 50.12815046310425, 53.06624140058245, 51.98562976292202, 48.60932288851057, 46.32187516348702, 47.565026010785786, 47.174141202654155, 46.085066659109934, 47.17524249213082, 43.71163845062256, 33.30642965861729, 19.49410046849932, 7.882891110011509, 9.351554427828107, 11.517228892871312, 9.08868670463562, 5.699511766433716, 1.1917151787451334, 0.01645777527508991, 0.07851745321282319, 1.7514422982931137, 30.924979754856654, 40.53862544468471, 18.232609851019724, 22.702485016414098, 37.39345039640154, 46.44795370101929, 53.94658163615635, 50.09431273596627, 23.48722846167428, 1.7064811566046305, 0.041672804925058565, 0.0166283216593521, 0.05180123608027186, 0.013414147077128291, 0.00476936115384368, 0.051714061293751, 0.009321261164067047, 0.024610037649316446, 0.0405808724462986, 0.03899045082341347, 0.033205023767160516, 0.017423576575570872, 0.026039834766249572, 0.01014895090234599, 0.01606563462077507, 0.07633330327059541, 0.040140995157084296, 0.017949844943359494, 0.09349203575402498, 0.15937373521072523, 0.16968855315021106, 0.06691096244113785, 0.15132325648197106, 0.1546519457229546, 0.1712133027613163, 0.20435471726315363, 0.11531351160790239, 0.08715759244348321, 0.23315244913101196, 0.12327940416123186, 0.1163993983396462, 0.1199355021651302, 0.172113691589662, 0.11640435164528233, 0.21779729665390082, 0.2194565319057022, 0.17000373266637325, 0.11895728537014552, 10.950235043253217, 61.5658198765346, 59.875990186418804, 61.48615183149065, 41.54441540581839, 27.849462134497507, 26.62692485536848, 32.5133171081543, 44.765370982033865, 27.163541180746897, 0.5799697190523148, 0.3016816904502255, 0.222587292481746, 2.382402024098805, 5.554086404187339, 13.016772610800606, 9.984336427279882, 11.0664975132261, 28.041140351976665, 52.231186049325125, 58.30100727081299, 56.37968792234148, 49.01755734852382, 45.08476577486311, 48.86932447978428, 50.21472501754761, 51.524505615234375, 50.65885387148176, 46.72974484307425, 42.62639931270054, 43.28072507040841, 50.49054765701294, 53.78327465057373, 49.88725989205496, 46.78083494731358, 48.674583843776155, 47.012404509953086, 48.57258081436157, 52.75933946881975, 52.63799612862723, 53.24741915294102, 52.69848019736153, 52.64921746935163, 42.97947202410017, 41.91208975655692, 45.281288623809814, 49.931499072483604, 52.79003661019461, 49.990669931684224, 53.24879142216274, 50.986739362989155, 47.173276151929585, 44.65848684310913, 42.13434178488595, 38.01101670946394, 40.865631989070344, 40.63876288277762, 41.685797350747244, 48.219438620976035, 55.70093577248709, 51.35281562805176, 52.02228845868792, 50.359918049403596, 52.002065726688926, 47.77849899019514, 52.03225564956665, 43.75551632472447, 47.772936957223074, 30.659846918923513, 25.71887867791312, 52.358150482177734, 47.089091777801514, 56.223065103803364, 50.749051911490305, 52.658437728881836, 48.111314228602815, 50.26533222198486, 43.53604357583182, 41.927000590733115, 39.85185159955706, 45.331736019679475, 41.52010365894863, 38.48655489512852, 39.691448960985454, 47.35324491773333, 46.64850650514875, 52.5888306753976, 51.65601764406477, 48.85161004747663, 41.31645890644619, 38.50061110087803, 39.00488008771624, 46.95390067781721, 50.12520790100098, 52.19186619349888, 46.658935751233784, 43.993037019457134, 40.778560638427734, 40.68373162405831, 44.6635034424918, 49.17234236853463, 48.99432952063424, 51.55705445153372, 55.12935263769967, 51.98773506709507, 55.38254499435425, 53.29692159380232, 53.06137766156878, 55.63622719900948, 53.737030914851594, 49.940677642822266, 47.35233122961861, 47.18618590491158, 48.645915576389854, 46.970017024448936, 47.15333134787423, 44.37981196812221, 35.85835361480713, 23.28381473677499, 10.432650702340261, 9.571946944509234, 21.483727557318552, 17.939375025885447, 7.460445846830096, 1.254561635000365, 0.2994845397770405, 0.2711985861616475, 2.30583113857678, 37.583240440913606, 63.80842045375279, 30.392813750675746, 27.21119713783264, 43.625727449144634, 53.21048947743007, 62.067646571568076, 58.80095100402832, 31.568045956747874, 2.7704361166272844, 0.12673236030553067, 0.12926831708422729, 0.16513005990002835, 0.13358603896839277, 0.13713567278214864, 0.12642408827585833, 0.10663008184305259, 0.1625209299049207, 0.11939251130180699, 0.09856724020625864, 0.11447584655668054, 0.10852381201194865, 0.09056106302887201, 0.26466299114482744, 0.06332035868295602, 0.13223210376288208, 0.07127435651740857, 0.09326266377632107, 0.2977556868323258], [0.04595690879172512, 0.042480207314448695, 0.06665474083274603, 0.033939931475158246, 0.03622088800849659, 0.021677153151748434, 0.0697932977761541, 0.06175182999244758, 0.014182006141969135, 0.055009315721690655, 0.025338767295969383, 0.05048502742179802, 0.06349139021975653, 0.017528685042634606, 0.04470454688583102, 0.04479128401726484, 0.030027590159858977, 0.033426989535135884, 0.02548100859192865, 13.398013319287982, 45.29407330921718, 49.38704170499529, 41.472011702401296, 22.65080084119524, 19.21700804574149, 24.601389476231166, 37.36475781032017, 34.57366991043091, 10.791960290500096, 0.08447021379002503, 0.11595270516616957, 0.02620329045956688, 1.3288596996239253, 4.274548709392548, 3.1569670098168507, 2.6977468856743405, 5.88332679441997, 28.605016197477067, 54.82053995132446, 54.11204603740147, 49.42989124570574, 47.60441882269723, 49.10256508418492, 48.58783905846732, 49.45355681010655, 50.47761358533587, 49.742365632738384, 46.469645977020264, 42.732710225241526, 41.5881404195513, 47.03618124553135, 47.11789900915963, 51.36793143408639, 45.51981680733817, 46.229189668382915, 46.73685285023281, 45.15451526641846, 43.63639293398176, 45.03315108163016, 44.689764159066335, 47.535242557525635, 46.45569052015032, 41.27437366758074, 36.4366626058306, 41.788606371198384, 43.39558574131557, 51.345558234623496, 48.105988434382844, 49.00833708899361, 43.85988174165998, 37.07104703358242, 35.22447640555245, 36.90269912992205, 35.57222332273211, 37.46405104228428, 35.668153626578196, 36.41730839865548, 37.29870128631592, 45.08982753753662, 47.45185375213623, 50.24867391586304, 47.58981718335833, 52.733478273664204, 48.87264224461147, 51.910189696720664, 46.14734683718, 52.197838170187815, 26.087791545050486, 23.251053980418614, 54.43541867392403, 45.12551348549979, 49.95244789123535, 42.37248434339251, 43.03362280981881, 37.625224930899485, 38.17757197788784, 35.049381801060264, 37.27404907771519, 35.22096061706543, 38.13329458236694, 36.047990798950195, 38.077677726745605, 35.95229325975691, 40.08165979385376, 44.13041680199759, 48.1024101121085, 46.376922266823904, 44.88070413044521, 38.13816179547991, 36.97694410596575, 40.713174615587505, 47.949681758880615, 48.67304481778826, 49.094133445194785, 46.01067924499512, 43.722519329616, 40.76825645991734, 43.42720004490444, 45.573446478162495, 47.02181584494454, 47.243953227996826, 48.03160796846662, 47.78819520132882, 50.1237279347011, 49.1292531149728, 50.18470185143607, 51.81898069381714, 49.03294760840279, 47.70260034288679, 46.74067783355713, 48.1854202406747, 49.60639633451189, 50.04996933255877, 51.46854134968349, 49.263870988573345, 50.16337782996041, 37.58731208528791, 25.92938651357378, 18.238626990999492, 12.665642789431981, 8.723278335162572, 3.76797639472144, 3.3071460255554745, 1.4767767510243823, 0.11207514216325112, 0.03129472377310906, 0.45780470009360996, 13.348073141915457, 42.07871103286743, 51.9810335295541, 33.34866428375244, 24.351183107921056, 38.66620751789638, 38.73044013977051, 36.452104977199006, 37.93348870958601, 5.382881922381265, 0.12493397109210491, 0.03589778320331659, 0.027473974507302046, 0.02548603484007929, 0.026480409250195538, 0.03649468367387142, 0.030419576447457075, 0.02616265299730003, 0.0016918742704936968, 0.032322436305029054, 0.03699122202981796, 0.06392451947821037, 0.033149519602635076, 0.048492041150374074, 0.028208754989983778, 0.06578189374080726, 0.03781825443729758, 0.024800278512494903, 0.07628232493464436, 0.04540423862636089, 0.03719735757580825, 0.008118635026871093, 0.02225229300425521, 0.046614643319376876, 0.059432875498064926, 0.038946437649428844, 0.0314019390914057, 0.008673020189494958, 0.018935647759852663, 0.04667932467002954, 0.022876916719334464, 0.016551387662600194, 0.04409074071528656, 0.05195451374830944, 0.1223989235503333, 0.029041292012802193, 0.0787972267717123, 0.03987143015755074, 17.79224865777152, 53.410034792763845, 53.99107789993286, 48.17243753160749, 30.785602365221294, 25.743836607251847, 25.533427783421107, 37.40389701298305, 37.535339559827534, 12.803519368171692, 0.0357255269108074, 0.10811373937342848, 0.026122139367674078, 3.195969202688762, 6.665175446442195, 7.222739287785121, 3.5801807003361836, 7.2808531522750854, 31.35201951435634, 56.11218575068882, 56.36635085514614, 51.433762141636436, 48.213383265904014, 51.48858690261841, 51.289545331682476, 51.24105732781546, 53.204069341932026, 51.77886526925223, 49.33264078412737, 43.87465361186436, 42.79689073562622, 48.370944091251914, 50.41914449419294, 50.659434046064106, 47.918255056653706, 46.20223413194929, 46.08522994177682, 45.31963225773403, 44.6977858543396, 46.57303517205374, 46.975179536002024, 49.216056959969656, 47.70467438016619, 44.267376218523296, 39.376250880105154, 42.6341152872358, 45.96942778996059, 50.770924840654644, 49.35462835856846, 50.727700097220286, 45.726994718824116, 39.19498974936349, 37.251578603472026, 38.1429317338126, 36.925204345158164, 39.22976895741054, 37.327494621276855, 40.01839644568307, 39.6061042376927, 47.511139256613596, 48.970000403267996, 51.86465467725481, 49.55428484507969, 54.70624555860247, 49.92435285023281, 52.96116031919207, 47.53101110458374, 53.31632096426827, 27.35443946293422, 24.795306750706263, 53.271022183554514, 47.07699843815395, 50.89698600769043, 44.753305435180664, 45.00886017935616, 40.766529832567485, 39.414848123277935, 36.57040500640869, 38.52683360236031, 36.75556060246059, 40.12283481870379, 39.293167795453755, 39.012842723301475, 37.58083289010184, 42.4043105670384, 46.52969230924334, 50.38549436841692, 48.98862852369036, 45.846017360687256, 39.53649371010916, 38.58732461929321, 42.67999424253191, 49.56288324083601, 52.325236865452354, 51.76878343309675, 47.89287328720093, 44.44271748406546, 42.42851461683001, 45.11134263447353, 48.26777376447405, 50.084387234279085, 51.07688181740897, 51.051590374537874, 50.0492501940046, 51.59724283218384, 52.01589611598423, 52.57555961608887, 53.489192145211355, 50.425613267081125, 48.39123283113752, 47.78849049976894, 48.13489294052124, 49.39619943073818, 50.200015681130544, 52.14693219321114, 50.49022109167916, 50.26241397857666, 39.58666317803519, 25.741409948893956, 13.324094908578054, 6.983835901532855, 10.726001909800939, 7.689093691962106, 3.0909285077026913, 2.481056890317372, 0.17238783330789634, 0.04198021521525724, 0.46994450581925257, 15.908605916159493, 48.83545548575265, 40.52474294389997, 30.46093041556222, 31.46028287070138, 41.397099699292866, 43.954776763916016, 43.415353366306846, 45.022325788225444, 7.539982744625636, 0.16040229930409364, 0.06665968735303197, 0.0692143581275429, 0.022581840499437282, 0.030466958547809293, 0.0009904644580923819, 0.07905748566346509, 0.019614388035344224, 0.01014978380408138, 0.03849166312388011, 0.01712929593798305, 0.029403059743344784, 0.03455128474161029, 0.03255381335371307, 0.017240329712097133, 0.04652186383360198, 0.017262287105300596, 0.02691282095786716, 0.07892369891383819, 0.20900086366704532, 0.13070187158882618, 0.1721107738890818, 0.1761279861841883, 0.088331749795803, 0.1515288661633219, 0.14333555581314222, 0.11365691585732357, 0.09494537633976766, 0.11682915527905736, 0.1427496408245393, 0.10991556197404861, 0.15478541356112274, 0.14687499803091797, 0.1592219876391547, 0.19541713542171887, 0.18119388792131627, 0.11381181861673083, 0.12400382171784129, 23.06617283821106, 62.19556985582624, 60.697545187813894, 54.82742214202881, 34.16818346296038, 26.551298924854823, 34.346210207257954, 49.020183767591206, 45.15821170806885, 14.95667839050293, 0.13163291662931442, 0.29400349674480303, 0.10679716430604458, 3.6097496279648373, 10.69582154069628, 10.449914370264326, 9.546654633113317, 8.721542154039655, 31.67474249431065, 60.49256638118199, 58.64992495945522, 54.49271351950509, 50.941881792885916, 55.38750600814819, 52.88733570916312, 53.09295722416469, 55.391039167131694, 54.343598229544504, 50.43870367322649, 46.03350755146572, 45.329060963221956, 50.877353872571675, 52.12985004697527, 52.20621769768851, 45.67929186139788, 48.031958852495464, 46.91358028139387, 45.74608142035348, 43.825050422123496, 47.30701507840838, 49.8896153313773, 51.35829775674002, 50.755576269967214, 46.40998179571969, 40.87057563236782, 44.8890107018607, 47.77930498123169, 55.1171099117824, 51.49761956078665, 53.66540888377598, 48.36766454151699, 41.44880471910749, 39.07878112792969, 40.6524577822004, 38.217409474509104, 40.79120288576399, 38.17592525482178, 40.912692138126914, 42.562038149152485, 49.31972755704607, 51.99662528719221, 53.97127553394863, 52.262452942984446, 56.64295516695295, 53.80042627879551, 55.405918734414236, 49.9680882862636, 52.54205887658255, 28.523409605026245, 27.145526238850184, 54.91191223689488, 49.035282203129356, 54.189553192683626, 47.11677687508719, 46.21122162682669, 42.730125495365684, 41.463204860687256, 39.145681858062744, 40.88100140435355, 40.047071661267964, 40.819850308554514, 39.92699984141758, 41.67503111703055, 39.523726395198274, 43.61908149719238, 49.129086358206614, 52.52734954016549, 50.35067694527762, 49.6345226424081, 42.05141156060355, 42.00550133841378, 44.64816182000296, 51.33988503047398, 53.8078921181815, 51.78246096202305, 50.00446210588728, 46.57515089852469, 44.374281202043804, 47.31574896403721, 50.53466176986694, 50.881554058619905, 52.34925331388201, 51.93021093096052, 52.89942210061209, 53.100332736968994, 53.95583316258022, 53.92955507550921, 57.06559671674456, 51.35384743554251, 49.82975312641689, 47.79786709376744, 49.25515447344099, 51.573056152888704, 53.7962886265346, 53.68482215063912, 51.907952376774375, 50.95071990149361, 41.93756185259138, 29.65718364715576, 23.31884581702096, 19.092430319104874, 18.950445617948258, 15.339524132864815, 9.032520941325597, 3.1169130333832333, 0.2895574638886111, 0.07438425892697913, 0.6909713713186127, 20.348133087158203, 56.11878306525094, 59.2573573248727, 42.59974602290562, 36.022032329014365, 48.89942407608032, 49.62462840761457, 50.19621501650129, 52.40368550164359, 10.232357587133135, 0.4079088174871036, 0.1165989554886307, 0.12311091034540109, 0.12439024741096155, 0.10889234473662716, 0.07879355589726142, 0.1353894221995558, 0.0939097690529057, 0.10957881182964359, 0.10695580579340458, 0.08504936378449202, 0.0978270670665162, 0.08564398437738419, 0.16563940899712698, 0.07449193564908844, 0.17394220775791577, 0.12933565489947796, 0.13847895498786653, 0.15883314636136803], [0.012714509619399905, 0.06405646739793674, 0.04537508536928466, 0.06551311923457043, 0.0021355267589180066, 0.024635604848819118, 0.03618002323699849, 0.11472199192004544, 0.04201175691559911, 0.04191173067582505, 0.019879401761240194, 0.029333774532590593, 0.016401304198162894, 0.007801431780015784, 0.02266015361861459, 0.03744612208434513, 0.05651536151500685, 0.08875128799783331, 0.6834444094981466, 24.021633522851126, 47.58652721132551, 44.78591333116804, 33.76938813073294, 17.625212226595195, 22.428904908043997, 36.02612829208374, 39.46864455086844, 33.137373038700645, 4.752437123230525, 0.0639935400603073, 0.09076302219182253, 0.22770465431468828, 1.7993973536150796, 7.36327702658517, 4.55151606457574, 1.5826228942189897, 9.487313543047224, 35.13957984106881, 51.84518929890224, 52.16423320770264, 50.049788679395405, 51.26222848892212, 50.9050737108503, 53.24503592082432, 41.25055524281093, 43.87309374128069, 51.797479493277415, 48.152544839041575, 47.834862777165, 43.49821758270264, 48.55236503056118, 48.31003270830427, 48.134149483272004, 44.26504162379673, 44.88657883235386, 44.567430700574604, 46.998813833509175, 45.354366302490234, 46.31956141335623, 43.43054212842669, 46.88523857934134, 47.8338622365679, 45.80665928976876, 39.08966200692313, 39.77810341971261, 43.472516196114675, 49.43647118977138, 47.737831183842246, 48.177808489118306, 42.64899832861764, 35.735655375889365, 34.275995186397004, 35.35836124420166, 35.77268580027989, 34.459729875837056, 35.73342500414167, 37.09318746839251, 35.70747000830514, 38.77475227628435, 37.75524657113211, 42.43033504486084, 40.30238321849278, 44.56188256399972, 41.90179252624512, 49.18675293241228, 45.205174582345144, 55.58938244410923, 29.351997920445033, 25.708082914352417, 54.17591387884957, 44.135996205466135, 47.72343104226248, 42.225547313690186, 45.465374197278706, 43.64713484900338, 45.717586857931956, 40.81927708217076, 41.01417405264718, 36.943290506090435, 36.622947284153526, 35.193303312574116, 37.09939568383353, 37.286597524370464, 40.92895092282976, 43.50087179456438, 47.36792993545532, 46.119453293936594, 43.93890707833426, 38.05352578844343, 38.30592605045864, 43.83747380120413, 47.87130607877459, 48.14882755279541, 48.16638912473406, 46.329966340746196, 47.09005757740566, 46.05045420782906, 47.13777085712978, 47.04174327850342, 49.582275663103374, 46.795898641858784, 47.88919421604702, 46.36673968178885, 47.308359554835725, 47.32028613771711, 48.175817830221995, 46.88137190682547, 48.44004740033831, 45.20406634466988, 49.02091332844326, 45.93417263031006, 49.85632651192801, 49.70291723523821, 50.22613743373326, 49.058933871132986, 47.43221466881888, 47.087076800210134, 37.29956633704049, 21.100103616714478, 16.052284240722656, 8.17197264943804, 5.082708886691502, 5.950594042028699, 1.8854809744017464, 0.13145039070929798, 0.05593118018337658, 0.03803072750036206, 5.952066625867571, 30.85976048878261, 55.71562079020909, 50.310377393450054, 22.847697155816213, 37.11455317905971, 42.27178757531302, 42.950379916599815, 45.80021136147635, 16.6215067250388, 0.22428973684353487, 0.03468517666416509, 0.03612021376777973, 0.07128529450190918, 0.04263691497700555, 0.009873754910326429, 0.023402331829337136, 0.061239088220255714, 0.07516285071947745, 0.03409556705238564, 0.044422656297683716, 0.05051681339474661, 0.06084258628210851, 0.1088085931592754, 0.012042021195936416, 0.03439471957140735, 0.06819525281233446, 0.043337685588215075, 0.030779345892369747, 0.009146442553693694, 0.06381469858544213, 0.02879994728469423, 0.025321758119389415, 0.054663354464407475, 0.1094776965411646, 0.030595778421099697, 0.022865189937874675, 0.015402809384145906, 0.038559978029557636, 0.03617018787190318, 0.04257339731390987, 0.018148769358439103, 0.03566515425752316, 0.018166465551725457, 0.029741000716707537, 0.024650008450927477, 0.08862882599766765, 0.766384838947228, 31.091208457946777, 53.912841183798655, 50.83845785685948, 38.51959705352783, 22.972292252949305, 19.992110865456716, 30.219129630497523, 45.22031470707485, 36.661561897822786, 6.422947347164154, 0.12177859326558453, 0.14170905309064047, 0.7348651502813611, 5.406624351228986, 9.045838900974818, 7.727848138128008, 5.112171854291644, 9.45856363432748, 37.111527238573345, 54.03369467599051, 55.275841508592876, 51.62057835715157, 54.50510215759277, 52.97110666547503, 55.55217136655535, 43.103215966905864, 47.461942536490305, 52.72114174706595, 50.05521869659424, 50.165278162275044, 46.53600474766323, 49.169889654432026, 49.79163530894688, 49.94843183244978, 46.59978921072823, 46.070152350834434, 45.08870887756348, 46.822635310036794, 45.37301179340908, 47.089359283447266, 45.5573023387364, 49.05765887669155, 48.51705081122262, 46.706492696489605, 40.30245617457798, 41.043867179325645, 45.40134654726301, 50.25381210872105, 49.089752605983186, 49.21195752280099, 44.97959436689104, 37.3863319669451, 35.46949768066406, 36.12682853426252, 37.16135277066912, 37.15180594580514, 38.51155798775809, 38.84053087234497, 37.767298221588135, 40.43364858627319, 40.42748900822231, 44.626983710697715, 43.22465658187866, 46.373913696834016, 44.53201573235648, 49.9812342779977, 46.561459473201204, 56.622812339237754, 29.79630742754255, 26.825181279863628, 54.48613010134016, 46.346225125449045, 50.77913761138916, 43.861184528895784, 46.6198729787554, 45.77498245239258, 47.26789672034127, 43.13941955566406, 42.42294910975865, 37.84538207735334, 38.144519397190635, 37.837864126477925, 38.04445144108364, 37.95786299024309, 42.308956963675364, 46.72897359303066, 49.628574984414236, 47.50879771368844, 44.83180618286133, 38.88156345912388, 39.716698714665, 46.00251163755144, 51.163421630859375, 49.41202742712838, 49.592909881046836, 48.376870904650005, 48.7471056665693, 47.16968045915876, 48.85427120753697, 49.0224141393389, 51.931148937770296, 48.25811229433332, 48.70783792223249, 48.28158678327288, 48.68680919919695, 47.10919986452375, 49.26444074085781, 48.1408405985151, 48.690081800733296, 47.72322954450335, 49.458212103162495, 47.282814502716064, 51.41968509129116, 51.415266036987305, 51.335660525730674, 49.91022021429879, 49.83771923610142, 48.652624062129426, 36.38346719741821, 17.983391863959177, 10.687876275607518, 7.965053558349609, 8.358265144484383, 7.664381555148533, 4.183318427630833, 0.4907206509794508, 0.12953758692102774, 0.055300573485770395, 7.583022492272513, 34.67432151521955, 61.641958236694336, 53.686927454812185, 28.157343762261526, 43.42089802878243, 44.649742535182405, 47.726133891514365, 52.49268497739519, 20.998236077172415, 0.09256962846432414, 0.028699880332819054, 0.024722321624202386, 0.027491214385788356, 0.0017609966328434113, 0.00997550378087908, 0.03513566963374615, 0.059141892540667734, 0.030152270969535624, 0.015710691256182532, 0.048008150687175136, 0.0416520553241883, 0.03282841308308499, 0.06280741335025855, 0.01807985225293253, 0.02073881046713463, 0.018545698773648058, 0.01499379356391728, 0.03310825110280088, 0.12628380794610294, 0.1994855771107333, 0.10461161658167839, 0.1551762225904635, 0.16131984149771078, 0.20686828238623484, 0.10524053033441305, 0.16259717009961605, 0.10190278943628073, 0.22944430953689984, 0.12223303530897413, 0.173599099740386, 0.18176902777382306, 0.15948291149522575, 0.11386298015713692, 0.13094789481588773, 0.17746038468820707, 0.18585721483188017, 1.3345294296741486, 38.608318601335796, 61.547337668282644, 58.35740579877581, 45.14773382459368, 26.390131984438213, 29.770307268415177, 47.32683481488909, 50.8138473374503, 43.913452352796284, 6.597308916704995, 0.24750799738935061, 0.2880629226565361, 0.5599361083337239, 4.307851425239018, 15.378685917173113, 12.746414729527064, 4.523243844509125, 11.380925212587629, 39.33148711068289, 56.06113386154175, 56.052066462380544, 54.592201301029746, 55.68905087879726, 55.42895548684256, 57.391793795994346, 44.34989997318813, 47.792787960597444, 56.8641927582877, 52.17243903023856, 52.12735564368111, 48.715300287519185, 52.01352678026472, 51.64083930424282, 50.33449459075928, 46.10877043860299, 45.404007707323345, 44.85521118981497, 47.71873753411429, 45.06313255855015, 47.488248416355674, 46.071611472538535, 50.280048506600515, 51.242742265973774, 48.85449354989188, 42.91536446980068, 43.270514692579, 46.8412321635655, 52.52490030016218, 51.38377332687378, 51.02894272123064, 46.69483014515468, 38.57501588548933, 37.993479456220356, 38.72190775190081, 39.76662152154105, 38.91686725616455, 40.30817106791905, 39.987018380846294, 39.85223027638027, 43.118008681706016, 40.57491588592529, 46.222689628601074, 44.06009408405849, 48.297282763889854, 45.77041053771973, 51.65321404593331, 49.46386793681553, 57.36052690233503, 30.91897303717477, 29.53282826287406, 55.11863504137312, 49.272292205265586, 49.61708961214338, 46.56859527315412, 48.29292971747262, 48.96988575799124, 50.45880133765084, 45.21495417186192, 45.680386202675955, 41.22010128838675, 39.53687933513096, 39.294616494859966, 39.2158899307251, 40.21842466081892, 44.78506217684065, 48.07717078072684, 51.10939243861607, 48.8658573286874, 46.63781670161656, 40.91540540967669, 41.55299990517752, 47.07036985669817, 52.6533968108041, 52.44184848240444, 51.39885786601475, 49.68487971169608, 51.17987149102347, 50.11591468538557, 52.1903132711138, 51.36148003169468, 53.45082419259207, 49.75222165243966, 49.88619334357125, 48.84452288491385, 48.247679574149, 48.2926378931318, 49.4377566065107, 47.40853173392159, 48.54453788484846, 47.45945855549404, 49.83305352074759, 47.47653375353132, 53.472460883004324, 52.96070868628365, 55.015273639133994, 52.48595912115914, 50.40732560838972, 48.191861220768516, 39.51928997039795, 24.434789044516428, 21.845247541155132, 13.704487068312508, 10.267114213534764, 16.5298148223332, 6.134588420391083, 0.478434715952192, 0.2650296986103058, 0.12767527970884526, 9.157764826502119, 43.641044752938406, 66.27670546940395, 57.33330386025565, 33.09694841929844, 49.218363761901855, 51.745069231305806, 53.92267983300345, 58.9268593106951, 27.958373410361155, 0.7918236053415707, 0.23801762663892337, 0.09021216032228299, 0.1138391907193831, 0.07827100929405008, 0.1828783375344106, 0.11926065837698323, 0.24716020748019218, 0.10808298816638333, 0.13863222247787885, 0.14839138809059346, 0.1931107813226325, 0.1317294585917677, 0.34146563708782196, 0.09683901829911129, 0.12796596411083425, 0.27631341027362005, 0.1213043922824519, 0.0773468581693513], [0.020534276263788342, 0.03967495355755091, 0.057090986520051956, 0.03869693014504654, 0.06398386415094137, 0.08317672248397555, 0.04359932869140591, 0.07139006709413868, 0.05663823742153389, 0.0448731356965644, 0.034186741802841425, 0.043953652892793925, 0.061652078559356074, 0.023146988923794458, 0.01591700322127768, 0.07372481109840529, 0.08327181238148894, 0.06022321951708623, 3.997587868145534, 28.68291940007891, 43.55146510260445, 42.002847126552034, 26.636419568743023, 13.808261019842965, 28.824219703674316, 43.35540083476475, 47.50610181263515, 24.80681470462254, 2.147233077457973, 0.14766752693269933, 0.3412454389035702, 0.6613809477005685, 7.120483083384378, 5.636210203170776, 5.878894712243762, 4.106245534760611, 9.342154383659363, 34.27056516919817, 50.73661811011178, 54.89052568163191, 49.51512827192034, 52.80527400970459, 51.2695449420384, 50.65285757609776, 48.458678994859966, 42.78916086469378, 45.69205917630877, 50.32099076679775, 47.31962258475167, 48.64416463034493, 47.40310171672276, 48.64061410086495, 46.94733463014875, 44.77483095441546, 46.93620361600603, 47.758165087018696, 49.82747411727905, 47.49497774669102, 48.585299491882324, 43.99126870291573, 47.14483717509678, 47.35102844238281, 47.51385947636196, 44.20524542672293, 41.67679943357195, 45.35083661760603, 46.90959548950195, 46.78294372558594, 47.57672330311367, 43.93599925722395, 34.213492665972026, 33.61923061098371, 34.92904942376273, 34.03830426079886, 36.6003725869315, 33.662691593170166, 36.8288745198931, 34.99984114510672, 35.86262328284127, 34.66550077710833, 36.05181578227452, 35.24493190220424, 37.24943855830601, 37.74359096799578, 47.63265630177089, 43.79105636051723, 52.63625907897949, 28.506092957087926, 27.267001594815934, 53.017746448516846, 43.67098454066685, 49.49909182957241, 44.922038963862825, 50.670922892434255, 47.33111490522112, 47.97607101712908, 45.370256832667756, 47.07889182226998, 42.41598701477051, 37.29190247399466, 33.89592177527291, 37.82236269542149, 35.46726730891636, 38.07677446092878, 44.92380033220564, 46.496598039354595, 46.062207085745676, 43.81772007261004, 39.49863992418562, 43.23237255641392, 47.36993449074881, 49.23628316606794, 48.042388098580496, 48.46448074068342, 49.08671276909964, 47.59731428963797, 49.57950333186558, 48.91184050696236, 49.19436468396868, 47.59805079868862, 43.78198201315743, 44.113921778542654, 42.67211845942906, 43.37245866230556, 44.2174186706543, 43.97335624694824, 45.12360967908587, 45.11545596803938, 49.24091066632952, 42.30025781903948, 50.39178943634033, 48.67487914221627, 48.87584883826119, 50.118707861219136, 53.133656297411235, 52.2760922568185, 36.35923535483224, 26.42402356011527, 26.107783249446324, 11.076194592884608, 11.55229297706059, 5.704320788383484, 2.4679449881826128, 3.164115837642125, 0.9187234959432057, 0.10377826022782496, 0.23725267340029987, 1.5399194828101566, 29.163819858006068, 21.65430235862732, 20.795006479535783, 24.784184421811783, 35.472895349775044, 40.91211543764387, 41.34120838982718, 42.3037805557251, 26.179500818252563, 3.2772398931639533, 0.1426417673272746, 0.08451859333685466, 0.09612770325371198, 0.03048807455758963, 0.023193246352353265, 0.005518956600488829, 0.036311194234128506, 0.05724820986922298, 0.02517330992434706, 0.02019513937245522, 0.041310775958533795, 0.07276615646800824, 0.015936509406726276, 0.04988744841622455, 0.030827481166592667, 0.014212496113032103, 0.00467612747369068, 0.004652241344696709, 0.01393205504531839, 0.04858976037108472, 0.059814076471541605, 0.027337225952318737, 0.028659928190921034, 0.06236437748053244, 0.05520145309024623, 0.0810147470661572, 0.023507693050695316, 0.017446874075436165, 0.033634193773780546, 0.06716064297194992, 0.017440791008993983, 0.02951351845903056, 0.042006138645644696, 0.07895721175840922, 0.03657080512493849, 0.09383808182818548, 5.954170627253396, 38.06895426341465, 50.22139528819493, 48.899726322719026, 37.07639019829886, 20.574291740145, 25.912146295819962, 45.68495116915022, 49.96814734595162, 31.30350719179426, 1.9870349764823914, 0.010567389877646096, 0.17178249864705972, 0.6701954432896206, 8.269571389470782, 8.843899062701635, 6.558016419410706, 6.2310168232236585, 9.869725891521998, 36.33347143445696, 54.1732040813991, 57.10549327305385, 53.303091594151084, 54.06369004930769, 54.047420842306956, 52.012449809483115, 48.79135874339512, 43.54963772637503, 49.20384202684675, 51.36502708707537, 49.519582067217144, 49.495100089481895, 49.458264214651926, 49.75600842067173, 48.04620960780552, 45.57824420928955, 47.24215711866106, 48.7482590675354, 50.160647187914165, 48.73483167375837, 48.652933256966726, 44.37648030689785, 48.316150597163606, 48.59767770767212, 49.22397790636335, 45.63163069316319, 43.69445208140782, 46.57667255401611, 49.49975538253784, 49.28568485804966, 49.40664952141898, 44.70167684555054, 35.88496174131121, 36.67779288973127, 36.17193971361433, 35.60394184929984, 36.855677195957725, 35.36250931876046, 38.02337755475725, 36.16700301851545, 37.72465712683541, 36.35015753337315, 38.10826369694301, 36.39757898875645, 39.12060233524868, 40.03048631123134, 48.77597195761544, 46.24821731022426, 54.50124590737479, 29.621987547193253, 28.128953422818864, 53.862143652779714, 46.468273707798545, 51.25470011574881, 46.396311214991975, 51.05884081976754, 48.50154938016619, 50.05423552649361, 48.320851053510395, 48.66638496943882, 42.86390263693673, 38.46061726978847, 35.0074702671596, 38.157057421548025, 36.20597199031285, 40.15310117176601, 45.73859126227242, 48.35076652254377, 48.659422874450684, 45.41366570336478, 40.80521740232195, 43.84528705051967, 48.22084910529, 49.896959577287944, 48.62452207292829, 48.52064650399344, 51.0488840511867, 50.51814242771694, 50.854233741760254, 51.60603577750069, 51.311359201158794, 48.18359981264387, 44.45973709651402, 45.042548520224436, 43.663358892713276, 45.097487926483154, 43.55912549155099, 45.11274964468819, 45.16313450677054, 45.236670766557964, 48.746761730739046, 45.165062631879536, 51.29250179018293, 50.07388850620815, 50.62669760840279, 50.680928298405235, 54.86849989209856, 53.42307308741978, 38.08255883625576, 28.358879736491613, 27.556315898895264, 9.71509199483054, 6.252249649592808, 6.478119083813258, 6.728162603718894, 4.853217269693102, 2.1134596211569647, 0.07113861558692795, 0.09310772030481271, 2.1851552597114017, 32.36470208849226, 30.246446473257883, 30.041412081037247, 32.01269939967564, 44.06573602131435, 45.84731667382376, 47.009771142687114, 49.216373103005544, 31.734653336661204, 4.194245338439941, 0.18220696784555912, 0.042525289181087694, 0.009800356929190457, 0.04218213027343154, 0.0795884325302073, 0.026450319614793574, 0.07264658502702202, 0.12117209152451583, 0.0071319976123049855, 0.023875757586210966, 0.00979583618962871, 0.04309717206550496, 0.025396636155034815, 0.11980044655501842, 0.04979131018210735, 0.020544260906587754, 0.054505537397095134, 0.01101226796994784, 0.10286601739270346, 0.09390851376312119, 0.3177455998957157, 0.0790905642456242, 0.21106358298233577, 0.15283743451748574, 0.0773482695221901, 0.21759502536484174, 0.10698622451829058, 0.15164797620049544, 0.07916744226323706, 0.2328728384205273, 0.09659551922231913, 0.10978225019893476, 0.07438142943595137, 0.11685320256011826, 0.18822721551571572, 0.1896624799285616, 7.701801078660147, 50.16798448562622, 57.67860153743199, 54.56721557889666, 38.865384578704834, 23.60057963643755, 40.347546509334016, 52.98145948137556, 56.28027309690203, 34.1138277053833, 3.069320695740836, 0.24457490763493947, 0.6642747095652989, 1.2896410269396645, 17.76684604372297, 15.919994013650076, 17.771569081715175, 14.120660713740758, 9.998067804745265, 38.85675491605486, 53.24892691203526, 58.8887414932251, 53.65475729533604, 56.2427111353193, 53.16419015611921, 53.30607237134661, 48.36487831388201, 45.639044421059744, 48.25309222085135, 54.76528787612915, 51.955999170030864, 52.63645362854004, 50.899511677878245, 49.13497495651245, 47.70444508961269, 45.72071354729788, 48.15390321186611, 50.07013995306832, 52.24482536315918, 49.965201309749055, 50.14758110046387, 44.25647449493408, 49.114842551095144, 50.54184968130929, 51.45457199641636, 48.657178606305806, 44.439993790217805, 49.12691157204764, 50.64601360048567, 48.84915733337402, 51.85658087049212, 48.22833578927176, 38.236266885484966, 37.59454863412039, 38.82303878239223, 38.124796935490195, 39.204724175589426, 37.451207297188894, 40.37879255839756, 38.74874169485909, 38.304345335279194, 38.048248631613596, 38.61241456440517, 39.40299449648176, 40.87597785677229, 42.37877941131592, 51.55351781845093, 48.335511752537315, 55.172191756112234, 31.488784381321498, 29.56296260016305, 54.056165150233674, 47.77371515546526, 53.48065628324236, 49.74295622961861, 53.23669113431658, 51.1909156526838, 52.07424361365182, 49.40445736476353, 50.49894802910941, 45.65838473183768, 39.74488408224923, 36.986483982631135, 40.88167537961687, 38.41778857367379, 42.5472662789481, 47.845253808157786, 51.62205137525286, 50.47640459878104, 48.27641384942191, 42.65373700005667, 47.31084353583199, 51.684793608529226, 52.22368894304548, 49.106525557381765, 50.64874424253191, 52.62529134750366, 52.82197053091866, 53.77331788199288, 53.43146998541695, 53.05404036385672, 48.52296372822353, 44.29199021203177, 45.961857727595735, 44.20057276317051, 46.85308231626238, 45.1361859185355, 45.1220463344029, 46.286988258361816, 44.91181468963623, 50.402715478624614, 45.495254925319124, 53.54613610676357, 52.6674599647522, 52.29596757888794, 53.35775307246617, 55.910483019692556, 55.360505308423726, 43.56711939402989, 30.433995723724365, 30.40636968612671, 13.053154247147695, 16.402721847806657, 12.84104311466217, 9.072275928088597, 8.525538682937622, 2.6123693755694797, 0.3361785736467157, 0.3991684450634888, 2.772422432899475, 39.05024835041591, 33.47822386877877, 30.697054522378103, 34.13383504322597, 46.641502720969065, 50.010409763881135, 54.513902051108225, 55.19744150979178, 38.68299436569214, 5.8957688467843195, 0.3459649213722774, 0.2564197134758745, 0.12496915991817202, 0.15929381735622883, 0.23641080143196241, 0.2430419341794082, 0.10410714615136385, 0.18124966349984917, 0.13760321055139813, 0.11541568541101047, 0.14413582001413616, 0.12566545898360865, 0.09735430457762309, 0.2133349518158606, 0.12411272658833436, 0.09212994455759015, 0.11703906687242643, 0.12671676757080214], [0.047795630126659355, 0.05591195050094809, 0.07092234612043415, 0.021959627280011773, 0.036351098878575225, 0.05890796759298869, 0.04506403134603586, 0.01547309204137751, 0.026147828703480105, 0.02370676674347903, 0.056742552002625804, 0.02676846263264971, 0.03564202639141253, 0.04595469676756433, 0.04199956703398909, 0.030946329967784028, 0.05219076267842736, 0.056895524329904995, 7.913870521954127, 37.03959948675973, 42.30873809541975, 46.69846405301775, 22.780082498277935, 19.085046121052333, 46.33978067125593, 52.600142342703684, 47.66364874158587, 13.869738680975777, 0.7792352065443993, 0.06498084922454186, 0.23075339357767785, 1.468809881380626, 5.048417355333056, 8.107208490371704, 4.129707864352635, 4.427284010819026, 8.970795750617981, 36.90105588095528, 52.53930391584124, 48.25795595986502, 47.94479717527117, 47.57328394481114, 47.92085368292672, 48.43176862171718, 48.72315870012556, 46.21894802365984, 44.23635251181466, 48.285338810511995, 49.91218308040074, 48.23440504074097, 49.00626652581351, 46.090312549046104, 44.926259994506836, 46.672116483960835, 50.4489175251552, 46.113509110042024, 46.95842742919922, 48.60686322620937, 47.91953699929373, 47.07907942363194, 44.86992400033133, 47.58765629359654, 47.460896832602366, 45.518958704812185, 44.3583733013698, 45.4188803264073, 48.940800598689485, 47.108720438820974, 48.803247111184255, 43.31076560701643, 33.853711468832834, 34.54578678948538, 33.21262550354004, 34.96524953842163, 34.7095627784729, 35.09241894313267, 40.67055436543056, 39.10747718811035, 41.50520672116961, 41.462176527295796, 44.1394807270595, 41.47674342564174, 43.127812589917866, 42.49037095478603, 47.5867634500776, 44.06505509785244, 53.32541268212454, 28.888924803052628, 25.540205751146587, 49.128016335623606, 42.52142940248762, 50.86076157433646, 46.34701722008841, 50.09261737551008, 46.44258969170706, 49.031380789620535, 47.8487730707441, 47.22794805254255, 48.53652661187308, 44.34487295150757, 34.93609837123326, 35.1919310433524, 33.86500229154314, 36.90071889332363, 43.2874960899353, 46.43211875643049, 46.45542648860386, 46.16016278948103, 43.140055315835134, 45.02464648655483, 46.5945155279977, 49.351390498025076, 45.69597101211548, 44.35241869517735, 45.689571721213206, 48.245817456926616, 46.95957735606602, 47.60753161566598, 43.47750847680228, 45.299982752118794, 45.0992180279323, 48.11290536608015, 48.491846220833914, 50.06781578063965, 45.250358717782156, 44.28033808299473, 44.51691034861973, 46.65270669119698, 42.266020570482524, 45.75182063238961, 47.9035005569458, 47.74065910066877, 49.391443388802664, 48.930743081229075, 51.87525762830462, 44.76717403956822, 31.361816474369594, 44.12047045571463, 33.58648722512381, 15.374520472117833, 9.157710977963038, 8.261633941105433, 5.5780112232480725, 2.3323728229318346, 0.7179368415049144, 0.2902393915823528, 0.0242886597157589, 0.5764766750591142, 15.416100229535784, 44.0449435370309, 18.983486039297922, 23.988077197756084, 32.9518700327192, 27.210323401859828, 45.52335344042097, 35.999370779309956, 32.48639283861433, 7.465703896113804, 0.09081869599010263, 0.05346288013138941, 0.044160616251506975, 0.08333946910819837, 0.047995037997939756, 0.024888817154403244, 0.0416911626899881, 0.03853933699429035, 0.05806384288838931, 0.02763377289686884, 0.02689731982536614, 0.022044810566252897, 0.01826075817059193, 0.10029954689421824, 0.007813891379295715, 0.01925543283245393, 0.03705157771972673, 0.029294317721256187, 0.07320190487163407, 0.019272168898688893, 0.060836805163749626, 0.056848366146108935, 0.00811269784545792, 0.0552182366539325, 0.037935467969094, 0.035489763133227825, 0.06304094474762678, 0.008679793665318616, 0.062086415610143116, 0.026132514168109213, 0.05300636516351785, 0.0453199917184455, 0.010386459363092269, 0.03753966152934091, 0.07229383502687727, 0.12144171419952597, 10.022907614707947, 44.80021619796753, 48.943836961473735, 51.19325719560896, 28.455164398465836, 19.433529547282628, 46.63719136374337, 56.626835346221924, 53.060234682900564, 17.808507442474365, 0.6410571411252022, 0.017492093345416442, 0.5446231471640723, 2.4680533366543904, 8.927061183112007, 8.49485456943512, 10.97374861580985, 8.500739693641663, 9.928453803062439, 38.75461292266846, 51.98140178407942, 49.85535723822457, 49.402602195739746, 49.0509295463562, 49.31710808617728, 48.51940972464425, 48.74978767122541, 47.827688762119834, 45.529172556740896, 48.720077174050466, 50.84577430997576, 50.18777642931257, 50.250258105141775, 46.83570487158639, 45.30207763399397, 48.07310261045183, 51.36398138318743, 48.06046731131417, 49.208535534994944, 50.431098869868684, 50.26671838760376, 45.96937567847115, 45.953669275556294, 49.88993494851248, 48.566108567374094, 47.330159527914866, 45.305093152182444, 47.34953110558646, 49.14939594268799, 47.99928147452218, 51.63970674787249, 45.329026222229004, 35.75101089477539, 36.508975982666016, 35.03941808428083, 37.47400781086513, 36.74427325384957, 37.30084480558123, 42.986868381500244, 40.66749020985195, 42.99833985737392, 43.800252301352366, 44.672956466674805, 43.26807240077427, 44.15645170211792, 43.48805931636265, 49.17604228428432, 46.07479722159249, 54.75918735776629, 29.515933718000138, 26.68091756956918, 50.45664739608765, 43.97409275599888, 53.153851236615864, 48.69528252737862, 50.02468483788626, 47.803036553519114, 49.736056668417795, 49.768803528376985, 49.37486498696463, 49.28830432891846, 46.02479451043265, 36.60276276724679, 36.85713284356253, 36.0180857522147, 39.21569538116455, 44.703782149723594, 48.49335397992815, 49.03051573889596, 48.30276141847883, 45.88827977861677, 46.697154317583355, 49.8073729787554, 49.7129921231951, 46.752583571842735, 44.99286195210048, 47.17966849463326, 50.25526775632586, 48.20776564734322, 47.970734800611226, 45.02946853637695, 44.36186129706246, 44.92207717895508, 49.89112309047154, 48.82768392562866, 50.811478001730784, 46.87890182222639, 45.398751395089285, 46.02984932490757, 46.293022768838064, 44.71918978009905, 46.86658614022391, 49.932391916002544, 49.26492364065987, 50.44996322904314, 51.05390065056937, 52.45661340441023, 45.55904286248343, 35.567884172712056, 46.20419004985264, 34.37226595197405, 15.567138433456421, 6.122347431523459, 7.976591910634722, 6.867217770644596, 5.51981919152396, 1.7063768250601632, 0.4591316431760788, 0.10598820807146174, 0.5773165385637964, 18.20385299410139, 41.598924023764475, 21.717253037861415, 23.599744115556987, 37.96305676868984, 33.16119146347046, 51.13425309317452, 43.24418101991926, 40.24404614312308, 10.320128968783788, 0.15127623400517873, 0.021888357354328036, 0.010641560540534556, 0.05031714428748403, 0.04224401945248246, 0.058493504832897864, 0.04008881581415023, 0.06799997043396745, 0.038239292201719115, 0.020762247066678743, 0.030702976776020866, 0.035908079972224574, 0.09778883840356555, 0.05147480645350047, 0.02243632187933794, 0.05661885846140129, 0.02166141283565334, 0.006753037500727389, 0.14098652186138289, 0.09369707546596016, 0.18365137891045638, 0.09683057053812913, 0.06999272600348506, 0.2123416851141623, 0.10171789542904922, 0.1064451267676694, 0.12179730726139885, 0.10127283073961735, 0.1590974900339331, 0.09792740203972373, 0.15446940623223782, 0.1173188675727163, 0.07671918613570076, 0.0825588959934456, 0.11948454779173646, 0.23735494219831058, 13.924447928156171, 54.04930033002581, 56.289521149226594, 59.23820114135742, 33.87674127306257, 29.514415536608013, 56.038194383893696, 58.91000298091343, 56.493954522269114, 20.749297755105154, 0.8623558548944337, 0.07163229731044599, 0.5317947641015053, 2.6355776616505215, 15.105745043073382, 15.86590576171875, 16.343686478478567, 9.657366360936846, 10.314214314733233, 38.759226526532856, 52.64403063910348, 50.76294483457293, 48.23371022088187, 50.750910554613384, 49.2742064339774, 49.97888926097325, 49.941355092184885, 48.72065734863281, 48.26098884854998, 51.18239368711199, 52.33018050874983, 51.21254539489746, 52.12235294069563, 48.26115213121687, 45.442323548453196, 49.65914011001587, 53.77859156472342, 50.4088750566755, 50.463762351444785, 52.859070437295095, 52.09522022519793, 47.422657421657014, 46.26985052653721, 51.93817704064505, 51.25157342638288, 49.717584882463726, 48.083076749529155, 50.45298222133091, 51.35338538033621, 49.35712971006121, 54.72534268242972, 48.56688329151699, 37.19607291902815, 37.74645709991455, 36.04321738651821, 39.677034923008506, 38.541244166237966, 39.31017351150513, 46.45413064956665, 42.574051584516255, 46.34301505770002, 46.051329680851524, 48.834468841552734, 45.56163454055786, 46.86994906834194, 46.07767030170986, 50.48936298915318, 48.69240249906267, 54.5406665120806, 32.49483142580305, 28.490926776613506, 50.4351600919451, 43.69141224452427, 54.38637481416975, 49.639490604400635, 51.48355640683855, 48.773387227739605, 51.87111302784511, 51.96907915387835, 50.71520028795515, 52.20670059749058, 48.40132508959089, 38.946018423352925, 38.6200019972665, 37.22562708173479, 41.857431752341135, 46.90662860870361, 49.76899112973894, 50.94397667476109, 51.73122147151402, 46.729168142591206, 48.98662049429757, 51.60471909386771, 52.02873638698033, 47.437717642102925, 45.55500595910208, 45.95902286257063, 50.60979611533028, 49.227761200496126, 48.139791420527864, 45.073308195386616, 45.82881014687674, 46.3564806665693, 50.65223918642317, 50.183996609279085, 52.05653265544346, 47.219280174800325, 46.33617803028652, 46.47571175439017, 48.14959880283901, 47.0574357850211, 48.16568040847778, 49.70489399773734, 49.55892971583775, 51.49309628350394, 54.73976019450596, 55.68131753376552, 50.88885661533901, 37.12331485748291, 46.173433848789756, 33.779080867767334, 17.552679981504166, 12.820360933031354, 13.561917849949428, 11.15687620639801, 9.424669453075953, 2.7558201466287886, 0.8543035984039307, 0.14644192984061583, 0.9291468794856752, 21.172693184443883, 55.85899339403425, 27.710960217884608, 33.38140766961234, 40.16144248417446, 38.91514410291399, 57.16000883919852, 50.14637906210763, 47.066711630140034, 13.92429072516305, 0.3115673485611166, 0.1003502673868622, 0.19555034541657992, 0.09923174990607159, 0.20229376213891165, 0.12520480155944824, 0.09223749235804592, 0.18435200702931198, 0.10492351198835032, 0.04544076755908983, 0.1318092950220619, 0.1418799353497369, 0.17971256455140455, 0.12802225537598133, 0.10304511671087571, 0.17973138711282186, 0.11493545903691224, 0.056921420618891716], [0.05807572403656585, 0.05751840251364878, 0.03566341042252524, 0.03265458258933254, 0.05739321280270815, 0.028455275243946483, 0.041211027918117385, 0.05860655555235488, 0.020734963173578893, 0.040757423865475824, 0.023415349523669908, 0.007404911182155567, 0.02076483398143734, 0.04972930904477835, 0.05226757623521345, 0.06442479656210967, 0.030860939728362218, 0.22415877958493574, 15.781261069434029, 36.123708793095176, 41.59346968787057, 33.62620312826974, 30.594217709132604, 37.889520508902415, 53.58467081614903, 58.82713876451765, 31.20895610536848, 12.720755900655474, 0.04386890386896474, 0.11614255926438741, 0.07446081803313323, 1.3853029566151756, 6.590925693511963, 5.964569474969592, 3.7018595082419257, 1.8725356119019645, 8.971853613853455, 37.22404636655535, 49.846658093588694, 51.02169227600098, 49.753395898001536, 51.69927018029349, 51.19842318126133, 49.330500738961355, 48.15578269958496, 42.570535796029226, 41.49051822934832, 46.73542846952166, 47.3320563861302, 46.7554566519601, 45.84922048023769, 44.90041616984776, 46.3202805519104, 46.10181876591274, 45.67511599404471, 43.05537067140852, 43.79640647343227, 44.02166359765189, 48.202356474740164, 47.88400738579886, 45.572664805821006, 44.213857718876426, 50.215423311506, 48.176179136548726, 47.36060306004116, 46.85970047542027, 47.22116661071777, 46.64507409504482, 47.4873104095459, 39.89048705782209, 34.36876405988421, 33.286582129342214, 34.925610065460205, 33.720820222582134, 38.55893427985055, 42.694842542920796, 46.50798266274588, 46.2297420501709, 46.64838491167341, 48.164103167397634, 49.09776040485927, 45.92847858156477, 50.92157915660313, 47.459875447409495, 50.07663304465157, 45.99726922171456, 52.16661296572004, 25.4088830607278, 25.188463619777135, 49.18210111345564, 38.94000823157174, 46.10464320863996, 41.75446292332241, 45.51474462236677, 42.624113355364116, 44.0759950365339, 41.54201132910592, 49.289537634168354, 46.67807109015328, 48.76090478897095, 38.28974717003958, 34.857000078473774, 34.86918027060372, 36.26197794505528, 39.77762746810913, 45.52508354187012, 45.614656244005474, 45.10584660938808, 44.017762184143066, 46.7956554549081, 49.06193201882498, 45.8064786366054, 44.070026533944265, 46.06500026157924, 43.66450187138149, 44.26016746248518, 42.93847417831421, 46.11548934664045, 45.65969794137137, 44.37901292528425, 47.219064780644004, 47.993097577776226, 47.80532251085554, 48.92009149278913, 48.279130595070974, 47.801441941942485, 45.40700238091605, 42.76060029438564, 46.03045034408569, 47.07861042022705, 45.74886417388916, 48.3323781149728, 47.185126304626465, 48.854792322431294, 49.71504184177944, 51.2211993762425, 56.691596031188965, 45.84877232142857, 38.66102416174752, 25.09054265703474, 12.014112813132149, 6.2657986368451795, 4.9212201578276495, 5.547730105263846, 1.7266968318394251, 0.3931617816644055, 1.9702407462256295, 0.08470671038542475, 8.600299562726702, 31.067984104156494, 32.18521622249058, 49.476065499441965, 29.881777218409947, 26.713485513414653, 38.70559685570853, 38.43801130567278, 40.52552809034075, 14.449972323008947, 0.10876387770154647, 0.07139603141695261, 0.03697831629376326, 0.057594608781593185, 0.0556101754440793, 0.021791835747925297, 0.05895329373223441, 0.03953190819759454, 0.05041117567036833, 0.015783545561134815, 0.06281123350241355, 0.06916256554956947, 0.0448577227736158, 0.0795104145737631, 0.026156325658251132, 0.04112049438325422, 0.03936120914295316, 0.00922297451844705, 0.05642107228881546, 0.026047278295404146, 0.03509188037631767, 0.025398117057713013, 0.02086953363115234, 0.047435253392905, 0.10397863161883183, 0.010934959082598132, 0.02335500910079905, 0.04518734830032502, 0.07124277749764067, 0.07996577942477805, 0.01069557956153793, 0.011669254412741532, 0.007973050249607434, 0.02305362420156598, 0.02470033708959818, 0.3195561213152749, 20.111753634044103, 46.20215422766549, 47.895339897700715, 40.373564038957866, 33.972279003688264, 38.873402799878804, 60.59765788487026, 64.77081544058663, 41.47378696714129, 13.403148906571523, 0.10075841298592941, 0.11015862678842885, 0.27868280027593884, 5.0979558399745395, 7.023056745529175, 9.854037727628436, 8.875606298446655, 4.485903791018894, 10.96377968788147, 39.73654276984078, 51.788029943193706, 51.65509353365217, 50.77944333212716, 52.47720786503383, 51.41655492782593, 49.637868200029644, 48.91061762401036, 43.92717504501343, 44.35787303107125, 47.702516964503694, 48.51080090659005, 47.674408027103965, 47.68209968294416, 45.34690393720354, 45.69224330357143, 47.75963115692139, 48.392591203962056, 45.68152570724487, 46.18627411978585, 46.49254723957607, 49.71732432501656, 47.596383231026785, 45.12536409923008, 44.84528916222708, 51.650243691035676, 50.07383292061942, 48.211437770298545, 47.958505971091135, 49.56718070166451, 48.110424859183176, 49.69837311335972, 41.77781234468733, 36.401313645499094, 34.86071389062064, 36.64853402546474, 36.474974972861155, 39.2934387751988, 44.11198670523507, 48.87065158571516, 47.39314842224121, 49.37652908052717, 49.62840822764805, 51.66864252090454, 48.195668833596365, 51.76355143955776, 48.35218048095703, 52.400444167000906, 47.28542355128697, 53.659332684108186, 26.269111735480173, 25.579509973526, 47.412196908678325, 40.6524612562997, 46.12709978648594, 43.70579154150826, 46.6406307220459, 42.51845209939139, 44.80619512285505, 43.73456055777413, 50.52847439902169, 49.41984067644392, 50.20145395823887, 40.48753534044538, 36.37896129063198, 35.78699214117867, 37.944873332977295, 40.55121210643223, 48.066199575151714, 48.32003811427525, 48.43448536736624, 46.090983050210134, 49.18745470046997, 50.76775298799787, 46.92814370564052, 44.065336499895366, 45.07957547051566, 44.98851237978254, 44.482113770076204, 42.12797376087734, 45.934742382594514, 45.71845885685512, 45.67715529033116, 48.03072554724557, 50.00919035502842, 49.715715817042756, 51.353798798152376, 50.43588617869786, 49.55531317847115, 46.863059929439, 46.38007327488491, 47.83986895424979, 46.94974912915911, 47.35800095966884, 51.250562463487896, 49.83890390396118, 51.54845952987671, 50.89957421166556, 52.76582213810512, 55.373418535505024, 48.749179703848704, 39.43191984721592, 26.09508194242205, 11.36098735673087, 6.852903178759983, 7.75057395866939, 7.141542639051165, 3.8135092428752353, 1.4418955998761314, 2.678951791354588, 0.06342065294406243, 10.253025003841945, 36.89641448429653, 28.220018250601633, 44.83358144760132, 32.885684967041016, 32.12324871335711, 43.64071471350533, 42.79783916473389, 47.29189232417515, 18.627849442618235, 0.342485855200461, 0.04143995206270899, 0.018746833516550914, 0.08662655736718859, 0.041864297685346434, 0.07076586237443344, 0.049874030386230776, 0.05990954634866544, 0.07277047873607703, 0.07660431694239378, 0.056730206057961495, 0.06816178067986454, 0.010197505171942924, 0.039577149519962926, 0.03882578055241278, 0.007250580936670303, 0.07644427088754517, 0.04259195524666991, 0.16082859571490968, 0.14241251748587402, 0.12066456090126719, 0.16663032796766075, 0.10077564777540308, 0.11114612594246864, 0.2686164618602821, 0.11470521853438445, 0.08881440532526799, 0.14116821996867657, 0.1287044680544308, 0.16706643599484647, 0.08890139351465873, 0.12459387577005795, 0.15976621343621186, 0.1309974007308483, 0.10598817414471082, 0.45071932886328014, 29.289999144417898, 55.22243765422276, 54.25915329796927, 44.36663123539516, 42.7212734903608, 50.3533867427281, 60.84174115317208, 62.26695564814976, 41.17216566630772, 17.35690232685634, 0.183081273787788, 0.5329692267945835, 0.21500022602932795, 4.09683506829398, 10.548289571489606, 14.011397685323443, 11.522755316325597, 8.066870723451887, 13.307539088385445, 40.53453295571463, 54.862739835466655, 51.77784388405936, 52.79381990432739, 53.52871349879673, 53.15791940689087, 50.882241930280415, 50.493201868874685, 44.06673656191145, 48.40189484187535, 48.42987176350185, 49.798027651650564, 48.84594031742641, 48.1241649218968, 45.40210737500872, 48.92392689841134, 49.8295134135655, 50.15768378121512, 46.74964100973946, 47.26965461458479, 48.34630230494908, 50.733265604291645, 49.79640177318028, 45.00709881101336, 45.467086928231375, 53.23821973800659, 52.47285829271589, 50.5442259652274, 50.20663731438773, 50.827538762773784, 49.99990061351231, 50.93476683752877, 44.50783600125994, 37.67308759689331, 37.53149025780814, 39.22608641215733, 37.698910576956614, 41.6684615952628, 46.33466679709298, 51.428002085004536, 49.98910311290196, 49.39915588923863, 52.725758825029644, 53.69523402622768, 50.65289231709072, 54.18806627818516, 51.79302222388131, 53.071476868220735, 49.891369751521516, 55.438161849975586, 28.317180122647965, 27.791630540575298, 45.82768453870501, 40.75907441547939, 45.527894088200156, 43.12522438594273, 46.50977529798235, 43.27910614013672, 44.701572622571675, 43.734960079193115, 51.29313407625471, 50.775333472660606, 51.475989818573, 42.36343084062849, 38.664665017809185, 38.19262525013515, 39.636422702244346, 43.31668199811663, 50.59030989238194, 49.447157519204275, 49.03996181488037, 48.02863761356899, 49.87725796018328, 53.9584595816476, 47.253058842250276, 43.536161695207866, 44.56616265433175, 45.74843338557652, 45.610806941986084, 42.65653017589024, 46.614668778010774, 46.06608765465872, 46.26488951274327, 50.43326670782906, 52.082004751477925, 52.069897515433176, 53.853920459747314, 53.063469069344656, 50.52563953399658, 49.39367723464966, 47.093715803963796, 48.47212723323277, 47.90216302871704, 48.2526718548366, 50.380404812949045, 50.6957105909075, 53.182825224740164, 53.21175752367292, 54.97698559079851, 57.4015907560076, 49.98311029161726, 42.98760141645159, 27.22001440184457, 13.959294881139483, 16.659614120210918, 12.21472988809858, 10.604384115764073, 4.95328392301287, 1.8141197179044997, 3.036971620150975, 0.2038095143756696, 12.256967987333026, 44.94097627912249, 43.858287130083355, 59.17777960641043, 38.01139538628714, 36.5575612613133, 49.49529463904244, 49.307526520320344, 55.60697875704084, 25.056463479995728, 0.7536854318210057, 0.17656713404825755, 0.11556851863861084, 0.2489914106471198, 0.1884405469255788, 0.12993678264319897, 0.12021982190864426, 0.12683536192136152, 0.17875349601464613, 0.1557438171335629, 0.10709102425192084, 0.13800471329263278, 0.12333213990288121, 0.14755244739353657, 0.12068631473396506, 0.10980881484491484, 0.14562790494944367, 0.16751686111092567], [0.015622239127489073, 0.017316446074151566, 0.014657842394496714, 0.05770233300115381, 0.04522845734442983, 0.05002876011920827, 0.06068908130483968, 0.031995426530816724, 0.034608166332223585, 0.03918740918327655, 0.07582351312573467, 0.02435167526294078, 0.015650771525023238, 0.03958744628887091, 0.04873592359945178, 0.027216336457058787, 0.051875084439026456, 1.050379482763154, 18.467313051223755, 37.18819713592529, 39.44315161023821, 22.737488303865703, 21.589496510369436, 25.780637741088867, 39.88867705208914, 25.809107984815324, 29.167648315429688, 6.855191307408469, 0.02419581407281969, 0.17051988068435872, 4.268470338412693, 10.712528484208242, 7.337308134351458, 7.962794525282724, 10.613859721592494, 9.68419075012207, 8.67854756968362, 40.153174127851216, 48.48126064028059, 52.06855303900582, 50.76479652949742, 52.58335896900722, 48.43296023777553, 51.12865284511021, 47.8573888369969, 49.50367764064244, 45.05060148239136, 43.733897004808696, 44.69350576400757, 45.32153606414795, 45.04251725333077, 45.46722936630249, 45.86161259242466, 47.58557530811855, 45.57906757082258, 40.70845678874424, 36.81641639981951, 41.44790840148926, 45.75282464708601, 47.26193516595023, 44.773920740400044, 43.98156901768276, 45.9441363470895, 45.882057666778564, 49.566617897578645, 45.84504113878523, 48.347757952553884, 48.706073079790386, 48.03934826169695, 38.364905834198, 33.617774963378906, 33.83839763913836, 33.73514740807669, 35.66929660524641, 45.57900851113455, 46.880732672555105, 48.0791197504316, 47.840219838278635, 49.12941639763968, 48.471960476466585, 50.239651679992676, 47.619795186179026, 48.77537441253662, 46.62508412769863, 53.355762413569856, 43.23193481990269, 49.984461716243196, 23.802461283547537, 20.22319058009556, 49.450503076825825, 37.66137988226754, 43.780623640332905, 39.012842723301475, 42.429205962589805, 40.81600448063442, 41.43672180175781, 38.7993106842041, 43.87498017719814, 45.59221008845738, 49.097795145852224, 42.87311942236764, 36.40022625241961, 33.796559061322895, 35.668890135628835, 35.90992661884853, 45.38219036374773, 45.804359436035156, 46.75424766540527, 44.33164358139038, 47.61532054628645, 43.232838085719514, 43.56661912373134, 42.61000851222447, 40.91936935697283, 39.44550704956055, 43.837390422821045, 41.774508476257324, 44.02051714488438, 43.62824617113386, 48.32116372244698, 45.81144659859793, 46.59869139535086, 44.79584578105381, 46.121864318847656, 46.231426988329204, 47.882673331669395, 46.15754679271153, 46.21568931852068, 44.0220422744751, 45.99634163720267, 44.75355557032994, 47.977755955287385, 47.28328003202166, 46.01863145828247, 46.87418746948242, 51.3566267149789, 54.14560236249651, 56.11792843682425, 44.07005432673863, 24.837683813912527, 13.00347810132163, 9.606589794158936, 9.24268570968083, 6.657648810318538, 0.585565407361303, 5.947565061705453, 3.1891310896192278, 0.07595124734299523, 3.7327707409858704, 27.676208802631923, 42.693664823259624, 27.646515675953456, 19.681123392922537, 23.461732046944753, 38.65874515260969, 39.93398972920009, 45.284109592437744, 27.611460277012416, 1.637696053300585, 0.013513289525040557, 0.011775685174922858, 0.07982911568667207, 0.03615014394745231, 0.027692700270563364, 0.054391329775431325, 0.05642558454668947, 0.015658209965165173, 0.05812127409236772, 0.027624638119180287, 0.024707602503310357, 0.017241617232295017, 0.039698688712503226, 0.04612884956545063, 0.024071767693385482, 0.01408552100682365, 0.026302253095699207, 0.026844860586736883, 0.02064253482967615, 0.047773706660206826, 0.02008960342832974, 0.08459027377622468, 0.02566373976878822, 0.0513097256688135, 0.038230515351252894, 0.018425905112443224, 0.07242222063775573, 0.04918175842612982, 0.0353395151240485, 0.0772433408669063, 0.022770844732544253, 0.03463715674089534, 0.07054839868630682, 0.0576493733429483, 1.3640854379960468, 25.97714148248945, 45.902193546295166, 44.63142360959734, 26.537685666765483, 27.53936403138297, 30.422989777156285, 45.708394391196116, 37.41214452471052, 31.182031835828507, 8.169736198016576, 0.018496255623176694, 0.3671392580228192, 2.8443553958620345, 6.573706320353916, 9.422964538846697, 7.655348896980286, 8.631745372499738, 3.4401942576680864, 12.452736956732613, 40.663147585732595, 49.92507198878697, 51.45311287471226, 51.637465953826904, 54.28829404285976, 50.856936591012136, 51.172579356602256, 47.62469366618565, 48.08408423832485, 45.3584622655596, 45.00024093900408, 46.121812207358225, 47.367349760872976, 45.7236977985927, 46.768286500658306, 47.411588941301616, 50.386474064418245, 47.559905188424246, 43.147927624838694, 39.190143380846294, 44.225426469530376, 48.07056304386684, 49.38194867542812, 45.60568264552525, 43.77607257025582, 46.29896347863333, 46.89025865282331, 50.60442515781948, 45.97738347734724, 47.678483145577566, 50.443021978650776, 50.09392016274588, 40.19604798725673, 34.84860665457589, 35.870089122227256, 34.724890504564556, 37.48054953983852, 47.17530155181885, 49.21895783288138, 49.93495927538191, 49.48276356288365, 50.77732413155692, 48.43271705082485, 50.84784139905657, 48.96923957552229, 51.07044083731515, 48.94483402797154, 54.13898420333862, 44.44580943243844, 50.14723021643502, 24.31686248098101, 23.17442750930786, 49.00874008451189, 37.36080775942121, 44.66298232759748, 38.88397795813424, 44.348548548562185, 40.42535243715559, 42.24597154344831, 38.16186557497297, 44.05569587435041, 47.71003491537911, 49.24161243438721, 44.70072841644287, 37.15932042258126, 35.51610619681222, 36.539065156664165, 37.458909375326975, 46.078420707157676, 46.775814873831614, 50.22459840774536, 46.69076197487967, 48.96479620252337, 45.22349350793021, 45.03556558064052, 41.535844802856445, 42.84527104241507, 40.9309207371303, 44.49845593316214, 43.187845025743755, 44.80281482424055, 44.420948777879985, 48.63463865007673, 47.082411084856304, 48.45413139888218, 46.603169509342735, 49.14983367919922, 47.8679153578622, 49.02914694377354, 47.09377833775112, 48.644581522260395, 45.12230689185006, 46.599302836826865, 44.73169306346348, 49.18350117547171, 48.357773780822754, 49.579954964774, 50.01522486550467, 53.6869170325143, 52.872945989881245, 55.744080611637656, 46.23825706754412, 29.30139419010707, 14.739875486918859, 11.451239245278494, 6.780678825719016, 7.294229303087507, 3.9974628005708968, 5.233978118215289, 4.015390021460397, 0.12855643885476248, 4.947049651827131, 28.993001869746617, 43.172583307538716, 35.02546262741089, 27.844190188816615, 28.354493686131068, 44.55800894328526, 44.90398754392351, 52.13869162968227, 32.30469397136143, 2.288189228091921, 0.06068163099033492, 0.04035652502040778, 0.02559106357927833, 0.051195063428687196, 0.048655883608652015, 0.0044062198139727116, 0.06201725932104247, 0.02836596646479198, 0.012159634215225066, 0.0175067480054817, 0.008489480707794428, 0.05074947287461587, 0.03763581333415849, 0.03639436227136424, 0.05475250718050769, 0.06343481396990162, 0.0052239316948024285, 0.12826312173690113, 0.10852051433175802, 0.13228524662554264, 0.24337962748748915, 0.14875295226063046, 0.1291911540819066, 0.17073132576686995, 0.1014123714662024, 0.1156196937497173, 0.12693148319210323, 0.18932762289685862, 0.15098303902362073, 0.11569753528705665, 0.12791093492082187, 0.17039602090205463, 0.12785115598567895, 0.1583552270063332, 2.374351667506354, 34.53297431128365, 56.07655886241368, 51.894455501011436, 33.73190259933472, 33.873399189540315, 35.20241934912545, 47.16286080224173, 33.98169033867972, 38.903297424316406, 9.278020773615156, 0.25105195865035057, 0.466598133955683, 6.590704653944288, 15.289191382271902, 16.331728628703527, 17.040854828698293, 20.221403156008037, 19.278638567243302, 15.610285009656634, 41.90378318514143, 49.081838607788086, 53.131874084472656, 53.42772143227713, 56.21197230475289, 51.64816617965698, 52.10418340138027, 49.49941144670759, 49.25288241250174, 46.16238273893084, 46.375122683388845, 45.33055830001831, 46.17805092675345, 46.93533509118216, 48.84577703475952, 49.18663133893694, 51.15311745234898, 49.590325151171, 44.45456416266305, 40.44262218475342, 45.12737907682146, 50.2952789579119, 49.67488472802298, 47.27444192341396, 45.30732699802944, 46.99044820240566, 48.613373688289094, 52.32178708485195, 46.35415996823992, 48.78213153566633, 52.82215813228062, 52.73888744626726, 42.87772955213274, 36.89920766013009, 36.93793344497681, 37.41625091007778, 39.097558634621755, 49.58120216642107, 51.270121642521445, 52.18173919405256, 52.94709369114467, 51.68213244846889, 50.60412291118077, 53.52960286821638, 51.26142597198486, 51.3055921963283, 50.48282126017979, 55.73626388822283, 44.61999729701451, 49.79271922792707, 26.558676174708776, 26.05165570122855, 52.62585415158953, 40.74403156552996, 48.394759041922434, 42.41036939620972, 46.95054817199707, 44.92825065340315, 44.76066357748849, 39.02324765069144, 44.40558283669608, 48.07862295423235, 52.59608806882586, 46.999539920261924, 37.985124247414724, 37.62842457635062, 38.22613293784005, 39.099855014256065, 49.538766043526785, 48.19184037617275, 51.34480088097708, 47.41879769733974, 51.29398175648281, 46.30305249350411, 45.58530010495867, 44.73397902079991, 43.80993114198957, 42.169593470437185, 43.9641672543117, 41.606685161590576, 45.256900446755544, 45.33621065957205, 52.14463581357683, 49.563960211617605, 50.714561053684776, 49.25831242970058, 51.83593429837908, 50.51498794555664, 51.539485931396484, 50.758706433432444, 50.07714026314871, 46.11066729681832, 46.97754887172154, 44.59659923825945, 48.81671619415283, 48.938643183027, 49.5038617679051, 52.332400458199636, 55.640114716121126, 55.82210193361555, 56.99113982064383, 49.549125807625906, 31.185926301138743, 17.95425980431693, 15.084097930363246, 16.748658759253367, 15.185492992401123, 5.788985022476741, 9.569254517555237, 4.418823276247297, 0.18849679747862474, 5.558733011995043, 37.4415145601545, 53.45235627038138, 37.762340681893484, 27.894755704062327, 31.985278333936417, 50.19255331584385, 52.59112358093262, 59.3339056287493, 39.02438368116106, 3.3529131582805087, 0.15203396763120378, 0.09362233483365603, 0.19259297767920153, 0.21886506650064672, 0.10577974175768239, 0.10514432085411889, 0.11462934474859919, 0.14769162849656173, 0.16629709942000254, 0.10325932343091283, 0.10561717155256442, 0.23709039496523993, 0.17303796485066414, 0.1037394819515092, 0.11622304708829947, 0.16117099805602006, 0.11258171605212347], [0.07604419306984969, 0.08056821674108505, 0.03223923094836729, 0.04360112341653023, 0.027979484792532663, 0.06477677303233317, 0.07810796411441905, 0.050453533218907456, 0.03570271795615554, 0.04667183364342366, 0.03728685973744307, 0.03887880467144506, 0.023501279198431542, 0.07570303244782345, 0.08193752076476812, 0.0388841549200671, 0.015450408615704094, 3.2978328338691165, 21.794893945966447, 36.73935740334647, 49.78107404708862, 37.35347046170916, 29.865313461848668, 35.21277911322457, 34.76627050127302, 25.024260316576274, 37.085502760750906, 2.18841135927609, 0.11843124431158815, 0.9795918869120734, 17.5195666040693, 7.567156280790057, 4.8992781809398105, 6.397817884172712, 5.4001725145748685, 1.6695692858525684, 11.664138998304095, 43.678339208875386, 47.65191323416573, 50.51285137448992, 51.03054428100586, 49.136100564684185, 48.016231604984824, 50.65939583097185, 50.530169759477886, 49.62512172971453, 49.46761301585606, 49.08344711576189, 44.78743846075875, 45.34274544034685, 46.78044237409319, 45.71727071489607, 46.035307134900776, 45.75696924754551, 42.91705288205828, 40.146184240068706, 35.00117172513689, 36.075269426618306, 46.27850103378296, 47.03612565994263, 47.68540007727486, 44.940733092171804, 47.41908604758126, 44.56477301461356, 44.52927119391305, 42.721078940800254, 44.28113712583269, 46.85674054282052, 44.13320302963257, 33.34711136136736, 32.17435271399361, 31.92100749697004, 36.14223616463797, 40.202447278159006, 47.765273094177246, 40.529064723423545, 43.44515419006348, 45.93217502321516, 43.84009674617222, 43.473023414611816, 43.87459455217634, 44.350410665784565, 45.90829406465803, 42.58951480048043, 44.46458346503121, 39.33898769106184, 49.70865992137364, 23.029208421707153, 22.52900413104466, 46.995666299547466, 42.13122204371861, 45.57018082482474, 39.83771896362305, 45.084967272622244, 40.695237840924946, 43.2567537852696, 40.41151509966169, 41.753747258867534, 44.25788497924805, 49.74540894372122, 45.524197646549766, 38.24030031476702, 33.100696972438264, 35.666670186179026, 34.30567441667829, 38.34383542197091, 44.61791978563581, 46.90602758952549, 46.13613591875349, 46.36823354448591, 44.96069526672363, 42.47010653359549, 40.63790478025164, 43.576892035348074, 45.3322571345738, 47.078690324510845, 46.69164439610073, 43.7314373425075, 45.526289054325645, 47.7829076222011, 45.84891128540039, 43.590441022600444, 39.641439301627024, 41.01565749304635, 43.1861183983939, 46.359576089041575, 45.24583196640015, 46.74103913988386, 46.43198674065726, 48.586192335401265, 47.222684792109895, 45.697572571890696, 45.78761427743094, 49.12437547956194, 45.61949566432408, 46.12041561944144, 41.29574285234724, 45.63549389157976, 46.29880714416504, 38.12738861356463, 13.958721654755728, 9.381211076463972, 4.933825058596475, 4.256892902510507, 5.128029380525861, 11.806187970297676, 2.2343917148453847, 0.08318039335842643, 0.8448711474026952, 19.34956751550947, 27.20334393637521, 29.320355824061803, 29.240072863442556, 19.012875182288035, 31.360683917999268, 38.18915115083967, 43.6571888923645, 28.848078080586024, 3.6872856616973877, 0.10463084626410689, 0.02924428254898105, 0.0836502585027899, 0.07818311186773436, 0.05529594248426812, 0.02696161950007081, 0.04271061745073114, 0.06930897305054323, 0.02169497317767569, 0.04422537902636187, 0.043456310472850285, 0.051170968650174994, 0.03368884976953268, 0.03336778735475881, 0.08500320983252355, 0.08897878721888576, 0.023926718958786557, 0.027351191899340068, 0.0829345126237188, 0.016410701908171177, 0.012458969090533043, 0.035648218023457696, 0.012974023818969727, 0.03959430967058454, 0.09009665330605847, 0.07185719095702682, 0.03836142511240073, 0.06253024536584105, 0.051527983242911954, 0.03370427626318165, 0.032924798982484, 0.01556150006529476, 0.024227401574275324, 0.03962740860879421, 4.37872131381716, 28.634704113006592, 44.21038709368025, 53.59527029309954, 42.61963871547154, 35.107583386557444, 40.79694209780012, 35.31251008169991, 23.74146131106785, 37.58077730451311, 2.8874780876295905, 0.015821268715496575, 1.0536812884466988, 16.966517789023264, 8.314924887248448, 6.979597066129957, 9.27985336099352, 7.678589752742222, 3.1541245451995303, 13.570467608315603, 42.98524945122855, 48.37968839917864, 50.87552997044155, 52.82010841369629, 49.56507887159075, 49.9857679775783, 52.28847394670759, 50.88152279172625, 50.18008129937308, 49.216407843998496, 48.62145791734968, 44.81234080450875, 46.11066729681832, 48.2293050629752, 47.09357336589268, 48.12132658277239, 48.528001172201975, 44.55969040734427, 41.10936437334333, 36.575407709394185, 38.69980205808367, 48.72470467431204, 48.487732887268066, 48.25053180967058, 43.92384338378906, 46.611625467027935, 44.109745911189485, 46.138783182416645, 43.722672189985005, 46.63261250087193, 48.22905840192522, 45.945772647857666, 36.29318230492728, 35.25353029796055, 34.60309553146362, 36.69534056527274, 43.40806123188564, 49.95766598837716, 43.212250573294504, 45.54241582325527, 46.64582102639334, 45.59530551092965, 43.097059862954275, 45.1292724609375, 44.407604762486045, 45.93564217431204, 44.88607161385672, 45.65818323407854, 39.371275969914024, 48.92392342431204, 24.21011209487915, 22.93562834603446, 50.20495932442801, 44.4434609413147, 49.20452642440796, 41.548733711242676, 47.574423449380056, 43.530106340135845, 45.64503376824515, 40.84646190915789, 40.94393471309117, 44.55599396569388, 53.25092451913016, 47.15467929840088, 39.49366848809378, 35.338875021253315, 37.245995725904194, 35.51322616849627, 40.62487343379429, 46.86440093176705, 47.88280187334333, 48.5395073890686, 47.80378348486764, 46.78238092150007, 44.15221677507673, 42.8150429044451, 45.221384729657856, 47.16847494670323, 47.937032563345774, 47.01172011239188, 44.152887276240754, 47.42376913343157, 50.797817843300955, 47.77390275682722, 46.17175585883004, 41.114485195704866, 43.69508784157889, 44.80850192478725, 47.91717113767351, 47.46308898925781, 48.90527793339321, 47.89048310688564, 48.429798807416645, 47.52309363228934, 45.92380244391305, 46.069829259599956, 51.35972908564976, 48.078136580330984, 49.33568409511021, 43.27962725503104, 45.6961794580732, 46.44750206811087, 39.411384446280344, 14.819685970033918, 7.577462196350098, 6.145425004618509, 7.295035294124058, 6.829133825642722, 13.831534011023384, 2.903359064034053, 0.017632741780419434, 0.984457905803408, 24.006885971341813, 31.99941791806902, 34.31926161902291, 29.03155047552926, 23.383642980030604, 36.09501968111311, 43.66007934297834, 50.767495904650005, 35.22155121394566, 4.748331606388092, 0.008764455327764153, 0.02841996428157602, 0.07553913909941912, 0.06535466773701565, 0.05733898428401776, 0.06032488441893032, 0.03532160858490637, 0.05172838856066976, 0.025152733349906545, 0.08296615271163837, 0.08000186391706977, 0.0373179196779217, 0.04671610126804028, 0.023574387954015816, 0.02678937847459955, 0.05284719102616821, 0.04568071111238428, 0.17299022312675202, 0.1835583924715008, 0.09218936386917319, 0.1158682954098497, 0.10634329223207065, 0.1263306268623897, 0.13643247980092252, 0.15041091186659677, 0.10364483988710813, 0.15255567963634217, 0.23976691705839975, 0.08321875772838082, 0.127461649743574, 0.14056508376130036, 0.16832296071308, 0.10248331007148538, 0.10366943678153412, 7.095822189535413, 40.123213495527, 52.59096377236502, 61.644160815647666, 48.03436292920794, 40.27186673028128, 44.72671815327236, 42.40294872011457, 35.12120532989502, 46.28247192927769, 3.2743724584579468, 0.25107193472129957, 1.543617878641401, 20.798772403172084, 13.88180422782898, 12.79909770829337, 15.341952528272357, 13.198373334748403, 6.447563946247101, 15.516416583742414, 46.41555077689034, 50.69490112577166, 52.21974931444441, 54.730880396706716, 52.04503338677542, 52.27736030306135, 54.53430543627058, 53.41824756349836, 52.001200675964355, 47.616397517068044, 49.604881627219065, 45.0110627583095, 46.241383756910054, 49.95055798121861, 48.638432366507395, 49.52967779976981, 50.61153663907732, 46.33881139755249, 44.024415084293906, 38.00715698514666, 40.34790434156145, 49.99569000516619, 52.01184531620571, 49.344664641789024, 46.14761086872646, 48.95041343144008, 45.731365135737825, 46.848583357674734, 44.275554248264854, 47.03503826686314, 52.10435363224575, 48.2886392048427, 38.00368288585118, 37.1900349344526, 36.43699264526367, 39.20763547079903, 46.05380323954991, 52.184657437460764, 44.31911597933088, 46.383561270577566, 46.41736078262329, 44.66487223761422, 44.17381525039673, 43.88141768319266, 44.29732642854963, 45.34408296857561, 44.26732758113316, 44.629377365112305, 39.510451861790244, 49.92782694952828, 26.85551711491176, 26.170825992311748, 49.49885211672102, 46.8113305909293, 50.242163453783306, 44.36266381399972, 50.06773240225655, 44.23836401530674, 47.68219000952584, 42.61571645736694, 41.93099927902222, 45.34821367263794, 53.786297116960796, 48.547939028058735, 41.703807081495015, 37.33534608568464, 39.57089076723371, 37.28262662887573, 41.303010668073384, 47.62524604797363, 51.197943755558555, 50.99643904822213, 49.32494912828718, 48.26506396702358, 45.81495196478707, 45.04240608215332, 47.49553707667759, 48.68240404129028, 49.752586432865684, 48.91453640801566, 45.92301034927368, 49.327912534986226, 52.868707588740754, 50.20676933016096, 48.473197255815776, 42.59054660797119, 46.22901943751744, 48.08625555038452, 50.91953638621739, 50.170423303331646, 50.70356205531529, 49.01594884055001, 51.61593001229422, 48.7362699508667, 46.22602128982544, 46.857768876211985, 51.92823764256069, 49.68487971169608, 50.88668877737862, 43.57964352199009, 47.00534514018467, 46.94199841363089, 43.22423621586391, 16.56085068838937, 13.58421983037676, 11.218346050807408, 10.15713291508811, 12.396814380373273, 15.485118423189435, 3.4869391322135925, 0.22612064145505428, 1.3471122916255678, 27.67858508655003, 39.62621579851423, 37.84483316966465, 37.44393948146275, 29.452698162623815, 43.78602239063808, 49.94115012032645, 58.30385603223528, 43.65537888663155, 7.895577652113778, 0.21247380945299352, 0.11540615877934865, 0.15680227747985295, 0.14945409606610024, 0.14140072677816662, 0.22355159930884838, 0.11579407724950995, 0.132004034572414, 0.08530307481331484, 0.12373075208493642, 0.1566593237221241, 0.1382321853722845, 0.12681587439562592, 0.10445830159421478, 0.3133648692497185, 0.21858123530234608, 0.09661974970783506], [0.024388738541996906, 0.01980176887341908, 0.02399391258534576, 0.03295118720935924, 0.01954367959738842, 0.05894728869731937, 0.06650594488850661, 0.014839808523122753, 0.036186208083693466, 0.05878017230757645, 0.04211403249895998, 0.015539557939129216, 0.040059007770781, 0.01544519916309842, 0.053409347111093144, 0.028692199316407953, 0.08101454350565161, 7.541165675435748, 31.952590533665248, 45.28031587600708, 36.534708636147634, 35.653256688799175, 20.617068324770244, 8.42087709903717, 25.526840891156876, 37.38135010855538, 26.477995429720195, 0.42619970600519863, 0.4651734275477273, 4.583905526569911, 4.811233648232051, 3.219494500330516, 7.004157211099352, 4.7202465534210205, 7.1547264116150995, 4.612646750041416, 24.74492883682251, 43.2561388696943, 51.67929063524519, 49.55894013813564, 49.9928377696446, 46.371589524405344, 47.226527145930696, 47.035951954977854, 50.003687381744385, 47.8892810685294, 46.821874482291086, 47.69408532551357, 45.75934900556292, 45.909600325993125, 50.35447413580758, 42.83739873341152, 43.136480467660085, 39.15999167306082, 38.86200775418963, 35.702463831220356, 34.8930994442531, 33.42259659085955, 39.50352798189436, 45.107750415802, 47.26566634859358, 46.85663284574236, 47.50217955453055, 47.2338297026498, 47.41527496065412, 47.0913325718471, 46.98808928898403, 47.98773009436471, 38.72020544324602, 32.142978123256135, 32.074427195957725, 33.24270078114101, 39.46778992244175, 44.21740130015782, 47.6014449937003, 43.91229200363159, 45.806072166987825, 44.5036427634103, 46.6892785344805, 45.3417900630406, 46.19682843344552, 42.19613906315395, 44.29095493044172, 39.490746770586284, 43.49700512204851, 37.98618037360055, 46.05495664051601, 25.024692841938563, 24.701742308480398, 54.09148979187012, 43.980262756347656, 48.942610604422434, 45.440631662096294, 48.77980736323765, 44.40036473955427, 47.43706798553467, 44.330660411289756, 43.34074360983712, 42.42386279787336, 46.1764771597726, 46.35115139825003, 40.80001320157732, 33.86962979180472, 35.25857121603829, 33.51349292482649, 34.52919101715088, 36.81702784129551, 45.082945346832275, 45.25606318882534, 49.67341865812029, 46.5724549974714, 45.969875948769705, 46.03662034443447, 49.90831988198416, 46.98915236336844, 46.00873722348894, 45.411640303475515, 48.59142780303955, 48.019862038748606, 47.6246519769941, 43.330887590135845, 39.36006505148751, 35.72461816242763, 39.555344172886436, 39.497556005205425, 45.77594130379813, 44.32863848549979, 47.41448286601475, 45.15016916819981, 47.509815624782014, 43.686697891780305, 46.94182470866612, 46.91351774760655, 48.963712283543174, 40.217632566179546, 49.73081077848162, 41.187750475747244, 30.716144698006765, 23.88298221996852, 26.810388565063477, 19.452854224613734, 10.973402074405126, 6.552509972027369, 4.272624492645264, 3.7523542387144904, 3.279788362128394, 1.2574106135538645, 0.18413733212011202, 0.48883459504161564, 12.911482214927673, 28.950730766568864, 29.366411958421978, 34.00736740657261, 19.901815550667898, 37.93469769614083, 36.99669088636126, 44.064718110220774, 39.468238081250874, 7.304025394575937, 0.06717327729399715, 0.023602682864293456, 0.011427806208043225, 0.018598824672933136, 0.015723211923614144, 0.05914649979344436, 0.01485142164996692, 0.03791155978771193, 0.023297735656212484, 0.031864703366799016, 0.056657328004283566, 0.01864999808770205, 0.03768542781472206, 0.03459546076399939, 0.029996581109506742, 0.05504467757418752, 0.06400825069951159, 0.03489403313558016, 0.024388619798368642, 0.06439873403204338, 0.059065740555524826, 0.04462434404662677, 0.04392454374049391, 0.010535572522452899, 0.04755894693412951, 0.036198611703834364, 0.10351660355393376, 0.019843877060338855, 0.04696115079735007, 0.03422791530777301, 0.08499229220407349, 0.03862622340342828, 0.03561108519456216, 0.04120097542181611, 9.089261668069021, 37.93771321432931, 51.89947557449341, 43.438883440835134, 40.316745144980295, 25.328714745385305, 17.31488483292716, 28.622562135968888, 34.09100634711129, 27.00333830288478, 0.8804801223533494, 0.5399510807224682, 6.380202029432569, 7.353985548019409, 6.297339984348842, 8.835314563342504, 9.755799753325325, 6.3406789387975415, 3.276381573506764, 26.04682149205889, 43.68531172616141, 52.381569385528564, 50.29649141856602, 51.376171997615266, 48.73126029968262, 48.046160970415386, 48.46518250874111, 51.25929634911673, 48.66442557743618, 47.080337047576904, 46.779118742261616, 46.71290240968977, 47.516805512564524, 50.617122990744456, 46.012572629111155, 44.694711276463096, 41.13249145235334, 41.67054952893938, 38.448975563049316, 37.00162410736084, 35.2913875579834, 41.79126058306013, 46.9190902028765, 48.196259430476594, 48.443663937704905, 48.59051758902413, 47.75050469807216, 49.431756837027415, 47.1741828918457, 47.94318866729736, 49.699807916368755, 42.68095656803676, 34.81769411904471, 34.35303681237357, 35.221026624952046, 40.80806616374424, 46.524529797690256, 49.695673738207134, 45.93833112716675, 45.73083012444632, 44.849329539707725, 47.47630098887852, 46.32831266948155, 46.89262451444353, 42.13751711164202, 44.65765653337751, 40.35383115495954, 42.803488050188335, 40.2753130367824, 48.510008811950684, 25.3224926335471, 25.330943380083355, 55.65440716062273, 44.610794407980784, 49.45583234514509, 47.35865409033639, 48.37901094981602, 46.590204170772004, 48.84208754130772, 47.801382882254465, 44.49734074728829, 42.810689858027864, 47.85441848209926, 48.2714250428336, 42.358959674835205, 35.30809102739607, 36.98927368436541, 35.868108885628835, 36.30601910182408, 39.58078152792794, 46.80405930110386, 48.93897322246006, 50.60706894738333, 49.10785961151123, 48.14146941048758, 46.656326702662874, 51.788321767534526, 49.06151860100882, 48.4815559387207, 48.776406220027376, 49.61306313105992, 49.89892591748919, 49.19386441367013, 45.16297122410366, 41.02391542707171, 37.2363029888698, 41.391489028930664, 41.96508714130947, 46.44505282810756, 46.140968390873496, 48.11148793356759, 47.04262569972447, 48.83056047984532, 45.65062359401158, 47.63354219709124, 47.44294268744332, 47.93938452856881, 42.856603554316926, 51.37515408652169, 44.718387263161794, 34.509704794202534, 24.16589723314558, 26.066123587744578, 18.704804216112407, 9.318573066166469, 6.2754314456667215, 6.928634635039738, 5.98556866816112, 7.7755449158804755, 1.0172236561775208, 0.05074988678097725, 0.3334001898765564, 15.745118277413503, 33.25733716147286, 35.59624324526106, 38.13308613640921, 27.241725785391672, 43.97950540270124, 41.960744517190115, 49.392833028520855, 46.01609883989607, 11.123224343572344, 0.04512316567291107, 0.026573103919093097, 0.02059289320771183, 0.04183335309582097, 0.0206856608191239, 0.035321371097649844, 0.08426101465842553, 0.03742057863356812, 0.011145815535980676, 0.07510816758232457, 0.07032263651490211, 0.01978184878160911, 0.030549203777419667, 0.03150438091584614, 0.031084259173699787, 0.09038642168577228, 0.020640227810612748, 0.13742778210767678, 0.10415637386696679, 0.22985645170722688, 0.10572112990277154, 0.15782450405614717, 0.22097889307354177, 0.10128104779869318, 0.16122327239385673, 0.1848779802343675, 0.1303726328270776, 0.11560969214354243, 0.10149782616645098, 0.16056735973273004, 0.1620753766702754, 0.20584254099854402, 0.1276445827846016, 0.1715661681124142, 12.168615562575203, 47.50632415499006, 59.51056357792446, 47.666580881391255, 45.59446130480085, 28.486413921628678, 18.123827116830007, 35.47231864929199, 48.7906083379473, 32.35739605767386, 1.109123027750424, 0.9640485495328903, 7.538588762283325, 8.296836120741707, 8.473814555576869, 17.036288125174387, 13.308844481195722, 13.043081096240453, 10.474538786070687, 32.46410649163382, 47.00396244866507, 52.65556117466518, 51.92337737764631, 53.12281363351004, 49.769345487867085, 50.1959753036499, 50.88772405896868, 53.50005565370832, 50.78591557911464, 48.418692111968994, 47.42599950517927, 46.524005208696636, 49.032461234501426, 54.446945735386436, 47.40831633976528, 46.90862968989781, 42.37615646634783, 44.11235843385969, 40.326066153390066, 39.185557569776265, 38.111095087868826, 43.84138216291155, 48.88801513399397, 50.912692410605295, 50.00172798974173, 50.4908116885594, 49.96851907457624, 52.02955280031477, 50.484891823359895, 50.087107454027446, 52.31488404955183, 44.017341818128315, 36.3040770803179, 35.757326807294575, 36.35114765167236, 43.87673807144165, 48.31109230858939, 52.55871718270438, 46.2489572933742, 45.003579548427034, 46.40198789324079, 46.63786881310599, 48.140451499394004, 46.807311058044434, 43.28659629821777, 46.08567462648664, 41.25447402681623, 42.90481015614101, 41.974807671138215, 48.93927894319807, 27.65548058918544, 27.826312473842076, 56.624743938446045, 47.326883452279226, 51.35273919786726, 49.65239340918404, 49.71794618879046, 48.41688558033535, 52.275571141924175, 49.35832132611956, 45.32832792827061, 44.46945415224348, 48.92462519236973, 49.229192529405864, 44.14936106545584, 37.28442621231079, 38.822062560490195, 37.56140225274222, 38.822826862335205, 41.303945200783865, 47.88788448061262, 48.8410279410226, 52.91004589625767, 50.96196208681379, 49.43934426988874, 48.28874690192086, 53.13094302586147, 53.122851848602295, 50.148043155670166, 50.430431842803955, 53.937813009534565, 52.100389684949604, 50.951699597494944, 48.014310428074424, 43.997456073760986, 38.63651091711861, 43.977962902614046, 42.79040806634085, 49.40175451551165, 48.42001574380057, 50.10598223549979, 49.640862873622346, 51.9591258593968, 46.548025131225586, 48.70433950424194, 48.02495854241507, 50.32240472521101, 42.50560488019671, 53.264195578438894, 47.11852087293352, 37.57592051369803, 26.182212352752686, 31.144164153507777, 22.792472873415264, 16.377774340765818, 15.600924049104963, 9.752790314810616, 8.893855742045812, 7.192870284829821, 2.4701100034373145, 0.22564629119421753, 0.7064998352101871, 18.86354970932007, 42.22165632247925, 39.66998597553798, 46.2899238722665, 29.669534070151194, 48.98723888397217, 48.92367328916277, 56.54106330871582, 53.684922899518696, 16.420203515461512, 0.11350565683096647, 0.1659476945974997, 0.10724178116236414, 0.13276681649897779, 0.08279837135757719, 0.20723957674843924, 0.1521217700626169, 0.11778739600309304, 0.12942968628236226, 0.13910387216934136, 0.12856057791837625, 0.10788636907402958, 0.10299810101943356, 0.08889998216181993, 0.10814840572753123, 0.23596850516540663, 0.23291716032794543], [0.06186634634754487, 0.036153343240065236, 0.037724979620959075, 0.05004094660814319, 0.030656449629792144, 0.03457831757675324, 0.08214444001870495, 0.011751693024832224, 0.03230731175946338, 0.04576968401670456, 0.02175151719711721, 0.06438152638397046, 0.05640757961996964, 0.014363853526966912, 0.04155600190694843, 0.05393586653683867, 0.187397815021021, 6.18741774559021, 34.97798558643886, 44.76293911252703, 35.38580315453665, 31.951961721692765, 17.986773899623326, 20.170269625527517, 29.73814058303833, 36.73765162059239, 15.808426788875035, 0.2227194303912776, 2.3562288114002774, 11.92382618359157, 0.6860972100070545, 5.121288759367807, 5.004933791501181, 10.179004975727626, 6.651174392019, 11.89369445187705, 42.7107434953962, 53.05165018354143, 52.95519529070173, 50.038209506443565, 50.504186970846995, 47.06525250843593, 45.903666564396445, 44.381813049316406, 48.22327402659825, 46.461624281747, 49.45746864591326, 44.638166836329866, 45.36788749694824, 45.512489931924, 47.29335839407784, 44.220427240644185, 39.30235678809029, 35.328171321323936, 37.205564158303396, 35.01097215924944, 35.8144861630031, 32.12406512669155, 35.432550634656636, 39.02878883906773, 43.36582660675049, 43.36779294695173, 45.70584787641253, 45.26146541322981, 47.49855954306466, 45.77827589852469, 46.378405707223074, 38.216732025146484, 34.94463423320225, 33.81921018872942, 34.16464335577828, 35.43769924981253, 37.96537051882063, 47.55649709701538, 44.04606567110334, 44.52538367680141, 50.17343882152012, 47.84322146006993, 49.538387366703574, 47.616619859422954, 48.91237551825387, 43.724881717136924, 47.69756637300764, 40.79517378125872, 44.983481884002686, 35.86593062537057, 46.45119850976126, 27.07537375177656, 28.460702112742833, 51.35184288024902, 42.095699378422324, 46.82546670096261, 41.53186001096453, 45.65417064939226, 43.28889267785208, 47.25332634789603, 47.088542870112825, 46.43502310344151, 44.92757667813982, 46.21772861480713, 45.11998619352068, 38.72999198096139, 34.61280911309378, 35.06839902060372, 34.736664227076936, 35.88947112219674, 33.678707190922324, 36.67027841295515, 39.06272036688668, 45.35250071116856, 45.70628908702305, 48.04252706255232, 47.41669239316668, 46.49524661472866, 45.322724206107004, 46.07595757075718, 47.29538379396711, 47.97429575238909, 46.549018723624094, 43.45568765912737, 38.116584164755686, 35.56722756794521, 36.42073386056082, 39.10894673211234, 40.841261182512554, 42.44463096346174, 42.32935687473842, 43.26850666318621, 44.85293912887573, 47.52338893072945, 47.060760498046875, 49.8945311818804, 45.65447637013027, 48.281413078308105, 47.00598784855434, 45.47694642203194, 47.115314279283794, 44.115679672786165, 32.79026535579136, 22.396918875830515, 16.88381164414542, 6.005615523883274, 3.932726000036512, 7.41521828515189, 11.72862262385232, 25.34457574571882, 18.984175648008073, 0.5133163556456566, 0.03491631283291748, 6.087080112525395, 25.69546672276088, 37.628549643925254, 26.627895866121563, 11.93396360533578, 17.98643864904131, 37.29992764336722, 44.364060401916504, 44.94417939867292, 15.292432716914586, 0.27985992282629013, 0.03833843973864402, 0.10618676777396883, 0.06279417513204472, 0.023071417086092488, 0.027926523437989608, 0.009216848195397427, 0.03487209609842726, 0.016010926038558995, 0.060272026540977616, 0.004073844100016036, 0.014479460627106684, 0.016374427426074232, 0.0581261527591518, 0.04537618120333978, 0.0325169485461499, 0.05367726666320648, 0.03159746913505452, 0.007339593704922923, 0.03535834786349109, 0.04688200647277491, 0.006541415575026933, 0.05849539116024971, 0.032934213655867746, 0.004642062047163823, 0.09528490847774915, 0.016196988822360123, 0.025987043045461178, 0.09761457704007626, 0.05018907758806433, 0.018222802617986287, 0.028271315918703164, 0.021699548200038925, 0.1510762833058834, 8.208380341529846, 41.23364332744053, 50.71994243349348, 40.484783853803364, 37.43543141228812, 21.567962305886404, 18.21434998512268, 32.247114249638145, 40.12734767368862, 18.722278935568674, 0.11994099829878126, 2.7711363647665297, 13.108513150896345, 1.153061372893197, 6.346728214195796, 7.93187243597848, 8.370114428656441, 4.194114625453949, 11.9842529296875, 40.80707951954433, 54.90731600352696, 53.68727139064244, 52.41733871187483, 51.618900367191856, 48.97964450291225, 48.527160440172466, 47.9774363381522, 50.558184896196636, 48.18102897916521, 48.46451895577567, 46.02533994402204, 45.33443192073277, 45.539685181209016, 50.14979410171509, 45.191462312425884, 41.45155273165022, 37.141032763889854, 38.38289124625069, 37.80505820683071, 37.40140955788748, 33.60192264829363, 37.601555892399375, 41.16646466936384, 45.874775954655235, 46.065601280757356, 47.07419831412179, 47.06273031234741, 49.029664584568565, 46.92934921809605, 49.41246863773891, 42.55626767022269, 36.4829341343471, 35.19749655042376, 35.9751215662275, 35.9713591166905, 40.54333632332938, 48.999797752925325, 45.30713244846889, 47.336134978703086, 50.81430244445801, 48.99681350163051, 50.07116828645979, 48.89884737559727, 49.600671018872944, 44.52568244934082, 47.420659814562114, 41.97234453473772, 44.86244426454817, 38.663733959198, 46.52294213431222, 28.630358014787944, 30.049201011657715, 52.75020258767264, 44.74016639164516, 48.88831043243408, 42.42858062471662, 47.09844405310494, 44.81554739815848, 50.4074124608721, 48.39699288776943, 48.41758734839303, 45.90332610266549, 48.67795024599348, 47.68958289282662, 41.68341064453125, 35.979964460645405, 36.06109510149275, 36.12481703077044, 38.09958192280361, 35.30472115107945, 38.523432459150044, 42.4508878162929, 48.68409940174648, 48.07325894492013, 51.079376220703125, 49.72952536174229, 47.704723017556326, 46.8549930708749, 47.768135751996724, 48.327538694654194, 49.68651601246425, 48.5966146332877, 46.92757395335606, 39.45237186976841, 38.24158920560564, 38.01898281914847, 40.65807540076119, 43.44787440981184, 43.6674861226763, 44.078155926295686, 44.18252829142979, 46.50404303414481, 49.62988124574934, 46.53482355390276, 50.714957101004465, 46.3406457219805, 48.68883112498692, 47.13576282773699, 46.980658190590994, 47.08508961541312, 46.085195200783865, 36.98677928107125, 25.61499616077968, 15.403751543590001, 6.621264134134565, 10.107944011688232, 12.136236088616506, 4.8974230119160245, 26.785854475838796, 23.57185925756182, 0.4713968964559691, 0.04076359514147043, 7.630879078592573, 30.250333990369523, 37.123224530901226, 28.600169828959874, 14.347808616501943, 25.014289651598247, 42.766127586364746, 49.53493063790457, 50.682557650974815, 20.3898309639522, 0.141718932560512, 0.006499572440848819, 0.06067327143890517, 0.09561758741204228, 0.03788630132164274, 0.01521430557061519, 0.06299078743904829, 0.014076245433118726, 0.060265865443008285, 0.00761688721831888, 0.025115498740758215, 0.02877779650901045, 0.051239178382924626, 0.06399683774049793, 0.05339067382737994, 0.0348100746050477, 0.027653114537575414, 0.11982998996973038, 0.09665036520787648, 0.1210130157747439, 0.08188276977411338, 0.1945827409092869, 0.12504294381609984, 0.15845429311905587, 0.08177258925778524, 0.14083060808479786, 0.16608930485589163, 0.11308567758117404, 0.19906082775975975, 0.14399948875818933, 0.061634870911283154, 0.12121718696185521, 0.13678104324000223, 0.25938282161951065, 11.352547901017324, 50.944195543016704, 57.157684666769846, 47.40614850180489, 42.68664366858346, 27.083397184099468, 30.710818903786794, 40.7146372113909, 47.969251360212056, 21.144476549965994, 0.23709177917667798, 3.2586905913693562, 14.179848943437849, 3.3645338032926833, 14.332518236977712, 14.091911673545837, 20.62505875314985, 13.530943649155752, 16.421045984540665, 45.79892247063773, 56.02014643805367, 55.69743735449654, 53.34233501979283, 55.63036291939871, 51.32147230420794, 51.63871315547398, 50.273444243839805, 52.22454357147217, 49.08885281426566, 49.87640333175659, 45.760710852486746, 45.747814995901926, 46.559694630759104, 52.39004966190883, 48.15077652250017, 44.318765095302034, 39.16032518659319, 41.815919739859446, 39.78138296944754, 40.28095497403826, 35.63515663146973, 38.947699887411936, 43.85710941042219, 47.49425513403756, 47.349642276763916, 49.22046559197562, 48.989413670131135, 52.6857510975429, 49.82232550212315, 51.77643687384469, 42.95279441561018, 38.0497841835022, 36.74323797225952, 37.405467305864605, 37.148741790226524, 42.38996253694807, 51.81959213529314, 48.91246584483555, 50.18454204286848, 51.394497871398926, 52.72181919642857, 51.611010687691824, 50.14202948978969, 51.202539988926475, 46.81731646401541, 48.71016556876046, 42.858104365212576, 45.41525684084211, 39.151650360652376, 46.66236121313912, 30.22660936628069, 33.184460980551584, 53.32371037346976, 45.75747994014195, 50.00563635144915, 45.17596435546875, 48.6697861126491, 46.66400098800659, 51.73316349302019, 51.122670446123394, 50.23001452854702, 47.69255324772426, 49.37079334259033, 48.81985330581665, 43.327545506613596, 39.04077100753784, 37.999489648001536, 38.10705818448748, 39.265006746564595, 36.72930335998535, 40.34819616590227, 44.65655871800014, 49.60504143578665, 50.59946414402553, 53.81502444403512, 53.17004748753139, 51.3264923776899, 48.626418931143625, 50.75218902315412, 51.63891812733242, 52.023059708731516, 50.816032545907156, 48.28655821936471, 42.614215646471294, 39.36593975339617, 42.5660993712289, 43.4240003994533, 46.32892063685826, 45.16329084123884, 46.634290490831646, 45.660003662109375, 47.98792116982596, 50.705250467572895, 48.80151006153652, 52.799197810036794, 49.05061687741961, 49.44383628027779, 48.841191223689485, 47.53312335695539, 51.0683251108442, 47.86810990742275, 41.39227417537144, 28.19802025386265, 19.085805211748394, 7.454824754170009, 10.150070939745222, 12.162998812539236, 25.85388912473406, 34.715493065970286, 22.12178063392639, 1.2316436533417021, 0.07133074956280844, 8.788446358272008, 36.7511693409511, 46.978806495666504, 35.165072781699045, 20.182644367218018, 29.093721219471522, 49.924495288303916, 56.05654457637242, 57.36706863130842, 26.13536238670349, 0.6367833475981439, 0.14804013765283994, 0.28238803574017113, 0.11602319138390677, 0.09343282678829772, 0.14758173296494143, 0.16331492444234236, 0.13000264125210897, 0.11894102767109871, 0.19352550192603044, 0.09851752394544226, 0.12247118752981935, 0.13253696954676084, 0.15368191206029483, 0.17792024144104548, 0.10191839574170963, 0.16228078279112065], [0.01185703813098371, 0.003647557443140873, 0.03661839757114649, 0.059382236429623196, 0.07861758462552514, 0.05034225686852421, 0.08864602686039039, 0.02609950683212706, 0.028379157185554504, 0.041929623644266806, 0.008966447569296827, 0.011760194220447114, 0.047357533991869004, 0.0612160519563726, 0.0653727235538619, 0.05165310849302581, 0.33832307000245365, 10.027488214629036, 31.699033396584646, 45.91905335017613, 43.09990167617798, 26.169568368366786, 16.150816644941056, 24.15644073486328, 29.386627742222377, 32.08202852521624, 10.030549764633179, 0.05759606084653309, 1.3346542801175798, 1.8003975685153688, 1.756783508828708, 7.089652623449053, 5.659128401960645, 7.526245287486485, 6.863404078142984, 25.435166358947754, 50.70699099131993, 51.10424034936087, 49.33758442742484, 47.80436713354928, 48.34227582386562, 46.61089243207659, 44.66090134211949, 45.774978978293284, 48.65055002485003, 48.15828057697841, 45.92062016895839, 44.28048052106585, 45.47506693431309, 46.57172891071865, 44.786021028246196, 43.06655379704067, 38.50522470474243, 34.69100066593715, 35.38529593603951, 34.98324537277222, 36.43434190750122, 34.87548576082502, 33.81054925918579, 35.15399040494646, 37.41262395041329, 38.21028062275478, 41.564099652426584, 40.685298442840576, 41.85881791796003, 38.48961557660784, 37.25660562515259, 32.30388103212629, 34.67470366614205, 32.9655510357448, 34.274067061288015, 33.66695431300572, 38.84472063609532, 46.290587425231934, 47.47110721043178, 45.95191832951137, 46.17838444028582, 45.517913000924246, 46.49227973393032, 43.26652642658779, 48.54303707395281, 43.678311416081016, 45.26212896619524, 42.57279396057129, 43.594755853925435, 38.85862398147583, 44.117465359824045, 27.363854272024973, 25.72696464402335, 52.45402520043509, 40.568655558994834, 46.07870210920061, 37.57124785014561, 39.741340500967844, 37.69548511505127, 42.21240827015468, 43.46456398282732, 47.51720155988421, 47.77034180504935, 48.031660079956055, 42.94218104226248, 37.40652690614973, 33.369529724121094, 35.03888654708862, 35.474489961351665, 36.06775494984218, 34.96756328855242, 35.82191031319754, 34.51038571766445, 37.45533800125122, 40.29696362359183, 42.14326327187674, 43.11648007801601, 42.436230591365266, 38.23135450908116, 37.79179409572056, 39.89382914134434, 40.353515011923655, 38.5356057030814, 34.92773274012974, 35.095045362200054, 35.983129365103586, 34.511146545410156, 36.233625820704866, 36.97143765858242, 37.951192719595774, 38.64353207179478, 41.43715606416975, 45.31175994873047, 46.31967258453369, 47.96082319532122, 43.58721011025565, 45.97605984551566, 46.699256147657124, 49.712714195251465, 51.43404006958008, 49.053747040884836, 52.44315126964024, 47.864145960126606, 44.869885785239084, 27.83641341754368, 11.937189306531634, 10.632329770496913, 9.546708481652395, 12.147976807185582, 9.503593172345843, 7.608039481299264, 1.5873270417962755, 0.04314866269539509, 3.7291880760874068, 21.9194803578513, 34.820692266736714, 60.02614770616804, 39.35981144223894, 33.034386839185444, 35.105544090270996, 41.70054142815726, 44.215073653629844, 23.94568623815264, 0.7071102453129632, 0.046151702624878714, 0.053715556394308805, 0.02463381182003234, 0.01611640939622053, 0.009733260842040181, 0.012796614052993911, 0.06250824047518627, 0.0023000083123666366, 0.0651347613228219, 0.020390705039192523, 0.10498262595917497, 0.04498999299747603, 0.030543066428175995, 0.010794091820051628, 0.024903811081977825, 0.014469352151666368, 0.017598523259428994, 0.012734750319006187, 0.024610434592302357, 0.0332566433187042, 0.056853132854614935, 0.0372361426374742, 0.04687264608219266, 0.03148126322776079, 0.03833201740469251, 0.008105386630631983, 0.024652429124606506, 0.04045885827924524, 0.0039577683866290105, 0.028583355514066558, 0.025970427419192026, 0.019779675773211887, 0.4472959025629929, 11.78627790723528, 38.082204478127615, 51.68595743179321, 46.76078244618007, 30.393074308122905, 19.183905090604508, 26.628641060420446, 32.82908494131905, 37.17506504058838, 11.501889875956945, 0.07914812437125615, 1.5968614901815141, 4.529627501964569, 3.817191788128444, 5.510241534028735, 6.429450861045292, 5.14509893315179, 5.352648573262351, 26.53160946709769, 54.193798542022705, 52.77899939673287, 51.44133220400129, 48.8198880468096, 50.70738703863961, 48.854698521750315, 46.657427992139546, 47.14174175262451, 50.27940232413155, 50.32904372896467, 46.779115268162315, 44.49708366394043, 45.92738424028669, 46.16812889916556, 47.06671857833862, 44.51411369868687, 39.885036196027485, 36.20350537981306, 36.618496962956016, 37.370180879320415, 37.534328596932546, 35.771594933101106, 36.22702155794416, 37.712511675698416, 39.15111534936087, 39.74739238194057, 43.65376690455845, 42.463224342891145, 42.818023681640625, 41.16016960144043, 39.09581116267613, 33.108312198093955, 36.289013385772705, 34.77622379575457, 36.08889136995588, 35.22538661956787, 40.9339953150068, 48.79743494306292, 48.865464755467, 47.71038927350725, 48.31006050109863, 47.84911700657436, 47.916684763772146, 44.56680188860212, 48.709137235369, 45.79219661440168, 46.512599740709575, 42.078481742313926, 44.72667646408081, 40.429781913757324, 44.48361458097185, 28.458678449903214, 27.122624976294382, 52.726137501852854, 43.9689302444458, 47.25272185461861, 38.13465295519148, 42.18589741843087, 39.70645012174334, 45.83880165645054, 45.18434388296944, 49.23696756362915, 48.81178297315325, 48.94688374655587, 43.74403442655291, 40.06905576160976, 36.056898389543804, 36.56395360401699, 38.43391534260341, 38.653877939496724, 36.50017956324986, 37.46264055797032, 35.93787227358137, 39.8553534916469, 41.13911655970982, 45.180108955928254, 46.51798806871687, 44.600590978349956, 40.17060368401663, 40.51127733503069, 42.75133139746529, 42.85535287857056, 41.21275009427752, 37.206686292375835, 37.332483427865164, 36.82057837077549, 36.64885711669922, 36.48685639245169, 40.104380403246196, 40.842317308698384, 40.6960438319615, 43.63311685834612, 46.63203232628958, 49.05549103873116, 48.80090209415981, 44.76558985028948, 46.69049446923392, 47.94678783416748, 50.47393798828125, 51.29804645265852, 52.03465625217983, 52.98346056256975, 50.78071485246931, 46.415613310677664, 29.88130474090576, 12.44699948174613, 12.486978547913687, 9.35174376623971, 17.759142228535243, 15.618016617638723, 8.347084624426705, 1.6950382334845406, 0.059364418100033484, 4.064843824931553, 25.998326539993286, 37.373276301792686, 50.33901786804199, 31.287363052368164, 34.04499190194266, 41.83374881744385, 47.41673060825893, 51.99961648668562, 29.51010070528303, 1.1708165173019682, 0.01844295669746186, 0.02276032404708011, 0.04974127161715712, 0.003399426304635459, 0.01922821848919349, 0.03459794080949255, 0.05814680057976927, 0.009976612337465798, 0.07348058598914317, 0.04227031946980527, 0.05130299460142851, 0.02637765190697142, 0.05037349662078278, 0.024603637367753044, 0.011122121093129473, 0.02418344607576728, 0.1286888617490019, 0.14138474049312727, 0.07951356297624962, 0.12586023924606188, 0.12419401508356843, 0.1509299368730613, 0.14988058246672153, 0.14570654715810502, 0.10179390492183821, 0.09992921605174031, 0.18054496417088167, 0.116935970261693, 0.10596855091197149, 0.19091513699718884, 0.11096292827278376, 0.1452586054801941, 0.5957625401871545, 16.254607098443167, 46.74899135317121, 59.46346173967634, 53.008345535823274, 35.772161211286274, 25.554404394967214, 34.163618496486116, 40.457428795950754, 43.425233704703196, 14.622007983071462, 0.23355026064174517, 1.9074822281088148, 4.315871383462634, 3.914070955344609, 13.08387223311833, 12.233549083982195, 19.21201750210353, 11.64626041480473, 28.429204191480363, 55.76837846211025, 55.75168888909476, 53.73611027853829, 50.88226624897548, 52.81457417351859, 51.28876713344029, 48.0681277002607, 50.72744301387242, 53.22313519886562, 51.01079750061035, 47.072301455906455, 46.68164593832833, 45.14383588518415, 47.9052653993879, 49.638514382498606, 47.42015607016427, 42.793267250061035, 38.50357450757708, 39.15023987633841, 41.138324465070454, 39.13778870446341, 39.390237603868755, 38.44362545013428, 40.974538053785054, 41.2865434374128, 42.21741444723946, 45.71639176777431, 44.86100251334054, 44.970370633261545, 43.572650160108296, 40.423247132982524, 35.19010019302368, 37.59442704064505, 36.95166308539254, 39.28496544701712, 38.45451327732631, 42.244884150368826, 50.531892912728445, 50.732449190957205, 48.11295747756958, 50.71686438151768, 50.51139225278582, 50.08495003836495, 46.034952776772634, 50.201919487544465, 47.88910736356463, 46.45395347050258, 44.546231746673584, 45.50156388963972, 41.93132584435599, 46.543668610709055, 31.23429618562971, 30.481733322143555, 53.59640979766846, 44.89763341631208, 49.542684827532085, 41.54159096309117, 44.68758242470877, 43.197398798806326, 47.07537603378296, 46.61260168892996, 51.059257711683, 52.64043494633266, 50.975545815059114, 45.53513411113194, 40.24696438653128, 38.47898135866438, 38.87952763693673, 40.07204696110317, 40.21277230126517, 38.83655650275094, 39.76344966888428, 38.71873589924404, 41.57296902792794, 43.48821217673165, 47.216546058654785, 48.053380148751394, 47.19471134458269, 41.574191910879954, 40.9460643359593, 43.99950231824602, 44.470607553209575, 43.10917752129691, 38.975207805633545, 38.54499619347708, 39.089557783944265, 38.38668843678066, 40.63744967324393, 41.88261202403477, 42.8238844871521, 43.463872637067524, 46.50694738115583, 48.76461165291922, 50.84186594826834, 50.064675194876536, 45.74025188173567, 47.72041204997471, 49.298264571598594, 52.52807910101754, 54.50964975357056, 53.24442795344761, 55.47571338926043, 52.285510540008545, 48.39041294370379, 31.187666824885778, 13.830121789659772, 15.884770120893206, 14.062317558697291, 15.663152115685598, 11.139080132756915, 9.256143501826696, 2.041989799056734, 0.22039379232696124, 5.459255652768271, 33.2305588041033, 46.12185042245047, 68.42559569222587, 50.185344559805735, 43.19506420407976, 47.27020352227347, 54.575258118765696, 58.20510475976126, 36.10168300356184, 1.8889383545943668, 0.14384364283510617, 0.1631650496274233, 0.14889593315976007, 0.10148940554686955, 0.1444909923842975, 0.12975463670279297, 0.14519160693245275, 0.101027214633567, 0.15200576771582874, 0.08972842592213835, 0.18996293523481914, 0.12613301032355853, 0.09404894337058067, 0.10709027786340032, 0.17247704709214823, 0.14837599891637052], [0.03822098871959107, 0.09749767902706351, 0.010173446016519197, 0.04153771199552076, 0.03808705269226006, 0.026098867312871983, 0.010384961497038603, 0.008961512923373707, 0.06548784380512578, 0.04213925025292805, 0.026428681133048873, 0.00020456281578974864, 0.00607760126669226, 0.019309876786012734, 0.02711616942126836, 0.07143522359962974, 0.36547074041196276, 11.486259034701757, 38.29686212539673, 42.819969177246094, 43.60829094478062, 33.7469037600926, 24.498380695070537, 22.251560824257986, 34.12765809467861, 31.853721141815186, 6.682575907026019, 0.13511148068521703, 4.3716263345309665, 3.80514144045966, 0.6005377439515931, 4.263812874044691, 3.778602361679077, 4.306334112371717, 13.825291054589407, 43.221623693193706, 49.19046674455915, 52.40624591282436, 45.59206765038626, 47.705021790095735, 43.969166483197895, 46.06179019383022, 47.14919716971261, 50.116338525499614, 46.991910798209055, 47.41417714527675, 45.45478514262608, 44.036960056849885, 43.79842145102364, 44.90049260003226, 46.915494510105674, 43.92618840081351, 42.7925237928118, 38.6947055544172, 34.64651482445853, 34.49030542373657, 35.85148532049996, 36.56950521469116, 37.35037503923689, 35.488931792122976, 33.26548739842006, 34.969956942967, 35.005375385284424, 34.71975925990513, 33.12289299283709, 32.63108560017177, 32.49641561508179, 32.6208404813494, 35.270390101841514, 33.40862028939383, 33.34641654150826, 33.796566009521484, 34.93291957037789, 44.834519454411094, 47.929796014513286, 45.350704601832796, 42.78070143290928, 41.01466737474714, 43.59577029091971, 43.504321575164795, 47.16786003112793, 45.713237285614014, 46.830198424203054, 41.091160093035015, 43.75981378555298, 39.125872543879915, 43.37105165209089, 27.69246585028512, 24.482684714453562, 52.99052340643746, 43.1047237260001, 46.489952087402344, 39.387871742248535, 37.39909928185599, 34.288988317762104, 37.62153891154698, 39.24820252827236, 40.18209947858538, 40.89396326882498, 41.73494890757969, 37.961180755070274, 34.68501826695034, 33.88302591868809, 35.37432125636509, 34.83003759384155, 36.57165220805577, 37.600013392312185, 37.482481139046804, 33.68417542321341, 34.53520815713065, 34.39316265923636, 36.20738247462681, 34.05179418836321, 34.70399727140154, 35.15722131729126, 34.518577643803184, 34.09320892606463, 35.696741989680696, 35.37795863832746, 35.36863415581839, 33.45139339991978, 33.5142502784729, 35.11471571241106, 34.668603147779194, 34.08749750682286, 34.829353196280344, 39.06317547389439, 42.70048795427595, 45.29960754939488, 48.561710357666016, 45.47854798180716, 46.54310580662319, 46.72582605906895, 47.43493141446795, 48.009491852351594, 48.30604791641235, 49.32173211233956, 51.87251308986119, 51.2420266015189, 50.10344614301409, 33.66637413842337, 17.9791829926627, 21.162121500287736, 16.023133073534282, 3.1234634476048604, 2.5108759530953, 1.1112423368862696, 0.06660876329988241, 0.06857958183224712, 1.6726766505411692, 19.54767107963562, 44.84263495036534, 59.09362302507673, 43.97609036309378, 23.504482575825282, 27.450838770185197, 40.209193978990825, 46.22997828892299, 27.02031970024109, 1.1652205032961709, 0.018861080153978298, 0.030280558192836385, 0.020776279170864394, 0.024904313197891628, 0.08743442116039139, 0.0128129107678043, 0.016509031810398613, 0.016606617020443082, 0.025592719204723835, 0.051198449318430254, 0.042525214542235644, 0.05988471196698291, 0.019415460227589523, 0.03543925977178982, 0.023965481968064393, 0.03672814043238759, 0.04940544767305255, 0.08686829225293227, 0.03390264936855861, 0.054834121372550726, 0.03628611218716417, 0.023733653693592975, 0.0360442687358175, 0.043266117107123137, 0.04513209519375648, 0.046538688109389374, 0.02186574856750667, 0.00913351052440703, 0.02621879837741809, 0.041274800031845055, 0.03506261855363846, 0.060217119487268586, 0.28268417556371006, 15.255866084780012, 44.034851278577534, 48.91269513538906, 49.112827573503765, 37.182881764003206, 24.755550895418438, 22.644186156136648, 34.9143956729344, 36.531220640454976, 7.922551427568708, 0.12426181430263178, 5.399239718914032, 5.4813452788761685, 1.8176184615918567, 7.675761835915702, 6.685121119022369, 6.554636555058615, 13.834420987537928, 46.07176433290754, 52.147571427481516, 52.694168840135845, 48.89901760646275, 49.26263420922415, 46.566545554569785, 46.60698407036917, 49.7540351322719, 50.873803343091694, 49.71979093551636, 47.67101730619158, 47.49352557318551, 45.28284502029419, 45.494459356580464, 47.09334407533918, 48.13611234937395, 45.65194027764456, 44.424961362566265, 40.47438587461199, 36.72877529689244, 36.39196831839425, 38.638202803475515, 38.81641714913504, 39.37901626314436, 37.44594056265694, 34.55019889559065, 37.24741663251604, 36.3046989440918, 38.514969553266255, 34.72810752051217, 34.17378371102469, 35.400700092315674, 34.936209542410715, 36.88076714106968, 34.43182938439505, 35.00781420298985, 34.36832284927368, 37.28425598144531, 46.90630899156843, 48.39675317491804, 47.88650873729161, 44.821908473968506, 42.031876700265066, 44.87195634841919, 46.450215339660645, 48.89765575953892, 46.34361260277884, 47.23565360477993, 43.05365794045584, 45.83677625656128, 40.11430590493338, 44.36054113933018, 29.143513747623988, 25.966689654758998, 53.74286045346941, 44.43397317613874, 48.43845278876168, 40.00443751471383, 38.713656766074045, 37.1319306237357, 39.59934711456299, 39.99519293648856, 43.15853752408709, 43.81986359187535, 44.4701246534075, 40.382138116019114, 37.26137556348528, 35.889040333884104, 36.23336178915841, 36.49456541878836, 37.726025921957834, 38.23928935187203, 39.32039431163243, 35.619009017944336, 36.261599268232075, 35.69141272136143, 37.33842066356114, 35.94372960499355, 37.14067145756313, 36.720955099378315, 35.20066492898123, 35.94726276397705, 37.097300801958355, 37.371004240853445, 36.56279672895159, 34.976905141557964, 35.056861536843435, 36.975901876177105, 35.8708291053772, 36.04190765108381, 37.28025034495762, 41.06941570554461, 45.02194363730294, 46.240063599177766, 48.721473761967246, 47.29588406426566, 47.665354524339946, 47.96920272282192, 49.28398949759347, 50.53015586308071, 49.71415942055838, 51.268870966775076, 53.244764941079275, 53.42164175851004, 50.71618693215506, 36.661982263837544, 17.505105665751866, 13.459401522363935, 13.125507576125008, 8.170581272670201, 4.796775749751499, 2.1284308178084235, 0.28241574711033274, 0.08681419265589543, 2.0693706955228532, 20.598429782049998, 44.43317413330078, 61.25024659293038, 47.32257904325213, 30.46952533721924, 32.015885148729595, 44.80981513432094, 51.66081884929112, 32.59406559807913, 1.8175160842282432, 0.03795366288561906, 0.018453955750114152, 0.013386654534510203, 0.03241591468187315, 0.05691779724189213, 0.05530606622674635, 0.057822284421750476, 0.016288085541288768, 0.018107114093644277, 0.04222066088446549, 0.0037114996147075935, 0.07401078646736485, 0.047182509276483736, 0.0590699203312397, 0.06028464050697429, 0.030021564768893377, 0.14339487334447248, 0.22990204926048005, 0.12785999051162175, 0.16529835015535355, 0.17978888617030211, 0.08210329365517412, 0.09135025353836161, 0.09554039048297064, 0.17835050049637044, 0.09756482006715876, 0.26899636004652294, 0.06956760345825128, 0.11089434195309877, 0.1408285724797419, 0.14780461814786705, 0.16985005805534975, 0.9166948390858514, 19.318255458559307, 53.39136150905064, 53.151905741010395, 56.38397148677281, 42.70249250956944, 34.833786146981375, 31.924415588378906, 47.649505683353965, 42.003361293247764, 9.97869622707367, 0.267249268080507, 7.2301812427384515, 8.664419276373726, 5.07136595249176, 10.321805221693856, 14.377022317477635, 12.45811312539237, 16.6730032988957, 48.967075211661204, 52.48886694226946, 56.18014260700771, 50.344149112701416, 52.6203407560076, 48.67444140570504, 50.882516384124756, 52.140623228890554, 54.67190408706665, 50.31514038358416, 48.00646243776594, 48.124220507485525, 45.728287083762034, 45.920595850263325, 46.32154859815325, 50.21508632387434, 48.37780543736049, 46.313749245234895, 43.69566454206194, 38.38633755275181, 38.88071925299508, 40.67749908992222, 41.0446766444615, 41.01525797162737, 40.46143095833914, 36.591989585331504, 40.092280115400044, 37.80770199639456, 38.68743773869106, 36.44572653089251, 35.85841614859444, 35.71118034635271, 36.70353943961007, 38.5934077671596, 35.99108852658953, 37.72609887804304, 36.2126908983503, 38.03943484170096, 49.29089253289359, 51.56959247589111, 49.741740294865195, 47.58240692956107, 44.145108767918174, 46.97261217662266, 47.00331974029541, 51.27700730732509, 48.22879089627947, 48.85495213099888, 43.60091543197632, 45.52101189749581, 41.23342793328421, 45.34629944392613, 31.08547272000994, 28.435306446892874, 54.68365001678467, 47.200784070151194, 50.613263266427175, 43.090886388506206, 41.04876218523298, 37.72959382193429, 40.71530423845564, 42.68075507027762, 43.66474505833217, 45.038480349949424, 44.93657806941441, 42.71408905301775, 39.15579496111189, 37.32611540385655, 37.43070663724627, 38.483094692230225, 39.43989290509905, 40.12798343385969, 40.77770948410034, 37.50622313363211, 37.470297472817556, 38.07853930337088, 39.26545490537371, 36.96677541732788, 38.83294691358294, 39.17282152175903, 38.343977860042024, 37.752995354788645, 40.01988683428083, 38.11293288639614, 38.40958969933646, 37.036240032741, 37.645239216940745, 39.641859667641775, 38.890193121773855, 38.61521468843733, 39.676399162837434, 45.34759528296334, 47.18301405225481, 48.864568437848774, 50.583993979862754, 49.03869029453823, 50.15621076311384, 49.989099638802664, 50.53944213049752, 52.52547352654593, 52.595236914498464, 52.82676478794643, 58.18579224177769, 56.46341718946184, 54.385360377175466, 38.27616344179426, 20.63728063447135, 27.884593963623047, 27.149288688387188, 6.896444499492645, 4.5617490240505765, 4.22812214919499, 0.28040139377117157, 0.16157953042004788, 2.4747340295995985, 27.40089511871338, 55.30836602619716, 65.20840603964669, 53.817115851810996, 34.834428855351035, 39.514509609767366, 54.05905212674822, 57.472312995365684, 40.388328960963655, 2.7700804557119096, 0.08712181329194989, 0.0990994084360344, 0.06558294048798935, 0.1430002645190273, 0.16691273424242223, 0.16057812129812582, 0.16820231718676432, 0.1559121616716896, 0.09576153861624853, 0.17765391644622597, 0.1350408044776746, 0.13696114000465187, 0.11990738367395741, 0.1061153451779059, 0.1233471626681941, 0.07627099339983293], [0.05292097831677113, 0.03237028998721923, 0.05101013210202966, 0.03054685943893024, 0.05296707120058792, 0.024157548090443015, 0.04608672611149294, 0.013095421367324889, 0.08235771714576653, 0.050558458481516154, 0.03503270194466625, 0.021712482773831913, 0.022359426898349608, 0.03191839584282466, 0.00760521217515426, 0.032180222150470526, 0.5749242955020496, 9.739382028579712, 37.44273049490792, 43.14132683617728, 37.13995579310826, 24.037419830049785, 18.87677560533796, 23.479147706712993, 32.42390421458653, 29.122995717184885, 4.689129480293818, 0.3062392473220825, 12.581905705588204, 25.94934868812561, 8.653546214103699, 4.79697551046099, 4.500181904860905, 5.224587193557194, 17.956385953085764, 42.14278037207467, 53.442955357687815, 47.39237022399902, 49.15324871880667, 46.268259389059885, 47.629560879298616, 48.670939513615195, 49.0023581641061, 46.839238030569895, 45.62364373888288, 44.82170350211007, 44.683760915483745, 45.42200354167393, 46.26288148335048, 43.28362594332014, 45.102136271340505, 46.02511412756783, 45.3833680834089, 42.576177733285085, 35.794815812792095, 33.452873366219656, 34.61881235667637, 38.10802745819092, 38.260741915021626, 39.40732669830322, 35.3939916065761, 34.20279591424124, 33.72074726649693, 34.238144874572754, 34.661477770124165, 34.23529611315046, 35.60364307676043, 32.79187733786446, 33.53241981778826, 32.81721741812569, 33.92055661337716, 34.03300278527396, 34.16613027027675, 35.32352992466518, 39.675579275403706, 38.50910527365548, 36.556112561907085, 39.20025995799473, 42.53732688086373, 45.14678886958531, 47.110926491873606, 44.42944989885603, 44.12578930173601, 41.164230823516846, 43.650657585689, 41.36521094185965, 43.56645236696516, 28.11818892615182, 22.31383752822876, 50.713379859924316, 41.59894486836025, 46.60669224602835, 43.17387567247663, 37.50179018293108, 33.91055815560477, 36.098156792776926, 32.6325238772801, 36.57095391409737, 33.79541955675398, 34.24891805648804, 33.9661819594247, 36.16668340138027, 34.891866139003206, 35.40411513192313, 33.62266649518694, 35.564906869615825, 38.25559677396502, 42.53164325441633, 36.00476952961513, 35.14730623790196, 33.25337668827602, 37.55437414986746, 34.31945616858346, 34.56440448760986, 35.23757723399571, 34.31429713112967, 37.059572083609446, 35.9459947177342, 33.743613788059776, 35.18489946637835, 35.20052249091012, 34.90964657919747, 33.65447882243565, 34.49495376859392, 34.0756265095302, 35.52797719410488, 40.36133173533848, 43.932688440595356, 45.087635380881174, 46.97782332556588, 45.11830472946167, 45.12792798451015, 46.8355450630188, 48.72040721348354, 47.407677105494905, 46.74410676956177, 45.408218315669465, 47.849214281354634, 49.19831473486764, 52.83277497972761, 42.47090557643345, 22.02461528778076, 10.396034564290728, 6.050209062440055, 13.819221803120204, 8.238579818180629, 1.6250341555901935, 0.1410927397332021, 0.07120714083846126, 0.7405164241790771, 18.25487882750375, 46.52561719076974, 63.77973828996931, 39.98350954055786, 19.13024936403547, 33.61783749716622, 42.942688260759624, 48.061655453273225, 33.897419112069265, 2.139471939631871, 0.07342303943421159, 0.025869257847911546, 0.04956852677943451, 0.03000573454690831, 0.04280811954023583, 0.0599863293713757, 0.01394448071784739, 0.053048257915569205, 0.043993370940110514, 0.021495896092216884, 0.02850753261840769, 0.08292801904359035, 0.08123416493513755, 0.023317177380834306, 0.03563773126474448, 0.06486962376428501, 0.1497603189200163, 0.021828785372365798, 0.041209681026105366, 0.044006541304822476, 0.059134510079664845, 0.07327509844409567, 0.0206935674484287, 0.0439251001392092, 0.07038962149194308, 0.059927412175706456, 0.017251640890858004, 0.020860315732924, 0.039282892631100755, 0.022506056619541984, 0.07324423188609736, 0.05293258126559002, 0.9048411580068725, 13.451679468154907, 45.86261313302176, 47.2644921030317, 43.78057500294277, 30.22381271634783, 26.34900212287903, 27.394985675811768, 36.62485456466675, 32.54842982973371, 5.517052071435111, 0.27894129497664316, 15.30181452206203, 25.19059497969491, 9.997954027993337, 9.672928588730947, 10.485647218567983, 12.005414537021093, 19.213174377168926, 45.70143229620797, 53.907953126089915, 50.092989104134695, 49.27207681110927, 48.704589639391216, 47.841539996010916, 50.253662722451345, 50.62678793498448, 48.28924022402082, 44.99406746455601, 45.243858678000315, 46.432935169764924, 44.80632366452898, 45.238678795950754, 45.36542088644845, 46.640609877450125, 47.85426214763096, 47.0394503729684, 44.38273368562971, 36.42835603441511, 35.773540428706575, 36.69971793038504, 38.379396302359446, 40.983198983328684, 40.74426780428205, 37.24158361979893, 36.776005676814485, 34.57313142504011, 35.80155209132603, 36.45573541096279, 35.94434799466814, 36.457746914454866, 35.37853533881051, 35.18459721973964, 34.17587511880057, 36.32783644539969, 35.81131083624703, 36.02270630427769, 37.85804864338466, 42.391991410936626, 41.43289334433419, 39.99738161904471, 39.74480765206473, 44.7698004586356, 47.740693841661724, 49.719804831913535, 46.847332681928364, 44.998573371342246, 41.89503192901611, 43.156050068991526, 40.194984912872314, 43.33751269749233, 30.259481293814524, 23.694333417075022, 51.63390152794974, 43.89915643419538, 47.71225486482893, 45.10246283667428, 39.36774281093052, 34.66896445410592, 37.165209020887104, 34.385474477495464, 37.41855076381138, 35.79625756399972, 37.34595945903233, 35.91776418685913, 36.60832480021885, 35.96212496076311, 36.58995028904506, 35.95374195916312, 37.3585079056876, 39.394079957689556, 43.11836651393345, 36.90673950740269, 37.56812810897827, 34.70257983888899, 37.96034697123936, 35.73087501525879, 35.811727728162495, 35.43983234677996, 36.53108515058245, 37.2486777305603, 37.94648878914969, 36.60884244101388, 37.46332148143223, 37.66821343558175, 36.98701899392264, 36.102777344839915, 36.46907247815813, 35.50765371322632, 37.40090581348964, 42.87366138185774, 46.02988406590053, 46.50085728509085, 48.05516236168997, 47.23318352018084, 46.647624083927695, 47.68179743630545, 49.67214366367885, 48.60198906489781, 48.81237357003348, 47.280500752585276, 50.11211402075631, 51.330456324986045, 54.561108112335205, 44.906117166791645, 22.307108197893413, 12.34171255997249, 7.939960139138358, 12.21358517238072, 4.76043667112078, 2.297328063419887, 0.5427421395267759, 0.09732138205851827, 0.661181349839483, 20.466554709843226, 48.665787424360005, 63.8159453528268, 48.862251213618684, 25.612196036747523, 38.82181242534092, 48.904357297079905, 53.94029699053083, 40.730461733681814, 3.583879747561046, 0.029783215772892748, 0.07494236755051784, 0.02474278284768973, 0.052146267744579484, 0.03518703134198274, 0.029723375769598142, 0.026922783548278467, 0.027483592741191387, 0.08547779758061681, 0.013464496920018323, 0.04464840489838805, 0.055594881264758964, 0.022366397149328674, 0.01282413543335029, 0.0852246293798089, 0.018019116583413312, 0.20592688290136202, 0.10652040344263826, 0.18688890018633433, 0.08763186128011771, 0.10064317738371235, 0.14285329383398804, 0.11943786458245345, 0.13487859389611653, 0.2766013262527329, 0.1286202890000173, 0.11748071174536433, 0.06342285139752285, 0.1184885533792632, 0.17635942090834889, 0.1547360433531659, 0.1996795702725649, 1.1450793040650231, 17.405449390411377, 51.77897296633039, 53.2917069707598, 49.940590790339876, 34.90382398877825, 29.61598082951137, 33.75045428957258, 43.39325114658901, 38.01124947411673, 6.210368948323386, 0.31024423241615295, 13.472589203289576, 30.72024760927473, 19.373094115938457, 13.026844024658203, 12.61964397771018, 9.534736735480172, 21.563312223979406, 46.211711474827354, 58.738604818071636, 50.705111503601074, 53.21404348100935, 51.04723385402134, 49.97993843896048, 53.34587860107422, 51.903519426073345, 48.15332651138306, 47.10484334400722, 45.61249188014439, 46.42539984839303, 44.94057328360421, 45.91775056294033, 45.35939679827009, 47.45375061035156, 50.10516234806606, 50.60785756792341, 46.0976185798645, 39.06048999513899, 37.38746452331543, 39.90374422073364, 40.90959324155535, 42.781691551208496, 43.460648672921316, 38.09929357256208, 38.31159578050886, 37.653024673461914, 37.77675471987043, 38.591055801936555, 38.06011268070766, 39.600264276777, 36.18351193836757, 36.68890305927822, 36.35466691425869, 38.2762885093689, 37.76050288336617, 38.09618425369263, 37.82536431721279, 42.90094000952584, 42.27915266581944, 40.85654027121407, 41.79634666442871, 46.16153505870274, 48.46244839259556, 50.16159561702183, 47.45084626334054, 46.13354424067906, 42.523319312504356, 44.061313492911204, 42.84359652655465, 43.76039048603603, 32.30863012586321, 27.317473309380667, 51.16630513327462, 45.29447283063616, 48.915109634399414, 47.936646938323975, 41.01182556152344, 37.342620849609375, 39.081428391592844, 35.52547236851284, 40.1537195614406, 37.172094685690745, 37.8633987562997, 38.24535165514265, 39.01844644546509, 38.70373126438686, 39.82919004985264, 37.60506125858852, 38.38118893759591, 41.254286425454275, 44.75850963592529, 39.185092040470664, 38.98087058748518, 36.74341515132359, 40.76031814302717, 38.55412265232631, 37.22051668167114, 37.634921142033164, 37.99409089769636, 40.60214935030256, 40.16543075016567, 38.233265263693674, 39.24595826012747, 39.95005396434239, 38.98213863372803, 38.74251958302089, 39.4400110244751, 38.12737124306815, 38.170099190303254, 46.13246726989746, 48.10390050070626, 47.819920676095144, 50.32424252373831, 48.815493311200825, 48.18750122615269, 48.00690712247576, 53.10356364931379, 49.43949365615845, 50.5977965763637, 49.77206570761544, 51.939174107142854, 54.56977946417672, 56.511147839682444, 48.37901094981602, 25.467798573630198, 14.788915872573853, 11.297673634120397, 23.886117594582693, 15.785732235227313, 4.0892354760851175, 0.6633178666234016, 0.2755830351795469, 0.9768144530909402, 25.935841390064784, 55.54494176592146, 66.61529813494, 49.45214632579258, 29.622880390712194, 44.85582957948957, 55.73628125871931, 60.51303577423096, 48.53721448353359, 5.420867724078042, 0.1389911946441446, 0.16093739201979979, 0.17767630810184137, 0.1366643759288958, 0.06923613231629133, 0.2760545898761068, 0.1069962125537651, 0.11871776250856263, 0.25166030600667, 0.08950104205203907, 0.157343843419637, 0.17019627376326493, 0.15230300676609787, 0.12776369282177516, 0.12812966746943338, 0.15805454099816935], [0.029271254315972328, 0.02755368880129286, 0.04628453264012933, 0.027937541150354912, 0.03759544728589909, 0.03759718094287174, 0.015723283169791102, 0.03305617693279471, 0.022678638608860116, 0.022482562344521284, 0.026207756916327134, 0.049825664410101514, 0.049970596097409725, 0.045929757212953906, 0.017528072664780275, 0.07464780871357236, 0.26743689658386366, 9.039302383150373, 35.14695535387312, 42.88061652864729, 35.95504822049822, 22.477342537471227, 15.177337544304983, 23.945220708847046, 34.958520208086284, 26.13062024116516, 2.7864877581596375, 0.09557386940079075, 2.228386951344354, 7.184587163584573, 5.445722733225141, 9.327238338334219, 9.628826635224478, 14.76570541518075, 22.265950543539866, 48.16396767752511, 51.0671751839774, 50.49967064176287, 49.96415213176182, 49.699154785701204, 46.933205468314036, 45.445366859436035, 47.754989760262625, 45.42101342337472, 45.4830504144941, 45.57219927651541, 43.92744255065918, 45.33366067068917, 46.46443830217634, 47.5381885937282, 47.03438861029488, 42.93099791663033, 46.47995710372925, 44.113108839307515, 35.32565259933472, 33.00330407278878, 37.58426182610648, 37.38255909511021, 40.51681852340698, 41.25579765864781, 38.82476193564278, 35.957042353493826, 33.6806492124285, 32.76176037107195, 34.01851231711251, 33.70756653376988, 33.6877190044948, 31.919194017137798, 33.84637417112078, 33.21945210865566, 33.276788643428254, 32.7358192716326, 33.22923864637102, 33.84637417112078, 32.954593726566856, 34.291621685028076, 35.28619725363595, 39.459851605551584, 45.82291112627302, 48.595228467668804, 47.86078303200858, 43.284188747406006, 43.63420425142561, 42.08279309953962, 42.24594375065395, 41.03859697069441, 43.55341059820992, 31.12534495762416, 23.19164514541626, 48.85725893293108, 41.24478128978184, 47.90763126100813, 43.24831172398159, 39.20421348299299, 33.52951547077724, 36.03088780811855, 32.89390121187483, 32.41335684912545, 31.03774901798793, 34.22702080862862, 34.338560240609304, 36.030943393707275, 33.21139219829014, 35.596625396183555, 33.412559917994905, 35.87892375673567, 33.351120471954346, 37.69756957462856, 35.587672642299104, 35.535863399505615, 34.288772923605784, 34.426885741097585, 33.39394916806902, 33.305894647325786, 34.79916327340262, 34.67149012429373, 34.73929064614432, 34.155575956617085, 34.84313494818551, 38.33162743704659, 37.8336569922311, 34.721503257751465, 34.26059797831944, 31.96781403677804, 33.9638022014073, 37.24594014031546, 40.71374436787197, 43.191114153180806, 45.045967033931184, 47.40497078214373, 45.93139682497297, 45.279694012233186, 45.61822761808123, 49.495881761823384, 47.074549198150635, 43.26308706828526, 45.15659972599575, 44.87074736186436, 49.867033685956685, 49.106730529240195, 48.87669651848929, 27.411107233592443, 16.124031339372905, 10.596897431782313, 9.673444492476326, 3.800989023276738, 1.878069417817252, 0.3402269849819796, 0.03346426146371024, 0.19500655388193472, 10.913807375090462, 45.25690739495413, 40.49656105041504, 22.953983749662125, 17.603797878537858, 28.080340351377213, 36.90582581928798, 43.13907561983381, 35.37143775394985, 4.584428812776293, 0.049172320004020414, 0.018379281274974346, 0.019660038175061345, 0.009985638549551368, 0.02942911209538579, 0.04793214797973633, 0.03451183471562607, 0.014747599006763526, 0.024490951360868554, 0.042128108707921844, 0.038199370593896935, 0.025021000865048597, 0.13061512767204217, 0.03136409040806549, 0.04421985235863498, 0.02890240607251014, 0.014115713270647185, 0.037563739344477654, 0.0077972443707819495, 0.009850707620249262, 0.026563919947615693, 0.04545889462211302, 0.041020939725318124, 0.03614565543830395, 0.03041340856413756, 0.02145014756492206, 0.0433071515123759, 0.03612994395994714, 0.008694577247037419, 0.023531202592753937, 0.03514108095051987, 0.04841589595058134, 0.5930305953536714, 11.867993933813912, 41.60995428902762, 47.88613700866699, 42.06270238331386, 25.369822025299072, 21.28763028553554, 28.77846929005214, 38.03893109730312, 30.398320198059082, 3.283055318253381, 0.1082552003541163, 2.450270725148065, 9.371426275798253, 3.8532320942197527, 8.18291085106986, 12.119649001530238, 12.596073951039996, 20.85472972052438, 50.42179523195539, 51.89760998317173, 52.29817015784127, 50.36590739658901, 51.05419594900948, 48.88740021841866, 47.41262769699097, 47.06902190617153, 45.628514426095144, 46.09098652430943, 46.52155944279262, 44.920513834272114, 46.18818834849766, 47.18618243081229, 46.93186099188668, 46.559239523751394, 45.296123027801514, 48.72375624520438, 45.77766445704869, 37.966371059417725, 34.76104198183332, 38.04247120448521, 38.533646311078755, 42.10651077542986, 43.28616203580584, 40.51330968311855, 37.44592319216047, 35.832384722573416, 34.86250305175781, 36.392687456948416, 34.98484345844814, 35.1119190624782, 34.74771533693586, 34.72676999228341, 35.03422430583409, 35.18126903261457, 35.11941269465855, 35.285835947309224, 35.93465873173305, 35.38040440423148, 37.6514231136867, 38.44862467902047, 41.2767082623073, 48.091008118220735, 49.160214287894114, 47.53794888087681, 44.10318333762032, 45.56665808813912, 44.034757477896555, 42.20577621459961, 41.71938494273594, 43.99963780811855, 31.87824480874198, 24.8780927998679, 49.103711536952424, 43.74034145900181, 50.98113564082554, 46.53769663402012, 41.682170391082764, 35.00783504758562, 37.6717118535723, 36.305984360831125, 34.21949243545532, 34.013262953077046, 35.87699563162667, 36.409918989454, 36.56999158859253, 35.15340328216553, 37.15801763534546, 35.594544410705566, 37.465878418513704, 34.256498541150776, 39.515847137996126, 36.349657263074604, 35.78942401068551, 36.145498343876426, 36.16535976954869, 35.2479578426906, 35.10516888754708, 36.55179425648281, 36.81623574665615, 36.14491816929409, 34.75069611413138, 36.74045869282314, 39.02546412604195, 40.372257777622764, 37.44932780947004, 36.53303064618792, 34.94824034827096, 34.8286132131304, 40.13054037094116, 43.84298719678606, 44.889521394457134, 47.263185841696604, 48.471241337912424, 47.10180698122297, 48.00749771935599, 47.2153058052063, 50.5200149672372, 50.15856967653547, 45.65619952338082, 47.37246363503592, 46.73950706209455, 50.63985749653408, 51.1961476462228, 50.76237160818917, 28.072605269295828, 13.05024208341326, 8.315573675291878, 8.33473333290645, 7.153428401265826, 2.861483573913574, 0.4216652736067772, 0.10179537055747849, 0.1440316377473729, 13.363690086773463, 48.512221813201904, 44.5505222593035, 32.68916211809431, 23.15471546990531, 32.17235858099801, 42.718233653477256, 48.81248126711164, 41.73590428488595, 6.021377078124455, 0.06482034855123077, 0.018315051150109087, 0.004192637770237135, 0.02610558141688151, 0.05833987093397549, 0.02909474021622113, 0.0076074640632474, 0.022196990703897815, 0.02738376327657274, 0.0018460658403845237, 0.06169665152473109, 0.03238261557583298, 0.07246186743889536, 0.026930981947641288, 0.0520342585763761, 0.04992602313203471, 0.16926795643355164, 0.08625884566988264, 0.12758792511054448, 0.10382731152432305, 0.1252633048487561, 0.14354677019374712, 0.09386943693139724, 0.13914575135069235, 0.17561745643615723, 0.07695395246680294, 0.10186808915542704, 0.16850407528025763, 0.09073579258152417, 0.20167636312544346, 0.1322829531771796, 0.22234774247876235, 1.1285644131047385, 15.710451977593557, 50.33926452909197, 52.932961055210654, 47.92236839021955, 30.942093167986187, 26.04642023359026, 36.07724618911743, 46.09236921582903, 34.90281302588326, 3.926518653120313, 0.1502530574798584, 3.194867044687271, 11.930261084011622, 9.940255318369184, 17.44683459826878, 15.021491186959402, 17.892097745622905, 25.615119491304668, 51.133183070591514, 54.90462705067226, 53.32825102124895, 53.361661434173584, 51.45323099408831, 50.42803471429007, 47.32480594090053, 48.77714620317732, 46.517762252262656, 47.63880893162319, 48.32179600851876, 46.27829258782523, 47.49942806788853, 48.19992113113403, 47.879706450871055, 49.13243538992745, 49.102238518851145, 50.669154575892854, 48.78426810673305, 40.72054318019322, 36.87262037822178, 41.3322799546378, 41.31590305055891, 45.351552282060894, 45.992540972573416, 43.20337772369385, 39.134397983551025, 37.52928073065621, 37.05946438653128, 38.182244641440256, 37.23948526382446, 37.69836514336722, 35.121861934661865, 37.191421100071494, 36.14615842274257, 36.99262271608625, 36.247782775333945, 37.2462215423584, 38.12476566859654, 36.53175217764718, 40.38478537968227, 39.224950381687705, 43.50351211002895, 51.05222266060965, 50.37961966650826, 49.00362968444824, 44.2791360446385, 46.608366761888774, 45.678920132773264, 43.085421630314414, 42.78767742429461, 42.79441717692784, 33.500395570482524, 28.536392314093455, 48.21260159356253, 45.0727801322937, 52.05242279597691, 48.403291429792134, 42.15476254054478, 36.43786464418684, 40.06315674100603, 37.273753779275076, 34.76258100782122, 35.847740241459434, 37.133702414376394, 38.71162094388689, 39.78029210226876, 36.790944303785054, 40.50746624810355, 36.62749488013131, 39.1193516595023, 35.059015478406636, 41.405645983559744, 38.49389566693987, 37.84488180705479, 38.65109518596104, 37.9086662701198, 38.19971588679722, 36.67318623406546, 38.861156599862234, 37.866890226091655, 37.83537319728306, 36.64924274172102, 39.14967359815325, 40.702352796282085, 42.59225239072527, 39.0145971434457, 37.799676827022004, 37.02781186785017, 37.96274757385254, 42.458148683820454, 46.110757623400005, 46.82938895906721, 48.33135672977993, 51.448263032095774, 49.35325608934675, 48.208248547145296, 47.42818818773542, 51.67522593906948, 52.9355388368879, 47.500977516174316, 49.6385942867824, 48.689703123910085, 53.95420381001064, 51.81551354272025, 54.975484779902864, 31.22231749125889, 23.289298602512904, 20.670619828360422, 17.83484980038234, 12.495109677314758, 6.736303286893027, 0.6508710916553224, 0.24788290155785425, 0.3265321398419993, 15.099462134497506, 55.88119983673096, 46.38097306660244, 32.189395563943044, 26.96242036138262, 39.56850406101772, 49.07336180550711, 55.40411220278059, 49.19156803403582, 8.846238868577139, 0.13951429086072104, 0.11100792192987033, 0.10357052673186574, 0.06262369999395949, 0.1486286310745137, 0.11155729102236883, 0.11274577224893229, 0.1481605369065489, 0.08099480492195912, 0.11503326307450022, 0.11875778250396252, 0.1150628472013133, 0.19607507011720113, 0.14398088332797798, 0.15895604262394564, 0.08532228413969278], [0.09285165475947516, 0.03411099015335951, 0.044463341257401874, 0.014866325671651533, 0.012266623920628002, 0.01664500853179821, 0.060435410988117964, 0.0459989406434553, 0.02875411563685962, 0.03501735008986933, 0.006895686341782233, 0.05341149128175207, 0.03692603177790131, 0.012257572263479233, 0.023852940149871365, 0.03183786730681147, 0.8208034017256328, 15.167052473340716, 41.845949854169575, 42.47600555419922, 36.96990558079311, 29.35792473384312, 13.894437789916992, 20.427735124315532, 31.423915999276296, 22.523721763065883, 1.334158786705562, 0.028156244861228124, 0.29493922367691994, 0.13273979723453522, 3.605936803988048, 5.395717850753239, 14.094638841492788, 22.877838441303798, 30.607683318001882, 49.03242301940918, 52.89720909936087, 47.70625856944493, 47.547540869031636, 44.02999448776245, 46.93618624550955, 46.20587498801095, 43.56365919113159, 45.84847354888916, 43.311835629599436, 44.45607539585659, 47.125152928488596, 45.68138326917376, 44.86877754756382, 44.16385153361729, 45.52665383475167, 45.02435466221401, 44.70291709899902, 41.35192251205444, 33.45855351856777, 33.991549832480295, 36.09153515951974, 38.65177958352225, 42.29806218828474, 43.71397999354771, 43.26693984440395, 41.128506660461426, 37.59647328513009, 35.14977979660034, 35.397913864680696, 34.23519536427089, 34.83694757734026, 33.54751477922712, 34.08066742760794, 33.194167613983154, 32.418241432734895, 33.77524198804583, 32.8762423651559, 33.902230739593506, 35.45627178464617, 35.5955171585083, 40.07142857142857, 43.06014060974121, 47.31080879483904, 46.57415035792759, 44.125466210501536, 42.72067594528198, 45.15081187656948, 40.277967248644146, 40.604390144348145, 40.141973631722585, 44.43664475849697, 34.11194126946585, 24.29025435447693, 46.19301387241909, 41.68192720413208, 47.99308368137905, 43.210457938058035, 43.38317625863211, 35.15566839490618, 36.007514068058555, 34.67423118863787, 32.90532752445766, 31.1419164112636, 32.74890272957938, 34.09441096442086, 36.23406703131539, 35.92464290346418, 35.3846184866769, 34.97462613242013, 35.121003832135884, 35.02083512714931, 33.86892107554844, 35.32318251473563, 35.4934481212071, 34.718466894967214, 37.01091384887695, 35.92936767850603, 35.1125339780535, 34.76295273644583, 35.720049721854075, 33.787800856998985, 37.02114854540144, 39.19076871871948, 41.1306779725211, 39.61154120309012, 37.65337903159005, 36.568202427455354, 35.097689151763916, 36.297184467315674, 37.775966099330354, 40.43873119354248, 43.44946902138846, 44.03844697134835, 47.496836389814106, 47.770185470581055, 43.51587642942156, 46.62606382369995, 47.69952923910958, 51.337592124938965, 45.831488677433555, 41.59669017791748, 47.00385822568621, 49.69888033185686, 51.872777121407644, 52.013564995356965, 32.67466122763497, 15.719625336783272, 4.8885631901877264, 6.947395205497742, 2.1459381069455827, 1.657615995832852, 0.5458916819521359, 0.04594325327447482, 0.051160135838602266, 7.08490526676178, 39.584853172302246, 39.844698429107666, 25.900692190442765, 29.720120429992676, 31.55555656978062, 43.754210063389365, 47.66569151197161, 38.92995071411133, 5.901733006749835, 0.16844904609024525, 0.02423710801771709, 0.11052652169018984, 0.04355248263371842, 0.06896611609097038, 0.00938535643009735, 0.021601572832358733, 0.011420642574583846, 0.012650032677421612, 0.0214204328201179, 0.016796153903539692, 0.036488132418266365, 0.05153489751475198, 0.015618790473256792, 0.062384706389691146, 0.011360816141989614, 0.02956348577780383, 0.030680442628051554, 0.047999411156134944, 0.02127235273032316, 0.04131779879597681, 0.012447514571249485, 0.016291827661916614, 0.06293902878782578, 0.0822454806683319, 0.06714223431689398, 0.041445943526923656, 0.020740649297035167, 0.19040239522499697, 0.029287074359932115, 0.011400512985086866, 0.051192559634468386, 1.0646471743072783, 17.376253059932164, 48.87458426611764, 47.331497056143625, 41.8966578074864, 31.754257678985596, 17.88576446260725, 27.09163079942976, 37.50940540858677, 26.022237028394425, 1.769795530608722, 0.062106412037142684, 0.46907907511506763, 1.0458410062960215, 4.678160880293165, 11.340568338121686, 10.582241075379507, 13.627773744719368, 30.857721192496165, 50.31268419538225, 52.67855971200125, 48.040845598493306, 49.50191627229963, 46.43666287830898, 46.54531533377511, 46.10933671678816, 44.568893296378, 44.7023925100054, 44.4290885925293, 45.69806241989136, 47.65208346503121, 47.90309408732823, 46.68815640040806, 46.82938895906721, 47.053367614746094, 46.81497144699097, 46.33638647624424, 44.74191038949149, 36.2981606892177, 35.431372914995464, 38.736533709934776, 41.80659873144967, 44.523611886160715, 45.95606640407017, 45.81770692552839, 42.88563312802996, 38.16971009118216, 36.99805620738438, 36.10487917491368, 35.995434624808176, 36.112397125789094, 34.60802527836391, 35.52646248681204, 34.66744974681309, 34.20273685455322, 34.694405283246724, 34.2083614213126, 36.12391029085432, 35.88223804746355, 36.211714676448274, 41.07801062720162, 45.67646394457136, 50.378535747528076, 48.831373419080464, 44.532210281917024, 43.56407608304705, 45.80308791569301, 42.31225388390677, 41.440633637564524, 40.784477029527935, 44.185661928994314, 34.934531552451, 26.997147457940237, 45.88343341009957, 41.98899589266096, 50.15723214830671, 44.34261131286621, 45.12182746614729, 36.09975487845284, 38.093960830143516, 35.618269034794395, 35.35270193644932, 33.64262866973877, 34.99864605494908, 36.50347648348127, 37.2538298198155, 37.58720786230904, 36.40049375806536, 35.997585092272075, 36.31859881537301, 36.28646339688982, 35.26239619936262, 36.72054862976074, 36.69382585797991, 36.471337590898784, 38.11578859601702, 36.53946120398385, 36.799313408987864, 36.3023886680603, 36.911116872514995, 35.10063171386719, 38.95136506216866, 41.74830681937081, 42.41747045516968, 40.89443227222988, 38.91854872022356, 37.86415958404541, 37.563021183013916, 38.07489149911063, 39.82752595629011, 43.26467820576259, 45.242614950452534, 45.61666079929897, 49.664222717285156, 49.2532228742327, 45.01253925051008, 47.21295383998326, 48.710092612675254, 52.11168398175921, 45.9235384123666, 44.43737779344831, 47.80586794444493, 50.98752103533064, 53.03599936621529, 53.409048148563926, 35.16156741550991, 16.634829895836965, 8.568970135280065, 10.638868025371007, 7.702773826462882, 3.5755929350852966, 1.4674305553947176, 0.08652099767433745, 0.01231307812434222, 8.516971554074969, 43.56691094807216, 43.970726353781565, 27.460126774651663, 28.174613509859356, 35.99632746832711, 49.23714126859392, 54.58479452133179, 43.57455396652222, 7.985177278518677, 0.10377389046230487, 0.026861667899148803, 0.05123522930911609, 0.05732103703277452, 0.0637637609615922, 0.011224987001956573, 0.03476277392889772, 0.015277463610150983, 0.018962510961240957, 0.007331960185963128, 0.035087846485631805, 0.025399070399414216, 0.04929133504629135, 0.06672163081488439, 0.07289912897561278, 0.05258357338607311, 0.13441932068339416, 0.11452113198382513, 0.10447447786905936, 0.1352480562137706, 0.13266196926789625, 0.11472740662949425, 0.14501612420592988, 0.13997850380837917, 0.22193002275058202, 0.13373743370175362, 0.1680595941309418, 0.11759655124374799, 0.2246211604880435, 0.10719810386321374, 0.07288935807134424, 0.13853523268231324, 1.8698036670684814, 24.86700521196638, 54.39117949349539, 52.869016783578054, 46.987853050231934, 37.95227663857596, 21.145346811839513, 30.201283182416642, 44.320130416325156, 29.803436279296875, 2.2965214209897176, 0.15541399483169827, 0.8471530335290092, 1.5402794863496507, 10.659738676888601, 15.382356303078787, 26.340216125760758, 29.136343206678117, 33.05609995978219, 52.684667178562705, 54.81662116731916, 50.41466638020107, 51.04238053730556, 46.770826067243306, 49.49100065231323, 47.05872120176043, 44.10347168786185, 46.96814101082938, 44.218849999564036, 47.96772970472063, 52.11895179748535, 48.77018410818917, 48.46108307157244, 48.63497911180769, 50.1364118712289, 48.81479501724243, 48.299565247126985, 46.0485052381243, 36.9563878604344, 37.05538579395839, 40.62592608588082, 44.62229367664882, 45.97273860658918, 48.472262723105295, 47.78002759388515, 45.14514214651925, 42.11075265066964, 39.34149251665388, 39.52940654754639, 37.357858249119346, 38.10017251968384, 36.821214130946565, 37.11468519483294, 36.733413219451904, 35.463317258017405, 36.87798091343471, 36.49538878032139, 37.065856729234966, 38.59560687201363, 38.85539654323033, 43.4510532106672, 47.622272218976704, 52.141345841544016, 49.8252090045384, 47.3246739251273, 44.58152164731707, 47.37312371390206, 43.36816120147705, 41.83926568712507, 41.486099175044465, 43.94570589065552, 35.1192945752825, 29.98974527631487, 45.45859275545393, 43.83355154309954, 52.47690561839512, 46.75012043544224, 47.73384639195034, 38.12538405827114, 40.69307000296456, 38.078490665980745, 37.6090738432748, 36.48752689361572, 37.269202709198, 39.96192496163504, 38.48751722063337, 39.67994621821812, 38.18895660127912, 38.23625298908779, 38.39129856654576, 37.54656784875052, 37.819666794368196, 38.25922720772879, 38.79215751375471, 38.36773027692522, 41.929557527814595, 39.259576729365754, 39.223915100097656, 39.68443128040859, 38.41704511642456, 37.051098755427766, 41.31876570837838, 44.092347621917725, 45.23865795135498, 43.175188882010325, 41.644424302237375, 40.84693786076137, 40.004889147622244, 40.90906865256173, 41.87517397744315, 46.068894726889475, 47.89656278065273, 47.239235401153564, 51.426508222307476, 51.85921771185738, 45.194884300231934, 47.74276787894112, 49.8664048739842, 54.367531299591064, 48.52825478145054, 46.118459701538086, 51.51053278786795, 53.86041007723127, 56.44444860730852, 55.41645915167672, 37.50028242383684, 19.88578258241926, 9.091299227305822, 18.60401017325265, 9.141197715486799, 6.348372331687382, 2.538128525018692, 0.2544062558029379, 0.20917378153119767, 10.201709951673235, 49.57658508845738, 48.31784248352051, 34.80922426496233, 40.374766077314106, 42.528586047036306, 54.723272119249614, 60.13609600067139, 51.98645659855434, 11.409960865974426, 0.20992714539170265, 0.13219196163117886, 0.2093632827912058, 0.1548528192298753, 0.22822943329811096, 0.06580720309700284, 0.11781997925468854, 0.0996515934488603, 0.0858604981164847, 0.06988829267876488, 0.07180842464523655, 0.13753847831061908, 0.16177186795643397, 0.12381734672401633, 0.1256872806698084, 0.11300256382673979], [0.051158341113477945, 0.10320772762809481, 0.05965108557471207, 0.02402730329361345, 0.058305727051837106, 0.027557748137041926, 0.016559553831549625, 0.031668416756604395, 0.07620401520814214, 0.028739825689366887, 0.028451675615672554, 0.09067269561014005, 0.013612721198504525, 0.02889715081879071, 0.07131411866950137, 0.042064021075410504, 1.963209169251578, 19.15757315499442, 36.74499934060233, 41.605080127716064, 34.00709295272827, 21.651505708694458, 16.960604872022355, 20.12093046733311, 31.87126534325736, 20.607055970600673, 0.5039476326533726, 0.5051598218934876, 1.215425580739975, 2.6194048609052385, 0.3073861343520028, 8.009170276778084, 11.216635925429207, 19.052248886653356, 30.801096848079137, 53.3463510785784, 48.28404991967337, 50.49947609220232, 45.14643451145717, 45.57607984542847, 40.37290743419102, 43.89380979537964, 43.69772468294416, 45.972679546901155, 44.071930340358186, 47.35292182649885, 42.83093343462263, 43.62393133980887, 43.261676583971294, 43.063128335135325, 44.07925374167306, 44.41361148016793, 42.07034887586321, 36.68020044054304, 33.216832637786865, 37.291259765625, 37.17231355394636, 41.672071184430806, 43.02377373831612, 45.54606710161482, 45.340414319719585, 45.15385171345302, 43.471015385219026, 39.51151841027396, 37.03911658695766, 34.16443838391985, 32.515707288469585, 32.42376872471401, 32.878420625414165, 33.42369440623692, 34.8147098677499, 32.30342245101929, 33.11591700145176, 32.99156509126936, 33.669052668980186, 35.7879753112793, 44.13741363797869, 44.23836401530674, 49.17217213766915, 42.43125568117414, 42.0499142238072, 42.089637075151714, 41.378506319863455, 43.34030934742519, 42.58735391071865, 39.38736799785069, 42.99099908556257, 35.7806692804609, 27.179581097194127, 46.076586382729666, 44.70707559585571, 45.76233673095703, 43.69542135511126, 41.18129907335554, 34.81771496364048, 37.09793308803013, 32.33857338769095, 34.40817771639143, 34.639010769980295, 36.31099053791591, 32.98754208428519, 34.35524981362479, 34.42915432793753, 36.021483421325684, 34.22808040891375, 34.971975394657676, 32.87421349116734, 34.515610763004844, 36.13300200871059, 38.369644505637034, 38.66948706763131, 40.90864481244768, 38.95126778738839, 38.208946568625315, 37.19345692225865, 37.39315162386213, 35.44318832669939, 41.123993805476594, 43.55875028882708, 43.77241086959839, 42.14554228101458, 39.47803156716483, 36.23489734104702, 35.42935446330479, 35.0176111630031, 36.94252273014614, 40.087812423706055, 40.53519650868007, 43.47490290233067, 44.4725912639073, 49.39516762324742, 48.07102509907314, 45.09536525181362, 50.76599856785366, 47.5976026398795, 44.74098627907889, 41.47071238926479, 48.334938526153564, 51.19235045569283, 51.43694789069039, 49.90620762961251, 40.40799931117466, 15.169225522450038, 10.495042051587786, 4.11745297908783, 8.16256478854588, 0.7867759019136429, 0.6934875962989671, 0.0356549931956189, 0.035578868351876736, 3.4433198613779883, 30.82515151160104, 35.63006707600185, 19.780772720064434, 16.160738672528947, 24.002821275166102, 35.66492966243199, 46.90240410396031, 36.00331040791103, 7.060632603509085, 0.15949934561337742, 0.08379530893372637, 0.05370608404544847, 0.05287865808765803, 0.013538308807515671, 0.041480959326561005, 0.04094114061444998, 0.02941892049940569, 0.034303829805659394, 0.024584830073373656, 0.05204415500962308, 0.05452487564512661, 0.026971405671377267, 0.018427138349839618, 0.06372598691710404, 0.05799995203103338, 0.042267822460936647, 0.06415811194373028, 0.015824707191703574, 0.023191746789962053, 0.030553532830838646, 0.06148535571992397, 0.019782422143699865, 0.018335600583148853, 0.02425900603910642, 0.04222336145383971, 0.0697969618652548, 0.07259602738278252, 0.06687508829470191, 0.01584348564834467, 0.08329564931669406, 0.02449714808192636, 2.403015809399741, 23.469849279948644, 44.16500493458339, 47.04367140361241, 38.804963043757844, 25.602128096989222, 15.820393323898315, 24.61198374203273, 36.06157800129482, 24.36350747517177, 0.602983509855611, 0.3367413505911827, 2.072737966264997, 3.561997264623642, 3.8788692099707465, 12.574901921408516, 8.443758385522024, 17.699507577078684, 33.55049555642264, 51.440244810921804, 49.376230307987754, 51.454544203622, 46.80496951511928, 45.48232432774135, 44.04595797402518, 43.95851836885725, 44.562956060682026, 47.48742505482265, 45.885187830243794, 49.51745244434902, 44.809078625270296, 45.535259178706575, 45.57571506500244, 44.16672461373465, 47.1672694342477, 46.77433490753174, 44.86703354971749, 39.48780768258231, 35.37697546822684, 38.044844014304026, 38.28223269326346, 42.6697039604187, 45.62698234830584, 46.91693278721401, 47.02842010770525, 46.75665174211775, 45.43021631240845, 40.936618259974885, 39.44335658209664, 36.075106143951416, 35.303970745631624, 34.51831361225673, 33.849115235464915, 34.7089513369969, 35.552754470280235, 33.79448849814278, 34.70219073976789, 34.241257667541504, 33.09245988300869, 37.01170594351632, 45.74906914574759, 46.05180215835571, 50.26903908593314, 44.78989117486136, 42.929785455976216, 43.5180790083749, 42.41423954282488, 44.05058200018746, 43.48627362932478, 40.23716395241873, 43.53654037203108, 37.4744108063834, 28.599544491086686, 46.35605682645525, 46.67709834235055, 47.24358149937221, 46.30505704879761, 42.42378984178816, 36.81146233422415, 38.78749527250017, 34.57789094107491, 35.71391446249825, 35.13289219992501, 37.35908113207136, 35.51247576304844, 36.46069642475673, 35.45072712217058, 37.58025271551949, 36.113057204655235, 36.35126577104841, 35.41822692326137, 36.89923892702375, 36.89310714176723, 39.91475016730172, 40.48553078515189, 41.76918268203735, 40.4082042830331, 39.81895187922886, 38.05655867712838, 39.681304591042654, 36.43822595051357, 42.041753564562114, 44.780573640550884, 46.49190105710711, 43.61136204855782, 42.369892665318076, 38.4648174558367, 37.13803114209856, 37.677027225494385, 39.09324380329677, 42.60857718331473, 42.03113324301583, 46.06709514345442, 47.554280621664866, 49.89850902557373, 49.03468813214983, 45.95561477116176, 51.060108866010395, 50.65249626977103, 46.13085181372506, 43.527969769069124, 49.91498320443289, 52.96445723942348, 53.29550763538906, 51.950246061597554, 40.971421786717, 16.385155064719065, 6.704995572566986, 5.798081951481955, 9.026363968849182, 6.569952121802738, 2.6524615670953477, 0.045753154903650284, 0.06790452769824437, 4.104803783552987, 35.577219077519004, 45.5108015196664, 26.850285121372767, 20.869855948856898, 29.37982198170253, 40.24839571544102, 51.741056646619526, 43.35718652180263, 9.52509524141039, 0.10451430787465402, 0.045876030810177326, 0.06346612157566206, 0.06273552256503276, 0.0639167231108461, 0.03340410594163196, 0.019386335808251585, 0.020837722213140557, 0.05158370793131845, 0.03421117245618786, 0.04353443020954728, 0.033378440354551585, 0.02368787463222231, 0.01980440498196653, 0.04456570165764008, 0.04339215159416199, 0.1331902359213148, 0.2559183846626963, 0.21165544193770203, 0.11133135921720948, 0.10974606392639023, 0.2039323699261461, 0.09774725777762276, 0.09464004236672606, 0.12587786758584635, 0.06646214545305286, 0.13002957909234933, 0.17428883058684214, 0.08800521838877882, 0.11313658127827303, 0.1748104611677783, 0.15335637809974806, 3.2459043860435486, 27.729091542107717, 51.87682792118618, 52.39932203292847, 45.88135589872088, 29.758905274527415, 25.629111426217214, 31.452514784676687, 43.10732582637242, 27.348884378160747, 0.8300683360014642, 0.6588890956980842, 3.405607427869524, 5.69222788299833, 2.684088464294161, 14.211693406105042, 20.489113773618424, 25.564203092030116, 33.37389319283621, 53.84733356748308, 50.03862987245832, 54.129475593566895, 47.34345490591866, 46.774435656411306, 43.718451159340994, 46.06193610600063, 45.0813125201634, 50.37055574144636, 46.446192332676475, 52.46780000414167, 46.054206235068186, 48.161872795649934, 49.2580692427499, 47.18835374287197, 48.3913266318185, 48.733685220990864, 45.91105944769723, 40.79140438352312, 36.539666175842285, 41.881142480032786, 40.94787086759295, 46.32079471860613, 47.51038190296718, 50.751185008457725, 49.8693265914917, 49.84426096507481, 47.40890346254621, 43.25658702850342, 42.018001147678916, 38.075072152274, 36.23877443586077, 35.85746771948678, 35.817720549447195, 37.121817520686555, 38.00160190037319, 34.93519510541643, 36.26689379555838, 36.42632021222796, 35.331826073782786, 39.781181471688406, 48.01952157701765, 47.55136237825666, 52.09427179609026, 45.93975898197719, 43.57823303767613, 42.4659480367388, 43.91627679552351, 44.63916390282767, 44.10132816859654, 41.12210736955915, 42.694773060934885, 38.38989503043038, 31.666290010724747, 45.89084018979754, 49.4213102204459, 49.710921560014995, 48.562231472560335, 45.03421415601458, 38.415321963174, 40.854289054870605, 35.927894660404746, 37.96061795098441, 38.501764501844136, 39.31083706447056, 37.61509793145316, 37.60434559413365, 37.561579431806294, 39.49848011561802, 37.123749119894846, 39.05090842928205, 37.42818096705845, 39.304357869284495, 40.043548924582346, 41.659456729888916, 41.92546156474522, 45.85099227087838, 43.145228249686106, 41.550859860011506, 41.130136013031006, 41.34421001161848, 38.74672324316842, 45.000682149614605, 46.51504898071289, 48.3924036026001, 45.96391092027937, 44.04667016438076, 40.56202350343977, 40.13652276992798, 40.29766886574881, 40.965970924922395, 44.57490348815918, 43.59751081466675, 49.07579367501395, 49.74901505878994, 53.11772755214146, 51.883744852883474, 46.218069076538086, 51.899833406720845, 52.61790541240147, 48.887935229710166, 45.333177770887104, 53.50348458971296, 55.78735746656145, 55.1532370703561, 52.847974164145334, 44.96906784602574, 18.830818482807704, 17.030609709875925, 11.081716673714773, 14.677550145557948, 7.025618893759591, 2.998320094176701, 0.20097988764090197, 0.2096467747219971, 4.785204827785492, 40.09737661906651, 47.61726951599121, 29.1894656590053, 25.005321264266968, 34.189069747924805, 48.118811334882466, 58.06614426204136, 50.47348288127354, 13.108432378087725, 0.2911522111722401, 0.2125299514404365, 0.15508892227496418, 0.11344298055129391, 0.18850339283900602, 0.11942341178655624, 0.1016510393736618, 0.1246564502694777, 0.14084309312914098, 0.15914985936667236, 0.1615226963268859, 0.1338102269385542, 0.1229519567319325, 0.13689579708235605, 0.14067823626101017, 0.17779389822057315], [0.022096881343583976, 0.035684037887092145, 0.05491750654099243, 0.010111162438988686, 0.03070064600823181, 0.049695894587785006, 0.017733404146773473, 0.029557786083647182, 0.037235440353729894, 0.07330757991543838, 0.04716422275773116, 0.02610549151099154, 0.03783609651561294, 0.02021635207347572, 0.052412012591958046, 0.05610056288008179, 0.9773644464356559, 18.510490894317627, 39.66645976475307, 41.548448835100444, 34.16326066425869, 18.669528211866105, 18.805700744901383, 27.94910625049046, 32.634045532771516, 14.090205890791756, 0.27839691990188187, 1.0116960385016032, 29.130187102726527, 11.970996635300772, 5.323338466031211, 19.107799734388077, 7.3992539303643365, 21.047142710004533, 39.60183456965855, 50.95809194019863, 48.44346243994576, 49.876215730394634, 43.98361873626709, 45.359230041503906, 43.83272818156651, 43.038069656917024, 43.96643236705235, 47.08057676042829, 45.29478897367205, 44.229595388684956, 42.18845782961164, 40.623942375183105, 40.748384611947195, 40.069271155766074, 39.54813194274902, 39.80906111853463, 36.00222648893084, 37.011824062892366, 37.584869793483186, 40.04770394733974, 40.811154638017925, 45.346417563302175, 45.516558102199006, 45.329370158059255, 44.813685280936106, 46.76342970984322, 44.688211236681255, 40.74234662737165, 37.13475506646292, 35.67446606499808, 33.34371369225638, 31.193315710340226, 32.71967165810721, 33.22377388817923, 32.524590560368125, 33.87906197139195, 32.1725183895656, 33.18128565379551, 34.713853291102815, 39.41604668753487, 44.523973192487446, 46.47602789742606, 45.88619531903948, 38.4351521219526, 43.44360474177769, 40.465582506997244, 43.079783167157856, 42.86980165754046, 41.67211982182094, 42.07467760358538, 42.77614688873291, 34.95967360905239, 26.534880331584386, 47.03586857659476, 45.25382934297834, 44.44618810926165, 39.7188526562282, 36.53080374853951, 36.453015191214426, 32.639781270708355, 31.30104058129447, 31.99293872288295, 31.813963549477712, 32.239116873059956, 34.68590416227068, 33.226640020098, 33.87768970217024, 34.52162095478603, 34.232186794281006, 33.78996522086007, 34.80572237287249, 35.71056890487671, 38.89658546447754, 41.961849280766074, 43.69742938450405, 43.74640028817313, 44.09828833171299, 43.30080883843558, 40.88107436043875, 39.76292160579136, 42.418318135397776, 45.33183329445975, 45.68663263320923, 45.50885949816023, 43.59165695735386, 40.79809202466692, 35.929103646959575, 34.63664838245937, 34.90996272223336, 36.916303702763145, 38.27208137512207, 38.10407740729195, 41.81412363052368, 46.70450551169259, 46.76626804896763, 44.51757737568447, 48.1685847554888, 50.21360288347517, 49.574927943093435, 45.09008114678519, 40.52775846208845, 45.61828667776925, 50.424171515873496, 50.44173656191145, 54.063155038016184, 44.43405655452183, 32.69083663395473, 14.092630812100001, 8.238558973584857, 8.641068986483983, 2.6092198874269212, 1.6131445935794284, 0.15287442824670247, 0.0847678328199046, 1.7624921053647995, 27.734820331845963, 36.77700274331229, 24.550855227879115, 22.19508065496172, 27.82001566886902, 38.33786344528198, 48.2134735924857, 37.34371171678816, 8.921062282153539, 0.10575279713209186, 0.029947326252503053, 0.03261789420087423, 0.03147321919511471, 0.033938065503856966, 0.05559779217998896, 0.021876901986875703, 0.02015086665882596, 0.03336886622543846, 0.03872899092467768, 0.01225769185527627, 0.03224446584603616, 0.06085295429719346, 0.05315403473962631, 0.035017733462154865, 0.023296137706243565, 0.05810531494872911, 0.02541562495753169, 0.0657044593244791, 0.03192316933668085, 0.04792586813813873, 0.05354588871289577, 0.014616007317921944, 0.016336081715832864, 0.029048223248017684, 0.024670101569167206, 0.009598214561784906, 0.06208940116422517, 0.017922720505989025, 0.10764213039406709, 0.020677740619118725, 0.04706929910129734, 1.4059500715562274, 21.429639305387223, 45.491878100803916, 46.31106376647949, 38.70573581968035, 24.198562451771327, 24.975419691630773, 33.3797470501491, 37.883861201150076, 17.024959087371826, 0.20189779624342918, 1.2057841952357973, 26.514565535954066, 12.641520380973816, 8.69983685016632, 15.031140497752599, 7.554568750517709, 22.004413400377544, 40.2959874016898, 52.9227819442749, 49.442474433353965, 51.422151701790945, 44.46220023291451, 45.45272500174386, 43.92100157056536, 45.40315307889666, 44.77753727776663, 49.643829754420686, 47.1639586176191, 46.754584653036936, 43.03758328301566, 42.67457464763096, 42.661070823669434, 43.794033663613455, 41.69143581390381, 42.409271580832346, 38.60765504837036, 39.81556463241577, 38.370433126177105, 41.1465858731951, 41.805448804582866, 46.937784331185476, 46.96444456917899, 47.626232692173545, 45.96433128629412, 47.85264321735927, 45.66226182665144, 43.60030051640102, 39.59482383728027, 36.559961863926475, 35.60770429883684, 33.52169874736241, 34.28984989438738, 34.62611838749477, 34.659091063908164, 34.77526147024972, 34.19812325068882, 33.97403342383248, 34.72678388868059, 41.36966126305716, 46.5592360496521, 47.83069038391113, 46.47907815660749, 39.473084449768066, 43.807822363717214, 42.88962834221976, 43.72632346834455, 43.052125862666536, 43.19705833707537, 44.10679987498692, 42.5051462990897, 36.45923730305263, 28.32455563545227, 49.14296885899135, 46.87495524542672, 47.831016949244905, 42.41838761738369, 36.82303803307669, 36.5136729649135, 34.628265380859375, 34.075379848480225, 34.100521905081614, 33.75962938581194, 33.971010957445415, 35.69717277799334, 35.001036235264365, 35.05330753326416, 35.83818299429757, 35.92351729529244, 35.04096405846732, 35.23765366418021, 38.29510770525251, 39.94900131225586, 44.31686128888811, 44.7874037197658, 45.22617898668562, 45.39208459854126, 45.41411733627319, 43.95310572215489, 41.24575751168387, 43.95906032834734, 48.33902754102434, 47.72231585638863, 46.450816358838765, 45.88148444039481, 42.97088752474104, 38.55326802389962, 37.396472862788606, 37.1369263785226, 38.583200863429475, 38.92695951461792, 39.13717378888811, 44.051110063280376, 48.98365361349923, 49.30135999407087, 45.99530635561262, 46.53313514164516, 50.789570331573486, 50.544712339128765, 47.55590302603585, 42.03332887377058, 48.65906504222325, 51.73240613937378, 53.338860920497346, 52.67687477384295, 47.230032512119834, 33.67218630654471, 13.75327558176858, 4.769466289452144, 7.656691636357989, 4.5543235710689, 2.604933934552329, 0.2549384986715657, 0.07925355514245373, 2.1926506289414, 30.973940236227854, 39.79393489020211, 19.818379844938004, 21.624562331608363, 27.690357072012766, 43.025844301496235, 53.31312826701573, 45.20920106342861, 10.917033076286316, 0.08694028481841087, 0.04162627099347966, 0.02972257849095123, 0.05786438073430743, 0.035282409616879055, 0.04777600010856986, 0.042389497360480685, 0.015321822836995125, 0.05294974820156183, 0.018904998333060315, 0.05318991567141243, 0.026733901451474855, 0.018389796871425848, 0.031076377989458184, 0.03614373518420117, 0.03172290311860187, 0.18475958944431373, 0.10293785389512777, 0.1631471770150321, 0.09245450142771006, 0.12408850288816861, 0.1739152292055743, 0.13258441271526472, 0.14320860191115312, 0.08722482847848109, 0.09101474511304072, 0.1266520760421242, 0.14065883015947683, 0.1675895864942244, 0.2148453571966716, 0.11748699497963701, 0.14540693323527062, 2.454508909157344, 27.265563317707606, 54.312289646693635, 51.55581419808524, 45.67778410230364, 27.710119485855103, 28.264260905129568, 39.058068547930034, 43.51851674488613, 19.03869468825204, 0.5925645232200623, 1.4668836018868854, 36.57461908885411, 16.487882443836757, 14.80969272341047, 31.855909824371338, 13.111751011439733, 25.423034804207937, 42.09343079158238, 55.97696338381086, 50.69993509565081, 53.06895467213222, 45.75700051443917, 46.10875654220581, 44.55202654429844, 45.88188396181379, 46.02209166118077, 50.884677273886545, 48.339698042188374, 49.50457395826067, 44.49853583744594, 44.66889524459839, 45.189697469983784, 45.584542751312256, 43.12504373277937, 44.185661928994314, 40.084706578935894, 42.64473213468279, 40.768895694187705, 44.1718419619969, 44.343591008867534, 48.46874693461827, 47.20886829921177, 49.16795110702515, 48.05928264345442, 50.46217468806675, 46.8264741897583, 46.58173779078892, 40.41290126528059, 39.92150729043143, 36.9433982031686, 34.661912032536094, 35.33665854590279, 37.66627836227417, 36.234303270067485, 37.29015152794974, 35.805776596069336, 36.33542387826102, 37.07217958995274, 43.16741732188633, 47.52348620550973, 50.152920791081016, 47.070098876953125, 40.86467661176409, 44.863264151981895, 43.02415588923863, 44.13869905471802, 45.58129446847098, 45.29385444096157, 46.553726128169465, 42.708749362400596, 37.46758420126778, 31.808787141527446, 47.749260970524375, 49.60638243811471, 47.872393471854075, 44.14338561466762, 40.307851450783865, 40.03842115402222, 35.88476024355207, 34.94821950367519, 36.221577644348145, 35.26911163330078, 34.978166239602224, 38.26808616093227, 36.25861154283796, 36.858140332358225, 37.63615097318377, 37.48907150541033, 36.07371997833252, 37.68184232711792, 39.53313078199114, 42.69276850564139, 46.48594645091465, 48.40960386821202, 47.846685137067524, 47.67380353382656, 47.195732729775564, 46.26056773321969, 43.19759334836687, 46.62614720208304, 49.890400477818076, 50.23644508634295, 48.2315354347229, 49.01624066489083, 45.488636766161235, 40.78110367911202, 39.47630493981497, 39.04005534308297, 41.412618500845774, 41.89866236277989, 41.716591766902376, 46.14132969720023, 50.63719286237444, 50.585119588034495, 45.78109686715262, 48.158690520695274, 53.37843091147286, 53.48506144114903, 50.21562133516584, 44.3729749407087, 50.9712553024292, 54.99665246691023, 56.100884505680625, 56.70474549702236, 48.36439888817923, 38.292828696114675, 17.436195169176372, 16.520231519426616, 12.408909457070486, 7.981978501592364, 5.521082026617868, 0.47370315556015286, 0.17359816336206027, 2.8385493074144637, 36.04710142953055, 48.478717599596294, 35.2627192905971, 31.916859422411235, 38.594495160239084, 51.06076547077724, 60.296571595328196, 52.80578122820173, 14.367709125791277, 0.19794831531388418, 0.10587429561253105, 0.11133177990892104, 0.09732508685972009, 0.11599746133599963, 0.12711442980383122, 0.1067365100607276, 0.09484395571053028, 0.13372636001024926, 0.12704141943582467, 0.10539009980857372, 0.0708973692463977, 0.10622030775994062, 0.1194637439080647, 0.130060968122312, 0.07618990846510444], [0.014825213234871626, 0.04894797597080469, 0.055861745694918294, 0.0024118868625789347, 0.02029247352454279, 0.09432282724550792, 0.024159057830859507, 0.027331343053707054, 0.03274972337697234, 0.01985595837634589, 0.022655702428892255, 0.01322514538852764, 0.01644254894927144, 0.06875755478228841, 0.03985696039827807, 0.04500932106748223, 1.28972527384758, 17.828822238104685, 40.492305278778076, 43.32522480828421, 30.458067757742747, 14.501077192170278, 12.770115034920828, 23.77907017299107, 32.72875990186419, 13.283510480608259, 0.09815751362059798, 0.9328343101910183, 22.08115972791399, 6.121909260749817, 6.535864693777902, 8.789360046386719, 8.785118171146937, 28.588387421199254, 44.73989193780081, 52.536403042929514, 48.0277864592416, 48.02873836244856, 43.67991992405483, 45.76940999712263, 45.68686539786202, 45.92961808613369, 45.03725746699742, 46.953449044908794, 44.67633676528931, 44.158504894801546, 40.735332420894075, 39.28186655044556, 37.496099608285085, 37.27647747312273, 37.05409690311977, 39.59853764942714, 36.301266533987864, 36.83326230730329, 39.36248997279576, 42.47437620162964, 43.22219344547817, 45.10347032546997, 44.53535781587873, 44.69226551055908, 43.205719266619, 42.87720843723842, 43.8726282119751, 39.341923304966514, 35.06394175120762, 34.8806482723781, 34.43396942956107, 33.122573375701904, 32.64246327536446, 32.891187940325054, 33.44770738056728, 33.0799948147365, 31.54957069669451, 33.27346740450178, 35.28397383008684, 42.744935580662315, 44.20735420499529, 47.55321407318115, 39.756817613329204, 40.61782796042306, 46.09521450315203, 45.192928382328574, 46.092733996255056, 43.92492730276925, 45.643154280526296, 42.230452741895405, 42.41301318577358, 36.29343938827515, 25.89107414654323, 48.00859553473336, 44.64281518118722, 44.79106542042324, 38.08972937720162, 36.838855607169016, 36.52999080930437, 37.87743411745344, 36.02642011642456, 34.92981372560774, 32.655129841395784, 33.42343732288906, 34.489958013807026, 33.757951395852224, 32.82586792537144, 33.88219908305577, 34.582886695861816, 34.66838427952358, 34.67978627341134, 37.4271491595677, 40.754165513174875, 44.71037251608712, 47.63903474807739, 46.58707053320748, 47.59342677252633, 47.789317335401265, 45.166896956307546, 45.58892011642456, 45.67214216504778, 45.139514105660574, 47.59133536475045, 45.65492105484009, 43.94997903278896, 38.92549344471523, 35.74614020756313, 33.39947646004813, 34.70291682652065, 36.06401334490095, 35.086050919124055, 36.71354831968035, 43.33574090685163, 48.19954245431082, 48.2776506287711, 50.617310592106406, 44.55748782839094, 48.43827560969761, 47.39076171602522, 46.16120849336897, 45.604650838034495, 45.565779141017366, 49.26196370806013, 50.44974088668823, 52.64456912449428, 43.65178319386074, 29.01358069692339, 15.143631832940237, 4.301217198371887, 8.911891528538295, 7.87607319014413, 2.507393168551581, 0.06294471491128206, 0.030026626640132496, 0.7919753257717405, 23.015970366341726, 49.08685520717076, 38.987238611493794, 27.354189327784947, 36.55922188077654, 43.20947476795742, 46.74963753564017, 37.50847087587629, 9.458905833108084, 0.0765125315104212, 0.0673897774623973, 0.018008545007822768, 0.07795905960457665, 0.01366743741423956, 0.01518760182495628, 0.07702067281518664, 0.06354234141430684, 0.03545403826449599, 0.05719706189951726, 0.021767433932317153, 0.02039269484313471, 0.053234990752701244, 0.05487539665773511, 0.02377858797886542, 0.021901692263782024, 0.03159610867234213, 0.025928702604557787, 0.023947733188314096, 0.01432770796652351, 0.021769683275903975, 0.008294235648853438, 0.04765545836250697, 0.002763317324154611, 0.009065681619436612, 0.03818053785445435, 0.0644588725907462, 0.04678273679954665, 0.05435953701713255, 0.03510247230795877, 0.03360499641192811, 0.046190467330494096, 1.3853019795247485, 21.169071435928345, 46.59233379364014, 48.51809998920986, 35.90168605531965, 17.926333257130214, 14.872318574360438, 27.033893006188528, 37.177806104932515, 15.043727159500122, 0.06952895410358906, 1.1257387761558806, 26.42087950025286, 10.513659749712263, 8.200253554752894, 10.78165350641523, 8.829920155661446, 25.5929217338562, 46.794397830963135, 52.433576651981895, 50.24400125231062, 47.99231243133545, 44.81392846788679, 46.04390205655779, 46.44009876251221, 46.43082291739327, 47.81913205555507, 47.32396868297032, 46.452591623578755, 45.85565798623221, 42.52632440839495, 40.50778586523873, 39.05935396466936, 39.82323544366019, 39.06575672967093, 42.07037666865757, 37.94331693649292, 38.43782370431082, 40.90613651275635, 43.525416306086946, 45.356895446777344, 45.71459913253784, 46.59215314047677, 46.973154136112754, 45.959707260131836, 44.95691892078945, 46.14075299671718, 43.07553434371948, 37.7332763671875, 37.266628401620046, 35.763448170253206, 35.20098107201712, 34.19628892626081, 34.10717827933175, 34.68478550229754, 34.24693087169102, 33.91273641586304, 34.93382283619472, 36.275971617017476, 43.82570702689034, 46.93367794581822, 48.00478097370693, 39.92316096169608, 41.637236390795024, 46.01275675637381, 46.43881681987217, 45.76260771070208, 44.7743376323155, 46.518026283809114, 45.52292960030692, 43.80947603498186, 37.208471979413716, 28.248240096228464, 49.646067074366975, 47.12325954437256, 47.665757519858225, 39.721583298274446, 37.49929230553763, 38.021209716796875, 38.95686108725411, 37.51252514975411, 36.39066553115845, 35.07079267501831, 34.713373865400044, 35.76009913853237, 36.4106068611145, 35.21487399509975, 34.75917986461094, 36.139512470790315, 35.45497594560896, 35.86769894191197, 38.66456426892962, 43.21258061272757, 45.34728608812605, 47.73906101499285, 48.15591818945748, 48.579956327165874, 47.92244482040405, 46.925565923963276, 47.79288870947701, 48.27871022905622, 47.41322871616909, 48.35571711403983, 47.59382629394531, 45.150672912597656, 40.5748359816415, 38.29684475490025, 35.86770589011056, 37.29655776705061, 38.702525751931326, 36.88123961857387, 37.871667112622944, 44.468394551958355, 49.51344680786133, 49.148468358176096, 49.59179816927229, 47.022093772888184, 50.05697659083775, 49.836058616638184, 48.36093521118164, 46.48439352852957, 46.66295875821795, 51.24777970995222, 53.324075153895784, 53.721845626831055, 46.433372906276155, 32.84645196369716, 23.971545696258545, 11.375018375260488, 6.524982077734811, 8.073953543390546, 3.551476172038487, 0.08421644847840071, 0.02370954873705549, 1.2072333289044244, 25.654526199613297, 52.64382914134434, 44.59999690737043, 32.069393226078574, 40.659468514578684, 47.67105552128383, 53.296789578029085, 43.98579699652535, 10.47985589504242, 0.031937004665711095, 0.06474444083869457, 0.043884659452097755, 0.011062654284095126, 0.05407640810257622, 0.010406099559207047, 0.04421505850872823, 0.041015738754400184, 0.02291753382555076, 0.035570749680378606, 0.04329915836985622, 0.04854253772646189, 0.0520408844708332, 0.024047744161050235, 0.018687052885070443, 0.005179650499485433, 0.16454803970243248, 0.1488910477076258, 0.1617699544876814, 0.07577795628458261, 0.05690949197326388, 0.20227670376854284, 0.09375229464577776, 0.1311557979456016, 0.14724341540464334, 0.08323336658733231, 0.15391087691698754, 0.11622472985514573, 0.14935137943497725, 0.1494113483599254, 0.1409419421106577, 0.13503988167004927, 2.631739216191428, 24.617429392678396, 53.56607048852103, 55.42740256445748, 42.458200795309885, 21.733767168862478, 20.159301894051687, 34.653518608638215, 44.82734196526663, 18.364634309496196, 0.2667393083018916, 1.4736194461584091, 27.946356500898087, 11.25782571520124, 13.666104350771223, 14.783178397587367, 11.662157893180847, 30.9260219846453, 47.27630056653704, 53.934460503714426, 49.918467726026265, 50.02222170148577, 45.31134653091431, 46.07367508752005, 47.90441077096121, 47.503676891326904, 47.75304079055786, 49.57379886082241, 48.35895497458321, 47.00188841138567, 44.086233207157676, 42.24755573272705, 41.41444935117449, 42.02465404782976, 41.54434939793178, 44.94506876809256, 39.9195305279323, 39.98420088631766, 44.01533031463623, 45.308574199676514, 47.01779631205967, 46.89462212153843, 49.01282909938267, 49.651316438402446, 47.13341433661324, 47.565248353140696, 48.01612738200596, 44.73228713444301, 39.53637211663382, 37.88757153919765, 37.85234069824219, 37.44588845116751, 36.42317615236555, 35.577976431165425, 36.83394323076521, 36.90009355545044, 34.581924370356965, 36.006315503801616, 38.33564002173287, 45.88551092147827, 47.87975856236049, 48.541035992758616, 41.17284311567034, 43.26752001898629, 46.61625296728951, 48.59067044939314, 47.66512175968715, 48.43973820550101, 49.41310787200928, 46.58415228979928, 43.872822761535645, 39.19652182715279, 30.633277007511683, 51.192916733878, 50.09861019679478, 49.71486813681466, 42.238349369594026, 40.2912973676409, 39.280834742954795, 41.13346767425537, 40.37183393750872, 38.05086810248238, 37.15520361491612, 36.726649148123606, 38.926956040518625, 38.184405531202046, 35.71611704145159, 37.00986467088972, 38.313152176993235, 36.92260571888515, 37.487935474940706, 40.84113958903721, 45.30739995411464, 48.162157671792166, 50.57113286427089, 48.6298965045384, 51.684501784188406, 50.95994710922241, 49.588021823338096, 50.19587108067104, 50.920821802956716, 48.84482513155256, 50.17693723951067, 48.693423884255544, 49.0589234488351, 42.87308815547398, 39.52843727384295, 37.33104167665754, 38.29027870723179, 40.87795809337071, 38.77498504093715, 41.751520361219136, 47.38587713241577, 52.4309641293117, 52.07535185132708, 49.55813414709908, 47.008878299168174, 51.79551315307617, 52.02184724807739, 50.79007755007063, 49.659032412937705, 50.528418813432964, 54.646473680223735, 55.31265653882708, 54.6355094228472, 49.41983372824532, 32.296404770442415, 19.314178603036062, 9.002325807298933, 19.405368498393468, 16.324737003871373, 5.9527245334216525, 0.2430613674223423, 0.14149920935077326, 1.2484671963112695, 30.357787881578716, 62.266608238220215, 47.84620918546404, 35.709339073726106, 47.20291369301932, 55.22927815573556, 59.94088636125837, 51.321916988917756, 14.216082062040057, 0.2070535495877266, 0.1255890152284077, 0.09048025629350118, 0.10399503859558276, 0.16146603865282877, 0.16066185251942702, 0.1444144264927932, 0.1521383805998734, 0.09962054368640695, 0.21883025765419006, 0.08571970210011516, 0.17775127265070165, 0.1691312859100955, 0.18468751545463288, 0.16682322190276214, 0.09785074115331684], [0.04998664005792566, 0.023073958199737326, 0.040876947809010744, 0.03901464059682829, 0.03987887707938041, 0.0048406641581095755, 0.037012276971446614, 0.044267248029687574, 0.032146003629480085, 0.06791236477770976, 0.07593442645988294, 0.006059936455650521, 0.0426089762976127, 0.04588383396289178, 0.020760689828810946, 0.01963138873023646, 1.4771423999752318, 16.77965988431658, 38.17822510855538, 44.370174816676546, 33.90470082419259, 23.141081367220195, 21.242762293134415, 30.92791189466204, 33.721240588596885, 10.107877135276794, 0.07633969507047109, 0.9567388274839946, 16.549191611153738, 3.885413544518607, 7.030146947928837, 11.739380172320775, 9.740040370396205, 32.21075780051095, 48.09650761740548, 47.47804498672485, 50.32474626813616, 47.17224434443882, 43.766317299434114, 45.499906744275776, 45.72689049584525, 45.22179119927542, 47.14695290156773, 44.1570006098066, 43.46970912388393, 42.50735930034092, 40.519983427865164, 37.799756731305806, 36.771308694567, 36.03624834333147, 37.893970830099924, 36.59567560468401, 39.269404956272666, 40.74294417245047, 40.091748578207834, 42.77291597638811, 43.144276346479145, 43.64525188718523, 41.223981857299805, 38.09009068352835, 35.97146333966936, 35.025716236659456, 34.93490328107561, 33.48539440972464, 33.46022456032889, 33.14376885550362, 33.5952593258449, 31.305091381072998, 32.79448291233608, 32.53726060049874, 33.31652886526925, 31.54261554990496, 32.62841054371425, 33.66160420009068, 37.3170028414045, 41.04463495526995, 46.06500026157924, 42.18159300940377, 43.866760458265034, 45.917034898485454, 43.983830656324116, 43.18623999186924, 42.95275967461722, 43.5196145602635, 44.06043801988874, 45.023072719573975, 43.03430373328072, 40.08237198420933, 26.49016867365156, 48.164179597582134, 43.452724252428325, 43.66574559892927, 38.47477422441755, 41.000864778246196, 43.618612493787495, 44.1756808417184, 43.30995266778128, 43.05938673019409, 37.870013441358296, 32.95605632237026, 34.33897018432617, 34.96509667805263, 33.64420938491821, 35.079095772334504, 33.55156905310494, 33.603854247501914, 35.139715330941335, 36.956172466278076, 40.18899556568691, 45.446179798671174, 46.15752247401646, 46.39308030264718, 45.972919259752544, 45.6497620173863, 46.34540523801531, 47.389670848846436, 47.02601950509207, 45.024837562016074, 45.90597684042794, 47.20503984178816, 41.699252537318635, 39.07393128531319, 34.776651109967915, 34.346192836761475, 33.17931931359427, 35.33108956473214, 34.62387759344918, 38.163008553641184, 45.22594274793352, 49.6149982043675, 47.19182436806815, 38.76331901550293, 41.75580045155117, 48.72966568810599, 49.55876990727016, 50.506149836948936, 47.37741075243269, 48.29086262839181, 45.58928837094988, 50.508164814540315, 41.90794168199812, 44.997621468135286, 42.17237622397286, 27.188912527901785, 11.07457913671221, 3.378915705851146, 2.150123745203018, 2.2542129712445393, 0.2956180301095758, 0.06417183870715754, 0.6041069467152868, 17.64922867502485, 41.35973923546927, 21.90799672263009, 18.790583201817103, 24.44100420815604, 40.08817720413208, 45.01605156489781, 36.346520151410786, 10.094696402549744, 0.029955197258719375, 0.055661873027150116, 0.04239957021283252, 0.030788007391882793, 0.067728698918862, 0.023219293615381633, 0.04880175845963614, 0.006254860482710812, 0.0243613291199186, 0.04903627373278141, 0.026662273598568778, 0.014491572477189558, 0.07737996389291116, 0.029605317461703504, 0.02859098564035126, 0.05510433776570218, 0.06774665974080563, 0.03859554683523519, 0.020772771144817983, 0.03155854158103466, 0.030815393065235445, 0.06346737686544657, 0.043701292148658206, 0.00949721462425909, 0.05869042926601001, 0.1334911933434861, 0.056200107359992604, 0.018719839697171534, 0.026226718577423265, 0.025421248316498737, 0.046976394086544, 0.03598571455638323, 2.192586358104433, 19.84265685081482, 44.9724029813494, 50.17781966073172, 37.455358845846995, 23.44559485571725, 23.65348322050912, 32.76760728018624, 38.08179106031145, 11.62406439440591, 0.03547985652195556, 1.1637523706470216, 17.957313537597656, 4.628376603126526, 5.893676570483616, 7.8296427215848645, 9.315012982913426, 33.10315316064017, 47.534676279340474, 49.68680436270577, 49.592652797698975, 48.03867776053292, 44.571856703077046, 45.986099992479595, 46.102183546338765, 46.04637214115688, 49.28431258882795, 46.067994935171946, 44.50295836584908, 44.64860303061349, 42.71331432887486, 39.77038744517735, 39.5686742918832, 38.477160930633545, 39.925269739968435, 39.200339862278526, 41.019180229731965, 42.55652127947126, 43.2670510155814, 44.88564082554409, 44.95478234972273, 46.13830723081316, 43.54675074986049, 40.409305572509766, 38.241318225860596, 38.31312785829817, 36.72405399594988, 36.16895546231951, 35.65012305123465, 34.84756095068795, 34.48633452824184, 33.09341526031494, 33.59526627404349, 33.789749826703755, 35.018625599997385, 33.58796371732439, 33.60498332977295, 34.357733794621055, 38.90924160821097, 44.16872916902815, 46.763613837105886, 42.67211498532976, 43.164134298052105, 47.54229497909546, 47.757564067840576, 45.309894357408794, 44.15309224809919, 45.90764093399048, 45.17834063938686, 45.444918700626914, 44.03940234865461, 39.0855313028608, 28.914937121527537, 49.674193382263184, 46.0930883543832, 45.53537729808262, 39.67253943852016, 43.20896060126168, 44.57128695079258, 46.7549911226545, 43.838721002851216, 44.506460257938926, 39.06780297415597, 35.54589312417166, 34.87733398165022, 36.260105405535015, 35.66508599690029, 37.0512238230024, 33.1549346106393, 35.22229814529419, 37.13116979598999, 38.95251151493618, 42.83780172892979, 47.27044670922415, 48.43855701174055, 47.84038312094552, 46.83449935913086, 46.813349042619976, 47.95111656188965, 49.426868779318674, 47.61360086713518, 46.4588554246085, 46.107148034232004, 49.10413190296718, 43.07059417452131, 41.72246299471174, 36.26413188661848, 36.718293939317974, 35.69368478230068, 36.71765123094831, 35.1225254876273, 38.99650750841413, 46.22086572647095, 49.93544217518398, 48.465074811662944, 41.35705028261457, 42.48381880351475, 50.456765515463694, 51.15174518312727, 52.53478758675711, 50.1606193951198, 49.677427768707275, 48.79232106889997, 54.27716302871704, 46.49748740877424, 48.524732044764924, 37.55655935832432, 21.84270623752049, 10.289003644670759, 10.7658246415002, 6.1561634455408365, 4.1502463051251, 0.6438688816768783, 0.07863044286412851, 0.47335927401270184, 20.884351628167288, 47.90999017442976, 27.25373748370579, 22.961609397615703, 30.745612008231028, 45.79899890082223, 52.109658581869944, 41.84951080594744, 12.18447743143354, 0.07934411242604256, 0.012092560180462897, 0.05976595476801906, 0.05001108767464757, 0.05872300573225532, 0.060582510594810755, 0.04029936183776174, 0.04730310869802322, 0.03162803374496954, 0.012966800813696213, 0.015514998364129236, 0.030538795050233603, 0.00549462645514203, 0.13689841622752802, 0.013685970750105168, 0.023173779182668244, 0.14692166766950063, 0.17125819463815006, 0.12504891492426395, 0.10847745449947459, 0.15381565131247044, 0.16660097454275402, 0.0960549982264638, 0.0917136836796999, 0.13027769220726831, 0.3118149595601218, 0.11515790995742593, 0.12659867533615657, 0.15954202546605042, 0.12392983425940786, 0.08508381979273898, 0.14783227523522718, 3.1342229502541676, 24.83134010859898, 54.06922081538609, 55.92599834714617, 44.67146955217634, 31.98311744417463, 31.45385926110404, 41.189647333962576, 44.06648642676217, 13.415302174431936, 0.13563678892595427, 1.3816197599683488, 23.837994371141704, 7.272647329739161, 13.862056578908648, 20.79613729885646, 12.822703344481331, 35.46264328275408, 48.514639786311555, 50.49709633418492, 51.820356437138145, 49.40850469044277, 45.60906294413975, 46.03840255737305, 45.593221051352366, 47.70830481392996, 50.923368317740305, 47.43116201673235, 47.29184021268572, 47.45166267667498, 45.196360792432515, 40.77198069436209, 40.99928406306675, 40.66186564309256, 42.245860372270855, 40.96040194375174, 43.38909264973232, 46.20595836639404, 44.61286497116089, 48.27129302706037, 47.377379485539024, 48.40067890712193, 44.641991819654194, 41.79622507095337, 39.62181758880615, 38.511683055332725, 38.970295429229736, 37.98861224310738, 36.741320269448416, 36.65962335041591, 36.014351095472065, 33.20316900525774, 35.96064846856253, 35.08280611038208, 37.629296575273784, 35.14249808447701, 35.91418933868408, 38.26878445489066, 41.49716765539986, 46.83712230409895, 49.44639669145857, 43.08095046452114, 45.9495073046003, 49.05247204644339, 48.973860127585276, 47.31189271381923, 46.539287771497456, 47.47821869168963, 47.114192145211355, 47.413569177900044, 43.89879512786865, 41.671616077423096, 31.97351850782122, 50.80393920625959, 47.459041663578574, 47.51080574308123, 41.32200009482247, 44.519297054835725, 47.7294933455331, 49.722122056143625, 46.80817263466971, 48.68462746483939, 41.02048996516636, 36.20002433231899, 37.18144696099417, 38.585952350071494, 37.898935317993164, 38.266793795994346, 34.908930914742605, 36.622794423784526, 38.366875648498535, 40.28039216995239, 44.64025477000645, 50.07857854025704, 50.55871295928955, 49.16390725544521, 48.47583409718105, 48.21845197677612, 49.35270370755877, 51.402950354984824, 49.148114000047954, 45.63012293406895, 47.889482566288535, 52.10672296796526, 43.90106718880789, 43.33445201601301, 38.70543704714094, 38.72340508869716, 37.13406024660383, 38.00264760426113, 37.330544880458284, 40.50693123681204, 49.41169391359602, 53.20901298522949, 49.18838575908116, 41.238927432468955, 45.483859879629954, 51.04975257601057, 52.610502106802805, 54.80695969717843, 53.749381337847026, 51.7195519719805, 50.79843275887625, 54.72212566648211, 50.76981660297939, 50.29202720097133, 43.315889903477256, 28.464521884918213, 20.050779717309133, 11.237665516989571, 7.533276864460536, 6.546843716076442, 1.0137116674865996, 0.17179764354867594, 0.743365674146584, 23.566153049468994, 52.190445286887034, 31.36428655896868, 27.472068990979874, 35.54782124928066, 51.480266434805735, 58.227926118033274, 51.012506757463726, 14.684830120631627, 0.20763862319290638, 0.19973769358226232, 0.14433559429432663, 0.13260136252003057, 0.2181999257632664, 0.120677507349423, 0.14520838031811373, 0.11154117581567594, 0.17118329794279166, 0.0953303567532982, 0.07986199749367577, 0.09147704459194626, 0.11511483655444213, 0.21647880811776432, 0.08493326644280128, 0.17237916163035802], [0.022091098528887545, 0.020663065603002906, 0.018901459772938063, 0.04874985731605973, 0.02284138184040785, 0.04275918020201581, 0.05046770442277193, 0.042848746824477396, 0.06647419623498406, 0.03131687115611775, 0.021412678861192296, 0.022064435495329753, 0.07518674872283425, 0.0419111030309328, 0.012173445795529654, 0.036480831381465705, 1.9002634840352195, 20.642153058733257, 35.51996939522879, 38.11816487993513, 34.49578755242484, 21.539261034556798, 12.867320333208356, 27.424831662859233, 32.504353931971956, 6.83231566633497, 0.04200572473928332, 0.2088800301509244, 9.043589421680995, 8.357829145022801, 4.681481684957232, 6.570334706987653, 11.07865251813616, 33.2346373966762, 45.289160932813374, 50.18431970051357, 50.95639657974243, 45.248444489070344, 46.02733407701765, 46.40532997676304, 45.66000713620867, 48.89437620980399, 44.947396414620535, 44.663489546094624, 42.13843774795532, 40.08364003045218, 37.31415407998221, 36.00606884275164, 36.430579457964214, 35.41418307168143, 36.02789313452584, 38.648458344595774, 38.28717981066023, 40.12186554500035, 38.787172181265696, 39.53639643532889, 39.7741116796221, 35.77177906036377, 31.819327558789933, 32.33781950814383, 31.280637196132115, 32.469383648463655, 31.8233505657741, 32.10825102669852, 32.774329662323, 33.505370480673655, 31.683719566890172, 32.435135977608816, 34.65887219565255, 33.67704657145909, 32.860258034297395, 32.53746557235718, 31.349719660622732, 33.21562017713274, 36.712568623679026, 43.99883181708199, 45.364288330078125, 45.08225747517177, 44.96545130865914, 44.65055547441755, 39.850409848349436, 39.97429970332554, 39.4715211050851, 42.08561406816755, 42.55993979317801, 44.66637304850987, 45.87420967647007, 42.531045709337505, 28.24051891054426, 48.668504170009065, 44.90312944139753, 43.71435867037092, 46.38355084827968, 45.34552819388253, 44.803950854710166, 47.42875446592058, 46.59081561224801, 46.312342235020225, 44.20330687931606, 37.86026859283447, 33.11032370158604, 34.526932852608816, 34.1743916784014, 34.33887985774449, 35.43807445253645, 34.71243585859026, 34.524136202675955, 36.637715680258616, 37.84635829925537, 42.70948239735195, 44.70985834939139, 46.66301781790597, 44.275126934051514, 43.73159715107509, 43.63117136274065, 45.747974804469514, 44.21124519620623, 42.55296727589199, 44.600702149527415, 47.4963013785226, 43.037350518362864, 38.80122143881661, 35.850863456726074, 33.77369253976004, 32.3711256980896, 34.3999788420541, 32.9261269569397, 37.60210132598877, 44.48846442358834, 47.54255553654262, 43.40806818008423, 43.95224414552961, 47.408844402858186, 46.56327295303345, 47.61363908222744, 49.99851792199271, 50.445241928100586, 49.42033052444458, 48.84672546386719, 50.44365079062325, 52.809290068490164, 49.759475571768625, 32.38654375076294, 33.37700945990426, 14.328994631767273, 5.195575424603053, 6.772367911679404, 3.8398937242371693, 0.24162762292793818, 0.09242012684366532, 0.5037829929164478, 14.816882371902466, 45.91184459413801, 39.64399971280779, 22.465878009796143, 33.00293581826346, 39.56501953942435, 47.70189510072981, 31.74300159726824, 9.8229558297566, 0.08592693348016057, 0.034775191119738987, 0.03329063453046339, 0.0336091185121664, 0.05325567250006965, 0.006214257795363665, 0.029695135142121996, 0.019872563824589764, 0.0463296789675951, 0.02055091054977051, 0.05467451636546424, 0.03661624322246228, 0.015920056628861597, 0.050622759852558374, 0.05001746929649796, 0.02097995502741209, 0.02937107699524079, 0.053488518577069044, 0.02503774032395865, 0.027924759246941124, 0.07742540538311005, 0.01265660852992109, 0.012167776635448848, 0.06671123565839869, 0.0945299704160009, 0.01080352854582348, 0.015548265239756023, 0.03750023525208235, 0.07980311422475747, 0.02380945623320128, 0.013074994070588477, 0.03452791938824313, 2.576557274375643, 23.670025144304546, 43.17399379185268, 44.8384347643171, 40.00127608435494, 24.429746389389038, 18.230132818222046, 33.157310894557405, 37.24324423926217, 7.487447415079389, 0.09517482295632362, 0.103378419897386, 11.309381348746163, 7.282750444752829, 8.649618744850159, 8.872709768159048, 8.583447575569153, 36.207643032073975, 46.756933144160676, 50.96176058905465, 50.0861451285226, 47.08783415385655, 45.63650485447475, 46.032225608825684, 45.83022410529, 49.92165347508022, 48.37576266697475, 46.01712369918823, 43.17992407935006, 41.82542140143258, 40.638116700308665, 39.10793229511806, 37.38999714170183, 37.000658307756694, 38.73181240899222, 40.95246015276228, 41.09396716526577, 42.4355913570949, 41.02908141272408, 42.413815702710835, 40.73195212227957, 38.99249839782715, 34.2029070854187, 33.84556123188564, 32.153730460575645, 33.538350105285645, 33.564291204724995, 33.83587196895054, 34.475453649248394, 34.806295599256245, 32.98025689806257, 33.23342841012137, 35.49705423627581, 34.97024181910923, 34.45432765143258, 34.29058640343802, 32.71289021628243, 34.4244191305978, 37.75614636284964, 46.80109242030552, 48.27297101702009, 46.35418081283569, 46.53244726998465, 47.842269556862966, 42.195746489933555, 41.342577184949604, 41.25959832327706, 43.37199660709926, 44.15492309842791, 46.88730219432286, 46.27494355610439, 42.24652739933559, 30.531322615487234, 49.9612477847508, 47.2780966758728, 47.02640860421317, 46.92771986552647, 47.42135116032192, 46.694187436785015, 49.89091117041451, 47.36898953574044, 48.392469610486714, 46.324505056653706, 40.82380730765206, 34.53028883252825, 36.85490247181484, 35.375471183231895, 36.734785488673616, 36.0640480858939, 37.05102232524327, 35.80465793609619, 38.63899837221418, 40.35303558622088, 43.299314975738525, 47.439954962049214, 48.41517284938267, 46.71631744929722, 46.14668675831386, 45.04448011943272, 46.960112367357524, 43.490883759089876, 42.61566434587751, 46.79369953700474, 49.38607243129185, 43.314149379730225, 41.38022599901472, 37.575677326747346, 35.542113304138184, 34.31931373051235, 36.456048079899375, 35.788743087223594, 40.93255703789847, 46.62069981438773, 49.56453691210066, 46.4143522126334, 44.99974761690412, 48.37519638878958, 49.03485836301531, 48.637598582676475, 51.3371022769383, 52.203223024095806, 51.585510798863, 50.71468264716012, 52.65622820172991, 53.54898139408657, 49.74240037373134, 35.63272476196289, 29.488943440573557, 11.73099456514631, 5.542334394795554, 8.834821241242544, 5.113876334258488, 0.7336249511156763, 0.06409825158438512, 0.2740155921450683, 16.583701576505387, 48.046167918613975, 38.71589061192104, 27.431385551180156, 34.89181750161307, 43.58756446838379, 53.39519344057356, 39.364470209394185, 12.338650141443525, 0.19916228231574806, 0.025749604982723082, 0.031551013235002756, 0.05320668227172323, 0.033388021269014904, 0.03485859325155616, 0.038499574842197556, 0.05395032611808606, 0.04531996796971985, 0.049769698841763396, 0.022696114278265407, 0.08185853928859745, 0.025755805096455982, 0.0021692753944080323, 0.030732723751238415, 0.08924691033150468, 0.11310165029551301, 0.1105428065306374, 0.10636552782463175, 0.1748173822249685, 0.22804365041000502, 0.18280316942504474, 0.14618042244442872, 0.1931934811707054, 0.1259162048144, 0.11666203210396425, 0.09381581909422364, 0.10562469650592123, 0.10939588557396616, 0.1526610018419368, 0.08950594786022391, 0.13608316997332232, 3.7466562816074918, 28.67426368168422, 51.148774828229634, 51.90552398136684, 46.19104405811855, 31.185141154697963, 20.61071072305952, 38.22888789858137, 43.14082656587873, 8.617581469672066, 0.15154384821653366, 0.33503939477460726, 11.215506843158177, 14.125602619988577, 12.78428588594709, 13.015310883522034, 14.70459600857326, 37.15667315891811, 48.64859758104597, 51.302312646593364, 51.123340947287424, 47.83423743929182, 46.106668608529226, 45.99837398529053, 47.38289982931954, 52.183389391217915, 50.11315277644566, 48.789757183619905, 45.73367888586861, 44.455814838409424, 42.514908518110005, 40.43028565815517, 39.8608147757394, 39.33816432952881, 38.699232305799214, 43.02659470694405, 43.196815150124685, 43.65674420765468, 41.6248060635158, 44.270419529506135, 42.690107345581055, 39.38392516544887, 35.233595916203086, 35.32442971638271, 33.82526554380144, 36.028250966753276, 34.89707381384713, 36.16690574373518, 37.55498559134347, 36.18048252378191, 34.37602145331246, 33.56049401419503, 36.75657851355416, 36.19530997957502, 36.07109008516584, 34.622414997645784, 34.63342441831316, 38.44281945909773, 39.00704097747803, 48.24071747916085, 49.93752316066197, 48.33922903878348, 48.36389514378139, 49.28719956534249, 43.54004921231951, 42.803995268685476, 43.45001792907715, 45.17103460856846, 46.63464832305908, 48.83700493403843, 46.636812686920166, 43.138220991407124, 33.61863306590489, 50.878375257764546, 49.22107703345162, 48.026094572884695, 49.701892375946045, 49.09990392412458, 47.835185868399485, 51.04545511518206, 49.9653958593096, 49.683736733027864, 47.21632719039917, 43.29580960954939, 36.839592116219656, 37.435351508004324, 36.98639713014875, 38.640648569379536, 39.42272738048008, 39.147877488817485, 37.83559553963797, 39.92787878853934, 41.54829250063215, 45.6307760647365, 48.94211728232247, 51.31256818771362, 49.64103657858712, 48.03762510844639, 46.90101793834141, 48.50342191968645, 45.04420566558838, 44.249616622924805, 47.42942844118391, 52.68635211672102, 47.35102844238281, 43.02714361463274, 40.06184353147234, 36.450288023267476, 35.97186286108834, 37.52139799935477, 37.29407031195504, 43.68399504252842, 48.24728352682931, 52.07663379396711, 48.45807450158255, 47.06703472137451, 50.65618576322283, 49.35914121355329, 49.192047459738596, 52.997318744659424, 54.009758131844656, 55.14371803828648, 53.48088904789516, 54.366065229688374, 54.07079458236694, 49.98170328140259, 38.07954331806728, 35.38217272077288, 19.8724159853799, 10.326946020126343, 15.558020659855433, 7.145995131560734, 1.247969314455986, 0.2030960348035608, 0.6192745928253446, 18.943486997059413, 59.287811279296875, 50.595632212502615, 30.39855296271188, 43.865395137241904, 51.57516493116106, 61.18604523794991, 48.60716894694737, 15.47647660119193, 0.2904645566429411, 0.10587687404560191, 0.1547756019447531, 0.09816997152354036, 0.12515775194125517, 0.11303485530827727, 0.15332800176526817, 0.16366975754499435, 0.14067092165350914, 0.08693336376122066, 0.11703354359737464, 0.2414360317800726, 0.15787954681685992, 0.13569949913237775, 0.11274522942091737, 0.14607795008591243], [0.011935168045705982, 0.04342724881800158, 0.03185256776799049, 0.026202720490151217, 0.026435268011742404, 0.011881931884480374, 0.007081515031001929, 0.044320197509867806, 0.027236051292025616, 0.025180536322295666, 0.024271743837743998, 0.03652360283636621, 0.0808409471064806, 0.02068875833148403, 0.04450106780443873, 0.04100314514445407, 2.3727535818304335, 16.723085914339336, 41.17792572293963, 36.96084860392979, 33.89588008608137, 18.50712275505066, 25.902507407324656, 33.97916119439261, 32.721040453229634, 4.397160530090332, 0.03300225714753781, 0.08248306291976146, 6.863868304661342, 9.033543195043292, 6.593943817274911, 4.050897487572261, 8.201807345662798, 38.37617581231253, 47.0338397026062, 53.570493016924175, 43.841541971479145, 45.64313691002982, 43.52931077139718, 46.358752727508545, 45.38534484590803, 45.38506344386509, 40.82043048313686, 41.89948225021362, 34.87485694885254, 34.976811340876985, 34.35218218394688, 35.75440856388637, 34.32078674861363, 32.57653529303414, 33.33434057235718, 34.319216455732075, 35.012570244925364, 34.91450684411185, 33.622360774448936, 32.98564175197056, 31.646425110953196, 30.96276753289359, 31.096812180110387, 32.23964841025216, 29.409487315586635, 30.807746274130686, 30.55449833188738, 31.90019416809082, 32.26635728563581, 32.48370041166033, 31.525519507271902, 32.39715365001133, 32.37307814189366, 31.779153074537003, 31.78496524265834, 31.48135675702776, 32.134018421173096, 32.48186261313302, 35.523043973105295, 39.95122473580496, 42.93638277053833, 43.26655421938215, 40.28558247429984, 40.26641239438738, 37.68088347571236, 36.22423185620989, 36.541431018284385, 39.63260119301932, 41.47486741202218, 44.6253091948373, 44.50222185679844, 43.50736836024693, 25.595443929944718, 45.72171756199428, 47.2436648777553, 46.376665183476035, 46.65353700092861, 48.070934772491455, 49.10264846256801, 45.989737374441965, 46.622878074645996, 45.587381090436665, 46.77741643360683, 43.0172632762364, 33.682712827410015, 35.025500842503135, 33.788617270333425, 34.953177043369834, 34.94238649095808, 36.067824431828086, 34.24570451463972, 33.351137842450825, 35.69333389827183, 38.74080337796892, 40.24472706658499, 43.418792724609375, 44.60088627679007, 45.8938696043832, 46.418274470738, 45.212268693106516, 45.00351701463972, 45.466496331351145, 45.619210788181846, 47.556354658944265, 44.423571722848074, 42.835877077920095, 38.3046441078186, 35.32828944069998, 34.43090179988316, 35.313156264168875, 33.04408999851772, 36.52360888889858, 39.78230707986014, 42.9300981249128, 45.698753765651155, 50.69477258409773, 45.86998517172677, 49.651719433920725, 47.60195916039603, 49.01473985399519, 46.82017912183489, 51.37312868663243, 47.835915429251536, 55.45904813494001, 48.43996402195522, 53.47039379392351, 37.16015420641218, 17.516587563923427, 6.96048344033105, 11.908626130649022, 7.758349861417498, 3.174091930900301, 1.4024238607713153, 0.09264926811946289, 0.18436130295906747, 10.08368524483272, 42.37277616773333, 31.310219151633127, 20.198477574757167, 23.80621678488595, 44.52268082754952, 49.24233504704067, 34.669304915836875, 6.970349448067801, 0.1521903428116015, 0.006514817426380302, 0.04117225981982691, 0.08576253801584244, 0.036223059320556264, 0.030418673995882273, 0.011429284566215106, 0.04541365329974464, 0.01583556884101459, 0.021112364350951145, 0.041407518088817596, 0.013455616592961763, 0.01937704666384629, 0.002134470364710848, 0.12001613926674638, 0.0381552590323346, 0.013315561876100088, 0.020823620559115495, 0.0015194984922085755, 0.04526050794603569, 0.03132093897355454, 0.04365630866959691, 0.030747196903186183, 0.04500143649056554, 0.04588871941502605, 0.028966673516801426, 0.04655067782316889, 0.04699994942971638, 0.03350564531449761, 0.02378847593042467, 0.04178862746006676, 0.00835497725555407, 3.037457994052342, 21.500766277313232, 49.132098402295796, 44.49320656912667, 39.74077769688198, 21.783387729099818, 24.707969631467545, 35.40849249703543, 38.07401255198887, 5.136297736849103, 0.024898033356294036, 0.03499558607914618, 7.388251457895551, 10.569482445716858, 7.225040444305964, 5.034167468547821, 8.049223167555672, 39.926228591373985, 47.608525208064485, 53.575975145612446, 45.268510886601035, 46.39238200868879, 45.17403275626046, 46.62738398143223, 46.28362185614449, 47.90911817550659, 42.418411936078755, 44.53864083971296, 37.82021917615618, 36.64915241513933, 35.69724573407854, 37.187203543526785, 36.45187221254621, 35.339243275778635, 35.4006792477199, 36.43971633911133, 37.78777456283569, 37.140494278499055, 36.35845020839146, 35.47589349746704, 33.212733200618196, 32.6935499055045, 32.50576441628592, 33.65307181222098, 32.146528652736116, 31.095773424421036, 31.8391820362636, 33.39459187643868, 33.15447950363159, 32.74695028577532, 33.10782582419259, 34.015698296683176, 34.35286658150809, 34.211759090423584, 33.61904648372105, 33.42756455285208, 32.33687802723476, 33.67916924612862, 37.70665781838553, 43.35131876809256, 44.7718779700143, 45.9669577053615, 41.063443728855674, 43.34893206187657, 39.20830944606236, 38.82153797149658, 38.99879346575056, 42.262445722307476, 43.50815003258841, 46.76247433253697, 46.758517333439414, 44.37320423126221, 27.72897342273167, 47.77281188964844, 48.78188487461635, 49.504302978515625, 49.03406626837594, 49.40862628391811, 50.04489714758736, 46.849979945591514, 47.543302467891145, 48.63779313223702, 47.72767639160156, 45.155001640319824, 35.83953094482422, 35.75690991537911, 35.86689295087542, 36.17936733790806, 37.44634703227452, 37.870277472904746, 35.4368758882795, 35.97159882954189, 36.23914269038609, 39.23404557364327, 41.54769148145403, 45.84311648777553, 47.01161241531372, 47.706421852111816, 48.00298833847046, 48.01616212299892, 46.904759543282644, 45.18266589300973, 46.72192464556013, 48.32406112125942, 45.60379620960781, 45.33267055238996, 40.592074462345664, 37.184066431862966, 35.90491349356515, 35.97795990535191, 35.89282362801688, 37.39118528366089, 41.84450462886265, 44.60881069728306, 49.616561549050466, 51.545909540993826, 49.30699845722744, 50.15195151737758, 48.170123781476704, 49.54615197862898, 49.516590867723735, 52.51937648228237, 52.17177895137242, 54.804350648607524, 50.465537616184776, 51.63972411836897, 38.41218485151018, 19.100698675428117, 13.840592724936348, 9.689393213817052, 6.797692358493805, 4.562817309583936, 1.6858464181423187, 0.012838778219052722, 0.18953867442905903, 11.394403849329267, 48.25893218176705, 29.304621628352574, 16.083747420992168, 32.248076575142996, 49.37484761646816, 56.20944663456508, 41.89086300986153, 9.823710577828543, 0.18553899547883443, 0.07958286175770418, 0.036466744994478564, 0.06566897194300379, 0.009082973236218095, 0.03926723882822054, 0.02233085039603923, 0.04769248601847461, 0.025350265071860383, 0.04667322464021189, 0.03754994133487344, 0.04760682436504534, 0.03842993000788348, 0.07182573407356228, 0.08758384135684796, 0.0371465285175613, 0.22911603429487773, 0.09041857746030603, 0.08059682377747127, 0.14724394466195787, 0.15258153182055267, 0.0727428352194173, 0.060663961938449314, 0.156254238315991, 0.17019927288804734, 0.08351132845772163, 0.07195048952209097, 0.11317912542394229, 0.15177001750894956, 0.10010433915470328, 0.1322199444153479, 0.10800490235643727, 4.259724293436323, 26.35355840410505, 57.83566556658064, 50.32568080084664, 46.760438510349815, 28.378581353596278, 35.989987237112864, 44.8256049156189, 43.80331993103027, 6.240594046456473, 0.13980065977999143, 0.19904496361102375, 9.296558567455836, 12.584708435194832, 13.1023223059518, 10.079180206571307, 9.772853238242012, 41.798236574445454, 48.973342486790244, 54.30753360475813, 46.67495482308524, 47.33974804197039, 44.16590820040022, 46.01801654270717, 47.84750502450125, 48.58210332053048, 45.180633544921875, 46.59438351222447, 39.256026199885774, 38.27925886426653, 37.8680088860648, 39.52427182878767, 37.8356476511274, 37.35186195373535, 37.80141735076904, 38.37048871176583, 39.05814845221383, 39.29222978864397, 37.68180758612496, 36.942251750401084, 34.87235559735979, 33.5726637840271, 34.47926821027483, 36.161909988948274, 32.59464577266148, 34.68842288425991, 32.529325757707866, 34.98896026611328, 33.79978649956839, 35.050997257232666, 34.36214590072632, 36.56942878450666, 35.756308896201, 35.14144543239048, 34.58482871736799, 34.03451749256679, 34.051207065582275, 36.487579005105154, 39.68236071722848, 44.53840807506016, 45.05418675286429, 47.61465351922171, 42.953794956207275, 44.67986992427281, 40.861876487731934, 40.112714767456055, 40.65390648160662, 44.42371416091919, 45.466736044202534, 49.49636466162545, 47.33479050227574, 45.57317202431815, 29.28499644143241, 48.327298981802805, 50.10829945972988, 51.927317006247385, 52.72876044682094, 51.71660940987723, 51.643364974430625, 46.10611275264195, 49.07217713764736, 49.698522499629426, 50.36994777406965, 46.835319246564595, 37.309040205819265, 39.01246404647827, 37.5767126083374, 38.616507053375244, 37.882634844098774, 40.43477072034563, 37.334081513541086, 37.27453197751726, 37.6056935446603, 41.327767099652974, 43.61904328210013, 47.38264274597168, 49.042133126940044, 49.665414333343506, 50.76361880983625, 49.24875865663801, 49.24971750804356, 47.00904158183506, 47.01832784925188, 49.373478821345735, 48.48167405809675, 48.0426139150347, 44.190841811043875, 38.51669270651681, 37.33902515683855, 39.196532249450684, 37.3515180179051, 40.72160972867693, 44.35372148241316, 47.61657122203282, 51.31827960695539, 55.33289316722325, 50.27224915368216, 53.90109872817993, 48.30073949268886, 51.7150217464992, 50.7369064603533, 53.13198178155081, 51.795447145189556, 55.309953689575195, 49.16172552108765, 54.73078312192644, 40.38243341445923, 22.900265489305767, 10.862993461745125, 19.115071024213517, 15.593659707478114, 6.4572519063949585, 3.121418288775853, 0.18724111414381436, 0.39286906165736063, 12.609198229653494, 53.614270142146516, 42.201697622026714, 28.624446834836686, 34.904609135219026, 56.71772125789097, 59.23441437312535, 51.51543474197388, 13.31418330328805, 0.493598399417741, 0.13646680010216578, 0.12767825169222696, 0.17935095966926642, 0.09112430816250187, 0.0892090005800128, 0.10493510815181903, 0.18647941787328037, 0.09660715609788895, 0.1562776749155351, 0.11184629944286176, 0.1355377770960331, 0.08575932854520422, 0.20838411604719503, 0.19870653748512268, 0.1378273849508592], [0.09459505549498967, 0.027190869341471365, 0.020072979320372854, 0.005188265773800335, 0.058221500499972274, 0.050185450818389654, 0.06339096025164638, 0.0331994088898812, 0.010873972355122013, 0.01617422736515956, 0.06618730484374932, 0.029438411417816366, 0.02842261565716139, 0.06943853931235415, 0.034692426810839345, 0.03852481295221618, 2.4072989395686557, 17.74480983189174, 43.92939846856253, 37.12658051082066, 32.7371255329677, 14.138111114501953, 23.26694277354649, 34.69528423036848, 30.390030997140066, 3.733680520738874, 0.02605620103089937, 0.2334671536726611, 15.740108626229421, 7.825887220246451, 8.228095855031695, 7.984988808631897, 9.1704808984484, 39.49483231135777, 42.071252141680034, 37.97610548564366, 36.60850197928292, 45.47377109527588, 44.372756072453086, 48.07026774542672, 44.90385552815029, 45.468629428318565, 40.18015398297991, 37.8673210144043, 35.400349208286826, 34.92845187868391, 31.284364904676163, 31.584061554500035, 30.45850202015468, 32.08557210649763, 32.02970858982631, 33.70062180927822, 32.203837394714355, 33.298536505017964, 30.907324382237025, 31.413253988538468, 31.102117129734584, 31.17777259009225, 31.011439664023264, 33.44166592189244, 33.774998801095144, 35.96287884031023, 37.82298108509609, 36.68548801967076, 34.16196135112217, 32.215190751211985, 31.930769715990337, 32.51857689448765, 31.752496310642787, 32.29988234383719, 31.209126336233957, 33.366674014500205, 33.56934601919991, 32.99443817138672, 31.540951456342423, 36.39472675323486, 38.000740323747905, 37.78175742285592, 34.13302557809012, 34.23767934526716, 34.97152723584856, 35.620482036045615, 36.15698719024658, 39.75455597468785, 41.681176798684255, 43.97943592071533, 42.81320858001709, 44.481318201337544, 25.741809470312937, 41.545544488089426, 45.71607215063912, 46.42959656034197, 45.65055411202567, 43.354171003614155, 38.753282342638286, 39.83006204877581, 40.53950786590576, 42.76683630262102, 47.55173410688128, 43.10930953707014, 34.092246600559776, 32.822769028799875, 33.636896405901226, 34.2039840562003, 32.533268860408235, 34.061427865709575, 33.49842228208269, 32.91967555454799, 33.207768712724956, 33.120343003954204, 32.189680440085276, 35.02175576346261, 39.08723013741629, 39.91900593893868, 42.374516691480366, 44.56269897733416, 45.42783308029175, 44.59930208751133, 46.17120347704206, 46.20028863634382, 47.29546022415161, 46.12210750579834, 41.76452391488211, 37.293691635131836, 34.739339283534456, 34.04520729609898, 32.69958094188145, 33.25555147443499, 36.022334575653076, 37.72188479559762, 40.56867292949131, 41.47413785117013, 47.88738073621477, 49.80420807429722, 49.496291705540244, 34.7277045249939, 42.40651314599173, 46.92754963466099, 49.41592189243862, 47.547617299216135, 51.40700115476336, 53.042940616607666, 53.884832995278494, 36.10985061100551, 17.903336456843785, 4.999903295721326, 5.292336906705584, 5.819309566702161, 0.5472223705479077, 0.024200526498524205, 0.04138614084305508, 7.727195007460458, 39.28784547533308, 43.30935512270246, 34.27246897561209, 17.478094543729508, 31.007378441946848, 45.56553595406668, 38.46611329487392, 10.030176298958914, 0.15526046949837888, 0.05861878953874111, 0.0075907661646072355, 0.061133148547794135, 0.02524700222004737, 0.06439188761370522, 0.053296449062015326, 0.05106932071170636, 0.04309631711138146, 0.07524464811597552, 0.024640948312090974, 0.006836284417659044, 0.07735688691692692, 0.11445935815572739, 0.028490023022251468, 0.04213085338207228, 0.018257777705522518, 0.06608359755149909, 0.008085975440085998, 0.03375579064179744, 0.02081538992933929, 0.05162617065278547, 0.06213978917471, 0.039254682537700446, 0.011282946615080749, 0.04339866213766592, 0.07647876760789327, 0.036615191493183374, 0.029670745200876678, 0.04081072957654085, 0.006392865599731782, 0.05242663162893482, 3.0668332406452725, 21.968126433236257, 51.25600985118321, 42.9410206930978, 39.45323692049299, 18.211502960750035, 24.800986903054373, 36.647189549037385, 35.38884646551949, 4.548152702195304, 0.027644252870231867, 0.1884020875607218, 15.623385838099889, 12.666445306369237, 10.277785778045654, 5.952881736414773, 10.113590291568212, 41.76406185967581, 43.121225697653635, 39.921806062970845, 39.173165457589285, 46.629419803619385, 45.18124846049717, 47.96391861779349, 45.729086126599995, 46.32070091792515, 42.15559632437569, 40.38779047557286, 36.23320892878941, 37.26400545665196, 34.27256277629307, 33.86141702107021, 32.99149213518415, 34.09755849838257, 33.43728160858154, 34.918870312826975, 33.84861149106707, 34.990832805633545, 32.768899645124165, 32.227315357753206, 33.881202016557964, 32.70823492322649, 32.90272542408535, 34.878094809395925, 35.01790298734392, 36.587146690913606, 37.229643140520366, 37.267389229365754, 34.83038847787039, 33.48858363287789, 33.45301233019148, 34.31887946810041, 32.98834112712315, 34.22392191205706, 32.77439219611031, 35.41518708637783, 34.366474628448486, 34.07186753409249, 32.687973976135254, 38.848330225263325, 39.60121965408325, 40.237879616873606, 36.59226751327515, 37.48989486694336, 36.432125432150706, 37.631808349064414, 38.356620107378276, 41.60296440124512, 43.75663498469761, 45.033526284354075, 45.909902572631836, 46.26391329084124, 27.33736773899623, 42.15668371745518, 46.459397384098594, 46.55161387579781, 47.92651299067906, 44.781157289232524, 38.67164100919451, 40.2078286579677, 41.054998193468364, 46.75943102155413, 50.396646227155415, 44.426205090114046, 35.52838713782174, 34.00129120690482, 34.00164556503296, 35.24686350141253, 35.43797022955758, 35.7839731488909, 34.57640402657645, 34.17104959487915, 36.20275150026594, 34.8163948059082, 35.66965096337454, 37.09257255281721, 40.47269398825509, 44.31529099600655, 45.3356374331883, 46.07712139402117, 46.2549501146589, 46.89475761141096, 48.178242751530235, 47.720988750457764, 48.69458770751953, 48.227397782461985, 43.05509621756417, 37.70108188901629, 36.18229947771345, 35.46396344048636, 34.183375699179514, 35.19283430916922, 38.73110369273594, 39.4723653112139, 41.439640045166016, 43.9949825150626, 49.19759907041277, 50.438964230673655, 50.50276606423514, 37.53446756090437, 43.27247061048235, 46.76781749725342, 48.56160960878645, 49.45092691693987, 53.04262099947248, 55.1397054536002, 53.424639906202046, 33.359559059143066, 17.552443742752075, 7.663268974849156, 6.535460829734802, 6.531408292906625, 1.8548331218106406, 0.14253411096121582, 0.007183657875949783, 8.414776580674307, 42.71541615894863, 42.768639360155376, 34.362691334315706, 21.689835446221487, 38.3396178654262, 50.513275214603965, 46.61861188071114, 13.640422940254211, 0.1787847221962043, 0.015896475840626017, 0.019146107270249298, 0.024654510530776212, 0.017294152806113874, 0.027542755905804888, 0.039740184521568675, 0.039020296186208725, 0.02784533841934587, 0.11175091777529035, 0.030389252717473676, 0.07080805368189301, 0.04996533066566501, 0.020769571852205054, 0.05237855403018849, 0.01144688661276762, 0.19437884113618306, 0.1692299313311066, 0.08539682799684149, 0.15061764791607857, 0.20323847287467547, 0.14958991163543292, 0.22056719873632702, 0.09471983808491911, 0.08650488246764455, 0.120836148836783, 0.10804292067353215, 0.09406232408114842, 0.12453583388456277, 0.18585471782301152, 0.11706854243363653, 0.21904107848448412, 4.194465943745204, 27.27456818308149, 58.83494853973389, 49.318056515284944, 45.27321481704712, 22.90015779222761, 33.48225729806082, 44.58662857328142, 41.08422579084124, 5.839336880615779, 0.12385043209152562, 0.8684161497013909, 18.414174965449742, 13.83761715888977, 10.98183458192008, 15.480591671807424, 11.581123658588954, 43.77243171419416, 43.88713257653372, 40.15485211781093, 40.990366050175254, 46.91233655384609, 45.657130581992014, 48.060206753867014, 48.36366932732718, 49.1174898147583, 44.66190535681588, 41.541177545275005, 38.90332869121006, 38.90015683855329, 36.383227484566824, 34.82278714861189, 34.23141207013811, 36.85889768600464, 34.403852462768555, 37.05306509562901, 35.50694499697004, 37.137468338012695, 36.15754304613386, 34.04064927782331, 35.77765376227242, 34.73167542048863, 33.83669533048357, 37.56345544542585, 38.30742686135428, 39.435960224696565, 40.90245049340384, 39.84132507869175, 36.853585788181846, 34.74169819695609, 35.180199010031565, 35.69918428148542, 34.29914658410208, 35.44053758893694, 35.16562516348702, 37.03973150253296, 36.502885886601035, 35.63148103441511, 35.6016663142613, 41.01797124317714, 42.30120277404785, 40.42093685695103, 39.13705914361136, 39.311674322400776, 39.15090342930385, 40.81141866956438, 40.242500168936594, 44.29881681714739, 45.283664907727925, 48.374675273895264, 48.21925449371338, 47.03324910572597, 31.094137123652867, 41.76595524379185, 45.64320639201573, 47.58642646244594, 48.21318524224417, 43.94038357053484, 38.64439364842006, 39.84120001111712, 41.78111273901803, 47.742771353040425, 51.917815344674246, 46.760216167994905, 38.713371889931814, 35.191670485905235, 37.00178739002773, 38.27368988309588, 35.84245613643101, 36.91596324103219, 35.482730524880544, 35.774999550410676, 37.15575252260481, 36.763700417109895, 37.251748834337505, 39.07086018153599, 43.31651176725115, 45.98614168167114, 46.95485952922276, 47.366842542375835, 49.175093855176655, 48.66495711462838, 49.86544254847935, 48.35399396078927, 50.61662966864449, 51.1977596282959, 46.06750161307198, 40.7961117880685, 38.608936991010395, 37.43786675589425, 36.55447278703962, 36.72221619742257, 40.775809151785715, 41.890032700129915, 44.71413149152483, 46.87891224452427, 51.94611883163452, 53.102417196546284, 51.331651415143696, 38.361077376774375, 46.101933411189485, 48.86055932726179, 51.166464941842214, 50.17736802782331, 55.41702890396118, 55.95663295473371, 56.08537265232631, 39.01734515598842, 24.71674346923828, 10.300580212048121, 12.144883121762957, 12.707701972552709, 2.451939812728337, 0.5570743733218738, 0.10179208644798823, 9.525510396276202, 50.159181118011475, 52.601514611925396, 43.877102851867676, 26.707907846995763, 41.9151018006461, 58.03166730063302, 54.60398891993931, 18.3811970778874, 0.4486218142722334, 0.1108426715114287, 0.10305710642465524, 0.14772499884877885, 0.039597108627536466, 0.08714978250541858, 0.12031654029020242, 0.13143505581787654, 0.15958698519638606, 0.2083120827696153, 0.09209901014608995, 0.20428518099444254, 0.12845387150134358, 0.2079133755926575, 0.1032168199973447, 0.0983774403908423], [0.008380295941606164, 0.05828634809170451, 0.014796404334317361, 0.03195461943479521, 0.07270333769598178, 0.07955134380608797, 0.02034076995083264, 0.017659981568743075, 0.03606646361627749, 0.03811575811622398, 0.03913268533402255, 0.02318634225853852, 0.014099185853930456, 0.0468671533412167, 0.04580594153542604, 0.008779276228908981, 2.7747570276260376, 19.61236228261675, 42.390834535871235, 38.731972217559814, 27.64912646157401, 15.288222108568464, 18.772660323551722, 32.68845340183803, 29.81933375767299, 2.8068592250347137, 0.10488412303051778, 0.9819650224276951, 15.482846362250191, 9.592606544494629, 6.555428649697985, 2.4669385850429535, 6.755596697330475, 26.072272743497575, 16.419041429247173, 25.784337656838552, 39.31009360722133, 45.19660745348249, 45.53739922387259, 45.40016882760184, 44.41482394082205, 44.419576508658274, 41.1870938709804, 38.795704569135395, 35.71666247504098, 34.60338735580444, 33.923506123679026, 34.49590914590018, 32.55760840007237, 31.554420539311, 32.744150161743164, 33.436048303331646, 33.26382677895682, 33.070350715092246, 31.467220646994456, 33.57739898136684, 33.35191951479231, 38.678307805742534, 40.840945039476665, 42.904452323913574, 43.342609201158794, 43.342595304761616, 43.828944887433735, 45.179594789232524, 41.4554055077689, 37.735183647700715, 33.52073294775826, 32.51806967599051, 32.76129484176636, 32.88267292295183, 32.96961225782122, 32.87534604753767, 32.719970430646626, 32.065304211207796, 31.320304461887904, 33.658487933022634, 32.46898412704468, 32.17461674554007, 31.150268145969935, 33.17195074898856, 33.43486016137259, 35.55113206590925, 34.90191323416573, 36.981238092694966, 39.69282470430647, 42.73988424028669, 41.82961811338152, 47.206599712371826, 26.466252974101476, 37.6374329158238, 40.68802908488682, 38.3210175377982, 41.514680589948384, 37.49437298093523, 44.34677675792149, 46.413264819553916, 47.777894496917725, 45.1679287637983, 44.976165430886404, 41.89078310557774, 33.9829375403268, 33.62108925410679, 32.445176124572754, 33.21604401724679, 32.82275513240269, 33.741796834128245, 34.43743658065796, 33.41277183805193, 33.25095871516636, 34.26098360334124, 32.93604898452759, 33.53495591027396, 34.32446929386684, 34.89403050286429, 33.90889058794294, 36.84712396349226, 41.39158977781023, 44.66342006410871, 48.27225187846592, 47.12205750601632, 46.66013778959002, 48.17054762159075, 44.56922333581107, 39.35540975843157, 33.479557922908235, 33.770454679216655, 35.38894026620047, 36.613344873700825, 40.82697916030884, 41.02614579881941, 39.724678720746724, 41.34290722438267, 42.02164200374058, 46.57871185030256, 45.36188425336565, 42.94265699386597, 44.618409633636475, 46.16688517161778, 49.28707102366856, 51.07628427233015, 53.15461901256016, 53.322327681950156, 51.81581231525966, 37.44579117638724, 25.3262220791408, 8.450601492609296, 4.154610208102635, 3.244190135172435, 1.140225118824414, 0.0073456419964454, 0.009367895179561206, 5.493442092623029, 38.066279206957134, 35.32660797664097, 23.050379582813807, 29.781400067465647, 37.44432858058384, 46.87808888299124, 44.69769205365862, 13.49114089352744, 0.16410586557218007, 0.07285885792225599, 0.0731639408373407, 0.04259410620267902, 0.06297066887574536, 0.02010525723120996, 0.05146498126643045, 0.019084401295653412, 0.11763623197163854, 0.010424760120388652, 0.036651764530688524, 0.04851366945409349, 0.02366685870635722, 0.011405507002824118, 0.08556958301258938, 0.03147733451000281, 0.01074289296021951, 0.042845174337604215, 0.026969600768227662, 0.059025313439113755, 0.014782370533794165, 0.04918517145727362, 0.0296387556674225, 0.011987406760454178, 0.0752082107854741, 0.069239613200937, 0.030958462173917463, 0.054403041289853196, 0.06319378476057734, 0.02956376736983657, 0.018911013546000634, 0.035443520971706936, 3.891511023044586, 21.929388489042008, 49.10646997179304, 44.77496297018868, 33.484970569610596, 17.839640583310807, 24.913530349731445, 35.39620113372803, 35.705058983394075, 3.8308819106646945, 0.08176838912601982, 0.683618494442531, 14.157807520457677, 9.905540381159101, 5.338262762342181, 2.794791941131864, 8.390226858002798, 29.29506438119071, 18.850732019969396, 28.739144223076956, 41.60238422666277, 45.500229835510254, 45.57803576333182, 46.22271394729614, 45.33489745003836, 45.33110720770699, 43.082096917288645, 40.706348010471885, 36.33840118135725, 37.83079086031233, 35.45452431270054, 35.18036924089704, 33.78634868349348, 33.82612712042672, 35.16319676807949, 35.209329332624165, 34.76659706660679, 33.780109201158794, 32.87761116027832, 35.255736351013184, 35.338135038103374, 41.03958708899361, 41.756012371608186, 44.920281069619314, 45.07053933824812, 46.480752672467915, 44.85731301988874, 47.51437711715698, 42.931532927921836, 38.67968007496425, 34.90023871830532, 34.6093419619969, 33.877053941999165, 34.98997817720686, 33.28447682516915, 35.33268070220947, 34.505914551871165, 34.73250920431954, 33.44448341642107, 34.65366104670933, 34.33706290381295, 33.397656032017295, 33.770319189344136, 34.425951208387104, 35.22812768391201, 38.32597507749285, 36.68634612219674, 39.47970955712454, 40.93001399721418, 45.20492097309658, 43.6814797946385, 47.31012439727783, 28.675599472863333, 37.64639956610543, 41.24447209494454, 38.259463446480886, 41.68539088112967, 38.29538563319615, 44.023265157427105, 47.15248366764614, 49.30817270278931, 46.622593198503765, 46.61032615389143, 43.79066726139614, 35.105054242270334, 36.11306415285383, 34.64197417667934, 34.87310252870832, 35.51379592078072, 35.84074340547834, 34.67010743277413, 34.4819015775408, 35.28716652733939, 36.0913336617606, 33.659165382385254, 34.58663524900164, 36.18720143181937, 38.32982785361153, 36.38383197784424, 38.898055008479524, 44.1259560585022, 46.72128193719046, 50.01254286084856, 48.584038393838064, 47.80880355834961, 49.82022019795009, 46.54173353740147, 41.91462237494332, 34.78498200007847, 34.647595269339426, 36.30210031781878, 37.59041098185948, 41.38999169213431, 42.102654525211875, 41.58404793058123, 41.93078735896519, 43.78463969911848, 48.81528486524309, 46.15016433170864, 42.00060633250645, 43.898916721343994, 46.204811913626536, 49.462155205862864, 52.51657983234951, 54.219659737178254, 55.78595393044608, 53.15367405755179, 40.61507994788033, 19.638523987361364, 8.539433343069893, 6.10749739408493, 5.397328095776694, 2.042173057794571, 0.08514752744563989, 0.04284372227266431, 5.978292167186737, 43.42850283214024, 40.29865550994873, 28.750309978212627, 31.065277780805314, 39.82370444706508, 51.107075214385986, 49.59429604666573, 16.672522136143275, 0.22351848679993833, 0.0334319530187973, 0.031203932394938808, 0.03497811040974089, 0.04929011707593288, 0.016365173904757415, 0.02567133936099708, 0.07519346621951886, 0.03955463572804417, 0.06790689578545944, 0.07916926752243723, 0.10565419920853206, 0.056808067951351404, 0.06842829566448927, 0.023333036440557668, 0.037343497055449655, 0.10721120637442384, 0.17570363038352557, 0.08239329273679427, 0.21202649202729973, 0.09305156474666935, 0.18819874418633326, 0.09474016699407782, 0.1139518953859806, 0.13799947500228882, 0.14187928395611898, 0.13700839318335056, 0.0972083652658122, 0.13338816458625452, 0.12468108109065465, 0.26718784709061894, 0.09497911310089485, 4.576027137892587, 28.65610977581569, 57.07210717882429, 51.37866987500872, 39.11447402409145, 24.296759605407715, 27.465857301439556, 43.00280407496861, 40.18775531223842, 4.662640341690608, 0.332932000713689, 2.438192584684917, 18.712235314505442, 12.91746721948896, 14.575406415121895, 6.502935877868107, 8.715767332485743, 31.3376020022801, 19.470954281943186, 30.900358813149587, 43.36552436011178, 45.06007187707083, 47.50518465042114, 47.43095704487392, 47.45992061070034, 47.96134431021554, 45.85130146571568, 42.38197210856846, 38.70894588742937, 39.6636700630188, 38.0261081968035, 38.11662585394723, 35.755919797079905, 34.534013066973, 37.42474855695452, 37.79992348807198, 37.5561146736145, 35.863915647779194, 35.57080936431885, 37.33930655888149, 37.240471908024375, 44.74338340759277, 44.4939535004752, 48.193945680345806, 48.38627529144287, 47.12147038323538, 46.679068156651084, 49.189910888671875, 46.43564149311611, 40.60480008806501, 36.41138505935669, 36.29088592529297, 35.809608527592246, 36.85003873280117, 36.140242031642366, 36.72977931158883, 35.86573607581002, 35.83325324739729, 35.57589544568743, 37.113139220646445, 36.44131095068795, 34.88125276565552, 35.47068582262312, 36.10976028442383, 37.363604409354075, 39.715375082833425, 39.119348185403005, 39.97882298060826, 43.28597443444388, 46.87747744151524, 45.74023451123919, 49.18010350636074, 32.2792010307312, 37.67311538968767, 40.242190974099294, 37.616244384220664, 41.481169428144185, 38.418670994894846, 44.60537828717913, 49.23930563245501, 51.0297452381679, 48.22629301888602, 50.0083635193961, 44.88064507075718, 37.33220897402082, 38.08001232147217, 36.343945843832834, 36.864463193076, 36.17313827787127, 36.90276861190796, 36.108318533216206, 36.658619335719514, 36.81175068446568, 39.781660897391184, 35.94524778638567, 37.53225455965315, 38.024621282305034, 39.81398739133562, 37.837415967668804, 40.96364675249372, 45.919814177921836, 48.513840743473594, 51.54591996329171, 51.8796523639134, 48.957788944244385, 51.86695800508772, 48.61031648090908, 43.219858850751606, 36.731234959193635, 36.68363632474627, 39.23241969517299, 39.96944291251046, 44.942303385053364, 45.629535811288015, 44.487502098083496, 45.06593268258231, 46.29443325315203, 50.66384962626866, 48.79484326498849, 45.52218614305769, 44.84522662843977, 46.99344287599836, 52.254399980817524, 55.24993862424578, 55.36794682911464, 58.63051169259207, 55.45272874832153, 40.68723004204886, 29.435411044529506, 17.43093364579337, 9.86907970905304, 11.35852769442967, 3.9964652998106818, 0.18707826573933872, 0.20877553575805255, 7.159225804465158, 49.00813559123448, 45.47597714832851, 36.40044512067522, 40.158892495291575, 47.321349212101524, 58.85406303405762, 58.55207347869873, 21.81336225782122, 0.3117646665445396, 0.15141210385731288, 0.14865653243448052, 0.1057995685509273, 0.21342016224350246, 0.12739994376897812, 0.0888593854116542, 0.11104286648333073, 0.1699112347726311, 0.1026802955727492, 0.09915929593678031, 0.19015303360564367, 0.10759516898542643, 0.1110878601404173, 0.2756409820701395, 0.15463765577546187], [0.06575564800628594, 0.03613204741850495, 0.012061887853113669, 0.05029225562300001, 0.056369988779936514, 0.030860661529004574, 0.03975193335541657, 0.021409303149474517, 0.016493617191112468, 0.05960415130747216, 0.05658378159361226, 0.03385272954723664, 0.034273899625986814, 0.02691030189661043, 0.050885471648403575, 0.057342784080122194, 2.5669802682740346, 21.730187109538488, 42.69627734592983, 41.15945741108486, 26.895564794540405, 11.637662019048419, 22.426339285714285, 43.047484466007774, 27.97669928414481, 3.104975376810346, 0.06872289521353585, 0.33005265093275477, 10.676680990627833, 24.278473683765956, 17.790197202137538, 0.629475362598896, 5.804156848362513, 17.758678436279297, 21.97708092417036, 38.08540064947945, 48.987450804029194, 46.643371786390034, 45.53829206739153, 43.738218784332275, 44.583352497645784, 43.466314928872244, 40.163325445992605, 37.60725341524397, 34.690444810049875, 33.92236314501081, 31.872279780251638, 33.9485821723938, 34.898546831948416, 35.03319249834333, 33.92260980606079, 32.37485340663365, 35.02552168709891, 32.91032327924456, 30.88372482572283, 33.55163158689226, 37.21519783564976, 44.11656209400722, 44.66335753032139, 44.18301813943045, 43.939306599753245, 44.9876959664481, 44.12880481992449, 43.654572895595, 41.4457996232169, 41.36152492250715, 38.9700939314706, 33.489935057503835, 31.89986412865775, 31.58989109311785, 32.23507302148001, 32.96422740391323, 31.83228247506278, 30.814176831926616, 30.14019809450422, 32.56763465063912, 32.74929877689907, 32.04601253782, 31.639021805354528, 33.919979912894114, 34.33792448043823, 33.94863428388323, 34.204546860286165, 37.86954096385411, 37.227979046957834, 43.20012249265398, 40.885785239083425, 47.39794962746756, 26.985422372817993, 36.183779444013325, 43.25809131349836, 40.96777745655605, 46.21202066966465, 47.91119221278599, 48.24369478225708, 43.760282788957866, 44.99374089922224, 43.75375495638166, 43.56818246841431, 34.87741388593401, 33.52153199059622, 34.026457582201274, 35.02482339314052, 32.96393557957241, 33.91205896650042, 33.56066077096121, 33.98571334566389, 33.02756370816912, 32.5514349256243, 32.70839473179409, 33.12177780696324, 31.25819798878261, 31.61793749673026, 32.37714631216866, 33.92247779028756, 33.6937187739781, 32.5897125516619, 36.96649054118565, 41.21087755475725, 45.72298560823713, 47.723253863198416, 47.28038610730852, 42.95579603740147, 40.11035932813372, 36.303747040884836, 33.82724578039986, 36.77360507420131, 46.60995442526681, 45.95655277797154, 45.91811534336635, 45.92300687517439, 44.48187058312552, 44.14410127912249, 48.416298457554404, 48.355974197387695, 46.767591680799214, 47.78113235746111, 47.82448564256941, 50.15557847704206, 50.414781025477815, 49.275644711085725, 50.581235545022146, 53.54212352207729, 47.19926241465977, 24.997419425419398, 8.001271043504987, 5.154624913419996, 4.124048122337886, 2.4432246003832137, 0.08903394533055169, 0.04443875114832606, 4.618842806134905, 32.61974614007132, 44.15384612764631, 26.537494591304235, 23.62175600869315, 36.99337659563337, 44.609953675951274, 45.48845611299787, 16.122000728334697, 0.35331733684454647, 0.06921595947018691, 0.04055851811010923, 0.022286755797852362, 0.020947370079479048, 0.010395813816493111, 0.035435565148613284, 0.06597189711672918, 0.010766399957771813, 0.028523067677659646, 0.04294627605538283, 0.01369156442316515, 0.03873248538002372, 0.030662444486681904, 0.03548916262973632, 0.07052813763064997, 0.07109420546995741, 0.010568262643313833, 0.0005336382652915615, 0.021405048734907593, 0.06896760208266121, 0.010819703124330511, 0.04846283021782126, 0.03799804586118885, 0.024720350479973213, 0.006504751359378653, 0.035609059767531495, 0.01456066600180098, 0.04764254244842699, 0.019356953545606563, 0.026354030406634723, 0.05539146664419344, 3.52437515769686, 25.922683238983154, 49.646515233176096, 46.0801681791033, 33.31032759802682, 18.777586596352712, 23.895579304013932, 42.93790790012905, 33.128764220646445, 3.1378299338476996, 0.17599662180457795, 0.34055270893233164, 12.655904020581927, 23.113945177623204, 12.53367304801941, 4.261308482715061, 6.864807179995945, 20.80686010633196, 23.92413640022278, 41.01429912022182, 48.671926157815115, 46.04452044623238, 45.28092384338379, 45.02256897517613, 45.59037923812866, 45.88258225577218, 41.76509714126587, 39.91897119794573, 37.11768681662423, 36.32967076982771, 35.588454314640586, 35.45166860307966, 36.747785568237305, 36.23656490870884, 36.22418669291905, 34.16781520843506, 36.11745888846261, 34.471972601754324, 31.640765803200857, 34.95223208836147, 39.089557783944265, 45.71131263460432, 47.424210344042095, 45.7933361189706, 45.579814502171104, 46.11333540507725, 45.40553978511265, 44.7794897215707, 43.927581514631, 43.68507548740932, 39.513505595070974, 35.9091032573155, 32.68157468523298, 33.44743640082223, 33.764899594443186, 33.08262818200247, 33.82001270566668, 33.238476276397705, 32.19529111044747, 33.82015514373779, 34.07296534946987, 34.02184050423758, 33.198739528656006, 36.03870800563267, 36.28881188801357, 36.44361775262015, 36.19430249077933, 39.88106530053275, 39.276273250579834, 45.62509938648769, 43.290059975215364, 49.825896876198904, 28.192824738366262, 37.844749791281565, 43.91974742071969, 41.205381529671804, 47.45539385931832, 49.10323905944824, 49.5332978112357, 47.1636563709804, 47.29343482426235, 45.261472361428396, 44.833355631147114, 36.603395053318565, 35.02964891706194, 35.62659297670637, 35.6627687726702, 34.82648706436157, 35.25421469552176, 35.55475902557373, 35.107541697365896, 34.75020279203142, 34.08718831198556, 34.023834637233186, 34.36097860336304, 32.59076172964913, 32.753617082323345, 34.0699394089835, 35.202408926827566, 35.267596926007954, 34.432732650211875, 39.53745256151472, 45.229170186179026, 48.207150731767925, 50.338291781289236, 50.178500584193635, 46.86120476041521, 42.17354004723685, 35.956750529153005, 35.36629261289324, 38.55822556359427, 47.6550156048366, 46.72430092947823, 47.80893210002354, 46.89935384477888, 46.17330183301653, 46.11997788293021, 49.158484186444966, 48.617063181740896, 48.79601403645107, 47.988577774592805, 48.39206314086914, 51.81003488813128, 52.23217616762434, 51.24964182717459, 53.49956580570766, 55.5083247593471, 45.69194105693272, 21.4558652809688, 8.175110629626683, 5.018070663724627, 3.9230957967894415, 2.5226344764232635, 0.11958425172737666, 0.020293138488861065, 5.393594741821289, 37.06184761864798, 46.65281091417585, 35.61732407978603, 30.27865137372698, 42.28608001981463, 50.75323820114136, 51.50560304096767, 18.88488415309361, 0.5517087898084095, 0.12552878846015247, 0.05490990694878357, 0.03611496190673538, 0.014238619711250067, 0.03248975286260247, 0.020122851644243513, 0.09250967311007635, 0.020529114308633974, 0.03548143072319882, 0.030904209906501428, 0.009216868551447988, 0.02340416726656258, 0.022994997079617212, 0.026306215740208114, 0.06691017534051623, 0.12879457750490733, 0.1210998682571309, 0.11713535099157266, 0.10351939911821059, 0.09531925592039313, 0.10594630174871002, 0.06758780112223965, 0.09829061504985605, 0.08032940634127174, 0.1166209400232349, 0.13506082126072474, 0.0829583563442741, 0.14767841063439846, 0.131878614159567, 0.13964849151670933, 0.1304199674299785, 4.766007389341082, 32.513049602508545, 57.157563073294504, 51.28706135068621, 39.98346437726702, 19.60746727670942, 30.523412091391428, 52.982553822653635, 38.13323204857962, 4.456082556928907, 0.326196943542787, 0.7019345430391175, 14.165760602269854, 29.568503788539342, 37.33370631081717, 5.031935794012887, 7.039808852331979, 23.69554761477879, 27.183862924575806, 44.44483321053641, 49.44824838638306, 46.5186550957816, 46.69052226202828, 47.28366218294416, 48.84063189370291, 47.56676306043352, 43.46181944438389, 40.800513471875874, 38.68778167452131, 38.71909373147147, 37.25231858662197, 37.22041245869228, 39.845073631831575, 38.598841258457725, 37.72541100638253, 36.069693497249055, 37.84773751667568, 35.7730644771031, 32.94928877694266, 37.10076795305525, 40.948402404785156, 47.792944295065745, 50.134719984872, 48.04406608854021, 44.89468043191092, 47.836822169167654, 47.56877456392561, 47.311260427747456, 45.0978353364127, 46.067102091653005, 42.16782862799508, 37.32785245350429, 34.78702129636492, 36.04489885057722, 36.32097509929112, 36.116753646305625, 34.5476975440979, 34.198571409497944, 33.20292581830706, 37.47785016468593, 35.80906309400286, 36.62634147916521, 35.38635206222534, 37.43830449240548, 38.18210915156773, 37.80229977199009, 38.4428368295942, 42.83460555757795, 41.30311141695295, 48.081756591796875, 45.61810949870518, 49.5730310848781, 32.113093921116416, 38.08184664590018, 43.671384062085835, 42.28892878123692, 48.51387201036726, 51.035050187792095, 52.15992532457624, 48.8385648046221, 49.69295351845877, 48.58111320223127, 46.742199489048545, 38.27923801967076, 36.82721390042986, 36.76797008514404, 38.5364533833095, 36.13518026896885, 36.983763762882774, 36.73616818019322, 37.6843193599156, 36.455071857997346, 35.59845277241298, 34.633761405944824, 35.671985558101106, 35.16680983134678, 34.78288017000471, 35.87885774884905, 37.12805700302124, 38.32429708753313, 35.078821318490164, 40.43094226292202, 46.270538398197715, 49.92699316569737, 51.6990304674421, 51.03130510875157, 47.89085136141096, 44.95901032856533, 39.77260044642857, 36.303882530757356, 40.57474912915911, 50.960395268031526, 50.70713342939104, 48.74890177590506, 49.47093425478254, 47.9145690373012, 48.20311382838658, 51.51231847490583, 52.56616217749459, 49.53359310967581, 49.88624545506069, 49.094133445194785, 52.621685232434956, 54.0217924118042, 52.617248807634624, 54.962974548339844, 57.190997804914204, 50.7741870198931, 30.07352318082537, 13.587209292820521, 10.214846389634268, 9.50991255896432, 3.899368567126138, 0.21191437090081827, 0.11753708443471364, 6.247457563877106, 43.262354033333914, 55.321529388427734, 36.66967739377703, 34.67371007374355, 49.092229638780864, 58.00636543546404, 58.014421871730256, 23.62719123704093, 0.9764662832021713, 0.2971961125731468, 0.10832610726356506, 0.12260632456413337, 0.15274385096771376, 0.12289991309600216, 0.12475840694137982, 0.16733506800872938, 0.08647639756756169, 0.08409496356866189, 0.12502169209931577, 0.0962864261652742, 0.17488543928733893, 0.10255868174135685, 0.11351276109261171, 0.09577509574592113], [0.02342707460879215, 0.02518597647680768, 0.029255617476467575, 0.051886867199625285, 0.05528760328888893, 0.029533290969473974, 0.02747191854619554, 0.06420538547847952, 0.04197397608576076, 0.03011079551652074, 0.021739615692890117, 0.03460807812267116, 0.02990472103868212, 0.056616558227688074, 0.04564540693536401, 0.0353974518366158, 2.261403053998947, 27.915261575153895, 48.90806416102818, 41.846429279872346, 23.538184813090734, 13.915967651775905, 50.43788725989205, 48.779734407152446, 29.17023651940482, 3.582885069506509, 0.09628573405955519, 0.9506802154438836, 12.281353558812823, 14.30941026551383, 7.495254584721156, 1.852451626743589, 3.9785315649850026, 28.29033749444144, 42.107278551374165, 49.56042357853481, 45.28947012765067, 45.21100412096296, 45.46829244068691, 47.413312094552175, 45.57278292519705, 42.75088323865618, 37.067802224840435, 36.398159163338796, 32.62909494127546, 33.96069983073643, 33.47132083347866, 34.643905775887625, 32.4362998008728, 31.81375162942069, 33.16751085008894, 32.61395829064505, 30.450237137930735, 30.713480063847133, 31.006440435137065, 33.43004853384835, 35.98835441044399, 42.25710950578962, 43.209419182368684, 43.319468225751606, 45.48985617501395, 42.81901379993984, 42.92963259560721, 40.914331912994385, 40.30006946836199, 42.27182231630598, 39.96979379653931, 36.72378996440342, 34.76039579936436, 34.14350693566458, 32.07774148668562, 32.32067135402134, 31.09136826651437, 32.48094892501831, 31.303034714290074, 31.056140899658203, 32.55294615881783, 32.636515617370605, 31.843767847333634, 34.711702823638916, 33.581981318337576, 36.13408245359148, 35.17333418982369, 35.128257751464844, 38.92309979030064, 42.670006207057405, 43.72446135112217, 48.918514251708984, 27.828320503234863, 34.9763423374721, 45.67722824641636, 44.62377711704799, 44.769015312194824, 42.31149305616106, 42.769400187901084, 40.59323828560965, 41.68300417491368, 37.26900468553816, 34.74549886158535, 32.69435589654105, 33.541702611105784, 34.26937355313982, 33.815670081547324, 33.67448616027832, 33.88392571040562, 33.02183839253017, 33.45151499339512, 32.63917677743094, 34.39401728766305, 33.89117268153599, 33.60339914049421, 32.53276859010969, 33.34089272362845, 30.384059020451136, 33.43572173799787, 31.866234847477504, 31.244273798806326, 31.26677553994315, 33.55396965571812, 36.23271908078875, 42.483186517442974, 42.169576099940706, 42.515568596976145, 40.367706707545686, 36.76501362664359, 35.332969052451, 40.74765852519444, 46.44140502384731, 47.651531083243235, 48.006087235042024, 48.735151290893555, 47.813378947121755, 48.45585107803345, 45.51449448721749, 42.14141157695225, 46.97125032969883, 47.94456788471767, 51.280505725315635, 49.32435853140694, 51.554441928863525, 48.9004419871739, 50.96428973334176, 52.361992835998535, 48.53272247314453, 21.427560056958878, 6.957695909908839, 3.4867934371743883, 0.9491670280694962, 1.5267600289412906, 0.0957401715485113, 0.05429855707500662, 2.504507060561861, 32.26191738673619, 38.21864972795759, 19.9672988482884, 17.138812269483292, 35.67842653819493, 49.13222694396973, 44.456537451062886, 12.84575833593096, 0.7104698621800968, 0.03597914633740272, 0.03050640518111842, 0.04225948665823255, 0.03707323655752199, 0.055423201727015634, 0.020881168810384612, 0.037183420466525216, 0.014156669644372804, 0.05178201657586864, 0.02744763038520302, 0.020775334310850928, 0.03636892060084002, 0.045777253074837584, 0.024536202861262218, 0.04365926029692803, 0.016064270765387585, 0.04931073436247451, 0.028612016833254268, 0.038394452804433446, 0.04174273135140538, 0.0032818830472284128, 0.021612678754276464, 0.009886819253941732, 0.0755839766934514, 0.026313179205836992, 0.01925233192741871, 0.027883314328002076, 0.06380697685692992, 0.021936131308653524, 0.06724829612565891, 0.08201585763267108, 3.292358087641852, 31.847617149353027, 54.719533988407676, 47.684531552451, 28.598107951028005, 13.17492229597909, 38.235940320151194, 51.456941332135884, 32.69803844179426, 3.5919852554798126, 0.0610765383711883, 0.4762016843472208, 12.100152356284005, 15.693329879215785, 9.716928924833026, 4.167552096503122, 6.299651563167572, 32.14145646776472, 42.53857408251081, 47.88808250427246, 44.80981513432094, 45.662379946027485, 45.9653457232884, 48.41511378969465, 46.877480915614534, 44.50703001022339, 38.49303756441389, 39.039992809295654, 34.31018727166312, 35.399706499917166, 35.57346357618059, 36.424708230154856, 35.58034576688494, 35.087131364004954, 34.47266394751412, 34.76596825463431, 32.74249301637922, 33.03399426596505, 32.312406471797395, 34.805368014744346, 37.40218080793108, 43.34862634113857, 43.577183859688894, 42.27499416896275, 47.18169389452253, 45.6202460697719, 43.926633085523335, 43.94405916758946, 42.213249002184185, 43.87317017146519, 42.132684639522004, 37.7757784979684, 36.417648860386436, 35.913299969264436, 34.252510275159565, 34.08852236611502, 33.78001192637852, 33.472158091408865, 33.20584406171526, 33.66771861485073, 33.57530409949166, 34.09342432022095, 33.186225822993684, 36.17151934759957, 34.57988159997122, 37.63296175003052, 36.76971755708967, 37.553689752306255, 40.75370693206787, 43.09108788626534, 45.49490751538958, 49.1048857825143, 30.598497799464635, 34.45335142953055, 46.89569214412144, 46.991754463740754, 46.025134972163606, 44.8565730367388, 45.64534643718174, 43.50916794368199, 43.19315692356655, 40.09274564470564, 36.364317962101524, 33.01160022190639, 34.80979749134609, 35.91051026753017, 36.6041385105678, 35.39157363346645, 35.55850757871355, 34.308220931461875, 34.806337288447786, 34.27995565959385, 35.11533062798636, 34.88000903810774, 34.39838770457676, 33.32749659674508, 34.79504646573748, 32.64161559513637, 34.00897938864571, 32.97426755087716, 34.24588516780308, 33.99005944388253, 36.50115231105259, 38.441214425223215, 45.79192910875593, 45.48693445750645, 44.841759477342876, 42.29469926016671, 38.48771871839251, 36.27191734313965, 42.11670725686209, 48.069691044943674, 48.44482776096889, 49.93832220349993, 51.368066923958914, 49.73925978796822, 50.3469249180385, 47.13550921848842, 46.076791354588096, 49.93332644871303, 49.46185295922415, 50.7359093938555, 51.071795736040386, 53.93611070087978, 51.41563776561192, 53.51509502955845, 53.51927089691162, 49.674193382263184, 22.193449565342494, 7.456928321293422, 7.152136904852731, 3.6197283267974854, 2.594848624297551, 0.04958624332877142, 0.046499061664300304, 3.1670955291816165, 36.76685489927019, 44.24328333990914, 21.680667298180715, 21.47732652936663, 41.08710234505789, 53.78935432434082, 50.73162235532488, 17.39117952755519, 0.7994871969733919, 0.01960207601743085, 0.035730208802436075, 0.010110076782958848, 0.07268249988555908, 0.04861411299290402, 0.03637626913509198, 0.0698790035343596, 0.020296743206147636, 0.06053273326584271, 0.05576838266902736, 0.035018988751939366, 0.0400841101737959, 0.04197636113635131, 0.038088769385857243, 0.03056857255952699, 0.1265986074826547, 0.10792226357651608, 0.15832021459937096, 0.10014339563037668, 0.18110818894846098, 0.13124737303171838, 0.08319824561476707, 0.17441111616790295, 0.18268362512545927, 0.09137913198875529, 0.09231384111834423, 0.11906348967126437, 0.22724933017577442, 0.15886689669319562, 0.2065557762980461, 0.1357642856559583, 4.3870461242539545, 37.947788102286204, 60.23963805607387, 54.005102838788716, 34.98298828942435, 22.470778226852417, 57.76093421663557, 56.86954981940133, 36.73494529724121, 5.064127666609628, 0.19510734347360476, 1.4798478548015868, 15.110162360327584, 15.734643868037633, 9.129668048449926, 5.446916086333139, 6.214767158031464, 35.027053764888215, 43.42623424530029, 50.56092596054077, 46.68329960959298, 47.37635115214756, 47.129558086395264, 51.51631716319493, 48.73461627960205, 47.222368649074006, 39.5907313483102, 40.936256953648154, 36.74790368761335, 37.95544849123274, 38.62075935091291, 39.28093549183437, 36.47913694381714, 35.94864892959595, 36.76674025399344, 36.470736571720664, 33.53385809489659, 34.110513414655415, 34.50067213603428, 36.381667613983154, 40.16252292905535, 45.66438102722168, 44.40951204299927, 43.06210000174386, 49.20085777555193, 47.36220809391567, 47.37998506001064, 46.311108929770334, 43.7215187890189, 46.228008474622456, 43.9429474558149, 40.420116969517295, 38.32530457632882, 38.69574083600725, 37.51072209221976, 35.195453780038015, 35.96210411616734, 36.21526173182896, 35.57222332273211, 34.47390072686331, 36.386684213365825, 36.24523278645107, 35.78457069396973, 37.652725900922505, 36.619646889822825, 40.513792582920615, 40.28867094857352, 38.980102811540874, 43.904072284698486, 45.384611810956685, 47.91713292258126, 51.23280981608799, 32.428694997514995, 35.45776217324393, 47.6248847416469, 50.21473543984549, 47.78158746446882, 46.692196777888704, 47.073802266802105, 45.06312561035156, 46.24272475923811, 41.510709694453645, 37.860150473458425, 36.44968352999006, 36.689816747392925, 39.28674765995571, 37.66193921225411, 37.020116737910676, 37.57707391466413, 35.45567076546805, 36.118382998875205, 35.86399902616228, 37.38170794078282, 36.54253230776106, 36.092872687748496, 35.466214656829834, 36.22585426058088, 34.122714451381135, 37.07239498410906, 34.590182304382324, 34.602160998753135, 35.875612940107075, 37.36866964612688, 39.51604516165597, 46.77432795933315, 46.948296955653596, 47.13439403261457, 45.24894823346819, 40.78554357801165, 39.53489909853254, 43.84696504047939, 50.303835664476665, 50.44174003601074, 52.4244293485369, 52.47973700932094, 51.96529933384487, 51.48340007237026, 48.92727940423148, 48.29218626022339, 52.400555338178364, 52.199665546417236, 54.49406841823033, 53.48363011223929, 56.72366196768624, 52.74273674828665, 56.32074287959507, 56.749856676374165, 53.74071346010481, 23.791724579674856, 9.519135424068995, 8.431777085576739, 7.902181914874485, 4.327255138329097, 0.30849059937255724, 0.2194389442780188, 3.3994254853044237, 42.52631746019636, 48.71487644740513, 28.55604181970869, 26.7546101638249, 47.44879307065691, 59.69124453408377, 59.378957748413086, 21.688808849879674, 1.1915396281651087, 0.11675937473773956, 0.19360024934368475, 0.15186769941023417, 0.15978842867272242, 0.18045944161713123, 0.12575672194361687, 0.18585923686623573, 0.1278926958995206, 0.1314013326274497, 0.1413319640393768, 0.15796593789543423, 0.1384109929203987, 0.10023285368723528, 0.10087558241294962, 0.10228604637086391], [0.05238351412117481, 0.010902885580435395, 0.0413003333045968, 0.08683782603059496, 0.039958655834198, 0.09728998624320541, 0.051368015219590495, 0.016987209008740525, 0.010900599765591323, 0.028465846819537025, 0.00966523855458945, 0.05369230639189482, 0.054010929473276646, 0.06422448623925447, 0.05635474549074258, 0.028921693430415223, 4.034145815031869, 24.6939012663705, 40.354536397116526, 43.733115332467214, 31.32849291392735, 40.873271533421104, 58.23060464859009, 45.39922734669277, 26.000624656677246, 4.305615842342377, 0.003934724913311324, 11.28717838014875, 37.34988866533552, 12.371053065572466, 7.847146102360316, 5.931291077818189, 3.553248179810388, 23.6408531325204, 43.552170344761436, 49.12395511354719, 47.677923815590994, 48.55028404508318, 49.185220854622976, 47.65350784574236, 42.62116731916155, 41.42452423913138, 37.81008175441197, 34.89043828419277, 33.31673731122698, 35.00180401120867, 34.709250109536306, 33.01306976590838, 32.57751151493618, 31.768977437700542, 31.01306206839425, 31.538853100367955, 31.2282304082598, 31.14193378176008, 30.958664621625626, 33.420373167310444, 36.92196648461478, 41.92952626092093, 45.130502292088096, 43.547584533691406, 44.30729014532906, 40.49932295935494, 38.54824447631836, 36.238882132938926, 39.11205605098179, 41.30162797655378, 41.72808756147112, 38.35701962879726, 36.392027378082275, 33.297310147966655, 32.42444617407662, 31.62384693963187, 30.82439763205392, 32.584789752960205, 30.69778755732945, 32.88456630706787, 31.848555156162806, 31.26123435156686, 32.59330129623413, 34.44271721158709, 31.768553597586497, 34.89422852652413, 33.28230898720877, 34.77044289452689, 35.6775267464774, 41.58494772229876, 39.60140725544521, 49.06126846585955, 28.766205719539098, 36.755015168871196, 50.24876076834542, 41.092643533434185, 43.237222399030415, 40.5319447517395, 38.47829696110317, 34.69776126316616, 36.02178566796439, 31.679456847054617, 33.720128876822336, 33.44501495361328, 34.147050516945974, 34.03084189551217, 34.31586047581264, 33.387803486415315, 34.67904281616211, 32.59660863876343, 35.001362800598145, 34.81166655676705, 35.59911632537842, 34.452920641217915, 35.325444153376985, 32.32017803192139, 33.488972731998985, 33.85456262316023, 34.661828654153005, 36.234852177756174, 32.78767715181623, 32.823161602020264, 31.415856088910783, 31.77399751118251, 34.011897632053916, 37.616862773895264, 38.171266487666536, 38.732872009277344, 34.527224676949636, 34.827432019369944, 39.162472179957796, 48.40404183523995, 45.75018433162144, 46.14346974236624, 45.501998152051655, 46.12737076623099, 46.368657384599956, 49.22643062046596, 49.07957002094814, 48.93185479300362, 46.86625957489014, 48.18677166530064, 50.012435163770405, 50.54535852159773, 48.01226418358939, 48.90851926803589, 52.260993821280344, 53.22401067188808, 28.23186492919922, 6.367886347430093, 2.794258232627596, 1.345226181404931, 2.547900080680847, 0.12023050204983779, 0.019011967682412693, 2.6064642752919878, 28.60351538658142, 48.886298928942, 44.89455883843558, 35.12366499219622, 45.23760182516915, 51.24347530092512, 40.46675327845982, 14.749498741967336, 0.85094153881073, 0.03314041027000972, 0.04377574101090431, 0.035604812138314755, 0.048573906400374005, 0.09201939763235194, 0.03135405148246458, 0.05308167237256255, 0.02231119493288653, 0.0252582574196692, 0.03535862945552383, 0.019654682837426662, 0.02278734161518514, 0.06948988405721528, 0.020694312140611664, 0.01005796529352665, 0.0516551237420312, 0.030121017646576678, 0.0298052783390241, 0.008278052588658673, 0.04328657493793538, 0.01267062027805618, 0.020122814324817488, 0.012727610434272459, 0.016610856167972088, 0.022200729431850568, 0.01821505374807332, 0.013977675499128444, 0.0776471234858036, 0.04957933923495667, 0.039206811892134805, 0.07773432202105011, 4.7601135798863, 30.73523834773472, 47.94811841419765, 48.1758907863072, 35.70783131463187, 37.43156473977225, 60.350559098379954, 51.29061188016619, 30.449205330439977, 5.062508302075522, 0.010456982052086719, 10.919383304459707, 36.66043976375035, 13.551335743495397, 8.579870121819631, 6.848646538598197, 5.7826951657022745, 27.604001385825022, 43.16097981589181, 48.15993424824306, 48.56138031823294, 50.350742953164236, 50.17715610776629, 49.095627307891846, 45.69751698630196, 44.5054805619376, 38.91574512209211, 35.95716742106846, 34.604693617139546, 37.18684571129935, 36.48543201174055, 36.268922669546946, 34.205078397478374, 33.697470801217214, 33.31223487854004, 32.89343915666853, 32.27110637937273, 33.241443157196045, 33.650521823338096, 35.09408303669521, 37.295043059757774, 44.520301069532124, 45.099624497549875, 45.19038186754499, 45.099297932216096, 41.9722125189645, 40.414586203438894, 38.649024622780935, 41.02813645771572, 44.08822386605399, 43.002477509634836, 40.57762220927647, 37.693560464041575, 35.82205622536795, 33.95625645773751, 32.632895605904714, 32.396236487797324, 34.40536022186279, 32.78226103101458, 34.205790587833945, 32.25175564629691, 33.45833465031215, 33.8873998097011, 35.86080980300903, 33.389940057482036, 37.583619117736816, 34.52673830304827, 37.49970572335379, 36.49479818344116, 44.28529562268938, 42.73969316482544, 51.24397904532296, 30.447930335998535, 37.269682134900776, 51.51390961238316, 42.910521575382774, 44.99176761082241, 43.287454400743755, 42.1913343838283, 37.054444313049316, 36.07534238270351, 33.79553420203072, 36.33959974561419, 34.5365561076573, 35.86116416113717, 35.20032099315098, 35.56562600816999, 35.78072486604963, 36.21213851656233, 33.72620507649013, 36.57579333441598, 35.56990262440273, 36.478508131844656, 35.832905837467735, 35.856505393981934, 34.999563217163086, 34.59939561571394, 34.8180901663644, 36.042974199567524, 36.83265086582729, 34.92172949654715, 33.989698137555806, 32.706848757607595, 34.228104727608816, 36.30449744633266, 40.44343512398856, 41.18449871880667, 40.775944641658235, 36.56807735988072, 36.81271300997053, 41.874100480760845, 50.36240897859846, 49.22574274880545, 48.36935642787388, 48.2892610686166, 47.60192789350237, 48.39880984170096, 51.572628838675364, 51.385691029684885, 49.94041361127581, 49.49562120437622, 51.71601186479841, 51.42215517589024, 53.32274109976632, 49.13952602658953, 50.96522774015154, 53.97002485820225, 54.4478246825082, 26.60752374785287, 8.652023690087454, 9.11550327709743, 4.229212147848947, 3.398910232952663, 0.27567813864776064, 0.020773327543533275, 2.755094277007239, 33.03101001467024, 47.37828622545515, 39.733158997126985, 34.99503993988037, 47.691403320857454, 57.79614768709455, 47.18266316822597, 18.596719775881084, 0.932328177349908, 0.08171067972268377, 0.0286665710487536, 0.05310061367760811, 0.03186614186103855, 0.03939067113346287, 0.031798454600253274, 0.04489240948376911, 0.005988001141564122, 0.037200963989432366, 0.09102016660783972, 0.03657283055196915, 0.06520093884319067, 0.045659242264394245, 0.0710484247122492, 0.044514526546533616, 0.1564587080585105, 0.06537454881306205, 0.10799992190940039, 0.13255713560751506, 0.11611646280757018, 0.2142844530088561, 0.16271443452153886, 0.10746263074023382, 0.10521838973675456, 0.10982890626681702, 0.11645498392837388, 0.13764948663966997, 0.17612360284796783, 0.13443982601165771, 0.21751373686960765, 0.16807270342750208, 6.481197135789054, 37.918768950871055, 54.1473776272365, 54.60681683676583, 41.22222048895699, 48.36114713123867, 61.727212633405415, 53.489490917750764, 34.12298543112618, 6.395243142332349, 0.08001892907278878, 15.130301713943481, 44.703535488673616, 15.51826480456761, 12.556218215397426, 13.141529253550939, 6.129805888448443, 27.595833778381348, 46.38732372011457, 49.888590472085134, 50.16274554388863, 51.54974147251674, 52.88367053440639, 51.03899329049246, 46.66005441120693, 45.518222195761545, 41.55642884118216, 37.7797771862575, 36.86151715687343, 39.432635511670796, 38.7551201411656, 37.51884453637259, 36.393594196864534, 36.089718205588206, 33.91732917513166, 34.75478860310146, 33.44616488048008, 34.56603036608015, 35.25880398069109, 37.90504278455462, 40.429695061274934, 46.452212946755544, 47.10155684607369, 46.407956395830425, 48.974329130990164, 44.49158069065639, 42.33557551247733, 40.24882650375366, 44.20550945826939, 45.426672731127056, 45.29693596703665, 42.38815253121512, 40.47276694434029, 38.0054338318961, 35.49947220938546, 34.38963644845145, 33.76375661577497, 35.289094652448384, 33.98771442685808, 36.58520814350673, 34.652198450905935, 34.47461291721889, 36.45483214514596, 39.04253584997994, 34.70099912370954, 40.00542763301304, 37.73757382801601, 39.25802033288138, 39.11249031339373, 46.0249855858939, 44.32051951544625, 52.82257155009678, 34.05911758967808, 38.96694639750889, 52.72431707382202, 45.07678229468209, 46.319471086774556, 44.80970743724278, 43.22821405955723, 38.88725403376988, 38.43648617608206, 36.0795008795602, 37.81091901234218, 37.12358583722796, 37.54958684103829, 36.6016024180821, 37.94111088344029, 37.853358609335764, 37.86041450500488, 35.19314350400652, 37.493862288338796, 37.61850602286202, 39.09772539138794, 38.21873310634068, 38.810796056474956, 36.08070986611502, 36.439608642033164, 37.43115479605538, 39.364609173366, 40.09364196232387, 37.5115385055542, 36.955894538334434, 34.514155115400044, 35.37021834509713, 38.01606804983956, 40.96215983799526, 41.74111890792847, 43.570152282714844, 36.93359776905605, 38.82434851782662, 43.67703294754028, 52.59568507330758, 50.26599924904959, 51.090625354221885, 49.652362142290386, 50.22743327277047, 50.44084024429321, 54.95629732949393, 51.43634687151228, 53.72004951749529, 50.78313977377755, 53.665137904030935, 53.53859036309378, 56.14522443498884, 51.212993553706575, 53.09027174540928, 55.709412574768066, 56.94016783578055, 31.895941870553152, 9.917618955884661, 7.995085409709385, 11.010480267660958, 7.462791732379368, 0.7499177711350578, 0.10027865480099406, 3.7252671207700456, 37.930132729666575, 61.09698322841099, 56.5687449319022, 46.552166257585796, 57.07552221843174, 63.24681840624128, 57.07704387392317, 25.277242490223475, 1.5029566947902953, 0.20786209191594804, 0.2611747240381581, 0.1537857414888484, 0.08055826263236147, 0.10115298788462367, 0.1397495118102857, 0.11906393750437669, 0.19027427424277576, 0.13573141741965497, 0.12689477444759437, 0.1060231186981712, 0.13998885825276375, 0.1319970049496208, 0.1739186897341694, 0.15280806752187864], [0.055500110278704336, 0.023923679121903012, 0.05248177956257548, 0.01991938443721405, 0.06487779332590954, 0.051819067980561934, 0.06410933884658984, 0.019780847942456603, 0.041637487177337916, 0.02466245278316949, 0.05173371166789106, 0.007510997587814927, 0.08115372460867677, 0.03765420502583895, 0.041685303540102074, 0.011846486063274955, 2.2485243507793973, 27.793937342507498, 44.516354492732454, 41.22690010070801, 23.756806407655986, 25.560894012451172, 43.18305771691458, 37.54921858651297, 28.943221500941686, 4.273788750171661, 0.03649369640541928, 15.669973509652273, 16.615140438079834, 2.943414343254907, 5.204033987862723, 3.8105176091194153, 2.9931751702513014, 13.188517315047127, 38.011742796216694, 50.526191915784565, 46.10534497669765, 46.85086931501116, 46.31186628341675, 43.675514766148154, 39.31660059520176, 37.67682920183454, 36.171936239515034, 34.95815542766026, 34.732967785426546, 35.27659484318325, 35.18507317134312, 33.38586841310774, 30.844908714294434, 31.438962323325022, 31.423929895673478, 33.971431323460166, 33.87404537200928, 35.123508657727925, 35.129056794302805, 37.15997007914952, 37.23542404174805, 41.6842166355678, 44.56409556525094, 43.774894850594656, 43.90112624849592, 41.10218688419887, 36.2128507069179, 33.642913545881, 34.77778714043753, 39.912988798958914, 41.15028926304409, 38.49096352713448, 37.55139684677124, 34.34774228504726, 32.743740218026296, 32.63539348329817, 30.864342825753347, 32.50100837435041, 32.018876348223, 32.238463742392405, 32.06328228541783, 32.17091335569109, 31.93689455304827, 32.690624713897705, 31.402359213147843, 32.1849695614406, 32.32467351640974, 34.410439355032786, 32.95941230228969, 39.615182059151785, 42.012984548296245, 46.05409853799002, 34.60908487864903, 39.513300623212544, 46.52611746106829, 39.94867474692208, 39.602352210453574, 31.93438277925764, 33.06389583860125, 30.46441146305629, 30.637435504368373, 33.239720003945486, 32.70913471494402, 33.064614977155415, 35.676217011043, 33.7391391481672, 33.810267857142854, 33.703981263296946, 32.473611627306255, 32.17748982565743, 33.332450662340435, 35.86326599121094, 37.96070827756609, 36.87124810900007, 34.60287666320801, 33.05390085492815, 36.8150441305978, 40.49279165267944, 43.92200558526175, 45.604744638715474, 42.2085520199367, 39.38187197276524, 35.00514609473092, 33.4450740133013, 31.927698612213135, 30.883999279567174, 33.23984854561942, 34.95368773596627, 33.82325404030936, 33.320968764168875, 38.24993746621268, 43.922808102199006, 46.02100426810128, 45.55470718656267, 46.67276266642979, 48.155939034053254, 47.75388152258736, 46.90128891808646, 45.37577370234898, 43.921856198992046, 42.52420520782471, 47.331719398498535, 49.80709852491106, 50.255601269858225, 44.48999650137765, 49.66643571853638, 50.701936176845, 51.41636037826538, 29.009297132492065, 10.64755848475865, 17.16348011153085, 1.6311522615807397, 2.4183435354913985, 0.23957033189279692, 0.06377468537539244, 2.3619467445782254, 29.02791483061654, 42.4746332849775, 31.300620215279714, 28.58618310519627, 45.31405980246407, 46.802544593811035, 42.28260939461844, 16.72570538520813, 1.2864665687084198, 0.0531509745466922, 0.044110404660126994, 0.025329408601724675, 0.016555565741977522, 0.032830309588462114, 0.01836198372101145, 0.011074122374079056, 0.02893685529540692, 0.025534553486587744, 0.05322444971118655, 0.07460641129208462, 0.04876762814819813, 0.05284329962783626, 0.020402648951858282, 0.03126141109636851, 0.011374380057012396, 0.04515202037457909, 0.049224160079445155, 0.027240300617579902, 0.03583617222362331, 0.02400500832923821, 0.014628611105893339, 0.010836057514617485, 0.02842438324088497, 0.023805549567831413, 0.02018442191183567, 0.03500725348879184, 0.023818772519007325, 0.07704315946570464, 0.025799696134137254, 0.054554605656968694, 3.405621758529118, 32.12755312238421, 48.450410638536724, 48.20912749426705, 31.13617025102888, 34.17901223046439, 48.447565351213726, 46.1544201033456, 30.716804776872905, 5.187982780592782, 0.05013903223776391, 18.35800572804042, 23.995324168886455, 4.458234761442457, 5.139273302895682, 6.775074235030583, 5.378384266580854, 14.67800177846636, 40.70550380434309, 51.873044627053396, 48.40767574310303, 47.451864174434114, 48.26516124180385, 44.8810202734811, 42.51240021841866, 40.7595225742885, 37.685163566044395, 36.83576365879604, 36.96198810849871, 37.246492522103445, 37.30567380360195, 34.75783886228289, 33.126912525721956, 33.031857694898335, 31.92621169771467, 34.85886914389474, 35.59422826766968, 36.74997425079346, 36.389195987156455, 38.23164285932268, 39.28657742909023, 42.901012965611045, 45.24834026609148, 45.07621601649693, 45.69213908059256, 42.40891374860491, 36.822475228990825, 35.68790735517229, 37.278141566685264, 40.2579460144043, 42.448337827410015, 41.08780063901629, 38.67469126837594, 35.65190526417324, 34.08741760253906, 33.88154247828892, 32.70503875187465, 34.33323792048863, 32.497124331338064, 33.21435213088989, 32.850534030369346, 33.1797570501055, 33.547532149723594, 34.273698806762695, 33.70889711380005, 35.16207810810634, 33.85786649159023, 36.784086431775776, 35.65689059666225, 41.96983970914568, 43.61063943590437, 48.14325509752546, 37.066978863307405, 40.82134764535086, 47.66564287458147, 41.4785395349775, 41.96877316066197, 34.309475081307546, 35.3056765283857, 32.50176225389753, 34.2919864654541, 34.12928049904959, 35.35921934672764, 33.537474632263184, 37.35034377234322, 34.215035166059224, 35.38342687061855, 34.75931535448347, 35.96292052950178, 34.737588337489534, 35.2131404195513, 36.06783832822527, 40.07021263667515, 38.17303480420794, 34.85417563574654, 32.538021428244456, 38.01931285858154, 42.168092659541536, 46.62188448224749, 46.6198764528547, 43.183412075042725, 39.598572390420095, 35.18337433678763, 35.11551822934832, 33.13962772914341, 33.04512528010777, 35.378733362470356, 35.82883071899414, 35.739747864859446, 34.11595038005284, 39.98765066691807, 46.99824408122471, 48.71429974692208, 47.96846621377127, 48.521740845271516, 48.081600257328574, 49.775921957833425, 49.39063392366682, 48.614242213112966, 46.0826278414045, 46.43815674100603, 49.44969708578927, 50.86005285808018, 51.48620367050171, 46.724999223436626, 50.09555993761335, 52.499178068978445, 54.57220091138567, 30.73351866858346, 8.374673315456935, 7.772895915167672, 3.4328778045518056, 2.092807403632573, 0.17218766547739506, 0.05602368825514402, 2.4158586859703064, 33.272376537323, 49.80152954374041, 36.44774498258318, 34.66738026482718, 51.46229491915022, 53.28289665494646, 48.02603898729597, 20.561246497290476, 1.614577442407608, 0.018012653537360684, 0.05880562415612595, 0.04776084502892835, 0.028860574388610463, 0.03347456841064351, 0.09065836495054619, 0.024395931013194577, 0.08499461279383727, 0.06155307351478508, 0.05595624865964055, 0.0658628022564309, 0.001588922696620492, 0.028141435834446123, 0.035603502565728765, 0.052895302551665475, 0.11741084977984428, 0.08451543814901795, 0.2120893650821277, 0.11633913085928985, 0.12434246497494833, 0.14162355767829077, 0.18780902081302234, 0.1050996868205922, 0.13154613200042928, 0.09033887673701559, 0.1633753954832043, 0.11303523528788771, 0.1197167696165187, 0.1769335429583277, 0.1461761069617101, 0.08960063742207629, 5.240178951195308, 40.26974752971104, 57.08502388000488, 53.259978021894185, 34.48873860495431, 34.786486285073416, 50.37721906389509, 45.8287649835859, 36.77393511363438, 5.755002685955592, 0.26112350821495056, 17.552933590752737, 22.116948161806377, 3.794897190162114, 9.67109773840223, 9.8670152255467, 7.584308777536664, 17.992653812680924, 41.233028411865234, 55.167272431509836, 50.34960344859532, 51.28374705995832, 51.58213744844709, 48.46952165876116, 44.36450161252703, 42.73850154876709, 40.088635785239084, 38.20916543688093, 38.94580997739519, 40.421635150909424, 39.32196113041469, 36.629791259765625, 34.82547262736729, 35.507153442927766, 35.13598414829799, 38.01574843270438, 38.081888335091726, 39.250915799822124, 38.44428205490112, 40.74030385698591, 41.086178234645296, 46.459039551871165, 46.38695893968855, 46.33524349757603, 48.002762522016255, 44.01651150839669, 39.02818781988961, 37.97587966918945, 38.19480351039341, 43.32828548976353, 43.78367042541504, 43.30563088825771, 40.470237800053184, 37.505601269858225, 35.47785288946969, 35.636337825230186, 34.77483068193708, 36.455328941345215, 34.18760715212141, 34.372245107378276, 34.93826968329293, 35.46358476366316, 36.14817687443325, 35.98659651620047, 35.412157671792166, 36.544109548841206, 35.684537478855674, 38.99111223220825, 36.73520932878767, 43.495813505990164, 47.21108477456229, 49.57953807285854, 38.90056678227016, 42.883812699999126, 50.71332080023629, 43.50279991967337, 42.744035788944785, 35.754266125815256, 38.49799163000924, 34.85763236454555, 34.76901503971645, 36.984270981379915, 36.342368602752686, 35.34989139011928, 38.0604635647365, 35.22795745304653, 36.59928171975272, 36.48655761991228, 36.31448548180716, 36.43809740883963, 37.57021951675415, 38.142924785614014, 42.61840888432094, 39.813799789973665, 37.14442695890154, 35.86830343518938, 40.837533473968506, 45.218733991895405, 49.516309465680806, 49.48262807301113, 45.448326792035786, 43.58970103945051, 38.33372579302107, 37.91075072969709, 34.8707401411874, 34.66348927361624, 38.33573382241385, 37.24485969543457, 36.79101378577096, 37.33632230758667, 42.67140279497419, 48.45371103286743, 50.31291348593575, 50.687164306640625, 50.61605644226074, 49.69637203216553, 53.225685187748496, 51.95580462047032, 51.47511434555054, 48.49943017959595, 47.27831207002912, 51.42327036176409, 53.851964541843955, 54.450367723192485, 49.61778095790318, 54.53844656263079, 55.97121722357613, 54.3350693157741, 32.29254157202584, 14.950520549501691, 26.283061981201172, 5.397849210671016, 4.813087514468601, 0.6515903387750898, 0.15595698569502148, 3.013498216867447, 37.85547433580671, 54.309124742235454, 42.78832013266427, 40.92859656470162, 58.05436706542969, 60.99587304251534, 56.9844764981951, 26.036736181804113, 2.0479776263237, 0.13105238920875958, 0.16719557477959565, 0.1377051400818995, 0.06696336570062808, 0.09480753195072923, 0.13920582884124347, 0.1317643488624266, 0.2650919338422162, 0.12494207280022757, 0.15659710206091404, 0.1113298935815692, 0.20313169860414096, 0.23364028866801942, 0.1322340172316347, 0.14630821772984096], [0.04109176860323974, 0.022983614654679383, 0.032693930835063965, 0.077323815120118, 0.046919858548790216, 0.011468937304536147, 0.04004912830090948, 0.02235019882209599, 0.01874515414237976, 0.029944659609879767, 0.0037005535726036343, 0.11892372502812318, 0.036787077984107394, 0.02739533908399088, 0.10104858848665442, 0.07519523041056735, 3.1219863040106635, 27.632218020302908, 47.926863874707905, 39.72243792670113, 24.91021258490426, 18.281653710774012, 23.34177139827183, 28.84088843209403, 32.96014533724104, 5.264418610504695, 0.2119270052228655, 2.2502318705831255, 0.3880664179367678, 1.7467607323612486, 2.7013814449310303, 6.937156166349139, 1.6107589730194636, 8.159368617194039, 35.59757382529122, 51.364252362932476, 46.88656568527222, 44.980299609048025, 43.37384482792446, 38.13551800591605, 36.63428327015468, 36.335191113608225, 36.603568758283345, 36.11156334195818, 36.113880566188264, 35.58726269858224, 34.451857566833496, 32.05549682889666, 31.89302362714495, 30.923586641039165, 34.60514177594866, 41.48336853299822, 42.64812980379377, 43.37632186072213, 43.111425263541086, 43.68585368565151, 43.59106636047363, 46.05437299183437, 42.110853399549214, 42.29085690634591, 41.7892073903765, 38.525499548230854, 35.381988593510215, 31.741233280726842, 32.34719957624163, 35.4530999319894, 35.68412406103951, 37.04865646362305, 33.46704421724592, 33.22001838684082, 31.339158398764475, 31.831615447998047, 31.48872879573277, 32.50571230479649, 30.999895232064382, 31.673231261117117, 31.223186016082764, 32.68280799048287, 31.508010046822683, 31.481492246900284, 29.868919576917374, 33.134406157902305, 31.73501464298793, 32.77300950459072, 31.2957147870745, 37.65481036049979, 39.10644885471889, 45.377656664167134, 34.99122537885393, 39.47924402781895, 49.57760647365025, 39.979945114680696, 38.26427507400513, 31.849798883710587, 32.51857342038836, 31.444632053375244, 32.21075780051095, 31.91951710837228, 32.393776825496126, 33.246640409742085, 32.4289208139692, 32.47348655973162, 32.85539429528372, 33.03298330307007, 34.734211512974326, 31.87706708908081, 33.6625908442906, 35.98919514247349, 39.63343497685024, 39.9724097933088, 37.666052545819966, 38.398868628910606, 42.70870419910976, 43.66224023274013, 46.470618724823, 46.13669177464077, 45.18082462038313, 44.208163670131135, 45.07303374154227, 39.81360524041312, 35.53777762821743, 32.324722153799875, 32.153296198163716, 31.502170085906982, 33.78427464621407, 32.82676076889038, 36.94276244299752, 45.433541025434224, 47.365873268672395, 47.17017725535801, 47.64117479324341, 45.46525955200195, 45.18794652393886, 44.06080280031477, 43.214411463056294, 41.57152380262102, 40.02041837147304, 40.60702003751482, 46.35360411235264, 45.125416210719514, 45.2282634462629, 49.4004864692688, 51.372843810490195, 54.189296109335764, 31.909713200160436, 12.973540919167654, 7.9635805402483255, 3.424470918519156, 2.2929011923926215, 0.20422271506062575, 0.08550618070044688, 1.7252461782523563, 28.082994563238962, 41.227025168282644, 31.296836921146937, 23.282228810446604, 36.59162827900478, 47.02312905447823, 42.650978565216064, 20.156458343778336, 0.9714437127113342, 0.01991335056456072, 0.0396042196745319, 0.024294006571705853, 0.004084665037225932, 0.03290885680222085, 0.03795574259545122, 0.04044894488262279, 0.053797397895583084, 0.04871999498988901, 0.04605044484404581, 0.038465376677257676, 0.10238136697028365, 0.05080905503460339, 0.029185755510947535, 0.034176210939352, 0.0077182425385607135, 0.03632006607949734, 0.054224084464034865, 0.007644527342303523, 0.03782309917733073, 0.024440317381439463, 0.018396209027352076, 0.033305877819657326, 0.05201012308576277, 0.05414516744869096, 0.04249793404181089, 0.11155681604785578, 0.03109096988503422, 0.06251054749424968, 0.030788387371493236, 0.06405774982912199, 3.719546582017626, 34.64042125429426, 53.875376496996196, 42.82627814156668, 28.617416994912283, 23.834087746483938, 34.180992467062815, 36.46841934749058, 36.46846103668213, 5.925303467682429, 0.2699337697454861, 3.3199359221117835, 2.576597443648747, 5.762389489582606, 5.279079743794032, 5.998120154653277, 4.1773963911192755, 11.268071702548436, 35.158916677747456, 51.725027152470176, 47.55312722069876, 46.90988383974348, 44.684257711683, 39.61744717189244, 38.557485580444336, 38.77310902731759, 37.480629444122314, 38.69064780644008, 38.2592202595302, 36.353027139391216, 35.44813544409615, 34.1869192804609, 33.61052451814924, 32.466503620147705, 36.08427081789289, 43.31255824225289, 45.509259019579204, 45.773255825042725, 43.9433330808367, 44.88427203042166, 43.79693453652518, 48.73007910592215, 43.067981651851106, 44.92501974105835, 44.13150072097778, 41.004286766052246, 36.71040425981794, 33.49328408922468, 33.506252901894705, 37.71122625895909, 38.7270633152553, 38.900716168539866, 35.06179475784302, 34.14652245385306, 33.54206739153181, 34.35725784301758, 33.12809371948242, 33.953088079180034, 33.37955597468785, 32.51589488983154, 32.43054321834019, 33.83377013887678, 33.086300304957796, 33.76007407052176, 32.502338954380576, 34.404651505606516, 33.09439843041556, 34.62446819032942, 32.88757140295846, 39.041243485042024, 42.06071172441755, 47.5859192439488, 38.27280746187483, 39.94555500575474, 49.64482682091849, 41.79910857336861, 38.724707875932964, 33.428363595690044, 33.9422801562718, 33.077347551073345, 33.58613634109497, 32.403552940913606, 33.737697396959575, 34.3358747618539, 35.02325657435826, 34.25215591703142, 34.24767085484096, 36.11336987359183, 35.78382723672049, 33.57654782703945, 35.13457018988473, 37.850245816367014, 40.254197461264475, 40.84750066484724, 39.55857161113194, 39.81498793193272, 44.36134365626744, 46.08738040924072, 48.8965996333531, 47.841341972351074, 47.484107289995464, 46.1659436907087, 46.684404373168945, 41.184550830296104, 36.1093225479126, 33.6716547693525, 33.250479289463584, 32.527884006500244, 35.894769123622346, 34.99653032847813, 39.2938209261213, 47.14223507472447, 48.070840971810476, 47.93188394818987, 49.12922879627773, 49.02390105383736, 47.120546272822786, 46.17265912464687, 44.977016585213796, 43.58672373635428, 42.05868632452828, 43.18242195674351, 47.50654649734497, 48.208113057272776, 48.02199166161673, 50.61017826625279, 54.93935414722988, 54.22355072838919, 34.11848299843924, 9.892881631851196, 6.3216052651405334, 4.911292484828404, 0.9394238080297197, 0.2218653040805033, 0.062264829607946534, 1.8135196758168084, 32.79833568845476, 45.76216302599226, 36.14043310710362, 28.777764047895158, 41.24061584472656, 54.02634000778198, 49.30829429626465, 24.134072746549332, 1.382548213005066, 0.06305455616010086, 0.006340217219466078, 0.029393505970282213, 0.05177705648488232, 0.05046498689002224, 0.037784005382231305, 0.08629205317369529, 0.04089987211461578, 0.014500449411571026, 0.045608474274298975, 0.026393402401091795, 0.04895947374669569, 0.017486203661454574, 0.01372196788101324, 0.01843077869021467, 0.06621626471834523, 0.13031666725873947, 0.1150452731443303, 0.10463424572455031, 0.07963394865925823, 0.09094025553869349, 0.13771298394671508, 0.12371634000114032, 0.16578134495232785, 0.09759952713336263, 0.05494993033685854, 0.2839447579213551, 0.1689947782350438, 0.11801507164325033, 0.2621010871870177, 0.14641796398375714, 5.354417324066162, 41.02886254446847, 60.81975705283028, 49.36513750893729, 35.50680603299822, 27.616949353899273, 32.796143531799316, 39.16094010216849, 42.246826171875, 7.431840981755938, 0.3113528500710215, 3.5216670972960333, 2.4929148597376685, 4.960556081363133, 7.962090151650565, 14.1785227060318, 3.6940336653164456, 11.112080301557269, 38.072199072156636, 54.41545649937221, 50.98534624917166, 49.37676531927926, 46.11161572592599, 41.057218142918174, 39.46374259676252, 40.04508447647095, 39.0151356288365, 41.14384480885097, 40.953151498522075, 39.899036816188264, 39.66549049104963, 35.668726852961946, 34.90304231643677, 33.0794563293457, 38.44082532610212, 46.66802052089146, 48.021130084991455, 47.96745525087629, 46.7209484236581, 48.77059752600533, 47.67312955856323, 50.68212686266218, 43.52289758409773, 46.88892459869385, 45.00287083217076, 43.12795155388968, 38.05121203831264, 36.089742524283274, 34.8767329624721, 38.40668535232544, 39.84945099694388, 41.053361892700195, 36.888066223689485, 35.39893177577427, 34.72235441207886, 36.75656809125628, 34.71027149472918, 35.400331837790354, 35.24723523003714, 34.133914947509766, 34.24381113052368, 36.10329845973423, 34.868704319000244, 35.205744062151226, 32.61530276707241, 36.691446099962505, 35.865965366363525, 35.669789927346365, 34.788945947374614, 40.191347530909944, 43.960050446646555, 48.69096074785505, 39.358817849840435, 42.65605075018746, 52.41639723096575, 43.0860504422869, 40.509370054517476, 34.58857379640852, 35.09928723743984, 34.76074668339321, 35.08736065455845, 36.11858449663435, 34.83419956479754, 36.449388231549946, 36.84934738704136, 36.034723213740754, 35.29910005841936, 37.75242907660348, 38.23461668831961, 34.825948578970774, 37.0328597341265, 40.43839420591082, 43.34880352020264, 43.99694538116455, 42.33479731423514, 41.998028550829204, 44.96127891540527, 47.035239764622276, 50.041263239724294, 49.97993843896048, 48.543349742889404, 48.495747634342735, 49.11382811410086, 44.09087460381644, 38.7846291405814, 35.94043615886143, 34.68994453975132, 35.38389934812273, 38.02207824162075, 37.006644180842805, 42.06453670774187, 49.45736789703369, 49.45001670292446, 49.745256083352224, 51.52218839100429, 51.02163669041225, 49.527704511369976, 48.811161109379356, 47.494355882917134, 45.72591427394322, 44.11209787641253, 45.876783984048025, 48.658352851867676, 50.83993782315935, 49.4939466885158, 53.818477698734824, 55.322533403124126, 57.43567861829485, 35.78226736613682, 16.627692358834402, 15.914666482380458, 7.080684670380183, 8.111348748207092, 0.423733719757625, 0.22550382598170213, 2.32468073282923, 37.447118282318115, 53.53683246885027, 42.63923263549805, 34.09690536771502, 48.37367473329817, 61.87349305834089, 57.656141485486714, 29.53588547025408, 1.8041485100984573, 0.2089172410113471, 0.14555703875209602, 0.11363259037690503, 0.13930589918579372, 0.09192359527306897, 0.08214280474931002, 0.27404126791017397, 0.18871747063738958, 0.11380330300224678, 0.10059333220124245, 0.11902952220823083, 0.14355993377310888, 0.240551656378167, 0.08860496870641198, 0.08702199400535651], [0.06944341119378805, 0.023646017503259436, 0.030011166219732592, 0.027321980966787254, 0.1006229773962072, 0.04064390156418085, 0.028480621919568096, 0.024905699105667214, 0.05110224323081119, 0.03897881055516856, 0.012641809681164367, 0.01244000658126814, 0.014881411201453634, 0.03485358566311853, 0.03022267237039549, 0.029603108830217804, 3.2213474980422427, 26.09049960545131, 43.8477258682251, 42.244161537715364, 28.59826602254595, 16.21993558747428, 15.76006385258266, 34.479956081935335, 33.086960383823936, 6.554253535611289, 0.05101988943559783, 0.7576155066490173, 4.520435469491141, 5.336227808679853, 3.933333533150809, 3.822273526872907, 3.9791516917092458, 7.108523062297276, 29.716965947832378, 48.83200570515224, 45.36089760916573, 42.991891929081504, 38.673402377537315, 34.2294214112418, 34.214468887874055, 36.69085202898298, 36.46944768088204, 38.85619558606829, 37.08001020976475, 35.37995624542236, 33.310421398707796, 32.2118695122855, 31.357369627271378, 36.001760959625244, 40.78025252478463, 45.26271956307547, 40.706949029650005, 41.99404375893729, 44.11850758961269, 45.615899971553254, 42.672007288251606, 43.38517733982631, 41.99311964852469, 42.40700299399239, 41.67151185444423, 40.67027991158621, 34.512046337127686, 33.07672568729946, 32.16892269679478, 31.295339584350586, 32.549072538103374, 32.70094626290457, 31.42588233947754, 32.68423237119402, 32.2000332559858, 32.01743459701538, 31.792646476200648, 32.020352840423584, 31.549744401659282, 32.22026988438198, 31.505202974591935, 31.671518530164445, 31.305317197527202, 32.25807850701468, 32.0851274217878, 33.55355623790196, 34.660800320761545, 38.014563764844624, 35.51683923176357, 38.85024445397513, 39.40586062840053, 47.010879380362375, 38.254207134246826, 39.15830673490252, 45.66065331867763, 41.56603472573416, 40.3404871395656, 34.938832487378804, 37.333358900887625, 34.48840856552124, 35.07454817635672, 31.965020860944474, 32.809786319732666, 31.1864196232387, 33.38665008544922, 32.60623189381191, 33.8411317552839, 33.00202560424805, 33.94376359667097, 33.00242165156773, 33.54160533632551, 35.386216572352815, 41.84132930210659, 42.088362080710276, 44.15900863919939, 43.904371057237896, 45.284856523786274, 46.67485754830496, 47.49543285369873, 45.60714176722935, 46.011433124542236, 45.29977778026036, 44.309986046382356, 46.19290270124163, 45.8166230065482, 38.37342085157122, 33.496039049965994, 30.90669904436384, 32.186345304761616, 32.95158168247768, 34.383838176727295, 39.87796292986189, 46.698391096932546, 46.70444297790527, 47.50163064684187, 46.73072106497628, 46.23932361602783, 45.59416948046003, 45.55231353214809, 43.918340410505024, 42.77770675931658, 38.22653245925903, 39.2329477582659, 41.516730308532715, 46.45046894890921, 49.57065480095999, 51.39994873319353, 51.57072155816214, 33.08854109900338, 8.479640620095388, 1.2469119940485274, 3.0388046417917525, 0.6106101348996162, 0.11577534968299524, 0.01246207084373704, 1.2274968815701348, 24.71189362662179, 43.679864338466096, 30.46889999934605, 24.386408737727574, 35.056482860020225, 47.6843717438834, 46.38212994166783, 19.495239973068237, 0.8721685569201196, 0.01070536403650684, 0.04794855495648725, 0.00946256608170058, 0.055315708209361346, 0.08430843747087888, 0.06164943905813353, 0.0300580020993948, 0.04782087502202817, 0.023598291046385254, 0.01698016411890941, 0.04323305548833949, 0.007614192586126072, 0.019333768004019345, 0.017909048025363257, 0.015465733329100268, 0.09114805688815457, 0.05792529282293149, 0.013571080352578844, 0.043032025918364525, 0.042282170083905966, 0.050987391000879664, 0.029909664166292975, 0.0022738200412797077, 0.030641124916395972, 0.039553146343678236, 0.027716647467709014, 0.04121558088809252, 0.044558790778475146, 0.010117115735608553, 0.0627294700326664, 0.006602792460138777, 4.181848883628845, 30.96277448109218, 50.16668864658901, 47.53925861631121, 33.106985092163086, 20.5775591305324, 22.78445986339024, 37.83658218383789, 37.21281460353306, 7.395170126642499, 0.07736768240907363, 0.22845606399433954, 4.492269643715449, 7.1837881207466125, 3.9558092185429166, 7.461961422647748, 5.334774766649518, 7.507505995886667, 31.435599395206996, 52.42940078462873, 47.41891929081508, 45.76150642122541, 39.78337015424456, 35.896363735198975, 35.32446445737566, 37.97708865574428, 37.929726260049, 40.44855942044939, 38.20207480021885, 37.62702798843384, 35.28886188779558, 33.36929695946829, 33.072511604854036, 36.469941002982004, 42.11034965515137, 47.09460169928414, 44.45747198377337, 42.74215977532523, 44.6163147517613, 45.455493858882356, 42.8490161214556, 43.26170785086495, 42.246822697775706, 43.9065979548863, 44.4040333884103, 44.47580827985491, 36.68608209065029, 34.163875579833984, 33.78217281614031, 33.1089688028608, 35.053672313690186, 33.610065937042236, 33.45164006096976, 33.900538853236604, 33.48236152103969, 33.66229901994978, 32.33903891699654, 32.88757487705776, 32.837672914777485, 34.56581497192383, 33.2861339705331, 34.05091871534075, 32.6585031918117, 34.179870332990376, 33.110799653189524, 35.359024797167095, 36.52775696345738, 39.01415940693447, 37.397897243499756, 39.95700911113194, 41.829510416303364, 48.81347138541085, 40.50797694069998, 41.58396107809884, 47.884003911699565, 42.54932641983032, 42.013877391815186, 36.15452752794538, 37.35585369382586, 35.15966360909598, 36.20206710270473, 35.51352841513497, 33.52027089255196, 32.79562589100429, 34.91335344314575, 33.99253300258091, 34.84300640651158, 33.3811297416687, 35.48585374014718, 35.23675734656197, 35.97368676321847, 36.9118846484593, 42.61934341703142, 44.93376404898507, 46.33229398727417, 45.676175594329834, 47.87503726141793, 48.504443304879324, 47.51916095188686, 46.982933725629536, 47.74095092500959, 47.13120133536202, 47.16885014942714, 48.2673533984593, 48.00612892423357, 40.17097888674055, 34.57800211225237, 33.27030944824219, 34.852351733616416, 34.1229750088283, 36.03092949731009, 42.44446420669556, 48.62807607650757, 49.35769598824637, 49.3188590322222, 49.88283388955252, 47.818190574645996, 47.16385439464024, 46.46265261513846, 45.536537647247314, 43.99685852868216, 39.84429890768868, 40.91623224530901, 42.80070529665266, 48.07968602861677, 52.05384022848946, 54.10259301321847, 53.020720277513774, 33.427825110299246, 12.80750502858843, 3.8469543967928206, 6.0435657160622736, 1.0212061681917735, 0.2564950580043452, 0.0172941392354135, 1.4598578874553954, 30.075416564941406, 47.62363059180123, 35.66434253965105, 30.3056138583592, 42.20670032501221, 55.106361048562185, 52.99228477478027, 23.680878230503627, 1.0805410700184959, 0.018907585247818912, 0.06920761348945753, 0.022705086207549487, 0.02056186889032168, 0.08380012653235878, 0.03127858481769051, 0.06337935051747731, 0.036113937318857224, 0.029231339493500333, 0.02475229760498873, 0.045747394141341956, 0.007654853797118578, 0.024489090478579913, 0.05606756911480001, 0.029581175185739994, 0.19242513525698865, 0.16386197294507707, 0.08118012640625238, 0.10630808304995298, 0.10536058353526251, 0.12889425429914678, 0.06015627525214638, 0.1314687111548015, 0.11570615268179349, 0.08872292523405381, 0.14835630783012935, 0.10296194867363997, 0.07752509574804987, 0.15174352750182152, 0.23884815350174904, 0.12380758939044816, 5.898533795561109, 38.278240953172954, 57.00660651070731, 53.8435572215489, 40.23449584415981, 22.802787474223546, 23.963437148502894, 45.195683343069895, 42.351618903023855, 8.461440682411194, 0.23771467432379723, 1.4072570928505488, 9.486088923045568, 9.625857148851667, 6.345240865434919, 7.500226889337812, 9.483095117977687, 9.414411306381226, 33.147604261125835, 53.94988203048706, 48.24039438792637, 47.27696411950247, 42.36871494565691, 37.580634866442, 36.57740879058838, 40.46509613309588, 40.83065823146275, 43.000031743730815, 40.257661138262065, 39.747024127415244, 36.183025564466206, 35.02841561181204, 35.175276211329866, 39.85747616631644, 45.130366802215576, 49.269495555332725, 46.26167597089495, 43.95279305321829, 45.342446667807444, 47.8644551549639, 43.37824303763253, 43.0985016141619, 42.394958291734966, 45.49423701422555, 45.8482859475272, 47.32684523718697, 38.02209561211722, 35.383610997881206, 35.292183126722065, 34.35817500523159, 36.85768869944981, 36.20940440041678, 35.078908170972554, 35.43558699744088, 35.67115524836949, 35.876401560647146, 35.294396127973286, 34.72488703046526, 34.931766169411794, 36.46055746078491, 34.10311358315604, 35.43620886121477, 35.256302629198345, 36.254164695739746, 36.21243381500244, 37.60515505926949, 38.52942180633545, 41.94885267530169, 39.71026815686907, 42.93077557427542, 43.744423525674, 50.502463817596436, 42.9184946332659, 43.52065331595284, 49.06669500895909, 46.000930922372, 44.507815156664165, 39.480730942317415, 40.36798463548933, 37.44540555136544, 38.14181307383946, 36.80064398901803, 35.981781414576936, 34.64235980170113, 37.65511608123779, 35.356770106724326, 37.444130556924, 35.64756958825247, 37.64067077636719, 37.31152071271624, 38.449065889631, 39.759023666381836, 45.28396020616804, 47.17876870291573, 48.9523971421378, 47.81740542820522, 50.783737318856375, 50.3845876285008, 50.81389250074114, 49.19991976874215, 49.39051580429077, 47.36457395553589, 48.07173728942871, 51.513176577431814, 51.62526839120047, 42.00661652428763, 37.34042174475533, 34.308523178100586, 36.70815651757376, 36.278243677956716, 38.38577822276524, 44.270933696201865, 50.93252256938389, 50.20033529826573, 51.29768514633179, 50.06084673745291, 50.46863998685564, 49.18200731277466, 49.54385559899466, 47.64657701764788, 46.763485295431956, 41.10817970548357, 42.99014793123518, 45.57864025660923, 51.4015120778765, 54.11130952835083, 56.0984456879752, 53.61633723122733, 36.31364822387695, 11.286710245268685, 7.5733219385147095, 6.9841177378382, 2.8760678427559987, 0.7402634120413235, 0.11067577903824193, 1.9280519357749393, 32.834851946149556, 55.02256229945591, 40.451032979147776, 34.2812306540353, 47.93437835148403, 62.271402495247976, 59.80804375239781, 28.117893627711705, 1.4468759383474077, 0.12470667543155806, 0.1048524354451469, 0.08790865607027497, 0.141025130503944, 0.2702522198004382, 0.17219149241490023, 0.11456310616007873, 0.11480082411851202, 0.15896322152444295, 0.19877957499453, 0.15801860578358173, 0.08306658946509872, 0.0680583312309214, 0.1898287481495312, 0.12680351148758615], [0.00959979130753449, 0.07115593858595405, 0.013849332296688641, 0.05762664241982358, 0.016693104790257554, 0.02647749154961535, 0.019819096961457814, 0.08684476744383574, 0.05105485773778387, 0.021596376950453435, 0.03495372725384576, 0.04752085058550749, 0.06088824490351336, 0.024412678953792368, 0.020763244513156157, 0.040169554696019204, 1.8453677211488997, 23.136521611894878, 44.266740458352224, 41.25475890295846, 31.525870391300746, 21.763449873243058, 24.105541706085205, 32.86235291617257, 34.418068477085654, 7.827003274645124, 0.1139393017760345, 0.10012569265174014, 6.897441565990448, 8.334059357643127, 3.6563383851732527, 6.124607767377581, 4.515358941895621, 7.7542712688446045, 35.557069301605225, 49.921264375959126, 46.05823271615164, 45.256952558244976, 40.71235472815377, 37.49496010371617, 37.273614815303254, 38.88794885362898, 39.34855188642229, 40.703846658979145, 38.19465412412371, 33.74507290976388, 31.356014728546143, 31.37739086151123, 34.59370156696865, 40.72567095075335, 45.29839856284005, 42.337239606039866, 42.17394304275513, 44.32068974631173, 44.654647963387625, 45.08747557231358, 43.98558507646833, 42.64700766972133, 42.25822121756417, 43.5380585534232, 41.317942346845356, 40.046755518232075, 35.18990911756243, 31.17063331604004, 32.398605823516846, 32.48753234318325, 33.30099269321987, 36.03635604040963, 29.736570290156774, 32.8545674596514, 32.24227135522025, 33.55276414326259, 30.894873210362025, 32.78951842444283, 30.760446412222727, 32.85727725710188, 31.073560033525737, 31.780803271702357, 31.084638936179026, 33.45288378851754, 35.59414141518729, 41.43797247750418, 39.94614907673427, 44.580885887145996, 40.075215339660645, 43.24200970785958, 39.09607866832188, 46.1598014831543, 35.31309025628226, 36.58967930930001, 48.11477790560041, 44.07547739573887, 45.7318480355399, 40.060165541512625, 40.95509352002825, 37.53624282564436, 38.219021456582205, 34.165487561907085, 34.246413230895996, 31.74383190699986, 31.11600657871791, 32.462053298950195, 32.961566243852886, 32.99161720275879, 35.53241014480591, 33.89526169640677, 32.51847614560808, 33.516473702022004, 39.981650897434776, 42.72489697592599, 44.37078625815255, 44.23830148151943, 45.07663985661098, 44.61314637320382, 42.72700228009905, 42.96045480455671, 43.09618091583252, 45.80103472300938, 47.6182005746024, 45.15088483265468, 45.829459803445, 46.52472087315151, 37.10747643879482, 31.50273288999285, 33.052823884146555, 31.505095277513774, 33.03445632117135, 36.59277820587158, 43.810994216373985, 46.31477410452706, 48.702067443302695, 47.714575563158306, 49.14894430977957, 49.4602027620588, 48.95881380353655, 49.76067066192627, 47.86066838673183, 44.02543646948678, 39.77950348172869, 39.51702833175659, 48.47293322426932, 51.1666316986084, 50.140889985220774, 54.04819209235055, 33.35941662107195, 13.271605610847473, 3.2957097249371663, 7.418825268745422, 0.4125379462327276, 0.18127729344580853, 0.06369142912860427, 1.613026799900191, 25.541491167885916, 43.95629841940743, 36.23202426092965, 26.31952265330723, 32.17491551807949, 45.30095897402082, 44.27019371305193, 13.351093002728053, 0.8839982992836407, 0.01051816894739334, 0.009763196958894176, 0.015359393320977688, 0.045157302769699266, 0.020646282039316635, 0.01648015166366739, 0.022283039122287716, 0.011735959494087313, 0.04176297205101166, 0.05010967542018209, 0.050213867864970646, 0.059335933199950626, 0.12100612185895443, 0.043724389480693, 0.026667255741943206, 0.03321876070861306, 0.02850427565031818, 0.047107883995132785, 0.04836662413020219, 0.032466896410499296, 0.04362919441025172, 0.04443817100088511, 0.02769507175045354, 0.0775868288640465, 0.02911102505666869, 0.07129501112337623, 0.05363171660740461, 0.04996414322938238, 0.013596587332098611, 0.053299122489988804, 0.031789867739592276, 2.5011919013091495, 28.541603463036672, 50.86344357899257, 46.1527282169887, 37.562145709991455, 20.712060621806554, 22.83952260017395, 38.6396028654916, 39.96244607652937, 8.400074192455836, 0.12222922194216933, 0.10026312991976738, 2.422173512833459, 6.70328414440155, 6.0046558039528986, 8.438282336507525, 5.504435879843576, 10.169024756976537, 35.03565910884312, 50.76960468292236, 48.381091935294016, 46.256346702575684, 41.989506585257395, 40.78279209136963, 39.84445524215698, 40.66023281642369, 41.63504076004028, 41.397242137363975, 40.42936154774257, 37.05263083321707, 33.821888719286235, 33.16766718455723, 34.94129214968, 42.82744891302926, 46.377290521349224, 43.44845111029488, 42.73170273644583, 45.360591888427734, 44.58013200759888, 45.91862603596279, 44.36516863959176, 43.05635036740984, 42.216386113848, 44.843698024749756, 43.43736525944301, 42.34213808604649, 37.536927223205566, 33.088777337755474, 33.35381637300764, 34.47664873940604, 34.73674760546003, 37.03080306734358, 32.23210961478097, 34.556869166237966, 33.77282401493618, 34.523604665483745, 32.616140025002615, 34.32812752042498, 33.30451542990548, 33.69153356552124, 32.631627559661865, 33.04831797736031, 32.55145924431937, 34.39925970349993, 37.111443860190256, 42.115407943725586, 43.06759950092861, 45.53522096361433, 42.485632283346995, 45.7792694909232, 39.92640577043806, 46.93803794043404, 37.97074147633144, 38.50297001429966, 50.501039436885286, 45.30134459904262, 47.758033071245464, 41.459935733250205, 43.11101879392351, 40.29631049292428, 38.6245322227478, 36.97456087384905, 36.67074741636004, 34.12906163079398, 33.19145434243338, 34.61289596557617, 34.27877446583339, 34.87448869432722, 36.79688848767962, 34.692511899130686, 34.08910254069737, 35.73341458184378, 40.66405779974801, 44.4308499608721, 45.35261188234602, 45.07263422012329, 45.90288489205496, 46.09915065765381, 45.939255237579346, 44.81700651986258, 45.81466361454555, 46.8418470791408, 48.061123916081016, 45.0443411554609, 48.49298572540283, 48.09248113632202, 39.03975657054356, 33.455471992492676, 34.9412122453962, 33.024207728249685, 33.85116842814854, 38.49789782932827, 45.52265862056187, 49.398235252925325, 49.385801451546804, 49.571148123059956, 50.94974715369088, 50.38267339978899, 51.80492448806763, 50.53902523858206, 49.35464225496565, 45.881164823259624, 41.321944509233745, 41.84039824349539, 48.89495638438633, 53.89003719602312, 53.50346027101789, 54.754698821476524, 33.6152423449925, 13.223977446556091, 2.1398325945649828, 6.510857258524213, 2.169708545718874, 0.15475528660629476, 0.042096590756305625, 1.7118644905941827, 28.523116043635778, 47.05345099312918, 37.598745346069336, 30.64054482323783, 38.004874501909526, 51.36525290352957, 50.95579556056431, 17.255807774407522, 1.2558396692786897, 0.03411936327548964, 0.025541959696316292, 0.03551916744826095, 0.012216777041820543, 0.029691338738692657, 0.005858984917202699, 0.02076950230236564, 0.03218854438247425, 0.06503678765147924, 0.1266448428588254, 0.019007548723103743, 0.04324453290817993, 0.028703384966190373, 0.0606684877670237, 0.05590044254703181, 0.06717261232967887, 0.14619839005172253, 0.07707306250397648, 0.1795516431863819, 0.1603576788412673, 0.13431540983063833, 0.1591912635735103, 0.15017848648130894, 0.09508645734084503, 0.12484745787722723, 0.1289832509521927, 0.15279330259987287, 0.23205954634717532, 0.1307448907090085, 0.10206780236746583, 0.11130781405206237, 3.5951182416507175, 34.15831702096121, 57.484673840659006, 53.18989849090576, 43.53846502304077, 31.561674458639963, 32.86360706601824, 42.381572587149485, 46.12535578863961, 10.575470924377441, 0.3168991138892514, 0.19267544682536805, 9.32407169682639, 14.085824183055333, 11.645247714860098, 13.949110559054784, 10.833047594342913, 11.619720033236913, 39.052794865199495, 53.18149811880929, 50.76828452519008, 48.844383920942036, 43.560504708971294, 41.9411610194615, 41.956387996673584, 42.877535002572195, 44.66393075670515, 42.93700463431222, 43.312804903302876, 36.55339581625802, 35.3765412058149, 34.96255363736834, 37.932585443769185, 44.33778231484549, 48.43996054785592, 43.063694613320486, 42.783456393650596, 46.42206471306937, 47.52772460665022, 48.44519601549421, 46.24570206233433, 42.15653085708618, 42.98739297049386, 46.35307257516043, 45.63305854797363, 44.38302550997053, 39.331379413604736, 33.58883571624756, 35.89250748498099, 37.153779234204976, 36.190081460135325, 39.61499445778983, 32.687039443424766, 35.51429966517857, 35.69564070020403, 36.47133411679949, 33.49136986051287, 36.24789047241211, 34.12923533575875, 35.713285650525776, 34.00247587476458, 35.00878695079258, 34.51827539716448, 36.61960172653198, 39.97991732188633, 45.54297515324184, 45.33085707255772, 47.72567531040737, 44.195559637887136, 48.626554421016145, 42.50951671600342, 49.063762869153706, 40.66764307022095, 41.27772964750017, 51.581279345921104, 47.669023173195974, 49.15998499734061, 44.8369791167123, 44.729278564453125, 42.47202771050589, 40.95419372831072, 39.07743665150234, 37.64699016298567, 36.08849532263619, 34.88568571635655, 35.75148684637887, 37.122623511723106, 36.10022040775844, 39.026881558554514, 37.04763855252947, 35.54360369273594, 36.45711462838309, 42.62468310764858, 46.20018441336495, 47.47141293116978, 47.05946118491036, 48.31431974683489, 47.32614346912929, 47.98810877118792, 47.03108474186489, 48.244393076215474, 50.238783155168804, 50.840566635131836, 45.53203868865967, 50.84519066129412, 50.682724407741, 41.13517345700945, 35.05467285428728, 37.566502230507986, 34.611183234623496, 35.72148105076381, 40.244935512542725, 48.041050570351736, 51.40448243277413, 52.80261632374355, 51.72532592500959, 52.76730557850429, 54.46331569126674, 53.559612137930735, 52.372953619275776, 52.12888077327183, 49.024752208164756, 44.567642620631624, 43.04332249505179, 51.686085973467144, 56.85698400224958, 54.867464610508506, 58.01873322895595, 36.56844561440604, 16.110928773880005, 9.088196856634957, 16.536928040640696, 4.000686764717102, 0.28288428911140984, 0.24006302974053792, 2.193483544247491, 33.35478912081037, 55.63038376399449, 48.125328745160786, 37.750361987522666, 44.14269079480852, 59.419354575020925, 58.185281549181255, 22.23224135807582, 1.65583812551839, 0.1116349764966539, 0.06798339382346187, 0.20722276265067713, 0.15547438444835798, 0.11164909681039197, 0.0822660131379962, 0.08206210657954216, 0.14970068926257746, 0.21388258385871137, 0.2083913085183927, 0.11864059950624194, 0.20271372103265353, 0.16639026227806294, 0.1450817792543343, 0.09951724351516791], [0.01837619224430195, 0.040480663002069504, 0.02443127759865352, 0.01968156130585287, 0.025307133993399993, 0.06955279103879418, 0.07425717610333647, 0.020632604469678233, 0.03464149936501469, 0.044996883520590406, 0.0344632244668901, 0.024988027455817376, 0.0421039325052074, 0.026055244296523075, 0.06642726196774415, 0.01412901679785656, 2.264695414475032, 20.322923285620554, 41.95185429709298, 47.1309095110212, 37.74582133974348, 26.57830309867859, 20.989672422409058, 26.83360423360552, 38.48627349308559, 10.3154102734157, 0.0996624907212598, 0.04246466886252165, 2.6045850047043393, 4.531181292874472, 1.8771099150180817, 9.162169115883962, 3.5156614652701785, 4.407166370323726, 34.24545785358974, 52.730441910879954, 45.831575529915945, 45.20042201450893, 40.04188483101981, 37.974232946123394, 38.842618806021555, 41.207320077078684, 42.31941747665405, 41.112949643816265, 36.492380210331504, 33.12822226115635, 33.4203314781189, 34.461383547101704, 41.56504808153425, 44.49127149581909, 42.08735806601388, 43.33566795076643, 45.019949504307334, 41.93168020248413, 39.87350566046578, 40.39516598837716, 42.39374235698155, 44.18241017205374, 44.547989640917095, 43.62743670599801, 42.38961165291922, 41.346683570316856, 37.39690365110125, 31.602498599461146, 31.229126725878032, 31.909275463649205, 32.673584256853374, 32.152531896318706, 31.15663616997855, 33.64311851773943, 31.32636329105922, 33.24871097292219, 30.807742800031388, 32.35908446993147, 31.313498701368058, 31.774487359183176, 31.201931476593018, 33.375432218824116, 30.346292087009974, 34.36992788314819, 35.60070398875645, 40.27292285646711, 43.24016496113369, 47.15848691122872, 43.441020011901855, 45.49713441303798, 44.962223870413645, 47.17611449105399, 33.41399819510323, 33.82077700751168, 48.90510075432913, 43.42912817001343, 45.96917418071202, 43.97281428745815, 43.86447102682931, 42.38560254233224, 43.243086678641184, 40.6421605518886, 37.66436413356236, 34.686362743377686, 33.927741050720215, 32.68897451673235, 32.86799485342843, 33.09090348652431, 32.732042925698416, 33.11357545852661, 33.8565810748509, 33.02358933857509, 36.72394977297102, 40.284929343632285, 44.03020640781948, 45.33307007380894, 42.23177637372698, 40.756847517830984, 39.73304087775094, 38.255714893341064, 40.77900879723685, 42.60018375941685, 45.5516152381897, 44.90570722307478, 45.72599070412772, 43.82591894694737, 37.41328402927944, 33.929446833474294, 32.411296708243235, 33.11187662397112, 32.26883084433419, 33.637334142412456, 37.740759577069966, 46.250850677490234, 48.66175399507795, 48.184245995112825, 45.30884517942156, 44.89364167622158, 48.19737114225115, 50.18715109143938, 49.961720262254985, 47.5377265385219, 42.608858585357666, 41.63278954369681, 48.09843226841518, 50.92123522077288, 53.14599282400948, 49.123642444610596, 32.76084668295724, 11.6641537632261, 2.534781881741115, 4.650863145078931, 0.4757583024246352, 0.2883906007877418, 0.015279341455815094, 1.1803645363875797, 27.311579499925884, 44.24409280504499, 36.20989424841744, 27.20876353127616, 32.31645032337734, 47.202250140053884, 45.33170127868652, 16.065885339464458, 0.8344988439764295, 0.06248126192284482, 0.06629316309200865, 0.060593808202871254, 0.04679057727168713, 0.005351191361634327, 0.1076562846345561, 0.025492192545373524, 0.0298112528398633, 0.016069307191563503, 0.02953389147296548, 0.026814465610576526, 0.059288897152457914, 0.006780449467312012, 0.04868849400164826, 0.060353851078876426, 0.09670835959592036, 0.04226802262876715, 0.0018407442174585803, 0.06290125474333763, 0.03581018772508417, 0.07586455092366252, 0.005026159092916974, 0.028718814852514436, 0.021532296103292277, 0.06433594240141766, 0.0823306707399232, 0.023069379784698998, 0.026465759679142917, 0.04448108834081462, 0.03005445675392236, 0.05065956359196987, 2.897934909377779, 23.769342694963726, 47.831319195883616, 51.95319209780012, 43.576568944113596, 30.41955736705235, 25.263271399906703, 32.79448986053467, 42.054051876068115, 11.552507502692086, 0.01999300209406231, 0.10111390426754951, 2.385227335350854, 5.886532085282462, 5.186381220817566, 9.586494735309056, 7.199551846299853, 8.351566212517874, 36.293755531311035, 53.95316852842058, 48.803358282361714, 46.20359250477382, 42.31808342252459, 40.18685204642159, 39.62698357445853, 43.03612763541085, 43.01314646857125, 42.57150854383196, 39.16041203907558, 34.922170707157676, 34.04441172736031, 35.20527505874634, 42.58402572359358, 46.55024855477469, 42.82940135683332, 44.11361953190395, 46.09818833214896, 43.757031032017295, 42.06809765951974, 43.42682484218052, 44.69973482404436, 46.2234330858503, 45.24973337990897, 44.88817344393049, 44.94128199986049, 42.60570757729666, 40.146003586905344, 34.61803763253348, 32.761815956660676, 32.61115121841431, 34.79726641518729, 34.90485232216971, 33.105953284672324, 34.408466066632954, 34.10740409578596, 33.74033076422555, 33.37302466801235, 34.38097204480852, 32.81090497970581, 32.65922927856445, 33.41119459697178, 34.78100068228585, 32.43310362952096, 36.283652850559776, 36.87180396488735, 43.25997427531651, 44.38726043701172, 49.45726367405483, 44.69141435623169, 47.61353138514927, 47.398561068943565, 48.00028548921858, 34.49407134737287, 35.268246582576204, 50.17365074157715, 45.47277055467878, 46.70113563537598, 46.7118775503976, 44.18950775691441, 44.13277224131993, 44.06346048627581, 42.727519920894075, 39.449106216430664, 36.58737598146711, 34.05781480244228, 34.44990512302944, 33.272296633039204, 34.49686452320644, 36.03026941844395, 35.00574016571045, 34.45017957687378, 35.525024209703716, 38.293780599321636, 44.169583797454834, 45.46324804850987, 46.698467527117046, 45.08701351710728, 42.57360689980643, 41.83297061920166, 40.49180848257882, 43.008487701416016, 44.87799433299473, 46.53898899895804, 44.27278886522566, 47.0951714515686, 47.11558525902884, 39.29000289099557, 36.18405737195696, 33.17500448226929, 34.175496441977366, 33.274183068956646, 35.566973958696636, 40.28862925938198, 48.227363041469026, 49.94063247953142, 49.14451483317784, 45.94675234385899, 47.95231512614659, 48.62973322187151, 52.20017276491438, 51.54076092583792, 51.015852315085276, 44.04998792920794, 44.11331728526524, 48.53632511411394, 55.24435922077724, 53.56190504346575, 52.74001652853829, 32.64236947468349, 15.968636614935738, 2.9986255977834975, 5.880551423345294, 2.354050334010805, 0.760399617254734, 0.00819738325662911, 1.295984297990799, 31.431253296988352, 49.80896411623274, 40.18744611740112, 30.40496962411063, 37.482171944209504, 52.69606222425188, 52.28053910391671, 19.351389680589946, 0.9145653247833252, 0.038956880303365846, 0.0023165679594967514, 0.08494227738784892, 0.017286249569484165, 0.024091870989650488, 0.09820806447948728, 0.00799742153113974, 0.020914678262280564, 0.014017426625027187, 0.05069778546957033, 0.012652747665664979, 0.02412615736414279, 0.009186897659674287, 0.018212110602429936, 0.036718328816017935, 0.15582583844661713, 0.11700972701822009, 0.10726311430335045, 0.15418273875755922, 0.11952118868274347, 0.11674551905265876, 0.17494931657399448, 0.1661804863916976, 0.06937470952314989, 0.14357947558164597, 0.1618390836353813, 0.1112519231225763, 0.08164443434881312, 0.09414526141647782, 0.11555485294333526, 0.13830332298363957, 3.5770613934312547, 29.10616544314793, 54.37264517375401, 58.30232048034668, 48.543565137045725, 35.81892258780343, 29.527095999036515, 35.527063505990164, 48.587210246494834, 13.13358919961112, 0.25726223683782984, 0.2805665763361113, 4.8371643253735135, 14.583391632352557, 7.311581560543605, 18.496973173958914, 7.722375563212803, 6.993576841694968, 37.70796060562134, 56.73780155181885, 51.45847340992519, 48.674222537449424, 44.411009379795615, 42.33051374980381, 43.265459878104075, 45.7751978465489, 46.10155473436628, 45.11033167157854, 40.61569486345564, 36.85490594591413, 37.06803846359253, 38.335977009364534, 44.94906398228237, 47.431703976222444, 43.246859550476074, 45.47296510423933, 49.282693658556255, 47.25846454075405, 44.41212803976876, 45.13460520335606, 47.302186080387656, 48.77848720550537, 47.86686270577567, 46.426032134464805, 45.865069321223665, 44.85788624627249, 43.68857043130057, 35.862011841365266, 33.12787137712751, 34.19424615587507, 35.631237847464426, 34.771829060145784, 34.42604848316738, 36.00032268251692, 35.6612297466823, 34.30237054824829, 34.78922387531826, 34.94496079853603, 34.27068676267351, 34.46286003930228, 35.015286990574424, 37.17867462975638, 34.2306547164917, 38.26938547406878, 39.6975599016462, 44.245673520224436, 48.67107152938843, 52.9812718800136, 47.7706093106951, 48.658634253910606, 50.9551875931876, 47.334985051836284, 36.721504007067, 38.02577468327114, 50.439349855695454, 48.75053112847464, 48.63249165671212, 49.14360114506313, 46.31827252251761, 46.060945987701416, 45.93692411695208, 45.70346464429583, 42.067128385816304, 38.36694860458374, 36.80628592627389, 36.508708477020264, 34.93488243647984, 36.49539572851998, 37.40022141592843, 35.98400483812605, 36.711324896131245, 35.79094219207764, 39.13967514038086, 45.85585600989205, 48.37747539792742, 49.01175560270037, 47.21578523090908, 44.56308807645525, 45.171448026384624, 42.50961399078369, 44.980584485190256, 45.82814311981201, 48.72140080588204, 46.21411902563912, 47.33215366091047, 48.003773484911235, 41.823361260550364, 37.49523803165981, 36.65799052374703, 36.881927490234375, 36.71001516069685, 36.0818042073931, 41.94371795654297, 50.618012360164094, 52.572273118155344, 50.23907845360892, 47.84765441077096, 48.23957797459194, 50.09783547265189, 54.1533739226205, 54.75859676088606, 51.66156578063965, 47.02559566497803, 46.801412037440706, 52.18141957691738, 56.9308294568743, 57.9503664289202, 52.698987415858674, 36.10328803743635, 16.841344254357473, 5.880952247551509, 8.232385499136788, 2.4323704285281043, 1.6519115247896738, 0.11374872843069689, 1.5656220636197498, 35.65114791052682, 57.26489884512765, 47.369937964848106, 38.0119686126709, 44.362253870282856, 59.14428234100342, 61.124143736703054, 25.47270747593471, 1.4702323079109192, 0.20759138358490808, 0.14349989699465887, 0.14799224665122374, 0.11443110395755086, 0.0904672419918435, 0.23527208396366664, 0.17375490495136806, 0.09444722307047673, 0.10453950187989644, 0.1321470561836447, 0.09720973590654985, 0.10630623743470226, 0.08236677558826548, 0.10339704568364791, 0.11180060010935579], [0.05005947061415229, 0.05073630929525409, 0.03986156765105469, 0.019015809886955788, 0.038720604231847186, 0.0408580438233912, 0.05803518835455179, 0.01567818603611418, 0.05580263850944383, 0.03336003848484584, 0.04381503836650934, 0.05647445942408272, 0.04334016902638333, 0.04647741300453033, 0.05002835299819708, 0.059807942514973025, 1.0701618726764406, 17.57437573160444, 41.56903287342617, 40.82046522412981, 29.711473396846227, 12.02405742236546, 15.05122252873012, 29.960406507764542, 36.468603474753245, 14.480865750994, 0.09083327770765338, 0.17790650789226803, 0.7218630079712186, 5.824747834886823, 4.782887603555407, 5.285037389823368, 6.546745572771345, 7.852086271558489, 24.01658739362444, 51.74789367403303, 43.551201071058, 43.81778955459595, 41.05938598087856, 41.19384404591152, 38.726896558489116, 40.813100133623394, 39.63340023585728, 39.68645668029785, 34.04533931187221, 32.87665925707136, 32.12835911342076, 39.973205362047466, 45.72038003376552, 43.50344262804304, 43.95690986088344, 42.969820976257324, 38.36141783850533, 39.02057259423392, 37.26757335662842, 38.5072466305324, 38.18937349319458, 40.07168565477644, 41.28020320619856, 44.7272948537554, 43.44023833956037, 42.85331358228411, 37.53898041588919, 31.363105365208217, 30.522752012525284, 32.97404520852225, 30.52624695641654, 30.89086757387434, 30.92097064426967, 31.90475218636649, 33.787140778132844, 34.49340432030814, 30.90582357134138, 30.725451810019358, 31.25108650752476, 33.59836169651577, 31.87605265208653, 32.67452573776245, 31.53077929360526, 33.93148612976074, 34.36312212262835, 38.27203968593052, 41.979310103825156, 44.78480509349278, 45.46290758677891, 45.745970249176025, 40.616771834237234, 44.21311773572649, 30.799338953835623, 29.62242875780378, 43.61376959936959, 41.54654850278582, 48.410444600241526, 44.279320171901155, 46.25693729945591, 43.48572819573538, 44.40953288759504, 42.790814535958425, 42.7209712437221, 37.449331283569336, 33.90389483315604, 32.80775049754551, 31.222644056592667, 32.833365031651084, 31.977659634181432, 33.80872188295637, 33.66609968457903, 33.81728206362043, 32.801330362047466, 35.899750982012065, 39.72058623177664, 38.59439788545881, 38.00623982293265, 35.01087488446917, 34.26772335597447, 34.1466440473284, 40.68600715909685, 41.17555638722011, 46.01312501089913, 45.29274272918701, 45.21213320323399, 43.45371784482683, 36.86808320454189, 33.454735483442036, 33.64105142865862, 31.47090319224766, 30.30057294028146, 33.76182501656668, 32.60720464161464, 37.146042415073936, 44.19272824696132, 48.00893947056362, 48.07432549340384, 48.40441703796387, 45.58123888288225, 48.292731693812776, 51.002001081194194, 48.563767024448936, 47.9445435660226, 43.33051586151123, 46.127419403621126, 51.41406052453177, 53.55175372532436, 54.368267808641704, 31.91958659035819, 10.958251527377538, 0.4669095001050404, 3.6881485411099026, 1.7391453981399536, 0.26107649930885857, 0.06641474299665008, 1.6973609945603778, 29.22033303124564, 42.61971861975533, 35.306715284075054, 37.819486141204834, 33.606661319732666, 46.66055815560477, 42.30760553904942, 17.8407609803336, 0.9116956101996558, 0.03618520385186587, 0.05009835067072085, 0.08362750722361462, 0.0662226565182209, 0.016816640572090234, 0.010521547203617436, 0.027129896184695617, 0.025980322156101465, 0.05712704387094293, 0.020744905407939638, 0.023392308170774152, 0.019475191665281142, 0.061627556303782124, 0.0028278716615334687, 0.047792023713035245, 0.021419165655970573, 0.08553717618009873, 0.0015297929286524387, 0.047336078714579344, 0.03321970387228897, 0.03472224503223385, 0.03129754987146173, 0.02550488115022225, 0.07059531938284636, 0.01812435227579304, 0.019519466075247953, 0.021515497272568088, 0.01627193471150739, 0.028443675687802688, 0.05195500568619796, 0.10518110423747982, 1.5269263514450617, 21.544036184038433, 47.7885217666626, 46.98093959263393, 35.81769275665283, 18.331079721450806, 18.531113147735596, 33.45741401399885, 43.99165085383824, 15.811391932623726, 0.265786346580301, 0.16275818645954132, 0.65424031657832, 3.51660207765443, 7.2316751054355075, 10.264343619346619, 8.925943391663687, 6.97558274439403, 27.273979323250906, 52.84290197917393, 45.615448338644846, 46.05897617340088, 41.84027665002005, 43.179159777505056, 41.49749769483294, 42.87271295275007, 42.70784609658377, 41.70317479542324, 35.68551370075771, 34.23228406906128, 33.31537199020386, 41.18961606706892, 47.08219569069998, 44.11703109741211, 43.79534339904785, 44.768459456307546, 41.131720202309744, 40.529804706573486, 39.868176392146516, 40.270730699811665, 39.93408005578177, 43.16712897164481, 43.70890433447701, 45.787249497004915, 44.43029063088553, 44.178022384643555, 39.91711255482265, 33.64982352937971, 32.60396678107125, 34.08169576099941, 32.621344225747244, 33.66931670052664, 32.49731193270002, 34.01041766575405, 35.026709829057964, 34.518810408455984, 32.76144075393677, 32.82948098863874, 32.26757322038923, 34.103471415383474, 32.35696874346052, 34.46711581093924, 33.478022371019634, 35.17971958432879, 35.95568050657, 40.90059879847935, 44.17309611184256, 45.42484882899693, 45.62050315311977, 46.45135484422956, 41.877411297389436, 44.27362959725516, 32.92930228369576, 33.468308789389475, 44.10029288700649, 42.31172929491316, 49.64057799748012, 46.45851148877825, 48.627454212733674, 45.17545018877302, 47.243223667144775, 45.28979321888515, 43.449104240962434, 37.55604519162859, 35.19323035648891, 34.40275117329189, 32.51452956880842, 34.50122104372297, 34.325525420052664, 34.55959980828421, 35.18502453395298, 34.25063426154, 35.393143926348, 38.40966612952096, 42.05051176888602, 41.27114970343453, 41.24005651473999, 39.358209882463726, 36.77693326132638, 35.37282739366804, 42.74162476403372, 43.49598721095494, 46.024339403424946, 46.139735085623606, 45.87932355063302, 46.89268010003226, 39.12284312929426, 35.68217509133475, 34.84581347874233, 33.592372349330354, 33.06791189738682, 34.057411806924, 34.36571032660348, 38.97450951167515, 45.89151416506086, 49.82701553617205, 49.700339453560964, 49.348517417907715, 47.869992869240896, 49.04321357182094, 53.631772654397146, 50.66952977861677, 48.76846442903791, 45.300170353480745, 47.096689632960725, 53.47085584912981, 55.49081529889788, 54.64054339272635, 33.08661992209298, 13.364725368363516, 2.739235665116991, 5.221969894000462, 2.2758216517312184, 0.1405829428029912, 0.07745770364999771, 1.700893285019057, 30.873028073992046, 49.147961139678955, 43.24747099195208, 40.36595228740147, 41.66460187094552, 51.36441217150007, 50.219269139426096, 21.20313150542123, 1.0314266426222665, 0.023536205092178922, 0.015515223977022936, 0.028726231240268265, 0.06896839596863304, 0.03796343718256269, 0.019175467480506216, 0.014833230126116956, 0.028997879342309067, 0.0179299859197012, 0.02720224667739655, 0.011364853425350572, 0.04100385421354856, 0.04973404521920851, 0.04322460772735732, 0.00933262747379818, 0.11977964267134666, 0.21290347139750207, 0.16298229300550052, 0.0780865970466818, 0.1581173190580947, 0.12774862934436115, 0.19667222164571285, 0.07885544507631234, 0.2227994432406766, 0.09026339650154114, 0.10557789116033486, 0.1477680993931634, 0.05764961761555501, 0.11074880297694888, 0.1404684196625437, 0.23847669629114016, 2.0918324845177785, 24.403565577098302, 53.96128749847412, 53.74322870799473, 40.75930370603289, 21.841563258852275, 21.87683752604893, 38.74836996623448, 49.003587995256694, 19.376526526042394, 0.5025474620716912, 0.39842819049954414, 2.9177728848797932, 9.744849392345973, 11.88817584514618, 9.792229158537728, 11.445275953837804, 9.861773678234645, 28.40887897355216, 54.98229054042271, 48.453627654484336, 47.26334912436349, 44.48986448560442, 45.590636321476524, 42.21863733019148, 44.81587743759155, 43.57612773350307, 43.4802634375436, 36.11885895047869, 35.52575724465506, 35.83436148507254, 43.296441895621165, 50.08607564653669, 43.880806241716655, 45.84519747325352, 48.37101704733712, 43.531006131853374, 42.6821551322937, 42.30971779142107, 42.59036595480782, 42.66058792386736, 44.91215167726789, 44.20481811250959, 46.6636118888855, 46.64096770967756, 48.62919821058001, 41.618490150996614, 34.75929798398699, 33.87403842381069, 36.56752150399344, 34.978211402893066, 35.52485745293753, 33.21228851590838, 35.57422092982701, 37.6624881199428, 37.22920887810843, 33.09428725923811, 34.324514457157676, 34.68272883551461, 36.19731453486851, 35.6181891305106, 35.69533845356533, 35.38766874585833, 38.22282212121146, 37.61057118007115, 42.077172006879536, 46.56432213102068, 47.664590222494944, 48.828733103615896, 48.84405040740967, 41.8599157333374, 45.45022365025112, 36.45724664415632, 36.84397642953055, 44.23475442613874, 43.83927338463919, 51.18668072564261, 48.00211633954729, 50.10135473523821, 47.33689233234951, 47.85682603291103, 46.15712642669678, 45.80480064664568, 41.08570575714111, 37.28300877979824, 35.99743570600237, 33.26046732493809, 37.943817206791465, 35.493031229291645, 36.37789126804897, 37.09768990107945, 35.74981233051845, 36.695083481924875, 40.04040139062064, 43.59108373097011, 43.55847930908203, 42.45610243933541, 40.30368253162929, 38.9014561516898, 37.28096253531319, 45.17232697350638, 44.88901417595999, 48.70626762935093, 47.076751777103965, 48.179066113063264, 49.18917785372053, 41.67950923102242, 37.1728172983442, 36.811368533543174, 35.83434411457607, 34.50164835793631, 37.13050971712385, 37.03935282570975, 40.09428814479283, 47.7606178011213, 53.26243768419538, 51.58949211665562, 51.48995222364153, 47.27392428261893, 50.92203426361084, 54.28553213391985, 54.28119993209839, 52.33870594842093, 48.288024289267405, 47.981848444257466, 56.27757024765015, 57.49895933696202, 56.6492953981672, 34.071964808872764, 14.980536767414637, 4.685103867735181, 13.951155935014997, 4.509663590363093, 0.42835500463843346, 0.2981797983603818, 2.3176437275750295, 37.34100191933768, 53.780995641435894, 48.55875389916556, 48.211302280426025, 45.9269187109811, 59.97193786076137, 58.5376490184239, 26.477988481521606, 1.7376507754836763, 0.19071190218840325, 0.18813437835446425, 0.1744602963860546, 0.20896875538996287, 0.18646043246345861, 0.13397832720407418, 0.13869643903204373, 0.12964934163859912, 0.1992310450545379, 0.14826625266245433, 0.09635185729712248, 0.10665902136159794, 0.17477798648178577, 0.14497934760791914, 0.09730949412499156], [0.026095422051314796, 0.06868880561419896, 0.06266384212566273, 0.05380627991897719, 0.030652052722871304, 0.023944691655093005, 0.03054171275081379, 0.03885050636849233, 0.026129845829148377, 0.06528156915945665, 0.041571967835937224, 0.03904951051143663, 0.03695900518713253, 0.006514461619579899, 0.09590770862996578, 0.008271858412107187, 0.32054626675588743, 9.789277911186218, 36.807279518672395, 43.47367654527937, 34.085753508976524, 26.55655697413853, 25.38153668812343, 25.81314488819667, 32.134247711726594, 17.80572121483939, 0.30973351267831667, 0.022643800924665163, 0.9654572967972074, 0.9312171169689724, 5.3196472355297635, 12.134139469691686, 9.929536853517805, 6.184670167309897, 23.444919143404277, 50.71481466293335, 45.724847725459504, 42.67961209160941, 39.343340737479075, 37.96707630157471, 40.74251338413784, 38.267189843314036, 38.301274231501985, 36.454651491982595, 33.323310307094026, 33.440206800188335, 35.427978719983784, 43.84471729823521, 43.65525729315621, 42.28724384307861, 43.995302132197786, 39.263016087668284, 37.714731625148225, 36.874211515699116, 35.112308161599294, 34.72215291431972, 36.46772105353219, 38.771392822265625, 39.172283036368235, 42.04584952763149, 44.90974760055542, 42.32372535978045, 38.284442220415386, 31.59709984915597, 31.215098312922887, 32.12337378093174, 31.010147299085343, 31.481005872998917, 32.3101761000497, 31.147117137908936, 35.5215014730181, 36.543275765010286, 31.493057523454937, 32.97237416676113, 31.555313382829937, 31.43147563934326, 31.084260259355815, 33.199458667210166, 30.645266124180385, 32.437303815569194, 32.833497047424316, 35.90473631450108, 38.293495723179404, 41.108214446476524, 43.03745126724243, 43.91379976272583, 44.94630902154105, 40.31162779671805, 31.433448927743093, 30.1399062701634, 41.70749657494681, 43.4388313293457, 47.46977315630232, 44.29300117492676, 46.46045003618513, 46.18432167598179, 46.54864352090018, 46.031225068228586, 44.39933293206351, 38.399539130074636, 33.29786252975464, 31.672209875924246, 31.994352681296213, 33.34341491971697, 33.27818523134504, 34.42145224979946, 32.5542037827628, 32.303009033203125, 33.409457547324045, 33.74053226198469, 35.11839478356497, 32.461896964481895, 32.986611025674, 33.81056662968227, 32.199036189488, 34.00780861718314, 38.570072242191856, 41.83743136269705, 43.88941158567156, 45.26032590866089, 45.53697885785784, 42.8806026322501, 39.301133905138286, 38.0828298160008, 34.66313144138881, 35.18034839630127, 34.03782136099679, 31.918968200683594, 33.297817366463796, 33.067647865840364, 35.04628985268729, 43.0482348714556, 45.872472626822336, 48.63342271532331, 47.97014767783028, 46.802322251456125, 48.38234608513968, 52.80523232051304, 49.076898438589915, 47.51217106410435, 45.128674915858674, 52.13935170854841, 51.49764387948172, 55.20393112727574, 29.518810272216797, 18.03272407395499, 2.7712321196283614, 3.9585346494402205, 2.558856304202761, 0.2315610402396747, 0.07415532799703733, 1.9711789701666151, 33.64694350106375, 42.85864632470267, 30.435322829655238, 21.069944960730417, 29.38712453842163, 44.73439938681466, 48.82641587938581, 20.948453971317836, 0.9460653087922505, 0.054339510056057146, 0.016578883597893373, 0.03254650213888713, 0.031668080881770165, 0.019900069937908223, 0.007465732516720891, 0.021904253733477423, 0.019308470522186587, 0.05793311633169651, 0.05277318999703441, 0.06185884853558881, 0.036361684024866135, 0.022163696686870286, 0.04748861338677151, 0.048742708949638267, 0.07630457409790584, 0.062205600286168714, 0.022819785767101815, 0.031651524627315145, 0.042768082581460476, 0.06629838781165225, 0.03945547801309398, 0.0517161206475326, 0.018906177287655215, 0.03463776402973703, 0.013892229280567594, 0.049687792879662344, 0.011561822811407703, 0.005788600479718298, 0.0867245988920331, 0.0520656849257648, 0.3909235931932926, 13.682515127318245, 44.79579714366368, 49.62095628465925, 39.141558102199006, 26.637706722532, 24.289352825709752, 31.007764066968644, 36.84339278084891, 19.82108095714024, 0.35014013733182636, 0.023825349219675575, 0.5917787796684674, 4.115450595106397, 7.350735528128488, 10.117259808949061, 10.301916871752058, 10.00034247125898, 25.392302921840123, 54.019902501787456, 47.55389847074236, 45.50580923897879, 42.382816314697266, 40.161824635096956, 42.605676310403005, 40.43459701538086, 41.26216568265642, 37.96750361578805, 34.228337492261616, 35.013428347451345, 35.51902791431972, 46.17027589253017, 44.54568631308419, 42.33153860909598, 45.99808216094971, 41.811768191201345, 39.81323003768921, 39.409053325653076, 37.85304594039917, 37.44580854688372, 38.67516027178083, 41.745266982487266, 41.28435475485665, 45.4075026512146, 47.555764062064036, 43.57013838631766, 39.5052615574428, 33.9944680758885, 32.77724095753261, 32.40243080684117, 34.132824080330984, 33.01149252482823, 33.83939470563616, 33.53404917035784, 36.82066522325788, 39.02725328717913, 32.075191497802734, 32.860334464481895, 32.27212429046631, 33.650136198316304, 32.358070032937185, 34.5366325378418, 32.718751021793906, 34.542736530303955, 35.48337670734951, 38.12410906382969, 40.783438273838584, 43.90967600686209, 43.51634543282645, 44.99916744232178, 46.39227083751133, 43.086898122514995, 35.000515120370046, 32.254764216286794, 43.212594509124756, 43.191471985408235, 49.931502546582905, 45.999350207192556, 47.56206260408674, 45.53521401541573, 47.45824262074062, 47.48551082611084, 45.599213872637065, 39.99971273967198, 35.066714082445415, 35.39306402206421, 33.393754618508474, 33.95486681801932, 34.627219676971436, 34.63578680583409, 33.77389751161848, 33.80073492867606, 34.84170709337507, 35.62491151264736, 36.889379433223176, 35.54567773001534, 35.23991877692086, 34.600173813956125, 34.26735510144915, 35.08073902130127, 41.41397687367031, 43.887657165527344, 47.151750632694785, 46.94640357153756, 46.68672507149832, 44.544251510075156, 41.174785137176514, 38.654958384377615, 36.284510953085764, 35.964185101645334, 35.382773739951, 33.577308654785156, 35.84063918249947, 35.24448374339512, 38.56487498964582, 46.056367124829976, 48.569572244371685, 50.07540668760027, 50.28170912606375, 46.437600885118755, 50.36116177695138, 54.518182141440256, 52.988411154065815, 48.03868123463222, 47.623283181871685, 53.252251625061035, 53.5903058052063, 55.27100903647286, 32.19149391991751, 10.895527533122472, 4.430695576327188, 2.3980339510100226, 3.162392032997949, 0.17393080836960248, 0.04035373963415623, 2.0024502064500536, 35.47296483176095, 49.081699643816265, 38.37647111075265, 28.626124824796403, 34.326171602521626, 51.63978317805699, 53.98540122168404, 23.59385030610221, 1.2802443483046122, 0.05755723507276603, 0.04084823899237173, 0.013720453051584107, 0.011664476678041475, 0.047605938876846006, 0.04059192238907729, 0.04547448057149138, 0.016883589926042726, 0.02725076023489237, 0.012251255102455616, 0.051399573883307834, 0.03589541172342641, 0.016094055060031157, 0.06467933540365525, 0.06858173957360642, 0.15251255195055688, 0.1436460805790765, 0.16048945034188883, 0.19726728328636714, 0.13021766899951867, 0.21223477513662406, 0.11037951707839966, 0.15006674533443792, 0.09613875658916575, 0.23036660147564753, 0.144384801653879, 0.08781572391412087, 0.06503015157899686, 0.08534962231559412, 0.15056709705718926, 0.1928222682327032, 0.7074348564658846, 16.051038776125225, 52.14100537981306, 54.87533344541277, 46.392222200121196, 36.03309038707188, 35.45569161006382, 35.65295444216047, 43.04214824948992, 23.803920405251638, 0.764875451368945, 0.13233855233660766, 2.401706508227757, 7.047599954264505, 11.453413162912641, 19.637620721544536, 16.78445761544364, 9.869821429252625, 27.303408418382915, 57.22603757040841, 49.40672595160348, 47.06331396102905, 43.5112350327628, 42.992656230926514, 44.67447812216622, 41.91388586589268, 43.3376864024571, 39.98081016540527, 35.424848556518555, 36.877921853746685, 38.33221803392683, 48.24898930958339, 45.66134466443743, 42.091311591012136, 48.810098034994944, 43.435110569000244, 42.102432182856965, 41.95409509113857, 40.20225967679705, 39.176709038870676, 41.30411543164934, 44.97861467088972, 43.009234632764546, 46.410905906132285, 48.771827357155935, 45.70622655323574, 41.694965498788015, 35.26851756232125, 34.43508114133562, 35.84203577041626, 35.00813034602574, 35.757403237479075, 35.525930949619834, 34.36640862056187, 38.652377128601074, 39.070596149989534, 34.71951607295445, 34.85071195874895, 34.54552623203823, 35.23843533652169, 34.84680012294224, 36.32128082002912, 34.583126408713206, 36.81101417541504, 37.424352509634836, 38.95973069327218, 41.62163768495832, 46.43506479263306, 46.114332471575054, 46.851696150643484, 48.16878972734724, 45.153337546757285, 37.519601890019004, 35.70675434385027, 43.4023254939488, 45.25397525514875, 51.80877031598772, 47.403390066964285, 49.18186140060425, 48.430851459503174, 47.44993952342442, 49.14858995165144, 47.27109636579241, 42.775313104902, 37.257074628557476, 35.137947014399934, 34.54794767924717, 36.3236015183585, 36.20264032908848, 36.91567836488996, 35.27175194876534, 35.75428697041103, 36.509198325020925, 36.56181008475167, 38.738899571555, 36.26105383464268, 36.59924003056118, 36.95255592891148, 36.03206900187901, 37.449484143938335, 41.9266288621085, 46.44273560387747, 48.3830999646868, 49.50737755639212, 48.02545881271362, 46.68753106253487, 43.37746483939034, 42.8606196131025, 38.11738320759365, 38.92372512817383, 38.36416932514736, 35.93994978496006, 37.44544376645769, 36.9819016456604, 40.04348986489432, 48.23843847002302, 51.368574142456055, 52.84707089832851, 50.99420172827584, 48.88685825892857, 50.616032123565674, 57.9864935874939, 54.86093330383301, 51.19250679016113, 49.350678307669504, 57.28260980333601, 54.83958148956299, 58.309296471732004, 31.829079355512345, 23.31754650388445, 10.265106184141976, 11.996684125491551, 8.018783109528677, 0.3819626968886171, 0.21679548041096755, 2.5405810219900946, 41.96203340802874, 54.284385681152344, 41.429589475904194, 31.986848626817974, 40.70780365807669, 57.31083338601248, 63.24690873282296, 29.5723774092538, 2.0625579868044173, 0.13271933261837277, 0.10106689536145755, 0.16038663871586323, 0.10890326236507722, 0.08599608298391104, 0.10487330718232052, 0.12266451572733265, 0.16270683492933, 0.17464863056583063, 0.12602238197411808, 0.11572284464325223, 0.13140756157892092, 0.11441986741764204, 0.12669622153043747, 0.11729484743305615], [0.02640680516404765, 0.03940951744360583, 0.013640281594624477, 0.028517761533813815, 0.07197032988603626, 0.0702453310202275, 0.04955008759030274, 0.023378725596038357, 0.05034737641523991, 0.03354033202465091, 0.03370966383122972, 0.02847265252577407, 0.045837133790233305, 0.06407731877905981, 0.03603749695633139, 0.06257340019302708, 0.20335104183426925, 7.112140468188694, 30.61451687131609, 38.733823912484304, 40.95662212371826, 24.185690913881572, 26.838832753045217, 36.82393087659563, 38.04905462265015, 20.840876749583654, 1.2560034947735923, 0.05949034741414445, 0.18895997905305453, 1.6525298058986664, 6.195503277438028, 9.787348917552404, 10.2017559834889, 13.271619507244655, 26.152312517166138, 47.64899846485683, 46.25406074523926, 45.60777405330113, 40.63776581627982, 42.4630297933306, 37.903899805886404, 36.60712971006121, 35.35562712805611, 35.04105091094971, 33.20687239510672, 31.013680458068848, 37.23674072538103, 45.80389738082886, 44.38737508228847, 45.20403160367693, 41.9475359916687, 38.258740833827424, 36.398166111537385, 33.86381762368338, 30.071786131177628, 30.392577511923655, 32.9341903414045, 35.209756646837505, 35.85882261821202, 38.96059226989746, 40.399143832070486, 39.64464936937605, 34.10349920817784, 30.988986560276576, 31.618472508021764, 31.7271214893886, 32.606888498578755, 31.624510492597306, 32.3775041443961, 33.08577919006348, 32.83682870864868, 31.894923959459575, 32.16853707177298, 31.455467769077845, 30.657071113586426, 31.440657683781215, 31.482537950788224, 31.71255806514195, 32.75112962722778, 32.55858809607369, 30.355154514312744, 33.52845587049212, 31.950158664158412, 36.537873540605815, 39.80276952471052, 42.33243145261492, 43.27551392146519, 44.901579993111746, 34.85487392970494, 33.991369179316926, 49.97657898494175, 43.11408294950213, 45.92243364879063, 43.62560585566929, 44.778867857796804, 44.610572065625874, 46.52768080575125, 45.09459400177002, 45.137182985033306, 37.40252126966204, 32.79314191000802, 32.076306683676584, 32.83402511051723, 33.208060537065776, 34.222177914210725, 31.968394211360387, 34.676784651620046, 31.979570388793945, 32.78547804696219, 33.445515223911826, 31.758423124040874, 31.6703234400068, 31.844514778682164, 32.21687568937029, 33.07264709472656, 35.647187437329976, 39.87843540736607, 41.291236945560996, 45.87053407941546, 42.48788002559117, 44.94882774353027, 45.724899836948936, 45.2558582169669, 41.900316034044536, 41.42576796667916, 41.916342054094585, 42.91224125453404, 39.5997952733721, 34.560555185590474, 33.63787957600185, 33.950944559914724, 35.648987020765034, 42.785780566079275, 47.21585818699428, 48.49694619859968, 48.48771551677159, 46.770096506391255, 50.43885653359549, 49.48212432861328, 45.91680213383266, 47.30215828759329, 49.50295155388968, 54.55507707595825, 51.42263112749372, 32.411150796072825, 7.028130233287811, 1.1671961801392692, 1.2107194789818354, 1.0857782747064317, 0.19978641239660128, 0.10221736505627632, 1.9345016011169978, 30.1684981073652, 44.696066175188335, 31.82079710279192, 27.760005814688547, 35.5098180770874, 46.86248322895595, 46.104257583618164, 18.030705622264318, 0.5311175318700927, 0.03728240515504565, 0.07170090398618154, 0.03997272525780967, 0.04568944725074938, 0.0005443537115102767, 0.03444667160511017, 0.03331712453759142, 0.08008053326713187, 0.05719300426010575, 0.06670625521136181, 0.08184194232204131, 0.05778897513768502, 0.08077697482492242, 0.011523438085402762, 0.0336695081288261, 0.042395512573421, 0.07672751854572978, 0.042080336449933906, 0.022616347397810647, 0.10993610801441328, 0.027426733202966194, 0.029147689696401358, 0.0230336600049798, 0.0583519624280078, 0.028812031993376355, 0.06470581184008292, 0.03422500439254301, 0.02144381683319807, 0.019799417749579464, 0.04356201265805534, 0.04096080116661532, 0.10432528158915894, 9.484059180532183, 38.39840657370431, 47.606708254132954, 46.07625634329659, 31.30403525488717, 26.330896854400635, 32.06743730817522, 39.80888046537127, 23.327881949288503, 1.2515642472675867, 0.019733389506914785, 0.11538192150848252, 4.710555987698691, 8.253883225577217, 7.41172160421099, 7.864341156823294, 11.447961432593209, 27.028714861188615, 49.416022641318186, 49.10372543334961, 48.752309867313926, 42.60031924928938, 42.90919099535261, 41.108568804604666, 40.4106569971357, 36.54564510072981, 36.84961141858782, 34.53436395100185, 32.568402426583425, 39.1762296131679, 46.88228212084089, 46.22099079404558, 44.35182809829712, 43.962055001940044, 40.06229863848005, 39.56895221982683, 35.32913364682879, 31.762935979025706, 32.33921262196132, 34.35844251087734, 36.83121606281826, 37.84358944211687, 41.47112233298165, 42.89703859601702, 42.674817834581646, 36.79291064398629, 32.24186488560268, 32.57740381785801, 32.47054747172764, 34.228643212999614, 31.760545798710414, 33.069982460566926, 34.587799072265625, 33.70054885319301, 33.274645124162944, 33.05227150235857, 33.00447484425136, 32.17404351915632, 32.932977880750386, 32.71024642671858, 33.03929574148995, 35.68015316554478, 33.947539942605154, 32.19722965785435, 34.93063708714077, 36.350953102111816, 38.111300059727256, 41.69409349986485, 44.69400256020682, 45.80308444159371, 46.039239815303254, 36.84146465573992, 35.31748499189104, 50.954683848789756, 44.292792728969026, 48.36194269997733, 47.02658230917794, 47.05479199545724, 45.67270149503435, 49.110333170209614, 46.386389187404085, 46.845095361982075, 41.01548031398228, 34.06304332188198, 34.64794615336827, 33.604903425489155, 34.6868873323713, 36.01433025087629, 34.012943335941856, 36.444875376565115, 33.8358268056597, 35.30631576265608, 35.106975419180735, 33.784903458186555, 32.52961410794939, 33.36588886805943, 34.322909423283164, 34.46515989303589, 36.93317740304129, 41.7309502192906, 44.47068050929478, 48.271164485386436, 42.95028264181954, 48.066036292484824, 47.342850412641255, 45.005938461848665, 43.52356113706316, 44.737279415130615, 42.49282366888863, 44.11467913218907, 41.02971369879586, 35.51839910234724, 34.08523934228079, 35.99300970349993, 37.836964334760395, 45.50914784840175, 48.83827992847988, 52.35330063956124, 50.3021194594247, 49.17573308944702, 51.936141218457905, 51.84359816142491, 47.67395639419556, 48.80470970698765, 52.51222678593227, 55.23192541939871, 52.666497639247346, 30.446346146719797, 9.18236666066306, 7.686811208724976, 2.8004210676465715, 2.257250419684819, 0.3762923425861767, 0.028563067317008972, 2.1748430473463873, 34.164011069706504, 48.400324548993794, 36.09544699532645, 29.389334065573557, 38.59798315593174, 51.79130254473005, 52.17734793254307, 22.746098858969553, 1.3352965542248316, 0.05981219692953995, 0.06717126204499177, 0.04128078810338463, 0.017693482538951293, 0.010120239541200655, 0.018477524663986902, 0.04016310182799186, 0.04521713259496859, 0.026708363089710474, 0.04633858473971486, 0.03383201387311731, 0.021696983337668434, 0.007569683233409056, 0.06340871751308441, 0.010971180130062359, 0.07082240469753742, 0.1520530887480293, 0.07786521142614738, 0.11638979028378214, 0.22732789096023354, 0.17331471214337008, 0.1316551590072257, 0.08135340389396463, 0.28137468440192087, 0.19209553008633, 0.1495089895491089, 0.17136427680296556, 0.09624172427824565, 0.1388263649174145, 0.14911953758980545, 0.09984688939792769, 0.3626491203904152, 11.74767632143838, 44.39018562861851, 52.018623283931184, 53.88148743765694, 33.523154394967214, 34.444516795022146, 44.821383884974885, 47.49841710499355, 27.583043881825038, 1.8137809932231903, 0.14947534778288432, 1.065483455147062, 8.466442516871862, 13.79273874419076, 19.945710795266287, 18.396908691951207, 16.358890874045237, 27.920972994395665, 50.492225646972656, 51.26677261080061, 50.89199372700283, 44.78646223885672, 46.15355157852173, 41.96602862221854, 41.02632645198277, 37.83116953713553, 39.45804507391793, 35.63320418766567, 33.687531403132844, 41.6122020312718, 50.40977137429373, 47.096647943769185, 45.903110708509175, 46.78998919895717, 42.00232948575701, 41.44717884063721, 37.59292622974941, 32.960030691964285, 33.260505540030344, 36.67334604263306, 38.22034856251308, 38.93042319161551, 43.09479127611433, 45.16173791885376, 44.37118577957153, 37.99119002478463, 33.7373708316258, 34.67341477530343, 34.156166553497314, 36.89039734431675, 34.17726823261806, 35.632068157196045, 36.135232380458284, 35.059821469443186, 35.16223096847534, 35.268625259399414, 33.467346463884624, 33.67827640260969, 33.77505438668387, 34.49157346997942, 34.97174263000488, 38.54750796726772, 37.345639841897146, 33.6601277078901, 36.13951941898891, 36.98285354886736, 39.74096877234322, 44.7545873778207, 46.828113964625764, 48.438980851854595, 48.246588706970215, 37.31858008248465, 37.991565227508545, 53.153017452784944, 46.85655641555786, 51.17310047149658, 50.153077125549316, 47.868182863507954, 48.120979172842844, 50.29004349027361, 48.587828636169434, 49.39667190824236, 41.54159096309117, 37.28207424708775, 35.6271835735866, 34.84909997667585, 36.537821429116384, 39.050112860543386, 34.01087972096035, 39.201746872493196, 36.31936659131731, 37.910761151994976, 36.34922994886126, 35.61446837016514, 33.613606044224326, 35.072800704411094, 36.07568631853376, 36.64855487006051, 39.7871013368879, 43.90733446393694, 45.79650102342878, 50.212730884552, 43.53953504562378, 48.30965403148106, 49.491869177137104, 47.99442120960781, 46.357644489833284, 46.97154215403965, 45.91709395817348, 48.35644667489188, 44.69252954210554, 37.357927731105256, 36.74283845084054, 37.80143124716622, 39.59607103892735, 47.68788405827114, 51.16934149605887, 54.32028702327183, 53.17498070853097, 49.205836159842356, 53.26292405809675, 54.94022267205374, 50.22235066550118, 50.10772623334612, 54.19583783830915, 57.790394578661235, 55.15466839926583, 34.290523869650706, 10.948294758796692, 7.658452136175973, 5.2241703016417365, 4.405312069824763, 0.7644295724374908, 0.19744379738611834, 2.5331099714551653, 39.71882138933454, 54.857570375714985, 44.782324586595806, 40.235586711338584, 45.740342208317344, 59.671998023986816, 57.417005334581646, 26.68313925606864, 2.4875310914857045, 0.11010912087346826, 0.10930382194263594, 0.16172333913190023, 0.1789003988461835, 0.10998326619820935, 0.10525711373026882, 0.10258800123951264, 0.17603889453623975, 0.13806263304182462, 0.12420679868331977, 0.14099032165748732, 0.11071526299097709, 0.21284760082406656, 0.1375698944819825, 0.13909769750067166], [0.02283999084361962, 0.01773441516395126, 0.03314385383522936, 0.03673492917524917, 0.014531014021486044, 0.04449070657470396, 0.01598898900140609, 0.11106278148612805, 0.038205820069249184, 0.04858689695330603, 0.06308687478303909, 0.010263790409745914, 0.027093312969165187, 0.09542829649788992, 0.10156555753201246, 0.02955811856580632, 0.09193209053150245, 5.170226224831172, 31.720545019422257, 44.18006168093, 37.063643727983745, 24.908485957554408, 34.80914436067854, 42.75927318845476, 42.05930471420288, 26.52075638089861, 2.521481509719576, 0.03594006611300366, 0.35266078636050224, 4.200994644846235, 6.876455834933689, 6.303400116307395, 6.960269783224378, 15.84588279042925, 27.036316190447124, 45.95219278335571, 48.693253653390066, 45.814090388161794, 42.60714932850429, 40.12101786477225, 37.802046162741526, 34.745815004621235, 33.216738837105886, 32.1453127179827, 31.410283633640834, 32.61592810494559, 39.8903272492545, 44.541771003178184, 43.495334080287385, 43.17201355525425, 41.61475896835327, 39.56170872279576, 36.47425583430699, 32.53262962613787, 31.515962260110037, 30.525722367422922, 30.44113152367728, 32.205775942121235, 32.96045453207833, 35.69247579574585, 36.91438947405134, 35.526038646698, 30.884291103907994, 32.93718501499721, 34.24251529148647, 30.94956248147147, 33.80088778904506, 31.738429682595388, 32.217608724321636, 32.79355880192348, 31.856688022613525, 33.591250215257915, 32.05294336591448, 31.798472540719168, 31.98185634613037, 31.319158009120397, 31.076075281415665, 31.58284214564732, 34.05004324231829, 32.086322511945454, 32.73622574125017, 34.19716787338257, 35.105999197278706, 35.653993197849815, 39.522440978458945, 41.61741318021502, 42.36747121810913, 48.36288070678711, 39.36754478727068, 37.468025411878315, 47.15208414622715, 41.75295169012887, 42.08118806566511, 40.24308729171753, 41.87181452342442, 41.557273047310964, 43.58694955280849, 42.54532078334263, 40.66957466942923, 35.46997710636684, 32.58581461225237, 32.27107163837978, 32.300031730106895, 32.877975940704346, 33.95359182357788, 33.85344396318708, 33.36302621023995, 32.60526262010847, 33.34268535886492, 33.08587646484375, 32.8647153036935, 33.09745563779558, 32.50723743438721, 32.802400384630474, 31.689298970358713, 35.08876419067383, 39.44349554606846, 41.29145233971732, 43.7336642401559, 42.13818761280605, 45.14990861075265, 45.199539593287874, 45.14883858816964, 46.140384742191856, 43.248172760009766, 44.06098345347813, 45.42101342337472, 45.842192377362935, 45.49510553904942, 38.04666444233486, 33.32454013824463, 32.707012040274485, 35.50834853308541, 41.966963154929026, 45.85750273295811, 46.77907010487148, 47.40142372676304, 49.31469358716692, 52.01910618373326, 48.56118924277169, 49.41832249505179, 51.784152848379954, 53.99593121664864, 47.76055179323469, 24.223697560174124, 4.376684188842773, 5.566249660083225, 1.4570459297725131, 1.9205969529492515, 0.07439924098019089, 0.0221103231223034, 2.0790790660040717, 30.839805262429373, 47.834379877362935, 35.83015782492501, 23.62114804131644, 31.563064098358154, 46.727375507354736, 42.813059193747385, 15.98959585598537, 0.6066512359040124, 0.04406572312914899, 0.029002133756875992, 0.04923687243301954, 0.05581039755738207, 0.024430943420156837, 0.024810916245249764, 0.010115663670668644, 0.03639452172709363, 0.033485469075718095, 0.04317789737667356, 0.05030422158805387, 0.041463880600141625, 0.044433445004480224, 0.035260743993733606, 0.02970663970336318, 0.022862708196043968, 0.0512605284872864, 0.04728566695536886, 0.02620134984941355, 0.0264982988259622, 0.036086046136915684, 0.053522550500929356, 0.013661402693417455, 0.009240359433793595, 0.1018598788817014, 0.03485329728573561, 0.038763867624636204, 0.013461192454477506, 0.04611412535554596, 0.028620322101882527, 0.012970836400719625, 0.077516295148858, 6.763473783220563, 37.879195485796245, 48.83915540150234, 42.59715781893049, 25.81042640549796, 34.292837619781494, 50.483488287244526, 45.85593938827515, 30.57648938042777, 2.604377427271434, 0.009384425988953029, 0.27252628920333727, 3.365323292357581, 5.903598598071507, 4.5986522095544, 8.081790242876325, 12.10450713975089, 28.420692648206437, 48.33702645983015, 51.32262223107474, 48.01025268009731, 44.370928696223665, 41.934306621551514, 40.12516246523176, 37.91576385498047, 34.51235900606428, 34.211081641060964, 33.268190247671946, 33.66703421728951, 42.02073526382446, 46.56450278418404, 43.685454164232524, 44.34658568246024, 45.11542470114571, 40.80629089900425, 38.585337434496196, 33.61999143872942, 33.635009969983784, 32.33585316794259, 32.74994843346732, 33.17042909349714, 35.06439685821533, 36.84438289914812, 37.6926155090332, 36.73320129939488, 32.48891850880214, 34.45035675593785, 34.811885425022666, 32.32642446245466, 34.462113107953755, 32.74817316872733, 33.42173501423427, 33.754515511649, 33.52060440608433, 33.65859910420009, 32.477196897779194, 33.7862548828125, 33.57303898675101, 33.024791376931326, 32.42428636550903, 33.85116147994995, 35.944667611803325, 34.2108280318124, 34.51125771658761, 35.137373788016184, 35.18274552481515, 37.88581711905343, 40.6559944152832, 44.03962469100952, 43.233654499053955, 49.396897724696565, 40.19557898385184, 38.57791675840105, 49.07782254900251, 44.57223885399954, 45.52748761858259, 42.367030007498606, 43.200674874441965, 42.43331929615566, 45.50376646859305, 45.34811987195696, 44.207871845790315, 35.8843537739345, 33.87274258477347, 33.99959584644863, 34.38892773219517, 34.7428411756243, 36.06886318751744, 35.27637597492763, 35.42961502075195, 34.38213586807251, 34.72683947426932, 34.345077650887625, 34.60494375228882, 34.343423979622976, 34.58568334579468, 34.550504616328645, 34.74657235826765, 36.755855900900706, 41.894868646349224, 45.432776723589214, 45.40184334346226, 43.44157586778913, 44.76696211951119, 47.16670315606253, 45.553706645965576, 48.64079475402832, 45.31867340632847, 47.09673479625157, 48.26688092095511, 47.67698233468192, 45.54733167375837, 37.943237032209126, 34.9409099987575, 33.747351918901714, 38.23205280303955, 45.729565552302766, 48.93982785088675, 49.428633621760774, 47.92893443788801, 49.79022135053362, 52.48942974635533, 50.718000411987305, 51.169424874441965, 54.613195283072336, 54.87595878328596, 51.22267934254238, 27.002205746514456, 10.513844745499746, 10.956752453531537, 6.42130149262292, 2.6037136571747914, 0.45766633323260714, 0.042293074141655645, 1.9508138000965118, 35.7615304674421, 49.29227522441319, 38.369661876133506, 31.713749681200298, 38.48567942210606, 53.32732343673706, 49.77656119210379, 19.914489064897808, 1.0421874480588096, 0.03970031380387289, 0.06832299381494522, 0.021568740219143883, 0.09404835304511444, 0.006621372445286917, 0.05823139354054417, 0.02053490560501814, 0.019093475005190288, 0.02186761114613286, 0.06561263318040542, 0.026269298346181, 0.06398799642920494, 0.06373389185007129, 0.037947413578097305, 0.047815982784543715, 0.20566378773323127, 0.07860662628497396, 0.10364053797508989, 0.17057599553040095, 0.06710465704756123, 0.1074895007269723, 0.1331853097570794, 0.15194088619734558, 0.17413711015667233, 0.23430332594684192, 0.17577673574643476, 0.10200965870171785, 0.16552502156368323, 0.14742386500750268, 0.18496836109885148, 0.07624929384993655, 0.12263915208833558, 8.628049799374171, 45.89051709856306, 57.090471267700195, 49.06462444577898, 34.31660393306187, 42.664781161717, 50.97596270697457, 51.1920690536499, 34.56554399217878, 4.203505115849631, 0.12988734458174023, 0.8324559107422829, 7.981639776911054, 16.410807813916886, 12.856458561761038, 11.736341203962054, 19.173983063016617, 30.920890739985875, 48.97746276855469, 53.2029333114624, 50.50983238220215, 46.50278193610055, 44.630645411355154, 42.683899130140034, 39.85602399281093, 36.31559371948242, 35.20052249091012, 34.494408335004536, 36.6446465083531, 44.44150154931204, 47.41823489325387, 44.195806298937114, 45.073666027614046, 47.41701895850045, 44.44250556400844, 40.437911306108745, 35.9577510697501, 36.08989191055298, 33.36748695373535, 33.51287106105259, 34.715663296835764, 36.073792934417725, 38.23786497116089, 40.03168487548828, 38.73248291015625, 33.38018478666033, 36.23246547154018, 36.979247433798655, 33.803152901785715, 36.32950053896223, 35.624067306518555, 33.97068091801235, 34.54436935697283, 37.08867113930838, 34.829103061131065, 35.30884143284389, 35.578344685690745, 35.71324743543352, 33.50174004690987, 34.35156032017299, 36.20067746298653, 38.55592223576137, 35.91061101640974, 34.97967399869646, 37.558466638837544, 37.83136408669608, 39.81890671593802, 44.287869930267334, 45.15074239458357, 45.73940767560686, 50.58410862513951, 42.44235890252249, 42.08907079696655, 50.175849846431184, 47.03171007973807, 46.13643816539219, 44.1311011995588, 44.41891990389143, 45.85220125743321, 47.39575399671282, 47.24742037909371, 45.09682089941842, 37.494633538382395, 36.218103545052664, 36.1143912587847, 36.347503321511404, 35.99853352137974, 38.070208413260325, 37.76399782725743, 36.79035023280552, 35.40109266553606, 36.9080353464399, 35.00307553155081, 35.488657338278635, 36.02578783035278, 36.10229444503784, 37.14844649178641, 35.73220212118966, 38.951479707445415, 43.822906902858186, 47.340251786368235, 47.56728764942714, 44.73245736530849, 45.7974841935294, 46.76142168045044, 46.429985659463064, 50.550708634512766, 46.891266141619, 46.51767887387957, 50.687685421534944, 50.29961463383266, 49.34689153943743, 42.00792278562273, 36.77617938177926, 35.79185240609305, 40.681077412196565, 46.474714687892366, 51.80038036618914, 51.19657496043614, 49.39240224020821, 50.514470304761616, 57.90830203465053, 52.83974749701363, 54.045669896262034, 57.56913961683001, 58.08657891409737, 52.190170833042686, 26.960518292018346, 6.624502428940364, 9.525329743112836, 5.349294764654977, 6.643859241689954, 0.912836091859, 0.13478235048907145, 2.8171898935522353, 38.05762869971139, 59.081456729343955, 46.235929421016145, 35.78099584579468, 45.10078484671456, 59.58427701677595, 58.44992801121303, 25.88357182911464, 1.6699292893920625, 0.13500694558024406, 0.22884540738804, 0.0829088097172124, 0.19103533269039222, 0.05647737033931272, 0.11264535585152251, 0.1477797023419823, 0.11080800515732595, 0.13147449227316038, 0.1622214788304908, 0.17316637081759317, 0.15167367910700186, 0.09137337801179715, 0.19119280709752015, 0.18154923671058246], [0.03495254321023822, 0.04002849405099239, 0.05894560593047312, 0.03378225350752473, 0.009431842864224953, 0.049289676028170755, 0.03995096463976162, 0.037458478207034726, 0.038664889721465964, 0.014427472970315387, 0.06629253205444131, 0.01741992775350809, 0.021504450722464492, 0.049948764233184714, 0.07644286632005658, 0.06828217993357352, 0.033414005767554045, 3.602030396461487, 27.935039622443064, 45.03812599182129, 44.69879681723458, 34.49860157285418, 16.277138369424, 20.22625994682312, 33.63796990258353, 32.2416147504534, 4.9602659940719604, 0.08513429601277624, 0.18088106970701898, 2.379916957446507, 4.525938442775181, 1.9998743789536613, 5.993295064994267, 11.704458526202611, 31.564068113054546, 41.635600090026855, 48.49973242623465, 48.401620388031006, 44.03249931335449, 42.15109041758946, 40.77339812687465, 38.38887711933681, 35.28062827246529, 32.83294813973563, 30.616549219403947, 35.21035419191633, 44.71185943058559, 45.236576965876985, 42.58186135973249, 44.19362803867885, 43.267971651894705, 39.257801464625764, 36.069769927433555, 32.057226930345806, 31.66752679007394, 32.86858892440796, 31.899436814444407, 30.621836798531668, 31.851793016706193, 31.453887053898402, 31.630152429853165, 32.0282564163208, 31.368358203342982, 31.481315067836217, 32.0219544001988, 32.285888671875, 32.926630701337544, 34.35073001044137, 30.94603279658726, 33.207879883902415, 32.17172976902553, 32.251644475119456, 32.80901854378836, 31.52904224395752, 31.35909972872053, 32.13922957011631, 31.361423901149205, 33.04783507755825, 31.357883793967112, 34.76437016895839, 33.66226775305611, 34.90295546395438, 34.443238326481406, 35.04273584910801, 38.8597217968532, 41.922286237989155, 41.04109137398856, 45.09221076965332, 41.41586678368704, 38.171659060886924, 47.06844520568848, 41.60294008255005, 41.673339230673655, 35.171631881168906, 37.32290186200823, 36.21664094924927, 38.38382577896118, 35.23306785311018, 33.738152503967285, 33.40066112790789, 32.84236294882638, 33.56395421709333, 32.990637506757466, 32.32323523930141, 32.35000317437308, 33.65724420547485, 33.51637642724173, 31.74536051068987, 33.25778532028198, 32.485927309308735, 33.72944293703352, 34.83381741387503, 32.57258176803589, 33.81202575138637, 32.74545642307827, 35.649244104112896, 42.33510998317173, 43.34966162272862, 46.47488144465855, 41.274592535836355, 42.56750290734427, 43.245341369083945, 42.89420025689261, 44.43158994402204, 44.7952412877764, 45.8699608530317, 46.55580711364746, 45.46563128062657, 45.78936522347586, 46.170373167310444, 38.48453991753714, 32.18998963492257, 34.70001595360892, 38.21682235172817, 44.04573563167027, 46.191339356558665, 47.451704365866526, 48.65600436074393, 51.166395459856304, 51.666929789951865, 51.788262707846506, 52.18790919440133, 56.24862057822091, 47.069883482796804, 18.40492865017482, 8.2201167174748, 14.510894996779305, 5.004665851593018, 0.866091325879097, 0.22856509100113595, 0.005301056105443942, 2.0996229350566864, 26.31300003187997, 50.88739749363491, 43.53921890258789, 23.519145011901855, 31.80471202305385, 44.84478194372994, 43.30053785869053, 19.085890327181133, 1.157511042697089, 0.05970401809151683, 0.01779870974964329, 0.05758642564926829, 0.0250232061038592, 0.012182090331667235, 0.060742387015904696, 0.06648875759648425, 0.06338380849254982, 0.06803146124418293, 0.01380243110803089, 0.04902512200974992, 0.004070269916805306, 0.03147192658590419, 0.052951478465859375, 0.06314497095133577, 0.0238761664035597, 0.03477766098720687, 0.09441143713359322, 0.08770562482199498, 0.025835616081686955, 0.03623825850497399, 0.055271352375192304, 0.04914116506863918, 0.03339270316064358, 0.04822757873418076, 0.023526851486946856, 0.02627000741527549, 0.05949452040450914, 0.031047692921544825, 0.02095263551122376, 0.03145887157214539, 0.04098223948052951, 5.1355703473091125, 34.53547913687569, 51.206622055598665, 48.23108032771519, 39.43717268535069, 21.921684673854283, 29.433413437434606, 42.40018681117466, 34.32225629261562, 5.145381203719547, 0.04035198222845793, 0.11006840877234936, 1.5295186809131076, 9.115223612104144, 5.7585762313434055, 3.924643508025578, 10.625435420445033, 32.021415914808, 43.07617705208914, 50.31354924610683, 50.41787992204939, 45.50912700380598, 45.139395986284526, 42.11833660943167, 39.184442383902415, 37.0320120538984, 35.77211952209473, 32.318572998046875, 36.80530623027256, 46.837351594652446, 47.41186339514596, 42.8936687197004, 45.46764625821795, 45.22029038837978, 40.350179876599995, 38.38356522151402, 35.616135937826975, 33.43479067938668, 33.69209289550781, 33.505300998687744, 31.34000607899257, 32.71607249123709, 33.598882811410085, 33.09997088568551, 33.78535509109497, 32.601236139025005, 32.729531151907786, 32.72591461454119, 33.416266781943186, 33.75810425622122, 36.109346866607666, 31.9510132925851, 34.311729771750315, 33.812929017203196, 33.1550874710083, 34.20139932632446, 33.14401204245431, 32.62936244692121, 33.7707326071603, 32.34972524642944, 34.16038758414132, 33.85937425068447, 36.276982579912456, 35.87342425755092, 36.80376720428467, 36.01720333099365, 37.38467829568045, 42.29650926589966, 44.36877128056118, 42.611842836652485, 47.74480022702898, 43.95814316613333, 39.24457904270717, 49.44668504170009, 43.79786559513637, 44.67433568409511, 37.493681635175435, 38.97925860541207, 39.47730895451137, 40.4852910723005, 37.32429844992501, 35.99526786804199, 35.74309689658028, 34.184105260031565, 35.15555027553013, 33.66178832735334, 34.03096696308681, 34.37146690913609, 35.7237218448094, 35.98208018711635, 33.960918698992046, 34.71865797042847, 34.25534166608538, 34.65434544427054, 36.61560651234218, 33.87188100814819, 34.40651362282889, 34.30277006966727, 38.378503458840505, 44.21425029209682, 46.597089835575645, 46.99549954278128, 43.08156190599714, 42.970866680145264, 43.26823915754046, 42.775782108306885, 44.3034999029977, 46.21917731421334, 48.236590249197825, 48.164085796901155, 47.615730490003315, 47.7299484525408, 47.093423979622976, 39.7665833064488, 33.90995018822806, 36.58887331826346, 39.880877699170796, 47.01366213389805, 49.26904739652361, 48.04431274959019, 49.46389920370919, 53.82772922515869, 51.669469356536865, 52.60426957266671, 54.4425961630685, 57.97181551797049, 49.03430598122733, 24.296492099761963, 9.892048716545105, 9.218267134257726, 4.9708850128310065, 1.848710673195975, 0.20969870979232447, 0.05498636427468487, 2.1857122012547086, 30.044597830091202, 55.474709374564036, 44.02984162739345, 26.05098693711417, 37.37835543496268, 51.72592347008841, 51.1416459764753, 22.927316563470022, 1.4596627950668335, 0.03056185845551746, 0.012446920004939395, 0.05975686239876917, 0.01691055321134627, 0.06113835291138717, 0.012044683597715837, 0.030760852420436482, 0.03106458844350917, 0.04953611655426877, 0.04752810073218175, 0.020419620809012225, 0.07006805696125541, 0.041482007663164816, 0.020541373740083406, 0.019625437978122915, 0.13283841551414557, 0.18276069313287735, 0.17578335824821675, 0.18343696184456348, 0.11188184110713856, 0.16456777150077478, 0.10817180161497422, 0.1396876158458846, 0.17968504317104816, 0.2167871615716389, 0.2236763411866767, 0.06401965008782488, 0.14477457930999144, 0.13151641216661247, 0.12413709956620421, 0.13888247976345675, 0.1191142305199589, 5.8399244376591275, 38.26166255133492, 58.32549967084612, 55.039568015507285, 43.80915641784668, 24.44719157900129, 29.17490918295724, 44.5024858883449, 41.16165999003819, 6.2549768175397595, 0.25733361872179167, 0.5378976709076336, 6.431685141154698, 11.818910990442548, 8.079056995255606, 10.762174231665474, 13.680827583585467, 33.88009377888271, 44.87027488436018, 51.061488083430696, 51.96428142275129, 47.96534647260393, 46.947602135794504, 44.74400527136666, 41.37729038511004, 39.7904052053179, 36.687958104269846, 34.439712115696494, 39.9465868132455, 49.09168420519148, 48.69483436856951, 43.286210673195974, 45.07206446783883, 48.13955865587507, 43.31700161525181, 40.23290818078177, 36.171439443315776, 34.051377296447754, 36.40450634275164, 35.73406423841204, 33.28241321018764, 35.1584928376334, 35.027713843754356, 34.90353911263602, 35.60037047522408, 35.464321272713796, 35.32309218815395, 34.33375556128365, 35.88289812632969, 36.24550029209682, 38.00997447967529, 32.65898609161377, 36.3486567224775, 35.851610388074604, 35.80030141557966, 36.21120398385184, 35.30138601575579, 34.8325319971357, 35.20897497449602, 34.82325267791748, 36.07422719682966, 35.80124289648873, 39.022799491882324, 38.248287269047324, 38.52232422147478, 38.51338883808681, 39.1497917175293, 43.45779643739973, 46.51812008449009, 44.88425465992519, 49.052819456372944, 44.71229369299752, 42.592255864824565, 50.744625908987864, 45.11396557944161, 45.81700168337141, 37.815765380859375, 40.23971741540091, 39.50763784136091, 42.5748610496521, 39.04321329934256, 37.51800380434309, 38.20285299846104, 35.07694183077131, 38.3645966393607, 35.42559896196638, 35.260881492069785, 35.61522224971226, 38.011398860386436, 37.925724097660606, 35.14983885628836, 36.19510153361729, 36.60940177100045, 36.86846188136509, 38.48345947265625, 36.22152900695801, 37.35983848571777, 35.47359364373343, 40.19108002526419, 46.60938119888306, 48.32110813685826, 50.3360926764352, 44.39693580354963, 44.18950080871582, 44.31227200371878, 43.67990255355835, 46.79448468344552, 47.90787097385952, 50.720442703792024, 50.98736470086234, 49.27794109072004, 49.10649429048811, 50.51013462884085, 43.670543330056326, 35.93787922177996, 39.13542979104178, 41.55920812061855, 48.94829075677054, 51.29815067563738, 49.52670744487217, 51.39530733653477, 54.19628947121756, 54.1375389780317, 55.990943159375874, 58.751055989946636, 58.498113768441335, 52.040388516017366, 22.270623207092285, 11.071323037147522, 23.49892054285322, 11.451111572129385, 2.9509183977331435, 0.6130371732371194, 0.1278461076851402, 3.3000638570104326, 34.37780366625105, 62.63506426130022, 54.60506589072091, 34.98567376817976, 44.44949892589024, 60.276623317173545, 57.67189652579171, 28.260705164500646, 2.0023620511804308, 0.09788506823991026, 0.17488178876893862, 0.1166669311267989, 0.12260142554129873, 0.1528177298605442, 0.20374068378337792, 0.1734079835670335, 0.10691216242100511, 0.16496630225862774, 0.10651341453194618, 0.13045453200382845, 0.1113163839493479, 0.1059827119378107, 0.09963765633957726, 0.08446210529655218], [0.044588269732360325, 0.032143292882080586, 0.024609309920508946, 0.030579116993716786, 0.04121597104572824, 0.007984343616824065, 0.010948115876609725, 0.04613693770287292, 0.04178794213969793, 0.017226684372872114, 0.015496197855100036, 0.035407202384833775, 0.06509750975029809, 0.03451055906979101, 0.01550133097251611, 0.04877406405285001, 0.06659915524401835, 1.4245413882391793, 20.888214826583862, 42.61667878287179, 45.82138252258301, 32.577209268297466, 19.487419775554113, 29.43742949622018, 33.81735849380493, 39.127731187003, 8.11595366682325, 0.04838360446904387, 0.048348198511770794, 1.3483207353523798, 4.331372380256653, 2.7962755986622403, 4.724277377128601, 9.387327228273664, 30.232633454459055, 46.248182569231304, 44.64118930271694, 47.69489826474871, 44.845643520355225, 45.11239876065935, 42.05345433098929, 41.044040884290425, 37.32733481270926, 33.51675162996565, 31.885116577148438, 37.06847620010376, 45.715585776737754, 46.01243366513933, 43.27116782324654, 42.29723882675171, 43.62935788290841, 41.05081537791661, 38.8154478754316, 35.52677862984793, 30.611094883510045, 31.199117456163677, 31.733461720602854, 31.89776577268328, 29.929379326956614, 31.596394606998988, 32.773784228733604, 31.86280243737357, 31.017731257847377, 31.165901592799596, 32.62528038024902, 33.22339173725673, 32.91093472072056, 34.14387171609061, 31.72844512122018, 31.69725465774536, 32.91061510358538, 32.14830044337681, 33.249228613717214, 31.87120975766863, 31.029491083962576, 32.662446294512065, 31.571763242994034, 32.35173327582223, 32.97520555768694, 35.25150837217058, 34.34759637287685, 35.44869129998343, 34.60560730525425, 37.829081603458945, 38.81238719395229, 41.99820572989327, 43.04519503457205, 45.86553485052926, 38.40767547062465, 37.64565263475691, 45.630136830466135, 39.926600319998606, 37.72918735231672, 32.97038003376552, 33.67999608176095, 31.24218586512974, 32.74109295436314, 30.71574170248849, 32.71190357208252, 33.06261737006051, 35.67919084003994, 32.53227874210903, 34.37965188707624, 33.07821607589722, 34.85109063557216, 33.902668476104736, 34.19295031683785, 35.172806126730784, 33.76534080505371, 34.12269013268607, 31.44905458177839, 32.81616824013846, 31.97277852467128, 32.70417717524937, 32.306087085178916, 36.541886125292095, 40.94962181363787, 43.89519943509783, 43.35026264190674, 41.11825111934117, 45.87615169797625, 48.40625136239188, 45.181585448128835, 47.1412136895316, 44.436745507376536, 43.57046495165144, 44.34539059230259, 46.46794714246477, 47.64700780596052, 45.99614013944353, 45.918226514543804, 38.00362035206386, 32.64121954781668, 33.82796491895403, 40.035110337393625, 47.291843686785015, 47.27286120823452, 50.7801068850926, 46.9130209514073, 50.19698626654488, 51.4787517275129, 53.81948518753052, 53.34853628703526, 36.12447656903948, 16.210691009249004, 11.564031958580017, 8.905811854771205, 9.875934975487844, 2.3652458361216953, 0.08738847076892853, 0.177642164219703, 1.872477637869971, 31.021424225398473, 46.2487974848066, 44.74470703942435, 33.403384821755544, 31.067275387900217, 43.22450372150966, 42.08793824059622, 19.1804518359048, 0.7495265549847058, 0.04205788711884192, 0.015219207986124923, 0.07221211905458144, 0.057005640385406356, 0.023388004562418376, 0.04189457391787853, 0.10467875083642346, 0.0871762725125466, 0.010861227771134248, 0.02686818522800292, 0.06561276888740913, 0.041717720550618, 0.03215391534779753, 0.05424431498561587, 0.04381391199837838, 0.03919643369902458, 0.03560018113681248, 0.11877997059907232, 0.04054238594004086, 0.010734313733077474, 0.028989197486745458, 0.05748886588428702, 0.057146436401775906, 0.08323834703436919, 0.04829916078597307, 0.00790674380758511, 0.035426174223955186, 0.06655361875891685, 0.03783972328528762, 0.046306534138109, 0.030123382341116667, 0.024738543700160723, 2.084634150777544, 25.31695144517081, 48.73572104317801, 51.67426708766392, 36.06693853650774, 19.62881909097944, 31.013058594294957, 39.11179549353463, 43.153458390917095, 8.541582942008972, 0.11903002432414464, 0.0673384191468358, 1.318060679095132, 5.1526385971478055, 6.68598964384624, 4.231208886419024, 7.792995316641671, 30.914734636034282, 47.1725709097726, 44.5248521396092, 48.72875199999128, 46.74773720332554, 46.49600396837507, 44.440157072884695, 43.15408372879028, 38.93374443054199, 34.79053013665335, 32.93172720500401, 39.840102195739746, 47.48316928318569, 46.19366700308663, 42.133577483040945, 43.00276585987636, 45.911076818193706, 43.87609536307198, 40.06042609895979, 38.926716327667236, 33.03786441258022, 33.40140805925642, 32.88765825544085, 33.939438343048096, 31.345029626573833, 32.526358876909526, 33.00082703999111, 33.314065728868755, 32.61989205224173, 33.698429652622764, 33.23884800502232, 33.781200068337576, 34.47762496130807, 36.10749864578247, 32.490565231868196, 33.651859351566856, 33.342817374638145, 33.755568163735525, 33.54056658063616, 32.82503761563982, 32.181085518428254, 34.75823490960257, 34.43282992499215, 35.30260195050921, 34.06696210588728, 36.77593272072928, 36.732735770089285, 37.99120739528111, 35.81926652363369, 39.2477057320731, 40.293763978140696, 43.879854338509695, 42.773259912218364, 47.85027040754046, 40.43980816432408, 39.81762824739729, 47.68741158076695, 40.72193281991141, 40.502765791756765, 34.8987900188991, 36.17256852558681, 31.820863110678538, 34.047055516924175, 31.26308604649135, 33.891040665762766, 34.808960233415874, 37.53192799431937, 34.9011732510158, 35.440697397504536, 34.334488596235005, 36.169459206717356, 34.786802428109304, 36.53407635007586, 36.31196675981794, 34.634122712271555, 34.64216872623989, 32.62449523380825, 35.35921934672764, 34.16095733642578, 33.61611434391567, 34.0892345564706, 37.27698816571917, 42.960913385663716, 45.608930928366526, 46.054289613451274, 42.63944108145577, 45.79124471119472, 46.69822086606707, 47.83031865528652, 48.220126492636545, 47.846469742911204, 45.73277562005179, 46.67123058864048, 47.27219418116978, 48.68195240838187, 48.78309733527047, 47.65712090900966, 38.67617470877511, 35.354300022125244, 35.16210242680141, 43.29786280223301, 48.42702300207955, 50.90020997183663, 50.44419622421265, 49.64261381966727, 52.920964990343364, 54.26201248168945, 54.29600306919643, 56.365214824676514, 38.39159386498587, 20.52822518348694, 10.25401599066598, 6.808749548026493, 8.583468420164925, 3.1148537610258376, 0.0982260253014309, 0.04538260353729129, 2.4318100128855025, 32.424268995012554, 54.41313580104283, 51.24216556549072, 38.73938594545637, 37.96094104221889, 50.52756071090698, 47.84291226523263, 23.177338804517472, 1.1275617011955805, 0.07085312876318182, 0.010449415538460016, 0.0598097134913717, 0.02571703360549041, 0.008410323660687676, 0.01992926899609821, 0.052586630186332126, 0.0706340976591621, 0.06184356114161866, 0.012281663649316345, 0.013253533597370344, 0.006948302491634552, 0.02676612338317292, 0.12164128491921083, 0.035526295458631854, 0.12341010357652392, 0.08536362049302884, 0.17042538789766176, 0.07492499026869025, 0.10210393435720887, 0.08518897236457892, 0.1813606582581997, 0.10281327486570392, 0.16675749900085585, 0.19772621723158018, 0.07724723565791335, 0.20844529276447638, 0.11639776985560145, 0.09889099640505654, 0.2215747825269188, 0.2235188124967473, 0.09364453649946622, 2.5345308780670166, 29.540756157466344, 54.62843268258231, 57.7064916065761, 43.8210517338344, 29.743400369371685, 38.75011396408081, 42.99081148420061, 49.162041664123535, 10.753009557723999, 0.30788971590144293, 0.30403636981334003, 4.133427321910858, 10.756689497402736, 9.051430463790894, 8.148437363760811, 10.889641540391104, 31.9511661529541, 46.884154660361155, 46.66884388242449, 49.769953455243794, 48.618220056806294, 48.767797401973176, 47.07889877046858, 45.55587100982666, 40.786245346069336, 36.73985767364502, 35.33914600099836, 41.77957371303013, 49.38804919379098, 47.9569982119969, 43.80496665409633, 43.97167130878994, 47.36303145544869, 45.71093395778111, 43.85190520967756, 41.257760524749756, 34.01950938361031, 35.31225994655064, 34.997298104422434, 35.61279385430472, 33.56300578798567, 34.95378501074654, 35.618269034794395, 35.24881941931588, 34.48665067127773, 34.360780579703196, 35.957049301692415, 35.5344911302839, 37.13860436848232, 36.264573097229004, 34.93738726207188, 35.07633038929531, 36.036071164267405, 34.968675000326975, 36.013743128095356, 35.72385386058262, 33.80271169117519, 36.96949216297695, 34.77697767530169, 37.19821296419416, 36.24867214475359, 40.19156639916556, 39.33277252742222, 39.93495205470494, 36.46516759055001, 42.411946637289866, 40.980961663382395, 46.683066844940186, 46.51792900902884, 50.974423680986675, 41.84433092389788, 43.19433811732701, 49.35686220441546, 42.23328413282122, 41.79663154057094, 37.0126439503261, 38.19537673677717, 33.83610820770264, 36.26524707249233, 32.91777522223336, 35.7049686568124, 36.240306513650076, 39.32454586029053, 36.06384311403547, 37.33699975694929, 36.25803484235491, 38.105908257620676, 37.85702378409249, 38.24780784334455, 37.48208161762783, 37.10561779567173, 37.300302846091135, 34.08320699419294, 36.60609095437186, 36.514051641736714, 35.770504065922324, 36.27198682512556, 39.05286087308611, 46.866891860961914, 47.322971616472515, 48.76287112917219, 46.15287412915911, 45.871055194309776, 51.32186835152762, 47.702280725751606, 52.16947562353951, 49.488283906664165, 48.454100131988525, 49.22054897035871, 49.5245361328125, 49.42883859361921, 48.694306305476594, 50.122494629451204, 43.07258830751692, 36.824260916028706, 37.59325974328177, 44.32008177893502, 51.615961279187886, 53.613933154514854, 54.0453085899353, 50.35522106715611, 56.31800528935024, 54.14039121355329, 56.843820640019004, 56.36256756101336, 38.33856521333967, 17.645718097686768, 16.93863640512739, 20.28267237118312, 22.023107528686523, 8.12941667011806, 0.23218640525426182, 0.34168496674724985, 2.4954351016453336, 39.65292467389788, 57.46494790485927, 56.228998865400044, 43.67972537449428, 42.55547904968262, 57.58709028788975, 57.29197250093733, 28.023778540747507, 1.5918702951499393, 0.18310466967523098, 0.12274580422256674, 0.1409838077213083, 0.1261404470673629, 0.08597895676004035, 0.12869385576673917, 0.16275672082390102, 0.22062999036695274, 0.13227348082831927, 0.10160915340696063, 0.12368036407445158, 0.10051637954477753, 0.0929996364616922, 0.23601111716457776, 0.10000050294079951], [0.041545878164470196, 0.014140152405681354, 0.05445840974737491, 0.03180349611544183, 0.03906007869435208, 0.004664901111807142, 0.02168968738988042, 0.0867069298401475, 0.026765643319647228, 0.03689792685742889, 0.034857483846800666, 0.047345449283186875, 0.03458194434642792, 0.033012655696698597, 0.058706591970154216, 0.04017351734052811, 0.056076261148388894, 0.682416673217501, 17.76877416883196, 41.374288763318745, 42.62245273590088, 38.05778503417969, 18.603937217167445, 26.069121735436575, 33.42348248617989, 38.96146774291992, 14.931195872170584, 0.12922540652964795, 0.04028007108718157, 0.3979561472577708, 7.735484208379473, 6.504332900047302, 1.4394569993019104, 5.399074264935084, 22.725744111197336, 42.1067087990897, 46.1646409034729, 44.6334524835859, 47.64912005833217, 45.1500996862139, 45.5675231388637, 42.27814517702375, 41.14115238189697, 34.796585491725374, 31.784478868756974, 34.91451726640974, 40.04517132895333, 42.629765714917866, 44.6276854787554, 41.698738370622905, 41.53847122192383, 41.28351749692644, 41.68431738444737, 38.91572775159563, 35.001192569732666, 32.452930314200266, 30.7259555544172, 32.174123423440115, 31.782974583762034, 31.65993240901402, 31.30337517602103, 31.24902289254325, 33.09715339115688, 31.605896268572124, 31.882643018450054, 33.753431592668804, 32.30204323359898, 32.208371094294954, 33.487808908735005, 33.24734565189907, 31.600841454097203, 31.438576698303223, 30.74948910304478, 30.85375029700143, 32.252638067517964, 31.718769754682267, 31.638292244502477, 32.16865866524832, 34.58311251231602, 35.43452044895717, 36.06790781021118, 36.702507632119314, 38.93049267360142, 41.666898250579834, 42.686073916299, 41.83961309705462, 43.40197808401925, 44.469294343675884, 37.05400310243879, 41.33997161047799, 44.84253420148577, 40.54586546761649, 39.927010263715474, 33.63625022343227, 32.48556252888271, 33.281138215746196, 32.51054130281721, 31.948015144893102, 33.11806746891567, 34.75836345127651, 34.189274719783235, 32.631919384002686, 33.21952853884016, 31.559079306466238, 33.51841572352818, 33.22828326906477, 34.85510669435774, 35.96446997778756, 33.92813014984131, 33.818664755140034, 33.504161494118826, 32.47771801267351, 32.55814341136387, 31.769251891544886, 31.884703159332275, 36.23561300550188, 41.28088412966047, 43.697460651397705, 44.82008457183838, 44.214184284210205, 47.17183092662266, 42.80693783078875, 41.229443141392295, 41.1213812828064, 41.87539979389736, 38.95677770887102, 40.55311243874686, 42.42348412105015, 44.95374359403338, 46.75990349905831, 48.13896458489554, 44.903379576546804, 36.28326375143868, 32.91466590336391, 36.82268020084926, 39.524181502205984, 45.96598495755877, 47.17686142240252, 50.33189943858555, 48.04582745688302, 49.87097678865705, 49.724633829934255, 48.14243868419102, 30.17260101863316, 15.223522220339094, 4.508400755269187, 3.890891330582755, 2.1147202849388123, 2.0127993311200822, 0.018620091656755124, 0.03809293219819665, 2.354440084525517, 28.963682208742412, 51.425417355128694, 36.79678079060146, 27.598050253731863, 33.45069858006069, 45.27869694573538, 40.99913467679705, 18.018070323126658, 0.8100342910204614, 0.07731622909860951, 0.07329686584749392, 0.045503786498946805, 0.057106077138866694, 0.02421970189815121, 0.056721602233925035, 0.03299079669107284, 0.015209813668791736, 0.03066849701904825, 0.08136397546955518, 0.042947558486568074, 0.038875123618968895, 0.02625921701214143, 0.05262594450531261, 0.08378393668681383, 0.024401450895571282, 0.005820341075637511, 0.02760486730507442, 0.0680615949843611, 0.03154597511248929, 0.02703720999748579, 0.04213172869224634, 0.04642746264913252, 0.036236959110413275, 0.038721907019082985, 0.0729440479938473, 0.05404908349737525, 0.029598596572343792, 0.10572357262883868, 0.021287316123821905, 0.026832414558157325, 0.07577826841069119, 0.9367415862424033, 21.40550126348223, 48.28708628245762, 48.984449182237896, 43.58179746355329, 24.696595430374146, 29.483162539345876, 40.98770489011492, 45.0045279775347, 15.202517815998622, 0.3683306840913636, 0.008368871956398445, 0.5622357449361256, 4.9617681077548434, 6.714467704296112, 4.233965149947575, 6.825561583042145, 25.358708381652832, 42.75229719706944, 47.2040045601981, 46.58795642852783, 49.655919619968955, 46.732749938964844, 47.972447531563894, 45.06025947843279, 42.90197876521519, 35.33299684524536, 32.453750201633994, 37.511079924447195, 43.09299864087786, 44.33899824959891, 45.96367120742798, 43.497356006077354, 43.449079922267366, 42.77889837537493, 43.42380237579346, 40.30160502025059, 35.758045945848735, 32.754277161189485, 32.65798207691738, 33.49140460150582, 32.97703293391636, 32.67704445975167, 32.48156384059361, 33.14184767859322, 33.77766343525478, 33.050353799547466, 32.877305439540315, 34.24111870356968, 33.853909492492676, 34.176146098545615, 34.70700931549072, 34.19704280580793, 33.57244838987078, 31.895948818751744, 32.09068250656128, 32.13176025663103, 33.471491064344136, 33.80356979370117, 32.90208966391427, 32.55321019036429, 36.839908259255544, 36.37016487121582, 38.03968150275094, 39.14233977454049, 40.806961400168284, 43.6508868762425, 43.89773205348423, 44.51258162089756, 46.13525349753243, 46.508687904902864, 39.374503408159526, 42.88458742414202, 47.46576057161604, 42.307636805943076, 41.29860551016671, 34.744911738804404, 33.54696587153843, 34.7909574508667, 33.95363698686872, 33.60714421953474, 33.963826520102366, 35.449886390141074, 34.94896990912301, 34.6242493220738, 34.051009041922434, 34.027048179081504, 34.87959909439087, 35.87245845794678, 36.260560512542725, 36.46062694277082, 34.7433032308306, 35.1579578263419, 34.023775577545166, 34.97707537242344, 34.14106116976057, 34.43904856273106, 33.550071716308594, 37.68842921938215, 44.15722295216152, 45.58543906893049, 46.87135260445731, 46.74794912338257, 49.46105391638619, 46.36385270527431, 44.70172895703997, 45.05932147162301, 42.684962204524446, 42.15838950020926, 43.23713207244873, 45.00011239733015, 46.926781858716694, 48.099113191877095, 49.65581887108939, 46.41875737054007, 37.04033946990967, 35.05667046138218, 38.19653013774327, 43.17084625789097, 47.37777553285871, 50.33638450077602, 51.76387105669294, 49.875256878989084, 50.55636099406651, 50.510978834969656, 48.77866438456944, 32.663672651563374, 17.883584465299332, 10.411751389503479, 8.347254855292183, 3.7150719421250478, 2.4497765345232825, 0.20643106156161853, 0.05823608221752303, 2.834465503692627, 33.65110894611904, 52.42886924743652, 42.541593074798584, 30.664311136518204, 37.112093516758506, 52.219763210841585, 48.91263607570103, 23.556607961654663, 0.9163469948938915, 0.07077479868062905, 0.04706318210810423, 0.0908786513443504, 0.04528822270887239, 0.025044695307899798, 0.0696417334090386, 0.056266973593405316, 0.0709091621850218, 0.03504533626671348, 0.03561027095253978, 0.04524256408746753, 0.09688273631036282, 0.03263078636622854, 0.038362629512058835, 0.08960316157234566, 0.12684080377221107, 0.09219096521181719, 0.2469857425561973, 0.205384190593447, 0.06426386841173683, 0.10927413603557007, 0.05468782243717994, 0.20660198453281606, 0.14855947478541306, 0.126028855198196, 0.12965428137353488, 0.09732428618839808, 0.09745181005980287, 0.16258453577756882, 0.14533825192068303, 0.10761125026536839, 0.1767408118716308, 1.1276310746158873, 24.407758814947947, 54.294651644570486, 55.38158614294869, 49.26907171521868, 29.243585177830287, 34.657916818346294, 44.842805181230815, 49.01791518075125, 18.828963313783916, 0.4059091476457459, 0.21020843886903354, 1.4234340190887451, 13.900747622762408, 13.598069327218191, 3.307123443910054, 7.266775233404977, 25.1515600000109, 43.384517260960166, 47.055632727486746, 47.69137552806309, 49.04340464728219, 49.16130862917219, 50.25833191190447, 46.443364415849956, 45.58203445162092, 38.57858031136649, 33.6585921560015, 40.276372637067524, 44.76594073431832, 47.164948735918315, 48.39586727959769, 44.372464248112266, 44.06512805393764, 45.46943889345442, 46.749033042362754, 42.59297152927944, 38.68880305971418, 35.73421362468174, 34.97550160544259, 35.624925409044536, 34.8867244720459, 35.42329216003418, 34.439173630305696, 34.550438608442036, 36.25916739872524, 34.44249486923218, 35.100072383880615, 35.7948887688773, 35.34617757797241, 35.8348513330732, 36.3592666217259, 36.91287129265921, 35.011566230228965, 33.83401679992676, 34.32736669267927, 33.57492194856916, 34.6237907409668, 36.40371772221157, 35.327605043138774, 36.373110907418386, 38.66038840157645, 38.39226089205061, 40.617122718266074, 39.88457414082119, 43.45992953436715, 45.00046328135899, 46.248637676239014, 46.45593023300171, 47.3724810055324, 47.138861724308555, 39.345466886247905, 45.61266558510916, 47.612384932381765, 44.31486715589251, 43.984435149601524, 37.37746606554304, 35.43649026325771, 36.641967977796284, 35.7143417767116, 35.63911363056728, 36.27583612714495, 38.50007956368582, 36.480592591421946, 35.48912634168352, 36.80050849914551, 33.91871534075056, 36.15703930173601, 37.06422390256609, 38.84148972375052, 39.41135317938668, 37.06518622807094, 36.89908259255545, 36.82214171545846, 36.061984470912385, 35.87295178004673, 35.84750052860805, 35.77107381820679, 39.83050325938633, 46.12578310285296, 47.638326031821116, 50.32484701701573, 48.24307986668178, 50.599457195826936, 48.490029266902376, 45.71368891852242, 45.6665940284729, 46.42006015777588, 44.04352957861764, 44.78281096049717, 48.129195417676655, 48.45899861199515, 49.30081456048148, 52.3514906338283, 48.05270964758736, 39.990725244794575, 37.343075956617085, 40.38386474336897, 45.06668308803013, 50.25473621913365, 53.51066207885742, 54.86566502707345, 51.89054366520473, 52.98540258407593, 50.94022464752197, 48.873323168073384, 33.9616482598441, 18.395531211580547, 9.852011459214346, 8.899032149996076, 7.5101845264434814, 3.710494816303253, 0.47211880343300955, 0.13597900127725943, 3.1827869500432695, 36.89335380281721, 61.51932947976248, 45.63132149832589, 37.06505421229771, 45.162609917776926, 58.954443659101216, 57.70505680356707, 29.739686557224818, 1.3392999108348573, 0.2404182292521, 0.17759941651352815, 0.13210816255637578, 0.20288544467517308, 0.047081750218889544, 0.17695645030055726, 0.10448245744087867, 0.1066667295194098, 0.12603682119931492, 0.18255425563880376, 0.11135368301932301, 0.20558448056025164, 0.10202482395938464, 0.18279328995517322, 0.12995887574340614], [0.019689086259209683, 0.03196608328393527, 0.01334907641700868, 0.0075525468315130895, 0.021217013110539744, 0.06251719713743244, 0.02305153601004609, 0.007856100498299514, 0.06299543540392603, 0.05452468565532139, 0.025611082058666006, 0.03318707651591726, 0.0029840733914170414, 0.0468570635254894, 0.07802628885422434, 0.0511207095613437, 0.012297502352989145, 0.2753456564886229, 8.480979885373797, 37.50683110100882, 45.1990601675851, 40.94834681919643, 29.871434824807302, 35.741537025996614, 34.86388226917812, 45.392088072640554, 21.42780498095921, 0.7117338914956365, 0.012695779508378888, 0.4436700556959425, 1.5670729343380247, 8.374305060931615, 6.177014555249896, 1.9998791558401925, 21.893237011773245, 39.09763159070696, 48.37958417619978, 45.174477440970286, 46.38606609616961, 45.34807470866612, 45.67784663609096, 42.830259459359304, 42.161599567958284, 32.71882745197841, 31.32910782950265, 31.95972980771746, 35.18612929752895, 40.83863128934588, 42.26382493972778, 41.37867655072893, 41.12174258913313, 44.47857018879482, 42.69568674904959, 39.398547649383545, 38.74725825445992, 33.02582318442208, 31.826908043452672, 32.33186490195138, 30.8938935143607, 31.659067358289445, 32.16954803466797, 31.14607490812029, 31.163591316768102, 31.632414068494523, 34.48786660603115, 34.03381225040981, 33.061029706682476, 33.353100708552766, 34.12830775124686, 32.29401111602783, 31.443680150168284, 31.847123827253068, 32.55067409787859, 31.991337163107737, 31.38889707837786, 30.835730143955775, 30.85065140042986, 32.51513753618513, 33.22431584766933, 35.98704814910889, 38.1933582850865, 38.88122647149222, 41.10800947461809, 41.6791479246957, 41.68332379204886, 45.60100303377424, 43.76878390993391, 42.078773566654746, 36.381281988961355, 38.83373553412301, 45.13759640284947, 41.75510563169207, 41.6833689553397, 37.780339990343364, 37.52500411442348, 33.15694611413138, 31.664976801191056, 31.557359627314977, 32.70769643783569, 32.954475607190815, 33.709518977573936, 32.66066755567278, 34.24528067452567, 33.55743333271572, 33.882008007594514, 35.20497281210763, 34.571067810058594, 34.023508071899414, 33.55715193067278, 33.88959196635655, 34.55281489236014, 32.80042014803205, 33.47587537765503, 32.208457946777344, 32.618714332580566, 33.093811307634624, 39.627247606004985, 44.75668225969587, 46.725763525281636, 45.219751902988975, 43.29204716001238, 41.65320682525635, 40.53880262374878, 39.010699204036165, 37.91568047659737, 38.32037830352783, 39.02246250425066, 38.761453424181255, 43.12266050066267, 47.503489289964946, 44.65818459647042, 49.51056677954537, 43.444431577410015, 35.198927879333496, 32.78500556945801, 36.74462066377912, 40.70956155232021, 45.288368838174, 45.53542593547276, 49.59038073675973, 51.81674337387085, 48.926945890699116, 44.76118469238281, 27.34831288882664, 14.731761728014265, 12.220647147723607, 7.179395122187478, 4.330183804035187, 1.5818707517215183, 0.1820411474577018, 0.0530644240123885, 2.612273837838854, 26.896431582314626, 49.28352049418858, 37.80814668110439, 33.30654430389404, 32.729076044900076, 42.05451740537371, 40.24828454426357, 11.701881613050189, 1.2445141055754252, 0.06293586002928869, 0.03394877617912633, 0.05671341570892504, 0.06250060695622649, 0.04240237256245954, 0.007970934068518025, 0.05289787080671106, 0.02675729394624276, 0.023045339288988283, 0.06956701991813523, 0.04901508986949921, 0.011555741441303065, 0.00845534191466868, 0.03724330796727112, 0.01783284854276904, 0.011439761146903038, 0.04632997073765312, 0.01124864412538175, 0.044918387196958065, 0.012530395927439843, 0.03662619393851076, 0.025525021765913283, 0.03609140317088791, 0.023061177992661084, 0.028824160806834698, 0.02268950025817113, 0.031989421495901685, 0.030731688985334973, 0.03948479411857469, 0.03700617354895387, 0.007847405920204307, 0.03784890725676503, 0.4378877973982266, 13.175401721681867, 44.18930973325457, 50.51568276541573, 45.5926547731672, 27.426452330180577, 32.395809173583984, 37.13245521272932, 48.28726346152169, 22.354010275432042, 0.695535306419645, 0.06337018350937537, 0.3583872690796852, 3.304008262498038, 4.404480023043496, 3.2344263962336948, 5.1061681764466424, 24.28629388128008, 40.875314303806846, 48.78175980704171, 45.83001913343157, 47.50888804027012, 46.32320921761649, 46.80405930110386, 45.67884022848946, 44.37195355551583, 35.473444257463726, 32.41960327965872, 33.105286257607595, 36.82738413129534, 41.96408660071236, 44.67266116823469, 42.971839427948, 42.68213428769793, 45.85817323412214, 44.500981603349956, 42.159233706338064, 40.18774141584124, 33.8099239213126, 33.35155473436628, 32.96727418899536, 33.18340832846505, 33.49484395980835, 33.915651185171946, 32.8360470363072, 32.69473457336426, 32.63284349441528, 35.85947227478027, 35.1050021307809, 34.65077754429409, 33.801151820591514, 36.127891608646934, 34.12757471629551, 33.7266845021929, 33.58569860458374, 33.69908973148891, 33.861052240644185, 32.972096238817485, 31.987394060407365, 32.59150866099766, 33.732826709747314, 35.56768614905221, 37.04834726878575, 40.20061642783028, 41.45346001216343, 42.90533127103533, 42.92928865977696, 45.0039130619594, 45.913161277770996, 45.35409879684448, 41.827589239392964, 39.02038499287197, 40.833388873508994, 46.99291133880615, 43.011110646384104, 42.958752495901926, 39.00445972170149, 37.867946352277485, 35.09153652191162, 33.76291240964617, 33.13217231205532, 33.70157718658447, 34.562347820826936, 35.17127752304077, 34.85869891302926, 35.50090701239449, 35.189367158072336, 35.043899672372, 35.75149726867676, 35.445762634277344, 35.06988246100289, 34.119156973702566, 36.37513978140694, 35.809198583875386, 34.06598240988595, 33.5425363949367, 33.65709481920515, 35.49181876863752, 35.386296476636616, 41.378283977508545, 46.131438936506, 47.497732707432334, 45.58897917611258, 45.17896250316075, 43.43610068729946, 43.55565139225551, 41.441269397735596, 40.19842774527413, 40.637216908591135, 41.92987019675118, 41.50934437343052, 44.81175715582711, 50.08849014554705, 46.549977575029644, 50.046356269291465, 46.17158910206386, 37.903368268694194, 34.500074590955464, 37.261987004961284, 42.403146743774414, 47.81406681878226, 47.30941915512085, 52.80159841264997, 51.69953073774065, 49.97521366391863, 44.61118698120117, 31.672355788094656, 15.054491656167166, 7.658429554530552, 6.5616828969546726, 9.236726760864258, 1.000783241220883, 0.26925371480839594, 0.15283877801682266, 2.434687001364572, 32.151270798274446, 52.85412679399763, 42.3036207471575, 39.43533836092268, 39.970023087092805, 48.723488739558626, 48.1140900339399, 19.42584136554173, 1.2899862655571528, 0.1045842512643763, 0.004698534396343997, 0.0035998555831611156, 0.043422454968094826, 0.022640716983005404, 0.039287099548216374, 0.04166252851220114, 0.047592337642397196, 0.046816565162901363, 0.048870344779321125, 0.0234339278124805, 0.07254156816218581, 0.005771302501671016, 0.027779381422858154, 0.062490015024585385, 0.11855078861117363, 0.11257236583956651, 0.08505325179014887, 0.0998149575399501, 0.21317973014499458, 0.14431565893547876, 0.07060900543417249, 0.11976383280541215, 0.135124359279871, 0.1736712008714676, 0.16380788013339043, 0.15474850125610828, 0.09041004148977143, 0.07594553407813821, 0.18848260252603463, 0.10571644122579268, 0.07166147431624786, 0.5211131572723389, 15.939827646527972, 50.630303723471506, 57.43271173749651, 51.21928514753069, 39.833953039986746, 45.023579938071116, 45.009343079158235, 56.38198430197579, 26.07984106881278, 1.1748864246266228, 0.2194530985185078, 1.1202226664338792, 6.071920011724744, 23.406330585479736, 15.943121092660085, 3.8225657854761397, 25.090615613119944, 41.53685229165213, 50.475237301417756, 47.580048016139436, 48.47750513894217, 48.53466102055141, 50.01158053534371, 46.8074882371085, 47.57103967666626, 36.69100488935198, 34.52537645612444, 35.70241519383022, 38.64031852994646, 44.67773335320609, 46.73827723094395, 43.162119320460725, 42.44263335636684, 46.77567590985979, 47.34447629111153, 43.922686508723665, 42.99609906332833, 36.618403162275044, 35.41609035219465, 36.13912337166922, 35.36283935819353, 34.62693132672991, 35.2964562688555, 34.912627356392996, 33.883345535823274, 34.51574625287737, 37.958001954214915, 37.28188664572579, 37.21777214322771, 36.55935042245047, 38.37777737208775, 34.88453926358904, 35.61052526746477, 35.18940537316458, 37.131763866969514, 35.52574682235718, 35.899261134011404, 35.287371499197825, 33.7300682749067, 36.17397206170218, 37.53794513429914, 39.53073017937796, 42.37773718152727, 42.983078139168875, 45.08318158558437, 46.10412209374564, 48.25076110022408, 49.076092447553364, 47.799006598336355, 42.154168469565256, 39.767107895442415, 43.86654506410871, 47.99456017357962, 44.16428927012852, 44.4050304549081, 41.4885379927499, 41.076916285923545, 37.21200861249651, 35.257872922079905, 34.671312945229666, 34.726922852652415, 36.93501172746931, 36.576693126133506, 36.92035450254168, 37.740467752729145, 36.757037094661165, 37.61942318507603, 37.68105370657784, 37.182701110839844, 37.50829717091152, 36.479560783931184, 37.37668786730085, 37.93331847872053, 35.802517890930176, 36.40960284641811, 35.21926178250994, 37.22296939577375, 36.86863906042916, 44.22918891906738, 48.72649383544922, 51.001695360456196, 47.28104618617466, 48.02813734327044, 46.637781960623606, 45.568238803318565, 43.14955002920968, 42.4759395463126, 42.35525975908552, 43.32225792748587, 44.15004893711635, 47.0791072164263, 52.55610466003418, 46.956169264657156, 52.40591239929199, 50.02387537275042, 40.034929684230256, 36.0532158442906, 39.465090547289165, 44.396518911634175, 50.32575028283255, 51.05177797589983, 54.45684691837856, 56.70554106576102, 48.957754203251426, 47.378188950674875, 31.092438289097377, 16.978093487875803, 19.658821412495204, 15.29152945109776, 14.94436618259975, 5.187885940074921, 0.8533642888069153, 0.24438635632395744, 3.78101338659014, 36.373871735164094, 60.3597446169172, 46.828913007463726, 42.64907475880214, 42.94166340146746, 55.76090914862496, 56.517845903124126, 27.121212754930767, 1.4478579142263956, 0.13299038021692208, 0.09137653998498406, 0.1474957490073783, 0.08819086556988102, 0.08404598012566566, 0.18022252433001995, 0.13455704972147942, 0.10642152731972081, 0.14767220882432802, 0.20473343479846204, 0.11869296883898121, 0.126286902065788, 0.09247964793550116, 0.1400994730315038, 0.13338196277618408], [0.01292018630608384, 0.049666856681661944, 0.022620398251871978, 0.010172029574667769, 0.05387257279029914, 0.018207189527207186, 0.012390356477616089, 0.08593430915581328, 0.04144778914217438, 0.06637781712093524, 0.0246885271875986, 0.05386357202327677, 0.03872588323429227, 0.05684874612571938, 0.05483337837670531, 0.01847256626933813, 0.02094646423522915, 0.043657268796648295, 8.605931946209498, 36.28484099251883, 45.46734748567854, 49.06201539720808, 34.58825765337263, 28.61635218347822, 40.52533006668091, 40.78745780672346, 29.287456103733607, 2.060219917978559, 0.05005720430719001, 0.40561580338648384, 7.292187401226588, 4.133256656782968, 2.2788610543523515, 5.608704021998814, 17.16609958239964, 39.27072858810425, 49.055675165993826, 48.02011564799717, 46.07728815078735, 48.207588468279155, 44.40561410358974, 44.54830230985369, 39.41007123674665, 34.5466970035008, 32.87994575500488, 33.77176441465105, 35.86266497203282, 41.10967009408133, 44.71851927893502, 41.67010484422956, 37.943688665117534, 39.845229966299875, 45.094656535557334, 42.622338090624126, 40.437817505427766, 34.40217447280884, 30.24654722213745, 31.02896649496896, 30.376527173178538, 32.329224586486816, 30.69701283318656, 30.950535229274205, 31.26710557937622, 33.354671001434326, 31.772958755493164, 32.83823571886335, 32.35063893454415, 32.156176226479666, 31.47899089540754, 33.39984471457345, 31.699502399989537, 31.313540390559606, 32.863155433109824, 30.408478464399064, 31.666415078299387, 31.30140883581979, 30.32863324029105, 33.39003733226231, 32.68297127314976, 37.728426524571006, 38.57631867272513, 41.541024684906006, 43.57715606689453, 43.22286394664219, 41.75076995577131, 45.77085174833025, 40.117522920881, 43.20232507160732, 40.32951593399048, 35.927550724574495, 47.45532785143171, 44.01498637880598, 42.61017179489136, 44.985813004629954, 42.59211342675345, 41.535716261182515, 38.08741562707083, 34.267824104854036, 32.40811790738787, 33.81832776750837, 32.855672223227366, 32.71623229980469, 34.78083392551967, 32.6152332850865, 33.730280194963726, 35.073307922908235, 34.04886899675642, 34.038002014160156, 33.25489139556885, 32.705914224897114, 33.38746649878365, 32.388854026794434, 32.999725750514436, 32.00032465798514, 30.92419113431658, 32.70881857190813, 33.31147405079433, 37.15473461151123, 39.17430148805891, 39.4958085332598, 39.906676360539024, 38.20401334762573, 33.817688533238, 35.038792746407644, 31.364498479025706, 33.87675516945975, 35.86594104766846, 41.1508138520377, 42.07034192766462, 47.818934031895225, 45.04491785594395, 46.972487109048025, 47.69920267377581, 43.21465465000698, 34.27868413925171, 34.46252999986921, 35.03014918736049, 40.30692386627197, 45.8811092376709, 47.94372715268816, 49.729709489004954, 53.678172724587576, 42.83418519156319, 30.709443160465785, 13.926501989364624, 8.046935473169599, 6.8503579667636325, 3.4950641819408963, 1.0665422954729624, 0.1880772185644933, 0.04301840093519006, 4.921609256948743, 31.80348219190325, 43.86492613383702, 34.16203430720738, 19.840306622641428, 27.70653247833252, 43.507048743111746, 38.085247789110454, 7.988357816423688, 2.4766756168433597, 0.1379272381642035, 0.03855504168729697, 0.059218071667211394, 0.0196468321872609, 0.06754501270396368, 0.011897362618973213, 0.050552158283868005, 0.0603805717879108, 0.02444157436756151, 0.04484751421426024, 0.012088096268208963, 0.028421321351613318, 0.01511657447554171, 0.08887256934706654, 0.017715864016541412, 0.0059715008662481394, 0.0553967592173389, 0.039335777650454214, 0.022874862454565506, 0.02193610416725278, 0.027999991817133765, 0.07490886827664715, 0.055896557934050045, 0.07056893115597111, 0.04259122582152486, 0.036838901096156666, 0.029769685784620897, 0.07696793028818709, 0.026417982332142334, 0.06427469783063446, 0.04659900308719703, 0.03870495721431715, 0.02612650574051908, 10.099064213888985, 43.0144944190979, 51.24485451834542, 51.698453766959055, 40.84802177974156, 35.163297516959055, 42.471100125994, 47.16010584150042, 30.214985030038015, 2.3061394648892537, 0.1236501828368221, 0.23850286060145923, 5.096104579312461, 6.000890748841422, 4.225925649915423, 6.396182886191776, 20.506152493613108, 37.94008949824742, 49.48290947505406, 50.19940076555525, 48.16872371946062, 49.15169927052089, 46.841242585863384, 47.060777868543354, 41.76076146534511, 36.08816180910383, 34.531348432813374, 35.55841030393328, 36.67088638033186, 43.328083992004395, 45.94565452848162, 42.907700606754844, 39.31076410838536, 40.54037986482893, 46.56679916381836, 44.92663867133004, 42.30713306154524, 35.382666042872835, 32.29555014201573, 33.977090631212505, 30.98291383470808, 33.61602054323469, 32.835518973214285, 32.5759516443525, 32.450192723955425, 35.26344885144915, 33.356255190713064, 34.880220958164756, 34.635244846343994, 33.345999649592805, 33.01204143251692, 34.64550733566284, 32.687296526772634, 33.78144325528826, 33.73432404654366, 32.31247247968401, 33.70350531169346, 32.66992950439453, 32.978714397975374, 33.974047320229666, 35.449827330453054, 38.69874940599714, 40.54254422869001, 42.79555320739746, 44.47426230566842, 45.562409264700754, 45.07452760423933, 47.24497808728899, 42.73231765202114, 43.75781617845808, 41.14453615461077, 38.086449827466694, 50.14756720406668, 45.46755940573556, 44.22457878930228, 44.58417933327811, 42.82166453770229, 41.69850560597011, 39.800997734069824, 36.18047904968262, 34.16588360922677, 35.076747281210764, 34.672591413770405, 35.094232422964915, 36.47870962960379, 33.852443422589985, 34.41601875850132, 36.26594189235142, 35.16714334487915, 36.16084344046456, 34.319351945604595, 35.18254402705601, 34.45124959945679, 34.70778056553432, 34.10850885936192, 33.86655521392822, 31.558134351457866, 33.89665828432356, 34.75133534840175, 40.510235105242046, 41.76750469207764, 41.97938305991036, 42.27199602127075, 40.81151247024536, 37.00536571230207, 37.164660113198416, 32.81347581318447, 36.586733273097444, 37.87436648777553, 43.57320254189627, 44.72644369942801, 49.18992131096976, 45.74769687652588, 49.24697296960013, 49.94130992889404, 43.63270344052996, 35.63449307850429, 36.91077641078404, 37.606145177568706, 42.11415031978062, 48.4033921786717, 50.02566453388759, 51.352881635938374, 54.12835693359375, 43.89301075254168, 33.16062865938459, 14.124849608966283, 5.967046507767268, 8.886157138007027, 5.931925535202026, 2.3355998269149234, 0.2686614894441196, 0.02430889193367745, 4.143342401300158, 34.26244272504534, 51.1439527784075, 34.46629592350551, 24.65376499720982, 32.74098178318569, 47.97885029656546, 49.491841384342735, 18.239888089043752, 2.5569939698491777, 0.10038567334413528, 0.06540711849395718, 0.04906983746747885, 0.04178051218124373, 0.06841036198394639, 0.0705116628003972, 0.0225473403864141, 0.014259142002889087, 0.012274054727250976, 0.048319706826337745, 0.05688314785116485, 0.03086794220975467, 0.00931408565624484, 0.023979419077347432, 0.022980576514133384, 0.10864290847842183, 0.16694120557180472, 0.08951344567217998, 0.10463357397488185, 0.08959788935525076, 0.12074409877615315, 0.11521744461996214, 0.18407577542322023, 0.15100969187915325, 0.09732765172209058, 0.1925273769135986, 0.10201327529336725, 0.0940196103017245, 0.17250702476927213, 0.12964129421327794, 0.0983823122722762, 0.07553144451230764, 0.10345930805695908, 12.873278413500104, 49.41686684744698, 58.23154265539986, 58.647229058401926, 46.19987869262695, 37.28372097015381, 50.087493079049246, 50.59300231933594, 36.18089941569737, 2.9985265859535764, 0.3942595427589757, 1.005745340670858, 13.136134845869881, 8.448899183954511, 7.427363736288888, 8.910355976649694, 19.682474817548478, 42.656749044145855, 51.032298701150076, 51.88989053453718, 49.27867412567139, 51.029192856379915, 48.235930170331685, 48.2363783291408, 43.3481399672372, 37.60258422579084, 35.72482313428606, 37.83263908113752, 38.18967226573399, 46.16643006461007, 47.12064354760306, 42.84769596372332, 39.3643798828125, 40.88374594279698, 48.20626483644758, 46.583610330309185, 45.24699926376343, 37.64890786579677, 33.55932671683175, 34.57693556376866, 32.695425919124055, 35.73053107942854, 34.221524783543174, 34.06988034929548, 33.82685668127877, 37.33784048897879, 35.45823465074812, 36.068974358694895, 36.46362509046282, 36.33272450310843, 35.438776220594136, 36.640828473227366, 34.76400538853237, 35.877172810690745, 36.46616465704781, 33.5990252494812, 35.27968679155622, 34.43162093843733, 34.97952113832746, 35.76738085065569, 36.548625877925325, 40.86250182560512, 41.52518974031721, 45.64512062072754, 46.312172004154746, 46.649263858795166, 44.95246859959194, 47.73792151042393, 44.76199763161795, 43.91370248794556, 43.26924317223685, 40.11146756580898, 51.19777005059378, 47.55084821156093, 46.527965681893484, 48.24297564370291, 44.679466928754536, 45.478353432246614, 42.70874241420201, 38.04868289402553, 36.05168376650129, 37.16714409419468, 35.694640159606934, 36.22688954217093, 38.4080228805542, 34.962810720716206, 37.122144086020334, 37.870927129473, 36.540875162397114, 37.98827525547573, 36.534889289310996, 36.41934422084263, 36.297493662152974, 35.35265677315848, 36.02017021179199, 34.2487165587289, 33.29255410603115, 36.277177129473, 37.356187207358225, 40.90940564019339, 44.0128949710301, 44.37083836964199, 45.021648338862825, 41.58398192269461, 38.05872304098946, 40.00220019476754, 34.24784803390503, 38.501660278865266, 40.06099585124424, 45.55566256386893, 47.77011946269444, 51.91683217457363, 46.69467033658709, 48.5483454976763, 52.92163896560669, 48.39288650240217, 36.9371656690325, 38.873308999197825, 39.70995896203177, 44.13342884608677, 51.375306946890696, 52.69433907100132, 53.73052045277187, 56.49864455631801, 45.829421588352744, 36.274255411965505, 18.38045883178711, 16.17849826812744, 16.771678141185216, 8.51885277884347, 4.408255934715271, 0.6990082657762936, 0.11934677804155008, 6.600160717964172, 40.631057330540244, 56.87370484215872, 43.76787369591849, 31.646015167236328, 38.63346413203648, 58.21890040806362, 55.78660706111363, 31.317229884011404, 2.9624048556600298, 0.30303566636783735, 0.15954226973865712, 0.20265080726572446, 0.1707880241530282, 0.13659425612006867, 0.1962746272661856, 0.10790673869528941, 0.16243322246841022, 0.07822434644081763, 0.12479150587958948, 0.1239356832312686, 0.12706754303404263, 0.12698541315538542, 0.18529176445943968, 0.07704259628163916], [0.05188527264233146, 0.04976533925426858, 0.09372251374380929, 0.027642902585544755, 0.07935697744999613, 0.09935461224189826, 0.06097845613424267, 0.051657328980841806, 0.07481274022055523, 0.03882832505873271, 0.039895548684788604, 0.029313150460698774, 0.05139724311551877, 0.023573012224265506, 0.07391854641692978, 0.006003303378487804, 0.019817485440788523, 0.08568690171731369, 3.63301653947149, 25.844964163643972, 44.42043113708496, 45.91506855828421, 21.777410541261943, 17.47197665487017, 30.31253773825509, 42.82027837208339, 31.45959152494158, 3.579170171703611, 0.18869252769010408, 0.7086406403354236, 33.745673928942, 14.459079674312047, 0.8514401263424328, 4.207462114947183, 14.598969493593488, 33.70448848179409, 44.54690572193691, 49.60839741570609, 44.84952061516898, 47.070967401777, 43.87120730536324, 43.96006086894444, 37.07258605957031, 32.596278599330354, 33.13214799336025, 34.96148361478533, 41.95810072762625, 44.50496639524187, 43.81079271861485, 41.861128193991526, 45.57613543101719, 43.6365145274571, 44.802783557346885, 44.067368847983225, 40.27390602656773, 32.330586433410645, 29.00082380431039, 31.81373425892421, 31.15362412588937, 30.73624583653041, 30.632408482687815, 31.69536474772862, 31.283121177128383, 32.817116669246126, 33.21422011511666, 34.06877905981881, 32.30554512568882, 33.11769226619175, 32.97410774230957, 32.02337530681065, 33.10592201777867, 33.08078343527657, 30.356651851109095, 31.622898510524205, 32.52260684967041, 31.581594944000244, 32.48448208400181, 32.31911148343767, 34.71750456946236, 37.07330519812447, 39.68928459712437, 41.97304630279541, 43.84742362158639, 44.42346402576992, 43.39491524015154, 41.71836355754307, 43.1689007622855, 43.51458406448364, 36.67189734322684, 35.92205817358834, 44.33644478661673, 47.12513903209141, 44.32008525303432, 44.128356661115376, 45.63610185895647, 44.11919546127319, 43.734598772866384, 43.18881777354649, 34.523639406476704, 34.547030517033164, 40.28158378601074, 32.49759333474295, 33.03704105104719, 33.57917077200753, 33.63711527415684, 34.196761403764995, 32.80278948375157, 34.026388100215364, 33.60468455723354, 33.40978063855852, 35.539337498801096, 33.399816921779085, 33.77236195972988, 32.42096165248326, 31.332779952457972, 32.926835673195974, 33.52237272262573, 33.79026051930019, 34.469794341496055, 34.89327662331717, 33.518763133457725, 33.05040938513619, 33.58322851998465, 32.264470849718364, 32.18546288354056, 33.21724952970232, 34.434372425079346, 39.561726093292236, 39.18710354396275, 46.13657365526472, 47.64681673049927, 42.22351843970162, 48.928804533822195, 46.64077663421631, 41.28642879213606, 35.96272597994123, 33.414713859558105, 37.068392821720664, 40.41853972843715, 48.60409436907087, 48.34252595901489, 52.207082748413086, 46.290785448891775, 29.745106152125768, 12.303692885807582, 2.6699252128601074, 4.861284562519618, 5.641327117170606, 0.39216373807617594, 0.05760667991957494, 0.021795608402628983, 4.20093297958374, 35.1740220614842, 43.931364808763774, 36.564662320273264, 29.76391839981079, 37.90532071249825, 52.19274166652134, 35.880268233163015, 14.843466179711477, 1.0326226013047355, 0.14547950934086526, 0.07273573095777205, 0.08002568049622433, 0.05862003804317542, 0.03013581988800849, 0.022724258214501396, 0.019273144292778203, 0.048432682906942706, 0.03470491185518248, 0.03236027141766889, 0.06590681882309062, 0.07152911927551031, 0.06442937667348556, 0.03259930573403835, 0.047833438097898445, 0.012866561683560056, 0.022412680022950684, 0.05225934221276215, 0.008872612961567938, 0.08691216632723808, 0.05399916706872838, 0.004168059111439756, 0.03403321986219712, 0.0726943878190858, 0.00751512053622199, 0.0314518385566771, 0.024201393327010528, 0.06595232816679136, 0.025635656900703907, 0.029952025107507194, 0.04562532229881201, 0.035922427595193894, 0.19438025248902185, 5.853431735719953, 33.891134466443745, 50.637866837637766, 51.258476461683, 27.559756994247437, 23.692271539143153, 40.44107968466622, 48.752337660108296, 35.517864091055735, 4.05670531306948, 0.14308312721550465, 0.6683153584599495, 32.06416470663888, 15.575980016163417, 2.901381867272513, 4.369472392967769, 16.01183703967503, 36.79442882537842, 46.64398322786604, 51.45502362932478, 46.45339414051601, 47.75965894971575, 46.51562220709664, 46.59693002700806, 39.71941198621477, 34.13514825275966, 32.979652404785156, 36.57163483755929, 42.88335411889212, 46.4336438860212, 45.43050813674927, 41.80255487986973, 45.82260887963431, 44.80872426714216, 46.53091866629464, 46.24289151600429, 42.38983052117484, 34.355899470193044, 30.592876706804546, 32.42359849384853, 32.44961602347237, 32.88912085124424, 33.72344316755022, 33.14934825897217, 32.808688504355295, 33.4363922391619, 34.77091537203108, 35.05434628895351, 34.22925465447562, 33.9618740762983, 34.912832328251426, 34.67177152633667, 33.324227469308035, 33.547070094517295, 31.908375671931676, 33.354240213121685, 33.38996090207781, 34.460963181086946, 32.765863282339915, 33.53301041466849, 35.65808916091919, 39.411426135471885, 41.88538782937186, 44.392951011657715, 45.202954632895334, 46.1112961087908, 45.160713059561594, 43.434648513793945, 41.42716802869524, 44.91543470110212, 37.813826833452495, 36.816343443734304, 45.692632402692524, 48.09470108577183, 44.829256193978445, 44.75585194996425, 46.73164170128958, 45.83258649281093, 46.10814510072981, 44.24863345282418, 36.601741382053916, 36.13515247617449, 41.001834051949636, 34.40611410140991, 34.387378283909385, 35.724395820072715, 35.42777722222464, 36.38257782799857, 33.85166869844709, 34.79276398250035, 34.98211976460048, 35.625919001443044, 36.49047292981829, 34.80083778926304, 35.41852569580078, 33.48515122277396, 32.882725034441265, 34.04164287022182, 35.15118333271572, 35.310849462236675, 36.95651987620762, 36.92117091587612, 35.21062169756208, 34.219099862234934, 35.02376726695469, 33.83369023459298, 33.795982360839844, 35.639975207192556, 36.385433537619456, 41.60723406927926, 41.890418325151714, 49.22090332848685, 49.31783764702933, 43.16231039592198, 50.511416571480886, 48.84551647731236, 41.55857236044747, 36.61422382082258, 35.75993932996477, 38.101885250636506, 43.50534643445696, 51.731707845415386, 51.475989818573, 54.87117147445679, 47.023542472294395, 31.05282313483102, 13.4302989925657, 3.5863135712487355, 3.8186730572155545, 6.067272535392216, 1.1904845876353127, 0.2170949179146971, 0.03421279754755752, 5.193427562713623, 37.5778660093035, 51.91908686501639, 40.09939159665789, 32.05898482458932, 40.20871455328805, 57.260497161320274, 44.15973820005144, 20.665043898991176, 1.4546409845352173, 0.16519794054329395, 0.024242219082745056, 0.03571342184607472, 0.01098364481835493, 0.0537345350187804, 0.059085886260228496, 0.005240865384361574, 0.028345851294164146, 0.024317463527300527, 0.01761975122748741, 0.05146860803610512, 0.03414005180820823, 0.041216021935854635, 0.06802040790872914, 0.04645655483805707, 0.1492070686072111, 0.12312133264328752, 0.11053101359201328, 0.13678305170365743, 0.1396400641117777, 0.22018996040735925, 0.13524184083299978, 0.15643730706402234, 0.19153904994683607, 0.09778721670487098, 0.1431555404726948, 0.1270245374845607, 0.15008575788566045, 0.06813470713262047, 0.19479323604277202, 0.14646635710128716, 0.10665686362023864, 0.31615324105535236, 6.4898658820561, 38.50766352244786, 57.49287271499634, 56.737989153180806, 31.085166999271937, 26.577054159981863, 40.1932235445295, 53.42749214172363, 39.56399120603289, 4.852931525026049, 0.2891400562865393, 0.956502805863108, 41.151248114449636, 21.79807448387146, 3.608586456094469, 7.789617623601641, 17.26683282852173, 38.54878990990775, 47.41057103020804, 52.74325091498238, 47.616998536246165, 48.740953036717, 47.50050503867013, 49.23734276635306, 40.30055931636265, 35.15386186327253, 37.06743049621582, 38.65770639692034, 45.584841523851665, 49.722274916512625, 46.04358243942261, 43.18046603884016, 48.07923092160906, 46.807825224740164, 48.00461074284145, 50.02364955629621, 44.38263988494873, 36.32298312868391, 31.528691359928676, 34.138886383601594, 34.22680541447231, 35.32564565113613, 34.74217414855957, 34.83432115827288, 34.618628229413716, 36.150146688733784, 37.328856468200684, 37.42102779660906, 36.28381265912737, 36.79309824534825, 36.40490933826992, 35.50619459152222, 36.539964948381694, 35.974433694567, 33.28268418993269, 34.762167590005056, 35.741015911102295, 35.679326329912456, 35.575805119105745, 36.417836461748394, 38.453759397779194, 41.34024259022304, 44.099875995091026, 46.31020218985421, 45.831884724753245, 49.58713245391846, 45.9960880279541, 45.340938908713206, 42.5722450528826, 45.76628678185599, 40.90567793164934, 38.71544592721121, 47.80317551749093, 48.96960435594831, 47.640570299965994, 46.50484902518136, 49.579576287950786, 48.24868706294468, 47.68245751517159, 46.91946193150112, 37.93041065761021, 38.22911024093628, 43.153545243399485, 34.99925054822649, 36.71250261579241, 37.128428731645855, 37.900846072605674, 38.48453991753714, 34.92233051572527, 36.682090350559776, 37.65774597440447, 38.20177602767944, 38.7146885735648, 37.09378501347133, 36.52885477883475, 35.370756830487935, 34.79300716945103, 35.971122877938406, 36.78593117850167, 37.05997160502842, 37.3372985294887, 37.52031408037458, 36.68675259181431, 36.041233675820486, 36.38657999038696, 35.49557079587664, 35.49981614521572, 37.777161189488, 38.430312701633994, 43.63479137420654, 44.15708746228899, 51.57005105699812, 51.47030619212559, 45.45550775527954, 50.8661116872515, 51.18926198141915, 45.064192158835276, 41.08221428734915, 36.45328964505877, 40.77441256386893, 44.52090208871024, 55.931421416146414, 53.22363894326346, 56.64254869733538, 49.49578448704311, 35.16258880070278, 18.807614973613195, 9.075805612972804, 11.816400953701564, 11.426013810294014, 3.40398154939924, 0.46635766114507404, 0.25285154208540916, 5.702618045466287, 45.309508732386995, 57.29261868340628, 48.79097311837332, 41.245899949754985, 50.40534537179129, 64.65244592939104, 52.96360608509609, 28.69755925451006, 2.507686729942049, 0.43545839775885853, 0.141315489209124, 0.15995662393314497, 0.16621149544204983, 0.13559918451522077, 0.10208235015826565, 0.13159656072301523, 0.11646992526948452, 0.12749850776578697, 0.07185253620679889, 0.10552067030221224, 0.132860590038555, 0.10745844417916876, 0.13415595410125597, 0.10406718043876545], [0.0461668678825455, 0.02434010454453528, 0.02387735553617988, 0.003223846886872447, 0.0804806857236794, 0.04801792837679386, 0.05410881154239178, 0.0707567021516817, 0.07428519281425647, 0.0454072445364935, 0.025234054075554013, 0.023518030531704426, 0.018928343330376914, 0.037792870442249944, 0.08621942957064935, 0.06059670554740088, 0.039522649587265084, 0.041458978184631894, 1.2945716423647744, 21.388433013643535, 43.810601643153596, 47.09360463278634, 29.192224093845912, 19.04037962641035, 32.8118325642177, 44.67731646129063, 34.396511690957205, 8.364594084875923, 0.0786439592817, 3.985729898725237, 25.729068211146764, 30.2670305115836, 6.424074258123126, 2.132122482572283, 13.306336181504385, 23.437805925096782, 47.38029425484793, 47.199568135397776, 47.557313510349815, 41.27520397731236, 43.95638179779053, 38.33643906457083, 36.898526736668174, 32.15050302233015, 37.842682702200754, 40.47997917447771, 42.84166840144566, 44.72142710004534, 45.142981256757466, 45.891121591840474, 43.52975198200771, 42.55690343039376, 41.70416838782174, 40.658919606889995, 34.86623770850045, 30.16163328715733, 31.28453860964094, 29.934635639190674, 32.87682948793684, 33.48562022617885, 34.99230234963553, 30.431675025394984, 32.14848109654018, 32.337635380881174, 32.99954162325178, 33.2433990750994, 32.57270336151123, 33.624410493033274, 32.44659008298601, 30.75026035308838, 33.43490879876273, 31.317083971840994, 32.79370471409389, 30.87547731399536, 31.634873730795725, 30.510686465672084, 32.008408887045725, 30.489133153642925, 33.65589278084891, 35.85508796146938, 39.41524417059762, 40.28136491775513, 46.23293822152274, 41.69802270616804, 46.53798845836094, 43.353121825626914, 47.02790246691023, 38.53748171670096, 37.30861289160592, 36.046139104025706, 47.58141333716256, 42.52040106909615, 46.30951084409441, 45.55877883093697, 45.61101886204311, 44.50327450888497, 44.79265308380127, 45.165729658944265, 39.781341280256, 34.42543356759207, 36.1460611479623, 34.42330394472395, 33.030124119349885, 33.28395571027483, 33.99750443867275, 33.6606627191816, 34.13252878189087, 35.37881326675415, 33.51213107790266, 32.052648067474365, 33.982742990766255, 33.12654774529593, 33.09171642575945, 33.886958599090576, 32.783855642591206, 31.93584190096174, 32.11690500804356, 33.9561105455671, 33.23941775730678, 32.520313944135395, 31.22952972139631, 32.68323530469622, 33.70664937155587, 32.45723124912807, 31.252844401768275, 32.65752696990967, 34.354912825993125, 38.19703735624041, 42.06251130785261, 44.06442281178066, 46.94524322237287, 43.423910072871614, 46.33559785570417, 48.76415307181222, 46.230680056980674, 40.38139118467058, 35.3558703150068, 33.896981375558035, 38.29323516573225, 44.03034537179129, 47.13031891414097, 48.9133482660566, 48.404156480516704, 30.02142906188965, 10.403067878314427, 2.2164961951119557, 2.8154643518584113, 7.022865670067923, 1.5502062908240726, 0.0384949811601213, 0.05239617558462279, 5.971159407070704, 36.065458570207866, 44.16198941639492, 29.579176221575054, 21.38763918195452, 37.211143561771934, 46.10235377720424, 43.23762192044939, 16.546841382980347, 0.381986744169678, 0.03150672525433557, 0.03666645820651736, 0.01094424313799079, 0.024547927946384464, 0.013803306418204946, 0.013402162452361413, 0.05989438109099865, 0.023435944757823433, 0.048808984857584746, 0.027235649260027067, 0.04076553235894867, 0.06431976612657309, 0.018048101903072426, 0.06424700681652341, 0.053307973979307074, 0.012872395388382887, 0.05945982690900564, 0.03907681815326214, 0.04326417310429471, 0.0903128142069493, 0.04262068781203457, 0.026274216028728654, 0.09047558797257287, 0.026532848132774234, 0.053710725224976025, 0.05166021275467106, 0.05305314676037856, 0.03943486751190253, 0.04501560769443001, 0.04592602187767625, 0.02733299189380237, 0.04103507700243166, 0.04123209643044642, 1.8797369854790824, 24.767982959747314, 50.897851058415, 53.09850188664028, 31.234751292637416, 19.929387739726476, 34.4678384235927, 49.418593474796836, 36.32960476194109, 7.932942458561488, 0.09700710499393088, 2.980112991162709, 29.759839807237896, 27.667997768947057, 8.818103875432696, 2.523124541555132, 12.644616671970912, 26.561288697378977, 47.08673981257847, 49.692151001521516, 47.542625018528526, 45.238602365766255, 45.36151947293963, 41.962596212114605, 38.33117927823748, 33.28716925212315, 37.47323308672224, 42.246589933122905, 44.588216236659456, 45.81974969591413, 44.912408760615754, 46.71567126682827, 45.36640058244978, 44.758099692208425, 44.818288462502615, 42.69149003710066, 37.342850140162874, 32.231407846723286, 32.6953946522304, 32.344194480351035, 33.73801701409476, 34.55040734154837, 36.35180425643921, 31.618409974234446, 34.83932038715908, 33.663907527923584, 34.5941983631679, 34.374774251665386, 35.374015535627095, 35.18964508601597, 33.94425344467163, 32.041756766183035, 33.49876274381365, 33.37251744951521, 33.84335517883301, 32.405946595328196, 33.86838953835623, 32.442330837249756, 33.69631740025112, 30.93259150641305, 35.328265122004915, 37.87145171846662, 41.38373483930315, 42.85157305853707, 46.302173546382356, 43.56202636446272, 48.57915381022862, 45.38261420386178, 46.85126536233084, 40.233366761888774, 38.411184310913086, 39.64484739303589, 48.73623520987374, 43.65354108810425, 47.87507547651018, 46.74391222000122, 47.284165927342, 46.67223807743618, 46.53593179157802, 46.612431458064485, 40.351670265197754, 36.4017687525068, 37.27171100888933, 35.93886586597988, 34.933885369982036, 34.789890902382986, 35.664113249097554, 35.656661306108745, 36.14104107448033, 37.690489360264365, 35.84900481360299, 35.738511085510254, 35.259175709315706, 34.19939824513027, 34.0218266078404, 35.3172869682312, 33.66524853025164, 33.351426192692344, 33.914699281964985, 34.153321266174316, 34.28612565994263, 34.20615536825997, 34.56751728057861, 34.52807930537632, 34.792350564684185, 34.07504633494786, 33.94990927832467, 34.10280091421944, 36.81048958642142, 39.368746825626914, 44.079476084027974, 46.78292635508946, 48.265849113464355, 45.56926713671003, 46.24584797450474, 50.866882937295095, 49.75804424285889, 41.69328056062971, 36.455464431217735, 36.41920525687081, 41.81343923296247, 46.52285875592913, 49.74109411239624, 51.16331740788051, 50.35839639391218, 30.57359892981393, 13.638991611344473, 4.67248637335641, 4.095980439867292, 8.968822462218148, 2.3426461688109805, 0.13271847766424927, 0.03333331099046128, 6.720817923545837, 40.16429124559675, 48.199212414877756, 36.57640824999128, 28.14958609853472, 43.6216801234654, 52.84380177089146, 47.990141119275776, 20.769987753459386, 0.44514562508889605, 0.05773202569356986, 0.021362077112176588, 0.04445225399519716, 0.040590999581451924, 0.019182887260935137, 0.00631247234663793, 0.03562376022871051, 0.07933455865297999, 0.06834303095404591, 0.019741233371730362, 0.05420540100229638, 0.04925846341731293, 0.008551360556988843, 0.022229699484471763, 0.044239190606666465, 0.10079359502664634, 0.09714703927082674, 0.1782516786562545, 0.17383160654987606, 0.15752109033720835, 0.09754312730261258, 0.1401868819126061, 0.2190588153898716, 0.1344077991587775, 0.16505025061113493, 0.08681388052978686, 0.21223036465900286, 0.1024192427950246, 0.15287939512303897, 0.20185187299336704, 0.13102737840797218, 0.1309579914169652, 0.15920634062162467, 2.339564425604684, 29.662314891815186, 58.45159557887486, 58.27171713965279, 37.71942513329642, 27.081896373203822, 41.541622229984824, 54.63378974369594, 42.341877528599326, 11.107360737664358, 0.1967420700405325, 4.730265855789185, 30.660069261278423, 40.92333330426897, 14.977373600006104, 5.6132025463240485, 18.02071237564087, 25.88058236667088, 50.35414409637451, 49.625152996608186, 51.22215127944946, 46.671515464782715, 46.4294193812779, 42.960739680698936, 40.886000633239746, 35.2946149962289, 40.30148690087454, 45.42787824358259, 46.117695399693076, 47.47397334235055, 46.64065851484026, 49.602154459272114, 48.4582690511431, 45.60803461074829, 47.61354180744716, 45.84405102048601, 39.26340171269008, 33.22850561141968, 33.87474366596767, 34.17754963466099, 36.838949407849995, 37.471134730747764, 38.56144257954189, 33.044152532305034, 36.14436231340681, 35.22891977855137, 36.00484595979963, 36.13320350646973, 36.93492834908621, 37.39904022216797, 35.43086569649832, 34.15780980246407, 35.606196539742605, 34.875426701136995, 36.5823906489781, 33.53716196332659, 35.55300807952881, 33.7815648487636, 35.71753794806344, 32.71530818939209, 36.35527835573469, 40.353935377938406, 44.53447886875698, 44.43913221359253, 49.25499813897269, 44.53759166172573, 51.166673387799946, 47.41411461148943, 48.21436643600464, 43.761345863342285, 39.95852729252407, 42.913113253457205, 50.335984979357036, 43.714438574654714, 48.628107343401226, 47.833393233163015, 47.82053211757115, 46.84503630229405, 49.415240968976704, 47.92967094693865, 42.16067893164498, 37.651086126055034, 37.51319912501744, 38.02338450295584, 36.59609944479806, 36.07455028806414, 38.15952055794852, 37.734155314309255, 38.57885823931013, 40.910017081669395, 37.37627444948469, 36.77234745025635, 36.60073389325823, 36.33558716092791, 35.6425529888698, 38.46972288404192, 34.608490807669504, 35.03458908626011, 36.334280899592805, 37.571157523563926, 36.08996834073748, 36.00512388774327, 33.94016095570156, 36.41571726117815, 37.02296897343227, 36.32756893975394, 36.014802728380474, 36.330268314906526, 39.63189595086234, 42.24534967967442, 46.576561382838655, 48.09771660396031, 51.21459858758109, 45.32940837315151, 46.02825818743025, 51.028018610818044, 51.9953224999564, 43.95378317151751, 38.988166196005686, 39.21839475631714, 44.03704343523298, 48.88173048836844, 51.62782185418265, 53.225421156202046, 53.966477802821565, 32.11554316111973, 14.549661602292742, 5.5271934015410285, 9.445430670465742, 19.045717579977854, 4.475241780281067, 0.512254964028086, 0.11234821858150618, 8.200893657548086, 46.18138953617641, 56.530811241694856, 41.05622802461897, 33.10970878601074, 48.94907242911202, 58.91374111175537, 56.35611963272095, 25.40399500301906, 0.900165183203561, 0.14412940107285976, 0.09823504303182874, 0.16015965518142494, 0.09238862924809967, 0.08507258325283017, 0.13034819199570588, 0.21685839417789662, 0.19824298950178282, 0.11439571157097816, 0.17204890506608145, 0.13796389262591088, 0.1232518692101751, 0.11167054530233145, 0.11181639640458993, 0.11268925028187887], [0.021919739598940526, 0.04504624355052199, 0.06712434134845223, 0.07004618777760438, 0.05387941920863731, 0.028212982263149958, 0.006342557317111641, 0.03510530519166163, 0.03440183401107788, 0.07654985093644687, 0.04046172508969903, 0.05502993640090738, 0.04844284396884697, 0.04474666016176343, 0.06944302442882742, 0.02812977521015065, 0.05165069969370961, 0.012857660152284163, 0.5685902525271688, 15.34974319594247, 40.00295754841396, 44.89865132740566, 33.77934489931379, 24.316297939845494, 30.281229155404226, 45.62066990988595, 41.11409262248448, 11.905579345566885, 0.32126334256359507, 1.5986932090350559, 21.75302583830697, 14.741640329360962, 4.640431293419429, 1.3118600632463182, 4.702466547489166, 21.516866990498134, 37.9998196874346, 49.5807956968035, 44.39964212690081, 41.08547994068691, 39.22278949192592, 37.4708046913147, 34.326762199401855, 37.85249703271048, 42.16853387015206, 44.879901613507954, 44.7853296824864, 44.68887478964669, 46.427199431828086, 42.24120160511562, 39.4560717855181, 37.92970888955252, 36.63393586022513, 32.332712582179475, 30.05562114715576, 30.85250309535435, 31.82164478302002, 36.73958321980068, 40.30364431653704, 42.107862200055806, 39.61366040366036, 36.66029732567923, 33.78628267560686, 34.17452369417463, 35.86721951620919, 36.179475034986226, 38.268888677869526, 37.16507005691528, 35.41776834215437, 32.16144643511091, 32.44431802204677, 31.111188002995082, 31.56818492071969, 31.1742741721017, 31.491073812757218, 32.47713783809117, 31.18276834487915, 32.617349011557444, 30.63383286339896, 34.573933941977366, 36.74354716709682, 39.08203635896955, 38.80388607297625, 43.13499355316162, 41.91733912059239, 44.68789856774466, 41.03759643009731, 38.89063433238438, 44.536268029894146, 37.16414942060198, 47.18493522916521, 40.161036014556885, 40.43974215643746, 41.55565411703927, 46.93783296857561, 44.96689305986677, 46.34920242854527, 43.2759690284729, 39.647560664585654, 33.349223613739014, 33.92354781287057, 32.21126849310738, 33.29641383034842, 33.2081960269383, 33.48767689296177, 35.190367698669434, 37.47821494511196, 37.29686001368931, 37.77208205631801, 36.21748515537807, 34.01670578547886, 33.40322848728725, 32.82523911339896, 33.057315894535606, 33.273161683763774, 32.80992875780378, 33.082510062626426, 33.64657524653843, 34.055726868765696, 33.57640886306763, 32.96339014598301, 32.24816690172468, 32.87756599698748, 31.550995077405656, 32.393391200474326, 31.893673283713206, 34.69800097601754, 35.43713297162737, 41.05377878461565, 43.06157193865095, 44.92719800131661, 47.6773054259164, 44.09926455361502, 46.73188836233956, 48.23114633560181, 44.316444396972656, 38.09629542487008, 35.03187928880964, 38.559594358716694, 41.69916221073696, 46.493426186697825, 50.018924781254356, 48.78698137828282, 30.46468244280134, 12.677935889789037, 2.6040352284908295, 1.463780688388007, 3.2818702161312103, 1.177204191684723, 0.04066508882013815, 0.10915341108505215, 6.797070060457502, 39.55485085078648, 45.674393381391255, 34.0612576348441, 29.37273829323905, 36.02004861831665, 50.52982929774693, 44.10164778573172, 10.883684328624181, 0.1700836369501693, 0.03941460645624569, 0.07528980462146656, 0.01993029867298901, 0.029615142648773532, 0.022030437498220375, 0.04974872871701207, 0.08006993455014058, 0.014728940990088242, 0.0368842170573771, 0.02369432071489947, 0.07351381384900638, 0.020890513933928948, 0.05253077318359699, 0.03249672820259418, 0.03201862903577941, 0.04963125055655837, 0.023579141091821448, 0.0697186046413013, 0.021062709158286452, 0.033510293279375346, 0.02260549083751227, 0.05020858886252556, 0.06881098262965679, 0.04455881791987589, 0.042678119016012976, 0.04437375088621463, 0.0773730156943202, 0.02984349343127438, 0.07092839865280048, 0.028424763220495412, 0.00883845381239163, 0.07359747043145554, 0.055904846239302836, 1.0136454424687793, 18.569121531077794, 46.889873027801514, 50.57708747046334, 37.6486542565482, 26.647448096956524, 34.629738398960654, 49.835151876722065, 44.399176597595215, 12.778701271329608, 0.09528963786682912, 2.180328433002744, 22.743038177490234, 18.82570287159511, 6.282129509108407, 2.926975122519902, 7.780712638582502, 23.516733986990793, 39.98740400586809, 49.54249722617013, 47.26047257014683, 43.96099887575422, 41.390804631369456, 38.798859051295686, 38.071966307503835, 38.99344335283552, 43.23414087295532, 46.17228044782366, 46.866336005074636, 44.495544637952534, 48.67158569608416, 44.752395221165244, 40.66464492252895, 40.819009576525005, 38.65513208934239, 34.609727587018696, 32.61697033473423, 32.94294507162911, 32.814320019313264, 36.37858261380877, 42.31009299414498, 43.854284967694966, 41.0671888078962, 37.32144274030413, 35.75811890193394, 35.41811227798462, 36.07702384676252, 38.54153946467808, 39.8120835849217, 39.13766711098807, 36.42194284711565, 34.238864013126914, 32.98045492172241, 33.49533380780901, 32.39770950589861, 32.62173679896763, 32.4058632169451, 34.773906571524485, 32.63710274015154, 33.71690143857683, 32.653726305280415, 36.66429601396833, 38.37268781661987, 40.53596428462437, 42.14385734285627, 44.306967054094585, 45.00273881639753, 45.718090602329795, 43.04558760779244, 39.973830699920654, 44.57354858943394, 38.982350553785054, 47.793218748910085, 39.854592663901194, 42.04475866045271, 42.68508379799979, 45.514782837459016, 46.074210098811555, 48.17517859595162, 44.52773216792515, 40.92141212735857, 35.01847621372768, 34.358626638139995, 33.353802476610454, 34.69305385862078, 34.33013902391706, 34.80109487261091, 36.54104886736189, 39.51671566282, 39.62361369814192, 38.693187373025076, 38.14297342300415, 35.46935524259295, 35.575367382594514, 35.506357874189106, 34.26979739325387, 33.84180225644793, 32.925807339804514, 34.4236478805542, 33.783576352255686, 36.2351370538984, 35.08296939304897, 34.48952375139509, 33.75806951522827, 34.89921038491385, 33.4981096131461, 34.53767129353115, 34.41174214226859, 35.74748468399048, 37.51004811695644, 43.096476214272634, 44.61878136226109, 48.776423590523855, 48.481892926352366, 45.56851673126221, 47.900929723467144, 48.554532868521555, 46.34536354882376, 38.276886054447715, 36.83700738634382, 39.46612582887922, 45.147987433842246, 49.032402174813406, 51.161920819963726, 50.449546337127686, 33.30701330729893, 13.499727129936218, 5.0146061182022095, 3.014377598251615, 3.3386087715625763, 1.8450989127159119, 0.08702795154282025, 0.0915609590177025, 6.949602561337607, 42.660890170506065, 49.64648049218314, 39.31997741971697, 32.14620903560093, 42.14549016952515, 55.71278592518398, 49.83163956233433, 14.490926742553711, 0.19650399924388953, 0.06335228375558342, 0.01427324365691415, 0.036508746312132904, 0.023261060838454535, 0.02101014305039176, 0.06359294655599765, 0.022831724590754936, 0.0710508877943669, 0.0968698916424598, 0.008017888691808497, 0.04200308184538569, 0.03754200247515525, 0.031168434835438217, 0.05889679890658174, 0.056966929962592464, 0.13711110981447355, 0.13773598628384726, 0.16990853420325688, 0.1257142320807491, 0.1492304644946541, 0.1267499207918133, 0.14435742955122674, 0.1598352204476084, 0.12666244405720914, 0.23388578263776644, 0.12535694268132958, 0.1680628646697317, 0.16496912496430532, 0.20389593259564467, 0.14004232681223325, 0.19830658180373056, 0.1531199086457491, 0.11145511721926075, 1.3405935785600116, 21.197748388562882, 53.27044895717076, 55.787274088178364, 45.37899766649519, 34.37939827782767, 37.27203410012381, 54.121217659541536, 50.21061168398176, 14.914876290730067, 0.5912825262972287, 2.0983909325940266, 25.348591804504395, 18.564983878816875, 11.076092106955391, 3.638300644499915, 6.277647921017238, 25.229489258357457, 41.56218889781407, 54.39791577202933, 48.30487367085048, 45.05248097011021, 42.91138662610735, 42.62942525318691, 38.81701816831316, 42.201082706451416, 46.65330423627581, 49.34128434317452, 47.5876840863909, 45.164701325552805, 52.01874835150582, 47.18277086530413, 43.03010702133179, 43.19427905763899, 39.80551058905465, 35.94187443596976, 33.692874567849294, 34.42908137185233, 34.655516215733115, 39.0997542653765, 45.77617754255022, 45.66894251959664, 43.63507277624947, 38.97445740018572, 37.48993655613491, 37.70251669202532, 39.99641234534127, 40.80646807806832, 43.563370840890066, 41.09629828589303, 40.51230219432286, 36.26042849676949, 35.09792539051601, 34.70303494589669, 34.93430226189749, 34.56195177350725, 34.31975146702358, 36.696952547345845, 33.439838545663015, 36.57091222490583, 34.86676229749407, 38.486266544886995, 40.557072911943706, 43.61819560187203, 44.97595003673008, 46.41291046142578, 45.676081793648855, 47.32905823843819, 44.55138036182949, 43.685464586530415, 46.06552485057286, 41.331644194466726, 47.95223869596209, 42.70731108529227, 41.67639643805367, 43.42818668910435, 48.06050552640642, 47.48260300500052, 49.411054679325645, 46.306033270699636, 41.97768422535488, 35.81475019454956, 36.69371468680245, 35.031907081604004, 36.72877877099173, 36.8186537197658, 35.630497864314485, 38.978893824986045, 42.26786184310913, 42.219894954136436, 41.23991060256958, 41.18516574587141, 38.892722266060964, 36.43928555079869, 38.154364994594026, 36.75022438594273, 36.993532930101665, 36.393434388296946, 36.41392810004098, 36.612983567374094, 38.88691357203892, 37.5353673526219, 35.68480845860073, 35.260752950395855, 36.98855454581124, 36.35144642421177, 35.22485508237566, 35.53317444665091, 38.45787967954363, 39.59605366843087, 44.13842460087368, 47.890014103480745, 50.38903794969831, 50.03629527773176, 45.112725325993125, 47.38874673843384, 51.539152417864116, 48.51179797308785, 42.64586121695382, 37.3804155758449, 42.79055050441197, 46.86602333613804, 51.88200780323574, 54.71978759765625, 52.74294866834368, 34.74102422169277, 15.480155672345843, 6.530462035111018, 6.939827748707362, 10.176990866661072, 3.179999419621059, 0.6818649971059391, 0.40339091420173645, 8.29821446963719, 49.65595783506121, 57.2246653011867, 44.898911884852815, 41.03459480830601, 49.612420422690256, 64.71922506604875, 56.58156435830252, 18.772168738501414, 0.624762909752982, 0.1577518465263503, 0.15775757336190768, 0.09300647609468017, 0.12284786946007184, 0.08914270092334066, 0.1353812390672309, 0.2290971710213593, 0.14691341668367386, 0.13268399451460156, 0.0987046639035855, 0.1671636700630188, 0.18435896879860333, 0.13630720866577967, 0.16895462253264018, 0.13781374639698438], [0.02272683155855962, 0.01658684281366212, 0.05595795517521245, 0.09530138330800192, 0.005190564311176006, 0.02211228578484484, 0.08906158206186124, 0.027015096541228037, 0.026220489625952074, 0.0406340390576848, 0.042246367183646986, 0.02993401339543717, 0.05613923259079456, 0.01893859769084624, 0.030136685020157268, 0.02116106280923954, 0.03476108776937638, 0.02696183493493923, 0.2520266334925379, 8.946418864386422, 37.70720672607422, 48.84382111685616, 41.186003003801616, 14.788690056119647, 25.36032383782523, 40.47696713038853, 41.701277937207905, 19.382764271327428, 0.9119539963347572, 0.05610687325575522, 3.9377994877951483, 5.830967775412968, 5.909015587397984, 1.0891257865088326, 1.805579621876989, 11.941565803119115, 28.95384529658726, 44.95452526637486, 45.24928869519915, 44.32974672317505, 40.53478309086391, 39.09378923688616, 39.9117693901062, 43.59672219412667, 44.30954483577183, 48.48281008856637, 45.45651871817452, 48.41319261278425, 41.99513462611607, 39.45719391959054, 37.612843241010395, 33.05887923921858, 30.50616318838937, 30.687483378819056, 29.99092994417463, 32.01052461351667, 38.89801331928798, 42.99775273459298, 44.68092605045864, 45.59786939620972, 42.03282165527344, 41.67653540202549, 39.60758767809187, 38.76847457885742, 39.199936866760254, 42.509718213762554, 42.06225422450474, 41.30234364100865, 38.726837498801096, 34.78388071060181, 32.316634450639995, 32.24870538711548, 32.15343516213553, 31.50190952845982, 31.360426834651403, 32.12506219318935, 32.103901454380576, 32.52393395560128, 31.292383125850133, 32.32581649507795, 34.170486790793284, 34.798131465911865, 39.043036120278494, 41.12371587753296, 39.458625248500276, 43.35023137501308, 40.70049067905971, 45.376207964760916, 44.32936109815325, 35.2181396484375, 38.62636654717581, 39.13038192476545, 41.06802259172712, 44.85463796343122, 45.808173997061594, 44.70023162024361, 42.73148386819022, 41.673467772347585, 36.66473375047956, 33.365784645080566, 32.63107517787388, 33.1707695552281, 31.796975203922816, 33.49042837960379, 33.46350758416312, 34.926381315503804, 39.3895879473005, 42.30758816855294, 42.28253991263253, 38.53559875488281, 35.724027565547395, 33.97061838422503, 35.5395633152553, 37.29344497408186, 38.888066973005024, 39.490319456372944, 38.13007756641933, 34.73652873720442, 32.53404358455113, 32.69556140899658, 33.62981619153704, 32.05179343904768, 32.96038852419172, 32.56347962788173, 33.62073837007795, 31.49248777117048, 32.04964297158377, 34.97485889707293, 37.529499598911826, 42.59451750346592, 43.5265280178615, 49.64263119016375, 46.636159556252615, 47.06547137669155, 49.86382014410836, 47.20758983067104, 39.868638447352815, 34.512636934007915, 37.601264068058555, 39.97197205679757, 44.74016639164516, 49.04294259207589, 48.8559387751988, 30.753859519958496, 12.222561376435415, 5.586026838847569, 2.2910464576312473, 3.222101160458156, 2.5396675510065894, 0.0597928926082594, 0.11221825876938445, 8.304906453405108, 38.72642060688564, 41.560292039598735, 30.01177453994751, 29.491034848349436, 36.006572587149485, 46.27311270577567, 40.32688256672451, 10.500744785581317, 0.15043726616672107, 0.08487610665283032, 0.07813534300242152, 0.0520196463247495, 0.015313302133498448, 0.021545008456866657, 0.017229150847664902, 0.03336674241083009, 0.013823530154435762, 0.07470937219581433, 0.0536651039229972, 0.04894209307219301, 0.09119281984333481, 0.08584902408931937, 0.07199097770665373, 0.04080711977024164, 0.03648290769862277, 0.042450928528394015, 0.054057548221732886, 0.016839330783113837, 0.038412111678293774, 0.038161165679671934, 0.06482839597655193, 0.030151321020509516, 0.03484691905656031, 0.02062878940653588, 0.01767881091551057, 0.02012358446206365, 0.05138973512553743, 0.027596550162083337, 0.03624907435317125, 0.013061524302299534, 0.020478599072833146, 0.013305255777335592, 0.39039634434240206, 12.350035633359637, 42.910514627184185, 52.99775995526995, 44.98899180548531, 21.91935702732631, 28.191124166761124, 48.412834780556814, 47.44162252971104, 20.188730989183696, 1.0142245313950946, 0.14069947440709385, 6.397055753639766, 7.333326816558838, 4.484966218471527, 4.926985425608499, 4.407126418181828, 17.57862455504281, 30.877801486424037, 47.466913972582134, 46.360743386404856, 46.27845239639282, 43.59145545959473, 41.88029132570539, 40.33597775868007, 45.60313960484096, 46.55552223750523, 49.814543519701274, 45.649824551173616, 50.71156638009207, 45.241920130593435, 41.94520834514073, 40.0871592930385, 35.555697032383506, 33.25986977985927, 32.32237713677542, 33.31083829062325, 32.2373867716108, 38.913869108472554, 44.43944835662842, 46.766254152570454, 47.61546298435756, 44.59697791508266, 43.740730558122905, 40.52678918838501, 40.656532900674, 40.584976877485005, 44.15419006347656, 44.632066317967, 43.07696219852993, 40.93859502247402, 37.05534063066755, 34.03852660315377, 33.455204486846924, 33.635652678353445, 32.914975098201204, 33.08918380737305, 33.44157212121146, 32.770390033721924, 33.72024004799979, 33.09220279966082, 33.47186974116734, 36.67404433659145, 37.526772430964876, 40.26526941571917, 43.41605860846383, 42.219113281794954, 45.46117748532976, 42.91932494299752, 45.57764319011143, 45.543767247881206, 38.972154072352815, 38.63633026395525, 40.707515307835166, 42.11772864205496, 45.68793542044503, 47.78466551644461, 47.4459582056318, 44.628623485565186, 43.29518774577549, 39.50907611846924, 34.63071462086269, 33.56021956035069, 34.08964450018746, 33.25691679545811, 35.328772340502056, 35.383628368377686, 36.30536944525582, 41.74233831678118, 43.56143576758248, 44.25372648239136, 40.64016989299229, 37.636588709695, 35.250222955431255, 36.21471282414028, 38.1247170312064, 40.291179248264854, 40.7301664352417, 38.89441762651716, 36.049644470214844, 34.08035128457205, 34.079291684286936, 35.46033648082188, 34.58870581218174, 34.222865785871235, 34.45652328218733, 35.47919736589704, 34.39829042979649, 33.43367896761213, 36.673481532505576, 40.14221681867327, 44.83775731495449, 45.64469678061349, 50.897256987435476, 47.24009697777884, 47.73715720857893, 53.384197916303364, 48.60388592311314, 40.92437205995832, 36.92769180025373, 39.038783822740825, 43.42667893001011, 47.62218884059361, 53.047550746372764, 51.6383900642395, 30.665012904575892, 13.407098957470485, 5.813641139439174, 6.712668555123465, 5.450341548238482, 2.2858036075319563, 0.07530422349061285, 0.16222070530056953, 8.66826684134347, 43.115642820085796, 47.390997954777305, 35.529912267412456, 36.51074777330671, 41.393521377018516, 52.33638872419085, 46.00589541026524, 13.039551411356245, 0.2080861713205065, 0.06720904287483011, 0.01683069472866399, 0.02699683716387621, 0.07070749479212932, 0.008611638215370476, 0.05339221070919718, 0.022088820347562432, 0.033792085479944944, 0.02703599541980241, 0.021324706796024526, 0.05241443156929953, 0.017651326854580214, 0.04321441952405231, 0.02830306626856327, 0.04462964001244732, 0.06801039273185389, 0.10956733780247824, 0.1847537811845541, 0.11307993717491627, 0.16933632562203066, 0.1411387308367661, 0.19198011127965792, 0.12175477668642998, 0.12385724458311285, 0.0730799992701837, 0.2899037610207285, 0.14465768129697867, 0.16336327684777124, 0.21168902942112514, 0.1689973430974143, 0.10005676027919565, 0.1551167829228299, 0.06448270952595131, 0.6967436958636556, 14.233515092304774, 50.1667720249721, 60.197518076215474, 52.54103749138968, 24.76931527682713, 34.96637167249407, 48.89061376026699, 51.473130634852815, 25.35171675682068, 1.5087062205587114, 0.25750450098088806, 5.3504950659615655, 8.011718528611318, 13.48498044695173, 4.894678907735007, 3.108404964208603, 13.341701643807546, 31.84138114111764, 48.95410639899117, 48.40781818117414, 48.70649344580514, 45.94636671883719, 43.453978402274, 43.170599596840994, 49.05040495736258, 48.548606055123464, 51.545780999319895, 47.92926447732108, 53.88908181871687, 46.80845403671265, 44.10545539855957, 41.98702955245972, 36.66879497255598, 34.70708574567522, 33.987123829977854, 33.813168730054585, 34.84893321990967, 42.08110816138131, 47.524121965680806, 47.777672154562815, 50.76418856212071, 45.625564915793284, 46.240987709590364, 42.690534659794395, 43.70644119807652, 43.75079154968262, 46.199802262442454, 46.76262719290597, 45.615833963666645, 43.057159832545686, 38.97519390923636, 36.03911794934954, 34.682579449244905, 34.30185638155256, 33.95246621540615, 33.97653477532523, 34.62403392791748, 33.17771427971976, 36.48163482121059, 34.947594165802, 35.73897661481585, 39.36114549636841, 38.528577600206646, 42.933110169001985, 44.33614253997803, 43.03684677396502, 47.28649704796927, 44.365245069776265, 48.85656411307198, 46.85741799218314, 43.23092038290841, 42.307379722595215, 41.11519391196114, 43.240838936397004, 46.208206108638215, 49.6112322807312, 49.2424635887146, 45.424296447208945, 44.778902598789756, 40.00737312861851, 35.92553227288382, 34.83286551066807, 36.442971570151194, 36.26463910511562, 36.83801140104021, 36.32964645113264, 38.19899327414376, 44.173912525177, 46.268189907073975, 45.955958706992014, 42.73363433565412, 41.04619482585362, 36.699387890951975, 38.33675520760672, 40.195839541299, 41.75645705631801, 43.18675068446568, 41.98615755353655, 39.22723286492484, 35.60749237877982, 36.80151946204049, 37.89999839237758, 36.12495599474226, 36.313325132642476, 35.11760268892561, 37.670263154166086, 35.73174006598336, 35.55172266278948, 39.131601333618164, 42.35134792327881, 47.087590966905864, 48.294163022722515, 53.84479052679879, 48.28924717221941, 49.021305901663645, 53.593536717551096, 52.72983046940395, 44.4937242099217, 39.42243903023856, 42.10360990251814, 45.47731467655727, 49.21483755111694, 55.39174440928868, 53.21068402699062, 33.708455903189524, 15.669513191495623, 9.496402655329023, 9.067430428096227, 10.935953889574323, 4.670011077608381, 0.1720958596893719, 0.3377252263682229, 10.131352492741176, 48.53427539552961, 54.571054458618164, 42.50225584847586, 41.551947253090994, 48.28507477896554, 59.40519414629255, 53.02327721459525, 16.370840038572037, 0.42937579272048815, 0.16096055720533642, 0.20342065952718258, 0.09525138206247773, 0.1956380528530904, 0.10584604141435452, 0.12589890217142446, 0.11171537611101355, 0.1169077567756176, 0.15595310447471483, 0.11585019209555217, 0.13235973619988986, 0.1669270106192146, 0.23332653407539639, 0.1891027699623789, 0.13242993743291923], [0.009865587893208223, 0.000531448982656002, 0.06114915518888405, 0.04259182971769145, 0.04097867038633142, 0.052892344138984165, 0.03834578488022089, 0.03772546477349741, 0.07406311508800302, 0.0176699085360659, 0.026971212288896953, 0.04127333100352969, 0.011705388098822107, 0.021386787661218216, 0.017698152556217144, 0.06046552437224558, 0.048167742123561244, 0.03440768298293863, 0.09064570348709822, 5.345355570316315, 32.42125347682408, 48.437650271824424, 37.36816242762974, 28.09497673170907, 34.9082430430821, 38.60679694584438, 38.18360996246338, 28.986984729766846, 3.3093750945159366, 0.0059923861741221374, 0.3018018454313278, 2.967621215752193, 2.574233753340585, 7.73981727872576, 3.4465323175702776, 8.153200353894915, 13.324469242777143, 34.950647899082725, 48.64248316628592, 46.951802321842735, 43.44699546269008, 43.00804649080549, 43.383075509752544, 44.56194857188633, 45.203684193747385, 42.045734882354736, 43.6673332623073, 41.37777328491211, 41.13035140718733, 36.039319447108674, 31.46397236415318, 28.686956303460256, 30.65973574774606, 31.81596463067191, 33.627189772469656, 38.69108206885201, 40.66245971407209, 43.0543840272086, 45.062493324279785, 43.16889728818621, 44.760826860155376, 42.07131120136806, 41.82850292750767, 40.833743231637136, 41.94134862082345, 42.44037519182478, 45.07770640509469, 43.83964511326381, 42.00988565172468, 34.1907616342817, 31.61091981615339, 31.442568438393728, 32.119406359536306, 33.481941155024934, 32.151517459324424, 31.924575396946498, 31.96194280896868, 31.34597110748291, 31.802019596099854, 32.47491441454206, 32.7880071912493, 33.40704304831368, 34.59446586881365, 36.963527134486604, 38.77807698931013, 38.629559244428364, 43.51409421648298, 42.98242500850132, 46.58503818511963, 35.34286676134382, 39.22827509471348, 43.43505498341152, 45.00895050593785, 45.14331824438912, 43.07283844266619, 43.865686961582725, 42.07113402230399, 39.9638009752546, 35.01078803198678, 33.21361909593855, 31.835176399775914, 32.70660557065691, 33.09054912839617, 34.367211137499126, 34.07860728672573, 36.20796959740775, 44.06102861676897, 44.828957421439036, 45.3958192552839, 42.56451170785086, 40.05975559779576, 35.47418771471296, 39.14622729165213, 43.883866923195974, 43.637341363089426, 42.36853429249355, 44.03167942592076, 42.284690380096436, 39.96439504623413, 36.32903848375593, 34.719891275678364, 34.55012593950544, 33.115208285195486, 32.92575175421578, 32.65172869818551, 32.93340172086443, 32.76269142968314, 32.72418451309204, 33.63591323580061, 39.33089303970337, 44.23716197695051, 44.55362810407366, 49.40553780964443, 45.449344703129356, 47.30208880560738, 46.43236889157976, 42.47342429842268, 38.45361001150948, 37.50279072352818, 41.92614943640572, 46.153801713671, 51.89028310775757, 48.3591182572501, 29.14239161355155, 8.904225928442818, 2.2010601205485205, 3.7088936907904486, 1.471061966248921, 1.842218233006341, 0.2339877528803689, 0.07515157346746751, 9.048335909843445, 39.134474413735525, 46.4546274457659, 36.124396664755686, 26.751738820757183, 37.901200430733816, 46.456896032605854, 30.32914045878819, 7.767819387572152, 0.08218244476509945, 0.04445366874071104, 0.024030624722529734, 0.03740305207403643, 0.018728621636650393, 0.03517054633370467, 0.04521288496575185, 0.012511885492131114, 0.02712187759711274, 0.007862862947929119, 0.015083573924909745, 0.039308673569134304, 0.016679037062983428, 0.024171374937785522, 0.10355902556329966, 0.037263592771653614, 0.04796835121565631, 0.007215437063548181, 0.0027875624405818856, 0.012170719781092234, 0.043977150560489724, 0.015422483507011617, 0.03135593441714134, 0.048522812713469775, 0.05642195099166461, 0.008801611057216567, 0.04708842021812286, 0.06799478642642498, 0.04744863071079765, 0.03721959316836936, 0.023265211776431118, 0.014851884750117148, 0.037886318285018206, 0.022746583712952476, 0.0901436757828508, 7.324619855199542, 39.7881053515843, 54.1992633002145, 42.51580136162894, 24.667727402278356, 34.28438861029488, 42.88195753097534, 44.27358443396432, 31.02622890472412, 3.263239924396787, 0.09809987885611397, 0.34601735855851856, 3.176924407482147, 4.009887916701181, 8.719656586647034, 4.351895187582288, 9.922982096672058, 17.887939248766216, 39.189518042973106, 48.30575956617083, 49.14913885934012, 45.49082892281668, 45.52890157699585, 45.801253591264995, 46.47728899547032, 46.55661310468401, 42.57350615092686, 47.14069257463728, 44.90079484667097, 43.329473631722585, 39.37536498478481, 33.21404988425118, 30.912438256399973, 31.879919324602398, 34.689346994672505, 35.23464509419033, 39.89684118543352, 43.175008228846956, 44.628116267068044, 46.5758387701852, 45.26612418038504, 46.51159225191389, 44.29410941260201, 44.67813982282366, 43.39621802738735, 43.41294928959438, 45.1784657069615, 47.23793608801705, 44.0260374886649, 43.93130227497646, 36.5685533114842, 33.1002071244376, 33.23656552178519, 34.151931626456125, 34.12217944008963, 32.557820320129395, 32.46142101287842, 33.41769116265433, 33.19350406101772, 32.71666656221662, 32.78133692060198, 34.69893203462873, 34.97252777644566, 37.20000212533133, 37.91163662501744, 40.5068096433367, 41.31328010559082, 44.6620443207877, 44.900680201394216, 47.12311363220215, 38.57193783351353, 39.64159563609532, 44.222209453582764, 46.036050592150005, 46.46538325718471, 45.1594033241272, 45.90492418834141, 44.647289821079795, 41.43666969026838, 36.4750896181379, 35.08371979849679, 32.45210347856794, 35.32913712092808, 35.16419383457729, 35.66494703292847, 35.74025855745588, 37.48651109422956, 44.859863008771626, 47.31802797317505, 46.94756392070225, 42.86510814939226, 39.94232756750924, 38.306846686771934, 40.530721868787495, 45.4290212222508, 45.374637671879356, 45.5323999949864, 45.89583247048514, 43.929443631853374, 40.922099999019075, 38.13920055116926, 35.44926800046648, 36.47752843584333, 34.826959541865754, 34.4842848096575, 34.0854686328343, 35.33805513381958, 33.37630769184658, 34.95296164921352, 34.76895250592913, 41.98887429918562, 45.34468051365444, 47.639156341552734, 49.92718424115862, 47.000415393284385, 48.35951083047049, 48.670289857046946, 44.10226617540632, 39.74796560832432, 38.531554903302876, 44.36239283425467, 48.663154057094026, 53.71787125723702, 50.14576414653233, 30.394272872379847, 9.681032793862478, 4.169343428952353, 7.027717683996473, 5.5346575038773675, 1.512424266764096, 0.13004195557108947, 0.15548403321632318, 10.280813455581665, 44.72347681862967, 50.066620690482004, 35.639742442539756, 33.22835969924927, 43.04105738231114, 52.86278077534267, 37.65394530977522, 10.450678672109332, 0.14794116653501987, 0.018496537215209434, 0.09200417130653347, 0.04005701966317637, 0.030507511193198816, 0.006000453107325094, 0.032775083623294315, 0.02750033898545163, 0.041584059329969544, 0.04472405476761716, 0.0424593728967011, 0.02220738077137087, 0.04823123603793127, 0.03599137014576367, 0.05403124141905989, 0.022352208982088735, 0.09238020862851824, 0.10448161605745554, 0.1492681096174887, 0.116038336285523, 0.20724569713430746, 0.12621698581746646, 0.0909029021859169, 0.13631634174713067, 0.18341976776719093, 0.08243570117545979, 0.16641737653740815, 0.13372264163834707, 0.13567428477108479, 0.12930859492293426, 0.09087883454880544, 0.11331850330212287, 0.26338530970471247, 0.1789925303310156, 0.1955444828740188, 8.060811025755745, 46.362904276166645, 60.93552098955427, 48.77624988555908, 37.03261654717581, 43.144797461373464, 48.313871588025776, 48.42876352582659, 37.403768471309114, 4.725690467017038, 0.1454072589320796, 0.741142142031874, 6.5600244488034924, 10.015101313591003, 8.679327504975454, 7.22125324181148, 10.82408354963575, 14.785356657845632, 38.92744588851929, 51.84753084182739, 50.67939622061593, 48.566306591033936, 47.32662636893136, 47.96870592662266, 48.12379666737148, 49.64922850472586, 44.5841828073774, 48.70725079945156, 45.61714022500174, 44.337177821568076, 40.75506183079311, 35.23171642848423, 32.81478207451956, 34.84377418245588, 36.505734648023335, 37.49745103291103, 44.12608460017613, 44.695055212293354, 46.869414057050435, 49.0445476259504, 46.91487264633179, 48.322476931980674, 45.969490323747905, 46.37035969325474, 46.437548773629324, 45.40065172740391, 46.89194359098162, 50.04106174196516, 46.60854741505214, 45.522491863795686, 37.66365194320679, 34.40181316648211, 35.84874078205654, 35.303380148751394, 36.19691848754883, 34.90858350481306, 34.883799280439106, 35.720025403159006, 35.28160449436733, 34.538765634809224, 35.30658674240112, 36.67349542890276, 36.68666573933193, 39.105215549468994, 39.60637174333845, 40.885861669267925, 42.83783646992275, 46.97578402927944, 48.35384110042027, 49.29608283724104, 41.69996820177351, 41.71921123777117, 45.912344864436555, 48.629100935799734, 48.20352029800415, 47.607573304857524, 47.3979218346732, 45.51142685753958, 43.136421407972065, 36.788241454533164, 36.23969854627337, 35.11388192858015, 36.96232509613037, 36.81218842097691, 37.34262432370867, 38.210325786045615, 39.14660596847534, 47.955917767116, 49.055004664829795, 48.82338299070086, 43.6622610773359, 42.75165101460048, 40.469699314662385, 42.45993437085833, 47.88981260572161, 47.104391711098806, 47.273107869284495, 48.07590968268258, 47.06865017754691, 44.709632532937185, 40.92657811301095, 38.90664298193795, 39.174565519605366, 37.5616523878915, 36.162691661289756, 36.07464061464582, 37.212046827588765, 35.41026428767613, 36.331623213631765, 36.33767856870379, 43.53968790599278, 47.82970026561192, 48.433630738939556, 53.18069560187203, 47.32741846357073, 48.78196477890015, 51.356320994240896, 47.235076904296875, 42.12871374402727, 41.38860552651541, 46.87990583692278, 52.0070093699864, 56.61866773877825, 53.39666645867484, 31.425555774143763, 11.25405284336635, 4.800894728728703, 9.74323306764875, 6.530029075486319, 4.618507555552891, 0.8802965379187039, 0.21664788547371114, 11.551199504307338, 50.66497870853969, 58.45591041019985, 46.96897826875959, 38.4219331741333, 48.32995319366455, 60.75486782618931, 43.90827941894531, 12.890348400388445, 0.58373254856893, 0.1317146122455597, 0.10684975076998983, 0.15688714863998549, 0.10832596477121115, 0.06355425648923431, 0.1734294659857239, 0.11769898289016315, 0.16149912402033806, 0.090855058681752, 0.2031676202480282, 0.11665813731295721, 0.15214714727231435, 0.15829909858959063, 0.18309092255575315, 0.1110694854121123], [0.07642626256815024, 0.022097695585606352, 0.08297748424644981, 0.039884003411446295, 0.009437936108692415, 0.0175208547485194, 0.046486943028867245, 0.0665649910058294, 0.0019609208268645617, 0.02830722399189004, 0.0469022437797061, 0.0629640192325626, 0.05133694510108658, 0.030765968574477092, 0.02088577945583633, 0.013362301912690912, 0.017132273010377373, 0.030870384935821806, 0.03677881003490516, 2.1852792416300093, 22.924132551465714, 43.29803303309849, 42.05176591873169, 33.863862786974224, 28.16879960468837, 36.700621196201865, 37.27025188718523, 31.691828114645823, 6.46312096289226, 0.0025015260034706444, 0.08390755898186139, 1.9170611883912767, 3.2660502535956244, 10.107834577560425, 3.089126101561955, 3.7662167634282793, 7.476651651518686, 19.839745555605205, 40.47474023274013, 46.97861542020525, 47.2904714175633, 46.070968764168875, 46.860374450683594, 46.30057198660714, 45.126962184906006, 46.28755801064627, 41.999598843710764, 39.68597725459507, 36.2925569670541, 31.486091954367502, 32.20999697276524, 30.298078536987305, 34.35337380000523, 35.290081296648296, 38.82955619267055, 40.05509335654122, 42.89587824685233, 42.05889477048601, 42.34968730381557, 43.312794481004985, 46.110260827200754, 43.65970761435372, 45.258547169821604, 43.954992158072336, 44.11193459374564, 44.498049463544575, 46.09832034792219, 44.45332738331386, 43.631654262542725, 37.767096723829, 32.15547098432268, 32.95557689666748, 30.867813450949534, 35.70693152291434, 33.674128328050884, 31.596797602517263, 31.76626069205148, 33.40110233851841, 32.33911187308175, 33.96815872192383, 32.12338072913033, 32.62604815619332, 32.22863898958479, 35.047745500292095, 37.16647359303066, 37.46881055831909, 39.89871025085449, 42.05839797428676, 45.285481861659456, 37.97296142578125, 38.718774114336284, 45.89289338248116, 43.994881766183035, 43.69736337661743, 43.179534980228965, 42.51625994273594, 39.65764250074114, 36.41409485680716, 34.9123980658395, 32.917017868586946, 33.45924833842686, 33.3599134172712, 33.1273398399353, 34.72196183885847, 32.739519187382285, 36.55886057444981, 44.35910981042044, 45.82036113739014, 46.24970422472273, 43.36249494552612, 43.74046652657645, 41.06981175286429, 42.75643832342965, 44.35423564910889, 46.09533609662737, 45.15798241751534, 46.02728196552822, 43.629090377262656, 43.11346108572823, 42.84688302448818, 40.96573468617031, 41.08311407906668, 39.79843732288906, 40.088302271706716, 36.8795234135219, 32.40359115600586, 31.768772465842112, 32.47958012989589, 32.42370271682739, 34.965937410082134, 41.12544597898211, 45.1289632661002, 46.54530838557652, 48.72990887505667, 46.363870075770784, 50.995132786887034, 45.14436742237636, 44.21028981889997, 38.51072767802647, 40.43323169435774, 46.46394498007638, 50.605495180402485, 47.90732554027012, 28.623316015516007, 7.045142463275364, 4.913699601377759, 7.624125429562159, 5.643231792109353, 0.9331775946276528, 0.016790656073551093, 0.19700360457812036, 8.917768836021423, 39.616759300231934, 42.38266345432827, 31.304181167057582, 22.207729850496563, 34.45192357472011, 46.84201383590698, 31.940139361790248, 7.69499705518995, 0.10623809894812958, 0.021233728820724145, 0.027830364847821847, 0.03303531537364636, 0.011482725136115082, 0.019506528108779873, 0.030616802828652517, 0.02654450197171952, 0.03270060083429728, 0.010806474235973187, 0.09414665919861623, 0.020530856447294354, 0.028487997595220804, 0.06429222439016614, 0.05232540777485285, 0.01384271149124418, 0.0065820856917915595, 0.02803070400841534, 0.012005856127611228, 0.011442258155771663, 0.009736540710686572, 0.004256888251152954, 0.014466697383405907, 0.028293388662859797, 0.013729200216143258, 0.056532603089830706, 0.058410574282918654, 0.05798228297914777, 0.04979580547660589, 0.055427673272788525, 0.03798798657953739, 0.040080775174179246, 0.03947886032983661, 0.017034226396520222, 0.0738821430131793, 2.726452499628067, 28.75689513342721, 50.07029628753662, 46.81241798400879, 39.34169054031372, 30.65661253247942, 40.95126853670393, 43.47373907906668, 34.54480709348406, 6.654124336583274, 0.042468723109258075, 0.19285311443465097, 1.2533506942646844, 4.5524232387542725, 5.261422199862344, 4.309708331312452, 5.627791157790592, 7.555295705795288, 25.015753984451294, 42.457214151109966, 48.456406933920725, 48.63601439339774, 48.06810685566494, 46.57067625863211, 47.979857785361155, 46.032885687691824, 49.8327443259103, 43.07439136505127, 42.33107655388968, 38.655628885541645, 33.213848386492046, 32.136564935956685, 32.684399127960205, 34.02203157969883, 36.03936113630022, 39.765846797398154, 42.64179304667881, 44.95009578977312, 43.267516544886995, 44.64519146510533, 44.80068867547171, 46.793789863586426, 45.824165276118684, 46.703216620853965, 45.631672382354736, 45.521797043936594, 47.64198773247855, 48.105835574013845, 46.166794845036094, 44.87892539160592, 40.06790583474295, 34.05421910967146, 33.35129417691912, 32.66930764062064, 36.318505014692036, 37.10826505933489, 34.45889956610543, 34.076984882354736, 32.93904365812029, 33.92672661372593, 34.71330438341413, 33.813811438424246, 34.683687686920166, 34.23001548222133, 36.231583050319124, 39.01785932268415, 40.973905767713276, 41.46264900479998, 42.87544706889561, 46.00143814086914, 37.72687012808663, 39.50512259347098, 46.86499847684588, 46.19848557880947, 45.62167739868164, 44.81169809613909, 44.8755589893886, 41.461231572287424, 39.12130062920706, 35.57826478140694, 35.999815464019775, 35.35375458853585, 34.43626928329468, 35.11081082480294, 35.70346089771816, 34.55579219545637, 37.76116991043091, 47.83475508008684, 47.46999202455793, 47.89139679500035, 45.686809812273296, 45.42684643609183, 42.3420547076634, 44.70206594467163, 45.8994768006461, 46.37863152367728, 47.368874890463694, 47.405748980385916, 46.992699418749126, 44.94796616690499, 44.73579250063215, 43.71726996558053, 41.365172726767405, 39.85665280478341, 40.7021860395159, 37.15935863767351, 33.93364354542324, 33.535536084856304, 33.744461468287874, 34.66987466812134, 37.272895676749094, 44.008086817605154, 48.516355991363525, 48.96335097721645, 50.41822733197893, 46.82050221306937, 51.81090341295515, 47.4496476990836, 45.692521231515066, 40.30250481196812, 43.06688036237444, 49.49300520760672, 53.12190689359392, 51.75809015546526, 29.833344800131663, 8.40314269065857, 3.9977433340890065, 11.89023424897875, 5.769960420472281, 1.721514018518584, 0.20280195772647858, 0.02047318436338433, 10.019429172788348, 44.783686433519634, 50.61470849173409, 36.49571534565517, 27.831184898103984, 39.74755913870675, 54.07814925057547, 36.51234585898263, 9.418728743280683, 0.06539970210620336, 0.011561984811643404, 0.07545470898704869, 0.08367378331188645, 0.018814262934029102, 0.017089908676488057, 0.0686884324199387, 0.05556487983890942, 0.01763724725294326, 0.046039418649992774, 0.03099643638623612, 0.04505729688597577, 0.03707054955884814, 0.06407248760972704, 0.03426654091370957, 0.03787420643493533, 0.14182577468454838, 0.1613367370196751, 0.17399657198360988, 0.13657252942877157, 0.07330086920410395, 0.08840005791613034, 0.13844154056693825, 0.11887723180864539, 0.09798504358955792, 0.15634514843778952, 0.1478399969637394, 0.1584812852420977, 0.09799679581608091, 0.13306720395173344, 0.04370178747922182, 0.16948005290968077, 0.19317547285131045, 0.1464237586728164, 0.15222777080323013, 3.2432132618767873, 33.337887627737864, 55.74349001475743, 52.447511264256065, 43.8502584866115, 37.04561315264021, 46.246178013937815, 48.38445833751133, 39.803665842328755, 8.90110445022583, 0.41698387052331654, 0.4967920737607138, 5.9654388683182855, 8.07851937838963, 18.336712973458425, 9.09068865435464, 6.38864756481988, 8.632276041167122, 22.384714365005493, 44.593034812382285, 49.949269090379985, 52.970891271318706, 49.00613798413958, 48.987673146384104, 49.915243761880056, 48.10911512374878, 50.275820527757915, 46.05175699506487, 44.10784905297415, 40.81379495348249, 33.90875857216971, 35.29313850402832, 34.69243894304548, 38.19542537416731, 39.22900812966483, 42.72629356384277, 44.573861258370535, 46.475544997623985, 44.287647587912424, 44.65245233263288, 44.59449740818569, 48.67573029654366, 46.90629162107195, 50.30069160461426, 47.19030966077532, 48.000514779772075, 49.21938862119402, 49.66391352244786, 47.32639707837786, 46.731165749686106, 43.3246237891061, 34.5968074117388, 34.737640448978965, 33.66341420582363, 37.545553411756245, 38.35943412780762, 35.33704764502389, 35.556169509887695, 34.85761846814837, 35.915175982883994, 37.44792079925537, 36.730053765433176, 36.200816426958355, 35.396149022238596, 38.554747990199495, 41.310917718069895, 42.96435621806553, 42.05203342437744, 43.51347582680838, 48.30561365400042, 41.78796713692801, 41.39547382082258, 47.81945514678955, 48.36009100505284, 46.92043815340315, 47.03041424070086, 46.22896037782942, 43.65077917916434, 40.00656018938337, 36.233188084193635, 37.729489598955425, 37.47169753483364, 35.84841421672276, 36.81338003703526, 37.73005240304129, 36.91819708687918, 39.96699367250715, 49.00522082192557, 49.07000582558768, 50.05907842091152, 48.10596758978707, 48.54553147724697, 44.33548246111189, 48.05547503062657, 48.6142943246024, 49.68462610244751, 48.137925829206196, 51.11825834001814, 47.800688062395366, 46.226462500435964, 45.9972379548209, 45.71056917735508, 44.225898947034565, 42.916080134255544, 45.01332439695086, 40.068767411368235, 35.795409883771626, 35.23722634996687, 36.460814544132774, 36.98089068276541, 38.89149938310896, 45.90527507237026, 50.558844975062776, 52.015718936920166, 51.93688120160784, 46.54629155567714, 53.65844678878784, 50.87784719467163, 48.9686142376491, 42.35878944396973, 45.76351792471749, 51.09654521942139, 55.58250372750418, 51.84218420301165, 33.147468771253315, 8.93222803728921, 8.751706889697484, 20.00642762865339, 16.368981395448955, 3.5539052188396454, 0.43454780376383234, 0.517969368823937, 11.745319145066397, 51.75903511047363, 53.681514808109824, 43.51800605228969, 33.67008100237165, 47.035121645246235, 61.80912494659424, 44.30923911503383, 11.654824938092913, 0.16635693263794693, 0.08903988251196486, 0.13560165438268865, 0.13410175272396632, 0.10631819322173085, 0.14394087690327848, 0.20158644366477216, 0.14080167535160268, 0.12598902519260133, 0.070242365822196, 0.16042517950492247, 0.1228287076311452, 0.08858300452785832, 0.173050585602011, 0.11054749520761625, 0.13923995915268148], [0.038080915343016386, 0.028926836725856577, 0.03530827537178993, 0.010908479253495378, 0.03347822232171893, 0.04633166368252464, 0.022133439114051204, 0.05721058510243893, 0.021618938239823495, 0.0878099835078631, 0.049013719228761535, 0.01767248527279922, 0.0412712139742715, 0.03228106941761715, 0.025264506727190952, 0.0637900202668139, 0.011752853319714112, 0.0415973314749343, 0.04803635399522526, 0.46640423578875406, 15.60846631867545, 43.01367800576346, 43.443104471479145, 30.984369482312882, 20.417826993124827, 24.441914422171457, 33.79016671861921, 37.80053492954799, 10.628178221838814, 0.0721951217523643, 0.03315826591902545, 0.4240899235010147, 2.54323154262134, 6.575211473873683, 3.151025648627962, 1.4456229827233722, 2.0581530460289548, 11.282510927745275, 23.328515972409928, 43.513239588056294, 45.46242816107613, 46.77027715955462, 47.54468515941075, 46.99033008302961, 47.338459151131765, 41.74466943740845, 40.18691110610962, 37.49106911250523, 32.13650587626866, 31.408654281071254, 32.69457823889596, 35.95634405953543, 38.298255239214214, 40.025410652160645, 43.130015168871196, 43.04882894243513, 46.136973176683696, 43.27786936078753, 44.699185916355674, 44.752318790980745, 44.83763919557844, 43.084146635872976, 44.13555152075631, 43.72687932423183, 46.91934381212507, 43.6524259022304, 44.550588267190115, 44.4688218661717, 41.63465166091919, 40.389023780822754, 33.81750093187605, 32.613027232033865, 31.914208684648784, 32.20452526637486, 34.06665985924857, 32.12704242978777, 32.36956582750593, 32.88233593532017, 30.99920388630458, 31.22307484490531, 31.565454278673442, 32.02277428763253, 33.89918048041207, 33.54765721729824, 34.523611613682334, 36.002747603825156, 39.021170139312744, 42.20371607371739, 45.84607989447457, 39.52197197505406, 42.82228640147618, 45.97568464279175, 44.5740453856332, 42.70641476767403, 41.110180786677766, 39.994435582842144, 38.42997223990304, 35.21754557745797, 32.5916337285723, 32.30992596490042, 32.96265016283308, 32.341842515128, 33.08142614364624, 33.66842038290841, 33.695841448647634, 36.728379249572754, 45.56591463088989, 45.34582001822335, 47.052099568503245, 44.63500540597098, 43.15618903296334, 42.55217865535191, 43.63900893075125, 45.626791272844585, 45.10458551134382, 42.29596035821097, 48.4993884904044, 46.39864233561924, 45.07276276179722, 46.12382023675101, 44.666473797389436, 43.978126185280935, 44.45028754643032, 43.68743092673165, 43.462378774370464, 42.75365209579468, 36.032941000802175, 33.17240585599627, 33.26449728012085, 32.3907230922154, 36.118025166647776, 43.93245915004185, 44.37779351643154, 48.86664942332676, 46.27187245232718, 41.919962065560476, 51.15163401194981, 47.969181878226145, 42.98253617967878, 42.80188996451241, 46.601293495723176, 51.67870003836495, 44.53735889707293, 25.88696081297738, 5.948249459266663, 2.0524689853191376, 5.994831485407693, 2.350685017449515, 1.1604400340999876, 0.14029372403664248, 0.34526160625474794, 9.481018475123815, 39.203539507729666, 40.892465932028635, 32.36848538262503, 24.249442373003276, 39.61843729019165, 46.8831958089556, 33.1812960760934, 4.108787272657667, 0.015047893160954118, 0.10283599221812827, 0.030731332754450183, 0.02315835438535682, 0.017435096403849975, 0.028096774659518684, 0.03656876612720745, 0.021141527786052654, 0.037722584392343245, 0.05158029150749956, 0.029899988256927048, 0.011772617348469794, 0.042039475071110895, 0.04114094203604119, 0.01330295215094728, 0.012815576562258815, 0.04657029766323311, 0.0470961792660611, 0.03679497952439955, 0.051784706967217584, 0.06335463827209813, 0.05119291586535318, 0.029932079570634023, 0.08615029363759927, 0.023246333235874772, 0.09643384468342577, 0.05509202235511371, 0.036216518242976496, 0.009211492857762744, 0.0365673853084445, 0.04343634457992656, 0.09830812803868737, 0.03535399506134646, 0.05677766279716577, 0.04583023987444384, 0.8470636840377535, 20.33792097227914, 47.93104669025966, 48.270837920052664, 34.61478240149361, 23.926458835601807, 31.497097900935582, 40.50783450262887, 41.655107157570974, 11.389157959393092, 0.3538816879902567, 0.13234906962939672, 0.44203972603593555, 3.32424749646868, 6.384700553757804, 4.952055394649506, 4.569166660308838, 4.355631581374577, 15.56899881362915, 29.02896921975272, 44.90549530301775, 46.39576925550188, 47.53899111066546, 48.550006117139546, 49.33757053102766, 48.63061216899327, 43.0354779788426, 42.960149083818706, 38.456340653555735, 34.66080379486084, 33.750072138650076, 34.00970547539847, 36.3106917653765, 41.4051422391619, 42.98799398967198, 45.28216757093157, 45.15412269319807, 46.94770288467407, 45.47234671456473, 45.519163676670615, 45.733765738351, 44.766503538404194, 44.01802274159023, 44.75452831813267, 46.30519601276943, 47.960743291037424, 44.19340222222464, 45.27705717086792, 45.52784892490932, 44.21619231360299, 41.37623078482491, 33.50621816090175, 32.98812573296683, 34.11157301494053, 34.05250290461949, 34.99988283429827, 32.86388846806118, 33.350536823272705, 33.84039524623326, 32.66000747680664, 32.539133140019004, 34.3135849407741, 33.242325578417095, 35.52423906326294, 35.6404025214059, 36.96778638022286, 37.90745380946568, 41.377543994358604, 44.09415762765067, 47.39862012863159, 41.2750163759504, 44.76715666907174, 47.40710735321045, 44.998024463653564, 44.74702773775373, 43.04655340739659, 41.15346458980015, 40.42104802812849, 38.61465188435146, 34.707561697278706, 33.658324650355745, 34.675471442086355, 33.73523078645979, 34.15896667752947, 34.887586048671174, 35.33420235770089, 38.18332161222185, 47.35470403943743, 46.61810466221401, 49.65669781821114, 47.69087873186384, 46.67283909661429, 44.80426352364676, 46.13304397038051, 48.14577381951468, 48.44857284000942, 44.23504277638027, 50.5590568951198, 49.040649686540874, 47.47870853969029, 47.220721926007954, 46.191672870091026, 45.52336733681815, 46.7553003174918, 45.87688473292759, 46.168941838400706, 43.87852723257882, 37.50706039156233, 33.768832274845664, 34.68866607121059, 33.68965755190168, 40.425682476588655, 46.886169637952534, 46.650736876896445, 51.201598508017405, 47.12363822119576, 43.23164994376046, 52.41046346936907, 50.03378002984183, 44.84814487184797, 44.04519019808088, 48.05779225485665, 54.07669012887137, 48.665589400700156, 27.991250549043926, 7.027753293514252, 4.157641359737941, 5.312746371541705, 5.516395900930677, 1.1170996682984489, 0.1329505502113274, 0.20271040978176252, 10.261183057512556, 43.60963889530727, 43.788992745535715, 35.06516810825893, 24.263210228511266, 44.29225076947893, 53.03600631441389, 38.753779138837544, 5.851513598646436, 0.02426291779348893, 0.06702895289553062, 0.05960112504128899, 0.015196456706949642, 0.0306027537610914, 0.03494358315531697, 0.07703467099262135, 0.017310356222359196, 0.055535407670374425, 0.03634000483102032, 0.03002855707226055, 0.054042810441127846, 0.04456691284264837, 0.050420346071145365, 0.09366477041372231, 0.028929055535367558, 0.11367582662829331, 0.16234636998602323, 0.1072951682976314, 0.13452525357050554, 0.2206843274512461, 0.15244163147040776, 0.1111621665103095, 0.23862681537866592, 0.1087156677884715, 0.11794799167130675, 0.0795121176966599, 0.1427364365330764, 0.15807676980538027, 0.14776982287211077, 0.17904316261410713, 0.17931938064949854, 0.10254547066454377, 0.11921245524925844, 0.13007202824311598, 1.0436159542628696, 23.6619530745915, 55.27264533724104, 53.54461097717285, 43.36698695591518, 31.81528718130929, 35.966533592769075, 44.44642087391445, 48.65077236720494, 13.828376054763794, 0.41485166922211647, 0.32867023082716124, 2.588039606809616, 8.342482311385018, 13.921520130974905, 7.4076586450849256, 3.5092237421444485, 4.16510763338634, 14.894188029425484, 27.239559684480938, 46.568852356501985, 47.530201639447895, 49.42650747299194, 48.94400371823992, 51.575571400778635, 50.51008251735142, 45.769406523023335, 44.33802202769688, 40.66937664576939, 36.568289279937744, 35.52881097793579, 35.46421357563564, 39.19389540808541, 43.879913398197715, 45.27112340927124, 46.911714690072195, 46.93440055847168, 49.339891229357036, 45.841118880680625, 46.0593444279262, 48.22998946053641, 46.17411477225167, 45.40571696417672, 46.379864828927175, 48.00097336087908, 49.885838985443115, 44.667741843632285, 46.7410843031747, 46.65588896615164, 46.72678491047451, 44.17907156263079, 36.389581612178254, 35.20557035718645, 35.57987676348005, 35.703801359449116, 37.357472624097554, 34.73027188437325, 35.06178433554513, 36.56164680208479, 34.34539379392351, 34.90382398877825, 35.277414730616975, 36.15978384017944, 37.88696704592024, 37.404508454459055, 37.56604017530169, 40.159767968314036, 43.525586536952424, 45.66966165815081, 49.25242383139474, 45.31502560206822, 44.74680192129952, 49.74524218695504, 46.879773821149556, 47.98684072494507, 45.95428419113159, 43.54040357044765, 42.77957582473755, 39.10206454140799, 35.785529545375276, 34.97312184742519, 37.24426909855434, 36.077934060777935, 35.983959674835205, 37.29996238436018, 37.70760972159249, 40.340101514543804, 49.90012795584542, 48.476782526288716, 51.302802494594026, 48.67692886080061, 48.76487568446568, 46.5354836327689, 47.67964349474226, 51.45227909088135, 48.29775871549334, 45.715672629220144, 52.0762551171439, 50.4136380468096, 48.066783223833355, 50.773516518729075, 48.763010093144004, 48.57933446339199, 48.67519875935146, 47.65921926498413, 48.07334579740252, 47.41998583929879, 40.719639914376394, 36.840578760419575, 37.0162570135934, 36.59019695009504, 40.92599099023001, 49.456933634621755, 48.642976488385884, 53.06575502668108, 48.342810835157124, 44.348565919058665, 54.25139216014317, 52.661112785339355, 48.164172649383545, 48.101239340645925, 51.391694273267476, 57.03183194569179, 48.376099654606406, 29.316239016396658, 8.458638821329389, 7.8239582266126355, 17.391839606421335, 9.92640061037881, 2.917308224099023, 0.20944770611822605, 0.6121017177190099, 13.068601829665047, 50.073627948760986, 51.552006585257395, 44.071749687194824, 34.13221263885498, 54.025655610220774, 60.84372138977051, 44.15310614449637, 6.848741207803998, 0.18682502289967878, 0.16662555108112947, 0.15596032408731325, 0.08453396215502705, 0.20264422547604355, 0.11125138029456139, 0.11269547923335008, 0.14414728725595133, 0.08804044792694704, 0.13843708937721594, 0.08985723222472838, 0.07861954559172903, 0.20446639055652277, 0.1793956072734935, 0.14531410964471952, 0.10303149172770125], [0.007858194627000816, 0.03854130135316934, 0.03445044086713876, 0.033478381777448316, 0.06649007395442043, 0.020484030745657425, 0.035780515388718674, 0.05474936217069626, 0.034370896206902604, 0.05862965966973986, 0.005948210575817419, 0.04424681734027607, 0.004731096019635775, 0.057065283613545556, 0.035063975623675754, 0.020500995817461183, 0.022420810568811636, 0.026812027973522033, 0.0264626299363694, 0.15970867366663047, 10.400507467133657, 39.40604475566319, 43.641353947775706, 33.7723445892334, 16.47071691921779, 29.363761220659526, 33.35850640705654, 39.08598640986851, 13.509511930601937, 0.584887252322265, 0.06609697147671666, 0.18051314087850706, 3.1285684193883623, 1.415011499609266, 3.325366807835443, 6.114982775279453, 1.266399628349713, 6.644772061279841, 18.099987847464426, 35.07555219105312, 46.54675361088344, 48.77616650717599, 45.61123078210013, 46.4268867628915, 42.34270436423165, 42.10870293208531, 36.8601587840489, 32.4155455316816, 32.734401839120046, 32.66817161015102, 36.72620793751308, 41.73099190848214, 41.90127835954939, 44.13074336733137, 44.39929819107056, 46.283771242414204, 46.4210398537772, 44.803092752184185, 43.007379463740754, 44.36147219794137, 45.125134808676584, 45.23460367747715, 44.35930783408028, 45.86551400593349, 44.708802223205566, 46.21257305145264, 46.01626559666225, 44.68931600025722, 43.6325922693525, 44.337650299072266, 36.86541857038225, 31.47680221285139, 33.31047698429653, 33.210600103650776, 32.429535729544504, 31.642843314579554, 32.24418558393206, 31.85021230152675, 34.77391699382237, 35.24328865323748, 32.80440146582467, 30.441371236528667, 32.7972274507795, 33.17912823813302, 34.45989663260323, 34.46303374426705, 41.23784351348877, 43.802437509809224, 46.07226807730538, 39.05019276482718, 42.69161857877459, 46.87440633773804, 43.12636389051165, 42.63935770307268, 42.67489079066685, 40.82818119866507, 37.07769993373326, 36.079983779362266, 33.68738201686314, 32.05628892353603, 31.51981156212943, 32.61263118471418, 32.92559889384678, 33.32610695702689, 33.98298270361764, 34.70055443899972, 43.200424739292686, 45.10832364218575, 46.50744070325579, 47.568197863442556, 45.66501678739275, 45.267774377550396, 44.257916246141704, 46.51981891904558, 45.02287469591413, 41.86118030548096, 44.01808180127825, 47.1876346043178, 45.6209374155317, 45.44217068808419, 45.86139025006975, 46.295784677777974, 48.192205156598774, 47.30135577065604, 46.73267003468105, 43.609246322086875, 42.999868461063926, 40.52173089981079, 35.83562953131539, 33.489334038325715, 33.49924564361572, 39.77141577856881, 44.97254194532122, 46.94920022147042, 49.925113677978516, 40.130370140075684, 50.23946755273001, 50.62064572743007, 46.5838291985648, 46.26454905101231, 48.47122049331665, 50.2764458656311, 40.30804600034441, 17.407678025109426, 6.406966490404947, 2.421868009226663, 6.300005487033299, 2.9608697380338396, 0.8268481173685619, 0.3279614602880818, 0.17345233261585236, 11.150324055126735, 40.2327310017177, 42.78757667541504, 31.132536343165807, 29.043061903544835, 41.210686479296, 40.504704339163645, 20.87497329711914, 1.2226781972817011, 0.03351873764768243, 0.05018255008118493, 0.06129265855997801, 0.028060469643345902, 0.029192347478653704, 0.015447441721335053, 0.04590171675330826, 0.04417070945990937, 0.023698503883289437, 0.04886790205325399, 0.07486553024500608, 0.057973475594605715, 0.03844094602391124, 0.0355660847521254, 0.027411954710260034, 0.01626510525654469, 0.040654534207923074, 0.021494601786668812, 0.01105849486443081, 0.02006944245658815, 0.01619080058299005, 0.08716186042875051, 0.025601937102952173, 0.08409156410821847, 0.05764910192894084, 0.06889176222362689, 0.011147014846626137, 0.014901489052655441, 0.017954097661588873, 0.0016808646157317395, 0.03685087723923581, 0.035240387943174155, 0.03836946914504681, 0.06140187555657966, 0.017512059238340174, 0.24652192315885, 13.015222293989998, 45.0377334186009, 50.13796131951468, 40.972575187683105, 23.067902939660208, 32.67981679098946, 36.71350315638951, 45.87067651748657, 15.72626086643764, 0.7079713876758302, 0.08841245475092105, 0.34896176627704073, 3.085126110485622, 4.03046761240278, 7.027349863733564, 7.466430851391383, 2.9470888546534946, 8.492418357304164, 21.298792566571915, 36.609596320560996, 47.14887407847813, 49.34275736127581, 48.17974703652518, 48.1442243712289, 45.117356300354004, 43.174417631966726, 38.90589257649013, 33.167080061776296, 34.492768560137065, 33.62496634892055, 38.45515945979527, 42.423015117645264, 44.4874221937997, 46.10781506129673, 44.45283753531319, 47.87611075810024, 48.038083689553396, 45.93461036682129, 43.80861445835659, 47.40373052869524, 44.989922864096506, 44.456975187574116, 45.414322308131624, 47.715405872889924, 47.4627172606332, 47.137166363852366, 46.6554651260376, 47.51191398075649, 46.26614713668823, 46.24674081802368, 38.884738785879954, 33.13604245867048, 34.09869105475289, 33.03986201967512, 33.969287804194856, 31.98585503441947, 34.81452921458653, 33.44075223377773, 36.6235865184239, 35.472037247249055, 33.66902487618582, 32.08740643092564, 34.80366918018886, 34.5589987891061, 36.79945584705898, 37.23343685695103, 43.856779370989116, 45.13447666168213, 50.00820371082851, 42.30097695759365, 44.02776411601475, 48.14485318320138, 45.60405329295567, 44.60411718913487, 43.12100682939802, 41.28330557686942, 39.05650520324707, 37.45809643609183, 35.35311882836478, 32.776726790836875, 34.192773137773784, 34.58606202261788, 34.613010610852925, 35.20987824031285, 35.02744286400931, 36.74077483585903, 45.64680903298514, 47.62776824406215, 49.43908371244158, 48.43332501820156, 48.01627676827567, 46.401491097041536, 46.39848600115095, 47.85443932669503, 44.89927666527884, 43.59568343843733, 45.2703869002206, 47.01031310217721, 48.13296481541225, 48.05650336401803, 47.48109177180699, 48.85575464793614, 49.5811048916408, 49.13831009183611, 49.211116790771484, 46.5623905318124, 45.154341561453684, 42.9249529838562, 36.96985346930367, 34.690059185028076, 35.66269581658499, 42.03920010157994, 47.7951329776219, 48.99680655343192, 51.52508578981672, 42.0500670841762, 51.285557065691265, 53.34233154569353, 48.70945337840489, 48.36069202423096, 50.54118265424456, 51.249019963400706, 42.36191265923636, 20.798741136278423, 5.5050025922911505, 4.4885857956750055, 8.014242461749486, 4.389865355832236, 0.7780632951429912, 0.1381654582385506, 0.20827343341495308, 12.103678567068917, 46.47680262156895, 47.28809513364519, 32.31477233341762, 31.360777718680247, 46.50648185185024, 50.45005008152553, 27.305960144315446, 2.0900867496218, 0.07427154068968125, 0.05089826542618019, 0.020929370241771852, 0.05685817776247859, 0.019455651553081613, 0.024260434355320673, 0.05757207463362387, 0.022021380752058964, 0.03111141753782119, 0.053054371516087225, 0.04519906999277217, 0.07385749862130199, 0.034437782796365876, 0.031351364483790736, 0.02993618810017194, 0.01512850312116955, 0.13245847661580357, 0.0705600016351257, 0.12241611762770585, 0.08506600824849946, 0.08943326997437648, 0.15281615565930093, 0.13394821381994657, 0.1838879840714591, 0.09515646858406918, 0.15014328408454145, 0.12599091151995317, 0.08892865026635782, 0.1793277266302279, 0.12773888558149338, 0.10662518960556813, 0.14151341787406377, 0.11602488772145339, 0.1439927305494036, 0.08245252884392228, 0.39094479062727516, 14.945920842034475, 50.684041091373985, 57.137333393096924, 45.13782916750227, 29.294612748282297, 38.47022662843977, 43.11350972311837, 49.97955628803798, 18.636261974062236, 1.094787591270038, 0.22757528482803277, 1.0354057891028268, 8.563107592718941, 6.659761931215014, 11.350030047552925, 11.73014427934374, 3.0311809480190277, 11.20730710029602, 21.511669737952097, 38.016005516052246, 50.203257015773225, 52.17414481299264, 49.53792878559658, 49.85643768310547, 47.608928203582764, 45.449893610818044, 40.61797734669277, 35.40662343161446, 36.54170894622803, 36.320012773786274, 41.295722007751465, 45.81038005011422, 46.9704269681658, 47.367964676448274, 45.90328093937465, 49.374600955418174, 50.24582862854004, 47.96933821269444, 47.13870191574097, 48.468496799468994, 47.02299009050642, 46.01862103598458, 45.29118980680193, 50.27793278012957, 48.16925873075213, 48.96098164149693, 48.27120270047869, 47.5521753174918, 47.42875446592058, 48.040741375514436, 40.9177816935948, 34.89818205152239, 35.743538107190815, 36.34426198686872, 35.557816232953755, 33.86759396961757, 36.47715670721871, 34.21232884270804, 38.40242610658918, 39.02724633898054, 35.76705775942121, 33.51222487858364, 37.49783665793282, 35.80432094846453, 39.73790461676461, 38.64846876689366, 44.69510384968349, 46.64739826747349, 51.51398951666695, 44.11270931788853, 45.81995119367327, 49.157990864345, 47.08851160321917, 45.76087760925293, 45.39401272365025, 42.83799627849034, 39.96799768720354, 40.53964335577828, 36.636829784938264, 34.2146634374346, 34.81968477794102, 35.92417042595999, 36.58679928098406, 36.71994761058262, 36.51733119147164, 37.66880055836269, 47.73677505765642, 49.49582270213536, 50.46301542009626, 50.212192399161204, 49.814227376665386, 48.41282088415963, 47.956376348223, 48.309949329921174, 45.27752617427281, 42.797477858407156, 44.679678848811555, 49.28093229021345, 48.4947054045541, 48.299804959978374, 48.205823625837056, 49.9007567678179, 53.110167912074495, 49.85966512135097, 51.381240708487375, 48.02813734327044, 46.79953254972185, 46.023033142089844, 39.30498668125698, 38.211305482046946, 37.85476909364973, 43.76821763174874, 50.28861910956246, 50.729166167122976, 52.24591623033796, 41.95676667349679, 50.52984666824341, 55.69028418404715, 50.9878580229623, 50.685378619602744, 53.50151824951172, 53.6634008543832, 44.164105142865864, 19.831649167197092, 9.20026695728302, 7.76794011252267, 13.422226922852651, 5.67738653080804, 2.775561715875353, 0.5852780342102051, 0.5462179758719036, 14.451262950897217, 52.13287946156093, 54.66519212722778, 41.524369852883474, 40.41220644542149, 52.919088976723806, 57.22754532950265, 31.79972321646554, 2.756887129374913, 0.11723755193608147, 0.14365829420941217, 0.12761014034705503, 0.1552000663110188, 0.15326180388884886, 0.12480336667171546, 0.16181272933525698, 0.11152409708925656, 0.10749460331031255, 0.23322087260229246, 0.22211385145783424, 0.2294965838747365, 0.11681417322584561, 0.08710720443299838, 0.1294283563537257, 0.09687834618879215], [0.03514955246022769, 0.012656404969415494, 0.03863734119970884, 0.024184920193095292, 0.11037669437272207, 0.03907883000959243, 0.07070628699979611, 0.004548236769291439, 0.008016414574480482, 0.023678595665842295, 0.029167652196649994, 0.02897188127306955, 0.07233484568340437, 0.042386966424861124, 0.06360710079648665, 0.029297883422779183, 0.036316880357584784, 0.07120287963854414, 0.04266474169812032, 0.01729376773749079, 4.626264785017286, 31.441679068974086, 42.62369646344866, 33.26413597379412, 29.096107925687516, 25.492991004671367, 31.501159123012, 36.5989864213126, 24.023071799959453, 3.3317984512874057, 0.1886492778680154, 0.26041259350521223, 1.8646659084728785, 4.904778982911791, 5.377935239246913, 5.279074966907501, 3.8386539050510953, 4.660099906580789, 17.33047832761492, 38.22549022947039, 47.82910966873169, 45.71357079914638, 44.311743940625874, 43.08147505351475, 40.12323086602347, 36.70752770560128, 33.77634327752249, 33.361351694379536, 34.432989733559744, 39.14726604734148, 41.290319783346995, 42.388465200151714, 45.915999616895405, 44.32228783198765, 46.94924191066197, 44.81710726874215, 43.172642367226736, 41.58420079095023, 41.38160521643502, 43.689407689230784, 43.66448450088501, 44.506050314222065, 45.804873602730886, 44.04922710146223, 42.79184981754848, 43.169630323137554, 44.70748553957258, 44.709785393306184, 45.023065771375386, 43.78055763244629, 44.33633361543928, 36.54847649165562, 31.889844826289586, 33.218076365334646, 33.49920048032488, 32.83415712629046, 32.79313843590872, 32.39655263083321, 33.92404113497053, 33.7759541784014, 33.565986565181184, 31.52224690573556, 33.18135860988072, 31.457121440342494, 33.53539364678519, 35.06349359239851, 41.50845847811018, 42.11615834917341, 44.612468923841206, 39.525355747767854, 43.32874059677124, 46.418580191476, 43.0487733568464, 42.02843039376395, 41.304230076926096, 39.02123267310006, 37.567540986197336, 35.683057512555806, 33.39946951184954, 33.01140219824654, 32.95191519601004, 33.19770424706595, 33.30647482190813, 31.935067176818848, 33.661395754132954, 34.500845840999055, 40.30291822978428, 45.01576321465628, 47.11640862056187, 48.001567431858604, 44.44285992213658, 47.639792101723806, 47.21992288316999, 47.1475956099374, 47.709774357931956, 47.44099719183785, 45.911031654902864, 44.486480712890625, 44.29232372556414, 47.978999682835166, 46.63498183659145, 47.478593894413535, 46.28302778516497, 48.030683858054026, 45.13678346361433, 48.15314933231899, 44.17678907939366, 44.98486110142299, 41.74824775968279, 39.20291416985648, 37.13180555616106, 39.01436785289219, 43.665603160858154, 46.72854280471802, 48.83369411740984, 45.06690195628575, 45.62447057451521, 47.36401115145002, 50.46870946884155, 47.15915741239275, 51.058031354631694, 47.91282156535557, 30.678829397474015, 12.175155554498945, 2.313894088779177, 2.0049819563116347, 2.1237922438553403, 6.143193764345987, 0.564079894551209, 0.11524052838129656, 0.3066791280039719, 10.233665585517883, 38.04738358088902, 38.34089980806623, 34.569560050964355, 29.96179962158203, 45.49527924401419, 38.303160667419434, 17.61971272741045, 0.47002071887254715, 0.10641354096255132, 0.056974828110209534, 0.1352164636233023, 0.0341207339162273, 0.011728235221068774, 0.016194291645660996, 0.05057588665347014, 0.06784477590450219, 0.057291486832712374, 0.009101087576709688, 0.06571879676942315, 0.054158456557031186, 0.022924107133543918, 0.03272900091750281, 0.04379501479810902, 0.09187119879892894, 0.0642039401988898, 0.015888791431539824, 0.027700601810855523, 0.019989646738395095, 0.015609263841594969, 0.060392622569842, 0.03680392261594534, 0.06244512993310179, 0.03086352494678327, 0.03030020517430135, 0.05176915155191507, 0.04057926771097949, 0.07537961551653487, 0.10359365120530128, 0.02537627501546272, 0.031301861961505244, 0.06114287195461137, 0.007604352132018123, 0.05250540954459991, 0.07267727516591549, 6.6941772273608615, 38.05321659360613, 48.73298692703247, 39.92061097281319, 31.080501283918107, 29.769205978938512, 35.106058256966726, 41.759726183755056, 21.63619187899998, 2.512409333671842, 0.17254032726798738, 0.2229084295353719, 1.3498882055282593, 4.959346226283482, 6.8498920031956265, 9.250857659748622, 8.176708715302603, 6.65845480135509, 18.972393240247452, 38.641986097608296, 51.43967158453805, 47.3193689755031, 46.15508713041033, 44.2239534514291, 42.796525955200195, 38.71731151853289, 35.716499192374094, 35.57580859320504, 36.09914691107613, 40.171027524130686, 43.30923005512783, 44.490392548697336, 47.26499932152884, 47.335433210645405, 48.340504033224924, 47.48993682861328, 44.47888980593, 42.47075271606445, 43.447408880506245, 44.58227552686419, 46.23740938731602, 45.81702252796718, 46.58505208151681, 44.78403731754848, 44.36719403948103, 47.028131757463726, 46.30094371523176, 45.47589029584612, 46.60315213884626, 44.99730879919869, 44.385446957179475, 37.220200538635254, 33.69875969205584, 34.04464101791382, 34.296919686453684, 34.16001238141741, 35.56857551847185, 34.46727909360613, 36.33803640093122, 36.107578550066265, 35.69618613379342, 33.629649434770855, 34.7650580406189, 33.16704879488264, 35.472871031079976, 36.50618280683245, 43.53844765254429, 44.33102171761649, 46.69363505499703, 40.73483909879412, 44.79021079199654, 48.16047273363386, 46.124119009290425, 44.20026009423392, 42.71953296661377, 40.919372831072124, 38.98371934890747, 36.11747973305838, 34.59592499051775, 33.94161312920706, 34.11969198499407, 34.645218985421316, 35.188258920397075, 34.807417733328684, 35.659843581063406, 35.085852895464214, 43.42268718991961, 48.242645604269846, 47.95348589760916, 47.56548111779349, 45.96186120169503, 47.946131229400635, 48.95067746298653, 46.98058523450579, 47.56210776737758, 48.02251277651106, 46.73415000098092, 45.72734907695225, 45.361759185791016, 48.843101978302, 47.92001295089722, 48.93777813230242, 48.05674655096871, 47.27677304404122, 45.47186034066336, 49.97422701971871, 46.644657203129356, 45.95341566630772, 43.940129961286274, 39.48899235044207, 38.1930490902492, 41.00656577519008, 45.99982268469674, 49.06400258200509, 51.150550092969624, 46.31250204358782, 46.57211800983974, 49.68560927254813, 52.99275030408587, 49.403981413160054, 52.786430495125906, 51.29431527001517, 33.393164021628245, 13.772815653256007, 2.511882573366165, 5.2344488586698255, 6.094765254429408, 3.7324076976094926, 1.2785509420292718, 0.10422920781586852, 0.4251493609377316, 12.753829325948443, 43.92628567559378, 44.52168376105172, 37.351306097848074, 34.291107518332346, 50.71645096370152, 44.44559751238142, 22.033135516302927, 1.082315357668059, 0.05360836482473782, 0.005008220747445843, 0.0400677439091461, 0.026737190649977753, 0.01899552338623575, 0.03074278642556497, 0.021407070769263164, 0.02896883465083582, 0.06147107934313161, 0.013287870861989046, 0.050587984932852645, 0.02278315505412008, 0.060678876138159206, 0.02689245981829507, 0.03022376141910042, 0.03660315088927746, 0.2827673096741949, 0.10368108044245414, 0.13312757999769279, 0.26400918194225853, 0.2015541453978845, 0.13211042886333807, 0.21055784369153635, 0.10144089029303618, 0.06351258086838893, 0.18571343326142856, 0.1473274723227535, 0.18476942820208414, 0.18182375840842724, 0.1598039942660502, 0.14096949063241482, 0.09442111304295914, 0.144537729876382, 0.1335396407438176, 0.10046810856355087, 0.18391532903271063, 7.654027002198355, 43.83862025397164, 54.77533497129168, 46.94877290725708, 38.663730485098704, 33.94845363071987, 41.4211300441197, 47.09620325905936, 28.698879412242345, 4.453533002308436, 0.40240627846547533, 0.7474967039057187, 5.610743318285261, 11.503685116767883, 11.102295500891548, 14.179946218218122, 6.726657884461539, 7.6709423916680475, 19.540048905781337, 44.794115679604666, 52.60511725289481, 49.568785735539024, 47.81604358128139, 46.62554618290493, 43.749579089028494, 41.472234044756206, 36.90644768306187, 37.631982054029194, 38.66755894252232, 43.94777645383562, 45.23247058050973, 47.661769253867014, 49.78695569719587, 47.65302842003958, 50.309126717703684, 49.14204127447945, 47.3178334236145, 44.08092825753348, 46.197915826525005, 47.82515614373343, 49.266400132860454, 47.24615233285086, 48.29403100694929, 47.55919994626726, 46.46968419211251, 48.67010920388358, 47.3478878566197, 47.0576685496739, 48.11473274230957, 46.99419328144619, 47.37335647855486, 39.85603094100952, 35.598848819732666, 36.263457911355154, 36.27467230388096, 36.14594302858625, 35.95249475751604, 36.03593914849417, 38.86590916769845, 36.72007267815726, 38.16851847512381, 35.03643730708531, 37.748760427747456, 34.041997228349956, 36.88903202329363, 38.29482282911028, 46.31907156535557, 46.1770156451634, 48.20065416608538, 43.38653918675014, 46.04356854302542, 51.91436556407383, 47.79559850692749, 45.67530012130737, 43.78497668675014, 41.72573559624808, 40.505089964185444, 39.01015724454607, 36.59569297518049, 34.65536682946341, 35.867372376578196, 35.88691071101597, 36.81986270632063, 36.43862894603184, 37.12507275172642, 36.882243633270264, 43.99603864124843, 50.625276701790945, 50.79992314747402, 49.05514710290091, 46.77200378690447, 50.321331228528706, 50.92739132472447, 48.97359609603882, 50.26993192945208, 49.69117825371878, 48.55884075164795, 45.92424365452358, 47.04579407828194, 50.443911348070415, 49.08432606288365, 50.5713552066258, 49.01027911049979, 48.73344898223877, 47.11543239865984, 51.21291364942278, 48.6207457269941, 48.774655273982454, 45.876877784729004, 43.5899372782026, 40.715943472726, 42.81807926722935, 49.221149989536826, 50.75029911313738, 53.657369818006245, 46.10621697562081, 46.17722756522042, 49.88966049466814, 55.524583544049946, 51.397096497671946, 56.05709000996181, 52.756587982177734, 35.146670477730886, 14.721103191375732, 4.064680976527078, 8.07046033654894, 11.206795539174761, 12.520864043916974, 1.6736664431435722, 0.39951191948992865, 0.7040656858256885, 14.300012826919556, 49.45987272262573, 50.582736355917795, 46.42336402620588, 40.334067004067556, 57.74654797145298, 52.66462162562779, 26.823484182357788, 1.6862485451357705, 0.20944233212087834, 0.1377972579960312, 0.1366757753172091, 0.1526346475418125, 0.09053227957338095, 0.2659473493695259, 0.12392992925431047, 0.1681605465710163, 0.16879542464656488, 0.05649501903514777, 0.1878577396273613, 0.2388310544192791, 0.09359651657619647, 0.14465918764472008, 0.0602046615843262, 0.27871241154415266], [0.04621627540992839, 0.020937611049573337, 0.002681613226221608, 0.03209218562447599, 0.027330661126013314, 0.08024756823267255, 0.022147807093071084, 0.07226798284266676, 0.08111097690250192, 0.008843229002585369, 0.02780763731737222, 0.027330347303567187, 0.0069840918211931625, 0.01887223357334733, 0.0380864793301693, 0.06419990970087902, 0.04493342014029622, 0.008756794667403613, 0.03812136620815311, 0.03872236842289567, 1.7208009596381868, 21.805463893072947, 40.980131353650776, 36.938378129686626, 22.789697068078176, 24.404239552361624, 30.864836147853307, 39.472424370901926, 34.167561599186485, 6.957269029957907, 0.03427786227049572, 0.2779550307563373, 1.3044507865394865, 2.6936224784169878, 5.827485425131662, 9.303309610911779, 7.582867894853864, 5.145937493869236, 19.482875653675624, 34.29110404423305, 47.0240774835859, 45.264171736580984, 43.99980803898403, 41.75206926890782, 39.18776362282889, 37.964046886989046, 39.762306690216064, 39.58343921388899, 41.57982689993722, 40.79559414727347, 44.01695966720581, 46.16695465360369, 45.70422894614083, 43.24867303030831, 42.175596714019775, 42.54838841302054, 40.787916387830464, 38.14106961659023, 39.11855261666434, 38.91684293746948, 43.662928104400635, 42.64786229814802, 42.134546756744385, 42.17546122414725, 40.46068402699062, 43.639912196568076, 43.3769610949925, 46.25696856634957, 46.182636737823486, 47.54772847039359, 44.19486134392874, 39.63268804550171, 33.334441321236746, 31.977128096989222, 32.4668927192688, 31.205513272966655, 32.86169631140572, 31.42756380353655, 33.088683537074495, 33.2179582459586, 33.592004094805034, 32.25154372623989, 33.953442437308176, 31.983329364231654, 34.43337188448225, 36.57327113832746, 42.38779469898769, 43.561678954533164, 46.309899943215505, 41.98649801526751, 45.42370932442801, 46.22649029323033, 43.196867261614116, 44.0258846282959, 41.0835657119751, 39.52435173307146, 39.11814962114607, 36.13346406391689, 33.93764918191092, 33.33056075232369, 33.00524956839425, 33.43660068511963, 33.167893001011436, 33.13053253718785, 33.67364195414952, 33.709630148751394, 39.48172453471592, 44.73808193206787, 46.177679198128835, 44.35478803089687, 42.772467817579, 46.2172074999128, 44.93403502873012, 44.17901597704206, 43.918006896972656, 43.60419845581055, 43.11219998768398, 45.51099954332624, 47.099468912397114, 46.68271943501064, 46.7336288860866, 44.17456912994385, 45.075003555842805, 45.42137472970145, 44.82484408787319, 44.90957736968994, 51.22045591899327, 45.59162643977574, 42.80493327549526, 44.08618804386684, 43.05894551958357, 43.09708765574864, 44.39478881018502, 47.30530234745571, 51.3537814276559, 46.72981432506016, 46.03329563140869, 47.49942111968994, 51.230110440935405, 50.90488958358765, 52.97646025248936, 41.53489637374878, 22.901860100882395, 6.867560403687613, 0.9588304523910794, 4.178878094468798, 6.615705140999385, 2.3414573754583086, 0.5597372704318592, 0.07580606799040522, 0.7487778865865299, 10.423703159604754, 36.02588163103376, 31.72252525602068, 27.358745609010967, 34.56839622770037, 45.74919421332223, 41.369160992758616, 16.011977740696498, 0.22932882287672587, 0.06773652242762701, 0.024662763212940524, 0.04672794848946588, 0.014544698376474636, 0.00776572133015309, 0.05928981996008328, 0.016218031889625957, 0.009816212596238723, 0.04826267595802035, 0.032246090937405825, 0.019283620873466134, 0.07283077335783414, 0.009580552295249487, 0.019040506865297045, 0.04719080775976181, 0.06390100145446402, 0.04622668752978955, 0.023781989135646393, 0.035289011762610505, 0.014188514140966748, 0.005229519854765385, 0.04846705070563725, 0.042572566108512025, 0.04877413869170206, 0.015396137688575047, 0.033749673648604324, 0.031098929100802968, 0.01696023384907416, 0.04352064237796834, 0.024243038413780074, 0.07671236685876336, 0.03742154554596969, 0.036928864661604166, 0.008504265137682003, 0.0690219323816044, 0.06885549452688013, 2.622118349586214, 27.85587705884661, 46.40387780325753, 43.310796873910085, 29.18533148084368, 27.1963940007346, 34.262206486293245, 42.91379765101841, 36.84024177278791, 7.1341297796794345, 0.12202150880226068, 0.07462159012045179, 0.552486988050597, 3.711403727531433, 4.892913196768079, 8.174744112151009, 8.292363217898778, 5.730361768177577, 20.284991332462855, 36.67316538946969, 48.701191970280235, 47.907492297036306, 46.16834429332188, 43.5060829435076, 40.370819500514436, 39.405957903180806, 40.53761100769043, 39.795029231480186, 43.043704645974294, 43.160660198756624, 44.60221685682024, 47.161999225616455, 47.69432503836495, 45.32267904281616, 43.5995466368539, 42.82482596806118, 43.487274169921875, 40.86929716382708, 39.90922634942191, 40.79805728367397, 46.1073807988848, 44.83822979245867, 44.82616771970476, 44.58648613521031, 43.317974363054546, 45.15182631356375, 47.31013134547642, 46.760104996817454, 47.156013352530344, 48.118894713265554, 45.885024547576904, 41.642357213156565, 35.05771963936942, 33.475263936179026, 33.92614296504429, 32.99054023197719, 34.380065304892405, 32.956077166966026, 34.4698360306876, 34.1075256892613, 34.196410519736155, 34.06330735342843, 34.71290486199515, 33.927980763571604, 36.88127088546753, 38.509265082223074, 44.23098502840315, 45.18842247554234, 46.88930327551705, 42.56047827856881, 46.8589848109654, 47.666837964739116, 45.4132661819458, 45.227745805467876, 43.69251353400094, 41.87615714754377, 40.752286025456016, 37.15985195977347, 35.63141850062779, 34.320595673152376, 34.42850814546858, 34.470815726688926, 34.386426380702424, 34.995713915143696, 35.535946777888704, 35.8056515284947, 40.88704981122698, 45.72594901493618, 47.356767654418945, 46.8057998248509, 45.31449406487601, 46.817052432468955, 46.303604875292095, 47.016212122780935, 46.15070629119873, 45.628146171569824, 45.32201548985073, 47.25184290749686, 48.339156082698274, 47.916795934949604, 48.36658409663609, 47.39506959915161, 47.658270835876465, 47.1454381942749, 45.62752430779593, 47.5339606148856, 52.3434932572501, 47.63709967476981, 46.179951259068076, 46.7015768459865, 44.380319186619346, 43.91979258401053, 47.101681913648335, 49.4292311668396, 51.75334106172834, 47.48732778004238, 45.52041435241699, 46.77827801023211, 51.19966343470982, 52.762427943093435, 56.461489064352854, 43.307409627096995, 24.807973316737584, 7.029271909168788, 4.92357907124928, 4.013464067663465, 8.17467897278922, 4.665499525410788, 0.7346970364451408, 0.061862933316401074, 0.7495462053588459, 12.081200276102338, 41.967956747327534, 38.36018105915615, 35.492207867758616, 39.86323969704764, 50.454580307006836, 47.62623964037214, 19.063763788768224, 0.5133860547627721, 0.03277531432520066, 0.12933104086135114, 0.011477434259307171, 0.028406149308596338, 0.0740372221916914, 0.051867634124521694, 0.025018115394881794, 0.024410838427554284, 0.01718684927826481, 0.06093025300651789, 0.0069155296743182194, 0.017711692722514272, 0.03713993654985513, 0.028165070905483196, 0.06311795168689319, 0.031750298969979794, 0.12940604612231255, 0.12648823697652134, 0.14352916899536336, 0.2121112003390278, 0.10925197508186102, 0.15831049797790392, 0.07367825002542563, 0.11840722417192799, 0.15738022646733693, 0.10286967469645397, 0.15703785126762732, 0.13229538393872126, 0.2554007981504713, 0.09976137362952743, 0.09774843842855521, 0.17476309942347662, 0.07816293223627976, 0.09293075158659901, 0.18624548614025116, 0.12816507342670644, 3.2451294447694505, 32.77402394158499, 53.01296956198556, 50.12124047960554, 33.9347448348999, 34.6800468308585, 41.439622674669536, 49.0186447416033, 42.90979896272932, 9.596998674528939, 0.1343224123120308, 0.7392274790576526, 4.765554453645434, 8.685065848486763, 15.170629058565412, 18.102185215268815, 13.838534321103777, 6.330148943832942, 23.012758561543055, 40.81807851791382, 52.05252701895577, 49.705390793936594, 47.63289948872158, 45.901891299656455, 44.29308107921055, 41.80125209263393, 42.882655824933735, 43.43226875577654, 46.92390530450003, 44.543480260031565, 46.40212338311331, 49.48063046591622, 49.29821593420846, 47.00528260639736, 45.820771081107004, 47.003173828125, 44.815314633505686, 42.40011732918875, 42.51484945842198, 42.48579556601388, 48.044205052512034, 46.34044075012207, 45.88460765566145, 45.98853186198643, 44.72258744921003, 46.79967498779297, 48.43964440482003, 48.40820033209664, 48.08594635554722, 50.55347054345267, 47.10074738093785, 43.62715877805437, 36.92248412540981, 34.78970677512032, 36.38660083498274, 33.62695005961827, 36.23301437922886, 34.5373204095023, 35.375988824026926, 36.491584641592844, 36.72874402999878, 35.76788112095424, 36.76648664474487, 36.32462290355137, 38.66686759676252, 41.10864870888846, 45.940530232020784, 49.00631863730294, 49.59089142935616, 45.882721219744, 48.16924136025565, 49.24597242900303, 46.81924111502511, 48.7348837852478, 45.826301847185405, 43.51503569739205, 43.028338704790386, 39.3197203363691, 37.021127700805664, 35.77070208958217, 37.10666349955967, 36.404572350638254, 36.761247703007285, 37.605794293539866, 37.65904181344168, 37.0358544077192, 43.68546806062971, 47.59700162070138, 49.95755134310041, 46.83348144803728, 47.72390351976667, 49.10891921179635, 49.26191854476929, 47.74696111679077, 48.1287750516619, 47.86739771706717, 46.82476493290493, 49.464121546064106, 50.983918394361226, 50.2628447668893, 51.20067439760481, 48.44279888698033, 49.59580727985927, 48.26084988457816, 47.759276798793245, 48.270323753356934, 53.407196453639436, 50.08477980749947, 46.75456728254046, 48.1685847554888, 48.551927294049946, 46.16089929853167, 48.836396966661724, 52.38996628352574, 54.73725536891392, 48.287801946912495, 47.46853985105242, 46.90898404802595, 52.701217787606375, 53.65917982373919, 58.18946783883231, 45.465989112854004, 26.839954887117656, 8.2417916229793, 3.2395502584321156, 7.753551261765616, 15.004308291843959, 8.537615520613533, 2.3206247219017575, 0.2855525059359414, 1.1432755951370512, 15.06988365309579, 47.155457496643066, 44.0304183278765, 41.76238734381539, 46.17344427108765, 57.76904623849051, 54.516274860927034, 22.396194526127406, 0.8877480466450963, 0.12994345942778246, 0.20679525844752789, 0.07904276145356041, 0.13753292789416655, 0.22857621897544178, 0.1612644594694887, 0.07383106289697544, 0.13461074898285524, 0.12919028555708273, 0.18648864594953402, 0.11539566862796034, 0.12173621196831975, 0.09436431966189827, 0.11652510373720101, 0.14415371976792812, 0.17469174468091556], [0.020635408515642797, 0.0326390916348568, 0.009393668484075792, 0.08277906703629664, 0.04359514891569104, 0.041654586259807856, 0.027983321908063123, 0.016821390317220773, 0.03508073543863637, 0.027115468833861605, 0.05268826794677547, 0.06909499703241245, 0.044460308205868514, 0.02786637470126152, 0.035288672495101175, 0.014490676810964942, 0.011911604220845869, 0.033122449448066096, 0.031199447278465544, 0.04906616320035287, 0.6688784339598247, 14.993696655545916, 37.52404873711722, 36.82384402411324, 29.816227912902832, 22.0909914289202, 33.73301083700997, 37.87111473083496, 37.22122539792742, 13.565727199826922, 0.13727986147361143, 0.03925125254318118, 0.24766520038247108, 2.770199009350368, 2.752022738967623, 7.429426482745579, 9.819202933992658, 6.643583919320788, 22.593144689287456, 39.69552755355835, 51.064979553222656, 45.076118741716655, 43.735404763902935, 41.135993344443186, 43.41564866474697, 42.46247741154262, 41.81171260561262, 41.72042369842529, 42.8600880759103, 44.90664175578526, 47.077363218579976, 43.20365217753819, 43.870008741106304, 42.13398395265852, 41.10757868630545, 39.49562440599714, 35.592056955610005, 32.154845646449495, 34.09089865003313, 36.37914889199393, 39.004303387233186, 40.34095614297049, 39.37600769315447, 37.358546120779856, 35.88679953983852, 41.65991531099592, 43.69025189535958, 43.58366652897426, 46.36269930430821, 46.38243218830654, 45.90550436292376, 42.428083828517366, 36.50900377546038, 32.168488434382844, 33.41518633706229, 31.488954612186976, 32.33356373650687, 31.352801186697825, 32.00545242854527, 32.75619486400059, 31.81714235033308, 31.94062920979091, 32.62235171454293, 32.40982716424124, 34.85131297792707, 36.08083840778896, 42.75533703395298, 43.00054938452584, 45.61992645263672, 41.216846057346885, 43.4906336239406, 44.447952951703755, 42.439735957554404, 44.086139406476704, 40.635518074035645, 39.12308979034424, 37.12273120880127, 34.50433383669172, 32.13459512165615, 33.602148464747835, 32.04160043171474, 33.13299914768764, 33.75530413218907, 31.42503465924944, 32.25848150253296, 34.39963143212454, 42.03119230270386, 43.70416218893868, 47.313650608062744, 47.26786197934832, 47.192105770111084, 43.84822613852364, 42.89841433933803, 43.55890662329537, 42.90633528573172, 42.383785588400706, 42.017778805324006, 41.482944692884175, 43.61851521900722, 44.33295679092407, 43.158030305589946, 41.92818873269217, 42.686984130314414, 44.31054537636893, 45.347393785204204, 46.24584797450474, 44.82080371039254, 47.38442843300955, 46.41816677365984, 45.67543561117989, 43.4490556035723, 44.38096536908831, 44.94925505774361, 50.422424043927876, 46.955224309648784, 47.79901007243565, 48.84736122403826, 49.07093341009957, 48.38595220020839, 51.449121134621755, 47.59953423908779, 35.24692950929914, 13.871936917304993, 1.8495179670197623, 3.2935253850051334, 3.8431050947734287, 4.576016281332288, 1.8405849720750536, 1.0115536004304886, 0.11357141365962369, 1.1844061080898558, 13.79578639779772, 40.4985134942191, 35.90098428726196, 36.36520038332258, 38.89203092030117, 49.83359200613839, 35.48960229328701, 10.77819504056658, 0.16946270955460413, 0.040016175247728825, 0.019597278774849007, 0.04831075694944177, 0.0585741147931133, 0.016351196083373258, 0.023314001836947033, 0.060287904260413985, 0.01906398926595492, 0.022311654640361667, 0.051466379048568864, 0.07754334834005151, 0.04044016124680638, 0.05540809075215033, 0.07251032162457705, 0.014493838784151843, 0.03762358274044735, 0.043908102836992056, 0.08731547397162233, 0.03828289146934237, 0.08548969229949371, 0.020846248005649874, 0.04078798847539084, 0.039053127103086026, 0.053304286141480715, 0.033004367391445806, 0.00894677683910621, 0.05830337253532239, 0.0492444686325533, 0.03179210351247873, 0.028606496950877563, 0.04960519141916718, 0.038081848328667026, 0.04982204442577703, 0.03495366279301899, 0.07490797261042254, 0.025065400803993856, 1.0953310706785746, 19.101544618606567, 44.641606194632395, 42.79109246390206, 31.854242256709508, 28.525071961539133, 39.62938417707171, 41.881142480032786, 42.084141050066265, 13.180494751249041, 0.20187290757894516, 0.03200537046151502, 0.5568277665546962, 4.927895205361502, 6.001610321657998, 7.962930883680071, 8.20631846359798, 4.882110485008784, 21.968475580215454, 41.33229732513428, 50.75329031263079, 47.54585593087332, 45.87601968220302, 42.89973449707031, 44.31267499923706, 42.88808931623186, 43.78718621390206, 43.977903842926025, 44.90162168230329, 46.169584546770366, 48.660659653799875, 46.41859756197248, 45.13082538332258, 44.00648873192923, 42.983140672956196, 42.65097509111677, 38.45399563653128, 34.18828112738473, 35.97620548520769, 38.98073509761265, 40.48580871309553, 42.198261737823486, 42.11997291019985, 39.6714312008449, 37.160706588200156, 43.419536181858604, 45.93875844138009, 44.62200880050659, 47.57913432802473, 47.516805512564524, 48.58219364711216, 44.98019191196987, 37.846747398376465, 33.311401094709126, 34.565057618277415, 32.84731701442173, 33.00710473741804, 33.9459661756243, 33.76325634547642, 33.488844190325054, 34.16203778130667, 33.37390014103481, 34.07400410515921, 34.71017074584961, 35.65005704334804, 37.34166199820382, 44.54750326701573, 44.747861521584646, 48.05697236742292, 42.84280790601458, 45.24443885258266, 46.67094223839896, 44.39343391145979, 45.59584052222115, 42.969522203717915, 40.73861197062901, 39.28587218693325, 36.52331011635916, 32.89045490537371, 34.09516831806728, 33.84552649089268, 34.45514406476702, 34.88643959590367, 33.537082059042795, 35.59666361127581, 35.48033687046596, 41.85158831732613, 46.5445545060294, 50.10006237030029, 48.04666471481323, 48.11176586151123, 45.3666924067906, 45.5391640663147, 44.032759870801655, 43.17479630878994, 44.119626249585835, 44.2427031653268, 44.106275285993306, 45.66189009802682, 45.37645809991019, 45.109622955322266, 43.77877541950771, 44.766434056418284, 46.92577089582171, 46.861302035195486, 47.24774694442749, 46.66920518875122, 48.60163818086897, 48.515918254852295, 47.3980781691415, 47.09498037610735, 47.434441566467285, 47.90372289930071, 51.54701083047049, 48.73021806989397, 46.93309429713658, 49.23469202859061, 48.96648461478097, 49.460216658455984, 51.91898611613682, 50.33094058718, 37.2155556678772, 16.491196734564646, 3.1463019592421393, 5.366521086011614, 6.169656412942069, 7.471935561725071, 5.192054424967084, 0.9699537583759853, 0.07748372546796288, 0.9848095497914723, 16.255100420543126, 43.95789997918265, 37.729413168770925, 36.09758704049246, 43.56678588049752, 54.34824310030256, 43.33871820994786, 14.118360860007149, 0.28183033423764364, 0.06561368490968432, 0.10194812236087662, 0.04187444856922541, 0.039423763286322355, 0.027964451849194508, 0.02550569030323199, 0.0393921605178288, 0.031754641594099145, 0.06127780542841979, 0.02016222703137568, 0.03906795987859368, 0.09452544458742652, 0.042821249192846675, 0.04409949381702712, 0.04257908004469105, 0.0419587972573936, 0.099381054751575, 0.2023468914308718, 0.12207590016935553, 0.22012843085186823, 0.09222059683608157, 0.2204040110643421, 0.18215910398534366, 0.145879668582763, 0.17073338851332664, 0.09340010782969849, 0.11101569794118404, 0.17755072484058992, 0.18026244933051722, 0.12986180452363832, 0.06864241417497396, 0.09789839466767651, 0.08395711917962347, 0.20635988323816232, 0.1569528986832925, 0.39871314806597574, 1.4722999398197447, 22.44508899961199, 50.66205699103219, 49.835759844098774, 38.744604042598176, 30.600696904318674, 43.293037278311594, 47.864830357687815, 47.43952069963728, 16.71265493120466, 0.2862998715468815, 0.23485435066478594, 1.4322068797690528, 9.009776881762914, 5.922574996948242, 17.669548681804113, 18.365085942404612, 8.36751319680895, 25.348624808447703, 45.32206760134016, 52.910125800541465, 48.156300340379985, 48.6825464793614, 45.330638204302105, 47.33449867793492, 46.59116302217756, 46.7137257712228, 45.513504368918284, 47.58682598386492, 48.74265187127249, 51.06584460394723, 46.62503201620919, 47.82987397057669, 46.51763023648943, 45.12398140771048, 43.88821302141462, 39.507478032793315, 35.04663726261684, 37.20492492403303, 40.47586931501116, 42.280076776232036, 45.64458213533674, 42.662821769714355, 40.465787478855674, 38.31813056128365, 46.58877979006086, 47.99644660949707, 47.02143021992275, 49.33689308166504, 48.12825741086687, 51.25743770599365, 46.477414063044954, 39.34373331069946, 35.07884216308594, 37.1693570954459, 34.33887638364519, 35.8496926852635, 34.97240965706961, 34.59845413480486, 35.46176086153303, 34.736327239445274, 35.37203529902867, 37.09770379747663, 37.06324420656477, 37.76381022589547, 39.499108927590505, 46.48234380994524, 47.117975439344136, 49.88398381641933, 45.73296322141375, 46.89745698656355, 47.60424164363316, 45.02937126159668, 48.869421754564556, 45.186129570007324, 42.745897906167166, 40.28755923679897, 37.97282941000802, 34.785371099199565, 36.61192396708897, 35.74436146872384, 37.07561547415597, 36.73015104021345, 34.89163684844971, 37.57054260798863, 37.27764129638672, 45.03705249513899, 47.803224154881065, 52.20646435873849, 48.68542650767735, 49.883170877184185, 47.73358930860247, 46.73164864948818, 46.787494795663015, 45.504499503544395, 45.76408420290266, 45.695925848824636, 45.10943535396031, 46.91729409354073, 48.61793170656477, 48.461757046835764, 46.524303981236045, 46.22037240437099, 49.97335502079555, 48.71456030436924, 49.65478358949934, 47.571842193603516, 49.803224904196604, 50.526747771671836, 49.213333266122, 49.28141171591622, 48.797278608594624, 49.47643722806658, 52.832399777003694, 50.37433556147984, 48.831262247903005, 49.64475733893258, 49.56875099454607, 48.685628005436485, 53.634909766060964, 50.36790500368391, 38.3540666443961, 17.40972079549517, 4.024581185409001, 5.510879899774279, 9.818878974233355, 7.613396542412894, 7.4085862295968195, 2.578454783984593, 0.24533122990812573, 1.4772705073867525, 19.99897047451564, 52.518431527274, 47.86316973822457, 47.46329743521554, 50.165851388658794, 62.54757949284145, 49.333526679447715, 15.364402157919747, 0.532895347901753, 0.16564273381871836, 0.14054368276681217, 0.1460107479776655, 0.15410161311072962, 0.12931174332542078, 0.12281509621867112, 0.1548039647085326, 0.1050934646544712, 0.0964125386838402, 0.10809598211199045, 0.21978643563176903, 0.19023471565118857, 0.11382315693689243, 0.18997451104223728, 0.17170686913388117, 0.14765567971127375], [0.021290763081716638, 0.010213347268290818, 0.05868624270494495, 0.028991358620779853, 0.018393779871985316, 0.022526841843500733, 0.006638946502269911, 0.11009753149534975, 0.03602282702922821, 0.020494972122833133, 0.03241063228675297, 0.026553670676159005, 0.019393214457003132, 0.027605255766372596, 0.02915319600807769, 0.020760621975309083, 0.022531259106472135, 0.03670279375676598, 0.048782796798540015, 0.07761582266539335, 0.0896824144625238, 9.616504005023412, 35.03033331462315, 43.47744246891567, 31.87613950456892, 20.193238633019583, 28.999197925840104, 37.0725165775844, 42.745144026620046, 16.77268041883196, 0.6413455456495285, 0.0614736442055021, 0.36060721852949684, 3.1026444733142853, 6.234999009541102, 3.990566713469369, 4.560139647551945, 4.132825868470328, 20.014371156692505, 39.56605134691511, 47.64831754139492, 46.282621315547395, 43.25522518157959, 44.15744529451643, 43.58398962020874, 46.88595771789551, 46.227508204323904, 45.11833252225603, 47.350156443459646, 46.621255670275005, 44.761587687901084, 43.15496267591204, 39.69215420314244, 38.74657038279942, 34.9122382572719, 32.71210159574236, 31.34129844393049, 31.671011311667307, 33.58707087380545, 31.75226354598999, 33.937079429626465, 33.997407163892476, 34.419847215924946, 33.77622168404715, 34.475043705531526, 36.18959856033325, 40.9504451751709, 42.20145443507603, 44.01657404218401, 45.06881965909685, 46.02942895889282, 43.04642833982195, 37.334929193769185, 32.83131878716605, 31.415414878300258, 30.987718514033727, 31.724766050066265, 31.124420847211564, 32.566540309361045, 31.77866322653634, 32.79145697184971, 31.308610643659318, 32.5023980140686, 33.64904185703823, 35.47157171794346, 35.11418070111956, 42.043375968933105, 42.72346912111555, 46.83413110460554, 40.732681683131624, 44.79838534763881, 46.616308552878245, 43.53655774252755, 43.56502798625401, 41.51582704271589, 41.539377961839946, 38.002206393650596, 35.673031261989046, 33.856431688581196, 32.779617241450715, 32.32984297616141, 32.452336243220735, 33.42721019472395, 33.02223791394915, 32.4691925730024, 35.589989866529194, 43.26807587487357, 45.97652884892055, 48.221703733716694, 46.17084911891392, 45.28519351141793, 44.550741127559114, 41.92438806806292, 38.75057601928711, 36.573708874838694, 36.4674049104963, 38.58399990626744, 39.10785239083426, 42.30564962114607, 41.11757019587925, 39.03543479101998, 38.19533504758562, 38.367897033691406, 41.86110387529646, 42.87875441142491, 44.68987880434309, 45.15828813825335, 43.914456367492676, 47.59981216703142, 47.67360898426601, 48.32221984863281, 46.940073762621196, 48.55352190562657, 45.514817578451975, 46.378742694854736, 49.53992291859218, 50.23057733263288, 48.51601552963257, 53.49062694822039, 49.33035135269165, 43.031194414411274, 23.91392775944301, 8.752911533628192, 2.014495777232306, 7.827980365071978, 1.8220113515853882, 11.180513109479632, 4.762060812541416, 0.21925141076956475, 0.14784021409494535, 0.6581953072122165, 16.430945430483135, 42.17970657348633, 39.79389667510986, 34.95478555134365, 37.26262623923165, 52.594740118299214, 35.42023842675345, 6.946687792028699, 0.06986410290535007, 0.013384405190923383, 0.038431100480790646, 0.03619180939027241, 0.03226877775575433, 0.027407540839963725, 0.059321602540356774, 0.022973039686413746, 0.08887533776994262, 0.014538089445393, 0.03284476238435932, 0.016760462961558784, 0.05095437348687223, 0.02294997119211725, 0.029201412706502845, 0.056865183636546135, 0.007043884751120848, 0.022355016420728395, 0.04602387680539063, 0.0758523101519261, 0.02015888355007129, 0.03324651957622596, 0.02540266154600041, 0.006628937262576073, 0.10090926489127533, 0.04605540154235704, 0.03127436772254961, 0.010709810137216533, 0.02440066040227456, 0.028984295071235726, 0.039040855797273774, 0.07235589383968286, 0.022483451225395714, 0.04699594607310636, 0.05407989237989698, 0.06295523898942129, 0.0675510313095791, 0.2043374553322792, 12.495062776974269, 42.75682742255074, 48.341508047921316, 37.583719866616384, 20.70424042429243, 31.909296308244976, 41.52876458849226, 46.63566623415266, 18.23330467087882, 0.842070534825325, 0.04685642570257187, 0.507762682225023, 2.9542394195284163, 4.689263667379107, 5.187063012804304, 5.539966361863272, 5.552445760795048, 21.47351544243949, 42.854123047419954, 48.244865553719656, 48.19955635070801, 44.59985794339861, 46.548977034432546, 45.1740779195513, 48.08122852870396, 46.8838141986302, 48.06452505929129, 48.46706199645996, 48.16694845472063, 47.286399773189, 44.87683398383004, 42.88472638811384, 41.756140913282124, 38.37447350365775, 34.69259875161307, 32.495342118399485, 33.20472192764282, 34.166672229766846, 34.28579562050955, 36.74695873260498, 36.86777400970459, 37.01854991912842, 35.56629303523472, 35.7679888180324, 37.869850158691406, 43.272713797433035, 45.44873326165335, 46.384263038635254, 45.79315546580723, 47.002972330365864, 45.0159021786281, 37.68747384207589, 34.28832476479666, 33.402870655059814, 33.01143346514021, 32.8139066014971, 33.65995747702462, 33.896852833884104, 32.60785777228219, 34.00268432072231, 34.61820091520037, 33.57691608156477, 35.89684316090175, 35.23639604023525, 38.01433447429112, 43.866836888449534, 44.02120154244559, 47.90482071467808, 43.05719804763794, 46.05560629708426, 47.27628319604056, 43.81843226296561, 45.226081711905344, 44.354329449789866, 42.84341587339129, 39.19438525608608, 37.654185022626606, 35.933098861149375, 34.07688413347517, 34.25594963346209, 34.88050236020769, 35.33130495888846, 34.512567452022004, 34.68062005724226, 36.70432111195156, 45.22879498345511, 48.182196276528494, 50.00464275905064, 46.92022623334612, 47.01840080533709, 45.10981750488281, 43.9015222958156, 40.65418093545096, 39.69150802067348, 38.713691507067, 40.26836483819144, 41.52124316351754, 44.53459003993443, 43.03128126689366, 41.6920542035784, 40.806259632110596, 42.08233104433332, 44.303281034742085, 45.142036301749094, 46.779869147709434, 47.62420381818499, 44.587358134133474, 49.57036297661917, 49.93139484950474, 49.27918134416853, 49.496903147016255, 49.705974442618235, 46.94280787876674, 48.18296752657209, 49.965871810913086, 50.504152229854036, 50.03165735517229, 52.677131857190815, 50.70705699920654, 43.499134744916645, 26.16384826387678, 9.690069794654846, 2.7168644198349545, 6.152536485876356, 6.6202640277998785, 8.31598709310804, 3.207795036690576, 0.799272997038705, 0.2011801368956055, 1.0573181275810515, 17.860235043934413, 47.264248916081016, 44.51791088921683, 41.9430821963719, 44.05403525488717, 58.10817044121878, 41.134773935590474, 9.063201580728803, 0.09663266222923994, 0.031387523614934514, 0.006883342517539859, 0.03579486979703818, 0.022104411385953426, 0.02976225921884179, 0.007648182101547718, 0.040103540024054904, 0.028887919349861995, 0.01180097078239279, 0.008712533828137177, 0.07342793167169605, 0.008864583347791007, 0.061700308828481605, 0.04598281525873712, 0.01753327702837331, 0.018511276692152023, 0.09657643203224454, 0.09793242319886174, 0.09703052123742444, 0.17576055947159017, 0.11066461713718516, 0.12247434950300626, 0.1073102317750454, 0.16061123380703585, 0.18838714621961117, 0.1553688043994563, 0.1403696249638285, 0.11818865447172097, 0.10763691924512386, 0.11848274511950356, 0.14672911300190858, 0.13719117694667407, 0.20519614139837877, 0.14007182951484407, 0.1875879948160478, 0.18760875798761845, 0.272599815257958, 14.047709839684622, 47.42776434762137, 55.54654679979597, 42.524837493896484, 29.24956062861851, 39.10276630946568, 47.766634941101074, 52.33215727124895, 20.940223830086843, 1.159348841224398, 0.23133174968617304, 2.2663291096687317, 8.381319267409188, 13.219132815088544, 10.615709679467336, 7.644468017986842, 6.052600979804993, 23.447264160428727, 43.0356308392116, 52.35321726117815, 49.448727812085835, 47.537257535117014, 49.39300325938633, 47.360154901232036, 50.0750766481672, 49.828606673649375, 48.48284135546003, 50.87605108533587, 49.632511138916016, 48.65338488987514, 47.78422430583409, 44.29342154094151, 42.72750949859619, 40.06234727587019, 36.474502495356965, 34.084092889513286, 34.2972149848938, 35.77724381855556, 35.005993774959016, 37.66957875660488, 37.626486028943745, 37.300344535282676, 37.726522718157085, 38.14177138464791, 38.84551273073469, 45.48806701387678, 46.78275612422398, 48.75315407344273, 47.785509722573416, 48.62480694907052, 46.83867175238473, 39.83941779817854, 35.61556271144322, 34.875461442129954, 33.50635365077427, 35.591070311410085, 35.568071774074006, 34.369587421417236, 34.59409761428833, 36.35930483681815, 35.729738984789165, 36.12760673250471, 37.85329607554844, 38.36563539505005, 39.45588765825544, 46.38179990223476, 46.03168364933559, 49.94859511511666, 44.513655117579866, 48.1122487613133, 49.9525660106114, 46.16726384844099, 46.943596499306814, 45.587037154606406, 44.69697291510445, 41.67606292452131, 38.921706676483154, 37.841122831617085, 34.9926358631679, 35.889099393572124, 36.76832096917288, 37.923219272068565, 37.25601850237165, 35.92187057222639, 38.056881768362864, 47.283603123256135, 50.266225065503804, 51.50656189237322, 48.01873295647757, 48.52723339625767, 46.99594422749111, 46.930151735033306, 42.45870106560843, 40.55552693775722, 38.909992013658794, 42.929132325308665, 42.53384583336966, 46.40404456002371, 43.512690680367605, 42.71624646868025, 41.90746920449393, 43.85283974238804, 45.532139437539236, 48.01554025922503, 49.271965639931814, 51.64439330782209, 46.90381806237357, 50.258696692330496, 52.530736786978586, 51.48870849609375, 50.19635745457241, 51.27447121483939, 50.215614386967246, 50.57757037026541, 51.95492914744786, 53.53762108939034, 52.600201402391704, 56.60973930358887, 51.94248144967215, 45.049743379865376, 25.996007578713552, 10.903079356466021, 3.857537806034088, 14.408677441733223, 9.311547568866185, 18.42098593711853, 9.501081398555211, 1.6171510985919406, 0.6900770621640342, 1.4420766873019082, 22.056269543511526, 53.94829436710903, 51.72252580097744, 46.69067859649658, 48.909613609313965, 62.39485113961356, 50.03554139818464, 10.76481454713004, 0.11380569823086262, 0.16937459499708243, 0.1405553807105337, 0.13250825394477161, 0.07020800480885164, 0.14616504684090614, 0.1709424994353737, 0.12734142690896988, 0.18572396412491798, 0.08851204333560807, 0.1501458625176123, 0.1777179701519864, 0.08535429742187262, 0.09340962089065995, 0.09059532226196357, 0.14433418294148787, 0.0894161369651556], [0.020993050753272006, 0.031871305512530465, 0.030862327332475355, 0.07283000661326305, 0.020332327278863107, 0.04013967201379793, 0.055581805894949605, 0.0324277381545731, 0.031670550749238045, 0.046865131306861124, 0.031009718709226166, 0.028135140725810612, 0.0264137313102505, 0.015403671123619591, 0.03187649291274803, 0.003485891385935247, 0.05827366627220597, 0.10627883140529905, 0.026803871982597878, 0.015847760418962156, 0.10127141938677856, 4.973530973706927, 26.847290447780065, 43.195415088108604, 35.071900912693565, 28.879869563238962, 26.928888354982647, 33.0803040095738, 42.34957265853882, 20.439340353012085, 1.9654829672404697, 0.03703523859647768, 0.16824514631714138, 2.97176907317979, 3.6906538009643555, 4.08786928653717, 5.525414228439331, 5.357566595077515, 17.771346739360265, 38.65977348600115, 49.07764536993844, 45.67630761010306, 43.20337077549526, 42.92689847946167, 46.96756431034633, 45.59498936789376, 48.1559807232448, 45.69577298845564, 43.638668469020296, 44.32232257298061, 44.67321702412197, 39.43641185760498, 37.44810492651803, 32.41724784033639, 31.934612069811138, 31.26039014543806, 32.880195890154155, 31.898450170244487, 31.609224455697195, 31.417315210614884, 32.28471095221383, 31.46376391819545, 32.081493513924734, 34.66479900905064, 34.78948790686471, 33.06804043906075, 37.29669673102242, 41.527183873312815, 44.43917390278408, 46.11244950975691, 44.80947814668928, 43.955985750470845, 35.42500489098685, 32.48881775992257, 33.33088731765747, 32.43513250350952, 31.928403854370117, 31.70002351488386, 34.404005323137554, 34.961240427834646, 36.366548333849224, 34.37587554114205, 34.48439598083496, 32.49344873428345, 34.33237286976406, 35.006198746817454, 42.048277923039024, 42.7512514931815, 46.28402137756348, 41.1754869052342, 42.74704088483538, 45.39014605113438, 43.590878759111675, 42.60603066853115, 42.32469810758318, 41.9266288621085, 38.32153170449393, 36.67670202255249, 33.405076708112446, 32.464651925223215, 32.454055922372, 32.50608055932181, 31.809516702379497, 33.67480230331421, 31.459188529423304, 36.38366174697876, 43.39453656332833, 48.14708702904837, 45.16521201814924, 45.95071281705584, 47.08260563441685, 44.172001770564485, 41.43566220147269, 35.67153739929199, 33.84587390082223, 34.365453243255615, 32.51051351002285, 34.41393082482474, 33.965678215026855, 33.623938015529085, 32.054628304072786, 31.83191074643816, 33.23859786987305, 35.14080619812012, 40.82623222896031, 44.05913870675223, 43.9729254586356, 44.39092908586775, 46.362150396619526, 44.60308190754482, 47.64215448924473, 46.946486949920654, 47.427562849862234, 46.92589943749564, 48.26121466500418, 48.887566975184846, 47.68905830383301, 48.05295283453805, 48.9530085836138, 51.50683634621756, 37.199133600507466, 17.74223726136344, 3.237953258412225, 1.4218831594501222, 2.5605004216943468, 6.467504841940744, 5.180470909391131, 3.601448050567082, 0.6108930568609918, 0.11394441793007509, 1.2242504443441118, 17.451764345169067, 40.954353536878315, 40.557920592171804, 31.556074210575648, 40.52214084352766, 45.489904812404085, 30.419571263449534, 4.444367025579725, 0.0534547546745411, 0.029582566182528223, 0.024682096371959363, 0.018693458255646483, 0.015615318070298858, 0.05403452552855015, 0.06047735123762062, 0.054046528813030036, 0.05557205195405653, 0.03013981645926833, 0.07009329846394913, 0.03264793294614979, 0.08096053890351738, 0.014131859011415924, 0.03141429182142019, 0.018590490566566586, 0.05154803056003792, 0.07014837515141283, 0.05089899145865014, 0.03757138643413782, 0.019792576420253942, 0.048186493438801596, 0.03408939577639103, 0.08267468799437795, 0.08327170381588594, 0.03747146536729165, 0.04570059897378087, 0.05242628218340022, 0.03902694922206657, 0.017309879551508596, 0.05237391624333603, 0.048758437391370535, 0.013701481212462698, 0.05235619630132403, 0.14414681228143827, 0.07138911714511258, 0.05909997943256583, 0.14835419080087117, 6.269745647907257, 34.41105079650879, 48.22190523147583, 38.0374094418117, 29.137718949999126, 31.953486851283483, 38.40582724979946, 46.66597775050572, 21.296595198767527, 2.075331164257867, 0.07654558295117957, 0.567446731030941, 2.4295329579285214, 4.449948600360325, 6.874849498271942, 6.13461925302233, 4.735345423221588, 19.41834773336138, 39.98308917454311, 52.27466092790876, 47.35637508119856, 45.99477481842041, 45.15881967544556, 46.8259357043675, 47.49945586068289, 49.07066937855312, 48.139405795506065, 46.40772015707833, 47.131291661943706, 46.81005212238857, 42.18588352203369, 39.319699491773335, 35.35876771381923, 32.859170641217915, 33.83108466012137, 33.98430633544922, 34.55389186314174, 33.432497773851665, 33.79338720866612, 34.59685952322823, 33.1687649999346, 33.363818304879324, 36.885759421757285, 36.89746366228376, 34.490607670375276, 38.87169006892613, 44.94002437591553, 47.16285732814244, 47.89833457129342, 46.59993164879935, 45.316276277814595, 36.83560732432774, 34.351157324654714, 34.63087790352957, 34.220951557159424, 33.239049502781455, 33.52459267207554, 35.41541985103062, 37.28841100420271, 37.99640812192644, 36.36866058622088, 35.9473044531686, 34.59118979317801, 36.351439476013184, 37.86647680827549, 43.54818902696882, 44.54086078916277, 48.66751405170986, 42.728044509887695, 45.024941784994944, 47.458287784031455, 44.37070982796805, 44.938579150608604, 43.12996653148106, 42.54228442055838, 38.8853884424482, 38.48091990607125, 34.88671404974801, 33.37443167822701, 33.468374797276084, 33.18582282747541, 34.66215521948678, 35.44105870383126, 35.205358437129426, 39.284350531441824, 45.274024282182964, 49.25198262078421, 47.422674792153494, 47.68371861321585, 48.37281663077218, 45.1630858693804, 42.643234797886436, 37.226314953395296, 35.67462934766497, 35.63971812384469, 34.40153523853847, 36.3500394139971, 36.75258329936436, 35.01909112930298, 35.78886815479824, 33.98264571598598, 35.352132184164866, 37.27499403272356, 43.57715606689453, 45.5992659841265, 46.38108076368059, 46.68202461515154, 48.182592323848176, 46.76746661322457, 49.125587940216064, 48.74681731632778, 49.298851694379536, 48.72237702778408, 49.980244159698486, 49.60133457183838, 50.154824597494944, 50.22234371730259, 51.152512959071565, 52.56710018430437, 40.19684703009469, 18.821601697376796, 4.934714862278529, 2.8062523433140347, 5.631187958376748, 5.740262516907283, 10.864152942384992, 6.917741162436349, 0.4723858748163496, 0.07343059152896915, 1.197617022054536, 19.722164664949688, 44.17123052052089, 43.77049664088658, 33.70292861121041, 45.42181594031197, 51.75779485702515, 35.29249232155936, 6.302441264901843, 0.037320749168949466, 0.0306725376950843, 0.04190910474530288, 0.04881357514698591, 0.029809383475886922, 0.029084002399551015, 0.052763995847531726, 0.05888325534760952, 0.0386389154009521, 0.0474955955121134, 0.025899535776781182, 0.03748098860627838, 0.02958847622254065, 0.07086096584264721, 0.07728533539921045, 0.012014755114380802, 0.010775338808473731, 0.17039637374026434, 0.15504341971661362, 0.19586625775056227, 0.17317648098937102, 0.1850732219006334, 0.1195409611931869, 0.2122127634606191, 0.19433645983891829, 0.11069277634045907, 0.11721688375941344, 0.18899215518363885, 0.08899709409368889, 0.05237696286556976, 0.20759781609688485, 0.13392065172748907, 0.0782458424302084, 0.12222067240093436, 0.23448169923254422, 0.15846143130745205, 0.13719675450452737, 0.1675257906317711, 7.806118726730347, 38.68806307656424, 55.84477390561785, 45.97909273420061, 38.845182691301616, 36.496653352464946, 42.32103293282645, 50.778515747615266, 26.42610454559326, 2.736249242510114, 0.1411584219230073, 1.7933257137026106, 6.538955339363643, 10.697420494897024, 10.624195166996547, 13.191528490611486, 8.189192022596087, 19.170964070728846, 41.61703797749111, 54.434366021837505, 50.11221824373518, 46.84269823346819, 47.11858688082014, 48.07922397341047, 47.442869731358115, 50.56582791464669, 49.614793232509065, 48.40330185209002, 49.46794305528913, 49.54700313295637, 43.111397470746724, 40.47400024959019, 36.314627919878276, 34.197122710091726, 35.726695673806326, 36.208619253976, 35.83285025187901, 35.41852569580078, 34.91172061647688, 36.24996450969151, 34.90402896063668, 35.47242982046944, 39.13650328772408, 38.741216795785085, 36.47306769234793, 40.137401717049734, 46.032645974840435, 48.788138253348215, 48.48340763364519, 48.66284486225673, 48.53273984364101, 37.75760201045445, 36.59002324513027, 36.236370359148296, 36.15317610331944, 35.17316395895821, 35.04487936837332, 38.03838218961443, 40.000209535871235, 40.60086393356323, 38.57532855442592, 37.18613004684448, 35.91440125874111, 39.05864872251238, 39.155586515154155, 45.28456817354475, 47.3414295060294, 48.008258547101704, 45.147198813302175, 45.084873471941265, 48.47961739131382, 46.56852926526751, 45.94454281670706, 46.34222991125924, 45.4571544783456, 40.81984336035592, 39.75719281605312, 36.40142829077584, 35.74102980749947, 35.22219739641462, 35.931761332920615, 35.61326633180891, 37.79347555977957, 35.35476207733154, 41.226417200905935, 46.91668265206473, 52.153143882751465, 47.042750767299104, 47.377320425851, 50.5831949370248, 47.52771765845162, 46.481909547533306, 39.233166626521516, 36.842138631003245, 38.40051187787737, 35.94425419398716, 38.85916594096592, 36.667874336242676, 37.42196232931954, 36.298720019204275, 34.93979133878435, 36.12935420445034, 38.220789773123606, 45.0894592830113, 49.97227805001395, 47.76682949066162, 48.955172947474885, 51.00731297901699, 47.93550048555647, 49.10801942007882, 50.3327123778207, 49.94242858886719, 50.70804016930716, 51.72892509187971, 52.62275872911726, 50.815664291381836, 51.7761207308088, 52.10524647576468, 56.39855228151594, 40.96200697762625, 21.06065695626395, 4.568427111421313, 3.525790636028562, 8.18946213381631, 14.070030059133257, 13.945078866822378, 10.167132241385323, 2.4598244982106343, 0.25134872272610664, 2.116471230983734, 24.084881237574987, 52.06884833744594, 51.13231801986694, 42.917615686144146, 53.74544518334525, 58.50076798030308, 40.693427835192, 7.350780691419329, 0.21971347954656395, 0.16617999784648418, 0.1419437854949917, 0.09905079140194825, 0.08760657227997269, 0.12112102497901235, 0.0962885906919837, 0.16884187715394156, 0.12257397201444421, 0.19060989123369965, 0.14889502392283507, 0.20199490817529814, 0.2023144303155797, 0.0988051685105477, 0.1993006763181516, 0.10351018461265735, 0.09460031414138419], [0.02147316008007952, 0.011560670150044774, 0.07146497736019747, 0.03486647104312267, 0.03397587686777115, 0.015749323647469282, 0.014130697020196488, 0.05265201721340418, 0.06365391971277339, 0.019634262326040437, 0.025632951242317046, 0.043226046221596856, 0.012514058500528336, 0.04088638962379523, 0.031016286928206682, 0.05219142085739544, 0.02799646682771189, 0.07883986591228417, 0.04311305317761643, 0.04599883547052741, 0.057359951016094, 1.9821723231247492, 20.349529675074987, 42.530180658612935, 44.10824510029384, 29.847737993512833, 24.43020670754569, 34.882673672267366, 39.989901883261545, 29.08730455807277, 3.9048611181122914, 0.07254636540476765, 0.42840771323868204, 2.7844165435859134, 2.227822410208838, 5.526322705405099, 3.9501525163650513, 3.104204995291574, 13.973128744534083, 35.89247621808733, 47.0333776473999, 48.405983856746126, 45.57925864628383, 46.87763377598354, 46.60339185169765, 46.35161345345633, 45.917962482997346, 44.78727517809187, 44.49244574138096, 40.58980934960501, 37.59914486748831, 33.787509032658164, 31.335170132773264, 30.017166342054093, 31.238499845777238, 31.0963397026062, 32.52137007032122, 32.406193256378174, 32.92668628692627, 31.760441575731548, 31.35784557887486, 32.21299859455654, 32.44149010522025, 32.472110816410606, 36.5229766028268, 38.37651627404349, 40.74548373903547, 42.17973436628069, 43.616013867514475, 44.9318220274789, 43.80944129398891, 39.135648659297395, 32.860952854156494, 32.84589958190918, 32.39889069965908, 30.524291038513184, 31.334294659750803, 32.857829638889854, 39.06479787826538, 37.64828600202288, 39.56053447723389, 37.737688473292756, 38.82797200339181, 35.46584292820522, 35.46311923435756, 36.551102910723, 41.72582244873047, 42.33511345727103, 47.392217363630024, 39.697212491716655, 43.43055255072457, 45.68110881532942, 42.8704617364066, 43.57631533486502, 41.22140754972185, 41.751374449048726, 37.77699095862252, 36.015987396240234, 33.684640952519004, 32.95013993127005, 31.409463746207102, 32.26975842884609, 31.909796578543528, 34.24964414324079, 32.3934884752546, 36.547521114349365, 43.469462462833945, 45.79267604010445, 45.340542861393516, 45.2264221736363, 45.765984535217285, 43.47890159061977, 39.99028056008475, 34.05688374383109, 32.7518070765904, 31.493311132703507, 33.398472445351736, 32.274108001164024, 34.16244077682495, 33.62392064503261, 32.97718579428536, 32.77684838431222, 32.92653342655727, 33.25348438535418, 34.35353708267212, 36.989965030125205, 41.751364026750835, 41.19320828574044, 43.163286617824006, 43.3016356740679, 44.544970648629324, 46.82769012451172, 45.623900822230745, 46.011825697762625, 44.75740834644863, 44.36170843669346, 46.00919580459595, 45.09429175513131, 49.897612707955496, 47.586520263126914, 34.18468196051461, 12.158855080604553, 2.848681083747319, 1.161986768245697, 4.665390959807804, 4.901449058737073, 10.603271535464696, 3.0559701664107184, 0.03641933236005051, 0.0817203081345984, 1.6362214067152567, 21.423007249832153, 38.600335121154785, 31.940285273960658, 29.917272090911865, 40.396322863442556, 42.30573647362845, 22.972769941602433, 2.532142434801374, 0.045828021064932854, 0.08871201439095394, 0.07010689630572285, 0.03109274764678308, 0.018266540985288363, 0.04507208555670721, 0.036490446222679954, 0.021819268918729255, 0.025328553647601178, 0.044498733643974574, 0.014719531405717134, 0.02901552464546902, 0.04381528603179114, 0.025387530215084553, 0.012838319359746362, 0.01588834699110261, 0.0035278216694548193, 0.015370619682861226, 0.0214049435619797, 0.02131438797472843, 0.08590813806014401, 0.03729227105421679, 0.009910706231104476, 0.06319633605224745, 0.06837614346295595, 0.03302502539008856, 0.01597092639920967, 0.05312250321730971, 0.07823647864695106, 0.01928902031587703, 0.04556680204612868, 0.041976354351001124, 0.017403734515288045, 0.0069808259473315305, 0.013388947982873236, 0.03799267525651625, 0.05240560382870691, 0.07721100188791752, 2.948995918035507, 25.433231285640172, 49.193169593811035, 48.55009644372122, 35.22587994166783, 31.286616121019634, 39.170403548649375, 44.95456348146711, 30.568481581551687, 4.537636603627886, 0.07766186126640864, 0.5371652873499053, 3.9496448636054993, 3.685097847666059, 6.538906267711094, 4.578210609299796, 5.449629357882908, 14.93775497164045, 37.31925753184727, 50.84542342594692, 50.3264034135001, 47.554853848048616, 47.797523157937185, 48.45584412983486, 47.38824994223458, 48.87543889454433, 47.089588574000764, 46.47773368018014, 43.71184689658028, 40.89896944590977, 36.07792363848005, 33.72054576873779, 32.09212078366961, 31.887402534484863, 32.540404660361155, 33.56144939150129, 33.75777074268886, 33.16294935771397, 33.08826664515904, 33.088905879429404, 34.370785985674175, 34.458072730473106, 34.72971602848598, 37.79446915217808, 37.91503082002912, 41.846387590680806, 44.42678526469639, 45.61073398590088, 47.08290440695626, 45.63190862110683, 40.89635344914028, 35.365472725459504, 33.89079400471279, 33.76313475200108, 32.33002710342407, 32.277265957423616, 34.79786743436541, 39.27000944955008, 40.291248730250764, 40.957372529166086, 39.082661696842735, 38.88015644890921, 37.54252052307129, 37.266798632485525, 39.2550082887922, 42.77927010399954, 44.51358910969326, 48.79216126033238, 41.30106169836861, 44.76059409550258, 46.96555975505284, 44.67959199632917, 45.65771075657436, 43.60181869779314, 42.09807218824114, 40.14784138543265, 38.45593418393816, 36.75837114879063, 33.95974097933088, 31.876646723066056, 34.170170647757395, 33.78734227589199, 36.09618003027779, 34.68380928039551, 38.6401344026838, 44.15878282274519, 47.009489740644185, 48.147955553872244, 46.48133979524885, 48.29881831577846, 44.81221226283482, 42.61241953713553, 36.099595069885254, 35.43943282536098, 33.47708783830915, 34.65188578196934, 33.77352230889456, 35.57136174610683, 34.81609950746809, 33.78242989948818, 34.28978736060006, 33.9698714528765, 35.19137518746512, 37.54234334400722, 39.637916564941406, 43.53274665560041, 43.51562976837158, 44.42830344608852, 45.64350863865444, 47.84597642081124, 47.69195570264544, 46.80012662070138, 48.29090779168265, 47.60602385657174, 46.738134792872835, 47.73192521503994, 47.55942228862217, 50.977956839970176, 49.84145736694336, 35.2869302885873, 15.009038278034755, 4.39274798972266, 4.326671923909869, 9.20839808668409, 9.806201117379324, 7.138719933373587, 5.021064903054919, 0.5133442570056234, 0.18852748083216803, 1.70765420794487, 23.77482656070164, 45.211751052311485, 39.248292854854036, 36.50965690612793, 47.224220343998496, 47.90427875518799, 27.50408455303737, 3.2413168379238675, 0.013744143253591443, 0.0902849060616323, 0.022823495657316277, 0.06239558330604008, 0.007509355533069798, 0.026981902608115758, 0.054699289678995094, 0.02841924164178116, 0.016384612236704146, 0.01607717650144228, 0.04863443511671253, 0.029512344593448297, 0.02433804519075368, 0.06382319384387561, 0.05119447988857116, 0.05075727942000542, 0.01576250249386898, 0.1070882829704455, 0.1288234152431999, 0.08133034727403096, 0.1341271706457649, 0.1199158246495894, 0.11317226543490376, 0.16296923799174173, 0.17790698286678108, 0.1931408132825579, 0.1078818907429065, 0.11806897446513176, 0.1658533646592072, 0.09804843233100005, 0.09636871889233589, 0.15521679898457869, 0.10665135391588722, 0.07832040664340768, 0.15695996901818685, 0.09548811614513397, 0.150929597605552, 0.17688204215041228, 3.1056606428963796, 28.712636845452444, 54.10965238298689, 53.77484995978219, 39.73220361982073, 33.94644907542637, 44.7578877721514, 49.67909186226981, 35.53278534752982, 5.219032543046134, 0.1331691470529352, 1.1179479999201638, 8.270337428365435, 9.264346718788147, 13.09021246433258, 8.053115895816259, 6.693391212395259, 14.56313589641026, 38.76752962384905, 51.88885872704642, 53.242148944309776, 49.39563315255301, 49.61877107620239, 49.20176451546805, 49.25489044189453, 51.17442062922886, 49.54616240092686, 50.372497762952534, 44.41305562428066, 41.9425402368818, 37.77942630222866, 34.99251079559326, 34.12714045388358, 33.48323004586356, 33.999995367867605, 35.210586956569124, 36.06241873332432, 35.33415372031075, 34.58634342466082, 34.711786202022004, 35.544927324567524, 35.445641040802, 36.051478794642854, 41.17163412911551, 42.79520232336861, 44.650583267211914, 46.306151390075684, 46.268558161599294, 49.13505833489554, 46.89394814627511, 42.24331733158657, 36.49494062151228, 35.76289231436593, 35.40531369618007, 34.662790979657856, 33.796823092869346, 36.684980801173616, 42.13533190318516, 41.602363382067, 43.232188429151265, 40.99674449648176, 43.458984579358784, 39.38214642660958, 40.631178924015586, 41.915157386234824, 44.90089906964983, 45.91005195890154, 51.67058106831142, 43.85351024355207, 45.90174191338675, 49.419656549181255, 46.29237311226981, 47.50355182375227, 44.68987880434309, 44.12389244352068, 42.79916974476406, 39.92005511692592, 37.98639229365757, 35.77135522024972, 34.13124336515154, 34.8896427154541, 34.99450492858887, 37.601420402526855, 35.88101169041225, 39.76725728171212, 45.89619377681187, 48.585890088762554, 48.96128041403634, 46.4211996623448, 49.89519820894514, 46.12535578863961, 43.93745143072945, 38.258535861968994, 36.700409276144846, 34.38979625701904, 36.49560417447771, 34.72722509929112, 37.916788714272634, 37.39935983930315, 35.295945576259065, 36.0910279410226, 35.98358447211129, 36.59078059877668, 39.01687615258353, 40.77240106037685, 46.62773486546108, 44.83723272596087, 46.379298550742014, 48.38692494801113, 49.40185179029192, 50.90161350795201, 50.16670254298619, 51.71198190961565, 49.66821445737566, 47.84738343102591, 51.43562078475952, 49.92949104309082, 53.703175817217144, 51.45321362359183, 37.20487628664289, 14.94168244089399, 4.00783211844308, 4.760561304433005, 10.831515516553607, 11.818347317831856, 15.314045088631765, 7.180103838443756, 1.1874714578901018, 0.3231414189296109, 2.5023337943213324, 28.589617252349854, 52.29309449877058, 44.54604067121233, 41.92673308508736, 52.300859110695974, 55.125850745609824, 31.141645431518555, 4.0370636241776605, 0.13961959949561528, 0.3263150357774326, 0.14561170153319836, 0.19449035158114775, 0.12106558866798878, 0.1293236312589475, 0.08257349128169672, 0.15105577797761985, 0.061710134015551636, 0.13708491836275372, 0.09770424544279065, 0.08461618702858686, 0.13221887233001844, 0.12027250336749212, 0.08840363379567862, 0.162582540884614, 0.11273332113134009], [0.019370602277506675, 0.04122714991016047, 0.036984107590147426, 0.05464211631832378, 0.049487696295338016, 0.15281334652432374, 0.024863655379574214, 0.029548788709299903, 0.011040370345913937, 0.04173004274655666, 0.03410864242219499, 0.06469144725373813, 0.022512090492195318, 0.01879452265399907, 0.025214317188199078, 0.04936336153852088, 0.05538658458473427, 0.04373736307024956, 0.08401871658861637, 0.016970890241542032, 0.05138521608231323, 0.8482171392866543, 15.022787025996617, 38.075704438345774, 43.14117744990757, 30.816539219447545, 28.434498718806676, 28.979944467544556, 38.62298277446202, 33.38465247835432, 7.225642332008906, 0.09207033525620188, 0.5884967872074672, 5.458237307412284, 3.8927130614008223, 4.248198534761157, 3.2539132705756595, 2.234409519604274, 11.97054065976824, 31.42403064455305, 48.16691023962838, 48.686357566288535, 46.95550223759243, 45.695950167519705, 46.90919944218227, 45.273176601954866, 45.75817476000105, 42.64232458387102, 37.85877125603812, 33.6683474268232, 31.66735655920846, 31.34917422703334, 32.44993564060756, 33.58110237121582, 37.59164081301008, 38.36161238806588, 39.5754348891122, 34.54944501604353, 32.49342441558838, 32.1383193561009, 31.923196179526194, 31.64455951963152, 34.435049874441965, 34.15796961103167, 40.22199950899397, 43.51638017381941, 43.621895517621724, 43.25569418498448, 45.55434240613665, 45.49347618647984, 42.84465265274048, 37.59996822902134, 32.02539375850132, 31.5973847252982, 32.557518073490684, 30.8430882862636, 33.6833381652832, 39.60323115757534, 44.43517174039568, 41.43177121026175, 43.30935512270246, 41.50562013898577, 40.965251786368235, 36.00983476638794, 38.41359880992344, 36.81607941218785, 39.734857831682476, 40.4515506199428, 45.781683989933555, 39.776602608816965, 41.12184681211199, 46.92815065383911, 41.554976667676655, 44.933392320360454, 42.903750555855886, 40.598824637276785, 39.30365610122681, 37.20685999734061, 34.58054167883736, 31.506679466792516, 32.764431953430176, 31.806473391396658, 32.82939066205706, 32.94085366385323, 33.067571435655864, 34.86932965687343, 41.818500995635986, 44.361374923161094, 47.060461725507466, 46.454717772347585, 46.86431407928467, 44.59115532466343, 42.50608777999878, 35.915349687848774, 33.91752372469221, 33.09615979875837, 33.62016861779349, 32.859736919403076, 35.15261466162545, 33.04780381066458, 34.69433232716152, 32.455174582345144, 33.073463508060996, 33.48667982646397, 33.460599763052805, 32.28817115511213, 34.05724505015782, 36.10295452390398, 36.07344552448818, 38.66727754047939, 41.51250580378941, 41.97327559334891, 43.83393716812134, 40.6713673046657, 40.87447009767805, 40.12209830965315, 43.004020009722026, 45.08969552176339, 49.07619667053223, 47.617443220955984, 29.963064193725586, 10.060399225779943, 3.2399534710815976, 2.881047312702451, 7.0626462783132276, 5.217268569128854, 9.24446097442082, 7.896879570824759, 0.11923400552145072, 0.011549280939756759, 2.2000139823981693, 20.768693651471818, 40.4290315083095, 26.98853690283639, 24.980806282588414, 41.576540402003694, 42.47460549218314, 17.78425475529262, 1.7564490182059151, 0.1278645774083478, 0.011310710571706295, 0.06577569193073682, 0.06130504182406834, 0.017664288569773947, 0.05552506340401513, 0.03221756871789694, 0.07142518128135375, 0.0855636526165264, 0.036739030919436894, 0.01763916920338358, 0.02732828286077295, 0.05013223331687706, 0.033888712259275575, 0.02668004951971982, 0.058960750832089355, 0.04292102098198874, 0.07481316769761698, 0.048338732948260646, 0.0110558892899592, 0.05705391815198319, 0.029167133117360727, 0.05337309977039695, 0.03778055503166147, 0.012047396041452885, 0.02770209119522146, 0.006209709490316787, 0.04393264205594148, 0.08944332586335284, 0.022263515973463655, 0.02895264819796596, 0.03689236965562616, 0.02992352663672396, 0.015497032453172972, 0.02490954639922295, 0.03872317248689277, 0.02413613861426711, 0.03514218356992517, 1.155902317592076, 19.17853934424264, 45.68960298810686, 48.20994390760149, 36.37656416211809, 27.524397611618042, 32.46248408726284, 42.832111154283794, 38.00188330241612, 7.136779648917062, 0.1977138000407389, 0.6544206983276776, 5.419183654444558, 3.877495203699384, 8.431330663817269, 4.03515373808997, 2.625454136303493, 12.6351523569652, 33.3707526070731, 49.781331130436485, 51.487895556858604, 48.142330987112864, 48.264528955732075, 48.445036206926616, 48.22282586778913, 47.585391180855886, 44.295332295554026, 41.842149189540315, 35.81030682155064, 34.40234817777361, 31.92761175973075, 33.17155122756958, 34.630579130990164, 38.44694321496146, 39.37916912351336, 40.56780787876674, 35.910572801317485, 34.240323134831016, 33.32567964281355, 32.659625325884136, 33.07997397014073, 35.359170709337505, 36.21736008780343, 42.288779394967214, 44.81927163260323, 45.046602794102256, 46.19850294930594, 48.04258959633963, 45.759192671094624, 44.89486803327288, 40.42971590587071, 34.311479636601035, 31.98704317637852, 33.90555892671858, 32.002978869846885, 35.07892206736973, 41.67526388168335, 44.831872190747944, 42.32074110848563, 44.862242766789024, 43.51808248247419, 42.42086117608206, 37.94334472928728, 40.45493786675589, 38.687639236450195, 41.682788780757356, 44.088540009089876, 47.26650708062308, 42.87311247416905, 41.934497697012766, 48.290011474064414, 44.53855398723057, 45.68994344983782, 43.82396650314331, 42.82830354145595, 39.335690770830425, 39.09578684398106, 37.31289645603725, 33.5150910105024, 33.629812717437744, 33.27827903202602, 33.88796608788626, 35.27681023733956, 35.14040320260184, 36.7463264465332, 43.931691374097554, 45.30563163757324, 49.43296234948294, 46.52391488211495, 47.562562874385286, 46.229849747249055, 43.526239667619976, 35.895102637154714, 34.980438300541465, 35.007751669202534, 34.108581815447124, 34.10379103251866, 36.475774015699116, 34.66481637954712, 35.82635021209717, 33.971174240112305, 34.420222418648855, 34.41377101625715, 34.38793413979666, 34.22806303841727, 36.16003744942801, 38.650883265904014, 39.96013927459717, 42.265728746141704, 43.70589229038784, 44.392624446323936, 46.92294992719378, 44.338807174137656, 43.61934552873884, 42.79850966589791, 43.62951421737671, 46.41713844026838, 49.59179816927229, 49.448779923575266, 32.50337076187134, 12.05678083215441, 4.031758674553462, 6.46613734960556, 7.536578127316066, 12.339505638395037, 3.9291098969323293, 3.4343888206141333, 0.7000580951571465, 0.09272409017596926, 2.46358260512352, 24.97577404975891, 43.70793158667428, 32.42537375858852, 26.797638620649064, 47.270123617989675, 47.903375489371165, 23.419019733156475, 1.861677097422736, 0.02163844951428473, 0.03953075468806284, 0.055536700279584954, 0.1290043941033738, 0.030931717716157436, 0.029905345290899277, 0.05097520790461983, 0.027586777561477253, 0.029410187753715684, 0.0067361648793199235, 0.013592589912669999, 0.013923296006396413, 0.011391487621170069, 0.022699213486963084, 0.022972093130062734, 0.056075484225792546, 0.10855815945459263, 0.14139455210949692, 0.11380755741681371, 0.19438224738197668, 0.18118784895965032, 0.15757464032088006, 0.2148508397596223, 0.11433514553521361, 0.1315244324505329, 0.10590148451072828, 0.07550086293901716, 0.09544901895735945, 0.19449848043067114, 0.13607962802052498, 0.08556839557630674, 0.11519014037081174, 0.11289207796965327, 0.20183680951595306, 0.1130605853561844, 0.145199002964156, 0.11091984129909958, 0.12879878442202294, 1.2972026211874825, 22.314334324428014, 50.66636487415859, 54.26721320833479, 40.6759809085301, 36.871088300432476, 38.436420168195454, 48.42397274289812, 41.019617966243196, 10.004145741462708, 0.31260067597031593, 1.392179827604975, 8.986443962369647, 9.67751179422651, 13.799219676426478, 8.63956035886492, 4.118853909628732, 13.661658372197833, 35.097970553806846, 49.85630914143154, 52.25847857339041, 49.880582673209055, 49.94900158473423, 49.08024399621146, 48.54517364501953, 49.93479599271502, 46.83226203918457, 42.027280466897146, 37.59996475492205, 35.7135774748666, 34.88565444946289, 35.32052135467529, 36.83632298878261, 41.88655512673514, 42.01342575890677, 45.05830008643014, 39.38802807671683, 35.31731128692627, 35.21487052100045, 34.681113379342214, 34.01158496311733, 37.77028942108154, 38.14047901970999, 44.12222140175955, 46.56809152875628, 46.99751104627337, 47.20471327645438, 49.35641751970564, 46.983232498168945, 46.48702342169625, 41.794727734157014, 36.347419943128315, 34.545265674591064, 35.603830678122385, 34.27210419518607, 37.79879093170166, 43.92342301777431, 48.0425374848502, 43.41050699778965, 46.865957328251426, 46.67564616884504, 44.902778557368684, 39.449988637651714, 44.05545268739973, 41.331977707999094, 43.80612700326102, 46.86186136518206, 48.96019649505615, 45.15812138148716, 42.807861941201345, 49.663277762276785, 46.18107339314052, 48.12249388013567, 47.125614983694895, 44.39116185052054, 42.914579323359895, 41.86093364443098, 38.23179224559239, 35.63971812384469, 35.89781590870449, 35.06771114894322, 35.340177808489116, 36.86877802440098, 36.74404048919678, 37.68479183741978, 44.859053543635774, 46.800331592559814, 50.55692727225167, 47.731487478528706, 49.464514119284495, 48.215676171439036, 46.02755641937256, 37.99580362864903, 35.938716479710166, 37.1231689453125, 35.65766879490444, 36.663278102874756, 38.01028714861189, 36.50766624723162, 37.561947686331614, 36.05331311907087, 35.48764637538365, 37.037490708487375, 36.770030226026265, 36.12986489704677, 37.37730278287615, 40.319840567452566, 40.5933564049857, 43.19602305548531, 44.45546742847988, 45.99050167628697, 48.55825710296631, 45.013477257319856, 44.889198303222656, 43.84128141403198, 45.31479631151472, 50.3489989553179, 52.66535813467843, 51.961505617414204, 34.70584896632603, 13.892313378197805, 5.347100870949881, 8.267968961170741, 15.788546255656652, 13.95622204031263, 17.281194755009242, 13.413744040897914, 1.4606915627207075, 0.4263435825705528, 3.4431263974734714, 28.986447981425695, 52.22398771558489, 40.037417139325825, 34.833417892456055, 53.71691935403006, 55.70509079524449, 27.341225726263865, 2.47873032944543, 0.15129450016788074, 0.09793965638216053, 0.13452114164829254, 0.3047920949757099, 0.0913494121549385, 0.106876573259277, 0.10578333799328123, 0.15739633488867963, 0.3632592590791838, 0.12671097288174288, 0.15404503686087473, 0.1588093297822135, 0.20383519014077528, 0.09067709930241108, 0.186005189748747, 0.17886006672467503, 0.17118948618216173], [0.050763874780386686, 0.05160894604133708, 0.053898268911455355, 0.018890925516773547, 0.019796905473672917, 0.03172450106857078, 0.0411175936460495, 0.023185394005849957, 0.05668531418112772, 0.040485640056431293, 0.044146638430122814, 0.011985866485961845, 0.0624205262533256, 0.01892232133208641, 0.01328429498244077, 0.019043633215395466, 0.0564462561160326, 0.024838405395192758, 0.10559681550200496, 0.04856814563806568, 0.06599114715520825, 0.2711827627250126, 9.46313554900033, 35.58785676956177, 47.29892042704991, 36.608456815992085, 23.972766842160905, 25.853508710861206, 36.89676884242466, 34.410067626408164, 14.161583866391863, 0.8630450293421745, 0.14353138101952417, 2.4884918970721106, 3.782683994088854, 3.281778803893498, 2.9091358397688185, 1.6070610114506312, 8.064021093504769, 28.72946538243975, 46.71747432436262, 51.21815953935896, 48.712239606039866, 47.148808070591514, 46.088092599596294, 43.47218268258231, 39.572263036455425, 34.68107863834926, 33.18134123938424, 31.731550965990337, 33.704425948006765, 37.258412156786235, 40.15265301295689, 43.00063623700823, 44.395334243774414, 45.37736483982631, 44.812559672764365, 43.99758114133562, 34.74765975134713, 31.952302183423722, 33.45305054528372, 31.512675762176514, 34.30451059341431, 38.869174821036204, 45.53980677468436, 45.29587984085083, 46.62773139136178, 45.205021721976145, 47.31608247756958, 42.796876839229036, 40.50517334256853, 34.50829083578927, 32.43957587650844, 31.96794605255127, 31.49382529939924, 29.61532075064523, 37.67107261930193, 43.62567186355591, 43.6917005947658, 46.032190867832725, 44.73455572128296, 45.148560660226, 42.84276621682303, 39.15208462306431, 40.421600409916465, 35.83791201455252, 41.96385383605957, 43.194748061043875, 47.62183100836617, 36.76513522011893, 41.198256152016775, 45.42538731438773, 45.842369556427, 46.89658498764038, 42.88888488497053, 40.694841793605256, 38.34966148648943, 37.234993253435405, 34.58165686471121, 31.587476594107493, 32.63292687279837, 32.29268748419625, 31.702924387795584, 32.689047472817556, 32.94452231270926, 34.77149207251412, 38.740125928606304, 42.64444031034197, 45.85387577329363, 46.41821888514927, 47.275310448237825, 44.9720903124128, 41.81347744805472, 36.30579328536987, 33.310035773685996, 32.76572431836809, 31.48817641394479, 32.87491873332432, 32.34627546582903, 39.69064991814749, 41.0211500440325, 39.10850552150181, 35.52561133248465, 33.31449999128069, 33.82052339826311, 33.62806524549212, 32.11555358341762, 32.19247014181954, 31.946660246167863, 33.565489768981934, 34.82857499803816, 33.79043075016567, 35.71436262130737, 35.76603984832764, 37.27614048549107, 40.62957041604178, 44.936557224818635, 45.57752159663609, 50.238793577466694, 45.39187267848423, 27.386102403913224, 6.928695431777409, 2.5079255742686133, 6.611658683844975, 8.107793007578168, 14.57726332119533, 9.99723662648882, 2.596340749944959, 0.16921131233019487, 0.15457843323903425, 3.0965092139584676, 24.59466883114406, 36.330362115587505, 36.20886244092669, 29.860936096736364, 45.49905906404768, 35.85428891863142, 12.620973689215523, 0.7892666682600975, 0.06455122799213443, 0.04319316441459315, 0.07337896179940019, 0.04910663442154016, 0.021862362677763616, 0.060400167879249365, 0.07223379824842725, 0.04814829191725169, 0.03731155841212187, 0.015137476746791174, 0.0205749866685697, 0.033867738741849146, 0.03636588415663157, 0.009710467154426234, 0.009230601252056658, 0.04077827524659889, 0.02876935892605356, 0.05523123399221471, 0.014762277415554439, 0.05276155651413968, 0.01955292633335505, 0.03046809509396553, 0.009191657582830106, 0.0791978474174227, 0.013478604511224797, 0.05430468763890011, 0.0584364061110786, 0.05450678250885435, 0.02886578893022878, 0.019159029969679456, 0.04859032016247511, 0.03296422865241766, 0.03691262053325772, 0.02725814948124545, 0.024801588085080897, 0.034697325833673985, 0.0781786267512611, 0.062448386901191304, 0.34286404347845484, 12.193233030182974, 41.52229234150478, 52.75424296515328, 38.90317235674177, 24.897120441709244, 29.029801266533987, 40.687594822474885, 37.543024267469136, 13.346678291048322, 0.7939251097185271, 0.10260237261120762, 4.056380919047764, 5.9692160827772955, 3.355221697262355, 5.295301181929452, 2.7975436449050903, 9.696762646947588, 30.436993871416362, 48.08255216053554, 50.79903030395508, 51.160298415592735, 48.310480867113384, 47.00960438592093, 45.35196917397635, 42.29162120819092, 37.775736808776855, 34.85412352425711, 33.54320689610073, 35.37751047951834, 38.37567554201399, 40.79362780707223, 43.95338365009853, 44.94927937643868, 45.12122644696917, 47.33685411725725, 44.80001122610909, 37.37891476494925, 33.38547583988735, 35.16662917818342, 33.34706967217581, 36.633949756622314, 40.17988995143345, 48.20899200439453, 47.18885748726981, 48.22362838472639, 46.40948847361973, 48.844383920942036, 44.66792597089495, 42.582194873264854, 36.717842306409565, 33.44327095576695, 32.36281565257481, 32.8776980127607, 30.997404302869523, 39.499647412981304, 44.56342158998762, 45.79056378773281, 48.42901366097586, 46.616968631744385, 46.21743679046631, 44.49380758830479, 40.66703857694353, 40.94652986526489, 37.80769157409668, 43.50394984654018, 46.07122932161604, 48.90499653135027, 40.09021650041853, 40.72278050013951, 46.26043224334717, 46.64892339706421, 47.84508010319301, 44.57650852203369, 43.176912035260884, 40.64145878383091, 38.71044322422573, 37.076171330043245, 34.161276953560964, 33.74111591066633, 33.764315945761545, 33.59343542371477, 33.78628614970616, 34.448529379708425, 35.897906235286165, 40.42704084941319, 44.85537794658116, 47.59335034234183, 46.20652117047991, 47.870746748788015, 45.985439913613455, 43.56425673621041, 38.10417120797293, 34.28974567140852, 34.575493812561035, 32.50084161758423, 34.79668624060494, 33.749686513628276, 40.20389597756522, 42.5807774407523, 40.330662386757986, 37.1140251159668, 34.77838815961565, 35.45608418328421, 34.63746132169451, 34.4507771219526, 33.58852652141026, 33.01861790248326, 35.24345541000366, 36.1261545589992, 37.39161259787423, 37.54353496006557, 38.913542543138774, 38.78905861718314, 42.092982632773264, 45.44343178612845, 47.664489473615376, 51.59723240988595, 48.344843183244976, 28.65924515042986, 9.27800166606903, 3.1882349891321997, 5.381138358797346, 5.53818849154881, 8.788162350654602, 13.01713044302804, 1.7103031000920703, 0.11486494567777429, 0.11798214912414551, 3.6935594507626126, 28.05413522039141, 45.82510328292847, 39.45299025944301, 34.50800595964704, 48.03898695537022, 43.8262038230896, 16.844708919525146, 1.0311442634889056, 0.1462613988135542, 0.0440122036795531, 0.035926413988428454, 0.037412884046456645, 0.029520900920033455, 0.07749863966767277, 0.023157687724700997, 0.015120338648557663, 0.055034380805279524, 0.05304959123688085, 0.02830425200850836, 0.011764529211047505, 0.09120069084955112, 0.028687449571277415, 0.021309219234223877, 0.05033240793272853, 0.005790130152100963, 0.10348393209278584, 0.127425008852567, 0.10471691843122244, 0.1235254816710949, 0.1310678869485855, 0.0849422909585493, 0.16704363721821988, 0.08503980322607926, 0.1538723904107298, 0.20611817549381936, 0.14286397397518158, 0.11699227509754044, 0.18021412406648907, 0.0975870420890195, 0.11800635925361089, 0.09318577218800783, 0.08455203154257365, 0.11570156578506742, 0.1349328359855073, 0.17980618881327765, 0.19721627102366515, 0.5548580065369606, 13.103242942265101, 48.189898354666575, 60.18603270394461, 46.874791962759836, 34.463141441345215, 37.17479058674404, 45.319354329790386, 44.348718779427664, 17.07627500806536, 1.6010057649442127, 0.38309796739901814, 6.171392159802573, 11.035491177013942, 10.20143028667995, 8.233297450201851, 3.6904058371271407, 9.586528607777186, 30.92191559927804, 49.7604135785784, 53.53428942816598, 52.75149495261056, 50.21547889709473, 49.487839221954346, 46.0074657031468, 43.283775329589844, 37.39461074556623, 35.58609887531826, 34.928834029606406, 37.40458835874285, 41.15251963479178, 44.55922140393938, 45.895161969321116, 48.089903354644775, 49.078656332833425, 48.843567507607595, 49.48322909218924, 40.79678576333182, 35.95667062486921, 36.99247680391584, 34.34579678944179, 39.329774379730225, 42.114539418901714, 50.25862373624529, 49.2447634424482, 51.2335775920323, 48.11477790560041, 51.42283957345145, 46.81656605856759, 42.722298349652974, 38.62882968357631, 35.97205393654959, 35.150012561253135, 35.560053552900044, 32.12531927653721, 42.28115374701363, 48.38557004928589, 47.02762801306588, 50.71071522576468, 47.9421568598066, 49.28583771841866, 46.369043009621755, 42.469682693481445, 42.42823321478707, 40.10212571280343, 44.18822234017508, 47.41780757904053, 51.144435678209575, 42.54420559746878, 42.272339957101, 46.63015978676932, 48.36677169799805, 50.19178901399885, 47.32305499485561, 44.05750935418265, 43.071737153189524, 40.86321749005999, 39.5084090914045, 35.16931465693882, 35.28605134146554, 36.13820620945522, 35.82176092692784, 34.61634922027588, 35.39567654473441, 38.80090529578072, 43.083288533346995, 47.2999244417463, 48.69602598462786, 48.048030035836355, 49.683267729622976, 48.41519021987915, 44.82889836175101, 39.74660723549979, 37.18637670789446, 36.37990624564034, 35.616333961486816, 37.27163110460554, 35.720178263528005, 43.76746027810233, 46.85385704040527, 42.51727785382952, 40.166882923671174, 36.37531001227242, 38.22167566844395, 36.66548763002668, 36.17049101420811, 35.42997980117798, 34.6752074105399, 37.128901209150044, 38.33171081542969, 37.51064566203526, 40.09981196267264, 40.03069475718907, 41.398273944854736, 44.59469543184553, 48.55249357223511, 49.2356230872018, 53.79584741592407, 47.712077685764854, 30.800120626177105, 9.31920622076307, 7.138773347650256, 11.724729895591736, 18.488551957266672, 23.558325903756277, 14.747608831950597, 6.118127269404275, 0.413829686918429, 0.3975110282855374, 4.714228544916425, 33.25867816380092, 49.50736018589565, 46.75216667992728, 41.91278805051531, 57.93848500932966, 48.89932680130005, 21.502258402960642, 1.0789371218000139, 0.2012102502797331, 0.18642997981182166, 0.13197622820734978, 0.14666485573564256, 0.0884832123826657, 0.11108938005885907, 0.17753495568675653, 0.14220677209751947, 0.17215795921427862, 0.0750585056043097, 0.0896246847031372, 0.12602525896259717, 0.0836344486368554, 0.10409820305981807, 0.12201048939355782, 0.19247715175151825, 0.0684689941949078], [0.026748813954847198, 0.04248028534597584, 0.061391446473343034, 0.04672575682135565, 0.04318150718297277, 0.029609073153031722, 0.04278797044285706, 0.019798737518223267, 0.0163346822373569, 0.045209251410726986, 0.02426833419927529, 0.07012181729078293, 0.04672090190329722, 0.032597008893000226, 0.014375583701101797, 0.025070786675704376, 0.03033580451405474, 0.07186899068100111, 0.013060938217677176, 0.04600281847108688, 0.02601899017047669, 0.04079024799700294, 4.315920455115182, 25.72105172702244, 44.077005999428884, 39.41539355686733, 18.583799600601196, 22.962255580084665, 29.290530681610107, 39.807240690503804, 18.579007080623082, 1.959857966218676, 0.02586797032771366, 3.6479823078427995, 5.038349415574755, 2.9294061235019138, 3.86905357667378, 0.6417684086731502, 5.539333641529083, 24.975817476000103, 49.50413274765015, 47.23464611598423, 49.33013595853533, 44.88711036954607, 43.03568295070103, 39.85844891411917, 36.33626113619123, 32.57028538840157, 33.998220103127615, 37.167328221457346, 42.06626680919102, 41.843726430620464, 44.15470423017229, 45.77430847712925, 46.19126640047346, 44.753572940826416, 44.73999268668038, 44.987272126334055, 36.81113576889038, 31.391096183231898, 32.98144851412092, 33.36117104121617, 36.150858879089355, 42.80693783078875, 48.487955229622976, 44.01270736966814, 44.82492399215698, 45.89693375996181, 45.02517107554844, 40.064410890851704, 33.648326192583355, 32.250383377075195, 31.807560784476145, 30.533657210213796, 31.61823626926967, 33.036881242479595, 43.18225172587803, 45.00489623206002, 45.21442263466971, 44.216619627816335, 46.40717819758824, 43.72276599066598, 43.803757667541504, 41.76560435976301, 42.24434913907732, 41.755275862557546, 41.20394672666277, 43.54472534997122, 47.93580968039376, 38.62733234677996, 39.792312485831125, 42.54454605919974, 46.07886191776821, 44.617183276585166, 42.868658678872244, 38.66278900418963, 37.937817437308176, 36.63997037070138, 35.34475319726126, 32.344246591840474, 33.44227736336844, 32.20322247913906, 32.47117975779942, 32.84436403002058, 33.377857140132356, 32.183555603027344, 37.68486131940569, 41.410784176417756, 44.13914026532854, 46.409578800201416, 45.99394450868879, 46.70056240899222, 44.16240283421108, 37.87657601492745, 33.252084323338096, 33.57959113802229, 33.30773939405169, 33.19077689307076, 41.893472058432444, 47.23971135275704, 45.64307090214321, 44.95412227085659, 43.39835112435477, 40.69025250843593, 38.61288704190935, 35.43399238586426, 36.449746063777376, 34.30167572838919, 33.71312856674194, 33.318241596221924, 32.707508836473735, 35.751306193215505, 38.01505708694458, 38.267342703683035, 39.51779958180019, 42.97569567816598, 46.00886229106358, 48.38343000411987, 49.74268872397286, 43.72573981966291, 24.869499615260533, 7.08634832075664, 2.172978324549539, 4.493956318923405, 2.249821058341435, 8.67857449395316, 7.731690491948809, 9.00549852848053, 0.6394491216966084, 0.0497689422752176, 5.395347424915858, 27.98919561931065, 33.01930924824306, 24.874132326671056, 31.582849093845912, 50.11071743283953, 27.345858437674387, 9.27597279208047, 0.10607157288385288, 0.03240641858428717, 0.0688270435535482, 0.01689215812699071, 0.10373507147388798, 0.043613364188266654, 0.049786078677113564, 0.07604237459599972, 0.07697233398045812, 0.006949369912035763, 0.038280767654733996, 0.05264502151736191, 0.034660098009875843, 0.02875861432403326, 0.032890251372009516, 0.08206069522670337, 0.031981509777584245, 0.006756336029086794, 0.045213034243455956, 0.058308454762612066, 0.08343314086752278, 0.03719598354239549, 0.07777310029736587, 0.0834628539159894, 0.04210458050615021, 0.01660638801487429, 0.0553387241171939, 0.01859032771816211, 0.032213524649185796, 0.04237516670088683, 0.027084710841466273, 0.018052675229098116, 0.020948832322444235, 0.08443353218691689, 0.025074896901579838, 0.07683796369071517, 0.03477369834269796, 0.012138159430053617, 0.02689115533472172, 0.03665749475892101, 6.209335403782981, 31.487794263022288, 50.99627229145595, 43.563600131443565, 25.543573890413555, 27.71602371760777, 38.25389099121094, 44.827064037323, 20.70252421924046, 1.5162003955670764, 0.0366767278340246, 2.110619762114116, 6.927779138088226, 4.6967668533325195, 5.056452078478677, 3.139733523130417, 6.389698479856763, 27.036225863865443, 48.557815892355784, 49.728271211896626, 51.12778432028634, 47.849096161978586, 44.296152182987754, 42.56999383653913, 38.65114729745047, 34.549483231135774, 34.83762502670288, 37.630300589970176, 41.63907766342163, 43.14624268668038, 45.33614117758614, 48.130081312997, 47.456967626299175, 45.85832609449114, 46.211714948926655, 46.681572982243125, 39.33794893537249, 34.238891805921284, 35.66617686407906, 34.04877519607544, 37.325135707855225, 44.99403967176165, 48.421822275434224, 46.8423820904323, 46.7922751562936, 47.11921569279262, 46.24783515930176, 41.61503689629691, 36.947664397103445, 33.3586870602199, 33.059424672807964, 32.82516615731375, 33.1008289882115, 34.60419682094029, 44.913138321467805, 46.77752065658569, 46.76097352164132, 47.139764990125386, 47.33346687044416, 44.88465070724487, 44.5063282421657, 43.07955387660435, 43.218097482408794, 42.52397244317191, 41.534736565181184, 44.94425582885742, 48.97279705320086, 40.90966967173985, 40.414655685424805, 42.63457039424351, 47.285242898123606, 45.025000844682964, 43.85278068270002, 40.94962181363787, 39.723580905369346, 38.39188568932669, 37.51008980614798, 34.67071540015084, 33.87022386278425, 33.807776927948, 33.18063947132656, 33.89894076756069, 34.800677980695454, 33.45586109161377, 38.884412220546174, 43.936346667153494, 45.943406786237446, 47.58567953109741, 46.87247126443045, 48.16621889386858, 47.34526491165161, 39.28401354381016, 34.413482666015625, 34.94027771268572, 34.40646845953805, 35.129518849509104, 42.80040652411324, 49.563585008893696, 48.34055961881365, 46.29239048276629, 44.83199725832258, 42.703913416181294, 38.63202238082886, 37.59065416881016, 37.458753040858674, 35.703509535108296, 34.476176261901855, 35.353389808109824, 34.18021426882063, 37.70897504261562, 37.98325170789446, 39.980261257716585, 42.855662073407856, 44.73280824933733, 47.74033253533499, 49.26277664729527, 51.45382506506783, 45.353827817099436, 28.1058680330004, 6.8332419480596265, 3.1434825105326514, 5.487549585955484, 6.0288020968437195, 5.356791436672211, 13.394131881850106, 8.477929626192365, 0.1508505211344787, 0.10936408942299229, 5.878664987427848, 32.96879931858608, 38.78650515420096, 31.56558629444667, 37.45934016363961, 56.191294465746196, 33.07272352491106, 11.66259389264243, 0.29000353280987057, 0.011071546485514512, 0.041149891912937164, 0.008009468072227069, 0.08457131550780364, 0.039199198729225566, 0.054484421387314796, 0.03492445864581636, 0.05371981420155082, 0.030684310277657847, 0.02504144173248538, 0.023629054127793227, 0.03792990737461618, 0.037923637711043866, 0.009651451571179288, 0.057232094662530084, 0.041936622732984166, 0.016225865576416254, 0.10247644329709665, 0.1326439609485013, 0.13676836820585386, 0.13480852837009089, 0.15616836292403086, 0.14682816554393086, 0.1033004562237433, 0.18718324867742403, 0.17643610893615655, 0.08778974959360701, 0.10173750509108816, 0.15175700320729188, 0.15887430629559926, 0.09312776422926358, 0.15221095670546803, 0.18551743163594178, 0.1523015954132591, 0.16523831337690353, 0.1512227383043085, 0.14635476523212024, 0.06157579765255962, 0.20671144580202444, 6.336184757096427, 36.06692116601126, 56.37273277555193, 50.525976521628245, 30.386157376425608, 30.986266340528214, 38.59022201810564, 50.444460255759104, 23.353776148387364, 2.4469913925443376, 0.154270201921463, 5.396866474832807, 9.475030864988055, 9.756331290517535, 11.307930912290301, 2.123817865337644, 7.165100940636226, 27.705504144941056, 50.732056617736816, 50.75194583620344, 53.15837451389858, 48.94940594264439, 46.596370697021484, 42.74012395313808, 40.12809460503714, 35.66213648659842, 37.8879189491272, 40.49224621909005, 45.56820058822632, 45.12321015766689, 47.19744198662894, 50.96216358457293, 48.593147482190815, 48.75116341454642, 49.88283388955252, 48.512944425855366, 41.22933891841343, 35.60823236192976, 37.739654813494, 35.94779430116926, 40.844582421439036, 46.31776877811977, 51.045642716544016, 48.83000462395804, 47.57403782435826, 49.936310700007844, 48.22914872850691, 43.73012065887451, 37.77115099770682, 36.00627728870937, 35.36360713413784, 33.69547666822161, 34.43714475631714, 36.639567375183105, 46.00418267931257, 48.61668103081839, 48.48030178887503, 48.06322227205549, 49.080080713544575, 47.28736209869385, 47.29383087158203, 46.800512245723176, 45.08319200788225, 45.824818406786235, 43.99773052760533, 46.860186849321636, 51.43559299196516, 41.910297121320454, 41.04934235981533, 43.59736837659563, 48.11075489861624, 48.08083248138428, 46.33385385785784, 41.85194614955357, 41.51126555034092, 39.82844311850411, 38.72420065743582, 36.18040261949812, 36.00546087537493, 34.99583550861904, 35.502831663404194, 35.31722443444388, 35.7379378591265, 35.01718037469046, 41.19434779030936, 45.53011751174927, 46.514246463775635, 48.07737922668457, 47.178890296391074, 49.54146194458008, 48.605887004307334, 41.38870974949428, 36.65487425667899, 36.97464772633144, 37.123300961085725, 36.53977734701974, 45.88071666445051, 51.945597716740195, 49.636951037815635, 48.80753762381417, 47.98663227898734, 45.13313218525478, 41.292977469308035, 39.10201242991856, 40.04534503391811, 37.10227223805019, 37.03898457118443, 38.22408321925572, 35.25361715044294, 38.81709112439837, 39.89291892732893, 42.668387276785715, 43.81273126602173, 47.95794316700527, 50.10272005626133, 52.918505328042166, 53.75952570778983, 48.311828817640034, 29.266104289463588, 8.965865135192871, 5.019456395081111, 9.07761996132987, 11.172173534120832, 18.916484560285294, 14.357994675636292, 15.045415571757726, 2.302379620926721, 0.31577917827027185, 8.026132566588265, 37.88118267059326, 42.68851968220302, 34.52410840988159, 44.093674727848594, 62.63735021863665, 40.75998115539551, 14.173864807401385, 0.5670033491083554, 0.19583717573966297, 0.1242373599005597, 0.0815245168549674, 0.18732711167207786, 0.11174515022763185, 0.25300521669643267, 0.1765592766127416, 0.12042035614805562, 0.11447398737072945, 0.08924164489975997, 0.11749076763434069, 0.09849454874971084, 0.09795811932001795, 0.07521110813000373, 0.12863846016781671, 0.12161714264324733, 0.11846245692244597], [0.06657971521573407, 0.020063574825014387, 0.0390618768121515, 0.05486207362264395, 0.013681734995251256, 0.02140931672017489, 0.012271623027377894, 0.04204733929197703, 0.006292041657226426, 0.014992567111871071, 0.04661145081211414, 0.021900911948510578, 0.017601895578471676, 0.01026904905614044, 0.06368779896625451, 0.04761359275185636, 0.04475723513002906, 0.019835317341078604, 0.04282505916697638, 0.017886267908449684, 0.0330208354363484, 0.04574202014399426, 0.7866863895739827, 15.62563705444336, 38.82355294908796, 36.279681955065044, 24.499435084206716, 17.323879276003154, 28.93138871874128, 37.645374706813264, 26.07960135596139, 4.984454844679151, 0.236786031297275, 7.078313163348606, 11.758381758417402, 0.6421059391328267, 2.573021726948874, 4.893785629953657, 2.533633909055165, 19.65272089413234, 37.28757374627249, 46.409766401563374, 50.5847304889134, 47.643624033246724, 41.91534846169608, 38.58201272147042, 35.12295627593994, 37.76139572688511, 42.57046283994402, 43.355001313345774, 45.87992109571184, 44.84543507439749, 45.90157863071987, 44.80597972869873, 43.7607934815543, 40.87630442210606, 42.20599855695452, 44.63627345221383, 34.1637088230678, 30.429715633392334, 33.000719342912944, 33.66603715079171, 38.655997140066965, 44.13596493857247, 47.188746316092356, 43.66262238366263, 44.725067956107004, 45.89695807865688, 41.02673292160034, 33.63196665900094, 31.393149375915527, 32.93103238514492, 32.61333990097046, 32.45187766211373, 31.10624783379691, 35.46155936377389, 45.93004192624773, 46.43547821044922, 45.661639962877544, 44.48644249779837, 43.22242621013096, 44.655488695417134, 44.46783522197178, 45.58629022325788, 43.570332935878206, 43.56177970341274, 42.500320775168284, 45.82089614868164, 47.68182175500052, 34.80319670268467, 37.92014122009277, 46.059476443699424, 46.20113979067121, 44.77477536882673, 42.10922752107893, 39.84125907080514, 37.32040745871407, 35.39616639273507, 34.916778905051096, 33.75795834405081, 33.58808183670044, 32.21637889317104, 32.71879965918404, 32.246061597551616, 32.89763239451817, 33.17876345770699, 36.6172775541033, 42.473393031529014, 44.52520649773734, 47.17806346075875, 46.259254523685996, 44.57992703574044, 43.27998161315918, 34.71703904015677, 32.61839471544538, 33.68606185913086, 30.359073298318044, 33.83046627044678, 43.79932819093977, 46.6692989894322, 45.37596130371094, 45.55803189958845, 44.95023127964565, 43.949760164533345, 42.47029760905674, 44.48702267238072, 41.78204379762922, 41.94125829424177, 39.03991985321045, 35.968239375523154, 35.965644223349436, 36.717411518096924, 35.577684606824604, 36.950613907405305, 42.00801658630371, 43.07873746326992, 45.522422381809776, 48.295372009277344, 51.20889064243862, 42.0023364339556, 22.199369430541992, 5.308269560337067, 0.5612068144338471, 5.836617963654654, 4.272152449403491, 8.2794143812997, 1.8866810585771288, 1.2678242261920656, 0.4891754367521831, 0.2118535063096455, 5.431569252695356, 34.13770866394043, 35.36358281544277, 26.72005329813276, 30.25112955910819, 41.735338006700786, 26.863950490951538, 6.397320219448634, 0.08114232522036348, 0.061962121565427096, 0.03420150672484722, 0.01992977111201201, 0.029368525703570673, 0.0234147999103048, 0.0141059661151043, 0.014146603577371155, 0.03681831434369087, 0.026218923906396543, 0.08115174328642231, 0.043017491698265076, 0.058431289957037995, 0.014770899899303913, 0.061860124181423864, 0.01089920792063432, 0.044732319324144294, 0.026807595443512713, 0.030502401824508394, 0.027864374719294052, 0.017999182920902967, 0.042614998295903206, 0.017906724042924385, 0.06819333255823169, 0.04178947223616498, 0.015637066813984087, 0.048574109960879595, 0.027834639618439332, 0.053790683791573556, 0.009068228670262864, 0.036180481248136075, 0.036645983412329636, 0.0556695133314601, 0.009655089367048016, 0.07425065538180725, 0.05103102758792894, 0.03875883289479783, 0.03263262180345399, 0.0582263588107058, 0.05351537160043206, 1.283907026052475, 21.522701740264893, 44.941771847861155, 43.23302568708147, 26.642685106822423, 22.013930695397512, 29.327283178056987, 43.17741925375802, 28.519266741616384, 5.129004733903067, 0.18951245583593845, 6.928245101656232, 7.411507947104318, 3.2826946633202687, 7.457827244486127, 3.519344227654593, 4.808174269539969, 19.61190891265869, 43.14037145887102, 47.3415823663984, 51.22415583474295, 47.10942220687866, 44.483357497623985, 38.77369615009853, 36.930616991860525, 39.15321717943464, 42.879619462149485, 44.74487727028983, 47.81286130632673, 47.272114276885986, 47.55375255857195, 46.093762329646516, 44.635731492723735, 42.05896772657122, 45.96267761502947, 46.63060794557844, 38.07164321626936, 31.85501003265381, 34.53933538709368, 35.07832799639021, 39.78646557671683, 45.76075254167829, 47.56795467649187, 45.26581845964704, 47.26546137673514, 47.585269587380544, 43.989701884133474, 36.239517893110005, 32.63939217158726, 33.519134862082346, 34.65735054016113, 33.71533809389387, 32.393870626177105, 36.763196672712056, 47.16314915248326, 47.20937899180821, 47.135752405439106, 45.45719269343785, 44.803214345659526, 45.91636439732143, 46.96319041933332, 46.69998918260847, 46.13234567642212, 46.125668457576204, 45.11987502234322, 47.092110770089285, 49.14748518807547, 39.08397143227713, 39.136121136801584, 46.775154794965474, 47.321411745888845, 45.00540345055716, 45.209103788648335, 41.54965782165527, 38.89195449011666, 36.92496463230678, 37.314973967415945, 35.32820953641619, 34.62537840434483, 33.759889943259104, 33.83350610733032, 34.801105294908794, 34.53272417613438, 35.224163736615864, 39.50130803244454, 43.4259980065482, 45.633180141448975, 48.746247564043315, 48.012750557490754, 46.527725969042095, 46.1359726360866, 37.001248904636924, 34.30591760362898, 35.68687207358224, 32.509790897369385, 35.6330235345023, 46.11284555707659, 49.32023477554321, 47.945815086364746, 47.919161796569824, 46.46126297542027, 44.805392605917795, 45.084720611572266, 45.71253899165562, 43.149188722882954, 41.627168451036724, 39.160054206848145, 37.8679324558803, 37.165466104234966, 37.785658836364746, 37.62903949192592, 38.8863160269601, 43.64825003487723, 46.07291425977434, 47.99116250446865, 49.95629371915545, 52.585933276585166, 44.326560974121094, 22.786594697407313, 6.554234862327576, 3.0394870851721083, 5.647164472511836, 3.8685910872050693, 8.613665291241237, 3.7740508573395863, 3.056001433304378, 0.6799864864775113, 0.1561968071120126, 6.790642108236041, 37.49858011518206, 40.10727432795933, 27.615420750209264, 34.90077372959682, 49.39984028679984, 31.408254759652273, 8.038106918334961, 0.12770710300121987, 0.016269551357254386, 0.027815118165952817, 0.06914359371044806, 0.07419009613139288, 0.06271876275007214, 0.0673197933605739, 0.04861407906615308, 0.014042370420481478, 0.06082942270274673, 0.05182200603719268, 0.015875342867470214, 0.07871736320001738, 0.06403182300605945, 0.07028115088386194, 0.027856257744133472, 0.041155374475887845, 0.026740817419652427, 0.14489088021218777, 0.09917309733905963, 0.0930663568100759, 0.10563393815287522, 0.1369245941085475, 0.21299922625933373, 0.19361695487584385, 0.16844289856297628, 0.13042861196611608, 0.1459098362496921, 0.16491261656795228, 0.0630685950496367, 0.07955107917743069, 0.10542700532823801, 0.13758820135678562, 0.10357674211263657, 0.14286367541977338, 0.09127125849149056, 0.12033463003379957, 0.09719655197113752, 0.21855425675000462, 0.12131182902625628, 1.631465147648539, 24.00012363706316, 52.43884686061314, 49.32049880708967, 34.321957520076204, 27.44671675137111, 37.39668478284563, 47.80871670586722, 34.12476069586617, 6.869141553129468, 0.4836651352899415, 9.67057922908238, 17.984408038003103, 8.095897691590444, 8.001322286469595, 9.595878277506147, 4.642695537635258, 22.828004223959788, 44.318250928606304, 50.6180853162493, 52.71450274331229, 52.23917647770473, 45.20268712724958, 42.590487548283164, 38.31077936717442, 42.01903295516968, 46.559385435921804, 47.76270226069859, 50.662255014692036, 49.89964853014265, 49.36775697980608, 47.24613148825509, 45.15072849818638, 44.293862751552034, 46.629728998456685, 48.33520950589861, 38.88364097050258, 33.31062984466553, 36.69171013150896, 36.62360041482108, 42.280615261622835, 48.33778381347656, 50.11793313707624, 44.8040064402989, 48.344989095415386, 49.93682139260428, 45.24020739964077, 36.81366491317749, 34.52814531326294, 35.74839489800589, 35.71852459226336, 36.44517762320382, 33.923804896218435, 39.53288412094116, 50.34932552065168, 49.58655227933611, 48.47190489087786, 48.353528431483674, 44.381976331983296, 48.248673166547505, 48.95146608352661, 49.56124694006783, 47.96781655720302, 48.71210759026663, 46.07750007084438, 51.29166453225272, 51.19682509558541, 40.25491312571934, 40.269889967782156, 47.144653047834126, 50.302369594573975, 47.66897800990513, 45.64833763667515, 42.97426087515694, 41.95856973103115, 38.97118827274868, 40.328525815691265, 37.213214124952046, 37.09443467003958, 35.65940237045288, 34.89156041826521, 35.99399287360055, 34.97545296805245, 37.06816700526646, 39.87829644339425, 46.34357786178589, 46.190463883536204, 50.913147517613, 48.81038638523647, 48.390496322086875, 48.4923916544233, 37.94224343981062, 34.853699684143066, 37.659618513924734, 33.308715615953716, 37.99220098767962, 47.53801141466413, 50.57761900765555, 48.107114042554585, 48.88563885007586, 50.13252435411726, 46.50893109185355, 46.86672510419573, 50.510464668273926, 46.269280774252756, 44.9087609563555, 41.59921932220459, 38.95735788345337, 39.99780893325806, 39.65425525392805, 39.31676387786865, 40.85729415076119, 46.053174427577424, 47.6798415184021, 51.65465579714094, 52.84829725537981, 54.9898293358939, 43.82961538859776, 25.15814515522548, 7.501415031296866, 4.3054430059024265, 13.417413558278765, 12.50967744418553, 14.266957640647888, 5.754852431161063, 3.405162526028497, 1.0233356824942996, 0.5127703249454498, 8.366423198154994, 47.03579909460885, 47.23662287848336, 37.215913500104634, 40.437629904065815, 55.33791324070522, 36.85026107515608, 9.175388063703265, 0.18768512031861714, 0.13589147025985376, 0.18132352882197925, 0.10994536323206765, 0.13851631512599333, 0.10948264984680073, 0.12310630987797465, 0.08505673267479454, 0.09201540784644228, 0.16068357921072415, 0.12716361002198287, 0.1365433388522693, 0.13818698136934213, 0.11586426491183893, 0.12990878628832953, 0.06371291154729468, 0.12083651524569307, 0.11052619599338089], [0.02698494923034949, 0.04099777793245656, 0.04164516140839883, 0.04646784905344248, 0.033041591822568855, 0.022444026644474695, 0.06746741543923106, 0.02761527263958539, 0.01904064596497587, 0.014086548987376903, 0.07892358356288501, 0.04696476399632437, 0.04169896584270256, 0.015069382364994712, 0.06412993238440581, 0.049195349482553344, 0.02559955544503672, 0.037959332045699866, 0.033476749900728464, 0.04980460607579776, 0.08042637578078679, 0.012331723418485905, 0.23734783115131514, 5.650907814502716, 35.96038096291678, 40.724732943943565, 24.534577335630143, 21.791091544287546, 35.692951747349326, 36.86808320454189, 31.65334551674979, 8.026777012007576, 2.85158434510231, 19.347517796925136, 35.87991040093558, 7.497975672994341, 2.863476186990738, 3.867833733558655, 2.5985924005508423, 10.168342964989797, 33.71462590353829, 54.15326969964163, 47.85412318365914, 46.95733308792114, 41.53963851928711, 40.09012617383684, 41.687881810324534, 44.1903589112418, 45.16733816691807, 45.650647912706646, 45.77436406271798, 45.74172837393624, 43.677307401384624, 44.947267872946604, 45.89956712722778, 45.36155421393258, 45.22923271996634, 40.43402031489781, 32.434131962912424, 32.49176032202584, 32.24068716594151, 35.80277150017874, 38.3816614151001, 45.24715212413243, 46.23471001216343, 46.259237153189524, 46.036512647356304, 44.61419555119106, 41.736922195979524, 34.0122207232884, 30.85710280282157, 31.523049422672816, 30.55599914278303, 31.709334100995743, 30.856112684522355, 33.85410751615252, 45.13947589056832, 44.57271133150373, 45.74593550818307, 42.01449925558907, 42.71608666011265, 41.424291474478586, 45.12503405979702, 45.14027493340628, 44.910498006003245, 43.96077653339931, 44.3662942477635, 40.561359950474326, 42.88549068995884, 34.57982948848179, 39.67486708504813, 48.99508687428066, 43.45772000721523, 45.36215870720999, 40.94521318163191, 39.217411586216514, 36.07297999518258, 34.856458118983674, 33.75544309616089, 33.1918295451573, 31.4154600415911, 32.00763763700213, 31.97348029272897, 30.93067032950265, 33.163494791303364, 33.94668531417847, 39.3493926184518, 43.75077417918614, 46.42684159960066, 46.98243692943028, 44.30033152444022, 44.96424232210432, 41.12320171083723, 33.80224963596889, 33.097799573625835, 33.23024613516671, 32.59997156688145, 34.51431144986834, 44.35732412338257, 46.36997059413365, 42.98585394450596, 43.80688088280814, 46.3560915674482, 45.729530811309814, 45.83556032180786, 44.68937158584595, 44.422029222760884, 44.097294739314485, 44.17159530094692, 42.13894149235317, 41.57803773880005, 38.82346262250628, 38.375157901218955, 39.36344882420131, 42.997971602848594, 42.55865090233939, 47.85051359449114, 48.93907397133963, 47.21986034938267, 38.24465683528355, 19.59181124823434, 3.8078846761158536, 2.908449922289167, 2.227461103882108, 8.930031538009644, 2.2184964077813283, 2.635848424264363, 1.657628915139607, 0.02544329222291708, 0.38569873784269604, 6.126434275082179, 28.029446533748082, 25.00382045337132, 28.74783989361354, 36.61289324079241, 41.8591479573931, 19.53579487119402, 3.1105584715093886, 0.03507891017943621, 0.06115968605237348, 0.017662310640194585, 0.009280180957700526, 0.03979172604158521, 0.058630317848707945, 0.01692403230949172, 0.0231454367749393, 0.07081829956067459, 0.03831289289519191, 0.037553211873663325, 0.031641814791198285, 0.016371709893324544, 0.0752578116953373, 0.06195178747709308, 0.05334530697603311, 0.03034644733582224, 0.03723705526707428, 0.043382733528103144, 0.05085420136206916, 0.04147518499355231, 0.019459777045994997, 0.07387221604585648, 0.057472581043839455, 0.05192508568455066, 0.05575537854539497, 0.033893404328929524, 0.01787062767626984, 0.030906323543084518, 0.0479503361109112, 0.08954710779445511, 0.019552468322217464, 0.04574147731597934, 0.028582819471401826, 0.04511470773390361, 0.029242481038506542, 0.017817695159465075, 0.07654011395892926, 0.044094391233686886, 0.018947079378579344, 0.42770730225103243, 9.17703652381897, 42.50651509421212, 44.796095916203086, 28.358018159866333, 21.724970749446324, 36.61330318450928, 40.194682666233604, 33.20360674176897, 8.405412146023341, 3.0572067286287035, 18.967281103134155, 31.653005055018834, 6.313231817313603, 4.166720918246678, 5.383968881198338, 5.02002614736557, 11.956849234444753, 36.60516684395926, 53.245365960257395, 50.93852233886719, 48.97559717723301, 42.268883228302, 41.24145310265677, 42.96727098737444, 46.45153202329363, 47.645357608795166, 47.414642674582346, 48.56674780164446, 46.744506290980745, 44.98142521721976, 45.75916140420096, 46.427661487034385, 47.006804261888774, 47.27340316772461, 42.92138160978045, 33.83896739142281, 34.20656878607613, 34.75677578789847, 36.97723593030657, 41.973616055079866, 46.20820958273751, 48.20075838906424, 46.34766340255737, 48.03406415666853, 45.78738151277815, 43.36293268203735, 35.26967096328735, 33.132127148764475, 33.006851128169465, 31.861642088208878, 33.26178053447178, 32.3316981451852, 35.15154116494315, 46.92568056924002, 47.13537720271519, 46.80745349611555, 44.427723271506174, 43.22982256753104, 43.94186006273542, 47.706446170806885, 46.75386898858206, 46.9508330481393, 45.22036681856428, 46.21749932425362, 43.996948855263845, 45.477634293692454, 37.23245368685041, 40.90624073573521, 50.074680600847515, 45.39240768977574, 46.79824365888323, 42.16840532847813, 39.6393826348441, 37.3386812210083, 37.98597887584141, 35.456320422036306, 35.452787263052805, 33.24430581501552, 33.37043298993792, 33.091737270355225, 32.50146695545742, 34.65314340591431, 36.15202617645264, 39.21529933384487, 46.08123472758702, 48.27759851728167, 47.987094334193635, 46.17122779573713, 45.97171374729702, 43.88625362941197, 35.911872114454, 34.431610516139436, 35.065032618386404, 33.36097649165562, 35.542756012507844, 45.720623220716206, 47.82818555831909, 43.163981437683105, 44.647453103746685, 48.05624975476946, 46.626737798963276, 47.47817005429949, 46.55882263183594, 46.713190759931294, 46.222380433763774, 46.42020606994629, 43.587904930114746, 43.19924354553223, 39.8335257257734, 39.872067383357454, 41.455718176705496, 44.01563603537423, 46.23026663916451, 47.9444636617388, 50.4604480607169, 47.89844921657017, 41.15512868336269, 21.127269336155482, 4.616021837506976, 2.9264049359730313, 5.9628841025488715, 5.587862031800406, 4.288453357560294, 5.913785091468266, 1.1765221825667789, 0.0688131878684674, 0.36575344524213244, 7.251192161015101, 33.72521843229021, 30.39558608191354, 33.058507510593955, 41.134832995278494, 45.93211248942784, 24.8145706312997, 4.274236908980778, 0.033112922816404274, 0.045096502639353275, 0.023887426692194173, 0.011742344508612794, 0.07894039766064712, 0.08433260688824312, 0.019406496779993176, 0.07965076275702034, 0.03210241114720702, 0.03985973560650434, 0.03202385036274791, 0.026223235996440053, 0.04716685886627861, 0.047206471740667305, 0.038826296239026954, 0.025641456678775803, 0.03907848734940801, 0.0244155729056469, 0.12163817722882543, 0.1531061479555709, 0.10406067328793661, 0.09617680204766137, 0.06082128028252295, 0.1900331771799496, 0.12102307166372027, 0.12843069274510654, 0.14504622401935713, 0.15145333164504596, 0.19263599679938384, 0.08764579160405056, 0.14001319051853248, 0.15974090408001626, 0.12394533199923378, 0.23217755715761865, 0.11646776752812521, 0.206553116440773, 0.09809753791029964, 0.17274517699011735, 0.12451212587101118, 0.09369653942329542, 0.6812716860856328, 10.357232349259512, 48.37057931082589, 52.975289481026785, 35.374665192195344, 31.739395482199534, 46.74368987764631, 47.03895705086844, 38.88372087478638, 10.279142413820539, 5.1426462190491815, 22.408881936754497, 43.230652877262656, 14.391516259738378, 11.595493401799883, 10.463410377502441, 4.583479515143803, 13.608925018991743, 39.13428333827427, 54.75889900752476, 53.640002795628135, 51.18179266793387, 45.05205365589687, 44.341516971588135, 47.15303257533482, 49.107717173440115, 48.22149528775896, 49.22082689830235, 50.42319876807076, 49.22505835124424, 45.09936741420201, 46.5573148727417, 49.57299634388515, 48.651672158922466, 48.46022496904646, 45.26497425351824, 35.34929384504046, 36.1734162058149, 36.32735354559762, 38.86357804707119, 43.99849830354963, 50.42569317136492, 49.75359392166138, 48.55471699578421, 49.13404042380196, 47.78086485181536, 45.49587331499372, 37.47680098669869, 34.54633917127337, 34.11157996313912, 34.29791675295149, 34.96230002811977, 34.443794182368684, 36.68684639249529, 48.513097286224365, 49.8673289843968, 48.64269508634295, 45.10054860796247, 45.766575132097515, 44.95920140402657, 49.167530741010395, 48.51045002256121, 48.12071166719709, 46.69086619785854, 48.40045656476702, 45.052998610905235, 45.10462720053536, 38.902505329677034, 44.59782212121146, 49.41860389709473, 47.010792527879985, 48.80600207192557, 43.779140199933735, 40.828650202069966, 39.96485710144043, 38.90482950210571, 37.590966837746755, 37.341189520699636, 34.362468991960796, 34.731963770730154, 35.321132796151296, 32.95242241450718, 35.83114446912493, 37.265322140284944, 41.17852674211775, 47.46256787436349, 50.06523452486311, 49.69058418273926, 47.445572580610005, 49.355778285435264, 45.11081109728132, 36.836788518088206, 36.49536098752703, 36.70414740698678, 36.27759402138846, 37.80288689477103, 48.56324243545532, 48.94900642122541, 44.415907859802246, 43.792386940547395, 48.7314270564488, 49.260004316057476, 49.22274112701416, 48.316623074667795, 48.25074372972761, 47.487932273319785, 48.559136050088064, 46.33214807510376, 46.91552925109863, 42.103634221213206, 42.00163813999721, 43.51658861977713, 46.891922746385845, 47.17897367477417, 51.24853706359863, 52.78400557381766, 49.53758484976632, 42.333320822034565, 22.581131253923687, 5.647113229547228, 6.822558658463614, 8.023351550102234, 16.806278433118546, 5.956542134284973, 9.080822212355477, 4.986351268632071, 0.2653019540011883, 0.7707340855683599, 9.340081214904785, 37.71499218259539, 36.945472240448, 41.721566677093506, 48.05104555402483, 53.678843225751606, 28.94788200514657, 4.890315004757472, 0.1335375237145594, 0.10082184243947268, 0.09177764239055769, 0.13311320862599782, 0.15062452826116765, 0.2696483779166426, 0.13453469877796514, 0.1996879841067961, 0.09534611912178141, 0.13656725042632648, 0.11916825547814369, 0.11206915748438664, 0.13794941268861294, 0.20738050847181252, 0.12905132158526353, 0.13138328359595366, 0.10804912926895277, 0.07757224714649574], [0.05501909341130938, 0.07145063312990324, 0.05217924793916089, 0.060765246860682964, 0.011013696286162096, 0.025782352779060602, 0.04744958744517394, 0.03873070761827486, 0.02441124215589038, 0.07715283108076879, 0.018073319657040492, 0.010459253448061645, 0.019791080250537822, 0.04063001195234912, 0.07721787544765643, 0.06489758619240352, 0.03172414483768599, 0.0367795428527253, 0.04843477958015033, 0.04509065706016762, 0.027201127094615783, 0.054112512950918505, 0.05265098244750074, 2.1077041242803847, 23.7097966330392, 39.07559885297503, 29.108677216938563, 26.94302272796631, 23.72484643118722, 32.10293565477644, 38.26165907723563, 13.49069881439209, 1.5125911320958818, 15.11619860785348, 38.780661719185964, 36.48856217520577, 13.287771463394165, 2.682139277458191, 5.228175938129425, 8.004197972161428, 37.49452584130423, 46.09101431710379, 50.80603756223406, 47.10948126656668, 44.46130044119698, 42.12421825953892, 45.9297570501055, 46.09572866984776, 48.41872337886265, 46.34509604317801, 44.884866101401194, 43.96144356046404, 46.01142965044294, 44.32909706660679, 45.13001939228603, 42.61060953140259, 41.73791578837803, 36.39481707981655, 32.98969602584839, 32.00117581231253, 34.444301400865825, 33.46472004481724, 41.01816579273769, 44.16277803693499, 46.0324444770813, 44.94046558652605, 46.0810158593314, 45.40752696990967, 42.19405460357666, 33.1384847504752, 31.392562253134592, 31.18132311957223, 32.55211584908621, 31.872752257755824, 34.78771611622402, 31.105935164860316, 42.377712862832205, 43.72487824303763, 45.06400455747332, 45.36617824009487, 44.11320263998849, 40.938264983040945, 41.66750274385725, 41.13363095692226, 43.736005783081055, 40.78133296966553, 42.450773171016145, 38.29738324029105, 37.041346958705354, 35.16957868848528, 40.83946507317679, 49.0569223676409, 43.069360869271414, 42.635810647692, 38.704679693494526, 37.678646155766074, 34.858459200177876, 35.507691928318565, 32.83091926574707, 34.46866178512573, 33.15337126595633, 34.02537366322109, 31.383929116385325, 33.45630925042288, 33.66168410437447, 34.19597625732422, 40.13265609741211, 44.877198764256065, 46.381219727652415, 47.538362298692974, 45.897760595594136, 43.6837796483721, 35.078255040305, 31.694246087755474, 33.953004700796946, 32.58011361530849, 32.04429980686733, 32.73273079735892, 39.01787321908133, 47.2670316696167, 47.71436364310128, 49.24726479394095, 45.828087534223286, 43.445317472730366, 47.01565279279436, 47.56182289123535, 48.11530944279262, 47.67257717677525, 45.29833255495344, 45.37743084771292, 44.60605573654175, 44.41934026990618, 41.631973130362375, 42.69213621956961, 40.55520732062203, 45.18421186719622, 44.355545384543284, 48.383172920772004, 48.39137874330793, 36.01569904599871, 14.672847952161517, 3.6734253082956587, 1.3082957459347588, 8.151245304516383, 14.345952578953334, 3.666520970208304, 1.8551866114139557, 1.5407910474709101, 0.10145409458449908, 0.34681954979896545, 10.266701664243426, 28.209715809140885, 30.790323666163854, 22.41735700198582, 42.102817807878765, 43.46893092564174, 16.88642590386527, 1.7369472703763416, 0.07971136950488601, 0.02909763416807566, 0.02293894499806421, 0.030611880057092224, 0.022434973290988376, 0.03418098443320819, 0.041174152932528935, 0.027603483093636375, 0.009738792598779713, 0.021130674618429372, 0.027823818681229438, 0.011837385212337332, 0.04161677150321858, 0.052738795056939125, 0.01928977688242282, 0.050759236993534226, 0.017529465357906053, 0.020574606688959256, 0.022821034271536127, 0.04594092589936086, 0.07161861125911985, 0.05853729069765125, 0.07008537996028151, 0.029625181574374437, 0.032693204802594016, 0.009588329154731972, 0.05615199922717043, 0.050837241379278045, 0.030226651978279864, 0.005988994347197669, 0.05083408619144133, 0.044682260403143506, 0.028868106127317463, 0.028319727695946182, 0.05996861960738897, 0.03511437720486096, 0.03829469458599176, 0.025206315563991666, 0.02981174477775182, 0.04942252639947193, 0.07007654543433871, 3.49759202344077, 30.411942141396658, 44.052833216530935, 32.589187962668284, 29.190539155687603, 31.32106876373291, 37.34006043842861, 42.03411054611206, 13.743017435073853, 3.2236675449780057, 15.547098091670446, 44.1651473726545, 28.284521852220806, 7.475734489304679, 4.583181176866804, 3.0731791172708784, 10.681209479059492, 37.35825082233974, 49.19267279761178, 51.07651356288365, 48.91914306368147, 45.637484550476074, 44.13172306333269, 46.13667787824358, 47.10858842304775, 50.57845279148647, 47.236921651022776, 44.96584735597883, 45.255038329533164, 46.85070603234427, 46.329997607639854, 47.19932494844709, 45.65826661246163, 44.44524662835257, 38.19461938313076, 33.909029551914756, 33.88323089054653, 34.61679737908499, 35.35214608056204, 43.203940527779714, 46.54926885877337, 48.79594455446516, 45.086655684879844, 48.6226669039045, 47.6531708581107, 45.43743896484375, 35.09331178665161, 32.300615378788535, 33.88698639188494, 33.02212674277169, 34.34550149100167, 35.312197412763325, 32.746516023363384, 45.639044421059744, 44.99346644537789, 46.028358936309814, 46.4920573915754, 43.3131662096296, 43.45650407246181, 43.57699973242623, 43.00088289805821, 45.296227250780376, 42.07217277799334, 42.79178033556257, 38.77220228740147, 39.1258864402771, 38.19871882029942, 43.08709267207554, 50.778352464948384, 45.68764707020351, 45.460277693612234, 40.468139444078716, 38.6343708719526, 37.25278411592756, 37.32824502672468, 34.67793805258614, 35.122469902038574, 34.42634378160749, 34.31549916948591, 34.358341761997764, 33.8997015953064, 34.559130804879324, 36.31831741333008, 41.77304588045393, 46.754282406398225, 48.50583641869681, 47.724883215767996, 46.563356331416536, 46.76046282904488, 37.47909389223371, 32.792002405439106, 35.44806943620954, 34.87842832292829, 34.90637397766113, 34.06377635683332, 41.70645087105887, 48.363245487213135, 46.825345107487266, 48.11556305204119, 45.071393966674805, 44.200326102120535, 48.92040416172573, 48.494121755872456, 49.745839732033865, 48.82716975893293, 46.57699564525059, 46.90524591718401, 46.09785829271589, 46.055071285792756, 43.18392971583775, 42.78733001436506, 43.998011929648264, 46.34079163415091, 47.57903357914516, 50.975538866860525, 50.44385576248169, 36.801971094948904, 16.316289731434413, 3.0222123435565402, 3.507516873734338, 6.736361043793814, 10.748399427958898, 4.922841259411403, 2.758767702749797, 1.7573075549943107, 0.006144058682756233, 0.37202376020806177, 10.465033650398254, 32.25930833816528, 32.86607715061733, 27.350527627127512, 47.21625770841326, 48.87862811769758, 20.983660493578228, 1.976810267993382, 0.04401384234162314, 0.016161864457119788, 0.06707165310425417, 0.026036253797688653, 0.009583728687305535, 0.012763236067257822, 0.0767204821375864, 0.04042689249451671, 0.04938898980617523, 0.037948407631899626, 0.002753124667963545, 0.009367021565724696, 0.004919417052795845, 0.06368856571082558, 0.01266771530000759, 0.057108472367482524, 0.05142163305676409, 0.05256538525489824, 0.12607587767498835, 0.16443946052874836, 0.08574201233152833, 0.10998542393956866, 0.12199621301676546, 0.09520506526210479, 0.09797200893184968, 0.12873132447046892, 0.18368386716714927, 0.17952926510146686, 0.1371227263339928, 0.07754351118845598, 0.20642878168395587, 0.18883959337004594, 0.17323049237685545, 0.13009663192289217, 0.1458314654550382, 0.1565747782588005, 0.16166752284126623, 0.15778714391802037, 0.10298929363489151, 0.2989198629345213, 0.17272396598543438, 4.387249359062739, 34.38507495607649, 52.3053754397801, 39.45727729797363, 37.30427026748657, 33.39523458480835, 40.75850813729422, 47.93972846439907, 17.383246421813965, 3.5211205780506134, 15.661856276648384, 46.01312501089913, 46.06619187763759, 25.267829418182373, 7.82377062525068, 8.21473707471575, 10.807022247995649, 41.19564710344587, 49.23726633616856, 53.857898303440635, 50.52518442698887, 47.66009473800659, 46.49539600099836, 49.27709341049194, 49.90756252833775, 53.368446350097656, 47.74609954016549, 44.190824440547395, 45.48750420979091, 49.002844538007466, 48.96064117976597, 49.668370791843955, 46.64079747881208, 45.32674373899187, 39.57867274965559, 37.66720247268677, 36.73719651358468, 37.693018504551475, 37.7587936265128, 45.62290722983224, 48.62171500069754, 49.58620834350586, 46.67223112923758, 50.137940474918906, 51.21623488834926, 46.686787605285645, 36.76597247804914, 34.941764627184185, 35.413957255227224, 35.28142384120396, 34.933430262974326, 37.50237383161272, 34.18041229248047, 46.07749659674508, 46.75852428163801, 48.25693457467215, 47.60264355795724, 45.58806548799787, 44.93288857596261, 43.91903870446341, 44.35247080666678, 46.005138056618826, 44.883017880576, 44.832077162606375, 41.595373494284495, 42.28483976636614, 39.83538089479719, 44.32126644679478, 53.537770475660054, 48.72079978670393, 46.44914879117693, 42.497604029519216, 40.843175411224365, 38.00849798747471, 39.80026469911848, 36.091020992824006, 36.624218804495676, 36.11591291427612, 36.747191497257774, 35.112659045628135, 37.0004220690046, 37.41769960948399, 37.43819332122803, 44.0590831211635, 49.07095772879464, 49.07127039773123, 49.15381499699184, 48.87372963769095, 48.35986171449934, 38.70935583114624, 35.49697780609131, 36.40857798712594, 36.29680231639317, 36.34447043282645, 36.58174794060843, 42.76581144332886, 50.70297840663365, 49.4548213822501, 50.865854603903635, 46.37040833064488, 45.75478056498936, 50.24097531182425, 51.33304105486189, 53.113443987710134, 52.412843227386475, 48.32785136359078, 49.08545861925398, 47.36488315037319, 48.693201541900635, 45.14647620064871, 45.38357652936663, 44.27663469314575, 49.15206752504621, 48.11208200454712, 53.075857707432334, 50.9931560243879, 39.22744825908116, 17.36346663747515, 5.8676221285547525, 5.210962210382734, 16.720883335386002, 20.03676346370152, 8.690623538834707, 10.433690326554434, 3.1627631102289473, 0.44161936002118246, 0.5022572119321141, 14.739741734095983, 39.32142264502389, 41.07995612280709, 34.03263453074864, 55.633982930864605, 55.74934039797102, 25.315342937197002, 2.4546339767319814, 0.15104549138673715, 0.03522487663264785, 0.13990728477282183, 0.14477341222975934, 0.14234148844012193, 0.09302689999874149, 0.17501607084912912, 0.22383359846259865, 0.1609084185745035, 0.10289001717631306, 0.15749998789812836, 0.09148220145808798, 0.1408489013889006, 0.1454545528228794, 0.09210514410265855, 0.22807225744639123, 0.13415109579052242, 0.14908529871276446], [0.03861335159412452, 0.012163971750331777, 0.058022302974547656, 0.032210301607847214, 0.06443143263459206, 0.027145605966714875, 0.09585255051829986, 0.046656977119190354, 0.026360922626086643, 0.030528864690235684, 0.03214934541444693, 0.03193104034289718, 0.02118981403431722, 0.022434048787025467, 0.030619622141655003, 0.01721260816391025, 0.04445869668519922, 0.03567239083349705, 0.050109970582915206, 0.017854844951736074, 0.04409810621291399, 0.041829821321048906, 0.044170902842389684, 0.4456120772021157, 17.14143521445138, 40.28148651123047, 42.418985162462505, 25.809700318745204, 28.595293930598668, 28.097146306719097, 36.0967150415693, 17.323290416172572, 3.5139489514487128, 4.91452773979732, 17.680346182414464, 32.4984827041626, 21.928238562175206, 5.4736970492771695, 1.4146397709846497, 9.375369378498622, 30.986349718911306, 52.59735264096941, 49.921184471675325, 46.17950657435826, 45.67933702468872, 45.53670787811279, 46.0689503124782, 49.53246055330549, 45.35018348693848, 43.91016238076346, 44.918540545872276, 47.92090579441616, 44.647838728768484, 44.7239944594247, 40.80543279647827, 40.88078601019723, 35.19663149969918, 33.295552253723145, 33.13509055546352, 33.45597573689052, 32.57227257319859, 34.54476887839181, 40.407985414777485, 43.93097570964268, 45.58711705889021, 46.05833346503121, 46.65321043559483, 45.594179902757915, 41.35481643676758, 33.52072599955967, 32.22379609516689, 31.75916658129011, 32.689502579825266, 31.59072835104806, 32.19710111618042, 30.992575304848806, 37.19611460821969, 44.67595114026751, 42.41680342810494, 44.40111861910139, 46.7313220841544, 46.417440686907085, 45.59250538689749, 44.0884462084089, 43.404173714774, 39.40794856207711, 39.82464245387486, 39.12771381650652, 42.49571411950247, 37.56973314285278, 39.74969570977347, 48.44311850411551, 41.336719853537424, 42.796842098236084, 36.47217832292829, 36.134839807237896, 34.865608896527974, 34.78355067116873, 36.45915045057024, 34.31982789720808, 32.656085218702046, 33.36186238697597, 32.60789598737444, 33.595683165958945, 33.0627771786281, 34.859411103384836, 39.08670902252197, 46.52068396977016, 46.363237789699006, 47.07233272280012, 45.79945400782994, 45.1260415485927, 38.93779870441982, 35.93793133326939, 31.605225767408097, 33.75752755573818, 31.45916768482753, 31.19627911703927, 35.18611887523106, 41.98622356142317, 45.45748104367937, 45.150947366442, 46.03743328366961, 44.052558762686594, 41.76867893763951, 42.86239835194179, 40.33819770812988, 45.67409460885184, 45.54190165655953, 46.0058502469744, 45.45459406716483, 41.58948489597866, 43.92369747161865, 42.76394932610648, 41.183626719883506, 46.667718274252756, 47.05429172515869, 47.73009436471121, 46.221042905535015, 33.64682885578701, 13.400888136454991, 1.3411227273089545, 1.8072725938899177, 7.730852365493774, 13.625064815793719, 9.291023458753314, 3.5794589562075476, 0.8214251569339207, 0.026532368069248538, 0.6306050962635449, 10.105311512947083, 26.58721763747079, 30.153767926352366, 30.450525488172257, 40.64376905986241, 39.6889580317906, 6.718183687755039, 0.7729997954198292, 0.1002156799659133, 0.013043475270803486, 0.014794534970340984, 0.10611201357096434, 0.036243456083216836, 0.031989479171378274, 0.022633728072313324, 0.04344929102808237, 0.07349174110484974, 0.025395949138328433, 0.034839838543640714, 0.11558291715170656, 0.05872521097106593, 0.016448521753773093, 0.03611342841759324, 0.032445010263472795, 0.011522553445372199, 0.013092060922645032, 0.03809892026973622, 0.011637472680636814, 0.020547923299350908, 0.04130367848223873, 0.058675779694957395, 0.03569644150723304, 0.03037807046036635, 0.09352754349155085, 0.04542044543528131, 0.026752668033753122, 0.015652661245050173, 0.029625578517360345, 0.024040115731103078, 0.017889680939593484, 0.04188952222466469, 0.0223406552270587, 0.09306245523371867, 0.028447509410658052, 0.013529654941521585, 0.007822273831282343, 0.021198874173153723, 0.07015058717557363, 0.03579033039776342, 0.8999191192643983, 21.465116807392665, 45.02030038833618, 46.60255806786673, 30.128174236842565, 28.886668375560216, 33.39833695547921, 42.768990244184224, 18.74092616353716, 3.9940955298287526, 5.933213123253413, 23.619047948292323, 34.992013999394004, 16.820358957563126, 7.203454562595912, 1.9735394035066878, 10.205905795097351, 33.00524262019566, 53.31365633010864, 52.47275406973702, 49.16789204733712, 46.93435192108154, 47.470113618033274, 47.49528694152832, 50.667379311152864, 46.187455313546316, 44.55758857727051, 45.863294056483674, 48.806752477373394, 47.16085624694824, 45.01787894112723, 42.984554631369456, 43.20841516767229, 38.13006714412144, 35.61209903444563, 33.92427042552403, 33.87792246682303, 34.883813176836284, 35.984098638807026, 41.93085336685181, 46.61993898664202, 46.5417925970895, 46.55356631960188, 48.46147911889212, 46.54733378546578, 43.949895654405864, 35.78893763678414, 34.046669891902376, 33.32951157433646, 34.12693895612444, 33.145391259874614, 33.76751906531197, 32.82423162460327, 38.736842904772075, 46.22568777629307, 44.559721674237935, 47.39625079291207, 48.226557050432476, 46.93547058105469, 44.71931137357439, 44.93107509613037, 43.344815254211426, 40.09991271155221, 40.03919587816511, 41.30967746462141, 43.602353709084646, 38.74705328260149, 42.43294409343174, 49.919794831957134, 43.038045338221956, 43.50641645703997, 38.20590673174177, 37.70662307739258, 35.33563368661063, 37.7389634677342, 37.98748663493565, 36.51776197978428, 33.64846863065447, 34.904695987701416, 33.86463751111712, 35.87170457839966, 34.13204935618809, 36.43631172180176, 41.620619773864746, 48.698826108660015, 47.588750634874614, 48.40234994888306, 48.105474267687114, 46.07984856196812, 40.446221351623535, 35.847504002707346, 33.41760083607265, 35.20669249125889, 33.441836152757915, 32.87273005076817, 36.990600790296284, 45.37398106711251, 49.27052388872419, 47.02002668380737, 46.663875920431956, 46.12548780441284, 43.549905232020784, 44.495304925101145, 41.79707275118147, 47.816988536289756, 47.43033865519932, 46.946480001722065, 47.070380278996055, 44.39136334827968, 46.29088619777134, 44.32093988146101, 43.45463848114014, 47.007096086229595, 48.76429550988333, 48.282038416181294, 47.368197441101074, 35.63829026903425, 14.15103302683149, 2.37402987905911, 2.957459475312914, 9.342273371560232, 18.473137378692627, 11.358327065195356, 5.069771340915135, 0.5488049313426018, 0.028497337629752498, 0.7020609134009906, 12.39441898890904, 33.348316873822895, 37.30844613483974, 35.86557626724243, 45.75954008102417, 46.89159965515137, 10.752656068120684, 1.0057780189173562, 0.042931324536246915, 0.031056517269462347, 0.019139932601579597, 0.045399787436638556, 0.043988380315048356, 0.005727375416816878, 0.06989081682903425, 0.07095341623893806, 0.020540232104914527, 0.045321050233074596, 0.020827350805380514, 0.02365259250759014, 0.040161588694900274, 0.036473387852311134, 0.030797374567815235, 0.04348934495023318, 0.016000273038766215, 0.06145108970148223, 0.14714886833514484, 0.14388742191450937, 0.2123039857085262, 0.11765832507184573, 0.18034666909703187, 0.15445435632552418, 0.15297912620007992, 0.1269920899399689, 0.09056079840021473, 0.14470524660178594, 0.12124278130275862, 0.1540578476020268, 0.11779963677482945, 0.10662412430558886, 0.11859988740512303, 0.12009186377482754, 0.16678787022829056, 0.21839561526264462, 0.07575742381491832, 0.0933350431067603, 0.13088723378522055, 0.2012531201222113, 0.24686431192925998, 1.1260799978460585, 24.68276330402919, 52.37622274671282, 53.316341808864046, 35.739376136234824, 36.181823526109966, 36.89313840866089, 48.7185138293675, 22.705755880900792, 6.82613958631243, 5.509848526545933, 24.40576641900199, 37.49798257010323, 26.625092267990112, 11.965050714356558, 3.749732596533639, 12.387390886034284, 35.85531725202288, 55.11175285066877, 53.55391461508614, 51.93605784007481, 49.846039703914094, 49.37099484034947, 49.81857000078474, 53.495556695120676, 46.13708782196045, 45.15955965859549, 47.074531827654155, 52.808821065085276, 49.25247941698347, 48.706757477351594, 44.63415772574288, 45.12539884022304, 38.79887294769287, 36.656760692596436, 35.67211757387434, 36.227487087249756, 36.85839394160679, 37.71615253176008, 43.62326431274414, 47.46122687203543, 49.16904544830322, 47.66206802640642, 49.39372934613909, 48.86880683898926, 44.85596506936209, 39.09879193987165, 34.55479860305786, 33.959153856549946, 35.940887791769846, 33.95246968950544, 35.42781891141619, 36.100856167929514, 39.93979147502354, 48.446234771183555, 45.56534835270473, 48.83152627944946, 50.78700992039272, 47.77942657470703, 46.55828414644514, 46.66236121313912, 45.22715868268694, 41.72348090580532, 40.2731625693185, 41.355000564030235, 43.258282388959614, 42.12856435775757, 43.752830845969065, 50.410785811288015, 44.467359270368306, 45.295591490609304, 40.84765005111694, 39.261112281254356, 37.43696696417672, 38.19651971544538, 39.45090579986572, 36.783707754952566, 36.35770327704293, 34.73791142872402, 36.1970157623291, 38.657918316977366, 36.96439913340977, 37.92332696914673, 43.93226112638201, 50.670082160404746, 49.83725370679583, 50.57724380493164, 49.50180857522147, 48.48519679478237, 42.21312740870884, 38.19733265468052, 35.9662834576198, 36.42589637211391, 34.3753787449428, 34.69516611099243, 39.91583061218262, 46.16258423668997, 49.46564320155552, 47.87398113523211, 48.35379941122872, 47.836499077933176, 44.87718139375959, 46.5748347554888, 44.176135948726106, 48.936454500470845, 48.56695624760219, 49.53106049128941, 49.42983218601772, 44.860623836517334, 48.324245248522075, 47.801011153629844, 44.845567090170725, 48.57199369158064, 50.523985862731934, 50.004708766937256, 50.1072016443525, 37.977578503744944, 17.567971229553223, 2.2960354813507626, 4.741387750421252, 15.171058109828405, 18.314440522875103, 16.91352561541966, 9.279061266354152, 2.47249236702919, 0.29087295329996515, 1.1381799599954059, 15.32216579573495, 37.69410589763096, 41.993150915418354, 41.662437507084434, 51.69624771390642, 52.57090779713222, 12.941171867506844, 1.2875947824546268, 0.13625304800059113, 0.10635490875158991, 0.20637167617678642, 0.1544751330677952, 0.1317424186106239, 0.14425773918628693, 0.163974365485566, 0.22352520429662295, 0.16124320775270462, 0.20836122227566584, 0.11992512057934489, 0.14661401989204542, 0.142901211977005, 0.14499499462544918, 0.09934437993381705, 0.11369683407247066, 0.09313502455396311, 0.16084880248776504], [0.07681227435490914, 0.014668259603370513, 0.015294518587844712, 0.047567828957523615, 0.020134016937975372, 0.01683772265511964, 0.042304093550358496, 0.026016810376729285, 0.05444960914818304, 0.0232167745541249, 0.06868533830025367, 0.020799196691119244, 0.027776397565113645, 0.04637992109305092, 0.02988481621391007, 0.059748882826949866, 0.07069997662412268, 0.027985503398148075, 0.017403422389179468, 0.016078557320205227, 0.022795689292252064, 0.011948450368696024, 0.030373626055994203, 0.0695761258580855, 8.325157846723284, 33.80820424216134, 44.05302081789289, 33.24829060690743, 26.21181341579982, 25.825358084269933, 35.70051138741629, 25.068070445741924, 4.7726793970380506, 2.132648374353136, 2.353985628911427, 19.21264805112566, 12.929894941193716, 6.9002338732991895, 0.24340443472777093, 10.12027793271201, 34.69951915740967, 44.89560801642281, 49.56370660236904, 51.76111262185233, 48.20298528671265, 47.79786709376744, 42.84705325535366, 45.46936593736921, 46.17884649549212, 47.51064593451363, 47.70878076553345, 44.96646574565342, 43.102788652692524, 43.48899384907314, 37.586533887045725, 34.78689970288958, 32.6993863923209, 33.35931239809309, 34.142395223890034, 33.44194384983608, 31.69775492804391, 33.845307622637065, 41.78097724914551, 44.430895124162944, 45.99067538125174, 45.603844846997944, 46.49422870363508, 46.949582372392925, 42.125097206660676, 34.215677874428884, 32.930900369371685, 34.33202198573521, 32.43723085948399, 31.182320186070033, 31.444746698651993, 32.15750333241054, 35.97249167306082, 41.289934158325195, 43.42243358067104, 43.2128689629691, 43.35703713553292, 44.24793863296509, 44.35969693320138, 47.211442606789724, 47.31658622196743, 44.64059175763811, 47.358688831329346, 42.53434610366821, 42.35885892595564, 36.36635378428868, 40.91357108524868, 46.74888365609305, 42.4003883089338, 42.069615840911865, 37.9087427003043, 35.327073505946565, 33.190214088984895, 32.729812553950715, 30.691798210144043, 33.72503430502755, 32.929726123809814, 32.84828628812517, 31.922640323638916, 32.230994428907124, 32.42086785180228, 34.248066902160645, 37.78345625741141, 44.775737694331575, 44.033496379852295, 45.90942314692906, 47.132722990853445, 45.14031662259783, 43.56384679249355, 41.42138365336827, 37.78926842553275, 33.21247959136963, 32.73171288626534, 32.801587445395334, 32.47750956671578, 35.545948709760395, 40.984262057713096, 42.824096407209126, 43.18728222165789, 45.959474495479036, 44.24349178586687, 44.64414923531668, 42.9274126461574, 43.42573397500174, 42.90972253254482, 47.98068809509277, 46.57385505948748, 48.19358784811837, 45.023649420057026, 45.4892030443464, 42.13793052945818, 43.554407664707725, 46.522907393319265, 49.51495804105486, 44.20382104601179, 33.19058581760952, 12.592568584850856, 1.7174096958977836, 2.215793341398239, 8.42133481161935, 24.485491786684307, 8.36447422845023, 1.781219563313893, 0.5278068780899048, 0.11725794869874205, 0.9301950803824833, 11.022790738514491, 28.523527724402292, 27.903647661209106, 32.07318694250924, 43.85053988865444, 31.04612159729004, 4.954054738794055, 0.09045566618442535, 0.05314088812363999, 0.03153159695544413, 0.04800483265093394, 0.04635186027735472, 0.011807517797153975, 0.03517004082511578, 0.028061387361958623, 0.03170155640691519, 0.0499146848118731, 0.04105891054496169, 0.013142390409484506, 0.01521905870842082, 0.05695445170359952, 0.03613160637074283, 0.03356498320187841, 0.010621426710193711, 0.052745865391833444, 0.016145623721448437, 0.06302545379315104, 0.08096469832318169, 0.06518145131745509, 0.01881236642865198, 0.02493255043269268, 0.01871953096373805, 0.06000947420086179, 0.03210407355800271, 0.05374901495607836, 0.03163830676515188, 0.1004000243597797, 0.05391833997730698, 0.09836874157190323, 0.02009521152025887, 0.03928760166413017, 0.055359487288764546, 0.0156588986782091, 0.058422835410705636, 0.04792124392198665, 0.01676242223142513, 0.026364647783339024, 0.02861882253949131, 0.03175027182857905, 0.10299877276910202, 11.410351702145167, 40.12148686817714, 48.41712876728603, 37.51966789790562, 31.37959691456386, 28.514562811170304, 40.574085576193674, 26.344885315213883, 6.697492386613574, 2.910384778465543, 3.9460752265793935, 21.33542173249381, 13.250860895429339, 8.501829692295619, 0.9988712923867362, 10.325220261301313, 37.07383326121739, 46.111556666237966, 51.848802362169536, 52.367787633623394, 49.98362793241228, 48.27654586519514, 45.19081265585763, 46.61321660450527, 46.856070041656494, 49.49439137322562, 49.01413536071777, 47.79408727373396, 45.81114435195923, 47.122561250414165, 40.190815993717735, 36.854666233062744, 34.02464757646833, 34.705869810921804, 36.778673785073416, 36.04807070323399, 33.887695108141216, 37.217560223170686, 43.43385989325387, 46.18574258259365, 47.06829234531948, 46.70986952100481, 48.01838207244873, 48.396499565669465, 44.11008289882115, 35.437581130436485, 33.299325125558035, 34.79031474249703, 33.61892489024571, 32.93447174344744, 33.39637756347656, 33.51508058820452, 36.53759561266218, 42.826451846531455, 44.543695654187886, 45.20947551727295, 44.14404569353376, 46.92238712310791, 46.48961509977068, 48.13040093013218, 48.12457833971296, 47.26057679312569, 47.599780900137766, 42.621177741459434, 43.01800325938633, 39.18050275530134, 43.765024934496196, 48.697644914899556, 43.614641598292756, 43.48528003692627, 38.54807424545288, 36.36360924584525, 33.76176248277937, 35.18182488850185, 33.026650020054404, 34.7908011163984, 33.22817209788731, 34.90044021606445, 32.89697926385062, 34.05805104119437, 34.93562936782837, 35.913994789123535, 40.646416323525564, 47.37943615232195, 45.5428535597665, 49.72743047986712, 47.51941456113543, 45.95739351000105, 45.50567027500698, 42.95114769254412, 38.18342930930001, 33.864814690181184, 35.29871095929827, 34.65542588915144, 34.019134180886404, 36.931079047066824, 42.78743423734392, 44.70210763386318, 46.420032364981516, 48.00540631158011, 46.541601521628245, 46.95908055986677, 43.31749493735177, 44.43948309762137, 44.222570759909495, 48.03753130776541, 48.59096574783325, 49.50445931298392, 46.54904999051775, 47.116335664476665, 44.82335717337472, 46.317369256700786, 49.170334339141846, 51.155052525656565, 46.51585149765015, 34.87151486533028, 14.30532819884164, 1.090332384620394, 3.315580270120076, 8.56189947468894, 26.119444063731603, 10.031561596052986, 3.9082744206701006, 1.1804411837032862, 0.07106654838259731, 0.947250519480024, 13.805423549243383, 29.65532500403268, 32.119267395564485, 36.93523754392351, 49.116593497140066, 36.1285343170166, 6.582084110804966, 0.0928729200469596, 0.01944786366740508, 0.017233025282621384, 0.03940509678795934, 0.07872241828590631, 0.03474986140749284, 0.12123785513852324, 0.03361252475796001, 0.02855252966816936, 0.015453677458156432, 0.09995312762579747, 0.009474898455664515, 0.05392486748418637, 0.0667267944663763, 0.0364226470036166, 0.04708466791946973, 0.0452755646380995, 0.030529319308698177, 0.05549416631194098, 0.15349383572382586, 0.09983865876815148, 0.2362672777048179, 0.14338267328483717, 0.06889453064650297, 0.07019217458686658, 0.14316714342151368, 0.14436663048607962, 0.1653474760907037, 0.128871957638434, 0.1971782459212201, 0.07504488740648542, 0.27112381160259247, 0.2225008471203702, 0.17660258071763174, 0.212204973878605, 0.10104234596448285, 0.13203859914626392, 0.1685079972126654, 0.09943289482699973, 0.23611884138413838, 0.14845932301666054, 0.11139607110193797, 0.19156640847878798, 12.860421640532357, 44.951607022966655, 54.36480065754482, 46.488374846322195, 36.5367305619376, 34.164751052856445, 47.39844989776611, 31.161461693899973, 7.043933476720538, 3.135410006557192, 5.0160456980977735, 25.369849818093435, 16.119245767593384, 11.31072495664869, 3.320989659854344, 13.244656154087611, 39.39039741243635, 47.872751304081504, 51.764027391161235, 53.072824818747385, 51.40694209507534, 48.415655749184744, 45.977140290396555, 45.840535231998985, 49.02430057525635, 52.31294550214495, 51.17444494792393, 49.425461769104004, 47.26736518314907, 48.64728437151228, 40.922548157828196, 38.62271874291556, 34.82025453022548, 35.98287575585501, 37.86327716282436, 37.805621010916575, 35.20191560472761, 38.721209457942415, 45.01117740358625, 48.76240907396589, 49.73291608265468, 46.438861983163015, 49.848777294158936, 49.73387145996094, 46.036272934504915, 37.56739854812622, 35.89726005281721, 37.60319914136614, 35.74648414339338, 35.496863160814556, 34.457343169621055, 34.955605438777376, 38.52391535895211, 44.07465750830514, 46.72568014689854, 46.537046977451865, 45.89750698634556, 48.707709380558555, 47.8925849369594, 50.94793367385864, 50.549180030822754, 49.41536603655134, 49.663072790418354, 44.75185326167515, 42.803203174046104, 39.83740282058716, 47.32022360392979, 49.43875019890921, 45.80677740914481, 45.474187987191335, 42.18347944532122, 38.540059498378206, 35.319159507751465, 35.551486424037385, 33.323275566101074, 37.0568379674639, 35.109417710985454, 35.59532955714634, 34.32775231770107, 35.591369083949495, 36.31180695125035, 37.12834882736206, 41.277038301740376, 49.398023332868306, 45.77422857284546, 50.69103445325579, 50.21225840704781, 48.27135903494698, 47.07333673749651, 44.82676179068429, 41.90839678900582, 34.97762428011213, 37.43804046085903, 35.82168102264404, 36.849976199013845, 39.18996272768293, 43.663209506443565, 46.3721592766898, 47.77651875359671, 50.68499299458095, 48.40594564165388, 47.23080723626273, 44.64437157767159, 43.42910385131836, 43.40177658626011, 49.58375562940325, 50.40361874444144, 52.22617292404175, 48.995663574763704, 49.32000548498971, 47.19087246486119, 47.08591992514474, 50.890979290008545, 53.17671080998012, 48.145047732761924, 37.60411977767944, 16.18964317866734, 2.9768961923463, 7.085237043244498, 16.509390592575073, 30.156526361192974, 15.412336042949132, 8.371438929012843, 1.679532568369593, 0.19682620838284492, 1.82549934727805, 17.336769921439036, 39.38704490661621, 37.89257424218314, 43.09214401245117, 55.019435610089985, 42.19910594395229, 8.461338196481977, 0.22132911213806697, 0.10795294693005936, 0.12312354466744832, 0.12489985435136727, 0.11299227723585707, 0.14675637653895787, 0.21714004049343721, 0.08323367192809071, 0.09881428802119833, 0.15968649914222105, 0.18587158620357513, 0.15046724384384497, 0.09188516983496291, 0.12472150820706572, 0.1548876009349312, 0.1989638651055949, 0.09552806828703199, 0.11220077292195388, 0.095523338897952], [0.025035465535308634, 0.06887257325329951, 0.054036835940288644, 0.03480045637115836, 0.03925800735929182, 0.018284321995452046, 0.014087463313314532, 0.019086844021720544, 0.03605202439108065, 0.052258626358317475, 0.003105637604936159, 0.04291369280378733, 0.08821517069424901, 0.01912085898220539, 0.08679340912827424, 0.08762879430183343, 0.06613536298807178, 0.04955716471054724, 0.009809474743503546, 0.05897361585604293, 0.05556110718420573, 0.01808002358302474, 0.0501758868673018, 0.022012324005897557, 2.506905708994184, 28.690479040145874, 46.58846364702497, 32.264738355364116, 27.990890979766846, 33.54941511154175, 41.19773851122175, 24.47206265585763, 2.8932181681905473, 0.31308783697230474, 0.8467103572828429, 12.772140434810094, 11.970581480434962, 9.277457969529287, 1.8515785421643938, 8.434012668473379, 24.60823518889291, 41.50284433364868, 52.28117486408779, 49.22966153281075, 45.5941173689706, 46.431684494018555, 47.44210542951311, 48.85056781768799, 47.378265380859375, 43.25684758595058, 44.56302901676723, 42.11104447501046, 40.491815430777415, 36.38127851486206, 33.496650491442, 33.90291861125401, 35.196732248578755, 33.3311721937997, 32.87386608123779, 32.167546953473774, 34.215420791081016, 33.42641462598528, 39.783248560769216, 43.4486734526498, 44.50950356892177, 46.22669179098946, 44.94485337393624, 45.9312231200082, 43.60015113013131, 36.92630910873413, 33.044360978262766, 33.78415305273873, 32.71253933225359, 32.69414745058332, 32.24555785315377, 31.03556033543178, 35.33229855128697, 36.20234503064837, 40.20721026829311, 42.92587014607021, 42.910695280347554, 43.094468184879844, 43.86253942762102, 43.24309710093907, 45.98467561176845, 43.229520320892334, 44.289620876312256, 44.981345312935964, 47.903597831726074, 37.27417414528983, 39.90444598879133, 47.947913442339214, 41.986101967947825, 41.97876467023577, 36.53262765066964, 33.995708329336985, 31.821554456438335, 33.75547783715384, 31.681020191737584, 32.965356486184255, 32.06656878335135, 33.088443824223106, 32.2019579069955, 33.18031638009207, 33.1166535105024, 31.44179024015154, 34.94117750440325, 41.824313163757324, 45.95108454568045, 44.83968196596418, 46.695518016815186, 46.31290851320539, 45.45770686013358, 45.04800285611834, 42.17677443368094, 39.34971570968628, 33.6886431149074, 33.02886649540493, 31.463558946337017, 31.14211790902274, 33.18391554696219, 39.51625708171299, 43.89990683964321, 45.912970202309744, 45.39368615831648, 47.19580568586077, 45.943128858293804, 46.76828302655901, 43.16942187717983, 43.1561473437718, 43.98780850001744, 46.298880100250244, 47.60594742638724, 47.90424748829433, 45.33122532708304, 47.76162528991699, 45.44241387503487, 49.111285073416575, 36.38675022125244, 25.087337800434657, 7.983284762927464, 2.9702181049755643, 2.154264654432024, 12.696942687034607, 22.516368831907, 2.6766436866351535, 3.813051096030644, 0.6617293347205434, 0.31754144227930475, 1.0880854023354394, 18.12586293901716, 36.01900291442871, 28.759389536721365, 36.23182276317051, 44.93344790594918, 25.1412193434579, 3.073297453778131, 0.0392317141273192, 0.025819397398403714, 0.013092036325750607, 0.03752827910440309, 0.039433137247604985, 0.001306784655233579, 0.06408080644905567, 0.029860704472022395, 0.021607949365196482, 0.02351335881810103, 0.05629410142345088, 0.018029582986075963, 0.034649699460715055, 0.0319080346130899, 0.05173216460804854, 0.02050892958816673, 0.035231241291122775, 0.021343715954571962, 0.027590706279235225, 0.04663204434993012, 0.04585810052230954, 0.03268340336424964, 0.0017513173308023916, 0.050448240645762, 0.03228644680763994, 0.045280341524630785, 0.057596970083458085, 0.024464636076507822, 0.04259479491572295, 0.01792164672432201, 0.02868854201265744, 0.00947781276356961, 0.015358599435005869, 0.04078552878594824, 0.0806335596633809, 0.14641900892768586, 0.08172570927334682, 0.049754859280905554, 0.06281205452978611, 0.003949698060750961, 0.024624346256522194, 0.05309358744749001, 0.05474685498380235, 3.8988561374800543, 34.734836850847515, 52.18116249356951, 38.96660246167864, 29.16106489726475, 32.69845533370972, 44.781011377062114, 27.33010687146868, 3.9289830923080444, 0.38217282561319216, 1.0697734249489648, 15.468333312443324, 13.123809610094343, 7.749487434114728, 3.006969081504004, 9.891545840672084, 27.029161282948085, 44.31494358607701, 52.43436527252197, 51.46256242479597, 48.23824739456177, 47.51310907091413, 48.14941120147705, 49.292796339307515, 49.7988405908857, 46.07616254261562, 46.8583698953901, 45.14552082334246, 43.05396366119385, 38.11599356787545, 35.33452892303467, 34.6715908731733, 36.11669111251831, 35.00549350466047, 34.9303765296936, 33.56104639598301, 35.46473816462925, 34.66845376150948, 42.12678214481899, 45.91141380582537, 46.66897937229702, 45.953342710222515, 46.48323665346418, 47.546373571668354, 44.91253730228969, 38.208432401929585, 35.2060741015843, 34.8300758089338, 34.99105167388916, 33.71997601645333, 33.92409324645996, 33.23726034164429, 35.44047852924892, 38.72003868647984, 42.52140160969326, 44.98261335917881, 46.01657479149954, 45.01802485329764, 45.827118260519846, 44.92181314740862, 46.94143908364432, 45.033738204411094, 46.849681173052105, 45.749527726854595, 47.349419934409006, 38.70481170926775, 42.6945298739842, 49.565443652016775, 43.41748993737357, 42.85223661150251, 37.21631302152361, 36.21113797596523, 33.6622816494533, 34.00246197836739, 33.672422545296804, 34.27166645867484, 34.110134737832205, 33.23731940133231, 33.50824703489031, 33.540622166224885, 34.218259130205425, 32.92176348822457, 37.45815896987915, 44.07695736203875, 48.11492034367153, 46.776287351335796, 47.087719508579795, 47.95842259270804, 46.92330775942121, 46.56199101039341, 43.27138669150216, 39.96251208441598, 34.36104113715035, 33.87667873927525, 32.08051381792341, 34.13936580930437, 35.40066882542202, 42.00066539219448, 45.567484923771445, 46.40272440229143, 46.770308426448274, 47.40655844552176, 48.26464360100882, 46.54385968617031, 44.57370492390224, 44.873050689697266, 45.96747882025582, 47.97650875364031, 49.734802518572124, 49.38154220581055, 46.59438003812517, 48.115757601601736, 47.02626616614205, 50.16189438956124, 39.932336057935444, 28.886246272495814, 9.821619170052664, 2.5066373348236084, 3.8974847367831638, 12.024048737117223, 28.3612733909062, 7.417643206460135, 5.368364529950278, 0.3040141138647284, 0.31538101392132895, 1.2532598248549869, 19.55165934562683, 39.42635781424386, 32.93275901249477, 38.0478595324925, 51.16943529673985, 29.035959107535227, 4.2742460284914285, 0.07174416737897055, 0.008526030844742698, 0.020989281491243413, 0.02459375959421907, 0.016690500912123492, 0.041042978542723825, 0.01800575792523367, 0.02675521593274815, 0.024900618574715087, 0.05101898359134793, 0.025204307100336467, 0.049276315673653565, 0.031078556086868048, 0.0570913664996624, 0.0053209901920386726, 0.027185483469760845, 0.03808466764166951, 0.020496710868818418, 0.027494900527277162, 0.07693586272320577, 0.1831309154097523, 0.14910123071500234, 0.13170910254120827, 0.1675277312419244, 0.10817120450415782, 0.10450972776327815, 0.14258441754749843, 0.07246650861842291, 0.1302102186850139, 0.1022160215569394, 0.1940202625202281, 0.12831737739699228, 0.1209171252059085, 0.2408575399645737, 0.22982222640088626, 0.1913477980664798, 0.20140892533319338, 0.08891141547688416, 0.22117276409907, 0.1284461904849325, 0.1003956070968083, 0.21463009874735559, 0.14991886541247368, 4.744022854736873, 39.13400193623134, 59.18622861589704, 44.465806347983225, 36.2409005846296, 43.978949546813965, 52.22950111116682, 31.287467275347026, 4.6902802756854465, 0.5360404391373906, 1.467173906309264, 16.175402845655167, 16.003487042018346, 14.321029390607562, 5.490087415490832, 10.554799165044512, 28.523230688912527, 47.608017989567344, 55.08415807996477, 54.314315046582905, 47.68691825866699, 48.095948287418906, 47.81106519699097, 51.56494413103376, 51.12249674115862, 47.32248524257115, 50.295150416237966, 48.10344191959926, 45.0431877544948, 39.69224452972412, 38.26202385766165, 38.351242201668875, 39.003667627062114, 35.87377166748047, 36.05609239850725, 35.68988759177071, 36.864827973502024, 36.149820123400005, 44.169069630759104, 47.29774618148804, 47.978082520621165, 47.45082541874477, 46.76667104448591, 48.91457462310791, 47.67930998120989, 41.29417603356497, 37.064699854169575, 37.1678979737418, 36.15318305151803, 36.19287116186959, 35.292534010750906, 33.80211762019566, 38.53744350160871, 39.461908272334504, 43.77210167476109, 45.829859324863975, 48.44333389827183, 48.28907694135393, 46.96779360089983, 47.06794840948922, 50.25116484505789, 46.21128763471331, 46.692658833095, 48.0215608733041, 50.07293312890189, 41.89508056640625, 43.9284222466605, 49.797471795763286, 45.2510917527335, 45.247801780700684, 39.455495085035054, 37.71737888881138, 34.93616437911987, 37.18256909506661, 34.26121289389474, 35.796608448028564, 35.82897663116455, 34.318754400525776, 34.992778301239014, 35.92092909131731, 36.17187023162842, 32.853087493351524, 39.17067452839443, 44.912926401410786, 51.68158006668091, 48.64882339750017, 49.543584619249614, 49.231773785182405, 49.81938988821847, 48.19368512289864, 44.57599088123867, 42.677183696201865, 36.975603103637695, 36.26683473587036, 33.941957065037315, 34.83861861910139, 35.53104134968349, 42.43149539402553, 47.914833068847656, 48.64667640413557, 49.070200375148225, 49.388684953962056, 49.67448173250471, 48.940852710178916, 46.328635760716026, 44.817996638161794, 45.20516068594796, 48.689581530434744, 50.545056274959016, 52.38794435773577, 50.04744713647025, 50.59287377766201, 48.23666320528303, 52.901972089494976, 40.88429832458496, 29.91995756966727, 10.770283647945949, 4.598617034299033, 6.756284134728568, 23.87726558957781, 27.576258965900966, 7.772692680358887, 10.939055391720363, 2.0292441972664426, 0.8029243839638573, 1.9383461262498582, 23.670756442206248, 45.0761604309082, 40.912702560424805, 44.812010765075684, 57.62614263807024, 33.958420821598594, 5.040525070258549, 0.17168778872915677, 0.07453803531825542, 0.11323069408535957, 0.16737849424992288, 0.08602202337767396, 0.07157356331923179, 0.11824942406799112, 0.09258871565439872, 0.25110211595892906, 0.12039891444146633, 0.13984549737402371, 0.09884005878120661, 0.13860650600067206, 0.18132256530225277, 0.14891912548669747, 0.14633097579436644, 0.09908363928220101, 0.11315549204924277, 0.15238855646124908], [0.04684413743338414, 0.026987641318035976, 0.049692115147731135, 0.05857998412102461, 0.008715801822420741, 0.003747616761497089, 0.020211775354774933, 0.055142739455082586, 0.049618782475590706, 0.0075999959371984005, 0.10467434714415244, 0.06348516805363552, 0.02942494928304638, 0.10345799169902291, 0.020852940057271292, 0.026529553845258694, 0.04448726300948432, 0.037310754348124774, 0.028503980487585068, 0.03448620305529662, 0.022985572228208184, 0.03218491422012448, 0.017456417670473456, 0.03517218499577471, 1.3640592736857278, 21.189985513687134, 44.858129433223176, 42.592940262385774, 31.43084682737078, 42.96374477658953, 50.12890781675066, 30.120496477399552, 7.512633766446795, 0.26388357153960634, 0.10318676089601857, 7.368835585457938, 11.688013008662633, 5.402315165315356, 1.9373169243335724, 7.20375029529844, 24.147944825036184, 38.21028757095337, 43.807308197021484, 43.45940147127424, 48.684148039136616, 50.59353385652815, 49.90635701588222, 45.70880433491298, 45.274333477020264, 44.01561171667916, 41.68232672555106, 38.70308855601719, 34.58055904933384, 33.26956251689366, 33.183568137032644, 34.430821895599365, 31.77636684690203, 33.99543387549264, 34.6316248348781, 33.861747060503276, 34.57332944869995, 34.70073856626238, 39.208351135253906, 42.72799934659685, 45.41028193065098, 47.212154797145296, 46.77249016080584, 45.65870087487357, 43.191868032727925, 42.08116027287075, 39.13945279802595, 34.44775812966483, 34.108067648751394, 32.404609067099436, 32.56210388456072, 31.686099324907573, 33.063353879111155, 33.13290187290737, 34.884250913347515, 37.18607793535505, 38.80166959762573, 40.928231784275596, 43.27538537979126, 43.907185077667236, 44.71167877742222, 40.79833173751831, 44.52917044503348, 44.12978799002511, 45.85196154458182, 38.60490008762905, 38.95653452192034, 48.13233947753906, 41.72924791063581, 43.534077235630576, 41.19716875893729, 37.87436648777553, 34.22575971058437, 33.22447565623692, 31.83600323540824, 33.151033197130474, 32.84867538724627, 33.46741247177124, 32.618189743586946, 32.25158541543143, 32.98726415634155, 32.13200691768101, 32.589524950299946, 35.97399248395647, 39.64982577732631, 43.7556448663984, 45.27204057148525, 47.206186294555664, 46.672543798174175, 46.63943215778896, 47.60810136795044, 43.38433313369751, 37.08638865607125, 30.74364914212908, 30.871499470302037, 31.364029475620814, 32.92087411880493, 33.41847283499581, 35.3036858694894, 38.548136779240195, 41.460039956229075, 43.90855387278965, 44.493887492588584, 44.89978388377598, 44.73131091254098, 46.263062136513845, 43.69873564583914, 44.87359612328665, 46.9077125276838, 48.63395772661482, 46.659578459603445, 48.32571479252407, 47.852882930210654, 45.9798709324428, 31.511553628104075, 14.171767319951739, 2.1225795660700117, 0.3749922423490456, 2.5383982019765035, 17.181979690279277, 9.008148397718157, 4.862855723925999, 3.03510559456689, 0.3050820737012795, 0.4030126173581396, 1.4385209466729845, 22.781128202165874, 33.92806761605399, 28.917719875063213, 34.57456622804914, 42.416146823338096, 18.930818693978445, 1.153918824025563, 0.029929558813039745, 0.0153951572054731, 0.026207787450402975, 0.0495519128495029, 0.01489962138501661, 0.027202380688062737, 0.032263285014778376, 0.020118281710892916, 0.06193449840481792, 0.034734818286129406, 0.039289213184799464, 0.07258608684475933, 0.04498003549607737, 0.0030870374757796526, 0.02215543552301824, 0.034066956623324325, 0.016838818489174758, 0.0415767515078187, 0.061392213217914104, 0.054950907427285395, 0.0073734135865899065, 0.07510070369711944, 0.0032660012989903665, 0.04316720366477966, 0.01721287957791771, 0.023009412556088397, 0.08264870010316372, 0.055109481061143537, 0.04384418483823538, 0.012044125502662999, 0.04797720270497458, 0.03721099612968309, 0.024831845657899976, 0.004076594711347882, 0.054390301794878075, 0.014431976746501667, 0.011462023880864893, 0.0017837470638499195, 0.012479673738458326, 0.014877568996910537, 0.04249529114791325, 0.006381767311333013, 0.001286529006652667, 1.8947913433824266, 27.58265825680324, 50.7365277835301, 44.045176301683696, 35.134080341884065, 41.686912536621094, 50.94141278948103, 29.13033996309553, 6.876753304685865, 0.29140858884368626, 0.16035511397889682, 8.900452188083104, 10.976110134805952, 6.68550717830658, 4.00505805015564, 9.23062711102622, 27.229347569601877, 41.087842328207834, 48.27060168130057, 48.100422927311485, 50.01964739390782, 51.335010869162424, 52.53618764877319, 48.89118003845215, 45.199303354535786, 46.09098999840872, 43.90211636679513, 40.299319062914165, 37.75803279876709, 36.13009071350098, 34.23578596115112, 35.48881714684622, 33.918274130140034, 34.66975654874529, 36.840662138802664, 35.83199214935303, 35.35398735318865, 35.92345128740583, 41.34854221343994, 44.883782182421, 47.706585134778706, 47.24007960728237, 47.78446749278477, 47.17344638279506, 45.625050749097554, 42.977530002593994, 40.00568471636091, 35.626700673784526, 34.96069499424526, 34.16949667249407, 34.382337365831646, 34.24549259458269, 34.361645630427766, 34.10934959139143, 37.68672343662807, 39.13515881129673, 39.61750275748116, 43.03836495535714, 43.655090536390034, 45.78071471623012, 46.00291463306972, 43.45759841373989, 46.661225182669504, 44.98902307237898, 47.95221785136631, 41.401042801993235, 40.941676548549104, 48.33607803072248, 42.806302070617676, 44.901913506644114, 43.31085940769741, 38.77092729296003, 35.659200872693745, 33.56509372166225, 32.7411276953561, 34.664368220738, 33.504821572984966, 34.27987922940935, 34.46767861502511, 34.046781063079834, 33.0222726549421, 33.26918731416975, 33.975899015154155, 37.11521325792585, 42.76601988928658, 45.71254941395351, 45.591744559151785, 49.280928816114155, 48.09676122665405, 47.38249683380127, 47.368325982775005, 44.8246043750218, 37.59972504207066, 33.07448836735317, 31.576880591256277, 32.41730342592512, 33.64662388392857, 35.05389813014439, 38.290890148707796, 41.44577530452183, 43.41922698702131, 46.66235079084124, 45.92540747778756, 48.42428541183472, 46.42057432447161, 46.92395741598946, 44.086757796151296, 47.65200703484671, 46.33513232639858, 50.143610204969136, 48.35223954064505, 50.91795914513724, 48.4451265335083, 48.87885046005249, 32.360668659210205, 17.606591054371425, 2.840470267193658, 2.229686264480863, 3.646957882813045, 17.30345504624503, 17.166231598172867, 6.917082820619855, 6.066674990313394, 0.6266648705516542, 0.16932768108589308, 2.0004334918090274, 24.249984332493373, 37.237866333552766, 33.77233764103481, 40.811071259634836, 48.18651110785348, 23.85312581062317, 1.552535457270486, 0.05479429475963116, 0.02504288192306246, 0.02203854768803077, 0.02724100968667439, 0.009922260834303285, 0.08913305215537548, 0.08059491709406887, 0.004582945531832853, 0.03033314465678164, 0.02496839574139033, 0.038761214552713294, 0.014968653841476356, 0.0052687332416618505, 0.022170619440398047, 0.022547825538952435, 0.06000612223786967, 0.032578559525843175, 0.01214559278118291, 0.031234235768871646, 0.08327548325593982, 0.09181513145033803, 0.1298133706940072, 0.15085851427699837, 0.16351955703326634, 0.08747012567307268, 0.14740186690219811, 0.12529943005314895, 0.16949172371200152, 0.12356460600027017, 0.1781557338046176, 0.20802716591528483, 0.18224158670221055, 0.14006070154053823, 0.09304524080029555, 0.0879826367433582, 0.08576688063996178, 0.20243622735142708, 0.08065515743302447, 0.10686907544732094, 0.06710891824747835, 0.14938139782420226, 0.10385789309761354, 0.08989516233227082, 2.367020232336862, 33.213497502463206, 56.431580543518066, 53.10699258531843, 42.994167464120046, 50.804772990090505, 57.1580286026001, 36.684150491442, 10.72697639465332, 0.6601664242999894, 0.3164231080029692, 10.5579206432615, 14.397318874086652, 8.05486684186118, 4.561125423227038, 10.405809811183385, 35.51468529020037, 44.59089824131557, 48.64028058733259, 47.37805346080235, 50.21584367752075, 50.9427398954119, 53.736002581460134, 49.98744249343872, 49.79865646362305, 49.06793526240757, 45.26350123541695, 41.48419189453125, 38.59229605538504, 37.61750200816563, 36.02926887784685, 37.74971233095442, 34.75430222920009, 36.32300049918038, 39.312949316842214, 38.06838798522949, 37.33035033089774, 38.20985678264073, 44.42507948194231, 44.96646921975272, 48.65782478877476, 48.57077775682722, 49.377355916159495, 49.61187498910086, 48.070625577654155, 47.08273070199149, 43.020716530936106, 38.85690082822527, 37.21456554957798, 35.34882831573486, 36.42027527945382, 35.88652856009347, 36.240553174700054, 36.08873503548758, 39.41000522886004, 40.507660797664094, 41.2305201121739, 45.734092303684776, 45.453537940979004, 48.46918814522879, 47.49359505517142, 45.925542967660085, 48.21872295652117, 48.119057995932444, 47.9402356828962, 44.99236863000052, 42.60787541525704, 48.99881458282471, 45.931851931980674, 46.999088287353516, 46.00229624339512, 40.715241704668315, 38.10357713699341, 36.67402001789638, 34.18818037850516, 36.184661865234375, 35.35651649747576, 36.44593497685024, 35.55737154824393, 35.739386558532715, 34.61412579672677, 34.70726292473929, 34.964137826647075, 39.23558807373047, 42.9755289213998, 47.40598521913801, 48.542741775512695, 51.83812298093523, 48.59892838341849, 50.87078782490322, 51.28477886744908, 48.153503690447124, 39.890334197453086, 34.151827403477256, 33.67653587886265, 33.21430001940046, 35.96449082238333, 36.624243123190745, 40.223719188145225, 42.109463759831016, 44.40831695284162, 48.27454130990164, 48.35630771092006, 49.528972557612825, 48.23278611046927, 47.60972377232143, 44.72344902583531, 47.35117782865252, 47.24663175855364, 52.533015796116416, 49.727076121738975, 52.00230891363961, 52.034180300576345, 49.44970055988857, 33.368091447012766, 17.422453369413102, 3.276921578816005, 1.171745404601097, 7.617905054773603, 24.292875562395366, 12.283013309751238, 14.135618448257446, 8.132039615086146, 1.2385446258953638, 0.9357033733810697, 2.4527301703180586, 29.299191611153738, 43.8082149369376, 40.31956958770752, 46.30564764567784, 54.429325103759766, 27.453284536089214, 1.8898843952587672, 0.16946068752024854, 0.0855049661227635, 0.12855483751211846, 0.10098337448601212, 0.09162874466606549, 0.13081604189106397, 0.19408732892147132, 0.09024899798844542, 0.1330298302429063, 0.11074396502226591, 0.09408016955213887, 0.1400747336447239, 0.14681220640029224, 0.07931475900113583, 0.16325859246509417, 0.12517885438033513, 0.14234849092151436, 0.13902531138488225, 0.1776279556964125], [0.02412088684338544, 0.00810402786425714, 0.003527787106577307, 0.009759361539701266, 0.07006834873131343, 0.015179834295330303, 0.04882752921964441, 0.03467554146690028, 0.04119227660287704, 0.020309504753510867, 0.01052844790475709, 0.03593400340261204, 0.00717619653525097, 0.08224309222506625, 0.026261093161467994, 0.021520348797951425, 0.043545025533863475, 0.03154912690765091, 0.07124595304152795, 0.08519717585295439, 0.014573318983561226, 0.08091663090246064, 0.002604459553757416, 0.01178375634896968, 0.5414195390684264, 13.967110736029488, 46.770600250789094, 42.44502701078142, 37.760110310145784, 62.888360840933665, 59.39442443847656, 35.956090450286865, 19.099018948418752, 1.2298248537949152, 0.03856449368010674, 1.5226145599569594, 10.881987231118337, 2.0439841491835455, 0.4498627191143376, 7.973679746900286, 18.918582916259766, 28.495615073612758, 42.713157994406565, 50.567617075783865, 51.289434160505024, 51.02527059827532, 45.793391704559326, 44.402126107897075, 44.23816251754761, 40.57194553102766, 37.66259929112026, 34.54398373195103, 33.514597688402446, 34.09547403880528, 33.77548517499651, 31.883181503840856, 34.99936866760254, 36.388407366616384, 36.01483746937343, 35.45029980795724, 35.915426118033274, 37.92992775780814, 41.14757946559361, 44.43774604797363, 44.7134609903608, 45.545507771628245, 42.92797545024327, 45.74827357700893, 46.08579274586269, 44.868461404527935, 44.48625489643642, 40.60478271756853, 36.398270334516255, 33.74278000422886, 32.78557879584176, 31.697602067674907, 32.62506151199341, 33.171700613839285, 32.38999005726406, 32.772165298461914, 33.94892610822405, 36.28362505776541, 38.28309079578945, 39.19169282913208, 40.09007406234741, 38.89821481704712, 42.653844697134836, 42.41693891797747, 46.554327147347585, 38.81102534702846, 38.29916892732893, 46.92142479760306, 44.365981578826904, 44.309642110552105, 43.22523675646101, 42.44096231460571, 41.179808684757774, 38.18341888700213, 32.48896367209298, 31.722452299935476, 33.43644782475063, 31.711408138275146, 31.899398599352153, 32.561600140162874, 32.253711564200266, 33.17695345197405, 32.993833678109304, 32.06780208860125, 35.080075468335835, 37.13705492019653, 43.40281534194946, 44.56701380865914, 46.72837257385254, 46.484070437295095, 48.21326167242867, 46.98790168762207, 42.30480541501726, 34.16039800643921, 31.380639144352504, 30.883453845977783, 32.65670708247593, 32.173661368233816, 32.34381580352783, 33.38583714621407, 35.53236845561436, 40.800840037209646, 43.14734050205776, 43.85697044645037, 46.18247692925589, 45.93242168426514, 45.9181535584586, 43.87481689453125, 46.91371577126639, 47.179331507001606, 49.28015409197126, 47.69802842821394, 46.838543210710796, 41.030516215733115, 23.40925404003688, 7.744466492107936, 0.9923258721828461, 2.4073803637708937, 13.409430946622576, 10.009464587484088, 4.750172444752284, 8.80843198299408, 5.833067868437086, 0.23001039773225784, 0.029110750249986137, 3.7409257548195973, 21.765772308622086, 33.5291611126491, 23.07633978979928, 32.473611627306255, 41.169400283268516, 10.725668396268572, 0.3997599918927465, 0.02805589631732021, 0.016572390017764907, 0.00606544828042388, 0.028183007978701165, 0.024992602478180612, 0.03695150398250137, 0.020582922135612795, 0.03879877146599548, 0.03120311815291643, 0.012666021506967289, 0.03174485033378005, 0.006405755220579782, 0.012948959583549626, 0.08599123824387789, 0.035065190201359134, 0.07044425713164465, 0.03699904553858297, 0.034792643040418625, 0.044270053771989684, 0.035528561765594144, 0.08945329354277679, 0.03288117257346, 0.03716107291568603, 0.01035612799958991, 0.029742269577192407, 0.03825105121359229, 0.012846063140646687, 0.05395406484603882, 0.020591454713472297, 0.016340086768780435, 0.052746048596288474, 0.02599720750004053, 0.06454538580562387, 0.04447169402348144, 0.020024072212566222, 0.048531796517116685, 0.04583362915686198, 0.05923006138099091, 0.07385291850992612, 0.050321419058101516, 0.038974610423403125, 0.038199499515550475, 0.04637367857087936, 0.6892851303730692, 19.236727033342632, 52.0067001751491, 48.95655216489519, 38.32634333201817, 58.25247062955584, 60.809682164873394, 42.09981966018677, 18.491009882518224, 1.463747033051082, 0.012260321178473532, 3.6320898234844208, 15.280158724103655, 3.2728857610906874, 1.372379632932799, 9.77848562172481, 22.965510811124528, 33.45236962182181, 45.95277990613665, 50.80361958912441, 51.35722426005772, 51.87710237503052, 47.38269485746111, 45.42523445401873, 47.169416427612305, 42.707575116838726, 40.376881803785054, 35.77218205588204, 34.76848350252424, 34.27196870531355, 34.57415975843157, 34.309798172542024, 36.78630290712629, 38.35122830527169, 37.75327328273228, 37.453927516937256, 37.91260589872088, 39.33998128346035, 41.43915714536394, 47.55522905077253, 47.04330314908709, 46.22531952176775, 43.397809164864675, 46.623399189540315, 48.76600824083601, 47.63405636378697, 46.13851567677089, 42.39909246989659, 36.5723192351205, 34.33931412015642, 33.63583680561611, 33.27412748336792, 34.543320178985596, 34.631437233516145, 33.675750732421875, 34.678813525608604, 36.493436336517334, 39.05643572126116, 40.33229521342686, 40.93201855250767, 42.63560567583357, 40.35339341844831, 43.77394642148699, 44.47591250283377, 47.53669820513044, 41.78650801522391, 39.313995020730154, 48.22505276543753, 46.128927162715364, 44.48657103947231, 44.956050395965576, 43.343783446720664, 42.5279780796596, 39.143819740840364, 33.65686205455235, 33.73754801068987, 35.250229903629844, 33.758312702178955, 33.22002533503941, 32.40718684877668, 34.0919999395098, 33.55950389589582, 35.09323535646711, 33.73656484058925, 37.10934550421578, 40.56696367263794, 45.245727743421284, 46.27911942345755, 46.42272479193551, 46.975196906498496, 48.313802106039866, 48.054693358285085, 44.03701564243862, 36.05540452684675, 33.47283206667219, 31.695253576551163, 34.52083928244454, 32.130603381565635, 33.57478298459734, 35.218049321855815, 38.9151406288147, 42.06684003557478, 44.85270983832223, 45.0519563811166, 46.41800349099295, 47.097360134124756, 45.64805276053292, 44.58525630405971, 47.19435003825596, 48.87498378753662, 50.048124585832866, 49.702045236315044, 48.71992083958217, 42.61148847852434, 25.763770989009313, 9.964276109422956, 2.2368680962494443, 2.1774861855166296, 8.703082527433123, 16.203843559537614, 8.689490113939558, 9.65591766153063, 3.853602954319545, 0.25091937290770666, 0.2390792625291007, 4.0414696506091525, 23.928001335689, 37.55836588995797, 26.980873039790563, 38.41421719959804, 45.949715750558035, 15.118203163146973, 0.3252408334187099, 0.024413905405838574, 0.06273879310382263, 0.018362292454444935, 0.03785394537927849, 0.08471086301973887, 0.04033544633005347, 0.02573226671665907, 0.008827452215233018, 0.03421350661665201, 0.002771839511946642, 0.046949167868920734, 0.018228247861510942, 0.027737761781151806, 0.05192111964736666, 0.08329889949943338, 0.045612922071346214, 0.043084765052688975, 0.05475962162017822, 0.01421750963865114, 0.12187808007001877, 0.1259725367916482, 0.08604743451412235, 0.0991751668708665, 0.12084000291568892, 0.10552026318120104, 0.14588445903999464, 0.2833062293274062, 0.12560524578605378, 0.13718812353909016, 0.13078328222036362, 0.15911563406033175, 0.09054507674383265, 0.12826739650751862, 0.09615406433918647, 0.11291571134435278, 0.1557318749172347, 0.10576465113886765, 0.13605308373059544, 0.16694284762654985, 0.1438625603914261, 0.15044345440609114, 0.1755912107016359, 0.12211650370487145, 1.095308380467551, 24.494802372796194, 61.37689140864781, 54.441689423152376, 46.5782984324864, 66.99679592677525, 63.70698370252337, 44.81564467293875, 23.753349678856985, 1.9817252499716622, 0.5710758620074817, 2.8773465284279416, 14.832779850278582, 4.52394300699234, 1.816481779728617, 12.1798403773989, 24.21248664174761, 34.86352791104998, 47.41957589558193, 50.254784856523784, 53.02360030582973, 53.73128475461687, 49.310340540749685, 47.56202786309378, 50.08197968346732, 45.14858497892107, 41.7042795589992, 36.59231615066528, 35.70905072348458, 37.00493492398943, 36.75138473510742, 35.0835599899292, 39.306612559727256, 40.54374279294695, 39.966489928109304, 40.51510579245431, 38.905604226248606, 42.43740136282784, 45.10062156404768, 49.676767689841135, 47.90424401419503, 47.41281877245222, 43.136247703007285, 48.80747161592756, 50.18041133880615, 48.7045236315046, 48.6676356451852, 44.84185675212315, 38.612751552036826, 36.40957505362374, 35.76273945399693, 34.57683481488909, 35.930441175188335, 37.53098998750959, 35.77920321055821, 35.1734036718096, 37.649981362479075, 41.29476663044521, 41.94059474127633, 43.41841057368687, 44.01457296098982, 41.82758576529366, 46.2889198575701, 46.207528659275596, 50.67369522367205, 43.86181681496756, 40.89730882644653, 49.29782336098807, 48.7831529208592, 47.05886016573225, 48.292293957301546, 46.06082786832537, 45.344958441598074, 42.155373982020784, 35.07276248931885, 34.2195063318525, 36.55964919498989, 35.0235345023019, 34.717514991760254, 35.66996015821184, 35.81904765537807, 34.94415133340018, 37.2183974811009, 35.17776019232613, 38.50114958626883, 41.130657127925325, 47.176910059792654, 47.58507851191929, 49.97233016150338, 46.609690393720356, 49.04315798623221, 49.28837728500366, 46.12445599692208, 38.546135698046, 35.03695147378104, 32.63763427734375, 36.20688567842756, 34.075431959969656, 35.102146421160015, 36.41358069011143, 39.31121226719448, 42.81765195301601, 46.67334631511143, 47.104561941964285, 49.839077608925955, 50.36769655772618, 46.52848332268851, 44.159053802490234, 47.35811560494559, 48.917468547821045, 50.53626332964216, 49.41986152103969, 48.058928285326274, 42.583313533238, 26.34488010406494, 11.018502831459045, 2.0356426196438924, 5.444827284131732, 20.467572620936803, 14.117470622062683, 10.535808869770594, 19.386514561516897, 11.03809414591108, 1.2461166424410683, 0.46316072983401163, 5.53902097259249, 29.46112632751465, 41.249467849731445, 32.52822099413191, 44.38504048756191, 51.55697454724993, 18.167138712746755, 0.7165183776191303, 0.09449246778552021, 0.11885835496442658, 0.06510559788772038, 0.13043247961572238, 0.16317446769348212, 0.1694237616445337, 0.1275815333106688, 0.1196078240339245, 0.13428225660962717, 0.21499937107520445, 0.09678426052310637, 0.10833291975515229, 0.08754753973335028, 0.15274786789502415, 0.2201474705444915, 0.11754857881792954, 0.05983640027365514, 0.11360111992274012, 0.10803099202790431], [0.01678188261575997, 0.08755985514393874, 0.05481650660346661, 0.03372296651027032, 0.028183067350515296, 0.04052551755947726, 0.028842681420168707, 0.030183666784848486, 0.022228474728763103, 0.020968613314575384, 0.01119053693089102, 0.04741350295288222, 0.044184280160282335, 0.038174841552972794, 0.09553834130721432, 0.008533263179872717, 0.06255699321627617, 0.07539485541305371, 0.015459445005814944, 0.023834650238443698, 0.03609080945274659, 0.014960107692916478, 0.04859053050833089, 0.023286575451493263, 0.1703049343611513, 8.912485599517822, 43.591556208474294, 39.96852227619716, 46.0236028943743, 58.51313577379499, 40.470984731401714, 32.9676320212228, 20.70725073133196, 1.609372807400567, 0.03398606167840106, 0.459410656775747, 4.288557580539158, 8.659569433757238, 1.6915076800755091, 2.8971321753093173, 12.573781524385724, 30.38884632928031, 44.83917127336775, 50.82876164572579, 51.963374682835166, 52.267295837402344, 47.086743286677766, 43.79536771774292, 40.05724729810442, 38.80331284659249, 35.733734198978965, 34.863434110369, 34.88982336861746, 35.95763989857265, 35.2860061781747, 35.935732228415354, 39.63512338910784, 40.042211396353586, 38.17459120069231, 38.940744740622385, 39.86204808098929, 40.72818619864327, 43.319544655936106, 45.58249650682722, 47.121970653533936, 44.868676798684255, 44.44421829496111, 45.783716338021414, 46.512016092027935, 46.51925958905901, 44.7876330103193, 42.62767430714199, 38.88401617322649, 36.436488900865825, 34.186599663325715, 34.33385631016323, 31.52246229989188, 31.57820769718715, 31.25985860824585, 31.01423978805542, 33.261224678584504, 34.046704632895334, 36.359912804194856, 36.054841722760884, 36.64673444202968, 35.0886356489999, 41.56121962411063, 41.38021905081612, 45.609580584934776, 39.58581549780709, 37.923434666224885, 44.07655436652047, 44.04515545708792, 45.176867621285574, 43.618070534297395, 45.909617696489605, 42.14541026524135, 44.622825213841026, 39.56074639729091, 32.9920688356672, 32.51704134259905, 32.26154913221087, 32.02311822346279, 32.83101306642805, 32.69826078414917, 32.890444483075825, 32.00323247909546, 32.89144502367292, 32.58572775976998, 33.4532277243478, 37.11913551603045, 43.59853914805821, 44.41988570349557, 43.87705421447754, 44.90034668786185, 44.65621478216988, 43.994735854012625, 33.958928040095735, 30.781607151031494, 31.50902795791626, 31.89115456172398, 33.28461231504168, 30.98153461728777, 32.780131408146445, 32.107055936540874, 34.3943646975926, 37.025706563677105, 41.33755711146763, 40.91961254392351, 43.4932530948094, 45.62849358149937, 47.46300561087472, 43.962211336408345, 47.316909313201904, 46.04815782819475, 50.03184495653425, 44.31849064145769, 35.14548928397042, 16.269571781158447, 4.766165895121438, 1.7102699875831604, 19.799633605139597, 19.04749458176749, 3.277628992285047, 5.131744929722377, 5.671831446034568, 2.551493819270815, 0.08574847198490586, 0.10612698205347572, 4.486902160303933, 19.71532937458583, 35.271592140197754, 35.47210325513567, 36.629610606602256, 36.14250019618443, 5.5591277565274915, 0.23819996256913456, 0.040346682869962285, 0.03649852078940187, 0.05582454840519598, 0.019182005165410892, 0.014517584117129445, 0.058779514128608365, 0.048015838488936424, 0.002443406298490507, 0.03203994182071515, 0.03133487269016249, 0.021561501946832453, 0.04057922021352819, 0.09228682185390166, 0.013173501240089536, 0.045349219614373784, 0.029086974382932698, 0.06465513884489026, 0.03199949774092861, 0.019502723223662803, 0.027253891674003432, 0.06885361498487846, 0.014852502216984118, 0.050880660835121355, 0.04408671021727579, 0.04021236007767064, 0.034046118812901635, 0.047213006032896895, 0.03133330527426941, 0.013707561734398561, 0.007038158339647842, 0.01608252166105168, 0.03028206793325288, 0.0074884575026642, 0.02703132200986147, 0.01497344599504556, 0.06963086327803986, 0.02219448351700391, 0.04241029106612716, 0.04711374653769391, 0.0459294620502208, 0.02729677508718201, 0.042196450755000114, 0.0862377228747521, 0.3882928857845919, 12.727046625954763, 49.28946120398385, 44.71397863115583, 50.07068191255842, 62.979403087071006, 48.84199374062674, 38.17099550792149, 25.063736506870814, 2.0120439316545213, 0.014448946907318063, 0.6637119597622326, 10.880280579839434, 8.528401340757098, 2.350231430360249, 4.7144786800656995, 14.779377732958112, 32.81178740092686, 45.79687622615269, 50.67637722832816, 51.9941725730896, 53.184437206813264, 49.29101760046822, 47.36006457465035, 41.45742743355887, 40.642556599208284, 38.26978152138846, 36.70445660182408, 35.93324824741909, 37.47383063180106, 35.95156022480556, 37.60300806590489, 41.06378419058663, 41.63002068655831, 39.720339570726665, 40.70185947418213, 40.181950092315674, 42.040047781808035, 44.783825397491455, 47.728329522269114, 47.685000555855886, 46.88009343828474, 45.195030212402344, 45.79675463267735, 47.156371184757774, 48.206011227199006, 47.05949592590332, 44.263457434517996, 39.86877046312605, 37.61886732918875, 35.67019292286464, 35.73810461589268, 33.748279503413606, 33.39623512540545, 33.601179191044395, 34.22747244153704, 33.79899787902832, 37.4223062651498, 37.35193838391985, 38.169928959437776, 39.367180006844656, 36.80639362335205, 42.702120780944824, 42.68623719896589, 48.33087035587856, 41.799254485539024, 39.26107406616211, 45.01942491531372, 46.59529372623989, 47.41564668927874, 46.17825589861189, 47.78829595020839, 44.07658563341413, 46.24149145398821, 39.69405453545706, 34.70709964207241, 32.5586645262582, 33.69112362180437, 33.26966673987252, 33.992425305502756, 33.8204573903765, 34.086785316467285, 34.02322666985648, 34.15381806237357, 33.96975680759975, 33.43245261056082, 39.44179323741368, 45.207936491285054, 47.35683366230556, 44.992313044411794, 44.95943764277867, 46.19709593909127, 45.67269107273647, 36.87135928017752, 33.478897844042095, 33.27329369953701, 33.09365497316633, 34.50731461388724, 33.30499832970755, 34.47227832249233, 33.43098306655884, 37.32020943505423, 40.096636635916575, 43.77806322915213, 44.65714584078108, 46.35115834644863, 46.421668665749685, 47.92527968542916, 45.57619449070522, 46.934397084372385, 46.75205203465053, 49.06351968220302, 46.59944527489798, 37.43981572559902, 19.10296552521842, 6.4726026483944485, 4.022426809583392, 18.65726637840271, 24.14184604372297, 8.640558293887548, 9.343237434114728, 4.327198249953134, 2.1631739820752824, 0.053497051154928546, 0.20961210158254417, 5.39308100938797, 24.01590994426182, 38.30990389415196, 35.206216539655415, 41.295867919921875, 42.651107106889995, 8.22585940361023, 0.12635761898543152, 0.05216846601771457, 0.012094339638549303, 0.03848191936101232, 0.07824686023273639, 0.03500126202457717, 0.020448670589498112, 0.012838155663173114, 0.020590036575283324, 0.027512235400666083, 0.08932906056621245, 0.016852697922981212, 0.013682974169829061, 0.04165640812633293, 0.04088603678558554, 0.05700530790324722, 0.019386571599170566, 0.038005038164556026, 0.05157644082126873, 0.04078622428434236, 0.06554505109254803, 0.12193852396947996, 0.19701414901231015, 0.1387847707207714, 0.10680444498679467, 0.12126682858381953, 0.1343182868191174, 0.1846784773681845, 0.10611515518810068, 0.11927737747984272, 0.07165736239403486, 0.13302896171808243, 0.22569141377295765, 0.10646401039723839, 0.15913821570575237, 0.08855145943484136, 0.20209314647529805, 0.14866099719490322, 0.08452865601118122, 0.10850731682564531, 0.08485025446861982, 0.12782719012882027, 0.11044209157781941, 0.16398267075419426, 0.4480044016880648, 15.480254684175764, 57.36071450369698, 51.65252617427281, 56.68423441478184, 63.45074803488595, 47.39275584902082, 42.61380917685372, 27.232927628925868, 2.794647114617484, 0.1582118525568928, 1.1022501736879349, 6.31626079763685, 12.687815359660558, 5.047003831182208, 4.577111491135188, 15.444419349942889, 33.99418319974627, 47.087601389203755, 51.58369731903076, 55.19171966825213, 56.41112504686628, 52.20856966291155, 49.79413666043963, 43.23394284929548, 42.81775617599487, 39.704560211726594, 39.08205025536673, 37.95659841809954, 38.93513407026018, 38.772574016026084, 38.724134649549214, 42.53145565305437, 44.209365708487375, 41.053035327366416, 43.439699854169575, 42.481807300022666, 45.343388148716514, 45.367453234536306, 49.88653380530221, 50.25488560540335, 48.807937145233154, 46.42645250047956, 46.7330904006958, 48.32756996154785, 50.90125567572457, 47.109724453517366, 45.648007597242085, 42.386759417397634, 40.39672933306013, 37.59101547513689, 38.06559133529663, 35.605390548706055, 34.18665524891445, 35.45742865971157, 36.03908320835659, 36.458872522626606, 37.88431978225708, 39.36070428575788, 40.528043338230674, 41.04331827163696, 38.143181868961875, 44.66487223761422, 44.28552491324288, 49.066333702632356, 44.42723689760481, 42.402538776397705, 43.43634387425014, 48.027070794786724, 48.692086356026785, 48.45906114578247, 49.428265367235454, 46.00127138410296, 46.93190615517752, 41.772646359034944, 36.06878675733294, 34.79527923039028, 34.81252465929304, 34.37181779316494, 34.37013980320522, 36.11857754843575, 36.806508268628804, 36.22111211504255, 35.53181259972708, 35.47855813162667, 35.97729982648577, 40.75203589030674, 46.45798689978463, 48.20697702680315, 46.53134250640869, 45.31295156478882, 48.25613553183419, 47.75466319492885, 37.84322466169085, 34.75204406465803, 34.843037673405235, 34.74650635038103, 36.7980557850429, 34.102588994162424, 36.277607917785645, 35.272005558013916, 38.277177878788535, 40.707702909197124, 44.973834310259136, 44.87308890478951, 46.60231835501534, 49.00672163282122, 47.9597601209368, 44.419500078473774, 49.84584515435355, 46.965299197605674, 51.03974717003958, 48.60799925667899, 41.42211668831961, 20.24689088548933, 6.155429107802255, 3.634673684835434, 27.33004433768136, 23.226373979023524, 4.417982544217791, 16.219282456806727, 14.42411025932857, 4.6957055159977505, 0.35142552692975315, 0.5433900047625814, 6.257931104728153, 27.50549156325204, 44.1777548789978, 43.206969942365376, 48.61997447695051, 46.96527140481131, 10.752517972673688, 0.4325881132057735, 0.12124808744660445, 0.10975123436323234, 0.1619729178824595, 0.18933040489043507, 0.1202359167592866, 0.20639431210500853, 0.07717654587967054, 0.10253522478576217, 0.15024343585329397, 0.16381419050906385, 0.11745240326438632, 0.14194606537265436, 0.11975134776106902, 0.13433928069259438, 0.1836495061538049, 0.0719605182696666, 0.1203337615089757, 0.10833780520728656, 0.09013889211096934], [0.04754688597417303, 0.012129368160718253, 0.04595515477870192, 0.0131428323054154, 0.02668803248421422, 0.05116298907835569, 0.05373365292325616, 0.018986130765240108, 0.04021345930440085, 0.023098848560558896, 0.03423972520977259, 0.044171354068177085, 0.03991304810291954, 0.08065183939678328, 0.02473663192774568, 0.03911238356626459, 0.04899958873699818, 0.04382894154904144, 0.050269467024398704, 0.02567615356695439, 0.017481233392442976, 0.042854507586785724, 0.06604156230709382, 0.056678142065980604, 0.1434865298547915, 5.197965604918344, 35.16308559690203, 45.53671135221209, 44.21040793827602, 46.859919343675884, 26.660835538591655, 27.858354091644287, 21.27556994983128, 3.987248948642186, 0.03881029638328722, 1.4097358626978738, 2.048158496618271, 2.6319155267306735, 4.296438574790955, 1.7149980195931025, 5.799291372299194, 18.321723972048076, 36.783603531973704, 47.772638184683665, 53.24460860661098, 47.71195609228951, 47.555246421269004, 42.956890378679546, 42.185518741607666, 39.389664377485005, 37.25008126667568, 36.279813970838276, 35.729009423937114, 34.435633523123606, 37.879324027470176, 41.606160572596956, 42.89994989122663, 41.13649361474173, 39.4586113521031, 36.94136585508074, 40.10785102844238, 41.88918849400112, 46.2758537701198, 47.77727958134243, 47.80853605270386, 46.78681039810181, 46.51224538258144, 45.42647123336792, 47.86694261005947, 45.714713777814595, 48.07657323564802, 42.080111094883506, 39.696312699999126, 36.074873379298616, 34.561406339917866, 33.284549781254356, 33.928178787231445, 32.989668233054026, 32.850037234170095, 32.11658886500767, 31.98689726420811, 33.083566188812256, 34.55248485292707, 33.870150906699045, 35.394665581839426, 36.32011352266584, 41.94750819887434, 42.74247244426182, 48.32601356506348, 39.67473159517561, 36.10749169758388, 43.70882790429251, 38.86504759107317, 45.950007574898855, 45.05201891490391, 47.16914544786726, 45.66560738427298, 44.41649150848389, 42.32635177884783, 34.35514906474522, 32.24965729032244, 31.982047421591624, 32.52925974982125, 32.1915807723999, 32.162221159253804, 33.06716496603829, 34.44026102338518, 36.988061223711284, 38.88190392085484, 39.58563484464373, 40.23645871026175, 44.58883810043335, 44.96046945026943, 45.47294078554426, 43.971970081329346, 42.75530229296003, 45.159083706992014, 35.690738746098106, 32.18645647593907, 33.51851647240775, 32.984547410692485, 33.48000955581665, 34.43107550484793, 34.30817229407174, 33.244333607809885, 34.07348299026489, 33.219636235918315, 35.991873673030305, 40.16550718035017, 42.15391486031668, 45.507546288626536, 46.19733565194266, 44.17867204121181, 47.78240735190255, 43.14184100287301, 42.909771169934956, 46.74041032791138, 29.582160472869873, 12.137888022831508, 2.7629737513405934, 1.773523239152772, 6.325070244925363, 11.788833107267108, 5.084964879921504, 6.380296264375959, 5.278278095381601, 1.376334352152688, 0.1507327003138406, 0.534144829426493, 8.024736847196307, 25.617964778627666, 36.58972447259085, 48.1049462045942, 38.29414537974766, 27.684822831835064, 2.703721250806536, 0.08000518195331097, 0.05336337297090462, 0.0623422572389245, 0.014942835584016783, 0.04904669603066785, 0.03025059069373778, 0.01664558019755142, 0.12034816002207142, 0.015655719741646732, 0.023283184472737566, 0.06795296152787549, 0.055749030850295506, 0.029144378445510353, 0.05648861027189663, 0.046976991197360415, 0.01124468317721039, 0.011466090850132917, 0.0213356651365757, 0.024830278242006898, 0.03480415777968509, 0.017810733390173743, 0.005216384264973125, 0.038185864354350736, 0.036375580422048054, 0.08092272414692811, 0.027602804558617727, 0.04628932649003608, 0.0492822732111173, 0.04193264651777489, 0.01753387922820236, 0.025021391022684317, 0.027622320922091603, 0.0372072743651058, 0.03701312514021993, 0.054555708276374, 0.015726524870842695, 0.06615438910999469, 0.035309849573033195, 0.003608709616985704, 0.045476902941507955, 0.01159242813342384, 0.022323386510834098, 0.05446828582457133, 0.052828646664108546, 0.08586064060883862, 7.342074598584857, 43.06123495101929, 48.769530977521626, 47.048076561519075, 53.162032740456716, 33.23702757699149, 35.08865301949637, 23.867091689790996, 4.350767408098493, 0.010438432601014418, 0.7668370689664568, 2.66408177784511, 6.958714255264827, 4.85532865353993, 2.6467190980911255, 8.152014817510333, 20.582798072269984, 39.991823060171946, 50.14948490687779, 55.2131791796003, 48.78796454838344, 49.631653036390034, 44.599972588675364, 43.46783658436367, 39.9752585547311, 38.488034861428396, 37.078530243464876, 36.80434390476772, 35.99137340273176, 39.880266257694785, 43.8788537979126, 44.06794902256557, 42.79472984586443, 41.326464312417166, 38.70234162466866, 42.51427970613752, 44.22027785437447, 47.49845879418509, 47.493893827710835, 48.5821658543178, 47.942778723580496, 48.959633690970286, 47.30111953190395, 48.97642053876604, 48.06278453554426, 49.13025712966919, 44.32092251096453, 41.7058915410723, 37.67154162270682, 36.31069523947579, 34.61511244092669, 33.595245429447715, 33.695525305611746, 34.48755046299526, 33.234477588108604, 33.13597297668457, 34.96674687521798, 36.11495406287057, 34.644114221845356, 37.6923862184797, 37.96141004562378, 43.8139819417681, 45.6476845060076, 49.40277937480381, 42.89883470535278, 37.69127798080444, 43.630994183676584, 40.02766534260341, 46.31585802350725, 48.4636469568525, 49.43281643731253, 46.37222875867571, 44.44880410603115, 45.38066176005772, 35.40235376358032, 33.91297960281372, 33.03460223334176, 34.60075051443917, 33.69030720846993, 34.0804694039481, 35.04864181791033, 35.658735343388145, 38.20756735120501, 40.1350428036281, 38.96577215194702, 41.14554016930716, 46.36983857836042, 46.58621590478079, 45.42222588402884, 45.264592102595735, 45.277696405138286, 46.81745890208653, 36.645876339503694, 33.53524773461478, 34.26099402563912, 35.44228506088257, 34.66064051219395, 34.471451486860005, 35.811647823878694, 35.038879598890034, 33.99849108287266, 36.011384214673726, 38.17168337958199, 41.75821495056152, 44.1038156236921, 47.691920961652485, 47.70248917170933, 45.733800479343955, 49.668766839163645, 45.23666729245867, 45.682213578905376, 46.965618814740864, 33.04215839930943, 14.945008890969412, 3.6865986585617065, 2.313119364636285, 11.952656865119934, 15.529180424554006, 7.200838131564004, 2.7384874309812273, 3.820885189941951, 0.5619586855173111, 0.03538608976772853, 0.6399869014109884, 7.929656829152789, 28.177311147962296, 41.91459458214896, 51.40131058011736, 43.15567486626761, 32.65384789875576, 4.6106930034501215, 0.11259335971304349, 0.007672685697408659, 0.04287218003134642, 0.033152864780277014, 0.051124176875288994, 0.017406044927026545, 0.028777077261890684, 0.12483114589537893, 0.023779219016432762, 0.02853246878034302, 0.03416029929316469, 0.05193903975720916, 0.024113746958651712, 0.018725296815059016, 0.06936328299343586, 0.022345069097355008, 0.039054083837462325, 0.044362232754273076, 0.03942470305732318, 0.02597331119302128, 0.185959307210786, 0.16637842862733773, 0.10713155993393489, 0.10894772676484925, 0.19096099239374908, 0.1676266345062426, 0.12318120657333306, 0.0982104597081031, 0.15784567434872898, 0.0895285362909947, 0.10905171904180731, 0.10498578114701168, 0.12194669353110449, 0.16606315411627293, 0.09723431923027549, 0.12089770553367478, 0.11411364456372601, 0.1514074219656842, 0.08026987167873553, 0.2256712612829038, 0.11715297933135714, 0.12243563229484217, 0.21129078364798, 0.11321292325322117, 0.31235235929489136, 9.630963206291199, 49.28922496523176, 54.93014778409685, 54.48199244907924, 55.130620683942524, 37.28077145985195, 38.20887361254011, 29.767166682652064, 6.190579175949097, 0.3587228724999087, 2.3553932905197144, 5.857789124761309, 5.776331918580191, 7.139366550104959, 2.5377196669578552, 7.221310564449855, 22.83027802194868, 41.12782573699951, 51.541254247937886, 55.97963844026838, 52.97079052243914, 51.07353973388672, 47.93735565458025, 45.659128189086914, 42.84354788916451, 40.26324054173061, 39.68706464767456, 39.85982813153948, 37.193436077662874, 40.59057017735073, 46.58651467732021, 46.65932832445417, 44.86362198420933, 44.2133400780814, 41.31289448056902, 43.790559564317974, 46.6112676348005, 51.14069754736764, 49.884046350206646, 51.48908369881766, 50.25930118560791, 51.1733158656529, 47.931432315281455, 50.83858987263271, 48.85339226041521, 50.03380782263619, 44.75453874043056, 44.167176246643066, 40.18772404534476, 38.77388375146048, 37.443706716809956, 36.522670882088796, 35.49176318304879, 36.435700280325754, 34.77119329997471, 34.37623337336949, 36.89409031186785, 37.637530190604075, 35.478040490831646, 38.58864477702549, 39.50730432782854, 45.12287664413452, 46.492071287972585, 51.85547610691616, 44.20987640108381, 39.047545501164024, 43.629184177943635, 40.14791086741856, 47.02048179081508, 48.46527978352138, 50.9171462059021, 48.26914603369576, 46.88278933933803, 46.41592250551496, 36.802255971091135, 35.07923126220703, 33.30132620675223, 36.55442762374878, 35.01362984521048, 35.358201435634065, 36.33341932296753, 37.546564374651226, 40.805599553244456, 42.728728907448904, 41.61217423847744, 43.16549267087664, 48.603211947849815, 49.073563303266255, 45.98856660297939, 45.833427224840435, 46.48110008239746, 48.84409557070051, 40.30351230076381, 34.459573541368755, 37.248344217027935, 36.436342988695415, 37.0017283303397, 37.80477680478777, 37.836054120744976, 36.57543550218855, 37.311253207070486, 36.94675765718733, 38.87504604884556, 43.79458951950073, 45.81640413829258, 48.53298997879028, 49.59788131713867, 45.65258298601423, 51.140569005693706, 45.669564383370535, 45.84837974820818, 49.675857475825715, 33.45709787096296, 15.188989673342023, 5.580560777868543, 3.5197515657969882, 12.802168812070574, 20.132198708398, 12.414526207106453, 14.661918435777936, 9.761069961956569, 4.108518464224679, 0.7393648688282285, 0.8426902272871563, 11.153099860463824, 33.77676016943795, 46.810906750815256, 54.80953400475638, 51.49385016305106, 37.82071944645473, 5.8792772974286756, 0.23117747796433313, 0.12654256049011434, 0.13719917008919374, 0.07856855368507759, 0.23031286150217056, 0.13954254505889757, 0.1316845260028328, 0.18799089533942087, 0.055317801489893875, 0.1373016967305115, 0.18082073437316076, 0.2315553676869188, 0.14758271005536827, 0.137601568496653, 0.12686130910047463, 0.13047255389392376, 0.12147169187664986, 0.0783203523606062, 0.12649099182869705, 0.07783001581473009], [0.05620724554838879, 0.026207500769357597, 0.01578856332759772, 0.024253650701471736, 0.01541845640167594, 0.04123837287936892, 0.03569712343492678, 0.015657685796863267, 0.07572473878307001, 0.06944255623966455, 0.013305346531394337, 0.0015658493253535458, 0.017011583682947924, 0.030921030789613724, 0.024041912152564952, 0.011211380678495126, 0.020640862240855182, 0.004125747364014387, 0.016675405204296112, 0.02885265927761793, 0.029147465779845203, 0.016150700859725475, 0.04131088452413678, 0.023674387052389126, 0.04248541846339192, 3.2460125173841203, 22.630937678473337, 41.4021440914699, 45.449414185115266, 40.002564975193565, 20.901645694460186, 28.124850511550903, 28.274490390505107, 5.912055424281529, 0.10613877499209982, 0.46735255633081707, 3.748916183199201, 4.248319259711674, 1.7542620726994105, 2.868491700717381, 3.3822050264903476, 12.330497298921857, 28.880472319466726, 46.717324938092915, 53.007171290261404, 50.87738513946533, 46.00352260044643, 44.15161575589861, 43.03794111524309, 38.67317656108311, 37.77846050262451, 36.28945459638323, 36.21283681052071, 41.507391929626465, 42.14041451045445, 44.33669492176601, 46.470073291233604, 44.73516716275896, 39.63247612544468, 34.700974805014475, 36.9626099722726, 39.944325174604145, 45.566995075770784, 46.558398791721885, 45.12982136862618, 45.32227952139718, 44.595574378967285, 43.998946462358745, 45.92450768607003, 45.26460599899292, 44.87924500874111, 41.322135584695, 39.24628482546125, 36.333405426570344, 35.440026896340505, 33.26274285997663, 33.32449150085449, 32.91195958001273, 34.654289858681814, 32.75458288192749, 31.37525429044451, 32.10148000717163, 33.528567041669575, 33.37710673468453, 36.246222904750276, 38.27142824445452, 44.481745515550884, 43.342953136989046, 48.05238308225359, 38.62511934552874, 34.683343751089915, 43.9677768434797, 43.60856192452567, 48.17402172088623, 46.66701650619507, 44.10934291567121, 42.891528674534385, 47.18346568516323, 40.35330309186663, 34.50002595356533, 31.07139219556536, 35.03888307298933, 32.26755237579346, 33.2736827986581, 35.82034696851458, 38.07343585150582, 39.52858318601336, 44.51014627729143, 43.58522987365723, 45.81653962816511, 44.593559401375906, 44.61540453774588, 46.65671927588326, 45.03334215709141, 40.31344822474888, 46.9011047908238, 42.04972314834595, 35.37175389698574, 31.065586975642614, 33.11556959152222, 32.261503968920024, 37.317433629717144, 39.65100697108677, 39.61380978993007, 35.60772861753191, 34.108720779418945, 32.92288562229702, 33.56662579945156, 35.70646946770804, 40.66104228155953, 43.31002214976719, 44.892026220049175, 42.4506515775408, 40.96385867255074, 48.022297382354736, 42.89433574676514, 36.284323351723806, 24.33775224004473, 12.495926090649196, 2.430751932518823, 6.118190671716418, 23.173802171434673, 28.54371224130903, 9.586056998797826, 4.732013327734811, 2.194317545209612, 0.9448802066700799, 0.05467291841549533, 1.156655220048768, 12.008342334202357, 22.321527447019303, 28.63046223776681, 43.41282422201974, 42.11714846747262, 18.226888009480067, 0.8752727189234325, 0.09806927014142275, 0.01651720985371087, 0.019623870562229837, 0.022370860213413835, 0.0309947909388159, 0.013988631295173295, 0.010406057150768382, 0.040386794467589686, 0.04129131218152387, 0.004062205528108669, 0.03634012696732368, 0.019950308670688952, 0.016367077195484723, 0.03995462872886232, 0.11149562575987407, 0.01786267524585128, 0.0508658314522888, 0.05356860945799521, 0.024992188571819236, 0.06015561028782811, 0.03385588134239827, 0.06150357438517468, 0.012044402005683099, 0.11693016200193337, 0.02027053479105234, 0.08269488798188311, 0.02178493165411055, 0.06843521672167949, 0.05561612619619284, 0.041957016102969646, 0.02706609862590475, 0.033794406069708724, 0.03957478143274784, 0.03392632006268416, 0.055189093574881554, 0.03203764837235212, 0.04180214387763824, 0.03484836433615003, 0.05284019533012595, 0.05673850793391466, 0.030565444513091018, 0.06249631182955844, 0.06960606282310826, 0.05026350609425988, 0.05555373150855303, 4.938334005219596, 28.40438870021275, 47.1079318182809, 50.876450606754844, 47.445492676326204, 27.30350395611354, 30.892281532287598, 31.755365916660853, 6.173442312649318, 0.18932231675301278, 0.09681583275752408, 3.0967222196715216, 4.9352194752011975, 4.3200646213122775, 2.0658800942557196, 4.027307050568717, 14.958556141172137, 29.791891847337993, 46.826390811375205, 52.49094097954886, 51.537172181265696, 47.80580888475691, 47.464402198791504, 44.41304867608206, 40.074767180851524, 37.90599121366228, 37.68387814930507, 38.3252455166408, 42.84339155469622, 44.05276026044573, 45.40860741479056, 47.347873960222515, 46.15492384774344, 41.433852195739746, 36.06795992170061, 38.050399099077495, 43.49530628749302, 47.46159165246146, 48.76336792537144, 47.823109899248394, 46.47218901770455, 45.44824341365269, 46.636065755571636, 46.22287722996303, 47.52087715693882, 46.07024962561471, 42.82922417776925, 40.122146947043284, 37.96396698270525, 36.92105279650007, 34.62161248070853, 35.46417883464268, 33.83767850058419, 35.97557667323521, 34.166526317596436, 33.77791009630476, 34.43017223903111, 34.66258948189871, 36.40918248040335, 37.39445788519723, 39.91661923272269, 45.259318419865195, 45.84074715205601, 49.563001360212056, 40.79556635447911, 36.83843524115426, 43.45081697191511, 43.978133133479524, 50.06747531890869, 47.91731357574463, 44.1076614516122, 44.83261912209647, 48.70479113715035, 41.76911320005144, 35.6207252229963, 32.71346344266619, 36.08360031672886, 33.54024348940168, 34.4603864806039, 35.48638875143868, 38.728789942605154, 40.948246070316856, 46.150334562574116, 45.05008384159633, 46.04401322773525, 46.137376172201975, 47.03967271532331, 46.69572993687221, 45.972627435411724, 42.911122594560894, 47.67421695164272, 43.19974034173148, 36.0694259916033, 31.913902963910783, 35.229263714381624, 34.14091525759016, 38.916571957724436, 41.26152297428676, 40.79501397269112, 37.74597767421177, 35.722158500126426, 34.67884479250227, 35.159875529153005, 37.45716190338135, 43.002338545663015, 44.669020312173025, 46.84683588572911, 43.68735102244786, 44.6727306502206, 47.781205313546316, 42.508971282414024, 41.48402861186436, 27.69860632078988, 14.921452760696411, 4.099661682333265, 6.060705619198935, 8.957819121224539, 22.87593984603882, 2.2558690309524536, 0.6159806038652147, 0.4789544737764767, 0.1790785142885787, 0.06643777247518301, 1.3152743428945541, 14.535018273762294, 28.388915061950684, 33.67399631227766, 48.35107224328177, 45.433634826115195, 23.52606020654951, 1.258469888142177, 0.048319445590355566, 0.06815255938896111, 0.05080147919112018, 0.04551596959520664, 0.04002419892432434, 0.05855854241443532, 0.009875380001696092, 0.07788838339703423, 0.01447210700384208, 0.039618244993367364, 0.04054766154981085, 0.054026400071701834, 0.030928596455071653, 0.0025393560270978405, 0.014269379399982947, 0.0977570286818913, 0.04284105563004102, 0.008987609380190926, 0.023675830635641302, 0.035755409593028684, 0.2881888044731957, 0.10884194994079215, 0.1318481343665293, 0.23352013368691715, 0.09180903820587055, 0.19512689885284218, 0.17904928299997533, 0.1753935127386025, 0.15785754871155533, 0.15611774421163968, 0.13270724112434046, 0.12225009367934295, 0.09780626996819462, 0.12950473225542478, 0.05346692420010056, 0.12333788030913898, 0.1263834304575409, 0.11912079873893942, 0.12988733101103986, 0.10488142924649374, 0.11616651155054569, 0.14562704999532017, 0.1684491682265486, 0.20612369876887116, 0.11761886147516114, 5.752874800137111, 32.409358160836355, 54.43355655670166, 58.505993025643484, 50.042447907584055, 31.12747458049229, 38.75613457815987, 37.90762404033116, 8.020972660609655, 0.35159782054168837, 1.1947817227670123, 11.037121398108345, 8.507160697664533, 4.571628059659686, 5.271461912563868, 5.1510926229613165, 15.954326799937657, 31.41128417423793, 48.830456256866455, 54.71648372922625, 53.5792373248509, 49.09032235826765, 48.73910134179251, 46.7630649294172, 43.53280918938773, 40.56048100335257, 40.27526787349156, 40.851784229278564, 45.48348120280674, 46.46959386553083, 48.0756630216326, 49.499936035701204, 48.257486956460134, 43.842132568359375, 37.24093048913138, 39.84131465639387, 44.60976954868862, 48.51895114353725, 50.91503047943115, 49.469110352652415, 48.94909674780709, 47.25915936061314, 49.277454716818674, 49.65216759272984, 51.035043239593506, 48.429649421146934, 43.47822414125715, 42.34922524860927, 39.61414677756173, 38.047724042619976, 36.26090792247227, 36.41593265533447, 35.401721477508545, 38.41429015568325, 36.14597429547991, 33.40099811553955, 36.21265615735735, 35.97610821042742, 37.4188425881522, 38.902661664145334, 41.89249236243111, 47.775938579014365, 48.67728669302804, 51.665970938546316, 43.28804152352469, 39.78778920854841, 42.76217753546578, 44.641512393951416, 49.393545218876426, 48.155219895499094, 45.238411290305, 46.50022847311837, 50.02158941541399, 43.77735798699515, 37.330906186785015, 33.65333931786673, 37.86845704487392, 35.51910087040493, 35.3288939339774, 39.01704290934971, 41.4856927054269, 42.844357354300364, 48.30843114852905, 47.48353058951241, 48.662511348724365, 48.78823900222778, 48.38769619805472, 47.15494680404663, 46.22200870513916, 45.66419342585972, 50.264647824423655, 44.27126720973423, 36.98964541299002, 34.57976000649588, 36.198526995522634, 36.915059975215364, 41.633317606789724, 43.5836352620806, 43.38622651781355, 39.956783294677734, 36.76724747249058, 35.96190956660679, 36.881086758204866, 39.28796706880842, 44.41183621542794, 48.80750983101981, 48.67806141717093, 46.54860183170864, 43.534205777304514, 52.01723364421299, 44.55702229908535, 44.993977137974326, 30.885718958718435, 17.914142642702373, 4.029635565621512, 11.68317358834403, 32.04482439586094, 36.450138636997764, 18.61695466722761, 8.612377268927437, 7.152617633342743, 2.2147541514464786, 0.1539894784135478, 2.234783636672156, 17.163198709487915, 30.812231336321148, 39.19446863446917, 53.336519377572195, 53.42893736703055, 26.89041096823556, 1.7088329046964645, 0.18284366439495767, 0.1483925823122263, 0.11557648463972978, 0.12044434914631502, 0.1471381610525506, 0.11647664276616913, 0.07225275651684829, 0.07137295444096838, 0.11543859275324003, 0.13073526908244404, 0.09440381718533379, 0.13065106288662978, 0.12924391696495668, 0.12739599469516957, 0.1487621260540826, 0.131173860547798, 0.14408355924699986, 0.12806492165795394, 0.07052634629820075, 0.18116407309259686], [0.026555343264979974, 0.02809139557315835, 0.014244509395211935, 0.025784585159271955, 0.041551883199385235, 0.012638708776129144, 0.06642797442951373, 0.01151440932881087, 0.01137520871790392, 0.023820680898747275, 0.04844184312969446, 0.048391041212848256, 0.014916142016383154, 0.03214848706764834, 0.046572452011917315, 0.031001515220850706, 0.05983485999916281, 0.10352320569966521, 0.04723879036360553, 0.040090705534177165, 0.03159056164856468, 0.017151187174022198, 0.07120684228305306, 0.023857971487034644, 0.07384463359734841, 1.177711844444275, 13.47899283681597, 33.0628536088126, 41.146144662584575, 34.88444198880877, 28.849514620644705, 32.45801986966814, 27.312656470707484, 9.503912789481026, 0.5430986689669746, 0.17499602692467825, 0.6160222930567605, 6.0021092891693115, 3.6095985046454837, 0.2351945409817355, 5.954031663281577, 17.61597807066781, 18.062788929258073, 37.47649526596069, 48.77333164215088, 51.00790357589722, 46.33455562591553, 46.879336084638325, 44.17050790786743, 42.246058395930696, 40.76137774331229, 41.0316036088126, 44.26550367900303, 44.62809542247227, 45.73521096365792, 46.30806214468819, 45.19360930579049, 44.98373201915196, 41.8785195350647, 34.3744581086295, 35.72502810614449, 39.26694876807076, 39.5054144178118, 40.09401716504778, 39.471444674900596, 38.020087582724436, 37.588222299303325, 39.154763153621126, 39.651892866407124, 40.959318024771555, 37.97866242272513, 36.89395482199532, 35.72505242483956, 34.813077041081016, 35.56412172317505, 33.56431204932076, 35.11266251972744, 33.90044157845633, 31.724581922803605, 31.331233978271484, 33.34049320220947, 33.52397428240095, 33.27408579417637, 34.832045623234336, 38.934876986912315, 41.621210370744976, 43.12822253363473, 46.16627025604248, 47.52490711212158, 39.155878339494976, 35.02367346627371, 46.50946262904576, 45.213529791150776, 44.97671086447579, 45.370975971221924, 45.05963066646031, 44.23684235981533, 42.382448060171946, 37.737747532980784, 34.416449546813965, 32.331006799425396, 32.34141867501395, 32.535568714141846, 35.83703306743077, 40.43742840630667, 46.159798009055, 46.89320816312517, 46.021448952811106, 44.84098475319998, 46.05229895455496, 44.58264378138951, 46.27871642793928, 43.639644690922324, 45.154563903808594, 45.49764163153512, 44.357904297964915, 39.37242589678083, 32.43666805539812, 32.78717688151768, 30.41934197289603, 34.395688329424175, 41.68866000856672, 44.16058588027954, 43.71325738089425, 40.47692196709769, 37.726897920881, 36.034476552690776, 35.76344122205462, 37.356864656720845, 39.14770030975342, 41.13161250523159, 42.329992634909495, 46.50023889541626, 44.02180256162371, 45.57910926001412, 43.89820800508772, 27.19057141031538, 16.663376569747925, 2.592413063560213, 3.977501928806305, 21.850941589900426, 30.545187745775493, 13.617662378719874, 1.205204346350261, 0.3051381749766213, 0.746626116335392, 0.18303203928683484, 0.07626442518085241, 4.487378111907414, 16.59154782976423, 25.01949906349182, 32.20964956283569, 41.25424821036202, 36.57121099744524, 10.840074828692845, 0.33540376807962147, 0.1001102016972644, 0.0338135950400361, 0.10330610842044864, 0.04586129642224737, 0.029895496355103593, 0.018888947587194185, 0.031050508841872215, 0.03988369807068791, 0.06492030354482786, 0.031952085106500556, 0.023212314882714833, 0.019865026996870126, 0.031215050191219364, 0.06366371775844268, 0.06463291003767933, 0.024203751236200333, 0.019653095065483024, 0.07748745741056544, 0.016613278537988663, 0.042749131098389626, 0.015353054107565964, 0.015635952320215956, 0.043600529698388915, 0.05923359654843807, 0.06023017450102738, 0.018832866667902896, 0.06026587222835847, 0.12184822452919823, 0.02400088792533747, 0.021411472765196646, 0.05473931985242026, 0.0244507905694523, 0.018935038774673427, 0.006751860242470035, 0.003913815008542899, 0.036580677809459825, 0.09495380374469928, 0.021390662096174698, 0.03194681967475584, 0.060642377739506106, 0.022683267914024845, 0.04360241263306566, 0.04854922129639557, 0.017512766611097113, 0.09180249712829079, 1.226693930370467, 17.886341163090297, 39.4575309072222, 48.439571448734824, 40.92428173337664, 27.766361679349625, 36.96075132914952, 30.99228695460728, 10.176407217979431, 0.5398496804492814, 0.26710856705904007, 1.1458267782415663, 5.555294522217341, 4.411648826939719, 2.6588647663593292, 7.168787394251142, 18.663794210978917, 20.978035926818848, 40.66631596429007, 51.25979661941528, 51.65236636570522, 48.53018638065883, 48.618022033146445, 46.61589860916138, 43.51821449824742, 43.573716708592, 42.039009026118684, 46.03595331736973, 46.36704192842756, 47.0412951196943, 48.6391202381679, 47.66788714272635, 47.48056370871407, 42.84150859287807, 35.483623368399485, 36.70531817844936, 41.406281743730815, 42.9099622453962, 43.28727722167969, 41.3161427634103, 39.64384685243879, 41.34461995533535, 41.93780156544277, 42.440680912562776, 42.7730827331543, 39.83600970676967, 39.94573218481881, 37.200537136622835, 37.8346505846296, 37.38061359950474, 35.96806219645909, 36.36261565344674, 36.73775931767055, 32.914301122937886, 33.597340311322895, 34.37167535509382, 35.18279068810599, 35.97626107079642, 37.30218928200858, 39.56694419043404, 44.40938350132534, 45.277772835322786, 47.74671792984009, 48.311047145298545, 40.572199140276226, 36.935873304094585, 46.547132287706646, 47.9235600062779, 46.236909117017476, 46.24858556474958, 46.540837219783235, 45.47061661311558, 44.18773944037301, 38.99094200134277, 36.224544525146484, 33.96497644696917, 33.52871642793928, 32.84423548834664, 36.16184745516096, 41.32778099605015, 46.80310044969831, 47.61904130663191, 48.24255180358887, 47.40635347366333, 47.29979937417166, 45.99422243663243, 46.81591987609863, 45.98115634918213, 45.951181820460725, 47.423421723502024, 46.43328257969448, 40.180133138384136, 34.46944693156651, 34.35828965050833, 32.96278912680489, 35.85649149758475, 41.82483775275094, 46.35625832421439, 45.07009465353829, 43.209523405347554, 39.66063370023455, 37.09755441120693, 37.56862837927682, 39.05008854184832, 41.54628447123936, 44.22313008989607, 44.42517328262329, 47.59510823658535, 45.01425892966134, 48.027595383780344, 44.945760113852366, 31.480331897735596, 19.946740865707397, 4.895946519715445, 5.131001906735556, 17.149788686207362, 27.319052287510463, 20.014079332351685, 2.7973150057452063, 0.6675029620528221, 0.5940743450607572, 0.17591294486607822, 0.13696063788873808, 5.1909322908946445, 19.46004213605608, 26.572833129337855, 35.79802935464041, 46.11531564167568, 43.43988050733294, 13.07948010308402, 0.4915053088750158, 0.026524629377360855, 0.013515566858196897, 0.07695258861141545, 0.041024267939584594, 0.02768453749428902, 0.027147746744698713, 0.06691313375319753, 0.16832454848502362, 0.0376108059260462, 0.014388606484447206, 0.01369581205238189, 0.02772451168857515, 0.023510410583445003, 0.04548407844933016, 0.03181027128760304, 0.027643533623112098, 0.04826746302257691, 0.05749199393072298, 0.024905493848824074, 0.01981627255944269, 0.06393107412649052, 0.0900896101125649, 0.09343441456024136, 0.13765613628285273, 0.12372126616537571, 0.10031144161309515, 0.15716513086642536, 0.22104327247611114, 0.07854194832699639, 0.1335278478051935, 0.0993585070329053, 0.12934883204954012, 0.08265592650111232, 0.1217166565890823, 0.09078816191426345, 0.181694253214768, 0.28489367557423456, 0.19365723271455082, 0.09811600084815707, 0.11718466691672802, 0.19020074818815502, 0.10292130442602293, 0.19091629050672054, 0.13055676008973802, 0.15740325594586985, 1.7489547346319472, 19.991629702704294, 44.32965292249407, 53.545719214848106, 46.65551028932844, 38.057524476732524, 43.449208463941304, 37.248646463666645, 12.950888923236302, 1.2176176288298197, 0.5561625308224133, 2.117511506591524, 14.449032579149518, 6.746096338544573, 2.1415036363261084, 10.56813188961574, 27.056875910077775, 27.84500139100211, 45.39187615258353, 53.761908939906526, 55.15939664840698, 50.168974603925435, 50.59292936325073, 49.231311729976106, 46.692196777888704, 46.11010101863316, 43.7388927595956, 48.260884625571116, 49.62420456750052, 49.771120752607075, 49.99280997685024, 48.894480432782856, 48.66502659661429, 45.59446477890015, 37.79581362860543, 38.21991777420044, 42.96104540143694, 44.0454820224217, 44.928806509290425, 42.57999924251011, 42.371633189065115, 41.16842753546578, 42.64737592424665, 43.40783541543143, 43.83368008477347, 40.51626961571829, 40.90226984024048, 37.55714995520455, 38.171721594674246, 39.725887707301546, 38.533712318965364, 38.42426429476057, 38.583510058266775, 33.61040639877319, 33.89132901600429, 36.91822140557425, 37.56930235454014, 37.21120262145996, 39.61673150743757, 40.98252848216465, 46.08002574103219, 46.0342892238072, 50.370250020708355, 50.12652458463396, 42.3050069127764, 39.14471953255789, 46.760507992335725, 49.897699560437886, 48.72102560315813, 49.66755090441023, 48.591869013650076, 47.5582480430603, 44.37291240692139, 40.66403348105294, 38.03880602972848, 35.74773134504046, 34.544897420065745, 34.783081667763845, 39.21675498144967, 44.80447891780308, 50.0261925969805, 51.32028068814959, 49.538345677512034, 50.3728278023856, 48.730690547398154, 47.56654419217791, 47.65789910725185, 44.75776965277535, 47.20080491474697, 48.87903806141445, 48.64523812702724, 41.942161560058594, 35.67551176888602, 36.20872000285557, 34.22341121946062, 37.066381318228586, 44.862322671072825, 48.11230782100132, 47.444440024239675, 46.1644845690046, 41.4642470904759, 39.366099561963765, 39.95953478131975, 41.15597636359078, 43.12769447054182, 45.016169684273855, 46.4288079398019, 48.5572635105678, 45.13007150377546, 46.763113566807334, 45.79038660866873, 32.48847729819161, 21.17056703567505, 5.087663386549268, 8.739894952092852, 27.938781227384293, 35.84826135635376, 17.511484112058366, 6.379065998962947, 2.1394078859261105, 2.8333253477300917, 1.0619948080607822, 0.2636892662516662, 7.239346785204751, 25.003202063696726, 34.28062616075788, 44.128440039498464, 49.928431442805696, 48.252942834581646, 15.585881199155535, 0.9820550233125687, 0.22600999953491346, 0.09020003490149975, 0.16347955060856684, 0.09379662333854608, 0.1237605262015547, 0.14968287093298777, 0.13162079799388135, 0.29644416006548063, 0.16164962308747427, 0.10591333851750408, 0.07897612252937895, 0.1352397102330412, 0.11430363436894757, 0.21715196913906507, 0.12312153620379311, 0.16109781126890863, 0.11011395204280104, 0.188839851213353, 0.13044484252376215, 0.14540504690791878], [0.017238221164526682, 0.009442636660034103, 0.0273309444143836, 0.05331355832251055, 0.10249690791325909, 0.04527650780177542, 0.02520602549027119, 0.021284510381519794, 0.024355770221778324, 0.01126044469752482, 0.0193221192540867, 0.06727277088378157, 0.07122736796736717, 0.05723376385867596, 0.022180252941325307, 0.030612399136381488, 0.05186618545225688, 0.020203955238685012, 0.05790763734174626, 0.035813889133610895, 0.036610421392002275, 0.03896758758596011, 0.028815282176115682, 0.01757712735395346, 0.058795561481799395, 0.3487259346459593, 4.8148566995348245, 24.17263524872916, 41.13811949321202, 36.45343208312988, 34.961719853537424, 20.337179252079554, 19.817542587007793, 12.688784633363996, 0.9591584290776933, 0.07037006611270563, 0.9674691259860992, 2.131094149180821, 5.364246419497898, 2.213106776986803, 12.65997132233211, 14.918277433940343, 22.239509173801967, 28.604691369192942, 38.44082532610212, 49.961994716099326, 50.525146211896626, 46.34521763665335, 42.74114881243025, 44.36334473746163, 43.56466667992728, 46.43474517549787, 44.44357558659145, 45.766703673771445, 46.26719978877476, 44.71138000488281, 46.05678749084473, 44.748768261500764, 40.68809509277344, 34.05858605248587, 33.26533801215035, 32.074385506766184, 35.007279191698345, 32.838847160339355, 33.3342467716762, 32.20738445009504, 32.87495347431728, 34.52549804959978, 34.3588559286935, 33.722904682159424, 35.541644300733296, 33.99854319436209, 35.46488060270037, 34.297597135816304, 34.398047242845806, 33.22292620795113, 33.676334381103516, 32.19972406114851, 33.747619424547466, 32.19055591310774, 33.59755917957851, 33.71380949020386, 35.03155272347586, 38.000681264059885, 44.135770389011924, 43.094909395490376, 46.23024926866804, 43.229666233062744, 46.09734065192086, 37.627934728349956, 36.37624454498291, 49.17898137228829, 43.06433384759085, 44.22941126142229, 42.16096380778721, 41.74407189232962, 39.898137024470735, 38.560296126774375, 34.481053897312705, 32.64892857415335, 32.758220263889854, 32.41486113412039, 32.05093881062099, 37.480459213256836, 44.40936265672956, 46.35072408403669, 45.8989383152553, 44.61814907618931, 43.573299816676546, 44.818965911865234, 43.18433271135603, 43.141385895865305, 46.048588616507395, 45.93996742793492, 44.614122595105854, 42.7429518699646, 36.18560334614345, 33.02468020575387, 32.05816841125488, 33.020288944244385, 35.64483199800764, 45.22764505658831, 44.101540088653564, 45.52482993262154, 44.19806793757847, 41.866443565913606, 39.81497056143624, 39.27511984961373, 38.29655640465872, 40.91569375991821, 41.131532600947786, 45.13889224188668, 43.70201172147478, 45.87384489604405, 43.69156510489327, 33.67374617712838, 18.88762869153704, 9.954651117324829, 17.236651590892247, 24.921023981911794, 34.36240645817348, 15.56597808429173, 2.368321499654225, 0.3037215567060879, 0.049890562891960144, 0.09510972430663449, 0.06123423669487238, 0.29079074199710575, 10.105935982295446, 19.491237810679845, 27.732636860438756, 31.19431277683803, 33.6289997782026, 25.352757249559673, 4.748473610196795, 0.07870096979396683, 0.03144794715834515, 0.004485544798496578, 0.11930352821946144, 0.08938999979623727, 0.03859966554279838, 0.0597781344716038, 0.039857045215155394, 0.031432239072663445, 0.023794038221240044, 0.06896007712930441, 0.08765383902937174, 0.041587462183088064, 0.09821001866034099, 0.018548460411173955, 0.029449912586382458, 0.03831274022481271, 0.04624332520844681, 0.027144778153992126, 0.028909985308668444, 0.07197927297758204, 0.04167767341381737, 0.04324115041111197, 0.06648731231689453, 0.019002608988167982, 0.06057436138923679, 0.04534258014921631, 0.027836461484964405, 0.03440371694575463, 0.0039450717241769385, 0.04233184223994613, 0.06152112130075693, 0.04726459165768964, 0.049905137824160714, 0.05350419952135001, 0.007317699924377459, 0.053606393680508645, 0.03679176326841116, 0.05182624348838415, 0.01981550920754671, 0.062010704672762325, 0.022234768141061068, 0.031018936607454504, 0.026017985938649093, 0.0719548457169107, 0.015411701585565294, 0.5962827865566526, 7.016611422811236, 28.969270297459193, 47.91697311401367, 39.87305402755737, 39.15612847464425, 26.726143394197734, 27.741320371627808, 15.116926431655884, 0.9981170871428081, 0.06664927184049572, 0.874277335192476, 3.549751716000693, 5.936533493655069, 4.370706132480076, 13.034265569278173, 19.11865108353751, 26.04636812210083, 33.292140688214985, 42.39696284702846, 52.37544107437134, 51.285341671534944, 49.0636864389692, 44.72171197618757, 45.9588109425136, 44.86267702920096, 47.243154185158865, 46.12400088991438, 49.27184404645647, 47.645639010838096, 46.24168947764805, 47.50807857513428, 46.31624017442976, 41.84670025961739, 35.770094122205464, 35.262298924582346, 36.139074734279085, 36.719315324510845, 35.688226972307476, 34.62584740774972, 35.05206380571638, 34.12026868547712, 35.11324616840908, 35.92737007141113, 36.48258325031826, 36.985608509608674, 35.558021204812185, 36.93185724530901, 36.42781407492501, 36.51725476128714, 36.46828038351876, 35.55659335000174, 35.40627602168492, 35.064501081194194, 34.25322593961443, 34.73749106270926, 35.549061502729145, 35.789990288870676, 38.76525061471121, 45.4941223689488, 45.22133261816842, 46.71426773071289, 44.3571434702192, 46.53353813716343, 38.402547700064524, 39.38934128625052, 50.31975398744856, 45.06134687151228, 45.30002791540963, 45.127809865134104, 43.95054531097412, 42.137503215244834, 40.711698123386924, 36.305220058986116, 34.41031081335885, 34.51408563341413, 33.93163551603045, 33.82016209193638, 38.96229805265154, 45.626971926007954, 47.98873063496181, 46.253199168613975, 44.54053769792829, 45.381064755576, 45.43390927995954, 44.95068986075265, 43.83486475263323, 46.34574222564697, 46.78848491396223, 46.95509229387556, 43.85301692145211, 36.531526361192974, 33.886176926749094, 33.34926182883126, 34.65563086100987, 37.02543558393206, 45.44952883039202, 45.93842492784773, 47.48085553305489, 45.00768593379429, 42.967746938977925, 40.124950545174734, 40.65047754560198, 39.746509960719514, 42.82715708868844, 43.775846753801616, 47.440580299922395, 46.14881638118199, 44.997194153921946, 44.46419784000942, 36.11302246366228, 20.859610830034526, 13.585090960775103, 14.625403915132795, 18.759590762002126, 30.36108480181013, 23.719584907804215, 3.7671252403940474, 0.6464810786502702, 0.18874058154012474, 0.11402449863297598, 0.07561583391257695, 0.5223153041941779, 14.551891105515615, 24.44975893838065, 32.52694599969046, 36.25386939729963, 39.460049629211426, 31.049699919564382, 7.45341340133122, 0.22751478664577007, 0.029172717460564206, 0.0446859312775944, 0.043666154212717495, 0.020835225204271928, 0.050834571343979666, 0.03050885469253574, 0.02274802729620465, 0.057340728119015694, 0.02836460091306695, 0.052613696948226006, 0.08801749308726617, 0.06173612190676587, 0.04195388466385858, 0.056487405872238536, 0.04120003225814019, 0.0246999995184264, 0.009434193139895797, 0.06950805522501469, 0.0308810820403908, 0.05677064335239785, 0.15033806434699468, 0.1419858546661479, 0.15753509529999324, 0.16645508951374463, 0.14765729462461813, 0.10394066758453846, 0.09882641344198159, 0.1466099215405328, 0.09871198529643671, 0.12767282341207775, 0.12554010642426355, 0.13919620721467904, 0.16446087509393692, 0.25582849234342575, 0.12856033364576952, 0.17462999799421855, 0.11531311805759158, 0.06271765673799173, 0.15339419964168752, 0.26957118777292116, 0.11347567915384259, 0.12926830351352692, 0.07835626721914325, 0.136446104784097, 0.1542201531784875, 0.6751523315906525, 7.759608353887286, 32.30675411224365, 55.987590653555735, 46.93142672947475, 46.06815126964024, 31.51301622390747, 29.545696326664515, 18.480794293539866, 1.6914373295647758, 0.5006673772420202, 3.0050376994269232, 6.404201541628156, 11.89593698297228, 5.526745676994324, 17.38445540836879, 18.186414752687725, 31.57400403703962, 36.42406899588448, 42.26791395459856, 51.64863518306187, 54.281932967049734, 51.25982788630894, 46.7031923021589, 49.22898408344814, 47.128588812691824, 51.375897543770925, 47.89620842252459, 49.86254514966692, 49.11798661095755, 46.72348799024309, 48.52810192108154, 49.57993412017822, 44.59180498123169, 36.87765087400164, 37.283641065870015, 35.72820690699986, 38.20667450768607, 37.06679821014404, 37.11085673740932, 37.46255023138863, 35.90045969826834, 37.261927945273264, 37.6722468648638, 38.31572995867048, 38.728918484279085, 36.251281193324495, 38.55856602532523, 37.23850209372384, 38.09431866237095, 38.182929039001465, 37.5540406363351, 36.74252230780465, 36.711786951337544, 35.90627186638968, 36.66267013549805, 36.90762192862374, 37.98485674176897, 41.529782499585835, 47.43462569372994, 46.59210450308663, 47.850492749895366, 47.19471481868199, 48.47431244168963, 40.75670855385916, 42.01562138966152, 50.98336601257324, 47.560256072453086, 46.60712650844029, 46.93065547943115, 44.54319885798863, 44.72213929040091, 41.238646030426025, 37.88486174174717, 36.10253068378994, 36.73243352345058, 34.96998473576137, 35.221846512385774, 40.243382590157644, 47.098464897700715, 48.92068556376866, 47.044724055698936, 44.812757696424214, 44.712606361934114, 46.27167790276663, 45.45190511431013, 44.609707014901296, 48.23482540675572, 48.12725339617048, 48.772334575653076, 45.30687189102173, 38.9461122240339, 36.01410443442208, 35.31541790281023, 36.315037863595144, 39.14101266860962, 49.70265320369175, 47.65691941125052, 48.00302307946341, 48.87956959860665, 45.83434438705444, 43.037034375326975, 42.438030174800325, 41.54585715702602, 45.039022309439524, 45.39090340478079, 50.22392095838274, 46.71096733638218, 46.08731440135411, 44.68953834261213, 36.52422380447388, 23.344620159694127, 17.857825756072998, 23.946045807429723, 32.9942957333156, 38.2978070804051, 18.6313339642116, 3.808681547641754, 1.2989395622696196, 0.30787636233227594, 0.510617903300694, 0.16640525790197508, 1.1588749523673738, 22.77333927154541, 28.995890583310807, 38.390370982033865, 42.583073820386616, 46.60116842814854, 34.33909525190081, 8.19981494971684, 0.391477359192712, 0.05823964452637093, 0.07436540922416107, 0.1291990793709244, 0.13498730877680437, 0.09673645773104259, 0.1141556730227811, 0.18716313689947128, 0.12191012049359934, 0.15779744407960347, 0.09180267354739563, 0.19206913507410459, 0.12168568825083119, 0.2470275674547468, 0.17979113890656404, 0.07908250324960266, 0.06835556349584035, 0.13053283494498047, 0.16641000764710562, 0.06702868148152318, 0.13617285873208726], [0.031809063495269845, 0.041122594449136934, 0.061406001049493036, 0.020415023734260882, 0.03030726533117039, 0.034603226597287824, 0.028916807978280952, 0.050418676874999485, 0.0678933590118374, 0.02637636777944863, 0.04644753710765924, 0.05844581060643707, 0.038269130779164176, 0.03253679569544537, 0.047370741676006994, 0.06704835899706398, 0.01285700621415994, 0.05875160598329135, 0.0184115099920226, 0.006073512669120516, 0.010363354397538518, 0.039377887533711534, 0.05139638816139527, 0.04987901761861784, 0.11949317875717368, 0.07472917863300868, 1.3545290593590056, 10.639554159981863, 28.425714458738053, 40.30363736833845, 31.07710361480713, 19.839563165392192, 19.51379340035575, 19.833514758518763, 2.879613161087036, 0.25173844609941753, 0.4529454665524619, 3.1031912096909116, 5.556790556226458, 4.532269554478781, 8.445107204573494, 5.907878254141126, 3.5447726803166524, 14.851315907069615, 33.11211633682251, 46.85299546377999, 51.073004722595215, 49.01825564248221, 47.52803727558681, 48.57328953061785, 46.875681332179475, 47.85430383682251, 48.2743432862418, 48.95708022798811, 46.21685314178467, 49.34667614528111, 46.02802889687674, 44.57812050410679, 37.77360371180943, 32.56740883418492, 34.57520546231951, 33.001250880105154, 34.08438471385411, 34.47141327176775, 34.3957473891122, 32.85800681795393, 34.511539118630544, 33.48674236025129, 32.692469460623606, 33.89884001868111, 33.805980818612234, 36.87882511956351, 35.91353620801653, 35.713153634752544, 34.38511664526803, 33.964691570826936, 32.88958290645054, 33.634839739118306, 34.30524015426636, 32.44241074153355, 34.90097522735596, 34.89986004148211, 39.629554407937185, 42.17325169699532, 44.65452636991228, 45.22835029874529, 44.451288087027415, 41.7277957371303, 44.98033782414028, 39.78908852168492, 39.24701091221401, 49.128297737666536, 41.88966791970389, 42.22669724055699, 38.883880683353965, 36.998282023838584, 35.26927144186837, 34.16333014624459, 33.00332839148385, 33.91302129200527, 30.85287482397897, 32.99453544616699, 35.4944486618042, 40.17163896560669, 43.28691244125366, 43.02397871017456, 44.52716588973999, 44.77066550936018, 44.4097135407584, 44.61105843952724, 44.49004166466849, 45.41850512368338, 44.12278767994472, 42.110829080854145, 39.788067136492046, 34.20583922522408, 30.96756178992135, 31.582008361816406, 32.091391222817556, 32.009805474962505, 36.038221631731304, 43.98090546471732, 44.68608856201172, 46.561282294137136, 47.19703899111067, 44.77268743515015, 41.572579928806846, 43.214970793042866, 41.37869392122541, 40.679149287087576, 43.56671987261091, 45.25592769895281, 45.63757835115705, 46.013892786843435, 40.428642409188406, 32.39769908360073, 18.870970385415212, 8.20690471785409, 12.476008210863386, 27.06529712677002, 26.612048762185232, 6.059426282133375, 1.3851441251380103, 0.05689293911148395, 0.06645219134432928, 0.08272098443870034, 0.41183748096227646, 2.2485152312687466, 8.33050535406385, 20.125846317836217, 27.34209077698844, 27.33949215071542, 33.89675555910383, 14.810120037623815, 1.7085243612527847, 0.015673950281260268, 0.05814245795564992, 0.0528576879629067, 0.029896354701902186, 0.006327699944709561, 0.015964834851079752, 0.02984551546562995, 0.016473161056637764, 0.057826226710208824, 0.03290126060268708, 0.03198653432939734, 0.014944677806592413, 0.0296761565176504, 0.037146640475839376, 0.007004559830030692, 0.005576173217767584, 0.046386910003743, 0.005870525525616748, 0.014335246490580695, 0.02785480228651847, 0.03604285738297871, 0.02053233395729746, 0.03196990343609026, 0.04840811654659254, 0.08129694299506289, 0.009759889948847038, 0.0403531018112387, 0.016725294491542236, 0.06729186485920634, 0.028829979244619608, 0.06426375306078366, 0.03366688898365412, 0.012329597907539989, 0.05006897010441337, 0.033739756859306774, 0.02164739090949297, 0.05675154937697308, 0.02543264431213694, 0.08886412158608437, 0.07008214334824256, 0.019561078931604112, 0.027799091168812344, 0.008028881807279373, 0.04134897069473352, 0.02736094923290823, 0.11192684833492551, 0.11128737657730069, 2.5537613204547336, 13.933973908424377, 36.803360734667095, 46.109534740448, 36.88787167412894, 23.79534980228969, 24.451428243092128, 18.920952251979283, 3.45586678811482, 0.08528136847806828, 0.537885023014886, 1.576917446085385, 6.019873227391924, 6.996351778507233, 10.627567648887634, 9.509793571063451, 6.802570862429483, 21.16831408228193, 35.54411091123308, 50.697694301605225, 50.909211363111226, 51.811817101069856, 47.304843766348704, 50.435250418526785, 47.56929567881993, 49.42989819390433, 50.091728006090435, 49.49767787115914, 47.054604394095286, 50.41451699393136, 48.448475565229145, 46.66885430472237, 40.58779089791434, 33.972581250326975, 36.466442584991455, 34.444902420043945, 34.14252723966326, 35.59853615079607, 35.247700759342735, 34.68940258026123, 35.85800967897688, 35.35781928471157, 34.54962566920689, 35.55543647493635, 34.644558906555176, 38.84959479740688, 38.2747460092817, 35.83567122050694, 35.87277807508196, 36.06673009055001, 34.07797152655465, 35.71682228360857, 34.60793495178223, 34.45441450391497, 36.494954517909456, 36.5786212512425, 40.39842816761562, 43.71476513998849, 45.414968490600586, 47.171858719417024, 46.13415220805577, 45.43803998402187, 45.67603315625872, 41.06697341373989, 40.179542541503906, 50.14664656775338, 43.79136902945382, 43.903186389378135, 40.40340655190604, 39.94613865443638, 37.11595671517508, 36.03470584324428, 33.87989228112357, 34.93415287562779, 32.47741576603481, 33.98116227558681, 35.443782397678916, 40.980447496686665, 45.60836812428066, 45.42066601344517, 44.94121599197388, 46.57908010482788, 45.60154846736363, 46.99226515633719, 46.31056349618094, 45.7177015032087, 46.97521080289568, 44.07436220986502, 43.16698653357369, 36.833453382764546, 32.77786629540579, 33.33852686200823, 33.49776915141514, 32.90667200088501, 38.340951919555664, 46.42445836748396, 46.551857062748496, 47.44940798623221, 47.377209254673545, 45.65825271606445, 43.30214636666434, 45.15705483300345, 42.92461947032383, 43.594523089272634, 44.11248697553362, 47.03546558107649, 45.4472393989563, 47.277412278311594, 40.973961353302, 33.3193359375, 21.451642513275146, 11.279151473726545, 15.950062343052455, 32.11358724321638, 31.448509148189, 10.024191294397626, 1.6510930487087794, 0.05896904253001724, 0.09999126129384552, 0.11592020333877631, 0.2802871827568327, 3.1889799662998746, 13.137174470084053, 23.310695580073766, 31.32888548714774, 32.83655078070504, 38.61572885513306, 20.027350391660416, 2.516518758875983, 0.023330200164179717, 0.03196687038455691, 0.10182883590459824, 0.033801608718931675, 0.055211844854056835, 0.03223848116717168, 0.04609763016924262, 0.027165573555976152, 0.04512423436556544, 0.06411792231457573, 0.026801972084545662, 0.06096608644085271, 0.08784350313778434, 0.017307777789288332, 0.05287698549883706, 0.034138006025127, 0.03256685479677149, 0.03160225959228618, 0.027887799444475343, 0.07796519356114523, 0.031385186061795266, 0.0730472667408841, 0.05430717786241855, 0.14771562149482115, 0.2073302154562303, 0.09049431553908757, 0.12251221175704684, 0.11966801009007863, 0.1661167312413454, 0.10554627142846584, 0.13060063416404383, 0.12772661766835622, 0.2289379324231829, 0.15490118520600454, 0.11876216584018298, 0.10923225006886891, 0.12563070441995347, 0.0744262398885829, 0.18134744039603642, 0.19041701086929866, 0.0593116959290845, 0.10102337412536144, 0.10348883111562047, 0.1034606583416462, 0.13282331132463046, 0.14875656206692967, 0.18209237685160978, 2.787792499576296, 14.949151754379272, 42.02429621560233, 55.63485492978777, 42.925394194466726, 29.555128506251744, 29.72357021059309, 25.80395415851048, 4.391325780323573, 0.2862876850579466, 1.0607466293232781, 7.3481395074299405, 12.13255614893777, 11.258670789854866, 10.490304248673574, 9.050099883760724, 4.900517131601061, 20.13078474998474, 37.1091023172651, 50.428819860730854, 53.353917666843955, 51.90863330023629, 51.5530036517552, 53.944104603358674, 49.77510207039969, 52.012647833142964, 51.98406294413975, 50.10184110913958, 48.22068582262312, 51.41451563153948, 51.14436272212437, 50.28701754978725, 40.34027521950858, 36.26571954999651, 39.39879083633423, 37.30234561647688, 37.58945560455322, 38.696609360831125, 38.113794463021414, 35.715307576315745, 38.67232540675572, 36.535934993198936, 36.55725901467459, 37.395923955099924, 36.6514835357666, 41.585263865334646, 38.923912729535786, 38.011742796216694, 37.88858945029122, 37.455563817705425, 35.36469452721732, 37.51118067332676, 37.73033380508423, 35.44749273572649, 38.879277501787456, 38.21586350032261, 44.03097070966448, 45.96830218178885, 48.54382569449288, 48.87929514476231, 48.474173477717805, 46.41891370500837, 44.87818888255528, 42.47136763163975, 43.01508501597813, 51.85518775667463, 47.247083391462056, 45.69398035321917, 42.583132880074636, 41.44829402651106, 38.61440174920218, 36.81531858444214, 36.66906247820173, 36.682552405766074, 33.76076194218227, 35.215561866760254, 37.87242794036865, 43.56462499073574, 46.28091900689261, 47.20766626085554, 44.98588596071516, 47.397449357169016, 47.537181104932515, 48.38979107992989, 47.57353407996041, 48.06746762139456, 48.825411864689414, 44.68115186691284, 44.8071539742606, 37.61340604509626, 33.92289468220302, 34.87147317613874, 35.77232796805245, 34.53922769001552, 39.53804315839495, 48.84476954596383, 49.00000619888306, 49.9719306400844, 50.04071085793631, 47.24999121257237, 45.62090614863804, 47.567860875810894, 45.47431305476597, 44.65969235556466, 45.70022678375244, 47.821317264011924, 46.56162622996739, 46.087870257241384, 43.289677824292866, 37.385796955653596, 26.87152750151498, 12.409327217510768, 13.974290830748421, 34.807914529527935, 30.825255734579905, 9.006740518978663, 5.816018291882106, 0.1593933855848653, 0.35999409428664614, 0.3494572868304593, 1.1695899431194579, 5.695822707244328, 16.28829370226179, 27.26935182298933, 39.305608545030864, 37.60269539696829, 44.246100834437776, 21.20687484741211, 3.249836415052414, 0.1565490753522941, 0.13946744480303355, 0.1662344163549798, 0.12031708311821733, 0.08500430905925375, 0.06965043901332788, 0.24294427941952432, 0.1531187958483185, 0.12766679802111217, 0.13711724377104215, 0.1589676727141653, 0.10667229350656271, 0.09725442422287804, 0.14639338744538172, 0.08459108801824705, 0.0892429341162954, 0.12424088828265667, 0.0850778826113258, 0.09481203063790287, 0.15968989181731427, 0.09854340327105351], [0.015926473873800466, 0.02692709394198443, 0.04988243064976164, 0.045790213093693764, 0.0540884181724063, 0.024788858768131052, 0.025935934091519033, 0.058073525583105426, 0.034788456479353566, 0.008790544999231185, 0.0021691803995054215, 0.018818603861810904, 0.04170340006904943, 0.02525455940381757, 0.02185056295378932, 0.0135880708694458, 0.04645440048937287, 0.014992836829540985, 0.014613520487078598, 0.017209108619551574, 0.0386497617832252, 0.056157023778983524, 0.06505226503525462, 0.025985687671761428, 0.009063861449249089, 0.0277072667210762, 0.16922599582799844, 4.258719844477517, 22.237023455756052, 38.581880705697195, 37.25746372767857, 28.403299570083618, 29.005564212799072, 20.28885974202837, 4.593112758227757, 0.0934607485043151, 0.6757080246295247, 1.456974602171353, 4.050781539508274, 5.054103587354932, 3.466801081384931, 0.515564640717847, 0.5412266722747258, 6.175812082631247, 21.116593429020472, 36.17983634131295, 48.242961747305735, 49.835648672921316, 48.584698472704204, 47.28797354016985, 48.15445906775338, 47.39461101804461, 48.0062609400068, 48.505978856767925, 47.542934213365825, 46.48070750917707, 45.2424829346793, 41.32809713908604, 34.36556441443307, 34.379019601004465, 36.20833785193307, 39.864281926836284, 41.56149755205427, 42.76867757524763, 41.372888701302664, 38.853482314518516, 34.893624033246724, 33.684349128178184, 32.72340978894915, 33.50452627454485, 33.69653279440743, 34.752193450927734, 36.81486347743443, 35.06906952176775, 34.610418932778494, 34.05963175637381, 32.90727996826172, 33.008497851235525, 34.809391021728516, 34.09474447795323, 34.29309122903006, 39.27184724807739, 44.06590972627912, 45.4790552003043, 46.274092401777, 43.135083879743306, 44.977641923086985, 42.603310448782786, 44.147467681339805, 39.083255767822266, 38.17866979326521, 47.467344760894775, 42.5059175491333, 42.22070789337158, 35.39018051964896, 35.23052133832659, 32.04284415926252, 32.8823150907244, 32.94352872031075, 31.633028984069824, 31.64659881591797, 31.867996215820312, 36.440657820020405, 40.99196066175188, 43.14185837336949, 45.53511674063546, 44.74071877343314, 45.198358399527415, 42.55430480412075, 42.84833172389439, 41.36022213527134, 38.999001911708284, 37.97394459588187, 36.919736112867085, 33.99521500723702, 31.348528044564382, 31.813560553959437, 30.45739378247942, 32.45207915987287, 32.58798939841134, 36.71718222754342, 42.5115316935948, 44.80594151360648, 44.478591033390586, 45.20645652498518, 45.081760678972515, 45.87279919215611, 43.391069412231445, 42.919397899082725, 43.12581498282296, 45.56981257029942, 47.002003056662424, 45.718820163181846, 42.333928789411274, 35.084268706185476, 18.801318168640137, 3.989492348262242, 0.6871042102575302, 1.1172807557242257, 2.2959977005209242, 2.157878586224147, 0.5317235993487495, 0.368329679859536, 0.055489291037831984, 0.09499174742294209, 0.19360916529382977, 0.24406858480402402, 3.755578637123108, 11.701947620936803, 27.293693099703106, 24.911426782608032, 29.91344015938895, 21.691214663641794, 6.676132755620139, 0.9523305211748395, 0.15560908722026007, 0.037432622630149126, 0.03258610822792564, 0.05115741830585258, 0.037708067135619264, 0.0938763851299882, 0.07544058188796043, 0.041281761801136393, 0.03526645386591554, 0.013904951812167252, 0.013954104040749371, 0.029600167380911962, 0.019588663076449717, 0.023775817859651785, 0.028770196916801587, 0.01041273054267679, 0.0321133660950831, 0.02574704012035259, 0.09434259975595133, 0.05339475521551711, 0.03731826233810612, 0.030671455431729555, 0.01917327581239598, 0.00576905909526561, 0.019382941436820796, 0.026724960056266615, 0.11263606670711722, 0.03448459153462734, 0.014112712449527212, 0.0199527191663427, 0.03585761732288769, 0.03246939002669283, 0.06236850975879601, 0.04371317329683474, 0.019403409445658326, 0.10993848967232875, 0.04309990656163011, 0.04672965161236269, 0.018319802591577172, 0.02077933257844831, 0.030700639222881625, 0.024593683259029473, 0.03422201883846095, 0.028399830451235175, 0.050132229924201965, 0.03524159234283226, 0.02119339839555323, 0.3009501211345196, 6.82880118063518, 26.396541697638376, 46.53152315957205, 39.99816676548549, 29.86711651938302, 29.060479300362722, 25.878920010157994, 5.863358974456787, 0.2618212050625256, 0.17246709976877483, 0.1892156239066805, 1.7241080850362778, 5.350820328508105, 8.424793277468, 0.41586884749787195, 0.8164295107126236, 8.017609732491628, 25.181584903172084, 40.14475638525826, 50.21487440381731, 51.511324882507324, 49.79309443065098, 49.09667648587908, 50.25220707484654, 49.791836806706016, 49.639834540230886, 49.267431940351216, 49.027993542807444, 48.350999287196565, 47.522575991494314, 43.09850508826119, 36.244458062308176, 36.55798510142735, 36.28643907819475, 40.70723737989153, 43.804640088762554, 42.9995106288365, 42.47220836366926, 38.740487234933035, 35.845291001456125, 36.33571570260184, 34.820452553885325, 36.09443255833217, 34.4762214251927, 36.78653219767979, 37.14950956617083, 36.93703365325928, 35.89003045218331, 35.371802534375874, 35.354223591940745, 34.206777232033865, 34.89290142059326, 35.02169670377459, 35.35551943097796, 39.72510256086077, 45.67619643892561, 47.198692662375315, 47.386325291224885, 46.85404464176723, 46.343108858381, 44.950964314596995, 43.40716144016811, 39.137066091809956, 41.698978083474294, 48.114729268210276, 44.604176248822895, 43.83891902651106, 39.103433336530415, 36.67756707327706, 33.755192961011616, 33.79350880214146, 34.82834570748465, 32.77297823769705, 33.65263754980904, 33.09487438201904, 38.64859730856759, 42.92666571480887, 44.51459312438965, 46.57667255401611, 46.42139073780605, 46.833533559526714, 45.149727957589285, 46.16169139317104, 44.11053800582886, 41.944513525281636, 39.97724573952811, 38.39736086981637, 36.420059885297505, 33.55541835512434, 32.32675797598702, 31.195851802825928, 33.49319723674229, 34.07930905478341, 37.941684109824045, 44.68558134351458, 46.11880016326904, 45.29900305611746, 46.05015543528965, 46.9625129699707, 47.21848808016096, 45.75579500198364, 44.626771790640696, 45.27012634277344, 47.199446541922434, 48.86853238514492, 46.86337954657418, 43.467756680079866, 37.931581429072786, 24.404263871056692, 7.51959672995976, 0.6773873716592789, 1.5256580880710056, 5.519889976297106, 4.870462698595865, 0.2098407136010272, 0.7011803377951894, 0.17215610002832754, 0.03278752795553633, 0.26817101719123976, 1.3990584356444222, 6.420071661472321, 15.276252099445887, 30.1307589667184, 30.129483972276958, 34.6114889553615, 29.024430309023174, 9.714550035340444, 1.0937997528484888, 0.06802337989211082, 0.01661219627463392, 0.06934986157076699, 0.05467776994087866, 0.0382529036141932, 0.022755676082202365, 0.022148003868226494, 0.025958956784701774, 0.041914007160812616, 0.03457611912329282, 0.016622218236859356, 0.04741272942296096, 0.06133499914514167, 0.02282151603139937, 0.040529551450163126, 0.026834568906841532, 0.04915337869897485, 0.0577634350795831, 0.0197814009484968, 0.03281601285561919, 0.04047958752406495, 0.16898268674101147, 0.22758715919085912, 0.09431433877242462, 0.12057149303810936, 0.14900805428624153, 0.2139306648501328, 0.11097819531070334, 0.08363460469990969, 0.13195775848414215, 0.07395921102059738, 0.07259825297764369, 0.11905347449438912, 0.12464011114622865, 0.0907085629712258, 0.2250461812530245, 0.11094210403306143, 0.07472752300756318, 0.16244958873306, 0.10868028218724898, 0.16955437963562353, 0.07780255550252539, 0.08327622964446034, 0.1461075342127255, 0.0873606236917632, 0.13910403501774582, 0.08994881409619536, 0.2863077154116971, 6.413866051605769, 31.45279618671962, 51.59452608653477, 48.26830530166626, 38.74665723528181, 39.459816864558626, 29.614354951041086, 7.190903076103755, 0.47926991113594597, 1.2924904397555759, 5.42145745243345, 11.547051429748535, 12.177269543920245, 6.81964475767953, 1.705836819750922, 1.3035006203821726, 9.49344185420445, 26.0597242968423, 40.93340124402727, 51.75127397264753, 52.10351637431553, 50.79562221254621, 49.91456978661673, 51.51982600348336, 48.91770131247384, 49.35359655107771, 49.77857616969517, 50.718712602342876, 50.95559753690447, 48.66016285760062, 44.66662318365914, 39.053559167044504, 39.68525811604091, 39.58906725474766, 43.91919503893171, 46.666380746024, 45.250907625470845, 45.7303854397365, 42.10804285321917, 39.06861243929182, 37.615414074489046, 36.68266357694353, 37.036048957279746, 36.087908199855256, 39.321526868002756, 39.71469068527222, 38.75195871080671, 37.83899668284825, 37.0095728465489, 35.84728513445173, 35.8855037008013, 37.782792704445974, 35.631397656032014, 36.917634282793315, 42.311982904161724, 47.18080105100359, 49.76257446834019, 48.324478013174875, 48.38945756639753, 47.73005614961897, 45.76116248539516, 42.861380440848215, 41.52715608051845, 44.297173568180625, 50.1143548148019, 47.33923387527466, 46.03050940377371, 40.11816562925066, 38.46741260801043, 34.98677853175572, 34.73018503189087, 37.16009167262486, 34.373770236968994, 34.74251113619123, 35.07570505142212, 40.38434416907174, 43.314038208552766, 45.94073172977993, 47.80950880050659, 48.448089940207346, 48.32075030463082, 46.64901024954659, 47.69371012278965, 44.9537227494376, 43.38152258736746, 41.18687847682408, 39.4334762437003, 37.58314316613333, 36.43339000429426, 34.56050654820034, 32.32341589246477, 36.43077400752476, 36.38930368423462, 40.175373622349326, 46.38459307806832, 47.67912237984793, 46.19386502674648, 46.27084411893572, 47.97807557242257, 48.655486719948904, 46.84401491710118, 46.32408469063895, 46.798549379621235, 49.427890164511545, 50.57526009423392, 46.65501696722848, 45.96281657900129, 40.00666093826294, 25.48255828448704, 6.856807197843279, 0.8035901082413537, 2.428926510470254, 6.7099626660346985, 4.768217785017831, 1.3468362092971802, 1.054529077240399, 0.44506810924836565, 0.4484358142529215, 0.7423069423862866, 2.684248055730547, 8.889017190252032, 21.76225652013506, 37.559032917022705, 35.149658203125, 41.740389347076416, 33.034498010362896, 10.839951498167855, 1.1735378227063586, 0.2601197106497628, 0.1860178919242961, 0.2540652241025652, 0.145112150481769, 0.15257079739655766, 0.15274189678686007, 0.16941340720014914, 0.09034288009362561, 0.10058576653578452, 0.09048858191817999, 0.09737206183906112, 0.07936698584152119, 0.1633357418967145, 0.06407980221722807, 0.10450298991054296, 0.07472870365849563, 0.08498862811497279, 0.1350572250251259, 0.20740123093128204, 0.14723969703274115, 0.09788223196353231], [0.07113389976854835, 0.029048443771898746, 0.061682985829455514, 0.028386505719806467, 0.020546267673905407, 0.029201399135802473, 0.05505646372746144, 0.03519204232309546, 0.05888971500098705, 0.03791629935481718, 0.04159802018797823, 0.018946531461551785, 0.030703977615173374, 0.03266554432255881, 0.028195633819060664, 0.008704402434107448, 0.015067100790994508, 0.008403791912964411, 0.027377576733540212, 0.044048203354967494, 0.021723654852913957, 0.02864006068557501, 0.009194890802193965, 0.03352090556706701, 0.016268014475437145, 0.0552135717256793, 0.07152396240936858, 1.2018801761525018, 10.364556619099208, 31.034302711486816, 39.12586212158203, 32.08418246677944, 20.301064252853394, 19.867960453033447, 11.232726216316223, 0.7316352150269917, 0.21981986026678765, 0.040759150737098286, 1.7180055039269584, 6.528576033455985, 6.465155482292175, 0.4889507602368082, 0.34056180130158153, 1.0919474065303802, 8.392929707254682, 23.31411235673087, 39.07989283970424, 48.507007190159385, 51.046987192971365, 48.84355708530971, 48.32188980919974, 45.884176867348806, 48.23890052522932, 50.54834277289254, 47.911814076559885, 44.593910285404746, 41.68139566693987, 35.44976132256644, 35.798529624938965, 35.75785834448678, 41.99187592097691, 46.05769770486014, 48.64904573985508, 47.00771795000349, 45.55250808170864, 43.29192904063633, 41.16738530567714, 34.89046260288784, 35.2692540713719, 34.51224088668823, 33.79617691040039, 34.548197814396445, 33.827951022556846, 33.36642387935093, 34.92490482330322, 33.019027846200125, 35.13350364140102, 34.17019844055176, 40.07352692740304, 37.45921857016427, 37.10926212583269, 43.217190742492676, 44.80532659803118, 44.81080872671944, 46.58326639447893, 40.88200889314924, 47.09859691347395, 39.185915402003694, 58.80776023864746, 51.87657083783831, 33.456500325884136, 49.562931878226145, 40.75108398709978, 44.6201605796814, 36.80403470993042, 35.71651656287057, 33.853454385484966, 33.93116998672485, 32.03681659698486, 32.39843559265137, 30.85572705950056, 33.47240475245884, 36.669006892613, 42.76683630262102, 45.873893533434185, 45.78698546545846, 42.914905888693674, 43.57664884839739, 39.503361225128174, 37.10133075714111, 35.67805828366961, 35.13341678891863, 32.69514799118042, 31.47109079360962, 31.350741045815603, 31.42231443950108, 31.370091778891428, 31.47069822038923, 33.091556617191856, 32.930671078818186, 36.74396058491298, 42.8038979939052, 42.79590061732701, 46.40353734152657, 44.722486700330464, 45.40331288746425, 43.05166728155953, 44.18722527367728, 45.0922246660505, 45.57138981137957, 44.98008074079241, 45.98511334827968, 42.999319553375244, 35.468212263924734, 17.671782527651104, 4.567591156278338, 0.3891915375632899, 0.21752368419298104, 0.2368364328784602, 0.9263305791786739, 0.27809687171663555, 0.046808110616569004, 0.03481360977249486, 0.06213278669331755, 0.1947048365005425, 0.11755308429045336, 1.7778267796550478, 6.04844639131001, 18.572762387139456, 24.27121455328805, 26.538585458483013, 33.53934022358486, 15.321406705038887, 3.3587911171572546, 0.05998425305421863, 0.033177387035850964, 0.08343442329870802, 0.02984015503898263, 0.063678211266441, 0.030201424046286514, 0.075658079502838, 0.018930365364732485, 0.022711905484486903, 0.03136987152642437, 0.03478219360113144, 0.01796418578097863, 0.042757531361920495, 0.0034980072648197946, 0.06539871823042631, 0.05724357547504561, 0.037453124565737586, 0.03753910852330072, 0.006359457928088627, 0.04756435825090323, 0.05246495867946318, 0.033860332532120604, 0.013872130225146455, 0.06142983798469816, 0.09124726549323116, 0.01863672594273729, 0.03313562999080334, 0.03622195670115096, 0.04510971710884145, 0.05758865802947964, 0.02004425014768328, 0.05454519437626004, 0.045601624463285716, 0.030444882410977567, 0.029737852314221006, 0.023052821833906428, 0.036308347779725275, 0.08716117510838167, 0.038133037010473866, 0.05063296501923885, 0.026784309818010246, 0.020633532366316234, 0.03526616209585752, 0.013910504773126116, 0.07406145946255752, 0.03548803286893027, 0.011812424453507577, 0.007045536135722483, 0.05559834857870426, 2.23740462745939, 15.861919232777186, 37.64922400883266, 45.52473265784127, 36.662701402391704, 25.723094497408184, 23.489271232060023, 10.808338063103811, 0.9127146069492612, 0.12173747404345445, 0.15936593205801078, 0.8577685239059585, 3.857317634991237, 7.549760597092765, 1.1962918703045164, 0.21943667797105654, 2.0666161690439497, 10.831347022737775, 26.53492202077593, 42.22438696452549, 50.87604761123657, 50.46733372552054, 49.01552152633667, 48.310310636247905, 45.840990339006694, 48.39335897990635, 50.97741835457938, 49.345025948115754, 46.92360653196062, 44.439795766557964, 37.10822684424264, 36.58849116734096, 36.01946496963501, 43.435607365199495, 47.28943961007254, 49.693676131112234, 48.31902367728097, 48.60029717854091, 44.524897302900044, 41.51649406978062, 36.007326466696604, 35.7568439074925, 34.86158241544451, 35.21901164736067, 36.09898362840925, 35.890155519757954, 36.174413272312705, 35.915717942374094, 34.50122104372297, 35.29087686538696, 35.52015004839216, 40.89897639410836, 39.26251581736973, 38.32125377655029, 45.42272615432739, 47.845253808157786, 47.60813610894339, 45.69900737489973, 42.913412025996614, 47.47864253180367, 42.076956612723215, 55.40327841894967, 48.85196787970406, 38.30411604472569, 48.677748748234336, 43.49523680550711, 45.898187909807476, 39.01784890038626, 36.25658961704799, 34.53991208757673, 35.33045033046177, 33.84753452028547, 33.857466970171245, 33.030304772513254, 33.874076638902935, 38.18471820013863, 44.4096405846732, 48.357912744794575, 46.72689955575125, 45.53513411113194, 44.484986850193565, 42.17632974897112, 37.98299809864589, 38.03403956549508, 36.369560377938406, 35.36024420601981, 33.4858842577253, 33.338975020817344, 32.17702777045113, 32.36324644088745, 32.74968440192086, 34.12038333075387, 34.63304226739066, 39.15228264672415, 43.91591201509748, 44.10750164304461, 49.065124716077534, 45.519465923309326, 45.6323915209089, 45.44317470278059, 45.848862648010254, 47.12788357053484, 47.0608160836356, 47.854015486580984, 47.34640441622053, 44.68596349443708, 38.20692811693464, 21.052546671458654, 5.758683494159153, 0.8588340410164425, 1.4300035408564975, 0.9311780333518982, 0.80171138048172, 0.38230082445910996, 0.019100178931174532, 0.0675293453303831, 0.029436565802565644, 0.2874141888959067, 0.6293936126998493, 3.665749720164708, 9.405961428369794, 19.4280161517007, 28.452112402234757, 30.695772579738072, 38.82631138392857, 19.525230135236466, 4.892083755561283, 0.12088611615555626, 0.06123762936996562, 0.006754290246005569, 0.010235159624634045, 0.04777802214292543, 0.03098796826920339, 0.07811536014612232, 0.044806829254542074, 0.058069712216300626, 0.034845436457544565, 0.03441973376486983, 0.05212906688185675, 0.021736764149474244, 0.02518408845311829, 0.04341855678441269, 0.04130579890417201, 0.029967960502420152, 0.01701482029498688, 0.05879738674099956, 0.021655945539740578, 0.005294136320506888, 0.07329880645764725, 0.157612624711224, 0.12391543574631214, 0.14901131125433104, 0.12194013888282434, 0.12901073162044796, 0.11844515427947044, 0.13938085016395363, 0.13031662654663834, 0.13301864798579896, 0.1239140515348741, 0.08750910072454385, 0.10069468497697796, 0.09409744505371366, 0.09277227973299366, 0.06972769022520099, 0.12181341568274157, 0.16718562745622226, 0.21907052690429346, 0.0969330971794469, 0.23530164094907896, 0.11792626498000962, 0.11232490411826543, 0.12357631751469203, 0.13585366228861467, 0.12331006037337439, 0.08504824420171124, 0.1187806355633906, 2.4482160125459944, 16.100212914603098, 43.91322306224278, 50.89658301217215, 44.37500728879656, 30.171923569270543, 28.887121745518275, 14.236782482692174, 1.4410941685949052, 0.23770406203610556, 0.41225089877843857, 8.91431210722242, 13.441172923360552, 11.926275423594884, 2.91744783946446, 1.2910100391932895, 2.1422651154654364, 10.411102601460048, 28.155389581407817, 43.558712073734824, 50.64897353308541, 51.34226826259068, 49.83437715257917, 47.30488198144095, 45.24431378500802, 50.07220704214913, 53.77282803399222, 51.86727067402431, 48.43743487766811, 45.11587633405413, 39.36886494500296, 38.86212934766497, 38.46913923536028, 47.34785311562674, 50.513782433101106, 52.099823406764436, 51.68660361426217, 50.00065796715872, 46.41699252809797, 44.520926407405305, 37.712278911045615, 39.17740385872977, 37.90392065048218, 36.17814792905535, 37.57081706183297, 38.40557016645159, 36.720499992370605, 37.7747015271868, 36.89150905609131, 37.61920779091971, 36.75999355316162, 42.047027247292654, 41.58702523367745, 40.44557864325387, 48.062496185302734, 48.138078689575195, 48.91794797352382, 46.25023923601423, 44.47502660751343, 47.43495225906372, 42.86840506962368, 53.657943044389995, 49.7460481779916, 40.21819884436471, 49.55036953517369, 45.27955157416207, 47.093688011169434, 41.164154393332346, 37.98808765411377, 37.23975624356951, 37.3648898260934, 35.40361138752529, 35.391052518572124, 34.93347890036446, 34.560589926583425, 40.03247697012765, 47.16656419209072, 47.872813837868826, 47.758755683898926, 47.20907327107021, 46.02858822686331, 43.320795331682476, 40.431223664964946, 39.789943150111604, 38.28671775545393, 36.243256023951936, 35.122796467372346, 34.54586321966988, 34.198693002973286, 35.85391024180821, 33.63336672101702, 36.50141634259905, 35.916499614715576, 40.97114385877337, 45.37910188947405, 45.41258178438459, 49.62475347518921, 45.44029467446463, 46.28436878749302, 43.8737781388419, 47.31554399217878, 47.564980847494944, 47.64459678104946, 48.30724648066929, 48.575120380946565, 45.22274310248238, 38.43119512285505, 21.36943142754691, 7.548623698098319, 0.712028267128127, 1.5769535984311784, 1.5278119210686003, 1.985748256955828, 0.6184950917959213, 0.31424509201731, 0.21494103063430103, 0.16968292130955628, 1.1774426017488753, 1.7508058867284229, 8.670736057417733, 15.105675561087471, 27.605259009769984, 36.137052808489116, 36.27053812571934, 45.388144969940186, 23.31701496669224, 5.9661137121064325, 0.17265145773334162, 0.1218538156577519, 0.12477617098816804, 0.14208910055458546, 0.12340566595750195, 0.17807882864560398, 0.2919411302677223, 0.12417592533997127, 0.22181537747383118, 0.17801991823528493, 0.11648699721055371, 0.13904055128140108, 0.13974757120013237, 0.060306129711014886, 0.19713005636419567, 0.12596602285546915, 0.15207993159336702, 0.07670433300414256, 0.17567974595086916, 0.10974985693714448, 0.11075349165392773, 0.13545597291418485], [0.009427663088510079, 0.03908634139224887, 0.010704290254839828, 0.04353560068245445, 0.037769956314670186, 0.028170824882441332, 0.012797809970964278, 0.02525387577978628, 0.0449723375162908, 0.036917414383164475, 0.014676495322159358, 0.03185608936473727, 0.04527026527960386, 0.005251598112019045, 0.024771902178015028, 0.035285771757896454, 0.08266447604234729, 0.030135972558387687, 0.009420622439522828, 0.02730996920061963, 0.009960306292798902, 0.028160884344418134, 0.025455468533826724, 0.09201205588345017, 0.021831718339983906, 0.04476896021515131, 0.053778599082891426, 0.32637911662459373, 2.3641299988542284, 20.74824857711792, 32.33928905214582, 31.002108233315603, 28.9970509324755, 27.929755517414637, 12.234745042664663, 2.906681605747768, 0.03149385005235672, 0.09278276988438197, 0.2929157779685089, 0.5507711629782404, 3.1342655079705373, 0.5536207929253578, 0.26288799781884464, 0.06331296265125275, 2.399180620908737, 13.338951894215175, 27.25073412486485, 40.631891114371165, 48.80448389053345, 48.307350703648154, 46.783027103969026, 47.779103483472554, 47.492462498801096, 46.14339678628104, 44.849305221012656, 41.695806230817524, 36.563446385519846, 37.13326120376587, 36.27910525458199, 39.71713992527553, 44.843757084437776, 46.482698168073384, 46.44559131349836, 46.17067888804844, 48.551753589085166, 44.890945775168284, 43.520090511866975, 37.933311530521934, 36.013687542506624, 35.822761467524934, 35.49531371252877, 37.08761848722185, 35.42340680531093, 34.27613762446812, 34.64151906967163, 33.313610621861045, 33.379059178488596, 37.899793420519146, 44.44589628492083, 43.62071432386126, 37.08047226497105, 43.73980644771031, 46.92427355902535, 46.07528359549386, 45.06710345404488, 46.08699131011963, 44.04700367791312, 43.3664345741272, 43.23086132322039, 45.105016299656455, 36.42134877613613, 48.35588387080601, 44.49957806723458, 43.18306813921247, 40.73812212262835, 40.22732877731323, 37.232172284807476, 33.960918698992046, 31.614543301718577, 32.7688683782305, 32.45365987505232, 32.24156263896397, 38.23027059010097, 44.267171246664866, 44.26715040206909, 45.45980174200875, 45.10780252729143, 41.37195416859218, 34.10379450661795, 32.107924461364746, 32.371028423309326, 33.343202999659944, 33.192982946123394, 33.82774952479771, 32.32889802115304, 33.033837931496755, 30.815083571842738, 31.70112133026123, 32.022256646837505, 31.119939259120397, 34.78127861022949, 42.5099891935076, 43.1765889440264, 44.37685203552246, 44.722545760018484, 43.172228949410574, 44.67921331950596, 45.42168045043945, 44.085795470646445, 46.64182928630284, 45.82665967941284, 45.72397572653634, 37.84576422827584, 24.224837064743042, 8.162045410701207, 0.4415780236678464, 0.10012400309954371, 0.6855950398104531, 0.4784315675497055, 0.5572254966412271, 0.24516488026295388, 0.08054568259311573, 0.04852258540423853, 0.06921589161668505, 0.4430023772375924, 0.3151761234870979, 1.6269518584012985, 12.584934251649038, 23.74002824510847, 24.870355980736868, 28.748682362692698, 29.744070870535715, 10.819887706211635, 1.4067991631371635, 0.026292565311970453, 0.0580320195960147, 0.017416969340826784, 0.04972356524584549, 0.045989302053515396, 0.03377656059871827, 0.06887281074055604, 0.04295967372932604, 0.030784071888774633, 0.01087009792016553, 0.02120736094989947, 0.024317585663603883, 0.04946035133408649, 0.034612603951245546, 0.01191857023098107, 0.06241709286613124, 0.09662443838481392, 0.03710284782573581, 0.018030716139557104, 0.029991447992090668, 0.024775627335267406, 0.037829053322119374, 0.007902017811180224, 0.05343855804364596, 0.024110362765246203, 0.0510011279423322, 0.00924056553880551, 0.02314799145928451, 0.008384398533962667, 0.025964585232681463, 0.004166199501404273, 0.026448492659255862, 0.09505293092557363, 0.043162548914551735, 0.06992994115820952, 0.0338895502500236, 0.07132855110934802, 0.03631187276914716, 0.035457471651690345, 0.028397284248577695, 0.03427794369469796, 0.02626611940961863, 0.04407773319897907, 0.03158461428912623, 0.0364709960163704, 0.032579312699713876, 0.05857121744858367, 0.029668940297727073, 0.04916760418564081, 0.4715261438063213, 4.266944340297154, 26.085837364196777, 39.14326735905239, 36.934904030391145, 30.840732846941265, 29.879140377044678, 15.178334610802786, 2.688625203711646, 0.2670159605996949, 0.22433414017515524, 0.11859527336699621, 0.5069398092372077, 1.098186997430665, 0.6251634625451905, 0.3151274860969612, 0.5599866999047143, 3.076915511063167, 16.27561845098223, 30.59162950515747, 43.79385995864868, 49.322920254298616, 48.62204851422991, 47.62766054698399, 48.7935265813555, 50.43716812133789, 48.15741205215454, 47.74598489488874, 44.691452571323936, 37.812086309705464, 37.74263211659023, 37.61685235159737, 41.61037465504238, 46.73660618918282, 47.66706725529262, 48.62526900427682, 47.18182938439505, 48.922054358891074, 46.13302659988403, 44.09640189579555, 39.13274083818708, 36.52088172095162, 36.360906396593364, 36.588518960135325, 36.695972851344514, 37.69766684940883, 35.57236576080322, 36.64863477434431, 34.61976773398263, 34.99145119530814, 39.52181911468506, 45.33971949986049, 44.71676138469151, 38.64070068086897, 46.459168093545095, 48.744850976126536, 47.27981635502407, 47.742000102996826, 45.73540898731777, 44.955227034432546, 42.81783608027867, 45.4372478893825, 47.55614273888724, 39.871417726789204, 49.08404813494001, 44.60474252700806, 45.531639167240684, 41.404044423784526, 39.87166786193848, 37.84874847957066, 35.40546655654907, 33.62056119101388, 35.432078157152446, 34.12775536945888, 34.48147773742676, 39.94265760694231, 45.796598298209055, 46.53262792314802, 47.27742617470877, 45.89745487485613, 43.243646008627756, 37.00906910215105, 34.391418661390034, 33.740132740565706, 35.209833077022004, 33.87287112644741, 34.17912687574114, 35.26791654314314, 34.54622800009591, 31.866964408329554, 33.06135974611555, 32.61542783464704, 32.91355766568865, 36.81279638835362, 45.0640184538705, 45.17202125276838, 46.19096415383475, 45.46623577390398, 45.04640824454171, 44.209244115012034, 44.6954790524074, 46.55667216437203, 46.38440547670637, 44.66821084703718, 46.76997143881661, 40.09519141060965, 27.186612674168178, 10.488889421735491, 1.6312007904052734, 1.3018297957522529, 1.7465820333787372, 1.564853310585022, 0.6975370932902608, 0.3770475520619324, 0.026111291289063435, 0.09674054251185485, 0.047981453726866415, 0.28944116298641476, 0.9519176461866924, 1.8590335249900818, 12.866331083433968, 26.923903022493633, 31.235220296042307, 33.815680503845215, 33.692996161324636, 14.69093758719308, 1.9784242042473383, 0.028044524070407664, 0.01896259917079338, 0.0701771043241024, 0.031471899444503446, 0.047231991442718675, 0.027080771945683018, 0.03159664471500686, 0.02259773518224912, 0.05540497627641473, 0.027758155151137283, 0.03638110030442476, 0.012941162368016583, 0.07933234662881919, 0.05254134475918753, 0.030981243987168585, 0.02437181248595672, 0.08872496083910976, 0.027498554438352585, 0.03533337777480483, 0.02227257441596261, 0.04189105910648193, 0.011902287086871053, 0.09026466536202601, 0.18554329739085265, 0.11491897063595907, 0.1113764817959496, 0.17564767838588782, 0.07951099132852894, 0.045919765784804306, 0.10775550681033305, 0.07009914065045969, 0.11866985793624606, 0.23693351766892842, 0.13372284519885266, 0.17933873246823037, 0.11155596109373228, 0.190813044618283, 0.09083821744258914, 0.15771739051810332, 0.1373569294810295, 0.08290161046066455, 0.09967098597969327, 0.15241007959204061, 0.16021336801350117, 0.15960853546857834, 0.15211521541433676, 0.13419015226619585, 0.11524507456592151, 0.1595515249563115, 0.6994471965091569, 3.996193451540811, 28.945642948150635, 46.745055198669434, 45.450338295527864, 39.37382248469761, 38.434464250292095, 17.707240922110422, 4.434793710708618, 0.7804885964308466, 0.7009805770856994, 0.7817250500832285, 3.8881750191961015, 8.248622570719037, 1.3423370335783278, 0.8179613713707242, 1.0939146152564456, 4.180649016584669, 16.954872608184814, 32.59283924102783, 44.823235579899375, 50.455240385872976, 49.136760643550325, 48.34661497388567, 51.20963757378714, 53.0862626348223, 51.00294256210327, 49.536038875579834, 45.696335792541504, 39.261824471609934, 40.14592368262154, 39.836061818259104, 44.31601708275931, 47.95616790226528, 48.136584826878135, 49.225482191358296, 49.810753277369905, 51.445115498134065, 48.763732705797466, 46.814019543784006, 40.632259368896484, 38.942210810525076, 39.70834003176008, 37.688293729509624, 40.77424233300345, 39.367805344717844, 38.22210645675659, 38.58008459636143, 37.019619941711426, 37.07393053599766, 40.41036169869559, 46.61679145268032, 46.190363134656636, 39.70098188945225, 48.10639837809971, 50.33994197845459, 48.319503102983745, 49.01697022574288, 46.945552417210166, 46.346652439662385, 43.6920862197876, 46.23812157767159, 51.46000896181379, 40.73806306294033, 51.16708680561611, 45.87074947357178, 48.281402656010215, 44.01629958833967, 43.05924081802368, 41.56810528891427, 35.78601244517735, 35.277793407440186, 37.69291775567191, 36.28387519291469, 35.70391253062657, 42.06800733293806, 46.605392932891846, 50.48616681780134, 49.40183094569615, 48.160229546683176, 43.986950397491455, 38.11722687312535, 35.43671260561262, 36.203474112919395, 36.190150942121235, 36.681826319013325, 37.037532397678916, 36.23293447494507, 37.380273137773784, 34.02880259922573, 35.79947110584804, 34.25338922228132, 34.10603182656424, 37.66127565928868, 47.009086745125906, 47.020815304347444, 47.32707800183977, 46.13918270383562, 44.07719360079084, 45.38140869140625, 46.715737274714876, 46.49024738584246, 48.662594727107454, 47.25189849308559, 46.9107106753758, 40.96579374585833, 27.60031189237322, 13.094919000353132, 1.073212891817093, 0.5213110180837768, 1.4898859390190669, 3.051525490624564, 1.4416333053793227, 0.772683380969933, 0.24488632806709834, 0.21349280620259897, 0.23938552609511785, 1.2938039749860764, 2.4877784039293016, 3.4780106970242093, 15.822481257574898, 33.386097703661235, 36.40189382008144, 38.847430433545796, 38.65170315333775, 16.525484357561382, 2.2585403961794714, 0.06602273974567652, 0.13632513556097234, 0.22788994865758078, 0.12510710608746323, 0.1317026971706322, 0.11848073665584836, 0.147342481517366, 0.16069607782576764, 0.10774144077939646, 0.13457744648414, 0.11889450731022017, 0.10898562973099095, 0.10140815776373659, 0.1300401370972395, 0.13905120428119386, 0.18922342705939496, 0.2009565867483616, 0.11359438207000494, 0.12665548228791781, 0.0895897876471281, 0.1786465724664075, 0.09849021291094166], [0.02524398104287684, 0.040893487100090296, 0.031166358518281152, 0.06220758839377335, 0.024230522835361104, 0.04116127773055008, 0.04226736444979906, 0.04773022952888693, 0.07194835213678223, 0.01747748109378985, 0.03478569484182766, 0.03381654327469213, 0.050070116828594885, 0.028901001505021538, 0.0037873818821805927, 0.09281203509973628, 0.047353367786854506, 0.07324182308678116, 0.0307784162993942, 0.011060051254129835, 0.010015727336784559, 0.051730587014130185, 0.008934553030745258, 0.010477344039827585, 0.015603472545210804, 0.0696196945916329, 0.06294552236795425, 0.015945837566895143, 1.4126497634819575, 12.582326071602957, 26.39520069531032, 34.52855525697981, 26.70060702732631, 22.67184693472726, 19.551907743726456, 9.203346746308462, 0.6758881892476762, 0.35559325186269625, 0.03204387393114822, 0.11398975764002119, 0.25632534282548086, 0.5424709426505225, 0.31732330684150967, 0.6649946623614856, 0.021683041139372757, 1.993489852973393, 13.695302418300084, 30.984619617462158, 43.02188035420009, 49.25946235656738, 46.58543075834002, 49.63276474816458, 46.75486952917916, 46.69618851797921, 43.2571394102914, 40.11554963248116, 36.23061030251639, 37.04086058480399, 36.58267552512032, 42.069469928741455, 44.98726517813546, 48.03107990537371, 47.84656701769148, 46.74520458493914, 46.292935916355674, 47.00498383385794, 44.19924218314034, 43.16884865079607, 39.53895337241036, 40.10595417022705, 39.09780876977103, 39.778086049216135, 36.87648705073765, 37.18968752452305, 34.13226127624512, 33.89458424704415, 32.45030736923218, 37.68262052536011, 42.40317106246948, 43.598049300057546, 36.83500630514962, 42.629112584250315, 46.821280411311555, 44.7786420413426, 47.39880425589425, 48.854827063424246, 47.65209041322981, 46.47313397271292, 40.668876375470845, 33.03650256565639, 36.34429325376238, 49.116756779806956, 47.632228987557546, 44.80251605170113, 43.18013947350638, 43.99639647347586, 41.93551213400704, 35.66661460059029, 31.989318711417063, 33.418743814740864, 32.919797148023335, 32.26398794991629, 40.34528487069266, 42.5652516910008, 44.588508061000276, 43.83889470781599, 41.54345308031355, 36.49960286276681, 32.45183597292219, 35.69179834638323, 35.34718854086739, 38.579580851963584, 39.28611189978463, 40.53177452087402, 42.97030735015869, 39.61411551066807, 36.72190352848598, 32.17707640784127, 32.546605927603586, 33.268325737544465, 34.07399368286133, 41.46784973144531, 43.29190124784197, 44.05013036727905, 45.59869623184204, 46.51397548403059, 44.45481777191162, 43.094402176993235, 41.831858907427105, 41.25230271475655, 43.33866957255772, 40.185045514787944, 28.06833733831133, 11.870054943220955, 1.0482646248170306, 0.8814634553023747, 3.496660530567169, 1.5910944853510176, 1.4046722544091088, 0.4062001848859446, 0.05065039319119283, 0.048213353247514794, 0.025505099977765764, 0.053082374656306844, 0.1915567461401224, 0.20010951720178127, 2.8754837598119463, 16.05306417601449, 24.36991892542158, 23.794415269579204, 27.70370282445635, 23.516879899161204, 6.224611018385206, 0.0981616187574608, 0.04625970843647208, 0.019380298542923162, 0.010989771141404552, 0.06772090255149774, 0.0027190091994790627, 0.06283175918672766, 0.026232608261385133, 0.04128456415076341, 0.040566572320780585, 0.006694708086018051, 0.015163142333871551, 0.049446054601243565, 0.04359279439917632, 0.049780151673725674, 0.02845445760924901, 0.02399952237361244, 0.021352123003453016, 0.016838659033445374, 0.10064445302954741, 0.028386648212160383, 0.04810098784842661, 0.0066255042994660986, 0.025073410909889, 0.019855608930811286, 0.03682508612317698, 0.02411187080932515, 0.019991877422268902, 0.051130558497139385, 0.028755543953073875, 0.04216953666348543, 0.07707663159817457, 0.022586999061916555, 0.06885200685688428, 0.07960463594645262, 0.08607458948556866, 0.028275914689792053, 0.014305943955800362, 0.052666059495615106, 0.045572644232639244, 0.05591280884774668, 0.03957401129550167, 0.032394761352666786, 0.01764454659340637, 0.022275704158736125, 0.06097874790430069, 0.10056062681334359, 0.03876833238505891, 0.06449978146702051, 0.03955837445599692, 0.04985437661941562, 1.8427304455212183, 15.731015171323504, 34.48205096381051, 40.35809734889439, 31.991191250937327, 31.455537251063756, 20.469686610358103, 8.556233218738011, 0.7644076964684895, 0.3987419722335679, 0.004345413746445307, 0.19338839714016232, 0.37549927085638046, 0.2661416546574661, 0.18059628855969223, 0.3489227912255696, 0.39060720588479725, 3.5144062297684804, 16.900292771203176, 34.523406641823904, 45.966370582580566, 49.43615157263619, 48.55560289110456, 51.84824650628226, 48.485287121364046, 46.85318306514195, 46.74528796332223, 40.350443908146445, 37.48848785672869, 38.15396894727434, 38.49253729411534, 43.69944783619472, 46.781637464250835, 48.51841960634504, 49.6753328868321, 46.90756661551339, 47.96111849376133, 47.588236468178884, 45.11218336650303, 45.12467622756958, 40.45997878483364, 41.07228878566197, 40.13211761202131, 40.74984720775059, 39.45542907714844, 37.97012308665684, 35.90004628045218, 36.86440065928868, 33.93765613010952, 38.75702742167881, 42.6637840952192, 45.05690697261265, 38.26417779922485, 43.88472849982125, 47.35182401112148, 46.920677866254536, 49.20862933567592, 49.37562581471035, 48.11637599127633, 47.656933307647705, 39.629467555454795, 35.899382727486746, 38.06389250074114, 48.49081441334316, 49.17558717727661, 45.96851757594517, 45.139430727277485, 45.08007574081421, 42.926669188908164, 37.57793549128941, 32.5828720501491, 34.676663058144705, 34.2155875478472, 33.6439140864781, 41.29480831963675, 45.985877650124685, 46.48761054447719, 46.084132126399446, 43.519902910505024, 38.30208369663784, 34.7253178187779, 36.12413610730852, 36.02319962637765, 39.44712597983224, 39.57492419651577, 42.96060766492571, 42.60972363608224, 41.429724965776714, 38.238375663757324, 33.906826972961426, 33.08584172385079, 32.95868274143764, 35.21684728349958, 42.90335103443691, 44.303176811763215, 45.20357649666922, 45.72710936410086, 45.78919499261038, 44.8511187008449, 44.822429588862825, 43.57604782921927, 44.62551416669573, 44.120803969247, 41.263947895595, 29.710844584873744, 13.609826547758919, 2.4591357580253055, 1.7741203499691827, 4.400585123470851, 2.841988665716989, 1.5365731652293886, 0.7076909084405217, 0.2530654434646879, 0.04419004770794085, 0.09253288579306432, 0.04132518804232989, 0.4280217896614756, 0.20639667340687343, 2.8426298541682105, 17.435170309884207, 28.917844942637853, 31.283451216561453, 32.963956424168174, 29.621146815163748, 8.732974546296255, 0.4199149246726717, 0.054506059869059494, 0.04917974656979952, 0.01304522080213896, 0.022065249737352133, 0.017051807238853404, 0.09078506100922823, 0.03229533222370914, 0.05050214686031852, 0.027540453975754123, 0.04553307207035167, 0.055196672811039856, 0.02927241800352931, 0.026221665187871883, 0.04637161921709776, 0.04513899250222104, 0.04188631953937667, 0.02807550597935915, 0.015077599424070545, 0.042214357294142246, 0.04921377170830965, 0.020587334309571555, 0.08035165550453321, 0.13747855009777205, 0.08366427025092499, 0.234832230423178, 0.18709372276706354, 0.08016565548522131, 0.1589034561600004, 0.14524314845246927, 0.10679350021694388, 0.18192343520266668, 0.12020161002874374, 0.12133764049836568, 0.09918154510004179, 0.14693655472780975, 0.06681055282907826, 0.13147917416478905, 0.26103139030081884, 0.16671137219028814, 0.17630789295903274, 0.07999405397900514, 0.1486945982490267, 0.11552725013877664, 0.21617808139749936, 0.14955314860812255, 0.21583367059273378, 0.10794776292251688, 0.11656257244093077, 0.11363830364176206, 0.1981894802302122, 2.6830900950091223, 17.34000083378383, 41.31305776323591, 49.48512247630528, 39.26566335133144, 34.50889532906668, 26.69455862045288, 10.518074461391993, 1.72598312156541, 1.5700995262180055, 0.35018597915768623, 0.6019457312566894, 1.0857681781053543, 1.2448126609836305, 1.45492379793099, 1.554286620446614, 0.516790400658335, 2.906465994460242, 16.853746788842336, 35.41271700177874, 46.0566520009722, 49.131341048649375, 50.50470808574131, 52.366787093026296, 50.62873690468924, 49.78272077015468, 47.24816383634295, 41.800713607243125, 39.318573883601594, 39.44586140768868, 39.83592980248587, 45.79662609100342, 48.935037067958284, 51.73974691118513, 51.44490705217634, 47.42394283839634, 47.801157065800254, 48.760807514190674, 48.01828827176775, 46.99109785897391, 42.08848367418562, 41.72775752203805, 42.02821499960763, 42.90024518966675, 41.64135667255947, 41.74014616012573, 38.267763069697786, 37.35317863736834, 35.43092475618635, 40.118770122528076, 43.88647597176688, 45.90166548320225, 39.2267986025129, 45.21523209980556, 48.63623673575265, 48.60021727425711, 51.23268474851336, 52.56552989142281, 50.87997334344046, 49.41289595195225, 43.1535313470023, 40.705927644457134, 40.60835756574358, 49.86166272844587, 51.67682749884469, 48.15701947893415, 48.55661732809884, 47.103603090558735, 46.12762090138027, 39.42408575330462, 35.08845499583653, 35.80083990097046, 36.38752841949463, 34.83862556729998, 43.20937749317714, 47.62459291730608, 46.75105149405343, 47.03693512507847, 45.17127084732056, 39.215407030923025, 35.89880950110299, 38.60879455293928, 38.8588775907244, 42.44431134632656, 42.83569989885603, 46.217346463884624, 46.494583061763215, 43.78206539154053, 41.43583243233817, 36.888212135859895, 35.634281158447266, 35.713059834071565, 36.93703017915998, 43.90165778568813, 46.341781752450125, 45.36906174251011, 47.89746952056885, 46.954623290470664, 45.81350326538086, 44.72864280428205, 45.33315692629133, 44.77801322937012, 44.07889938354492, 42.10224805559431, 30.4763172013419, 14.309355548449926, 2.058805308171681, 2.228719813483102, 7.268727677209037, 4.45375577892576, 2.109818765095302, 0.9688381382397243, 0.24838862727795327, 0.17582996003329754, 0.25045981471027645, 0.12085897475481033, 0.7905183753796986, 0.4919073273028646, 4.2518089924539835, 22.577872548784526, 35.08893442153931, 34.08287000656128, 39.109648500170024, 32.88575097492763, 9.617738178798131, 0.41597627316202435, 0.264165000723941, 0.23202542960643768, 0.13453668010021957, 0.17496261586036, 0.10372118186205626, 0.26800008064934183, 0.12273310204701764, 0.17387712267892702, 0.07358918551887784, 0.08919220005295106, 0.1438336819410324, 0.1880490593612194, 0.11879724610064711, 0.2213708691831146, 0.11299087266836848, 0.11480074269430977, 0.051179331594279835, 0.09367404598742723, 0.1576325057872704, 0.1335028912872076, 0.12241401416914803, 0.08486598291035209], [0.05544203446645822, 0.004171301660660122, 0.0062147857804250506, 0.012415770158570791, 0.08137485238590411, 0.02538418334110507, 0.003931896270452333, 0.017828307447156737, 0.01629883692865925, 0.07637100267623152, 0.04750695758100067, 0.05092979694849678, 0.03475793936688985, 0.06904500257223845, 0.007002195135490703, 0.025657733037535633, 0.03557958420632141, 0.051965139606701474, 0.04402928579864757, 0.02510612817215068, 0.06527695512132985, 0.03194973737533603, 0.0756627478237663, 0.059740217934761725, 0.06229646291051592, 0.05598990060389042, 0.0662710021382996, 0.016741893154435923, 0.5158434371863092, 4.458360263279506, 18.28613703591483, 31.73470892224993, 29.020080736705236, 21.920736244746617, 35.265856402260916, 15.71383227620806, 2.774544890437807, 0.46219536449228016, 0.2632116861641407, 0.05181206549916949, 0.10857552316571985, 0.06694545237613575, 0.037892808472471576, 0.0728227598592639, 0.13243981690279075, 0.6478434141193117, 2.9845811171191077, 16.43674370220729, 33.86421367100307, 46.02182762963431, 49.53249876839774, 52.22094440460205, 48.431066853659495, 47.33815690449306, 42.02621391841343, 39.334360190800254, 37.31851407459804, 36.78280101503645, 40.3756867136274, 41.88066305433001, 42.10890442984444, 45.60982377188546, 47.52201666150774, 48.38841186250959, 45.71339362008231, 46.319332122802734, 45.545806544167654, 43.847381932394846, 44.5747332572937, 44.800066811697825, 43.45548268726894, 44.01108496529715, 43.303918157305034, 41.55344458988735, 36.58270331791469, 33.187709263392854, 34.480796813964844, 35.34554876599993, 37.78651693889073, 37.79122086933681, 34.8084009034293, 35.64875078201294, 42.499042306627544, 43.45719541822161, 44.680074896131245, 46.134065355573384, 47.918939454214915, 46.29790735244751, 47.8008965083531, 37.638033935001914, 38.11809887204851, 47.809175286974224, 45.80102777481079, 47.91955784388951, 45.00775194168091, 45.27852324077061, 43.01179504394531, 36.88007926940918, 30.964032105037145, 33.82626608439854, 32.46932111467634, 32.58631835665022, 37.0318591935294, 42.02179833820888, 44.87403733389718, 42.566273076193674, 39.38174343109131, 36.32810395104544, 35.387547152382986, 37.42257029669625, 40.11206858498709, 42.60043042046683, 43.271720205034526, 44.28514971051897, 45.69862174987793, 44.28291239057268, 43.23309516906738, 38.72960288184029, 30.605303559984478, 32.4814908845084, 32.543156147003174, 39.093775340488975, 42.77680001940046, 43.27133110591343, 44.9928480557033, 45.06845487867083, 46.10473700932094, 44.231592995779856, 42.48945379257202, 43.86458567210606, 41.497831208365305, 29.24399859564645, 15.250873804092407, 2.899333885737828, 0.6795591722641672, 1.9596037055764879, 3.2761931036199843, 3.042307185275214, 1.3748842413936342, 0.8541932414684976, 0.7242151903254646, 0.04079032263585499, 0.02456059619518263, 0.01868136676161417, 0.047016308909015994, 0.7255925621305193, 7.257964049066816, 20.963465554373606, 21.45408480507987, 25.147882665906632, 24.362345388957433, 11.60531120640891, 2.253550721066339, 0.038723348905997615, 0.01173287385609001, 0.012821858100193952, 0.014429067527609212, 0.01779365466375436, 0.1335569162453924, 0.029122332842754464, 0.04573483106547168, 0.006057294834006045, 0.05088063030104552, 0.11122248148811714, 0.07624335666852337, 0.06112229198749576, 0.009018330901329006, 0.01664843682997993, 0.09323791081884078, 0.006606628303416073, 0.024970375367307236, 0.04651303609300937, 0.011645704158581793, 0.02319454405057643, 0.03403787121974996, 0.028237579157575965, 0.06709145275609833, 0.06879306251981429, 0.006519551480388535, 0.03461617983079382, 0.033013588682349236, 0.015426123847386666, 0.017115604797644273, 0.03137198855568256, 0.023704977107367346, 0.02578328237203615, 0.08837780875286885, 0.06400327025247471, 0.014145127763705594, 0.022380846552550793, 0.04525290496115174, 0.0029653036285058726, 0.04002890117200358, 0.03819246989275728, 0.05488003783726266, 0.06503338819103581, 0.04450698123712625, 0.0013074606457459076, 0.012666615225108606, 0.039046019448765686, 0.04313556696953518, 0.019647185025470595, 0.04968085825177176, 0.10254257332001414, 0.7890567566667284, 7.091140406472342, 24.304878575461252, 37.207672936575754, 33.23243829182216, 25.863125017711095, 34.43239218848092, 15.266762597220284, 3.843171536922455, 0.7128651450787271, 0.1791641725493329, 0.1534667078937803, 0.020281126722693443, 0.08753907840166773, 0.10067124837743384, 0.15807381139269897, 0.3079436187233244, 1.0661634015185493, 4.9127824391637525, 19.969331196376256, 36.901684692927766, 45.783698967524934, 51.275833061763215, 52.80789000647408, 50.94341387067522, 49.13390840802874, 44.52426501682827, 40.79459360667637, 39.92776066916329, 38.413275718688965, 41.175935064043315, 42.698761326926096, 45.016812392643516, 47.85358469826834, 49.719360147203716, 47.86180094310215, 46.54350880214146, 46.84608548028128, 47.23526103155953, 45.269942215510774, 45.25978742327009, 46.543581758226665, 44.76471785136631, 45.6427686555045, 44.74898712975638, 42.41115801674979, 38.859287534441265, 34.221670695713584, 35.52579893384661, 36.901785441807334, 40.2033748626709, 40.17577314376831, 36.30451481682913, 38.41413034711565, 44.39319767270769, 45.51515456608364, 46.52131625584194, 47.989161423274446, 50.281549317496165, 48.39161845615932, 49.08004944665091, 38.626557622637065, 38.73400109154837, 48.892840657915386, 47.37230382646833, 48.07923786980765, 45.71371323721749, 47.432864325387136, 43.724051407405305, 38.04761981964111, 32.49235091890608, 33.84891721180507, 32.88388190950666, 34.667383738926475, 38.11113330296108, 43.45673336301531, 46.9655111176627, 44.160742214747835, 40.869088717869346, 38.07425921303885, 37.20786401203701, 39.26148400987898, 41.024009227752686, 43.49798829214913, 44.266406944819856, 45.534394127982004, 46.80141551154, 45.239491735185894, 44.51073340007237, 38.64599173409598, 32.71866416931152, 34.36465072631836, 33.632077830178396, 41.31434317997524, 43.36419030598232, 44.92855984824044, 45.513691970280235, 46.97126422609602, 46.4552458354405, 43.790260791778564, 44.16930934361049, 44.958357197897776, 42.669130734034944, 31.05241666521345, 17.70720965521676, 3.5439304283687045, 2.8357361555099487, 5.2469682097435, 8.031789268766131, 3.0559015529496327, 1.253519622342927, 0.9785047109637941, 0.9279707883085523, 0.028742651787719557, 0.0651910322319184, 0.025751618535390923, 0.015802614091496383, 0.7676391516413007, 7.211760265486581, 24.641174861363, 26.116220099585398, 29.217817783355713, 30.036895751953125, 17.854829345430645, 3.2965324350765774, 0.0586665380480034, 0.03915915837777512, 0.03533516910725406, 0.01444525906949171, 0.04264905736116426, 0.04630230686494282, 0.020852668643263832, 0.04805707645469478, 0.019713438881028975, 0.03311829681375197, 0.022038445907777975, 0.05204949847289494, 0.0024983400695158964, 0.04487960892064231, 0.055551607693944655, 0.018538343454045907, 0.014991551005680646, 0.020446285538907562, 0.04377842800957816, 0.008849236582006727, 0.045317772908934524, 0.028971392727856125, 0.06801498641393014, 0.19628567381628922, 0.22338055420134748, 0.11020981547023569, 0.09657004023236887, 0.10829954940293517, 0.13722380091037067, 0.15760140174201556, 0.11038096914333956, 0.060641068166920116, 0.2004970692630325, 0.14953246686075414, 0.26049366486924036, 0.09252546261996031, 0.16479839198291302, 0.12430822609790734, 0.09316515150879111, 0.128956190975649, 0.12720228651804583, 0.08910209060247455, 0.13935133389064244, 0.16454426704772881, 0.1567732768931559, 0.1276332919618913, 0.2216756942548922, 0.1132297712777342, 0.14065509821687425, 0.21907770580479077, 0.1694139771695648, 0.7248269032154764, 6.836700848170689, 27.802949156079972, 44.659834793635774, 40.848747866494314, 31.667651857648575, 41.7225672176906, 18.438637835638865, 5.614108851977757, 2.3076650287423814, 0.6726318182689803, 0.5200691361512456, 0.24232165568641253, 0.4649769780891282, 0.4485410414636135, 0.3916468300989696, 1.1626619377306529, 1.8939681989806039, 4.619212797709873, 20.048796006611415, 36.65701082774571, 47.28326613562447, 51.55233662469046, 56.42450727735247, 54.80564648764474, 51.56174101148333, 45.201325280325754, 42.483565194266184, 42.2018643787929, 40.217879227229524, 44.70589440209525, 44.69782059533255, 46.71429552350725, 48.93047210148403, 51.72379037312099, 50.249872480119976, 47.703263895852224, 48.10346276419503, 48.188637256622314, 48.10299028669085, 48.32535696029663, 48.04848166874477, 46.27399860109602, 48.132916178022114, 47.95078999655587, 45.3727581841605, 40.20958307811192, 35.799738611493794, 37.3746520451137, 39.82861682346889, 41.36193486622402, 41.892169271196636, 37.458898953029085, 38.63553816931588, 45.084790093558176, 45.897691113608225, 48.18021603993007, 51.075009277888704, 52.598940304347444, 50.46402638299124, 50.31008904320853, 41.216331890651155, 42.03756032671247, 48.03362989425659, 49.265218939099995, 49.57015800476074, 48.2562050138201, 49.44686222076416, 47.49533210481916, 39.519953523363384, 34.77587291172573, 36.2726469039917, 35.27850212369646, 36.24316917146955, 39.664823463984895, 43.41458559036255, 48.10207659857613, 46.10614749363491, 44.61329228537423, 39.51338052749634, 38.29981858389718, 41.687659467969624, 44.14695698874337, 45.94884722573416, 46.4397930417742, 47.35362359455654, 48.385385922023225, 46.35811349323818, 47.13860464096069, 42.18161732809884, 34.54328891209194, 36.18588474818638, 35.07481568200247, 43.29091460364205, 45.307347842625205, 46.97558947971889, 47.20671088354928, 45.27525758743286, 47.03517375673567, 45.10940408706665, 46.38159493037632, 44.930130141122, 44.71713311331612, 31.581723485674175, 18.352539232798986, 3.6179845460823605, 2.400243043899536, 5.373027205467224, 10.126002379826136, 12.745182292801992, 2.4920995320592607, 2.953618858541761, 1.8375974638121468, 0.11291573170040335, 0.18164693218256744, 0.15445941819676332, 0.1669024612222399, 1.1858621899570738, 9.509462663105555, 27.647674288068497, 30.780071599142893, 35.23351601191929, 35.797699315207346, 19.317298344203405, 3.624588591711862, 0.14842011726328305, 0.13541980699769088, 0.1521217564919165, 0.2949977676783289, 0.16355739214590617, 0.14063727988728456, 0.1432020744042737, 0.09953358942376715, 0.08925822151026555, 0.14306710021836416, 0.21646930862750324, 0.14896696220551217, 0.1807634388761861, 0.13301955722272396, 0.15445331138159546, 0.16748724984271185, 0.1072171503411872, 0.07647592454616513, 0.11455279242779527, 0.11410588212311268, 0.11022405792027712, 0.15336019146655286, 0.19668723084032536], [0.021721417383689965, 0.0454043845113899, 0.029819836307849203, 0.09178765756743294, 0.03564383129456213, 0.05522673869771617, 0.04143410648352333, 0.02622070336448295, 0.03153212621275868, 0.038860158529132605, 0.04277187559221472, 0.013923580142935472, 0.046209042226629596, 0.07812070700206927, 0.028721922542899847, 0.061846695973404815, 0.03777162211814097, 0.03965614117415888, 0.01313515892252326, 0.03054529880838735, 0.025894261863348738, 0.028870694738413607, 0.023244077106937766, 0.05793732324881213, 0.03746202355250716, 0.051850467188549895, 0.0498723102999585, 0.06245490083737033, 0.04085857308070574, 1.6795082496745246, 10.421557903289795, 28.47572238104684, 32.16704320907593, 26.58687891278948, 37.71192455291748, 18.382793426513672, 2.3384116760322025, 0.33568500727415085, 0.22871461297784532, 0.16223504953086376, 0.08043544779398612, 0.07619755555476461, 0.09707434102892876, 0.0374078357459179, 0.3535473330744675, 0.27206550964287346, 0.4292835390993527, 4.0173468078885755, 20.561074529375347, 39.75536891392299, 50.594843591962544, 49.73017154421125, 49.418902669634136, 48.01343495505196, 46.55363232748849, 45.308824334825786, 42.72721767425537, 40.796052728380474, 38.423215116773335, 38.76828350339617, 40.56864513669695, 45.17744084766933, 46.09796251569475, 46.08703299931118, 47.752922671181814, 44.68423686708723, 47.055580615997314, 46.69367674418858, 46.01278107506888, 45.2052892276219, 45.61742510114397, 47.22734355926514, 45.56038039071219, 43.68159096581595, 43.89581782477242, 38.30115263802664, 33.95272329875401, 34.35978698730469, 32.91978325162615, 34.55189078194754, 34.20514440536499, 34.044620173318044, 34.47183016368321, 38.38821356637137, 42.372508662087576, 43.202252115522114, 42.915555545261924, 42.71980742045811, 48.48700680051531, 43.159093379974365, 34.91690744672503, 43.58809947967529, 43.20992292676653, 46.72418975830078, 45.00865173339844, 43.28458479472569, 43.32625661577497, 35.30548892702375, 31.886308193206787, 32.399248531886506, 32.35553394045149, 33.082242556980674, 34.89586482729231, 41.79252168110439, 42.04822928564889, 40.120680877140586, 35.69708939961025, 35.05747992651803, 36.607761996132986, 40.388509614127024, 40.256650175367085, 42.35805293491909, 44.57900987352644, 45.19334527424404, 45.099555015563965, 46.31135906491961, 44.004049914223806, 41.90793125970023, 35.21155623027256, 31.640883922576904, 34.70658547537667, 36.450079577309744, 43.66666970934187, 42.34808921813965, 45.44847617830549, 43.54429108755929, 44.485681670052664, 43.67101928165981, 42.42021499361311, 41.7125027520316, 30.746345043182373, 16.364968810762676, 4.193255220140729, 0.3455488165574414, 1.791484983904021, 3.6774743710245406, 5.385209134646824, 0.7479473054409027, 1.418731825692313, 0.32020990337644306, 0.2638629169336387, 0.11240061505564622, 0.06243535224348307, 0.05056441601897989, 0.04901705762105329, 1.2721581650631768, 9.903620941298348, 18.278422798429215, 18.851320879799978, 27.052882432937622, 22.736802169254847, 5.657414368220738, 0.32339624954121454, 0.04360163910314441, 0.02943445895133274, 0.049620292216007195, 0.017626405959682803, 0.037034858616867235, 0.03850513543667538, 0.01624062201673431, 0.03755564781438027, 0.06313926447182894, 0.025552687334961126, 0.044001679601413865, 0.017250925036413328, 0.026298399016793286, 0.03679637052118778, 0.04665550809087498, 0.01650167309812137, 0.0454633254557848, 0.01025696943647095, 0.022784602030047348, 0.009260608615087611, 0.05159724470494049, 0.040522348800940175, 0.04331661707588604, 0.016816102833087956, 0.026357538432681134, 0.0488014768676034, 0.1509374278996672, 0.06017598669443812, 0.08341267625136034, 0.06037784407713583, 0.030893719755113125, 0.068265169060656, 0.04178864103076713, 0.03738135591681514, 0.028799194110823528, 0.017979997343250682, 0.01593574944750539, 0.02974662577201213, 0.07680278843534843, 0.09545847095016922, 0.10721119280372347, 0.06036381197295018, 0.027939870221806423, 0.045437144182090244, 0.027163222432136536, 0.043476595277232785, 0.05355343062962804, 0.0232828655612788, 0.052746818733534644, 0.020260110796828355, 0.03760582208633423, 0.0887602853721806, 2.7145587035587857, 15.712918588093348, 35.8019585609436, 37.56912864957537, 30.168518951960973, 40.929089886801584, 25.276014396122523, 4.683885327407292, 0.22227834191705498, 0.39139878483755247, 0.18068989925086498, 0.036893713154963086, 0.014443918962829878, 0.05346089541645987, 0.1263099451150213, 0.5582929136497634, 0.08840718931917634, 1.1939184090920856, 6.605043130261557, 24.367608649390085, 41.37866265433175, 52.65988295418875, 50.63554613930838, 50.510051250457764, 49.05906588690621, 48.330085209437776, 45.80199704851423, 44.02614518574306, 41.232625416346956, 39.72464050565447, 40.62022508893694, 42.72889913831438, 46.490302971431184, 48.85898208618164, 49.34465421949114, 48.93059022086007, 44.65327569416591, 46.87263107299805, 47.23076902117048, 47.069591658455984, 47.15995992933001, 47.75304079055786, 48.18835238048008, 46.111726897103445, 44.936994961329866, 43.977921213422505, 37.98716006960188, 35.69885771615164, 35.73358481270926, 33.81245306559971, 36.3754871913365, 34.94955703190395, 35.760359695979524, 36.90522827420916, 40.58475106103079, 45.62227494376046, 46.19506706510271, 46.18955714362008, 44.99803836005074, 49.49092422212873, 44.86799587522234, 37.74273633956909, 44.5014888218471, 44.810801778520855, 48.248061725071494, 47.80659055709839, 45.38417754854475, 44.12138761792864, 36.86598832266671, 32.47632489885603, 33.39762823922293, 33.72124753679548, 35.0452059337071, 36.96380506243025, 43.49080385480608, 42.91436045510428, 42.58718020575387, 38.16319962910244, 36.649941035679404, 37.9873685155596, 41.81071206501552, 42.66256468636649, 44.52390023640224, 46.84736394882202, 46.744391645704, 47.095748152051655, 47.21785926818848, 45.59142146791731, 44.003122329711914, 35.5113571030753, 33.797973019736155, 35.351916790008545, 39.47407456806728, 46.389863286699565, 44.24627801350185, 46.7463093485151, 44.461158003125874, 43.62113468987601, 43.71542869295393, 44.25600896562849, 42.12706354686192, 32.32266548701695, 18.823000022343226, 4.896978327206202, 1.4567689789193017, 3.9242787275995528, 7.038965080465589, 6.96221831866673, 4.855574446065085, 1.154077872633934, 1.3602641459022249, 0.8461261114903859, 0.22244731070739882, 0.12729516439139843, 0.0808583108176078, 0.17486546321638993, 1.5734514892101288, 11.490890877587454, 23.623779671532766, 24.096839087350027, 32.28606932503836, 26.95495625904628, 8.342216542788915, 0.5581525383251054, 0.023041573419634784, 0.06114326550492218, 0.05577001115307212, 0.018653158364551406, 0.010269946418702602, 0.029814116257641996, 0.021320881554856896, 0.06658238864370755, 0.030353385356387923, 0.06850807102663176, 0.013465925236232579, 0.028245791127639155, 0.04100680923355477, 0.03567593617896948, 0.03111205536073872, 0.0615053250055228, 0.06201246886381081, 0.016003653839496628, 0.03228680982387491, 0.011247231924374188, 0.03884997711117778, 0.020792784535193017, 0.046735361484544616, 0.15434166522962706, 0.0854080238246492, 0.09134466919515814, 0.26475980452128817, 0.18011132601116384, 0.19251808098384313, 0.10707048499690634, 0.1229852456599474, 0.16283544445676462, 0.1516300764467035, 0.08726579842290708, 0.08580793200859002, 0.11463930564267294, 0.1660872692508357, 0.09412565853978906, 0.29645661796842304, 0.14480752897049698, 0.15890815162232944, 0.09475941703255687, 0.09472520529691662, 0.07871088319058929, 0.13900011059428963, 0.11067673577261822, 0.15787946539265768, 0.13527959452143737, 0.15471263389502252, 0.13686797714659146, 0.10014004366738455, 0.2529798394867352, 2.8904304206371307, 16.728467294148036, 39.88178791318621, 45.63236025401524, 38.258098125457764, 46.15853343691145, 25.509204626083374, 7.9459147453308105, 2.0408550713743483, 0.5539954528212547, 0.6603050082921982, 0.48569943755865097, 0.32787650770374704, 0.2870883563799517, 0.3478768973478249, 1.0598377180950982, 2.373395638806479, 1.3102467783859797, 5.574493263448987, 23.89836379459926, 42.80261605126517, 53.03898361751011, 52.743775503976, 52.66803319113595, 52.40673228672573, 50.381304604666575, 48.68406466075352, 46.68754843303135, 44.8192264693124, 42.72890261241368, 41.97141695022583, 44.605204582214355, 49.385287284851074, 50.38519212177822, 50.871736254010884, 49.80409690311977, 44.723865917750764, 48.32632623400007, 49.60873440333775, 49.44952685492379, 49.48700891222273, 49.64642490659441, 50.92355244500296, 48.575860364096506, 48.51343774795532, 46.476576805114746, 41.3732465335301, 37.03884908131191, 38.058545861925396, 34.72226408549717, 37.88754027230399, 37.79284674780709, 38.08611978803362, 37.589962823050364, 41.22663606916155, 46.64412566593715, 47.282515730176655, 47.21524327141898, 46.09671878814697, 51.88029159818377, 46.30194425582886, 41.44866575513567, 46.47031300408499, 46.770506450108115, 49.15587861197335, 48.67077970504761, 46.25265026092529, 48.42062023707798, 38.20488882064819, 35.02501794270107, 34.357167516435894, 35.83337484087263, 36.02399519511631, 37.91977643966675, 44.8888578414917, 44.806771823338096, 45.79473965508597, 39.25557804107666, 38.22677217211042, 39.889632429395405, 44.85036482129778, 44.601362228393555, 46.51085574286324, 48.82045085089547, 48.59098311832973, 49.15740026746477, 49.620365687779014, 48.06780113492693, 46.08753326960972, 38.11812319074358, 35.39485665730068, 37.35715995516096, 39.56871945517403, 48.489907673427034, 46.54694468634469, 48.96047094890049, 44.41164861406599, 44.35370063781738, 44.38986253738403, 45.42123229163033, 43.199267864227295, 33.49936376299177, 18.852493388312205, 5.1939990520477295, 0.976228090269225, 3.594267087323325, 8.475581135068621, 14.14193262372698, 7.393463475363595, 3.0723472876208167, 2.627757029873984, 1.3859923481941223, 0.47545643576553887, 0.4021985653255667, 0.23290475670780453, 0.38383328222802704, 2.2445816823414395, 13.24602494921003, 27.85226399557931, 28.80145914213998, 38.855281897953574, 31.047983714512416, 9.915093285696846, 0.652006633579731, 0.1762001687394721, 0.22827940061688423, 0.118595884048513, 0.12880117286528858, 0.10724181508911507, 0.12865370006433555, 0.06295967660844326, 0.14648630603083543, 0.1291601721729551, 0.1640159325408084, 0.13958873972296715, 0.14996587431856565, 0.10224622993596963, 0.16908452127661022, 0.09274146745779685, 0.1418137103319168, 0.13325020484626293, 0.06307485792785883, 0.11933353303798608, 0.0610771897648062, 0.08683739855353322, 0.14131105159010204, 0.19297310656734876], [0.04417841083237103, 0.04001089285260864, 0.03442641733480351, 0.024389576532744935, 0.013595179371934916, 0.027616460075868026, 0.017485248623415828, 0.04533684652830873, 0.02637749584391713, 0.03847578201176865, 0.037866281145917516, 0.030942231616271392, 0.013514848459245903, 0.010412548186390527, 0.02365220574262951, 0.038052379552807124, 0.06626933294215373, 0.020084570394828916, 0.053245491082114835, 0.0592984441401703, 0.06669759710452386, 0.03698711010760494, 0.03891694851751838, 0.0486058857558029, 0.03353480196424893, 0.021658211846702864, 0.014527382162798728, 0.037908564055604596, 0.043192665691354444, 0.528770777795996, 4.503659043993268, 15.7754419531141, 34.08539915084839, 27.85044183049883, 29.65006521769932, 16.897018432617188, 4.721618388380323, 1.4071905421359199, 0.051613641503666124, 0.027022322939176644, 0.11601299978792667, 0.005197564672146524, 0.01609506268453385, 0.04093914232882006, 0.24320290982723236, 0.23742247000336647, 0.7968708202242851, 1.0291296115943362, 6.994635573455265, 25.8417523588453, 44.824291706085205, 53.41148349217006, 49.754570143563406, 50.10012490408761, 48.77537441253662, 47.42611762455532, 46.69305140631539, 46.5357163974217, 43.16741732188633, 40.02726582118443, 36.799348149980815, 39.48980528967721, 44.76879644393921, 46.67932176589966, 47.1658867427281, 44.06148719787598, 44.07332692827497, 47.65149286815098, 47.38512325286865, 47.60424859183175, 47.66867576326643, 44.82963834490095, 46.3247378213065, 46.815148626055034, 44.704674993242534, 43.24628632409232, 38.72408948625837, 33.808801787240164, 32.94685690743582, 34.27481746673584, 33.52706970487322, 33.06767218453543, 32.82161910193307, 34.05320814677647, 37.763087613242014, 38.741744858878, 42.13571752820696, 43.84935174669538, 47.80479097366333, 44.92323752811977, 32.969497612544465, 44.0320337840489, 43.69933319091797, 45.667747429439, 44.819764954703196, 43.97165741239275, 38.99281801496233, 32.43236017227173, 33.68794134684971, 30.981378282819474, 32.78181982040405, 33.66272286006382, 32.77299213409424, 37.14316586085728, 38.20271403448922, 36.25618314743042, 33.85297495978219, 33.89878443309239, 35.47505971363613, 37.7551840373448, 39.76059395926339, 40.80053431647164, 42.07190874644688, 46.06603206907, 44.692793573652, 44.50579670497349, 44.02940041678292, 43.18071617398943, 36.77203130722046, 31.647168568202428, 33.54340491976057, 37.13826738085066, 40.75985608782087, 43.33487933022635, 44.413205010550364, 44.176983628954204, 43.53585944856916, 45.169957637786865, 41.70778145108904, 32.86157819202968, 16.584854977471487, 6.14493385383061, 0.4561428321259362, 0.5800088569521904, 5.685729580266135, 7.520018833024161, 7.284594757216317, 2.0961399333817616, 0.5969795063138008, 0.6193844069327626, 0.8677196470754487, 0.13465953565069608, 0.06172658848975386, 0.13211034743913583, 0.519381427339145, 4.141169786453247, 12.975581952503749, 22.50973677635193, 21.66274789401463, 29.056173154285975, 17.31964956011091, 3.4179962830884114, 0.07421197210039411, 0.05379087378137878, 0.002832094905897975, 0.031646303300346644, 0.05447893203901393, 0.014780757316787328, 0.09467142461133854, 0.033373972201453786, 0.04431073194635766, 0.06319543360067265, 0.08377257122525147, 0.031741905491799116, 0.029968299769929478, 0.0349241363416825, 0.015492686436378529, 0.03897302265145949, 0.00894904653874359, 0.07040115658726011, 0.04160519569580044, 0.06931681691535882, 0.016493445861020258, 0.027356384388570274, 0.03593460051342845, 0.0062792559370531565, 0.04991720217679228, 0.06347882375121117, 0.021310588178624, 0.004023464995303324, 0.04194670237068619, 0.025233701237344315, 0.024600224336609244, 0.027877863995464783, 0.04436429550072976, 0.02612896034094904, 0.03410230829779591, 0.036974268832377026, 0.0177797022874334, 0.04332674081836428, 0.046300186443009546, 0.027902242062347274, 0.07099863381258079, 0.054586072718458514, 0.02788806746580771, 0.0632493296372039, 0.048485737560050826, 0.04566618028495993, 0.0428031119517982, 0.05216295970603824, 0.011427583139655846, 0.00994080604453172, 0.02059388386883906, 0.028405623443956887, 0.08069301290171486, 0.8764602637716702, 6.943612779889788, 24.41023932184492, 39.530629430498394, 32.94989674431937, 36.34714896338326, 20.894629750932964, 6.6821690031460355, 1.9426425014223372, 0.09104596450924873, 0.10251572368932621, 0.08153590945793049, 0.050407433549740484, 0.10879305470734835, 0.09512961216803108, 0.24698148135628017, 0.7027098100100244, 0.7303394845553807, 1.8268902897834778, 8.982587712151663, 28.589922973087855, 48.55974401746477, 54.82010916301182, 51.81967551367623, 50.73425224849156, 49.335003171648296, 48.17136056082589, 48.50635405949184, 47.58812877110073, 44.32488645826067, 40.7449244090489, 38.396141460963655, 42.278523853846956, 47.203955922807964, 47.541537625449045, 47.89650024686541, 44.72857332229614, 44.82520539419991, 47.552289962768555, 48.1638182912554, 49.41053703853062, 48.82470662253243, 47.91612195968628, 47.09796462740217, 47.29297276905605, 45.82207039424351, 45.58961493628365, 38.22482320240566, 35.3091402053833, 34.664733001164024, 35.775308745247976, 34.98012910570417, 34.46398564747402, 34.7194813319615, 36.900440965379985, 39.27139214106968, 41.018527099064414, 44.44973169054304, 44.59168338775635, 50.718799454825266, 46.25653082983834, 35.874813897269114, 44.097329480307444, 45.13916322163173, 47.55107402801514, 46.33007403782436, 44.103367464882986, 41.297403471810476, 34.07004363196236, 34.75880813598633, 33.96764802932739, 34.052638394492014, 34.89734131949288, 34.53897755486624, 40.41400950295584, 40.43259246008736, 38.35947234289986, 36.08182852608817, 35.2537248475211, 37.60981035232544, 41.21970871516636, 41.14501558031355, 42.20243065697806, 43.452630451747346, 47.744261741638184, 46.183168275015696, 46.00117758342198, 45.15010316031319, 45.72312804630825, 38.65248482567923, 33.37466444287981, 34.00039141518729, 38.70643411363874, 42.65936156681606, 44.534895760672434, 45.19818122046334, 44.897609097617014, 43.863373211451936, 44.8714873450143, 43.073547158922466, 34.89645889827183, 18.43964879853385, 7.77141855444227, 1.1144140809774399, 2.6367532099996294, 6.759732612541743, 9.116604566574097, 7.257178034101214, 4.107401541301182, 1.5202470698526926, 1.0438487189156669, 2.8502376973629, 0.20379891565867833, 0.19257089814969472, 0.054657742979803255, 0.42943813651800156, 3.94391998222896, 15.898683888571602, 25.67171256882804, 25.911932638713292, 32.9906826700483, 22.352646691458567, 4.645660247121539, 0.09933691604861192, 0.025511802207412462, 0.030233871590878283, 0.017646056333822862, 0.052259036872003756, 0.05075887058462415, 0.03170410430591021, 0.05764367364879165, 0.08465271256864071, 0.03684508255017655, 0.031101724665079798, 0.037824598739721944, 0.04126403846644929, 0.07663053553551435, 0.022941764311066697, 0.016569429908746054, 0.04375055039833699, 0.015206918020599654, 0.08704497598643814, 0.048666098953357766, 0.029838757256844213, 0.020175207406282425, 0.0049976249990452614, 0.008079525116564972, 0.09992747221674238, 0.13183935412338801, 0.08143731831972088, 0.10918627932135548, 0.11307130620947906, 0.14354894150580677, 0.10296399784939629, 0.12104041501879692, 0.08760819397866726, 0.13512491567858628, 0.11818915658763476, 0.11736175098589488, 0.1404010954179934, 0.1272666659206152, 0.08580643923154899, 0.12372688443533011, 0.2241930863154786, 0.1193378349500043, 0.1438005015786205, 0.17277600962136472, 0.1545623926711934, 0.15620687657168933, 0.25392669439315796, 0.100401381429817, 0.10399641602167062, 0.12927139763321194, 0.10057455035192625, 0.06938131166888134, 0.2524824733180659, 0.8855192490986415, 7.72024507181985, 27.843234811510357, 47.083081586020334, 39.620285511016846, 40.549440315791536, 28.274572031838552, 12.936331578663417, 2.1408272726195197, 0.23188236728310585, 0.2677197642624378, 0.2461544828755515, 0.15689366257616452, 0.23034659826329776, 0.2345103605517319, 0.5908439755439758, 1.4658282356602805, 2.2396634433950697, 1.7974184198038918, 8.71441330228533, 28.8167781829834, 47.09665489196777, 58.32810524531773, 55.05402374267578, 54.58255025318691, 52.83786800929478, 50.99543155942644, 51.28624146325247, 49.95376457486834, 47.35963031223842, 43.21532167707171, 40.57515559877668, 44.365589005606516, 47.78465856824602, 49.19254425593785, 49.843270846775596, 44.42541299547468, 43.8120607648577, 48.68523890631539, 50.237205914088655, 49.77420922688076, 50.484308174678254, 47.44068799700056, 48.253533431461875, 51.22617776053292, 48.028401374816895, 48.33414643151419, 41.84586647578648, 36.957141739981516, 36.62533746446882, 37.49441467012678, 36.31765038626534, 36.42614998136248, 35.63570901325771, 37.36418458393642, 40.58338226590838, 43.37605088097708, 45.45867960793631, 47.76614161900112, 51.75069727216448, 48.51010956083025, 40.31083917617798, 46.31803628376552, 46.782676219940186, 48.80362926210676, 48.488271372658865, 46.46688754217965, 43.450837816510884, 36.3364383152553, 37.339310032980784, 35.22202021735055, 34.99545335769653, 37.383816719055176, 34.81811448505947, 40.18267617906843, 42.359122957502095, 39.9335207257952, 37.8962150982448, 37.69084024429321, 39.23477166039603, 41.468846797943115, 43.168000970567974, 44.36649227142334, 45.018903800419395, 48.855143206460134, 46.83875165666853, 46.457538740975515, 47.31450176239014, 46.78929785319737, 41.3620981488909, 34.93773119790213, 36.32692275728498, 40.871635232652935, 43.88996049336025, 46.30780158724104, 46.32038824898856, 44.406937735421316, 43.95511375154768, 45.54241929735456, 44.40452323641096, 35.12382827486311, 18.863596609660558, 7.395230054855347, 0.9482668020895549, 3.1485729345253537, 9.966912950788226, 15.087151663643972, 16.274652651378087, 8.632818869182042, 1.488220976931708, 1.6062083372047968, 4.519267737865448, 1.4292902648448944, 0.3099537380039692, 0.37224770390561646, 0.8206783341509956, 5.861300570624215, 18.477509532655986, 31.15260968889509, 32.7416592325483, 39.74010719571795, 24.569538933890207, 5.322814745562417, 0.1629252146397318, 0.17187068105808326, 0.1212690948907818, 0.10256022880119936, 0.1922622597111123, 0.19997694502983773, 0.18534228817692824, 0.24286152528864996, 0.2262417735265834, 0.1631573007575103, 0.1554099643336875, 0.17292029330773012, 0.19082300551235676, 0.22640038787254266, 0.10683266525822026, 0.14215542056730815, 0.1075831860569971, 0.1051663528861744, 0.22944867930241994, 0.09387862429554973, 0.11725363321602345, 0.16229071654379368, 0.07332672138831445, 0.09988521984113113], [0.008030539129062422, 0.06368476591472115, 0.030007339282227413, 0.021095289017206857, 0.04809176316484809, 0.031036351208708117, 0.026488633094621555, 0.07375701437039034, 0.07171848482851471, 0.026550868326531987, 0.028160984428333383, 0.03548206854611635, 0.011847653991675802, 0.041845213887946944, 0.03379905064191137, 0.011526650948716062, 0.051751183944621255, 0.13411528271223816, 0.01849599608353206, 0.024065917025187185, 0.027595715564010397, 0.031899451145104, 0.0508402778234865, 0.02672970640872206, 0.06406714075378009, 0.03300467612487929, 0.04415118122207267, 0.06451561168900558, 0.03190792265481182, 0.08098865060933999, 2.0421813087803975, 11.611818194389343, 27.65197696004595, 32.03814370291573, 28.948760952268326, 22.4563798223223, 8.55145980630602, 3.0568462908267975, 0.6613369243485587, 0.04779509747666972, 0.06444623148334877, 0.09013661223330668, 0.0958553325118763, 0.07705827044056994, 0.367874057165214, 0.43542555666395594, 0.6506403354661805, 1.1853965520858765, 0.7335354930588177, 12.027126789093018, 33.191836493355886, 47.352119309561594, 53.89679431915283, 50.681077684674946, 51.506506306784495, 49.60252618789673, 50.23524652208601, 47.14253384726388, 47.76117365700858, 45.6257073538644, 40.411747864314485, 36.9667580468314, 43.766386781420024, 46.90736164365496, 48.83590711866106, 47.49747214998518, 47.38825341633388, 46.32366779872349, 46.579754080091206, 46.02403020858765, 44.70561300005232, 44.68998997552054, 44.464826651981895, 47.16387523923601, 46.69252681732178, 44.50465720040457, 44.81905276434762, 38.20374584197998, 34.64180394581386, 33.812404428209575, 34.89652838025774, 33.329945836748394, 32.646531445639475, 33.57238238198416, 36.15076160430908, 37.789799962724956, 41.23877109800066, 46.49199833188738, 45.56049851008824, 45.32888725825718, 30.66532209941319, 44.590675898960654, 46.32215656552996, 47.28089679990496, 46.14437300818307, 43.13696684156145, 36.372346605573384, 35.525864941733225, 33.6131648336138, 33.30522414616176, 35.2836194719587, 33.227355684552876, 33.00129951749529, 34.00188527788435, 35.19514111110142, 35.220922401973176, 34.51267862319946, 34.17664984294346, 33.03566878182547, 35.58588695526123, 37.307789530072895, 38.06556701660156, 42.99491092136928, 44.08399588721139, 46.22906460080828, 45.45571967533657, 43.445977551596506, 43.47056375231062, 39.603630678994314, 34.95486545562744, 33.31832497460501, 39.22893517357962, 41.61712482997349, 44.02878202710833, 44.533266408102854, 43.461635317121235, 42.522985798971995, 44.052534443991526, 33.49689367839268, 18.310325452259608, 6.01968388898032, 1.4731692246028354, 0.4694259964994022, 2.443448462656566, 4.9972204225403924, 6.80740897996085, 3.2916808554104398, 3.3443327844142914, 1.1029011330434253, 1.1321487064872469, 1.7289741039276123, 0.2613736705056259, 0.14209246608827794, 0.24762275123170444, 1.008284798690251, 4.069970726966858, 12.657701866967336, 20.09324710709708, 24.4264303616115, 28.08603092602321, 10.786928057670593, 0.6008949790682111, 0.014452731436384576, 0.019945782842114568, 0.048575134548757753, 0.031793572540794096, 0.013592487284248429, 0.008982712901862604, 0.09971401867057596, 0.03871559664340956, 0.029109094624540637, 0.026679881582302705, 0.03241918861333813, 0.06320290427122797, 0.03425738747630801, 0.048839529111449204, 0.035976645935858996, 0.05561627547389694, 0.03170627222529479, 0.046602779134575806, 0.02729501768148371, 0.016848524932616522, 0.04169330346797194, 0.0414006377437285, 0.05569624421851976, 0.07499262663934912, 0.08198161875563008, 0.04425587239009993, 0.06770187642957483, 0.025142740225419402, 0.030963456191654717, 0.03673816578728812, 0.014966499492792147, 0.03994933954839196, 0.008167529412146126, 0.05730779881456068, 0.020535407720931938, 0.020202196136649166, 0.025493676840726818, 0.06316725404134818, 0.05875961948186159, 0.01746504015422293, 0.062231622104133875, 0.05681475830663528, 0.011674392619170249, 0.01861709592464779, 0.07508105332297937, 0.03610096372930067, 0.04930136040119188, 0.008992693303818149, 0.07971580712390797, 0.05943813414445945, 0.07829361808087144, 0.08183675831449883, 0.050863487113799365, 0.2105975379901273, 3.5312912208693366, 14.15145947252001, 34.02847950799124, 34.11768395560128, 34.8780392238072, 28.61929474558149, 12.47034021786281, 4.178799058709826, 0.7480475657752582, 0.06026784676526274, 0.09503377588199717, 0.0502649479811745, 0.10081625131091901, 0.009088812878222337, 0.11956712550350598, 0.43972174184662954, 0.8373171527470861, 0.7994826372180666, 1.410443167601313, 15.283942018236433, 35.41322422027588, 49.75646352767944, 54.99423449380057, 50.67267036437988, 52.24203566142491, 51.91225331170218, 51.716460023607524, 49.022855349949424, 48.439856324877056, 47.21482637950352, 41.41287211009434, 38.46843746730259, 43.946834972926546, 48.60255534308297, 48.489497729710166, 48.89162472316197, 46.624229499271934, 46.421901430402485, 46.83465569359915, 46.10633856909615, 45.62817743846348, 46.640842642102925, 45.487632751464844, 47.86752625874111, 48.28940698078701, 45.03154952185494, 45.573342255183626, 39.27745444434029, 35.19773278917585, 35.27665390287127, 34.85318899154663, 34.32118279593331, 34.3019015448434, 35.36064372743879, 37.402295453207834, 38.686430249895366, 43.48865338734218, 48.10308756147112, 46.906903062547954, 46.97839307785034, 33.3349346433367, 44.08296060562134, 47.89514534814017, 48.34555884769985, 48.710016182490754, 46.20413099016462, 37.043559959956575, 35.91892106192452, 34.44649355752127, 34.166286604745046, 35.607679980141775, 34.20372697285244, 34.55501747131348, 35.14720548902239, 36.41646419252668, 37.457561424800325, 34.983707427978516, 35.38195037841797, 36.46098477499825, 37.403959546770366, 38.10969155175345, 39.9049323626927, 43.05644416809082, 46.33410051890782, 47.313813890729634, 45.379560470581055, 44.759058543613975, 44.7182274545942, 40.52211652483259, 36.30691194534302, 35.35731554031372, 40.68721961975098, 43.74531289509365, 45.31202050617763, 45.251119545527864, 44.19761977876936, 41.82008171081543, 44.839487416403635, 35.18815122331892, 20.95691340310233, 7.846703154700143, 3.1121552543980733, 1.257896444627217, 4.928385487624577, 8.31827826159341, 6.801732735974448, 6.293980096067701, 6.765603840351105, 1.533604547381401, 1.6811184946979796, 2.5981231800147464, 0.4815300298588616, 0.14498545442308697, 0.2764914578625134, 2.031057677098683, 7.667479583195277, 17.332786866596766, 25.425256490707397, 29.1043050629752, 32.77182483673096, 13.999187094824654, 1.3198008771453584, 0.022850530188796774, 0.05319966621963041, 0.028633489073919396, 0.02051145882744874, 0.03356590600950377, 0.0290295906764056, 0.075724046677351, 0.01831878987806184, 0.0645619352747287, 0.04890284999938948, 0.016488178732938, 0.054015458694526126, 0.09481658360787801, 0.018188860600015948, 0.028248924263087765, 0.03763403557240963, 0.060370271626327715, 0.03199922971959625, 0.015104001221646155, 0.01994538420279111, 0.03993881886292781, 0.06584019346960954, 0.016554739625592316, 0.025060746053765928, 0.1873548094715391, 0.13265472251389707, 0.16002442315220833, 0.12572219808186802, 0.06470986269414425, 0.09437090823692934, 0.11446539711739336, 0.14377691570137227, 0.13578122189002378, 0.08514456224760839, 0.10951664445123502, 0.11675550708813326, 0.15696855927152292, 0.12307846280080931, 0.13774757566196577, 0.08342898823320866, 0.1477892832564456, 0.1768824899835246, 0.07438363467476197, 0.07856916436659438, 0.08507569772856576, 0.10570767455335174, 0.12707735465041228, 0.08150149416178465, 0.180460269429854, 0.13990424493593828, 0.19563932849892549, 0.1770754246307271, 0.14635446667671204, 0.2798990064433643, 3.3121283182076047, 17.103432042258127, 38.78779404503958, 42.974615233285085, 42.33952556337629, 33.02198430470058, 18.8673677444458, 5.56950706243515, 1.3306909842150552, 0.17145551262157305, 0.14920539941106523, 0.34893666048135075, 0.4629806194986616, 0.2031753555472408, 0.9636142871209553, 1.1824433505535126, 2.100200721195766, 3.111247863088335, 1.7567161981548582, 14.251064504895892, 36.502038206372944, 50.27025849478585, 57.31010382516043, 52.18135009493147, 55.222048555101665, 53.42333364486694, 55.118409224918906, 51.30442489896502, 51.57019002096993, 50.39275871004377, 44.746103627341135, 41.03850317001343, 47.13214976446969, 51.013243266514365, 50.80040257317679, 50.93006985528128, 47.46211971555437, 45.7986341203962, 46.631424358912874, 46.719246115003315, 46.99309894016811, 45.70340558460781, 45.52920382363455, 50.6864139011928, 50.12593051365444, 46.56661851065499, 48.08289957046509, 42.87134763172695, 38.81790753773281, 36.2342198916844, 37.54493849618094, 35.87330266407558, 36.3108411516462, 37.19642727715628, 39.386593273707796, 40.94579683031355, 45.3858312198094, 49.26769249779837, 48.1595903124128, 47.53071928024292, 36.79821211951119, 45.07781410217285, 48.04712677001953, 50.475237301417756, 50.21694844109671, 48.51383032117571, 39.048705850328716, 38.69157886505127, 36.02259513310024, 37.192376477377756, 36.76125117710659, 36.20457887649536, 36.262248924800325, 38.27150814873831, 38.20854009900774, 39.17196341923305, 36.67598288399832, 37.80422442299979, 36.76896367754255, 39.03787013462612, 40.89315727778843, 41.267269134521484, 45.716172899518696, 47.70665461676461, 49.376087869916645, 47.121585028512136, 47.52170746667044, 47.01647962842669, 42.873605796269004, 39.239287989480154, 35.70716428756714, 42.847358976091655, 45.170311995915, 47.21080684661865, 47.09836414882115, 42.99017224993025, 42.45950705664498, 45.05154991149902, 34.093611921582905, 21.267343282699585, 7.7325025626591275, 2.2101917905466895, 1.6316056315388, 7.633586270468576, 10.83929055077689, 13.893270492553711, 12.055845430919103, 10.27620940549033, 1.7978525736502238, 4.245608593736376, 6.571339155946459, 0.5267473320875848, 0.5800510346889496, 0.7315391344683511, 2.2930629551410675, 6.872673409325736, 20.906820365360804, 30.541783128465923, 34.64490631648472, 38.201769079480854, 15.043485709599086, 1.2607108993189675, 0.15641830808350018, 0.10474341522370066, 0.18094017010714325, 0.09195748809725046, 0.10544109850057534, 0.09724153884287391, 0.2314829272883279, 0.1042657604973231, 0.11802425900740282, 0.09913125886980977, 0.10439650741006647, 0.16285882677350724, 0.21995429162468227, 0.10999725759029388, 0.15493748682950223, 0.20478946822030203, 0.09697828761168889, 0.0725408692711166, 0.08888801280409098, 0.1303813045046159, 0.1043291153120143, 0.1274643096008471, 0.13797006729458058, 0.18680773382740362], [0.024260123925549642, 0.05745576016072716, 0.044898048109774075, 0.09829260315746069, 0.009997914944376265, 0.09519446654511349, 0.08487504813820124, 0.019107083024989282, 0.037360650420721085, 0.020317402901127934, 0.001676536728544826, 0.020545746898278594, 0.08108578289725951, 0.05795474802809102, 0.042605380062013865, 0.015032427651541573, 0.03607229223208768, 0.05300104205629655, 0.024866846190499406, 0.010470862334061946, 0.038482509686478546, 0.017316301885460104, 0.018170506227761507, 0.026697981503925154, 0.033729806143258295, 0.025058176102382795, 0.032084416398512464, 0.061393149596239836, 0.06160025205463171, 0.04471238396529641, 0.5479456345949854, 7.668520944459098, 23.74320009776524, 37.71931048801967, 34.76378999437605, 21.4592855317252, 19.236327511923655, 8.497270805495125, 1.4188204152243478, 0.10895133657114846, 0.07737363316118717, 0.04676219754453216, 0.011499518877826631, 0.020053408674097488, 0.10152217878827027, 0.4896080163972718, 0.9682707743985313, 0.4440133401325771, 0.22460271790623665, 2.7711665460041592, 17.918962955474854, 36.950408935546875, 48.263611793518066, 51.05133676528931, 48.339312417166575, 49.01932219096592, 48.19398736953735, 49.25510583605085, 49.30660588400704, 49.49165030888149, 45.131471565791536, 36.630854334150044, 37.74819414956229, 45.21523904800415, 47.47510242462158, 48.772247723170686, 49.06790746961321, 48.940904821668354, 46.580841473170686, 46.24225228173392, 46.06914138793945, 44.47740289143154, 44.629224504743306, 45.35196917397635, 47.328092438834055, 45.976855414254324, 45.111200196402415, 45.131558418273926, 41.25195530482701, 36.29676062720162, 35.29609843662807, 34.90538733346121, 33.81240790230887, 33.199774810246055, 33.68344586236136, 38.08950356074742, 42.923952443259104, 44.23874964032854, 47.7285727092198, 45.425727776118684, 34.004952907562256, 46.50956685202462, 46.92423186983381, 46.948689528873985, 45.426561559949604, 42.194478443690706, 37.812788077763145, 36.15231452669416, 33.639939716884065, 35.02074132646833, 34.74588448660714, 32.55837270191738, 32.965613569532124, 35.03565216064453, 33.65792165483747, 33.953310421534944, 34.32031774520874, 33.619112491607666, 33.881066526685444, 33.25896651404244, 34.47231306348528, 37.40565490722656, 41.51062631607056, 42.91953338895525, 44.226197719573975, 44.68191269465855, 44.392488956451416, 42.57297461373465, 42.247996943337576, 35.37818098068237, 35.90651852743966, 40.1559534072876, 41.468631403786794, 42.75336027145386, 45.11758211680821, 43.43216453279768, 44.4047976902553, 35.961662905556814, 22.54390627997262, 10.234891942569188, 1.39055720610278, 1.3922780794756753, 1.4315591773816516, 3.885147341660091, 7.726564458438328, 6.146234904016767, 6.1824840903282166, 4.236728361674717, 1.1717627750975745, 0.5481366014906338, 1.9880070728915078, 0.24464422677244457, 0.09158090116190058, 0.8067672806126731, 4.315874423299517, 10.82929469857897, 14.496409739766802, 19.254050629479543, 27.191839456558228, 20.14663359097072, 4.570548049041203, 0.07396892764206443, 0.08739176844911915, 0.03320856571995786, 0.020859413281349198, 0.03584689646959305, 0.035631156260413785, 0.0662192434870771, 0.03949184749009354, 0.029959414353860275, 0.05545393597068531, 0.020431982020714452, 0.024770825003672923, 0.037764660348849635, 0.03995372288461242, 0.02183525520376861, 0.03453560719000442, 0.021715162987155572, 0.04685572681150266, 0.054006267937698534, 0.05301455168851784, 0.03576460713520646, 0.07281846473259584, 0.041461410732673745, 0.051445799081453254, 0.031989065265016894, 0.042355333122291734, 0.05839215884251254, 0.027800551715439985, 0.00998104062663125, 0.03538529588175671, 0.029920812496649365, 0.0509881238186998, 0.046761325627033196, 0.04916328191757202, 0.07691742692674909, 0.004665679730741041, 0.014478273190824049, 0.09098179545253515, 0.00811391751215394, 0.008860445132346025, 0.04474132348384176, 0.07520909966634852, 0.021630547973992567, 0.058305686339735985, 0.043320684893322844, 0.039656582221921, 0.006239693104622087, 0.018590734839173298, 0.028326582595972077, 0.027511556865647435, 0.012140629297521497, 0.051546581887773106, 0.04625285184010863, 0.05093868914991617, 0.012989924438962979, 1.0763881100075585, 11.545777303831917, 28.55045894214085, 42.415445055280415, 39.55859592982701, 26.229102270943777, 21.63824507168361, 12.042230435780116, 1.7451098838022776, 0.11712803638407163, 0.015714557209451283, 0.07132778436477695, 0.04786255403554865, 0.08749930946422474, 0.09958282392472029, 0.08730752154120378, 0.36799285507627894, 0.7251464117850576, 0.8124194230352129, 3.0184040793350766, 21.174134935651505, 38.60707139968872, 51.38559375490461, 52.659466062273296, 49.936098779950825, 48.90021964481899, 50.43157482147217, 49.386513641902376, 50.817001819610596, 50.87190301077706, 47.485969407217844, 37.9243483543396, 39.35090732574463, 46.69526093346732, 48.99057749339512, 49.22881385258266, 50.12013224193028, 48.56657409667969, 46.761046477726524, 47.00445229666573, 46.56030607223511, 45.45529930932181, 45.11552892412458, 46.731850147247314, 48.57557201385498, 47.56181594303676, 47.605860573904856, 46.59002004350935, 41.72729894093105, 38.2219431740897, 36.0320794241769, 36.896278994424, 35.23391900743757, 34.64630290440151, 37.0986522265843, 39.72708279745919, 44.78279359000069, 46.49143900190081, 48.92758859906878, 46.55170767647879, 35.420398235321045, 46.80665792737688, 48.686538219451904, 47.3883124760219, 46.43207706723894, 43.53614779881069, 38.59585353306362, 37.14336041041783, 33.88368252345494, 36.94366223471505, 36.42653213228498, 33.877901622227256, 34.40092727116176, 36.0662055015564, 35.520674637385774, 34.53021935054234, 36.18222304752895, 35.332569531032014, 35.587141105106895, 35.08671794618879, 35.601968560900005, 38.735324723379954, 44.668634687151226, 44.18555423191616, 46.346798351832796, 46.21304900305611, 45.831488677433555, 44.01379476274763, 42.3957017489842, 37.505198274339946, 36.374285152980256, 41.730456897190635, 43.01746824809483, 44.393840381077354, 46.830868925367085, 43.95806673594883, 44.10070630482265, 37.19967555999756, 25.35452035495213, 11.148448910032, 3.008732621158872, 2.532439253159932, 2.3319344350269864, 3.8444795353072028, 8.452021530696324, 9.068945135389056, 8.510349052292959, 7.088527449539729, 3.017271088702338, 2.618287069456918, 0.2382881992629596, 0.23715428582259587, 0.03943261138296553, 0.4802238228065627, 3.943459664072309, 9.830941046987261, 17.53520178794861, 21.14077663421631, 29.675172533307755, 24.04174334662301, 7.379062465259007, 0.19006580114364624, 0.0479339698462614, 0.059639686186398776, 0.024229060592395917, 0.029793465044349432, 0.039941288730395694, 0.10022306242691618, 0.04586184603561248, 0.041987543393458636, 0.03673272393643856, 0.029871218372136354, 0.04355170910379716, 0.07691746763885021, 0.04349979778219547, 0.0347446095464485, 0.04381907904254539, 0.02337025069365544, 0.06482654357595102, 0.06857907293098313, 0.030361568488712822, 0.02822002036763089, 0.06357080595833914, 0.03686906537041068, 0.057498188955443244, 0.06323121275220599, 0.08332059226397957, 0.14698596564786776, 0.12115731303180967, 0.19787634988980635, 0.08888718499136822, 0.1886737458407879, 0.170667543475117, 0.11101375054568052, 0.15562043232577188, 0.19422739212002071, 0.09335553486432348, 0.1586240218686206, 0.17465168397341455, 0.1275067723223141, 0.10969944857060909, 0.16591789333948068, 0.16019599751702376, 0.08639515656977892, 0.13985669320183142, 0.12123096122273377, 0.1288888803017991, 0.09100793940680367, 0.12442093076450483, 0.08996973333082028, 0.09885413838284356, 0.10815183911472559, 0.10563030799052545, 0.2520708739757538, 0.1421453511076314, 0.1159938108175993, 0.9723882334572929, 13.452944040298462, 33.17416375023978, 50.13532795224871, 45.860525199345176, 32.336871079036165, 25.94548375265939, 12.968778797558375, 2.661784312554768, 0.4414330343050616, 0.1786116821957486, 0.1457909569144249, 0.22843470371195249, 0.1967331405196871, 0.5522408698286329, 1.056605720094272, 1.8307193986007144, 1.3708274705069405, 0.7200397029519081, 3.7083408747400557, 19.782164096832275, 40.47089440482003, 51.81849431991577, 53.665926524571006, 50.55030911309378, 51.06948546000889, 51.043745858328684, 51.16277544839041, 52.66264486312866, 53.99040045057024, 49.24983215332031, 40.815090792519705, 40.86344678061349, 49.89837006160191, 50.36657789775303, 51.56891850062779, 51.459143911089214, 49.56067023958479, 47.63210391998291, 48.41587809153965, 47.49258061817714, 45.90558426720755, 45.75895643234253, 47.43470212391445, 49.94313383102417, 49.80671637398856, 49.25850697926113, 48.292054244450156, 45.28894553865705, 40.999989305223735, 38.121041434151785, 38.721647194453645, 36.708674158368794, 36.28314215796334, 37.31476204735892, 41.44681406021118, 46.747104917253765, 47.4690158026559, 51.214570794786724, 48.87833629335676, 38.981773853302, 47.68134927749634, 49.67927598953247, 51.31010157721383, 48.52555888039725, 45.78455359595162, 41.665338379996165, 38.622725691114155, 36.04307842254639, 38.19877093178885, 38.579229967934744, 36.47031620570591, 36.321999958583284, 37.768302236284526, 36.36478696550642, 37.369367940085276, 38.31221764428275, 36.54952914374215, 37.3655811718532, 36.74098675591605, 37.084575176239014, 40.13838836124965, 46.137136459350586, 45.39475270680019, 46.898989064352854, 46.08538627624512, 46.53852694375174, 45.88601119177682, 45.34714017595564, 39.4868939944676, 39.0320405960083, 44.105038506644114, 44.511143343789236, 46.02556576047625, 48.0809714453561, 43.997264998299734, 45.84952620097569, 36.006958212171284, 25.211387463978358, 11.815404755728585, 2.3828864438193182, 2.9747637467724934, 3.351072971309934, 6.978796286242349, 13.431603516851153, 14.992781230381556, 13.95317438670567, 12.101363948413304, 3.348289132118225, 4.029930429799216, 7.055221259593964, 1.0767016474689757, 0.2663986294397286, 1.237187230161258, 4.976205161639622, 15.203462771006993, 22.80495183808463, 28.075261218207224, 36.379395553043906, 27.006996529442922, 7.077213176659175, 0.2434679998883179, 0.16069021528320654, 0.1507264170795679, 0.16498642760728086, 0.08568439792309489, 0.16154370377106325, 0.17723155553851808, 0.11574657979820456, 0.11230901282812868, 0.12720312790146895, 0.08272724731692246, 0.22596601689500467, 0.08989485699151244, 0.27376966391290936, 0.14941943649734768, 0.10576016602239438, 0.12504142389765807, 0.20106725580990314, 0.16541326684611185, 0.14998899879200117, 0.10422823751079184, 0.19549598119088582, 0.2171235792338848, 0.14803470937269075, 0.15330893493124417], [0.05087734619155526, 0.01652293329659317, 0.037610266490706375, 0.04000703877370272, 0.07472800476742641, 0.029587268430207456, 0.07428992898868662, 0.02535553219994264, 0.0178875893553985, 0.03747333812394312, 0.05241310842601316, 0.04736298941341894, 0.018908438505604863, 0.03156609706846731, 0.032078136556914875, 0.008561653085052967, 0.04716958657705358, 0.0027865350961552133, 0.053272669802286794, 0.021043077443859408, 0.019249958751190985, 0.0303219691850245, 0.0740810419831957, 0.0506640147816922, 0.04918153111689857, 0.08553977496922016, 0.0029779173824603534, 0.04892848165971892, 0.0435681567926492, 0.0365591512859932, 0.17220734299293586, 3.0991825333663394, 10.856497764587402, 30.489074093954905, 32.49400806427002, 24.6726519380297, 16.598143407276698, 15.459156479154315, 6.177229080881391, 0.3558899073728493, 0.11193941480347089, 0.026975916232913733, 0.07396824910704579, 0.022887820777084147, 0.024906632091317858, 0.12659374917192118, 0.08997324814221688, 0.2776706703007221, 0.3865899257361889, 0.11885429732501507, 4.0775968091828485, 18.044124330793107, 34.22209453582764, 44.707204137529644, 50.78140619822911, 50.07340908050537, 48.30457489831107, 47.37360661370413, 49.49753195898873, 49.21655028206961, 47.76525224958147, 41.52203525815691, 35.76926033837454, 41.75825316565377, 45.8861015183585, 47.269223826272146, 46.96271446772984, 50.03269263676235, 48.3412891796657, 48.151926449366975, 46.13304049628121, 44.706380775996614, 43.902543681008474, 44.78561455862862, 46.6211062840053, 47.256119523729595, 46.95007916859218, 47.00035980769566, 45.31822524751936, 44.015316418239046, 39.210817745753694, 34.102272851126536, 33.35470226832798, 33.56839411599295, 33.718419619968955, 40.32605920519148, 45.6755815233503, 46.781689575740266, 47.77049813951765, 46.3375746182033, 33.56109503337315, 47.92913246154785, 46.622773851667134, 44.34879868371146, 45.45531667981829, 42.673344816480366, 39.705102171216694, 36.98944044113159, 34.468321323394775, 31.764193602970668, 32.22656495230538, 32.83298635482788, 32.51430375235421, 34.80034794126238, 34.20503323418753, 32.70666810444423, 33.16898734228951, 32.7685661315918, 35.79094219207764, 38.000149726867676, 39.139275618961875, 41.58619839804513, 42.37660115105765, 43.91034650802612, 45.8692695072719, 44.47703116280692, 44.373544692993164, 43.46358776092529, 41.380625520433696, 38.6832549231393, 39.46546227591378, 40.292561939784456, 43.16133417401995, 44.818656717027935, 45.718184403010774, 44.935667855399, 41.08998237337385, 27.544316359928676, 13.743847744805471, 3.389121089662824, 0.8759675930653299, 2.490233723606382, 1.7044183015823364, 2.9359215795993805, 10.859125052179609, 4.581353800637381, 4.855098060199192, 7.045831637723105, 2.9824013369424, 1.5753953563315528, 0.25154416795287815, 0.2858076351029532, 0.07618572868938957, 2.7831348180770874, 13.236315710203987, 36.02628810065133, 26.085354464394705, 22.705134017126902, 26.218818937029155, 10.673092246055603, 0.74182968799557, 0.023775938299617598, 0.07780514072094645, 0.0043492618881698164, 0.017445377905720046, 0.030747590453497002, 0.03142769967338868, 0.07505408155598811, 0.012206703341299934, 0.06201727967709303, 0.03758161534954395, 0.01757046244373279, 0.014393094993595566, 0.04680034817595567, 0.016667681779446344, 0.035295898893049786, 0.039726953088705025, 0.02639279680858765, 0.013297313524942313, 0.09658700360783509, 0.06944252231291362, 0.025856452195772102, 0.04790263509910021, 0.03459889075851866, 0.056154876215649505, 0.08272308111190796, 0.029857623923037733, 0.042476129318986616, 0.008883539919874497, 0.052156893602971516, 0.019925099398408617, 0.05055956110092146, 0.022324438240113, 0.016526843354638134, 0.04602085393188255, 0.014114982997333365, 0.02962297633556383, 0.03660527131121073, 0.049636495632252524, 0.03505914106166788, 0.028209540394267867, 0.048320212334926636, 0.00878883509098419, 0.020009943417140415, 0.013167715880886784, 0.06920711137354374, 0.025966356209080135, 0.04354660991313202, 0.03110913766015853, 0.017687031367261494, 0.044593606410282, 0.024801374346550022, 0.04314428275184972, 0.05930406241012471, 0.05437420694423573, 0.021541914337181618, 0.3150359924350466, 5.4509278024945935, 17.892789091382706, 36.97481100899832, 38.97730616160801, 31.401594911302837, 24.296160323279246, 17.39412382670811, 5.908563085964747, 0.6814084787453923, 0.011297126300632954, 0.06157872213848999, 0.009039340890012681, 0.07667141048503773, 0.1123549903609923, 0.08035550958343915, 0.21732738401208604, 0.17393291182816029, 2.1796998381614685, 0.8211934236543519, 5.315406663077218, 22.62679307801383, 36.876379353659495, 47.85631881441389, 51.08228056771414, 50.347835132053916, 49.0497726712908, 47.9038062776838, 49.649985858372276, 50.326465947287424, 49.31990473611014, 42.349586554935996, 37.08460296903338, 43.778924805777415, 48.251900604793, 49.40314415522984, 49.22041348048619, 51.000903265816824, 49.32889223098755, 48.91715587888445, 47.76687465395246, 44.861627851213726, 44.88582147870745, 45.655601978302, 47.63496657780239, 47.20143372671944, 50.01452309744698, 48.49142238071987, 46.925656250544954, 46.49388476780483, 40.47645991189139, 36.140189920152935, 35.40243714196341, 34.8842648097447, 36.08728633608137, 41.02547182355608, 47.45027303695679, 47.27430990764073, 48.363304546901155, 47.78616632734026, 36.10287114552089, 48.40012999943325, 47.66895021711077, 47.85189628601074, 47.16070686067854, 44.59543194089617, 41.59679092679705, 37.47471652712141, 34.827835014888215, 33.72228281838553, 33.38709477015904, 33.68267113821847, 33.41107300349644, 36.69466311591012, 35.66640962873186, 34.43555014474051, 35.779759066445486, 34.98262003489903, 37.49963971546718, 39.0294315474374, 40.54703276497977, 41.92783090046474, 44.20804555075509, 45.325364521571565, 45.756920610155376, 45.56453193937029, 45.92904485974993, 44.12005703789847, 42.84145648138863, 39.2794520514352, 42.534151554107666, 42.444255760737825, 43.64094747815813, 46.58755343300955, 46.370373589651926, 44.96491977146694, 42.24076386860439, 29.430859974452428, 16.699293545314244, 4.599554172583988, 2.2925839637007033, 2.948490002325603, 4.519750203405108, 6.9088617988995145, 7.543946691921779, 8.800346885408674, 9.47938825402941, 6.79685857466289, 5.114744859082358, 2.184079808848245, 0.34661476793033735, 0.10294904972293548, 0.09530756476202182, 2.9005135595798492, 12.31453468118395, 32.03771638870239, 25.75180619103568, 25.821821451187134, 31.995210783822195, 15.111197641917638, 1.6689459021602358, 0.04017484048381448, 0.06670870472277914, 0.028370259895122478, 0.07253012806177139, 0.036950211373290846, 0.01815925950982741, 0.03429378070203321, 0.019079227466136217, 0.06521892680653504, 0.060284253742013655, 0.03222551775564041, 0.039324089884757996, 0.031090949528983662, 0.04748004688216107, 0.043210195643561225, 0.051949088860835345, 0.04790606848629458, 0.019386902384992157, 0.02276451400082026, 0.045237895766539235, 0.04385849853445377, 0.02884312246793083, 0.02325762914759772, 0.01567216743049877, 0.033679804897734096, 0.12124921381473541, 0.12481081698622022, 0.13750490439789637, 0.1333402328725372, 0.13057506696454116, 0.15460895374417305, 0.10541479169790234, 0.14476427914840834, 0.16352746875158378, 0.13027615871812614, 0.11143224380378212, 0.14840977638959885, 0.17281332904739038, 0.07691877042608601, 0.09246113750019244, 0.15592708944209985, 0.10664125052945954, 0.07310723566583224, 0.07248700716133628, 0.1696219617234809, 0.12122964486479759, 0.0815070445782372, 0.16429504113537924, 0.15836598857172898, 0.1004196000950677, 0.1745271049439907, 0.1543073992111853, 0.11152812080191714, 0.07697242897536073, 0.1730828567274979, 0.4546267677630697, 5.8495094776153564, 18.323771953582764, 43.62489366531372, 44.20753485815865, 36.773424421037944, 26.250897032873972, 21.735314880098613, 8.35157229219164, 1.4075559739555632, 0.39482128833021435, 0.16870080972356455, 0.2894297364567007, 0.273718638079507, 0.23304002944912228, 0.5690650099090168, 0.7774946827973638, 1.9180591234139033, 1.4318882397242954, 0.6964783615299633, 5.457644104957581, 20.67875443186079, 37.15186153139387, 48.53978531701224, 51.97489479609898, 51.09962327139718, 50.04178088051932, 49.09905276979719, 51.47634070260184, 52.656825746808735, 52.25953817367554, 45.58740888323103, 40.19632591520037, 46.94007723672049, 48.468566281454905, 51.35068947928292, 50.27717195238386, 52.46802234649658, 50.69791316986084, 49.92076757975987, 47.97794008255005, 46.491581439971924, 44.592187132154194, 46.42091131210327, 48.425174781254356, 48.480392115456716, 51.67284270695278, 51.62611607142857, 49.00809737614223, 48.377173151288716, 42.32602868761335, 37.59130729947771, 37.09754746300833, 36.41651282991682, 37.525744097573416, 43.382415430886404, 49.81499515260969, 51.11648307527815, 49.83822298049927, 49.47234126499721, 40.50219603947231, 49.396400928497314, 48.47229051589966, 48.33138452257429, 50.138875007629395, 46.69935689653669, 43.49453156335013, 40.47234310422625, 38.04831811359951, 35.23084790366036, 35.714501585279194, 35.31589732851301, 35.38995817729405, 38.035109588078086, 36.94925553458077, 36.56724010195051, 36.775345597948345, 37.21658052716936, 39.34449413844517, 41.82573754446847, 42.82960285459246, 45.73706265858242, 46.71638345718384, 47.12180042266846, 48.318613733564106, 46.42541027069092, 47.83295897075108, 46.2588654245649, 44.658573695591514, 40.32077510016305, 42.630637713841026, 43.57298019954136, 45.44896602630615, 48.507222584315706, 46.40410361971174, 44.70951441356114, 42.18499067851475, 29.18701294490269, 16.387741531644547, 4.488128951617649, 1.6981915214232035, 5.685746950762613, 6.169196963310242, 9.155190518924169, 20.556129149028234, 11.678009339741298, 14.562535745756966, 15.87864007268633, 11.835102898733956, 5.708732025963919, 1.1616511919668742, 0.929288883294378, 0.30803456955722397, 3.9648840001651218, 16.457892281668528, 39.244999408721924, 32.95236682891846, 31.850087233952113, 35.85746077128819, 15.902194465909686, 1.8221509669508253, 0.06883224113179104, 0.23681656537311419, 0.11290589972798314, 0.11656375309186322, 0.15026763241205895, 0.1378932571304696, 0.11321834474802017, 0.1358165057109935, 0.13806846844298498, 0.20335964565830572, 0.18442869505711965, 0.0930625841553722, 0.08442980702966452, 0.14674450217613152, 0.1054351409631116, 0.09950451419821807, 0.08068661431648902, 0.09734723424272877, 0.17496106880051748, 0.2507838287523815, 0.13021867323134625, 0.10402094506259475, 0.10054823676390306, 0.13288598081895284, 0.12009240660284247], [0.03284533913912518, 0.02999322914651462, 0.059191527377281866, 0.030145743462656225, 0.05010501388460398, 0.046541086730680296, 0.06048583971070392, 0.07277364070926394, 0.05897806704576526, 0.02017536007666162, 0.0688217713364533, 0.052477918698319366, 0.02222795904214893, 0.03310393562008228, 0.050083765560495, 0.026840904727578163, 0.05727496450500829, 0.005743686126412025, 0.035997918008693626, 0.03837606789810317, 0.011114230579031366, 0.0446027428843081, 0.03379182085128767, 0.013588862210911299, 0.04013546170400722, 0.018464415367426615, 0.03881425902779613, 0.0383316747445081, 0.036404167102383714, 0.12894175175045217, 0.11773966784988131, 1.03672779245036, 6.704064513955798, 18.987410034452164, 32.019505160195486, 22.679416997092112, 19.464219740458898, 26.20321502004351, 7.6666640383856635, 1.8984469643660953, 0.06421079340257815, 0.055105545558035374, 0.036700384957449775, 0.060865235781030994, 0.07264987592186246, 0.05911468328641994, 0.03206624183803797, 0.35937198624014854, 3.204517658267702, 0.3575730270573071, 0.1276443927947964, 3.417905739375523, 15.394883905138288, 30.20535135269165, 41.09599951335362, 48.17281968252999, 48.78394154139927, 48.40758194242205, 49.587479863848, 48.51715850830078, 46.17354154586792, 44.49899789265224, 38.198937688555034, 36.18311241694859, 38.235030106135774, 42.09329877580915, 44.74955340794155, 46.06891209738595, 46.76345750263759, 50.0839911869594, 47.39115081514631, 47.442869731358115, 44.833824634552, 45.11094658715384, 45.05550691059658, 45.3287969316755, 48.43049015317644, 45.90230471747262, 46.72281748907906, 46.24989182608468, 44.726971762520925, 37.40965359551566, 34.53807428904942, 34.87201860972813, 34.55554206030709, 43.29980482373919, 45.49495962687901, 48.21955326625279, 46.19732175554548, 45.6011871610369, 34.734989711216514, 47.61442770276751, 46.38547549928938, 44.29793439592634, 43.938990456717356, 44.12566770826067, 40.92124884469168, 39.32815892355782, 35.21832030160086, 32.841539587293354, 31.959104469844274, 32.6919344493321, 32.95249537059239, 33.24826281411307, 34.04892805644444, 32.85299369267055, 34.59923928124564, 36.69669893809727, 42.34853390284947, 40.937132426670615, 43.063718932015554, 43.001959868839805, 43.79583672114781, 44.60613564082554, 45.24268095833914, 44.94121251787458, 45.17816693442208, 43.2456088747297, 40.357649190085276, 41.91904142924717, 42.974417209625244, 42.2734968321664, 45.77613932745797, 44.373134749276296, 44.27469614573887, 42.98415163585118, 34.652729988098145, 19.14446885245187, 7.253988376685551, 1.2899222118513924, 2.4979316762515476, 1.7753565864903587, 2.8826097888605933, 4.130994583879199, 3.2732792028359006, 11.798429438046046, 7.835006730897086, 3.81822316135679, 2.99910089799336, 1.5157826351267951, 0.09811990920986448, 0.1409056811992611, 0.8091134375759533, 5.213276829038348, 15.916648456028529, 19.57384146962847, 32.78126743861607, 23.995979036603654, 19.106535162244523, 4.900385984352656, 0.31101048844201223, 0.0648775151265519, 0.03469052691278713, 0.04333463557330625, 0.02025960698457701, 0.034823095692055564, 0.030893081932195594, 0.01983989236344184, 0.04594445428145783, 0.029060531873255968, 0.04942749666848353, 0.07526551306779895, 0.027397854752572517, 0.0445323075566973, 0.06495423708111048, 0.04714404991162675, 0.08752858146492924, 0.032207438190068514, 0.03773260974724378, 0.08775590426687684, 0.013218383787066808, 0.04322930997503655, 0.07034530636987515, 0.03397282346018723, 0.020120590426293865, 0.004607487719372979, 0.07827704147036586, 0.016308273654431105, 0.04095845343545079, 0.041343104759497304, 0.07591288297304086, 0.034761420251535516, 0.022821010522810475, 0.051374020254505534, 0.01709113173585917, 0.029064046684652567, 0.03605748999065586, 0.06212950258382729, 0.027678113463999968, 0.018692352243566086, 0.01024086186329701, 0.02897392027080059, 0.10053404181131295, 0.01233683617985142, 0.04605348128825426, 0.01763000219528164, 0.039905523149562735, 0.00750122159453375, 0.014524622221610375, 0.012157988767804844, 0.029670982688133205, 0.022305193290646588, 0.017962385966841663, 0.050632021855562925, 0.030645976441779306, 0.03744743504960622, 0.035871808882802725, 1.7380024194717407, 9.822751726422991, 27.33497061048235, 38.993189743586946, 28.551414319447108, 21.583743401936122, 29.63141277858189, 10.75292704786573, 2.293245996747698, 0.0866829843393394, 0.044942481975470266, 0.09902977038707052, 0.15980677625962666, 0.11411797361714499, 0.1443299488829715, 0.029481020024312393, 0.14016652586204664, 2.805834148611341, 1.684849460210119, 0.9418587173734392, 5.239495422158923, 19.357601370130265, 32.3690481867109, 43.549307686941965, 48.81946768079485, 49.238103594098774, 48.383190291268484, 50.13269458498274, 49.67288364682879, 49.40869229180472, 45.61914130619594, 39.39700167519705, 37.51732982907976, 41.565180097307476, 43.78470918110439, 46.822565828050884, 48.84220913478306, 47.97732516697475, 50.246916021619526, 48.64735385349819, 47.92591544560024, 44.196021693093435, 44.74918515341622, 45.48476314544678, 47.50295080457415, 49.92917142595564, 48.55305290222168, 48.43653508595058, 47.422674792153494, 46.05961888177054, 38.77300133023943, 36.278097765786306, 35.89060715266636, 36.289965288979666, 44.55051531110491, 47.67262234006609, 48.05865730558123, 48.573730741228374, 45.69675963265555, 36.33759866441999, 48.01328904288155, 47.58298363004412, 47.11555746623448, 46.52701725278582, 46.35862765993391, 41.80603245326451, 39.845004149845664, 37.770650727408274, 34.433333669389995, 33.83150502613613, 34.62496846062796, 33.51592826843262, 35.020470346723286, 36.19565391540527, 34.93031399590628, 35.54825203759329, 38.63457236971174, 43.182665143694194, 43.152996335710796, 44.22400556291853, 45.1909134047372, 45.597799914223806, 45.212560517447336, 46.73588010243007, 45.74676234381539, 46.09580857413155, 42.86049801962716, 43.11068180629185, 42.73127889633179, 44.09814241954258, 43.63503456115723, 45.021658761160715, 45.77385337012154, 44.715333529881065, 43.05519349234444, 36.644007274082725, 20.556073563439504, 8.87752834388188, 2.6787967596735274, 3.777909278869629, 2.6342416533402035, 5.819421606404441, 6.251204814229693, 7.574629068374634, 8.31757823058537, 7.604947532926287, 8.069290433611188, 3.7588156291416714, 1.1716615919555937, 0.1597257184662989, 0.2053982905511345, 0.588023766875267, 5.352292478084564, 18.264481237956456, 27.584650652749197, 34.889448165893555, 28.380842992237636, 23.135324784687587, 7.578587804521833, 0.5166526309081486, 0.08983406703919172, 0.06072163741503443, 0.05658609539802585, 0.025902065016063194, 0.06764131717916046, 0.06915737475667681, 0.01949696076501693, 0.029708634596318007, 0.03680104902014136, 0.026236769377386997, 0.04000601079314947, 0.05512097883703453, 0.03687160648405552, 0.05272584182343312, 0.029707128248576607, 0.09117578861436673, 0.04132570033626897, 0.03996655737449016, 0.08781385115746941, 0.044218834556107006, 0.06307120062410831, 0.013808488729409873, 0.02663630267073001, 0.04721668030002287, 0.016488107486761043, 0.13685819267162255, 0.08856281811105353, 0.23421134373971395, 0.1243168299219438, 0.1501083123896803, 0.13083596367921146, 0.10713816886501652, 0.15288551550890717, 0.09454835192965609, 0.1293635426887444, 0.13985961090241159, 0.146581002378038, 0.25515902255262646, 0.06933184646602188, 0.22236518082874163, 0.09506740407752139, 0.15419920001711163, 0.10130706283130816, 0.11334090174308845, 0.12193761473255497, 0.15719478284674032, 0.12279013970068522, 0.07717094118041651, 0.07745441954050745, 0.1092134275074516, 0.08961974496820144, 0.08513538845415626, 0.15499501302838326, 0.2382725386747292, 0.2254818007349968, 0.15918567244495663, 2.090473243168422, 11.606419444084167, 30.475552899496897, 44.34867361613682, 36.35043546131679, 27.683348076684133, 35.86086886269705, 12.793447085789271, 3.3576668117727553, 0.20108948461711407, 0.23690206078546389, 0.2096783673124654, 0.35741614976099556, 0.17929264636976378, 0.3250773607620171, 0.2564402866576399, 1.916051094021116, 7.678545457976205, 0.9956974855491093, 0.46834718010255266, 4.456961504050663, 17.691525833947317, 32.198383058820454, 43.39207342692784, 49.03552886417934, 49.842405796051025, 50.255052362169536, 51.95671483448574, 51.9738004548209, 51.94657046454293, 48.11321108681815, 40.94853094645909, 38.53905200958252, 42.040339606148855, 46.32007558005196, 48.79694856916155, 50.92015824999128, 49.243571826389854, 53.27557325363159, 48.772230352674214, 49.56549228940691, 46.59714542116438, 44.35866165161133, 45.54136317116873, 47.93691096987043, 52.57942281450544, 50.157173088618684, 50.829734393528526, 48.80076313018799, 47.85709701265608, 41.44683143070766, 38.26052304676601, 38.486197062901084, 38.46646070480347, 46.955210413251606, 50.25266913005284, 50.2350207056318, 48.25410318374634, 48.21204226357596, 39.38308790751866, 49.30897174562727, 48.057719298771445, 48.49697746549334, 47.89307478496006, 48.84353971481323, 44.220083304813926, 41.74875150408064, 39.477232524326865, 36.2030919619969, 36.03476142883301, 35.98459196090698, 35.77502039500645, 35.82794482367379, 36.93416057314192, 35.30147286823818, 37.48605946132115, 39.7618168422154, 46.89584847858974, 45.0347387450082, 46.67383616311209, 48.06457717078072, 47.20410878317696, 46.59603370938982, 47.24224049704415, 44.67210183824812, 45.307931491306846, 44.68198217664446, 44.88480356761387, 44.414757932935444, 47.11377872739519, 45.82524919509888, 48.28498445238386, 45.8203125, 45.02702624457223, 43.27513871874128, 37.065495422908235, 20.07057339804513, 9.224640369415283, 2.155475160905293, 5.869808205536433, 4.713182406766074, 7.815127066203526, 11.359494362558637, 11.00453087261745, 19.007040432521276, 16.041101115090505, 11.983551161629812, 8.61951654297965, 4.672959719385419, 0.6137287361281258, 0.3206986114382744, 1.362414070538112, 7.221126871449607, 21.205493892942155, 29.996238367898123, 41.69524342673165, 32.75128248759678, 27.848909752709524, 8.09485285622733, 0.5926626665251595, 0.19121374668819563, 0.16664634139410087, 0.1685354100274188, 0.13051653653383255, 0.19797538886112825, 0.16194653644093446, 0.07541061778153692, 0.09295925005738225, 0.10731107994381871, 0.08766770828515291, 0.15342963274036134, 0.17029767403645174, 0.09335933466042791, 0.16411182310964378, 0.12380482096757207, 0.22777400059359415, 0.09357398242822715, 0.0934971451227154, 0.16653168254664966, 0.1374834898327078, 0.17976056411862373, 0.16035786883107253, 0.07955271444682564, 0.1268333127456052, 0.11202607051070247], [0.007732458695370171, 0.05523096936355744, 0.006644602515734732, 0.009949643114980842, 0.01636204246564635, 0.07974243962338992, 0.029519445462418453, 0.07207787768649203, 0.0019656570012947278, 0.005979256097426904, 0.017297112915132726, 0.0037199079358418074, 0.04154218354129365, 0.05997908261737653, 0.01835726959896939, 0.06562612924192633, 0.026071037199082117, 0.034735473072422404, 0.08031135730977569, 0.040284630842506886, 0.05405401983963592, 0.029835303513599292, 0.03090485112209405, 0.038206983756806166, 0.06719302944839001, 0.04267777296315346, 0.036364622081496885, 0.041515310161880085, 0.11812883482447692, 0.09013475983270577, 0.028134631824546626, 0.10348587270293917, 2.1392402606351033, 10.248134340558734, 25.06775951385498, 28.414170026779175, 20.74997694151742, 19.49770658356803, 11.612744910376412, 4.19171575989042, 1.2008414204631532, 0.0780241514689156, 0.046975566273821254, 0.07064906614167349, 0.12018539304179804, 0.05685060191899538, 0.15329834978495324, 0.22346033634884016, 2.2352278871195654, 2.1899199868951524, 0.3651956894568035, 0.26019223247255596, 2.2173855645315985, 10.843317031860352, 24.62364455631801, 38.290709495544434, 46.725746154785156, 46.61416850771223, 48.361581393650596, 50.36192260469709, 49.044690064021516, 48.12062134061541, 42.67018338612148, 40.00694234030587, 38.67683826174055, 36.26262412752424, 39.00310134887695, 41.31878655297415, 44.58351578031267, 46.55245113372803, 48.37022147859846, 48.46762480054583, 47.21948167255947, 45.184927531651084, 44.08231094905308, 42.19542339869908, 46.93357024874006, 45.873320307050435, 46.33137335096087, 47.69242123195103, 44.82470859800066, 40.01700333186558, 36.82119328635079, 33.822368144989014, 37.43557385035923, 45.131145000457764, 46.52508217947823, 46.817660399845664, 46.67980466570173, 44.77575853892735, 33.91111748559134, 46.736627033778596, 46.0873977797372, 46.33628225326538, 42.46246351514544, 41.9519168308803, 41.514937673296245, 37.93532303401402, 35.89755882535662, 33.063569273267476, 32.334814412253245, 32.830693449292866, 33.141507216862266, 32.20685986110142, 33.73192344393049, 33.41086803163801, 36.50387600490025, 40.55261564254761, 44.25263908931187, 44.75203044073922, 44.26148762021746, 44.909563473292756, 45.50753934042794, 43.43918916157314, 44.57506677082607, 43.617035252707346, 43.603896209171836, 43.47744941711426, 44.609654903411865, 43.04436819893973, 42.4920836857387, 44.13536044529506, 46.107137611934114, 45.64488090787615, 43.912156513759065, 41.12258332116263, 25.36142339025225, 13.419743810381208, 4.2099929962839395, 1.5199798899037498, 2.3885891778128485, 2.758107841014862, 5.327092664582389, 6.796713096754892, 5.510416107518332, 5.475342903818403, 5.424737002168383, 5.610466258866446, 3.064859300851822, 0.7287690831082207, 0.0726201357319951, 0.2834405249782971, 3.7597692693982805, 11.4549435036523, 21.793141262871877, 28.598132269723074, 26.317141158240183, 26.507120541163854, 14.075481789452688, 2.160947301558086, 0.037721932998725345, 0.03694632336763399, 0.02828859650929059, 0.02804715508994247, 0.01131558754215283, 0.05876371104802404, 0.011348955349863639, 0.026805897409628545, 0.07204623081322227, 0.06628740911505052, 0.04135373740323952, 0.033453197950231175, 0.043953710568270514, 0.020275834149547985, 0.026308895953531777, 0.04598737840673753, 0.012333200928489012, 0.0037766495786075082, 0.06335577821092946, 0.03296554840302893, 0.026224213086866906, 0.019847810867109468, 0.03254839525158916, 0.053241002572966475, 0.11747779404478413, 0.027959515506933843, 0.004912677079638732, 0.031739825781966956, 0.03517855643959982, 0.0449238392258329, 0.03665993069963796, 0.10214153198259217, 0.043316457620156665, 0.023759539804554412, 0.05033192956554038, 0.04362635474119868, 0.01699584167051528, 0.040971725580415556, 0.04272087350753801, 0.06303478364965745, 0.05607454106211662, 0.07609335293195077, 0.035793702716806104, 0.04421565901221974, 0.05743717508656638, 0.051669976873589415, 0.04424709893230881, 0.061373824918908734, 0.045517927168735435, 0.0013520171778509393, 0.008192639448679984, 0.0347801546034004, 0.030118239045675312, 0.0878335829558117, 0.02645723897564624, 0.06627836424325194, 0.02552994793014867, 0.398761622607708, 6.047572221074786, 15.842092548097883, 32.15121521268572, 35.55935525894165, 25.820006234305247, 28.19530177116394, 15.935886280877249, 5.621048365320478, 1.217183149286679, 0.06070836527006967, 0.08993832394480705, 0.3924111862267767, 0.3644828205662114, 0.19323891587555408, 0.38343215946640286, 0.4922545201012066, 4.3540317586490085, 5.705014739717756, 2.2126481958798, 0.7577936628035137, 4.589138388633728, 13.743318813187734, 26.919030598231725, 41.99063914162772, 47.897733552115305, 47.41973570414952, 50.46701063428606, 50.175311361040386, 50.22538355418614, 47.86552517754691, 43.00138316835676, 40.61159542628697, 38.91884054456438, 38.04549019677298, 40.9354544367109, 43.665370396205354, 46.9545954976763, 49.28674793243408, 48.52842501231602, 49.77295855113438, 46.496160302843364, 46.135430676596506, 43.02267939703805, 43.21680511747088, 46.451313155038015, 48.52155671800886, 48.395026547568186, 48.66454717091152, 46.95376171384539, 42.34732491629464, 37.53591626031058, 35.31971536363874, 39.60005235671997, 45.68624005998884, 48.62352500643049, 48.330522945949006, 47.07921143940517, 45.47597367422921, 35.770066329411094, 48.49401405879429, 46.7414664540972, 47.10542699268886, 43.88078192302159, 43.67533411298479, 42.47600902829851, 38.656288964407786, 38.467641898563926, 34.504997389657156, 34.43623454230172, 34.245777470724924, 34.03814097813198, 33.92964833123343, 35.64061791556222, 33.8840959412711, 37.59383644376482, 41.26720660073416, 46.43622861589704, 45.37365102767944, 46.0509683745248, 46.73546668461391, 46.83049372264317, 45.571789332798545, 44.137854848589214, 44.26217201777867, 45.674282210213796, 44.381990228380474, 46.13611160005842, 44.349979877471924, 45.23200505120413, 45.01005526951381, 46.64246504647391, 45.28851127624512, 44.2559985433306, 41.09108018875122, 27.610499688557216, 14.067706755229406, 4.668255354676928, 2.335442623921803, 4.277953326702118, 3.903668633529118, 3.9060175589152744, 5.951347053050995, 7.207329486097608, 7.140689313411713, 7.092316823346274, 4.2170176250594, 1.5755347545657838, 0.3951406883341925, 0.04490492845486317, 0.18727798573672771, 3.5225579866341183, 11.198072944368635, 20.25872540473938, 28.781050545828684, 29.95811012813023, 31.711870193481445, 18.28180135999407, 3.788135724408286, 0.19406942916767939, 0.07073530115719352, 0.05919897090643644, 0.03657440814588751, 0.05075489097673978, 0.04535920764984829, 0.023901592807046006, 0.054671795440039465, 0.046008250143911154, 0.10235430020838976, 0.030721510960055248, 0.03909931837448052, 0.04422600327857903, 0.048724575101264885, 0.06697626465133258, 0.021555788681975434, 0.01395194121037743, 0.02884207752400211, 0.033643177577427456, 0.07018905332578079, 0.03245942573994398, 0.010183152459960963, 0.021196674023355757, 0.039615381575588665, 0.0369489289421056, 0.05182103912479111, 0.08687611576169729, 0.12892660684883595, 0.11465332417615823, 0.09682991914451122, 0.07340169272252492, 0.2578242266816752, 0.14016921286072048, 0.1707027323011841, 0.12772509774991445, 0.16692889694656643, 0.09271338289337498, 0.2115858785275902, 0.13345467458878243, 0.15322493229593548, 0.12570638821593352, 0.19472213914351805, 0.1069565996793764, 0.1223292380039181, 0.18625973537564278, 0.1583354544958898, 0.15305923404438154, 0.1971793994307518, 0.09810903907886573, 0.0670764639175364, 0.12880721182695457, 0.11107607398714338, 0.10053548709090267, 0.14525802194007806, 0.1814300316785063, 0.17464112596852438, 0.19997296881462845, 0.5509760262710708, 5.805444436413901, 17.587799651282175, 38.07940435409546, 41.84452894755772, 33.74320731844221, 32.152702127184185, 20.974516664232524, 7.115223731313433, 2.2064191358430043, 0.30429852860314505, 0.19134551818881715, 0.5893517956137657, 0.3890483666743551, 0.3000414270375456, 0.6071791904313224, 0.681534903390067, 8.148839490754263, 6.231966120856149, 1.7767418835844313, 0.5485575646162033, 2.8632935796465193, 12.014515808650426, 27.06523633003235, 41.69304084777832, 48.16989796502249, 48.35708243506295, 50.615483215876985, 54.24238729476929, 53.92676189967564, 51.51283611570086, 45.63498667308262, 42.36627612795149, 42.62905005046299, 38.15227706091744, 42.684996945517405, 46.39223609651838, 49.33777550288609, 49.834766251700266, 50.94815949031285, 51.030325412750244, 48.299058028629844, 46.31002153669085, 43.00075783048357, 43.58767911366054, 47.995824745723176, 47.70883287702288, 49.52575206756592, 49.880811963762554, 48.295476232256206, 44.525411469595774, 40.61824485233852, 37.0774359021868, 42.75714703968593, 47.42661789485386, 51.15938820157732, 49.93036651611328, 48.32626370021275, 44.856534821646555, 39.34075253350394, 50.84633016586304, 47.92675617762974, 50.233578954424175, 45.71572126661028, 45.27516726085118, 44.06233835220337, 40.00009141649519, 41.02075399671282, 36.80302722113473, 36.00407818385533, 35.61305788585118, 36.03506020137242, 35.23136901855469, 37.924935477120535, 36.07507487705776, 40.0006924356733, 43.36272076198033, 48.21861178534371, 48.1250820841108, 46.72222689219883, 48.36518056052071, 49.990996497017996, 46.378784384046284, 47.35427325112479, 46.96988500867571, 46.087613173893516, 46.11661148071289, 49.06010116849627, 45.80783353533064, 45.69271230697632, 46.39633205958775, 46.90174749919346, 47.702440534319194, 44.33710833958217, 43.123945917402, 26.635012558528356, 15.293560062135969, 5.028856873512268, 3.2302179591996327, 5.203979705061231, 5.32777749640601, 10.84975106375558, 13.448835917881556, 13.400717905589513, 13.806888750621251, 14.00937489100865, 12.04257437161037, 6.851665096623557, 1.773323152746473, 0.4280523237373148, 0.5506440326571465, 5.068558011736188, 15.786161286490303, 28.20088291168213, 37.23427064078194, 36.209039619990754, 37.06794466291155, 20.494222436632427, 4.351843076092856, 0.21028725749679975, 0.12157535845679895, 0.17178068017320974, 0.06758797075599432, 0.056161868519016674, 0.13956117763050965, 0.10132046389792647, 0.12593107830200875, 0.20169384218752384, 0.27330820581742693, 0.17999104889375822, 0.14809847809374332, 0.13021918891796044, 0.21854335947760514, 0.22416232153773308, 0.10636550068323102, 0.11774136418742792, 0.07761880821947541, 0.10694142085100923, 0.12619629049939768, 0.15195794456771441, 0.10830837035817759, 0.09796019563717501, 0.1369060022490365, 0.13618231751024723, 0.1230536148484264], [0.05029955665980067, 0.03200941453022616, 0.014194483552793307, 0.08620783340718065, 0.016005809884518385, 0.023212876370442764, 0.006836518936324865, 0.06917040262903486, 0.040843390859663486, 0.06416398127164159, 0.02180855824345989, 0.018443923609863435, 0.06429191904940776, 0.04147069309172886, 0.04495122829186065, 0.012106369216261166, 0.043457888066768646, 0.05547288406108107, 0.05087876432974424, 0.047949915419199636, 0.04726318709020104, 0.014226152478451175, 0.01227700974725719, 0.06325737706252507, 0.01274109462143055, 0.0391220187635294, 0.02654776572515922, 0.0736665724377547, 0.04492816488657679, 0.030191215486930947, 0.05430493191150682, 0.13087265885302, 0.4638750915016447, 4.999676176479884, 11.756288613591876, 28.225288459232875, 26.00545539174761, 16.663670131138392, 13.989519545010157, 8.055326291493007, 2.723453917673656, 0.12131937433566366, 0.20125420577824116, 0.04296218430889504, 0.17631439332451138, 0.1536056582948991, 0.08480534902108566, 0.1783398339258773, 1.382547018783433, 7.304353696959359, 3.1932730845042636, 0.6253481326358659, 1.0075679400137492, 1.7746641550745283, 7.566359843526568, 19.511629036494664, 33.66167368207659, 40.56646340233939, 48.21479375021798, 49.20523861476353, 48.06984390531267, 46.2262853213719, 45.14950214113508, 46.76042461395264, 46.55702999659947, 44.74205977576119, 42.96318892070225, 39.38980681555611, 38.623958996364046, 44.57899250302996, 46.160760334559846, 47.021579606192454, 48.71410172326224, 45.61870009558541, 45.7857208933149, 45.83841255732945, 45.15442493983677, 48.16199091502598, 48.01137828826904, 47.21168231964111, 46.61342852456229, 41.314544677734375, 36.89411115646362, 33.89574112210955, 37.526807171957834, 44.807928698403494, 47.31433153152466, 47.477325848170686, 44.00322307859148, 45.4151873588562, 34.16812787737165, 47.50135619299752, 46.52725696563721, 45.481518336704795, 42.30598660877773, 41.5526316506522, 38.819411822727744, 37.40851756504604, 33.56045232500349, 33.482472692217144, 33.190676144191194, 33.549248354775564, 33.08024842398507, 33.24668904713222, 32.32527800968715, 33.77870566504342, 40.724666936056956, 43.09917906352452, 46.85748747416905, 46.23369904926845, 44.586159569876536, 43.32319940839495, 39.94516243253435, 40.33355631147112, 41.68041249683925, 41.62613664354597, 40.322394030434744, 42.18988915852138, 43.49116516113281, 44.55217940466744, 45.82070854731968, 44.63357407706124, 43.13962800162179, 43.06228065490723, 42.84073734283447, 33.90017754690987, 20.188003165381296, 7.190939119883946, 2.1134554956640517, 1.6142685732671191, 3.5057583280972073, 3.1413852402142117, 2.494922237736838, 3.749185425894601, 6.598460146359034, 4.55616614648274, 4.460167663437979, 4.859313879694257, 1.0574889012745448, 0.249971975173269, 0.08922642535929169, 1.7091721722057887, 9.988776326179504, 18.42124649456569, 30.982149532863072, 27.189331156866892, 25.31453173501151, 22.495671885354177, 9.056976863316127, 1.1512531042099, 0.030467324956719364, 0.05846615308629615, 0.010800258007033594, 0.02336842713079282, 0.05271614216534155, 0.06492656642304999, 0.009139015987914587, 0.0681832902399557, 0.030303747127098695, 0.0587778381471123, 0.03445297519543341, 0.03941546480304428, 0.0726384629628488, 0.04688850683825357, 0.08126611714916569, 0.010715184134564229, 0.057340280285903385, 0.025815594209624187, 0.040824585261621645, 0.020277622089322125, 0.05629363323428801, 0.015065368830359407, 0.029998813489718095, 0.03281827237723129, 0.04933891052912388, 0.009799697902053595, 0.016283929514299546, 0.009286227552885455, 0.03302781077634011, 0.05565093504264951, 0.021794417573671256, 0.01387008953107787, 0.011133459413291087, 0.02593094007378178, 0.01192965664501701, 0.04726119219724621, 0.037003391555377414, 0.01218192748326276, 0.00752801270157631, 0.036570720308061154, 0.05456728069111705, 0.02895919606089592, 0.018762450000005107, 0.02630544051394931, 0.018200658627652695, 0.03834795279960547, 0.026021458341607025, 0.022170405701867173, 0.059351030604115555, 0.01557291132797088, 0.027278147604582564, 0.027222679063145603, 0.009210293547117283, 0.00816079495208604, 0.03824317342202578, 0.01738482035164322, 0.033736506676567454, 0.036518585069903305, 1.177677320582526, 9.242435574531555, 21.69144916534424, 32.328950132642476, 30.83891589300973, 23.13417833192008, 21.404467718941824, 13.981076615197317, 3.644777451242719, 0.3537101543375424, 0.05838111907775913, 0.19743393148694718, 0.8917292015893119, 0.5932550547378403, 0.4719914016979081, 0.789887392095157, 4.033099242619105, 10.80214548110962, 6.7819390552384515, 3.0903574526309967, 1.2878779215472085, 3.486097965921674, 10.72102873665946, 24.180618728910172, 37.250352246420725, 43.28996270043509, 48.183217661721365, 51.836608273642405, 49.44605622972761, 50.07464238575527, 48.38198477881295, 47.39520508902413, 48.17794050489153, 46.121999808720176, 41.82530328205654, 41.11869927815029, 40.02256883893694, 47.61419841221401, 48.51473011289324, 49.38459593909127, 48.44561985560826, 46.58185591016497, 44.577849524361746, 44.80029610225132, 45.99168634414673, 48.29401363645281, 49.67933504922049, 48.89771134512765, 47.22896596363613, 43.7504232951573, 38.248356751033235, 34.67070150375366, 39.21299253191267, 47.62440184184483, 49.583613191332134, 48.20606333868844, 44.79814216068813, 45.66569076265608, 37.31390741893223, 48.77276883806501, 47.96860865184239, 47.140810694013325, 44.16393838609968, 42.92225360870361, 41.08073779514858, 40.06257309232439, 35.71762132644653, 34.73712975638253, 34.24660430635725, 35.14724023001534, 35.60434137071882, 35.18583399908883, 34.04517602920532, 35.189836161477224, 41.005124023982454, 44.42831039428711, 46.32483162198748, 46.68163551603045, 46.362730571201865, 43.430882590157644, 41.602370330265586, 42.43977069854736, 43.084025042397634, 43.6868577003479, 43.81002146857125, 43.036690439496724, 44.49349839346749, 45.33837849753243, 46.15669911248343, 45.25961371830532, 45.09136308942522, 43.82813542229788, 44.216414655957905, 35.31630727222988, 22.42362948826381, 9.218635388783046, 2.900681184870856, 2.71515559724399, 4.206864135605948, 5.421434870788029, 4.351678490638733, 5.197054088115692, 7.20781455721174, 6.765361087662833, 7.643790568624224, 4.02869234766279, 1.0957600133759635, 0.10967048869601317, 0.04920293889673693, 1.3304226100444794, 9.475703971726553, 19.34868856838771, 34.34857259477888, 33.882421425410676, 29.03142888205392, 25.86313717705863, 11.729947992733546, 1.6842966441597258, 0.0385913738448705, 0.038442642361457856, 0.038011915116970024, 0.03775004131187286, 0.05164994651983891, 0.012785186675111098, 0.026769787472273623, 0.04327675314354045, 0.04187323059886694, 0.04039568327633398, 0.017236392512651424, 0.03788588402260627, 0.02668669237755239, 0.041194787182446034, 0.03824596559362752, 0.016849271321137036, 0.046129477210342884, 0.04756447020918131, 0.02925081005586045, 0.05567261762917042, 0.009391330082767775, 0.0321685920602509, 0.012391873003382767, 0.009300665081744748, 0.027860887049298202, 0.08093847294471093, 0.12357261271349021, 0.10963411921901361, 0.12187460597072329, 0.18132062469209942, 0.11867709111954484, 0.11103776389999048, 0.07809506516371455, 0.17536504140922002, 0.0885852776201708, 0.12000938105796065, 0.26486742017524584, 0.0647010010268007, 0.16199142831776822, 0.12260964938572474, 0.11650288850069046, 0.11282716252441917, 0.09937061209763799, 0.14575397675590857, 0.15369133012635366, 0.09980719509933676, 0.16176300628909043, 0.09964605660310813, 0.12299933204693453, 0.11875725324664797, 0.07360017778617994, 0.1642533383731331, 0.08716923610440322, 0.11089828424155712, 0.11577042351875987, 0.13162847901029245, 0.14966687107724802, 0.21838406659662724, 1.6719742310898644, 11.480140277317592, 22.174324648720876, 40.25082411084856, 37.9690773827689, 28.167991876602173, 23.912991489682877, 13.429072635514395, 4.029397589819772, 0.6667090217982019, 0.41439278955970493, 0.607732495026929, 1.5454385238034385, 0.584760990525995, 0.349616281156029, 0.6565870163696153, 8.85744023323059, 20.148106609072002, 9.606087786810738, 2.317768143756049, 2.013182350567409, 2.627930734838758, 9.276670217514038, 22.777909449168614, 37.080743244716096, 42.648654392787385, 50.29411860874721, 52.31033297947475, 52.41384376798357, 51.06160272870745, 51.18099362509591, 49.72968169621059, 50.44539131437029, 49.837045260838096, 45.82409232003348, 43.74931853158133, 41.629805292402, 49.11073963982718, 50.092012882232666, 50.69475521360125, 50.124638148716514, 46.99406473977225, 44.0075865473066, 47.00177724020821, 45.48283154623849, 49.589307240077424, 51.758899620601106, 50.81951011930193, 48.14761509214129, 44.78327301570347, 41.14509201049805, 36.13861615317208, 40.853097438812256, 47.63093662261963, 51.287033557891846, 49.69990519114903, 43.92486129488264, 46.57307686124529, 40.42548097882952, 49.6370587348938, 49.43758290154593, 48.55940702983311, 45.420600005558555, 46.01321186338152, 43.235850129808696, 42.20274332591465, 37.60533571243286, 37.07788406099592, 35.6234940801348, 35.410305976867676, 37.80170917510986, 35.42256607328142, 34.62736211504255, 37.67404644829886, 43.73473426273891, 46.55009569440569, 48.790702138628276, 48.793762820107595, 46.13252285548619, 44.51535742623465, 43.43503761291504, 43.060838903699604, 43.237083435058594, 44.73001854760306, 44.909983839307515, 45.241558824266704, 46.70154905319214, 46.95343862261091, 48.44925376347133, 45.6979512487139, 45.08452606201172, 43.994565623147146, 44.15512459618704, 35.47820724759783, 22.290359565189906, 7.806135228702, 3.2262188366481235, 4.931999853679112, 8.822004420416695, 8.02056358541761, 7.600090742111206, 8.785952823502676, 13.521522760391235, 12.70397686958313, 10.43375894001552, 8.777923311506, 4.918024855000632, 1.220868625811168, 0.33489405257361277, 2.329633495637349, 13.05940328325544, 25.055310079029628, 38.96272536686489, 35.85096767970494, 33.4073348726545, 30.4124493598938, 14.138131959097725, 1.9564485720225742, 0.151075577629464, 0.2036409798477377, 0.1424184614526374, 0.1906138810196093, 0.12221464700996876, 0.17231628857553005, 0.10070770606398582, 0.17455951177648135, 0.10180517538849797, 0.1290221717208624, 0.15341741911002568, 0.12268033916396753, 0.18386567384004593, 0.12030527660889284, 0.13483805821410247, 0.10995993137891803, 0.13812424402151788, 0.12338091300002166, 0.09741551522165537, 0.09951118419745139, 0.08229389414191246, 0.19841391247298035, 0.0820083733914154, 0.18473365583590098, 0.09872698770569903, 0.196636897112642], [0.026869469355525713, 0.016815984089459692, 0.014031429891474545, 0.007719293419670845, 0.03152817713895014, 0.017251754545473626, 0.02548790250771812, 0.026856215870273963, 0.039047481691730876, 0.042226285939770083, 0.04698893680636372, 0.023443478192867975, 0.04774411574804357, 0.043555257841944695, 0.029862845250006233, 0.04672472205545221, 0.04783438126157437, 0.03925240605271288, 0.036884284910878966, 0.029673744325659106, 0.006597726772140179, 0.05310312764985221, 0.010892229187967522, 0.03862253895827702, 0.03620267952127116, 0.023170847911387682, 0.03917042545175978, 0.03516860572355134, 0.07920284822051014, 0.027181395296273485, 0.01228088078953858, 0.06048937487815108, 0.10237800143659115, 2.3684793540409634, 5.062306804316385, 13.773500919342041, 23.851807389940532, 18.804417065211705, 15.78841597693307, 12.861872945513044, 6.417242441858564, 1.897206928048815, 0.10869503353855439, 0.18322957440146379, 0.8771937872682298, 0.6410374364682606, 0.32183950021862984, 0.6512154074651855, 2.607672393321991, 6.060188846928733, 4.8734252367700845, 3.033637136220932, 1.1724146029778888, 0.38915522236909184, 1.1844540940863746, 6.078183378492083, 14.50112235546112, 23.155212266104563, 36.275377546037944, 46.65929358346121, 50.754443713596885, 48.99801901408604, 45.06374052592686, 49.62128632409232, 46.38274138314383, 47.832868644169395, 45.44458171299526, 43.56076874051775, 38.58105387006487, 40.65818657193865, 45.32187305177961, 46.218607561928884, 47.05754695619856, 47.96098300388881, 44.048236983163015, 46.80874933515276, 47.31804186957223, 48.610045501164024, 45.936587129320415, 46.8398494720459, 44.4095641544887, 41.6145852633885, 37.692042282649446, 34.96224096843174, 37.20112773350307, 45.71013838904244, 46.03837823867798, 48.027626650674, 46.12649529320853, 45.287753922598704, 34.457930292402, 47.704584053584504, 45.48275164195469, 44.40546471732003, 43.2108678817749, 38.03069053377424, 37.70752286911011, 33.62040485654558, 31.63347019468035, 32.69385215214321, 36.77727024895804, 35.59096261433193, 36.992563656398225, 35.41745219911848, 34.10323517663138, 33.902324540274485, 38.53594963891165, 43.70387383869716, 46.64637688228062, 46.2331987789699, 42.68745313371931, 40.17363657270159, 41.589568274361746, 43.26332678113665, 44.85680232729231, 43.71884025846209, 43.07169198989868, 42.43073456627982, 43.60020324162075, 42.79247515542166, 43.496765409197124, 44.023195675441194, 47.2698769569397, 43.49814115251814, 41.865877287728445, 28.813783509390696, 16.88706166403634, 4.630294305937631, 1.0618423819541931, 1.2555601128510065, 3.058258295059204, 4.5927536232130866, 2.5209085004670277, 4.288820309298379, 5.358795123440879, 5.101845094135829, 6.390789781297956, 2.5493872123105183, 0.9719837180205754, 0.26373893501503126, 0.611433279301439, 7.163767755031586, 16.659902470452444, 25.2693840776171, 22.969349690846034, 23.60813753945487, 27.482199464525493, 18.253928661346436, 4.5640345471245904, 0.2593046272439616, 0.031006746725844483, 0.04171255350645099, 0.0530020734295249, 0.01924637608629252, 0.02574141336871045, 0.02771862200461328, 0.06441183654325348, 0.03952475304582289, 0.031592410656490495, 0.009793501180995787, 0.02361918822862208, 0.008961711394866663, 0.04070645910022514, 0.00060050481676756, 0.04487080492877534, 0.022827482050550834, 0.01746452446760876, 0.02815793441342456, 0.03010759622390781, 0.0584346487053803, 0.02404725391949926, 0.019567794731951187, 0.0708361721730658, 0.07364528000886951, 0.07589240478617804, 0.019635120672839027, 0.009689709071868231, 0.01791639147060258, 0.0061794888128393465, 0.02888702368363738, 0.02255922831994082, 0.02435399585270456, 0.11122994537332229, 0.10812486056238413, 0.052700556215963194, 0.05588970812303679, 0.1175306790641376, 0.060665251154984744, 0.06199937992330108, 0.03343274011941893, 0.0637991533481649, 0.03759425984961646, 0.03768063057214022, 0.01796730195305177, 0.0050360025156156295, 0.0181439263147435, 0.06924298551997968, 0.019853876970176185, 0.06162301690450736, 0.06251580614064421, 0.017820205739034072, 0.014796102386234062, 0.053872291198266406, 0.0246479134740574, 0.08885745158685104, 0.008476477432330804, 0.07395178784749337, 0.017283603282911435, 0.16766936864171708, 4.187656709126063, 10.412154385021754, 27.205598626817974, 33.50809070042202, 23.523025580814906, 20.640554973057338, 15.283801317214966, 8.470961451530457, 1.6917061379977634, 0.06955161038786173, 0.1295166609010526, 0.29139241256884163, 1.3666323870420456, 1.511527406317847, 2.9988522827625275, 7.466835583959307, 6.121317795344761, 7.001450453485761, 5.646266417843955, 2.005953401327133, 1.3913902299744743, 2.498230448790959, 7.268970429897308, 17.889686720711843, 25.891015086855205, 40.755263328552246, 48.2621283531189, 52.0371367590768, 47.91119221278599, 47.81419883455549, 51.58609792164394, 48.597872257232666, 50.60918467385428, 47.9989583832877, 44.85900838034493, 40.930785247257774, 43.21935510635376, 47.82304736546108, 47.38185065133231, 49.67858811787197, 47.2551155090332, 45.04111024311611, 45.643873419080464, 47.37510742459978, 48.913480281829834, 48.88349185671125, 46.67613254274641, 46.93467501231602, 42.410692487444194, 39.68825626373291, 36.3808650970459, 39.70608881541661, 46.27401944569179, 49.23403194972447, 49.9530211176191, 46.32107612064907, 45.27766513824463, 37.8245062146868, 48.23365463529314, 48.53941706248692, 46.332068170819966, 44.95623452322823, 40.50282137734549, 40.144940512520925, 34.91625779015677, 33.39449460165841, 33.791386127471924, 38.061821937561035, 36.35032776423863, 38.10511268888201, 36.60062272208077, 35.28330332892281, 34.40598208563668, 41.128815855298726, 45.07468046460833, 49.50050231388637, 46.11422824859619, 44.01174504416329, 42.18327794756208, 43.40384020124163, 44.10869325910296, 46.20256069728306, 46.49975252151489, 44.958193915230886, 44.11572483607701, 43.98455326897757, 43.25308861051287, 45.978793961661204, 45.24736751828875, 48.14984546388899, 44.76984214782715, 42.242956025259836, 30.628027643476212, 19.512143203190394, 6.227009015423911, 2.655839477266584, 3.0469260002885545, 5.270480479512896, 6.130921074322291, 5.875944333417075, 6.370944423334939, 7.578751955713544, 5.887916079589298, 4.156291237899235, 1.2953204193285532, 0.40322266465851236, 0.07679632199662072, 0.7080352785331863, 6.1496807762554715, 17.401122399738856, 27.280936207090104, 30.15095738002232, 25.368880544389995, 32.40427555356707, 21.403930970600673, 6.7906820603779385, 0.5519311864461217, 0.056954438132899146, 0.014147593390329607, 0.05583629723904388, 0.02806037464844329, 0.030513336416333914, 0.0446060032450727, 0.02087197805355702, 0.0073317099761750016, 0.04332699187632118, 0.013481133750506809, 0.04496771330013871, 0.0717008700594306, 0.019338965582262193, 0.023185867284025465, 0.05889960125620876, 0.013763929334735232, 0.029665690114987747, 0.04019350019682731, 0.049070665280201604, 0.025943360657298138, 0.03108142628999693, 0.026228637135188495, 0.033200236702603955, 0.04770296259916254, 0.03925795307649033, 0.018240388549332107, 0.11813606800777571, 0.09329459563429866, 0.06292520702949592, 0.1248781548014709, 0.10057534423789807, 0.10737541863428694, 0.1729471632944686, 0.17687316691236837, 0.1666421073355845, 0.14892831285084995, 0.1850503824119057, 0.06483375640319926, 0.13550266969416822, 0.1659545749425888, 0.13802615499922208, 0.17984725375260624, 0.12350367355559554, 0.21272827365568706, 0.18962406127580575, 0.06541694368102721, 0.1567229295947722, 0.12852351633565767, 0.11824326297002179, 0.10537114154015269, 0.10092327663941042, 0.09081998520663806, 0.12015918801937785, 0.10273601008313042, 0.1387421451508999, 0.13264028328870023, 0.15746697038412094, 0.1634025504546506, 0.22207163300897392, 5.063623922211783, 13.375562821115766, 29.458034379141672, 40.56686987195696, 31.527440684182302, 28.9349878856114, 20.473403896604264, 10.545854227883474, 2.551970205136708, 0.4524911737867764, 0.6801133996673993, 4.080916745322091, 3.9648275460515703, 2.197623150689261, 2.708123586007527, 11.766290545463562, 12.461714029312134, 10.272935935429164, 7.151997940880912, 3.1789374308926717, 1.4772654048034122, 2.0742290062563757, 7.513398936816624, 16.75492603438241, 24.960812841142925, 39.7128563608442, 50.29724529811314, 54.62896074567522, 50.85462978907994, 48.282799243927, 54.38720512390137, 49.04884508677891, 51.45835181644985, 50.12683377947126, 46.79043735776629, 43.88788645608084, 44.94403001240322, 49.322722230638774, 50.21481534412929, 50.60863924026489, 48.64631162370954, 44.81818076542446, 47.300393445151194, 48.79869951520647, 51.60479899815151, 48.929989201681956, 48.66554423740932, 47.75789410727364, 45.303953647613525, 41.772177355630056, 38.80267013822283, 41.088537148066926, 48.73083298546927, 50.83453907285418, 52.3340402330671, 47.321936334882466, 45.07715054920742, 41.1434383392334, 49.60305077689034, 48.853736196245464, 47.89273432322911, 46.48222916466849, 42.03176205498831, 41.59166315623692, 36.47250141416277, 34.74390772410801, 35.08530746187483, 39.9957731110709, 38.62297235216413, 40.4115880557469, 38.70722273417881, 36.342952251434326, 35.57606220245361, 42.155214173453196, 46.74649347577776, 49.78913743155343, 47.47378921508789, 43.96175275530134, 43.7624054636274, 42.68206480571202, 43.95877545220511, 46.88529069083077, 46.689889975956504, 45.3976605279105, 44.30429547173636, 45.93272393090384, 44.56483902250017, 47.14389222008841, 45.052314213344026, 50.25210632596697, 44.85743113926479, 45.40600878851754, 31.352460724966868, 19.558635337012156, 5.498790902750833, 3.527656444481441, 4.894438760621207, 9.556448119027273, 11.087223989622933, 8.73843583038875, 9.6739456312997, 16.43450117111206, 15.075028794152395, 14.639166559491839, 6.450579464435577, 1.008818507194519, 0.6623435989022255, 1.1109495354550225, 9.420899186815534, 22.001524686813354, 32.600131375449045, 32.212953431265696, 32.54989242553711, 38.301951680864605, 24.31645601136344, 7.279661101954324, 0.7281522676348686, 0.12316752730735711, 0.06601922493427992, 0.1736278153423752, 0.13047621798302445, 0.1075191255658865, 0.12897350718932493, 0.18549449715231145, 0.14653806468205793, 0.11130919147815023, 0.19667242520621844, 0.13498577528766223, 0.14824178468968185, 0.16580148387168134, 0.10879861190915108, 0.2041187770664692, 0.11706248990127019, 0.22532960533031396, 0.16394053372953618, 0.08452322773103203, 0.12590894448970044, 0.138038341488157, 0.09678794496825763, 0.17064365904246057, 0.18129547818430833, 0.13595503542040074, 0.08521280929978405], [0.02576840718808983, 0.036455430423042605, 0.01009855356200465, 0.0844951770933611, 0.010031841695308685, 0.04770645366183349, 0.02191694742733879, 0.048174982092210224, 0.034578707734388966, 0.05356924728091274, 0.037051228274192126, 0.044537026767752, 0.046192988088088374, 0.02536081798773791, 0.032210020015814474, 0.02220455976203084, 0.0165234472868698, 0.05401619829769645, 0.01343858621216246, 0.06726422812789679, 0.006466942115886403, 0.030493143214178935, 0.00696711233052026, 0.03755048755556345, 0.014455055418823446, 0.024280656395213943, 0.07124918286821671, 0.060837103719157834, 0.06750184430607728, 0.021263991482555866, 0.08244462391095501, 0.01975327397563628, 0.051045534666627645, 0.4412363405738558, 3.50398936016219, 8.034753543989998, 20.734548466546194, 25.53585617882865, 16.85691343035017, 17.690235206059047, 6.692901798657008, 4.527566492557526, 0.7663793563842773, 0.1017320564548884, 0.11084544671965496, 0.789026792560305, 0.7139532981174332, 3.4380481328283037, 5.1656017644064764, 5.293548498834882, 5.3114496639796664, 6.4332332866532465, 0.8381461054086685, 0.9784238295895713, 0.418964541384152, 0.24130838577236446, 3.071812710591725, 8.87696293422154, 19.623614890234812, 32.194050856998985, 41.012002740587505, 49.635116713387625, 49.539957659585134, 47.50749840055193, 48.14615944453648, 47.724292618887766, 48.523325034550254, 47.13977888652256, 42.04973357064383, 38.77331052507673, 43.71765906470162, 46.90816763469151, 49.68484149660383, 48.738194601876394, 46.05885457992554, 45.942076206207275, 46.86481434958321, 47.11623838969639, 45.449216161455425, 45.92062016895839, 41.391627992902485, 39.07242700031826, 36.02633326394217, 36.867694105420796, 36.16609975269863, 44.94784804752895, 47.227565901620046, 47.5096731867109, 48.677088669368196, 47.4477994782584, 35.76621355329241, 48.06418807165963, 47.923817089625764, 43.59656585965838, 42.03432594026838, 35.53047159739903, 33.47043146405901, 32.68399265834263, 33.068148136138916, 33.620519501822336, 35.864405495779856, 36.7818386895316, 37.55720206669399, 35.41878277914864, 33.63930395671299, 33.1358757019043, 37.47271544592721, 44.48371532985142, 44.933760574885774, 45.58175999777657, 42.063605649130686, 43.885454586574006, 45.65574441637312, 44.08325937816075, 45.180376461574006, 43.580564158303396, 42.331879070826936, 41.012304987226216, 41.5175085067749, 42.19830690111433, 41.60413864680699, 42.44933141980852, 46.49839414869036, 43.338450704302105, 34.86001212256295, 20.98351284435817, 12.65491737638201, 4.927933854716165, 1.4337955202375139, 1.9060422139508384, 3.112022804362433, 3.632854776723044, 4.314271994999476, 3.96499126298087, 3.090142709868295, 3.7112300225666592, 3.2565846358026778, 1.377851230757577, 0.41610191070607727, 0.39398479035922457, 4.939170394624982, 15.740954569407872, 23.61540535518101, 25.61345018659319, 24.48142535345895, 29.238200323922293, 21.31947214262826, 8.10737611566271, 1.6361916597400392, 0.037528438560132465, 0.027345624519512057, 0.031613960928682766, 0.03658739869881954, 0.05317294890327113, 0.04459789475159986, 0.005296758434269577, 0.05763430308018412, 0.016802667839718715, 0.015303159731307199, 0.0526807735274945, 0.03557717201433011, 0.011875457812233694, 0.03694893233478069, 0.011069654220981258, 0.042810915104512653, 0.050645992891596894, 0.1009457293631775, 0.059233284422329495, 0.004686679965483823, 0.004936938523314893, 0.035967003953244, 0.05294832667069776, 0.010038802616431244, 0.034925110039434264, 0.056832688594503064, 0.037301271821239164, 0.04985854960978031, 0.033959235796438794, 0.004856775123958609, 0.05816546707813229, 0.06432969309389591, 0.06600889763129608, 0.027791364351287484, 0.07795073397989784, 0.007122655881435743, 0.022849159548059106, 0.026419719381790076, 0.03232054997767721, 0.03436918290598052, 0.018914277299440334, 0.017020715067961385, 0.05186062485777906, 0.026854334631934762, 0.05687727513057845, 0.0024015103658062537, 0.027317282111783112, 0.06032833816217525, 0.015887967011492168, 0.027302827619548355, 0.03753059630149177, 0.011043392371253243, 0.007534195851933743, 0.06065918505191803, 0.05456266665299024, 0.015101054683327675, 0.019878265215083957, 0.07022303435951471, 0.060575175631259165, 0.018774855316483548, 1.2796089138303484, 6.51856107371194, 12.976316724504743, 29.869412899017334, 30.546285561152867, 22.58843728474208, 22.323356560298375, 12.628961512020656, 6.818407544067927, 1.0399106102330344, 0.11017318136457886, 0.06355317083320447, 0.8550805481416839, 2.7448658772877286, 5.594972210271018, 5.645243729863848, 6.479004544871194, 8.740764345441546, 7.635035838399615, 3.386619955301285, 3.0940056911536624, 1.756576691355024, 0.8843479348080499, 7.022471794060298, 11.414605736732483, 22.633511986051285, 36.23939282553536, 44.24702147075108, 52.12927334649222, 51.57269137246268, 50.21076454435076, 51.02014977591378, 49.751426083701, 49.78524991444179, 48.8659302847726, 42.22336210523333, 39.60524960926601, 45.50468363080706, 48.08963932309832, 49.38259138379778, 49.628446442740305, 45.39018079212734, 46.03207969665527, 49.707680225372314, 49.29352937425886, 47.28340857369559, 47.638933999197825, 43.52578108651297, 41.59879200799124, 37.32619530814034, 38.101312024252756, 38.37306996754238, 47.20959786006382, 48.8491712297712, 48.31902020318167, 48.251466342381065, 46.75080483300345, 38.286978312901084, 49.27934810093471, 49.241720131465364, 45.257046358925955, 44.40128190176827, 37.19915097100394, 35.76148877825056, 34.44804300580706, 34.5755216053554, 34.73539965493338, 38.07395349230085, 38.82710347856794, 39.18518584115164, 37.41464935030256, 35.55169139589582, 34.990214415958945, 37.6288275718689, 46.32654782703945, 46.04824120657784, 46.736755575452534, 43.7717855317252, 45.365591117313926, 45.08700656890869, 44.25819417408535, 45.67138133730207, 45.119044712611604, 43.007817200251985, 42.46957499640328, 42.89207410812378, 44.54012428011213, 43.25360625130789, 45.23269292286464, 45.41821329934256, 45.17474147251674, 36.404384749276296, 24.738032749720983, 12.267714244978768, 5.316696422440665, 1.6427287203924996, 3.2528571443898335, 3.5967143731457845, 4.931224695273808, 5.387061263833727, 6.748251148632594, 5.403442510536738, 4.309577618326459, 1.8359824419021606, 0.384989397334201, 0.014621688352365578, 0.5730629382388932, 3.6582174386296953, 17.082068068640574, 26.203616278512136, 30.53847231183733, 26.983462980815343, 31.153248923165457, 26.94062386240278, 11.089392696108137, 2.2577608951500485, 0.18142343631812505, 0.023530921000721197, 0.017802361964381168, 0.038010008433567624, 0.031670028277273686, 0.018690343779910887, 0.028316075481208305, 0.047826221877975125, 0.05472158633970788, 0.010636329035540777, 0.034725335759243796, 0.02001771773211658, 0.02273584759261991, 0.03186549386009574, 0.033955741341092756, 0.03344595119623201, 0.04013281202475939, 0.05623223599312561, 0.03346953368080514, 0.008835196844302118, 0.006492779457143375, 0.033155544993600676, 0.03111851162144116, 0.02619356196373701, 0.06959803575383765, 0.03100771703092115, 0.02481004093507571, 0.0931027534284762, 0.18092571731124604, 0.06903650052845478, 0.17846255376935005, 0.10041780876261847, 0.11551794063832078, 0.13578603948865617, 0.16460996280823434, 0.09837028184639555, 0.16716193301337107, 0.11730319341378552, 0.094629525073937, 0.1594107017985412, 0.10845776341323342, 0.1620788371988705, 0.12300725733595234, 0.1711989449603217, 0.11048182658851147, 0.11378112847783736, 0.16597457815493855, 0.13449402738894733, 0.1141040093664612, 0.18701806611248425, 0.08947661479136773, 0.16237154363521508, 0.07718282911394324, 0.1972713273550783, 0.09202468342014722, 0.17441551307482378, 0.16586879454553127, 0.16736115089484624, 0.12179485096463136, 0.10394490842840501, 1.3921987180198943, 8.475350107465472, 17.839664902005875, 34.11918476649693, 39.029556615012034, 27.05088308879307, 28.254800932747976, 12.202607018607003, 6.904775389603206, 1.5512107397828783, 0.3704823729182993, 0.8725629757557596, 2.2364579354013716, 8.515872870172773, 11.697273220334734, 10.752621327127729, 11.747223820005145, 14.057512879371643, 13.285264032227651, 3.5435513172830855, 3.002641439437866, 1.3095153719186783, 0.540613982294287, 4.104388194424765, 10.455599733761378, 22.028700828552246, 34.50585896628243, 43.71012374332973, 52.79632125582014, 52.16347585405622, 52.18460880007063, 52.59811346871512, 52.52621003559658, 51.64887489591326, 51.43852513177054, 45.494372504098074, 41.98716156823294, 46.758517333439414, 50.38030753816877, 52.10379777635847, 51.96143960952759, 45.40469210488455, 48.083024638039724, 50.43793589728219, 51.08372926712036, 49.11114263534546, 50.44708667482649, 44.729646818978445, 42.83895860399519, 39.4493077141898, 40.23092794418335, 40.23153591156006, 48.48084027426583, 50.60625948224749, 50.423452377319336, 50.01600306374686, 47.66136278424944, 42.08269929885864, 50.68214423315865, 52.04751736777169, 47.613051959446494, 47.47287205287388, 37.23270034790039, 36.78020586286272, 36.052639143807546, 36.705467564719065, 37.09466396059309, 39.48769303730556, 41.26134926932198, 40.68992246900286, 38.427321502140586, 37.04251773016793, 36.85242543901716, 40.690613814762656, 47.92777408872332, 48.0825069972447, 48.101239340645925, 44.65600981031145, 45.75677817208426, 45.567665576934814, 45.25165455681937, 47.247955390385215, 46.75201729365757, 45.81307942526681, 44.628237860543386, 43.74537195478167, 46.155959129333496, 45.39487777437483, 46.122541768210276, 49.209932122911724, 45.93924828938076, 37.71403680528913, 22.655808755329677, 14.214872206960406, 7.575781600815909, 3.1139852362019673, 5.6223190171378, 6.232647478580475, 9.083681396075658, 10.714924744197301, 9.98771151474544, 9.968379020690918, 9.61301861490522, 9.209978801863533, 4.2332282066345215, 1.1425675302743912, 1.0529281688588006, 6.777456598622458, 19.16526828493391, 30.63492373057774, 34.87008006232125, 34.06058018548148, 37.213658809661865, 29.92357063293457, 11.861432228769575, 2.44423491188458, 0.3661137473370348, 0.1050993339823825, 0.12390930178974356, 0.09528817901653902, 0.16612971840160234, 0.12240752737436976, 0.10470806354922907, 0.22981487108128412, 0.11325094157031604, 0.11432514392903873, 0.1771078993167196, 0.08925245396260705, 0.11731301860085555, 0.14938028502677167, 0.11674678112779345, 0.10788656584918499, 0.07190052898866789, 0.2836252222103732, 0.10312615414815289, 0.1534504909068346, 0.06125625515622752, 0.1536659664873566, 0.2724768647125789, 0.08183100433754069, 0.22019895778170653, 0.17977245205215045, 0.13205007995877946], [0.018796799138986638, 0.02609654333043311, 0.07793544658592769, 0.029037024027534893, 0.025091529491224458, 0.026586644085390226, 0.0905756786731737, 0.0032883516063780655, 0.053417207939284186, 0.008352029020898044, 0.029324967148048536, 0.05410728823127491, 0.034068096562155654, 0.03342518802466137, 0.03002443497202226, 0.06831237474190337, 0.05951353974108185, 0.016534670256078243, 0.01918908567833049, 0.020691837184131145, 0.05161816054689033, 0.024572507877435004, 0.0332446943170258, 0.0639514708891511, 0.041261337897075076, 0.02552754930885775, 0.04863206363682236, 0.03551776288077235, 0.044609019333230596, 0.054462457208761146, 0.04834949112098132, 0.08259973701621805, 0.0065491326386108994, 0.01960764509359641, 2.01248014824731, 6.296988666057587, 12.942421674728394, 24.322905676705496, 18.20214547429766, 10.745482053075518, 10.880324006080627, 9.100264140537806, 4.1170165453638345, 0.58595971763134, 0.08250311362956252, 0.49248875038964407, 1.5052549200398582, 3.3509448638984134, 5.041080491883414, 6.2432235053607394, 5.4625517044748575, 6.487597295216151, 3.849310270377568, 2.880955900464739, 2.6195273229054044, 0.7307175642677716, 1.8242992631026675, 1.6856149562767573, 7.900047949382237, 14.298516358648028, 27.4418842792511, 38.374695846012656, 47.059037344796316, 49.42270680836269, 47.26453726632254, 48.7949891771589, 50.95219986779349, 46.8429205758231, 45.631919043404714, 42.49350111825125, 44.2545394216265, 45.729232038770405, 48.77091714314052, 47.26793840953282, 46.28014080865042, 45.01614536557879, 48.38123089926583, 47.94873332977295, 45.37074668066842, 42.24767732620239, 39.769939286368235, 36.729254722595215, 34.191873346056255, 35.86350222996303, 37.47223254612514, 42.17942517144339, 48.03609650475638, 49.055143628801616, 48.37620040348598, 47.611648423331125, 36.95912545067923, 44.66771057673863, 48.24896846498762, 43.82968487058367, 41.676504135131836, 35.88556623458862, 34.555403096335276, 31.993789877210343, 34.73127589906965, 34.06669807434082, 36.831077098846436, 35.66183771405901, 37.94058976854597, 36.15402030944824, 34.588980266026084, 33.98820080075945, 35.55472081048148, 41.6019742829459, 44.16405650547573, 43.056902749197825, 45.67832953589303, 41.38379389899117, 43.033268451690674, 44.9684042930603, 45.54775203977312, 42.347151211329866, 40.92561231340681, 39.693140847342356, 39.720923219408306, 40.667073317936485, 41.68243094852993, 42.4674141066415, 44.328294549669536, 41.80690097808838, 27.614934376307897, 18.088412148611887, 6.854975044727325, 1.6148056473050798, 1.6514875761100223, 2.3347367303712026, 3.347433635166713, 4.015868578638349, 5.001140943595341, 6.9161695667675565, 4.565514079162052, 3.0345134777682166, 1.0036710862602507, 0.11525964949812208, 0.456689079957349, 3.063128113746643, 13.89819415978023, 20.29703082357134, 29.095294986452373, 18.9669006892613, 24.57778297151838, 25.799852984292166, 13.855850969042097, 3.2737380010741095, 0.26530990643160685, 0.044263149678174935, 0.056702168990990946, 0.02057667282809104, 0.03771056753716298, 0.030311702950192348, 0.04058833972417882, 0.052814634915973456, 0.05461585362042699, 0.029932215277637755, 0.047061251675976176, 0.006583477536748562, 0.032507191212581735, 0.04931479539456112, 0.056801520088421445, 0.026771519432908723, 0.05605556922299521, 0.016904853517189622, 0.050106187750186236, 0.06315661461225577, 0.04379954741203359, 0.03443738246070487, 0.01783679422390248, 0.03688287016536508, 0.08079182795648064, 0.03971428483990686, 0.06930394510605506, 0.024358246874596392, 0.14871218587671006, 0.005979463898776365, 0.06413411894547087, 0.0277900259409632, 0.027354839025065303, 0.042855253975306234, 0.03604080820722239, 0.023540836093681197, 0.03930528089404106, 0.02152153623423406, 0.02181121301172035, 0.025898767335872565, 0.019069334425564324, 0.04901016031258872, 0.02237645473464259, 0.04135929799771734, 0.03861133973779423, 0.12168969160744122, 0.0144486025507961, 0.07732558609651667, 0.03873867361939379, 0.013196515451584543, 0.020430752175993154, 0.03209786156990698, 0.033690644494657, 0.041578067865754874, 0.011826839929978763, 0.05557464735050287, 0.04284095384978822, 0.01493017581690635, 0.040085711516439915, 0.0920112416414278, 0.10838282600577388, 0.07842443963246686, 3.5888859246458327, 9.382262860025678, 19.977993862969534, 31.46849911553519, 22.186065367289952, 17.130795785358973, 12.229416642870222, 10.79338640826089, 3.904904978615897, 0.5708221984761102, 0.14487205765077046, 0.20854039623269013, 0.847564117184707, 4.126492585454669, 6.3077583738735745, 7.959686074938093, 6.630325019359589, 8.244441492216927, 6.515630236693791, 3.4971725259508406, 4.385975233146122, 1.5627041459083557, 2.0630543487412587, 3.4190986582211087, 9.365232825279236, 19.454096215111868, 30.486607483455114, 41.57559197289603, 48.43933868408203, 50.92836059842791, 47.874752385275706, 50.66252252033779, 51.59182671138218, 49.17749793188912, 46.79153169904436, 43.43763971328735, 44.97468546458653, 48.66076387677874, 50.99601520810808, 48.92743226460048, 44.413076468876426, 46.06398235048567, 49.903862612588064, 48.76867982319423, 46.96684864589146, 44.69425964355469, 39.74730205535889, 39.2354074205671, 35.62880597795759, 38.88214363370623, 38.87054361615862, 44.19537551062447, 49.23725938796997, 51.5609940801348, 49.5697272164481, 47.023518153599326, 38.21146876471383, 46.87754692350115, 49.479751518794465, 44.767514501299175, 43.042519978114534, 38.295125075748985, 36.20576007025582, 34.68059573854719, 35.433294091905864, 35.96365703855242, 37.51840679986136, 38.088377952575684, 39.14132881164551, 38.717144761766704, 36.26540340696062, 36.5780098097665, 37.21871362413679, 43.63649715696062, 44.924251965114046, 44.035692010607036, 46.64768661771502, 42.36596345901489, 42.108435426439556, 45.36304807662964, 46.41764565876552, 44.26323856626238, 42.6175924709865, 42.39859914779663, 40.580801010131836, 41.81392560686384, 42.410237380436485, 44.069074630737305, 44.38433524540493, 42.59580292020525, 28.921009847096034, 18.930827379226685, 8.270040392875671, 3.2154849554811205, 2.559675540242876, 3.952551816190992, 4.6722718477249146, 6.085756480693817, 6.745636020387922, 7.2122566274234226, 5.234306854861123, 2.0194824125085558, 0.314188366489751, 0.0987800695002079, 0.37920887608613285, 2.2922296055725644, 14.247568692479815, 22.63565376826695, 30.465929644448416, 24.52771598952157, 28.37953325680324, 29.426781381879533, 17.09811840738569, 4.77610181910651, 0.4004092141985893, 0.03611567097582987, 0.061494882351585796, 0.050689022189804485, 0.03447900040607367, 0.07515797205269337, 0.009218558951813196, 0.09581792487629823, 0.037627891437815766, 0.03930266514154417, 0.02647015149705112, 0.025083258149347136, 0.05778647134346621, 0.034884011173354726, 0.028512831976903335, 0.037885962054133415, 0.048372144012578895, 0.018991123086639812, 0.02604281353498144, 0.010792502351770443, 0.03268075707767691, 0.039571029134094715, 0.011694204993546009, 0.025300341857863323, 0.015234892323080982, 0.030893899566893066, 0.058963369977261336, 0.048317426948675087, 0.19367741234600544, 0.19892896126423562, 0.200475437566638, 0.1766061633825302, 0.11910209831382547, 0.12235407238560063, 0.17022847703525, 0.1169920986784356, 0.09455034682261092, 0.07331050440136876, 0.15170715802482196, 0.17057925249849046, 0.15728034611259187, 0.13669617207986967, 0.11717135405966214, 0.15613854809531144, 0.10209284030965396, 0.24424687666552408, 0.150262285556112, 0.21802546083927155, 0.17252739439053194, 0.08082648752523319, 0.10362450419259922, 0.16777771711349487, 0.11816732133073465, 0.12136783530669552, 0.1088059807994536, 0.17280712723731995, 0.13657364222620214, 0.10947760154626199, 0.19396299416465418, 0.1752520381872143, 0.20286848129970686, 0.18439536541700363, 3.9112538950783864, 11.739885653768267, 25.686842271259852, 38.2340087209429, 27.669211966650828, 20.15042383330209, 16.8933584690094, 13.884587849889483, 6.099455722740718, 1.659913786820003, 0.28366430582744734, 1.5332792848348618, 5.030107983521052, 12.990036811147418, 15.005418266568865, 16.51661671910967, 14.002622979027883, 13.10543509892055, 9.76463873045785, 6.499542985643659, 6.262549485479083, 1.5678153059312274, 3.5404383071831296, 2.866414189338684, 9.809940116746084, 15.986199923924037, 30.025914124080114, 40.012188230242046, 47.83900737762451, 50.504339831215994, 49.10944727488926, 50.74447652271816, 53.200654302324565, 50.629032203129356, 49.76923431668963, 45.02982289450509, 46.99963024684361, 49.26521546500069, 53.01888247898647, 49.22665296282087, 46.01771082196917, 46.79833745956421, 51.10461902618408, 52.16816241400582, 48.82891723087856, 46.187771456582205, 42.77662631443569, 40.64484255654471, 37.18624816622053, 40.39773334775652, 40.343662466321675, 47.11880922317505, 52.04731934411185, 54.00990056991577, 51.61531162261963, 46.84262875148228, 40.75397443771362, 47.94425174168178, 50.995184898376465, 46.05670758656093, 44.97729451315743, 39.14550815309797, 37.94121510641915, 36.38633680343628, 37.84083795547485, 37.98089974267142, 39.997961793627056, 39.71838365282331, 41.00207029070173, 41.15087638582502, 38.29137304850987, 37.67868089675903, 37.95853696550642, 44.647592067718506, 48.314024448394775, 46.74063267026629, 47.51039579936436, 42.83203819819859, 43.951809883117676, 46.30269466127668, 48.41216427939278, 45.13937166758946, 44.18702725001744, 43.95731633050101, 43.134260518210276, 43.60947561264038, 44.943599224090576, 45.68600034713745, 47.258871010371614, 44.821838991982595, 29.540158612387522, 21.32706478663853, 9.552398187773568, 3.5836969230856215, 4.025580423218863, 7.55265017918178, 8.314540999276296, 9.019703251974923, 13.061938507216317, 12.886597241674151, 10.282950026648384, 7.121022003037589, 2.6588026668344225, 0.6212490211640085, 0.8341219042028699, 3.913701832294464, 16.752270085471018, 26.752690723964147, 38.05185127258301, 26.592057057789393, 33.253300258091514, 35.04548733575003, 19.341005597795757, 4.901099043233054, 0.4555506610444614, 0.11532454458730561, 0.138592786022595, 0.2937585727444717, 0.12566897379500525, 0.14114695468119212, 0.10700192581862211, 0.14617738260754518, 0.09106416960379907, 0.13329196189131054, 0.11999381546463285, 0.13658753862338407, 0.12321919096367699, 0.16689339599439076, 0.11432268763227121, 0.11824060311274869, 0.11546819045075349, 0.11492460247661386, 0.13729822263121605, 0.142998106777668, 0.08558611891099385, 0.15649593248963356, 0.053319702457104406, 0.16729050182870456, 0.15084486215242318, 0.12903678736516408, 0.14115174513842377, 0.16643389207976206], [0.03149933600798249, 0.05967152304947376, 0.017207346124840633, 0.0858395720965096, 0.09654418804815837, 0.04642860937331404, 0.012582476034627428, 0.06381130591034889, 0.05083625750350101, 0.08275149137313877, 0.025193498037489395, 0.008763820897521717, 0.044259882532060146, 0.029374252539128065, 0.01711308573638754, 0.05194201852594103, 0.02292262453452817, 0.03180578617112977, 0.03025295878095286, 0.04837967575128589, 0.015097029274329543, 0.04841505117448313, 0.0071719599322282845, 0.028409574214102964, 0.04725275122161422, 0.04263032300929938, 0.026371952212814773, 0.10397070632981402, 0.050242505435432704, 0.016876115862812315, 0.029158885524209057, 0.04061007320082613, 0.08722769868160997, 0.0426869399712554, 0.36797942008290974, 4.651224885668073, 11.131565655980792, 19.650978633335658, 21.831427574157715, 13.380735754966736, 16.688166005270823, 10.333214163780212, 9.60396250656673, 4.729226665837424, 0.25080641039780205, 0.19159258635980742, 0.7063546829989978, 2.995515844651631, 3.186603899512972, 3.9858415041651045, 5.357324276651655, 7.203977414539882, 4.1696938787187845, 3.322243809700012, 2.9745311992509023, 1.465664952993393, 1.3697315007448196, 0.9130731991359166, 1.258261767881257, 7.115667547498431, 14.438862153462, 26.599717446735927, 41.4615546635219, 48.465272835322786, 49.22365828922817, 52.048844473702566, 50.10200439180647, 48.44462626320975, 45.231914724622456, 43.41199738638741, 44.28071328571865, 47.559974670410156, 48.73702730451311, 49.58658354622977, 45.80737148012434, 46.542268548692974, 48.29934637887137, 47.64246368408203, 45.861518791743684, 42.19955062866211, 36.61903197424752, 37.22357736315046, 35.201481342315674, 35.54157134464809, 36.4332788331168, 40.51646416527884, 45.70981182370867, 46.51208904811314, 45.839670181274414, 47.34774194444929, 38.01453249795096, 45.355988706861226, 50.007699966430664, 45.92663730893816, 40.974117687770296, 34.99043328421456, 32.82658358982631, 34.69441570554461, 38.93007925578526, 41.693096433367046, 44.69341196332659, 42.21873460497175, 41.94778265271868, 38.54916858673096, 35.73200757162911, 33.62326751436506, 34.11096852166312, 36.82508427756173, 44.43296568734305, 44.06895651136126, 46.340875012534006, 45.90958990369524, 43.26570306505476, 44.590067931583945, 44.69729948043823, 44.31515898023333, 42.25584493364607, 40.51635299410139, 40.31336484636579, 42.55835560389927, 42.45883308138166, 43.886868544987266, 41.29058381489345, 36.80730731146676, 20.56708993230547, 10.492703982761928, 2.0950888012136732, 1.3021671090807234, 1.583689225571496, 2.996109698499952, 3.387874539409365, 4.679558336734772, 2.9580978410584584, 4.828116033758436, 5.23297974893025, 1.4363860040903091, 0.1597719131303685, 0.25159492237227304, 2.676567256450653, 9.527504529271807, 19.899296828678676, 28.871304171425955, 22.889669486454554, 16.941367047173635, 25.014214958463395, 20.228094271251134, 5.583638829844339, 0.2599620462528297, 0.023345847181709747, 0.044311006753040214, 0.030494608849819218, 0.0188859789964876, 0.008355835602352661, 0.045496434572019746, 0.01615448369245444, 0.03278225234576634, 0.06355528786246266, 0.01505998635132398, 0.013257156974369926, 0.010838645277544856, 0.029884531229202236, 0.0126991255341896, 0.013409285373719675, 0.009466661040538123, 0.012165766475456101, 0.05434739802564893, 0.050612561471228085, 0.046627752615937164, 0.04222250649971621, 0.04748614012662854, 0.03255804401955434, 0.04930730776063033, 0.04185383128268378, 0.030913366736578088, 0.026429388505805815, 0.034681536323790035, 0.026493106336731995, 0.039910588413476944, 0.04127855911584837, 0.060477548012776036, 0.020781461482069323, 0.037701369994985204, 0.005434608760489417, 0.04584883851930499, 0.008723901834205856, 0.09657204869602408, 0.0644820174202323, 0.03848148849127548, 0.029212160701198236, 0.025037005809800963, 0.058533972661410055, 0.05903418867715767, 0.03336133448673146, 0.03438033123633691, 0.06811515175338302, 0.028694021182933023, 0.013289333104954233, 0.03002300326313291, 0.05959281298731055, 0.045128600738410435, 0.04328741632135851, 0.04158354364335537, 0.06540362403861114, 0.04688643730644669, 0.04715594123782856, 0.04873467170234237, 0.047469597442873886, 0.03119446343875357, 0.052157507677163394, 0.01077660936529615, 0.7948956319264003, 7.076586970261165, 16.494917494910105, 28.05308256830488, 27.14031856400626, 14.821622780391149, 16.070754289627075, 17.311954430171422, 13.162577952657427, 3.764547024454389, 0.16065881268254348, 0.3478841712432248, 0.21563328563102654, 2.0831637382507324, 2.7094348413603644, 5.53964935030256, 9.617218800953456, 9.412885308265686, 8.352617127554756, 5.0222031048366, 3.4634572608130316, 3.557199316365378, 2.7797382346221378, 1.950090970311846, 1.9412387481757571, 9.468187757900782, 16.341428313936504, 30.79916524887085, 43.06417751312256, 49.76855339322771, 50.89613832746233, 52.115644454956055, 51.143542834690635, 48.969545296260286, 47.51643030984061, 44.79768010548183, 46.10942356927054, 49.80543443134853, 49.3324670791626, 48.629993779318674, 46.737742219652446, 47.05506992340088, 48.762558460235596, 49.795283113207134, 47.37886987413679, 44.53712960651943, 40.73537063598633, 39.202646664210725, 37.51328250340053, 37.03004223959786, 37.89182383673531, 43.63289451599121, 48.870099203927175, 48.037569522857666, 47.668922424316406, 47.853932108197895, 42.16056081226894, 47.227503367832725, 49.4635900088719, 47.04863589150565, 41.9592958177839, 35.71213919775826, 34.639841079711914, 36.479852608272004, 39.524918011256624, 42.548391887119834, 44.5492159979684, 43.800954069410054, 41.860697405678884, 39.30743939535958, 36.55174561909267, 34.57050848007202, 34.661769594464985, 38.878197056906565, 46.16734722682408, 45.30634035382952, 47.48435047694615, 45.89482498168945, 44.160092558179585, 44.77626575742449, 45.85615130833217, 45.63142572130476, 43.63443354197911, 41.31386028017317, 41.3329713003976, 43.3107899257115, 44.53492702756609, 44.24904339654105, 43.30276475633894, 37.3605089868818, 23.41236162185669, 11.55587477343423, 3.7842503786087036, 2.11954711164747, 4.548598255429949, 5.255887091159821, 4.551800072193146, 6.721657352788108, 7.251935184001923, 6.416132032871246, 2.1384236301694597, 1.0506932373557771, 0.13687987865081855, 0.22050588631204196, 2.3777908086776733, 9.94025010722024, 19.485581977026804, 29.868898732321604, 30.187716824667795, 18.188930000577653, 27.468141521726334, 24.554421390805924, 7.870131611824036, 0.5990271078688758, 0.05520682708759393, 0.04674696443336351, 0.010546663177332707, 0.0003580300362955313, 0.026529238326475024, 0.019804957988006727, 0.02379452167744083, 0.07056724838912487, 0.05471490955512438, 0.08681791102779762, 0.029137952718883753, 0.021046812779137065, 0.0452324403449893, 0.035124945387776406, 0.026257712360737578, 0.04977254529616662, 0.04024162868570004, 0.01893306423776916, 0.03712239641962307, 0.02753178569089089, 0.012542132886924913, 0.014110447838902473, 0.04304447364328163, 0.04770827552835856, 0.045091260956334214, 0.04054600592436535, 0.010415988358935075, 0.01445278911186116, 0.17094001599720546, 0.13182984106242657, 0.11279508817408766, 0.18979834978069576, 0.15490806555109365, 0.13118454068899155, 0.13042600639164448, 0.1270076148211956, 0.12910479014473303, 0.23890732175537518, 0.11023205784814698, 0.08138152238513742, 0.04727706652400749, 0.13867138751915523, 0.247736039438418, 0.11951020998614174, 0.14917918081794465, 0.11182421991335494, 0.22256719427449362, 0.12713063322007656, 0.09741188505930559, 0.08723575289228133, 0.08229606545397214, 0.17233470401593617, 0.14448766756270612, 0.08705253486654588, 0.11418023599045617, 0.18462918858442987, 0.050065533324543915, 0.1223886776715517, 0.06823377324534313, 0.12894718003060135, 0.1405006636466299, 0.05717372029487576, 0.9359378750835146, 8.482746464865548, 21.511982406888688, 32.703145367758616, 34.468123299734934, 22.303533349718364, 24.30480214527675, 17.49294110706874, 13.919827376093183, 5.888208772454943, 0.6366171879427773, 0.7037706045167786, 2.3135043382644653, 6.839712457997458, 11.160596098218646, 10.880284053938729, 13.548579914229256, 17.082618713378906, 10.595545138631548, 8.750628181866237, 8.125750626836505, 5.5746495979172845, 4.702354507786887, 2.8242625083242143, 1.9669459973062788, 9.71249771118164, 16.857420648847306, 28.02986168861389, 42.952620710645405, 49.60670552934919, 51.77638128825596, 54.297239848545615, 52.70841612134661, 51.867579868861604, 50.276841912950786, 48.35288919721331, 49.19218989780971, 52.21764748437064, 53.14421755926949, 49.924665519169395, 46.29403373173305, 48.017280782972065, 50.34141847065517, 50.659142221723286, 49.34273999077933, 46.3465690612793, 41.70244870867048, 40.72419098445347, 39.15210199356079, 38.773477281842915, 39.10542746952602, 45.42991406576974, 49.93295472008841, 49.636447293417795, 49.57689080919538, 47.329933711460654, 44.051367146628245, 50.22470957892281, 52.751838888440815, 49.376841749463765, 43.99180024010794, 38.22685555049351, 35.58272205080305, 38.19405310494559, 42.16615063803536, 45.69431734085083, 46.876685346875874, 46.982357025146484, 44.22704192570278, 41.133495467049734, 38.48393195016043, 36.451767989567344, 37.04648167746407, 40.28075000217983, 47.20042623792376, 46.95184748513358, 49.50236095700945, 45.70148440769741, 44.29758698599679, 45.75693103245327, 46.53529603140694, 48.48392874853951, 45.57616669791085, 43.25588526044573, 43.32507542201451, 47.252579416547505, 46.31857476915632, 46.74660117285592, 43.35631104878017, 38.973116397857666, 23.680398804800852, 12.151052253586904, 3.634678895984377, 3.003437876701355, 4.680769060339246, 7.5402780430657526, 9.237368600709097, 10.643808194569178, 7.5542482648577005, 10.144310014588491, 10.347774113927569, 3.6926657387188504, 0.840066848056657, 0.5455235902752195, 3.5307601179395403, 11.694725837026324, 25.62812304496765, 37.37515231541225, 31.343747683933803, 24.833610432488577, 34.75676883969988, 28.509065049035208, 7.7275493655885965, 0.6049975103565625, 0.15088625278856072, 0.1416488941758871, 0.12893724627792835, 0.09910552203655243, 0.12596634855227812, 0.1183358830000673, 0.13843688581671032, 0.20635058730840683, 0.11081048181014401, 0.14404059440961905, 0.10317338697080101, 0.14255568837480886, 0.16485946013459138, 0.16035687816994532, 0.10950615429984671, 0.11931293271481991, 0.08110607787966728, 0.07290045211889915, 0.12409697100520134, 0.14611440098711423, 0.11649066129965441, 0.11222352420112916, 0.19294319674372673, 0.19681565037795476, 0.11616131397230284, 0.07483420906854527, 0.07391856677298035, 0.14193085261753627], [0.007607578566031796, 0.04150121359686766, 0.02747032738157681, 0.054325929177658897, 0.028633587461497103, 0.018810010215799724, 0.0514335752730923, 0.039750169164368084, 0.017114244334931885, 0.03363985614851117, 0.015466846126530851, 0.020243698731064796, 0.027124274522066116, 0.01900303816156728, 0.08113866791661296, 0.03468704602814146, 0.041712109066013775, 0.03647623091403927, 0.017049240680145364, 0.038664720087711296, 0.017457606803093637, 0.08259876671114139, 0.0154513840097934, 0.060733633914164135, 0.04196749268365758, 0.02085341842445944, 0.019402164333899106, 0.023995573299803903, 0.06267114994781357, 0.006859379629271903, 0.05246380856260657, 0.028824103131358112, 0.010377565465335335, 0.0785046967544726, 0.07173180447093078, 1.3942092444215501, 7.465830700738089, 17.908672673361643, 25.297493015016826, 20.60300169672285, 8.012622662952968, 9.02100430216108, 10.6776294197355, 10.725948061261859, 3.264423506600516, 0.2675157423530306, 0.1174841858446598, 1.2730515514101302, 1.7950825222900935, 5.645661490304129, 7.776769535882132, 5.882779189518519, 7.280802343572889, 2.8238091383661543, 2.9659588592393056, 3.0870852853570665, 2.1853700024741034, 0.8567437188965934, 1.4102570861577988, 3.140840023756027, 7.066397437027522, 17.33447527885437, 27.926552397864207, 38.29766116823469, 45.55396025521414, 51.71307972499302, 50.499229431152344, 50.16913093839373, 47.12654256820679, 48.445807456970215, 46.262405531747, 47.897208963121685, 49.37024790900094, 49.64211354936872, 46.45243181501116, 46.95207330158779, 48.65643514905657, 48.33555344172886, 46.16057620729719, 43.82363298961094, 37.54527200971331, 38.676063537597656, 36.287582056862966, 36.722066811152864, 35.73533575875418, 41.31895330974034, 45.51984460013253, 48.79278312410627, 48.50796604156494, 49.67505495888846, 37.29394177028111, 45.74876689910889, 49.75663028444563, 44.61140932355608, 40.64573540006365, 34.64935316358294, 36.96550389698574, 39.43149948120117, 45.36654302052089, 45.01149354662214, 46.89915929521833, 46.28206545966012, 46.30930239813668, 43.84957408905029, 40.49494906834194, 35.37092706135341, 33.980811391557964, 35.06614433016096, 41.07131603785923, 42.63211073194231, 44.58128540856497, 46.28420203072684, 46.085994243621826, 46.54496097564697, 44.12583793912615, 44.11950465611049, 44.14626564298357, 43.27956472124372, 44.437843322753906, 43.54256098611014, 43.26604700088501, 41.94143547330584, 37.63177013397217, 25.484618425369263, 11.462377207619802, 3.2841249065739766, 1.3439511869634901, 1.5189349459750312, 3.0825211874076297, 2.201460076229913, 2.5932744230542863, 5.987020407404218, 10.056398800441197, 5.1303392222949435, 1.8229233026504517, 0.5745108776858875, 0.10456198853041444, 1.2811288322721208, 6.076955718653543, 17.17530073438372, 30.701616014753068, 21.928754465920584, 14.611665589468819, 25.595761810030254, 27.45657798222133, 12.206543173108782, 1.508107481258256, 0.06147310816283737, 0.04008362841393266, 0.05866708087601832, 0.031196414226932184, 0.026573236233421733, 0.01538941849555288, 0.025591976208878413, 0.020715916695605432, 0.0744091747328639, 0.04435780531327639, 0.035149247119469304, 0.010750279662066271, 0.06518964123513017, 0.029863900371960232, 0.03690359262483461, 0.025198235908257108, 0.05392298794218472, 0.029148293592567955, 0.005827812594361603, 0.041107537757073126, 0.04214295844680496, 0.0064512764386433575, 0.016616415066112365, 0.07708202595157282, 0.02186130585947207, 0.13452872766980103, 0.06929120900375502, 0.018719819341120974, 0.024171909284112707, 0.03978022148034402, 0.02738061317774866, 0.034245988087994714, 0.020467004605701992, 0.007785712668140019, 0.010783734831160732, 0.05772568817649569, 0.03748729219660163, 0.027681397573490227, 0.0059149038362582874, 0.03996545475508485, 0.0375538734453065, 0.044183964641498666, 0.02463625624243702, 0.04173826319830758, 0.005901325078281973, 0.05181023006194404, 0.02988455497792789, 0.03407107872356262, 0.07778312904494149, 0.025488896561520438, 0.024981013100062097, 0.035800871439278126, 0.02180836825365467, 0.027806490593190705, 0.036731455075953684, 0.04787038093698876, 0.01721372944302857, 0.020722232160291502, 0.039435420517942736, 0.018747640973223106, 0.04994853013860328, 0.0657447235924857, 0.08103215148938553, 0.132561790357743, 3.081792929342815, 11.862165263720922, 24.396322080067225, 32.35364055633545, 24.422044311250957, 11.943201235362462, 11.8834901537214, 16.950832230704172, 14.756288869040352, 2.5743566496031622, 0.21106195449829102, 0.01311967136072261, 1.0186479283230645, 2.135696027960096, 5.480262228420802, 7.197124319417136, 7.332338435309274, 9.768066797937665, 5.39753350189754, 4.335853968347822, 4.15193167754582, 2.101135471037456, 1.863513593162809, 1.979796907731465, 3.424557988132749, 8.784069861684527, 21.233550718852452, 31.05057191848755, 41.63862255641392, 47.503857544490266, 53.030211516789024, 52.60972390856062, 52.012981346675325, 49.74855647768293, 48.90891531535557, 47.29202086584908, 49.85851866858346, 51.372416496276855, 50.16180406297956, 46.05925062724522, 46.9894163949149, 48.77195937292916, 48.73431403296334, 47.579533849443706, 43.934769426073345, 38.60444150652204, 40.3962846483503, 38.956881931849885, 38.740546294621055, 38.03931324822562, 42.87779903411865, 47.65252120154244, 49.87082392828805, 50.63867630277361, 49.80693871634347, 39.07428216934204, 47.30693864822388, 49.55791180474417, 47.040461335863384, 43.010450567517964, 37.41666432789394, 38.467787810734336, 41.24569150379726, 45.93828248977661, 46.83596542903355, 47.33360583441598, 45.59561817986624, 47.704740388052805, 45.38572699683053, 41.27281379699707, 35.97023350851876, 36.59467853818621, 37.13097524642944, 42.74690886906215, 44.25593948364258, 45.852857862200054, 46.982495989118306, 46.35825593130929, 46.533076081957134, 44.180690492902485, 44.501992566244944, 45.609907150268555, 44.50770745958601, 45.920449938092915, 44.017049993787495, 44.217717443193706, 44.079879079546245, 39.54163537706648, 27.1540082522801, 13.211137175559998, 3.7138112783432007, 1.6685151138475962, 2.2357055757726942, 5.5030306066785535, 7.8089249304362705, 7.216418598379407, 6.193312857832227, 7.066444771630423, 5.640566289424896, 0.8325222443257059, 0.45385999605059624, 0.03943810412394149, 1.418679062809263, 7.656184417860849, 18.236367089407786, 32.70134925842285, 29.177605084010533, 17.39772125652858, 25.734786578587123, 31.088335377829416, 15.730117116655622, 2.375867026192801, 0.049835845828056335, 0.05924711296600955, 0.04115366456764085, 0.023355933604761958, 0.031195233575999737, 0.05507203271346433, 0.01576654995525522, 0.0695523296349815, 0.01722002455166408, 0.05823674039649112, 0.021728078901235546, 0.013924473264653767, 0.017409281539065496, 0.030964060087821314, 0.02061638917907008, 0.052669272358928404, 0.021168665794123496, 0.015540646987834146, 0.03944640939256974, 0.016641778705109442, 0.004425300218697105, 0.051043516024947166, 0.021299070046682442, 0.05312947516462632, 0.05926529770450933, 0.05861523401524339, 0.03083918589566435, 0.040911970393998284, 0.005027567477165056, 0.09445153855319534, 0.10851487570575305, 0.09497586970350572, 0.1998912189155817, 0.1395861612898963, 0.2201982792466879, 0.14011364084269318, 0.2525467441550323, 0.1711888483592442, 0.12904047859566553, 0.07969488110393286, 0.09612015115895442, 0.15242002691541398, 0.0886170059176428, 0.2333311481135232, 0.10960103385150433, 0.13974615984729358, 0.07771435273545128, 0.09713548381945916, 0.1555835743035589, 0.10715287950422082, 0.18451362050005368, 0.06424003826188189, 0.16647300283823693, 0.16089583853525774, 0.11211651244333812, 0.1949503711823906, 0.08530200272798538, 0.16326681630952017, 0.1445664590490716, 0.15000962625656808, 0.12154870560126645, 0.16627413779497147, 0.30668431201151436, 0.27770329426441875, 2.923621965306146, 14.797830411366053, 31.676628930228098, 40.04272208895002, 33.53248235157558, 16.545276301247732, 15.21181971686227, 18.288904156003678, 14.963803768157959, 4.570368264402662, 0.5818439413394246, 0.5863377973437309, 3.183024274451392, 7.477912749562945, 15.39636560848781, 17.50341030529567, 14.616965327944074, 18.06533544404166, 9.901187334741865, 8.280963829585485, 9.346386705126081, 4.407265382153647, 2.604486210005624, 3.139616923672812, 4.67646986246109, 9.132128579275948, 21.316816193716868, 29.446500369480678, 40.420436586652485, 48.22449343545096, 54.181962285723, 54.26270382744925, 55.19636801310948, 52.67742715563093, 52.24202871322632, 49.129138469696045, 51.78393398012434, 53.461527892521445, 49.614827973502024, 46.25182689939226, 46.83659424100603, 50.57824781962803, 52.82663624627249, 50.381502628326416, 46.42999955586025, 41.41948332105364, 42.74197564806257, 40.437258175441194, 39.64747381210327, 39.06726448876517, 44.66831507001604, 49.31541967391968, 52.94764607293265, 53.378305843898225, 50.31297254562378, 42.236146790640696, 49.932916504996165, 52.36851372037615, 47.91243594033377, 44.19934293201992, 39.14603621619088, 40.781801973070415, 43.16703864506313, 48.04163074493408, 48.697651863098145, 50.14293622970581, 49.21666840144566, 49.90049968447004, 47.65866688319615, 43.34433582850865, 37.65593249457223, 37.80320651190621, 38.92929063524519, 44.36616918018886, 46.22548975263323, 48.361313888004844, 47.05763380868094, 47.821550028664724, 46.903415066855295, 45.35115276064192, 47.45665495736258, 47.284502914973665, 45.390674114227295, 48.614037241254536, 46.71881185259138, 45.63216570445469, 44.87480510984148, 38.79483257021223, 27.94059123311724, 13.123974629810878, 4.564890478338514, 2.7420666217803955, 3.7808427214622498, 8.099777391978673, 9.380589212690081, 9.927221366337367, 13.353590880121503, 20.112040247235978, 10.232093555586678, 3.5006370714732578, 1.7861654864890235, 0.531365441424506, 1.8543649869305747, 8.773884671075002, 22.65151650565011, 39.004695960453574, 28.36130292075021, 22.290472473417008, 35.02799871989659, 35.16629913875035, 17.1758166381291, 2.3064762353897095, 0.19904129952192307, 0.1295851386551346, 0.14319372842354433, 0.0689636937209538, 0.09835692827722856, 0.11131174276982035, 0.10710462209369455, 0.15182605093078955, 0.20037915344749177, 0.15414046602589743, 0.09938999105777059, 0.18630115315318108, 0.12156063424689428, 0.0839521319472364, 0.25074998342565125, 0.1417187290000064, 0.07772275299898215, 0.09719100834003516, 0.10017669812909194, 0.19817269327385084, 0.14691773216639245, 0.1096943731286696, 0.16187223685639246, 0.2200707010924816, 0.16691723971494607, 0.2168276294001511, 0.11012296298784868, 0.10775424473519836, 0.10855402039097888], [0.014508656292621578, 0.006834751352601285, 0.043874841050377915, 0.06721395546836512, 0.004149350628722459, 0.03697408562792199, 0.014914023290787424, 0.08637594724340097, 0.07596574763634376, 0.06657706214381115, 0.06203441947166409, 0.0549109451073621, 0.022159795110513057, 0.06382683079157557, 0.054564183178756914, 0.019518726472077624, 0.07954468059220485, 0.05844652985355683, 0.026777782311130847, 0.03962598368525505, 0.0072425530192309195, 0.015844089544511268, 0.04264185131926622, 0.11690585687756538, 0.0650588943223868, 0.052434143011591265, 0.028297118909124817, 0.05714924553675311, 0.020622623219553913, 0.004936508501746825, 0.0316768475542111, 0.0663682429918221, 0.020614714893911566, 0.0033083692375969675, 0.032310124287115674, 0.279892736779792, 5.386026416506086, 12.296501500265938, 18.813887459891184, 24.21064189502171, 13.41522227014814, 15.3667437008449, 16.147806337901525, 14.376043490001134, 9.367403268814087, 3.263047763279506, 0.14805535040795803, 0.9364579043218068, 0.5233992774571691, 2.5431077778339386, 8.14453855582646, 7.320202537945338, 7.660161393029349, 4.385865364755903, 1.9653902522155215, 1.8909824277673448, 1.376288103205817, 1.9121312243597848, 0.724369190633297, 1.347231062395232, 4.209098415715354, 10.078617402485438, 19.40338478769575, 29.060628686632427, 39.89917925425938, 49.73722743988037, 53.840329783303396, 51.2591678074428, 49.14344481059483, 47.11006491524832, 49.38538108553205, 47.32647698266165, 49.686912059783936, 47.933113779340474, 48.56456954138619, 47.57894672666277, 49.53799131938389, 48.37799651282174, 47.737942355019705, 44.10903024673462, 38.28705474308559, 39.36040898731777, 38.932417324611116, 37.77290194375174, 38.14064230237688, 43.98112780707223, 47.08363396780831, 48.43116412843977, 48.498064858572825, 48.13937105451311, 36.7537853377206, 44.36249705723354, 48.02946097510201, 44.376424721309114, 40.75982482092721, 36.91998277391706, 41.37515728814261, 43.24495574406215, 46.55696398871285, 46.79837914875576, 49.39221116474697, 46.55326059886387, 45.43213748931885, 43.86692026683262, 44.673248291015625, 42.63406317574637, 38.19674205780029, 34.94655541011265, 37.82161923817226, 43.19602305548531, 44.66172470365252, 44.616325174059185, 44.48400020599365, 45.112742696489605, 45.04887138094221, 45.521685872759136, 45.976532323019846, 43.693517548697336, 44.287758759089876, 44.939756870269775, 43.07081651687622, 36.916133471897666, 27.391167640686035, 14.160896863256182, 4.01452453647341, 0.38594252190419603, 1.3464112835271018, 1.6560156302792686, 4.307915696075984, 7.685953974723816, 4.99201318195888, 2.9952031757150377, 4.656531138079507, 3.7798104797090804, 1.2053554696696145, 0.29362861971770016, 0.947865217924118, 5.429457868848528, 22.127573694501603, 26.46677930014474, 27.264368227549962, 22.427631650652202, 20.6865850516728, 28.99172340120588, 18.4783832686288, 3.408113556248801, 0.2616947532764503, 0.041647156301353655, 0.03995733269091163, 0.0470323732255825, 0.029158437691096748, 0.0946330873827849, 0.005093976971693337, 0.036570520140230656, 0.05546094184475286, 0.045271791983395815, 0.015283341419750025, 0.03277618285002453, 0.01459638069250754, 0.025012106967291663, 0.031090810429304838, 0.022547628763797026, 0.047699027096054385, 0.01981666780609105, 0.020234628414203013, 0.0332891213973718, 0.018133517587557435, 0.04247073496558836, 0.017782401160470078, 0.04147047596052289, 0.017410777708781616, 0.08218192907848529, 0.11739122654710497, 0.004800304047031594, 0.009053754670146321, 0.06985149572470359, 0.021140126611239145, 0.040043937508016825, 0.07408805124993835, 0.0161321123928896, 0.040062943273889165, 0.037414118980190585, 0.013868192177531975, 0.06402379593678884, 0.02728063952443855, 0.017697891320234964, 0.058685109551463804, 0.06072954913335187, 0.039846463461539576, 0.02975493104064039, 0.023510178185201118, 0.036411315468805175, 0.01028896405893777, 0.12866459733673505, 0.030371783833418573, 0.04738029884174466, 0.010350581823981233, 0.07281119762254612, 0.038294904931847534, 0.08381224516779184, 0.04664256164271917, 0.02303521554651005, 0.04664319268028651, 0.02730705658905208, 0.05228533688932657, 0.01665352753895734, 0.05752111665372338, 0.011242678106230284, 0.026592031653438295, 0.07244316701378141, 0.03134151554799505, 0.7296339709843908, 7.594544342585972, 19.31607719830104, 29.003830637250626, 31.391189983912877, 16.40236575262887, 13.269253645624433, 20.35103222302028, 22.438184227262223, 10.251809069088527, 3.576756541218076, 0.11367113116596426, 0.1382052611027445, 0.374366714486054, 2.7972739679472785, 4.790414239679064, 7.5422191960471014, 8.142329897199359, 5.559653648308345, 5.223268338612147, 6.339916374002184, 3.1238564550876617, 2.943558952638081, 1.830588468483516, 1.6775854442800795, 6.617730106626238, 12.578096355710711, 21.337144885744365, 31.209987912859233, 41.64912823268345, 51.537488324301584, 54.86698865890503, 52.25559507097517, 50.27430929456438, 49.456666128976, 50.71793787819998, 49.81137861524309, 50.571108545575825, 49.22353669575283, 49.40728528159005, 48.40820380619594, 51.005562032972065, 50.047242164611816, 49.40619094031197, 46.13679599761963, 40.35600594111851, 40.37998070035662, 41.13868577139718, 40.38747780663626, 39.94293206078665, 45.38875641141619, 48.55571753638131, 49.67604507718767, 50.00142921720232, 48.919740608760286, 38.82230922154018, 45.999829632895334, 49.30185331617083, 47.09222194126674, 42.67983443396432, 39.09893090384347, 42.29303516660418, 46.068960734776084, 49.195535455431255, 48.287791524614605, 50.59161615371704, 47.70114469528198, 46.53911754063198, 44.96251916885376, 46.60130739212036, 43.64790262494768, 38.89960445676531, 35.77454096930367, 39.729910714285715, 45.83882597514561, 46.584732464381624, 45.25727217538016, 45.72895063672747, 46.59925419943673, 46.42193269729614, 46.76933567864554, 46.274672576359336, 44.79419558388846, 45.654677867889404, 46.34536354882376, 44.83895935331072, 38.27299506323678, 29.070547240121023, 16.15763282775879, 5.547684941973005, 1.3975936685289656, 1.9425992923123496, 3.0657829770020077, 6.713635657514844, 6.439205697604588, 7.562352469989231, 5.8513303399086, 5.508687743118831, 4.169754241194044, 0.3873809618609292, 0.21000482408063753, 0.7577724925109318, 5.04126592193331, 17.857563461576188, 29.464020252227783, 32.02022429874965, 20.398391144616262, 19.975758280072892, 31.622342654636928, 22.544594151633127, 5.471989529473441, 0.426529446882861, 0.037885283519114764, 0.01700038955147777, 0.014883526534374272, 0.03081639051171286, 0.10889780694352728, 0.021997586225292513, 0.04107811308598944, 0.03362236351573041, 0.029731966022934233, 0.01432998275517353, 0.06206103161509548, 0.03063562199739473, 0.06171890747334276, 0.019422627253723995, 0.018664830863209705, 0.052697075331317525, 0.028161780010642748, 0.017700966780206988, 0.027915420908746973, 0.037081772528056584, 0.035795426195753474, 0.06877558345773391, 0.07602454269570963, 0.055603787036878724, 0.02660078475517886, 0.028232227212616375, 0.043990639836660454, 0.01732974705685462, 0.045940026840461154, 0.10501782835594245, 0.14610319158860616, 0.16209141723811626, 0.11441741112087454, 0.09010942333510943, 0.16851745599082538, 0.09267465211451054, 0.18340694345533848, 0.1599612786833729, 0.12697626650333405, 0.1911565326154232, 0.13384218593793257, 0.12940065855426447, 0.19137776217290334, 0.11827983600752694, 0.12184481828340463, 0.1398220607744796, 0.23723142168351583, 0.09275912972433226, 0.1365543311195714, 0.07865792353238378, 0.08864692931196519, 0.12103580098067011, 0.21432497512016976, 0.15709454965378555, 0.11458997614681721, 0.12853505143097468, 0.10919900863830533, 0.1186928738440786, 0.09347620553203992, 0.14392642410738127, 0.16174290808183805, 0.1071918952677931, 0.08258423927639212, 0.1162499442164387, 0.9038823608841214, 8.657447627612523, 22.03564034189497, 34.732470989227295, 39.70035307747977, 24.565074716295513, 23.976110662732804, 23.963105372020177, 20.77480980328151, 12.651854089328221, 4.445737557751792, 0.5215990426284927, 1.7848318666219711, 2.254143923521042, 6.7628310748509, 18.193456751959665, 13.30602959224156, 14.710046870367867, 10.49513932636806, 8.319578443254743, 5.080629638263157, 5.200908601284027, 4.118174723216465, 1.8394832483359744, 2.597170625414167, 6.260316942419324, 11.527885692460195, 22.125933919634136, 30.617306573050364, 42.529631750924246, 52.69352960586548, 57.96701431274414, 54.140540599823, 53.46558911459786, 50.92883307593209, 54.3253105708531, 51.77517230170113, 52.288776193346294, 50.012577601841514, 50.262288911002024, 48.704520157405305, 51.953160830906455, 52.73402370725359, 50.77620199748448, 48.90298850195748, 42.40093721662249, 43.810327189309255, 43.17465387071882, 40.21103525161743, 41.3787772996085, 47.53198037828718, 50.30151844024658, 52.098298277173726, 51.3623172896249, 51.350557463509695, 43.74160255704607, 47.737007822309224, 52.04685728890555, 49.516205242701936, 44.067695413317, 39.61586993081229, 45.00640051705496, 47.924039431980674, 51.05731916427612, 50.51066616603306, 52.492782252175466, 49.637336662837434, 48.44390712465559, 47.01367603029524, 48.402075495038716, 46.53423295702253, 41.49038273947579, 37.47798218045916, 41.688465459006174, 47.76706920351301, 47.78907414845058, 45.647458689553396, 45.029367787497385, 45.86208854402815, 46.134263379233225, 47.28581265040806, 49.12492438725063, 45.83449377332415, 47.13862548555647, 47.13023553575788, 46.34832695552281, 40.567825249263215, 29.030655894960674, 16.064704145703995, 5.575943265642438, 0.9484341016837529, 2.813381846461977, 4.978876743997846, 9.734750185694013, 13.20067926815578, 10.004492282867432, 10.71144803932735, 10.327329908098493, 6.376044401100703, 2.7151091311659132, 0.826172839318003, 1.4231323152780533, 6.778020705495562, 26.41559018407549, 32.873087882995605, 36.327179840632844, 30.633242266518728, 28.233572449002946, 37.93234920501709, 25.496414729527064, 5.722714841365814, 0.5424173112426485, 0.11340412085077592, 0.18870046654982225, 0.12579239931489739, 0.10976650140115193, 0.1576795554054635, 0.19607299380004406, 0.15841026976704597, 0.11332321912050247, 0.11093616006629807, 0.113890854375703, 0.16883464397064277, 0.09822272083589009, 0.1616778637149504, 0.12677807999508722, 0.1359505978013788, 0.12888565047511033, 0.10121362177389008, 0.09517035819590092, 0.09322640286492449, 0.15352020359465054, 0.13717984541186265, 0.15899820679000445, 0.16460635300193513, 0.15084887907973357, 0.09359929856977292, 0.20194774999150208, 0.11220120718436581, 0.11277520709804126, 0.16050950783704007], [0.05542474539418306, 0.041792892052658966, 0.030241091203476702, 0.038083178257303577, 0.02609612772773419, 0.02829067621912275, 0.050079640067581616, 0.013296961534901388, 0.05307756384302463, 0.06284014587955815, 0.0872692996636033, 0.006909311324956694, 0.049911963886448314, 0.0570727407134005, 0.05579691506656153, 0.019810106372460723, 0.019803492352366447, 0.03088310407474637, 0.07653312504823719, 0.06304577591695956, 0.04215431373034205, 0.016699937637895346, 0.0038561009402785984, 0.058771113865077496, 0.0353626124560833, 0.05694166810384818, 0.029192286410502026, 0.02790680181767259, 0.048211785831621716, 0.013933209403018867, 0.04988356041056769, 0.039194740754153044, 0.026035251262198602, 0.05245974753051996, 0.052847465832850764, 0.045598353924495835, 0.941867185490472, 8.532459088734218, 15.048702069691249, 16.89444065093994, 18.81750226020813, 18.414402518953594, 9.652514781270709, 17.886817114693777, 14.620786837169103, 9.093541758401052, 2.390098891087941, 0.30604819900223185, 0.13546734516109737, 2.9335426901068007, 2.678585925272533, 5.246545238154275, 6.604856397424426, 5.28915593453816, 3.447878096784864, 6.97004155601774, 1.984665640762874, 2.4615750099931444, 1.8228093087673187, 0.6199015591825757, 3.086080836398261, 6.223350788865771, 12.725549289158412, 22.677539246422903, 29.831882204328263, 41.418166637420654, 49.26133489608765, 50.7299165725708, 51.127850328172954, 50.223941802978516, 48.231778621673584, 51.3148124558585, 49.351261956351145, 48.41715656008039, 49.45423425946917, 49.49479784284319, 49.8816214288984, 49.91953427450997, 47.68670286451067, 44.2723719733102, 38.40191541399275, 40.5442465373448, 40.061117444719585, 40.97847073418753, 40.39085463115147, 46.81126110894339, 46.89767585481916, 50.306375231061665, 48.4737148966108, 45.319396018981934, 37.30890819004604, 45.46394634246826, 48.58865199770246, 43.55954933166504, 43.84254946027483, 41.151050090789795, 43.28868423189436, 44.97194440024239, 47.22513403211321, 47.995491232190815, 48.05545418603079, 47.517733097076416, 49.27318157468523, 46.17484433310372, 43.70686156409127, 43.66589845929827, 44.304969446999685, 41.94329064232962, 40.30301203046526, 41.28109952381679, 44.72649928501674, 45.826284476688926, 46.10926028660366, 46.24983971459525, 45.40543903623308, 43.845974922180176, 44.71051148005894, 45.57000364576067, 47.850458008902415, 40.174234117780415, 33.9139141355242, 22.742204393659318, 13.391301359449114, 4.865127350602831, 0.5732361003756523, 0.7357556053570339, 1.579094077859606, 1.8412072701113564, 5.160393221037729, 6.220822078841073, 7.981148191860743, 4.798165389469691, 4.044564638819013, 5.387716565813337, 0.10317806886242968, 0.40207583191139357, 4.4991631252425055, 15.239016703196935, 20.29111269542149, 19.56536987849644, 26.747410093035015, 46.91986492701939, 28.847629921776907, 21.919075625283376, 9.806036966187612, 0.6751769216997283, 0.04783646436408162, 0.0404562187780227, 0.06897485562201057, 0.0355231097367193, 0.04230051088546004, 0.062400923376636844, 0.07485023606568575, 0.009641849452496638, 0.017795379839039276, 0.07317632410143103, 0.021939849680555717, 0.015621494435306107, 0.04598057948585067, 0.011702960639792894, 0.022489654731803706, 0.014933671968589936, 0.057051190441208224, 0.061856310814619064, 0.035926831287464926, 0.03189139014908245, 0.0035240504990464872, 0.04457636822813323, 0.05250575899013451, 0.08762399705925158, 0.007948164129629731, 0.06635142889406, 0.02762975766589599, 0.00992442705735032, 0.014265225069331271, 0.06957068400723593, 0.0393145496823958, 0.02475385823553162, 0.03679589893934982, 0.05259616360334413, 0.030083284314189638, 0.04773607850074768, 0.022654080730197684, 0.06372536266488688, 0.10186224696891648, 0.023280148028529117, 0.05157423897513321, 0.04633697661172066, 0.03201951452397874, 0.03258750940273915, 0.07302826097501175, 0.05005153853978429, 0.029120928275265863, 0.04480961464079363, 0.06482498294540814, 0.06056112317102296, 0.029306453320064714, 0.045613933088524, 0.02544302080890962, 0.020026265577014004, 0.07909876773399965, 0.03087754687294364, 0.04934254069147365, 0.04554069201861109, 0.00982612938553627, 0.016975962290806428, 0.05084456955747945, 0.0420764213028763, 0.015401871309482625, 0.03840475635869162, 0.056085489224642515, 0.03897305657821042, 2.1837949327060153, 12.180232950619288, 21.411813701902116, 26.718410049165996, 25.90115598269871, 22.736411333084106, 10.821233919688634, 19.486638103212627, 22.461717775889806, 9.512889862060547, 1.9324735956532615, 0.6500376335212162, 0.054093595394598584, 0.5520491429737636, 2.1853246220520566, 5.0105761630194525, 7.6686903067997525, 5.087552649634225, 7.188187633241926, 14.037541151046753, 5.6433234214782715, 3.564955894436155, 2.4247054798262457, 1.8981256101812636, 3.6403004229068756, 5.853816057954516, 14.069750394139971, 24.268838269369944, 31.794994967324392, 44.12230478014265, 51.47335992540632, 52.71025391987392, 52.13508898871285, 49.87054252624512, 50.73897702353341, 52.10365186418806, 50.52825205666678, 48.56470503125872, 49.670010566711426, 49.956401416233604, 50.062889507838655, 51.23589481626238, 48.48505088261196, 46.57078742980957, 41.63111155373709, 40.96341746194022, 41.79295941761562, 42.49175017220633, 41.833067893981934, 47.77854067938668, 47.940103667122976, 51.777465207236155, 49.52836111613682, 47.72731508527483, 40.33248976298741, 47.337027822222026, 50.370757239205496, 44.684017998831614, 45.79308598382132, 42.729253496442524, 44.791131428309846, 45.956531933375764, 49.13629511424473, 49.704925264631, 49.144848346710205, 47.97542136056082, 49.23627969196865, 47.18446275166103, 45.76099572862898, 45.839378356933594, 45.557420458112446, 42.89288704735892, 41.074036257607595, 43.57089226586478, 45.01318195887974, 46.68006522314889, 45.701241220746724, 46.10264907564436, 46.29852226802281, 45.409871986934114, 46.59468923296247, 47.471280915396555, 47.89333186830793, 42.539956774030415, 36.903623240334646, 26.367003168378556, 15.858733483723231, 7.520567740712847, 1.6413394063711166, 1.9548107513359614, 2.840683272906712, 4.481553784438542, 6.433621082987104, 9.467641455786568, 10.588335514068604, 4.3961130891527445, 1.9384905185018266, 0.3337894247046539, 0.22807535156607628, 0.3087715400116784, 4.310661971569061, 17.7796984740666, 30.351131507328578, 22.011121886117117, 31.266660894666398, 43.64295898165022, 29.205790451594762, 28.115201200757706, 12.9903381892613, 0.9851286240986415, 0.020595729484089782, 0.018071816701974188, 0.01514658099040389, 0.04053810438407319, 0.03320876249511327, 0.045814270552779944, 0.038223801247243366, 0.05447995662689209, 0.06127752722906215, 0.07467053963669709, 0.02555122339565839, 0.027561442760218467, 0.014940318219097597, 0.010407738221277083, 0.028444425468998294, 0.056364455326859436, 0.05259571237755673, 0.02243228968498962, 0.011230465324063386, 0.012323072096998138, 0.06716573198458978, 0.03706844949296542, 0.02809374500066042, 0.08301035926810332, 0.06093625804143293, 0.02136853676555412, 0.01556924045351999, 0.01813935298871781, 0.009456309988828642, 0.024303787653999667, 0.11667854764631816, 0.16479911123003277, 0.1581932878387826, 0.13587918877601624, 0.0885757849152599, 0.0714151661044785, 0.17294846608170442, 0.1545788132186447, 0.1689542561237301, 0.2033774232757943, 0.17922458930739335, 0.07912644517741033, 0.14611437384571346, 0.13901832247419016, 0.10881447605788708, 0.15824028317417416, 0.12170638356889997, 0.12765879130789212, 0.19157463232321398, 0.18754243797489575, 0.14270958011703833, 0.16526712397379534, 0.09194783932928528, 0.1511687133461237, 0.15632997639477253, 0.10917087657643215, 0.24254179958786282, 0.12527388999504702, 0.1577864789537021, 0.07853989236588989, 0.12601132185331412, 0.10472976309912545, 0.10682781373283692, 0.15961515797036036, 0.1310684433473008, 0.16568723214524134, 2.1795476291860854, 14.504507865224566, 27.507324150630406, 33.391020502362935, 33.50436299187796, 30.58692557471139, 17.15711382457188, 26.671511445726665, 22.371886253356934, 12.817320227622986, 3.3889814742973874, 0.9148363045283726, 0.48113533960921423, 5.450762348515647, 7.707773923873901, 13.964748348508563, 18.157663106918335, 13.821020518030439, 9.180074623652867, 16.45184908594404, 6.546538429600852, 6.501940982682364, 6.150459843022483, 1.8001400509050913, 5.479253436837878, 8.547942280769348, 15.087605033602033, 25.56109724725996, 32.5892504964556, 44.769237654549734, 53.6564804485866, 54.84436879839216, 54.151101861681255, 53.034637519291465, 52.2848539352417, 55.42940017155239, 52.291572843279155, 49.296166215624126, 50.425818238939556, 50.04699550356184, 50.925150530678884, 53.87002985818045, 50.88139772415161, 48.438459736960276, 43.167959281376426, 43.962715080806184, 44.2372453553336, 46.01519904817854, 44.45817027773176, 49.77822528566633, 50.75353349958147, 54.198009150368826, 50.508199555533274, 49.67568377086094, 43.548998492104666, 48.55833353315081, 51.57602303368704, 47.299938338143484, 47.96232400621687, 45.57414477212088, 47.25854444503784, 47.880675724574495, 51.09751449312483, 50.689022949763704, 49.33589254106794, 48.55602673121861, 51.42040422984532, 49.790732043130056, 47.77192252022879, 46.622370856148855, 48.638661657060894, 45.638307912009104, 43.20085552760533, 44.556358746119905, 47.84891898291451, 50.11995506286621, 47.7806772504534, 46.476420470646445, 46.478727272578645, 44.29515164239066, 48.23765332358224, 48.14772278921944, 52.19930076599121, 42.57175520488194, 36.27417203358242, 24.935281685420446, 14.809871639524188, 5.8186803204672675, 1.7212655118533542, 1.5876005185501916, 3.4409431431974684, 5.850904328482492, 12.135737555367605, 14.588863338742938, 14.906272683824811, 9.780819347926549, 8.05613054547991, 8.221470747675214, 0.4487873768167836, 0.7540154712540763, 6.325131910187857, 19.301180260522024, 26.96018304143633, 27.74208641052246, 32.34282568522862, 50.613496031079976, 37.68643161228725, 31.661818844931467, 14.645270551953997, 1.2311406689030784, 0.11306682787835598, 0.14654499930994852, 0.13635481468268804, 0.1437023447028228, 0.14377829991281033, 0.15853161896978105, 0.1462985146790743, 0.09565211127379111, 0.18203993966536863, 0.1532012921358858, 0.1106894515188677, 0.1901931350252458, 0.08649601401495081, 0.06439796050212213, 0.08114331588149071, 0.15087425628943102, 0.15690384060144424, 0.11563105242592947, 0.10629285672413451, 0.08204124162771873, 0.1011020163340228, 0.08507221005856991, 0.14549398927816323, 0.3204732835292816, 0.16208666749298573, 0.16475791058370046, 0.12032546981104783, 0.11261427894766841, 0.07331755438021251, 0.06729349334325109], [0.0061796368182902885, 0.01685531028280301, 0.06637069250323943, 0.036035692053181786, 0.03625004465824791, 0.03276183183438011, 0.008073588783320571, 0.024910750798881054, 0.034570487282638035, 0.03796708770096302, 0.008921327535063028, 0.02073379439700927, 0.049165683931538036, 0.01880048188780035, 0.07643273579222815, 0.033852583662207635, 0.022645770372556787, 0.039749911321060996, 0.02610438210623605, 0.05826047555144344, 0.04159178784383195, 0.05558536820379751, 0.04077888932079077, 0.04127707312415753, 0.0725374019571713, 0.007408421752708299, 0.019770028701584254, 0.0439623008216066, 0.045280826677169116, 0.053384109001074515, 0.030934048483946493, 0.03608894348144531, 0.08669238883469786, 0.03577227797359228, 0.059697958773800304, 0.053166937083005905, 0.04018818048228111, 3.2266016389642442, 12.348801459584918, 16.85929318836757, 21.827168328421457, 25.85950674329485, 17.41559723445347, 18.974736520222255, 13.193572998046875, 20.545979567936488, 8.511943663869586, 2.3781212823731557, 0.46566718391009737, 0.6455734159265245, 1.8514751877103532, 4.745968350342341, 4.469405293464661, 3.586449061121259, 5.856917125838144, 15.750885282244, 5.555252833025796, 1.9322193350110735, 2.0736961662769318, 2.1994646404470717, 0.6914019425000463, 2.267369168145316, 4.811707862785884, 12.679163115365164, 21.822379282542638, 32.58603000640869, 39.678973470415386, 48.05637829644339, 49.74846962520054, 51.69843292236328, 48.79310621534075, 51.98641490936279, 49.501412527901785, 51.32078790664673, 46.741247585841585, 48.491008962903706, 51.54647581917899, 50.09139449255807, 47.41334336144583, 45.59898110798427, 39.598409107753206, 41.157473700387136, 40.45379488808768, 42.37454448427473, 45.12534325463431, 48.58230481828962, 48.09904718399048, 50.60395268031529, 49.87046957015991, 52.50557041168213, 40.42459855760847, 46.99405084337507, 50.250782694135395, 45.23135886873518, 44.29407467160906, 44.923307010105674, 43.60274975640433, 45.24270180293492, 44.67836911337716, 45.933380535670686, 46.482003348214285, 48.04835312707083, 48.43594796316964, 47.72607830592564, 48.14619071143014, 45.38509818485805, 44.21201644624983, 45.62259108679635, 44.55642475400652, 43.47684839793614, 43.89275714329311, 44.59803751536778, 44.81455727985927, 45.38315963745117, 46.01605715070452, 46.92743498938424, 41.50318826947893, 41.078177383967805, 35.8795873097011, 29.93049451283046, 22.482689176286968, 13.329720343862261, 3.559818135840552, 0.8991918925728116, 0.3799760549196175, 2.8457294021333968, 1.9640173316001892, 4.153909742832184, 4.9870882119451245, 4.6841293828828, 8.566237756184169, 2.949664899281093, 2.1839048010962347, 0.8419076321380479, 0.5640194235103471, 3.6305032457624162, 11.225841420037405, 22.133700268609182, 17.333782196044922, 19.865042209625244, 15.898553609848022, 36.960793018341064, 38.00399208068848, 15.610422236578804, 4.549860656261444, 0.05982641223818064, 0.03112076435770307, 0.05762835232807057, 0.05098884306581957, 0.032064755846347125, 0.054284541934196434, 0.048386060765811374, 0.0822634007781744, 0.03003657396350588, 0.05880547487842185, 0.06851757730224303, 0.0355906816465514, 0.07521101313510112, 0.037025053785847764, 0.049506308510899544, 0.09083123531724725, 0.026872828103868023, 0.06068322554762874, 0.03841426602697798, 0.04757081790428076, 0.04132726775216205, 0.00735246721056423, 0.05711993960929768, 0.08011893834918737, 0.036148868301617246, 0.006854171873003776, 0.02300028795642512, 0.012669012150061982, 0.01663928508891591, 0.09068972005375794, 0.02255846157536975, 0.028556960501841137, 0.032723586208054, 0.028904869154627835, 0.04836200669940029, 0.04497326032391616, 0.045183514577469656, 0.009573350494195308, 0.035576900600322654, 0.05308150952415807, 0.04063508060893842, 0.03891723689490131, 0.035465926198022704, 0.023436355271509716, 0.0442519233162914, 0.08522156918687479, 0.021584770608959452, 0.06886557077190705, 0.036215001717209816, 0.004634599010127464, 0.08252363252852644, 0.009170892714921917, 0.021225035090797713, 0.018612174849425043, 0.020718695296506797, 0.030999276055289165, 0.02752739387298269, 0.028860699917588915, 0.025132728441219245, 0.026147055173558847, 0.04120598301025374, 0.03675809096811073, 0.02757724584080279, 0.019697184574657252, 0.05832186939993075, 0.02885246928781271, 0.015720160212367773, 0.11853468018983092, 5.059073286397116, 17.210819925580704, 22.932519027165004, 31.05974701472691, 31.827971117837087, 16.988965681621007, 15.601815155574254, 16.534312043871196, 27.742710011346, 9.396473663193838, 1.7106436703886305, 0.2712955081037113, 0.37664208667618887, 0.6666966453194618, 2.305871742112296, 5.048916757106781, 6.723754405975342, 10.422425559588842, 16.83020976611546, 9.528027381215777, 3.9645313790866306, 3.4907146096229553, 2.960975698062352, 2.6054426729679108, 4.291670373507908, 7.029360498700823, 13.392786536897932, 24.437778506960186, 34.4282580103193, 43.72592742102486, 50.0184314591544, 51.74284928185599, 53.48833404268537, 49.77221161978585, 51.71222857066563, 49.498945917402, 50.89887939180647, 47.01425967897688, 48.66034698486328, 52.51114634105137, 50.890763895852224, 49.63180937085833, 47.40018694741385, 41.17111996241978, 43.10213899612427, 42.43135643005371, 45.07325608389718, 45.9734924861363, 48.69815560749599, 49.99510635648455, 51.04333938871111, 50.98187562397548, 51.30317422321865, 42.43494170052664, 47.70210354668753, 51.40192896979195, 47.128349099840435, 46.06893294198172, 45.750017574855256, 45.29930877685547, 46.522031920296804, 46.64766229901995, 47.692518506731304, 47.598620550973074, 49.23609209060669, 48.55745458602905, 48.81454488209316, 48.30167402539934, 47.17007303237915, 46.14231634140015, 47.19802563531058, 45.05954728807722, 44.51485020773751, 45.71591234207153, 46.372062001909526, 47.172873156411306, 47.23973567145211, 46.69741834912981, 47.28069877624512, 43.25296354293823, 42.90301057270595, 38.25211920057024, 32.58282341275896, 24.131910119737896, 15.129070145743233, 4.952445796557835, 1.7147554840360368, 1.1502543006624495, 3.730933810983385, 4.492922774383, 5.396403551101685, 6.852823708738599, 8.051239882196699, 7.144991551126752, 3.0766047963074277, 1.5079397474016463, 0.23006717754261835, 0.13796007925910608, 3.291762496743883, 12.683572615895953, 25.90890496117728, 17.70873131070818, 22.062865121023997, 22.366859231676372, 43.951757771628245, 41.27168124062674, 18.15140799113682, 5.980711877346039, 0.07864393892564944, 0.08327677925782544, 0.03915100238685097, 0.014713638329080172, 0.06750279425510339, 0.05061401692884309, 0.04356383113190532, 0.02164950454607606, 0.036378840782812664, 0.058373987674713135, 0.04063064977526665, 0.03884955302679113, 0.016413517828498567, 0.04945861428443875, 0.08466565901679651, 0.054658401158771346, 0.0070988880719856495, 0.08472660503217153, 0.05651554811213698, 0.07376512286386319, 0.05325206269377044, 0.01963630980545921, 0.030082385255289928, 0.02429141117525952, 0.005351595514054809, 0.023578499876228825, 0.03252211219764181, 0.004814939199215067, 0.01956197968684137, 0.12827861947672708, 0.06397183372506074, 0.10134253664208309, 0.08001977724156209, 0.17350293775754316, 0.11724980627851826, 0.1851850173303059, 0.13071409878986223, 0.07432312970714909, 0.09038045057760817, 0.14819966123572417, 0.09711782833827393, 0.1422228262360607, 0.08183793896543128, 0.17528736272028514, 0.10557038656302861, 0.11017567837344748, 0.08491359571261065, 0.12882573583296367, 0.20666332409850188, 0.06923148435141359, 0.14242444613150188, 0.13484136946499348, 0.08533518987574748, 0.12040799324001585, 0.11076840585363762, 0.1558371428400278, 0.1334332600235939, 0.1227058113685676, 0.12207881786993571, 0.09557277017406055, 0.23068792851907866, 0.13671465537377767, 0.103369687151696, 0.15235578321984836, 0.10375656067792859, 0.21342835894652776, 0.08851319005978958, 0.2896091139742306, 5.409248598984309, 19.190017768314906, 31.843267577035085, 41.241484369550435, 40.35987956183297, 27.76819600377764, 27.382921866008214, 21.021126917430333, 27.842751911708287, 11.757813743182592, 3.3362424756799425, 0.9193013906478882, 1.2848588206938334, 4.873413945947375, 11.446372900690351, 11.493415679250445, 10.298305545534406, 15.904068742479597, 26.774250984191895, 18.268165520259313, 5.3483975785119195, 6.271899155208042, 4.9411567108971735, 2.785408833197185, 4.6620393225124905, 7.2913466691970825, 14.159632291112628, 24.71111021723066, 35.50563178743635, 44.40038211005074, 51.485220500401084, 55.39415890829903, 55.21056318283081, 51.63380077907017, 52.27629028047834, 50.78030490875244, 51.35335758754185, 47.18226364680699, 48.93447078977312, 53.40037679672241, 52.64648682730538, 52.123662676130024, 49.65760455812727, 43.59942156927926, 44.28979805537632, 44.84015791756766, 47.032512596675325, 48.501855100904194, 52.13337973185948, 51.6401618548802, 52.368020398276194, 51.327447754996165, 50.810765811375205, 44.100629874638145, 49.08914116450718, 52.60619074957711, 50.04063442775181, 48.38898508889334, 49.297375202178955, 47.741562366485596, 49.39707490376064, 47.87908458709717, 49.28887060710362, 50.038581235068186, 50.99675171715872, 51.46717602866036, 50.07111964906965, 50.98171581540789, 48.695261682782856, 47.773315634046284, 48.55062450681414, 47.043188503810335, 45.85686697278704, 48.06578268323626, 47.57442692347935, 46.90564891270229, 46.45545775549752, 46.27709402356829, 47.00867680140904, 42.82309586661202, 43.193976811000276, 38.35311474118914, 30.489574364253453, 24.662078516823904, 14.183594022478376, 4.954001324517386, 1.5951495191880634, 1.5996177537100655, 6.863024967057364, 6.950385102203914, 9.994526829038348, 11.496504153524127, 10.742379682404653, 15.741468736103602, 8.237666130065918, 5.237853041716984, 1.9009150947843279, 0.8462074271270207, 4.6003163031169345, 14.655442714691162, 28.16656402179173, 24.403515202658518, 28.237994977406093, 24.82151882989066, 43.524488721575054, 46.39118691853115, 22.580563238688878, 6.4893564922469, 0.1780614445784262, 0.21373436466923781, 0.1654625284884657, 0.17351000809243747, 0.11746254057756492, 0.1318975995693888, 0.16354076803794929, 0.12646709382534027, 0.1016125800088048, 0.13620761329574244, 0.11679934045033795, 0.08621482231787272, 0.17836569968078816, 0.32527036326272146, 0.20763638402734483, 0.20024423354438373, 0.07750604927007641, 0.18039726066802228, 0.16255489736795425, 0.19575686433485576, 0.19474477507174015, 0.10113547489579235, 0.13026941408004078, 0.09149563645145722, 0.08248097303190402, 0.10532155420098986, 0.09148437277014766, 0.07019304311169045, 0.11315029447099992, 0.21684813472841466, 0.15793530882469245], [0.03623156475701502, 0.014922698361000844, 0.05161333277023264, 0.020553717988410165, 0.0081801306556112, 0.04324943871636476, 0.016250474345205084, 0.011523427059208708, 0.06571962458214589, 0.041470051876136234, 0.025185755952926617, 0.06050424836575985, 0.06573470163026027, 0.018693627889401147, 0.04052373640505331, 0.05406998576862471, 0.03558560959728701, 0.06822193280926772, 0.03504354154158916, 0.07912373103733573, 0.02804610675333866, 0.056397642474621534, 0.012175499212129839, 0.034860774741641114, 0.041233473856534274, 0.006551866710651666, 0.057689345840896876, 0.03183559760717409, 0.04082565734695111, 0.0880116034033043, 0.04707528717283692, 0.04716461630804198, 0.005499506818263659, 0.05655421782284975, 0.03315070364624262, 0.014518703699910214, 0.04019364608185632, 0.5159463573779378, 3.443428861243384, 17.19878043447222, 22.7359162739345, 28.148896489824565, 25.48681926727295, 21.764445202691213, 30.354640347617014, 20.172633750098093, 28.683600323540823, 12.297122495515005, 1.8335698970726557, 0.7739788400275367, 0.08861370145210198, 0.9305549753563744, 4.264105132647923, 3.5557512683527808, 9.13876497745514, 13.226116623197283, 8.089950033596583, 3.068286499806813, 0.8985735571810177, 2.484770051070622, 2.5613563529082706, 1.2649883840765273, 1.8017681006874358, 3.941976223673139, 11.004436203411647, 17.848671504429408, 27.206623486110143, 35.37644393103463, 45.76165233339582, 50.53964362825666, 52.71673658915928, 52.14554255349295, 51.24194669723511, 49.36611373083932, 51.68525218963623, 51.74805695669991, 51.647825717926025, 50.11494888578142, 49.44927324567522, 45.56910732814244, 41.08833565030779, 43.82132271357945, 43.45894636426653, 47.62971373966762, 46.01614052908761, 48.590760775974815, 48.4679548399789, 51.13352700642177, 48.495097977774485, 49.90992838995797, 39.368482794080464, 43.30730193001883, 53.137832164764404, 44.717254706791465, 48.813624245779856, 46.59969541004726, 46.88683666501726, 42.28103562763759, 44.46473632540022, 42.498211996895925, 43.915203298841206, 46.113887786865234, 49.04173707962036, 48.30891752243042, 47.597119740077424, 47.5767684664045, 45.79251970563616, 45.645030294145855, 45.84701790128435, 45.35556486674717, 43.817178113119944, 45.420026779174805, 46.935140541621614, 48.071869305201936, 43.49835654667446, 41.637535163334434, 35.6689943586077, 29.446152959551128, 25.274784564971924, 16.234177657536097, 7.680798411369324, 2.448724316699164, 0.4722883829048702, 1.2214203562055315, 1.28870866554124, 3.088553309440613, 3.1063378751277924, 3.8477247783115933, 4.799586730343955, 8.473024197987147, 8.273689065660749, 2.2568446014608656, 0.250286055462701, 0.1677224707922765, 1.7273020850760596, 9.86002881186349, 21.032063382012502, 20.015562772750854, 17.659791673932755, 9.572111095700945, 18.880060366221837, 24.844901255198888, 23.279157706669398, 9.290877546582903, 0.9185330718755722, 0.06514221163732664, 0.008793993653463466, 0.010816399506958467, 0.012788424135318823, 0.015428883788575019, 0.0586864191240498, 0.010599244552265321, 0.04433593273695026, 0.0342678844130465, 0.028500777802297046, 0.03201261721551418, 0.03307802236772009, 0.00310746265209413, 0.07729476703596966, 0.02834792421864612, 0.03250328963622451, 0.02910222445747682, 0.03394680842757225, 0.028793925286403725, 0.012049250138391341, 0.018688033368172388, 0.030983757959412675, 0.0008016924641976532, 0.05227687895031912, 0.029541979610387768, 0.047904382326773236, 0.07290701355252947, 0.01549513594779585, 0.03469564985217793, 0.04286095366946288, 0.0322540331897991, 0.05195179282288466, 0.02579022039260183, 0.05947869696787425, 0.02921468485146761, 0.004979531438688615, 0.050945932511240244, 0.019994491478428245, 0.10427040167685066, 0.03965632437861391, 0.01266151009726205, 0.030356425193271468, 0.037228180029030354, 0.011332282896286674, 0.01267168897071055, 0.040312990213611295, 0.07035754714161158, 0.016504699364304543, 0.12345158920756408, 0.04600592616147228, 0.05288626107254198, 0.06280805117317609, 0.07692396800432887, 0.015481570336435522, 0.018032263199399625, 0.05554072738492063, 0.016246878109606247, 0.04897873396320002, 0.05086716138092535, 0.035161762697888274, 0.0301532853793885, 0.06676923683179276, 0.07497842490140881, 0.04188080983502524, 0.12183849433703081, 0.005677408522127995, 0.013427153745267009, 0.05715335745896612, 0.8922875002026558, 7.001985030514853, 22.34171370097569, 30.43032012666975, 35.19805588041033, 29.75056048801967, 23.54329695020403, 25.739155258451188, 23.38476858820234, 28.175508090427943, 12.193717667034694, 2.660764664411545, 0.13547429335968836, 0.1083100734810744, 0.355666669351714, 2.1760733127593994, 4.64593209539141, 8.046790429524012, 10.029535327638898, 9.816339407648359, 5.466322839260101, 3.522964890514101, 3.1916760844843726, 2.9831204754965643, 2.4114383288792203, 2.939170296703066, 5.236154641423907, 13.532615559441702, 21.423156636101858, 30.502432005746023, 40.1065343448094, 49.294578552246094, 52.90596382958548, 54.632830892290386, 53.33993789127895, 51.25878913061959, 49.528493131910054, 51.77492911475045, 51.661767278398784, 51.41883741106306, 51.77636044366019, 49.87253318514143, 46.79115997041975, 42.739449977874756, 44.913645539964946, 43.90342957632882, 47.89062554495675, 46.46564381463187, 50.058741433279856, 50.862439564296174, 52.76357786996024, 49.58512789862496, 49.326307501111714, 41.08851630347115, 45.11150939123971, 52.51308488845825, 47.65253857203892, 48.96743304388863, 48.70231063025338, 48.93343898228237, 44.211266040802, 46.93263571602957, 43.615867955344065, 46.385791642325266, 47.129808221544536, 49.500290393829346, 49.42003870010376, 48.13550785609654, 49.652653966631206, 47.10422148023333, 46.01542486463274, 47.725122928619385, 46.636545181274414, 45.29658855710711, 47.233155727386475, 47.01860230309622, 48.31990262440273, 44.43736389705113, 43.61604860850743, 36.85555560248238, 32.68429837908064, 28.042078358786448, 18.776103155953543, 10.268245901380267, 4.5065334268978665, 1.1636271945067813, 1.3499382542712348, 2.0893400354044775, 3.789686909743718, 3.8318116664886475, 6.954251340457371, 6.093129822186061, 8.283200281006948, 5.493618403162275, 0.6029778101614544, 0.4009778808270182, 0.11760827632887022, 2.0654462661061967, 9.059243713106428, 24.13335360799517, 24.301531280790055, 22.46053831917899, 14.841706548418317, 20.213728870664323, 28.13912558555603, 28.71362348965236, 12.271827578544617, 1.373750165104866, 0.056926414636628966, 0.016085152680586492, 0.04097074170463851, 0.013909504782142383, 0.011527825662467097, 0.06355875517640795, 0.019994354075086967, 0.021845204223479544, 0.0517970461265317, 0.09705356428665773, 0.03293944516086152, 0.009495206160603889, 0.032655020244419575, 0.06498829953904663, 0.034164889582565854, 0.034935284672038894, 0.08083407354674169, 0.03941835196954863, 0.06581527766372476, 0.07112277179424252, 0.028562622876571755, 0.05558002134785056, 0.020092851914731518, 0.07323750081871237, 0.05322912142478994, 0.08169055437403065, 0.06504035674567733, 0.025339174416980574, 0.04587710628818188, 0.030988076834806373, 0.01111761901328074, 0.1338991421673979, 0.14018544341836656, 0.131556527156915, 0.07915273840938296, 0.09403750327016626, 0.1801579956497465, 0.08227457624993154, 0.20337233426315443, 0.18044957571796008, 0.13092373896922382, 0.04956672866163509, 0.20186281097786768, 0.08718073727296931, 0.11103697001401867, 0.13375648696507725, 0.13397980641041482, 0.10488550045660563, 0.2794608899525234, 0.159028863002147, 0.11984271928668022, 0.17464914625244482, 0.18543846373047146, 0.07343034725636244, 0.16868107792522224, 0.1642967239022255, 0.10671362307454858, 0.16845698494996342, 0.15990407818130084, 0.12043835089675017, 0.1233877254916089, 0.15218211896717548, 0.12464076253984656, 0.15515714218573912, 0.23349318227597646, 0.07776015384921006, 0.12729019751506193, 0.11228911139603172, 1.0346772053412028, 7.7082602977752686, 26.536386353628977, 37.03137976782662, 41.735338006700786, 36.26788738795689, 31.570133890424454, 39.33009052276611, 29.432367733546666, 34.55097361973354, 15.66993876865932, 2.693399267537253, 1.2269226780959537, 0.9612946744476045, 3.425027425800051, 8.509724582944598, 9.421970946448189, 20.034201315471105, 24.43039604595729, 22.30203774997166, 8.895004800387792, 4.995814280850547, 6.429024415356772, 6.2266629082815985, 2.4873018009322028, 2.8799369037151337, 4.677072618688856, 12.580199922834124, 19.905369554247173, 29.405082157679967, 38.69986459187099, 50.37415838241577, 53.99756751741682, 57.73732771192278, 54.67591667175293, 52.57268306187221, 49.55991636003767, 52.35766410827637, 52.880404881068635, 52.9387662751334, 53.6611704826355, 54.28624432427542, 48.7858418737139, 45.29324994768415, 48.63570867265974, 46.429652145930696, 51.41524519239153, 48.58318029131208, 50.71449504579817, 53.30537060328892, 53.70001091275896, 50.270202909197124, 48.53848600387573, 44.56123290743147, 46.982725279671804, 53.32537794113159, 49.61552974155971, 51.97486005510603, 51.966897419520784, 51.323132923671174, 46.02112586157662, 49.63781261444092, 45.366661139896934, 47.35386330740792, 49.5137733731951, 51.95917797088623, 51.34393930435181, 50.49530369894845, 50.51205233165196, 48.375919001443044, 47.53553785596575, 49.875093596322195, 48.601558276585166, 46.606282302311485, 49.20356062480381, 49.56687845502581, 48.79494053976876, 44.20268154144287, 43.144300665174214, 37.38986165182931, 30.71265322821481, 26.960026706968033, 18.578043018068584, 9.091870716639928, 3.210386714765004, 0.8497605621814728, 2.7804004848003387, 3.0924429978643144, 7.003573996680124, 8.493015033858162, 9.474712984902517, 11.719099249158587, 15.124251570020403, 16.57130251611982, 4.990200136389051, 0.8191297543900353, 0.5409569410341126, 2.682819332395281, 12.438369819096156, 27.15391618864877, 26.75707503727504, 25.909870760781423, 17.392628226961406, 26.563093491962977, 34.77756479808262, 29.85818808419364, 13.360313262258257, 1.4370654076337814, 0.17464561787034782, 0.12010250320391995, 0.06939330138266087, 0.1613699309527874, 0.0913701413997582, 0.1653389944029706, 0.12390680478087493, 0.13454487680324487, 0.09253397823444434, 0.1282420600099223, 0.1315060170101268, 0.18204885561551365, 0.10077997004347188, 0.21883036621979304, 0.14699368737637997, 0.11215823556163482, 0.14196169881948403, 0.10355479150478329, 0.1666909618569272, 0.1153149636728423, 0.15749789801027092, 0.15237190521189145, 0.08780026010104588, 0.10675965489021369, 0.10663843460913215, 0.23701412762914384, 0.1625789175076144, 0.14619065475250992, 0.1873494897569929, 0.10819943834628377, 0.11150135259543147], [0.017548142034294348, 0.01698463736101985, 0.049444592358278375, 0.013388802097844226, 0.020779698987358382, 0.05625268703858767, 0.02332772690403674, 0.03935537374179278, 0.09579121095261403, 0.05905552860349417, 0.0473988024917032, 0.03854305875886764, 0.020949202124029398, 0.046273207890668085, 0.013382473910626556, 0.02008616495212274, 0.06632073196981635, 0.019418868169720684, 0.06143904570490122, 0.028904706306223358, 0.029099371217723404, 0.005839767533221415, 0.03542639814051134, 0.04253093119976776, 0.0320447865607483, 0.0890890152326652, 0.017329148249700665, 0.008913988330667573, 0.027255781394030367, 0.03328621726749199, 0.10964069422334433, 0.021511417580768466, 0.06549428988780294, 0.024152331852487156, 0.04369056451001337, 0.03584815515205264, 0.06434535368212632, 0.007826032915285655, 0.9059275197131293, 8.117081012044634, 19.83177249772208, 26.798621790749685, 28.646401405334473, 17.80515319960458, 25.10024755341666, 52.728829928806846, 43.45734133039202, 16.29473294530596, 7.426064423152378, 2.668965275798525, 0.13457394524344377, 0.8453614296657699, 1.596775723355157, 5.173787176609039, 5.823034235409327, 6.627810205732073, 3.5088552704879215, 4.270324638911656, 2.8974930473736356, 1.0504007616213389, 2.3066186734608243, 3.1499560603073666, 1.2407101839780807, 1.3687691752399718, 4.0637920413698465, 8.2033611365727, 13.148297667503357, 23.225182362965175, 30.807555198669434, 41.076190199170796, 47.96980374200003, 52.45512648991176, 49.11578403200422, 49.97696808406285, 49.20356409890311, 51.630715778895784, 50.27887773513794, 51.997615405491416, 48.75665943963187, 46.314186981746126, 43.646704060690745, 44.756161144801546, 44.49473864691598, 47.55349547522408, 48.480492864336284, 51.00611441476004, 49.19987460545131, 52.13529396057129, 47.81402512959072, 50.80580479758126, 40.2170523915972, 42.15253216879708, 53.04705742427281, 48.433363233293804, 48.732476234436035, 47.57841171537127, 45.37787900652204, 46.09448841639927, 44.32905190331595, 40.75138623373849, 42.213843073163716, 45.75573246819632, 45.47201320103237, 46.70609317507063, 47.339497906821116, 48.41190024784633, 46.77663823536464, 47.25722081320626, 47.25979164668492, 45.60563748223441, 46.22829335076468, 46.29058395113264, 45.552521978105815, 41.496399879455566, 36.96974924632481, 32.48238720212664, 21.84021357127598, 17.74201144490923, 10.087490252086095, 5.401008469717843, 1.0930790943758828, 1.0832232918058122, 0.5394688323140144, 0.9006382035357612, 1.2513465732336044, 2.5695207033838545, 2.9556077803884233, 4.456428664071219, 4.86390837601253, 9.705256819725037, 2.626175011907305, 0.8152147701808384, 0.8906532621809414, 1.5880598596164157, 7.992078576769147, 17.890725476401194, 21.094963686806814, 15.50326885495867, 8.083337954112462, 17.612010649272374, 22.858428648539952, 23.015805346625193, 10.3866206237248, 1.4680008505071913, 0.08798803109675646, 0.026304722963167087, 0.027999951105032648, 0.01311944829233523, 0.04069448974249618, 0.017524970063407506, 0.041786680064563236, 0.03423127066344023, 0.015331646327727606, 0.008194415514091296, 0.11172093331281628, 0.051843763262565644, 0.06774578443063156, 0.055642287113836834, 0.016054369243127958, 0.08720244360821587, 0.023518295160361698, 0.05015943578577467, 0.06041658842670066, 0.047988191579601595, 0.01916231238283217, 0.02795917454308697, 0.009667514191408242, 0.02445493981109134, 0.011747894076896566, 0.05031922399731619, 0.10199393025998559, 0.042300744980041466, 0.05958076220537935, 0.06423551243330751, 0.028925581436072077, 0.024048185208812356, 0.05429421445088727, 0.02057265759711819, 0.02972321631386876, 0.017333080360133733, 0.04123027456392135, 0.01782800889174853, 0.006700864094974739, 0.038105400279164314, 0.033259309961327484, 0.07168024938021388, 0.037992743110018115, 0.027232014008664658, 0.03112727150853191, 0.011803073392781829, 0.03454292179750545, 0.01552031807867544, 0.06840188029621329, 0.009290844983687358, 0.011634797556325793, 0.014883658848702908, 0.03178847674280405, 0.025049692718312144, 0.024572869197332432, 0.042693118032600195, 0.02170989246639822, 0.056913783707256825, 0.02470290195196867, 0.019094475844342793, 0.02922780771872827, 0.03166044736281037, 0.049374900026513, 0.008278952495727156, 0.06033264685954366, 0.023477598326280713, 0.02876139971028481, 0.02866790776274034, 0.04019585810601711, 0.06717542146465608, 1.4351270773581095, 11.78029463972364, 24.904120751789637, 33.78194005148751, 35.316140515463694, 24.184950930731638, 32.73125083105904, 42.05056388037545, 49.18721498761858, 23.04172212736947, 8.877122742789131, 3.065587341785431, 0.23048746213316917, 0.2117685672960111, 0.5985433938247817, 3.0148574582168033, 4.733732572623661, 5.9803992084094455, 7.12707735810961, 5.315185623509543, 5.407634879861559, 5.8671852605683465, 3.5526497662067413, 2.1013536878994534, 3.0586506511483873, 2.5675780304840634, 5.1211033293179105, 10.717755266598292, 15.992166689464025, 26.18299228804452, 33.26788452693394, 44.31511034284319, 49.21076243264334, 53.20186676297869, 49.66175610678536, 49.39360427856445, 49.24401651109968, 51.16103145054409, 50.939317907605854, 54.67172690800258, 50.01333148138863, 47.19011163711548, 46.30096108572823, 47.73453426361084, 44.84070682525635, 49.07032544272286, 49.999511514391216, 51.62000860486712, 49.24197026661464, 52.91304404394967, 47.93727227619716, 50.93326602663313, 41.15248489379883, 43.570590019226074, 53.98701320375715, 49.98430190767561, 50.21110153198242, 49.94990832465035, 46.80560874938965, 48.30331032616751, 45.77617406845093, 42.377566950661794, 43.234338896615164, 46.154475688934326, 48.73809037889753, 47.89940806797573, 48.5509614944458, 49.02390105383736, 47.532404218401226, 47.02663442066738, 48.36391946247646, 47.87382480076381, 48.435003008161274, 47.48593814032418, 46.18853575842721, 43.68006583622524, 38.68263305936541, 34.73817893436977, 24.652477843420847, 21.460529259272985, 13.849674020494733, 7.4011698961257935, 2.276005561862673, 1.367597100990159, 1.605712735227176, 2.8668714676584517, 3.0068561732769012, 4.662155704838889, 5.701968388898032, 6.337457145963397, 6.0441528388432095, 5.35680707011904, 4.008838304451533, 0.15851219929754734, 0.21077862541590417, 1.4605090639420917, 7.965530378477914, 19.962151970182145, 25.412089654377528, 17.738995926720754, 10.95400617803846, 18.846936566489084, 26.181696449007305, 27.135757071631296, 13.549185276031494, 2.5982554129191806, 0.06966823698686701, 0.03615583007090858, 0.035196761534150155, 0.08162493325237717, 0.03723630548587867, 0.04916588749204363, 0.021163105199645673, 0.033224623251174173, 0.026580630568787456, 0.03591450909152627, 0.044717259239405394, 0.023398732201063206, 0.014873669116890855, 0.02728538418055645, 0.024031360933024968, 0.010089227098173328, 0.028690329952431575, 0.09736410940864257, 0.042165791150182486, 0.009633797786331602, 0.023465075962511555, 0.05895680854363101, 0.021782329472314035, 0.03378227386357529, 0.022770234051027467, 0.05754721989589078, 0.05367152286427362, 0.037981387826481035, 0.03351291920989752, 0.041176924748080115, 0.017128725968567387, 0.0299784302977579, 0.12499887975198881, 0.07744399724262101, 0.21225685466613087, 0.10362681121166263, 0.22402984436069215, 0.14381028605358942, 0.13395288214087486, 0.14164308591612748, 0.11612240677433354, 0.20973954402974673, 0.2020886545734746, 0.12181497631328446, 0.11794880591332912, 0.07690460940024682, 0.20171870371060713, 0.08478094211646489, 0.2163476472986596, 0.06537473201751709, 0.15880257157342775, 0.18318428897431918, 0.12754949288708822, 0.0702964382778321, 0.13316835995231355, 0.17341738806239196, 0.144724788410323, 0.1732072050550154, 0.11475667863019876, 0.06561618870390312, 0.11795829183288983, 0.14074702614120074, 0.22083797492086887, 0.0896423469696726, 0.20249326500509465, 0.092956658053611, 0.1740443951317242, 0.12040492626173155, 0.2112822476774454, 0.18337024828152998, 1.9364733695983887, 12.992616329874311, 30.65211704799107, 40.59273106711251, 40.70270368031093, 28.643286875316075, 34.84841557911464, 59.20216083526611, 51.83899845395769, 23.211096627371653, 11.113217200551714, 4.199578080858503, 0.4986292751772063, 1.2482172782932008, 4.601979093892234, 9.523199251719884, 14.68697190284729, 17.185170650482178, 10.481903008052281, 10.040100063596453, 7.071355410984584, 6.962185314723423, 6.2035132476261685, 6.192822575569153, 3.675985719476427, 2.4069078862667084, 5.384212502411433, 10.412468791007996, 15.416029010500226, 26.027293579918997, 33.7271465573992, 43.50947366441999, 50.1808317048209, 54.11935901641846, 49.91443082264492, 49.47614540372576, 49.065347058432444, 51.52983488355364, 51.89062009538923, 55.94715213775635, 52.75660187857491, 51.67473609106881, 46.70533234732491, 49.0053528376988, 46.562730993543354, 51.77557529721941, 52.896569865090505, 53.60611990519932, 52.899554116385325, 53.72905438286917, 50.411299977983745, 49.977027143750874, 43.66357428686959, 45.807625089372905, 53.75111838749477, 53.176505838121685, 52.6055827822004, 52.92486640385219, 49.426903520311626, 52.365703174046104, 47.329617568424766, 45.53382437569754, 46.7448537009103, 48.25757728304182, 49.823944432394846, 49.925499303000315, 49.71116474696568, 50.71724305834089, 48.360705920628135, 48.51667560849871, 48.11666781561715, 47.95496933800833, 48.90299197605678, 48.59361301149641, 46.607630252838135, 44.823888710566926, 37.71627065113613, 36.01141895566668, 23.100139107022965, 20.065551587513514, 12.238054990768433, 7.805952838488987, 1.8953285259859902, 2.405138918331691, 2.1983442434242795, 3.1804408473627905, 4.150386571884155, 7.131954559258052, 8.469017692974635, 10.291058574404035, 13.265426056725637, 17.743540048599243, 6.719164686543601, 1.8543204750333513, 1.1811302495854241, 2.3078109409127916, 10.342786175864083, 22.09267463002886, 28.913752453667776, 21.709915740149363, 14.799834966659546, 25.684908935001918, 32.347779750823975, 30.841250487736293, 15.21820511136736, 2.9263152607849667, 0.22148163323955877, 0.10718604629593236, 0.10133043157735042, 0.13583895164941037, 0.12726985503520283, 0.09452798909374646, 0.08688018697180919, 0.17500130592712335, 0.19333973260862486, 0.047372634788709025, 0.16144253419978277, 0.14477525784501008, 0.19156195728906564, 0.10460926885051386, 0.10236827802977391, 0.2810765361147267, 0.17880475254995482, 0.17620516275720938, 0.17554983363619872, 0.11236938887408801, 0.11183323085840259, 0.14716143480369023, 0.20135708525776863, 0.08851374645850488, 0.0595960495993495, 0.16165258150015557, 0.19566222227045468, 0.16745075822940894, 0.16877616782273563, 0.22673449851572514, 0.10952083779765026, 0.10194884160799639], [0.03626632271334529, 0.012690964454252805, 0.06665822850274188, 0.03867073530065162, 0.019237936806998084, 0.023661365965381265, 0.05021438355158482, 0.07980578765273094, 0.08948085563523428, 0.017742298044530407, 0.052763022149779966, 0.03809454711154103, 0.015463962352701595, 0.02685153906765793, 0.046285859176090786, 0.03254688551117267, 0.0077981705710824046, 0.0448586795079921, 0.02063379529863596, 0.01669554242731205, 0.05282080279929297, 0.02250983945227095, 0.014983132082436765, 0.008042870654857584, 0.04287161006193076, 0.024317541558827673, 0.029093549387263398, 0.05115020887127944, 0.04995754786900111, 0.03421801548185093, 0.026562286374558295, 0.048840580840728114, 0.014592021105012723, 0.06458250167114393, 0.06728267749505383, 0.048264820128679276, 0.009926236201343792, 0.027381690352090766, 0.028572702514273778, 1.3074110448360443, 12.577441487993513, 25.21042513847351, 28.97652074268886, 23.16339898109436, 17.82064768246242, 20.774637835366384, 19.87076578821455, 17.577952316829137, 21.572240659168788, 11.762720039912633, 2.7908169201442172, 0.2891678490809032, 0.282784815877676, 1.9211697450705936, 2.616764111178262, 2.752329328230449, 5.82351062127522, 3.4942540654114316, 4.153379074164799, 4.533815962927682, 1.847736188343593, 0.8228684280599866, 1.4376279945884431, 1.6446444690227509, 0.9820739137274879, 2.1544915565422604, 3.2509546407631467, 7.939783828599112, 15.830146857670375, 26.306524310793193, 32.09735625130789, 42.069539410727366, 45.61876957757132, 47.29478972298758, 49.47876487459455, 52.053499766758506, 51.16131285258702, 52.532543318612234, 47.83172566550118, 48.42587654931204, 45.34075478145054, 45.79319020680019, 47.8502321924482, 50.665072509220664, 48.55183001926967, 52.341488701956614, 51.694243158612935, 51.90177542822701, 47.759620734623496, 50.95033427647182, 41.73601198196411, 40.00370100566319, 53.96980946404593, 48.71900715146746, 52.065829345158164, 49.104218755449565, 48.23417575018746, 46.11679213387625, 48.63177599225725, 44.50237471716744, 41.71892636162894, 42.169576099940706, 45.54816893168858, 46.251073019845144, 47.347790581839426, 47.30713667188372, 47.746304512023926, 45.72883251735142, 46.43698944364275, 46.5151948928833, 45.75228616169521, 45.283449513571604, 42.869527203696116, 34.36853476933071, 27.44491716793605, 18.99718267577035, 12.155350582940237, 8.293417607034955, 4.793861848967416, 0.7415513800723212, 0.7069332833800996, 0.7030588484236172, 2.2136845631258826, 3.2222787737846375, 2.5571359736578803, 2.9312473961285184, 3.1009245770318166, 5.676988746438708, 4.413102303232465, 2.59378251007625, 3.7744690520422797, 0.36255740959729466, 2.1230490037373135, 6.704474023410252, 12.750871998923165, 16.903415986469813, 11.7263331924166, 15.051906926291329, 21.09340034212385, 23.426231963293894, 22.891938073294504, 8.350179178374153, 2.105609893798828, 0.14304115303925105, 0.011235125163303954, 0.04468203987926245, 0.037049620146197934, 0.02244147365646703, 0.01593573248412992, 0.03972259350121021, 0.060087906063667366, 0.03771202638745308, 0.07710468902119569, 0.034940821517791064, 0.01101882940357817, 0.028309797335948263, 0.01239817404919969, 0.07992617333573954, 0.03559223549174411, 0.027828212195475186, 0.048245532770774195, 0.0632562031969428, 0.07537637211914573, 0.06244203581341675, 0.04215838494045394, 0.03233559649171574, 0.02958190461088504, 0.024430612634335245, 0.032893036758261066, 0.05840793478169611, 0.014660824555903673, 0.04134834644251636, 0.04720372028116669, 0.04530988493934274, 0.057579341743673594, 0.047394408977457454, 0.05466914236811655, 0.017123496159911156, 0.03245094744488597, 0.03493419562333396, 0.07310865380402122, 0.07593390398791858, 0.013792426109180918, 0.008635913653831397, 0.049584397713520696, 0.028364292179633464, 0.03177235475076096, 0.0657690694289548, 0.05526017690343516, 0.01759853004477918, 0.02313083130866289, 0.05703324318996497, 0.024749900680035353, 0.06290804009352412, 0.03685258375480771, 0.010840618966280349, 0.036023583595774004, 0.062444118915924, 0.014888493410710777, 0.03751783984314118, 0.030288415628352335, 0.024197618975969296, 0.04075225342863372, 0.04190552547307951, 0.05589097019817148, 0.049041179540966234, 0.023909965929176127, 0.01969647889823786, 0.036134517285972834, 0.016903883212112954, 0.019278409724522914, 0.06389321865780012, 0.019745382613369396, 0.01268003071059606, 0.04751478448244078, 2.663401071514402, 17.518093585968018, 32.39619827270508, 34.9386031968253, 26.387055669512065, 21.645575421197073, 37.21175847734724, 29.401194640568324, 20.589032343455724, 22.176054750170024, 11.333417773246765, 2.572668888739177, 0.3666202872991562, 0.1392678605126483, 0.33014338463544846, 2.2768356544630866, 3.2690575207982744, 5.772498250007629, 5.898896838937487, 4.932869681290217, 3.2703501028673987, 3.6542178818157742, 2.452286354133061, 2.8567197152546475, 0.8831722236105374, 2.185340906892504, 3.2293780956949507, 5.194948349680219, 10.687780737876892, 18.852613244737896, 29.624329090118408, 36.441908495766775, 43.715810843876426, 46.06921781812395, 50.12986319405692, 49.072594029562815, 51.70681939806257, 52.198487826756065, 52.79761362075806, 50.5037214415414, 48.90808153152466, 47.114053181239534, 47.532258306230815, 49.156698499407085, 51.68293496540615, 49.73191901615688, 53.0499860899789, 51.956728730882915, 52.36674887793404, 47.89229311261858, 50.82251174109322, 43.78984042576381, 42.54474755695888, 52.352498122623985, 49.46928753171648, 52.83263601575579, 51.47336687360491, 48.28998020717076, 47.300883293151855, 50.432200159345356, 46.49720253263201, 43.012055601392476, 44.460060187748496, 47.19546175003052, 47.4126798084804, 48.77228593826294, 48.70869255065918, 48.0672105380467, 45.411487443106516, 47.32539653778076, 47.605078901563374, 46.61008644104004, 47.02159002849034, 43.66314002445766, 35.16843570981707, 29.12034671647208, 21.63631694657462, 15.658811228615896, 11.136766382626124, 6.107202529907227, 1.9425274218831743, 1.2809051871299744, 2.8562022915908267, 3.7763272609029497, 4.023646652698517, 5.4956559623990735, 5.203045172350747, 5.487762374537332, 6.623808911868504, 3.5119823941162656, 2.4035488665103912, 0.8453247887747628, 0.1954158190637827, 1.72154115991933, 7.267590778214591, 16.48670298712594, 20.937739849090576, 17.329430886677333, 15.434961114610944, 19.247653075626918, 27.174540179116384, 26.030194452830724, 12.812426090240479, 3.8578769649778093, 0.26967766348804745, 0.02026926084155483, 0.040276339144579, 0.022315389975639324, 0.03885687441964235, 0.04419859724917582, 0.024860181280278733, 0.020498169719108512, 0.030728225064064776, 0.04057874184634004, 0.038503384816327264, 0.04265347123146057, 0.048337291061346016, 0.03904222983068653, 0.008004621635856373, 0.043368708209267685, 0.0497679414360651, 0.04895916162058711, 0.0759538257760661, 0.03346632421016693, 0.01677189627662301, 0.014905253225671393, 0.012662274297326803, 0.02087646656270538, 0.03983507085857647, 0.029208757848079716, 0.04568761520619903, 0.02571334916033915, 0.010334922083919602, 0.0340605444673981, 0.02388329102125551, 0.07827889387096677, 0.011972782634464758, 0.12570592681212084, 0.06157134646283729, 0.10499125692461218, 0.07527268518294607, 0.09930230397731066, 0.17025038014565194, 0.11946454457938671, 0.1823437333639179, 0.16991633735597134, 0.09928914718329906, 0.09642100001552276, 0.09139114205858537, 0.09712715819478035, 0.11804532073438168, 0.15606977178582124, 0.13477143964597157, 0.0821935116712536, 0.10047129089278833, 0.1214383350951331, 0.1027412958709257, 0.1259173040411302, 0.12556473724544048, 0.13725132229072706, 0.07848097517022065, 0.08971205965748855, 0.13578956787075314, 0.09980303567967244, 0.1451383147920881, 0.12409509824854986, 0.13262813751186642, 0.11953828776521341, 0.13784035854041576, 0.1299614134643759, 0.1018817141386015, 0.10434825678489038, 0.16447186736123903, 0.11541199418050901, 0.12380776580955301, 0.14508688183767454, 2.5809706832681383, 18.223644937787736, 36.84244435174124, 42.30301625388009, 32.17200074877058, 27.185791049684795, 32.201575756073, 29.211943081447057, 25.787876026971, 25.335002865110123, 15.027544804981776, 3.9136579717908586, 0.7411564726914678, 1.0105707560266768, 4.433179557323456, 6.514028242656162, 9.020728979791913, 13.385855708803449, 12.527145215443202, 8.884381873267037, 9.162292446408953, 5.462277250630515, 2.397304390157972, 4.01508994613375, 3.522512389080865, 2.308979323932103, 3.367607729775565, 4.437995093209403, 9.724831632205419, 18.11106675011771, 28.671896083014353, 35.295570373535156, 43.31883593967983, 46.657539163317, 48.36243254797799, 48.47967645100185, 53.588422843388145, 53.230152879442485, 57.208670548030305, 53.52599327904837, 51.453418595450266, 48.95944261550903, 49.81411273138863, 52.97416039875576, 53.8834433555603, 52.70198208945138, 56.7917160987854, 54.92559323992048, 53.30904967444283, 48.76854085922241, 50.61414916174752, 46.11687898635864, 45.52157122748238, 52.88925688607352, 50.172285420554026, 52.63358402252197, 54.691407680511475, 50.40114518574306, 48.44762441090175, 53.10279587336949, 49.65746559415545, 44.22593716212681, 45.4298689024789, 49.49286624363491, 49.02281366075788, 49.75397259848458, 49.25878490720476, 48.954551083701, 45.35429334640503, 48.38190834862845, 47.54522017070225, 47.16797815050398, 47.15611062731062, 44.62208523069109, 35.30149023873465, 28.283917358943395, 21.12500422341483, 14.549686789512634, 10.704124638012477, 5.987973613398416, 1.8620290671076094, 1.506491482257843, 2.195982724428177, 6.540343242032187, 7.404877628598895, 8.450010027204241, 8.15901165349143, 8.250421285629272, 11.874672021184649, 8.545813526426043, 7.107253279004778, 5.457724443503788, 0.9825593105384282, 2.9363541049616675, 9.192837595939636, 16.530525275639125, 24.073583466666086, 19.793095350265503, 22.354446274893625, 28.807156664984568, 32.55498545510428, 30.630522046770366, 13.653511609349932, 3.9607784833226884, 0.3621608465909958, 0.06462609076074191, 0.15514080306249006, 0.09499880418713604, 0.10462989631508078, 0.11787784472107887, 0.1359466351568699, 0.1636154611728021, 0.15581105995391095, 0.1381666660308838, 0.12146319661821638, 0.16633996926248074, 0.19576708307223661, 0.15565833529191359, 0.1252170151897839, 0.07430347933300904, 0.15711402360882076, 0.17441562164042676, 0.21134171448647976, 0.17449119687080383, 0.19889153327260697, 0.21330884178834303, 0.13191859344286577, 0.10879803515438523, 0.10068021182503019, 0.10897648986428976, 0.11899117140897683, 0.11033659295311996, 0.13634030760398932, 0.1263785721468074, 0.11830120986061436, 0.2115299536713532, 0.09901681715356452], [0.0567756916529366, 0.030863501198057617, 0.04298723582178354, 0.012018520135565527, 0.03532010902251516, 0.04286296891846827, 0.014609450973304254, 0.04610920936933585, 0.027727370017341206, 0.018437918574948396, 0.03563040308654308, 0.07725507273737874, 0.043956367032868524, 0.03149294760078192, 0.02475118650389569, 0.05900036370647805, 0.025491759979299138, 0.07850794693721191, 0.0523599757413779, 0.023491011267261844, 0.029995461526725973, 0.06384485946702105, 0.026084233008857285, 0.09768646782530205, 0.05688122081171189, 0.01923005562275648, 0.04740779986605048, 0.01111504142837865, 0.00744446468473013, 0.03131793306342193, 0.09784702278141465, 0.04160947725176811, 0.026026542265234247, 0.034762539834316285, 0.05848070087709597, 0.04377182247117162, 0.030418752027409415, 0.042809775165681324, 0.019917121522926858, 0.11700363377375261, 1.72454734146595, 12.838646854673113, 24.918887410845073, 27.306350980486187, 20.683354139328003, 10.164104563849312, 14.569324135780334, 20.891925164631434, 16.507175854274205, 17.095425980431692, 9.565049120358058, 2.8828258344105313, 0.47268063042845043, 0.5597226140754563, 2.335828031812395, 2.871538051537105, 4.705136392797742, 3.120880889041083, 4.7700052091053555, 3.6300548698220934, 2.7124288635594502, 1.96373136980193, 2.7333401186125617, 0.42619501054286957, 1.326497529234205, 1.2204598763159342, 1.059532757316317, 2.258132189512253, 4.673355332442692, 10.84438271181924, 17.045042855398997, 25.50437389101301, 31.615404878343853, 39.67709398269653, 44.12233257293701, 52.33930001940046, 53.18907165527344, 52.51759426934378, 50.155759130205425, 50.08544683456421, 49.10880109242031, 49.637277603149414, 48.85561220986502, 51.62112379074097, 51.70934854234968, 53.43186255863735, 49.380673680986675, 51.03161777768816, 46.79149348395211, 50.53989028930664, 42.431881019047324, 38.67669234957014, 53.4597213608878, 50.63411481039864, 48.64352887017386, 51.71731117793492, 50.19983850206648, 47.38457781927926, 47.50042860848563, 46.35738393238613, 44.106504576546804, 43.29050118582589, 43.826328890664236, 44.64320775440761, 45.91671528135027, 49.82130411693028, 47.83195843015398, 47.38822562353951, 47.5790752683367, 47.59033135005406, 43.94581706183297, 40.889318398066926, 33.310567310878206, 24.8255991595132, 16.805741684777395, 10.037279963493347, 5.8198041915893555, 3.175216453416007, 0.5815966288958276, 0.9651333370379039, 0.6444098097937447, 3.019701438290732, 2.6469379663467407, 3.821422806807927, 4.319831422397068, 4.828968056610652, 5.2019586477960855, 4.81622462613242, 2.406556567975453, 1.8634286948612757, 1.5434752234390803, 0.6572890015585082, 6.206150523253849, 10.634237051010132, 14.493673018046788, 11.223763908658709, 11.240454350199018, 17.42186450958252, 25.531464917319163, 22.004595790590557, 7.467104826654706, 2.1012444709028517, 0.040189646117921383, 0.04361686882163797, 0.030078073165246418, 0.01960100732477648, 0.026448838712115372, 0.013970337142901761, 0.025399847322010567, 0.010758565422812743, 0.04778879388634648, 0.04947824090985315, 0.02845633715125067, 0.03745878354779311, 0.04680002587182181, 0.05652228596487215, 0.055608109304947514, 0.0400352149403521, 0.1447775512933731, 0.04156983045062848, 0.042798273997115235, 0.02803856144393129, 0.026048458946336592, 0.07417622009026152, 0.040101460314222744, 0.037312440507646115, 0.013623171485960484, 0.052819462692631144, 0.048626248591712544, 0.041571726956005604, 0.037479804562670846, 0.03658620108451162, 0.02226014874343361, 0.09894056338816881, 0.020933017367497087, 0.0413721223095698, 0.048087186446147304, 0.015577214936326658, 0.04272674283544932, 0.04285042619864855, 0.07522208004125527, 0.07029875886759587, 0.06200347827481372, 0.028140675875225236, 0.07667537991489683, 0.06212199798652104, 0.07397340597318751, 0.02078820951282978, 0.023009721289521883, 0.05522711867732661, 0.09205488501382725, 0.008596275334379502, 0.04357893532142043, 0.045537848956882954, 0.028116660824577724, 0.03823458316868969, 0.022817405805523907, 0.0441054784958916, 0.04295685441632356, 0.0682163213246635, 0.06004549762500184, 0.04750897961535624, 0.011027121101506054, 0.011949606422734047, 0.01159252058382013, 0.04076500988698431, 0.025872075464576483, 0.01942783670632967, 0.040736172148691754, 0.0960722126598869, 0.018422497170312063, 0.050802673412753005, 0.04275709370683346, 0.04869516400088157, 0.02560926358481603, 0.21938054955431394, 3.6953998548643927, 17.458868878228323, 31.120199816567556, 32.80183410644531, 24.370250701904297, 12.788634589740209, 19.145901918411255, 19.548652512686594, 23.24893477984837, 25.485785722732544, 13.926071201051984, 3.4242338112422397, 0.3957771813230855, 0.2743177302181721, 0.41168386063405443, 1.7132084241935184, 2.5800159573554993, 4.841606829847608, 5.962567525250571, 4.5260708928108215, 2.1561450106757025, 4.116491087845393, 3.3943841329642703, 2.3124599371637617, 2.3985040400709425, 1.7980490773916245, 1.7239187466246741, 3.0358527430466244, 6.30120405129024, 13.626005428177969, 19.598115001405986, 28.88973253113883, 35.05345344543457, 41.12603310176304, 46.37801660810198, 52.41960382461548, 53.46648890631539, 54.31986665725708, 51.82012367248535, 51.98421927860805, 51.26417745862688, 52.554437092372346, 52.48193611417498, 52.83345242909023, 51.85969713756016, 54.94636140550886, 51.140148639678955, 51.37997613634382, 48.25991882596697, 48.93301861626761, 43.170342513493125, 41.186173234667095, 52.96479422705514, 49.99835811342512, 50.52176243918282, 51.84923662458147, 51.0066042627607, 49.22648968015398, 48.7890693119594, 48.297560691833496, 45.978255476270405, 44.01345082691738, 45.60030821391514, 46.12718663896833, 47.46485383169991, 49.771384784153526, 49.611037731170654, 48.11879743848528, 46.91053349631173, 47.79979174477713, 45.603740624019075, 41.909525871276855, 35.70240477153233, 26.73744637625558, 20.386197056089127, 10.969161067690168, 8.590566873550415, 4.262254306248256, 2.1197879101548875, 3.2957359978130887, 1.9783310549599784, 4.292772097246988, 5.641201615333557, 5.965649051325662, 7.018817910126277, 8.391105805124555, 6.848161033221653, 3.3899212181568146, 1.6380486743790763, 0.8118057016815458, 0.5022896730474063, 1.3757129226412093, 6.3940371956144055, 12.783209783690316, 16.70156213215419, 16.358915192740305, 12.738562396594457, 17.206256696156093, 28.78520383153643, 24.382081747055054, 12.435712133135114, 3.080467994724001, 0.1530939478959356, 0.03843391640111804, 0.026958930805059414, 0.0629336005076766, 0.029007419544671263, 0.0191857167519629, 0.031996997339384894, 0.011412054865754076, 0.033415166062435935, 0.014990804617160132, 0.0057283940675136235, 0.015543422196060419, 0.10372589768043586, 0.049182654092354436, 0.02823746550296034, 0.031514809999082766, 0.14241034617381437, 0.03869375120848417, 0.036112722741173844, 0.08017839837287154, 0.0341169714395489, 0.08378217928111553, 0.02000320217173014, 0.028887342595096146, 0.029273680078663995, 0.07155553464378629, 0.05102594196796417, 0.014553861991901482, 0.028915345735315765, 0.07391707399593932, 0.06682776726250138, 0.020755181820797067, 0.013047166501304932, 0.01933056701506887, 0.15353992182229245, 0.10113526454993657, 0.17811518455190317, 0.17789331717150553, 0.16531710486326898, 0.14753844243075165, 0.139320026284882, 0.08570910338312387, 0.20746710311089242, 0.12217352778783866, 0.14864327386021614, 0.1298451397035803, 0.112981176402952, 0.08563272748142481, 0.09898507528539215, 0.09631541996662106, 0.1682739026312317, 0.19196337860609802, 0.12962827991162026, 0.10735066567680665, 0.09971237661583082, 0.14566688000091485, 0.2036096586712769, 0.23309235806976045, 0.3619676541004862, 0.1260879963104214, 0.11459346381681305, 0.12803829594382218, 0.12218841484614781, 0.1423665399530104, 0.14189185042466435, 0.15124650060066155, 0.12302267365157604, 0.1727627646178007, 0.12056541336434227, 0.11920326788510595, 0.10031876979129654, 0.20065770564334734, 0.08155895929251399, 0.30599641320960863, 3.81605749470847, 19.668276173727854, 34.9887170791626, 39.107206208365305, 31.531918798174175, 18.46278977394104, 24.808570861816406, 29.5115841456822, 26.018684761864797, 24.15032458305359, 13.570106301988874, 4.178591915539332, 0.9365536591836384, 1.2020987187113081, 5.21514242036002, 8.975763712610517, 11.84332435471671, 10.606451204844884, 10.665942549705505, 7.552085638046265, 6.9064299293926785, 5.390290004866464, 4.561017726148878, 1.6650409059865134, 3.14107300554003, 2.5953195818832944, 1.7333074999707085, 3.412435552903584, 6.121244404997144, 12.71671986579895, 19.722051756722585, 26.91622700010027, 33.7691901070731, 40.411535944257466, 45.48142453602382, 52.11070081165859, 56.3925837789263, 56.37254517418997, 53.98186111450195, 54.57620307377407, 53.89686380113874, 53.93070500237601, 54.31672954559326, 55.625648566654746, 55.21321044649397, 55.96104506083897, 51.445483752659385, 51.49192203794207, 48.16457911900112, 50.14648675918579, 45.509561266217915, 44.17562525612967, 51.82130834034511, 51.56578138896397, 48.45528827394758, 52.74523115158081, 53.24132558277675, 52.2781662940979, 50.78310850688389, 50.78211838858468, 47.68146044867379, 46.69546243122646, 48.367438725062776, 47.55293961933681, 48.23336281095232, 52.394055298396516, 50.266919885362896, 49.34872586386544, 48.78231566292899, 48.11817557471139, 44.697421073913574, 44.046169894082205, 35.93174396242414, 26.425194331577845, 19.676579271044048, 12.484794207981654, 9.123894095420837, 4.363295878682818, 1.8715923939432417, 3.253608201231275, 2.593105060713632, 5.829839561666761, 6.939307936600276, 8.817587971687317, 10.346472195216588, 11.423068642616272, 13.15268806048802, 10.525826045445033, 5.4862463644572665, 4.0143047996929715, 2.3804563113621304, 1.8150367715529032, 8.3578109060015, 15.059765338897705, 21.392256259918213, 19.327397550855363, 18.41068696975708, 24.903820242200577, 35.933553968157085, 28.235865354537964, 12.781072344098773, 3.5789258990968977, 0.227810017232384, 0.15787508205643722, 0.09173360546784741, 0.16534215637615748, 0.1828513318406684, 0.08958787417837552, 0.10053096804767847, 0.17501628798033508, 0.15601994017405169, 0.15995594539812633, 0.11170814292771475, 0.07330751206193652, 0.18434807152620383, 0.1755692804498332, 0.1401561035641602, 0.15049047688288347, 0.35757204996688025, 0.14461125593100274, 0.16537820015634808, 0.15340467622237547, 0.1406390576490334, 0.13006175522293362, 0.0991060377231666, 0.08103838044085673, 0.16175677733761923, 0.1259940599224397, 0.1576614656618663, 0.24627569637128285, 0.12232595389442784, 0.19659817990447792, 0.08549559555415596, 0.18169061626706803, 0.11740196097109999, 0.11695612275174685], [0.013802296249195933, 0.023182596745235578, 0.07181812769600324, 0.017209262986268316, 0.024734782919819866, 0.03193027020565101, 0.05642686019252453, 0.02613514518764402, 0.09422557282128505, 0.07357111613133124, 0.019080866128206253, 0.024397573067939708, 0.009143086349857705, 0.05391327132071767, 0.026307881543678895, 0.026529228148449744, 0.05948827788233757, 0.0038892817267748925, 0.024643977970949242, 0.017576263918142234, 0.029436633656067506, 0.07318926376423665, 0.012449217694146293, 0.018209720462826744, 0.04516460041382483, 0.02923723596281239, 0.055502539434071095, 0.010079311157044555, 0.06574941905481474, 0.05625945542539869, 0.04522575338238052, 0.020614896402029053, 0.020025196884359633, 0.07506916538945266, 0.04769830106358443, 0.06670700159988233, 0.06328831825937543, 0.043207780058894835, 0.021760017544563328, 0.024149224162101746, 0.028721006520624672, 3.237085384981973, 12.122858200754438, 24.12383805002485, 30.175672122410365, 25.574863365718297, 15.726141010011945, 14.62209483555385, 17.83056971005031, 13.872605681419373, 10.77993903841291, 4.991342680794852, 3.584094273192542, 0.6262076465146882, 0.4957380103213446, 1.1324824371508189, 2.0155903356415883, 3.081439656870706, 4.383642375469208, 2.484541411910738, 1.9810612627438136, 4.755343207291194, 2.94041554416929, 2.1084595237459456, 2.2197640197617665, 0.8403121520365987, 1.5098033845424652, 0.6294248253107071, 1.4007067871945245, 2.9423011115619113, 5.976289783205305, 11.845546909740992, 18.00047401019505, 25.659631388528005, 37.676203863961355, 44.929928643362864, 51.64913545336042, 54.62225225993565, 52.015725885118755, 52.18695729119437, 50.29029709952218, 51.63405786241804, 52.14879083633423, 54.72093752452305, 52.400246143341064, 51.96011945179531, 47.922291960035054, 50.0064423424857, 48.82170500074114, 51.94114392144339, 47.09615114756993, 37.9600065095084, 51.65404435566494, 50.95303017752511, 52.69167791094099, 48.693621907915386, 49.11315761293684, 48.98023509979248, 48.69485521316528, 47.02568251746041, 46.69552149091448, 46.34994241169521, 46.11584023066929, 46.78194318498884, 48.29628917149135, 47.845406668526785, 48.63345398221697, 47.709173338753835, 48.95226512636457, 43.15237099783761, 37.670766898563926, 29.330927508217947, 21.013007947376796, 14.279737983431135, 8.63675241810935, 3.947575603212629, 1.8850616940430232, 1.0196964549166816, 1.2117860274655479, 3.735979505947658, 2.082353404590062, 6.078445672988892, 4.981193099703107, 3.5050391895430426, 5.704423274312701, 5.549172290733882, 4.573194444179535, 3.786685287952423, 1.346008722271238, 0.7368144456829343, 0.9567019151789802, 5.204422218458993, 10.196548308644976, 14.545060157775879, 15.105927433286395, 16.35468373979841, 22.085507563182286, 29.01750990322658, 20.7938391821725, 9.885518278394427, 1.75787915289402, 0.19478749563651426, 0.0027855874795932323, 0.018604110460728407, 0.026949614519253373, 0.02846493079726185, 0.0584414272702166, 0.04589616633685572, 0.019270550592669418, 0.061317832209169865, 0.007001648914800691, 0.018265601214287535, 0.02745420199685863, 0.019427572077672397, 0.04847928808469858, 0.04069654909627778, 0.0074446563708728975, 0.038060501616980345, 0.04486069814967258, 0.0463760161240186, 0.035555669239589145, 0.029906475051705326, 0.03753362935302513, 0.06464835349470377, 0.07662759069353342, 0.037807017897388766, 0.023698213809568967, 0.04344451414155109, 0.012121967888171119, 0.046792066656053066, 0.03847193471821291, 0.018426807564018027, 0.016555799836558954, 0.05849237846476691, 0.019766030433986868, 0.017717965778761675, 0.05021254472168429, 0.03354499016755393, 0.01711992028036288, 0.059113156582627974, 0.04763006079675896, 0.010463836103943842, 0.01392739181340273, 0.08319340766008411, 0.08044527976640634, 0.02916503305147801, 0.014301575886617814, 0.07473938379968915, 0.06046633182891777, 0.036892661425684176, 0.051631100209695954, 0.09128266466515404, 0.033207921111690145, 0.0035362651895931257, 0.062301382289401123, 0.04690703423693776, 0.05647751961701682, 0.04660044836678675, 0.050387270881661346, 0.03778651256912521, 0.03470270322369678, 0.04834887365411435, 0.06987303921154567, 0.04925908427685499, 0.07405920672629561, 0.03079788007640413, 0.010925232283105808, 0.017768696449430924, 0.03911339458344238, 0.08252427713679415, 0.0401075569513653, 0.04093150541718517, 0.05480455420911312, 0.07846614918006317, 0.014390550487275635, 0.08192304082747016, 0.23989969279084886, 5.333280469690051, 16.852688925606863, 30.8159590448652, 33.18330063138689, 28.661793402263097, 19.38767143658229, 19.277624130249023, 18.296717405319214, 16.608994756426128, 14.79128520829337, 11.369973983083453, 3.115606120654515, 0.17149342915841512, 0.6050259545445442, 0.43797462273921284, 1.5174283811024256, 1.9526068695953913, 4.331477906022753, 3.693129530974797, 3.754141662802015, 4.512039874281202, 4.524590492248535, 2.8990761509963443, 3.292077988386154, 1.2068499837602888, 2.8094330983502522, 1.2059962238584245, 2.7481449927602495, 4.205677730696542, 8.612654328346252, 13.716576065335955, 21.60923981666565, 29.854185921805247, 38.881521769932334, 47.86568151201521, 54.177831581660676, 54.08555255617414, 53.37565163203648, 53.09283563068935, 52.82121665137154, 51.69262422834124, 54.51138680321829, 55.45524747031075, 53.597549302237375, 53.65260682787214, 49.12416703360421, 50.53033651624407, 48.4090758051191, 50.7843313898359, 47.85199703489031, 40.832582882472444, 52.44975553240095, 49.823496273585725, 52.44165393284389, 49.04040649959019, 50.15863915852138, 49.71321446555001, 50.81631742204939, 48.57775027411324, 49.99067687988281, 47.70409420558384, 48.27266877038138, 47.5565561567034, 49.31058720179966, 50.028290952954976, 50.821657112666536, 47.878250803266255, 49.626309871673584, 43.515640190669465, 39.91339526857649, 32.276178564344136, 24.47969698905945, 17.12103530338832, 10.762595466205052, 5.735093057155609, 2.8903737493923733, 2.081162005662918, 1.9144150103841509, 3.5496342480182648, 5.529361239501408, 5.741631746292114, 7.3924290622983655, 9.524297067097255, 9.69020094190325, 6.406194371836526, 4.988596839564187, 1.964199070419584, 0.4981893130711147, 0.4381752519735268, 0.848590224981308, 5.082019712243762, 11.686299409185137, 17.8277713230678, 15.17715515409197, 15.856671605791364, 20.80685315813337, 30.601502895355225, 25.21198500905718, 14.724189928599767, 2.6986012969698225, 0.4581897280045918, 0.02728292958012649, 0.057635409092264514, 0.016634684621489475, 0.0367522318182247, 0.056932209325688224, 0.012732951353037996, 0.051479172826345475, 0.02762350157302405, 0.012447890310016061, 0.023832477230046476, 0.010217773861118724, 0.03406652236091239, 0.03401652450806328, 0.03385648523856487, 0.007679806074260601, 0.05932559911161661, 0.08653285846646343, 0.048476512876472304, 0.02972108232123511, 0.06562566105276346, 0.02969130141926663, 0.053329693885254006, 0.06638992897101811, 0.030098754912614822, 0.013637635308051748, 0.01407917246355542, 0.05812362860888243, 0.028676538728177547, 0.04317125791151609, 0.06359429005533457, 0.03446655607383166, 0.054934748115816286, 0.046173385211399624, 0.05020067375153303, 0.1570097463471549, 0.09372127202472516, 0.14103100661720547, 0.0868776153240885, 0.1779416695769344, 0.09507771102445466, 0.15456197197948182, 0.18112705222197942, 0.16664068241204533, 0.09091613361878054, 0.19485701833452496, 0.22013121284544468, 0.17229164418365273, 0.17277106988642896, 0.09928959501641137, 0.16493051632174424, 0.21443588845431805, 0.16598531257893356, 0.07777683223996844, 0.2348278606576579, 0.11970845077719007, 0.11905962202165808, 0.18838543631136417, 0.10573958605527878, 0.24107567540236882, 0.08136380583580051, 0.12933652342430182, 0.1677068237747465, 0.1493270064571074, 0.11342518936310496, 0.09115005856645958, 0.1365522276610136, 0.08896668215415307, 0.19267339764961175, 0.18997656021799358, 0.15198007838002273, 0.20061129384807178, 0.2348486509706293, 0.11584306747785636, 0.0911500992785607, 0.450413173862866, 5.273737013339996, 18.07611210005624, 36.95356341770717, 41.23258720125471, 36.9536954334804, 25.55871227809361, 24.212167024612427, 26.361053773335048, 21.725069761276245, 17.12965280669076, 9.488301924296788, 4.747951192515237, 1.311407236116273, 0.9507860669067928, 1.8850241303443909, 4.906958545957293, 7.100966462067195, 11.505248461450849, 9.00841850893838, 7.0336431946073255, 10.229492323739187, 8.522282583372933, 5.2576232722827365, 4.051475490842547, 2.1921505757740567, 3.1676646300724576, 1.2153097412415912, 2.294314065149852, 3.8205577560833524, 7.135739590440478, 13.42556813785008, 21.061290979385376, 29.432843685150146, 39.26197733197893, 49.57704019546509, 55.22273642676217, 58.38574750082833, 56.30691596439907, 56.44690132141113, 55.29420212336949, 54.45605134963989, 56.104831082480295, 57.90034287316458, 54.41527584620884, 53.76034559522356, 48.064090796879356, 50.82157026018415, 49.830374990190776, 52.44084446770804, 51.06081410816738, 44.628554003579275, 51.06215858459473, 48.63234921864101, 53.054443359375, 50.11824580601284, 49.706481661115376, 52.40159061976841, 52.36335815702166, 51.19632135118757, 51.115461690085276, 50.24749272210257, 49.222067151750835, 50.26955325262887, 51.55750955854143, 51.71316310337612, 50.6124016898019, 49.88674225125994, 50.383653095790315, 43.694337436131065, 39.81484201976231, 32.444953782217844, 23.934114013399395, 16.109443596431188, 10.701208131653921, 6.541024599756513, 3.338141505207334, 2.9236380330153873, 3.4865133379186903, 6.190596980707986, 6.027555329459054, 12.297883323260717, 11.185193589755468, 8.080475296292986, 11.92516371182033, 10.495627437319074, 10.263363923345294, 8.298373409679957, 2.920541524887085, 1.3042167190994536, 1.732321398598807, 6.491678059101105, 13.959611892700195, 21.08257852281843, 23.36817455291748, 25.252018792288645, 32.13002668108259, 38.80139166968209, 29.50825595855713, 15.206214257649012, 3.035781958273479, 0.34984934436423437, 0.07728945410677365, 0.12927852225090775, 0.17933396915239946, 0.0826882179826498, 0.1320364006928035, 0.11039776288505111, 0.09131017926016025, 0.15090925512569292, 0.09856884154890265, 0.15872912694300922, 0.10990874948246138, 0.051407146334115944, 0.108252241941435, 0.12796356209686824, 0.10356134615306344, 0.18927419504949025, 0.18368161443088735, 0.15180329286626407, 0.13302708896143095, 0.08659699359642607, 0.09288379017795835, 0.17382141495389597, 0.19894422830215522, 0.0671321852132678, 0.12449742880250726, 0.07949265731232506, 0.09208782110363245, 0.08490715641528368, 0.12411913195891039, 0.1661487038114241, 0.1278069019317627, 0.1118038570774453, 0.1498449593782425, 0.1306155619344541], [0.04173350327515176, 0.11385836611901011, 0.04820567223110369, 0.05538067115204675, 0.06120464578270912, 0.05563612262319241, 0.050269636658153365, 0.05224909294130547, 0.04214480745473078, 0.030085594725928137, 0.050813859062535424, 0.07268042356840201, 0.032740963489881585, 0.029284865728446415, 0.05503365138013448, 0.03959742075364504, 0.07600604583110128, 0.0205068617526974, 0.048147576062807014, 0.06216294078954628, 0.03421337430232337, 0.06899693515151739, 0.022108779455135976, 0.03388988273218274, 0.03723543356837971, 0.02080677931995264, 0.02560269197316042, 0.017340330506807992, 0.011130205837876668, 0.07558185287884303, 0.09805354848504066, 0.03565971579934869, 0.03836010196911437, 0.026584766239726117, 0.022320826737476245, 0.030287190872643675, 0.035230474546551704, 0.008138027557704066, 0.05071857917521681, 0.01780702010728419, 0.0420386201169874, 0.2954739364130156, 2.828099868127278, 12.68401208945683, 20.30496392931257, 31.274515833173478, 26.08345239503043, 13.88256071295057, 15.88017041342599, 15.50420686176845, 15.874754292624337, 12.152367200170245, 7.364152499607631, 5.264222323894501, 0.9799056415046964, 0.7587022483348846, 0.7255088037678173, 2.4002137311867306, 2.7329217067786624, 3.3253943834986006, 1.7503411173820496, 3.20137967807906, 3.430769677673067, 4.257371459688459, 2.180495624031339, 1.473493292927742, 1.664929409112249, 0.8478229918650219, 0.5963143791471208, 1.798700905271939, 1.2306774194751466, 2.605227278811591, 6.543931986604418, 11.678275108337402, 18.87933427946908, 32.8989143371582, 44.19693190710885, 51.12327493940081, 52.319511549813406, 55.346570696149556, 54.56594753265381, 51.966807092939106, 53.12926851000105, 52.75641080311367, 51.44814838681902, 50.89630855832781, 53.21078130177089, 49.1704455103193, 54.05810717173985, 48.60900674547468, 50.14416258675711, 41.69698395047869, 54.730262007032124, 45.720981052943635, 45.69338975633894, 55.81174564361572, 49.09713854108538, 50.282518591199604, 49.53507655007498, 48.01523106438773, 48.85895429338728, 47.962647097451345, 47.46510396684919, 47.030789443424766, 47.11453260694231, 48.801180022103445, 48.477209840502056, 49.32685988289969, 45.69442156382969, 36.665609223502024, 27.127334117889404, 16.44977331161499, 10.004788449832372, 4.612835219928196, 3.508003464766911, 1.0556419832365853, 0.8067778114761625, 0.9506689246211733, 1.6482856507812227, 3.65467038324901, 5.001336361680712, 3.5434703273432593, 6.713247861180987, 11.920187064579554, 9.673698101724897, 6.915028759411403, 5.7012297085353305, 0.39995600708893364, 0.5655913448759488, 1.146234659211976, 4.661271980830601, 9.822470324380056, 10.191968577248709, 13.91085638318743, 15.589438676834106, 28.713234390531266, 29.00965322766985, 18.177461998803274, 9.04521530015128, 2.309636797223772, 0.22205922938883305, 0.04460652232436197, 0.0709502814071519, 0.049533622938075235, 0.008638642212775136, 0.029885169052119766, 0.05160841339134744, 0.023723151667841842, 0.033273549018693824, 0.03815872634627989, 0.05516326853207179, 0.04733309316049729, 0.024657138157635927, 0.006860443656998021, 0.052466393781027625, 0.07894073014280625, 0.04181994524385248, 0.048551901509719234, 0.03363912672336612, 0.03589592401736549, 0.03819529938378504, 0.024532820364194255, 0.06680361820118767, 0.03450553112530282, 0.03276027798918741, 0.029000213502773216, 0.04258736834994384, 0.053407138479607444, 0.019040325357179557, 0.02823875641583332, 0.12089383788406849, 0.03164351452142, 0.046283253601619175, 0.1093198557251266, 0.03252912485705955, 0.04482772134776626, 0.08052578794636897, 0.07229304792625563, 0.05227850064901369, 0.03533120985542025, 0.11382003567580666, 0.03891563894493239, 0.06164764094033411, 0.02737365480113242, 0.02418996170828385, 0.03999435356152909, 0.03551401397479432, 0.02331427494729204, 0.02591253481140094, 0.02538037167063781, 0.031717505372528515, 0.05584981365661536, 0.035029329625623565, 0.02407842581825597, 0.02631705703346857, 0.03182193191189851, 0.046186097564974, 0.034639144848499975, 0.03871312338326659, 0.04698401403480342, 0.03879813703575304, 0.058878458105027676, 0.0023091225219624384, 0.029908422447208847, 0.02389193555739309, 0.019329320206972103, 0.03195695020258427, 0.01598143351397344, 0.06765036883630923, 0.026114553346165588, 0.03442018838333232, 0.06190897870276656, 0.03218641717519079, 0.04152605815657547, 0.03033428798828806, 0.04431963771847742, 0.0224683215908174, 0.4627112139548574, 5.718507272856576, 17.70913256917681, 28.664060252053396, 34.26735162734985, 30.692096982683452, 19.2479726927621, 17.789502382278442, 16.52902967589242, 16.77082003865923, 17.034888063158306, 13.852333443505422, 5.015600144863129, 0.7549142315983772, 0.04801099714157837, 0.29172883023108753, 0.6553250498005322, 3.0190693693501607, 3.9147944365228926, 4.376126595905848, 6.044519356318882, 4.6031659330640515, 5.199869845594678, 3.657484403678349, 2.6331377582890645, 2.7995655706950595, 1.327666346515928, 2.1845475094658986, 2.385931057589395, 1.8436582471643175, 3.383304144654955, 7.63508187021528, 13.423186642783028, 22.20750229699271, 36.10092912401472, 47.30287395204817, 53.41449553625924, 54.74686125346592, 55.18240908214024, 56.473794324057444, 53.54576437813895, 55.00722067696707, 53.46498114722115, 51.98850284303938, 51.30410875592913, 52.114692551749094, 49.93419844763619, 54.8696984563555, 49.68567875453404, 51.77490132195609, 43.27403742926461, 54.56660066332136, 46.4415648324149, 46.60983977999006, 54.27491876057216, 49.40479435239519, 50.61158875056675, 50.723777839115684, 48.80746119362967, 49.91506658281599, 47.92491143090384, 49.70027344567435, 47.83530398777553, 49.62482990537371, 49.510598046439036, 50.4466941016061, 50.06634971073696, 47.18922921589443, 38.33770016261509, 29.557921682085308, 19.184763193130493, 13.88998920576913, 6.291025808879307, 4.384028434753418, 1.6298456745488303, 1.7668319067784717, 2.202046113354819, 2.6459578360830034, 3.115832588502339, 7.071976406233651, 5.268698266574314, 7.108542604105813, 12.114713174956185, 9.445629562650408, 7.638204216957092, 2.6446216106414795, 0.6650074731026376, 0.1618453397282532, 1.200696919645582, 5.099276866231646, 12.63559443610055, 13.454185162271772, 15.373019661222186, 15.449602706091744, 29.596887179783412, 31.921858651297434, 26.885079962866648, 13.036826848983765, 3.8650605337960378, 0.46002356388739174, 0.016048245464584658, 0.072940180344241, 0.08206225585724626, 0.004312430159188807, 0.04273675801232457, 0.044072335452905724, 0.02187407758486058, 0.10180214912231479, 0.012090594973415136, 0.02416951405549688, 0.04253645108214446, 0.061660030989774635, 0.06053029732512576, 0.05571585388055869, 0.026081710554925457, 0.10567145435405628, 0.028166271912466203, 0.019725326814555695, 0.05062225434396948, 0.051398807138736756, 0.056522686300533156, 0.07911343087575265, 0.03549783769994974, 0.03781828836404851, 0.06331939516322953, 0.011897007236257195, 0.009873774418208216, 0.011547958644639169, 0.010206088639928826, 0.017948192710589086, 0.05484355640198503, 0.038779355186436854, 0.018195154012313912, 0.053859975787677934, 0.07259500958025455, 0.11970627946513039, 0.13269202836922236, 0.1811425092497042, 0.09637598600238562, 0.16705887711473874, 0.08170694099473101, 0.12156694462256772, 0.14492461697331496, 0.09597476824585881, 0.09798285870679788, 0.09392656279461724, 0.1318059837711709, 0.18309968922819408, 0.10373239126056433, 0.1063777075282165, 0.12223467736371926, 0.07751324852662426, 0.08755574322172574, 0.15772410801478795, 0.18733473840568746, 0.11214839001851422, 0.1551139195050512, 0.07984179750617061, 0.11973587716264383, 0.12569542309003218, 0.08655230528009789, 0.09163037993546043, 0.14478017043854507, 0.12889194728008338, 0.15749014914035797, 0.1617478071046727, 0.12405323263789926, 0.13402192986437253, 0.16146191315991537, 0.13594352746648447, 0.18023135885596275, 0.14275189356080123, 0.09517499259007828, 0.12137584201991558, 0.11541500687599182, 0.1980063979114805, 0.505641581756728, 5.575792142323085, 19.177219186510357, 31.91655717577253, 43.047477517809185, 38.76815496172224, 24.630773408072336, 25.16632318496704, 24.090484959738596, 25.826290879930767, 18.728641748428345, 12.188345840999059, 6.3634329863957, 1.693466420684542, 1.4864351813282286, 2.329088930572782, 5.226414135524204, 11.290862662451607, 10.393640909876142, 5.492667368480137, 8.920815621103559, 7.0399981907435825, 11.066818867410932, 6.692259958812168, 5.128833200250353, 3.2904132434300015, 2.952483696596963, 2.0354057294981818, 3.4518023090703145, 1.9567818684237344, 3.3542439554418837, 7.7937995706285745, 13.567383476666041, 20.933169671467372, 36.38523203986031, 47.43260029384068, 53.88630601337978, 56.22313458578927, 57.50754731042044, 58.257407324654714, 54.22486046382359, 56.095114026750835, 52.60379014696394, 50.50786256790161, 52.63032184328352, 53.61218915666853, 49.93174225943429, 56.37269456045968, 48.52778230394636, 52.85351882662092, 47.732908385140554, 55.16621283122471, 48.31987483160836, 47.305410044533865, 55.71595777784075, 51.15700496946062, 51.63229996817452, 52.56474821908133, 51.35548373631069, 53.01725312641689, 50.85645716530936, 50.48374884469168, 50.23804317201887, 50.44179214750017, 50.76926074709211, 52.0744868006025, 50.4134851864406, 47.216219493321006, 39.18922274453299, 29.437554563794816, 18.982362168175833, 13.1151009116854, 7.4189399140221735, 5.356060573032924, 2.1298627981117795, 2.6383936362607137, 2.5834752917289734, 6.476836706910815, 9.59251708643777, 10.95601681300572, 10.321136457579476, 11.615631886890956, 21.675605535507202, 16.704588072640554, 12.797709805624825, 9.988875338009425, 2.4595771857670377, 1.4987134081976754, 2.2908393144607544, 6.395475472722735, 14.016995327813284, 14.943683522088186, 23.33318863596235, 24.325598103659495, 40.00765453066145, 38.52788625444685, 31.482663018362864, 14.067467042378016, 3.9225521002496992, 0.5761985299842698, 0.11976296428058829, 0.10945628197597605, 0.10284395143389702, 0.13271823339164257, 0.13806666353983538, 0.14225059188902378, 0.12139258826417582, 0.14936087892523833, 0.17654194682836533, 0.12910656790648187, 0.15850294407989296, 0.11217593854027134, 0.13746674358844757, 0.1318166639123644, 0.22030904330313206, 0.15969076034213814, 0.0986832764797977, 0.10723371338099241, 0.15197289947952541, 0.14373264807675565, 0.14316871762275696, 0.1543343641928264, 0.16143380823944295, 0.14907745484794888, 0.18642556933420046, 0.127059916300433, 0.07697738906634705, 0.16148781962692738, 0.1809109388185399, 0.1552045446421419, 0.1766767581658704, 0.14925684593617916, 0.17700782897216932, 0.11412964441946574, 0.1640685868582555], [0.02351998640889568, 0.06307704959596906, 0.025544868915208747, 0.036119474164609394, 0.024316566164738367, 0.01984628246697996, 0.07302735852343695, 0.05193793374512877, 0.03725191518398268, 0.06717027816921473, 0.045626265462487936, 0.06434333843312093, 0.03547935101336666, 0.031900261994451284, 0.028003191109746695, 0.027581488381006887, 0.03588223796603935, 0.020356294832059314, 0.02913679920935205, 0.03830101853236556, 0.051508865518761535, 0.026862646685913205, 0.05010674075622644, 0.01586874241807631, 0.08328650266464267, 0.05235477137778487, 0.0147468085134668, 0.04244384462279933, 0.022719735778602104, 0.06137503271124192, 0.03709156718105078, 0.039329623337835073, 0.03716624674520322, 0.04951230676046439, 0.015790844901597927, 0.019531789967524152, 0.04789064877799579, 0.017734359184812223, 0.021623486120785986, 0.024023108250860657, 0.013786214969253965, 0.030644035831625973, 0.2509426602295467, 2.628179350069591, 11.532925742013113, 23.89552024432591, 32.36388220105852, 27.663662093026296, 13.045130814824786, 6.436082482337952, 14.801488637924194, 24.689624650137766, 13.562959211213247, 12.655656491007123, 5.881685716765268, 1.6287613213062286, 0.16723193068589481, 0.40240492139543804, 1.1501458436250687, 1.6855355948209763, 4.078340266432081, 4.200285060065133, 2.6478809671742574, 2.4098065878663744, 3.485311950956072, 0.621900523347514, 1.87900481905256, 0.7315608475889478, 2.8617610675948004, 1.5530374646186829, 1.0472119727305003, 0.5439144851905959, 0.6917874589562416, 2.822493323257991, 8.346203071730477, 16.562985522406443, 28.341111455644878, 39.253823620932444, 48.87164517811367, 51.18123681204659, 53.08424070903233, 52.14263473238264, 51.149657249450684, 52.60701411111014, 51.99361324310303, 49.613302843911306, 52.198720591408865, 51.06047364643642, 53.71105507441929, 52.09122848510742, 52.159095014844624, 49.91546263013567, 53.228009360177175, 49.375931535448345, 50.18864842823574, 50.87620741980416, 52.51095526559012, 49.03330544063023, 50.657658781324116, 51.56350932802473, 51.3643148967198, 49.8863114629473, 51.496122223990305, 48.472141129629954, 51.26566784722464, 47.32402079445975, 49.31832749502999, 40.90074471064976, 33.55218396868025, 21.640286105019705, 14.760023525782994, 6.870506005627768, 4.446377660546984, 1.302435808948108, 0.8689419329166412, 0.6758004682404655, 1.4052443951368332, 3.3550451695919037, 0.5957947841712407, 1.8963944230760847, 8.659765720367432, 4.782142409256526, 6.210400215217045, 12.20687929221562, 7.957856961659022, 6.226734127317156, 2.0894205910818915, 1.1606873465435845, 0.959882344518389, 5.331370149339948, 10.804748450006757, 11.066007665225438, 19.133942331586564, 19.83336363519941, 21.344796589442662, 21.460028988974436, 17.657948664256505, 7.9946772030421664, 2.3249662603650774, 0.2077826897480658, 0.013466719970373171, 0.0507485059622143, 0.037156401202082634, 0.03931934013962746, 0.03687540628015995, 0.0427073265558907, 0.011393728483069156, 0.03058741886966995, 0.02721333224326372, 0.011485680156121296, 0.0161375593327518, 0.09596503805369139, 0.041109000000038316, 0.05186985971938286, 0.025109252825911556, 0.02320938361143427, 0.04640259434069906, 0.008147210681012698, 0.050562600937805006, 0.07096251539353814, 0.11629978939890862, 0.026741806384442107, 0.022084053639056425, 0.11253342471484627, 0.09345094367329564, 0.09692481905221939, 0.04190588848931449, 0.03305425667869193, 0.028583362299416746, 0.03958459644179259, 0.029833074526063035, 0.012618162735764469, 0.07464458567223378, 0.06776666295315538, 0.12278076234672751, 0.06813904297138963, 0.05226750838171158, 0.04785361772935305, 0.027123667233224426, 0.04485849291086197, 0.020289487970460738, 0.04947012223835502, 0.02479558135382831, 0.07177385328603642, 0.03280404010521514, 0.05533662065863609, 0.03580671362578869, 0.0412230685220233, 0.011851155232372028, 0.028422300138377717, 0.03738726256415248, 0.026993875358519808, 0.01575767980622394, 0.10414986671613795, 0.024999496393970082, 0.020616721661229218, 0.08296351999576602, 0.04906152202082532, 0.022450314967760017, 0.05590286152437329, 0.039264860562980175, 0.052205907580043585, 0.021608770392569046, 0.0168607351702771, 0.07451516868812696, 0.018351052521861026, 0.04054122564515897, 0.0453296845911869, 0.05220817727968097, 0.016066691439066614, 0.04366038666505899, 0.00834450576387878, 0.03828393980594618, 0.021131124147879224, 0.013461932057647832, 0.01972779498568603, 0.0524978303084416, 0.037285651945109875, 0.5824029456291879, 5.063782427992139, 16.187980822154454, 30.91546767098563, 37.31788873672485, 29.527280126299175, 16.920392172677175, 9.476375341415405, 14.253361753055028, 16.472533873149327, 12.879951289721898, 13.50132087298802, 5.797439677374704, 1.9386996158531733, 0.1858024706265756, 0.30151349518980297, 0.7323750896113259, 1.4594552176339286, 4.255277012075696, 5.081313167299543, 5.52133389881679, 4.475831942898886, 2.8009133040905, 3.4802462799208502, 3.3698285477502004, 2.6814987404005866, 3.4869667078767503, 3.1552273545946394, 2.6695230858666554, 1.0481815721307481, 2.1917810184614996, 5.275548321860177, 10.725017871175494, 20.489843334470475, 30.97055298941476, 40.835747786930625, 50.87352194104876, 53.604872703552246, 54.34634971618652, 52.09766599110195, 52.240145751408164, 51.488618169512065, 52.71244955062866, 51.70104544503348, 52.36732905251639, 51.53541081292288, 53.81623690468924, 52.62854310444423, 52.885834898267476, 49.219082900456016, 53.04409749167306, 50.903232438223704, 50.83232607160296, 51.98497315815517, 52.35486398424421, 49.68277440752302, 50.92511578968593, 53.016064984457834, 52.89841113771711, 51.77112150192261, 52.14724486214774, 49.92413398197719, 52.580117634364534, 49.934990542275564, 51.69515337262835, 44.403154441288535, 37.236938749040874, 24.09038073675973, 17.868909869875225, 9.348221898078918, 5.043524086475372, 2.1031233072280884, 1.1141897844416755, 1.7982603460550308, 2.7171579812254225, 3.8661461898258755, 3.7751538838659013, 4.645873469965799, 5.023999648434775, 4.926420884472983, 4.805644690990448, 5.688934436866215, 4.118300659315927, 3.0092124811240604, 1.709624565073422, 0.5515193428312029, 1.101500745330538, 4.295271277427673, 12.509714790752955, 15.121161358697073, 17.89378615788051, 21.07898804119655, 25.27146680014474, 29.131290129252843, 25.21755572727748, 11.920722075871058, 4.253461795193808, 0.6025950621281351, 0.041444406645106416, 0.07143666887921946, 0.03137200891173311, 0.04217732624549951, 0.03270239555942161, 0.07022429643464939, 0.03017390945128032, 0.05116916035435029, 0.014305491033675415, 0.03744173874812467, 0.03659074726913657, 0.07317763367401701, 0.003156397325385894, 0.02409106183664075, 0.03569211245381406, 0.04123300566737141, 0.04707703779318503, 0.048936142320079465, 0.01274879344938589, 0.04801691735961607, 0.042986319799508364, 0.036784737038293054, 0.1140054182282516, 0.08741990051099233, 0.009185002002465938, 0.03563256422057748, 0.013772217639988022, 0.029059795662760735, 0.0784478083785091, 0.05040239203455193, 0.03728112950921059, 0.022841950113485967, 0.01816465555956321, 0.04059325231771384, 0.023537799649472748, 0.05142154484721167, 0.1413553599268198, 0.16577293111809663, 0.1251779180020094, 0.19038036997829164, 0.0759440820131983, 0.11804477790636675, 0.08921288858566966, 0.16647597482161863, 0.14031321156237805, 0.11069281705256019, 0.154685180368168, 0.18165031128696033, 0.1472636086067983, 0.14793710889560835, 0.20999109053186008, 0.0841968252456614, 0.09030429180711508, 0.14629004656204156, 0.10758265679968254, 0.2352139199418681, 0.16740966614867958, 0.14043209089764527, 0.09991237481257745, 0.11892870547516005, 0.21428538938718183, 0.10754241967307669, 0.05845056713691779, 0.229336395327534, 0.13765943396304334, 0.1375042258628777, 0.1303339156189135, 0.16060279283140386, 0.12409650960138865, 0.12255346668618065, 0.08005294403327362, 0.1070746308458703, 0.13756187419806207, 0.07766443291412932, 0.11394736277205603, 0.10635690364454474, 0.1822264960833958, 0.10887251115803208, 0.609085059591702, 4.708742942128863, 17.385428156171525, 34.1942253112793, 44.083009243011475, 38.01151697976248, 22.377066135406494, 14.290089062282018, 22.335498537336075, 32.23452411379133, 19.991042579923356, 18.747033630098613, 7.534764647483826, 2.281666172402246, 0.35944999062589233, 1.4499558359384537, 3.593191202197756, 6.053254978997367, 11.140399421964373, 10.935162663459778, 9.558935574122838, 7.117921369416373, 6.4717045937265665, 3.229080843073981, 6.606556969029563, 3.0111423432826996, 6.649674015385764, 3.2173373017992293, 3.0842686593532562, 1.2445993295737674, 1.897715449333191, 4.005291683333261, 9.435502563204084, 18.664120776312693, 30.12306731087821, 41.64988906042916, 51.16218485151018, 53.3339832850865, 55.62629474912371, 51.24955497469221, 51.86177812303816, 51.33376366751534, 53.68603808539254, 50.59403412682669, 52.862207548958914, 50.26378624779837, 54.057520048958914, 53.13118968691145, 54.514937332698274, 52.23148829596383, 54.24601772853306, 52.47410896846226, 52.28916181836809, 50.77675090517317, 52.5693861416408, 50.508036272866384, 52.191105365753174, 54.836670194353374, 53.62539768218994, 52.92704119001116, 54.77994510105678, 50.366536208561485, 54.75515392848423, 49.68688079289028, 53.63479164668492, 42.94081572123936, 37.438499041966026, 24.001214504241943, 18.024718012128556, 9.150190421513148, 6.125892749854496, 2.170344957283565, 1.7434944276298796, 2.4341671892574857, 4.569728595869882, 6.9594520671027045, 6.443993874958583, 9.139663900647845, 17.372139726366314, 14.269264442580086, 14.758345535823278, 22.579090220587595, 15.971368994031634, 11.529394320079259, 4.117618433066776, 2.302071294614247, 1.5009956743035997, 6.624998790877206, 14.234249864305768, 17.115560122898646, 27.649227210453578, 29.66963481903076, 31.305609021868023, 33.69922522136143, 28.86779359408787, 14.038509556225367, 3.998776878629412, 0.5790937574846404, 0.10155671622071948, 0.20557399040886334, 0.15210868790745735, 0.12373406333582741, 0.09813223819115333, 0.11775885682020869, 0.13668066076934338, 0.18176145532301494, 0.09244928349341665, 0.11090284399688244, 0.17195670572774752, 0.1994359762008701, 0.16038822648780687, 0.09215549818639245, 0.10993938533855335, 0.18710637065981114, 0.10512106745902981, 0.09055245920483555, 0.12016263497727257, 0.14426863645868643, 0.25495003376688274, 0.19581414626113006, 0.15659704777811254, 0.23465895972081594, 0.24132773759109633, 0.24005787287439617, 0.09825161964233432, 0.1488883335675512, 0.16516267029302462, 0.12311430302049432, 0.08252994290419988, 0.10656150230871779, 0.14500901315893444, 0.16867057420313358, 0.18680862949362823, 0.1825869203146015], [0.06545373384973832, 0.03733864892274141, 0.049984197331858535, 0.057513327071709294, 0.04904534574598074, 0.029127259006989852, 0.038787463679909706, 0.033697775897703, 0.03299775846036417, 0.016440698245008076, 0.04107228786285434, 0.025531881754951816, 0.06432435980864934, 0.02042647570903812, 0.02673182004530515, 0.06402254064700433, 0.05415588490931051, 0.05602613098121115, 0.0304882916887956, 0.019781383985121335, 0.0425050552668316, 0.06436525511422328, 0.025189060418467437, 0.026485184440389276, 0.04116098935316716, 0.031114586296358278, 0.07561109773814678, 0.0327548123896122, 0.024682064141545976, 0.054926103579678705, 0.023452268614034568, 0.055060290664966614, 0.028947647394878522, 0.031298068950751, 0.05634423837597881, 0.009061095570879323, 0.0531285828910768, 0.012050816706115646, 0.03819631379363792, 0.026516088317813616, 0.014752749087555068, 0.07471308378236634, 0.04449281681861196, 0.17942150016980513, 1.7766927033662796, 8.73516583442688, 19.268730436052593, 28.37327814102173, 25.625852721078054, 23.07066658564976, 19.27358201571873, 23.774548632758005, 28.192991495132446, 18.51799668584551, 13.82399434702737, 7.340847373008728, 2.712304664509637, 0.4674980885216168, 0.5556205713323185, 1.148239974464689, 2.3502820219312395, 4.405104058129447, 4.769893169403076, 3.5579525445188795, 1.1685030928679874, 2.5986901095935275, 2.4462854989937375, 1.8148453703948428, 2.3883761720997945, 2.216394577707563, 0.5546616656439645, 0.8958771675825119, 1.5237645953893661, 0.7752610540815762, 2.0682333622659956, 7.45477785382952, 16.012478010995046, 22.221886805125646, 33.36495086124965, 44.86811399459839, 49.91146394184658, 53.67717913218907, 52.39340911592756, 51.21997996738979, 53.243514265332905, 52.54369865145002, 52.2997647694179, 51.03460897718157, 53.52768863950457, 49.09175716127668, 52.395142691476, 48.91485602515084, 55.59481593540737, 49.65456472124372, 49.82025841304234, 55.88533401489258, 54.975245067051475, 49.64151947838919, 51.94360358374459, 50.09248883383614, 52.30513225282942, 50.247204371861045, 51.7855737549918, 50.77465949739729, 45.0338111604963, 46.33037975856236, 39.212579114096506, 26.729296139308385, 18.717380455562047, 10.857031907354083, 4.624896858419691, 1.5212885396821159, 1.813890970179013, 0.274620601109096, 0.20294485720140593, 1.2109202167817523, 2.818539581128529, 2.270068109035492, 2.777738021952765, 1.7127421349287033, 2.8235618259225572, 2.5545599290302823, 2.531315382037844, 3.8082503250667026, 2.833242620740618, 2.229894710438592, 0.8070562279650143, 0.5483759343624115, 5.853869037968772, 12.53716972896031, 14.850468226841517, 15.496532576424734, 21.043444531304495, 18.115728991372244, 23.624465806143625, 22.146446738924297, 12.290587714740209, 3.284229346684047, 0.3646760401981217, 0.029882689006626606, 0.06356126575597695, 0.03803984701101269, 0.010531386809556611, 0.01383460808678397, 0.03279189093570624, 0.024656376502077495, 0.014685848927391427, 0.007617995774905596, 0.018927610512556772, 0.07544063617076192, 0.061787541290479045, 0.05272052550156202, 0.02581658147807632, 0.038518088670181375, 0.045892264760498486, 0.03077408724597522, 0.015162499421941382, 0.06642553848879677, 0.028666744075183357, 0.050550641758101325, 0.05569091771862336, 0.05077688908204436, 0.07549671030470304, 0.07593156304210424, 0.035276811702975204, 0.044875938046191416, 0.0924626167065331, 0.05533105667148318, 0.009912071782829506, 0.03155315740566168, 0.01570957336973931, 0.0125949534454516, 0.03942170732521585, 0.05433431926316448, 0.02496575454383024, 0.04995375485824687, 0.01006202887011958, 0.07164143039179699, 0.05488967303452747, 0.060682390949555805, 0.01716626761481166, 0.0325563069699066, 0.043014322939727984, 0.06079616770148277, 0.04482931251238499, 0.03299376867445452, 0.023867357322680097, 0.011976455205253192, 0.023294130938925912, 0.019488482469958917, 0.06829010522259132, 0.036938703419374566, 0.059876596688159874, 0.05030628094183547, 0.02648437359104199, 0.017791549508859004, 0.0415691722716604, 0.0397011619726462, 0.012853667821868189, 0.020772492945460335, 0.07813377558652844, 0.04543307636465345, 0.016475800557860305, 0.0429466933544193, 0.05142124629180346, 0.04963614618671792, 0.025017681132469858, 0.047942672057875564, 0.035149114805140665, 0.037587274331599474, 0.02152552262746862, 0.06496531077261482, 0.026843819035483257, 0.03966970508918166, 0.07272348340068545, 0.05177031184679695, 0.049594965896436145, 0.09878319754664387, 0.06696088904781, 0.38734470094953266, 3.7895414318357195, 12.826274718557086, 26.466866152627126, 34.09904541288103, 28.584126438413346, 23.953706196376256, 19.24238634109497, 22.684661149978638, 25.878534385136195, 26.8099456174033, 17.061628205435618, 7.285992213657924, 2.4737945028713773, 0.13870139233767986, 0.3175856556211199, 0.5887377485632896, 1.726404681801796, 3.2962888138634816, 4.680726068360465, 4.661043558801923, 4.246864480631692, 8.25776205744062, 6.107077896595001, 4.0189783317702155, 4.086457933698382, 4.348993446145739, 2.217676954610007, 1.720519231898444, 1.7079310502324785, 1.567999433193888, 3.997761138847896, 9.624319859913417, 17.219527755464824, 25.9899765423366, 36.03065504346575, 46.167663369859966, 50.95478112357003, 52.90406697137015, 51.79190008980887, 52.12019899913243, 53.17390373774937, 51.72999164036342, 51.83013950075422, 51.68993527548653, 53.298411982400076, 52.20549855913435, 53.62706872395107, 48.12966094698225, 54.680877685546875, 51.77222973959786, 51.26355559485299, 54.189355169023784, 54.635075160435264, 51.06408323560442, 52.146556990487234, 50.402270793914795, 52.15931040900094, 51.36082690102713, 51.559097221919465, 50.60815634046282, 49.0249467577253, 47.200217791966026, 42.324100562504356, 31.14003692354475, 22.35072030339922, 14.156501259122576, 6.725595678601946, 2.4781280074800764, 3.0481879668576375, 0.6161203277962548, 1.7805630671126502, 2.4815517323357716, 3.6826451335634505, 3.303333852972303, 3.2358965916293005, 4.492961423737662, 3.443281646285738, 4.160646021366119, 4.925098989691053, 5.100682573659079, 2.8723412198679785, 0.5755779689976147, 0.3780192413500377, 0.6560542306729725, 4.409310323851449, 14.54271079812731, 18.643712180001394, 14.075371486800057, 25.670613016401017, 22.74201852934701, 26.082203456333705, 26.614729029791697, 14.905348573412214, 5.035607482705798, 0.6793570231114114, 0.04001341700287802, 0.024979493181620325, 0.02033645616445158, 0.02790221492094653, 0.028090272597702484, 0.06332692690193653, 0.08433917510722365, 0.0140351050067693, 0.010559025237203708, 0.01467220189182886, 0.051055675372481346, 0.08314418672983136, 0.016959619774882282, 0.09647003095597029, 0.03912162860589368, 0.06459567882120609, 0.0351074798963964, 0.0624250452965498, 0.047904867479311566, 0.019423399087307707, 0.023816604599622742, 0.035097335797867606, 0.006191235102180923, 0.0824232975553189, 0.05868901112782104, 0.041963709850928614, 0.08861558777945382, 0.0905773342986192, 0.01708189008890518, 0.019610342270295535, 0.012215302924492528, 0.029023544929389442, 0.02057731065100857, 0.009598764175150012, 0.03846828419981258, 0.032686436415783, 0.039781279994973114, 0.1207487942384822, 0.25734759654317585, 0.12112448550760746, 0.2100366609437125, 0.1818308423140219, 0.14958402195147105, 0.15511017399174826, 0.08629428555390664, 0.1306601281144789, 0.06362552980759315, 0.20325177216104098, 0.08201439878238098, 0.15412894450128078, 0.11761985213628837, 0.1299108218933855, 0.13866036811045238, 0.14808274965201104, 0.1722076279776437, 0.10128047782927752, 0.11387607588299684, 0.14941026270389557, 0.17841905967465468, 0.12498676111655575, 0.06554173984165702, 0.18253733297543867, 0.09909942879208497, 0.14481412433087826, 0.29512837209871834, 0.14222495683601924, 0.17284972566579068, 0.0926776851660439, 0.20682894092585358, 0.14991369497563156, 0.06863974753235068, 0.12339643788124834, 0.12858944279806955, 0.08698442352137395, 0.10543018765747547, 0.17628874470080647, 0.20689512523157255, 0.11697130836546421, 0.20238288092826093, 0.15233299801392214, 0.5115954279899597, 3.142952493258885, 14.108563031469073, 30.324127333504812, 40.679448059626985, 37.231366293770925, 32.9721622467041, 28.671970776149205, 34.887450558798655, 36.888382366725374, 27.366343464170182, 19.918902908052715, 10.42552011353629, 3.380566771541323, 0.8060768033776964, 1.3640026024409702, 2.3536770854677473, 6.009595973151071, 11.905216302190508, 14.676844903400966, 9.558088762419564, 9.792389835630145, 8.096292001860482, 6.244182791028704, 5.719763159751892, 5.7703859976359775, 6.54259489263807, 3.0844475754669736, 2.5403432633195604, 2.8865665708269392, 1.9111259068761552, 3.011199883052281, 9.400130152702332, 17.597172771181377, 23.915513685771398, 34.65090608596802, 46.02052484239851, 50.7791028703962, 54.32145779473441, 52.01788330078125, 51.616927078792024, 53.112012658800396, 51.92419726508004, 52.469884463718955, 50.97319732393537, 54.078743321555, 51.81239380155291, 54.79095799582345, 48.71584572110857, 57.9261589050293, 51.63369655609131, 50.41617413929531, 56.25530127116612, 55.44202504839216, 52.111777782440186, 52.78314052309309, 51.23785768236433, 52.0699531010219, 51.81159128461565, 51.73244088036673, 51.84053747994559, 48.88708060128348, 48.20872449874878, 41.91017552784511, 28.905008145741053, 21.026774065835134, 13.29091031210763, 6.579878926277161, 3.3208841340882436, 3.5692346819809506, 0.8888162236128534, 1.396635251385825, 2.5761343027864183, 6.151044360228947, 5.992331436702183, 5.74473020860127, 7.25493289743151, 7.368290151868548, 7.675363183021545, 7.746294736862183, 9.058473331587654, 8.441240532057625, 4.918780471597399, 1.8686804473400116, 1.1768078186682291, 7.344958101000104, 16.90028234890529, 21.098409993307932, 23.284083979470388, 31.534416675567627, 28.134216683251516, 32.58598484311785, 31.367941311427526, 16.47357783998762, 4.957791566848755, 0.7906496854765075, 0.15534276222544058, 0.20287802150206907, 0.1023859538670097, 0.09566891180085284, 0.06309865415096283, 0.1827552377113274, 0.13851897498326643, 0.15558285505643912, 0.1580504019345556, 0.1426145445023264, 0.18710356152483396, 0.22971520785774502, 0.13621137237974576, 0.21083647731159413, 0.11714202777615615, 0.19339929441256182, 0.1708732210099697, 0.19099802683506692, 0.2231641693839005, 0.20751542837492057, 0.11213500252259628, 0.1052459721852626, 0.11387188253658158, 0.1800583324262074, 0.20829525510115282, 0.14812724797853402, 0.12031322903931141, 0.2731216086872986, 0.139608892213021, 0.07878828368016652, 0.06778505125216075, 0.1324675961264542, 0.06711754242756537, 0.12123121906604085, 0.06137130755398955, 0.2028205767273903, 0.19502456220132963], [0.028552780726126263, 0.05441541776859334, 0.03598778408819011, 0.06265584898314305, 0.026949246414005756, 0.03926627870116915, 0.06362280888216836, 0.03762371166210089, 0.03912998476464834, 0.028545533972127096, 0.024176816788635085, 0.10303725249000958, 0.030141214241406748, 0.024770171913717474, 0.024313232861459255, 0.039745419419237545, 0.03474840934255293, 0.004745003443011748, 0.03296244071264352, 0.04120937568534698, 0.09304110852203198, 0.09535570003624473, 0.04185484569253666, 0.0415234865088548, 0.03831817529031208, 0.06646119550402675, 0.05345474449651582, 0.022918359941935966, 0.07681613521916525, 0.0531848130880722, 0.07294323375182492, 0.03497995263231652, 0.017806241488350288, 0.00517502670741773, 0.055227539369038174, 0.014657740614243915, 0.008537811060835208, 0.005011188489983657, 0.002065789050123255, 0.04912901250645518, 0.012062453581685466, 0.008265053554038917, 0.03079731689233865, 0.008277016974586462, 0.16105689560728415, 1.2761395914213998, 8.87538308756692, 18.692387785230363, 29.807862281799316, 31.920993600572857, 23.750712837491715, 11.847673058509827, 9.043649349893842, 12.610691223825727, 14.995951345988683, 14.291096551077706, 9.41949999332428, 2.9195359902722493, 1.026540213397571, 0.35700094061238424, 0.9838673089231763, 1.215605473944119, 2.765889823436737, 3.461907595396042, 2.149371168443135, 9.640072294643947, 4.962569321904864, 3.7099567651748657, 3.464745283126831, 4.8117000460624695, 3.4992912922586714, 0.9653240868023464, 1.1575303673744202, 1.48556307383946, 1.3125117825610297, 1.4288032395499093, 4.399288850171225, 11.851490225110735, 21.107286317007883, 29.704674584524973, 39.416699818202424, 47.469762734004426, 53.13854782921927, 54.4627320425851, 54.844139507838655, 53.582343169621055, 53.39956733158657, 51.37502554484776, 54.04496465410505, 48.322522095271516, 46.84661701747349, 43.401443072727744, 53.2051671573094, 54.442373820713584, 48.15564373561314, 53.309087889535085, 46.62885005133492, 51.940879889896934, 51.34105927603585, 52.597064290727886, 51.43305689947945, 51.908647196633474, 47.301199436187744, 54.5013918195452, 47.43441029957363, 34.536879198891775, 26.27405537877764, 17.344334772654943, 7.634171656199864, 3.372623243502208, 1.5947295874357224, 1.3537207884447915, 1.4990180432796478, 0.7837235799857548, 2.0535998046398163, 3.381827869585582, 1.6410945909363883, 3.3030702556882585, 2.1913897480283464, 4.0104963183403015, 1.454602986574173, 1.5518780925444193, 2.4825607410499027, 1.9278384957994734, 1.8852938073022025, 0.2334464719252927, 2.3394940750939504, 6.456386855670384, 12.530765226909093, 14.515490361622401, 15.205703565052577, 21.150985274996074, 23.34454894065857, 26.9994056224823, 21.082236324037822, 8.787654263632637, 3.2828544718878607, 0.2947087931845869, 0.02730773003505809, 0.009240970115310379, 0.05695111331130777, 0.052769288420677185, 0.017849850933998823, 0.03580534298505102, 0.053659824920552116, 0.013037555900934552, 0.02420628217181989, 0.01309623900202236, 0.023656125978699753, 0.013049008723880564, 0.04127156002713101, 0.007941081072203815, 0.0405135482017483, 0.00892495854558157, 0.009737663686142435, 0.08469425248248236, 0.03268361031743033, 0.09804512786545924, 0.04148802287610514, 0.052229870044227154, 0.012567786599642463, 0.061372142152062485, 0.05207589687779546, 0.03297182485195143, 0.0934406638677631, 0.0841373787926776, 0.00952632462472788, 0.03693936499101775, 0.028094750928825567, 0.01861439026626093, 0.031403669355703254, 0.06209764536470175, 0.01823705354971545, 0.04286358638533524, 0.05775328419570412, 0.06333761382848024, 0.014551580417901278, 0.050237406244767566, 0.023730113437133174, 0.016223494096526077, 0.03265916948605861, 0.02281378921387451, 0.10435734915414027, 0.08093283431870596, 0.03408271220645734, 0.025081957058448876, 0.04295048975784864, 0.01972168986685574, 0.017340213459517275, 0.010875446472450026, 0.04054925949977977, 0.06894073209592275, 0.044043548604739566, 0.05333018921581762, 0.01780616515316069, 0.05353165304820452, 0.047334884492946525, 0.03965469589456916, 0.009861783856259925, 0.09039888637406485, 0.02264114106739206, 0.05806172585913113, 0.07531314622610807, 0.04596803676603096, 0.029418058759932007, 0.036987924349627326, 0.046717309060373476, 0.05805338666375194, 0.026339540291311483, 0.025542921519705226, 0.08341113597686801, 0.01999115987148668, 0.03470070154539176, 0.018105811306408474, 0.02280469684462462, 0.04547176982409187, 0.0721001336351037, 0.018891729580770646, 0.027603808790445328, 0.023038489477975026, 0.3696739934384823, 2.7237503017698015, 12.07255324295589, 24.72197198867798, 36.11137226649693, 36.02328300476074, 27.75009594644819, 18.436562061309814, 16.51983720915658, 17.727255208151682, 22.782642909458705, 19.886800493512833, 10.819951108523778, 4.105416962078639, 0.3734827733465603, 0.2135062547666686, 0.5661417182002748, 1.6003678334610802, 3.895430241312299, 3.8306378551891873, 7.37303056035723, 15.320972442626953, 7.747563651629856, 4.57430876152856, 5.327090493270329, 6.826418382780893, 3.3665020976747786, 3.0386839168412343, 3.089695853846414, 1.9635674357414246, 1.2798893387828554, 2.4274430700710843, 5.480377307959965, 12.785425390516009, 22.040319953645977, 32.877315861838206, 42.40757622037615, 49.26980127607073, 53.78013406481062, 54.39772817066738, 56.92047316687447, 56.243808950696675, 54.86490419932774, 52.83142008100237, 55.0630008152553, 51.850654057094026, 48.553924901144846, 42.61006409781319, 53.46651322501046, 55.90355913979666, 50.62005165645054, 55.05688292639596, 51.21640511921474, 50.933648177555625, 51.72507578986031, 52.40441853659493, 52.111631870269775, 52.754194327763145, 50.04497010367257, 53.92748103822981, 47.60757677895682, 39.081282479422434, 30.204732963017054, 20.575849873679026, 10.93446089540209, 5.102884718350001, 3.0940723504338945, 2.0635383341993605, 1.5642860553094318, 1.7463440575769968, 1.9102146072047097, 3.802537168775286, 4.498795304979597, 3.590076672179358, 4.436080430235181, 5.159661054611206, 4.046958727496011, 3.9241614767483304, 2.7956984639167786, 1.9525667003222873, 0.27321443227784975, 0.3259683586657047, 1.3719715348311832, 5.857408710888453, 15.042528595243182, 22.10365104675293, 20.26190594264439, 21.828354733330862, 27.385296412876674, 29.475349290030344, 26.67894775526864, 14.040704318455287, 5.533666517053332, 0.7707278973289898, 0.02755883548940931, 0.004954904434271157, 0.045900590385177305, 0.06610816730452435, 0.057459295328174315, 0.013952429755590856, 0.03121129789256624, 0.027330734068527818, 0.043786166701465845, 0.08124532005084412, 0.00397988226697115, 0.03794007861454572, 0.04948318064478891, 0.04580685755770121, 0.04878401476889849, 0.043959196523896286, 0.04728021492649402, 0.047646362600581985, 0.048158205313874144, 0.0933437215696488, 0.04571429181045719, 0.019564030558935235, 0.024490074354356954, 0.04423727374523878, 0.0070097111830753935, 0.04925187823495694, 0.021382592618465424, 0.05633820280698793, 0.032053607515990734, 0.0038354467583953267, 0.0350960330106318, 0.011372811792950546, 0.026668258277433257, 0.023785352973001342, 0.03750192141160369, 0.07107066030481032, 0.07387391916875329, 0.0345211068966559, 0.1203690046178443, 0.15101742717836583, 0.1334774869361094, 0.11378517933189869, 0.1547624519360917, 0.10958269304995026, 0.1718026782785143, 0.17287317583603518, 0.20722422828631742, 0.14802124723792076, 0.11776841059327126, 0.15107082788433346, 0.08125017157622746, 0.0786253809928894, 0.094774412656469, 0.13632271997630596, 0.18247744547469275, 0.12437427469662257, 0.15320995024272374, 0.11623074167541095, 0.18484979388969286, 0.20541815805648053, 0.06834626756608486, 0.24260620613183292, 0.19820548008595193, 0.13828129773693426, 0.22167406577084744, 0.15280471555888653, 0.11925548794014112, 0.12266433930822782, 0.18464317997651442, 0.08933583913104874, 0.04206443837444697, 0.11302382232887404, 0.15553414981280053, 0.20926486807210104, 0.19037574236946447, 0.13497797213494778, 0.15395441172378405, 0.1831614901976926, 0.23575126539383615, 0.07865085998283965, 0.15191526471504144, 0.09848563279956579, 0.31384866471801487, 2.350899760212217, 13.413231611251831, 27.27231001853943, 41.56767102650234, 43.81718853541783, 34.95053325380598, 22.091656718935283, 18.94306663104466, 19.350960629326956, 22.95056176185608, 20.565596069608414, 12.6939697265625, 3.9635382209505354, 1.4701381815331322, 1.1135467503752028, 2.916526334626334, 5.996803905282702, 8.897900462150574, 10.809343814849854, 4.656717436654227, 16.736131157193864, 10.717986294201442, 8.640166589191981, 8.004508904048375, 10.504893728664943, 9.725560324532644, 4.529493314879281, 5.136254744870322, 3.3224031840051924, 2.7666534738881245, 2.3380115032196045, 5.4779298050062994, 14.469344769205366, 23.300005776541575, 32.184424127851216, 41.07629789624895, 50.053561551230295, 54.28625127247402, 55.15664168766567, 55.91523906162807, 53.94043942860195, 54.84307990755354, 52.65363652365548, 53.91227837971279, 52.269474097660606, 50.050292423793245, 43.1580685206822, 54.97022499356951, 57.93601145063128, 52.688526902879985, 56.46212829862322, 52.26843534197126, 51.52676030567714, 51.56631987435477, 52.32879434313093, 50.67468534197126, 52.735166685921804, 50.16547966003418, 55.74456351143973, 49.40721927370344, 37.566724572862896, 27.95696813719613, 18.993826695850917, 10.178999764578682, 5.468307418482644, 3.3189484093870436, 2.5304032138415744, 2.8468074585710252, 2.618246248790196, 3.2043100808347975, 7.086370468139648, 5.157050703253065, 8.472246868269783, 6.9208991186959405, 9.370945981570653, 6.869767759527479, 8.52724620274135, 6.671092706067221, 6.184656270912715, 3.879120647907257, 1.377618357539177, 3.3755538633891513, 8.254205448286873, 16.830044746398926, 20.404029607772827, 23.296658481870377, 28.611101082393102, 33.900893211364746, 38.07378673553467, 31.27018015725272, 15.339852435248238, 5.617208182811737, 0.6780016901237624, 0.14485615278993333, 0.12030500519488539, 0.1513652035168239, 0.15147090570202895, 0.0968495084504996, 0.12235000117548875, 0.118191748591406, 0.14711562011923107, 0.15945999058229582, 0.19466454509113515, 0.17226011944668634, 0.12623909248837403, 0.14623182825744152, 0.11759912967681885, 0.13052157126367092, 0.12059076343263898, 0.11161565181932279, 0.16509054202054227, 0.1552477537521294, 0.2533440499433449, 0.10576131953192608, 0.11721159118626799, 0.19267395404832705, 0.13887102609234198, 0.09992783862565245, 0.08950357977300882, 0.1782209003078086, 0.145681658493621, 0.1096695251762867, 0.12412559161228792, 0.1344564908317157, 0.07960549090057611, 0.10374173468777112, 0.1744241847523621, 0.07764830413673605, 0.1922628568219287, 0.11899031645485333, 0.14367835170456342], [0.03730191303683179, 0.04609678878581949, 0.054921279195696115, 0.06882817670702934, 0.018121458323938505, 0.04928800683202488, 0.04654212149658373, 0.0304397967910128, 0.08391312975436449, 0.006880801827979407, 0.03317462539832507, 0.03227738497246589, 0.013459567363107843, 0.025957623463390127, 0.07116714119911194, 0.049804565363696644, 0.05346378258296421, 0.018009500045861517, 0.06830665469169617, 0.04462220326864293, 0.06892904093755142, 0.019782791945285032, 0.02362399056021656, 0.05568178463727236, 0.02060661148945136, 0.02383318460280342, 0.04901406528162105, 0.1239794623106718, 0.08042546654386179, 0.050946383737027645, 0.02356588251755706, 0.05238801280834845, 0.06861937112574067, 0.07996794395148754, 0.05419079553601997, 0.015070176250966532, 0.04715768846550158, 0.03962237048628075, 0.036070260019706826, 0.05138740775042346, 0.0751778870554907, 0.05689600608976824, 0.039960538768874745, 0.044522027751164775, 0.039121313087110005, 0.15958934649825096, 0.9477677260126386, 7.175289605345045, 17.28514654295785, 27.313917568751744, 31.9910557610648, 20.929377692086355, 16.549568550927297, 22.653828518731252, 13.312164851597377, 13.756562948226929, 18.639531101499283, 9.893211671284266, 5.32548372234617, 1.2200595949377333, 0.29394012157406124, 1.0579254435641425, 2.5848957640784125, 2.3727416396141052, 11.618980918611799, 16.904710088457378, 9.013158917427063, 2.0705662199429105, 4.897620601313455, 3.6077485467706407, 1.3162268974951334, 2.2535461613110135, 1.4718389702694756, 1.4121816286018916, 0.8497301095298359, 1.2059757049594606, 0.6643461457320622, 2.541107565164566, 6.387609243392944, 11.875154052461896, 22.62107297352382, 32.22196524483817, 41.89263480050223, 48.885656220572336, 49.994922229221885, 51.5491612979344, 53.21153865541731, 53.183829239436555, 51.80777324948992, 44.82253033774239, 36.23634256635393, 34.54220846721104, 47.21170663833618, 53.09086929048811, 45.75796978814261, 44.15140730994088, 52.33421393803188, 56.587192399161204, 50.96266385487148, 53.30481822150094, 53.61568757465908, 54.953323500497, 47.43410457883562, 35.31984390531267, 32.41473259244646, 21.123724017824443, 11.8078807251794, 6.334411229406085, 2.157220244407654, 0.8033659202711922, 0.5890148079821041, 0.7191417568496296, 1.281194840158735, 1.452157437801361, 2.4225623948233466, 3.097776825938906, 4.857790921415601, 2.494368987424033, 2.000650623014995, 4.2445177265575955, 3.4983739129134586, 2.412133800131934, 4.160878351756504, 3.0922415001051764, 0.9226800607783454, 1.566121248262269, 5.7607844557080945, 11.17385412965502, 14.917335953031268, 18.926555974142893, 14.168037005833217, 18.06948004450117, 27.16539634977068, 23.695604937417166, 14.00718447140285, 2.574187287262508, 0.5353876341666494, 0.02139330668640988, 0.043991630497787676, 0.026606297852205377, 0.04346543676885111, 0.02339874068275094, 0.04692201968282461, 0.050222590432635376, 0.04113041456522686, 0.0155357259126114, 0.05872187936412437, 0.023758925730362535, 0.05062187097168394, 0.022275880577840974, 0.08244375538613115, 0.00895013558744852, 0.020354411897382567, 0.01112486407094236, 0.02389416454492935, 0.04480482757623706, 0.033044696120279174, 0.04128592800615089, 0.004642928875650146, 0.005341665154056889, 0.03384230724935021, 0.04520877982888903, 0.028648084362170527, 0.02446056147372084, 0.14749676680990628, 0.05469593093065279, 0.03315607085824013, 0.02856084850749799, 0.05445892204131399, 0.008004009258002043, 0.05668379087001085, 0.05894756689667702, 0.04045937057318432, 0.05858513420181615, 0.037532048366431675, 0.0635319733992219, 0.08438353772674288, 0.05765241317983184, 0.043920520027833324, 0.037864581415695805, 0.03250134563339608, 0.03394204850441643, 0.025435066682153513, 0.026900917757302523, 0.025600364598046457, 0.09550896074090685, 0.059383471363357136, 0.017468867091728107, 0.04154470429888793, 0.036827518671218834, 0.06696293822356633, 0.02346233298469867, 0.014846605747672064, 0.012352832642916058, 0.036473255537982495, 0.0448641485002424, 0.031400412387613735, 0.027896031770589094, 0.005846129223105631, 0.05403818283230066, 0.053139079827815294, 0.0266506672570748, 0.010637049130829317, 0.12593373815928185, 0.07888215899999652, 0.055087944359651635, 0.034651735065771, 0.014311065198853612, 0.0832391952031425, 0.012501629435324242, 0.03301922730835421, 0.036493292677083185, 0.04260931556512203, 0.005223463505639562, 0.07219869084656239, 0.07916353390152965, 0.033385178207286766, 0.06928397582045623, 0.016239577072805593, 0.03922738168122513, 0.06612289829977921, 0.15603773136224064, 2.673407997403826, 10.958453893661499, 23.005766936710902, 33.545742988586426, 35.84180300576346, 23.173506872994558, 15.640005929129464, 16.436299017497472, 17.029332978384836, 19.22296612603324, 22.004767758505686, 9.479962348937988, 5.94797283411026, 1.1759623097521918, 0.3795693681708404, 0.2539556271263531, 0.964338093996048, 3.1204689911433627, 10.489057047026497, 9.197984474045889, 6.377097921712058, 7.669752512659345, 5.667055428028107, 4.327176536832537, 2.972922908408301, 3.8512514233589172, 3.5087753662041257, 3.1951988211699893, 1.960319152900151, 1.2281445839575358, 1.3052548233951842, 4.260300125394549, 8.654827288218907, 14.468823654311043, 24.56490101133074, 35.59534692764282, 43.65862716947283, 49.123211656297954, 52.61775255203247, 54.70346280506679, 55.506959438323975, 54.536858899252756, 53.635073048727854, 48.75841038567679, 40.732591356549946, 36.77793380192348, 50.41222756249564, 56.610215255192344, 48.72554888044085, 47.68273196901594, 53.29351350239345, 54.212002822331016, 50.88056741441999, 53.73230961390904, 53.015755789620535, 54.576595646994456, 48.53321926934378, 41.41826391220093, 37.00368077414376, 23.460232973098755, 14.75078763280596, 8.701802321842738, 4.005756344114031, 1.5734246735061919, 1.4491864315101077, 1.9287582635879517, 1.7357852927276065, 1.1974592762334006, 2.7690136900969913, 5.108213118144444, 7.893699901444571, 4.038682120186942, 3.399825006723404, 4.611874197210584, 3.27942727293287, 1.8581949642726352, 1.304259711078235, 0.7851381355098316, 0.3880439448569502, 1.2858629439558302, 5.969568703855787, 14.618862186159406, 18.169176271983556, 16.473020247050695, 13.53145694732666, 20.707433121544973, 30.761512960706437, 29.527974946158274, 17.307757718222483, 3.978570214339665, 0.9415556022099086, 0.18426317322467053, 0.01087145329386528, 0.08105314536286251, 0.03021337304796491, 0.04306781864059823, 0.03483730082267097, 0.033832251360373836, 0.03699730848893523, 0.011284201056696475, 0.013814210475954627, 0.026143830435882722, 0.030998638232371638, 0.020520152557375174, 0.04721737579841699, 0.028677481891853467, 0.029309706895479133, 0.07004109197961432, 0.04977516444133861, 0.011160967222947096, 0.09748729744127818, 0.059403555999909124, 0.0490303026246173, 0.019287746366379515, 0.014169808626840157, 0.018716004277978624, 0.049802003894001245, 0.02769331943376788, 0.13140262184398516, 0.05390426376834512, 0.02157100143709353, 0.03129217926678913, 0.020670344587415457, 0.013250549739625837, 0.09132921895278351, 0.02395970593871815, 0.07792505142944199, 0.04974838266415255, 0.05268915343497481, 0.01737331918307713, 0.12652950547635555, 0.1785278966916459, 0.18738984901990208, 0.1383397060313395, 0.10193489092801299, 0.13889147713780403, 0.16904526124043123, 0.13801212289503642, 0.2228505097861801, 0.19021745372031415, 0.07526393886655569, 0.15436101704835892, 0.06907767403338637, 0.10129746156079428, 0.16883967870048114, 0.11343329107122761, 0.20907886805278914, 0.15701784805527755, 0.11825238248067242, 0.08213985990732908, 0.11655548853533608, 0.05211998808330723, 0.1130870007244604, 0.15212770045867988, 0.19152648347829068, 0.10882263204881124, 0.19874919019639492, 0.3182147932904107, 0.2592323496937752, 0.10884075571915933, 0.11266968133194105, 0.12991087617618696, 0.13933806174567767, 0.118797897494265, 0.14432213215955667, 0.11341842436896903, 0.13809133507311344, 0.14323613686220987, 0.20951526106468268, 0.1760670401688133, 0.15670136575187954, 0.2485250128167016, 0.0976394046364086, 0.112998241558671, 0.1260962744376489, 0.3685952313244343, 2.163610415799277, 10.917685338429042, 25.60669653756278, 38.824584756578716, 43.03028072629656, 32.570160320826936, 25.043994937624248, 30.914373329707555, 21.295193399701798, 23.132019179207937, 25.946492978504725, 13.736984661647252, 7.120087470327105, 1.9142261062349593, 0.63931819157941, 2.9252285190990994, 5.846287684781211, 5.840623165879931, 19.022918803351267, 29.811593464442662, 18.673711027417863, 7.6197150605065485, 8.996199233191353, 7.2948876449040005, 4.80176933322634, 7.069178453513554, 5.488487592765263, 3.620598805802209, 2.364166259765625, 2.605802676507405, 1.2559267388922828, 3.369939936058862, 7.316465275628226, 13.023877143859863, 23.44790686879839, 33.939976828438894, 43.113068512507844, 50.62794828414917, 51.65138666970389, 53.963253838675364, 53.88900886263166, 54.63955327442714, 53.966255460466655, 51.41087130137852, 41.57388966424124, 40.51769399642944, 51.85142878123692, 56.80368089675903, 52.921496527535574, 49.77638053894043, 54.46394450323922, 55.71785116195679, 51.88213634490967, 52.86276340484619, 53.03269897188459, 55.0505496433803, 48.95453371320452, 40.02884653636387, 35.41176162447248, 23.49715222631182, 13.984072157314845, 7.459754501070295, 3.553284440721784, 2.1247658601828983, 1.4876761947359358, 1.9345547982624598, 2.723343615021024, 3.037064335175923, 6.694674892084939, 8.524465186255318, 12.291365912982396, 7.241246248994555, 7.932640211922782, 11.277917299951826, 8.033517633165632, 7.4729916879108975, 7.798125692776271, 4.910166442394257, 1.5719948645148958, 1.9701953658035822, 7.673857160976954, 15.764250142233712, 20.956988096237183, 25.27734671320234, 19.454712867736816, 27.11915261404855, 36.18353625706264, 33.60707473754883, 20.340061017445155, 4.731150014059884, 0.833443423467023, 0.30036432828222004, 0.14757534116506577, 0.25750748653497013, 0.12021071596869401, 0.12350854543702942, 0.12558704747685365, 0.09726334017302309, 0.15384518115648202, 0.09533108278576817, 0.10070081893354654, 0.1111300785892776, 0.14874352062387125, 0.09088933827089411, 0.17089720043752873, 0.10997350886464119, 0.10090226919523307, 0.23209119322044508, 0.17558378752853188, 0.1329546757042408, 0.21729230375162192, 0.16198602717901978, 0.09716151242277452, 0.08489503777985062, 0.11751946966562953, 0.2098933814891747, 0.16286220587790012, 0.23564112558960915, 0.1954854910394975, 0.210326273260372, 0.10559619803513799, 0.14645122577037128, 0.18243522702583245, 0.1560630135770355, 0.2684077173471451, 0.16368476673960686, 0.13845619692334107, 0.1288335525563785, 0.10329211024301392, 0.15798877738416195], [0.053296693334622045, 0.07049861457198858, 0.01182703924964049, 0.051995371734457355, 0.009921697650237806, 0.01597990681018148, 0.06932607213301317, 0.04329107701778412, 0.03179615775921515, 0.05016930168494582, 0.009693145851737686, 0.01898113335482776, 0.038696411065757275, 0.10319259629717895, 0.027509880884151374, 0.017071606890697564, 0.02450151615110891, 0.10441985580005816, 0.017720817322177545, 0.007453043063703392, 0.04091940713780267, 0.007792024740150997, 0.07889070175588131, 0.06923194575522627, 0.04188973596319556, 0.017921258263023834, 0.054058162295924764, 0.05450202597837363, 0.033782341717077155, 0.012523397686891258, 0.06174025418502944, 0.01307336813105004, 0.024161619300554906, 0.016011684301442335, 0.026555853862581507, 0.07672006144587483, 0.059467460427965434, 0.01961472221384091, 0.07459583971649408, 0.022309446008875966, 0.032984689875905, 0.042045666703156064, 0.03666230557220323, 0.04474932001903653, 0.0664419454655477, 0.07582940959504672, 0.04759328419874821, 0.8642423993774823, 3.3766888082027435, 14.331069537571498, 25.46037789753505, 33.236794812338694, 27.205343280519756, 17.98529393332345, 22.599919182913645, 23.572651352201188, 17.78171866280692, 21.681973559515818, 12.344785400799342, 7.486824682780674, 2.4296198104109084, 0.3546703356717314, 0.7642667240330151, 3.029576131275722, 13.024369597434998, 9.461107543536595, 4.910506904125214, 7.27718016079494, 4.8119653803961615, 5.1203116689409525, 2.0440588423183987, 3.3121469914913177, 2.400871855872018, 3.30829964365278, 1.868717359645026, 0.966775500348636, 0.8250824064016342, 0.29285853675433565, 1.356722735932895, 3.609324267932347, 8.029112475258962, 14.516918216432844, 22.907929352351598, 31.24819953101022, 37.62819528579712, 42.475984709603445, 43.74793584006173, 47.27173212596348, 49.16027682168143, 45.07933923176357, 30.849810668400355, 24.99554341179984, 35.02239152363369, 47.68174532481602, 47.135165282658164, 54.506550856998985, 52.57001147951399, 52.31223331178938, 53.92447941643851, 54.51033067703247, 50.28814663205828, 46.8253937448774, 39.017372948782786, 27.80039743014744, 15.616557495934622, 8.222697973251343, 3.4481021761894226, 1.2027364330632346, 0.6389795211809022, 0.3642610753221171, 1.0609272824866431, 1.8962888973099845, 1.6403732810701643, 1.475450296487127, 1.1794294608490807, 3.441667058638164, 6.093626618385315, 2.6494584253856113, 3.4649862987654547, 3.0347112842968533, 2.991384272064481, 1.4350472816399165, 0.44941453316381996, 0.6873811068279403, 1.6606202231986182, 6.939262773309435, 13.218894839286804, 23.150046280452184, 18.31088478224618, 24.580491031919205, 20.795852422714233, 26.01817580631801, 24.8144177709307, 15.81570155279977, 5.162037772791726, 0.8854272397501128, 0.010087963326701095, 0.029948768139417683, 0.061458363596882136, 0.009516311144190175, 0.07615818016763244, 0.009842911252884992, 0.06919907751892294, 0.10523842009050505, 0.02260161131354315, 0.04784508175881846, 0.024525651641722237, 0.036706088044281514, 0.04623421587582145, 0.04934877982097013, 0.031103509212178842, 0.05498023031811629, 0.041128399316221476, 0.04776656168646046, 0.06768158144716706, 0.04419491619669965, 0.024784840144483105, 0.03551937100876655, 0.014159471993999822, 0.022810192978275672, 0.04908592553277101, 0.04493734885805419, 0.030816797632724047, 0.02003616201026099, 0.06289835061345782, 0.04767905441778047, 0.06639357948941843, 0.03484286820249898, 0.052607050697718344, 0.04210375947877765, 0.09419082504298006, 0.01745217852294445, 0.04719306728137391, 0.007725566475918251, 0.06568877838019814, 0.014295696380681224, 0.03872095028470669, 0.050436451099812984, 0.03539218640487109, 0.08441346112106528, 0.021582582333524312, 0.024722313142514656, 0.04230165760964155, 0.07875787852598087, 0.06364274424101625, 0.06267698534897395, 0.03349535872361489, 0.01148306270728686, 0.018978461623191833, 0.034709003421344926, 0.023095520346292427, 0.02129604378049927, 0.021559227158182433, 0.048395193847162385, 0.030644632942442383, 0.014987581575821553, 0.026729000732302666, 0.047233019423271926, 0.07036154371287141, 0.06049784978053399, 0.010341784617464458, 0.019579112696062242, 0.042720917612314224, 0.058226270601153374, 0.03917372313195041, 0.027769612214927162, 0.08036559261381626, 0.03827450816918697, 0.02191714250615665, 0.028391221538186073, 0.035825414050902636, 0.04058864845761231, 0.04424795388643231, 0.05865277735782521, 0.030658122218613113, 0.06438117354576077, 0.040726279108119864, 0.022965770880026475, 0.04031982645392418, 0.04702931981799858, 0.0710334155176367, 0.07999336187328611, 0.1227305643260479, 1.8606205369744981, 6.964709682124002, 20.01867035457066, 31.962859971182688, 38.79342903409685, 31.238333089011057, 21.150875840868267, 17.545285361153738, 24.68986436298915, 25.45343143599374, 24.137070894241333, 14.298500725201198, 6.919989773205348, 1.8736627399921417, 0.4126707762479782, 0.2770292918596949, 0.4507952162197658, 2.2071741010461534, 2.9413919832025255, 5.073146862643106, 5.451210073062351, 5.293365240097046, 6.306921984468188, 4.246602186134883, 4.572001091071537, 4.234100205557687, 4.787590231214251, 2.06541109085083, 1.9522116908005305, 1.2000827640295029, 0.8440130448767117, 1.6237298484359468, 4.631933646542685, 9.816462738173348, 16.892476047788346, 26.009056295667374, 34.76681593486241, 41.23703057425362, 45.41762965066092, 46.8718980380467, 50.90188796179635, 51.792487212589805, 50.03002452850342, 33.83483668736049, 29.209806510380336, 40.32878637313843, 51.632484095437185, 51.619011538369314, 55.645662852696006, 52.09939956665039, 52.51208087376186, 53.424330711364746, 54.46321494238717, 53.30384199959891, 49.108592646462576, 41.12313917704991, 30.540167672293528, 19.327560833522252, 11.021030238696508, 4.845728848661695, 2.6086974697453633, 1.1083438524178095, 1.1525856384209223, 1.1993040229593004, 3.3006878920963834, 2.014009186199733, 2.4457841430391585, 3.7097895741462708, 5.32038938999176, 5.28752875328064, 4.481619792325156, 4.068999716213771, 3.6523045216287886, 1.903619898217065, 0.6809417009353638, 0.370913025523935, 0.5863873032586915, 1.7655920875923974, 6.360671511718205, 15.344175951821462, 21.51431005341666, 21.193164314542496, 22.61263264928545, 17.005855015345983, 27.054787976401194, 29.78384930746896, 19.464287485395158, 7.935848542622157, 1.3335935941764285, 0.0819993285196168, 0.0428281634646867, 0.04193773892308984, 0.02435028087347746, 0.024381286531154598, 0.005953654547088912, 0.02930994438273566, 0.06867586595139333, 0.041248367700193606, 0.031146121211349964, 0.017058212609429444, 0.04787343095189758, 0.046176455582359006, 0.03457079601607152, 0.032545877886669974, 0.02952585761834468, 0.060565933984305174, 0.03528970726100462, 0.07492297501968485, 0.031559667949165614, 0.026393568642171364, 0.011491557965720338, 0.02880020173532622, 0.07769721972623042, 0.05538394847618682, 0.02787265963187175, 0.02539244280861957, 0.026252387557178736, 0.09605106950870582, 0.05813580831246717, 0.0508596058934927, 0.013702162291987665, 0.05846592238438981, 0.0427129448258451, 0.029389058173234974, 0.025835266636152352, 0.03388905831213508, 0.01987980379323874, 0.038939852467072864, 0.03908136773056217, 0.11241194659045764, 0.13360724997307571, 0.09536792723728077, 0.12372436028506074, 0.075768728208329, 0.10540447796561889, 0.13966290360050543, 0.1329487045960767, 0.14779186168951647, 0.11963503328817231, 0.16387871918933733, 0.15031918750277587, 0.07029609901032277, 0.15046974085271358, 0.11974114259438855, 0.22571802591638906, 0.03580851852893829, 0.25679393910935944, 0.16043879091739655, 0.0878084364480206, 0.18802816048264503, 0.14735952631703444, 0.15703667061669485, 0.24286771352802003, 0.08938461901353938, 0.08548378904483148, 0.1799831371754408, 0.12140230488564287, 0.10883945293192353, 0.11405225071523871, 0.1385038165109498, 0.1235828585922718, 0.0822728324149336, 0.12356301822832652, 0.13063456091497624, 0.16221328212746552, 0.14301725503589424, 0.11251838837883302, 0.15889677937541688, 0.13199517290507043, 0.1074738401387419, 0.1413142949874912, 0.12173621196831975, 0.1371486328010048, 0.23841809800692967, 0.13753722980618477, 0.1499684527516365, 1.4429316414254052, 6.585995946611677, 21.540605510984147, 36.03788464409964, 45.85483462469918, 40.465919494628906, 27.928965159824916, 31.23843731198992, 33.90032345908028, 28.04744063104902, 28.867392335619243, 16.951723337173462, 9.928305285317556, 3.61328278694834, 0.7534384450742176, 1.2820379606315067, 5.435690402984619, 18.85131914275033, 20.34532948902675, 8.088660274233137, 14.279731035232544, 13.231450234140668, 11.162156837327139, 6.512236475944519, 8.150168333734785, 6.205324121883937, 7.694302235330854, 5.19773370879037, 3.1590660171849385, 2.548435526234763, 0.8111106646912438, 2.4539413281849454, 4.321715252740042, 9.328087755611964, 15.454317058835711, 24.461091450282506, 33.55473395756313, 40.071664810180664, 43.129441942487446, 45.456383228302, 49.84839514323643, 53.82113191059658, 55.73185525621687, 38.25927931921822, 34.19325256347656, 43.38980484008789, 53.59543357576643, 54.86855895178658, 56.54020868028913, 54.74798338753836, 53.458585330418174, 54.271302223205566, 55.14748396192278, 52.186689785548616, 48.432216780526296, 41.71980530875069, 29.53975214276995, 19.5789692401886, 9.988352486065455, 4.649318039417267, 2.2980862855911255, 1.4718802251986094, 1.3300338366201945, 3.215153613260814, 4.835363439151219, 3.933640556676047, 4.903956489903586, 6.11783674785069, 8.979569588388715, 11.429509622710091, 6.116802334785461, 8.683277555874415, 8.755145379475184, 6.686369623456683, 4.517079055309296, 1.7065728945391518, 1.4697738353695189, 2.812556965010507, 8.707767350333077, 18.533025639397756, 29.812691279820033, 26.732523577553884, 30.978810923440115, 27.853928089141846, 35.98468228748867, 36.89333643232073, 22.286185434886388, 7.975514071328299, 1.3792480358055659, 0.13093538263014384, 0.1450971412871565, 0.11393647907035691, 0.0773873259978635, 0.19831536204687186, 0.0470857875022505, 0.205032560176083, 0.31357328806604656, 0.184237538171666, 0.09712228631334645, 0.10282494566802468, 0.11706462050122873, 0.10940618573554925, 0.1467460220945733, 0.05989892727562359, 0.1363610029220581, 0.1663571633398533, 0.1002208029053041, 0.1519244656498943, 0.18336771056056023, 0.1419579397354807, 0.1020200267168028, 0.10064205101558141, 0.16265812968569143, 0.12908604900751794, 0.15076849982142448, 0.08531955642891781, 0.07751387956419162, 0.23306087404489517, 0.14994226129991667, 0.16104101788784775, 0.1603635549545288, 0.21795121553753102, 0.17167059465178422, 0.17638992784278734, 0.16777021251618862, 0.12468963063188962, 0.1538467010749238, 0.1602753454021045, 0.14604908520621912], [0.04734721686691046, 0.06706138008407184, 0.02105508412101439, 0.013760307654073196, 0.01029893767554313, 0.03423318413219281, 0.013013490808329411, 0.020844780673672045, 0.0067085904884152114, 0.02819950825401715, 0.050256466293441396, 0.13671947297241005, 0.00358246685105509, 0.031562273523637226, 0.044850591370569806, 0.037135977298021317, 0.0426770537160337, 0.02692672244406172, 0.05597212637907692, 0.05725778399833611, 0.034798139174069674, 0.01734799625618117, 0.09911732176052672, 0.01771626265586487, 0.035725964565894434, 0.03798673468242798, 0.061841064132750034, 0.03203872385035668, 0.07161822449415922, 0.02017861365207604, 0.06280564915921007, 0.0357403393302645, 0.04530600032636097, 0.016358911026535288, 0.0031950352297696683, 0.07088202756962605, 0.021280814062005708, 0.03982703021860548, 0.055123713333159685, 0.056959058956376145, 0.05297923394079719, 0.02138045014414404, 0.020782033147822534, 0.0300354611660753, 0.05151747952082327, 0.015100554263751422, 0.01400376092975161, 0.03972106340474316, 0.269743834223066, 2.084435041461672, 10.638709085328237, 20.622854437146867, 29.382285118103027, 31.909841741834367, 26.621229069573538, 14.910064663205828, 19.56817521367754, 22.4571475982666, 30.3534973689488, 18.252290623528616, 8.532857741628375, 4.494852202279227, 1.0670463655676161, 1.1399610872779573, 1.3340402330671037, 0.9962812427963529, 2.6448146402835846, 7.145995131560734, 2.603983768395015, 3.0912320571286336, 2.703414010150092, 1.9677330979279108, 3.382717239005225, 3.5604771290506636, 2.1939212807587216, 1.320258046899523, 0.7741184553929737, 1.086992363844599, 0.4757924463067736, 0.41089165742908207, 0.42903660663536614, 2.42396810225078, 7.008157202175685, 11.792277676718575, 18.585837159837993, 23.78561885016305, 28.82118160384042, 30.457192284720286, 34.51640633174351, 38.41243846075875, 29.195149285452707, 24.529998472758702, 26.64658304623195, 42.011647020067485, 43.903794356754844, 51.730971336364746, 48.05682298115322, 48.873632362910676, 45.620482308524, 40.7018803187779, 32.5667313848223, 27.531663690294536, 14.975461108343941, 8.94368040561676, 4.294752768107823, 1.7004471889563968, 0.379034194030932, 0.6286688830171312, 0.9041861817240715, 0.9975426665374211, 0.8226800667388099, 1.6690158184085573, 1.7187002152204514, 1.605572142771312, 2.82816544175148, 4.380403646400996, 4.846280361924853, 4.810597453798566, 2.0383734788213457, 1.5373169481754303, 1.0564221356596266, 0.3951251363115651, 1.0418677223580224, 3.0991625572953905, 7.246601573058537, 12.281315343720571, 23.836748906544276, 22.161619867597306, 17.01393403325762, 17.29384916169303, 25.497444799968175, 26.015384367534093, 17.11303445271083, 4.380467048713139, 1.1418357981102807, 0.0321347026287445, 0.03044409870303103, 0.08283058141491242, 0.04992993488641722, 0.08122631428497178, 0.01551323926209339, 0.013920827835266079, 0.026193312602117658, 0.015423618356830307, 0.012632353447510727, 0.03954965528100729, 0.02193971736622708, 0.031163542597953762, 0.03330332313531211, 0.06329426222613879, 0.012643712971891676, 0.043639518320560455, 0.03535494161769748, 0.03980634168588689, 0.040412758610078266, 0.011804539028422108, 0.0074203495501673645, 0.07851353806576558, 0.04662862453343613, 0.038347274264586825, 0.04486965820459383, 0.02382614989099758, 0.04466275252135737, 0.08993842572505985, 0.049525765502559285, 0.03600024877648268, 0.028470084270728484, 0.11858513605381761, 0.022763960994780064, 0.03234820027968713, 0.04139912800331201, 0.03103452255683286, 0.03914875643593924, 0.05676886559064899, 0.009907142225919026, 0.06815018451639585, 0.04434652466859136, 0.06338954889880759, 0.009756435357433344, 0.017390611648027385, 0.001461485232409489, 0.016814788171489323, 0.03831222114552345, 0.05484861148787396, 0.043781115008252006, 0.00929361001388835, 0.03791906099234309, 0.07619237833257232, 0.06813611848545925, 0.048403088602104356, 0.03500856984672802, 0.0043655530898831785, 0.046957605451877625, 0.008615299759964858, 0.012766465893946588, 0.026490375233281935, 0.050503235909023454, 0.007169110085149961, 0.06297449581325054, 0.013849384883152587, 0.053359881908233674, 0.05455512473625796, 0.042260881047695875, 0.05107614677399397, 0.005929098788848413, 0.0738122606916087, 0.06525883823633194, 0.06378218997269869, 0.0921525601297617, 0.06996597815304995, 0.0033770193819821414, 0.017422736888485293, 0.04188432464642184, 0.013842767470383217, 0.06305119741175856, 0.019024656287261417, 0.027323790958949497, 0.10331865453294345, 0.03907238731959036, 0.063812656195036, 0.04386581992730498, 0.031410217218633206, 0.023063963378912637, 0.039233206904360225, 0.5479918835418565, 4.188825743538993, 15.359939677374703, 26.36522442953927, 34.352925641196116, 33.68052067075457, 28.799456323896134, 17.695078100476945, 18.230954442705425, 27.775932822908672, 29.65964330945696, 25.017475400652202, 11.878266845430646, 3.870523989200592, 0.6557418874331883, 0.3258153354482991, 0.11423362312572342, 0.5445295636143003, 2.0883653334208896, 3.43279790026801, 3.280817346913474, 6.155186355113983, 3.8822099907057623, 5.412559415612902, 4.9853980626378736, 5.535547307559422, 3.463456175157002, 3.502539357968739, 3.0038669279643466, 1.828218047107969, 1.3734789682286126, 1.534099497965404, 1.946858755179814, 6.444288739136287, 10.128457699503217, 16.07268762588501, 21.027835403169902, 27.298697539738246, 32.16499696459089, 33.62541798182896, 38.94543130057198, 43.86912284578596, 31.682395935058594, 27.288197074617656, 30.71898651123047, 47.489881243024556, 48.628725733075825, 54.36644043241228, 52.22938993998936, 50.95958232879639, 48.02964162826538, 43.7305132320949, 35.745987347194124, 30.54287052154541, 19.05212903022766, 12.202282190322876, 6.89895453623363, 2.565516152552196, 1.5447992895330702, 1.4927454484360558, 2.267107525042125, 2.0066551693848202, 4.089715336050306, 3.943800125803266, 3.3455363426889693, 3.3460561547960554, 3.669782280921936, 5.7649438210896085, 6.291669385773795, 4.863015966756003, 2.645237611872809, 2.549237608909607, 0.8742186554840633, 0.48891254514455795, 0.49786101068769184, 3.039415649005345, 7.961551666259766, 15.64072506768363, 24.43837605203901, 23.848880461284093, 17.63537744113377, 20.404429129191808, 27.258893047060283, 29.780486379350933, 21.271242959158762, 7.101868859359196, 1.439520618745259, 0.07553376510207142, 0.031424602161028554, 0.047475259817604504, 0.023041145942573036, 0.0681953885193382, 0.015344747142600161, 0.02360681344621948, 0.012935097113118639, 0.041923353980694494, 0.06712520308792591, 0.029018187895417213, 0.06468254487429347, 0.03973948563049946, 0.02844065281429461, 0.021199505210721066, 0.048014511952974966, 0.04369189104597483, 0.05453973895471011, 0.029840514662542512, 0.04864861649860229, 0.05410052323713899, 0.031636277945446115, 0.05420098713200007, 0.09423065504857472, 0.11975110348846231, 0.06966397578694991, 0.06247656646051577, 0.06094398655529533, 0.037648861562567096, 0.0087389542854258, 0.034608970396220684, 0.030649647316230193, 0.03689117204131825, 0.022209692879446914, 0.08014194747166974, 0.07249398928667818, 0.03313294977747968, 0.03963144928483026, 0.0557955715672246, 0.04663857524948461, 0.023274563685325638, 0.13411187646644457, 0.16285415845257895, 0.15417237074247428, 0.06719676139099257, 0.09689941470112119, 0.10028114502451249, 0.11497085142348494, 0.23131532913872174, 0.10101524527583804, 0.07553705599691186, 0.11189178843051195, 0.18146275063710554, 0.09829704756183283, 0.12958887059773716, 0.10834071612251656, 0.09512035695037671, 0.16320353613368102, 0.13100341255111353, 0.10117166795368705, 0.10293545188116175, 0.1066170743267451, 0.16114294741834911, 0.2317313796707562, 0.12321970665029117, 0.1620208224547761, 0.1329478903540543, 0.13546541812164442, 0.10494641254522971, 0.12977377139031887, 0.09971270231263978, 0.2537533151251929, 0.12642373543764862, 0.1237757932394743, 0.11004361510276794, 0.1426449293004615, 0.13101087643631867, 0.0858906250713127, 0.14939225438450063, 0.13698108893420013, 0.17187866062990256, 0.1072397455573082, 0.18031447939574718, 0.11306863956685577, 0.1428105461278132, 0.15564609452017716, 0.09543671711747136, 0.0675294471106359, 0.1388639286160469, 0.5388064735702106, 3.561650723218918, 15.438879898616246, 29.98026098523821, 43.009609835488455, 43.63560778754098, 38.67908600398472, 23.434060846056255, 27.85770617212568, 33.19508825029646, 38.88932459694998, 25.230072907039098, 11.751970308167593, 5.772924695696149, 1.5950002414839608, 1.551391827208655, 2.846977255174092, 2.3217579296657016, 6.288889237812587, 13.486536843436104, 8.282422951289586, 8.918534874916077, 6.826287235532488, 9.586426990372793, 11.597466690199715, 11.164961303983416, 5.186758594853537, 5.329251817294529, 3.201881251164845, 3.3938293627330234, 1.6741528170449393, 1.4787207267114093, 1.2760777090276991, 2.9818639372076308, 7.791596991675241, 14.013303228787013, 20.589492661612375, 26.871280840465, 30.160292284829275, 34.08949858801705, 39.155457973480225, 45.06253501347133, 37.69245570046561, 34.33244929994856, 35.88418354306902, 52.89966876166207, 54.58220979145595, 57.78915432521275, 54.081143924168174, 54.465330668858115, 51.286175455365864, 43.70817477362496, 34.86811719621931, 28.889166252953665, 16.42261106627328, 10.475680896214076, 5.418458870479038, 2.3920899842466627, 1.6142599965844835, 2.0733018560068945, 2.366865417787007, 2.6935579904488156, 4.779138616153172, 5.581470991883959, 4.009172686508723, 2.375609291451318, 7.106885024479457, 10.636194705963135, 11.723218662398201, 11.365645255361285, 7.086208053997584, 5.0710354787962775, 3.4544554352760315, 1.4934088928358895, 1.8316213616303034, 4.525712626320975, 9.930472254753113, 17.257763692310878, 30.707733903612407, 29.545981202806743, 24.638645717075892, 26.44637417793274, 34.041688033512656, 35.36365229742867, 24.088563782828196, 7.638628925595965, 1.657848977616855, 0.1620373787092311, 0.12359230379973139, 0.21107495522924832, 0.14470000831144197, 0.11020660599959747, 0.1629301000918661, 0.1380037904850074, 0.08287930022925138, 0.10119395782904965, 0.17474271623151644, 0.12007772310503892, 0.1195614393800497, 0.13235992618969508, 0.11789412956152644, 0.16783803887665272, 0.15035589624728474, 0.10155931500984089, 0.1079851094899433, 0.09703429389212813, 0.07517570895808083, 0.17824269485260757, 0.11019053829035588, 0.1099112532766802, 0.14832673727401666, 0.15414449652390821, 0.21054700070193835, 0.1288136714803321, 0.15181515365839005, 0.15859373206538813, 0.10000629084450857, 0.10387888697109052, 0.10394543090036937, 0.23957603158695356, 0.1574309537453311, 0.16177844974611486, 0.13296017183789186, 0.19025948217936925, 0.17110243013926915, 0.15593668392726354, 0.12111979004527841, 0.11063522300017731], [0.03427256291200008, 0.0825652674372707, 0.025937584627951895, 0.04763687328834619, 0.015501269904364432, 0.07255069445818663, 0.05286302124815328, 0.029136351376239742, 0.08658731090170996, 0.013954186313120382, 0.014500167819538286, 0.015260028652846813, 0.05789069432233061, 0.03773963258468679, 0.04041928272428257, 0.02610158484562167, 0.09834991901048593, 0.02774669469467231, 0.014696702095014709, 0.04825916453929884, 0.02357378745052431, 0.04456042604787009, 0.012973149356964444, 0.07993164911334004, 0.04964610368811658, 0.026587027457675765, 0.04311128220121775, 0.0187647129142923, 0.04349188267120293, 0.0324251291874264, 0.04940494894981384, 0.046541473495640924, 0.03808559723464506, 0.03232136761237468, 0.018302691634744406, 0.008526986730950219, 0.043441531980144124, 0.01631395977788738, 0.02918662064309631, 0.04932003029222999, 0.05309231858700514, 0.012774463277310133, 0.046902494837663004, 0.016699123395872966, 0.05379847676626273, 0.019708237910111035, 0.029469437431544065, 0.05961036668824298, 0.021542986422511082, 0.19191870386047022, 1.4792488983699252, 6.320566075188773, 20.158744301114762, 36.242022718702046, 34.62044865744454, 29.427194799695695, 29.850902897971018, 37.0556081363133, 28.576942001070293, 18.53669602530343, 17.732763392584665, 9.527743373598371, 6.1277492216655185, 1.449059626885823, 0.7312399819493294, 0.0759933300848518, 3.0134810635021756, 1.6949196798460824, 2.576929871525083, 6.400293614183154, 3.5863893500396182, 4.393263459205627, 3.2414668755871907, 3.4504521872316087, 2.0982055025441304, 2.237571818487985, 2.197905421257019, 1.6124622587646757, 0.7318374184625489, 1.7885023610932487, 0.409394022077322, 2.545610649245126, 1.6869173092501504, 2.557124899966376, 3.5165764561721256, 7.628276109695435, 10.28198856966836, 12.922477739197866, 15.874042102268763, 20.037668466567993, 20.49645107133048, 18.32278183528355, 18.236933367592947, 35.10031904493059, 41.03050231933594, 39.77763441630772, 40.546362263815745, 30.607950823647634, 26.334471702575684, 20.251648664474487, 14.07129897390093, 7.887594171932765, 3.098483805145536, 1.1306975100721632, 0.4375363162585667, 0.13450881945235388, 1.0207321707691466, 1.4873108714818954, 1.6948712595871516, 2.1394945212772916, 3.952684700489044, 4.739026231425149, 2.7805281579494476, 3.124883702823094, 2.8543267122336795, 2.7666864778314317, 2.655819501195635, 3.2122731506824493, 1.9818088454859597, 1.9858785356794084, 0.5581242027027267, 2.155115374497005, 5.91943050282342, 9.359368545668465, 14.463175637381417, 22.12566293988909, 24.009845903941564, 20.984548125948223, 20.719766174043926, 25.383032287870133, 24.359008516584122, 18.522867373057775, 6.202945232391357, 0.8659597443682807, 0.017728664579668214, 0.04328577426661338, 0.011351111394885396, 0.029766605235636234, 0.07296851596661977, 0.07657733839005232, 0.018721084808930755, 0.07585368079266377, 0.050452671479433775, 0.029986582896006957, 0.03447463742590376, 0.029880259851259843, 0.05446535794596587, 0.012712524904470359, 0.01963503924863679, 0.0845502062833735, 0.04163673400346722, 0.11920528991946153, 0.017340369522571564, 0.037299684049295526, 0.01662195021552699, 0.04080553878364818, 0.08687553222158126, 0.03475242966253843, 0.0624996434365, 0.0392569658080382, 0.03794716252014041, 0.019023733479636054, 0.06249226097549711, 0.02682173950597644, 0.035981114088956795, 0.05205678593899522, 0.004930316445617271, 0.012878385156260004, 0.031196780635842254, 0.040680220151054006, 0.03161559280540262, 0.051969519550246854, 0.020075589983857105, 0.024016757163086107, 0.0023673240752291997, 0.017614636769784347, 0.05275777707408581, 0.07959500074918781, 0.015202222558270608, 0.030458975583314896, 0.025513610503237163, 0.08543585054576397, 0.03869489793266569, 0.024803542265934602, 0.012231299387557166, 0.014969603790502464, 0.01556357807878937, 0.01755907153710723, 0.03985236671620181, 0.007425009389407933, 0.02380310514542673, 0.015925264385129725, 0.05177188265536513, 0.0222384661569127, 0.06863602916044848, 0.018428451315100704, 0.07554202965859856, 0.08793070167303085, 0.04268334712833166, 0.0024826345283405055, 0.02299620656828795, 0.06754534518612282, 0.020506089919113686, 0.03509921194719417, 0.025086901882397275, 0.021827757391812544, 0.08512114600411483, 0.006123639443623168, 0.04480130937216537, 0.010243363961178278, 0.009696839626745453, 0.012899043154902756, 0.06566127735589232, 0.12506491478000367, 0.0019013552061681236, 0.029964350696120943, 0.02525217774590211, 0.011027152483750666, 0.014113546199431377, 0.07132187432476453, 0.04584028897807002, 0.047171863062041144, 0.05974277601178203, 0.05850157939961978, 0.06081640161573887, 0.2975623314934117, 2.8571151111807143, 11.048676252365112, 27.008810009275162, 40.58719335283552, 37.89455795288086, 28.127061775752477, 29.18567541667393, 35.30687856674194, 37.70257922581264, 26.025973422186716, 22.730925730296544, 13.71444731099265, 7.858952828816005, 2.2035944759845734, 0.29386306713734356, 0.22176512517035007, 0.453602668430124, 0.3660841089274202, 1.7007963359355927, 2.5870868350778307, 4.359387082712991, 3.123005517891475, 6.1224282043320795, 4.8696315203394205, 4.800443530082703, 4.1552581276212415, 4.124546221324375, 2.602982142141887, 2.7064340880938937, 2.0835415465491156, 3.792884383882795, 6.402156599930354, 1.293205669948033, 3.5470590719154904, 5.46546082837241, 10.258447204317365, 12.823962705475942, 17.933934586388723, 19.291548320225306, 23.101223026003154, 24.53312863622393, 20.40531849861145, 22.271060943603516, 40.1996853692191, 46.00197662625994, 46.081474440438406, 46.27334894452776, 35.647795404706685, 31.033395971570695, 22.89935701234, 18.635770389011928, 11.309616718973432, 5.085837747369494, 2.385114209992545, 0.9905520187956947, 1.0324534560952867, 2.42885941692761, 0.9877341985702515, 3.2444543838500977, 3.31619171159608, 5.805349332945688, 6.1582900285720825, 2.9395606986113956, 4.0824978947639465, 3.2125704033034186, 4.664999255112239, 4.5811362351690015, 3.5814398441995894, 1.2679845775876726, 0.787696646792548, 0.4577211045793125, 1.8204860048634666, 4.954379567078181, 11.916844112532479, 17.57272379738944, 21.861105067389353, 27.803678716932023, 23.450265782220022, 22.0442213671548, 26.853912081037247, 27.486590726034983, 22.45697389330183, 8.617426003728594, 1.2679930457047053, 0.06416582688689232, 0.028480601563517536, 0.01807469199411571, 0.11988120579293796, 0.044401662424206734, 0.010661487417694713, 0.012142447771371474, 0.018654315266758204, 0.023610324864940982, 0.02093502752748983, 0.031364046303289275, 0.03594178280660084, 0.028880038165620396, 0.02550472508716796, 0.07595840588744197, 0.03273576591163874, 0.05300767134342875, 0.01173455747110503, 0.018117853606651937, 0.024748031316058974, 0.030322165960179906, 0.026739061710291674, 0.03809341395805989, 0.050040936430117915, 0.045609444579375644, 0.03758616153416889, 0.06471697374113969, 0.06210272080664124, 0.06032654682972601, 0.017515029525384307, 0.042535524881844006, 0.017693706455507448, 0.02320267290009984, 0.04361787305346557, 0.01181911989780409, 0.03913771327851074, 0.08335713816008397, 0.054027170208948, 0.021532913570159247, 0.05101932625153235, 0.06990832981786557, 0.026145297767860547, 0.13348328162516865, 0.20920219857777866, 0.11647167588983263, 0.07755863573402166, 0.13902042593274797, 0.36248719479356495, 0.1261157483926841, 0.08200954725699765, 0.19579456374049187, 0.08450125676712819, 0.10984848878745522, 0.11245772056281567, 0.18704689028007643, 0.13524280435272626, 0.12411022957946573, 0.0644812642463616, 0.13167554219918592, 0.14497094734438828, 0.18233697515513214, 0.1344186421483755, 0.1352174814258303, 0.21803076698311738, 0.07975693991673843, 0.1365910805761814, 0.09592990351042577, 0.18152001899267944, 0.2038192038557359, 0.13270714612943785, 0.11089624863650117, 0.1862686648964882, 0.1653572062828711, 0.11745523954076426, 0.20652824134698936, 0.18294723598020418, 0.13913159711020334, 0.1013382618714656, 0.15451306317533764, 0.19160984829068184, 0.13076151481696538, 0.1726275733006852, 0.08747772526528154, 0.06922273124967303, 0.14542392375213758, 0.13878112020237104, 0.09051564189472369, 0.26465365450297085, 0.18407268130353518, 0.1822459293263299, 0.10317658287073884, 0.3426569817321641, 2.4771945604256222, 11.203189424106053, 29.552224159240723, 47.591786997658865, 45.41398532049996, 39.353168964385986, 39.010674885341096, 46.22926957266671, 38.225830691201345, 26.318685395377024, 24.270073311669485, 13.058758837836129, 7.818684543882098, 2.6320147556918005, 1.159142132316317, 0.7864666527935437, 5.3090555753026685, 4.679605671337672, 5.188044011592865, 12.626245634896414, 11.833277259554182, 11.652869888714381, 9.04194530418941, 9.41978052684239, 7.602468763078962, 6.947937599250248, 6.7297632949692865, 4.049800106457301, 3.6313022886003767, 3.688029553209032, 4.181263932159968, 6.3439419865608215, 1.9014926637922014, 4.145253590175083, 4.238772434847696, 8.436760681016104, 11.243619254657201, 15.286994014467512, 19.1201171534402, 24.99019503593445, 26.14010626929147, 23.883419956479752, 25.54929746900286, 43.6414338520595, 49.81659671238491, 47.52048110961914, 47.531761510031565, 35.79308223724365, 31.383446216583252, 24.12568974494934, 15.892350605555944, 9.513291989053998, 4.095111915043422, 1.9392956410135542, 1.4945341753108161, 0.5672872481601579, 2.852232481752123, 3.8219382762908936, 4.7955511297498425, 5.518618021692548, 9.996217846870422, 11.787039603505816, 8.27883073261806, 9.975032789366585, 9.109830072947911, 8.600970932415553, 7.7947792666299005, 6.719810000487736, 4.7384408456938605, 3.7389550719942366, 1.0687845008713859, 2.900368298803057, 7.912281121526446, 12.429296340261187, 20.78424719401768, 30.78220122201102, 33.50815323420933, 30.669692516326904, 28.27185181209019, 34.0805458341326, 34.970474583762034, 23.462369544165476, 9.294283032417297, 1.2407525245632445, 0.1053086823916861, 0.11573541111179761, 0.10869316756725311, 0.1785079070499965, 0.1811657558594431, 0.14571221971086093, 0.09937810312424387, 0.1722694153764418, 0.11211288906633854, 0.09630429199231522, 0.14028816004948957, 0.08304630126804113, 0.16234466007777623, 0.09600844393883433, 0.16366443783044815, 0.16837971338203975, 0.1604145129344293, 0.21632365430040018, 0.10994933266192675, 0.0839678943157196, 0.0893829023199422, 0.1630949162478958, 0.1718245271061148, 0.09018269833177328, 0.09619027096778154, 0.13641111951853546, 0.12719603042517388, 0.13872292903917177, 0.12553478670971735, 0.15373350786311285, 0.12497773660080773, 0.1522347732846226, 0.10856684470283133, 0.08405619886304651, 0.1334399910909789, 0.10588783238615308, 0.27634152876479284, 0.12664173516844, 0.1919231414794922, 0.11536774012659277, 0.15626068439866814, 0.12819662530507359], [0.05099626284624849, 0.09110410817499671, 0.04672098672017455, 0.04565459429951651, 0.06183539157999413, 0.03013980288856796, 0.03299203162480678, 0.05152509268373251, 0.030065723827907016, 0.06070600396820477, 0.020004206403557743, 0.010726956717137779, 0.011395593606201666, 0.04836740444547363, 0.022475159527467828, 0.010792087597240294, 0.07356032742453472, 0.020440680839653527, 0.020521552035851136, 0.014181055344774254, 0.03822124317022307, 0.08065848903996603, 0.05945387615689209, 0.04749886265822819, 0.0029441208254346357, 0.05017798014783433, 0.03512488431962473, 0.012352026882581413, 0.05998634294207607, 0.0663316970957177, 0.043118416996938844, 0.024088342607553517, 0.02531410424437906, 0.025379194412380457, 0.01717938369672213, 0.04040928790345788, 0.032802191097289324, 0.04810660611838102, 0.08063326789332287, 0.015884107843573605, 0.02359277455668364, 0.007712549629754254, 0.02977114463491099, 0.07699351105839014, 0.0585599537672741, 0.04030712427837508, 0.019842759173895632, 0.016070776219878877, 0.034324708328183205, 0.052363690720605, 0.01812528695778123, 0.5384959759456771, 4.534157727445875, 19.680225338254655, 31.60416269302368, 38.96242659432547, 31.314249106815883, 27.376503467559814, 19.428050892693655, 20.47695963723319, 19.283679485321045, 14.66100127356393, 11.273172548839025, 8.233150669506617, 3.643177628517151, 0.849608841751303, 0.15530772267707757, 0.5157907285860607, 1.9073345788887568, 2.8906338725771223, 1.4196548504488808, 1.9941890154566084, 3.640525587967464, 4.367440913404737, 3.800967744418553, 3.0185122106756483, 4.182668771062579, 1.337573609181813, 3.0655829991613115, 2.5464958931718553, 0.7442765395556177, 6.996608861855098, 1.7177018459354128, 0.4279717409185001, 0.5291607997247151, 0.7704120799899101, 1.8774455998625075, 1.951822157417025, 2.4126045405864716, 4.068394788673945, 9.240912181990486, 7.955551028251648, 8.753195541245596, 16.771586077553884, 24.129829134259904, 20.194169691630773, 17.872152941567556, 12.285925473485674, 7.638908590589251, 4.701311409473419, 2.3086731689316884, 1.6795016271727425, 0.3812012991734913, 0.44917191618255203, 1.2298414643321718, 2.576424607208797, 3.061197817325592, 2.071569800376892, 3.819978884288243, 2.113584037337984, 2.9366550488131384, 3.359125064952033, 2.0831745948110307, 2.0562394687107632, 1.2128365082400185, 3.98470938205719, 4.967479092734201, 3.40216372694288, 1.0931607357093265, 1.1169757949454444, 2.686373118843351, 10.7881908927645, 15.35316344669887, 13.196049162319728, 14.822991575513567, 21.601435252598353, 19.020945514951432, 19.873480796813965, 23.75668134008135, 23.497800145830425, 16.969877243041992, 6.943563273974827, 0.9138397808585847, 0.05377767288259097, 0.012833414399730307, 0.04949645957510386, 0.022744176609973823, 0.051314624691648145, 0.01036233829134809, 0.05237872027126806, 0.007347063527309469, 0.045641040562519004, 0.13705774982060703, 0.014520194780613695, 0.01584128719488425, 0.013836745472092713, 0.020520344243517945, 0.043763283107961924, 0.025902312681345, 0.016744181513786316, 0.03099051956087351, 0.06055039553237813, 0.03095506949882422, 0.05255849473178387, 0.04648522972794516, 0.05263979001236813, 0.026821113557421734, 0.07784379686095885, 0.026144922877262746, 0.030717541530196155, 0.032223288768104145, 0.03630131815693208, 0.04345987278169819, 0.08595661260187626, 0.014258115718673383, 0.05832708054887397, 0.02960556512698531, 0.03528195499841656, 0.004819105404229569, 0.014058332956795181, 0.06181295921227761, 0.03607178672349878, 0.04517853073775768, 0.08339355513453484, 0.023921953946618096, 0.011559995855869991, 0.022740524395235946, 0.03602726125557508, 0.06317597321633782, 0.0067163860076107085, 0.04994216887280345, 0.01933639054186642, 0.0815615580816354, 0.09559672246021883, 0.07794129555778843, 0.03163456464452403, 0.026716459708820497, 0.02335248834320477, 0.014758192634742175, 0.02625097959701504, 0.0469557123391756, 0.02748852569077696, 0.041730293804513555, 0.04138341313228011, 0.08149834575929812, 0.025362505843596797, 0.03238860025469746, 0.02173268615401217, 0.05962248532367604, 0.058118051051029136, 0.030691923440567086, 0.04608200350776315, 0.05482864559495023, 0.05736134201288223, 0.015699225710704923, 0.05319192074239254, 0.05063472921028733, 0.03991583688184619, 0.021738526644185185, 0.030498133839241097, 0.016110368738217012, 0.033309372275003364, 0.016536992542179565, 0.014797152419175421, 0.037087875950549326, 0.06800776680133172, 0.06763837233717952, 0.0036611701278681202, 0.01272737464335348, 0.025433724879154136, 0.021626296952100735, 0.009625626528369529, 0.02055028290487826, 0.09641101198004824, 0.03683753724076918, 0.05351150734350085, 0.13534693233668804, 1.3981018641165324, 7.826269371168954, 25.00020044190543, 38.832404954092844, 42.642067500523154, 33.599028723580496, 31.67675747190203, 19.477678401129587, 15.657921859196254, 20.272838933127268, 17.488551582608903, 17.696163756506785, 11.894901701382228, 5.752205167497907, 0.8610253834298679, 0.2003772942615407, 0.30283997686845915, 0.8879315225141389, 0.5870177437152181, 1.8511653414794376, 1.9419242313929965, 2.9798090074743544, 3.9692874210221425, 2.7592688415731703, 5.001923050199236, 4.278421895844596, 4.504859345299857, 4.977923103741237, 2.6582153269222806, 8.761206814220973, 11.922878623008728, 2.3997136780193875, 1.6137570121458598, 2.0539120393139974, 2.164158672094345, 2.7740109648023332, 4.390709127698626, 4.008435308933258, 6.375446421759469, 11.635718260492597, 10.31909281866891, 10.935119237218585, 20.842881304877146, 29.53441592625209, 24.1301018510546, 23.02152371406555, 16.18833691733224, 10.34777237687792, 6.523017474583217, 3.8798406549862454, 2.498275394950594, 1.4510457260268075, 3.038907127720969, 3.467898896762303, 3.9205319115093777, 4.235370423112597, 3.991861249719347, 4.492870228631156, 4.017218266214643, 5.973821869918278, 4.919622940676553, 3.2293906893048967, 4.900076789515359, 2.51649791428021, 3.247717648744583, 1.2516015938350131, 0.47435454917805536, 0.742016746529511, 1.1454202000583922, 3.1726525681359425, 9.35176374231066, 17.84454080036708, 17.97333608354841, 20.981979029519216, 26.94531042235238, 21.430321965898784, 25.417550938470022, 26.69373004777091, 28.731129476002284, 21.265231030327932, 9.736763426235743, 1.7173872228179659, 0.1162587787423815, 0.04767789412289858, 0.06890196060495717, 0.06403470677988869, 0.013819837227596768, 0.06489444457526718, 0.06055259398583855, 0.030591768279139484, 0.07416541102741446, 0.05650737855051245, 0.04984445643744298, 0.014424662139000637, 0.04015520368037479, 0.03657866934580462, 0.007250666601716408, 0.006838265315829111, 0.05265655322000384, 0.041349408349820545, 0.029637045759175504, 0.0243621077388525, 0.03720952370869262, 0.049857226466493945, 0.03392057287107621, 0.03337334455656154, 0.042069934508098025, 0.04822804692334362, 0.050218790636530945, 0.03387358092835971, 0.08802374918013811, 0.03409423712374909, 0.02708114344360573, 0.012798410474455782, 0.05658006661438516, 0.03497295693627425, 0.031451258409236155, 0.01743475204732801, 0.0223520512226969, 0.00769125550453152, 0.01896889936844153, 0.03694358208615865, 0.12704819121531077, 0.03260534469570432, 0.016707983366878967, 0.10106652216719729, 0.2005884950714452, 0.12336237542331219, 0.09400488609181983, 0.09799881106508629, 0.0974558609138642, 0.14757995520319256, 0.21631453478974955, 0.17971943132579327, 0.22788267476218088, 0.08673770818859339, 0.05825626863432782, 0.13384635214294704, 0.1685127740991967, 0.1104334673977324, 0.1900097405804055, 0.1426323764026165, 0.1499097051897219, 0.13536812977067061, 0.10125965358955519, 0.11623692991478102, 0.17596350929566792, 0.14224820344575814, 0.08959025583629097, 0.14159269790564263, 0.1164044737815857, 0.11642440914043359, 0.10802274104207754, 0.15532465891114303, 0.16778015983956202, 0.10543256253004074, 0.09596283960023097, 0.11474717913993768, 0.1764001737215689, 0.14129530957766942, 0.06641382697437491, 0.13460314939064638, 0.15138942721698964, 0.17329639169786656, 0.12338669411838055, 0.1184441229062421, 0.12453333687569414, 0.10775386475558792, 0.13190730262015546, 0.13980675302445889, 0.059142964625997205, 0.10768417242382254, 0.29947319467152866, 0.2342854669051511, 0.0996987312766058, 0.19106913730502129, 1.3488258911030633, 7.554254344531468, 27.06766298839024, 43.83956520898001, 51.05433143888201, 41.39302805491856, 38.45299857003348, 27.817463942936488, 28.896685940878733, 25.79610616820199, 20.59611255781991, 15.72657527242388, 10.69952927316938, 4.734187679631369, 1.3917746607746397, 0.5358490379793304, 1.0254624826567513, 3.419383317232132, 5.7520162633487155, 6.433227206979479, 6.312550025326865, 8.828553097588674, 9.546184761183602, 11.90303543635777, 8.522709897586278, 8.565222450665065, 7.846490366118295, 8.45022107873644, 5.779099472931453, 5.392140397003718, 12.722493818828038, 3.798760388578687, 1.3797871725899833, 1.3594048491546085, 1.3714436888694763, 2.1934475004673004, 2.672911201204572, 3.6024184099265506, 5.530940651893616, 11.404922553471156, 10.219186408179146, 12.04434095110212, 20.903259413582937, 29.74292094366891, 25.76660064288548, 22.822669744491577, 15.408082008361816, 9.25241231918335, 6.095648544175284, 3.4639395092214857, 2.290046134165355, 0.9081520289182663, 1.5157102218696048, 3.046668916940689, 6.356021864073617, 7.407867959567478, 6.602545252868107, 9.689364552497864, 7.552383542060852, 9.127893652234759, 8.265800254685537, 6.96413037606648, 9.456936887332372, 6.696250396115439, 8.776351281574794, 9.417160187448774, 6.544297635555267, 2.7050003707408905, 1.849594614335469, 3.7744712233543396, 12.981431467192513, 20.433344057628087, 18.374997547694615, 21.640445913587296, 30.743468488965714, 28.613779612949916, 30.65656736918858, 33.426657812935964, 33.65614291599819, 23.46459296771458, 9.641974364008222, 1.5947738822017397, 0.4153464569577149, 0.13433431381625788, 0.23316129722765513, 0.13650572087083543, 0.20585953151541098, 0.19392491477940763, 0.1303575557789632, 0.13604245787220343, 0.23848217885409081, 0.2028702183493546, 0.12421112773673874, 0.15100169873663358, 0.14956910775176116, 0.12516277310039314, 0.04700873985088297, 0.12774999998509884, 0.1625478541744607, 0.08500299270131759, 0.15674608120960848, 0.10996379224317414, 0.1273057631083897, 0.1580706765609128, 0.09990895499608346, 0.10265717788466386, 0.13949706964194775, 0.11736310805593218, 0.15948031949145453, 0.1261257907109601, 0.19538390077650547, 0.22760887231145585, 0.14718088161732468, 0.10402135218360595, 0.17128286617142813, 0.10596401829804693, 0.09092424889760357, 0.11738304341478006, 0.10039381576435906, 0.1830396388790437, 0.05883657892367669, 0.11971454402165753, 0.19166668238384382, 0.11597629104341779, 0.20358440359788282], [0.07972217178238289, 0.043286429052906375, 0.042702719303114076, 0.024568109274176613, 0.02303035045042634, 0.027844761664580022, 0.026359446812421083, 0.09397805003183228, 0.035924788897058794, 0.021753220320014015, 0.02558075832868261, 0.0968100041417139, 0.017740150481196384, 0.02580095990560949, 0.032956493353205066, 0.03313241034213986, 0.010527091682888567, 0.025695849742208208, 0.014790881059265562, 0.019182715930842927, 0.08862946382058517, 0.06773780485881226, 0.03830973092200501, 0.06965144324515547, 0.0519553856658084, 0.035165840693350346, 0.08222131125096764, 0.029852070113910095, 0.0167157492001674, 0.020946793324713196, 0.042823807269866974, 0.023138264659792185, 0.02660134793924434, 0.03875169809907675, 0.03033106155427439, 0.02734958377134587, 0.03886504737394197, 0.06779410290930953, 0.052434824939285, 0.031919590064457486, 0.005979247615739171, 0.05658134565289531, 0.03163319400378636, 0.0456771386255111, 0.0005239269448793493, 0.03335882729983755, 0.10441921119179044, 0.01862290927342006, 0.009584137504654271, 0.04316666762211493, 0.06603937063898359, 0.032579255024237294, 0.5156968193394798, 4.9086582490376065, 17.02086659840175, 29.433211939675466, 36.49678884233747, 32.97543484824044, 39.45164925711495, 36.09455067770821, 33.22632735116141, 28.246445723942347, 25.77510002681187, 16.04551669529506, 11.012470926557269, 5.4597606999533514, 2.551655582019261, 0.1818640362471342, 0.2544813560588019, 0.24372646744762147, 1.1872747370174952, 0.7025326852287564, 4.492135890892573, 3.7207095367567877, 2.347193330526352, 3.3686199954577853, 3.080569394997188, 2.9135488143989017, 2.544424895729337, 2.6257717992578233, 16.50899280820574, 11.754366568156652, 1.727365487388202, 2.05570011479514, 1.9800075250012534, 1.5782170849187034, 0.45261360864554134, 2.016729188816888, 0.5270446932741574, 0.32764662003942896, 1.2739518859556742, 1.8619806468486786, 1.7316493775163377, 4.8316826309476575, 4.675129728657859, 4.013670342309134, 3.2055792127336775, 1.5056151407105582, 1.1228882776839393, 0.5125071076410157, 1.3313640909535545, 0.6623717173933983, 2.3114044623715535, 5.085690098149436, 2.05635324546269, 3.551629249538694, 2.74696683883667, 1.5116837407861436, 2.6684693481240953, 2.038471404995237, 4.89014390536717, 4.2183495078768045, 1.3541686215570994, 2.2022499995572224, 0.9925622195005417, 1.7716092275721687, 0.747928360743182, 0.5978936829737255, 1.3577645314591271, 3.1735486686229706, 7.917883975165231, 32.2186335836138, 23.04434507233756, 13.876619134630475, 15.902816329683576, 12.452460765838623, 22.101637806211198, 21.600643157958984, 27.05555748939514, 15.814258064542498, 5.6019482016563416, 1.0544980274779456, 0.07367152574339084, 0.008793169233415808, 0.06987164821475744, 0.027625803503074815, 0.03113103737788541, 0.009411838803706425, 0.049669285837028704, 0.02356564672663808, 0.015814883700971092, 0.0013249952628809425, 0.0410054385928171, 0.03315188090449997, 0.04999225154252989, 0.017056825005316308, 0.036026352018650086, 0.01275417932109641, 0.013763605334263827, 0.043693224367286475, 0.05614927830174565, 0.04789666059826102, 0.047219757456332445, 0.00867508548045797, 0.01441129669547081, 0.064975760211902, 0.06394400700394597, 0.07530505808868579, 0.043004205982599936, 0.04923463326745799, 0.021244032374982322, 0.00982451023134802, 0.039459267631173134, 0.045886873799775324, 0.054225112444588115, 0.05523951551211732, 0.04304259070860488, 0.06959656333284718, 0.022068711962284784, 0.02844910227161433, 0.0445830110859658, 0.034503963709409745, 0.016775940345334153, 0.04033143279541816, 0.05667931253888777, 0.03271431402702417, 0.04045575737421002, 0.06210756554667439, 0.011277886440179177, 0.016257778774680834, 0.040230897654380114, 0.03633832545684917, 0.0213941005723817, 0.03195694341723408, 0.015959640665512, 0.08699266772185053, 0.01192409689870796, 0.08405674847641162, 0.03863676105226789, 0.02646246030261474, 0.04447579576766916, 0.03525093916271414, 0.047084555961191654, 0.024267336752797877, 0.05523643496313265, 0.019881349156743715, 0.023389064773385013, 0.049573680252901146, 0.046245971495019536, 0.052615267756794176, 0.0670434735449297, 0.0653376772201487, 0.014461937460250087, 0.011021301815552371, 0.026621656492352486, 0.00849188441809799, 0.05210210190021566, 0.04967252244906766, 0.04142546873273594, 0.08469776050852877, 0.0069294125007997665, 0.08515913039445877, 0.049349051234977584, 0.01604958387490894, 0.06827859726867505, 0.029259346026395048, 0.06934484719697918, 0.13797259144484997, 0.022474813474608318, 0.04455859400331974, 0.0822552108604993, 0.0365905267452555, 0.052647464243429046, 0.0166173514444381, 0.03389775373839906, 0.04103473773492234, 0.010193124380228775, 0.023582552426627705, 0.9138866811990738, 8.299752627100263, 21.76533283506121, 36.90646505355835, 39.80687591007778, 35.76263870511736, 35.291307653699604, 29.132172550473893, 21.8947708266122, 18.66389843395778, 15.51295290674482, 15.21519306727818, 13.31067967414856, 8.765503406524658, 3.207693202154977, 0.5328614211508206, 0.3307391383818218, 0.297318411724908, 0.275397035160235, 0.28735276790601866, 0.611002002443586, 2.028019143002374, 3.0129477892603194, 3.9764418942587714, 2.867650534425463, 3.6369142617498125, 5.785796233585902, 2.7184258103370667, 9.568367753710065, 14.261120285306658, 5.492565751075745, 3.053881798471723, 2.1528669808592116, 3.0621942324297766, 1.5754462735993522, 2.0909222705023627, 1.5663273057767322, 0.7945919739348548, 1.7129341874803816, 2.5611505125250136, 3.199916430882045, 6.700455359050205, 7.269053374017988, 5.517625297818865, 4.511326381138392, 2.5685959415776387, 1.6351468243769236, 1.1129086017608643, 3.3343634222235, 3.108605159180505, 3.496248632669449, 10.377918004989624, 8.936680964061193, 6.5039147053446085, 5.754528905664172, 3.6549943430083136, 5.42427842106138, 2.6116569680827, 4.663283484322684, 3.6512596862656728, 2.8902571499347687, 2.926273354462215, 0.9454126123871122, 0.5797220809119088, 0.18883401581219264, 0.6961289431367601, 2.1272441957678114, 4.606677378926959, 10.36874725137438, 29.836148398263113, 28.947209766932897, 17.56462046078273, 12.228391783578054, 15.641324349812098, 25.213018553597585, 24.912053857530864, 31.774872984204972, 20.424054316111974, 8.061650889260427, 1.5251779024090086, 0.18076623444046291, 0.07500587164291314, 0.032264465665710826, 0.037989282581423006, 0.022632959631404707, 0.035776644346437285, 0.037509544752538204, 0.004727376799564809, 0.024176945710288625, 0.02580822192664657, 0.04412910508524094, 0.018039535398461988, 0.00588484515901655, 0.05874916325722422, 0.012167891986402017, 0.029715623507010083, 0.014603400137275457, 0.06319022245172944, 0.03698412794619799, 0.023086982679420283, 0.020688454687063183, 0.04405062572498407, 0.06983423379382916, 0.0034713866397006704, 0.026789977281753505, 0.03691457810678652, 0.08148185057299477, 0.06484094208904675, 0.024834814248606563, 0.030900382968996252, 0.03451394835220916, 0.0882316455245018, 0.03984025825879403, 0.024403735862246582, 0.09277375893933432, 0.106953892324652, 0.01663235724637551, 0.008693176920392683, 0.06239692680537701, 0.01913818876658167, 0.006293902539515069, 0.00981056718488357, 0.029396440634237866, 0.013183244154788554, 0.18689160075570854, 0.17869349994829722, 0.21182251082999365, 0.13599212414452008, 0.1282642481050321, 0.11253936868160963, 0.15609989874064922, 0.24613200979573385, 0.09780625639749424, 0.23293732638869966, 0.12047936155327729, 0.22882423709545816, 0.11587099597922393, 0.0849547895735928, 0.10924556971128498, 0.1575238723307848, 0.11765500025025435, 0.19775939759399208, 0.11800136523587362, 0.18535493606967585, 0.12528007823441709, 0.16881329725895608, 0.16414036229252815, 0.21664925611444882, 0.19093750151140348, 0.13442645887179033, 0.2502294113593442, 0.12168346265597002, 0.09357146506330796, 0.0818320017840181, 0.12920777818986348, 0.10387540608644485, 0.20752457502697194, 0.24392503393547876, 0.070565470627376, 0.1687013796929802, 0.12268916011920997, 0.12787700816988945, 0.10324054158159665, 0.1544280970203025, 0.08715272056204931, 0.18984652576701982, 0.1540967005171946, 0.14701310704861367, 0.09329748619347811, 0.12801409938505717, 0.23167636405144418, 0.07846360467374325, 0.10584205841379506, 0.14008670300245285, 0.11569446830877236, 0.1453156838459628, 0.9465952175004142, 8.120200753211975, 24.100420883723668, 40.19621821812221, 49.213336740221294, 43.78914213180542, 48.40604986463274, 45.48800448008946, 41.230652127947124, 35.923385279519216, 32.00487920216152, 20.912837505340576, 14.947425127029419, 7.599883164678301, 3.5874769602503096, 0.8118385970592499, 0.7393087946942875, 0.8806155579430717, 2.9940623683588843, 3.5587787287575856, 9.369785632405963, 7.181272004331861, 5.373008532183511, 10.19123033114842, 8.937117832047598, 8.635522586958748, 8.915687850543431, 8.133738449641637, 26.58681811605181, 16.08897246633257, 4.346050449780055, 5.345158849443708, 4.642414569854736, 4.227557608059474, 1.295562520623207, 3.5085074262959615, 1.402006208896637, 0.7357122876814434, 1.8460427820682526, 3.0843333644526343, 2.5980571721281325, 7.231147042342594, 6.85515786920275, 4.916966557502747, 4.13992041349411, 2.3414109093802313, 1.6730228662490845, 0.961639261671475, 3.104549582515444, 1.5644230651003974, 5.680644367422376, 10.838415946279254, 6.29634986604963, 9.871356981141226, 9.825458918298994, 5.45737703357424, 8.304088303021022, 8.187139698437282, 10.894030196326119, 11.6880955185209, 5.539337984153202, 6.694846860000065, 5.363145998546055, 3.638240716287068, 2.2725440561771393, 0.9301632706608091, 2.408244545970644, 4.668802525315966, 11.129408240318298, 36.871988092150005, 30.266797746930802, 20.870215518133982, 20.812354394367762, 19.661171640668595, 32.616688932691304, 33.57300077165876, 38.926115308489116, 23.491020441055298, 8.347577946526663, 1.447635571871485, 0.1968561860599688, 0.1158697067626885, 0.17578296469790594, 0.11665983365050384, 0.10578226590795176, 0.05523624836600252, 0.16089206588055405, 0.11279371753334999, 0.07943590464336531, 0.09994028295789446, 0.09821233925010477, 0.11826659100396292, 0.15978776370840414, 0.1397965614284788, 0.12891873584261962, 0.13666369739387715, 0.094785655981728, 0.1984919575708253, 0.12415704849575247, 0.119112778455019, 0.1331856490245887, 0.08009741521839585, 0.10929809510707855, 0.14422829076647758, 0.16419951697545393, 0.15217658212142332, 0.16318887977727822, 0.1648906727454492, 0.12324417462306363, 0.08628036880067416, 0.0941572172035064, 0.19688597374728747, 0.13093699754348823, 0.22708866665405886, 0.1531832023922886, 0.1762176478015525, 0.1456070603536708, 0.1343093437275716, 0.17041539986218723, 0.18840860149690083, 0.0947962004159178, 0.1108409141057304, 0.08691914166722979, 0.1737287813531501], [0.042288507600980144, 0.04918662352221353, 0.008615594922697969, 0.0342964473446565, 0.04209638041044984, 0.03966539639181324, 0.0356451035477221, 0.0467734747965421, 0.028766926378011703, 0.03169346148414271, 0.02740128813976688, 0.02178487567497151, 0.04922156468299883, 0.02033005079387554, 0.020709513021366935, 0.01269582870216774, 0.0012055842318139704, 0.02063091831015689, 0.05406928687755551, 0.029967465171856538, 0.03836115709106837, 0.01570379055504288, 0.01378737187146076, 0.02649203934041517, 0.06352192429559571, 0.11077299275036369, 0.02374191316110747, 0.009660979051009884, 0.041929976482476504, 0.03723245819232293, 0.044377157132008245, 0.025097320787608624, 0.01086901396047324, 0.033535812981426716, 0.02225052033151899, 0.07173797913960048, 0.043779618838535886, 0.056075127994907756, 0.04484532933150019, 0.05048257112503052, 0.0772910350933671, 0.03293144523299166, 0.04888672800734639, 0.044209891464561224, 0.01207884359506092, 0.008323886780999601, 0.039637067554784675, 0.027203540982944623, 0.05312830129904406, 0.04236301753137793, 0.025312701373228004, 0.021948836876877716, 0.026648078645978655, 0.14315851245607647, 4.1795898505619595, 13.163280589239937, 29.22345277241298, 36.94102539334978, 37.41172068459647, 39.78938382012503, 48.83160965783255, 37.3435241154262, 35.1385167666844, 35.927404812404085, 34.15542309624808, 17.394349643162318, 10.541937180927821, 5.187551558017731, 2.3093868792057037, 0.2649659163185528, 0.15203964018395968, 0.2843254160668169, 0.40667445372257915, 2.006154247692653, 2.9532755741051266, 2.6396825270993367, 2.409517369100026, 3.3799266687461307, 4.625194328171866, 1.357103909764971, 8.294462442398071, 18.40122526032584, 6.243470166410718, 2.679346970149449, 3.4426259100437164, 3.6510642681803023, 1.8292416036128998, 1.3457061499357224, 1.0968975637640273, 0.39715924859046936, 0.2832696698606014, 0.16375393659940787, 0.5658953285643032, 0.13715611025691032, 0.3584306410380772, 0.11817797433052744, 0.4165672500218664, 0.39134105507816586, 0.38889482777033535, 0.6399553088205201, 3.321436950138637, 4.243572771549225, 1.440795504621097, 11.635579296520778, 12.860272254262652, 4.347281583717891, 3.4068934960024695, 3.0555975692612782, 4.204865225723811, 1.8953235319682529, 3.722236837659563, 2.0875617308276038, 2.2350737239633287, 3.5018467094217027, 0.4408059593822275, 0.8622814331735883, 0.6721052750945091, 1.755635101880346, 4.227836838790348, 7.70691408429827, 23.42082279069083, 51.124813965388704, 17.648711034229823, 11.64748329775674, 22.885880981172832, 26.185596125466482, 20.18141279901777, 22.439483540398733, 11.218768153871808, 3.4802651703357697, 0.674847913639886, 0.01433827106042632, 0.06102768384984561, 0.03235570148431829, 0.022933457346100892, 0.013792250538244843, 0.07877109638814415, 0.055131268820592334, 0.01757826898912234, 0.062478113520358286, 0.04614022520503827, 0.0482877003295081, 0.028659928190921034, 0.013910944972719465, 0.04748133270602141, 0.024000041452901702, 0.08670523350260087, 0.01344941817556641, 0.03246193631951298, 0.048277352670473714, 0.0016597846531242663, 0.03763153177819081, 0.10362050762133938, 0.004858397670821952, 0.06635573759142842, 0.0427130974962243, 0.011090028083084949, 0.03186553457219686, 0.04014595185539552, 0.030103796427803378, 0.021493531397676895, 0.004971749066109104, 0.05177967223737921, 0.04251682784940515, 0.02820787628713463, 0.051025012374988625, 0.020980328221672347, 0.05134256337104099, 0.01254006929229945, 0.024336638926927532, 0.020986887958965132, 0.039145893018160544, 0.03965194443506854, 0.028227523268599595, 0.017589712482211844, 0.04709238286263176, 0.04001130336629493, 0.05961382721683808, 0.06104379227118833, 0.02602195706484573, 0.05961149984172412, 0.05493649534348931, 0.03523695794865489, 0.03686139792469995, 0.01740070994544242, 0.030471721863640205, 0.008182533517745989, 0.04671050335413643, 0.046454539589051685, 0.055790489339934926, 0.04678036192698138, 0.021350759148065532, 0.020358444091730883, 0.041991997975856066, 0.012929236266895064, 0.026100258309660212, 0.04219771622280989, 0.046527953685394356, 0.03281075081654957, 0.024205305081393038, 0.01858562886315797, 0.02058162274105208, 0.022554660082927773, 0.011935568381366985, 0.0692799724638462, 0.027162750850298574, 0.06320076688591923, 0.04051449475809932, 0.014296064485928841, 0.031160204205662012, 0.039731804614088366, 0.020441605343616435, 0.051011913256453614, 0.011765882888409709, 0.07901683463049786, 0.02036770779107298, 0.038836213028324504, 0.03555461411763515, 0.0347326605447701, 0.045165194131966145, 0.048833398547555716, 0.029817495362034867, 0.02568016540525215, 0.02718323073349893, 0.04984436144254037, 0.03338482536907707, 0.024057045179818357, 0.0416224338779492, 0.04046100923525436, 0.45737651735544205, 6.478074354784829, 18.561825922557286, 34.74396330969674, 41.467036792210166, 41.301791259220664, 42.00257267270769, 47.12275579997471, 35.253429549080984, 31.391134398324148, 27.75599844115121, 22.982492208480835, 16.386991126196726, 13.429038763046265, 5.861053909574236, 1.5507462961333138, 0.22594081610441208, 0.26113729604652947, 0.26520571059414316, 0.11827617191842624, 0.710772271667208, 0.8298306316137314, 1.1660699205739158, 1.6099352857896259, 2.8575382999011447, 3.196043027298791, 1.5148128185953413, 4.611945850508554, 15.064384153911046, 6.9934652362551, 4.263507153306689, 3.930657608168466, 5.408487336976187, 6.948269375732966, 3.6185831768172125, 2.3676067037241797, 1.765747987798282, 0.9302812814712524, 0.5213753974863461, 0.5447936494435582, 1.0582996691976274, 0.5957687284265245, 0.3037389543439661, 0.976468563079834, 0.8630511632987431, 1.267761692404747, 2.5142438752310614, 4.048128630433764, 8.26797764641898, 4.975744409220559, 8.071018798010689, 18.479580095836095, 4.41743928194046, 3.9063801680292403, 3.1242386060101643, 2.391928004367011, 2.6619855931827, 3.3762343525886536, 2.812741526535579, 1.6372111993176597, 0.5620749049953052, 0.3283781079309327, 0.38228771516254967, 1.0129272810050418, 3.8893305914742604, 8.349786605153765, 13.3140868970326, 23.340195894241333, 51.81935589654105, 25.40061296735491, 13.243939621107918, 20.175902877535137, 24.006616728646414, 27.418849263872417, 28.056313480649674, 16.818988425391062, 6.304943919181824, 1.2084343901702335, 0.11121399301503386, 0.04738637512283666, 0.03907763578795961, 0.026279612078464458, 0.06461099335657698, 0.0248721218002694, 0.00875873867023204, 0.030539375197674547, 0.12799542610134396, 0.11025054792740516, 0.07400941582662718, 0.050503500537680726, 0.06661294986094747, 0.04438964217635138, 0.0587823571903365, 0.07932229752519301, 0.031816361139395406, 0.035773933599037785, 0.060110311289983134, 0.02880005245762212, 0.014070765414674367, 0.03316235409251281, 0.016120465339294503, 0.14882107717650278, 0.02392816254203873, 0.012883871111885777, 0.08055018128028937, 0.042677013003932576, 0.024822936493105123, 0.017442295660397837, 0.008293402747118046, 0.017353986024058292, 0.010665333863081676, 0.013035750997784947, 0.0515518066074167, 0.0762341625190207, 0.03404936221029077, 0.015180032766823257, 0.040147766936570406, 0.02062869441163327, 0.023138123863775815, 0.005022496700153819, 0.05184115090274385, 0.08119174292577164, 0.04759152000769973, 0.11254763323813677, 0.13074517569371633, 0.2066068292728492, 0.08767049027872936, 0.1709957101515361, 0.18647887504526547, 0.16739648899861745, 0.12368994498891489, 0.05867052783391305, 0.09734824525990657, 0.09139113527323518, 0.14420892537704535, 0.2241010226841484, 0.09417470305093698, 0.0770092937829239, 0.09682152566633054, 0.09447732966925416, 0.14898631402424403, 0.1256679017096758, 0.11949335517627852, 0.10544951912015676, 0.1510083076677152, 0.13168542166905745, 0.08452014039669718, 0.09845140070787498, 0.20381096644060953, 0.14865421184471675, 0.12137380641485963, 0.11644731648266315, 0.08578249373074089, 0.09353647301239626, 0.21591315418481827, 0.11155453617019312, 0.12628011671560152, 0.17306011223367282, 0.13199723565152713, 0.1169613746127912, 0.09419146286589758, 0.16138095036149025, 0.11122336358364139, 0.1239842799093042, 0.1516701371542045, 0.11154397816530295, 0.23478182884199278, 0.07513237771178995, 0.10093840797032629, 0.0804858086630702, 0.10301401945097105, 0.16499623922365053, 0.10795807665480034, 0.08063509315252304, 0.11469433483268533, 0.08338702762765543, 0.40926613179700716, 6.230230373995645, 20.11569673674447, 39.15813650403704, 46.86426196779524, 47.78634698050362, 47.936122349330354, 53.9524632862636, 42.0134813444955, 40.77940137045724, 42.529656069619314, 42.88340623038155, 23.101532220840454, 14.3553352526256, 6.662169916289193, 2.7931282818317413, 0.6237324050494603, 0.5585898948567254, 0.9590723365545273, 1.6374148683888572, 4.821168269429888, 7.507000514439174, 6.752662820475442, 7.9853657484054565, 8.365447844777789, 12.207826852798462, 5.016107363360269, 20.66166533742632, 32.42497771126883, 13.628805552210126, 9.423987661089216, 10.26344382762909, 8.041482874325343, 9.3672981773104, 6.063235197748456, 2.647377222776413, 2.0565445380551473, 1.0069585612842014, 0.601667369050639, 1.2810708582401276, 0.675506092607975, 0.8439939373305866, 0.2485319881566933, 1.09287813944476, 1.2069158830812998, 1.9965540085520064, 2.3566559084824155, 5.26793874161584, 9.385785596711294, 6.858867338725498, 23.55650200162615, 22.457144124167307, 9.181469474520002, 11.729843769754682, 8.170191305024282, 10.375907370022365, 6.398254317896707, 8.850892424583435, 6.347094731671469, 5.67529251745769, 6.230067525591169, 1.136081712586539, 1.2863188109227588, 1.30827576986381, 3.043376122202192, 7.146649565015521, 11.756229553903852, 28.427204847335815, 56.63502727236067, 23.104193380900792, 17.111021212169103, 30.504252433776855, 33.105807372501914, 34.37697335651943, 35.305374281747, 19.764847448893956, 6.469147656645093, 1.2707506120204926, 0.12437457325203077, 0.1834134573915175, 0.1653022449463606, 0.1982448079756328, 0.12121435068547726, 0.15480040918503488, 0.12426117647971426, 0.1213071064225265, 0.1932604390063456, 0.18139596922057016, 0.17585947630660875, 0.08360239464257445, 0.11956728835191045, 0.09874083660542965, 0.10992597748658486, 0.171380629496915, 0.12648251014096396, 0.10944408870169095, 0.13785707764327526, 0.06960526215178625, 0.12249077005045754, 0.13957206133220876, 0.12864690114344868, 0.21319178092692578, 0.1404619871505669, 0.08178597675370318, 0.13836563963975224, 0.07832071198416607, 0.15568371250161103, 0.07943556537585598, 0.16389321269733564, 0.11970238467412335, 0.14305907993444375, 0.15604382460670813, 0.275178356894425, 0.1713425772530692, 0.10515854973345995, 0.07940626623375074, 0.14013782383075782, 0.0923169216673289, 0.14729988308889524, 0.10212439218802111, 0.08609164785593748, 0.22269146117780889, 0.20069773920944758], [0.024084466476259486, 0.03064114527244653, 0.02384605641210718, 0.06445638915257794, 0.023315793169396262, 0.056516308071357865, 0.08611697756818362, 0.032021058191146166, 0.03339663866375174, 0.08142730314284563, 0.010259580948123974, 0.008822291108247424, 0.01520971188853894, 0.044067734985479286, 0.006079011771362275, 0.019127135431127887, 0.10148829274943896, 0.032462234874921184, 0.022753862697365027, 0.06447859760373831, 0.02539123671262392, 0.0405546131410769, 0.015512236726603337, 0.04034989234060049, 0.07331246536757265, 0.006808105706503349, 0.035496551876089404, 0.011278866923281124, 0.028342066765097634, 0.03504609622593437, 0.09611728095582553, 0.0069377716281451285, 0.017231814097613096, 0.05000804105241384, 0.02068424946628511, 0.06556470825203828, 0.07562659547797271, 0.025273410802973167, 0.09039206709712744, 0.11892851548535482, 0.018790419213473797, 0.048589600915355344, 0.0774009306249874, 0.05236915632018021, 0.038835371644901376, 0.037876605056226254, 0.016254063795453737, 0.03525066774870668, 0.048156709144158025, 0.10546979374651398, 0.0468365785532764, 0.003253516466689429, 0.04110982781276107, 0.03829911524163825, 0.028110230008938482, 1.9366618394851685, 10.951681137084961, 25.271925381251744, 33.31342996869768, 28.4114602293287, 23.939217465264456, 16.628013713019236, 10.44385814666748, 12.599348289625985, 21.579280921391078, 29.2658645766122, 22.53174693243844, 16.348029102597916, 10.361137236867632, 6.14539634329932, 2.1694925001689365, 0.7308431746704238, 0.13579306911144937, 0.2518054039350578, 0.47109014434473856, 1.2593869417905807, 0.7755205801555088, 2.2500088768345967, 2.5876678781849995, 1.0053864227873939, 4.4566492693764825, 8.8315703528268, 7.426894732883998, 2.4002254562718526, 1.1062373540231158, 3.2712687849998474, 3.5429472582680837, 2.7650918662548065, 2.8316829672881534, 2.253506209169115, 1.157583890216691, 0.20270844203020844, 0.1878066323697567, 0.6056397301810128, 0.6822617501020432, 0.5668798557349614, 0.4103783049753734, 0.8927328905888966, 1.041228922350066, 3.819670992238181, 5.823480222906385, 8.766191278185163, 4.7406468987464905, 7.255012367452894, 20.325367314474924, 4.706052252224513, 3.3229479662009647, 1.8920394224779946, 2.5906208625861575, 1.3382407448121478, 2.4542398835931505, 1.2603824883699417, 0.8757284773247582, 0.4887373745441437, 1.3304337923015868, 1.854863737310682, 5.074490036283221, 6.860641734940665, 11.610222714287893, 13.374131492206029, 43.85026543481009, 50.49945872170584, 15.848908730915614, 18.877732719693864, 19.492422478539602, 29.400673525674, 20.462825264249528, 11.462892242840358, 3.353248191731317, 0.3521455611501421, 0.03161847997190697, 0.04226420247661216, 0.03269686210634453, 0.0600127854517528, 0.06626631346132074, 0.019694794435054064, 0.06867448852530547, 0.010808308825029858, 0.025947358924895525, 0.043604665369327576, 0.00860403523048652, 0.05317934409582189, 0.03434242827019521, 0.0784526327624917, 0.00948594500576811, 0.065576596185565, 0.030286142536039864, 0.09726799492325101, 0.03297164164749639, 0.0368156375230423, 0.02460189183641757, 0.01069161861336657, 0.01815432825657938, 0.023401826320748245, 0.014982991286420395, 0.02909719990566373, 0.05762569247079747, 0.040461687770273, 0.04528341868094035, 0.030896427109837532, 0.04940937639081052, 0.04727594694122672, 0.009062503531043018, 0.007349582588566201, 0.011332577210851014, 0.027804426150396466, 0.012698649711507772, 0.03559407771431974, 0.01932036524106349, 0.03789119355912719, 0.040357363011155806, 0.04999073501676321, 0.019949292564498525, 0.036326518947524686, 0.017663548966603618, 0.03532839732776795, 0.03659342748246022, 0.11664843426219054, 0.04096062135483537, 0.01874329665276621, 0.07084698802126305, 0.03342348490176456, 0.018605616808469807, 0.04036268272570201, 0.062196073654506884, 0.05242145101406744, 0.020759020632665073, 0.03455279448202678, 0.034477141220122576, 0.020682364835270813, 0.021196027718750492, 0.04976594315043517, 0.06904449367097446, 0.02924500858145101, 0.019410137120368223, 0.013115645103555704, 0.0575898318950619, 0.008600552649503308, 0.06341747061482497, 0.07737123793257134, 0.03284203467358436, 0.03828861491222467, 0.023935229484257952, 0.024763428971969655, 0.06110486042286668, 0.02017306493196104, 0.04105765525517719, 0.0365903774675514, 0.019426245541710938, 0.021518603266615952, 0.03812757141089865, 0.02793710010259279, 0.03394438266488058, 0.02214969172408538, 0.06275034855519022, 0.05488102849838989, 0.018386665432314788, 0.08484036821339812, 0.028442606995148317, 0.09939681033470801, 0.04805844370275736, 0.06382926673229251, 0.006287210063809263, 0.031918114250791926, 0.016804713622799942, 0.07299407638077225, 0.006953640865893769, 0.0243313836732081, 0.043771948000150065, 0.04619639433388199, 0.31864902856094496, 3.310092713151659, 16.014409610203334, 31.496934618268693, 37.883784770965576, 32.532327379499165, 29.40393223081316, 21.77573081425258, 17.45208396230425, 20.698836462838308, 28.457858562469482, 29.335155487060547, 21.49407516207014, 21.207983085087367, 13.981899108205523, 8.115947587149483, 1.6776115000247955, 0.5974067662443433, 0.029770615377596447, 0.10264262330851384, 0.3070321019206728, 0.351657260209322, 0.5871462853891509, 0.6694494890315192, 0.5697095096111298, 0.7622862703033856, 2.0930642698492323, 7.539240155901227, 3.883797654083797, 2.8313010334968567, 2.5135434099606107, 4.264192853655134, 5.265415242740086, 3.804513931274414, 2.3883577159472873, 2.523412457534245, 2.056739087615694, 1.5082715238843645, 0.7886833995580673, 2.7126008314745764, 1.9814431965351105, 1.2807287680251258, 2.4267966704709187, 1.6941477784088679, 2.898588691438947, 5.052534597260611, 5.134439962250846, 8.848771486963544, 2.7817306305680956, 4.432309295449938, 8.934647747448512, 4.352453649044037, 3.702606439590454, 2.5690814469541823, 0.9879791225705827, 1.5272512882947922, 1.07657191157341, 0.3400349052889006, 0.2177598008087703, 0.345904178917408, 1.0065928037677492, 2.8314462942736487, 7.434266771589007, 9.319331288337708, 14.807198320116315, 15.080755846840994, 40.248621531895225, 59.85295690808977, 14.035600866590228, 11.267627886363439, 22.28973422731672, 35.08357736042568, 25.47641955103193, 15.836467981338501, 4.932839282921382, 0.6378380081483296, 0.03460044799638646, 0.09321499669126102, 0.02827631841812815, 0.045789242788617096, 0.011101575900933571, 0.0724241476772087, 0.044116056856832335, 0.045812944016818485, 0.031424140757215877, 0.05129804129579237, 0.07703255396336317, 0.037337397025632005, 0.03380036699984755, 0.024829250261453644, 0.011984397457646472, 0.04196430017639484, 0.07248078499521528, 0.06658847510282483, 0.048375082069209645, 0.016508185337962847, 0.0466516302632434, 0.034906311226742606, 0.04550016651462231, 0.020814261864870787, 0.07362702063151769, 0.026584338762664368, 0.07594671472907066, 0.04509497254288622, 0.03404907722558294, 0.02166553832856672, 0.041505956556648016, 0.029082631758813347, 0.027316713838704994, 0.03209069624011006, 0.014283633724387203, 0.031489327616457424, 0.016375309521598474, 0.01642219289871199, 0.04219520903591599, 0.029108100570738316, 0.05091435009879725, 0.03555545210838318, 0.008192670830924596, 0.007378734149304884, 0.006676359650945025, 0.061781448046011586, 0.1774256301245519, 0.171383140076484, 0.06603065824934415, 0.10706457495689392, 0.17891447166247026, 0.19693652460617678, 0.10402131825685501, 0.13544245649661335, 0.12666586387370313, 0.22577088379434176, 0.15321160586816923, 0.16377613826521806, 0.10054860995816332, 0.08448254277131387, 0.08406987134367228, 0.14628621962453636, 0.19095327066523687, 0.16713903924184187, 0.10893949613507305, 0.10273014075521912, 0.14933612596775803, 0.11282628042889492, 0.117135473127876, 0.2006926094847066, 0.17209649751228945, 0.11843800252037388, 0.18984582009060041, 0.12726476602256298, 0.11283818193312202, 0.07655550313315221, 0.14041111059486866, 0.09695270684148584, 0.08180690955902849, 0.12410292854266507, 0.1612857383276735, 0.1311686358281544, 0.1658952302698578, 0.12586819167648042, 0.23731735135827745, 0.12942003751439707, 0.08474090855036463, 0.14671778146709713, 0.1570203314934458, 0.2703374709401812, 0.12149272646222796, 0.18228190525301866, 0.12838844715484551, 0.09167605891291584, 0.09264619435582842, 0.23903773618595942, 0.09535517756428037, 0.22492580914071628, 0.18691730366221496, 0.11743605057043688, 0.3496996323977198, 3.643357413155692, 16.524291004453385, 35.59939077922276, 44.81414038794381, 39.97554343087332, 33.933084215436665, 24.485794033323014, 17.44007921218872, 20.385726315634592, 28.866485595703125, 39.793212277548655, 28.94264653750828, 24.452882153647288, 13.082212482179914, 8.303904175758362, 3.032460502215794, 1.282351172396115, 0.2719356380403042, 0.627364521580083, 1.2441454167876924, 2.857416272163391, 2.463289043733052, 6.269324847630092, 6.90474933385849, 4.5690085887908936, 8.669160553387233, 22.408767291477748, 16.39478874206543, 7.926254817417689, 6.547766523701804, 12.529835905347552, 11.42174674783434, 7.455660275050572, 7.4375810623168945, 4.627977081707545, 3.2643859429018836, 1.289036099399839, 1.4417519675833839, 2.451211988925934, 2.9480103594916205, 1.9923892148903437, 1.8385817195687975, 2.2067261593682423, 3.6210615124021257, 8.901879174368721, 14.836533614567347, 16.901936020169938, 10.77868836266654, 17.38808410508292, 30.85217305592128, 12.416780029024396, 9.88982355594635, 7.064884032521929, 7.593809570584979, 5.873566746711731, 5.239165816988264, 3.9202665771756853, 2.611611370529447, 1.1571651526859827, 2.1228559740952084, 2.6789563511099135, 7.4422650166920254, 9.903137172971453, 17.17932026726859, 18.187276329313004, 49.306487764631, 58.35721124921526, 20.49190694945199, 24.820914336613246, 29.49776417868478, 42.63999693734305, 31.908834253038677, 19.54226016998291, 5.593546092510223, 0.7603189530117171, 0.10804347707224743, 0.2331660741141864, 0.09446517032171999, 0.16734519175120763, 0.14065273691500935, 0.13048087273325237, 0.16051630675792694, 0.09758653997310571, 0.1338767505117825, 0.14234902017882892, 0.19362778429474148, 0.1670132659907852, 0.09772591785128627, 0.1765781534569604, 0.13881632259913854, 0.14699967205524445, 0.1523726244590112, 0.26827108753579004, 0.12024355706359659, 0.08759865377630506, 0.09382111166736909, 0.08030914528561489, 0.10924114566296339, 0.14443594962358475, 0.14822699262627534, 0.12526694179645606, 0.20877350015299662, 0.11943734889583928, 0.08938732636826378, 0.09145617964012281, 0.13524538278579712, 0.13326036930084229, 0.10418122860469989, 0.10064395091363362, 0.10445231013000011, 0.10469139194382088, 0.1261655664337533, 0.18688085276101316, 0.12473106198012829, 0.11612380455647196, 0.1380318682640791, 0.09130400459149055, 0.12806003620581968, 0.07038504138056721, 0.08928454188363892, 0.12567896183047975], [0.060222785254674296, 0.03015832689457706, 0.008789358411117323, 0.06214221154472657, 0.11341351177543402, 0.052608495977308066, 0.05581532372161746, 0.03538261906110814, 0.10583768186292478, 0.04186716788847532, 0.09410228979374681, 0.025563053653708527, 0.05932316317089966, 0.025380420864426663, 0.005266430463442313, 0.042345270447965176, 0.04288308069642101, 0.02721350866236857, 0.013690675542290722, 0.05127691510798676, 0.025778525841555426, 0.00934738221777869, 0.02207378570788673, 0.04061891111944403, 0.02054174693434366, 0.06484341874186482, 0.03064626481916223, 0.024406370274456482, 0.025464423499735336, 0.030299614848835126, 0.04259042515020285, 0.04830675359283175, 0.015065224641667945, 0.0758573313110641, 0.033671777828463485, 0.02700533581498478, 0.026659410180790082, 0.03830329841002822, 0.040108910628727505, 0.022286082351846353, 0.037553639350725074, 0.01456600267972265, 0.00732756158270474, 0.03801861565027918, 0.06680979286985737, 0.075468510389328, 0.015328513192278998, 0.020309601444751024, 0.025516531596492444, 0.014601108385249972, 0.05536054241071854, 0.08771202340722084, 0.018268116882869175, 0.041842669381627014, 0.028530243185481856, 0.13546805083751678, 1.2305171766451426, 7.973575523921421, 21.85827193941389, 33.94464949199131, 42.21666751589094, 34.06934881210327, 27.898505994251796, 15.99675076348441, 10.797161017145429, 5.722232375826154, 12.26229725565229, 25.029254334313528, 19.835752078465053, 15.614380972726003, 11.18296582358224, 8.366067971502032, 3.684987110751016, 1.7923636053289687, 0.6897200441786221, 0.36044941842556, 0.2230148102555956, 0.3056924838040556, 0.4061374882502215, 0.5685542087469782, 1.9931915146963937, 8.189318827220372, 2.3696001853261675, 2.11631315946579, 1.5315163965736116, 5.3620064939771375, 4.753811998026712, 2.681178254740579, 2.1104297723088945, 2.403109175818307, 2.4920346098286763, 1.9538955433028085, 0.6471548367823873, 4.439144585813795, 2.083921960421971, 1.390068443758147, 3.070641939129148, 1.5194960130112511, 2.990726798772812, 4.5767614756311685, 2.5037214798586707, 10.551432762827192, 3.021947009222848, 2.8282716189111983, 10.492539831570216, 1.4591163843870163, 1.8370459505489893, 2.162970530135291, 0.3673037349113396, 1.0548769214323588, 1.4875155176435197, 1.1272751965693064, 1.6045312157699039, 2.2816394652639116, 4.437031030654907, 6.116850537913186, 11.448023097855703, 15.37622799192156, 15.692574262619019, 17.88019027028765, 36.462589808872764, 36.10070330756051, 27.51907876559666, 32.60105548586164, 27.67140759740557, 21.39502685410636, 9.192453707967486, 2.868037462234497, 0.44683357594268663, 0.07145901982273374, 0.053369506927473206, 0.031747347342648675, 0.070754639405225, 0.03516512144623058, 0.05715235322713852, 0.03588260437494942, 0.025905320287815163, 0.020580345398879478, 0.016850545270634548, 0.09319495955216033, 0.059962655284575055, 0.061175970892821036, 0.05308723296704037, 0.010889730482761349, 0.021901851719511405, 0.015065419720485806, 0.044050184677221944, 0.00768776613819812, 0.01117209519725293, 0.06650886258908681, 0.02856091975367495, 0.020820034501541938, 0.021932450256177356, 0.029251288423048596, 0.04466453706845641, 0.007358722455267395, 0.020133017795160413, 0.019932005188560913, 0.03169948687510831, 0.022657849992226278, 0.06909380959612982, 0.042461669737739224, 0.03037507812093411, 0.037972183498953066, 0.1070836146495172, 0.030455762720001594, 0.034807292611471245, 0.03751178391809974, 0.029042686402265514, 0.01477636889155422, 0.016290406131052544, 0.02061169541307858, 0.027918674484161392, 0.003848679887596518, 0.05077981356797474, 0.036988948937505484, 0.023179977600063597, 0.01643591287678906, 0.05000878744093435, 0.02795820084533521, 0.0507706940573241, 0.04510489272485886, 0.010916401149838098, 0.01317890577151307, 0.0711408479671393, 0.028267032666397945, 0.06496086636824266, 0.013249457298245813, 0.005209536150297416, 0.012154829339124262, 0.019719851036955203, 0.005922079768164882, 0.022866294253617525, 0.036990468855947256, 0.003730802663734981, 0.01517971555170204, 0.052347528016460795, 0.023319414850058298, 0.03399760016639318, 0.0265319117544485, 0.036582828765468936, 0.02794288800630186, 0.021214611096573726, 0.058941371871956756, 0.04277919698506594, 0.020050060103780458, 0.017508459610066245, 0.06057563703507185, 0.015154874384669321, 0.03348906531131693, 0.014759824511462023, 0.02276507718488574, 0.008383455370286745, 0.036690566555729935, 0.02546428100738142, 0.02431537363944309, 0.037098973390779326, 0.0805525290114539, 0.021346706597666656, 0.028370897718040005, 0.05652524437755346, 0.0413031933297004, 0.03296715992369822, 0.0695744159498385, 0.04580534103193453, 0.018696995119431188, 0.015820471436849663, 0.04331539571285248, 0.03090188592406256, 0.032355918615524254, 0.03380299632304481, 0.16873882125530923, 1.9593398911612374, 10.978016546794347, 27.225312403270177, 37.6727089200701, 43.59308133806501, 30.470550196511404, 21.93719479015895, 14.545853989464895, 13.10863561289651, 14.07098022529057, 18.024929932185582, 25.469751017434255, 21.38894718033927, 19.797757591520035, 15.893564803259713, 8.355643936565944, 4.562873763697488, 1.0685920140572955, 0.5775043570569584, 0.33446424135140007, 0.18522777860718115, 0.07933531182685069, 0.39744941730584415, 0.15014099063617842, 0.5460335229124341, 0.43254460554037777, 1.2870215560708727, 1.5533987709454127, 0.9006231671997479, 1.4569187994514192, 2.594644303832735, 1.4411868836198534, 1.7433335334062576, 0.9754490235022136, 1.186308394585337, 1.536664143204689, 0.9194144074405942, 2.9904401855809346, 3.2308026935373033, 1.2203073416437422, 3.1715389021805356, 3.0370851797716956, 3.6362446291106085, 4.07778137070792, 3.541979504483087, 3.522198851619448, 2.841865335191999, 3.1512119472026825, 0.8250229667340006, 1.9915098335061754, 1.0976361355611255, 0.8174222345863069, 0.19933927139001234, 0.20548689365386963, 0.28481751680374146, 0.614399183009352, 1.3290099544184548, 3.777273084436144, 7.832534040723528, 9.719078523772103, 14.425679683685303, 16.034661872046335, 17.93400754247393, 11.900774666241237, 37.52648408072335, 42.555357456207275, 24.21689874785287, 31.67712572642735, 30.702324731009348, 26.388447046279907, 13.113587072917394, 4.631580591201782, 0.6493468848722321, 0.020756828964554837, 0.08661452694130795, 0.044395511504262686, 0.010542795527726412, 0.029752427246421576, 0.047344852172370465, 0.0335459604726306, 0.05377029042158808, 0.03394240812797632, 0.02013025785397206, 0.11416348974619593, 0.05151725899694221, 0.028088803569387113, 0.03946357632854155, 0.024254721090463654, 0.00259404319305239, 0.059877980899597914, 0.12326287504817758, 0.025863337629873837, 0.0933940756533827, 0.07017667684704065, 0.02242493097271238, 0.05059861418391977, 0.02129158071641411, 0.04985136392393282, 0.03107072240007775, 0.051507030081536086, 0.025326511257195046, 0.005355405912268907, 0.024775788487334336, 0.06004599974091564, 0.04815795425591724, 0.01692737579079611, 0.058421695471874306, 0.03817942166434867, 0.055496110314769406, 0.033528142143040895, 0.07644539047032595, 0.025875537689509134, 0.027758278983778188, 0.015863843395241668, 0.0567743820803506, 0.009704624119746898, 0.02811464896824743, 0.027168911948267902, 0.06125525092439992, 0.03780862602538296, 0.1953605456011636, 0.07444784444357667, 0.06517835719777004, 0.15632806292601995, 0.16183953146849359, 0.11022033276302473, 0.14589953608810902, 0.07203232763069016, 0.15142925722258432, 0.08913115225732327, 0.22668349982372352, 0.07445589186889784, 0.11909301951527596, 0.11535340946699892, 0.1775322686880827, 0.17707482751991066, 0.10325212417436497, 0.12407286944133894, 0.1054166644545538, 0.17326336061315878, 0.09032644597547394, 0.14584293269685336, 0.0866606401811753, 0.1354538287435259, 0.10133740691734211, 0.12386278142886502, 0.07208539585449866, 0.1613249033689499, 0.12112776961709772, 0.11635184660553932, 0.11142037622630596, 0.10612148591982466, 0.09808022169662373, 0.12324684805103711, 0.18787312880158424, 0.10591007476406437, 0.11861064897051879, 0.11422554855900151, 0.11074610919292484, 0.12681590153702668, 0.11855171141879899, 0.12747610253947123, 0.06406022648194007, 0.10428169249956097, 0.14072969635682447, 0.1592847385576793, 0.16478953031556948, 0.1504481362977198, 0.20907639818532125, 0.13779225040759358, 0.12513835941042217, 0.1765420146818672, 0.13002292944916657, 0.17557179102940218, 0.16037739706890924, 0.32623692282608574, 2.0547673191343034, 11.215937631470815, 30.53631489617484, 44.06847708565848, 52.89577777045113, 43.76467752456665, 35.84420360837664, 23.647023132869176, 18.761286122458323, 13.016898546900068, 19.679203953061783, 33.33595950262887, 28.297626154763357, 22.702123710087367, 15.368685722351074, 10.775698031697955, 4.83010321855545, 2.3123541942664554, 1.0577051639556885, 1.0520726719072886, 0.7199806975466865, 1.469177593077932, 1.4816582947969437, 1.4838882322822298, 4.781611740589142, 15.888061829975673, 8.161250710487366, 4.781442378248487, 6.776349663734436, 11.048671041216169, 10.7964540379388, 8.07924199104309, 7.303381817681449, 7.417177677154541, 5.935446969100407, 7.324163011142185, 3.5696815380028317, 10.174073491777692, 6.007310015814645, 4.952767585005079, 6.383311348302024, 7.659543003354754, 7.501991731779916, 12.14099039350237, 9.007190414837428, 17.266721657344274, 10.497555562428065, 6.144053169659205, 21.58731303896223, 7.480474029268537, 3.5012550268854414, 5.684986991541726, 1.497694194316864, 2.3427940351622443, 2.2557893437998633, 1.9173755943775177, 2.289559326001576, 3.3740107119083405, 7.255147423063006, 9.358161296163287, 15.782463107790266, 22.847136088779994, 21.558116708483013, 24.472799164908274, 42.457401752471924, 43.51265593937465, 34.22444302695138, 41.50308404650007, 36.95505380630493, 32.50018501281738, 16.073726381574357, 5.002509304455348, 0.7217331092272485, 0.23209930849926813, 0.1745136020971196, 0.16926019399293832, 0.1302986725100449, 0.09146776223289114, 0.142018641478249, 0.19551170963261807, 0.14169966216598237, 0.26581362368805067, 0.0897416505696518, 0.17695516108402184, 0.1458363916192736, 0.093924371126507, 0.20767682471445628, 0.129648500255176, 0.1503346445305007, 0.23090394692761557, 0.19373664845313343, 0.13390470615455083, 0.2986609068300043, 0.11886363396687166, 0.19304617121815681, 0.18263049583349908, 0.16003960876592568, 0.13799674729151384, 0.2098853476345539, 0.21677531435021333, 0.10859812516719103, 0.12317918453897748, 0.1056976525911263, 0.09485234240336077, 0.14457846911890165, 0.12101368073906217, 0.11493520119360515, 0.1823091959314687, 0.2076142095029354, 0.2060990815183946, 0.15049329958856106, 0.10176682458924395, 0.07790815590747766, 0.11760321445763111, 0.14905302758727754, 0.16531410573848657, 0.14333324879407883, 0.09460164407002074, 0.20401934454483645, 0.1219067278185061], [0.00661491448824693, 0.03732987207227519, 0.02123737085743674, 0.05747178037251745, 0.021712284302338958, 0.04446255415678024, 0.03171749858717833, 0.028953160491905043, 0.018578918151823536, 0.07343149398054395, 0.0665039432102016, 0.015712999971583486, 0.0809813156457884, 0.02102362214853721, 0.057564868591725826, 0.012668986704998782, 0.047458221803286245, 0.04411034019930022, 0.012328994859542166, 0.015833984461746047, 0.03211984610451119, 0.028216510645246932, 0.012467846024914511, 0.04719082133046218, 0.05727468630565064, 0.08705557470342942, 0.014375542989000678, 0.07286865596792527, 0.07085050961800984, 0.0591737429744431, 0.03734143430899296, 0.012279410913054432, 0.05121499878753509, 0.027165286874930774, 0.011350387906921762, 0.007397951957370553, 0.013126584784393864, 0.04832436157656567, 0.023264841974845955, 0.059932345125292025, 0.007311085056114409, 0.021308613641719733, 0.012438780129221933, 0.01366035605315119, 0.03742418843986733, 0.07344223518988915, 0.0708509303097214, 0.10676042163478476, 0.01624512579292059, 0.02928627368861011, 0.03469451330602169, 0.04334496966164027, 0.04604298095884068, 0.03071924126041787, 0.0604097895058138, 0.07312475544001375, 0.02084876537056906, 0.3307194880076817, 3.9892209342547824, 14.770374604633876, 25.230218819209508, 38.19966377530779, 39.93161344528198, 36.62421533039638, 28.664824553898402, 20.758443321500504, 13.203871096883502, 10.771811383111135, 26.058121000017437, 38.05125372750418, 24.038783414023264, 20.091650758470806, 14.239217826298304, 9.268737980297633, 7.186857921736581, 4.511171783719744, 2.930709345000131, 0.9674745542662484, 0.7123784997633525, 0.6687520635979516, 0.12749947128551348, 0.38355220588190214, 0.8559368593352181, 0.7577447539993695, 0.4677689054182598, 0.8853434813874108, 2.2458169417721883, 1.0884378062827247, 1.0511187059538705, 1.0182087804589952, 1.0889484988791602, 1.6365925925118583, 0.7647183569414275, 2.3573509454727173, 3.78474109513419, 1.0394409554345267, 4.030024664742606, 1.6921273725373405, 3.324736910206931, 3.188034577029092, 1.802514054945537, 3.8975381510598317, 1.0097967918430055, 2.1049298388617377, 0.4829477880682264, 1.224315692271505, 1.4804239038910185, 0.7510112981711115, 0.49804986055408207, 0.7000951703105653, 1.8454424142837524, 3.564983470099313, 6.603978753089905, 10.564304300716945, 10.111061147281102, 9.773059947150093, 14.398771047592163, 14.621943712234497, 15.628150565283638, 14.620951856885638, 21.55483889579773, 28.47930244037083, 30.61641025543213, 29.459170409611293, 18.61929621015276, 7.488612106868199, 1.5480895872626985, 0.09780728777072259, 0.05619502513270293, 0.03486486291512847, 0.008368410552585763, 0.012790791374365134, 0.027112013394279138, 0.022825429482119422, 0.02182713653227048, 0.02805662404612771, 0.015588726282918026, 0.05293354817799159, 0.02471049645516489, 0.008919028149518584, 0.0042134272350397494, 0.02979979238339833, 0.024924102671710507, 0.017303362222654477, 0.08820833106126104, 0.019336996134370565, 0.08181144895830325, 0.014217771722802093, 0.01689930140439953, 0.019916571909561753, 0.005213239679246077, 0.05005766910367778, 0.05481130223987358, 0.014769050891378095, 0.04411151406488248, 0.07428329970155444, 0.029420308103518825, 0.04711388224469764, 0.07104016015572207, 0.0299525238307459, 0.02547971428638058, 0.04557622689753771, 0.03572601206334574, 0.03654667641967535, 0.05266908236912318, 0.04897700709157756, 0.02203661047055253, 0.03215241578540631, 0.029379348337118114, 0.006390902513105954, 0.03830160546515669, 0.01488503797112831, 0.03171527638499226, 0.026419419130044322, 0.0285203806789858, 0.015414280018636158, 0.01743759510905615, 0.022990757932088206, 0.0379456629577492, 0.04297151416540146, 0.02480935222203178, 0.04644068729664598, 0.025777852395549417, 0.03880389440538628, 0.039340062599096975, 0.052934379383389435, 0.017155694342883568, 0.033100617583841085, 0.059406738329146586, 0.06289971446884529, 0.03531977654035602, 0.01636148606693106, 0.018488538983677114, 0.04102800666753735, 0.008154236911130803, 0.020405880474884595, 0.029826167039573193, 0.09606095576392752, 0.006097210080562425, 0.029059514070727994, 0.00942726360101785, 0.027322676465181366, 0.02150691719725728, 0.017281727133584873, 0.022445349787761058, 0.026679706859535406, 0.03394590936867254, 0.03391400804477079, 0.050890296032386165, 0.006138391643097358, 0.025422164338773916, 0.02926588031862463, 0.024406821500243883, 0.06600355077534914, 0.04468399066744106, 0.06164164947611945, 0.027939483456845795, 0.019285039011655108, 0.02828042864400361, 0.01311769088663693, 0.01551063877663442, 0.024949479881407957, 0.021573054005524943, 0.06837482031966959, 0.014327920008716839, 0.045532892258571725, 0.0638859583331006, 0.03484237287193537, 0.08989038544573955, 0.008584616406421577, 0.04672560075830136, 0.020967933083219186, 0.03393521565677864, 0.6041334367224148, 5.784412239279066, 19.18723848887852, 32.689638069697786, 42.71807384490967, 44.32906927381243, 35.65071364811489, 26.84391709736415, 13.674211161477224, 12.944727608135768, 15.304201228278023, 24.076593773705618, 29.59429897580828, 23.943382910319738, 23.093168326786586, 17.516691786902292, 15.908743143081665, 6.941931750093188, 4.574257518563952, 2.3484572512762885, 0.8515175336173603, 0.28317209652491976, 0.2789330711322171, 0.1666480377316475, 0.27926172635384966, 0.3254221922584942, 0.028097137675753663, 0.46044968387910296, 0.14384601770767144, 0.2134233242166894, 0.4883303620985576, 0.6428895656551633, 0.8945570098502296, 0.4339300926242556, 0.5732885918446949, 0.9232467732259205, 1.6522340731961387, 1.0892612763813563, 1.0643205004079002, 1.4928473915372575, 1.0738182536193301, 0.8952510154673031, 0.6073005124926567, 0.3210792424423354, 0.8739645034074783, 0.49556088554007666, 0.41665980219841003, 0.5435318457228797, 0.25225261279514855, 0.22776132555944578, 0.18276907982570784, 0.2897210179695061, 0.42672622203826904, 2.2365328456674303, 3.9876905935151234, 8.581872940063477, 12.109986662864685, 14.876008067812238, 14.23364884512765, 16.723280463899883, 16.555557898112706, 10.53775783947536, 13.342095954077584, 26.56222496713911, 30.14916127068656, 31.40257808140346, 33.96214853014265, 23.438604967934744, 10.677726694515773, 2.248460514204843, 0.2781202947454793, 0.05123420132856284, 0.06862152886709996, 0.056825709861836264, 0.013826655656365412, 0.0679663558091436, 0.012431389186531305, 0.020544878373454725, 0.06465357821434736, 0.002757273061433807, 0.09811202463294778, 0.02434207059975181, 0.03929889927219067, 0.06483003124594688, 0.03782538244766848, 0.07867569436452218, 0.04888980855633106, 0.054624949382351976, 0.009196102835371025, 0.0335891356558672, 0.022254790013123835, 0.08872788532504014, 0.01186740699423743, 0.05116844789258071, 0.05577036738395691, 0.04175118589773774, 0.008933702317465628, 0.050883598891752105, 0.039994156786373684, 0.029230671136506965, 0.02406063293372946, 0.10871337434010846, 0.07654186457927738, 0.037899013675217114, 0.07750265659498316, 0.03648140135088137, 0.022829724608787468, 0.0377824990344899, 0.046074946743569205, 0.03200410160103014, 0.037271290751440186, 0.03350879032430904, 0.04191721663145082, 0.011053951224312186, 0.011134290618688931, 0.03347180677311761, 0.026049198549506918, 0.04292858325477157, 0.026724373123475482, 0.15901222532348974, 0.11176448847566332, 0.0951649434864521, 0.10005393757351808, 0.10459595599344798, 0.10952379621033158, 0.0739223529983844, 0.06764878106436559, 0.09707757764096771, 0.12020652262227875, 0.128749264936362, 0.17454277910292149, 0.2508087988410677, 0.11291247473231383, 0.1443640791944095, 0.11128185330224888, 0.11212301280881677, 0.11435464663164956, 0.08961257285305432, 0.08079119691891329, 0.15902734308370522, 0.18403992163283484, 0.18993381251181873, 0.11624742006616932, 0.12310265935957432, 0.16228440616812023, 0.12581191398203373, 0.13947317163859094, 0.21237717249563762, 0.107506626950843, 0.08912770529942853, 0.12071004988891737, 0.16864785685070924, 0.11154154222458601, 0.1578730871634824, 0.10587548983416387, 0.15486731273787363, 0.20661835079746588, 0.15514496926750454, 0.11446599422820977, 0.12328616237001759, 0.11259494069963694, 0.11132656875997782, 0.07179137306021792, 0.0800888521064605, 0.14039810986391135, 0.19258646374302252, 0.275958102196455, 0.0711884946961488, 0.13523297916565621, 0.21607347843902452, 0.10127715979303632, 0.151080598788602, 0.1320834503109966, 0.20213913757886204, 0.12119508029094764, 0.11036323902330228, 0.765733716743333, 5.853939822741917, 20.49143099784851, 36.49984952381679, 49.23639781134469, 53.211924280439106, 47.37935277393886, 38.898701190948486, 28.254078320094518, 20.3494028704507, 17.05764515059335, 33.52349485669817, 49.236825125558035, 33.506527355739046, 27.758207968303136, 17.709259373801096, 13.97745052405766, 10.098705513136727, 5.960311532020569, 3.5889139345714023, 1.3371661624738147, 1.4232257902622223, 1.0478905077491487, 0.4782029283898217, 0.9112494055713926, 2.0319524747984747, 2.1036355197429657, 1.8359021033559526, 3.2413889254842485, 6.322009997708457, 4.3179797274725775, 2.9567611813545227, 4.026606585298266, 3.1939809322357178, 5.177324243954249, 3.8265931350844244, 7.318966627120972, 10.359988178525652, 6.893426809992109, 11.616571630750384, 5.578439840248652, 8.715878503663198, 7.360133835247584, 6.0767368503979275, 9.21344769001007, 4.05095785004752, 4.1066567812647135, 1.5721573872225625, 2.524061462708882, 2.768956584589822, 1.6416656460080827, 0.800455167889595, 1.3101325673716409, 2.627819997923715, 5.338948896953037, 9.467587607247488, 14.06734892300197, 15.507745231900897, 16.318188326699392, 22.92739646775382, 20.94353117261614, 21.46890878677368, 22.831101383481705, 30.989657061440603, 35.69740554264614, 38.7468934740339, 40.670693329402376, 27.262111800057546, 12.215998802866254, 2.337447396346501, 0.3677827806345054, 0.17298616548734053, 0.1510526974286352, 0.11303286041532244, 0.07010499640767064, 0.20004975183733872, 0.14027910839234078, 0.09607762736933571, 0.15560048339622362, 0.11689832513885838, 0.21624957184706414, 0.1501890851983002, 0.16811710675912245, 0.060605675780347416, 0.08315853774547577, 0.1768066840512412, 0.12101680200014796, 0.2544380926660129, 0.11747229791113309, 0.19430367302681717, 0.0886763913024749, 0.16864909178444318, 0.12247559800744057, 0.12250925334436552, 0.15824793704918452, 0.1374265607446432, 0.10240034559475523, 0.16455896411623272, 0.139604563159602, 0.06857575489474194, 0.11853180320135184, 0.2410655788012913, 0.16307453305593558, 0.11130864865013532, 0.21280308892684324, 0.09627347293176822, 0.1750840600579977, 0.0777955258797322, 0.12836012510316713, 0.08350590017757245, 0.10785223197724138, 0.07983794342726469, 0.15300690542374337, 0.15344317629933357, 0.08969708438962698, 0.13671040774456092, 0.08103848222110953, 0.10178732313215733, 0.09487575186150414], [0.02380935614928603, 0.05039544722863606, 0.0271772223059088, 0.023210688095007623, 0.014927407394030263, 0.03579885958294783, 0.030724523655538048, 0.08294248541018792, 0.021776219264471104, 0.02181847333641989, 0.018312557533915554, 0.006681909643313182, 0.01619573013990053, 0.04588681273162365, 0.03665972035378218, 0.033110809179821184, 0.03572023094498685, 0.01394827542493918, 0.011760215424666447, 0.08945571591279336, 0.056359793791281323, 0.06110762884574277, 0.02112494269385934, 0.030342589864241223, 0.021531475075919713, 0.018986658326217105, 0.03745192355875458, 0.011373659961723855, 0.002127922501780891, 0.04100258196038859, 0.04470816008480532, 0.009219693801631885, 0.017602643663329736, 0.026349524934110895, 0.03496019708524857, 0.024184782789754014, 0.011102968594059348, 0.02412834224690284, 0.04475853791726487, 0.023912325534703474, 0.041624768038413355, 0.020988406181069355, 0.04888339640040483, 0.035873267733092816, 0.037283670622855425, 0.033937855158001184, 0.018258542753756046, 0.018517692240753343, 0.02451863219695432, 0.0486552864978356, 0.02635253932593124, 0.05136106702099953, 0.041929192774529965, 0.037507824666265926, 0.03119377133303455, 0.037249170509832244, 0.09841518729392972, 0.042464102285781076, 0.04882917805973973, 1.0100750454834528, 7.749051434653146, 19.44593381881714, 29.54550177710397, 35.9730475289481, 34.218696866716655, 41.212652819497244, 25.952652556555613, 14.284699865749904, 12.66949817112514, 23.27532056399754, 48.94904463631766, 39.350518226623535, 35.85757194246565, 18.910319771085465, 19.286543880190166, 15.667981113706317, 11.879012039729528, 9.714107956205096, 7.89925411769322, 3.568217856543405, 2.1597472173827033, 0.8109117182237762, 0.8275965143527303, 0.5826478696295193, 0.385184679712568, 0.30217305836933, 0.3739014837358679, 0.20167005274977, 0.7086761955704007, 0.2501999357981341, 0.14292965616498673, 0.1694219431706837, 0.24206264529909405, 0.6614438614674977, 0.43550461956432884, 0.1191551461815834, 0.9851636907884053, 1.1017965865986687, 0.8455825777990478, 0.7673423875655446, 0.6515610803450856, 0.1381230362291847, 0.5438510285956519, 0.9507708677223751, 0.5586294127362115, 1.1583382040262222, 1.3900611698627472, 1.5996825673750468, 3.6833186745643616, 6.771943203040531, 9.063819101878575, 11.698202541896276, 14.176355736596243, 12.607500263622828, 15.08121269089835, 12.19060400554112, 14.119454332760402, 14.851008449281965, 19.92238221849714, 21.608967099870952, 24.97133415085929, 31.72277886526925, 26.85327284676688, 17.24514923776899, 4.776014532361712, 0.8181488641670772, 0.042392469343862364, 0.07007892030690398, 0.015924707986414433, 0.0159854453522712, 0.01751493283414415, 0.0151356073828148, 0.039211544673889875, 0.01958476998178022, 0.027952857382063354, 0.06068464368581772, 0.025727165829656378, 0.020748823947672333, 0.01961871878510075, 0.023173587496525476, 0.03494827522497092, 0.038246437175465484, 0.03402132175064512, 0.045255290011742284, 0.03587729823110359, 0.03505719027348927, 0.018449982927579964, 0.02917813217001302, 0.09225272546921458, 0.03518876839163048, 0.05435136067015784, 0.024233369289764335, 0.032220367674848864, 0.009714788574326252, 0.05630864242890051, 0.016622077440842986, 0.06912423510636602, 0.02155732217111758, 0.05936218571982213, 0.057710034373615465, 0.03914841716842992, 0.046176567540637085, 0.021766935209078447, 0.04688768920355609, 0.055939041011567624, 0.04898086117048349, 0.012428953245814358, 0.0514523537297334, 0.017058738474068896, 0.03506501717492938, 0.06912116812808172, 0.028139754763937423, 0.04487969373751964, 0.007766818012376981, 0.036617325485817025, 0.030764893096472536, 0.06262181366660766, 0.03470257090936814, 0.07562859037092753, 0.0131919819894912, 0.01330781470252467, 0.06772069899099213, 0.028002476951639568, 0.00669895317072847, 0.06143521198204585, 0.02853846363723278, 0.05170308259714927, 0.03811448925573911, 0.030086755020810024, 0.0076869629223697954, 0.04370831159342613, 0.02643160052996661, 0.03207382446687136, 0.02471101383811661, 0.043973896985075304, 0.03087201002719147, 0.038091242646000216, 0.06662698875048331, 0.02372144515226994, 0.04962277226150036, 0.011578111044530357, 0.05654680822044611, 0.039823990381721935, 0.04504917482180255, 0.023289866346333708, 0.0376347514268543, 0.04900663871584194, 0.04344758451251047, 0.0642619210162333, 0.05668877810239792, 0.01545552646608225, 0.0459348326548934, 0.06513904287878956, 0.041673517386828146, 0.034344351916973076, 0.03233985769163285, 0.0425217234795647, 0.010704017144494822, 0.054499250770147355, 0.027514452513839518, 0.022989792716024176, 0.08920777243162904, 0.01842192211188376, 0.01288049794467432, 0.018394680627222573, 0.00430737210470917, 0.011298138165979512, 0.03520126361399889, 0.027236880801085914, 0.032876626388835054, 0.039751909606690915, 0.0035365660774654573, 0.01834652669328664, 0.030519680718758276, 0.11713398035083498, 1.5314323667969023, 9.752189295632498, 24.051955461502075, 34.40886211395264, 41.684220109667095, 36.72003793716431, 38.44280208860125, 21.100506612232753, 12.187093428203038, 18.657179525920323, 31.30836398260934, 45.0118340083531, 35.216343539101736, 30.4093747820173, 21.078576360430034, 29.54917390005929, 21.30446924482073, 16.067509480885096, 10.665614247322083, 8.098862835339137, 4.07035939182554, 2.103071412869862, 0.9514154217072895, 0.8049744282449994, 0.5115328399198396, 0.2753657139837742, 0.10515952003853661, 0.13412660067634924, 0.07167608317519937, 0.20926066115498543, 0.03627457709184714, 0.27987658764634815, 0.0319265111216477, 0.05244168832099863, 0.16714247262903623, 0.4402773806027004, 0.36187284918768065, 0.5402315056749752, 0.28122364250676973, 0.2512832305261067, 0.19527226819523744, 0.44161841007215635, 0.21058660000562668, 0.08196786485080208, 0.10826275244887386, 0.7422754583614213, 0.46240310477358954, 1.4165279439517429, 1.6396704273564475, 5.059589624404907, 7.885404620851789, 11.888136761529104, 16.32286099025181, 20.84957242012024, 18.026257038116455, 18.12009593418666, 14.02663334778377, 15.034301928111486, 14.91237667628697, 19.436225448335918, 23.6641070161547, 27.087658166885376, 35.61222062792097, 30.293864454541886, 21.23054736001151, 7.287615486553737, 1.3599665675844466, 0.0825802291344319, 0.039595999222780974, 0.0343933387526444, 0.050440881933484755, 0.024560597891520177, 0.08424151356198958, 0.054318054778767486, 0.054163864481129816, 0.008168572659737297, 0.037986717719052515, 0.0093829586569752, 0.03436589540381517, 0.014356430353862899, 0.04582138159977538, 0.026171328067513447, 0.04985869210213423, 0.06637977130178895, 0.04183176871655243, 0.02535723871551454, 0.020825644289808612, 0.0561391138471663, 0.010093422140926123, 0.024143429473042488, 0.03860045264342001, 0.040493928361684084, 0.04258121742999979, 0.04168802107285176, 0.03104967424379928, 0.0898128899612597, 0.03233683821079986, 0.09309922504637923, 0.02502974039608879, 0.018706788076087832, 0.04187481837081058, 0.050415233309779844, 0.009760649059899151, 0.009340501872689595, 0.04142196070668953, 0.01802500117836254, 0.013064694757174169, 0.05185742895784123, 0.042787749918976, 0.03043819884104388, 0.045873330240803104, 0.05740345868148974, 0.008878476352297833, 0.02713415229560009, 0.05899587859000478, 0.036297162129942856, 0.024014738521405628, 0.12475695487643991, 0.12403784346367631, 0.28921108533229145, 0.10412837751209736, 0.11423758577023234, 0.12379545718431473, 0.14078814536333084, 0.123627438342997, 0.17666045975472244, 0.11259617563337088, 0.14496735110878944, 0.0943264506225075, 0.10532817670277186, 0.17542824016085692, 0.15275234622614725, 0.08077239471354655, 0.08593358990869351, 0.08314703657690968, 0.12128588184714317, 0.1695894191839865, 0.17894333654216357, 0.1606608075754983, 0.1124101077605571, 0.21684839257172175, 0.20076636624123367, 0.2038423011877707, 0.1013662310849343, 0.15376663394272327, 0.06089481312249388, 0.1596438464309488, 0.16286660278482096, 0.07933046030146734, 0.12508098248924526, 0.1645262451576335, 0.11204732901283673, 0.1212130750396422, 0.17419228862438882, 0.1267003605940512, 0.14363430121115275, 0.07198701506214482, 0.2300299938235964, 0.12157421851796762, 0.11232601013034582, 0.1288757710052388, 0.11707585704113756, 0.18720611530755246, 0.06875247934034892, 0.0964691217190453, 0.10572429187595844, 0.11838477823351111, 0.16637791294072354, 0.10823966868753944, 0.08498723033283438, 0.10057266402457442, 0.1251238930438246, 0.15066426327185972, 0.15167419479361602, 0.13985035568475723, 0.15990448530231202, 1.9645679763385226, 11.283056361334664, 28.415191411972046, 40.21783753803798, 47.78876495361328, 45.38408374786377, 52.22818442753383, 35.33901398522513, 20.912908724376134, 19.330041340419225, 31.160162380763463, 56.30630104882376, 49.37970788138253, 43.77368238994053, 25.245275565556117, 28.228984900883265, 21.305426359176636, 15.58854409626552, 13.150356071335928, 9.988505346434456, 4.826241757188525, 2.9890870239053453, 1.3479293563536234, 1.7118522226810455, 1.1408767295735223, 0.9853987353188651, 0.7465857299310821, 0.6306125330073493, 0.7614950984716415, 1.5899675743920463, 0.8275165015033313, 1.1579876456941878, 0.8640262995447431, 1.4783796135868346, 1.869472324848175, 2.53437345794269, 1.6378146069390433, 2.360385788338525, 3.3076593237263814, 2.6171931624412537, 1.6494043107543672, 1.9115918704441615, 0.9666698660169328, 1.2657184877565928, 2.2872792312077115, 1.5605565011501312, 1.732663597379412, 2.064308498586927, 2.466246370758329, 5.5176795806203565, 8.970776643071856, 12.135950343949453, 16.62292242050171, 21.288504021508352, 18.902595111301967, 22.085069826671056, 19.5986830166408, 22.21091386250087, 22.452709436416626, 30.01979970932007, 29.434066568102153, 34.81826387132917, 41.10084935597011, 34.78237989970616, 23.026507309504918, 7.725043671471732, 1.4848060458898544, 0.16111803161246435, 0.11940342214490686, 0.13161980733275414, 0.07275155439440693, 0.13336635647075518, 0.19556494749018125, 0.18051559717527457, 0.19439740585429327, 0.0769707937059658, 0.16227399744093418, 0.07550594516630683, 0.1516605969518423, 0.11029709542968444, 0.14680804019527777, 0.1545668981437172, 0.23253153530614717, 0.1563728598079511, 0.1330748035439423, 0.10374664728130613, 0.1056256125281964, 0.1831592238907303, 0.07607136161199637, 0.18249187112918921, 0.19859163436506475, 0.11453329133135931, 0.07089240915541138, 0.16735984810761043, 0.09750512255621807, 0.20300308907670633, 0.12727389910391398, 0.26998818825398174, 0.10223962100488798, 0.1548972497028964, 0.1782498737531049, 0.08742572234145232, 0.17739608670983995, 0.10590058205915348, 0.14076922780701093, 0.1090459514941488, 0.07579354901931115, 0.12401093276483671, 0.15137125604919024, 0.1088254072570375, 0.17563403983201298, 0.14555375464260578, 0.12879182265273162, 0.08774471522441932, 0.10124974019293274, 0.08839411394936697, 0.08034866316510098], [0.04457059050244944, 0.048803485331258604, 0.026606294459530284, 0.07027696432279688, 0.03997304756194353, 0.047140009235590696, 0.12674990722111293, 0.032583221061421294, 0.04614452711705651, 0.011049365175754895, 0.08380252854632479, 0.03875181684270501, 0.0596952514190759, 0.022583450323769023, 0.0157719307379531, 0.04134840751066804, 0.06913277107690062, 0.022413512924686074, 0.06250720231660775, 0.04288550306643758, 0.03510048420035413, 0.05795663435544286, 0.016971782515091554, 0.025680667521165948, 0.013585566227058215, 0.041621829981782606, 0.02757179381192795, 0.07177905086427927, 0.016408216773665378, 0.04474796973434942, 0.019140680686437657, 0.0735708854294249, 0.0072540041458393845, 0.028966656553425958, 0.045711384287902286, 0.05566744379965322, 0.012147548658374165, 0.030663150163101296, 0.01204991849538471, 0.018718151841312647, 0.04851207828947476, 0.07026758696883917, 0.0642353156581521, 0.019041214238053987, 0.026284751981230717, 0.0469934626349381, 0.09046627168676682, 0.013391427180197622, 0.01728931994044355, 0.061490431161863465, 0.07646154638911996, 0.02312264308732535, 0.01852124267523842, 0.020981278170698454, 0.08498152385332755, 0.06718593875744513, 0.02082207010659788, 0.009344181228828217, 0.0234733371263636, 0.04653153974296791, 0.11568575591913291, 1.7329541189329964, 10.297162566866193, 25.32282441002982, 38.37615149361746, 35.92121049336025, 37.579707281930105, 31.934518269130162, 18.612023183277675, 9.480408770697457, 16.916859013693674, 32.305093492780415, 51.37854828153338, 46.771656376974924, 16.146718944822037, 20.00747333254133, 22.1585122857775, 21.707080875124248, 16.814717020307267, 14.439241698810033, 10.24890124797821, 8.475252832685198, 7.658178550856454, 4.313262769154139, 4.175488676343646, 3.0625963594232286, 2.2350559192044392, 1.2054500303098132, 0.6307834152664457, 0.7476382191692079, 0.2726527138480118, 0.47736045931066784, 0.4565952249935695, 0.33035731315612793, 0.43331069871783257, 0.6054477861949376, 0.5083228807364191, 0.4913958747472082, 0.3629766899560179, 0.7061938430581773, 0.7860886816467557, 1.7299888666187013, 2.058271599667413, 2.5402090762342726, 3.8675692677497864, 5.693591032709394, 7.977114762578692, 10.781236614499774, 13.848769886153084, 11.219241499900818, 15.571455001831055, 15.507286650793892, 13.79748957497733, 13.824523278645106, 11.400335005351476, 13.54059556552342, 17.366367510386876, 24.82358591897147, 25.095448085239955, 25.654637370790752, 25.063298770359584, 16.445988280432566, 10.89763457434518, 2.7397020629474094, 0.1978771641318287, 0.010341016176555837, 0.029115092874105488, 0.0285397596391184, 0.03345985098608902, 0.04620050286341991, 0.04135918943211436, 0.03222246774073158, 0.05246116227603384, 0.03876334854534694, 0.0011395481435881394, 0.0123537274609719, 0.02185583347454667, 0.06263366767338344, 0.06141518841364554, 0.04977063522008913, 0.09623453859239817, 0.0029309767539546427, 0.0050765250510136995, 0.03458536077024681, 0.056620731218052764, 0.01268123256574784, 0.07843674147235495, 0.029217273462563753, 0.013961522124840744, 0.03799696359783411, 0.020632199045004587, 0.05290437117218971, 0.027080303756520152, 0.022893679926970174, 0.005683615421211081, 0.0821397038442748, 0.05381744521270905, 0.023996105949793543, 0.011228853803394096, 0.060298774391412735, 0.04672127849023257, 0.02947343061012881, 0.04735149163752794, 0.0400254745701594, 0.032154349610209465, 0.009101477734345411, 0.04907492308744362, 0.022651811030560305, 0.09172781756413834, 0.024230546584086757, 0.03085429347785456, 0.04808622292642083, 0.019846925378910134, 0.03735872677394322, 0.10059758661580936, 0.04354407897751246, 0.027540856007752672, 0.04396503871040685, 0.054604447446763515, 0.06246718232120786, 0.03779612401766436, 0.01893770880997181, 0.06771174232874598, 0.02668220895741667, 0.02119686401316098, 0.007781563426500985, 0.02367562537879816, 0.04393321881070733, 0.05093535754297461, 0.018378110802067176, 0.03697966657845037, 0.02586809585669211, 0.016449008602648973, 0.023090103940506066, 0.014065642475283571, 0.00824940059932747, 0.033819002964134724, 0.03265806008130312, 0.03417641789253269, 0.04226095229387283, 0.03377761572067227, 0.04444556703258838, 0.05119324156216212, 0.052214718357260735, 0.015124248706602623, 0.07198008043425423, 0.0712022011035255, 0.11255416753036634, 0.03748963653509106, 0.014250833341585738, 0.01544194049867136, 0.04179811677230256, 0.03592271597257682, 0.030633362475782633, 0.0033704859379213303, 0.0232441110336887, 0.023446382322747792, 0.027121438245688165, 0.027037649348910366, 0.020568072396729673, 0.031326821872166226, 0.01199413019432021, 0.033278576963182004, 0.013426928132373308, 0.07148618836488042, 0.05714910304439919, 0.08370794076472521, 0.03313657654715436, 0.046267972992999215, 0.03700326941907406, 0.05125445559886949, 0.024426973990297744, 0.05246724194980093, 0.015627837041392922, 0.04653582808428577, 0.02171953784168831, 0.30094496426837786, 3.029822358063289, 14.057373915399824, 29.854310989379883, 41.719645500183105, 41.484435081481934, 37.92990691321236, 30.103591510227748, 15.66155924115862, 13.133175781794957, 24.967418840953282, 39.238096373421804, 46.35290929249355, 34.49739606039864, 19.02987047604152, 29.446024417877197, 26.48847505024501, 28.66474986076355, 24.289319821766444, 18.173650911876134, 15.950639043535505, 8.96554638658251, 6.928801391805921, 4.553352126053401, 2.8227584404604773, 2.6645787911755696, 1.3533860806907927, 1.0700960819210326, 0.8611294435603278, 0.2997775583394936, 0.1792121042630502, 0.2991361256156649, 0.1708133877920253, 0.21809724984424456, 0.522294893860817, 0.30862473217504366, 0.3168724338923182, 0.4634207987359592, 0.2403302096894809, 0.5329228149993079, 0.9838527611323765, 1.185279735497066, 1.620475811617715, 2.7951499904905046, 3.9536448546818326, 6.040406457015446, 7.657135452542986, 13.471619929586138, 15.876739740371704, 16.84673431941441, 17.2280045577458, 15.867415257862636, 14.936744008745466, 11.653797473226275, 9.649364641734532, 13.071806686265127, 18.872165475572857, 25.63138175010681, 28.177959067480906, 29.504493509020122, 30.744041715349468, 22.079542534691946, 14.204363056591578, 4.028187734740121, 0.409879988857678, 0.03266074029462678, 0.06445528314049755, 0.02783793899496751, 0.010607236846616226, 0.07462694376174893, 0.04655989232872214, 0.03369710075535944, 0.05407849120508347, 0.014518683343859655, 0.02266815354648445, 0.09059950203767844, 0.01021657370230449, 0.045843026866870265, 0.03777832265145012, 0.05064591486006975, 0.04372211978105562, 0.04117614782548376, 0.04838614558268871, 0.03320222820288368, 0.013768251602804022, 0.016706020704337528, 0.07210683077573776, 0.03412461852920907, 0.0569290609232017, 0.045750915738088746, 0.024771917445052947, 0.044442242210997004, 0.020646063211773123, 0.04865790903568268, 0.030938642166022743, 0.025089268273274814, 0.02870837559125253, 0.03251833615026303, 0.057031194014208655, 0.03215288058189409, 0.056366233088608296, 0.014413837809115648, 0.044651617761701345, 0.011854124671247388, 0.01796440630485969, 0.039376598317176104, 0.01123143223646496, 0.07739604517285313, 0.024526445527694056, 0.034599776246718, 0.07811649329960346, 0.018301590711676648, 0.034341994007783275, 0.024926167114504745, 0.029012735866542374, 0.019340602547994683, 0.11510996467300824, 0.14041686457182678, 0.12132189848593303, 0.2472990086036069, 0.18205288611352444, 0.1014176911807486, 0.20113669708371162, 0.12153326214424201, 0.09549253340810537, 0.09305260969059807, 0.2293671736759799, 0.13690168676631792, 0.16189015018088476, 0.07815303919570786, 0.10103998466261796, 0.10299952594297272, 0.2110113086444991, 0.12319762712078434, 0.1116188137925097, 0.13716338415231022, 0.13167134885277065, 0.0904774810852749, 0.14590664713510446, 0.13262808322906494, 0.08391490073076316, 0.0786797045064824, 0.0998603922447988, 0.1431477101785796, 0.07957506539033991, 0.06914569716900587, 0.2419814925108637, 0.2246434028659548, 0.0848944949518357, 0.08812628260680608, 0.1357307117432356, 0.13742409087717533, 0.09525036425994975, 0.1564137347574745, 0.08243388948696, 0.1359980952526842, 0.10709164171878781, 0.12077392717557293, 0.1304224780095475, 0.1842344711933817, 0.10253529263926403, 0.10053368897310325, 0.14850430988839694, 0.11328267665313822, 0.146981025912932, 0.1932697892189026, 0.13865306707365171, 0.11432161554694176, 0.13654062471219472, 0.19811754194753511, 0.22007302168224538, 0.14789949091417448, 0.13889482910079615, 0.11023568801049675, 0.16630839024271282, 0.16952315345406532, 0.3723839265959603, 3.233718982764653, 16.510196583611624, 33.428672790527344, 48.28359481266567, 47.51054171153477, 50.73309537342617, 41.255144527980256, 26.470189128603252, 17.284745284489222, 24.929134266717092, 39.2243389402117, 59.84944806780134, 57.18675940377371, 23.57746124267578, 28.64408939225333, 31.422373499189103, 29.51312664576939, 23.498453276497976, 19.070420163018362, 14.349838359015328, 11.776291608810425, 9.650066409792219, 6.492136640208108, 5.079109285558973, 4.3564653652054925, 3.2443942385060445, 1.8713715715067727, 1.2576144997562682, 1.1539212124688285, 0.5361775032111576, 0.8562993056007794, 0.8034920735018594, 0.6947161789451326, 1.0559005865028925, 0.9574111742632729, 1.1378355899027415, 0.945120136652674, 0.7545507539595876, 1.4185622462204523, 1.5971536402191435, 2.5036485237734656, 2.7768521266324178, 3.482514215367181, 5.089439954076495, 7.724943791116987, 10.786987117358617, 15.584861551012311, 18.614606176103862, 17.198439972741262, 22.878065994807653, 22.239243405205862, 21.25212672778538, 21.30901857784816, 17.73537070410592, 20.167250633239746, 26.309088196073258, 33.86240366527012, 35.82229593821934, 35.36328056880406, 34.21711615153721, 23.287466015134537, 15.22695984159197, 4.155706286430359, 0.48611822937216076, 0.11603548643844468, 0.2066557380769934, 0.15421443991363049, 0.09029500266270978, 0.16697619083736623, 0.09790424363953726, 0.19332594477704593, 0.11947749102754252, 0.2121517224503415, 0.100785832586033, 0.1473254502883979, 0.08501211221196822, 0.11200107328061547, 0.18549280081476482, 0.278456196721111, 0.13662164179342134, 0.14730750982250485, 0.15390761994889804, 0.1640752772135394, 0.18866478917854174, 0.08867994004062243, 0.24073228240013123, 0.07994054470743452, 0.2043125530970948, 0.07495705783367157, 0.09796789700963668, 0.1862423920205661, 0.08161168146346297, 0.12359623930283956, 0.16987878722803934, 0.3015338240989617, 0.17829135938414506, 0.1561277186764138, 0.10064283133085285, 0.16548319666513375, 0.17894370295107365, 0.12047708167561463, 0.2594151741691998, 0.08715181811047451, 0.13600980676710606, 0.09043161211801426, 0.0881249119660684, 0.11061075502740485, 0.14073535533887999, 0.11457423413438456, 0.1400474158248731, 0.08238664309361152, 0.0866862413074289, 0.08038541940706116, 0.16766601667872497, 0.09764329264206545], [0.028287670308990136, 0.020273696764239242, 0.05858048623693841, 0.054945034706698995, 0.04697800899988838, 0.05690780581374254, 0.02215879427136055, 0.025063071732542345, 0.04382208834535309, 0.04584066556500537, 0.029365882809673036, 0.019504572231588618, 0.033222998159804513, 0.051806833994175704, 0.022899176060621227, 0.03938636922144464, 0.02516735577955842, 0.013253595513690795, 0.026909167046791742, 0.04067310571138348, 0.013463201766301478, 0.009438753743389887, 0.05347949745399611, 0.04794726913262691, 0.09763790507401739, 0.04644220721508775, 0.029364563059061766, 0.03715880660872374, 0.04117957442732794, 0.027152839150013666, 0.05477407102340034, 0.040192292404494116, 0.022227560402825475, 0.014602684282830783, 0.03080429901768054, 0.015094437270558305, 0.007068925661899681, 0.025924042765317217, 0.04506302372153316, 0.006434469126231436, 0.058304919595164914, 0.029797247877078395, 0.0343166303687862, 0.009556879056617618, 0.010788480335447406, 0.043879458481179814, 0.05195488015721951, 0.006056083224913371, 0.04697387672162481, 0.041098482707249265, 0.03634525669206466, 0.03173570707440376, 0.00524954723992518, 0.02135852667769151, 0.031785382623119016, 0.035311481449753046, 0.09705577631081853, 0.027387456203411733, 0.03025689089138593, 0.03018790762871504, 0.01618970135625984, 0.09091659502259322, 0.5440426468849182, 3.55221745797566, 11.311899202210562, 29.37284251621791, 34.27158655439104, 41.26108523777553, 38.89003678730556, 32.60263967514038, 22.75077325957162, 17.711281299591064, 39.618124621255056, 55.38006101335798, 47.63990674700056, 19.42736996923174, 22.288676364081248, 19.06519511767796, 24.960128443581716, 21.705184016908916, 19.980351039341517, 23.154670306614467, 15.996385983058385, 19.778938395636423, 15.553113494600568, 14.262216363634382, 10.952333399227687, 10.41951252732958, 7.859176908220563, 5.555049163954599, 5.666231632232666, 5.079211337225778, 5.642891764640808, 4.879715093544551, 4.132750306810651, 3.6562854051589966, 5.059040716716221, 5.1503760899816236, 5.783349599157061, 5.562626608780452, 6.986457543713706, 7.919841630118234, 10.337007011686053, 11.9761825970241, 20.96748682430812, 19.323760168892996, 21.695915119988577, 16.99996641704014, 24.923898799078806, 26.601854017802648, 26.16975944382804, 26.707244294030325, 24.791035345622472, 35.31612661906651, 29.60469695499965, 28.50093218258449, 29.436508859906876, 26.82138408933367, 24.912208454949514, 18.357983146395, 9.258760367121015, 4.059547126293182, 1.0219228097370692, 0.028853032471878187, 0.01348098277646516, 0.027750597967367088, 0.10017050988972187, 0.03692651014508946, 0.0371086730488709, 0.034328396166009564, 0.014090471767953463, 0.021116362618548528, 0.0659420212198581, 0.04681201219292624, 0.03698653335283909, 0.024898850990991508, 0.020559717934312563, 0.0375601023967777, 0.020093635622678057, 0.05225738463923335, 0.019559565798512528, 0.018213038499067937, 0.005466803126702351, 0.05345498876912253, 0.013121464389509388, 0.052426092193595, 0.04044027320508446, 0.0353947410892163, 0.0562681847784136, 0.07919319945254497, 0.021131987583690455, 0.008043330362332719, 0.009006223292089999, 0.01534830775511052, 0.02869029263300555, 0.07012163408632789, 0.06134842735316072, 0.028033061917605143, 0.04770683024876884, 0.06125721189060381, 0.0458929127614413, 0.06664642877876759, 0.023489581254710044, 0.04067786902721439, 0.018744417931884527, 0.046722381109637875, 0.031145055911370685, 0.04589656667251672, 0.04214052250608802, 0.021065097601552094, 0.07892627734690905, 0.017854207128818547, 0.05688560075525727, 0.028185598286134855, 0.07888184008853776, 0.055640227760055234, 0.032354819388794046, 0.023978899998058165, 0.054987392255238125, 0.05744489002972841, 0.03607484691643289, 0.027032943708556037, 0.010295601827757699, 0.01890365992273603, 0.0622091693803668, 0.0304319631042225, 0.04953292743968112, 0.029485552638236965, 0.03947251263473715, 0.024690296467659727, 0.030088763484465222, 0.0769878588616848, 0.03806047786825469, 0.010972929902241697, 0.037756392399647405, 0.047354076855948994, 0.022438267578503916, 0.014521299096356546, 0.05148480127432516, 0.026114622896005, 0.02216314198449254, 0.024418763716572096, 0.07214128678398472, 0.03654040336342795, 0.07055721285619906, 0.01746909100828426, 0.06910066958516836, 0.026685340396527733, 0.03957216568025095, 0.05759851035795041, 0.05353321707142251, 0.017641131865925024, 0.1332032230815717, 0.02566564136317798, 0.022221675807876245, 0.024400836821379404, 0.030728991808635846, 0.08239274312342916, 0.053324828789170296, 0.01808382846814181, 0.04404113641274827, 0.048815834668598006, 0.0183021929115057, 0.03116078096042786, 0.0036525586703126983, 0.020372360844963362, 0.05666448315605521, 0.024434273330760852, 0.043117277058107514, 0.019692965783178806, 0.028379433688574603, 0.050220904273114035, 0.056080698767410855, 0.017138125374913216, 0.0749073415728552, 0.051598754445356984, 0.0322455006119396, 0.020725282175200324, 0.7290333317858833, 4.782426851136344, 15.944656644548688, 33.80327449526106, 40.52240834917341, 44.95361852645874, 38.495108127593994, 28.16979840823582, 19.741659573146276, 20.821074383599417, 46.333096504211426, 54.38058696474348, 31.607480457850865, 17.33375092915126, 23.664438792637416, 23.50257703236171, 28.846992424556188, 28.843335935047694, 22.609170709337505, 30.249194485800608, 24.96184812273298, 23.845312561307633, 20.608360494886124, 15.227310725620814, 12.258433188710894, 10.512931925909859, 9.10649493762425, 5.971954541546958, 5.214131457465036, 5.133138477802277, 5.687863980020795, 6.680462786129542, 5.76144757441112, 5.0845814262117655, 5.795605787209102, 5.600658876555307, 5.9044137086187085, 5.716287323406764, 9.10425761767796, 10.920125024659292, 14.438344512666974, 16.23142617089408, 21.044620513916016, 22.130154950278147, 28.10268575804574, 23.044635159628733, 26.879002026149205, 22.627918686185563, 25.88462621825082, 26.20220753124782, 22.616702556610107, 31.29253946031843, 24.831810849053518, 27.304007700511388, 30.924055644444056, 30.217833791460308, 28.612858976636613, 23.07441861288888, 13.516982981136866, 6.058745358671461, 1.4289628309862954, 0.06718705155487571, 0.06738544162362814, 0.09897959950779166, 0.03229425335302949, 0.021390753698402216, 0.011520824029243417, 0.011179159594965833, 0.046591759725872955, 0.0652629230171442, 0.014664800771112953, 0.02262237448511379, 0.06104441652340548, 0.03600982290559581, 0.06102573645434209, 0.03631436638534069, 0.02967393770813942, 0.02407136226871184, 0.026295235347268835, 0.03674692567437887, 0.03395258276058095, 0.029305208208305494, 0.020344466270346726, 0.043919587042182684, 0.05157425933118377, 0.022521181165107658, 0.028907746143106903, 0.0900151137528675, 0.02267933580359178, 0.031178080210728303, 0.03803943310465131, 0.035264801633145125, 0.0069978346998271134, 0.03202175708221538, 0.09079522546380758, 0.04083660211680191, 0.05030949041247368, 0.045258882854666026, 0.07653578490551029, 0.053718528377690485, 0.018822013500279615, 0.05336241962920342, 0.05537739722058177, 0.02370169130153954, 0.06295724066772632, 0.01604895792635424, 0.050263275392353535, 0.025460043556189964, 0.04875421690355454, 0.03073687299287745, 0.03937603513311062, 0.016780606969924908, 0.040205686685762236, 0.018487972406936542, 0.1268388903034585, 0.0715493056923151, 0.138169366600258, 0.15346095391682216, 0.17984956077166966, 0.09656414376305682, 0.09122203077588763, 0.13592979391770704, 0.16246603642191204, 0.14265486305313452, 0.1625568244074072, 0.1245172420250518, 0.1574924833008221, 0.1771188915840217, 0.07949724420905113, 0.24919811955520085, 0.06863178831658193, 0.14533840119838715, 0.16036046083484376, 0.2277616783976555, 0.14683132751711778, 0.09113690855779819, 0.08081939004893814, 0.15593430905469827, 0.1464169461812292, 0.10880864744207688, 0.1465637268764632, 0.16619933609451565, 0.18319765611418656, 0.09436545281537942, 0.17315311224332877, 0.10531414459858622, 0.11569539111639772, 0.10748420136847667, 0.1270184578107936, 0.1409260779619217, 0.16964528975742205, 0.08173484235469784, 0.09051030182412692, 0.09739579020866326, 0.21238687554640429, 0.17748900529529366, 0.11193264302398477, 0.10375711707664387, 0.09321045050663607, 0.22800901798265322, 0.12276462678398405, 0.09943541219191891, 0.13999325515968458, 0.17168436891266278, 0.11019152895148311, 0.08585381454655103, 0.12142538864697729, 0.07167465146631002, 0.08562083954789809, 0.155080291309527, 0.16959810443222523, 0.1276259230715888, 0.10278337861278228, 0.14685781752424582, 0.106066192101155, 0.21949846536985465, 1.0094750033957618, 5.7833765234266, 18.232668910707744, 39.40258802686419, 45.983219964163645, 52.08326932362148, 48.523248604365754, 42.22797918319702, 31.41581439971924, 24.431539024625504, 47.74049929210118, 63.795135498046875, 56.81004892076765, 27.6450982434409, 33.7550505229405, 28.76818769318717, 35.43401323046003, 30.836803640638077, 27.532210860933574, 32.365615776606965, 23.536124672208512, 26.86672977038792, 21.24358218056815, 19.130843435014995, 15.387508392333984, 14.966440609523229, 10.602379560470581, 8.342182670320783, 7.9307416166578015, 7.0548790608133585, 7.12906801700592, 6.99264361177172, 6.141791096755436, 5.862920369420733, 7.032082889761243, 6.868074136120932, 6.968509912490845, 7.788124629429408, 9.221229672431946, 11.694127423422676, 15.353840896061488, 17.201314789908274, 27.585765838623047, 26.588145221982682, 31.261675562177384, 25.285613332475933, 34.27480704443795, 36.20212616239275, 34.2663962500436, 33.89026246752058, 32.712713037218364, 44.4871894291469, 37.10581929343087, 37.42152806690761, 38.63824101856777, 35.4321163722447, 32.96767718451363, 25.6836930002485, 14.144337568964277, 5.844282695225306, 1.5081411365951811, 0.17281862162053585, 0.14119476425860608, 0.2275590542703867, 0.15847531413393362, 0.14771954342722893, 0.21106941838349613, 0.09296919059540544, 0.14439597034028598, 0.188633834410991, 0.19154578101422104, 0.2472475485077926, 0.14725535762097153, 0.12931026411908014, 0.2576056569814682, 0.1220441854425839, 0.07423292526176997, 0.13478236405977181, 0.15994739585689136, 0.1506491590823446, 0.07561995262014014, 0.17279055741216454, 0.11541617395622389, 0.12893014880163328, 0.10168158702020134, 0.05368828607190933, 0.11066430501107659, 0.12282220726566655, 0.09893254310424839, 0.16623398209256784, 0.1593381121222462, 0.11867725396794931, 0.1361205436821495, 0.17854700423777103, 0.1848065983504057, 0.17396625503897667, 0.190681802374976, 0.08975779291774545, 0.12704227438994817, 0.18133849730449064, 0.09668521476643425, 0.09034451536302056, 0.19172712628330502, 0.077084651882095, 0.0918425510504416, 0.08633400020854813, 0.13613814488053322, 0.12078934349119663, 0.14361923773373875, 0.093968251986163, 0.20413643254765443, 0.13405767508915492, 0.23147975174444063, 0.17865889466234616], [0.06278390889721257, 0.04942766969491329, 0.047113122285476754, 0.06747264015887465, 0.06786322527165924, 0.022125542662771683, 0.014313389181292482, 0.03730408774156656, 0.06381922441401652, 0.03228906595281192, 0.02388691100558, 0.03811825512509261, 0.08351643782641206, 0.06593183640922819, 0.03853413263069732, 0.0051973208236241976, 0.027186818487410034, 0.015267646904768688, 0.013692689943127334, 0.028569591431213275, 0.06253050999449832, 0.05168720827038799, 0.040487098906721385, 0.06877325608261994, 0.03157749306410551, 0.04505006031000188, 0.010379869939892419, 0.028389357263222337, 0.08579339100314037, 0.020265247306919525, 0.04700171362076487, 0.007984135815474604, 0.027330343910892094, 0.005585130728182516, 0.05542106094903179, 0.028901595223162855, 0.07114104474229471, 0.0324486709598984, 0.11054453000958477, 0.0334059956616589, 0.013288971785056804, 0.0051725729551565435, 0.03798586276492902, 0.006618452200200409, 0.0530485598636525, 0.045150374927158864, 0.013897275884768792, 0.03852127778476902, 0.01712769629167659, 0.028044437557192783, 0.03183268329926899, 0.018659314373508096, 0.028621872554400137, 0.05911593179085425, 0.04749289155006409, 0.04732744096379195, 0.04370349399479372, 0.06042295308517558, 0.01524526542717857, 0.010531374935193785, 0.04515488379235778, 0.03349212211157594, 0.08914946591747658, 0.06583965064159461, 1.0323288227830614, 5.3836870448929925, 16.913803543363297, 29.242324079786027, 35.02692174911499, 38.30912569590977, 41.98998253686087, 35.70232834134783, 28.261299235480173, 49.45386947904314, 62.62195995875767, 37.70247500283377, 19.5824259689876, 19.80759276662554, 17.67660631452288, 23.191657304763794, 27.24634633745466, 13.712216070720128, 22.26779702731541, 21.060490199497767, 18.195537737437657, 23.491666623524257, 21.673217092241558, 22.149083580289567, 16.174935579299927, 19.11859723499843, 19.449732746396744, 17.447755234582083, 15.99218579701015, 14.595029864992414, 14.898400374821254, 15.737833091190883, 16.784827607018606, 14.758560929979597, 19.11861286844526, 29.428261348179408, 17.062818084444316, 18.79795002937317, 13.38653836931501, 16.601139817919048, 23.532810381480626, 28.481183665139334, 15.933292865753174, 22.8097790990557, 27.582726001739502, 22.449841567448207, 14.589419194630214, 17.854683433260234, 21.680651664733887, 30.59711163384574, 36.77322292327881, 34.98086908885411, 23.223850045885357, 16.719521488462174, 10.12158419404711, 3.7391022869518826, 0.7975719368883541, 0.12747205847076007, 0.011720978289044328, 0.030219154166323797, 0.07010463678411075, 0.029797590537262813, 0.0520804430624204, 0.01234035099124802, 0.03752158874911921, 0.01401340460870415, 0.04043738603858011, 0.039634088786052804, 0.05945069382765463, 0.017803758050182035, 0.026243312151304314, 0.024804638099989722, 0.029853009884910922, 0.09636751788535289, 0.037526067080242295, 0.048383740176047595, 0.02566931054129132, 0.03234617824533156, 0.003385124906864283, 0.04375414663393583, 0.016662779363936613, 0.09136754261063677, 0.057865513887788565, 0.09873814282140561, 0.06178411468863487, 0.06000899922634874, 0.05867859561528478, 0.030725996076528515, 0.04725352135886039, 0.0469607809957649, 0.009925621278983141, 0.029383955589894737, 0.038333184484924586, 0.02979898831940123, 0.006905684555282018, 0.05376101824055825, 0.008777499315328896, 0.07184206641146115, 0.049876625782677105, 0.013233175002304571, 0.029658392470862185, 0.05661829527733581, 0.03926922015047499, 0.045808526753847084, 0.005253485287539661, 0.04553633921646646, 0.017248733368303095, 0.021542262086378675, 0.014925478658239757, 0.01716597584475364, 0.03170255724606769, 0.040675860563559194, 0.017427001481077502, 0.05539275586072888, 0.03346933690564973, 0.030094961901860576, 0.020491347049496005, 0.051654669123568704, 0.038333537323134284, 0.0320032703956323, 0.02998030644708446, 0.034288898642574034, 0.030276626082403318, 0.03262336319312453, 0.014155367705305772, 0.04028842046058603, 0.02937914477661252, 0.010603628736654562, 0.017950245279020498, 0.05985737379108157, 0.0396019601529198, 0.037532930461955924, 0.029786730584289347, 0.018889464970145906, 0.018249669212049673, 0.00506570581014135, 0.044312954148543734, 0.0229497947730124, 0.05671534953372819, 0.05359575764409133, 0.02634806269114571, 0.04870813759043813, 0.03924163091661675, 0.03020467083635075, 0.03234315876449857, 0.0874515880963632, 0.0022277212202815072, 0.01427734031208924, 0.016524539728249823, 0.023580518517909304, 0.017412170401907394, 0.04615270685670631, 0.017626847007444928, 0.04590701271912881, 0.0648142620921135, 0.044605636836162636, 0.07393379309879881, 0.03676899163318532, 0.06132994405925274, 0.03183322273460882, 0.01655169639603368, 0.05254205043560692, 0.044657738147569556, 0.02772779410172786, 0.02505361465071993, 0.048852784293038506, 0.020096817951915518, 0.034746757109782526, 0.033821795135736465, 0.04252903130171554, 0.051735092486654005, 0.022374047631663934, 0.04406710394791194, 0.061839964906019826, 0.07812595207776342, 0.080576074176601, 1.5767011834042413, 7.764561550957816, 20.706250190734863, 35.670998913901194, 42.59944030216762, 44.289662565503804, 44.0677718435015, 30.873038496289933, 32.50428097588675, 55.15486294882638, 63.33676283700125, 29.252645628792898, 19.14698931149074, 21.74122953414917, 21.229400907244, 23.21032190322876, 26.358352661132812, 25.262241329465592, 23.667086056300572, 29.158459322793142, 26.790554932185582, 33.55553994859968, 28.90673303604126, 33.143532616751536, 24.415238550731114, 23.911078998020717, 23.88060072490147, 25.830313886914933, 24.66507840156555, 20.91914299556187, 20.32737708091736, 21.031286920819962, 23.442926747458323, 24.567626442228043, 24.741357462746755, 29.50962127958025, 20.388582025255474, 22.96029966218131, 21.294689655303955, 23.279244559151785, 31.170442240578787, 33.2364821434021, 21.451180458068848, 23.64179982457842, 27.295409304755076, 26.744735036577495, 19.266479219709122, 20.631433725357056, 25.372048922947474, 34.949834959847585, 41.488020351954866, 39.56629800796509, 29.725394112723215, 20.76434929030282, 14.230168666158404, 6.4036261439323425, 1.6268946443285262, 0.25814886497599737, 0.03694783650072558, 0.04007040037374411, 0.016610007999198775, 0.03349363185199244, 0.012839465235759105, 0.012618756453905786, 0.023245914240500758, 0.018366053234785795, 0.10539781475173575, 0.016002371408311383, 0.017232704674825072, 0.06825596812580313, 0.012286342148269926, 0.03765528389651861, 0.036268914717116525, 0.003603187614187066, 0.019296397687867284, 0.019959314526723962, 0.025720921611147265, 0.0718691535294056, 0.04462401156446763, 0.008831129875034094, 0.010593994387558528, 0.03367688719715391, 0.030279279154326235, 0.018216105477352227, 0.03604284381227834, 0.03223424032330513, 0.0163104347884655, 0.010365682620821255, 0.04558337865663426, 0.035230097959616354, 0.027410673975412334, 0.020627040482525314, 0.04282208379091961, 0.03594627810109939, 0.03933333492438708, 0.08160587320370333, 0.04577608260193041, 0.029997585341334343, 0.0508475042214351, 0.017637796866308366, 0.04388086983401861, 0.028902273758181503, 0.019202038911836486, 0.03864563629031181, 0.006146257136216653, 0.04968463769182563, 0.09128814722810473, 0.027804385438295345, 0.02433289510996214, 0.04397667558597667, 0.023448178744209663, 0.01647645195147821, 0.13183009890573366, 0.21548657278929437, 0.10995951747255665, 0.25185566980923924, 0.17383350644792828, 0.13334305557821477, 0.1167573934154851, 0.19748772574322565, 0.10372550413012505, 0.1041378430756075, 0.07952279783785343, 0.09653325684900795, 0.17227250949612685, 0.08933541165398699, 0.12838384668741906, 0.11061415448784828, 0.1484579388052225, 0.2754984625748226, 0.17888467040445122, 0.17780696680503233, 0.18501087810311997, 0.19249495651040757, 0.10933046122746808, 0.16800769977271557, 0.16347395948001317, 0.13840594461985997, 0.1676008773169347, 0.16858053260615893, 0.18467113561928272, 0.14450537732669286, 0.1383320792977299, 0.12729747141046183, 0.10962265876254865, 0.2172318191400596, 0.13690643651144846, 0.0795286875218153, 0.21774926994528088, 0.1307054813951254, 0.1938577533832618, 0.08328551878886563, 0.06331202627292701, 0.17658309319189616, 0.11522378213703632, 0.09807678830942937, 0.12989486274974688, 0.16179571167698928, 0.15761257042842253, 0.17417007338787827, 0.15690765396824904, 0.10436695721000433, 0.12995000050536223, 0.09645574779382773, 0.09046958293765783, 0.11542271503380366, 0.12265326561672346, 0.15028030744620732, 0.09319278824010066, 0.13368016534617969, 0.20233971253037453, 0.13812998442777566, 0.13352896060262406, 0.19680045119353703, 0.1923879651086671, 0.30001496417181833, 1.7013798760516303, 8.69182470866612, 23.902640410831996, 41.094710622514995, 49.73994418552944, 53.45719569069998, 55.090196064540315, 44.37599393299648, 38.11731719970703, 56.86787530354091, 70.69941452571324, 47.754107339041575, 30.080999442509242, 31.862965720040457, 28.78697041102818, 32.02034936632429, 38.497105734688894, 22.43843957356044, 32.357555866241455, 32.61895057133266, 27.530312265668595, 34.36581802368164, 32.62100376401629, 31.83759089878627, 22.799144881112234, 27.87519131387983, 26.106035777500697, 24.9982636315482, 22.53033471107483, 21.329008545194352, 20.604902029037476, 23.231359311512538, 23.458365644727433, 21.0015903200422, 26.63633792740958, 38.94246094567435, 23.120790890284947, 27.17889322553362, 19.665748766490392, 25.167474848883494, 34.16419172286987, 39.46396493911743, 25.57625995363508, 33.727243832179475, 36.8623057774135, 30.588019915989467, 23.473418916974747, 25.908484595162527, 31.75001927784511, 40.03701066970825, 47.682718072618755, 45.20366334915161, 32.117287158966064, 23.016032900129044, 13.489766018731252, 5.6781972987311224, 1.3761242777109146, 0.2729965139712606, 0.14218686388007232, 0.10551055334508419, 0.10686254115509135, 0.1021287212414401, 0.16560162816728863, 0.14658237301877566, 0.16862751437085016, 0.11308592863913093, 0.1972270325890609, 0.11467589225087847, 0.12808242786143506, 0.10914596755589757, 0.09618896139519555, 0.15128048163439545, 0.13461210605289253, 0.12012254712837082, 0.07696713640221528, 0.13810110597738198, 0.09360710172248737, 0.19373974257281848, 0.16601595522037574, 0.11530407997114317, 0.11538076799895082, 0.26512322787727627, 0.11748493223318032, 0.18877411474074635, 0.10801132808306388, 0.16209052157189163, 0.1412956759865795, 0.07061287986912898, 0.12773873630378926, 0.1495179326406547, 0.1547955915864025, 0.07929285589073386, 0.11738226988485881, 0.07903186418116093, 0.0871905353186386, 0.13354205632848398, 0.0951081636760916, 0.14829118203903946, 0.1554019304790667, 0.10969751474580594, 0.11411392954843384, 0.1248976830393076, 0.13942252578479902, 0.09726106708071061, 0.07294042461684772, 0.0893396796392543, 0.1842295043170452, 0.1356180885008403, 0.16261861180620535, 0.1176667253353766, 0.11983422402824674, 0.13047978707722255], [0.056380339831646, 0.029809166344680955, 0.03414971414687378, 0.025064486478056227, 0.016633242734574845, 0.013918290962465107, 0.02919327707162925, 0.04038087424955197, 0.011570806615054607, 0.014705022630680884, 0.029751972627959082, 0.03631231042423418, 0.05067309358024171, 0.03558640009058373, 0.07867694965430669, 0.07745681476912328, 0.023302298804212893, 0.02159425483218261, 0.022873342536123734, 0.04392556154302188, 0.03619627754337021, 0.03333991652886782, 0.030979269450264316, 0.04875965536172901, 0.02937816090083548, 0.04123206928904567, 0.06452559972448008, 0.02482258195855788, 0.024054989218711853, 0.03745676151343754, 0.03339792448761208, 0.009968621739452439, 0.030020156808729683, 0.05290232538910849, 0.033457591464476924, 0.01926109181450946, 0.03869400565911617, 0.030241501717162982, 0.02673095491315637, 0.06321547752512352, 0.006082232692278922, 0.014354979985260537, 0.004767050318020795, 0.04639988359329956, 0.06925245786884002, 0.06552245587642704, 0.06125292354928596, 0.03524135485557573, 0.033410901469843726, 0.03730217766548906, 0.016366749802338224, 0.021356798109731505, 0.011872962499702615, 0.04173232601689441, 0.01428036657827241, 0.031901479964809756, 0.050698022956826856, 0.017894666475643004, 0.060227853911263604, 0.02412363321387342, 0.06419632025063038, 0.019770725896315913, 0.0907968675185527, 0.024200234728466188, 0.017121933833030716, 0.12831125701112406, 0.5453626417687961, 5.030525309698922, 12.104014686175756, 28.80794702257429, 35.9388484954834, 45.11871119907924, 37.24841717311314, 36.04639966147286, 53.97412429537092, 49.950915813446045, 36.22881071908133, 30.243813105991908, 26.162536791392736, 28.83723541668483, 21.90418563570295, 23.22172737121582, 41.60818944658552, 24.065297739846365, 24.04259623800005, 21.983810254505702, 19.419742584228516, 13.32314213684627, 24.36983207293919, 18.026356049946376, 27.019852433885845, 19.13382247516087, 18.334489549909318, 21.683566434042795, 17.654620477131434, 24.33388556752886, 23.05074610028948, 19.96827507019043, 33.25535345077515, 65.04563059125627, 38.46079792295183, 17.564926181520732, 15.054554189954485, 14.021367481776647, 15.447589465550013, 31.594723565237864, 29.56307029724121, 27.722881589617046, 22.454931122916086, 20.522166354315623, 30.839659350258962, 30.201957157679967, 28.180583749498638, 29.232210976736887, 20.867983409336635, 14.224451167242867, 7.14980491570064, 2.709766183580671, 0.7182294800877571, 0.10969063440071684, 0.09093818600688662, 0.021596857013979127, 0.03472867415153554, 0.045933122746646404, 0.028453884247158254, 0.027371101813124757, 0.010096176993101835, 0.09703136940619775, 0.006248557740556342, 0.04038687928446701, 0.027133919897356203, 0.032998226649527035, 0.009870447900279291, 0.04666112296815429, 0.03842068836092949, 0.02899442899173924, 0.016016127009476935, 0.02847211987578443, 0.03347145393490791, 0.016849910840392113, 0.06431746589285986, 0.02865170095381992, 0.04153815643595798, 0.038434957952371666, 0.057844173961452076, 0.018018322697441493, 0.0475708518310317, 0.054101870129151006, 0.03647004946001938, 0.057101571666342874, 0.08537530486604997, 0.039358620531857014, 0.060190120578876564, 0.025714838544705083, 0.05026552134326526, 0.011096005128430468, 0.07594240603170224, 0.04097571536632521, 0.055789983831346035, 0.023991035596866692, 0.04249733353831938, 0.02247905940748751, 0.048015149775892496, 0.03725051400916917, 0.029602861164935997, 0.02618057819615517, 0.07374853946800743, 0.06244579489742007, 0.019153647490644028, 0.0268997744257961, 0.02363620249421469, 0.0436284514144063, 0.04886446527338453, 0.09331256324159247, 0.012242094031535089, 0.0038959971030375785, 0.05900964606553316, 0.011926139289114093, 0.0650815370359591, 0.015076249139383435, 0.02037800964899361, 0.04513957943501217, 0.045814480898635726, 0.05084970946024571, 0.027530725479924252, 0.03196817317179271, 0.01696827957805778, 0.03414141566359571, 0.04193035985476204, 0.020183041093072722, 0.03370807945196118, 0.01999581971072725, 0.0352943348698318, 0.019827559989477907, 0.017987995574783002, 0.018659395797710334, 0.04966185587857451, 0.06335391902497836, 0.026764932554215193, 0.03491920678477202, 0.025699311967140863, 0.011000936435136412, 0.024900549024875675, 0.04379382736182638, 0.07215075913284506, 0.03755092860332557, 0.07127391546964645, 0.04326734525550689, 0.017554294650575945, 0.00650401514888342, 0.006794727116357535, 0.024289721623063087, 0.03741775932056563, 0.05170375434681773, 0.01818225166893431, 0.012049028766341507, 0.0366482598973172, 0.0010333420401106455, 0.006246110773645341, 0.03619740051882608, 0.007070170349574515, 0.0547938706752445, 0.041662348700421195, 0.016585702874830792, 0.02525703775297318, 0.04486707977152296, 0.03431338357872196, 0.027520559329007353, 0.014065497438423336, 0.05553082077364836, 0.024063341984791414, 0.06689338838415486, 0.04839213026155319, 0.009686357957044882, 0.05546877892421825, 0.022523252393252084, 0.020963395380281975, 0.041920253075659275, 0.04414934578484722, 0.04391448445884245, 0.024420563530709063, 0.2882935702800751, 1.1720573135784693, 7.271860880511148, 16.900377886635916, 36.1499000276838, 43.22473996026175, 50.984644481113975, 39.743706362588064, 41.827040331704275, 59.36712496621268, 50.83630044119698, 36.2744117464338, 29.86930172783988, 21.513637815202983, 25.503560951777867, 23.713758843285696, 13.346680896622793, 36.15025438581194, 25.366584164755686, 21.674511194229126, 24.86748116356986, 24.32683662005833, 19.87293883732387, 22.653611387525284, 27.90272876194545, 31.348187582833425, 22.83983700616019, 21.567354338509695, 21.376661028180802, 23.8892251764025, 29.051083598818096, 29.001763548169816, 23.918320758002146, 38.95808744430542, 69.55974320002964, 35.69776684897286, 21.7981595993042, 13.695514338357107, 14.563534549304418, 19.411366530827113, 33.21035691670009, 28.9462457043784, 28.81955919946943, 26.695791925702775, 22.956097739083425, 29.577751840863908, 28.509488889149257, 30.572164126804896, 32.63933311189924, 26.01297160557338, 20.017767088753835, 10.597734689712524, 4.8169081551688055, 1.405699719275747, 0.26223250584942953, 0.026777536342186586, 0.03646570683590003, 0.05748572426715067, 0.054739601444453, 0.03637993661686778, 0.06522023637912103, 0.03050942126927631, 0.1113476644137076, 0.032954491674900055, 0.06597144928361688, 0.007163527438284031, 0.008596529785011495, 0.051536715988601954, 0.035642922057637146, 0.0737120071426034, 0.05086007747533066, 0.023883097638775195, 0.05210233599479709, 0.015402163079540645, 0.051299483182707, 0.049559587080563815, 0.02180019699569259, 0.025754885681505715, 0.03643370373174548, 0.09108078014105558, 0.0547018986461418, 0.004212925543210336, 0.03894045636323946, 0.009504301074360098, 0.05537149735859462, 0.07666471334440367, 0.03541264084300824, 0.05742226767220667, 0.011345392192846962, 0.045282044647527595, 0.019660747244155834, 0.011278564127029052, 0.051813795763467035, 0.029843208446566547, 0.0208139785765005, 0.0209824113241796, 0.06443610774087054, 0.04310722116913114, 0.03650518739596009, 0.09935719067496912, 0.053440155993614874, 0.06663640681654215, 0.08457518994276013, 0.05639654664056642, 0.06029185333422252, 0.06841885045702968, 0.0693554255579199, 0.013039663600336229, 0.048324941724006615, 0.0628041292407683, 0.09342669961707932, 0.16476183251610824, 0.08946163273815598, 0.15286127823804105, 0.09183169449014322, 0.1059262781803097, 0.17776135568107876, 0.09797299280762672, 0.15974744515759604, 0.12026205392820494, 0.08509791296507631, 0.07918954893414464, 0.08623023863349642, 0.22826067305036954, 0.15781968645751476, 0.11710385339600698, 0.12178385869732924, 0.12149101655398097, 0.11383072938770056, 0.1434704621455499, 0.1886806668979781, 0.10379988513886929, 0.10516910773835011, 0.13281368969806603, 0.12901530494647367, 0.08612368827951805, 0.13582781010440417, 0.24703399996672357, 0.11614459486944334, 0.16319528514785425, 0.1363904242004667, 0.15394818277231284, 0.1715284822774785, 0.10366467346570321, 0.14574913201587542, 0.09477148138518844, 0.05793614938322987, 0.09179930122835295, 0.11268099929605212, 0.14233188038425787, 0.09418742558253662, 0.06544270765568529, 0.11115130995001112, 0.07901190846626248, 0.0908937623192157, 0.19927471556833812, 0.13149228346134934, 0.22110702762646334, 0.10765789954790048, 0.1413705726819379, 0.1955475362816027, 0.09713370605771031, 0.11190448382071086, 0.14685096432055744, 0.15334795069481644, 0.12250371649861336, 0.14560556757662976, 0.11636790074408054, 0.07192317170224019, 0.12562845168369158, 0.16816608341676847, 0.11528090121490614, 0.15102901655648435, 0.18981291114219598, 0.11849045327731542, 0.16263808576124056, 0.5192150505525726, 1.4488654030220849, 8.349435721124921, 21.206341573170253, 42.40571410315377, 51.38461058480399, 57.64323173250471, 49.64752272197178, 47.51248025894165, 63.631324768066406, 61.19732216426304, 47.71083048411778, 41.802798066820415, 36.40479121889387, 38.02179683957781, 33.24558775765555, 30.491061278751918, 54.375737122126985, 34.471965653555735, 34.39499698366438, 32.15808698109218, 30.448284694126674, 21.938283920288086, 34.91017811638968, 28.013790505273, 40.153900214603965, 29.02190637588501, 29.330298696245464, 32.67856611524309, 25.9280264036996, 34.17921025412423, 33.457768372126985, 27.74188838686262, 44.16411209106445, 74.62457002912248, 48.69917699268886, 26.559859105518886, 22.879391363688878, 22.541936465672084, 27.343765292848857, 41.983930655888145, 38.43042387281145, 37.08593702316284, 32.64114311763218, 29.747013432638987, 41.26655694416591, 40.3526291166033, 40.44095809119088, 39.111976146698, 28.459513970783778, 19.609100103378296, 9.199702416147504, 4.151808347020831, 1.1793992796114512, 0.30085594047393116, 0.21184973365494184, 0.10024525052202599, 0.15736765999879154, 0.068025605486972, 0.07680569935057845, 0.13594580734414713, 0.15112956187554769, 0.23817545388426098, 0.10090561437287501, 0.19504619389772415, 0.09579234410609518, 0.08046724394495998, 0.11315672698297671, 0.17208676732012204, 0.2174437663384846, 0.12553093263081141, 0.12507555420909608, 0.09737041978431599, 0.12381058851523058, 0.07940642229680504, 0.13217220269143581, 0.07760150557649986, 0.07775011153093406, 0.12588827631303243, 0.15973881419215882, 0.10951838828623295, 0.17636311213885034, 0.14536856886531624, 0.1287556295948369, 0.22392762984548295, 0.1384310368448496, 0.10206117986568383, 0.12983428314328194, 0.1259782907686063, 0.10214998652892453, 0.13405755295285157, 0.1969108216996704, 0.10957550057875258, 0.16137671630297387, 0.1571047683911664, 0.11151364764996938, 0.14036969281733036, 0.19664365532142775, 0.12547512991087778, 0.1244771813175508, 0.1646480964762824, 0.16206255235842296, 0.21230682198490414, 0.15824672925685132, 0.15850522395755562, 0.13062070522989544, 0.2500650973192283, 0.11056510319135018, 0.19446631787078722, 0.162934646276491, 0.17978725768625736], [0.04378119643245425, 0.02422243639427636, 0.09427089896053076, 0.05959904193878174, 0.06990899478218385, 0.056195055666778765, 0.012482876423746347, 0.03748124984226056, 0.029145779620323862, 0.010206812976061233, 0.10398864679570709, 0.04120836466816919, 0.011872383200430443, 0.10162819988493409, 0.03870697246332254, 0.05395986971312335, 0.038626213225403, 0.03103273461705872, 0.02113861178181001, 0.02570430768121566, 0.02518796288807477, 0.041549487970769405, 0.024713076584573303, 0.04879462366391506, 0.06000237672456673, 0.010942519659043422, 0.034290605158145936, 0.032454455470932383, 0.08404865355363914, 0.06912706459739379, 0.048998062033206224, 0.020202460765306438, 0.044231909925916364, 0.0213847639305251, 0.018400499065007483, 0.013423184315407915, 0.03316415560298732, 0.060491016932896206, 0.017231890432802693, 0.026324905987296785, 0.01586813512923462, 0.030297280688370978, 0.03638525972408908, 0.040252264722117355, 0.0020223895262461156, 0.007832478149794042, 0.03708493110856839, 0.01505906184736107, 0.021697682228737643, 0.023252726732087985, 0.035872836863355975, 0.02281950247873153, 0.04421965219080448, 0.11313443032226392, 0.016091176375214542, 0.007171400140837899, 0.00719271377394242, 0.018227937431739907, 0.02908685224662934, 0.07013105893773691, 0.05831477192363568, 0.01561132149903902, 0.07049978165222065, 0.05470128457194992, 0.01635510614141822, 0.033914713721190176, 0.05240923399105668, 0.09820011204906873, 0.34442038568002836, 3.825827964714595, 12.367744854518346, 22.927045583724976, 32.6083128792899, 36.70102071762085, 40.11938156400408, 50.52360718590872, 41.19214868545532, 43.79063599450247, 46.138772760118755, 37.597706590379985, 32.55222354616438, 47.06147616250174, 35.57466908863613, 31.982829093933105, 25.379089185169764, 30.211695058005198, 31.096881662096294, 27.395946264266968, 28.760383129119873, 21.746699503489904, 26.023689201899938, 27.905277013778687, 26.276065145220073, 25.263227973665508, 23.44154405593872, 22.879262822014944, 24.018237590789795, 24.57751546587263, 23.386639390672954, 74.24605996268136, 46.47642741884504, 18.181337356567383, 30.67821795599801, 29.528794833592006, 34.603884152003694, 41.68447024481637, 34.222469738551546, 27.35166539464678, 35.33259732382638, 35.47566768101284, 31.05684961591448, 26.36982934815543, 16.53687592915126, 11.418511492865425, 4.794799855777195, 1.3657135963439941, 0.20995477533766202, 0.056512430243726285, 0.061319854243525436, 0.029748522277389253, 0.0313895388639399, 0.040428904350847006, 0.04173239726307137, 0.09752985515764781, 0.047593440261802504, 0.037504364137670824, 0.020145175446357046, 0.06768510304391384, 0.03856696694024971, 0.010978225868062248, 0.07439373806118965, 0.06316434991146837, 0.018276727492255822, 0.017043985426425934, 0.030234594230673144, 0.02464057002881808, 0.060703344110931666, 0.04946104343980551, 0.011153264154147888, 0.02056551940872201, 0.006586482174628015, 0.015166816600997533, 0.04521921569747584, 0.07988654689065047, 0.024290525687060187, 0.032809278395559104, 0.019157995203776017, 0.05845362054450171, 0.03416355286857911, 0.047071592549660375, 0.04395303881860205, 0.04134814966736095, 0.0719323522810425, 0.017089598246717026, 0.04797637828492692, 0.024588999671063254, 0.030238285461174588, 0.0178920575084963, 0.02293483816486384, 0.012435942156506436, 0.042373667138495615, 0.02817841260028737, 0.06180896942636796, 0.03777338970186455, 0.026584170825247253, 0.03758077735879591, 0.11300056893378496, 0.007335134033512856, 0.029053319046007733, 0.05998392057205949, 0.021329225839248726, 0.07222900100584541, 0.02486661379225552, 0.06944617961666413, 0.054415146354585886, 0.030529695895633528, 0.04843392801870193, 0.02655019488052598, 0.07124576983707291, 0.0463531732426158, 0.0695335545710155, 0.06121936320726361, 0.06131441917802606, 0.017840807758537785, 0.01220197819306382, 0.009348874994819718, 0.027865499391087463, 0.06444066749619586, 0.04169872496277094, 0.056956046260893345, 0.048677715472877026, 0.030644622764417102, 0.03708483611366578, 0.05189435822623117, 0.03697692868965013, 0.01647253510808306, 0.027451403039906706, 0.03447827437360372, 0.04601639934948512, 0.12619205644088133, 0.06038487369992903, 0.041476039947675805, 0.07464082658823047, 0.02142933350322502, 0.02402335761248001, 0.09829488303512335, 0.010939261842785137, 0.028784374906016246, 0.06515185361994164, 0.031175233756325076, 0.03027559470917497, 0.02817575104667672, 0.021064865203308206, 0.014809539075940847, 0.08459163084626198, 0.044193189325077195, 0.006980117726405817, 0.07408239226788282, 0.008065937452816536, 0.02036369764911277, 0.07542634622326919, 0.029301941062190702, 0.03741025811593447, 0.029342503885605505, 0.07776258300457682, 0.043933245952108076, 0.025724789260753562, 0.015889373275318315, 0.006328311050310731, 0.023551660423566188, 0.016437526093795896, 0.06538366832371269, 0.030376913558159555, 0.036304307103689225, 0.016027075172002827, 0.024359751526000242, 0.023962718634200946, 0.028340631663533192, 0.04522695778203862, 0.024829882995358536, 0.018868259054475596, 0.04791795641982129, 0.04881722227271114, 0.18352593135620865, 0.8014646108661378, 5.132582621915, 16.219364098140172, 29.347161974225724, 39.92112166540963, 42.629935945783345, 48.2198555128915, 56.069148608616416, 46.87678262165615, 46.64443833487374, 47.16683169773647, 40.358986718314036, 33.13575758252825, 41.11602074759347, 42.52738053458077, 32.5694967678615, 24.99915473801749, 27.144056694848196, 31.433810234069824, 19.890390975134714, 25.471441166741506, 19.40676508631025, 30.271616322653635, 26.551014048712595, 25.26277460370745, 27.575781277247838, 19.1876015322549, 23.79326707976205, 23.473842757088796, 22.07867227281843, 27.58395756993975, 77.08829007829938, 47.898383208683555, 17.48934367724827, 23.85576265198844, 26.338574613843644, 34.31163944516863, 44.94081647055489, 39.62159177235195, 31.957819053104945, 37.89668410164969, 37.34620264598301, 38.385107721601216, 31.883987494877406, 22.836175305502756, 16.274623121534074, 7.205201600279127, 2.8512223873819624, 0.7562622906906264, 0.19712620228528976, 0.048045341191547256, 0.07492799617882286, 0.07418434893978493, 0.046390302678836245, 0.011595834379217454, 0.05885428190231323, 0.03394332754292658, 0.038599638401397636, 0.05275182292929717, 0.09803928567894868, 0.009943720352436815, 0.03389882243105343, 0.0077406011155939525, 0.031699995776372294, 0.03659839775147183, 0.04467770064781819, 0.10056159711842026, 0.07652211242488452, 0.035555896548820395, 0.03592336058084454, 0.034165171174598594, 0.02184176574727254, 0.024392246568043317, 0.006026172553122575, 0.030248192072446858, 0.030809930858335326, 0.0727311847731471, 0.029223010476146425, 0.03239061550370284, 0.02124713497635509, 0.08450146032763378, 0.02140235834355865, 0.009072666289284825, 0.05875258307371821, 0.02132069326138922, 0.029754676590008394, 0.08499186472701174, 0.0579975296610168, 0.05173982187573399, 0.034044168024723015, 0.027562413065295135, 0.02350963874986129, 0.09970058367720672, 0.046800053013222556, 0.02819366267483149, 0.06050140530403171, 0.03295686994014042, 0.04445583666009562, 0.013993792402158891, 0.004977704483150903, 0.028436031990817616, 0.03371419644515429, 0.031688776199838946, 0.03300381099273052, 0.03953968420890825, 0.04381507568593536, 0.07505663284765822, 0.051275279838591814, 0.14182491973042488, 0.21227654575237206, 0.20950930352721894, 0.1401809515165431, 0.11808614140110356, 0.14560220204293728, 0.13148429031882966, 0.11653669311531953, 0.09352487684892756, 0.10778066688882453, 0.18798302433320455, 0.17676009583686078, 0.14986004999705724, 0.17969378270208836, 0.17106764843421324, 0.13823529306266988, 0.28559107386640137, 0.1128625888377428, 0.0882447005382606, 0.08759709314576217, 0.10140578289117132, 0.13588792830705643, 0.08085125405341387, 0.17775074339338712, 0.11954427244407789, 0.1411085088870355, 0.20015564401234898, 0.13440902052181108, 0.14245527876274927, 0.1693050315869706, 0.09213675026382719, 0.10272513316678149, 0.13541443300034317, 0.09361288284084626, 0.09687755908817053, 0.09404403756239585, 0.09741377138665744, 0.12015499467296259, 0.17232350818812847, 0.13492438143917493, 0.05455236988408225, 0.1796794520424945, 0.15841303818992206, 0.1869882241423641, 0.1432100132639919, 0.1547290544424738, 0.18695541018886225, 0.11475058538573128, 0.15754753963223525, 0.1266485205186265, 0.07962621336004563, 0.08984824163573128, 0.25552841701677864, 0.13622076330440386, 0.10328631555395466, 0.11685466819575854, 0.08497558667191438, 0.10252027665930134, 0.13792672247758933, 0.11712015180715493, 0.15500973723828793, 0.1248590743967465, 0.15251544250973634, 0.171040751306074, 0.1698790450713464, 0.20942307529704912, 0.10529524739831686, 0.3433065840176174, 1.2477440408297946, 6.6328176856040955, 19.25593532834734, 34.04177836009434, 46.07845892224993, 51.945093972342356, 55.91388416290283, 64.01126616341728, 55.65149239131382, 56.17638363157, 57.50569561549595, 50.607569217681885, 45.02594927379063, 57.589994634900776, 49.930540221078054, 43.696071011679514, 35.568026610783164, 42.106590679713655, 45.049739905766074, 36.91239881515503, 40.40094688960484, 31.7315058026995, 37.82247386659895, 38.834541525159565, 38.14352233069283, 35.710780824933735, 31.549504688807897, 34.42897367477417, 35.58908312661307, 32.62423120226179, 31.614887237548828, 82.52277496882847, 55.00776263645717, 26.60091253689357, 40.23216472353254, 39.577904973711284, 44.17638955797468, 52.70381988797869, 45.903246198381694, 40.32724734715053, 47.66473960876465, 47.27447666440691, 41.02271686281477, 34.04513086591448, 23.30289622715541, 16.240432773317607, 6.83255147082465, 2.1725449306624274, 0.6555847387228693, 0.1685259783906596, 0.1858899880732809, 0.1873187521206481, 0.26290601970893995, 0.10486156174114772, 0.13698186246412142, 0.21427906544080802, 0.11401136219501495, 0.09216155750410897, 0.16943673523409025, 0.23147375349487576, 0.1514176542737654, 0.1840959686253752, 0.09939508007041045, 0.2367340283734458, 0.13746274023183755, 0.07862568633364779, 0.12993328140250274, 0.14138792960771493, 0.14321253741426127, 0.1213060479078974, 0.09562845075769083, 0.18614654216383184, 0.12090233314250197, 0.06059514491685799, 0.11967623393450465, 0.18167686914759024, 0.12443572282791138, 0.0938990685556616, 0.07491855775671345, 0.09935748923037734, 0.26060391323907034, 0.12123287469148636, 0.1278654730745724, 0.10717268594141517, 0.20527060383132525, 0.10265797177063567, 0.179187609148877, 0.13885304491434777, 0.17715842303420815, 0.12778396744813236, 0.09212870283850602, 0.1023526174415435, 0.18316189731870378, 0.1164915162537779, 0.1360380066824811, 0.19036430226905005, 0.0705198934301734, 0.11146424351526157, 0.27533944110785213, 0.14935173227318696, 0.13378957233258656, 0.2000315806695393, 0.1587535949157817, 0.1385030294103282, 0.13005971961787768, 0.10845496784895658, 0.2543777844735554, 0.09939039139343159], [0.00822333213207977, 0.033523497570838244, 0.0595370102673769, 0.018690584659842507, 0.08586301548140389, 0.05625946221074887, 0.0448802128168089, 0.0319364516596709, 0.006333093449939042, 0.014171398943290114, 0.051131325241710456, 0.023415239261729375, 0.03176243456878832, 0.017225573271779076, 0.08230640632765633, 0.03232161867033158, 0.016440018013651882, 0.043212115897664, 0.03074791275763086, 0.06102193665823766, 0.010536208649032881, 0.10455111161406551, 0.04136727756953665, 0.06102079671940633, 0.04540129717705505, 0.04765385701986296, 0.02963462338915893, 0.018267183897218535, 0.025844548995207463, 0.022977343294769526, 0.03691065278170364, 0.03181185905954667, 0.036069584877363274, 0.03875038852649076, 0.061303650827280114, 0.04032364321340408, 0.030362996804927076, 0.033132084645330906, 0.04316271176295621, 0.07874399569949933, 0.044354300679905076, 0.01955288222857884, 0.03487967872726066, 0.04208004467987588, 0.006154182425234467, 0.0020270351586597307, 0.028925934274281775, 0.03411906132740634, 0.023298488830083182, 0.04548222265605416, 0.04312261373602918, 0.0474752123201532, 0.020325353635208945, 0.049290086541857035, 0.0078058609173500115, 0.0660942844780428, 0.028128849009850194, 0.03919269836374691, 0.040597364239926846, 0.0784967103973031, 0.01228194948219295, 0.03676061172570501, 0.02405112496178065, 0.044072518657360754, 0.03034047283498304, 0.035673452740801234, 0.06158222337918622, 0.04337426880374551, 0.0354864111702357, 0.025953097634815743, 0.2540793647723538, 1.2733889733042036, 6.865152418613434, 13.717029435294014, 23.055707114083425, 31.892863818577357, 36.21003321238926, 39.844114780426025, 44.455714089529856, 46.44308648790632, 50.09818983078003, 47.72428914478847, 43.10477931158883, 44.11550596782139, 40.421739373888286, 39.48326703480312, 42.367620604378835, 40.57608665738787, 43.47029972076416, 44.20986597878592, 32.2621362549918, 32.455157211848665, 30.53331674848284, 27.63257758957999, 29.319160733904155, 33.01775285175869, 31.436231681278773, 32.43231153488159, 28.817151648657664, 59.11557238442557, 51.320621149880544, 30.67831175667899, 40.15952478136335, 36.48553276062012, 40.73982095718384, 35.060641356876914, 35.04506696973528, 30.376044273376465, 27.55972225325448, 17.14900701386588, 11.014827234404427, 5.360096607889448, 2.1851391920021603, 0.6077902519277164, 0.04088509362190962, 0.020242865829329406, 0.016393428102933934, 0.022561308029772978, 0.024551364726253917, 0.01935468384596918, 0.031202809419482946, 0.016032793525872484, 0.05752792235996042, 0.06318142185253756, 0.03490846896810191, 0.017114098449902873, 0.04904753741409097, 0.06189641223422118, 0.07430140980120216, 0.048306088628513474, 0.02039831650576421, 0.016833045852503607, 0.021105891126873236, 0.02894947604675378, 0.04293997585773468, 0.017300042490075742, 0.012087013156685446, 0.029784793366811106, 0.08107114689690725, 0.08366652298718691, 0.005896439202063317, 0.034963908671800575, 0.056652642719979794, 0.09871241277349846, 0.026275917455287914, 0.047710626652198176, 0.034699948371521065, 0.04855587433225342, 0.06035687055970941, 0.026990905071475675, 0.02289038394311709, 0.05420800996944308, 0.019316908105143478, 0.026248031362359012, 0.05898163613996335, 0.022186870354094675, 0.032383104121046405, 0.025968273070507815, 0.029343297771577324, 0.008102278940246573, 0.02283281533579741, 0.045967432869864364, 0.012490626989996858, 0.022530487272888422, 0.06648924614169768, 0.0161621341747897, 0.059832654760352204, 0.05421233902286206, 0.017752301347042834, 0.025282543884324174, 0.05501962945397411, 0.024196499393188527, 0.03411673055961728, 0.018359013433967317, 0.022710960624473434, 0.04512977121131761, 0.021058605717761174, 0.048250899982771704, 0.026273768195616345, 0.026395682278754454, 0.05075185792520642, 0.024348350441349403, 0.06777492072433233, 0.10906707428927932, 0.04320116773513811, 0.04421001020818949, 0.038713907091213126, 0.01361695780152721, 0.033120949885674884, 0.03538974367880395, 0.05629777569057686, 0.08598803555858986, 0.03872113348916173, 0.030855270568281412, 0.09367407312882797, 0.05126844359827893, 0.011692441650666296, 0.08197340169655425, 0.054852506278881004, 0.02903021153594766, 0.03417868080681988, 0.02475182432681322, 0.043630480234112055, 0.030888077736433064, 0.02388904499821365, 0.018839970929548144, 0.04009250704465168, 0.041485356233481846, 0.07936740653323275, 0.05951189090098653, 0.07115482578852347, 0.054773436593157906, 0.04182754144338625, 0.018790921329387596, 0.057946761670921526, 0.04877955340115087, 0.004803374842075365, 0.013303290570287831, 0.035527510036315234, 0.05587185586669615, 0.032290819965835126, 0.019823655020445585, 0.027836054363953214, 0.009173393964634409, 0.02775633498094976, 0.042666326077388864, 0.04504048618088875, 0.02356206575807716, 0.023858875634946992, 0.021589296437533836, 0.0516239993407258, 0.04571490588464907, 0.023542691886957203, 0.017574735518012728, 0.0362670691018658, 0.12739747390151024, 0.05884748298142638, 0.0358824109924691, 0.027187625944082226, 0.007739934454938131, 0.01397075698644455, 0.045630526662405045, 0.012574616054605161, 0.033600297556923966, 0.010312233569233544, 0.0354381164402834, 0.39553117166672436, 2.3236415428774695, 9.547173142433167, 18.48690176010132, 29.46000419344221, 39.36901085717337, 42.74983058656965, 46.61783715656826, 52.18971572603498, 51.01885046277727, 53.54332208633423, 50.39839022500174, 45.82010752814156, 47.7409405027117, 41.900812830243794, 41.904363359723774, 44.12211717878069, 40.491273471287315, 44.00745453153338, 40.325989723205566, 31.91571991784232, 35.37839984893799, 32.20240953990391, 32.18380921227591, 31.32544265474592, 34.80550003051758, 32.083098547799246, 31.309312411717006, 28.21563741139003, 64.91212095533098, 54.042498043605256, 33.170439515795024, 44.30062334878104, 41.503619057791575, 45.35683638708932, 39.827161175864084, 38.81663254329136, 34.1090612411499, 33.53704384395054, 22.78521547998701, 14.789820875440325, 7.456421102796282, 3.6043226506028856, 1.2556798607110977, 0.12602124203528675, 0.041049970846090994, 0.01318225179732378, 0.05169630063963788, 0.03753041988238692, 0.02999923757410475, 0.029284689309341565, 0.01629346632398665, 0.05139689027730908, 0.023258017608895898, 0.021189454410757338, 0.020112744865140746, 0.026726098298760395, 0.06930712064994232, 0.007859010565360742, 0.019466604804620147, 0.027587785185979943, 0.03347350650333932, 0.029166359587439468, 0.05405456266765084, 0.055686208685593944, 0.039296307268419435, 0.033032784438026805, 0.030679736951632158, 0.10360484703310899, 0.01176148937416396, 0.024951067653351595, 0.027857686060347726, 0.07817849104425736, 0.028964661660471132, 0.01774548546278051, 0.0517118526622653, 0.024535118901569928, 0.036784048325249126, 0.01970304881355592, 0.03191808032404099, 0.02956775376307113, 0.04518441363636937, 0.039257695233183246, 0.017956531905968274, 0.04599968363930072, 0.01563242224178144, 0.0807027363085321, 0.018860771420544813, 0.030409832684589282, 0.008374174707569182, 0.05134060579751219, 0.03166376879172666, 0.041429234602089436, 0.0737502561616046, 0.030675034703952924, 0.024215703630553823, 0.012843500822782516, 0.05040673465867128, 0.007514573467363204, 0.07349767150091273, 0.02194196162080126, 0.01575627863141043, 0.006086595248364444, 0.014914398181385227, 0.057390865071543624, 0.07603114484144108, 0.07790393541966166, 0.1477143865610872, 0.13745531705873354, 0.08609561050044638, 0.18578754285616533, 0.09102490956762008, 0.1957721585141761, 0.15294145393584455, 0.0990833950095943, 0.1201916898467711, 0.11888762696513108, 0.2020753959992102, 0.13082216227693216, 0.12273063217954976, 0.21163317241839, 0.23772048258355685, 0.10371002674634967, 0.14363761246204376, 0.12625650369695254, 0.0890651715121099, 0.1748410359557186, 0.23568058918629373, 0.16791634181780474, 0.1499170469386237, 0.16957826406827994, 0.11614329208220754, 0.18713824823498726, 0.12512830352144583, 0.08311194953109537, 0.0791009119046586, 0.10798797969307218, 0.07324089349380561, 0.2068621212882655, 0.15077870498810494, 0.19690546127302305, 0.10412615870258637, 0.11057272313960961, 0.10448237601667643, 0.13463499982442173, 0.11473826318979263, 0.10897075624338218, 0.13319535207535538, 0.22869585826992989, 0.16755893028208188, 0.09649502818605729, 0.12197747187955038, 0.08134865414883409, 0.13308602651315077, 0.09290160172219787, 0.11593886305178915, 0.08281260702226843, 0.11385805399290153, 0.06414342166057654, 0.16027678389634403, 0.1721063226993595, 0.21115234893347534, 0.14880335384181567, 0.09454595670104027, 0.11734732533139841, 0.1742546052805015, 0.12653627725584166, 0.17282900320632116, 0.09258440017168011, 0.12667137357805455, 0.0626504071322935, 0.09546367531376225, 0.12253438628145627, 0.20238853991031647, 0.07937419188341924, 0.13489162176847458, 0.7433493893061365, 3.063483557530812, 11.286162206104823, 20.72625231742859, 33.19762086868286, 44.74924768720354, 48.88950204849243, 53.79814032145909, 60.07308278764997, 60.78257724217006, 64.45060076032365, 61.65600749424526, 59.92734432220459, 58.98335511343819, 55.35141011646816, 51.614637647356304, 53.551646028246196, 53.051924637385774, 55.43264150619507, 55.870239053453716, 43.924847398485454, 44.986236844744, 42.58837877001081, 40.398567131587434, 40.97778981072562, 43.16535023280552, 42.890295369284495, 42.39495134353638, 39.35522215706961, 67.19953046526227, 60.11265972682408, 42.215621812003, 50.9147629737854, 50.573783602033345, 53.224983419690815, 47.43108558654785, 47.70085634504046, 40.53283759525844, 35.647340297698975, 23.382220336369105, 15.585026570728846, 7.046954640320369, 3.2603711869035448, 1.0952098029000419, 0.14599082618951797, 0.07537500147840806, 0.13528135871248587, 0.18435990517692907, 0.1287937361214842, 0.12989693906690392, 0.11022558462406908, 0.09370062420410769, 0.19706567696162633, 0.1495468518031495, 0.14427071277584347, 0.09878341467784983, 0.08181235819522824, 0.15722413627164705, 0.30175831062453135, 0.15094182480658802, 0.10787368725453104, 0.1501984761229583, 0.1390317574675594, 0.198043893756611, 0.17867751366325788, 0.17511600548667566, 0.1152230357485158, 0.14522545225918293, 0.22116103901394776, 0.12133631056972913, 0.09090030339679547, 0.14902243922863687, 0.15071467842374528, 0.1722364385745355, 0.1754994456257139, 0.1651885767600366, 0.08100981411657163, 0.19904904839183601, 0.16002149188092776, 0.16646350334797586, 0.08326820257518973, 0.13875886425375938, 0.1198810293738331, 0.08004331562135901, 0.09972645621746778, 0.11534837473716054, 0.2793139192674841, 0.11767128509070192, 0.16040019584553583, 0.07709753726209913, 0.2141660215067012, 0.10991347208619118, 0.06955519305276019, 0.10211067899529423, 0.19714863465300628, 0.11801986210048199, 0.16857951480363095, 0.1960098221898079, 0.12498418268348489, 0.10368099223290171, 0.14301340095698833, 0.13090874334531172, 0.13969972091061728, 0.08775646066559212, 0.10159441562635557, 0.2212699574551412], [0.022100586144785796, 0.016958395019173622, 0.02638484607450664, 0.056172592764986415, 0.04409580597920077, 0.027239650920299546, 0.011654670150684459, 0.025740599126688073, 0.07231755661112921, 0.10016086790710688, 0.04848523883681212, 0.033536610260073624, 0.06221346450703485, 0.014636802719905972, 0.025251293954040323, 0.02141957277698176, 0.023683747442971383, 0.05033530866993325, 0.03134393113266144, 0.06786833464034966, 0.03012524152706776, 0.05153148448360818, 0.10547704050051314, 0.01777824852615595, 0.041536259930580854, 0.013187851407565176, 0.015275941995371665, 0.020127640405137624, 0.04658946967018502, 0.050400906042861085, 0.026009354973211884, 0.02599987923167646, 0.007464037027343043, 0.03144673936601196, 0.12463739700615406, 0.004189750179648399, 0.0628318338255797, 0.015367759657757623, 0.055511445206190856, 0.03875344193407467, 0.010136688926390238, 0.04294453900573509, 0.020709026172491055, 0.03704807647903051, 0.08844500407576561, 0.04800764178591115, 0.019351396343803833, 0.0490294001730425, 0.03643443315689053, 0.018489107256755233, 0.0391780996828207, 0.03159880924171635, 0.023679297949586595, 0.022607339845438088, 0.013236973102071455, 0.03494886215776205, 0.04664191703445145, 0.011381273972801864, 0.03196219527827842, 0.013425416695619268, 0.039886927897376676, 0.048055739740708044, 0.0527817327529192, 0.024049481210697974, 0.009587095917335578, 0.03463071405089327, 0.02311598665879241, 0.021120688279292414, 0.08052238848592554, 0.03568322364506977, 0.024384467164054513, 0.004294397666983838, 0.04389582135315452, 0.5352541527577809, 2.94010374375752, 5.2478858062199185, 8.458891562053136, 13.170082875660487, 19.31870882851737, 23.46110323497227, 22.775272607803345, 33.65795986992972, 39.72491495949881, 42.992475577763145, 42.28025048119681, 45.85864918572562, 44.450336183820454, 49.48367725099836, 46.29798378263201, 47.140081133161274, 43.83116136278425, 45.31709963934762, 49.84325347627912, 47.222042083740234, 40.56705052512032, 42.96065977641514, 47.33283805847168, 49.45137160164969, 44.677160126822336, 43.43949835641043, 47.8114265033177, 35.89306681496756, 34.9224590573992, 31.645316873277935, 26.744596072605678, 23.81854636328561, 17.304078647068568, 8.69257424558912, 4.20624053478241, 1.2045514328139169, 0.3987366525190217, 0.034971827175468206, 0.01630341025468494, 0.01495524768584541, 0.051746732754898925, 0.009551471980687763, 0.027517826529219747, 0.03888848736616118, 0.03407323307224682, 0.048529343613024266, 0.05220958184716957, 0.037974483732666285, 0.034453735154654296, 0.023715855720053827, 0.008268467433351492, 0.018661056512168477, 0.02157582582107612, 0.03830708124275718, 0.010793958657554217, 0.09287355108452694, 0.030452013814023564, 0.046706120017915964, 0.07578656689396926, 0.021673168454851423, 0.007310138499763395, 0.04667940948690687, 0.09569727456463234, 0.03872590359034283, 0.029864053042339425, 0.00792366307827511, 0.07251262185829026, 0.0223871925513127, 0.08533596340566874, 0.025140029478019903, 0.017505658956776773, 0.02926167000883392, 0.01866455944920225, 0.04954474073435579, 0.053962661884725094, 0.04523527662136725, 0.027907346342025057, 0.026343728548714092, 0.02144813401225422, 0.04855872757200684, 0.013880337106197007, 0.052462071512958834, 0.01594451442360878, 0.03404476174286433, 0.03625653823837638, 0.02949910976790956, 0.024035372771322727, 0.07098021837217466, 0.09610122681728431, 0.03289595785151635, 0.04551116217459951, 0.032990145297454934, 0.02754083734803966, 0.04249169151963932, 0.03540973671312843, 0.074838164927704, 0.04990701397348728, 0.07170644761728388, 0.043626385275274515, 0.0382353838400117, 0.019147238727392893, 0.008091067845400955, 0.014942976380033153, 0.041797078613724024, 0.02591144576269601, 0.09866092553628342, 0.014524026807131512, 0.012025361464891051, 0.021742292513538684, 0.059647353632109504, 0.09933881594666413, 0.0780944884089487, 0.04010608113769974, 0.01818215158501906, 0.024353515789178864, 0.06932210948850427, 0.04109150058190737, 0.03177380342302578, 0.09195647708007268, 0.01705303029822452, 0.03365222244922604, 0.031048802326300314, 0.07219724556697266, 0.008100529168067234, 0.047443779185414314, 0.016419802759108797, 0.012470488918812146, 0.023931648515697037, 0.03861513953389866, 0.06189759288515363, 0.006167836246147219, 0.017720104860407964, 0.04851448369611587, 0.07795635224985224, 0.025898456906101534, 0.01265656781781997, 0.07445095891931228, 0.03595133997233851, 0.05881564611835139, 0.00879944144149444, 0.031471879088452885, 0.060268939206642766, 0.07588829286396503, 0.051588596776127815, 0.0627667758879917, 0.020116631174460053, 0.017020796492163624, 0.017426475616438047, 0.024408017418214252, 0.02180051081813872, 0.04694133418213044, 0.008222947063456689, 0.05916908143886498, 0.04480135008426649, 0.03373311060879912, 0.007208757734458361, 0.04149075737223029, 0.015185642555089933, 0.030753537812935453, 0.010263332398608327, 0.06782460984374795, 0.07169090916535684, 0.020579051093331406, 0.043055784822042496, 0.10045914511595454, 0.03638463547187192, 0.005850669894633549, 0.03425625093015177, 0.024061313165085654, 0.03628900274634361, 0.05003308917262724, 0.04325069739882435, 0.026380425418860147, 0.08503212899501834, 0.12283938777233873, 0.7667812662465232, 4.519717199461801, 8.623603820800781, 13.148370623588562, 19.877361365727015, 26.354640586035593, 30.693663801465714, 33.33833926064627, 41.80992691857474, 46.889786175319124, 50.47004699707031, 48.575804778507774, 51.512148244040354, 50.28700017929077, 53.7587822505406, 53.207043170928955, 53.25293949672154, 49.91573360988072, 50.51925761359078, 52.67471040998186, 50.82556200027466, 41.89190523965018, 48.59658336639404, 52.168054716927664, 52.21674421855381, 46.36848367963518, 48.35714149475098, 52.25850984028408, 39.80749429975237, 40.95670550210135, 38.15057127816336, 32.63559150695801, 29.342597007751465, 23.11652295930045, 12.854987280709402, 6.925291682992663, 2.3507303978715623, 0.8063472945775304, 0.06346026581845113, 0.0664079576464636, 0.03893507218786648, 0.027417723954256092, 0.00846251572615334, 0.028858891621764218, 0.05115930463320442, 0.025269867153838277, 0.020914001423599463, 0.018447172096265212, 0.0385766123155398, 0.04084118901352797, 0.006363512598909438, 0.010024142867353345, 0.008245432865805924, 0.03560638973223312, 0.05086293750043426, 0.02023143251426518, 0.0824258081348879, 0.007608221477961966, 0.07408465857484511, 0.05622144050097891, 0.03524159912818244, 0.04384091769212058, 0.05131764756515622, 0.021989085877846395, 0.041574593766459396, 0.03998880653775164, 0.021699614357203245, 0.006809083221014589, 0.008445141837000847, 0.03846196364611387, 0.03651260378371392, 0.026709372410550714, 0.026647803839296103, 0.021639524992289286, 0.012528754720863487, 0.04738108594236629, 0.04621686234271952, 0.015417482703924179, 0.04818135353603533, 0.03227235024262752, 0.0012164906220277771, 0.014909704415393727, 0.02097082364239863, 0.016406461064304625, 0.021965762932917902, 0.0801873482497675, 0.02964123910559075, 0.04422176582738757, 0.037357077933847904, 0.08942523611975567, 0.02309014125993209, 0.04143194195681384, 0.032671481503971984, 0.040415676310658455, 0.03265991587457912, 0.05111688940918871, 0.036967286707035134, 0.012812349280076367, 0.05915915447154215, 0.010123051220684178, 0.025509478224973594, 0.014704120179106082, 0.03399169012638075, 0.04886682318257434, 0.10809387865343265, 0.0737818351813725, 0.14749407981123241, 0.07320281410855906, 0.12397997799728598, 0.05861741889800344, 0.12454593048564025, 0.18972923420369625, 0.21257921308279037, 0.13889211496072157, 0.17313902585634164, 0.09636023720460278, 0.14963115299386637, 0.08511711550610405, 0.05471839722512024, 0.11941066889890603, 0.1546801727797304, 0.07860584596970252, 0.1117307652852365, 0.2552611285022327, 0.0925943949925048, 0.26807659225804464, 0.1026160925892847, 0.11532351321407727, 0.0873823571684105, 0.09610556944140367, 0.14219477559838975, 0.09066152013838291, 0.19163521192967892, 0.10234210014875446, 0.1074392959209425, 0.13773462921380997, 0.14442092685827188, 0.12823260123176233, 0.21633783568228993, 0.21529893071523734, 0.09831660294107028, 0.1245770345308951, 0.15298817785722868, 0.18690582284969942, 0.1316028439572879, 0.12948802672326565, 0.10568824131041765, 0.20020953326353005, 0.1886975352785417, 0.08873965790761368, 0.08764672119702611, 0.09264922062201159, 0.1279942047383104, 0.13543672966105597, 0.0968888159841299, 0.10082219527768237, 0.1261415598647935, 0.09135048424026795, 0.13286725325243814, 0.1164725444146565, 0.10984831236835037, 0.14461060453738483, 0.08701524936727115, 0.10674606383379016, 0.08115052870873894, 0.20433455120239938, 0.15854022279381752, 0.09700907953083515, 0.06573113253606216, 0.08306143938430718, 0.1468703161392893, 0.16598905809223652, 0.13042618281074933, 0.15402050103460038, 0.12917215510138444, 0.2569865344890526, 1.1443335669381278, 5.006959191390446, 9.312826037406921, 13.888107112475804, 19.725025585719518, 27.028313602719987, 32.35235513959612, 36.28854438236782, 44.564866815294536, 52.31316784449986, 55.78860814230782, 55.66236284800938, 59.467554228646414, 59.70954608917236, 62.38392162322998, 62.328787667410715, 61.13273865836007, 59.17107459477016, 60.52412509918213, 64.65208462306431, 61.560671261378694, 53.27112293243408, 56.83465944017683, 62.067646571568076, 61.23962279728481, 56.27984230858939, 54.72222294126238, 58.40831524985177, 47.55906445639474, 48.20489256722586, 43.44720390864781, 37.1312392779759, 32.22915315628052, 22.362355061939784, 12.434035880225045, 6.276027687958308, 2.262706926890782, 0.7798186923776353, 0.20987236047429697, 0.15881642725850853, 0.09895960308079209, 0.09188478307000228, 0.15311566101653235, 0.1701033144657101, 0.09322673534708363, 0.06983859677399908, 0.1682098896375724, 0.18277906786118234, 0.14157820439764432, 0.15746406625424111, 0.11353489490492003, 0.16380218043923378, 0.09207315117652927, 0.1292423020516123, 0.13043788075447083, 0.1090038823229926, 0.16401415477905953, 0.11524838581681252, 0.14683009258338384, 0.1561911209885563, 0.10507222650838749, 0.10202544142625161, 0.1440462533916746, 0.25659930812461035, 0.13679936368550571, 0.08681578042783908, 0.10931541132075445, 0.11470517782228333, 0.08306732228291885, 0.2336415643138545, 0.11906430391328675, 0.13214299854423317, 0.09069525689951011, 0.11093616006629807, 0.12889026451323712, 0.12110389875514166, 0.08526844238596303, 0.11618434345083577, 0.10396536625921726, 0.08869227580726147, 0.1717921338443245, 0.0680547689220735, 0.12120491904871804, 0.12772644124925137, 0.16886923568589346, 0.12514158923711094, 0.08857997147632496, 0.06659045642507927, 0.10599552946431295, 0.2211572935006448, 0.11177835094609431, 0.23608401896698133, 0.10010108218661376, 0.10689348235194172, 0.16286816341536386, 0.16683616835091794, 0.13791741297713347, 0.10823994688689709, 0.15763129799493722, 0.1303383396672351, 0.08798142216567482, 0.09431703255644866, 0.1471665102456297], [0.06880366123680558, 0.029880626260169914, 0.028658923959093432, 0.01087656690339957, 0.08282034232148103, 0.02158310141281358, 0.014800935251904386, 0.018659278750419617, 0.06776702257671527, 0.029517145228705237, 0.013232102916975106, 0.04803268312077437, 0.07801740004548005, 0.07776092737913132, 0.01386447889464242, 0.022072878167299286, 0.04326757935008832, 0.04045259540102311, 0.01120424164193017, 0.04037127637171319, 0.01008432637900114, 0.005894092743151954, 0.05260562916685428, 0.060380056101296625, 0.017004917076389705, 0.036083111472960026, 0.03772833836930139, 0.020804792908685546, 0.04841332769553576, 0.05797798106712954, 0.0424531982280314, 0.04143014383901443, 0.03795933883105006, 0.011130449262314608, 0.03067315516195127, 0.05297357156606657, 0.0364032205460327, 0.024837791321000884, 0.07159325440547296, 0.06877676410866634, 0.030126968398690224, 0.0353269181214273, 0.016282133092837672, 0.012325318896078637, 0.018684381153434515, 0.026300151333478943, 0.060873208567500114, 0.012176725664176047, 0.10099000377314431, 0.044020101827170165, 0.015440454506980521, 0.08831222834331648, 0.05860502884856292, 0.06427464354783297, 0.021757276263087988, 0.11611890553363732, 0.05970165000430175, 0.034422868596655984, 0.019134897871741226, 0.049294707365334034, 0.02137977839447558, 0.07076022374842848, 0.021268054210980023, 0.02630003767886332, 0.07582040543534926, 0.027673261938616633, 0.06997209853891816, 0.05310535663738847, 0.03669130615890026, 0.03357033684317555, 0.020999400144709007, 0.059025815555027554, 0.022448398106332337, 0.040628566672759395, 0.07920612554465022, 0.05462489170687539, 0.30190880969166756, 0.6817389524408749, 1.3979392328432627, 2.9434356221130917, 3.2984811876501356, 4.112014276640756, 5.183016121387482, 8.662789055279323, 12.161018575940814, 13.584828666278295, 18.37957293646676, 22.43536499568394, 23.62017181941441, 24.156199284962245, 23.765988452093943, 25.90443205833435, 26.830983025687082, 29.784971441541398, 33.8314459664481, 31.698039804186138, 30.365222454071045, 30.72636202403477, 28.445105143955775, 32.72923237936837, 26.425833565848215, 23.79093943323408, 17.329241548265728, 11.061336738722664, 5.441123025757926, 2.4000804126262665, 1.0473569078104836, 0.25627730254616055, 0.0192533649969846, 0.0341139587440661, 0.027360883075743914, 0.019680937053635716, 0.017960511513852646, 0.030459576086806397, 0.03026281450209873, 0.05367986884500299, 0.026643159267093455, 0.054693342319556644, 0.0160922009630927, 0.014407742868310638, 0.019419002180386866, 0.03388387430459261, 0.027656001704079763, 0.021672389835917523, 0.034142402932047844, 0.022355141949706843, 0.036759424289422374, 0.015127668523096612, 0.030304191567535912, 0.05182870317782674, 0.043249459072415314, 0.026493126692782556, 0.0198480704067541, 0.00926688251950379, 0.05272516328841448, 0.04432242989007916, 0.014776655572599598, 0.031611979606428316, 0.02553303526448352, 0.028486576064356735, 0.006320979903518621, 0.015310632098200066, 0.02711725846997329, 0.04800396412611008, 0.01673463961508657, 0.03870895717825208, 0.020769459893926978, 0.008329148820069219, 0.05898863183600562, 0.04775143714089479, 0.039263455995491574, 0.07439573973949466, 0.032639359656189165, 0.017649812025151083, 0.021864181151613593, 0.059712906900261126, 0.01920406094619206, 0.04572295330997024, 0.022653040875281607, 0.01361198244350297, 0.09101551864296198, 0.027848106842221956, 0.0583073351798313, 0.06499154293643576, 0.008742335086156214, 0.026644397593502487, 0.023854495691401616, 0.031097646669617722, 0.0860374193372471, 0.048224040174058506, 0.07903314661234617, 0.04505879305569189, 0.01486829511954316, 0.06161647582692759, 0.02300113782153598, 0.010352503774421555, 0.027531135993610536, 0.029116792604327202, 0.10122382694057055, 0.020857450618807758, 0.04306715367627995, 0.05096916215760367, 0.01019036867988429, 0.03553941832589252, 0.08432191996169941, 0.032814350444823503, 0.020168018327759843, 0.006318360334262252, 0.07950771400438887, 0.01863071072979697, 0.02146678524357932, 0.01934913682219173, 0.061253982063915045, 0.022565090862501944, 0.03373408091387578, 0.0529298806962158, 0.032124863870974095, 0.04823211474078042, 0.058411205320486, 0.020349897943171005, 0.024813306384852955, 0.042172600249094624, 0.06618319292153631, 0.03801849351397582, 0.03291560483298131, 0.05043967753382666, 0.04899055743589997, 0.005604342174982386, 0.02559352496505848, 0.02258681076844888, 0.033131803053298166, 0.03274267339812858, 0.06870250523622547, 0.03808514940153275, 0.01164868292731366, 0.028957024748836244, 0.03091951087117195, 0.05445860991520541, 0.01027357149203973, 0.009655808614167784, 0.006788093164297087, 0.05330485950357147, 0.013490130276685315, 0.008966316951305738, 0.021422115586964146, 0.043962294036256414, 0.029254362186683074, 0.03196954381253038, 0.061256675847939084, 0.004648615423190806, 0.024850462962474142, 0.061532595327922275, 0.07957627318267312, 0.006705118509541664, 0.04841763300022908, 0.010423907710771476, 0.008158155450863498, 0.03525202142606888, 0.04862201114052108, 0.024238997737744024, 0.03647006303071976, 0.020055213577247093, 0.045894866942295005, 0.017478756739624908, 0.014140858082100749, 0.05083587413121547, 0.044678966115627966, 0.043034665419587066, 0.05576738861522504, 0.1383036622511489, 0.05865121672728232, 0.03433441137894988, 0.6207527135099683, 1.4033022650650568, 2.5135883561202457, 4.263713427952357, 5.460863292217255, 7.510868924004691, 9.166795747620718, 14.48141986983163, 18.227542877197266, 21.24105998447963, 26.217404978615896, 30.41124037333897, 31.14728042057582, 32.213346004486084, 32.3553671836853, 33.838550499507356, 34.96456514086042, 38.35897207260132, 41.97562755857195, 38.18744189398629, 39.5538364137922, 38.95457165581839, 36.24772718974522, 39.98340879167829, 34.25369841711861, 29.66903727395194, 22.90869539124625, 15.257952281406947, 7.786785364151001, 4.302625511373792, 1.8297794376100813, 0.4051737513925348, 0.11900708984051432, 0.010506400605663657, 0.04657117975875735, 0.06327140238136053, 0.023743478880663003, 0.010862138704396784, 0.010505096970259078, 0.033045147346066575, 0.03315230838156172, 0.03596975541274462, 0.027215953084773252, 0.01847292758923556, 0.008465200180320867, 0.031099237834236453, 0.04175893137497561, 0.040376124504421435, 0.013231860340705939, 0.0378614669399602, 0.0272902289205896, 0.032238739010478766, 0.03226770567042487, 0.016624995141423175, 0.024408838445586816, 0.044873410503246954, 0.039376822233732255, 0.06282489919768912, 0.045283092984131405, 0.03850665196244206, 0.06245384232274123, 0.031400677016271014, 0.011615409266336687, 0.03722381365618535, 0.06796743467982326, 0.01553295409706022, 0.034540818338947635, 0.015402003623811262, 0.03965366452134081, 0.026192143825548034, 0.021213350717776587, 0.01236267394519278, 0.03654257467548762, 0.013487562869808503, 0.06381254084408283, 0.04174077717055168, 0.04808230438668813, 0.02627292341951813, 0.009034240851178765, 0.026637345918321183, 0.04032554989680648, 0.04823668806680611, 0.06812787428498268, 0.031469256550605805, 0.016807376872748137, 0.0364905751443335, 0.0397229022346437, 0.026142006873020103, 0.0186585832520255, 0.054869944628860266, 0.03657671855762601, 0.007193755325196045, 0.022773967689967582, 0.03208731374304209, 0.03585206351376005, 0.006610880597561065, 0.015992395247199705, 0.01622469849618418, 0.03388988273218274, 0.011921012957048203, 0.14501659918044293, 0.07784242622022118, 0.18834301430199826, 0.13154329572405132, 0.24278360232710838, 0.14379197917878628, 0.11645549961498805, 0.1570438359464918, 0.22921195200511388, 0.10490067249962262, 0.13890234726880277, 0.09807914961129427, 0.25058767784919056, 0.19447036193949835, 0.09894960825996739, 0.17426413191216333, 0.14137844368815422, 0.14653383062354156, 0.1250963852341686, 0.12609441525169782, 0.09507510544998304, 0.11046233906277589, 0.11457598475473267, 0.10969836291457925, 0.12395840058369295, 0.2578812236232417, 0.1605566388794354, 0.12129866544689451, 0.15262258318918093, 0.11841552944055625, 0.10460767429322004, 0.1035600094390767, 0.11948428994842938, 0.11015737828399454, 0.08279014072780098, 0.16621150901275022, 0.11248318598206554, 0.1379878313413688, 0.1889511580978121, 0.20170317882938044, 0.10338455385395459, 0.14298085841749394, 0.0986012958788446, 0.10551931323217494, 0.07396255619823933, 0.1332677381911448, 0.130600349179336, 0.11139501937265907, 0.2311674085046564, 0.18897634531770433, 0.10967335211379187, 0.1870010755956173, 0.15724236172224793, 0.1305289672953742, 0.1094488248761211, 0.17212581022509507, 0.11966065477047648, 0.10107633378356695, 0.18150898601327622, 0.11108169225709778, 0.08491935647491898, 0.1255791357585362, 0.12433614102857453, 0.1346378903836012, 0.2036843653768301, 0.05056810385680624, 0.1266915260681084, 0.12198161094316415, 0.12312610952981881, 0.11140594378645931, 0.09232125072074787, 0.17782534153333732, 0.12111485031034265, 0.18838851686034883, 0.2528260834515095, 0.17975699502442563, 0.6958576919777053, 1.5030060921396529, 2.1690510724272047, 4.26236287185124, 5.1262319684028625, 7.050403552395957, 8.68411307675498, 14.511920724596296, 18.13135896410261, 20.839191811425344, 26.896525382995605, 32.070630005427766, 32.62079184395926, 34.71293960298811, 35.14655583245413, 36.653800759996685, 36.74095548902239, 40.76806191035679, 45.81772082192557, 42.83626617704119, 44.020572730473106, 45.46035412379673, 40.333132471357075, 43.918434211185996, 37.34661953789847, 32.378000940595356, 24.16954677445548, 15.454318795885358, 7.614226852144514, 3.7491281032562256, 1.760611857686724, 0.44407826236316134, 0.20879256698702062, 0.10781422723084688, 0.14500871460352624, 0.10345318088574068, 0.053384767180042605, 0.1615270118096045, 0.11285447355891977, 0.0886416028120688, 0.18327840178140573, 0.26405407381909235, 0.11830399185419083, 0.1355837546288967, 0.10043101983943156, 0.11364510256264891, 0.17870361012007507, 0.09802132485700504, 0.12088113570851938, 0.1961424079324518, 0.1221271702753646, 0.12006018976015703, 0.099001516188894, 0.07509416261953966, 0.1849793397954532, 0.11597141916198389, 0.10412609084908452, 0.16096708471221582, 0.11069656935121332, 0.2366604208946228, 0.1308234514934676, 0.1599522405969245, 0.11109942916248526, 0.1452211367764643, 0.1269859288419996, 0.08320337533950806, 0.14830730403108255, 0.1913542848612581, 0.10122624252523695, 0.13347104085343225, 0.11730670822518212, 0.10947721478130136, 0.14747308593775543, 0.1188687365502119, 0.12897033164543764, 0.11313055588730744, 0.14214232484144823, 0.08949623802410704, 0.03558140268017139, 0.12098681075232369, 0.12029976690454142, 0.13205339120967047, 0.16888290138116904, 0.13062700203486852, 0.2030267563781568, 0.10146830310778958, 0.15826935161437305, 0.17070787559662545, 0.11411152753446784, 0.140161735404815, 0.13481268100440502, 0.0891870092600584, 0.1747678355979068, 0.1088578887283802, 0.19068671496851103, 0.09655538387596607, 0.08384744077920914, 0.10111589237515416, 0.13791220182819025, 0.11419120111635753], [0.0186434977222234, 0.09148138721606561, 0.032275067775377204, 0.046944418123790195, 0.05222110337178622, 0.037834088051957745, 0.023533041422654475, 0.0322277297798012, 0.1002521715792162, 0.02142302312755159, 0.02687562027546976, 0.03436375462583133, 0.014351792567010437, 0.06009932580803122, 0.023273215096976076, 0.0297763625692044, 0.05969766700374229, 0.0337841262641762, 0.09300150921834366, 0.03760122161890779, 0.056508827222777266, 0.031680932335023365, 0.010650139767676592, 0.06331672173525606, 0.03231415817780154, 0.01710526562029762, 0.01659319899044931, 0.027962149919143746, 0.030582468956708908, 0.0570533617532679, 0.052420205902308226, 0.017855262250772545, 0.052383276633918285, 0.024463470692613294, 0.014269789913669229, 0.019662523309567144, 0.02340104430913925, 0.05286298732140234, 0.00913591169020427, 0.04914153487022434, 0.012419202697596379, 0.08419168873557023, 0.03884377869378243, 0.005261169696625854, 0.05241523902597172, 0.013820933061651886, 0.03496543198291745, 0.05703063761549337, 0.034408707570816786, 0.032186915898429494, 0.01651612589401858, 0.01653038870011057, 0.025028005042778592, 0.02561632204534752, 0.05852435782019581, 0.06039520100291286, 0.01967118650541774, 0.15873813788805688, 0.01291244846236493, 0.02801197304922555, 0.0711993919685483, 0.05012367359761681, 0.048533557315490077, 0.02654463258971061, 0.02616272254713944, 0.12139965859907013, 0.03559511248022318, 0.041990776612822495, 0.03291798649089677, 0.0753395412383335, 0.010705948424791651, 0.04923267908660429, 0.011303708938482617, 0.02632245308320437, 0.026036759306277548, 0.010871258215047419, 0.01563270383381418, 0.03481109580025077, 0.03629659216052719, 0.05862344428896904, 0.12323325020926339, 0.06773453432002238, 0.05731142219156027, 0.09673006593116693, 0.5468869028346879, 0.6591194719076157, 1.3387028000184467, 1.3042717618601662, 1.6677524404866355, 1.734420080270086, 1.7321109984602248, 1.9563113451004028, 2.9555554517677853, 3.504797522510801, 5.463751137256622, 5.356442723955427, 6.03843447140285, 7.514191899980817, 7.744766133172171, 6.093990530286517, 3.357814243861607, 2.7444103360176086, 0.3183129908783095, 0.04696609053228583, 0.05327239499560424, 0.01642027773362185, 0.01223166155562337, 0.007339410500467888, 0.03360257404191153, 0.07675377106560127, 0.05063419995297279, 0.03323208035102912, 0.054790640848555734, 0.008012987124467534, 0.0339958325826696, 0.07999321938093219, 0.04643500117318971, 0.0229381477194173, 0.03795832781387227, 0.06537029439849512, 0.07259928435087204, 0.04067258323941912, 0.051647167918937545, 0.041802279584641965, 0.05566218854593379, 0.03999098802783659, 0.04327179644522922, 0.08619553835264274, 0.07493343124432222, 0.03512005993564214, 0.07485417156879391, 0.04330597425411854, 0.02245605707035533, 0.07723066583275795, 0.04110056580975652, 0.06366871177617993, 0.030163191990660768, 0.02321746157083128, 0.050776461604982615, 0.05360707560820239, 0.034784263132938316, 0.04141766558002148, 0.06735728242035423, 0.0175748508689659, 0.01225804554165474, 0.11123811493494681, 0.004963068482798657, 0.03737056381734354, 0.07706869273845639, 0.0490579664973276, 0.04107645406786885, 0.055065362714231014, 0.07087659250412669, 0.035934661581580124, 0.030252300601984774, 0.025107079817514335, 0.03981174621731043, 0.012776878013807749, 0.012843836697616746, 0.041054761303322654, 0.031953130050429275, 0.08417891870651927, 0.013026778220332094, 0.031385243737271855, 0.028212573445801224, 0.045272633366818936, 0.03488076777596559, 0.07870508850153003, 0.04252582861642752, 0.03475185290777257, 0.036019390249358754, 0.05766654706427029, 0.048116112393992286, 0.01117338695829468, 0.017446139561278478, 0.024177815931450044, 0.03689395064221961, 0.06124970729329756, 0.0613263478236539, 0.07729015299784285, 0.042550252484423776, 0.017616290698892305, 0.03764167587671961, 0.0571059753586139, 0.03289839718490839, 0.027700367716274092, 0.06933388207107782, 0.027337799314409494, 0.04623127442651561, 0.05575225728430918, 0.030109882886920656, 0.05393783768106784, 0.03279129382488983, 0.0022230637135050657, 0.023557504306414297, 0.03199023234524897, 0.025917310001594678, 0.0630968085357121, 0.013864844455383718, 0.03170686594343611, 0.01707354580451335, 0.04538500215858221, 0.04350361454167536, 0.06606193871370383, 0.024206750360982757, 0.06830970809928008, 0.04036755460713591, 0.05109607534749167, 0.04217066303161638, 0.032308146357536316, 0.041646484551685195, 0.03957427592415895, 0.02064794105743723, 0.03988185924078737, 0.022667475011465803, 0.021718017923246537, 0.058308488689363, 0.056488935968705585, 0.05878284573554993, 0.03353204032672303, 0.02237015962600708, 0.030193098421607698, 0.012907786926786815, 0.019374017004988024, 0.0459699230933828, 0.03807987039908767, 0.01773621328175068, 0.013961511946815466, 0.010565414492573057, 0.03082033958552139, 0.043255894977067194, 0.03534514357202819, 0.024203869979828596, 0.09575555393738405, 0.05259356142154761, 0.015718357005555714, 0.06046814351741757, 0.014571553096175194, 0.030819538914199387, 0.06674980358885867, 0.019795109052211046, 0.06846578472426959, 0.03580335148477128, 0.031231691262551715, 0.055228923580476215, 0.11777938928987298, 0.020441284735820124, 0.02523802180907556, 0.05364238657057285, 0.04325712312545095, 0.018494969799316356, 0.016699808716241802, 0.023795152715008174, 0.01077456951939634, 0.01668840254257832, 0.03876824078283139, 0.09008376114070415, 0.10275808282728706, 0.04093217716685363, 0.24950147899133818, 0.9818603651864188, 1.2304836298738207, 2.222054102591106, 2.732109418937138, 3.3886173452649797, 3.4636066470827376, 3.6574474913733344, 3.697824341910226, 5.348843131746564, 6.264812861170087, 8.08220887184143, 8.135740399360657, 9.540686130523682, 10.923561777387347, 11.059551920209612, 8.706015535763331, 5.119371925081525, 3.717321421418871, 0.7840706642184938, 0.23686734693390982, 0.06403934795941625, 0.07787722828132765, 0.033319384059203525, 0.03157106055212872, 0.040062495440776856, 0.03226381766476801, 0.026547221200806752, 0.02426119601087911, 0.061793715959148746, 0.019489612230764966, 0.057842321560851166, 0.06240306754729577, 0.023915635089256933, 0.03161010345710175, 0.0221576136204281, 0.026935390728924955, 0.06052649074367114, 0.023547249945944974, 0.02456873861540641, 0.01627462849553142, 0.0368994807026216, 0.07063016894140414, 0.035648686212620566, 0.05460126172485096, 0.032180988895041604, 0.05719316710851022, 0.051859444206846614, 0.0508885216633124, 0.011112767487897404, 0.002944170655350068, 0.057778674976101944, 0.029793383620147194, 0.008690908068924077, 0.06436974701604672, 0.031778587094907246, 0.05562627368739673, 0.021233849260689955, 0.026660982685695802, 0.03250376461073756, 0.05443069837721331, 0.036745955369302204, 0.025423660508490036, 0.03249592753127217, 0.019225297395938208, 0.021953627334109375, 0.042765968944877386, 0.019662528398579786, 0.02764572189854724, 0.01388989427193467, 0.07689960859715939, 0.032746089821947474, 0.025549472775310278, 0.03420666019831385, 0.02610406998012747, 0.02578811693404402, 0.01569108329048114, 0.009339225378685763, 0.016427963839045594, 0.02623609423504344, 0.015773409944293753, 0.09547968874020235, 0.022170237764450054, 0.01951037031332297, 0.01548640659478094, 0.01730775404056268, 0.056359814147331884, 0.012911758901152228, 0.03506558035899486, 0.03462670051625796, 0.021626454711492573, 0.04704229680023023, 0.009601681027561426, 0.11687121087951319, 0.20097948051989079, 0.07940646300890616, 0.16199186258018017, 0.13213097490370274, 0.10243183640497071, 0.11852455644735269, 0.14396009301500662, 0.15614365067865166, 0.1380587111094168, 0.22503095492720604, 0.10782480559178761, 0.187318602842944, 0.14442300317542894, 0.16122316382825375, 0.1421633187149252, 0.19549587262528284, 0.12699488550424576, 0.13810287016843045, 0.10516906024089881, 0.1678871919534036, 0.12807686387428216, 0.07172439486852714, 0.17836735530623368, 0.09292821386562926, 0.18869611035500253, 0.1947541252842971, 0.23891003589544976, 0.13335350501750196, 0.16806867292949132, 0.12849275155791215, 0.16584752925804683, 0.17271112810288156, 0.18693574624402182, 0.09595019849283354, 0.08631200210324355, 0.08955404920769588, 0.11648291242974144, 0.09803672760192837, 0.14374712801405362, 0.1628536834780659, 0.15886822662183217, 0.10823448467999697, 0.10497446996825081, 0.22049197634415968, 0.07356873447341578, 0.08699420121099267, 0.09557263446705681, 0.11718466691672802, 0.11346529078270708, 0.08081537990697793, 0.07103163097053766, 0.0843233313145382, 0.16927175622965607, 0.16603416710027627, 0.15078835375607014, 0.31139939757330076, 0.37638120353221893, 0.10523625556379557, 0.05822901188262871, 0.19780476444533893, 0.07880474493971892, 0.1719007808715105, 0.09656242028410945, 0.13051019901675837, 0.25389453183327404, 0.11550111296985831, 0.1603987030684948, 0.11849176963525158, 0.2332321905664035, 0.09780480433255434, 0.2015646355492728, 0.14547566883265972, 0.09278434408562523, 0.16336132266691752, 0.13797023014298507, 0.062311383895576, 0.1338107833372695, 0.15467023902705737, 0.09063227527907916, 0.21750224248639174, 0.14606615714728832, 0.2757416766669069, 0.3621031439730099, 0.8528684696980885, 1.1732248280729567, 2.0563910262925282, 2.3032346836158206, 2.958788101162229, 3.074109524488449, 3.2775069645472934, 3.1118145755359103, 4.6852454372814725, 5.567763064588819, 7.853609664099557, 7.622516921588352, 9.335815889494759, 10.628014070647103, 10.802459018571035, 8.883542878287178, 5.377969545977456, 3.6318983137607574, 0.9624042149100984, 0.30047194393617765, 0.0965484424627253, 0.12418918391423565, 0.20476341247558594, 0.11314679323030369, 0.10490467585623264, 0.1945413774145501, 0.10896785889885255, 0.12996110133826733, 0.11628123825149876, 0.0727267675101757, 0.1356248738510268, 0.17338783107697964, 0.10360560699232987, 0.141737198723214, 0.15185601503721305, 0.1656520433191742, 0.1832659031663622, 0.14744515743638786, 0.07517127812440906, 0.09939086636794464, 0.19923990672188147, 0.12363351801676409, 0.11965842917561531, 0.2037232182919979, 0.12750510312616825, 0.18678127096167632, 0.13876205336834702, 0.12205897750599043, 0.07121953767325197, 0.14419553109577724, 0.13348368874617986, 0.15992070228925773, 0.1108986981479185, 0.09995290370924131, 0.1256517390055316, 0.11541434191167355, 0.12340086192956992, 0.0819051003615771, 0.16875871590205602, 0.11175663782549755, 0.08406860926853758, 0.16210373943405493, 0.14705726610762732, 0.10006537088858229, 0.15771531420094625, 0.0949213562001075, 0.1151311213948897, 0.10570994764566422, 0.09545181452163629, 0.1639932016176837, 0.11381603910454682, 0.23233109606163843, 0.11385662906936236, 0.14018323139420577, 0.0607318425817149, 0.10933126189879008, 0.06664030839289938, 0.12617969353284153, 0.1151652109942266, 0.0829045417319451, 0.14026606694928237, 0.14793524970965727, 0.1549521703273058, 0.11591891412224088, 0.10420761004622493, 0.13136014555181774, 0.1376778765448502, 0.15693609815623077, 0.20682244056037494, 0.0902934352468167, 0.08321769242840153, 0.12068157855953489], [0.03368100590471711, 0.0038449161386649522, 0.026883116391088282, 0.02474219930757369, 0.001650193242572381, 0.042785978942577324, 0.02168181977633919, 0.05273003516984837, 0.044122319735054455, 0.059011824162943025, 0.07674415622438703, 0.05572223550240908, 0.07502489097948585, 0.03402984415047935, 0.02628034828895969, 0.03401729464530945, 0.03089878162635224, 0.06306077154087168, 0.0349600817342954, 0.04049526846834591, 0.06598984436797244, 0.10504599434456655, 0.03193147460530911, 0.03510158003440925, 0.05652691696637443, 0.023417349505637373, 0.0125600122846663, 0.08047036520604577, 0.030460105344120945, 0.05944964888372591, 0.03224521901990686, 0.015757430444604585, 0.05651479833094137, 0.01241222905394222, 0.060879478231072426, 0.03454294893890619, 0.03177199173452599, 0.036942126628543646, 0.0287573386781982, 0.02777835853131754, 0.034123471805027554, 0.03278615052944847, 0.06116606428154877, 0.013285194889509251, 0.05375970188262207, 0.07052122335880995, 0.01126961425013308, 0.0035164182523398525, 0.03238715836778283, 0.046490681756819995, 0.02515665188963924, 0.02609004296495446, 0.03785940080082842, 0.04100701279406037, 0.034392337913491895, 0.034775041842034886, 0.0363248022539275, 0.019561694702133536, 0.049864988907107284, 0.041860087375555716, 0.07522809186152049, 0.05664004571735859, 0.02644561736711434, 0.024514315017898167, 0.08745094348809548, 0.044739691607121906, 0.0461266578973404, 0.02754094760998019, 0.04653963466574039, 0.03491972925673638, 0.015155295076380883, 0.0608059453911015, 0.07506766582706145, 0.027008160216999904, 0.016822844078498225, 0.03965344060478466, 0.03981092858261295, 0.06297043138848883, 0.0435773441568017, 0.03660994641748922, 0.010598185189467455, 0.018940614636189172, 0.02830801109251167, 0.005633209175097623, 0.03351578602035131, 0.05156709060871175, 0.04613750767228859, 0.003631218319891819, 0.078054074863238, 0.022783428164465085, 0.12163185328245163, 0.02570450445637107, 0.009932896022551825, 0.07463438729090349, 0.05222053340237055, 0.02189917489886284, 0.033069089454199584, 0.12395080099148409, 0.11367290214236293, 0.0296353426362787, 0.020540218534214155, 0.0552906804451985, 0.023085098048405986, 0.052686954981514385, 0.05709716118872166, 0.03585136801536594, 0.01910605843711112, 0.01538757627297725, 0.015104851086757012, 0.02563349237399442, 0.01677138398268393, 0.04092567680137498, 0.031785267272165844, 0.044813024279262335, 0.008669920132628508, 0.030724140283252512, 0.03209092015666621, 0.0629585977377636, 0.032990091014653444, 0.026257859942104136, 0.06459528527089528, 0.013720253731922379, 0.027650229067408612, 0.010940027739187437, 0.05095586965658835, 0.025819326152226756, 0.07018889047737632, 0.08957443918500628, 0.052570087502577474, 0.03512115576969726, 0.05002313845657876, 0.024672289844602346, 0.030334145495934144, 0.006508859040747795, 0.02535602413783116, 0.045145604825977764, 0.08183509590370314, 0.006558202955472682, 0.0068701009066509345, 0.023852227688101784, 0.031083438146327223, 0.011390000781310456, 0.028107656664880257, 0.04133173590525985, 0.051709440470274, 0.03942277941054531, 0.008493052346498838, 0.019625519402325153, 0.04303656531763928, 0.10481582169554063, 0.06177557193275009, 0.08604903585676636, 0.009718783449248543, 0.028593910126281635, 0.014463024812617471, 0.03221408783325127, 0.001774011252564378, 0.03550656366028956, 0.04626668377646378, 0.08152674923517875, 0.06531993352941104, 0.02230199399803366, 0.015684832286621844, 0.04988662399617689, 0.02814759693241545, 0.025888506190053055, 0.006343149762999798, 0.026104237917544584, 0.07308323588222265, 0.03983718449515956, 0.03881429973989725, 0.03385680415002363, 0.033794850510145934, 0.011104381643235683, 0.012020967950645303, 0.03659632482698985, 0.035193077088998895, 0.05323955729337675, 0.050057095741587024, 0.02267369717758681, 0.008311777475423046, 0.018147709147472466, 0.012083360093778797, 0.07492633376802717, 0.041308326447116475, 0.01687734740387116, 0.04572579976437347, 0.06653179028736693, 0.031193642411381006, 0.02385288417073233, 0.07821940670588187, 0.008369231579958327, 0.033568002682711394, 0.07206886674144439, 0.02345021434926561, 0.059044970598603995, 0.03757084021344781, 0.06491925181554896, 0.044486218065555604, 0.018432897415810397, 0.08869213331490755, 0.018554324650072625, 0.032645778597465584, 0.020547070041564957, 0.04783434054947325, 0.03595419321209192, 0.02260441366317017, 0.040184489251779656, 0.02740447555801698, 0.013540507260976093, 0.014491994865238667, 0.036899155005812645, 0.015850299836269448, 0.006296007694410426, 0.05514613891552601, 0.018335807536329542, 0.04670960768791182, 0.026154751457007866, 0.03257328052339809, 0.00481062286832769, 0.026688697448532497, 0.03876048852024334, 0.012146879453212023, 0.010614989109204283, 0.06248942469911916, 0.033411746245941946, 0.043635196052491665, 0.04140788110505257, 0.007464625656471721, 0.03847806867478149, 0.028610798862895796, 0.02012750639447144, 0.016233170005892004, 0.06852417266262428, 0.037225116443421156, 0.05414426838979125, 0.016248085901939442, 0.04799674451351166, 0.04939284049240606, 0.04357739843960319, 0.027288744625236307, 0.0281592202372849, 0.029793563431927135, 0.005726300786981093, 0.03437088602887733, 0.08916191703506879, 0.08267826387392622, 0.017256926678653275, 0.03575975900249822, 0.024654471515012637, 0.08515083869653088, 0.015993007625054036, 0.016198464636025683, 0.02648088931372123, 0.021891571913978884, 0.0198230188938656, 0.08451589276748044, 0.033233627410871644, 0.02243724638330085, 0.015422776973407184, 0.03238489206082054, 0.009306216346366065, 0.01995622719238911, 0.05792371183633804, 0.040104869952691455, 0.03833411407790013, 0.07091312482953072, 0.023069162653493028, 0.046603433920868804, 0.043308257524456294, 0.11272333309586559, 0.08251399733126163, 0.1397780781345708, 0.26632475054689814, 0.28015869536570137, 0.05146266746201685, 0.023191078432968686, 0.08303761601980243, 0.04682827328464814, 0.033279947603919675, 0.04114782238113029, 0.0497101031110755, 0.011940692168926554, 0.09787774684705905, 0.03714773630989449, 0.00447718651931999, 0.057363364047237804, 0.05395242618396878, 0.033056909750614843, 0.0407433273004634, 0.0407643618860415, 0.009700446888538343, 0.028317122121474574, 0.05841142923704215, 0.01722661651937025, 0.025789755596114055, 0.00499643459417192, 0.0035233142885512537, 0.032221470294254165, 0.03914543839969805, 0.06252210294561726, 0.08352955390832253, 0.02017069005939577, 0.04020705393382481, 0.045963731461337635, 0.039610669149884155, 0.04062716889062098, 0.04696624320266502, 0.040364871001137156, 0.01972446677141956, 0.03615635932822313, 0.0716692435422114, 0.06980930441724402, 0.02579090740930821, 0.009147994702548852, 0.01183921895322523, 0.051087325638426204, 0.0348423050184335, 0.02283138023423297, 0.04641513027516859, 0.03187629274491753, 0.032631237592015944, 0.07184343705219881, 0.028316733660176396, 0.02733735317763473, 0.10424620511808566, 0.014773766709757703, 0.014173906978352793, 0.07512698335839169, 0.02616205588648362, 0.023950555893991674, 0.05516707511352641, 0.03503521591691034, 0.061536951522741995, 0.020705718314275146, 0.04584512354007789, 0.031511444465390274, 0.033125105912664106, 0.008218764743235494, 0.06909083082739796, 0.03677433170378208, 0.013760583308924521, 0.05051191097923687, 0.02262822345697454, 0.011022771692036517, 0.030151823136423315, 0.009961291016744716, 0.006320234363166881, 0.047476260656757016, 0.014405027031898499, 0.04819742463795202, 0.06644434069416352, 0.13747498100357397, 0.13452297369284288, 0.19939594263476984, 0.12925338931381702, 0.1425691233681781, 0.09598985886467354, 0.12753331661224365, 0.19967536335544928, 0.2188012706381934, 0.18558361594166073, 0.15394237451255322, 0.1676174607127905, 0.21067269252879278, 0.126605786383152, 0.12424582801759243, 0.10750705442790474, 0.12345760102782931, 0.17724447484527314, 0.14270037918218545, 0.15460592747798987, 0.16295969778937952, 0.20658948591777257, 0.09823943993874959, 0.05991284402885607, 0.15539946061159882, 0.09945335944316216, 0.10060844317610775, 0.14914445339569024, 0.2021798768213817, 0.11277358539934669, 0.09005976814244475, 0.11941418371030263, 0.10649590832846505, 0.10833016490297658, 0.16709208461855138, 0.11511277380798544, 0.15249775988715036, 0.09303440459604774, 0.20211975861872944, 0.12130000894623143, 0.13080468321485178, 0.08370310281004224, 0.10590801880295787, 0.09272765248481717, 0.17328807285853795, 0.19011586345732212, 0.13880299617137226, 0.09302134279693876, 0.14841500110924244, 0.07766131165304355, 0.11249137589974062, 0.21416041680744716, 0.28382207878998345, 0.11608287532414709, 0.11064209655991622, 0.1767048088035413, 0.07942669013781206, 0.14043926979814256, 0.15598483277218683, 0.12174154525356633, 0.1200703949268375, 0.17293318547308445, 0.08192449289241008, 0.12271345167287759, 0.16130414019737924, 0.12447187517370496, 0.09645080805889197, 0.10391797058816467, 0.09312964377126523, 0.19603202385561808, 0.13009200431406498, 0.191860770540578, 0.16716064379683562, 0.11762697675398417, 0.17290244783673966, 0.11723486493740763, 0.07894034337784563, 0.11914779086198125, 0.16169747337698936, 0.13384274233664784, 0.1982212628104857, 0.1488180916224207, 0.12262436002492905, 0.11182637765471425, 0.14962134137749672, 0.1277482086526496, 0.12806907429226808, 0.1304863960083042, 0.26682692074349945, 0.14409225806593895, 0.18813467690987246, 0.09452798230839626, 0.1884400855217661, 0.13362772815993854, 0.17605984769761562, 0.11947602539190225, 0.18475080920117243, 0.33803366124629974, 0.4212650465113776, 0.1229636003928525, 0.11148115260792629, 0.17910703990076268, 0.14006969891488552, 0.09927128135625805, 0.09535996123616185, 0.12659388487892492, 0.09847231315714972, 0.13650449950780186, 0.12154227308928967, 0.12389566323586873, 0.11229326403034584, 0.1350888176155942, 0.09452926473958151, 0.1375287209770509, 0.10623277923358337, 0.12583882468087332, 0.08885534812829324, 0.09292153708104577, 0.07470390998891421, 0.08996714132704905, 0.17717037882123673, 0.07535947659718138, 0.09154968176569257, 0.0898124353427972, 0.14360930398106575, 0.12063136696815491, 0.12458524480462074, 0.15739999897778034, 0.09921847776110683, 0.10624483001551457, 0.09234767287437405, 0.13900604099035263, 0.17483642191759177, 0.09491047928375856, 0.13548231364360877, 0.17020189203321934, 0.11356166311140571, 0.12198214020047869, 0.11497029502476964, 0.19746840106589453, 0.1322591094566243, 0.1337029505521059, 0.10860940241920096, 0.13299933687916823, 0.11251197622290679, 0.14688581387911523, 0.1925617107855422, 0.127430830683027, 0.10518709570169449, 0.23095361569098063, 0.10489052840109382, 0.13811220681028707, 0.14862443772809847, 0.15480871445366315, 0.12261898602758135, 0.11052956152707338, 0.10181581481759037, 0.16858890572828905, 0.10611213570726769, 0.19335018204791204, 0.10998165807021515, 0.11561362764665059, 0.04827129335275718, 0.141716421980943, 0.06714940643204109, 0.08846025075763464, 0.16279425738113268, 0.21527012011834554, 0.10849454001124416, 0.1088305776938796, 0.05240123067051172, 0.1320845495377268, 0.09531299982752119, 0.07341215573251247, 0.06424362092678036, 0.11573893949389458], [0.048790562631828446, 0.036615659682346244, 0.08373623567500285, 0.019147333722295504, 0.05406066269746848, 0.03652280216504421, 0.023116164774234806, 0.02525563657815967, 0.03809807210096291, 0.04167276421295745, 0.04011049161532095, 0.028862487857363055, 0.0218459048108863, 0.11004532501101494, 0.08119649945625237, 0.011063173363384391, 0.05647415069064923, 0.024008161820737377, 0.06900956268821444, 0.035322948691568205, 0.021792390450303043, 0.032893952780536244, 0.052118451201489994, 0.06556809414178133, 0.015494160553706544, 0.060801317782274315, 0.021099253358053308, 0.030436753561454158, 0.03770931224737849, 0.021025437229712094, 0.04481502595756735, 0.03150191104837826, 0.01693389142331268, 0.04309536037700517, 0.07278675679117441, 0.054037399124354124, 0.007808932136478168, 0.029558719069297825, 0.042353334836661816, 0.019033589200781922, 0.007359214393155915, 0.008925654892144459, 0.012493961141444743, 0.029253490269184113, 0.044750561738120656, 0.016636319890884415, 0.07529017103037663, 0.05027754498379571, 0.006895142241514155, 0.03620582792375769, 0.018097997975668738, 0.04377136446003403, 0.04327451397797891, 0.01982263721791761, 0.05086770760161536, 0.023118710976892283, 0.010691828959222351, 0.05774938940469708, 0.05453471440289702, 0.012546965752595236, 0.04933439148589969, 0.02550940358612154, 0.038253996055573225, 0.07234448766601936, 0.059202940336295536, 0.05508907412045768, 0.0025430372916162014, 0.01133444657482739, 0.049719985973622115, 0.029426394562636102, 0.026771502469533255, 0.04694000764616898, 0.021425479424319098, 0.032198834366032054, 0.013204299096417214, 0.030129370412656238, 0.04999925402392234, 0.05211067519017628, 0.04542707132973841, 0.08578879053571395, 0.04563364453081574, 0.033250278660229275, 0.017735816338764768, 0.015250400240932192, 0.018906832073948214, 0.03999959185187306, 0.055613720789551735, 0.037755286387567005, 0.022211915081632987, 0.01837871639457132, 0.07469373196363449, 0.042141000873276165, 0.037928743687059195, 0.07443389376359326, 0.04958844178223184, 0.06561916068728481, 0.039583337759332995, 0.0366910856350192, 0.01745884004049003, 0.00704480246973357, 0.023957005369343927, 0.08352242250527654, 0.03819103479119284, 0.07777922068323408, 0.007587515133699136, 0.06859412283769675, 0.051103831002754826, 0.04638752407793488, 0.04090339371136256, 0.014869278995320201, 0.035068070582513294, 0.021149458164083104, 0.016945928634543504, 0.06569151287632329, 0.040173785361860476, 0.027858617349660823, 0.03677905091483678, 0.03910533019474574, 0.04975460822294865, 0.08103164937347174, 0.03248978000400322, 0.059039399826100895, 0.013359061907976866, 0.05079641731988106, 0.06842070285763059, 0.06050288451037236, 0.027552592967237746, 0.04433769692799874, 0.03128717846370169, 0.011798542475194802, 0.02123634796589613, 0.04828432461779032, 0.005379668628198228, 0.018638513882511427, 0.014570842330743159, 0.04622702340462378, 0.0563809437278126, 0.05314506111400468, 0.031340565598968945, 0.028394997585564852, 0.12783168203064374, 0.018383099730791788, 0.033518021793237755, 0.043775276214416535, 0.011284269758367112, 0.0395297165294843, 0.06367420112448079, 0.049587071141494174, 0.01874642469920218, 0.07346082026404993, 0.026558941196916357, 0.03995010968563812, 0.013486232941171952, 0.01885343815333077, 0.01993834100929754, 0.027247554156929255, 0.028163961500727704, 0.04194666165858507, 0.024860942935837165, 0.049610752013645, 0.012684606581128069, 0.03719070114727531, 0.030137003931616033, 0.037934809790125916, 0.03286230590726648, 0.019472243430625116, 0.059201854680265696, 0.039153699563550096, 0.023814568994566798, 0.05245309110198702, 0.0314344680601997, 0.034804670073624165, 0.0036863497142413898, 0.03594041895121336, 0.04311726688008223, 0.031652382974113734, 0.0616431286824601, 0.019773652078583837, 0.01477867760695517, 0.015646271141512052, 0.04664248361119202, 0.03556465643591114, 0.05012997040258987, 0.05067245236464909, 0.05145495930420501, 0.023643065875928317, 0.04925593248169337, 0.014982960752344556, 0.026221968832292726, 0.13509636292500155, 0.05502988211810589, 0.030049723972167288, 0.05666896487985339, 0.021814463194459677, 0.02414830305081393, 0.024162201144333397, 0.008644031477160752, 0.01520289430793907, 0.05752890623573746, 0.07949167343654803, 0.05041366589388677, 0.03854161347927792, 0.07762818557343312, 0.02228169053393815, 0.03282971926299589, 0.0581937755591103, 0.07892483206731932, 0.047268058971634934, 0.04032582470348903, 0.036998675736997805, 0.02262747028310384, 0.04669368586369923, 0.008930401244599904, 0.03447444065074835, 0.07584149430372886, 0.02996023538123284, 0.02522119414061308, 0.020828385571283952, 0.0549645120544093, 0.008047762044173266, 0.04727057633655412, 0.024289553685645972, 0.019520855375698636, 0.036871542023228746, 0.004173989083418357, 0.06449104193598032, 0.05774668204997267, 0.035747552157512734, 0.022718125954270363, 0.047793251861418994, 0.017320239084905813, 0.04009402357041836, 0.02028635992402477, 0.03076423831017954, 0.08178490466837372, 0.03295038993071232, 0.08257994414972407, 0.012734321993775666, 0.03087340441665479, 0.07014077555920396, 0.028554660268127918, 0.0464667328633368, 0.0248492534738034, 0.05528273480013013, 0.02407648690444018, 0.03570267724405442, 0.024634212155693343, 0.1211885256426675, 0.051038125064224005, 0.04558269672894052, 0.01462819380685687, 0.08448854102087872, 0.03344413272238203, 0.034338441876960654, 0.04566505391682897, 0.029249011938061033, 0.08790909711803709, 0.006688510940875858, 0.02306984967019941, 0.02022246567399374, 0.030352068998451744, 0.013038565221774791, 0.041525053924747875, 0.04824941738375595, 0.045036241944347105, 0.03734458949682968, 0.015066961691315685, 0.022040237240227203, 0.03388740268668958, 0.011950491910933383, 0.018714436862085546, 0.03334788931533694, 0.009781481781309205, 0.011637520178088119, 0.01864189637957939, 0.0039698925351590985, 0.05412434320896864, 0.04878909021083798, 0.037593337041991096, 0.04374578708250608, 0.029737950701798712, 0.048550032145742855, 0.011118002385566277, 0.04220255417749286, 0.03174498604078378, 0.041315271253032346, 0.05598038415025387, 0.01818291493691504, 0.04798345201249633, 0.03811138495802879, 0.016104568960145116, 0.023346232250332832, 0.04174807481467724, 0.010847553594170936, 0.03453387353303177, 0.05938592766012464, 0.03165548727182405, 0.024242410768887827, 0.03509174806198903, 0.010107774852908083, 0.048080604656466415, 0.0240221820505602, 0.05144777361835752, 0.05489190880741392, 0.004955797131905066, 0.018179934471845627, 0.038568507214742045, 0.040364284068346024, 0.022635361645370722, 0.061784413244043074, 0.02900847466662526, 0.05823236384562083, 0.03248458242576037, 0.04995863013235586, 0.0248851734213531, 0.03779774571635893, 0.061893182407532416, 0.027477775999744023, 0.06578078094337668, 0.020331199214394604, 0.009894726731415306, 0.02669558797164687, 0.038886312661426406, 0.08928867416190249, 0.027577371369781237, 0.01575179521127471, 0.039587921263383966, 0.042931473813951015, 0.043856805589582236, 0.027978085314056704, 0.014338810495766146, 0.034367985291672606, 0.013773061567917466, 0.05353751219809055, 0.037989655775683265, 0.09064497066927807, 0.03975620473335896, 0.025671758356371095, 0.046996353194117546, 0.016159991700468317, 0.06293065566569567, 0.04826819584039705, 0.008601498357685549, 0.10988466148929936, 0.03227730694093874, 0.07983147020318679, 0.03350531283233847, 0.03404569133583989, 0.006476399197708815, 0.03939933602565101, 0.03746989455872348, 0.027134164169962918, 0.14870255067944527, 0.17988200831626142, 0.10372900537082128, 0.0826893714921815, 0.22473273878651007, 0.07829100572104965, 0.1732221328254257, 0.09269280292625938, 0.16135340183973312, 0.14463067560323647, 0.10224907978304795, 0.10328310608331646, 0.06147496056343828, 0.24051582972918237, 0.12226515715675694, 0.08652823764298644, 0.17946365076516355, 0.11454473143177372, 0.07681458137397255, 0.12779752457780497, 0.0886200661105769, 0.17620794475078583, 0.09457431267946959, 0.12311887634652001, 0.19161815355931008, 0.10734318143555097, 0.2536070229751723, 0.1517197923468692, 0.13290660828351974, 0.10890314022877387, 0.10967869896973882, 0.09802519929196153, 0.16496669580893858, 0.1297558716365269, 0.11011968566370861, 0.16532771715096065, 0.09231565959219422, 0.08737196879727499, 0.1585859153419733, 0.11262983775564603, 0.04838288861459919, 0.09435891173779964, 0.12562497758439609, 0.08813055737742356, 0.1248575137662036, 0.13904312971447194, 0.16437680460512638, 0.17846431796039852, 0.11427398238863264, 0.17744484623628004, 0.1488118762416499, 0.21094929054379463, 0.10603347314255578, 0.1037126255354711, 0.09493519152913775, 0.08182711633188383, 0.07105782242225749, 0.13999066315591335, 0.1741057482681104, 0.09712253058595316, 0.15762881455676897, 0.1023930309872542, 0.16373512760869094, 0.18898517984364713, 0.19987794677061693, 0.16673672225858482, 0.09399162751755544, 0.16001621287848267, 0.13641265300767763, 0.0992434478497931, 0.0987837335893086, 0.12940369839114801, 0.07124242465943098, 0.11999792738684587, 0.0712762496301106, 0.08659747535628931, 0.1354076883622578, 0.16727112286857196, 0.1066084433613079, 0.152872446924448, 0.1905239344175373, 0.05855496653488704, 0.09144106187990733, 0.16367954201996326, 0.13499193638563156, 0.20607333789978707, 0.12119881223355021, 0.0772247693634459, 0.17520882907722676, 0.3240716904401779, 0.12254835053214005, 0.15197359158524446, 0.08232731199158089, 0.11666148927594934, 0.1628914235958031, 0.1391088661870786, 0.15155085069792612, 0.0722219238856009, 0.1177886173661266, 0.16366504851196492, 0.12447950190731458, 0.11916421140943255, 0.1103854678305132, 0.1444129201450518, 0.1113836606964469, 0.22034379786678723, 0.07517706602811813, 0.09310828348887817, 0.12242143734225205, 0.15884438290127686, 0.17720883818609373, 0.05733818361269576, 0.12557560737643922, 0.15153471513518266, 0.06442023680678435, 0.09176484522010599, 0.1902165309126888, 0.08495793119072914, 0.06661195241447006, 0.19524139485188893, 0.12241427201245512, 0.1427522599697113, 0.0894944059795567, 0.1296815313398838, 0.1717989734773125, 0.13944274612835475, 0.19707991262631758, 0.18688903589333805, 0.12859706953167915, 0.11141690891236067, 0.15989737425531658, 0.11855081575257437, 0.08781463147274085, 0.1421725739325796, 0.09249370039573737, 0.20707229072494165, 0.10339426369007144, 0.12793258018791676, 0.1394880994090012, 0.06616877405239002, 0.18207436853221484, 0.12111809370773179, 0.12786973427448953, 0.1379866778318371, 0.09179016814700194, 0.14678326009639672, 0.15565381624868938, 0.13089638043727192, 0.04873764707839914, 0.17924190552106925, 0.193143473139831, 0.1552797398929085, 0.11588219180703163, 0.1205241855766092, 0.09114767690854413, 0.11351192649453878, 0.10559904109686613, 0.10748298679079328, 0.1647765567260129, 0.13845217999603066, 0.13151677857552255, 0.1382041483053139, 0.11008854769170284, 0.15865277818271092, 0.13266777752765588, 0.10604742382253919, 0.1358538115663188, 0.23015788410391125, 0.06117479024188859, 0.11707791978759424, 0.10165616231305258, 0.09682288273636784, 0.15559550294918673, 0.11929387945149626, 0.1067898700545941, 0.12687232850917748], [0.03149976687771933, 0.0148569042129176, 0.03201489030782666, 0.04676127812958189, 0.02334949600377253, 0.016717708470033746, 0.036213505547493696, 0.03869192594928401, 0.042047838015215735, 0.05350195696311338, 0.010771451650985649, 0.039059976914099286, 0.038586542675537724, 0.06965110397764615, 0.03379956293585045, 0.016570825994546925, 0.022963847233248607, 0.03491458935397012, 0.0069000488978677565, 0.024820989097601602, 0.05568420700728893, 0.01565480202303401, 0.022514441616034934, 0.05781379594866719, 0.030422416116510118, 0.04728763470692294, 0.061001451686024666, 0.01182509439864329, 0.04704836968864713, 0.02239400165022484, 0.04767275082745722, 0.06291421476219382, 0.017128098323675137, 0.10833127091505698, 0.016125627294448868, 0.013790871415819441, 0.011046836784641658, 0.00687027902209333, 0.057475763373076916, 0.08125918930662529, 0.03409207598971469, 0.05041451066998499, 0.024926835471498113, 0.024858775016452585, 0.06434086178030286, 0.05796255796615567, 0.04785700361909611, 0.029689286170261245, 0.022278777922370603, 0.08638478176934378, 0.03091620301295604, 0.024837479194892303, 0.046392375603318214, 0.01688089614201869, 0.046328342253608365, 0.03911161682169352, 0.024213330454326103, 0.07254163601568767, 0.05012881689305816, 0.10051912082625286, 0.03967220209805029, 0.036178052092769315, 0.05057216828156795, 0.08690212400896208, 0.03286187503752964, 0.02949158481455275, 0.05658738800723638, 0.0356632781081966, 0.05820227760289397, 0.08994928907070841, 0.009816233800458056, 0.09338809775986842, 0.021840222080105116, 0.022768569943894233, 0.05206776124292186, 0.008351184244799827, 0.026913664037627832, 0.02301698161422142, 0.023125491238066127, 0.0077904776803084785, 0.048279971815645695, 0.003937955164084477, 0.021807706682011485, 0.04711677958922727, 0.05497071725715484, 0.04666763351165822, 0.0687700601826821, 0.03628330644486206, 0.044680163729935884, 0.03266543236428073, 0.09379770220922572, 0.04433153583002942, 0.036899229644664695, 0.009027804946526885, 0.04283938304122005, 0.061934973379330974, 0.020223963540047407, 0.01851030469073781, 0.0212852601627154, 0.015619328212259071, 0.05564761022105813, 0.016814560862258077, 0.08871844690293074, 0.04724988780383553, 0.044115527599517784, 0.05043559614568949, 0.034928044703389914, 0.02728058354529951, 0.033720340579748154, 0.008756102561684591, 0.016097992259476866, 0.028649760343666588, 0.027851945654089962, 0.024318053852766752, 0.0578707657488329, 0.016005589360637323, 0.032503734076661725, 0.015455733419262936, 0.02669397645097758, 0.011261508301166552, 0.03519911265798977, 0.04952620315764632, 0.03482950106263161, 0.017882315441966057, 0.050244605501315424, 0.01886179091941033, 0.010054682880373937, 0.04337060471464481, 0.032638070439653735, 0.04437757443104472, 0.023213517586035386, 0.02072266472636589, 0.046249394704188616, 0.01891722044508372, 0.051550371505852254, 0.031891882086970975, 0.01858313863963953, 0.07617812231183052, 0.027000640352655734, 0.040566477325877974, 0.04203808746699776, 0.036590781195887497, 0.027142924057053666, 0.014801907253318598, 0.05674995142700417, 0.035219512813325436, 0.026097547562260712, 0.04077989015994327, 0.03864160579230104, 0.055476744925337176, 0.03073559734704239, 0.024109864042007496, 0.034949974955192635, 0.07918882290167467, 0.037069484258868864, 0.023324887234983698, 0.024773330494229282, 0.06274388890181269, 0.01624647098859506, 0.017265842628798315, 0.06764155466641698, 0.030447362456470728, 0.01857681978227837, 0.04908867359959653, 0.008361065411008894, 0.03849182936495968, 0.02373409304501755, 0.042948026675730944, 0.028718875920666114, 0.024693037749135067, 0.015290019900671073, 0.04169049094031964, 0.008295137252259468, 0.030074867087283304, 0.0740366182955248, 0.06395968794822693, 0.06774948923183338, 0.026641532479386245, 0.0683631155905979, 0.06829277865056481, 0.032575292379728386, 0.003913863778247365, 0.019623673787074428, 0.04341460771060415, 0.024005868372374346, 0.0225873535964638, 0.01381308919683631, 0.031251144861536365, 0.040603871390755684, 0.013346615879397308, 0.05043047320629869, 0.00896131869272462, 0.03629710106179118, 0.05675208202696272, 0.03181457659229636, 0.04346452074657593, 0.05160545837134123, 0.02381600918514388, 0.02275570322360311, 0.03459016479817884, 0.03731704776042274, 0.04901910001145942, 0.021344457254079834, 0.025773063634655306, 0.018606938255418624, 0.033310793805867434, 0.005688353291978794, 0.00976992632994162, 0.023403263118650233, 0.05064546024160726, 0.0148747259351824, 0.013127905383173908, 0.02059322060085833, 0.015160674162741219, 0.03910917070295129, 0.02547966848526682, 0.07079914451709815, 0.013660142314620316, 0.04571161498980863, 0.036811057411666424, 0.04965002562052437, 0.014416187236617719, 0.040731218843055625, 0.006491376585992319, 0.02691160638018378, 0.04004886027957712, 0.021804922992097478, 0.05255165509879589, 0.0315593252889812, 0.02243128714949957, 0.025922063139400313, 0.031565116585365365, 0.03990597437535014, 0.07957220197256122, 0.007042050162064177, 0.06012696932469096, 0.014456358206059252, 0.11240513409887042, 0.01481083338148892, 0.07160498627594539, 0.023129971265526753, 0.07827814069709607, 0.02442505712887006, 0.015039881358721426, 0.0399124170653522, 0.05783624867243426, 0.08793215373797075, 0.06259084532835654, 0.04676710335271699, 0.01170384867249855, 0.08562503289431334, 0.02928843142996941, 0.07035086357167789, 0.01498661466341998, 0.015913695363061767, 0.04779853086386408, 0.024189953226596117, 0.027953837865165303, 0.027480354432814887, 0.024284522348482693, 0.019674511327009116, 0.03013335002054061, 0.0603948820914541, 0.057323255842285495, 0.047324665755565674, 0.020851732264938097, 0.03718497431171792, 0.03942567336239985, 0.061083255867872915, 0.030573949949549775, 0.04509495557951076, 0.031045565714261363, 0.06677011214196682, 0.0156478300757174, 0.058337604627013206, 0.03620960736381156, 0.07675170831914459, 0.07983561605215073, 0.009456093705791448, 0.030119280596928935, 0.012613577535375953, 0.061151258647441864, 0.060067699290812016, 0.03292587785316365, 0.01557657032805894, 0.06576719667230334, 0.03289084509015083, 0.02263935821663056, 0.043837067005889754, 0.04729042009317449, 0.05020730982401541, 0.07534716118659292, 0.0078100322113771525, 0.022668117923395972, 0.02173455212531345, 0.04570892799113478, 0.05506294034421444, 0.036785483426813564, 0.04844054373513375, 0.039093890094331334, 0.026975980693740503, 0.07253972254693508, 0.08108597967241492, 0.040016283813331804, 0.03442353356097426, 0.02548558870330453, 0.012640071783347853, 0.028113571793905327, 0.039846029199127636, 0.03963076396446143, 0.05903278410966907, 0.023210012952664068, 0.0501396429192807, 0.03077725600451231, 0.013818983121642044, 0.028433460343096937, 0.03791075911638992, 0.014302653060959918, 0.020168936046372567, 0.006361092773399183, 0.06828302131699664, 0.033454449847340584, 0.01541137758509389, 0.004907082982494363, 0.022943757507683973, 0.13917777820357255, 0.023701431761894907, 0.012896073716027396, 0.003799972523536001, 0.05689026229083538, 0.08925897468413625, 0.044273012184670994, 0.018633658964452997, 0.034843210862683396, 0.015389257343485951, 0.006377739781912948, 0.02956536871248058, 0.061847428791224957, 0.0075295402535370416, 0.01950633472629956, 0.032185144922030826, 0.07477845384606294, 0.030444743311298744, 0.12989095438803944, 0.030446005386433432, 0.009293459039846701, 0.04937439112524901, 0.020212374161928892, 0.03120020723768643, 0.010963423626630433, 0.004472503779522542, 0.025724010641819665, 0.09469543118029833, 0.10613891748445374, 0.18364021022404942, 0.23275026785475866, 0.08146892448088952, 0.12549868864672525, 0.1704242615295308, 0.15494881836431368, 0.10420939459332398, 0.14243302281413758, 0.08455378216292177, 0.10434761896197285, 0.1601188073733023, 0.20433703464056763, 0.09407123324594327, 0.08945209253579378, 0.10735849597092186, 0.1712509478841509, 0.15744932847363607, 0.11610427631863526, 0.17831862292119435, 0.08039181799228702, 0.07783958315849304, 0.16572913846799306, 0.08837645846818175, 0.19157373665698937, 0.18258865736424923, 0.08569063365991626, 0.07630553083228213, 0.10746229825807468, 0.06306996569037437, 0.09573049563914537, 0.11365266144275665, 0.13493546870137962, 0.08086468226143292, 0.057714356641684256, 0.10702727588691882, 0.061014282783227305, 0.09793541553829398, 0.23498965054750443, 0.13020964871559823, 0.12377146418605532, 0.11097862957311527, 0.053370042970137935, 0.1676679030060768, 0.09270428373877491, 0.12376161185758454, 0.08308156473296029, 0.12459099878157888, 0.27057178265282084, 0.07296858382012163, 0.11773178327296462, 0.09722429048269987, 0.11311948219580309, 0.07502370354320322, 0.09367072795118604, 0.13048797020954744, 0.10336299001106194, 0.11874266474374703, 0.15378099174371787, 0.1787858349936349, 0.15637915661292418, 0.100175062859697, 0.13731701805123261, 0.13125532546213695, 0.16827460830765112, 0.2367295500423227, 0.11884371217872415, 0.14142311843378202, 0.14402831292578153, 0.12015635174299989, 0.2431848607957363, 0.11213372687676124, 0.11469052146588053, 0.11728241667151451, 0.08447653095104865, 0.15437264713857854, 0.08904572469847542, 0.08779330511710473, 0.09930140152573586, 0.0951057073793241, 0.09403475520334073, 0.0778606381001217, 0.19542321509548596, 0.14679509374712194, 0.08844862745276519, 0.19474326872399875, 0.134593202067273, 0.18454940643693718, 0.13394077707614216, 0.10531630233994552, 0.1612218746117183, 0.10940201274518456, 0.1059056982131941, 0.08909255718546254, 0.1205553167632648, 0.11286461087209837, 0.09534006658941507, 0.16156141353505, 0.17111157679132052, 0.15472358545022352, 0.12533788941800594, 0.1622608338615724, 0.1449387576431036, 0.09086543348218713, 0.124581906412329, 0.09029610867479018, 0.1963261959276029, 0.09273304005286523, 0.1522671936878136, 0.09938171293054308, 0.10514419193246535, 0.09948412422090769, 0.09240131785294839, 0.2643863388470241, 0.06754955888858863, 0.10795127773391348, 0.16037369226770742, 0.13542067552251474, 0.08559563875730548, 0.17779123836330005, 0.16782864795199462, 0.1564824025013617, 0.127868987885969, 0.1774612667837313, 0.18558405020407268, 0.1626427405114685, 0.10411721561104059, 0.09900105478508131, 0.20963370613753796, 0.09098281325506312, 0.09781022582735334, 0.16449549395058835, 0.18706761273954595, 0.1604075783065387, 0.14152704285723822, 0.07658366233642612, 0.1415348867220538, 0.08010027185082436, 0.13187131312276634, 0.18113641600523675, 0.07694587111473083, 0.0820709275347846, 0.09546803829393216, 0.11766183988324233, 0.16931576601096562, 0.12188819024179663, 0.11845241460416998, 0.13397793365376337, 0.13735642736511572, 0.18243225504245075, 0.11385069867329937, 0.10783273766615561, 0.16802150117499487, 0.16537868870156153, 0.08887667448392936, 0.11389649978705815, 0.11924431925373417, 0.06304279036287751, 0.08885515135313783, 0.1035320470109582, 0.11316495761275291, 0.09565807559660502, 0.09761602910501616, 0.06550413543092352, 0.17415273003280163, 0.11906325896935803, 0.23239715823105403, 0.11845062327172075, 0.13517922562147888, 0.10713236739060708, 0.11432532034814358, 0.10130906450961318, 0.21224317540015492, 0.15240246642913136, 0.2103790090020214], [0.02286638755218259, 0.038333167521549125, 0.04193900099822453, 0.04333685099014214, 0.04877913270943931, 0.028604831147406782, 0.038512402546725104, 0.06717123490359102, 0.06354615478111164, 0.061115242008652, 0.024292372998648455, 0.026029756824885095, 0.019678943857018436, 0.0387829480293606, 0.046003130597195456, 0.056075986341706345, 0.026236704916560223, 0.034943203175706525, 0.02716735640673765, 0.04048725836245077, 0.032239875556635, 0.013709096919878252, 0.02736823839534606, 0.033499592782131264, 0.03576992345707757, 0.016385531651654413, 0.002367654861050791, 0.029524012003093958, 0.036708727545504055, 0.03495232268635716, 0.04756202069776399, 0.039679065479763916, 0.0952602776565722, 0.038102648819663694, 0.02783381350205413, 0.008224292259131159, 0.06102081707545689, 0.0028598970301183207, 0.029372104975794042, 0.05365448145728026, 0.0784260749018618, 0.0830994848428028, 0.019930890694792782, 0.04755076380180461, 0.025482075588245476, 0.059181742902312956, 0.03756437377472009, 0.02376294944302312, 0.05139501073530742, 0.0332705973913627, 0.012010903579981198, 0.08990825127278056, 0.08568097132125072, 0.025189820377688323, 0.03747245942109397, 0.047004994337580035, 0.033529679024858136, 0.06593908994857754, 0.04136324028617569, 0.012343849687437927, 0.02449811838700303, 0.057534409154738696, 0.04046927718445659, 0.02691628148646227, 0.03718234159584556, 0.043190402777067254, 0.030680374774549688, 0.009976141603796609, 0.040572987869381905, 0.03268374941710915, 0.06128512682127101, 0.07652262132614851, 0.029842319565692117, 0.018203761229025464, 0.03942616530028837, 0.07055953344596283, 0.03872756939381361, 0.024159602355211973, 0.04353826393240264, 0.06251619290560484, 0.04907134720789535, 0.04376193282327481, 0.024815640545317104, 0.051479661371558905, 0.01507394212032003, 0.035912161360361745, 0.030133428052067757, 0.0459232330987496, 0.03706447667043124, 0.039229932972895246, 0.006203671800903976, 0.021231109675552164, 0.014818436366372874, 0.033722549211233854, 0.011996145443325596, 0.08006287100059645, 0.011505530698091855, 0.04691859308098044, 0.04719104863969343, 0.01228843882147755, 0.0025453186535742134, 0.013095054958414818, 0.023634618114946142, 0.03162236797756382, 0.04047842383650797, 0.03645092834319387, 0.06215812319091388, 0.024863397536267127, 0.005182141571172646, 0.05678098422608205, 0.027494778390973806, 0.06879492849111557, 0.017780294309237173, 0.005093007938869829, 0.018564908100025992, 0.04916467969971044, 0.03059945608090077, 0.02892878751403519, 0.008506305831750589, 0.04690491042232939, 0.019432294681402187, 0.01182843279093504, 0.031588895845093896, 0.01260376167816243, 0.017720927584118078, 0.035770578243370564, 0.06067259968923671, 0.014275754236483147, 0.07368342046226774, 0.022249092015304735, 0.01369694181318794, 0.02514391069832657, 0.033259106400821886, 0.0215421501281006, 0.018114986796198145, 0.05627693109480398, 0.021160343562119772, 0.016449198592454195, 0.06480540042476994, 0.03032645090882267, 0.042839749450130124, 0.046702289687735696, 0.02925141734470214, 0.034642666445246766, 0.03523018277649369, 0.03106488360624228, 0.08816988526710443, 0.038235156530780454, 0.01222792622034571, 0.07308176346123219, 0.0490442091998245, 0.017592860884698372, 0.048809693926679235, 0.05210684146732092, 0.019597329664975405, 0.03331944852003029, 0.06328750401735306, 0.037151871980833154, 0.03734296101278492, 0.10907442960888147, 0.06070026356194701, 0.038871741121900935, 0.06567876998867307, 0.01767298229970038, 0.03959958867302962, 0.016410542452441793, 0.06825564921434436, 0.02853244503161737, 0.042754539022488255, 0.02560621017723211, 0.023014004541827098, 0.018549990507641008, 0.0959900827812297, 0.031810261109577756, 0.054525401509766064, 0.04357233317568898, 0.07658331628356661, 0.013065962769490267, 0.020072626482163156, 0.03132680830146585, 0.0342627105835293, 0.019971005685095276, 0.0152136728367103, 0.052407279810202975, 0.041579774381326776, 0.03694071527570486, 0.0036640089487523903, 0.009973517369611986, 0.03817008502249207, 0.029931346752813885, 0.06161533588809626, 0.013728924561291933, 0.01312324808843966, 0.04919382277876139, 0.013123181931275343, 0.03267490810581616, 0.02681608561293355, 0.024197237300021306, 0.019404018430837562, 0.018064206931740046, 0.06384447270206042, 0.05489286214911512, 0.019514297334743396, 0.02261651024621512, 0.02960996881925634, 0.07309292536228895, 0.03770699844296489, 0.02688957774080336, 0.08844735180693013, 0.08007137982973031, 0.03878250698159848, 0.049491438415965865, 0.041754256268697124, 0.049192693017955334, 0.022155749345464364, 0.019198161084204912, 0.024164221482351422, 0.08917547416474138, 0.04619028412603906, 0.057880156673491, 0.03388488532177039, 0.010385849529744258, 0.04808696252959115, 0.020104063009577136, 0.09202155537371125, 0.034274832611637454, 0.03800958774185606, 0.04714550876191684, 0.06393858550914697, 0.05221532903877752, 0.01055793194765491, 0.019102979584464004, 0.05819857958704233, 0.047667580390615125, 0.033754728734493256, 0.05114948283880949, 0.03356881692473378, 0.0377737662887999, 0.0227659745474479, 0.13905435268368038, 0.02577847664776657, 0.07233969720878772, 0.019153793375673037, 0.029134197027555535, 0.02419617708905467, 0.04429502725335104, 0.01891401267078306, 0.028162752012056962, 0.04906471113541296, 0.055325696244835854, 0.04960876390604036, 0.07513407404933657, 0.0900727417320013, 0.011167449776881506, 0.05976952386221715, 0.014183691453321703, 0.03195921311687146, 0.020158625706764202, 0.01920083790485348, 0.036691689531185796, 0.038554010314068625, 0.062278508873922486, 0.061902159425829134, 0.020142714060576897, 0.01142528120960508, 0.022895978464345847, 0.013222332860875343, 0.01356726444126772, 0.053623116176043234, 0.01902213552966714, 0.03914669368948255, 0.06571692401277167, 0.03671451884188822, 0.06172959439988647, 0.05872955359518528, 0.07430050056427717, 0.023212801731590713, 0.027730401372537017, 0.03748272226325103, 0.023067647824063897, 0.04708039314885225, 0.06496679676430565, 0.04025590166981731, 0.03710833038868649, 0.06621870065906219, 0.0872023825400642, 0.03518311619492514, 0.01977104989678732, 0.03333630332989352, 0.00811530087542321, 0.06865104514041118, 0.00933956803887018, 0.04757781020764794, 0.067679796900068, 0.011176403046452572, 0.009059663013821202, 0.038227713001625876, 0.014161448227241635, 0.060409972710268836, 0.009957096822160696, 0.023410263903705136, 0.03928956602300916, 0.08151969925633498, 0.04117815628913896, 0.03345082986301609, 0.02589148495878492, 0.03394224527957184, 0.043478742840566804, 0.08984818056757961, 0.0530492146499455, 0.020472322623910646, 0.04970094967367394, 0.024973861340965544, 0.017808704570467983, 0.03797742518197213, 0.05185132214267339, 0.04071858112833329, 0.0676843159432922, 0.04061485008735742, 0.03079882324008005, 0.027113382338679264, 0.062190638589007516, 0.06572486965784005, 0.04262646214504327, 0.042633030364023786, 0.031565136941415925, 0.04607623935277973, 0.02999033858733518, 0.03696570572044168, 0.012244763218664696, 0.055457918971244774, 0.03966223102595125, 0.01814856070892087, 0.025230573190908347, 0.05328792326950601, 0.0738614069830094, 0.06858681501554591, 0.0457106752188078, 0.03295297175645828, 0.07693286359842334, 0.05524019404713597, 0.06324752473405429, 0.04633948040593948, 0.018655202451295087, 0.04568649223074317, 0.06320334531899009, 0.07166232248502118, 0.03601896955764719, 0.06560662136014019, 0.024071721892271723, 0.046066828072071075, 0.0466908902994224, 0.14991520132337297, 0.11142755512680326, 0.10410916818571941, 0.1285712987716709, 0.08279907703399658, 0.08570018064762865, 0.12268598457532269, 0.17366383198116506, 0.2190472124410527, 0.12351598218083382, 0.09809785682175841, 0.0998362906809364, 0.07389674508678061, 0.14866599121264049, 0.1824567908687251, 0.1342772218797888, 0.06538545965616192, 0.0869497096698199, 0.14560578470783575, 0.14438854716718197, 0.10071172299129622, 0.08438511871333633, 0.141471728682518, 0.11202220286109618, 0.11954077120338168, 0.13599619535463198, 0.283676519457783, 0.1046555381534355, 0.10203560588083097, 0.16339340380259923, 0.15992078371345997, 0.09786572999187879, 0.16011994731213364, 0.16024787830454962, 0.13598087403391088, 0.10489803978375026, 0.09822199480342013, 0.11701366252132825, 0.12093859405389853, 0.09362253839416163, 0.1557738355227879, 0.244479451328516, 0.18092635513416358, 0.15054664601172718, 0.09862893939550434, 0.14088789001107216, 0.17138575922165597, 0.07848008628934622, 0.1745253950357437, 0.12438727542757988, 0.09567116453711476, 0.12071509818945612, 0.13732331485620566, 0.08016463768269334, 0.11329397426119872, 0.11634727327951364, 0.13936482316681317, 0.09921361266502313, 0.17367076660905564, 0.11974575663251535, 0.10532149991818837, 0.27001769095659256, 0.0939952169678041, 0.16916073432990483, 0.08888525795191526, 0.17252845290516103, 0.12232789450458117, 0.08745888913316385, 0.08973835288946118, 0.08742555270769767, 0.10803025921008416, 0.1537609885313681, 0.11408601461776666, 0.21542310262365, 0.20395064965954848, 0.1975025992308344, 0.14339875456477913, 0.1593434861195939, 0.10200413542666606, 0.1570044673447098, 0.15699751914611884, 0.1254666346524443, 0.11617451826376574, 0.1688059147979532, 0.13116368252251828, 0.09241507854312658, 0.1727022121527365, 0.07303274609148502, 0.07129858021757432, 0.15712930421744073, 0.1068816894133176, 0.08561883108424288, 0.11770647391676903, 0.11879683897963592, 0.13651314404393944, 0.24307569808193616, 0.16203790796654566, 0.11629828305116721, 0.14480405487120152, 0.1849485207349062, 0.11260417556124074, 0.09011332491146666, 0.13850575712110313, 0.0749071922951511, 0.16424161328801087, 0.21735122773264134, 0.11440521106123924, 0.10516814421862364, 0.10569468739309482, 0.16764732982431138, 0.08139792257653815, 0.15482793056539126, 0.11063178282763277, 0.10419492144137621, 0.1651725633335965, 0.08844159782997199, 0.10725971484290701, 0.08367179520428181, 0.1314186488411256, 0.09404601209930011, 0.1400757243058511, 0.072026682219335, 0.1579855339867728, 0.09676971273230654, 0.12680671417287417, 0.1568299617086138, 0.18145486606018885, 0.11936465065394129, 0.17062790345932755, 0.08297920772539717, 0.0846946799595441, 0.17541677291904176, 0.3295913285442761, 0.15522323149655545, 0.14196882343717984, 0.1763415482959577, 0.13992743726287568, 0.08761476219764777, 0.15391626448503562, 0.1382014477359397, 0.13943802352462495, 0.20615036519510405, 0.15882465110293456, 0.0854927660631282, 0.13958567274468286, 0.09811723578189101, 0.1647832335105964, 0.11666288705808775, 0.11880323077951159, 0.20365864889962332, 0.24040661273258074, 0.07467583220984254, 0.18395722178476198, 0.17231745565576212, 0.12315805495849677, 0.10552548790084464, 0.08533333747514657, 0.06729585464511599, 0.09746427474809544, 0.31031667281474384, 0.11414020242435591, 0.09259146372122423, 0.13114051733698162, 0.1411397757806948, 0.19011382785226616, 0.1838987727782556, 0.10116820742509194, 0.15278055971222265, 0.21415212510951928, 0.11065395056669201, 0.15713095984288625, 0.09619495964476041, 0.18243537630353654, 0.12052079290151596, 0.1184903582824128, 0.14245492592453957], [0.053263638501188586, 0.02293574740178883, 0.0180791635398886, 0.06237622470195804, 0.03219910917271461, 0.04384780821523496, 0.09076395178479807, 0.03152067932699408, 0.051160756698144336, 0.12986441009810992, 0.07004543460373368, 0.03710548393428326, 0.052083316658224375, 0.02068793730411146, 0.065372872831566, 0.01726074004545808, 0.020767448037596684, 0.013480890326068869, 0.004972021752369723, 0.027988580554457645, 0.026428764253588657, 0.02510211124484028, 0.034785080767635784, 0.011420753684693148, 0.030807756153600555, 0.05994233316076653, 0.043516007983790975, 0.03976913421813931, 0.02147516854373472, 0.07114955357142858, 0.03705849877691694, 0.0072620914350929, 0.014732364199257322, 0.048160783746945005, 0.010242603153788617, 0.029450482555798123, 0.028808262731347765, 0.08976070383297545, 0.07064629771879741, 0.023177275334351828, 0.0068647328464846525, 0.032177569078547616, 0.043397892000419755, 0.024671236418985894, 0.029132663538413386, 0.024064322467893362, 0.023575247997151952, 0.05308020334424717, 0.04663427673014147, 0.1259608388479267, 0.035571404466671605, 0.031034196860023906, 0.05343118576066835, 0.049709753665540896, 0.05221209242673857, 0.028575806811984097, 0.02227123939831342, 0.05738681421748229, 0.016990359107564603, 0.050477909589452405, 0.017676505592784712, 0.020633384784949676, 0.04804404518966164, 0.020553824857675602, 0.011613425399575914, 0.04174740985035896, 0.04690132097208074, 0.024533575234402503, 0.08607774467340537, 0.0465065425128809, 0.03702540323138237, 0.024090824349384223, 0.04222897633111902, 0.00267398458423226, 0.038782127001988034, 0.004757312492334417, 0.07883740961551666, 0.046097789624972005, 0.09881825066570725, 0.052674086564885716, 0.016155223295624768, 0.006155807092519743, 0.059773181165967665, 0.02490258802260671, 0.1105796102700489, 0.00849704722142113, 0.04598234367689916, 0.05182076771078365, 0.02166258161222296, 0.05244116924170937, 0.05375698434987238, 0.04708045082432883, 0.011900706948446376, 0.029830689475472485, 0.0400916928026293, 0.0329088839436216, 0.050460260893617354, 0.05343394400551915, 0.06472818313964776, 0.020074634945818355, 0.055398469125585895, 0.03244032837184412, 0.013317741669847496, 0.034108038526028395, 0.06171288886772735, 0.017201390283714448, 0.04764377059681075, 0.0591495939131294, 0.060651802590915134, 0.01990808343647846, 0.05282667551987937, 0.09329991534884487, 0.024665029519902806, 0.04446706980732935, 0.03863235396732177, 0.03763246815651655, 0.055214463999228816, 0.018939644331112504, 0.02412390971689352, 0.02789882054951574, 0.04335017741790839, 0.0332015191337892, 0.056539636105298996, 0.06551180287663426, 0.029777265020779202, 0.04541051507528339, 0.037179247476160526, 0.032246392885489125, 0.022967085541625108, 0.055285723746887276, 0.04802881207849298, 0.027769466329898154, 0.053969664366117547, 0.03488826219524656, 0.011344154714606702, 0.025667312255661403, 0.08315378121499505, 0.030214872610356127, 0.01827764181819345, 0.005122480955573597, 0.03481246304831334, 0.13450894158865723, 0.06322760973125696, 0.008843927893654575, 0.01531931056108858, 0.025994539161079695, 0.05432133888825774, 0.027731963699417453, 0.005982127572808946, 0.03177300275170377, 0.013813602338944162, 0.03013072069734335, 0.018673573786924993, 0.03099879090275083, 0.01624457278688039, 0.13519397697278432, 0.03819137066602707, 0.02915448522461312, 0.039061466298465214, 0.01870522744554494, 0.054975602709289105, 0.012076677372013884, 0.028002817915486436, 0.04823115800640412, 0.023656567026461874, 0.013419796729327312, 0.14910532906651497, 0.05090508470311761, 0.049085837323218584, 0.053707101847976446, 0.041658046788402965, 0.057774630907390795, 0.06925333317901407, 0.0489274876059166, 0.014118775159918835, 0.038754514019404135, 0.02796584284598274, 0.03520130093342491, 0.08196201587894134, 0.054825873779399056, 0.03491571572210107, 0.02411670028232038, 0.04455146599294884, 0.036359366827777455, 0.015197467724127429, 0.016481992189905474, 0.04131578354697142, 0.09729981143027544, 0.029645208535449843, 0.027746748977473805, 0.04097678066630449, 0.03396224170657141, 0.026071802247315645, 0.046503855514207056, 0.025173381170524017, 0.02977629132302744, 0.046571861686451096, 0.018040330980771353, 0.043989326871399365, 0.04241320876670735, 0.016409358408834254, 0.02674623721811388, 0.03439795618344631, 0.014834687280069505, 0.04992054056908403, 0.033281738936368904, 0.02279783346291099, 0.010357626713812351, 0.03562811981620533, 0.0666602233956967, 0.032008372978972535, 0.008315154035309595, 0.013178543603446866, 0.09274437158767666, 0.025933445564338138, 0.02051686675154737, 0.012346000643447042, 0.025632087806505815, 0.03366930456832051, 0.03356963795210634, 0.005365067826850074, 0.006689387523303074, 0.02396064401338143, 0.03621618576081736, 0.0375918306942497, 0.023674135994432226, 0.08806608297995158, 0.005929788774145501, 0.06507304856287581, 0.0969313397737486, 0.07068818368549858, 0.04456821223720908, 0.02609388856217265, 0.08758300675877503, 0.011096751516950982, 0.04863652161189488, 0.052092039225889106, 0.029893433608646904, 0.021834313736430237, 0.02166022200669561, 0.018965457499559437, 0.07445083678300891, 0.011402602872944303, 0.04532268550246954, 0.06427838227578572, 0.039579951869589944, 0.009526535818752433, 0.027113911595993807, 0.05171843784462128, 0.03759563388302922, 0.036980399396270514, 0.0037605237698049416, 0.0503803158977202, 0.03493061974378569, 0.031613625053848536, 0.03375925456306764, 0.009874342691286333, 0.011526610236614943, 0.05335512537775295, 0.02046729128674737, 0.006661225775522845, 0.07023968560887234, 0.05805914742606027, 0.022063507598691752, 0.016615042729037147, 0.04018957147906933, 0.013547881240291255, 0.05072002445480653, 0.03858341123642666, 0.024002877729279653, 0.01653227163478732, 0.007323364843614399, 0.028746644966304302, 0.028350283824173466, 0.006813033142991896, 0.03265920002013445, 0.09817246174705879, 0.020256672320621352, 0.04919192288070917, 0.05756049882620573, 0.029055578567619835, 0.04480098028268133, 0.033776618274194856, 0.033865289230431826, 0.10252526389168841, 0.02087471085334463, 0.019350324258474366, 0.034648946286844354, 0.049677112738468816, 0.01683548009688301, 0.07926323783716985, 0.008018378085190696, 0.018498849323285476, 0.0036834091131043223, 0.033845289410757165, 0.05517045761059437, 0.00742052766560976, 0.013685868121683598, 0.038601263492767296, 0.04919250302815011, 0.04504498826073749, 0.03730069167379822, 0.061627814147089205, 0.017603870115375946, 0.027671070270506398, 0.05321894000683512, 0.03915182002154844, 0.028436808913413967, 0.015578310770381774, 0.02482739446817764, 0.012146748835220933, 0.048837140668183565, 0.011725453227492315, 0.05368619618405189, 0.025441402502890145, 0.06339093989559583, 0.02596978111458676, 0.05308502433555467, 0.019573988060333898, 0.04139111789741686, 0.07406059093773365, 0.010439303670344608, 0.054702309159828086, 0.05685076476739986, 0.05711243501199143, 0.019966157552387034, 0.04772146964179618, 0.022019669147474424, 0.00714645380087729, 0.07477943772183997, 0.01838351702982826, 0.08140482327767781, 0.057598259299993515, 0.03529365294213806, 0.06255670823156834, 0.03365441072466118, 0.04868254324953471, 0.013533830476392592, 0.039335180539637804, 0.025131401905257787, 0.020080868986302187, 0.06581752361463648, 0.11528983073575155, 0.04112054527338062, 0.08785370151911463, 0.058402872910456996, 0.08732526523194142, 0.04853584058582783, 0.027101584311042513, 0.020456032694450448, 0.017182024894282222, 0.021169646277225444, 0.07537352227206741, 0.10798517734344516, 0.16272105702332088, 0.16115741378494672, 0.13743679305272444, 0.0824826422280499, 0.2022661186222519, 0.10832586299095835, 0.08573348993169409, 0.18069177200751646, 0.14311889958168778, 0.24389200285077095, 0.12071751377412251, 0.12239834001021725, 0.13276887924543448, 0.07438508673970189, 0.14022386207112245, 0.16510475054383278, 0.09633143339306116, 0.18521641993096896, 0.10577267820813827, 0.10267780534923077, 0.20248509544347013, 0.12335862991000925, 0.07506787617291723, 0.15861571659999235, 0.10638721380382776, 0.08245220993246351, 0.17726191319525242, 0.12505966291895934, 0.05350022330614073, 0.11130447565977063, 0.16705438521291527, 0.10841807589999267, 0.09411543980240822, 0.12223044330520288, 0.10642738986228194, 0.1666569129696914, 0.13225847163370677, 0.12821210947419914, 0.09941126313060522, 0.07710370514541864, 0.08267608577651636, 0.10497153869697026, 0.16227994140769753, 0.17146991113466875, 0.17888851091265678, 0.11196821182966232, 0.1314457766711712, 0.20733715008412087, 0.18710847411836895, 0.07930674550256558, 0.2105202121394021, 0.16634599465344632, 0.09978044724890164, 0.14565785548516683, 0.08384847893778767, 0.14709765251193727, 0.08063419748629842, 0.17719613601054462, 0.12308005057275295, 0.1040923540879573, 0.17565249598452023, 0.12141712409045015, 0.06749240588396788, 0.14077179266938142, 0.16536834782787732, 0.09305151046386786, 0.19017872294144972, 0.09684933881674494, 0.06730176468512841, 0.09432102234235831, 0.11572872075651373, 0.1222158819437027, 0.1414030473679304, 0.07758395866091762, 0.21864801671888145, 0.1521414475781577, 0.09914734014975173, 0.13399961963295937, 0.11222359205463103, 0.05343479895964265, 0.1619927039636033, 0.12317670110080924, 0.12720995396375656, 0.18081272765994072, 0.16762682449604782, 0.20236950021769318, 0.077576840828572, 0.06758563659553017, 0.12643912461187157, 0.20491236448287964, 0.09477266882147108, 0.1906138810196093, 0.1354801966143506, 0.07453526689537934, 0.15892948476331575, 0.1869042215070554, 0.19180609418877534, 0.11503122746944427, 0.15173287450202874, 0.11119157421801772, 0.11899602971971035, 0.12599825326885494, 0.13856925442814827, 0.09711197936641318, 0.08408217996891056, 0.11526112870446273, 0.18553037808409759, 0.07500060621116843, 0.24109562433191709, 0.2410463626895632, 0.14620098205549376, 0.10086112961705242, 0.1636801798428808, 0.08588772094143288, 0.17076067919177668, 0.1252796168306044, 0.16110180105481828, 0.1445691596184458, 0.09045331166791064, 0.09981718992016145, 0.0857273627604757, 0.15801629876451834, 0.07197421110634293, 0.1238607322531087, 0.14685332562242234, 0.16625169185655458, 0.09042780553655964, 0.14882255638284342, 0.18017949163913727, 0.17922477929719857, 0.1346367775861706, 0.13482146124754632, 0.0947023250960878, 0.14733142139656202, 0.09991206268646888, 0.15882083773612976, 0.11341887898743153, 0.1347801656063114, 0.1438520159572363, 0.210562742714371, 0.12121878830449921, 0.11698953381606511, 0.15338928704815252, 0.08076531080795185, 0.13230781470026287, 0.14236089454165526, 0.08611857891082764, 0.08858892135322094, 0.11490271293691226, 0.10780930785196167, 0.12283870923732008, 0.22109030852360384, 0.10162788097347532, 0.21604926830955914, 0.1533861793577671, 0.12510056500988348, 0.1814368034579924, 0.06612663024238177, 0.11917661502957344, 0.04905855682279382, 0.08717269663299833, 0.06982117199472018, 0.08236945580158915, 0.13537027394132956, 0.25287108389394625, 0.08578672778925725, 0.15631616142179283, 0.11847078933247499, 0.18056817006851944, 0.13836257266146795, 0.10516758103455816, 0.11843908817640372, 0.07443559010113988, 0.10486643362258162], [0.026043788929070746, 0.014805091278893607, 0.0400500239671341, 0.029056101039584194, 0.03224075425948415, 0.11149181917841945, 0.035405913168298345, 0.049027510453015566, 0.016850219573825598, 0.04594645595976284, 0.04740792539502893, 0.04249823259721909, 0.06695091458303587, 0.06388800750885691, 0.009131686961544412, 0.0719321555058871, 0.03172776142933539, 0.061531977861055305, 0.043784181986536296, 0.019335981724517684, 0.05244768317788839, 0.006685033448905284, 0.020615939649620225, 0.022016113623976707, 0.04167506444667067, 0.018059733689629605, 0.034248359567884884, 0.03288431419059634, 0.04650148742699197, 0.05426887456061585, 0.02264400787784585, 0.036661287769675255, 0.045053775289228985, 0.019738656634997045, 0.009380387009254523, 0.022387988133622066, 0.06516656425914594, 0.022928963747939894, 0.045926632559193034, 0.020755037632105604, 0.04446969573785152, 0.04599374306521245, 0.013580860586703887, 0.022499635981928025, 0.016814625323084847, 0.022480709943920374, 0.02248977347543197, 0.026747255020641854, 0.02059250813908875, 0.08867065089621715, 0.04501086812732475, 0.037799442053905556, 0.06031502530510936, 0.046192506328225136, 0.01706596147934241, 0.0444414890371263, 0.02026698096389217, 0.0663608198187181, 0.03613648164485182, 0.025391879624554088, 0.04716740169429353, 0.017303474180932556, 0.01820725398803396, 0.07622813034270491, 0.03016045070918543, 0.043497338092752864, 0.017413905755217587, 0.03592566420723285, 0.034458725779716454, 0.04424235936520355, 0.0621695090085268, 0.011116488404305918, 0.009989298397808202, 0.05725945319448199, 0.024094895559496114, 0.006279862377726073, 0.0123737959823172, 0.027987143756555657, 0.04090946999245456, 0.05514745866613729, 0.029770564487470046, 0.07772672921419144, 0.040385759701686244, 0.018396300629579594, 0.015066237355183278, 0.022997867282746092, 0.03333955690530794, 0.0375413239401366, 0.004215885228144803, 0.02024264700178589, 0.02615896685581122, 0.010863864727850472, 0.04336295423230954, 0.014683326473459601, 0.02426216801229332, 0.04513351672462054, 0.026378242232437645, 0.068219686858356, 0.03798362359936748, 0.032426208058106046, 0.032085787039250135, 0.048280551963086636, 0.06982473430356809, 0.02444223085019205, 0.01527960947714746, 0.05381668186081307, 0.018864174273663332, 0.03335217087130461, 0.04141269191833479, 0.02794421963127596, 0.03342324402183294, 0.02158545423299074, 0.029424555732735565, 0.03292446989299996, 0.0795213050608124, 0.03471611786101546, 0.017040569002607038, 0.0352365508276437, 0.07468723159815584, 0.01624255414519991, 0.04133222445047327, 0.015197464331452335, 0.015907485071303587, 0.01886509538495115, 0.10337274055927992, 0.023505308000104766, 0.006724817653386188, 0.021232263185083866, 0.056473387338753255, 0.042287313379347324, 0.02132582977148039, 0.006113460994259055, 0.0011718661303997838, 0.019860222968938093, 0.022354504126789312, 0.05793988811118262, 0.02987028538648571, 0.04306705868137734, 0.06861866544932127, 0.06739485290433679, 0.05261368677020073, 0.032412606823657236, 0.08730608983231442, 0.0822596891916224, 0.033171629666217735, 0.009054690200303282, 0.03875002211758068, 0.02184860877293561, 0.04563345793368561, 0.039725775830447674, 0.013048032481622483, 0.020739796039249216, 0.033308211980121474, 0.03094081347808242, 0.02816069944362555, 0.03824769246524998, 0.04261524596118501, 0.05466621448951108, 0.01967851977263178, 0.027478929509275725, 0.04124376384009208, 0.028615972692412988, 0.03358057254393186, 0.06976614959005799, 0.025310209453372017, 0.042325121350586414, 0.005043960459131215, 0.016947022772261074, 0.02753603671278272, 0.0456828620683934, 0.05387416734759297, 0.06548534679625716, 0.017030314642137716, 0.013009592624647277, 0.04445111744904092, 0.02480150666087866, 0.060859101824462414, 0.03380973417577999, 0.054357599799654314, 0.0197783153104995, 0.0708414443901607, 0.09091504117740051, 0.052403751428106, 0.06860083354903118, 0.031638693530112505, 0.027577155934912816, 0.034710893141371865, 0.008706738290909146, 0.05033050464200122, 0.051035146295492134, 0.02721224319455879, 0.03411835565098694, 0.06228369288146496, 0.00972769855122481, 0.042890517440225394, 0.026592971424439123, 0.058049003327531476, 0.04218743980995246, 0.016725570994562337, 0.010178992192127874, 0.02840614252324615, 0.0330386605512883, 0.0321113067413015, 0.027221211731167774, 0.05951480860156672, 0.012973247744542147, 0.0521893818596644, 0.0087686359516478, 0.06794501588280712, 0.04072927823290229, 0.03137350508144923, 0.02928959851020149, 0.034778349700250795, 0.01142554244558726, 0.029716858440744023, 0.014720595009358866, 0.05656804297385471, 0.026730164419859648, 0.02661131731500583, 0.04305516056982534, 0.020352289779111743, 0.1859332514660699, 0.040230938366481235, 0.07090942681367908, 0.028315354537750994, 0.024258235901860253, 0.022242486476898193, 0.028632389847189188, 0.023846217564174106, 0.05745705616261278, 0.02790326495388789, 0.0653409884710397, 0.05778545354093824, 0.016771864046209624, 0.058245893833892684, 0.040260417320366414, 0.06946646781372172, 0.0034532019012008925, 0.01387777309199529, 0.05015650451449411, 0.041247434714542966, 0.031167440781635896, 0.04643228703311511, 0.03156959152381335, 0.00997640029527247, 0.031909615599683354, 0.022188242691169893, 0.04030854920191424, 0.05157860195530312, 0.011956980402049209, 0.02281692234932312, 0.03179246313603861, 0.03152542228677443, 0.03684100116203938, 0.030599347515297786, 0.06001537745552404, 0.030142924149653742, 0.010177496022411754, 0.04847077586288963, 0.04223897454461881, 0.033307387560073815, 0.0549273622621383, 0.014146613755396433, 0.04149289136486394, 0.013629213840301548, 0.017329865800482885, 0.03010941469775779, 0.044348234576838355, 0.04103466648874538, 0.013360524150942053, 0.047866703277187686, 0.05101107187303049, 0.007899324875324965, 0.06767782914851393, 0.02245224709622562, 0.039973542892507145, 0.05080087190227849, 0.04773072485945054, 0.01032531657256186, 0.03316952281498483, 0.0419610567790057, 0.047174482207213125, 0.021821687896070734, 0.029699833997126137, 0.02029599851396467, 0.053998505497085195, 0.022738442989066243, 0.016876813057543974, 0.027415228641725013, 0.02067916384632034, 0.03915829324562635, 0.02711157573919211, 0.019636774601946985, 0.03307346261239477, 0.01636287197470665, 0.022017709877608076, 0.027129037837897028, 0.034569238778203726, 0.011939071318400758, 0.05641043285972305, 0.01980452542193234, 0.006823814216269446, 0.019235736657200114, 0.01770017289423517, 0.03533215301909617, 0.06651837565004826, 0.0327382934545832, 0.05915681352572782, 0.016692507679441144, 0.027497048090611185, 0.013210452560867583, 0.030407508702150414, 0.023937829969716922, 0.01891116112736719, 0.0177952169906348, 0.02349257020146719, 0.018039691461516277, 0.027703426212870648, 0.04014553455635905, 0.10718536776091371, 0.06645797246268817, 0.007518043325814817, 0.027018411184794137, 0.03411110889698778, 0.0798725283571652, 0.014891635027847119, 0.009920896978915801, 0.020243286521040967, 0.012673597350450498, 0.01124881036646132, 0.033478120541466136, 0.025916760388229574, 0.015373350786311286, 0.03412987717560359, 0.014560060409296836, 0.06424879814897265, 0.0197708599069821, 0.02414124967929508, 0.1066820847668818, 0.042751092064593516, 0.06377444110278573, 0.10185578053018876, 0.05427071339051638, 0.020287284427987676, 0.060452530426638465, 0.01158755794832749, 0.010864914760791829, 0.09832919655101639, 0.048176759853959084, 0.01733134500682354, 0.02839557094765561, 0.02732569255333926, 0.16711455769836903, 0.11939192776169096, 0.1774262408060687, 0.09499617825661387, 0.11246740325753178, 0.21724230929144792, 0.12742466958505766, 0.10887297934719495, 0.08027068592075791, 0.1359631506992238, 0.1316372999655349, 0.11293118194277797, 0.15009472811860697, 0.18522168536271366, 0.08852707967162132, 0.27229868141668184, 0.14173501384045395, 0.15135528333485126, 0.10402370670012065, 0.13018253445625305, 0.12103196047246456, 0.2573151897106852, 0.13032436184585094, 0.12592550074415548, 0.08490093424916267, 0.20912213144557817, 0.12506695038505963, 0.10674458462744951, 0.0693411220397268, 0.11819211500031607, 0.16896356562418596, 0.13126135085310253, 0.1383051685988903, 0.12734164404017584, 0.132331251299807, 0.08686052981231894, 0.1717224075858082, 0.12527642771601677, 0.13019808647888048, 0.16640371084213257, 0.20722524608884538, 0.17982454997088226, 0.10324729979038239, 0.1274617040263755, 0.06316084188542195, 0.26401238462754656, 0.06136220161403928, 0.10377747312720333, 0.10450757680726902, 0.10830224318695919, 0.10780143684574536, 0.11748399585485458, 0.12322216294705868, 0.25589496163385256, 0.08558987799499716, 0.13320506869682244, 0.06620436999946833, 0.12340623592691762, 0.13871664580489906, 0.09680160387818303, 0.16830093546637467, 0.10153547128928558, 0.09513765959335224, 0.14160640431301935, 0.12112505547702312, 0.13532243722251483, 0.18587672949901649, 0.11660169677010604, 0.1051713740453124, 0.13655262121132442, 0.21503025798925332, 0.10730598414582865, 0.15506036952137947, 0.15243271552026272, 0.13369722371654852, 0.12970491365662642, 0.1314624279205288, 0.12708499495472225, 0.13661279369677815, 0.2379455662199429, 0.10750803830368177, 0.14583652732627733, 0.1091875210404396, 0.052049193132136545, 0.10367394225405795, 0.15148185725722993, 0.058303481100925376, 0.2103811531726803, 0.12896408912326607, 0.13925378769636154, 0.13575873523950577, 0.117821051340018, 0.09941595180758409, 0.17656186861651285, 0.17934869336230413, 0.14815824345818587, 0.08584170948181834, 0.12669348024896213, 0.08245067644332137, 0.14943843547786984, 0.14105973578989506, 0.14230095275810786, 0.14709383914513247, 0.11152052120970828, 0.08692161153469767, 0.12723881884344987, 0.14661235069589956, 0.12913920544087887, 0.12132294342986175, 0.11716550508780138, 0.10951009658830506, 0.10556071065366268, 0.05844798870384693, 0.0922895088525755, 0.12918816852782453, 0.14677491411566734, 0.09879714144127709, 0.11950103619268962, 0.10815367794462613, 0.12335002608597279, 0.08335250376590661, 0.11830511822232179, 0.1420501119324139, 0.23019186513764517, 0.16187884578747408, 0.08940587751567364, 0.1478418968617916, 0.0810997471479433, 0.15448565036058426, 0.17104465966778143, 0.0872680918712701, 0.1095976818885122, 0.06440904097897665, 0.12752801046839782, 0.1303171015211514, 0.15371658519974776, 0.17249843451593602, 0.09242251528693096, 0.11410380580595561, 0.14787719425346169, 0.2057042419910431, 0.09699996002018452, 0.14436013012060098, 0.2276215609163046, 0.19773088555250848, 0.09488610630588871, 0.14061771093734673, 0.13723590597510338, 0.13168871934924806, 0.15099959527807577, 0.10668224082993609, 0.09516585950872727, 0.10021139162459544, 0.13575285912624427, 0.07965070847421885, 0.09225455751376492, 0.15114235904599937, 0.17717430075364454, 0.07514904931719814, 0.15479449235967227, 0.10062707574771983, 0.12202203805957522, 0.18620283342897892, 0.128263189590403, 0.12221865036657878, 0.13385055906006268, 0.07793820822345358, 0.10470746643841267, 0.13415930606424809, 0.09192548160042081, 0.0974657471690859, 0.26025156357458656, 0.13831598444708756, 0.11412329333169119, 0.10156145918049983, 0.10570686709667955], [0.06203286562647138, 0.020040748906987052, 0.01524004410021007, 0.017586063660149063, 0.053141142574271986, 0.018856805383360813, 0.03543410969099828, 0.09737966821662017, 0.04622938470648868, 0.03490274552521961, 0.046918674505182674, 0.013210391492715903, 0.07033345236309937, 0.045424106131706915, 0.042831817375762124, 0.015670443951551403, 0.05638588346274836, 0.09261414036154747, 0.04297786186050091, 0.02809142610723419, 0.038821397216192315, 0.03843422852722662, 0.07245302612760238, 0.0553191958793572, 0.07358311263046094, 0.03641214667420302, 0.06177570763975382, 0.001951996607073982, 0.04746678152254649, 0.03613049018063715, 0.0073998060543090105, 0.03903206876878228, 0.05687995534390211, 0.03811364447964089, 0.04172598171447005, 0.012644476323787655, 0.03537838839526687, 0.08112526006464447, 0.08277846992548023, 0.0567367810622922, 0.09227992793811218, 0.028046742879918644, 0.04025357090202825, 0.035251319142324586, 0.036755780556372235, 0.04604488085689289, 0.04541658117835011, 0.01279259373300842, 0.023880034053165997, 0.045718006789684296, 0.05855856277048588, 0.02439465876003461, 0.023752969889236347, 0.02509318681300751, 0.045623809165720425, 0.04350132787866252, 0.036141964207802496, 0.017639566146369492, 0.014549863724304097, 0.06212450856609004, 0.008510511052528662, 0.011035061657561787, 0.012015779702258962, 0.026826987974345684, 0.09205792485071079, 0.08395179946507726, 0.007136711734347045, 0.05040930291371686, 0.011756442769962763, 0.03388495996062245, 0.06618693843483925, 0.05152757612190076, 0.037954748541648896, 0.027894069108047655, 0.02308722016667681, 0.04674076601596815, 0.07213749377323048, 0.020042660679402094, 0.028743835831327096, 0.024075966128813367, 0.025691893883049488, 0.025038174586370587, 0.03225442674010992, 0.02695796389265784, 0.043501796067825386, 0.020596475872610296, 0.013808553190236645, 0.024523042674575533, 0.015745973380814706, 0.01090544874646834, 0.03842232363032443, 0.05533642049080559, 0.02998824869947774, 0.050410805868783166, 0.02084019547328353, 0.011292897331129228, 0.05218094427670751, 0.034329722701971016, 0.015341357860182012, 0.05600553744339517, 0.011394222965463996, 0.038420101428138356, 0.04632769085999046, 0.03183305649352925, 0.04318853002041578, 0.03440074156969786, 0.057938666748149056, 0.06375785092157976, 0.027725320841584886, 0.07113878522068262, 0.023837323666417172, 0.10510697428669248, 0.014315994755764092, 0.06263833599431173, 0.02395176368632487, 0.054120278784206936, 0.028320267131286006, 0.09885512904397079, 0.01143941848671862, 0.02387238017815564, 0.030473540337490182, 0.036685192558382235, 0.04284102848864027, 0.05369479661541326, 0.027239265851676464, 0.050832267717591355, 0.06801665561007601, 0.07276724890938827, 0.04633749229833484, 0.026168205110090118, 0.018665694299020937, 0.03682570359004395, 0.026977193575086336, 0.020675791527277658, 0.06891194864043168, 0.10950675819601331, 0.0840903427451849, 0.022682748834735582, 0.025640410038509538, 0.05194385057049138, 0.04530993243679404, 0.011277140051658665, 0.025398715864866972, 0.07357065472751856, 0.009029625964883183, 0.014086541353857942, 0.02944329008460045, 0.03246598378089922, 0.007010157743934542, 0.0696996192314795, 0.049113633510257514, 0.050162312774253745, 0.029320821299084594, 0.014968645359788622, 0.0518438887915441, 0.056659546813794544, 0.017022060263635855, 0.050767067287649424, 0.02151313766704074, 0.03020667251465576, 0.05425154816891466, 0.08919403209750142, 0.026320856829573, 0.01656972846415426, 0.03509971406310797, 0.012391713547653385, 0.023650382179766893, 0.03028550132044724, 0.04546775628945657, 0.03098712010043008, 0.05313165665471128, 0.04126401132504855, 0.019078686334458844, 0.07563429685043437, 0.02655845943705312, 0.036445700230875185, 0.05226660932281187, 0.06934180736009564, 0.018862389726564288, 0.019198664896456257, 0.07256834315402166, 0.044203832146844695, 0.023873715195804834, 0.05762414541095495, 0.015505705827048846, 0.035799239562558274, 0.08489507170660154, 0.06570629815437964, 0.0639178359082767, 0.04357104056647845, 0.060881873459688256, 0.01757135132460722, 0.026763080153614283, 0.04793958133086562, 0.0275675750204495, 0.015969942523432628, 0.06596455536782742, 0.03777394610057984, 0.023585704221789325, 0.07276324555277824, 0.07523442937859467, 0.019920057883220058, 0.014179853489622474, 0.03645981375926307, 0.035727854285921366, 0.046978372016123364, 0.004451268602029553, 0.0737230469073568, 0.03660607198253274, 0.038519418598817926, 0.013774920753868563, 0.019536404005650963, 0.0426320702369724, 0.01781718116918845, 0.008924811812383788, 0.04030955004106675, 0.029550142386662107, 0.055954012886754105, 0.03614479030615517, 0.010904603122201349, 0.019779214369399205, 0.06335150344031197, 0.04916412330099514, 0.023782911943271756, 0.012127666734158993, 0.026478784158825874, 0.07941126703683819, 0.013859648573478418, 0.010384439873243017, 0.046516388056001494, 0.007404754270932504, 0.024762161807822328, 0.05615160567685962, 0.0363767135755292, 0.024634305454258407, 0.06633142568171024, 0.030478303653321097, 0.015204417619055935, 0.013968689150975218, 0.037032035911189656, 0.05030857778287359, 0.03215378981881908, 0.026001090416684747, 0.023649206617847085, 0.048128594045660326, 0.04659083013289741, 0.022777183945955973, 0.026215768718559827, 0.06563641583280903, 0.016259916159989576, 0.047639909732554636, 0.035617836617997715, 0.0376651260469641, 0.006903810102293002, 0.02633717898944659, 0.046672596995319636, 0.03247028569291745, 0.010103135369718075, 0.011265833113741661, 0.06425358860620431, 0.06186351007116692, 0.018829066871798465, 0.009578853413196546, 0.07417933456599712, 0.03245296608656645, 0.008539962016844323, 0.014781371390979205, 0.04822917668414967, 0.017796083819121122, 0.07184320635029248, 0.03001113568565675, 0.02436342748946377, 0.00608155076458518, 0.03276373851778252, 0.06727171236915247, 0.023640390751617293, 0.04182304275621261, 0.03213067891608391, 0.013220447381692273, 0.005978993589191565, 0.03198066160881093, 0.0709656977227756, 0.053915856539138725, 0.02976234403571912, 0.019742551426004087, 0.025296409747430255, 0.01569681691138872, 0.023827674898451993, 0.02249134937301278, 0.011451360703046833, 0.04722978620390807, 0.02334465635275202, 0.023948007994996648, 0.08418182283639908, 0.14730103659842694, 0.030842531073306288, 0.07238752714225224, 0.05718834950987782, 0.06806296562509877, 0.09015484446925776, 0.025179954478517175, 0.024056183440344672, 0.012757269199937582, 0.05313074741778629, 0.02228075245927487, 0.024143487148519074, 0.03748932440898248, 0.09181638674012252, 0.04628544526972941, 0.009266805336145418, 0.04362943529018334, 0.05632600614002772, 0.012334209401160479, 0.031526643649808, 0.015176238059731466, 0.03401759998606784, 0.035022744443267584, 0.05167612100818327, 0.06367795342313391, 0.02458433643914759, 0.015877582033031752, 0.02276493638886937, 0.05531742151028343, 0.05316825683361717, 0.02291621746761458, 0.01906451004158173, 0.08299002357359443, 0.12185585126280785, 0.06073436673198428, 0.007057742132539195, 0.030532583062137877, 0.006821415594978524, 0.01575258231189634, 0.031141371466219425, 0.009453591607910181, 0.005582047634691532, 0.03688433240833027, 0.030777313679988896, 0.008792287986060339, 0.04837018983172519, 0.010844747851868826, 0.021993515015180622, 0.03894783203889217, 0.03940116467752627, 0.029495330327855687, 0.047430720778980424, 0.06982009990939073, 0.08624188229441643, 0.048420801758766174, 0.026729569005380784, 0.08340546342411212, 0.02457556128501892, 0.19411651949797357, 0.18227541845824036, 0.12821802629956178, 0.05733092328799622, 0.1376817034823554, 0.1628299347524132, 0.1530125644057989, 0.17054441651063307, 0.06566836126148701, 0.10028968099504709, 0.1187864031110491, 0.1528867504426411, 0.13530588096805982, 0.182524210108178, 0.1621185043560607, 0.11237972974777222, 0.151625910241689, 0.18309400310473783, 0.0824889118916222, 0.1309807901935918, 0.12898349522479943, 0.14483699096100672, 0.1466700533138854, 0.15811288143907273, 0.17222221648054464, 0.09602384668375764, 0.15557300272796834, 0.09969613248748438, 0.14776607735880784, 0.0835140086710453, 0.07588190784943954, 0.20197437570563384, 0.1413271464407444, 0.1461710858025721, 0.1600762903690338, 0.1555850263684988, 0.07372736239007541, 0.1687486328716789, 0.17290335707366467, 0.21588207728096417, 0.21221009003264563, 0.13416339084506035, 0.09072527528873511, 0.11627886337893349, 0.10743998124131135, 0.13040900230407715, 0.14225114828773908, 0.07051800031747137, 0.058931621323738775, 0.12230179804776396, 0.17012763316077845, 0.1222605159772294, 0.12154998124710151, 0.21117790256227764, 0.1368493852870805, 0.1258952652237245, 0.1216640972665378, 0.10094620433769055, 0.14491750592631952, 0.2582277107451643, 0.11366345014955316, 0.1039768945691841, 0.12913611132119382, 0.2941357839320387, 0.2047992255538702, 0.15178464672395162, 0.09005871641316585, 0.09319986536034516, 0.19320650904306344, 0.1284024521176304, 0.105442068805652, 0.09172142576426268, 0.11795814255518572, 0.1916817594319582, 0.11310100568724529, 0.157180872878858, 0.12287335523537227, 0.12169338283794266, 0.13439467629151686, 0.06322506522493702, 0.1599549547369991, 0.12049776342298303, 0.13445419738335268, 0.20593399394835743, 0.12809438364846365, 0.09136414993554354, 0.11718900954084736, 0.23303644678422383, 0.08900666143745184, 0.10146575860146965, 0.08200373221188784, 0.13277200050652027, 0.0915166846077357, 0.20704774132796697, 0.1126537968271545, 0.14211921393871307, 0.06727866735309362, 0.15489889175764152, 0.190364627965859, 0.14059534642313207, 0.1097563233758722, 0.11605186627379485, 0.17427751262273106, 0.12795676317598137, 0.14501814624028547, 0.13969913737050124, 0.12661700935236045, 0.13678523658641747, 0.09120685194752046, 0.1254409317459379, 0.14289213317845548, 0.2024032369788204, 0.08617327561868088, 0.14871770915176186, 0.10550892486103944, 0.17108006562505448, 0.09082392070974622, 0.12536583149007388, 0.22731608445090906, 0.1112855581034507, 0.14643762792859757, 0.16909334223185266, 0.20227740944496223, 0.1989987553762538, 0.14817209914326668, 0.20249086299112865, 0.12440153823367187, 0.11176973355135747, 0.18283240071364812, 0.08099258611244814, 0.15992956395660127, 0.13655688241124153, 0.12862794287502766, 0.09460825300110237, 0.26066104588764055, 0.20402610275362218, 0.12045962975493499, 0.09419825500143425, 0.0628684882872871, 0.1095251872071198, 0.11530356428452901, 0.2003726259406124, 0.07803127608661141, 0.11812755917864186, 0.07381308850433145, 0.08763286551194531, 0.11122610486511673, 0.1252666296703475, 0.07194386702030897, 0.14247585194451468, 0.2344897873699665, 0.19485441276005336, 0.14941647808466638, 0.09357331067855869, 0.12309009289102894, 0.19566569636975015, 0.055991820857993195, 0.13849825252379688, 0.08954938088676759, 0.15734572974698885, 0.1531043430524213, 0.12275866924652032, 0.08537774080676691, 0.09340394833790404, 0.05632435729993241, 0.10530268414212124, 0.0571421209190573, 0.15286834857293538, 0.07115481900317328, 0.10009340117020266, 0.14838671976966517, 0.1368019421185766, 0.10105104478342192, 0.16510878104184354, 0.12516844565314905, 0.11614479842994894], [0.04566422610410622, 0.036590085697493384, 0.044514431551631005, 0.00884836890535163, 0.026283228670113852, 0.024221455911174417, 0.015705442787813287, 0.04430596184517656, 0.11297718661704234, 0.018816001680014387, 0.0185335038030254, 0.023906712353761708, 0.025609774182417562, 0.003788364485704473, 0.02305398552146341, 0.011415222776122391, 0.021466395085943595, 0.03930118932787861, 0.024508048747000948, 0.03128991974517703, 0.072926026103752, 0.04897768223392112, 0.018620144243219068, 0.04061728942074946, 0.08636301436594554, 0.017493708258760825, 0.024833092465996742, 0.0659960393926927, 0.02081514904940767, 0.04264827026054263, 0.019656830400760685, 0.03498441060738904, 0.034716256960694275, 0.038685788600040336, 0.043066074805600305, 0.07532426741506372, 0.02466811176522502, 0.021303334639274647, 0.01340591220650822, 0.02473465569450387, 0.014153975860348769, 0.039124437740870883, 0.03483293784250106, 0.010920115280896425, 0.02079909491086645, 0.04181239654177001, 0.03785399626940489, 0.047120491175779274, 0.047075168429208655, 0.05426045733370951, 0.040664240651364834, 0.06461437246096985, 0.0484153158031404, 0.06264955217817, 0.04094886912831238, 0.05281359336471983, 0.02818786459309714, 0.07233810265149389, 0.033166187815368176, 0.027108607148485522, 0.043478535887386115, 0.005842861228822065, 0.04106414204995547, 0.032600208185613155, 0.028347744406866174, 0.03128744648503406, 0.016469695439030017, 0.03258327195154769, 0.033908033543931584, 0.018829813260318976, 0.02553483168594539, 0.06471097549157483, 0.1000712402164936, 0.032540212119264264, 0.03219530259125999, 0.03812222116227661, 0.027255535425086106, 0.01696746703237295, 0.023434345111516968, 0.0372361392447991, 0.014783493509250028, 0.07911925949156284, 0.05383256636559963, 0.028379431992237057, 0.03212408694837775, 0.041237514532570324, 0.06298574592385973, 0.04770095752818244, 0.040377793700567315, 0.016413438100633875, 0.043209130343581946, 0.021471675784726228, 0.08286127833915607, 0.04579821302156363, 0.018548283992069106, 0.025475593882479837, 0.03124603210017085, 0.03390606239970241, 0.0255570418334433, 0.04994695933003511, 0.04218895633571914, 0.049536934188966236, 0.07083097459482295, 0.022596909065863917, 0.03141796269587108, 0.010237108716475112, 0.017629381335739578, 0.022049239703587124, 0.020186567778832147, 0.009373210653263544, 0.013185669069311448, 0.006885613913514784, 0.04924482825611319, 0.024984412560505525, 0.006715900855072374, 0.03068796418873327, 0.022453950219122425, 0.0315578698313662, 0.03128868481144309, 0.024425996899870888, 0.03703776613942214, 0.05925764382949897, 0.05069511882694704, 0.09232064682458128, 0.04037405497261456, 0.037063017820141146, 0.0127877829197262, 0.054428689913558106, 0.03156697916399155, 0.006668899582499372, 0.09075662360659667, 0.05194793874397874, 0.03215650735156877, 0.034420663357845376, 0.03627368821097272, 0.03560220995651824, 0.04315916981015887, 0.05159578924732549, 0.041839008685201406, 0.012908137220490192, 0.03638752603105136, 0.02874723189909543, 0.03687600339097636, 0.02589226697039391, 0.010880306479521096, 0.01834394656387823, 0.05597792785348637, 0.024044529601399387, 0.03756640598710094, 0.0968234052083322, 0.03355907316186598, 0.013251222337463071, 0.03941250639036298, 0.01746631071104535, 0.008098113583400846, 0.031626286517296515, 0.0734984382454838, 0.05928738401936633, 0.02690781167309199, 0.01185129433205085, 0.03792728144409401, 0.04732899141630956, 0.007892434352210589, 0.015045854163223078, 0.03762681595981121, 0.04348827625757881, 0.013247660876783942, 0.03905203126903091, 0.013596968159877827, 0.04783138892214213, 0.05756279227456876, 0.026345209451392293, 0.08456979558936187, 0.016889320154275213, 0.056385930960199664, 0.049676081365240474, 0.012632734275289943, 0.03077583447364824, 0.04408507155520575, 0.029517094338578836, 0.0578603773776974, 0.05318226179640208, 0.016742230725607703, 0.0361493941662567, 0.025433862282495414, 0.02504695313317435, 0.030078612600586245, 0.09479907061904669, 0.012723789433948696, 0.02691011021046766, 0.043795092829636166, 0.016643254518775002, 0.01703554784346904, 0.06735454113887888, 0.026403286959975958, 0.01856001416620399, 0.05873370622949941, 0.03968373719336731, 0.034403187688440084, 0.030184745655528138, 0.08154896447168929, 0.06673652465854372, 0.0014413829963554495, 0.03308718937582203, 0.024130343925207853, 0.011385037297649043, 0.07624679684106793, 0.02478562724510474, 0.028364170043330108, 0.042436842141406875, 0.071513607964984, 0.15036768918590887, 0.07564008475414344, 0.04979698612753834, 0.009230748833423215, 0.06887091762785401, 0.01641112090354519, 0.0037997503033173935, 0.009986205126291938, 0.05736812736306872, 0.05567434110811778, 0.02557179148841117, 0.06127586481826646, 0.029272984580269883, 0.0064368219464086, 0.07285017267401729, 0.03004938131198287, 0.10250495533858027, 0.0648691827165229, 0.058907119424215386, 0.00567248702282086, 0.06827044127775089, 0.024353556501279985, 0.04531399346888065, 0.024501945324508206, 0.05926990495728595, 0.07003594868417297, 0.02557037504655974, 0.008184821028927607, 0.03255275483908398, 0.012774318240449896, 0.06184923369437456, 0.018890333494969776, 0.08560198305972985, 0.018071027905015007, 0.0184363358920174, 0.054527762811630964, 0.016329118250203983, 0.05748544606779303, 0.0125775956715058, 0.022582261191148843, 0.042482636469815455, 0.024960378850144998, 0.017972942275394286, 0.06389725594116108, 0.035109233909419606, 0.012384788249619305, 0.09425161499530077, 0.05660834116861224, 0.0214936043401914, 0.03148150071501732, 0.048869035206735134, 0.015075034561700054, 0.025320948966379677, 0.008579187278103615, 0.026850502605416944, 0.0419682831769543, 0.055876303663743396, 0.03690002353063651, 0.05030004859768918, 0.03882246930152178, 0.07701529203248875, 0.01639413377935333, 0.03152600921956556, 0.007849431347234972, 0.06990746807839189, 0.05014709323378546, 0.016800747585615942, 0.05073066049122384, 0.017579395357253294, 0.01678747544065118, 0.05410857066246016, 0.024260534439235926, 0.027664961759001017, 0.05810977292380162, 0.014609333926013537, 0.032392718962260654, 0.03692800631480558, 0.048643551234688075, 0.023922425528456057, 0.017796166939660907, 0.028558867185243537, 0.05973433503615005, 0.07340530252882413, 0.04059335749064173, 0.011137327911066157, 0.004261070571374148, 0.08628733735531569, 0.006749925569498113, 0.034482959657907486, 0.041319084619837146, 0.06385849802089588, 0.027608709509617517, 0.053537797182798386, 0.034851268466029844, 0.027916274166532924, 0.035172724431114535, 0.0051174771838954514, 0.02972513996064663, 0.03620791102626494, 0.023526600428989956, 0.007359477325475642, 0.04847317787685564, 0.02577061581957553, 0.0611415013138737, 0.01406736595423094, 0.023100097064993212, 0.05833223062966551, 0.019589338218793273, 0.05516061546014888, 0.08241081251097576, 0.028055587583886724, 0.044016475057495494, 0.03251676194901977, 0.05830669057156358, 0.041218491803322516, 0.022499871772847006, 0.033723302385104556, 0.06088276234056268, 0.030256460021649088, 0.04052413334803922, 0.040536526790154834, 0.07798758521676064, 0.024220740056729743, 0.031131084875336716, 0.008124069244201695, 0.054310662139739306, 0.061606209592095444, 0.007745587499812245, 0.021634609006079178, 0.10120037677032606, 0.030778738603528057, 0.0018968357388595386, 0.014284790626593998, 0.027818378526717424, 0.07020844585661377, 0.01580331807157823, 0.048104024292635064, 0.043503400803144486, 0.048174781924379725, 0.020012864510395696, 0.018017974948244433, 0.17263794131577015, 0.09657420643738338, 0.1902898262654032, 0.08716511061148983, 0.14356201009026595, 0.1250032495175089, 0.0993159900286368, 0.12301115212695939, 0.1670318849916969, 0.11650926672986575, 0.11966392530926637, 0.14930715252246174, 0.11254933636103358, 0.16685999850077288, 0.15756191100393022, 0.09538153864975486, 0.10038842141096081, 0.12333998376769678, 0.07301173864730767, 0.09539137062217508, 0.16190688285444463, 0.15232210074152264, 0.10935294787798609, 0.10395285407347338, 0.2589547745883465, 0.14165831224194594, 0.09859081251280648, 0.1163098859999861, 0.06397890405995504, 0.12864550336131028, 0.17054643854498863, 0.15208529202001436, 0.12484155462256499, 0.14227853396109172, 0.08404578335051026, 0.17080075346997806, 0.1128833791507142, 0.1143044214695692, 0.18870774044522218, 0.11609605247420923, 0.1223821501646723, 0.10647720111800091, 0.09481224776910883, 0.09378670315657343, 0.16775780889604772, 0.10566939839294978, 0.15083692329270498, 0.14179190221641744, 0.11383943499198981, 0.11195213733507053, 0.12986758564199719, 0.12978237521435532, 0.2144682952868087, 0.1900183851165431, 0.15567611290940217, 0.13306881886507782, 0.14138816030962126, 0.18926515696304186, 0.12358095869421959, 0.09357865753450564, 0.12971503739910467, 0.12560631787138327, 0.11814582534134388, 0.14400220289826393, 0.11104797585202114, 0.13835596373038633, 0.09954515166048493, 0.1826974536691393, 0.09337884932756424, 0.04044711962342262, 0.13005735831601278, 0.07349956461361476, 0.22619984006243093, 0.09407054114022426, 0.15960043376045568, 0.07427238885845457, 0.1603145104433809, 0.0788942708500794, 0.13132916364286626, 0.09337727512632098, 0.11167671318565096, 0.19025053908782347, 0.1402320180620466, 0.13910753625844205, 0.1289129682949611, 0.09237027487584523, 0.16655385707105907, 0.11257980936872107, 0.13316894349242958, 0.08357602677174977, 0.15224860182830266, 0.06603438340659652, 0.168391329901559, 0.14920880565685885, 0.1428156622818538, 0.10583886251385723, 0.17444842202322824, 0.09321999749434845, 0.04846438067033887, 0.13114306862865174, 0.17942166301820958, 0.24591276156050818, 0.10214425290801696, 0.11954041836517197, 0.16305275208183698, 0.08347969515515224, 0.1113861712760159, 0.12752685695886612, 0.17689397079604013, 0.09589523037097283, 0.2058331636445863, 0.11303431248026234, 0.13996490596660546, 0.09165810487632241, 0.12020859893943582, 0.1725602083440338, 0.11853362167520182, 0.19413280433842114, 0.12823961728385516, 0.1259547591741596, 0.0967897159446563, 0.14309739002159663, 0.11582880467176437, 0.12016148146774087, 0.22522701083549432, 0.16416176328701632, 0.0828344626352191, 0.1092275342504893, 0.07722383977047034, 0.11165546825421707, 0.17007031052240304, 0.09841180818953685, 0.08292729301112038, 0.14404195147965634, 0.11601308121212892, 0.16508463876588003, 0.14756219115640434, 0.1299149338155985, 0.16637951428336756, 0.11812892981937953, 0.15076765843800136, 0.1020343845177974, 0.0904741630490337, 0.11243495571294002, 0.10401218517550401, 0.08402518302734409, 0.15268115433199064, 0.11255853051053626, 0.15554111158209188, 0.2546172801937376, 0.14023982121476106, 0.11937902202563626, 0.13540133727448328, 0.10897856618144683, 0.11251745200050728, 0.05552345188334584, 0.16531345434486866, 0.12754869221576623, 0.13040689884551934, 0.09991937729396991, 0.14164787637335913, 0.1269517849598612, 0.1109883054824812, 0.060760924592614174, 0.16423003748059273, 0.2011605136628662, 0.13490241047527107, 0.13390721673411982, 0.08147456989224468, 0.18154531477817468, 0.10859006417116948, 0.07463710821632828, 0.1331488045730761, 0.08463064660983426, 0.20211352966725826, 0.1540687448744263], [0.039249763158815246, 0.03697350548048105, 0.06669669465294906, 0.034589906954871755, 0.09426217978554112, 0.004944976618779557, 0.07041764498821326, 0.024886752711609006, 0.015779413282871246, 0.03412099515220948, 0.09500954539648124, 0.01697425577523453, 0.03127280030665653, 0.025276335288903544, 0.04825787193008831, 0.014345840118559343, 0.04346429683001978, 0.07559966442308255, 0.031833643426320384, 0.01856995640056474, 0.042520916022892506, 0.025571218126320412, 0.040466766604887586, 0.018838189775124192, 0.03632972841816289, 0.07876625843346119, 0.06272544632000582, 0.08509022516331502, 0.028169813865263547, 0.040919359640351365, 0.008423420234716364, 0.03493435847173844, 0.019059102117483104, 0.041881098212408166, 0.016849010085154856, 0.04182758215548737, 0.011176086679500128, 0.06251225740249668, 0.010160873610792416, 0.04625815798395446, 0.01996290567331016, 0.01530397227699203, 0.008859117748215795, 0.056165427435189486, 0.010691772980083312, 0.03661557486546891, 0.07362389258508172, 0.016376571596733162, 0.0183576410968921, 0.05345750613404172, 0.021092152489083152, 0.04160026613888996, 0.06377104842769248, 0.033357059716113975, 0.04058386817840593, 0.04765133626226868, 0.04811840244968023, 0.017696239087464552, 0.0667590248797621, 0.025297756639442275, 0.03352250690971102, 0.03742132502208863, 0.009970569983124733, 0.036822209134697914, 0.03606151709599154, 0.032394028534846644, 0.019755085664136068, 0.02128124493174255, 0.038118458685598204, 0.02078125113621354, 0.02885622837181602, 0.03141506874401655, 0.04679681300850851, 0.049664804113230536, 0.025714255004589046, 0.022270043480343053, 0.022318674085129584, 0.07792697168354477, 0.08801098593643733, 0.11372675068144288, 0.012264301634526678, 0.02384240589370685, 0.09503616432526282, 0.03305598694298949, 0.046985890184129984, 0.04805284578885351, 0.020911519681768756, 0.014910396521112748, 0.05661742675251194, 0.018789196154102683, 0.04201451516044991, 0.06262733694165945, 0.024158962835956897, 0.03224448959476181, 0.04548339652163642, 0.03440834455458181, 0.0382394991548998, 0.01148779718537948, 0.08299618467156376, 0.04277258126863411, 0.021679709532431195, 0.005714881890786013, 0.10518436120556933, 0.016194910808865513, 0.02720050623507372, 0.01580281086665179, 0.04948515518169318, 0.031083797769887105, 0.011629752648462142, 0.08492884239447968, 0.004584440005211425, 0.01721842660169516, 0.04645711802212255, 0.041565145166324716, 0.001439242430413807, 0.02791482040525547, 0.04396423125373466, 0.010166176361963153, 0.04769198390256081, 0.01401155729711588, 0.011198793005730425, 0.03436123386823705, 0.03697640621768577, 0.029711080715060234, 0.050447470508515835, 0.0046476001651691535, 0.04362889246216842, 0.07530586554535798, 0.041902109049260616, 0.019818057106541734, 0.055752457452139685, 0.011656464875808783, 0.04689015907102397, 0.02470177219116262, 0.08012733861271824, 0.01713770468320165, 0.002169152197893709, 0.03096296764644129, 0.008327565288969448, 0.023214445482673388, 0.009458302337277149, 0.0856557705306581, 0.024689521241400923, 0.047613419725426605, 0.01611168509615319, 0.03841806243040732, 0.017904128646478057, 0.03149045059191329, 0.061157446886811934, 0.009889881991382157, 0.03970711611743484, 0.041249005523111136, 0.045088852157018015, 0.058428161910602024, 0.032420281054718156, 0.04437866008707455, 0.07664434372314385, 0.010500923131725617, 0.07177052846444504, 0.0716671875811049, 0.017890866679538573, 0.05743537696876696, 0.011209519796206482, 0.02965857567531722, 0.02002697634244604, 0.042120478581637144, 0.020993744555328573, 0.04647594058353986, 0.02958810642095549, 0.03877425938844681, 0.022291162882798483, 0.05483660141804388, 0.02845711916285966, 0.018567413590582352, 0.07724475900509528, 0.006957826578790056, 0.030397130509040186, 0.025946755028728927, 0.022523652728913084, 0.014548482905541147, 0.06855993145810706, 0.0203794464468956, 0.024565256034423198, 0.015207119884767702, 0.03205859814105289, 0.035234440583735704, 0.07630939848188843, 0.0333794852984803, 0.01395532370744539, 0.024527047727523104, 0.0444693021875407, 0.03955270529591611, 0.03545954796884741, 0.02462106553970703, 0.03035793493368796, 0.020845313323661685, 0.03889698262459465, 0.03230347803660801, 0.0407777188478836, 0.06983154000980513, 0.03769642008202417, 0.043641723559371064, 0.021580887692315236, 0.030732235206024985, 0.010830853151024451, 0.030515884315328937, 0.02374618623538741, 0.05332504252770117, 0.008868973469361663, 0.052537609423909865, 0.011334099673799105, 0.069822366216353, 0.038548697384872606, 0.040587596728333404, 0.009865419107622333, 0.05374479786093746, 0.02301763809685196, 0.04131590568327478, 0.016336422679679732, 0.015572124227349247, 0.020589045914156095, 0.04512975764061723, 0.053117505806897364, 0.04218428462211575, 0.044439996260085275, 0.04402574045317514, 0.04067973839119077, 0.044524538330733776, 0.05258060140269143, 0.038720617802547555, 0.03679176326841116, 0.03437502509249108, 0.06374128109642438, 0.04011712768780334, 0.0029913901193400045, 0.043641743915421624, 0.04050851007923484, 0.010528833821548947, 0.016007412923499942, 0.012238972770449306, 0.0358826145529747, 0.03035016231504934, 0.05263673999745931, 0.02522175053932837, 0.04127039633957403, 0.03845001803711057, 0.030891175248793194, 0.024752585982371653, 0.06626406751040902, 0.026521306252107024, 0.04007438337430358, 0.028497656541211263, 0.0836645688063332, 0.02474448597058654, 0.02685002763090389, 0.011424382998874145, 0.058801552946014066, 0.04183781446356859, 0.05751425666468484, 0.0738818376724209, 0.018705817771011164, 0.022097736297707473, 0.01804937415623239, 0.0459815701469779, 0.05673114922163742, 0.04729565838351846, 0.041270311522696695, 0.026119659322180917, 0.053102876591895304, 0.0738092954935772, 0.006074938016744065, 0.10418785789183208, 0.059509651735424995, 0.03488535128001656, 0.055319375691137145, 0.021314024958493452, 0.03221895292933498, 0.0522716169112495, 0.13251927335347446, 0.05656185134180954, 0.018688791631055728, 0.038224211760929654, 0.040523356425442865, 0.028645119164139032, 0.05950775183737278, 0.042407919586236985, 0.021508091062839543, 0.024786980922466943, 0.03803546706746731, 0.03797168477571436, 0.028844944334455898, 0.013193635918599154, 0.04965126394693341, 0.004377550861266042, 0.013213421999742942, 0.05658093513920903, 0.005097315363985087, 0.01292228467562901, 0.05883199881230082, 0.05452986627018877, 0.019662548754630343, 0.02472313416988722, 0.015189868131918567, 0.024512572879237787, 0.06203633972576686, 0.024739798989945223, 0.03915671565170799, 0.035559469035693576, 0.036844712748591385, 0.02286893714751516, 0.015678330224805644, 0.0317022010151829, 0.033282658351319175, 0.018644871755636165, 0.02377773811375456, 0.022217816639957682, 0.05862725765577384, 0.02782853619594659, 0.023160620692319105, 0.02287678949401847, 0.01744517095253936, 0.03929773558463369, 0.04958694221984063, 0.02382799211357321, 0.0199681575343545, 0.08502635466200964, 0.09033212531358004, 0.043718930666467974, 0.01919333839655987, 0.010575093794614077, 0.029382696907435144, 0.07699721585959196, 0.05172443948686123, 0.02829174660811467, 0.00940518152700471, 0.031538216064551046, 0.040294283003147156, 0.06348772613065583, 0.006712164671625942, 0.023716831114143133, 0.058092063159814904, 0.042528379908097644, 0.03970135874780161, 0.03023869258218578, 0.03214756765269807, 0.027329470297055583, 0.014787354373506137, 0.013418590633331664, 0.0378467088033046, 0.06565109933061258, 0.030059633976114646, 0.013509331121375518, 0.15263983154935495, 0.06985915638506413, 0.13258636689611844, 0.09075639290469033, 0.18649193005902426, 0.04125967548627939, 0.1257870660296508, 0.12240220765982356, 0.08877054482166256, 0.088903659821621, 0.3002604581415653, 0.1504813709429332, 0.12679307561899933, 0.10870129641677652, 0.18597761408558913, 0.1657133557434593, 0.1629355148013149, 0.17272051902753965, 0.08070272273783173, 0.154878969969494, 0.18295472700681004, 0.11248337597187076, 0.14780373605234282, 0.11625805949526173, 0.1988732942513057, 0.2353151845080512, 0.1463815402239561, 0.15631354227662086, 0.09513632966471569, 0.15955467335879803, 0.09008521320564405, 0.2382074807371412, 0.08771062562508242, 0.12136233917304448, 0.08527216754321541, 0.17337032487349852, 0.20534753613173962, 0.15667678921350411, 0.1592852949563946, 0.09861524655882802, 0.12143629949007716, 0.11697865011436598, 0.07051152030804328, 0.10642807518265077, 0.10717371052929334, 0.1311398795140641, 0.16918649151921272, 0.07880548454288926, 0.12528879062405654, 0.14182067210120813, 0.15457558339195593, 0.1215605256812913, 0.14528327701347216, 0.16122245815183434, 0.15148130085851463, 0.18724057131579944, 0.1298440404768501, 0.19288735331169196, 0.11735440923699311, 0.17257764669401304, 0.09291004269782986, 0.0832804162055254, 0.11079716216772795, 0.12575532416147844, 0.17086084453122957, 0.1556212194263935, 0.14068176464310714, 0.06102970588420119, 0.17844709674162523, 0.11481581974242415, 0.08056595721947295, 0.10930625109800271, 0.1833102386444807, 0.1014453482681087, 0.09883783997169562, 0.08911021945199796, 0.2088102496096066, 0.14021714457443782, 0.17587998163487228, 0.11775717405336243, 0.09847338524247919, 0.08523069548287562, 0.16607287073773996, 0.18517836768712315, 0.11306147423705884, 0.12994381226599216, 0.11627643422356673, 0.12678293830582074, 0.1947122189615454, 0.10162248662007706, 0.15070223409150327, 0.12598443829587527, 0.10476984416267701, 0.12149872471179281, 0.09697437246463128, 0.2941855884024075, 0.08941846434026957, 0.1578095220029354, 0.1298636229974883, 0.16245792114308902, 0.09987307406429734, 0.1100774265027472, 0.23238790301339968, 0.18803322235388414, 0.1719353725867612, 0.13654119468161038, 0.10953653909798179, 0.08555388849760805, 0.10404881249581065, 0.11047559085169009, 0.1311066448688507, 0.09746999479830265, 0.13860171554344042, 0.15462802057819708, 0.13044458468045506, 0.07758871519139834, 0.09835603261100394, 0.11747951752373151, 0.10535393389207975, 0.12675141356885433, 0.06124431972524949, 0.14903998614421912, 0.12657412593918188, 0.1356968664165054, 0.11501995021743433, 0.13049204141965934, 0.1507463931505169, 0.16335854067334107, 0.11797841718154294, 0.07258309450532709, 0.11634751755212035, 0.1485343011362212, 0.09134744440338441, 0.1806710495480469, 0.12617467237370356, 0.08580388793987886, 0.07212888994919402, 0.10275580973497458, 0.11762468330562115, 0.12033885052161557, 0.09447482587503535, 0.1737978155059474, 0.11738552685294833, 0.0953498442790338, 0.05277783117656197, 0.09920606735561575, 0.17781162155526026, 0.10492340342274734, 0.15358687644558294, 0.1866743474134377, 0.15861511948917592, 0.13352936772363527, 0.07403840962797403, 0.10712527669966221, 0.07652876885341746, 0.3866547665425709, 0.16599648126534053, 0.0935027226805687, 0.12736672269446508, 0.23292788118124008, 0.11507016180881433, 0.17914931263242448, 0.07356087025254965, 0.14675869712872164, 0.1309048756957054, 0.1109734455655728, 0.1072355250694922, 0.11942505384130137, 0.13023038474576815, 0.08875162726534264, 0.13420285444174493, 0.12197927678269999, 0.1560620636280094, 0.22631113337618963, 0.1413403507322073, 0.09954706512923751], [0.06090934734259333, 0.051013670662151914, 0.021822563206244792, 0.10852011399609701, 0.04449546310518469, 0.04278758367789643, 0.014492049148040158, 0.03137049238596644, 0.028790379940931286, 0.03713441666747842, 0.025933297982971584, 0.02705892311808254, 0.04697374440729618, 0.038563794789037535, 0.052454068192413876, 0.026160013496077487, 0.031296063879770894, 0.022634886670857668, 0.04360392915883234, 0.034033698229385276, 0.05446577863767743, 0.039000411717487235, 0.023504005212868963, 0.0637643173603075, 0.0022712492417278035, 0.01535803116192775, 0.020941716186436157, 0.034362255063440116, 0.10805807236049857, 0.02561616598229323, 0.05193761144099491, 0.03718879107119782, 0.026124063014451946, 0.01805858696544809, 0.03538532641583255, 0.047527086322328875, 0.036469984999192614, 0.017656770401767323, 0.05623530636408499, 0.016300492554104755, 0.02150432180081095, 0.05107291016195502, 0.030003366459693228, 0.1224061024508306, 0.08762298604207379, 0.018370942079595158, 0.04751022133444037, 0.033738823873656135, 0.05442002841404506, 0.03294795059732028, 0.04688982319618974, 0.026702682055266838, 0.008547972122739469, 0.008266908499146146, 0.032177694607526064, 0.018856511916965246, 0.058534461206623485, 0.03104717723493065, 0.047521848031984906, 0.010947009864529329, 0.0327122377098671, 0.042313989983605485, 0.04553045631785478, 0.01797096773849002, 0.05272714461066893, 0.028195387850116407, 0.03626901310469423, 0.026750817329489758, 0.009784407115408351, 0.03537363865013633, 0.006484206167182752, 0.012729009912748421, 0.04892691085115075, 0.06114574894309044, 0.03212647878431848, 0.006038376853601741, 0.07723156149898257, 0.033183843296553404, 0.04733296423884375, 0.02210104076324829, 0.037690784848694286, 0.019901559322274158, 0.05965662920581443, 0.044497895653226545, 0.012303252089103418, 0.06559829573546137, 0.010848678265964347, 0.013790506703246917, 0.008061570231802762, 0.020613169530406594, 0.017911480573405112, 0.03527320528935109, 0.05492714513093233, 0.044582563252853494, 0.020367885906515375, 0.0349518986019705, 0.04022481119526284, 0.021509158059156368, 0.03820982003318412, 0.014451169109504138, 0.03440861596858927, 0.055206582814987214, 0.016875305013465028, 0.041312594432383776, 0.013679294813690441, 0.030768543614872863, 0.03675010461094124, 0.0302227164751717, 0.02822693803214601, 0.048631205290023766, 0.04197344343577113, 0.007979379284993877, 0.014892888621294072, 0.026589797576889396, 0.0445464651898614, 0.006639993990704949, 0.010941218568145164, 0.07439728001398699, 0.09654232886220727, 0.04842696624941059, 0.022841005253472497, 0.023113192790853124, 0.02489294095097908, 0.023598165517406802, 0.03789268294349313, 0.011008464781168317, 0.028634011545883756, 0.028464018167661767, 0.026778996888814226, 0.031107739878020117, 0.010631102619559636, 0.03757764252700976, 0.008052182699819761, 0.09537426475435495, 0.021729103489113704, 0.041861624257372956, 0.0053092930964859465, 0.047391735549483976, 0.03222896132086005, 0.03294232893469078, 0.033817432155566554, 0.10450042504817247, 0.007562512814599488, 0.01020794952221747, 0.016715265743966614, 0.03221547204468932, 0.02770235582387873, 0.07318900592092957, 0.020613356127536724, 0.01782305728244994, 0.0612253885982292, 0.03910721652209759, 0.011848390202171035, 0.01303523955201464, 0.06060828814016921, 0.03824916149356535, 0.023082063300535083, 0.01715326518751681, 0.05258981930091977, 0.03193191226039614, 0.028935009680156196, 0.022271639733974422, 0.026470014093709842, 0.018967993524191634, 0.05493037835029619, 0.06844737606921367, 0.016085154376924038, 0.02927471823724253, 0.04082735368449773, 0.07264621861811195, 0.08701809242899929, 0.013826147603270198, 0.017916003009304404, 0.005426231397515429, 0.05695840756275824, 0.056208344775119, 0.016732566690604602, 0.035551737129156075, 0.01951346273667046, 0.053909420634486845, 0.024748097473223294, 0.06986814018871103, 0.04725307013307299, 0.01803617495378213, 0.022453188563563993, 0.025709233845451047, 0.02739052827070866, 0.056244056073150465, 0.01082307968421706, 0.06396818320666041, 0.028044926102406213, 0.03068887342565826, 0.04326748774786081, 0.0522423991933465, 0.04684648855722376, 0.028774149383285215, 0.07207367076937642, 0.04116163396143487, 0.04381476355982678, 0.030222855574850525, 0.026053639561203972, 0.03707931623128908, 0.053779565995293, 0.020934571212689792, 0.04403683450073004, 0.05057037355644362, 0.07002829480916262, 0.005841232744777309, 0.03022917952122433, 0.015869902712958198, 0.06530081241258553, 0.03921059811753886, 0.008732203710159021, 0.012901479095619704, 0.05675889791122504, 0.04785141249054244, 0.017628012391339456, 0.014546998610187854, 0.025759808453066007, 0.07291189900466374, 0.00784358407171177, 0.1352621561714581, 0.053666613663413694, 0.0027802185712581767, 0.02649689934748624, 0.10621561229761158, 0.03692329049642597, 0.02724756603129208, 0.028562493954918215, 0.02105426987899201, 0.01667292176612786, 0.05403499711038811, 0.03171921528077551, 0.04753333902252572, 0.011206558839018856, 0.010208990225302321, 0.0355153812228569, 0.011784102401829191, 0.05793429019727877, 0.035918108719800196, 0.010052749903739562, 0.01759444865664201, 0.02595204590553684, 0.026265951472201517, 0.009055320389701851, 0.07284024570669446, 0.026359818310343792, 0.026156437616529207, 0.01818068086036614, 0.026567341460447227, 0.008369756596429008, 0.024807611779708947, 0.03214316735310214, 0.03660485740484936, 0.013964083594536143, 0.0762062475883535, 0.029594382869877985, 0.026076541814420904, 0.084720837484513, 0.011480624222063592, 0.05767766825322594, 0.05447034517835293, 0.028672050219029188, 0.01812754647939333, 0.052832127548754215, 0.042853818873741796, 0.03343890800273844, 0.031171362714043686, 0.022791285599981035, 0.04332891891577414, 0.05563633296904819, 0.02905421471223235, 0.023460054803373556, 0.06284146902284451, 0.03746746201068163, 0.0890844419066395, 0.027639213051380854, 0.058275790086814334, 0.022394413860248666, 0.029846648619111096, 0.012636090479125934, 0.007695355552381703, 0.014930852655587452, 0.001385860490180286, 0.029741133031036173, 0.014824987621977925, 0.07043230812996626, 0.04981881459908826, 0.020845544025568024, 0.02438232977874577, 0.09071891741561038, 0.03806957023750458, 0.03614409141508596, 0.07531583322478191, 0.04088358388149312, 0.08169147039630584, 0.05863818206957408, 0.07317570663456406, 0.022743598158870424, 0.04246267057689173, 0.0337363302574626, 0.06554035563021898, 0.06936797167041472, 0.05018368662734117, 0.02074603007973305, 0.01417103931973023, 0.011922537116333842, 0.053764885890164545, 0.012167538300023546, 0.05774708238563367, 0.05331542090113674, 0.04971937189943024, 0.03189563777829919, 0.019618294700714092, 0.03978691862097808, 0.0033994358465341584, 0.023694503919354508, 0.07814857443528515, 0.04579883388110569, 0.031426810792514255, 0.0185991690294551, 0.05271493098033326, 0.04310426954180002, 0.004049214127007872, 0.05143059650436044, 0.023061001573556235, 0.04688993515446782, 0.06766743399202824, 0.01933801732957363, 0.03446514472099287, 0.011962437519936689, 0.058635054023138115, 0.02516975100817425, 0.0373360433482698, 0.014087119804961341, 0.022156765451654792, 0.026379417794357454, 0.02917014920551862, 0.03309822914057544, 0.026961721280323606, 0.020055145723745227, 0.007520455517806113, 0.020496371601309096, 0.00873248275768544, 0.05865130493683474, 0.027996804398883666, 0.03833181384418692, 0.023371126003829495, 0.008804147930017539, 0.02613074149537299, 0.023613284973959838, 0.048954978452197144, 0.13175360086773122, 0.10473441106400319, 0.08763662459594862, 0.16995768728000776, 0.0871275265568069, 0.12809746419744833, 0.2149553612938949, 0.1441881622054747, 0.1346739205930914, 0.14841535394745214, 0.16124269206609043, 0.12981201362396988, 0.15323003487927572, 0.14252131379076413, 0.09329169828976903, 0.09132790938019753, 0.10741850560797112, 0.08102439583412238, 0.21065948823732988, 0.11556838293160711, 0.1357573510280677, 0.14841892304165022, 0.07491653572235789, 0.11253184372825281, 0.11251909405525241, 0.08809813018888235, 0.13626820647290774, 0.11093714394207511, 0.19641919593725884, 0.18262714387050696, 0.18435637679483208, 0.14103334077766963, 0.1034167299845389, 0.1282022571457284, 0.12759129064423697, 0.1622503844222852, 0.09159409188266311, 0.09287137977246727, 0.147521207641278, 0.18153528603059904, 0.07590545301458665, 0.12070268099861485, 0.2673037680132048, 0.23271929951650755, 0.16761467871921404, 0.3258622900715896, 0.1710027397743293, 0.06551926676183939, 0.14349566293614252, 0.23006628187639372, 0.11226315743156842, 0.07814746842320476, 0.07210104965737887, 0.10241876103516136, 0.07895347303045647, 0.13855412309723242, 0.13761937325554235, 0.10707697179168463, 0.10296458817486252, 0.08748224430850574, 0.11077375270958457, 0.11751181579061917, 0.1730599629559687, 0.09041180568081991, 0.1191330123692751, 0.08610491321555205, 0.1077772674283811, 0.13993728959134646, 0.08877630558397089, 0.09717960895172187, 0.12835560605994292, 0.09270632612918105, 0.07522875682583877, 0.18312794342637062, 0.11316687786685568, 0.10102536223296608, 0.1613737850316933, 0.1417938428265708, 0.11756970839841024, 0.13758693928165094, 0.11622095720044204, 0.13091337095413888, 0.14747273309954576, 0.15986240256045545, 0.08546785704259362, 0.14904666292880261, 0.11687712770487581, 0.09541372156568936, 0.10536251736006566, 0.1185157083507095, 0.08629005149539028, 0.09523434404815946, 0.11294845744435277, 0.09053149247275931, 0.14511091554803507, 0.07594123895147017, 0.1210486524339233, 0.17842786705919675, 0.1322978673768895, 0.1405545121857098, 0.09940530559314148, 0.16052557554628166, 0.09231272832091365, 0.13103526298488888, 0.09111952449062041, 0.06013448070734739, 0.10986520789031472, 0.0678251865985138, 0.1700818184763193, 0.10875453427433968, 0.13749716909868376, 0.09476257222039358, 0.15680625369506224, 0.0972173965669104, 0.2459523608641965, 0.15646249428391457, 0.09467369091830083, 0.13707782088645867, 0.23706295500908578, 0.09395263211003371, 0.08344158184315477, 0.2232267303126199, 0.11112133227288723, 0.08672788300152336, 0.0918031417365585, 0.11725781299173832, 0.12405289337038994, 0.15607700496912003, 0.20017920274819645, 0.22614048181899957, 0.11692919848220688, 0.21035919577947684, 0.06584049202501774, 0.20772346721163817, 0.1675738309110914, 0.08545843897653477, 0.13101619615086488, 0.17379717768302985, 0.1330311330301421, 0.1071830607418503, 0.12663196426417145, 0.09929957626653568, 0.11515191170786108, 0.09800727918211903, 0.11945125886372157, 0.11185900161841086, 0.2117636547024761, 0.09609285369515419, 0.15978912077844143, 0.07519666211945669, 0.17890769988298416, 0.12836110219359398, 0.06191952992230654, 0.09398511358137641, 0.16971084981092385, 0.12011075418974672, 0.10337412477071796, 0.07172872392194611, 0.1328667782779251, 0.0867529616558126, 0.11975917805518423, 0.14716482747878346, 0.196003131834524, 0.0908862373658589, 0.11478114660297122, 0.11374211949961525, 0.10330697694527251, 0.09658324452383177, 0.12744687125086784, 0.2430596032312938, 0.21588640633438314, 0.09449035754161221, 0.057435315900615284, 0.10427722773913826, 0.15610315570873873, 0.192179071317826], [0.05225032787503941, 0.06298680443848882, 0.06682888005993196, 0.006076351914089173, 0.031745888492358584, 0.09207114949822426, 0.06970651993261916, 0.08040674576269728, 0.05017705394753388, 0.0615693312138319, 0.0418355956540576, 0.01624236924440733, 0.02027251441696925, 0.018171320469783883, 0.023044896544888616, 0.016315517015755177, 0.04506387867565666, 0.04810673164735947, 0.05112292497817959, 0.05703455276255097, 0.041419392451643944, 0.05599796159991196, 0.07750422401087624, 0.0530196440938328, 0.01970513361240072, 0.0708649352725063, 0.0394821783660778, 0.030973691892411028, 0.04334224534354039, 0.029021651816687415, 0.07490613378052201, 0.02855125062965921, 0.09532800902213369, 0.04404406089867864, 0.028274197996194874, 0.05110355619607227, 0.008740136632695794, 0.01591363429491009, 0.07876535598188639, 0.05214274954050779, 0.002652125366564308, 0.09083464156304087, 0.05238558704565678, 0.007777324278971979, 0.02404069248586893, 0.05187562387436628, 0.0658398067046489, 0.03772000256659729, 0.02892817683251841, 0.028443256692428674, 0.01566184012751494, 0.019367548869922757, 0.05868884149406638, 0.05609384538339717, 0.05894973820873669, 0.0269586135899382, 0.041417356846588, 0.02237278555652925, 0.05039172885673387, 0.0286681282866214, 0.02758260626745011, 0.05753159323441131, 0.041678453729088814, 0.03226712552298393, 0.004103517708634692, 0.019316482324419276, 0.039072356785514524, 0.022649166440325122, 0.019381869351491332, 0.07991752879960196, 0.010437317259077514, 0.03264756653723972, 0.043916106157537015, 0.06150299084505864, 0.04781186068430543, 0.04749945637636951, 0.05612476283152189, 0.02209431308853839, 0.014094519229339702, 0.05642965575680137, 0.046087421609887054, 0.042215982385511906, 0.02353926358877548, 0.012659691623412073, 0.022713438973629048, 0.09016749236200537, 0.0546664553694427, 0.02455639436707965, 0.05339292995631695, 0.009177076713448125, 0.04645823760490332, 0.06390506587922573, 0.062390697853905816, 0.019737721953008856, 0.06509093474596739, 0.0073736536183527535, 0.037405979952641895, 0.039026073911892514, 0.011525169197869087, 0.01882734169651355, 0.041896758800638575, 0.0267524525988847, 0.02456597188886787, 0.056211354077926705, 0.026456940420238034, 0.04925503342279366, 0.0427879975842578, 0.04546039079182914, 0.021197179531944648, 0.01748418332343655, 0.05406031325193388, 0.08134698495268822, 0.07674658537975379, 0.03892263124829956, 0.013852551945352128, 0.028286550726209368, 0.018808357983029315, 0.06540045528007404, 0.011643107065797915, 0.021977968081565838, 0.07340693101286888, 0.0872085572087339, 0.06925694977066346, 0.05505603625039969, 0.020971222281722084, 0.019421563650082265, 0.013184553727374544, 0.02626861132947462, 0.020959641385291303, 0.01659101410768926, 0.05821159388870001, 0.014749536224241768, 0.04496780150969114, 0.04667438154241868, 0.01718063559383154, 0.021833706447588544, 0.028886602991925817, 0.017859453900850246, 0.008649598008819988, 0.012810845476841288, 0.016397477260657718, 0.004471783260149615, 0.012269558584583657, 0.1105445164388844, 0.021347408881410956, 0.051394040430230756, 0.03190790229876127, 0.033212976197579076, 0.020342910728816475, 0.015888620101447617, 0.08828121929296426, 0.0568726339510509, 0.06811402538525206, 0.052556303063673634, 0.04803081714947309, 0.04339954084051507, 0.029009818165962185, 0.006360549097215491, 0.024193954886868596, 0.019020905684945837, 0.03040340356528759, 0.043469501193612814, 0.026114560131515776, 0.007314076547377876, 0.044048488339675326, 0.030700174426393848, 0.03302665726680841, 0.023502548058916415, 0.045670896103339534, 0.022392844748018042, 0.027181151023666774, 0.057387967727013996, 0.018092749507299492, 0.029392060690692494, 0.038835463247128894, 0.04299033672681876, 0.05162648617156914, 0.010749652865342796, 0.02267554109649999, 0.029405919768448387, 0.047083656902291944, 0.060857588691370826, 0.05468527453818491, 0.05720059706696442, 0.031158813208873783, 0.096330408805183, 0.03237332982410278, 0.021619701591719474, 0.01714697347155639, 0.04720303835347295, 0.0447386907679694, 0.014755804191476532, 0.03214240739388125, 0.02655673086909311, 0.008004894746201379, 0.00782506600288408, 0.03629295860550233, 0.02923990599811077, 0.0377660343822624, 0.05150072988388794, 0.08819302331124033, 0.06603963526764087, 0.018347106840727583, 0.033007712569087744, 0.017747254742841636, 0.02757238413739417, 0.01581472933425435, 0.053738131254379234, 0.08022099680134229, 0.04386458499357104, 0.05648194705801351, 0.12540108816964285, 0.024457257008180022, 0.030246193786816936, 0.03534509946725198, 0.021350447021956955, 0.05158220497625215, 0.030001215503684113, 0.019426291342824697, 0.012850560979651553, 0.03706914499135954, 0.014492781965860298, 0.017791859938630035, 0.07806096199367728, 0.030367770298783268, 0.06151825788297823, 0.050533617314483435, 0.02262082403259618, 0.01642557030676731, 0.056892175759587965, 0.020664293751386658, 0.029593232753021375, 0.087146050562816, 0.018559145641380122, 0.0429434770984309, 0.023639388216127242, 0.0188553787634841, 0.04490362227495227, 0.035629171545484235, 0.02600148566333311, 0.03909461273412619, 0.030991238807993274, 0.017923215836552635, 0.01000688093647893, 0.022960488484906297, 0.03008555740650211, 0.03288066367219601, 0.03978492712069835, 0.03363006828086717, 0.031448344101331065, 0.05600758322647639, 0.0640492138585874, 0.028665593958326747, 0.03423316377614226, 0.017275109720815505, 0.030084230870540653, 0.036933984208319864, 0.019685313604505997, 0.046145039410995584, 0.025647870531039577, 0.01715299377350935, 0.003871306061877736, 0.031785918665783744, 0.034664349031767676, 0.04847586487552949, 0.016865817397566776, 0.016147813693221127, 0.02189882884600333, 0.03295147558674216, 0.025958410564011762, 0.08232136123946734, 0.03808638433526669, 0.04264284198039344, 0.05267613234796694, 0.054932834647063694, 0.031792524204190285, 0.019706833342622434, 0.04922226357406803, 0.04186939009066139, 0.020225346055147902, 0.023014153819531202, 0.01169985719025135, 0.016434850969484875, 0.03167070002694215, 0.03722970334014722, 0.034026773779519966, 0.02133553451858461, 0.029616859342370714, 0.06710083011005606, 0.04327284138915794, 0.0250779299531132, 0.05377829374213304, 0.016920071361320357, 0.03717197697343571, 0.05033537991611021, 0.030492997329149927, 0.060399998245494704, 0.06370280816086701, 0.040418912922697406, 0.015013732315440263, 0.01984296103806368, 0.011769861648125308, 0.014573997518579875, 0.019235404175040976, 0.020137292565777898, 0.06544374581426382, 0.042698210437915156, 0.02480651594565383, 0.018813626807449118, 0.010793007012190563, 0.041268102891210995, 0.07614572905004025, 0.0025319909535547985, 0.05761989778173821, 0.029277395057891096, 0.04216497012280992, 0.02965444339705365, 0.012766662669101996, 0.0018268556658378138, 0.05725939212633031, 0.09957210985677582, 0.055920656105237346, 0.014633583071242486, 0.013122940203174949, 0.06649607898933546, 0.010126805215674852, 0.05543954424293978, 0.03155333721744163, 0.03620788388486419, 0.04120511109275477, 0.025906517902123075, 0.01556708271216069, 0.03401956773762192, 0.005978479174830551, 0.020438663894310594, 0.05342796611200486, 0.02667283669247159, 0.027731083300230757, 0.005341594756048704, 0.01164078647603414, 0.026422155322507024, 0.022163937566801906, 0.03749595030343958, 0.04657766994621072, 0.05750605317630938, 0.03926406667700835, 0.01452233046958489, 0.048816187506807704, 0.029980123242629424, 0.04555095825344324, 0.050908575765788555, 0.0653229665809444, 0.18312170090419905, 0.15551686074052537, 0.11140316179288284, 0.10840949243200676, 0.12550118565559387, 0.20066864362784795, 0.17046665639749595, 0.24172807325209889, 0.21503637837512152, 0.13213769240038736, 0.1473529173859528, 0.09774965979158878, 0.06016010218965156, 0.08620712773076125, 0.17824467617486203, 0.10702292647744928, 0.14399130562586443, 0.219801716240389, 0.10625567300511257, 0.10389526680644069, 0.12480115464755467, 0.1327100231179169, 0.21208901224391802, 0.14871951405491146, 0.10774213288511549, 0.17805043874042376, 0.12256299331784248, 0.1272379910307271, 0.1479121930897236, 0.12443793485207216, 0.14641530412648404, 0.11572071404329368, 0.2009202308420624, 0.13647112915558474, 0.07377155537583999, 0.21685806848108768, 0.07787260745785066, 0.19012494225587162, 0.1820109255079712, 0.1164151132106781, 0.12943622735994204, 0.14296846836805344, 0.13826623425952025, 0.06959348278386251, 0.1467996942145484, 0.09866629953363112, 0.1822224384439843, 0.21410854959062167, 0.11319282504596881, 0.11941796993570668, 0.1666508332959243, 0.10229286564780132, 0.11532089406890528, 0.1698906615908657, 0.11964062441672597, 0.10074906277337245, 0.11283816836242165, 0.17176557598369463, 0.08543654265148298, 0.11506822119866099, 0.13780768029391766, 0.15018338550414356, 0.18499067133026464, 0.08338500559329987, 0.05840830797595637, 0.10690665271665369, 0.1847091878631285, 0.1231823872242655, 0.09710843062826566, 0.13558982073196343, 0.16183537883417948, 0.10679898277989455, 0.14065881658877644, 0.11657645526741232, 0.10999609729541199, 0.10033781626927, 0.11213457504553453, 0.15494929333882673, 0.08662269650293247, 0.11695263508175101, 0.21775028774780886, 0.1324667547430311, 0.12149229219981603, 0.09809190606964485, 0.08705980876194579, 0.08431401502873216, 0.2717400842479297, 0.08676259006772723, 0.18498930068952696, 0.07643628453037568, 0.1632554440626076, 0.14945463889411517, 0.18657380209437438, 0.11435639725199767, 0.13437330243842943, 0.1064901068540556, 0.1310091529573713, 0.11272275634109974, 0.1739830555660384, 0.11625259050301143, 0.07887226595942463, 0.12636474360312733, 0.11028645600059203, 0.13345482386648655, 0.09565335977822542, 0.08667534403502941, 0.1668070727693183, 0.12710122551236833, 0.074343356836055, 0.1100303293871028, 0.12952728675944464, 0.1597741658666304, 0.17729024881763117, 0.13584432564675808, 0.08190162626228162, 0.09317144152841397, 0.07078878328736339, 0.13826725206204823, 0.10144557218466486, 0.11226534909967865, 0.13491462410560676, 0.20226267166435719, 0.15700043684669904, 0.11530045659414359, 0.09386261765445982, 0.14011545931654318, 0.12683266135198729, 0.13054378650018147, 0.09416356150593076, 0.13073301634618215, 0.17406776387776646, 0.08048669075859444, 0.12551510919417652, 0.15583341089742525, 0.09818944547857557, 0.1563123751963888, 0.0946476487442851, 0.11082094482013158, 0.09683843475899526, 0.1336829744811569, 0.09666800711836133, 0.11869195103645325, 0.1350414151591914, 0.21694093117756502, 0.1330237098570381, 0.11871766751366002, 0.11242502196026699, 0.14675757076059068, 0.11271531281194516, 0.09628809536142008, 0.13055614940822124, 0.14483268904898847, 0.22981625529272215, 0.120942977390119, 0.11589684816343443, 0.08416064575846706, 0.1205951739102602, 0.062486866622098854, 0.05627549599323954, 0.10928562363343579, 0.08413761627993413, 0.10935659839638642, 0.0759383144655398, 0.16494769682841642, 0.11597596534660884, 0.12451295368373394, 0.10428817929433924, 0.0943804687953421, 0.12114568294159003, 0.13743858438517365, 0.07250138531838145, 0.13431056509060518, 0.06927313961620842, 0.13116349253271306, 0.12433045490511827, 0.1367518390927996], [0.06251038464584521, 0.003712191296342228, 0.03660440617906196, 0.022224847959088426, 0.03599872885804091, 0.0405123946922166, 0.04191916402695434, 0.08051479567906686, 0.03221354500523635, 0.06235749713544335, 0.05001836496272257, 0.018168816675565073, 0.003034438077260607, 0.035568049111004384, 0.02208247604513807, 0.028013883125303046, 0.04209175280162266, 0.04559973135058369, 0.01782838547868388, 0.03922056579696281, 0.03851340338587761, 0.037507746634738784, 0.034447282286626954, 0.0548121470159718, 0.009894314521391476, 0.01457762428825455, 0.04218849493190646, 0.047137987201235125, 0.05042682268789836, 0.027206172002479434, 0.02636244084819087, 0.005403102683236024, 0.039031424160514555, 0.029001282195427587, 0.030440729776663438, 0.020025139208883047, 0.04165729361453226, 0.022640245401167443, 0.036960175660039694, 0.029313947739345685, 0.04498111775943211, 0.030362355589334453, 0.024097809867401208, 0.013548619995292808, 0.1327381551797901, 0.010729897318274846, 0.0737343445154173, 0.05855680536478758, 0.005113571366694356, 0.020591787195631435, 0.021286764814119254, 0.007900065326664065, 0.011571424081921577, 0.008379989752678998, 0.059922581006373675, 0.0278270010104669, 0.03412199938403709, 0.011924884847498365, 0.1257955612880843, 0.021582645098013536, 0.04352173821202346, 0.04975515444363866, 0.0339016994195325, 0.0031857887058452305, 0.009899259345339877, 0.0233722286232348, 0.02350252600652831, 0.012107234348409941, 0.036516712313251834, 0.0424125845144902, 0.03198794907491122, 0.09072329396648066, 0.037351914282355986, 0.11327532133353607, 0.08876618862684284, 0.029888205496328216, 0.02692198457329401, 0.05486664016331945, 0.05275987713996853, 0.03448267128052456, 0.011084124828422708, 0.005775612471292594, 0.037581866407500844, 0.012702079706027039, 0.013695939277697886, 0.02057810453698039, 0.03719193608100925, 0.02384137112780341, 0.007481329492293298, 0.021027781568201523, 0.03760532336309552, 0.021404592420107553, 0.011770438402891159, 0.03870838720883642, 0.061478210746177604, 0.04423719232103654, 0.030638400598296096, 0.05476049014500209, 0.07485526401017394, 0.05398838853995715, 0.016510733236957873, 0.042329799849539995, 0.01828378256011222, 0.018989706644788384, 0.03660781581753066, 0.0037413008727266318, 0.03400891813050423, 0.026612229944605912, 0.024153912839080607, 0.02597819664515555, 0.049359063019177744, 0.01941341783718339, 0.07867194885121924, 0.05002949293702841, 0.03887982586664813, 0.009439579859775091, 0.033020659017243555, 0.060092689735548835, 0.054763445165008307, 0.044003715206469805, 0.07085152742053781, 0.09593957263444151, 0.013896098626511437, 0.03385754036051886, 0.011897599258060967, 0.03555611368002636, 0.00772980138260339, 0.04214172690574612, 0.05117833414780242, 0.026488407481727854, 0.008255337780740644, 0.0654532928019762, 0.02936106521104063, 0.03386881421985371, 0.00577510950721002, 0.023412738860185658, 0.02681376163049468, 0.04212271435452359, 0.006455755193850824, 0.0916555467993021, 0.07479113566556148, 0.02082033475328769, 0.017868995799549987, 0.041126302643013854, 0.0359900503951524, 0.026544759815026606, 0.020971178176945875, 0.024345973872446587, 0.061028722008424144, 0.06279728960778032, 0.040352762543729374, 0.05282637017912098, 0.034365528994905095, 0.02576220198534429, 0.058387605872537406, 0.052863346944962225, 0.1337833705225161, 0.06673011928796768, 0.033621230362249274, 0.07636631399925266, 0.020140898979402015, 0.016062031599826047, 0.04155430217672672, 0.010177719938967909, 0.08319580967405013, 0.006702015908168895, 0.030725836620799134, 0.012702740429501449, 0.030680164428693906, 0.05451843974047473, 0.043501490727066994, 0.034680433704384735, 0.01576598677118974, 0.013695288732248758, 0.024863984469058256, 0.032914926297962666, 0.12223995636616435, 0.0379521361818271, 0.03945360864911761, 0.09828132590545074, 0.03560534818097949, 0.03412521564002548, 0.008619308205587524, 0.023807954974472523, 0.024068030661770275, 0.03037728675241981, 0.026792341976293495, 0.04328309744596481, 0.010367204235600573, 0.03463783188323889, 0.04697119311562606, 0.04418734035321644, 0.015809945662372878, 0.005610035083788846, 0.012720931953351413, 0.04951084451749921, 0.03747798269614577, 0.04402286685737116, 0.040245794890714545, 0.00988240199097033, 0.06567449521805559, 0.0032524956955707496, 0.06474450190684625, 0.018665124329605272, 0.05573414718466146, 0.0255585227361215, 0.004596635399918471, 0.025676375787172998, 0.029816867717142616, 0.0177070108308856, 0.026805536089731113, 0.03779527924156614, 0.06312527986509459, 0.03363468910434416, 0.032000817491539886, 0.045630472379603555, 0.047155737677322965, 0.028364636536155428, 0.02724783744529954, 0.04956714596067156, 0.04645828510235463, 0.02408779808320105, 0.036437018375311575, 0.022291563218459487, 0.057025711451257975, 0.046714296364890676, 0.06465122369783265, 0.028412385045417717, 0.0320452377865357, 0.002306239172217569, 0.019045773993379304, 0.031557204867047925, 0.06673936093492167, 0.042283483049167056, 0.007774389615016324, 0.024980185287339345, 0.052058003909353695, 0.05872711765446833, 0.03334725149241941, 0.01439613991949175, 0.03216385588582073, 0.011191732000692614, 0.015669850233410085, 0.06456435085939509, 0.10003003278481108, 0.013402488997339137, 0.04065222379618457, 0.03750011990112918, 0.05193645114611302, 0.023960755971659507, 0.008271543741492289, 0.00545916791140501, 0.07310985481100422, 0.006754861487674394, 0.039354508609644005, 0.01833379059098661, 0.016249380207487514, 0.025707301716985445, 0.08660153299570084, 0.01675677003471979, 0.013658823412177818, 0.031069687634174312, 0.04909254464187792, 0.03910432596291814, 0.037151142555688105, 0.022861629325364317, 0.03052854577877692, 0.014737459997247373, 0.023311409833175794, 0.027681233028748205, 0.08880768782858338, 0.041439076752534935, 0.04874772671610117, 0.04327077525002616, 0.022043200741921152, 0.11235401327056543, 0.012602997478097677, 0.04018120174961431, 0.08904600968318326, 0.05757402881447758, 0.0186307955466743, 0.024488055712676475, 0.039630814854587824, 0.06435397107686315, 0.04475850738318903, 0.007973311485589614, 0.02902439988351294, 0.056553366261401346, 0.0925757692062429, 0.027105224651417563, 0.03547368524596095, 0.022830784819754105, 0.02065991550417883, 0.045349636913410256, 0.01623554996746991, 0.05018946435302496, 0.040718944144568274, 0.01811740407720208, 0.012617493530602326, 0.04138176768485989, 0.035308875875281434, 0.04282728476183755, 0.046829348762652705, 0.013943050705295588, 0.026511825421558957, 0.018815511438463415, 0.015119931527546473, 0.012241064354644289, 0.04024469227130924, 0.035448138402508836, 0.038546654994466474, 0.03073159059775727, 0.009347778312595827, 0.007441154282007898, 0.028453738362129246, 0.038888056496424336, 0.00584054912074602, 0.031177055622850145, 0.03195998664679272, 0.03762498391526086, 0.04053316804181252, 0.042760506737977266, 0.061512408911117485, 0.04152423289737531, 0.06877943753663983, 0.04158762842416763, 0.05273656267672777, 0.05096032763166087, 0.036090310729507885, 0.08803274655448538, 0.04551239710833345, 0.06829066162130662, 0.07167229694979531, 0.0332289794459939, 0.04901359369978309, 0.033958489407918284, 0.04668465795527611, 0.049190131548259936, 0.03692580786134515, 0.03494133720440524, 0.019191280739115815, 0.002500818630713703, 0.04269088225971375, 0.022507432349292294, 0.011671940563246608, 0.06378917209804058, 0.03523656439834407, 0.006108248148978288, 0.045224576124123166, 0.024992103754941906, 0.03767300383853061, 0.01971655335676457, 0.1336819159665278, 0.14334030555827276, 0.1308773678860494, 0.2518196531704494, 0.0942732874037964, 0.10831366971667324, 0.08808807429990598, 0.16280400114400045, 0.07587453895913703, 0.2218227327934333, 0.15074171125888824, 0.1561677386718137, 0.12708386858659132, 0.12004341637449605, 0.13742130888359888, 0.09136151721967117, 0.21991786786488124, 0.10855440037058932, 0.08300990464964084, 0.18053399904498033, 0.13003639158393654, 0.1566573152584689, 0.1281776534659522, 0.062858697026968, 0.1285998108131545, 0.08482051427875247, 0.16955505817064218, 0.12565658374556474, 0.19032156813357556, 0.045390491506883075, 0.14657565552209104, 0.051729260478168726, 0.13903023754911764, 0.11379082474325385, 0.1397942001266139, 0.1662133274866002, 0.1966262576835496, 0.10717567828084741, 0.1470284555107355, 0.10908579507044383, 0.14237882143684796, 0.1343694076474224, 0.05175470893404313, 0.1384426262229681, 0.10586920659989119, 0.17237804883292743, 0.16720028381262506, 0.11792513861187867, 0.0990316363583718, 0.08477856045854942, 0.13952212115483625, 0.16793059105319635, 0.1373680303139346, 0.09897554186838013, 0.1210266136165176, 0.19593096284994058, 0.09366734206144299, 0.12457822875252791, 0.18202753604522773, 0.11812905195568289, 0.09136317963046686, 0.20515108667314053, 0.1033476483342903, 0.07443109141396624, 0.17297900015754358, 0.09737225861421653, 0.13097131784473146, 0.10954040674758808, 0.12903944722243718, 0.14159785477178438, 0.11319877579808235, 0.12152573040553502, 0.10446479517434325, 0.2199048807046243, 0.17276341601141862, 0.14259972529751913, 0.08900157242481198, 0.12603863967316492, 0.18788114908550466, 0.12414596123354775, 0.14044343600315706, 0.1351287697574922, 0.18841154633888177, 0.11019251282726016, 0.09435844354863678, 0.09144235788179295, 0.17272495664656162, 0.1498000267893076, 0.14509718199925764, 0.09082808012941054, 0.11358845167394195, 0.15223964516605648, 0.19952945118503912, 0.19016349661563123, 0.24804433860949107, 0.12711217706756933, 0.20705779721694334, 0.18929212194468292, 0.1465636725936617, 0.17250268214515277, 0.06277188525668212, 0.13214552269450255, 0.12982630357146263, 0.11682182710085597, 0.14112119749188423, 0.08070124353149108, 0.13204300962388515, 0.18459587251501425, 0.11835994385182858, 0.12682048843375274, 0.17023063477660927, 0.226405639733587, 0.14337249525955745, 0.15993001178971358, 0.12241390560354505, 0.11372187201465879, 0.09149264411202498, 0.194751573992627, 0.09750396226133619, 0.10146780099187579, 0.18494052759238652, 0.21598425108407224, 0.09781485343618052, 0.0983066081202456, 0.10113434852766139, 0.2247938612209899, 0.09653287008404732, 0.13409697583743505, 0.1539602471249444, 0.09243639132806233, 0.1006016917526722, 0.17597766353615693, 0.13183402083814144, 0.10660734413457768, 0.11628946209592478, 0.10121729943369116, 0.07139335120362894, 0.15079661831259727, 0.09883449479405369, 0.20020053588918277, 0.1574299766549042, 0.0810499426775745, 0.10197761827813727, 0.16430165006646089, 0.09968518771763359, 0.18024355891559804, 0.22425802211676324, 0.1343794906777995, 0.159126449908529, 0.1522759467895542, 0.10169007549328463, 0.10966151167771646, 0.12105760909616947, 0.13678409664758615, 0.0865203191393188, 0.16908355775688375, 0.30051968566008974, 0.15951203421822616, 0.1549074820109776, 0.14611206682665007, 0.12643091433814593, 0.09329899254121951, 0.07988022294427667, 0.09053289704024792, 0.11665203049778938, 0.08334831720484154, 0.15897721291652747, 0.14063274727335998, 0.07843864137040717, 0.12705033538596971, 0.10336691872881991, 0.12952222488820553, 0.09093361946621112, 0.06905311785106148, 0.07991290797612496, 0.11911451550466673], [0.02429535346371787, 0.008663186520737196, 0.028234973583104353, 0.07517927805227892, 0.030463267317307845, 0.05675409049061792, 0.027500496744843464, 0.02989462104492954, 0.046977476349898746, 0.02184261052337076, 0.033721877461565394, 0.03111679832051907, 0.040490264272583384, 0.0493964842254562, 0.04121450541008796, 0.04857628466561437, 0.05825105070003441, 0.06656332859503371, 0.10411146841943264, 0.011355645705147513, 0.0054786660392502585, 0.021799593099525998, 0.04792881298011967, 0.02910494877557669, 0.04048686820481505, 0.011103545348825199, 0.06305413546838931, 0.04917824700740831, 0.01149247313982674, 0.052589544494237216, 0.024097178829833865, 0.07121454365551472, 0.05302078403266413, 0.02381075732409954, 0.046282469893672636, 0.024949642729812434, 0.05471258557268551, 0.02730089209840766, 0.029124127567878792, 0.048183253434087546, 0.028045558836311102, 0.02043101510831288, 0.007862362528352864, 0.04665045639766114, 0.045649983654064794, 0.027534208060907464, 0.030776862454201494, 0.03174370700227363, 0.02930653135159186, 0.07088863650070769, 0.011221818243419486, 0.016397375480404923, 0.023371707847607986, 0.03423212901023882, 0.10411754809319973, 0.005772409361920187, 0.03766797589404242, 0.03334161625908954, 0.024406185373663902, 0.0686548992193171, 0.0380866828906749, 0.053483619554234405, 0.012397269901287342, 0.046122481514300616, 0.019120691044788276, 0.023704398656263947, 0.03974047629162669, 0.01965312220688377, 0.014843050224174346, 0.02895047688590629, 0.04320631103057947, 0.01055005839693227, 0.03129459824413061, 0.032018571360302825, 0.042804055115474124, 0.018998566615794386, 0.024411123412262117, 0.015860644102628742, 0.06931856075035674, 0.020916747794087445, 0.04933357724387731, 0.04944379847230656, 0.0066001016447054485, 0.025018359667488506, 0.03498140469725643, 0.04272009658494166, 0.017786713250513588, 0.03219163850215929, 0.04966016632637807, 0.04225034000618117, 0.05990689327674253, 0.04614086981330599, 0.024617506623534218, 0.062165790636624606, 0.029544337519577572, 0.055634840192007165, 0.007851656093927366, 0.03049241378903389, 0.04842466940837247, 0.03135758664991174, 0.06127545769725527, 0.007228888172124113, 0.04175569815561175, 0.020475779759830663, 0.031187460957361118, 0.04800568421238235, 0.04016468281458531, 0.0716243109532765, 0.05231851385906339, 0.02702767318779869, 0.03143732129995312, 0.04379970347508788, 0.03326400542365653, 0.047414765028016906, 0.0423997771660132, 0.024561858270317316, 0.1450623052992991, 0.03163361130282283, 0.1028991366869637, 0.015803743852302432, 0.006978608834158097, 0.0412513871810266, 0.04279708995350769, 0.0412658433695989, 0.010690454925809587, 0.035132843535393476, 0.02680986514315009, 0.015140367305970617, 0.04234574881515332, 0.053541783576032946, 0.05494929251394101, 0.004477174220872777, 0.016019855559404408, 0.058788789702313285, 0.06281664821186236, 0.004857043569375361, 0.052573605706649165, 0.03171913046389818, 0.02545371282446597, 0.024031238796721612, 0.009477654156009001, 0.028270231959010874, 0.04289310944399663, 0.07790108557258334, 0.06509679050317832, 0.01301159939196493, 0.03589640577722873, 0.04981284688359924, 0.08094453904777765, 0.04417085534493838, 0.025843329328511442, 0.035954607118453295, 0.06253483904791729, 0.03615439496934414, 0.021642150922811458, 0.01526001508214644, 0.05841214169881173, 0.02778388519904443, 0.023995758200596486, 0.003194061744060101, 0.014916174246796539, 0.03082352870010904, 0.015162784406649215, 0.051625787280499935, 0.09177044991936002, 0.013622722804679402, 0.016470976173877716, 0.023579666956460903, 0.04773018881678581, 0.10162530254040446, 0.05181720540193575, 0.012095342174039354, 0.07765939139894076, 0.051823600594486506, 0.01693586935289204, 0.013313953748105891, 0.025595786183008125, 0.022406128767345632, 0.033695367098386796, 0.029414167361600057, 0.06235319522342511, 0.02236077039768653, 0.03629251416506512, 0.05009504620518003, 0.04803862708753773, 0.027918535384482572, 0.03232551685401371, 0.012725529876271529, 0.05604188656434417, 0.0288394210594041, 0.08493428424532924, 0.0642206050189478, 0.009907642645495278, 0.022986701989014233, 0.049674748043928824, 0.04498733653287802, 0.043598059830921035, 0.07440086267888546, 0.06158947691853557, 0.025338375441996113, 0.03413114942876356, 0.029287708790174553, 0.042497716910604916, 0.058020952689860544, 0.01301145350693592, 0.022197436840672578, 0.005461046605237893, 0.09485995556627001, 0.05607592188087957, 0.02215671625786594, 0.030885319491582255, 0.03279595196779285, 0.004789431795610913, 0.05890801509044, 0.023218085823048438, 0.029095310185636793, 0.013240547285282185, 0.00657872948795557, 0.023356015028964196, 0.04064833579052772, 0.025165294729439274, 0.07126533200166055, 0.05999798660299607, 0.02999718500567334, 0.026750199862622788, 0.03751571602853281, 0.02170338701190693, 0.003399731221309464, 0.012325885472819209, 0.038885430565902164, 0.04646558953183038, 0.030474042453403984, 0.039491576076086075, 0.011673887110581356, 0.03661296250564711, 0.06431909437690463, 0.02736565487326256, 0.006875323081788207, 0.03866366157308221, 0.04453124225671802, 0.02568100339600018, 0.021806171496531794, 0.058553561967398436, 0.06618922509785209, 0.02062181237020663, 0.05332943604194692, 0.03945354079561574, 0.018450339158464755, 0.02381815335580281, 0.010850876719424767, 0.020183039396735172, 0.020798677611829977, 0.011539349731590067, 0.054048662805663686, 0.08636412037802593, 0.03495579678565264, 0.05363979795947671, 0.06117419313107218, 0.07905720746410744, 0.028039105968283753, 0.015396806045568414, 0.017123122965650897, 0.021743632620200515, 0.06353572569787502, 0.055113365674125295, 0.034403954433011155, 0.01969612606002816, 0.009110208783697869, 0.0498066450735288, 0.05302681281630482, 0.026932824170216918, 0.05840834868805749, 0.017837620340287685, 0.07016921974718571, 0.06478405371308327, 0.02037945662492088, 0.058551166738782606, 0.02349390521911638, 0.05699356246207442, 0.0198957137430885, 0.008437680496302034, 0.008437774643035871, 0.023575292101928165, 0.013119092061450439, 0.03901745990983077, 0.009998789406381547, 0.045083121928785524, 0.05891391155975206, 0.04304361868915813, 0.036796153389981816, 0.03351101252649512, 0.002384131811725508, 0.05305929428764752, 0.04338684545031615, 0.13396809489599296, 0.020574998542932526, 0.02469856272052441, 0.05681300090093698, 0.0693072360008955, 0.04234729587499585, 0.04155683311234627, 0.06984492750572306, 0.03881334979087114, 0.035945161910993714, 0.0691238958388567, 0.02285028082717742, 0.01609244353936187, 0.032992153761110136, 0.017352869833952615, 0.05594585689582995, 0.05056658393836447, 0.012436311109922826, 0.024146840807848742, 0.02258088715773608, 0.026600923854857683, 0.035473295088325224, 0.03425018143440996, 0.01706822100095451, 0.07173035240599088, 0.06106119669441666, 0.039133910089731216, 0.04962000044594918, 0.043773410243115256, 0.04022097407973238, 0.05059141153469682, 0.053516470827162266, 0.018268490077129433, 0.024878055589007478, 0.0185874201956072, 0.010460903984494507, 0.02710591166812394, 0.014353882454867874, 0.02449460357560643, 0.021821385947987437, 0.036594428321612735, 0.023070295806974173, 0.05058962020224758, 0.035790337183113606, 0.029908388520457914, 0.0544137858918735, 0.04820461032379951, 0.01881119765208236, 0.04361833445727825, 0.017361151353855218, 0.035675583340759785, 0.07938388814883572, 0.03575172514787742, 0.04677412619016, 0.01008406259851264, 0.012925242240141546, 0.034157574975064824, 0.038844871135162454, 0.12251660866396767, 0.06655671966395207, 0.11248900102717535, 0.16082696723086493, 0.08785377615796668, 0.12062927708029747, 0.15360016216124805, 0.14522227671529564, 0.2030704676040581, 0.08934164739080838, 0.09331369639507361, 0.12241843821746962, 0.16210040104176315, 0.10644165945372411, 0.12861490143196924, 0.1326217864240919, 0.09893715035702501, 0.10873014094041926, 0.1739855661456074, 0.13067327812314034, 0.13743964289980276, 0.1444711655910526, 0.12271883924092565, 0.11271103804132768, 0.08321313267307621, 0.08774039295635053, 0.12299671290176255, 0.1516290722148759, 0.10722830545689378, 0.1322483750326293, 0.10321128315159253, 0.23286228041563714, 0.15329399359013351, 0.10978632819439683, 0.18415787816047668, 0.12921091302164964, 0.08210528854812894, 0.13829395920038223, 0.1306196874273675, 0.15903469840330736, 0.09975568750607115, 0.12625239177473954, 0.19502406008541584, 0.12552786565252713, 0.14010724904281752, 0.15443338959344796, 0.11662769823202065, 0.12023565891597952, 0.09506245755723544, 0.15113659149834088, 0.07289559380816561, 0.11426020812775407, 0.074539148115686, 0.14057674099292072, 0.23502102600676672, 0.09029628509389502, 0.09593133521931511, 0.14534045037414345, 0.14944436587393284, 0.138056607650859, 0.09935476830495255, 0.1253471989184618, 0.06680705837373223, 0.08771521252180849, 0.11763537701751504, 0.10104632896504231, 0.15130990291280405, 0.13477973134389945, 0.06043640164924519, 0.10258836764842272, 0.13366552256047726, 0.15147591329046659, 0.07663223865841116, 0.08987080292510134, 0.14932140175785336, 0.06325934481407915, 0.143415595803942, 0.11230272280850581, 0.14709541334637574, 0.11435978992709092, 0.22421406661825521, 0.1531681931976761, 0.16087563176240238, 0.18630886131099292, 0.1430935902254922, 0.1198313334690673, 0.09896633414817707, 0.10938323089586836, 0.12416932997959, 0.16376343608966895, 0.12480450661054679, 0.0941318671352097, 0.12668898834713868, 0.21408531655158314, 0.10272024771464722, 0.10154526254960469, 0.10932505330336945, 0.09835518444223063, 0.14695035613008908, 0.10034295277936117, 0.17041583412459918, 0.07030591062669243, 0.17334805535418646, 0.16535626990454538, 0.09484183189592191, 0.16012753333364213, 0.09674146531948022, 0.1433902864477464, 0.1528320333787373, 0.12467519140669278, 0.15420738314943655, 0.2345870350088392, 0.17445345675306662, 0.10054679148431335, 0.13721639130796703, 0.11997906411332743, 0.20881771349481174, 0.1766892024981124, 0.22077563112335546, 0.12548758781382016, 0.0777781485979046, 0.13623501253979547, 0.1592376617980855, 0.20450731978884765, 0.11580436384039265, 0.11200299353471824, 0.12745810779077665, 0.06499784652675901, 0.1412848194262811, 0.11360170346285615, 0.12357306054660253, 0.1374235480491604, 0.14900509587356023, 0.09585213661193848, 0.08482484333217144, 0.1659315318933555, 0.0987032593360969, 0.11371882539242506, 0.14005677960813046, 0.12383767563317503, 0.08287279986377273, 0.07561339797186, 0.20030337465660913, 0.1388053439025368, 0.11101921275258064, 0.12706689164042473, 0.11208641941526107, 0.13299419358372688, 0.2113765233329364, 0.14693982526659966, 0.14380420637982233, 0.1359007390482085, 0.18543877585658006, 0.08456242669905935, 0.10991549412054674, 0.0995702642415251, 0.1286775709262916, 0.1526749932340213, 0.127858362027577, 0.12778741440602712, 0.07738654568259205, 0.10108272558344261, 0.10295272738273654, 0.10313101245888642, 0.2180661457989897, 0.06767628208867141, 0.11424595889236246, 0.11283776802676064, 0.11740527222199099, 0.29239591157862116, 0.12070231458970479, 0.1436024507773774, 0.18879318157477037, 0.16207074906144822, 0.09741421921976975, 0.1480259019881487], [0.011347488017885812, 0.035423534722732644, 0.038069760227309804, 0.030173933200005974, 0.013192777571800565, 0.05051555810496211, 0.05500144810814943, 0.023335290873157125, 0.03266269447548049, 0.01883360287839813, 0.02390771828192685, 0.023205152945593, 0.011843799064601106, 0.054952162717069895, 0.012700282436396395, 0.06087200077516692, 0.023303280983652388, 0.03360366987596665, 0.05884856863745621, 0.05013683717697859, 0.034526508035404344, 0.015109587261187179, 0.029612964551363672, 0.016431792472888316, 0.022429475460999777, 0.060539647537682734, 0.04378722860877003, 0.02631589673858668, 0.056414670310914516, 0.05735961174858468, 0.05463225381182773, 0.018295102220560824, 0.04051894594782165, 0.03524259318198476, 0.08128893628184285, 0.02218315876754267, 0.05378101466755782, 0.02079245544570897, 0.01319512615113386, 0.0379390845607434, 0.020954689775992717, 0.020989446035985435, 0.00873829865096403, 0.06980717381728546, 0.013599797650905592, 0.08406537265649863, 0.042688999325037, 0.02756604492398245, 0.01947572431527078, 0.024218865603740727, 0.04679886218426483, 0.0983681580317872, 0.012484330185023802, 0.03183737536892295, 0.038967021009219546, 0.04804114105978182, 0.015121967132602419, 0.06958968298775808, 0.04272145365497895, 0.02733804189067866, 0.042186517002327104, 0.02025481652734535, 0.04365042577098523, 0.02900798272873674, 0.013724236732481845, 0.05751127111060279, 0.06266227470976965, 0.020204572705551982, 0.05837655932243381, 0.026658590849755064, 0.04440120441306915, 0.014606937001060163, 0.01363848686950015, 0.012011496449953743, 0.03927235837493624, 0.03174383592392717, 0.05028806227658476, 0.1065222897699901, 0.018226984090038707, 0.05766896264893668, 0.02464920438693038, 0.0640489628006305, 0.026125703372859528, 0.021997382664786916, 0.013794428635654705, 0.04817631541352187, 0.06204590028417962, 0.04283577662759593, 0.032579292343663316, 0.00671335422833051, 0.030137546759630953, 0.0609518304201109, 0.06331187699522291, 0.059480332237269194, 0.04833774228713342, 0.006098557820743216, 0.06765097273247582, 0.05022259382531047, 0.01646942232868501, 0.03619064909539052, 0.03138771021206464, 0.09711926683251347, 0.03922584479940789, 0.04302297765389085, 0.0164011769728469, 0.03666224789672664, 0.02433671017310449, 0.058569853593196185, 0.04569348453411034, 0.047933131855513365, 0.012423464745682265, 0.049699935263821056, 0.03580759572131293, 0.054118290676602294, 0.019944193373833383, 0.06298473490668194, 0.015882676134684255, 0.057526287090565474, 0.06392673828772136, 0.020885424921289086, 0.005526952287514827, 0.036005303862371614, 0.011662100109138658, 0.05172698060050607, 0.034704715080027065, 0.046194989766393385, 0.01582432721209313, 0.07109894164438758, 0.06540083525968449, 0.0732594242851649, 0.05132748632292662, 0.008717388746195605, 0.04706575036314981, 0.00969945198656725, 0.0784790888428688, 0.07903120600219284, 0.01396259421017021, 0.03111963459689702, 0.04928085507292833, 0.016338873887434602, 0.017529053147882223, 0.07919271090733153, 0.0646311187052301, 0.029962226881512573, 0.08076005216155734, 0.014829934142263872, 0.01468092785216868, 0.015104766269879681, 0.05832230366234269, 0.016256116363885145, 0.054636657504098754, 0.06456915488732712, 0.021067387657240033, 0.03681582072749734, 0.041759518307766745, 0.05160203855484724, 0.03613233579588788, 0.0557790560248707, 0.04952532106212207, 0.018866559324253882, 0.027547938217009817, 0.034876767812030654, 0.019884899591228793, 0.05144611120756183, 0.02699190591062818, 0.011264165613933333, 0.11472459749451705, 0.03395131390009608, 0.03472713726971831, 0.045076034630515745, 0.03576808462717703, 0.025522662160385932, 0.01088104269001633, 0.0657083744715367, 0.014258880766906908, 0.07529382833412715, 0.00535751912476761, 0.008946288293892784, 0.04268248538885798, 0.012676587993545192, 0.012701791328644114, 0.025762064582003013, 0.04530117254970329, 0.029267369702990566, 0.08103881470326867, 0.010692696635877448, 0.07136253214308194, 0.0006415079457968074, 0.028208632853680422, 0.0054858987984646645, 0.02330323518253863, 0.06252911899771009, 0.025896848778107336, 0.0666226732677647, 0.04247079264106495, 0.05685635589595352, 0.022315522289967964, 0.053659071746681414, 0.007076159693367247, 0.0015746729311233918, 0.0035824350447260906, 0.04338762237291251, 0.01682633174849408, 0.04698511665420873, 0.04722090078783887, 0.07266936344759804, 0.05469645679529224, 0.008613223442807794, 0.003939698574998016, 0.022766541124188473, 0.045650692723159275, 0.026607385204572762, 0.06764477770775557, 0.05937807700995888, 0.04220487815993173, 0.010497573713239814, 0.02666683674656919, 0.02263694432830172, 0.03768753127327987, 0.018294035224244, 0.02600223714086626, 0.04324820717530591, 0.03126325331894415, 0.05607516870700887, 0.04427472548559308, 0.021002258473475064, 0.02199720115666943, 0.06162502536816256, 0.015991862597210065, 0.009133818409671741, 0.03869161043050034, 0.024744684442079494, 0.019656055174501877, 0.06483361391084534, 0.055357142950275114, 0.02932008508858936, 0.07803774252533913, 0.03242885773735387, 0.03710631174700601, 0.00929039460606873, 0.017956530209630728, 0.03756494035146066, 0.037245519991431913, 0.03959889317463551, 0.016914975563330308, 0.013587402512452431, 0.036503996567002366, 0.03496517753228545, 0.038462207918720584, 0.009779095882549882, 0.018185922543385198, 0.0322998207328575, 0.02664879280408578, 0.055970681099487204, 0.022340490682316676, 0.03195568812744958, 0.02116752924796726, 0.0716822442731687, 0.052403215385441265, 0.034282991995236704, 0.017916698507698517, 0.041505895488496335, 0.0023067699138274683, 0.04578628437593579, 0.0050460490747354925, 0.03128153644502163, 0.01918612896198673, 0.03213643628571715, 0.01706943048962525, 0.04461529578215309, 0.0288788812634136, 0.01807115682666855, 0.020850750085498606, 0.03934658671330128, 0.040037087697003565, 0.04747277977211135, 0.029384949643697058, 0.019592608757583157, 0.035786859691143036, 0.059539018731032095, 0.04703984728881291, 0.05817864422819444, 0.03232929968674268, 0.04355736808585269, 0.03082837683281728, 0.039775390311011245, 0.026115389640576074, 0.03949587120275412, 0.006119486385224653, 0.015591562559295977, 0.00926800973580352, 0.009908000572717615, 0.019332758683179106, 0.06492940948477813, 0.0033735117800201154, 0.07404376326927117, 0.007527878690910126, 0.011618808726780117, 0.02710462754060115, 0.04207982076331973, 0.07862220544900213, 0.05169037363624998, 0.010212044481055012, 0.028837229391293864, 0.061418085758175166, 0.032925178962094445, 0.041141922519143136, 0.027618706026779752, 0.0406948357953557, 0.04354914424142667, 0.08212605171969958, 0.01745598340806152, 0.026341472419777086, 0.06160819769970008, 0.06533072223620755, 0.0038772228872403502, 0.00959495674552662, 0.030673056774373566, 0.027974460240719572, 0.01957772339561156, 0.012235834545988058, 0.017887351868141974, 0.02805184037424624, 0.03849271485315902, 0.04229634468044553, 0.047378680535725186, 0.04587626829743385, 0.024501821491867304, 0.06390509980597667, 0.0175847659619259, 0.03243953787854739, 0.04148019597466503, 0.04163023703066366, 0.05741198108132396, 0.05344694134380136, 0.03053576878405043, 0.051233373515840085, 0.045952878293714354, 0.05068317321794374, 0.04772248065897396, 0.010618645564786025, 0.03973603527992964, 0.08199878569160189, 0.009265831638393658, 0.03127479859228645, 0.021336872928908894, 0.013051735586486757, 0.06357307226530143, 0.0354017707120095, 0.06554167198815516, 0.013315168325789273, 0.04371908333684717, 0.0933341813672866, 0.09333531452076775, 0.13746746283556732, 0.12383201665111951, 0.11305082802261625, 0.13249883587871278, 0.1688507931040866, 0.11542035373193876, 0.09825387237859623, 0.06252649985253811, 0.15415020978876523, 0.08082324412784406, 0.0976388550230435, 0.16115961223840714, 0.06385560746171645, 0.17160883439438684, 0.1545227797968047, 0.13908264759395803, 0.1873967700770923, 0.16123841729547295, 0.10669572332075664, 0.0951284993706005, 0.09408650028386287, 0.13892233691045217, 0.14645190430538996, 0.16135777160525322, 0.1372705248317548, 0.19922795093485288, 0.1933216835771288, 0.14813141418354853, 0.15850525109895638, 0.14971644484571048, 0.07711937930434942, 0.1406725501375539, 0.19352113216051034, 0.1210960956024272, 0.17473029904067516, 0.11837089540702955, 0.13817231144223893, 0.06973247389708247, 0.12651764468422957, 0.10865151230245829, 0.13374800527734415, 0.21826855279505253, 0.18045347050896712, 0.1597388413335596, 0.11760649856712137, 0.1764483225664922, 0.1833083387464285, 0.0971537906942623, 0.10491655700440917, 0.17054061671452864, 0.09594984565462385, 0.1392992902547121, 0.13027401454746723, 0.0752602204946535, 0.13028948514589242, 0.1616226988179343, 0.21386804963861192, 0.1658176737172263, 0.15421192933406147, 0.16877715848386288, 0.13471923316163675, 0.06848322307424885, 0.1175289691558906, 0.13224195609135286, 0.21940433899206774, 0.10845202300697565, 0.25510490259953905, 0.07327935964401279, 0.15234579518437386, 0.1445914969912597, 0.06978811376861163, 0.07068147297416415, 0.1406938697078398, 0.12712747124688967, 0.15374205740434782, 0.2162027529307774, 0.09897687179701668, 0.17978486924299172, 0.0981256224747215, 0.17174648200826986, 0.12595889823777334, 0.08039382645594222, 0.07154469843953848, 0.16121761341180119, 0.1014031773166997, 0.09729793867362396, 0.07041467300483159, 0.1036838081532291, 0.22117714743529046, 0.08791793842933007, 0.14898972027003765, 0.16471632995775767, 0.13994186291737215, 0.14700197907430784, 0.11067019469503846, 0.10730772798082658, 0.12884743538286003, 0.121527548879385, 0.13465304885591778, 0.11153796634503774, 0.16484512947499752, 0.13167297733681543, 0.12192901090851851, 0.13521522868956837, 0.11982895859650203, 0.14579308751438344, 0.10690625916634287, 0.10475235831524644, 0.08199495875409671, 0.11550082798515048, 0.10068258669759546, 0.12519983468311174, 0.10178130452654191, 0.14990826669548238, 0.11544218898883887, 0.17098840911473545, 0.1553884276321956, 0.14603707513638906, 0.14222700601177557, 0.09005343062537056, 0.11088275257498026, 0.14749356412461825, 0.23869608023336955, 0.12822952068277768, 0.0773640318906733, 0.14905650168657303, 0.2232179364987782, 0.23864456585475377, 0.14048645512333938, 0.08089339786342212, 0.10386711438851697, 0.18458618303494795, 0.14076343311795167, 0.12171367103500025, 0.08742941357195377, 0.12555435565965517, 0.12428919997598444, 0.06274081513817821, 0.09563491041106836, 0.16194452797727926, 0.12973387353122234, 0.1306147069803306, 0.14643427596560546, 0.11345229683709995, 0.09015168928142105, 0.061417203662650924, 0.15676452379141534, 0.11253478178488356, 0.19245410870228494, 0.06706023335989032, 0.11993803988609995, 0.055838488907154114, 0.10607592229332242, 0.1591673655701535, 0.12834439666143485, 0.17287529286529335, 0.1251986404614789, 0.1069497736170888, 0.15879916532763413, 0.13839193965707505, 0.15539613579000744, 0.16483565712613718, 0.13906330934592656, 0.13463144430092402, 0.18486655370465346, 0.11699748624648366, 0.11059932849769082, 0.09719285395528589, 0.12260089628398418, 0.11568628517644745, 0.0824887083311166, 0.11628848500549793, 0.11396287408258234, 0.12103809442903314], [0.007860297237389853, 0.019507009868643115, 0.07582386596394436, 0.021491589091186012, 0.03725141646074397, 0.002638664504047483, 0.02236439038201102, 0.003870048651671303, 0.011956741218455136, 0.019563039897808006, 0.03679101348721555, 0.06010742751615388, 0.046910033361720185, 0.05746836055602346, 0.04729932925796934, 0.06076054461300373, 0.05330671190417238, 0.03886987515059965, 0.032184167831603966, 0.026425654866865704, 0.026173036279422895, 0.06772944530738251, 0.052226144886974774, 0.033561118944947205, 0.029292848692940812, 0.048377304271395714, 0.035528585514319797, 0.0659464859802808, 0.020640327894527997, 0.04256056282403214, 0.030731465068778822, 0.01575552376120218, 0.006321582951516445, 0.001698311765462027, 0.015106985079390662, 0.031481046096554825, 0.05426584829443267, 0.03923685403008546, 0.06203486051942621, 0.02774837746151856, 0.027914131692211543, 0.020107918784820607, 0.06827631060566221, 0.02377877796867064, 0.01847262733748981, 0.019769585957484584, 0.03258857809539352, 0.02614343349289681, 0.030203401975865875, 0.023074056587315032, 0.022768457985616157, 0.05089329515716859, 0.03891450918412634, 0.023478371856201972, 0.05296886253303715, 0.009388522644128119, 0.007827145712716239, 0.0404290061310998, 0.033162428731364865, 0.022916477007259215, 0.02260357397608459, 0.07736326514610223, 0.07345520199409553, 0.019753255315923264, 0.02172104418942971, 0.031964654967721016, 0.029569643483098065, 0.04889147775247693, 0.01647077770238476, 0.029473885228591304, 0.031079499250543968, 0.010244152758137455, 0.0238046284565436, 0.05581573762797883, 0.03767663400088038, 0.02727793386605169, 0.04770387522876263, 0.057076208027345796, 0.02971711289137602, 0.04835965896823576, 0.011752102690349733, 0.03391552796321256, 0.07652416838599102, 0.08472813852131367, 0.008661502905722176, 0.0534113284333476, 0.036254580664847574, 0.01640854586314942, 0.050660415153418265, 0.03365046504352774, 0.01886941765301994, 0.022208988899365067, 0.03189227902995689, 0.038130601069756916, 0.01738278305024973, 0.027079348718481402, 0.028844730595925024, 0.02322026900947094, 0.010747320401216192, 0.030769306966768842, 0.05658507759549788, 0.07073878882718937, 0.02763344720005989, 0.03248931520751544, 0.018935703738991703, 0.06810243600713355, 0.011054432984175426, 0.03018603826473866, 0.032066574320197105, 0.010781147916402136, 0.11506756980504308, 0.035828833867396624, 0.03087894126240696, 0.05899615678936243, 0.03629612736403942, 0.01843919082810836, 0.005576671092837516, 0.0244047808061753, 0.023963643138163855, 0.028366957125919204, 0.029469291546515057, 0.016366022073530724, 0.040290184651634524, 0.011453078244812787, 0.052121009278510294, 0.05532929926578488, 0.04352404523108687, 0.03162520086126668, 0.025881125425387706, 0.028552858757653406, 0.046243820539010425, 0.02767248501602028, 0.07218634829457317, 0.05395513353869319, 0.05812522316617625, 0.05373906763270497, 0.06930971265371356, 0.023482668679207563, 0.053526027992899926, 0.03695311211049557, 0.09958167720053877, 0.08595321992678301, 0.029331586257155453, 0.028138424835300872, 0.06393061272267785, 0.03584312042221427, 0.03783370128699711, 0.05462546506896615, 0.0609705104891743, 0.02587612292596272, 0.05650341929867864, 0.022779277226488506, 0.06578058416822127, 0.025636942724564245, 0.04447134118527174, 0.034741532390138934, 0.07235060126653739, 0.042311767781419415, 0.07487573541168656, 0.02600263069117708, 0.03872832256768431, 0.04448947164097002, 0.0794885725315128, 0.04401419857250793, 0.04608916544488498, 0.04521921909015093, 0.06913188898137637, 0.022969574068806002, 0.010587679771041232, 0.06233180779963732, 0.05860166331487043, 0.04107546340674162, 0.03059816686436534, 0.06759151270879166, 0.04134995457051056, 0.04033730551600456, 0.03131195856258273, 0.005863828809067074, 0.006637545751540789, 0.008347609213420322, 0.05012759892269969, 0.04565059433558157, 0.02920992492831179, 0.037754390721342394, 0.014122351887635887, 0.018528535230351344, 0.022924493898504546, 0.02616662242715912, 0.03376650810241699, 0.050102784897067716, 0.01617788975792272, 0.10834162535944156, 0.08532974802489791, 0.025153557769954205, 0.03985655666994197, 0.017688924479963522, 0.022634642398250953, 0.051484957337379456, 0.046692854658301385, 0.004798972422057497, 0.014933617685788443, 0.057672586025936265, 0.025687440996989608, 0.05384454590135387, 0.0892076435099755, 0.04207172244787216, 0.0524998896622232, 0.009907381409513099, 0.026126202096098235, 0.028794912554855858, 0.029320288649094955, 0.00968704158107617, 0.015427901609135526, 0.018016907951927612, 0.06961560302547046, 0.055083625484257936, 0.034047574270516634, 0.06783744772630078, 0.03848507794152413, 0.023196425288915634, 0.01495037241173642, 0.01773344655521214, 0.055277279378580194, 0.0245078468828329, 0.036216158619416614, 0.013326014708062368, 0.06852119389389243, 0.007367615504855556, 0.019401161798409054, 0.016981717964102114, 0.031864771220300875, 0.04394223993378026, 0.014662152788202678, 0.052871672569641044, 0.032224951178899834, 0.012715359484510762, 0.03707673101286803, 0.04143910389393568, 0.03348917726959501, 0.0158286596581872, 0.029471544282776967, 0.06065194508326905, 0.025977665691503456, 0.034952088591775725, 0.07100110368004867, 0.045356517258499346, 0.023065111799431697, 0.030867840429501872, 0.02334837133197912, 0.03711556696466037, 0.04689241859263607, 0.05531001190787979, 0.024185291691018, 0.018934974313846657, 0.03542206569441727, 0.07190714470509972, 0.009909518794821841, 0.11511423944362573, 0.027993756080312387, 0.03456308785825968, 0.032732878745134385, 0.05689074744337371, 0.06812720253531422, 0.05468646875981774, 0.020093873109934584, 0.04372846408347998, 0.019229349946337085, 0.047420637748603306, 0.03218522634623306, 0.016967327932694128, 0.08777900838426181, 0.04565349846546139, 0.022112333282296146, 0.0030842272805914816, 0.05224611756524869, 0.026357397636664764, 0.03736360204805221, 0.05000756268522569, 0.00467550619006423, 0.040590198910129924, 0.029143849188195806, 0.05071575986221433, 0.0773972597505365, 0.015214252984151244, 0.018463171952004944, 0.029086346738040447, 0.012613933766260743, 0.022371031543506042, 0.04357718809374741, 0.0903687390631863, 0.0448612850824637, 0.02528075933722513, 0.03487219448600497, 0.015468849501173412, 0.02599059178360871, 0.018190029376585568, 0.015491658455825277, 0.02485896330992026, 0.05215285631961056, 0.045727170405111144, 0.03109855590654271, 0.008738238430981125, 0.05633260150040899, 0.037530552196715555, 0.04694359031106744, 0.027111918399376527, 0.036320249283952374, 0.017239379763071026, 0.00477331828525556, 0.020021485297807624, 0.04167343596262591, 0.030465350419815098, 0.02066912661705698, 0.006082708939045135, 0.006188490003946104, 0.011004737079409617, 0.04580282027434025, 0.08541210860546146, 0.024270490244297043, 0.01570930704474449, 0.0390897408526923, 0.033653277571180036, 0.03274336889652269, 0.0137197414379833, 0.03882452526262828, 0.02802267185013209, 0.01838644321209618, 0.04164385862116303, 0.04843043017068079, 0.052296190056949854, 0.0021292004800800768, 0.04629993199237755, 0.12403094954788685, 0.05262494366616011, 0.04332037955256445, 0.045224311495465894, 0.03576995059847832, 0.05713581054338387, 0.059101485780307224, 0.020694452936628034, 0.05208612918587668, 0.023590721988252232, 0.007479642484603184, 0.023459710446851592, 0.06570582996521677, 0.046650649780141454, 0.03924129164910742, 0.05400906350197537, 0.035162509086408784, 0.03724422059687121, 0.07801151714686837, 0.05670604681862252, 0.14878556265362672, 0.13355743193200656, 0.12552504294684955, 0.09922810617302145, 0.15148743481508323, 0.14997831865080766, 0.2074402602655547, 0.07730292302689382, 0.061193952070815225, 0.10781679209321737, 0.09952611875321184, 0.1352174271430288, 0.16924180569393293, 0.11490283507321562, 0.10880350414663553, 0.1805659851857594, 0.08104825991072825, 0.18368082733026572, 0.1361769706543003, 0.11567000033599989, 0.12656744915459836, 0.20280845809195722, 0.12736942326383932, 0.08392379632485764, 0.16073190447475227, 0.09778132023555891, 0.09027215638863188, 0.16028488560446671, 0.16602070496550628, 0.15981922059186868, 0.08955924000058856, 0.12253881032977786, 0.04088760080880352, 0.14107565422143253, 0.24532962856548174, 0.08351202056344066, 0.12079625097768647, 0.09380341547408275, 0.16741620722625936, 0.16870064687516007, 0.11358780028032404, 0.1766442699091775, 0.1643630846270493, 0.078412619552442, 0.11307127906807832, 0.10638108663260937, 0.14304340577551297, 0.10452175818915878, 0.10791640781930514, 0.09435992954032761, 0.1878190224191972, 0.10830656545502798, 0.11512610023575169, 0.13551903595881803, 0.04777753020503691, 0.1085746478555458, 0.13920087553560734, 0.11185393296182156, 0.08155862002500466, 0.08077821654400655, 0.07913333909319979, 0.11218085791915655, 0.0997154503794653, 0.0975521043209093, 0.11347850864487034, 0.13905322631554945, 0.1408726636852537, 0.15708496873932226, 0.13794844916888646, 0.12202225519078118, 0.15991205775312015, 0.1228938198515347, 0.1342225998107876, 0.1622338281678302, 0.28336819314530914, 0.12713584436901978, 0.14157802797853947, 0.08540801025394883, 0.09954969105975968, 0.11069779749959707, 0.12378259216036115, 0.2650928023670401, 0.24499003535934857, 0.17487779898302896, 0.08208032524479286, 0.17191611576293195, 0.24490052301968845, 0.168768758220332, 0.09652584046125412, 0.08284099692744867, 0.22887499151485308, 0.1638298918093954, 0.1901397614606789, 0.132119887641498, 0.19094450399279594, 0.17317644027726992, 0.08333876343177897, 0.09711378426956278, 0.1807819085993937, 0.08490364160388708, 0.16003393621316978, 0.15260168431060656, 0.12477610313466617, 0.11062311115009443, 0.14644072204828262, 0.09987912659666368, 0.15319020487368107, 0.07288002821483783, 0.10381577642900602, 0.14940725000841276, 0.21920643746852875, 0.15950052626430988, 0.12672419074390615, 0.20628084747919015, 0.14808747225574084, 0.07315722334065608, 0.07820565280105386, 0.133956926209586, 0.10435007525874035, 0.13582827150821686, 0.12479187228849956, 0.12502098642289639, 0.1643280993614878, 0.15768131959651197, 0.18864680800054753, 0.09200919246567146, 0.1582221527184759, 0.1159803486828293, 0.09157123882323503, 0.11922215830002512, 0.098333111698074, 0.10165503594492163, 0.22583292903644697, 0.1449296652738537, 0.12538059641207966, 0.10363235484276499, 0.1088829402412687, 0.10456158140940325, 0.17264912357287748, 0.08903661875852517, 0.20454257646841661, 0.16844321068908485, 0.15744631577815327, 0.11755605627383504, 0.1846800787108285, 0.07380982475089175, 0.10598072383020606, 0.1236429496535233, 0.17757357790001801, 0.11482470855116844, 0.08194020097809178, 0.12071300830159869, 0.14675440878740378, 0.09057388055537428, 0.07186133680599076, 0.10028417807604585, 0.16978087462484837, 0.15119904386145727, 0.15666206500359944, 0.10239768573748213, 0.13400409796408244, 0.11760155883218561, 0.1834471805819443, 0.10078961202608687, 0.11646696685680322, 0.09400584282619612, 0.15666792754616055, 0.16929828694888524, 0.12270358577370644, 0.09496004626687084, 0.11387250678879873, 0.16641516451324734, 0.13792927376925945, 0.13115563509719713, 0.14160274022391864, 0.1300240693879979], [0.021783667882638316, 0.06849236972630024, 0.020107036689296365, 0.008542404742911458, 0.016457905893081, 0.0941216212564281, 0.01059728188972388, 0.03665696210893137, 0.029475778341293335, 0.05993969365954399, 0.07819457232419934, 0.03057154793558376, 0.08936968445777893, 0.014084673686219113, 0.04614630148613027, 0.0321332946685808, 0.02089728062440242, 0.019696419526423727, 0.02234646857583097, 0.041579716705850193, 0.013696899404749274, 0.14569779405636446, 0.04352725809440017, 0.042453116803829155, 0.007993374917922276, 0.023948114864262085, 0.021332769488383616, 0.03930422916476216, 0.03128035918676427, 0.08276079408824444, 0.03681573251794491, 0.02707233097005103, 0.027027021794180785, 0.055637537368706295, 0.0050838048835950235, 0.023807259476078407, 0.053880477723266394, 0.02110198276516582, 0.0478114230292184, 0.027047203121972934, 0.029658229622457708, 0.014167885828231062, 0.04836368268089635, 0.059202098952872415, 0.02549869121451463, 0.03291405098778861, 0.03355469321832061, 0.03809853350477559, 0.05921849914427314, 0.03255799652210303, 0.03600242008854236, 0.020627737677256976, 0.05773575085082224, 0.03618383999647839, 0.07351552375725337, 0.034575820567884614, 0.030601362764303173, 0.014603054084415947, 0.032023921608924866, 0.04018881151984845, 0.04156801876212869, 0.009463465140600289, 0.03416056392182197, 0.0180539373042328, 0.05214356717520526, 0.11153101814644677, 0.0014093766055469001, 0.0269537417085043, 0.013326605881697364, 0.011026309403989996, 0.043089776033801694, 0.02740720326879195, 0.017036789562553167, 0.03554915530341012, 0.0018156787097853208, 0.033963483425655534, 0.036719655351979394, 0.08032717396106039, 0.1112926420090454, 0.05156276834064296, 0.03757468072165336, 0.010988923820800014, 0.021985986669148718, 0.02618185553832778, 0.01136661846456783, 0.025074396482003585, 0.012131470771107291, 0.04096005138541971, 0.005656521093832063, 0.025897038767912557, 0.03383362878646169, 0.04016672520499144, 0.02480420553391533, 0.07210652543497936, 0.0261324446182698, 0.00806053207322423, 0.017453136953658292, 0.02829718845896423, 0.05801639971988542, 0.007012158998155168, 0.021622146014124155, 0.05609685129352978, 0.029537799834672893, 0.053342005903167386, 0.029653642725731646, 0.011758685328199394, 0.03180704824626446, 0.032501956314912865, 0.010839121100226683, 0.07027703896164894, 0.022077046068651334, 0.040560848877898285, 0.030328968273741857, 0.03448837776003139, 0.06466444834534611, 0.03992152300530246, 0.026826808162565743, 0.024147069813417535, 0.023593369971162508, 0.02828075094813747, 0.012923100613988936, 0.09406932656254087, 0.04551318081627999, 0.013176466438121029, 0.009071584874098855, 0.026649523925568377, 0.030558984859713485, 0.07393027150205203, 0.022263034213600413, 0.020240190705018382, 0.007825595260198628, 0.009742707745837314, 0.059918374089258056, 0.04545006688152041, 0.03640950038763029, 0.03583696610959513, 0.01929317634286625, 0.08314249039228473, 0.042129157044525654, 0.036318040652466674, 0.005632293576906834, 0.026877745786415677, 0.08273766282945871, 0.03721688920632005, 0.057850138284265995, 0.00273410278688451, 0.005698876946033644, 0.03575606098664658, 0.04655231309256383, 0.09043790213763714, 0.053608283400535583, 0.03635616414248943, 0.022949957621416876, 0.01332805200945586, 0.09765731117555074, 0.01044794820648219, 0.08370786612587315, 0.030441157253725187, 0.028084941008793454, 0.0313053496315011, 0.01895408864532198, 0.05603772035932966, 0.008424691639707556, 0.02620763817269887, 0.008801117422990501, 0.083292263426951, 0.002727125962597451, 0.045552776727293215, 0.012605245973515724, 0.009616336535795458, 0.07806193908410412, 0.012740869856705623, 0.056036081697259627, 0.04210900116179671, 0.06830236635037831, 0.039729032798537185, 0.05135858358283128, 0.041905433870851994, 0.0706398244947195, 0.003761505101075662, 0.09703151868390185, 0.09032690737928663, 0.020941482091854726, 0.0349053612777165, 0.04329928389883467, 0.0374515605425196, 0.07259788656873362, 0.058029509016445706, 0.04840568060587559, 0.011936820278476392, 0.04838095139712095, 0.035217585773872476, 0.046788487383829694, 0.027519560186192393, 0.027626059650044357, 0.042481669557413886, 0.022708529772769128, 0.04904545770425882, 0.015315280063077807, 0.03249839061338987, 0.06364575015114886, 0.040222327757094584, 0.02944101020693779, 0.050018826366535256, 0.07830994363342013, 0.057797640029873164, 0.043263867763536315, 0.06301270412015063, 0.0474780248478055, 0.02978817925655416, 0.006881231425463089, 0.019640557434675947, 0.06204541173896619, 0.052083859486239295, 0.04745041525789669, 0.03817727070833955, 0.06300096546432801, 0.028315464799691523, 0.02491608408412763, 0.031995484206293306, 0.0284249192835497, 0.03155037201941013, 0.012924369474473809, 0.05007710913196206, 0.055586742237210274, 0.07897201739251614, 0.03231808689555951, 0.03809391607397369, 0.061435693741909096, 0.05783320205020053, 0.036825951255325756, 0.017773264686443975, 0.011754540327404226, 0.015505247815911258, 0.049738588011158366, 0.02089719071851245, 0.04143277316221169, 0.008475231472402811, 0.025076442265084813, 0.04155168303155473, 0.029345275701156685, 0.01900488886583064, 0.02140629554300436, 0.026988852503044263, 0.02575993398204446, 0.03639460654397096, 0.062459745577403476, 0.0768927214667201, 0.0152342307514378, 0.022423814782606702, 0.015664231963455677, 0.010983309791689473, 0.055117820256522725, 0.06544145236590079, 0.035938688686915805, 0.0260988825799099, 0.04707760097725051, 0.011074978176371326, 0.07705600413360766, 0.057853877012218745, 0.04196947739858713, 0.025629543300185884, 0.024817820339064513, 0.023955214036894695, 0.04883523737745626, 0.04866206166999681, 0.07160815503448248, 0.028071831712233167, 0.03148844212825809, 0.0838292356846588, 0.039478181794817956, 0.022296530094795992, 0.06453362679375069, 0.035614145387496264, 0.02411699035604085, 0.02396400785073638, 0.0006632588099039692, 0.045303350647113154, 0.027006190769108276, 0.02560829327973936, 0.03911984066611954, 0.015438798881535019, 0.02386906892726464, 0.040479428068335564, 0.01764928107149899, 0.028921958059072495, 0.02119605316381369, 0.04293777061892407, 0.020708339155784676, 0.061896005113209994, 0.03888392421816077, 0.025433409360370467, 0.03907863323443702, 0.04902723564633301, 0.07278581362749849, 0.019606483102376972, 0.030235527216323783, 0.07715369960559265, 0.03133410594559141, 0.04019040946981736, 0.04742143163457513, 0.03974326167787824, 0.0386915765037494, 0.049387144190924506, 0.014348272666601198, 0.03145406415153827, 0.037189452642841, 0.020777449643771564, 0.06160851661115885, 0.05621083499863744, 0.011278677781644677, 0.027767322159239223, 0.003061784098723105, 0.12977359497121402, 0.0704420315367835, 0.02220859026004161, 0.0418904212835644, 0.023707019497773478, 0.022974568086543252, 0.008176906766103846, 0.013277519810279565, 0.03138326580769249, 0.07649261650762387, 0.02667865852293159, 0.056229345433946164, 0.03931169304996729, 0.0742713235584753, 0.03314314476613488, 0.020802209386602044, 0.028141071121873598, 0.05349376704543829, 0.010665348281950822, 0.08640918867396456, 0.020516308656494533, 0.03458389513460653, 0.022984647724245275, 0.019712108952392424, 0.018728333259267465, 0.11701108408825737, 0.041688726749271154, 0.00920660316478461, 0.06023696663656405, 0.06907069190804448, 0.0346219643418278, 0.07381488662213087, 0.01450179799992059, 0.06178085093519517, 0.07223616633564234, 0.059820624334471564, 0.02550428403940584, 0.008373328235133417, 0.03974961955100298, 0.13384880843971456, 0.1455553966973509, 0.16429749743214675, 0.13258819894066878, 0.2514559312590531, 0.26851416592087063, 0.09493459441832133, 0.07481218382183995, 0.11774928947644574, 0.14084199390241078, 0.14100256242922374, 0.17297700526458876, 0.13087667578033038, 0.09393273746328694, 0.1476611215621233, 0.06698452242250953, 0.13573250307568482, 0.1346985785556691, 0.13230105649147714, 0.13711120480937616, 0.10341625501002584, 0.19155658329171793, 0.0916416368314198, 0.11807053509567465, 0.0766911083566291, 0.11084450355597905, 0.08452744821884803, 0.15562567061611585, 0.2011808425720249, 0.1893344625298466, 0.09797911997884512, 0.18779079536242144, 0.08939696835087878, 0.17137145570346288, 0.0885009832148041, 0.10033168909805161, 0.1077096921258739, 0.08409971331379243, 0.21657107530960015, 0.07897571540836777, 0.14764884007828577, 0.08001854230782815, 0.0688177544091429, 0.1481443334903036, 0.13545844278165273, 0.1004179919670735, 0.16425256484321185, 0.18211870401033334, 0.1846385116555861, 0.14237675869039126, 0.09259473426001412, 0.10316288324871234, 0.15463977280472005, 0.1811468790152243, 0.1388605223702533, 0.06794599975858416, 0.1517221536487341, 0.09155488612928561, 0.13501818212015287, 0.09957182487206799, 0.09717931718166385, 0.043771350889333656, 0.10238626599311829, 0.08776724258703844, 0.12941498921385833, 0.13586340605148248, 0.04991435572238905, 0.08550557680428028, 0.13568507347788128, 0.0904180414176413, 0.1608115644859416, 0.1346538902393409, 0.18496069365314075, 0.15473588050476142, 0.05993877763726881, 0.14757158208106244, 0.15166559096957954, 0.19658767618238926, 0.17411508490996702, 0.13543867027120932, 0.1964408547750541, 0.15337541779237135, 0.12113086373678275, 0.11006954871118069, 0.09320350230804511, 0.11033660652382032, 0.11161170953086444, 0.11618342064321041, 0.1159827099846942, 0.11783720047346183, 0.11055858925517116, 0.08311655678387199, 0.07946606552494423, 0.1777035580681903, 0.15630311997873442, 0.13206008156495436, 0.095902076789311, 0.09794287263814892, 0.17053383136434214, 0.06463650627327816, 0.12404988067490713, 0.16038916286613258, 0.1559214847428458, 0.1998347919434309, 0.15531102035726818, 0.18126193141298635, 0.1297020638095481, 0.10196899409805026, 0.15292261780372687, 0.17046637141278811, 0.1137595714202949, 0.11090817728212901, 0.07517091850084917, 0.07724684889295272, 0.13743147333817823, 0.09786450862884521, 0.14031511146043027, 0.16851447043674334, 0.21016379126480647, 0.14293010399809905, 0.0960981191268989, 0.20777785857873304, 0.11080307220774037, 0.11025440200631108, 0.16204341767089708, 0.16988308914005756, 0.15372835099697113, 0.13244254461356572, 0.19788369163870811, 0.077124712589596, 0.1359584688075951, 0.08354502450674772, 0.3083475370492254, 0.12046652367072445, 0.23733637748020037, 0.11981652783496038, 0.1822136446301426, 0.16070378598357948, 0.2461039727287633, 0.13357261754572392, 0.09540144008185182, 0.1316474779908146, 0.16230474864797934, 0.11795732831316334, 0.09438588350479092, 0.14351694179432734, 0.25521707800882204, 0.13887133821845055, 0.173955642751285, 0.12723695965749876, 0.18076921999454498, 0.1332249226314681, 0.17819105833768845, 0.07548043903495584, 0.13483052647539548, 0.08248496960316386, 0.14991446850555284, 0.10701728106609412, 0.11185059456952981, 0.16635183005460671, 0.11300247561718736, 0.16568717786243983, 0.158376722995724, 0.10744754012141909, 0.09077931381762028, 0.11737752013972827, 0.13191079029015132, 0.15749160120529787, 0.15029805792229517, 0.10213751505528178, 0.1439466037388359, 0.16188419264342102, 0.1803830928568329, 0.13278557120689324, 0.0703240003702896, 0.1404026967606374], [0.07058408284293753, 0.025232294973518168, 0.017446709530694143, 0.0429281150656087, 0.024290249184040085, 0.030270980671048164, 0.025100587933723415, 0.033473099382328134, 0.03721900623557823, 0.029823137380714928, 0.016541421679513793, 0.011676021103215004, 0.06344774006200687, 0.037707605731806586, 0.018362828497109667, 0.036678030621260405, 0.06733168129410062, 0.028722791067723717, 0.047647132737828155, 0.04782277152740529, 0.02054061208452497, 0.01610737300610968, 0.12451017169015748, 0.04729964477675302, 0.0317929686446275, 0.01568351423234812, 0.017470804309206348, 0.012070717290043831, 0.07790114664073501, 0.00233459027367644, 0.07884703124208109, 0.0181124745202916, 0.07460414498512234, 0.0050287010547305855, 0.02471120043524674, 0.03800989308261445, 0.03481543503169503, 0.03423142672649451, 0.04912313978586878, 0.07465713178472859, 0.04813824959897569, 0.03280964819714427, 0.024828515747295957, 0.019308093935251236, 0.013654164421106023, 0.007898594602011144, 0.04914264427497983, 0.03512343904003501, 0.035379185673913786, 0.004781635428246642, 0.05070822812350733, 0.07809376237647873, 0.02801414775396032, 0.012919188859606428, 0.03984936759141939, 0.025691958343876258, 0.03339247585141233, 0.031945252258862765, 0.03849531024960535, 0.024267453800088594, 0.01630703702435962, 0.03746861552021333, 0.020975110287378942, 0.050482326852423806, 0.03395167691633105, 0.02206716999145491, 0.04223478798355375, 0.015604899165087512, 0.047049835324287415, 0.04722610854410699, 0.012537244042115552, 0.04542544623836875, 0.05465417727828026, 0.02942716469988227, 0.011449936627676445, 0.0334989210324628, 0.013895342908134418, 0.0826448460242578, 0.016843664925545454, 0.018069904929559146, 0.04473470437473484, 0.04695317801088095, 0.044671933100159676, 0.039922018335866075, 0.06451342002089534, 0.007300217469621981, 0.03224948361249907, 0.022269480296277573, 0.03306126594543457, 0.038994552567601204, 0.05095215807003634, 0.03720194786520941, 0.018146212977756346, 0.032533603188182623, 0.025343450883935605, 0.04292051547339984, 0.04829615826851555, 0.028795723404203142, 0.02423316572925874, 0.03386205601106797, 0.02107555212985192, 0.08340658979224307, 0.016103739451084818, 0.027881299078996693, 0.006735796774072307, 0.0372091301583818, 0.07478557846375875, 0.03511507609593017, 0.05605094839951821, 0.07377144681023699, 0.015762353216164877, 0.021492796883519207, 0.013968933423581933, 0.02937731273206217, 0.07947479827063424, 0.042067888725016794, 0.04860203506957207, 0.02090467495976814, 0.012147832794913223, 0.029018096293189695, 0.06465548489774976, 0.04061980000031846, 0.019048829097300768, 0.04956118163785764, 0.06480580076043095, 0.049432304089090655, 0.041755474239055596, 0.03827929184106844, 0.012847019026854208, 0.09854104196918861, 0.02492875572560089, 0.04274348568703447, 0.08403016347438097, 0.03585487264873726, 0.002354087553352916, 0.02062377503274807, 0.02590987495412784, 0.004915818696775074, 0.012178391467646828, 0.010487820620515516, 0.054683954787573645, 0.03459860238113573, 0.07086878935141222, 0.01565890715989683, 0.07131592357265097, 0.04131319832855037, 0.04906384939593928, 0.05348513947267618, 0.04574999293046338, 0.04671687479796154, 0.026759012336177484, 0.057043835121606074, 0.005851903132029942, 0.022613821551203728, 0.017019972072115967, 0.024613106323938285, 0.0027352225817074733, 0.052079052065632174, 0.07154361278350864, 0.060331215150654316, 0.0020325544049098554, 0.055386981527720175, 0.026024540586929237, 0.016466563999918953, 0.012747737479263117, 0.03801316362140434, 0.054690390692225525, 0.04213760480550783, 0.06019875154431377, 0.01505671750887164, 0.030708038647259985, 0.007605374175389963, 0.02648188845653619, 0.037111112382262945, 0.05435406123953206, 0.027180837201220647, 0.012978021238398339, 0.04300434508227876, 0.02862764349473374, 0.019824467566130415, 0.01677647978067398, 0.0407694339353059, 0.016637000122240612, 0.05628297684182014, 0.020279021567798088, 0.04539299190842679, 0.03349657669397337, 0.049141209173415384, 0.060715483102415285, 0.042789778738681755, 0.033921095343040567, 0.05196178085835917, 0.02598824574878173, 0.15444123345826352, 0.07140453346073627, 0.03899787399651749, 0.0476738161274365, 0.03666247859863298, 0.06955442630818912, 0.030895198961453776, 0.02396932417260749, 0.015415355496640717, 0.0640217535463827, 0.022157347295433283, 0.05632671181644712, 0.043908621916281323, 0.036676493739443164, 0.06626627274921962, 0.026455657989052788, 0.039372425326811414, 0.03358156320505908, 0.02220850544316428, 0.022067848526473557, 0.017908975082848753, 0.04088049654715827, 0.031160580792597363, 0.05002579492117677, 0.03630364213937095, 0.0021398204012906975, 0.006064855834535722, 0.04335324100351759, 0.010556909904283072, 0.010236094306622232, 0.012598436026434814, 0.018708082381635904, 0.011067907841477011, 0.02058842675095158, 0.04009627291400518, 0.00800771830004773, 0.07945894090724842, 0.031087719702294896, 0.028805531627897705, 0.02954059200627463, 0.03800211028595056, 0.028810223697551658, 0.00753208645619452, 0.014447791701448815, 0.004957550296759499, 0.03668228503582733, 0.029853338974394968, 0.03345637349411845, 0.03342780716983335, 0.04404460033401847, 0.0257321004755795, 0.047640625586999316, 0.023493988339656165, 0.01510283414141408, 0.03656972964693393, 0.05441567561190043, 0.02936785395390221, 0.012225568311155906, 0.058332495258322785, 0.03426962146269424, 0.035132694257689376, 0.03586886404082179, 0.043202921748161316, 0.011758083128370345, 0.0421202987698572, 0.09460476533110652, 0.039356079418212175, 0.10632476144071136, 0.027643075611974512, 0.03040773601138166, 0.03582405698086534, 0.032483004831842015, 0.0523627373789038, 0.01860857182847602, 0.004641526852667863, 0.020670748315751553, 0.011245521167958421, 0.052383483587098975, 0.07555584463157825, 0.0664453109992402, 0.032800379408789535, 0.07013803427772862, 0.042937478848866055, 0.01890323923102447, 0.0569686195147889, 0.04565547978771584, 0.043975898663380315, 0.059078307024070194, 0.01764843120638813, 0.01280654950200447, 0.058468107267149856, 0.07321974355727434, 0.04236161635656442, 0.04583991239113467, 0.0275724469018834, 0.00439038111029991, 0.005336273769249341, 0.03286728296162827, 0.012334906595892139, 0.08686513706509556, 0.04397358146629163, 0.0212373403233609, 0.028665122376488786, 0.08038632864398615, 0.06960193054484469, 0.02021279146096536, 0.009057325460681958, 0.053208595740475824, 0.04873801687998431, 0.03502401330375245, 0.031525303543146165, 0.048385015821882656, 0.048772557705108605, 0.04313283247341003, 0.01403431620981012, 0.04027261398732662, 0.03309876179056508, 0.006928194954525679, 0.04249891113223774, 0.021818334236741066, 0.013061604030164225, 0.01237427010866148, 0.009502120432443917, 0.027747732853250842, 0.031803937163203955, 0.032442913590265174, 0.05476634929488812, 0.035048060584813356, 0.034055977926722596, 0.01145265416042613, 0.03126399292211447, 0.020959792359332954, 0.09095462012503829, 0.016485958227089474, 0.05519460327923298, 0.037403622043452094, 0.02560012711078993, 0.03760725718789867, 0.02291833788954786, 0.06062858312257698, 0.05663528579420277, 0.014886944654530712, 0.04116146432768021, 0.029220374367598976, 0.036141404416412115, 0.08807087343718324, 0.039897530007043054, 0.060952359677425454, 0.030019532556512525, 0.04459862078406981, 0.033270030814622126, 0.024350477648632865, 0.05304540467581578, 0.014560469226645572, 0.050634844561240504, 0.046885846980980465, 0.04358732879960111, 0.03755287939150419, 0.031872615085116456, 0.1325364267187459, 0.07905414048582315, 0.15254510806075164, 0.15390866489282676, 0.0962741853935378, 0.1138504408299923, 0.1321667336991855, 0.1713342855551413, 0.2152320814452001, 0.10346084833145142, 0.1235458105802536, 0.06595610760684524, 0.15844129238809856, 0.15462183233882698, 0.11795259213873319, 0.14624119204069885, 0.18818160439176218, 0.3633900263479778, 0.1390349194407463, 0.13176141759114607, 0.20387887422527584, 0.10396717116236687, 0.15173694571214064, 0.16079161555639335, 0.1499678013580186, 0.12454249709844589, 0.09062021771179778, 0.06943830861044781, 0.16205516989742005, 0.13668357846992357, 0.12461225049836294, 0.12004779971071652, 0.19112807485674108, 0.09313670732080936, 0.18899311870336533, 0.12530678537275108, 0.18178684610341275, 0.13435424917510577, 0.12233244068920612, 0.17188566311129502, 0.13131380161004408, 0.10162866807409696, 0.09199779307735817, 0.11730991091047015, 0.10565905073391539, 0.06865276183400836, 0.12576099671423435, 0.1315305121243, 0.1317695871527706, 0.1379746270499059, 0.08164283300616912, 0.11368558396186147, 0.11587965408606188, 0.16700258584959166, 0.14812545664608479, 0.14869363472930022, 0.13042615566934856, 0.08256272971630096, 0.13558716087469033, 0.05939896910318306, 0.12669836570109638, 0.1484082836125578, 0.09841672078307186, 0.07918073476425239, 0.12860666401684284, 0.1674758368836982, 0.1134791328970875, 0.13057179642575129, 0.19473733832793577, 0.28166485311729567, 0.0741038882572736, 0.10537792010498898, 0.13975552363055094, 0.1990190435733114, 0.08255548974765198, 0.07978243926273924, 0.09473742571260248, 0.1445079693304641, 0.13245673956615583, 0.15341923758387566, 0.27120320019977434, 0.30164803511330057, 0.14168716355093888, 0.11230796788419996, 0.17788999234991415, 0.07183289940335921, 0.13052733881132944, 0.09802457503974438, 0.13557215168007783, 0.11061629865850721, 0.15997205381946905, 0.11071689147502184, 0.08584170948181834, 0.0936638204646962, 0.1138237744037594, 0.08897170331329107, 0.15654357921864304, 0.09623297117650509, 0.1240245984601123, 0.14024484237389906, 0.08559333173824207, 0.11254568584263325, 0.08862310594746045, 0.13779888648007596, 0.07932287427995886, 0.10050862388951437, 0.12982744351029396, 0.16971653593438013, 0.17156373895704746, 0.2727350065750735, 0.11329630163631269, 0.16320524604192801, 0.09679532742926053, 0.05244136601686478, 0.13255531713366508, 0.07301684801599809, 0.1364623082003423, 0.09373254249138491, 0.11161646606134516, 0.15851709832038197, 0.14481892835881027, 0.15391763512577328, 0.1770176813006401, 0.11190035154244729, 0.12266154374395098, 0.20765735075942107, 0.1749865681465183, 0.09673312612410102, 0.13443761398749693, 0.20466487562017782, 0.13819082187754766, 0.07765904534608126, 0.09570249249892575, 0.12833079881966114, 0.11443290886070047, 0.12243823786931378, 0.06833271043641226, 0.07295630912163428, 0.1431401241570711, 0.0871871697849461, 0.1705705536795514, 0.07978138074811016, 0.11106694769114256, 0.153847691736051, 0.1540438969220434, 0.08408800858472075, 0.13604656979441643, 0.136951138398477, 0.1241145586328847, 0.1436097789555788, 0.09536393745137112, 0.17572322647486413, 0.08911688945123128, 0.128504571637937, 0.14736739732325077, 0.10109143797308207, 0.1574968530663422, 0.1690562263663326, 0.1574755742081574, 0.18509702490908758, 0.06584142840334348, 0.15663153092776025, 0.18459956374551567, 0.10739508936447756, 0.14721163282436983, 0.07712974053408418, 0.13979729424629891, 0.10310061409005097, 0.10746559593826532, 0.15449859680874006, 0.06504088600299188, 0.10546127813202993, 0.09974091579871518, 0.1409645373267787, 0.10917133119489465, 0.08213965634682349], [0.04502422848184194, 0.06826831746314253, 0.03773011273837515, 0.049479553875114234, 0.04440476672191705, 0.012578545620531907, 0.04739065667880433, 0.020216031465679407, 0.030133326271814958, 0.024625681274171387, 0.04904173254700644, 0.017605946432533007, 0.1245576555707625, 0.00810115087577807, 0.05023240204900503, 0.02248968187320445, 0.05936353600450924, 0.013880198854686958, 0.0699987785358514, 0.02242247637228242, 0.037729308674378056, 0.032231685638959916, 0.038484412977205854, 0.06157623870032174, 0.008367201912083795, 0.06323309907955782, 0.03004286059045366, 0.00748562122628625, 0.06130745740873473, 0.01612990545774145, 0.08164506538638047, 0.03887842808450971, 0.05400979292712041, 0.02980554975303156, 0.026115164027682373, 0.031670252193829844, 0.061810068653098175, 0.02703802254317062, 0.05437059374526143, 0.06999002543411084, 0.018499624549544284, 0.031086284600730454, 0.01487313985957631, 0.01998104969970882, 0.024286013429186175, 0.03641188543822084, 0.04514715188582029, 0.00959295337088406, 0.03970609831490687, 0.05575553121577416, 0.043220448307693005, 0.013785958822284426, 0.027165319105344157, 0.03485709708184004, 0.0030259116486247096, 0.01903662734132792, 0.020630098979121873, 0.08892550864922148, 0.044769136634256156, 0.04251355731061526, 0.04098308425662773, 0.05590180979509439, 0.10065615775861911, 0.04180693433486989, 0.03005290630140475, 0.0066659954526195565, 0.027961618965491652, 0.05655522205467735, 0.026828328081007515, 0.015475885909316795, 0.07841945918542997, 0.12762217755828584, 0.0675898842247469, 0.025592191643746834, 0.017777451247509037, 0.01000863834217723, 0.026804470789751837, 0.010495869742174233, 0.03670301088797195, 0.020707706421879784, 0.016148236081270233, 0.045302957096802335, 0.04608412392969642, 0.032761560420372655, 0.031966524331697395, 0.04524727651317205, 0.036711573999907286, 0.08567580088440861, 0.04840870008670858, 0.036647988483309746, 0.0025545645413720714, 0.05082056977386985, 0.04128209767597062, 0.015113449821780835, 0.01782509628018098, 0.03056116634979844, 0.023996010954890932, 0.031073321189199175, 0.05512334692424961, 0.01795898820273578, 0.05853136030158826, 0.0319317324486162, 0.07890036409454686, 0.06211224743830306, 0.023262161761522293, 0.011088620971090027, 0.07615792232432536, 0.043414108987365446, 0.03319544963804739, 0.019080484452258264, 0.027898759481364062, 0.033835002819874456, 0.03155131518308606, 0.052652047747480016, 0.04439710606155651, 0.02856999515954937, 0.08484225454074995, 0.03321665385738015, 0.020274507613586526, 0.007003011073850627, 0.028784758278301785, 0.014509244921750255, 0.02154719164328916, 0.055874943201031, 0.024032276955300143, 0.01843956232603107, 0.02142501462783132, 0.01847222869816635, 0.01946786348707974, 0.0771947441888707, 0.01489504296997828, 0.04553058523950832, 0.03360891155898571, 0.05080047835196767, 0.01871389912308327, 0.03613822887252484, 0.03833363571071199, 0.018486233660951257, 0.03687667853331991, 0.036989841211055, 0.02562242716417781, 0.08914774243852921, 0.060018308726804595, 0.021388185443356633, 0.037971657634313614, 0.08511068299412727, 0.038223051466047764, 0.029885616885232072, 0.015117259795910545, 0.009524834392193173, 0.06841568848384277, 0.0549670701314296, 0.0526836335525981, 0.013449940647530769, 0.03564216549109135, 0.03684641926416329, 0.01619729246678097, 0.002059183087632326, 0.09986894178603377, 0.006760870339348912, 0.02681456908716687, 0.023748281212257485, 0.03930892801976629, 0.060263198800385, 0.02724362035015864, 0.013381737700131322, 0.10040242637374572, 0.019370073020192127, 0.015947272668459585, 0.074933241254517, 0.050407155350382836, 0.029627156111278703, 0.0254752614003207, 0.018130515070099915, 0.05929528895233359, 0.05349050329199859, 0.05298261643786516, 0.05867268557527235, 0.08892748318612576, 0.07741176682923522, 0.02152836399285921, 0.04831554062132325, 0.04828023644430297, 0.0545041464003069, 0.01413723809777626, 0.0772140213687505, 0.06564600353262254, 0.014943230830665146, 0.07372915372252464, 0.06686090691281216, 0.03539104985871485, 0.01603608950972557, 0.062468946512256346, 0.013677772350742348, 0.027212014188989997, 0.044398894001330645, 0.01034773452140923, 0.045494371825563054, 0.05562695900776556, 0.011926431907340884, 0.04178670720596399, 0.04675241306956325, 0.03107538732833096, 0.031218643034143106, 0.12393281981348991, 0.0274614962483091, 0.02134072022246463, 0.022557269050074474, 0.06539373099803925, 0.025253433035686612, 0.04299473024106451, 0.035695935998644145, 0.010102890248942589, 0.05130874518571155, 0.01846036620970283, 0.032756376412830183, 0.07632428554019757, 0.005914804176427424, 0.0036403488567365067, 0.020631732552179267, 0.07798153268439428, 0.026531482581049204, 0.025996903855619685, 0.04970996740407177, 0.012632903060875833, 0.04506617212401969, 0.030449296281273876, 0.0374974464731557, 0.05457567756197282, 0.01030111831745931, 0.01263559005954968, 0.031878246925771236, 0.035946098289319446, 0.02280850342607924, 0.03120671438851527, 0.03157254993649466, 0.05616409072120275, 0.040949530699955564, 0.016361776140651534, 0.049187186706279, 0.029917077161371708, 0.05176670204049774, 0.03355140232348016, 0.07073983377111809, 0.024630897512127246, 0.03618340573406645, 0.07866211009344884, 0.056064854974725416, 0.03432028427986162, 0.011501095623576214, 0.046821454007710726, 0.017507138163117424, 0.005980301041355622, 0.03138343883412225, 0.049039534093546014, 0.047828294802457094, 0.05961913336068392, 0.00647411126244281, 0.03935982153884002, 0.04285025656489389, 0.05333975995225566, 0.027967362764424512, 0.025060746053765928, 0.013452907541899808, 0.009620804688893259, 0.049984614630895, 0.04379530996084213, 0.04806114427213158, 0.10686543171427079, 0.01019418374302664, 0.058561324408011775, 0.02698632326376225, 0.03055903914251498, 0.04365243423464043, 0.017975790426135063, 0.003252323093225381, 0.04778147249349526, 0.015510350399251496, 0.019198686948844364, 0.022847463210512484, 0.039721684264285226, 0.01714086496005101, 0.05744224374315568, 0.042397256408418925, 0.012757561818164374, 0.016577165207958648, 0.04678178685052054, 0.08004282707614557, 0.014450945192947984, 0.024456999164872935, 0.017577400464298468, 0.04184843014393534, 0.04761423057477389, 0.04814059393746512, 0.07276646180876664, 0.018726854052926813, 0.02657602840502347, 0.04364488892523306, 0.020318751489477496, 0.03102570160159043, 0.05159455092091646, 0.019322969119197557, 0.011802783319061356, 0.030281830445996354, 0.01828147723738636, 0.016519857836621146, 0.033486402061368735, 0.04654210453320827, 0.031537208440048356, 0.019796194708240882, 0.04781724146700331, 0.010754443322574454, 0.008308214318406369, 0.029163981322199106, 0.052066370246133635, 0.037904238394860706, 0.011261708468997052, 0.04555128734292729, 0.0072243674325623685, 0.04507487772830895, 0.01469266481165375, 0.06385283903884036, 0.022850314753928354, 0.024297319518934404, 0.04304022940673998, 0.06010456409837518, 0.055275243773524246, 0.02116563274259014, 0.09292502475104161, 0.08495927469006606, 0.0068787505318011555, 0.021459628395470123, 0.07787669223866292, 0.022090491240045855, 0.046301648685974736, 0.02768937375263444, 0.060497639434678216, 0.019911589766187326, 0.026092943702159182, 0.04990660685247608, 0.012945091085774558, 0.08062834172908749, 0.0338457745632955, 0.03197045983480556, 0.01871040975674987, 0.06925764866173267, 0.029421739812408174, 0.028120404641543115, 0.0239671342008348, 0.04379864496045879, 0.08566158557576792, 0.025218474911525846, 0.1284178820039545, 0.20209710911980697, 0.1171223231192146, 0.15509561263024807, 0.13088982578899178, 0.15568622308118002, 0.1600197684019804, 0.11116275683577571, 0.1253515144011804, 0.1417719939989703, 0.2018123415431806, 0.10509750872318234, 0.18619622449789727, 0.07329409063926765, 0.13907333809350217, 0.12207562875534807, 0.16990694643131324, 0.07114789794598307, 0.12078966918800559, 0.1029344272932836, 0.10131838079541922, 0.16807739888983114, 0.1294449261788811, 0.15101697934525354, 0.11722445621022157, 0.1346250253596476, 0.08884254417249135, 0.057650995041642866, 0.2562368075762476, 0.07538099972797291, 0.11789292176919323, 0.10051804195557322, 0.0923921779862472, 0.1420920453965664, 0.1928654909133911, 0.08415518355156694, 0.12856357704315866, 0.13102766339268002, 0.10836871926273618, 0.12717410017337116, 0.14559685518699034, 0.0924434820190072, 0.07090746584747519, 0.09211745951324701, 0.14168887345918588, 0.09364849914397512, 0.14834294069026197, 0.16768179940325872, 0.08897373213299684, 0.10952070209064654, 0.2963334231504372, 0.11584009549447469, 0.1860497152166707, 0.10842862033418246, 0.07359572659645762, 0.09999326975750071, 0.11154344890798841, 0.1634036089692797, 0.11092549349580492, 0.14224162165607723, 0.1597758893455778, 0.17191660430814537, 0.13036618674440043, 0.12241777325315134, 0.10756475026054041, 0.18305426809404576, 0.08181565587541886, 0.14154013858309814, 0.16064697903181824, 0.09250212780066899, 0.1452036848557847, 0.21270347998610564, 0.16391956699745996, 0.0872405365641628, 0.1363059873027461, 0.11880210441138063, 0.12437314832849161, 0.07925589608826808, 0.10660340184611933, 0.15667938121727534, 0.15617206772523268, 0.1543474192065852, 0.10537661731775318, 0.1234586595424584, 0.13979437654571875, 0.13578830579561846, 0.13619440900427954, 0.25091877579689026, 0.2262768537870475, 0.10428405380142586, 0.08934611215123109, 0.15399151401860373, 0.15019108009125504, 0.14101195335388184, 0.15656941783215317, 0.10736073513648339, 0.10229567478277854, 0.10525654376085315, 0.0945495054391878, 0.15795437565871648, 0.18043145883296216, 0.09725149973694767, 0.12910096320722783, 0.1358367939080511, 0.06207714682178838, 0.13308167031833104, 0.18387425052268164, 0.13846798986196518, 0.0702013008828674, 0.14160253666341305, 0.10034147357302052, 0.17277153129024164, 0.10764059690492493, 0.11387596731739384, 0.09443474481148378, 0.12072957812675408, 0.2229613416961261, 0.1442213018557855, 0.07598598155059985, 0.08895570345755134, 0.21765142519559177, 0.09470382465847901, 0.06988223336104836, 0.17025473634047167, 0.15492000776742185, 0.09307983251554625, 0.08177493020359959, 0.10498137745474066, 0.16072020653103078, 0.11677746448133673, 0.10931155724184853, 0.15652580160115445, 0.13376875487821444, 0.13491039004709038, 0.13218196002500399, 0.09974802684571062, 0.08659596900854792, 0.11936940039907183, 0.15346039751810686, 0.12537693232297897, 0.10391063562461308, 0.21869798403765472, 0.10547801759094, 0.09633068700454064, 0.1532816442527941, 0.24713366319026264, 0.08605511553053345, 0.1361411711467164, 0.08855146622019154, 0.09479201385485274, 0.09494422283023596, 0.15623255233679498, 0.23542735991733416, 0.13985268984522137, 0.1293148917279073, 0.12124419265559741, 0.15039218430008205, 0.07657364715955087, 0.12213832539107118, 0.11241740201200758, 0.13109173066914082, 0.0670992084113615, 0.1132248044013977, 0.1309738555657012, 0.08275605112846408, 0.07869533795331206, 0.18742929904588632, 0.0730542895783271, 0.08950356620230845, 0.19823077587144716, 0.11562221789998667, 0.08964031814996685, 0.0749718973945294, 0.09498380177787372, 0.16249290640865052, 0.09303578880748578], [0.03260680015331932, 0.007189745183235833, 0.009131545317359269, 0.03615528724289366, 0.04525746810915215, 0.04258111904242209, 0.02842244941608182, 0.06031167334211724, 0.0034450342479561058, 0.00535504035152761, 0.01925196891118373, 0.04661537952987211, 0.022678109351545572, 0.06372171893183674, 0.011354815347918441, 0.05175897352663534, 0.02849755815363356, 0.018617850794856037, 0.029090621508657932, 0.04115698938923223, 0.01414356119598129, 0.020280188648030162, 0.07866597095770494, 0.08286380927477564, 0.01267544211753245, 0.02819603924373431, 0.04253107708479677, 0.007120823836885393, 0.020214888134172986, 0.014397678497646536, 0.02165376065698053, 0.0014380013474562603, 0.019053670444658825, 0.025808766450999037, 0.04225998877414635, 0.038918264875454564, 0.04753136109294636, 0.1046847083738872, 0.014671923692471214, 0.007572465226985514, 0.041093770281544754, 0.07980939067367997, 0.02607785986869463, 0.07009254529007844, 0.025687502065141286, 0.118651008233428, 0.060780961731714864, 0.0157235596728112, 0.016283973619075756, 0.0516102420432227, 0.0251607400631266, 0.06239772069134882, 0.01762891823558935, 0.05996450089982577, 0.012291376029939523, 0.01116492138576827, 0.0165137323617403, 0.038110896412815363, 0.043633452217493734, 0.03994361949818475, 0.06932117989552872, 0.04597119873921786, 0.012317219732462295, 0.036050840347473107, 0.038411141373217106, 0.07566483771162373, 0.015373835938849618, 0.08256824620600257, 0.0944401595209326, 0.03585743751110775, 0.09518044801162821, 0.010007815618467118, 0.038643210527620146, 0.03082325050075139, 0.03760338953829237, 0.05050094246066042, 0.03840792850990381, 0.026677321808944856, 0.043363205290266445, 0.03448818098487599, 0.026310441317036748, 0.015058390097692609, 0.02103718606355999, 0.04422379803976842, 0.04434972735387938, 0.002366849312758339, 0.04074886753889067, 0.030908379504191022, 0.045663530605712106, 0.043615050347787995, 0.05170811732698764, 0.05609074787103704, 0.06889419137899365, 0.011008015251718462, 0.04577067128515669, 0.08995319743241582, 0.014773469850687044, 0.04890009853988886, 0.025826031774548546, 0.029172093208347048, 0.033691889606416225, 0.06083825044333935, 0.024120830864246403, 0.02651349122502974, 0.03088669691767011, 0.03165640329409923, 0.07950947141008717, 0.03883747510345919, 0.026181835182277218, 0.01826014748907515, 0.03741150662036879, 0.007667678957139807, 0.04267357961673822, 0.026498217401759963, 0.06922563537955284, 0.014571756656680788, 0.06295605323144368, 0.01116314871303205, 0.011985368610891913, 0.029328196974737302, 0.04520252373601709, 0.018337005150637457, 0.03232116065919399, 0.04223632486537099, 0.03224089335916298, 0.044020851608365774, 0.02047556602129979, 0.03777479426935315, 0.03951136215722986, 0.06504628035639014, 0.07974566945007869, 0.01945683390035161, 0.06122872020517077, 0.025821500856961523, 0.014841816986777952, 0.02707924015287842, 0.03651264788849013, 0.020181975793093443, 0.02433628778505538, 0.05274325642468674, 0.02085102828485625, 0.020665516810757772, 0.05866783404988902, 0.027240368471081768, 0.06124071670430047, 0.02315739934731807, 0.048299388095204315, 0.03904842485540679, 0.02809709357097745, 0.021591572922521403, 0.012626680046586054, 0.021273991392393197, 0.048294339794665575, 0.016598491563594768, 0.028065657043563466, 0.10204577033541032, 0.05064816420365657, 0.0535696679726243, 0.03157957616661276, 0.010805972968228161, 0.005640076797655118, 0.03540626261383295, 0.09327403602323361, 0.022149238801960434, 0.05836490887616362, 0.028968369854348044, 0.08338634909263679, 0.022333956390087093, 0.04384564368852547, 0.04579860996454954, 0.035048111474939754, 0.055422173746462376, 0.07367068435996771, 0.044119439353900294, 0.04420592203470213, 0.03365431912243366, 0.0503820733034185, 0.02728416451386043, 0.02001010626554489, 0.013226319254109902, 0.04064499061288578, 0.02787204216500478, 0.024556287497814213, 0.03805443212123854, 0.027506612041699033, 0.007441552073162581, 0.015920786054006646, 0.02398443005846015, 0.0340497523679265, 0.024363707385158966, 0.014497818392036217, 0.05318813790966358, 0.06552016921341419, 0.023896968590893915, 0.05034187349623867, 0.02145874290727079, 0.029702252974467616, 0.03664501989260316, 0.019462006033531258, 0.04270684479602745, 0.012561046202400965, 0.05226511315309575, 0.07669742551765271, 0.006394981356736804, 0.0275329358077475, 0.01594737614504993, 0.05871067675096648, 0.0209439553519977, 0.0376375639545066, 0.05589426787836211, 0.02345907432027161, 0.04202578223443457, 0.09397692366370133, 0.041813210783792396, 0.012063772484127964, 0.013699245439576251, 0.004749814256293965, 0.03373296133109501, 0.04008995236030646, 0.06149393918790987, 0.021134426917082498, 0.0472173181229404, 0.03169722735349621, 0.048053293621965816, 0.03506163128518632, 0.05404379431690488, 0.028397606552711556, 0.09459775606436388, 0.01846862058820469, 0.050215360642011674, 0.05998991203627416, 0.040799499821982214, 0.02014427469111979, 0.029648472288889543, 0.03789839281567505, 0.03705098739426051, 0.01906157028861344, 0.029634565713682344, 0.025796398453946625, 0.07870552276394197, 0.02295540625761662, 0.0044261806178838015, 0.03638642341164606, 0.031556790960686545, 0.08699545650077717, 0.04494514522541847, 0.05097844112398369, 0.043302666395902634, 0.03630841563322714, 0.046216428080307584, 0.020153689364503537, 0.061553399211594036, 0.031879251157598834, 0.042745405941137245, 0.015177866543776222, 0.035331328599048514, 0.005116466590802052, 0.12137320930404322, 0.046934894884803464, 0.027047754431675588, 0.08681262524000236, 0.024481502760733877, 0.01041688148065337, 0.06385788055402891, 0.032057105364011865, 0.013553203499343778, 0.03365642597366657, 0.03321256907656789, 0.026737148241539086, 0.02633044113671141, 0.049670782006744824, 0.05795193210776363, 0.0269061492622963, 0.06609004363417625, 0.013290808918619794, 0.03463679711733546, 0.11486341218863215, 0.040065043339771886, 0.04724457487463951, 0.03708506342289703, 0.021759276245055453, 0.07718337194195815, 0.018979253812826107, 0.030469177357320274, 0.052883740314947705, 0.02706561008069132, 0.029458675866148303, 0.031621085546378574, 0.06041327717580965, 0.02350548781188471, 0.10066329594701529, 0.03474845005465405, 0.013265316357969173, 0.02146048334959362, 0.04359947796911001, 0.03261333105287381, 0.01700360750380371, 0.07179894551102604, 0.018338026345840523, 0.024873258346425633, 0.01189573243859091, 0.01060604177681463, 0.022159408345552425, 0.03136923709618194, 0.03875321462484343, 0.02477457221331341, 0.03947488411462732, 0.029987821222415993, 0.07020864941711936, 0.02911819377914071, 0.027032017508255582, 0.023914859862998128, 0.02152800097662423, 0.048326885726835044, 0.03596457479787724, 0.057556841522455215, 0.035720651636698415, 0.030313582492194006, 0.09308961020516497, 0.047178451637072225, 0.0471140009883259, 0.015457093881975328, 0.0054794497471967974, 0.04930042741554124, 0.04114228214270302, 0.036465269180813005, 0.06536470326994147, 0.022069156402722, 0.035311807146562, 0.021484308410435915, 0.022569297779617564, 0.048586160742810795, 0.03227930183389357, 0.01750404404343239, 0.06350072686161314, 0.013540433470292814, 0.010948712139257362, 0.0332797847555152, 0.06574312903519187, 0.02457970883032041, 0.05547553374032889, 0.0292115262709558, 0.06655591220727988, 0.06480750388332776, 0.038919462489762476, 0.04050871024706534, 0.035881352477840016, 0.05322037171572447, 0.039258981057043583, 0.01928466072838221, 0.033568229991942644, 0.05755589157342911, 0.2044244570923703, 0.0999096403164523, 0.12636289798787662, 0.10279974487743207, 0.14144764068935597, 0.11218273067580802, 0.2038218230009079, 0.09606078613017287, 0.07660899883402245, 0.08582818627889667, 0.053587221673556736, 0.12853026097374304, 0.07073302806488105, 0.08096217417291232, 0.06747652816453151, 0.15859416632780007, 0.15653458184429578, 0.1380577611603907, 0.08796859106847219, 0.15441392920911312, 0.07881931308656931, 0.08792934460299355, 0.14736126336668218, 0.17151736787387303, 0.12799664746437753, 0.20249652197318418, 0.08757168200931378, 0.06663367910576717, 0.10814270603337459, 0.05759025937212365, 0.1553481769348894, 0.0767291606004749, 0.11441699042916298, 0.11487079464963504, 0.10341476223298482, 0.060455767038677416, 0.1775505348507847, 0.1293139010667801, 0.11045463769031422, 0.1193966775068215, 0.08383146127951996, 0.12538622825273446, 0.0713484457560948, 0.16871467897934572, 0.1601169210459505, 0.19989976845681667, 0.10932830348610878, 0.10558429653091089, 0.12578674033284187, 0.12271256957735334, 0.09212575799652509, 0.15938347897359303, 0.0903228565252253, 0.1456179576260703, 0.09081068249153239, 0.18674277088471822, 0.04598143104729908, 0.075606266568814, 0.20748933191810334, 0.10135125581707273, 0.11189208698592015, 0.14921260545296328, 0.07341465274138109, 0.1359601787158421, 0.18138694470482214, 0.1767624028559242, 0.10833224800548383, 0.15118676237761974, 0.13590319534497602, 0.08993634940790278, 0.19611260667443275, 0.13883775073502744, 0.15660314102258, 0.06306841184518167, 0.12156176061502524, 0.09488908507462059, 0.10773058421909809, 0.11246278921940497, 0.14119142586631434, 0.14899352006614208, 0.07576483341732196, 0.20634625825498784, 0.12709704573665345, 0.11774980516305991, 0.16827188059687614, 0.10449473213936601, 0.12182493720735822, 0.12273274920880795, 0.07233732912157263, 0.11117463798395225, 0.19589782319962978, 0.2328929773398808, 0.16029399154441698, 0.09607325081846543, 0.15760114389870847, 0.1656067578920296, 0.11113910989037581, 0.13007654728634016, 0.08410268529717412, 0.1117039495812995, 0.21281934662589005, 0.1039846705804978, 0.13800753599831037, 0.18995108801339353, 0.10401010207299675, 0.1520292857395751, 0.21305508326206887, 0.1938240166221346, 0.11554557058428015, 0.09446825765605484, 0.1641577192183052, 0.20636254309543542, 0.1961856306131397, 0.08879514171608857, 0.1511350715798991, 0.11697510816156864, 0.14777614681848458, 0.08642984327993222, 0.15604643018117972, 0.10736366640776396, 0.08144947766725506, 0.09911474332745586, 0.15893842785486154, 0.14083880478782312, 0.12442046936069216, 0.11791565269231796, 0.09930389174925429, 0.12030222320130893, 0.12862654509288923, 0.14920016112072126, 0.19448402763477393, 0.0699638950505427, 0.1396477451281888, 0.1385492105036974, 0.06747128987418753, 0.08641581117574658, 0.09389336886150496, 0.11448732736919608, 0.11514340287872724, 0.1525975452469928, 0.09585107131195919, 0.2131413793457406, 0.10537167758281742, 0.10233648187880005, 0.10185206215828657, 0.13422813665653976, 0.11781149756695543, 0.1486464494041034, 0.06883263468210186, 0.14083879121712276, 0.13331847903983934, 0.11100878366934401, 0.0912058816424438, 0.1454320933137621, 0.10388187931052276, 0.21961578407457896, 0.1445959210395813, 0.13972249254584312, 0.1744873020797968, 0.14834479987621307, 0.09974087508661406, 0.2070009766944817, 0.11117264309099742, 0.10930351660187755, 0.11090586347771542, 0.10919961253447191, 0.17941098287701607, 0.11723660198705536, 0.1321318434285266, 0.1628962547651359, 0.10101163546953883, 0.28529067284294535, 0.2235000306474311, 0.15135476764823708, 0.21117930034441607, 0.14540455836270536], [0.046742024698427746, 0.03678068279155663, 0.038926230876573494, 0.037355395167001655, 0.02794954104215971, 0.01255693003934409, 0.037105053064546416, 0.06325578250523124, 0.0335335602451648, 0.03425877168774605, 0.00620051788532042, 0.021139860286244323, 0.05237962272284286, 0.08785212731787137, 0.03946550336799451, 0.013497712057349938, 0.14615395957870142, 0.035851456224918365, 0.01144678907335869, 0.09701291325369052, 0.03929631405376962, 0.01461558323353529, 0.037937276264918704, 0.028629804628768137, 0.02101497252338699, 0.040972957121474404, 0.054732347905103645, 0.07149749954364129, 0.012272080190346708, 0.039521061815321445, 0.06553732257868562, 0.020189901082111255, 0.03426452227202909, 0.04238768906465598, 0.02836865176712828, 0.027907258132472634, 0.047577969663377316, 0.08170419971325568, 0.02827751772877361, 0.009852116428581732, 0.012336209383127945, 0.009867125623194235, 0.07673017840300288, 0.024951052386313677, 0.07547938052032675, 0.0445064010896853, 0.04051060335976737, 0.05123187056077378, 0.05276044032403401, 0.042086843600762744, 0.07012099626341037, 0.03856864292174578, 0.07428256688373429, 0.019989093732354895, 0.026972996835995997, 0.025009435235655735, 0.12575365496533258, 0.034422851633280516, 0.03952486500410097, 0.043126145510801246, 0.03260101903496044, 0.03201906329819134, 0.08418482874653169, 0.01733569611263062, 0.04447923594021371, 0.01741769876597183, 0.015120101161301136, 0.02110454423486122, 0.052860938145646026, 0.030135718107755696, 0.042636134661734104, 0.062414263375103474, 0.06057187116571835, 0.04990604366841061, 0.03012846117573125, 0.03845753620511719, 0.017098049400374293, 0.06180276083094733, 0.05778990473066058, 0.007905015239625104, 0.03384855994954705, 0.05340356599273426, 0.028330496046692133, 0.09836334043315478, 0.03891189343162945, 0.021016621363482306, 0.03990494978747197, 0.023262134620121548, 0.039650495762803724, 0.032206881791353226, 0.03650494651602847, 0.016059632978535125, 0.013769668892824223, 0.03912343690171838, 0.011098986441668655, 0.07195943939898695, 0.09669883974960872, 0.025988795362146835, 0.03861283251483526, 0.024945941321285706, 0.08389235979744367, 0.026265176245942712, 0.020897107597972666, 0.048836597840168645, 0.0174521038840924, 0.05946627977703299, 0.05606035289487668, 0.03739038043256317, 0.004959657147992402, 0.0451863033563963, 0.06408641793365989, 0.05970644724688359, 0.026369312711592232, 0.014521928437586342, 0.004263799978486661, 0.0558398527625416, 0.03863042014251862, 0.06735070063067333, 0.02322501875460148, 0.017561514263174365, 0.05578354114134397, 0.036289118097296784, 0.04880319695387568, 0.017226182256958315, 0.03835216989474637, 0.06564363544540745, 0.023382924031466246, 0.00832220062147826, 0.0446970728226006, 0.008058808594276863, 0.0821996456278222, 0.04691678139248064, 0.04180277830788067, 0.02654224923545761, 0.04457984572010381, 0.05072788867567267, 0.029734174654419934, 0.020670582074671984, 0.08265395196420805, 0.019239432976714203, 0.013241040919508253, 0.028665960367236818, 0.029657011652099233, 0.042071688521121225, 0.03615397088495748, 0.07388974939073835, 0.030434768846524612, 0.03307863644191197, 0.06247501940067325, 0.04073155811056495, 0.0503387488424778, 0.03644690802320838, 0.04092673870867916, 0.02871331532618829, 0.05434029715667878, 0.03540122449131949, 0.04034195008820721, 0.05794882441737822, 0.003646006990623261, 0.026870934991165996, 0.015000763814896345, 0.025210166250222495, 0.026694894169590304, 0.05829105033938374, 0.02694600640929171, 0.027269396199179546, 0.011661283322609961, 0.0050284784104275915, 0.003044051646221695, 0.03911010368860193, 0.012458729058770197, 0.06825262973351137, 0.02268463516208742, 0.011015890498778649, 0.02523704132597361, 0.015395569415496928, 0.07623906154185534, 0.02742379853901054, 0.03055382120822157, 0.1315718756190368, 0.024506433833656565, 0.03842211328446865, 0.018195423729983822, 0.02050628499793155, 0.04766681703871914, 0.020398168924397657, 0.056188545123274834, 0.02534971885117037, 0.004982060677970627, 0.10026198998093605, 0.024016236387459294, 0.02235926065727004, 0.0298459429426917, 0.050038239253418784, 0.031484472698399, 0.0492859881903444, 0.05742445934031691, 0.030533315879958015, 0.009918492420443466, 0.019647395371326377, 0.0646445197718484, 0.04916305121566568, 0.06320227323366062, 0.06550884446395294, 0.011628841715199607, 0.036693748884967396, 0.05133035313338041, 0.01725061291030475, 0.045898381753691604, 0.02289618711386408, 0.04730634531006217, 0.02818630396255425, 0.03188631809981806, 0.019667909181277667, 0.05007469354729567, 0.04226690983133657, 0.026393380348703692, 0.0715121559000441, 0.07449489406176976, 0.037146023008972406, 0.03568843140133789, 0.04592425090127757, 0.019425427907013466, 0.01196335269404309, 0.01989510645424681, 0.03844703248302851, 0.05331312066742352, 0.003221768873377836, 0.009932694158383777, 0.03144675972206252, 0.016291771682777574, 0.01807794896220522, 0.07274340518883296, 0.031006017300699438, 0.01065814563272787, 0.08763721492141485, 0.007002832534323845, 0.0760006175509521, 0.02896721973749144, 0.0759571370269571, 0.05401171996657338, 0.026505148636975458, 0.020494383493704454, 0.05433822423219681, 0.019871459508846914, 0.006585054706582534, 0.05841287451663187, 0.126620049189244, 0.03290894501177328, 0.02499866858124733, 0.0195696691849402, 0.03551170017038073, 0.04048104637435504, 0.03100447024085692, 0.02791463041545025, 0.03171944259000676, 0.03536594067034977, 0.03648631733709148, 0.04403195922662105, 0.020649469457566738, 0.030479504660304104, 0.03289084169747574, 0.017219709032880406, 0.04262905414881451, 0.019550434413499067, 0.01784251257777214, 0.05753903676356588, 0.047413414743329794, 0.03673495292397482, 0.04559872711875609, 0.03824519206370626, 0.0364396680545594, 0.08886009787342378, 0.030380584432610443, 0.041166974032031636, 0.10477415964539562, 0.0273294635117054, 0.015589540524940406, 0.021309298962088566, 0.09851080644875765, 0.014992450064580356, 0.026439870175506388, 0.029597229324281216, 0.013743075409105845, 0.017107791466904537, 0.051082837129277844, 0.034246663230338266, 0.04301995138770767, 0.0223096546583942, 0.12229455129376479, 0.025170444810230817, 0.05312083741383893, 0.020194901885198693, 0.021518180878566842, 0.035323637404612133, 0.03060945768707565, 0.09023195997412715, 0.03263972606509924, 0.018875008781573603, 0.02625422129806663, 0.036230353572006734, 0.04760682775772043, 0.04021327270727072, 0.013315550849906035, 0.0676342197028654, 0.06084474402346781, 0.0430277172209961, 0.009334091413100916, 0.02346871460654906, 0.019929070524605255, 0.018551479892006943, 0.06374721827783755, 0.027378287498972247, 0.03386074643848198, 0.06438489870301314, 0.047059955674090555, 0.012391603285712855, 0.02900695814085858, 0.05769601584013019, 0.049054204020649195, 0.07894041801669768, 0.020339875980945568, 0.03223213007939713, 0.09222552978566714, 0.027208596068833555, 0.02248729342993881, 0.010044517577625811, 0.023468521224068742, 0.06401041522622108, 0.03533004956053836, 0.04203537332692316, 0.01523263958681907, 0.03465935840670552, 0.015838752866589596, 0.033247306676847596, 0.003628466012222426, 0.018556557030283978, 0.0380216690578631, 0.04074438920776759, 0.013346764308932637, 0.03702847020966666, 0.028323244203680327, 0.07764474182788815, 0.06644575204700232, 0.03492072670321379, 0.021465078728007417, 0.06722701048212391, 0.08645934598254305, 0.07231262366154365, 0.022912762028032115, 0.03935893605064068, 0.05086327337526849, 0.13745602273515292, 0.16318645062191145, 0.14074186927505902, 0.2635330946317741, 0.09977071027138404, 0.11794648532356534, 0.09402239908065115, 0.13985435904136725, 0.1122264690431101, 0.10880836245736905, 0.10346357604222638, 0.09556717904550688, 0.13051067399127142, 0.1989629151565688, 0.1252775133720466, 0.23213478231004306, 0.19892721064388752, 0.2052710380937372, 0.09877334521817309, 0.13739342109433242, 0.11540178901382855, 0.1666422973253897, 0.10016183821218354, 0.15446386938648565, 0.13474239834717341, 0.10171023476868868, 0.1982827109417745, 0.21169975027441978, 0.1184391967420067, 0.12603797470884665, 0.16474073007702827, 0.13591778384787695, 0.19313571069921764, 0.17626591878277914, 0.10121398818280015, 0.11752563076359884, 0.09808908336396728, 0.17297753452190331, 0.10220576210745744, 0.09334813204727002, 0.11237164161034993, 0.12890402520341532, 0.18002422925617012, 0.156708368233272, 0.1518672380064215, 0.08859587633716208, 0.09508825545864445, 0.08782664154257093, 0.14893279118197306, 0.13980030694178172, 0.19779727341873304, 0.10353550075420312, 0.10358007371957813, 0.14591408387890883, 0.19760792143642902, 0.20000813049929483, 0.21047195472887584, 0.1142454839178494, 0.10838332133633749, 0.3180347643792629, 0.09464051734123911, 0.1172271432088954, 0.11745393675352846, 0.20673880433397634, 0.1584830901452473, 0.10477802050965172, 0.058816277155918736, 0.09059539690081563, 0.08302325143345765, 0.11215880553105048, 0.1363545704100813, 0.21417888653065476, 0.14750299576137746, 0.10466215386986732, 0.13287397074912274, 0.11769637731569153, 0.1730102263391018, 0.1778269021638802, 0.13595020425106796, 0.08230437750795058, 0.16274618996041162, 0.13003579447312014, 0.15683632636708872, 0.2004313056490251, 0.13163521007767745, 0.09988356421568564, 0.10085293969937734, 0.1495183397616659, 0.1637461470173938, 0.1039907502542649, 0.1347762979567051, 0.12836361277316297, 0.16094234532543591, 0.11661567459149019, 0.16061569856745855, 0.11407167038747243, 0.20048372926456587, 0.07642991987190076, 0.10814170858689717, 0.111678606298353, 0.14867828626717838, 0.08713110243635518, 0.11467677434640271, 0.12211687011378151, 0.08858244812914304, 0.10836346740169184, 0.10541602663163628, 0.09744146918611866, 0.09550374280661345, 0.14091161159532412, 0.13950932398438454, 0.12397271767258644, 0.11727208936853067, 0.1638076901435852, 0.12638147627668722, 0.10318183473178319, 0.07320608464734894, 0.19643991839672836, 0.10931542489145483, 0.13069710827299527, 0.10799325191016708, 0.08683069462754897, 0.12896772607096604, 0.11093470800135817, 0.08560045635593788, 0.1349294568811144, 0.09585737490228244, 0.08916530292481184, 0.10758520130600248, 0.09145792347512074, 0.13470188980656012, 0.10972718029682126, 0.14009583608380385, 0.10516522651804344, 0.07714676497770206, 0.15426741992788656, 0.07248377054929733, 0.13034509787602083, 0.1429360072527613, 0.15396973304450512, 0.13828697028969014, 0.1219244511531932, 0.17521899353180612, 0.12042573014540331, 0.11615964477615696, 0.21154117664056166, 0.11037809894021068, 0.15966471816812242, 0.13125578686594963, 0.1735261165137802, 0.11420114843973092, 0.1428591428058488, 0.1980107133941991, 0.11197451541998557, 0.11478947901300021, 0.1011499548330903, 0.09589860269001552, 0.18019223452678748, 0.10518498545778648, 0.16466526341225418, 0.10955251181232077, 0.14285167892064365, 0.10447217763534614, 0.11324763710477523, 0.07461291165756327, 0.08267072534986905, 0.15701068272548063, 0.1839634914483343, 0.09762729278632573, 0.15576953361076967, 0.2258085696292775, 0.21127056330442429, 0.13676796108484268, 0.06419809801237923, 0.1155044242207493, 0.11099044286778995], [0.027460860121729117, 0.04145250156787889, 0.030278295278549194, 0.04061948448153479, 0.029930827673524618, 0.07325903752020427, 0.01367606159432658, 0.027807233589036123, 0.026480231134753143, 0.022420751196997504, 0.056776906230619976, 0.02709329261311463, 0.03851061121427587, 0.0726928271885429, 0.04063431386436735, 0.08124287732477699, 0.035101783594914844, 0.058011005366487164, 0.023161071918106506, 0.017101316546489085, 0.028536597665931498, 0.014438336315963949, 0.0547006467490324, 0.04498387939695801, 0.08671493655336754, 0.0281006321310997, 0.03191609560911145, 0.014792921753334147, 0.06233379590724196, 0.01981660334526428, 0.012694408867641218, 0.04813767284420984, 0.04584964258330209, 0.030775081299777542, 0.07915003784000874, 0.014303903261731778, 0.005725006057348634, 0.05587041737245662, 0.04746595031714865, 0.06871009125773396, 0.07790538069925138, 0.0009043634532385372, 0.02386772882060281, 0.07757657619991473, 0.026958403244082416, 0.017657515093950287, 0.034952383754508834, 0.025453290436416864, 0.052463923913559744, 0.03827804672930922, 0.015062651297609721, 0.0264508336050702, 0.03851428887407694, 0.03486641676032117, 0.018753303347953727, 0.03435308466266308, 0.04947651403823069, 0.03906106935547931, 0.07871334627270699, 0.03779008844867349, 0.016466725151985884, 0.04160673936296787, 0.03340919834694692, 0.023156301816925406, 0.008043025021574326, 0.046060222533664534, 0.01900031214712986, 0.02697542599136276, 0.01218676713428327, 0.031038800720125437, 0.01811070184755538, 0.09144714155367442, 0.057840034897838316, 0.038650430140218565, 0.054084509810698886, 0.014762021268584898, 0.026434209497113312, 0.028364282001608183, 0.014484692132100463, 0.02847578057221004, 0.01508685973073755, 0.05303991872019001, 0.026561473828873465, 0.047583577755306444, 0.02064680281494345, 0.015334328237388815, 0.020407027199066112, 0.06260818189808301, 0.04854660554389868, 0.030053299851715565, 0.018372633328129138, 0.020608441837664162, 0.06969463878444263, 0.023021658416837454, 0.035579787766827006, 0.06545238356505122, 0.0239489375879722, 0.03992112266964146, 0.042256463784724474, 0.05207991719778095, 0.05521614337339997, 0.06079808795558555, 0.04489499130951507, 0.025706704606169035, 0.014074795912685139, 0.048968372733465264, 0.054786118412656445, 0.05692405333476407, 0.030277959403714964, 0.01728646839702768, 0.048929197514163594, 0.04858753477622356, 0.06973210748817239, 0.0586591080895492, 0.03832202597654291, 0.04345352169392364, 0.036717521359345744, 0.011992009772386934, 0.04969209139900548, 0.02244599100335368, 0.03621950040438345, 0.03523714454578502, 0.04180175032732742, 0.022415838603462492, 0.048007869095142396, 0.09490497636475734, 0.026701776211016943, 0.03241010981478861, 0.069288406654128, 0.017038641963154078, 0.019837656590555395, 0.007806087378412485, 0.050690162128635814, 0.026726544435535158, 0.04239844045202647, 0.05810783231364829, 0.03455420922754066, 0.07879373910171644, 0.02720981403919203, 0.05240303896633642, 0.05065455600353224, 0.013508783204347959, 0.022778096575556055, 0.04201595704736454, 0.0062403199013455635, 0.018484834182475294, 0.027425552552033747, 0.04567253476540957, 0.024860763124057224, 0.011378746429857398, 0.06457656448973076, 0.026716671751013825, 0.09027237351983786, 0.07941243411707026, 0.046775435762745995, 0.02055357549605625, 0.04261639268536653, 0.03325621584164245, 0.03802525172276156, 0.009232408699712582, 0.03226661662171994, 0.09591828699090651, 0.03603681842131274, 0.06898837203958205, 0.05298355281619089, 0.02170391457288393, 0.10708012697952134, 0.0267681420248534, 0.023708692086594443, 0.012111521841559027, 0.018965009666447128, 0.036407519065375836, 0.020956990009705936, 0.01839571200045092, 0.0057220675766335004, 0.0043072173139080405, 0.05301212592582617, 0.0702333820185491, 0.029624866055590764, 0.030650610835956674, 0.027592668941776668, 0.03447218791448644, 0.025264991879729286, 0.02979351593447583, 0.01705054346738117, 0.0217620141338557, 0.018531642920736755, 0.055264824868312905, 0.028187350602820516, 0.043224373632775884, 0.0320558331108519, 0.03842602503885116, 0.02672626114716487, 0.01550009603878217, 0.029633710759558847, 0.011456454804699336, 0.030255292941417013, 0.02033945359289646, 0.02859229182026216, 0.04722223071647542, 0.026862254831939936, 0.007178903041806604, 0.019225931826180646, 0.023574971494131854, 0.04039396997541189, 0.08015742485544511, 0.06779385185135262, 0.06583644117095641, 0.0769598421507648, 0.0769879606419376, 0.043816598997052224, 0.01984464719758502, 0.05651446245610714, 0.037876907004309554, 0.04050955841583865, 0.03704700778637614, 0.08620982151478529, 0.07000481749751739, 0.03787754821990218, 0.03653378764699612, 0.05878604842083795, 0.022360933246091008, 0.04184886101367218, 0.06585075825984989, 0.014480704042528356, 0.08031827158161572, 0.037083872593939304, 0.05908664621944938, 0.048285284744841714, 0.05804363611553397, 0.008638193531494056, 0.022095763457140753, 0.026951195505846823, 0.07160527126065322, 0.030349514314106533, 0.04666593378143651, 0.022313888716910566, 0.017616747013692344, 0.03793848744992699, 0.036482951803398986, 0.030817476167742695, 0.02940339222550392, 0.07907225737082106, 0.03394091874361038, 0.039280687392290146, 0.05432964754956109, 0.05659876364682402, 0.006979489233344793, 0.10789118667266198, 0.006867395248264074, 0.011195927043445408, 0.037504628766328096, 0.016295666473784616, 0.021927627568532313, 0.009586218062655201, 0.025378666851403456, 0.03965853640277471, 0.03481290748875056, 0.05961681955627032, 0.07205589315188782, 0.04687100063477244, 0.026420526838462268, 0.021328070633379475, 0.07742505933025054, 0.06753045812781368, 0.05281819722482136, 0.026534900701205646, 0.02638259164190718, 0.07919788812952382, 0.06754064972379378, 0.0793561903493745, 0.06518117311809744, 0.047876915229218345, 0.04562101699411869, 0.011730146993483816, 0.01590010939565088, 0.019474608125165105, 0.038924195271517546, 0.03646750495369945, 0.02680143604188093, 0.011845622627463723, 0.022916477007259215, 0.044666006096771786, 0.032769044661628347, 0.04919914249330759, 0.009456173433656139, 0.056504576200885434, 0.033545648346522024, 0.03201729232179267, 0.03650822723284364, 0.05547709097819669, 0.03898512093084199, 0.03953751968219876, 0.04385450535586902, 0.02309620736299881, 0.03686414259885039, 0.042837632420871935, 0.026262451927842836, 0.02003757336309978, 0.06315599036003862, 0.025161303247192075, 0.015142314701474138, 0.07152805397553103, 0.035499266016163995, 0.0139284859511203, 0.019298058402325426, 0.09021633331264768, 0.029297578082020794, 0.016121925885922143, 0.017370851011946797, 0.08501619699278049, 0.015470895284254636, 0.1014050840001021, 0.011595424713699945, 0.026357965909742882, 0.04381550994834729, 0.04062233432861311, 0.02268449097339596, 0.021359695454261134, 0.022215470605130707, 0.023638758874897445, 0.016125525514196073, 0.024050018949700252, 0.01436254395438092, 0.042749989445188215, 0.03981829068756529, 0.04428072373515793, 0.022895781689190438, 0.05677968483152134, 0.04642517937879477, 0.02431443047576717, 0.03662935591169766, 0.058686330914497375, 0.052099533645170074, 0.02788609971425363, 0.026161750545725226, 0.046245187787073, 0.04470075387507677, 0.01396877905686519, 0.061729472263583114, 0.01968314907779651, 0.039797425735741854, 0.04310100578836032, 0.00842231507080474, 0.030062025812055384, 0.04998199887839811, 0.021202819854287163, 0.018649299196632843, 0.0220367258215057, 0.01644856246587421, 0.010913392695199167, 0.08691491439406361, 0.1072077662018793, 0.20017791353166103, 0.10793930837618453, 0.06689705925860576, 0.11094774944441659, 0.19271873735955783, 0.08181803074798413, 0.11576889002961771, 0.07651754588420902, 0.06297493007566247, 0.17889345064759254, 0.10811573426638331, 0.10110127673085247, 0.19108532715056623, 0.12804415848638329, 0.17629242236060755, 0.15399828579808983, 0.08590150198766164, 0.1427741495094129, 0.08499925397336483, 0.09640116643692766, 0.11324024785842214, 0.14919245296290942, 0.18094576123569692, 0.1341835840472153, 0.12556298662509235, 0.11440970296306269, 0.14580492116510868, 0.1062379903825266, 0.1184269559702703, 0.10201250854879618, 0.15851534770003387, 0.25410075219614164, 0.15940099874777452, 0.22051135530429228, 0.08803033096981899, 0.10699444157736641, 0.1332751206521477, 0.08894259416099105, 0.2223379308623927, 0.18742665275931358, 0.13018093311360904, 0.16136181567396435, 0.15028690280658857, 0.1465701458177396, 0.06827232760510274, 0.10033315473369189, 0.1413650494068861, 0.1747004027877535, 0.1485213954001665, 0.13419817255011626, 0.21617577437843594, 0.09213653991797141, 0.13400086813739367, 0.11831598835332052, 0.07257499958255462, 0.14432464273912565, 0.17040960517312798, 0.2261007468083075, 0.11016746131437165, 0.09905376338532992, 0.09243586207074778, 0.10323529650590249, 0.10797729955187865, 0.04555424575560859, 0.0663989195600152, 0.1498142217418977, 0.10750334962670292, 0.18789948310170854, 0.11160370960299458, 0.09053720573761634, 0.11686127712684018, 0.23275233060121536, 0.0868056295439601, 0.08378687474344458, 0.1363812775484153, 0.0722680099840675, 0.07615982222237758, 0.06278077406542641, 0.10546152240463666, 0.08449806765254055, 0.1176975036838225, 0.1396717924092497, 0.1719500832259655, 0.11211430041917733, 0.07304970946695123, 0.1261751473482166, 0.13482873514294624, 0.18493454291352204, 0.10044930635818414, 0.181999091857246, 0.13538301682897977, 0.17494045490665094, 0.1332572480397565, 0.08774544125688927, 0.1978437937796116, 0.16779192563678536, 0.1970070379653147, 0.12798686298940862, 0.11805186181196145, 0.11800049671104976, 0.11055012113813843, 0.08651961346289941, 0.14150971307286195, 0.0912958418152162, 0.13723904080688953, 0.1852279957383871, 0.10915970110467502, 0.09694594184734992, 0.10622918978333473, 0.16820509918034077, 0.09140353210802589, 0.11986029334366322, 0.15065013617277145, 0.09666991380176373, 0.18045862737510884, 0.14267942602080957, 0.11393813469580241, 0.14965904078313283, 0.1467347719839641, 0.15629927947052888, 0.09020992794207164, 0.19117559944944723, 0.2082013322838715, 0.13058250370834554, 0.27110098568456514, 0.14980943128466606, 0.07821892494601862, 0.13805469418210642, 0.08758171754223959, 0.2586183569261006, 0.09786492932055678, 0.1348381396383047, 0.13170747405716351, 0.1154548233108861, 0.1360473976071392, 0.17359148657747678, 0.159949784300157, 0.12378986605576106, 0.144911846944264, 0.10901997038828475, 0.09111657286328928, 0.0878125483702336, 0.10234774556010962, 0.09061379877052136, 0.07136190789086477, 0.17479044438472816, 0.08703200239688158, 0.11654069647192955, 0.11054475392614092, 0.19913944282702037, 0.08793178732906069, 0.1303428451397589, 0.21942554999675068, 0.11905177815684251, 0.15042051992246083, 0.2684557576264654, 0.08825490570494107, 0.07890185008623771, 0.11734432620661599, 0.1026693033054471, 0.18319038221878664, 0.1409895345568657, 0.22324465720781259, 0.22067786779786858, 0.18499383330345154, 0.17057784114565167, 0.070196483284235, 0.07188706685389791, 0.14140728142644676, 0.10826313921383449, 0.13084612813379082, 0.13854626566171646, 0.04030167224950024, 0.07053462442542825, 0.15206009122942174], [0.017289470914485197, 0.04261932395664709, 0.03763368273419993, 0.0073068543902731365, 0.017527969188189933, 0.012423809102204229, 0.013876532221079936, 0.056292547578258176, 0.001199890156775447, 0.021325660137725726, 0.02706939460975783, 0.04338987510917442, 0.04233484475740364, 0.04059242111231599, 0.09333217290363141, 0.05509184254333377, 0.016179833760751144, 0.12188992729144436, 0.013442134950309992, 0.06816887137080942, 0.005476153763343713, 0.02018325822427869, 0.03572821730215635, 0.07387852642152991, 0.01866665272973478, 0.03927027527242899, 0.058152581698128154, 0.016234153881669044, 0.09063554581786905, 0.012250881060026586, 0.06602709594049624, 0.0235125717174794, 0.07542998317096915, 0.01901524670289031, 0.0319678780090596, 0.033134042218859704, 0.03591108588235719, 0.07583078023578439, 0.05360386274488909, 0.06124689815832036, 0.018606729605900388, 0.06177314277738333, 0.020011288612814884, 0.020776550584871854, 0.0641000157754336, 0.07901137242359774, 0.036427763157657216, 0.06373720988631248, 0.054482226326529465, 0.028639168412025486, 0.020974940653624277, 0.02736455903920744, 0.0373753033844488, 0.013481611269526184, 0.06393009025071349, 0.022380804144112126, 0.04890615785760539, 0.0350549680713032, 0.04409984665523682, 0.02357324292617185, 0.027105499458100115, 0.008462821066911732, 0.05874014552682638, 0.019482730189338326, 0.02631717238442174, 0.05605610865833504, 0.055311518255621195, 0.007164462968440992, 0.06306410314781324, 0.018616112048870752, 0.058364277838596275, 0.049440887557076554, 0.06886671749608857, 0.013529026448460562, 0.045963202204023085, 0.024160384366820966, 0.016347713502390043, 0.0773986711033753, 0.04404055965798242, 0.06507376780999558, 0.012829271943441458, 0.0068918759435681355, 0.026979693976630057, 0.08019825230751719, 0.008471864242372769, 0.03407266988818135, 0.05735661940915244, 0.012482440464996865, 0.0115073915803805, 0.03877078528915133, 0.03007343877106905, 0.02336435592068093, 0.026723625038617423, 0.06467500635023628, 0.07970692510051386, 0.03339331384216036, 0.03979571922016995, 0.015545298345386982, 0.030501302597778182, 0.05125727491187198, 0.03334563997175012, 0.003173453575332782, 0.06634322540568453, 0.04950175554092441, 0.0256189920806459, 0.02914727239736489, 0.03327782039663621, 0.009879653075976031, 0.015461923354970557, 0.023004191229119897, 0.016688616281109195, 0.04479052405804396, 0.05216098516913397, 0.0480749388890607, 0.026502203794994524, 0.026146680282961045, 0.05348672724461981, 0.0835713923775724, 0.026250273920595646, 0.04480017961135932, 0.02983855708901371, 0.020467097904267054, 0.009262902911619415, 0.10477328433522157, 0.01691296709967511, 0.03987160657665559, 0.04395909813631858, 0.02794189564883709, 0.01040367379651538, 0.04278121901942151, 0.042524994018354585, 0.07986357169491903, 0.015139534404235227, 0.0336059531463044, 0.01595322002789804, 0.04763718880712986, 0.032416684819119315, 0.00935413533755179, 0.014862987279359783, 0.0418004034353154, 0.04083972677056279, 0.020792796409555843, 0.013258373248390853, 0.021800653310492635, 0.02753473392554692, 0.07443705573678017, 0.025985116006008217, 0.01917449208641691, 0.022962266246655157, 0.03952958421515567, 0.07865994556673936, 0.045747991252158365, 0.028697284936372722, 0.026278930150770714, 0.011264549834387643, 0.006440481794665435, 0.020812460354396274, 0.014633932516777089, 0.022999383808512772, 0.01890564803034067, 0.052263979999614615, 0.03282676424298968, 0.09024346792804343, 0.059661426448396275, 0.024736747278698852, 0.027683592634275556, 0.016129248975110904, 0.0815360112381833, 0.03873252948479993, 0.03842974680342844, 0.09030927903950214, 0.047236690297722816, 0.005831111970889781, 0.017825863024752055, 0.06883413424449307, 0.048693779789443524, 0.01226224228074508, 0.021849541758586253, 0.011544610922490912, 0.027382183986316835, 0.024562236553590213, 0.0700468256005219, 0.02649526747076639, 0.05334997529696141, 0.042925129511526654, 0.041885009966790676, 0.04874084297833698, 0.07319804400737796, 0.026547451902713095, 0.015272936085239053, 0.01926719693333975, 0.04533436309014048, 0.01839895879051515, 0.025895761425739953, 0.040830013541770835, 0.06438416588519301, 0.03168208584455507, 0.00636529375333339, 0.034040653213326416, 0.034662326997412105, 0.0116241513418832, 0.03230106584461672, 0.02699622478602188, 0.046211060868310075, 0.02904872875660658, 0.032219604322952886, 0.04489308462611266, 0.020454933467720236, 0.10898994521370955, 0.04981379343995026, 0.06210061734808343, 0.04592617115538035, 0.0049310153366864794, 0.045811000013990064, 0.05345282084973795, 0.025037959151502167, 0.030296642865453447, 0.04408657451027206, 0.04006155566977603, 0.011803016565474016, 0.028808720742485354, 0.049362445516245704, 0.009649317578545638, 0.05280328981046166, 0.021657263594014303, 0.036173634829797914, 0.014085747467886125, 0.026852473749646118, 0.04721871590507882, 0.07275457387523991, 0.13201069778629712, 0.013475754664146473, 0.035812070659760914, 0.020354768128267357, 0.07427356950938702, 0.04212460068187543, 0.03160674131608435, 0.05590025594990168, 0.02190285425500146, 0.013012651121243834, 0.025010458127196347, 0.039996830214347155, 0.03971221191542489, 0.0362289150777672, 0.029483798625213758, 0.007624658140619951, 0.042951154722166915, 0.009436888620257378, 0.03402281792036124, 0.048983361572027206, 0.011872928572951682, 0.0007555813977627882, 0.02417339018679091, 0.018140394539971436, 0.054054701767329655, 0.09423362024660621, 0.025729652660499727, 0.02926520856895617, 0.01894040937934603, 0.07427412590810231, 0.028264481374727826, 0.01622364846324282, 0.05631064071453043, 0.04807379895022937, 0.022007614972868135, 0.042805741274995465, 0.02196540161302047, 0.05463815028113978, 0.051299245695450475, 0.0288005138614348, 0.037441392695265155, 0.021187871727826338, 0.01709937084732311, 0.06325871377651181, 0.019448001070746353, 0.035854723371033154, 0.038048623861478906, 0.03805385197379759, 0.04790562065318227, 0.02707172368120934, 0.022189194336533546, 0.0287487552102123, 0.02834088950684028, 0.02562409296764859, 0.024905926414898465, 0.030122775052274977, 0.04682376441944923, 0.025676380876185637, 0.017079684850094572, 0.03518119254814727, 0.026994726919968213, 0.0390574086590537, 0.028856571032000438, 0.07837014326027461, 0.03615616594574281, 0.029496483837387392, 0.003979010773556573, 0.04532818502879568, 0.0189365586931152, 0.006773286257937018, 0.022929335245862603, 0.012278334586881101, 0.07284320411937577, 0.06003576743283442, 0.050504531910909076, 0.02654127893038094, 0.011863862496933766, 0.0344520795292088, 0.026533207756334116, 0.02486655781311648, 0.016063865340713943, 0.03440040908753872, 0.03904035368135997, 0.045046626922807524, 0.02087678208148905, 0.044407199269958904, 0.034774610972298045, 0.014061675589930798, 0.02255562869166689, 0.06407782089497362, 0.024421230191364884, 0.06672218721359968, 0.014403865040679063, 0.02486282926318901, 0.021767162518309693, 0.05408414340178881, 0.04554764021720205, 0.006999144272413105, 0.042132339373763115, 0.043984858718301566, 0.005453879579103419, 0.05600658238732389, 0.011254960438236594, 0.03202071553096175, 0.042877988291106055, 0.027478890493512154, 0.042082711322499175, 0.006503863750757384, 0.0570381489981498, 0.04969717362629516, 0.02581318880298308, 0.005531488294114492, 0.005283750917962087, 0.04073408226083432, 0.019599499280697534, 0.031421443580516746, 0.030015305283346345, 0.01840260421990284, 0.0082641706103459, 0.07768380508891173, 0.046808242930897644, 0.05022573204977172, 0.07882222400179931, 0.11201988905668259, 0.12175184541514941, 0.18188971201223986, 0.13942658342421055, 0.12948802672326565, 0.09257457498461008, 0.15808974339493684, 0.08057570098234074, 0.20466981535511358, 0.10726570630712168, 0.10444098538053886, 0.07579150662890502, 0.152839809390051, 0.1382434626242944, 0.198109860931124, 0.2269927082317216, 0.18053515255451202, 0.07840370360229697, 0.1715966479054519, 0.1475086004606315, 0.1528899259865284, 0.1112841535359621, 0.3167940495269639, 0.10508425014891795, 0.093713116033801, 0.17408995197287627, 0.14578821563294955, 0.15866636245378427, 0.11820728704333305, 0.13363364498530114, 0.11844067594834737, 0.13303528566445622, 0.11803763971797057, 0.22472471850258963, 0.13587560611111776, 0.08984495074089084, 0.2304291624043669, 0.1755893922277859, 0.09630872961133718, 0.10816541660044875, 0.09431939385831356, 0.09523070031510932, 0.06308292570923056, 0.16228902020624705, 0.11496968434325286, 0.12950499009873184, 0.12571221004639352, 0.10552166774868965, 0.12644063095961297, 0.07410893655781235, 0.11012881195970944, 0.11314331913100821, 0.10891811549663544, 0.17045611196330615, 0.10343976624842201, 0.10481939078973872, 0.13783517453287328, 0.1510572571839605, 0.16751828603446484, 0.11765616733048644, 0.12876177712210587, 0.1451950403196471, 0.12844857892819814, 0.08695150778761931, 0.20157385005482606, 0.1121179780789784, 0.1151275523006916, 0.12931702232786588, 0.1475438435695001, 0.12005792345319476, 0.11069785856774875, 0.13062757200428418, 0.0892771254958851, 0.13416724492396626, 0.1162107384630612, 0.055535879252212386, 0.1311248703194516, 0.20113296514110907, 0.13830001173274858, 0.12126923059778554, 0.1208874596548932, 0.07815972955099174, 0.1816778869501182, 0.09809417916195733, 0.1447221285530499, 0.15606929681130818, 0.11867916743670191, 0.21305262696530136, 0.11408537679484912, 0.1461369554911341, 0.11770971731415816, 0.13281010703316756, 0.1384003942034074, 0.13650501519441605, 0.13883780501782894, 0.07418884084160839, 0.0961078086069652, 0.10414494733725276, 0.20875117635088308, 0.08616178123546497, 0.14634871269975389, 0.1251396079148565, 0.16373453049787454, 0.09668289417667048, 0.19217300521475927, 0.06695670248674494, 0.10263830782579524, 0.09992156217672996, 0.12011060491204262, 0.12810518592596054, 0.11018067917653493, 0.12049450645489351, 0.13137204705604485, 0.09735433850437403, 0.07296720639403377, 0.1004896384796926, 0.2651056945323944, 0.12230121450764792, 0.1013417834682124, 0.15547587722539902, 0.09737704907144819, 0.09808193839022092, 0.15518975257873535, 0.12417638674378395, 0.14310394466987678, 0.1275675826306854, 0.20310518145561218, 0.1390689547572817, 0.07483015142913375, 0.12559263860540731, 0.22634834423661232, 0.0958411782713873, 0.17959147319197655, 0.07282588112034968, 0.1500083641814334, 0.170998980690326, 0.06988665062401976, 0.05688039639166423, 0.12009113095700741, 0.12364969429160867, 0.10438107073839221, 0.18149826515998158, 0.11309897008218936, 0.08982806878962687, 0.119169503982578, 0.13362609967589378, 0.17596208437212876, 0.09881132282316685, 0.15484217980078288, 0.1557299614484821, 0.08378209785691329, 0.11335694909627948, 0.22113558038004807, 0.058549239699329646, 0.10512906738689967, 0.1290960641843932, 0.11350194524441447, 0.1580395453742572, 0.15000282733568124, 0.21044223489505903, 0.13727619738451072, 0.15125689575714724, 0.15004036389291286, 0.047682508161025386, 0.09566887787410192, 0.08710063621401787, 0.16894460735576494, 0.10528657572077853, 0.1415400164467948, 0.12101897331220762, 0.10147246931280408, 0.07606701898787703, 0.15268757327326707, 0.21537135754312786, 0.10698405320623092], [0.020683472543688755, 0.027095211170879856, 0.0398764207826129, 0.03146969759836793, 0.03485307676185455, 0.02915298566222191, 0.043883665398295434, 0.03612943845135825, 0.03681348656703319, 0.01729222576666091, 0.01504183214690004, 0.016269615818081156, 0.02110140770673752, 0.020247162652334998, 0.03231597665165152, 0.011246723023110201, 0.04209020234910505, 0.0408069365657866, 0.0522713149631662, 0.04479818471840449, 0.010187447586629008, 0.016791848598846366, 0.032438387761690786, 0.03201047983020544, 0.03770065414054053, 0.041471704108906646, 0.035015277165387354, 0.023040925418691974, 0.008212807205771762, 0.038716872289244614, 0.05135161163551467, 0.02033142652362585, 0.08337598107755184, 0.01363432575349829, 0.03730229301644223, 0.06313146131911448, 0.01661422848701477, 0.05665044765919447, 0.06874196204755988, 0.04717667048264827, 0.05303646158427, 0.07199375970023018, 0.029875282796898057, 0.055114488649581156, 0.04739050740110023, 0.010796847520396113, 0.027796770579048564, 0.04837432210998876, 0.03342897425006543, 0.054961014206388166, 0.026877745786415677, 0.025515978590452244, 0.014623878324138266, 0.03423584738214101, 0.027879339809130346, 0.016195872632254447, 0.06337870590920959, 0.016636782991034643, 0.021296228681291853, 0.03975657792761922, 0.06953206857932465, 0.013586282929671662, 0.013719955176514174, 0.01889646066618817, 0.006016183669479298, 0.0398733571970037, 0.04810213117993303, 0.05094819881820253, 0.05791945063642093, 0.04575553656156574, 0.023546079473037804, 0.019446754262649586, 0.035435361588107686, 0.09196160680481366, 0.06326311746878283, 0.03160178801044822, 0.028812242339232137, 0.01944173140717404, 0.03636374677132283, 0.01811352794590805, 0.032241541360105784, 0.037599732234541855, 0.019963165212954794, 0.03095242999760168, 0.0177919277921319, 0.023661737463303974, 0.037262103387287686, 0.020695155220372335, 0.05060089745425752, 0.03561477303238852, 0.05788764770009688, 0.014632970693388155, 0.09962382779589721, 0.020979228994942138, 0.021329069776194434, 0.034448700424815924, 0.02690204412543348, 0.02746712469628879, 0.051151247029857974, 0.05376161874404975, 0.014226418803445995, 0.05312419955485633, 0.03761678381956049, 0.010408281897460776, 0.017607508759413446, 0.03451727317380054, 0.03837732997323785, 0.0378385290636548, 0.05413734393992594, 0.06248057660247598, 0.012891808275266417, 0.007498137652873993, 0.026455992167549472, 0.034528082236647606, 0.018508650761629854, 0.01819742371195129, 0.04800628810854895, 0.03932509411658559, 0.02538958956886615, 0.07121882521148239, 0.06958406471780368, 0.04362246673554182, 0.040595101325639656, 0.06141096792582955, 0.02307427711119609, 0.02341818919272295, 0.06510014925152063, 0.01588960736989975, 0.032902183410312445, 0.03754773609606283, 0.010642797170606042, 0.05051558863903795, 0.03872900449537805, 0.07933976301657301, 0.017120020364278128, 0.03721305548346468, 0.009793170395174196, 0.022588619064273577, 0.02285138514292027, 0.04203020628275616, 0.012174447482850934, 0.019944334169849753, 0.006463590576978666, 0.029667525552213192, 0.04518903785252145, 0.020655416817005192, 0.03591925883665681, 0.02188979584856757, 0.015388614431555783, 0.02825654251500964, 0.01888934283384255, 0.011593633381250714, 0.02870521361806563, 0.008985999555859183, 0.021916657353618314, 0.009189269987733235, 0.042607341028217754, 0.061600129918328354, 0.024075871133910756, 0.04875521095735686, 0.025794320440452014, 0.009744359130438949, 0.02423056185112468, 0.05207094357215932, 0.035869413654186895, 0.06459901721349784, 0.03446990803682378, 0.0089576138915228, 0.10089276970497199, 0.015285879140719771, 0.018154967775834457, 0.02651911458399679, 0.07551053884838309, 0.04403633917016642, 0.05739283960844789, 0.10614033562264272, 0.007045164213715387, 0.07335534199540104, 0.02722502509797258, 0.0790593855615173, 0.060021565694894106, 0.030990031015660082, 0.07311415672302246, 0.05182366844798837, 0.04688513112653579, 0.05437749783907618, 0.05506604803459985, 0.05788679953132357, 0.002972153015434742, 0.04676699139443891, 0.045630492735654116, 0.01912231443982039, 0.07570557695414339, 0.011048755342406886, 0.07173370436898299, 0.04685329087078571, 0.06416202709078789, 0.0183797308044242, 0.01489137888087758, 0.019565438519098928, 0.014652617674853121, 0.044901508638369184, 0.03804939739140017, 0.05784044201884951, 0.031149323896637986, 0.01695842046423682, 0.046124632470309734, 0.013911139203368552, 0.08518710639327765, 0.04294244572520256, 0.00543870753608644, 0.02745748101733625, 0.027983946160280278, 0.0374107975512743, 0.005694656034133264, 0.04517495146553431, 0.01378283671302987, 0.01922153661559735, 0.035718069810952456, 0.01646417216397822, 0.0262918138344373, 0.05671799921297601, 0.04688358406669327, 0.038075042622429986, 0.02917927210884435, 0.05296459115509476, 0.030969522294721434, 0.021664673196417943, 0.04098624962248972, 0.01032631571537682, 0.055413756519556046, 0.038324349958981783, 0.030010979622602463, 0.040420429448464086, 0.020828283791031157, 0.03646506901298251, 0.07629600420062031, 0.0062624880644891944, 0.04332726329032864, 0.024137933339391435, 0.03425177599170378, 0.04034306967098798, 0.022243178582617214, 0.02918427630460688, 0.12666496820747852, 0.012064637616276741, 0.03607648897117802, 0.040807842410036495, 0.04984898905136755, 0.017546593278114284, 0.04572017131639378, 0.01631129313526409, 0.042595877179077694, 0.008324261671597404, 0.03802085142316563, 0.06331072348569121, 0.03301609247656805, 0.012174806258242046, 0.006134936627599278, 0.021073452063969204, 0.023971466646928872, 0.048816954251378775, 0.05232854939198919, 0.06000179996980088, 0.0667562157447849, 0.026536837918683887, 0.07537933053182704, 0.04633930737950972, 0.15746570830898626, 0.01548254064151219, 0.013283356059608715, 0.04067321427698646, 0.018624985590577126, 0.018131694024694816, 0.06080317696822541, 0.023374896962195635, 0.07122531879161086, 0.02985170709767512, 0.029571706229554753, 0.017681643799213425, 0.04055871827793973, 0.022295664962647215, 0.02453331908743296, 0.021276317071169615, 0.03295943480251091, 0.026450153373714005, 0.0337315601562815, 0.027082044198842983, 0.06965744149472032, 0.004974367363112313, 0.034081548518900356, 0.013523292827552982, 0.052573697308876684, 0.04330533303852592, 0.03478237341291138, 0.03666746922369514, 0.014957575060959374, 0.022488385871318833, 0.02825624735227653, 0.03255145883719836, 0.06204564244087253, 0.022169674580384578, 0.010486944462172687, 0.01581736883547689, 0.03381875869152801, 0.04928578123716371, 0.03477033959435565, 0.06993259423013244, 0.009638377049538707, 0.04122684796207717, 0.018733756450404013, 0.00441717221734247, 0.04336957673409155, 0.01682051331070917, 0.04625075177422591, 0.026242587815171907, 0.01564139417106552, 0.07095061388931104, 0.024592924996146133, 0.020173158230526105, 0.10234617814421654, 0.012309451354667544, 0.03285899804905057, 0.006681301082218332, 0.01266709019962166, 0.018948685810235993, 0.01356786918560309, 0.03307200715477977, 0.035512826538511684, 0.05161818090294089, 0.049119716576699696, 0.015103673828499658, 0.019184793944337537, 0.05132458219304681, 0.042218730452337434, 0.050427063567829986, 0.05757784218128238, 0.03373451517628772, 0.06938500289938279, 0.015605253699634756, 0.012867566763556429, 0.05527387313278658, 0.07824409180986029, 0.036008034965821674, 0.008866495968374823, 0.005113190962999527, 0.026548634249983088, 0.024176051740401557, 0.025983132987416217, 0.010206137833717679, 0.07250701037368604, 0.07390510463821036, 0.13935976129557404, 0.09030794911086559, 0.15118305757641792, 0.24513830883162363, 0.13198320354734147, 0.07220812926867179, 0.21239827493471758, 0.09852781053632498, 0.11801053902932576, 0.15554347288395676, 0.12858903567705834, 0.17949069717100688, 0.09224128536880016, 0.12641629869384424, 0.11400478040533406, 0.06616266045187201, 0.23303150704928807, 0.1564604179667575, 0.1146768286292042, 0.11027933816824641, 0.21469141117164067, 0.11317484386797462, 0.14593092511807168, 0.1453221027872392, 0.10823291726410389, 0.14627667942217418, 0.09452598063009125, 0.1599036982016904, 0.08956632390618324, 0.10042377987078258, 0.0811932221321123, 0.06916593786861215, 0.16640372441283294, 0.1047260243711727, 0.17350247635373048, 0.1841565618025405, 0.12121353644345488, 0.1904976072588137, 0.12779190630785056, 0.1865924618073872, 0.11782333121768065, 0.15542528565440858, 0.1452743067805256, 0.15516890798296246, 0.11709063553384372, 0.08874067571014166, 0.09730616251805, 0.16534819533782347, 0.13590422671820435, 0.1040712787902781, 0.0853309626025813, 0.13412961337183202, 0.14072155393660069, 0.09230797179043293, 0.21743065704192432, 0.16443526718233312, 0.1290076103593622, 0.16900578407304628, 0.1619907904948507, 0.10604672493146998, 0.15665754596037523, 0.08578507894916193, 0.10587026511452027, 0.08521174399980477, 0.14174633180456503, 0.2629384265414306, 0.13626854574041708, 0.12539933754929475, 0.19274914929909365, 0.10527181079877274, 0.12528672787759984, 0.13419072223561151, 0.14525294649813855, 0.15450097168130533, 0.13639923158500875, 0.09152617731264659, 0.1228335795125791, 0.1483095839087452, 0.1674357218933957, 0.11043570656329393, 0.11013452522456646, 0.24295239469834737, 0.08747399332267897, 0.09279064767594848, 0.13249218623553002, 0.1971160921135119, 0.15230688798640454, 0.11460737378469535, 0.1608200461736747, 0.09805007438574519, 0.12697420375687735, 0.11702077356832367, 0.17678009904921055, 0.11786147845642907, 0.0661713524854609, 0.10335088494632926, 0.11797710082360677, 0.11660133036119597, 0.15511727146804333, 0.10119365927364145, 0.10826901532709599, 0.12202278444809572, 0.11058857371764523, 0.0959402240280594, 0.08944931054221732, 0.14175617056233542, 0.10352893253522259, 0.13549648145479815, 0.12831549106964044, 0.14812286464231356, 0.15286606869527272, 0.07224630364882094, 0.10684541493122067, 0.08090762674276318, 0.10425782163760491, 0.17982415642057145, 0.18059604428708553, 0.13174760261816637, 0.08331393583544663, 0.16275913640856743, 0.19423325466258184, 0.10950499400496483, 0.07698020498667445, 0.16240776383451053, 0.15251180556203636, 0.08266394678503275, 0.14655068543340477, 0.12417372688651085, 0.13536812977067061, 0.1212706012385232, 0.10961517452129296, 0.12584046673561844, 0.11934593665812697, 0.14426836504467896, 0.08376259676047734, 0.1453942989132234, 0.07498118653893471, 0.15915569476783276, 0.1666022909006902, 0.12033026026827948, 0.10936515472297158, 0.12915506958961487, 0.1104629293882421, 0.11858597743724074, 0.22131982977901185, 0.10308129619807005, 0.09483588792915855, 0.15203565039805003, 0.11366400654826846, 0.10203026581023421, 0.08042575831391982, 0.08150169093694005, 0.09667421571378197, 0.17072307478104318, 0.1119540168770722, 0.11182787043175527, 0.12996966445020267, 0.10396788362413645, 0.08411633742174932, 0.13598459240581307, 0.12147823295422963, 0.06223647362951722, 0.13161731032388552, 0.1617250626108476, 0.13015456524278435, 0.22702335087316378, 0.13812252054257051, 0.09024048237396137, 0.16711469340537274, 0.05867356088544641, 0.1798560611371483, 0.08669562544673681, 0.13788651249238423, 0.10105428139546088, 0.14788146902407917, 0.17834040389529296], [0.07128606803183045, 0.020562800179634775, 0.006475301667316151, 0.031031296122819185, 0.008831193487692093, 0.03210346626916102, 0.008152063902733582, 0.02192019421740302, 0.04022953040631754, 0.029738222115806172, 0.02085796800175948, 0.05510934196146471, 0.05132430399368916, 0.023265383106523325, 0.01844597278561975, 0.05187047379357474, 0.01884660360935543, 0.01831532595679164, 0.06220686914665358, 0.007496839954650828, 0.05139488859900406, 0.027938007643180232, 0.005309624306391925, 0.029428291068013226, 0.0557099777672972, 0.040062492048101764, 0.01648241118527949, 0.013648016045668294, 0.07637725198375327, 0.01204524508544377, 0.03542277815618685, 0.03977739877466645, 0.014434718027977007, 0.027836466573977044, 0.042944189560200484, 0.05835914811385529, 0.050850360853863616, 0.04829591738858393, 0.01256708346772939, 0.008459845690854957, 0.009369119087101092, 0.03990513977727719, 0.03619689840291228, 0.014147766416759362, 0.03445948573893734, 0.019652910164690444, 0.03734380918155823, 0.051017582416534424, 0.013358743844686874, 0.011426937683219356, 0.09405413416347333, 0.06361271906644106, 0.039446640094476085, 0.017978645362226025, 0.04597094768126096, 0.047810222022235394, 0.02377009780944458, 0.04993155658511179, 0.009711187249714774, 0.020534104933696132, 0.006266874369300369, 0.04621515582714762, 0.0064796710087518606, 0.055630592562790425, 0.01566614373587072, 0.02840503990384085, 0.03504731419629284, 0.04141908371821046, 0.057188003457018306, 0.03301146147506578, 0.02538989151694945, 0.06887547738317933, 0.0316362847307963, 0.021192497640315975, 0.012411310487160725, 0.07222265670342104, 0.09227663704327174, 0.07366092702639954, 0.07556663333837475, 0.04909172700718045, 0.020930808736011386, 0.0199046754943473, 0.038094777813447375, 0.06250615058732883, 0.041170017261590273, 0.024321027532485977, 0.02568168532369392, 0.024231342166396122, 0.027264202013611794, 0.05625960809577789, 0.023813003275011266, 0.04119380669934409, 0.020044669143057296, 0.05140624388254114, 0.047610559700323005, 0.012623499413686139, 0.02218797636617507, 0.03930089755782059, 0.06411049235612154, 0.04025145387277007, 0.03476202075502702, 0.0666793038004211, 0.026903733677629913, 0.03840840009174176, 0.0300962545110711, 0.042351275482880216, 0.019403833530044982, 0.018590215759884034, 0.014150379624749933, 0.050511693848030906, 0.07305084262043238, 0.04264243485938225, 0.05988665257713624, 0.049892679921218326, 0.01512192133148866, 0.003313027592542182, 0.06880638894758054, 0.01840533871602799, 0.029853898765785352, 0.009205731247285647, 0.06487925896154982, 0.027926012840388075, 0.03750417075519051, 0.02559440366790763, 0.03100566446248974, 0.016231573752260635, 0.025543525415871824, 0.041262623720935414, 0.007952999539806374, 0.024161620996892452, 0.04182374503995691, 0.010261780249753168, 0.015749857993796468, 0.025195197767711112, 0.0542369189539126, 0.031416262965649366, 0.055691396085811515, 0.0728621148903455, 0.02318556872861726, 0.015222263090046389, 0.016471580070044314, 0.04422939934634736, 0.03521648993981736, 0.03905401259128537, 0.01937445466007505, 0.018320735577227812, 0.0033500715757587124, 0.060677376575767994, 0.04537974351218768, 0.008099668276762324, 0.036013269863490543, 0.08063287434301206, 0.03806363305609141, 0.03425531455182603, 0.010567301668093672, 0.026819783628785183, 0.02535784600435623, 0.051613515974687676, 0.0071014313060524204, 0.050373927490519624, 0.03908526591424431, 0.0396851960436574, 0.021220862100433027, 0.015752449997567704, 0.06750292317675692, 0.0442625152479325, 0.07102048264018126, 0.030529821424611976, 0.03734909496935351, 0.0318014537250357, 0.04349162143522075, 0.04410026395427329, 0.03592383894803269, 0.01373623323161155, 0.051335177517363, 0.040372124540486505, 0.0455038373890732, 0.010479267686605453, 0.04603723715990782, 0.011533402372151613, 0.026831006597993628, 0.019847018677475195, 0.028778271483523504, 0.054927823665950976, 0.06684598592775208, 0.03479168291336723, 0.03651487009067621, 0.0598618724782552, 0.059040424413979053, 0.009998315280037267, 0.006913277362140694, 0.028323559722464, 0.04894155702952828, 0.022070591504286443, 0.03453257753114615, 0.03990064448277865, 0.016455398706187094, 0.049431649302797656, 0.02809730391683323, 0.007992491974229259, 0.0639346500060388, 0.04416174940498812, 0.027339621180934564, 0.025859196869922534, 0.02300582649851484, 0.050609996608857594, 0.04397696735603469, 0.030568504706025124, 0.029703827175710882, 0.03288836504465767, 0.043107750426445685, 0.03316584854785885, 0.022174419236502478, 0.05830932328743594, 0.05187078931235841, 0.005647781138707484, 0.031017515076590434, 0.012409052661886173, 0.01902695991364973, 0.012308239321490484, 0.013040476146021059, 0.030351434568209306, 0.009647125910435404, 0.051174727734178305, 0.05494051905614989, 0.07675725195024695, 0.03924604139423796, 0.08318738226911851, 0.04749209427141717, 0.032985561793403964, 0.08225801321012632, 0.009918684954755008, 0.016529935777985623, 0.04792971882436957, 0.05332435042198215, 0.017201819457113743, 0.04892532307920711, 0.011830384427282428, 0.016813884023576975, 0.04933774344889181, 0.0231165939476341, 0.042458154926342626, 0.03119788325524756, 0.027769374727670635, 0.04188033486051219, 0.05308583518490195, 0.032497111574879715, 0.06954139165048089, 0.04040107423705714, 0.024399756254362207, 0.02886028940390263, 0.028527712249862294, 0.030954750587365458, 0.05324437828468425, 0.017503072042018175, 0.025535447456474816, 0.023763790826446245, 0.033998560293444564, 0.017305029722462808, 0.017074151397017494, 0.029795049423617975, 0.036135358669395955, 0.07669952219086033, 0.014682944797511612, 0.026562053976314406, 0.03250967804342508, 0.01099652935019029, 0.026015227693798285, 0.012975830418456877, 0.026210518553853035, 0.029164052568376064, 0.033162330343787155, 0.04611603203894837, 0.04833753194127764, 0.03686472613896642, 0.0167038510886154, 0.039839067429836304, 0.03198907544304218, 0.06980614244405713, 0.013167154393158853, 0.010160093295520969, 0.0390175481193832, 0.031106481195560524, 0.07600775573934827, 0.011247315893082746, 0.021131326012047272, 0.03998740875561323, 0.054060822153197866, 0.02614774219026523, 0.07866272077496562, 0.02868014174912657, 0.03548682846927217, 0.026201972405293157, 0.016348205440278565, 0.07212504265563828, 0.03968520961435778, 0.0200898239522108, 0.056577630673668215, 0.046083384326526096, 0.030663126414375644, 0.06348554803324596, 0.050137834623456, 0.02392992334041212, 0.016610937592174326, 0.06643586579178061, 0.05797530085380588, 0.016966279596090317, 0.0735018037791763, 0.02161264991653817, 0.10302231793424912, 0.013504012254998088, 0.03949790680781007, 0.017508904050503458, 0.036401941507522545, 0.004707051707165582, 0.08478908453668867, 0.0384655123842614, 0.033021748065948486, 0.05105264910629817, 0.02902581123635173, 0.01711446825148804, 0.013029007207868355, 0.020806796283328106, 0.005431056629666793, 0.06415950294051852, 0.009513643653398114, 0.0407812336592802, 0.024226863835273043, 0.0072777638976861325, 0.04012152459472418, 0.02409687518541302, 0.04393557671989713, 0.0914152232663972, 0.052961958439222405, 0.022670502973986522, 0.0495916750015957, 0.03907341190746852, 0.055458129317100556, 0.029047351330518723, 0.018347196746617556, 0.06564976940197603, 0.051193787782852135, 0.03994850834299411, 0.0345361160912684, 0.01980277310524668, 0.03315751613782985, 0.038465054373123815, 0.018586353199290376, 0.010773169192751604, 0.03982804123578327, 0.027193373135690178, 0.05373801929610116, 0.1569990390645606, 0.10496240561561924, 0.1522450598755053, 0.12482114428920404, 0.11766026568199907, 0.10558508363153253, 0.15749709733894893, 0.11462620991681303, 0.13802798704377242, 0.11362352514905588, 0.07332999871245452, 0.16470365492360933, 0.1524790594620364, 0.07997726702264377, 0.10786694261644568, 0.11866231262683868, 0.11558738191212926, 0.07798415861491646, 0.09521495830267668, 0.09537622572055884, 0.13862926406519754, 0.15025745438677923, 0.05555961101448961, 0.07763835002801248, 0.12191598303616047, 0.11529679250504289, 0.08071457674460751, 0.07813859318516084, 0.12283478730491229, 0.11719493993691035, 0.09869947311069284, 0.14747337092246326, 0.10121453779616527, 0.1273596930716719, 0.1371757606310504, 0.13466522177415235, 0.25206962547131945, 0.17961640256856168, 0.09757410242621388, 0.12694391395364488, 0.08363529002027852, 0.07629651988723449, 0.09715683731649603, 0.10098281130194664, 0.07092986428844077, 0.10232280939817429, 0.12780888325401715, 0.16779112496546336, 0.16400160188121454, 0.18465148524514266, 0.18819930058504852, 0.18122698685952596, 0.103840590454638, 0.14243602193892002, 0.3592391290834972, 0.08223088538008076, 0.13233870161431177, 0.13233830806400093, 0.10099298932722636, 0.09160729617412601, 0.13159801278795513, 0.15430779276149614, 0.09449205387915884, 0.10798348100589854, 0.09611425468964235, 0.15130858655486787, 0.12409550536956106, 0.10213140145476375, 0.18453080100672586, 0.26574009763342993, 0.125294083197202, 0.19578749340559753, 0.10043553888265576, 0.08506783350769963, 0.16328519103782518, 0.16572642432791845, 0.18147263010697706, 0.20286837273410388, 0.17947973204510553, 0.1548287719488144, 0.07492564844765834, 0.07955071955387082, 0.15035219144608292, 0.15735611133277416, 0.12225447701556341, 0.09928780368396214, 0.13921565402831348, 0.11518761622054235, 0.18254421332052775, 0.09838419181427785, 0.11296105783964906, 0.08112427618886743, 0.11256625902439867, 0.11701918579638004, 0.17026439867913723, 0.09240485302039556, 0.10765181987413339, 0.1837136141423668, 0.2089997780110155, 0.07724190237266676, 0.18118377774953842, 0.12799231841095857, 0.10439833266926662, 0.1344088983855077, 0.11365532808537994, 0.21935903999422277, 0.08187235426157713, 0.12027219124138355, 0.08520079244460378, 0.10080633791429655, 0.15727442928722926, 0.09467209636100701, 0.08336163006190743, 0.11560161757682051, 0.1588920567716871, 0.13359483278223447, 0.1891944943261998, 0.10221412844423737, 0.2224602164434535, 0.1337451690009662, 0.14603258323456558, 0.19776519228305134, 0.11008261729563985, 0.09858575064156737, 0.17385131120681763, 0.16836357781929628, 0.0973714172307934, 0.10430457270038979, 0.15162713160472258, 0.16243763294603142, 0.0833488939596074, 0.09855821569051061, 0.06668576345379863, 0.1719642781785556, 0.17149652327810014, 0.16752595348017557, 0.12014440952667169, 0.11905768141150475, 0.08870412981403725, 0.16576272595141614, 0.12025373508887631, 0.11719522492161819, 0.16133400930890016, 0.12868618832102843, 0.057041487390441556, 0.09944546808089529, 0.1134447515276926, 0.10595957389367477, 0.10377355119479553, 0.09005083862159934, 0.1025755297658699, 0.12534566542931966, 0.08234909975102969, 0.12070140535277979, 0.15126834942826203, 0.12843245693615504, 0.12103357538580894, 0.20252936306808675, 0.08600562997162342, 0.1613826738404376, 0.09017249995044299, 0.20705817719655378, 0.06507939286530018, 0.08810575013714177, 0.08336356388671057, 0.18836987071803638, 0.2165132641260113, 0.13407281999077114, 0.09392849661942039, 0.13857553766242095, 0.11740596432771001, 0.08070049714297056, 0.1051311097773058, 0.12612125809703553, 0.18907598139984266, 0.10126157384365797], [0.006689509235522044, 0.04729779916150229, 0.0005006845229737726, 0.02804287862298744, 0.03364085020231349, 0.038027633380677016, 0.06869424067969833, 0.023001037737620727, 0.0295497454436762, 0.05940426167632852, 0.02551787848850446, 0.05768948833325079, 0.04240689499835883, 0.0310919334047607, 0.0349386977031827, 0.026020593209458247, 0.007509962821911488, 0.017479106185159514, 0.042489954469991584, 0.03369185907234039, 0.04135755416271942, 0.03675756510347128, 0.011698246517750834, 0.03413321556789534, 0.07493527007422277, 0.04560217746932592, 0.05069836900968637, 0.05781146178820303, 0.007516598046225096, 0.06146394794008561, 0.04335631476715207, 0.01990923864234771, 0.02885139041713306, 0.006756164274910199, 0.015575980002592717, 0.027654810875122036, 0.006589718786666968, 0.12288385895746094, 0.08600544676716838, 0.03148871354226555, 0.02973280062100717, 0.004710256512875536, 0.06603224602128778, 0.004217109559769077, 0.047469353170267174, 0.031014210611049618, 0.020460745120154958, 0.012611646255079125, 0.047019884788564274, 0.09243901047323431, 0.05019889598978417, 0.04259948020002671, 0.014216323898706053, 0.009958413180096872, 0.042857951152005365, 0.03693688155284949, 0.053226909400629144, 0.022997904602172117, 0.015568609415952648, 0.025046467980636016, 0.03431733604520559, 0.031969686304884296, 0.01683534269354173, 0.02609182072670332, 0.04567456358511533, 0.03381474515689271, 0.027459893209327544, 0.011103557223188025, 0.018542211103652204, 0.02747334855874734, 0.05022645808224167, 0.029491496605000327, 0.022309306909197142, 0.07371066364326648, 0.033296469931623766, 0.021979813696816564, 0.03442700766026974, 0.056613599815006764, 0.06564533856830426, 0.027543179990191544, 0.021212629774319272, 0.04893099902463811, 0.027597081115735427, 0.05024164030328393, 0.08574785451803889, 0.06935594124453408, 0.050044264644384384, 0.037496747582086494, 0.02590659593365022, 0.05680368122245584, 0.01703911184865449, 0.04569751163944602, 0.042086076856191666, 0.007460917462594807, 0.029827401973307133, 0.031120628650699343, 0.036481937393546104, 0.02773020968639425, 0.052857022998588424, 0.030893085324870687, 0.010995359725451894, 0.024473494351176277, 0.07422883369560752, 0.018479024226378118, 0.05580476571672729, 0.045887365737663846, 0.05670368890943272, 0.03501746883349759, 0.03854415798559785, 0.009849117303799306, 0.03674373995246632, 0.04303693511922445, 0.0022787258494645357, 0.010123341294404651, 0.012007209804973431, 0.029297917349530116, 0.050387396410639794, 0.026978572697511742, 0.0047035432570347825, 0.032273625888462575, 0.015736487461254, 0.02474097115918994, 0.018360273812764456, 0.06520671996154956, 0.031826444169772525, 0.01806826117847647, 0.0371528558566102, 0.040337369976831336, 0.04018996502938015, 0.01966924759160195, 0.033381605720413585, 0.0352979005713548, 0.09155369190765278, 0.039014484533774, 0.045868770485477786, 0.028299358074686358, 0.04537303958620344, 0.028689726056264978, 0.064403850186084, 0.03250260431585567, 0.04980859246903232, 0.037192003934511116, 0.055297486151435545, 0.04321879607492259, 0.04308733670040965, 0.08235601402286973, 0.07728439223553453, 0.01871316460892558, 0.028643175161310604, 0.025675754927630936, 0.03327035311875599, 0.03156305383890867, 0.08382576158536331, 0.0632717212928193, 0.00705103184528915, 0.04087028120245252, 0.02593057875388435, 0.06855199938373906, 0.010308247175998986, 0.007935830907497023, 0.017598682715158378, 0.023523669157709395, 0.028687544566180025, 0.02309757630739893, 0.058335786153163226, 0.04585772732804928, 0.0479318121049021, 0.0325980775856546, 0.03649908058079226, 0.01970676888179566, 0.0086087773420981, 0.03175814622747047, 0.014905753645247646, 0.036444424585040124, 0.022906360050131167, 0.06516314444265195, 0.04439207811706832, 0.021788738235565167, 0.058043500408530235, 0.029811632819473743, 0.020171000489166806, 0.026245147588529756, 0.02331730630248785, 0.08757997370724167, 0.04367738735995122, 0.035062533736761124, 0.02045122018483068, 0.07344740562673126, 0.05299436866438814, 0.06854828101183687, 0.024477114335500767, 0.0072058357930343065, 0.049919186891721826, 0.009707264469138213, 0.052271128366036076, 0.019637967127242258, 0.014828636444040706, 0.02133060496167413, 0.038193793036043644, 0.07892578201634542, 0.06449077730732304, 0.09179496538958379, 0.03724071935617498, 0.015102983419118183, 0.031856320066643615, 0.009940034210948008, 0.04886406833039863, 0.048517611742551835, 0.030821625409381728, 0.019866740297792212, 0.015711790482912744, 0.017318973617096032, 0.013388132892682083, 0.04524011118337512, 0.029672251548618078, 0.04574776394292712, 0.026554605358147194, 0.08039897653673377, 0.04745351277025683, 0.0029908154849960867, 0.07168678367244345, 0.022310496041817323, 0.03369170640196119, 0.024385278013401797, 0.014639628818258643, 0.010109825725001948, 0.03672206415129559, 0.04991771786340645, 0.05327236106885331, 0.06603238172829151, 0.0449996451581163, 0.08154527324118785, 0.011833503992030663, 0.02747961143696947, 0.06063829295869384, 0.028997377226395265, 0.04835398641547986, 0.05632338699485574, 0.041988944568272145, 0.011184482702187129, 0.011457329266704619, 0.008987121683146273, 0.049255046993494034, 0.030060431254761558, 0.003621201870763408, 0.035787100571074655, 0.04007637148190822, 0.026175311068072915, 0.052560513373464346, 0.021864488188709532, 0.04641907595630203, 0.03788011647494776, 0.03119632601737976, 0.019247778957443576, 0.02573487738014332, 0.030100318935832808, 0.042702885544193644, 0.017804356857335994, 0.02280877823276179, 0.042782223251249106, 0.041146112472883294, 0.04630122799426317, 0.0343768232102905, 0.03327377972060016, 0.008196662313171794, 0.06598171551844903, 0.00874114256086094, 0.024807649099134972, 0.017417004963915263, 0.019508249891389693, 0.05518018101741161, 0.05203193459393723, 0.024626571851383363, 0.014687748825443643, 0.03389560956774013, 0.036618407749171765, 0.018670238787308335, 0.012437233069379414, 0.050036804151854346, 0.0448703231689121, 0.043753841293177435, 0.03585088964817779, 0.017479258855538707, 0.05632759391197136, 0.045394250590886386, 0.06705322409314768, 0.016204045586554066, 0.039649505101676495, 0.058836232870817184, 0.030245311691292694, 0.025281906061406647, 0.03258230843182121, 0.048420126616422615, 0.019790059055334756, 0.01702100514168186, 0.041465342843106816, 0.021309068260182227, 0.021932926927027956, 0.04020842118188739, 0.06049622129648924, 0.06724083902580397, 0.045763651840388775, 0.049309828518224616, 0.010765529736610395, 0.06796825570719582, 0.09128269859190498, 0.028238388310585703, 0.09939659998885222, 0.07655363037650074, 0.05163277279851692, 0.03152792268831815, 0.0033481589551748975, 0.05060262432587998, 0.04625990181895239, 0.06137847288378647, 0.04527017367737634, 0.01624855409110231, 0.04098854646352785, 0.03455942376915898, 0.011882014156851386, 0.05146609406386103, 0.04312937194481492, 0.02190273890404829, 0.05651187723768609, 0.0792586984378951, 0.02821031222785158, 0.013872508508419352, 0.0256217537181718, 0.04419782371925456, 0.02252957464328834, 0.03194054322583335, 0.022361937477918606, 0.07191246441964592, 0.09346619714051485, 0.08842757929648672, 0.04264440939628652, 0.09923521722001688, 0.019464686246854917, 0.00523367418541706, 0.03357889995511089, 0.014988989535985249, 0.009620840311981738, 0.050530926923134496, 0.027211739382307445, 0.014509477319994142, 0.061306928151420186, 0.010720683660890375, 0.038635088463446925, 0.02759957473192896, 0.022493907450033084, 0.0666885454473751, 0.07463239918329886, 0.08008717612496444, 0.10448324454150029, 0.09476630416299615, 0.19603030037667069, 0.1305431622479643, 0.12454172356852464, 0.099451934519623, 0.1531834602355957, 0.10512351697044713, 0.21015578455158643, 0.12965688694800648, 0.15449981817177363, 0.14121075054364546, 0.17469190752932004, 0.11981318944266864, 0.13835432167564118, 0.11570661408560616, 0.08129998961729662, 0.21318984031677246, 0.08851062519741909, 0.109361931681633, 0.1069489186629653, 0.12662015775484697, 0.15145580151251384, 0.15023015013762883, 0.17378366126545838, 0.0896356226876378, 0.1466200588537114, 0.06601106894335576, 0.17338811606168747, 0.13065379059740476, 0.08006262672798974, 0.10320968180894852, 0.07889059319027833, 0.0812414116891367, 0.08986863161304168, 0.13160584308207035, 0.1754629947245121, 0.15921950420098646, 0.12910350092819758, 0.08430979454091617, 0.12551179794328554, 0.07229355004216943, 0.09273733517953328, 0.11091664539916174, 0.1059404324207987, 0.15264568052121572, 0.0626620507932135, 0.10565388029707329, 0.19878550539059298, 0.1728678425507886, 0.17035435885190964, 0.15636481238262995, 0.1428171686295952, 0.0832591305619904, 0.21055021695792675, 0.11454786626355988, 0.11118934183780636, 0.12877906619438104, 0.13082251511514187, 0.1231436835868018, 0.08480981378150837, 0.08724641946277448, 0.10978878449116435, 0.15659659994500025, 0.054349776290889294, 0.14625248286340917, 0.16732049307652883, 0.07385557158184902, 0.12026151110019002, 0.15823948250285216, 0.13779792296034948, 0.16554188994424685, 0.1906069056796176, 0.10890134211097445, 0.1580969494368349, 0.13867600155728205, 0.14146091283432075, 0.12340377963015012, 0.095540112283613, 0.15557882455842836, 0.09621954975383622, 0.09872337111404964, 0.0877763485269887, 0.13966773476983818, 0.15272167644330434, 0.20005846422697815, 0.15622625553182193, 0.10888496227562428, 0.18567078055015632, 0.08425682809736047, 0.08811851338084255, 0.11310471048844711, 0.17035035549529962, 0.17768396197685174, 0.19680008478462696, 0.1579638615782772, 0.09741191220070634, 0.14317273455006735, 0.1515647199537073, 0.10972492077520915, 0.19575978203543595, 0.09205559747559683, 0.19379367253610066, 0.11545244843832084, 0.13013135934514658, 0.11911680895302977, 0.15701535104640893, 0.09554644301533699, 0.14963071873145445, 0.10540114635867731, 0.20632263166563852, 0.16305979527533054, 0.18567411894244806, 0.12284538602190358, 0.1488025260290929, 0.15637379618627684, 0.13615505397319794, 0.19409414141305856, 0.1020115450290697, 0.1195840345961707, 0.11100697198084422, 0.07842674665153027, 0.2606334430830819, 0.14672567961471422, 0.22539177270872252, 0.2159278919654233, 0.0776670520593013, 0.10836326384118625, 0.1348050135586943, 0.1124928415353809, 0.19191216278289044, 0.19113631227186748, 0.1577260350542409, 0.12986776206110204, 0.07449543010443449, 0.14901317044028214, 0.15017134829291276, 0.16478387133351394, 0.1544869260064193, 0.20814407749899796, 0.08929664694837161, 0.15958594025245734, 0.06218958007437842, 0.15098686596112593, 0.13699092769197055, 0.14873609745076724, 0.13923079892992973, 0.14561577274331025, 0.06042724821184363, 0.1412912519382579, 0.11373705084302596, 0.2370325294988496, 0.12677417163337978, 0.1070036900096706, 0.1908808709787471, 0.14123171727572167, 0.15827152292643273, 0.18115696204560144, 0.1195328730557646, 0.12596648425928184, 0.060076269188097546, 0.1068367093269314, 0.13006817416421004, 0.14516328488077435, 0.09342021960765123, 0.19140058809093066, 0.09043177496641874, 0.07257615309208632, 0.11543103387313229, 0.15607567504048347, 0.09108174366078206, 0.093637615442276, 0.09904505099569048, 0.1853457215641226, 0.12082290383321898], [0.08059297648391553, 0.005206469596097512, 0.04117272800898977, 0.019519689991804104, 0.021288033674604127, 0.04310305496411664, 0.059911079837807586, 0.026834814875785793, 0.05396439214902265, 0.008383461307468159, 0.03880400975633945, 0.06914222985506058, 0.04959721863269806, 0.02847334463149309, 0.017425081226974726, 0.046161931540284834, 0.02718439951006855, 0.017408312930326377, 0.04036772084821548, 0.06493873255593435, 0.03825720213353634, 0.025785979548735277, 0.02320255246013403, 0.011838165527608777, 0.025754695691700493, 0.0073084294396851745, 0.04645191705120461, 0.0821761479601264, 0.032034228555858135, 0.05193197281498994, 0.013711594776915652, 0.06387833838484117, 0.05718475327427898, 0.023530084706310714, 0.04322500127766814, 0.03178870744471039, 0.04610219331724303, 0.051541435199656656, 0.015496742379452502, 0.008377508010848292, 0.025515205060530986, 0.05798263581735747, 0.06571139395236969, 0.04889838523896677, 0.045752130315772126, 0.011346148759392756, 0.06071050265537841, 0.0651926403599126, 0.005073379617117877, 0.008926777019431549, 0.04833743355369993, 0.02179431070440582, 0.023346875162263, 0.04665537238387125, 0.037334553963903866, 0.025142428099310825, 0.02121964413007455, 0.03608435658471925, 0.07353788827146802, 0.03330741130879947, 0.03607778497306364, 0.029078760716531957, 0.01721685579312699, 0.10523795868669238, 0.055528825880693536, 0.031055770880941833, 0.08626448429588761, 0.02786850699755762, 0.012187657711495246, 0.029163665803415433, 0.05184305080079606, 0.06014365450079952, 0.02416440299046891, 0.013323974862162555, 0.03568301669188908, 0.0686809006812317, 0.01795054892344134, 0.08133677300065756, 0.016434392958347286, 0.03322254693401711, 0.06285119242966175, 0.024707517686433027, 0.022339081025815437, 0.019425466922777038, 0.0407277142096843, 0.030890798661857843, 0.007345535127179963, 0.10656042343803815, 0.005872998361675335, 0.012381070725885885, 0.00918699604725199, 0.030840135844690458, 0.04382953865985785, 0.046861728453742604, 0.05148958494620664, 0.04265528291996036, 0.02161610874879573, 0.026159618249429122, 0.01841252270553793, 0.08894436513738972, 0.004758558028178024, 0.05487124402342098, 0.01651880780367979, 0.029886180069297552, 0.03881067975557276, 0.04013226580406938, 0.08141042119158165, 0.024200482393747995, 0.00856774632952043, 0.008970502664202025, 0.042051166229482205, 0.0075692294631153345, 0.007045481004752219, 0.017820534828518118, 0.04657821955957583, 0.05907285160252026, 0.03698841289484075, 0.02160123865386205, 0.04477284482813307, 0.016697539016604424, 0.029817213770002127, 0.024865674021254693, 0.024656515601756315, 0.02423730818554759, 0.03207281005701848, 0.013514789087431771, 0.021147727899785553, 0.04742126200082047, 0.02434202140596296, 0.05010827424536858, 0.042942438939852376, 0.06957628192113978, 0.04522958031988569, 0.028432973494221057, 0.031905106734484434, 0.03407268345888172, 0.05066632519343069, 0.03907562053895422, 0.041284696465092044, 0.02181591186672449, 0.0011744477441035478, 0.1268092111817428, 0.01437220290037138, 0.029077264546815838, 0.03762783036966409, 0.03630170152921762, 0.009047814096058053, 0.008115232173752571, 0.038495975213923624, 0.047822496720722744, 0.020181371896926845, 0.011282853316515684, 0.014795316981949976, 0.07506862934678793, 0.060223382365490706, 0.0241043153218925, 0.008271714223415723, 0.04760230192914605, 0.028342175330700617, 0.053619150138859234, 0.043866050629211326, 0.008646352915093303, 0.06363327867750611, 0.011553031542072338, 0.01805540463621063, 0.06061379784452064, 0.01306327577081642, 0.0022123082973329084, 0.07740084920078516, 0.013049719489312597, 0.017702839536858455, 0.05011773980887873, 0.07926854398101568, 0.04862911879484143, 0.09048723163349287, 0.024473575775378516, 0.023642358503171375, 0.032839961749102385, 0.018759064110262052, 0.031880978029221296, 0.03689013388273971, 0.004278381696037416, 0.024126813846773336, 0.026957500792507614, 0.08356692761714969, 0.016713756003550122, 0.03187924437224865, 0.04226444335654378, 0.043207349189157994, 0.021836736106446812, 0.01633248378389648, 0.07695873613868441, 0.03840450530073472, 0.0024929618313243346, 0.011143363480057036, 0.004522107233892062, 0.014500844658219388, 0.03219363678778921, 0.0297512092760631, 0.04961744236892887, 0.053065034693905284, 0.05260414656783853, 0.04657623823732138, 0.0564559964862253, 0.030389524131481136, 0.11614101220454488, 0.012935025866941681, 0.09458352718502283, 0.04348092772332685, 0.039405785501003265, 0.0291426990713392, 0.010075411277024873, 0.01307462087632822, 0.06223333201238087, 0.003106046634327088, 0.03232471618269171, 0.011038484866730869, 0.03701477398031524, 0.04207929489868028, 0.024170918622985482, 0.07079617253371648, 0.046015025316072364, 0.03340441806774054, 0.03128026758453675, 0.01818309983770762, 0.03461145383438893, 0.018264993925445845, 0.015365866545055593, 0.023317228270960704, 0.0716640188225678, 0.03520569784034576, 0.025780641174476062, 0.014639844253127064, 0.028255148125546317, 0.019353206335966076, 0.034323792305908034, 0.0462672266044787, 0.005824902951384762, 0.06206960829773119, 0.07992048721228327, 0.023410024720111063, 0.03625146279643689, 0.0014281830517575145, 0.03163707183141794, 0.047221704851835966, 0.019162307293819528, 0.016822121438703368, 0.05673907111798014, 0.033819525436099084, 0.03837842241461788, 0.05020525386290891, 0.062489132929061136, 0.028433947191972817, 0.03130868463111775, 0.008024498471058905, 0.03755194301317845, 0.015761781550411667, 0.09028638526797295, 0.03308081453932183, 0.025929813705650822, 0.06399415752717427, 0.019620252274242894, 0.03216692286410502, 0.0718253744500024, 0.024728572628061687, 0.02393149584531784, 0.03680597857705184, 0.026544177971248115, 0.03302757668175867, 0.045888546388596296, 0.03217489565057414, 0.025329023533101593, 0.03473749171410288, 0.020261863113514016, 0.01924080361745187, 0.013778137009856957, 0.05492811204333391, 0.0399466084449419, 0.03416858759841748, 0.01854308132481362, 0.04703464631789497, 0.0074844482088727605, 0.06838450979973588, 0.04360735576067652, 0.011912984191440046, 0.0018767519504763186, 0.021372984562601362, 0.04350191481145365, 0.048904916138521264, 0.06311153953096696, 0.02228590254006641, 0.06848438336913075, 0.002735380977225889, 0.03583799748282347, 0.044614125309245925, 0.01569056760386697, 0.06764839429940496, 0.0050628949788266, 0.02907234856060573, 0.0255329945523824, 0.01615084844109203, 0.0278225074123059, 0.06636038555630616, 0.08488310913422278, 0.023141618319121853, 0.06525226323200123, 0.03199922293424606, 0.047674803395888636, 0.02671450892064188, 0.0767995925354106, 0.041039853888962946, 0.022426593383508067, 0.015662793469216143, 0.03766164516231843, 0.07170535517590386, 0.0204009577033243, 0.05895752100540059, 0.06570397077926568, 0.04655521043709346, 0.020509428311405436, 0.024344224948436022, 0.06933200252907616, 0.050323268066027334, 0.014938230027577706, 0.02923794842458197, 0.07980979779469115, 0.046949150905545266, 0.02756910850959165, 0.05274467795555081, 0.027587720725153173, 0.04379972043846335, 0.0381834216282836, 0.03301879643861737, 0.05528576445898839, 0.010563942919751363, 0.0545164516328701, 0.035878539950187714, 0.024291903113148043, 0.05896596198103257, 0.02533383434638381, 0.03290082294760006, 0.052265438849904707, 0.05087657944698419, 0.060466426823820384, 0.042740109975316694, 0.03096654013331447, 0.06181553764534848, 0.034595297915594916, 0.056979150378278325, 0.02187933453491756, 0.005358570005877742, 0.02501373884401151, 0.13614046547029698, 0.12386044726840087, 0.12709832138248853, 0.125634762059365, 0.1484301867229598, 0.22891005820461682, 0.09400141877787453, 0.2201035828994853, 0.20241234291877064, 0.07483834813215903, 0.15178119976605686, 0.1780207460480077, 0.12114712143582956, 0.11149278269814593, 0.10135515739342996, 0.1587009813104357, 0.1734784697847707, 0.06910637606467519, 0.09245028093989406, 0.12452485518796103, 0.10026363882103137, 0.17911420523055963, 0.06667000108531543, 0.09209421290350811, 0.10259214708847658, 0.08328597340732813, 0.13110356431986603, 0.12869948760739394, 0.18428184650838375, 0.3098269876624857, 0.08508023712784052, 0.20073340301002773, 0.1437457845147167, 0.14600982517004013, 0.11119583541793482, 0.12847661599516869, 0.13222668905343327, 0.16201512276061944, 0.071449751034379, 0.15690696186253003, 0.12425490681614194, 0.1325012378926788, 0.1711991485208273, 0.07281873614660331, 0.14279806108347007, 0.12843305404697145, 0.1656883992254734, 0.09666332522673265, 0.11110214330255985, 0.18338402254240854, 0.18334968867046492, 0.09227781090885401, 0.16856291783707483, 0.1643110274204186, 0.12439343652554921, 0.07742998549448592, 0.08307312375732831, 0.10608500787722212, 0.1427903664963586, 0.11617018921034676, 0.10403234445090805, 0.056620242672839334, 0.19848612216966494, 0.17059830576181412, 0.10988952658538308, 0.10462540441325732, 0.1330104105706726, 0.07833929705832686, 0.11589946730860642, 0.09236125036009721, 0.1117709752704416, 0.09774730527507407, 0.08736911895019667, 0.17025514346148285, 0.11789668085319654, 0.1353677362203598, 0.10401183912264449, 0.20391744215573582, 0.06921252608299255, 0.1442592048219272, 0.21515197360089847, 0.17586647878800118, 0.09043099465114729, 0.10318926469023738, 0.1578077578118869, 0.21377460179584368, 0.07923089885818106, 0.19129746433879646, 0.10639351060880081, 0.17967930276479038, 0.14815525790410383, 0.08194016705134086, 0.153698291895645, 0.13600034798894609, 0.11473348630326134, 0.11932274433118956, 0.1304914578795433, 0.0902196377781885, 0.12918169530374662, 0.1581610981374979, 0.1495019599263157, 0.10224904585629702, 0.13909634043063435, 0.07863404588507754, 0.11584795292999063, 0.1373517183320863, 0.14953708089888096, 0.1918107353683029, 0.1275457880858864, 0.06997296706374202, 0.10265943740627595, 0.1439528734024082, 0.1572959931301219, 0.21546814377818788, 0.06646063910531146, 0.14206721101488384, 0.06144260801374912, 0.09759468917867967, 0.14655121469071933, 0.10883772266762597, 0.11359502667827265, 0.06530921267611639, 0.10703146244798388, 0.1311923981245075, 0.06968096630381686, 0.11644089754138674, 0.13436064097498143, 0.16475544071623258, 0.08742125758102962, 0.16588852634387358, 0.10690833548349993, 0.148372049842562, 0.21260767084147247, 0.15171467619282858, 0.1745115936334644, 0.12777772492596082, 0.10574142488517932, 0.1926854755729437, 0.13819364458322525, 0.11677793945584979, 0.14910539692001684, 0.1817562034619706, 0.11832581354039055, 0.06995151178645236, 0.13207287873540605, 0.19060561646308216, 0.1266251110604831, 0.15765938934470924, 0.09957150596060924, 0.16583131227110112, 0.08355038493339505, 0.12549009839338915, 0.16901426576077938, 0.15433260000177793, 0.15320173996899808, 0.12479293080312864, 0.16104208997317723, 0.15623633856219904, 0.0997330244364483, 0.1331899780780077, 0.187601646940623, 0.0739317439230425, 0.1559139665748392, 0.18208707070776395, 0.11979530325957707, 0.14408220217696258, 0.12404861859977245, 0.13395729261849607, 0.15671733846621855, 0.06538395330842052, 0.1308210901916027, 0.1337581697319235, 0.26012465038469856, 0.11335591772305113, 0.16367941988365992, 0.11477700753935746], [0.0387701474662338, 0.04321915230580738, 0.05659823099683438, 0.019851312107805694, 0.03708423561017428, 0.039387828071734736, 0.042382270962532075, 0.0251282077016575, 0.023188381256269555, 0.010304193777431334, 0.01160737541171589, 0.03237893791603191, 0.040693834956203184, 0.02185173681937158, 0.03612526546099356, 0.03905072508912001, 0.04020114050113729, 0.04582108982971736, 0.06467934218900544, 0.04259753958987338, 0.08102219059531178, 0.11021822930446692, 0.048831732744084935, 0.06983363668301276, 0.02615848170327289, 0.023107791652104685, 0.041158777329006364, 0.04733924408044134, 0.05388691702059337, 0.022182950118024434, 0.05874238469238792, 0.04635898150237543, 0.01574436355648296, 0.02517448039725423, 0.04354338347911835, 0.036833062302321196, 0.03551218532291906, 0.015212497274790491, 0.0457871834348355, 0.03823593684605189, 0.026997171342372894, 0.020993568136223724, 0.041076895115630965, 0.03130168893507548, 0.006774352406085069, 0.0274176187813282, 0.03195805282198957, 0.04313817932935698, 0.05756839018847261, 0.04794647524665509, 0.028065538299935203, 0.0037268913334368593, 0.0421710565819272, 0.07422998041978904, 0.021722136630809734, 0.01430666829193277, 0.015853558500696505, 0.024947442580014467, 0.05060377444273659, 0.01622739397654576, 0.019180363110665764, 0.04172405128234199, 0.04766594172854509, 0.06648500529783112, 0.02609771380334028, 0.02018217256824885, 0.02531190579091864, 0.04913962140147175, 0.009188206384091504, 0.03989999648183584, 0.03857368443693433, 0.046684030310383866, 0.07617434965712683, 0.03281535128397601, 0.08755230983453137, 0.04369178248037185, 0.04354888979079468, 0.036431447602808475, 0.05691012640350631, 0.03847078799403139, 0.04932452219405344, 0.07078729729567255, 0.03072867289717708, 0.04087933285960129, 0.02239610510878265, 0.037826223831091604, 0.040902243594505956, 0.038753004278987646, 0.04664653446525335, 0.043187895590173345, 0.017442767242235795, 0.03244448100615825, 0.08364002619470869, 0.021664466243237257, 0.035980798570173125, 0.04439708909818104, 0.13760848955384322, 0.09818785770663194, 0.01952815132348665, 0.07005114108324051, 0.030244273532714163, 0.04136297905019351, 0.021086820900174122, 0.023092616216412613, 0.029531659092754126, 0.024473027858350958, 0.033329691006136794, 0.07741272356361151, 0.03694760919149433, 0.016728486998804977, 0.03243096798126187, 0.03054464402209435, 0.05106705101206899, 0.02833881149334567, 0.012954803466397737, 0.017352440660553317, 0.04326389151226197, 0.10280517994293145, 0.062289562209376266, 0.05606060056015849, 0.013664835232443042, 0.03611071767019374, 0.03578469516443355, 0.05889803384031568, 0.04043353535234928, 0.038616513567311425, 0.07671637700072356, 0.018789379358557717, 0.03242274752951094, 0.016940274741500616, 0.024975742579304745, 0.08810144143977336, 0.05605922652674573, 0.05995312865291323, 0.031561113228755336, 0.029842536696898084, 0.07105734066239425, 0.03640670482335346, 0.045029548196388144, 0.05290878164981093, 0.0180773840818022, 0.06157562801880496, 0.03027605272031256, 0.02790216063814504, 0.08769225089677743, 0.0036961384300541666, 0.04625952183934195, 0.04205812799877354, 0.03646897058933973, 0.008777068445592054, 0.056260273060096164, 0.04859270182039056, 0.02156330006463187, 0.06682453065046243, 0.016318829962983727, 0.02766249019519559, 0.0776759951508471, 0.01991314021870494, 0.005051168621451194, 0.08801621065608092, 0.04552214765655143, 0.06853879509227616, 0.031164068462593213, 0.024347195235480155, 0.014226080384105444, 0.031062939603413855, 0.0644263911194035, 0.042832041292318275, 0.015464379651738065, 0.05006984541458743, 0.03946790538196053, 0.07246056465165955, 0.035590746107378175, 0.01274626505827265, 0.019298903178423643, 0.006065711636827993, 0.029142539615609815, 0.022028289934886352, 0.028857151179441383, 0.05300777651635664, 0.03738548480240362, 0.03789210618872728, 0.02269969355048878, 0.04039925237053207, 0.026266716520435045, 0.02295587444677949, 0.011103752302005887, 0.04373525282634156, 0.0774872809914606, 0.02493945283016988, 0.040336918751043935, 0.1006106755563191, 0.06721299194863864, 0.021214222635275552, 0.031436635979584286, 0.04716755436467273, 0.04784840997308493, 0.07450277863868646, 0.0331358505146844, 0.035364420751907995, 0.023104602537517036, 0.06277562398463488, 0.0508048854369138, 0.05007670879630106, 0.03334658992077623, 0.0472170161748571, 0.023642780891220485, 0.04152309635121908, 0.043709465102957826, 0.09078905758048807, 0.07247824048889534, 0.006559342894304011, 0.03366254296685968, 0.009627726594252246, 0.04235661555347698, 0.01322403852827847, 0.05252366552927664, 0.029282660489635806, 0.020383850139166628, 0.013609531235748103, 0.011169783937345659, 0.06371162911610943, 0.017017773618655543, 0.01420576504564711, 0.046915346290916204, 0.017664049386179874, 0.07060310896486044, 0.049978789407759905, 0.03651032051337617, 0.025031178890328323, 0.035001889669469426, 0.025709992108334388, 0.02675333130173385, 0.03559639830408352, 0.020269813847595027, 0.028806926017361026, 0.02209087970134403, 0.030886836017348936, 0.028686825319060257, 0.04264276734154139, 0.022528069991884486, 0.0702121981552669, 0.013925140773478364, 0.03843790618702769, 0.027779661318553344, 0.01075655611098877, 0.009408394390318011, 0.027242222568020225, 0.07865995235208954, 0.021117531395118152, 0.03360568851764713, 0.03992383341704096, 0.020151489214705567, 0.040267083926924636, 0.00606641943366932, 0.029939424712210894, 0.019923498055764606, 0.05847638539437737, 0.02173286596579211, 0.021192674059420824, 0.038026310237390656, 0.05888915860227176, 0.020517787862835184, 0.03208480655614819, 0.00661492721077853, 0.04240040820358055, 0.027724915416911244, 0.03591192726578031, 0.06620888904269252, 0.01278671422707183, 0.10701261953051601, 0.04996716271021536, 0.015701773609699946, 0.03878010496763246, 0.04535361991396972, 0.08846792498869555, 0.02512735783654664, 0.012474888370239308, 0.08455776516348124, 0.02526165857645018, 0.0321112558511751, 0.03780425286718777, 0.07717147043773107, 0.03616942112733211, 0.024899263201015334, 0.08147158433816262, 0.019227743514680436, 0.05996045683111463, 0.03262574485103999, 0.029609551520219872, 0.04659580040190901, 0.00598298804002947, 0.003154258243739605, 0.06719351120825325, 0.03803400482450213, 0.07146083829658371, 0.05126827735719936, 0.011622308271138795, 0.021190344987969314, 0.05443259148991533, 0.07163005814488445, 0.04016755980306438, 0.0396570843378348, 0.029076172105435814, 0.029217683976250033, 0.043937659822404385, 0.04217397088983229, 0.03075916286824005, 0.038674918469041586, 0.03320018920515265, 0.022688991356907145, 0.056966258212924004, 0.018923493501331125, 0.07796061344976936, 0.003485471330350265, 0.05016705573403409, 0.041632920636662414, 0.022597490909642408, 0.01483512663149408, 0.035565714950540235, 0.05087808579472559, 0.04404782676803214, 0.04351106485618012, 0.018834417120420506, 0.0405913151002356, 0.03203727857076696, 0.05430111515202692, 0.01591217883729509, 0.01629132724234036, 0.03979355808613556, 0.03769518854096532, 0.031306784733065536, 0.04505875234359077, 0.013760723256772118, 0.024769133755138943, 0.0173446934869779, 0.02664977328718773, 0.03983265527391008, 0.016158984075965624, 0.06236772944352456, 0.03435449262282678, 0.048516061290034225, 0.01998672055612717, 0.01999385535184826, 0.005116705774396125, 0.024593822358708297, 0.02642433511625443, 0.03981284883671573, 0.03258762475369232, 0.020496308836819868, 0.011954790430276521, 0.01943574333563447, 0.13062792484249386, 0.18501897981124266, 0.16572513511138304, 0.08937843755951949, 0.10395459790847131, 0.12005363511187689, 0.18078228857900414, 0.14057803020945617, 0.11594901393566813, 0.1362942350762231, 0.07170664439243929, 0.12087034700172287, 0.1382430690739836, 0.1781949531286955, 0.15331441749419483, 0.2792871307049479, 0.13350275558020386, 0.11454577637570244, 0.13279418860163006, 0.12205265355961663, 0.11473807319998741, 0.20088523200580052, 0.07342121417501143, 0.09104715194553137, 0.16708466144544737, 0.11896816907184464, 0.1405289721276079, 0.23002057575753757, 0.11055662150361709, 0.12030109683317797, 0.08878983557224274, 0.12321750819683075, 0.10430796537548304, 0.16980068784739288, 0.18563639239541121, 0.07902444100805692, 0.07585486822894641, 0.06990285404026508, 0.08427822909184865, 0.20770134697003023, 0.09554079760398183, 0.10830934744860445, 0.15375774513397897, 0.1902259082666465, 0.06140816557620253, 0.11828983761370182, 0.07643817085772753, 0.10640115769846098, 0.1037633256720645, 0.11131223810038396, 0.17504045739769936, 0.09340996015816927, 0.11603777988680772, 0.12227490091962473, 0.09234493159289871, 0.15943683896745953, 0.0813949913052576, 0.09903644038630383, 0.14763609719063553, 0.09385045152157545, 0.11751451635999338, 0.1070361714810133, 0.15785293467342854, 0.1790795728032078, 0.12970399084900106, 0.14870050150368894, 0.11040251941553184, 0.15020247947956833, 0.1500973201223782, 0.10837374042187418, 0.09980317138667617, 0.14594084530004434, 0.17776925382869585, 0.13445696580622876, 0.2224772341017212, 0.13427464344671794, 0.11626219855887548, 0.12910461372562818, 0.24251378966229303, 0.14152983842151506, 0.10017608744757515, 0.08921071727360998, 0.10377407366675989, 0.13509594223329, 0.09481010359844991, 0.1746039151081017, 0.19622964039444923, 0.1608955128384488, 0.22391072075281823, 0.22857339626976422, 0.11647293796496731, 0.09874346253595181, 0.17831912503710814, 0.10579493415674993, 0.1612037577267204, 0.16245907465262072, 0.24299340535487446, 0.18984423231865677, 0.0725329371967486, 0.14553993966962608, 0.10560002497264318, 0.2040507471454995, 0.13537123746105603, 0.1348292101174593, 0.1322539390197822, 0.07612523729247705, 0.24238589938197816, 0.10467375003333602, 0.18326709738799504, 0.11730094067752361, 0.09305950360638754, 0.11559632500367505, 0.16950867351676735, 0.1295970944421632, 0.14546555866088184, 0.07505434618464538, 0.10093113407492638, 0.2744532200906958, 0.254522583846535, 0.16909579852862017, 0.08042836388839142, 0.11814316548407078, 0.09054404537060431, 0.07367629584457193, 0.12907049698489054, 0.0897504375981433, 0.2167890886110919, 0.15840429865888186, 0.07037474121898413, 0.08770589623600245, 0.07053482798593384, 0.2477486873311656, 0.15340625042361872, 0.19118043061877998, 0.1163766538458211, 0.20378009309726103, 0.18841887451708317, 0.18366478676242487, 0.11079256170030151, 0.11666659185928957, 0.09325003623962402, 0.17121592190648827, 0.11570907038237367, 0.08991184750837938, 0.206554134243301, 0.17224661659981522, 0.09234214281397206, 0.08421562066567795, 0.10626199016613619, 0.13819285748260363, 0.13204522164804594, 0.05012149889288204, 0.11748768708535604, 0.15665986655013903, 0.05801139213144779, 0.12216002494096756, 0.17963853638087, 0.05399075662717223, 0.10924737461443458, 0.10115481992917401, 0.2264607503478016, 0.152025716645377, 0.16401726246944495, 0.09400865874652352, 0.16067083632307394, 0.18280407866196974, 0.126748563721776, 0.09964313211717776, 0.17215288377233914, 0.1378715168684721, 0.2634791375270912, 0.10891842762274401, 0.09611724024372441, 0.10556170131478991, 0.14732931793800422, 0.09857184067368507], [0.010880727171232658, 0.014968458762658494, 0.04372777197776096, 0.007527907528648419, 0.04087786043861082, 0.08029249403625727, 0.04011177743918129, 0.07346481004995958, 0.019749626849911044, 0.03462877004806485, 0.020132585229086022, 0.009172559366561472, 0.018707731239763752, 0.03600823852632727, 0.013233035902625747, 0.019655805812882524, 0.019368337666881934, 0.055181185249239206, 0.027530654233747294, 0.05554596906793969, 0.05097182880022696, 0.04650699034599321, 0.014814521219315273, 0.020322055955018316, 0.05514779454097152, 0.027572669122102003, 0.029054845749799694, 0.022553990029596856, 0.031706618278154304, 0.016461100096681287, 0.01805839527930532, 0.07547469184334789, 0.013662183008688902, 0.0006932983503377597, 0.06613552583647625, 0.052804232974137576, 0.07468026304351431, 0.05494354871500816, 0.02736880666842418, 0.04265563575817006, 0.027690415303888063, 0.0408186853996345, 0.032307844409453015, 0.03442036819511226, 0.04564896585153682, 0.018423452208350812, 0.07094709229256425, 0.05348065096352782, 0.04728309530764818, 0.038362836465239525, 0.025936510846284882, 0.07647901866585016, 0.04527774952085955, 0.002761443507292175, 0.045818016066082885, 0.01972315041348338, 0.020657464296423962, 0.036139158465500386, 0.013322588106218194, 0.039941678888031414, 0.012996692825773997, 0.06360652404172079, 0.04697287588247231, 0.016027677371831875, 0.01678516502891268, 0.014291341882199049, 0.03282436222902366, 0.033402949039425166, 0.026332039086680328, 0.039505048388881345, 0.03529034508392215, 0.0561216924605625, 0.024137802721400346, 0.0666660520115069, 0.036400445337806425, 0.004105278082923698, 0.02651581690380616, 0.049276692260588915, 0.07145432436040469, 0.020144898943336945, 0.011897068304408873, 0.022115174647686735, 0.027720662698681866, 0.02969215637339013, 0.07284090388566256, 0.047708750502871614, 0.01786842752647187, 0.03696339191602809, 0.039267910577889, 0.030493024470550672, 0.03878991997667721, 0.03996101713606289, 0.06237625862870898, 0.07849299202540092, 0.027576492666932087, 0.022083531167092066, 0.008931513193861713, 0.0471800190529653, 0.05445657091747437, 0.03136420915169375, 0.028356458492843167, 0.037577622170959196, 0.041191540392381806, 0.0034138392366003245, 0.028015922123034085, 0.013660628315327423, 0.03193982397871358, 0.012106622818724384, 0.044467592279293706, 0.011915341252461076, 0.04679366460602198, 0.09223390290779726, 0.02426777610422245, 0.01380393491126597, 0.015200578807187932, 0.015425450401380658, 0.03707494646576898, 0.017851491292406405, 0.010402737418189645, 0.07880180688308817, 0.06300646159797907, 0.014892301688502942, 0.0535359312114971, 0.06120615213045052, 0.026972399725179588, 0.052058098904256306, 0.04484508166621838, 0.06301768456718751, 0.006837458283241306, 0.026286371983587742, 0.018731912531490837, 0.026992905053443143, 0.049813002946653535, 0.01069829539795007, 0.028942850152296678, 0.019062725494482687, 0.04976394486480525, 0.009239071065426936, 0.010387264275258141, 0.0272181634125965, 0.06159881356039217, 0.06549646119986262, 0.06783865551863398, 0.027176465739363005, 0.013370910825740014, 0.03972045272322638, 0.025583891464131217, 0.04805165156722069, 0.011803056429406362, 0.04128439790968384, 0.019042001338675618, 0.013846820868950869, 0.03740131163171359, 0.07011099465723548, 0.04938691688169326, 0.05672389907496316, 0.07175234372594527, 0.04475407994219235, 0.03850569522806576, 0.05554426933771797, 0.056063711643218994, 0.0007930843463067763, 0.045874809447143755, 0.03746252906109605, 0.012859743254791414, 0.023429597062723975, 0.0585141187267644, 0.0028149084620443837, 0.03648619180811303, 0.05130232285176005, 0.07455398767654385, 0.09161911625415087, 0.04618960898369551, 0.03346967278048396, 0.07525993550994567, 0.03399808192625642, 0.02590166637673974, 0.031539824192545245, 0.02089120603964797, 0.010630251058111233, 0.009396877954714, 0.01929656901795949, 0.029839530786765472, 0.017926238710060716, 0.015297300581421171, 0.0719033381236451, 0.09459339986954417, 0.03048384389174836, 0.0638745046619858, 0.032234118187001774, 0.018417470922161425, 0.036339624851409874, 0.02518393747907664, 0.040731011889874935, 0.007573986841764833, 0.011182027253588396, 0.06260518955865077, 0.05839210455971105, 0.03300040813961199, 0.03878964177731957, 0.023588175785594752, 0.03526456753856369, 0.04333779076114297, 0.0510674445623798, 0.007553516288420984, 0.0684571944709335, 0.021028544920097505, 0.06777738380645003, 0.01868544814975134, 0.0363892664733742, 0.03018067783809134, 0.05609692932505693, 0.07041822174297911, 0.024428860317649584, 0.024375571569960033, 0.05756785414580788, 0.02727055479772389, 0.07476343108075005, 0.049906125092612844, 0.031614354478993585, 0.034784392054591856, 0.026717843920258538, 0.032605168276599476, 0.016618905289630805, 0.012954503214651985, 0.021647233150101135, 0.027226261728044068, 0.026434574209685837, 0.0486321925584759, 0.03168426054928984, 0.0622510892738189, 0.019683030334168246, 0.0260829200435962, 0.04663917575297611, 0.024125032692349384, 0.0344383222317057, 0.02652835114193814, 0.05500304605811834, 0.07865021537457194, 0.034530904942325184, 0.0523081153099026, 0.03359907280121531, 0.040604285297117064, 0.058727687623883994, 0.026942131974335228, 0.06282803402947527, 0.02126169633785529, 0.026817910872133713, 0.0183294021657535, 0.03763120608138187, 0.04564437556213566, 0.02409158430860511, 0.05475269377763782, 0.06402651007686343, 0.023451434015961628, 0.014874071148889405, 0.012940246345741408, 0.03761877192716513, 0.014330793604520815, 0.02558697370945343, 0.04929748935891049, 0.023162864946893284, 0.03834606986492872, 0.026611459807359746, 0.03591575420328549, 0.034580739946769815, 0.026261028700641224, 0.018146749020421078, 0.05254390283620783, 0.051278085580893924, 0.04081761331430503, 0.023401027345763784, 0.09213062987795897, 0.02059220110199281, 0.02214089112489351, 0.043600624693291526, 0.04896737189431276, 0.056175232266208956, 0.027031277905085256, 0.030053645904575075, 0.029463612208408967, 0.024475789495876858, 0.062189288304320404, 0.010287596810875195, 0.05056095209770969, 0.04561942243682487, 0.047230943106114864, 0.04808555456942745, 0.007813245922859226, 0.03078352566808462, 0.008643019611814191, 0.01686393785556512, 0.027313914881753068, 0.07594690471887589, 0.011067612678743899, 0.054455946665257215, 0.02906398900917598, 0.03212869759382946, 0.04114651959389448, 0.04650151117571762, 0.055615834426134825, 0.034708440237279446, 0.02884066277848823, 0.10095349858914103, 0.032781183653111966, 0.025496501242741942, 0.029252835482891117, 0.052704145666211843, 0.10849800732518945, 0.019037098923165883, 0.06271920379783426, 0.04963481625808137, 0.03648763369502766, 0.025073689109246646, 0.021879013927121247, 0.03301622818357178, 0.028452532266133597, 0.036562506641660414, 0.015555790193112833, 0.038654284219124486, 0.03169689826401217, 0.025433897905583893, 0.05767059113298144, 0.0067817162073749515, 0.037415333557873964, 0.015803004249132106, 0.01576310978271067, 0.021066812598811727, 0.03053736673401935, 0.0625049699363964, 0.0193710908227201, 0.016211646875100474, 0.035304838591920476, 0.04074900663856949, 0.015117122392569269, 0.03689533146098256, 0.06587551121733018, 0.0022552421765535003, 0.06115067510732582, 0.018146682863256762, 0.015151819280747856, 0.027745069603302648, 0.02857979659789375, 0.06337052956223488, 0.03992435588900532, 0.01663684575552387, 0.04638634003432734, 0.05392036879701274, 0.08393920585513115, 0.053062286627079756, 0.07656078892094748, 0.004323211656550744, 0.05445620111588921, 0.18493414936321123, 0.09679404499807528, 0.08422486231263195, 0.1628703482981239, 0.15563128888607025, 0.13898077234625816, 0.13833868822881154, 0.1002374202279108, 0.19823871473116533, 0.13610169397933142, 0.0828588627544897, 0.1429181753524712, 0.13010425865650177, 0.08367153736097471, 0.11471580368067537, 0.19006115996411868, 0.13416359440556594, 0.11386141952659402, 0.08343231305480003, 0.24367799290588923, 0.1454043955143009, 0.1577527964753764, 0.07814702059009246, 0.10857516354215996, 0.09709160295980317, 0.18372589562620434, 0.10301689643945013, 0.15939178424222128, 0.15271202767533915, 0.17445572306002888, 0.11642226496977465, 0.10231377809707608, 0.05822240295154708, 0.0946310314216784, 0.10734236040817839, 0.21058426584516252, 0.08412969099091631, 0.07899012749216386, 0.14546426944434643, 0.09047659898975066, 0.15888438932597637, 0.14895501998918398, 0.07882245470370565, 0.14215748331376485, 0.17308700936181204, 0.22982551051037653, 0.1636642071285418, 0.09521887344973427, 0.11347609984555415, 0.1376955048846347, 0.1729678993246385, 0.13576881826988288, 0.19012317806482315, 0.14998445260737622, 0.06772650725075177, 0.10057387860225779, 0.08862752321043185, 0.12921676199351037, 0.1449731457978487, 0.14589152937488897, 0.19303705170750618, 0.16926748145903858, 0.11968311427959374, 0.16251151183886187, 0.18079347083611147, 0.12382034584879875, 0.14878158643841743, 0.14035534858703613, 0.13550100049802236, 0.10691132782293217, 0.0760656822738903, 0.12040929602725164, 0.1892855537257024, 0.14837667745138916, 0.15622941750500882, 0.09450631668525082, 0.13990290143660136, 0.12553622520395688, 0.08170048812670366, 0.05126530537381768, 0.1651039363018104, 0.17486730883164064, 0.07518422457256488, 0.18424863900457109, 0.11868842265435628, 0.12582511827349663, 0.13719585883830274, 0.15150240329759462, 0.08968564428921257, 0.06552946514316968, 0.10934843562011208, 0.10068101928170238, 0.18747771930481705, 0.105229103804699, 0.07977930443095309, 0.17826220951974392, 0.13335195795765944, 0.17338970383363111, 0.08995620334254843, 0.11635447932141167, 0.19765921868383884, 0.08337699209472962, 0.09965658068124737, 0.16498447342642716, 0.08336397100772176, 0.16311186605266162, 0.10119486028062445, 0.19031364284455776, 0.04486230288499168, 0.13099848638687814, 0.1232500643070255, 0.08857263651277338, 0.1251319268984454, 0.06949510877685887, 0.11070942080446652, 0.0914699946131025, 0.14858582908553736, 0.08376433381012507, 0.1829981261066028, 0.16410586557218007, 0.102659111709467, 0.12098501941987447, 0.13360463082790375, 0.09484586239393268, 0.09264698145645005, 0.10579348887716021, 0.24028651203427995, 0.15107693469950131, 0.10230947618505784, 0.08848897314497403, 0.09840252583048173, 0.3823401252073901, 0.06918390547590596, 0.12106587365269661, 0.1671060895813363, 0.11904393429202692, 0.11052967687802655, 0.08030319453350135, 0.15897566585668496, 0.14228232018649578, 0.10889877724860396, 0.14564835599490575, 0.09502303467265197, 0.15277819841035775, 0.12083063913243157, 0.22641866760594503, 0.23916964339358465, 0.16514622260417255, 0.1073373392490404, 0.07323800293462616, 0.10668278365795102, 0.08725376799702644, 0.10736638733318873, 0.0961385869554111, 0.10317772959492036, 0.16393226917300904, 0.10171733903033392, 0.11273483426443168, 0.10034882889262267, 0.16059838235378265, 0.12252385541796684, 0.11516624236745493, 0.11863416699426514, 0.0873041967196124, 0.1115996791049838, 0.15566475423318998, 0.1143017616122961, 0.15304973455412046, 0.10447668310786996, 0.22848059982061386, 0.15594360498445375, 0.1669146477111748, 0.1620132364332676, 0.21071810009224073, 0.12386141078812735], [0.03548452823555895, 0.03725333332217165, 0.028317668342164586, 0.005803984564928604, 0.01922785716929606, 0.04066681229908552, 0.006935369190094727, 0.0323170894490821, 0.03668933501467109, 0.02946161731545414, 0.02298985717685095, 0.020261959804754173, 0.03152264368587306, 0.003414801272031452, 0.04402271757966705, 0.026187819861141697, 0.024891858687624335, 0.012516848975792527, 0.061853277763085704, 0.048047475184180906, 0.0054845455451868474, 0.04461426780159984, 0.018819696303190928, 0.09310022249285664, 0.02966062824374863, 0.1184187185551439, 0.031013800097363334, 0.014387663320771285, 0.12921146942036493, 0.08761091490409204, 0.04729086114093661, 0.03404547081195882, 0.024848047377807752, 0.036500553001782725, 0.03480241394468716, 0.0097114501820345, 0.04469560718696032, 0.06380119573857103, 0.06521185647164073, 0.05155469038124595, 0.04161970277449914, 0.03159862603726132, 0.060396449507347176, 0.04691048798018268, 0.08831388396876198, 0.04308911446215851, 0.0404810158402792, 0.02901188430509397, 0.024103460367769003, 0.013858807190055293, 0.046274744772485325, 0.038598705415746996, 0.04505478630640677, 0.07941464614123106, 0.06891043550734009, 0.06585957242974214, 0.004325174743176571, 0.004903499469427126, 0.02703556794274066, 0.053557210069681914, 0.057345837487706115, 0.07476457101958138, 0.054418528851653845, 0.02229930360668472, 0.06007888833326953, 0.024753703868814876, 0.02086130639405123, 0.05550117897135871, 0.0779398570635489, 0.021152660849371126, 0.03590953542983957, 0.05273938877508044, 0.06026280525007418, 0.011251461742046689, 0.019471016978578906, 0.032604937574693134, 0.03761272618014898, 0.028230289995138134, 0.04392767857228007, 0.00821741869939225, 0.028277531299473982, 0.04811461961695126, 0.02194929658435285, 0.06613416198108878, 0.01739667266208146, 0.039263625629246235, 0.03753190587407776, 0.06150480931890862, 0.04343731149232813, 0.04437725551958595, 0.03822031696992261, 0.02449624054133892, 0.01886391982303134, 0.01756964989804796, 0.06636745589120047, 0.02494257239491812, 0.06749868911824056, 0.0077889730289046255, 0.05545523197257093, 0.025138774188235402, 0.034401766157576015, 0.050015046926481385, 0.06831636452781302, 0.06275189561503274, 0.043769254216126034, 0.05260414996051362, 0.006026621234403657, 0.07543464470654726, 0.01629759860225022, 0.021908363959352885, 0.03539163339883089, 0.012349550229763346, 0.03635980448286448, 0.008171789763894464, 0.03007670252450875, 0.04183494086776461, 0.028141220399577702, 0.00508468401052856, 0.04949152323284319, 0.03575258349467601, 0.01880507217720151, 0.012888815087665404, 0.026553356853712882, 0.005253793172804373, 0.04326604586094618, 0.030482927869473184, 0.05047494439142091, 0.06741986370512418, 0.027435116503121595, 0.026436258672869632, 0.004180367312593651, 0.06946637281881911, 0.03131966672039457, 0.027314067552132264, 0.01865536529969956, 0.029672166731740748, 0.06987827071653945, 0.013613392948172987, 0.04082825952874763, 0.012205067223736217, 0.014157024178920048, 0.038987984348620684, 0.022533837539542998, 0.03519154359985675, 0.034034125706447024, 0.013344577729835041, 0.021234091836959124, 0.012884268054871686, 0.059111310967377255, 0.023232229885512164, 0.009283483726903796, 0.04434878079752837, 0.022878387443987385, 0.05934572446026972, 0.06920287052967719, 0.1102866188489965, 0.02530711024467434, 0.009993383178620465, 0.010901711714853133, 0.029073580101664578, 0.009264595856490945, 0.05257266254297324, 0.0421349076288087, 0.011550914512814155, 0.0373468897305429, 0.027615164073982408, 0.014838653317253505, 0.05704038816371134, 0.02211696937281106, 0.024288496867354428, 0.019058060566229478, 0.08249235884951693, 0.019757009310913936, 0.04880315284909947, 0.03192653826304844, 0.042339808241065056, 0.022133624014843787, 0.019852716675294296, 0.0037441269710793024, 0.004618824343197048, 0.012387590599246323, 0.016622735619811074, 0.04373294919995325, 0.011188465702746595, 0.008354793202930262, 0.02833251129569752, 0.007124422616990549, 0.025268961309588382, 0.04890375245096428, 0.03771760394530637, 0.026617203606292605, 0.025791994761675596, 0.022095037424670796, 0.08351041922079665, 0.1005881821204509, 0.03415696429354804, 0.04146699168320213, 0.029841885303280184, 0.020562243780919483, 0.07973294013312884, 0.057039085376475535, 0.04286231752485037, 0.02143516211903521, 0.07656135210501296, 0.07251228937613112, 0.06168724702937262, 0.040958256660295386, 0.026636119466274977, 0.03696237750617521, 0.01094725837797991, 0.034180265186088424, 0.02851006355402725, 0.016224118348743235, 0.02967232618747013, 0.044601032976061106, 0.050324523355811834, 0.015276495001411863, 0.030009938071348836, 0.1472375528620822, 0.07794532605579921, 0.0212215779548777, 0.03543811983295849, 0.05236051178404263, 0.03662796491490943, 0.008355045109055936, 0.026824039739689658, 0.040998419148049185, 0.038254518527537584, 0.043148309857185395, 0.03864886950967567, 0.02177793426173074, 0.036428584185029776, 0.0020667729259002954, 0.03287542538185205, 0.05392383611095803, 0.014912932545744946, 0.08994330439184393, 0.08223931957036257, 0.018931627439867173, 0.025423202497352446, 0.04445866954379848, 0.03710392330374036, 0.058291599952748845, 0.017115838892225708, 0.07277002411761455, 0.027223647671884725, 0.051410386338829994, 0.020347182106758867, 0.03652974018560989, 0.04160217960764255, 0.04343469573983124, 0.030468081523265158, 0.059192348404654434, 0.04448380587356431, 0.023516393565971936, 0.005058041757105717, 0.04713805844741208, 0.007111955384191657, 0.045025487164301534, 0.020350688436467732, 0.03695968711482627, 0.031142681038805416, 0.030844777024218013, 0.00987134950368532, 0.036517896356859376, 0.027736119726406674, 0.0583840435636895, 0.01878683315590024, 0.04703216287972672, 0.00963957975285926, 0.04935535143262573, 0.03910295871485557, 0.01888659137434193, 0.06890020319925887, 0.034875763580203056, 0.03150930708008153, 0.03403390518256596, 0.04259394335427454, 0.04015895937170301, 0.06622425107551472, 0.035694928374141455, 0.042396940889635255, 0.06475045265895979, 0.033014691301754544, 0.05306521450568523, 0.012023376749961503, 0.01790737034752965, 0.004310533229727298, 0.07061207241245679, 0.02206305637290435, 0.015988651430234313, 0.07715583020555121, 0.01475450479691582, 0.00743479301620807, 0.02179162370573197, 0.03053794688146029, 0.0327434638914253, 0.018756930117628405, 0.04981222263138209, 0.024379500287718008, 0.05603441928646394, 0.04078157292678952, 0.039114266500941346, 0.043772324587085416, 0.021136577873091613, 0.07504211898360934, 0.02609190554358065, 0.011738662607967854, 0.02410131789344762, 0.062041136968348704, 0.049423398316970894, 0.033161061483302286, 0.0253001518680581, 0.04904237715527415, 0.019285144184583, 0.0030080689341827694, 0.06984072058860745, 0.06203020576919828, 0.0957074933020132, 0.04699700798041054, 0.03752753610855766, 0.028887949883937836, 0.01410229439248464, 0.027920284308493137, 0.030471362240080322, 0.12857341580092907, 0.08712739763515336, 0.03182978256206427, 0.025284467531102042, 0.04690803507609027, 0.02009913684534175, 0.0469120825374765, 0.031064853072166443, 0.04826191599879946, 0.022771063560087765, 0.05053921522838729, 0.020381940063089132, 0.04269493989912527, 0.019777574010991623, 0.0714930754953197, 0.015463500948888915, 0.04122872071872864, 0.01339944067876786, 0.021055101084389856, 0.009508720033669045, 0.050598105282655785, 0.020201704198760644, 0.04881299499954496, 0.040165290103427, 0.059594997870070596, 0.046921520959585905, 0.024309341463127306, 0.10061761696955987, 0.14257073828152247, 0.16055311049733842, 0.16161626630595752, 0.09175064348216568, 0.1274110988846847, 0.16416309321565287, 0.06482608217213835, 0.09047252777963877, 0.07809196425867931, 0.14696394040116242, 0.1812919769436121, 0.08755900018981524, 0.10914567578583956, 0.09566055903477327, 0.10457226155059678, 0.13923485656934126, 0.14110875315964222, 0.1951708679220506, 0.12473564887685434, 0.11452529818883964, 0.10883521887340716, 0.11888432928494044, 0.13583076851708548, 0.13830170807029518, 0.31234858664018766, 0.11791610052543026, 0.1856093324188675, 0.19161315954157285, 0.20738482395453112, 0.09533182917428867, 0.11134457029402256, 0.0565705603387739, 0.1587693640696151, 0.1434161386319569, 0.06397312972694635, 0.12347598932683468, 0.20790158265403338, 0.14468328920858248, 0.1980695966631174, 0.11051578726619482, 0.08584584854543209, 0.1992651889366763, 0.18055256376309053, 0.1796652978020055, 0.09104570666594164, 0.15768304307545933, 0.10477924865803548, 0.09809943780835186, 0.1273763443210295, 0.11488447391561099, 0.1396449902760131, 0.143200011657817, 0.19224526919424534, 0.11080750982676234, 0.13405810935156687, 0.07096648482339722, 0.11673588385539395, 0.21725598855742387, 0.1833239450518574, 0.18498920569462435, 0.19313326797315053, 0.13336231240204402, 0.15569011787218706, 0.10783212019928864, 0.13268512088273252, 0.15607929841748305, 0.10381623104746852, 0.26944829151034355, 0.16268197340624674, 0.1545460128358432, 0.12055604958108493, 0.13150415782417568, 0.13314446194895677, 0.1416301123265709, 0.142103675486786, 0.17335091877196515, 0.1372848962034498, 0.10311632896108286, 0.05618187512404152, 0.19814844243228436, 0.09363018548382179, 0.1210163813084364, 0.13760477118194103, 0.10587901143091065, 0.11733931861817837, 0.10934314304696661, 0.20716622711292335, 0.1308826876005956, 0.07899991196713277, 0.13192703441849776, 0.17935295456222125, 0.14553930184670857, 0.0945058756374887, 0.1404783669859171, 0.1256945002824068, 0.16284417041710444, 0.1671368136469807, 0.08233367665005581, 0.14280139947576181, 0.10861412502293076, 0.15407193398901395, 0.07964803504624537, 0.11013846751302481, 0.10514174242104803, 0.16021153596895082, 0.16687031223305634, 0.13526909079934868, 0.21439657413533755, 0.1396502149956567, 0.06922973373106547, 0.10049166729939835, 0.1942624452390841, 0.0993231146463326, 0.07871308842939989, 0.12245938102049486, 0.07797921209463052, 0.09310710283794574, 0.10236380648400102, 0.14706097090882914, 0.1458914615213871, 0.12796453918729508, 0.1208987504776035, 0.07638570653008563, 0.10262866584318024, 0.12498662540955202, 0.1457594728895596, 0.11583166808954307, 0.12377648534519331, 0.14625313425702707, 0.10422797966748476, 0.13681798268641743, 0.108964018390647, 0.1576616692223719, 0.10929056336837155, 0.162954038807324, 0.11406964835311685, 0.12943898221211775, 0.1298083495348692, 0.08103614127529518, 0.11703046304838997, 0.13586795223610743, 0.21716530913753168, 0.08454422160450902, 0.10495910115007843, 0.08446851066712822, 0.1279189009219408, 0.06301573717168399, 0.24423694291285106, 0.21274123367454323, 0.12288780803126947, 0.0994928569665977, 0.1776441726833582, 0.13352858062301362, 0.1128236341423222, 0.1588875377284629, 0.12704751268029213, 0.13487772537129267, 0.13298271277121135, 0.08955790328660182, 0.09308890452874558, 0.13028157342757496, 0.08770409811820302, 0.15721118982349122, 0.10901572275906801, 0.09805327028568302, 0.08950432616152934, 0.15969006823641912, 0.13867541801716599, 0.135551782058818, 0.07229560600327593, 0.1561050284653902, 0.08648517102535282, 0.14444813611251967, 0.1931720394641161, 0.12489796802401543], [0.02730722283013165, 0.024575298352699195, 0.057383122986980846, 0.005351252853870392, 0.01565279525571636, 0.02234681123601539, 0.008924754985075976, 0.054470704801912816, 0.04608947757099356, 0.04414399892890027, 0.027443526944677745, 0.038938207019652636, 0.020663489687389562, 0.01656707708856889, 0.011900215858726628, 0.044655342918953726, 0.029381224486444677, 0.12574076279997826, 0.051398437337151597, 0.01082879294907408, 0.03812206170654722, 0.048100892853524, 0.018075579178652594, 0.037844839439328225, 0.02684182414252843, 0.03727091755717993, 0.01063274806697986, 0.002576699837975736, 0.028417436738631556, 0.025345216771321635, 0.021669349999033978, 0.04608019181926336, 0.05786628063235964, 0.0432574997123863, 0.012810870921904487, 0.02306742051483265, 0.049693258479237556, 0.02789042707133506, 0.040742292534559965, 0.04657186507912619, 0.02457301168968635, 0.019097766739183238, 0.030433818897498504, 0.04578349898968424, 0.05568606619324003, 0.040449983041201315, 0.007664170082924622, 0.08464379661849566, 0.04061133527596082, 0.03705809504858085, 0.04668321267568639, 0.03856824937143496, 0.1174882570547717, 0.04407892742061189, 0.043762967589178255, 0.014378496312669345, 0.06959657011819737, 0.06391774091337409, 0.025467634666711092, 0.048700483715427775, 0.03396994986438325, 0.04777336400002241, 0.01096096308901906, 0.03351705488083618, 0.022906882522095526, 0.036766945850104094, 0.02588394473839019, 0.02106765398223485, 0.0846948360225984, 0.03786329219916037, 0.05587071932053991, 0.005952356424781361, 0.03874496024634157, 0.018011735818747963, 0.02121250594167837, 0.053310196181493144, 0.1017677066847682, 0.031191348963017975, 0.01489869348837861, 0.0238016157610608, 0.04809298113520656, 0.0365652275670852, 0.03453352748017226, 0.019242650929040143, 0.04000028056491699, 0.01713209828761007, 0.03211986646056175, 0.05778169445693493, 0.025055504370746867, 0.026526015285136442, 0.034860829024442604, 0.012462111555838158, 0.02212888784041362, 0.052491011031504185, 0.04300002281420997, 0.050717931174274, 0.030718050431460142, 0.018589722125657966, 0.0083571087036814, 0.04616632505453058, 0.034912336617708206, 0.022849732910149863, 0.034335541139755926, 0.029125857832176343, 0.005593995364116771, 0.00477591749846137, 0.015197769672210728, 0.07385757326015405, 0.07765790540724993, 0.02092145852345441, 0.018292011493550878, 0.07622207102498837, 0.02909899123811296, 0.07743420598230191, 0.1026619683418955, 0.04690269161281841, 0.034560743519770246, 0.0811075706567083, 0.024775778309309056, 0.04860300537464874, 0.04338719828852585, 0.0337878412434033, 0.011505196519595171, 0.004881712558147098, 0.049001651483454874, 0.05562587674441082, 0.06039358608956848, 0.03473335265048912, 0.04894333139860204, 0.05259041301906109, 0.045628056794937165, 0.09923208917358092, 0.01066209894738027, 0.023108963821349398, 0.02350795767935259, 0.09446644596755505, 0.057090932237250466, 0.0182394131552428, 0.04005421731354935, 0.01428966420436544, 0.00781073364695268, 0.04240802475916488, 0.021369574924132655, 0.07889580433922154, 0.07510166043149573, 0.06203462303216968, 0.08934750314801931, 0.023997298475088816, 0.06885725871792861, 0.007253461317824466, 0.03303283193547811, 0.03417686911832009, 0.027834498822422962, 0.03226312555904899, 0.016316387236916592, 0.017927504177870493, 0.03303131201703634, 0.029251760004886558, 0.07260747426854712, 0.0427595839303519, 0.08548105454870633, 0.02394451353965061, 0.03522268157186253, 0.07865810673683882, 0.01897125049228115, 0.004523053790243077, 0.06386427913925477, 0.1059609716758132, 0.019509508573849286, 0.012445861490310302, 0.04538505304870861, 0.038767070309924226, 0.025846158819539205, 0.03427325841039419, 0.016180553007870913, 0.053105278605861325, 0.0403795070014894, 0.06950191448309592, 0.022810191281938126, 0.03563267278618046, 0.04621284541540912, 0.009281154655452286, 0.011890933499671519, 0.028346132886196886, 0.04832595952653459, 0.02970283312190856, 0.04488017889005797, 0.03573226137086749, 0.02969429375869887, 0.02324522552745683, 0.013957763040837432, 0.06506982552153723, 0.007990643814472216, 0.08382494055799075, 0.012269273599875825, 0.031338699627667665, 0.041591767487781386, 0.0332618646456727, 0.01767816291456776, 0.04581108822354248, 0.0398360072369022, 0.060923311593277116, 0.026808689581230283, 0.015474659457270588, 0.03431778048564281, 0.046136513618486266, 0.07646437588014773, 0.021754395881933824, 0.06424914420183216, 0.09341354960841791, 0.029407171665557792, 0.02219800850642579, 0.05950159752475364, 0.0636576855821269, 0.04469796509615012, 0.02138297090173832, 0.060920448175498416, 0.030960239935666323, 0.04757349133225424, 0.00085920360808294, 0.021746535053742782, 0.0147830812992262, 0.05054279450061066, 0.02511884391840015, 0.06329262695674386, 0.09288154422704663, 0.063905730843544, 0.029131357358502488, 0.10046085502420153, 0.04607076018250414, 0.05589645954647234, 0.049496076202818325, 0.05029808763148529, 0.06697277019598655, 0.04293256625533104, 0.006038784398697317, 0.044950003536151986, 0.04676810758454459, 0.023712978731574755, 0.015428074635565281, 0.05459508027083107, 0.02285297291486391, 0.03483356548739331, 0.03790530030216489, 0.069942656904459, 0.024698033463209867, 0.009224776028921562, 0.033685976173728704, 0.031997594450201304, 0.04131455200591257, 0.05403827443452818, 0.017837362496980598, 0.009038815873542001, 0.045124807727656195, 0.01090299160153206, 0.049195403765354834, 0.07997079379856586, 0.06638354395649262, 0.041851856745779514, 0.022102523362264037, 0.005751908274500498, 0.02395960924747799, 0.02113609272055328, 0.04794888404597129, 0.06218351397131171, 0.03293821022712758, 0.015440868413341897, 0.05640976111005459, 0.025211989813085114, 0.013131135209862674, 0.0327447191812098, 0.04010157905785101, 0.026333732031551853, 0.008667502851624573, 0.04334447093840156, 0.05398883976574455, 0.0661566893437079, 0.025607779289462736, 0.01996019492591066, 0.007659427971313042, 0.02295278711244464, 0.02142955911611872, 0.04234752657690218, 0.02769619133323431, 0.028252155786114078, 0.050341174605169466, 0.010870561020315757, 0.038251539758805714, 0.04473145758467061, 0.008281608960325164, 0.07033114534403596, 0.07476749550551176, 0.01063049108987408, 0.03473624660234366, 0.05662388301321438, 0.04407405893185309, 0.026917830242642334, 0.04119352171463626, 0.016189613146707416, 0.045780842525086234, 0.015888379221515994, 0.010893272435558694, 0.010520967904345264, 0.021409874815227728, 0.062082805803843906, 0.026791113827909743, 0.0313113207396652, 0.043247440430734835, 0.032409556808748415, 0.02181856663498495, 0.0028369413422686712, 0.09091286307999066, 0.057539179255919795, 0.031350356859288046, 0.060187182522245815, 0.009853523540576654, 0.009142625794213797, 0.08546508861971752, 0.013024043724206942, 0.01383254025131464, 0.04011252382770181, 0.014704500158716525, 0.03232132690027356, 0.012860529507244272, 0.044976232307297845, 0.04321171895467809, 0.051884529646486044, 0.06564456503838301, 0.051278669121009965, 0.04178023737456117, 0.06419860691364322, 0.07221352362207004, 0.052178257278033664, 0.013515433695699488, 0.03823338894705687, 0.007714684470556676, 0.09300944129271166, 0.028594201896339655, 0.029985032443489348, 0.04400987630443914, 0.013798471008028303, 0.009523975197225809, 0.09805412523980651, 0.04666176079107182, 0.06279752709503685, 0.01728922494554094, 0.007111305686911302, 0.0331967490326081, 0.04038393104981099, 0.02885853878355452, 0.02845470527453082, 0.06115900751735483, 0.06200911690081869, 0.1580942895795618, 0.1448280071573598, 0.11856908191527639, 0.12742015054183348, 0.09049712467406477, 0.045848736739052195, 0.10049647811268057, 0.07920084654220513, 0.17417456528970174, 0.14754347716059002, 0.07531178915607077, 0.09079762747777359, 0.11020218195127589, 0.11985341299857412, 0.10352606233209372, 0.09574507057134594, 0.15590980036982469, 0.2507563887962273, 0.08712799474596977, 0.11276935134083033, 0.07948638764875275, 0.06621630543044635, 0.19555719862026827, 0.220125730282494, 0.11478812194296292, 0.09237351827323437, 0.1999368028981345, 0.09773962425866298, 0.12202389724552631, 0.1673859174230269, 0.1739210510360343, 0.17193465333964142, 0.20303953997790813, 0.10946158811982189, 0.187763708244477, 0.13091915207249777, 0.12709518655070237, 0.10638275582875524, 0.12557085763130868, 0.1951804081244128, 0.09807872213423252, 0.14556257559784821, 0.11676898279360362, 0.14456491198922905, 0.15544359252921172, 0.09497691464743444, 0.1071081640464919, 0.12237058792795454, 0.1834147194666522, 0.18163393145161016, 0.07440203654446773, 0.18703804218343326, 0.23428161282624516, 0.156629956726517, 0.155656204691955, 0.08737798061754022, 0.13054263299064978, 0.08419706951826811, 0.13483459768550737, 0.08809494785964489, 0.15763638700757707, 0.10621299993778978, 0.1483284743236644, 0.14933631595756325, 0.15323369896837644, 0.07891817563878638, 0.14193477454994405, 0.18764514103531837, 0.08354549269591059, 0.09292157779314689, 0.08981849466051374, 0.1753229722380638, 0.08850343272622142, 0.12795232555695943, 0.09799062793276139, 0.20257293858698436, 0.08253910312695162, 0.11527528294495173, 0.14717683754861355, 0.1466720617775406, 0.1814872728926795, 0.10820334670799119, 0.11688389948436193, 0.10295472906104156, 0.1091041833694492, 0.12971720871116432, 0.32185640931129456, 0.12788160863731587, 0.1868305326040302, 0.12582893164030143, 0.11880541566227164, 0.08053433748760394, 0.0831312131402748, 0.15392509901097842, 0.08580719240541969, 0.1544706275952714, 0.05138735346762197, 0.08807824911283595, 0.09483598970941134, 0.1427722903234618, 0.07522163220814296, 0.10593048509742532, 0.09341184648552112, 0.21681458795709269, 0.08721969875374011, 0.23437313362956047, 0.14587947859295777, 0.15678082220256329, 0.1511643842927047, 0.14455975512308733, 0.12344241541411195, 0.1274353904383523, 0.11734731176069804, 0.2743285053542682, 0.1466471188302551, 0.12636383436620235, 0.20895924232900143, 0.15652429525341305, 0.10040769859084062, 0.1648837381175586, 0.1143503582903317, 0.07915346444185291, 0.14691051255379403, 0.10283027216792107, 0.12188914019082274, 0.08444977631526333, 0.12339152528771333, 0.16598548899803842, 0.10803708527237177, 0.10520663751023156, 0.15318309382668563, 0.10825899336487055, 0.12840389061186994, 0.0687843704862254, 0.1900004175092493, 0.1646789155368294, 0.10448973133627858, 0.15759446711412498, 0.08790611156395503, 0.05956305244139262, 0.22848708661539213, 0.1631883369492633, 0.21095405385962554, 0.16979615523346833, 0.13734358948256287, 0.1786024948315961, 0.0786599727081401, 0.11589200342340128, 0.1673032854284559, 0.12175982498696872, 0.17365233759794915, 0.1602315798934017, 0.09362972408000912, 0.16675428274486745, 0.15001995355955192, 0.12883351184427738, 0.08463597310973064, 0.17406063926007065, 0.17022768993462833, 0.2231638165456908, 0.0796462097870452, 0.11597639960902077, 0.1674105075321027, 0.09468892402946949, 0.0699870330946786, 0.12738129762666567, 0.1954180175172431, 0.17165473050304822, 0.09527422155120543, 0.06919637694954872, 0.1196800744427102, 0.06199442661766495, 0.10963234145726476, 0.07522051941071238, 0.12281220565949168], [0.021312152201841985, 0.003378320896964786, 0.01590507457564984, 0.06651680823415518, 0.024704840865784457, 0.03852412423917225, 0.04468544951773115, 0.007084255888392883, 0.036122452933341265, 0.047670138467635424, 0.05639922346121498, 0.03442579986793654, 0.07024034378784043, 0.012548105691426566, 0.01003684165022735, 0.004492875521204301, 0.01481162557112319, 0.0316191177948245, 0.022053594202069298, 0.029477189694132124, 0.029643261139946323, 0.02045237030168729, 0.031400941644928286, 0.015544803014823368, 0.02184350449325783, 0.0303992305749229, 0.03805705465908561, 0.04537654082689967, 0.05169787144820605, 0.02334259869530797, 0.020386547315865755, 0.059748136438429356, 0.05349322761009846, 0.03484284106109824, 0.006299230735749006, 0.033617549309773107, 0.018613771103056412, 0.04563572424064789, 0.030211395118385553, 0.03250039229169488, 0.035283383314630816, 0.012098674629149693, 0.06950384152254888, 0.04277599090710282, 0.06759823020547628, 0.016340653345521008, 0.06615723895707301, 0.018394550009231483, 0.025596213660069873, 0.04346105003995555, 0.0313776916425143, 0.031287253102553744, 0.03641575308782714, 0.027944336678566675, 0.011878436580965561, 0.00624615403025278, 0.06894053532076733, 0.041317829330052645, 0.09992886999888079, 0.05804760554539306, 0.03820182689066444, 0.012318616666431938, 0.0067742120341530866, 0.039626156711684804, 0.035306277086160014, 0.0044778391851910525, 0.04131722882656114, 0.028879359630601745, 0.030460682098886797, 0.08632574243737118, 0.06023633559899671, 0.027218606156696166, 0.00893890074387725, 0.053315814451447556, 0.05670208417411361, 0.031553405070943494, 0.0301764302088746, 0.03862321749329567, 0.01577043456823698, 0.06509520951658487, 0.02341292206464069, 0.06208765732922724, 0.054556312172540596, 0.029332492101405348, 0.04841353464871645, 0.026260791213384697, 0.012441440834663808, 0.030579093244991133, 0.008428139445771064, 0.0053842992056161165, 0.016232082653524618, 0.05450070283508726, 0.05125105953110116, 0.012260871640007411, 0.051177044931266985, 0.014939278364181519, 0.051163426733442714, 0.04318220268136688, 0.04287402564659715, 0.041917277699602504, 0.06682073763970818, 0.034840476366558244, 0.02771035405541105, 0.016733268974348903, 0.07978244604808943, 0.03240518704322832, 0.03537695329370243, 0.011514837654041392, 0.015858323512864963, 0.02523857820779085, 0.17439263287399495, 0.026858378700645905, 0.03473759349435568, 0.032526817837996144, 0.07791717363787548, 0.048130687326192856, 0.012636266050062009, 0.02978952954124127, 0.01092861986918641, 0.01496289307916803, 0.0315734829221453, 0.033589892222412994, 0.06426451302000455, 0.017903261817991734, 0.06188748949872596, 0.022921784847442592, 0.03032924308042441, 0.052429552722190104, 0.008095517338785743, 0.04617265239357948, 0.039005290384271314, 0.02925353098128523, 0.037241482708070955, 0.07550000798489366, 0.0660990002964224, 0.10328075156680175, 0.05938727115946157, 0.08461615988718611, 0.10541047621518373, 0.07431795927030699, 0.014706031951521124, 0.015866247105545232, 0.02649773394555918, 0.03573469391890934, 0.05873316340148449, 0.0352902161622686, 0.004677169024944305, 0.04655267610879881, 0.03606419391664011, 0.03691637283191085, 0.0476612123394651, 0.03811315593442746, 0.04122454772836395, 0.009681558169956719, 0.03983954918969955, 0.04728266783058643, 0.045094307578567944, 0.05133134379450764, 0.053955011402389834, 0.0203821317492319, 0.014882140626598681, 0.04105853056535125, 0.05212369966985924, 0.10293559437351567, 0.026355496042275002, 0.06351220088877849, 0.04013044733021941, 0.03868455705898149, 0.04436060766290341, 0.11054463178983756, 0.016788515295567255, 0.0011465793566977872, 0.007430522486434451, 0.05732837878167629, 0.022143988637253642, 0.037755513696798255, 0.04955995688214898, 0.020594185816922357, 0.05377809018162744, 0.03683728618281228, 0.006733473215717822, 0.056245494567389996, 0.02302087301255337, 0.004115136772660273, 0.05595899672646608, 0.006932500259219003, 0.05670268128493002, 0.027555554772594144, 0.02176269606154944, 0.021985837391444614, 0.03447159080367003, 0.07206843247903244, 0.016961467086470554, 0.012262768993553306, 0.038408725788550716, 0.02197512162716261, 0.01684267765709332, 0.02439622956860278, 0.05692614322262151, 0.040120279482964954, 0.027997662745682255, 0.04934797575697303, 0.006075612735003233, 0.03076279303058982, 0.048768160798187764, 0.027147375246776, 0.032223848559494526, 0.035667783580720425, 0.03545742415423904, 0.010119130984613938, 0.031549696877066574, 0.03692278838051217, 0.04414655361324549, 0.019204574936468686, 0.022163659367444258, 0.040303131099790335, 0.0928429016577346, 0.009186363313347101, 0.07919720959450517, 0.041116440136517794, 0.04685224931953209, 0.0174069202372006, 0.04001470961208854, 0.011771043995395303, 0.04796275330175247, 0.03692228287192328, 0.055981120360749106, 0.012240100834917809, 0.012672227557881601, 0.01715180803356426, 0.0888705812394619, 0.034615447012973685, 0.06543232606989996, 0.024088239130963172, 0.009007827179240329, 0.017947429358693104, 0.039046446925827434, 0.07651095052382775, 0.021427950988124524, 0.07808903298739876, 0.00790626204772187, 0.040555023654763184, 0.056012879192296944, 0.014658709222983037, 0.04536687509555902, 0.04939456057867833, 0.04348924656265548, 0.09096992787505899, 0.010254205254438733, 0.047289198730140924, 0.027250561763399413, 0.05016877921298146, 0.016020715602540543, 0.004982268055235701, 0.022732651692682078, 0.07597365935466119, 0.07698501579995666, 0.03225852509162255, 0.01631850765884987, 0.06530738063156605, 0.03788046592048236, 0.0424004319523062, 0.01787515859385686, 0.07216599224401371, 0.023354690189340284, 0.0038504614661048564, 0.0784332538023591, 0.04319061651559813, 0.0255217987245747, 0.02321212150023452, 0.027361207076215317, 0.06382161285728216, 0.010658192282010402, 0.0271526220188077, 0.01475342592623617, 0.012365399959630199, 0.05230708732934935, 0.021005630792517747, 0.00372414496294888, 0.031149520671793392, 0.05230413909469332, 0.04467269305938056, 0.03063979498775942, 0.012578451473798071, 0.04913202180926289, 0.03604580222495964, 0.02325017374408032, 0.02290641263659511, 0.03374645739261593, 0.04009885134707604, 0.09619677811861038, 0.039403427591813464, 0.036749042703637054, 0.06662174367478915, 0.04027216615421431, 0.019185469086681093, 0.01919469716293471, 0.03947830732379641, 0.013255044185955609, 0.0476772291585803, 0.0268687738571316, 0.018809226507853185, 0.03678761063409703, 0.01153079086049859, 0.030130707126642977, 0.060248413522328646, 0.026129394603360976, 0.025043217797896693, 0.003611118416301906, 0.020695636980235577, 0.019431253130148565, 0.0773412873968482, 0.027595070955742682, 0.06276073692632572, 0.06617399198668343, 0.02627682499587536, 0.013539309646668178, 0.05216991129730429, 0.02062829407597227, 0.03238803707063198, 0.005167089544037091, 0.05262822438297527, 0.05610521084495953, 0.0243287492609982, 0.0935537281579205, 0.014272412451516305, 0.04282021442694323, 0.025025167070063095, 0.04267311142757535, 0.018772146265421594, 0.04872812044673732, 0.0690808699333242, 0.01694574373375092, 0.05555943459538477, 0.022568052667858343, 0.056854428856500556, 0.03685244465512889, 0.0541189929603466, 0.01827109225892595, 0.06901918431477887, 0.044411803130060434, 0.09335653231080089, 0.04165107484108635, 0.06228014414331742, 0.030002179023410593, 0.013922491942399313, 0.03955185373446771, 0.035234817170671055, 0.06853443211210625, 0.03145803018872227, 0.04345751826518348, 0.03005053142883948, 0.1568917083953108, 0.12056181712874345, 0.10780054796487093, 0.08279363518314702, 0.12934712214129312, 0.11663856836301939, 0.0943096840221967, 0.11504112051001616, 0.11247440573892423, 0.17848303195621285, 0.1104816569547568, 0.11163762278322663, 0.16738090983458928, 0.17938327150685446, 0.07156413846782275, 0.13355578987726144, 0.17344355237271103, 0.10810879285314254, 0.08397010633988039, 0.12268754520586558, 0.09494823297219616, 0.08871787014816489, 0.14048007689416409, 0.09578905999660492, 0.11050457108233656, 0.1281086193131549, 0.16998786851763725, 0.10884629935026169, 0.17621240951120853, 0.1510211726916688, 0.07945745491555758, 0.1769605079399688, 0.16615064442157745, 0.14175002303506645, 0.09534289608044283, 0.11064382682421378, 0.08660429463322673, 0.09462812050644841, 0.10021821090153285, 0.09751196897455625, 0.16572140316878045, 0.08224014738308531, 0.09899678679981402, 0.08292113869850125, 0.09774028243763105, 0.09344843987907682, 0.19434789993933269, 0.093880198496793, 0.0761023231648973, 0.09023200747157846, 0.1211894755916936, 0.12394884681063038, 0.09184609300323895, 0.13069808536342212, 0.10368754688118186, 0.15734872887177126, 0.16455789203090326, 0.1266865591917719, 0.15623422153294086, 0.12182216878448214, 0.10126431512513331, 0.18100338242948055, 0.06922516719038997, 0.1330483949610165, 0.06459386034735612, 0.069741444130029, 0.1313121731259993, 0.12897041306963988, 0.09645036022577967, 0.19439622520336083, 0.14677720756403037, 0.24193727916904859, 0.09121016998376165, 0.13181799384100096, 0.15118142909237317, 0.1953043493309191, 0.09642542406384434, 0.070988381148449, 0.06415881083479949, 0.1407670157828501, 0.12727072356002672, 0.1284563277981111, 0.12635164787726744, 0.21938856983823435, 0.08236960507929325, 0.10273516191435711, 0.10801402865243809, 0.1769482128854309, 0.05716678566698517, 0.09009612404874393, 0.1294602339289018, 0.17488960549235344, 0.09688639361411333, 0.1210654801023858, 0.1152523077492203, 0.09998085256665945, 0.16335533798805305, 0.09081336949020624, 0.13165173919073173, 0.13108115909355028, 0.15016184880265168, 0.07793520909867116, 0.09527467616966792, 0.13651850447058678, 0.18509276370917047, 0.10719242452510766, 0.09969060921243258, 0.12399590999952384, 0.12906559796205588, 0.16426711263401167, 0.17567867386553968, 0.12007253909749643, 0.08254556278032915, 0.08350180182605982, 0.17583974450826645, 0.24351918857012475, 0.1157554414655481, 0.12134372017213277, 0.11614354992551462, 0.11393498629331589, 0.09306852812213556, 0.09779471451682703, 0.1660001589251416, 0.21792060003748961, 0.1555337698331901, 0.11073495407721826, 0.09580135505114283, 0.07323448812322957, 0.0930089663181986, 0.10418581550142594, 0.18299071650419915, 0.12064834391432148, 0.11899551403309618, 0.11859429627656937, 0.15878749452531338, 0.1717463598719665, 0.10437022774879422, 0.16352889367512294, 0.19540177338889667, 0.1611152496188879, 0.0824772207332509, 0.1445595651332821, 0.10980787846658911, 0.15853448238755974, 0.1148525420576334, 0.1396543269178697, 0.13704288990369864, 0.12828094006649085, 0.16312621028295585, 0.1505475959607533, 0.08354485487299305, 0.12098016110914094, 0.14183785260788032, 0.12578360550105572, 0.1443684489599296, 0.14475213337157453, 0.10843767877668142, 0.10434972242053066, 0.19104948693088122, 0.0833409618852394, 0.11692363449505397, 0.1618170855300767, 0.08100337481924466, 0.16505329044801847, 0.12343189812132291, 0.30472831268395695, 0.16489733595933231, 0.1592708964432989, 0.16983580881995813, 0.19508159985499723, 0.11645539104938507, 0.0658889529960496, 0.3487633897789887, 0.26203896052071024, 0.08795673706169639, 0.11432238907686301], [0.05189359148166009, 0.00984188072782542, 0.034283290550644906, 0.04311797934185181, 0.024707095298383917, 0.049090010313583274, 0.03761648526415229, 0.029027263301291635, 0.06553907998438392, 0.05861672679228442, 0.07945110382778303, 0.004971964076893138, 0.034120272512414625, 0.02308289789860802, 0.03136169857212475, 0.03180177263649447, 0.06523638551256486, 0.033313789537974765, 0.03325697240818824, 0.035164249528731616, 0.017932177587811435, 0.033206726890057325, 0.03408442550737943, 0.01370376957181309, 0.03313704812899232, 0.010397650950056101, 0.020900703833571503, 0.05603050413940634, 0.023203638116163865, 0.024217822356149554, 0.0015001937468436413, 0.004277301129020218, 0.01935386790760926, 0.027999135166672722, 0.029465356043406894, 0.017209765102182115, 0.08246259830359902, 0.01740391263073044, 0.023654587400544966, 0.049137731681444814, 0.02022197373610522, 0.020523655494408946, 0.02085426659323275, 0.0451103956438601, 0.028277010523847172, 0.00729879254608282, 0.003566036973747292, 0.01542453098643039, 0.01485217482383762, 0.0626403648140175, 0.03172813801627074, 0.02863503274108682, 0.0587292414690767, 0.03648545899029289, 0.03947153893698539, 0.03649468706654651, 0.03301895928702184, 0.028199187646220838, 0.029544249310025146, 0.02841426458741937, 0.06842098105698824, 0.009646320998269533, 0.024503332928621342, 0.018908185751310418, 0.039923212557498894, 0.07108172042561428, 0.04125174680458648, 0.00783362572214433, 0.023025493836030364, 0.08699344803712197, 0.06157435915832009, 0.030632120756698505, 0.07171861375016825, 0.11139295662620238, 0.042744232075554986, 0.0990130105721099, 0.05906090260084186, 0.05362380488908716, 0.023230506406564797, 0.031842569554490704, 0.032363871045942814, 0.05352580068366868, 0.01348184366777007, 0.020401291881820986, 0.0024011730066766696, 0.019603356752278547, 0.027169456472620368, 0.036273369299513955, 0.038198410466845543, 0.035905800094561915, 0.02422629895487002, 0.024197318724223545, 0.01655382360331714, 0.0322995187847742, 0.08301416584955794, 0.04419953702017665, 0.04849179348509226, 0.03037801617756486, 0.017090597389531986, 0.022958094952628016, 0.017161124319370304, 0.02799078240059316, 0.009408406264680837, 0.022486619983932803, 0.02475085062906146, 0.0370695656830711, 0.02859840202810509, 0.018787145282008817, 0.045224535412022045, 0.02944609921957765, 0.0359194657898375, 0.017862692209226743, 0.0033030669105106165, 0.0281137855324362, 0.06274201614516121, 0.015672993546883975, 0.08618698881140777, 0.012477398949808307, 0.020287983319056884, 0.021580833409513746, 0.012733227856058096, 0.06476547542427268, 0.05925015958824328, 0.046538019752396007, 0.017067479701446633, 0.053293921519070864, 0.011405352636107376, 0.023967639709423696, 0.04160125680001719, 0.03128860677991595, 0.03781735198572278, 0.026762170916689292, 0.07205052593989031, 0.005340445911445255, 0.020758537176464285, 0.02927565461556826, 0.018562579028574482, 0.02352432903301503, 0.04501866449468902, 0.03730736167303153, 0.04745356026770813, 0.004653250241452562, 0.03741002402135304, 0.04360862462116139, 0.07477478297161204, 3.08050558227738e-05, 0.055479367463184256, 0.008996811163212572, 0.04008266828688128, 0.04433148493990302, 0.031409260484256914, 0.014941288524174264, 0.046152584720402956, 0.013358108566275664, 0.015686874677027975, 0.023406660882756114, 0.039068953932396004, 0.012291491380892694, 0.01577956764958799, 0.0177421267144382, 0.025024369791416184, 0.009907824153612767, 0.09338738529809884, 0.02417564801206546, 0.07718936340617281, 0.015210120705887675, 0.008301807251492781, 0.036718830931931734, 0.05893299874982663, 0.0358216176474733, 0.06158875088606562, 0.07303076476923057, 0.014380637090653181, 0.0564077492537243, 0.07070486207625695, 0.007256853144748935, 0.007192950413030173, 0.025326326356402466, 0.0366888261134071, 0.03360076913876193, 0.011401933667782162, 0.004476065240201673, 0.00765158495466624, 0.0336918522869902, 0.0310403240312423, 0.08871029091200658, 0.056739410385489464, 0.050639129509883266, 0.04576622688078454, 0.037067424905087264, 0.05173256155103445, 0.052809678217662234, 0.0481381953161742, 0.04252781333135707, 0.01751790821020092, 0.075663100661976, 0.023931387279714857, 0.020563968956204395, 0.039119687995740345, 0.04185249796137214, 0.022018088160880973, 0.031005942661847388, 0.029297893600804464, 0.061056860855647495, 0.0291741254207279, 0.026251027094466344, 0.012563034310005605, 0.02408329600335232, 0.0031536814889737536, 0.02551327971741557, 0.020918791880831122, 0.036916830843048434, 0.018305901105382612, 0.053961186071059535, 0.12884440911667688, 0.017126563138195446, 0.0478507339555238, 0.026374495022797158, 0.015051830360399825, 0.0055936493112572604, 0.046248305655483685, 0.013142457414817597, 0.04888388155294316, 0.015461809700354934, 0.05193280402038779, 0.05788653490266629, 0.011168516773198332, 0.020110042599428977, 0.032203886059245894, 0.028082304900246005, 0.10302121870751892, 0.014471947548112698, 0.04337784129061869, 0.06937192074422326, 0.021985367505944202, 0.03856344534350293, 0.01337922627239355, 0.030930954364261458, 0.03730013527508293, 0.06951327994465828, 0.014721254884664501, 0.015200583896200572, 0.03697227054674711, 0.019400491745078137, 0.02864940750545689, 0.055400640437645574, 0.016695223515853286, 0.025176247980977808, 0.040673523010419946, 0.055148015064852576, 0.03017193152170096, 0.034889605694583485, 0.03307089775002428, 0.040947417063372474, 0.014796663873961993, 0.046404236395444186, 0.015042381760265146, 0.013199034512841275, 0.03561395200501595, 0.023691087495535612, 0.014960809976660779, 0.03431567024173481, 0.016361513208331804, 0.01609769031139357, 0.010922052498374666, 0.06516159059745924, 0.018422159599140286, 0.04705343155988625, 0.026246580993756652, 0.04349895639877234, 0.014517372074936117, 0.019890107347496917, 0.03661686068932925, 0.015374726516061595, 0.06171657331287861, 0.02082081142413829, 0.013927357886651797, 0.029256757415298904, 0.04481778759509325, 0.04893699388152786, 0.03986289079434105, 0.020868746530530707, 0.007092580240818539, 0.01816664875618049, 0.04771929154438632, 0.026834311063534448, 0.013087248413025268, 0.0345975676152323, 0.008151977389518703, 0.03521710740668433, 0.03927298601982849, 0.07374847161450557, 0.09316370622920138, 0.036564830624099286, 0.03295708707134638, 0.025680061928661804, 0.027340420155919025, 0.04026390499036227, 0.06856244882302624, 0.04822503762053592, 0.014783406996035149, 0.061427476682833264, 0.1272359282842704, 0.03964145089100514, 0.05448574453060116, 0.04207751374425633, 0.007224602375312575, 0.0023084662513740894, 0.013153374195098877, 0.025659504013934305, 0.07915986981242895, 0.01933545246720314, 0.016906839928456714, 0.05462948878162673, 0.047428457864693234, 0.04702833254954644, 0.026319196115114858, 0.0072846035306741086, 0.048556003253906965, 0.06563999171235732, 0.03214360500818916, 0.055590019561350346, 0.02727283806806164, 0.02855590877256223, 0.05869699748499053, 0.10019364793385778, 0.033381151101951084, 0.022123529110103846, 0.012850950289118503, 0.030248806146638732, 0.03302925605592983, 0.0051668439991772175, 0.04461738906268563, 0.05038897061188306, 0.015880230015942028, 0.030331139585801532, 0.0016712655716608943, 0.022111166202064072, 0.010178154201379843, 0.06300688907504082, 0.02807723793999425, 0.02036999784676092, 0.0549675247498921, 0.05555172983024802, 0.033595432460840256, 0.05941660422831774, 0.0824934784322977, 0.0864593256264925, 0.015626028745568225, 0.04576448304578662, 0.0429572377886091, 0.007237861797745738, 0.08009692667318241, 0.04784839300970946, 0.14007972766246113, 0.11987313122621604, 0.1522557535873992, 0.07760163449815341, 0.08629427198320627, 0.11135753709822893, 0.09869615507445165, 0.1720498957272087, 0.1310448981821537, 0.1901647722614663, 0.20406495566879, 0.15283994509705476, 0.2000055249248232, 0.1482524648308754, 0.11972801972712789, 0.07743523057018008, 0.08624081020908696, 0.1424286530486175, 0.05992092538092818, 0.18807164100664003, 0.10228643313582454, 0.1217571244175945, 0.0818233165357794, 0.0680594372430018, 0.11775930465332099, 0.1177878709776061, 0.12182968695248876, 0.15139385126531124, 0.05540034866758755, 0.12077091448009014, 0.09936400316655636, 0.1394246970968587, 0.1422128789126873, 0.10424553336841719, 0.1480256984276431, 0.07825304847210646, 0.23635198601654597, 0.14468455128371716, 0.13014872984162398, 0.12740941611783846, 0.07781651975320918, 0.2677741013467312, 0.12292823514768056, 0.09256547583001, 0.11353553951318775, 0.04092885573793735, 0.12662911441709312, 0.1609623892498868, 0.09311848865555865, 0.18305705008762224, 0.1112403744565589, 0.12398620694875717, 0.1276783195457288, 0.16098114395780222, 0.12192434258759022, 0.11133831420115062, 0.08260698377021722, 0.11521497475249426, 0.19143498981637613, 0.08394417273146765, 0.07719401815640074, 0.15950081124901772, 0.12685498515410082, 0.1652340114648853, 0.07632319309881755, 0.14820142542677267, 0.07818018738180399, 0.1545447643314089, 0.09173952907856021, 0.11821545660495758, 0.1562414818576404, 0.18537692060428007, 0.17716286065323011, 0.17470560036599636, 0.1294922743524824, 0.12620142022413866, 0.10037635705832924, 0.1690402536519936, 0.16231468240065233, 0.11424536178154604, 0.10684455997709717, 0.08884182492537157, 0.07460900329585586, 0.19925928568201406, 0.09552297248904194, 0.1338527982256242, 0.07696046640298196, 0.14085384112383637, 0.18433692998119763, 0.13247685134410858, 0.12169886540089335, 0.1274430171719619, 0.1785822202052389, 0.10523318858551127, 0.12778748225952896, 0.16702348472816603, 0.15834069278623375, 0.10666685844106333, 0.14325856922992639, 0.14711769643638814, 0.15765527742249624, 0.1505033690482378, 0.09166090722594943, 0.12103710376790591, 0.13863576443067618, 0.14163958467543125, 0.059388255035238605, 0.11010241016213383, 0.17210552202803747, 0.15477332206709044, 0.09506405889987946, 0.1448072711271899, 0.12445823661983013, 0.25236687809228897, 0.20155559746282442, 0.16288609031055654, 0.19413152869258607, 0.15884592996111938, 0.16267165967396327, 0.14778063872030803, 0.1378121721957411, 0.23029513816748345, 0.1616381558456591, 0.18228656000324658, 0.2697851434350014, 0.1196190198617322, 0.09436431966189827, 0.09514444494353873, 0.09569269445325647, 0.08166881411203317, 0.1701175229890006, 0.07294233130025012, 0.11287890760494129, 0.14769708391811165, 0.23525715619325638, 0.11682497550334249, 0.128461091113942, 0.1572160752756255, 0.17389798084540026, 0.07911372264581067, 0.20219762729746954, 0.12924087712807314, 0.20889883914164134, 0.11040668562054634, 0.10914604219474963, 0.07614576297679118, 0.15969320306820528, 0.26363080367445946, 0.12527075516326086, 0.07514960571591343, 0.19009377035711492, 0.04704744348834668, 0.0985958268865943, 0.09815565443464688, 0.1074144004711083, 0.09630073646881751, 0.20982418448797294, 0.09348079921411616, 0.11263184621930122, 0.06001940116818462, 0.10738285537809134, 0.11858892227922167, 0.1241512130945921, 0.08264487995100872, 0.1206934664930616, 0.14999182149767876, 0.12571606412529945, 0.12003489397466183, 0.15928427715386662, 0.17668602695422514, 0.17857825756072998, 0.0984355229884386, 0.10540050853575979, 0.06903112653110709], [0.05681792027982218, 0.02124778806631054, 0.05982856997953994, 0.052143495929028304, 0.07899717068565743, 0.07967797879661832, 0.03372650167771748, 0.01961894779066954, 0.0364247572475246, 0.10149340211812939, 0.003949098405428231, 0.02680609079210886, 0.029986162204295397, 0.02357912921745862, 0.030158896863992726, 0.06398687684642416, 0.027339692427111522, 0.04354381774153028, 0.15359516814351082, 0.016738634490008866, 0.013070497079752386, 0.003376922266657597, 0.04285052797890135, 0.050090829110039134, 0.07457180600613356, 0.06003509568316596, 0.02195049080598567, 0.008530863710413021, 0.04317471844011119, 0.029442614942256893, 0.019688663871160576, 0.014480834660519446, 0.05281711156879153, 0.06955871464950697, 0.057446613508675776, 0.01735333463044039, 0.05529601373044508, 0.035483367940677066, 0.014681365507255708, 0.028467729754213775, 0.03729724132322839, 0.018380913151694194, 0.028763723692723682, 0.08107935038528272, 0.05533640692010522, 0.04243165134851422, 0.04336451147017734, 0.0674951539507934, 0.04116117595029729, 0.042213400559765954, 0.0795171388557979, 0.02234161026509745, 0.0389247720262834, 0.08478447049856186, 0.038428681503449164, 0.040985771255301576, 0.03926423970343811, 0.05390789393069489, 0.043418729810842445, 0.022162287030369043, 0.03383680433034897, 0.0006878783398341121, 0.02717110192004059, 0.011996363422700336, 0.02949493338486978, 0.04179452392937882, 0.040492903773805926, 0.11193801023598228, 0.0027443728384761406, 0.029564157527472292, 0.04192622757649847, 0.07639230867581707, 0.008952278909938676, 0.048091739416122437, 0.011824417559962188, 0.06702940751399313, 0.021110018316124166, 0.05152737934674535, 0.013809021379399513, 0.02835228550247848, 0.05316406009452684, 0.10381623104746852, 0.019688848771953156, 0.0287154696748725, 0.06441447604447603, 0.02117403130978346, 0.04419387125277093, 0.027723634682063545, 0.015031754205535566, 0.06418013040508543, 0.04468997534630554, 0.07884131119187389, 0.02946553924786193, 0.020480716102091328, 0.029906088286744695, 0.019259587163105607, 0.08556608177189316, 0.03941645207149642, 0.020091443954567825, 0.05558622315792101, 0.04126781112115298, 0.02059297972092671, 0.017553765393261398, 0.033567748232079406, 0.009266582267758037, 0.008322838444395788, 0.031225455525730337, 0.012852214060590735, 0.06439552456140518, 0.03585296257265976, 0.018374592597995485, 0.025606508732640317, 0.07263821869024209, 0.020789858352925097, 0.051628175723765574, 0.06613044360918657, 0.049329899584076235, 0.021945668118340627, 0.025315968519342796, 0.021392119250127246, 0.02197109961083957, 0.02247638428317649, 0.050095446540841033, 0.08018551620521716, 0.07821101322770119, 0.0057967988790811175, 0.006417049011880798, 0.04489164952454822, 0.05097524183137076, 0.028114665931622897, 0.06958574748464993, 0.02741078763002796, 0.12451659063143389, 0.04937499502141561, 0.06597879781786885, 0.07211753805833203, 0.04067327195246305, 0.047217603107648234, 0.035777187174452205, 0.03958257440743702, 0.005636157833838037, 0.024658308630543094, 0.028881327382155826, 0.03366145391815475, 0.0426043079766844, 0.024192192392157655, 0.01575650254796658, 0.04373433680406638, 0.01906830644501107, 0.047555801924318075, 0.025674681145963923, 0.014809489882151996, 0.027223768111850535, 0.03237879881635308, 0.04579774483240076, 0.009232771715947559, 0.06988400433744703, 0.015671134360932877, 0.004815747079971645, 0.06301900092512369, 0.010718218882435133, 0.025670053537136743, 0.011662229030792202, 0.02751325150685651, 0.03503589445192899, 0.047657012207699675, 0.056447406232889207, 0.017379707590277706, 0.008531523585718657, 0.012147848061951143, 0.009889163592431163, 0.020115530251392295, 0.04665350301989487, 0.04573262582666107, 0.06109731511345931, 0.02306403632142714, 0.0014783914625045977, 0.0636806200657572, 0.013952830939420631, 0.02757696424877005, 0.04644364910200238, 0.04603843138154064, 0.023971380133713995, 0.010080055849227523, 0.021125307406431863, 0.07324608428669827, 0.08648496746484723, 0.010556948920046645, 0.02360091867324497, 0.03545480500906706, 0.03656200791842171, 0.049925171570586305, 0.016853067724566375, 0.04244308127090335, 0.060986802114972045, 0.06743169057049922, 0.013988142749959869, 0.019059361657127738, 0.04086681388850723, 0.051874429652733464, 0.03614567579435451, 0.05754347438258784, 0.028278028326375142, 0.010161855790231909, 0.016080713365226984, 0.037858908862939904, 0.05259511187406523, 0.1335066639419113, 0.049079815324928076, 0.04266105046761887, 0.015932687558233738, 0.05195922278133886, 0.02360239448691053, 0.02009528107009828, 0.014279140126226204, 0.014894573084477867, 0.04893650533631444, 0.05374774270291839, 0.03165052718083773, 0.029233371705881188, 0.04806632488699896, 0.026155336693461453, 0.014018509736550706, 0.012100381144721593, 0.03657283055196915, 0.06643341628036328, 0.08779765452657427, 0.018286489914836626, 0.023120185094220296, 0.03471437402601753, 0.008223913127689489, 0.046146087747599394, 0.013219186154726361, 0.02547390093760831, 0.07297431065567903, 0.06938427008156266, 0.04811705216499312, 0.028619358582156043, 0.03497812398044126, 0.05936184645231281, 0.01744976293827806, 0.03182568081787654, 0.010379434829311711, 0.01366945605592004, 0.06427156978419848, 0.02741875363114689, 0.018437139956014495, 0.025617188873833845, 0.005413057216043983, 0.014297094162819641, 0.003265806856299085, 0.026118595718539188, 0.011137631555487002, 0.010621592103104507, 0.019628004536830952, 0.03764497355691024, 0.03581754643736141, 0.11036028061062098, 0.02529752254486084, 0.023116219057036296, 0.0626944304843034, 0.021614183405680314, 0.03323763755283185, 0.03437706069754703, 0.0589560621551105, 0.05419300077483058, 0.06367335974105767, 0.03274325015289443, 0.03334526338481477, 0.028594768473080227, 0.05597469124144741, 0.008307631626459104, 0.04848418032218303, 0.00998460378364793, 0.0394207777322403, 0.01918010357102113, 0.013319483808507877, 0.05568910263744848, 0.04176023416221142, 0.047838825665946515, 0.03516343189403415, 0.021717256267688105, 0.031319653149694204, 0.033363980773304186, 0.07026312220841646, 0.0885398361299719, 0.02542241200405572, 0.008972159985985075, 0.008775772443706436, 0.06218250295413392, 0.04261809580826333, 0.06832205743661948, 0.004686734672369701, 0.006610428523604891, 0.036879847291857004, 0.026949156508115784, 0.035654952483517785, 0.030443898535200527, 0.07780402792351586, 0.0503616901114583, 0.028066427180809633, 0.033516936137207916, 0.02442579503570284, 0.08779008886111633, 0.0643536453800542, 0.012554711229833109, 0.09039857424795628, 0.04112358511026416, 0.0700470766584788, 0.011024264469077545, 0.06550708705825464, 0.042397161413516314, 0.06360418309590646, 0.07798030453601054, 0.04782565530123455, 0.04089985854391541, 0.04323479253798723, 0.010198886838874646, 0.02702242641576699, 0.03406911436468363, 0.041166743330125294, 0.032034639069544416, 0.0511654928725745, 0.07825129106640816, 0.021545963494905403, 0.035442265681922436, 0.04255300733659949, 0.052224750497511456, 0.04232256327356611, 0.03198995753856642, 0.03359589386465294, 0.023782662581652403, 0.025082097854465246, 0.014841443792517697, 0.052034957467445304, 0.00893336983530649, 0.027754701407892362, 0.03218698035925627, 0.050948999489524534, 0.03259129223546811, 0.026436175552329848, 0.04443392337166837, 0.04805023342903171, 0.014856162913409727, 0.014655665993424398, 0.04381521139293909, 0.03112288477963635, 0.01637413565601621, 0.023190466055114354, 0.050547218548932245, 0.10560332943818398, 0.02406799334234425, 0.10490202956965991, 0.1113423921966127, 0.11306598649493285, 0.11296220456383058, 0.24303569165723665, 0.23505500704050064, 0.14445004958127225, 0.13918750839573996, 0.09940908503319536, 0.3072026584829603, 0.13228152825364045, 0.11286090607089655, 0.12245285351361547, 0.1189425883016416, 0.0744042553539787, 0.21611499121146543, 0.09636453233127083, 0.08544613713664667, 0.3395162874034473, 0.1977723440421479, 0.10381854485188212, 0.08697966020554304, 0.1622126985873495, 0.1327079196593591, 0.15915952170533793, 0.15700734433318886, 0.130049324461392, 0.051887094508856535, 0.07065446049507175, 0.10801807272114924, 0.20030888436096056, 0.21336988279862062, 0.17355945972459658, 0.24496104834335192, 0.18341714862201894, 0.08700376855475561, 0.12408082187175751, 0.10628257691860199, 0.05885221915585654, 0.12965487848435128, 0.12802184825497015, 0.11576469668320247, 0.0749284779386861, 0.11026778950222901, 0.15463392383285932, 0.17373848440391676, 0.1723851870213236, 0.13854185518409523, 0.1007706266162651, 0.1341008706284421, 0.1684978734701872, 0.0573449893189328, 0.11311988931681428, 0.15693940940712178, 0.21133156360260077, 0.14511075269963059, 0.1448898081268583, 0.08506430512560265, 0.12430419559989657, 0.10623180892850671, 0.1114196026963847, 0.0897213216604931, 0.12055750164602484, 0.11737905362887041, 0.05729660298675299, 0.12839676599417413, 0.08515459778053419, 0.2501870979155813, 0.12571625411510468, 0.1421754780624594, 0.1579873524606228, 0.13690421091658728, 0.10482958238571882, 0.10830877747918878, 0.1087588429717081, 0.16700388863682747, 0.19274327318583215, 0.14433182163962296, 0.09824272404823985, 0.13072107412985393, 0.08729781849043709, 0.14928956489477838, 0.04504747169890574, 0.09783604408481292, 0.18414281468306268, 0.142782522631543, 0.18368313434932912, 0.11631333295788084, 0.1000091474769371, 0.17080453969538212, 0.15423271964703286, 0.19730312350605214, 0.1394357979297638, 0.11537441691117627, 0.16126770286687783, 0.07100338355771132, 0.2311719139771802, 0.09549868093537432, 0.07872171260948692, 0.11736704355904035, 0.17944990364568575, 0.13577464010034287, 0.09491864884538309, 0.09989838342049293, 0.0709297489374876, 0.08891614486596414, 0.13908635239515985, 0.13975902487124714, 0.16355467800583157, 0.18658988337431634, 0.10188560892960855, 0.12498064073068754, 0.11783300712704659, 0.11742463761142322, 0.22388740628957748, 0.19304261569465908, 0.12716430212770188, 0.11220761255494185, 0.09597839840820857, 0.1601044088602066, 0.11873878352344036, 0.08528940911803927, 0.16744815265493734, 0.11772410225655351, 0.2424165963062218, 0.09363649585949523, 0.1152420211583376, 0.2014679443091154, 0.14913715235888958, 0.14088684506714344, 0.2695598969502108, 0.11923315056732722, 0.21027280470090254, 0.11495649362249033, 0.09069601007338081, 0.14498643151351384, 0.1135737681761384, 0.13494977221957274, 0.09636698862803833, 0.1100763137053166, 0.10522482224873134, 0.10045436822942325, 0.15401751548051834, 0.15784796779709204, 0.11917379232389586, 0.11403701081871986, 0.07027150890124695, 0.12847772879259928, 0.08638951115842376, 0.10418249746518475, 0.13041622191667557, 0.09902619450752224, 0.10597281211188861, 0.18882235858057225, 0.2215864397585392, 0.08022178390196391, 0.14458419595445904, 0.09470538528902189, 0.0657745384212051, 0.11100507886814219, 0.14867464931947844, 0.07130668192569699, 0.1258245754454817, 0.0917582566450749, 0.13055874141199247, 0.15758294558950833, 0.11275683915508644, 0.06402273742215973, 0.08925831650516816, 0.08960225233542067, 0.12494994380644389, 0.14081599244049617, 0.11890053270118577, 0.13971209738935741, 0.1760458563055311, 0.10932438833905117], [0.02924724096166236, 0.021954117575660348, 0.03312294138595462, 0.012444897970583822, 0.008261523475604398, 0.049947827854858975, 0.02342099493502506, 0.025458328558930328, 0.00727587248132165, 0.027955356087269526, 0.02206596389545926, 0.07313683336334569, 0.034715340938419104, 0.0395591886980193, 0.033460363280028105, 0.007165460414918405, 0.018946151481941342, 0.024913899201367582, 0.01903385722211429, 0.024903049426419393, 0.08945809078535863, 0.013211244750501854, 0.045693535424236736, 0.02596199492524777, 0.028180655158524002, 0.01907390944792756, 0.046012477417077334, 0.026404221641964147, 0.014133117693875517, 0.010762567083085222, 0.008252368341865284, 0.020900858200288246, 0.04591838496604136, 0.04826889133879116, 0.06437717697450093, 0.030162306502461433, 0.03837552507008825, 0.025288007787561843, 0.06385731736996345, 0.008894523705488868, 0.022183168945567946, 0.029066903317081075, 0.044425122772476504, 0.037018695912723026, 0.019389472336375287, 0.03766133303620985, 0.019787660434043834, 0.041425139643251896, 0.01629784796386957, 0.04465059656649828, 0.04182332095557025, 0.026985188413943564, 0.017422088887542486, 0.05271583003923297, 0.06332084044281926, 0.016463005083746145, 0.019812360805060183, 0.03769672542278256, 0.03613102622330189, 0.03543171785505755, 0.06916739671890225, 0.017103796591982245, 0.041864558921328614, 0.10084816959819623, 0.057472526761037965, 0.07060309539416007, 0.05532209661656192, 0.025667675271896378, 0.03036808581756694, 0.007172961619549564, 0.07498592949871506, 0.036072655248322656, 0.01751119240985385, 0.06817747519484588, 0.03372627097581114, 0.044906750321388245, 0.031008035942379917, 0.025168814629848515, 0.019255341230226413, 0.07000441037650619, 0.07652998343110085, 0.011292664084716566, 0.03243212827614375, 0.016459970335875238, 0.06356622584696327, 0.014542043608214174, 0.04188640774892909, 0.029870756968323673, 0.04918768542951771, 0.06592921047870602, 0.049861043225973845, 0.027372789668983648, 0.06730069259979896, 0.04334666260651179, 0.011654680328709739, 0.02329321830932583, 0.04239253041201404, 0.052665984856763055, 0.002795031414799658, 0.08070531474160296, 0.02688972871484501, 0.041836966294795275, 0.032220628910831044, 0.05342556070536375, 0.04400990005316479, 0.0212403530188437, 0.03420923863138471, 0.03220243399430599, 0.03226317644917539, 0.03954892585586224, 0.03234233095177582, 0.06710445348705564, 0.015120793267020156, 0.013102227921730705, 0.040167274818356545, 0.019161961240960017, 0.027033398327018534, 0.030689250012593608, 0.06096322302307401, 0.010660441625597221, 0.03279533789360097, 0.01946880156174302, 0.046338947755949836, 0.026335072138213685, 0.060226259353969774, 0.0404269467773182, 0.055852412445736785, 0.03988552672256317, 0.03853156776832683, 0.041094309716884575, 0.01660682906263641, 0.00589810882229358, 0.026306195384157554, 0.06258408033422061, 0.038825733054961474, 0.02801226481928357, 0.04030320234596729, 0.05134695688528674, 0.057743350443031104, 0.02823143671931965, 0.03158819695402469, 0.05996431091002055, 0.03630575916862913, 0.04922354600525328, 0.015194385478805219, 0.003927727520931512, 0.07906426422830139, 0.0537559190498931, 0.04284993426076003, 0.023496062960475683, 0.05575080521936927, 0.013105540020790483, 0.010869739992943193, 0.03865182113700679, 0.06740678154996463, 0.052672380049313815, 0.038605395771030865, 0.0058833901254859355, 0.08519828186503478, 0.04113317959542785, 0.041306419763714075, 0.04149980902937906, 0.036260456778109074, 0.01888654557322817, 0.03660427047205823, 0.04360349489642041, 0.04730184662288853, 0.04983297223225236, 0.02485114149749279, 0.033854866932545385, 0.012182957160153558, 0.0661485604941845, 0.04331444915650146, 0.018451197505263344, 0.02092807593622378, 0.03479375244517412, 0.00977617733380092, 0.051931056792714765, 0.014172293761345958, 0.017000277593199695, 0.030028519752834524, 0.03396807371505669, 0.03307686885818839, 0.02932871605402657, 0.020443320340876068, 0.032181341733251295, 0.03168602813301342, 0.04222876259258815, 0.11893897849534239, 0.058027581976992745, 0.06736384385398456, 0.0749880193865725, 0.058454543352127075, 0.044373150382723124, 0.029229677082704644, 0.05882756797862904, 0.03909835824742913, 0.054079583646463494, 0.017758425125586133, 0.039724408582385094, 0.012788944910945637, 0.06302708227719579, 0.0387822457456163, 0.013662020160284425, 0.025037482480651567, 0.0197764561245484, 0.05867084674537182, 0.016480850554736595, 0.04349145180146609, 0.055540031886526516, 0.006814473757653364, 0.021888311553214277, 0.054235117443438084, 0.04276538879743644, 0.08671609684824944, 0.0022014307448573944, 0.054550999243344576, 0.046233754472008774, 0.04335037080038871, 0.0838283264477338, 0.010413861999820386, 0.03582110196085913, 0.0679203714909298, 0.0431715021841228, 0.026537903218663166, 0.016026352532207966, 0.033525353364114246, 0.02328687739957656, 0.025442425394430757, 0.043515631396855624, 0.04373275242479784, 0.013310219260997005, 0.0481564173741, 0.057455183405961306, 0.026857856228681545, 0.03043876202510936, 0.014779588540217705, 0.015780607504504066, 0.01548081885890237, 0.03458965589691486, 0.08230417394744498, 0.051304487378469536, 0.028299419142838036, 0.013575369542065476, 0.018692264034013664, 0.04106289015284606, 0.00952916853462479, 0.011329454253427684, 0.020332233980298042, 0.04634069498362286, 0.026917638556499566, 0.06884931985821043, 0.02107692277058959, 0.005953151158921952, 0.04917180771008134, 0.02643277100287378, 0.016142493978674923, 0.060661118876721175, 0.039235958363860846, 0.009297469181806912, 0.02594072794142578, 0.015201304839657885, 0.08087903327707734, 0.013029412632541997, 0.02935152840135353, 0.02146264787630311, 0.01913123717531562, 0.0194693138556821, 0.11206677582647119, 0.057169540519160886, 0.008326118313042181, 0.04693693048985941, 0.04535862071705716, 0.03144071736772146, 0.019086715100067, 0.012987199272694332, 0.05531217982726438, 0.021975377774132148, 0.027041401647563492, 0.06203705218753644, 0.10060223458068711, 0.05254919540935329, 0.014420519682711788, 0.012043448663981897, 0.0378219592384994, 0.07428568814482008, 0.03473824828064867, 0.03474058583378792, 0.046285818463989666, 0.0730004206831966, 0.07163341010787658, 0.043635908514261246, 0.03444718050637415, 0.06039836297609976, 0.07947042171976396, 0.045660385595900674, 0.03362077913646187, 0.035125712132347484, 0.03717270979125585, 0.03840266986350928, 0.02439603448978492, 0.006974947713648102, 0.021969233639538288, 0.04853191186806985, 0.07790847481893641, 0.046037247337933095, 0.025349759563271488, 0.018639976125476614, 0.04040679767993944, 0.0618135698937944, 0.010709266461032842, 0.07547578428472791, 0.03587256544934852, 0.02753729369890477, 0.0322893305814692, 0.015360098997397082, 0.039116118901542256, 0.014022384171507188, 0.012231934665968376, 0.007727523201278278, 0.040848958239491494, 0.06170847839010613, 0.03983767982572317, 0.08397106985960688, 0.05823344271630049, 0.041417468804866076, 0.057349691566612036, 0.07374098737324987, 0.02393778756127826, 0.020277199701273015, 0.03209468602601971, 0.05813646649143525, 0.028686645507280315, 0.017230853970561708, 0.04993415876690831, 0.07608728004353386, 0.1037895849772862, 0.02193749346770346, 0.011183292721398175, 0.005467136457030262, 0.0548065728507936, 0.008318463589863052, 0.05413590205301132, 0.03319254211549248, 0.03280168558870043, 0.025747501524165273, 0.05934665405324527, 0.05929787417075463, 0.03646775601165635, 0.017965578474104404, 0.036207737999835184, 0.05248155564601932, 0.11522587202489376, 0.16904788038560323, 0.12600805131452425, 0.15471397739435944, 0.07097103779337235, 0.11056859086134604, 0.09114219434559345, 0.11023574907864843, 0.09283508493431977, 0.1814675818064383, 0.15282211319676467, 0.1564824160720621, 0.15845615230500698, 0.0814440833138568, 0.08032927741961819, 0.19730904033141478, 0.1542303990572691, 0.15958554670214653, 0.0946994616783091, 0.11791474345539298, 0.18096546589263848, 0.14732105338147708, 0.18848558808011667, 0.10920867776232106, 0.08681309342916523, 0.13093452767602035, 0.10310771835169621, 0.12321786103504044, 0.06643649682934795, 0.09260886814445257, 0.15962643522237027, 0.16617978071527822, 0.13426179199346475, 0.17124188265630177, 0.21702330532882894, 0.06490568790052618, 0.24510411066668375, 0.1404933218977281, 0.22220525012484618, 0.107936159973698, 0.11225288441138608, 0.08142389011170183, 0.1223753783851862, 0.15172432496079377, 0.04346167089949761, 0.157394638551133, 0.1580403053334781, 0.15571088104375772, 0.10247377665447337, 0.09081316592970065, 0.10932878524597202, 0.16059341547744616, 0.10591481772384473, 0.15411886147090367, 0.09089842385479383, 0.09841114322521857, 0.08337402689669814, 0.21215626863496645, 0.06679654786629335, 0.13112800515123776, 0.1373805832117796, 0.12174168096057006, 0.12585002050868102, 0.1318527619753565, 0.17237551111195767, 0.15720441804400512, 0.10147534630128316, 0.09941450652799436, 0.14486580155789852, 0.09358974479671035, 0.13044491037726402, 0.13714108749159745, 0.11485400769327368, 0.13034589854734285, 0.09824429146413292, 0.1358927051935877, 0.1118107849199857, 0.09482482780835458, 0.11951318196952343, 0.14815417224807398, 0.14278408326208591, 0.1472675169685057, 0.08960411830672196, 0.07095282591347184, 0.12333577685058117, 0.14762070801641258, 0.13234669475683145, 0.15299360613737786, 0.08679339555757386, 0.2246072098080601, 0.10417829054806914, 0.09231648061956678, 0.23958056420087814, 0.12972488972757543, 0.12716039376599447, 0.13846786772566183, 0.1495681849441358, 0.12803243340126105, 0.11034211622817175, 0.2767641746572086, 0.11365940608084202, 0.11866730664457593, 0.12089020093636853, 0.13752348268670694, 0.18161459320357867, 0.07905748566346509, 0.09068645630031824, 0.09480569990617888, 0.10642649419605732, 0.13431545054273947, 0.11337656554366861, 0.10168148523994855, 0.12123951076396874, 0.1329814371253763, 0.14800693014902727, 0.1132386668718287, 0.12009471362190587, 0.28516783086316927, 0.23272554203867912, 0.162019546808941, 0.08516741530703646, 0.1672771754009383, 0.129662654495665, 0.1423955676811082, 0.20342040168387548, 0.1217586307653359, 0.1720564639461892, 0.16553082982344286, 0.15098811446556024, 0.21379578565912588, 0.1243196933397225, 0.09631024274442877, 0.12642608316881315, 0.23743479219930513, 0.18352408574095794, 0.15495580727500574, 0.15979046427777835, 0.1207908634096384, 0.12669804000428744, 0.1483676800770419, 0.07287810796073504, 0.10662218369543552, 0.04919308317559106, 0.11220308672636747, 0.09305669447141034, 0.11152796473886285, 0.13542993074016912, 0.18929296332810605, 0.14254092345280306, 0.13971889631024428, 0.16451811630811009, 0.13485780358314514, 0.06026066786476544, 0.10460778285882302, 0.128958810120821, 0.12807736599019595, 0.0874940101057291, 0.09314240701496601, 0.17264486237296037, 0.23370841358389172, 0.1857810424906867, 0.10372264071234635, 0.1000302770574178, 0.07547461720449583, 0.10683068393596581, 0.14103487426681177, 0.16801424085029534, 0.17208534239658288, 0.11753146616475922, 0.2572780874158655, 0.160682154287185, 0.09813193963574511, 0.07777802646160126, 0.07029673004789011, 0.0995944133028388, 0.12136115852211203], [0.07739426741110426, 0.03207638593656676, 0.04053457939465131, 0.02029223942996136, 0.01985843333282641, 0.021364314581400583, 0.0958309934607574, 0.05261574951665742, 0.025353591589789306, 0.05041499582252332, 0.08619629152651344, 0.019932739702718597, 0.020405052662161843, 0.035656353658331294, 0.012360821544591869, 0.01694681412274284, 0.03377572939332042, 0.04398059073303427, 0.057495067694357464, 0.04917665923546467, 0.04035432995962245, 0.036590218011822016, 0.10178099918578352, 0.021082132223195264, 0.048255799005606344, 0.05139952977853162, 0.0913843974205, 0.023089747709621276, 0.012485544762707182, 0.03503603355160781, 0.05076487561953919, 0.03752368202965174, 0.035541355543370755, 0.016985524545556734, 0.058138081404779635, 0.05568433253626738, 0.017486644709216695, 0.04191445838660002, 0.01829298010229, 0.040206565388611386, 0.06873470850821052, 0.059166720137000084, 0.02275548269972205, 0.036376292883817635, 0.0463369562556701, 0.02954289223998785, 0.032925399485975504, 0.04304962372407317, 0.008690262612487589, 0.026548359443300536, 0.04085694459666099, 0.031768371750201495, 0.05882747976907662, 0.038318701154951534, 0.031752921507826874, 0.03193587829758014, 0.01514163616645549, 0.0031057198773071703, 0.027068733038114648, 0.06931762437203101, 0.03468338193904076, 0.0526975910179317, 0.046204160167170424, 0.03450119528653366, 0.02400314575061202, 0.027440951904281974, 0.04478562164253422, 0.08996530249714851, 0.013070156964074289, 0.01584627103459622, 0.06030862671988351, 0.048345728644302914, 0.04223850974813104, 0.10410829287554536, 0.001422192223669429, 0.032680536553795846, 0.018188139656558633, 0.02705106059355395, 0.018473692637469088, 0.012912270346922534, 0.005373083021757858, 0.027095950774050186, 0.02209119182745261, 0.03654772814895425, 0.010909974575042725, 0.021858189687398926, 0.12923409177788667, 0.010364658881111868, 0.03312638155849917, 0.07042248294289623, 0.02254456008917519, 0.03169525281659194, 0.05414101142170174, 0.05468470456876925, 0.029983940002109324, 0.04524921712332538, 0.04930248337664774, 0.07308793812990189, 0.020110006976340498, 0.03786028628902776, 0.018187607006568993, 0.02661258787182825, 0.06425903045705386, 0.01995388455023723, 0.10866696933018309, 0.01863974372723273, 0.05171223942722593, 0.06348111041422401, 0.06447052982236658, 0.02117869284536157, 0.040204672275909355, 0.08672069731567587, 0.03614620165899396, 0.014800465366403972, 0.035967122696872265, 0.037709844897368124, 0.06717223913541862, 0.03004408873883741, 0.022153550892003944, 0.06529350459043469, 0.003364853885224355, 0.018455938768706152, 0.10748213862201997, 0.052617232115673165, 0.018736706381397586, 0.0642464639885085, 0.060873805678316524, 0.05569550800802452, 0.021006299149511114, 0.037611803372523615, 0.044705456122756004, 0.036145665616329224, 0.024429633847570846, 0.012433334037528505, 0.04539932942550097, 0.04387834568374923, 0.06485684694988386, 0.03791784302198461, 0.025376091811007688, 0.03280431491189769, 0.032622657516705136, 0.011960889611925398, 0.0093237954923617, 0.035188910883984396, 0.025485951719539504, 0.04531381365710071, 0.013372572388366928, 0.03434775137741651, 0.005266977956385485, 0.01801168662495911, 0.04838704803426351, 0.024952443383101906, 0.027565441027815853, 0.016954317023711543, 0.013822854163923433, 0.07629272009113006, 0.12142670500491347, 0.015417124776701843, 0.009728506007897002, 0.01877360511571169, 0.05217343628672617, 0.03175153051103864, 0.004718024890670287, 0.01208739313629589, 0.05458729747416718, 0.011249039372030114, 0.022790004865133336, 0.015863534661808183, 0.03826692554035357, 0.0915900817407029, 0.029046245318438326, 0.08515838400593825, 0.022373922102685486, 0.040914630251271386, 0.01904148225938635, 0.016985924881217734, 0.03400173583733184, 0.06150405614503792, 0.059538964448230605, 0.07135975014950548, 0.011442934146283992, 0.02653421029182417, 0.06111048547817128, 0.06939852610230446, 0.019171852585194365, 0.07163575105369091, 0.020815698662772775, 0.12569549094353402, 0.03214508082185473, 0.03532557122941528, 0.014562207972630858, 0.03181365039199591, 0.04956199927255511, 0.04008791336257543, 0.09428928047418594, 0.05486344087070652, 0.05557766343866076, 0.04072246913399015, 0.04931462915348155, 0.029278701237801994, 0.04335556498595646, 0.061294259902622016, 0.047829736689371724, 0.018370314434702908, 0.04676381924322673, 0.012249076156876981, 0.050943686560328515, 0.015888867766729424, 0.019802885063524758, 0.049069301424814124, 0.04499165880094681, 0.0807027363085321, 0.027889019111171365, 0.0073830207942851955, 0.059499677270650864, 0.04202820121177605, 0.04372688648956163, 0.026654212602547238, 0.011874532460102012, 0.02364313372943018, 0.0032004174967629035, 0.014716544155297535, 0.08285653537937573, 0.025557733939162323, 0.03491412116480725, 0.027096748052697097, 0.028980488489781107, 0.020776922082794563, 0.038662399497947524, 0.06935412955603429, 0.05712666389133249, 0.019948681882981743, 0.031572410836815834, 0.017750291187050085, 0.055334622373006175, 0.020514692046812603, 0.024330550771472708, 0.02773237760577883, 0.01471789613632219, 0.012989171265092279, 0.016781149797939827, 0.05650135994489704, 0.038559957673507075, 0.033281121469501934, 0.05788886906313045, 0.024079974574436034, 0.02836358141420143, 0.07878666198147194, 0.04379513014906219, 0.12946383016450064, 0.030687933654657433, 0.0419715978205204, 0.033921227657369206, 0.037222100355263264, 0.051585716394973655, 0.009120629385246761, 0.02701363429826285, 0.006041316182485649, 0.07391642260232142, 0.03684507576482637, 0.03171104911182608, 0.012527429033070803, 0.014877172053924628, 0.02004110174519675, 0.012840268451587429, 0.029560279699840715, 0.01446495354840798, 0.04547227194000568, 0.04924388848511236, 0.03551978152245283, 0.027909088480685438, 0.025672877939151864, 0.10979027726820537, 0.04213120282760688, 0.06678019517234393, 0.03521669689299805, 0.020603379966425042, 0.03673442027398518, 0.03990757232531905, 0.04886167649445789, 0.017876127202595984, 0.0289931940580053, 0.024140891752072742, 0.05646174707050834, 0.00806596374604851, 0.03287905554420181, 0.02730422540168677, 0.06048739355589662, 0.020516541054738418, 0.049390604719519615, 0.010108389775268734, 0.02254074502603284, 0.0384602910572929, 0.027180567483550737, 0.044518509547093084, 0.07729234466595308, 0.016374987217464616, 0.016549177334776947, 0.16372999788394996, 0.051626591344497035, 0.047158041303711276, 0.0038589490910193747, 0.056041187673274956, 0.04222840636170336, 0.04449423495680094, 0.020673657534644008, 0.038539323423589976, 0.11172018692429576, 0.06638660414942674, 0.055321228091738055, 0.050584317451076846, 0.03204424034005829, 0.008614545737925385, 0.05647455781166043, 0.005444470842901085, 0.03358664203967367, 0.013259536087779062, 0.017196793208963106, 0.057909272611141205, 0.029409936695758785, 0.047556619559015544, 0.03512919980234333, 0.03461721459669726, 0.03103980834462813, 0.02452130732126534, 0.012759393014545952, 0.08137933071702719, 0.03074636569778834, 0.06162612459489277, 0.008929855023909892, 0.03647509776055813, 0.029645951531295265, 0.061461342365614006, 0.020125480967440774, 0.008363507288907255, 0.023924228735268116, 0.026501630432903767, 0.03299749722438199, 0.031086216747228588, 0.02036512766166457, 0.04212487209588289, 0.014947529350008284, 0.02708286522621555, 0.06574506285999503, 0.012959181713605565, 0.03864125295409134, 0.018833387443529706, 0.05219635719965611, 0.041833149535315375, 0.0689229341223836, 0.0184707240467625, 0.0652148759524737, 0.16689311100968293, 0.14375056140124798, 0.2066045222537858, 0.18033007213047572, 0.06495505810848304, 0.11551289233778204, 0.10513310467026063, 0.10091677627393178, 0.10689666468117918, 0.20507848342614515, 0.17739653454295226, 0.20184358129543917, 0.14823083313448088, 0.10488076428217546, 0.10693920882684843, 0.058702303628836355, 0.13811011692242964, 0.11210675510976996, 0.15172328001686505, 0.09335795723434005, 0.1276847927698067, 0.08034506014415196, 0.1548635536538703, 0.1012774244216936, 0.19498382295880998, 0.15215527612183774, 0.22251576132008008, 0.09029566762702805, 0.13923531797315392, 0.124785521200725, 0.20402550564280578, 0.12905543350747653, 0.08956631712083306, 0.12124269987855639, 0.256197669676372, 0.12404471023806504, 0.09585727990737983, 0.1550544798374176, 0.15504664954330238, 0.10213667367185865, 0.15830470328884466, 0.20862357105527604, 0.0752173438668251, 0.12399656139314175, 0.1522222610988787, 0.041697574845914326, 0.1644460151770285, 0.14021638461521693, 0.08202901442668267, 0.10637960742626872, 0.1006508380440729, 0.15898931798126015, 0.1031140083713191, 0.20966007400836262, 0.09784099060509886, 0.12520633504859038, 0.18040695014808858, 0.05795846639999321, 0.13818813487887383, 0.17406803529177392, 0.10456897065575634, 0.14108820711927755, 0.1483206304588488, 0.14281146893543856, 0.14068438378827913, 0.1316760985979012, 0.1935521819229637, 0.17578995360859803, 0.13211549073457718, 0.11096233794731752, 0.15625695245606558, 0.122961144096085, 0.11456915869244508, 0.19708467594214849, 0.08396167893494878, 0.1501987746783665, 0.1809581784265382, 0.06740203859018427, 0.1057609124109149, 0.08114523613559348, 0.09351682263825621, 0.09765478023993117, 0.12451443289007459, 0.09919476974755526, 0.1176996071423803, 0.11270489729940891, 0.25629250173057827, 0.09524103440344334, 0.10164170273180519, 0.15394773493920053, 0.14474494090037687, 0.1385132074356079, 0.13160787868712628, 0.10751624179205724, 0.14578190525727613, 0.08465573204947369, 0.2084679151219981, 0.17074951050536974, 0.11528692660587174, 0.26327527846608845, 0.11468797017421041, 0.08290944075477974, 0.14993756583758763, 0.0841360285079905, 0.27460993453860283, 0.08614776948732988, 0.25253732608897345, 0.14284547711057322, 0.1266753633639642, 0.13072518605206693, 0.10152257912393127, 0.17828537470528058, 0.15831458275871618, 0.16386479565075465, 0.10338279644825629, 0.09717194150601115, 0.1621676031500101, 0.13736269702868803, 0.10744093797568764, 0.11053391093654291, 0.05494189987491284, 0.0727846058351653, 0.21159308456948825, 0.19376609687294277, 0.17589963200901235, 0.14137803656714304, 0.1645923208977495, 0.10499131120741367, 0.13936752373618738, 0.10761784562574965, 0.13698004399027142, 0.1325935593673161, 0.12894928348915918, 0.11600274033844471, 0.1598286386579275, 0.07124026013272149, 0.35871709138154984, 0.12929490208625793, 0.09541593358985015, 0.2640317907290799, 0.09225007239729166, 0.06887082941830158, 0.14538996985980443, 0.07346583463783775, 0.14735321594136103, 0.1630449624998229, 0.10421658027917147, 0.09221966045775584, 0.1515232478933675, 0.07414622884243727, 0.17456514361713613, 0.058546674836959155, 0.10977949534675904, 0.07473600469529629, 0.1049564548635057, 0.17204058622675283, 0.22251691482961178, 0.11742471903562546, 0.14120883707489285, 0.09689834261579172, 0.09621954296848603, 0.15115617401897907, 0.09696734284183808, 0.1817624188427414, 0.127668792914067, 0.1762015258095094, 0.09889545438012906, 0.09839331811027867, 0.08464904847954001, 0.18862934250916752, 0.11386051028966904, 0.1994337234646082, 0.13784799884472573, 0.15154025198093482, 0.10923279289688383, 0.13841419560568674], [0.01975852922935571, 0.08399685419031552, 0.07942200146083321, 0.026021817965166907, 0.031835458507495265, 0.007009121705777943, 0.0236934521900756, 0.05150500465450542, 0.08814418236059801, 0.037344881266887696, 0.04360839052657996, 0.05127917802227395, 0.04537759255617857, 0.043771571413214715, 0.02649509783701173, 0.015729527388300215, 0.05264182561742408, 0.04359620064496994, 0.06771199338670288, 0.08710328928594079, 0.039459739213011095, 0.07032683664666754, 0.04077296231740287, 0.016597487331767167, 0.08851367860500302, 0.054146653440381796, 0.04395990898566587, 0.0728035776742867, 0.02600337199068495, 0.042768435419670174, 0.02241761127619871, 0.030057001260242293, 0.018984230867187892, 0.03918613353744149, 0.024398599352155412, 0.05406504264101386, 0.06524352370096104, 0.023903363783444678, 0.155507714088474, 0.027937793904649358, 0.04743180304233517, 0.06386859462197338, 0.04468158186812486, 0.026847159124112556, 0.03355385183489748, 0.027568762456732135, 0.03883876771266971, 0.04541051846795848, 0.04453230416402221, 0.07545890233346395, 0.021426882295470153, 0.016526887459414344, 0.05756609674010958, 0.06844251775848013, 0.033305385881768804, 0.0188485527011965, 0.02699708822183311, 0.03158657864800521, 0.047177535614797046, 0.030281029774674346, 0.039570258996848545, 0.05450883507728577, 0.0192684250817235, 0.015781330144298927, 0.03363444483173745, 0.054859447692121775, 0.014405768331406372, 0.08319454759891544, 0.0876955282209175, 0.03876258519345096, 0.016257202019914985, 0.02000032687958862, 0.017583983950316906, 0.007096040345329259, 0.009100412434366132, 0.03953081575621452, 0.0313928501148309, 0.06087856220879725, 0.04878512417365398, 0.04560932244307228, 0.04407881206965872, 0.01724677749111184, 0.03207991771133883, 0.0572309818650995, 0.0674178891682199, 0.011997858744247683, 0.016458335066480295, 0.03419679769181779, 0.03671279875561595, 0.005478903950591172, 0.048073968583984036, 0.0055196024810097045, 0.018790534564426968, 0.04760481929406524, 0.053143832965620925, 0.002025731735297346, 0.010275080384287451, 0.017809361053098525, 0.04390999934236918, 0.02309267219555165, 0.05101007103387799, 0.05348396221441882, 0.01271729330931391, 0.04102246303643499, 0.0832113820527281, 0.0664737755432725, 0.054034389821546416, 0.052473671069102626, 0.023611327400431037, 0.03840313126732196, 0.05242522366877113, 0.02787257481499442, 0.041819982563278506, 0.04859049318890486, 0.0277270205718066, 0.0023381301060518517, 0.03264288803828614, 0.06621230885918651, 0.044230810699186156, 0.062354626932314465, 0.04540337688688721, 0.07465293843831335, 0.036928172555885146, 0.02256709084446941, 0.03822186742244022, 0.029503269187573875, 0.11658858747354575, 0.06561903855098145, 0.014269360740269934, 0.04456421905862434, 0.054045670466231446, 0.02353621187752911, 0.031904187319534164, 0.05469020748777049, 0.033798745301152976, 0.043677360218550475, 0.07152914641691105, 0.010174470604397357, 0.044146550220570395, 0.005322905357128808, 0.02326718800967293, 0.005830488142757011, 0.03581884243924703, 0.08008588690842901, 0.07786709096814905, 0.10230518784373999, 0.0365484575740993, 0.004214531974866986, 0.06684585700609855, 0.1279549989849329, 0.04283246198402984, 0.03337332759318607, 0.038215495978615115, 0.08710119261273316, 0.034388894348272254, 0.039588518374200375, 0.01376773082717721, 0.019546702470896498, 0.027496642665937543, 0.037146749041442356, 0.04247761531067746, 0.017012313108092973, 0.0708117245563439, 0.029067110270261765, 0.021933120309508274, 0.02436388380426381, 0.030355787370353937, 0.006933448087823178, 0.04048389282875827, 0.012958884854534907, 0.07565679028630257, 0.0283852080215833, 0.023690422531217337, 0.0035368972873714355, 0.10099014626549822, 0.03810253346871052, 0.057415950511183055, 0.029689401521214416, 0.045106412643300633, 0.0241650357243738, 0.03042799367436341, 0.02802508743479848, 0.034962490533611605, 0.05220600936029639, 0.06810573368732419, 0.07158862679664578, 0.030665989832154343, 0.018459511255579333, 0.06878977841032402, 0.025765594660437534, 0.025188453129625747, 0.0329213350612138, 0.014505029522946902, 0.06422648791755949, 0.10815879409866673, 0.03892579661416156, 0.02077066259724753, 0.041656961132373126, 0.034682452346065214, 0.03346826142764517, 0.03605005663952657, 0.04134923532339079, 0.048276772523032765, 0.0283411812768983, 0.028907640970179012, 0.011781609633804431, 0.019057750136458447, 0.019510838502485837, 0.045707638774599345, 0.042859053771410666, 0.01100096442470593, 0.03531807681013431, 0.002829748022902225, 0.025383883089359318, 0.06950749882629939, 0.04084822202899626, 0.04837896328951631, 0.05129413293408496, 0.0685270225097026, 0.040454081392713954, 0.03160473285242915, 0.019716914676662003, 0.01929359364190272, 0.03451860310243709, 0.028113103604742458, 0.03357963277293103, 0.02964088966005615, 0.032330728002956936, 0.020474152972123454, 0.022546529537066817, 0.025653624507997717, 0.006692877313720861, 0.049775870117758, 0.04958614494119372, 0.012809223778146719, 0.023819861567712257, 0.04840113442125065, 0.018081523145415952, 0.038757716704692156, 0.0443951518807028, 0.04887168149330786, 0.017107632011175156, 0.061023449791329246, 0.0842886921018362, 0.05153452432049172, 0.030787685087748935, 0.016911440395883152, 0.03976918510826571, 0.033889343296842914, 0.029234426827835183, 0.029396376173411096, 0.013708071483831321, 0.035215845331549644, 0.023929926733087217, 0.060607765668204854, 0.045414063813430924, 0.005013696949130723, 0.03251767118594476, 0.08271145780703851, 0.07474576202886445, 0.04076985123434237, 0.021568304260394404, 0.03445443404572351, 0.01936823927930423, 0.040666822477110794, 0.043483105820736716, 0.03609373054600187, 0.030690121930092573, 0.013330537992130433, 0.05068061174824834, 0.012137341795356145, 0.04071759385988116, 0.032561687752604485, 0.007216389557080609, 0.02627326947237764, 0.02142157275894923, 0.03816804602476103, 0.02563105812961502, 0.027474736162860478, 0.0710986363036292, 0.04674309678375721, 0.07379868999123573, 0.02145764198420303, 0.017417937949565903, 0.027206657155017768, 0.020757017258022512, 0.06438291738075869, 0.04704034261937652, 0.020068014140373895, 0.03829789048592959, 0.03118821752390691, 0.03200531617871352, 0.024092590236770253, 0.05677276038165603, 0.052071530504950454, 0.09161120453583342, 0.08199881283300263, 0.05590098537504673, 0.008358723617025783, 0.018811223097145557, 0.015372517884575894, 0.06181855034083128, 0.06910474758063044, 0.04556363668026669, 0.02346113197771566, 0.03572134034974234, 0.0656581696655069, 0.012542703704509352, 0.019769107590296438, 0.05140956531145743, 0.058492649878774367, 0.02291850752330252, 0.02719341724046639, 0.028347985286797796, 0.014981379765751106, 0.04159538068675569, 0.005441694362421653, 0.06207619008741208, 0.06126323728156941, 0.029078451983098472, 0.036577010327684026, 0.07798706274479628, 0.06428665361766304, 0.07903360123080866, 0.07136580946722201, 0.016708868855078305, 0.035670457008693895, 0.04701026655467493, 0.02113521741037922, 0.010129642340221574, 0.04470096082825746, 0.014423522200169308, 0.028534473851323128, 0.013922425785234996, 0.03952076325991324, 0.023885984805279543, 0.033226295839995146, 0.018529590352305343, 0.04103013387482081, 0.028222368098795414, 0.01241134780658675, 0.03239852382934519, 0.022952235802741985, 0.012660264137334057, 0.030458870410387005, 0.013882878219841846, 0.04061096208170056, 0.017402531811967492, 0.05266996446464743, 0.021973937583555068, 0.030010304480258907, 0.044078021576361995, 0.13032935586358818, 0.24344313836523465, 0.13389133901468345, 0.1270587220788002, 0.12729063177747385, 0.13069577834435872, 0.1341445275715419, 0.06468021071382932, 0.17727069343839372, 0.13314269775790827, 0.20622425765863486, 0.11190686547862631, 0.13909796891467913, 0.1283829374504941, 0.10350871219166688, 0.13046887623412268, 0.16083768808415957, 0.12139618449977466, 0.1609257755002805, 0.24622776465756552, 0.07826509925403766, 0.1398918413157974, 0.12923961505293846, 0.10091476781027657, 0.1398099557097469, 0.15075757540762424, 0.23701458903295652, 0.13845717401376792, 0.11810003779828548, 0.10530086566827127, 0.09696495439857244, 0.13640280067920685, 0.16830389387905598, 0.12443938691701208, 0.1765125934034586, 0.13714220028902802, 0.13438569248786994, 0.07784571711506162, 0.18567943865699427, 0.11325747586254563, 0.18430241969014916, 0.1333571962480034, 0.1084121862160308, 0.07070841759975467, 0.11774771527520247, 0.08405552032802786, 0.10340010587658201, 0.15330512156443937, 0.11433473841420241, 0.10357659962028265, 0.08116964304021426, 0.07445121676261936, 0.11378600035927125, 0.13129533188683645, 0.13643703955624784, 0.10725946378495012, 0.1022624062108142, 0.1664245282965047, 0.10688821013484683, 0.12265352346003056, 0.09101954235562257, 0.1435224786400795, 0.08436894922384194, 0.09130759404173919, 0.20335946923920087, 0.12841598210590227, 0.1440412322325366, 0.20471043246132986, 0.15732435589390142, 0.09036389432315316, 0.08075803691255194, 0.13265819661319256, 0.13718907348811626, 0.11545376479625702, 0.14612130847360405, 0.12155368604830333, 0.0847535700138126, 0.13595298624464444, 0.10367949267051049, 0.1270668509283236, 0.12475691416433879, 0.1348638425448111, 0.10651365201920271, 0.11323317073817764, 0.1429526585021189, 0.08141513022461108, 0.10352486132511071, 0.1272232803915228, 0.12952597040150846, 0.10630402541054146, 0.07265256292053632, 0.036536060739308596, 0.057444537191518714, 0.12176652891295296, 0.20096376564885887, 0.06541216000914574, 0.10010991671255656, 0.08798001081283603, 0.1467562544026545, 0.1023730549163052, 0.12198835558124951, 0.16414710693061352, 0.22132531234196254, 0.18185294898492949, 0.11300940345972776, 0.17335239797830582, 0.11324536401246275, 0.14855194304670605, 0.1324467243892806, 0.20690144917794637, 0.17466282551842077, 0.06177998919572149, 0.19128611923328467, 0.11398974406932082, 0.16903144626745156, 0.07555473183414765, 0.10790481844118663, 0.14661703258752823, 0.14482146607978003, 0.1610457133501768, 0.23695428084049905, 0.26574666585241047, 0.07711882290563413, 0.10790390920426164, 0.12310294434428215, 0.20010060125163623, 0.1440675322498594, 0.18423980447862828, 0.06521740010274307, 0.11927234275000435, 0.13957002572715282, 0.122944479276027, 0.150442830153874, 0.21377544317926678, 0.12259970206235137, 0.1401013865002564, 0.14198556968144008, 0.07734216949237244, 0.153038620150515, 0.19318012760153838, 0.057583779362695556, 0.12982322302247795, 0.1477151329496077, 0.14647644013166428, 0.11536278682095663, 0.11670933956546442, 0.06430800032934972, 0.10705867170223168, 0.16997481350387844, 0.24097164241330965, 0.1051562155729958, 0.13767392747104168, 0.1231274665998561, 0.13808866164513997, 0.09169774489211184, 0.09756655711680651, 0.09129902414445366, 0.05061746049406273, 0.12588305159338883, 0.17221874238124915, 0.11317415854760579, 0.07687452994287014, 0.15443127256418976, 0.08828292920121125, 0.10750418422477585, 0.10834276529827289, 0.07737752795219421, 0.08266868295946292, 0.11121857312640973, 0.10008276852646045, 0.12812088722629206, 0.1186065777604069, 0.07598824785756213, 0.10949241396571908, 0.21184604242444038, 0.12974164954253606], [0.011015607210408365, 0.05781462376138993, 0.019053032621741295, 0.02438540354238025, 0.008844063600658305, 0.035644940699317625, 0.03534615119653089, 0.014974667358079126, 0.02266914929662432, 0.03186701377853751, 0.02819556087654616, 0.026806404614554982, 0.016375270505834903, 0.09998472700161593, 0.04531339296538915, 0.06481349534754242, 0.01628607538129602, 0.007429288400869284, 0.04405580973252654, 0.029277663079223464, 0.029456222962055887, 0.04270474812281983, 0.010135245343138064, 0.028234381561300585, 0.0051953857265678895, 0.04290527218420591, 0.04700504183503134, 0.06725238090647118, 0.015491763628753168, 0.01682568883656391, 0.03298758722043463, 0.026791936551619853, 0.07203256511794669, 0.0410360642708838, 0.028315432569278137, 0.016008142348644987, 0.032705923941518576, 0.026626105985737274, 0.06100706995597907, 0.013802118981922311, 0.03545989402170692, 0.02735520713031292, 0.024044129265738384, 0.021945980244449208, 0.0668624946847558, 0.02653206272849015, 0.02257056494376489, 0.0067138402290376166, 0.014433142130396195, 0.02048950143424528, 0.040243057001914294, 0.019312523072585464, 0.0373705841733941, 0.012446216024857546, 0.034088062455079386, 0.10376108650650297, 0.06011546137077468, 0.0010598580224073625, 0.021215323558343307, 0.07012470784996237, 0.07404276582279376, 0.023006561012672525, 0.014734275971672364, 0.04352114788655724, 0.02968970007662262, 0.08344711190355675, 0.05575537854539497, 0.08957838147346463, 0.0497703468427062, 0.012844748479048056, 0.024659268757594482, 0.06340007297694683, 0.07095175382814237, 0.01130639508898769, 0.046801827382296324, 0.0655375329245414, 0.03719947121239134, 0.00874015105156494, 0.06667148029165608, 0.05053568684629031, 0.033150191352303536, 0.065202479117683, 0.009224405379167624, 0.02622644885975335, 0.03423344876085009, 0.017607871775648425, 0.08572674529360873, 0.04372224870270916, 0.05056765602369394, 0.02703795299333121, 0.02018771111033857, 0.07911725781325783, 0.038484039782945595, 0.1170623270528657, 0.03759965081033962, 0.020378177586410726, 0.027787357602002363, 0.0536204223920192, 0.055372990135635645, 0.02107351482845843, 0.0333018235729209, 0.01666980389771717, 0.07558049580880574, 0.0010750648403440469, 0.03153854515403509, 0.06654475030622312, 0.032386439120663066, 0.012064122777831341, 0.022898078530228565, 0.05530301621183753, 0.050283125934324095, 0.03174026682972908, 0.02985762053036264, 0.04134629726676004, 0.036069506845836125, 0.049366587972534556, 0.05205797676795295, 0.07035073465002434, 0.03701660602486559, 0.08783745739076819, 0.04578665078484586, 0.03888244501182011, 0.04133294030491795, 0.032442615034856966, 0.04653497991551246, 0.04222949880308338, 0.0626820879323142, 0.04854683285312993, 0.020139452003474747, 0.034082987013139894, 0.04367493445585881, 0.016496314367811595, 0.027228641689621975, 0.05025593703612685, 0.06061174188341413, 0.07927906805915491, 0.06010603651936565, 0.01667268597520888, 0.006928398515031273, 0.03907723205962351, 0.10477842084531273, 0.05109265213832259, 0.05458098370581865, 0.02825010321768267, 0.09274695680609771, 0.046749274845102, 0.057292070372828414, 0.04537042722638164, 0.06550866125949792, 0.02609051624312997, 0.053929908999374936, 0.0678441177255341, 0.011878794508187898, 0.05126533930056861, 0.03477239216278706, 0.04577566869556904, 0.013485948804632893, 0.056781676331801076, 0.047027609909751585, 0.03131350562242525, 0.07021228636481933, 0.04752398880996874, 0.047858489610786946, 0.014128088901218559, 0.0885554017232997, 0.06508322658815555, 0.015383165795356035, 0.030101852424974953, 0.024713690658765178, 0.016607343052913035, 0.07808298045503241, 0.033895107451826334, 0.03404434444382787, 0.06368990242481232, 0.026698517546589886, 0.0419469975334193, 0.04049615395654525, 0.036842490546405315, 0.022766782004120092, 0.03270761688639011, 0.01189547120260873, 0.018909089899222766, 0.04379980864801577, 0.04952569764905742, 0.035244432011885304, 0.022601278831384013, 0.043808331047849994, 0.03653027962094971, 0.013326478656381369, 0.034528679347464016, 0.058911848813295364, 0.052843913702028136, 0.03970215941912361, 0.02898862073197961, 0.020457539042191844, 0.018978210565234934, 0.01954023603216878, 0.03186096803152135, 0.04135390703699418, 0.038730884037379704, 0.02587700162881187, 0.008646669282045747, 0.06294799223542213, 0.03699076741135546, 0.020882805776117102, 0.024882545794493387, 0.07273541883166347, 0.023973705812490413, 0.06626834906637669, 0.061977293608444076, 0.011802016574490284, 0.011749206193988877, 0.03504286300657051, 0.04836866991328342, 0.04777745217350977, 0.027376991497086625, 0.0929326107725501, 0.03553373898778643, 0.009580974683298596, 0.026977339460115348, 0.04691571948517646, 0.016423398994707634, 0.06359179983181612, 0.04060715889292104, 0.02986746946615832, 0.03461946054760899, 0.07567314976560217, 0.031108065574829067, 0.02930095718641366, 0.030922611776207174, 0.037764453395668945, 0.042861957901290486, 0.012364653571109687, 0.03484443222571697, 0.037974880675652196, 0.015811255234958868, 0.06545576266944408, 0.012384070698837084, 0.006674771879001388, 0.019229918219415203, 0.02584940560960344, 0.05796137052987303, 0.04896967212802597, 0.04290649354723947, 0.047748492298913855, 0.019252713603366698, 0.023774152056181004, 0.022563562462372438, 0.0732728796345847, 0.023044837173074484, 0.1095486848748156, 0.06341820343264512, 0.03587919134380562, 0.019332163268700242, 0.023308268216039454, 0.05954347670610462, 0.018346765876880715, 0.08192941227129527, 0.0322570458852819, 0.009533397504128516, 0.03183054591396025, 0.013060364007417644, 0.017197375052741597, 0.05208852441449251, 0.027292610578505055, 0.03044068567188723, 0.04146362954218473, 0.02448038148161556, 0.035019942093640566, 0.04662212077528238, 0.05208430392667651, 0.052660105350826464, 0.0415492878029389, 0.04446248969595347, 0.042441537603735924, 0.03028518919433866, 0.027708348984430944, 0.014421549359602588, 0.023533855664676855, 0.0062582985348334265, 0.00964619207661599, 0.021809146872588565, 0.030532901973596642, 0.031722149944731166, 0.03806550242006779, 0.051257305445947816, 0.01700048624271793, 0.03814069088548422, 0.014795193149309074, 0.07453146031392471, 0.014505950634234717, 0.05667228291609457, 0.031061528250575066, 0.08515940859381642, 0.027591310175401822, 0.03262579913384148, 0.04225354269146919, 0.020967814339590923, 0.03481417974191053, 0.007688307269875492, 0.03094136987679771, 0.06088942555444581, 0.08117766332413469, 0.017804633360356092, 0.03471344443304198, 0.0080093018311475, 0.03413093229755759, 0.026507157100630657, 0.01966488461143204, 0.07923059351742268, 0.02010158126774643, 0.04110973960320864, 0.031027723635946, 0.021104949659534862, 0.043158959464303086, 0.041025638580322266, 0.009701322198712399, 0.050536148250103, 0.06466009893587657, 0.03678038762882352, 0.03468193665945104, 0.02688039037665086, 0.0450454835913011, 0.007087371636381639, 0.0022837311054380344, 0.03998296774391617, 0.03204931578199778, 0.0928165405722601, 0.00873663624016834, 0.07780735274510724, 0.04981194103934935, 0.04802743125973003, 0.031401891593954394, 0.05194021362279143, 0.030469438593302454, 0.01686906079495592, 0.04023973557299801, 0.017967988969758153, 0.03521929907479456, 0.03491711689691458, 0.024984471932319657, 0.055964408043239794, 0.024718621912013208, 0.046903373540512154, 0.04708641175446766, 0.021202999666067104, 0.028755906969308853, 0.032920951688928266, 0.07443405661199774, 0.060744130850902626, 0.022507849648328762, 0.1252295816583293, 0.12487052806786128, 0.11063049361109734, 0.08818758146039077, 0.18270731956831046, 0.05465758013139878, 0.10008828501616206, 0.1348717271217278, 0.15896224443401608, 0.1322512791625091, 0.10041790375752108, 0.08622873228575502, 0.11665147409907409, 0.06361739417271954, 0.1515961904078722, 0.11458568780549935, 0.16694295619215282, 0.10105290396937303, 0.050207428567643674, 0.19045922931815895, 0.10740224112357412, 0.10941426030227117, 0.17990053232227052, 0.14449082953589304, 0.09043996488409382, 0.06623362842947245, 0.07549032529017755, 0.1900105005396264, 0.11152666873697724, 0.1127150956807392, 0.16277217785162584, 0.12608600141746656, 0.1721437642616885, 0.14738573133945465, 0.15312445483037404, 0.12998071100030625, 0.13089861960283347, 0.07657015270420484, 0.12584054815982068, 0.16090201320392744, 0.14772540596979006, 0.19602948613464832, 0.16092536837926932, 0.12686054914125375, 0.09337215897228036, 0.1266754176467657, 0.10782046975301844, 0.15896890764789923, 0.10017924263541188, 0.13483309133776597, 0.10069388430565596, 0.13144272326358727, 0.15505650187177317, 0.11180048475840262, 0.11331681374992643, 0.10393638602857079, 0.18243733048439026, 0.1158508299184697, 0.1202961163861411, 0.10157853112156902, 0.10765633891735758, 0.10965946250196014, 0.15980261005461216, 0.056378579033272605, 0.0894090123474598, 0.08959624051515545, 0.24377578337277683, 0.17817197793296405, 0.09761963891131537, 0.11318028571882419, 0.17007119261792727, 0.1385903704379286, 0.075724046677351, 0.15144627488085202, 0.09192321529345852, 0.20892387708382948, 0.15199166775814124, 0.17311166732438973, 0.10918277129530907, 0.1462495515921286, 0.11084617275212492, 0.09748535683112484, 0.24653720376746996, 0.2307852575821536, 0.11464998578386647, 0.13654062471219472, 0.13271513927195752, 0.16362243651279382, 0.10863790088998419, 0.21394454767661436, 0.11754039568560463, 0.1114341097750834, 0.1445046037967716, 0.12080775893160275, 0.1616034284234047, 0.23680326608674868, 0.10715204490614788, 0.09502064622938633, 0.16086147752191338, 0.09711100227598633, 0.19698489058230603, 0.06025282399994986, 0.08243070037237235, 0.21617871922041687, 0.12400808291775839, 0.09198760148137808, 0.0924672782421112, 0.07978810503014497, 0.11728982627391815, 0.10417183768004179, 0.16651200503110886, 0.08902011678687163, 0.1018647507631353, 0.12306875975004264, 0.183123627943652, 0.11706063071531908, 0.13108790373163565, 0.12806208538157599, 0.17563090500022682, 0.06748477236500808, 0.18005019000598363, 0.11791018370006766, 0.1126571080780455, 0.10816036151455981, 0.13187036317374023, 0.10384200859282698, 0.14160383945064886, 0.1718120284910713, 0.1313710563949176, 0.09362123560692583, 0.10429243370890617, 0.16524779929646424, 0.18765438268227236, 0.09248159533100468, 0.10391571106655256, 0.1339625580502408, 0.12217911891639233, 0.15859082793550833, 0.12470928100602967, 0.12857106806976454, 0.12097915687731334, 0.283503140189818, 0.10579198252941881, 0.09225770591625146, 0.20241144725254603, 0.15852491504379682, 0.0832000437325665, 0.20123376830347947, 0.07231909010027136, 0.11943349481693336, 0.14346347323485784, 0.21480292161660536, 0.2680885616157736, 0.12345590469028268, 0.19113030045160226, 0.12095368467271328, 0.14827858842909336, 0.10636964653219495, 0.1099424794582384, 0.20036670911524976, 0.14113759089793476, 0.23370578086801938, 0.09744355228862592, 0.10712286111499582, 0.05236190278083086, 0.21008181066385337, 0.1067558347380587, 0.11338261807603495, 0.13974397496453353, 0.15775381427790436, 0.06469498920653548, 0.1322676454271589, 0.13147692142852715, 0.18182177708617278, 0.1856523651097502, 0.09576124684619051, 0.19676553378147738], [0.025385460683277676, 0.018961842604247586, 0.021098257607913444, 0.029957589094660113, 0.034343083056488206, 0.03386129605184708, 0.01968075384918068, 0.006794606676391725, 0.045261071130101166, 0.04785295615770987, 0.017251306712361317, 0.029318582133523056, 0.022746073115350943, 0.023862007074058056, 0.05964491090604237, 0.03273283803303327, 0.03579307167923876, 0.06010434018181903, 0.025470440409013202, 0.02949545585683414, 0.047420247590967586, 0.05660406639799476, 0.030138191367898668, 0.029376630804368427, 0.025639663649989024, 0.046826895858560286, 0.06437714983310018, 0.057020751360271654, 0.015783228346013596, 0.04051500705203839, 0.030702549298959117, 0.0028321290446911007, 0.04948021544675742, 0.03931495341073189, 0.04536511090451053, 0.02108083282863455, 0.053097007263983996, 0.01962489345377045, 0.08683465048670769, 0.03565422984372292, 0.0008205688843320656, 0.014140926783771386, 0.006322948079157088, 0.022308501148862497, 0.019312020956671665, 0.024684047160137976, 0.015436447757695402, 0.028638873249292374, 0.05327407776245049, 0.05976595476801906, 0.030589739459433725, 0.012076938607996064, 0.052111509788249216, 0.09677037091127463, 0.04112003297944154, 0.05737776256033352, 0.03038293555645006, 0.017991406909589256, 0.07715293286102158, 0.041086638878498755, 0.04839316163478153, 0.04857766209170222, 0.01568762954723622, 0.007927027763798833, 0.047659119058932574, 0.035414839296468666, 0.00794237368141434, 0.02719267933363361, 0.03512852465999978, 0.03526124610964741, 0.06126676566366639, 0.01984121381039066, 0.022510970909414545, 0.04191893671772309, 0.02929066720285586, 0.04541749720062528, 0.022216378145718148, 0.06612264045647212, 0.07066790905914136, 0.053243245131203105, 0.026904717553406954, 0.10415083702121462, 0.03915954853541084, 0.016738324060237834, 0.04542422826801028, 0.012882146784769637, 0.021242917881214192, 0.0970337035666619, 0.008707403255227422, 0.012530970137699373, 0.013242800021544099, 0.01565125667756157, 0.028133707320583717, 0.042091257471059046, 0.04302801238372922, 0.07604859676212072, 0.045313565991818905, 0.12327409801738602, 0.02061466739646026, 0.03574020701593586, 0.04842672197680388, 0.03249857042516981, 0.03421196294948459, 0.01032329538637506, 0.035223363499556265, 0.045809334210519276, 0.03420114710128733, 0.03694709689755525, 0.06421102410448448, 0.14218889948512825, 0.014766336751303502, 0.051304070079433065, 0.06337931659072638, 0.05558656242543033, 0.02741572566862617, 0.03633152314328721, 0.04182856263858931, 0.04041980180357184, 0.03213422086888126, 0.038666440173983574, 0.05362084308373077, 0.0027158321712964346, 0.03943692008033395, 0.036339886087392054, 0.01232570905371436, 0.018452423957309554, 0.03187139032940779, 0.03865348015512739, 0.02795103212286319, 0.040637886351240535, 0.006345330829000366, 0.031220522576144764, 0.047632391564548016, 0.009870538654338037, 0.011557632009498775, 0.010231254655601723, 0.016343840763771107, 0.048953088732170205, 0.0277716003225318, 0.055020782963505814, 0.023191655187734535, 0.03520092773916466, 0.04285724547558597, 0.0409112579322287, 0.014636683976277709, 0.06780266602124486, 0.05885075352021626, 0.010990068848643984, 0.036187802640987296, 0.049808907987815995, 0.032959858886897564, 0.04772180551663041, 0.04143481215994273, 0.01268953613803855, 0.07010811088340622, 0.08773195198071854, 0.009061933561627353, 0.09000435897282191, 0.09707189830286161, 0.0352907216708575, 0.02277389305111553, 0.014101590412402791, 0.03755475214815565, 0.04706789453380874, 0.05956018902361393, 0.04799319577536412, 0.012415347770521683, 0.06211171818098851, 0.014848792326769658, 0.0192957361162241, 0.016794515241469656, 0.0480690661684743, 0.033505987974682024, 0.0063775722685802195, 0.042710349429398775, 0.017724160803481936, 0.03385111124121717, 0.013134594890289009, 0.0237851986062846, 0.013317440569932972, 0.019339686525719504, 0.04867725746173944, 0.031939956293042214, 0.04135407327807375, 0.04299200253028955, 0.012789080617949367, 0.0964347810617515, 0.035625432817531485, 0.014000548066438308, 0.01351827590925885, 0.060068520318184576, 0.07169456646910735, 0.06452713321362223, 0.027486374734767845, 0.005477714817970991, 0.028134211132835065, 0.03936749237722584, 0.09211519320628472, 0.021090164381478513, 0.040950619748660495, 0.09372850520802395, 0.036713351761656146, 0.05332699670855488, 0.023046338431803242, 0.013012875037799989, 0.043517134351921935, 0.013042381981254687, 0.06172147912106343, 0.022865988912859132, 0.01423984785963382, 0.046141955469335826, 0.04806129354983568, 0.06987311385039773, 0.040011703701955934, 0.04681202576362661, 0.05529154897002237, 0.0319868532408561, 0.04781002524707999, 0.08925745476569448, 0.06776814894484622, 0.0036805702922200517, 0.031302272475191524, 0.01685373777789729, 0.01985288461271141, 0.017569967113169174, 0.02576638854640935, 0.020141536802319542, 0.03648673802880304, 0.036149913245545964, 0.013332075722116445, 0.030931975559464524, 0.020861092655520354, 0.06630405357905797, 0.053197857923805714, 0.0059563559646319065, 0.02128320759428399, 0.04569464822166732, 0.023220967900540148, 0.022499968464087163, 0.05609159603981035, 0.018391645879351666, 0.024210266868716905, 0.026706765139741555, 0.05106288141437939, 0.006787415901531598, 0.07550956854330641, 0.014585858310705848, 0.03019837403137769, 0.04260178721909012, 0.02597253257408738, 0.02395250159315765, 0.09897181671112776, 0.034408107067325285, 0.06078456475266388, 0.07466411391007048, 0.027741843169288974, 0.026938569665487324, 0.08131980962519135, 0.021689363389409015, 0.07950580053563629, 0.013137883240623134, 0.027702559384384325, 0.03611001538644944, 0.06901697229061808, 0.030591222058449472, 0.044031161947974136, 0.03416031964921525, 0.03418252131502543, 0.020819995485778366, 0.04965012400810208, 0.046262222408716164, 0.02525891729497484, 0.010407392168417573, 0.04323920301560845, 0.02381564107989626, 0.027058527871434177, 0.01673645299992391, 0.032761784336928806, 0.04673572789345469, 0.022253365089584674, 0.0533283910980182, 0.04997705914346235, 0.04187811605100121, 0.01738599082455039, 0.03798027842172554, 0.06184915227017232, 0.010128263217796172, 0.007446703850291669, 0.06366152609033243, 0.018249209504574537, 0.03722373562465821, 0.015364692679473331, 0.08503366248416049, 0.03164369772587504, 0.03731920210910695, 0.022263646591454744, 0.03229411086067557, 0.04091652336397341, 0.031835533146347315, 0.03460516042209097, 0.0174954283450331, 0.016590344054358344, 0.04066818293982318, 0.03101131326651999, 0.048209926645670614, 0.06840373948216438, 0.03055516810023359, 0.005084875696671328, 0.06534755669002022, 0.02954473446256348, 0.0073316081959222046, 0.02656688175297209, 0.027472256117367318, 0.03817155744348254, 0.03557585226371884, 0.05043039856744664, 0.06603791857404367, 0.018160263741655008, 0.032328967204583545, 0.06503009729619537, 0.06617730323757444, 0.028654265816190412, 0.023213224119639823, 0.048347971202539544, 0.05207958132294672, 0.08050159138760396, 0.03161402199683445, 0.02058235216619713, 0.03146812000444957, 0.0599240737834147, 0.03533701132982969, 0.07974353885012013, 0.014278281779427613, 0.09611196124127933, 0.02304425024028335, 0.041536765439169746, 0.009567834004493696, 0.03102479575734053, 0.038669415550040345, 0.006893239798955619, 0.04177948759336557, 0.01880558786381568, 0.06870295306933777, 0.011656618394356753, 0.028884550423494408, 0.03138685186526605, 0.07701277466756956, 0.029533728624561002, 0.03684249393908041, 0.0049373418275666025, 0.022899550951219032, 0.024553800666970865, 0.16061921337885515, 0.11917481012642384, 0.1028884904725211, 0.12004268355667591, 0.09622252852256809, 0.10067204904875585, 0.12866478732654027, 0.1164685817701476, 0.12020565409745489, 0.1477702028517212, 0.12298893689044885, 0.10977174647684608, 0.10831519642046519, 0.09468519208686692, 0.09725907897310597, 0.2010258108909641, 0.15358527510293893, 0.09967113525739738, 0.11710088141262531, 0.17192742015634263, 0.17623584611075266, 0.16614392692489283, 0.152719627267548, 0.20390020736626216, 0.12275681006056921, 0.15547574151839527, 0.1050837683890547, 0.11322485189884901, 0.0697953130251595, 0.10703372196959597, 0.12374113367072173, 0.1086917155023132, 0.14609601268810885, 0.12393632105418614, 0.08418064897081681, 0.12737308735294, 0.11648281743483883, 0.1284315748406308, 0.20514595694839954, 0.16024338640272617, 0.07284616931740727, 0.06960389829639878, 0.15911583762083734, 0.13774381657796247, 0.07159721704998187, 0.1163887589105538, 0.1173587247197117, 0.12113342859915324, 0.12022932139890534, 0.1132156238225954, 0.10197667511446135, 0.13147145243627684, 0.17304827858294758, 0.12052278779447079, 0.10958355478942394, 0.20822210902614252, 0.1896832295294319, 0.1283971324030842, 0.08315089744116579, 0.09491587363715683, 0.19251645249979837, 0.10966292303055525, 0.12055946939757892, 0.17847802436777524, 0.15060860982963017, 0.061014805255191665, 0.1103029851136463, 0.13626269676855632, 0.13954501492636545, 0.13604586411799702, 0.19419176903154167, 0.08210131233291966, 0.06477352284959384, 0.11355639089431081, 0.1307376982378108, 0.19924416792179855, 0.1446773452418191, 0.19790586616311753, 0.1585946955851146, 0.10295943130872079, 0.0935531242617539, 0.20323023545954907, 0.13782726281455585, 0.1581323282527072, 0.14710062449531897, 0.0925928343619619, 0.10578788417790617, 0.19525947102478572, 0.08676755694406373, 0.14026437061173574, 0.09701963753572532, 0.07898843793996743, 0.07589230979127543, 0.1090188847322549, 0.12364251539111137, 0.11095132532396487, 0.0884449565783143, 0.18621539989752428, 0.11347695479967765, 0.10778543699000563, 0.09534282144159079, 0.1250029509621007, 0.2259895484894514, 0.17804883739777974, 0.10800812539777585, 0.09191535785794258, 0.16155640594661236, 0.10169876752687351, 0.13765213292624268, 0.18070117650287493, 0.13074609850134167, 0.13721637773726666, 0.09984366635658912, 0.12801502219268254, 0.1136202003274645, 0.16102888568171433, 0.15661576177392686, 0.13510530601654733, 0.09295788620199476, 0.12991696942065442, 0.11434988331581865, 0.16122601367533207, 0.15954190332974705, 0.08902477832244975, 0.07229025236197881, 0.08852849102446012, 0.12760771119168826, 0.1202915430601154, 0.20410648201193127, 0.20559913691665443, 0.09496533884001629, 0.07645064911672048, 0.17977158352732658, 0.11948616270508085, 0.08953317747052227, 0.16299863212874957, 0.12186178165887084, 0.19816957201276506, 0.11762944662145206, 0.09556700262640204, 0.16645546949335507, 0.17138255653636797, 0.1731078675282853, 0.17308358954531805, 0.14480613118835858, 0.15121435161147798, 0.16091786378196307, 0.08955177611538342, 0.07498718478849956, 0.17591826458062443, 0.13686473374920233, 0.12042532302439213, 0.1355014211897339, 0.10953408958656446, 0.13269375184816973, 0.122635528711336, 0.13409200896109852, 0.2503751063985484, 0.18480824040515081, 0.1872754887278591, 0.07657547920410122, 0.10210340509989432, 0.15415379245366367, 0.09997358545660973, 0.07805711470012154, 0.06443415356001683, 0.14920298382639885, 0.11271753162145615, 0.1009280060284904, 0.08888183813542128, 0.27415537035890986, 0.1151718334960086, 0.10153371388358728, 0.09923289663025311, 0.0871217522237982, 0.06382441520690918], [0.06202779018453189, 0.13692007506532328, 0.02551613634984408, 0.07737434562295675, 0.04740218498877116, 0.035619848474328, 0.02047454652243427, 0.017964329969670092, 0.03034288841964943, 0.03804853565192648, 0.020383967186457345, 0.02433734799602202, 0.02371994558987873, 0.042494012109403095, 0.06410967132874898, 0.04049585200846195, 0.05209719269935574, 0.03968812052958778, 0.04706559769277062, 0.012939656868443956, 0.011039528962490814, 0.016967489084761058, 0.05252726176487548, 0.032950003165751696, 0.04613219474309257, 0.03260054066777229, 0.05594496462228043, 0.017996779210599403, 0.08237398163016353, 0.02096395517167236, 0.08465611202908413, 0.09789839466767651, 0.04359625492777143, 0.048227348032274416, 0.028926032661859478, 0.014836001941668136, 0.05711006692477635, 0.0230496988764831, 0.02481095356467579, 0.09282996199492898, 0.015319965347381575, 0.047748977451452186, 0.018848968303895423, 0.017916306653725247, 0.058230111109358926, 0.02214125414112849, 0.06316348817199469, 0.04243775816368205, 0.02895169485626476, 0.002941895866700049, 0.01851608750543424, 0.02495087087819619, 0.02092162985354662, 0.07402802125683852, 0.012187181888813419, 0.01434690541853862, 0.008656100070636188, 0.03365757269784808, 0.017939220781305006, 0.02313206115338419, 0.07244232563035828, 0.04985824087634683, 0.04602379538118839, 0.04147359382893358, 0.018484898643302064, 0.020121414846341525, 0.03258535505405494, 0.041005526802369525, 0.015789143475038663, 0.03218827975381698, 0.04500006924250296, 0.01695413381925651, 0.016812627037454928, 0.010594282764941454, 0.030883416200854948, 0.09306242130696774, 0.056179639351155074, 0.035574227172349177, 0.03413646235795958, 0.05532595069546785, 0.07417365522789103, 0.0008946956014759572, 0.07833990773984364, 0.027756095797355686, 0.053181505229856284, 0.09029486695570604, 0.017136997310444713, 0.039918520487844944, 0.007471642556733319, 0.013007760580096926, 0.02131133626348206, 0.03482582340283053, 0.03369120767872248, 0.058849274313875606, 0.05916233001542943, 0.021052134190020815, 0.05227960666109409, 0.028260528908244202, 0.02345665025391749, 0.016860887840656296, 0.02986312684203897, 0.016520417628011534, 0.026516240988192812, 0.02531330187671951, 0.06315947124468428, 0.016651756562558667, 0.03913471754640341, 0.004838399971569223, 0.04789924920935716, 0.007893991590078388, 0.03173037039648209, 0.02538789832033217, 0.03597341610917023, 0.02875841754887785, 0.04286560841969081, 0.01161336009058037, 0.020969644687803726, 0.05871728568204811, 0.07275308109819889, 0.03569327274869595, 0.027323607754494463, 0.04738146931465183, 0.05953289834516389, 0.0041989485699949515, 0.01954440393352083, 0.03921177537579622, 0.01633499775614057, 0.02649768814444542, 0.018743571459448764, 0.045306136033364704, 0.02106532491078334, 0.01344147083416049, 0.01937985579882349, 0.012867883978677648, 0.025419148250616024, 0.026338726049289107, 0.02639315473580999, 0.013612064715873982, 0.047675675313387594, 0.039417435947273455, 0.008726293670146592, 0.029518410696515014, 0.011064828988829893, 0.052620902990124056, 0.01650192924509091, 0.014977941289544106, 0.059562781027385166, 0.05369202479986208, 0.07566654083452054, 0.01508174357669694, 0.020680461544543505, 0.015395796724728175, 0.028093797587124363, 0.011114503689376371, 0.06290941751961197, 0.04118101631424256, 0.0841586644362126, 0.022147756202944686, 0.044367287840162, 0.023310234271255986, 0.056207985151559114, 0.036423457852963886, 0.05330335654850517, 0.05131210732672896, 0.039202187675982714, 0.0332072425766715, 0.01638546888716519, 0.030999852810055017, 0.053784583761755905, 0.005376872215752623, 0.07247516672526087, 0.01850617750148688, 0.01402431629997279, 0.028307500494910137, 0.07918025978973933, 0.07305722084960767, 0.02612958289682865, 0.04751203980829034, 0.0225584123815809, 0.05451011411579592, 0.016856557090899775, 0.02620485787545996, 0.015140628541952797, 0.03385984059423208, 0.03384202565731747, 0.019566111965104938, 0.04387482747967754, 0.002815768293138327, 0.03426644252613187, 0.04853477528584855, 0.030346705179129328, 0.010606405641218382, 0.03407164190762809, 0.007688677071460656, 0.03389116855604308, 0.01958571993080633, 0.02673937383640025, 0.03796858726335423, 0.04789147998339363, 0.050627211042280705, 0.024414967313142757, 0.01599637994409672, 0.044132199204925976, 0.0036906295738715145, 0.017783081391826272, 0.039878938147532086, 0.0419999605842999, 0.03797414107248187, 0.04257139902827995, 0.05589860710980637, 0.023662923203249062, 0.031260552749569924, 0.04375212799225535, 0.053943021688610315, 0.02986379519903234, 0.03976834372484258, 0.015092832535239202, 0.06244886187570436, 0.04148834518023899, 0.052023490225630145, 0.013256987340615263, 0.020084076760602847, 0.09725956073296921, 0.03380622954240867, 0.04875378942649279, 0.03490861485313092, 0.04878897485988481, 0.03402154227452619, 0.03850705908345325, 0.008391125360503793, 0.03514059579798153, 0.05542671314573713, 0.023738820737759982, 0.021647675894200802, 0.025768780382350087, 0.0455806984433106, 0.03286219055631331, 0.02913680938737733, 0.06785470287182502, 0.024366336708356227, 0.021147744863161018, 0.03768729717869844, 0.010830155108124018, 0.024046945186065774, 0.01677662905837808, 0.01825272261963359, 0.0657249917941434, 0.034582914651504586, 0.03971601849687951, 0.058731677409793646, 0.03621062855901463, 0.0616152680345944, 0.07293234326477561, 0.03764402360788413, 0.041085329305912764, 0.08845887333154678, 0.031271110754460096, 0.026181582427982773, 0.054809799284807274, 0.04883550200611353, 0.011942276548195099, 0.03644295555672475, 0.01717237612631704, 0.07259002913321767, 0.04664173382999642, 0.026166098258857216, 0.023663230240345, 0.02827854062031422, 0.026120909522952776, 0.04420806620536106, 0.043469708146793504, 0.039923721458762884, 0.04029555864898222, 0.009393658306050514, 0.060920373536646366, 0.07832500711083412, 0.006119034735352865, 0.04468579217791557, 0.014765407158327954, 0.012260096413748605, 0.06369033668722425, 0.013766869087703526, 0.03081611231235521, 0.013790857845119067, 0.014890549371817281, 0.013972142046051366, 0.010093396695862924, 0.019876477275309817, 0.07343867288104125, 0.015294759467776333, 0.024459514833454574, 0.04689659158300076, 0.059626006920422824, 0.04457380336576274, 0.04640768335333892, 0.04315024707466364, 0.04067446956677096, 0.06531533984733479, 0.005375936685595661, 0.035786934329995086, 0.015519529281716262, 0.0869522202493889, 0.021442037375111665, 0.03037545131519437, 0.022440635665718998, 0.04461237468889781, 0.005094787821040622, 0.0633009390107223, 0.01939958759716579, 0.03990059359265225, 0.01982291880995035, 0.03517471932406936, 0.027473121249516095, 0.012536691036075354, 0.03547051988009896, 0.02796297603552895, 0.09085727749126297, 0.008032559467080449, 0.017361765428047096, 0.05037361536441105, 0.020837844349443913, 0.006766822363715619, 0.043697492352553775, 0.011514397454448044, 0.063503305294684, 0.004354869556014559, 0.03164620830544403, 0.01992388312438769, 0.021952816484762088, 0.026818385846646767, 0.04055712032797081, 0.07717191827084337, 0.03297342619459544, 0.037498243751802614, 0.05799503943749836, 0.020061878487467766, 0.0326842277842973, 0.037402967257159095, 0.016341889975592494, 0.026126146116959195, 0.016762230545282364, 0.05104305801380958, 0.04868022944512112, 0.032698080076703, 0.021924165343599658, 0.01821804099849292, 0.04729836913091796, 0.019300643620746474, 0.03116626013070345, 0.019538826375667537, 0.03908138808661273, 0.018412213972104446, 0.11832541999007974, 0.21614034127976212, 0.16450294426509313, 0.28004706278443336, 0.08319310231932572, 0.11127989233604499, 0.11919051142675535, 0.12910582151796135, 0.1541558009173189, 0.10290228508945022, 0.12370447920901434, 0.0718790397846273, 0.094653321297041, 0.12122372803943497, 0.13768840740833962, 0.12373912520706654, 0.10998805665544101, 0.0796030888866101, 0.08773972799203225, 0.08760134077497891, 0.14379865596336977, 0.09182535697306905, 0.13123990914651326, 0.12657405808568, 0.12638036347925663, 0.11669787232364927, 0.1191013790667057, 0.11844925263098308, 0.2924283726939133, 0.1240394583770207, 0.17128578387200832, 0.19817003341657774, 0.11612729222646781, 0.10618887801787683, 0.07335510450814452, 0.132129237854055, 0.18725556693971157, 0.08772664583687272, 0.12183420599571296, 0.13968623163444654, 0.07878379856369325, 0.1042879553777831, 0.08411663597715752, 0.14174515115363256, 0.15898535533675126, 0.12564171025795595, 0.12212535180151463, 0.09388485324702092, 0.14519277401268482, 0.1624048189925296, 0.12366751262119838, 0.10521081050059625, 0.13565261236258916, 0.10408709544156279, 0.07597339472600392, 0.18216097674199513, 0.12428785647664752, 0.12172429689339229, 0.17949665470847062, 0.13684551763747418, 0.21469503454864025, 0.10947170507694994, 0.19501442488815102, 0.12119071052542754, 0.14933440248881066, 0.08403234157179083, 0.10727536186043705, 0.08010601904243231, 0.06759346010429518, 0.1488018882061754, 0.1735650644238506, 0.08398266602307558, 0.08736283571592399, 0.14877309117998394, 0.16534564404615334, 0.15544029484902108, 0.15464518751416886, 0.16568772069045476, 0.16155316254922322, 0.18218902737966605, 0.16025374084711075, 0.07794715131499938, 0.15246308674769743, 0.13757222864244664, 0.0687120250825371, 0.2505939746541636, 0.16732780768402986, 0.24313424208334514, 0.15646459774247237, 0.09452398573713643, 0.09905220954013721, 0.1648170788373266, 0.15655683779290744, 0.09917473939380475, 0.14736547028379782, 0.17232259895120347, 0.13699012702064856, 0.20736976047711714, 0.17677762918174267, 0.09782203912202801, 0.12695164925285748, 0.11425309708075863, 0.19302113327596868, 0.12806950855468, 0.16198055818676949, 0.06753910944930144, 0.11266129463911057, 0.036318736150860786, 0.06042750605515071, 0.13147074675985745, 0.12306372502020427, 0.15963723749986716, 0.2040049596024411, 0.11151180203471865, 0.1461098955145904, 0.10627627332827874, 0.10350433564079659, 0.14905906654894352, 0.16385331483823912, 0.09879895312977688, 0.0892723078972527, 0.20040598272212914, 0.15285791270434856, 0.14964287807898863, 0.09743377459900719, 0.1025465020377721, 0.10389122952307973, 0.11797410169882433, 0.06112620034920318, 0.09872849405344043, 0.15966840939862387, 0.09428309223481587, 0.1191175417708499, 0.0640204439737967, 0.1465572536523853, 0.14199546272201197, 0.08353019851659026, 0.11466897119368825, 0.14026028583092348, 0.14399856595056398, 0.1356789395213127, 0.1393427707787071, 0.14607902217124188, 0.11733094549604825, 0.13568197935819626, 0.087028779355543, 0.1146583589059966, 0.11929915845394135, 0.17739653454295226, 0.12852228140192373, 0.1301019787788391, 0.08478135602282626, 0.11846055702439376, 0.09851186496338674, 0.19923749113721506, 0.22834318290863717, 0.15834681317210197, 0.13225706028086798, 0.12072226351925305, 0.1251141085688557, 0.1766154050294842, 0.0749105578288436, 0.08746958284505776, 0.11462630491171565, 0.05060880577989987, 0.0870908788804497, 0.10521762977753367, 0.08544575037168604, 0.11454500284578119, 0.06584848516753741, 0.14165114691214903, 0.09672475978732109, 0.07899383907871586, 0.16240445258361952, 0.13561651429959706, 0.11621846019157342], [0.03360967830355678, 0.04027545704905476, 0.025195562480283634, 0.026911704767761484, 0.0178392182902566, 0.02347574083666716, 0.021203852923853055, 0.018543700488018136, 0.029158067889511585, 0.03266723726743034, 0.0685216620830553, 0.059098099890564165, 0.052685686121029515, 0.027408740150609186, 0.02690628157662494, 0.07567287835159472, 0.013693486373605472, 0.07365224177816085, 0.03281082206272653, 0.028837887570261955, 0.06363445932843856, 0.04829114728740283, 0.011440227639728358, 0.026969639783991233, 0.023166339046188762, 0.01781557982654444, 0.013513906991907527, 0.02758964097925595, 0.04465581450079169, 0.022602729199986373, 0.01644592635732676, 0.07057716857109751, 0.014227251705181385, 0.010443178953469863, 0.05666022874148829, 0.04871356587058731, 0.03414678626826831, 0.06669768531407629, 0.01762120838143996, 0.009582432685419917, 0.05095934375588383, 0.061870173285050054, 0.019531717025009648, 0.09432286117225885, 0.03687288552256567, 0.06528513825365476, 0.04520658137542861, 0.03957785858905741, 0.03395042841189674, 0.0278867426261838, 0.04673670498388154, 0.014159098799739565, 0.049011510597275834, 0.03705567607123937, 0.03612250043079257, 0.04352912406570145, 0.05338019046134182, 0.05569909745827317, 0.08871315432978527, 0.03334332616733653, 0.01372763280025018, 0.046510684969169755, 0.03765420163316386, 0.029418927284755876, 0.062132257436003, 0.020468846828277622, 0.01541951491630503, 0.05467206006869674, 0.03160936724660652, 0.035973053092935255, 0.046239332029862065, 0.012686919537372887, 0.02932053292170167, 0.02701641459550176, 0.07417408949030296, 0.04269455313416464, 0.01854267081112734, 0.042394457451467, 0.01748010702431202, 0.049689587604786666, 0.03566376665341003, 0.023364790183092867, 0.02580289033773754, 0.03330805252439209, 0.05339624459988304, 0.06192119911845241, 0.04529894016949194, 0.016382920988170162, 0.0960520330284323, 0.09186699866716351, 0.030969152493136268, 0.02544153142454369, 0.004952261964457908, 0.04043651072840605, 0.04085860022210649, 0.013816832165632929, 0.02033470045509083, 0.03551734218906079, 0.0656698201117771, 0.0254212432274861, 0.12030687795153686, 0.04892831541863935, 0.011915194519263293, 0.04709253892568605, 0.02978490532508918, 0.0359144921281508, 0.0802905669968043, 0.049368827138096094, 0.09039735967027289, 0.07361353135534696, 0.047502431752426286, 0.05320409705330219, 0.06432399339973927, 0.029099394966449057, 0.013494501738542957, 0.0319227452522942, 0.030462575211588825, 0.058768454007804394, 0.05809695539729936, 0.02799585784253265, 0.02791017752939037, 0.08868636576724903, 0.03649261753473963, 0.011663777786972267, 0.0008384196563773522, 0.07100729870476893, 0.04919405008799263, 0.05750595818140677, 0.014961795548775365, 0.0044386274946321335, 0.006271618177249495, 0.006621272785456053, 0.05467999553573983, 0.019661810847797563, 0.057890470405774455, 0.04582962240757687, 0.026623720935146724, 0.04373303401683058, 0.09188381276492562, 0.057863139015223296, 0.07643389608711004, 0.05702106348638024, 0.054978147215609036, 0.021497192094102502, 0.04752230604312249, 0.05340588318982294, 0.032679803735975704, 0.05304273124784231, 0.013461289145717663, 0.056012268510780165, 0.010726692088480507, 0.07178663010043757, 0.040946392475494316, 0.028197096062025855, 0.0087004983132439, 0.03945382238764848, 0.05065741942131093, 0.02066104526498488, 0.051774176103728156, 0.03462641553155013, 0.05575968385008829, 0.05954645547483649, 0.03746807608487351, 0.01169438989433859, 0.06227384733834437, 0.008639723627961107, 0.04286923518936549, 0.03193149156868458, 0.010055971248740596, 0.005918166741529214, 0.07848855440637895, 0.02260403029088463, 0.034868072385766676, 0.04353249638474413, 0.028182495684762086, 0.03829414836530175, 0.05396793410181999, 0.041750090063682625, 0.033508875141186376, 0.023898695462516377, 0.02372782338144524, 0.025642912136390805, 0.013408350691731487, 0.03869450777502997, 0.002246365454214226, 0.02892628711249147, 0.06195044397775616, 0.042211361562034914, 0.05834558419883251, 0.015673188625701835, 0.02476767490484885, 0.03743238175021751, 0.023297469331217662, 0.02511416541944657, 0.01039397159391748, 0.03313380473160318, 0.008533515085998391, 0.023731477292520658, 0.013144674527991031, 0.007193181114936513, 0.021329180038134967, 0.07249567883887462, 0.01271059107966721, 0.038889732477920394, 0.03860535166625466, 0.024511210720187852, 0.025655804301745126, 0.07659096337322678, 0.008033643426772739, 0.017656831469919, 0.030556766050202504, 0.027250444716108695, 0.019592574830832224, 0.024105845418359553, 0.02013837482913264, 0.025402870195518647, 0.015744120980213796, 0.044858801644295454, 0.045511155389249325, 0.14018534842346395, 0.023744751133822968, 0.004731825444780822, 0.01032047692154135, 0.012938128468314452, 0.03649522310921124, 0.043975060672632287, 0.022359810270635144, 0.01574183940621359, 0.029350096692464182, 0.08031150658747979, 0.01766127078527851, 0.034110172518662045, 0.05362640707088368, 0.042500373375202925, 0.013112947078687804, 0.04056301340460777, 0.022357957870034233, 0.03421834796401007, 0.040170253587088416, 0.01964330719783902, 0.03320065060896533, 0.04283563752791711, 0.015916855639911125, 0.02297408293400492, 0.031623372209391425, 0.03271915537438222, 0.0203834124840796, 0.040807822053985934, 0.025860577688685486, 0.02843765029683709, 0.023166023527405093, 0.010778042770523046, 0.015545668146972145, 0.011157313311871673, 0.021316330281219313, 0.03108031688524144, 0.035249178364340744, 0.039144230607364855, 0.021696567734969512, 0.012177774000779858, 0.09125020354986191, 0.061978379264473915, 0.04109046242332884, 0.017512476537376642, 0.01825708390346595, 0.06339885161391326, 0.01200651006573545, 0.04469787349392261, 0.026914636039042046, 0.007343993156350085, 0.014977805582540376, 0.055041810763733726, 0.02068374735037131, 0.07701607913311039, 0.0390193530225328, 0.02445473285791065, 0.021043645716937523, 0.02243364166601428, 0.020736026777220622, 0.03458154061809182, 0.022292012747909342, 0.03836178134328552, 0.018573572992214134, 0.021439701518309966, 0.05111080634274653, 0.027836354615698968, 0.07774934478636299, 0.03144728558670197, 0.07228156032838992, 0.007972176635770925, 0.046170426798718314, 0.04156328937304871, 0.02045219388258244, 0.027482976970661963, 0.040053253793822866, 0.06646496137338025, 0.019812761140721183, 0.015358233026095798, 0.017306600531030978, 0.03540927530931575, 0.02296352492911475, 0.06312673871538468, 0.026516157867653028, 0.016059590570096458, 0.020284912948097502, 0.010282282185341631, 0.04809257401419537, 0.04140922799706459, 0.016335689861859595, 0.009714007410886032, 0.0331811834392803, 0.05885668391627925, 0.027265065449423025, 0.004498674875191812, 0.059974868914910724, 0.0297257574275136, 0.038782035399760516, 0.04661098601562636, 0.027376260375604033, 0.03196934364469988, 0.01825979125819036, 0.021719393652996848, 0.015778263166014637, 0.04147047596052289, 0.0277064626570791, 0.010622819403319486, 0.026660338077428083, 0.009597395230749888, 0.04376446036621928, 0.026049407199025154, 0.00745795141639454, 0.05423230830846088, 0.041745706727462153, 0.04037245023729546, 0.0459728340086128, 0.012070859782397747, 0.028974860041801418, 0.06971850964639868, 0.03870517434552312, 0.03267128472881658, 0.045915745464818816, 0.013473747048660048, 0.07594968671245234, 0.06402503087052278, 0.0065857820113056475, 0.037389423698186874, 0.0536780062663768, 0.036391878833195994, 0.004992521991620639, 0.01735500043391117, 0.04814162191801837, 0.011866226343304982, 0.16213264502584934, 0.10753572931779282, 0.1463875656149217, 0.11733994287039552, 0.07177945119994027, 0.11896694770881108, 0.08609620082591261, 0.11506200581789017, 0.0638747082224914, 0.0890964926885707, 0.1306129970720836, 0.15645095918859753, 0.16859140273715767, 0.07148605265787669, 0.14709062288914407, 0.14504386271749223, 0.08848226921898977, 0.11524073194180216, 0.09955777919718198, 0.10482638648578099, 0.11115065177104302, 0.1727137201066528, 0.08498327447367565, 0.09122770332864352, 0.15492528676986694, 0.10199996922165155, 0.10677939347390618, 0.1064316239207983, 0.1427505500614643, 0.07660343484686953, 0.13094461070639746, 0.1320146197187049, 0.08075789442019803, 0.08151821326464415, 0.12926514154034002, 0.16685553374035017, 0.11157702960606132, 0.1039999851158687, 0.13567018641957215, 0.15703426860272884, 0.13267136019255432, 0.11010048990803105, 0.11560358532837459, 0.28598587268165176, 0.05696994944342545, 0.18059010032032216, 0.09760596643068961, 0.100415936005967, 0.07886191151504006, 0.16214964911341667, 0.12772664480975696, 0.10789506110761847, 0.14749516546726227, 0.17659400403499603, 0.09295874794146844, 0.08254581383828606, 0.1319574327873332, 0.1760956607758999, 0.22257615093673977, 0.1255881195621831, 0.10263714074556317, 0.1401131930095809, 0.12312116979488305, 0.11218016581343752, 0.10822569086615529, 0.1053357966510313, 0.07701770761715514, 0.15536837013704435, 0.2608890879367079, 0.1766314727387258, 0.10485462711325713, 0.13045563123055867, 0.17435150008116448, 0.06692494026252202, 0.14243659190833569, 0.09524233040532895, 0.12361979803868703, 0.16968611042414392, 0.11543591932526656, 0.1400215229285615, 0.127430030011705, 0.32629964660320965, 0.12689667434564658, 0.11869291455617972, 0.19671756135565893, 0.15389000517981394, 0.1392319660101618, 0.09709991501378161, 0.17201296985149384, 0.15488973153488977, 0.0762689510094268, 0.07505575075213398, 0.1198096474898713, 0.09592010546475649, 0.08546747706298317, 0.11952071370823042, 0.0694951427036098, 0.1287766234683139, 0.1517078908426421, 0.17061917749898775, 0.20322338225586073, 0.12522617541253567, 0.07553037242697817, 0.0968768194850002, 0.1045110576919147, 0.12100966381175177, 0.1207677253655025, 0.13058984545724733, 0.12015435685004507, 0.09611445146479777, 0.11936954967677593, 0.11014300691229956, 0.2271037029900721, 0.12917381072682993, 0.10532339303089039, 0.09465462408427681, 0.12584437509732588, 0.19520503894558974, 0.12492852924125535, 0.185367203982813, 0.08092972662832056, 0.10351262055337429, 0.10862696969083377, 0.15512374469212123, 0.17306537766541752, 0.11088731233030558, 0.2415862594332014, 0.1703538160238947, 0.07784471288323402, 0.11410392794225897, 0.11859938528920923, 0.14839636853763036, 0.11587314014988286, 0.11861127322273594, 0.07828284973012549, 0.15104778483510017, 0.14362512741770062, 0.10214972190026726, 0.17190387499119553, 0.16063963728291647, 0.31177286324756487, 0.2711895480751991, 0.15188298001885414, 0.10139842757156917, 0.07147068383970431, 0.1068390706287963, 0.10301619754838091, 0.08863297863198177, 0.05786022131464311, 0.16756400572402136, 0.1589061024465731, 0.15951911812382086, 0.09888887259044818, 0.10039649597768273, 0.03804411838895508, 0.08216854158256735, 0.16197002732328006, 0.14406994783452579, 0.13661480216043337, 0.1332549817327942, 0.1386347466281482, 0.23549220072371618, 0.12248045631817409, 0.11409825538950306, 0.16445019495274338, 0.21289017211113656, 0.13222641763942583, 0.11607702635228634, 0.09791619942656585, 0.09569744419838701, 0.13481029256113938, 0.07199207693338394, 0.12667289349649632, 0.12048651331237384, 0.16317925815071377, 0.10515553703797714], [0.015911351024572338, 0.028899607115558217, 0.05473744709576879, 0.05343899569873299, 0.03771219262853265, 0.0375524688778179, 0.04020192420908383, 0.015337702252769043, 0.02017717176516141, 0.0360520481398063, 0.029792304749467542, 0.029010103150670017, 0.03000178886577487, 0.01859699602105788, 0.03192494370575462, 0.05104939553088375, 0.025725148884313445, 0.014107822756549078, 0.04127852179642234, 0.039903328088777404, 0.02172361414081284, 0.013675986107305756, 0.05488070958693113, 0.07086618377694062, 0.046897086913564374, 0.018497429488758956, 0.0167272469760584, 0.01723943404587252, 0.02578118909150362, 0.04414200742862054, 0.017047323818717684, 0.03864308839131679, 0.024606670419286405, 0.021330906909757426, 0.05174753681889602, 0.028211599748049463, 0.031055092345923185, 0.02920410649052688, 0.01658482586831919, 0.037186507800860066, 0.02212514741612332, 0.029912137426435947, 0.03871173577915345, 0.03632418139438544, 0.02146332641132176, 0.027103404481230036, 0.03469166685161846, 0.012645953833790762, 0.037274988767291815, 0.011998552546304251, 0.03255900414660573, 0.06400934314089161, 0.06552850840879337, 0.021048641431012323, 0.06543259069855724, 0.04902927125138896, 0.00966113681040172, 0.023732839451570596, 0.03272110276988574, 0.04723936372569629, 0.027995954533772807, 0.026997451238068085, 0.027194594498723745, 0.07499371229537896, 0.026548885307939987, 0.0356960072448211, 0.06041145870195968, 0.022171664384326766, 0.04103556554764509, 0.06252159404435328, 0.09219109413347074, 0.039040893116699796, 0.053631519832249196, 0.03345071111938783, 0.011368970436576222, 0.029361736960709095, 0.06698260895375695, 0.026651362755468914, 0.02810181787104479, 0.0754642424040607, 0.04853351999606405, 0.08932278411728994, 0.05597472516819835, 0.031202884058334997, 0.026454367076179812, 0.030552026483097246, 0.021542509751660482, 0.028077670506068637, 0.023768623692116568, 0.008003003329836895, 0.05950676117624555, 0.0071217737859115005, 0.03652843400569899, 0.07082668625350509, 0.034063479131353755, 0.030451589729636908, 0.013162570889107883, 0.020828500922237123, 0.032882634816425185, 0.13814630998032434, 0.047615930304995606, 0.03289808505879981, 0.039128183254173825, 0.03446318714746407, 0.010264101687685719, 0.0626687750752483, 0.01784317584575287, 0.003991524231553609, 0.029203550091811588, 0.054432801835771115, 0.026138851685183387, 0.017030767564262663, 0.04940842644178441, 0.06726847575711352, 0.05390941384913666, 0.03412345823432718, 0.033588867634534836, 0.02078280158873115, 0.02872278428237353, 0.062411997068141184, 0.048193282181663175, 0.01961995880784733, 0.057623941850449355, 0.020646127672599893, 0.022479714193780507, 0.043460242583283355, 0.08159338815936021, 0.01068567464660321, 0.04464823526463338, 0.054426050412335565, 0.0554784378702087, 0.0664579113945365, 0.062171178204672675, 0.022672350285574794, 0.024801123288593123, 0.04126214535374727, 0.007586029142008296, 0.030871742005859102, 0.019096630193027, 0.06615111178585462, 0.028211823664605618, 0.03373498336545058, 0.056862377894244025, 0.017979435855522752, 0.05974162928760052, 0.04615462711080909, 0.033331316097506454, 0.08464484834777457, 0.025011704935293113, 0.045774871416922124, 0.022337398258969188, 0.05248856491276196, 0.007444510485843888, 0.05749019581292357, 0.023945940159527317, 0.06847472103046519, 0.05809912670935903, 0.04923661458971245, 0.0459115860451545, 0.053770965563931634, 0.06751483825168439, 0.037927339119570594, 0.02898975388546075, 0.02440101663315935, 0.05221037234046629, 0.04415787157735654, 0.07351423454071794, 0.01357965194620192, 0.03507433346073542, 0.007926963302972061, 0.02302968378977052, 0.047819785973323245, 0.025465680485857383, 0.06107230431267193, 0.023483557560081993, 0.032878424506634474, 0.05246962700039148, 0.0646841801436884, 0.055982932049248896, 0.024383539267416512, 0.03312886838934251, 0.05428924418187567, 0.016812087602115104, 0.06308701727539301, 0.0121935923484021, 0.04562863354970302, 0.04654245397874287, 0.029230976477265358, 0.06982355365263564, 0.030872278048523834, 0.04321263836962836, 0.03739059077841895, 0.0928898359249745, 0.041911795136651823, 0.032693930835063965, 0.04438445477613381, 0.030393717477896383, 0.025969684423346604, 0.0487257218254464, 0.05512551823630929, 0.021619479371500865, 0.026055139123595188, 0.030254682259900228, 0.03462725352229817, 0.009494223132995623, 0.028711839512522732, 0.048962442337402275, 0.03381557636229055, 0.04510485879810793, 0.0396096920594573, 0.026069347646885684, 0.01994671073875257, 0.03318159395296659, 0.012968387737471079, 0.015443842093061124, 0.004799363003777606, 0.02500494842284492, 0.03568738306473408, 0.02131942779357944, 0.01743939153051802, 0.030978054872580936, 0.016330348094925284, 0.0038890361819150193, 0.026854076788627675, 0.050666345549481254, 0.06473520597709076, 0.01549161265471152, 0.029050808466438736, 0.048267398561750136, 0.024836032218965035, 0.019294004155589, 0.02313185080752841, 0.04037090317745294, 0.051174276508390903, 0.040388551873287985, 0.021972689079120755, 0.017790480816204633, 0.031686380971223116, 0.039000835801873884, 0.06932514254003763, 0.0462002551981381, 0.02813159198766308, 0.017720847856253386, 0.04665034443938306, 0.07183511142752, 0.03232829545491508, 0.0756705306204302, 0.038325835950672626, 0.08265619791511979, 0.03531083684148533, 0.030896501748689582, 0.02695324637794069, 0.07905304804444313, 0.0380685558276517, 0.05345145020900028, 0.014372370837788497, 0.03059648409751909, 0.017539806231590252, 0.028484092626188482, 0.06488769993718181, 0.07920738083443471, 0.007790041721558997, 0.024867867385702472, 0.021526277497676865, 0.0684829448748912, 0.024001437538702573, 0.03226474386506847, 0.037079346765364916, 0.05370152768279825, 0.022346142879022018, 0.02283176191018096, 0.06014098785817623, 0.03664332694773163, 0.03444455796852708, 0.04649838312928166, 0.04670807759144476, 0.016917984866138016, 0.03312454612127372, 0.012296454864554107, 0.036406267168266435, 0.04601517120110137, 0.038501138865415535, 0.039035634470305274, 0.043898389608200104, 0.03024019892992718, 0.0005462260970879079, 0.03377506782167724, 0.04325189162045717, 0.03865830793178507, 0.023391739897696034, 0.02392154004025672, 0.007067035517788359, 0.06293292197265796, 0.019001876170347844, 0.0324526878872088, 0.03335284262097307, 0.034487407454954724, 0.06501580734870263, 0.05103660175310714, 0.06064148885863168, 0.05366333633927362, 0.03422289414863501, 0.022122811559321623, 0.03315429648916636, 0.030365117226860354, 0.04878838453441858, 0.028806481576923813, 0.01553932045187269, 0.02928501500615052, 0.019423259987628887, 0.026662753662094474, 0.01989333378151059, 0.016912717738055756, 0.04072180077699678, 0.022227801282757094, 0.030850639566779137, 0.0708592627197504, 0.03102172877905624, 0.027921539598277638, 0.09077937488577195, 0.006897083699836263, 0.03460808151534625, 0.04001734572063599, 0.04506281676835247, 0.030536613560148647, 0.02243967044965497, 0.042541981142546446, 0.055016613365816217, 0.0019238569116818585, 0.045202703547797034, 0.00309136080405941, 0.08628040951277528, 0.0790677247568965, 0.03281021138120975, 0.0069662628894937885, 0.06842642290783779, 0.10397017028714929, 0.029009271945272173, 0.03684496380654829, 0.07023407412426812, 0.05699599840279136, 0.027818826359829733, 0.057053307470466406, 0.03206394499699984, 0.028473517657922845, 0.006580252374988049, 0.03835736068763903, 0.10355288482138089, 0.02964466231475983, 0.020749556765492474, 0.039791946565466266, 0.037800656631588936, 0.11167555967611925, 0.15526416072888033, 0.24216762823717936, 0.1699594379003559, 0.12096424267760345, 0.12566953019372054, 0.12161877112729208, 0.16838818149907248, 0.10047587100416422, 0.15690208998109612, 0.14480246709925787, 0.11979942875249044, 0.10468464730573551, 0.10424724327666418, 0.0770381586626172, 0.12078163533338479, 0.16359920347375528, 0.16355182815875324, 0.11256451518940074, 0.16652691923081875, 0.12763667106628418, 0.07083947663860661, 0.13685637419777258, 0.1225302065057414, 0.11130921861955098, 0.09997368723686252, 0.11584785793508802, 0.13093596617025988, 0.12428858929446765, 0.15439355958785328, 0.14447424614003726, 0.07645617917712245, 0.20302782846348627, 0.09809054221425738, 0.18211381855819905, 0.13560527775968823, 0.16978174314967223, 0.14816798722105368, 0.09175966121256351, 0.16146002683256352, 0.14410972355731896, 0.13777831329831056, 0.10825686955026217, 0.08002862533820526, 0.16274091095796653, 0.12537406890520028, 0.1299545331192868, 0.08404535587344851, 0.16400857722120626, 0.18102470199976647, 0.10542034211435489, 0.16468477807939053, 0.1412560495414904, 0.10515158117881843, 0.07554993459156581, 0.15850168200475828, 0.12903834799570696, 0.10489632309015308, 0.07749787970845189, 0.12898121534713677, 0.13132707375500882, 0.11056041451437132, 0.20277001229780062, 0.20334477217069694, 0.08824892781142678, 0.12433770165911742, 0.14185835793614388, 0.08276997466704675, 0.13837659119495324, 0.1350762104349477, 0.17234208647693905, 0.09352790311511074, 0.1586871799081564, 0.07991347116019044, 0.06952939515135118, 0.12843986653855868, 0.12801552430859633, 0.13073247351816722, 0.1715754233300686, 0.09906008733170373, 0.13860274691666874, 0.18427903737340653, 0.1759012740637575, 0.16023201415581362, 0.21365291332559927, 0.15775382784860476, 0.15076153805213316, 0.11483253884528365, 0.14304492569395474, 0.09254055323877505, 0.08559926213430506, 0.10716989037713834, 0.16211611591279507, 0.1590660060090678, 0.07783143395291907, 0.1419196975018297, 0.10707564186304808, 0.1186588928103447, 0.1025124192237854, 0.3673268865261759, 0.06651061320943491, 0.1330122019031218, 0.1308107493179185, 0.11169073171913624, 0.1195131955402238, 0.07950760543878589, 0.09158320139561381, 0.1264321357011795, 0.1764057105673211, 0.13185790527079785, 0.11032224872282573, 0.09047472623309918, 0.16796763906521456, 0.1819682999380997, 0.15610179863870144, 0.09917444083839655, 0.11789279963288989, 0.11997527788792338, 0.09626276564917394, 0.1854429692029953, 0.11357355104493243, 0.13373607663171633, 0.14230266266635486, 0.11657678096422128, 0.09449073073587247, 0.23378354098115647, 0.1369899913136448, 0.10673425053911549, 0.1559697828654732, 0.15235182057533944, 0.11122030339070729, 0.10503096479390349, 0.12235566015754427, 0.052617323717900684, 0.08765306549945048, 0.16395437584391662, 0.11672091537288257, 0.12288133480719157, 0.06975026508527142, 0.1550818383693695, 0.14428273641637393, 0.10962446366569825, 0.07709593591945511, 0.23222304614526884, 0.11974104759948594, 0.10185569232063633, 0.12574232343052114, 0.1961864855672632, 0.09803542481469256, 0.12922289595007896, 0.07296695533607687, 0.11752252307321344, 0.13301635453743593, 0.16292206623724528, 0.06555900855788163, 0.1150068137794733, 0.13961457833647728, 0.10635430485542331, 0.11471196317246982, 0.22595587958182606, 0.16250138809638365, 0.1279448073889528, 0.19895883037575654, 0.1254360055817025, 0.2056462001055479, 0.1178877241909504, 0.1871874148824385, 0.05572984527264323, 0.13353546096810273, 0.09515850418912512, 0.11185045886252608, 0.16253557269062313, 0.08351881948432752, 0.13168540809835705, 0.08210864729647126, 0.1332786897463458]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.01888060330280236, 0.016531455696427395, 0.020879599698153988, 0.011424585711210966, 0.055266958860946555, 0.030123453587293625, 0.02033037818702204, 0.09160014441502945, 0.04060964233108929, 0.00473500183683687, 0.06273841312421219, 0.022787305992096663, 0.04757506214082241, 0.030350131780973504, 0.07055788460586752, 0.021898715191387703, 0.07475807743945292, 0.08146720778729234, 0.009958861013209181, 0.01777952247565346, 0.010086372162082365, 0.04406338557600975, 0.032856053207069635, 0.042974611677761586, 0.04249851079657674, 0.034262859861233404, 0.05696669247533594, 0.03513800718688539, 0.010415311520253974, 0.0032227251836697435, 0.013271401968917676, 0.07442640952233757, 0.06710865361882107, 0.08695293949650866, 0.05974172428250313, 0.05183954616742475, 0.010125851025804877, 0.02549270653565015, 0.02712765701913408, 0.12149944395891257, 0.045758077675210576, 0.044556035926299434, 0.010934248317166098, 0.019481283213411058, 0.06056564899959734, 0.046021328906395605, 0.031841015709297996, 0.027932820242962668, 0.0381844292527863, 0.025528804598642246, 0.007500910316593945, 0.034870314944003306, 0.020083703566342592, 0.01714161304490907, 0.062127086999160905, 0.008975621362748955, 0.0504069246484765, 0.006676864735449531, 0.019536777199911218, 0.04873832900609289, 0.0602881485330207, 0.05551623905609761, 0.08270919150007622, 0.0480094263330102, 0.024928346908252155, 0.010264815845792847, 0.03551804447280509, 0.006415966324441667, 0.02048408842113401, 0.03996378555893898, 0.01384288621401148, 0.06583726219832897, 0.023011823051742146, 0.125573924609593, 0.04281539682831083, 0.04941975797659584, 0.01595343037375382, 0.10121102977011885, 0.06313794132854257, 0.033025971946439574, 0.03207477441589747, 0.00916604882305754, 0.04576967044600418, 0.06724872360272066, 0.02533248745437179, 0.024711982446855733, 0.03389697003045252, 0.06622608312006507, 0.039684025570750237, 0.034184682449059825, 0.05114237518448915, 0.026976235144372498, 0.0024946399332423297, 0.02884786542771118, 0.030228331352451017, 0.006594228924119047, 0.02865239305953894, 0.02147850693602647, 0.05115326227886336, 0.031744992826133966, 0.05978126251803977, 0.04673446581832, 0.01401869039649942, 0.011414880964106746, 0.042291676359517236, 0.044979502846087725, 0.08178070453660828, 0.02267854191761996, 0.05552202356713159, 0.03314935336155551, 0.003844211310414331, 0.009970888894583498, 0.0466698557138443, 0.02220839518122375, 0.011797305845123316, 0.018901359689022814, 0.039282726390021186, 0.03729323796661837, 0.021393167586731057, 0.028717596882155964, 0.03255827132878559, 0.019149523694068193, 0.03769310883113316, 0.05349837429821491, 0.01762238055068467, 0.02851289643773011, 0.041499205133212466, 0.013845151672804994, 0.029863394863371338, 0.05626616274405803, 0.02232718969961362, 0.05602397323985185, 0.04056964608441506, 0.029086784393127476, 0.0588473201330219, 0.016846748867205212, 0.008944334113039076, 0.02311092648389084, 0.018838164330060993, 0.012293951070335294, 0.03256078190835459, 0.023304994284574474, 0.04181471034618361, 0.012170882629496711, 0.02053960276368473, 0.028100437052281838, 0.0696843114814588, 0.026922291610389948, 0.01857521674329681, 0.016999682178720832, 0.05381004578833069, 0.02316957905090281, 0.014716997077422482, 0.028231960887621557, 0.022544254748416797, 0.04057968161734087, 0.005995843734126538, 0.017056076920458248, 0.037214531297130246, 0.05422585544043353, 0.05990392807871103, 0.0437843821543668, 0.0016990966396406293, 0.0197350383470101, 0.038134567106940916, 0.04861181954454098, 0.0178493589961103, 0.05399066163226962, 0.06623468015875135, 0.02493364965942289, 0.012162933591753244, 0.04456239379942417, 0.012519468969133283, 0.008715137706271239, 0.03117764594831637, 0.05861631967127323, 0.039521719994289536, 0.08238289758030858, 0.021325748347278153, 0.03892493148201278, 0.021371873461508324, 0.022226576527048434, 0.03125309904239007, 0.047396376729011536, 0.028041731898805926, 0.019301578302734664, 0.015436971925997307, 0.03910623603899564, 0.02041413146071136, 0.020970358845910857, 0.033519304224423, 0.04434671465839658, 0.046390166971832514, 0.007481795985118619, 0.02474346647172102, 0.028459436359948347, 0.009121654821293694, 0.04020862474239298, 0.018679807827408825, 0.01655819167249969, 0.02480106900579163, 0.03464617786396827, 0.06287630501070193, 0.10055242332496814, 0.025150755420327187, 0.03235842580241816, 0.04760166749890361, 0.07098028622567654, 0.03969614759885839, 0.0762468104117683, 0.040579176108751974, 0.026214554140876447, 0.01775587213757847, 0.01874364779463836, 0.06652442139706441, 0.11500095123691217, 0.04595186049118638, 0.06879376141088349, 0.005560142827952015, 0.027223776593538265, 0.05311800113746098, 0.060540570345308097, 0.008093465618523104, 0.01406524722863521, 0.08183027830507074, 0.04918975156864949, 0.04022822422640664, 0.02388405946216413, 0.030906323543084518, 0.017821881720530133, 0.0756470804501857, 0.011035443333509778, 0.010085839512092727, 0.018191880080848932, 0.02469590286325131, 0.056304774779294214, 0.01769157076653625, 0.04590325024245041, 0.04830146441236138, 0.05514964015622224, 0.02429427968205086, 0.05653372606528657, 0.031525083019265106, 0.025766020441161733, 0.018078278051689267, 0.030790158347891908, 0.03259086815108146, 0.04317211625831468, 0.034735154160963636, 0.06220323898430381, 0.011298871831968427, 0.023648112480129515, 0.02043507105138685, 0.06025016414267676, 0.03261898324957915, 0.025917734085981334, 0.029426411526011567, 0.015219701620350991, 0.029709211351083856, 0.016959221135558825, 0.02928279958931463, 0.03610747766547969, 0.0044159750271189424, 0.02308036357031337, 0.005139587671562497, 0.043356715102813075, 0.04038771388253995, 0.06995598333222525, 0.024009785215769495, 0.027083922044507096, 0.03493831433089716, 0.03573233600971954, 0.06937183932002101, 0.02974020004538553, 0.04651717854929822, 0.03064951839457665, 0.025313495259199823, 0.03302680315183742, 0.060494606383144855, 0.011647537051300918, 0.018188767301450883, 0.04573555709794164, 0.13970278788890156, 0.039281901969973526, 0.06602794410926954, 0.023388260709387914, 0.03985610883682966, 0.03557387772681458, 0.030744475977761403, 0.03596929740160704, 0.02903349564543792, 0.010658462847849088, 0.052309326494910886, 0.053345276441957266, 0.017928040220535228, 0.05683349944385035, 0.04500529056947146, 0.026491031715912477, 0.06712670265031712, 0.027040887657286863, 0.05107061671359198, 0.0762246698141098, 0.04047360623787556, 0.026105072515617524, 0.021869811295930828, 0.04393503049920712, 0.047023009442325146, 0.054604488158864636, 0.017179056303575635, 0.05119523984779205, 0.05085612161617194, 0.014078057121618517, 0.018808559847197363, 0.03358472178557089, 0.0336395372370524, 0.052358669561467, 0.04953441682404705, 0.08320639482034103, 0.009607273852452636, 0.021983250476686016, 0.040209645937596045, 0.0033195044213373747, 0.03903907464284982, 0.03243066942585366, 0.004877290206163057, 0.014275603262441499, 0.043452256226113865, 0.018026829830237796, 0.07656387625528233, 0.03364995614226375, 0.028322460495733788, 0.022092338551634123, 0.02402382410530533, 0.0114847615893398, 0.016250801738351583, 0.060767567450446744, 0.021191990435389534, 0.03682687067027603, 0.017135056700291376, 0.014546415070071816, 0.003296968577030514, 0.056269440068198104, 0.07593332044780254, 0.04866937967017293, 0.046592584145920615, 0.05707516308341708, 0.08737551075007234, 0.017386922113863484, 0.0492244891689292, 0.025998584926128387, 0.0190389733761549, 0.039594448770263364, 0.11011747363954782, 0.13005456275173596, 0.10456738966916289, 0.07876539669398751, 0.11229183910680668, 0.08945743939174072, 0.09883480013481208, 0.25547638695154873, 0.13327498494514398, 0.07655704340764455, 0.09622459805437497, 0.0914074404697333, 0.1056827926742179, 0.10753914234893662, 0.10516914166510105, 0.1576561459473201, 0.1663011299180133, 0.10249249743563787, 0.16229423135519028, 0.09016984009316989, 0.13222624122032098, 0.1283392940780946, 0.0859381157372679, 0.12053843481200081, 0.12718003056943417, 0.12272201478481293, 0.15947514905461244, 0.20465712675026485, 0.10081674664148263, 0.1607893763908318, 0.09860136373234646, 0.12356890791228839, 0.09084962361625262, 0.1372390000947884, 0.11979872307607106, 0.13200550020805427, 0.14790126867592335, 0.14022285783929483, 0.10582882019558124, 0.3057664441210883, 0.09594930282660893, 0.11648162321320601, 0.0718182905444077, 0.13386638249669755, 0.14830457632030758, 0.17562779730984143, 0.08217667043209076, 0.14923596062830516, 0.12827861947672708, 0.16271941496857575, 0.09342539004449334, 0.16684859911245958, 0.07618488730596644, 0.09091658145189285, 0.1303710721965347, 0.12337464333644935, 0.10666706200156893, 0.18111881480685302, 0.0857010559578027, 0.13678731290357454, 0.08371022742773805, 0.17611696677548544, 0.24718699604272842, 0.20343528874218464, 0.12331011465617589, 0.12989147007465363, 0.12093061448207923, 0.09943887272051402, 0.061544625753802915, 0.23087479706321443, 0.07221116232020514, 0.20850937361163752, 0.11529215132551533, 0.20307718510074274, 0.14601313642093114, 0.15271442968930515, 0.07489886667047228, 0.14679026257778915, 0.12787277411137307, 0.13163504722927297, 0.08290872829301016, 0.09165005066565104, 0.15716107322701386, 0.09774771918143545, 0.12777815918837274, 0.1454951020755938, 0.11045736540108919, 0.12231801503470965, 0.06343511931066002, 0.13771009338753565, 0.15079044364392757, 0.19490128595914158, 0.10761572181114129, 0.07827212209148066, 0.14970846527389117, 0.09610176964529923, 0.11712781925286565, 0.061273252458444664, 0.1529401782900095, 0.09421263315847941, 0.1046769730746746, 0.07071687214608703, 0.14261200678135666, 0.08891740694109883, 0.10197611871574606, 0.07496324607304164, 0.19460233700062546, 0.12270364005650793, 0.19090307264455728, 0.14033085347286292, 0.15121717431715556, 0.18433872131364687, 0.1349291176136051, 0.07762921016131129, 0.05153951833822897, 0.08112174525324788, 0.16175259756190435, 0.1876428068748542, 0.08981587551534176, 0.11643769485609871, 0.1635486390441656, 0.1495069810854537, 0.08230257260480098, 0.10283136460930109, 0.10784359422645398, 0.14353356590228422, 0.14932673504309996, 0.1721371824720076, 0.10412012652627059, 0.19564287045172282, 0.08372979637767587, 0.17279392294585705, 0.12688910189483846, 0.14064941209341797, 0.15647253660219057, 0.07182139144944293, 0.13155413871364935, 0.07459033001214266, 0.08522082279835429, 0.059708923899701664, 0.10825309011020831, 0.12757218309811183, 0.11010036098637752, 0.08142818523836987, 0.08972998655268125, 0.06402533621128116, 0.11318898453776326, 0.13631379045546055, 0.07250386197119951, 0.11244030256888696, 0.14484714184488567, 0.14029428043535777, 0.09473387697445494, 0.10662439571959631, 0.1503848425511803, 0.09587205840008599, 0.09417129680514336, 0.11356507614254951, 0.11292875278741121, 0.1579267457127571, 0.11027177250278847, 0.13234533768679413, 0.08494990412145853, 0.2670463046857289, 0.15950872296733515, 0.08895781370145933, 0.09471068464751754, 0.1278171885226454, 0.20082953785146984, 0.10615235926317317, 0.10352188255637884, 0.08587297637547765, 0.1853873429021665, 0.10171143577567168, 0.09144355888877596, 0.1462591460772923], [0.03806137014180422, 0.07687932718545198, 0.03405047840039645, 0.04921233321407011, 0.05204996666205781, 0.028506796407912458, 0.08492137172392436, 0.07481929486883537, 0.026360201682629328, 0.04238886632291334, 0.04157185248498406, 0.03812913543411663, 0.06685418941612754, 0.055140642781874964, 0.03923284388812525, 0.016302721541641012, 0.021869212488776872, 0.027743269789165685, 0.041647088447851796, 0.020611934596672654, 0.008033489060055996, 0.03738259763589927, 0.037196960632822344, 0.02811336992973728, 0.02104572033775704, 0.05512925357158695, 0.05097652426255601, 0.0755704738465803, 0.07614631259015628, 0.03954905138484069, 0.04155778306137238, 0.03618924792057701, 0.05858541918652398, 0.021112566215119193, 0.08121081654514585, 0.018879862003294483, 0.091878696610885, 0.02366655506193638, 0.03382481800924454, 0.04376570887065359, 0.03896093115742717, 0.03661561897024512, 0.02075341254073594, 0.015785513312688897, 0.05241815333387681, 0.01113091321063361, 0.04947120450170977, 0.023856912972405553, 0.032377998145031076, 0.08151343637811286, 0.014521828353671091, 0.027597927588171194, 0.024027021701580713, 0.04076520666213972, 0.10013741773686238, 0.042718898970633745, 0.02868421295923846, 0.02668283660230892, 0.0562349501332002, 0.011143430485390127, 0.04384611866303852, 0.026805424131453037, 0.04185194834800703, 0.03800287703052163, 0.04376633312287075, 0.0340981454854565, 0.027867767394387295, 0.026528032230479375, 0.01586216062839542, 0.019126436540058682, 0.04777373719428267, 0.02165467498291816, 0.03805629809253982, 0.02322654376205589, 0.07954638371510164, 0.09246003827346222, 0.04872274644938963, 0.04721164217750941, 0.021097584161907434, 0.04763948225549289, 0.06078998624746289, 0.03760409860738686, 0.04151639921058502, 0.06817780767700501, 0.03533883998170495, 0.07272888453943388, 0.05933739883559091, 0.03743466502055526, 0.031406939894493134, 0.033600480761379004, 0.02920728881976434, 0.019883732510996715, 0.05064775708264538, 0.022550186840817332, 0.02584686958497124, 0.07603081235928194, 0.03230156796053052, 0.028381284392837967, 0.006295533992150533, 0.020878417350883995, 0.052305696332561116, 0.08509101226393666, 0.060653302153306346, 0.013085239949370069, 0.033739909529685974, 0.03970139267455254, 0.023549182074410573, 0.04911765383024301, 0.06186722165771893, 0.03328401881403156, 0.017266478755378296, 0.011382301105186343, 0.0138423993651356, 0.0718533843755722, 0.04632817940520389, 0.038624367610152276, 0.06628850155643054, 0.03336940226810319, 0.019070001086220145, 0.05257502045216305, 0.04776552352788193, 0.09645656203585011, 0.02415453709129776, 0.03043867042288184, 0.03852526757067867, 0.018333451323477284, 0.05523343923102532, 0.01407190365716815, 0.0635176630956786, 0.009008546426360096, 0.026942666320662414, 0.023402569316593663, 0.054261458172862015, 0.020372806981738125, 0.021320576214098504, 0.04295905286978398, 0.016384194937667677, 0.04525043509368386, 0.0592341868739043, 0.044422876821564775, 0.027981805382296443, 0.03728708365399923, 0.01864794551927064, 0.04417041090450116, 0.0032760870859159952, 0.0196776325880949, 0.04623752712671246, 0.04773118287058813, 0.09874240402132273, 0.01123243646829256, 0.008266244382996644, 0.024732038245669434, 0.051978910474904945, 0.027900530457762734, 0.010483037796802819, 0.025845782232603857, 0.036274397280067205, 0.020587592152878642, 0.02227089334545391, 0.07082203150327716, 0.05352419934102467, 0.07532020977565221, 0.015557242258052741, 0.00936627941804805, 0.018607318235029067, 0.0982064495661429, 0.007360483253640788, 0.03605278774297663, 0.008606537328367787, 0.010927646171434649, 0.07662139566881315, 0.02393135504930147, 0.04664802045694419, 0.0501483281675194, 0.05520192467208419, 0.012928385553615434, 0.006995141763971853, 0.0046414144703054005, 0.06140614354184695, 0.029436833823898008, 0.012666438806003757, 0.03407643236485975, 0.02884832683152386, 0.03177420715136187, 0.019462545468871082, 0.023439608846924136, 0.043696050465639145, 0.06767802592366934, 0.08253725072635071, 0.06819284401301827, 0.03366023934047137, 0.04649814564202513, 0.029699012969753573, 0.02154916787653097, 0.0433909912992801, 0.04277833863826735, 0.008085677732846566, 0.015180042944848537, 0.015310474338808229, 0.04420041233035071, 0.02971608830349786, 0.04987437643909028, 0.016441556591806666, 0.004629063860712839, 0.00826168802034642, 0.033845509934638224, 0.03519971655415637, 0.009857946740729468, 0.08687453477510385, 0.014326837745362093, 0.04730544285848737, 0.009360254875251224, 0.0718104127528412, 0.03089877823367715, 0.04092138846005712, 0.036735030955501964, 0.026488699251785874, 0.041890054874654324, 0.02501530625990459, 0.03903068116466914, 0.04474564914458564, 0.015606039103918841, 0.05464322233040418, 0.04723500753087657, 0.023270214275856103, 0.012017596479771393, 0.029473400076052973, 0.020952496411544935, 0.030812841773565327, 0.004828076485344874, 0.04180946187781436, 0.010551077895797789, 0.010996938167539026, 0.030068722952689444, 0.030445194537086145, 0.007087755432751561, 0.056416929832526615, 0.008051632238285882, 0.02849632321989962, 0.06286209648741142, 0.03379829068269048, 0.04965104003037725, 0.03929868892633489, 0.038866221239524226, 0.05463517151240792, 0.019836372463032603, 0.02309975610114634, 0.036612161834325106, 0.011373556485133511, 0.05321723009858813, 0.08078167028725147, 0.08798596156494957, 0.04615749731393797, 0.01986884036367493, 0.037666764709034135, 0.03938763129657932, 0.020020475976967385, 0.041796125272022824, 0.024936921894550323, 0.03495999013206788, 0.022456842474639416, 0.03326476877555251, 0.027027622297672287, 0.07407245851520981, 0.07007346488535404, 0.018385627273736254, 0.059376095687704425, 0.01062552845438144, 0.057474637004945955, 0.02680487960710057, 0.018632318857791166, 0.05451639395739351, 0.014955527581540602, 0.03656665588329945, 0.01973162022685366, 0.06839512887277774, 0.0844900541539703, 0.05969020311853715, 0.0016673047295106308, 0.04119246659268226, 0.00849783601838031, 0.04084911769522088, 0.019544315723968402, 0.014587848114648035, 0.06060512616698231, 0.03804332450298326, 0.03348243941685983, 0.03956798929721117, 0.0023482780213401255, 0.01300930424726435, 0.026840650276946168, 0.029649405274540186, 0.05103647283145359, 0.035482618159481456, 0.026957590698397586, 0.018048588751948307, 0.060947983126555166, 0.030816281946109872, 0.06772624940744468, 0.07497921200203043, 0.07975054133151259, 0.02939054077225072, 0.08261917025915214, 0.026244621723890305, 0.03488443525774138, 0.02785643925225096, 0.011503531564293163, 0.024374514751668488, 0.0558820712114019, 0.027975815614419322, 0.0884888374379703, 0.03481949945645673, 0.01663791444817824, 0.02882677995200668, 0.040628417395055294, 0.028526877651789358, 0.04540475431297507, 0.053406147818480215, 0.03780971507408789, 0.009981430784266974, 0.029869783270571913, 0.038068566005676985, 0.01903689536266029, 0.02130194703516151, 0.025897432318223373, 0.037291731618876965, 0.013438795709849467, 0.04675864202103444, 0.04360863479918667, 0.035125579818018844, 0.015117129177919455, 0.02313875320500561, 0.04989769429500614, 0.04194136230008943, 0.03173068930794086, 0.07575764094612428, 0.048549340040023835, 0.04818393536178129, 0.0268381006816136, 0.031193530453102927, 0.028274106393967356, 0.023100144562444518, 0.005573501062047268, 0.037228648218193224, 0.033026236575096846, 0.12997433277113096, 0.0601908058992454, 0.05271313625520893, 0.054324358369090726, 0.07229538887206997, 0.05133547607277121, 0.015685778842972856, 0.06990133412182331, 0.08509143295564822, 0.09970407134720258, 0.10522966698876449, 0.10571560662771974, 0.10579311568289995, 0.20785435661673546, 0.13100057627473558, 0.05767175821321351, 0.21176867586161408, 0.1378716118633747, 0.14754096658102103, 0.18412141368857451, 0.11942259754453387, 0.06537675405187265, 0.114321588405541, 0.11701807299894945, 0.06054008858544486, 0.178965619632176, 0.062357734622699876, 0.11141117529145309, 0.09606455878487655, 0.10857179800846747, 0.1172520454440798, 0.14700956509581634, 0.10489635023155383, 0.13029633834958076, 0.2202613151499203, 0.10376676584460906, 0.1542386771844966, 0.11704655789903232, 0.13375648696507725, 0.16013796920222895, 0.10107763657080275, 0.18888227322271892, 0.17840456616665634, 0.1566476257784026, 0.15257044455834798, 0.14203556414161408, 0.18073138488190515, 0.09551404975354671, 0.11638814822903701, 0.1374394121978964, 0.10491174619112696, 0.1078609104401299, 0.07977507715778691, 0.11907501119588103, 0.11591268517076969, 0.08115261859659638, 0.14334919436701707, 0.0939457585502948, 0.11443315313330718, 0.25546232770596233, 0.1472826482994216, 0.16128676970090183, 0.09459639899432659, 0.11224985135985271, 0.12582334051174776, 0.13681164516934327, 0.09617455609674964, 0.16653831861913204, 0.09741733369550534, 0.1473944437290941, 0.2127389402261802, 0.11515770639692034, 0.09777587159935917, 0.19362283098910535, 0.16022778009729727, 0.10031808447092772, 0.09691610666257994, 0.1036510281264782, 0.17285808521722043, 0.1345812055681433, 0.12680553352194174, 0.22619794016437872, 0.26054773053952623, 0.1522566085415227, 0.1377458521830184, 0.0810951195391161, 0.13269208265202387, 0.08559954033366271, 0.07925063744187355, 0.1850321026785033, 0.17264335602521896, 0.052506580017507076, 0.1352965036141021, 0.11960805473583085, 0.13930969898189816, 0.11995002281452928, 0.1093066514336637, 0.2013450480465378, 0.17324513516255788, 0.13604476489126682, 0.1323334497532674, 0.07220132356243474, 0.19233645073005132, 0.07946125471166202, 0.12120733463338443, 0.11181824201984064, 0.11699432427329676, 0.22955024242401123, 0.22328538287963184, 0.1324746393199478, 0.1512085162103176, 0.08448836460177388, 0.142006088580404, 0.0787664009258151, 0.1359620379017932, 0.14249641155557974, 0.161762517743877, 0.17869096222732747, 0.09577754525733845, 0.09298353482569967, 0.11929625432406153, 0.1766619932438646, 0.09131297482443707, 0.16140655827309403, 0.11292649326579911, 0.1015751723732267, 0.11281696414308888, 0.12725228097821983, 0.1659800742885896, 0.10059893690049648, 0.09526317500110183, 0.24487696428384098, 0.12121355001415525, 0.11412934586405754, 0.1088070325287325, 0.15658490200127873, 0.09693114299859319, 0.09240659007004329, 0.07010906761778252, 0.16448968569082872, 0.08063679627541985, 0.20619319432548114, 0.11971363478473254, 0.061511268972286155, 0.20704346655734948, 0.12261939314859253, 0.09357366351676838, 0.14375191847128527, 0.10345195273735694, 0.10011294297873974, 0.08302329214555876, 0.11321088764816523, 0.18210359982081822, 0.09899678679981402, 0.15615517220326833, 0.09686549473553896, 0.154398825019598, 0.16765739928398812, 0.1442367181714092, 0.12475843408278056, 0.07426020236951963, 0.07062725802617413, 0.06777105986007623, 0.1492910169597183, 0.09405498233224664, 0.14326823156859192, 0.2953482445861612, 0.1683970567371164, 0.14054114504584245, 0.10466739894556147, 0.10105310074452843, 0.08797000242131096, 0.21910701851759637, 0.11764240664030824, 0.1836057813572032, 0.1572811467839139, 0.1951082662812301, 0.15982511027583055, 0.16764244437217712, 0.09049603223268475, 0.18291617264705046, 0.09669283471469368, 0.08691795423094716], [0.028070225280576518, 0.040612590565745316, 0.03101749811321497, 0.043601462684039555, 0.007533563118028853, 0.0029917291748071356, 0.014867759076878428, 0.055128106847405434, 0.027242527908778617, 0.03252234968489834, 0.011329872400632926, 0.006001181684301368, 0.014380594682214516, 0.017000218221385564, 0.012068266082288963, 0.06032134246613298, 0.01002096223445343, 0.09967116918414831, 0.04723214750577297, 0.03649707550981215, 0.05249912291765213, 0.007769756917176502, 0.08643921384853975, 0.04211311647668481, 0.01829534479682999, 0.04542406881228089, 0.02731236442923546, 0.054058016410895755, 0.022256657680762664, 0.027370195968874862, 0.029474075218396525, 0.026362953142129948, 0.061852178536355495, 0.018990765159417475, 0.10181225250874247, 0.01664313577514674, 0.01721067094643201, 0.08981752435543708, 0.00589509994357026, 0.017550751001441052, 0.06315560359507799, 0.046857301012745926, 0.026374069242072955, 0.019848855811038187, 0.025062464443700652, 0.09926078441951956, 0.06647975343678679, 0.0570061696427209, 0.059525400533207824, 0.02501013921573758, 0.05226303005058851, 0.030413110008729354, 0.010741038863281054, 0.009809368722406881, 0.09955373512847082, 0.08559198823890515, 0.01551931384684784, 0.029601799257631813, 0.010774460105624582, 0.1118327219571386, 0.043841860855796506, 0.027383227233908007, 0.01494465405786676, 0.04716379188799432, 0.013579219380127532, 0.010923814144916832, 0.04395737126469612, 0.024949574876310568, 0.0607291827244418, 0.037040300467716794, 0.01063874886105103, 0.06214385359947171, 0.02380646389376904, 0.031822942929076295, 0.004410024699089783, 0.036168494927031655, 0.05077364229198013, 0.015724041432674443, 0.01854724413715303, 0.03106952817844493, 0.032800508330443075, 0.054600742645561695, 0.053317948444081206, 0.014385766815394163, 0.01977326700996075, 0.01406147372576275, 0.00861395032344652, 0.027042278654075096, 0.03460641910455056, 0.022878794564998577, 0.030633342119732072, 0.06817398752485003, 0.014058613700659146, 0.046172601503453085, 0.05556883569806814, 0.033279350493103266, 0.09247759197439466, 0.01953887556945639, 0.010225345463758069, 0.006582787127367088, 0.03415844689256378, 0.026978861074894667, 0.014453684778085776, 0.01576105721427926, 0.027214755470465337, 0.05614449462986418, 0.05007852387747594, 0.06326738545405013, 0.04034764638968876, 0.06058939772525004, 0.03576108553845968, 0.05025330771292959, 0.029892622759299617, 0.034446311981550286, 0.07120584483657565, 0.008550363958680203, 0.06809542674039092, 0.0501513374703271, 0.015610037371516228, 0.08431964686938695, 0.06094592038009848, 0.029506261527006115, 0.035323566158435175, 0.04113068597923432, 0.03657347855291196, 0.019450177471818667, 0.040494935986186774, 0.029901138373783658, 0.03739805127094899, 0.03222531419513481, 0.02080841628568513, 0.13796417761061872, 0.030750620112355267, 0.03290959979806628, 0.018332352096747075, 0.02201535366475582, 0.024774455166022693, 0.039364082738757133, 0.036641175991722515, 0.062432597391307354, 0.04233558096789888, 0.03929680259898305, 0.015024081670812197, 0.035693357565573285, 0.018902613282469765, 0.054864272076104365, 0.07523896877786942, 0.036484777062599144, 0.03302915766835213, 0.03384713841868298, 0.023349638496126448, 0.018928141466208866, 0.058949039317667484, 0.04599918830873711, 0.08153799256043774, 0.004256785198646996, 0.03778393413605435, 0.02095347859098443, 0.047207638820899386, 0.023306615983269045, 0.06040184386074543, 0.08819595458252089, 0.09758223806108747, 0.04141445950205837, 0.03455369693360158, 0.06291154133422033, 0.07552901535694088, 0.030637990084609816, 0.02842196256720594, 0.024301366980320642, 0.014844353011410152, 0.05729050295693534, 0.032456698029169014, 0.03022872151008674, 0.0930459193353142, 0.07055339270404407, 0.017744630508657013, 0.01654668541492096, 0.03625806833484343, 0.05178056451092873, 0.00539727958052286, 0.022093515809891478, 0.0484731507354549, 0.04769362256463085, 0.018162669148296118, 0.027827796592776264, 0.033768944043133936, 0.01687314727210573, 0.036496661603450775, 0.05507925911141293, 0.009438109983290945, 0.010141118911893239, 0.04340380882578237, 0.0544380299480898, 0.04534700080486281, 0.04474738619423338, 0.06602661418063299, 0.02289256882587714, 0.11705634237400123, 0.08471608773938247, 0.03103116380849055, 0.017074477093826448, 0.012049462180584669, 0.05243831939463105, 0.024670975183003714, 0.014097480186527329, 0.02023961055757744, 0.034977343665169816, 0.06786177320671932, 0.01317731969590698, 0.04195386091513293, 0.03260762796604207, 0.014114428294955619, 0.03588717430830002, 0.028028800717688034, 0.02407628164759704, 0.028954290252711092, 0.04320502520671912, 0.02969258724312697, 0.009302782959171703, 0.04194871083434139, 0.03244926128536463, 0.05849160493484565, 0.05624464300594159, 0.06178828089364937, 0.03091896804315703, 0.03421990180920277, 0.03956516659153359, 0.04250206971274955, 0.011637799225614538, 0.05653117138094135, 0.03631976752408913, 0.02827837098655956, 0.037051937343286614, 0.022763000867728676, 0.04687296499365142, 0.08044018396841628, 0.02890516092468585, 0.021013975076909577, 0.04735908444438662, 0.023891621734946966, 0.04521318691383515, 0.07027788034507207, 0.03774897940456867, 0.019591205886432102, 0.02744754047931305, 0.018252181487956216, 0.012208671941022788, 0.053512423365776024, 0.027656161159809147, 0.03757147464369025, 0.07741144791777645, 0.04879790098805513, 0.030223286444587365, 0.004103235692517566, 0.10092450478779418, 0.0642422435006925, 0.02921460342726537, 0.021078296804002354, 0.007351469764086817, 0.036405914330056736, 0.08962499682924577, 0.024025528924539685, 0.03240842365526727, 0.054746210375534635, 0.02905260319156306, 0.025995609550071613, 0.03198979469016194, 0.020341831858136823, 0.031277994492224286, 0.011034831803824221, 0.027936876186036637, 0.010694727151920753, 0.050090622156858444, 0.026405251318854944, 0.04988036111795476, 0.012076048030784088, 0.02765486346158598, 0.010574129426718822, 0.03887636533805302, 0.027494941239378283, 0.07605578923331839, 0.0941753883713058, 0.03200988611206412, 0.07389908603259496, 0.017422833579725454, 0.010139683810328799, 0.0255585227361215, 0.0334170897092138, 0.03658966161310673, 0.05029571954427021, 0.04506278284160154, 0.031770190224051476, 0.053377866478902955, 0.021799438732809255, 0.07434043235012464, 0.013318963881049837, 0.03205507654430611, 0.05770046702985253, 0.05369713756122759, 0.05477849167904683, 0.011459132473516678, 0.06254952254572085, 0.013958365240666484, 0.09426243762884821, 0.06696340641272919, 0.06906928734055587, 0.08896492474845477, 0.008707885863259435, 0.019735854285370027, 0.024082673447472707, 0.022481154384357587, 0.031147020270249674, 0.04279528505035809, 0.025091115584863082, 0.005444063721889896, 0.047725181228348186, 0.029904259634869437, 0.02715568899709199, 0.0372075220303876, 0.0019971577774932875, 0.03232709105525698, 0.022470654054944004, 0.039545339798288684, 0.016965680788936358, 0.019354483678138683, 0.0263835856957095, 0.04230120638385415, 0.016959368716925383, 0.008531576172182602, 0.06792038506163017, 0.03884072189352342, 0.013231301397484328, 0.011448185159159558, 0.05863791065556662, 0.01358798605256847, 0.04384036468608039, 0.0037198137891079697, 0.04204541903787425, 0.032388135458209684, 0.057349318372351785, 0.033866259535508494, 0.03723049383344395, 0.05064979608037642, 0.04165743949956127, 0.038655390231204886, 0.030639645710055317, 0.022157691651955247, 0.043859889531241994, 0.013204623096888619, 0.04937362777335303, 0.0179377178262387, 0.0883485706789153, 0.07407950849405356, 0.12896311203283922, 0.12347651858414922, 0.06967971779938255, 0.11071834353996174, 0.11467382950442177, 0.12475079377847058, 0.08441957472158329, 0.1277820404086794, 0.11869182890014988, 0.12337602754788739, 0.15357185368027004, 0.11884407858763422, 0.07444984612188169, 0.2018250844308308, 0.10274610668420792, 0.14501148302640232, 0.10017985331692866, 0.1523244349019868, 0.19673706245209488, 0.11952797403292996, 0.2517173843724387, 0.15365861116775445, 0.10873548779636621, 0.12094645148941449, 0.09354887663253716, 0.15036376725350106, 0.09343505238315888, 0.12009963978614126, 0.1332677517618452, 0.18994342056768282, 0.18579058269304888, 0.10663764072316033, 0.168257794209889, 0.17520133805062088, 0.09401345598910536, 0.1348108218184539, 0.10891959470297609, 0.08804908567773444, 0.2007178102752992, 0.0696489190948861, 0.15078217908740044, 0.08523564200316157, 0.11637814662286214, 0.2002300385917936, 0.18074543055679115, 0.11503162101975509, 0.11248444127185003, 0.137531380834324, 0.09452798230839626, 0.1717878319323063, 0.08988085202872753, 0.12221840609397207, 0.17653886627938065, 0.23950087704828807, 0.06515230823840414, 0.15532626025378704, 0.12585869218621934, 0.14726136944123677, 0.22503144347241946, 0.12248520606330462, 0.14790167579693453, 0.13221731169947556, 0.13309585170022079, 0.11285559992705073, 0.1623564665871007, 0.1715124145682369, 0.18272323799984796, 0.14114619472197124, 0.12185616338891642, 0.24669937363692693, 0.13938551848488195, 0.15463145396539144, 0.1043767077582223, 0.12389001782451357, 0.11966153686600071, 0.11014561927212135, 0.07650803960859776, 0.2422317090843405, 0.11013080685266427, 0.19290650156991823, 0.1076578316943986, 0.09670048180435385, 0.07790855624313865, 0.1653997911406415, 0.17894124665430614, 0.11745912076107093, 0.13420718349516392, 0.10232480429112911, 0.12232322618365288, 0.17858249161924633, 0.12124522402882576, 0.190586726048163, 0.0901463899229254, 0.09001325456691639, 0.23764592515570776, 0.07893691677600145, 0.08637648328606572, 0.09515771030315331, 0.14994497543999127, 0.08945762259619576, 0.10526043176651001, 0.22010445142430918, 0.09491215526525464, 0.1355249120720795, 0.1448636031044381, 0.1607353107205459, 0.18334484393043177, 0.20418470352888107, 0.08391475823840924, 0.15503172177289212, 0.10286229223545108, 0.16403212238635334, 0.15840627998113632, 0.1842128530676876, 0.162669284801398, 0.14746453639652046, 0.09612863284668752, 0.1364259658647435, 0.1411802978920085, 0.11271487854953323, 0.07099207916430064, 0.11212613406990256, 0.2019329714987959, 0.08466044108250312, 0.1989062303411109, 0.1425221280327865, 0.10088940417127949, 0.12661842070519924, 0.18004610522517137, 0.338972346591098, 0.22181703309927667, 0.19789411393659456, 0.14558784424194268, 0.15233337799353258, 0.16583015876156942, 0.16360950363533838, 0.1264940316655806, 0.15818530826696328, 0.13784533898745263, 0.0708262248496924, 0.16775670966931752, 0.07499603967049293, 0.11495386090661798, 0.12589268679065363, 0.1488187023039375, 0.10678526958716766, 0.0984089719131589, 0.17116318616483892, 0.08552813130830016, 0.11457206282232489, 0.1263338431183781, 0.08588459289499692, 0.1408985565815653, 0.1160014918340104, 0.12238840625754424, 0.07155253551900387, 0.13464916763561113, 0.12382240859525544, 0.2141237080629383, 0.12343349946396691, 0.19136208801397256, 0.15838318264910153, 0.10790521199149744, 0.21846972485738142, 0.10290905686893634, 0.09888275220457997, 0.09238304490489618, 0.09499283986432211, 0.07826300936618022, 0.11768438081656184, 0.10902757676584379, 0.10051042200731379, 0.2187456036252635, 0.12913783480014118], [0.022106826970619813, 0.040026203995304446, 0.05417683128533619, 0.010153100992153798, 0.015686737273686698, 0.013172412191384604, 0.02372281748934516, 0.019534814537369778, 0.028418089828587005, 0.06113816970693214, 0.07940511272421905, 0.037849389016628265, 0.009175404124627156, 0.043344389514199326, 0.02469428625356938, 0.03387808979355863, 0.008257415794235255, 0.04634769407234021, 0.01969670451113156, 0.06791845802217722, 0.006546688640290605, 0.0180722865874746, 0.05136321797700865, 0.016896241211465428, 0.036048818313117535, 0.04602018557488918, 0.09035394699977976, 0.04721497717712607, 0.040169032224054844, 0.01408499090134033, 0.03785330755636096, 0.059540219738015106, 0.06819002809269087, 0.016901347187480757, 0.06243024966014283, 0.0363821859604546, 0.02648267216448273, 0.033429140491144996, 0.02061351727960365, 0.019217341572844555, 0.1344960087112018, 0.039304405583867004, 0.0165866782689201, 0.012261565442063978, 0.0321237578588937, 0.04241517312558634, 0.07842987469796624, 0.050572134354817014, 0.030277592994804894, 0.06873649984065976, 0.06686581950634718, 0.021238724534798945, 0.01895346100042973, 0.06179341061839035, 0.01790577918291092, 0.02507680358498224, 0.06593702041677066, 0.0315428606367537, 0.08060978379632745, 0.03916128897773368, 0.04522346332669258, 0.017674953443929553, 0.03885957159634147, 0.03216045303270221, 0.013164164598232933, 0.012238583460982357, 0.04000667575746775, 0.029510580402399813, 0.01769588455291731, 0.026103491529024074, 0.05676180204110486, 0.067620961128601, 0.016306365274691155, 0.04513660745163049, 0.025957333389669657, 0.015023788204416633, 0.020607822674459646, 0.03236521115260465, 0.03227156653468098, 0.03694728349468537, 0.029963163259838308, 0.03019496439290898, 0.02004682518807905, 0.05359639207433377, 0.031888733684484444, 0.03268960517432008, 0.041287505600069246, 0.017065501771867275, 0.023165819966899495, 0.01048343813246382, 0.030351943469473293, 0.02229609583238406, 0.05011271186439054, 0.026537996517228227, 0.06738411169499159, 0.015304778037326676, 0.04276260341118489, 0.007949426204764416, 0.0677961181583149, 0.0036480281768100603, 0.049824263235288005, 0.028102270793169737, 0.07823455839284829, 0.005295398395641574, 0.02318537873881204, 0.06284031551331282, 0.0534340186443712, 0.029864433021949868, 0.05298099473917058, 0.049567410589328835, 0.008283887141650277, 0.007700408093764314, 0.05638221937364765, 0.07366284049515213, 0.01793743284153087, 0.03057399405432599, 0.07408269760864121, 0.0839978652074933, 0.018263392582801834, 0.015409820347226091, 0.03233232595292585, 0.058344220343445025, 0.01275386380231274, 0.028113040840253234, 0.04347136716491409, 0.03406721107395632, 0.06479250825941563, 0.04667508721883808, 0.015926580743065903, 0.03117460271875773, 0.05130477575585246, 0.02779695887251624, 0.03966515551188162, 0.06313706601836852, 0.026633770038772906, 0.018982702467058386, 0.009274282792050923, 0.011217502760700881, 0.05766074558986085, 0.03859231022319623, 0.02211700499589954, 0.0021288593041910125, 0.0464064382415797, 0.036777476713593514, 0.013321441382036676, 0.043409712080444605, 0.028824934336755956, 0.03253737245021122, 0.045128003627594025, 0.03183500049635768, 0.0453503154484289, 0.028378073225862215, 0.01544534504812743, 0.026428160357422063, 0.032369937149009535, 0.03669306356459856, 0.038212557921984365, 0.04141411344919886, 0.017867397849581072, 0.023808860818722417, 0.06915068440139294, 0.025228851408298527, 0.010990196922128754, 0.040325370085026534, 0.009713834384456277, 0.08765724527516536, 0.03236390497269375, 0.06349777523428202, 0.05823621113917657, 0.059993236857865534, 0.05172480928844639, 0.06452633932765041, 0.02183272935716169, 0.06699059531092644, 0.028151398424857428, 0.027137867274827192, 0.02986069768667221, 0.07016161336962666, 0.018233236790235554, 0.09828854551804916, 0.03801058179565838, 0.030456556605973413, 0.028467027470469475, 0.015156340020309602, 0.020333626673423817, 0.04935781451474343, 0.06849275649126087, 0.039247870046113215, 0.0361283561880035, 0.026884093481515135, 0.07330856379121542, 0.016810669463926127, 0.037053229952497144, 0.04496745884950672, 0.034378492406436374, 0.01846335346012243, 0.02346475705105279, 0.03090871198635016, 0.02394188421645335, 0.012723149066524846, 0.06946284443672214, 0.04262209916487336, 0.03169449625004615, 0.011496987942207073, 0.03649349623758878, 0.009986831923015416, 0.02968059413667236, 0.053994614098753245, 0.08106934199375765, 0.041060634023909054, 0.08180055168590375, 0.018695013797176734, 0.010350080556236207, 0.07516353603984628, 0.04893122972654445, 0.03451471848945532, 0.05804514924862555, 0.06110517254897526, 0.03468438617086836, 0.018861512720052685, 0.0397452430001327, 0.008864059179489101, 0.04554712792326297, 0.023699158669582436, 0.03777875352118697, 0.042377297300845385, 0.020483881467953324, 0.02798563231980162, 0.034823733514973094, 0.04268610876585756, 0.06367776343332869, 0.02199873634214912, 0.05498023710346647, 0.016808913754565374, 0.05819821317813226, 0.04389319881530745, 0.03659465902351907, 0.027393971835928302, 0.009031268867797084, 0.022843071392604282, 0.013553608075848647, 0.033514934458902905, 0.04876553826034069, 0.016239985890154327, 0.017010021356067488, 0.016874962353280613, 0.04985511622258595, 0.04291109062199082, 0.024616751753325974, 0.053086418725017986, 0.04250131653887885, 0.018943623938996876, 0.014676727720403245, 0.02721503366982298, 0.04047962823616607, 0.020468117403132573, 0.03878797258117369, 0.00784270536886262, 0.027598819861720716, 0.022706221057368175, 0.014577357963259732, 0.018947340614561523, 0.0625594359423433, 0.06837530207953282, 0.022454348858445883, 0.024291830170633535, 0.04646878543176821, 0.01621545006388, 0.00422132495857243, 0.028642768040299416, 0.07952663834605898, 0.020243121976298944, 0.007070002836241786, 0.04128574140902076, 0.016339625364967754, 0.014075246290303767, 0.049769186547824314, 0.028955989982932806, 0.02172914589755237, 0.0069551684178545, 0.03726684634706803, 0.029712224046566656, 0.05126954961035933, 0.024412819749808738, 0.044759426798139296, 0.03160491944955928, 0.02863803186586925, 0.029963546632123843, 0.014423393278515764, 0.043701644986867905, 0.00824457367083856, 0.0359900503951524, 0.01981344137207738, 0.056641925259360244, 0.030118429035480534, 0.03479212396112936, 0.04377237208453672, 0.028298806764983704, 0.04726939229294658, 0.03421593237934368, 0.06975345419985907, 0.04369073753644313, 0.07204294670373201, 0.020846019000081078, 0.07004773483744689, 0.025762003513851335, 0.030107151783470596, 0.03497269570029207, 0.07370445504784584, 0.03825611308483141, 0.016123747752447213, 0.031235698011836836, 0.037706815238509855, 0.069501771990742, 0.057479821012488434, 0.035520460057471476, 0.020511823540021266, 0.018017277753512775, 0.03947047024433102, 0.08457098981099469, 0.027027393292103494, 0.039821330524448834, 0.043576974355216534, 0.031090878282806704, 0.05065755173563957, 0.09053427446633577, 0.0727817424173866, 0.06366602477750608, 0.035360027237662246, 0.042464774035449536, 0.03046779314588223, 0.04531709098124078, 0.026247247654412473, 0.05148571390392525, 0.010719976288133433, 0.0016618288458890415, 0.05913961944835527, 0.010071111909512962, 0.01676266311135675, 0.02537804768819894, 0.055040535117898665, 0.020737064935799156, 0.015398882362725479, 0.07420760233487401, 0.017668858503124545, 0.024181128878678595, 0.018610833046425666, 0.03518848679959774, 0.05816875118762255, 0.030614075117877552, 0.027847606422645704, 0.03207840457824724, 0.06653103032814604, 0.14671612584165164, 0.18900837217058453, 0.13727066053875855, 0.1324292996100017, 0.12844560694481644, 0.12869578280619212, 0.08699611467974526, 0.10282422642090491, 0.10896645433136395, 0.16129987899746212, 0.19054091136370385, 0.13992181899292128, 0.19319063132362707, 0.14703271671065263, 0.08399632493300097, 0.1196458355656692, 0.15080093379531587, 0.09219344864998545, 0.11539556006235735, 0.1198105431560959, 0.0851459125322955, 0.09699791762977839, 0.07958683797291347, 0.11647643920566354, 0.08153210966182606, 0.17428387728120598, 0.12633425023938927, 0.16016568057239056, 0.08448301096047674, 0.15038761097405637, 0.16788356857640402, 0.14519452463303292, 0.10561916644551925, 0.15553577829684528, 0.10481300577521324, 0.07038508209266833, 0.15951978308813913, 0.11714447050222329, 0.13742563793701784, 0.2746416356946741, 0.12324782514146396, 0.09681298291044575, 0.07452405071152107, 0.1181352266243526, 0.1135358177125454, 0.1469282087470804, 0.15238596445747785, 0.15276542838130677, 0.16192263843757765, 0.08413455608700003, 0.16052162647247314, 0.16313608975282737, 0.10411999081926686, 0.1140899501208748, 0.18752379183258328, 0.11148508132568427, 0.1393163079129798, 0.16399029748780386, 0.16999268611626966, 0.10117207507469825, 0.13097910742674554, 0.08755598749433245, 0.09553153560097728, 0.1334357163203614, 0.1091780826183302, 0.13509007969072886, 0.07995740630264793, 0.11582682334950992, 0.1361206386770521, 0.16147342111383164, 0.12630018778145313, 0.09272285524223532, 0.2027534967554467, 0.13759905791708402, 0.0895130792632699, 0.06257729498403412, 0.14559608165706905, 0.13229969942143985, 0.11048193515411445, 0.19713959656655788, 0.17719353043607303, 0.07573174126446247, 0.10388215072453022, 0.15240573696792126, 0.0756696756663067, 0.13454537891915866, 0.12357542184846741, 0.1257896851748228, 0.05447730016229408, 0.09763791864471776, 0.10161013049738747, 0.1279667512114559, 0.11781001836061478, 0.18322073987552098, 0.10475050591464553, 0.14638037314372404, 0.08001562460724797, 0.17371495280947002, 0.07751567768199102, 0.119071917076196, 0.08853671486888613, 0.1970421996499811, 0.17594034411013126, 0.11021810716816358, 0.1922437357051032, 0.10047318400549037, 0.09750449830400092, 0.09166822183345046, 0.10146833703454052, 0.12108237562435013, 0.1239322227026735, 0.05111257053379502, 0.21631781889923982, 0.1259618295090539, 0.11281649595392601, 0.171005711757711, 0.1412822138518095, 0.10323851954724107, 0.20827572686331614, 0.14577464493257658, 0.10978188379002468, 0.18320043810776301, 0.08166394901594945, 0.14650663493999413, 0.18529975760195935, 0.19334497089896882, 0.12598276909972939, 0.12813842057117394, 0.16413733602634498, 0.16438529986355985, 0.06147325065519128, 0.14065448753535748, 0.08171649476779358, 0.10651891066559724, 0.08120544933314834, 0.14716161122279509, 0.12543383426964283, 0.10322885042322533, 0.20164915387119564, 0.08924673391239983, 0.12751735746860504, 0.11965249877955232, 0.10221196391752788, 0.15505898530994142, 0.10119077549981219, 0.15763136584843906, 0.08099977858364582, 0.11519394016691617, 0.14700660668313503, 0.15187578754765646, 0.07741617730685643, 0.07483538971947772, 0.16733187889414175, 0.13379493275923388, 0.15500163553016527, 0.09789659654987709, 0.1126945564257247, 0.11227157805114985, 0.1310689861753157, 0.12853805055575712, 0.11398772203496524, 0.09021047755543675, 0.13178208576781408, 0.12520325449960573, 0.12456615082919598, 0.12972372264734336, 0.15271680456187042, 0.14675064970340046, 0.16831057066363947, 0.15037055260368756, 0.15167825243302754, 0.09896007126995496, 0.1783284888203655, 0.16251573232667788, 0.14036967924663], [0.014680759914751564, 0.026991144255069748, 0.03493434150836297, 0.05921595463795321, 0.04566778162760394, 0.020712033778961216, 0.01021213099426989, 0.04606548457273415, 0.06387553603521415, 0.03596548403480223, 0.02567371423356235, 0.07910133938172034, 0.05620803264901042, 0.027761486758078848, 0.024448240974119732, 0.05660024285316467, 0.005332079998749707, 0.08453234724168267, 0.028827787576509372, 0.013874583977407642, 0.041773899857486994, 0.01645477954298258, 0.04973973812801497, 0.038876151599522145, 0.025312933771471893, 0.03368207799004657, 0.043890895188919136, 0.09030437323131732, 0.03143097360485366, 0.022064871454079236, 0.0029240266469839427, 0.018268010013603737, 0.04047285645667996, 0.08323293911027056, 0.014822704351640173, 0.09860196084316288, 0.01261477090884, 0.06969240640423127, 0.04990941598745329, 0.05676185632390635, 0.07693122154367821, 0.0370465226338378, 0.032943156747413535, 0.0865101818261402, 0.016964573080518415, 0.03813616844958492, 0.04234163350026522, 0.04124965352405395, 0.036868413976792774, 0.009093810288634683, 0.03675771777385047, 0.026330247754231095, 0.014118460489303937, 0.0711030060691493, 0.019312385669244186, 0.06947868144405739, 0.04161065111735037, 0.015793757513165474, 0.028849415880228792, 0.016617555004943694, 0.044194587107215605, 0.03373363986611366, 0.03533340152353048, 0.008535494711915297, 0.08926411119422742, 0.025618439074605703, 0.015981336822733283, 0.003421136880725888, 0.011559909342655113, 0.019199575829718794, 0.036524237266608646, 0.040344436919050555, 0.008547660844799663, 0.04357139340468815, 0.018677991049896394, 0.031589584558137825, 0.033650129168693504, 0.01075759596590485, 0.03293385403230786, 0.008809886639937758, 0.03017986359606896, 0.05710084563387292, 0.04061843953760607, 0.04823796031996608, 0.03985011058726481, 0.01747407315165869, 0.03702776114057217, 0.042594845805849345, 0.0196681687209223, 0.0141857762521665, 0.02517348464711436, 0.042842670543385405, 0.04740657850301691, 0.06271714783672776, 0.03805677306705287, 0.061373431368597915, 0.02286974460418735, 0.04945639208225267, 0.03853860417647021, 0.038672468957624266, 0.04093931196257472, 0.03806699180443372, 0.03160802713994469, 0.013375602047225195, 0.04630183528310486, 0.0061852987689365235, 0.012196660174855163, 0.016180541133508086, 0.08458968345075846, 0.036363797661449225, 0.04601278275783573, 0.07446691127760069, 0.011951480875723064, 0.05450773924323065, 0.0040514558370757315, 0.022317752973841767, 0.06250866795224802, 0.039913621465010304, 0.0677094692364335, 0.03315545678404825, 0.025065775694591657, 0.03032669857410448, 0.0359783015613045, 0.06336242785411221, 0.04509886733389326, 0.03341741540602275, 0.03664722513141377, 0.03250623447820544, 0.004528508787708623, 0.05231417802029422, 0.015090827464259096, 0.038619146283183775, 0.009417648759803601, 0.014203881262801588, 0.06344073758061443, 0.02288640772790781, 0.07521183416247368, 0.0262641024642757, 0.03607505726228867, 0.02062165630715234, 0.009381588864406305, 0.03941059631428548, 0.023517669211806994, 0.034570399073085616, 0.06886523150439773, 0.04442403372377157, 0.047796305269002914, 0.04873637482523918, 0.04113742722464459, 0.036673613358289, 0.052177432857986004, 0.07552876429898397, 0.046385271341672966, 0.026597197001267756, 0.03846304590946861, 0.008778213473436023, 0.021800853478323137, 0.03863485436886549, 0.010490582258041416, 0.06042348912784031, 0.03649802206616316, 0.017125609796494246, 0.005709653778467327, 0.039243211903210194, 0.011262531192707164, 0.07868709375283547, 0.06566469717238631, 0.06274697623614754, 0.04249386961704918, 0.024632765179766074, 0.024374144950083325, 0.026742839454008, 0.037913853236074956, 0.014571848258908306, 0.02960403842319335, 0.03143523819744587, 0.002495024577781026, 0.039152315352112055, 0.01551611116155982, 0.007857385473991079, 0.09047668719930307, 0.02507301905591573, 0.03126019312601004, 0.03807586704247764, 0.008975451728994293, 0.030762837135366032, 0.026469081108059202, 0.017690174680735384, 0.043374163630817614, 0.05826143907116992, 0.01920064282603562, 0.07859155602220978, 0.05279814312234521, 0.016094112735507742, 0.02192861822965954, 0.007664528010146958, 0.040672152369682274, 0.01710978296718427, 0.03642895398661494, 0.0640874696629388, 0.03891220895041313, 0.06256485065179211, 0.020417084784380028, 0.03699147987312504, 0.03982137462922505, 0.04763848141634038, 0.03949450056201645, 0.011211320458512222, 0.049000382622970004, 0.03622820261599762, 0.06135377420910767, 0.04861421138048172, 0.018043781331341182, 0.06385340900825602, 0.010761830024421215, 0.019446786493062973, 0.0610945602612836, 0.0520876728530441, 0.07817334774881601, 0.019075217324176004, 0.0028797499045530067, 0.017056134595934833, 0.05622859565275056, 0.0991217050967472, 0.019605974201112986, 0.015731447642402988, 0.015191464385549937, 0.04691830470359751, 0.06199625187686511, 0.08425899262406997, 0.02587172093002924, 0.032961297381137095, 0.007462920837237367, 0.0322272276638874, 0.010554665649708892, 0.035878319426306655, 0.12969390781862394, 0.028489680362067053, 0.02566795177491648, 0.007621106009797326, 0.025410235693146075, 0.09240248493318047, 0.08952359655605895, 0.013774495821313133, 0.029450662367578064, 0.1634641071515424, 0.04547433129378727, 0.004186695923895708, 0.03650765387075288, 0.028504818478333097, 0.0869129602132099, 0.011060478731191583, 0.061247040650674274, 0.032325971472476206, 0.018391723910878812, 0.01653891958163253, 0.011958010078940009, 0.03651373693719506, 0.02095782121510378, 0.02829521561839751, 0.04106608944545899, 0.07430915188576494, 0.006735362935744758, 0.007575538990619991, 0.036327842090811045, 0.009492480994335242, 0.04309827807758536, 0.0572570376098156, 0.023907095726047243, 0.054359204534973414, 0.047717021844748936, 0.012001345566074764, 0.014792214380577207, 0.04731871161077704, 0.03940307814627886, 0.045808659068175724, 0.06967073399573565, 0.05510649211438639, 0.03706204072971429, 0.035868850470121415, 0.06787708095674004, 0.020208418302770172, 0.025403713275279318, 0.03849445868815694, 0.01775749383627304, 0.019106592783438306, 0.00934843479522637, 0.030757205294711248, 0.10823795199394226, 0.04178418305569461, 0.03877550110753093, 0.010731854891803647, 0.03284580393561295, 0.02069473622499832, 0.016422309946002703, 0.051582099803324254, 0.021231691519330655, 0.023401051094489436, 0.04746168911723154, 0.041303647948162894, 0.004965495093659098, 0.05050284914406283, 0.021931310317346027, 0.08100328660969223, 0.03024071461654135, 0.04949165215449674, 0.09715328179299831, 0.06001432572624513, 0.015189342267279114, 0.011313827591948211, 0.06998469214886427, 0.01919503982311913, 0.05461452029911535, 0.04341564586918269, 0.010589332851980413, 0.012686005211435258, 0.07494834544403212, 0.06010815354862383, 0.03978348523378372, 0.056122075832848034, 0.04672088154724666, 0.03280665585771203, 0.008197050774469972, 0.0493581809236535, 0.06457592666681324, 0.045470375434628556, 0.053657260058181624, 0.028616396776799644, 0.019616762907909494, 0.03305258408987096, 0.06352781397955758, 0.003863659396301955, 0.022146887678120817, 0.049518505177859745, 0.04006321129522153, 0.09442538781357662, 0.028731452567236762, 0.013495916484056838, 0.02045290295167693, 0.01942779599422855, 0.020463354087301662, 0.010314231006694692, 0.043209333904087543, 0.09109882238720145, 0.0198542959655502, 0.03500769453655396, 0.07317645302308456, 0.04056402102911046, 0.017802285629191568, 0.027520908774541955, 0.020364718844315836, 0.030870144055890184, 0.0852331178528922, 0.08697966020554304, 0.10914220847189426, 0.11856197086828095, 0.19360254279204778, 0.09222636438374009, 0.11491362378001213, 0.1416464921619211, 0.16712850837835244, 0.15616689728839056, 0.11372082028537989, 0.16472407882767065, 0.1653426042092698, 0.12688288651406765, 0.14225924999586173, 0.20162195818764822, 0.08916855989290134, 0.24527569860219955, 0.11942881292530469, 0.10084080070789371, 0.13261990009674005, 0.06549044937959739, 0.09923983804349389, 0.1726361092712198, 0.19360802535499844, 0.2628049722739628, 0.15239087705101284, 0.13945665609623703, 0.1494536210915872, 0.11646612547338009, 0.13925490049379213, 0.057073867081531456, 0.14537192082830838, 0.14042241498827934, 0.14265539231044905, 0.14684635028243065, 0.1364443405930485, 0.2536165496068341, 0.11672814855618135, 0.1074191637869392, 0.23288651768650326, 0.07719857112637588, 0.1489564584834235, 0.16266620425241335, 0.12214198948017188, 0.12851183196263655, 0.16941458785108157, 0.19158000632056169, 0.1575273871421814, 0.13140301539429597, 0.09898317538733993, 0.11964595770197255, 0.11108599416911602, 0.22068415103214128, 0.09950597304850817, 0.24197031025375637, 0.09847206209919282, 0.1441337979797806, 0.12638562891100133, 0.09581044742039271, 0.1648556196263858, 0.09193534071424178, 0.16077835698212894, 0.12371971910553319, 0.13085076931331838, 0.19572543459279196, 0.18255987390875816, 0.16583516635000706, 0.08657749249999012, 0.24683939612337522, 0.11370265590293066, 0.05752549998994384, 0.12308431177267007, 0.11890582527433123, 0.15959942952862807, 0.15284540051860468, 0.1321119623524802, 0.10691604364131178, 0.1553805430552789, 0.049863547020192654, 0.08615912816354207, 0.24849453302366392, 0.12830890927995953, 0.11462983329381261, 0.1381699229989733, 0.16180690750479698, 0.23213410377502441, 0.11505298130214214, 0.10691366876874651, 0.08824109073196139, 0.07771294816796269, 0.16808829616223062, 0.15058099345437118, 0.15782394765743188, 0.07574164109038455, 0.1576638269637312, 0.09623860980251006, 0.111817054583558, 0.21115608087607793, 0.268728854400771, 0.1369889463697161, 0.11389377207628318, 0.10791554607983146, 0.13630549875753267, 0.23383505535977228, 0.05721543662782226, 0.10732387032892023, 0.1259318654026304, 0.1238717788032123, 0.11131922701107604, 0.13468575424381665, 0.14127400357808384, 0.1793243068137339, 0.11185762419232301, 0.13022572999554022, 0.04814045823046139, 0.16508799072887215, 0.14715132463191236, 0.16970941131668432, 0.23726011014410428, 0.102121732330748, 0.06173090397247246, 0.2909303573625428, 0.14395360622022832, 0.14750876330903598, 0.17129483552915709, 0.10629171678530318, 0.12326453067362309, 0.16066619514354638, 0.1257210717137371, 0.17661749491734163, 0.1086263522239668, 0.08790900890848466, 0.09824599458702973, 0.1273126434534788, 0.07287012838891574, 0.22537407651543617, 0.12281574761228901, 0.08335028495639563, 0.05749542731791735, 0.12313503905066422, 0.12638124557478086, 0.14678902764405521, 0.14678103450153554, 0.19274966498570784, 0.18206383766872541, 0.10336955823004246, 0.13640622049570084, 0.11901547653334481, 0.10225589227463518, 0.1712658620838608, 0.19021635449358396, 0.1488727136914219, 0.09679321718535253, 0.09379909320601396, 0.07898431244705405, 0.12573452027780668, 0.1297286759529795, 0.06973351884101119, 0.1796248706855944, 0.13280307741037436, 0.07104284036904573, 0.08895273147416966, 0.1362911138151373, 0.12677770001547678, 0.1696443533790963, 0.1747177732842309, 0.2459416671523026, 0.24714530685118266, 0.10610305690871817, 0.19307232195777552, 0.08343113918921777, 0.11628293458904539, 0.14106373914650508, 0.1428288665733167, 0.09975493433220045], [0.02652290420207594, 0.07196610939822026, 0.0403733832229461, 0.0476100066942828, 0.03346480768440025, 0.019480009263913547, 0.0278680405047323, 0.018248320623700107, 0.027070938276925256, 0.08262948399143559, 0.033169549956385574, 0.029502180138868943, 0.06098490221691983, 0.054898175078311136, 0.02160553208419255, 0.00935562132924263, 0.022280866113890494, 0.05267767940780946, 0.045658926745610576, 0.02368496880600495, 0.01970056876806276, 0.05337149164240275, 0.05643386606659208, 0.010669606937361615, 0.002323293301742524, 0.02821870061701962, 0.05497784526752574, 0.020284895984722034, 0.010330416611395776, 0.016027543361165693, 0.026974684691854885, 0.023309788134481226, 0.06352805825216429, 0.06940577964165381, 0.04550859731222902, 0.026082344985167896, 0.03054529880838735, 0.0594454894640616, 0.09605507965066604, 0.014552479476800986, 0.04514857002400926, 0.024213869889665927, 0.04312365189460771, 0.0526340835328613, 0.008360134969864572, 0.016437008710844175, 0.04394962918013334, 0.0433224117649453, 0.021560255138735687, 0.048833456223032305, 0.051486619748175144, 0.020382002827578356, 0.021041211472558122, 0.06318900787404605, 0.07178670473928962, 0.028651670419744084, 0.0006022028506517277, 0.051841802296361754, 0.021575837695438947, 0.05006744000794632, 0.09004697097199303, 0.06816547191036598, 0.02037293590339167, 0.036939731399927817, 0.043343636340328624, 0.05608375556766987, 0.011315727490000427, 0.024508337124383876, 0.017221993999555707, 0.026298529634784375, 0.025650923938623497, 0.017444541611309563, 0.062018806380884986, 0.06111822756273406, 0.03945133216413004, 0.026695040054619312, 0.05414574420345681, 0.031658710313162634, 0.06403321400284767, 0.05155474466404744, 0.03724162520042487, 0.02496602256516261, 0.016036588232964277, 0.03789118677377701, 0.05345285138381379, 0.024434393770726662, 0.04162094110090818, 0.03598922258242965, 0.05096973891236952, 0.0346602201461792, 0.012297174111673874, 0.04034693392791918, 0.00831053830084524, 0.06308809614607266, 0.013862960672538196, 0.030056492358978306, 0.045597376834068976, 0.012482540548912116, 0.0326982836372086, 0.025153403403237462, 0.031361016644431014, 0.021819087410611764, 0.03177161514759064, 0.01293906060579632, 0.031907712308956046, 0.07187668526811258, 0.02698731392488948, 0.005492446661394621, 0.017033629285703813, 0.019548627814011912, 0.048520196960972886, 0.01581453425543649, 0.013494111580907233, 0.054426087731761594, 0.0336962186598352, 0.013333774604169386, 0.006519049364474735, 0.06727693030344588, 0.03319582961765783, 0.0336186044317271, 0.030472681990691593, 0.03628774406388402, 0.07302315839167152, 0.043105959093996456, 0.007510613367360617, 0.07232508834983621, 0.019919067222092832, 0.030936131586453745, 0.028645329509994814, 0.06220995648098843, 0.03788929705375007, 0.010026608493977358, 0.030991194703217064, 0.025258304917120507, 0.02481603409562792, 0.042741568825606785, 0.028668521836932217, 0.017969914312873567, 0.017291657493582795, 0.011336938494683375, 0.035972364379891326, 0.026306353143549392, 0.10042886888342244, 0.025000005295234065, 0.02641462697647512, 0.018745445912437778, 0.03699244000017643, 0.053448274665113, 0.048987005305077345, 0.09391549588846308, 0.051347174016492705, 0.04345677187666297, 0.02250982418523303, 0.029217412562242577, 0.05128604818933776, 0.03575515853507178, 0.04413210081734827, 0.0345219584581043, 0.08964996691793203, 0.01575379180056708, 0.11834513821772166, 0.03815148298495582, 0.003643467997400356, 0.048695635582719526, 0.048367767461708615, 0.019046625554827706, 0.07433543833238737, 0.01698894436205072, 0.021251214668154716, 0.05585334882406252, 0.048687184429062266, 0.06269577398364033, 0.06524212591882263, 0.021318299729110937, 0.03741564568398254, 0.022264028267402734, 0.035471653033580096, 0.03821765711264951, 0.026761573805872883, 0.029525840654969215, 0.05076113349891134, 0.035129155697567124, 0.07633108446108443, 0.00861408094143761, 0.040423828908907514, 0.027147482116041437, 0.017588857528088347, 0.004824827998943094, 0.09846231155097485, 0.09781232250056096, 0.059311424515077045, 0.017433861470116035, 0.01804493653721043, 0.018616641306185296, 0.048619310571146865, 0.052517127844371965, 0.040533286785440784, 0.02243500212872667, 0.04016364126333168, 0.03944630761231695, 0.0363095928914845, 0.047606461348810365, 0.05211929597758821, 0.03340511695880975, 0.043261357183967314, 0.04523985334006803, 0.03514231249157872, 0.043911509082785675, 0.015889941548396434, 0.02909233820225511, 0.013288613009665693, 0.03452867256211383, 0.06566682777234487, 0.046766434995723624, 0.03401836333796382, 0.010005070944316685, 0.04434309806674719, 0.03808118336434875, 0.05219791443752391, 0.05458465458026954, 0.026383478826444064, 0.02593670253242765, 0.03975050164652722, 0.05167540854641369, 0.021910754098956074, 0.06018784748656409, 0.03430299520758646, 0.09387970995157957, 0.015835244840543185, 0.020909553626552224, 0.03548492178586977, 0.08134847772972924, 0.026068156817927957, 0.01957969623617828, 0.04627046321651765, 0.029584408405103853, 0.07466321824384586, 0.041254895207073004, 0.02113288494625262, 0.04086485970765352, 0.019309827592223883, 0.027277874494237558, 0.07073745889855282, 0.053701113776436875, 0.0026540965107934816, 0.047476348866309435, 0.04495219859693732, 0.07380118021475417, 0.06577677080141646, 0.07308934269739048, 0.005631962367000857, 0.028700382448732853, 0.02424594932901008, 0.044418429024517536, 0.02559388628495591, 0.03189080660896642, 0.051507142039814165, 0.024106973482828056, 0.01818621431344322, 0.04282464526061501, 0.028671561673815762, 0.030118432428155626, 0.030285603100700036, 0.06819304078817368, 0.05133627335141812, 0.02605960558035544, 0.044827894374196015, 0.00740935728286526, 0.02588933569911335, 0.022754875410880362, 0.05710517468729189, 0.0035434873466978645, 0.06184872479311057, 0.03346637849296842, 0.03130841660978539, 0.03749941761738487, 0.038792305027267764, 0.028241361990304928, 0.08521156079534974, 0.020319682778790593, 0.046939793907638104, 0.013527087534644773, 0.010643403611278959, 0.01733136027386146, 0.06295934412628412, 0.013417618631917452, 0.0856024037514414, 0.03841704462787934, 0.015721208548971584, 0.0558135459598686, 0.017502490198239684, 0.0652189946600369, 0.022973823394360285, 0.06285514150347028, 0.03713345654042704, 0.03850240094055023, 0.04108206555247307, 0.04580423501985414, 0.0775893394436155, 0.03240053229300039, 0.02280743303708732, 0.047618491774691005, 0.03119453468493053, 0.01949442982939737, 0.025487768497051935, 0.026016820554754565, 0.01392013403320951, 0.06705794669687748, 0.02476919482329062, 0.016596824063786438, 0.06711712173585381, 0.07516209754560675, 0.030926180870405266, 0.06259328126907349, 0.023324955088485564, 0.02000181287127946, 0.0819013819896749, 0.031260386508490355, 0.019369431804599505, 0.0058987385876077625, 0.03928643797657319, 0.016710695810616016, 0.050959720342819176, 0.031148886241550957, 0.11418657350753035, 0.04654756334743329, 0.03623274201527238, 0.030337426212749312, 0.007014280268257218, 0.06605022041393177, 0.08512177704168217, 0.021286537504888008, 0.04036681500396558, 0.02008926585715796, 0.011321718106046319, 0.017640080136646117, 0.09080082337771143, 0.04080132508118238, 0.011360904351542038, 0.07244541975004332, 0.07964882893221718, 0.013452128074797136, 0.05485244521072932, 0.05790767126849719, 0.018384112444307123, 0.03706977602892688, 0.02214081139702882, 0.077503341915352, 0.04064830864912697, 0.05582272314599582, 0.02733443208437945, 0.11823704758925097, 0.14383125278566564, 0.08729830703565053, 0.10891187297446386, 0.11292656790465117, 0.10794481808053595, 0.0730167937331966, 0.21586747520736285, 0.0816763254946896, 0.1300625151821545, 0.15518230226423058, 0.08063950363014426, 0.177426797204784, 0.1625343513275896, 0.20259110975478375, 0.12820635549724102, 0.1268590563642127, 0.1208349410444498, 0.1213433537632227, 0.097728163802198, 0.11903401411005429, 0.16887299476989678, 0.22559176412011894, 0.07982541767082044, 0.11786630962576185, 0.0861793892191989, 0.19636850937136582, 0.13805362209677696, 0.12924293987452984, 0.19339869730174541, 0.10177145219807114, 0.09479382554335253, 0.11490854833807264, 0.08181269746273756, 0.16961148514279298, 0.18878852682454245, 0.15121911492730888, 0.10677024003650461, 0.12511273792811803, 0.14259574908230985, 0.1411195554371391, 0.12438233569264412, 0.18754574922578676, 0.10374357351767165, 0.09435142071119376, 0.11106972968471901, 0.09239161480218172, 0.09389764363212244, 0.11425199785402843, 0.08977450523525476, 0.1364104002714157, 0.12231298030487128, 0.14850798754819802, 0.08946284731583935, 0.1865431730236326, 0.09834368327366454, 0.17938414003167832, 0.08577583051685776, 0.1146495243800538, 0.14925969578325748, 0.11323234971080508, 0.2632893919944763, 0.2146088606012719, 0.14568279843245233, 0.13438718526491097, 0.11072587527866874, 0.15191450475582055, 0.16716745628842286, 0.19611422158777714, 0.08618621528148651, 0.15617647820285388, 0.13491579118583882, 0.08615828678011894, 0.11772862129977771, 0.15005191255893024, 0.12040479055472783, 0.12473125196993351, 0.09685986968023436, 0.12108416695679937, 0.11946902291050979, 0.12469952367246151, 0.10944006498903036, 0.09074289684316941, 0.09474229080868618, 0.08815822803548404, 0.1377930510789156, 0.13167543363358292, 0.21365327973450932, 0.15536117766584667, 0.09483858849853277, 0.12654520677668707, 0.1121271654431309, 0.10830260959586926, 0.07740798738918134, 0.13963361802910054, 0.1091969119650977, 0.15032661067587988, 0.13341671733983926, 0.13929794675537518, 0.1047870721668005, 0.08976858162454196, 0.13522806657212122, 0.1994775432561125, 0.1356423529131072, 0.08875463996082544, 0.11706932953425817, 0.1447357806776251, 0.1637582385114261, 0.18105816734688623, 0.14287374487945012, 0.17122121447963373, 0.40207642902220997, 0.16306359507143497, 0.07881180848926306, 0.15824329586965696, 0.2040752558303731, 0.20643483421632222, 0.10240753806595292, 0.1518186413283859, 0.160128510424069, 0.10849201586097479, 0.11194147076457739, 0.17845175149185316, 0.14468970814985888, 0.10584249267620699, 0.12448613797979695, 0.10794793255627155, 0.10077168513089418, 0.15396570254649433, 0.13379485133503163, 0.1542154848575592, 0.13411659907017434, 0.08975565553243671, 0.09836772376937525, 0.19652225183589117, 0.17782749927469663, 0.14695459018860543, 0.09495769853570632, 0.15402299804346903, 0.10472054180822202, 0.08302104619464704, 0.16416189899402006, 0.0898608420310276, 0.1593540712658848, 0.08791289691414152, 0.17046303302049637, 0.11281927794750247, 0.2778845445386001, 0.1600622989769493, 0.17136092483997345, 0.25235735146062716, 0.07714339944400958, 0.14204348943063191, 0.17140793374606542, 0.17948981507548264, 0.12799638962107046, 0.12379975909633295, 0.09024418717516319, 0.13685777197991097, 0.16966039394693716, 0.11689418607524463, 0.23058242989437921, 0.2046071458607912, 0.0892921346904976, 0.15860662423074245, 0.1226491808359112, 0.06575615690754992, 0.2492357918194362, 0.1453540482159172, 0.08100531542939798, 0.1114806979894638, 0.07801875711551734, 0.20942079541938646, 0.14856328815221786, 0.15020021317260607, 0.1478516949074609, 0.17747657453375204], [0.03820099907794169, 0.05519984156957694, 0.0026500199996267577, 0.04944898247984903, 0.0116883102205715, 0.011646399656975908, 0.0420411306965564, 0.05561733738120113, 0.04387208280552711, 0.019746363096471344, 0.06676290610006877, 0.023631121963262558, 0.027176576001303535, 0.027026746987498233, 0.05260805832222104, 0.018175641041515127, 0.07441345628883157, 0.036752672865986824, 0.03696459970836129, 0.014273942547983356, 0.024686416943690608, 0.014833532074200255, 0.04780617456084915, 0.02539517730474472, 0.04182370432785579, 0.035327888426503966, 0.039067457762679884, 0.029865854552813938, 0.03798312148345368, 0.01338811932198171, 0.05704365191715104, 0.03387341468728014, 0.040385630780032704, 0.02888844521450145, 0.025959598000294397, 0.02391438658482262, 0.018991935632324645, 0.055311016139707396, 0.042967629552419694, 0.00918610462187124, 0.009206165509697582, 0.025176777238292352, 0.029842848823006664, 0.03498118756605046, 0.04343575086178524, 0.010911141655274799, 0.03295543823125107, 0.010817715016725873, 0.016739411412605217, 0.020317046670243144, 0.036197037502591095, 0.020066546808396066, 0.03589422767981887, 0.010690836601757576, 0.046613649265574555, 0.0544865248458726, 0.07193661348095962, 0.056275784370622466, 0.021518528627763902, 0.004930289728300912, 0.03874612732657364, 0.030789371247270277, 0.04577699862420559, 0.024437219869079332, 0.02728306019811758, 0.027645031489165764, 0.008825363175544356, 0.010580472032805639, 0.03604173780019794, 0.031193544023803303, 0.011390927829779685, 0.038662552168326716, 0.015897476679778526, 0.024757320460464274, 0.018132201229621257, 0.041379453880446296, 0.013049330179845648, 0.035788260865956545, 0.04565323722947921, 0.07680986555559294, 0.0341395123728684, 0.040130199664937596, 0.08885140583983489, 0.0047698441859600794, 0.0513089249974915, 0.05830097730670657, 0.0629611083173326, 0.05484574467742017, 0.02037912923177438, 0.03706933158848967, 0.0816369161808065, 0.04348340437614492, 0.011819314976621951, 0.026572113257965872, 0.024799164018726776, 0.039232294274760146, 0.01250282789780093, 0.02956212531509144, 0.04778732146535601, 0.035907801772866926, 0.03091481201616781, 0.05167184963024088, 0.03385824603693826, 0.02984349343127438, 0.01219169414668743, 0.026686137675174644, 0.036337307654321194, 0.035202786925115755, 0.014995817294610398, 0.019462452170306017, 0.07775106147996017, 0.053457462029265504, 0.0842958710023335, 0.025785574124061635, 0.01687316593181874, 0.011916683055460453, 0.0310937417005854, 0.023286952038428614, 0.009425244111168598, 0.026000708740736758, 0.04701250911291156, 0.014944487816787191, 0.016877003047349196, 0.021977443913263933, 0.02477535592125995, 0.021931084704452326, 0.037384256654019864, 0.03402324539742299, 0.058520001625376086, 0.06478911558432238, 0.022278304644195095, 0.05593267296041761, 0.0540848015807569, 0.012888206950654941, 0.06604516532804285, 0.022324947141376988, 0.038005391002765725, 0.06573153287172318, 0.016661296764920865, 0.06927754330847945, 0.01426640572026372, 0.006040663940698973, 0.043489273704056225, 0.04686227806710771, 0.00951847227822457, 0.009569605829061141, 0.023900415548788648, 0.05431560526735016, 0.045486331185592074, 0.04963937940608178, 0.02653011363664908, 0.027914521849847267, 0.018329610815271735, 0.026697090926713178, 0.005759014232483293, 0.015764020715973208, 0.034338068682700396, 0.04207319486886263, 0.09332697532538857, 0.023697738835055913, 0.07820912011499916, 0.03188079482476626, 0.04250614092286144, 0.021639947380338396, 0.007148728589527309, 0.023284896077322106, 0.04053967519264136, 0.018830822581159215, 0.019273166345166307, 0.027414650190621614, 0.04442023732034223, 0.10497841904205935, 0.07103625857936484, 0.003900556858362896, 0.004974576012630547, 0.05027203527944429, 0.02043666221600558, 0.09279049839824438, 0.04759880068844982, 0.019205613095047216, 0.02056859147601894, 0.0711169024663312, 0.0111687211818727, 0.03469190773155008, 0.0328734915570489, 0.029570756280528646, 0.07775850500911474, 0.0753512866795063, 0.013569126171725137, 0.028708942167993103, 0.12470204782273088, 0.05130052473396063, 0.015805099226002182, 0.02359078814541655, 0.04234215257955449, 0.054193706451249976, 0.00790025107562542, 0.032137606758624315, 0.011525745952634938, 0.011289527556592864, 0.032481186357992034, 0.03652731781559331, 0.055442282131740024, 0.04381652435820017, 0.03843817760103515, 0.013688949518837035, 0.053307468470718176, 0.0457868814867522, 0.03721680099676762, 0.061658701061138084, 0.0661010155454278, 0.02118076746618109, 0.014834342923547541, 0.029018418597323552, 0.014348817190953662, 0.015124201209151318, 0.030572670911039625, 0.03888331353664398, 0.0368542970557298, 0.03462106867560318, 0.016204388246738484, 0.011772391735576093, 0.053901678549924066, 0.012861896755306848, 0.021183206799573133, 0.03246686248374837, 0.04986062253426228, 0.07014249225280114, 0.03477077046409249, 0.02884532092139125, 0.061530030465551784, 0.07076564524322748, 0.0646109865712268, 0.02160525049215981, 0.01438897119701973, 0.027060141088441014, 0.030061048721628528, 0.03047216630407742, 0.0438217830045947, 0.02308054847110595, 0.06893075084579842, 0.03567250618445022, 0.012361048005654343, 0.021058797403903942, 0.0034763579689232366, 0.048799688927829266, 0.04969275636332376, 0.026122979054759656, 0.03303111863455602, 0.03999814657228334, 0.03924448076369507, 0.02803070909742798, 0.015564058142315065, 0.022853537795266936, 0.0361185174302331, 0.03642342731888805, 0.04323859911944185, 0.014543829851650765, 0.07447345235518046, 0.025099956896156073, 0.036230971038873704, 0.03654824722824352, 0.014786375586741736, 0.03277232198576842, 0.012153223755636385, 0.04423724999651313, 0.05035268595176084, 0.009666597320964294, 0.052954192605933974, 0.031609601341187954, 0.015040646406954952, 0.05258782780064004, 0.01934276707470417, 0.0197169655667884, 0.0507259616362197, 0.016012808973235742, 0.05781370773911476, 0.039325599625174484, 0.03153857568811093, 0.027292064357815043, 0.043588146434298584, 0.023337730206549168, 0.08012457018984215, 0.030281925440898964, 0.023626950669235418, 0.05898921537612166, 0.03715866750904492, 0.015034509057711278, 0.009784678529415811, 0.0700428154585617, 0.08250660129955836, 0.01446126401424408, 0.02928811591118574, 0.027239952868382846, 0.02138191238710923, 0.021255947449909787, 0.03321931032197816, 0.0011565922011089111, 0.0046285282421324936, 0.04392563278919884, 0.051615497296942134, 0.016856523164148842, 0.03152559870587928, 0.03418082497747881, 0.04986883620066302, 0.01456873378317271, 0.02837713006218629, 0.03019771245973451, 0.03105575731024146, 0.006566503135088299, 0.02523336705884763, 0.012299580366483756, 0.005387831404472568, 0.06399471392588955, 0.018765956329713975, 0.029619037439780574, 0.04384464963472315, 0.044734755264861245, 0.057580563106707165, 0.07301526024405446, 0.03776581385838134, 0.049325109126844575, 0.038080935699066946, 0.02077992629658963, 0.020446948806888292, 0.030675842160625116, 0.08266114443540573, 0.029877769627741406, 0.024390865749280368, 0.029627240928156034, 0.017448612821421454, 0.03164605224238975, 0.05295528843998909, 0.04368558745565159, 0.030567473332796778, 0.05769904210631337, 0.018015435530937145, 0.030035064223089387, 0.04702346745346274, 0.03839547399963651, 0.0845504030585289, 0.04941523214802146, 0.10394370063607182, 0.05871227809361049, 0.03170306614733168, 0.024422694130667617, 0.024277341751647846, 0.05233640682750514, 0.09600434558732168, 0.025843678774046044, 0.031052975316665003, 0.03323481823982937, 0.14081732236913272, 0.17258501558431558, 0.11214014581803765, 0.1928908545523882, 0.0809757448732853, 0.1033009040568556, 0.11863586333181177, 0.15842480398714542, 0.12662353685923985, 0.09781748615205288, 0.16650086348610266, 0.14932556796286786, 0.07151395401784352, 0.09114648947226149, 0.2812446228095463, 0.16356360752667698, 0.10541157544191394, 0.10464160782950264, 0.13046635208385332, 0.11415751863803182, 0.1638538712369544, 0.1570530097399439, 0.109778111135321, 0.1462752002158335, 0.11121489546660866, 0.09460945400808539, 0.22989246834601673, 0.14344258792698383, 0.10888249919350658, 0.09565676602401904, 0.1523193730307477, 0.1379309429654053, 0.10764745689396348, 0.2287388773901122, 0.15519940134670052, 0.11473485694399901, 0.08729720780892031, 0.20873428082891873, 0.13980987428554467, 0.08623226066785199, 0.10015674241419349, 0.10473871297602143, 0.11906082981399127, 0.08198269084095955, 0.11971173488668033, 0.13182118295558862, 0.16568953916430473, 0.08096636073397738, 0.1556340301675456, 0.08905726657914263, 0.12372773938945361, 0.19066239627344267, 0.08558481612375804, 0.11189368154321398, 0.0987380953239543, 0.16189461494130747, 0.15607809062514985, 0.14903340435453824, 0.15751112944313458, 0.12579554771738394, 0.10373612998851708, 0.12583962535219534, 0.08607023329074893, 0.06168606637844017, 0.11947683963392462, 0.09058314934372902, 0.08273348983909402, 0.16950342165572302, 0.07513494257416044, 0.13840811593191965, 0.0631957118000303, 0.13213484255330904, 0.07858949327575308, 0.10442569120121853, 0.10497163369187287, 0.1954132542014122, 0.10428708006760903, 0.15393227791147573, 0.1622098758816719, 0.16801139100321702, 0.10523284253265176, 0.16399397514760494, 0.2171550089759486, 0.11250753181853465, 0.16243771437023366, 0.13139020465314388, 0.1824676338583231, 0.16376613665904316, 0.11726752961320536, 0.10762350460780518, 0.11544088620160307, 0.1265750623175076, 0.12165539844759873, 0.11680517585149833, 0.09848707129380532, 0.07519391405263118, 0.1412704616252865, 0.11667447643620626, 0.1150603366217443, 0.1439589530761753, 0.09819321134792906, 0.12034358669604574, 0.22332438507250377, 0.0764417942347271, 0.16297807251768454, 0.05656944075599313, 0.18874001157070908, 0.19020742497273854, 0.07765109291566269, 0.1290551892348698, 0.14176495080547674, 0.18623559309967927, 0.16642230270164354, 0.15780190884002618, 0.1329731454274484, 0.13649945120726312, 0.07660594542643853, 0.10216791342411723, 0.16281242854893208, 0.08588122057595424, 0.09478204617542879, 0.10494057035871915, 0.07429127248802356, 0.17354863030569895, 0.11757235468498298, 0.07648006360977888, 0.13881356774696282, 0.16136288775929383, 0.12380372174084187, 0.13494921582085745, 0.09914437495172024, 0.12017140164971352, 0.1598232646605798, 0.09930520132184029, 0.08870270489049809, 0.13938102658305848, 0.13685047094311031, 0.15283220979784215, 0.09406643600336143, 0.13103504585368292, 0.10559980105608702, 0.11076719127595425, 0.19651572432901177, 0.18216086817639215, 0.09556861753974642, 0.13826798487986836, 0.09414323259677206, 0.12867735379508563, 0.09810437754328762, 0.11671250153865133, 0.1991675477474928, 0.08897149296743528, 0.06074172205158642, 0.192114596920354, 0.12222360367221491, 0.08750181325844356, 0.0744114885372775, 0.13842431934816496, 0.16367446657802376, 0.11605687386223248, 0.12802963783698423, 0.18384835762637003, 0.1555845106818846, 0.15854903017835958, 0.17876930588058063, 0.10735499473022563, 0.15264394347156796, 0.1977731989962714, 0.11088706127234868, 0.13979031890630722, 0.12324150119509016, 0.15397163294255733, 0.1843745479626315, 0.1133867639249989, 0.17220202327838965, 0.23235033931476728], [0.008212244869875056, 0.054929676066551886, 0.04493843112140894, 0.0068203774363999915, 0.03291540466515081, 0.01254226011224091, 0.04159535015267985, 0.03508388723379799, 0.015607640446562852, 0.0728207038981574, 0.02587294907841299, 0.020504344387778213, 0.031769440442855866, 0.051679849558110745, 0.0380452651131366, 0.01769437311616327, 0.007454711411680494, 0.009333663087870394, 0.029767843562045267, 0.04776746753071036, 0.027106447710788677, 0.06897284715835537, 0.04221406213140913, 0.019568692094513347, 0.036648958788386414, 0.005854872570905302, 0.09497013608259813, 0.07884515848542963, 0.020917027689782635, 0.022536505878503834, 0.022767097522903765, 0.02392103792434292, 0.031782329215535095, 0.01328245275986514, 0.024583551034863507, 0.031823468793715746, 0.04985370486974716, 0.028365226861621653, 0.052018180689109225, 0.022148614549743276, 0.025912251523030654, 0.04590183888961162, 0.03257922788283654, 0.06569864427936928, 0.029815609034683024, 0.0694363544295941, 0.02475279802456498, 0.011633175857631224, 0.017123263761667267, 0.0343094005781625, 0.03154402093163558, 0.00914367921983025, 0.037936210964939425, 0.0630513263334121, 0.018986604043415616, 0.017891082114406993, 0.017840069851705005, 0.029098651970603635, 0.07200179355485098, 0.05951611138880253, 0.05568885836484177, 0.018785062179501568, 0.0348873868850725, 0.05003922991454601, 0.028146891255996058, 0.03755757146115814, 0.0758158185386232, 0.02861758421308228, 0.008520031747009073, 0.041192775326115746, 0.016312149785725132, 0.04976811106981976, 0.04719152361420648, 0.08325860809002604, 0.08271257738981928, 0.03439426834561995, 0.0193861288550709, 0.034850186202675104, 0.02069749616618667, 0.05743634727384363, 0.023368474628244127, 0.007724913385962802, 0.04206965970141547, 0.05105634033679962, 0.02493610086717776, 0.009739929993104721, 0.015987923701426814, 0.012684931429768247, 0.02410917023995093, 0.006304010166786611, 0.016285384971914545, 0.003802274029502379, 0.05512344191915222, 0.023216297883274298, 0.04876846613894616, 0.013778772288268166, 0.020017990842461586, 0.0642520822584629, 0.028976291750690768, 0.04171684184776885, 0.004140371490003807, 0.008978310905929123, 0.039733616302588155, 0.017132101680285165, 0.003619084841505225, 0.0317214815877378, 0.03505161271563598, 0.02330214952650879, 0.006561227949402694, 0.046567403711378574, 0.0066543721477501094, 0.023695915272193294, 0.01648834327768002, 0.019456635428858653, 0.013521628720419747, 0.03780814087284463, 0.02312457182311586, 0.0318301184368985, 0.019393187315602387, 0.033515009097754955, 0.024249752517789602, 0.017892376419955065, 0.015247898143050926, 0.02195808700551944, 0.021424100301893692, 0.08756993817431585, 0.007343954988755286, 0.04178021023316043, 0.07511846774390765, 0.008479163582835878, 0.0089310814759561, 0.01858265687977629, 0.06667817743229014, 0.016425546558041657, 0.01566012343391776, 0.03105887517865215, 0.07670364089842353, 0.034406855170215876, 0.03045787296390959, 0.04721809843821185, 0.017714411951601505, 0.030407719048006192, 0.07088116583015237, 0.01960341103508004, 0.04039396319006171, 0.02116688124702445, 0.04294977051072887, 0.02872821595519781, 0.07243284649614777, 0.03241454743381057, 0.049245656068835936, 0.03740845660545996, 0.060302832030824254, 0.07500651625118085, 0.037282283018742285, 0.030341816334319965, 0.03863884415477514, 0.03858227129759533, 0.01445468731357583, 0.049396738676088195, 0.019680455293772475, 0.027847129751795104, 0.015283970760979822, 0.011736729631333478, 0.017514055827632546, 0.012483605000722622, 0.030862941406667233, 0.029861338902264833, 0.003222228368810777, 0.03213867884395378, 0.022363942548898712, 0.035252326766827276, 0.009609297583145755, 0.07336500433406659, 0.03323056721793754, 0.043053091038018465, 0.1035791305559022, 0.04788573279178568, 0.03191763249092868, 0.018492501628186022, 0.016624874701457362, 0.03865208576566406, 0.02000661689921149, 0.027115584184814776, 0.025303512312737957, 0.021049589683700885, 0.021421148674562573, 0.051778199816388745, 0.04617761926991599, 0.022731201324079717, 0.04690579930320382, 0.05976813965077911, 0.017736460947032486, 0.012076159989062165, 0.04379434983379074, 0.036949699079351764, 0.02534803608432412, 0.026492789121610776, 0.0314342678923692, 0.044809882662125995, 0.028556438029876778, 0.050852735726428885, 0.02862384369862931, 0.047146384072090895, 0.016238270892894695, 0.021520294515149932, 0.060192217252084186, 0.03732823341020516, 0.05869576255125659, 0.014540006306820681, 0.015419126455006855, 0.020541297404893806, 0.018730195837893655, 0.017429713924814547, 0.047360529723976336, 0.01995933657911207, 0.03204030144427504, 0.018606541312432716, 0.0033827052933962216, 0.029421929802213396, 0.03241566362391625, 0.03974567386986954, 0.018336559013862695, 0.010907729472299772, 0.06405070663562842, 0.021144418345232095, 0.0264740259320076, 0.020222034804256897, 0.044424298352428844, 0.045964287860052924, 0.04486463026010564, 0.032298453484794924, 0.032254827075770924, 0.05506681477917092, 0.04804636238675032, 0.034534531711999855, 0.08879981682236705, 0.019034934396456395, 0.020322035598967756, 0.028885100036859512, 0.045181132919554196, 0.03357314258547766, 0.019191202707588673, 0.054238425301654, 0.07993505535913364, 0.029250236693769693, 0.013675525551661849, 0.023655421998617903, 0.010133277591583984, 0.01396798771539969, 0.052897806345884285, 0.023656561937449232, 0.04097253642976284, 0.026805369848651544, 0.04986797446118934, 0.05862395319023302, 0.07260795602841036, 0.028267526300624013, 0.020711039725158895, 0.034685414151421616, 0.036105723652456484, 0.01631110653813396, 0.0390198042483202, 0.02368270419538021, 0.029044287744909525, 0.025918969019715275, 0.010676973283157816, 0.019612133602744768, 0.011395452810185296, 0.02946929833186524, 0.021019667985716035, 0.04874702103968177, 0.032644543663731644, 0.025479926328573908, 0.05394967472446816, 0.009688787112411643, 0.01280816356718008, 0.04691267964829292, 0.04899463203868695, 0.0494260038914425, 0.07945976871997118, 0.03214844635554722, 0.01970974595418998, 0.021857679089797393, 0.007677572845880474, 0.013357583549804986, 0.033350959686296325, 0.026107751032603637, 0.009464617801963218, 0.0456195038610271, 0.06025203011397805, 0.026223481965384314, 0.054990961349436214, 0.023130775329523852, 0.011726443888619542, 0.034735527355223894, 0.04430948344192334, 0.057956077956727574, 0.08255584937121187, 0.0699884444475174, 0.021881342998572757, 0.03176363557577133, 0.027564709906333258, 0.019041095494425724, 0.030716974953455583, 0.07074430531689099, 0.01713944342918694, 0.011139008133406085, 0.024278403658952032, 0.005779161633524511, 0.030898062379232476, 0.04469768011144229, 0.04086939910692828, 0.016829469972955327, 0.054670502830828936, 0.005568155902437866, 0.014073150465264916, 0.019089871984241263, 0.1312954675938402, 0.017547799374109933, 0.019748093360768895, 0.038462961092591286, 0.022227249973054444, 0.017338143927710395, 0.038994270975568464, 0.05654020607471466, 0.035430052051586766, 0.037544526625424623, 0.06070778851530381, 0.06228300756109612, 0.022773837071976492, 0.04327192536688276, 0.03753559710457921, 0.035037482223872624, 0.03303152236289211, 0.055415887119514604, 0.056757632443415265, 0.015664656047842333, 0.031309549763266525, 0.03295696493504303, 0.0430622105486691, 0.02463112651769604, 0.03658714085551245, 0.044707196565078836, 0.007774839144466179, 0.006091992994437793, 0.07599040559892144, 0.042118066389645846, 0.021152747362586002, 0.011902492343714195, 0.04318784470004695, 0.04638733748080475, 0.1653767888035093, 0.11458997614681721, 0.08182404256824936, 0.16688929764287813, 0.11148469456072364, 0.13492925332060882, 0.04972495284995862, 0.3321729643004281, 0.07906764333269425, 0.12771779671311378, 0.056625670952988524, 0.10504904096680028, 0.2069269756653479, 0.1148921006492206, 0.1101760176409568, 0.11006925015577249, 0.1310097500681877, 0.044682935545487065, 0.11100365394460303, 0.15090768092444964, 0.08306992785739047, 0.15305810767625058, 0.12252928369811603, 0.09997693741960184, 0.1414935096566166, 0.1208971898470606, 0.1679618036640542, 0.23498224094510078, 0.16342828050255775, 0.11651541425713471, 0.1810650612626757, 0.07324408260839325, 0.10768628266773053, 0.08740902359464339, 0.1074091282540134, 0.11740459368697234, 0.18070648264672073, 0.16119334899953433, 0.15259028492229326, 0.09513466046856982, 0.13663965011281626, 0.09678744963769402, 0.06701278340603624, 0.17636178221021379, 0.0715216418196048, 0.10172911161290747, 0.09424045987959419, 0.10240200122020074, 0.18223693195198262, 0.11625097558966704, 0.1256057886140687, 0.06628998754812138, 0.11781113115804535, 0.17137172711747034, 0.15254288246589048, 0.13294627544070992, 0.11667838479791369, 0.11896415214453425, 0.15935534691171988, 0.14186257842395986, 0.13850764344845498, 0.12969580771667616, 0.10558114812842437, 0.1297987550497055, 0.11740915344229766, 0.1339070810271161, 0.1510456135230405, 0.14279632403382234, 0.1485861683530467, 0.13427980031285966, 0.09031700755336455, 0.12297149854046957, 0.12856840821249144, 0.1243031235145671, 0.1881294793316296, 0.06653499297265496, 0.08651126069681984, 0.17144737020134926, 0.11220982457910265, 0.11538034730723926, 0.11152204112815005, 0.10966856165656022, 0.16306672990322113, 0.10310680232942104, 0.15768171314682278, 0.13104765303432941, 0.09764622391334601, 0.2294670268893242, 0.10779767097639185, 0.16964603614594254, 0.13441690509872778, 0.11209365259855986, 0.12192302622965404, 0.0783904314573322, 0.09091229989592518, 0.09052424571876015, 0.07898205292544194, 0.09286278951913118, 0.1298095573272024, 0.07632455695420504, 0.07433637471071311, 0.12205870609198298, 0.15934370325079986, 0.050984527583100965, 0.13041114647473606, 0.1101309357743178, 0.06104691353227411, 0.0482747979861285, 0.03473937804145472, 0.07455571115549121, 0.08686774263956717, 0.09990942318524633, 0.09562323960874762, 0.10246074878211532, 0.17649603714900358, 0.15973620861768723, 0.19352136286241667, 0.12041131806160722, 0.11496486674462046, 0.08276374571557556, 0.07412031559007508, 0.13137104282421724, 0.18352443857916764, 0.0667391980865172, 0.1098634097725153, 0.1584447529166937, 0.10025549640080758, 0.12425744453711168, 0.1340675681297268, 0.1419143642165831, 0.08957880895052638, 0.1232720488416297, 0.14483579673937388, 0.12227559302534376, 0.08204888871737889, 0.1419432290962764, 0.18235353140958718, 0.12921000378472464, 0.12385032352592264, 0.13032114558986255, 0.051928607281297445, 0.13517523583556923, 0.23825999934758457, 0.1406670268625021, 0.08130096670772348, 0.09760088420339993, 0.0858714496716857, 0.06603356237922396, 0.12788110652140208, 0.16989412211946078, 0.08988765094961439, 0.1418383547237941, 0.2740716119962079, 0.10923745443246194, 0.11335549703133957, 0.09772278301950012, 0.14730137586593628, 0.13656677545181342, 0.1282627960400922, 0.19139381631144456, 0.1503818162849971, 0.13604304141231946, 0.09242372307926416, 0.11681282972650868, 0.12406925963503973, 0.1542584089828389, 0.09052636274801833, 0.10368593875318766, 0.14554497439946446, 0.0886678621172905, 0.1603230328432151, 0.09127207273351294, 0.05521350047950234, 0.15448657316820963, 0.12406567697014127, 0.0962318651644247], [0.023578199624483074, 0.04159145196899772, 0.019365372468850443, 0.1581965448068721, 0.035219475493899415, 0.07041841173278433, 0.021480878415916647, 0.0493744454080505, 0.05427016716982637, 0.06124404152589185, 0.059825061953493526, 0.020817367858918648, 0.025023406271689703, 0.013695918073478554, 0.20356288046709128, 0.029135598202369044, 0.006287665106356144, 0.008757206029258668, 0.017616299180580035, 0.04887521326807993, 0.09741449741912739, 0.040734207789812765, 0.10445689024137599, 0.0021410843848051237, 0.03631902113556862, 0.022061424496184503, 0.0257156833208033, 0.044500681039478095, 0.013233530385020589, 0.05352817216355886, 0.03970078877838595, 0.02212660457007587, 0.028400210430845618, 0.05142429969938738, 0.027277725216533457, 0.07744356298020907, 0.04441803547420672, 0.022906519505860548, 0.0384487457839506, 0.05295976337843707, 0.04221777371796114, 0.04253661732322403, 0.045738098211586475, 0.03990311095757144, 0.05533451380740319, 0.05777596762137754, 0.07810896834624664, 0.028584481882197515, 0.023821167747623155, 0.0323656386296664, 0.04169046379891889, 0.03125122289306351, 0.027651608189834014, 0.03242975340357848, 0.04096870270690747, 0.03280669656981315, 0.01114725911923285, 0.024176083970814943, 0.055760725401341915, 0.04940203803458384, 0.028939091068293368, 0.006102191375768078, 0.042833598530186076, 0.031643114185759, 0.06275251986724989, 0.0211470273123788, 0.025307016946109276, 0.023863281023555567, 0.007328647238734577, 0.016548936454845325, 0.04518251373831715, 0.0590615879212107, 0.04981998507199543, 0.03602036055443542, 0.04205605846696666, 0.03297350422612258, 0.02720313555827098, 0.02073827781714499, 0.061674565209874084, 0.10639435877757412, 0.00916880791607712, 0.051271347728158743, 0.02857698067756636, 0.014996500918641686, 0.006821223060666982, 0.019152373541146517, 0.01585321075149945, 0.04523195179977587, 0.07651137121553932, 0.07167351831282888, 0.05493307213432022, 0.0395597417040595, 0.0661199873845492, 0.020909119364140288, 0.017185824690386653, 0.006749615987895855, 0.03267521005389946, 0.11156577949545213, 0.053566210836704285, 0.03716464200988412, 0.04537860696603145, 0.023803203533004438, 0.021866123458104472, 0.01075148066904928, 0.04192823604015367, 0.04754687240347266, 0.07666877776916538, 0.026339082280173898, 0.03853312500619462, 0.043519149600927315, 0.007825538432890815, 0.009170528850518167, 0.05542359188465135, 0.05654450798673289, 0.049096520857087204, 0.07035157603344747, 0.01670342361155365, 0.05692705924489668, 0.05128458933904767, 0.015205416761870896, 0.018163673380123715, 0.0028391211360160795, 0.03975461017606514, 0.016819531131269674, 0.019370369879262786, 0.025382434417094504, 0.050289968959987164, 0.01166924338654748, 0.02108003894266273, 0.027037880050816705, 0.08573001583239862, 0.029681659436651638, 0.021534664190507362, 0.01805081943582211, 0.03496769489720464, 0.03925897087901831, 0.021417805193258182, 0.060061429627239704, 0.014451583015865513, 0.007595495553687215, 0.024910012892048274, 0.06031575133757932, 0.05898565985262394, 0.03012279880100063, 0.0469559633971325, 0.014924421839948212, 0.10965778652046408, 0.05316421276490603, 0.03600856761581131, 0.03375486783417208, 0.0022032367082179655, 0.0031020899269995944, 0.037366394219653945, 0.0779724403151444, 0.03716947317921689, 0.04577842015506966, 0.02700682689568826, 0.010639272181184163, 0.06732562197638409, 0.0650607060108866, 0.031711632651942115, 0.03984026165146913, 0.0173311651950436, 0.028699486782508235, 0.03268816668008055, 0.05357603941644941, 0.06048683037183114, 0.044894363664622815, 0.05409701181841748, 0.026043848300884877, 0.05294552771374583, 0.0451710939939533, 0.004862464216005589, 0.0826328427397779, 0.01871372609665351, 0.07547566893377475, 0.021759746130555868, 0.021506723814776967, 0.013455647975206375, 0.008527538040652871, 0.06449216151876108, 0.05228193064353295, 0.03277487667011363, 0.023372827430388758, 0.010166284927566136, 0.06884011892335755, 0.03582013165578246, 0.038105379923113754, 0.020406251972807304, 0.014249539036037666, 0.11010507680475712, 0.02278197609952518, 0.04376840604735272, 0.015232240947495614, 0.04701078902663929, 0.04013912579310792, 0.03477762366778084, 0.017506902372198443, 0.06377708060400826, 0.01979631684454424, 0.016859965033030937, 0.03253436314740351, 0.0269017828894513, 0.02754396030546299, 0.03546284564903804, 0.036798657184200625, 0.025608432379418185, 0.027025188053292886, 0.045776109743331156, 0.05394471463348184, 0.025586434274113605, 0.0947077465908868, 0.0490131322959704, 0.015985270629503896, 0.07055626969252314, 0.04144057970760124, 0.044275465088763406, 0.02388378804815667, 0.018588434605460082, 0.02567319176159799, 0.01209111574904195, 0.051323041918554475, 0.053557627368718386, 0.04444505134597421, 0.027164783062679426, 0.014082750887610018, 0.01920560122068439, 0.04690882556938699, 0.056230247885520966, 0.017063886858522892, 0.042048737074115446, 0.02526226586529187, 0.031400860220726044, 0.061759402443255694, 0.09071472406919513, 0.04868840918477092, 0.05489076886858259, 0.024376518126311045, 0.02685345762542316, 0.015927900493677174, 0.060662333454404554, 0.018233396245964935, 0.02248299491059567, 0.054140624656741104, 0.046610446580286534, 0.058680264811430655, 0.016364037358601178, 0.0032719832213063326, 0.014205222217632192, 0.024272519064002802, 0.03555130286674414, 0.015235906732933862, 0.027892773106162037, 0.03847716961588178, 0.0125590207753703, 0.0878786648224507, 0.0417665682866105, 0.010881376868513013, 0.012196116498671472, 0.0057589667350319874, 0.0004408719791432044, 0.037106338888406754, 0.015908122894221118, 0.05311628105118871, 0.05091418046504259, 0.04915004369935819, 0.018822820956951807, 0.03488976175763777, 0.02777109481394291, 0.025431219388597777, 0.0331116064584681, 0.025695656359727894, 0.014141668931448033, 0.015437396010383964, 0.04948798806539603, 0.007197477937942105, 0.04679705049576504, 0.03394865065014788, 0.02360299668673958, 0.014027206859152232, 0.0198012820245432, 0.0077024861072589245, 0.040820544585585594, 0.026994194269978573, 0.02175473514944315, 0.027702713751101067, 0.04324295870693667, 0.016332692433414713, 0.012971697292024536, 0.017809730854683688, 0.03132039614553962, 0.03153135268283742, 0.05542899641607489, 0.058620031257825236, 0.02049601706676185, 0.03573042932631714, 0.022632377787626216, 0.02434229790898306, 0.027629128324666193, 0.013587975026374417, 0.05510169826447964, 0.06643464442874704, 0.03297432525349515, 0.03542510213862572, 0.05656351375260523, 0.011942016160381692, 0.0502791090070137, 0.010018864713077034, 0.036958404683641026, 0.007133416598662734, 0.02833338999854667, 0.0231282410012292, 0.038455364893057516, 0.017942564262609397, 0.021751318725624254, 0.01455181451248271, 0.05710033673260893, 0.07313042120741946, 0.023904042318463326, 0.03974857121439917, 0.03342570710395064, 0.019671308641721095, 0.07761116112981524, 0.009500172188771623, 0.05080317213599171, 0.03684106223019106, 0.0327845797208803, 0.03620098318372454, 0.04347316189003842, 0.07593467751783983, 0.016270384258989776, 0.027623774683369056, 0.01795963790001614, 0.025673067928957086, 0.03451654714133058, 0.03991611168852874, 0.03875877861199634, 0.05341648190681424, 0.005321006307245365, 0.06994408182799816, 0.027716228472334997, 0.024807231800098504, 0.02857090439647436, 0.04126581622819815, 0.07309398387691804, 0.026934832633872117, 0.016645995800250342, 0.06703548718776021, 0.031167491671762297, 0.03218408640740173, 0.07162186144185917, 0.030438952014914582, 0.08858240063169173, 0.1530988604894706, 0.10080911990787302, 0.2348399928637913, 0.16693330742418766, 0.16283524089625903, 0.135620951918619, 0.0974265956985099, 0.1141987464257649, 0.28486466141683714, 0.14410365745425224, 0.132744628403868, 0.17808285914361477, 0.07977862589593444, 0.3444220684468746, 0.10121921968779393, 0.1310918935175453, 0.09517405621175255, 0.09289057552814484, 0.14850650834185736, 0.1631821622805936, 0.13373507239988872, 0.188067746215633, 0.09062956792435475, 0.09437911851065499, 0.0833197237391557, 0.13050183946532862, 0.09604649618268013, 0.1309508260871683, 0.0777194688894919, 0.0915087525333677, 0.17165088999484265, 0.1024144726938435, 0.1244701516947576, 0.2316649103803294, 0.17091706794287476, 0.18728530034422874, 0.18332207229520592, 0.11632186892841544, 0.18145189407680715, 0.12537850652422222, 0.1354761254042387, 0.08706923361335482, 0.16837728422667297, 0.10365307730223451, 0.17171860778970377, 0.11164550736014332, 0.09058525958763701, 0.10329164205385105, 0.14565887328769478, 0.09215083665081433, 0.07014675345271826, 0.10974201985767909, 0.20284313123141015, 0.13724649112139428, 0.14298890584281512, 0.07335645479283162, 0.20053147098847798, 0.14846393705478736, 0.1280574577727488, 0.15453837253153324, 0.09387180501861231, 0.10499122978321143, 0.0834920716338924, 0.1295335835644177, 0.10400778826858316, 0.12949186723147119, 0.13347185509545462, 0.09142500095601593, 0.11758972518146038, 0.12073028380317347, 0.16188151921544755, 0.11128158867359161, 0.17740490766508238, 0.08511737334941115, 0.09789274925632135, 0.08134273732347147, 0.18152784928679466, 0.2077762708067894, 0.2519361712038517, 0.08170456612216574, 0.0819642346884523, 0.09150984497474772, 0.08494326804897614, 0.09557578965489354, 0.12071724236011505, 0.11622943888817515, 0.07589465073708977, 0.1536282535110201, 0.1359343265316316, 0.14001648819872312, 0.1744734871068171, 0.11887586116790771, 0.1860932500234672, 0.1387176364660263, 0.10051608777471951, 0.12159642018377781, 0.22587229763822897, 0.15475287102162838, 0.11387889858867441, 0.1891534836696727, 0.1532682635422264, 0.08125414100608655, 0.04557585031060236, 0.14179952895002707, 0.12879847229591437, 0.20301357922809465, 0.08720159543944256, 0.10175900786582913, 0.10211736256522791, 0.2186787679259266, 0.08136343264154025, 0.05610048145587955, 0.16148381627031735, 0.13067749861095632, 0.14787898558591092, 0.20137630136949675, 0.16584596862750395, 0.14591795152851514, 0.11994664371013641, 0.0890570833746876, 0.09565618926925318, 0.08270109657730375, 0.14812773652374744, 0.11416206482265677, 0.1577890980988741, 0.1886580173990556, 0.15681918657251767, 0.118172573191779, 0.1562778784760407, 0.15797061978706292, 0.08255259240312235, 0.12610329048974173, 0.12202240446848528, 0.0861029861760991, 0.16103952511080674, 0.08650000380086047, 0.12606526538729668, 0.0899472873924034, 0.12776278358485016, 0.10420640903924193, 0.14524219850344317, 0.13096914653267178, 0.11298823316714593, 0.12100420839020185, 0.14474817072706564, 0.2667813231902463, 0.26126081656132427, 0.15084769842880114, 0.19639569148421288, 0.1192366246666227, 0.11659219727984496, 0.12334803119301796, 0.18351082716669354, 0.08801745237516505, 0.12664221014295304, 0.20492331603808062, 0.13424401437597616, 0.15300310562763894, 0.144815861380526, 0.0674080504104495, 0.13136254756578378, 0.19684622516589506, 0.14484053291380405, 0.1447735479367631, 0.1542474167155368, 0.1794452624661582, 0.09177666530013084, 0.17221460331763538, 0.09176049581063644, 0.09719993107553039, 0.1420037272785391, 0.11413143575191498, 0.1837476087468011, 0.12839466253561632, 0.1469555129962308], [0.043155885700668604, 0.07264468512896981, 0.10642638563045434, 0.05709168541112116, 0.012730858072505465, 0.037489768849419694, 0.01839581038802862, 0.04137291619554162, 0.0450390578646745, 0.030190068762749434, 0.04182431500937257, 0.034754031005182436, 0.006582677713595331, 0.061854682330574305, 0.03258759082694139, 0.03395825531333685, 0.014661375865606325, 0.03058925430689539, 0.08671068213880062, 0.017002630413376858, 0.06695989838668279, 0.06371009562696729, 0.022564039133223038, 0.01048059931157955, 0.031243884536836828, 0.022080133402986184, 0.02877485505970461, 0.021992962009140422, 0.01952047030707555, 0.021879826472806077, 0.053481896075287035, 0.03116302691133959, 0.035034306679985354, 0.028905622328498533, 0.06220393109002283, 0.09714767709374428, 0.025470082481790866, 0.029420338637594665, 0.01812920210483883, 0.07574475556612015, 0.030545380232589583, 0.045160597057214806, 0.022951674315014055, 0.04455391550436616, 0.016870256712926284, 0.035771687648126056, 0.031549086195549796, 0.024082807458138893, 0.022268861133073057, 0.080141920330269, 0.030986119261277572, 0.004257976027604724, 0.07616912493748323, 0.06674367641764027, 0.06468878061111484, 0.034755822337631664, 0.053573844355664084, 0.005424007923076195, 0.04444372481001275, 0.06700096332601138, 0.044434344063379934, 0.01623613859659859, 0.023893704837454215, 0.023175925049664717, 0.029115917294153144, 0.03176383235092674, 0.019373206155640737, 0.05080499739519187, 0.04974965152463742, 0.028770142634000097, 0.047336903134627004, 0.03573244457532253, 0.0390055482275784, 0.05350071185135415, 0.032417957072279284, 0.0428382057829627, 0.05563634653974857, 0.05431926596377577, 0.08177501841315202, 0.05043681750872305, 0.06515779758670501, 0.05016400571912527, 0.06626958400011063, 0.093628373795322, 0.03046934020572475, 0.0031384225086575107, 0.020117421667756777, 0.009667917919744338, 0.025647266634872982, 0.02856449902589832, 0.03207953433905329, 0.006925611432442176, 0.03797474157597337, 0.02314270906416433, 0.022941501378746967, 0.033544996952904124, 0.03607690627021449, 0.03004538474072303, 0.09297394034053598, 0.02454581600613892, 0.032272150074797015, 0.019657885522714684, 0.06368637404271535, 0.04444030499351876, 0.09708558435418776, 0.04392980917223862, 0.06721220484801702, 0.04650697338261774, 0.03324140002951026, 0.026321713480034044, 0.007492989268419998, 0.0586110135274274, 0.07298038354409592, 0.03627013608015009, 0.00639948428475431, 0.016693561105057597, 0.03254996606015733, 0.05226203599678619, 0.0253051475821329, 0.0638950914144516, 0.0306383497081697, 0.021670798671298792, 0.004748991532583854, 0.02339201809705368, 0.039077632395284514, 0.047231614855783324, 0.017043216985517314, 0.037708331764276536, 0.026463807194626758, 0.028624735972178832, 0.015347525743501527, 0.012630870848494982, 0.06733789667487144, 0.012381800151030933, 0.012056442609589015, 0.02654059530634965, 0.054870538347001584, 0.06545876179422651, 0.05492120116416897, 0.026930922575827156, 0.019984606919544082, 0.026299554222662534, 0.0725454358117921, 0.017134067735501697, 0.005360291788487562, 0.039808987972459624, 0.01481662637421063, 0.05093471632738199, 0.041131666462336264, 0.05241020090345826, 0.06781437753566674, 0.08089550132197992, 0.017450589054663266, 0.05808341183832713, 0.03461395762860775, 0.05402143319536533, 0.05145552588094558, 0.00859967733932925, 0.043545588717928956, 0.04169074539095163, 0.043020314403942654, 0.020736137039161155, 0.02268307113886944, 0.01852094751250531, 0.01228364581973957, 0.0471673677675426, 0.03808771765657833, 0.021281859005934427, 0.002594551246147603, 0.013587221004334944, 0.009994628290379686, 0.029993636267525808, 0.04425461370764034, 0.050545763091317246, 0.033511752129665444, 0.011152615305036306, 0.06942269551966872, 0.0441706924965339, 0.012984764180146158, 0.06963504983910493, 0.02865044566403542, 0.1060663413788591, 0.03756309473620994, 0.036325541857097826, 0.07698812349034206, 0.0531647318441953, 0.0909002423286438, 0.02377392813962485, 0.040377976905022345, 0.007395083450579217, 0.017906298262200186, 0.03847986000723072, 0.07264064784560885, 0.08289688107158456, 0.036259506829082966, 0.03500408473025475, 0.03523302244554673, 0.029705462445105826, 0.00550316709060488, 0.022129637621609227, 0.03150791947596839, 0.05603296382884894, 0.028602500379617726, 0.06561357634408133, 0.03063402065475072, 0.024244273347514014, 0.03934280388057232, 0.052402207760938575, 0.08380429273737328, 0.04938528500497341, 0.04147315617384655, 0.045985319052955935, 0.024510720478636876, 0.015679609263315797, 0.011889800346190376, 0.02971992202635322, 0.03341635349871857, 0.05422534314649446, 0.026116487170968736, 0.03389835763456566, 0.004475121652441365, 0.024632990792659775, 0.03664097243121692, 0.046937324040170224, 0.01891900159950767, 0.09234696041260447, 0.05169566281672035, 0.0665686008121286, 0.014066107271771346, 0.033582109425749095, 0.03652927538912211, 0.016259076472904, 0.05803871673664876, 0.016190515598282218, 0.051234333642891476, 0.03522006921204073, 0.034957666149629016, 0.04124515483688031, 0.038090564110981565, 0.020602134854665825, 0.021272325588922416, 0.01906785013021103, 0.002794023578254772, 0.04054344445466995, 0.05690110528043338, 0.07128214609942266, 0.03901961425851498, 0.025133932840877345, 0.03147254405277116, 0.026929014196087207, 0.024444397073239088, 0.051637685392051935, 0.019141043702672635, 0.041557810202773125, 0.03260912413575819, 0.06581530480512551, 0.029548473190516233, 0.05489023282591786, 0.03449947180758629, 0.08066713357610361, 0.04002224474347063, 0.014898739289492369, 0.07634544226207904, 0.02331833597937865, 0.08205998955028397, 0.012444452681977834, 0.022159545748893703, 0.04111217554392559, 0.048404791725001166, 0.025809733363400613, 0.020089354066710387, 0.02569818390267236, 0.058156883610146384, 0.02408172858745924, 0.026797363135431494, 0.053528548750494204, 0.014223379814731223, 0.038903001230210066, 0.05800894262003047, 0.03124769451096654, 0.0619776803734047, 0.03641435191301363, 0.037739724186914306, 0.11364702960210186, 0.03189892528046455, 0.049390357054237805, 0.025386454737079994, 0.020426623290404677, 0.016361041626493846, 0.030062544891344647, 0.03606624987774661, 0.023489053693733046, 0.0336488772715841, 0.015993430013103143, 0.04874379799834319, 0.07175584496664149, 0.04145482215764267, 0.042237495338278155, 0.04013929881953767, 0.0461263050591307, 0.032328142784535885, 0.038966810663363764, 0.0166349729988724, 0.029534922846193825, 0.05685151115592037, 0.013443704910709389, 0.027588599428002323, 0.06325582321733236, 0.022291634464636445, 0.028731425425836017, 0.02977949400831546, 0.046975060765232356, 0.015505369952214616, 0.060437378739672046, 0.10632190480828285, 0.05354541034570762, 0.07397313455918006, 0.03492100150989635, 0.03188523583646331, 0.038839429284312894, 0.04949132306501269, 0.01669796310099108, 0.052653021445231776, 0.030700747788484608, 0.050815874311540804, 0.06859261648995535, 0.06268593522586993, 0.048414311571312804, 0.03579927348930921, 0.08937889896333218, 0.012706685262466115, 0.04567021756832089, 0.02084297577052244, 0.026355899770611098, 0.037414509137826304, 0.05961563890533788, 0.11659386647599083, 0.06717405760926859, 0.03153270975287471, 0.054118572268635035, 0.0325655452241855, 0.03198956738093069, 0.012411061125541372, 0.010084475656705243, 0.035081298622701845, 0.037198310917509456, 0.025678553884582858, 0.044124772639146874, 0.06539825682661363, 0.040830498694309166, 0.0354239079169929, 0.02504280219519777, 0.16818569307880743, 0.14236386652503694, 0.17426630322422298, 0.10792477415608508, 0.16507018596998282, 0.20544881426862308, 0.0751932490883129, 0.11795655478324209, 0.11141580968563046, 0.1303727278219802, 0.19544628528612001, 0.15251308120787144, 0.11423124825315815, 0.14609337997223648, 0.08885781121041093, 0.11798180985663619, 0.23262145476681845, 0.14020527021161147, 0.12250326866550104, 0.10709014215639659, 0.10654702915677003, 0.1162292081862688, 0.12050693721643516, 0.10893940792552062, 0.09367447346448898, 0.0947142740977662, 0.08134406046675784, 0.13149277200656279, 0.08555808862937347, 0.1311997263027089, 0.14773596397468022, 0.12205831254167215, 0.22733726831419127, 0.133067733209048, 0.163276451506785, 0.14814412992979797, 0.19236925111285277, 0.08737114098455225, 0.09050525352358818, 0.07976964887763772, 0.10100199348692383, 0.14129412892673696, 0.10405398293265275, 0.1751293319144419, 0.057815953690026484, 0.15397729192461285, 0.08631392235734633, 0.0966706330488835, 0.09989695849695376, 0.16920573477234158, 0.16585382606301988, 0.17727977223694324, 0.1845082329320056, 0.12804565126342432, 0.18744448465960367, 0.06670814153871366, 0.12749993268932613, 0.12270658489848886, 0.08705735246517829, 0.22382373256342752, 0.07229465605424983, 0.10307006644351141, 0.09298832528293133, 0.09499140815543276, 0.08398906460830144, 0.08693538579557623, 0.08013041237635271, 0.08598919585347176, 0.12252396398356982, 0.13207625783979893, 0.09039450982319457, 0.08042505942285061, 0.18735250245247567, 0.15745649380343302, 0.07624136856091873, 0.15652961496795925, 0.15017522951321943, 0.17944561530436787, 0.24356204484190258, 0.15466361652527535, 0.1754814237356186, 0.2359838400568281, 0.14066273852118424, 0.21774348882692202, 0.15918997435697488, 0.16031552824590886, 0.2746866632785116, 0.09675682735230241, 0.11023167786853653, 0.0782686887042863, 0.09080692340752908, 0.13641152663954667, 0.15737392966236385, 0.08616526890546083, 0.08321993837931327, 0.15784315019845963, 0.16721305384167603, 0.11525305413774081, 0.15080671491367476, 0.12300695878054414, 0.15356790460646152, 0.09998115112206765, 0.16411486294652733, 0.0875432106799313, 0.12308494959558759, 0.21184972008424147, 0.21080179060144083, 0.19800029109631265, 0.10699196492454835, 0.20443064533174038, 0.1215266939252615, 0.1926832499780825, 0.11203776166907378, 0.0896990792825818, 0.1082341182710869, 0.10602807200380734, 0.10063042092536177, 0.1525412132697446, 0.12876887459840092, 0.14547370108110563, 0.12276527817760195, 0.12140738032758236, 0.13673883836184228, 0.1405253623213087, 0.10659547655710153, 0.13022036956889288, 0.06049214330102716, 0.14590564290327684, 0.10763916519603559, 0.09257991505520684, 0.08974936551281384, 0.10743007463003908, 0.1264282273394721, 0.09667296720934765, 0.13274139857717923, 0.24033892207912036, 0.1039053498368178, 0.10569707583636045, 0.1825672835111618, 0.1108342305357967, 0.20516408740409783, 0.12262711487710476, 0.2547756502670901, 0.11783000800226416, 0.10906565615109035, 0.09824407433292695, 0.1751437032861369, 0.14349649074886525, 0.09053348058036395, 0.09900931255625826, 0.1691275539674929, 0.18822980751948698, 0.12721948059541838, 0.15363455031599316, 0.13459090861890996, 0.1696083095989057, 0.16399096245212214, 0.10411668635372605, 0.1344300822487899, 0.13870300725102425, 0.13673286725367817, 0.17375533921378, 0.0968268114541258, 0.14145572882677826, 0.16679255211991922, 0.1154983581176826, 0.11023929103144578, 0.11955483044896807, 0.18299340350287302, 0.08091963002724306, 0.1361302738743169, 0.1658487506210804, 0.19209506868251733, 0.17425579950213432, 0.18624855311853544, 0.11048040845032249], [0.015454875072464347, 0.022206861692081605, 0.020273008051195314, 0.019132748612069657, 0.016922541228788238, 0.02017707168124616, 0.041726141170199425, 0.03076465560921601, 0.06102847773581743, 0.031040442774870565, 0.04009759944996663, 0.014911985989393932, 0.06258226864572082, 0.053268910718283484, 0.01369287314758237, 0.08245516834514481, 0.03318697473566447, 0.04866280127316713, 0.021675176918506622, 0.05168169178068638, 0.006616323720663786, 0.026708514063752124, 0.020223176439425776, 0.05150261621123978, 0.01745835319161415, 0.09283811120050293, 0.061113471032253334, 0.01198222444924925, 0.009362017369962164, 0.024624638026580215, 0.05200096286301102, 0.04546137806028128, 0.007887660010185624, 0.030653677814240967, 0.02627190900966525, 0.006281169405805745, 0.07648859958031348, 0.026744308482323374, 0.056211856193840504, 0.017621150705963373, 0.02931495875652347, 0.04752415165837322, 0.0029527206206694245, 0.04545015509107283, 0.021695205575919578, 0.02976425750447171, 0.031100415092493807, 0.003700180378343378, 0.03051830668534551, 0.03857479044901473, 0.032348437766943655, 0.07072417996823788, 0.024900041819949235, 0.043448585351662974, 0.03482133150100708, 0.05732844663517816, 0.02705121665660824, 0.04422744855816875, 0.022043144762782112, 0.03982510996450271, 0.057207138144544194, 0.044574705817337544, 0.03941527820591416, 0.055727480578103235, 0.024604044488764236, 0.041310049926063845, 0.054218883493116925, 0.028042809073148028, 0.020702439293797528, 0.009883827762678266, 0.05297102705974664, 0.04740409506484866, 0.05967033561319113, 0.01532026390278978, 0.03190685396215745, 0.031174897881490842, 0.010106984359611357, 0.016314930082964044, 0.03420341680092471, 0.03744116538603391, 0.02228185677501772, 0.04352398755561028, 0.03259334480389953, 0.05651670501434377, 0.02825506161233144, 0.04175845640046256, 0.027567293428416764, 0.03222730230273945, 0.030312137212604284, 0.012171729101932474, 0.03891237858416779, 0.0015417676934573266, 0.03670853416302374, 0.03480713315574186, 0.04123661547367062, 0.02445749449543655, 0.130957000755838, 0.047266114968806505, 0.06459526491484471, 0.05744232516735792, 0.032841179719460864, 0.08180350331323487, 0.028113196903307523, 0.0031911037554631805, 0.017695967673457096, 0.02221938405585076, 0.01626905263401568, 0.02972073287570051, 0.05144239962100983, 0.023668380321136544, 0.02964275563135743, 0.0063559147030381215, 0.026738861542461172, 0.024837743823549578, 0.02739630769273, 0.043131176847964525, 0.07559091132134199, 0.08357538894883224, 0.042559076832341294, 0.06613969204149076, 0.048658126166888645, 0.019820493047258685, 0.07466841582208872, 0.07274851455752339, 0.020796200959011912, 0.03348264976271561, 0.02159610723278352, 0.03563148534989782, 0.024663244972803762, 0.07602741289883852, 0.03822345180170877, 0.011326221034063824, 0.015454076097479888, 0.008035841032064386, 0.0546447693902467, 0.018899671833163927, 0.03345412415053163, 0.045392364263534546, 0.010179491763535355, 0.024787145467208963, 0.014589390085477914, 0.012122084087293063, 0.06574006205690758, 0.013419700886255928, 0.07211568565773112, 0.026129959483764002, 0.0725201875237482, 0.05254842866478222, 0.0403862346761993, 0.06077603556747947, 0.05066970429782357, 0.03116159520245024, 0.031965516707194705, 0.02984582759173853, 0.044411314584847005, 0.021103317782815014, 0.01174647339420127, 0.046419649318392785, 0.017877435078844428, 0.05448356982586639, 0.04492496559396386, 0.018062917715204612, 0.0897959740832448, 0.005333780577140195, 0.04528388687010322, 0.047593776136636734, 0.027300724160990546, 0.04780332810644593, 0.0026126978170525816, 0.05027716500418527, 0.014282117198620523, 0.008373278193175793, 0.03880705977124827, 0.029549918470105956, 0.04441701088632856, 0.02619647457530456, 0.01877181717593755, 0.010169085580855608, 0.0443997218140534, 0.07425613794475794, 0.027488920937425325, 0.020567960438451598, 0.03512646869889327, 0.03921237927196281, 0.04386915831959673, 0.01205372083599546, 0.042720133904367685, 0.008995180134661496, 0.010804461531474121, 0.049888489967478175, 0.05302739974909595, 0.03359361059431519, 0.035971777447100194, 0.04135736756558929, 0.027018278870465498, 0.04856624574001346, 0.03868265376825418, 0.030124769945229803, 0.07066465209105185, 0.007064918064445789, 0.010175006647062088, 0.041298375731067996, 0.06745440792292356, 0.019470864308199713, 0.019466625160670707, 0.04529707080551556, 0.017471993441826532, 0.011457483633421361, 0.038278423316244564, 0.01863486845312374, 0.030908410038266863, 0.031506148499569724, 0.06988504928137575, 0.0334914910740086, 0.018561055717457618, 0.0408848018518516, 0.030503395878310715, 0.02231441288521247, 0.012255026060821754, 0.06224637345543929, 0.03370987078441041, 0.023934800310858657, 0.11180032190999814, 0.008739905930789453, 0.020270081868927394, 0.042937441529440026, 0.026246362166213136, 0.013845784406709884, 0.0057266816147603095, 0.04042210882263524, 0.08754070688571249, 0.006885350557110671, 0.01753931090102664, 0.024274189956486225, 0.032648886287850995, 0.006478943704028747, 0.03734240122139454, 0.0675643305959446, 0.0496589958534709, 0.0027486261928320994, 0.047602346033922265, 0.0330651166316654, 0.025974568179143325, 0.01756657274173839, 0.02332901781690972, 0.02522742478842182, 0.05550678027793765, 0.03994814193408404, 0.06028506798403604, 0.044186095241457224, 0.028222030527623634, 0.0073557055189407295, 0.02750949581552829, 0.012932966513160084, 0.07817464375070163, 0.10407110915652343, 0.031421796418726444, 0.04502004870612707, 0.04206635184319956, 0.07695029516305242, 0.026027414182733213, 0.0580174650198647, 0.023268903006932566, 0.015122781374624797, 0.030508752912282944, 0.047625358549079726, 0.021308084384405186, 0.01346490319286074, 0.021112995388518487, 0.034201537258923054, 0.038445973968399424, 0.011679758982998984, 0.029358473207269396, 0.03750732594302722, 0.025744909520394037, 0.0037139699062598602, 0.04011666628399065, 0.05101270714242544, 0.04219373661492552, 0.016789977538532445, 0.021076999105779187, 0.029329638861651932, 0.006323470551121447, 0.03081579679357154, 0.025508292485028505, 0.012254970081682717, 0.030312242385532175, 0.02163600848455514, 0.013841412096683468, 0.06086364122373717, 0.07024840478386198, 0.014768353696646435, 0.1067373107320496, 0.057307317054697444, 0.02279644925147295, 0.05788355613393443, 0.03703496718247022, 0.03664474169324551, 0.02292173565365374, 0.013213730733176427, 0.012415751498857779, 0.018910404560821395, 0.05867695356053965, 0.02644913217851094, 0.039871324984622855, 0.02431064085768802, 0.041003599762916565, 0.045365853900355954, 0.023746274444939833, 0.02590331352049751, 0.07160022974546466, 0.0042878879716486806, 0.0174280057129051, 0.02565190102905035, 0.027298144031582133, 0.04806343772049461, 0.06625610829464026, 0.017437627339469533, 0.06003541459462472, 0.03569170194012778, 0.08905518347663538, 0.07704581253762756, 0.03099027868094189, 0.020956643956846426, 0.030784618109464645, 0.09496867723230805, 0.059458992310932705, 0.02690428838000766, 0.019632576166519096, 0.059097855617957454, 0.021189695290688957, 0.09501596433775765, 0.006465598616549479, 0.07608984490590436, 0.04341396649501153, 0.04417593078687787, 0.06836398411542177, 0.02841110261423247, 0.10426966885903052, 0.024813635474336997, 0.04528251622936555, 0.03635357892406838, 0.044019901659339666, 0.029384946251021962, 0.07814229798636266, 0.021313276873635392, 0.023322834666552286, 0.0953788041536297, 0.01656132311161075, 0.041202369811279435, 0.054033280416790924, 0.048373867491526265, 0.10077894545559372, 0.08753981121948787, 0.07163552713713475, 0.122672169602343, 0.07946390099823475, 0.1539863978645631, 0.18563739662723883, 0.0893022787890264, 0.09227707130568367, 0.09865975845605135, 0.23495322678770336, 0.11589197628200054, 0.1488732700901372, 0.15155731035130365, 0.13332359519387993, 0.15249322727322578, 0.13591649463134153, 0.15277513143207344, 0.1979949035282646, 0.11953390442899295, 0.13418221340647765, 0.08988425827452115, 0.10773099812545947, 0.21679884594466003, 0.15274279245308467, 0.16162647147263798, 0.21769189302410397, 0.09444527567497321, 0.09436845194016184, 0.07797461841255426, 0.11099080927670002, 0.1905136342559542, 0.11816444434225559, 0.08749186593507018, 0.09775848074683122, 0.13025154146764958, 0.17384141816624574, 0.1804193944803306, 0.08064828387328557, 0.15934587456285954, 0.09410879694457565, 0.12490292132965156, 0.12469158481274333, 0.12956836526947363, 0.0679187633629356, 0.06023472747100251, 0.193690494501165, 0.06815913439329181, 0.12631341921431677, 0.1190515745963369, 0.15087133858885082, 0.18356017023324966, 0.12530970307333128, 0.11966446813728128, 0.1431928870401212, 0.18504799396864005, 0.13321314326354436, 0.11312064927603517, 0.13781465563390935, 0.1331417342381818, 0.18923359151397431, 0.0935101458536727, 0.08443832264414855, 0.17439920109297546, 0.13361119904688426, 0.1614680335457836, 0.11998708439724785, 0.09086063623960529, 0.13744391767042025, 0.0809887931016939, 0.13727797514625958, 0.1407725526286023, 0.2737767749599048, 0.1162073186465672, 0.09272174244480473, 0.0841860840363162, 0.07866460710231747, 0.08468628648136343, 0.15105116393949303, 0.25037307079349247, 0.14768875150808267, 0.16782963861312183, 0.2087010054716042, 0.17994655056723527, 0.11415838716285569, 0.1155202883694853, 0.08495264540293387, 0.08196532034448215, 0.10288386286369391, 0.17094723560980388, 0.11399167110877377, 0.16263355314731598, 0.16086246818304062, 0.0963034031114408, 0.13572449636246475, 0.1094524889652218, 0.16124890744686127, 0.12160226915563856, 0.1264675416584526, 0.08073211008948938, 0.18922570693705762, 0.09708525187202863, 0.09065491799265146, 0.11149255199623959, 0.10399395293955292, 0.11818478682211467, 0.18962334202868597, 0.09243659488856792, 0.16119911654719285, 0.09127611680222408, 0.11771294714084693, 0.06445040447371346, 0.08300043908613068, 0.21432102604636125, 0.17531641758978367, 0.14109439535864762, 0.21167967920856817, 0.17704673617013864, 0.11927466333976813, 0.27272083876388414, 0.1478005876498563, 0.11106031161866017, 0.17053103580006532, 0.183185591761555, 0.08709468546190433, 0.14042256426598343, 0.1366123322929655, 0.1784512765173401, 0.1072580185053604, 0.10907447710633278, 0.1070888868666121, 0.09782332833856344, 0.05373781234292047, 0.05698345907564674, 0.17356853852314608, 0.12001225804643971, 0.10680312862885849, 0.11990148041929517, 0.09666211064904928, 0.09522046122167792, 0.09944603126496077, 0.0789231357297727, 0.1853714787534305, 0.1547136109854494, 0.1828519289514848, 0.11279960721731186, 0.10466442017682961, 0.12771194774125302, 0.06585568442408528, 0.1648619978555611, 0.15967600899083273, 0.13186334712164743, 0.059752512989299636, 0.13493073252694948, 0.20249084942042828, 0.11287545386169638, 0.13883316383830138, 0.14383878452437265, 0.09080763586929866, 0.10385977942496538, 0.18165161407419614, 0.0938449553879244, 0.169617890513369, 0.12780813686549664, 0.2044010612049273, 0.13190384209156036, 0.09832471821989332, 0.15735316649079323, 0.16211842293185846, 0.1078849034383893, 0.0807375315842884, 0.09964604981775795, 0.12875385183308805, 0.11469593617532935, 0.19834402336605958, 0.11718216990785939], [0.022345796826162508, 0.055047272970633845, 0.103743295318314, 0.0418023135113929, 0.0827293372047799, 0.09629961010068655, 0.039499565825930665, 0.03391503602532404, 0.018378002236464193, 0.0625387541949749, 0.06355148128100804, 0.02494726107189698, 0.03354719879903963, 0.016917959421074817, 0.03293004745085325, 0.021074315499780432, 0.02061996845129345, 0.07151064276695251, 0.017329526532973562, 0.008651279927497464, 0.008021398414192455, 0.01861120624068592, 0.050933152304164, 0.11362953696932111, 0.024663565580600073, 0.015832459454291632, 0.021940864090408598, 0.012972568361354726, 0.077374318481556, 0.03131416380139334, 0.043824995867908, 0.022371252067387104, 0.03899802327422159, 0.010811653154503022, 0.031443590963525433, 0.028512801442827498, 0.030726528726518154, 0.04445493081584573, 0.005829930047704173, 0.05220592115074396, 0.02675989443170173, 0.039257471316627095, 0.02707285513835294, 0.004537804717464107, 0.06631637577499662, 0.02767999979135181, 0.02728217640625579, 0.01718159232820783, 0.03798121480005128, 0.032117549263473065, 0.019646472563701015, 0.008690176947441484, 0.0029785535090403365, 0.01510642868067537, 0.03977468802726694, 0.022312901448458433, 0.04934081721252628, 0.03482164362711566, 0.008997091058907765, 0.009257938579789229, 0.019502056563006978, 0.012926795237165476, 0.012600000049652798, 0.029225582123867104, 0.0441273680355932, 0.026049749859209572, 0.041646484551685195, 0.04835825100807207, 0.054565350258988995, 0.020299119775050452, 0.05007366556674242, 0.01070944288013769, 0.02690529091549771, 0.03269841255886214, 0.06370213641119854, 0.09790258801409177, 0.02615177438461355, 0.024328988444592272, 0.057703377945082526, 0.01499874347687832, 0.020831642539373467, 0.006666509018811796, 0.04575275117531419, 0.03831549168431333, 0.06589835749140807, 0.00430561724351719, 0.044553158937820365, 0.015017672907561064, 0.02591929810919932, 0.035656089029674015, 0.09719005160565887, 0.029447700562221662, 0.024171395293836082, 0.014327360217326453, 0.03353801143488713, 0.012720496842770703, 0.03933227640975799, 0.022454348858445883, 0.03548195319516318, 0.008659908348428351, 0.03142271922635181, 0.01297217735555023, 0.044640839232930114, 0.022072062228939364, 0.10196509930704321, 0.042173662156398804, 0.04919564803796155, 0.027102776836337786, 0.0053985692211426795, 0.03658934948699815, 0.03368624758773616, 0.0488914913231773, 0.03209036375795092, 0.023572482966950963, 0.027113999805546234, 0.01222284568939358, 0.017474995959284048, 0.0663840121456555, 0.031911060879273076, 0.019783952240166918, 0.04343340652329581, 0.02862025424838066, 0.010103567935792463, 0.015861154700230275, 0.013878885889425874, 0.029958640823939016, 0.0102338644709172, 0.031657831610313485, 0.031581391247787645, 0.04392361414751836, 0.04034245220412101, 0.05162271012419036, 0.014357485475816896, 0.14857820235192776, 0.012711855699308217, 0.1332432295062712, 0.04609214421361685, 0.04232159636116453, 0.022469583665952086, 0.016887968173250556, 0.05281500471755862, 0.011314171100301402, 0.10487877617457084, 0.02488874421188874, 0.0616549284064344, 0.03523549231301461, 0.03079396832202162, 0.03843763477302023, 0.025185140182397196, 0.021640502082716142, 0.04622453318110534, 0.010048023907334676, 0.02571353066845664, 0.06027419785303729, 0.039367841822760444, 0.04094350191631487, 0.0243800057963069, 0.01570654540721859, 0.0473413712877248, 0.023606703184278946, 0.01902002528575914, 0.007356561321233, 0.08672337752899953, 0.015662335458078554, 0.010295949576954757, 0.02714726159216038, 0.03296131434451256, 0.017416541863765036, 0.019897233661530272, 0.017367979112480367, 0.019344085128977895, 0.007242988129811627, 0.0356743721557515, 0.06853653557066407, 0.06089376139321497, 0.02156333059870771, 0.06428901491952793, 0.09354101241167102, 0.14346869795450143, 0.02221769789632942, 0.03952870211963143, 0.0841271939820477, 0.02972600170012031, 0.02539279734316681, 0.010001174456972097, 0.018120345526507924, 0.01835414324887097, 0.02020646581825401, 0.03950585923822863, 0.04719750829307096, 0.05336541196863566, 0.04889873807717647, 0.015000176882105214, 0.048028951178171804, 0.0237650919173445, 0.0037091069305980845, 0.04274937876367143, 0.03557543157200728, 0.04082351317629218, 0.008956501942260988, 0.05260620592162013, 0.09840046986937523, 0.05619971041700669, 0.013197196531109512, 0.04799607954919338, 0.052659097726323774, 0.07250061857381038, 0.027997537216703807, 0.05271435083289232, 0.03207728499546647, 0.04924106238675969, 0.03455969179049134, 0.0983214612518038, 0.027877161711720482, 0.0556880882275956, 0.024518920574337244, 0.03844469153721418, 0.05241183956552829, 0.016340020611616116, 0.042126432726425786, 0.02079468104057014, 0.05853205919265747, 0.03126736863383225, 0.04200148728809186, 0.04499091919777649, 0.05787072503673179, 0.005525420070625842, 0.06161904747464827, 0.008702897782703596, 0.019674490970958556, 0.004016316628881863, 0.034967501514724324, 0.045921004111213345, 0.038176113806132755, 0.047954458211149485, 0.027900152174489837, 0.03537879890895315, 0.019158824712836316, 0.016264160396531224, 0.04122445951881153, 0.02637609127642853, 0.10339408727096659, 0.04949765379673668, 0.03258107689076236, 0.05800282223416226, 0.045723112765699625, 0.0287172779706972, 0.04068525488089238, 0.05738287192902394, 0.020999847977821316, 0.03656133616875325, 0.03878123812111361, 0.028898755554109812, 0.021441930505846227, 0.05807984274412904, 0.03315407257261021, 0.026241810892575552, 0.015103288759876574, 0.07981016420360122, 0.05712032637425831, 0.06160344795456954, 0.03708030689241631, 0.05572238138743809, 0.0039390043488570625, 0.010510517616889306, 0.021295299088316302, 0.05714467899607761, 0.058241632633975575, 0.029199207467692237, 0.016929336757000004, 0.04446578059079392, 0.02431082066946796, 0.038575129716524055, 0.038732607516327074, 0.016508076772359864, 0.04126678653327482, 0.017364808657605733, 0.033031362907162735, 0.020372315043849603, 0.013918979675509036, 0.03298712581662195, 0.0586417375930718, 0.03143346043569701, 0.022176975617185235, 0.01666710672101804, 0.032352726108261516, 0.03392201815066593, 0.04968785734048911, 0.0739521271150027, 0.046795747708529234, 0.009507048293016851, 0.011883009906991251, 0.037313600802528005, 0.052020738766129525, 0.06229196422334228, 0.03376842157116958, 0.025461041002667377, 0.03170545119792223, 0.029846241498099904, 0.005152057024783322, 0.024513879059148685, 0.04681076029581683, 0.01176000592697944, 0.033560420053878, 0.03361667399959905, 0.01868991969552423, 0.07045678967343909, 0.02078680324900363, 0.06418885636542525, 0.08125445313219513, 0.055074845241116624, 0.008301297502060021, 0.022952001708160554, 0.026387924927153757, 0.03088686315874968, 0.03053189434909395, 0.008062828914262354, 0.025697970164141486, 0.021602636436000466, 0.02427974546195141, 0.033483582748366256, 0.028413733633767282, 0.03620529527376805, 0.04937736310863069, 0.07217427715659142, 0.045084173658064434, 0.0871788848723684, 0.046285950778318305, 0.026656431412058215, 0.011739742326816278, 0.024875636611666, 0.037420045983578475, 0.01557832773375724, 0.07266596398715462, 0.03582495603976505, 0.03350207622029951, 0.004667900236589568, 0.007116420144614364, 0.023372160769732933, 0.02355756876724107, 0.00699795938063679, 0.03047626804826515, 0.07917782384902239, 0.027508394892460535, 0.045535514796418805, 0.013671361042984893, 0.0336880389201854, 0.026843367809695855, 0.022579256977353777, 0.011672512228999819, 0.050937847766493044, 0.05487483347366963, 0.16203398603413785, 0.21176288117255482, 0.4396826039467539, 0.12419128737279347, 0.10898171458393335, 0.19394016824662685, 0.13280389165239675, 0.09273156084652458, 0.0977961869378175, 0.12380707370383398, 0.221881629633052, 0.1605500570897545, 0.06872356017785412, 0.22717000943209442, 0.15086901799908706, 0.2311901801398822, 0.09722334731902395, 0.16468034046036856, 0.09695687983185053, 0.10110938522432532, 0.10910272451915912, 0.11898458961929594, 0.21412733143993787, 0.14204019175044127, 0.1828750805663211, 0.10050619473414761, 0.1555924495416028, 0.09152154970381941, 0.16013852560094424, 0.15351767944438116, 0.22752725811941282, 0.06286123474793774, 0.22697163293404238, 0.13869164857481206, 0.06755154021084309, 0.09060878439673356, 0.1209488535033805, 0.10122371158961739, 0.11999537609517574, 0.1140362915716001, 0.20998537726700306, 0.19165471302611486, 0.06884109601378441, 0.1637642096195902, 0.09600843715348414, 0.19273529361401284, 0.16495510643082006, 0.08627595832305295, 0.14906547191951955, 0.10805347867842231, 0.09694082569330931, 0.2201113724814994, 0.08826880210212298, 0.1495589432971818, 0.13269624885703835, 0.10857734842492, 0.12329624540039472, 0.13275552567626747, 0.1708198610161032, 0.13712515548935958, 0.08548894591097321, 0.058531258521335464, 0.123771016352943, 0.15695330580430372, 0.07148684654384851, 0.14662388579121657, 0.14934358985296317, 0.11201534287205764, 0.07777171608592783, 0.08641314453312329, 0.09116816188075713, 0.12920362555554935, 0.1938167970095362, 0.07659449854067393, 0.12955725086586817, 0.2162734969918217, 0.06844624291573252, 0.09275274470980678, 0.1770133658179215, 0.1374812913792474, 0.12002804077097348, 0.14385315589606762, 0.1073281518848879, 0.2152451364589589, 0.155568660103849, 0.10234237156276192, 0.14769348768251284, 0.0711642981373838, 0.10031313116529159, 0.078007283088352, 0.21637223740773542, 0.16174628718623094, 0.2601584142872265, 0.12999510951340199, 0.15848152951470443, 0.12919750516968115, 0.13899412591542515, 0.08751093955444438, 0.16521977580019406, 0.07885946878897292, 0.11426746845245361, 0.10442851390689611, 0.12220467254519463, 0.10014015901833773, 0.11580812292439596, 0.17608192722712243, 0.12088215351104736, 0.12690046057105064, 0.10253871245575802, 0.09896922470735652, 0.08260058518499136, 0.11343745049089193, 0.08454811639551606, 0.11601394973695278, 0.08670370679880891, 0.0603885038622788, 0.08260767587593623, 0.15435837076178618, 0.14532329700887203, 0.10162350442260504, 0.10430744968886886, 0.1149650024516242, 0.14208036102354527, 0.14051346081708158, 0.08101900148072413, 0.1136894380407674, 0.1834786103240081, 0.09693238471767732, 0.18276715278625488, 0.09369353351316281, 0.1572706973446267, 0.14659036616129534, 0.1844543301101242, 0.2939704656600952, 0.10763135525797095, 0.2834921750639166, 0.14941204046564444, 0.14770879543253354, 0.06951678118535451, 0.09227572102099657, 0.16164680038179668, 0.11217280370848519, 0.12539906613528728, 0.08700701873749495, 0.08484631218016148, 0.14451711598251546, 0.0625194770150951, 0.13412670924195222, 0.15572883508035115, 0.0948964539649231, 0.18361821211874485, 0.1244227085262537, 0.1299993707133191, 0.1997100229242018, 0.09892991038837604, 0.14273958493556294, 0.0697383296542934, 0.1585376307900463, 0.13469462948186056, 0.1122801818751863, 0.0934895183891058, 0.06459714445684638, 0.13530787586101464, 0.08195883354970387, 0.05045378427686436, 0.083330322456147, 0.14138795674911567, 0.06238110336874213, 0.11781508023185389, 0.1745499037206173, 0.14397298518036092, 0.06946992834231683, 0.11603514717093535, 0.10578613355755806, 0.19068396011633532, 0.20080646766083582], [0.04090530378744006, 0.03356210282072425, 0.008384622450518821, 0.06433213581996304, 0.06940375082194805, 0.04087256447279027, 0.03764729414667402, 0.022965655529073307, 0.06025097159934895, 0.03557477339303919, 0.05179169248523457, 0.02792963112837502, 0.009403285021627588, 0.053493570270282884, 0.03279861182506595, 0.024902686410184418, 0.030679988009589057, 0.06285817455500364, 0.01841157954186201, 0.0511199054973466, 0.043023846178714714, 0.04331058489957026, 0.008327234503147858, 0.04320618210892592, 0.06115581840276718, 0.01038641865099115, 0.06512053244348083, 0.042889285899166546, 0.021038541437259743, 0.012235054230716611, 0.018259904912805984, 0.02062485899244036, 0.03445844418768372, 0.04077045852318406, 0.058446217727448256, 0.00883659632277808, 0.02083345762054835, 0.017006900094981705, 0.03748448984697461, 0.01994799486627536, 0.010279825888574123, 0.011246152205525764, 0.018552516354247928, 0.08583205392850296, 0.014128033770248294, 0.02792239115972604, 0.026746686747563735, 0.041799012438527176, 0.0213589083536395, 0.03387375056211438, 0.09579798273210015, 0.027041169249319603, 0.01131579025448965, 0.02581524646042713, 0.016683311833600913, 0.026179543430251733, 0.042863023201269765, 0.05028819798358849, 0.05054477243019002, 0.021501017335270132, 0.07562553017799344, 0.027024640136265328, 0.028266259136476686, 0.03187055912400995, 0.03925740007045014, 0.036010206277881346, 0.018694593105465174, 0.026628648795719658, 0.01625912057768021, 0.035612750998032947, 0.039699659017579894, 0.037613805050828626, 0.04429257095658353, 0.055229412125689645, 0.0197311231999525, 0.026804896570476036, 0.06849888366247926, 0.015353890401976449, 0.05535105309848275, 0.03632126030113016, 0.047090710273810794, 0.044118519938950024, 0.04506325103076441, 0.06854773818382195, 0.03094912213938577, 0.04025010358808296, 0.052601744553872516, 0.053996863442340066, 0.04997088447479265, 0.03106711259377854, 0.06498576181807689, 0.02353468008472451, 0.005973588633683643, 0.02753578226215073, 0.06340880572263684, 0.024936784491209046, 0.03566294223336237, 0.13851148395666055, 0.016359211278281043, 0.008697449994672622, 0.09744651748665742, 0.09233677560197455, 0.029967594093510082, 0.039073873311281204, 0.04128788897235479, 0.024026149784081748, 0.02814459441495793, 0.08080001108880554, 0.023608301134247865, 0.0393383934029511, 0.04849263486851539, 0.003851142545629825, 0.03413823672703334, 0.021388400878225054, 0.009384420051771616, 0.04853669893262642, 0.04015717143192887, 0.04190325916611722, 0.04062146919646433, 0.04772569691496236, 0.07858791228915964, 0.019236986857971976, 0.0765193100752575, 0.03871929805193629, 0.020771631205986654, 0.08813900513840572, 0.008659642023433532, 0.05410808211724673, 0.020790981328380958, 0.007634835317730904, 0.02335274957918695, 0.027390954051432864, 0.005525116426204997, 0.03179088214944516, 0.028664077432560067, 0.04772292849208627, 0.08667843136936426, 0.11423352813082081, 0.05162072880193591, 0.025990342421989356, 0.028207703260704875, 0.05276893558246749, 0.042490683895136626, 0.006204732860039387, 0.015237837165061916, 0.06488390692642756, 0.05585560156032443, 0.030186116296265806, 0.010180819995834358, 0.05637181064646159, 0.023948834111381854, 0.06564947763191802, 0.024452644666390758, 0.04708995031458991, 0.05304942838847637, 0.05252827278205326, 0.03759693667026503, 0.02379728331496673, 0.0190430632459798, 0.05082756546991212, 0.018717856678579534, 0.034965442160942724, 0.047224714154643674, 0.07631270294742924, 0.04523373295419982, 0.07159577855574233, 0.08146131131798029, 0.031772955254252465, 0.017960811765598397, 0.07095714818154063, 0.006141962433632995, 0.04856881738773414, 0.03108605389882411, 0.02908289638747062, 0.033770348610622544, 0.029918909205922058, 0.022984954761341214, 0.03919952103335943, 0.05268452243347253, 0.02432375693959849, 0.020914496754163077, 0.02307988011411258, 0.04589482283751879, 0.06036577293915408, 0.011724840849637985, 0.026386756150584136, 0.017057649425363967, 0.028433168573038917, 0.05666277324780822, 0.04524233677823629, 0.02301860331291599, 0.018227252111371075, 0.05370808572375348, 0.026193994529811398, 0.022224688503359045, 0.06218592955597809, 0.015054154342838695, 0.059783515254301686, 0.03289090955097761, 0.019625602522864938, 0.02255937929398247, 0.0345130255445838, 0.10153383601989065, 0.023483593183170472, 0.032712956956986866, 0.059921352857989926, 0.0038698908922794673, 0.02326449592198644, 0.04533433594873973, 0.0503262943322105, 0.060518226187144, 0.06932322228593485, 0.025046678326491798, 0.030633196234703064, 0.044213633585189066, 0.030120966756450276, 0.04550379328429699, 0.04194691950189216, 0.08154926981244769, 0.04668708032529269, 0.03263928841001221, 0.02686665513153587, 0.05774851409452302, 0.03495930141902395, 0.02115214346641941, 0.050178400839545896, 0.05676852632313967, 0.05042478029749223, 0.06625325844756194, 0.04972182819619775, 0.02477328638945307, 0.01812305288123233, 0.0379798984421151, 0.03363573065559779, 0.05088235717266798, 0.031953411642462015, 0.03802229670275535, 0.022423231242490665, 0.029509308149239848, 0.03139712488544839, 0.028513201778488498, 0.01325062268214034, 0.06121291033923626, 0.007720579243531185, 0.04233292450330087, 0.027377600482265865, 0.04134139485125031, 0.028717763123235533, 0.02284837414377502, 0.015622172970324755, 0.023414908475907784, 0.026474958917658244, 0.050659984283681424, 0.0463555854346071, 0.02817568149683731, 0.055694127189261575, 0.018688247106703262, 0.030157319270074368, 0.028984006693852798, 0.0361375978349575, 0.03873750653916171, 0.021908107812383344, 0.012469722174241074, 0.004622697081815983, 0.03395979219515409, 0.01298106786063207, 0.04229698250336306, 0.03569633972698024, 0.03642640948029501, 0.058520490170589516, 0.043747327356998406, 0.026402124968756522, 0.018930049845948815, 0.1053252454314913, 0.024662909097969532, 0.011194614926353097, 0.03622732391314847, 0.02485807442904583, 0.017790348501875997, 0.037702940803553374, 0.028964804152825048, 0.03218818815158946, 0.06301205951188292, 0.026211136020720005, 0.01191380267430629, 0.04796848013730986, 0.0257261514198035, 0.03589865512081555, 0.013593918993137777, 0.005839540648074555, 0.0414667541959456, 0.0363376028170543, 0.023876320770276443, 0.05782135482877493, 0.014138969210242587, 0.016989906185439656, 0.033555212297609875, 0.024235175889251486, 0.04540831322914787, 0.04145705114517893, 0.02868376512612615, 0.09622435378176825, 0.03157191889892731, 0.04700304015672632, 0.026089276220383387, 0.047480386149670394, 0.06387874550585236, 0.01530230138450861, 0.029872263316065073, 0.07411472446152143, 0.09387762684907232, 0.0921522615743535, 0.0906188470710601, 0.04596016915248973, 0.055820456839033535, 0.10105873937053339, 0.01885142968967557, 0.03329052257218531, 0.04479695317734565, 0.01998333297004657, 0.019646216416731477, 0.006585238335121955, 0.025196636261950647, 0.051944115199148655, 0.07003001828810998, 0.044731705249952416, 0.033771773534161706, 0.009303369043794061, 0.08030297740229539, 0.07275895042611019, 0.04735454504511186, 0.037651348393410444, 0.056424434429832866, 0.012696125561238399, 0.05279572753767882, 0.00903711190247642, 0.08501906719590936, 0.010615747372087623, 0.021539061097428203, 0.03108119898076568, 0.024741671746596694, 0.043202772470457215, 0.037205920687743595, 0.007520966115407646, 0.024398436503750936, 0.04479176238445299, 0.021758275405902947, 0.029227217393262044, 0.01946879647273038, 0.02156307784441326, 0.055238056661827226, 0.04542024526745081, 0.08264336681791715, 0.09833504552287714, 0.10259545833936759, 0.11675698629447392, 0.17608152010611125, 0.09037965669163636, 0.13783123902976513, 0.1158792469650507, 0.1538087981087821, 0.12010115970458303, 0.1018696226445692, 0.09383942532752242, 0.1740488191800458, 0.1428088362195662, 0.12401936016976833, 0.11966985570532934, 0.14502791714455399, 0.19900134738002503, 0.1370815663997616, 0.15407259895333222, 0.1796291997390134, 0.14305696290518555, 0.15365489279585226, 0.0994579599105886, 0.13998785402093614, 0.20422840118408203, 0.2330773760165487, 0.10289182207946267, 0.09929318446666002, 0.10889210046402045, 0.09873447873230491, 0.06721193343400955, 0.16662195484553063, 0.12314216366836003, 0.17829467063503607, 0.1294044583503689, 0.07456541420625788, 0.10282664879092149, 0.16014571807214192, 0.11101065642599549, 0.15990561167044298, 0.11401543340512685, 0.16061845341963427, 0.13308472372591496, 0.10104079211929015, 0.07582007973854031, 0.11153541505336761, 0.12914049465741428, 0.1034384702465364, 0.1125991747581533, 0.2092938550880977, 0.1546193760420595, 0.20112106363688195, 0.11302849743515253, 0.11420317047408649, 0.08250847405620984, 0.09815258745636259, 0.15934560314885207, 0.1706144277538572, 0.07783371383058173, 0.16968012574527944, 0.06776208284177951, 0.08654705341905355, 0.1446320598146745, 0.14601770974695683, 0.11065009648778609, 0.10289790175322976, 0.10051103947418076, 0.14130056143871375, 0.07799203640648297, 0.10569352709821292, 0.19111196643539838, 0.1846038792282343, 0.11480701235788209, 0.08743882485266243, 0.11457067861088685, 0.146120942064694, 0.1333265264651605, 0.07968958853078739, 0.10426336526870728, 0.08469398106847491, 0.1542677049125944, 0.1466415412724018, 0.12475637133632388, 0.11634966172277927, 0.1098124042951635, 0.11390012316405773, 0.1311208533921412, 0.12694736091153963, 0.07483328626091991, 0.12857127163027013, 0.10260674237672772, 0.10704179653631789, 0.14197404815682343, 0.12167947287006037, 0.14476493054202624, 0.10094485405300345, 0.24950731439249857, 0.07417415734380484, 0.10706310932125364, 0.1869114682610546, 0.16882988065481186, 0.08243094464497906, 0.17455956605928286, 0.11293194868734904, 0.11280844174325466, 0.25615429771798, 0.11486419928925377, 0.11169423295983247, 0.15983710677496024, 0.1666167029844863, 0.09370923481349434, 0.06517935464424746, 0.11537498688059193, 0.12582331337034702, 0.10275165710066046, 0.09766090062579938, 0.12456680222281388, 0.13543062284588814, 0.08646482854549374, 0.14030482486954757, 0.1053005535421627, 0.32773890080196516, 0.15686983242630959, 0.11423333814101559, 0.17738080610121998, 0.10777133024696793, 0.12684167229703494, 0.1093581183148282, 0.1328647562435695, 0.10616967547684908, 0.09552418706672532, 0.09606523731989519, 0.11455287385199751, 0.1999719917242016, 0.256421586232526, 0.21654769299285753, 0.17713624850979873, 0.11959582753479481, 0.1374264114669391, 0.07546744508934872, 0.09850310507629599, 0.14843843770878656, 0.09782790844993931, 0.057441002024071555, 0.12695882815335477, 0.11607929265924863, 0.22283015373562062, 0.17475541840706552, 0.18332726987344877, 0.19560270117861883, 0.12278395146131516, 0.13666457948940142, 0.11955242843500205, 0.14076616082872662, 0.13355616985687188, 0.12856870676789964, 0.07360724133572408, 0.14376535346465452, 0.21731784380972385, 0.16909651777573995, 0.08042186352291278, 0.06710503024182149, 0.1377138253301382, 0.0728057829130973, 0.07301702443510294, 0.12403434222298008, 0.11009984529976334, 0.06934868091983454, 0.1529542375355959, 0.065547378467662, 0.11017809395811387, 0.0768894577132804, 0.13611915947071143, 0.16562779247760773, 0.09577107881861073], [0.06469881614404065, 0.03178576599540455, 0.008916702470742166, 0.006601865411669548, 0.06152015099568026, 0.028092576224090796, 0.03143942815118602, 0.012924689234101346, 0.058539550219263346, 0.02852190738277776, 0.07407671292977673, 0.0038868733515430775, 0.04234580309795482, 0.0150653976680977, 0.06368015187659434, 0.030292456304388385, 0.031002902824963843, 0.02616639681426542, 0.03666070083688412, 0.030262885748275688, 0.024843667434262376, 0.03671508541862879, 0.019989416036488752, 0.027532788226380944, 0.005726579410423125, 0.06677284663809196, 0.012968733790330589, 0.04147159554330366, 0.055084952020219395, 0.04756289940061314, 0.015500141839895929, 0.07400446930634123, 0.049255236983299255, 0.01663236233538815, 0.02482256160250732, 0.012763131742498704, 0.027433362490098392, 0.03279264410957694, 0.011414708785845764, 0.046531767052199156, 0.0038716707744502594, 0.018769813801294992, 0.0020885505073238164, 0.05413503013551235, 0.031559413498533626, 0.009100548141369862, 0.11989046101059232, 0.005349304610198098, 0.03267101670748421, 0.09476033984018223, 0.04048488688256059, 0.00314341822273231, 0.010378357654969608, 0.012821285586271967, 0.004034319859264153, 0.06176341937056609, 0.0499918444215187, 0.040466861599790196, 0.03633769441928182, 0.042206798414034505, 0.015212828060612082, 0.03975610973845635, 0.02161525040199714, 0.0630391805565783, 0.0355082498198109, 0.0756243902391621, 0.04696478435237493, 0.11370732422385897, 0.010663511996556605, 0.011934846589740897, 0.018710542071078504, 0.12156915664672852, 0.014227312773333063, 0.03364858889420118, 0.021066663321107626, 0.04328814913917865, 0.07431766071489879, 0.0344000698200294, 0.0672590984031558, 0.0607172337227634, 0.004043119610287249, 0.023424918563770394, 0.08155498986265489, 0.018033057085371444, 0.02281682226540787, 0.05550470056810549, 0.03691719046660832, 0.058254165175770006, 0.016268328297883272, 0.04574013042396732, 0.02126359793224505, 0.034817908291838, 0.0284394263622484, 0.016879796915288483, 0.021923230661611472, 0.014156117486501378, 0.03693152791155236, 0.022602739378011653, 0.008709002901533884, 0.01881404241014804, 0.028316804906353354, 0.016085244282814007, 0.01904915988312236, 0.05056935914659074, 0.12921028876943247, 0.043642524230693064, 0.029243760077016692, 0.03310109255835414, 0.01988060785723584, 0.04135859232129795, 0.058695443639797826, 0.01811958895996213, 0.010370199119539132, 0.004255089285184762, 0.0058218050149402446, 0.027343415888026357, 0.007441579214563327, 0.03977687291002699, 0.046521253152085204, 0.014142065874433942, 0.027207412025226013, 0.08981516305357218, 0.04133628208988479, 0.05303166773436325, 0.08280136369700943, 0.08660457961793457, 0.025216205211888467, 0.03167490694405777, 0.028327973592760305, 0.022638236937512244, 0.07480349178825106, 0.02204932112778936, 0.018202663698632802, 0.02133238102708544, 0.023718125419691205, 0.01052177366467991, 0.01919905505409198, 0.008709956243235086, 0.028412256123764173, 0.04591462927471314, 0.05896026907222612, 0.027480831103665487, 0.028842711954244545, 0.03808597042890532, 0.08603342955133744, 0.03340105592672314, 0.011967780135039772, 0.06415115695978914, 0.01654647506906518, 0.008919873773785574, 0.015609777831871594, 0.030713982614023343, 0.026234233352754797, 0.010677483032590576, 0.051809907757810185, 0.043515556758003573, 0.04210791550576687, 0.039040139942829094, 0.052856914432985444, 0.04895932446899159, 0.016147795033508112, 0.02142718424355345, 0.03265336801164916, 0.04578081199101039, 0.05019917079646673, 0.06028920026229961, 0.030263391256864582, 0.02945060469210148, 0.020870515810591832, 0.06195625902286597, 0.012271254922130277, 0.005859705860660012, 0.02578501942168389, 0.03307715384289622, 0.04299661996109145, 0.04794101982510515, 0.07796314438538891, 0.029368468028094088, 0.03298621318702187, 0.07654229884168931, 0.045897913564528735, 0.03363329471488084, 0.02922411648822682, 0.043740314697580676, 0.02643636554213507, 0.012387380253390541, 0.0629052377438971, 0.0029411793761287947, 0.0237186784257314, 0.030527626363826648, 0.028703965113631318, 0.06310643016227654, 0.04845309663297875, 0.11091711358832461, 0.023555563696260964, 0.025421657133847475, 0.0330183282494545, 0.053467738442122936, 0.01765104186987238, 0.053366901353001595, 0.01477993798575231, 0.03522652547274317, 0.01527898692126785, 0.024501594182636057, 0.017575393696980815, 0.02522206266543695, 0.05863704213074275, 0.02939220318304641, 0.046062746683933904, 0.036973946528243165, 0.03728976047464779, 0.03832066212115543, 0.05399210691185934, 0.032055575267544816, 0.043062668559806686, 0.06336138969553368, 0.025352767169741646, 0.02117939682544342, 0.04234764192785535, 0.05560772932533707, 0.042622462181108337, 0.04414723214826413, 0.03864882879757455, 0.01381193399096706, 0.018775940972513387, 0.06779773307165929, 0.04141959261947444, 0.01088472713516759, 0.08440204137670142, 0.022214629221707582, 0.028239080416304723, 0.03102832074676241, 0.038754123861768415, 0.05029381964621799, 0.04780257832525032, 0.041120843828788826, 0.0790236946195364, 0.037011869850435426, 0.015678145324013064, 0.04453698266297579, 0.02040576851660652, 0.06946558571819748, 0.04540469663749848, 0.05468166133921061, 0.019110158484961306, 0.030772801422114884, 0.0638000083022884, 0.08742925750889949, 0.00923486754098641, 0.0541151762008667, 0.02627085049503616, 0.04181196567203317, 0.031763795031500716, 0.03716316619621856, 0.04919271676668099, 0.053700475953519344, 0.027725020589839135, 0.05237252185387271, 0.03430395533463784, 0.021447051748899475, 0.015011790008949382, 0.030033513770571778, 0.06615314739091055, 0.061292217512215884, 0.054943334976477284, 0.055145205929875374, 0.022465760121122003, 0.01983017913464989, 0.03149424020999244, 0.03943220426195434, 0.04264561040326953, 0.05058460582845977, 0.023644999700731466, 0.02499776952234762, 0.03765507015798773, 0.03474313034010785, 0.02856672801343458, 0.05475840704249484, 0.010485489004557686, 0.06192020845732518, 0.028344585826354365, 0.040981635584362915, 0.03950743683214698, 0.1040920555325491, 0.020094080063115274, 0.06131832075438329, 0.06550060704882656, 0.03603291345228042, 0.01621108199469745, 0.02538150821679405, 0.046737210492470434, 0.05646035946639521, 0.038065814546176364, 0.00944901573737817, 0.026428930494668226, 0.0340862948713558, 0.05916079652628728, 0.08423394111118146, 0.015496062148096306, 0.01167517208627292, 0.05742801486381462, 0.02448090904259256, 0.016529489641210864, 0.03035924450627395, 0.04010968755132385, 0.010962322703562677, 0.023365005617961287, 0.025884842100952352, 0.010055442839594824, 0.020069454330950975, 0.019239432976714203, 0.009337191469967365, 0.0524173560552299, 0.021584492409601808, 0.018267565573166524, 0.010886494718891169, 0.009473681333474815, 0.02270557644910046, 0.06217083893716335, 0.02226877461985818, 0.024590212552409087, 0.03476360174162047, 0.06717394225831542, 0.057304847187229564, 0.03244463706921254, 0.014069387140417737, 0.028906680843127624, 0.05781758217407124, 0.030578784511557648, 0.01959493274002203, 0.01788690742770476, 0.032868419507784505, 0.065940962705229, 0.034269278802509816, 0.01304924112212445, 0.0404287075756916, 0.03645458225426929, 0.022452930720256906, 0.039642953846071444, 0.029381003962563615, 0.01951410564860063, 0.019617314217612147, 0.04545842982562525, 0.05104264071477311, 0.009911485698207148, 0.05168562049844435, 0.017100670241883824, 0.0349033019239349, 0.04352636242817555, 0.010656452687856342, 0.04613486138571586, 0.03773492694433246, 0.1324800404586962, 0.1377655839813607, 0.12864836677908897, 0.14211474917829037, 0.0769992039671966, 0.08347214984574489, 0.09299010304468018, 0.14178408549300262, 0.1544633944119726, 0.1714456467224019, 0.12368915788829327, 0.12687114785824502, 0.12905805265264852, 0.11458351649343967, 0.11693731376102992, 0.11353876255452633, 0.16222138383558818, 0.17546751376773628, 0.13698556726532324, 0.15034856806908334, 0.13164059764572553, 0.13260869069823197, 0.1037078011514885, 0.1213385768766914, 0.15435516807649816, 0.15478465360190186, 0.14118911884725094, 0.17212277038821153, 0.11299320682883263, 0.08874433979924236, 0.09706932665514094, 0.1959717563752617, 0.09383669083139726, 0.1389174378876175, 0.14253260461347445, 0.08202313152807099, 0.09830014168151788, 0.15394058318010398, 0.13891818427613803, 0.1928463562258652, 0.08761061634868383, 0.0948355079495481, 0.14481683847095284, 0.11017575301229954, 0.16141143015452794, 0.10375739527600152, 0.22470391461891787, 0.14512520549552782, 0.08662608917802572, 0.195491367152759, 0.1556434618043048, 0.12679870745965413, 0.13960822724870273, 0.06397388290081706, 0.13512456284037658, 0.11743530418191638, 0.14521977970642702, 0.13350789887564524, 0.11979435331055097, 0.17517929923321518, 0.17106922263545649, 0.12577072690640176, 0.11053723575813429, 0.17137818677084787, 0.1688750982284546, 0.2057786365704877, 0.10858405913625445, 0.22364914550312928, 0.10225870819496256, 0.13528084302587168, 0.14308615348168782, 0.33228082422699246, 0.11514037661254406, 0.10025299939193896, 0.07321520415799958, 0.11877607580806528, 0.13621008316321032, 0.11000534572771617, 0.11940933897026948, 0.21706898430628435, 0.12489822586732251, 0.148167308686035, 0.13933575472661427, 0.07260558115584509, 0.12892006577125617, 0.2678852453827858, 0.12576670997909137, 0.10594307870737144, 0.10605841608984129, 0.19196177726345404, 0.11563527291374547, 0.0837066854749407, 0.0728569987363049, 0.07400118519685098, 0.2211477125861815, 0.19783647917211056, 0.1627940945327282, 0.05213379627093673, 0.13078638991074903, 0.2035848514309951, 0.09101151528635196, 0.1932346818170377, 0.09339661337435246, 0.1405793737087931, 0.18613845402640955, 0.12708583633814538, 0.08832666078316313, 0.16181963682174683, 0.08919678694967713, 0.19452824097658905, 0.11525701678224973, 0.09396557177283935, 0.1557118852755853, 0.1160147368375744, 0.10732621806008474, 0.17097572050988674, 0.1029361846989819, 0.06409443821758032, 0.12952518330088683, 0.15671760988022598, 0.1519260805632387, 0.23812526943428175, 0.16347656505448477, 0.08799915907106229, 0.23362511662500246, 0.09724586789629289, 0.1565115659364632, 0.08855773588376385, 0.07924010657838412, 0.09176565946212836, 0.2120937891304493, 0.2194653121488435, 0.10356304927596025, 0.11477274633944035, 0.1342601499387196, 0.1288497288312231, 0.10430322241570268, 0.10423591852720294, 0.1403867376169988, 0.09569536788122994, 0.10953102939363037, 0.1480104721018246, 0.11673658953181335, 0.11559294589928218, 0.18907193733113153, 0.09847987203725747, 0.1413261964917183, 0.18466615517224583, 0.05452539133174079, 0.10086769105068275, 0.06644951113100563, 0.15931669755705766, 0.17712233854191645, 0.08612619885908705, 0.10926532186567783, 0.15867470843451364, 0.19550139590033463, 0.13943981485707418, 0.1145885240818773, 0.09047081108604159, 0.18086109363606998, 0.08922399620392493, 0.1216676120779344, 0.12758331107241766, 0.12857147519077572, 0.13207690923341683, 0.1561301342610802, 0.19451180685843739, 0.0876788634008595, 0.09789291210472584, 0.06505863647907972, 0.09226015542766877, 0.21516117453575134, 0.08222192193248443, 0.10424220176147563, 0.1592390052974224], [0.02282708341122738, 0.03745779627934098, 0.035755036398768425, 0.053415318219257255, 0.019193823549098203, 0.032989476940461566, 0.0450804756422128, 0.03618733784449952, 0.02256493310311011, 0.020374533853360584, 0.08072084640817982, 0.03313442219847015, 0.023663063999265432, 0.012022665136360695, 0.025359594928366796, 0.048260613211563656, 0.06708264537155628, 0.03871860255354217, 0.07945092740867819, 0.06795822017427001, 0.022467218971412097, 0.01521205113801573, 0.05037371035931366, 0.0787142962217331, 0.057767357011990886, 0.0456058008463255, 0.030107850674539804, 0.043431937494980435, 0.0396286706839289, 0.04582422126882842, 0.026937816491616622, 0.03910965924816472, 0.028469069860875607, 0.008909174124710262, 0.008278157761586564, 0.030517407626445805, 0.08365045527794532, 0.06741339048104626, 0.01623272556545479, 0.02847693408174174, 0.06788007329617228, 0.008679919194297066, 0.06989676079579762, 0.05572852212935686, 0.02151262367676411, 0.040146470934684785, 0.060847844928503036, 0.048972844279238155, 0.05250703802864466, 0.005174918141814747, 0.014999062388337083, 0.0369344693608582, 0.03316273067944816, 0.04799785391826715, 0.044386456454438825, 0.022418769874743054, 0.030792791063764265, 0.027527331108493463, 0.02186519216879138, 0.018563547637313604, 0.019542661794860448, 0.029176619036921432, 0.0423620777603771, 0.05006370467266866, 0.048667367813842635, 0.008727383567020297, 0.009632415271231105, 0.0461059727572969, 0.023924783437645862, 0.03677003996978913, 0.027346257253416946, 0.07012282830796071, 0.05540860304608941, 0.04587024969181844, 0.0839675414775099, 0.03292197288413133, 0.009711722444210733, 0.025411647045984864, 0.01355797953770629, 0.038882081995585134, 0.03201437122853739, 0.031809602930609665, 0.021923191645847898, 0.0919614846685103, 0.025176797594342912, 0.02823446468184037, 0.019016279772456204, 0.05063110922596284, 0.03224707481318286, 0.023574691598436663, 0.04333973815664649, 0.0032337492573008475, 0.046790624769138436, 0.027763395137818794, 0.015127777088699597, 0.035473301873675415, 0.05032758694142103, 0.03355768555775285, 0.020147535051884394, 0.025566970497103672, 0.09850849264434405, 0.0498628718778491, 0.029694568565381423, 0.0451759081999106, 0.007880686366531466, 0.05983808304050139, 0.04046092441837702, 0.034917384918246946, 0.06431914865970612, 0.021164911799132824, 0.05803131391959531, 0.0038088375835546424, 0.05109388028670635, 0.044497539422341754, 0.04196713984544788, 0.06504512006150824, 0.0318048667561795, 0.04418365590806518, 0.0819573136312621, 0.040454478335699866, 0.05034133066822376, 0.06287770279284034, 0.030472515749612024, 0.04564129840582609, 0.044526967486100535, 0.029210583107279878, 0.008995583014828818, 0.044884392592523775, 0.025885715714788864, 0.09765472595712968, 0.03624331359086292, 0.02685314549931458, 0.021745254318895083, 0.03183595044538379, 0.06802077431763921, 0.025990859804941074, 0.06798398414892809, 0.02781327933605228, 0.06362869178078004, 0.08120842810188021, 0.03977047771747623, 0.09315890898661953, 0.03021318305815969, 0.039821299990372996, 0.014269024865435702, 0.04120638334591474, 0.03396379555176411, 0.05519369404230799, 0.02454650471918285, 0.022096674390403286, 0.05685051031676786, 0.03912210697308183, 0.027071014612114856, 0.053764851963413615, 0.05734384259475129, 0.02131727514123278, 0.04406584526545235, 0.043627823769514046, 0.0644660514912435, 0.03793460622962032, 0.027579227163057243, 0.03808984147118671, 0.016006897236885767, 0.07361804361322097, 0.0354360604791769, 0.06441068981907197, 0.008479068587933267, 0.1281653991235154, 0.020640412711405327, 0.005441550597814577, 0.0848505123119269, 0.08550045386488948, 0.05689968714224441, 0.064354547831629, 0.029677303241831914, 0.0478977225055652, 0.045068492713783465, 0.026718072925827334, 0.02171861842673804, 0.05808440249945436, 0.05011287471279502, 0.017502500376264964, 0.04792595295501607, 0.03649474474202309, 0.07280836813151836, 0.031760700911815674, 0.042256484140775034, 0.022941272373178175, 0.040564346725919416, 0.06695655999439103, 0.0390819580560284, 0.023776034990857755, 0.018382960631112968, 0.051569122821092606, 0.0896700651251844, 0.10236536032919373, 0.03973261885611074, 0.0348640418877559, 0.03380326434437718, 0.06271121065531458, 0.02191417391545006, 0.03158059057646564, 0.0753289900187935, 0.06319217663258314, 0.0322433903680316, 0.03041691319750888, 0.009953186764115734, 0.040928998230291266, 0.020675028175381676, 0.012226679412248944, 0.017010866132165705, 0.017058826683621322, 0.029188025210584913, 0.05543677582006369, 0.051520872195916514, 0.01322588583986674, 0.0681208378768393, 0.025049875922767178, 0.010090091382153332, 0.024133329479289905, 0.07191642027880464, 0.06382041863564934, 0.030746413195239644, 0.019142716291493604, 0.02291298594458827, 0.03848593628832272, 0.04304419544392398, 0.027240628010726402, 0.021194906439632177, 0.04377273849344679, 0.024838868495342985, 0.10992153986756291, 0.02510243185263659, 0.01809858830113496, 0.022010264652115957, 0.010794789862952061, 0.037721783721021244, 0.01938358604508851, 0.05945747239249093, 0.017822631501725743, 0.07353248713271958, 0.060847824572452476, 0.015713502087497284, 0.025453107231961827, 0.003333214433431359, 0.04900426045060158, 0.06850678181009633, 0.031871193554252386, 0.01884161468063082, 0.041168636442827325, 0.12383401154407433, 0.006672588268494499, 0.021463087227727686, 0.024198428128979037, 0.04259616555646062, 0.03655460849404335, 0.04412608899708305, 0.017399376624130776, 0.04646921290882996, 0.04390953115320631, 0.03180131123268178, 0.01969393269558038, 0.04586885190968003, 0.023315908520349433, 0.025055468747658387, 0.041653683808233054, 0.033722308331302235, 0.09508999929364238, 0.02680630961965237, 0.015361149030338441, 0.0053599088402864125, 0.03526967351457902, 0.027976041227313023, 0.029081020238144056, 0.016618788242340088, 0.033686797201101265, 0.04820021341687866, 0.04729643191343971, 0.030635486290391003, 0.03799703484401107, 0.0032332051570327686, 0.05674230094466891, 0.040974215803934, 0.03862684087029525, 0.08387460932135582, 0.03430775173806718, 0.09446677844971418, 0.01612094709915774, 0.03660555290324347, 0.038969931924449544, 0.030876990474228348, 0.050377635684396536, 0.007667968182691506, 0.020561935047485998, 0.042979344459516663, 0.0835096931883267, 0.019376391877553294, 0.042398026545665095, 0.02471470506861806, 0.03667939108397279, 0.04481278679200581, 0.02430889193367745, 0.018413104549316422, 0.01186869281809777, 0.0311067933216691, 0.03202617095251169, 0.036897489202341864, 0.011608139611780643, 0.02939106324421508, 0.09183122630098037, 0.05110047225441251, 0.007587884935284299, 0.035495581571012735, 0.050028139259666204, 0.03570210727463875, 0.05265380176050322, 0.03013704464371715, 0.0937013230951769, 0.016972574704725827, 0.03526303744209664, 0.020773607439228466, 0.056942611267524104, 0.020582689737368907, 0.025673841458878348, 0.06321494826780898, 0.037301533057221344, 0.03732655403603401, 0.028136667429602573, 0.029472171927669218, 0.043201496824622154, 0.031103824730962515, 0.007793769423317696, 0.04953197409797992, 0.022251185295837264, 0.05364935173253928, 0.022533192931275283, 0.026535346837980405, 0.026636511320248246, 0.09583457612565585, 0.048130721252943785, 0.11945744710309164, 0.03365742002746888, 0.04524666243898017, 0.025142165166991096, 0.05591293437672513, 0.015569103050178714, 0.03762103484145232, 0.05889029854110309, 0.10605811753443309, 0.048928094894758294, 0.016457799023815563, 0.02319805377296039, 0.13325927007411206, 0.13129693322948047, 0.09425206282841307, 0.12033081666699477, 0.1783320443438632, 0.07323558734995977, 0.13322309058691773, 0.14058352634310722, 0.16998987698129245, 0.09443152177014522, 0.13486431751932415, 0.1443806490195649, 0.09222438306148563, 0.08184285834431648, 0.09125972339617354, 0.11308447657419102, 0.11056973758552756, 0.16736044521842683, 0.2370628464434828, 0.17724508552678994, 0.13195119026516164, 0.23102928591626032, 0.16539122802870615, 0.14892053683953627, 0.12355555434312139, 0.12493477176342692, 0.15961363805191858, 0.17876443399914674, 0.06975141859480313, 0.10765756706574134, 0.10509709481682096, 0.0994365249893495, 0.1459416188299656, 0.08439288115394966, 0.08613354739333902, 0.09357484416770083, 0.109234509590481, 0.15787942468055657, 0.13668190927377769, 0.15954343681888922, 0.3194775198187147, 0.11843652331403323, 0.09458230582198926, 0.12221881321498326, 0.12002015619405679, 0.1232840046286583, 0.13075219174580915, 0.15667034313082695, 0.12452851927706174, 0.1085510009101459, 0.13612059796495096, 0.1349141898431948, 0.12659668044320174, 0.16530813463032246, 0.12000788828091961, 0.17663676531187125, 0.1385084848318781, 0.1106465816763895, 0.18225393603954995, 0.1767171581408807, 0.12089512710060392, 0.16484018974006176, 0.15364194634769643, 0.19121146681053297, 0.19744971421148094, 0.12878281170768396, 0.10577886644750834, 0.13398393190332822, 0.1211540832051209, 0.13185971017394746, 0.16437255697590963, 0.12310677128178732, 0.11065125678266798, 0.09997793486607925, 0.14904367737472057, 0.1743604296020099, 0.0820519421249628, 0.08161111827939749, 0.16021818561213358, 0.1497146670839616, 0.16677401454320975, 0.1475839449891022, 0.24257863046867506, 0.14242758096328803, 0.16583902042891296, 0.14199653480734142, 0.13137409623180116, 0.11221282370388508, 0.0857213373695101, 0.1093740299610155, 0.07863199670932122, 0.17705155376877102, 0.1368372802223478, 0.08859749125050646, 0.14228819629975728, 0.11212225284959589, 0.15158069266804627, 0.0943484962252634, 0.10258279687591962, 0.15071883105805942, 0.2600987032055855, 0.198533171787858, 0.09475531868104424, 0.31393676570483614, 0.1883951529328312, 0.13197373119848116, 0.15172956325113773, 0.14217152898865087, 0.13092282973229885, 0.2209018657782248, 0.35711764863559176, 0.07137024708624397, 0.10947472455778293, 0.1710496943976198, 0.20260658035320894, 0.19271379762462207, 0.06662240863910743, 0.08440288954547473, 0.2453901810305459, 0.1649738204266344, 0.0970373744411128, 0.10049419144966773, 0.15977082747433866, 0.13171884630407604, 0.10996426721768719, 0.16420812079949038, 0.10712220293602773, 0.10443449180041041, 0.21129105506198748, 0.15671234444848128, 0.10034315633986678, 0.10080975094544035, 0.08571248248751674, 0.18439309911004134, 0.17295154663068907, 0.0874370810176645, 0.13218014155115398, 0.08691276343805449, 0.13805020228028297, 0.2036150326686246, 0.12838863714465074, 0.22165987081825733, 0.07362457790545054, 0.11440526534404073, 0.07501683676881449, 0.16891775093972683, 0.18606313663933957, 0.08293646001922232, 0.1598251781293324, 0.1626896679933582, 0.14660074774708065, 0.12033739845667567, 0.15463210535900934, 0.14636019351226942, 0.07533378047602517, 0.13445643654891423, 0.1890182787818568, 0.08421383611857891, 0.11081232742539474, 0.12914494584713662, 0.10110186705631868, 0.10801877161221844, 0.13830885982939176, 0.14970953735922063, 0.31783484082136837, 0.15028946766895906, 0.09071781818888017, 0.2256380266376904, 0.09357668978295156, 0.15622012157525333, 0.22389941635940755, 0.10523399604218346, 0.18776046484708786, 0.1532881853303739, 0.12763383478990623, 0.10645643794643027], [0.036987174568431716, 0.010830566469979073, 0.014455693241740977, 0.053168246655591896, 0.01755680692648249, 0.031363859706159146, 0.03872921823390892, 0.02756928832137159, 0.03176804266071745, 0.030007817649415562, 0.02290984772012702, 0.04501344316772052, 0.02477056037501565, 0.08012938100312438, 0.06744895250137363, 0.013528684636444917, 0.06491296858127628, 0.019559779537043402, 0.025428639259189367, 0.05113400545503412, 0.07968523912131786, 0.0012557136568440391, 0.06019176263362169, 0.030249559320509434, 0.01171301568060049, 0.006567855116112956, 0.06639773212373257, 0.026798623514228632, 0.016743158622245704, 0.020334551177386726, 0.016200177936947772, 0.03030160634911486, 0.051344086682157855, 0.047249653709254096, 0.047188646625727415, 0.03459655659805451, 0.03202771122700401, 0.020195327665922896, 0.05652117316744157, 0.008642549726313778, 0.0035341750896934953, 0.028897992202213833, 0.04028038660596524, 0.021095499363062636, 0.06296910824520247, 0.027175130721713816, 0.06981546551521335, 0.038795989472419024, 0.03941410434033189, 0.045229044277220964, 0.07051187993160316, 0.04621734410258276, 0.05434507404321006, 0.04531776273090925, 0.0416354380015816, 0.09728043925549303, 0.02353999810293317, 0.005889720857209925, 0.03131038775401456, 0.030825516807713678, 0.005126545380335301, 0.027688970024298345, 0.059108338983995576, 0.07371324886168752, 0.03062169167346188, 0.08526862559041806, 0.010194791880037104, 0.013336835645272263, 0.04710826736741832, 0.025263371877372265, 0.04804378395367946, 0.03718598193622061, 0.014991215130846416, 0.062105964204030376, 0.04875889200983303, 0.030850866876010383, 0.02992124336638621, 0.013511337040524398, 0.019802423659712076, 0.03374802480850901, 0.04026707714157445, 0.02821545721963048, 0.03387589134009821, 0.10691147031528608, 0.01414554930358593, 0.008624778894175376, 0.08487157403890576, 0.02572294873451548, 0.056413615188960514, 0.006051318212744913, 0.040987549017050436, 0.039511935519320626, 0.002607268900776814, 0.01260945458696889, 0.034959196246096065, 0.04994799070326345, 0.016221492418221066, 0.004341911657580307, 0.02515322359145752, 0.042350060905196836, 0.04438211043764438, 0.04443366552836128, 0.02461444982327521, 0.04318977852485009, 0.03449155330391867, 0.07923342979380063, 0.038510981015861034, 0.031016670300492218, 0.051800761105758805, 0.025541415171963826, 0.03341242817363568, 0.025461750071761862, 0.033062487308468134, 0.02356764840494309, 0.032242610052760155, 0.011991646756151957, 0.038412047217467, 0.09790251337523971, 0.011510026840759175, 0.023391534640852894, 0.06849446639950786, 0.023543955658429434, 0.048111902084201574, 0.026229660026729107, 0.012728367000818253, 0.010149494578529681, 0.02423198677466384, 0.01860578983489956, 0.03950250388256141, 0.045039912818797996, 0.07305583663816963, 0.10727836777056966, 0.0314693108334073, 0.07788081094622612, 0.02423164920349206, 0.06261652109346219, 0.08983184822968074, 0.01804228685796261, 0.03847560898533889, 0.021067535238606588, 0.031895400291042666, 0.015807597931208353, 0.03257219486736825, 0.07352011743932962, 0.052283783044133864, 0.08996144841824259, 0.08929076404975993, 0.03693555501688804, 0.057895986895476065, 0.035601500887423754, 0.024919469973870685, 0.06300059227006775, 0.00788869392792029, 0.017628341480823498, 0.0050809677590483, 0.05345508376402514, 0.060536790905254226, 0.04504271177574992, 0.06676080264151096, 0.04723590998245137, 0.049263186021042724, 0.030216765723058155, 0.02677035404901419, 0.014400004176422954, 0.02009038713627628, 0.0380005835821586, 0.008341325979147638, 0.03349851391145161, 0.0718915858971221, 0.05657585630459445, 0.02748004230670631, 0.04223463192049946, 0.06222871118890388, 0.04893079546413251, 0.01999823359905609, 0.044500755678330145, 0.030631683101611476, 0.02442296045566244, 0.0162809151224792, 0.0405864466114768, 0.020866559951433113, 0.05834068517599787, 0.035303396705005846, 0.04841500706970692, 0.05253403354436159, 0.030075501517525742, 0.020916269426899295, 0.02312091112669025, 0.04803049145266414, 0.061367405977632315, 0.07183469752115862, 0.033033887057432106, 0.07914425672164985, 0.028480676202369586, 0.05322211555072239, 0.021934981191796914, 0.0521165377327374, 0.023939470328124504, 0.039147338297750266, 0.0049889910650173465, 0.03752575156145862, 0.01239864478286888, 0.08031787124595471, 0.037785426913095374, 0.0036813875028331366, 0.033095844089984894, 0.04363323508628777, 0.04344208837885942, 0.03502990298771432, 0.03188578544982842, 0.02780650755656617, 0.020278918091207743, 0.030600921716541052, 0.05847827172172921, 0.03563746663608721, 0.035908531198011975, 0.01896716231879379, 0.03517940460837313, 0.04143771289714745, 0.0363579351188881, 0.03361738646136863, 0.08578536393386976, 0.03504681208037904, 0.036723716384066005, 0.03271467025790896, 0.049896832555532455, 0.032410591574651856, 0.060873507122908316, 0.05045855098537036, 0.07311454348798309, 0.05812421214899846, 0.06857162261647837, 0.06685855918164764, 0.09754434866564614, 0.042372150612728934, 0.05841234525931733, 0.028631704526820352, 0.02571992077199476, 0.03856412387852158, 0.038326378778687546, 0.03892695690904345, 0.06734493308301483, 0.05192457678328667, 0.036420200884874375, 0.03814849743087377, 0.013759595192303615, 0.013303779963670033, 0.04714362582724009, 0.03971437983480947, 0.10236149267958743, 0.02482005611195096, 0.027257504872977734, 0.02144239190965891, 0.0127518502496449, 0.06704084761440754, 0.03916756881933127, 0.008615676346900207, 0.009762342852939452, 0.017868213787940995, 0.029127740766853094, 0.01439579386663224, 0.04629831029368298, 0.051018725748040845, 0.04125986547608461, 0.012542116771718221, 0.018864628892125826, 0.03956238120528204, 0.03495278409016984, 0.014730845977153097, 0.019949911727703044, 0.034638208470174243, 0.003983879262315375, 0.019482955802232027, 0.04769850801676512, 0.04143875784107617, 0.03203813013221536, 0.03349780144968203, 0.08234867905931813, 0.050962644828749556, 0.06680511776357889, 0.008306272011915488, 0.08777503216905252, 0.00834886365503605, 0.047481624476079426, 0.014339765533804893, 0.06915263858224664, 0.04684594912188394, 0.026003967405163815, 0.024501819795529758, 0.021657833563429967, 0.0074983946480123055, 0.05352797538840345, 0.07619752162801367, 0.03270791204912322, 0.03387377431084003, 0.026103842670896223, 0.0257218834345362, 0.03929405453215752, 0.07433498371392488, 0.013748596139651324, 0.03729378079463329, 0.014534849440678954, 0.04401193565822073, 0.010819373186677694, 0.06847639022661106, 0.05043793369882873, 0.051889452418046336, 0.05685068673587271, 0.01902153672251318, 0.02577278882797275, 0.01639528219987239, 0.027945400282208408, 0.043850464679832966, 0.018094861447545033, 0.05109650621722851, 0.038568639529070685, 0.055047066017453156, 0.05496322962322405, 0.0506814327756209, 0.059189003227012496, 0.12155832722783089, 0.07252003824604408, 0.02590058750606009, 0.09688951487519912, 0.013629415704469596, 0.058720115173075876, 0.02090706509937133, 0.007104142901620695, 0.03308034295748387, 0.03390890546143055, 0.013684845230142986, 0.04435103692646537, 0.04112395830452442, 0.021900189308715717, 0.056223024880247455, 0.04393212636932731, 0.0687184575945139, 0.03959111377064671, 0.051683700244341574, 0.02612229882340346, 0.057533079226102145, 0.019534578746450797, 0.0334693504763501, 0.01550165327664997, 0.03184059841026153, 0.02056553976477257, 0.04716261123706188, 0.06844763391252075, 0.03910902142524719, 0.039425595330872705, 0.048711832213614664, 0.01724857051989862, 0.11657904727118355, 0.13705021808190004, 0.08704294038138219, 0.16478868893214635, 0.165732775415693, 0.23100724709885462, 0.21213154281888688, 0.1043489013931581, 0.1317345883165087, 0.11302480620465108, 0.1392116371010031, 0.13966632341699942, 0.08658395893871784, 0.12289011505033288, 0.14710477712963307, 0.12150393586073603, 0.16652877841676983, 0.0936368622684053, 0.15104554566953862, 0.18861115777066775, 0.09484486494745527, 0.09890273506087915, 0.123870421733175, 0.08728643945817437, 0.08322578056582383, 0.07880495528557471, 0.1572950431810958, 0.1842523438057729, 0.07958967424929142, 0.1138052571831005, 0.09645748484347548, 0.10582168200718504, 0.10537807616804327, 0.08672312647104263, 0.11908886688096182, 0.10365274482007537, 0.12298436356442315, 0.11482941758419786, 0.17351975185530527, 0.10299569222011737, 0.13656635476010187, 0.08224632205175501, 0.09287725588572876, 0.07610836212656327, 0.2223726582846471, 0.19138647456254276, 0.1361285096832684, 0.09389202536216804, 0.09283815869795424, 0.10551615804433823, 0.09850437393678085, 0.11471254671258585, 0.17501813359558582, 0.19500810094177723, 0.12101410143077374, 0.22450837439724378, 0.14782914040344103, 0.187295206955501, 0.2342727104468005, 0.10203874071261712, 0.11723396927118301, 0.15186445601284504, 0.13980129760290894, 0.1464874731110675, 0.1182643925505025, 0.18744022345968656, 0.10112743425582137, 0.11348281734223876, 0.10360076225229672, 0.08986840769648552, 0.1504107897302934, 0.08414013364485332, 0.1244759192424161, 0.2682993688753673, 0.08094126850898777, 0.118180905601808, 0.12430389704448835, 0.18432988678770407, 0.13029381419931138, 0.2520061960177762, 0.07630770892969199, 0.09097669286919491, 0.14059569926134177, 0.13757859330092156, 0.11878296972385474, 0.16032707691192627, 0.14658172162515776, 0.11972236074507236, 0.18072355458778994, 0.06410530156322888, 0.0887397461171661, 0.1564876272210053, 0.045863233639725616, 0.0743956718859928, 0.12118460371025971, 0.07366209410663162, 0.08513681337769542, 0.1124171373833503, 0.10028055469904627, 0.14314893154161318, 0.10981760865875653, 0.13191317873341696, 0.21148555033973285, 0.22799409021224293, 0.07974351170871939, 0.25841656061155455, 0.16621214683566773, 0.11453433627528803, 0.08428448518472058, 0.13585985052798474, 0.14401120027261122, 0.13646551088563033, 0.17096076559807571, 0.1289785419191633, 0.12875043201659406, 0.0967452379741839, 0.1385678295046091, 0.1430829915085009, 0.057001806662550995, 0.09054194869739668, 0.1305801695478814, 0.06894896951104913, 0.13375236147216388, 0.09073862885790211, 0.08185108897409268, 0.06066548864224127, 0.12798630659069332, 0.07989940512925386, 0.18138326704502106, 0.12391707780105726, 0.1359522941389254, 0.22865150922111102, 0.06586480393473591, 0.2137457097747496, 0.09356022173804895, 0.10632068344524928, 0.12386166863143444, 0.1236962146524872, 0.13673393933900765, 0.1398823961083378, 0.17500422362770351, 0.07099368050694466, 0.09156996317739997, 0.1038878300626363, 0.23866269631045206, 0.13488702130104813, 0.17531899602285453, 0.15256007654326303, 0.1036716555910451, 0.14093278188790592, 0.1525587330439261, 0.26901248203856604, 0.08994379972240754, 0.07465308771601745, 0.0973889370049749, 0.16823794027524336, 0.12904744036495686, 0.10449106805026531, 0.18266705530030386, 0.08483834617904254, 0.11904001235961914, 0.10381092490362269, 0.11431146466306277, 0.09899038821458817, 0.11605935730040073, 0.09264816889273268, 0.1436216261770044, 0.08142075527991567, 0.1790511150445257, 0.11833867856434413, 0.11437760825668063, 0.13954302003341063, 0.10621320349829537, 0.10072365163692407, 0.1647773573973349, 0.11864309651511055], [0.04012293255488787, 0.045660724863409996, 0.024555424062002982, 0.036513984602476866, 0.01825836124563856, 0.06696306035986968, 0.033605685124972036, 0.025269280221047144, 0.02164626114868692, 0.02741742879152298, 0.04320538143760391, 0.05477566558069416, 0.034349797160497735, 0.023096356640702913, 0.0707556436370526, 0.02348561691386359, 0.026430669240653515, 0.015412522612937858, 0.015818020229094794, 0.11010914801486901, 0.042853252297001224, 0.02429476992360183, 0.03940301029277699, 0.09263083232300622, 0.012351912379797016, 0.030449547339230776, 0.024198192338060056, 0.036009626130440404, 0.029598990122654607, 0.017907273656289493, 0.01965487961258207, 0.04059843632525631, 0.004521980856744838, 0.03498816629871726, 0.014341994521341153, 0.03228630092261093, 0.03760676525001015, 0.06646038126200438, 0.0732870406604239, 0.016913879729275192, 0.009765466658531554, 0.01885609801060387, 0.03930033098108002, 0.05972163964595113, 0.039222095893429856, 0.05039483654711928, 0.043126349071306844, 0.029989978963775293, 0.04702212056145072, 0.0713494974853737, 0.024797450717804686, 0.03565459964530809, 0.001952838838665879, 0.02116102209713842, 0.0135620151247297, 0.02847461009930287, 0.07908026408404112, 0.02461141168272921, 0.048004764797432084, 0.03003976647076862, 0.022059212472023706, 0.05663141475192138, 0.04287181022976126, 0.008810238629978682, 0.03286442972187485, 0.06966229302010365, 0.04005181869225843, 0.06788614618458919, 0.052996251599064896, 0.05914435562278543, 0.03706206787111504, 0.045271551103464196, 0.04273104814014264, 0.03894362512177654, 0.055945632979273796, 0.030150537312562977, 0.034069596124546866, 0.0706438957048314, 0.04203688306733966, 0.027310035357783948, 0.06503176649234124, 0.050227883005780835, 0.027957812384037033, 0.056996697293860574, 0.026402099523693323, 0.023328819345416765, 0.046814841683954, 0.01580900080235941, 0.08992386436355965, 0.011108229784960193, 0.0207217554894409, 0.027566911752468774, 0.02256887369523091, 0.012464521203323134, 0.031173069229615585, 0.027078425910856043, 0.066547620509352, 0.06658668377037559, 0.06700471562466451, 0.06429090803222996, 0.06079970965428012, 0.024091682696182812, 0.08818662472601448, 0.04027570810701166, 0.08350136756364789, 0.042423413933387825, 0.02844375032665474, 0.011103505484892853, 0.011964258538292987, 0.05464156670495868, 0.046849026278193505, 0.04168396343344024, 0.04058632108249834, 0.10102883633226156, 0.041803514518375905, 0.04158198979816266, 0.05651443870738149, 0.03527831465804151, 0.014036017636369382, 0.04250006464176944, 0.07672736926802567, 0.02737993125005492, 0.05921493683542524, 0.009344921680167317, 0.03271704173779913, 0.05136657672535096, 0.0867950851097703, 0.027288463033203567, 0.00047894288270202063, 0.0465587557825659, 0.034835947145308764, 0.06630079661096845, 0.06901864148676395, 0.026349731887291585, 0.04190785624086857, 0.03680721011811069, 0.01102153760647135, 0.0270131084336234, 0.07701079334531512, 0.03915919230452605, 0.021654547757602165, 0.0052131650403940254, 0.008396963306170489, 0.017380214795204144, 0.011337328652319099, 0.04171364934050611, 0.05595543781029327, 0.021458430781162212, 0.01818210069489266, 0.04691257108268993, 0.015021004514502627, 0.045090551887239726, 0.02157186487290476, 0.045290950419647355, 0.03266250787835036, 0.01714538230693766, 0.008266801629880709, 0.04866489116102457, 0.020587044235851084, 0.06652694554733378, 0.03134016187063285, 0.03921673546678253, 0.00848971480237586, 0.09871988344405379, 0.016985020733305385, 0.05068137849281941, 0.01111489808785596, 0.0162620128331972, 0.057635524443217685, 0.023649668021659766, 0.031991219613701105, 0.0783059945596116, 0.014693952331851636, 0.023582257263894593, 0.02415518000322793, 0.0716219496514116, 0.023360388187159385, 0.026546357764995525, 0.0335343643091619, 0.03667083475738764, 0.022517247358337045, 0.05008358235603996, 0.030248795968613455, 0.014857243480426925, 0.03135097771883011, 0.03160586939858539, 0.011324450905833925, 0.06528809666633606, 0.043345190185521326, 0.047711725878928385, 0.06590609957597085, 0.06106690317392349, 0.01826707024260291, 0.027563125527064716, 0.04315063723229936, 0.03619998234457203, 0.00862856681591698, 0.042775414152336974, 0.023694288484486084, 0.04947998135217598, 0.004924202421014863, 0.02497176806043301, 0.063275276816317, 0.03808118336434875, 0.022171628761238286, 0.03118864500096866, 0.07226127213133232, 0.09178146254271269, 0.07010456893060889, 0.025583942354257618, 0.03741826482915452, 0.04709650496287005, 0.007378147216513753, 0.03992646952558841, 0.05131477736202734, 0.0423066516273788, 0.001235023745851192, 0.05223972237269793, 0.034407174081674645, 0.042974591321711025, 0.05594429626528706, 0.03160913993737527, 0.029046591371297836, 0.08132141775318555, 0.03251192060166171, 0.04090584322277989, 0.011597600266603487, 0.022228322058383907, 0.05242645520982998, 0.028271594118060808, 0.007266543472984007, 0.026934542560151646, 0.07201246012534414, 0.05267930789185422, 0.02102513867430389, 0.024236621168841208, 0.0029918443137181123, 0.024043771338516047, 0.026492083445191383, 0.015446210180276206, 0.03359315597585269, 0.04551333687933428, 0.013896923894727868, 0.03960922387029443, 0.05574800965509244, 0.06201702183378594, 0.04576476803049445, 0.06733596963541848, 0.05555085112739887, 0.023837988630735447, 0.023563695938459465, 0.034307052846997976, 0.05854659341275692, 0.06000458196337734, 0.026053517424900616, 0.010188196519655841, 0.07274799887090921, 0.06872068318937506, 0.04133462307176419, 0.021667957305908203, 0.03257050531517182, 0.033336496712373834, 0.027308724088860408, 0.0033992163828640643, 0.02126303474817957, 0.044131055873419554, 0.033306756522506475, 0.040591002974127016, 0.02539225621148944, 0.022355898516252637, 0.0244785782748035, 0.04604687574984772, 0.027948043176106045, 0.028777779545634985, 0.010304132709279656, 0.03823425068653055, 0.04340974600719554, 0.007054794746051941, 0.05396551173180342, 0.04936605532254491, 0.08111745691193001, 0.0769821320261274, 0.100221854634583, 0.010429670169417347, 0.011271330095561487, 0.037006126051502566, 0.034682435382689746, 0.020642424567735622, 0.020467572878780108, 0.056199805411909304, 0.05472396799762334, 0.0226899430022708, 0.031674072345984836, 0.039149418007582426, 0.020487625284918716, 0.05284087386514459, 0.0147549916457917, 0.041186970459031205, 0.06664642877876759, 0.023065157600545456, 0.016995327680238655, 0.040284162653344016, 0.07417087323431458, 0.04902259446680546, 0.015887432665164982, 0.046761155993278535, 0.028864425074841295, 0.060479997524193356, 0.027142106422356198, 0.01984301532086517, 0.03912153700366616, 0.035333961314920864, 0.008065258069629115, 0.05789066718092986, 0.0491847304095115, 0.061272227870566506, 0.04795431232612048, 0.012776464955615146, 0.06504870272640671, 0.047908253369054625, 0.014089365755873067, 0.05754259907241378, 0.08363259623625449, 0.04352299010913287, 0.04111477433304701, 0.03561313097764339, 0.020903760633830513, 0.0308252555717315, 0.05668023195383804, 0.055650683984692605, 0.06603654114795582, 0.02162166086158582, 0.011374559020623565, 0.016014997248670886, 0.04633822850883007, 0.049861138220876455, 0.0015683371103867622, 0.03818209509232214, 0.05235345162717359, 0.09366635818566595, 0.013365897300120975, 0.014769456316051739, 0.06007047449903829, 0.046322785051805634, 0.014377873756789734, 0.06417750447456326, 0.04661409031333668, 0.08595750826810088, 0.031286747593964846, 0.01262224157939532, 0.058368898662073274, 0.021271265377955775, 0.1166329908051661, 0.14356818475893565, 0.10147426064525332, 0.10827654706580297, 0.07948710011052233, 0.13843789004853793, 0.16157773908759865, 0.11436791877661433, 0.17534859372036798, 0.08281114817197834, 0.2116152048110962, 0.1307174100407532, 0.12227389668779713, 0.1293906026652881, 0.15712839498051576, 0.18304227159491607, 0.07712087208139044, 0.1542487195027726, 0.11657832802406379, 0.14701734110713005, 0.10764675121754408, 0.11175405939242669, 0.10609855822154454, 0.1433411469416959, 0.11267112661153078, 0.10444226781172411, 0.19014939665794373, 0.10630559282643454, 0.0858534684936915, 0.1037195058805602, 0.12390848754772119, 0.14677756040224008, 0.2245635257235595, 0.12872443055467947, 0.18082545697689056, 0.13895371236971446, 0.12398958605315004, 0.1462367001388754, 0.20199459604918957, 0.08823497713144336, 0.08424645329692534, 0.07468140976769583, 0.11091730357812983, 0.1968451937926667, 0.17066995905978338, 0.09495246024536234, 0.13216986853097165, 0.159295133714165, 0.0823399598843285, 0.15789568237960339, 0.09837769823414938, 0.13891200960746833, 0.16470740043691226, 0.11460598957325731, 0.08360847431634154, 0.1562505742268903, 0.3148630474294935, 0.1497186975819724, 0.15812506792800768, 0.08009208193314926, 0.08904210132147584, 0.11382574894066368, 0.1369273896728243, 0.12536218097167356, 0.11669443893645491, 0.15068445647401468, 0.10730823688209057, 0.11994882859289646, 0.2125944529793092, 0.1170775398079838, 0.09048248188836233, 0.22970470413565636, 0.21791133124913487, 0.11983134703976767, 0.21911529664482388, 0.18401774710842542, 0.1528494038752147, 0.1390243750065565, 0.11597110703587532, 0.21592057735792228, 0.14198145775922708, 0.17599947165165628, 0.14086007007530757, 0.08980582641171557, 0.08533982426992484, 0.1330995565014226, 0.1255382200969117, 0.17883854359388351, 0.21794060324983938, 0.17452132382563182, 0.08896010036447219, 0.20284041709133557, 0.10355772277606384, 0.07699053228965827, 0.1015787889648761, 0.10663396984870945, 0.11528396819319044, 0.17022463652704442, 0.14793318696320057, 0.19189093820750713, 0.11577798239886761, 0.17610045123313153, 0.22403315561158316, 0.09834981044488293, 0.307556826621294, 0.14741982093879155, 0.2018427127706153, 0.20642704463430814, 0.0853597731994731, 0.12121631843703133, 0.30055971922619, 0.09890071302652359, 0.08784966423575367, 0.16324666381946631, 0.1217912140169314, 0.07571435041193451, 0.17841477133333683, 0.0851812574214169, 0.08659345842897892, 0.1200948493289096, 0.13331424498132297, 0.10985972532736403, 0.10645757109991141, 0.11017168180218764, 0.15027532699917043, 0.12507005807544502, 0.15295943511383875, 0.12397036994142191, 0.09706808493605681, 0.11998817005327769, 0.09044305221842867, 0.1300198081880808, 0.16162371662046227, 0.13472334508384975, 0.08257806460772242, 0.08740895574114152, 0.09829657937266997, 0.14897180694554532, 0.13620339280792645, 0.12221566481249672, 0.11795755901506969, 0.06673015321471862, 0.05937463005206414, 0.2268737339015518, 0.18414147118372576, 0.16644826345145702, 0.09965124739600079, 0.07940279891980545, 0.14214133418032102, 0.13160334607320173, 0.06084457438971315, 0.11135676356830768, 0.11877608937876565, 0.2538615550313677, 0.19635854847729206, 0.1108528563220586, 0.05828251436884914, 0.06993549836001225, 0.06258551882846014, 0.19209382017808302, 0.09993494967264788, 0.10903648593063865, 0.09616490732878447, 0.2155890722892114, 0.11623559998614447, 0.14322118195039885, 0.22035769426396914, 0.10877956543117762, 0.1179676420454468, 0.10035014525055885, 0.07891427406242915, 0.12320405963276114, 0.06732227001339197, 0.10057601598756653, 0.11399670583861214, 0.10313736354666096], [0.043809908641768355, 0.03688625944778323, 0.06949538697621652, 0.025973368868497864, 0.022084158811984316, 0.03801655290382249, 0.003613341042572366, 0.06532027958227055, 0.04227351536974311, 0.045229044277220964, 0.05198220136974539, 0.04307916035343494, 0.04720079240256122, 0.024697543221658895, 0.03531791056905474, 0.03417763247021607, 0.02124992884429438, 0.06298698764294386, 0.04983889923564025, 0.010626606476892318, 0.007022826416817094, 0.05386915975915534, 0.037646055820264986, 0.01158084299614919, 0.04426043553810034, 0.018802442854004245, 0.05749143074665751, 0.10897012520581484, 0.07425328131232943, 0.04598310363612004, 0.044156534863369803, 0.0099459866593991, 0.004833918671855437, 0.01823444797524384, 0.023509496257507374, 0.015019026584923267, 0.032592069158064466, 0.026027261512354016, 0.030542272542204176, 0.00965138541401497, 0.0325256337943886, 0.05630068999848195, 0.07312731351703405, 0.022838462443490113, 0.01366531614413751, 0.028950965431119715, 0.014686522373397435, 0.14357285307986395, 0.026665785017290285, 0.024166570909853493, 0.028360539880980338, 0.00812608449320708, 0.030415264357413565, 0.048763729964515994, 0.02106082283093461, 0.010872586447346424, 0.017005804260926585, 0.03293126881388681, 0.09798300798450198, 0.03674325140725289, 0.03856363194063306, 0.022516051440366676, 0.033333151534731896, 0.05239667770053659, 0.024469409570364014, 0.07334750491593565, 0.01821913513621049, 0.01558172719420067, 0.04994228083108153, 0.06616790552756616, 0.033038060047796795, 0.029491635704679147, 0.005476884036657533, 0.03343464680282133, 0.011688369592385632, 0.03991013379501445, 0.061920649505087307, 0.014027796336449683, 0.013863195615288402, 0.08450329915753432, 0.03527738506506596, 0.06302096867667777, 0.05405014201200434, 0.018821372284686992, 0.03938971779176167, 0.016244153791506375, 0.01708346089747335, 0.05060627145160522, 0.011451555781864693, 0.005317592003848404, 0.037594626258526526, 0.11988207431776182, 0.01958693450848971, 0.023087142135149667, 0.029968503330435072, 0.020885445277339647, 0.011771794624759682, 0.04479859183941569, 0.015157561383343168, 0.03411393838801554, 0.030072020632880073, 0.02058391958209021, 0.05564578835453306, 0.021692968106695583, 0.021796412466626083, 0.037167383291359456, 0.032766198207225115, 0.029125898544277464, 0.07138704082795552, 0.04377520496823958, 0.0031493515873860034, 0.03564213156434042, 0.005083952040877193, 0.044918478799185584, 0.09483164029994182, 0.013978745888120361, 0.028693916010005132, 0.050932572156723054, 0.03314249337251697, 0.028265651847634996, 0.03255799652210303, 0.028262484785435454, 0.031098644116095135, 0.02189958032353648, 0.02281355851196817, 0.0942587328276464, 0.04646192883540477, 0.037236488690333705, 0.023184420308098197, 0.044894068501889706, 0.038834174030593464, 0.09503340268773691, 0.032009160079594166, 0.056456552884940586, 0.02315333322621882, 0.025918887595513036, 0.07247870867805821, 0.027997679709057723, 0.01898480762195374, 0.017302907604191984, 0.03813025162422231, 0.04431825689971447, 0.027542040051360215, 0.024644352861547043, 0.016695790092593858, 0.03341013811794775, 0.025124435046953813, 0.012529602041468024, 0.005440431439118194, 0.07337958605161735, 0.03180175906579409, 0.04382875155923622, 0.053599676183824024, 0.01868605543859303, 0.03400233634082334, 0.021977360792724148, 0.030273810162075927, 0.02076187387241849, 0.014222247509418853, 0.030636578731771027, 0.045696694004748545, 0.07240771355905704, 0.013584155722388198, 0.018464512058666775, 0.057292653912944455, 0.012769603270239063, 0.012923204090579279, 0.06595582262213741, 0.0308442816936544, 0.04963403594280992, 0.011105238293696727, 0.012824131192506423, 0.03376627400783556, 0.0674737733123558, 0.025126134777175527, 0.027119173635063425, 0.027370206146900142, 0.044383050208645206, 0.06163350027054548, 0.07229264080524445, 0.04187160211482218, 0.004626554553397, 0.033732964723770104, 0.01416949141171894, 0.02747471411047237, 0.05156247657058494, 0.056848946293549876, 0.020610979558633905, 0.06825325398572854, 0.02671577438845166, 0.03991544333153537, 0.022535991888227205, 0.07641339754419667, 0.014962021161669066, 0.042615910925503285, 0.06337992727224316, 0.029628570856792585, 0.07305884254830224, 0.03642610074686153, 0.05813935026526451, 0.03238689034645047, 0.04933632531070283, 0.02608098621879305, 0.09004368686250278, 0.04116301138752273, 0.03638008589457188, 0.018634474902812923, 0.007709157802829785, 0.023086008981668522, 0.05175059022647994, 0.03290901625795024, 0.01670738964873765, 0.014082402290244187, 0.03165037790313363, 0.05629654075684292, 0.024027768090101223, 0.06053240078368357, 0.031864119826682975, 0.07793360097067696, 0.019488043118534342, 0.04243758513725229, 0.030120006629398892, 0.03307024974908147, 0.08065420069864818, 0.05303504005340593, 0.021739349367895296, 0.03413136316729443, 0.03844962448679975, 0.08111046800123793, 0.026860969008079598, 0.008351481952039259, 0.027110641057203923, 0.022643461657155837, 0.09527670498937368, 0.0444469105319253, 0.02652210183441639, 0.0855221805561866, 0.022518326229016696, 0.045581756957939694, 0.07418861013970204, 0.01394170890229621, 0.031734604454998455, 0.03434616360547287, 0.04186707289357271, 0.05994097609072924, 0.037163322259272845, 0.031476140288369994, 0.020358718898413435, 0.03591726394370198, 0.03805650504572051, 0.012664929065587265, 0.019518626388162374, 0.033403603825718164, 0.02739127805190427, 0.017982821745265807, 0.022166809466268336, 0.07307400102061884, 0.06845004949718714, 0.019142865569197705, 0.01916639377096934, 0.0214845408086798, 0.028272364255306975, 0.05681317053469164, 0.04736947960087231, 0.0539043757266232, 0.05496808793395758, 0.0268979661299714, 0.047666979887123616, 0.012436085497029126, 0.042886008575026474, 0.023157611389511397, 0.05257507134228945, 0.019821495582748736, 0.01760568350021328, 0.029505956186247722, 0.08050480085824217, 0.0478718160385532, 0.04387391145740237, 0.07382478644805295, 0.043038556817919016, 0.05106542931337442, 0.04378921671637467, 0.02818920130708388, 0.0369440604533468, 0.07920088725430624, 0.025481134120907103, 0.019393202582640306, 0.03277615910129888, 0.02240698711414422, 0.04954489340473499, 0.007167048186862043, 0.05697723690952573, 0.041367104543106895, 0.03374096465163997, 0.04179149087784546, 0.03296996566600033, 0.04555925673672131, 0.017288437844919305, 0.037982191890478134, 0.06568298369113888, 0.04052336660346814, 0.03859768761321902, 0.013308002147823572, 0.03260591466511999, 0.010355944795134877, 0.04757028864696622, 0.0036686789660182384, 0.08198012597858906, 0.08228863549551793, 0.05339583747887185, 0.02864525487114276, 0.00492194459574031, 0.0065846391038836116, 0.0413375339869942, 0.013224959639566285, 0.06462998555174895, 0.02687319620911564, 0.013844748792637671, 0.033819963091186116, 0.03458071619804416, 0.040768575588507314, 0.043433297957692824, 0.04233769799715706, 0.04050262039527297, 0.006990478956140578, 0.022436449104653935, 0.007169804735375302, 0.018762044575331465, 0.03282379565228309, 0.010163078849603022, 0.02257624258553343, 0.03563786018639803, 0.007941975890259658, 0.03260669158771634, 0.0384947843849659, 0.06712995961840663, 0.03045487723180226, 0.03001780907756516, 0.021829816745594144, 0.02901367224486811, 0.034598290255027156, 0.028696304453270774, 0.017600541901109473, 0.06298890111169644, 0.00971617448210184, 0.052107883018574545, 0.014188626099244823, 0.04144122092319386, 0.05514376065028565, 0.028925021644681692, 0.037834719089525085, 0.0949807008728385, 0.11200891036008086, 0.09708438334720475, 0.15626985819212028, 0.24953928696257727, 0.12311926989683084, 0.0929545003122517, 0.15417735118951115, 0.3043331338890961, 0.14472535837973866, 0.22252488083073071, 0.12462940386363439, 0.143147615183677, 0.24101094316158975, 0.1226876402007682, 0.12340610021991388, 0.13325889009450162, 0.14496482695852006, 0.09769167218889509, 0.12622140986578806, 0.19086257767464432, 0.13986373639532498, 0.1068697946944407, 0.0971676463793431, 0.15742974595299788, 0.14467852589275154, 0.17029326355883054, 0.18574256955512933, 0.1764182091823646, 0.17205708819840634, 0.1209446330155645, 0.053051996643521955, 0.11582300998270512, 0.0548047645549689, 0.12332920863160066, 0.08624839623059545, 0.09598655439913273, 0.12233600978340421, 0.09450656774320773, 0.1488021867615836, 0.10460553012256112, 0.16412348034126417, 0.10798878714974437, 0.10543394674147878, 0.11078444642147847, 0.0852567105154906, 0.0949323009699583, 0.10215915353702647, 0.28093097678252626, 0.08304379747382232, 0.1168958552713905, 0.13750707570995602, 0.09665213618427515, 0.1673683569367443, 0.15060837912772382, 0.07184907567820378, 0.11204489985746996, 0.10722090263984033, 0.1973389908671379, 0.2389065075133528, 0.10473891653652702, 0.10586641103561435, 0.1254067878637995, 0.11800190806388855, 0.11855636616902691, 0.08976246802402393, 0.16591892471270903, 0.09101957628237349, 0.11980188504925796, 0.12021439362849508, 0.22619882225990295, 0.1657868003738778, 0.06629432338689055, 0.1362032163888216, 0.07709061620490891, 0.06480280842099871, 0.12675761537892477, 0.11555023890520845, 0.13461279815861157, 0.105167357118002, 0.14849120059183665, 0.1537374026541199, 0.10949007980525494, 0.07066071658794369, 0.0991549872394119, 0.16858357244304248, 0.15004454366862774, 0.10117778833955526, 0.1254273746162653, 0.12204638389604432, 0.1542292862598385, 0.10993105292852436, 0.14442217536270618, 0.08172088488936424, 0.11114852795643465, 0.12434992886015347, 0.1062418580321329, 0.14295221066900662, 0.0713150550478271, 0.11336746638906853, 0.13257199552442345, 0.17610763013362885, 0.11370908162955727, 0.1892091506826026, 0.13586164186043398, 0.11445931744362627, 0.19473638837890966, 0.13602662086486816, 0.15974083622651442, 0.1540127657353878, 0.1580097305455378, 0.10544715781829186, 0.09477721500609602, 0.06338338780083827, 0.16137895546853542, 0.16145801836890833, 0.18359637686184474, 0.17635100707411766, 0.24168703545417103, 0.16959665236728533, 0.09767709725669452, 0.11840567711208548, 0.09457774606666394, 0.14530142103987082, 0.1386589024748121, 0.0927564020135573, 0.20018431890223706, 0.12033286584275109, 0.14446524876568997, 0.1267261720661606, 0.1313332619943789, 0.11809063330292702, 0.1666827787246023, 0.24971405044198036, 0.09092251863330603, 0.0844179665935891, 0.13830111095947878, 0.09943149025951113, 0.20722265408507415, 0.08083689625241927, 0.12827154914183275, 0.17244039263044084, 0.20311850788337843, 0.12071522032575947, 0.13024775524224552, 0.11900620774499007, 0.09803558766309704, 0.10580832165266786, 0.16708714488361562, 0.08173904248646327, 0.13245748595467635, 0.09188208250062806, 0.14892040113253252, 0.16307487232344492, 0.10794510985059397, 0.08394422022891895, 0.06652074373726334, 0.11522581774209227, 0.1103262792208365, 0.13890343292483262, 0.2347420124070985, 0.12266104162803718, 0.1654933068369116, 0.1136218084554587, 0.09192715758191687, 0.1441185852246625, 0.19091320995773586, 0.11642029721822057, 0.1416165551968983, 0.10870971703635794, 0.23124923982790538, 0.11485450980918747, 0.14539427177182265, 0.20289285427757672, 0.17563030788941042, 0.11931319055812699, 0.16657652014068194], [0.021869421138295105, 0.08340540914131062, 0.03887825505807996, 0.0501126847229898, 0.026743268627407293, 0.0039145312870719606, 0.01886200126526611, 0.024797465984842608, 0.03554748949993934, 0.0494544209380235, 0.029153779548193728, 0.04545112878882459, 0.08232020094458546, 0.03522107005119324, 0.044041540141084363, 0.06427390394466263, 0.048115230298468044, 0.01882892777211964, 0.03502202180347272, 0.014313655506287302, 0.02589827709432159, 0.020505755740617002, 0.14802109796021665, 0.03358668953712497, 0.0100752229835572, 0.011435430397146513, 0.024937958356791308, 0.036987842925425084, 0.018647399298580628, 0.02795332726756377, 0.019813183528770293, 0.035902020654508045, 0.009320694587326475, 0.05104610124336822, 0.018956276920757124, 0.030228327959775925, 0.07609759377581732, 0.014689633456457938, 0.04927125380241445, 0.028388675335528593, 0.03814621076786092, 0.011431277762832386, 0.0248919265411262, 0.031148435015763556, 0.03226927308631795, 0.006186578231531062, 0.016984080962304558, 0.04301737295463681, 0.04776937421411276, 0.06000918921615396, 0.03532943209367139, 0.044112952559122016, 0.05817412518497024, 0.0562419797559934, 0.015276625619402953, 0.04761099396273494, 0.027816047758928368, 0.027562134865937487, 0.021660800457799008, 0.010224116467205542, 0.024586271960288286, 0.07964034724448409, 0.010752456063138587, 0.05948283603148801, 0.06524953552122627, 0.027398977728028382, 0.06817735984389271, 0.05146584639857922, 0.03630566078105143, 0.0213262012694031, 0.011173565073737075, 0.045228280925324986, 0.030479928744690757, 0.04684768617153168, 0.030913546548358033, 0.005340970927915935, 0.022177185963041017, 0.025140553646321808, 0.016029504327369586, 0.008676417105432068, 0.016273763363382647, 0.04759104164051158, 0.026694822923413346, 0.047006229271313975, 0.013385940376403076, 0.013670785136387816, 0.018827546953356693, 0.022338658637766327, 0.011831490439362824, 0.0182801286490368, 0.03415515939039843, 0.021714438651023165, 0.05684449849650264, 0.05321981870968427, 0.012674511676388127, 0.08468644254441772, 0.02077202814897256, 0.0057449558350656715, 0.029264658955591064, 0.08749071242553846, 0.0345499751690243, 0.059324689874691625, 0.034007425353463204, 0.01825064460613898, 0.02523386917476143, 0.053202906224344454, 0.053315230911331515, 0.05349540231483323, 0.037606717752558846, 0.039269366035504, 0.010938932753301092, 0.11184459631996495, 0.08540140810821738, 0.05550700080181871, 0.04542924603447318, 0.016998562595940063, 0.02237154044477003, 0.04375677934980818, 0.029869159018354755, 0.024981189519166946, 0.025618557818233967, 0.032149311487696, 0.020559010561555624, 0.04991376878959792, 0.07547115667590074, 0.04351907156940017, 0.023756218375638127, 0.01358323885194425, 0.04125370777079037, 0.048972416802176406, 0.049424460224275074, 0.07099190274519579, 0.0367565981910697, 0.03162541799247265, 0.06230492424219847, 0.02738614832716329, 0.01901672251655587, 0.028079027576105933, 0.011296768373410617, 0.04004302487841674, 0.04841667965852788, 0.012140060176274605, 0.010767130231085633, 0.06263587291219405, 0.02156045530656619, 0.11566408351063728, 0.0796061490795442, 0.020194852691409842, 0.0280601931403258, 0.06292754797531025, 0.01108787627890706, 0.006235250820671874, 0.02578231885230967, 0.04138393560424447, 0.006597536358250571, 0.013920353708921798, 0.03950351829241429, 0.02928255870938301, 0.02469506996151592, 0.05384250011827264, 0.029844043044639484, 0.03998053180319922, 0.0325500814111105, 0.04612692252599767, 0.02579595401350941, 0.03293807452012386, 0.045086826729987345, 0.04915826754378421, 0.015205577913937824, 0.04227697589833822, 0.006871804029547742, 0.006859293116057026, 0.03992231010592409, 0.02529488134730075, 0.038637761891420395, 0.02195443818345666, 0.02719410595351032, 0.044873037308986695, 0.037521463220140765, 0.06434794568589755, 0.0334461072592863, 0.04161400647301759, 0.05270564183592796, 0.019431780691125562, 0.01541209513587611, 0.062079141714743206, 0.03418311842584184, 0.05710970051586628, 0.06343802344053984, 0.006177103762248797, 0.07145023957959243, 0.04745637618803552, 0.017671155344162668, 0.014914920653349586, 0.054072791510926824, 0.029821169629160846, 0.034511990778680356, 0.026565480578158582, 0.09216104860284499, 0.0070065886497364515, 0.027042750235913054, 0.018640256021171808, 0.009630772368317204, 0.025091878936759064, 0.03132279815950564, 0.018591655950461115, 0.05792415288410016, 0.016403031069785357, 0.02464951990571405, 0.022468209632539322, 0.01125335315841117, 0.009145427295672042, 0.09425726040665593, 0.03003913543320128, 0.03461911449474948, 0.012453363543110234, 0.018176231366981353, 0.0190597823488393, 0.041182305530778, 0.015076520553390895, 0.012561586485909564, 0.0196941481304488, 0.047017659193703105, 0.05743087828159332, 0.09160300104745797, 0.010451215352596981, 0.030976769048720598, 0.034386312522526295, 0.031523437571844885, 0.02604648780210742, 0.005193319587436105, 0.009874424115488572, 0.028282776375168135, 0.012666367559826799, 0.01673022235211517, 0.04638735105150512, 0.0070850251774702755, 0.030870310296969752, 0.05020349306453552, 0.05581146964271154, 0.011447705095633864, 0.024847611419058273, 0.041567068813102584, 0.07196626546127455, 0.050412339357925315, 0.031666306512696404, 0.0034364024343501243, 0.027721454888316135, 0.07416777911462955, 0.03477465168439916, 0.021337410667911172, 0.01932280627079308, 0.020749066523941498, 0.013034816315796758, 0.037448673376015255, 0.05679767958021589, 0.01031128955738885, 0.06646670520837818, 0.058695402927696705, 0.0345649843636368, 0.06796925993902342, 0.00843519196912114, 0.026463289811675037, 0.02004979886779828, 0.048229590590511046, 0.05086170256670032, 0.007569042865985206, 0.04093412456235715, 0.030164857794131552, 0.024156223250819103, 0.061052070398415835, 0.05374886567837425, 0.021732214572174207, 0.029299868137708733, 0.03809274560106652, 0.06666880007833242, 0.03883257947329964, 0.016601175169593523, 0.03101210036714162, 0.046244682278484106, 0.0070670448476448655, 0.04563955796350326, 0.03826112067326903, 0.056342776133013625, 0.03391175191583378, 0.06539515592157841, 0.045158642876361094, 0.020567521087027023, 0.02826267307890313, 0.019134528070156063, 0.0553309956033315, 0.0382131923522268, 0.07234616364751544, 0.02157840086147189, 0.025023004239691154, 0.025400904140302112, 0.020901309426075647, 0.025797412863799503, 0.01996862911619246, 0.08599608976926122, 0.032460202662540336, 0.039292917986001284, 0.0091502050303721, 0.025037667381444147, 0.03501890054238694, 0.038483965144093545, 0.05081026961228677, 0.04970667990190642, 0.03287267392235143, 0.05622111480416996, 0.07411176604884011, 0.014510249153577855, 0.010926054158647145, 0.053069767475660355, 0.04325407650321722, 0.10885148335780416, 0.09192835180354969, 0.05746139200138194, 0.06992815661111049, 0.11457591690123081, 0.011644654973809208, 0.07030983255910021, 0.0657133481332234, 0.00853246420488826, 0.048120020755699704, 0.04752594977617264, 0.09070503458912883, 0.06311196022267852, 0.005072495825256088, 0.022023094052981054, 0.03820770639660103, 0.027615930818553482, 0.02485870716295072, 0.03294826950877905, 0.028156847061057175, 0.018486135273373554, 0.03937028794150267, 0.055876076354512146, 0.049445993533091884, 0.025303739621969204, 0.01726509115126516, 0.007418276625685394, 0.01648054351764066, 0.07806250905351979, 0.02794474040690277, 0.03631312805893166, 0.04954510714326586, 0.0012474040413508192, 0.05689551415187972, 0.09826622171593563, 0.08546816916870219, 0.06627035753003188, 0.06636174262634345, 0.164383630667414, 0.1151848885097674, 0.1272341776639223, 0.1360277608036995, 0.11944463636193957, 0.19755118233816965, 0.1000717966152089, 0.12218076097113745, 0.146158492192626, 0.08277082962117024, 0.16512212104031018, 0.15463144039469107, 0.08632193585591656, 0.1532542450087411, 0.1376616731286049, 0.1373485970710005, 0.1361839867063931, 0.16512332883264336, 0.07015191710421018, 0.12828672118484974, 0.1403873890106167, 0.22742452791758946, 0.07728405975337539, 0.09118336106517486, 0.0985325195693544, 0.10276994361941304, 0.11545995303562709, 0.12622748953955515, 0.1534525536532913, 0.13964832866830484, 0.08189654403499194, 0.09244608759347882, 0.20890125472630772, 0.0951207640713879, 0.15139344414430006, 0.15689713667545999, 0.13994750832872732, 0.19133749790489674, 0.18815093460891927, 0.1504307250891413, 0.10121633591396467, 0.10769089670585734, 0.1364460505012955, 0.09165233732866389, 0.11326690071395465, 0.10882377877299275, 0.14942980451243265, 0.21265235915780067, 0.1589639407715627, 0.19023087514298304, 0.15965159530086176, 0.08521688729524612, 0.10085288541657583, 0.07889506473605122, 0.07342642532395464, 0.06899206327008349, 0.10410048293748073, 0.08848032182348625, 0.1387727606509413, 0.07683060158576284, 0.17228479097996438, 0.11104452210877623, 0.13453437308115618, 0.15551060464765343, 0.14818446205130645, 0.1307510110948767, 0.13169915521783487, 0.1559361003871475, 0.14883998116212233, 0.062438269944063256, 0.14591879291193827, 0.13615132203059538, 0.19861238396593503, 0.11152547451534442, 0.07691304359052863, 0.17097166287047522, 0.07681385534150259, 0.08652399001376969, 0.072846705360072, 0.18229027837514877, 0.08056147888834987, 0.1074550107919744, 0.15721679452274526, 0.16752602133367742, 0.08632456178643874, 0.13140692375600338, 0.15596311965159007, 0.10942936449178628, 0.11114209544445787, 0.10559610982558557, 0.1464496108570269, 0.14821085706353188, 0.06508718244731426, 0.1305973364838532, 0.1798213337148939, 0.15343079982059343, 0.16070276818105153, 0.0932502940829311, 0.1636669619807175, 0.0773001681747181, 0.08520042603569371, 0.1495703969682966, 0.09013480733015708, 0.15225792489945889, 0.1244942939707211, 0.15689086701188767, 0.10888100641646556, 0.11566929465958051, 0.18845829740166664, 0.1261605452746153, 0.1888521598385913, 0.20831573328801564, 0.16412977714623722, 0.0994505842349359, 0.10974862878876072, 0.16247818219874585, 0.10320531204342842, 0.09869141211467129, 0.11952592485717364, 0.17213054639952524, 0.1051179054858429, 0.1437966339290142, 0.18273657799831458, 0.1440195326826402, 0.12446875391261918, 0.13238089292177133, 0.12248314331684794, 0.10213859392596142, 0.24093513722930635, 0.1072852820424097, 0.1843001398124865, 0.19351627384977682, 0.14154203848115035, 0.1247634823833193, 0.13588942108409746, 0.10495353716292552, 0.15184958252523625, 0.1102412316415991, 0.1912079791405371, 0.18253947714609758, 0.11027270209576402, 0.12196970943893705, 0.15898162339414867, 0.07968453344489847, 0.18199579417705536, 0.16112967527338437, 0.09706273808010987, 0.1193744351289102, 0.11425454914569855, 0.15491753789995397, 0.12157854757138661, 0.09830006025731564, 0.10135666374117136, 0.08186215588024684, 0.12426440630640302, 0.1391205641308001, 0.10545481169330222, 0.09363593946077994, 0.1142889101590429, 0.12372449599206448, 0.07916047370859555, 0.09965803274618727, 0.150104553305677, 0.09695481708539383, 0.11208616835730416, 0.14672269406063215, 0.15581104638321058, 0.07408686381365572, 0.16142677861664975, 0.1014707051217556, 0.08022806035088641, 0.1231145201517003, 0.20145225657948426, 0.1000482514500618, 0.21170920905257973], [0.02724357963805752, 0.021116681530007293, 0.05964696008179869, 0.04100256160433803, 0.04897000461018511, 0.058489372554634295, 0.029895404752876078, 0.004469621702030833, 0.05806057234959943, 0.03214079926588705, 0.006083940480103982, 0.01962559064850211, 0.02606286763745759, 0.06760920211672783, 0.023427759929160987, 0.03763321115236197, 0.026247924493093575, 0.03403305022844246, 0.06649021644677434, 0.02141285697663469, 0.012811939614558858, 0.02446466321790857, 0.03366209174107228, 0.021629279113507698, 0.030004302838018963, 0.04926032599593912, 0.006576581500537161, 0.010373747857686664, 0.02514098451605865, 0.061220828842903884, 0.08269185493034975, 0.026037120626174977, 0.023322870289640765, 0.004108708925611738, 0.06875429102884871, 0.09992897856448378, 0.03510920676801886, 0.03196713840588927, 0.024532309766592722, 0.046294211942170344, 0.004155293747317046, 0.07313770188816957, 0.020387220761871765, 0.06480874560241189, 0.025459314131044915, 0.009329042264393397, 0.008505854605963188, 0.024635421644364084, 0.007058250185634408, 0.03676376012819154, 0.10071873904338904, 0.07796463716242995, 0.017687553839225854, 0.10502846099968467, 0.02411899881969605, 0.0151481568879847, 0.008454518342789794, 0.03545439110270568, 0.016657958372629116, 0.03259214718959161, 0.01835895236581564, 0.01534816187008151, 0.04225705750286579, 0.02813917800917157, 0.03749064415959375, 0.0302522870312844, 0.02720012286278818, 0.06504686389650617, 0.02732915647460946, 0.0201223054235535, 0.015729625775877918, 0.04982997989282012, 0.04014662021238889, 0.03988904492663486, 0.039828987792134285, 0.03335070523566433, 0.037011547546301565, 0.043499024252274206, 0.022054705303162336, 0.00995814091792064, 0.03089323460257479, 0.02825245094884719, 0.029311118248317922, 0.04816998128912278, 0.02095911043163921, 0.02890218554862908, 0.02847314446366259, 0.02693150102693055, 0.056915598788431714, 0.029392284607248645, 0.03507875750905701, 0.022212279794205512, 0.01448170657801841, 0.10414337313600949, 0.040267531760036945, 0.07720166524606091, 0.04141184714223657, 0.016703316742288213, 0.019171572689499174, 0.024361799005419016, 0.069660413478102, 0.047916277045650144, 0.014898528943636587, 0.040304104797542095, 0.03560536175167986, 0.0328253461048007, 0.07169031883989062, 0.01167157500250531, 0.014460007028122033, 0.03720477735623717, 0.05575469322502613, 0.026474531440596496, 0.027514374482312372, 0.02461292820849589, 0.017016799920903783, 0.015077606209420731, 0.014584168758509415, 0.02231706595713539, 0.03244219095047031, 0.04059439564922026, 0.06202798017433711, 0.031118515014116253, 0.09610981028527021, 0.04012605381597366, 0.028841195428477864, 0.039439722429960966, 0.04492172219657472, 0.003866139017710728, 0.022286625179861273, 0.0569032562364425, 0.03262632839115603, 0.035848253539630344, 0.040609801786818674, 0.02860207629523107, 0.023430713252829652, 0.021893237717449665, 0.0054727865333136705, 0.0294506929016539, 0.045521445372807126, 0.03968983383050986, 0.0248834923508444, 0.004006219603719988, 0.01245637793493058, 0.03788346504526479, 0.023144527538014308, 0.013001810676152152, 0.05550806610179799, 0.06947163825056382, 0.11675166657992772, 0.08031424786895514, 0.01728064487023013, 0.00645081969975893, 0.03647947431142841, 0.030608385601746183, 0.06632210261055402, 0.023008544031264525, 0.019151301455817053, 0.034328993276825974, 0.02735329875057297, 0.055179875676653216, 0.04601574795586722, 0.021334050223231316, 0.040434196923992465, 0.01948971570735531, 0.09083789853113038, 0.03391770266794732, 0.07859398517757654, 0.04489713887284909, 0.02794541046023369, 0.033723241316952875, 0.08447934687137604, 0.03326908425827112, 0.03984777642680066, 0.011963910789095929, 0.025337118455874066, 0.09082722517528705, 0.07889505795070104, 0.02789122943899461, 0.04876461884539042, 0.050497064633028846, 0.04640147815059338, 0.029123683127441576, 0.016454258767355765, 0.08601602512810912, 0.0353663240426353, 0.012989462186981524, 0.01570939695063446, 0.015159951522946358, 0.06499534273254019, 0.07660854421555996, 0.01147772348485887, 0.09941189416817256, 0.024383671581745148, 0.050393126638872285, 0.03692556019606335, 0.02528725461369114, 0.034342597903949876, 0.05230665306693741, 0.032247159630060196, 0.0501002336053976, 0.03082873984905226, 0.010122808644415011, 0.00849684705359063, 0.061109393036791256, 0.021325906106669987, 0.058067405197237215, 0.030025401884423833, 0.053022979093449454, 0.010273671575954981, 0.028635297369744097, 0.058474051233913214, 0.024242454873664037, 0.07186320956264224, 0.020822780872029916, 0.04009941453114152, 0.023591799162594334, 0.043351609126797745, 0.019453330963317837, 0.0359351263780679, 0.09975072741508484, 0.045930371287145784, 0.0697943087933319, 0.00967759043643517, 0.03946531337818929, 0.04810759338683315, 0.06277923379093409, 0.04659772065601178, 0.09636915315474782, 0.029429732954927852, 0.07038150621312005, 0.04006677021139434, 0.03434727301022836, 0.042561753652989864, 0.0108603236232219, 0.04349001330722656, 0.0477751247983958, 0.057766217073159556, 0.0408972020793174, 0.11942000554076262, 0.027977186255156994, 0.06440938703183617, 0.04663900272654636, 0.03143448841625026, 0.05223654343613556, 0.00987770822497883, 0.040388833465320725, 0.02941015043428966, 0.009837326061512743, 0.0376341000332364, 0.03760990686714649, 0.10331890559090035, 0.04574766555534942, 0.02148580627648958, 0.012543037883006036, 0.003630000349533345, 0.021314903661342602, 0.03449142438226512, 0.03968205103384597, 0.03788922580757311, 0.03653844578989914, 0.009413937173251594, 0.05201803141140512, 0.04476360318117908, 0.05775842070579529, 0.025953387708536217, 0.06304843577423266, 0.04167317133396864, 0.02586532404114093, 0.02737330874827291, 0.03557584887104375, 0.06146264515284981, 0.02830346830056182, 0.07005088323993341, 0.0475651283881494, 0.02657156534093831, 0.0536153028453035, 0.03050510578655771, 0.02755304080035005, 0.035703491486076794, 0.032148310648543496, 0.02951592725834676, 0.06551706830837897, 0.021201566260840212, 0.020264127724138752, 0.05573651187920144, 0.05526821415073105, 0.026846131143559302, 0.0360671116172203, 0.04349269352055021, 0.042328452957527976, 0.029119466032300676, 0.046495024380939345, 0.025138585894767727, 0.023060686054772565, 0.08780403275574956, 0.0031861097377259284, 0.023370949584724646, 0.038452949308391125, 0.05006371485069394, 0.07962282747030258, 0.033454303962311575, 0.03559635080663221, 0.08087517919817142, 0.0388396260594683, 0.014145132004549461, 0.030241837591997216, 0.039471932487296205, 0.05113708261134369, 0.022317641015563692, 0.04826660128310323, 0.05305404242660318, 0.03698864698942218, 0.04692705101998789, 0.025898450120751346, 0.01360742184000888, 0.06285572504358632, 0.054123081133833954, 0.05025712447240949, 0.02032918226905167, 0.042530924414417574, 0.025413682651040808, 0.046368447065885575, 0.01357381315236645, 0.028227664064615965, 0.10069293435662985, 0.0391128822895033, 0.003982793182201151, 0.05245831242895552, 0.05387526657432318, 0.009480769479913371, 0.018464590090193918, 0.03362570530069726, 0.03633883775078824, 0.07119021138974599, 0.06784010758357388, 0.026435454608872533, 0.01621026435999998, 0.02882035422538008, 0.031343035466436825, 0.025044274616188238, 0.041499646180974584, 0.03255778617624726, 0.018258471507579088, 0.020024726998859217, 0.022603350059528435, 0.017708388256973455, 0.06853200974208967, 0.05075490115476506, 0.06783127305763108, 0.016430747528959597, 0.02693270373025111, 0.038356665189244916, 0.16854642943612166, 0.1061149380568947, 0.14096285455993243, 0.12305628827639989, 0.153056886313217, 0.15895294850426062, 0.07204600011131593, 0.13973860096718582, 0.13782574289611407, 0.1601250363247735, 0.0885619835129806, 0.10143875969307763, 0.11033269816211291, 0.151596692523786, 0.1571116623069559, 0.12504051466073307, 0.12792253786964075, 0.19222286396792956, 0.11432416683861188, 0.09274971165827342, 0.05225230919729386, 0.09650051074900798, 0.09779616658176694, 0.1541221048682928, 0.10204113594123296, 0.12424683224942003, 0.12584555574825831, 0.08780469772006784, 0.05553877998941711, 0.10548893521939005, 0.14361398587269442, 0.12921061446624144, 0.13418433043573583, 0.12324179975049836, 0.12317173422447272, 0.17791667234684738, 0.2012084453765835, 0.0966383076405951, 0.14146479405462742, 0.08911440601306302, 0.14484073647430964, 0.10591863787599973, 0.0985006419941783, 0.1721125923629318, 0.18080306532127516, 0.15264319708304747, 0.10873390680977277, 0.14279875318918908, 0.08752883252288614, 0.10446633544883557, 0.13576211434389862, 0.2977632592831339, 0.06579047720879316, 0.1991952048348529, 0.15505840176982538, 0.11305928256894861, 0.11044688882040125, 0.09654580296150275, 0.07567933800497226, 0.09649676523570504, 0.2107058186084032, 0.10154238556112562, 0.19570125160472734, 0.09092922934464046, 0.17484152450093202, 0.0860931881304298, 0.13492355362645217, 0.24085531436971255, 0.0868108474782535, 0.149422286344426, 0.13755787084145205, 0.14007805846631527, 0.15135613828897476, 0.07915164596800293, 0.1942965891212225, 0.16679536125489644, 0.10636566353163548, 0.0984083137341908, 0.12047967367938586, 0.07689605985901185, 0.10566631105861493, 0.08420752574290548, 0.14865624744977268, 0.09241982150290694, 0.1135084523952433, 0.17641457223466464, 0.11567827846322741, 0.21524201519787312, 0.11907790175506047, 0.1047578544488975, 0.13210063081766876, 0.09124387281813792, 0.05969611315854958, 0.13681235084576265, 0.144021636141198, 0.13610093402011053, 0.12574467116168567, 0.19063051869826658, 0.0562774739228189, 0.14820067903825215, 0.09813434843506132, 0.13729484352682317, 0.10521731765142509, 0.07548113792602505, 0.07393295850072588, 0.128943638077804, 0.15420204986418995, 0.12427960549082075, 0.18238327838480473, 0.13542231757725987, 0.27393272944859093, 0.21229216562850134, 0.08802630047180823, 0.179601895489863, 0.14200029389134475, 0.13136165189955915, 0.10157414099999837, 0.1068429382784026, 0.12144514758672033, 0.08478285558521748, 0.11143567719097648, 0.1037634749497686, 0.1320930312254599, 0.09926782761301313, 0.10367124847003392, 0.11745791296873774, 0.1822952316807849, 0.14302128553390503, 0.0825181296095252, 0.13815278320440225, 0.10011844589774098, 0.08776343600558383, 0.1584691530359643, 0.10297641504023756, 0.0969832477026752, 0.08436850139072963, 0.1511184067598411, 0.16810105262058123, 0.07847168602581535, 0.11005020367779902, 0.12274036237171718, 0.11166591769350426, 0.0825672826862761, 0.09635777412248508, 0.092448604958398, 0.1302642436431987, 0.11829023116401263, 0.14615917072764464, 0.13478454894253186, 0.12665020328547272, 0.12085345147975854, 0.12926978271986755, 0.1593231029276337, 0.12414365421448435, 0.13444184804601328, 0.05997689773461648, 0.13939371518790722, 0.11991950230939047, 0.1480627464396613, 0.2106098873274667, 0.08182797128600733, 0.0992005712219647, 0.18144989918385232, 0.14680282904633454, 0.2627032463039671, 0.07645290185298238, 0.18564175282205853, 0.17014235737068312, 0.09566835540213756, 0.08497048408857413, 0.18046263073171886, 0.1268883283649172, 0.12771604609276566, 0.160029105043837, 0.10440765574042286, 0.16134078108838626], [0.007762909650669566, 0.03739292833155819, 0.02532534417696297, 0.02792868117934891, 0.017139209334605505, 0.03240423370152712, 0.033673609873013835, 0.05052141386217304, 0.039618095715663264, 0.047945929025965076, 0.025859924598730037, 0.06365782807448081, 0.0462564820024584, 0.0840406943378704, 0.033195721052054844, 0.015467390650883317, 0.012811956577934325, 0.022209887958264778, 0.015127790659399969, 0.05628550099208951, 0.054877076031906266, 0.04272477508389524, 0.011223194821338569, 0.009634440698261772, 0.042136960197240114, 0.018737435806542635, 0.02004867249966732, 0.008423678078023451, 0.03528671492157238, 0.024105570611677, 0.04968491928385837, 0.05279563932812639, 0.027127156599557826, 0.022529225197753737, 0.11234839500061103, 0.03508059973163264, 0.027363090010892068, 0.020968184141176086, 0.012378687371632882, 0.06720847969076463, 0.030160040195499147, 0.07602444770080702, 0.01664221296752138, 0.04774619545787573, 0.08435231833053486, 0.07472267148217984, 0.001140676950204319, 0.033998729927199225, 0.010224315786867269, 0.056643119480993064, 0.05436703482908862, 0.010210650939760464, 0.04794562368520668, 0.06301785420094218, 0.047884647135755846, 0.02700764113771064, 0.05536087150020259, 0.07185050738709313, 0.045668636581727436, 0.01739759207703173, 0.004187600071808057, 0.020373957098594735, 0.010250872799328395, 0.03471446902092014, 0.039082290538187535, 0.031248739454895258, 0.009618611324445477, 0.02730452056441988, 0.017987305165401528, 0.020803430749635612, 0.03033902755539332, 0.008866300041388189, 0.031054149182247262, 0.04832067713141441, 0.03610484155693224, 0.011372630284833056, 0.023697850793333988, 0.01118495173951877, 0.07745280462716307, 0.052785508800297976, 0.020090767115886723, 0.02499391374710415, 0.03558197943493724, 0.00577031056829063, 0.047339657986802716, 0.04451301680611713, 0.015164322984804, 0.03908314549231103, 0.013484282152993339, 0.04488479292818478, 0.016929251940122673, 0.05166190569954259, 0.011491316237619944, 0.02881440008059144, 0.02473010102819119, 0.06774027472628014, 0.06437564348535878, 0.08841855478073869, 0.009719101512538535, 0.042674746696970293, 0.0445850704397474, 0.031204482008303915, 0.03099659244929041, 0.030643313191831112, 0.05477684623162661, 0.00900591371048774, 0.021652624110824296, 0.013053469243459404, 0.06578306082103934, 0.020091610195647393, 0.018634429101699164, 0.016249554930254817, 0.08361861841487032, 0.014566988251837236, 0.03220513117100511, 0.06224117587719645, 0.023637593491002917, 0.016811227558978965, 0.034230161258684735, 0.05141574676547732, 0.05112976461116757, 0.03618474244805319, 0.022405363719112108, 0.05222589722169297, 0.034353386610746384, 0.04561156500130892, 0.033551246260425875, 0.06443557169820581, 0.038712315926594396, 0.028660328526582037, 0.10954749743853297, 0.04425403695287449, 0.006019320197603, 0.007442278953801308, 0.01922425754102213, 0.03964295723874654, 0.027828336028116088, 0.0450919225279774, 0.006744061754683831, 0.0031398200787537333, 0.06872645073703357, 0.0035767590992950966, 0.03696600766852498, 0.01313628613882299, 0.016373808262869716, 0.05887140134083373, 0.04600634685318385, 0.010239425913563796, 0.010284581570886075, 0.03652373854336994, 0.042252144909330776, 0.012318106068830405, 0.025375163914369683, 0.03505007583381874, 0.04253541970891612, 0.05831570830196142, 0.012393307256778436, 0.06659770996442863, 0.023567667064656104, 0.045216715295932124, 0.007363729195536247, 0.022516468739403144, 0.05258808903662222, 0.04511875180261476, 0.015345841280317732, 0.0642580601519772, 0.02509730212789561, 0.017784004199451635, 0.023981858410739472, 0.039749782399407456, 0.047623747028410435, 0.06937266034739357, 0.06829444784671068, 0.032784142065793276, 0.017070826575426117, 0.005377046090351152, 0.02521996259955423, 0.020831401659441844, 0.022431487317330072, 0.011554640518235309, 0.1026486147727285, 0.02783746741312955, 0.03150797375876989, 0.03460151329636574, 0.04936565498688391, 0.042699425015598536, 0.00585595822693514, 0.033366549028349776, 0.050839955519352636, 0.0068501184744361255, 0.038564788842839856, 0.0034295195447547095, 0.03353182998086725, 0.028160618019423315, 0.059240110484617095, 0.05342428505952869, 0.05394973579261984, 0.036150099842676094, 0.02848576182233436, 0.03298572803448353, 0.041212585155985186, 0.028066210049603666, 0.02560299901025636, 0.009128726852525557, 0.015571155618610126, 0.014936072286218405, 0.02193506940134934, 0.06339647674134799, 0.026797186716326644, 0.02566593822224864, 0.07820604635136467, 0.03019345804516758, 0.011369830479712358, 0.026677047002262304, 0.018481767204191004, 0.047482635493257215, 0.04118228517472744, 0.04928024439141154, 0.012989418082205313, 0.0736982464524252, 0.04393567850014993, 0.022046125227851526, 0.03493750687422497, 0.00794891984800675, 0.012086907983757555, 0.032965846958437135, 0.0421286820700126, 0.013774590816215744, 0.07873460477484123, 0.03347350650333932, 0.03348700935021043, 0.014513290686798947, 0.01931249593118472, 0.04004836155633841, 0.02502058695868722, 0.03570347113002624, 0.027349244503836547, 0.04215394053608179, 0.03888836183718272, 0.060429426309253485, 0.04242542239704302, 0.016770086284460764, 0.024571766577927128, 0.04128493055967348, 0.045648860678608925, 0.0029070562741253525, 0.015667203946837356, 0.04055008731250252, 0.072359829342791, 0.01753265786516879, 0.03705379652923771, 0.03662194970196911, 0.01836004650353321, 0.020088465185835958, 0.02190237758415086, 0.02368438696222646, 0.015288140358669417, 0.025191326725429723, 0.03664378835154431, 0.08553438740117209, 0.047644415205078464, 0.002259216271340847, 0.02475263347982296, 0.011142924976801234, 0.014428643443222557, 0.02883305979360427, 0.020192121587959782, 0.04358346114999481, 0.05051403818652034, 0.05628712608345917, 0.02545066620223224, 0.05566275851534946, 0.05447133244680507, 0.061532554615821154, 0.01248148373062057, 0.052598487585783005, 0.01984218241912978, 0.027290193297501122, 0.01992908918431827, 0.02140637018185641, 0.07267824547099215, 0.052509161843253035, 0.030306600366852114, 0.02614243435008185, 0.020370191229241233, 0.06569406416799341, 0.015366171885813986, 0.010938836062060935, 0.03572006470390728, 0.026411336081634675, 0.03446855775213667, 0.03909283497237733, 0.07132900572781052, 0.0506442829833499, 0.020382669488234178, 0.01547900547406503, 0.043334262379045994, 0.03206384660942214, 0.024561315442302396, 0.045034491323999, 0.043972604375864775, 0.016595159956653203, 0.024175381687070643, 0.0291927512069898, 0.03262163292882698, 0.05043706517400486, 0.03214893150808556, 0.047013859397598674, 0.02798323878752334, 0.02502286683634988, 0.025445273545171534, 0.014281126537493296, 0.06305940090013401, 0.058461274419512065, 0.05994632973202637, 0.04926200537011027, 0.06281594253544297, 0.01069011481013149, 0.01960540932070996, 0.055412426590919495, 0.03108704455995134, 0.04631931773786034, 0.04558096307196787, 0.08347605142210211, 0.025604766593979936, 0.013847644440829754, 0.04174453625455499, 0.006943318651922579, 0.02568831291448857, 0.027886866458824704, 0.047200921324214766, 0.06803557316639594, 0.004081591273591454, 0.06703740744186298, 0.02505652217327484, 0.022853634486507093, 0.04175928421318531, 0.02644507453909942, 0.06532465613314084, 0.03201771979885442, 0.08122098778507539, 0.005622360248318208, 0.11784155666828156, 0.04420510779267975, 0.01466317567974329, 0.04736272478476167, 0.016308981027188044, 0.014777890506333538, 0.02408192027360201, 0.019653626019135118, 0.04376695058973772, 0.04770030274188944, 0.13702570939702646, 0.09637963652078595, 0.1574083992413112, 0.06374845321157149, 0.14562797280294554, 0.13495079002210073, 0.11878948366003377, 0.19435288038636955, 0.11790126774992261, 0.14393121456461294, 0.17757555922227247, 0.10290854118232216, 0.12485437893441745, 0.13217023493988173, 0.10746654588729143, 0.0971211531598653, 0.14995033586663858, 0.07458580418356828, 0.12356124046657767, 0.12076051932360445, 0.17562953435948916, 0.15766758604773454, 0.18096180180353777, 0.24152603266494616, 0.08933654480746814, 0.12663999811879226, 0.09599046276084014, 0.1383988471435649, 0.12241660617291927, 0.11435848713985511, 0.23713889664837293, 0.23905117117932864, 0.08978105309818472, 0.09587207875613656, 0.21697818275008882, 0.12185826684747424, 0.10729354659893683, 0.07525005604007415, 0.13824479255293096, 0.11850282975605556, 0.13864104343312128, 0.1182881412761552, 0.12701655791274138, 0.1571104545146227, 0.14005426902856144, 0.16359600078846726, 0.14876264174069675, 0.07491287841860737, 0.13703600955860956, 0.10265269276819058, 0.17997578185583862, 0.08386987314692565, 0.17960460962993757, 0.1607203558087349, 0.17671472898551396, 0.08155454881489277, 0.08443913010082074, 0.21800205138112816, 0.09357692727020808, 0.09268744249961205, 0.09712128886686903, 0.12149219720491342, 0.08716645411082677, 0.10983141006103583, 0.10950384049543313, 0.09689934006226913, 0.0882602118487869, 0.1252030645098005, 0.10842856605138097, 0.06750577302383524, 0.09197888230638844, 0.10610395936029297, 0.11486156657338142, 0.17314030150217669, 0.11681360325642995, 0.11477683112025261, 0.08028774429112673, 0.08250300506395952, 0.21770010329782963, 0.13480787697647298, 0.11746323268328394, 0.07767109612801246, 0.0918247327208519, 0.21070560147719725, 0.14855537643390043, 0.1519095107380833, 0.09232461625444037, 0.09790657780000142, 0.0856302711846573, 0.13473524658807687, 0.14931020593004568, 0.13935810567012855, 0.1600252373942307, 0.1891094603176628, 0.1387800888291427, 0.13566414745790617, 0.1519009204847472, 0.15371042410177843, 0.0629963514262012, 0.05539213500118681, 0.09121781028807163, 0.11667336363877569, 0.05428303897913013, 0.15973380660372122, 0.20680988766252995, 0.08522187452763319, 0.11637959868780204, 0.11544638233525412, 0.1745326689311436, 0.11121714141752038, 0.06820406698222671, 0.07009809570653097, 0.19736225104757718, 0.22908362746238708, 0.13824867377323763, 0.20956180856696197, 0.1546867409987109, 0.21845638485891478, 0.09418439931635346, 0.12775491257863386, 0.14530807068305357, 0.12541829581771577, 0.06775531106229339, 0.15516143052705697, 0.13507908742342675, 0.10764010157436132, 0.0874816607683897, 0.15670357777604035, 0.10287757284407105, 0.13267251370208605, 0.17469988710113935, 0.15282615726547583, 0.11192606123430388, 0.1685265212186745, 0.1214763873389789, 0.1356306413986853, 0.1031453295477799, 0.24977077596953937, 0.17678165967975343, 0.14828829147986003, 0.2014156835419791, 0.06847852082656962, 0.10622802948845284, 0.1921023561486176, 0.06805459250296865, 0.11532930790313653, 0.1392913106828928, 0.09666161531848566, 0.11348729567336184, 0.06670282860951764, 0.07690171884106738, 0.09489869313048464, 0.1674378253519535, 0.12495567064200129, 0.09670209671769824, 0.18809055856295995, 0.0749462962682758, 0.1535392975700753, 0.10168670317424194, 0.08669232776654617, 0.12326732623789992, 0.08469986396708659, 0.1631913496447461, 0.14931851119867393, 0.11529094353318214, 0.14722870476543903, 0.2656075933149883, 0.12400325174842562, 0.13783658588571207, 0.15176007018557616, 0.08803517570985214, 0.14645818753966264, 0.10002158502382891, 0.092571806561734, 0.10565063011433397, 0.08189633368913617], [0.0492957794506635, 0.08765999334199087, 0.02753649981293295, 0.032911163821284256, 0.04523273550772241, 0.05288184041689549, 0.04364579137680786, 0.02317797761809613, 0.004539635913845683, 0.025073945256216184, 0.016692322778648565, 0.056896443744855266, 0.011422536535454648, 0.038458041713706086, 0.03310154717681663, 0.07277775263147694, 0.02003967173264495, 0.024937032156490853, 0.01989243132993579, 0.03399981897590416, 0.041386900802275965, 0.06088833989841597, 0.019464567503226653, 0.02693016261660627, 0.03646363051874297, 0.010548452813444393, 0.025541676407946006, 0.04017276416665741, 0.025441117518182312, 0.05349168394293104, 0.031401799991726875, 0.05278935270117862, 0.024939547825072492, 0.013119905455304044, 0.03051702764683536, 0.03084455310766186, 0.019036349141970277, 0.04172636169408049, 0.04059928110135453, 0.04704595749665584, 0.013428437024621027, 0.025323780153744986, 0.04830324895946043, 0.040394852070936134, 0.04236488011000412, 0.025083560097430433, 0.06981991670493569, 0.02276376761229975, 0.0702308239415288, 0.013499622133427432, 0.014028434159367211, 0.03528825180338962, 0.03714092042563217, 0.01991823092768235, 0.052971627563238144, 0.03506746329367161, 0.0214751532766968, 0.04407559920634542, 0.012534417943762881, 0.01320638389526201, 0.01792312932333776, 0.027032685865248953, 0.019981232904163853, 0.06551881214337689, 0.01898324359873576, 0.013921819344562079, 0.04565214478809919, 0.07043742428400687, 0.027392217822905098, 0.03909773399521198, 0.042385619532849104, 0.03548140697447317, 0.03275744171280946, 0.06148486038936036, 0.12913137514676365, 0.0430656744699393, 0.02451110045824732, 0.03522721757846219, 0.07243495674005576, 0.03487407402800662, 0.01177423565448927, 0.03508048098800438, 0.07551141415855714, 0.07278390694409609, 0.038398927742881436, 0.004238629721969898, 0.02237920619414321, 0.03264888968052609, 0.03868781741974609, 0.04492597321846655, 0.029646742024591992, 0.013654066033528318, 0.01344291356924389, 0.016952790319919586, 0.06499384995549917, 0.044186845022652826, 0.041588571587843556, 0.038897067441471984, 0.03094450810125896, 0.04919436560677631, 0.04416549831096615, 0.018008421175181866, 0.024766438274777362, 0.05373487428628972, 0.01938133839783924, 0.014099800776291107, 0.023077517115910138, 0.06338913499244622, 0.04436315895457353, 0.05735657869705132, 0.05832226973559175, 0.030519219314945594, 0.011988199798257222, 0.06462518830916711, 0.04035933076270989, 0.032458940587405644, 0.032027751939105134, 0.015114776357742292, 0.03736608887889555, 0.036683194272752316, 0.03405005770868488, 0.03887300319703562, 0.02641878300346434, 0.007812524131233138, 0.014552179225055235, 0.054820611740329435, 0.033228711424661536, 0.024727017086531435, 0.005013672776320683, 0.016497635814760412, 0.028675931439335858, 0.0464455490000546, 0.03869941358321479, 0.01374686841986009, 0.031195504990007197, 0.012618331521350359, 0.03520904980333788, 0.04575581136824829, 0.05801040825567075, 0.029058594655777727, 0.01967087437930916, 0.055432857280331, 0.018355213637862886, 0.025240430608391762, 0.039754437149635384, 0.046914749180099795, 0.056666640897414515, 0.020395710931292603, 0.13679337900664124, 0.003437815059442073, 0.026086054875382354, 0.026923553685524633, 0.02713229989499918, 0.015474527142941952, 0.03332579621512975, 0.07228042038955859, 0.04189841103340898, 0.014239608676039746, 0.008634779652181481, 0.017671024726171578, 0.004861011302896908, 0.031003252270498445, 0.030536308219390254, 0.027750392710523944, 0.025317766637142216, 0.05586036826883044, 0.03656380942889622, 0.02332846650720707, 0.0500863270301904, 0.02767700745191957, 0.029505657630839517, 0.042717046570032835, 0.017075530519442897, 0.0495875087965812, 0.00930913319877748, 0.02718412809606109, 0.04355241138754146, 0.051848781029028554, 0.00715377349739096, 0.03439648036978074, 0.04121661226132086, 0.03668291946606977, 0.032199153277490816, 0.04583993613986032, 0.04724844252424581, 0.02965223476556795, 0.03645338124728628, 0.02767201343418232, 0.07629953258271728, 0.016141477872484496, 0.012927278693366264, 0.08444670933697905, 0.05565758129315717, 0.014682164482240165, 0.09197685348668269, 0.07534332067838737, 0.028609492682984898, 0.06943820004484483, 0.058395741507411, 0.03749401308596134, 0.046048083542180915, 0.06323232554963656, 0.01999587399352874, 0.026074631738343408, 0.02734720041709287, 0.09109831348593746, 0.08131761795708112, 0.03400672306971891, 0.045269973509545834, 0.020677540451288223, 0.04434431603710566, 0.02521251398138702, 0.014966077104743038, 0.04739907390571066, 0.03490063528131161, 0.02937401844454663, 0.030143711250275373, 0.03267044673806854, 0.03281916125810572, 0.02178939471819571, 0.022557720275861875, 0.026922393390642743, 0.0485711990456496, 0.04075916091512356, 0.019423399087307707, 0.05633320539657559, 0.036852756781237464, 0.008123805463713194, 0.02191389910876751, 0.051756941314254484, 0.022418132051825523, 0.020633712178096175, 0.053029435354151895, 0.006840624921356461, 0.03377499318282519, 0.0500302495035742, 0.063332110909479, 0.047443667227136235, 0.041143157452877076, 0.048070558945515325, 0.025724154830511128, 0.05993193121893065, 0.022007787999297892, 0.0340920183142381, 0.024756073652367507, 0.07831827604344913, 0.04378073163596647, 0.07118768045412642, 0.022309641087693826, 0.04757595441437193, 0.06806684684540544, 0.04476059387837138, 0.05153677027140345, 0.08767550465251718, 0.03444190150392907, 0.10240863050733294, 0.037607589670057805, 0.0719570577410715, 0.08075228972094399, 0.020906427276453803, 0.014750335199226226, 0.016676735132932663, 0.02323647921106645, 0.045881177498293776, 0.015836123543392335, 0.028945588041096926, 0.05356348312592932, 0.06477016410125153, 0.019648421655542085, 0.050108023187411685, 0.040883926541677544, 0.04263883523110833, 0.04562006365241749, 0.017929451573374014, 0.020778121393440024, 0.010038141892956836, 0.0211346525299762, 0.054764242443655214, 0.06144878268241882, 0.05555182143247553, 0.0008005772812923949, 0.053723641139056, 0.0634162492517914, 0.02155760715582541, 0.02267599232228739, 0.016163788103897656, 0.059319879061409404, 0.06789697560348681, 0.007486816296087844, 0.05062051729432174, 0.0427632005220013, 0.016011372175333754, 0.10202787736696856, 0.012602680262976458, 0.06653470120259694, 0.021693911270371506, 0.10312973002770118, 0.026171646978972212, 0.008048878234278942, 0.03914711098851902, 0.005497123888095042, 0.060592593625187874, 0.017236482418541397, 0.03670828989041703, 0.06441309183303799, 0.009148423027779375, 0.05937261480305876, 0.01609747826920024, 0.042828658795250316, 0.03339910174586943, 0.03685804256903274, 0.03751620796642133, 0.007790881408644574, 0.07936431241354772, 0.02881476648950151, 0.037737664833132706, 0.0758019085707409, 0.014017547064992999, 0.04698470953319754, 0.03898096151117768, 0.031155542670083896, 0.10273323487490416, 0.04926130987171616, 0.03873816132545471, 0.049585106782615185, 0.06637046858668327, 0.016899654242609228, 0.029246457253715823, 0.0562501119981919, 0.0853767908577408, 0.03633070211591465, 0.10066918563097715, 0.024389357705201422, 0.06352054686950785, 0.03140924012820635, 0.06612155480044228, 0.10047049700681653, 0.008742799882643988, 0.006874689075630158, 0.03518453772578921, 0.005795192871508854, 0.03202309040352702, 0.029169959215713397, 0.02329147108165281, 0.012031821966437357, 0.03854648536071181, 0.01972824621147343, 0.07809449519429888, 0.03388232724475009, 0.002132074924052826, 0.049741987471601794, 0.0285714879365904, 0.1931814711008753, 0.13340611862284796, 0.14727176459772245, 0.12024637976927416, 0.16795500474316732, 0.11679837693061147, 0.07395561478499856, 0.12147034837731294, 0.1037558007187077, 0.12015694885381631, 0.16313538407640799, 0.1366020864141839, 0.11957842989691667, 0.1250820138624736, 0.11302935917462621, 0.14562479725905828, 0.10320288967341185, 0.08885382820985147, 0.19594316290957586, 0.21274869755974837, 0.15847018440919264, 0.14262386757348264, 0.14964468298213823, 0.11561596180711474, 0.10255741288087197, 0.09364863485097885, 0.09875242598354816, 0.08983936639768736, 0.08424063825181552, 0.1607464658362525, 0.1142019626817533, 0.07286534471703426, 0.1333236630473818, 0.13124654521899565, 0.07940484809556178, 0.09015704970806837, 0.10767709530357804, 0.24013650151235716, 0.09719455029283251, 0.11918971075543336, 0.13938821905425616, 0.14659168251923152, 0.15016469864973, 0.15686793252825737, 0.10981226180280958, 0.10335894594235079, 0.11984144364084516, 0.11751698622746126, 0.11208106577396393, 0.10335064067372254, 0.09824908870671477, 0.16535388146127972, 0.08169283425169331, 0.2601633540221623, 0.13377969286271504, 0.11753641947039536, 0.10364866003926311, 0.15755912901035377, 0.10428442699568612, 0.15362005680799484, 0.1216169526534421, 0.14138752248670372, 0.17679627532405512, 0.2251516527363232, 0.16691928889070237, 0.21182500783886227, 0.097575344145298, 0.1985790000430175, 0.09751044227076427, 0.0975267474672624, 0.10781382010983569, 0.12647918531937258, 0.10562373298619475, 0.13698661220925196, 0.2797652264790875, 0.1013940917328, 0.1205153510506664, 0.12128517617072378, 0.1606952364423445, 0.22595965223652975, 0.06896348337509803, 0.13284669364137308, 0.16170961915382318, 0.08848326666546719, 0.13132000342011452, 0.09433347345995051, 0.14141528813966683, 0.0920982366161687, 0.08839123017553772, 0.13867754861712456, 0.11059779500854866, 0.1710780028785978, 0.09634974026786429, 0.12232188268431596, 0.08457970898598433, 0.09110152974192585, 0.1486461101365941, 0.13991434153701576, 0.12668870336243085, 0.1392322238534689, 0.13686033684228147, 0.12326282076537609, 0.14599039192710603, 0.21473908504205091, 0.11139217631093093, 0.12630990440292017, 0.23092017748526164, 0.21051261254719325, 0.09125409155551877, 0.09326836347047772, 0.17832345409052713, 0.25770722010305946, 0.08507676981389523, 0.0763107216251748, 0.123526431620121, 0.1037648863026074, 0.14129445462354592, 0.12766128831676074, 0.17933619474726065, 0.11321041945900236, 0.18161736162645475, 0.1104788953172309, 0.06542092668158667, 0.14773681892880372, 0.06812579796782561, 0.13082423859408923, 0.1110423779381173, 0.11503004681851182, 0.14458699151873589, 0.06846190350396292, 0.1330355435077633, 0.18037800384419306, 0.08103520489696946, 0.11939508973487786, 0.10018887104732649, 0.10857580815042768, 0.14951767479734762, 0.1322271233158452, 0.12358777118580681, 0.0894519771848406, 0.16664858055966242, 0.16336305971656526, 0.12323698215186596, 0.17619537828224047, 0.12808002584746905, 0.26349059119820595, 0.15212556985872133, 0.17176193903599465, 0.18527189695409366, 0.1193152397338833, 0.10099086551261799, 0.0966493474053485, 0.14932978845068387, 0.15775730194790022, 0.11264348309487104, 0.17352919706276485, 0.2443478698176997, 0.12404751937304224, 0.10398489449705396, 0.1893168884728636, 0.17166976683906146, 0.09585611961249794, 0.15900834410318307, 0.15267378544168814, 0.13170458349798406, 0.2071942234677928, 0.16063933872750827, 0.14382194328520978, 0.14001572823950223, 0.10871297400444746, 0.12610487826168537, 0.1584091026868139, 0.17737298937780516, 0.15693767235747405, 0.10324487742036581, 0.1481255923530885], [0.039069011607872586, 0.0603736439453704, 0.018177486656765853, 0.06590242870151997, 0.03940741737772312, 0.04358248745224305, 0.03932801181716578, 0.01791201322339475, 0.05916866074715342, 0.03185547868322049, 0.024109428083258014, 0.0269406646423574, 0.053074442581938844, 0.02306165127083659, 0.0804631184520466, 0.012181410100311041, 0.010972596571913787, 0.025503245880827308, 0.0554836591971772, 0.025787457058738385, 0.024384774201150452, 0.015971250399681072, 0.039488716050982475, 0.039345565518098216, 0.025130591055910503, 0.02847187899585281, 0.04977634169959596, 0.052481233341885467, 0.011832820367999375, 0.081034933482962, 0.010334287653677166, 0.035056715298976214, 0.06441008592290537, 0.029546715784817934, 0.041641867120883296, 0.019474331622145007, 0.023863778050456728, 0.05665542810623135, 0.029196347442588637, 0.030603646034640924, 0.08789682920489993, 0.038210613919155936, 0.0268020789538111, 0.03861114974798901, 0.01187439336042319, 0.05537929372595889, 0.05432240758091211, 0.07331584447196551, 0.054537265694567134, 0.04562764288857579, 0.013209482255790914, 0.03741996795205133, 0.04500368583415236, 0.07590342419488089, 0.07219218369573355, 0.018588575401476452, 0.07075541972049645, 0.03918073918404324, 0.0502455690210419, 0.06629237599138703, 0.048262645423944504, 0.05291319212743214, 0.034929208390946896, 0.0251629486946123, 0.025806523892762404, 0.01688485200117741, 0.003997144197845566, 0.05947733311248677, 0.032336967132453404, 0.0031633198668714613, 0.05489028371604426, 0.02256746743140476, 0.039187331151749404, 0.06512028138552393, 0.017254059868199483, 0.024901393800973892, 0.05528546590358019, 0.036970713308879306, 0.06417151979569878, 0.05286365907107081, 0.04554057666765792, 0.058628411165305545, 0.03957833017089537, 0.029327002753104483, 0.0506545763595828, 0.020370225155992166, 0.05050254041062934, 0.049942586171839914, 0.0315340193254607, 0.02823405247181654, 0.03890568483620882, 0.024235030004222478, 0.03639862686395645, 0.035412871544914584, 0.02844301241982196, 0.006359582608898303, 0.011666675131501896, 0.013571950573740261, 0.024624046004776443, 0.04195286346865552, 0.014116824371740222, 0.05492521130612918, 0.03432992286980152, 0.057476754034204144, 0.03445972322619387, 0.03485527860799006, 0.07248214206525258, 0.01098117749539337, 0.02483885662098016, 0.027390251767688563, 0.011829382739961147, 0.021111555197941403, 0.02769011674847986, 0.11123272058154855, 0.04200218617916107, 0.019875713923413838, 0.018886828861598457, 0.022619224386289716, 0.022357067292822257, 0.07176007223980767, 0.02799923185791288, 0.00955208859938596, 0.03505144986723151, 0.0252132264431566, 0.030217213556170464, 0.019301708920725753, 0.01864456811121532, 0.019342677168814198, 0.016021533237238015, 0.015533503710425325, 0.03143262244494898, 0.055111438634672334, 0.0491457689287407, 0.012771994258011026, 0.029514600722385303, 0.027843419861580645, 0.030347760301083326, 0.07395638152956963, 0.017615612163873653, 0.051757745378251584, 0.029286507783191543, 0.06308578234165907, 0.023373565337221538, 0.02883086134014385, 0.05066462207053389, 0.06689167169055768, 0.048909441967095645, 0.027364090850044574, 0.010673455927254898, 0.04033826564305595, 0.015472403328333582, 0.034296762863440175, 0.009669395429747445, 0.024859697824077945, 0.008832645552632, 0.0363403169571289, 0.03890055850414293, 0.01296644373464265, 0.03164019309250372, 0.07384062345538821, 0.007365385669150523, 0.06376669901822295, 0.040897134225815535, 0.04406665611479964, 0.04204494745603629, 0.029703172389417887, 0.01940372835711709, 0.0094241635441514, 0.05499319712232266, 0.057083536205547195, 0.011113193268621606, 0.014271733916497656, 0.05404372646340302, 0.06444616362984691, 0.04371143963986209, 0.05336638905906251, 0.05112409205841167, 0.009202518383972347, 0.033852173148521354, 0.037644016822533946, 0.010819904140329786, 0.013552351937895375, 0.028981431653457027, 0.014098355496701385, 0.04836914828047156, 0.03278870860646878, 0.07426410394587687, 0.06559463843171086, 0.011829867892499481, 0.047741231974214315, 0.01492285103138004, 0.0276606530616326, 0.04776791875649776, 0.07307978892432791, 0.0606161252196346, 0.051012680001024685, 0.033048926786120446, 0.04248706730348723, 0.013271973634670888, 0.035358005203306675, 0.020098744991368482, 0.08144113168652568, 0.02801246159443898, 0.02353632722848228, 0.023874207133693353, 0.036903029440769126, 0.07070390534188066, 0.042515379177140336, 0.04125049151480198, 0.02344145785484995, 0.05674581236339041, 0.03444699051656893, 0.023409848301006213, 0.035067493827747445, 0.07414584886282682, 0.036547188713614426, 0.034852435546261926, 0.0407134581889425, 0.014708717253857424, 0.07531084599239485, 0.01818936610860484, 0.03565959366304534, 0.03332368936389685, 0.00889137530300234, 0.1134632687483515, 0.023490515936698233, 0.01340216160419264, 0.02053017112692552, 0.08942044566252402, 0.04809621774724551, 0.07688438227134091, 0.03240960769887481, 0.058287406606333594, 0.017146445910579393, 0.021472249146816984, 0.01661509701183864, 0.024179853232843534, 0.04447045230439731, 0.011647828821358936, 0.01602462226791041, 0.02877920786184924, 0.08835856549973999, 0.08044441802693264, 0.046997357425945144, 0.01596349474441792, 0.02759619732387364, 0.0028923513600602746, 0.01580243936872908, 0.013764978519507816, 0.031858959567866156, 0.04611179119508181, 0.09205227265400545, 0.030796163382806947, 0.04342301475948521, 0.04466273895065699, 0.07296230737119913, 0.015107899405328291, 0.01048901823482343, 0.05003684147128037, 0.06300986105842249, 0.02742893504910171, 0.02350734021248562, 0.04059704872114318, 0.0230821294576994, 0.00775467902089336, 0.05160258477553725, 0.05152628351269024, 0.07728448044508696, 0.03347772020580513, 0.03130679151841572, 0.09066164227468626, 0.023612587779228176, 0.040875923221132586, 0.04384029683257852, 0.04719420722020524, 0.009067531475531203, 0.04245089120896799, 0.031241024511733224, 0.027726908613528525, 0.019385146675631404, 0.018712163769773076, 0.05979724880307913, 0.047993647001151524, 0.04540954137753163, 0.0209263083525002, 0.022158373579648987, 0.02785120265824454, 0.015638488344848156, 0.06410505729062216, 0.029142149457974092, 0.020838787513119832, 0.048284762272877355, 0.045063559764197895, 0.044150210916996, 0.0025569353851356675, 0.06264742836356163, 0.06233080356780972, 0.01642915127532823, 0.0056101614609360695, 0.025426069307806234, 0.025335276233298436, 0.01878419195834015, 0.10407759595130171, 0.011125507831041302, 0.017737013953072683, 0.04337004153057933, 0.06103045905807188, 0.07986082362809352, 0.04530440237639206, 0.03482922286327396, 0.04804982291534543, 0.013957426317834427, 0.02734384506142565, 0.02628408871324999, 0.035235811224473376, 0.03389962988772562, 0.03353281385664429, 0.03063351514616183, 0.02542223728128842, 0.04437769317467298, 0.038497905646051676, 0.03115894891587751, 0.02554084180987307, 0.004495077791424202, 0.03570447875452893, 0.01394185733183154, 0.018996184957878928, 0.03145080379077366, 0.0023636659233099116, 0.013753132994419761, 0.007217509139861379, 0.028897334023245742, 0.06376876176467963, 0.02252687407391412, 0.04579583814899836, 0.08756400777825288, 0.023873479404885854, 0.06337844128055231, 0.03363901476508804, 0.0813698855095676, 0.003546939817689625, 0.06858817208558321, 0.021580341471625224, 0.024469071999192238, 0.02601296647584864, 0.03177223939980779, 0.027915017180410878, 0.02252524219719427, 0.06107923894056252, 0.01509242711056556, 0.0414323151510741, 0.0489674499258399, 0.1481917088053056, 0.1439564832087074, 0.056960327816861014, 0.1333129829061883, 0.08644555815096412, 0.0680759052879044, 0.127989387139678, 0.15192382782697678, 0.19347257619457586, 0.09876655308263642, 0.11740551649459771, 0.17155569153172628, 0.06709035352936812, 0.07578932853149516, 0.1368263286671468, 0.07841675183070557, 0.19173661220286572, 0.16726394396807465, 0.10164924804121256, 0.12079587099807602, 0.1044320830010942, 0.17166745981999806, 0.14696026274136134, 0.1067382674664259, 0.12169514702899115, 0.1642837638833693, 0.14583280895437511, 0.23074497974344663, 0.09634918386914901, 0.23259054071136884, 0.13871891211186135, 0.09408910585833447, 0.14107649560485566, 0.12546123351369584, 0.19719397436295236, 0.1550574382500989, 0.11715608702174254, 0.10500910239560263, 0.20631785477910722, 0.09722990196730409, 0.2514542484922068, 0.13531704965446675, 0.06903934359018292, 0.15122799016535282, 0.15447214751371316, 0.22029498405754566, 0.11296850136880364, 0.1796157376042434, 0.2816539422741958, 0.13017569482326508, 0.1461227469678436, 0.1335839219391346, 0.14595653302967548, 0.26462531888059204, 0.2599414459296635, 0.06375023097332035, 0.2421190451298441, 0.10581428597548179, 0.10863866084920508, 0.13374648535890238, 0.12928707179214272, 0.16196537257305213, 0.10804005047040326, 0.09554733189621142, 0.0631274851039052, 0.19242233969271183, 0.15559139102697372, 0.13819709154111998, 0.10321592433112008, 0.16457509967897618, 0.15435717654015335, 0.09271039055394274, 0.1023341002208846, 0.19735577782349928, 0.11117711463677031, 0.1673198959657124, 0.23074484403644288, 0.12117395071046692, 0.12265614260520254, 0.15312879745449337, 0.1300565983567919, 0.08992487538073744, 0.18927287869155407, 0.10756542201020888, 0.10001758845256907, 0.12270712772650377, 0.10863353790981428, 0.08564324477421385, 0.10801556892693043, 0.0914342018908688, 0.11651347364698138, 0.09313516026096684, 0.1281235877956663, 0.09842225084347384, 0.1905479138450963, 0.14307373629084655, 0.1146359129675797, 0.10557487167950187, 0.13005526842815535, 0.082182173351092, 0.11040700453200511, 0.17675860305981977, 0.14381418084459646, 0.1078547832689115, 0.14849854234073842, 0.10035015203590904, 0.15634011370795114, 0.10360851112220969, 0.10378018048192773, 0.15235473827591964, 0.13231082739574568, 0.10452804820878164, 0.15461658047778265, 0.15397422494632856, 0.08788889034518174, 0.06535421990390335, 0.09437632973172835, 0.09694277987416301, 0.1475909746118954, 0.18391612970403262, 0.1189708560705185, 0.10710202330457312, 0.06710866040417127, 0.10900491369622094, 0.09593891445547342, 0.1306840396885361, 0.14028350529926165, 0.27988204306789805, 0.11695925758353301, 0.12662512463118347, 0.15686306064682348, 0.1443666983395815, 0.1483640702707427, 0.13056961154299124, 0.05724409116165979, 0.10785311407276563, 0.11833308743579046, 0.15422891985092843, 0.10715220775455236, 0.1388392706534692, 0.12305760463433606, 0.13759869150817394, 0.11175930446812085, 0.06824688932725362, 0.12141819617577962, 0.09407611869807754, 0.18611220829188824, 0.13067836713578018, 0.13087607866951398, 0.09686791032020535, 0.08852959703654051, 0.13753207294004305, 0.10590161343238183, 0.041321775011186085, 0.02996195886018021, 0.1149730227355446, 0.16811002285352775, 0.12577384816748755, 0.131393556616136, 0.11042429360428027, 0.09534907074911253, 0.11398802059037344, 0.11294710715966565, 0.1110345001465508, 0.11859238280781678, 0.15765824940587791, 0.0830766453540751, 0.11682812390582901, 0.14155674912035465, 0.1436287100825991, 0.11546833972845759, 0.08234015665948391, 0.20906780793198518, 0.0811318214982748, 0.08423436858824321, 0.12666290546102182], [0.009912316055436219, 0.03673754832042115, 0.048985848402870555, 0.03714137165141957, 0.03743726720235177, 0.03903677101646151, 0.03525147859805396, 0.03256650874391198, 0.047164775763771365, 0.012237988894672265, 0.03588255687749811, 0.024559259481195892, 0.014844700760607208, 0.023057653003239205, 0.0290054416150919, 0.04562952921592763, 0.00493877989772175, 0.005818819460858191, 0.06221472658216953, 0.01679183672448354, 0.01914297922381333, 0.010745028649190707, 0.03901501039841345, 0.07455026251929146, 0.010868522022584719, 0.004864260213383074, 0.04092060135943549, 0.11157740280032158, 0.043769026906894784, 0.07248349234993968, 0.02599775880974318, 0.02870843665940421, 0.02614558784158102, 0.015567055570759943, 0.019317819038406014, 0.025192716025880406, 0.02465713646129838, 0.051800140246216736, 0.044589280749538114, 0.03767596225121191, 0.0044389179924369925, 0.024779659529615725, 0.020329928657572185, 0.03551300974296672, 0.02425568800286523, 0.08313064317085914, 0.03620900686032005, 0.034179165959358215, 0.02887028083205223, 0.0333901281202478, 0.028954219006534134, 0.027156735637358258, 0.015117917974878634, 0.05318793434915798, 0.021545064436005693, 0.01635940805343645, 0.02802231053023466, 0.083487654370921, 0.017649445616241013, 0.08639988595885889, 0.03863972285762429, 0.037051676107304435, 0.012754595771964108, 0.022589799715206027, 0.02217077719978988, 0.01947452500462532, 0.02748490740279002, 0.024091043176927736, 0.029051066309745823, 0.02262759072306965, 0.03383263812533446, 0.1039803618831294, 0.02249047575917627, 0.03220733301714063, 0.05362679383584431, 0.04120384901762009, 0.05090843666610973, 0.03046639875641891, 0.0651827473193407, 0.022321440811668123, 0.0333344543219677, 0.03096317799229707, 0.021857428031840494, 0.01483159146404692, 0.020447742692860107, 0.015055642030867082, 0.04397738465507116, 0.021562855624194657, 0.06454614576484476, 0.02551460625337703, 0.031969947540866475, 0.02463068377359637, 0.022543267479964664, 0.026791029011032412, 0.014190516667440534, 0.027652125572785735, 0.03223197401634284, 0.048574462799089294, 0.010367040539027324, 0.04725626603301082, 0.03234187633331333, 0.03729697669457112, 0.024262027216276953, 0.024073844010542546, 0.03807570080139807, 0.029383555254233733, 0.047940558421292474, 0.04545214319867747, 0.05683340784162283, 0.007245337557313698, 0.05714761705270835, 0.029106885993054936, 0.03408142298992191, 0.013527509074525108, 0.03333685972860881, 0.009728198970801063, 0.057236525496201854, 0.018795681252543415, 0.039488380176148245, 0.03312272425474865, 0.018353632651269436, 0.012290417599225683, 0.03992023378876703, 0.04515949783048459, 0.01177899303313877, 0.033815634037767134, 0.020788737073806778, 0.01859180353182767, 0.01760146301239729, 0.03837500599079898, 0.045476584030049186, 0.05152691455025758, 0.05818956864199468, 0.15018732100725174, 0.021714530253250684, 0.030183313946638788, 0.024470128817483783, 0.03266860790816801, 0.0784267805782812, 0.026109671286706413, 0.010417875534455692, 0.019767881138250232, 0.07409978312041078, 0.03290103668613093, 0.04531544892649565, 0.05419925008235233, 0.03106771988262023, 0.0313364740328065, 0.027482693682291677, 0.026281939453578422, 0.027723480315346802, 0.0451403190381825, 0.023635356021778922, 0.0136428803837459, 0.012240418898207801, 0.04111601944480624, 0.0489262865989336, 0.04940759523638657, 0.011678847201567675, 0.030924487925533737, 0.016760730982891152, 0.06037681270390749, 0.05229998646037919, 0.032712095217513185, 0.05045311591987099, 0.019241455011069775, 0.042683896741696765, 0.07089571362095219, 0.05416714180526989, 0.0445601207071117, 0.018364280562049577, 0.03379275044426322, 0.06635310487555605, 0.07657435283597026, 0.023771130879010473, 0.01723946288361081, 0.05935371081743922, 0.057813789163316996, 0.06939987638699156, 0.019968079502827356, 0.03053858470437782, 0.02171484237935926, 0.07853919347482068, 0.027252878960488097, 0.012872677828584398, 0.022046813940895454, 0.01990425480263574, 0.014216853156020599, 0.03647832080189671, 0.09074715125773634, 0.02785834763199091, 0.018068705618913685, 0.01025651057716459, 0.05890131794980594, 0.04094341031408735, 0.018757681595161557, 0.03876436634787491, 0.02200465147117419, 0.023609697220048735, 0.0750371656779732, 0.07359162145959479, 0.01949676568619907, 0.04710112578634705, 0.00801819488073566, 0.03644071639116321, 0.0399435414666576, 0.00905813291735415, 0.02568103393007602, 0.016745201012651836, 0.010025123350455292, 0.006766292682316686, 0.0698746337688395, 0.02456022469725992, 0.04064522470746722, 0.037253553846052716, 0.003887424661245729, 0.020530366205743382, 0.04912140952157123, 0.011629687339466597, 0.06371713203511067, 0.020681696478277445, 0.03434059622564486, 0.03596740089622991, 0.08736189255224806, 0.0504866932252688, 0.041300452048225064, 0.04959533230534621, 0.04857930414644735, 0.011908488048772727, 0.03816313003855092, 0.018885086722938076, 0.013032611076986151, 0.07062194509697811, 0.037083987944892476, 0.05407048449186342, 0.014813963124262435, 0.07575394293027264, 0.015191759548283048, 0.01096480105271829, 0.03872934715556247, 0.01414242125714996, 0.07878597666110311, 0.027276892314798067, 0.04892829506258879, 0.057842321560851166, 0.04120255640840956, 0.02641543443314731, 0.018902072150792395, 0.043600583981190405, 0.0134459958145661, 0.01328983437269926, 0.04029824225498097, 0.027940608128639202, 0.05682089565587895, 0.0375867077548589, 0.018393362572948848, 0.024419381183439066, 0.059353290125727654, 0.0219478903205267, 0.033129971008747816, 0.03648060407223446, 0.027776826738512943, 0.023531775954844694, 0.012110630416178277, 0.05037251953035593, 0.048625162935682704, 0.023205359898773686, 0.010788679655109133, 0.005472850994140441, 0.078871078523142, 0.008252386153409523, 0.0653327578412635, 0.05840190260538033, 0.04370131589738386, 0.026384403330406973, 0.03376483212092093, 0.03665922502321856, 0.039987574996692796, 0.023662305736382092, 0.03970562334039381, 0.027327331215409294, 0.04841903417504259, 0.024247414964650358, 0.04025479226506182, 0.021696562645956874, 0.03469000783349786, 0.06450585435543742, 0.038557976351252625, 0.030775732693395445, 0.014761809226391571, 0.049187905953398774, 0.053067636875701804, 0.029556123672851493, 0.04589964722150138, 0.038067008767809184, 0.03338294582707541, 0.031957506601299555, 0.04158806607925466, 0.024762814897777777, 0.031333593651652336, 0.018065070367551277, 0.02498401392118207, 0.03428543472130384, 0.01943998078682593, 0.02993993361347488, 0.01712900077524994, 0.025317125421549593, 0.02877333853393793, 0.0442105055387531, 0.08491551596671343, 0.04918090007933123, 0.030520264258874313, 0.031015506612935236, 0.059738270539258204, 0.054439577007932324, 0.06814072573823587, 0.03080685030935066, 0.016167165511952977, 0.04459656482296331, 0.060154911396758895, 0.0686765851985131, 0.02872712690649288, 0.050063935374575, 0.02276709921924131, 0.019145908798756342, 0.023216562511931573, 0.02206274085412068, 0.01929319160990417, 0.043910084159246514, 0.028287631293226565, 0.019659237503739338, 0.033209305323128185, 0.04718811058306268, 0.04875691408025367, 0.03142530105209776, 0.008243939240596123, 0.04783454071730375, 0.06898856202938727, 0.02519984233991376, 0.06598176301590034, 0.00998327724768647, 0.04061288572847843, 0.07958054116794042, 0.06545511806117636, 0.05474940627547247, 0.033929173302437575, 0.05887908235724483, 0.0456355206801423, 0.05223434159000005, 0.08718804509512015, 0.04681691460843597, 0.05596966668963432, 0.12946573006255285, 0.14698707844529832, 0.16439990193716117, 0.11094385465340954, 0.13611537324530737, 0.11799664263214384, 0.23628084840519087, 0.13679085485637188, 0.13669459787862642, 0.1327184640935489, 0.11674372772020952, 0.06323824916034937, 0.13683844730257988, 0.11666531621345452, 0.10474056537662234, 0.07752569285886628, 0.11468734592199326, 0.09275456996900694, 0.12312894580619675, 0.07099606216486011, 0.13283481927854673, 0.12370195505874497, 0.17958799909268106, 0.25408172607421875, 0.18039485865405627, 0.1329360974154302, 0.18346057486321243, 0.1777390997324671, 0.09240735002926417, 0.14421569715653146, 0.12041343509086541, 0.09130921574043376, 0.11611444077321462, 0.075189686779465, 0.12718286684581212, 0.18599407534514154, 0.14646114595234394, 0.1144116571439164, 0.09459670433508498, 0.10214903657989842, 0.16066851573331015, 0.1096754487869995, 0.095857795593994, 0.17243697281394685, 0.19107026367315225, 0.08750029334000178, 0.11305183903979403, 0.12129310145974159, 0.1441872122564486, 0.10326532846582787, 0.1010460371949843, 0.14049752881484373, 0.09593362866767816, 0.09303810939724956, 0.0870571896167738, 0.06620307399758271, 0.2480912660913808, 0.12302576777126108, 0.18376039234655245, 0.1536507537322385, 0.10717084032616445, 0.155515245827181, 0.06964060025555746, 0.15211330194558415, 0.1275164618023804, 0.21686603448220662, 0.08533303891973835, 0.14375890738197736, 0.1232702439384801, 0.1823093452091728, 0.1665291991084814, 0.16875145557735646, 0.15982631806816372, 0.1734590908246381, 0.1128485363775066, 0.12628825913582528, 0.12660596280225686, 0.10834009865564959, 0.16213301143475942, 0.06436294130980968, 0.11037689793322768, 0.12027095630764961, 0.19427327465798172, 0.12535128369927406, 0.0829741254981075, 0.09796339153711285, 0.09696302735911948, 0.12859743594058923, 0.2378650919667312, 0.11652703077665397, 0.07936425813074623, 0.11262015506092991, 0.12179354817739554, 0.22167277655431203, 0.07818378361740283, 0.23211621759193285, 0.24777631727712496, 0.13094041735998221, 0.10348630018000092, 0.11582048583243575, 0.14387077066515172, 0.22073357552289963, 0.08747554716787168, 0.10033286974898406, 0.1645793608788933, 0.12735087211642945, 0.13020405758704456, 0.15654428489506245, 0.14614194950887135, 0.1195839803133692, 0.1872745252081326, 0.14736931079200336, 0.11463083752564021, 0.07566457308296647, 0.10924013464578561, 0.12067051843873092, 0.17439175077847072, 0.0723258958065084, 0.14375438833875315, 0.08706143046064035, 0.08817156124860048, 0.10391820129007101, 0.08056462050548621, 0.16537932652447904, 0.10982676209615809, 0.09522537381521293, 0.11521976520972592, 0.15828176880521433, 0.10172303193914038, 0.11250497374151434, 0.07135859663997378, 0.1035282811416047, 0.14540548117033072, 0.2527715020946094, 0.12500786355563573, 0.11321428710860865, 0.13009079652173178, 0.10703833600772278, 0.10215955387268748, 0.17673627925770624, 0.10645934207631008, 0.06648379072014775, 0.162200091406703, 0.20545539605830396, 0.1380025962633746, 0.12691133070204938, 0.16913983545133046, 0.0923743528713073, 0.0822854395955801, 0.12313102212335382, 0.09647699951061181, 0.13036455826035567, 0.11238574156803743, 0.07936747438673462, 0.113371449389628, 0.1547595342355115, 0.1738901234098843, 0.09788265944059406, 0.04646841563018305, 0.060859441091971736, 0.1296625595007624, 0.1351477958794151, 0.15866182983985969, 0.13391453134162085, 0.09598476306668349, 0.09618739397930247, 0.13712751679122448, 0.14998841525188514, 0.15231811095561298, 0.08719395513513259, 0.13286168926528522, 0.11459908208676747, 0.1002309402184827, 0.18603759658123764, 0.12449231264846665, 0.191756561132414], [0.056135755098823986, 0.04033980931022337, 0.04606324540717261, 0.022420254170096347, 0.025456773017400076, 0.008663564804010093, 0.030616449990442822, 0.05504401260986924, 0.039526429027318954, 0.03519326029345393, 0.004633703767987234, 0.07009353595120565, 0.03726854607728975, 0.08031965579305377, 0.01796561579353043, 0.020972150178360086, 0.09941010962107352, 0.04363091788919909, 0.01264022445372705, 0.05514985728742821, 0.04165094252675772, 0.002414936453403373, 0.041860257009310384, 0.05473063799685665, 0.048795176669955254, 0.029293360986879895, 0.07566084792571408, 0.007634272133665425, 0.02145014756492206, 0.05363366739558322, 0.020493850843714814, 0.03555001365020871, 0.02490787041772689, 0.04279772777642522, 0.029858577264738933, 0.057352364994585514, 0.010452560548271452, 0.07287394854107074, 0.03993346182895558, 0.008697714623329895, 0.01074204733595252, 0.061723969344581874, 0.017758967953601053, 0.037871668713965585, 0.011551106198956924, 0.03748818447015115, 0.00752045212513102, 0.06473502277263574, 0.028767221540744816, 0.02708993386477232, 0.060576410564993105, 0.03998022646244083, 0.024843860816742693, 0.09246650471218995, 0.022204176389745305, 0.02993391840053456, 0.05791017506271601, 0.0917678511302386, 0.06499579056565251, 0.04708045082432883, 0.012027002671467406, 0.06107273857508387, 0.012892491051128932, 0.027891507638352256, 0.018353624169581702, 0.021349283334399973, 0.06542528966175658, 0.04503260160397206, 0.02438947814516723, 0.03959815696414028, 0.03760872282353895, 0.025254077643954327, 0.0208924952561834, 0.016481193214921013, 0.0224708321703864, 0.040699035927121124, 0.02884304104372859, 0.041054126873080216, 0.05065093941188284, 0.06303289053695542, 0.008547453891618975, 0.054187942296266556, 0.0359882420993277, 0.04941798700019717, 0.025400761647948196, 0.003928815721467669, 0.031201476098171303, 0.012269083610070603, 0.02899513127548354, 0.031178185383656194, 0.042745836810874085, 0.036198255472949574, 0.03833858223099794, 0.03552509784432394, 0.047153437443609746, 0.01836364952448223, 0.040250822835202725, 0.0183267931986068, 0.024593813877020563, 0.028263811321396912, 0.014933061287073153, 0.05534793523007205, 0.033935554924287965, 0.11730187705584935, 0.011983904671589178, 0.01640210147680981, 0.04271522470350776, 0.08376062222357307, 0.023490773780005317, 0.03888858575373888, 0.03759093842070017, 0.06212448821003948, 0.003359007457869926, 0.04801008451197829, 0.03239609467397843, 0.02528211471092488, 0.03809253864788583, 0.09284884562449795, 0.06384080861295972, 0.047736417768257, 0.04106698511168361, 0.0017625437987070264, 0.02418553426728717, 0.029265171249530146, 0.0600520929853831, 0.05215475961033787, 0.014342981789793288, 0.04632982485262411, 0.011818651708641222, 0.012829377964538122, 0.04926381366593497, 0.03009975914444242, 0.005525689364211368, 0.028335513813155036, 0.01694766229151615, 0.02774834183843008, 0.04698477399402431, 0.020312734580199634, 0.014216362066300852, 0.06431817156927926, 0.06221083179116249, 0.008106075343675911, 0.03988148265385202, 0.042063552886247635, 0.0059068708298062635, 0.024946545217452303, 0.05731372921062367, 0.033148003076868396, 0.02919474949261972, 0.0644862311226981, 0.04235612700826355, 0.04114778506170426, 0.030021466381315674, 0.013785127616886581, 0.02231768681667745, 0.037632787067975314, 0.042038745645965846, 0.056123069886650355, 0.019203194117705737, 0.04387197423992412, 0.054796438930290084, 0.03178914509979742, 0.02619817091285118, 0.0444365696582411, 0.01852506791640605, 0.015700253691258173, 0.015528894761311156, 0.0016704776228704888, 0.04199045091601355, 0.015199616983798998, 0.01990816825335579, 0.016015709710440466, 0.013370416343345173, 0.023504620983398387, 0.02630016320784177, 0.030469509839479412, 0.0040968235365913385, 0.04225166654214263, 0.0062306291490261045, 0.03839234256052545, 0.014288390254867929, 0.020971376648438827, 0.020256701158359647, 0.03145096663917814, 0.07250133782093014, 0.02307671305191304, 0.012603025467667197, 0.10509301682135888, 0.047290582941578965, 0.03674579930624791, 0.03802656129534755, 0.0648377529744591, 0.02348613429681531, 0.02344121358224324, 0.03251513685765011, 0.05166938654812319, 0.041744234306471686, 0.019961112644523382, 0.01793733615029071, 0.04611953667231968, 0.02091269863636366, 0.06995195283421449, 0.16485168412327766, 0.03227580398587244, 0.015264561266771384, 0.047577484510838985, 0.05502307301919375, 0.013512138560015177, 0.07661043732826199, 0.084828174939113, 0.06345607925738607, 0.06212870869785547, 0.009970544538061534, 0.05711766651698521, 0.048548573295452764, 0.04840654573802437, 0.06321943338428225, 0.022045853813844066, 0.01407074336228626, 0.04745261371135712, 0.012628180457146039, 0.04945278227595346, 0.0394890044283654, 0.026222308099802052, 0.03316322261733668, 0.02149130410647818, 0.016012963339952484, 0.027122651127034, 0.06467530490564448, 0.0924289817256587, 0.024237411662137935, 0.031130525083946328, 0.03245911022116031, 0.046407622285187244, 0.03696092204856021, 0.06592805696917431, 0.05869022570550442, 0.04292488184624484, 0.026639915869704316, 0.030387220505092825, 0.026955672140632356, 0.05478625411966017, 0.0767960302265627, 0.037302924054009576, 0.054216060787439346, 0.025605100772476623, 0.03191901670236673, 0.0018784612225967326, 0.061125277541577816, 0.026721340071942126, 0.051884322693305354, 0.07918932501758848, 0.04246511669563396, 0.01422226956180696, 0.01579313665362341, 0.04846907952534301, 0.0722432095291359, 0.049856741313955615, 0.04036942057843719, 0.031457680743187666, 0.015483405773660966, 0.07802670276058571, 0.02423644474973636, 0.024621082503082495, 0.04895416421017476, 0.02846943966246077, 0.06272788904607296, 0.0726769630398069, 0.06396802714360611, 0.05634141227762614, 0.017624845329139913, 0.053543198321546824, 0.04447122922699366, 0.07193385184343372, 0.03970148427678006, 0.027956173721966997, 0.04829388178352799, 0.060604434061263285, 0.02062764098601682, 0.04128729186153837, 0.023980737131621157, 0.07848939578980207, 0.021952402578400712, 0.029462289065122604, 0.06303483114710876, 0.03325754237760391, 0.040564740276230235, 0.03453837222020541, 0.013296621419223291, 0.03052036603912711, 0.10682136765015976, 0.029523265614573444, 0.02754810785076448, 0.06280002410390548, 0.05219818585153137, 0.03191589204860585, 0.0549421712889203, 0.03333578085792916, 0.014308788713866046, 0.04366820678114891, 0.054189194193375964, 0.05959775950759649, 0.028366500811119164, 0.03868275894118207, 0.008056354842015674, 0.015000678998019015, 0.08236492318766457, 0.033210954163223505, 0.012713679262170834, 0.01584380116712834, 0.01360133707722915, 0.031153958290815353, 0.04181478837771075, 0.04504501540213823, 0.00437528667472569, 0.05119256641981857, 0.008685755443626215, 0.014494005025231411, 0.018327295314520597, 0.004530717419194323, 0.04496645122500403, 0.05633455907393779, 0.042611049222094674, 0.03733179571905306, 0.06000080930867365, 0.03995185012796095, 0.06814737538141863, 0.03257157400782619, 0.01573358672404928, 0.04399544386459248, 0.04373510015596237, 0.02738150884397328, 0.04467944448281612, 0.06534921910081591, 0.03000284738040396, 0.03526404506659933, 0.016631544700690677, 0.06127695047429629, 0.043724823743104935, 0.06015030414398227, 0.01970910813127245, 0.012315959353665156, 0.0347567112185061, 0.03698267588125808, 0.0143725201154926, 0.06487144902348518, 0.011160533808703934, 0.035735355490552526, 0.027771459526515434, 0.013341359777509101, 0.07699659839272499, 0.020819023484364152, 0.15639272731329712, 0.15727007309240953, 0.20601621882191726, 0.12468531514917101, 0.08471228794327804, 0.08596550141062055, 0.06630507138158594, 0.12507631416831697, 0.19190100766718388, 0.16402008517512254, 0.12268948581601892, 0.2514113379376275, 0.2779241167008877, 0.17461824576769555, 0.17227462652538503, 0.1413580197840929, 0.15759768337011337, 0.14169245612408432, 0.13628135648156914, 0.22632048358874662, 0.09574266855737992, 0.11274455767124891, 0.1480012983083725, 0.1849179052348648, 0.10004635155200958, 0.15314318239688873, 0.20612379376377377, 0.09573488576071602, 0.08936689567885228, 0.0913436853193811, 0.09092514456382819, 0.1344285894717489, 0.10566399725420134, 0.13348074390419892, 0.13164765440991946, 0.14321434231741087, 0.10077856547598328, 0.08241577260196209, 0.13573267949478968, 0.13856559033904756, 0.12055444823844091, 0.11981743707188539, 0.14179557987621852, 0.1873552030218499, 0.12450277565845422, 0.18168765785438673, 0.0682827363322888, 0.10978617891669273, 0.11894634738564491, 0.11086489353328943, 0.12479131588978426, 0.08646024164876767, 0.09229136125317641, 0.22474914576326097, 0.21702447240906103, 0.13474558746176107, 0.11733319823231016, 0.17665703993822846, 0.16966690788311617, 0.1373650176184518, 0.10071665594088179, 0.12415764560656888, 0.10238088521042041, 0.1614866525466953, 0.056341629408832104, 0.12735674822969095, 0.16203971286969526, 0.11898830799119813, 0.1674258288528238, 0.18935490000460828, 0.11990922928920814, 0.08535219396331481, 0.10002452308045966, 0.11056828552058764, 0.13087341881224088, 0.10647241066076926, 0.11529329126434666, 0.07781343920422451, 0.0854914632758924, 0.13227729419512407, 0.12274387718311378, 0.1423682091491563, 0.15980026232344763, 0.1269634829035827, 0.13097553833254746, 0.10837922298482486, 0.08761111167924744, 0.14319475979677268, 0.16952991166285106, 0.07971451790737254, 0.11742212703185421, 0.20724709491644586, 0.1875593742089612, 0.12326736695000104, 0.13450849375554494, 0.08567924105695315, 0.12046298171792712, 0.12597818220300333, 0.1362782759325845, 0.14315098071736948, 0.16751791962555476, 0.11329919219549213, 0.09376328691307988, 0.22205143980681896, 0.1028575696317213, 0.22025029574121746, 0.11719062445419175, 0.1116247306178723, 0.18959394789167813, 0.11511892133525439, 0.09224803679223571, 0.1392548190695899, 0.07041470014623233, 0.14735837280750275, 0.19038615109665052, 0.12024092434772424, 0.12024276996297495, 0.21442562900483608, 0.13510772160121373, 0.16606482331241879, 0.11114687233098916, 0.10331959769661937, 0.0920663115435413, 0.15151936667306082, 0.161116308133517, 0.13408066385558673, 0.10632915156228201, 0.17392901703715324, 0.09258576402706759, 0.07887886810515608, 0.17642038049442427, 0.08473900865231242, 0.13704907814306871, 0.11076875869184732, 0.11276616901159286, 0.1174680231405156, 0.10375194663980178, 0.1302994867520673, 0.05838039983063936, 0.21307940195713723, 0.15845653228461742, 0.11050752949501787, 0.18227896041103772, 0.11976607197097369, 0.17354655398854188, 0.19457527702408178, 0.1265214037682329, 0.17789434854473385, 0.18786284221070154, 0.20666415191122464, 0.15471789932676724, 0.08165114506014756, 0.11051665579101869, 0.0810340785288385, 0.08858934883028269, 0.13101493407573017, 0.09525969411645617, 0.12322480923363141, 0.0886663014867476, 0.0823856388617839, 0.10353639642042772, 0.15503989133451665, 0.09802507037030798, 0.11484336826418128, 0.1084583673094, 0.13467837178281375, 0.0823747483747346, 0.1035786827227899, 0.10392321566385881, 0.11313542098339115, 0.09508488313960177, 0.07025040646216699, 0.16195231755929335, 0.1145008166453668, 0.13572691194713116, 0.08340023191911833], [0.04447506634252412, 0.012357903844011682, 0.018980288578729545, 0.03740179678425193, 0.07936830898480755, 0.022166112271536673, 0.02895585766860417, 0.07546770293265581, 0.0504935735703579, 0.01474165334366262, 0.025606759790597216, 0.04907475006101387, 0.05460192668916924, 0.04876009301681604, 0.020601515691461306, 0.036898483256144185, 0.0413208657742611, 0.05713617016694375, 0.03825436246448329, 0.041571265552192926, 0.03140775074384042, 0.017635835900104473, 0.07819575297513179, 0.11909643933176994, 0.050542058290115426, 0.028812001459300518, 0.0561292750893959, 0.04041004107732858, 0.022745850895132338, 0.030884566317711557, 0.0074475952756724185, 0.03396560384758881, 0.043303232972643206, 0.0641556895737137, 0.05106354977137276, 0.052049026891056976, 0.02287103042804769, 0.0475833504460752, 0.04181856442508953, 0.05029713428978409, 0.026796981459483504, 0.03854092815890908, 0.009313866828701325, 0.02712340260456715, 0.05927352833428553, 0.028040244210777537, 0.030604894539075236, 0.052112052616264136, 0.025049195691410984, 0.026520989036985805, 0.05320596302460347, 0.03984294865014298, 0.01182654222273933, 0.02718124262589429, 0.04059704872114318, 0.03100886375510267, 0.03444915843595352, 0.009026212085570608, 0.030221271195581982, 0.0608852661347815, 0.033025748029883416, 0.0581066720187664, 0.024824049290535704, 0.033048926786120446, 0.0619115639211876, 0.047161929309368134, 0.019591339897098284, 0.02156039254207696, 0.04659250272171838, 0.027655121304893067, 0.013320518574411315, 0.005605873967786985, 0.04941970030111926, 0.0620677491117801, 0.02089122130668589, 0.03487861003460629, 0.04274569771119526, 0.0670012550960694, 0.029240703276757683, 0.04643100120925477, 0.07039343485874788, 0.007604786394430059, 0.035601348217044554, 0.05522951390594244, 0.019519727311230133, 0.07427774928510189, 0.0368228707063411, 0.05056363231103335, 0.020474365014316778, 0.034536143232669146, 0.07114745689822094, 0.05375271636460509, 0.015329614115346755, 0.03767129732295871, 0.01425755931995809, 0.05541459111762898, 0.02441142705668296, 0.0612431119329163, 0.03485930232065065, 0.07182836000408445, 0.022326375457591245, 0.03597862047276326, 0.07692705533866372, 0.02400019921229354, 0.018850155740178058, 0.02222231193445623, 0.029866896104067564, 0.01972817157262138, 0.019983292257945453, 0.040808164714170356, 0.03206490173137613, 0.08287799065666539, 0.050571371002921035, 0.05629952970360007, 0.029277045612356493, 0.025417133001610637, 0.00710839604393446, 0.00909702484828553, 0.04714690993673035, 0.03835729622681226, 0.08682732909385647, 0.016717767841847878, 0.02573266196330743, 0.054447766925607405, 0.03505634889006615, 0.040755425579845905, 0.018290793523192406, 0.04426919881786619, 0.023583750040935617, 0.01232087703621281, 0.006625603959296963, 0.035545172302850654, 0.014383251146812524, 0.07338992013995137, 0.04622050607576966, 0.03682013960289104, 0.05041547758238656, 0.0037268726737238467, 0.07431061073605504, 0.10422812894518886, 0.03288968479526894, 0.02714848974054413, 0.03997944275449429, 0.05755287887794631, 0.036751366686075926, 0.036279913769768815, 0.008342532075143285, 0.020791625936648676, 0.032546013593673706, 0.0045489386289513534, 0.03479339282161423, 0.007611961054083492, 0.04037425514044506, 0.03013545347909842, 0.025536404190851108, 0.05330209447337048, 0.03320205517645393, 0.014907410967030695, 0.026597132540440986, 0.04656841472855636, 0.0032430723284570767, 0.052875808240579705, 0.01929374970495701, 0.0749790287975754, 0.035519391364817104, 0.027187595410006385, 0.028922460174986293, 0.0746636050088065, 0.07329421956092119, 0.014062293056797768, 0.05853173349584852, 0.016125588278685297, 0.047356017466102324, 0.002367294601364327, 0.006915921528291489, 0.022884351766801307, 0.0409297310481114, 0.03155421931296587, 0.009762364905327559, 0.05144154127421124, 0.04388397752440401, 0.01416607668423759, 0.03336816054901906, 0.01623423700220883, 0.021414073250655617, 0.03110710884045277, 0.0376853090710938, 0.05226896044665149, 0.03317769576928445, 0.056188283887292655, 0.03892156594832029, 0.007246260364939059, 0.01984165485815278, 0.046419272731457434, 0.024561066080683043, 0.01358361289437328, 0.061671688221395016, 0.013502138650177844, 0.09067047001527888, 0.09026013953345162, 0.0327304597677929, 0.034869137685745955, 0.009790968549038683, 0.026604562498895184, 0.019950519016544734, 0.04867025837302208, 0.03999709484300443, 0.017148225368665795, 0.014007041646566774, 0.01761441963857838, 0.041189755845282755, 0.02960043540224433, 0.009619330571565245, 0.019503591748486673, 0.022996192997587577, 0.03105660547901477, 0.03206715446763805, 0.05590955527233226, 0.02790108007112784, 0.02785472764766642, 0.06872525651540075, 0.017412752245685885, 0.08332031406462193, 0.05317506593252931, 0.048221851898623366, 0.008621296313192164, 0.03401346770780427, 0.03082136417339955, 0.046858644512082846, 0.044193823755319626, 0.05917837058327027, 0.04070952607850943, 0.02695206572700824, 0.021146313154271672, 0.004838241788093001, 0.012168132866333638, 0.009135239940535809, 0.03823120406429682, 0.04510597498821361, 0.06963439166013684, 0.04581573618842023, 0.05243904881977609, 0.034059346853090186, 0.04298191949991243, 0.0783480094479663, 0.022954653083745922, 0.021699724619143775, 0.028591165452131202, 0.029420895036309958, 0.03778850406940494, 0.03471118491142988, 0.033349965632494004, 0.060871749717210016, 0.06558239765997444, 0.03950573031657508, 0.03805517511708396, 0.012650555149385971, 0.021302942785301378, 0.033278224124972305, 0.06924529253904309, 0.05234262560095106, 0.03427147725597024, 0.03757804625534585, 0.008066062133626213, 0.04217644075730017, 0.021640178082244735, 0.09242100215383939, 0.04012032358774117, 0.06266419496387243, 0.01854805668283786, 0.02932138109047498, 0.07710080780088902, 0.04709770596985306, 0.05041315699262278, 0.0074721395836344785, 0.06318082474172115, 0.05405253724062017, 0.03187887117798839, 0.01965850977493184, 0.05213904134663088, 0.0035543311844646397, 0.02015399979427457, 0.03433144957359348, 0.05184659275359341, 0.02754979401028582, 0.05950998421758413, 0.027856666561482207, 0.046495265260870965, 0.016961707966402173, 0.05657441441767982, 0.04442730426256146, 0.009151541744358838, 0.01147810770531318, 0.02663276411060776, 0.05370904245812978, 0.03808086784556508, 0.024336211449865783, 0.03295116685330868, 0.05210642756095954, 0.017640663676762154, 0.03359539853408933, 0.025352153095549772, 0.05964964708047254, 0.03714187376733337, 0.04135427683857935, 0.062438290300113816, 0.03681752724306924, 0.01243108808661678, 0.022519534021349888, 0.040577666368335485, 0.04017228240679417, 0.025104082389069454, 0.017326030381289974, 0.03886918304488063, 0.03430511562951973, 0.06707406190357038, 0.006886688543350569, 0.018543485053149716, 0.01794315967708826, 0.09071404553417649, 0.03410563651206238, 0.0358930063167853, 0.016544081536786895, 0.03709132630111916, 0.03134431450494698, 0.022810572957886115, 0.023122948428083743, 0.017504271352663636, 0.039898839579629045, 0.020930689992383122, 0.01718417415395379, 0.037195759625839334, 0.05202725948765874, 0.02255571520488177, 0.0337849303281733, 0.03813384446714606, 0.057749063707888126, 0.02208546668823276, 0.0760607086122036, 0.03376927313261798, 0.06403368897736073, 0.024291543489588157, 0.03576552315748163, 0.06431302148848772, 0.00905983943292605, 0.021264212006436925, 0.03934674956170576, 0.013439512412462915, 0.06397927046886512, 0.006658948866450893, 0.07066062159304108, 0.03888143738731742, 0.11579814845962183, 0.07753521270517792, 0.07194393487381083, 0.25627979955502916, 0.17711549890892847, 0.1191953154546874, 0.09287866723856755, 0.1561606004834175, 0.18592333128409727, 0.12240185482161385, 0.10018061327614955, 0.17995011966143334, 0.1788793642606054, 0.12204779524888311, 0.11413400061428547, 0.1350005537803684, 0.08586633351764508, 0.19855629626129354, 0.1501511958028589, 0.12104981951415539, 0.11756160669028759, 0.052119981297957044, 0.18735238031617232, 0.21628896759024688, 0.18022352856184753, 0.15353012377662317, 0.2549550820674215, 0.11864001596612589, 0.10557301249355078, 0.08201955564852272, 0.08993813395500183, 0.10133951716125011, 0.10002903533833367, 0.09304227560226407, 0.17691809950130327, 0.17984000699860708, 0.09547972945230347, 0.12586216628551483, 0.15713239833712578, 0.13188751653901168, 0.13098321934895857, 0.2914243037147181, 0.11754133206393037, 0.10362727261547532, 0.10084747749247722, 0.11408526822924614, 0.14294919797352382, 0.1963475833513907, 0.21061497634010656, 0.0945502518277083, 0.13237129843660764, 0.1785895483834403, 0.08743964588003499, 0.10068170460207121, 0.10675946490040847, 0.1337194118116583, 0.13128881795065744, 0.10105770121195487, 0.10088177065231971, 0.12504147818045958, 0.08233537298760243, 0.1352725513279438, 0.12589347389127525, 0.12504116605435098, 0.20944383846861975, 0.17003265182886804, 0.08975732472858258, 0.2124800926872662, 0.16077689134648868, 0.19108502859515802, 0.07187494821846485, 0.08733244413243872, 0.10302523563482932, 0.08630280795374087, 0.08452358056924172, 0.095626564430339, 0.17316430807113647, 0.10608106558876378, 0.08728627660976988, 0.17215357587805816, 0.1341634722692626, 0.1399304906704596, 0.13538634165057115, 0.22398477606475353, 0.09602457950157778, 0.20563448859112604, 0.2270105808441128, 0.11548467885170664, 0.10879055091312953, 0.09538163364465747, 0.23424983024597168, 0.12524559508476937, 0.11393881323082106, 0.14495147338935307, 0.07777070506875004, 0.25136829167604446, 0.15716112750981534, 0.13866448003266538, 0.07348162414772169, 0.17567591901336396, 0.09425850891109024, 0.12989655908729347, 0.172249045755182, 0.08368423953652382, 0.06402347702533007, 0.06569409130939416, 0.11201213340141944, 0.11185748169996909, 0.09724062960594893, 0.16297702757375582, 0.12839967012405396, 0.1283845252224377, 0.11502847261726856, 0.10217748755323035, 0.1182132852928979, 0.09252730144986085, 0.09022324079913752, 0.08539994925792728, 0.15357251864458832, 0.11802681029907294, 0.09477012431515114, 0.11138497026903288, 0.14471055274563177, 0.1553722242159503, 0.11727427425129072, 0.09132865576871804, 0.12596132739314012, 0.10550648892032248, 0.13510069197842053, 0.11596989924354212, 0.11487743072211742, 0.19386190601757594, 0.06856214348226786, 0.18048552450324806, 0.09306100316877876, 0.08931472312126841, 0.10478601365217141, 0.11711138513471399, 0.26552578913314, 0.18831235808985575, 0.09756201771753174, 0.08981621478285108, 0.07936763044978891, 0.1988919811057193, 0.1446992890643222, 0.12233763826744896, 0.10586599034390279, 0.12210095168224402, 0.2039843728499753, 0.06657902989536524, 0.14764423961085932, 0.10876417625695467, 0.1723694857209921, 0.1015082620350378, 0.10317082889378071, 0.1205717780228172, 0.12670791947415896, 0.09876487710114036, 0.10462497015084539, 0.13218478273068154, 0.15325919831437723, 0.17254571483603545, 0.12109701841005258, 0.15181036320115837, 0.1921560146978923, 0.09893879241177014, 0.1813444955540555, 0.13951648931418145, 0.22788384184241295, 0.07528733475399868, 0.10186336655169725, 0.09133032496486392, 0.16829322730856283, 0.1083869379279869, 0.140887265758855, 0.08813240299267427], [0.046196431653308015, 0.021528498003525392, 0.03849692516294973, 0.010324480278151376, 0.02110401158487158, 0.005506006759657923, 0.025592863393415297, 0.07476754978831325, 0.025100667661588107, 0.03487827415977206, 0.05424727000562208, 0.04273844417184591, 0.024970421168420995, 0.06465854509068386, 0.03081257714490805, 0.01603070872702769, 0.020601458015984724, 0.037318258945431025, 0.03251251431980303, 0.06321923660912684, 0.09140984248369932, 0.016289181375343884, 0.08219682292214461, 0.03351719058783991, 0.019185626846072928, 0.046268424218786616, 0.012830523840550865, 0.011628884971807045, 0.05005005933344364, 0.028717284756047384, 0.06875110869961125, 0.022014875297567675, 0.037498152149575095, 0.01713747058862022, 0.04349482072783368, 0.056255296005734375, 0.07301522631730352, 0.03445238826264228, 0.03490254535738911, 0.007121360727718898, 0.09317411495638744, 0.052592146676033735, 0.02231028230328645, 0.026092746927003776, 0.016455298622271845, 0.014249298156106045, 0.054883691748338084, 0.026462577349905456, 0.021601230172174316, 0.00883335801440158, 0.04914721081565533, 0.017045318747737577, 0.07309719334755625, 0.034378960595599244, 0.016131342255643437, 0.09532243824963059, 0.028752761959497417, 0.003955376126603889, 0.045711679450635395, 0.0628789784386754, 0.01848107509847198, 0.02480514530491616, 0.037001152389815876, 0.05481335480830499, 0.00435619185113215, 0.04345174053949969, 0.054912746617836614, 0.042237641223307164, 0.0759422228272472, 0.027966904753286923, 0.038056576291897466, 0.011397641085620438, 0.018703163002750704, 0.012506699788251092, 0.028239470573940446, 0.04462718032300472, 0.017305197659879923, 0.038146665386323414, 0.0267988406454346, 0.02984658076560923, 0.04138767772487231, 0.016619495615097027, 0.09508273218359266, 0.0484151665254363, 0.04013700537117464, 0.051248365747077126, 0.03191168173881514, 0.07419709861278534, 0.01812588406859764, 0.05644475994631648, 0.004622249248703676, 0.07092100940644741, 0.0302685515156814, 0.007073124097327569, 0.03654237790033221, 0.043970209147248945, 0.042353144846856594, 0.06581926744963441, 0.013030255712302668, 0.07044146156736783, 0.022408983703436594, 0.021295553538948298, 0.016745385913444415, 0.020629333930888345, 0.032150217331945896, 0.02053255108850343, 0.07312048066939626, 0.034726343383746486, 0.06156322439866407, 0.036799030378460884, 0.025615256745368242, 0.02305348340554961, 0.010092086275108159, 0.051394668075123, 0.04096172058156558, 0.03642401085900409, 0.05003452766686678, 0.039659557597977776, 0.03597048144521458, 0.03637205882530127, 0.01874718805109816, 0.035301808933062215, 0.03282968533624496, 0.016432501541982805, 0.034555077752364535, 0.03616980789229274, 0.019792825781873295, 0.03131033007853797, 0.0567643940448761, 0.016971368608730178, 0.01140623473163162, 0.0388382214919797, 0.04049976037016936, 0.01530150240952415, 0.008846675112311329, 0.010277784346336765, 0.010393388901970215, 0.038466214668005705, 0.04024278898058193, 0.009968101811994399, 0.03644808188879064, 0.02900218464700239, 0.014316751322309886, 0.03609001895944987, 0.06469218007155828, 0.051286879394735606, 0.08757265231439046, 0.03697265391903264, 0.0038123952274742934, 0.14268083737364837, 0.024719205452129245, 0.039624721610120366, 0.04182732431218028, 0.034996349431042156, 0.005119970376004598, 0.01986159530601331, 0.05511558448363628, 0.018005630699917674, 0.04838049677865846, 0.019723716990223954, 0.02614390677107232, 0.04202026913740805, 0.020014494690777998, 0.016595880900110518, 0.08111607270049197, 0.020584525174594352, 0.08739344443061522, 0.051821371606950245, 0.056827786178993325, 0.05757746898702212, 0.05893911913569484, 0.057947942321853976, 0.030433903714375835, 0.047516385825084786, 0.021811189262994697, 0.021294059065569724, 0.032326303954635344, 0.10267151532960789, 0.059543659910559654, 0.03969656150521977, 0.0681501573749951, 0.03203947702422738, 0.016590201562004428, 0.035518841751452, 0.04459516704082489, 0.048684331189308844, 0.10194654137428318, 0.03140064648219517, 0.04934479682041066, 0.025019489428294555, 0.05577090342662164, 0.004220414873478668, 0.022327498433047106, 0.026004971636991416, 0.07337603052811963, 0.08417417574673891, 0.023777531160573875, 0.01848349577215101, 0.044672268974993906, 0.06091821579528706, 0.017669148576845015, 0.0701917131830539, 0.032219356657671075, 0.01173840306832322, 0.025545142025553753, 0.026990745615746294, 0.02627905398341162, 0.04356476751023105, 0.03679848076509578, 0.024907295359298587, 0.014471213033955013, 0.03238812188750931, 0.004783550593336778, 0.033871871020112715, 0.024902560881205967, 0.03393348539248109, 0.007752049697696098, 0.0582695339939424, 0.012987620812574667, 0.03466586216485926, 0.02071726867663009, 0.04359771717073662, 0.013252476779078799, 0.04713196520294462, 0.04889865665297423, 0.014547458317662989, 0.059879236189382415, 0.026945254931758558, 0.07301842900259153, 0.005607628404894578, 0.00699496576895139, 0.0036150594325070934, 0.02354437465380345, 0.026747650267290216, 0.046832921249525886, 0.020428974414244294, 0.02241394549076046, 0.016554324022893394, 0.04019572239901338, 0.03609127085655928, 0.014543356573475259, 0.01757751920792673, 0.042154992265360694, 0.025499510545549647, 0.07227679022720881, 0.017838188613365804, 0.032616353926381896, 0.004258948877187712, 0.02982180066672819, 0.049732124965105734, 0.01919954190296786, 0.006857905936028276, 0.02394034224562347, 0.029930060928953544, 0.059562781027385166, 0.015305822981255395, 0.02582636764938278, 0.02676001487166754, 0.01540201380183654, 0.04301811255780714, 0.027803340494366627, 0.014740443854991878, 0.03190423481698547, 0.01572405330703727, 0.01811470520416541, 0.0405927705578506, 0.01273361886186259, 0.03429630145962749, 0.06848629683788333, 0.014726896903344562, 0.027207227124433433, 0.039031108641730886, 0.10167650479291167, 0.024830083163189035, 0.01722178535003747, 0.06995926065636532, 0.026028657598154883, 0.035044074191578796, 0.03244529864085572, 0.01870872190089098, 0.06368250639310905, 0.0174887261153864, 0.059890404875789366, 0.0384940278184201, 0.072405820446355, 0.031347978594047685, 0.03260433707120163, 0.031188957127077237, 0.034849086975944896, 0.02692209992424718, 0.07061390445700713, 0.055262388927595954, 0.07940052582749299, 0.024735300302771584, 0.008703965627189194, 0.026528734514223676, 0.017211631073483398, 0.026575365137042742, 0.021094559592061808, 0.021980726326416646, 0.017778119604502405, 0.04248223274147936, 0.009590802414874946, 0.03088244589577828, 0.035393808103565655, 0.030419827505413975, 0.008258930623664387, 0.03801959952605622, 0.026543284001361047, 0.03315093434814896, 0.03728403703176549, 0.06975835322269372, 0.020096471899056008, 0.054846918543002436, 0.04332633369735309, 0.07477736140468291, 0.048634391011936326, 0.03929755238017865, 0.0448788082493203, 0.040579593407788446, 0.10891192725726537, 0.047979882918298244, 0.04503584160868611, 0.029581097154212848, 0.032373394284929545, 0.04129825698743973, 0.007770852751231619, 0.012998373048113925, 0.042895928756999116, 0.07662307165030922, 0.019633895917130367, 0.042355502756046395, 0.011453021417504974, 0.017437430564314127, 0.02877428848296404, 0.0570734938872712, 0.001334671172246869, 0.036201417446136475, 0.035609582239495854, 0.02083520315188382, 0.037162687829030414, 0.045223900981779606, 0.04145015722938946, 0.021742757310026457, 0.028704518119671514, 0.01215065295608448, 0.031915488320269754, 0.06181804822491748, 0.032538770232349634, 0.03717931532966239, 0.08115587556468588, 0.018037691479548812, 0.09855387985174145, 0.13438899016806058, 0.13964116333850793, 0.18017117279980863, 0.11836845268096242, 0.07880961003580264, 0.06800625366824013, 0.2375717477074691, 0.15980687125452928, 0.14540495191301617, 0.2091027796268463, 0.10236747057310172, 0.10213843786290713, 0.1658234005527837, 0.18683226965367794, 0.12040185928344727, 0.11764149740338326, 0.129879731418831, 0.2324610219470092, 0.18580519833735057, 0.14237755936171326, 0.11780396582824842, 0.15782284843070166, 0.13368148170411587, 0.07551372796297073, 0.07140329174165215, 0.0965015556929367, 0.10917333965854985, 0.13178443349897861, 0.09289489779621363, 0.12300880439579487, 0.21352403238415718, 0.08478687929787806, 0.05921817344746419, 0.14288789911993913, 0.11724459512957505, 0.12258166660155569, 0.09174399383898292, 0.17973163138542855, 0.06857040125344481, 0.15748933489833558, 0.17687096845890793, 0.13333027197846345, 0.12410328138087477, 0.07020283437200955, 0.09476204974842922, 0.2090300406728472, 0.13456743130726473, 0.17651872736002716, 0.07978766398238284, 0.17648660551224435, 0.08213286421128682, 0.16342714056372643, 0.09304909487920147, 0.13693379504340036, 0.1381081220294748, 0.05940464844128915, 0.07943832701338188, 0.15578581845121725, 0.12091456034353801, 0.07273832296154328, 0.08039489854127169, 0.1796436525349106, 0.1151239424943924, 0.0824933834373951, 0.08571740186640195, 0.17722856998443604, 0.11540405532079083, 0.24072082872901643, 0.11718867027333804, 0.1345692090690136, 0.03611186100170016, 0.07621029844241482, 0.12352898291179112, 0.09643883870116302, 0.05287186934479645, 0.14717594188238892, 0.06569441022085291, 0.13858845696917602, 0.07643254580242292, 0.1402467151305505, 0.12269639330250875, 0.24074984288641385, 0.1176577415317297, 0.20307923427649907, 0.11688411661556788, 0.12871456465550832, 0.16360674878316267, 0.09304927129830633, 0.13310395340834344, 0.06674098941896643, 0.1404849352048976, 0.11913941773985114, 0.11645605601370335, 0.08170179769928966, 0.15848904768271105, 0.22178997312273296, 0.09270864671894483, 0.10403872946543352, 0.2124612701258489, 0.20125545428267547, 0.10444017792386667, 0.15143773891031742, 0.0789976388748203, 0.12575526987867697, 0.15644357672759465, 0.1457080263644457, 0.160625428759626, 0.22467490046152047, 0.12346495634743146, 0.2045188955962658, 0.07895123386489493, 0.16926540514188154, 0.11409631477934973, 0.2399888794337, 0.12640925550035068, 0.1760360582598618, 0.1460536585322448, 0.11348300733204399, 0.10205463200275387, 0.06920107241187777, 0.1727514737950904, 0.09644761215895414, 0.09386831056326628, 0.14159264362284116, 0.12032500840723515, 0.1165180334023067, 0.051660267037472556, 0.1329527079526867, 0.07759951068354504, 0.16942917635398252, 0.1255157877291952, 0.09830664883234672, 0.1448811771614211, 0.10359659604728222, 0.16675520555249282, 0.0973468203363674, 0.1711881426828248, 0.1629081969814641, 0.16196972876787186, 0.15872348153165408, 0.1942810642399958, 0.09590323708419289, 0.16461221554449626, 0.13381492240088327, 0.13608998246490955, 0.21141487413219043, 0.10676906617092234, 0.1607289867741721, 0.1951503897351878, 0.1317155079117843, 0.16361115926078387, 0.08542932982423476, 0.12305326201021671, 0.07280141993292741, 0.14393440367920057, 0.09534655338419334, 0.06146869768521615, 0.09362795988896064, 0.08082067248012338, 0.07215342577546835, 0.17896173841186933, 0.09502022553767477, 0.09190391097217798, 0.17110297296728405, 0.08265106140502862, 0.20185126231185027, 0.11812213089849267, 0.14122243491666658, 0.11189600891832795, 0.12110286738191332, 0.1808037438562938, 0.09716424013354949, 0.17083387954958848, 0.12939020911497728, 0.0791713913370456], [0.04693931893312505, 0.00559798430185765, 0.022993704470406686, 0.04155219532549381, 0.025436011542166983, 0.019452135045347468, 0.029769858811050653, 0.01280257074228887, 0.03368150462795581, 0.0141354985036222, 0.07833281026354857, 0.020234375659908568, 0.007290763780474663, 0.031668080881770165, 0.040814034042081664, 0.022624986844935586, 0.032750412090016265, 0.03391242027282715, 0.01771090562189264, 0.004716025756871594, 0.019796525494062474, 0.02501318753430886, 0.061235573408859115, 0.010319393810017832, 0.031137826120746986, 0.027999715314113667, 0.017720598494634032, 0.010262394323945045, 0.0489302492434425, 0.012258295751442867, 0.028800710636590208, 0.029806781294090406, 0.06091592913227422, 0.01764704190593745, 0.06773721453334604, 0.03594228152983955, 0.014511365343683531, 0.024652761606765643, 0.04714398205812488, 0.014743078267201781, 0.04514152683051569, 0.02244010640840445, 0.01632561531317021, 0.029919523280113935, 0.03499117899420006, 0.05243171046354941, 0.0281564077096326, 0.00907396398750799, 0.04714389045589736, 0.03832583934334772, 0.05002182209864259, 0.03763373362432633, 0.026638809857623916, 0.025432781715478216, 0.020356545890016214, 0.04097284855587142, 0.03780403234330671, 0.05518208770081401, 0.022705554396712353, 0.03479200861017619, 0.009897816610256476, 0.014124337450734206, 0.005976078857202083, 0.025354629748367837, 0.01435051522483783, 0.018859338015317917, 0.04470632464757987, 0.013718508200586906, 0.05209909938275814, 0.020575897601832236, 0.0212413826957345, 0.01485658360512129, 0.04197053252054112, 0.011513003064984722, 0.01604494608805648, 0.01287931899007942, 0.03186040145478078, 0.05961831233331135, 0.0031724035423914237, 0.01464978648748781, 0.05029149227110403, 0.02069163871263819, 0.02516224980354309, 0.058186216679002555, 0.046081382648221085, 0.03381705217595611, 0.05218447944415467, 0.021205133658700755, 0.04835232061200908, 0.0303715192047613, 0.014857141700174128, 0.03257728048733302, 0.028603351941066127, 0.012502114587862576, 0.04998284365449633, 0.01663758366235665, 0.0352657685455467, 0.011878473900391586, 0.026237388540591513, 0.04445735997121249, 0.034714723471552134, 0.055172893551311324, 0.012000019030113305, 0.036542286298104694, 0.031942239563379965, 0.030073761075202907, 0.05820974827344928, 0.06062843384487288, 0.007346077955194882, 0.060993309265800884, 0.015864973156047717, 0.0022180427664092606, 0.01584922435826489, 0.04149491000654442, 0.03802906508956637, 0.04045075996379767, 0.017237230503399457, 0.04402398644015193, 0.04149283029671226, 0.047227896483881135, 0.021669333035658513, 0.05577676936185785, 0.04138795253155487, 0.10516082282577242, 0.07176730542310647, 0.017195366589086394, 0.031188753566571643, 0.04494262786049928, 0.009554459231107362, 0.027010389204536165, 0.02338301224101867, 0.0223278037738055, 0.02426332830717521, 0.01644687630635287, 0.06661442228193794, 0.013147077390125819, 0.012391736448210264, 0.010030647473675864, 0.02157466552619423, 0.007467688393912145, 0.02503016448047544, 0.041413105824696164, 0.01681878135007407, 0.006427198623506618, 0.050379901991358826, 0.03394019949649062, 0.03506649638127003, 0.034196054695972374, 0.01727811393461057, 0.01173161093278655, 0.0415702748910657, 0.041063741714294465, 0.0007574638553446025, 0.03581807230200086, 0.05574350418256862, 0.04433578345924616, 0.04591111107064145, 0.0368670976188566, 0.021540672618097494, 0.0436816146331174, 0.027110047339062606, 0.05213209314803992, 0.048715954313852956, 0.013484761368350258, 0.04888315212779811, 0.014879828518522637, 0.034951847711844106, 0.05204385645421488, 0.026249425751822333, 0.02340286278298923, 0.026893737160467675, 0.0313792963778334, 0.033007210453173945, 0.01868191807131682, 0.039173923299780915, 0.013891728012822568, 0.051397833440984995, 0.0547434690940593, 0.03350588619442923, 0.017096943388293897, 0.03672430331685713, 0.018911987243752395, 0.07318616964455162, 0.022800408503306762, 0.014216521522030234, 0.017598835385537574, 0.034463200718164444, 0.05182175158656069, 0.04038685892841645, 0.036244650304849656, 0.026304078354899372, 0.012028083238484604, 0.032498807912426333, 0.06454936202083315, 0.02213860276554312, 0.024237993505916426, 0.04727154324895569, 0.03357070325208562, 0.021280332302142466, 0.020324089863736714, 0.03072481881827116, 0.01798594300635159, 0.01495399748507355, 0.03714218928611704, 0.036835192902279754, 0.020133077166974545, 0.02512867928349546, 0.025051728323368088, 0.04921988191615258, 0.016457174771598408, 0.04031010643978204, 0.0741234707779118, 0.036965458055159876, 0.010890765248664787, 0.016724889066868594, 0.029073899013123343, 0.029767704462366443, 0.08926430796938283, 0.01925658294931054, 0.03527993635673608, 0.046534013003110886, 0.11518361286393233, 0.0390871284928705, 0.016922682024804608, 0.051791628024407795, 0.02983214832576258, 0.006265879467329276, 0.019700000494984642, 0.02608071650112314, 0.016947323024006825, 0.030090008596224443, 0.04704359280211585, 0.022826910384797623, 0.049863082223704884, 0.016595153171303015, 0.0610150902398995, 0.057351279338555675, 0.04444337536447814, 0.06864022250686373, 0.029280604528529302, 0.016300467109041553, 0.037059587825621874, 0.03521278853129063, 0.05950318529669728, 0.022427056483658295, 0.006204827854941998, 0.02560108045249113, 0.013678685828511204, 0.010855422904049712, 0.015252739490408982, 0.07865531117256198, 0.019770203424351554, 0.032537233350532394, 0.03521660189809544, 0.010209291325216847, 0.04074016193460141, 0.011243198033688324, 0.04143404880804675, 0.0657679159194231, 0.03017488993438227, 0.03159164051924433, 0.05091666051053575, 0.06150927407933133, 0.02545553638732859, 0.023390394702021564, 0.046811014746448824, 0.03795618025053825, 0.005976114480290562, 0.030239296478352377, 0.03226078122055956, 0.02812346483447722, 0.01127980075710054, 0.03449835561748062, 0.030552820369069065, 0.03353384862254773, 0.03881815381880317, 0.029618185878332173, 0.06587697006762028, 0.03185800283348986, 0.023442540118204694, 0.009845487141449536, 0.004009218304418027, 0.03928078577986785, 0.07439590937324933, 0.018523936459262456, 0.07075879203953914, 0.009718357668524342, 0.033506327242191346, 0.06665923273456947, 0.02809393159779055, 0.030338603471006666, 0.06252280183668647, 0.10613018473876373, 0.07195511713091816, 0.05657501152849623, 0.052843462476240735, 0.020909341584358896, 0.03368463606706687, 0.08960107846983842, 0.04220913935984884, 0.030050483931388174, 0.03567154945007392, 0.02947784787310021, 0.05606289061584643, 0.01099875579322023, 0.019673875200429132, 0.05715518950351647, 0.05933277801211391, 0.03189247580511229, 0.04157281939738563, 0.0511018869999264, 0.029091669845261743, 0.04709365850846682, 0.01941811669218753, 0.038016485050320625, 0.00625384522468916, 0.026174255946118916, 0.03808406374550291, 0.026336617501718656, 0.025077726392607604, 0.048126324346022945, 0.020160758003060306, 0.02622556676422911, 0.024866298273471848, 0.025157667995829667, 0.01775689672545663, 0.020582496354888593, 0.08121847720550639, 0.02349678220759545, 0.013098250010183879, 0.018071289140997187, 0.045351414675159116, 0.039282295520284345, 0.007539643639964717, 0.015500421735591121, 0.029771528007196527, 0.05196662899106741, 0.03194943203457764, 0.029944021786962236, 0.033482568338513374, 0.016800691606476903, 0.008403629064559937, 0.022408629168889353, 0.023902149205761294, 0.05063332464279873, 0.08946968016347714, 0.043834658206573555, 0.03471749867977841, 0.017109711721007313, 0.061472748539277484, 0.03058801937316145, 0.008408473804593086, 0.1159625303532396, 0.11050855408289603, 0.0624086790319, 0.0890261557485376, 0.1390405377107007, 0.09129460009613208, 0.207215407331075, 0.0994585163093039, 0.09198183393371956, 0.04272807276408587, 0.20731531482722076, 0.0854265478306583, 0.13116456461804255, 0.10523148546261446, 0.18158625758119992, 0.0643152945808002, 0.17991577221878938, 0.1870407291821071, 0.10232002740459782, 0.11966161829020296, 0.1826975079519408, 0.16401244487081254, 0.14527805229382856, 0.10814396810850926, 0.1457656068461282, 0.09732822847685643, 0.14797374978661537, 0.11473833104329449, 0.10459474820111479, 0.09375597909092903, 0.14203788473137788, 0.05977289618125983, 0.1455762412931238, 0.10601530876010656, 0.17758294168327535, 0.09628840070217848, 0.07615316579384462, 0.08712760119565896, 0.11945207310574395, 0.10744953501437392, 0.16780664984669003, 0.15105587297252246, 0.1209932839764016, 0.10311002537075963, 0.11990267464092799, 0.13998557414327348, 0.09350055136850902, 0.06972985475191049, 0.13635260265852722, 0.3075074835547379, 0.10104622718478952, 0.14650013457451547, 0.10736110154539347, 0.06542486218469483, 0.10320373105683497, 0.09431845747998782, 0.07661466460142817, 0.17447578055518015, 0.19030649108546122, 0.15955290916774953, 0.12431760345186506, 0.1585656271449157, 0.17702296030308518, 0.15278073613132748, 0.0983479241175311, 0.1016140863565462, 0.14664201624691486, 0.12519383643354687, 0.12217639120561735, 0.08105241933039256, 0.0977461856922933, 0.0869634635746479, 0.13085638758327278, 0.10532050247171096, 0.21712115007851804, 0.09894143869834286, 0.10208684206008911, 0.13861251782093728, 0.06136767060628959, 0.1747943798878363, 0.10728843044489622, 0.084224936951484, 0.17285371545170033, 0.1498728200261082, 0.09998643690986292, 0.11221314940069403, 0.1425204181245395, 0.11477991166923728, 0.1975322240697486, 0.07404607028833457, 0.17428349730159554, 0.15158552383737905, 0.0967361523902842, 0.0804352578041809, 0.14599541308624403, 0.06449919114155428, 0.1332659875707967, 0.0828465541292514, 0.10966034459748439, 0.1360785695058959, 0.18559858442417212, 0.16447357726948603, 0.11545787671847002, 0.17122164874204568, 0.11242252495139837, 0.08415783662348986, 0.10157388315669127, 0.14118580759635993, 0.0906027386497174, 0.12310618774167129, 0.08669026502008949, 0.08762941855405058, 0.14578877203166485, 0.11292164852576596, 0.10332007267113243, 0.1464637650975159, 0.20368763591561997, 0.1633869441492217, 0.16560579437230313, 0.12465096770652703, 0.08653108070471457, 0.16837262947644505, 0.16973344502704485, 0.12621531662132057, 0.13857780396938324, 0.10845319008720772, 0.1255228580640895, 0.1543304015483175, 0.1023777707346848, 0.07878571203244583, 0.1706896230046238, 0.1768031149570431, 0.14506698719092778, 0.1408809418124812, 0.09405229533357279, 0.11753713871751513, 0.07062985002994537, 0.13551447620349272, 0.14463921157377108, 0.11453004793397017, 0.12140256272894995, 0.12693535084170954, 0.12266032238091741, 0.12007692243371691, 0.16971470388982976, 0.1192541987236057, 0.1568585280328989, 0.1481551221971001, 0.10363735564585243, 0.07486287717308317, 0.17756588331290654, 0.12307307523276124, 0.1204602811485529, 0.1424520896481616, 0.14113307185471058, 0.14616298409444944, 0.12394546770623752, 0.07811584869133574, 0.09252253134867974, 0.11557488329708576, 0.13131039536425046, 0.1419975118977683, 0.08008036363337721, 0.09346050423170839, 0.08722875041088887, 0.07124615660203354, 0.10387158593428986, 0.08614513677145753, 0.1464086544833013, 0.2255016818110432, 0.17204836223806652, 0.12243659581456866, 0.09856662952474185, 0.2434301104928766, 0.08709922486117908, 0.11800466291606426], [0.005104093504736998, 0.004898447776213288, 0.035143801875944645, 0.06557590407984597, 0.04261722728343947, 0.04686267840276871, 0.08052044109042202, 0.034137500516538105, 0.008707109788831855, 0.03327694169378706, 0.05336882160710437, 0.013408337121031113, 0.07311706085290227, 0.03441191025610481, 0.023637132087190236, 0.04917201127058693, 0.061704386823943684, 0.029561931932611123, 0.03412988396095378, 0.022897781671157906, 0.016992939236973013, 0.05039835814386606, 0.01799890472154532, 0.034721366329384704, 0.036632042910371504, 0.01784147950820625, 0.02157259260171226, 0.054165601530777555, 0.026407607531707202, 0.027244653419724534, 0.03360857568415148, 0.030496932832258086, 0.06451116049928324, 0.005370036823608513, 0.06124765133219106, 0.06575011116053377, 0.0723212274855801, 0.03152420770909105, 0.04462446957560522, 0.0152339542484177, 0.018876208092219064, 0.06092242271240268, 0.025968352798372507, 0.01609628913658006, 0.04777358452390347, 0.022464864454897385, 0.03222645413396614, 0.03468307999095746, 0.024607201372938495, 0.09359642158129386, 0.030731342932475463, 0.01666570215352944, 0.037592933313655, 0.048079871838646274, 0.07822410216821091, 0.08589903890554394, 0.032314527979386706, 0.042981838075710196, 0.041332889414791546, 0.027505014091730118, 0.033455929053681235, 0.0587313517129847, 0.03853897397805538, 0.010274428142500775, 0.03577004559338093, 0.02439500481289412, 0.02258796088530549, 0.07766570855996438, 0.05482314606862409, 0.01442754760916744, 0.05295012478849717, 0.016032657818868756, 0.024186563944177966, 0.019953716612820114, 0.040163776970335414, 0.036106436114226065, 0.040274846367537975, 0.12566423762057508, 0.032330198745642386, 0.016975906311667392, 0.048536057717033794, 0.035366775268422704, 0.03801482942487512, 0.041961443543966324, 0.016880814717816453, 0.03508869465440512, 0.04718104364084346, 0.015966064695801054, 0.012989300186745822, 0.06397628491478306, 0.034084371224577935, 0.04492047369214041, 0.02974150961797152, 0.007700641340176974, 0.03186583312760506, 0.0556349758990109, 0.017617057443463376, 0.04767770413309336, 0.040281187277287245, 0.01597721641883254, 0.04694302712700196, 0.046830770293516774, 0.011502291541546583, 0.026818938852686967, 0.04012826584013445, 0.021382818231359124, 0.010714727819764187, 0.01568345316419644, 0.009358120034448802, 0.02622209266493363, 0.03209570382854768, 0.03642809563981635, 0.019780345826542804, 0.009483027305187923, 0.01798483869060874, 0.03682255179488233, 0.012346251701403941, 0.03721874160692096, 0.03899321924628956, 0.03610709768586925, 0.0646545620901244, 0.026680166567010537, 0.01681244552933744, 0.044782195040690045, 0.04301706761387842, 0.04220375179180077, 0.030088044237345457, 0.027185488558773483, 0.026860312525449053, 0.033859226520040205, 0.008357031520323029, 0.018276055742587363, 0.01691263461751597, 0.025784434185230305, 0.050553824087338786, 0.0601227284808244, 0.004780751212300467, 0.0012751903684277619, 0.053028444693024666, 0.007034977282663541, 0.04185370236103024, 0.05949253908225468, 0.033107179017471414, 0.03416587345834289, 0.026475810479106646, 0.0607926393193858, 0.04948371668745365, 0.021952331332223754, 0.07461799388485295, 0.026236123072781732, 0.020429244131914208, 0.04755597495074783, 0.029498258206461157, 0.013806333532556891, 0.006104216802798743, 0.021121410919087272, 0.036341633315065076, 0.034017566059316905, 0.020920478040352464, 0.008051750133745372, 0.016933877852612307, 0.02865155167611582, 0.02636413718573749, 0.0484878613746592, 0.017256219305896332, 0.02108754523630653, 0.005737986856339765, 0.02158843300172261, 0.026455403538420796, 0.015115088483850871, 0.006769348210322538, 0.04632432871897306, 0.05552662403455802, 0.017684334190562367, 0.02586913401527064, 0.04564658758629646, 0.03514710973416056, 0.050271991174668074, 0.024654089839064648, 0.016099386648940187, 0.03911802897761975, 0.016603651822411587, 0.045552837795444896, 0.03450827579945326, 0.07194024364330939, 0.050248646177351475, 0.057227215995746, 0.02200006627078567, 0.06407661310264043, 0.014038390812597104, 0.009508928683187281, 0.12385553467486586, 0.02263533789664507, 0.016192720837092826, 0.010584332048892975, 0.06634685556803431, 0.03450385853648186, 0.018095850412334715, 0.016611675499007106, 0.03251013266188758, 0.03287056367844343, 0.011207829395841275, 0.022264058801478574, 0.02056720556824335, 0.014352527081168123, 0.040333305552069626, 0.07385993456201893, 0.05483249628118106, 0.04167070146650076, 0.04060487222990819, 0.058784426722143374, 0.024200049827673605, 0.07168539946100541, 0.02892462470169578, 0.023814073664003184, 0.003793816514579313, 0.020383437929142798, 0.023419751519603387, 0.007065714494923928, 0.001835385275106611, 0.01671483657056732, 0.029864721399332796, 0.02392664092725941, 0.019262433617508838, 0.06854211312851735, 0.06509957249675478, 0.05902166970606361, 0.03941518999636173, 0.03532935066946915, 0.07442120515874454, 0.025264883314126303, 0.028681329185409204, 0.049922684739742956, 0.01964635042739766, 0.04998380717422281, 0.023050530081880943, 0.021972799341061285, 0.06871977395245008, 0.016970800335652063, 0.013060941610352268, 0.02912913854899151, 0.012803735278014625, 0.011202508833126297, 0.01042124446082328, 0.015408045978152325, 0.03298598248511553, 0.0903343034109899, 0.011623533026847457, 0.04019564776016133, 0.036163348238915205, 0.009312972858814257, 0.0493129972767617, 0.01353144712213959, 0.023510887254295603, 0.031797877845487425, 0.029817244304077964, 0.052899570536932776, 0.07987318653613329, 0.06233397911169699, 0.043668379807578664, 0.04348340776882001, 0.003038710303371772, 0.02401909132355026, 0.02927586156874895, 0.012805293364051198, 0.06847147763307605, 0.026686161423900297, 0.037456137261220386, 0.047468549106270075, 0.05127946300698178, 0.018913266282262545, 0.014369851776531764, 0.05822220617639167, 0.07407423627695867, 0.024441660880776386, 0.019161917136183808, 0.006034993932449392, 0.03644496402037995, 0.014867574176085847, 0.013532073070694293, 0.023052762462092296, 0.05624868028930255, 0.027012677563886558, 0.05091152060776949, 0.09000942084406104, 0.025114207827885236, 0.048522385236408026, 0.06055404605077846, 0.028691344362284456, 0.01292715486072536, 0.009931085182220807, 0.03157242101484111, 0.00659162674232253, 0.02280956702972097, 0.014366815332323313, 0.021517938302297677, 0.0029346425393928905, 0.018233567576057146, 0.046398207611803494, 0.07332209377948727, 0.05422484781593084, 0.009048099080765886, 0.044313066106821807, 0.04246798350608774, 0.024536816935454096, 0.04650705141414489, 0.05810518602707556, 0.02947640259351049, 0.009053276302958173, 0.06250291397528988, 0.01650427358358034, 0.05347575872604336, 0.011748563282058706, 0.04917460327435817, 0.052088704226272445, 0.027349151205271482, 0.013903859370787228, 0.05612533280093755, 0.002427212000059496, 0.021993318240025213, 0.036136875195162635, 0.023595894121431878, 0.050563198048621416, 0.0012625388709628688, 0.08614775591662951, 0.03316873910703829, 0.04952007259375282, 0.03743425450686898, 0.04945335224536913, 0.015679424362523214, 0.08515838400593825, 0.03941239782475999, 0.030402969302875654, 0.013945143985828119, 0.023811790393665433, 0.016909666026809385, 0.04263560879709465, 0.04288948267432196, 0.05152334884873458, 0.04133533892620887, 0.017004565934517553, 0.07355344707944564, 0.04972308687865734, 0.031633285606013875, 0.016385280593697513, 0.01869095446142767, 0.03736082683982594, 0.023753561911040118, 0.05602810551811542, 0.029649344206388508, 0.017436584091878364, 0.05095761688426137, 0.0893218545243144, 0.13860837875732354, 0.1425024505172457, 0.10154476721904107, 0.08889203651675157, 0.1186621497784342, 0.1322871329528945, 0.14319839674447263, 0.1522811715091978, 0.10926570184528828, 0.13217531038182123, 0.09661333076655865, 0.18084806576371193, 0.11239868801619325, 0.10391059491251196, 0.1820956338196993, 0.12711050787142344, 0.08187801324363266, 0.07923857308924198, 0.11712859278278691, 0.15376412336315426, 0.10415331367403269, 0.09410744665988854, 0.117101234250835, 0.09425291099718638, 0.07761825182076011, 0.1110060763146196, 0.10246446036866733, 0.08073122799396515, 0.07192897317664963, 0.17858699709177017, 0.19596894724028452, 0.20018562168947288, 0.09777167825294392, 0.1602147522249392, 0.13649641137037957, 0.2304338307252952, 0.12588358085070336, 0.11108838261238166, 0.09515488081212554, 0.128860313977514, 0.17262454703450203, 0.10688559777502503, 0.14068921495761189, 0.1783702458654131, 0.08557256178132125, 0.08632120982344661, 0.06484767994178192, 0.17078760346131666, 0.16545285257909978, 0.13895713218620845, 0.09276231205356972, 0.11612289531954698, 0.14713546048317636, 0.2099909819662571, 0.1697020967091833, 0.09305885221276965, 0.0947834507429174, 0.09158664835350853, 0.08003059308975935, 0.08615519266043391, 0.1470700225659779, 0.11184039618819952, 0.08372883964329958, 0.09926191757300071, 0.06910594180226326, 0.08704943396151066, 0.20673410887164728, 0.1505890680210931, 0.11538084942315306, 0.18101338403565542, 0.20085354442042963, 0.14829981300447667, 0.15843388278569492, 0.11966689729264804, 0.22822248509952, 0.14995528917227471, 0.23897324821778707, 0.11240691186061927, 0.10003944406551973, 0.12176319052066122, 0.09184023724602801, 0.17139415948518685, 0.09724170169127838, 0.11376553574310881, 0.09135403976376567, 0.15464178126837524, 0.11999267552580152, 0.1686375838305269, 0.2362923292177064, 0.12998993907655987, 0.1478900457067149, 0.19136419147253036, 0.1382760458758899, 0.10931341642779963, 0.15489229639726027, 0.12379777777407851, 0.13827947926308426, 0.11468284044946943, 0.09747190148170505, 0.11058887227305345, 0.1279728715973241, 0.05493685835972428, 0.17490223981440067, 0.10248683166823216, 0.1676687579602003, 0.056023040254201205, 0.13428578499172414, 0.1275283768773079, 0.12594929018190928, 0.1491502480847495, 0.15819400708590234, 0.10406739078462124, 0.08304610449288573, 0.13389573592160428, 0.10021074701632772, 0.11686475122613565, 0.1429592538625002, 0.13211777061223984, 0.12713199029011385, 0.15572525241545268, 0.14909031987190247, 0.0730513786630971, 0.1413587797433138, 0.11844818054565362, 0.15352697537413665, 0.1826914418488741, 0.127265458128282, 0.10542294768882648, 0.10910740641078778, 0.08521793223917484, 0.114860168791243, 0.1152360907622746, 0.2098883060472352, 0.11182003335228988, 0.11970243895692484, 0.11037732541028943, 0.1318164196397577, 0.1177704461983272, 0.1591124449457441, 0.12526795959898404, 0.09712348732032947, 0.09238087359283652, 0.10491547813372952, 0.09927832454975162, 0.1583684448684965, 0.134286870647754, 0.07806847337633371, 0.18822024017572403, 0.1036482664889523, 0.10630306867616517, 0.09286703036299773, 0.13078478856810502, 0.18013933593673365, 0.32042168772646357, 0.09172464202025107, 0.17769614846578666, 0.09761494344898633, 0.08263657468238048, 0.13919360164020741, 0.16184778245432035, 0.15906543603965215, 0.12052981741726398, 0.10835261762674366, 0.12597633658775262, 0.1440986091537135, 0.11568514523761612, 0.05953129700251988, 0.13265629671514034, 0.1380903444119862, 0.14274258406034537, 0.1312204080500773, 0.10047707201114722, 0.09495828886117254, 0.12597554948713097, 0.1115447041977729], [0.05561330009784017, 0.053236955111580234, 0.040700050336974006, 0.044458927387105565, 0.020350362739658782, 0.02768694968628032, 0.04164119876388993, 0.03790933419285076, 0.03375895940033453, 0.005845372232475451, 0.05681150473122086, 0.02939347204353128, 0.048970282809542756, 0.03361804803301181, 0.0277670337818563, 0.016837624267541935, 0.02680802292057446, 0.042388818825462034, 0.019649110368586013, 0.008391499402932823, 0.01928891514294914, 0.006755048508888909, 0.04312695975282362, 0.025707288146285073, 0.029208832486931766, 0.08996547213090317, 0.03804414553035583, 0.019887613731303384, 0.04229171367894326, 0.06541660441351788, 0.024693226042602743, 0.04706005745434335, 0.02489729205678616, 0.024762384028040936, 0.018234931431444626, 0.04237005054684622, 0.04049383336678147, 0.01416979929698365, 0.06032860279083252, 0.09361886751971074, 0.07457021823418991, 0.023736026869820695, 0.08289066569081374, 0.04982008006689804, 0.014133498521654733, 0.11038615315088204, 0.014647213143429585, 0.03290269570425153, 0.019983590813353658, 0.0722117322896208, 0.05859373802585261, 0.03164693773058908, 0.03395064215042761, 0.065670471505395, 0.022619109035336545, 0.06306897502924715, 0.029347413086465428, 0.06476796564779111, 0.05712705744164331, 0.008154131738202912, 0.07920901610382966, 0.010007552686147392, 0.05812649202666112, 0.021209325308778455, 0.044991607910820415, 0.004076675711465734, 0.04389072894783957, 0.04080702138266393, 0.016303836035409143, 0.04104618801336203, 0.009839045299616243, 0.06159035222870963, 0.013559766629311656, 0.033338651061058044, 0.011692973452487161, 0.06669820100069046, 0.03435958842081683, 0.05783761252782174, 0.04189101839438081, 0.0512914527207613, 0.0373014041355678, 0.02673002192750573, 0.08272353573037045, 0.012949761103040405, 0.047920487355440855, 0.049800243095627854, 0.017711850481906107, 0.02145402199987854, 0.040113382174500396, 0.03528660974864449, 0.014859034812876155, 0.03341097610869578, 0.026502375125086734, 0.017711621476337314, 0.057682797977966924, 0.048263269676161666, 0.043047401521887095, 0.05437201866880059, 0.016831566646162952, 0.007290295591311795, 0.057231198996305466, 0.012225275692929114, 0.026440111055438007, 0.032203848739819865, 0.032467364599662166, 0.03517033938052399, 0.025218892210562314, 0.040280047338455915, 0.04752326617017388, 0.004693947075533548, 0.029857362687055553, 0.04937105273295726, 0.018244149329672967, 0.046547420855079374, 0.017311248495908718, 0.035663630946406295, 0.038775938762617965, 0.04390736323382173, 0.018834849686494896, 0.021873768851427094, 0.035204829315521886, 0.05439605577183621, 0.023821929403181587, 0.037163044059915204, 0.04321032117253967, 0.09004059274281774, 0.06800529693386384, 0.07256444157766444, 0.03124904479565365, 0.05830266007355281, 0.0613842336460948, 0.04609390501199024, 0.06515384172754628, 0.01531643866162215, 0.024546884698793292, 0.06812509229140622, 0.05499359745798366, 0.009048181353136897, 0.06211474444717169, 0.011951059335842729, 0.020746783253603747, 0.025299066212028265, 0.036484237627259324, 0.047854767846209664, 0.025360388814338615, 0.036098992585071495, 0.0225580595433712, 0.04772305402106472, 0.03917481218065534, 0.06281548113163028, 0.10847977508923837, 0.03040994464286736, 0.03950306706662689, 0.04322466201015881, 0.02526610128448478, 0.025455466837489178, 0.05014986844201173, 0.056640113570860455, 0.026235434359737804, 0.045736781853650293, 0.02092808611424906, 0.07273669447749853, 0.001580858095881662, 0.031926473802221675, 0.04739598317870072, 0.021817942382767797, 0.011380047520755656, 0.044327898882329464, 0.028194855200126767, 0.05776579638144799, 0.01452955008218331, 0.014613467900614654, 0.0029573060331001344, 0.004998150863684714, 0.05438603041693568, 0.04558872211990612, 0.1049976215830871, 0.015372889382498605, 0.032148398858095915, 0.03665798669680953, 0.02412134824719812, 0.03873552521690726, 0.03821437978850944, 0.018823733586551886, 0.011076124900552844, 0.05563015151502831, 0.01551683889036732, 0.03282956998529179, 0.015521008488056915, 0.031443367046969276, 0.019168453124750937, 0.03128257460360016, 0.043820385222456286, 0.07602765038609505, 0.038090418225952556, 0.0026238563254342546, 0.026397765381261706, 0.00410541082133672, 0.04874236289677875, 0.02263230484511171, 0.04478235449641943, 0.048159603096012554, 0.04240310198760458, 0.033502096576350074, 0.01834071843352701, 0.05415647862745183, 0.03600117836945823, 0.022114662353747656, 0.04689402672063027, 0.04412596686077969, 0.029345716748918806, 0.06169097897197519, 0.0031043358779113206, 0.02480136925753738, 0.04582542906116162, 0.04129462682508996, 0.027011183090507984, 0.012455021713062056, 0.038259102031588554, 0.03418336269844856, 0.018771652631195526, 0.019954668258183768, 0.02095584667819951, 0.029624723563236848, 0.03330586424895695, 0.02735304429994098, 0.022156251461378167, 0.04256760262485061, 0.07744742384446518, 0.050164426410836835, 0.06303242913314275, 0.05229913829160588, 0.04555761128930109, 0.017890417150088718, 0.05721446632274559, 0.05133007154134767, 0.07151605747640133, 0.026810094148718884, 0.06887167080172471, 0.10475528958652701, 0.036991703789681196, 0.05412331183574029, 0.010764159944041498, 0.020590272366202304, 0.02395933952980808, 0.0027570658962109257, 0.026083605363965034, 0.011678987149415272, 0.0389588107354939, 0.011781128722109964, 0.041882987932435105, 0.021805011201649904, 0.04684015104014959, 0.017299509840086102, 0.05380150303244591, 0.05969692740057196, 0.028681349541459764, 0.0062721118114755624, 0.029684807839138166, 0.04303262981453112, 0.04739274995933686, 0.03426556382328272, 0.03321525268256664, 0.023424034771908606, 0.03949635635529246, 0.07702428940683603, 0.028140485885420015, 0.029591753546680723, 0.0245966314936855, 0.015495331026613712, 0.04862346320546099, 0.0010328269896230527, 0.04535884124093822, 0.0498493181408516, 0.03247211095211761, 0.004662262034668986, 0.053195540726717026, 0.00990204727609775, 0.03549926940883909, 0.01644936144085867, 0.03503531091181295, 0.029050387774727175, 0.03213445496346269, 0.026754695157121335, 0.03125040865104113, 0.03098000566075955, 0.0322871660547597, 0.09482875652611256, 0.06138471540595804, 0.02137104225611048, 0.05864000054342406, 0.018903110309370925, 0.03328592889010906, 0.08392382346625839, 0.01729534872408424, 0.01550332416913339, 0.01909827394410968, 0.008740955115562039, 0.005512896434603525, 0.03283812631187694, 0.023445844583745514, 0.023661184457263777, 0.05951483574296747, 0.06124981585890055, 0.014399410458281636, 0.017907161698011414, 0.006677630631851831, 0.016701316760320748, 0.03623654181137681, 0.015795840615672723, 0.014059402497618325, 0.0386800821205335, 0.09395658118384224, 0.04612464264833501, 0.007789915344411773, 0.04317140718922019, 0.008622888325979667, 0.05678153723212225, 0.04846118477040103, 0.039963626103209596, 0.0065541067243819785, 0.06698615769190447, 0.02999277113537703, 0.021073346891041313, 0.03447423369756766, 0.03131459127845509, 0.09143120955143656, 0.03185247955843806, 0.03508306959910052, 0.01732938743329474, 0.024383863267887915, 0.027372940643025295, 0.03235758102631994, 0.0639451944402286, 0.0324506319261023, 0.02979552439813103, 0.07681194187275, 0.04232550811554704, 0.032051680476537774, 0.023812940510522042, 0.08569490164518356, 0.08522203737603766, 0.019591048127040267, 0.036331136378326585, 0.030273158768458024, 0.02746107386025999, 0.004956868793150144, 0.04282662658286946, 0.04648461904642837, 0.029047900943883827, 0.011353939189575613, 0.028700033003198247, 0.25001787128193037, 0.13065761753490993, 0.09001668795411076, 0.22909394119467053, 0.14969869436962263, 0.09602506804679121, 0.20804825478366443, 0.08372073793517691, 0.168442233598658, 0.19278072831886156, 0.11576612160674163, 0.11533420692597117, 0.061962046926575046, 0.13781422137149743, 0.13653092166142805, 0.10849105234124831, 0.09260685289544718, 0.14753671895180429, 0.0981622226536274, 0.07837523227291447, 0.11455469232584749, 0.08730051905981132, 0.10002643654921226, 0.0956179741770029, 0.09169114953173058, 0.23967374062963895, 0.17798836635691778, 0.10709030500480107, 0.08169676975480147, 0.1330305766314268, 0.06320503487118653, 0.14811841345259122, 0.1708451703722988, 0.10862620973161288, 0.1020648575254849, 0.15639943123928138, 0.1521093121596745, 0.11791124221469675, 0.20442527133439267, 0.19141520373523235, 0.1081036902698023, 0.14549564490360872, 0.1252926175615617, 0.091472959811134, 0.09647818694689445, 0.22301563806831837, 0.10010649689606257, 0.19753210193344525, 0.131180591615183, 0.17773487924465112, 0.13811236965869153, 0.13648792968264647, 0.11277607562286512, 0.1618544863803046, 0.10725745532129492, 0.13667509678219045, 0.07099245914391109, 0.11714964093906538, 0.1619267232183899, 0.09230781572737864, 0.24772290300045693, 0.08604280011994497, 0.2005519898874419, 0.2018173627023186, 0.1803865126733269, 0.12682766733425005, 0.10046241565474442, 0.15297012882573263, 0.11552710086107254, 0.09393397239702088, 0.10153931858284132, 0.10876365378499031, 0.1940881295927933, 0.17143139748701028, 0.09606055542826653, 0.11965268876935754, 0.17520369935248578, 0.11560567521623202, 0.11636533588171005, 0.23376057935612543, 0.07784079095082623, 0.06799114947872502, 0.1510544073368822, 0.08695010322013072, 0.10150955125157322, 0.15739029592701367, 0.14758405355470522, 0.11402615425842148, 0.143124327861837, 0.19456353836825915, 0.08011803589761257, 0.1383715428944145, 0.15355058839278563, 0.12233744827764374, 0.1175129557294505, 0.09061575973672525, 0.10363333193319184, 0.1032693318224379, 0.12271176890603133, 0.09162571161453213, 0.10335203167051077, 0.11039633796151195, 0.08024422305503062, 0.10799647495150566, 0.13875053184373037, 0.06848562508821487, 0.1295865092958723, 0.08560230197118861, 0.13215420794274124, 0.12348289681332451, 0.06801510176488332, 0.12005660709525857, 0.2129557728767395, 0.1068843560559409, 0.10392370420907225, 0.09678255061485938, 0.2001955418714455, 0.2172551200326, 0.0881900784692594, 0.07909986696072988, 0.09872126087014164, 0.09292110960398402, 0.09670379305524485, 0.08005384648484842, 0.1039423503513847, 0.23162237980536052, 0.14336459711194038, 0.15819917752274446, 0.18901633817170346, 0.16364957791353973, 0.12479070520826749, 0.12422256783715316, 0.14569092728197575, 0.14889685596738542, 0.11559203666235719, 0.14328724411981447, 0.1885288514729057, 0.09598379276160683, 0.09738006855228118, 0.10989329245473657, 0.06874672536339078, 0.14138802460261754, 0.10875393716352326, 0.16553490103355475, 0.099208550793784, 0.14186754530029638, 0.07412359969956533, 0.1343526749738625, 0.18241569878799574, 0.16675482557288238, 0.23435798872794422, 0.11650317348539829, 0.08111802009599549, 0.11500776372849941, 0.09525543291653905, 0.09216143536780562, 0.13465965778699943, 0.13215732920382703, 0.12505179191274302, 0.06643110247594969, 0.11484549886413983, 0.20482997676091536, 0.05033800923930747, 0.20001912276659692, 0.15788173169961997, 0.18130220925169332, 0.13944244757294655, 0.14055029169789382, 0.09730936520333801, 0.11038919298776559, 0.08665226027369499, 0.2094496874404805, 0.11907369483794485, 0.09729192006800856, 0.1059042936457055, 0.13950644699590548], [0.027603810486782874, 0.008390885328740945, 0.04345938762915986, 0.08086173741945199, 0.031128672683345418, 0.023609340989163945, 0.023207085074058602, 0.04465229968939509, 0.04019919989098396, 0.02619001322558948, 0.022636776390884603, 0.009632994570503277, 0.07038861726011549, 0.014180469260151898, 0.01429213916084596, 0.03596003200592739, 0.06271404014634234, 0.008264370778176402, 0.010469767348175603, 0.04401214261140142, 0.058398604925189695, 0.03218474119369473, 0.050489770381578376, 0.010977269133685954, 0.028497581902359213, 0.04098884162626096, 0.023083121815164174, 0.01775837253912219, 0.038480524971548996, 0.05165104913924422, 0.04834742158917444, 0.03131960904491799, 0.027923860188041414, 0.09066491959882633, 0.023842607757874897, 0.0026319822063669562, 0.04490919644013047, 0.03593158442527056, 0.023630718234926462, 0.02811898650335414, 0.04030054588136928, 0.01691941318235227, 0.025100669357925653, 0.03277499880641699, 0.030620117472218614, 0.05749722543571677, 0.011182838951104453, 0.052190477693719525, 0.028572889111403908, 0.04706875627328243, 0.04068458652389901, 0.06078708211758307, 0.05195166050855603, 0.0332475543421294, 0.047963964486760755, 0.06482473867280142, 0.021264693766300167, 0.019130526409883584, 0.05046833885301437, 0.03345281457794564, 0.024171927943825722, 0.036934513465634415, 0.0077169796152572545, 0.013688305758738091, 0.048467705491930246, 0.06354656868747302, 0.028549143778426305, 0.07094258682004043, 0.046813443901815584, 0.013592289660924246, 0.04852338268288544, 0.06642749945500068, 0.019387933758220503, 0.015409207969371761, 0.059818812645971775, 0.015545125318957227, 0.06117801328322717, 0.056639625025647025, 0.02472895260767213, 0.02406693822039025, 0.020609990593844225, 0.038274945824273994, 0.009421027016027697, 0.03468357871419617, 0.059482618900282044, 0.021789633901789784, 0.06408059610319988, 0.026824923531551446, 0.06429976969957352, 0.04019766300916672, 0.07020281401595899, 0.040819255369050164, 0.044509491816695244, 0.03254605091309973, 0.05413800211889403, 0.02602158726326057, 0.0076548266557178325, 0.04217354680544563, 0.04881520702370575, 0.04134492662602237, 0.0450159639253148, 0.010838080397141832, 0.08583217606480632, 0.022244123442630683, 0.043078760017773936, 0.06617652970765318, 0.0755447166572724, 0.012782954294899744, 0.06697471080613987, 0.03639380926532405, 0.01784676868867661, 0.023529490988169397, 0.04998032968225224, 0.019333079290975417, 0.0631195055320859, 0.03285134417404022, 0.0325198119639286, 0.11596932927412645, 0.06099999283573457, 0.029005132881658416, 0.0310101529716381, 0.018444315463836704, 0.04343707061239651, 0.030467891533459936, 0.03300859805728708, 0.011976958169335765, 0.037134647369384766, 0.01764232778389539, 0.04294254411278026, 0.021943340743226663, 0.036716489986117394, 0.009181219169736972, 0.0291008300680135, 0.0517698843697352, 0.052246969126697095, 0.02450155177419739, 0.02672014245763421, 0.028322884580120444, 0.02478542538093669, 0.011968334837417518, 0.04744200820901564, 0.044006653263100555, 0.07031477907938616, 0.02593746079531099, 0.06013975292444229, 0.008227794347996158, 0.0476416366041771, 0.007721308668676231, 0.045600016335291524, 0.01291860531949039, 0.02135889987195177, 0.0482431205787829, 0.04673419101163745, 0.027461715075852614, 0.05026525332193289, 0.08755739884717123, 0.0421664866485766, 0.05986721933420215, 0.038207506228770526, 0.04204964291836534, 0.013688879968997623, 0.04627239364864571, 0.033172772997724156, 0.10057275223412684, 0.02667185620936964, 0.01610552060550877, 0.027058091912684695, 0.032982457495693646, 0.01637091940002782, 0.07866209652274847, 0.06587049005819218, 0.040178643672594, 0.040401589923671315, 0.05288290571687477, 0.04527186322957277, 0.07800313045403787, 0.039468994430665455, 0.016193533382777656, 0.055632465319441896, 0.0617727017296212, 0.017972642023648535, 0.032242501487157176, 0.05169716577178665, 0.047407487739941905, 0.02645336284435221, 0.004003691212606749, 0.031098521979791776, 0.02334673097357154, 0.015874270782140747, 0.060030434147587845, 0.027657731968377317, 0.05137911944517067, 0.057023411217544756, 0.03004372232992734, 0.041552161398742876, 0.037517351297927756, 0.09131425725562231, 0.012918417874191488, 0.014953778657530035, 0.008175703214614518, 0.031674554105848074, 0.02754176015566502, 0.029918583509113108, 0.01589828074377562, 0.04201781962599073, 0.026083834369533827, 0.02261593858046191, 0.014115765857111131, 0.032376111817679236, 0.08089859544166497, 0.0370487312653235, 0.09975585035447564, 0.045107895242316384, 0.06498847595815148, 0.022104430045666437, 0.025645297186981355, 0.04392733591209565, 0.017207374962578927, 0.028245268655674796, 0.03943196677469781, 0.02807296147303922, 0.05127777345478535, 0.028151942949209894, 0.006518107473051974, 0.05549755559435912, 0.05979411397129297, 0.05490629035713417, 0.006009793990025563, 0.0785781413848911, 0.06366890176598515, 0.052006838976272514, 0.058710819243320396, 0.02916962673355426, 0.028506935507591282, 0.08193593299282448, 0.032239071492637904, 0.03088633729411023, 0.06857585667499475, 0.01997173680657787, 0.028756178383316313, 0.02655801669295345, 0.08036494800554854, 0.011699079419486225, 0.027964322927540967, 0.06095068369592939, 0.01678285970618682, 0.05038504867947527, 0.04904487416414278, 0.05222426534497312, 0.03144136197598917, 0.011454745744621115, 0.07013256528547832, 0.02882100561899798, 0.011210612237586506, 0.037131726276129484, 0.014597837846460087, 0.01669937275749232, 0.04912762150966695, 0.036954397934355905, 0.013807654979505708, 0.04656072014144488, 0.04364017989220364, 0.10156322337154831, 0.02194955782033503, 0.062486493427838595, 0.09286732213305575, 0.005674697350644107, 0.10693286452442408, 0.028932102157601287, 0.0369978784583509, 0.07201727772397654, 0.05488968999790294, 0.05237949040851422, 0.02211547320309494, 0.0321503157195236, 0.05109575643603291, 0.027190742116155367, 0.02505315324690725, 0.06383293082139321, 0.06881417852959462, 0.033590156851070266, 0.07115266804716416, 0.07508524666939463, 0.030367369963122264, 0.07442482175039393, 0.035543285975498815, 0.016948086375902807, 0.03132606191294534, 0.04428854385124786, 0.04759197123348713, 0.043970938572393994, 0.0870473508590034, 0.009737558513214546, 0.037224492191204, 0.02067497219624264, 0.07534776508275952, 0.028749559274209396, 0.07304847453321729, 0.04810312184106026, 0.04190867387556604, 0.053412380162626505, 0.022424143872090747, 0.03191780551735844, 0.03252712317875453, 0.04211071785539389, 0.038942451256194284, 0.049491662332522016, 0.015549741053421582, 0.0779797684933458, 0.1210864061223609, 0.018336777841406207, 0.045660127752593586, 0.03161366915862475, 0.009082376973570457, 0.023198557585211735, 0.03341735773054617, 0.03723148110189608, 0.041382049276892624, 0.030529383769524947, 0.01912183776896979, 0.10100003252071993, 0.061410737223923206, 0.02370779133135719, 0.048612908593245914, 0.02763009862974286, 0.02919749077409506, 0.0187982240625258, 0.030189695568489175, 0.02691296853923372, 0.005900063003147287, 0.006143615514572177, 0.0533641363228006, 0.005221232397681368, 0.019437909558681504, 0.0378094606234559, 0.043490417035562653, 0.02695185538115246, 0.016394230470593487, 0.04306575928681663, 0.033146506907152276, 0.028147352659808736, 0.012551788440240281, 0.020141609744834046, 0.04190654666828258, 0.013016363555964614, 0.09653913296226944, 0.025228534193177308, 0.042003930014158995, 0.01318894130443888, 0.012268033577129245, 0.04401898563706449, 0.03563840301441295, 0.08149811505739178, 0.12918195314705372, 0.19423571095934936, 0.20403823495975562, 0.10911699411060129, 0.12242082666073527, 0.17290562338062695, 0.1471597384661436, 0.12794301605650357, 0.09097487439534493, 0.1050481792273266, 0.08974735026380845, 0.10713943094015121, 0.16324616170355252, 0.09173068776726723, 0.1944890623646123, 0.18753585618521484, 0.11246135072516543, 0.11063807963260583, 0.10952663248670952, 0.141353039337056, 0.12877423502504826, 0.1193205187363284, 0.06305702602756874, 0.16040448418685369, 0.1402260876659836, 0.12855292404336588, 0.11119699571281672, 0.11757220540727888, 0.1114468119506325, 0.1330122154738222, 0.08785728418401309, 0.06571395202939, 0.19966818445495196, 0.13930539706987993, 0.13170532988650457, 0.09046089768941913, 0.14313439732151373, 0.14882054791918822, 0.10008465485381228, 0.06616922867085252, 0.11186217037694794, 0.17018758851502622, 0.13468027168086597, 0.1899271085858345, 0.2043833378702402, 0.09209242157105889, 0.08975282604140894, 0.13865416630038194, 0.14780224327530178, 0.1637802773288318, 0.15634417134736264, 0.1476291897041457, 0.14599820865052088, 0.10407351795583963, 0.22606485230582102, 0.1313263409371887, 0.1374611524598939, 0.21359708346426487, 0.11849592226956572, 0.06336799184126513, 0.18632833526602813, 0.09325194292302642, 0.11189916410616466, 0.12440636940300465, 0.11825623655957834, 0.07056806263114725, 0.14392748262201036, 0.16063852448548588, 0.10845253190823964, 0.1273145976343325, 0.24364384902375086, 0.1381051500460931, 0.13964195043912955, 0.16274625781391347, 0.33871279337576454, 0.12329036928713322, 0.14368220578346932, 0.09162450382219893, 0.11967031710914203, 0.0857422701748354, 0.12702627453420842, 0.12490198495132582, 0.15526962972113065, 0.19256525273833955, 0.07622350273387772, 0.20564269886485168, 0.07367548838789974, 0.181032871561391, 0.16030661229576382, 0.13837010440017494, 0.1664961680237736, 0.1178062864180122, 0.10423388970749718, 0.17453520665211336, 0.14785215631127357, 0.08730045799165964, 0.28390632569789886, 0.1480856402111905, 0.17457403242588043, 0.09429987240582705, 0.11841550229915551, 0.19779582135379314, 0.13933601256992134, 0.15945384305502686, 0.11398635139422757, 0.20227749086916447, 0.13110139300780638, 0.1351894579295601, 0.1411857261721577, 0.10460057681692497, 0.12575984320470265, 0.19439451529511384, 0.1257777972412961, 0.1832218798143523, 0.08489410818687507, 0.09583435899444989, 0.21146500429936818, 0.12147561380905764, 0.14772585380290235, 0.1272091804338353, 0.12986645927386625, 0.16286103879766806, 0.07738655246794224, 0.12637764933918202, 0.11125732426132474, 0.0865780556840556, 0.0652804970741272, 0.24139724671840668, 0.10132002963551454, 0.13788016140460968, 0.08958302943834237, 0.10307043963777167, 0.1493514608591795, 0.11062125196414334, 0.13612186004008564, 0.05019721322293792, 0.0854194164276123, 0.1504577307828835, 0.1162486414292029, 0.10918592648314578, 0.2109254061111382, 0.16045510289924486, 0.09369577267872435, 0.1818777969373124, 0.18807644503457205, 0.10448435733893088, 0.11280035360583238, 0.08184791343020541, 0.08397247442709548, 0.10222265762942177, 0.17626627162098885, 0.1064870466611215, 0.08139655872115067, 0.1127633395205651, 0.22862629485981806, 0.10497815441340208, 0.1103368236550263, 0.10747075280440704, 0.1225192549505404, 0.05283634125122002, 0.10817825448300157, 0.12799569751535142, 0.21982659133417265, 0.07677235613976206, 0.11612255605203764, 0.09031359452222075, 0.1376588504229273, 0.07624307846916573, 0.18010690196284226, 0.21180077056799615, 0.15029049904218741, 0.10943895219159977, 0.08048331165420157, 0.14859707919614656, 0.09692308200257164], [0.011339943556647216, 0.048007889451192956, 0.0425155963083463, 0.030519863923213313, 0.004484147864526936, 0.052317872643470764, 0.07861102319189481, 0.027390358636954, 0.037599603312888315, 0.008139985131232865, 0.059749296733311245, 0.024592992849648, 0.04778976079874805, 0.03694777882524899, 0.02374636604716735, 0.04043403746826308, 0.024064663431740234, 0.07016097554670912, 0.030416841951331923, 0.03556099234681044, 0.018505573605320284, 0.044841234372662644, 0.02680830281626965, 0.03855647678886141, 0.031251277175865004, 0.010652543477980154, 0.04147771932184696, 0.036677637070949586, 0.010005475520821554, 0.014157360053754278, 0.032967122604272196, 0.04862446743728859, 0.06907259180609669, 0.03562245065612452, 0.028055441698857715, 0.04037470975890756, 0.037069413012691906, 0.04535541124641895, 0.02573861101908343, 0.0357832125654178, 0.03169028933293053, 0.03352992669013994, 0.03910892303766949, 0.04538800467603973, 0.046810485489134274, 0.06005473927195583, 0.03016702232084104, 0.020474456616544297, 0.026200411774750267, 0.04267711817686047, 0.03239946360034602, 0.024598590763551847, 0.01892975129054061, 0.0326028476868357, 0.015687648206949234, 0.03272630374080368, 0.05490098760596343, 0.022245382125090276, 0.040280383213290145, 0.007303895129423056, 0.062033883428999355, 0.039882904184716086, 0.01637482606539769, 0.011012447781727781, 0.03257835257266249, 0.009404772709655975, 0.0377922394046826, 0.02313924683923168, 0.007208593189716339, 0.03521547552996448, 0.05224153406119772, 0.02854673158643501, 0.0684805428609252, 0.06127372743295772, 0.01563660371383386, 0.022809107322245836, 0.01792672386259905, 0.0692883591566767, 0.019307289871254137, 0.02020640475010233, 0.012478510899070119, 0.03161647490092686, 0.016629351336242895, 0.04153378327776279, 0.03183908188449485, 0.028100041805633476, 0.03381571885464447, 0.027469148426981907, 0.023116344586014748, 0.006366783985868096, 0.03163845943553107, 0.012682796588965824, 0.07035700431359665, 0.020903816612969552, 0.04223554455009954, 0.023659311700612307, 0.033849275803991725, 0.020301940784390484, 0.021504586429468224, 0.04890381691179105, 0.022231409392718757, 0.0319651163715337, 0.010877442213573625, 0.02019770084215062, 0.03405469210286226, 0.09002494572528771, 0.03629440727776714, 0.057748181612363884, 0.03731188750160592, 0.04329367241423045, 0.06493099047137157, 0.028002237768045495, 0.03653930413669773, 0.04766858462244272, 0.01941686649141567, 0.0362044165709189, 0.028714757213102918, 0.06297239235469274, 0.006637311232874968, 0.042784336887832196, 0.054065297091645856, 0.03640483206670199, 0.0048965215849291, 0.031492319955889664, 0.03620595684541123, 0.028840971511921713, 0.030545556651694433, 0.028173725619646053, 0.008090678535934006, 0.06598035844841174, 0.019072269089519978, 0.04684869379603437, 0.001419086123600469, 0.05541426202814494, 0.05114504861246262, 0.1104395402861493, 0.02437242995282369, 0.02662692531677229, 0.04593692593542593, 0.018263419724202583, 0.04205169209412166, 0.04752793109842709, 0.04186103053923164, 0.025638347292052846, 0.049213890451937914, 0.07955601212701627, 0.026033051112400632, 0.03361570708719747, 0.11464470678142138, 0.0020511223036529763, 0.027946755655908158, 0.01456674567556807, 0.06687907129526138, 0.0046425251473140505, 0.028472944295832088, 0.04435096228761332, 0.01430830016865262, 0.041395318029182296, 0.05772488750517368, 0.014484615796910865, 0.07268009108624288, 0.037042736408433745, 0.03714408579149416, 0.0314460167262171, 0.02110262737343354, 0.019594545975061398, 0.052639287896454334, 0.06429177655705384, 0.029962413478642702, 0.016566676752907888, 0.02823199820704758, 0.011568403752919818, 0.026093043786074435, 0.023952046974695156, 0.020182542369834015, 0.04722164039100919, 0.07422644525234189, 0.046694452608270307, 0.07249840654964958, 0.02479017003705459, 0.03755045702148761, 0.027999014726706913, 0.03317163984424301, 0.01772210653871298, 0.07043154817074537, 0.006980839518031904, 0.08847425572041955, 0.025261397340468, 0.03838751478386777, 0.012304700761368232, 0.02495227035667215, 0.044603499450853894, 0.10391608426081282, 0.02460366959816643, 0.04183160926082304, 0.025372466737670556, 0.025718000517891984, 0.080368238900389, 0.04976360559729593, 0.016688997957057188, 0.05006444427583899, 0.015043899982369371, 0.10295970272272825, 0.02624820438878877, 0.09856301971844264, 0.019467391905241778, 0.03773278616634863, 0.06520316443805184, 0.036799651238002946, 0.04082923322649939, 0.02731025418532746, 0.04587537941655942, 0.05370112056178706, 0.05184579208227141, 0.040720684586891105, 0.03294657656390752, 0.04837133316323161, 0.02162555734893041, 0.0471074259839952, 0.020565760288653628, 0.050843738352081606, 0.13176904432475567, 0.03140770663906421, 0.03008261595719627, 0.008349034985128258, 0.03225379230986748, 0.02130092753629599, 0.028833646726395403, 0.010612908551203353, 0.048032957927456925, 0.004340566885990224, 0.03777718271261879, 0.06067409246627774, 0.04529915051534772, 0.04954924959955471, 0.03160341310181788, 0.015240749776629465, 0.040373848019433875, 0.035606104747525284, 0.014290380058810115, 0.03898134149078812, 0.03493108454027346, 0.03460828507585185, 0.030714074216250862, 0.004186893123135502, 0.028663928154855967, 0.03221119048872164, 0.018387164155553495, 0.07580543016748768, 0.031522894743829966, 0.005191711883526295, 0.009862095134199729, 0.013223099605446416, 0.017752888279833963, 0.02385868564514177, 0.06363235586988074, 0.04421097033524087, 0.0027985748518923564, 0.026856796017714908, 0.032867686689964364, 0.0245219536258706, 0.028343442494847944, 0.00505058084049129, 0.012039842250357782, 0.04426833029304232, 0.01929558683852, 0.10310872258352381, 0.032420464259173186, 0.030405856469380002, 0.05662519597847547, 0.04116432435278382, 0.04860826741371836, 0.022980707132124474, 0.02472677281392472, 0.054322974157652686, 0.020311233321470872, 0.04444427103070276, 0.02726484153286687, 0.04339201927983335, 0.025152813077771237, 0.025597718311473727, 0.07448870582239968, 0.0606091973770942, 0.03785478337002652, 0.05503055726044944, 0.06945430168083735, 0.011583444329776933, 0.044600541038172584, 0.0299188379597451, 0.03976095108581441, 0.02960114786401391, 0.028512214510036365, 0.010764302436395414, 0.03613007627427578, 0.026815656439534256, 0.024822115465732555, 0.06469124369323254, 0.035198970165635855, 0.04065729923812406, 0.020505438525495783, 0.026779449810939174, 0.008521298062987626, 0.03154437376984528, 0.06309975337769304, 0.035070452240428755, 0.034733322116413286, 0.014168181839132947, 0.07082669982420546, 0.07024637596415621, 0.022191450465470552, 0.010663526415425752, 0.029243237605052333, 0.008073282594393407, 0.0748057309538126, 0.05086565503318395, 0.03383143711835146, 0.011369255421284055, 0.04948305172313537, 0.043591681601745744, 0.01957373191336436, 0.04146108503586479, 0.04497623569997294, 0.00525935079869149, 0.05288528058944004, 0.09329359140247107, 0.0272981864400208, 0.05422570277005434, 0.016612028337216804, 0.051501605194061995, 0.034346899815968106, 0.029200069207165922, 0.03743722649025066, 0.01672224447663341, 0.03863846078248961, 0.040014197318149466, 0.03692329388910106, 0.043347656660314114, 0.04048870364204049, 0.013128379509518189, 0.024955244036391377, 0.05113511146711452, 0.015754673896091323, 0.006398152235695826, 0.09245087126536028, 0.03248074870290501, 0.012312854207786066, 0.01742046040349773, 0.008854591071472635, 0.050483670351760726, 0.04039036695446287, 0.04940904390865138, 0.048600864596664906, 0.17644251430673258, 0.09428889370922532, 0.15131983666547708, 0.09160093151565109, 0.0851686027433191, 0.28663457930088043, 0.12618574606520788, 0.1430513717766319, 0.11514280576791082, 0.08924193666981799, 0.1175244501126664, 0.1642277440322297, 0.1340345506157194, 0.12070245029670851, 0.08867227259491171, 0.16781503653952054, 0.11483739715601717, 0.13571331410535745, 0.2260576734053237, 0.09092939897839512, 0.03692002335031118, 0.15259571320244245, 0.10455856192857027, 0.11189832272274153, 0.2797316254249641, 0.11459628652249064, 0.12119330252919878, 0.08005755807140044, 0.11960114724934101, 0.13257690811795847, 0.12189626480851855, 0.17801610486848013, 0.18587917222508363, 0.055418601259589195, 0.10378616516079221, 0.10389680029558283, 0.12305205421788351, 0.10293782675372702, 0.09891344912882362, 0.14985322393476963, 0.09226543443011385, 0.11578673550060817, 0.13319886688675198, 0.27758243360689705, 0.16771061000015053, 0.18659004622272082, 0.15261901409498282, 0.12799406903130667, 0.09604964458516665, 0.12129935755261353, 0.08172373473644257, 0.06941873966050999, 0.17524120876831667, 0.21291419225079672, 0.09583199769258499, 0.1571865590023143, 0.1349395534821919, 0.10244155302643776, 0.11429193642522607, 0.16067209839820862, 0.16325347631105355, 0.17668389635426657, 0.11949931271374226, 0.0921005504205823, 0.14850179930882795, 0.13561761352632726, 0.0724343324878386, 0.12421802165252821, 0.15823587269655295, 0.12678528603698525, 0.11513371339866094, 0.10180843914193766, 0.15431556877280983, 0.19912367367318698, 0.07988225854933262, 0.08499314715819699, 0.13908184692263603, 0.17243235877582005, 0.08616771163152796, 0.1340929317687239, 0.19040073959955148, 0.09781312317188297, 0.14561622057642254, 0.14930757321417332, 0.13907962132777485, 0.12147858579243932, 0.11400567607155868, 0.12528049892612866, 0.09254295525274106, 0.0485914261745555, 0.31198814883828163, 0.204029807554824, 0.1838645339012146, 0.1661201917699405, 0.0797667990305594, 0.20699007942208222, 0.2530264955546175, 0.16723929957619735, 0.17529935921941484, 0.1347061102943761, 0.12844431772828102, 0.1190860170338835, 0.10031623885567699, 0.13321059197187424, 0.20006462532494748, 0.12706476104046616, 0.14773821671094212, 0.20052364069436276, 0.0997286546709282, 0.15745947935751506, 0.13127777140055383, 0.11375649765666042, 0.07995402719825506, 0.11516654092286314, 0.1584741199123008, 0.10751171596348286, 0.07491659000515938, 0.2500913701951504, 0.07210820820182562, 0.1289987758334194, 0.1462847539888961, 0.11603513360023499, 0.11010683421045542, 0.09432877121227128, 0.10499366572392838, 0.08072837814688683, 0.19238550881189959, 0.12457290903798171, 0.12796129578990595, 0.13897505908140115, 0.14243121791098798, 0.19654616340994835, 0.17626365247581685, 0.11885916920644896, 0.11326472940189497, 0.11868196300097875, 0.12556012320731366, 0.1250557138451508, 0.17996603809297085, 0.10684698234711375, 0.20536072685250215, 0.10635634046047926, 0.09022320008703641, 0.10649054790181772, 0.1683100006942238, 0.13282328418322972, 0.08320051192172936, 0.10112480832529919, 0.16287266888788768, 0.0834294699930719, 0.156483868137002, 0.06383891550025769, 0.10933673089104039, 0.0654263821031366, 0.07632214815488883, 0.1368454633546727, 0.1164377084267991, 0.06790695685361113, 0.21271828562021255, 0.14327526119138512, 0.11113172064402274, 0.1444822528532573, 0.07534604160381214, 0.11504316968577248, 0.14331528118678502, 0.09557889055992876, 0.10195477878940956, 0.1466469152697495, 0.15680558873074396, 0.172492721251079, 0.09643304401210376, 0.12534281558224133, 0.13440024027866976, 0.091225355597479, 0.10331470545913492, 0.1452942014272724], [0.02556757439327027, 0.05285915359854698, 0.05226340663752385, 0.029852178679513078, 0.04571912297978997, 0.03939093236944505, 0.07093390157180172, 0.025416686864835874, 0.005099830184397953, 0.07470660377293825, 0.04259427244375859, 0.014942382661891835, 0.04188630936135139, 0.013561906559126717, 0.01879813246029828, 0.03590522673247116, 0.02035011168170188, 0.09938173328659364, 0.04108085776013987, 0.029748752979295592, 0.08465397464377539, 0.05704294624073165, 0.0086003304292847, 0.021836613970143453, 0.014189889022548283, 0.04693737493029662, 0.01116230308876506, 0.06692969679300274, 0.06242995789008481, 0.016081132360601, 0.04470670123451522, 0.02924798395750778, 0.019405122746580412, 0.03668136562087706, 0.01194698388488697, 0.03249906575573342, 0.0338546124819134, 0.01856937455678625, 0.03679213306999632, 0.005396995019899415, 0.035766873442168744, 0.020046487616907274, 0.05194378610966461, 0.013135842546554548, 0.06393465679138899, 0.022957443559010113, 0.02714880695566535, 0.04029423550569585, 0.04977852658235601, 0.01639860193245113, 0.03820045624992677, 0.031027306336909533, 0.04294609624360289, 0.03808149888313242, 0.06711634142058236, 0.03545009258336254, 0.06652273863021817, 0.028424746257119944, 0.019260850934577838, 0.07546591838555676, 0.007907694604779993, 0.024757194931485822, 0.012208721982980413, 0.022402391735730425, 0.02952364898685898, 0.01619158429093659, 0.03326119628867932, 0.00876953246604119, 0.05983794054814747, 0.016727101091029387, 0.044745191133448055, 0.06530684458890132, 0.02219092968984374, 0.057767655567399094, 0.036382114714277644, 0.00675473765503349, 0.03275538914437805, 0.043238741611795764, 0.0313419973078583, 0.03406651218288711, 0.043055058789572546, 0.036119823610144, 0.0499632780972336, 0.02461440402216145, 0.00644645926409534, 0.0520332509518734, 0.010747922601045241, 0.05343172519600817, 0.04675467937652554, 0.01188141365335988, 0.04848936093705041, 0.011247075013151126, 0.04211172887257167, 0.0410277793583061, 0.045066999936742444, 0.016449912750561322, 0.033341310918331146, 0.06470091960259847, 0.03901566518470645, 0.02214922183858497, 0.025719305001465336, 0.0038041925872676075, 0.03474283178469964, 0.003494435202030997, 0.07114381316517081, 0.06338946068925516, 0.09587981405534915, 0.022635137728814567, 0.00651710620981508, 0.058655667917004654, 0.05376684007101825, 0.015417323248194796, 0.02046724548563361, 0.02759136276186577, 0.015976883936673403, 0.020337324689275453, 0.009898730088025331, 0.040931050798722675, 0.03453302875693355, 0.04932749078476003, 0.024330364174342582, 0.019349757681733797, 0.013348821118207914, 0.029269127108688866, 0.05842567847243377, 0.008191537677443453, 0.020107124898848788, 0.06464918130742651, 0.008880201527582747, 0.017870547948405147, 0.013826083142443426, 0.039893088995346, 0.015532752232892173, 0.04126931746889438, 0.025226953206583858, 0.03975244564935565, 0.015415542093770844, 0.045700103643217256, 0.059506191206829886, 0.014224635952684497, 0.04894822702876159, 0.030932803372187272, 0.009549672166550798, 0.042263557868344445, 0.02719932558414127, 0.0056918820981601516, 0.03544806037098169, 0.06503789366355964, 0.013494568743876048, 0.02298723633534142, 0.044112274024103365, 0.05309564680127161, 0.019027970930827514, 0.041138031120811186, 0.025110591236235838, 0.028070476338533417, 0.03390224903289761, 0.04354585334658623, 0.023920033692515323, 0.023944048743162836, 0.01506442905935858, 0.05117368618292468, 0.013196987881591278, 0.01470930249031101, 0.048443498755139966, 0.06690334927822862, 0.04535196089584913, 0.016683625656047037, 0.022690187274877514, 0.0049264848431838405, 0.053236676912222586, 0.02434413504254605, 0.031110881495156457, 0.004686018393840641, 0.037808005165840895, 0.06709981230752808, 0.04013344306232674, 0.05285400691043053, 0.0381868380521025, 0.019805712858214974, 0.0037265134742483497, 0.026308459994782294, 0.0727999678679875, 0.04609036984454308, 0.0074157694387914875, 0.005332273805314409, 0.009163427133379238, 0.030162228470934287, 0.03698131202587059, 0.03183716502306717, 0.022172604155327593, 0.0758335350879601, 0.016053275105410388, 0.04176440375990101, 0.07120412814297847, 0.09258444766913142, 0.021678038639947772, 0.04652925307995506, 0.023947007155844142, 0.03578544155295406, 0.015711228995184814, 0.029358653019049337, 0.054711845969515185, 0.06650878795023475, 0.024505960555481057, 0.058092253149620125, 0.044743827278060574, 0.037746889516711235, 0.007899786279137646, 0.022231565455773046, 0.02309545249279056, 0.028594815970531533, 0.01673249205175255, 0.04539903426276786, 0.050828562916389534, 0.025416798823113953, 0.053942926693707705, 0.02276259713939258, 0.053914977836289575, 0.05763013008981943, 0.04091491523597922, 0.019686931910525476, 0.010136483669547098, 0.02274723001755774, 0.02236222755163908, 0.036075627231704335, 0.01165436311358852, 0.014387240932722176, 0.02772126829118601, 0.06936561715390001, 0.0710320652329496, 0.08052557760051318, 0.013023489869997969, 0.03150116126718266, 0.03133150715646999, 0.020292229251936078, 0.05480941591252174, 0.038195404556712935, 0.018601401409666454, 0.02503760122427983, 0.014732247151966606, 0.03564989400495376, 0.02961499337106943, 0.0912627564477069, 0.04591463945273842, 0.02275901277815657, 0.006146359764638224, 0.07552432667996202, 0.05148692508893354, 0.05204830425126212, 0.044464169070124626, 0.04014234544177141, 0.033981590132628164, 0.026730049068906477, 0.04643999179825187, 0.06030763605875628, 0.05838682555726596, 0.012853148742578924, 0.025705676625615785, 0.014004655747807451, 0.07316674318696771, 0.06263520116252558, 0.03580197745135852, 0.02674887502299888, 0.04084601339751056, 0.04484628267320139, 0.014383129010509168, 0.07870673734162535, 0.046743517475468774, 0.010612893284165432, 0.02609864339631583, 0.01513063202479056, 0.022207419787134444, 0.058470448212964196, 0.02182464800508959, 0.04864732728206685, 0.021721222304872105, 0.055999223675046644, 0.00253925339867627, 0.04292461721758757, 0.06226184405386448, 0.03639746317639947, 0.060368812776037624, 0.019482029601931572, 0.03950859034167869, 0.06588252048407282, 0.021145422577059696, 0.026126088441482613, 0.017016939020582607, 0.01607447593206806, 0.03192393608125193, 0.009116214666781681, 0.02093815727026335, 0.04575700558988111, 0.029488015720354657, 0.0231156660509961, 0.08912949663187776, 0.02618653403728136, 0.04515977602984224, 0.03125282084303243, 0.05461840830477221, 0.01287993391244007, 0.024950075295886824, 0.024474474834278226, 0.025553401493068253, 0.06293408905289002, 0.02618065453134477, 0.07341469345348221, 0.024532800008143698, 0.017832119117623994, 0.0058993004994200805, 0.046215013334793706, 0.018229267360376458, 0.029880731433097805, 0.0365498146441366, 0.043191922695509026, 0.06642119586467743, 0.05945378116198948, 0.04261812634233918, 0.026009667099320462, 0.03515658547569599, 0.031928326202822585, 0.022467753317739283, 0.04486616374924779, 0.04566773413015263, 0.021014248187254583, 0.03433300341878619, 0.014700791964839612, 0.029358914255031517, 0.054720096955341954, 0.020319699742166058, 0.022589599547375525, 0.015855746776131645, 0.044794856504138024, 0.08122607001236506, 0.025149288088349358, 0.015790749906695316, 0.01887703251226672, 0.034817056730389595, 0.05001679076147931, 0.03194236169968333, 0.036054392478295734, 0.04817099230630057, 0.025684384196730595, 0.01140638061666063, 0.0723044608852693, 0.02397138691906418, 0.03944760700687766, 0.007314804276185376, 0.015281314296381814, 0.03317489002698234, 0.06737045957041637, 0.12353551041867052, 0.17165630470429147, 0.08486804565680878, 0.09516407496162824, 0.06569315493106842, 0.06736892608127423, 0.2090262815888439, 0.09193736274859735, 0.12613946997693606, 0.16622209415904113, 0.09473634005657264, 0.15033157755221638, 0.13593727137361253, 0.060485296882689, 0.1217631498085601, 0.1254644226282835, 0.13173469688211167, 0.1576673417751278, 0.160320372985942, 0.1672915332019329, 0.13388417368488653, 0.16089032883090632, 0.10903030447661877, 0.18498368241957255, 0.1065823333337903, 0.13196119187133654, 0.17558933794498444, 0.18417621217668056, 0.1471682201538767, 0.10789355475987707, 0.18030697479844093, 0.14239875679569586, 0.04676456902442234, 0.11213230195322207, 0.07817336810486657, 0.08530021818088633, 0.07127461436071567, 0.11788422295025416, 0.10161215931709323, 0.09305851294526032, 0.18221477099827357, 0.10277619971228497, 0.14223183718110832, 0.12174222378858499, 0.2084733841142484, 0.10425609815865755, 0.07008547495518412, 0.12227950138705117, 0.1566977830869811, 0.08935606625995465, 0.10170670638659171, 0.11791705047445637, 0.08839553887290613, 0.20861462796373026, 0.1490109855575221, 0.1749549891267504, 0.1556161982672555, 0.09084388999534504, 0.09814452646034104, 0.26481064036488533, 0.18413959842707428, 0.08453335147351027, 0.10056633329285042, 0.07266664252217327, 0.09935242735913821, 0.12164725602737494, 0.1293639905218567, 0.21512100526264735, 0.1652420453195061, 0.1018900533339807, 0.08251979880567108, 0.16349027146186146, 0.13559533043631486, 0.11877281883997576, 0.14361030821289333, 0.08969093007700783, 0.08910751888262373, 0.09222681221685239, 0.12936462834477425, 0.13009473202483995, 0.1617171373218298, 0.1095521996862122, 0.14537188011620725, 0.06492750958672591, 0.16341924241610936, 0.11561890664909567, 0.08493347678865705, 0.14040786719747952, 0.12524996485028947, 0.12237058792795454, 0.17450847237237863, 0.0885004810988903, 0.14869151770004205, 0.09874462283083371, 0.15195915236004762, 0.07230020647070237, 0.13849602692893573, 0.1716163254209927, 0.09162118578595774, 0.1335187554359436, 0.1467720778392894, 0.0905399334483913, 0.0784059427678585, 0.06225430552980729, 0.16937156873089926, 0.11450754771275179, 0.24071689322590828, 0.1070035882294178, 0.06457001662680081, 0.17320259101688862, 0.1316806583532265, 0.14542826637625694, 0.11972507488514696, 0.09589729311742953, 0.10583209073437111, 0.12259953921394688, 0.10332824223275695, 0.11831587978771754, 0.10396331708346095, 0.106398538553289, 0.1291125797267471, 0.1306879073381424, 0.183786719505276, 0.11166874718453203, 0.14335773033755167, 0.10198363688375268, 0.07672746426292829, 0.22852926435215132, 0.08872181243662323, 0.1270304543099233, 0.09101695035185133, 0.10685351663934332, 0.142985553879823, 0.0665140398112791, 0.13138317503035069, 0.1844284100724118, 0.09900737194610493, 0.14645601622760296, 0.10674808586814574, 0.09290357625910214, 0.17276279175920145, 0.14064550373171056, 0.17068929730781487, 0.08173136147005217, 0.12523517278688295, 0.08402240781911782, 0.09768366547567503, 0.1363612607653652, 0.09025090467184782, 0.06232203011001859, 0.17659295909106731, 0.11948291930769171, 0.10064424268369164, 0.1601073265607868, 0.09642923064529896, 0.07106059084513358, 0.1643693542906216, 0.15774113924375602, 0.15072795056871005, 0.10833727594997201, 0.19920371366398676, 0.19171000005943434, 0.1237023893211569, 0.10092565151197569, 0.10589593409427575, 0.10011071059852839, 0.09257268187190805, 0.09001957172794, 0.09028456000877277, 0.12383459508419037, 0.1256973637001855, 0.15276020366166318, 0.08216350685272898, 0.07762684885944639, 0.12158519721456937, 0.12924276345542499], [0.04535729078842061, 0.04857786225953272, 0.02389348770624825, 0.021429852582514286, 0.046958368803773604, 0.035589602775871754, 0.037661336428884945, 0.023637154139578342, 0.06533373493169035, 0.045687177551112006, 0.02150459830383105, 0.01825082950693156, 0.030889119287686687, 0.04006663111171552, 0.02017631341836282, 0.0615710886195302, 0.03337102396679776, 0.013380147383681365, 0.01784586114808917, 0.06009400609348502, 0.053158872694309266, 0.027620532982317463, 0.04376447393691965, 0.05003666165950043, 0.019993385466347848, 0.07822082484407084, 0.033183958647506576, 0.03663544915616512, 0.042533268752907, 0.02255438357990767, 0.03871131848011698, 0.00600396325379344, 0.03484111079680068, 0.05464682874402829, 0.011352310705530857, 0.01933660258405975, 0.04122909730566399, 0.04213322146928736, 0.03513070275740964, 0.011309432381364917, 0.02733954314940742, 0.011368453053624501, 0.03954631010336535, 0.026145053495253836, 0.027479094054017748, 0.024256580276414752, 0.027943288341962864, 0.07493890702192273, 0.05471699605030673, 0.03500287015257137, 0.009053389109405023, 0.024160079026062573, 0.03475226342145886, 0.016166525992697904, 0.046415740956685374, 0.0036441664643851773, 0.015772767032363584, 0.011339350686674672, 0.01223088039218315, 0.04323600033032043, 0.049327524711510966, 0.049870152558599196, 0.019868952321953008, 0.08364191252206053, 0.01719623850658536, 0.04887136936719928, 0.03080048904355083, 0.03806714108213782, 0.03253925199221287, 0.04319337136777384, 0.03631112977330174, 0.015841144702530334, 0.06385376184646573, 0.06313380226492882, 0.02062324238275843, 0.043557856631066115, 0.03403024109346526, 0.026529499562457204, 0.03615136531048587, 0.02558050218171307, 0.01218710046461118, 0.00776614117369588, 0.013221534734059657, 0.02559096858437572, 0.01977646121356104, 0.024406695971265435, 0.031524560547300746, 0.030308069395167486, 0.0364334933858897, 0.034134338543351204, 0.017405103459688168, 0.031145330718053237, 0.040870569579835446, 0.04467942751944065, 0.04143313957112176, 0.03666742851159402, 0.013462434173561633, 0.007287350749330861, 0.03146287492875542, 0.03168362272637231, 0.11241953939731632, 0.02823309743377779, 0.045989732923252244, 0.03315216249653271, 0.0483759539867086, 0.02849967179021665, 0.061851764629994116, 0.006296765957293766, 0.04164293581353767, 0.008882778264316065, 0.06772206284637962, 0.009530132902520043, 0.02525593852624297, 0.051017731694238524, 0.027241979991751056, 0.0636659162119031, 0.017438719780849557, 0.01248417072929442, 0.053054300269910266, 0.027066576993092895, 0.022741696564480662, 0.0614159619435668, 0.014067013964190014, 0.04041451940845166, 0.0317166605964303, 0.04887881289635386, 0.023900066103254045, 0.03507061508883323, 0.01830997401183205, 0.024155378474720886, 0.0023811136031456825, 0.06213405555380242, 0.03126867142106805, 0.043257845765245814, 0.010601218241000814, 0.07154245927397694, 0.01220111221274627, 0.03289192396083048, 0.05358203427333917, 0.02501573204062879, 0.04630139423534274, 0.036907592588769536, 0.03837292628096683, 0.0573050303916846, 0.014179241959936917, 0.0330609470339758, 0.07965408757861171, 0.03065853612497449, 0.044708034555826864, 0.018956154784453765, 0.022812778196696724, 0.00220196254667826, 0.012883055173525853, 0.0651926878573639, 0.0227622341231576, 0.03997580919946943, 0.01168301425475095, 0.008438995157900666, 0.008218366952080811, 0.0443298394924828, 0.01401400171952056, 0.05537127683471356, 0.005143246247566172, 0.07944354494767529, 0.025097225792706013, 0.0260679837914982, 0.014341256614508373, 0.06145730508225305, 0.02514877918708537, 0.0673249162999647, 0.023305530327239206, 0.013770879229663737, 0.03950137412175536, 0.03286322871489184, 0.02860272429617388, 0.01582676145647253, 0.015002114099583455, 0.0452296312100121, 0.010124230175279081, 0.044937599916011095, 0.011642075692569571, 0.029673540765153508, 0.05411521691296782, 0.024420234441225017, 0.0654722171436463, 0.06959350313991308, 0.039944355708679984, 0.027387351030483842, 0.04152081647355642, 0.01914753558646355, 0.0264924261053758, 0.057786627406520505, 0.021880652589191283, 0.049405159295669625, 0.03695493058434554, 0.042676802658076794, 0.0013715344955146844, 0.07337338424154691, 0.0743339184139456, 0.00703850736109806, 0.03660503043127911, 0.018597669467063885, 0.02254276366771332, 0.02690599319924201, 0.050469115775610716, 0.04146413844344871, 0.029452284066272632, 0.019296058420357958, 0.07308023675744023, 0.05087269144132733, 0.00843091041315347, 0.00411611089449642, 0.03968551495511617, 0.07116328712020602, 0.0067337365721219355, 0.03707837646028825, 0.04004764909456883, 0.006700515921693295, 0.01857370021753013, 0.03303484718448349, 0.012940432094702763, 0.0027728978145335403, 0.03307322173246315, 0.033880071115813086, 0.06702613697520324, 0.04627144709229469, 0.012217215545076345, 0.019985478837043047, 0.008833581930957735, 0.025217431663934673, 0.0669820254136409, 0.05659612414560147, 0.037267338284956555, 0.029296071734279394, 0.038772552872874906, 0.08899896006499018, 0.03022293360637767, 0.05240814154967666, 0.018826564773917198, 0.0508193925156125, 0.07041786890476942, 0.05972191784530878, 0.054285987213786156, 0.0571777168661356, 0.028602520735668283, 0.09353127543415342, 0.021884642375100936, 0.016243951927338327, 0.004744425840077123, 0.030691862372415404, 0.016511343918474655, 0.030735454854688475, 0.018180723268804804, 0.08179108612239361, 0.02881987246551684, 0.024211929279512594, 0.009328619876344289, 0.07229734983827386, 0.03478408332115837, 0.011738931477468992, 0.06855512743017503, 0.007890707480588129, 0.05602127945582781, 0.034139285063637156, 0.05870516026126487, 0.07465848206941571, 0.02344792429357767, 0.05352396863911833, 0.02641894924454391, 0.030346376089645282, 0.05488345426108156, 0.056252357949103625, 0.03779804087909205, 0.02354631696029433, 0.0070841876108066314, 0.014654414096314992, 0.011747778725943394, 0.028255017507555227, 0.02892164254028882, 0.01953812748459833, 0.04129731043108872, 0.02919063757040671, 0.05910877324640751, 0.020092935035271303, 0.0537445773370564, 0.07746303693524428, 0.0396174748561212, 0.017576933971473148, 0.05146511697343417, 0.016529964615723917, 0.031864530340369256, 0.024117509435330118, 0.014035462933991636, 0.03583211458421179, 0.029860955529979298, 0.05934632157108613, 0.020041921076231768, 0.002461787176019113, 0.04518763667770794, 0.036946204624005725, 0.04988710575604013, 0.060391530128461976, 0.003196759768928002, 0.015087794412725737, 0.00444595397649599, 0.05850060909454312, 0.0289591044586684, 0.04721697546275599, 0.04838371642732194, 0.02413285450477685, 0.041567204520106316, 0.03341750700825027, 0.03307554910757712, 0.06183085896606956, 0.04112722884331431, 0.05147671313690288, 0.07932203968188592, 0.037519780453294516, 0.0544781449383923, 0.09216429878558431, 0.04017825012228318, 0.004741018322030348, 0.02905079150306327, 0.040872418587761264, 0.03946091647126845, 0.0242590162171317, 0.060204824432730675, 0.02376907322156642, 0.05600511335900851, 0.019591478996777108, 0.02138181060685643, 0.0207048871088773, 0.06208534352481365, 0.025322679230677228, 0.055270924898130555, 0.02580799292107778, 0.017641832453331778, 0.034660793508269956, 0.05048388069761651, 0.05339949478262237, 0.035975617955305746, 0.012956247049649912, 0.038380237495792766, 0.05292408261448145, 0.07631120338503804, 0.06410009719963584, 0.038574176374822855, 0.04511948801310999, 0.04693062011418598, 0.03701868912737284, 0.02271741009982569, 0.028350607824644873, 0.09442922832178217, 0.06876385837261166, 0.07383111717977694, 0.10906545937593494, 0.08744271285831928, 0.10967434956026928, 0.192684322063412, 0.0790199830329844, 0.15300807250397547, 0.12056762538850307, 0.0757916626919593, 0.1293751863496644, 0.18775875493884087, 0.09448351790862423, 0.1075790673494339, 0.16315968920077595, 0.11808445863425732, 0.10578510218432971, 0.06229995058051177, 0.08584366366267204, 0.14021025065864834, 0.1272198741457292, 0.230658941503082, 0.1967928244599274, 0.12971268966794014, 0.18533379291849478, 0.06595121536936079, 0.11936074229223387, 0.12214588427117892, 0.09362834665392127, 0.18992195171969278, 0.15403511667890207, 0.1766042092016765, 0.15650606980281218, 0.1482143040214266, 0.09749027621001005, 0.20435991484139646, 0.13292591939015047, 0.1266127210110426, 0.1561833449772426, 0.06242279934563807, 0.08448649863047258, 0.10557513630815915, 0.19267577252217702, 0.09215669919337545, 0.1429895708071334, 0.09278454764613084, 0.08158583606460265, 0.15132236081574643, 0.09958986033286367, 0.08192260656505823, 0.08375698527587311, 0.2106216802660908, 0.0874243788421154, 0.12184044851788453, 0.18257909002048628, 0.07219607848674059, 0.10118551006806747, 0.1525437781321151, 0.19366815712835106, 0.11821887642145157, 0.09711670197014298, 0.10085734339164835, 0.15554073160248144, 0.10766680871269532, 0.12486036361328193, 0.15897272101470403, 0.1554421540349722, 0.12415655995053904, 0.17387492422546658, 0.15925701361681732, 0.07691584594015564, 0.08070773032626935, 0.17846347657697542, 0.11891161996339049, 0.11241196694650821, 0.14906412842018263, 0.1332499198615551, 0.13681822695902415, 0.12171451241842338, 0.07141886412033013, 0.1497660321848733, 0.13295068591833115, 0.06442183136407818, 0.13346831314265728, 0.1302369393940483, 0.0960381773433515, 0.15882439325962747, 0.1474599494997944, 0.15709220192262105, 0.07106656195329768, 0.1092077074572444, 0.09239740949124098, 0.08864258668784585, 0.17292610156748975, 0.11839434557727405, 0.12787304552538054, 0.10782868681209427, 0.13168440386652946, 0.08022452518343925, 0.1904567051678896, 0.12441012848700796, 0.12474744181547846, 0.2331982638154711, 0.10665893315204553, 0.15067980172378675, 0.1232547326279538, 0.10670385217028004, 0.14268857267286095, 0.15688637511006423, 0.1405627088887351, 0.09773365993584905, 0.12606770811336382, 0.13330576329358987, 0.10088811495474406, 0.11181039136967488, 0.15903841677520955, 0.18630971626511642, 0.11015585836555276, 0.15188010303037508, 0.1452225481293031, 0.08015084306576423, 0.17955905278878553, 0.16286863838987692, 0.10895010163741452, 0.1375880249376808, 0.16672957049948828, 0.08642492390104703, 0.09687683305570058, 0.09597417113504239, 0.088893325733287, 0.16269200215382235, 0.13122628416333879, 0.10017037418271814, 0.09715594165027142, 0.18159978756947176, 0.09372309728392533, 0.1571897752583027, 0.11926643949534212, 0.10479746053793601, 0.20305106150252478, 0.12499631488961832, 0.1802346022533519, 0.17893119076532976, 0.09182708045201642, 0.0793520716418113, 0.24078241256730898, 0.13053154572844505, 0.13564312644302845, 0.09257372681583677, 0.1210408764226096, 0.06015741519097771, 0.11266943027398416, 0.1221438350954226, 0.12882663149918827, 0.13602641730436257, 0.15734897314437798, 0.11627262085676193, 0.1058678427445037, 0.13215902554137365, 0.16330988971250399, 0.10382031582828079, 0.08329545254153864, 0.14224170308027947, 0.14708964579871722, 0.16621244539107594, 0.14192442010555947, 0.21795182621904782, 0.1808973274060658, 0.19102568392242703, 0.10002217534929514, 0.11339145260197775, 0.08324714763356106, 0.08631660257066999, 0.059940053283103874, 0.11179267482033797], [0.037987447144197564, 0.0315073155798018, 0.03160647329475198, 0.018608785567006896, 0.05468617359708462, 0.023387336205425005, 0.021707531164533327, 0.04606532850967986, 0.05495599643992526, 0.012042439343141658, 0.03147098681490336, 0.019112156770591224, 0.03543315974197217, 0.027941956716988767, 0.019780832675418684, 0.009640736655066056, 0.0227126586583576, 0.03675314784049988, 0.04345239871846778, 0.027955284841092568, 0.04854479385539889, 0.018358818355149457, 0.009761944213615996, 0.01594599023727434, 0.030458704169307436, 0.06308661015438181, 0.011064784035884907, 0.046655480949474235, 0.01921090397185513, 0.04327428327607257, 0.004601959355308541, 0.031107750056045394, 0.06843362216438566, 0.048009684176317284, 0.05815855959164245, 0.02623892033339611, 0.03747999115980097, 0.05864559167197772, 0.008999610120164496, 0.04169294045173696, 0.02683050448207983, 0.03285066903169666, 0.04583641115043845, 0.03941087790631822, 0.02462092474369066, 0.02096409596768873, 0.036596857476979494, 0.018920933727973273, 0.01888209947251848, 0.018148757484076277, 0.08031209012759583, 0.0645221256251846, 0.02679053707314389, 0.020771960295470696, 0.046329529689891, 0.033193481886493306, 0.04257291555404663, 0.05222046554886869, 0.023731830130730356, 0.03068991158423679, 0.04661733710340091, 0.01353084746681686, 0.025314658946756805, 0.04663338106391685, 0.037074915931693146, 0.020711977799822177, 0.018331814357744794, 0.06771853446428265, 0.04145068648670401, 0.06354696223778383, 0.03988685665119972, 0.03389191494456359, 0.04944421237866793, 0.04097240750810929, 0.016349240206182003, 0.01396840246992984, 0.020912973443046212, 0.03596327540331653, 0.030504379754087756, 0.036237844598612616, 0.02266425027378968, 0.048596148778285296, 0.02413861357074763, 0.029691369272768497, 0.023027425964495966, 0.016422279411926866, 0.03333098700802241, 0.04932465450838208, 0.034681085098002634, 0.05153672616662724, 0.018028342963329384, 0.021509417598800998, 0.11503595007317406, 0.04824544795389686, 0.046607735832887034, 0.03729495466021555, 0.04456907058400767, 0.04187957150861621, 0.05737123505345412, 0.07411570155194827, 0.054587046416210275, 0.07812994864902326, 0.009607356124823647, 0.017485489503347447, 0.09722990875265428, 0.03025892310376678, 0.013664017597745572, 0.03834931326231786, 0.029407921446753398, 0.03061798008690987, 0.030239042027720382, 0.048473798736397705, 0.048940196566815884, 0.014528513619942325, 0.024624632937567573, 0.009666443802416325, 0.032949758893144984, 0.029755785994763886, 0.01856636186130345, 0.050865773776812215, 0.043677529852305136, 0.025169793416612914, 0.02493978531232902, 0.030710746001984392, 0.02758412279321679, 0.009293698223440774, 0.007062672961702836, 0.0511106231382915, 0.022382481821945736, 0.04002513190997498, 0.030527419410645962, 0.02702487083817167, 0.007186127743417663, 0.04832057874383671, 0.047321042378566096, 0.05692878272384405, 0.04317833163908549, 0.028836099630487815, 0.0501358261598008, 0.04912690565522228, 0.044667064611400874, 0.033347855388586006, 0.016265178199059198, 0.05457981323291149, 0.022517247358337045, 0.02296305843628943, 0.055297696497291327, 0.056598990956055265, 0.06940605784101145, 0.02322689999294068, 0.037058505562267134, 0.03191096927704556, 0.014265818787472588, 0.014903268510741847, 0.06363912086401667, 0.0239040304441005, 0.023915804723011594, 0.011619125093732561, 0.07445917597838811, 0.021375768252515366, 0.04885607518787895, 0.055267796851694584, 0.015570909649665867, 0.03736418898084334, 0.024855892938960875, 0.02395285103869225, 0.02254044307794954, 0.011530571184786302, 0.022120791221303598, 0.07003415056637355, 0.050875741456236155, 0.02976353486467685, 0.067560815784548, 0.05515506165102124, 0.034817898113812716, 0.02342083039028304, 0.014830142791782106, 0.07841829889054809, 0.05543845519423485, 0.04427936666512063, 0.08538019031818424, 0.004713266239767628, 0.025016865194109932, 0.035147825588605235, 0.03297136684081384, 0.07328188379428216, 0.02598398963787726, 0.048798213114163706, 0.026719245095072047, 0.044517240686608214, 0.0285681732930243, 0.031031730385231118, 0.005794951991577233, 0.07150659191289119, 0.05761624726333788, 0.01671337432760213, 0.06575756147503853, 0.016326130999784385, 0.04383428840498839, 0.043566857398088486, 0.07634046860039234, 0.07281626627913543, 0.037189774946974855, 0.02671561493272228, 0.04007391179246562, 0.02140313696249255, 0.016064584587833712, 0.008246923946509404, 0.030687933654657433, 0.03971193710874234, 0.03314922104722687, 0.05404809622892311, 0.006446759515841092, 0.03732371775965605, 0.05256245398361768, 0.014978282253390976, 0.03360523050650954, 0.05423351949346917, 0.04060092315609966, 0.045122056268155575, 0.021029879937746694, 0.0122711302413206, 0.027922845778188536, 0.10295523117695536, 0.0056920203496702015, 0.04315454898668187, 0.018196461888562356, 0.011064879030787518, 0.03420458048848169, 0.04375224673588361, 0.03827468119561672, 0.017741290420027714, 0.07440519851765462, 0.07289336142795426, 0.04140348419813173, 0.024810317438095808, 0.016361346967252235, 0.08448671576167856, 0.011168277589604259, 0.06670170902673687, 0.025601399363949895, 0.054561994903321774, 0.05049215543216892, 0.06611483730375767, 0.04708929552829691, 0.08451023378542491, 0.06802669792835202, 0.022991936886683106, 0.029123605095914433, 0.06784936280122825, 0.030072400612490516, 0.024742458847218325, 0.06556225874062095, 0.04814494334693466, 0.03683871449902654, 0.03227754782087036, 0.05961192731878587, 0.037080693657376936, 0.03289295194138374, 0.0071898028587124175, 0.021854625682213476, 0.020237154260809933, 0.042521048337221146, 0.0339377940898495, 0.025027209460469227, 0.0473740054294467, 0.02581593008445842, 0.01584883589696671, 0.09298850170203618, 0.01803940986948354, 0.011791468747625393, 0.007954240410721727, 0.014427433954551816, 0.05184652829276664, 0.05001278401219419, 0.08716705122164317, 0.03658332409603255, 0.01371134287078998, 0.05874940074448075, 0.04475120973906346, 0.037718187485422404, 0.007623840505922479, 0.046696671417781284, 0.026220876390912702, 0.0659560736800943, 0.004575786563301725, 0.017713190588567938, 0.02389614417084626, 0.05584624795509236, 0.024871139620829905, 0.03170341559286628, 0.026372964926330105, 0.03375112910621932, 0.02559689219508852, 0.01601420675537416, 0.06750181037932634, 0.009457857896839934, 0.020091323514602015, 0.04144192659961326, 0.025382096845922724, 0.015939978417009115, 0.016940748019676124, 0.037562735112650056, 0.03350137732923031, 0.01807545025699905, 0.05609156211305942, 0.01089713499615235, 0.017910866499213234, 0.052642154706908126, 0.07504473134343113, 0.01990952023438045, 0.06680558595274176, 0.10647932493260928, 0.041715725657663176, 0.02669814944134227, 0.08469089373414006, 0.05710464542997735, 0.06522327621600457, 0.06076572183519602, 0.05147033151505249, 0.04629851046151348, 0.022883339053285972, 0.009742178488522768, 0.026570935999708514, 0.07880625128746033, 0.017955186710293804, 0.07078570273837873, 0.040245401340403726, 0.0145884435291269, 0.044555890041270425, 0.06584357935935259, 0.08832049289984362, 0.03656049817800522, 0.019385228099833642, 0.0823115428377475, 0.055783120449632406, 0.0501239280482488, 0.03994042020557182, 0.06276408210396767, 0.02846087994320052, 0.05289315838100655, 0.012022592193846191, 0.01032144553028047, 0.017921007205066935, 0.029999899145747935, 0.043847133072891405, 0.021816334254773598, 0.05097911626632724, 0.02159652962083263, 0.03944416344165802, 0.06654281648141996, 0.048517255511667044, 0.12064412342650549, 0.17162407429090568, 0.0830342708421605, 0.11390150737549577, 0.14425467220800264, 0.12154776922294072, 0.17259425723126956, 0.08747082456414189, 0.15723990542548044, 0.15692079040621007, 0.1003723062042679, 0.06806059753788368, 0.10959574806370906, 0.12923675163515977, 0.1287732036518199, 0.11266274670405046, 0.10946426833314554, 0.12763941234775952, 0.18314523249864578, 0.20083770741309437, 0.1480083686432668, 0.09149757706161056, 0.11338943056762218, 0.18487066562686646, 0.09412624886525528, 0.1787717350359474, 0.15099157499415533, 0.12193705833383969, 0.1388225515506097, 0.14861906373075076, 0.1009952284927879, 0.12308797586177077, 0.15670758113265038, 0.1572432845298733, 0.13932888795222553, 0.1118152089683073, 0.14074284636548587, 0.12578703888825007, 0.19828690428818974, 0.08951812077845846, 0.09144316533846514, 0.1437400033963578, 0.18807599720145973, 0.1308228950947523, 0.08324428421578237, 0.12169041085456099, 0.13146972895732947, 0.23352379777601787, 0.16960626042314939, 0.19057695514389447, 0.10477143193462066, 0.15847443203840936, 0.15298137893634184, 0.10355639963277749, 0.14313789856220993, 0.0722553620913199, 0.15031909250787326, 0.12585930286773614, 0.11194362850593668, 0.16672399294163498, 0.1035816411354712, 0.15337590633758477, 0.06299426153834377, 0.0994645824123706, 0.11719287719045367, 0.20514512913567678, 0.09274202385651213, 0.22261446102389268, 0.13619062277887548, 0.21600156729774816, 0.1435424139989274, 0.13804733886250428, 0.10423555211829287, 0.11458006953554493, 0.10739765422684805, 0.08884204205657754, 0.16380661805825575, 0.11037434664155756, 0.10761935197349105, 0.18783096463552543, 0.10992303264460393, 0.14406175113150052, 0.12877563280718668, 0.08467247829373394, 0.07087815313466958, 0.06611320203436272, 0.1204101781227759, 0.1441437860152551, 0.0805762709517564, 0.1305466363472598, 0.06798878817686013, 0.08917644446981804, 0.19678061082959175, 0.14138757676950522, 0.10036248101719789, 0.0972277374405946, 0.12582164417420114, 0.17585170029529504, 0.24056889116764069, 0.15805302107972757, 0.1177416763135365, 0.14819481649569102, 0.1357090664761407, 0.14981895791632788, 0.19781072198280267, 0.10295587578522307, 0.14998769600476536, 0.1431897250669343, 0.1789427258606468, 0.059067518317273686, 0.095762610701578, 0.1331610046327114, 0.21016635612717696, 0.13939223598156655, 0.09863977559975215, 0.0706242589013917, 0.06978313332157475, 0.10460571332701615, 0.06799248619271175, 0.15930455178022385, 0.08022586189742599, 0.07024982292205095, 0.10506533937794821, 0.09242429304867983, 0.1320312845387629, 0.17605036177805491, 0.15203970803746156, 0.09877026466918842, 0.09016447966652257, 0.18320754915475845, 0.1238841824233532, 0.14370432602507727, 0.15477311850658484, 0.22823578438588552, 0.12851830518671445, 0.18753036005156382, 0.21801995113492012, 0.2132630135331835, 0.11131829063275031, 0.16531360362257275, 0.18761342630854674, 0.19904752847339424, 0.12320251257291862, 0.12472293313060488, 0.10438286885619164, 0.08223510586789676, 0.11672140391809599, 0.139780995835151, 0.12629592658153602, 0.17453490809670516, 0.15571721856083187, 0.10896094462701253, 0.17055128328502178, 0.12903373395758017, 0.14376719907990523, 0.13587456116718905, 0.11148860970778124, 0.10125926003924438, 0.18839756851749762, 0.16563947685062885, 0.11047047469764948, 0.12926591507026128, 0.09548817042793546, 0.0876779066664832, 0.18977777659893036, 0.07574700151703187, 0.11162331247968332, 0.08205618975417954, 0.16333011005605969, 0.1591010591281312, 0.08448677682983023, 0.14402312891823904, 0.13331914400415762, 0.1377913818827697, 0.13541767639773233, 0.1300153298569577], [0.01750422894422497, 0.05090082350320049, 0.06795731772269521, 0.019332490661846738, 0.07602062754865203, 0.03715620103425213, 0.046001407118248086, 0.016102158464491367, 0.01957058859989047, 0.0427909118921629, 0.05181995686143637, 0.014191517506593039, 0.027388087240979075, 0.02917626959138683, 0.011063853594740587, 0.044063117554677386, 0.027109060070610473, 0.09416832482176167, 0.0016152896132552996, 0.02106137583697481, 0.019799963970269476, 0.058371124256934435, 0.019567267170974185, 0.019768004970891134, 0.009841917199082673, 0.04793075019759791, 0.02560687005253775, 0.01545551628805697, 0.036687553860247135, 0.0327293571483876, 0.02995619470519679, 0.04383274134514587, 0.02632181695662439, 0.06497124795402799, 0.056488077621906996, 0.019907649174066525, 0.03481899055519274, 0.07777183822223119, 0.010733229773385184, 0.004699111999278622, 0.03774884709024003, 0.03494661281417523, 0.0678505434521607, 0.020457922414477383, 0.060730546579829285, 0.029872351525617496, 0.027766287393335785, 0.04707732277789286, 0.026430796465969512, 0.02675681049004197, 0.013872874917329421, 0.02772425384526806, 0.05600357986986637, 0.03689955873414874, 0.024396585799487572, 0.019573492729770284, 0.03271247858979872, 0.028182397297184383, 0.00637654513619574, 0.011241106449493339, 0.03684043458529881, 0.11166925608579602, 0.011178097687661648, 0.05308452221964087, 0.07305849649544273, 0.05034356304843511, 0.06156650172280414, 0.01754098348984761, 0.061023395508527756, 0.07432395751987185, 0.02814210419143949, 0.04562426717685802, 0.05029769068849938, 0.032509735718901665, 0.024303022605766143, 0.05889387442065137, 0.010778229367653174, 0.02346243306861392, 0.031934816390275955, 0.0464680899333741, 0.03363847193707313, 0.06083854899874755, 0.06939177467886891, 0.007037733407092414, 0.037147926299699714, 0.018773338790716868, 0.054970011580735445, 0.006033016426954418, 0.05530935372891171, 0.025372695743239353, 0.031106002828372375, 0.03035147188763533, 0.049479930462049584, 0.08676905650645494, 0.0653925503471068, 0.05167641617091639, 0.030256646618779217, 0.08594071452638932, 0.03494215483910271, 0.00043467928688707095, 0.03125543998820441, 0.024618627902652537, 0.011136126055914377, 0.028818013279565742, 0.025791212750066603, 0.02564618776419333, 0.04868414119950362, 0.008247610115047013, 0.011531784066132136, 0.05159051703023059, 0.02050282107666135, 0.05984725683395352, 0.040981187751250606, 0.017706927710345814, 0.04894378601706453, 0.015013082618159907, 0.04062300268560648, 0.056862042019409795, 0.019147915566073995, 0.04843107477894851, 0.0382553666963109, 0.05637382250279188, 0.016345859405451586, 0.06191163856003966, 0.007841676540140594, 0.009617224568501115, 0.01833364979497024, 0.012058820874829377, 0.031037728634795973, 0.03456504882446357, 0.006863447870793087, 0.05034432640033109, 0.05613681700612817, 0.0335581605322659, 0.028178209039781774, 0.04890228342264891, 0.024558324799207703, 0.024764484093923653, 0.04689291731587478, 0.06767482323838131, 0.022442925721406937, 0.04305087562118258, 0.048386739300830026, 0.03194055679653372, 0.00936229302481349, 0.03811825512509261, 0.009855907742998429, 0.02654146383117352, 0.04715608712285757, 0.02866176702082157, 0.021741990565455387, 0.060633807842220576, 0.01750811016453164, 0.03193697413163526, 0.03752006883067744, 0.036651503294706345, 0.0532743254277323, 0.019422762960727726, 0.02039852854795754, 0.10821458324790001, 0.06970560391034399, 0.024438178299793174, 0.046423245553991625, 0.06131293997168541, 0.042021999401705604, 0.028199430222490003, 0.025287285147766982, 0.024860842851921916, 0.015874077399660434, 0.03579215565696359, 0.04131731025076338, 0.036940518500549455, 0.023181846964039972, 0.02318760603001075, 0.03969474981671997, 0.03349469715197172, 0.03562641330063343, 0.06945631692984275, 0.019319238872932534, 0.03887191414833069, 0.035538549801068645, 0.0047925314283929765, 0.052749458234757185, 0.0785485233313271, 0.005055028213454145, 0.02335547559362437, 0.022872743728969778, 0.009228939689429743, 0.04704656478549753, 0.035233110655099154, 0.0366164841023939, 0.02160027852681066, 0.007716502096237881, 0.015320652364087957, 0.022384561531777893, 0.018787240276911428, 0.02265797891387982, 0.04759470572961228, 0.012557886773720384, 0.027391223769102777, 0.03885836719668337, 0.05817733465560845, 0.017157363539029444, 0.028741820582321713, 0.010026167446215237, 0.04666280234232545, 0.04503494933513658, 0.030773367998855453, 0.039200318312006335, 0.047027799899556806, 0.011839162125917417, 0.04153905210218259, 0.050269368636820994, 0.038457251220409355, 0.0038059287887465742, 0.006797541764431766, 0.011262755109263318, 0.03803425927513412, 0.052591902403427024, 0.041652733859206946, 0.07025310024619102, 0.05680247003744755, 0.008562954175951225, 0.07041154495839562, 0.029568931021328484, 0.05850736730332885, 0.014631810398506266, 0.05922120649899755, 0.019970439108354703, 0.03456696568589125, 0.04319116273628814, 0.03726985564987574, 0.03852394442739231, 0.05964764540216752, 0.0254423287031906, 0.01648737127626581, 0.06467805975782019, 0.06783911692244665, 0.017661528628585593, 0.058292122424713204, 0.05465543256806476, 0.02264105116150209, 0.032555662361638885, 0.017536176069240485, 0.02370293641329876, 0.0358153411985508, 0.035695735830813646, 0.047541936061211994, 0.03767559244962675, 0.032639135739633014, 0.09137997337217842, 0.02644103895207601, 0.03562880174389907, 0.00798912050335535, 0.04328705669779863, 0.022852136620453427, 0.08066225490931954, 0.02528689838280635, 0.0648048711674554, 0.037415764427610805, 0.05207305381606732, 0.009261951266255761, 0.05037405641217317, 0.05196062734882746, 0.03501035100115197, 0.03761054469006402, 0.029221884108015468, 0.021057779601375972, 0.044614593498408794, 0.039747346458690505, 0.02252288768067956, 0.017689603014982173, 0.03461188809680087, 0.06156414720628943, 0.03630784905648657, 0.018645314499735832, 0.025118284127009765, 0.04898114276251622, 0.02273898751341871, 0.05744381794439895, 0.0486556868334966, 0.1371379526598113, 0.034125473483332565, 0.05904940821762596, 0.017643790026860576, 0.04693889824141349, 0.03521164180710912, 0.03547865890764764, 0.04090262018144131, 0.06893877112971884, 0.01713618476475988, 0.06821760375584875, 0.06843392750514404, 0.004095011848091547, 0.04064424761704036, 0.018856125152004615, 0.007401460831585739, 0.05373015846791012, 0.05634649111224072, 0.07326745813978569, 0.028717328860823597, 0.02556872959913952, 0.02872734743037394, 0.03306734222652657, 0.05139584872605545, 0.016762038859139596, 0.04242885917691248, 0.05358697061559983, 0.0339898580818304, 0.01217401830945164, 0.014923746697604656, 0.03999106605936374, 0.020823138799252253, 0.021843835279079418, 0.019818518510354415, 0.0037983033273901257, 0.0296676714372422, 0.057164261516715796, 0.002096040261676535, 0.031146762426942587, 0.02723464842087456, 0.08093558238553149, 0.06415938080421515, 0.05314420276720609, 0.015967169011543905, 0.015834651122401868, 0.019437653411711966, 0.037555549426802566, 0.019590556189151745, 0.03507277961554272, 0.028271117447210208, 0.024369038974067996, 0.03566712200907724, 0.08849957186196532, 0.052385145997894664, 0.0017081628216796421, 0.028484788124582598, 0.054538917927337546, 0.05074042461014219, 0.012962658357407366, 0.02751201148410993, 0.03260220307856798, 0.02023643671002771, 0.02148886477308614, 0.05321028529267226, 0.04619803299595203, 0.07177502715161868, 0.052814000485731025, 0.026035095199144313, 0.05313863538737808, 0.0783879683752145, 0.04454992571845651, 0.08244345683072295, 0.17975995343710693, 0.14613897752548966, 0.0941238875633904, 0.15133868636829512, 0.0751467626541853, 0.22030143014022283, 0.16406817973724433, 0.059333347981529574, 0.13311786337622575, 0.11929306520947389, 0.050755175961447616, 0.2081258791897978, 0.10973699869854109, 0.11679544565933091, 0.10407847804682595, 0.08372881928724901, 0.12966056460780756, 0.08993742827858243, 0.06880032284451382, 0.1289318994219814, 0.1375113097684724, 0.08740473525332552, 0.09638233030480997, 0.11317158011453492, 0.1919560775692974, 0.10778861931924309, 0.08278483458395515, 0.14006310355450424, 0.12284047342836857, 0.17597197741270065, 0.1384496558457613, 0.08833900333515235, 0.1679876558482647, 0.14297476517302649, 0.13366476260125637, 0.22055976199252264, 0.16083850232618196, 0.1390542984008789, 0.09160948105688606, 0.12808234643723282, 0.10599268640258483, 0.2447540137384619, 0.13381655088492803, 0.1745416663054909, 0.1294615367161376, 0.09163069206156901, 0.111724889171975, 0.12989292213959353, 0.16006463313741343, 0.11366389798266546, 0.1251205817929336, 0.18209263469491685, 0.09364412259310484, 0.20204027502664498, 0.1433528991682189, 0.058796219660767486, 0.09766537217157227, 0.11911855957337789, 0.1701988521963358, 0.19926290905901364, 0.22906907967158727, 0.07151959942919867, 0.10759960660444838, 0.1735089902899095, 0.19478228448757104, 0.10316841330911432, 0.0791757543172155, 0.1203007847070694, 0.16998188383877277, 0.07901936556611742, 0.08445559814572334, 0.17072935801531586, 0.09743699764034577, 0.09707953182182141, 0.09774615855089255, 0.09289717767387629, 0.0918300049379468, 0.15644817719502108, 0.11954199256641523, 0.132504047027656, 0.12376851934407439, 0.21954132164163248, 0.14472978242806026, 0.11279437571231808, 0.07868612344775881, 0.0915194462452616, 0.09764363190957479, 0.08544146881571837, 0.12258626706898212, 0.14022774329142912, 0.15800312161445618, 0.12821071169206075, 0.1586718721581357, 0.11826011777988502, 0.13606394029089383, 0.19333055881517275, 0.1562912863280092, 0.08233663506273713, 0.06460393659238305, 0.10041334400219576, 0.12931467459670135, 0.09630556085280009, 0.12201047582285744, 0.16452266249273503, 0.24892415425607137, 0.1503364901457514, 0.11045087182096072, 0.1020066256501845, 0.16795056712414536, 0.1932564763618367, 0.15139066215072358, 0.10893513994025332, 0.14538357805992874, 0.11919125781527587, 0.1959864127316645, 0.11529942522091524, 0.1026481194421649, 0.1365082993039063, 0.12688994327826159, 0.12047841160425118, 0.1428119439099516, 0.11935002143893923, 0.12064694613218307, 0.10940667428076267, 0.11116810369172267, 0.10699483512767724, 0.1302878295204469, 0.11891795748046466, 0.1089746103222881, 0.14241073972412518, 0.12913049305123941, 0.14832814862685545, 0.12713933203901562, 0.137906407139131, 0.07669125084898301, 0.11706244918916907, 0.16174365447035857, 0.12699845459844383, 0.16541360611362116, 0.1441405833299671, 0.09831335954368114, 0.08550795846219574, 0.12235441165310995, 0.17362105713358947, 0.20571273724947656, 0.24841378735644476, 0.13961965377841676, 0.12022792361676693, 0.12066931064639773, 0.11389738188258239, 0.11234276994530644, 0.11614354992551462, 0.13796252198517323, 0.1168915940714734, 0.16992602683603764, 0.07679627449916941, 0.16166259667703084, 0.10416678937950305, 0.16333034075796604, 0.1671313853668315, 0.11671936831304006, 0.18723092254783424, 0.126958909577557, 0.19643599646432058, 0.20489537396601268, 0.10576885805598327, 0.08899047837725707, 0.18430292180606297, 0.10582900340003626, 0.16294069880885736, 0.09005864177431379, 0.0876847802262221, 0.12522181921771594, 0.147140359506011, 0.11246368488562958], [0.04220860331718411, 0.05559384649885552, 0.01544287518065955, 0.007965863715591175, 0.04204431302579386, 0.04909052600019744, 0.017670132452622056, 0.02447047995935593, 0.03240453564961042, 0.0229900556483439, 0.0053955908764952, 0.023538920928591063, 0.01058809198106506, 0.03333389113790222, 0.016897962994075248, 0.038513040369642634, 0.0336687583476305, 0.055884985519307, 0.02540729085116514, 0.030939605685749223, 0.02767653078106897, 0.07574705579983336, 0.027204523162384118, 0.04939175483637622, 0.017092833162418435, 0.027615974923329692, 0.025123054228190864, 0.06665067640798432, 0.09350737743079662, 0.03996626560443214, 0.033093710097351244, 0.11350254914058105, 0.048935687701616964, 0.04515214251088245, 0.03314650012180209, 0.06390341025378023, 0.03521433559113315, 0.06714579662574188, 0.03990418643557599, 0.029604184308222363, 0.050765309881951125, 0.04035959539136716, 0.027156014693900943, 0.061332726052829196, 0.04811794783121773, 0.04218763319243278, 0.02129261039330491, 0.039237342575298886, 0.009362411768441754, 0.012230064453823226, 0.0457826135014849, 0.038744844895388396, 0.04517139933471169, 0.05154765397310257, 0.006880739487574569, 0.022385177302307317, 0.0627189798812781, 0.049664390206869156, 0.024779959781361476, 0.1038410925705518, 0.011230612905429942, 0.0009235355662115451, 0.0142241940567536, 0.023737848736345768, 0.06307541432657413, 0.04332232355539288, 0.05798765019114528, 0.07176987707082715, 0.011007208643215043, 0.04440949611099703, 0.04327579640916415, 0.04713558179459401, 0.021315867181069086, 0.02059911367749529, 0.04903915072126048, 0.033683730222816975, 0.09590213107211248, 0.01795706116328282, 0.02096066597316946, 0.053387817194951434, 0.07599764556757041, 0.04554478697744863, 0.02752443546030138, 0.0705761236271688, 0.02154104581235775, 0.035348726236926656, 0.0373889589016991, 0.024170599711526717, 0.006861685376082147, 0.04713234857523015, 0.06563370169273444, 0.04785232172746744, 0.04962990366454635, 0.062420492326574664, 0.0037212857860140502, 0.017361158139205406, 0.05312102401096906, 0.018940914887934923, 0.028015489556959698, 0.035315803717821836, 0.02919821341388992, 0.015346236526966095, 0.07524788472801447, 0.027673831908032298, 0.04283061636877911, 0.034225126528846364, 0.03432450137500252, 0.029391365192298378, 0.04005919097523604, 0.011830878909677267, 0.021748389150681238, 0.014581274806654878, 0.026501384463959506, 0.0437378923275641, 0.03419803941090192, 0.015617648838087916, 0.04653645912185311, 0.04270788973995617, 0.08485200508896794, 0.0537700257929308, 0.06152195589882987, 0.01261487353726157, 0.013656480770025934, 0.061936567936624796, 0.03438051783346704, 0.024823672703600357, 0.01836966134474746, 0.09302512902234282, 0.02157323551364243, 0.016352709216464843, 0.060827468521893024, 0.02079720519083951, 0.0022986463653588934, 0.05990944456841264, 0.010331470885181, 0.020948330206530433, 0.010627793913174952, 0.07421515442963157, 0.06332735437899828, 0.06926664603607995, 0.0376595518817859, 0.030973637609609535, 0.04574914136901498, 0.044580263019140275, 0.09196326921560935, 0.03645009374512093, 0.027549446261088763, 0.031339537618415694, 0.034224454779177904, 0.009410163670379137, 0.045411146112850735, 0.04575022363236972, 0.08576865840171065, 0.048051023922328434, 0.009220815928918975, 0.009739152222339596, 0.024631309722151076, 0.06065176187881401, 0.009789993154949375, 0.049352871387132576, 0.02792712054880602, 0.05712479113468102, 0.015014278536130275, 0.06567600156579699, 0.019924042580117072, 0.041614997134144814, 0.062139694179807387, 0.012129586140092994, 0.024195020186847875, 0.00252336825776313, 0.011417176956976098, 0.0373037145473063, 0.04696399725175329, 0.05076021069128599, 0.011570544530903655, 0.015404833114839025, 0.03977622151640909, 0.06199025362730026, 0.08806405416024582, 0.09110242540815047, 0.11387182825378009, 0.050938600940363746, 0.01571855547704867, 0.0330543211395187, 0.06993380880781583, 0.09662853673632656, 0.031997411245746274, 0.04799065805439438, 0.04442799297560539, 0.039031617542994876, 0.06434850208461285, 0.06024172995239496, 0.059071650595537255, 0.01939735352061689, 0.021602957043796778, 0.013863177803744162, 0.03415561740153602, 0.029649140645882914, 0.0350441216890301, 0.02150824373321874, 0.013977511802555194, 0.0384833849966526, 0.014820395636239221, 0.04853695338325841, 0.045061798965824504, 0.07650388697428362, 0.05235979932227305, 0.02538582030683756, 0.045291374504034004, 0.06071601914508002, 0.024850866690810238, 0.06411172728985548, 0.03449169918894768, 0.10286634308951241, 0.048664151557854245, 0.007189508544148079, 0.06152677349746227, 0.02916611870750785, 0.03091402830822127, 0.055994887836277485, 0.06305693781801633, 0.047811311070940325, 0.02480868386503841, 0.019153655972331762, 0.047097241173365285, 0.04471031443348952, 0.046684379755918465, 0.022294655641806976, 0.0651533328262823, 0.025605987957013503, 0.06640607810446195, 0.01635380505051996, 0.04464770939999393, 0.026724473207390735, 0.047535262669303587, 0.014840105382193412, 0.014558889936389667, 0.0010023658562983784, 0.06251016751463924, 0.01871870145467775, 0.01442406842085932, 0.016536095179617405, 0.030302702183169977, 0.02060218235211713, 0.024115131170089756, 0.0919684125110507, 0.04770544943000589, 0.05556258978322148, 0.04169230602149453, 0.08506589968289648, 0.02074164165449994, 0.06707432653222765, 0.058457420340606144, 0.06483487598598003, 0.019279341013836007, 0.049707996259842596, 0.05130618710869125, 0.06589050684124231, 0.09503805065261466, 0.07922327890992165, 0.003352957470009902, 0.014107543709022658, 0.024187936281253184, 0.035692628140428236, 0.017689767559724193, 0.031207029907298938, 0.017374275917453424, 0.05358582049874323, 0.05331421989415373, 0.06656572382364954, 0.043804877304605076, 0.011575115312423025, 0.030920338683894703, 0.008139260795100458, 0.027907683913196837, 0.031513486855796406, 0.033240192237177064, 0.026041463250294328, 0.03529763255002243, 0.00973070615769497, 0.024428005363526087, 0.017721400862293582, 0.03749926833968077, 0.02797143567087395, 0.08178026348884616, 0.009992363679754947, 0.048385110816785266, 0.007524909252034766, 0.027236750183094825, 0.014262256478624684, 0.022918675460719636, 0.030279615029160465, 0.025553930750382797, 0.025822545800890242, 0.14296318936560834, 0.02123296886150326, 0.026774155541456172, 0.004517865541856736, 0.0234666094516537, 0.044810947962105274, 0.03494891983323863, 0.024556943980444754, 0.04164806214560356, 0.03716065561664956, 0.050631780975631306, 0.028463125894112245, 0.041373431882155795, 0.07006091877285923, 0.021013864814969044, 0.017558949400803874, 0.056718776135572364, 0.008790577229644572, 0.05401619151234627, 0.049947712503905804, 0.0514243879089398, 0.06706870147692305, 0.0019404411557063992, 0.020287888324154273, 0.026576213305816054, 0.07827464624175004, 0.04703863610380462, 0.014580845633255584, 0.09045178496411868, 0.023426190816930363, 0.017774669253932576, 0.034842684998043945, 0.03553364738555891, 0.042997057616178475, 0.045301270937280994, 0.041851951740682125, 0.027891053019889762, 0.03321317297273448, 0.027195473201572895, 0.009820861409285238, 0.056898893256272585, 0.024888454138168266, 0.05051513062790036, 0.04162295295723847, 0.032198909004884105, 0.06715572359306471, 0.006208410519840462, 0.014923899367983853, 0.0036955871203515145, 0.019244147098756263, 0.004288969810919038, 0.03689312622217195, 0.005548552177580339, 0.016614732299266115, 0.07864177439893995, 0.0388044338407261, 0.0076996481345434275, 0.0202945515380374, 0.10464897671980516, 0.12758393532463483, 0.12750298609691008, 0.312456663697958, 0.22488965679492268, 0.0711682132844414, 0.0729308504877346, 0.11793402742062296, 0.15137159531669958, 0.1559710313699075, 0.12122129888406821, 0.09090749586799315, 0.1310546283743211, 0.21764656688485826, 0.11219756345131568, 0.17928629528198922, 0.11418801200176988, 0.14432761472250732, 0.1179589025144066, 0.11939343410943236, 0.0985158479639462, 0.21772473411900656, 0.1358269415795803, 0.27523690089583397, 0.06362204892294747, 0.1263152648295675, 0.12370122224092484, 0.17686042402471813, 0.15687713346311025, 0.1159922501870564, 0.19188906545085566, 0.2199639268219471, 0.13561309448310307, 0.1389884262212685, 0.10303261809583221, 0.11828622780740261, 0.07537561894527503, 0.28189338371157646, 0.2009660726679223, 0.10118788494063274, 0.16961044019886426, 0.09177415472056184, 0.0831774485164455, 0.07964834038700376, 0.16223058477044106, 0.15022858950708592, 0.10645438877067395, 0.0907166511086481, 0.09947806490319115, 0.07305663730949163, 0.1084358331614307, 0.11733963074428694, 0.1882838596190725, 0.1262461356818676, 0.1340862007013389, 0.06032960702266012, 0.10813447540359837, 0.08830376022628375, 0.09008566103875637, 0.1804165853453534, 0.0855835811900241, 0.049838068030242405, 0.1756682244262525, 0.10800566231565815, 0.14991670767111437, 0.1526532529720238, 0.14142375625669956, 0.12194510575916086, 0.19296611765665667, 0.24776350653597287, 0.1264012080750295, 0.19823716767132282, 0.08978380116501025, 0.25142469150679453, 0.0976037069090775, 0.19749179695333752, 0.13965614539171967, 0.14164692642433302, 0.08253904884415013, 0.1468869402472462, 0.1578265939440046, 0.11833885498344898, 0.1393134987780026, 0.191836791113019, 0.16254470577197416, 0.09450305971716132, 0.11538468993135861, 0.12066518515348434, 0.07367871142923832, 0.12157947037901197, 0.14256999189300196, 0.11450723558664322, 0.11265470606407949, 0.17858741778348172, 0.09980393813124724, 0.12205627693661622, 0.11018800056938614, 0.08140692673623562, 0.12000170004154954, 0.14051038026809692, 0.11922890293811049, 0.10276359931698867, 0.13178353783275398, 0.15422408868159565, 0.20191698521375656, 0.10694397214267935, 0.17062535216765745, 0.12475628991212163, 0.11646731969501291, 0.13487084502620356, 0.1153658130871398, 0.0995328158938459, 0.10833011062017509, 0.12354830758912222, 0.057734298785882335, 0.1538730010922466, 0.1055097933858633, 0.15993098888014043, 0.23048005253076553, 0.1724865465824093, 0.17360972559877805, 0.06544084846973419, 0.07943133131733962, 0.10899348038115672, 0.09998195857873984, 0.23064176099640982, 0.1571574905621154, 0.19467164256743022, 0.17653004532413824, 0.10799633245915174, 0.20857386157980987, 0.15700161749763147, 0.0741411398297974, 0.12099105838154044, 0.16245083723749432, 0.12312399250056062, 0.16256518395883696, 0.1683232592684882, 0.17835089404668125, 0.2550039365887642, 0.09536132509154932, 0.1174415195626872, 0.10355033352971077, 0.12315760712538447, 0.17600426210888795, 0.11513805602278028, 0.13901083144758428, 0.12253321920122419, 0.09757034334221057, 0.09292060748807021, 0.12531188795609133, 0.10730360927326338, 0.15371602880103247, 0.18660337265048707, 0.10255063431603567, 0.1154219957866839, 0.06741629461092608, 0.15520610527268477, 0.09531830597136702, 0.07272266237331287, 0.21014951488801412, 0.13851950424058096, 0.08644731555666242, 0.13114594561713083, 0.10861669667065144, 0.11767212647412505, 0.1105624365487269, 0.14288347507161753, 0.09622300349708114, 0.10071813514722244, 0.07220202923885413, 0.13642071400369915, 0.13061529052044663, 0.14498824998736382, 0.13373584592980997, 0.11406826414167881], [0.005224120836438877, 0.021848552793796574, 0.05219250651342528, 0.08391946048608848, 0.03590854137603726, 0.05382903119815247, 0.027392414598060504, 0.015762283666325465, 0.04546765450920377, 0.021243974699505737, 0.07690496902380671, 0.005070993294274169, 0.05144436737256391, 0.03893728421202727, 0.05316153255158237, 0.0019563487730920315, 0.08253820746072701, 0.034353651239403656, 0.021986434502261024, 0.028310765944687382, 0.012719946381236826, 0.02639719201917095, 0.03233297395386866, 0.047104857728949616, 0.03649819509259292, 0.008288684384232121, 0.03602844190650752, 0.1233479090567146, 0.036095362422721725, 0.06391049415937491, 0.008646489470265806, 0.05099450544055019, 0.05265555238085134, 0.01611242300298597, 0.02595253105807517, 0.026854456768238118, 0.027236390559534942, 0.0313602702559105, 0.0705072387520756, 0.09404735559863703, 0.0020824903414385127, 0.010134119823175882, 0.019739740594689335, 0.023627829372084568, 0.045753195615751405, 0.05337915230276329, 0.05582272314599582, 0.02847639125372682, 0.05407653363155467, 0.0253259565548173, 0.022478762548416853, 0.04276278322296483, 0.05823853172894035, 0.008863451042478638, 0.030896627277668034, 0.03451134956308773, 0.013114876662647086, 0.021683273537616645, 0.06285110422010932, 0.047898075343774896, 0.0446334160598261, 0.008694927540740796, 0.025766809238120914, 0.0027510398691187477, 0.011691703743833517, 0.07193906977772713, 0.010615745675750077, 0.07527903627072062, 0.02591397500197802, 0.023174630744116645, 0.06496440832104002, 0.05643769639677235, 0.06380144001117774, 0.06760287138500384, 0.04439576256221958, 0.03504649656159537, 0.028849751755063022, 0.04604004629488502, 0.024465786193364432, 0.01830935993764017, 0.07054450389529977, 0.039827264313186915, 0.033750796624060185, 0.05061544185238225, 0.016659357851105075, 0.019872631678091626, 0.050093913051698885, 0.03011589470718588, 0.03737878766176956, 0.06488553541047232, 0.06231276810701404, 0.019821415854884044, 0.028225991475794996, 0.030615564502243484, 0.04793070948549679, 0.04893264786473342, 0.011389928686964725, 0.017217598788972412, 0.061237839715821404, 0.04973578226885625, 0.015591318286689264, 0.05373114573636225, 0.015483960476038712, 0.04655626216637237, 0.031732121016830206, 0.05456980823406151, 0.055881033052823374, 0.03101508252854858, 0.023975583658154522, 0.07474115477608782, 0.052926990137036355, 0.00529702942419265, 0.039435539261571, 0.0490243315164532, 0.04996113392657467, 0.009098928139012839, 0.01323419959018273, 0.027531746675127318, 0.022059918148443103, 0.07225719413587026, 0.02261873923375138, 0.04036367338682924, 0.021602412519444312, 0.052598168674324236, 0.07091682963073254, 0.03130437932642443, 0.03856806616697993, 0.032002388300108056, 0.009406276512891054, 0.03572159480037434, 0.07699736513729606, 0.014993182882400495, 0.07628088644040482, 0.02025971724651754, 0.048070820181497505, 0.031507909297943115, 0.15697689168155193, 0.05367537694317954, 0.04042435138087187, 0.055424904849912436, 0.08081753086298704, 0.03444504312106541, 0.005645157328607249, 0.023239673414666737, 0.013459898148929434, 0.030969647823699882, 0.0473832911811769, 0.019751748968181864, 0.08039582134889704, 0.009785994039183217, 0.021880616966102804, 0.051010376374636374, 0.037705471739172935, 0.049324210067944865, 0.01706001242356641, 0.05643791352797832, 0.029688627991293157, 0.07063980413866894, 0.03452270145394972, 0.07620677684566804, 0.016198613913729787, 0.04536543660131948, 0.0452913303992578, 0.03969772180010166, 0.026943626447713802, 0.03462878701144031, 0.012995034655822175, 0.05590170801484159, 0.05429765801610691, 0.02403801227254527, 0.02817264335629131, 0.029815520825130597, 0.027086999200816666, 0.03407523135787674, 0.021533364795946648, 0.014107624285056122, 0.035202766569065194, 0.02573868735427303, 0.015943372788439904, 0.0720019360472049, 0.022232109980125512, 0.03170823319149869, 0.040903865293200524, 0.04512849556548255, 0.05153732667011874, 0.02620769415183791, 0.057074423480246744, 0.01905579595560474, 0.02066579501011542, 0.03168999417019742, 0.040986707633627315, 0.035955411182450395, 0.08380818752838032, 0.02924682366262589, 0.04281828738749027, 0.027794643371765102, 0.01634857863453882, 0.019040170990462815, 0.03286914214757936, 0.08464504512292997, 0.05429164958851678, 0.04173857193174107, 0.006270141939499548, 0.05542720847630075, 0.03720866875456912, 0.027348983267854367, 0.01687561035422342, 0.032722442876547575, 0.02866844380540507, 0.1381406917103699, 0.05491344550890582, 0.02201861741819552, 0.04607677200276937, 0.03408256971410342, 0.017532681613894444, 0.03606327110901475, 0.020633898775226305, 0.0626741965700473, 0.05484101528834019, 0.03476632605972035, 0.01910306609767888, 0.05406079161912203, 0.05698379155780588, 0.020716812361830046, 0.021934311138466, 0.09970781007515532, 0.043701851940048594, 0.020488621035058583, 0.05939755096499409, 0.007854942747923945, 0.032222237038825235, 0.027828961976670792, 0.05473976768553257, 0.0059946456957342365, 0.03582671005278826, 0.02018019972768213, 0.024334464222192764, 0.04960238906954016, 0.09307795975889478, 0.01079787380461182, 0.0620855674413698, 0.08860607471849237, 0.02906248266143458, 0.06994123198091984, 0.03616096997367484, 0.03835018517981682, 0.04315850145316549, 0.007345401964682553, 0.029466428128736358, 0.08853180227535111, 0.047512026237589974, 0.05160950244005237, 0.17016731388866901, 0.056245229938732724, 0.010363215297859694, 0.04422451728688819, 0.05416493995913437, 0.05154408487890448, 0.04696568001859954, 0.08870007895997592, 0.005677689690076346, 0.06599432269909553, 0.07014043629169464, 0.08960330406469957, 0.01922629144974053, 0.04607109266466328, 0.03303823307422655, 0.006917914300824383, 0.023798876175923005, 0.026155484274828007, 0.020668878951775174, 0.014330021770937102, 0.0253534677571484, 0.03917118201830557, 0.03666703496128321, 0.028974961822054217, 0.05090863683394023, 0.043807096114116054, 0.029010812219764506, 0.016916429324607764, 0.026689968005354916, 0.03369346720033458, 0.06379962153732777, 0.03766190979097571, 0.017029510578140616, 0.033630828240088055, 0.06963062579078333, 0.028806189806865792, 0.04557175535176482, 0.008215941189389144, 0.01764459239452013, 0.052837532080177746, 0.02178239223680326, 0.041561589642826996, 0.025326141455609883, 0.024092776833900383, 0.032526068056800535, 0.05356607512970056, 0.021982437931001186, 0.011626375240406819, 0.04726717687611069, 0.06419114302843809, 0.02873136775035943, 0.0124564186470317, 0.006731148809194565, 0.035276424938014576, 0.06135282426008156, 0.0431981584323304, 0.009833390558404582, 0.02277228153044624, 0.07832182478159666, 0.07344564143568277, 0.06906809990427323, 0.06051623129418918, 0.02617072926035949, 0.0328867942360895, 0.03858717032042997, 0.026890028966590762, 0.012549349955017013, 0.03671090564291392, 0.020132508893896426, 0.07090425637683698, 0.0678007932645934, 0.026239570030676465, 0.012656082665281636, 0.05977979688239949, 0.007182242282267127, 0.05748065561056137, 0.03636694945661085, 0.029852867392557006, 0.026310171599366834, 0.0726235012656876, 0.01681020127476326, 0.03446386568248272, 0.02285081347716706, 0.021215199725702405, 0.01983363796690745, 0.04296066439045327, 0.02322477108931967, 0.039201906083949974, 0.010859628124827785, 0.016416642482259443, 0.031738119266395054, 0.030097275706274167, 0.020875821954437664, 0.06874207061316286, 0.04361475518505488, 0.036784757394343615, 0.012903705538649644, 0.04808646719902754, 0.05347784182855061, 0.037393091179962666, 0.12017855340881006, 0.12184470971780163, 0.12771390192210674, 0.13294480980506965, 0.10337097636823143, 0.11686920241585799, 0.05302746420992272, 0.1364388716007982, 0.19665259841297353, 0.10261419947658267, 0.23216526210308075, 0.07154277140008551, 0.1185815262475184, 0.1454893345279353, 0.18847251949565752, 0.1482378898986748, 0.18222082353063992, 0.09609925228038005, 0.08766899750168834, 0.07868274434336595, 0.1362677857811962, 0.10213625976549727, 0.16719226352870464, 0.24747439633522714, 0.13124175476176397, 0.1136294419744185, 0.0917799019121698, 0.2380742978836809, 0.16000195007239068, 0.1269637950296913, 0.11118428675191742, 0.08924142098320381, 0.0831841185156788, 0.17463014727192266, 0.14302530246121542, 0.07946390099823475, 0.1834083276667765, 0.15101075039378234, 0.13373951001891068, 0.20957149804702827, 0.06907419314874069, 0.12282710628850119, 0.11376678424754313, 0.0881195922515222, 0.17101458699575492, 0.1310134684400899, 0.11159409476178032, 0.11640303528734616, 0.11043545550533704, 0.14957259542175702, 0.09428106341511011, 0.143784583147083, 0.22835536939757212, 0.06452633932765041, 0.13934841619006225, 0.06821498461067677, 0.13130728767386504, 0.09467021003365517, 0.1735321826168469, 0.14093194050448282, 0.20271281179572853, 0.13578736941729272, 0.18158552476337977, 0.09805539410029139, 0.13521721001182282, 0.15391292609274387, 0.10164000639425856, 0.16317239137632505, 0.12482273206114769, 0.09237247332930565, 0.1310267270143543, 0.12689895422330924, 0.09783854787903172, 0.14344262863908494, 0.17731479821460588, 0.15095040148922376, 0.26042966544628143, 0.1082262811916215, 0.09398328832217626, 0.14370999857783318, 0.1566356157085725, 0.102831106765994, 0.15241784203265393, 0.2293071097561291, 0.08736858290753194, 0.16050587088934012, 0.12938004466039793, 0.20071190702063696, 0.16735181425298962, 0.13239193947187491, 0.12967070192098618, 0.18534819143159048, 0.12082622865481035, 0.09159465506672859, 0.10790922891880785, 0.14608563110232353, 0.06525898072868586, 0.1458288055977651, 0.16337432339787483, 0.14389249735644885, 0.1536260550575597, 0.12269484624266624, 0.136673916131258, 0.14484735897609166, 0.164998912651624, 0.16818995427872452, 0.17691056776259625, 0.16127380968204566, 0.11900707626981394, 0.08881397784820624, 0.21023815870285034, 0.06431203082736049, 0.11223809913332973, 0.15283371614558355, 0.14757209776767663, 0.11448051487760884, 0.09103571863046714, 0.12270102091133595, 0.07994849035250289, 0.16780221222766808, 0.14397907842482838, 0.10878844066922154, 0.10154497077954666, 0.13079894280859403, 0.11957829418991293, 0.16845637426844665, 0.19709205840315136, 0.07464328288499798, 0.16172671823629312, 0.09940780260201011, 0.16280166698353632, 0.09230453161788837, 0.12378198147884437, 0.13561705712761196, 0.1773121790694339, 0.2462097427674702, 0.20721413168523992, 0.10451670988862004, 0.14420843683183193, 0.2322242675083024, 0.16567697269575937, 0.11510286719671317, 0.14958852742399487, 0.19148266368678638, 0.09491688465433461, 0.11993466078170709, 0.14497845194169454, 0.15105930635971682, 0.11044704488345555, 0.08727435474949223, 0.09410698525607586, 0.1282630945955004, 0.12243131681212358, 0.10357254198087112, 0.16251107757644995, 0.25475076160260607, 0.14442085900477, 0.10483752803078719, 0.14699830141450676, 0.12020884321204253, 0.1096466314047575, 0.13360551292342798, 0.1612207753849881, 0.0824270634246724, 0.12710959863449844, 0.1704417813037123, 0.0628749140139137, 0.08305421298635857, 0.13254972600511142, 0.21080504756953033, 0.1048966623576624, 0.09866009772356067, 0.24862318326319965, 0.10069271044007369, 0.09211022632994822, 0.13792626107377665], [0.05270731781742402, 0.039463830779173543, 0.04056397692433425, 0.060366831453783174, 0.0009057494670352233, 0.045296616187053065, 0.03970371326431632, 0.01740306955096977, 0.01018496330029198, 0.01942028970058475, 0.07301428993897778, 0.10735160205513239, 0.03592636988365224, 0.037037515081465244, 0.03263227914326957, 0.0028340085866927567, 0.018723841357444013, 0.029419039243033955, 0.04102181503549218, 0.0061538999850329545, 0.010396902017029268, 0.06636110480342593, 0.06539333744772843, 0.04231569649917739, 0.04602495228339519, 0.04025922649140869, 0.041541722137480974, 0.016128597581493, 0.01488529920711049, 0.0304023450506585, 0.010235587949864566, 0.03812300826289824, 0.03283387528998511, 0.006895406870171428, 0.06328413848366056, 0.06928555002169949, 0.05537236588341849, 0.05963503822152104, 0.024746681031371866, 0.011770774277725389, 0.01501314707898668, 0.03860387924526419, 0.017751363272379552, 0.027240912995434234, 0.015549751231446862, 0.02367673478355365, 0.01049217681533524, 0.03355968723605786, 0.04359684864591275, 0.030852817664188997, 0.02555367460341326, 0.011918403141732727, 0.05540113237553409, 0.053463246540299485, 0.052935017206306965, 0.023703199345618486, 0.013428083338242556, 0.013583623920567334, 0.0653404388576746, 0.03273614928392427, 0.07982283923774958, 0.014834904411275471, 0.042679540546877046, 0.012163487445962216, 0.008209403504484465, 0.058965561645371575, 0.06733535895390169, 0.0240677914781762, 0.023420492819111263, 0.006711421251696135, 0.010347992364716316, 0.06497457277561937, 0.0739741659324084, 0.017493899944903593, 0.07098403173897948, 0.011634545650200119, 0.047155364483062706, 0.004839236690064094, 0.0395966404383736, 0.008272403784628426, 0.014200583582610955, 0.019585867512172887, 0.03791117302275129, 0.02426459886399763, 0.02671743679924735, 0.019856467277609875, 0.04647198811705623, 0.03958794501210962, 0.04061172204092145, 0.027931661644418324, 0.023112415868256773, 0.018918267085349987, 0.04631538562742727, 0.014177107967303267, 0.08739362084972006, 0.037389949562826326, 0.04986802874399083, 0.023350868340847746, 0.03269928108368601, 0.039054796299231906, 0.03154164945174541, 0.03293186253202813, 0.06903894325452191, 0.0057883371233141846, 0.07061812494482313, 0.01344192460445421, 0.024479528223829608, 0.013180507962325854, 0.015190439797671778, 0.046736911937062225, 0.020150551140042286, 0.01791266292067511, 0.05752446183136531, 0.019696137934390987, 0.03104573195534093, 0.03345448377409151, 0.07067244167306594, 0.016802618645929863, 0.057867176298584254, 0.08228372968733311, 0.013919112838006445, 0.01970316925352173, 0.024293127868856703, 0.0036558885809167153, 0.006133464206608811, 0.08379879660372223, 0.0289130692503282, 0.044159211684018373, 0.002027881207011108, 0.0432929463817605, 0.018108296440914273, 0.02140629554300436, 0.03357031987980008, 0.038350938353687525, 0.02395156691116946, 0.05787418556532689, 0.05255151939179216, 0.010955277813731559, 0.03227215346747211, 0.04084681746150766, 0.03994161103452955, 0.06822044681757689, 0.024278139030294757, 0.025263611060966338, 0.009881579267260219, 0.03575312293001583, 0.01695528732878821, 0.03496663638257554, 0.039958934033555646, 0.02836336089032037, 0.027091367269999216, 0.04757005115970969, 0.02500476691472743, 0.016358103569863097, 0.0432253710792533, 0.03798489924520254, 0.025972832825833132, 0.0643966712855867, 0.07268426407660757, 0.0384149072425706, 0.04995673701965383, 0.0486890741490892, 0.041099442834300656, 0.026148028871310607, 0.01987326441199652, 0.026722188240715435, 0.005497755773831159, 0.046993018194500885, 0.03091377385758928, 0.046261628690574846, 0.018437854114121625, 0.030851942354014943, 0.033132756394999366, 0.061527825226741176, 0.016458153558362807, 0.01711159635202161, 0.024152172396757772, 0.0187568317300507, 0.052100341101842265, 0.04532582372693079, 0.04434255523873227, 0.018871336210785166, 0.016996810279254402, 0.01463057885744742, 0.007857152227578419, 0.05297528486698866, 0.04206218224550996, 0.1291324608027935, 0.03564556155885969, 0.02142066691469933, 0.03088135684707335, 0.02041744440793991, 0.01830190623046032, 0.057978659602148194, 0.04451713212100523, 0.048818711657077074, 0.021325649959700446, 0.066423618234694, 0.021973920620179603, 0.03143735522670405, 0.016368427480171834, 0.0672822907300932, 0.04779887691672359, 0.04095938642110143, 0.046664535999298096, 0.08058728357510907, 0.0581183699624879, 0.013870493259413965, 0.009815447548005198, 0.0375687842523413, 0.11817090399563313, 0.0364530725138528, 0.04157980152272752, 0.045437843073159456, 0.05862166652722018, 0.018755257528807436, 0.02154769715187805, 0.06877280146415744, 0.039652215849075995, 0.03210472155894552, 0.044184317479708364, 0.024750772597534314, 0.04333007921065603, 0.03109874589634793, 0.03896157576569489, 0.03268424814034786, 0.012102031681154455, 0.04389139391215784, 0.044240388220974376, 0.02024808037094772, 0.03849108636911426, 0.05983101949095726, 0.022257402372945632, 0.037513157951512506, 0.060476347005793026, 0.014341889348413264, 0.05036819386961205, 0.023426029664863433, 0.04377558494785002, 0.004359504798360701, 0.033707285565989356, 0.00701988157483616, 0.03952608297445944, 0.051427522740725956, 0.013014181217710887, 0.027617801878867403, 0.02233143732883036, 0.027221500108550702, 0.03556764538266829, 0.014892406861430832, 0.02140409708954394, 0.026881889939042072, 0.013047956146432884, 0.017119601368904114, 0.08745632427079336, 0.04146665920104299, 0.01772527868992516, 0.029334232543728182, 0.05000020058027335, 0.02710105335739042, 0.1167130172252655, 0.03642428905836173, 0.02091140772349068, 0.05219824691968305, 0.014649952728567379, 0.04289771330409816, 0.03145738558045455, 0.013058637135795184, 0.0240075986366719, 0.0388657835844372, 0.06483480813247816, 0.03210562740319541, 0.05597747662769897, 0.05052101013383695, 0.02405622584878334, 0.05253934308088251, 0.04626952683819192, 0.03369920082124216, 0.04005235812759825, 0.021239988306271176, 0.010772523736315114, 0.029897284294877733, 0.012160430645703204, 0.04568905370043857, 0.012942009688621121, 0.05178971116298011, 0.041002666777265925, 0.007245295148875032, 0.06260822261018412, 0.032753607989954095, 0.03291910268100245, 0.06123328674584627, 0.013699345523491502, 0.03423323502231922, 0.054347326779471974, 0.04706041368522814, 0.03181263937481812, 0.00770660990383476, 0.012915579901475991, 0.012738512795684593, 0.03326088755524584, 0.031568539794534445, 0.02504256640427879, 0.03633069872323956, 0.02067196967878512, 0.012353034507084106, 0.030689497677875415, 0.01866218288029943, 0.11565642963562693, 0.014401306963658758, 0.010333582825426544, 0.022824104642495513, 0.04349395898836, 0.0400139767942684, 0.010929602048625904, 0.02159863307939044, 0.03553459054923483, 0.03948258887976408, 0.04360114377258079, 0.03124672081321478, 0.010167176352946885, 0.05132405972108245, 0.02347237869564976, 0.0573681341484189, 0.08368018868246249, 0.060898972542158196, 0.03301927141313042, 0.04794990524117436, 0.00538516221734296, 0.0934241008279579, 0.05124238446088774, 0.0553528308602316, 0.023126822863040224, 0.0435346201993525, 0.022929951016392027, 0.028140791226178408, 0.02473595508906458, 0.049748443732304234, 0.024319288786500692, 0.04163970937952399, 0.015443621569180062, 0.021753617262999927, 0.04501369083300233, 0.04514512985146471, 0.08179956102477652, 0.05334850287597094, 0.008370039884799292, 0.022988729112382447, 0.04682543022292001, 0.06431241759232112, 0.025374972228226916, 0.022547508323831216, 0.12602654817913259, 0.20257555773215635, 0.1424576129232134, 0.1443321066243308, 0.12128900310822896, 0.11385752473558698, 0.14316233939358167, 0.1096762969557728, 0.07600320276937314, 0.1040485817939043, 0.21088925376534462, 0.3308019164417471, 0.16271834288324627, 0.10776847361453942, 0.10567161041711058, 0.16253076866269112, 0.12725416730557168, 0.1881389245390892, 0.12815699885998452, 0.14193940215877124, 0.10580209948654686, 0.1655070268149887, 0.169040267222694, 0.16415621287056378, 0.07947232161781617, 0.17324840570134775, 0.13137193849044188, 0.08582079703254358, 0.13612076081335545, 0.213418398052454, 0.11788722207503659, 0.11034704239240714, 0.12207161182803766, 0.07684449119759457, 0.21005548350512981, 0.15659664065710135, 0.1706959062388965, 0.15364912524819374, 0.1666248454047101, 0.07925294446093695, 0.11346189132226364, 0.17603231274655887, 0.08398755147520985, 0.09431251351322446, 0.11514288719211306, 0.0879291206864374, 0.13672887746776852, 0.09008646171007838, 0.14544438836830004, 0.12580240092107228, 0.12464951564158712, 0.1337758387838091, 0.2024736146309546, 0.07799635188920157, 0.14356275647878647, 0.17674358029450687, 0.11440702953508922, 0.1481463826660599, 0.1255117572311844, 0.09910511491554123, 0.15373478350894793, 0.09329952179853405, 0.1429666363235031, 0.06477513776293822, 0.09548318998089858, 0.10438497910009963, 0.11991399260503904, 0.18457624928227492, 0.06662533991038799, 0.1110955954396299, 0.07590381095984153, 0.15228227073592798, 0.1509452581937824, 0.08408324526888983, 0.18520047435803072, 0.10583390242287091, 0.0923394626006484, 0.10059940508965935, 0.14261181679155144, 0.07061319199523755, 0.16335338380719933, 0.09983483183064631, 0.13370664178260735, 0.11750775815120765, 0.2527565743241991, 0.1394226886332035, 0.1429976046617542, 0.16470418418092386, 0.10719678750527756, 0.18483318335243634, 0.05130765274433153, 0.1255291820104633, 0.10870031254099947, 0.15855235499995096, 0.20967470322336468, 0.17527630259948118, 0.1210664300514119, 0.1370259943817343, 0.18037321338696138, 0.13260715720908983, 0.12428347314042704, 0.06316751867000546, 0.08720069298786776, 0.12275530371282782, 0.161676465932812, 0.1000721494534186, 0.11947846811796937, 0.15820152525390896, 0.07730552181601524, 0.12806346959301404, 0.12277603974299771, 0.09626462483512503, 0.12772116224680627, 0.11248429877949612, 0.11878847942820617, 0.09683814298893724, 0.10248089448681899, 0.13494822515973023, 0.11855293278183256, 0.13289083912968636, 0.09859734001968588, 0.08664199403886284, 0.12107047412012305, 0.15476477252585547, 0.13580095368836606, 0.22030489066881792, 0.12227498234382697, 0.10858991489346538, 0.15120368504098483, 0.12509358966989176, 0.08481528277375869, 0.054733151969100745, 0.14577773905226163, 0.07436617596873216, 0.10485476282026086, 0.16730249832783425, 0.13309286614613874, 0.1502928060612508, 0.06170289404690266, 0.0913193326975618, 0.15134320541151933, 0.14391258199300083, 0.10085736374769892, 0.09695007412561349, 0.1496249240423952, 0.12067681524370398, 0.07170039508491755, 0.134645707107016, 0.09342734422534704, 0.11742417620761053, 0.10659185996545212, 0.21974864123123033, 0.060135864918785434, 0.13368346302637032, 0.11608651227184705, 0.3085731906550271, 0.09812412969768047, 0.10987632907927036, 0.12916995664792402, 0.11246447198625122, 0.16770663378494127, 0.10233239709798779, 0.10202276799827814, 0.12589715155107634, 0.10256012702094656, 0.14364412639822277, 0.19185813782470568, 0.09491293558052608, 0.08516992588660546, 0.1694676357188395, 0.07010186836123466, 0.13836572106395448, 0.16528514586389065, 0.15650456345507077, 0.05017060786485672, 0.08759505754070622], [0.023305029907662953, 0.03046350141188928, 0.01859335907335792, 0.032151207993073125, 0.030173861953829016, 0.01887078320474497, 0.06147189358515399, 0.028107598989403675, 0.02264710539020598, 0.019387726805039814, 0.03648933681792446, 0.04604407000754561, 0.03357611456885934, 0.005090103808990014, 0.03231960342132619, 0.05257491867191025, 0.036069343997431655, 0.019569898190508996, 0.05149256032226341, 0.055649079249373505, 0.014633466023951769, 0.006251075105475528, 0.0011908200519558574, 0.03617252203236733, 0.01265456189867109, 0.02537675847166351, 0.03968073806858488, 0.059200022635715346, 0.005916523838615311, 0.03469332926241415, 0.054968607013246844, 0.028445631564993943, 0.09671051733727966, 0.021190782643056343, 0.016046041922111596, 0.055445946220840724, 0.04816245633576598, 0.060580583555357795, 0.05811182888490813, 0.05610747715192182, 0.0401248256675899, 0.05518683744594455, 0.046203281464321275, 0.038506431438560994, 0.02589225339969354, 0.026164155952366333, 0.05244035499968699, 0.04168585315346718, 0.06262075515197855, 0.02680992621130177, 0.03568609045552356, 0.013363206060603261, 0.01819139832098569, 0.055601761609848054, 0.04627964718799506, 0.052410774265549014, 0.027294646183561002, 0.037929194912846596, 0.03757542032482369, 0.06673226345862661, 0.029028399847447872, 0.03282597374969295, 0.037831950666649, 0.036486707494727204, 0.0700635447033814, 0.043302164279988835, 0.03800837655684777, 0.03688172683385866, 0.026848850372646536, 0.040625462375049076, 0.07370787486433983, 0.02393881554183151, 0.0573997131681868, 0.0194879141968808, 0.009200672768721623, 0.03704397473484278, 0.03758393593930772, 0.03592017485893198, 0.09262233027922255, 0.017583369876125028, 0.007955931659255708, 0.03533094522676297, 0.01934646169788071, 0.08140219734715563, 0.04668375211102622, 0.013098283936934811, 0.040813962795904705, 0.07835609758538858, 0.03532840072044304, 0.023835886868515184, 0.05225998342835477, 0.04292720243600862, 0.06363869338695492, 0.009844984177366962, 0.018151139141991735, 0.034373237152716944, 0.031117229190255915, 0.05970176535525492, 0.030997335445135832, 0.05945876160902636, 0.01359278244698154, 0.028128704821158732, 0.057345260732940266, 0.044630135343010933, 0.08851433678397111, 0.02421802930933024, 0.053264082941625795, 0.07592730184218713, 0.053379813874406476, 0.030005093331315687, 0.018737464644280926, 0.0701051117586238, 0.03757284189175282, 0.048583806226296086, 0.03061896057001182, 0.05026592846427645, 0.03585129676918898, 0.013532713438118142, 0.020982964330219796, 0.021289280482700894, 0.09207661849047456, 0.09959070850163698, 0.02171647934509175, 0.032396559470466206, 0.06895818401660238, 0.03377180067556245, 0.014109731136289026, 0.06777436432561704, 0.031763862885002575, 0.00850281392091087, 0.029865325295499394, 0.023658794317660586, 0.008145210699045231, 0.01419873203017882, 0.030779105012438128, 0.0342543781735003, 0.0311720073223114, 0.03850872488692403, 0.02434773467081998, 0.02070199146068522, 0.012640950486197003, 0.02479285025037825, 0.04453617859897869, 0.009021583628574652, 0.04131965458925281, 0.03160793214504208, 0.018289292264463644, 0.029334110407424823, 0.05156642225171838, 0.00922840619127133, 0.07878846009927136, 0.04532419524288603, 0.04081252430166517, 0.037706706672906876, 0.05717339459806681, 0.025905701963763152, 0.031224719315235103, 0.007649204144919557, 0.06984735666108982, 0.053339661564677954, 0.020194180941741382, 0.01492219285241195, 0.0395489971020392, 0.03944949672690459, 0.03671358585623758, 0.038080484473279545, 0.026311370910012295, 0.029185233038983176, 0.041342395690402815, 0.05853853241673537, 0.04575976722740701, 0.009517345910093613, 0.018318715239209787, 0.041140558663755655, 0.036488020459988287, 0.043665896369410415, 0.015748482264046158, 0.009846572797479374, 0.030619096277015548, 0.02538278216629156, 0.030120746232569218, 0.06457091907837562, 0.06721645926258393, 0.095151440639581, 0.039459209955696545, 0.02271267901440816, 0.021764019204835807, 0.05217959738469549, 0.03097343065642885, 0.015104869746470025, 0.0768990454130939, 0.013909392823864306, 0.012177511916628905, 0.048653356065707545, 0.05249325358974082, 0.05218798407752599, 0.03217059373855591, 0.02688960318586656, 0.062114378038261614, 0.06009348362152066, 0.0550196871294507, 0.01949987337658448, 0.05385806571160044, 0.008706872301575328, 0.06942217983305454, 0.07519865022706133, 0.013745465548709035, 0.021751764862399017, 0.03849821098681007, 0.04598451159628374, 0.027481434999832084, 0.04239195365724819, 0.02841581673627453, 0.04328783701307007, 0.043472530852471075, 0.04168361738058073, 0.026794981477516036, 0.04671969071828893, 0.007772471905419869, 0.0728927914585386, 0.02511546651034483, 0.033031617357794724, 0.06392211746424437, 0.08434223530015775, 0.0469619378979717, 0.008782475521521909, 0.017779549617054205, 0.0449993974928345, 0.013573048104132925, 0.048706763557025363, 0.03969643597624131, 0.02359882539271244, 0.009482131638963307, 0.007763893526446606, 0.029584449117204974, 0.06962924836469547, 0.03699315246194601, 0.035894950319613726, 0.04378772054665855, 0.00932705246045121, 0.03371233047385301, 0.024174823592017804, 0.052204635326883624, 0.016316541603633335, 0.010105090398740555, 0.01201944803220353, 0.03584201101745878, 0.05035143744732652, 0.03941131895408034, 0.0221906226527478, 0.055276068193571906, 0.04491799703932234, 0.014982265253950442, 0.007432836290848042, 0.01666435186884233, 0.02699997538833746, 0.04239249309258802, 0.026968850987032056, 0.029736366322530166, 0.0637364974245429, 0.026309528687436665, 0.042241257814956565, 0.02827280869574419, 0.02728820518989648, 0.04812101820217712, 0.006167249313356089, 0.18369401805102825, 0.03229355785463538, 0.03494942873450262, 0.02299146700118269, 0.01568485433900995, 0.02897098221416984, 0.026388231964249696, 0.05999534031642335, 0.021425878063642552, 0.03159411038671221, 0.04526567838287779, 0.03406944006149258, 0.050566987666700564, 0.02695907329741333, 0.08369110631091253, 0.02036075619980693, 0.016572932845779827, 0.017811488260381987, 0.01761798025108874, 0.003222708432336471, 0.06060418300330639, 0.056822700559028556, 0.010404276844513203, 0.033623547559337955, 0.05690224521926471, 0.03398328647017479, 0.04130725436178701, 0.05731974781623908, 0.019628213186349188, 0.05846394106213536, 0.026015419379941056, 0.02614298226710941, 0.05338941853759544, 0.012011469308552998, 0.027374828666714684, 0.02579925169370004, 0.01501670090614685, 0.042193906248680184, 0.035525623708963394, 0.019689963265721287, 0.06005034236503499, 0.041487466477389844, 0.014937548099883964, 0.010068081402485924, 0.032726463196533065, 0.0848328432600413, 0.023884648091292808, 0.04723955710817661, 0.004042262111657432, 0.07784418362591948, 0.04449274217975991, 0.04144490536834512, 0.048731628472783735, 0.03029341982411487, 0.07271618236388479, 0.05143124111262815, 0.04968970295573984, 0.06368842321847167, 0.030257817091686384, 0.08594550498362098, 0.004290341723909867, 0.060083074894334586, 0.027735130761616995, 0.03296080205057349, 0.03264613822102547, 0.08442487408007894, 0.03683143721095153, 0.015259138075634837, 0.03235571166234357, 0.024900699998917322, 0.018106401631874696, 0.0259579135371106, 0.02448250020721129, 0.07601153517940215, 0.03296523966959544, 0.00814804358274809, 0.018203028411205326, 0.025862664183867828, 0.030034494253673723, 0.03595327379714165, 0.027600041224754283, 0.026357679228697504, 0.06573749719453709, 0.020409529296947376, 0.009771102740030204, 0.062308995452310355, 0.11885897921664373, 0.08138026709535293, 0.07715259359351226, 0.1487459090671369, 0.1622981939996992, 0.2637347009565149, 0.09501719927149159, 0.1190719577882971, 0.14637840539216995, 0.05572690043066229, 0.08315249199845962, 0.18094132361667498, 0.09891505725681782, 0.07981051704181091, 0.16611435636878014, 0.14358911077891076, 0.16469666601291724, 0.11745693587831088, 0.17114493357283728, 0.12353823812944548, 0.10179570982498781, 0.08908355302576508, 0.20237708623920167, 0.14367984448160442, 0.07414948581052677, 0.07044932578823396, 0.15480317760791096, 0.21348439236836775, 0.24890944361686707, 0.2394309336585658, 0.17140113482517855, 0.11425961101693766, 0.1445398876177413, 0.0931122936308384, 0.08257593400776386, 0.12374193434204374, 0.1411097709621702, 0.15602363140455314, 0.11953398585319519, 0.13488043951136724, 0.11711317646716322, 0.24375624156423978, 0.15439455024898052, 0.14286188408732414, 0.08558688565556492, 0.15083433128893375, 0.16118836855249746, 0.16104519766356262, 0.1484250569982188, 0.11466996185481548, 0.0922548696398735, 0.11141006249402251, 0.08121028050248112, 0.15163023929510797, 0.09819812394146409, 0.11919633325721536, 0.10321708462600197, 0.11670586546616894, 0.11581093205937318, 0.18487792595156602, 0.16818380675145558, 0.09443894494324923, 0.11538231505879334, 0.11001680618418114, 0.09166671548570905, 0.12412392241614205, 0.156700945060168, 0.11314962950668164, 0.23299429618886539, 0.11973332587097373, 0.13477058469184808, 0.1175242465521608, 0.165089076384902, 0.07980593014508486, 0.1337801678372281, 0.14816652158541338, 0.13852171626474175, 0.0716872111495052, 0.15652740294379847, 0.0864011412486434, 0.05118433239736727, 0.10892312987042324, 0.12900235849831784, 0.21091543164636406, 0.13296488087092126, 0.22579904299761566, 0.09562429812337671, 0.1505687798240355, 0.07843212064887796, 0.05627206599872027, 0.36506899339812143, 0.1093535924862538, 0.1178341063537768, 0.11232870391436986, 0.10162935339446579, 0.08537405636161566, 0.11126526990639311, 0.1461647618561983, 0.12615232143018926, 0.1853430617068495, 0.16007683319704874, 0.13319262436458043, 0.10782426954912287, 0.1093470717647246, 0.16464877501130104, 0.13132410177162715, 0.12235431665820734, 0.06435994218502726, 0.11586251429149083, 0.05455508741683193, 0.13773874113602297, 0.12265779823064804, 0.07675086693572146, 0.15861461737326213, 0.12621769149388584, 0.16837511291461332, 0.19296822111521447, 0.14448781684041023, 0.12781652355832712, 0.07364023849368095, 0.20490845612117223, 0.18205161046768936, 0.12251762646649565, 0.07755704117672783, 0.1649345061076539, 0.13088104554585048, 0.13305068840937956, 0.14156413158135756, 0.11726955164756094, 0.13312097106661114, 0.1908002338771309, 0.15240744687616825, 0.1292463732617242, 0.07294764422944613, 0.10869107089404549, 0.11226980707475118, 0.14192433868135723, 0.08394095647547926, 0.11374220770916768, 0.10674318684531109, 0.17012828455439635, 0.14427691458591393, 0.16458341851830482, 0.07919967267662287, 0.14572465047240257, 0.09917054604738951, 0.0746401616239122, 0.12790205968277796, 0.10654599778354168, 0.19809586953903946, 0.22911929126296723, 0.11031865927257709, 0.139840123376676, 0.13641059026122093, 0.12509189333234513, 0.1127147428425295, 0.10454305740339415, 0.09736537826912743, 0.1718440553439515, 0.19818739034235477, 0.10618549891348396, 0.11430195160210133, 0.1085004432659064, 0.2075567375868559, 0.13483440769570215, 0.11276110035500356, 0.10689897848559277, 0.10044756930853639, 0.12875082556690487, 0.11888940472687994, 0.10770448097693068, 0.13877694042665617, 0.14636862091720104, 0.09779297068182911, 0.11525464190968446, 0.13587366550096444], [0.033504997313554795, 0.01028259176694389, 0.08428994060627051, 0.0296551728221987, 0.01124571539860751, 0.019589572313374708, 0.01553211101729955, 0.03175458052594747, 0.04917556679408465, 0.07677120941558055, 0.03074571430417044, 0.042705806637448926, 0.024251657504854456, 0.05451058230495878, 0.06274690838264567, 0.008890769710498196, 0.014601462919797217, 0.06807215977460146, 0.024935805704444647, 0.044467643169420104, 0.03792022807257516, 0.06734853610396385, 0.05908174041126456, 0.052725882535534244, 0.05500715458765626, 0.018572953829009618, 0.046186352015605996, 0.04649902434487428, 0.023391113949141333, 0.03959123929962516, 0.006734851914058838, 0.01428274653985032, 0.02025281824171543, 0.07515401619353465, 0.035978477980409346, 0.021994319079177718, 0.055237398482859135, 0.025787552053640996, 0.040141178361539326, 0.09609885194471904, 0.0239048565604857, 0.03055403833942754, 0.05736399508480515, 0.0453014711051115, 0.0409905311784574, 0.021656454441004565, 0.04213751320328031, 0.035254118099276505, 0.023555997958672897, 0.06096525862812996, 0.0034945195948239416, 0.05332816718146205, 0.021670627341206585, 0.056338362262717316, 0.03766800982079335, 0.04512265677164708, 0.012344294976043915, 0.03574776589604361, 0.04551557604489582, 0.019290833700714365, 0.04680169167529259, 0.007865165726148655, 0.0563601059173899, 0.025498433371207545, 0.02753226745075413, 0.011784087134791272, 0.01914890283452613, 0.024774287228605578, 0.04689614035721336, 0.03940399416855403, 0.03480082956541862, 0.054809049503611665, 0.01905708177946508, 0.028223677671381404, 0.0798119283946497, 0.040000256816191335, 0.05026188100289021, 0.01621324991408203, 0.03908860769921115, 0.01696715660260192, 0.043794098775833845, 0.0373447285965085, 0.02936786413192749, 0.051348239316471984, 0.04022185617525663, 0.04485473382685866, 0.08168979441480977, 0.045602543878235986, 0.020156948028930595, 0.023760566088770117, 0.03193693681220923, 0.07956817825990063, 0.06174040346273354, 0.07341544662735291, 0.05337198358029127, 0.046126132032700946, 0.04075434670916625, 0.06458303771380867, 0.02355350603881691, 0.03226767174367394, 0.03656543791294098, 0.024814863622720753, 0.029800650730196918, 0.04365461911740048, 0.04147200944966503, 0.022166700900665352, 0.013643589452840388, 0.04063656999330435, 0.02233848730767412, 0.07090203078197581, 0.05261926093537893, 0.001799944754956024, 0.06413932330906391, 0.029318873903581073, 0.027890430464010154, 0.07444809550153357, 0.04964580174003329, 0.04718895196648581, 0.057794627334390364, 0.06205816141196659, 0.03260977892205119, 0.03445744674120631, 0.024689212507967438, 0.044416423953537426, 0.014638551643916538, 0.024047041877305934, 0.04481097510350602, 0.026027783984318376, 0.005974411357393754, 0.03656910200204168, 0.07998557907662221, 0.05502533254080585, 0.06294634339532681, 0.018332177373979772, 0.029132741569940532, 0.046978148099567206, 0.019043504293741922, 0.018364250027973737, 0.07298080423580748, 0.014175967180303164, 0.04354243692276733, 0.024138465989381075, 0.020274304053080932, 0.030376265557216744, 0.03747789448659335, 0.02907780398215566, 0.033788872616631646, 0.04775762877293995, 0.028580431028136184, 0.030173610895872116, 0.025137232217405523, 0.03219321270340255, 0.022626925758751373, 0.026239042469699467, 0.016647780347349386, 0.008836012782662042, 0.010350052566666688, 0.03804282917241965, 0.02033606091780322, 0.023763685653518354, 0.019990418571978807, 0.027914219901763966, 0.016011302625494342, 0.0468356761017016, 0.01690577293213989, 0.027018144859799316, 0.02331262101818408, 0.07340589963964053, 0.04675231807466064, 0.04914929731083768, 0.013884568620207054, 0.019349391272823726, 0.040879607666283846, 0.04864346981048584, 0.01646592956967652, 0.04383793553071363, 0.05653809583080666, 0.012830943684093654, 0.05450874686773334, 0.04536662403760212, 0.06544057027037654, 0.015341296792030334, 0.011690573983027466, 0.0427603404968977, 0.17078962549567223, 0.03465835417487791, 0.051362379986260615, 0.005989437091297337, 0.039556420275143216, 0.0743128906137177, 0.022365447200302566, 0.08578375580587558, 0.017823196382128766, 0.01822259396846805, 0.04724784880610449, 0.04379308097330587, 0.0013497405868422771, 0.08935145222182785, 0.06089312357029744, 0.021814276597329547, 0.035874950499939065, 0.04862683891717877, 0.00271985842846334, 0.023011733145852174, 0.027176039958638803, 0.04880734280283962, 0.0192149344698659, 0.04617253704262631, 0.021406219207814763, 0.024730966160339967, 0.028967491151498895, 0.005662556662822941, 0.026083713929568018, 0.00599339252637167, 0.022668596290584122, 0.05531481593581183, 0.023873738944530487, 0.04288355227825897, 0.02180107569854174, 0.06867720266538006, 0.014600370478417193, 0.05065346695482731, 0.01090273036554988, 0.03252873130674873, 0.09151344121034656, 0.015258924337103963, 0.1124401329351323, 0.021938736883125136, 0.013600228520642434, 0.03040302697835224, 0.024396770700280155, 0.038614620454609394, 0.009885631817659097, 0.0053177730878815055, 0.02084485361618655, 0.015926482355488197, 0.02058723592199385, 0.03389689878427556, 0.053716302782829316, 0.04319538661677923, 0.03010711107136948, 0.015271312690206935, 0.03705996101988213, 0.04641238220834306, 0.030750928845788752, 0.027494266097034727, 0.033491830341517925, 0.022350882446127276, 0.03077795828825661, 0.03622480994090438, 0.049734954456133504, 0.014565585380686181, 0.052305041546268125, 0.06332898286304303, 0.01340329899851765, 0.03099407847704632, 0.025194017116778662, 0.038600496748196225, 0.031665597443601916, 0.017550966436309472, 0.023048893116148453, 0.03179113660007715, 0.040384433165724785, 0.01602958405523428, 0.012765029944213373, 0.05270372497450028, 0.053167388308793306, 0.08512985160840408, 0.047857142718774934, 0.05706552110080208, 0.032829542843891044, 0.007623705647087523, 0.022537557607782737, 0.02737687953880855, 0.029235366598836014, 0.0505274596091892, 0.03868042478071792, 0.020685034870569195, 0.02997622505894729, 0.07021015576486077, 0.010649131295005125, 0.023542649478518536, 0.025980354386514852, 0.022732117346354892, 0.040792989278478284, 0.05719432740339211, 0.08744417170860938, 0.02828173482391451, 0.0024189387498024318, 0.031677044329366515, 0.04892207968181797, 0.035265042513076744, 0.10505421140364238, 0.03177957436335938, 0.015458306763321161, 0.02794523404112884, 0.026640725022714053, 0.04099591535383037, 0.0050554641722036255, 0.014417790275599276, 0.04457412227722151, 0.07223807980439492, 0.01771124658573951, 0.028187491398836886, 0.023422297722260867, 0.024037778177963834, 0.021620885635327016, 0.03000190421672804, 0.08955696690827608, 0.03449082727144871, 0.02015759433353586, 0.053686202969402075, 0.05649759068286844, 0.033538092859089375, 0.01429280242882669, 0.07906126510351896, 0.044110462335603576, 0.07804448716342449, 0.03529998028118696, 0.051128672169787545, 0.043852649562593014, 0.03353072736146195, 0.02406838010730488, 0.0017806368289581898, 0.024577522251222814, 0.03850050104249801, 0.02728720265440643, 0.027459998382255435, 0.023118234306041683, 0.012352725773650621, 0.043392372118043046, 0.038848012752298794, 0.021232912882364223, 0.06294954608061484, 0.07202052112136569, 0.007229818613268435, 0.01681385518583868, 0.049981985307697735, 0.018756451750440255, 0.024363149290106127, 0.025864343558038985, 0.08537374423550707, 0.0302274865763528, 0.01820584263519517, 0.03909816486494882, 0.07166121647294078, 0.016833371549312557, 0.040701868810823986, 0.035328726417251995, 0.020077908877283335, 0.039280517758535485, 0.08044742393706526, 0.13953426693167004, 0.10964237699019057, 0.15804767422378063, 0.09625607529389006, 0.1198269637035472, 0.1389140316418239, 0.08856039574103695, 0.1430095468780824, 0.18393588864377566, 0.11403399812323706, 0.2035347619759185, 0.09674027788319758, 0.15118250117770263, 0.13576482848397323, 0.1687716759209122, 0.08856507763266563, 0.06735321121024233, 0.13996984570154122, 0.12678846158087254, 0.18047967553138733, 0.16188272700778075, 0.14260253443249635, 0.14657656475901604, 0.12852047649877413, 0.12200867091970784, 0.13863159822566168, 0.10452748502471618, 0.12288490390138966, 0.07023442696247782, 0.08497840937759195, 0.14095009810158185, 0.1655005943030119, 0.12431437362517629, 0.1308096908032894, 0.10275264776178769, 0.09794121022735323, 0.12930293594087872, 0.1167499159595796, 0.10622427718979971, 0.11550276859530381, 0.09003652153270585, 0.14511732091861113, 0.07347747151340757, 0.11666925171656267, 0.14796798223895685, 0.09147052387041704, 0.16874889071498597, 0.12633035544838223, 0.15939497335680894, 0.08510131242551974, 0.1533939689397812, 0.16585413818912847, 0.10298309861017124, 0.17580330717776502, 0.10981016512960196, 0.12883765090789112, 0.22674975198294434, 0.17820587754249573, 0.15587287449410983, 0.1564605129616601, 0.12637935924742902, 0.11509765604776995, 0.14542103319295815, 0.14214665389486722, 0.12550550113831246, 0.13591145990150316, 0.15919245779514313, 0.12593658800636018, 0.13986431993544102, 0.11632336170545646, 0.10713556329054491, 0.15197068745536463, 0.1672599134700639, 0.07010377504463706, 0.18581921687083586, 0.09452464391610452, 0.16085300940488065, 0.11008174877081599, 0.08983562766973462, 0.14886390630687985, 0.171523406835539, 0.17702948780996458, 0.1404986958950758, 0.10469721377428089, 0.15860770988677228, 0.16611533345920698, 0.12530271416263922, 0.17441494310540812, 0.11331775691360235, 0.11364280232893569, 0.11123666965535708, 0.16947037700031484, 0.14085063843854836, 0.16943801087992533, 0.13663985367332185, 0.12374261287706238, 0.05297704905803714, 0.16077016027910368, 0.07986368704587221, 0.1271248792431184, 0.1256927903741598, 0.10779663281781332, 0.0974688141473702, 0.11461516336670943, 0.16020730191043445, 0.05592023541352578, 0.11243408718811614, 0.12288691236504487, 0.11451735932912145, 0.19493830682975904, 0.13495262206665107, 0.07959251731101956, 0.14681570764098847, 0.09429374523460865, 0.14280319080821105, 0.12498050502368382, 0.1296211960060256, 0.13425662155662263, 0.13232925640685217, 0.1468972268381289, 0.09131809776382786, 0.09904916970325367, 0.09369839860924653, 0.10912660216646534, 0.0820141884365252, 0.14557862973638944, 0.11126452351787261, 0.1409546849983079, 0.1661578911755766, 0.0992797426879406, 0.1580515554440873, 0.2036873237895114, 0.17728041005986078, 0.1317680808050292, 0.10503279683845383, 0.12232382329446928, 0.09658359057669129, 0.07330483184861285, 0.11419624941689627, 0.1742544560027974, 0.1553375239350966, 0.11663546067263399, 0.07846044948590652, 0.13532965683511325, 0.15175354267869676, 0.11673641311270849, 0.12903965078294277, 0.1268964165023395, 0.11421096005610057, 0.22680300341120788, 0.09637245083493845, 0.16429381977234567, 0.060167674640459676, 0.10816965065896511, 0.1374296277229275, 0.1289917869227273, 0.07247298184250082, 0.10538380300360066, 0.0942359883338213, 0.13874979902591023, 0.08624796196818352, 0.1922116952815226, 0.10519745693142925, 0.0753370781562158, 0.16432457097939082, 0.17996487101273878, 0.12196029137287821, 0.13305987577353204, 0.10942850275231258, 0.14728728947894915, 0.061808250179248195, 0.09922495777053492, 0.12544729640441282, 0.09751613517957074, 0.176767926130976, 0.1328157524445227], [0.008183028848309602, 0.05233681055584124, 0.06271519365587405, 0.08836431947669812, 0.028234335760186826, 0.0689464725021805, 0.03599332093394228, 0.05561018901477967, 0.08363849949091673, 0.058350381441414356, 0.026451486695025648, 0.01199538548410471, 0.050736390719456334, 0.010269173736950117, 0.06297753565013409, 0.02069417473727039, 0.03653036783050213, 0.027348701675821627, 0.017533916547628384, 0.06693440582603216, 0.01920616440474987, 0.03842272735866053, 0.030289294331201484, 0.014832042689834322, 0.033199337643704245, 0.013566590147092938, 0.018668286302792172, 0.048552206850477626, 0.02439124572889081, 0.04317262515957866, 0.023965118951829414, 0.0203729189400162, 0.05292496471000569, 0.06387911870011262, 0.05263118618833167, 0.035679888645453114, 0.02655558753758669, 0.018580600918669785, 0.03540499714602317, 0.05228305361898882, 0.040979918890765736, 0.005614168634305575, 0.012961318250745535, 0.04504185342895133, 0.02295074302570096, 0.021223808638751507, 0.05347004885386143, 0.04428803834265896, 0.005211533587758562, 0.0405596851903413, 0.025039083823295574, 0.05495053084035005, 0.015343773444848401, 0.005566193239896425, 0.018682813737541437, 0.020906228804960847, 0.02532416352603052, 0.012428562240009862, 0.03034709533676505, 0.07924741440053497, 0.0435037977461304, 0.030662882141768932, 0.05283000712682094, 0.02284711885399052, 0.0353061345938061, 0.043113911524415016, 0.03761912137269974, 0.05186322703957558, 0.04829159851319023, 0.022447424408580576, 0.02460588331866477, 0.0627574392461351, 0.02780299953051976, 0.013032333725797278, 0.029504867137542794, 0.022615048003249934, 0.0815928385459951, 0.027849022864497135, 0.017839270876720548, 0.01712157081679574, 0.0200464231560805, 0.024798624583386948, 0.10232163553259202, 0.02160248885463391, 0.0371264438810093, 0.019531167411644543, 0.03792047234518187, 0.027506861403318386, 0.042260188941976855, 0.05718535717044558, 0.02581313282384404, 0.027276125570226992, 0.0056465377232858115, 0.03518336046753185, 0.026776772990290607, 0.017697231444929327, 0.03746678686833807, 0.02884366868862084, 0.06991610582917929, 0.06487756262400321, 0.006495919802026557, 0.06465565453150443, 0.017817462761221186, 0.04252941467400108, 0.042067176263247213, 0.009558199655397661, 0.027685823318149363, 0.05716270088617291, 0.01922111931656088, 0.038409360218793154, 0.02403788165455418, 0.024318808722974997, 0.020900301801572953, 0.04726592158632619, 0.01205683870440615, 0.07544710260948964, 0.023252401035279036, 0.0050197244605182535, 0.06099839149309056, 0.00957761678312506, 0.04694008228502103, 0.04651837616360613, 0.04489764098876289, 0.03453785314091614, 0.02753724789779101, 0.05230362680075424, 0.041299681910978894, 0.027077684611348168, 0.03623079461976886, 0.01090284826100937, 0.04879651338394199, 0.015780546436352388, 0.02354091921422098, 0.05201846567381706, 0.057353823844875605, 0.015399528667330742, 0.0756575231041227, 0.0223780815223498, 0.01061215198465756, 0.05643439193123153, 0.043042858729937246, 0.03406429676605122, 0.006814557726361922, 0.018225659250414798, 0.025829605957759277, 0.023663890115650635, 0.04884040102894817, 0.026539594467197145, 0.052102492057851384, 0.03539404219814709, 0.05262166973469513, 0.009395586193672248, 0.010163265446733152, 0.07331485381083828, 0.02829995857817786, 0.07801841784800802, 0.01549862531412925, 0.00680085428757593, 0.019927214731329253, 0.04897646765623774, 0.0028524250873098417, 0.030461509911609546, 0.023911402727078115, 0.027425589871459773, 0.024174969477046813, 0.02936954689877374, 0.01617590673933072, 0.01831308170221746, 0.05525233982396977, 0.006908060700100447, 0.01471812344555344, 0.018490276033324853, 0.04554783359968236, 0.05551209320713367, 0.04271579806559852, 0.03657486954970019, 0.01334204849055303, 0.02247737833697881, 0.03256145365802305, 0.11564337462186813, 0.02018539052057479, 0.032142746661390574, 0.010351256966324789, 0.04275061030473028, 0.010511980708023267, 0.029874410879399096, 0.039752713670688014, 0.002138021435322506, 0.0407248541845807, 0.05997887905687094, 0.019355409878439138, 0.010237267324035721, 0.034495736472308636, 0.04219236597418785, 0.027624320904059068, 0.020742617048589245, 0.06227730108158929, 0.01218923191273851, 0.04339483520016074, 0.051480801310390234, 0.035894665334905894, 0.03902578553450959, 0.02646321178014789, 0.03509739347334419, 0.0724374537489244, 0.0776677577357207, 0.034950605992759974, 0.015042123916958059, 0.028379286107208048, 0.036366440555346866, 0.026047162944450974, 0.02947827535016196, 0.04504546323525054, 0.07191414040114198, 0.0703846410449062, 0.014080750905642552, 0.025691401945160966, 0.024242914581139172, 0.022884066782093475, 0.006381885206792504, 0.01928456742981715, 0.03072812667648707, 0.044953016231634786, 0.04772341364462461, 0.017694300173648765, 0.05211054626852274, 0.01872735786517816, 0.03870107599401048, 0.004619024511027549, 0.005923313005561275, 0.03863246253292475, 0.08547976533217089, 0.002850917255273089, 0.03862329552482281, 0.029916530940681696, 0.03696797542007906, 0.03794896403061492, 0.02991541814325111, 0.06068517294313226, 0.04596369414191161, 0.0912944847451789, 0.01859270259072738, 0.05988683578159128, 0.09403448378933327, 0.1524530580001218, 0.052282107062637806, 0.01582160628666835, 0.05265566094645432, 0.06785063844706331, 0.049713536498269865, 0.10320160045687642, 0.04691348371229001, 0.07094869363520827, 0.03429550078830548, 0.033962122962943146, 0.03768358898482152, 0.025486338484500135, 0.06014876386948994, 0.06993686900074993, 0.018711229087784886, 0.010873847674312336, 0.08728773546005998, 0.06278387497046165, 0.013162017883067685, 0.03215987288526126, 0.051593455086861334, 0.031456069222518375, 0.08266408927738667, 0.03340179892256856, 0.0652806463518313, 0.04795575421303511, 0.03474171220191887, 0.005093062645755708, 0.02675987746832626, 0.02196031260038061, 0.019425502545865517, 0.05664386926218867, 0.02071308550824012, 0.05161500196637852, 0.01890462513880006, 0.01021024551508682, 0.05965335188167436, 0.014585975357996566, 0.0459631954186729, 0.039236104248889854, 0.020626802995268787, 0.016933251904057603, 0.043443645616727214, 0.007976770317847175, 0.041529932591531954, 0.01803905363859875, 0.022261239488476088, 0.09501546222184386, 0.03451317821496299, 0.0466450043687863, 0.09553778490849904, 0.036279913769768815, 0.04763462055208428, 0.024130237055942416, 0.030133112533284084, 0.05889949947595596, 0.03517355563651238, 0.01142901908938906, 0.055038221313485076, 0.0676606757832425, 0.01944834881994341, 0.010426650688584362, 0.022024037216656973, 0.041880555384393246, 0.05218841494726283, 0.07077953485505921, 0.07737401314079762, 0.008152321746040667, 0.030621457578880445, 0.02938933976526771, 0.01371962863153645, 0.04642484350396054, 0.06442397553473711, 0.05643474816211632, 0.030977467939789807, 0.049934579458619864, 0.023820037986817102, 0.016777938630964075, 0.03586981738252299, 0.05543024152783411, 0.023505962786397765, 0.04314499182094421, 0.002539810857602528, 0.042119525239935944, 0.030061564408242702, 0.048031912983528206, 0.045441900712570975, 0.044389767705329826, 0.028158880969775573, 0.02169101053316678, 0.059410259925893376, 0.011882399225474467, 0.029074197568531548, 0.027401569731799618, 0.01526233906458531, 0.042040469124913216, 0.018027774690251266, 0.043628549801984, 0.016956160942624723, 0.0559207782415407, 0.04628170993445175, 0.017898245747866373, 0.06877687267426934, 0.07268366018044096, 0.1388438982622964, 0.014640853573967303, 0.03472623142546841, 0.11639398363019739, 0.11123995376484734, 0.11859490695808615, 0.2828171141445637, 0.1241224432098014, 0.13529464442815098, 0.10724940111062356, 0.10898484941571951, 0.09168392313378197, 0.10955510381609201, 0.08780791397605624, 0.09183553499834878, 0.09142149292996951, 0.19638440066150256, 0.12324326538613864, 0.06105237573917423, 0.16830157328929218, 0.17677487432956696, 0.15598841543708528, 0.18130086575235638, 0.10142473437424217, 0.1577394971890109, 0.12493321113288403, 0.15959784175668443, 0.0800257008522749, 0.21133202500641346, 0.1601444152849061, 0.16581715803061212, 0.17665167951158114, 0.24227049414600643, 0.12747618396367344, 0.12206977978348732, 0.09859253599175385, 0.11758194917014667, 0.1329376580459731, 0.1236280897366149, 0.18147296937448637, 0.17476769989090307, 0.15672820859721728, 0.19360605760344438, 0.07692478903170143, 0.05917737313679286, 0.09836123018924679, 0.1154597494751215, 0.06578957475721836, 0.10415082345051424, 0.2387091081057276, 0.07938122150621243, 0.09825840499252081, 0.16230398868875845, 0.12885937759918825, 0.1539043765515089, 0.0829064009178962, 0.16722882299550942, 0.08729840203055314, 0.17678345101220266, 0.13748325913080148, 0.10095882508903742, 0.1312603059091738, 0.12319004109927587, 0.09412660848881517, 0.10924904381058045, 0.10008199499653918, 0.1557565735919135, 0.20569122768938541, 0.11993305943906307, 0.1520873819078718, 0.2253469079732895, 0.16124389985842363, 0.20712780846016748, 0.10285282667194094, 0.17523183141435894, 0.11895704109753881, 0.1105249339182462, 0.1620575583406857, 0.09823895817888634, 0.21156237407454423, 0.07550423525805984, 0.12916295416653156, 0.13186230217771872, 0.1527130590485675, 0.08485042410237448, 0.12709852494299412, 0.08582200482487679, 0.12947076479239122, 0.17668020512376512, 0.15767414069601468, 0.142117137621556, 0.12356168829968997, 0.13776677820299352, 0.10105440353176423, 0.14241483807563782, 0.09885764640888997, 0.23044178315571376, 0.12205468916467258, 0.14196946126009735, 0.09363232965448073, 0.11909614077636174, 0.12156978089894567, 0.16875062776463373, 0.14839601569942065, 0.10228842124342918, 0.12610311407063687, 0.19872443723891461, 0.1252793182751962, 0.15264245069452695, 0.12999688727515085, 0.11379026834453855, 0.15777265041002206, 0.15421013800161226, 0.11152942358915295, 0.11099807638674974, 0.08914385443287236, 0.13795448813055242, 0.07556446881166526, 0.12135416961141995, 0.23580082559159823, 0.08928171239261116, 0.10473685379007033, 0.2137175098593746, 0.1586301422544888, 0.09671894474221127, 0.17490722026143754, 0.14135871188981192, 0.12490669398435525, 0.09317326000226395, 0.10493761194603783, 0.08489934647721903, 0.16149121230202063, 0.10040733896728073, 0.15430639497935772, 0.1253580826201609, 0.25245378485747744, 0.0900167625929628, 0.1427549605390855, 0.11015471164137125, 0.1912375089845487, 0.10253801356468882, 0.08396024044070925, 0.11710278131067753, 0.125808467024139, 0.15140689270836966, 0.24083072426063673, 0.08307782600500754, 0.10791066062769719, 0.06830235956502811, 0.09746192023158073, 0.12601643800735474, 0.10139942501804658, 0.1292194625628846, 0.20832236936049803, 0.1206445712596178, 0.10598111738051687, 0.1444011814892292, 0.1257138249597379, 0.20965187730533735, 0.0916339083175574, 0.08645198387759072, 0.07286382479859249, 0.19327660171048983, 0.11827489627259118, 0.07146045153162309, 0.09337570092507771, 0.07973771701966013, 0.21741363938365663, 0.11708883063069411, 0.08590986832444157, 0.0785034889621394, 0.08731514148946319, 0.11751482848610197, 0.05675298108586243, 0.07864468531416995, 0.13980159615831717, 0.24065615077103886, 0.1318606465522732, 0.09471340557294232], [0.08734798258436577, 0.047799280645059686, 0.024986748417307223, 0.049890060776046345, 0.04272568432082023, 0.0018188956019002944, 0.05721374707562583, 0.1238707745713847, 0.06402480016861643, 0.024731609072270136, 0.07153359760663339, 0.022280918700354438, 0.032167313021740744, 0.05063464778608509, 0.010288270256881202, 0.05412189369755132, 0.05222639933760677, 0.03931379311585, 0.03918790112116507, 0.02094278487909053, 0.03843840830294149, 0.03118430237684931, 0.01307529941134687, 0.03362993935921362, 0.0505270592735282, 0.035266131561781676, 0.02973523995439921, 0.04657403299851077, 0.06350042830620493, 0.0668013993916767, 0.012494784713323628, 0.06807551173759357, 0.011104848136061003, 0.01578260918280908, 0.032632085760789256, 0.008529184336241866, 0.10646076699984924, 0.05134038527363113, 0.06990286082561527, 0.06914229092321225, 0.060995860557471, 0.0292015348428062, 0.052752396291387935, 0.0354932372325233, 0.05978655509118523, 0.018361534191561595, 0.03024658394445266, 0.07607881871185132, 0.01740090672059783, 0.02365979685315064, 0.006257832466092492, 0.0014022262247246025, 0.07057986914047173, 0.04805597383528948, 0.02498433961799102, 0.041446835800473175, 0.02173506441925253, 0.024554077169990966, 0.05560284726587789, 0.06187223603150674, 0.021752015920355916, 0.02945133750992162, 0.008847967721521854, 0.020785293508587138, 0.07595309974359614, 0.026704224026096717, 0.08841053449681827, 0.01253430004830339, 0.06966994010976382, 0.02155686924899263, 0.011942464841662772, 0.016389260201581886, 0.0669053713125842, 0.09944187184529645, 0.03374474409169384, 0.007470421193699751, 0.01744497926639659, 0.0785927502438426, 0.023961938318929503, 0.02759889280423522, 0.04676812454792006, 0.009868299488776495, 0.0889325314866645, 0.054497479793748686, 0.020959872087197642, 0.010838624921494296, 0.00549733720254153, 0.028845588942723613, 0.049141738430729935, 0.0299589495573725, 0.062075789751751084, 0.03170175996742078, 0.01614794770388731, 0.051921421595449956, 0.018023036819483553, 0.08621742789234434, 0.07468475494533777, 0.031231168790587356, 0.0327480813222272, 0.03579554154670664, 0.022098051816491143, 0.019915396347641945, 0.009812511187711996, 0.0223749195491629, 0.04584932027916823, 0.05511730117723346, 0.08132546860724688, 0.029444145038723946, 0.03500330102230821, 0.06223108606146915, 0.012346411157133324, 0.027545183364834105, 0.09466176227267299, 0.0472528631798923, 0.026271939543741088, 0.05500644551856177, 0.03657989749418838, 0.058733339820589335, 0.03656927502847143, 0.0351329317449459, 0.03085973532870412, 0.00489567468840895, 0.053940025956502984, 0.051191731821745634, 0.01991145745185869, 0.026256438411240066, 0.022444469388574362, 0.03564759377124054, 0.06396574048059327, 0.06015950507883515, 0.017125053397778953, 0.049619118350424936, 0.06056315199072872, 0.0158974139152893, 0.06115779293967145, 0.022984135430306196, 0.048195151545639546, 0.023168712222416486, 0.04056823133890118, 0.012287462579219468, 0.024433382753548876, 0.009271978317493839, 0.02101015322841704, 0.01779069285839796, 0.05802933259734085, 0.01519667383815561, 0.03300252516887017, 0.021874671303001896, 0.059607326851359436, 0.024797119931983094, 0.02927388363916959, 0.06898039246776275, 0.01623951770099146, 0.02667045164188104, 0.052318693670843325, 0.022733392992189953, 0.04401818157306739, 0.03143452573567629, 0.06811548423554216, 0.04002905723505786, 0.029453010098742585, 0.028022632834368517, 0.04387159426031368, 0.06577089468815497, 0.02961451161120619, 0.055921782473368306, 0.13671264691012247, 0.036383142694830894, 0.03388684628797429, 0.03974220994859934, 0.08188420826835291, 0.010043737262354364, 0.05167830589094332, 0.040640295150556734, 0.04853817813896707, 0.039796777734799046, 0.04161624224590404, 0.059615082506622584, 0.06731545073645455, 0.016434202968542064, 0.03478352352976799, 0.04025608826694744, 0.056177434112344465, 0.05979702488652297, 0.06544466862188918, 0.033111202730132, 0.0471711811343474, 0.06757681564028774, 0.06108824988561017, 0.11988609124507223, 0.014239133701526692, 0.03787745661767466, 0.016047700940232192, 0.07150408133332219, 0.025267073285898993, 0.01819005991066141, 0.032308648473450115, 0.0287621087793793, 0.046900041933570585, 0.04119469218754342, 0.060465775430202484, 0.05613974488473364, 0.0134267059121547, 0.01798370384079005, 0.009393749060109258, 0.03642838740987437, 0.02368724189831742, 0.025092470958562832, 0.02115900006278285, 0.019792174388255392, 0.041646243671753576, 0.05401022718953235, 0.12698639024581226, 0.01321051108451294, 0.09259607775935105, 0.04821989093241947, 0.05016593275857823, 0.012992885396150606, 0.06317123704190765, 0.021110194735229015, 0.07036165906382458, 0.039393470090414794, 0.035018707159906626, 0.062064770343048234, 0.014875908282452395, 0.05977350686277662, 0.027703000432146446, 0.07035585758941514, 0.027093124675697515, 0.01945185854232737, 0.03417350358462759, 0.03196002735889383, 0.00451338805890243, 0.013465892157650419, 0.07992570514657668, 0.007581675491694893, 0.030184959394059012, 0.03002740695540394, 0.009689661574416926, 0.049296654760837555, 0.030423006441976343, 0.035647692158818245, 0.04664920450055173, 0.02064746438658663, 0.012055106743771051, 0.01979473076893815, 0.03751783645046609, 0.034387564419635704, 0.020991866709664464, 0.03382605294297848, 0.0160637109739972, 0.06244508922100067, 0.04936391793723617, 0.03127626762060182, 0.04340006331247943, 0.0735032083466649, 0.05079401869859014, 0.06500198559037276, 0.019550183355542164, 0.046153476993952475, 0.025448077591136098, 0.021514896769076586, 0.08727893486086812, 0.05980883139584746, 0.014351824797423822, 0.0353934349093054, 0.0151209221886737, 0.016032863075711896, 0.06688963608550173, 0.05906060404543366, 0.05668397068179079, 0.017237632535398006, 0.021169435931369662, 0.041295736229845455, 0.011406018448594426, 0.03447817598602601, 0.03060022961082203, 0.039267720588083775, 0.011750624332177852, 0.09706853955451931, 0.031713597010821104, 0.003611604417009013, 0.015683680473427688, 0.0621426525924887, 0.050251747082386694, 0.03487781275595937, 0.01650113705545664, 0.013792532978446355, 0.03958023346162268, 0.06551407596894673, 0.039198167355997224, 0.023224477622924105, 0.06471997286592211, 0.07617469570998635, 0.04616233187594584, 0.06356488234762635, 0.043001420596348386, 0.018688985013536046, 0.06338499592883245, 0.055649340485355685, 0.06334089115262032, 0.03475267054247005, 0.0464546854740807, 0.015104432091382998, 0.04676075905029263, 0.05404079519212246, 0.004760009244949157, 0.03885280999488064, 0.07892262682850872, 0.08464018681219646, 0.030868576639997106, 0.036489214681621106, 0.029381041281989644, 0.016242533789149353, 0.006198020876451794, 0.008116797893308103, 0.020693353709897826, 0.026341401173600128, 0.01360019204938518, 0.039121957695377726, 0.10273069036858422, 0.06593875068106822, 0.008768222045286425, 0.0299426341828491, 0.09363080973603896, 0.012848623762173312, 0.027406706241890788, 0.010754271144313472, 0.0205675821551787, 0.06636334396898746, 0.06945225929043122, 0.029953168439013616, 0.006503637289694909, 0.012254687641481203, 0.03567024327016302, 0.1534470168075391, 0.015582845080643892, 0.04407689520823104, 0.04181905297030296, 0.03587981898869787, 0.09353097009339503, 0.008395150769501925, 0.058749115759772916, 0.04244168348876493, 0.03472544093217168, 0.045338783745786974, 0.04195636131667665, 0.009278381991732334, 0.04397080625806536, 0.038442944309541156, 0.04268284501241786, 0.029272058379969428, 0.15465299066688332, 0.09824971974428211, 0.1378783836428608, 0.1186742005603654, 0.12221563767109599, 0.16064487557326043, 0.14010100652064594, 0.13946672555591377, 0.16422911467296736, 0.09864388752196517, 0.1299279752586569, 0.13812957730676445, 0.14853326976299286, 0.21967474876769952, 0.08779282335724149, 0.14583385389830383, 0.09688695001282863, 0.17477113327809743, 0.1043125997696604, 0.08426368130104882, 0.1154978017189673, 0.09385870250740222, 0.11573277839592525, 0.1318891585937568, 0.1457024488065924, 0.1120804211656962, 0.0824693361563342, 0.19073961355856486, 0.09541469187076602, 0.14142216848475592, 0.11225855696414198, 0.20130220534546034, 0.1185112435902868, 0.1295343299529382, 0.12642275834722178, 0.1013718086427876, 0.2829155017222677, 0.05675949162936636, 0.1637794766575098, 0.12256162267710481, 0.11641493679157325, 0.08021706808358431, 0.11335218578044857, 0.06683907844126225, 0.17293238480176243, 0.09649308757590395, 0.09282645396888256, 0.24995748166527065, 0.079191272413092, 0.07197268440255097, 0.09069820174149104, 0.13051622440772398, 0.1133652204381568, 0.1845724494861705, 0.09774515431906496, 0.2045801265963486, 0.12030884570309094, 0.11856274439820222, 0.17402900595750126, 0.15833687941942895, 0.1190212576517037, 0.11883236707321235, 0.12751661108008452, 0.09436873692486968, 0.15519177461309092, 0.10965858719178609, 0.13750360161066055, 0.06658092300806727, 0.18172482800270828, 0.09745834435203246, 0.1343110129237175, 0.06171068362891674, 0.1569055233682905, 0.16774754944656575, 0.07774156198969909, 0.09742427510874611, 0.1069107578535165, 0.08727007997887475, 0.10360852469291006, 0.1372761566724096, 0.21286201290786266, 0.18119923477726324, 0.11270940955728292, 0.0867789699030774, 0.11497702609215464, 0.15646820754877158, 0.17782417445310525, 0.18117184910391057, 0.11385225930384227, 0.07732197629021746, 0.2156927524400609, 0.07102274894714355, 0.12678038701415062, 0.16362596489489079, 0.1562125626951456, 0.2530625121934073, 0.16457724384963512, 0.0660104989739401, 0.09259708199117865, 0.1258137867386852, 0.17186124942132405, 0.10507198223578078, 0.07220285705157689, 0.16009163883115562, 0.12129889614880085, 0.09701490136129515, 0.19770586118102074, 0.12506864672260626, 0.11074865369924478, 0.1695993665073599, 0.0976569719080414, 0.13026143450822147, 0.20243949789021695, 0.10837737058422395, 0.14066253496067865, 0.1619029880634376, 0.11941469939691679, 0.17938503569790296, 0.1189982146024704, 0.17643039567129953, 0.10691979593996491, 0.13090659917465278, 0.11316113067524773, 0.19755369291773864, 0.11928006447851658, 0.058962006121873856, 0.16128675613020146, 0.2041948815541608, 0.2037717064044305, 0.15946996504706995, 0.08976422542972223, 0.1598638817667961, 0.16711900888809136, 0.183330079008426, 0.17309825947242125, 0.13728178851306438, 0.12021348439157009, 0.12277344773922648, 0.08616967259773187, 0.11744236094611031, 0.13871987563158783, 0.09861258670155491, 0.09877966916454689, 0.09827889675008399, 0.14623340245868477, 0.2082850227930716, 0.12628504287983688, 0.1283157082008464, 0.16684250586799212, 0.1189370107437883, 0.16817190524722847, 0.07295168151280709, 0.0708674458520753, 0.14943152799138001, 0.13228794719491685, 0.1543575158076627, 0.11262726610792534, 0.10590633603611163, 0.1713786210332598, 0.19183356128633022, 0.08475902543536254, 0.08859683985688857, 0.09580132790974208, 0.08824183033513171, 0.13701152801513672, 0.13356450226690086, 0.28043860463159426, 0.10308487207761832, 0.12153491776968751, 0.09430643383945737, 0.13634276390075684, 0.10116947628557682, 0.12036506911473614, 0.1000375102407166, 0.1679822275681155, 0.08451596062098231], [0.04525086935609579, 0.005206322014730955, 0.07993561175784894, 0.06831097017441477, 0.042409751630787335, 0.022854436854166642, 0.03181432214166437, 0.013510897689099823, 0.03986656166879194, 0.01850338532988514, 0.05576479321877871, 0.04769708987857614, 0.05099405760743788, 0.022030939614134173, 0.017683129790904265, 0.030043413596493856, 0.06273953949234315, 0.0223337019394551, 0.07044023341898407, 0.0147785877010652, 0.0135632831370458, 0.023955015565401742, 0.010482824058271945, 0.08786375740809099, 0.025840318329366188, 0.017170878260263374, 0.019424980073901157, 0.04741892444768122, 0.020340003206261566, 0.021507312443905642, 0.013247876311652362, 0.020945061364078095, 0.045827590195196014, 0.02953251065420253, 0.052677397815776725, 0.03554367274045944, 0.07061178064239876, 0.04357385648680585, 0.07453032037509338, 0.02216369329419519, 0.030015234037169387, 0.036087206431797574, 0.010071607240076576, 0.043272997452212233, 0.03154531354084611, 0.0301907880098692, 0.021366942208260298, 0.10792141540774278, 0.0514340773890061, 0.010599243704096546, 0.05899157667798655, 0.004328955879567989, 0.03663891986278551, 0.047701049130409956, 0.031919213477522135, 0.030248568659382205, 0.056944599375128746, 0.02646694372275046, 0.008872890312756811, 0.031066956530724252, 0.03965939135689821, 0.017911017473254884, 0.02990370323615415, 0.00022923515747866726, 0.05159588084955301, 0.05062113815386381, 0.06919686549476214, 0.04419467870944312, 0.010742120278467025, 0.0572021644828575, 0.013419314121295298, 0.048030240394707234, 0.01632323026257966, 0.05301115222807441, 0.03436071139627269, 0.03864696282627327, 0.05982161499559879, 0.07322791311889887, 0.0336187062119799, 0.024893619485997727, 0.03838645966191377, 0.029214881626623015, 0.047129437660000155, 0.030000665890319005, 0.05065169597842863, 0.018429630269695605, 0.04985426466113754, 0.011001936426120145, 0.028773877969277755, 0.0324915950851781, 0.13938296719321183, 0.04805502727893846, 0.05489978659898043, 0.08636141302330153, 0.048039407402809174, 0.015848457613693814, 0.058414516571377, 0.018031795010236756, 0.08423998007284743, 0.057465788908302784, 0.05326529412663408, 0.0910365939406412, 0.03161744859867862, 0.08031358968998704, 0.025505999036665474, 0.009273276015717005, 0.04048771298091326, 0.03286703868902155, 0.04021870098741991, 0.013269144991811897, 0.04185958865231701, 0.015849885929908072, 0.050367983523756266, 0.03968403574877551, 0.03403697216085025, 0.031271110754460096, 0.010928432423887509, 0.04040143046794193, 0.05374049594891923, 0.028253597673028708, 0.05887739959039858, 0.014570572613073247, 0.06517425206090723, 0.029713570938578675, 0.022124725028074214, 0.01907605361858649, 0.037348508036562374, 0.047355610345091136, 0.013206353361186172, 0.05643397123951997, 0.029339708321328675, 0.06958376616239548, 0.05191454803571105, 0.05701841041445732, 0.01621399799894009, 0.019314365295161093, 0.021063830437404767, 0.062127684109977314, 0.0280042173939624, 0.019057577110028694, 0.028974093297230344, 0.019844435155391693, 0.039081618788519075, 0.047345378037009916, 0.05099797953984567, 0.011398237348268074, 0.037949547570730956, 0.02938910567068628, 0.020163563745362417, 0.02080861645351563, 0.02849067102319428, 0.0029237482355841038, 0.0444567492896957, 0.04927497895966683, 0.046535020627613576, 0.03410280702103462, 0.029306921509227583, 0.04890477364616735, 0.034541249208684476, 0.040309339695210965, 0.053073451920811615, 0.05067469831556082, 0.06725875913564648, 0.04768603993579745, 0.008622450670892639, 0.018669862200372984, 0.07466250578207628, 0.04318373617050903, 0.04186358183090176, 0.04937638941087893, 0.051197889527039867, 0.03167027933523059, 0.021167966903054287, 0.03753412468358874, 0.04366848837318165, 0.05176929743694408, 0.03652089208896671, 0.02494804817251861, 0.11566035156803471, 0.03208015180592026, 0.07520095724612474, 0.04826296433540327, 0.12448163250727312, 0.0571857982182077, 0.0757569284843547, 0.019215614701222097, 0.09891760854848794, 0.050635706300714185, 0.04970836606142776, 0.02662497283225613, 0.02771831157484225, 0.01521957609137254, 0.01414456797231521, 0.02165536878497473, 0.05637189546333892, 0.08269681502133608, 0.02163229350532804, 0.030486245905714374, 0.006630894412020487, 0.0656996960086482, 0.02827233202489359, 0.036094181771789274, 0.04144210980406829, 0.03972621687820979, 0.015479426165776593, 0.03646255164806332, 0.01960760947050793, 0.017856992515070096, 0.05808043985494545, 0.0483685274209295, 0.015144124693636383, 0.03418601577037147, 0.03084614427228059, 0.003909513944693441, 0.0662638232378023, 0.10084077356649296, 0.01540642767213285, 0.035078513236450296, 0.016717075736128857, 0.030266217355217253, 0.014512369575511132, 0.03199825602184449, 0.005666366212868265, 0.022909910484616245, 0.0269331837937768, 0.024978314227025424, 0.08082395658961364, 0.04091565144647445, 0.009984797166128243, 0.038891510239669254, 0.012147581736956323, 0.010636888826931161, 0.042200023241873295, 0.057318933574216704, 0.025665113802200983, 0.013683209112579269, 0.09759719975824867, 0.0166889657266438, 0.04889280428843839, 0.06178969224648816, 0.037965693311499696, 0.03467407583126, 0.03252677034054484, 0.03959249458940966, 0.0283748671478991, 0.021671049729255692, 0.023512332533885325, 0.04854841044704829, 0.07541434293878929, 0.07983319368213415, 0.07744372582861356, 0.019299043974440013, 0.04379537102899381, 0.08306275574224335, 0.037060340999492576, 0.04270952161667602, 0.05651098835681166, 0.021799718628504446, 0.06073331500270537, 0.04825287112700088, 0.03400985450882997, 0.022178196980218803, 0.06006493765328612, 0.03611531135226999, 0.0383855402469635, 0.016410625572981577, 0.034524920263460705, 0.07555154271956001, 0.10630918906203338, 0.061180645999099524, 0.02459694361979408, 0.013115840182373566, 0.01579281434948955, 0.02620179089717567, 0.003585609740444592, 0.05162866087630391, 0.023566863000659004, 0.010566785133310726, 0.02889562411499875, 0.043130600093198676, 0.06879893184772559, 0.014500288259504097, 0.014385252825117536, 0.06262581702321768, 0.025036675023979375, 0.018273903090240698, 0.012009997735731304, 0.005056603686950568, 0.04976199068395155, 0.03321128325270755, 0.04103226447477937, 0.01803951334607388, 0.0054233561053739065, 0.020884929590725472, 0.07167696527072362, 0.027796036064890877, 0.058882006843175204, 0.02428908719282065, 0.02988702484539577, 0.04116235660122974, 0.027458600600117018, 0.028982832828270536, 0.004722548174738351, 0.06858691001044852, 0.07833919527807406, 0.028008291996749382, 0.04805728680055056, 0.029299315131668533, 0.08259141139153924, 0.05526798005614962, 0.016142689057492783, 0.04809570545330644, 0.11971256269940309, 0.03304158164454358, 0.01887323610883738, 0.03337710024788976, 0.05082298535853624, 0.029971037658729723, 0.027010825163285648, 0.059986899340791364, 0.0018973963784186967, 0.05719201359897852, 0.02620717167987355, 0.07897934557071754, 0.018276072705962827, 0.0044335291521357635, 0.031724019308707545, 0.08486232560660158, 0.038313632498362234, 0.04224069123821599, 0.015406208844589335, 0.0526444244065455, 0.008902835759467312, 0.08441852977765457, 0.03256006944658501, 0.02106670572954629, 0.03940714257104056, 0.07258316914417914, 0.06365232515547957, 0.04133827359016452, 0.05130331690556236, 0.06307470865015473, 0.048191952253026624, 0.036844414193183184, 0.0802463400842888, 0.06624341968979154, 0.03444434083732111, 0.0680062740242907, 0.021857648555721556, 0.06103831649358783, 0.05146934085392526, 0.051784500014036894, 0.08767175235386405, 0.1073873404945646, 0.16860642550247057, 0.11724167742899486, 0.15009347961417266, 0.10299458620803696, 0.19780443874853, 0.10507431639624493, 0.15780941343733243, 0.12894327166889394, 0.24021803428019795, 0.10584296086536986, 0.136880258630429, 0.11124561953225306, 0.09188955317118339, 0.16285090148448944, 0.17176476174167224, 0.1632022333464452, 0.2077332923987082, 0.14569047944886343, 0.1286620189036642, 0.10574065814060823, 0.06353119308395044, 0.16368938077773365, 0.19384000290717396, 0.11165680496820382, 0.1275193795029606, 0.13065509338464054, 0.09016499535313674, 0.12168963732463972, 0.07048541706587587, 0.17510776807154926, 0.10928377801818506, 0.198230843724949, 0.19865481954600128, 0.13246214070490428, 0.16097621779356683, 0.10774752723851375, 0.15226020477712154, 0.2013982180505991, 0.11440632385866982, 0.09190328671996083, 0.12862870283424854, 0.0753040945689593, 0.11249348614364862, 0.14077468322856085, 0.11305865153138127, 0.1428923774510622, 0.18680455828351633, 0.055252628201352696, 0.12522637897304126, 0.09159236840371575, 0.0940661985161049, 0.1592514632003648, 0.08027513032513005, 0.1089553331424083, 0.1788090816033738, 0.18123481715364115, 0.10985230215426002, 0.12567521631717682, 0.12049347508166518, 0.07391940137105328, 0.08436598402581044, 0.10913290575678859, 0.0922401115032179, 0.169663080945611, 0.12134039535054139, 0.18966467838202203, 0.07301289894218956, 0.1625038172517504, 0.192941459694079, 0.15522874120090688, 0.13683628956122057, 0.16072254069149494, 0.20586968239928993, 0.17913654260337353, 0.3341884847198214, 0.19946908870978014, 0.11777951142617635, 0.10145002337438719, 0.18826138653925487, 0.11281847727618047, 0.1369837216500725, 0.09667809693408863, 0.17520971117275103, 0.1621947716921568, 0.13592068797775678, 0.11161211665187563, 0.09418336115777493, 0.06958590354770422, 0.21197843817727907, 0.21302965176956995, 0.15647831772054943, 0.24215476321322577, 0.19392153567501477, 0.07796729023435287, 0.15437506272324494, 0.07337562340710845, 0.13168441743722983, 0.19370924920908042, 0.16013822704553604, 0.12155939931316034, 0.10452559869736433, 0.12695258563118322, 0.16043049921946867, 0.08848389770303454, 0.07159983619515385, 0.21321799952004636, 0.12017917766102723, 0.16877109238079616, 0.11018105915614537, 0.17347662416951998, 0.1365735743727003, 0.1313272773155144, 0.1595696554120098, 0.14549474923738412, 0.09890213116471257, 0.15987743889646872, 0.2343653440475464, 0.11291990469076804, 0.24634175854069845, 0.10761194237108741, 0.09689513314515352, 0.11860351078212261, 0.10634970438799687, 0.13017545055065835, 0.09935843917940344, 0.1626462960349662, 0.1491188183426857, 0.18871775562209742, 0.18678276373871736, 0.18791765426950796, 0.16624862487827027, 0.0919880900265915, 0.10176212234156472, 0.1377937974674361, 0.2907992372555392, 0.17773346789181232, 0.06796032363282782, 0.11783592482762677, 0.11760329588183335, 0.15957128389605454, 0.1310783770999738, 0.1616113130003214, 0.14514246742640222, 0.11486897617578506, 0.09414995687880687, 0.0990818411644016, 0.09259440177785498, 0.12788087581949575, 0.1297328014458929, 0.15690673116062367, 0.09257011022418737, 0.12374107938792024, 0.20703769900969096, 0.11961527434842927, 0.10900681359427315, 0.1166723051241466, 0.15092741272279195, 0.25472231741462437, 0.15393282073949063, 0.15947919312332356, 0.10884083035801138, 0.10784356029970305, 0.21466585754283837, 0.14863453432917595, 0.2944158289049353, 0.11939738318324089, 0.12692093875791344, 0.13806502148509026, 0.1766330333692687, 0.13017200359276362, 0.2024278270878962, 0.10039983436997447, 0.1550588496029377, 0.17065672762691975], [0.005356890631706587, 0.018220524436661174, 0.034028364944138696, 0.029503917188516686, 0.03074567359206932, 0.020178384646507244, 0.03385175924215998, 0.022613370325416327, 0.042616379114666154, 0.01333988141933722, 0.04381484498402902, 0.05182343774608203, 0.03601233348516481, 0.03998047752039773, 0.037408524458961825, 0.03086686673175011, 0.05620760517194867, 0.017126970259206634, 0.026644317865637795, 0.0352813307461994, 0.02945120519559298, 0.017355436392660652, 0.047596303679581196, 0.03526945638337305, 0.022763815109751055, 0.022542509217081324, 0.03130812144705227, 0.03986543869333608, 0.00621504574415407, 0.023959563446364233, 0.03219008126429149, 0.018975649095539535, 0.009494520840235054, 0.04112752400604742, 0.03847389229174171, 0.04428020804854376, 0.0059128415138859835, 0.04784406056361539, 0.003998520775764648, 0.01668898099368172, 0.049098950012453964, 0.014342057285830379, 0.0021629919480931547, 0.056072953290172985, 0.014444848555805427, 0.035905684743608744, 0.019140304099502306, 0.013777807072204138, 0.06015827014510121, 0.02018367382697761, 0.019615163261603032, 0.06377448181488685, 0.03561099019965955, 0.0012534980279659586, 0.025275059643068483, 0.023402372541438256, 0.13475017435848713, 0.011491427347729248, 0.017110919513340508, 0.019094620033034256, 0.039272565328116925, 0.02854807169309684, 0.03222826921514102, 0.036442239702280076, 0.03801553510129452, 0.01850530049497528, 0.026483286238674606, 0.0534839215023177, 0.012172200683770435, 0.014287528515394245, 0.025104258808174303, 0.024735164595767856, 0.03033314465678164, 0.043838078023067543, 0.01667626015841961, 0.03789175674319267, 0.06456829314785344, 0.03900703421926924, 0.0655472291899579, 0.12717870064079762, 0.07845166924276523, 0.0961940029103841, 0.19431960502905504, 0.19587767070957593, 0.056158764221306355, 0.04083874968013593, 0.0295232384731727, 0.07150748757911579, 0.013330960380179542, 0.059605562660310946, 0.14480402772980078, 0.037162423200373135, 0.035859120277954, 0.027956821722909808, 0.03442297376958387, 0.0293950191033738, 0.05203278276271053, 0.038133087900600264, 0.10573955212852784, 0.08863230009696313, 0.04557950422167778, 0.04784859996289015, 0.022702141365568553, 0.04134202249614256, 0.055828429625502655, 0.06439123622008733, 0.024847434999953424, 0.022246661163600426, 0.009873178155560578, 0.04064487186925752, 0.05430999378274594, 0.022822477854788303, 0.047088189516216516, 0.04656152081276689, 0.04942190893260496, 0.014679077147905315, 0.04274466973064201, 0.04901505255007318, 0.03374339041433164, 0.03120593068056873, 0.04868638715041535, 0.010802732963514115, 0.024014979401337247, 0.023794306242572408, 0.037168696256620545, 0.08322572628302233, 0.018936596012541225, 0.057736225825335295, 0.01708878400469465, 0.03494119471205132, 0.02719534936893199, 0.1058193953441722, 0.021517291997692416, 0.06635824817099742, 0.03349400843892779, 0.034989313022898774, 0.05900745439742293, 0.030160674625741582, 0.0355413317946451, 0.04508960193821362, 0.014712511960949217, 0.04091384993599994, 0.01267245486711285, 0.02615938245851014, 0.060079390449183326, 0.018439699729372348, 0.0183682330285332, 0.01165231054515711, 0.03310145218191402, 0.04065555879580123, 0.04059141009513821, 0.03180995576881936, 0.03815177136233874, 0.007949053858672934, 0.0026689769957946347, 0.01657178781793586, 0.04518813540094665, 0.02277433918789029, 0.053642746194132736, 0.02751325659586915, 0.018762041182656373, 0.008056976549726511, 0.023684037516691854, 0.041173274229679785, 0.005707021910763744, 0.031674984975584915, 0.029420586302876472, 0.03462320266823683, 0.05269272592184799, 0.016077378365610327, 0.04741456486018641, 0.012912981960523342, 0.030756051785179546, 0.04496255982667208, 0.02362830943561026, 0.011663597127023553, 0.04143896818693195, 0.02052407618612051, 0.018979610043710897, 0.026923463779634664, 0.02790918347558805, 0.026754087868279645, 0.04864606520693217, 0.03641905755336795, 0.012348836071656218, 0.02085178654773959, 0.040981655940413475, 0.04260139027610421, 0.06482218738113131, 0.01983744963737471, 0.04910063277930021, 0.039677830546029975, 0.07292359694838524, 0.06330742580550057, 0.06335911660322122, 0.0201995668134519, 0.04652244058836784, 0.061466085325394354, 0.01802822421970112, 0.027740553952753544, 0.02099290317190545, 0.03705353190058044, 0.03863148883517299, 0.04773824642013226, 0.02934706024825573, 0.024217952974140644, 0.045400235269750865, 0.04200206743553281, 0.025582722687561597, 0.0033636556347898606, 0.012491496362989503, 0.039646438123392205, 0.010533623430611832, 0.03719390383256333, 0.01629842641497297, 0.04316533090812819, 0.020158910691472035, 0.019661520774077092, 0.002823850493379203, 0.011518674769571849, 0.013949876767583191, 0.09507018607109785, 0.048023268447390625, 0.06709069958222763, 0.02801533179756786, 0.024472381553745697, 0.004346716533681112, 0.043662093180630884, 0.04737634637526103, 0.06210110589329686, 0.035159140160041194, 0.07210476802928106, 0.06433154549449682, 0.029720430927617208, 0.03822990127706102, 0.03556628152728081, 0.09354901912489108, 0.05459945682170136, 0.0051069166344989625, 0.020106388688353554, 0.016981797691966807, 0.022592390022639717, 0.07062815369239875, 0.01900118406462882, 0.07129501790872642, 0.033610977698117495, 0.02666847880131432, 0.03956543800554105, 0.025631105627066324, 0.03216794405930808, 0.035121949655669074, 0.026151881253878986, 0.03193517940651093, 0.10175953712314367, 0.13976069406739303, 0.13828308906938347, 0.10713172956768956, 0.057685010002127717, 0.1939690195556198, 0.22161389328539371, 0.18449422796922071, 0.11058367469481059, 0.16159341324652943, 0.0241165883240423, 0.04948201695723193, 0.02199386276437768, 0.053354555408337286, 0.05472888398383345, 0.005118385572651667, 0.008209277975506015, 0.06084144634327718, 0.037223260650145154, 0.03043979000566261, 0.0711808136797377, 0.10237582333918128, 0.053705229091324976, 0.08696192330015556, 0.043634001830858846, 0.017172002932056785, 0.05465663357504776, 0.025301848205604723, 0.06884271771247898, 0.011975893717525261, 0.012725769908034375, 0.02181776935633804, 0.012656950341936733, 0.032661381510219405, 0.04936844715848565, 0.05732758489570447, 0.019586123659142425, 0.04639219918421336, 0.013815119712879615, 0.052333173608141284, 0.07330388189958674, 0.08703067925359521, 0.009504911755876881, 0.02080469621744539, 0.09029869389321123, 0.04043682963986482, 0.023891058550881486, 0.07075149100273848, 0.058221520856022835, 0.027911174975867783, 0.040244654951883216, 0.03049736370199493, 0.022870655537449887, 0.03216840546312077, 0.011073179210403135, 0.011892985219934156, 0.039185108949563334, 0.005104467971250415, 0.05339639048491206, 0.06378525016563279, 0.014219398510509303, 0.029001811452742134, 0.03853464831731149, 0.02405342858816896, 0.07066306431910821, 0.049262029118835926, 0.038176320759313445, 0.03175397323710578, 0.09065204778952257, 0.031118806784174273, 0.008334586430074913, 0.015368913167289324, 0.02883892912151558, 0.018716791378600255, 0.030777863293354, 0.04434261291420885, 0.026679584723232046, 0.023657974986625568, 0.03555918065831065, 0.05991274903395346, 0.027749871934897134, 0.021227906990264143, 0.0385164703641619, 0.007868082578560072, 0.017027296857642274, 0.03288372386513012, 0.03629870918978538, 0.0193075103951352, 0.026113216632178853, 0.032794204740119834, 0.08510304268981729, 0.015605492883228829, 0.07263342144766025, 0.07253447068589074, 0.07328569037573678, 0.008718264056369662, 0.022757864357637506, 0.018650900539276854, 0.022355979940454875, 0.11970313106264387, 0.09378735455019133, 0.13904735020228795, 0.16267970709928445, 0.08528106992266007, 0.08035143158797707, 0.12195494451693126, 0.07089639215597085, 0.08529716477330242, 0.06999696006200143, 0.11621430755725928, 0.11264576975788389, 0.12552425584622792, 0.09063764249107667, 0.15240222215652466, 0.11245162731834821, 0.17686826788953372, 0.0736638108002288, 0.0923016614147595, 0.10290928078549248, 0.10889751517346927, 0.1298203460339989, 0.15085691293435438, 0.09697270326848541, 0.09043912350067071, 0.17008455975779466, 0.1376233087586505, 0.10722130297550134, 0.14652119630149432, 0.10944201238453388, 0.17666482952024254, 0.11261816695332527, 0.0822806762797492, 0.08236338969852243, 0.08242353504257542, 0.28469950599329813, 0.06530849342899663, 0.12151465671403067, 0.0801633552515081, 0.13095064966806344, 0.11874499890421118, 0.13054747773068293, 0.11705258328999792, 0.081924635384764, 0.08612689775015626, 0.1932173113205603, 0.09540363174996205, 0.10743962840310164, 0.14813916305346148, 0.18339656186955317, 0.10952444081859929, 0.1343186939401286, 0.1477886318628277, 0.23560763310108865, 0.07949608391416924, 0.11731562417532716, 0.1957863670374666, 0.09090088015156132, 0.1242189851722547, 0.10157880932092667, 0.20132033580115863, 0.12347294948995113, 0.11109525617212057, 0.17967884136097773, 0.15477828894342693, 0.13550619807626518, 0.13860029061990126, 0.09547396868999515, 0.17425874434411526, 0.07735987247100898, 0.1566185980503048, 0.1558482436729329, 0.09014042560011148, 0.2656492553651333, 0.10315799101122788, 0.1517890164894717, 0.15200888897691453, 0.18308807270867483, 0.2531096839479038, 0.2808929245386805, 0.18899697278227123, 0.228137451090983, 0.31613736333591597, 0.3429278257702078, 0.2984571291932038, 0.30836222054702894, 0.20577392753745827, 0.11989622855825083, 0.1379754412919283, 0.23811674703444752, 0.18686777060585363, 0.14781510829925537, 0.09736843846206154, 0.05569151822211487, 0.16137481640492166, 0.15499725219394478, 0.16900997741946153, 0.19105380241359982, 0.25078309593456133, 0.15003067441284657, 0.3166259085493428, 0.16255748937172548, 0.08330708941710846, 0.14112760286246026, 0.1863126339656966, 0.14512660327766622, 0.0957347975511636, 0.08845807944557496, 0.14488509909382888, 0.1384517050215176, 0.2106681192027671, 0.08930008033556597, 0.16922225031469548, 0.09175043992166008, 0.14870294422975608, 0.14483530819416046, 0.07846840870167528, 0.10433140876037733, 0.15207930734114988, 0.11918448603578977, 0.1316317766904831, 0.22509907984307834, 0.15285599923559598, 0.08904189776097025, 0.16456640086003713, 0.23256755194493703, 0.13743802798645838, 0.14983925968408585, 0.1136963116005063, 0.09739377495965787, 0.1198761167802981, 0.17095558159053326, 0.14620324836245605, 0.2466366770012038, 0.10420339634375912, 0.1437486886445965, 0.16228855880243437, 0.13422270837639058, 0.14353558793663979, 0.13291836051004274, 0.11583856200533253, 0.17281491681933403, 0.08832197210618428, 0.09943845202880246, 0.1612065668616976, 0.1327137957726206, 0.08491062372922897, 0.08670526064400162, 0.10353548039815255, 0.11772913698639188, 0.11082312291754143, 0.14885030846510613, 0.11034601101917879, 0.16898727363773755, 0.0880622628277966, 0.1921282219035285, 0.13758499867149762, 0.1257280877658299, 0.1148509814270905, 0.05271073763391801, 0.10131427565855639, 0.07002442715955631, 0.1333787872322968, 0.10463778089199748, 0.09970534020768744, 0.1166731057954686, 0.07520809543452092, 0.21058816063616956, 0.13210371136665344, 0.16992988091494354, 0.18309170965637478, 0.10798484486128603, 0.12439454932297979, 0.10103588631110531, 0.1019517050257751, 0.07117747528744595], [0.05939900981528418, 0.011548360676637717, 0.01151380203996918, 0.027834220623065318, 0.04515598641176309, 0.02234099110189293, 0.03446727192827633, 0.04437684500589967, 0.025124472366379838, 0.06940107739397458, 0.013190278018425618, 0.04135280441758888, 0.029846126147146736, 0.041043300846857686, 0.043895583865897994, 0.04387516674718686, 0.060969798027404716, 0.031102162320166826, 0.06367148019905601, 0.03401705037270274, 0.0433587608858943, 0.053329429256596735, 0.03600145656881588, 0.028675259689667394, 0.038552863589887104, 0.09618821500667504, 0.07571458111384086, 0.012413622595236769, 0.018829217845840112, 0.028604234036590372, 0.04567678239462631, 0.015772560079182898, 0.04628671413021428, 0.019733364061851586, 0.017188504903710315, 0.017233210183413963, 0.01501187652216426, 0.03218486672267318, 0.03023004126069801, 0.05258482528318252, 0.0291761847745095, 0.025976235678951656, 0.019849452921854596, 0.041698453548763476, 0.04856240183913282, 0.046400046441704035, 0.028947827206658464, 0.03862176542835576, 0.043319131048130136, 0.020667871327272484, 0.017573069714541947, 0.00985279496360038, 0.029702877226684774, 0.010341374951946949, 0.062201820846114836, 0.009486170618661811, 0.05276767011465771, 0.07813936671508209, 0.06442771426268987, 0.03303627210802265, 0.05815971310117415, 0.036389989113169055, 0.0098793553687366, 0.05189445322113378, 0.020027795673481057, 0.02632386443604316, 0.028279755197997605, 0.045298092000718625, 0.07867971129183259, 0.06680634591196265, 0.02922557873119201, 0.06758791647319283, 0.03211673502145069, 0.192462115415505, 0.20127108772950514, 0.19416682608425617, 0.568331486412457, 0.9476683884859085, 1.795741081237793, 2.5048902971403937, 5.22608322756631, 6.556696695940835, 7.464272567204066, 6.9066618255206516, 7.800153698240008, 9.273884858403887, 7.67999415738242, 3.4879609516688754, 2.5062688631670813, 1.3690913979496275, 1.3868474108832223, 1.0792339401585715, 0.5303316254700933, 0.26755428314208984, 0.30872401541897226, 1.5287945483412062, 1.0921050437859126, 1.224476260798318, 2.051459325211389, 2.1512241661548615, 2.2880830509322028, 0.7041846737265587, 0.3365201753165041, 0.09166691226086446, 0.058241069449910095, 0.03148947350148644, 0.07557438220828772, 0.02431526337750256, 0.0560614996190582, 0.028314419855762805, 0.04642533544184906, 0.00964962800831667, 0.05537765506388886, 0.018933303421363235, 0.0678446673388992, 0.05371243513322302, 0.04387279865997178, 0.0634579723700881, 0.006311831555129694, 0.0345865210651287, 0.05484438421470778, 0.024340306408703327, 0.008737189246208539, 0.06305001676082611, 0.01050619110797665, 0.07584132466997419, 0.017007017142272422, 0.0472741488234273, 0.04542606709791081, 0.01790523974757109, 0.05116009173382606, 0.059370334925396104, 0.02951082806768162, 0.02574067546187767, 0.04048575201470937, 0.05720106525612729, 0.04415582918695041, 0.07852556849164621, 0.028260973348681415, 0.04004424284877522, 0.053450710605829954, 0.022683362908927456, 0.026947059834908162, 0.06995995954743453, 0.010849266895093024, 0.04106236428820661, 0.03537266495238457, 0.039857591435845406, 0.05092145096776741, 0.021454727676297938, 0.03327788485746298, 0.026419617601537278, 0.050948870567870994, 0.03299771435558796, 0.01766174745612911, 0.04448243523282664, 0.008713397263948406, 0.06829809836511101, 0.020451333839446306, 0.013506817149131425, 0.03654627947668944, 0.09672748749809605, 0.052983641025743315, 0.01944112920734499, 0.006504124138570789, 0.008340085108232285, 0.010665894502640834, 0.05425355323989477, 0.0629650234643902, 0.03239402514217155, 0.059601335387144766, 0.06563178822398186, 0.060908940221582136, 0.013773950448791896, 0.019902188663503954, 0.0525026512997491, 0.049875580838748386, 0.03268087921398027, 0.030023223787013973, 0.06853806227445602, 0.027178703208587, 0.10934508365711995, 0.020057449350133538, 0.04607039377359407, 0.01132562053057232, 0.04112992602001343, 0.0873953104019165, 0.06505466026387044, 0.029667654473866736, 0.022810896958357522, 0.019237100512587597, 0.07068761371608291, 0.053001225260751586, 0.03896884287574461, 0.03035414531560881, 0.057895376213959286, 0.02675699199815946, 0.009439085377380252, 0.04814127925783396, 0.011022855660745075, 0.037405216600745916, 0.016291722488988723, 0.04040899613339986, 0.03248327963852456, 0.025511174562520215, 0.009640213334932923, 0.037296393154455085, 0.018567613758412854, 0.04162577905559114, 0.07873751569007124, 0.04428342091185706, 0.02708551999447601, 0.024361171360526766, 0.10029889550060034, 0.03446150777329292, 0.035792617060776265, 0.05634152762857931, 0.04166840462546263, 0.07022585706519228, 0.05086731065862945, 0.05325927212834358, 0.036478887378637276, 0.02803516198348786, 0.013180049103019493, 0.052421179600059986, 0.006442366425679731, 0.0906588127836585, 0.012046222175870622, 0.02529299332361136, 0.03638898827401655, 0.017584265542349646, 0.052382397931069136, 0.08091791333364588, 0.04312698010887418, 0.0290642298891076, 0.044830927425729375, 0.04830059249486242, 0.02901861197980387, 0.037311212359262366, 0.05245254488129701, 0.01894691483383732, 0.07184034971786396, 0.04110118327662349, 0.07351616836552109, 0.12194404724453177, 0.07153487325246845, 0.06817317328282765, 0.11597680673003197, 0.05003428339426007, 0.17958634346723557, 0.11933023535779544, 0.4895179069467953, 1.0272374216999327, 1.7401463729994637, 3.41187253168651, 5.005098376955305, 8.079935942377363, 9.62134689944131, 11.028343217713491, 10.404835326331002, 10.261512228420802, 11.737731712205068, 10.066613520894732, 5.802225683416639, 3.7218338421412875, 2.1172346643039157, 2.2100688942841122, 1.251796034829957, 0.5572400987148285, 0.34249087635959896, 0.5363501768027032, 1.7956022258315767, 1.364171313388007, 1.2958554306200571, 3.1839703151157925, 3.1396438479423523, 3.3938178547791074, 1.7430498514856612, 0.5346340803163392, 0.10840850177087955, 0.057322753726371696, 0.04286603928942766, 0.03265282179095915, 0.03696489826376949, 0.026959102135151625, 0.05949792665030275, 0.008342712735092002, 0.035725591371634176, 0.03909593587741256, 0.017916052203093256, 0.0795534879767469, 0.04550964904150792, 0.05344741292563932, 0.11470733556364264, 0.045143962771232636, 0.00544542503277106, 0.027465440233104994, 0.022912290446194153, 0.059058948419988155, 0.03841779101639986, 0.03571399860084057, 0.023536376422271132, 0.0378788917192391, 0.035772003166909726, 0.04329772326829178, 0.028790179773100784, 0.039104085082986524, 0.038917810256992064, 0.030058385471680334, 0.009798463816488428, 0.022305515594780445, 0.045387777366808484, 0.053897583591086526, 0.049883546839867315, 0.07286736675138984, 0.03406061910625015, 0.02694505306759051, 0.06009696450616632, 0.02824107022024691, 0.07056609487959317, 0.02750925493559667, 0.03363132357065167, 0.0799661526190383, 0.034771523637963195, 0.04949143502329077, 0.062356458976864815, 0.04933581980211394, 0.06890627608767577, 0.04950085987469979, 0.019278903358748982, 0.031595362283821614, 0.029204018280974457, 0.01368317348949079, 0.06224569492042065, 0.06656645664146968, 0.06419629310922963, 0.046253119861441, 0.08256640059075185, 0.018302676367706487, 0.025294521723740866, 0.008376056794077158, 0.014330291488607014, 0.04124624388558524, 0.02713710901194385, 0.03667909252856459, 0.02396609095324363, 0.015586141064496977, 0.025818009794290577, 0.027655784572873796, 0.032536765161369524, 0.017965091625228524, 0.10691997235906975, 0.1753205566533974, 0.15055229142308235, 0.06750295031815767, 0.1594057756343058, 0.086412079233144, 0.21599573189658777, 0.07942233394299235, 0.13208088544862612, 0.10193646512925625, 0.13733722482408794, 0.21797670131283148, 0.19905234607202665, 0.10034536836402756, 0.10596665101391928, 0.16956847959331103, 0.18458040191658906, 0.1381148395261594, 0.11185318657330104, 0.10664917581847735, 0.11217834055423737, 0.13791043763714178, 0.13748183420726232, 0.12182172095136982, 0.06652539848749127, 0.13566349606428826, 0.19821320181446417, 0.12987308177564824, 0.0823238921750869, 0.12569939930524143, 0.1400102185351508, 0.1378243179725749, 0.13362181133457593, 0.10803538893482514, 0.06356840394437313, 0.1010754041905914, 0.18265907572848455, 0.1241173677678619, 0.17788521546338285, 0.09043103536324841, 0.20638809672423772, 0.14151307860655443, 0.1554568646741765, 0.08690166260514941, 0.24512821223054612, 0.17403640198920453, 0.10082809174699442, 0.11269311793148518, 0.1526019692953144, 0.09353301926915135, 0.1011213885088052, 0.13453518732317857, 0.09849496944142239, 0.11616216892642633, 0.11863442483757224, 0.17832048210714543, 0.1098572351038456, 0.23674065087522778, 0.16639351924615248, 0.1307667123952082, 0.09992283103721482, 0.10973878324564014, 0.1364411243370601, 0.1101729574480227, 0.11789535092456, 0.0919532540387341, 0.2539835827691214, 0.19746377345706734, 0.13498036057821342, 0.24145076956067765, 0.2099070878965514, 0.13334499618836812, 0.20520971209875175, 0.1442160364240408, 0.42120829384241787, 0.39412540995648926, 0.6013487290058817, 1.7252292420182909, 1.9384792276791163, 4.328605694430215, 6.65883868932724, 9.762311083929879, 11.470639484269277, 12.843262195587158, 11.96433070727757, 13.524719800267901, 13.937194398471288, 11.201581784657069, 7.72990219933646, 5.10791825396674, 3.7401154211589267, 3.4552429701600755, 1.939196412052427, 1.0400029995611735, 0.7153087396706853, 1.180102459021977, 2.775609484740666, 2.6678935161658694, 2.4970216793673377, 4.574662251131875, 4.255081593990326, 4.461253753730229, 1.9916418492794037, 0.736973874270916, 0.20207208474831923, 0.25095913505979944, 0.19414710785661424, 0.1693625577858516, 0.12284584742571626, 0.10504960415086576, 0.15939151282821382, 0.12382091581821442, 0.1417393157524722, 0.13525010538952692, 0.10302759015134402, 0.20399776713124343, 0.1422436979732343, 0.1862918572234256, 0.16130990774503776, 0.16881192661821842, 0.13753659198326723, 0.1625925289200885, 0.10926118958741426, 0.10784469345318419, 0.16036088152655534, 0.10427435075065919, 0.1502471270837954, 0.12611622336719716, 0.09795620585126535, 0.12271075110350337, 0.1686803586781025, 0.15589983947575092, 0.10821917014462606, 0.08424948634845869, 0.10165107330041272, 0.11132275539317302, 0.17941803964121, 0.11273942794650793, 0.13061423200581754, 0.1660200942839895, 0.1617432880614485, 0.11468507961503097, 0.1470638614680086, 0.07601383541311536, 0.17607508759413446, 0.10876895314348595, 0.07047529332339764, 0.22531098632940225, 0.168504088850958, 0.1828865342374359, 0.1212661364781005, 0.19088556644107613, 0.1415700755481209, 0.24675357501421655, 0.15779928969485418, 0.14238267551575387, 0.1269276019717966, 0.10059082840702363, 0.16414348355361394, 0.11998703011444636, 0.24080974395786012, 0.1375422373946224, 0.23037743089454515, 0.10865726627941642, 0.07796567532100848, 0.2806036243481295, 0.07151629496365786, 0.11012207410697426, 0.0878392622939178, 0.10243448947689363, 0.0908941151574254, 0.13133693965417997, 0.13219637210880006, 0.165770325543625, 0.0959243191672223, 0.10774310997554234, 0.20177048950323037], [0.04551888390311173, 0.01843533674920244, 0.04273290732609374, 0.04026771496449198, 0.006250553481679941, 0.026535521560747708, 0.019328385524983917, 0.01120220942954932, 0.06515956856310368, 0.07360960263758898, 0.07219710985996894, 0.049940289330801794, 0.03660194988229445, 0.035097071169210334, 0.02526339392976037, 0.06782329348581177, 0.05024831369519234, 0.052745064720511436, 0.058439371309110096, 0.10778945391731602, 0.0944126517112766, 0.007511350426024624, 0.0476105088101966, 0.020423724249537503, 0.059503924899867604, 0.02631055497165237, 0.08603517338633537, 0.011824864544905722, 0.03724420363349574, 0.0410731631730284, 0.07349985638367278, 0.08064662146248988, 0.03235164384490677, 0.03423298057168722, 0.07655411213636398, 0.02384522181403424, 0.014345341395320637, 0.012641853785940578, 0.038002585260463614, 0.026025524462706277, 0.021598007130835737, 0.02460226503067783, 0.043544106118913205, 0.05526703010712351, 0.019464637053066065, 0.022631997808015773, 0.017528008203953505, 0.028719920864594833, 0.010396580561064184, 0.029372881898390393, 0.06315784276063953, 0.018938487428905706, 0.0708033921463149, 0.035322796021189005, 0.04456779493817261, 0.018336850783920715, 0.022045083676597903, 0.005041207303293049, 0.08377854911876575, 0.03389964685110109, 0.05813084143613066, 0.043147149562303505, 0.035458950858030996, 0.01556432616364743, 0.06755668350628444, 0.04670879005321434, 0.07112171327961342, 0.04579388736081975, 0.06777496143643345, 0.05531754703926189, 0.0875353803858161, 0.2731000855565071, 0.5881024769374302, 1.5107078445809228, 3.3625553037439073, 9.491076861109052, 16.376400334494456, 24.858062880379812, 33.64086730139596, 41.71190173285348, 43.82178129468645, 47.067705222538535, 48.69390330995832, 55.285489082336426, 47.231894629342214, 45.45043904440743, 46.79333823067801, 33.81082023893084, 33.27807058606829, 21.80539267403739, 15.748453412737165, 17.334143502371653, 12.403858985219683, 10.500593662261963, 9.165086490767342, 13.23047661781311, 15.119928053447179, 17.70402216911316, 27.52042497907366, 28.199072905949183, 29.872567381177628, 22.401834726333618, 10.747209548950195, 2.8459081011159078, 0.28361184149980545, 0.1643179484776088, 0.04706276820174285, 0.06154034419783524, 0.06526259053498507, 0.06417026450591427, 0.05687504614304219, 0.017217251039775353, 0.0853529946346368, 0.02482597972266376, 0.0362009017595223, 0.03062841934817178, 0.028523858170956373, 0.055282388747270615, 0.017501204374379346, 0.0602029041786279, 0.020434959093108773, 0.012959306394415242, 0.08133668479110513, 0.012653449101240506, 0.044836450700781176, 0.06828806283218519, 0.0416714342843209, 0.03779613080301455, 0.004008544434327632, 0.012383678844863815, 0.021045225007193427, 0.05585740985614913, 0.027612921515745775, 0.023646767284455042, 0.08297837991267443, 0.07083874382078648, 0.03393525636887976, 0.02894903499899166, 0.021662389926080192, 0.037740731811417, 0.05263847026175686, 0.08859453962317534, 0.03341167839244008, 0.05944565909781626, 0.04298255393015487, 0.029071775198514973, 0.06684587057679892, 0.08446258027106524, 0.04580126642914755, 0.061066679257367334, 0.09030615777841636, 0.061916998986686976, 0.02606876749944474, 0.07470393713031497, 0.02823732979595661, 0.051515545696020126, 0.015667680617687956, 0.02128766048034387, 0.018577416893094778, 0.017466212323467647, 0.06246520099895341, 0.028448657831177115, 0.042374603516821346, 0.04044316037158881, 0.07718315481075219, 0.021112956372754912, 0.03363941510074905, 0.12922949131046021, 0.05123308513845716, 0.02380791595870895, 0.0403255872162325, 0.03239352981160794, 0.09707282789583717, 0.027783819041880112, 0.05815306345799139, 0.028600647979016815, 0.017434509471058846, 0.045194771473429034, 0.053233555651136806, 0.01005809591151774, 0.06312877432044063, 0.025230929421793138, 0.04284008193228926, 0.028295727912336588, 0.033561682129012685, 0.02146231030513133, 0.0627705417573452, 0.043537843240691085, 0.0890007038999881, 0.03459486365318298, 0.012061209318095019, 0.04312308192519205, 0.03887408885306545, 0.02101841608860663, 0.040514376014471054, 0.05373331026307174, 0.09534595627337694, 0.07811052219143935, 0.03162364701607397, 0.05366518195452435, 0.03530907604311194, 0.01229870760081602, 0.03613048678796206, 0.016738422447815537, 0.06368667259812355, 0.06601273813950163, 0.06226485674934728, 0.025789104202496152, 0.017931509230818068, 0.07444656201239143, 0.06541313709957258, 0.11070188228040934, 0.0774913929136736, 0.030520715484661714, 0.07018378789403609, 0.02286215010099113, 0.008446017147174903, 0.0521013283702944, 0.035747233246053965, 0.018067411313365613, 0.046240807843527625, 0.04067289197285261, 0.042186574677803686, 0.01701625030753868, 0.022285364801064134, 0.022583752271852324, 0.03944563586264849, 0.0592107909864613, 0.040587040329618115, 0.03401171030210597, 0.07262297200837306, 0.03006780693041427, 0.09645399717347962, 0.08635282955531563, 0.040401664562523365, 0.0031768666064765838, 0.07423143248472895, 0.03888965444639325, 0.04988045611285737, 0.09600667296243565, 0.10071598419121333, 0.05841895419039896, 0.060043326312942166, 0.08558280766010284, 0.06257498796497073, 0.1541224577065025, 0.23767610639333725, 0.27612038063151495, 0.7871740662625858, 1.8976018897124698, 5.383307065282549, 13.015900611877441, 22.961612871715, 32.24220882143293, 43.73460919516427, 51.82387569972447, 53.90853330067226, 57.38877132960728, 60.01906749180385, 64.91659559522355, 57.77401072638375, 54.13770920889718, 55.42683628627232, 41.65515579496111, 41.247831548963276, 26.766894578933716, 19.429357154028757, 20.07872884614127, 15.332440444401332, 13.235334277153015, 12.304730772972107, 17.33821862084525, 19.302262442452566, 21.785241161073955, 32.947159154074534, 37.0381612096514, 40.834462370191304, 30.687792573656353, 16.769397394997732, 5.729369044303894, 0.9935121685266495, 0.2963711496974741, 0.0892093466328723, 0.06144813128880092, 0.040443642131452046, 0.06358333171478339, 0.07392580674162932, 0.07346065741564546, 0.07198408379086427, 0.035024671482720544, 0.046982897844697745, 0.0341161673755518, 0.035004264542034695, 0.04749861838562148, 0.034647154954395125, 0.04190229225371565, 0.018875057975362455, 0.012557810438530785, 0.04632628629250186, 0.021475387371278236, 0.06562817163233246, 0.015348989682804261, 0.06131520627864769, 0.03512798522465995, 0.06500123241650206, 0.05219457943790725, 0.043441586262945614, 0.024261818566758717, 0.016999990912154317, 0.02633116377650627, 0.09903958878879036, 0.027098617416673472, 0.024285726748140793, 0.034457626552986245, 0.016560558063377227, 0.01800943897770984, 0.036168192978948355, 0.019600340664120655, 0.06721491898809161, 0.051583321166357825, 0.024217098020017147, 0.03853347445172923, 0.03539245103352836, 0.03185293756957565, 0.04436492653829711, 0.07041856101048843, 0.10080461443534919, 0.016638107830658555, 0.044377550682319064, 0.07030485889741353, 0.07172100897878408, 0.026763378709022487, 0.059899945078151565, 0.016835909270282303, 0.03421161011127489, 0.020172822355691875, 0.04122093452938965, 0.06391107091414076, 0.05072349516142692, 0.02875331835821271, 0.03215599845030478, 0.03616576721625669, 0.007457249980819012, 0.07867155530090843, 0.005144964213416512, 0.044394537806510925, 0.055199122322457175, 0.056083840384547196, 0.04167672346479126, 0.011855569102668335, 0.09848743091736521, 0.05883904879114457, 0.1314030018235956, 0.147659764492086, 0.12735646324498312, 0.10075291006692819, 0.19568236118980817, 0.13311755125011715, 0.08229514264634677, 0.1028424993689571, 0.1516061377312456, 0.12327553651162557, 0.12625815932239803, 0.163563498961074, 0.23179136216640472, 0.20007879313613686, 0.21552999903048786, 0.09524254075118474, 0.14172913772719248, 0.1420213013355221, 0.10471579206309148, 0.2743935361504555, 0.27122453334076063, 0.16014299036136695, 0.14014669906880173, 0.14201632088848523, 0.14821329978959902, 0.15153974986502103, 0.175270657188126, 0.13484913190560682, 0.1344738613281931, 0.13665632850357465, 0.14049068918185575, 0.11993808059820107, 0.11561889307839529, 0.2154310821954693, 0.17051685441817555, 0.1364363610212292, 0.22825831174850464, 0.1846868097782135, 0.16744664630719594, 0.15045113542250224, 0.1314272526651621, 0.1818948145955801, 0.1695012774850641, 0.10800016618200711, 0.10795405972748995, 0.14885281904467515, 0.17220302751021727, 0.1302276434642928, 0.14520889600472792, 0.18069308836545261, 0.08871732053479978, 0.12282557279935905, 0.1520254180899688, 0.06465555953660182, 0.1334217113575765, 0.13270699685173376, 0.15384305055652345, 0.19323111272283963, 0.15637733813907417, 0.08555635157972574, 0.2521872834435531, 0.12938175456864492, 0.14042578052197183, 0.13967027249080793, 0.15291096057210649, 0.11549457189227853, 0.116465867630073, 0.10290581347154719, 0.13193939732653753, 0.33579213438289507, 0.38048403337597847, 0.3952641002833843, 1.0101831768240248, 2.5644700144018446, 6.926104622227805, 15.750701154981341, 26.637081384658813, 38.596638679504395, 51.74723012106759, 59.27531841823033, 62.63605090550014, 67.1149569920131, 68.8917155947004, 75.58020441872733, 66.53608172280448, 62.415403911045615, 63.938039098467144, 50.61772748402187, 47.97648096084595, 34.90961531230381, 27.52452094214303, 26.91004310335432, 20.49716326168605, 16.599645955221995, 16.42650032043457, 21.850378785814556, 24.475427321025304, 29.00283704485212, 39.14553941999163, 43.33828394753592, 45.02782528741019, 34.554593631199424, 19.590008190699987, 7.085542763982501, 1.0005460253783633, 0.30864446397338596, 0.16004931181669235, 0.20503509789705276, 0.1656110326626471, 0.12213230000010558, 0.20003297845167772, 0.1171836219727993, 0.17259959051651613, 0.16094944280173096, 0.1370488881532635, 0.1608384751847812, 0.11425700544246606, 0.13878076736416134, 0.11501537689140864, 0.20449944878263132, 0.18215227792305605, 0.09376836235501937, 0.17162372145269597, 0.09512642305344343, 0.10858534835278988, 0.14451772666403226, 0.09766611856009279, 0.24733206682971545, 0.11738989661846842, 0.1720556497041668, 0.12491794409496443, 0.11247531497584921, 0.1424257489187377, 0.12667620474738733, 0.2384348442511899, 0.10903044696897268, 0.06021485996565648, 0.1837105064519814, 0.08387749988053526, 0.08112747208880526, 0.2601498376045908, 0.14104437375707285, 0.17698644154838153, 0.17417095548340253, 0.16751201637089252, 0.16428533808461257, 0.15248823325548852, 0.15867917319493635, 0.14300656132400036, 0.23470173456839152, 0.16848358352269444, 0.2165033303733383, 0.26091185957193375, 0.13255645707249641, 0.1401231810450554, 0.12066405878535338, 0.1719186127718006, 0.12833457147436483, 0.1242489085665771, 0.1485522144607135, 0.16309748111026628, 0.14071589495454515, 0.14951715911073343, 0.11442324652203492, 0.2022912787007434, 0.15123035146721772, 0.3233807789427893, 0.25899350536721094, 0.21656665126127855, 0.19210428318807057, 0.16021673354719365, 0.18685927534742014, 0.2298410353916032, 0.08766808147941317, 0.14520557118313654, 0.17019113046782358], [0.031140662397124937, 0.011263560869597962, 0.04005116729864052, 0.047654125041195323, 0.06405872691954885, 0.035435717818992477, 0.023436194119442786, 0.01935007659319256, 0.05129424828503813, 0.10922857919441802, 0.03762455643819911, 0.08178896230778523, 0.03662779188847967, 0.02888386171045048, 0.0641818470986826, 0.0430889176870031, 0.045573672213192494, 0.0724817756563425, 0.015744992897712758, 0.0013961459148309327, 0.031032405527574674, 0.011271531111560762, 0.06296305571283613, 0.05751444665449006, 0.03641550542254533, 0.029850590907569443, 0.04115564928257039, 0.01839694693418486, 0.055993839499673674, 0.006276621948927641, 0.05664614235450115, 0.05918993281998804, 0.06827126909047365, 0.02749819990380534, 0.032101461198180914, 0.07007826212793589, 0.03152975134019341, 0.011749303733397807, 0.03751105788562979, 0.09819960993315492, 0.05227515886404684, 0.02806338225491345, 0.03253741655498743, 0.014825976586767604, 0.062423172539898326, 0.05476725174646292, 0.04459759280351656, 0.08030380521501813, 0.03609019537855472, 0.006294728231815887, 0.025231180479750037, 0.02275478550499039, 0.006938996383853788, 0.04651665607733386, 0.0328275547362864, 0.02445660052554948, 0.02233640759784196, 0.047608666587620974, 0.04039877400334392, 0.059940338267811706, 0.066285061383886, 0.028562738227524927, 0.045992365639124594, 0.047437960747629404, 0.1483617089688778, 0.23020725431186811, 0.1120250527081745, 0.38617314238633427, 0.6530780675155776, 2.5810670895235877, 3.907796732016972, 6.954923578671046, 11.159264649663653, 21.488615615027292, 38.46676989964077, 47.35374518803188, 55.44673245293753, 63.3655492237636, 74.19066892351422, 70.74876063210624, 67.96752180371965, 73.82012149265834, 74.19096769605363, 68.26770482744489, 69.65352303641183, 77.91158212934221, 77.41135351998466, 76.50648266928536, 64.06040382385254, 63.20040443965367, 48.64851072856358, 54.39862796238491, 49.28920759473528, 54.434529304504395, 45.84968948364258, 55.34898172106062, 58.24790913718087, 58.83340603964669, 66.15837069920131, 62.27131911686489, 70.34380572182792, 59.3906307220459, 55.972617285592214, 32.63504607336861, 18.688816411154612, 2.797286344426019, 0.32942603741373333, 0.0868970960644739, 0.06209427983100925, 0.05251508545396583, 0.027199834485405257, 0.08628364612481423, 0.04235999805054494, 0.049390974521104775, 0.014890440806214298, 0.06724883216832366, 0.047576602415314743, 0.045383553486317396, 0.026486751856282353, 0.02499167967055525, 0.06995549478701182, 0.010387004735613508, 0.06827751161264521, 0.05291594019425767, 0.028088428678789308, 0.03900475773428168, 0.02526894604255046, 0.06837116980126925, 0.029355297663382122, 0.05039524706080556, 0.02333470224402845, 0.04341476038098335, 0.03467200290677803, 0.03849446547350713, 0.02527096977324358, 0.03390667986656938, 0.016070399632943527, 0.011008864268660545, 0.030717897761080946, 0.03660840953567198, 0.016859142309320823, 0.009315196757337876, 0.047251858948064704, 0.0659718428339277, 0.027400044724345207, 0.028288759357695068, 0.023549484022493874, 0.0400284363755158, 0.02259507023596338, 0.02257856147895966, 0.013400586554780602, 0.02800877036393753, 0.012052670803054102, 0.027164974748822193, 0.02939415057854993, 0.023191019061154554, 0.049088327546737025, 0.018486308299803307, 0.02260237805811422, 0.05507276892395956, 0.04273889200495822, 0.013404427062986153, 0.02557718244913433, 0.058154284821024964, 0.012283655149596078, 0.012000393072542335, 0.09879709394382578, 0.03476157631458981, 0.0304330182261765, 0.04496475149478231, 0.019141354132443666, 0.03322754095175436, 0.06312040119831051, 0.021914923696645668, 0.02802603568748704, 0.029355982983750955, 0.0603213831782341, 0.06274946645966598, 0.0009854615345830098, 0.02573597151786089, 0.03110366527523313, 0.04198498192376324, 0.03522349242120981, 0.03233111137524247, 0.019778335666550056, 0.10335375514945813, 0.055188384505787065, 0.014448166592046618, 0.026661852906857218, 0.0734948827219861, 0.05834067839064768, 0.024937742921922888, 0.04083438330729093, 0.019414169314716543, 0.050183466103460105, 0.04050418781116605, 0.02176439409543361, 0.025635626366628066, 0.05688823686380472, 0.033468705868082385, 0.06660850545657532, 0.0719284914167864, 0.06697041567947183, 0.034468510254685364, 0.1282683735979455, 0.04762454430705734, 0.04047126529206123, 0.05273346516436764, 0.02758186327160469, 0.017711736827290485, 0.03327476020370211, 0.031853738240897655, 0.037945320297564776, 0.028471855247127156, 0.01723190230716552, 0.07655654807708093, 0.06456282415560313, 0.032622528595051596, 0.006369052413252315, 0.03653324142630611, 0.012008936676595892, 0.00946389346583081, 0.03289383403690798, 0.03349558603284614, 0.01962667121551931, 0.06631261669099331, 0.029397200593458753, 0.12875254904585226, 0.022313854790159633, 0.0060125085541845435, 0.09180966245808772, 0.04830493511898177, 0.01567084089453731, 0.04012866956847055, 0.07858105908547129, 0.06744407383458954, 0.026295225169243555, 0.012906348432547279, 0.051974086090922356, 0.017655559216759036, 0.19087031297385693, 0.10529110154935292, 0.2154841029218265, 0.3646781843687807, 0.8249594015734536, 2.9235275132315497, 4.397292980125972, 9.803202969687325, 14.921735899788992, 27.60317976134164, 48.210854121616904, 58.56626170022147, 67.05937835148403, 74.53311089106968, 86.50462082454136, 80.75065081460136, 78.91056632995605, 83.94742665972028, 81.95985971178327, 78.48322432381767, 80.10965864998954, 87.28123487745012, 86.61604908534459, 84.0024494443621, 72.67908137185233, 72.5891022000994, 57.38238246100289, 64.03541115352085, 55.68060186931065, 58.73288645063128, 52.147071157182964, 64.60795661381313, 67.38487366267613, 68.36598014831543, 73.82065650394985, 72.38331045423234, 82.36297334943498, 70.43180465698242, 68.77053901127407, 44.02218471254621, 27.344628606523784, 6.243514026914324, 0.5502973826868194, 0.06342016439884901, 0.018301146271239434, 0.055381705917950184, 0.03287018369883299, 0.06089982749628169, 0.023148293407367806, 0.09551624820700713, 0.04209313022771052, 0.04147861498807158, 0.0381867871619761, 0.012913315290851253, 0.018413528633703078, 0.0190147004822003, 0.06367010955831834, 0.027141775636534606, 0.04193665326706, 0.07436342111655644, 0.05338895034843257, 0.019372398698968545, 0.027247956188927804, 0.010261323086784353, 0.012669230129436722, 0.05947214231959411, 0.029762486528073038, 0.05307253250586135, 0.07269834367824451, 0.021349142538383603, 0.03455463331192732, 0.04186207887583545, 0.04615116658221398, 0.0328930197948856, 0.01865380975816931, 0.04513234964438847, 0.01362504084993686, 0.07269872365785496, 0.09144317212381534, 0.021971410040610602, 0.006482722295913845, 0.017323183926886747, 0.015975250363616005, 0.08585306137268033, 0.04069880861788988, 0.03949192552162068, 0.06127893179655075, 0.04684142668598464, 0.05121791309544018, 0.004857782324376915, 0.06040307879447937, 0.02804969111457467, 0.023815825980688845, 0.01744013961537608, 0.03723690938204527, 0.02950215639014329, 0.01661944811764572, 0.031623596125947576, 0.0277128883837057, 0.009959994166690325, 0.04470677587336727, 0.062053845929247994, 0.08464038358735186, 0.018887419187064682, 0.0011313767796049692, 0.020161346632188985, 0.07820010238460132, 0.038936039100268056, 0.019254186024357165, 0.04476880754477211, 0.02243033889681101, 0.04426544312653797, 0.12681584725422518, 0.1907101787094559, 0.1189660791839872, 0.12299283168145589, 0.2095726379858596, 0.11652990776513304, 0.13240131682583264, 0.1712050653461899, 0.31831320800951546, 0.2201784795948437, 0.16656199949128286, 0.12437936370926243, 0.16143546386488847, 0.11772741350744452, 0.20438184509319918, 0.1130011999713523, 0.09565054385789803, 0.16502890389944824, 0.1050758431000369, 0.07749564054289035, 0.13114909401961736, 0.13758932772491658, 0.17571231563176426, 0.22550321530018533, 0.2259825731494597, 0.1494388561695814, 0.2514410577714443, 0.13456663063594274, 0.22152728507561342, 0.14633130149117538, 0.10888761534754719, 0.19700706510671548, 0.12057979830673762, 0.12025440005319459, 0.1484986644770418, 0.0724197779116886, 0.08691781852394342, 0.05849290093673127, 0.17784945666790009, 0.19110490967120441, 0.1389675544840949, 0.1775460293782609, 0.1307357983397586, 0.11624656511204583, 0.10292526028518166, 0.0886382372783763, 0.12616754775600775, 0.1521306045885597, 0.12055151696716036, 0.16350620346409933, 0.11991540395787784, 0.14767049891608103, 0.07014988149915423, 0.10878540761768818, 0.14402937144041061, 0.10165612160095147, 0.14288940546768053, 0.12587632052600384, 0.18139109733913625, 0.11481618615133421, 0.14809736529631273, 0.12530151994100638, 0.1608720083854028, 0.1973156085503953, 0.24157662423593657, 0.4316334415759359, 0.28505109569856096, 0.682219029537269, 1.1666239308459418, 3.5522459021636417, 5.766142385346549, 12.897854191916329, 18.067708253860474, 33.50209093093872, 56.47898462840489, 65.5559549331665, 77.6728628703526, 85.67102459498814, 96.24015181405204, 92.18620450156075, 88.74383762904576, 94.06546987806047, 94.52236257280622, 91.434951373509, 91.73406437465123, 98.53326579502651, 97.70497798919678, 95.75057479313442, 82.70031533922467, 83.1897325515747, 66.5049329485212, 73.97782475607735, 66.87860706874302, 69.95707593645368, 62.19522244589669, 75.99221869877407, 78.48996407645089, 80.33474554334367, 84.61268193381173, 84.11098030635289, 96.85929884229387, 83.57753930773053, 77.69390201568604, 52.59830107007708, 31.365613664899552, 6.329157957008906, 0.5552715872015271, 0.21932390545095715, 0.12847322332007544, 0.16057474219373294, 0.08465408999472857, 0.25636114233306473, 0.14341159244733198, 0.1808474822235959, 0.0730469139026744, 0.10861680523625442, 0.18925563033138001, 0.09925530864191906, 0.059617559159440656, 0.12718058696814946, 0.160581038998706, 0.2264080960303545, 0.15096660490546907, 0.11245547461190394, 0.11163916305771895, 0.3076270685664245, 0.14898631402424403, 0.10971441705312047, 0.0857024605252913, 0.11753606663218566, 0.08527534308710269, 0.06250835582613945, 0.1250402975295271, 0.11130466564957585, 0.09337287143404994, 0.12106568366289139, 0.10923068265297584, 0.13143076747655869, 0.1430283830102001, 0.11604181038481848, 0.09970217144915036, 0.09820245978023324, 0.2437637054494449, 0.19843980536929198, 0.1414061143462147, 0.1140053096626486, 0.14962765175317014, 0.1944405742521797, 0.13787218183279037, 0.22982518481356756, 0.18036234325596265, 0.10930667857506446, 0.175270657188126, 0.1181905407990728, 0.26253686951739447, 0.13427980031285966, 0.12461431324481964, 0.16871165271316255, 0.09235316222267491, 0.14156307306672844, 0.1027439014453973, 0.15142530814877578, 0.1180294430149453, 0.1599961689540318, 0.216651373143707, 0.15985025678362164, 0.2021524097238268, 0.12092336772808007, 0.11148350712444101, 0.12178567717117922, 0.239885362131255, 0.12091293185949326, 0.17946732842496463, 0.08432455267757177, 0.11172431241720915, 0.09840195586106606], [0.015001688318859254, 0.14187224076262542, 0.005411404559189188, 0.046642887339528115, 0.007182255004798728, 0.052625852903085094, 0.022215394269941107, 0.049923566835267205, 0.018829774244555404, 0.07773090898990631, 0.031063977761992385, 0.019284172183168784, 0.0490435578062066, 0.0030039171480374144, 0.019650881344984685, 0.010452795491021658, 0.016753916794966375, 0.01957810507155955, 0.01307577608219747, 0.031463176876838715, 0.04372774822903531, 0.04065454438594835, 0.019902780685307722, 0.026209599138902764, 0.0548482925764152, 0.05192409163074834, 0.03434577005516205, 0.027369814292926873, 0.0511299478156226, 0.015831010782026818, 0.013402371950048422, 0.03148099520642843, 0.02330104690710349, 0.06650668449167695, 0.024587366098005856, 0.01334055740984955, 0.010016789244088744, 0.033531585708260536, 0.05037366286186235, 0.019569027969347577, 0.04745305136644414, 0.036510262837899585, 0.02593641585138227, 0.03248422619487558, 0.027243435449366058, 0.06245756747999361, 0.012128325761295855, 0.1045374662748405, 0.017072986013122966, 0.023412408074364066, 0.009228263698917414, 0.020010986664731587, 0.017504306975752115, 0.010921389230393937, 0.06420501228421926, 0.1081930465464081, 0.03343488768275295, 0.17193443620843546, 0.10627636153783117, 0.3782454106424536, 0.27096180458153996, 0.4616952570421355, 0.6463379891855376, 0.701791236443179, 0.3739482212279524, 0.856756258223738, 1.9540868358952659, 3.6539469020707265, 7.844239149774824, 13.182050279208593, 22.832287788391113, 36.391950947897776, 48.22868319920131, 58.67753710065569, 64.40856415884835, 70.74316038404191, 65.36776297433036, 65.43142931801933, 65.01027120862688, 63.82868834904262, 56.38820988791329, 52.84099122456142, 60.23678234645298, 50.969751017434255, 52.55998175484793, 46.82783603668213, 54.17832142966134, 50.7932459286281, 58.5320348739624, 60.134046282087056, 62.157521520342144, 57.6576874596732, 57.42705937794277, 62.71300915309361, 63.26850373404366, 68.06559562683105, 64.37364251273019, 68.77700778416225, 66.71667930058071, 60.605731691632954, 64.53477123805455, 66.88719504220145, 60.73299489702497, 64.55903434753418, 58.8357058933803, 38.771677698407856, 13.086713177817208, 2.254952520132065, 0.1768539236592395, 0.08791561783956629, 0.08001391469900097, 0.021962694258296063, 0.020492159595180835, 0.12080047146550246, 0.0649541285155075, 0.04655882702874286, 0.015301300545356103, 0.04003458729545985, 0.05940496056739773, 0.010719882141399597, 0.01829632358359439, 0.04825720018041985, 0.05000562886042254, 0.022498909949458072, 0.0910359900444746, 0.07458522064345223, 0.04443505313247442, 0.019827928094725524, 0.011343533855064638, 0.011320180376060307, 0.04837879365576165, 0.018388319361422743, 0.034373501781374216, 0.11791348138025828, 0.01195710847553398, 0.03357724093699029, 0.04132409220827477, 0.009406499581278434, 0.09989924515996661, 0.013348401274665125, 0.017648931625964384, 0.05536882732329624, 0.020344527338498404, 0.03867782599159649, 0.07350486397211041, 0.04789278616330453, 0.06878762066896472, 0.012017994270926076, 0.014429578125210745, 0.03995362788970981, 0.016178717570645467, 0.04291932125176702, 0.06945320245410715, 0.029206959730280296, 0.028349335571484904, 0.026049553084054163, 0.0066999277166490045, 0.05118585231580904, 0.037359992241753, 0.01215728309138545, 0.03120197482141001, 0.013698247993098838, 0.07423289133501904, 0.03959676596735205, 0.020588413180251206, 0.06421105124588523, 0.08692474636648383, 0.04947049203994019, 0.051277339192373414, 0.026704061177692244, 0.035316977583404095, 0.04558904781671507, 0.051899813647781096, 0.033537248082991154, 0.053366470483264754, 0.036047152509646754, 0.034670255679105005, 0.04242616878556354, 0.026945131099117652, 0.005447382182215473, 0.005735331663994917, 0.03899883073089378, 0.03765784197353891, 0.02885018601747496, 0.04801730412457671, 0.020417276470522796, 0.02761949991275157, 0.015646730848987187, 0.019668945643518652, 0.010582769722012537, 0.03745479036920837, 0.01851240306028298, 0.016009236486362557, 0.032375955754624944, 0.059345134134803496, 0.0890156113143478, 0.027391795434855988, 0.05565034471718328, 0.006027303162097398, 0.03376142248245222, 0.007737024387876902, 0.028791950749499456, 0.03851477741929037, 0.018700457344363843, 0.0812509043940476, 0.020432630021657263, 0.04492161702364683, 0.015081078612378665, 0.011538695793465843, 0.02201074980465429, 0.029561484099498818, 0.019662021193653345, 0.018220668625352637, 0.07190514302679471, 0.07234724930354527, 0.014266831500987922, 0.012655150527799768, 0.014536169191290225, 0.015489544819242187, 0.03623407194390893, 0.06101946000541959, 0.0063383109601480615, 0.04024229704269341, 0.034754930064082146, 0.06329131738415786, 0.026317591379795755, 0.046903577101017745, 0.06711018032261304, 0.03872698924637266, 0.03076147667265364, 0.01343401288613677, 0.09182879036026341, 0.04483756010553666, 0.15118687094322272, 0.1293116890426193, 0.4766860497849328, 0.31116410877023426, 0.5209133422800473, 0.6251923952783857, 0.741683015865939, 0.5890847242304257, 1.268402338027954, 2.595498715128217, 5.78287364755358, 9.829240475382123, 19.390073776245117, 32.86110918862479, 47.082404136657715, 58.29547650473458, 67.60015664781842, 73.39264747074672, 79.66096482958112, 74.24483013153076, 74.7845036642892, 73.09986427852085, 73.5095578602382, 65.55820614950997, 61.666721616472515, 68.24555397033691, 58.343391282217844, 63.97437122889927, 55.52496916907174, 63.74966648646763, 60.92559201376778, 66.81992258344377, 68.2254945210048, 73.68424946921212, 64.31704943520683, 67.77222878592355, 71.93367167881557, 71.51509135110038, 76.19532149178642, 73.60411589486259, 75.56821877615792, 75.39766829354423, 66.37040192740304, 73.200286592756, 73.60293470110211, 68.08872617994035, 72.91895403180803, 69.38607992444719, 51.466689654758994, 20.83808183670044, 4.355168657643454, 0.2949684006827218, 0.018951837605397617, 0.08221941813826561, 0.032001112654272995, 0.00876621697430632, 0.05588787607848644, 0.014014140819199383, 0.017397933040878603, 0.019687557859080176, 0.07227623382849352, 0.06883435137569904, 0.032094767450221946, 0.02001139717841787, 0.055230066911982637, 0.04145796377477901, 0.04981007506804807, 0.00977320535041924, 0.04748332081362605, 0.06434020360133477, 0.01664711707936866, 0.021912124739693742, 0.019471508916467428, 0.06010125284748418, 0.0453162801318935, 0.048539742162185054, 0.03253802384382912, 0.01241956147298749, 0.044705194886773825, 0.037049939057656696, 0.06405768197562013, 0.056737802257495265, 0.04190273330147777, 0.03586267240877662, 0.010881677120258766, 0.04612608114257455, 0.007507570137801979, 0.006812729498571051, 0.04774577137348907, 0.05642951326444745, 0.053732669047479115, 0.01935558969021908, 0.04549820215574332, 0.04671374675152557, 0.055896635965577195, 0.0410708052638386, 0.06259279272386006, 0.030394470651767085, 0.06995006650686264, 0.04531021402882678, 0.06456188099192721, 0.029017648460077386, 0.031531410358314, 0.02040087797545961, 0.02778966971007841, 0.0370030455025179, 0.03092689672484994, 0.012359156589289861, 0.047736553475260735, 0.06702238467655011, 0.04787992453202605, 0.02426890077601586, 0.03273414421294417, 0.0011101176413441344, 0.028359662874468734, 0.017737443126471977, 0.03238921432888933, 0.028081536459337388, 0.016263235892568315, 0.12606778953756603, 0.20917716063559055, 0.16303439092423233, 0.08303581790200301, 0.08496033320469515, 0.16682400900338376, 0.13522471460912908, 0.14801125920244626, 0.16136562904076918, 0.21667493187955447, 0.11125382302062851, 0.07258005466844354, 0.1335324618433203, 0.11489419053707804, 0.22565652350229876, 0.08969213108399085, 0.18213853080357822, 0.21052782530231134, 0.138733853452972, 0.20049549506178924, 0.08101472671010665, 0.14778287788586958, 0.08812859641121966, 0.08727697389466421, 0.164412739819714, 0.14090923672275885, 0.10831811412104539, 0.13112955221108027, 0.12975384960217135, 0.1179844561432089, 0.10251748109502451, 0.13941788460527146, 0.058907472262425084, 0.1883869290884052, 0.09798458218574524, 0.11364966231797423, 0.09874266186462981, 0.17567433124142035, 0.10274280221866709, 0.14883691418383801, 0.10988271409379584, 0.22341499663889408, 0.11415796647114412, 0.10400575266352721, 0.12038986278431756, 0.10129566344299487, 0.11929321448717799, 0.1705502247703927, 0.08598431718668767, 0.10178514503474746, 0.13772408477962017, 0.09988631906786136, 0.231156551944358, 0.09967904697571482, 0.16300422325730324, 0.18015971912869386, 0.09022412289466177, 0.36302038761121885, 0.3076365409152848, 0.826252526470593, 0.7097424183573041, 1.0193677182708467, 1.2353536656924655, 1.2684149316379, 1.5503820585353034, 2.4718018897942136, 4.236572461468833, 7.6645830529076715, 13.49390367099217, 24.872511659349712, 40.26138884680611, 55.85291372026716, 66.9122849873134, 79.30571038382394, 82.8296560559954, 90.5264813559396, 86.21242128099713, 85.94470718928746, 85.09514399937221, 85.92242431640625, 77.21826308114188, 70.8641493661063, 82.99879605429513, 73.73044109344482, 75.22200393676758, 64.93637016841343, 73.20326736995152, 68.35211154392788, 77.31714984348842, 79.95208045414516, 82.69698020390102, 74.91537993294853, 77.07454654148647, 81.37896946498326, 82.09794821058, 85.4947349003383, 83.60128825051444, 85.99875722612653, 85.02485602242606, 77.87172031402588, 84.01790223802838, 84.55262865339006, 80.58570058005196, 85.91882514953613, 79.10186413356236, 57.10504511424473, 23.9400668825422, 5.404737481049128, 0.43217274120875765, 0.1652538925409317, 0.3099612018891743, 0.09440889941262347, 0.14876254674579414, 0.2739094964095524, 0.2074797781450408, 0.10232618850256715, 0.07987887265958957, 0.12298084875302655, 0.12838782290262835, 0.11243040952831507, 0.1069218044036201, 0.12728395499289036, 0.14834291354886123, 0.16703877890748636, 0.1432261759681361, 0.1863782483019999, 0.10737195810569183, 0.11114491136478526, 0.07784393935331277, 0.10441984901470797, 0.11257592814841441, 0.11217568748231445, 0.08754854396517787, 0.2314648511154311, 0.08673962844269616, 0.0860107121989131, 0.19288761115499906, 0.15670633262821607, 0.2318955308624676, 0.17185678466090135, 0.1509279826922076, 0.15236752187567099, 0.12986837274261884, 0.1764310606356178, 0.16001712211540767, 0.12465902870254857, 0.18172443445239747, 0.09836076200008392, 0.08376516162284783, 0.11432823804872376, 0.0948376656909074, 0.19722369419676916, 0.17557215743831225, 0.15283659313406261, 0.17640172078141145, 0.20732142164238862, 0.11810109631291457, 0.17531628188277992, 0.09365516235785824, 0.08619009650179318, 0.11143825562404734, 0.16492795145937375, 0.1483243624014514, 0.11432333902588912, 0.08913947788200208, 0.12018883999969278, 0.24756667709776334, 0.28240787610411644, 0.1467563629682575, 0.15755566848175867, 0.10408684438360588, 0.10484183672815561, 0.1201152325208698, 0.1360766017543418, 0.1738974651587861, 0.18681822397879191], [0.028294874654550637, 0.028006275051406453, 0.029686069914272854, 0.06598138303628989, 0.057192827841000896, 0.026253605527537208, 0.04386922956577369, 0.016300758879099573, 0.05286179309976952, 0.009586054366081953, 0.0176001534398113, 0.009903562953695655, 0.021360280690714717, 0.07337267856512751, 0.05753645833049502, 0.01904676465450653, 0.03160901101572173, 0.0669695742960487, 0.07633705556924854, 0.0569859900112663, 0.03672839827569468, 0.06153879713799272, 0.033268236089497805, 0.02980717145172613, 0.02443441582311477, 0.017369828120406185, 0.08455807050423962, 0.030125974344887903, 0.017333482392132282, 0.020454667142725418, 0.03049997266914163, 0.03566582939986672, 0.047554848582616875, 0.059743814170360565, 0.03222078158121024, 0.03692781971767545, 0.03847720354263272, 0.06230507351990257, 0.07286316661962441, 0.04331319047404187, 0.03428815903940371, 0.023349574035299674, 0.06623778106378657, 0.11035567335784435, 0.04346339777112007, 0.009844795035730516, 0.04957254709942, 0.02978543797507882, 0.06270884935344968, 0.09930602234921285, 0.046848052580441744, 0.04087366709219558, 0.08420401771685906, 0.01628211443312466, 0.018376646862764443, 0.022635500745049546, 0.761165167604174, 2.1810820954186574, 3.4547266321522847, 5.004423967429569, 8.958501781736102, 8.866427728107997, 8.528699244771685, 14.478557212012154, 15.306773798806326, 14.548966782433645, 17.795941625322612, 40.72982597351074, 37.52032102857317, 55.050709451947895, 61.005600520542686, 68.30564893995012, 62.72329943520682, 69.39372294289726, 60.7564937046596, 54.51539591380528, 42.606583050319124, 44.84792252949306, 42.46823399407523, 48.406935759953086, 42.04463011877877, 40.054360321589876, 36.60204015459333, 33.61243527276175, 42.68982941763741, 31.819796562194824, 40.000619479588096, 37.1708961214338, 37.201131207602366, 37.450769560677664, 37.60319219316755, 53.00889444351196, 42.05072021484375, 49.083037172045024, 52.803700242723735, 46.40051140104021, 50.10273395265852, 52.70164510181972, 47.65584591456822, 34.68760994502476, 53.32946000780378, 57.01069205147879, 53.825512749808176, 57.50497300284249, 64.81396375383649, 65.3206889288766, 54.32647092001778, 23.810663631984166, 9.020489266940526, 1.7394453649009978, 0.22172452163483414, 0.035530861999307356, 0.048716120554932525, 0.03454215844560947, 0.035581097339413, 0.07718797919473477, 0.023318527665521418, 0.02405257702672056, 0.022922592304114784, 0.05724645246352468, 0.034321889015180726, 0.02253831926334117, 0.08202559461018868, 0.04191304024841104, 0.02201027313380369, 0.03110075436000313, 0.020872040818046247, 0.03439535400164979, 0.0071931895966242465, 0.0719408882515771, 0.08982882874884776, 0.06303793883749417, 0.028627487431679453, 0.09190251319003956, 0.04192208172753453, 0.02841961313970387, 0.05496238484712584, 0.05758279548691852, 0.09661918652376958, 0.02894062116476042, 0.038029170262494257, 0.04392091018546905, 0.004292638140863606, 0.06038435801331486, 0.029218114845986878, 0.006483043327794543, 0.032422723780785284, 0.060584756545722485, 0.052541480466191254, 0.015460055687331727, 0.058129402941891124, 0.07037303809608732, 0.018225503187360506, 0.01794919863875423, 0.05112091651452439, 0.02116308993260775, 0.0606759652229292, 0.06923009335462536, 0.018982565063717108, 0.010199827458044248, 0.0035513403293277535, 0.024091604664655666, 0.021790141106716225, 0.0727638223075441, 0.057697915738182406, 0.037637801441763125, 0.058120948395558765, 0.056745398457029035, 0.033119341757680686, 0.018699758453294635, 0.027855967670412998, 0.05651202990806528, 0.04705879198653357, 0.059431097736316066, 0.020967481857431785, 0.04545425683526056, 0.013378316187299788, 0.06301131990871259, 0.022316139756834934, 0.01418709006559636, 0.057909313323242326, 0.047784444476876936, 0.05490166614098208, 0.036106307192572525, 0.038165789895824025, 0.017489908462656394, 0.036398687932108126, 0.011637291172519326, 0.031496703292110136, 0.04821935828242983, 0.0898953251806753, 0.04074040620720812, 0.0031420403725600666, 0.02274757607041725, 0.027613620406814983, 0.011446339543908834, 0.01898391025939158, 0.06581892818212509, 0.03895003388502768, 0.04386350951556649, 0.009290491297308887, 0.012978865166327782, 0.09636368416249752, 0.04371368898344891, 0.08402368346495287, 0.02879093973232167, 0.004382750984015209, 0.014829849325386541, 0.01643301044324679, 0.035429600825799365, 0.12681238672563008, 0.06657386624387332, 0.0706580499453204, 0.13011040618377073, 0.06216414179652929, 0.04117391883794751, 0.03709051884444697, 0.037309000335101566, 0.05708736992840256, 0.08780490806592361, 0.06434306023376328, 0.03362403949722648, 0.022259785727198635, 0.0062324026699310964, 0.009218402888758906, 0.053053587808140686, 0.03400699109105127, 0.0404118866925793, 0.10860059503465891, 0.09787978245211498, 0.04142716167760747, 0.03385977613340531, 0.9812720481838498, 2.510014376470021, 3.4327464401721954, 6.223490621362414, 10.211998496736799, 9.79231514249529, 9.29284736088344, 16.63343678201948, 17.642973559243337, 17.256865637642996, 23.406983716147288, 49.46752963747297, 48.282476152692524, 67.62908199855259, 71.96894073486328, 79.32309477669853, 71.67687320709229, 79.59699971335274, 69.40350600651333, 61.52713925497872, 53.21759401048933, 56.284077235630576, 54.123309067317415, 60.15366799490792, 49.323434420994346, 52.36633198601859, 46.78380530221121, 47.14219685963222, 51.93134001323155, 41.381226539611816, 48.526149477277485, 46.0697215625218, 46.47924838747297, 45.538382393973215, 45.9934789793832, 61.34578432355608, 52.413287912096294, 56.337963989802766, 60.73000717163086, 54.45920583180019, 57.367165906088694, 59.94385324205671, 55.00388206754412, 42.98284190041678, 60.421451568603516, 64.38594082423619, 62.44471141270229, 63.98481437138149, 71.2655884878976, 73.47877039228166, 65.58502619607108, 33.55519253867013, 14.336760112217494, 3.3823811198983873, 0.7238210971866335, 0.060596691976700506, 0.06960279906966857, 0.04161314134086881, 0.057059665343591144, 0.06733559644115822, 0.011958865033063506, 0.01032827837791826, 0.06309092563710042, 0.07177778878914458, 0.04638708981552294, 0.007819213638348239, 0.008325173453028713, 0.026645598600485494, 0.053827630023338964, 0.030008574215961353, 0.012340226310438343, 0.016824467473530343, 0.05307312622400267, 0.10381059242146355, 0.050823154992290905, 0.03735274888042893, 0.037849087068544965, 0.042364466203642745, 0.10578201484999486, 0.022817639900105338, 0.06830487014459712, 0.09773494915238448, 0.0876022025144526, 0.05867209524980613, 0.03342460787722042, 0.029244428434010063, 0.017126152624509165, 0.01328927542947765, 0.03551498767254608, 0.04178430519199797, 0.005397585769450026, 0.015018214039238436, 0.05402575885610921, 0.039283903648278544, 0.033029093207525353, 0.03363452286326459, 0.03007804263117058, 0.06494320410170726, 0.03535629529505968, 0.03483152988233736, 0.013756115155826722, 0.07215167515512023, 0.058413763397506306, 0.08920172668461289, 0.06852835922368936, 0.018551588457609926, 0.02604397722253842, 0.02116737318491297, 0.019153141982055137, 0.08675123817686524, 0.03426867151366813, 0.09209109164242234, 0.044378222431987524, 0.03501602355390787, 0.05231186082320554, 0.030216416277523552, 0.024162989941292574, 0.014503638526158673, 0.03407879027404955, 0.01415694021021149, 0.072450902312994, 0.1540412777768714, 0.13469921637858662, 0.08236176799982786, 0.15481874320123876, 0.11413596836583954, 0.1441474501043558, 0.08751953659313065, 0.1255039812198707, 0.14505087876958506, 0.0826023697320904, 0.13033515055264744, 0.10605792754462787, 0.1641680058091879, 0.15568221972457, 0.20988727467400686, 0.1091337539255619, 0.24343822577169963, 0.13800852665943758, 0.15378119530422346, 0.12618751025625638, 0.1359578309846776, 0.09030872264078685, 0.07567948728267636, 0.14296023095292704, 0.09662220600460257, 0.193119385146669, 0.2042738494596311, 0.08437200263142586, 0.10089791300041334, 0.21306015870400838, 0.09006371721625328, 0.1165707420025553, 0.16888984957976, 0.19603909419051238, 0.11229982546397618, 0.14610760206622736, 0.27647571585008074, 0.11800048314034939, 0.1588078641465732, 0.27986250125936096, 0.13520624488592148, 0.14221374743751117, 0.21745108094598564, 0.11001511663198471, 0.0780939320102334, 0.1309321392327547, 0.17005573559020246, 0.1414981372654438, 0.23827213155371801, 0.14421469292470387, 0.13418844235794886, 0.23932301944919995, 0.32048015030367033, 0.22007431089878082, 0.6485290059021541, 1.5492336515869414, 4.25513413974217, 5.997525649411338, 8.760462488446917, 13.929078033992223, 13.483115724154882, 13.110291889735631, 21.588883331843785, 23.197314875466482, 23.226294074739727, 31.997017315455846, 57.84876292092459, 57.14658144542149, 79.6653699874878, 84.02054950169155, 91.18890176500592, 80.96856021881104, 88.4791807447161, 80.39889131273542, 72.82800211225236, 61.17581748962402, 64.12309047154018, 61.41475214276995, 68.62092345101493, 60.22850704193115, 60.46713597433907, 56.85646636145455, 54.02211202893938, 58.9407696042742, 46.75826719829014, 58.0214638710022, 53.073196547372, 55.69873666763306, 54.33938414709908, 55.581218310764854, 71.23001371111188, 59.836468832833425, 66.32967853546143, 71.27191829681396, 63.25434330531529, 68.05297769818986, 68.66620486123222, 63.88462829589844, 51.84928526197161, 71.36455862862724, 73.52635860443115, 71.20974581582206, 73.27562591007778, 80.41583796909877, 84.01777022225517, 74.35429900033134, 38.32538448061262, 15.458687475749425, 3.9772235666002547, 0.737224063702992, 0.20013409374015673, 0.18515277334621974, 0.17735370541257517, 0.09930140831108604, 0.27231830464942114, 0.11861894066844668, 0.15095315634139947, 0.15457917962755474, 0.20834837082241262, 0.16175088765365736, 0.159316019022039, 0.13843179680407047, 0.11734915737594877, 0.19722349063626357, 0.179544260725379, 0.15857128612697124, 0.1745730553354536, 0.13315896902765545, 0.19031276074903353, 0.1647737475910357, 0.1853462779628379, 0.21289019925253733, 0.20097188092768192, 0.17050831844764097, 0.10996529180556536, 0.18291972817054816, 0.1401617761169161, 0.197815064606922, 0.1442160771361419, 0.13804036352251256, 0.13246851893407957, 0.14715857138591154, 0.14674986260277884, 0.129848912358284, 0.10085390321910381, 0.1436232818024499, 0.14110793891761983, 0.1615356427750417, 0.118721195895757, 0.10640942225498812, 0.12025724990027291, 0.17047382172729286, 0.07508493454328605, 0.1160644463130406, 0.13686165320021765, 0.18994054357920373, 0.16559966041573457, 0.15988407496895107, 0.1481261487518038, 0.12712224652724607, 0.14219531842640468, 0.11350161276225533, 0.13710418875728334, 0.15976398784135068, 0.166509209466832, 0.10440672614744731, 0.280735830111163, 0.11793642943458897, 0.18305452593735286, 0.15693577245942184, 0.1010035676881671, 0.19654176650302752, 0.09827329883618013, 0.11664652079343796, 0.13797796544219765], [0.026184286390032088, 0.09666653469737087, 0.024530289428574697, 0.08099924254098109, 0.06596716094229903, 0.041830306473587237, 0.025507462975968207, 0.04933136521971651, 0.02541640866547823, 0.10471656559301273, 0.012453483983076044, 0.049956173835588355, 0.00502816161939076, 0.020350130341414894, 0.03328848018177918, 0.055397627742162774, 0.08136756491980382, 0.02493327816150018, 0.026246299401723912, 0.014209872727016253, 0.07997531284179006, 0.07713546058429138, 0.05546852447358625, 0.06625741786722626, 0.029166678498898233, 0.05605359807876604, 0.05980247352272272, 0.014337370305189064, 0.04869920128424253, 0.03265585144981742, 0.05457089728276644, 0.09125272770013128, 0.055365767130362134, 0.02921171286808593, 0.028335987091330544, 0.06415425107947417, 0.015032013745180197, 0.04700120471950088, 0.03234953020832368, 0.07658219670078584, 0.045812574215233326, 0.08042225707322359, 0.06490884987371308, 0.028942168224602938, 0.10750883897500378, 0.11778827809861728, 0.012837216740341058, 0.06469513848423958, 0.053202797658741474, 0.11736483153487955, 0.09870477925453867, 0.120564748400024, 0.04510264338127204, 0.7705756340708051, 4.105132520198822, 7.864437563078744, 11.22506148474557, 19.694206850869314, 23.939738580158778, 29.545734541756765, 32.268073490687776, 43.057194573538645, 42.033752713884624, 45.67041553769793, 44.87250525610787, 44.03093596867153, 56.473116874694824, 61.10015855516706, 62.922566822596956, 59.60289818899972, 60.61641107286726, 49.92878580093384, 57.789039679935996, 36.838588101523264, 34.47039188657488, 35.510162012917654, 26.865925516401017, 27.21373323031834, 24.466380766459874, 19.3934679712568, 21.443591288157872, 15.477497986384801, 10.971351487295967, 14.670603684016637, 41.71581356866019, 21.925063235419138, 10.884811673845563, 26.365130628858292, 25.54678569521223, 35.49231209073748, 46.88646841049194, 32.411658014569966, 16.58831170627049, 24.95400013242449, 25.491762910570415, 24.99771993500846, 36.73430953707014, 37.04225022452218, 37.6051481110709, 25.166267599378312, 35.70704616819109, 46.257788453783306, 44.776116371154785, 45.506500584738596, 48.5266740662711, 56.51933976582119, 54.42296750204903, 60.40158666883196, 45.80234445844378, 26.650652953556605, 12.450028896331787, 5.465320995875767, 1.7178570947476794, 0.33825575932860374, 0.0684291302625622, 0.008237857022322714, 0.018793265667877028, 0.03288507414981723, 0.022395397736025707, 0.07633008701460701, 0.02620253898203373, 0.08744816827986922, 0.06217189745179244, 0.10163713619112968, 0.02104989332812173, 0.054513041994401386, 0.03939008420067174, 0.06635944917798042, 0.10360165791852133, 0.036160148946302276, 0.019084304604413252, 0.06263119102056537, 0.016481272942785705, 0.01828479188095246, 0.02491995851908411, 0.05187653650396636, 0.04828892508521676, 0.03922369723607387, 0.04271390834557159, 0.027274320667077388, 0.04855767245005284, 0.037788473535329103, 0.02004414327841784, 0.07686146814376116, 0.033951286758695326, 0.020416513118626814, 0.017572947578238587, 0.011622465182361858, 0.04491954070648976, 0.06952839770487376, 0.08087410032749176, 0.03258132794871926, 0.05720251053571701, 0.02746150642633438, 0.06099406922502177, 0.0394544161057898, 0.030075430271348784, 0.03818657003077013, 0.01798896079084703, 0.034288396526660235, 0.0498621695941048, 0.01412100499562387, 0.014893796161881514, 0.030506764804678302, 0.03426440352840083, 0.03715845037783895, 0.07638158782252244, 0.045641885338617225, 0.014746033287207996, 0.014897243119776249, 0.01444002756449793, 0.0735501968967063, 0.047399314785642285, 0.06458721748952355, 0.005464989317780626, 0.03720122183273945, 0.012072060789380754, 0.022243509368438805, 0.024936197558417916, 0.05760307011327573, 0.027162460776578103, 0.052526742685586214, 0.031241384135293107, 0.07644032859908682, 0.07030855691326515, 0.01696931434396122, 0.02563657970832927, 0.023296083423442075, 0.016923721879720688, 0.06294998034302678, 0.06974973582795688, 0.03167623687269432, 0.04859708176393594, 0.09108651376196317, 0.08632352362786021, 0.050691176538488696, 0.06102492221231971, 0.022278243576043417, 0.06415394573871579, 0.03577950097886579, 0.08747988300664084, 0.04958543587209923, 0.04252185918656843, 0.08145033940672874, 0.016229985980316997, 0.008140155613156301, 0.021622095123997757, 0.09862199119691338, 0.04489836362855775, 0.06308320390858821, 0.06636643130332232, 0.08727959982518639, 0.026082129550299475, 0.05112471631062882, 0.025127079637188996, 0.10288629201906067, 0.04853178973176649, 0.009065162540147347, 0.05385169766045042, 0.009677302059052246, 0.05234087837327804, 0.006793898455466011, 0.03140693650181804, 0.07584275637886354, 0.03317527000659278, 0.07404255547693797, 0.21077933109232358, 0.10362413778368916, 0.15781689089323792, 1.1557241614375795, 5.2122350335121155, 10.114131382533483, 15.131819895335607, 23.950579507010325, 27.654761450631277, 33.26735993794033, 36.39858995165144, 49.41360119410923, 47.708881514413015, 52.06994962692261, 52.77931901386806, 52.89320693697248, 68.4086559840611, 71.10478632790702, 71.134920665196, 66.5485954284668, 67.77007484436035, 56.82254178183419, 63.86062226976667, 49.89165115356445, 43.73975086212158, 44.399888787950786, 38.16731991086687, 39.22547844478062, 37.2360771724156, 34.68233626229422, 32.4399927684239, 23.879306622913905, 20.699529545647756, 25.818927526474, 54.2534453528268, 25.216437067304337, 21.785517351967947, 34.9373733656747, 29.98498923437936, 36.45094462803432, 44.537459645952495, 36.44198145185198, 24.70004173687526, 35.10817745753697, 35.753998620169504, 29.440990447998047, 44.768928459712434, 44.7101605960301, 48.05659369059971, 31.55313512257167, 45.5413110596793, 56.62340988431658, 54.23333031790597, 55.227982316698345, 55.809793199811665, 62.00340352739607, 61.06468800136021, 70.85480403900146, 55.45048795427595, 35.22206538064139, 18.20967037337167, 8.475334474018641, 2.873760606561388, 0.8197858163288662, 0.15897566585668496, 0.07642547546752862, 0.0038793492463550395, 0.044160446617752314, 0.033284100238233805, 0.06967087648808956, 0.045243262978536744, 0.08618475643119641, 0.0439525095612875, 0.07003634901983397, 0.06559484199221645, 0.055652105515556674, 0.08985552910183157, 0.013397492435095566, 0.017339833479906832, 0.050765160604247024, 0.017730477964505553, 0.04905743045466287, 0.052394499603126726, 0.005410633149689862, 0.03655471705964633, 0.02918666135519743, 0.048486673938376565, 0.047134601311492066, 0.015415913591693555, 0.0322782806386905, 0.02127183534737144, 0.04695867753720709, 0.026359268696978688, 0.021856439067050815, 0.058301323359566073, 0.023154278086232286, 0.04113232124862926, 0.020484873825418096, 0.05629771462242518, 0.060568478490625105, 0.0775678027421236, 0.0317949805009578, 0.0059138834892239955, 0.07663547527045012, 0.05630600632035306, 0.0728926421808345, 0.08742667907582861, 0.03640586004725524, 0.05911422188260725, 0.055523886145757775, 0.09212191748831954, 0.05020076196108546, 0.11196946033409663, 0.07363247605306761, 0.02314619503782264, 0.03014748390497906, 0.02261874601910157, 0.027190974514399256, 0.041961894769753726, 0.012798569930185164, 0.031278476252087524, 0.021699899341911077, 0.05153259728103876, 0.01552554449465658, 0.007997726871898132, 0.04492264161152499, 0.10623822786978313, 0.15056804700621537, 0.14916885351496084, 0.20329628405826433, 0.18164838424750737, 0.08503211542431797, 0.0550169729893761, 0.15307655025805744, 0.1582127075110163, 0.17489876571510518, 0.09969146416655608, 0.09818574067737375, 0.10255287348159722, 0.17413789725729398, 0.12566912307270936, 0.11031294600772006, 0.14438077115586825, 0.1794206994984831, 0.14230392474148953, 0.21347987332514354, 0.13437001832893916, 0.16194877560649598, 0.15062718811844075, 0.19747833481856755, 0.15904860837118967, 0.13639593390481813, 0.11981090956500598, 0.26552950750504223, 0.09065037180802651, 0.1125215096399188, 0.1473802759179047, 0.20024328359535762, 0.11417220213583537, 0.16814198185290608, 0.2539890653320721, 0.22221008129417896, 0.10016174321728093, 0.14645400776394776, 0.10479602204369647, 0.16644162737897464, 0.20829267666808196, 0.19775752483734063, 0.09371607444648232, 0.18703311601919786, 0.15367948290492806, 0.21944579748170717, 0.1370015942624637, 0.2637050896883011, 0.20065675569432123, 0.28376095635550364, 0.29236222910029547, 0.21919693797826767, 0.543673252420766, 2.4103871967111314, 7.64911549431937, 14.669893230710711, 19.576275076184952, 29.78542307444981, 34.05783217293875, 39.123565741947715, 44.136569431849885, 56.95248351778303, 55.32380492346627, 61.646794182913645, 61.67674091884068, 63.31076962607247, 80.38440431867326, 81.02058832986015, 80.59276689801897, 77.31853253500802, 77.48025185721261, 67.04350171770368, 75.68631035940987, 53.95022596631731, 50.443602153233115, 54.60841492244175, 41.952288559504915, 41.52302885055542, 40.15419898714338, 32.69296625682286, 35.53444596699306, 29.398710659572057, 25.571484804153442, 26.34741619655064, 53.962208134787424, 32.76262889589582, 22.259556463786534, 38.601870673043386, 39.59563677651541, 50.25304085867745, 61.12596416473389, 46.37955910818917, 29.798631599971227, 37.78891059330532, 43.033004420144216, 39.08689314978463, 52.46073021207537, 53.016568728855674, 54.65044457571847, 39.72691256659371, 52.52109268733433, 62.91866888318743, 61.29950932094029, 63.19817406790597, 64.84767641339982, 72.44541345323834, 71.47906494140625, 80.47885118212018, 62.83462347303118, 38.9959898676191, 20.756850446973527, 9.40389781338828, 3.340592916522707, 0.9155776990311486, 0.15324868102158817, 0.129229192755052, 0.10674961935728788, 0.13584469205566815, 0.09345905895211867, 0.21570446395448276, 0.14490811500166143, 0.2962243418608393, 0.14011929982474872, 0.20629136477197918, 0.22752313262649945, 0.13359081585492405, 0.19621129280754498, 0.17918452859989234, 0.246142676366227, 0.12223930497254644, 0.05720218483890806, 0.12210540287196636, 0.14862726043377603, 0.05213145871779748, 0.1253292720232691, 0.11499290381159101, 0.14767842420509883, 0.1458805642489876, 0.1433462630957365, 0.15009303178106034, 0.15851777685540064, 0.1908996935401644, 0.0907829168385693, 0.2010645688112293, 0.26059680219207493, 0.13494276973818028, 0.1570393576153687, 0.13613570215446608, 0.1915260356451784, 0.16184802672692708, 0.17584696412086487, 0.10328914504498243, 0.15756370233637945, 0.22401248743491514, 0.22961082203047617, 0.13128211402467319, 0.2014279378844159, 0.17848573252558708, 0.19195364841393062, 0.13365968715931686, 0.25653465730803354, 0.10487412142434291, 0.22208341237689766, 0.20407011253493174, 0.13337422747697147, 0.1311694907822779, 0.16657331745539392, 0.15050620532461575, 0.12270221513296876, 0.06211110071412154, 0.1717751840395587, 0.18419242916362627, 0.15264055079647473, 0.11482113945697035, 0.07856409571000508, 0.1423591710627079], [0.03145330758499248, 0.012240770040079951, 0.015326511513973986, 0.06184723201606955, 0.07668015001607792, 0.035096718331000636, 0.04451511687199984, 0.05656289967841335, 0.05552450021994965, 0.029535431747457812, 0.03224670161892261, 0.05622361181303859, 0.002613516087876633, 0.05704661032983235, 0.03223214025742241, 0.020856322554339255, 0.02442843623326293, 0.054244661038475375, 0.013912679477860885, 0.043566575806055746, 0.07473550257938248, 0.054085799027234316, 0.019713584766057984, 0.0243180301040411, 0.014213228082683469, 0.023696010267095904, 0.042064828532082696, 0.02170594678526478, 0.06398355202483279, 0.030094096769711802, 0.0894232140854001, 0.03664648552824344, 0.02397562945926828, 0.052679229860327074, 0.021290283018190945, 0.014511249992730362, 0.030412682531667606, 0.0095875369650977, 0.0411033342326326, 0.05618794122710824, 0.04342295029865844, 0.0175219098704734, 0.05100734332310302, 0.04140780646620052, 0.06393547781876155, 0.01883596078758793, 0.02809909694562001, 0.06382622011005878, 0.08718288822897843, 0.03897985889177237, 0.09099244845232793, 1.0265376078230994, 5.064357825687953, 15.619845730917794, 30.215815339769634, 39.22274432863508, 41.54493999481201, 49.09419250488281, 53.57099676132202, 55.62240375791277, 57.27087777001517, 61.03189945220947, 65.26414448874337, 64.55788094656808, 65.08506161825997, 63.743169920785085, 58.476025445120676, 54.8760004724775, 50.876384598868235, 44.50623444148472, 44.47540528433663, 32.86829015186855, 28.66967613356454, 20.0259016922542, 23.381706169673375, 20.45034282548087, 10.692315305982317, 11.285574214799063, 14.815812349319458, 14.290269715445381, 22.08587234360831, 47.60424859183175, 33.34756646837507, 22.991252149854386, 54.231527260371614, 69.59087112971714, 23.39116093090602, 40.47690807070051, 42.01036160332816, 24.402608462742396, 31.735143184661865, 53.54893970489502, 30.30791023799351, 25.644051790237427, 25.93142580986023, 33.932226112910676, 26.96183671270098, 32.90638712474278, 30.07074042728969, 28.164587259292603, 25.560999972479685, 25.026980536324636, 24.482894897460938, 23.484452656337194, 36.43628740310669, 43.75954280580793, 50.12689283915928, 55.84099408558437, 58.282841205596924, 54.92881720406668, 46.85395431518555, 35.21861560004098, 28.47709812436785, 13.626314623015267, 5.934517647538867, 1.292096455182348, 0.5739450880459377, 0.03279638962287988, 0.008297448512166739, 0.048010355925985744, 0.04580341399248157, 0.04593906671340976, 0.053659841883927584, 0.07442959185157504, 0.012404267293667155, 0.037051248630242686, 0.06741358047085148, 0.03193809710709112, 0.020171175211934105, 0.021729578463626758, 0.04982755413012845, 0.02045313365358327, 0.06658422747360808, 0.051445934788456986, 0.035718198732606, 0.05034953076392412, 0.028259085324992026, 0.06870858490999256, 0.012440869168910598, 0.05751215999147721, 0.019391541868182163, 0.031123407251600708, 0.03797397143872721, 0.025224120322881, 0.03906591409551246, 0.01210902992170304, 0.022996516998058984, 0.01218128202682627, 0.018714457218136107, 0.03145761628236089, 0.04718653638181942, 0.054594924207776785, 0.023339238250628114, 0.04450226881142173, 0.04202672539811049, 0.032413037693394084, 0.021640466459627663, 0.03253324017194765, 0.03284454186047826, 0.014125090624604906, 0.061899187442447455, 0.02028056693130306, 0.06308860504733664, 0.04062776600143739, 0.023731087134884934, 0.024503200614292706, 0.03189355128311685, 0.06201158676828657, 0.045968650840222836, 0.027558282483369112, 0.02762678568251431, 0.031103471892752817, 0.02174740018589156, 0.056242780427315404, 0.07212778393711362, 0.02363683862079467, 0.01127593734833811, 0.05266595432268722, 0.02434222157379346, 0.024027783357139145, 0.0394219821318984, 0.03588167817464896, 0.01976159111862736, 0.046099737020475526, 0.03491236036643386, 0.06531060367290463, 0.05165033328479954, 0.044233355205506086, 0.04212844119008098, 0.06624370467449937, 0.12003041564353875, 0.023911005784092203, 0.06588929226355893, 0.04786759555073721, 0.03460577788895794, 0.045419970460768254, 0.08821971009352378, 0.05382527889949935, 0.06142078632754939, 0.04668648321447628, 0.039863562544009516, 0.02540443421873663, 0.010023083504555481, 0.014397873576464397, 0.03692328371107578, 0.05785712040960789, 0.027591330531452383, 0.019624247149165188, 0.011499084615414696, 0.02090688019857875, 0.0468135863941695, 0.03867262162800346, 0.016575769122157778, 0.09135833489043371, 0.025149327104112933, 0.0352746539616159, 0.02198435309609132, 0.08383619066859994, 0.03589626667754991, 0.02827730738291783, 0.04150042310357094, 0.051029745156743696, 0.03393200618614044, 0.05054744925083859, 0.08289861812123231, 0.028171832506944026, 0.19489356423062937, 1.6451800231422697, 6.65900023494448, 19.08825966290065, 34.199961049216135, 44.39636952536446, 48.10850020817348, 54.02589532307216, 61.97099712916783, 64.1289894921439, 65.56695393153599, 67.0311200278146, 72.2096471786499, 72.42028181893485, 71.38511834825788, 73.07467705862862, 67.30305167606899, 62.50217996324812, 59.36973748888288, 54.14970874786377, 51.11847720827375, 41.41453620365688, 39.71752207619803, 29.993702275412424, 35.74514661516462, 34.24346719469343, 17.2287688595908, 18.95634811265128, 27.03082537651062, 18.366234132221766, 24.650627885546, 43.90432589394705, 32.396684646606445, 15.211107526506696, 44.76102488381522, 54.69298144749233, 21.199403796877178, 33.41119112287249, 44.531473772866384, 34.13786152430943, 44.67429746900286, 54.09630836759295, 21.115269797188894, 29.302200181143625, 28.38683581352234, 42.093642711639404, 38.861510957990376, 45.976761613573345, 40.560348987579346, 35.49535540172032, 37.144291469029014, 37.138677324567524, 38.703057289123535, 36.62848499843052, 46.30859020778111, 51.676233427865164, 58.46419266292027, 60.82301575796944, 66.11003902980259, 64.1535861151559, 58.64177472250802, 45.66536767142159, 38.735897949763704, 20.209876094545635, 10.061531782150269, 2.620723715850285, 1.049270593694278, 0.14284509713096277, 0.03957399433212621, 0.08236470605645861, 0.01292853313498199, 0.05467204649799636, 0.07688147135611091, 0.012571875621298594, 0.055903180435832055, 0.03657420797805701, 0.04133486734437091, 0.042366128614438434, 0.07908687301512275, 0.037363849713334014, 0.059341470045702796, 0.017990714803870236, 0.07396717702171632, 0.08230454714170524, 0.024706732282148938, 0.0292041980927544, 0.03210325253063014, 0.03327707740079079, 0.006540616600042475, 0.03181195744712438, 0.007959534680204732, 0.024747692048549652, 0.012652180240755635, 0.03964144749833005, 0.04101774382538029, 0.05037624468760831, 0.029201602696308067, 0.017997532384470105, 0.06619138962456159, 0.04268132848665118, 0.012543088773132434, 0.04071554129144975, 0.05272847453930548, 0.046768640234534226, 0.012669502391612955, 0.050717829394021204, 0.0219774863217026, 0.025997780862131288, 0.038895873219839165, 0.019683222020311014, 0.04003334218370063, 0.07302335516682693, 0.11662596118237291, 0.028341454387243305, 0.057603212605629645, 0.04261997535026499, 0.028527668145086085, 0.045253722595849206, 0.022166227622489845, 0.05530413918729339, 0.02888805844954082, 0.007735895475239626, 0.027782200735860636, 0.05652888471792851, 0.03965901816263795, 0.025003740630511726, 0.09485816423382078, 0.1240538161780153, 0.14899980330041476, 0.12462697470826761, 0.13713279579366955, 0.16718615671353682, 0.10020681151321956, 0.13288792142910616, 0.15327123552560806, 0.12278374790080956, 0.1310372171657426, 0.14643540233373642, 0.1280091053673199, 0.11943325054432664, 0.21577268386525766, 0.10910717570888144, 0.18401948415807315, 0.2037942066256489, 0.09341552414532218, 0.09964887930878571, 0.15510429787848676, 0.16879729740321636, 0.12538521045020648, 0.16630085850400583, 0.15753783658146858, 0.17376544938555785, 0.10708638985774346, 0.22977494608078683, 0.16985954397491046, 0.11484909509973866, 0.19297949836722442, 0.13433321458952768, 0.09280915811125721, 0.1087060258058565, 0.10924111852156264, 0.07084692016776119, 0.18296672350593976, 0.1678237896412611, 0.11586530985576765, 0.1332709544471332, 0.12085997898663793, 0.18913482395665987, 0.12296089982347828, 0.24355544948152133, 0.1250839816140277, 0.10719357803463936, 0.21962598924125942, 0.2112908379307815, 0.23731740564107895, 0.15922016916530474, 0.37303836005074636, 2.637638671057565, 9.771316817828588, 24.571953432900564, 44.26229361125401, 53.901334966932026, 59.62142903464181, 65.92694704873222, 70.20557825905937, 74.23971625736782, 75.96830994742257, 76.68289048331124, 81.53991058894566, 81.25969668797084, 80.42382144927979, 80.82660157339913, 75.46890122549874, 71.75262941632951, 68.63315228053501, 63.33604717254639, 62.976248604910715, 49.753274304526194, 43.219935280936106, 32.88249921798706, 38.79037182671683, 34.52401808329991, 21.891883850097656, 21.739320516586304, 25.494271210261754, 24.151950461523874, 35.38911049706595, 63.09121349879673, 48.06373643875122, 36.326186248234336, 64.53746019090924, 79.2857551574707, 35.66209132330758, 51.81142452784947, 54.99179220199585, 37.90602248055594, 47.34555326189314, 64.37860352652413, 42.18034928185599, 37.06716299057007, 38.938806193215505, 48.35888549259731, 40.04991694859096, 49.23773186547415, 45.02179077693394, 40.50067090988159, 39.80461427143642, 38.78299283981323, 37.05218614850725, 39.11721856253487, 52.766207763126914, 60.471339634486604, 68.24559565952846, 73.13327121734619, 76.91774654388428, 73.50647980826241, 68.56226675851005, 52.657791546412874, 42.86055360521589, 23.86371660232544, 11.219257133347647, 3.2991291071687425, 1.3749091029167175, 0.2565036346869809, 0.11641132698527404, 0.18252404725977353, 0.09516234469733068, 0.225634918947305, 0.12282292651278631, 0.12511754195605004, 0.14930897099631174, 0.12306531279214791, 0.2892305457166263, 0.12921788836164133, 0.10717398872865097, 0.14732166406299385, 0.10640852658876351, 0.11965442581900529, 0.2552250032978398, 0.16615683266094752, 0.1340090784111193, 0.13972095905670098, 0.1289410867861339, 0.1263395563832351, 0.06698165900473084, 0.1402483843266964, 0.06243972200900316, 0.12541083193251065, 0.1614688749292067, 0.1118155075237155, 0.2717578618654183, 0.10659616866282054, 0.09756568859198264, 0.15372328912573202, 0.20186096536261694, 0.20713900428797516, 0.12098162674478122, 0.18956064539296286, 0.13004358405513422, 0.18610452727547713, 0.0886871392971703, 0.08613670936652593, 0.12131808511912823, 0.17378049929227146, 0.11937583291104861, 0.1204964742064476, 0.19795933472258703, 0.07812186051160097, 0.17102357079940184, 0.11730203990425382, 0.20997278365705693, 0.06460449977644853, 0.10245716611721686, 0.12558768529977116, 0.12344379962555, 0.1639959021870579, 0.10947496204503945, 0.08819009203995977, 0.11975403475974288, 0.14803134383899824, 0.2239332888275385, 0.1262581864637988], [0.045427553089601655, 0.04819342128134199, 0.061390469382916174, 0.04192921991593071, 0.0629578988466944, 0.009861449677763241, 0.052073114884219, 0.045124264899641275, 0.06573526481432573, 0.07355515698769263, 0.03886440276567425, 0.061355056640292914, 0.03448047621973923, 0.013446089961299939, 0.0014001559507700481, 0.016943166997017603, 0.03427959932014346, 0.05039023268701775, 0.007675291271880269, 0.01298916363157332, 0.019554485267560397, 0.03511090649824057, 0.034487298889351745, 0.018048051012946025, 0.027095753998894776, 0.008456102722058339, 0.05403559082852943, 0.044361330302698274, 0.031555315147020986, 0.015629071975126863, 0.022799188836610744, 0.020699297676661184, 0.009685246007783073, 0.07590732577123813, 0.05407942079805902, 0.034715866803058555, 0.018874135167737092, 0.05516214555661593, 0.0674678971990943, 0.07109734030174357, 0.022042702018682445, 0.035460257037941895, 0.019334806162597876, 0.009152549368861531, 0.001671467859913329, 0.038212727555739026, 0.07082578380193029, 0.033427325409970114, 0.08736613339611463, 1.1587503190551485, 7.029852518013545, 19.521702187401907, 28.576479945863994, 38.330043247767854, 48.71882997240339, 49.55837385995047, 50.629650592803955, 57.38214274815151, 58.332107407706125, 54.493561199733186, 50.46600661958967, 54.500908919743125, 44.81158692496163, 51.94883905138288, 43.19684989111764, 40.83320127214704, 41.00858770098005, 41.44251659938267, 31.657729830060685, 22.04640483856201, 16.994753531047277, 19.02962555204119, 18.267164979662212, 16.658264432634624, 14.000863347734724, 19.53971712929862, 33.748967375074116, 39.608734130859375, 24.745232820510864, 55.44641283580235, 72.35823440551758, 56.49754326684134, 53.791348457336426, 54.821116651807515, 77.19946820395333, 60.17640944889614, 60.95605986458914, 54.311122349330354, 30.882102421351842, 25.226678712027415, 15.852473156792776, 18.03134659358433, 52.56458146231515, 35.94172157560076, 41.99785137176514, 18.317951100213186, 20.985762323651993, 11.65659759725843, 49.071187019348145, 34.628720487867085, 17.487752539770945, 27.699335881641932, 11.863348194531032, 17.485883474349976, 15.44347265788487, 22.689974784851074, 32.442045961107524, 43.95195232118879, 47.890212127140586, 52.50639724731445, 54.0502279145377, 61.0258823122297, 55.19154596328735, 53.38825566428048, 40.3058260508946, 31.55578933443342, 14.991822378976003, 7.130025999886649, 2.1323383109910146, 0.5484026415007455, 0.03956410129155431, 0.018952295616535202, 0.10995438774781567, 0.05739523483706372, 0.01618614244008703, 0.05897452509296792, 0.042541268680776866, 0.02926759361954672, 0.03835343196988106, 0.02705358304748578, 0.03304577499095883, 0.045792065494294674, 0.03596245437594397, 0.01036683443401541, 0.02710630352209721, 0.04789241636171937, 0.04895285124491368, 0.08973468201501028, 0.058955064708633084, 0.04480063083714672, 0.03495780185663274, 0.08328319819910185, 0.04498051047059042, 0.023187017400882075, 0.03791409072333148, 0.08510561433753797, 0.05111982746581946, 0.12046801644776549, 0.04265778332150408, 0.03409896990550416, 0.09197247015046221, 0.013297134561331143, 0.009166072571783193, 0.0465568999892899, 0.045846076881779094, 0.1069299400384937, 0.04910382867923804, 0.042774854360946586, 0.07739215716719627, 0.04579099001629012, 0.03630761835458023, 0.03965396646942411, 0.07250593828835658, 0.018894489521958997, 0.09794101345219783, 0.05184405842529876, 0.04155329115954893, 0.033126079610415866, 0.035351966241640706, 0.010581142934305328, 0.0428391591246639, 0.04267484847722309, 0.020084602625242302, 0.054756215374384604, 0.031027058671627725, 0.0064453324718799975, 0.01667497263822172, 0.021965696775753583, 0.04248795618436166, 0.04414353073973741, 0.00941137909623129, 0.020005605882033706, 0.041828175873628685, 0.05994467410658087, 0.024075701500156095, 0.06528417473392827, 0.010403908739265586, 0.008069626138811665, 0.01907777540119631, 0.030653277478579963, 0.038214410322585275, 0.0057019965107818794, 0.0383188707887062, 0.06218973613743271, 0.019759353649403368, 0.06864295700298888, 0.02071772838410522, 0.033943653239735534, 0.029095937830529044, 0.022140438202768564, 0.014977635948785713, 0.016478475682171326, 0.0231671736442617, 0.041278375911393335, 0.029982915414231162, 0.05048157028587801, 0.02636866471064942, 0.026431943190151026, 0.07165230730814592, 0.029594196272747855, 0.013557519830231155, 0.05509566608816385, 0.019681500237701193, 0.07195646741560527, 0.05510966765827366, 0.042726736050099134, 0.08219079074582883, 0.0139376605927412, 0.020316369831562042, 0.028552244683461528, 0.05860019089387996, 0.02124019865212696, 0.16488690009074553, 0.03768228959026081, 0.22243132442235947, 1.7508406277213777, 9.065389394760132, 22.99024292400905, 33.85289852959769, 45.50833143506731, 57.26604529789516, 59.218565532139365, 60.46425247192383, 65.4093826838902, 66.14813600267682, 62.679581369672505, 57.999253954206196, 61.739997318812776, 53.93383863994053, 60.35317856924874, 51.74600376401629, 49.59993798392159, 50.56481695175171, 50.83887127467564, 39.91640731266567, 35.08056879043579, 25.602574518748693, 28.16595779146467, 28.870753526687622, 23.403940405164445, 23.235766206468853, 18.425707238061086, 23.56222036906651, 25.445065804890223, 17.768070663724625, 36.49439171382359, 73.10376221793038, 71.08697809491838, 60.443324497767854, 56.98653316497803, 75.79096412658691, 75.30504880632672, 64.50763852255685, 56.48751354217529, 41.59804507664272, 30.921595982142858, 25.946701424462454, 34.47478314808437, 63.19958455221993, 44.57262100492205, 49.51398181915283, 30.411872659410747, 27.88522103854588, 24.16066002845764, 48.71624871662685, 44.590033190590994, 22.073355163846696, 41.61451925550188, 20.4841753414699, 26.836352246148245, 29.47233029774257, 35.075229099818635, 41.99948419843401, 51.061797278267996, 53.37954262324742, 60.78061785016741, 63.37700680324009, 69.53629997798375, 62.57073089054653, 63.076955795288086, 48.59673970086234, 41.194945335388184, 21.153055838176183, 10.447938476290021, 3.7552559801510403, 0.7737521550485066, 0.038499401815767796, 0.035205908186201534, 0.14326949364372663, 0.022193752395521318, 0.0741066023973482, 0.030812261626124382, 0.044506333236183436, 0.09314432726906878, 0.03592431392254574, 0.04911063438547509, 0.010900423346486474, 0.009409189972627376, 0.05242363589682749, 0.0060094297015374255, 0.02322946146263608, 0.01356356218457222, 0.02669656166939863, 0.035299132112413645, 0.03705546911805868, 0.0109837728918397, 0.030639357332672392, 0.05892493096845491, 0.007195189578591713, 0.05637646878936461, 0.032573192313845666, 0.07117553467729262, 0.024782059847244194, 0.038407378896538696, 0.09483185743114778, 0.012859414165307368, 0.060854372435382435, 0.023162281406777244, 0.04219659324735403, 0.055428721609392335, 0.024906528614727513, 0.058644349952893596, 0.042646570530320914, 0.024035082697602253, 0.062220080223466666, 0.028239948941128593, 0.031289702613971064, 0.036822249846799035, 0.07844649880592312, 0.034822705534419844, 0.036550086058144055, 0.026855326989399533, 0.04877993677343641, 0.05181638098188809, 0.025030466428558742, 0.06549969781190157, 0.04771297099068761, 0.024243991755481278, 0.05896749547017472, 0.022312519772510444, 0.03771707808066692, 0.06764164287596941, 0.1400368713906833, 0.13707560886229786, 0.1000917726861579, 0.12624080239662103, 0.22050079729940208, 0.11104370108140366, 0.14158269629946776, 0.15694248995610646, 0.10031616421682493, 0.1237112238470997, 0.1809318241264139, 0.11566571199468204, 0.08604347865496363, 0.09681992432368652, 0.17781246293868336, 0.07385877426713705, 0.10287780354597739, 0.22587400754647596, 0.1089044769427606, 0.10099959147295781, 0.12619764756943497, 0.20372506390724862, 0.11683651059865952, 0.07596151357782738, 0.08834409234779221, 0.1048505762591958, 0.13104603812098503, 0.08823707380465098, 0.2029007524251938, 0.08215303705739123, 0.12952179062579358, 0.11160757725260087, 0.17237363835530622, 0.16273552338991845, 0.2002349104732275, 0.24072845546262606, 0.1832041157675641, 0.17140056485576288, 0.19692834147385188, 0.1467750362519707, 0.16886238248220511, 0.08761711671416249, 0.17912765379462922, 0.13298892815198216, 0.10312935683344092, 0.13823958140398773, 0.3197786265185901, 0.23519065976142883, 0.326763140303748, 2.6479148396423886, 13.13757312297821, 30.515963622501918, 44.13322040012905, 54.96274873188564, 67.80483668191093, 68.22125611986432, 69.65330764225551, 73.96606840406145, 75.36016191755022, 71.84408160618374, 65.50227315085274, 70.06792749677385, 61.286154883248464, 68.66996383666992, 59.60250908987862, 58.487899916512625, 57.625948088509695, 57.98664992196219, 44.6821037701198, 36.224415983472554, 28.90603300503322, 31.408907890319824, 26.955199445996964, 25.35411388533456, 22.05474615097046, 29.959708213806152, 48.09169251578194, 54.5178347315107, 36.23536287035261, 69.28509480612618, 85.97220121111188, 68.80607209886823, 66.35430295126778, 71.84784058162144, 85.81814575195312, 70.38769054412842, 73.75637177058628, 68.75079223087856, 45.258314405168804, 36.31863703046526, 25.133248022624425, 32.104245390210835, 67.16665853772844, 47.22110060283116, 54.20355033874512, 27.98607587814331, 31.402442591530935, 21.62930621419634, 61.772591318402974, 44.40023619788033, 28.592427798679896, 40.79278360094343, 20.3392585005079, 29.637134620121547, 27.90930870601109, 37.76821538380214, 47.947545187813894, 61.05323042188372, 63.6395514351981, 69.79436997004917, 70.9260230745588, 78.22446646009172, 72.392489024571, 69.5520168031965, 55.82634033475603, 46.30408082689558, 23.313031911849976, 11.512593575886317, 4.025916542325701, 1.0243947399514062, 0.14242326548056944, 0.10087985718356711, 0.21207503442253384, 0.20789205602237157, 0.17217200488916465, 0.10684319612170969, 0.1923678261893136, 0.2316760112132345, 0.1657151470759085, 0.10704169475606509, 0.093987827721451, 0.16808516133044446, 0.13606565019914083, 0.08765499932425362, 0.11648220675332205, 0.11725261541349546, 0.07909901200660638, 0.16635086653488024, 0.15892919977860792, 0.13740024715662003, 0.0850505240793739, 0.17163282739264624, 0.17183854563960008, 0.11486920687769141, 0.12808690619255814, 0.14623865431972913, 0.09012287189917904, 0.17885087936052255, 0.27420805181775776, 0.13114507709230694, 0.20439903917057173, 0.09262518691165106, 0.14338662235864572, 0.11154439885701452, 0.18086397062454904, 0.17708348562674864, 0.1830838793622596, 0.14698216585176332, 0.1309243089386395, 0.12524365447461605, 0.15851826540061406, 0.08549526985734701, 0.15412420832685061, 0.12883713522127696, 0.16734698308365686, 0.1638172846287489, 0.16283834858664445, 0.11679904189492975, 0.09226465411484241, 0.10642654847885881, 0.17401405104569026, 0.1201664890561785, 0.12779247627726623, 0.14760184474289417, 0.11340142706675188, 0.14802397494869574], [0.014872739523915308, 0.024922843989250914, 0.04238394694402814, 0.10982024815997907, 0.019149109787706817, 0.010093361920943218, 0.023014393003125275, 0.06980593888355152, 0.032988537169460735, 0.04850300627627543, 0.0031304236409986125, 0.004391323425807059, 0.054450593023960076, 0.03319993814719575, 0.027249494767082588, 0.024635671005983437, 0.08265630648072277, 0.024649075465276837, 0.02150622509153826, 0.07329079295907702, 0.014630728135151523, 0.041139082850090096, 0.052509328084332604, 0.04706698529688375, 0.02463309426925012, 0.03443163187642183, 0.07686273021889584, 0.03419111496103661, 0.026903002556147318, 0.03175118785085423, 0.03267108116831098, 0.044466072360851934, 0.01386789616663009, 0.008949087250844708, 0.05567363543169839, 0.08092364016920328, 0.05788423466895308, 0.03823841010619487, 0.04917583481541701, 0.04349189284922821, 0.03368720432211246, 0.01724116431017007, 0.07079622003116778, 0.08121815829404763, 0.07111991516181401, 0.011314517153160912, 0.061954657680221965, 0.3274306287722928, 5.060583651065826, 16.685732398714336, 35.15183993748256, 55.773613929748535, 59.40747315543038, 61.699239185878206, 56.70573214122227, 57.45251062938145, 51.98366689682007, 48.74585846492222, 44.17181764330183, 46.945020880017964, 43.4343011038644, 44.54490464074271, 30.489341599600657, 28.555366107395717, 26.50665327480861, 19.426628249032156, 22.514982666288102, 18.61741324833461, 16.59827021190098, 10.77921642575945, 16.805359533854894, 14.977825232914515, 22.942762408937725, 59.05220481327602, 47.03336722510201, 68.67454964773995, 56.46264246531895, 62.37916905539376, 58.024823325020925, 68.02079364231655, 43.085921900612966, 24.383846589497157, 19.818063701902116, 23.138161386762345, 26.943180799484253, 17.708399534225464, 32.718045779636924, 27.014479739325388, 32.2038790839059, 47.88650873729161, 46.79149695805141, 30.42464692252023, 19.60542971747262, 36.39598090308053, 26.79644353049142, 37.67266028267996, 36.88611030578613, 30.828212193080358, 42.526338304792134, 26.800930329731532, 34.81927830832345, 23.563399825777324, 25.33129252706255, 22.101901837757655, 15.14202332496643, 18.251538481031144, 13.083778432437352, 25.268624986921036, 29.00985472542899, 33.742036546979634, 33.42968027932303, 45.119989667619976, 53.63641405105591, 52.41880478177752, 56.073727471487864, 57.826855250767295, 49.69087600708008, 43.58297518321446, 25.697737046650477, 12.169050693511963, 3.8429118480001176, 0.4214398371321814, 0.15362287951367243, 0.1039975763165525, 0.0065487386642156965, 0.020274509309924076, 0.03571893494310124, 0.020700259500050118, 0.045492573707763634, 0.033577603953225274, 0.04288834612816572, 0.03244645554306252, 0.023548647728083388, 0.024371837931019918, 0.04239970252716115, 0.06568487001849072, 0.07645214867911168, 0.05164788377338222, 0.01421892608050257, 0.06083151259060417, 0.08997775361474071, 0.026220106253666536, 0.031236200127750635, 0.019606888527050614, 0.037820205225476196, 0.02037468652373978, 0.09549214664314475, 0.04118640388229063, 0.0741461067061339, 0.05788791232875415, 0.06567003724298306, 0.014163984251873834, 0.02378307648801378, 0.03846405014129622, 0.025995304209313223, 0.04047957395336457, 0.0642008800059557, 0.03008297218808106, 0.0037651645252481103, 0.0833913159689733, 0.022903216736657277, 0.05533617961087397, 0.0443548876126962, 0.059251801642988405, 0.008260840699741883, 0.07284213203404631, 0.05256925290450454, 0.022944980567055087, 0.01994829681435866, 0.021610658416258435, 0.01637177774682641, 0.03119794771607433, 0.0233630921492087, 0.04165592636646969, 0.030648992529937198, 0.050242060994995494, 0.007456694430272494, 0.0040744988863090316, 0.050784356359924586, 0.05791914529566254, 0.023829079465940595, 0.028682262171059847, 0.07165124200816665, 0.039258645182209354, 0.019612703572160432, 0.02447341462331159, 0.03419333377054759, 0.03324396149920566, 0.019267297017255, 0.04526559356600046, 0.02449844408381198, 0.046925968756633143, 0.05749558338097163, 0.062364241773528714, 0.03362665185704827, 0.06845526064613036, 0.09908251291407005, 0.040443737126354656, 0.02782749125201787, 0.03507875750905701, 0.04322625996012773, 0.018787157156371644, 0.02821807806114001, 0.030874255978103195, 0.038051297289452383, 0.01029860264887767, 0.031112618544804196, 0.04657343588769436, 0.04832983735416617, 0.06552490538784436, 0.036169000435620546, 0.08496893024338142, 0.04431044356897473, 0.01722220773808658, 0.044956846561815055, 0.04976937314495444, 0.04717895375298602, 0.05460729390116675, 0.04941268764170153, 0.062239968084863255, 0.0023172785128865924, 0.07990313707185642, 0.061231312208942006, 0.2794558145105839, 7.793898582458496, 22.613513333456858, 45.04206562042236, 65.6919937133789, 68.36357607160295, 70.29787812914167, 64.97672530582973, 64.53393050602504, 60.72726263318743, 56.810979979378835, 54.092875957489014, 54.09730543409075, 53.10336562565395, 51.63434968675886, 39.03810289927891, 38.24759939738682, 32.945401259831016, 28.84543776512146, 32.17192779268537, 27.437347105571202, 23.698351212910243, 20.074189935411724, 27.843227863311768, 19.873166390827723, 24.02131564276559, 50.58692611966814, 28.894455569131033, 59.143267904009136, 66.25404044560024, 64.06976999555314, 45.21708032063076, 65.7074534552438, 49.0082745552063, 26.2460332938603, 25.530723197119578, 27.68073902811323, 32.07054662704468, 18.840726613998413, 24.457563502447947, 26.460013491766794, 29.41803707395281, 36.56283146994454, 33.57186821528843, 30.0814163344247, 31.174972466060094, 32.43077598299299, 29.30380174091884, 30.45135232380458, 35.92709214346749, 29.056814125605992, 43.65655313219343, 27.468704325812205, 34.00665521621704, 27.83367235319955, 22.191827160971506, 29.382809707096644, 20.975360870361328, 25.796201705932617, 23.978106532778057, 36.09168107169015, 39.740200996398926, 42.516100134168354, 40.04548747198922, 51.20481552396502, 60.11360468183245, 58.254739216395784, 61.81685134342739, 64.6064349583217, 58.96124594552176, 55.77238409859793, 35.44999408721924, 18.160602194922312, 5.699825738157545, 0.5997713250773293, 0.22512809400047573, 0.17133347131311893, 0.10711705285523619, 0.02977705467492342, 0.04278253537735768, 0.03868276572653225, 0.05529322834419353, 0.054489602002182176, 0.09530952572822571, 0.04386874441323536, 0.03582704592762249, 0.02479159496059375, 0.02964916100193347, 0.06193040683865547, 0.023944118293002248, 0.022241651878825257, 0.07132375386676618, 0.02730310072989336, 0.04596255420308028, 0.017244551896250675, 0.05184972419270447, 0.055818736752761264, 0.028346909808793237, 0.030919595688049282, 0.005787109823099205, 0.044019413114126237, 0.0331674804245787, 0.0035553822776169647, 0.01709242943408234, 0.042808184001062594, 0.018394641611458998, 0.05087673890271357, 0.023645747785589526, 0.020710586803033948, 0.0683807914278337, 0.029969225970229933, 0.04287155577912927, 0.10346265323460102, 0.0291714146733284, 0.09045683326465742, 0.034868835737662654, 0.03390115659151759, 0.034919389989227057, 0.030824159737676382, 0.01469414062531931, 0.041261161477970223, 0.03123985743150115, 0.005543359264265746, 0.070083323999175, 0.0407547775789031, 0.05398248189261981, 0.01991191885567137, 0.09067012396241937, 0.027332905380587493, 0.13098288008144923, 0.14409133525831358, 0.21397927509886877, 0.23398094038878167, 0.1688201776040452, 0.14708933367260865, 0.15603404013173922, 0.14582432726664202, 0.12441681884229183, 0.11443693935871124, 0.1493099887988397, 0.23776217177510262, 0.14606937340327672, 0.16116909815796784, 0.11815706188125269, 0.1630827026175601, 0.14610722208661692, 0.1534058161612068, 0.08129795401224069, 0.2054079800312008, 0.11286979487964086, 0.14547169261745044, 0.11772324730243001, 0.09774941551898207, 0.18702022385384354, 0.1552994716912508, 0.29675015221749035, 0.1694273850215333, 0.20894367673567363, 0.107756633178464, 0.20105676565851482, 0.16821036461208547, 0.0942224787016, 0.09935227808143411, 0.11572701084826674, 0.16873342011656078, 0.15344865886228426, 0.11614836752414703, 0.12526695536715643, 0.11084212868341378, 0.16570933881614888, 0.13564692623913288, 0.1504584364593029, 0.21149304136633873, 0.17603297771087714, 0.12696025307689393, 0.22616417626185076, 0.8478732577392033, 10.042125463485718, 27.73945825440543, 53.22212771006993, 75.23148127964565, 77.31942885262626, 78.28663199288505, 75.00925704411098, 74.9768020084926, 69.56143856048584, 65.80570098331997, 59.440928731645855, 62.006891523088726, 60.78131267002651, 59.82754039764404, 45.17019387653896, 41.93127025876726, 41.01997927256993, 32.709162507738384, 34.31880303791591, 29.829498972211564, 27.74057170322963, 19.855679512023926, 27.328248228345597, 26.269787447793142, 32.578324454171316, 73.74041175842285, 60.66740390232631, 85.42950521196637, 70.2537362234933, 73.99244376591274, 75.30463191441127, 82.35669912610734, 54.24667085920061, 36.51914119720459, 31.59968110493251, 34.237467425210134, 36.58586474827358, 26.03346358026777, 41.239521503448486, 39.214010443006245, 44.887231963021414, 64.6081303187779, 62.26143183026995, 43.094614097050254, 31.65399169921875, 47.966951506478445, 37.86597653797695, 52.74984475544521, 50.87583916527884, 41.23312221254621, 52.42898736681257, 37.32132462092808, 51.511616706848145, 32.17202854156494, 35.98983437674386, 32.33027376447405, 25.232127836772374, 29.157486574990408, 24.237187487738474, 39.21484422683716, 42.802821023123606, 47.51009355272566, 48.14581898280552, 59.77795805249895, 70.45770754132951, 68.32483986445835, 71.35132925851005, 72.14350032806396, 68.04591832842145, 61.41746194022042, 39.922740595681326, 19.4131053175245, 6.708110102585383, 0.9382249180759702, 0.36078637891582077, 0.3346339293888637, 0.23893383890390396, 0.1774586069264582, 0.10214363544114999, 0.11582739331892558, 0.12603766258273805, 0.12361255128468786, 0.17865613981017045, 0.11945969983935356, 0.07373869392488684, 0.12286449356802873, 0.1671608066452401, 0.18169657380453177, 0.11726192491395132, 0.13203501648136548, 0.12570717531655515, 0.11492400536579744, 0.11617538678858962, 0.14391996445400373, 0.15946003129439695, 0.12529968789645604, 0.18528292993349688, 0.15549376340849058, 0.1125412889357124, 0.16319924779236317, 0.1648798840386527, 0.13964372820087842, 0.1372257958033255, 0.13643600818301949, 0.16500162679169858, 0.1676459727542741, 0.13361189115260327, 0.13005487487784453, 0.12729204313031264, 0.11399841574685914, 0.1668440257864339, 0.1996024479823453, 0.1573108666177307, 0.17169726107801708, 0.113183990520026, 0.2534719673650605, 0.15111372486821242, 0.1379014402627945, 0.13298694682972773, 0.1447892492370946, 0.08166331119303193, 0.07986938674002886, 0.12269339417772633, 0.17072042849447044, 0.14242950800274098, 0.06292664552373545, 0.2769730548773493, 0.15864578927201883], [0.04164198586451156, 0.026910500368103385, 0.04857813028086509, 0.05552477502663221, 0.07539103526089873, 0.001360705288659249, 0.031813385763338635, 0.023877109567235624, 0.02813221623988024, 0.07044271685715232, 0.04436676876087274, 0.06705063208937645, 0.02746139107538121, 0.03133911692670413, 0.021907003496640494, 0.044494642077812126, 0.010958294750058224, 0.04022953040631754, 0.023631990488086427, 0.05746725454394307, 0.05060061586222478, 0.04383150641141193, 0.10569529807461159, 0.023186944458367567, 0.12983174542231218, 0.003943252826242575, 0.051972549209105115, 0.002869073368076767, 0.030367831366934946, 0.026252423180267215, 0.030052431326891695, 0.057210300117731094, 0.020970397861674428, 0.06843622095350708, 0.05117609498224088, 0.018314369222415344, 0.017713689311806644, 0.02753632509016565, 0.040125928286995204, 0.05054249933787754, 0.057766705618372986, 0.022644472674333622, 0.02651942501376782, 0.03808871510305575, 0.07959955371916294, 1.529796608856746, 5.083270822252546, 14.516793148858206, 37.71267148426601, 58.4444180897304, 60.38804462977818, 63.64306722368513, 53.47563968385969, 54.06764357430594, 47.95721708025251, 47.53366184234619, 37.57820994513375, 31.98072726385934, 27.458964688437327, 25.380699430193218, 22.37336448260716, 21.003553186144146, 24.803851297923497, 11.215055210249764, 12.553984369550433, 11.0712822164808, 14.980217150279454, 12.795022589819771, 19.915953397750854, 20.833902495247976, 21.65590912955148, 29.688936914716447, 46.64630740029471, 65.70885004316057, 76.12278924669538, 44.618770939963206, 22.722740752356394, 18.148239612579346, 19.381028958729335, 7.589885575430734, 10.272323625428335, 18.246136256626674, 11.244290624346052, 10.544213584491185, 13.589171290397644, 23.960715191704885, 24.04777785709926, 22.292998143604823, 26.72303581237793, 22.85119209970747, 29.213909421648296, 31.30091551371983, 36.03514010565621, 44.57167257581438, 48.62275375638689, 51.95505421502249, 38.39094768251692, 53.80497734887259, 31.200409821101598, 50.92259011949812, 40.35656179700579, 57.13763563973563, 46.03614091873169, 26.896745988300868, 36.45123297827584, 26.154490777424403, 15.886731249945504, 18.828344924109324, 15.875787837164742, 20.512308597564697, 22.485956566674368, 30.32124035699027, 39.50356272288731, 41.28357308251517, 48.81918280465262, 50.315491267613, 57.17336675098964, 62.76505810873849, 57.325799805777415, 48.38395111901419, 32.734342779432026, 16.780516249792917, 8.06055133683341, 0.9871913705553327, 0.11090105944978339, 0.01689764917162912, 0.07295531846050705, 0.08701726461627654, 0.033865306193807294, 0.04942593264526554, 0.050920864034976275, 0.00651429028948769, 0.007736629989397312, 0.026142066244834235, 0.032954149014715634, 0.03926084702834487, 0.01981572464241513, 0.03069280892876642, 0.07382775843143463, 0.02588464193312185, 0.028109295326950293, 0.07830942116145577, 0.023863515118137002, 0.0458646449925644, 0.035376064412828, 0.04535548249259591, 0.10998016529317413, 0.02525378417755876, 0.025122633536479304, 0.02184864439602409, 0.09368750133684703, 0.06257160207522766, 0.01392879129187869, 0.02388907383595194, 0.06364509197218077, 0.0333487103427095, 0.050589515029319694, 0.021377469679074626, 0.04156745218538812, 0.03054588913385357, 0.03444718729172434, 0.040634704022003074, 0.035292825129415305, 0.0651321964604514, 0.03464106510260275, 0.1263902158077274, 0.056813625153154135, 0.06504812597164086, 0.042704188331429443, 0.014875331527686544, 0.05339534214830824, 0.02182540117896029, 0.04241376855809774, 0.03286734402977994, 0.06490900593676738, 0.058537548540958335, 0.05335647566244006, 0.00757123453409544, 0.0130409451833527, 0.02220087531687958, 0.059654668239610534, 0.021132087667605708, 0.01724104387020426, 0.0453675841646535, 0.04220752783917955, 0.056424922975046296, 0.030490232298948934, 0.061324977182916234, 0.03068339764805777, 0.04767434877742614, 0.04696481827912586, 0.01575247713896845, 0.009184706839732826, 0.03916472575760313, 0.017774737107434442, 0.1372751117284809, 0.08822089752980641, 0.055628292329077206, 0.007022225489241204, 0.010101602728744703, 0.09051771142653056, 0.025382663422663296, 0.023115988355129957, 0.04552044453365462, 0.02716448111459613, 0.011431058087120098, 0.022135685064962933, 0.0231435775889882, 0.023475759496380175, 0.04065377764137728, 0.005434466692219887, 0.040614575280674865, 0.01157048431092075, 0.01891644182614982, 0.056434123909899166, 0.04740068542637995, 0.031136380841157267, 0.047444386474256, 0.048880912962236574, 0.041524046300245185, 0.08262080552854709, 2.20249405503273, 8.362802318164281, 21.754891429628643, 47.08911957059588, 70.06820542471749, 68.47611604418073, 71.76610892159599, 61.13639341081892, 62.099406787327354, 56.31932544708252, 58.119183335985454, 47.03753614425659, 40.80584968839373, 35.169675963265554, 35.27996819359915, 30.121663774762833, 29.88820082800729, 31.0785071509225, 18.208876541682653, 22.212510211127146, 19.15213097844805, 26.36929954801287, 18.71234995978219, 24.793482848576136, 21.26094572884696, 24.810733488627843, 29.44147334780012, 39.469738892146516, 57.9585930960519, 58.21881355558123, 51.03847564969744, 28.268674748284475, 23.09362690789359, 21.158499751772197, 10.421222652707781, 8.008035114833287, 10.20479495184762, 7.697038088526044, 6.701637855597904, 8.467702746391296, 11.456332274845668, 15.193320138113839, 15.165087870189122, 13.746596625873021, 14.49896320274898, 18.42744255065918, 20.78339777673994, 22.703655787876674, 28.83429980278015, 34.31586742401123, 39.39760269437517, 29.367450714111328, 30.500163418906077, 29.74151393345424, 35.29800224304199, 42.09619270052229, 36.8270332472665, 37.7470372744969, 29.88898597444807, 38.96977778843471, 27.95609266417367, 23.327242715018137, 31.308965001787456, 25.637840100697108, 31.179037162235804, 34.751363141196116, 35.86526707240513, 47.17039264951433, 47.44223744528634, 55.08370644705636, 56.36923088346209, 64.99646513802665, 69.41378934042794, 66.91218771253313, 59.20100048610142, 44.838799544743125, 25.271553652627126, 13.542652232306343, 2.613637638943536, 0.4204758017190865, 0.011700802050264818, 0.055096850131771395, 0.01858891297264823, 0.014454599104023405, 0.053973270779741664, 0.04592899725373302, 0.036635937701378546, 0.0505868008892451, 0.039332378190010786, 0.04553750968937363, 0.047341581633580584, 0.005349246934721512, 0.04995928831132395, 0.04245959681325725, 0.043314211669244936, 0.012123050151525863, 0.02660686442894595, 0.02786740437815232, 0.051378848031163216, 0.05347262389425721, 0.046799299839351854, 0.02216661099477538, 0.07071710963334356, 0.007349486745494817, 0.018937876747388924, 0.03262105956673622, 0.03332286494384919, 0.01852440125575023, 0.04512835307312863, 0.02305422809773258, 0.012813976067783577, 0.04194226814433932, 0.04629729249115501, 0.03384307060124619, 0.05709074903279543, 0.03135466216398137, 0.0482053160002189, 0.02992756731276001, 0.06853368572358574, 0.06075707729905844, 0.028541890239076953, 0.04188681486994028, 0.03250410048557179, 0.01616694838074701, 0.021292657890756215, 0.02520010357589594, 0.011747054389810987, 0.016274511448240707, 0.03868974445919905, 0.04445183669616069, 0.07153414043464831, 0.09235661596591983, 0.12050057255796023, 0.1624253514621939, 0.12914227241916315, 0.14997617448014872, 0.07839601580053568, 0.11452866372253213, 0.14698375362370694, 0.1365853673113244, 0.10787167879087584, 0.1351256484964064, 0.10260823515376874, 0.2117344912673746, 0.11444096985672202, 0.11206369527748652, 0.14330503530800343, 0.09135334087269646, 0.20271625875362329, 0.1700657100549766, 0.30492725915142466, 0.16003887594810554, 0.12203737295099668, 0.2582784380231585, 0.062156053659107, 0.207078343257308, 0.11696727786745344, 0.07249274078224387, 0.13943311093108995, 0.10060428375644342, 0.12194065456943852, 0.10315832349338702, 0.14121170049267157, 0.10077647558812584, 0.17096516250499658, 0.07409610546060971, 0.12467544924999986, 0.120295057871512, 0.11732401086815766, 0.12298874690064363, 0.13551292914365018, 0.0984724760055542, 0.07635711984974997, 0.19109485378222807, 0.16387825778552464, 0.33169494995049065, 2.7002953546387807, 11.180305532046727, 27.07677902494158, 57.30903032847813, 80.9151702608381, 78.72269398825509, 80.91074425833565, 69.32362951551164, 70.22745813642229, 64.129378591265, 63.03046539851597, 51.44879804338728, 47.63341365541731, 38.80030427660261, 38.71700232369559, 34.25935425077166, 34.68690470286778, 35.44145475115095, 21.287496532712662, 22.066222837993077, 19.51040267944336, 25.194072553089686, 21.79860254696437, 31.248925617762975, 29.391616548810685, 31.555483613695415, 43.03039189747402, 63.01786136627197, 77.14065170288086, 87.80025836399624, 53.286561829703196, 32.35843481336321, 26.662874834878103, 27.223113298416138, 11.704653075763158, 14.629322699138097, 24.67107469694955, 15.362133571079799, 15.14479044505528, 17.83143823487418, 30.871113845280238, 29.54218748637608, 29.15659373147147, 33.88446419579642, 28.524854830333165, 36.78382587432861, 39.62850522994995, 46.16739933831351, 58.08370583398001, 62.52833298274449, 66.60358347211564, 50.49953515189034, 64.46718611036027, 42.22962590626308, 67.28753634861538, 54.09890004566738, 73.33629063197544, 63.28946644919259, 37.712966782706125, 49.084537982940674, 36.55223546709333, 25.77385629926409, 31.113949911934988, 24.7717992578234, 30.45294346128191, 34.72697843824114, 44.34082562582833, 54.00431769234793, 56.07412004470825, 63.58618927001953, 64.38949830191476, 74.14606148856026, 79.42651176452637, 76.18831075940813, 68.80800369807652, 51.03789894921439, 29.145511354718888, 15.098348685673304, 2.6152048919882094, 0.5991551609975951, 0.10449995007365942, 0.16480016974466188, 0.15805098547467164, 0.10167657943176371, 0.17548872477241925, 0.13018374224858625, 0.1668634997414691, 0.13424955122172832, 0.15756866921271595, 0.15713967223252567, 0.1625009538339717, 0.10622200409748725, 0.129830429064376, 0.23147220643503325, 0.16217873112431594, 0.12642476681087697, 0.21657498367130756, 0.09217158625168459, 0.14759819422449383, 0.17841189434485777, 0.12123752944171429, 0.2529952829437596, 0.16874760149845056, 0.15036584357065813, 0.09921663893120629, 0.16030108902071202, 0.16424488382680075, 0.12934746140880243, 0.1498887791697468, 0.16832791401871613, 0.09493545615779501, 0.19271501898765564, 0.12065264582633972, 0.17460329085588455, 0.11705133478556361, 0.13567098709089415, 0.0988096332709704, 0.13200087259922708, 0.15856215304562024, 0.20758603672896112, 0.18047926841037615, 0.21422191922153744, 0.15286525445325033, 0.14869443540062222, 0.11711256578564644, 0.09652844603572573, 0.05985097520585571, 0.12879712879657745, 0.11488496246082441, 0.17778000182339124, 0.13539265202624456], [0.003187461506708392, 0.006386967009997794, 0.025665637970502888, 0.019250812008976936, 0.04182197745623333, 0.02244408940896392, 0.04732072346710733, 0.024675818226699318, 0.04290487863389509, 0.04631989788530128, 0.022491603823644773, 0.020475482900760004, 0.037387571297585964, 0.04786662524566054, 0.03935600138668503, 0.016381648735010197, 0.01501532517639654, 0.01308742568029889, 0.011579737832237567, 0.017954718521130935, 0.03292707886014666, 0.0362208812231464, 0.12226150663835661, 0.08234230761549302, 0.06472894988421883, 0.03297513610284243, 0.03260082904515522, 0.07895167491265706, 0.033038246644926925, 0.03121361169697983, 0.027521551686472127, 0.05830354895442724, 0.035495730848716836, 0.0548953795140343, 0.05510318086349538, 0.026169267017394304, 0.048936121964028904, 0.06312833327267851, 0.11388682387769222, 0.004614229812952024, 0.09415241996092455, 0.009963480988517404, 0.07289001625031233, 0.1224406398832798, 3.2283050332750594, 14.949995960508074, 46.70509958267212, 58.01845530101231, 64.55941649845668, 65.63171809060233, 64.10542120252336, 55.070053236825125, 48.94746044703892, 38.54971054622105, 44.68830851146153, 31.355351175580704, 57.19863387516567, 33.39059666224888, 22.345997265407018, 18.091889722006663, 17.38822133200509, 14.68587235042027, 11.994735155786787, 20.694467782974243, 14.440063323293414, 18.715137924466813, 16.649624347686768, 19.55119902747018, 26.432344027927943, 46.228512219020296, 46.09379359654018, 31.434671810695104, 29.381274155208043, 21.819342919758387, 10.917746135166713, 6.765977306025369, 8.550097959382192, 5.061324502740588, 0.9644973597356251, 0.7962716466614178, 0.3509163813931601, 0.14817197700696333, 0.2208373099565506, 0.4746469706296921, 0.6721164030688149, 0.9228244530303138, 0.15775278290467604, 0.9473463829074587, 2.38910225885255, 1.8878513957772936, 2.7217338042599812, 5.391309653009687, 11.016141312462942, 13.551150747707911, 14.374849268368312, 12.102998512131826, 20.088432005473546, 21.342022521155222, 17.28997901507786, 23.208506686346873, 24.92414198602949, 41.931322370256694, 36.29966150011335, 44.67916815621512, 46.83236973626273, 44.34340688160488, 45.58145775113787, 20.90195141519819, 21.496798855917795, 13.161639945847647, 12.281552450997488, 24.44294101851327, 21.90132645198277, 21.038954257965088, 20.624087742396764, 36.220094203948975, 39.01511131014143, 48.2151654788426, 54.053774969918386, 54.73793976647513, 57.16504280907767, 56.751416546957834, 41.610989570617676, 29.785405703953334, 14.339251041412354, 4.52396775994982, 0.7396588644811085, 0.12814022547432355, 0.07666495761701039, 0.06328617408871651, 0.1336334821368967, 0.08320938037442309, 0.1176779754459858, 0.06144370724047933, 0.1079565431656582, 0.057501785191042085, 0.025902461959049106, 0.027397883590310812, 0.061944818922451565, 0.026368462846481373, 0.0675131283434374, 0.025517328875139356, 0.06060171992118869, 0.04842844206307616, 0.046018428169190884, 0.0453167788551322, 0.050484698332313976, 0.028900882761393274, 0.04220967200983848, 0.02625687776266464, 0.08126167274479355, 0.05482165668425815, 0.048101011597152264, 0.05508112508271422, 0.021220095355861952, 0.032850872592202256, 0.032284088898450136, 0.03280308337083884, 0.1207432709634304, 0.07753418811729976, 0.04982910118997097, 0.0194009378818529, 0.05530365403475506, 0.07989091665617057, 0.08457941721592631, 0.06535771435924939, 0.047079229461295266, 0.04223264381289482, 0.018452094867825508, 0.004641518370980131, 0.04146708328542965, 0.020853793315057243, 0.037424782158008645, 0.04406665611479964, 0.034933734219521284, 0.06820074216063533, 0.02460058735284422, 0.04690819792449474, 0.031217492917286496, 0.02662150382197329, 0.03473748492875269, 0.007569439808971116, 0.03819690411910415, 0.04519485629030636, 0.06306893431714602, 0.059282668200986724, 0.09250672826809542, 0.03046106207849724, 0.06523044833115169, 0.004435793762760503, 0.06588963831641845, 0.027150732298780764, 0.030759379999446015, 0.04874972839440618, 0.05768514570913144, 0.1030016972550324, 0.0062109736858734065, 0.049722381202237945, 0.11585081634776932, 0.06601013935038022, 0.03864882540489946, 0.0188027176606868, 0.023507311374747326, 0.086871338875166, 0.05301202414557338, 0.040136404867683134, 0.03502396580630115, 0.03207456407004169, 0.040588027598070245, 0.03628124709108046, 0.009684614122046955, 0.058098502457141876, 0.09230388022427048, 0.019238588200615983, 0.03708704474515148, 0.026644519729805843, 0.10933162152234997, 0.009183935006149113, 0.0768944313749671, 0.32172974039401325, 4.305086476462228, 19.515619039535522, 54.850768089294434, 69.88195896148682, 72.50320856911796, 72.42266505105155, 71.46024921962193, 64.03187452043805, 57.21303401674543, 46.368226596287315, 53.51221152714321, 38.518450600760325, 60.99185003553118, 43.7145289012364, 30.01793759209769, 27.758607489722117, 25.355329820087977, 22.126703432628087, 19.558496373040335, 23.959796292441233, 21.4683164528438, 23.542808839253016, 21.3955705506461, 23.29978517123631, 29.58338335582188, 36.92834840502058, 31.536007813044957, 29.167603152138845, 24.931017228535243, 19.652171986443655, 12.799696121897016, 7.076038496834891, 5.859105374131884, 2.9691789150238037, 0.6697854995727539, 0.3089556944157396, 0.005754410796466151, 0.17687132129711763, 0.1394572260656527, 0.08422721682914666, 0.16866066759186132, 0.23310058191418648, 0.13795888503747328, 0.3437429906002113, 1.3057303407362528, 0.7784443604094642, 1.2560147855963026, 1.9926334874970573, 5.439055502414703, 7.316655482564654, 10.02691672529493, 9.836041024753026, 9.622800809996468, 12.184691957065038, 12.458040169307164, 17.402564150946482, 18.945267472948345, 34.27482441493443, 31.672546863555908, 29.206749303000315, 34.4907466343471, 38.606630189078196, 42.93010854721069, 26.892842837742396, 22.08622670173645, 17.776493617466517, 16.993728671755107, 34.91176577976772, 33.16729198183332, 29.01556440762111, 27.787776027406963, 42.47630432673863, 47.151906967163086, 54.52025270462036, 58.942006383623394, 62.10328388214111, 64.00185830252511, 64.98063714163644, 54.09339707238333, 41.16666964122227, 21.019177947725566, 6.817088254860469, 1.0768157499177116, 0.17825672695679323, 0.019073951856366227, 0.065174062071102, 0.05521107132413557, 0.025048337344612395, 0.08583564337875162, 0.03525382632921849, 0.08085807333035128, 0.015281555176313435, 0.027562463955421532, 0.03388735518923827, 0.024807718648974384, 0.06507190862404448, 0.06522260446633611, 0.03704584749149425, 0.03575915510633162, 0.02350476517208985, 0.017864578536578586, 0.01731082101884697, 0.01781534233928791, 0.0483295693328338, 0.06642661735947643, 0.04184062699122088, 0.04726196911984256, 0.039380136877298355, 0.0717009175568819, 0.07148538769355842, 0.016067174895267402, 0.024732528487220407, 0.05525292336408581, 0.02709573703551931, 0.02287731196598283, 0.011045990312205893, 0.03215859384675111, 0.023792665884164826, 0.051495929248631, 0.05470860257212605, 0.0854794599914125, 0.08426196460745164, 0.012029613334951656, 0.026599359831639698, 0.04418346252558487, 0.02248934599837022, 0.01095216503433351, 0.028246386542118022, 0.0031247703840823044, 0.07834686272378479, 0.0230833593024207, 0.04075233146016087, 0.08254280114280325, 0.14207323640584946, 0.10692385357937642, 0.1318269640739475, 0.15039112578545297, 0.048695116503430266, 0.2034640721976757, 0.12406429275870323, 0.08999702400927033, 0.1567111230854477, 0.15196133724280766, 0.14704175479710102, 0.1635529545268842, 0.16364906222692557, 0.15452256266559872, 0.09262081714613096, 0.09801821038126945, 0.13213904947042465, 0.10035377541290862, 0.1886479343686785, 0.147319994866848, 0.2813298468078886, 0.24311616591044835, 0.22779951351029532, 0.17936892727656023, 0.1460503065692527, 0.13808741314070566, 0.15002477115818433, 0.14005160917128834, 0.114015256986022, 0.11385757901838847, 0.12228623245443616, 0.11844710846032415, 0.12807158487183706, 0.09743359139455215, 0.24086475957717213, 0.14313804783991405, 0.1474866159260273, 0.14352767621832235, 0.15691829339734145, 0.19366815712835106, 0.10638798733374902, 0.12577255895095213, 0.9467532890183585, 6.683817028999329, 25.66450902393886, 64.37905515943254, 81.36785929543632, 84.22078963688442, 82.09905297415597, 80.42973436628068, 71.33327783857072, 65.25702953338623, 53.807683672223774, 59.66915621076311, 45.68604551042829, 70.46838692256382, 46.13999911717006, 31.804482732500347, 28.927812133516582, 27.468365601130895, 25.47771191596985, 22.437412977218628, 32.29862471989223, 23.885049309049332, 27.636142015457153, 25.55723752294268, 31.37207201548985, 38.87727642059326, 61.75428281511579, 61.19118690490723, 43.165909562792095, 38.34498187473842, 28.25635732923235, 14.193354504449026, 8.725174324853079, 11.715821436473302, 6.585017119135175, 1.3995634828295027, 1.3428880040134703, 0.7762612689818654, 0.6120279473917825, 0.7808879550014223, 0.8744932721768106, 1.2473718779427665, 1.4561155225549425, 0.6447958690779549, 1.869893993650164, 3.5570959619113376, 2.6917937994003296, 3.810400358268193, 7.68198481627873, 14.345911758286611, 16.394847801753453, 17.961734328951152, 16.233382088797434, 26.7444623197828, 27.38510533741542, 23.052613428660802, 29.046725341251918, 33.07568693161011, 53.4184490612575, 46.92921372822353, 57.457402161189485, 58.85556384495327, 61.48258740561349, 58.21620798110962, 30.94729389463152, 34.53645535877773, 21.12968209811619, 20.311938183648245, 37.474584511348176, 34.75025142942156, 32.628643308367046, 33.254210472106934, 49.59281955446516, 55.14263064520699, 63.33522033691406, 67.16981301988874, 70.2217606135777, 74.11020183563232, 75.34727300916398, 64.56582273755754, 48.095493180411204, 23.077741588865006, 7.899073464529855, 1.530245310493878, 0.2956240826419422, 0.18074279784091882, 0.16850718297064304, 0.2239978989320142, 0.19134663098624774, 0.16369155208979333, 0.22504261215882643, 0.2746251065816198, 0.09320667785193239, 0.09366153380168335, 0.0831525462812611, 0.13741289504936763, 0.2821870536676475, 0.19102272550974572, 0.18108054543180124, 0.21306228930396692, 0.0904200973787478, 0.1428020101572786, 0.17159387948257582, 0.1224945562758616, 0.13632502699536936, 0.12582988158932754, 0.17865470131593092, 0.16356454390500272, 0.12203060117151056, 0.16845528861241682, 0.17976338682430132, 0.11380720457860402, 0.12586053780147008, 0.1494984451149191, 0.1368241844964879, 0.14111787267029285, 0.15350070249821457, 0.19000163887228283, 0.21539339636053356, 0.09111633537603275, 0.16149407571979932, 0.2526649720966816, 0.24302955770066806, 0.1169763838074037, 0.10559786044593368, 0.2402224311871188, 0.16602624181125844, 0.23670254434858048, 0.05634272185021213, 0.1447721772960254, 0.1257807963660785, 0.09497536758759192, 0.18154972525579588], [0.06046599256140845, 0.038956893874066215, 0.0751128223325525, 0.020480312373755232, 0.03206493905080216, 0.08552714064717293, 0.03168838604220322, 0.06953566481492349, 0.020926442363166382, 0.024611727201512883, 0.017828838400808827, 0.03939929870622499, 0.016316726504425918, 0.021404916420578957, 0.038029825048787255, 0.03509459112371717, 0.05075722513720393, 0.03549544247133391, 0.022513206682300994, 0.022905491525307298, 0.04632155351074679, 0.058895536831447055, 0.02068241742173476, 0.05162052184875522, 0.018223241969410862, 0.038040671431060345, 0.04437208169006875, 0.0383063687809876, 0.04032452870160341, 0.03509925605197038, 0.10043301473238639, 0.032340054466788254, 0.05739731793957097, 0.026433134019108753, 0.0534694110309439, 0.0868778188845941, 0.021970544908461825, 0.008074580292616571, 0.013658154207015676, 0.1054707911929914, 0.03879718030137675, 0.05449550186416932, 0.5154003809605325, 7.950871416500636, 31.68528985977173, 47.71201515197754, 68.5683672768729, 60.781180654253276, 60.53449875967843, 54.203967230660574, 60.50391973767962, 46.77849687848772, 35.18385028839111, 27.62402262006487, 23.958976405007498, 23.429059880120413, 34.279691628047395, 20.966387271881104, 16.355856248310634, 15.443962505885533, 19.021249498639786, 27.007979699543544, 21.437687056405203, 26.447305236543926, 40.74278783798218, 44.421841621398926, 47.588153089795796, 35.88964135306222, 33.327771050589426, 32.91810178756714, 26.41261809212821, 14.915079525538854, 7.58405864238739, 6.121439388820103, 1.0169557162693568, 0.6653743705579213, 0.12981687193470343, 0.04630247310602239, 0.09997397900692054, 0.03365225976865206, 0.09103328947510038, 0.10800191001700503, 0.04423189974789109, 0.06511322462132998, 0.08605681865343026, 0.045249061060271094, 0.08952167630195618, 0.09244637936353683, 0.07154743972101382, 0.05457274968336735, 0.13791012551103318, 0.1340022659195321, 0.08370917569845915, 0.24529187487704412, 0.8231689376490456, 1.4931967556476593, 1.2252205865723746, 0.8651237892253059, 1.2379244991711207, 1.4100635136876787, 4.583386582987649, 4.521167201655252, 10.899780699184962, 27.241711888994487, 34.57957240513393, 32.66723012924194, 48.91531808035714, 52.13232707977295, 55.54522664206368, 53.102389403751914, 46.9088694027492, 28.09589215687343, 13.411625708852496, 13.297024726867676, 19.45202738898141, 23.739976133619034, 32.64332832608904, 31.107766015189036, 36.755855900900706, 44.40389442443848, 50.409618513924734, 53.78788825443813, 56.79420007978167, 58.060102803366526, 51.14139584132603, 38.45968273707798, 19.27327629498073, 7.2602982095309665, 1.9160167872905731, 0.3922596829278128, 0.07477789066199746, 0.059600005458508215, 0.05045243738485234, 0.035902302246540785, 0.034971409876431735, 0.08098240130181823, 0.008627867924847772, 0.06625337379851512, 0.013659521455078252, 0.047630966641008854, 0.0388418889737555, 0.05255045748448797, 0.03870078083127737, 0.01838980704945113, 0.03465599626568811, 0.03680983265595777, 0.03310729097574949, 0.055512978695333004, 0.01671303336375526, 0.027583673263766935, 0.031140024574207406, 0.0807730732485652, 0.06239292344876698, 0.008689162537588604, 0.0503413578096245, 0.03653670534757631, 0.06501839935247387, 0.007115719557207609, 0.07038145193031856, 0.053119924784238846, 0.031269519589841366, 0.04005818335073335, 0.018780746696782962, 0.05845813958772591, 0.08560165057757071, 0.09754885413816997, 0.07405060968760933, 0.026531531774838055, 0.04526686921183552, 0.093099035056574, 0.06285795063844749, 0.08890399230378014, 0.013918109454347618, 0.03451942073713456, 0.03291422401421836, 0.09832993615418673, 0.011438085165406977, 0.05098361156082579, 0.04687586912353124, 0.025613743612276654, 0.03868991409295371, 0.045129296236804554, 0.02016258835127311, 0.018402985895850828, 0.02080783444190664, 0.04369591136596032, 0.046880154072174, 0.03764387772285512, 0.044882546977273056, 0.05817264597862959, 0.028881860032145466, 0.018292152289567248, 0.043176842254719565, 0.03105016957436289, 0.019649152777024677, 0.05336917105263897, 0.0183958460111171, 0.011299588534581875, 0.041270274203270674, 0.021925086454887475, 0.02769126177632383, 0.041652659220354896, 0.07517309659825903, 0.026992696403924907, 0.015963221634072915, 0.04782341952834811, 0.038331667959157906, 0.05804986506700516, 0.018777954525181224, 0.01465819014369377, 0.041111334160502465, 0.02477573081185775, 0.020750986778044274, 0.05701894645712205, 0.02411391319973128, 0.041953419867370806, 0.055652013913329156, 0.030901685756232058, 1.1492646166256495, 10.988615155220032, 38.97427327292306, 55.9013808795384, 76.13147449493408, 67.79869447435651, 67.60821655818394, 60.4668094090053, 64.76468018123082, 52.97374350684029, 40.27847446714129, 36.30043969835554, 32.751987729753765, 32.59697689328875, 41.228407859802246, 26.57020149912153, 19.86054846218654, 18.32665719304766, 23.9926004750388, 30.410062653677805, 21.49066185951233, 27.347817829677037, 35.003600120544434, 28.216311386653356, 26.08289306504386, 28.21868245942252, 24.78034380504063, 26.211856842041016, 21.63807484081813, 12.248850754329137, 6.166434620107923, 4.019705721310206, 0.9235873435224805, 0.4361475722065994, 0.0859014205634594, 0.0581117949581572, 0.02576655987650156, 0.054366688776229105, 0.1030015479773283, 0.08175175144736256, 0.2011997601283448, 0.1404026967606374, 0.11568396458668367, 0.015456277943615402, 0.05722587249640908, 0.1248820631631783, 0.11707390286028385, 0.1548178746764149, 0.1680331448359149, 0.06344128040862934, 0.13057588120656355, 0.134437071159482, 0.5251348071864673, 0.8018623409526688, 0.705188199877739, 0.4495004085557801, 0.5967023926121848, 1.4040121755429675, 3.289460471698216, 3.610670481409345, 8.424253055027553, 17.982891593660625, 24.521097830363683, 29.15547854559762, 35.87849644252232, 37.31738499232701, 46.81798696517944, 48.514288902282715, 43.02167190824236, 34.04967498779297, 20.526590619768413, 20.140847478594097, 27.844151973724365, 32.87350824901036, 43.112853118351524, 39.698678561619346, 44.5749625478472, 51.73461219242641, 55.765560967581614, 61.27298109872, 61.733660561697825, 66.5361442565918, 59.595720699855256, 50.571080752781455, 27.749724217823573, 11.406035133770533, 3.1420246916157857, 0.48126431554555893, 0.10995553447199718, 0.10289649040039096, 0.03989543333383543, 0.04552061416740928, 0.04711045564285346, 0.06063515812690769, 0.03911639031554971, 0.027203493485493318, 0.04656582272478512, 0.030381378318582262, 0.0619331006226795, 0.05887904164514371, 0.05756434611976147, 0.038837451354733536, 0.01685997181838112, 0.0245969079967056, 0.016633688871349608, 0.032289883587509394, 0.01628665722507451, 0.053686854363019974, 0.02459526085294783, 0.006952850372597043, 0.01151677656785718, 0.010610610013827682, 0.03252519613930157, 0.04516363010874816, 0.025481424194627574, 0.019206703840089694, 0.04195706360042095, 0.09752103420240538, 0.024946981176201786, 0.020653345588860766, 0.05413484014570713, 0.03875821542793086, 0.0637533183076552, 0.040802007008876116, 0.07563215267977544, 0.04465710371732712, 0.041253816336393356, 0.02031281091538923, 0.08255225313561303, 0.08175673189439944, 0.04608786605032427, 0.047086805304778476, 0.016145123301872184, 0.04914057135049786, 0.07205583208373614, 0.11939257915530886, 0.15692593370165142, 0.06379972331758056, 0.10145255431000676, 0.13950590416789055, 0.12563264503010682, 0.1358733262334551, 0.06304321105458907, 0.08527005729930741, 0.19849772511848382, 0.0963827238551208, 0.11843447413827692, 0.09624714577304465, 0.14054425273622784, 0.12751975948257105, 0.14727842781160558, 0.09491997877401964, 0.08460957131215505, 0.1215188093483448, 0.0649617552491171, 0.1080603658088616, 0.0986686133380447, 0.21691319266600267, 0.1285694938685213, 0.12278281152248383, 0.19647160598209926, 0.157424656940358, 0.11206284032336303, 0.1541494091174432, 0.16474264354578086, 0.1652944960764476, 0.14045623317360878, 0.11585289266492639, 0.17648933322301932, 0.18337904209537165, 0.1888472336743559, 0.16155016342444078, 0.14929377181189402, 0.19560780376195908, 0.1954096851072141, 0.17308345383831433, 1.97189485175269, 15.624770266669136, 48.49688713891165, 67.69456877027238, 86.51620347159249, 77.55798830304826, 78.23476369040353, 70.91669859204973, 77.27264663151333, 62.299271719796316, 48.768089226314, 41.55193335669381, 37.25170367104666, 35.0285267829895, 45.96290690558297, 31.47381101335798, 25.238226618085587, 23.715259654181345, 26.79201579093933, 37.02712399618966, 30.566598619733536, 36.52317115238735, 53.748721258980886, 57.46243265696934, 63.01801422664097, 47.03321436473301, 44.32506363732474, 41.939993722098215, 34.686060496738975, 20.59707314627511, 10.726052284240723, 8.087070873805455, 1.4654542271580016, 0.9836864386286054, 0.405553188174963, 0.1093178540468216, 0.2590913772583008, 0.16929287223943643, 0.19925152324140072, 0.3841655472559588, 0.253822634262698, 0.20364574316356862, 0.26758712423699244, 0.27496787533164024, 0.5320814858589853, 0.40208782841052326, 0.26230861033712116, 0.2842709704169205, 0.49804796065602985, 0.5756944598896163, 0.35611238543476376, 0.9210081504923957, 1.4073536076716013, 2.4620835312775204, 2.2451303728989194, 1.3333215287753513, 2.1297611807073866, 2.690322084086282, 6.227162744317736, 6.341613471508026, 14.36745377949306, 35.13908304486956, 44.145042760031565, 42.04225730895996, 61.35150963919503, 66.58554594857353, 69.55588694981166, 67.09692641666958, 58.60216304234096, 38.373177664620535, 23.484245947429113, 24.13980848448617, 31.69263063158308, 36.324598584856304, 46.03750276565552, 44.830242838178364, 50.86367981774466, 59.550161361694336, 63.96467849186489, 68.40110329219273, 69.21224989209855, 73.74811731066022, 68.75657313210624, 56.82723181588309, 31.07462658200945, 12.466750604765755, 3.63547728742872, 0.7282371116536004, 0.34239951840468813, 0.2172356325068644, 0.23956427936043057, 0.17142320078398499, 0.18106964815940174, 0.20831668323704175, 0.18010189437440463, 0.17205981590918132, 0.17260816719915184, 0.11513118924839155, 0.14901816445801938, 0.14981017767318658, 0.16728311936770165, 0.12293659469911031, 0.07245441033904042, 0.09283355144517762, 0.15576212400836603, 0.1010311229952744, 0.10513857366251093, 0.1557571299906288, 0.12981267858828816, 0.16300355829298496, 0.09298359589385134, 0.11565276554652623, 0.2257511927081006, 0.1278124659189156, 0.19303181341716222, 0.14855708634214743, 0.17944503176425183, 0.19552472393427575, 0.12320072124046938, 0.15805576236120292, 0.15628403957401002, 0.10502696822264365, 0.1953533531299659, 0.17507400416902133, 0.16062845502580914, 0.16462912463716098, 0.09523171133228711, 0.17492172734013625, 0.21724830754101276, 0.1781149131378957, 0.1364845505782536, 0.15306634509137698, 0.07529587750988347, 0.16771322914532252], [0.030112332398337976, 0.029679698470447744, 0.033649121544190815, 0.05854039838803666, 0.053590441322220225, 0.0771307854780129, 0.03188783123290964, 0.007183970002058361, 0.059967086118246825, 0.03027043105768306, 0.05746976512351206, 0.0638938836221184, 0.037355937995016575, 0.06120733956673315, 0.04740899748035839, 0.019794961470844488, 0.010865445714443922, 0.006020413487151797, 0.031035849092794315, 0.04671162972226739, 0.027266178246853606, 0.07566292424287115, 0.04778278545875635, 0.022671955038926432, 0.0013269499738401333, 0.03947681454675538, 0.037480211683682034, 0.04541309690102935, 0.020573878960151757, 0.04363047005608678, 0.013884477017979537, 0.032626789794968705, 0.024157376760350804, 0.02539928413794509, 0.01093481998291931, 0.08976451041443007, 0.05287951982713171, 0.042923127833221636, 0.022264800100986446, 0.017817569630486623, 0.05162235050063048, 3.292698549372809, 19.582646574292863, 42.81893389565604, 63.08137484959194, 64.11129937853131, 59.442540713718955, 64.4577921458653, 35.02304465430123, 40.31518874849592, 54.62717853273664, 31.708865097590856, 27.358120271137782, 19.452920232500347, 18.768156153815134, 16.36867046356201, 22.821848120008195, 43.36687578473772, 50.13674538476126, 43.47428798675537, 48.44882992335728, 46.52816023145403, 48.20895378930228, 47.31150014059884, 50.96274375915527, 44.909066677093506, 35.832600116729736, 25.73078441619873, 15.479136024202619, 7.961651546614511, 2.8410780174391608, 1.1873811313084193, 0.19252166364874157, 0.12132655323616096, 0.09128114474671227, 0.010043224120246512, 0.16836399851100786, 0.138516667964203, 0.05277256574481726, 0.10163854754396848, 0.03669376584834286, 0.18288529930370195, 0.04333960923499294, 0.08978923623050962, 0.08766189324004309, 0.06354696902313403, 0.1055716418528131, 0.023530118633061647, 0.05594350237931524, 0.0881182826789362, 0.03804225581032889, 0.015797197685710022, 0.037294520397803614, 0.05433019037757601, 0.028568573628685305, 0.03197766248402851, 0.06426513048687152, 0.05520785506814718, 0.03496390188645039, 0.12176404547478471, 0.13940193903233322, 0.5943083039351872, 0.7847760149410793, 1.0071262951408113, 3.0449833273887634, 6.328345017773764, 15.817581040518624, 29.843565600258962, 29.110172816685267, 43.42148862566267, 46.410040855407715, 36.90211200714111, 29.943376473018102, 26.487465824399674, 20.964186429977417, 15.944022621427264, 19.767376593181066, 19.943652391433716, 30.887997967856272, 26.702158212661743, 36.90110451834542, 34.40129899978638, 44.749351910182405, 50.26934480667114, 54.0917329788208, 60.96208395276751, 57.95581381661551, 45.30698306219918, 25.005062443869456, 5.782131927353995, 0.7725776380726269, 0.15263681885387215, 0.043948173722518344, 0.015310818695330193, 0.02532181070585336, 0.03443500419546451, 0.025773374064426337, 0.028925900347530842, 0.05955979547330311, 0.036375078306134255, 0.07039278346512999, 0.024891103817416087, 0.04704332138810839, 0.05411137979743736, 0.05061048176139593, 0.05302991032866495, 0.019204953219741583, 0.034278262606156726, 0.06590114627033472, 0.047504077199846506, 0.04541833519137331, 0.10054841318300792, 0.020899161862741624, 0.05642373214608856, 0.04277405368962458, 0.03038957841428263, 0.08401375649763004, 0.02862522451739226, 0.02731279020995966, 0.04047741621200528, 0.047466360830834935, 0.037865555113447566, 0.02004771406895348, 0.020421393481748443, 0.07492964501891818, 0.0566791971879346, 0.06584979474012341, 0.032961660397372076, 0.09466295649430581, 0.029366904004876102, 0.04760746218796287, 0.08726604269551379, 0.02956112108326384, 0.0755364860274962, 0.035027256701141596, 0.03494096061746989, 0.03373011826936688, 0.08240431214549712, 0.06070337125233241, 0.06303455973310129, 0.024440446303093007, 0.011448645714803465, 0.05346063418047769, 0.007328991595256541, 0.026635868408318077, 0.018951332096808722, 0.0182925034314394, 0.03352920065766998, 0.01790218973266227, 0.045555640145071914, 0.06569776218384504, 0.0764592665114573, 0.04173778822379453, 0.044559292894388945, 0.050500538732324324, 0.021848625736311078, 0.028172667105016962, 0.058304132494543276, 0.05989849979856184, 0.007493227603845298, 0.02540072941753481, 0.02239762163454933, 0.04817837476730347, 0.02977325487881899, 0.00793653488757887, 0.03330029008377876, 0.018053788026528697, 0.03007800191906946, 0.03496081794479063, 0.026563439884089997, 0.010210459253617694, 0.03769139213753598, 0.08468285987951926, 0.023257296665438583, 0.02693554000662906, 0.03296812005074961, 0.3855301897440638, 5.733412027359009, 26.051961421966553, 50.874223709106445, 71.40976360866001, 71.59703840528215, 69.24533721378872, 74.42136996132987, 44.02662461144583, 49.82122073854719, 62.111885751996724, 44.33458961759295, 39.8705735206604, 30.689581734793528, 27.248840740748815, 21.398671184267315, 23.210096086774552, 32.812117440359934, 29.215986933026993, 22.211969988686697, 23.319240127290996, 30.357996327536448, 29.516875198909215, 30.45132453101022, 35.39125749043056, 34.52457046508789, 30.95296015058245, 18.39811246735709, 10.515174457005092, 4.4684008445058545, 2.9445115072386603, 1.2763352266379764, 0.3014310938971383, 0.11571475650582995, 0.030043508591396467, 0.048828611482999155, 0.06455605237611703, 0.14856811932155065, 0.11290925169097525, 0.1848359110632113, 0.2369451613298484, 0.6193117765443665, 0.2077289769159896, 0.30417042119162424, 0.2813904264143535, 0.11402711777814797, 0.09346329301063504, 0.11188074866575853, 0.04448460315221122, 0.07440401108137198, 0.14966187705951078, 0.06137703438954694, 0.061142322341246266, 0.07514598233891384, 0.06071789190173149, 0.070207326273833, 0.05424656093652759, 0.04344412737659045, 0.03425155546782272, 0.09686051428850208, 0.1584339099270957, 0.5222698152065277, 0.36829678448183195, 0.7489863868270601, 2.1369684168270657, 5.471077578408377, 11.230706896100726, 23.48789027759007, 28.058366673333303, 37.963619572775706, 40.600592953818186, 35.195669174194336, 29.74740947995867, 27.149147987365723, 30.80533524921962, 24.579601662499563, 31.114738532475062, 27.665109055382864, 41.45752123423985, 34.700432845524375, 45.148081234523225, 41.151984623500276, 51.734177930014475, 56.864804199763704, 61.115097182137625, 67.20497785295758, 68.35111795152936, 55.4730452810015, 31.364189284188406, 8.599852272442408, 0.9684246118579591, 0.18445458795343125, 0.06347532251051494, 0.018928373864452754, 0.005551521192371313, 0.033737931600106616, 0.048087267870349545, 0.029264563960688453, 0.037172099109739065, 0.040908357195023975, 0.031323653113629134, 0.019868216111457775, 0.024026041218478764, 0.008341596544986325, 0.023943270124228935, 0.044187089295259545, 0.0391050011052617, 0.04456345570672836, 0.05043578613549471, 0.01835440787752824, 0.03748080200914826, 0.028599708208015988, 0.031226934732070992, 0.034076269516455274, 0.04792631597125104, 0.024069606559351087, 0.017024716728233864, 0.055805959938360114, 0.013432847502242242, 0.05802698486617633, 0.11240231139319283, 0.05367000633850694, 0.042674207261630466, 0.023387427807652524, 0.02048000872933439, 0.0053522456354195514, 0.006104471253430737, 0.02735675927916808, 0.05908715512071337, 0.05031996699316161, 0.06822823639959097, 0.042932108244193454, 0.06639457693589584, 0.04376595314326031, 0.026753087029127137, 0.04005311130146895, 0.10204647601182971, 0.2772807026548045, 0.14946620113083295, 0.1347128820738622, 0.1918591827686344, 0.11901029252580234, 0.113974287041596, 0.08821914012410811, 0.1694303841463157, 0.09672959774200406, 0.08505336714110204, 0.12346610985696316, 0.18499633031232016, 0.12258591423077242, 0.11279646560017552, 0.1471556672560317, 0.17511281637208803, 0.12750263325870037, 0.16996623682124273, 0.11040659741099391, 0.11702507548034191, 0.16829746136707918, 0.15351477531450136, 0.14620833737509592, 0.16102398665887968, 0.10106963664293289, 0.07611957831042153, 0.17076647388083593, 0.18243452134941304, 0.13336822922740663, 0.11838705811117377, 0.10126409120857716, 0.12952255058501447, 0.11658824820603643, 0.09790910195027079, 0.24992195357169422, 0.17500771129769938, 0.09804354687886578, 0.13279223442077637, 0.17140003559844835, 0.887276329100132, 8.529933418546404, 32.78309481484549, 63.088059016636436, 82.25778457096645, 80.76697213309151, 76.55083302089146, 81.04782526833671, 53.048943860190256, 58.248711654118125, 69.71519524710519, 46.52305677958897, 39.60331106185913, 31.11590235573905, 29.04829216003418, 26.751983744757517, 31.73528562273298, 53.99816506249564, 64.67709118979317, 60.406512941632954, 63.76672431400844, 60.8465701511928, 64.06430871146065, 62.69115012032645, 63.82235854012625, 56.94810267857143, 44.62624372754778, 32.751199109213694, 19.226749420166016, 10.795636756079537, 4.8539012329919, 2.0884814986160825, 0.4391469955444336, 0.2674597496432917, 0.17091075756720134, 0.11732158171279089, 0.1996814158878156, 0.30395206862262314, 0.194799967110157, 0.3863245914024966, 0.23276448994874954, 0.36647817492485046, 0.18714407006544725, 0.2267979279692684, 0.3466786587876933, 0.23334295462284768, 0.3471726051398686, 0.1670541273696082, 0.13254709328923905, 0.14743869778301033, 0.3815744120095457, 0.3203084266611508, 0.10731745138764381, 0.1437181681394577, 0.18522427736648492, 0.21921938391668455, 0.15622089510517462, 0.36377985828689163, 0.21454803672220024, 0.4391553822372641, 0.33167182547705515, 1.3358605525323322, 1.229639315179416, 1.664917249764715, 4.137814675058637, 8.449240514210292, 19.41346662385123, 35.069184167044504, 35.73245573043823, 53.5166722706386, 58.23154265539986, 50.854199000767295, 41.71421548298427, 37.07430921282087, 32.93064676012312, 25.475846324648174, 31.53828682218279, 30.72999245779855, 43.98788145610264, 39.301373617989675, 52.3977586882455, 49.65652411324637, 62.95165198189871, 66.74233899797711, 68.07821355547223, 77.07225363595145, 79.07441180092948, 65.34377084459577, 36.979153633117676, 11.341039078576223, 1.5888300240039825, 0.3234297963125365, 0.2207952814974955, 0.14383452332445554, 0.12005230518324034, 0.15490403505308287, 0.11478942473019872, 0.21914068742522172, 0.16523285795535358, 0.12856247781642846, 0.15350216813385487, 0.06260116584599018, 0.11629107700926916, 0.13292602795575345, 0.1561202955033098, 0.1654100234487227, 0.1433544462280614, 0.1459829280419009, 0.16003746459526674, 0.093190908698099, 0.10513534383582217, 0.13267290725239686, 0.17111145465501718, 0.19204324217779295, 0.15365420069013322, 0.2416608982852527, 0.16061198019555636, 0.16682149842381477, 0.10604008207363741, 0.12195179611444473, 0.1746126003563404, 0.11455109609024865, 0.13362171633967332, 0.1277727580496243, 0.20111023421798432, 0.10334454064390489, 0.10217252746224403, 0.12255508159952504, 0.18299704045057297, 0.11171034138117518, 0.17489453165658883, 0.2021405217903001, 0.1728715609226908, 0.21415118873119354, 0.1268793445612703, 0.14970489617969307], [0.08561344351619482, 0.04601731876443539, 0.05460327358118125, 0.019071159684764485, 0.007701034042319017, 0.06365554819681815, 0.022872589362253035, 0.043157592216240506, 0.00978795754989343, 0.07490467493023191, 0.05633628933823534, 0.041340767206358056, 0.07442581241152116, 0.05401167246912207, 0.05153986778376358, 0.0753442095592618, 0.0756611871932234, 0.07681138547403471, 0.017835309928549186, 0.009878575901633926, 0.06676431745290756, 0.07288961591465132, 0.04995029093697667, 0.07034477032721043, 0.04430364464808788, 0.059076624257223945, 0.009538476338743098, 0.029876667008336102, 0.05563356115349701, 0.058582895036254606, 0.066047099152846, 0.06097818472023521, 0.03970114500927074, 0.034914205981684585, 0.044962495365845304, 0.1258211149168866, 0.06039537742201771, 0.055691409656511884, 0.1725878654313939, 0.2073827204959733, 11.61980949129377, 38.5359148979187, 57.969460078648154, 64.0760303224836, 61.42126955304827, 58.51697812761579, 50.82801818847656, 44.533815315791536, 33.98991353171212, 39.68677977153233, 36.72652060644967, 16.565789120537893, 11.990380372319903, 15.062575885227748, 22.267930780138286, 34.0388948576791, 47.61693252835955, 47.366557666233604, 59.51782444545201, 52.7035037449428, 48.86725739070347, 37.581989765167236, 30.342658179146902, 21.91697726930891, 14.48347566808973, 4.411216735839844, 1.7929917659078325, 1.4630850000040871, 0.7698288655706814, 0.4118099867233208, 0.04850956770990576, 0.05333503734852586, 0.114906159894807, 0.07233718662921872, 0.03334203016545091, 0.10555650373654706, 0.002229528455895239, 0.048215840078358135, 0.08547646765198026, 0.025838849301050817, 0.027372640391279544, 0.03327393239097936, 0.08083384963018553, 0.19499605015984603, 0.03844837598236544, 0.06402365344443492, 0.07597952189722232, 0.052116822717445235, 0.041468589633171044, 0.09463789819606713, 0.06304690228509051, 0.0295836823726339, 0.02355255269711571, 0.05442420479708484, 0.0913694900061403, 0.07636209351143666, 0.030579011820788895, 0.017849615143079842, 0.057904597504862716, 0.02223473591064768, 0.06120229126619441, 0.05241256220532315, 0.09301884578807013, 0.15934687879468712, 0.21755744809550898, 0.3088552712329796, 0.2246346226228135, 0.6236471267683166, 4.387013120310647, 9.601452469825745, 20.305389506476267, 30.803209100450786, 43.649146352495464, 44.84609167916434, 44.027013710566926, 38.62594965526036, 27.40356843812125, 24.11794250352042, 18.248241560799734, 21.60210054261344, 17.54763732637678, 23.7689779145377, 29.200436864580425, 33.11445440564837, 45.01073619297573, 50.52424989427839, 57.25503935132708, 57.78971365519932, 49.95515768868582, 30.471731390271867, 10.70565150465284, 1.2823482411248344, 0.2956990471908024, 0.116609445640019, 0.052286032387720685, 0.06435468353863273, 0.10027080415082829, 0.023376041990039603, 0.051637010249708376, 0.037378366970057995, 0.03690423044775214, 0.03618596720376185, 0.040073660734508715, 0.05772473144211939, 0.06017754053963082, 0.026995493664539287, 0.022689783546541418, 0.04271883450980697, 0.05207096392820988, 0.04364964206303869, 0.0593579380906054, 0.031428758188017776, 0.04170194121875933, 0.012275830792662288, 0.022646067231627445, 0.008807797600249094, 0.026005047972181013, 0.006672216346487403, 0.07116289356989519, 0.031173089585666145, 0.05861913559160062, 0.03764610331771629, 0.03260386888203876, 0.06238742731511593, 0.0806176412318434, 0.013810136721336415, 0.018611436942592263, 0.06719479363943849, 0.011327870722327913, 0.029550379873918634, 0.042950028354035955, 0.07484910969755479, 0.08538145917866911, 0.06946549750864506, 0.027615019885290946, 0.03709162485652736, 0.05850362179002591, 0.04219971450843981, 0.03435157831492169, 0.02053955356989588, 0.029967587308159897, 0.0324960123481495, 0.07953433293317046, 0.07490079370992524, 0.05839517153799534, 0.02599931774394853, 0.020685906788068156, 0.02938229317909905, 0.011988459337901856, 0.026919163563953977, 0.04598059305655105, 0.004019794544936823, 0.07987148341323648, 0.024439194405983602, 0.02053139588263418, 0.032986348894025595, 0.013455978761027967, 0.048023027567459006, 0.029203600981937985, 0.04118117576997195, 0.009952978962766272, 0.05467510669093047, 0.05472400870972446, 0.026036443787493875, 0.022433938525084938, 0.043245740700513124, 0.014830614373620068, 0.04859949056325214, 0.07090839544045073, 0.023996813322550485, 0.03751224192923733, 0.10422280923064266, 0.03458110635567989, 0.09480660914310388, 0.10485591632979256, 0.4300279734390122, 16.35802582332066, 46.7293244770595, 67.41646712166923, 74.97113227844238, 67.95586272648403, 66.22781099591936, 58.77140031542097, 53.529279776981895, 43.65697002410889, 47.55913046428135, 49.882726192474365, 25.37905444417681, 21.18620048250471, 14.861368213381086, 25.73087821687971, 33.68304286684309, 43.721616063799175, 56.41904946735927, 63.99085235595703, 54.6754789352417, 49.55708496911185, 37.024292605263845, 27.735473462513514, 20.39806284223284, 12.508233955928258, 6.541412830352783, 2.421425930091313, 2.0110750922134946, 0.6201665678194591, 0.3106545832540308, 0.16960110355700764, 0.043043245494897873, 0.10683814103582076, 0.06485985286001648, 0.043993560929915736, 0.11648801501308169, 0.05062723818368145, 0.07816474392477955, 0.1964341237076691, 0.20886048834238732, 0.4730936682650021, 0.7559090725013188, 0.3246869317122868, 0.7353051666702543, 0.12632149378103869, 0.09526402316987514, 0.22163707204163074, 0.11345414245235068, 0.07569822163454124, 0.047521267884543965, 0.0633156428645764, 0.0670277586738978, 0.1875490876180785, 0.10687328914978675, 0.04838627789701734, 0.14626761419432505, 0.19169562868773937, 0.26010966833148685, 0.1420142310006278, 0.1963846313634089, 0.32223457044788767, 0.08307851132537637, 0.1260891498199531, 0.23841744661331177, 0.19194334825234755, 0.1957398331058877, 0.37621786658252987, 0.5272987367851394, 2.862172314098903, 6.505042050565992, 16.80939643723624, 27.689740419387817, 36.385878222329275, 39.09804153442383, 37.799079281943186, 34.49801097597395, 27.652520656585693, 29.17522532599313, 29.736514704568044, 31.468370573861257, 31.478424617222377, 34.038825375693186, 39.83098268508911, 39.84446913855416, 53.406578063964844, 57.1545649256025, 63.68773719242641, 65.81502546582902, 59.147082465035574, 37.521773202078684, 15.006715842655726, 1.7337413281202316, 0.24089559220841952, 0.06114447329725538, 0.0874169488836612, 0.048223510916743956, 0.030806181952357292, 0.06186554567622287, 0.043627297904874594, 0.04651302930765918, 0.035749513123716624, 0.061767565219530036, 0.045005660371056626, 0.026558586662369113, 0.02793601105388786, 0.042251958312200646, 0.025705035410023162, 0.051108651994062324, 0.040395082772842476, 0.04057321517861315, 0.05216614882062588, 0.03437159170529672, 0.020741248104189123, 0.005181805696338415, 0.04410147513928158, 0.004270836810714432, 0.005166281663280512, 0.07859367983681814, 0.048119739163666964, 0.0178997385249074, 0.032898403970258575, 0.04339658582050886, 0.014703606188829457, 0.01879582035222224, 0.04592260545385735, 0.0059510417631827295, 0.011136856329228197, 0.031197211505579095, 0.023765175037884285, 0.04479651212958353, 0.03492537806076663, 0.021910021281135932, 0.03411096301195877, 0.03547348168545535, 0.011871077020519545, 0.022814058931544423, 0.16436315248055117, 0.14107600705964224, 0.12550862239939825, 0.14629974961280823, 0.07659737552915301, 0.12555666267871857, 0.19985140248068742, 0.13775069692305156, 0.2022681813687086, 0.1957399688128914, 0.14516888958002838, 0.09161501111728804, 0.15982212472174848, 0.13729770694460186, 0.1170568580606154, 0.1278075940374817, 0.21929038582103594, 0.16442405778382504, 0.09086653949426753, 0.11864315079791204, 0.12568610001887592, 0.12994457222521305, 0.09209342580288649, 0.18167043663561344, 0.11424487323633262, 0.1790908636259181, 0.13740122424704687, 0.17727287832115377, 0.1384331403034074, 0.1358500389116151, 0.17495437844523362, 0.14121062840734208, 0.12743837599243435, 0.15053322458905832, 0.1372194718569517, 0.22491658106446266, 0.10147287643381528, 0.2630265275282519, 0.24430590921214648, 1.58555449119636, 21.152946404048375, 56.72234180995396, 78.26947689056396, 83.37447125571114, 77.46224212646484, 74.77587400163922, 68.07979079655239, 57.588980197906494, 49.50121797834124, 54.51164736066546, 51.24826260975429, 25.83305321420942, 19.73857457297189, 24.066478933606827, 30.681872708456858, 46.10208279745919, 60.54097448076521, 58.373754910060335, 69.18813964298793, 63.83244732448033, 61.24410438537598, 46.756314754486084, 37.655366216387065, 29.088079282215663, 18.53115483692714, 7.206531311784472, 3.3074120112827847, 2.4371926954814365, 1.5455588144915444, 0.9252650077853883, 0.5066920625311988, 0.23396905245525496, 0.2772600751902376, 0.2165821354304041, 0.15324690325983933, 0.2999084341738905, 0.1313250381499529, 0.10822983671511922, 0.16926735932273523, 0.19463025193129266, 0.27875502354332377, 0.6487185071621622, 0.3890583004270281, 0.8693032935261726, 0.1342591999896935, 0.22047251595982484, 0.5153513093079839, 0.28981511720589226, 0.1248676103672811, 0.2644821208502565, 0.2452813440135547, 0.08854768678013768, 0.1874858752957412, 0.18217576880540165, 0.4005875603428909, 0.21231701358088426, 0.21422400910939488, 0.2329387106001377, 0.16897089380238736, 0.1838507324989353, 0.5550595042960984, 0.1320442445576191, 0.24729520880750247, 0.38778867998293465, 0.44359823954956873, 0.5960601185049329, 0.5468079213585172, 0.9949285153831754, 5.962664800030844, 12.803646172795977, 26.94152365412031, 40.546403953007285, 55.46814332689558, 59.43347331455776, 56.97560364859444, 51.087821756090435, 37.36205843516758, 35.06955936976841, 28.735574586050852, 33.60969073431832, 29.90264960697719, 35.734422070639475, 43.14422423498971, 46.824841363089426, 63.025983810424805, 66.32663522447858, 71.75257383074079, 73.71665586744035, 68.0376638684954, 46.893413134983604, 19.74092480114528, 2.0066440956933156, 0.45999495685100555, 0.177910144839968, 0.14483103342354298, 0.11155969303633485, 0.23619079323751585, 0.1521755371774946, 0.18751080467232636, 0.1411950085312128, 0.16782445460557938, 0.1288027334958315, 0.18034924753010273, 0.19938362043883118, 0.18213322465973242, 0.1023525699440922, 0.0931578233305897, 0.1862069589218923, 0.19027143796639784, 0.10802481057388441, 0.1356180477887392, 0.09795916426394667, 0.1373079392526831, 0.06582086879227843, 0.1345007313149316, 0.09828329365700483, 0.1216671099620206, 0.14120267597692354, 0.1405601847384657, 0.1933424738901002, 0.14998263413352625, 0.22362623816089972, 0.17197495831974915, 0.16788008090640816, 0.22217183906052793, 0.13008458114096097, 0.17605235667100974, 0.12468219388808523, 0.12023761309683323, 0.12474455125629902, 0.19257191595222267, 0.1550456453114748, 0.18563050271144935, 0.3513086017753397, 0.1374917679599353, 0.09667032770812511], [0.03648811884756599, 0.06445862831813948, 0.027153845078178813, 0.02486287845697786, 0.01873359190566199, 0.03568508283102086, 0.017711046417909007, 0.0287947395284261, 0.02723355937216963, 0.0401044458683048, 0.05383502944771733, 0.04707830326099481, 0.05204314059977021, 0.0486808401266379, 0.02515262139162847, 0.018000863991411667, 0.05495025942634259, 0.02355113795160183, 0.027916896722412536, 0.01661493077075907, 0.03158164909109473, 0.03774043664868389, 0.0143645880411246, 0.06595140535916601, 0.047569776353027136, 0.07246473764202424, 0.04826147495103734, 0.05595833854749799, 0.029956381302326918, 0.01770140104261892, 0.057372999244502614, 0.016458401223644614, 0.04426015055339251, 0.03907606837206653, 0.052363480374749215, 0.06184988508799246, 0.09280391982091324, 0.020954384435234324, 2.4552150198391507, 16.846767323357717, 51.93141644341605, 62.78028161185128, 65.15440464019775, 56.788759640284944, 53.629583971840994, 45.37109061649868, 41.40471492494856, 31.79950782230922, 37.56651612690517, 35.668101515088765, 18.92229846545628, 24.00413622174944, 30.739164079938615, 67.77443831307548, 55.400231633867534, 53.97012560708182, 54.73036970411028, 30.23807041985648, 16.323126758847916, 12.715576887130737, 7.058976326669965, 3.8437751616750444, 2.2483052653925757, 0.8611134844166892, 0.4246181223009314, 0.20117905123957566, 0.2493709017123495, 0.0493993476432349, 0.10604964941740036, 0.030315424714769636, 0.06924193379070077, 0.13944661377796105, 0.044669313954987695, 0.13230533126209462, 0.08260179976267473, 0.12966397085360118, 0.038797248154878616, 0.19076180165367468, 0.3048684165946075, 0.21019588597118855, 0.542918721480029, 2.0001001954078674, 0.6855442853910583, 0.5444942797933305, 0.16109650848167284, 0.1108619486913085, 0.0967092891888959, 0.23395464037145886, 0.052408233151904175, 0.07634383413408484, 0.01039301316320364, 0.03856830704691155, 0.053428841422178915, 0.08850114606320858, 0.07091676177723066, 0.05074082833847829, 0.11318175813981465, 0.08512468795691218, 0.08325607715440647, 0.24985141307115555, 0.3350080464567457, 0.07985987367906741, 0.10118009535861866, 0.04956885586891856, 0.07219816837459803, 0.026348050816782882, 0.06500923234437193, 0.3066257951515061, 0.3537907642977578, 0.9429987647703716, 1.2972382307052612, 5.7772152083260675, 13.595394270760671, 22.245392560958862, 41.16036415100098, 55.047148500170024, 63.2301218850272, 34.79148203986031, 35.02435091563633, 23.22557667323521, 18.950695753097534, 15.905420167105538, 14.907684905188423, 23.568786416734966, 27.506205490657262, 31.080501283918107, 49.59896176201956, 52.960145882197786, 60.04281643458775, 51.73190239497593, 37.731581006731304, 14.946122339793614, 1.7692448858703886, 0.32052029243537355, 0.04027654270508459, 0.21242061230753148, 0.0735138545611075, 0.09331338426896504, 0.062079067075891156, 0.03852055514497416, 0.041978824218469005, 0.032906841553215466, 0.08696591308606522, 0.017567276721820235, 0.031823353442762575, 0.0349812181001263, 0.0829963203785675, 0.024454339307599833, 0.04328462075708168, 0.06476628288094487, 0.012135430871109878, 0.05052045373512166, 0.011224005670685853, 0.040046817889170985, 0.04489755956456065, 0.033662125667823214, 0.004051330308097282, 0.03655286126637033, 0.07106823793479375, 0.10050287669790642, 0.08159371385616915, 0.016985190367060046, 0.057649441196450164, 0.021219291291864853, 0.0037273094806421015, 0.06796416414103337, 0.02564618776419333, 0.06093721477580922, 0.0677858315674322, 0.01901556900702417, 0.08116540219634771, 0.019126139680988023, 0.03877856469314013, 0.10389148058103663, 0.026723569059478383, 0.04287511469530208, 0.04815877189061471, 0.018781605043581555, 0.059252215549349785, 0.07930925608213459, 0.01154924277216196, 0.0455025820992887, 0.0789683193766645, 0.06567562837153673, 0.058909005751567226, 0.025735776439043026, 0.05121869341071163, 0.05393590385626469, 0.05852663769785847, 0.05097628338262439, 0.013373201729596725, 0.03935468502874885, 0.03696416883862444, 0.0675660405041916, 0.049437223467975855, 0.07050498601581369, 0.027055338756846528, 0.04609665986416595, 0.08428460732102394, 0.021352699758218865, 0.02180268891554858, 0.05799917850111212, 0.03267495560326746, 0.0575716607272625, 0.03415747319481202, 0.05406469998082944, 0.05586838176740067, 0.02641406548874719, 0.05417655987132873, 0.03017488993438227, 0.0398783817488168, 0.07322271554065601, 0.07890383819384233, 0.13021572838936532, 3.543745215450014, 22.145633799689158, 61.42909322466169, 70.48509039197648, 73.48487091064453, 63.314743995666504, 62.34045369284493, 52.67087153026036, 52.594062668936594, 38.70329352787563, 44.686873708452495, 45.15847226551601, 35.1757104737418, 29.07124032293047, 27.782064608165197, 62.94430078778948, 39.23908649172102, 40.78583887645176, 55.90649127960205, 31.433025087629044, 21.69865444728306, 17.412399326051982, 8.85473825250353, 5.542593215193067, 2.6938446036406924, 1.101447765316282, 0.5563149569290025, 0.2406671701797417, 0.07745119649916887, 0.04556732791076813, 0.12364098190196923, 0.11503224527197224, 0.09834449073033673, 0.18101323475795134, 0.0850869274831244, 0.23702281287738255, 0.35379763107214657, 0.2483029147343976, 0.3575094890381609, 1.4563387334346771, 1.321240131344114, 1.2565849721431732, 1.7709704275642122, 1.295836865901947, 2.341166202511106, 1.6051012937511717, 0.32458116167357987, 0.20699040511889116, 0.06292244539197002, 0.41424161195755005, 0.4234387198729174, 0.18115118092724256, 0.0862790931548391, 0.5584539164389882, 0.480753025838307, 0.3165512696972915, 0.11833677866629191, 0.2624702373785632, 0.7224583817379815, 0.6869504270809037, 0.7412078785044807, 0.9712110566241401, 1.2282586864062717, 0.6674160552876336, 0.5101095448647226, 0.2349125418279852, 0.205134476135884, 0.06195812499416726, 0.1627725035484348, 0.33531656275902477, 0.3152712269553116, 0.5950348249503544, 1.1904510408639908, 3.8287027818816046, 10.248157790728978, 20.97629714012146, 36.19072764260428, 44.38898011616298, 56.62211751937866, 33.926514693668906, 27.357790231704712, 22.299873386110576, 21.045007875987462, 24.38210780279977, 21.5005613054548, 31.621296950748988, 36.85927983692714, 39.983186449323384, 55.4275415284293, 59.750262532915386, 67.30586569649833, 61.83216517312186, 45.80613470077515, 22.816584859575542, 3.442922294139862, 0.2950056386845452, 0.0483761575472142, 0.1471734041614192, 0.0322441944320287, 0.03397245705127716, 0.010692081713516797, 0.029758852973048176, 0.07037444944892611, 0.011717203089834323, 0.04953060006456716, 0.03450662356668285, 0.02555709102723215, 0.026940471259877086, 0.14600295839565142, 0.0508502149688346, 0.04188945437116282, 0.027210012510684983, 0.016887204821354578, 0.031074868249041692, 0.010267568153462239, 0.041319593521101136, 0.0294602331040161, 0.04601007540311132, 0.005444199004809239, 0.00448834036277341, 0.07142370886036328, 0.0797094696068338, 0.10116818706904139, 0.03367772179522684, 0.04206926954377975, 0.03687602374702692, 0.03171772250373449, 0.02383836861034589, 0.037940604479185173, 0.02270457391361041, 0.032965100569916625, 0.03072843880259565, 0.03742851070793612, 0.014990838543911065, 0.07889946164297205, 0.01717810465821198, 0.03250393085181713, 0.09543937697474446, 0.1310817969164678, 0.20022580453327724, 0.08023857085832528, 0.10921266076288053, 0.06069640948304108, 0.16405490759227956, 0.18495548250419752, 0.1321306899189949, 0.15531715431383677, 0.16146232028092655, 0.1587171982973814, 0.1553871248449598, 0.14614482649735042, 0.2924815969807761, 0.09719244004892451, 0.09755732904055289, 0.13483685042176927, 0.21565183677843638, 0.2677790953644684, 0.09402144913162504, 0.1282895031784262, 0.16779875169907296, 0.1276131530425378, 0.13777853042951652, 0.12593998068145343, 0.15798948306058133, 0.13529958416308674, 0.16803043069584028, 0.11515268523778234, 0.20766508605863365, 0.2629430948623589, 0.1505713989692075, 0.11230272280850581, 0.14267000795475074, 0.15805720085544245, 0.12037914193102292, 0.20401953453464167, 0.2557863417480673, 5.457402220794132, 30.224333831242152, 73.8227618081229, 80.81353896004813, 81.12986959729875, 73.77773053305489, 69.07120146070207, 62.65788909367153, 55.45057480675833, 44.22854273659842, 50.84877940586635, 49.30800942012242, 29.96273762839181, 32.179543018341064, 40.930899892534526, 81.29007421221051, 67.46035889216832, 67.20386614118303, 62.622349057878765, 39.70251744134085, 23.405585391180857, 19.11224137033735, 9.683457715170723, 6.509772905281611, 3.4297886788845062, 1.2794089359896523, 0.8725488079445702, 0.6175172956926482, 0.3589259987430913, 0.25090257238064495, 0.19988376860107693, 0.17875030690005847, 0.16237914322742394, 0.35472578555345535, 0.10790067259222269, 0.290389890649489, 0.26562968641519547, 0.2109148752476488, 0.25375217518636156, 0.786334365606308, 1.0970339221613747, 1.470139810017177, 1.8929895886353083, 3.8539590494973317, 3.015075675078801, 2.9551518048558916, 1.1491020939179828, 0.21399479998009546, 0.14591101690062455, 0.9127020133393151, 0.46547046303749084, 0.24286356089370592, 0.0804628673940897, 0.38317920161145075, 0.2805467631135668, 0.1951039915106126, 0.19780021826071398, 0.1609632849161114, 0.33034846505948473, 0.43459671256797655, 0.6469863429665565, 0.8822402964745248, 1.1462400874921252, 0.49749927009855, 0.34765222083245007, 0.3217528648674488, 0.1986451164952346, 0.16018866933882236, 0.3015546144119331, 0.7097175568342209, 0.6381397662418229, 1.2940569328410285, 1.9878544296537126, 7.746590035302298, 17.660245043890818, 29.785648890904017, 52.66800887244088, 68.2053586414882, 79.45848737444196, 47.501891204289024, 47.44232429776873, 34.58813953399658, 29.68223885127476, 25.94491400037493, 25.470623016357422, 37.036076750074116, 40.629414081573486, 45.733133452279226, 65.14763709477016, 68.53420298440116, 75.48126901899064, 69.92650386265346, 53.69993795667376, 27.432186331067765, 5.31185656785965, 0.6667707956262997, 0.17496813913541182, 0.3451600159917559, 0.14102004149130412, 0.16939562958266052, 0.11139645108154841, 0.05961981189570256, 0.1637691900666271, 0.15962229615875653, 0.16778921149671078, 0.16271138111395494, 0.11830343545547553, 0.18339464840080055, 0.3007650167814323, 0.1055201410448977, 0.1429669755910124, 0.13778878987899848, 0.10003284191978828, 0.2386911404984338, 0.09716354124248028, 0.1525624921279294, 0.11875334488494055, 0.1324959046074322, 0.13036557606288365, 0.23003759341580526, 0.17727701738476753, 0.2877153498785836, 0.17526666740221636, 0.09467645934117691, 0.21752615406044892, 0.1264900147382702, 0.1331507044711283, 0.1512880812266043, 0.11063358773078237, 0.3650869610054152, 0.14456829109362193, 0.08060163459075348, 0.14082838248993668, 0.10672247117119175, 0.15449590981006622, 0.17321693524718285, 0.06788855498390538, 0.15066353045403957], [0.06446486405496087, 0.006727541547401675, 0.06560634316078254, 0.0730035894417337, 0.020974223102842058, 0.03624662823442902, 0.015251353582633393, 0.020450911451397196, 0.014790076995268464, 0.057564210412757735, 0.09443948098591395, 0.05214352307042905, 0.04623062303289771, 0.05240310342716319, 0.06109890288540295, 0.04716199716287, 0.036534584925643036, 0.07959642567272697, 0.07648128497281245, 0.05113821915749993, 0.018480150594509075, 0.11501798246588026, 0.03555099413331066, 0.018407501546399932, 0.02576349120187972, 0.03844431495027883, 0.012035718453781945, 0.02363964605943433, 0.03584210940503648, 0.03807505280045526, 0.031970283415700705, 0.07799165642687253, 0.0430786752008966, 0.043720094354024956, 0.07051050929086548, 0.14821163059345313, 0.10797162699912276, 3.8712422592299323, 30.318051133837017, 53.185621874673025, 61.61029529571533, 61.52341502053397, 54.130976404462544, 49.91476086207798, 38.894122328077046, 40.875192710331504, 27.89493635722569, 45.14140054157802, 53.77320671081543, 23.214742694582256, 16.43133279255458, 30.36040735244751, 40.43024744306292, 31.91952405657087, 49.99756601878575, 61.70903614589146, 31.242050375257218, 21.338275705065044, 12.864092894962855, 4.942817764622824, 2.665894172021321, 1.1277881690434046, 0.2736011972384793, 0.08705436691109623, 0.017125214549845884, 0.026921669054510336, 0.09315823723695107, 0.08470386732369661, 0.01086316753311881, 0.10401578819645302, 0.05998528442744698, 0.05850098228880337, 0.3139852945293699, 0.14054931460746697, 0.30204345818076817, 0.12080513978643076, 0.24582341206925257, 0.6096552461385727, 0.4385736605950764, 1.2917842205081667, 1.8439895893846239, 1.2146587818861008, 0.42274341146860805, 0.8975294274943215, 0.12474913815302507, 0.04046092441837702, 0.018996183261541382, 0.20741938852838107, 0.02497458058808531, 0.20847898881350244, 0.13408184450651917, 0.2981376206236226, 1.1698830702475138, 0.08983786683529615, 0.1877584835248334, 0.41127063280769754, 0.38248834439686363, 1.0251987768071038, 1.2127587752682822, 0.6043368886624063, 0.35648943377392633, 0.47714653078998837, 0.44927261077931946, 0.1904884334653616, 0.058834326187414784, 0.16337464909468377, 0.07028194476983377, 0.03229378177119153, 0.10013283762548651, 0.022613212566024492, 0.06792753003537655, 0.19594931043684483, 0.4876739744629179, 2.7866673256669725, 8.215869631086077, 19.716192688260758, 24.38897262300764, 51.24713005338396, 67.09071472712925, 66.1537640435355, 68.38742228916713, 60.95769269125802, 39.04586403710501, 29.276446683066233, 15.633181061063494, 19.774503707885742, 29.026684999465942, 39.73201949255807, 48.17778417042324, 53.60342400414603, 59.06617764064244, 51.92700433731079, 17.855312245232717, 4.006914521966662, 0.48511492035218645, 0.22595801018178463, 0.09833117108792067, 0.07134168754730906, 0.008918247834247137, 0.05882662481495312, 0.06442575329648596, 0.07798616029322147, 0.02320194517129234, 0.0165010810763176, 0.1071566046614732, 0.039263659555997164, 0.09872519637324981, 0.07392092128949505, 0.02653030532279185, 0.0476442455713238, 0.023485674589340175, 0.06136988941580057, 0.04362400701003415, 0.033242964052728245, 0.029488439804741313, 0.08333924519164221, 0.01959649845957756, 0.022789658812273825, 0.043047272600233555, 0.05211125533761723, 0.05593495283808027, 0.010854388986315047, 0.06626032199710608, 0.008744069591297634, 0.04120396776124835, 0.012027822850671197, 0.06738645264080592, 0.023847774802041904, 0.04484976016517196, 0.06610117839383227, 0.03382459409268839, 0.05695547629147768, 0.043890759481915405, 0.04516328405588865, 0.05129178859559553, 0.005942798834959311, 0.03407892598105328, 0.013987739021623773, 0.07880489421742302, 0.021713424241170287, 0.022090158757886717, 0.02136843159262623, 0.024452308791556528, 0.03679557324254087, 0.036761968795742304, 0.06614089983382396, 0.021626191779172847, 0.04622787496607218, 0.05462312073047672, 0.011229588317551782, 0.059505987646324296, 0.030195313838443587, 0.04015942756086588, 0.08014759288302489, 0.07021814890738044, 0.015033808470304524, 0.09263906973813262, 0.059226865481053076, 0.03432238095306924, 0.0808935132143753, 0.05828747445983546, 0.04656695248559117, 0.0406624527115907, 0.06175512767263821, 0.013084399414115717, 0.032107337311442406, 0.04744445772043296, 0.045282227851982625, 0.009594711624751133, 0.02340747512477849, 0.07602015257413898, 0.20045251665370806, 0.08073786406644753, 4.750958459717887, 38.43926545551845, 61.74950245448521, 71.65577152797154, 69.09287289210728, 63.77307496752058, 57.62295341491699, 52.78163276399885, 52.53156362261091, 40.43575736454555, 47.18745742525373, 59.811934743608745, 36.27235855375017, 14.86261020387922, 24.708384786333355, 29.165174756731304, 32.845277718135286, 43.91554376057216, 55.75529153006417, 32.3228565624782, 18.703147070748464, 7.837042553084237, 3.9230024303708757, 1.9837678032261985, 0.7278311305812427, 0.1840081661939621, 0.016160770319402218, 0.10253534013671534, 0.157370550557971, 0.1251891138298171, 0.21054526365229062, 0.1746040643858058, 1.0816665696246284, 0.6005709650261062, 0.5886460649115699, 1.062624379992485, 0.7516393501843724, 1.0235825606754847, 1.4100698104926517, 1.1686576902866364, 2.766884067228862, 2.0223635264805386, 2.3061965703964233, 3.515164234808513, 1.6073997361319405, 1.5252188316413333, 0.9050977528095245, 0.37554926531655447, 0.23021257402641432, 0.6180069808449064, 1.1675662802798408, 0.10439933011574404, 1.1395677540983473, 2.1019536214215413, 4.05256027834756, 2.89316149694579, 2.2737400148596083, 2.2349477878638675, 3.2198110776288167, 2.9455090079988753, 2.399561469044004, 2.468812644481659, 1.9003088644572665, 1.121300180043493, 1.6661213508674075, 1.3590583077498843, 0.8743557738406318, 0.6824084765144757, 0.6250291668942997, 0.37628998128431185, 0.3253035843372345, 0.162204203328916, 0.02051977427410228, 0.24714783100145205, 0.17965433267610414, 0.3593145007533686, 2.142288565635681, 6.461586279528482, 18.471871069499425, 23.935573135103496, 42.10084799357823, 59.90780598776681, 58.99709865025112, 61.70514515468052, 57.051495347704204, 45.87593630381993, 33.258626052311485, 26.4662720816476, 27.084079844611033, 37.12513875961304, 47.4440335546221, 53.887278761182515, 59.660832268851145, 66.99243245806012, 59.855222020830425, 24.224850961140223, 6.89182003906795, 1.154506272503308, 0.09764767597828593, 0.10897761623242072, 0.06162995831774814, 0.08549127328608717, 0.0420369610988668, 0.07250808245901551, 0.06483235183571066, 0.01990038376035435, 0.026112702641902224, 0.07983636922602143, 0.034893680297370465, 0.02218615110697491, 0.04165669311104076, 0.05414060769336564, 0.030559185027543987, 0.041930600734693665, 0.013786430404122387, 0.03781173710844346, 0.025871793872543743, 0.04805753107315727, 0.0661024676103677, 0.0142034359741956, 0.010405324332948242, 0.052499224697904925, 0.01990873652643391, 0.05356801913252898, 0.0340098375454545, 0.09834529818700892, 0.029203431348183324, 0.024300401764256612, 0.041017441877296994, 0.0922840873577765, 0.025387830466830304, 0.01857525745539793, 0.07446712162345648, 0.016556342664573873, 0.03130596709836807, 0.013016643451659806, 0.033163005486130714, 0.009681197698228061, 0.0353506091716034, 0.18416401211704525, 0.06609558047992842, 0.2046409233340195, 0.10363603250256606, 0.11397252285054751, 0.07221061949219022, 0.11788886412978172, 0.12764697122786725, 0.1299071849456855, 0.1569126344152859, 0.1609348271574293, 0.1681413711713893, 0.22518214610006126, 0.15154892365847314, 0.1655881931739194, 0.18916252175612108, 0.10258926331464734, 0.1534998882561922, 0.18912324814924172, 0.15260248498192855, 0.14122575973825796, 0.1924732569605112, 0.16528764287275927, 0.14274240764124052, 0.14381187382553304, 0.12237237926040377, 0.1552173960953951, 0.21364283029522213, 0.17120235120611532, 0.1249159084899085, 0.1581154598721436, 0.1331796372043235, 0.0855713811303888, 0.16422665837619985, 0.11919581757060119, 0.27242548604096684, 0.3368273616901466, 7.752093877111163, 51.53769677025931, 76.68027796064104, 81.15006801060268, 78.54482705252511, 71.33559158870152, 68.20576858520508, 55.55132021222796, 55.41805723735264, 41.218982628413606, 54.92906733921596, 62.82664694104876, 34.6547588620867, 23.875406946454728, 41.96389205115182, 56.24211359024048, 42.077599321092876, 63.50069863455636, 66.87650871276855, 35.39542988368443, 26.364491394587926, 16.82866726602827, 6.415410723005023, 3.9377460735184804, 1.6400954616921288, 0.474954754114151, 0.2719371036759445, 0.22177965939044952, 0.3251104732709271, 0.2823431710047381, 0.48504288707460674, 0.14738847262093, 0.8727732130459377, 0.462834001651832, 0.24290158599615097, 0.8486145436763763, 0.4362835506243365, 0.5814430085676057, 1.218210614153317, 0.9430259061711175, 1.7985175379684992, 1.1396041235753467, 2.9238714490618025, 4.68680921622685, 3.954107344150543, 2.6338716617652347, 2.5438703426292966, 0.5506616202848298, 0.791344342487199, 0.7687693195683616, 1.2656390177352088, 0.16761908919683524, 0.8355805373617581, 1.644269374864442, 3.862837544509343, 3.827389572347913, 1.3594482753958022, 1.866405997957502, 2.2954216514314925, 2.5671819831643785, 2.7417643751416887, 3.4461568977151598, 1.6548069694212504, 1.4058095876659666, 1.1197877526283264, 0.9741936794349125, 0.8288841024041176, 0.6791686617902347, 0.43943341874650543, 0.35125298904521124, 0.21154408077044146, 0.17444317016218389, 0.17935577726789884, 0.39962854608893394, 0.540867591542857, 0.8004485996706145, 4.087237434727805, 10.870910934039525, 27.008016177586146, 34.34495953151158, 61.064298902239116, 76.3910105569022, 74.91520622798375, 77.51688276018415, 70.64100102015904, 51.52293184825352, 43.116490500313894, 27.27738220351083, 31.646623134613037, 44.55435071672712, 56.23942811148507, 63.32376275743757, 69.28115517752511, 75.67182336534772, 71.06764125823975, 32.050779002053396, 9.63738421031407, 2.0628016080175127, 0.22946949675679207, 0.17534995079040527, 0.1164641170097249, 0.14113814729665006, 0.24458389143858636, 0.3019152693450451, 0.13604021870664187, 0.13757197079913958, 0.14209307676979474, 0.2774373899613108, 0.12366778403520584, 0.1547733899205923, 0.26044114625879694, 0.09105998304273401, 0.1100896740598338, 0.18471921661070415, 0.12386154649513108, 0.1980975115937846, 0.1362475382962397, 0.1358034506972347, 0.11948780475982598, 0.11951904451208455, 0.13987521720784052, 0.15597379979278359, 0.09854364754366023, 0.09618265780487231, 0.14359786388065132, 0.14695879710572107, 0.10032504624021904, 0.206853626029832, 0.11626181857926504, 0.16230276732572488, 0.1427631979542119, 0.08091652233685766, 0.1978596579283476, 0.1351070294954947, 0.12066355666943959, 0.11469181068241596, 0.18164142247821602, 0.14199462133858884, 0.1304311632577862], [0.03349193212177072, 0.03460619518799441, 0.024356969532423785, 0.03311332993741546, 0.04894015585471477, 0.03325290459075144, 0.06764688795166356, 0.03360633312591484, 0.03443462760852916, 0.038538688993347545, 0.041800841090402434, 0.008196492679417133, 0.09023060968944005, 0.05982308741658926, 0.041944480168500116, 0.06577536623392786, 0.05298112705349922, 0.0765894977375865, 0.06315567823393003, 0.02892430918291211, 0.1092241687167968, 0.06571828108280897, 0.07459005181278501, 0.05410497781953641, 0.023065254291785613, 0.03879657979788525, 0.01454888324120215, 0.024689139565452933, 0.05060699748407517, 0.04916880179994872, 0.007030519307591021, 0.04180699201034648, 0.004224593376940382, 0.13916124909051827, 0.10079255008271762, 0.6913390287331173, 5.986121918473925, 29.569962910243444, 55.95582696369716, 59.28490693228585, 64.18281023842948, 53.71381350925991, 40.63617467880249, 41.62187392371041, 23.35899077142988, 23.31710181917463, 18.921019996915543, 38.11262716565813, 49.72312607084002, 26.604794842856272, 49.8664048739842, 68.9155409676688, 63.74449702671596, 44.417707443237305, 22.208695650100708, 11.724306055477687, 6.677384734153748, 2.5194083409649983, 1.0107096114328928, 0.23310055477278574, 0.03449604859841721, 0.019117111772564904, 0.15582085799958023, 0.1373599964593138, 0.17474891804158688, 0.03932486341467925, 0.10758210040096726, 0.19968783482909203, 0.1671797377722604, 0.2713770680129528, 0.4630174775208746, 0.9425707991634096, 1.1055925829069955, 0.7167554848960468, 2.190557266984667, 0.5188622123428753, 1.2454637289047241, 4.797229988234384, 3.0678476776395525, 1.2250628407512392, 2.2207220026424954, 0.4209227120237691, 2.135120847395488, 1.4025095190320696, 0.2701156442718846, 0.3431274507726942, 0.5085539083395685, 0.03969616795490895, 0.728079582963671, 1.5972675255366733, 1.8241123131343295, 2.5959049676145827, 2.6553352986063277, 1.1042496263980865, 0.46465795806476046, 3.7018217274120877, 3.6774921757834296, 1.943331458738872, 1.407858437725476, 1.2640490744795119, 1.5923123742852892, 1.9050514442580087, 2.7168485692569186, 0.8231149805443627, 0.6946927830576897, 0.31437002388494356, 0.2653281183115074, 0.7445077300071716, 0.11760744851614748, 0.10261560404407126, 0.2716145009866783, 0.05431319646803396, 0.16793645359575748, 0.08614066522568464, 1.4207525572606494, 2.8875929500375475, 13.457410863467626, 19.587058680398123, 31.279845101492747, 38.004436765398296, 61.57020418984549, 79.27013560703823, 37.50340216500418, 19.04628733226231, 13.722198026520864, 19.943636757986887, 24.25993241582598, 33.9767883845738, 37.281188351767405, 40.46411643709455, 49.29154566356114, 52.86495556150164, 44.829162393297466, 34.39098787307739, 13.282170346805028, 3.555710881948471, 0.9533507121460778, 0.04489203289683376, 0.1418844951050622, 0.023519167077860663, 0.08769017457962036, 0.08591188357344695, 0.02498402918821999, 0.007699721077057932, 0.06709198879876307, 0.07222874316253833, 0.013988513399713805, 0.040201513695397546, 0.03943318135238119, 0.021322718688419888, 0.023861023198281015, 0.009039737832998591, 0.03330159965636475, 0.017589391874415532, 0.018007371142240505, 0.010115392256661184, 0.00503499065026907, 0.0701362904427307, 0.01500722686094897, 0.06591169070452452, 0.027796565322205424, 0.02822908220280494, 0.0094409810345886, 0.0702380978369287, 0.011265570181421936, 0.06760368562702622, 0.02049899922816881, 0.04556203194494758, 0.08782043294715029, 0.019000744713204246, 0.06287311589611427, 0.11395143398216792, 0.02787111766104187, 0.08627549691924027, 0.037848975110266886, 0.05632820459348815, 0.062918333469757, 0.03139320634571569, 0.01988619559311441, 0.03655831668792026, 0.03829620771908334, 0.09127871559134551, 0.029276061736579453, 0.04500347548829658, 0.03169250135709133, 0.0481847835305546, 0.013154600647145083, 0.05722099382962499, 0.07296485187751905, 0.022888743584709506, 0.03669502113812736, 0.059138248807617595, 0.021260614074500542, 0.043025610369763205, 0.061409325871084414, 0.010553439197662686, 0.055854770354926586, 0.10217889890606914, 0.03203142620623112, 0.091923778477524, 0.01236942536862833, 0.00800201012420335, 0.03582371771335602, 0.03259005390905908, 0.028434276281456863, 0.02655211174195366, 0.05885162204504013, 0.06739776381956679, 0.0071766078971060255, 0.054177299474499056, 0.15362511867923395, 1.2150586290018899, 11.032896024840218, 39.615772656032014, 66.82254900251115, 69.85871028900146, 71.6517276763916, 63.17402212960379, 51.69537571498326, 53.65681743621826, 32.35011434555054, 36.08633443287441, 26.640800407954625, 45.877100127083914, 50.90022039413452, 29.243692874908447, 33.02337394441877, 50.20345851353237, 56.06957939692906, 36.48049184254238, 25.46885469981602, 15.38172401700701, 6.024634046213968, 1.6793688514402934, 0.5722376225250108, 0.15311006988797868, 0.063425986229309, 0.11100199831915752, 0.16688049025833607, 0.28886484248297556, 0.5167943633028439, 0.45666856105838505, 0.6822603387492043, 0.8657377819929803, 1.2464579726968492, 1.47492972442082, 1.851837145430701, 2.5507225692272186, 3.354641739811216, 3.7646464705467224, 4.496130670819964, 5.219724757330758, 5.928057125636509, 6.9304416009358, 6.7649524467332025, 6.244513264724186, 4.959921189716884, 1.9499194366591317, 1.5621497013739176, 0.5138475128582546, 0.09834921333406653, 0.10735704390598194, 0.1153962928801775, 0.8395540927137647, 2.2237661821501593, 5.406509705952235, 5.323419238839831, 5.942277916840144, 6.217148653098515, 5.389335061822619, 4.090265112263816, 6.900759765080043, 6.319391829626901, 4.743675879069737, 2.9088943898677826, 3.7602178624698093, 4.4886214051927835, 4.198261831487928, 3.048879312617438, 2.0929329054696217, 2.3277555278369357, 1.6280020134789603, 1.6403229066303797, 1.6686942470925195, 1.1416446140834262, 0.7009907822523798, 0.5468203521200589, 0.11009278853556939, 0.15779243649116584, 0.011659156115326499, 0.45577142919812885, 2.727092602423259, 10.5856865133558, 21.039972169058665, 36.97673566000802, 46.71933644158499, 59.61380686078753, 78.90010234287807, 43.29361745289394, 27.5795385156359, 17.75842308998108, 22.76037219592503, 32.16378450393677, 40.71908753258841, 45.79506622041975, 47.64168895993914, 56.185617787497385, 60.57534721919468, 53.81190817696707, 41.79915721075875, 18.057777541024343, 3.9628264648573737, 1.5463458065475737, 0.0024795938432881875, 0.19248963679586137, 0.03139052613239203, 0.08491661519344364, 0.08690125548413821, 0.0905705557337829, 0.03938311903870531, 0.02384199368368302, 0.0765927614910262, 0.02700518653728068, 0.06651118317885057, 0.029116385483316014, 0.023861223366111517, 0.02878532824771745, 0.08782251604965755, 0.04639615165069699, 0.027205332315393856, 0.025245197316897765, 0.03132207212703569, 0.028229411292288984, 0.05291995033621788, 0.06515554485044309, 0.033223598663296015, 0.05463980929926038, 0.012315229928520108, 0.022204949919666563, 0.03167510371921318, 0.04009073267557791, 0.012803647916630974, 0.016814119814495956, 0.015378702731270875, 0.06743724098695175, 0.016872244820530926, 0.019921671100226895, 0.11247887049934693, 0.03331799306241529, 0.02371117382842515, 0.019453553183536445, 0.014152626423830432, 0.16381980877901825, 0.18149085555757793, 0.1482971395765032, 0.1381782011262008, 0.15281791985034943, 0.20712731991495403, 0.2279233325804983, 0.11445315634565693, 0.11373183969408274, 0.1533374334020274, 0.13199026031153543, 0.17352032182472094, 0.272150706499815, 0.11058857371764523, 0.10310000340853419, 0.1753514435674463, 0.12177587912550994, 0.1372671321566616, 0.16123544531209127, 0.11211098916828632, 0.20974607153662614, 0.17546120339206286, 0.1718023254403046, 0.20806056340890272, 0.11911752820014954, 0.13429388669984682, 0.12355197167822293, 0.1095268971153668, 0.14784599521330424, 0.11045511945017747, 0.15478306582995824, 0.15269650279411248, 0.10348835614110742, 0.2756797399904047, 0.333010303654841, 1.7628614455461502, 17.651316608701432, 56.037961619240896, 77.72877502441406, 80.03934982844761, 83.0135748726981, 73.89235496520996, 57.49383504050118, 57.28847060884748, 36.13763645717076, 36.56824064254761, 27.5999436378479, 48.79144559587751, 57.77100910459246, 36.59595005852835, 67.90793405260358, 80.76417895725795, 72.66130787985665, 52.75472239085606, 28.483896936689103, 15.348721810749598, 9.188483680997576, 3.842823258468083, 1.3258661116872514, 0.5153352958815438, 0.2321004755795002, 0.19844314376158373, 0.45950527169874733, 0.3483952709606716, 0.518997810781002, 0.4940835248146738, 0.5916609317064285, 0.604096035872187, 1.0985940098762512, 1.9510750089372908, 1.1755839586257935, 2.787577756813594, 2.9283721446990967, 4.382260118212018, 7.749141761234828, 4.189805439540318, 7.08440716777529, 13.86495658329555, 10.617815852165222, 8.800460662160601, 9.583825758525304, 3.689465659005301, 7.071397968700953, 3.8605659178325107, 1.2955543782029832, 0.3738622101289885, 1.1193451306649616, 2.046333291700908, 3.821694655077798, 5.524453205721719, 7.444126265389579, 8.299559814589363, 10.205356887408666, 8.594377091952733, 5.153418966702052, 10.839489442961556, 8.156501616750445, 6.125789395400456, 4.603795613561358, 5.765694660799844, 5.60858416557312, 5.618873579161508, 6.777648976870945, 2.6807646197932105, 1.8208657673427036, 1.1831761683736528, 0.9113656793321881, 1.7215902315718787, 1.079604365995952, 0.5967092865279743, 0.5044403576425144, 0.2323899386184556, 0.27177816363317625, 0.19669193987335476, 1.8261118744100844, 4.124531890664782, 17.090489285332815, 25.471125023705618, 39.99674238477434, 48.81153283800398, 70.68028613499233, 85.51255702972412, 49.12953799111502, 29.83771174294608, 20.472835881369456, 31.547124930790492, 38.723662172045024, 48.025778429848806, 53.2483571597508, 57.51223734446934, 65.77687290736607, 68.27144990648542, 62.61972958700997, 50.292068890162874, 22.519978421075002, 5.3977115494864325, 1.9110446998051234, 0.1374341874782528, 0.24107757530042104, 0.1471214826617922, 0.27992603927850723, 0.24725908360310964, 0.12289494621966567, 0.17587287058787687, 0.2658105567097664, 0.21523847324507578, 0.11863534764519759, 0.1320010625890323, 0.13326473906636238, 0.1167285285357918, 0.10419258049556188, 0.3248699190361159, 0.0941376889656697, 0.19641097209283284, 0.17388964843537125, 0.10295501404574939, 0.10025544890335628, 0.1910131445952824, 0.14089540817907878, 0.13590437599590846, 0.11185372940131597, 0.10014291387051344, 0.11856319223131452, 0.1781649754515716, 0.1521955132484436, 0.1656233412878854, 0.12595233001879283, 0.10160953338657107, 0.11488044341760022, 0.1558614886764969, 0.14754465781152248, 0.20586475623505457, 0.18633862185691083, 0.28141374087759424, 0.23580913086022648, 0.16718365970466817], [0.024766969228429452, 0.018892062062929784, 0.06329427579683916, 0.04557220997022731, 0.03549327455194933, 0.03546689650309937, 0.0316663574028228, 0.020798231475055218, 0.04362683989373701, 0.007225119758264295, 0.03833657716001783, 0.14367333054542542, 0.07285776548087597, 0.0356753763875791, 0.02489886965070452, 0.030644717759319713, 0.031367415229656866, 0.028246048970946243, 0.03647401549720338, 0.0672237060165831, 0.03879371638010655, 0.06125358851360423, 0.07324060172374759, 0.06126526610127517, 0.0954041610072766, 0.06665258309138672, 0.049630263288106234, 0.021100174469341124, 0.037165737843939235, 0.03583425196952053, 0.026087476406246424, 0.022078214845220958, 0.10217311778771025, 0.0324512324295938, 0.9341828035456794, 10.540233135223389, 20.752556460244314, 52.42637137004307, 57.24578087670462, 60.706876618521555, 53.844050543648855, 47.78003454208374, 31.92639582497733, 26.109624522072927, 25.333757400512695, 16.590206827436173, 22.1960186617715, 21.09423065185547, 45.936972754342214, 43.47994729450771, 51.20927626746041, 54.98764065333775, 31.644424029758998, 14.833848135811941, 5.750559312956674, 3.0951927474566867, 0.8315389656594822, 0.6091499818222863, 0.04275712084823421, 0.12248470394739083, 0.11782388761639595, 0.31647907357130733, 0.12532175385526248, 0.09511378194604601, 0.2982646966619151, 0.46052171715668266, 0.11996792256832123, 0.6519254807915006, 1.0658455214330127, 1.5118845871516635, 2.7291929125785828, 2.8820445963314603, 2.9588651827403476, 4.695221747670855, 2.974278892789568, 3.620892367192677, 4.444166830607823, 5.581913071019309, 5.452283569744655, 3.0839375342641557, 2.719997840268271, 0.7929297802703721, 1.2392284806285585, 0.8885309132082122, 0.26971153595617836, 0.12046019972435065, 0.08351686530347381, 1.1091994579349245, 2.308954570974622, 5.052800365856715, 4.0158655388014655, 6.292400683675494, 3.4962898875985826, 5.420533342020852, 3.9534989425114224, 6.627933536257062, 5.00494247674942, 3.795060472829001, 2.563856835876192, 3.9557796886989047, 1.1271334098918098, 3.5571906311171393, 2.093914338520595, 1.9514695363385337, 1.7457401071275984, 2.186302363872528, 1.9348915687629153, 1.4120549325432097, 1.1074309242623193, 0.3979283001806055, 0.26941490758742603, 0.027941079710477164, 0.12225265854171344, 0.07606800286365406, 0.16604476581726754, 0.028638140431472232, 0.4015772443796907, 1.867141421352114, 10.475635732923235, 21.301731654575892, 41.50671100616455, 44.40621859686715, 30.750910009656632, 22.97361241068159, 29.05241765294756, 20.874801329204015, 16.653715099607194, 26.60994519506182, 21.57688900402614, 24.17185183933803, 45.98958451407296, 55.09129040581839, 63.130790437970845, 57.236710003444124, 42.044609274183, 13.003144587789263, 2.7095238651548113, 0.8797647835952895, 0.04717757971957326, 0.07244275989277021, 0.051227823099387546, 0.057733742387167046, 0.027538074014176215, 0.04920181931395616, 0.042227768538785834, 0.024732694728299975, 0.015161849724661027, 0.03967491963079997, 0.00850563747475722, 0.03138442610257438, 0.05078236146696976, 0.019977180353764976, 0.02807705643187676, 0.023432429946426834, 0.028363615340952362, 0.008251015512671853, 0.040005627420863936, 0.060461493874234815, 0.059152932305421145, 0.036246224506092925, 0.050046307034790516, 0.023460312646680644, 0.05029593328280108, 0.006902434796627078, 0.0802554731656398, 0.023597775359771082, 0.03392620810440608, 0.03823408783812608, 0.05069886434024998, 0.019879973426993405, 0.02307036705315113, 0.0781779210748417, 0.02985450266195195, 0.006637114033635173, 0.045308666968984265, 0.031242439257247106, 0.04109253874048591, 0.008853801426344683, 0.020092572019036328, 0.0715965927977647, 0.08895743372184889, 0.044161986892244647, 0.04229005805349775, 0.05276396870613098, 0.05464611967493381, 0.038768471484737735, 0.10082385090312787, 0.08668350681130375, 0.022746710938268473, 0.015877454807715755, 0.05772822589746543, 0.02208375508364822, 0.04525169716881854, 0.07651838048228196, 0.060489720931010585, 0.030230170182351555, 0.027536571059109907, 0.09020141911293779, 0.06449202581175736, 0.03858890397740262, 0.02476017709289278, 0.05368198587426117, 0.05650464405438729, 0.012646809636083032, 0.04866806331223675, 0.024110530702663318, 0.07331701833754778, 0.04285942357299583, 0.08231759537011385, 0.07846855119402919, 0.882974634213107, 14.8990569795881, 35.29300301415579, 65.1237005506243, 68.5060349873134, 71.76187052045549, 62.4230260848999, 56.96028634480068, 41.056926318577354, 39.43314620426723, 35.57855313164847, 23.208751610347203, 24.86089253425598, 28.486561570848735, 46.22382913316999, 30.619331972939626, 54.440084389277864, 63.90919712611607, 37.45703336170742, 17.477450098310197, 5.635383801800864, 2.363418677023479, 0.5948300702231271, 0.22378747165203094, 0.006794683859750096, 0.316010233014822, 0.34657229163816994, 0.731528983584472, 0.6470739011253629, 0.8420164148722376, 1.2593361330883843, 1.5907559778009142, 1.538408032485417, 4.095460627760206, 3.433490983077458, 4.184324613639286, 5.914969325065613, 6.562282179083143, 5.81978725535529, 8.22608174596514, 8.37282943725586, 6.1722307205200195, 7.055809250899723, 8.99654838017055, 8.30861244882856, 6.24260858978544, 5.297714378152575, 1.264068833419255, 0.15961082891694137, 0.2750070132315159, 0.32255804166197777, 0.266197321670396, 0.448200416884252, 1.5319696579660689, 2.6970885438578467, 5.638460116727011, 5.684846290520259, 7.622636778014047, 6.181292474269867, 6.286724439689091, 6.3769711170877725, 7.104557377951486, 8.227185641016279, 5.489545021738325, 6.993060069424765, 7.046780935355595, 5.262621632644108, 6.798542644296374, 5.900130144187382, 4.492537583623614, 6.213070060525622, 3.1108856882367815, 4.462757170200348, 2.724515906402043, 2.3384933173656464, 1.2824007868766785, 1.5217269275869643, 0.6725125589541027, 0.4171431362628937, 0.12826800718903542, 0.07081023856465306, 0.1077197819416012, 0.3574221208691597, 2.2219466226441518, 9.222385678972516, 18.73456335067749, 38.514934812273296, 45.40335457665579, 25.4028867653438, 23.76534400667463, 22.126005138669694, 27.60859935624259, 27.574900593076432, 32.651273591177805, 32.92564058303833, 34.019262722560335, 52.02281304768154, 61.89029380253383, 71.09515612465995, 66.61640289851597, 50.69173274721418, 24.128635781151907, 5.571360494409289, 2.017382102353232, 0.14338063767978124, 0.08174230623990297, 0.053349561390600035, 0.08887066266366414, 0.08380799075322491, 0.023421142516391616, 0.07144807505288295, 0.04574859854100006, 0.026151343514876704, 0.04568750664059605, 0.07880019875509398, 0.038696241432002614, 0.05216638291520732, 0.04639578863446202, 0.04056081834382244, 0.0314188549694206, 0.03514459915459156, 0.022858311289123127, 0.019345376041850874, 0.04591763857752085, 0.03156651436750378, 0.048559687699058225, 0.02960157534107566, 0.024110601948840276, 0.026424136644761478, 0.024039584777450988, 0.018717033954869424, 0.05600430590233632, 0.018073312871690308, 0.04868814116343856, 0.00821312187638666, 0.028471499016242366, 0.027695390661912303, 0.032859869966549535, 0.02082712688882436, 0.03281021138120975, 0.0687862296721765, 0.05948088863598449, 0.10331448832792894, 0.21250765477972372, 0.19076010531612805, 0.19419353322259017, 0.15666210571570055, 0.14456280853067124, 0.1416622613157545, 0.12309394696993486, 0.12468710648162024, 0.15903783323509352, 0.1133428355678916, 0.24302274520908082, 0.1527554267751319, 0.17910169304481574, 0.11349182150193624, 0.12271015399268695, 0.17862605356744357, 0.14084571227431297, 0.21329679100641183, 0.21063483027475222, 0.17959006183913775, 0.20509349262075766, 0.12896552761750563, 0.1080579502241952, 0.12911309541336127, 0.18517873409603322, 0.14000650016324862, 0.2074901597308261, 0.13750977627933025, 0.13647097987788065, 0.10550621072096483, 0.12850290244179113, 0.14612924733332225, 0.17676950033221925, 1.1853096996034895, 22.182914359228953, 55.62335566111973, 75.6493250983102, 79.34119483402797, 80.06570434570312, 69.87831810542515, 63.855522292000906, 49.133957045418875, 38.96158586229597, 37.68050479888916, 25.699170112609863, 31.762675421578543, 30.42067950112479, 58.51779801504952, 61.11192185538155, 63.51401138305664, 65.21121311187744, 38.55426161629813, 17.52864616257804, 7.523119466645377, 4.389242189271109, 1.3728169351816177, 0.8532335758209229, 0.3643067814409733, 0.3050000252468245, 0.4614708519407681, 0.7709810723151479, 0.7914082333445549, 0.45846597318138393, 0.5113134288362094, 1.8044461969818388, 1.5912000111171176, 4.779558113643101, 3.487738392182759, 6.408000034945352, 8.654693535396031, 9.767008066177368, 8.693920459066119, 9.128655348505292, 10.06351636137281, 11.799825157438006, 13.267298596245901, 14.878226280212402, 17.296512058803014, 12.890237229210989, 9.28099547113691, 5.996885112353733, 4.512111961841583, 3.483917100088937, 1.759836373584611, 0.7155161542551858, 0.8933305985161236, 3.566851232733045, 8.150441919054304, 16.54451721055167, 12.003586292266846, 17.76939950670515, 13.572091749736241, 15.993360042572021, 13.414933051381793, 16.195059299468994, 12.909198863165718, 7.542613506317139, 7.559093764850071, 9.042086005210876, 6.260880180767604, 12.21288514137268, 7.940225907734462, 7.271959892341068, 8.21215842451368, 5.631624826363154, 5.721822866371699, 3.0784295669623782, 3.0975725054740906, 1.1088364145585468, 1.5436148388045174, 0.44554267664040836, 0.39201196336320465, 0.303739388606378, 0.26797421489443096, 0.1972899327852896, 0.569386961204665, 3.2239022638116563, 14.312603831291199, 30.16953338895525, 52.92764915738787, 53.5832325390407, 42.615640027182444, 32.73249108450753, 41.73681797300066, 32.15690231323242, 26.765433720179967, 39.005453314099995, 34.602907930101665, 38.99462454659598, 60.973388671875, 69.84529331752232, 79.55940995897565, 73.51583208356584, 58.926282610212056, 30.52154302597046, 9.139399869101387, 2.616250378744943, 0.22576344705053739, 0.19310935639909335, 0.10366440883704595, 0.1716405762625592, 0.219502916559577, 0.10294248828930513, 0.10403429863176175, 0.12323167600802012, 0.1320927869528532, 0.22855841421655246, 0.12411500646599702, 0.0867811276444367, 0.1068410858778017, 0.16991550954324858, 0.10555227646338088, 0.14023152951683315, 0.10579076116638524, 0.12105081017528262, 0.1818626927477973, 0.10643927101045847, 0.12004801684192248, 0.09421332526419844, 0.17762596080345766, 0.09574908749865634, 0.16295292600989342, 0.08245978916862182, 0.21553979707615717, 0.1778085274355752, 0.14402183970170362, 0.1469261460006237, 0.08185237140527793, 0.1374391136424882, 0.13243875838816166, 0.173746898238148, 0.08526293946696178, 0.17860215556408676, 0.1252842444394316, 0.1882359143346548], [0.0027159089305704193, 0.026932437405256287, 0.02696544983025108, 0.04914442203672869, 0.019589674093627503, 0.08970009708510977, 0.05105168558657169, 0.06883003589298044, 0.02768098027445376, 0.050240544469228814, 0.02855315731306161, 0.02988771695111479, 0.0037743569784132497, 0.01669916241163654, 0.06077034265867301, 0.06395444965788297, 0.018901103542053273, 0.02328445333322244, 0.0117158977580922, 0.0478224152965205, 0.026045108679682016, 0.011139253254181572, 0.07343380778495755, 0.040244834763663154, 0.045336785460157056, 0.043123807957662005, 0.020328552927821875, 0.055459645842867236, 0.012804864190651901, 0.06908094457217626, 0.07389643974602222, 0.06539497271712337, 0.05137500073760748, 0.2961317082600934, 8.710914884294782, 41.302367959703716, 46.02377312523978, 58.109108448028564, 60.771772793361116, 48.60691186359951, 51.32999079568045, 35.661531993321006, 31.067973681858607, 18.031482083456858, 22.29187948363168, 36.89502831867763, 30.376673085348948, 36.54013517924717, 44.088025842394146, 65.54100935799735, 42.696478843688965, 17.284637587411062, 8.679096477372305, 3.487250281231744, 1.4059966461999076, 0.1311896297016314, 0.03330979635939002, 0.12518824530499323, 0.05036840421546783, 0.06428569009793655, 0.09739454848957912, 0.04075217878978167, 0.10705073284251349, 2.0886198111942837, 2.3651192486286163, 0.959488359945161, 1.9595867693424225, 3.102091005870274, 2.758990045104708, 2.11808625289372, 3.9290065424782887, 3.817157047135489, 4.113841218607766, 9.570455687386648, 5.162516329969678, 6.763895886284964, 6.562348186969757, 5.874692789145878, 5.8578408019883295, 5.254096192973001, 4.613816652979169, 1.3837145332779204, 0.6437107558761324, 0.33554137498140335, 0.10041934225176062, 0.1616361473820039, 1.3268741433109557, 2.1594074070453644, 4.939726684774671, 6.631502304758344, 4.888372548988887, 5.950308731624058, 4.284360000065394, 3.8415964671543668, 3.8578717538288663, 5.871704629489353, 6.770243499960218, 4.230908811092377, 3.6375072470733096, 4.942799525601523, 6.903254168374198, 2.516844238553728, 2.9432947039604187, 1.489992876138006, 6.383049922330039, 2.8408545894282202, 4.764683323247092, 1.9381700328418185, 1.2535165825060435, 1.8975968956947327, 0.9932631190334047, 0.4255814791790077, 0.253168417939118, 0.22542660869657993, 0.04028076319290059, 0.06176589602338416, 0.06084957519280059, 0.23883157010589326, 1.137551907982145, 8.01988787310464, 14.489753365516663, 34.35744891847883, 44.341878277914866, 37.21369355065482, 29.99404968534197, 22.541158267429896, 15.781723124640328, 58.00322832380022, 28.935971055712017, 25.217479297092982, 38.135413782937185, 38.80475459780012, 45.5624544279916, 57.20647839137486, 55.83934041431972, 54.24311685562134, 33.93694741385323, 19.292979649135045, 3.9918842656271796, 0.26533911057880943, 0.06917611589389187, 0.013386087957769632, 0.08882188956652369, 0.02497437024222953, 0.018364867494840707, 0.02918196589286838, 0.06527370493859053, 0.029245659975068908, 0.02107527562683182, 0.010448550406311239, 0.051804910347397835, 0.06886249022292239, 0.017701399346281375, 0.01609950030355581, 0.021572926780208945, 0.020724128665668622, 0.04348294636500733, 0.04909535038418003, 0.021576767288414494, 0.07449381519109011, 0.02740087084073041, 0.10630277012075696, 0.01858918438665569, 0.08134301552282912, 0.019620130137939538, 0.07935798168182373, 0.025016117109251872, 0.010547580047776657, 0.0388660346423941, 0.025557141917358552, 0.07293581736407109, 0.0255486076431615, 0.011810365947894752, 0.13736969951008046, 0.050733581584479125, 0.056651353503444364, 0.03189488799710359, 0.04327103648600834, 0.03014927523742829, 0.04657130189506071, 0.015906472357788255, 0.043738255343799076, 0.04409256936716182, 0.018273002335003445, 0.020600845638130392, 0.02975287168685879, 0.08683952236814158, 0.06408221101654427, 0.04143970100475209, 0.013847546053252049, 0.022767440183088183, 0.0838031324424914, 0.026303041892658387, 0.08120529327009406, 0.04206534082602177, 0.04012507333287171, 0.032950111731354675, 0.006057920358476362, 0.06962732132524252, 0.03431743782545839, 0.014384840615093708, 0.05160897657541292, 0.01693645628568317, 0.07685842830687761, 0.0267477842779564, 0.0412285917970751, 0.03459816472604871, 0.057678624987602234, 0.05556300708225795, 0.27538308448025156, 9.36337070805686, 47.77541051592146, 55.916194438934326, 68.53430025918144, 69.00857734680176, 61.44040489196777, 57.68630708966936, 46.39750630514962, 41.862034933907644, 25.537273611341202, 29.307901178087505, 32.35869884490967, 25.227159874779836, 33.02951962607247, 45.685402802058626, 63.05975900377546, 48.62081173488072, 20.19484887804304, 8.855125614574977, 2.360959231853485, 0.8808692214744431, 0.2262855526059866, 0.010961857058906128, 0.2731029082621847, 0.10174996977938072, 0.8272130606429917, 0.7334804502981049, 0.8056551888585091, 1.7894321169172014, 3.7915581464767456, 5.335902980395725, 5.48352049929755, 5.600908143179757, 6.611793739455087, 7.005647599697113, 5.1264408486230035, 6.9980067525591165, 8.627132637160164, 8.842929788998195, 8.406533411570958, 11.346300601959229, 8.179392457008362, 7.04337979214532, 7.827259489468165, 6.248350841658456, 4.669111720153263, 2.466294139623642, 2.4655411286013464, 0.5207406144057001, 0.2722163072654179, 0.1661233673138278, 0.2781886639339583, 0.797813821051802, 2.2277151473930905, 1.4774178309100015, 2.6814850611346106, 2.9925040176936557, 4.71445175579616, 5.159755723817008, 5.2047309790338785, 8.634728755269732, 8.444378512246267, 9.917366215160914, 8.863382680075508, 6.029098698071071, 5.310931154659816, 6.640680006572178, 7.497275641986302, 3.8649207012993947, 5.999927989074162, 7.726742506027222, 6.318875925881522, 7.0346719622612, 4.681060450417655, 5.422200041157859, 5.45042405809675, 2.3245235298361098, 1.7204144660915648, 0.7913766407540866, 0.4603176681058747, 0.25168763739722116, 0.24223906440394266, 0.03652879023658378, 0.09253502317837306, 0.5168701963765281, 5.395497245447976, 14.645848989486694, 27.911886487688335, 35.70513193947928, 38.252741064344136, 32.13602645056588, 27.750735180718557, 20.180955954960414, 53.469084058489116, 32.487744263240266, 30.28645420074463, 47.918717111860005, 46.00798681804112, 52.82744918550764, 63.99958624158587, 62.77990640912737, 64.45505455562046, 48.062770639147075, 27.111558232988628, 7.588726094790867, 0.7038445919752121, 0.008994878186578197, 0.0344799401770745, 0.04685601518888559, 0.005364222202583083, 0.068709365225264, 0.08198178160403456, 0.05633418248700244, 0.08156322049243109, 0.01572304398619703, 0.03330178286081978, 0.04551870748400688, 0.0563272241103862, 0.028681373290185417, 0.041614305028425794, 0.04009928221681288, 0.045327632022755485, 0.003853507664254201, 0.03163002185257418, 0.032669160914208205, 0.059784560198230405, 0.027259654132649302, 0.019945547051195587, 0.006135900995494532, 0.07038977755499737, 0.02992212206923536, 0.028593346942216158, 0.02772215717206044, 0.059578699458922656, 0.02492177190392145, 0.056494299788028, 0.017539219298799123, 0.041528806223401, 0.04654252861759492, 0.054327476237501414, 0.03810301862124886, 0.010909029715029257, 0.07795414022569146, 0.10129043193800108, 0.08587016724050045, 0.09067771676927805, 0.12193572840520314, 0.1401307534958635, 0.15408979303070477, 0.13703558886689798, 0.16011371836066246, 0.16007360337035997, 0.1687837809856449, 0.1801940937127386, 0.07796327330704246, 0.09704244988305227, 0.13759228613759789, 0.10330535524657794, 0.16657852860433714, 0.10122219167117562, 0.13571773815367902, 0.10598805879375764, 0.18421944842806884, 0.0929684577775853, 0.21408771856554917, 0.12476230173238687, 0.10640554103468146, 0.1226714232138225, 0.14939677342772484, 0.15313684487981455, 0.11149234165038381, 0.1994168008012431, 0.22367765754461288, 0.20130494662693568, 0.13413634443921701, 0.52049791600023, 14.794604710170201, 60.284488677978516, 73.36165850503104, 79.24496228354317, 79.75397341591972, 65.55635792868478, 66.10533509935651, 50.173543044498985, 46.45689950670515, 28.373986857278005, 31.89275959559849, 49.61656502314976, 42.46061529432024, 50.21740354810442, 55.944001129695344, 75.31208733149937, 50.54082482201712, 23.97517786707197, 11.086434500558035, 4.949773345674787, 2.6445351924215044, 0.4146080751504217, 0.21769798626857145, 0.3327718935906887, 0.22934347923312867, 0.5987854951194355, 0.8059995589511735, 0.37419906205364634, 1.8038069627114703, 5.509591008935656, 8.17173901626042, 5.270110487937927, 8.212702121053423, 9.206896407263619, 11.999392185892377, 8.738450595310756, 13.8481810263225, 13.446937322616577, 17.252731459481375, 20.16762583596366, 17.000558750970022, 18.283665214266094, 16.93517099108015, 17.035876444407872, 14.367628352982656, 14.093045098440987, 8.466088158743721, 7.485146692820957, 1.9037712386676242, 0.7012162187269756, 0.400538081569331, 0.604763497199331, 1.2007385002715247, 2.1892777127879004, 8.497200454984393, 14.614675896508352, 11.6136759689876, 15.900104795183454, 13.711053115980965, 13.82165801525116, 13.054574285234724, 17.576621736798966, 17.27486147199358, 12.552665080342974, 11.715900472232274, 15.090644870485578, 14.207011188779559, 11.750997560364858, 8.83305639880044, 9.234838587897164, 12.784368395805359, 8.77922783579145, 11.639399068696157, 6.489754276616233, 6.173324193273272, 5.8969326700483045, 3.10001870564052, 1.7134066649845667, 0.5817820046629224, 0.7249305290835244, 0.1694850062153169, 0.28730833743299755, 0.11767364639256682, 0.36414005181619097, 1.389814834509577, 9.950163449559893, 19.073178597858973, 45.439054421016145, 59.09011418478829, 54.66580009460449, 43.419504914964946, 30.508702754974365, 22.088036707469396, 68.95854336874825, 37.03422505514962, 37.22138868059431, 51.6008107321603, 55.12022270475115, 60.5390567779541, 72.19563961029053, 71.17855535234723, 72.55886363983154, 55.76810053416661, 33.245455741882324, 9.333506481988088, 1.1789036776338304, 0.22116616873868875, 0.162125791822161, 0.13316218528364385, 0.15496669097670487, 0.10672122945210763, 0.22599076985248498, 0.1134774229888405, 0.11313877973173346, 0.11711647414735385, 0.09960482203002487, 0.14912075895283902, 0.17479157075285912, 0.08894179348966905, 0.07876207865774632, 0.13210113293358258, 0.12342877686023712, 0.06338614265301398, 0.13527077356619494, 0.12181125794138227, 0.15277433076075145, 0.10448164319885628, 0.3038164973258972, 0.08865773158946208, 0.2315631572689329, 0.09333157579281501, 0.1431391199252435, 0.09360421116330794, 0.10150029603391886, 0.10634232192699399, 0.1641954050532409, 0.15837618016770907, 0.10543270502239466, 0.0956317823646324, 0.24283508956432343, 0.14167456994099276, 0.07281214078622204], [0.04354397041190948, 0.1918657509876149, 0.04755665687844157, 0.06712508095162255, 0.05773857355649982, 0.03432038945278951, 0.09128261038235255, 0.01818452136857169, 0.09833727111773831, 0.03229800225900752, 0.017291742310460125, 0.017886590212583542, 0.04977353256461876, 0.04440126208854573, 0.04552079397918923, 0.05852212543998446, 0.13235607211078915, 0.11863078788987227, 0.03072192147374153, 0.04434944236917155, 0.03511105916861977, 0.016915584548509548, 0.015240417294470327, 0.06292767011161361, 0.03324951870100839, 0.09652894136628934, 0.055308451277336905, 0.0737874602366771, 0.0038833670218342115, 0.01825419334428651, 0.026727173776764954, 0.03512516591165747, 0.06671403800802571, 5.12094612632479, 36.905193533216206, 42.29551567350115, 59.68852778843471, 58.008522851126536, 45.69343144553048, 41.78726536887032, 47.35020160675049, 31.82986102785383, 20.707471336637223, 31.932878494262695, 40.24338606425694, 80.25509139469692, 92.22608021327427, 54.78716427939278, 53.428558690207346, 44.4160190309797, 14.315277150699071, 10.845716765948705, 1.6265847980976105, 0.7684662586876324, 0.11616105612899576, 0.09116754441389016, 0.11390319014234201, 0.31495986080595423, 0.13896249261285576, 1.6905898664678847, 0.6377727602209363, 2.1647640338965823, 1.791606360248157, 3.0517476158482686, 3.568288858447756, 3.9289149131093706, 1.2606898375919886, 4.373351659093585, 5.5030640448842725, 5.48833646944591, 5.179563735212598, 8.046763505254473, 7.381490860666547, 8.708624584334236, 10.608773640223912, 2.629615890128272, 5.751328391688211, 7.515291452407837, 4.311574791158948, 2.6615341774054935, 4.826070657798222, 0.2727062095488821, 0.06851338395582778, 0.16944472837660993, 0.33093976761613575, 4.814495827470507, 12.129122870309011, 16.07195806503296, 14.376582843916756, 4.115705507142203, 3.3290491359574452, 3.0501527871404375, 3.4963493815490176, 2.862693646124431, 5.759791297572, 4.597964772156306, 8.735398599079677, 8.014368397848946, 8.071356654167175, 6.6978228603090555, 3.943448373249599, 4.9107726727213175, 4.612169061388288, 5.3945666210992, 6.069869858878, 3.270154684782028, 7.2202683346612115, 3.8389392154557362, 3.436481531177248, 2.1964250206947327, 2.1707692316600253, 1.557666159101895, 1.4435469912631171, 0.34799922364098684, 0.1921267155557871, 0.028221681082089032, 0.012517300201579928, 0.09995780951742615, 0.03692512932632651, 0.0266603312920779, 0.9879832480634961, 10.747741954667227, 24.90461754798889, 37.74985129492623, 30.6909852709089, 30.85796090534755, 31.44017825807844, 89.05606882912772, 51.19125264031546, 19.463545765195573, 24.202092136655533, 32.0133490562439, 51.54232774462019, 41.47371053695679, 46.2092170715332, 47.49316774095808, 62.76072243281773, 50.06071819577898, 42.44261598587036, 15.939396858215332, 3.0029766900198798, 0.06693961697497539, 0.016550191744629825, 0.016347250402239815, 0.005198157118034682, 0.05978346097150019, 0.05505348156605448, 0.021269231469237378, 0.06461157011134283, 0.08411194730017867, 0.049862668317343505, 0.06223477050662041, 0.07109571181769882, 0.09102207329124212, 0.033925295474806, 0.05507858736174447, 0.07925508184624569, 0.03238148920770202, 0.02804565043853862, 0.06785654170172555, 0.022893076030803577, 0.045156461386276145, 0.05831464978733233, 0.013835844716855457, 0.051370858281318627, 0.11341765762439796, 0.09040267938481909, 0.049411629127072434, 0.04790839586140854, 0.03555350471287966, 0.048412004552249394, 0.08582741274897542, 0.011139173526316881, 0.05553256460864629, 0.0742956626095942, 0.06718772330454417, 0.024560786184987853, 0.15176990894334658, 0.02614537749572524, 0.023274243077529327, 0.0031180092067058596, 0.013091398502833076, 0.041562380136123726, 0.07991637529007026, 0.03985739805336509, 0.044365479544337304, 0.07390074844339065, 0.011655255387138044, 0.026994368992745876, 0.011164664390629955, 0.06066058961940663, 0.09059963095933199, 0.04164913083825793, 0.016669613907911947, 0.06643718893506698, 0.020203105373574153, 0.0038116950641519255, 0.02292603756567197, 0.019114127914820398, 0.07587991974183492, 0.031427655568612475, 0.043489239777305295, 0.03151151231889214, 0.030083216460687772, 0.059920206133808405, 0.046281906709607155, 0.022076543952737535, 0.08783165591635875, 0.06169829357947622, 5.977576068469456, 44.25341728755406, 52.868537357875276, 71.65633433205741, 66.26221152714321, 53.76190546580723, 45.61036573137556, 55.79912076677595, 41.70178515570504, 31.730230808258057, 34.10880068370274, 45.99471228463309, 73.74964591435024, 70.0613545009068, 49.548757553100586, 58.71548816135952, 52.11749267578125, 18.364153146743774, 9.830950600760323, 1.8866402379104068, 0.787934025483472, 0.05189335738707866, 0.3020849030997072, 0.25625963349427494, 1.1355000180857522, 0.9441228530236653, 3.3872541955539157, 3.939073613711766, 4.802793323993683, 4.308270922728947, 8.670259237289429, 6.557457957948957, 7.079124799796513, 5.7359403031212945, 7.310276167733329, 7.102802523544856, 5.86869215113776, 6.26906863280705, 10.615917256900243, 7.891895106860569, 12.016692331859044, 12.410934856959752, 6.509163635117667, 5.048814705439976, 4.15231556551797, 3.144833500896181, 2.1007830670901706, 2.2468650341033936, 0.6765763323221887, 0.1614548156836203, 0.45311879153762546, 0.840941343988691, 5.567964996610369, 11.574229308537074, 14.613835164478846, 13.463378497532435, 5.373359850474766, 2.0488151013851166, 2.678059382098062, 4.441543885639735, 5.0671245115143915, 7.625356997762408, 5.429176901068006, 6.7395176972661694, 5.756419684205737, 5.838639889444623, 6.29780638217926, 5.961543100220816, 5.891514377934592, 6.637607600007739, 8.907352617808751, 8.041233607700892, 7.221354424953461, 11.113361375672476, 8.193144679069519, 5.060209316866739, 5.517864142145429, 6.40605627638953, 3.354901645864759, 3.614514572279794, 2.5817295568329945, 1.0815037212201526, 0.1575046969311578, 0.37276035068290575, 0.1389447014246668, 0.04579222155734897, 0.06500870308705739, 0.8165101749556405, 8.552541119711739, 19.793168306350708, 32.50182131358555, 31.569609301430837, 31.05804123197283, 28.15600970813206, 94.59631225040981, 49.69668122700283, 28.318118129457744, 29.992302213396343, 39.49617678778512, 57.37560101917812, 46.97160121372768, 51.335080351148335, 52.51281043461391, 65.97679342542375, 59.85725089481899, 53.13106114523751, 22.687838213784353, 3.849583855697087, 0.08776625871126141, 0.025410118645855358, 0.02133189417820956, 0.09393985529563256, 0.05570558086037636, 0.08674735695655857, 0.011345668695867062, 0.11033874390912907, 0.004609234098877225, 0.02264715119131974, 0.0435044966371996, 0.02372983523777553, 0.030480753164738417, 0.06264799154762711, 0.04085125847320471, 0.05562238907441497, 0.07892381426479135, 0.0210128079966775, 0.09039396020982947, 0.08949735082153763, 0.0441515679870333, 0.07714189309626818, 0.04216086837862219, 0.07567806914448738, 0.07494274074477808, 0.03982103196904063, 0.04752312707049506, 0.033080733115119595, 0.05415464658290148, 0.07242811710706779, 0.02916346224290984, 0.028051321294956973, 0.03607338128079261, 0.027690973398940902, 0.026510587095149925, 0.07569973476763282, 0.15748119247811182, 0.1295154123966183, 0.19612571597099304, 0.09825370274484158, 0.1580186600663832, 0.16290430219045707, 0.09846280009618827, 0.14984335803559848, 0.1014052332778062, 0.12561033479869366, 0.06991523051900522, 0.20461593967463287, 0.2127133865973779, 0.14222958444484643, 0.10101960147065775, 0.2128993459045887, 0.24763192502515657, 0.09687838011554309, 0.10906355947788272, 0.18762380789433206, 0.09506786548133407, 0.0944348465917366, 0.24181240158421652, 0.06915390744273152, 0.1654827216906207, 0.17175908918891633, 0.16005133385104792, 0.2468602950019496, 0.12045528713081564, 0.14521212583141668, 0.17612620842243942, 0.14343656253601822, 8.429230570793152, 55.52031735011509, 68.48831708090646, 82.05322265625, 75.05361434391567, 63.50357518877302, 54.10645273753575, 61.3758978162493, 43.54060506820679, 31.862482820238384, 42.16644246237618, 51.95783002035958, 86.50273091452462, 95.15988758632115, 65.34233256748745, 62.63766288757324, 52.77238818577358, 21.42926583971296, 13.850525174822126, 2.6756361978394643, 1.1359523023877824, 0.15652873287243502, 0.3336088258240904, 0.42181856823819025, 0.8198480787021774, 0.8334546057241303, 3.884779521397182, 4.720471067087991, 6.61152058839798, 5.749006824834006, 10.394650135721479, 11.124842405319214, 12.863989540508815, 8.16690046446664, 11.53298567022596, 14.347925867353167, 15.302940130233765, 10.187316758292061, 17.438138927732194, 17.72007077080863, 17.549209356307983, 21.68470941271101, 12.887197392327444, 15.094897168023245, 18.958074740001134, 12.456557597432818, 10.013314758028303, 12.382666110992432, 1.1774667033127375, 0.3559481528188501, 0.6317006860460553, 2.093019106558391, 7.039351139749799, 8.115198918751307, 9.73544066292899, 8.976282221930367, 4.212649379457746, 9.32644624369485, 9.121582082339696, 12.597736307552882, 11.888172371046883, 15.080922603607178, 12.70248213836125, 19.0600916658129, 17.99134407724653, 17.221087626048497, 14.979392051696777, 15.33360947881426, 13.317921434129987, 11.115506631987435, 12.5728018283844, 17.242317846843175, 12.932643822261266, 17.777483735765728, 13.250770568847656, 9.093722411564418, 9.445786765643529, 6.6176588875906805, 6.1801924875804355, 5.621283735547747, 2.561354398727417, 0.67432337892907, 0.1262733449361154, 0.35199403070977753, 0.2133961556745427, 0.18053182773292065, 0.19843852972345694, 1.7450856736728122, 13.813816104616437, 30.931483268737793, 45.21640634536743, 42.372883864811485, 42.58459200177874, 39.23980910437447, 94.70858819144112, 58.84943553379604, 29.967893191746303, 32.45594235828945, 46.47169916970389, 64.7665353502546, 55.99021707262312, 60.035979407174246, 60.53007970537458, 74.347628729684, 69.62580667223249, 59.58771637507847, 27.29847867148263, 5.230986484459468, 0.21860339625605515, 0.13992992070104393, 0.1263242486332144, 0.2102783822587558, 0.12415398151746818, 0.20116705474044594, 0.11893361806869507, 0.25303870918495314, 0.16094968707433768, 0.1347882401730333, 0.16066147253981658, 0.17605412086205824, 0.13643797593457357, 0.14659664939556802, 0.1135795967919486, 0.2250734447900738, 0.15422518790832587, 0.11563914056335177, 0.11012627423873969, 0.1851356335516487, 0.1419046883072172, 0.20407919133348124, 0.12784019085977757, 0.1859596057661942, 0.29186277304376873, 0.16661086758332594, 0.1945125532469579, 0.12132987805775233, 0.15785483457148075, 0.15482940977173193, 0.2162034043243953, 0.14858481128300938, 0.17135850925530705, 0.20120039795126232, 0.10831260441669396], [0.021475931895630698, 0.4624318746583802, 0.20778669310467585, 0.07123018388769456, 0.035071273267801316, 0.056247961042182784, 0.12397658532219273, 0.04189821765092867, 0.039778962797884426, 0.020813128711389642, 0.027994536395583833, 0.043767327176673074, 0.06872471368738584, 0.07903768601162092, 0.13444176662181104, 0.150711611445461, 0.1836110467889479, 0.017424348409154584, 0.01895736936213715, 0.0318191736670477, 0.04349770789433803, 0.006964096666446754, 0.054393613045769076, 0.15392019998814377, 0.0948967118082302, 0.05164376167314393, 0.04173052789909499, 0.02637749075490449, 0.04700063135741012, 0.03893109257998211, 0.038347959584955654, 0.05738630531621831, 2.4868883831160407, 19.860136781420024, 43.98039129802159, 58.111311026981895, 61.899743352617534, 51.63171631949288, 46.70076390675136, 42.19445759909493, 59.526843207223074, 36.119866439274375, 23.216691664287023, 43.61004536492484, 47.28126852852957, 65.30778612409318, 85.84470871516636, 62.981348582676475, 34.12283604485648, 12.838203038488116, 6.7707706945283075, 1.1102330024753297, 0.026525336750117794, 0.14917881440903458, 0.17287023099405424, 0.1575979683548212, 0.3105254444692816, 0.7917918499026979, 1.8981505802699496, 2.212275815861566, 3.245560015950884, 2.5695851913520267, 3.5072120215211595, 6.079786241054535, 6.030670293739863, 5.901028198855264, 5.365704238414764, 6.948306288037982, 4.537673515932901, 3.7510870609964644, 6.569816631930215, 5.753058927399771, 5.756279417446681, 6.670958953244345, 6.760152110031672, 5.006109774112701, 4.086570841925485, 3.1240503532545905, 1.574358880519867, 3.013751608984811, 3.028766231877463, 1.8901812136173248, 0.6973468320710319, 0.5051805579236576, 5.3410168545586725, 21.159126826695033, 48.02116482598441, 48.98121132169451, 46.20110852377755, 27.82082165990557, 7.683254599571228, 3.0675339230469296, 1.9035243604864394, 1.898436759199415, 7.047458818980625, 5.582180576665061, 7.337593010493687, 7.826249395098005, 2.7063298651150296, 2.549182240452085, 4.074655984129224, 5.222360730171204, 3.384366350514548, 6.709123236792428, 4.8409371972084045, 7.691224183355059, 7.1592744418552945, 8.533339772905622, 10.53559694971357, 9.841707280703954, 4.034309531961169, 2.5006397366523743, 3.0984075920922414, 1.2214260016168867, 0.560522579721042, 0.7339698640363557, 0.06892485437648636, 0.1641798394599131, 0.022550305584445596, 0.05106166344402092, 0.041083632968366146, 0.49296844750642776, 4.204859580312457, 19.393931763512747, 33.690790108272004, 49.59882627214704, 41.07980326243809, 10.699481504304067, 14.775186232158116, 14.78386800629752, 18.670481852122716, 22.098250559398107, 40.64057983670916, 36.50005796977452, 37.91905730111258, 45.284144333430696, 52.81388630185808, 58.23106670379639, 56.93744414193289, 51.89539698192051, 24.34263161250523, 3.3115125341074805, 0.0596280764522297, 0.0567451134723212, 0.0203670462194298, 0.12455240370971815, 0.01785697555169463, 0.08891197187559945, 0.06543981709650584, 0.029639620799571276, 0.18784053197928838, 0.04087401314505509, 0.04211639040814979, 0.03475377316187535, 0.10715726284044129, 0.0509945495453264, 0.0753532951431615, 0.03997463533388717, 0.07926720048167876, 0.16098142894251005, 0.034171457801546366, 0.05547466521550502, 0.08992478038583483, 0.10645209532231092, 0.053023447282612324, 0.03193678753450513, 0.08057276292571, 0.019374432607686946, 0.03377185156568885, 0.09840789982782942, 0.06275813135185412, 0.047458516966019354, 0.12214481218584947, 0.09932732834879841, 0.24611309223941394, 0.13499979382114752, 0.042708429175296, 0.24583847554666655, 0.07862857689282723, 0.06109554413706064, 0.0346008279759969, 0.056440610704677444, 0.06795484785522733, 0.021809347040419067, 0.015214710995288832, 0.03831680125689932, 0.011991133614044105, 0.08560505682336432, 0.0523136385849544, 0.030087939064417566, 0.12442683401916708, 0.07444937793271882, 0.10740679409354925, 0.006756140526184546, 0.03558237298524805, 0.059768858897898874, 0.028600491915962527, 0.04702984568263803, 0.06033190047102315, 0.07694164384156466, 0.02502544696575829, 0.037726686136530976, 0.04160653919513736, 0.01490601318489228, 0.03839304145159466, 0.01679814201114433, 0.021784633098702346, 0.02651555397148643, 2.540761240891048, 25.057196514947073, 54.99635716847011, 69.54561751229423, 71.49290575299943, 62.60723672594343, 55.23012236186436, 47.576299462999614, 59.37173857007708, 41.216991969517295, 22.64914890698024, 37.561579431806294, 43.41112538746425, 72.01646641322544, 94.77175426483154, 70.30465957096645, 44.60481548309326, 16.524660996028356, 6.411355580602374, 1.0016546973160334, 0.10389810308281865, 0.0200427590669798, 0.29563930896776064, 0.5926678776741028, 1.2639972886868884, 1.962141969374248, 3.8633256554603577, 3.735685510294778, 4.2541487983294894, 7.412175842693873, 7.1988570264407565, 4.881225023950849, 6.423384649412973, 7.1601099627358575, 8.229123319898333, 7.726040737969535, 8.374524797712054, 8.229575821331569, 6.0285094039780756, 6.065886804035731, 5.911408807550158, 7.479782683508737, 6.127257202352796, 3.4369802815573554, 2.617584650005613, 2.0900626480579376, 0.8714620662587029, 1.5859510813440596, 2.8476898797920773, 3.3944208281380788, 0.6494988224336079, 1.007583573460579, 4.581814553056445, 23.917447022029332, 49.86862134933472, 51.3162715775626, 47.64998510905674, 28.444429431642803, 9.41466404710497, 3.2852468235152106, 2.507815271615982, 2.4364233996186937, 2.630683524268014, 2.930866982255663, 3.1067354423659186, 4.625398865767887, 3.1653784556048254, 5.359742249761309, 4.901364377566746, 6.374168821743556, 5.352250354630606, 8.268518737384252, 7.964047806603568, 9.81453548158918, 9.650639636175972, 10.988403235163007, 12.357320819582258, 8.162569999694824, 7.6955919946943006, 4.578004334654127, 5.348145272050585, 4.668584525585175, 3.4573606508118764, 3.5505461990833282, 1.127473003097943, 0.8711005428007671, 0.11928148940205574, 0.028902399287159954, 0.009486729561883425, 0.1426288615912199, 3.268872742141996, 13.877804671015058, 29.04713007381984, 38.21160772868565, 30.655611991882324, 20.771938460213796, 22.598875216075353, 19.083953516823904, 22.533016715730938, 32.00718947819301, 45.70118563515799, 46.6583069392613, 45.33541509083339, 52.100671086992534, 58.63971110752651, 64.33946432386125, 64.74097292763847, 60.79669598170689, 31.31278998511178, 5.114147748265948, 0.13981963161911282, 0.073470428319914, 0.02773798569770796, 0.12695983238518238, 0.06158778736633914, 0.03030268182711942, 0.027603367742683207, 0.02352591510862112, 0.07567639316299132, 0.025999824948874966, 0.0046564194240740365, 0.04692783472793443, 0.01753516335572515, 0.05484105600044131, 0.04660320321896246, 0.03801572169842465, 0.057783573998936584, 0.15990312823227473, 0.0627668301707932, 0.020901460400117294, 0.01296791445929557, 0.010896104471092778, 0.01900580488810582, 0.039748374439243755, 0.029153433495334218, 0.04001320665702224, 0.052829148780022345, 0.09200564372752394, 0.057514019177428315, 0.02281122774417911, 0.040200984438083, 0.09456758839743477, 0.1356165007288967, 0.02427830866404942, 0.19044868488396915, 0.4348440250115735, 0.266364512698991, 0.16222664926733288, 0.11801182824586119, 0.11489784105547837, 0.20943019991474493, 0.21161276208502905, 0.08135506630476032, 0.13812447472342423, 0.1629718164248126, 0.17334572119372232, 0.09904406033456326, 0.13096335184361252, 0.22322450471775873, 0.36216328931706293, 0.26774473435112406, 0.14187578271542275, 0.10550224129110575, 0.11324864812195301, 0.08312815973269087, 0.11330132958080087, 0.1686290885720934, 0.2941631153225899, 0.28321875259280205, 0.19555293742035115, 0.13855225034058094, 0.09444951651883976, 0.17744150784398827, 0.10237124322780541, 0.09189749203090157, 0.17004399693437985, 4.9129869767597745, 36.17130395344326, 68.64818123408726, 79.8113099506923, 80.15067386627197, 71.68573216029576, 62.75899233136858, 56.94006361280169, 70.62782028743199, 47.318153040749685, 30.882185799734934, 55.78214979171753, 56.09419339043753, 70.35206018175397, 90.0634742464338, 71.08531747545514, 43.19847924368722, 19.480770349502563, 8.961948088237218, 1.7234033857073103, 0.2602687712226595, 0.17589773211096013, 0.35503196769527023, 0.36587626008050783, 0.7908048257231712, 3.0747214002268652, 4.228504300117493, 8.220530135290963, 9.86756500176021, 11.330191203526088, 10.434286134583608, 15.642825160707746, 13.640150223459516, 13.215490221977234, 14.366540091378347, 17.63388705253601, 15.254054341997419, 14.208805561065674, 15.90042962346758, 12.877311842782156, 13.22831312247685, 16.921776601246425, 17.603045736040386, 15.111677067620413, 12.362778629575457, 11.323508773531232, 11.051541515759059, 9.903263977595739, 8.937016214643206, 5.1231778008597235, 1.6676866497312273, 1.7559539590563094, 6.855466195515223, 23.4524336201804, 35.77927964074271, 37.387151854378835, 33.067265714917866, 21.560338394982473, 9.448661582810537, 8.309893522943769, 6.336670696735382, 7.161909980433328, 16.904558965138026, 13.36557912826538, 17.517421347754343, 14.217418721743993, 11.33822158404759, 11.659106765474592, 14.639571292059761, 13.991544076374598, 8.805419938904897, 17.39767609323774, 14.935630559921265, 21.84970133645194, 21.343024798801967, 17.419071333748953, 24.02678213800703, 18.805462769099645, 10.61554639680045, 11.024620720318385, 7.555381689752851, 4.2964242441313605, 3.3382474652358463, 1.948387576001031, 0.734315536916256, 0.386702942528895, 0.14624671531575067, 0.1545543588165726, 0.1394229329058102, 0.5243965068033763, 5.567708347524915, 24.517550774982997, 42.72408056259155, 62.82967635563442, 52.281977381025044, 19.7908684526171, 21.41169384547642, 22.697414568492345, 28.366849320275442, 33.56354079927717, 51.61304303577968, 51.50214283806937, 51.64822176524571, 61.042516299656455, 69.18748651232038, 74.1697826385498, 73.479750088283, 70.76041970934186, 37.82393993650164, 7.378138354846409, 0.24969516002706119, 0.22735795006155968, 0.15470660850405693, 0.18976564439279692, 0.14797658606299333, 0.17826195167643683, 0.1599347751055445, 0.09921655072165386, 0.2392177108143057, 0.2560350384031023, 0.11330346696610961, 0.1455476206860372, 0.17040123205099786, 0.12202644853719644, 0.24282162742955343, 0.17029941108609947, 0.16917548568121024, 0.3282033715929304, 0.1675293461552688, 0.11145088316074439, 0.24798989295959473, 0.14466069399246148, 0.1632166997130428, 0.1778843333678586, 0.15956223223890575, 0.16163888866347925, 0.15056374509419712, 0.22058752764548573, 0.15289566639278615, 0.14056448665048393, 0.19636751871023858, 0.25004153858338085, 0.3265084725405489, 0.17228924216968672], [0.07649058090256793, 0.3669760839215347, 0.24655270150729588, 0.08085703517177276, 0.04338633654905217, 0.008546599785664251, 0.052917361725121737, 0.049770329879330735, 0.04573519408170666, 0.02467160452423351, 0.05851205598030772, 0.04449843169589128, 0.07710327088300671, 0.04898239805230072, 0.07424968507673059, 0.1641304421105555, 0.07033819532287972, 0.04221176529037101, 0.06857888294117791, 0.012765404834811176, 0.05928608801748071, 0.08376459165343217, 0.12500692717731, 0.19339324188019547, 0.14328805836183683, 0.05315375993294375, 0.03300188056060246, 0.20626104782734597, 0.0746060177417738, 0.07412855979055166, 0.04733015171119145, 0.24737410885947092, 17.837005478995188, 45.58741930552891, 64.93719005584717, 59.828485352652415, 54.73456989015852, 49.92146239961897, 36.906819411686485, 33.519371100834434, 48.14656244005476, 53.03403302601406, 63.39923409053257, 80.76128155844552, 85.38106931958879, 35.92529603413173, 28.763914551053727, 20.317767722266062, 10.257610814911978, 3.936248302459717, 0.35067194593804224, 0.051930608959602456, 0.09752241841384343, 0.12896685754614218, 0.24762394545333727, 1.4673091790505817, 0.6561002082058361, 2.66165338243757, 3.4629791378974915, 3.1448504371302466, 2.5842966990811482, 5.171256295272282, 5.227837647710528, 5.8378708107130866, 4.825463558946337, 3.951457909175328, 5.298574651990618, 4.255302199295588, 5.364830936704363, 4.282376723630088, 3.3207836023398807, 5.178147171224866, 3.2325590678623746, 6.681787720748356, 9.139653478349958, 4.562761723995209, 2.2409258442265645, 1.5474619695118494, 2.813671499490738, 2.5594814249447415, 4.9470566000257215, 6.539026124136789, 6.962548358099801, 8.195118835994176, 20.233590296336583, 37.222406591687886, 55.576100962502615, 54.30690826688494, 62.203032221112935, 52.41683496747698, 27.77638098171779, 15.557522126606532, 5.984537729195186, 7.0972443989345, 5.630434078829629, 6.83248633146286, 7.839736717087882, 4.2518046498298645, 2.8999611777918677, 4.813087514468601, 2.162666980709348, 3.238672831228801, 8.100790960448128, 6.06830130304609, 6.624004329953875, 4.7528053777558465, 8.756865058626447, 8.62587240764073, 7.098116397857666, 6.732195164476122, 13.679139171327863, 2.9795258683817725, 2.8035397231578827, 5.579979734761374, 3.536358194691794, 2.4474719039031436, 1.3085273163659232, 0.4984249004295894, 0.05625586936782513, 0.007902254450267978, 0.10887915401586465, 0.14434175539229596, 0.22732772811182908, 3.2146711477211545, 11.004013231822423, 34.89503451756069, 46.641176155635286, 30.62169783455985, 27.24243450164795, 29.57711260659354, 18.920995678220475, 17.992462737219675, 28.499247244426183, 19.56229703766959, 28.305891036987305, 40.64818811416626, 46.10368088313511, 45.3855220249721, 51.798806599208284, 59.26149150303432, 52.90949004037039, 31.51864426476615, 4.671280426638467, 0.30355366000107353, 0.0354616141079792, 0.002523345357206251, 0.13711261616221496, 0.07484341678874833, 0.043626700794058185, 0.10952720924147538, 0.05339578998142055, 0.08361303407166686, 0.021003055752121975, 0.15569440621350492, 0.16845794846968992, 0.09126346890947648, 0.017452258250809143, 0.007706888103192406, 0.03891670424491167, 0.09570070116647653, 0.02169687477206545, 0.09049198816397361, 0.020039130600967577, 0.10440174570041043, 0.029062611583088125, 0.06409708450415305, 0.06621600687503815, 0.040003954832042964, 0.012425027072562702, 0.2089133733617408, 0.02654596251834716, 0.015153770068926471, 0.03419253309922559, 0.14033073133655957, 0.32158450675862177, 0.07183887051152331, 0.0659513578617147, 0.22136131541005202, 0.03577645435663206, 0.032094557104366164, 0.0332115580593901, 0.1171523415084396, 0.08361077455005475, 0.00512223583479811, 0.05708603321441582, 0.03240792493202856, 0.10085065982171468, 0.062227204841162474, 0.1043296717107296, 0.04577181461666312, 0.13427152218563215, 0.0990786791912147, 0.06897590735128947, 0.05046108531366501, 0.009497605630063584, 0.014406952375013913, 0.021220838351707374, 0.08301544828074318, 0.13985781956996235, 0.1640882643737963, 0.07644418267799274, 0.03340980563578861, 0.03439342017684664, 0.08510224880384547, 0.06333985977939197, 0.04185848603291171, 0.08211268457983222, 0.17879495450428554, 20.68440158026559, 54.09843799046108, 73.01046875544957, 67.39288493565151, 64.13149084363664, 56.22212709699358, 47.246617862156455, 44.66907589776175, 58.87544958932059, 50.08879239218575, 51.11662203924996, 71.62433787754604, 65.68076542445591, 34.39007418496268, 37.27268375669207, 28.16508752959115, 11.522347109658376, 4.0118585995265414, 0.48533074877091814, 0.0635864936879703, 0.24424850514956883, 0.37500692584684914, 0.7350310385227203, 2.9170257364000594, 2.6973818881171088, 6.628477667059217, 5.875144422054291, 7.319789120129176, 7.436481509889875, 8.885158334459577, 7.097284351076398, 10.488048689705984, 8.879467759813581, 6.641304041658129, 6.749936521053314, 6.916279869420188, 6.881691302571978, 6.5231177892003736, 7.361123085021973, 5.925950084413801, 4.515794507094792, 7.331049544470651, 5.972186003412519, 3.775911237512316, 3.6019431097166876, 2.405333033629826, 3.6399141464914595, 4.825748435088566, 6.719175977366311, 6.778659505503518, 7.730511903762817, 9.69165050983429, 23.058343955448695, 46.78024435043335, 68.4804447719029, 66.21116311209542, 73.48193877083915, 59.260025433131624, 31.193030834197998, 17.946496929441178, 7.837391700063433, 8.055751868656703, 5.671359837055206, 5.750231879098075, 6.893864112240927, 1.5002439660685403, 2.1503280656678334, 5.472975739410945, 3.867379060813359, 4.9942934938839505, 6.078902951308659, 7.448134507451739, 5.842560844761985, 8.451786160469055, 8.6082752261843, 8.194718446050372, 10.261871797697884, 11.496818559510366, 8.012992654527936, 5.035907992294856, 7.263662874698639, 8.292382325444903, 3.347099687371935, 7.602288109915597, 3.968957381589072, 2.637397655418941, 0.7810207850166729, 0.20482180719929083, 0.06347503074045692, 0.10142415083412613, 0.10865709664566175, 1.6875292935541697, 7.888540863990784, 27.923644576753887, 37.87404339654105, 26.415258407592773, 23.402502128056117, 23.550052336284093, 22.53122408049447, 25.51743129321507, 43.2255528994969, 31.185776914869034, 35.19528007507324, 46.82491431917463, 52.63111046382359, 52.95151274544852, 60.053259577069966, 66.11374936785016, 61.55086040496826, 37.0828138078962, 6.273797316210611, 0.28410147236926214, 0.025545973230951598, 0.05947970798505204, 0.10695359376924378, 0.0663995166708316, 0.05999373218842915, 0.0342737571336329, 0.08074030679251466, 0.1046480064147285, 0.06577894211347614, 0.07834257438246693, 0.0240262753130602, 0.11730564971055303, 0.060950018731611114, 0.035288974443184476, 0.12073755769857339, 0.043925405479967594, 0.031603820222829065, 0.010584858761701201, 0.023950700082683136, 0.06954890303313732, 0.0422059977427125, 0.04960775288886257, 0.03148148714431694, 0.06190378790987389, 0.07022802159190178, 0.24364140629768372, 0.054497608715402227, 0.005281107599980065, 0.048544251027383974, 0.021530408079602888, 0.15002654891993317, 0.04750296440241592, 0.23897666803428105, 0.5759758076497487, 0.34157884387033327, 0.3581638682101454, 0.08946210092731885, 0.26007270174367086, 0.15116359719208308, 0.17839491739869118, 0.17558566028518335, 0.0977006492071918, 0.14264870195516519, 0.13529593364468642, 0.21715739741921425, 0.28647862481219427, 0.22173612458365305, 0.42172156487192425, 0.22021270490118436, 0.1338908640401704, 0.19556633170161927, 0.1331470132406269, 0.1085802186280489, 0.24209035666925566, 0.3140006022793906, 0.35989671094076975, 0.23240568063088826, 0.15489828107612474, 0.13359342142939568, 0.24122310749122075, 0.14332847190754755, 0.15030924017940248, 0.2429705522954464, 1.0116218881947654, 28.355879851749965, 68.65580340794155, 82.92398480006626, 75.91093172345842, 70.43721035548619, 65.50963129316057, 52.03518431527274, 46.11539902005877, 61.590367862156455, 65.72338567461286, 77.95189557756696, 90.57563291277204, 94.6113828931536, 46.82421255111694, 40.10663856778826, 29.924501691545757, 14.82051454271589, 5.470719311918531, 0.6229909562638828, 0.1772468090057373, 0.35093269337500843, 0.26146820400442394, 0.55940109704222, 2.345501009907041, 3.5342646156038557, 7.996080739157541, 9.521665436880928, 10.27001508644649, 13.38136282988957, 16.004430259977067, 15.689459732600621, 17.747057574135916, 13.92986752305712, 13.348444870540074, 13.119847399847847, 14.335561547960554, 14.52285371507917, 14.172430004392352, 13.194681235722133, 14.42822619846889, 8.760895882334028, 15.72443175315857, 22.058670146124705, 13.817283255713326, 8.846408230917794, 4.526748776435852, 6.128058850765228, 5.6299029758998325, 8.330759831837245, 9.737737911088125, 10.725268006324768, 11.034583568572998, 27.990585259028844, 41.27138941628592, 57.3450219971793, 56.066661153520855, 61.44140543256487, 49.21417399815151, 31.96758474622454, 22.492246423448833, 12.537141936165945, 12.642607774053301, 11.24963639463697, 13.284054177148, 14.70392724445888, 11.743323275021144, 9.170549511909485, 12.300759877477374, 9.535247428076607, 11.256078243255615, 17.043849502290996, 18.2700971194676, 16.275981494358607, 15.70016690662929, 20.04587950025286, 23.31420268331255, 18.476719175066265, 21.23736354282924, 28.14701005390712, 10.55863891329084, 12.15982174873352, 14.64960275377546, 9.925360117639814, 9.701526505606514, 3.3556731130395616, 1.6151679307222366, 0.4574798175266811, 0.14265187749905245, 0.3031577212469918, 0.3104497471026012, 0.37177221370594843, 3.7952207156590054, 13.211299589702062, 44.737484386989046, 59.74261256626674, 42.65267392567226, 37.77495513643537, 39.79111392157418, 28.884439740862163, 27.03413098199027, 40.233213901519775, 29.19524656023298, 40.870641640254426, 53.70169932501656, 61.50393227168492, 62.485684939793174, 68.43122373308454, 75.2540351322719, 71.44243403843471, 45.04556056431362, 9.101861357688904, 0.5081585124135017, 0.2838929992701326, 0.1953770611435175, 0.31147107801267077, 0.20311959353940828, 0.1468898986599275, 0.17381363894258225, 0.41335262251751764, 0.33853102741496904, 0.21594052628747054, 0.28261102948869976, 0.2422041877039841, 0.19796446444732801, 0.16075345474694455, 0.1791297301117863, 0.29501350969076157, 0.22690614073404244, 0.14469935691782407, 0.15314216459436075, 0.13334528117307595, 0.1414278953203133, 0.17389678662376745, 0.241301491856575, 0.15705087913998536, 0.15540598811847822, 0.13152901934725897, 0.3605554870196751, 0.1476759814790317, 0.11896378573562418, 0.2508367273424353, 0.282270214919533, 0.5237395220569202, 0.209720232923116], [0.12319063821009227, 0.24129592786942208, 0.23279385694435664, 0.2044287725750889, 0.06167071791631835, 0.0853065149858594, 0.06244757265916892, 0.03627930648092713, 0.048441490291484764, 0.056549983764333386, 0.10987238679081202, 0.06136830842920712, 0.02067354727270348, 0.051997526083141565, 0.04105172146643911, 0.07224530620234353, 0.11674769036471844, 0.0363611513748765, 0.025567621890721575, 0.021726604783907533, 0.047395006088273864, 0.06505843291857413, 0.07047783104436738, 0.1824304772807019, 0.05126917641609907, 0.10915302432009152, 0.06554984154977969, 0.09350414081875767, 0.1829883959144354, 0.08830542942242962, 0.09194887070251362, 5.6425838725907465, 35.76313550131661, 63.0480443409511, 67.11737496512276, 60.14810248783657, 48.63957187107631, 49.90914324351719, 31.560642651149205, 20.85287628855024, 24.548411199024745, 65.69455759865897, 70.14945765904018, 68.58394513811383, 41.159273283822195, 37.72600507736206, 33.86775030408587, 12.002336485045296, 4.228790479046958, 0.19948287654135907, 0.10778431062187467, 0.21193149712468895, 0.054582873425845585, 0.15524242046688283, 1.2467772641352244, 2.1769539969308034, 3.054529066596712, 2.6002213188580106, 7.193769642284938, 2.8513426780700684, 3.0671973696776798, 6.286017460482461, 6.829503817217691, 3.119238942861557, 6.694501621382577, 5.303183478968484, 6.554849777902875, 4.377636526312147, 5.10452492747988, 6.084890561444419, 2.802281230688095, 4.2994992562702725, 3.8966765744345526, 6.2667175361088345, 6.341364639145987, 9.581002184322902, 10.514239924294607, 17.49268923486982, 18.679389442716325, 23.771998643875122, 26.741547550473893, 24.835578509739467, 16.894400698798044, 27.387914146695817, 29.862871170043945, 46.65524278368269, 43.35139519827706, 53.21932063783918, 49.06513513837542, 55.13972282409668, 44.20464093344552, 37.59976325716291, 24.00883146694728, 23.78072558130537, 19.06205800601414, 14.925970826830183, 16.337631123406545, 10.227024844714574, 5.567375702517373, 4.559735783508845, 3.2997783294745853, 4.795700516019549, 4.87618236882346, 6.336598174912589, 5.956931667668479, 7.147558041981288, 6.182496249675751, 7.530697345733643, 9.754261595862252, 5.570124583584922, 3.32929709979466, 1.4499775490590503, 3.836423533303397, 4.877749187605722, 4.741483722414289, 9.991612928254263, 3.1276649364403317, 3.3218597045966556, 0.9341936601059777, 0.23110340908169746, 0.08741577501807894, 0.06364351098558732, 0.20193160085805825, 0.40463494030492647, 2.532441641603197, 8.338481886046273, 20.11881126676287, 43.30466161455427, 50.909645625523154, 38.92678580965315, 29.85495022365025, 23.313655512673513, 11.133698752948217, 18.706635066441127, 20.48366638592311, 26.731415339878627, 27.683363710130962, 37.796220098223, 45.63594552448818, 57.422786235809326, 60.10050732748849, 59.20022923605782, 23.158860070364817, 2.4946034891264777, 0.048179772549441884, 0.02184649004733988, 0.04882736297856484, 0.058327148402375836, 0.05450323037803173, 0.034216095227748156, 0.1383942195347377, 0.12614483040358337, 0.07630486586796385, 0.17759827657469682, 0.07339740438120705, 0.034180811406778436, 0.08161177645836558, 0.016747392680762068, 0.09987206304711954, 0.054198846354016235, 0.024800538052139536, 0.06774470555995192, 0.02874745920832668, 0.08819214800106627, 0.049226704585765085, 0.05046587237822158, 0.0823421176256878, 0.111069838250322, 0.06305857308741127, 0.20007061000381196, 0.06598275367702756, 0.03393178226958428, 0.21353077702224255, 0.08516413798289639, 0.09762983050729547, 0.07833172460751874, 0.04906015477276274, 0.1452375573239156, 0.07895113886999232, 0.08128890235509191, 0.06543467380106449, 0.06347570927547556, 0.03896857485441225, 0.05692354443350008, 0.10452388200376715, 0.08042265740888459, 0.05723757044013057, 0.1058886805549264, 0.11172337603888341, 0.012409399562914456, 0.09658063216400997, 0.06420105642506055, 0.008582930246900235, 0.06814255099743605, 0.06606227119586297, 0.043625859410635064, 0.03837464975991419, 0.13944620665694984, 0.18523425183125905, 0.2296163317348276, 0.02914566426937069, 0.036177824783538065, 0.030177485330828598, 0.05594029290867703, 0.13119558723909513, 0.07540995960256883, 0.07080411139343466, 7.721949986049107, 42.86946814400809, 72.16872923714774, 75.68780422210693, 69.35716847011021, 55.343534333365305, 56.482208592551096, 35.48326901027134, 31.676583766937256, 33.48569665636335, 59.90918173108782, 67.3393143245152, 71.44326087406704, 50.754016399383545, 39.613997391292024, 32.53918177740914, 10.042987040110997, 3.942199868815286, 0.14709667542151042, 0.026589736508737718, 0.2921785089586462, 0.25819204694458414, 0.8175596243568829, 3.6276438449110304, 4.463230516229357, 5.560519133295331, 7.435011097363063, 7.844827141080584, 6.6543188861438205, 7.225452993597303, 7.668513127735682, 9.023384928703308, 5.1785540751048496, 6.467351981571742, 7.741781881877354, 7.411915285246713, 7.767133252961295, 8.000623992511205, 5.429515191486903, 3.121522511754717, 3.7224500605038235, 1.815518585698945, 1.5355732760259082, 6.623501454080854, 10.50907220159258, 12.99131006853921, 18.11772312436785, 21.789917298725673, 24.409049442836217, 30.461493219648087, 26.03567658151899, 20.214602606637136, 30.269962651388987, 38.05207708903721, 58.50384603227888, 49.1810484613691, 57.706279686519075, 57.875416210719514, 67.1323413848877, 52.09569617680141, 39.33867849622454, 26.83581723485674, 26.422694717134746, 21.174933978489467, 17.33951793398176, 18.131308589662822, 10.570399607930865, 6.002242607729776, 3.5064383830342973, 3.5958990454673767, 3.372117979185922, 8.206880399159022, 5.661376144204821, 4.214283508913858, 5.552810975483485, 6.741811037063599, 8.790897335324969, 7.6231518132346014, 8.821016907691956, 9.387150049209595, 5.94084050825664, 11.094923462186541, 11.951301097869873, 9.086899280548096, 14.674041305269514, 5.603912370545523, 5.049744027001517, 4.610055940491812, 1.6680467618363244, 0.4793802137885775, 0.0952309106609651, 0.08710898898009743, 0.3311993751142706, 1.680846972124917, 7.394424932343619, 19.97692210333688, 38.60290595463344, 37.44735452107021, 33.92972476141793, 27.505970988954815, 22.879625865391322, 15.643019710268293, 22.616372517177037, 30.168908051082067, 38.28591871261597, 38.91700969423567, 47.47218765531267, 53.065338134765625, 65.23396151406425, 68.12141050611223, 65.53915418897355, 29.078247581209453, 2.554300022976739, 0.056898201150553565, 0.03723746917343565, 0.056375997207526646, 0.01680416740210993, 0.09630257529871804, 0.032299610387001715, 0.08923713942723614, 0.15211923234164715, 0.08644483211849417, 0.11444006061979703, 0.06941352172621659, 0.026012120003412877, 0.04172148981264659, 0.060385294391640594, 0.029747741962117807, 0.08279740783785071, 0.03637333447113633, 0.012310023868589528, 0.054145903659186194, 0.044512921811214516, 0.046020786078380685, 0.06410340845052685, 0.05990141071379185, 0.023033549743039266, 0.06835892224418265, 0.14434812005077088, 0.024021262635609934, 0.021769932637523328, 0.11545783600636891, 0.03507705099348511, 0.09564848111144134, 0.06148755417338439, 0.19000480084546975, 0.3978181332349777, 0.4075625203549862, 0.2569311117487294, 0.18575931579938956, 0.25344957570944515, 0.19061309391898767, 0.2295648173562118, 0.25340856505291803, 0.13318027502724103, 0.15409626625478268, 0.18842401781252452, 0.2520663413618292, 0.15794955806008407, 0.2809689747435706, 0.1394524084670203, 0.2966313271650246, 0.10327374230005912, 0.18078957604510443, 0.10211044829338789, 0.19133246317505836, 0.1872458096061434, 0.4306770328964506, 0.34439826543842045, 0.2019017453172377, 0.22075043033276284, 0.14176402799785137, 0.17232714513582842, 0.38571667830858913, 0.24092053515570505, 0.2816119002444403, 9.75750206198011, 57.413583346775596, 81.26908370426723, 81.95842838287354, 77.34277479989188, 64.46082156045097, 64.18127468654087, 44.2938106400626, 31.3442861693246, 34.95732511792864, 75.98402677263532, 78.91677107129777, 76.65985025678361, 51.470087323869976, 51.883737904684885, 44.38468960353306, 16.383372851780482, 6.719444351536887, 0.40879397998963085, 0.2673788411276681, 0.33950686933738844, 0.2769253674362387, 0.6543562646423067, 4.382681352751596, 6.561453172138759, 11.685028757367816, 11.184616020747594, 16.266453777040752, 11.00783039842333, 7.808901480266026, 16.836685487202235, 13.991369502885, 9.65185296535492, 14.485058120318822, 14.558292133467537, 16.567593915121897, 12.744468365396772, 12.818700313568115, 14.979791573115758, 9.601212756974356, 12.134083884102957, 10.14177131652832, 12.596859097480774, 10.337461250168936, 12.573552233832222, 18.865073101861135, 24.38538040433611, 22.88278729575021, 25.24447478566851, 34.268227100372314, 31.724460329328263, 25.38975293295724, 33.759615489414756, 44.44883189882551, 59.65243884495327, 56.02666384833199, 60.34427792685372, 62.234090668814524, 63.34720597948347, 53.788013322012766, 42.3993148122515, 31.363331181662424, 29.419249534606934, 24.4351190839495, 20.24496623447963, 22.4996132510049, 15.84304792540414, 11.379272409847804, 9.579415389469691, 10.150175162724086, 14.697958741869245, 13.49314284324646, 11.6917268208095, 16.720621040889196, 16.15296711240496, 16.25390359333583, 18.961486305509293, 21.208936725343975, 15.769403968538557, 13.457103405679975, 7.116041013172694, 15.363959210259573, 15.25876522064209, 16.637242657797678, 30.115115097590856, 9.139234849384852, 9.849818434034075, 4.114440066473825, 0.6664566067712647, 0.40318526380828446, 0.22879394729222569, 0.46835836235966, 0.914893627166748, 2.948014267853328, 10.837271230561392, 26.082596029554093, 55.63750914164952, 65.70697402954102, 53.70380115509033, 41.30280917031424, 33.74525703702654, 18.604003225054058, 28.603108916963848, 31.55292320251465, 38.96844373430525, 43.023245675223215, 52.311913694654194, 60.51418917519705, 72.31505135127476, 75.4523367200579, 75.1636529650007, 37.30257838112967, 3.960447141102382, 0.2000195841704096, 0.11181079849068608, 0.3296737569783415, 0.2259286567568779, 0.23221816069313458, 0.2308044194110802, 0.4567109559263502, 0.2452185388122286, 0.30747732945850914, 0.3612922132015228, 0.22234498762658664, 0.27487380323665483, 0.48265976352351053, 0.1509127835077899, 0.17866797346089566, 0.26285567241055624, 0.17528895049222878, 0.15798264342759336, 0.09575325370367084, 0.20376713307840483, 0.1257363794637578, 0.19739688347492898, 0.1883544544024127, 0.1153100917914084, 0.20967333258262702, 0.3981518910399505, 0.11464751591639859, 0.2538269768868174, 0.42931361177137917, 0.21507242215531214, 0.2725170339856829, 0.17426703604204313], [0.035647559844489606, 0.08019365862544094, 0.1563508752733469, 0.07061928523970501, 0.00893512724100479, 0.10751248270805393, 0.14839916410190718, 0.06122273552630629, 0.07235539850911923, 0.022627280293298618, 0.04052088995065008, 0.04421466835109251, 0.0348228276707232, 0.023208208049514463, 0.07633188513240644, 0.05477759940549731, 0.07849001325666904, 0.0794929422970329, 0.02750031862940107, 0.0521952579729259, 0.060815417739961825, 0.0619204527299319, 0.11820550928158419, 0.21944300191743032, 0.07041656611753361, 0.042405751666852405, 0.0665942562211837, 0.21663027070462704, 0.06644533135529075, 0.15984999894031457, 0.7958897671529225, 24.620205198015483, 60.09117589678083, 65.6355812890189, 67.91903727395194, 51.769704069410054, 43.75035381317139, 31.453470161982946, 30.74976008278983, 24.424034970147268, 41.54634353092739, 69.63499913896833, 64.92043794904436, 43.71938221795218, 25.36750306401934, 26.621639013290405, 7.964424746377127, 2.1590174393994466, 0.08547882895384516, 0.06774655796055283, 0.11803644549633775, 0.36058688962033814, 0.5781450026801654, 1.2803614905902316, 1.715189203619957, 4.358224127973829, 2.4633374639919827, 7.945567335401263, 4.832472554274967, 7.681492362703596, 7.6349698305130005, 6.682535086359296, 5.833735764026642, 7.74008652142116, 5.9139774697167535, 4.2830098782266885, 2.548394271305629, 6.33883592912129, 4.713871581213815, 3.510334368262972, 5.733672150543757, 6.993996773447309, 5.42667554957526, 16.49594235420227, 23.818209375653947, 30.53710699081421, 36.34393889563424, 36.794758864811485, 41.71225956508091, 48.51488297326224, 53.763176986149375, 44.90520347867693, 25.894881759371074, 34.93579612459455, 32.14470475060599, 36.28708873476301, 37.606746196746826, 51.529213019779746, 39.059965406145366, 48.17987905229841, 34.94193485804966, 47.24665607724871, 41.37192637579781, 46.42870371682303, 31.83124371937343, 33.900326933179585, 37.73103557314192, 23.56103570120675, 20.907626356397355, 15.253606183188301, 8.804053749356951, 7.23568378176008, 6.761780159814017, 5.001888743468693, 3.8139348200389316, 8.925289392471313, 7.652442812919617, 4.209380686283112, 4.79375067778996, 4.7935726302010675, 6.789905599185398, 5.045275466782706, 7.232170598847525, 6.5875254188265115, 0.9232193061283657, 7.3079537323543, 8.115252767290388, 7.848098874092102, 4.409866179738726, 2.685524352959224, 0.8650081125753266, 0.3788543551095894, 0.12087076769343444, 0.10276038984635047, 0.04716568500069635, 1.0288391986063548, 4.3009887763432095, 11.939807040350777, 32.60248681477138, 37.80558279582432, 40.507368973323274, 42.90398332050869, 39.81819452558245, 29.25589738573347, 16.25049376487732, 15.542823212487356, 21.00422716140747, 23.69752958842686, 39.36722864423479, 44.697705950055806, 55.07302359172276, 54.91194002968924, 41.680221421378, 18.10304852894374, 0.9723326478685651, 0.04825583632503237, 0.0803074421627181, 0.11879834532737732, 0.0687365744795118, 0.1454061054225479, 0.05006846798849957, 0.15111179782875947, 0.018855276983231306, 0.05080065137839743, 0.07967006029295069, 0.007717921082595629, 0.05934005190751382, 0.07053443443562303, 0.024489992930154716, 0.02287575472811503, 0.11417285352945328, 0.05859538008059774, 0.06197017577609845, 0.06788584084383079, 0.05267063621431589, 0.1054398567814912, 0.040207854605146816, 0.051740968599915504, 0.06555980922920362, 0.15586743264326028, 0.04019205830991268, 0.03532368829473853, 0.09244633865143571, 0.06957706902176142, 0.06600430394921984, 0.008902925665357282, 0.05472279413204108, 0.06789881443338734, 0.08709450225744929, 0.08415591636938707, 0.03862435403945191, 0.08437944616058043, 0.03011451049574784, 0.05328016422156777, 0.07922140615327017, 0.09896248685462133, 0.04757199176986303, 0.05154831554474575, 0.059790341316589286, 0.019006600470415184, 0.028370661927121024, 0.01837788688551102, 0.024314206559211016, 0.0712646534666419, 0.059519280147339614, 0.05331160414165684, 0.04135177982971072, 0.03248477241556559, 0.029445105165775334, 0.113057477665799, 0.12014478950628213, 0.07766809700323002, 0.061016135183828216, 0.18673130364290305, 0.07265724481216498, 0.32108936618481365, 1.748880910021918, 31.43100663593837, 67.249390738351, 75.53957830156598, 74.6121049608503, 59.673943519592285, 50.393599442073274, 41.450854437691824, 38.43825796672276, 22.433132886886597, 33.540458883558, 66.855726650783, 62.90490450177874, 50.41679947716849, 26.637350627354213, 27.344769307545253, 9.140640991074697, 2.295695888144629, 0.056902133260986636, 0.19871406922382967, 0.2829905476953302, 1.0225431535925185, 2.561288825103215, 4.188127883843013, 3.655756039278848, 4.446975205625806, 5.041220324380057, 9.439408319337026, 9.803401861871992, 10.132369535309927, 8.694631780896868, 10.476015278271266, 9.782811743872506, 6.949398023741586, 6.645856848784855, 6.194899218423026, 7.1714290125029425, 7.1851586529186795, 5.911653297288077, 5.356103999274118, 3.8864197305270602, 2.522912838629314, 6.094096490315028, 15.877015931265694, 25.087363856179373, 31.950301102229528, 40.2052960395813, 40.497200284685405, 46.259296212877544, 50.72032805851528, 56.80144705091204, 48.432147298540386, 28.51653609957014, 38.108531202588765, 38.99933195114136, 42.44511386326381, 44.943467208317344, 56.95694426127842, 46.58823783057076, 59.51485756465367, 43.68593011583601, 50.885542324611116, 46.94279745646885, 48.367438725062776, 36.491713183266775, 38.708879879542756, 39.52443858555385, 27.003760405949183, 20.29346466064453, 14.861293520246234, 8.074364355632238, 6.1311043330601285, 7.17749913249697, 5.9459391832351685, 5.321589257035937, 5.216746151447296, 7.608601416860308, 4.922775685787201, 5.882868213312967, 6.507240286895207, 5.918585428169795, 6.272350788116455, 8.575409378324236, 8.568086845534188, 8.936462095805577, 14.728671516690936, 8.44810448374067, 8.694675207138062, 5.945275630269732, 3.4712018966674805, 2.9496132220540727, 0.9067005068063736, 0.10838406093950782, 0.08246173656412534, 0.0786137848294207, 0.7638770820839065, 4.023926317691803, 11.538732698985509, 30.608176640101842, 38.688229833330425, 38.098143645695274, 33.307711601257324, 28.969923428126744, 25.822472844805034, 19.400565556117467, 20.752568619591848, 30.354153973715647, 32.37071575437273, 48.10453626087734, 53.24241644995553, 61.63489191872733, 62.4716773714338, 50.03330755233765, 20.364509991237096, 1.1953519093138831, 0.09037972454513822, 0.054766712311123095, 0.1282637052770172, 0.07537815666624478, 0.08871996003602232, 0.10609664475279194, 0.08946174808910914, 0.028614971853260483, 0.10021036703671728, 0.07278877882552998, 0.04145543962450964, 0.04641249077394605, 0.07548549412084476, 0.02687457193886595, 0.034993187457855256, 0.01844552155983235, 0.08470269345811435, 0.1289106205637966, 0.009418636876424509, 0.06770723007087197, 0.052385424197252305, 0.028158824990636537, 0.11405507342091628, 0.04537985207779067, 0.07685954788965838, 0.008095637778751552, 0.013132595756490315, 0.08609252316611153, 0.02415364821042333, 0.06640449711786849, 0.09672752821019717, 0.17227723209985665, 0.2808404602110386, 0.46902848354407717, 0.25929311929004534, 0.11424962298146316, 0.2074058721108096, 0.2497271325971399, 0.1524039592061724, 0.1606499645859003, 0.2620444159422602, 0.1407086889126471, 0.1581033005246094, 0.16816274502447673, 0.09195537106799227, 0.11254725325852633, 0.0928041437374694, 0.2009922776903425, 0.1562387134347643, 0.19237025534468039, 0.10924622789025307, 0.1826550452304738, 0.11801919713616371, 0.2177823553127902, 0.33028359711170197, 0.26606913283467293, 0.22211957829339163, 0.18201647592442377, 0.2813783213496208, 0.2448688761464187, 0.36347432753869463, 2.873741064752851, 40.641726289476665, 79.03603690011161, 83.63107517787388, 84.83950587681362, 67.57006399972099, 59.23674896785191, 44.57529258728027, 41.3367337499346, 34.96467283793858, 54.43351139341082, 81.42173562731061, 71.27536460331508, 54.26326663153512, 36.659109183720176, 34.461803913116455, 11.014227083751134, 2.489942333527974, 0.1665273942053318, 0.2890177842761789, 0.2913085999233382, 0.8979739493557385, 2.0058376703943526, 5.406060678618295, 5.953826691423144, 12.180759276662554, 8.264196957860674, 17.57251708848136, 14.914447239467076, 17.92698117664882, 19.045691524233135, 19.02706687791007, 16.41403525216239, 17.358866930007935, 13.468595726149422, 13.101784689085823, 11.649783151490347, 16.441798516682216, 13.980707492147173, 12.499305520738874, 14.2127252135958, 14.745211703436715, 9.257659077644348, 21.583397729056223, 28.874477761132376, 34.39009850365775, 43.92308950424194, 46.3280416897365, 52.090888023376465, 59.1507511138916, 56.86838599613735, 50.87641586576189, 32.69225754056658, 46.05387966973441, 44.226249831063406, 46.52403647559029, 49.731116499219624, 60.14952686854771, 50.937018053872244, 64.51623344421387, 46.03238889149257, 55.226936612810405, 50.95215470450265, 54.763578619275776, 41.89661264419556, 42.9159620148795, 44.875895977020264, 29.915479455675396, 24.308694873537334, 19.635756867272512, 15.281765495027814, 13.273653592382159, 11.54343923500606, 10.842987860952105, 10.954046130180359, 17.170640230178833, 15.65325961794172, 10.398317916052681, 11.83995360987527, 12.60236120223999, 11.375520382608686, 8.997750418526785, 11.792367134775434, 11.91594866343907, 9.945338794163295, 20.260405131748744, 19.871543986456736, 18.155757563454763, 12.306935088975088, 7.575865847723825, 2.0961030210767473, 0.8316007394875798, 0.22798991043652805, 0.24880484065839223, 0.15314915350505284, 1.5570742594344276, 6.0360421197755, 16.177558524268015, 42.035229206085205, 50.88780396325247, 55.34246778488159, 58.290987968444824, 55.04385852813721, 39.51782390049526, 25.222120693751744, 23.68644026347569, 30.23260566166469, 37.20035648345947, 52.78595454352242, 59.930874007088796, 69.06236335209438, 71.17117636544364, 59.00107996804373, 27.182181460516794, 1.9744893525327956, 0.30955022679907934, 0.2174989990890026, 0.29508776856320246, 0.16700413290943417, 0.19894359047923768, 0.19000600863780293, 0.2754807663815362, 0.13240210392645427, 0.2768216872853892, 0.22239207795688085, 0.14573971394981655, 0.1543194092810154, 0.10743966232985258, 0.11795004084706306, 0.12349323768700872, 0.30342449407492367, 0.20153904120836938, 0.2932142790939127, 0.1524677143565246, 0.15718472695776395, 0.21893296071461268, 0.11584225323583398, 0.2354420976979392, 0.22752828949264117, 0.25919424316712786, 0.1800149604678154, 0.06065117155334779, 0.21342856250703335, 0.2649147819195475, 0.24993780414972985, 0.2226149495691061], [0.023098943555461507, 0.08250662165560893, 0.011384078018766428, 0.050510350348693986, 0.09080881652023111, 0.04376933903300336, 0.0472969408147037, 0.034923274602208815, 0.12413807665663106, 0.06814902422151395, 0.050739847855376344, 0.020495218091777394, 0.060861198497670035, 0.008200295020027884, 0.06762024188148123, 0.09898129584533827, 0.08394010152135577, 0.0993595587621842, 0.05090833827853203, 0.032033421099185944, 0.012470175096366023, 0.03653086316106575, 0.039433639363518784, 0.08198976117585387, 0.007734730091345097, 0.07297594592507396, 0.026813035598024726, 0.11997686565986701, 0.08769942301192454, 0.7763680975352014, 17.687016453061783, 57.842645032065256, 62.857635906764436, 76.07239396231515, 55.14207131522042, 56.35980565207345, 47.409230027879985, 28.344653299876622, 21.74936066355024, 41.85407229832241, 73.21070889064244, 73.50249849046979, 79.94247109549386, 30.3255204473223, 32.88958290645054, 13.63460990360805, 2.0393010633332387, 0.11021345241793565, 0.06332364957779646, 0.05618895563696112, 0.10486696287989616, 1.4103507782731737, 1.7306099704333713, 2.4668022266456058, 3.381621594939913, 3.846937460558755, 3.1347464535917555, 4.93669205904007, 5.039314346654074, 5.117072071347918, 5.535067013331822, 3.1083548069000244, 7.245431235858372, 2.62765172123909, 3.246709508555276, 4.678896955081394, 6.065957588808877, 5.378279609339578, 6.624234054769788, 3.960781957421984, 7.870545029640198, 13.720741510391235, 25.221490144729614, 33.43138606207711, 47.077668939317974, 56.848048618861604, 51.880374976566856, 56.1886020387922, 56.22716801507132, 55.75251919882638, 58.19391468593052, 64.15566362653459, 36.88572815486363, 37.11420924322945, 40.37918513161795, 27.32036202294486, 43.20399611336844, 50.28442587171282, 41.99363728931972, 28.426391908100673, 27.898775236947195, 45.954756668635774, 48.5434296471732, 44.03044959477016, 45.116345337459016, 53.184190545763286, 48.688657420022146, 42.936170850481304, 40.840062618255615, 32.49072504043579, 24.98703360557556, 18.988784040723527, 29.585422652108328, 21.663199526923044, 18.13354069846017, 15.529757125037056, 16.136737857546123, 16.10568462099348, 6.67218313898359, 7.820881043161664, 5.686043551989964, 6.28566266809191, 9.796835814203535, 13.270667604037694, 8.637529747826711, 11.69671128477369, 4.723132227148328, 4.439207553863525, 7.867769224303109, 6.6467792221478055, 2.5828473482813155, 1.5435939942087447, 0.39519687103373663, 0.0714172695630363, 0.09548227395862341, 0.10866330524108239, 0.5257589508380208, 4.6892779980387, 9.972732067108154, 27.804646253585815, 37.49779496874128, 37.41074446269444, 43.60651568004063, 56.26590422221592, 54.398839882441926, 37.72870792661394, 19.640750885009766, 22.046766144888743, 21.130262272698538, 33.72259201322283, 49.81465121677944, 50.01976203918457, 45.22569956098284, 24.2064208643777, 2.3766625949314664, 0.038287105171808174, 0.16372086480259895, 0.038009170442819595, 0.009187196215082492, 0.022425380502162234, 0.04104983174641218, 0.18660676532558032, 0.05854344501027039, 0.09134962250079427, 0.07795030650283609, 0.11577739885875157, 0.03522070703495826, 0.07819544763437339, 0.0249880902203066, 0.02692777247700308, 0.0815340502719794, 0.07098338713071176, 0.07542004941829614, 0.07776347867080144, 0.02933538266058479, 0.04700865503400564, 0.008268190930331392, 0.11419318243861198, 0.03864452010020614, 0.09630383058850255, 0.027126900452588285, 0.012264644294711096, 0.11399872787296772, 0.07558156110878501, 0.13033578837556498, 0.047365377856684585, 0.04628025108416166, 0.0537566247263125, 0.057192658207246234, 0.051259544611509354, 0.03831850777247122, 0.04406338896868484, 0.0779019540974072, 0.06141760399831193, 0.08508897665888071, 0.05755501626325505, 0.0908034493082336, 0.015672350634953806, 0.05326388955914548, 0.08237282812063183, 0.05220852672521557, 0.02915883802675775, 0.06667354982346296, 0.049833114724606276, 0.010288464487530291, 0.061086981025125296, 0.020937616138585975, 0.05403057984741671, 0.07638340629637241, 0.0020549517856644733, 0.0211662790471954, 0.09044285544327327, 0.023228608204850128, 0.11786219770354883, 0.05465439101681113, 0.7763149003897394, 25.020317213875906, 66.60896832602364, 72.35348183768136, 81.5844624383109, 64.55508082253593, 62.01377023969378, 52.538306849343435, 38.121180398123606, 28.94862025124686, 36.22773722239903, 62.46549347468785, 75.12135233197893, 79.98035267421177, 35.229968956538606, 26.05820437840053, 12.723623769623892, 1.5819612954344069, 0.12447410076856613, 0.06161282530852726, 0.19446391585682118, 0.6639644290719713, 3.6482089928218295, 5.342305311134883, 5.679900041648319, 5.84417108978544, 5.709131113120487, 5.6843099764415195, 8.78214521067483, 9.226529410907201, 7.251382367951529, 6.5328113947595865, 8.369392684527806, 12.652323961257935, 6.07410044329507, 8.610327550343104, 8.32255574635097, 7.33495877470289, 5.561829737254551, 4.243221018995557, 3.9481675028800964, 7.160532934325082, 15.449107646942139, 24.800669022968837, 36.137198720659526, 48.375679288591655, 58.35942077636719, 54.47403328759329, 59.832925251552034, 59.64419133322579, 61.23830958775112, 59.059959002903526, 66.36552429199219, 40.510398387908936, 42.56473405020577, 44.84070682525635, 33.974672658102854, 50.0235036441258, 53.406039578574045, 50.65788459777832, 35.3477999823434, 33.86159072603498, 49.881458146231516, 52.01496505737305, 48.39022534234183, 51.22963448933193, 57.18830190386091, 52.095991475241526, 45.941190310886924, 42.36923606055123, 33.343571254185264, 25.56035031591143, 20.184496062142507, 21.913789783205303, 18.740392889295304, 18.52989547593253, 16.57577541896275, 15.77744824545724, 13.842030133519854, 9.502603922571454, 9.121773157800947, 8.89454448223114, 7.66566002368927, 11.70564579963684, 15.36234896523612, 11.597796729632787, 10.59621216569628, 10.030230147497994, 8.82853399004255, 9.251283236912318, 8.29127756186894, 3.340077881302152, 4.11653972523553, 1.0979218802281787, 0.8745777904987335, 0.13063656937863144, 0.21061549202672072, 0.10856651900602238, 3.873450917857034, 8.16345763206482, 26.376621212278092, 35.85912486485073, 38.84195525305611, 40.65268359865461, 40.20866938999721, 39.77954517092024, 38.38336719785418, 27.041287626538956, 30.620217868259974, 30.793040411812918, 40.80340739658901, 56.899996825626914, 57.04938309533255, 56.62169367926461, 31.481808389936173, 3.5393678503377095, 0.13460503571799823, 0.1076302763872913, 0.06864081283232995, 0.08713522114391838, 0.04711708492998566, 0.06879789368914706, 0.10773631784000567, 0.06446183778877769, 0.1014674888657672, 0.09611154054956776, 0.05852635271315064, 0.0533258330209979, 0.055318778580320735, 0.02916376419099314, 0.045541608040886264, 0.08496841455676726, 0.08619551799659218, 0.011864894718330885, 0.015126718574070504, 0.039375594085348506, 0.06518284231424332, 0.03603687948946442, 0.09483406945530858, 0.02587920517128493, 0.06904576931680952, 0.027606288835938488, 0.053117119041936736, 0.11800232875560011, 0.05403166889612164, 0.0748981542087027, 0.034408765246293375, 0.13970297787870678, 0.1871985699981451, 0.1588477755763701, 0.17494554391929082, 0.13116259686648846, 0.14343299344182014, 0.3022346150662218, 0.23753798380494118, 0.22305275393383844, 0.20605473246957573, 0.18862045370042324, 0.09642453518296991, 0.16265084221959114, 0.22956905141472816, 0.1587128285318613, 0.1995000977601324, 0.16238094813057355, 0.12785635356392178, 0.07293639411883694, 0.19368464552930423, 0.2114959183548178, 0.1520560471607106, 0.17634462884494237, 0.2652167028614453, 0.12362580985895225, 0.1528785673103162, 0.19859461991914681, 0.1569459911968027, 0.22009850745754583, 1.5367134319884437, 30.960196699414933, 79.65811606815883, 78.76268781934465, 93.20617921011788, 69.19306591578892, 70.38346603938511, 58.056767668042866, 40.703089305332725, 30.762850488935197, 57.45275729043143, 81.36830398014614, 80.07199246542794, 84.40229048047746, 40.24251406533377, 40.17874697276524, 17.698460136141094, 3.281945777790887, 0.21121381063546452, 0.2381854419197355, 0.37713771579521044, 0.5051934772304126, 3.844408316271646, 6.845597147941589, 10.359971676553998, 11.36312653337206, 10.105979408536639, 11.77290870462145, 13.5080806016922, 14.574412822723389, 11.332719479288373, 16.076717581067765, 12.272632701056343, 15.144922460828509, 10.841764109475271, 13.20158861364637, 13.167288831302098, 13.557078429630824, 12.460815974644252, 16.35358418737139, 12.446885704994202, 12.474005392619542, 19.34812750135149, 28.951997075762065, 36.35048062460763, 49.719308035714285, 62.02766663687569, 57.0216007232666, 61.597941398620605, 60.24036066872733, 66.22684519631522, 65.81556047712053, 68.47654683249337, 43.395637852805, 47.63709967476981, 50.08581856318882, 39.96555539539882, 53.29494135720389, 63.25089005061558, 55.21167836870466, 42.01333195822579, 38.53494215011597, 54.603957653045654, 53.40087359292166, 55.02893032346453, 55.24564463751656, 59.84841973440987, 53.341348375592915, 50.36999641145979, 45.06340701239449, 38.35530342374529, 27.29266129221235, 23.551495824541362, 33.93295567376273, 26.666308982031687, 24.438316992350988, 21.164582899638585, 21.51430310521807, 22.828188351222447, 11.620142136301313, 17.10405216898237, 13.930239251681737, 15.037538051605225, 19.788634606770106, 28.11575358254569, 14.123764821461268, 18.825840098517283, 16.784104994365148, 12.805104425975255, 17.22047618457249, 15.419186966759817, 10.173166751861572, 5.015525017465864, 1.1825895884207316, 0.6667295406971658, 0.2577814518340996, 0.2787343960787569, 0.7701530967439923, 6.072354274136679, 12.967416082109724, 34.80284581865583, 47.90100615365164, 50.467219080243794, 59.62329115186419, 73.43172413962228, 69.76915495736259, 51.64068296977452, 30.863092150006974, 34.367683615003315, 36.822485651288716, 48.22809260232108, 65.46035466875348, 65.29282665252686, 67.35942935943604, 39.321526868002756, 5.479735468115125, 0.2263934396739517, 0.3415905689554555, 0.23980274370738439, 0.19245028176477977, 0.17020001927656786, 0.17236237467399665, 0.32456892090184347, 0.14902144856750965, 0.21445878222584724, 0.20353864319622517, 0.2646626925894192, 0.21458500331001623, 0.19854641679142201, 0.14306676095085485, 0.21441918292215892, 0.1864220273814031, 0.1118832796013781, 0.23027415786470684, 0.309095174074173, 0.15644577518105507, 0.12421855090984277, 0.10651332632239376, 0.23945869931152888, 0.2892985077840941, 0.15147307701408863, 0.15470016242137977, 0.0895433487104518, 0.2539610282651016, 0.22862263077071734, 0.2800690744604383, 0.14728853798338346], [0.028722590899893215, 0.11092599561171872, 0.021805484479825412, 0.010763229502897178, 0.021374143161145703, 0.06298878576074328, 0.030829886573233774, 0.1333297970039504, 0.05522721706490431, 0.005984077512818787, 0.07752221197422061, 0.05999738270682948, 0.043973649319793494, 0.056988500590835295, 0.1650708509343011, 0.0684644208688821, 0.06902848024453435, 0.0652511775759714, 0.00514483401950981, 0.019347925637183443, 0.06511486667607512, 0.03159492462873459, 0.07381857106728212, 0.027756049996241927, 0.03506650995197041, 0.07929415189261947, 0.015155822637357881, 0.05348493930484567, 0.0177140879511301, 5.917340397834778, 42.743007455553325, 65.89445727212089, 60.93133817400251, 57.547607149396626, 55.080645765577046, 52.78878593444824, 34.45984104701451, 22.240504503250122, 24.931376797812327, 48.63000767571585, 64.55476120540074, 78.48170266832624, 38.82734319141933, 25.83152982166835, 11.659076367105756, 2.602614539010184, 0.21666122547217778, 0.07529668496655566, 0.16032687335142068, 0.22551371902227402, 0.6187610775232315, 0.9691245343003954, 4.399051742894309, 4.392899113042014, 2.2681412867137363, 2.8831278639180318, 4.633813568523951, 6.428331332547324, 8.023090992655073, 8.721219062805176, 5.415713897773197, 6.699756630829402, 10.503702112606593, 4.989331611565181, 5.318491228989192, 5.128775877611978, 5.835116284234183, 3.9312529819352284, 5.559692297663007, 12.972006235803876, 29.736410481589182, 37.78909124646868, 51.30151012965611, 57.82606315612793, 59.143677847726, 55.593078885759624, 57.0202944619315, 56.72457218170166, 58.91829218183245, 66.15510504586356, 59.0528301511492, 62.14027609143938, 51.33090100969587, 40.54934651511056, 49.60240112032209, 32.764275618961875, 43.87998635428292, 39.76825087411063, 45.58184685025896, 25.317608049937657, 34.40310900551932, 43.68438066755022, 51.22097703388759, 51.91396256855556, 55.4080935205732, 57.276352950504844, 55.033411911555696, 49.6967785017831, 48.85116536276681, 49.33127893720354, 46.34225075585501, 41.763307980128694, 45.8756479535784, 40.292134625571116, 43.54396799632481, 34.436557633536204, 35.71074955804007, 25.112002168382915, 25.057149614606583, 14.97709914616176, 11.890998550823756, 6.758243960993631, 10.04286892073495, 10.280953288078308, 13.534413405827113, 12.372999429702759, 4.804633728095463, 5.692511456353324, 4.4065062914575845, 3.563660489661353, 5.745379865169525, 1.9270090545926775, 1.010207929781505, 0.42008602406297413, 0.13458146341145039, 0.08483534705426012, 0.01136265242738383, 0.11940652983529226, 3.090570241212845, 11.143007602010455, 27.62869528361729, 40.648330552237375, 46.36746229444231, 71.0631388255528, 88.04721818651471, 73.88712991986955, 45.65855148860386, 25.679600511278423, 21.873669147491455, 32.693358830043245, 35.34201908111572, 43.30592271259853, 47.19240454265049, 35.83632435117449, 17.291823761803762, 0.6331808694771358, 0.10860757037465062, 0.06164074023919446, 0.033140559547713826, 0.08774242177605629, 0.0721687606668898, 0.1465393810399941, 0.07133895983653409, 0.027619672939181328, 0.12030930710690362, 0.07910637411155871, 0.05473981857565897, 0.00799453690914171, 0.0057924380193331414, 0.03893156416182007, 0.08179786468722991, 0.06824334058910608, 0.07140918142561402, 0.07697973679751158, 0.09055087143289191, 0.03867528487795165, 0.001405194921452286, 0.020959863605509912, 0.04595583670639566, 0.07032927937273468, 0.0339727895334363, 0.10779822737510715, 0.08185351134410926, 0.1667927149683237, 0.060507233919841905, 0.13259725059781755, 0.0588085622127567, 0.08241509406694345, 0.03355368220114282, 0.025627358417425836, 0.06876677607319184, 0.06724715618682758, 0.06766560873282806, 0.08298941289207765, 0.09129774171326842, 0.008343787364927786, 0.010292393205288266, 0.05316490487062505, 0.028202817808570604, 0.06505226503525462, 0.046871326331581385, 0.03871436170967562, 0.06406637400920902, 0.08605261173631464, 0.04285328961642725, 0.0855274527732815, 0.08870093391409942, 0.04567170016733663, 0.058106393819408755, 0.040379812342247794, 0.05062338410477553, 0.039936423634311984, 0.03837090763928635, 0.06816387735307217, 0.07042758552623646, 8.41018295288086, 50.97615030833653, 75.2653398513794, 68.70324570792062, 66.76810986655099, 60.92369515555245, 56.397569111415315, 39.358835220336914, 22.071388823645457, 21.34298137256077, 38.881368909563335, 65.42396695273263, 78.31402179173061, 49.23637696674892, 22.39940459387643, 11.616325838225228, 2.2304470922265733, 0.2892209919435637, 0.04659271985292435, 0.21043805511934416, 1.3403879553079605, 2.965657263994217, 6.668440665517535, 7.441623176847186, 8.508580735751561, 7.118057727813721, 5.0855797954968045, 9.070426838738577, 10.18648818561009, 9.846144574029104, 9.36543779713767, 6.487627259322575, 5.174609235354832, 9.19585050855364, 8.658384765897479, 7.7874089649745395, 6.059897456850324, 5.08128103188106, 3.8653145773070197, 5.071139701775142, 11.671788964952741, 28.151573283331736, 39.80152579716274, 53.12887593678066, 59.636735916137695, 61.01587690625872, 60.11259719303676, 59.432646478925435, 60.057261739458355, 61.74225548335484, 68.00302709851945, 61.0945930480957, 63.642608642578125, 56.0113639150347, 46.659877232142854, 52.537198611668174, 40.31711687360491, 51.02233845846993, 46.23106915610177, 51.5502347946167, 31.343813691820415, 41.67635127476284, 46.41039868763515, 54.46291616984776, 55.70265197753906, 59.33551066262381, 61.45865086146763, 54.7038380077907, 52.33301189967564, 51.271855218069895, 50.659715448107036, 47.189646107809885, 42.842797483716694, 46.430364336286274, 41.20590264456612, 44.589220251355854, 35.60549129758562, 33.94069596699306, 27.136092322213308, 24.550933395113262, 16.115370409829275, 15.582528693335396, 9.910101005009242, 7.718060731887817, 8.337078349930898, 8.957728794642858, 9.6311160666602, 12.016040069716317, 10.943553481783185, 8.717036247253418, 9.452464853014265, 10.158388801983424, 6.721431536333902, 5.427585763590677, 1.1729471172605241, 0.8043950136218752, 0.24903293699026108, 0.035421556793153286, 0.08860737750572817, 1.8389436772891452, 9.240216493606567, 25.223211560930523, 38.9677072252546, 44.77967037473406, 67.24772317068917, 81.07014983040946, 65.64312703268868, 41.25454698290144, 24.41468790599278, 25.03369423321315, 39.773420333862305, 42.0861942427499, 49.30130788258144, 55.31344515936715, 42.427003383636475, 19.264526775905065, 0.9951972152505602, 0.09089870883950166, 0.013451349455863237, 0.021223376072677116, 0.10313330590724945, 0.0456780919672123, 0.035528694079922776, 0.06568817448403154, 0.0394934725814632, 0.06603612045624427, 0.13197172273482594, 0.03702338798237698, 0.0513891990828727, 0.006807614192699215, 0.014534286256613476, 0.02050870906428567, 0.019851346034556627, 0.04324928943866065, 0.07575542892196349, 0.1104205616616777, 0.11339285716946636, 0.028203993370490413, 0.042523436780486784, 0.030758843956781284, 0.04380211905975427, 0.02814707954946373, 0.057684141477303844, 0.04622109979391098, 0.062088715843856335, 0.10510954593441316, 0.057464167209608216, 0.1438858477132661, 0.3783741151647908, 0.13928681878106935, 0.16906268601971014, 0.1918762954218047, 0.18812462102089608, 0.10373827415917601, 0.3500662041561944, 0.25475247151085306, 0.11405746186418192, 0.14347982592880726, 0.13393034120755537, 0.08989634976855346, 0.20729395454483374, 0.22931712493300438, 0.19272369066519396, 0.13085215352475643, 0.13700840675405093, 0.08795146484460149, 0.14233083544032915, 0.2507295459508896, 0.10196444112807512, 0.13653800556702272, 0.1804419354136501, 0.1206482353487185, 0.3417181063975607, 0.14120950203921112, 0.1842081711760589, 0.1545764519167798, 10.907952649252755, 63.60908358437674, 83.86305468423026, 77.1162496294294, 75.93081746782575, 69.01720700945172, 63.703516551426475, 44.71026829310826, 30.989448615482875, 37.40064525604248, 60.293903487069265, 70.4517320905413, 85.06943566458565, 48.184642042432515, 33.807318346840994, 14.643375430788312, 3.8992148382323126, 0.38145460986665314, 0.1958389263600111, 0.2661415732332638, 1.2284901482718331, 3.2800771466323306, 9.817718625068665, 13.973870464733668, 13.152384945324489, 9.835212452071053, 10.197916235242571, 11.401155761310033, 14.117401140076772, 18.722836528505596, 17.823447806494578, 13.418803197996956, 20.769400630678447, 21.011517558779033, 12.792131270681109, 13.845462543623787, 10.999332751546588, 12.155511260032654, 8.841643503734044, 11.271035977772303, 19.435523680278234, 35.284171853746685, 42.54474755695888, 57.16971547263009, 60.38709272657122, 67.07836777823312, 60.72634547097342, 63.365354674203054, 60.85909080505371, 62.10385363442557, 65.84320041111538, 62.203004428318565, 65.67692307063511, 55.9870730127607, 48.3953982761928, 58.514407294137136, 44.21078314099993, 52.22302539008004, 50.65238162449428, 56.88195582798549, 38.77739953994751, 48.25099386487688, 48.682876518794465, 58.640572684151785, 63.403667041233604, 61.460026604788645, 59.550321170261924, 56.59736803599766, 51.28220803397042, 50.76935107367379, 52.53176164627075, 49.16967078617641, 45.11684908185686, 47.65787131445748, 43.38356188365391, 49.715020997183665, 39.6830346924918, 41.93594292231968, 30.68384599685669, 30.67480639048985, 20.520458834511892, 17.181899785995483, 11.604133486747742, 16.901585136141094, 14.59936032976423, 23.63051768711635, 24.76541038921901, 11.840217641421727, 14.567079867635455, 12.719140444483076, 12.842890466962542, 15.46790599822998, 10.303028583526611, 6.026059295449938, 0.6708320177027157, 0.6092355315174375, 0.38405548887593405, 0.12613987709794725, 0.32155902098332134, 4.05804978949683, 13.931857313428607, 36.59911148888724, 50.94871882029942, 53.9357077053615, 76.42293058122907, 92.02113614763532, 78.19775758470807, 54.061706338609966, 36.393423965999055, 33.24337475640433, 45.982935088021414, 50.72710255214146, 57.39771366119385, 66.24748829432896, 55.456793444497244, 27.053983722414287, 1.4531415849924088, 0.294163956706013, 0.10107746015169791, 0.1172108855098486, 0.20291128328868321, 0.19176192155906133, 0.18046105653047562, 0.21839058053280624, 0.11879723252994673, 0.15921087323554925, 0.22158129646309785, 0.12927170975932054, 0.12958048390490667, 0.10584210591124636, 0.10622924406613622, 0.15834073349833488, 0.19209862420601503, 0.18522244532193455, 0.18292208947241306, 0.22335671048079217, 0.21459667411233696, 0.11434999188142163, 0.17820255272090435, 0.14672766093696865, 0.19150525890290737, 0.14235694546784672, 0.15102855515267166, 0.2051365388823407, 0.32870285479085787, 0.2167191452213696, 0.248206834175757], [0.09833273171846356, 0.05617177852296403, 0.025730187006826912, 0.044615811468767266, 0.06587154857282128, 0.04170663668108838, 0.008052806952036917, 0.07963568570890597, 0.07448411214032344, 0.024966365225347023, 0.0270616287764694, 0.04108428096930895, 0.03520299727097154, 0.09777423632996422, 0.07154436595737934, 0.13143486582807132, 0.0639677828709994, 0.018193498386868408, 0.03759433448846851, 0.06982316688767501, 0.025987355171569755, 0.07805980169879538, 0.07562332493918282, 0.018483473719762902, 0.022405826819262335, 0.1624357330479792, 0.04616746160068682, 0.0605156206126724, 1.2124804130622318, 20.631345135825022, 59.53752953665597, 67.15297753470284, 64.09495721544538, 51.02488497325352, 48.69033193588257, 37.356899397713796, 28.28711700439453, 33.035981450762065, 42.60551650183541, 57.12644556590489, 72.6830140522548, 56.04797049931118, 23.77808700289045, 14.742911849703107, 1.3732876756361552, 0.26635683168257984, 0.15904689846294268, 0.10867300829184906, 0.19728544088346617, 0.7172210142016411, 2.2166560036795477, 6.039165335042136, 5.401758006640843, 6.034987730639322, 4.5316572444779535, 1.796000553028924, 5.883330702781677, 6.065256255013602, 7.473671742847987, 4.271382502147129, 6.049740493297577, 5.022452371461051, 10.590292300496783, 4.241364112922123, 7.954332487923758, 10.106026308877126, 8.148264527320862, 12.101583685193743, 13.107848729406085, 29.51262984957014, 47.64510747364589, 61.128826822553364, 58.19443580082485, 52.266972746167866, 58.552608489990234, 59.03459807804653, 58.62451539720808, 63.66530840737479, 60.79024110521589, 60.9860691343035, 68.21382154737199, 60.45030743735177, 62.63113158089774, 54.19374990463257, 57.26386703763689, 39.89982196262905, 36.72063895634243, 37.15811491012573, 39.76334197180611, 34.00328881399972, 39.04564864294869, 48.83737318856375, 56.03651291983468, 63.31787068503243, 61.12559591020857, 61.14437689099993, 55.33210107258388, 53.38248518535069, 49.564543860299246, 51.208338260650635, 46.9628256389073, 48.73536321095058, 53.29092877251761, 54.94622244153704, 57.03006362915039, 51.775328636169434, 49.4616653578622, 43.870575019291465, 33.874882629939485, 29.126261370522634, 32.03590638296944, 20.70451487813677, 15.912179027284894, 16.64619541168213, 9.532010436058044, 8.441761646951948, 10.564281719071523, 9.49369546345302, 7.856157047407968, 6.757936068943568, 3.0998087397643497, 7.324476548603602, 3.721070408821106, 2.1732417047023773, 1.4240727105310984, 0.6282338063631738, 0.0028587184996078058, 0.29689041897654533, 0.031813473972891054, 1.8672458614621843, 9.342135276113238, 35.90082795279366, 60.18227372850691, 74.92373861585344, 88.4820989881243, 77.64664036887032, 61.08251013074602, 43.92437492098127, 22.296576465879166, 22.205063479287283, 42.33202150889805, 43.947227546146934, 51.61322021484375, 48.41588156563895, 25.039728743689402, 2.034631656748908, 0.07184880426419632, 0.0264425995826189, 0.0166909996353622, 0.02413681206027312, 0.23662535420485906, 0.0729176869083728, 0.03569352041397776, 0.05164158696840916, 0.007479924924804696, 0.061540751318846426, 0.012171092127183718, 0.08336014407021658, 0.05481585181717362, 0.035261622696582756, 0.0068718082703916085, 0.025532621358122145, 0.05324804576646004, 0.08172353117593698, 0.06224445320133652, 0.01768393555123891, 0.06401671881654433, 0.15598392353526183, 0.027740501366289597, 0.03159833765987839, 0.0037143520062922365, 0.02151468811955835, 0.030921861995011568, 0.13683253047721727, 0.05071753762396319, 0.003418638811646295, 0.03203689180580633, 0.06879914219358138, 0.005665826353444052, 0.11505721536065851, 0.02711007448046335, 0.030159473618758575, 0.011362630374995726, 0.01533980231865176, 0.03509024849959782, 0.036230448566909344, 0.028329038892739584, 0.02605380580228354, 0.028335927719516412, 0.07808801518487078, 0.004359876296283411, 0.017701209356476153, 0.06163177000624793, 0.04151602601632476, 0.03176428696938923, 0.06884862096714121, 0.02800127424831901, 0.04708851860570056, 0.05362987777750407, 0.017495309601404836, 0.018955286259629896, 0.018664656140442406, 0.051496590820274184, 0.052811513654887676, 1.5393330114228385, 25.67241781098502, 67.40745530809674, 75.6445586340768, 70.38925388881138, 58.348623275756836, 58.703780446733745, 51.01180151530674, 35.861160687037874, 34.055066789899556, 30.983688558850968, 53.4748614856175, 74.2690793446132, 67.66552530016217, 24.98199963569641, 13.028666189738683, 1.709310919046402, 0.42828598405633655, 0.14837305407438958, 0.3757466104413782, 0.8379120379686356, 2.9982781878539493, 5.765875313963209, 6.8819496887070795, 6.980853821550097, 9.035153440066747, 10.502279468945094, 10.57722795009613, 13.410935231617518, 9.757130333355494, 11.456804752349854, 7.267017986093249, 8.205067787851606, 5.306343172277723, 4.617561297757285, 4.790587510381426, 3.5301095928464616, 3.969243560518537, 5.729951824460711, 10.237068465777806, 14.69978438104902, 33.80652625220162, 51.93333067212786, 62.780886105128694, 61.4985682623727, 54.47123316356114, 60.71608992985317, 59.11216081891741, 57.34013046537127, 63.33010646275112, 59.647359711783274, 61.47029604230608, 66.86453696659633, 59.0669002532959, 64.40266513824463, 59.17261709485735, 57.76614536557879, 44.65250097002302, 43.75159754071917, 43.890915870666504, 45.07972138268607, 39.72770118713379, 44.29167059489659, 51.17312479019165, 58.65833922794887, 64.99589538574219, 62.213544845581055, 60.17516572134835, 55.55524941853115, 53.883134160723, 50.07863759994507, 51.63066019330706, 51.26244388307844, 51.51560844693865, 55.78119788851057, 56.89354542323521, 57.68972560337612, 54.43471690586635, 50.50859212875366, 44.17392989567348, 33.98037018094744, 27.83486918040684, 25.51212113244193, 16.555373770850046, 13.135363595826284, 10.708977954728262, 9.796583073479788, 11.529229300362722, 8.419856582369123, 10.164440682956151, 10.781797681535993, 8.946015000343323, 9.21530372755868, 7.5301293304988315, 6.6435222540582926, 3.8195472274507796, 3.6107403976576666, 1.4938370755740573, 0.3884634966296809, 0.22363789539252008, 0.07372614102704184, 1.4364720966134752, 7.813269291605268, 35.62936530794416, 60.997943605695454, 79.65657356807164, 92.39811066218785, 79.15346840449742, 64.49121992928642, 49.10868992124285, 28.69875955581665, 30.360372611454554, 47.40492909295218, 50.80701378413609, 57.96848038264683, 56.702126026153564, 29.64425652367728, 3.3548193531376973, 0.03961580226730023, 0.059074113677654944, 0.05844202438103301, 0.015659619621666412, 0.17022109457424708, 0.05567765235900879, 0.07114033906587533, 0.024125220985817056, 0.026633347650723796, 0.08138235019786016, 0.04460755709026541, 0.06090150347777775, 0.04359569174370595, 0.07358528394252062, 0.017083228499229466, 0.023955996048503687, 0.08327848238072225, 0.03634590469300747, 0.05684541791145291, 0.015964276756026914, 0.04090327157505921, 0.10182614890592438, 0.03061375959909388, 0.028535664680280855, 0.04357683864821281, 0.06541029403784446, 0.03384434285440615, 0.09323913218187434, 0.08260165048497063, 0.011775917573166745, 0.2791339174977371, 0.19245071602719171, 0.07288715961788382, 0.22101716244859354, 0.12198332085141114, 0.1256366076746157, 0.139998873429639, 0.2463021863784109, 0.15354691073298454, 0.14690166445715086, 0.10519565202827964, 0.15605189917343004, 0.09561283088156156, 0.18945111627025263, 0.17687001850988182, 0.19655085887227738, 0.1380329132080078, 0.12466717112277236, 0.10928941664419003, 0.22600995882281236, 0.10510497939373765, 0.09888980218342372, 0.2083347322685378, 0.07710395620337554, 0.10451132910592215, 0.3416754129741873, 0.12117184725190912, 0.1787105311772653, 2.7388719703469957, 32.15458161490304, 77.5357471193586, 83.46864019121442, 81.95491259438651, 64.85202598571777, 61.76747744424002, 50.1740711075919, 37.33869511740548, 46.00537429537092, 57.19562530517578, 66.72988782610211, 82.75668607439313, 65.13699245452881, 31.17870364870344, 17.769710438592092, 2.3165202907153537, 0.5389871267335755, 0.2968900389969349, 0.43880362968359676, 0.657590813934803, 2.2164605855941772, 8.547591396740504, 14.724834374019078, 14.110562375613622, 12.564159137862069, 12.220430885042463, 8.023287279265267, 14.30294062410082, 13.983190604618617, 16.327971390315465, 14.437779103006635, 13.740107008389064, 13.81585453237806, 19.6075211252485, 14.37450533253806, 15.27784149987357, 18.808714526040212, 14.207875370979309, 17.505984612873622, 19.373926162719727, 37.44640261786324, 54.75841610772269, 65.90359415326799, 62.17576054164341, 54.20175770350865, 60.940259660993306, 61.79645143236433, 59.722546168736045, 65.33917113712856, 63.378750801086426, 62.112441607883994, 63.54901640755789, 60.83375767299107, 64.5111334664481, 58.582270349775044, 62.3524671282087, 48.387400899614605, 46.376168387276785, 49.20949786049979, 50.05224486759731, 46.29152890614101, 48.60049172810146, 55.83547721590315, 63.07931123461042, 65.83534894670758, 61.18760858263288, 59.783704212733674, 56.21608911241804, 53.78862476348877, 50.90808922903878, 52.26806361334664, 50.78052725110735, 52.10552440370832, 57.09032188143049, 59.68130166190011, 63.344065393720356, 56.81064993994576, 52.918050221034456, 47.76977900096348, 37.886775970458984, 32.73917872565133, 36.60727909633091, 27.909176690237864, 24.6392536844526, 28.00091896738325, 20.307364531925746, 14.645093372889928, 19.033610343933105, 19.164147887911113, 15.835707153592791, 15.63050947870527, 12.517573203359332, 16.671905483518326, 11.21389833518437, 5.388265473502023, 4.261172992842538, 1.3560572287866046, 0.22805016434618405, 0.4756536994661604, 0.17975822995815957, 2.6294836572238376, 11.571307591029576, 43.14037840706961, 68.67718996320451, 79.92301613943917, 90.8863285609654, 81.41662870134626, 69.09936250959123, 54.06490250996181, 31.57198211124965, 34.803335666656494, 55.018653937748496, 58.430695397513254, 66.55183328901018, 66.47294344220842, 38.507413387298584, 4.471745533602578, 0.19472477185939038, 0.2317941305892808, 0.12028815038502216, 0.13346777031464235, 0.235588688403368, 0.15234603945698055, 0.1617361634437527, 0.1266076998519046, 0.10635539051145315, 0.22969194767730577, 0.0982218658817666, 0.1487011257559061, 0.17279126308858395, 0.127302899690611, 0.1750836665076869, 0.22669757264001028, 0.17616966180503368, 0.1257575090442385, 0.1975711855505194, 0.10839733986982278, 0.14108313167733805, 0.2246961114662034, 0.1227584792567151, 0.15705552031951292, 0.15233455864446505, 0.19084910196917398, 0.1301006759916033, 0.3177568364356245, 0.24597456253000669, 0.0575029319152236], [0.0669043127979551, 0.01213705850698586, 0.054555708276374, 0.030748638790100813, 0.05768565461039543, 0.07300669034676892, 0.05702169452394758, 0.07912192613418613, 0.04413323736350451, 0.01955419180116483, 0.0389831090745117, 0.022926812791930776, 0.0525111872702837, 0.05327887500503233, 0.04183791285114629, 0.044199285962219746, 0.07927735136555773, 0.06885299073266131, 0.028223580980141248, 0.09001386524843318, 0.009036923609008747, 0.059641314670443535, 0.029104606115392277, 0.03928769326635769, 0.05254298002858247, 0.022451843367889524, 0.08234109982315983, 0.08747355227491685, 5.140650349003928, 49.52115930829729, 67.8880205154419, 64.3362820489066, 60.17053822108677, 55.49731533867972, 28.462460006986344, 18.962896789823258, 14.608109848839895, 11.883055022784642, 31.948164531162806, 53.05560023444039, 61.231215476989746, 23.75341394969395, 16.602242844445364, 2.1457120733601704, 0.16331993203077996, 0.008365008547636015, 0.1010165141363229, 0.22753518340843065, 0.7128629737666675, 3.5997763574123383, 4.9635729023388455, 3.7211451019559587, 4.208259854997907, 7.86916754926954, 9.059286270822797, 7.72393890789577, 10.51826901095254, 11.949546677725655, 9.84417302267892, 5.537422018391745, 5.663982152938843, 4.450979539326259, 7.340010983603341, 11.518146923610143, 13.405394043241229, 13.058148264884949, 16.535305636269705, 25.678660767418997, 41.65025036675589, 54.347259930201936, 61.3486122403826, 55.06260129383632, 56.923005785260884, 59.82327420370919, 62.53825501033238, 58.63029629843575, 61.02905069078718, 64.22085857391357, 63.44420978001186, 61.63296031951904, 63.04830837249756, 59.72333131517683, 60.870465006147114, 60.3852653503418, 58.93820571899414, 51.78413200378418, 29.25683191844395, 37.05129330498831, 39.536253997257774, 40.023558957236155, 43.455847467694966, 49.77504301071167, 58.80224336896624, 66.75620065416608, 59.36424841199602, 59.55231530325753, 56.69795363289969, 53.343620436532156, 50.25874185562134, 52.47459186826433, 54.22480140413557, 52.18490757261004, 53.26325409752982, 54.960959570748464, 56.90959576198033, 53.55192743028913, 54.67546851294381, 51.53951025009155, 50.03735835211617, 39.78043106624058, 42.562260491507395, 33.77355357578823, 23.727966172354563, 18.047593218939646, 5.318781316280365, 12.758497646876744, 21.42490758214678, 12.739196419715881, 9.375210438455854, 7.693091511726379, 10.156433752604894, 5.417642891407013, 8.208258748054504, 5.158009988921029, 2.324847923857825, 0.2846985289028713, 0.3178464301994869, 0.05368110377873693, 0.2065988089889288, 0.3698722885123321, 0.9338100978306362, 7.267947741917201, 23.755831922803605, 36.521580014910015, 40.97117859976632, 39.403004918779644, 31.029063769749232, 17.916128090449742, 19.174676145826066, 28.987137590135845, 30.436139242989675, 38.85978433064052, 50.94937195096697, 51.82800987788609, 32.07515328271048, 6.4126240611076355, 0.34160538816026276, 0.08064445693578039, 0.038377353721963506, 0.03676116133907011, 0.11523520866675036, 0.01998005055689386, 0.01571488629893533, 0.053352231425898414, 0.02101500136112528, 0.02472392805585904, 0.051904006994196346, 0.02185271560613598, 0.015729301775406514, 0.08885834725307566, 0.011789857226956104, 0.03523048811725207, 0.043154671122985225, 0.0483049724384078, 0.17602578523967946, 0.03684954731059926, 0.05339542017983539, 0.032145257240959575, 0.040074882097542286, 0.05940316244959831, 0.06268435423927647, 0.01337451469485781, 0.08260872081986495, 0.12585878718112195, 0.07772054097482137, 0.01532587708373155, 0.09730804206005164, 0.009709293288843972, 0.02768063761426934, 0.08032029361597129, 0.011267120633939547, 0.010903865215368569, 0.029640224695737873, 0.04545553248109562, 0.07780935442341225, 0.020419971950884377, 0.015926801266946962, 0.03101790862690125, 0.029288930153208118, 0.050662348978221416, 0.0563972048195345, 0.01796458611663963, 0.07323403350476708, 0.09577583534909145, 0.07283607950167996, 0.05223845351221306, 0.0024692258282032397, 0.032283128771398745, 0.0527041185248111, 0.07274550186204058, 0.02924042847007513, 0.0265205666489367, 0.038547106220253875, 0.10483480032001223, 7.806038822446551, 60.12975924355643, 77.24236638205392, 73.54504925864083, 67.20817402430943, 61.6761850629534, 33.560421058109824, 25.966559376035416, 23.246704408100673, 21.06194063595363, 37.18625858851841, 54.74368592670986, 69.8916516985212, 30.01560299737113, 13.677773850304739, 2.0445000529289246, 0.17283489289028303, 0.053263448511383364, 0.5863463740263666, 0.938513376883098, 4.211763918399811, 6.9591428722654065, 9.375444071633474, 7.800115483147757, 5.144260372434344, 10.077798383576528, 14.103561197008405, 15.428664309637886, 17.44870366368975, 18.75556080681937, 9.91659322806767, 6.610182191644396, 6.178475848266056, 4.798976591655186, 5.561083240168435, 8.565179892948695, 9.554230775151934, 12.19731422833034, 15.792247908455984, 25.254263060433523, 40.452954156058176, 57.19050448281424, 61.42730058942522, 58.12523174285889, 60.32044560568673, 62.654025895254954, 63.15881947108677, 61.61019802093506, 63.04616832733154, 64.57955237797329, 63.39933136531285, 61.27933175223214, 63.2196717943464, 59.98944732121059, 60.62087181636265, 64.97622503553117, 61.00844233376639, 52.739026410239084, 35.52669872556414, 44.24201529366629, 45.6403854233878, 45.63373599733625, 47.908906255449565, 54.86100973401751, 59.5616397857666, 65.13756915501186, 59.412545340401785, 57.98167501177107, 55.42592607225691, 54.85060133252825, 51.57249334880284, 52.832118374960764, 53.10777078356062, 53.68533284323556, 55.04792669841221, 57.99187496730259, 58.86818177359444, 56.26028312955584, 54.257999897003174, 53.096997601645334, 50.12159136363438, 41.669934613364084, 36.144341468811035, 32.23161629268101, 22.53336238861084, 17.970971958977835, 8.78036734036037, 9.917633720806666, 9.907545804977417, 14.397315399987356, 12.500502347946167, 8.31881500993456, 10.453091434070043, 9.351100189345223, 9.280781814030238, 5.476036420890263, 6.546093310628619, 3.260250461953027, 1.5481764397450855, 0.2675516504262175, 0.16013951626207146, 0.27100658789277077, 1.0531929603644778, 9.2321400812694, 30.523467676980154, 49.07485914230347, 50.60530410494123, 46.64855514253889, 33.72610780170986, 25.240865196500504, 23.95206642150879, 30.405935423714773, 37.90515742983137, 45.9302191053118, 60.462807246616904, 58.852458000183105, 38.880055700029644, 7.951389057295663, 0.41574443131685257, 0.034923108361129246, 0.022281853382342627, 0.13482230263096945, 0.043518270898078165, 0.05565099271812609, 0.017411451154787625, 0.0413606754238052, 0.06371097093714134, 0.05297566145392401, 0.014231113417606269, 0.020632587506302764, 0.037036300503781865, 0.11554969607719354, 0.015820244127618413, 0.032336485372590165, 0.03593721965860043, 0.091655797857259, 0.03257108885528786, 0.04031421496931996, 0.021076157722356062, 0.021366728469729424, 0.05429732892662287, 0.052593622489699295, 0.07502189864005361, 0.025442839300792133, 0.09575697207557303, 0.11078627168067864, 0.02626090995701296, 0.0419708446466497, 0.17886793773089135, 0.18853444260145935, 0.14029208198189735, 0.23238985719425337, 0.14049974083900452, 0.17242925108543464, 0.20060871541500092, 0.1312417819031647, 0.14343220634119852, 0.14538683502801827, 0.09786359939192023, 0.1449509577027389, 0.19083433704716818, 0.12195685798568384, 0.1840533566262041, 0.11282155103981495, 0.1792003656072276, 0.22963888623884746, 0.13991427368351392, 0.12049742415547371, 0.1296490566538913, 0.09220590655292783, 0.16815408691763878, 0.21696140936442784, 0.15133324451744556, 0.09645316936075687, 0.17404480225273541, 0.19191339771662438, 9.856644170624868, 71.39743750435966, 84.43483584267753, 82.80649771009172, 75.38472379956926, 69.44823850904191, 39.64850909369332, 27.74836584499904, 20.958099808011735, 20.118642772947037, 42.55182082312447, 61.95673247746059, 70.96899768284389, 33.59567274366106, 21.092594351087296, 2.422873326710292, 0.54280451046569, 0.1993830640401159, 0.5064182600804737, 0.46133335360458916, 3.980299013001578, 12.655008571488516, 13.882279310907636, 14.19352386678968, 13.72108370917184, 19.211748259408132, 19.3707560471126, 15.95311086518424, 21.499998501368932, 22.102548020226614, 17.392246076038905, 15.29343499456133, 13.69116129193987, 12.31348637172154, 14.15798556804657, 18.366630179541453, 19.591328348432267, 17.752445902143204, 21.73620424951826, 30.76016501017979, 45.29471949168614, 60.12787628173828, 64.57648822239467, 60.23696994781494, 61.150505202157156, 66.1820571081979, 68.31869070870536, 62.77815546308245, 65.62272712162563, 67.72818415505546, 66.60752310071672, 65.68083490644182, 63.51826368059431, 60.357437814985005, 61.43094144548689, 65.38484859466553, 62.03026526314871, 56.941074575696675, 38.78100912911551, 48.219157218933105, 49.83725370679583, 51.44313178743635, 52.81885078975132, 56.98125948224749, 62.64836311340332, 66.38342979976109, 60.4426018851144, 58.240273066929404, 56.46491800035749, 54.946125166756765, 52.09798560823713, 53.868730545043945, 54.1715121950422, 54.61748232160296, 57.65417514528547, 59.34287575313023, 60.62923049926758, 59.31512464795794, 58.92491381508963, 55.25523315157209, 55.44564158575875, 44.167481967381065, 45.15765585218157, 37.836457116263254, 27.635864087513514, 21.919440405709402, 10.91784427847181, 23.428799322673253, 32.345379148210796, 27.3271313054221, 15.104989426476614, 21.06648996898106, 22.50957349368504, 15.617061240332466, 18.443883725575038, 13.585447924477712, 7.194094904831477, 2.5913536804062978, 1.0118933022022247, 0.2984066733292171, 0.5025398624794823, 0.5996310583182743, 1.9928043697561537, 10.64159345626831, 32.54419142859322, 48.07510021754673, 49.234459263937815, 48.90592064176287, 39.2214206968035, 27.5285039969853, 28.590723752975464, 38.860770974840435, 43.05758714675903, 53.85775933946882, 65.88074847630092, 68.0549509865897, 47.708964892796104, 12.150403465543475, 0.5964891154851232, 0.16026257537305355, 0.15424563895378793, 0.16290721989103726, 0.2324925059718745, 0.19042623894555227, 0.1323330154908555, 0.22208882708634647, 0.15790368909282343, 0.1557077733533723, 0.12085464570139136, 0.08491637770618711, 0.17806552935923847, 0.2584707891302449, 0.17588667199015617, 0.09414009097963572, 0.20697941285158905, 0.17764038645795413, 0.2689016636993204, 0.11468691165958132, 0.1229810251721314, 0.19069829077592917, 0.2305106408894062, 0.11786911876073905, 0.10931241898132221, 0.15254694010530198, 0.19444666749664716, 0.2723368693675314, 0.17101719257022652, 0.12128438907010214], [0.09014220336186034, 0.02553019898810557, 0.03284107115385788, 0.029393787562314953, 0.03910957443128739, 0.053075307714087624, 0.06423866762114422, 0.07425836353961911, 0.02546541585720011, 0.015017279357250248, 0.07397608618651118, 0.038841546313571076, 0.04391068805541311, 0.04962502499776227, 0.03540179106806006, 0.03260968731982367, 0.03998131211847067, 0.06720250858260052, 0.07007347167070423, 0.027443280975733484, 0.1326657012104988, 0.02522584210549082, 0.055824891065380404, 0.008583176215844495, 0.014698535835902606, 0.03074137507272618, 0.02952209853434137, 0.5540629806263107, 23.879678351538523, 72.24557631356376, 67.96069867270333, 55.59711231504168, 50.141977378300254, 44.042251110076904, 34.096749033246724, 33.40565340859549, 38.53363936288016, 36.75229842322213, 18.60524000440325, 52.67559283120291, 36.043318135397776, 17.912410804203578, 2.242781230381557, 0.309913161609854, 0.10341805991317544, 0.24021010899118014, 0.4707390974674906, 1.957325130701065, 3.2044774889945984, 2.8919616299016133, 7.106765602316175, 5.249683218342917, 3.9744369047028676, 6.636419892311096, 13.568333642823355, 22.41213369369507, 20.756298065185547, 12.418416329792567, 11.783502101898193, 13.57799163886479, 15.496239015034266, 14.687572922025408, 21.73332248415266, 27.17475209917341, 25.54932873589652, 36.86047492708479, 41.740712438310894, 52.07482726233346, 57.696298599243164, 59.35180418831961, 53.00180728094918, 55.87871585573469, 54.92695508684431, 52.98458269664219, 54.30944783346993, 56.585212162562776, 59.53549371446882, 61.23298726763044, 56.87959691456386, 59.40142822265625, 59.69036906106131, 60.552126339503694, 60.46890081678118, 67.1678466796875, 60.42864990234375, 57.94653797149658, 25.614061628069194, 32.551938670022146, 36.748831272125244, 43.406334604535786, 45.92520250592913, 54.655106816973, 58.210802282605854, 56.89598076684134, 55.70463916233608, 57.73759869166783, 56.91730826241629, 54.91660227094378, 54.06771305629185, 52.50226654325213, 52.49817405428205, 53.694730281829834, 53.37475184031895, 55.27882923398699, 56.34299795968192, 53.60509852000645, 53.78709615979876, 55.03420748029436, 51.37362895693098, 52.80824783870152, 42.28947768892561, 39.71119574138096, 34.401107924325125, 35.6959672655378, 27.11084083148411, 24.690884011132376, 10.827991911343165, 13.602287752287728, 16.05358702795846, 6.130181091172354, 8.532479064805166, 7.354200073650905, 5.209175654820033, 2.714261016675404, 5.9818175094468256, 4.235433391162327, 2.0342382150036946, 0.43351895468575613, 0.031285492304180346, 0.00820668597173478, 0.016695248960916485, 1.084006484065737, 8.146512712751116, 29.77570949281965, 37.59381907326834, 29.226047924586705, 35.277647495269775, 33.01547384262085, 24.169720479420253, 23.643714053290232, 29.724327564239502, 38.19214235033308, 47.399214199611116, 55.02040488379342, 47.73183141435896, 17.7777772971562, 0.4724004768899509, 0.08884844742715359, 0.04437167796173266, 0.056538058511380634, 0.03240537364035845, 0.03728867481861796, 0.020503080616305982, 0.018784485424735715, 0.036405819335154126, 0.0043989688191296795, 0.02514763924825404, 0.04010617613260235, 0.04383755215842809, 0.06216600098248039, 0.01963301212526858, 0.015314813570252486, 0.0830165950049247, 0.010606442960644407, 0.054422983434051275, 0.060070637347442765, 0.055262897828859944, 0.12143320537039212, 0.057978245695786815, 0.06404495944402047, 0.03118743042328528, 0.039664792495646646, 0.06144084382270064, 0.05978157464414835, 0.033381568400987556, 0.06921532843261957, 0.09506516491195985, 0.09308726247400045, 0.08182787629110472, 0.0296637054000582, 0.03613200670640383, 0.025947440349097763, 0.05205652470301304, 0.07366629423839705, 0.034327870301370106, 0.042041286759610684, 0.07857497262635402, 0.06760990779314723, 0.023996570746281316, 0.019222366124657646, 0.040100941234933477, 0.014930952739502703, 0.022300840488501956, 0.04569875675120524, 0.045927959095154486, 0.027163112170196006, 0.053870903594153266, 0.009247253349583064, 0.01866748902414526, 0.02887921713824783, 0.03910587641543575, 0.02020654215344361, 0.01837157820617514, 0.6221265569329262, 30.970653738294327, 80.25113786969865, 75.47794083186558, 62.708152362278526, 59.594261578151155, 51.9981677872794, 40.98549536296299, 39.01960332053048, 36.01544196265084, 32.18801634652274, 23.697507006781443, 59.23791626521519, 39.80059821265084, 15.970397983278547, 2.406876619373049, 0.25778302603534287, 0.09874564063336168, 0.34696358921272413, 0.9102656383599553, 4.4522788524627686, 8.009855542864118, 8.129606877054487, 9.944659607751028, 11.569163203239441, 11.337608405521937, 10.931846635682241, 14.865429435457502, 19.56700096811567, 13.311240741184779, 12.407637068203517, 9.49157018320901, 7.50905544417245, 13.79393470287323, 15.14528203010559, 21.485254423958914, 24.830558436257498, 27.091078417641775, 35.573369775499614, 42.39268970489502, 50.923444747924805, 59.66855866568429, 61.359687668936594, 57.20299734388079, 58.08772884096418, 57.48149503980364, 55.69538068771362, 58.46522099631173, 59.62576471056257, 61.13708823067801, 62.78932121821812, 58.622924259730745, 60.68089035579136, 61.825550488063264, 61.80596351623535, 62.510281562805176, 66.71225329807827, 60.708565030779155, 57.83780908584595, 30.701334612710134, 36.51716790880476, 42.804742200034006, 46.9246244430542, 50.75901910236904, 58.885309083121165, 60.348835945129395, 56.548605578286306, 55.12368638174874, 56.43484967095511, 56.39459180831909, 56.004561628614155, 54.21014765330723, 53.8088127544948, 53.843675340924946, 53.976347718920024, 52.42196273803711, 56.06203712735857, 57.42717749731881, 55.701137270246235, 56.19687039511544, 55.65946544919695, 54.09778485979353, 51.08250985826765, 43.5598064150129, 40.163582529340474, 34.403313977377756, 31.064673287527903, 24.90654914719718, 23.91263713155474, 13.168305005346026, 16.368114607674734, 12.804994991847447, 14.519106030464172, 12.713517614773341, 8.253140636852809, 9.45288348197937, 7.580542853900364, 9.345763972827367, 9.615243775503975, 4.99849454845701, 1.4823399782180786, 0.4716002398303577, 0.08341167201953274, 0.05881344766489097, 1.0299925995724541, 8.309199571609497, 28.26952416556222, 34.83870547158377, 27.62590558188302, 30.20677920750209, 28.311070919036865, 33.06441347939627, 29.802936008998326, 37.79021685464041, 44.73480238233294, 52.232224805014475, 61.4164058140346, 55.237407548086985, 22.69421492304121, 0.4886011247123991, 0.0398675353665437, 0.041413166892847846, 0.05151873481060777, 0.08211808571858065, 0.014438078472656863, 0.04496444954669901, 0.020959836464109163, 0.04580822819843888, 0.012120447121560574, 0.011250192881561816, 0.017061016655394008, 0.041288119674261124, 0.06302203397665705, 0.06938395795545407, 0.1071883804563965, 0.07725316605397634, 0.10041392075696162, 0.054963107486920695, 0.04169585815231715, 0.081114254226642, 0.08541823577667985, 0.048975147905626466, 0.034938504320702383, 0.056248469943446774, 0.031246110131697993, 0.042980168879564316, 0.09398889302143029, 0.03881818096020392, 0.015799497919423238, 0.157196044921875, 0.30719128623604774, 0.13167265164000647, 0.14428253285586834, 0.11328061390668154, 0.11474890261888504, 0.2509437458855765, 0.2249999458768538, 0.2118389042360442, 0.12179053548191275, 0.11946865650159971, 0.14016681084675447, 0.12677318097225257, 0.15447978781802313, 0.11962235825402395, 0.11022012920251914, 0.15452189770128044, 0.17925015650689602, 0.10369693102048975, 0.1462361437401601, 0.1982997828828437, 0.12878993632537977, 0.15954883795763763, 0.1270956208131143, 0.1402662026562861, 0.13019283461783612, 0.1383397060313395, 1.2120748119694846, 41.499689851488384, 89.09572219848633, 84.09208120618547, 70.77825573512486, 67.55176244463239, 59.654238428388325, 45.77338784081595, 42.87357452937535, 51.463184288569856, 53.56415973390852, 26.708573137010845, 64.75365339006696, 46.469757148197715, 21.7189553465162, 2.53681965810912, 0.4909503215125629, 0.2280828697340829, 0.4424652489168303, 0.6133962539689881, 5.918869870049613, 10.639309235981532, 12.702178154672895, 19.274445329393657, 13.50874936580658, 10.363763655935015, 16.022947209221975, 26.614961794444493, 33.85709524154663, 30.4428060395377, 18.583085673195974, 20.105877195085796, 21.631281239645823, 22.258149453571864, 19.58112144470215, 27.843078477042063, 32.841369356427876, 28.569061006818497, 40.7008068220956, 46.51398243222918, 53.82204907281058, 60.302797181265696, 65.76244844709123, 59.97532163347517, 61.26499761853899, 59.882716042654856, 58.31589726039341, 60.88113743918282, 61.9305169241769, 61.514938218253, 66.20828655787876, 61.85738018580845, 64.81866073608398, 63.017236028398784, 64.7945087977818, 64.52338314056396, 66.76772771562848, 59.77302483149937, 59.73815182277134, 33.68994590214321, 40.17018331800188, 47.58308090482439, 52.50548355919974, 54.589404651096885, 60.258134160723, 61.23326519557408, 56.23921619142805, 56.27364798954555, 56.67722715650286, 58.56855460575649, 56.36395025253296, 56.85535464968, 54.21469177518572, 54.15493726730347, 53.5399626323155, 55.16103294917515, 56.80668946674892, 58.611682074410574, 55.32461438860212, 57.978669915880474, 57.93755395071847, 56.061095646449495, 53.57163946969168, 45.68915135519845, 41.749494961329866, 37.2196273122515, 38.053623063223704, 31.177789960588726, 31.386301926204137, 17.310636009488785, 18.71932421411787, 24.661691154752457, 16.74558765547616, 17.800742830548966, 14.134828959192548, 12.402048110961914, 11.44974798815591, 16.22150066920689, 10.78635743686131, 5.711551691804614, 1.4263915632452284, 0.19219820600535187, 0.14452228641935758, 0.3280380261795861, 1.940598645380565, 10.336157594408308, 39.22239691870553, 51.68968514033726, 41.92300885064261, 49.58932113647461, 45.736614499773296, 35.26858009610857, 32.892202377319336, 42.41064037595476, 51.573136057172505, 59.28610897064209, 69.63470036642892, 64.86120455605644, 30.592011656079972, 0.7755266055464745, 0.16057784988411836, 0.11537618110222475, 0.15783913327114923, 0.2139155063778162, 0.09158818184265069, 0.10617576872131654, 0.11284192744642496, 0.1253685320594481, 0.10873969471348183, 0.11899912383939538, 0.11437948101333209, 0.1300646322114127, 0.09426526033452579, 0.1541895376784461, 0.20137252871479305, 0.17823202828211443, 0.2021877071154969, 0.13840722026569502, 0.20531465432473592, 0.15694185213318892, 0.209099929779768, 0.15588952574346746, 0.2824682928621769, 0.08099853007921151, 0.1038698624553425, 0.12790451597954544, 0.1746850543256317, 0.19928675277956895, 0.1390777485711234], [0.05815040360071829, 0.04605566277833922, 0.08987000225377934, 0.010612610843963921, 0.017182912078819106, 0.02315854437516204, 0.006522556542352374, 0.017496332492945448, 0.06635130675775663, 0.024261372429983954, 0.03376558190211654, 0.02249284045371626, 0.049302564800849984, 0.026785229232960513, 0.02835460439590471, 0.06370207534304687, 0.09450771446738924, 0.004780882254375943, 0.06294395495206118, 0.027426819716181074, 0.03173267063019531, 0.022468046784134846, 0.034437776011015685, 0.03607341520754354, 0.008482602907211652, 0.05129009225804891, 0.07634452623980385, 6.852397263050079, 47.67308439527239, 66.07773685455322, 60.670773778642925, 60.01057679312569, 42.088445459093364, 25.468804325376237, 13.598384601729256, 13.882509469985962, 23.94942958014352, 36.363025597163606, 32.23768901824951, 35.122890268053325, 18.099624804088048, 3.4110576382705142, 0.13552678482873098, 0.26293362251349855, 0.10856479552707501, 0.2429969065955707, 1.5369130841323306, 3.9061048456600735, 6.819853203637259, 7.225542885916574, 5.454418403761728, 7.497959171022687, 7.785081318446568, 8.466029967580523, 10.12489674772535, 19.552739790507726, 18.43444980893816, 40.974888937813894, 25.028686319078716, 26.082149607794626, 37.59232521057129, 43.30035720552717, 46.99544048309326, 48.587929385049, 53.2732629776001, 54.153641428266255, 53.72383281162807, 57.38308422906058, 56.854798793792725, 55.2601455279759, 53.96633883884975, 50.7742599759783, 50.37784440176827, 54.2692802974156, 52.55521181651524, 54.37202678407942, 56.54020520618984, 55.6675739969526, 53.13268007550921, 56.66659641265869, 57.77369805744716, 56.27788291658674, 59.07008947644915, 65.9703871863229, 60.48417295728411, 61.130946023123606, 34.48779017584664, 30.890197072710308, 36.84939949853079, 43.37430688313076, 53.578212465558735, 56.871821880340576, 56.677584988730295, 57.1014598437718, 59.65331431797573, 60.164215360369, 55.59868608202253, 55.50122022628784, 55.37899099077497, 54.54671491895403, 53.58510855266026, 53.894626481192454, 52.203824043273926, 52.48039361408779, 52.843565532139365, 52.303002629961284, 52.97776651382446, 52.078735624040874, 52.288915157318115, 51.662111214229036, 52.59554958343506, 52.00082547324044, 46.046059472220286, 38.16589553015572, 32.202360902513774, 31.633876664297922, 24.18528097016471, 31.67012541634696, 29.1232145854405, 11.602291345596313, 10.249335510390145, 6.723845601081848, 7.705547026225498, 4.001937440463474, 7.657812033380781, 6.813664530004774, 3.8312301891190663, 0.900382477257933, 0.5534253748399871, 0.2537231610289642, 0.04653323947318962, 0.11283297756952898, 0.9394261964729854, 11.663987006459918, 31.77296917779105, 45.32944311414446, 49.41071769169399, 43.87423324584961, 18.509837763650076, 14.718518461499896, 20.149272169385636, 31.28380557468959, 43.497477599552695, 53.372389452798025, 49.335020542144775, 33.8886261667524, 5.559192895889282, 0.028365611930244734, 0.09830071843628373, 0.07154642191848584, 0.01703761737527592, 0.048208226915448904, 0.05471272127968924, 0.07161722026233162, 0.06272074407232658, 0.050988439337483475, 0.005497276134389851, 0.048399678963635645, 0.04898268642968365, 0.027386752223329883, 0.018798788942928826, 0.037581920690302334, 0.09514572058937379, 0.00992375870035695, 0.015605647249945571, 0.04613590293696948, 0.05412520834111741, 0.009316228978734995, 0.02777204306663147, 0.025885106729609624, 0.05397754555035915, 0.021315482112446, 0.017136332346126437, 0.053746833465993404, 0.11515660717019013, 0.07098924967327289, 0.0153200281118708, 0.07935828023723193, 0.010810606514236756, 0.03665898414328694, 0.006545838351095361, 0.036532732525042126, 0.030988266824611595, 0.02338697827820267, 0.05836437961884907, 0.05345624405890703, 0.03122811538300344, 0.026247882084654908, 0.028357564504923563, 0.015048632764124444, 0.06815067984695945, 0.07185938941048724, 0.03253460063466004, 0.03300603998026677, 0.07528606589351382, 0.037640535937888284, 0.023474558489397168, 0.023156793754813925, 0.043904655879097323, 0.008875133719162216, 0.048655188110257895, 0.0066006164831508484, 0.05596303061715194, 8.904139944485255, 57.41307612827846, 75.36912509373256, 68.6689841406686, 66.13922146388462, 50.31076996667044, 35.24583516802107, 20.41187412398202, 21.913390261786326, 30.598879950387136, 39.70387234006609, 31.041205746786936, 41.358123779296875, 20.31079694202968, 3.9717275415148054, 0.18167087089802536, 0.18899756989308766, 0.1595831582588809, 1.1442278240408217, 3.5493302643299103, 7.264188766479492, 11.296158926827566, 9.12573710509709, 10.853639449392047, 12.387990168162755, 13.91661296572004, 11.203869479043142, 10.241817559514727, 11.62062416757856, 15.737006255558558, 12.64529846395765, 17.687299592154368, 23.9228127683912, 33.12474121366228, 38.52519382749285, 44.815620354243684, 49.11056246076311, 53.525499956948416, 55.23893962587629, 55.18725545065743, 58.0766464642116, 60.38689817701067, 57.2307380267552, 56.265136446271626, 54.15210935047695, 52.70692573274885, 56.219059467315674, 55.29156180790493, 57.14962823050362, 58.19526958465576, 57.77085624422346, 56.003436020442415, 60.09364945547921, 59.52522427695138, 58.70959608895438, 60.57980101449149, 65.75288077763149, 61.66230951036726, 59.72618702479771, 37.77517747879028, 36.427518776484895, 43.81619494301932, 45.29285042626517, 55.40839924131121, 58.7880551474435, 56.33441693442208, 56.77948032106672, 58.75035422188895, 62.048490388052805, 58.2760945047651, 56.680610929216655, 56.16043751580374, 54.79626989364624, 53.90262385777065, 53.50048296792166, 52.894742488861084, 52.401722635541645, 54.14632844924927, 52.537285464150564, 53.302278654915945, 52.74926110676357, 53.14249440601894, 54.203248092106406, 51.970527853284565, 51.824584415980745, 47.25832557678223, 40.71329620906285, 33.41222293036324, 32.29622411727905, 26.58155311856951, 22.014418806348527, 14.268210053443909, 9.165916800498962, 9.66727101802826, 7.478700501578195, 9.366437469209943, 9.02408148561205, 13.096612623759679, 11.135868327958242, 8.129540869167872, 3.0481289071696143, 2.229694949729102, 0.44541858615619795, 0.18786924758127757, 0.06758852715470962, 0.8162137365766934, 10.551578674997602, 33.835986614227295, 42.52804061344692, 47.042726448604036, 43.26563705716814, 21.01787863458906, 21.25660831587655, 26.09568296160017, 35.07412086214338, 49.14578982761928, 59.2328371320452, 56.36751120431082, 41.457038334437776, 6.774759829044342, 0.043724959450108666, 0.17881963960826397, 0.0793032239058188, 0.04763298189001424, 0.030891599333179847, 0.010977506620942481, 0.10834332169698817, 0.05165295921532171, 0.025122004195249507, 0.01903061382472515, 0.07175089844635554, 0.019762040648077215, 0.04917684243991971, 0.02298934488291187, 0.04897625052503177, 0.053518713385398896, 0.041056600133223195, 0.048644677602819035, 0.024341073153274398, 0.010112756148113735, 0.026410872981484448, 0.040057294469858916, 0.0458722785115242, 0.005340737257418888, 0.0645348820835352, 0.028448934334197214, 0.03178654970335109, 0.08586997046534504, 0.037588061432221105, 0.09230563762996878, 0.14619080403021403, 0.21447269219372952, 0.10851443465799093, 0.07872114942542144, 0.09936443742896829, 0.14477038596357616, 0.14222421044749872, 0.18376411071845464, 0.1230105414454426, 0.15713940081851824, 0.1165403707751206, 0.14466903997319086, 0.18752969508724554, 0.1836414858698845, 0.20708919981760637, 0.17799950790192398, 0.1440218939845051, 0.13887889709855827, 0.09298354839640004, 0.0901890629902482, 0.07539053314498492, 0.07452954684517213, 0.1450787801295519, 0.10214416469846453, 0.2057090460189751, 0.2270475338612284, 12.417886529650007, 67.46093559265137, 82.21963201250348, 77.453049659729, 74.47398172106061, 57.765422752925325, 38.54596894127982, 22.162722894123622, 20.681545870644705, 37.03819247654506, 50.079586029052734, 43.17541817256382, 45.56325347082955, 23.446958439690725, 4.286248173032488, 0.4745043154273714, 0.34747916726129396, 0.32964653415339334, 0.6074175462126732, 3.9534620302064076, 11.037816217967443, 19.673409155436925, 14.675003630774361, 19.15204065186637, 17.230971438544138, 17.27091142109462, 15.1431610924857, 21.007616145270212, 27.547521216528757, 30.844398021697998, 51.88100378853934, 32.9644775390625, 32.57993991034371, 43.35454968043736, 47.284881591796875, 51.892190388270784, 52.45245838165283, 55.86344371523176, 56.47038623264858, 53.75371353966849, 59.44363158089774, 61.49212728227888, 61.10430662972586, 59.45169843946184, 57.745408466884065, 54.95610277993338, 59.895535469055176, 59.33218247549874, 60.08777127947126, 62.00227097102574, 60.692347935267854, 59.25723225729806, 63.38255841391427, 62.49536378043038, 62.00060340336391, 62.159126554216655, 68.73549229758126, 60.45348971230643, 60.02622413635254, 41.32225022997175, 38.68204593658447, 46.74389137540545, 50.43664353234427, 59.179745946611675, 59.51843588692801, 57.19941554750715, 58.06411191395351, 60.264429228646414, 64.08850928715297, 60.21708420344761, 59.32855551583426, 59.39960779462542, 57.33832393373762, 55.6583502633231, 53.61844253540039, 53.96917717797415, 52.443592480250764, 53.915721212114605, 52.83527980531965, 53.663070814950125, 54.30383368900844, 55.008311544145855, 55.355023179735454, 54.187743186950684, 52.936546325683594, 48.53950391496931, 39.872557231358115, 35.118592807224815, 37.21243940080915, 31.54130581447056, 40.380696364811485, 38.6863295010158, 17.420077085494995, 21.178387233189174, 16.58337501117161, 20.228691816329956, 14.104737179619924, 15.707618849618093, 13.984287551471166, 11.368508781705584, 2.03839910030365, 1.1671612220151084, 0.7693822809628078, 0.22933897376060486, 0.19055503846279212, 1.6167248700346266, 13.975604908806936, 42.489481585366384, 58.704440525599885, 62.43749918256487, 55.09135641370501, 29.603342056274414, 23.706572668892996, 30.963316440582275, 44.45324053083147, 58.51849283490862, 70.00676945277623, 63.60105146680559, 49.451496669224326, 11.502175620623998, 0.47857205143996645, 0.24732338158147676, 0.1674532959503787, 0.21971552872232028, 0.19842882667269024, 0.11723718552717141, 0.13748646181608948, 0.19789572884993895, 0.16382811404764652, 0.13246007795844758, 0.16560392161565168, 0.16013244592717715, 0.16335673577019147, 0.09878239687532187, 0.1725136608417545, 0.2384750135242939, 0.13478434538202627, 0.1437839860362666, 0.09080956290875163, 0.18267424777150154, 0.08952340656625372, 0.09645690808870963, 0.11869626651917185, 0.17519056291452476, 0.12459482571908406, 0.1618864182382822, 0.14223433418997697, 0.20365759038499423, 0.18442988927875245], [0.025758334335737994, 0.011440700917903866, 0.023298828097592508, 0.02775149024091661, 0.03364568815699645, 0.047034568286367824, 0.036497581018401046, 0.01882790488057903, 0.013707470132171043, 0.04534887356151428, 0.03579777731959309, 0.03952028489272509, 0.0177153177958514, 0.07100568379142455, 0.03098362564508404, 0.011405967558468027, 0.03861293429508805, 0.08097898148532424, 0.05083749243723495, 0.08123094189379897, 0.018479463577802693, 0.06199367344379425, 0.017907580693385432, 0.047398792313677926, 0.03546690328844956, 0.13181409904999392, 0.3261290628995214, 18.578305312565394, 60.42829554421561, 64.89217267717633, 63.370663097926546, 48.469424383980886, 39.90817369733538, 26.84065839222499, 28.214433635984147, 37.34692178453718, 43.12058298928397, 39.80321420942034, 38.76671321051461, 22.012794664927892, 3.5555211092744554, 0.41361716975058826, 0.018089904749233807, 0.060486633596675735, 0.11266556262437787, 1.1564178956406457, 2.279004143817084, 5.2484772716249735, 5.776722754750933, 9.25927540234157, 9.301710656711034, 15.274622746876307, 20.021647657666886, 12.157192724091665, 12.788860406194415, 21.942550114222936, 25.87017743928092, 24.785537583487375, 37.89351224899292, 38.40806456974575, 55.79631716864449, 52.93853351048061, 55.266367639814106, 53.12307071685791, 57.613736629486084, 55.431171962193076, 58.52681677682059, 55.60045787266323, 59.64396899087088, 55.06227820260184, 51.93863214765276, 47.73258181980678, 47.71019124984741, 43.06170742852347, 42.41035549981253, 46.257899624960764, 49.79394905907767, 48.673555510384695, 45.629973547799246, 52.11996276038033, 52.72756883076259, 53.384541852133616, 52.59665434701102, 60.69439765385219, 58.93056270054409, 62.38483878544399, 38.97041007450649, 37.60306365149361, 55.83785349982125, 45.99828365870884, 56.9080810546875, 53.10307032721383, 57.05130079814366, 55.25349957602364, 59.846244948250906, 54.26600769587925, 54.192450591496055, 53.143877097538535, 57.884549617767334, 53.16244963237217, 53.48888989857265, 52.225596223558696, 52.88935416085379, 52.19783122198922, 53.42112759181431, 54.00690937042236, 52.529225553785054, 50.54741518838065, 48.76360069002424, 49.77702324731009, 49.71185261862618, 49.73726218087332, 52.1319067137582, 52.56534923825945, 51.377012729644775, 49.58000707626343, 46.04653194972447, 43.54364490509033, 27.582944869995117, 28.466090440750122, 14.741235596793038, 9.037369046892438, 9.028472747121539, 4.772020186696734, 9.074030348232814, 14.080351608140127, 8.670478974069868, 4.793087559086936, 4.332251327378409, 0.20589995863182203, 0.1518083954496043, 0.04667372675612569, 0.16862735152244568, 0.3766714265303952, 9.061703375407628, 26.7770128931318, 47.63829129082816, 33.00134815488543, 33.824838229588096, 18.379562514168875, 18.424508673804148, 43.75087145396641, 37.30989136014666, 46.64574112210955, 55.13685669217791, 50.96363312857491, 21.73621814591544, 1.825705621923719, 0.2069371808320284, 0.057968501932919025, 0.04871903147016253, 0.0291193540740226, 0.05859825028372662, 0.027071587974205613, 0.0808545517336045, 0.031374353250222545, 0.013197110866063406, 0.039216430126024146, 0.026134831365197897, 0.049735649954527617, 0.030996317642607858, 0.08034473444734301, 0.032034710315721374, 0.03153954938586269, 0.016215774064351405, 0.032542698950107606, 0.021643270505592227, 0.06512484114084925, 0.0080811926163733, 0.03932732988947204, 0.007491315831430256, 0.07178419415972062, 0.035072935678597005, 0.027722632146573493, 0.006092043884564191, 0.02354768251201936, 0.05105203842478139, 0.028970931324043443, 0.03240771458617278, 0.05453235649370721, 0.0374249551844384, 0.03100992226973176, 0.0738576411136559, 0.031040178146213293, 0.042910388338246515, 0.014334778301417828, 0.035285361244210174, 0.05979714023747614, 0.08035179121153695, 0.028502189155135835, 0.037183776697410006, 0.04177984721692545, 0.030192609876394272, 0.03603334432201726, 0.04904062653492604, 0.018500141932496002, 0.0055089036801031655, 0.0584146183516298, 0.04523766506463289, 0.06138240160154445, 0.0509700001483517, 0.1553968686078276, 0.1639471969434193, 24.310556990759714, 71.50081975119454, 69.8522276197161, 71.02404131208147, 56.43775749206543, 47.35610410145351, 34.02026326315743, 31.552485466003418, 21.550838470458984, 30.959995201655797, 35.43650763375418, 33.54202222824097, 24.400940895080566, 4.41616689307349, 0.46252572962215965, 0.07062676948096071, 0.2379723819238799, 1.0362813706908907, 3.5954582691192627, 6.428294854504721, 7.517983879361834, 10.442881056240626, 11.159052729606628, 11.801636900220599, 12.078259451048714, 16.800815411976405, 12.973712018557958, 9.940437708582197, 11.476837277412415, 16.56363344192505, 22.555845022201538, 31.895479815346853, 39.88407039642334, 50.682738304138184, 53.56147078105381, 56.136275155203684, 54.890977314540315, 57.04756266730172, 56.03786781855992, 57.57188068117414, 55.698813097817556, 60.61970451899937, 58.31873212541853, 55.40300049100603, 50.29952083315168, 49.722730023520334, 45.4520822933742, 45.59524992534092, 49.28435427801949, 52.66937071936471, 50.78198984691075, 48.14194188799177, 53.32095888682774, 54.70375462940761, 57.51289047513689, 55.15216704777309, 61.53116226196289, 61.45885235922677, 60.784008571079795, 43.32319940839495, 43.98360136577061, 55.394384724753245, 49.52262537819998, 56.88366161073957, 54.991778305598665, 56.85372877120972, 57.914340019226074, 58.709783690316335, 56.08847502299717, 55.92752000263759, 55.22404963629586, 59.817347390311106, 54.925947598048616, 55.05878325871059, 52.74593639373779, 52.57125868116106, 52.66321114131382, 54.07349395751953, 54.46994774682181, 52.911935806274414, 51.782652037484304, 49.611680439540315, 50.89724309103829, 51.909435817173545, 50.18416684014456, 50.927148137773784, 49.86053017207554, 49.71407604217529, 47.18088790348598, 43.47231469835554, 40.95285620008196, 26.08173792702811, 20.638995102473668, 10.208259497370038, 8.681834067617144, 9.174559491021292, 9.026951091630117, 11.567896025521414, 10.583883455821447, 9.184088945388794, 7.445027794156756, 6.226278586047036, 0.834164950464453, 0.39385470162544933, 0.030411182969276394, 0.1544722289379154, 0.3455112800002098, 10.350283282143728, 28.803944860185894, 46.69369411468506, 35.770368576049805, 32.073596886226106, 20.489867653165543, 23.627639395850046, 48.283323832920615, 43.993457385471885, 52.75412484577724, 62.06149046761649, 60.22317777361189, 27.960669789995464, 2.248298317193985, 0.1378943156450987, 0.07848290899502379, 0.087055086158216, 0.012213720241561532, 0.08923741762659379, 0.05050429103097745, 0.04340164769174797, 0.011375840603640037, 0.02858886182574289, 0.028931108103798966, 0.05297679460740515, 0.03985017504809158, 0.015280520410409995, 0.038119520592902384, 0.06260342536760227, 0.030318396698151315, 0.012761072388717105, 0.016350188458870565, 0.046508232065077336, 0.023000557674095035, 0.05598718646381583, 0.035811063035258224, 0.0443901307215648, 0.08702485063778502, 0.05543942889198661, 0.047794924450239966, 0.0681052247860602, 0.03453826704727752, 0.14095300223146165, 0.08876637861664806, 0.11736004107764789, 0.1425614966345685, 0.11136019017015185, 0.23427588599068777, 0.18334419253681386, 0.07757507663752351, 0.09380996333701269, 0.11466289151992116, 0.10595996065863542, 0.09309189686817781, 0.11910141977880682, 0.12174249520259244, 0.12261338132832732, 0.10123836116067, 0.07973394436495644, 0.1871125588991812, 0.12795603035816125, 0.22248069463031633, 0.13729264507336275, 0.16704861766525678, 0.16520513301449163, 0.15077470163149492, 0.20929928336824688, 0.274598697998694, 0.5400467813014984, 33.29336357116699, 80.99544974735805, 80.21042142595563, 79.24959673200334, 63.227912357875276, 53.935606956481934, 37.88656752450125, 40.387300627572195, 49.87527424948556, 56.47801535470145, 52.59240552357265, 49.87259571892874, 28.444526706423076, 5.713061187948499, 0.809870682656765, 0.13137334984328064, 0.284309809761388, 0.5115964593631881, 3.9323607853480746, 9.149759633200508, 15.003882714680262, 15.999399764197213, 20.816643169948033, 13.99648858819689, 29.259982926504954, 31.099049500056676, 23.357846055712017, 21.534020355769567, 32.81240579060146, 31.31911631992885, 32.01107004710606, 41.13676112038748, 44.433306149074006, 57.543591090611045, 56.38629565920149, 58.935482025146484, 54.998948846544536, 57.57757125582014, 56.55517510005406, 57.4341013772147, 56.45059776306152, 63.67188835144043, 59.252840995788574, 58.58081122807094, 53.16835560117449, 52.70296178545271, 48.34386696134295, 46.89372927801949, 51.790937764304026, 56.01363597597395, 53.89979246684483, 51.90469019753592, 56.3032785824367, 57.48094613211495, 59.809079033987864, 57.68015445981707, 64.19320474352155, 63.275806290762766, 60.41569151197161, 45.05370732716152, 48.73670768737793, 58.37359510149275, 54.3739583832877, 58.92472621372768, 55.96546064104353, 58.56735256740025, 58.97007015773228, 62.28183174133301, 58.801444326128276, 59.04956449781145, 57.80773033414568, 61.393240519932334, 56.670483929770334, 56.11716413497925, 53.46929250444685, 53.13474021639143, 54.17881127766201, 54.00839281082153, 55.379779611315044, 54.00930997303554, 52.39197431291853, 50.49706506729126, 52.256296839032856, 52.27165583201817, 50.13517509187971, 51.082718304225374, 52.693877015795024, 53.894814082554404, 52.24725028446743, 49.94178935459682, 49.67509664808001, 35.5431798526219, 33.972647258213584, 20.69352282796587, 19.16901683807373, 21.057495525905065, 15.676482234682355, 21.26791650908334, 23.60719779559544, 17.7079496383667, 11.671911426952907, 8.660798396383013, 0.25932973303965157, 0.3522950831268515, 0.16985419711896352, 0.614509539944785, 0.775772995182446, 12.613179547446114, 35.26108646392822, 58.851137842450825, 47.436456544058665, 47.820796149117605, 27.753688165119716, 28.903238092150005, 55.3237806047712, 49.052055154527935, 59.79502977643694, 69.54974474225725, 67.4567597252982, 35.5314165524074, 3.128744295665196, 0.25508829206228256, 0.19489789328404836, 0.16733039968780108, 0.14875084880207265, 0.2038471187864031, 0.1762871162167617, 0.23155007511377335, 0.07851304952055216, 0.1425078245145934, 0.09799175430089235, 0.0839710630742567, 0.1488543525338173, 0.09471529868564435, 0.1488227192312479, 0.11104359930115086, 0.07008797874940292, 0.10190246373947177, 0.11448143768523421, 0.11498423213405268, 0.17563697110329354, 0.13237988868994371, 0.1470133920333215, 0.1035200912239296, 0.14340586561177457, 0.07848342468163796, 0.10250913511429514, 0.14470919567559445, 0.12833398793424877], [0.02265154131289039, 0.021939288192827786, 0.03211639575394137, 0.0570837872635041, 0.0037601726279327913, 0.03150486606838448, 0.0063663603255658275, 0.01157530869490334, 0.022900777403265238, 0.04342433111742139, 0.040839343398277245, 0.028393430169671774, 0.0746717406436801, 0.00949764040498329, 0.03444109404725688, 0.05038869580520051, 0.024960146451901113, 0.041541837488434145, 0.02334199988815401, 0.018775905349424908, 0.04859612502955964, 0.0404014474313174, 0.034040877129882574, 0.11314999591559172, 0.013904066323967916, 0.15518241082983358, 1.8150061560528619, 37.23618834359305, 64.89060933249337, 60.01335607256208, 49.6996203150068, 39.64865847996303, 29.232839788709367, 19.76896251950945, 13.536738446780614, 41.054279054914204, 41.19865219933646, 35.116657733917236, 31.328968865530832, 6.82548645564488, 0.3664242449615683, 0.13501025683113507, 0.031505961902439594, 0.2314100797687258, 0.9592118433543614, 4.306643307209015, 4.916717725140708, 4.121176779270172, 10.537195035389491, 6.051051531519208, 14.675549064363752, 8.161407044955663, 17.06251757485526, 14.214643784931727, 18.92422137941633, 23.982108695166453, 41.86080510275704, 41.43648208890642, 52.084738867623464, 60.4577420098441, 57.655078411102295, 55.9363511630467, 57.61744696753365, 53.64296620232718, 58.54990564073835, 55.46901185171944, 54.03478901726859, 54.162750516619, 57.43913534709385, 53.84425898960659, 53.10789237703596, 44.6476719720023, 45.891611439841135, 44.084930419921875, 45.097546986171174, 44.699418681008474, 47.93335001809256, 44.0900616645813, 44.10777262278965, 46.54570095879691, 47.359897817884175, 49.44470827920096, 54.71855776650565, 57.01083101545061, 60.54785319737026, 59.97302177974156, 51.237475531441824, 35.888328143528526, 47.15828193937029, 46.31011881147112, 53.66838618687221, 55.88118246623448, 56.302264145442415, 55.331562587193076, 56.636670521327424, 53.56694596154349, 51.575415066310335, 50.50214420046125, 52.8730536869594, 57.0108449118478, 53.55447047097342, 51.342907496861045, 52.79900673457554, 50.63562604359218, 51.9787232535226, 53.56339543206351, 54.36040244783674, 49.53612572806222, 49.1779009274074, 45.79774127687727, 49.71292611530849, 48.983490330832346, 50.75873075212751, 47.85650641577584, 50.27377428327288, 56.8753376688276, 54.51205383028303, 48.24647058759417, 38.194487367357524, 31.80034508023943, 25.471627031053814, 13.733753749302455, 8.976973567690168, 10.09233227797917, 15.867759193692889, 8.342764581952776, 7.418370161737714, 5.053058751991816, 5.084954023361206, 1.5399469499077116, 0.4172671181815011, 0.05901746278894799, 0.007083906018773892, 0.033066568696605306, 1.9393987783363886, 11.44786068371364, 30.584108080182755, 36.32727016721453, 36.581695829119, 22.300298963274273, 20.88026261329651, 43.8477258682251, 41.68728426524571, 37.662647928510395, 46.34102092470442, 46.28795405796596, 34.5197171483721, 5.578728624752589, 0.3451086644615446, 0.0765825156122446, 0.05898955464363098, 0.019237148010038903, 0.057380707402314456, 0.029197358459766422, 0.06595740360873086, 0.05074367818555661, 0.03330109075510076, 0.02861510416758912, 0.027382002478199344, 0.0339020013676158, 0.048127002881041596, 0.024346165558589355, 0.004525706862165991, 0.03863940055349043, 0.0698693615517446, 0.04136475341926728, 0.04937675242711391, 0.03144829660387976, 0.053373432252556086, 0.03735289476545794, 0.07983420469931193, 0.019668580930946127, 0.04149559193423816, 0.03527241479605436, 0.01913998688438109, 0.03266750189608761, 0.02449476472767336, 0.07982826751789876, 0.03146173159724899, 0.04083993372374347, 0.004782908953659768, 0.01671099436602422, 0.06029310862400702, 0.009760040074719914, 0.006035390875435301, 0.011218858134400631, 0.01906841840328915, 0.029240465789501156, 0.06346912748579468, 0.07783418880509478, 0.04291396761046989, 0.059948399263833246, 0.02211826028568404, 0.02979257277079991, 0.03212209205542292, 0.06445600238761731, 0.044339440762996674, 0.016519338757331883, 0.043450848265950165, 0.11964616126247815, 0.04279487453667181, 0.12419252230652741, 3.5200494698115756, 49.225694111415315, 70.98272732325962, 69.11683028084892, 57.10417658942086, 48.95521463666643, 38.902189186641145, 27.69661045074463, 22.58512125696455, 39.03532361984253, 40.171173436301096, 34.08537483215332, 33.35191604069301, 7.564537678446088, 0.7060764293585504, 0.07434199298066752, 0.05223185136648161, 0.829349088881697, 2.1847303339413235, 8.355965290750776, 10.707970465932574, 10.132267917905535, 12.354074273790632, 9.050913691520691, 8.531942316464015, 11.480394755090986, 12.066815767969404, 9.888387884412493, 12.913312196731567, 20.84935528891427, 35.306142057691304, 41.350181988307405, 52.871459075382774, 59.84620325905936, 59.04600702013288, 57.56926815850394, 57.7181784766061, 55.7053096635001, 57.02268116814749, 56.004568576812744, 53.911340372903005, 54.910418374197825, 59.21033191680908, 56.168612071446006, 54.37054334368025, 47.22973026548113, 47.05292640413557, 46.21470614842006, 46.63408899307251, 46.82326412200928, 49.48728336606707, 47.1963198525565, 46.98223890577044, 48.62840264184134, 49.207052094595774, 51.469573157174246, 57.427757671901155, 58.566532679966514, 60.92655781337193, 60.66735526493618, 51.27543354034424, 43.166649545942036, 51.09491586685181, 48.10978215081351, 54.41648135866438, 56.995833328792024, 56.93902833121163, 55.46637501035418, 58.076778479984824, 55.141855921064106, 53.91807665143694, 53.23955726623535, 56.26455627168928, 58.00219651630947, 54.71261010851179, 52.55943979535784, 52.84456259863717, 52.114692551749094, 53.02348913465227, 53.23310586384365, 53.4778596333095, 50.78044387272426, 51.27735471725464, 48.63454484939575, 50.68456220626831, 48.7399594443185, 50.512695040021626, 49.94145584106445, 51.929227760859895, 55.82939406803676, 55.00501809801374, 49.25235434940883, 41.65374183654785, 30.564809458596365, 23.31232840674264, 10.442230531147548, 7.501215270587376, 9.755701610020228, 10.09742443902152, 13.560240728514534, 6.92108758858272, 12.832214559827532, 6.925905730043139, 3.6804112877164568, 1.6407221023525511, 0.12382683264357702, 0.013613874708036227, 0.016045845146956186, 1.7909011180911745, 11.986088122640338, 34.93449681145804, 40.08621433803013, 33.67843621117728, 23.605141128812516, 25.5349702835083, 49.450416224343435, 45.37016303198678, 43.54728923525129, 52.684608118874685, 53.381675720214844, 41.91877392360142, 8.360574551991053, 0.36479399672576357, 0.08290000911802053, 0.09356530396533863, 0.04647100763395429, 0.05188401056719678, 0.020168279563742023, 0.04158058862334915, 0.02011027160499777, 0.049628773903740306, 0.03725132825119155, 0.055330564733594656, 0.09259668844086782, 0.0620011305436492, 0.03272612053634865, 0.031848289604697905, 0.014929475229499596, 0.018504272514422025, 0.009456803623054708, 0.0762577483962689, 0.03146231174468994, 0.0918191144508975, 0.003102421136905572, 0.08367735919143472, 0.06242777979267495, 0.02211286423594824, 0.06358154038233416, 0.0045882745762355626, 0.07547267659434251, 0.15965041464992932, 0.1872144748589822, 0.19925032901976789, 0.13027089328638145, 0.11087608936109714, 0.12195719725319318, 0.09138931679938521, 0.11598062009683677, 0.1621920032692807, 0.15160944898213657, 0.12644029169210366, 0.08746785936611039, 0.19662827971790517, 0.12239828572741576, 0.18271865110312188, 0.06969557516276836, 0.14149169118276664, 0.22917205414601735, 0.12840783968567848, 0.14766616986266204, 0.12650169911129133, 0.12089657916554383, 0.13582851578082356, 0.20311223821980612, 0.15426165238022804, 0.27754875112857136, 6.052148478371756, 61.84847954341343, 78.729065486363, 77.23705795833042, 64.28832558223179, 54.33381864002773, 39.79395920889718, 29.184018271309988, 22.478419508252824, 59.769641058785574, 57.53521851130894, 48.51075226919991, 37.5367430959429, 9.364207965987069, 0.6172458274023873, 0.413460265312876, 0.18226514543805802, 1.049264948282923, 3.1771363275391713, 12.114533390317645, 16.1102808543614, 15.82399422781808, 18.840162072862896, 12.986939651625496, 23.95588619368417, 19.10588550567627, 29.03036059652056, 24.87391345841544, 29.553485257284983, 30.10349770954677, 46.31815440314156, 48.50126102992466, 56.564537797655376, 65.18421936035156, 61.3941924231393, 59.372009549822124, 61.28846863337925, 56.33941963740757, 57.634761878422324, 54.85574994768415, 52.97875663212368, 55.55398137228829, 61.633571760995046, 58.64392866407122, 57.86618900299072, 49.29652404785156, 50.16444090434483, 48.623768193381174, 49.760125228336875, 51.03695746830532, 52.78758042199271, 49.99841022491455, 50.67638765062605, 52.27693993704659, 51.85452767780849, 53.80618633542742, 57.720704146793906, 61.523533139910015, 65.20987905774797, 61.36423873901367, 52.69361298424857, 48.10564797265189, 55.58854866027832, 52.146831444331575, 56.67166859763009, 59.26985713413784, 59.368889808654785, 58.623146602085654, 59.82055745806013, 56.641739232199534, 56.66849674497332, 55.86152253832136, 57.65644025802612, 60.564424651009695, 54.95322275161743, 53.93142066683088, 53.41593033926827, 52.879762172698975, 53.267436913081575, 55.24013124193464, 55.32042809895107, 49.94338049207415, 50.18171412604195, 51.539941038404194, 52.65212181636265, 48.94826643807547, 51.4599985395159, 49.14803409576416, 52.94589512688773, 58.629990577697754, 57.8194762638637, 53.146031039101736, 44.229181970868794, 40.08583566120693, 32.55698306219918, 22.776563235691615, 17.233976534434728, 15.672855275017874, 25.584886142185756, 19.64499797139849, 17.240794454302105, 17.082703828811646, 12.37411548410143, 3.7401193295206343, 1.5509038248232432, 0.2360121485378061, 0.28881981489913805, 0.2195192285414253, 2.767081005232675, 14.796346970966884, 41.581414563315256, 50.32385342461722, 51.224246161324636, 31.372930118015834, 28.266083070210048, 54.884675298418315, 54.122642040252686, 48.53904185976301, 61.34961972917829, 60.19225134168352, 52.36580392292568, 11.642926148005895, 0.44391905090638567, 0.1589205688131707, 0.1648488071347986, 0.11223499144294433, 0.15792361088097095, 0.08462297237877335, 0.0935486052185297, 0.14977790654769965, 0.1496696937829256, 0.09724569147718803, 0.19858516114098684, 0.18135149803544792, 0.11436076701751777, 0.13244368455239705, 0.09778280622724976, 0.08643159390028034, 0.15064510144293308, 0.09236101287284068, 0.09942276429917131, 0.11827718972095422, 0.1794881865914379, 0.1367105705929654, 0.1956180224993399, 0.1756844007010971, 0.17543992453387805, 0.209566504029291, 0.08912518114915916, 0.1647855541003602], [0.05579980562574097, 0.02417945459352008, 0.1326867900788784, 0.05256702391696828, 0.03089694958180189, 0.03007429711786764, 0.0015457052109663241, 0.044124881204749854, 0.017677759186231663, 0.033652229234576225, 0.004741886422769832, 0.051250550629837174, 0.024412826535158923, 0.00519053462526894, 0.06242254150233098, 0.07233994826674461, 0.021674483116450052, 0.032886190339922905, 0.11160372995904513, 0.019025054926584874, 0.03975015559366771, 0.03193985790546451, 0.00930364809132048, 0.036871114546167, 0.05383360113150307, 0.8389383086136409, 15.220791578292847, 54.67333541597639, 62.55611188071114, 57.338841574532644, 49.70613425118582, 26.109551565987722, 18.581216607775005, 19.090538672038488, 26.65526134627206, 30.747446332659038, 28.442063570022583, 31.31727157320295, 10.945921080453054, 1.2291003955262048, 0.0961279407409685, 0.11883471480437688, 0.13735174547348702, 0.558699871812548, 3.3892858922481537, 3.617922229426248, 7.6564710310527255, 7.023885318211146, 10.685970732143947, 5.475430190563202, 8.293976068496704, 13.984059129442487, 20.431799820491246, 26.858329398291453, 27.26347017288208, 38.951660360608784, 48.12261199951172, 53.02853700092861, 54.515659945351736, 52.67885153634207, 53.99735907145909, 54.28806127820696, 56.217173031398225, 54.188361576625276, 52.215761048453196, 54.85391214915684, 53.43413461957659, 53.919160570417134, 55.69037798472813, 53.95642375946045, 49.41376447677612, 43.44132225854056, 42.47421639306204, 40.205782413482666, 44.32910054070609, 50.14438840321132, 52.59939888545445, 46.526457922799246, 44.313578265053884, 42.12589972359793, 44.76392228262765, 49.48774194717407, 55.142693178994314, 54.999205929892405, 58.34991564069475, 57.0395097051348, 55.361259187970845, 28.1932190486363, 38.03188909803118, 51.622690609523225, 53.332378251211985, 56.13672678811209, 54.75384071895054, 55.45390994208199, 52.3036835534232, 50.42072868347168, 45.2273462840489, 48.45395769391741, 54.084465163094656, 54.65659373147147, 52.4336496080671, 51.27198028564453, 53.3243704523359, 51.600188868386404, 51.432605266571045, 51.8833453314645, 52.4517878804888, 52.018411363874165, 49.64292648860386, 45.36093929835728, 48.37431396756853, 50.59674392427717, 49.48260375431606, 51.63061155591692, 52.43540402821132, 55.583862100328716, 54.65127141135079, 56.75426878247942, 52.738658155713765, 49.38451950890677, 38.200216157095774, 29.131972789764404, 15.506291321345739, 9.943215250968933, 6.326843338353293, 10.507304753576006, 5.6433777042797635, 9.121780974524361, 7.6122735398156305, 5.038157905851092, 0.9707881936005184, 0.2443030865064689, 0.07154973995472703, 0.1212568541190454, 0.10122441048068659, 1.7369271857397897, 15.340922457831246, 38.891874585832866, 52.66610854012625, 33.5292375428336, 24.05172790799822, 39.36937911169869, 45.4844400542123, 29.584307466234478, 50.118930203574045, 53.204305580684114, 51.17509113039289, 21.429814747401647, 0.26359519415668076, 0.059729856705026965, 0.03375703914623175, 0.025148921679439287, 0.02596997788974217, 0.05820282721625907, 0.03392427088692784, 0.04617719518552933, 0.0357771396770009, 0.025824491500056217, 0.0639236034559352, 0.027277916902676225, 0.03446965019351669, 0.0325900946211602, 0.021225486316585114, 0.0481323225955878, 0.06974955940885202, 0.05798838979431561, 0.03827581095642277, 0.04165726986580661, 0.05783929529466799, 0.05714406831456082, 0.02693189457724137, 0.04396623971738985, 0.05067590610789401, 0.06928510218858719, 0.015113281884363719, 0.0506708442366549, 0.010499505841705416, 0.037055601432387314, 0.02557045647076198, 0.020708505396864245, 0.02287714572490326, 0.033476074758384905, 0.04324975423514843, 0.07229829300194979, 0.030460722810987915, 0.04394062502043588, 0.0014395344125140192, 0.014171086817181535, 0.029551163581865172, 0.015581421853442277, 0.014195310517347284, 0.11206018725144011, 0.04784867799441729, 0.032199675749455176, 0.03475788508408836, 0.02513354268324162, 0.028967005998960564, 0.01838461625655847, 0.01838445510449154, 0.029954912274011543, 0.0356405336143715, 1.0162616563694817, 21.45579753603254, 67.4557522365025, 68.61947127750942, 63.33571365901402, 53.00530569893973, 34.261820861271445, 25.311707292284282, 20.138483354023524, 18.355521747044154, 33.40200907843453, 28.06776237487793, 31.481721537453787, 13.408770867756434, 1.7409585522753852, 0.04423461049529059, 0.13693752698600292, 0.24025234101074083, 2.5860296232359747, 6.97232186794281, 9.370646340506417, 8.932403479303632, 10.931519201823644, 15.787396328789846, 7.733511788504464, 3.763097890785762, 4.847379045827048, 16.580415078571864, 17.865513937813894, 28.61966473715646, 35.80461277280535, 49.19595929554531, 55.107775006975444, 58.71036039079939, 55.73781681060791, 56.2892119543893, 56.177401542663574, 58.876158305576865, 54.4684226172311, 53.79933193751744, 54.25924015045166, 52.73147719247, 54.952291693006245, 58.35205568586077, 54.44399969918387, 51.62630714688982, 45.2621602330889, 44.928865568978445, 42.25318724768502, 46.06839793069022, 50.8914726121085, 53.772404193878174, 48.41272013528006, 46.26301349912371, 44.339519364493235, 48.21845545087542, 51.58372858592442, 56.364304610661094, 56.54791075842721, 58.806280272347585, 57.29262563160488, 54.18008279800415, 32.60831635338919, 42.91761916024344, 53.02402762004307, 54.74589197976248, 57.26782056263515, 57.07965292249407, 56.27054909297398, 54.1848909514291, 52.462244919368196, 47.42698267527989, 49.72612769263131, 55.6303003856114, 56.19600534439087, 53.97887338910784, 52.07501833779471, 52.386002336229595, 50.86646951947893, 51.26167263303484, 51.457267897469656, 53.04772792543684, 51.508347579411094, 49.47505106244768, 47.080885955265586, 49.48774542127337, 50.15205921445574, 49.86649867466518, 50.83669301441738, 53.142136573791504, 56.79725728716169, 56.671178749629426, 56.561379841395784, 55.61151940482003, 51.360246726444785, 42.704788889203755, 29.635769299098424, 16.699706963130406, 9.098134517669678, 6.137066321713584, 7.511978898729597, 8.515022584370204, 9.506194404193334, 9.619192957878113, 6.217421804155622, 3.186811694077083, 0.9317753612995148, 0.20046306108789785, 0.03030328911596111, 0.008402317795636398, 1.959896832704544, 15.156760454177856, 35.985314573560444, 49.4171656199864, 33.01413631439209, 26.926248039518082, 44.077391624450684, 48.6624071257455, 35.50447491237095, 57.65969896316528, 59.30097116742815, 60.142801012311665, 27.9255588054657, 0.5080710085374969, 0.10005284513213805, 0.03757293349398034, 0.03817815619653889, 0.007040164682881108, 0.027217311851148094, 0.01757846915695284, 0.02378629783301481, 0.007508232557613934, 0.035020128690770695, 0.03258058834554894, 0.03781711110579116, 0.05016559009839382, 0.01597216133294361, 0.04586165604580726, 0.01519481634854206, 0.03937716828659177, 0.03725887016792383, 0.037136554052787166, 0.05446165314476405, 0.056651618132101636, 0.06309484078415803, 0.04364889567451818, 0.04263299982994795, 0.007830373843067458, 0.01007043507083186, 0.08562974192734275, 0.009038499506589557, 0.17858365869947843, 0.15150609452809605, 0.17516798126910413, 0.10320232648934637, 0.13868305832147598, 0.10607725222195898, 0.10805792308279447, 0.11072877262319837, 0.12810020547892365, 0.1516369567917926, 0.08768463773386818, 0.1788103301078081, 0.16245264214064392, 0.039802837052515576, 0.1392874430332865, 0.21679667463260038, 0.10883019771426916, 0.08780266890036208, 0.3571138488394873, 0.12179995354797159, 0.1300215588084289, 0.11014420791928257, 0.14580550470522471, 0.09624819750232355, 0.2230071292391845, 1.1335993600743157, 28.21833678654262, 79.36572197505406, 78.39661502838135, 73.96371296473912, 62.437804903302876, 37.94976486478533, 28.010483162743704, 27.315376690455846, 36.58539921896798, 47.19724743706839, 39.67775406156267, 40.23109817504883, 14.110787323543004, 1.9015730023384094, 0.32547951489686966, 0.3872881382703781, 0.26842112519911354, 2.792362242937088, 10.307232243674141, 12.732574786458697, 17.48027801513672, 17.378622395651682, 22.84569433757237, 12.889237557138715, 16.105908700398036, 22.3638402393886, 26.679036344800675, 31.669256891523087, 33.116948808942524, 42.348961217062815, 51.3228098324367, 55.94210427148001, 58.621270588466096, 56.807377338409424, 58.74782507760184, 58.63921083722796, 58.72094944545201, 54.97536318642752, 52.245353426252095, 55.069514751434326, 53.37281676701137, 56.9013169833592, 60.53622886112758, 58.44899000440325, 54.26984657560076, 48.56178331375122, 45.711385590689524, 44.67068093163626, 48.412087849208284, 55.41775846481323, 57.21717514310564, 52.32380206244332, 49.81249380111694, 46.759316376277376, 49.682812622615266, 55.87326151984078, 58.71514075142996, 59.301763262067524, 60.85084329332624, 59.02405071258545, 54.72517939976284, 37.627427509852815, 46.31881448200771, 55.8081499508449, 56.473544188908164, 58.493972642081125, 59.05874306815011, 60.1020359311785, 57.435699462890625, 53.76695333208357, 48.99294682911464, 51.93351827348982, 58.25282151358468, 58.67244407108852, 55.378136362348286, 52.60859482628958, 53.30859456743513, 53.647413049425396, 52.173731395176475, 53.45834214346749, 54.11077104296003, 52.7990380014692, 50.2125745500837, 48.47102246965681, 51.044979163578574, 52.18364994866507, 49.80544137954712, 52.92942789622715, 52.63377162388393, 58.283827849796836, 57.11886508124215, 61.941237994602744, 57.20663125174386, 55.01425225394112, 46.92345367159162, 36.31423882075718, 21.145027194704326, 21.428657872336252, 14.471019285065786, 18.30205362183707, 17.078409842082433, 16.878635236195155, 16.499678747994558, 12.636625375066485, 3.7859891653060913, 0.609616759632315, 0.35255317070654457, 0.16836815114532197, 0.23239642541323388, 2.8666660615376065, 20.466830900737218, 51.17248208182198, 65.95080021449498, 46.87321819577898, 33.31827981131417, 49.709285259246826, 55.5450564111982, 41.684546675000874, 63.39191763741629, 67.14659214019775, 67.964492389134, 35.14865071432931, 0.9591925186770303, 0.2285441378397601, 0.13483976812234946, 0.09974334495408194, 0.08166968942220722, 0.1026280348056129, 0.08544135346476521, 0.21270770047392162, 0.0675852701866201, 0.11640148822750364, 0.12963051907718182, 0.15886285262448446, 0.08334021549671888, 0.14920387949262345, 0.14840273319610528, 0.14693766752524035, 0.10304384785039084, 0.1317643488624266, 0.18082521270428384, 0.17942139160420212, 0.1785796010600669, 0.20674263127148151, 0.1632364857941866, 0.13560470779027256, 0.08715260521109615, 0.11642254995448248, 0.22952426810349735, 0.20520242463265145], [0.044858133287302086, 0.05313172450821314, 0.038570044096559286, 0.0073867798782885075, 0.06234778729932649, 0.03413261506440384, 0.038959458736436706, 0.023161614746121422, 0.038003009344850264, 0.06711796990462712, 0.038699070923030376, 0.011066202174073883, 0.06776440343154327, 0.10393149379108634, 0.03124122807223882, 0.03968135214277676, 0.025913949556914822, 0.04161032881321652, 0.0422014753068132, 0.020668342909110442, 0.04705518896558455, 0.011809935926326683, 0.07293200399726629, 0.08146739777709756, 0.03501970799905913, 1.9356550020830972, 33.36753906522478, 60.84078924996512, 57.26778929574149, 51.29138313020979, 40.59480857849121, 34.754121576036724, 27.134035655430385, 30.747481073651993, 50.23159524372646, 35.145590032849995, 35.887977259499685, 18.14600055558341, 2.065370053052902, 0.14337253597165855, 0.03327600531546133, 0.040588757023215294, 0.5338028477770942, 2.6067270040512085, 2.3625916242599487, 10.361512439591543, 8.011132274355207, 6.333752453327179, 10.135906168392726, 11.00097860608782, 8.396257894379751, 18.878646407808574, 37.25215530395508, 33.71674510410854, 46.3242757661002, 52.207801886967246, 61.22262750353132, 55.237296376909526, 54.06514917101179, 53.59626388549805, 52.18993806838989, 54.52457448414394, 56.42542791366577, 55.763153416769846, 54.89193616594587, 53.98991755076817, 52.12702907834734, 52.95100205285208, 55.04159688949585, 52.93651853288923, 48.07974508830479, 44.48537594931466, 39.47871943882534, 44.238346644810264, 46.80843319211687, 50.99879101344517, 50.44412326812744, 47.097443512507844, 45.11412191390991, 43.16107014247349, 45.11166572570801, 48.2660471371242, 52.2134507724217, 54.175799233572825, 54.76137604032244, 56.88165705544608, 54.88004779815674, 28.486629315785, 43.80093322481428, 50.81981584003994, 51.43308469227382, 54.61465440477644, 53.870213985443115, 53.64981712613787, 50.95793907982962, 49.629843030657085, 45.57430110658918, 46.59865665435791, 49.38618360246931, 54.949460302080425, 52.547044209071565, 51.3332599231175, 51.5656042098999, 52.535141944885254, 52.01749767575945, 50.49927806854248, 49.26191854476929, 49.831163610730854, 49.17942258289882, 49.28864131655012, 46.19652271270752, 49.50986501148769, 48.26821150098528, 48.725187574114116, 50.64354698998587, 54.43377889905657, 54.384338991982595, 51.858672278267996, 53.632439681461875, 54.48124551773071, 57.29611362729754, 41.98692185538155, 37.185119083949495, 33.66956683567592, 13.143983704703194, 13.161589571407863, 2.900822537285941, 10.178562896592275, 5.815248344625745, 5.925989168030875, 2.2668523958751132, 0.8047089853457042, 0.1622541163648878, 0.12855789091970238, 0.029520670218127112, 0.0926254176135574, 3.0102738184588294, 22.197868619646343, 35.4557089805603, 32.8720143863133, 20.132136174610682, 47.268793037959504, 71.9028286252703, 38.268054894038606, 25.764101028442383, 45.4226427759443, 45.249629156930105, 41.99938344955444, 6.207283513886588, 0.07160129504544394, 0.02578147916522409, 0.032538563279168944, 0.0430519205651113, 0.03694597392209938, 0.06546319941324846, 0.016501874962289418, 0.028766563361776725, 0.045643900587622604, 0.04045950288751295, 0.06440475942300898, 0.0670001015865377, 0.006481108230738235, 0.022969713168484823, 0.04490102348583085, 0.037532441916742494, 0.05946414239172425, 0.022473084906648313, 0.01998185715638101, 0.03979026379862002, 0.0404615384925689, 0.016594871579270278, 0.021110250714368055, 0.027072989149019122, 0.0683450394177011, 0.03909884000729237, 0.05085600965789386, 0.07178083541137831, 0.03920931229367852, 0.00997245715864535, 0.018769764607506137, 0.12106964630740029, 0.05491324873375041, 0.03466847452468105, 0.027279004255043607, 0.023117927268945744, 0.11554911253707749, 0.011029931932820805, 0.03476639391322221, 0.038525328638830354, 0.033367312380245755, 0.030788268627864972, 0.04160805572090404, 0.03349065647593566, 0.03395451997805919, 0.02527331920074565, 0.026726932896833335, 0.021748646993988326, 0.031509761698544025, 0.05588211870885321, 0.026094124353091632, 0.025188012081863623, 2.5695719463484625, 41.49194608415876, 70.34079020363944, 63.93186214991978, 59.5963807787214, 51.02776847566877, 38.83872086661202, 34.81517539705549, 31.187830107552664, 44.03944056374686, 43.18454810551235, 37.719876766204834, 20.606284720557078, 2.315209686756134, 0.20098915642925672, 0.0872097107182656, 0.35891468077898026, 2.2015412833009447, 5.4451994470187595, 6.686360938208444, 8.961593730109078, 11.8552839415414, 15.603161369051252, 12.462740625653948, 12.114258936473302, 6.981931660856519, 15.10748209272112, 25.72755524090358, 34.676294803619385, 43.37922273363386, 53.050656591142925, 61.001014709472656, 56.96432672228132, 55.40168380737305, 55.2796630178179, 54.54293509892055, 55.96998044422695, 58.62823963165283, 56.97301891871861, 54.95169414792742, 52.708909443446565, 50.902530670166016, 55.00316987718855, 55.7167637688773, 55.4855763571603, 49.76941844395229, 45.69961186817714, 42.405179091862266, 46.41577311924526, 49.14349692208426, 52.25360788617815, 52.254681382860454, 50.42897619519915, 47.679838044302805, 44.20253562927246, 47.641824449811665, 50.00983306339809, 53.313666752406526, 55.774572781154085, 54.56734412057059, 58.81074101584298, 55.029725892203196, 31.999105249132427, 47.190545899527415, 52.139792919158936, 53.56769984109061, 56.74653891154698, 55.31238555908203, 54.60874496187483, 52.42889356613159, 51.433772563934326, 47.3318201473781, 47.75257873535156, 53.28160776410784, 56.5572943006243, 54.42966556549072, 53.11095653261457, 53.748342582157676, 53.56782143456595, 53.25471476146153, 51.153781005314414, 49.96427719933646, 49.21551152638027, 50.95075811658587, 49.724342005593435, 47.16576862335205, 50.57993275778634, 48.36809532982962, 49.8749337877546, 52.45840951374599, 56.14561700820923, 55.882631165640696, 52.738484450748985, 55.300392968314036, 56.4834349496024, 55.28524242128645, 45.67671755381993, 35.861820765904014, 28.366635663168772, 13.718050820486885, 12.382765122822352, 9.107269661767141, 15.789011784962245, 7.594648565564837, 6.575681780065809, 6.559916751725333, 1.9552858344146182, 0.2595347591808864, 0.15360229276120663, 0.022693861542003493, 0.17693746489073547, 3.2403288909367154, 23.646670511790685, 39.09547764914376, 36.73712008340018, 20.973781892231532, 46.03867353711809, 68.96226065499442, 41.82641499383109, 33.80487952913557, 51.61685759680611, 52.499400411333355, 50.20924636295864, 9.612387197358267, 0.02753801124968699, 0.009775139175222387, 0.03955931083432265, 0.018171128783641115, 0.027818532893434167, 0.041043446731886694, 0.042113408246742826, 0.0034873884038201398, 0.02139022613742522, 0.06453013912375484, 0.013639216294645198, 0.04853799493451204, 0.03464974356549127, 0.0026190756221434897, 0.04155913334605949, 0.03077029762789607, 0.05655930683548961, 0.016716772091708014, 0.008564323120351349, 0.0235254995059222, 0.029911051770406108, 0.15544653737119266, 0.040114406762378554, 0.025709832652605007, 0.054201336577534676, 0.05642801709473133, 0.05125211804573025, 0.15105808499668325, 0.1525856844548668, 0.11326543507831437, 0.09880983683147601, 0.21138307798121656, 0.10809543249862534, 0.1555692572146654, 0.18105739381696495, 0.08674084302037954, 0.19592781444745405, 0.14214165987712996, 0.10809509323111602, 0.12332914077809878, 0.18851837489221776, 0.10194754560611077, 0.13704082715724195, 0.11192914856863873, 0.2743722301508699, 0.1553935437862362, 0.10013735666871071, 0.14244554857058184, 0.09897299736206021, 0.2085908249552761, 0.16040182432958058, 0.1330291788492884, 3.7605691807610646, 52.79144014630999, 79.3606984274728, 71.38397884368896, 66.03572804587228, 55.86634806224278, 47.87393249784197, 36.06876243863787, 43.65541015352522, 68.79711587088448, 47.36598791394915, 46.560406821114675, 22.667721441813878, 2.769809910229274, 0.45100273936986923, 0.18674389725284918, 0.44116417158927235, 1.7417426130601337, 7.4348234960011075, 9.32951387337276, 19.50348401069641, 17.79107267516, 17.919536181858607, 18.819942814963206, 22.802294152123586, 12.76033457687923, 26.438955238887242, 48.3098590033395, 37.80840376445225, 47.942726612091064, 53.96661329269409, 64.41705485752651, 58.85323619842529, 58.62040206364223, 57.41285031182425, 56.649774823869976, 58.786213874816895, 60.77461460658482, 56.19092968532017, 56.85372877120972, 53.37521389552525, 51.318383829934255, 56.09435667310442, 59.19052955082485, 57.904393672943115, 52.78367553438459, 48.90740755626133, 43.59410272325788, 49.08664328711373, 51.79400886808123, 55.73520081383841, 55.38071761812483, 53.623170784541536, 49.700315134865896, 47.00490045547485, 48.65971122469221, 51.94782114028931, 54.88687092917306, 58.90536853245327, 57.08087927954537, 61.04498291015625, 56.30199663979666, 35.846757071358816, 49.2433112689427, 52.54185043062483, 53.936148915972026, 58.212421212877544, 57.55698026929583, 57.372012274605886, 54.22766406195504, 53.07933528082711, 50.42289999553135, 50.146045548575266, 54.8434168951852, 57.65678071975708, 56.58364881787981, 53.832860469818115, 55.08754185267857, 53.88433967317854, 54.80353076117379, 52.671410015651155, 52.438148566654746, 49.352599484579905, 53.28977189745222, 50.51843077795846, 49.602130140577046, 51.82147509711129, 49.22406128474644, 50.337193965911865, 52.69636099679129, 57.30156101499285, 59.83263342721121, 55.799089499882285, 57.97863170078823, 59.58630589076451, 60.73639256613595, 46.45738935470581, 42.66562189374651, 42.55865090233939, 19.201042822429113, 21.56567461150033, 11.809147902897426, 21.944457394736155, 14.822475671768188, 12.09046483039856, 8.170292922428676, 2.1965322835104804, 0.24962806648441724, 0.2929908510829721, 0.14743393446717942, 0.31770206508891924, 4.270186543464661, 27.8586893422263, 46.018892015729634, 42.972162519182476, 29.944978032793315, 54.36896957669939, 77.38101073673793, 49.37509427751814, 37.40635667528425, 60.14821365901402, 58.36559077671596, 59.93046406337193, 13.16338220664433, 0.36350258173687117, 0.13452239015272685, 0.11526851116546563, 0.12324930434780461, 0.1559651145445449, 0.14682625207517827, 0.207114292042596, 0.09484688019646065, 0.08929377674524273, 0.13516231652881416, 0.10891389500881944, 0.20267520738499506, 0.09061710323606219, 0.08254180369632584, 0.11222748006028788, 0.09616181320909943, 0.13183720995272907, 0.1358444206416607, 0.07413411699235439, 0.09866154978850059, 0.1103205048878278, 0.3485066864107336, 0.10594069704945598, 0.09483529081834213, 0.1249230331076043, 0.18218133279255458, 0.304186678890671], [0.03346770842160497, 0.07930085581860372, 0.021543400328872458, 0.00981241449647184, 0.026813785379220332, 0.009590556445930685, 0.04875639160828931, 0.032445719332567284, 0.01683393812605313, 0.047719043879104514, 0.06841564098639147, 0.03588605133284416, 0.021254190044211488, 0.021349205302872827, 0.013651018563125814, 0.022078540542029908, 0.048545787909201214, 0.02736357685976795, 0.0032617731776554137, 0.04191698592954448, 0.058412338473967144, 0.02593258721753955, 0.028732293950659887, 0.07292880131197826, 0.11611749418079853, 5.901435536997659, 43.72824811935425, 62.43934045519148, 56.483646869659424, 38.18011154447283, 33.61945642743792, 21.47065452166966, 19.598069838115148, 32.999819551195415, 26.676594052995952, 30.662414278302872, 18.423824276242936, 3.815086918217795, 0.2121420329702752, 0.12691780392612728, 0.04002366288165961, 0.5509796089359692, 2.381264690841947, 3.3297406988484517, 6.893960952758789, 6.4037516457693915, 6.767406029360635, 13.055292555264064, 19.441327163151332, 13.533460634095327, 14.708785772323608, 29.600479398454937, 49.29627391270229, 52.465486254010884, 58.291057450430735, 54.51839058739798, 57.09056854248047, 51.75865295955113, 50.5500659261431, 45.2527072089059, 50.3289464541844, 51.99358197620937, 56.1072108404977, 52.88779081617083, 53.84733704158238, 55.0282598223005, 52.76937961578369, 54.674933501652305, 52.76039906910488, 50.61924566541399, 45.56429917471749, 39.86468839645386, 42.90674522944859, 44.72386244365147, 49.985027994428364, 53.039390087127686, 52.636134011404856, 46.90323788779122, 44.82095309666225, 42.34254455566406, 47.59365953717913, 46.453672068459646, 50.1077436038426, 52.425217969076975, 57.01988104411534, 52.25292696271624, 55.99626547949654, 29.071285486221313, 38.43560028076172, 53.01018680844988, 53.03320271628243, 55.13308729444231, 51.57710347856794, 51.745187350681846, 51.242940289633616, 45.934460980551584, 44.36956337520054, 46.382744857243125, 50.27606718880789, 52.53507246289934, 52.22630841391427, 53.15585231781006, 51.20747668402535, 51.97768102373396, 53.40483406611851, 52.69637489318848, 50.87945917674473, 49.432715688432964, 48.66568667548043, 50.399578366960796, 45.712208952222554, 46.892009598868235, 47.55076483317784, 49.77945164271763, 49.946086815425325, 54.68052332741873, 53.553438663482666, 50.979450702667236, 50.02001912253243, 54.46616792678833, 54.90534618922642, 56.74832112448556, 49.43126351492745, 34.521561895098, 27.882540770939418, 13.865011300359454, 9.760801587785993, 8.85660992349897, 8.050392201968602, 4.758537207330976, 4.100346514156886, 2.294982612133026, 0.3914457123194422, 0.0461094366785671, 0.04035840456240943, 0.08186869695782661, 0.12218080168323857, 4.171202940600259, 27.888088907514298, 55.36153711591448, 45.76694686072213, 50.17913981846401, 63.794836725507466, 37.01512793132237, 38.8537289755685, 37.296741894313264, 48.56593138831002, 46.87709181649344, 19.46665334701538, 0.6726374636803354, 0.15043831111064979, 0.009278940934953945, 0.02623834697130535, 0.035275220538356473, 0.04951013544840472, 0.07017877352024827, 0.06910464580037765, 0.08040610115442957, 0.04075513720246298, 0.0566463153809309, 0.11396714885319982, 0.04714144772983023, 0.03442497544788888, 0.07233325112611055, 0.03021364106929728, 0.03158728093174951, 0.0700865402551634, 0.05162636064259069, 0.04224632986422096, 0.03031238487788609, 0.04428622326148408, 0.044609395920165947, 0.03172393449183021, 0.003161748210134517, 0.06703423189797572, 0.05194554351536291, 0.0337381385532873, 0.04648223060316273, 0.0417770109405475, 0.03405970986932516, 0.006041811513049262, 0.003071566029185695, 0.01883412874303758, 0.01742578690339412, 0.0658253471234015, 0.016492916603705714, 0.04539601817460997, 0.016941626722525274, 0.03717687260359526, 0.020105937462566153, 0.008185628485599799, 0.03210512189460652, 0.03026841241600258, 0.009734723933174141, 0.01886979932896793, 0.016505941083388667, 0.05257009428792766, 0.039829099750412364, 0.09205432182976178, 0.10247360023536853, 0.12446420772799424, 8.169401815959386, 53.49589020865304, 70.58819471086774, 62.81615516117641, 45.43236330577305, 39.78344658442906, 29.446194648742676, 19.49199342727661, 32.25233234677996, 35.528814452035085, 35.808211939675466, 21.493102414267405, 4.650748934064593, 0.2996164469846657, 0.11104009127510445, 0.14503635812018598, 0.9577593441520418, 5.007770827838352, 8.403592586517334, 11.566667062895638, 10.772433246885027, 9.863489883286611, 9.50990561076573, 8.302392942564827, 10.918480038642883, 17.034542390278407, 31.813647406441824, 46.732663086482454, 51.0849278313773, 54.78377703257969, 55.424004895346506, 58.94557080950056, 54.96418700899397, 53.57610021318708, 48.58791201455252, 50.90823861530849, 54.562410899571006, 58.13395173209054, 54.84109967095511, 53.20326682499477, 55.521547181265696, 52.639854771750315, 57.03711257662092, 56.036700521196636, 54.39644275392805, 46.39071444102696, 41.576463971819194, 43.280405453273225, 46.792914390563965, 52.42383180345808, 54.03059230531965, 55.20005055836269, 49.43637044089181, 46.5520133972168, 43.60758917672293, 48.294757093702046, 49.15609400612967, 52.29117332186018, 52.53774751935686, 59.00168446132115, 54.12291301999773, 54.45455053874424, 31.59922252382551, 41.001257351466585, 53.63598326274327, 54.10198504584176, 55.060954570770264, 52.31472424098423, 53.79465579986572, 53.00136259623936, 48.72808149882725, 46.169935430799214, 47.65100302015032, 50.98512390681675, 54.382640157427105, 54.54622507095337, 54.13673298699515, 53.3189890725272, 52.51132352011544, 54.5380539894104, 54.60329062598092, 51.51130403791155, 50.90339919498989, 49.193308557782856, 49.773014136723106, 47.0056334904262, 47.415462562016074, 48.50935220718384, 48.777913979121614, 50.42800692149571, 56.398555755615234, 55.643623556409565, 53.00281476974487, 51.92996079581124, 55.83456352778843, 56.334145954677034, 57.42417587552752, 51.503223282950266, 35.60403912408011, 23.62124010494777, 15.470831189836774, 9.061710323606219, 6.828441177095685, 10.360357301575796, 11.877309731074742, 6.525165336472647, 4.529397342886243, 2.1128084446702684, 0.3436933761196477, 0.044002185110002756, 0.03598148389054196, 0.18818263576499053, 4.685836902686527, 28.331632375717163, 42.94850042888096, 26.213340282440186, 48.81287384033203, 72.02353967939104, 43.69093976702009, 40.195276737213135, 42.53620474679129, 53.26865632193429, 54.560659953526084, 26.62705339704241, 1.0189886071852274, 0.13697989471256733, 0.042653013220322986, 0.06707342408065285, 0.04807616025209427, 0.021042251327474202, 0.028264554317242334, 0.08062239776232413, 0.006538506356134478, 0.02401779532166464, 0.057595809788576195, 0.04177455464377999, 0.011144988571426697, 0.07017259206622839, 0.04734579533604639, 0.024835526710376143, 0.04601121534194265, 0.03273537236132792, 0.030369883935366358, 0.035189056769013405, 0.015891422451074635, 0.042554028531802554, 0.03691216591479523, 0.031174317734049897, 0.02093481718163405, 0.0256809168827853, 0.03694314782374671, 0.0952706728130579, 0.15860761489186967, 0.23226356825658254, 0.0756991987249681, 0.1216179568852697, 0.07804450073412486, 0.13842487574688025, 0.1685670976127897, 0.13607463400278771, 0.09186699866716351, 0.18664411189300673, 0.07529243055198874, 0.07049434658672128, 0.08045235010130064, 0.11758394406310149, 0.10916828457266092, 0.15623100527695247, 0.10845288474644933, 0.12804415848638329, 0.14562630360679968, 0.16205493919551373, 0.07241528600986515, 0.23140834271907806, 0.13365077120917185, 0.32360559116516796, 12.354973196983337, 65.64789349692208, 78.61926310403007, 71.46055494035993, 53.29428475243704, 46.13634436471121, 32.27289554050991, 29.689520563398087, 45.021425996507915, 36.98292997905186, 42.172723633902415, 25.46629081453596, 5.344313774790082, 0.4023016483655998, 0.26609247443931444, 0.20479337658200944, 1.2771756329706736, 6.519758769444056, 10.702632512365069, 18.427152463368007, 17.070382935660227, 15.034070900508336, 23.79576669420515, 28.62562802859715, 19.538897241864884, 20.664130210876465, 34.53551735196795, 56.61786869594029, 53.494309493473594, 60.21488857269287, 56.18407528741019, 62.342524256025044, 56.06849895204817, 55.97275277546474, 49.4047074999128, 54.336660453251426, 56.27978324890137, 60.151305607386995, 54.77813162122454, 54.07432426725115, 55.845423562186106, 54.480912004198345, 57.933093207223074, 58.55388695853097, 55.78706564222063, 50.38019636699131, 44.663600717272075, 46.485338483537944, 48.17329216003418, 55.22536284582955, 56.00239726475307, 57.66242960521153, 51.039295537131174, 49.555229800088064, 46.25442205156599, 50.63535506384713, 50.498690945761545, 54.63247653416225, 55.847403798784526, 60.97620964050293, 55.7949344771249, 56.46825660978045, 36.218516962868826, 44.30327756064278, 55.81685951777867, 57.080180985586985, 58.46074635641915, 53.77348811285836, 56.132929597582134, 55.167588574545725, 49.93340982709612, 49.39635229110718, 49.85211590358189, 54.32910776138306, 55.63025522232056, 56.751235893794465, 55.65839542661394, 54.826119354793, 54.62399278368269, 56.47388117653983, 56.29924862725394, 53.36198452540806, 52.41353109904698, 50.733557428632466, 51.62496614456177, 48.94121749060494, 49.223088536943706, 49.38398102351597, 50.30671221869332, 49.67346729551043, 58.06606783185686, 58.55976513453892, 55.62940754209246, 55.11629349844796, 59.83071572440011, 58.13156155177525, 61.15697397504534, 54.68514387948172, 38.16882766996111, 31.009125913892472, 18.316974878311157, 13.736180407660347, 19.872197117124283, 19.897146361214773, 13.152848737580435, 10.558376618794032, 5.528468830244882, 1.680541142821312, 0.3493375118289675, 0.2422159399305071, 0.174146012536117, 0.40312756119029863, 5.363820842334202, 36.50261490685599, 66.44301755087716, 57.39072029931204, 57.05892992019653, 66.37151363917759, 45.899758202689036, 51.06152629852295, 50.034790992736816, 63.071397236415315, 61.73557826450893, 35.78424412863595, 1.2792655208281107, 0.24355759365218027, 0.08187692080225263, 0.13276218889015062, 0.14169867150485516, 0.11710435551192079, 0.1473809815943241, 0.16379842135523046, 0.1184745484164783, 0.12701726358916077, 0.15336324487413677, 0.1829217637756041, 0.13355436495372228, 0.144596165312188, 0.178427731352193, 0.13715693806963308, 0.1388210044907672, 0.15424289767231258, 0.08489518705755472, 0.11438766414565699, 0.12430684188646929, 0.1070255795493722, 0.17874452578169958, 0.1652950117630618, 0.09391455951013736, 0.1661449447274208, 0.11835712114615099], [0.013769540819339454, 0.018390237919187973, 0.028859593905508518, 0.014567032356613448, 0.0470252418225365, 0.07071825635752507, 0.03464961464383772, 0.03153916262090206, 0.01968356468049543, 0.011064782339547361, 0.09407938923686743, 0.026209409149097543, 0.10467352611677987, 0.012087745974505586, 0.039742854556867054, 0.04013876956222313, 0.027114064266373004, 0.030226485737200295, 0.05506709976387875, 0.07368694205901452, 0.038121400134904046, 0.015027788168351566, 0.11430322724793639, 0.046561622593019686, 0.528890851352896, 17.35409525462559, 52.79875659942627, 57.06976216179984, 47.07662670952933, 41.02129248210362, 36.24310663768223, 23.115020411355154, 45.621528012411936, 43.17919451849801, 41.10429218837193, 34.96494729178292, 10.786323564393179, 0.6980736245002065, 0.1398828575121505, 0.01909209249008979, 0.0674906891903707, 0.8702325065221105, 4.581633465630667, 6.735779132161822, 7.497173156057086, 7.147536328860691, 11.870964288711548, 19.499824047088623, 21.24739326749529, 23.36850459235055, 42.727467809404644, 55.54244041442871, 55.630116258348735, 59.697345052446636, 53.284185545785085, 53.73534945079258, 55.740874017987935, 55.5990960257394, 48.26672111238752, 46.07581860678536, 48.042763301304404, 51.23857682091849, 56.17708192552839, 55.332771573747905, 52.376966203962056, 52.51769501822335, 50.52487523215157, 52.79691185270037, 55.44156299318586, 51.33488232748849, 43.937607765197754, 39.16548422404698, 41.88381058829171, 47.257946899959016, 52.5678505897522, 50.190979548863, 52.41849211284092, 47.395587239946636, 46.60438544409615, 42.706682273319785, 45.76911122458321, 44.83645452771868, 48.999943665095735, 50.48926224027361, 55.19733033861433, 52.583428450993125, 59.302492822919575, 29.134303910391672, 39.179630756378174, 54.796572140284944, 50.01685421807425, 53.21312631879534, 49.08115421022688, 52.244675976889475, 50.13557113919939, 46.046789033072336, 44.501443658556255, 45.97980145045689, 46.28636292048863, 50.74173545837402, 50.41282858167376, 50.541599546160015, 49.15312712533133, 49.29074314662388, 50.43240860530308, 51.69218649183001, 50.28624977384295, 50.71045814241682, 49.27845525741577, 50.26159061704363, 47.61872863769531, 48.07321030752999, 48.369109766823904, 49.1421593938555, 48.421203885759624, 52.5245737348284, 53.73837191717965, 49.92951536178589, 47.96416180474417, 45.73597526550293, 51.57082578114101, 52.44517319543021, 57.1845429284232, 53.42031117847988, 37.060933930533274, 33.94247817993164, 18.1064635685512, 13.414394565990992, 3.854879685810634, 7.415447575705392, 8.768150670187813, 2.1682906789439063, 1.5950772144964762, 0.6523618602326938, 0.07603855444384472, 0.16817692640636647, 0.014806176934923445, 0.6673078696642603, 6.630683720111847, 41.91993079866682, 54.43993500300816, 28.22138704572405, 16.64447225843157, 22.86547933306013, 34.815324783325195, 39.1387232371739, 44.77001237869263, 50.887126513889854, 34.07614762442452, 4.555747517517634, 0.12354842972542558, 0.024602899460920265, 0.04147913406736084, 0.014277871265741331, 0.029845657957983867, 0.02133313420095614, 0.05740058169301067, 0.0675475639956338, 0.03570327435487083, 0.11565325409173965, 0.09067232920122997, 0.05716179843459811, 0.01847968410168375, 0.015962851832487752, 0.0804320890456438, 0.04346487697746072, 0.04283344925248197, 0.03410846261041505, 0.029348522491220917, 0.030624297247933488, 0.02489209108586822, 0.03751715113009725, 0.008929363934190145, 0.08144105026232344, 0.08981483735676322, 0.03546323919934886, 0.05716854307268347, 0.02646481990814209, 0.04029385552608541, 0.01947145293732839, 0.049514087914888344, 0.022515829220148068, 0.006028616975527257, 0.039066446745502095, 0.01669700806295233, 0.004229022938358996, 0.04029723123780318, 0.08023881513093199, 0.047973467369696925, 0.013502147131865578, 0.0502668071671256, 0.060152930074504445, 0.04519863912303533, 0.07852672878652811, 0.0020730775764345056, 0.032278100826910565, 0.037955216730811765, 0.009436116786673665, 0.061011758632957935, 0.06237688288092613, 0.5997823987688337, 23.087222405842372, 65.3699586050851, 63.18156092507498, 54.96003893443516, 48.564006737300325, 43.85440656117031, 26.2411903994424, 34.452826840536936, 37.34697042192732, 38.01168721062796, 31.610405649457658, 11.378211072513036, 0.9817630904061454, 0.05894878825971058, 0.11196627121950899, 0.6759246130074773, 2.5451333948544095, 7.220810728413718, 7.5387885229928155, 9.588707736560277, 10.206349611282349, 7.471304144178118, 8.10452561719077, 19.465663228716167, 25.47406758580889, 42.81779786518642, 52.684771401541575, 57.358855860573904, 57.210616043635774, 54.684890270233154, 55.094166960035054, 58.171263558524, 55.351337160382954, 50.84140736716134, 48.20993001120431, 51.19506025314331, 52.800674302237375, 57.655377183641704, 55.31837838036673, 53.62501553126744, 52.076269013541086, 50.6253843988691, 53.12651007516043, 56.60736301967076, 52.356340476444785, 45.81189823150635, 41.56274822780064, 43.65148442132132, 47.907516615731375, 53.63974223818098, 53.42277431488037, 53.93295969281878, 49.47786160877773, 47.46152564457485, 43.58543484551566, 47.10007340567452, 46.24597651617867, 51.37098516736712, 51.68654802867344, 56.59556497846331, 55.06288616997855, 58.74599770137242, 31.295871121542795, 41.13825498308454, 56.79288339614868, 51.826453481401714, 54.38768802370344, 52.490739481789724, 53.26435191290719, 51.43086126872471, 49.08377020699637, 46.211395331791465, 47.17024673734392, 48.581210477011545, 50.86638961519514, 51.79985230309622, 51.99731315885271, 50.969921248299734, 50.861411230904714, 52.45357356752668, 52.977439948490684, 51.23904235022408, 53.14407859529768, 50.3742104939052, 50.97560487474714, 48.74554927008492, 47.72068650381905, 48.538496426173616, 49.84082508087158, 48.48797607421875, 53.30440827778408, 55.010944911411826, 52.929455689021516, 49.480078084128245, 49.42929022652762, 53.38827998297555, 55.80923386982509, 57.59016139166695, 53.82743392671858, 36.113943099975586, 23.68815646852766, 11.325147679873876, 8.440763711929321, 10.790309224809919, 12.130427394594465, 10.364879710333687, 7.477303045136588, 4.742089952741351, 2.4568005119051253, 0.28442510643175667, 0.10503937184278454, 0.05660227167287043, 0.689323182616915, 8.783385464123317, 40.06255919592721, 52.20395605904715, 38.05549560274397, 31.523025103977748, 28.749776703970774, 40.007942880902974, 42.6259719984872, 50.23889085224697, 57.57641090665545, 41.86040905543736, 6.568380091871534, 0.0897485784121922, 0.0334699543725167, 0.10639676079154015, 0.03532522178388067, 0.020861693159011856, 0.09975504968315363, 0.02010245488158294, 0.029952340626290867, 0.01745973909938974, 0.0329741488343903, 0.07274558328624282, 0.052689781079867055, 0.019814876473641822, 0.05214933133018868, 0.07422931545547076, 0.03075315783332501, 0.028302655754876987, 0.023247941363868967, 0.026502414140850306, 0.03526554123631545, 0.05480326499257769, 0.03788173138829214, 0.027989296408902322, 0.050113895907998085, 0.03618459317034908, 0.05389581600736294, 0.17780480906367302, 0.08490973484835454, 0.12239971065095492, 0.07966233856443848, 0.17394194991460868, 0.09860118052789144, 0.11898349039256573, 0.14234317120696816, 0.0755863922781178, 0.12244623101183347, 0.23856333164232119, 0.14991085869925364, 0.13754294307104178, 0.10779068885104996, 0.10257503443530627, 0.12253412843814918, 0.12472119608095714, 0.19733619530286106, 0.10961129330098629, 0.21462177990802697, 0.17663824451821192, 0.07580247175480638, 0.1914838579084192, 0.1735419263797147, 1.137243581669671, 31.530397142682755, 73.86301272256034, 71.56920392172677, 62.8817253112793, 54.77791970116751, 50.33135053089687, 34.06176137924194, 59.90874399457659, 58.08203131811959, 53.788954802921836, 41.53069618770054, 13.63004754270826, 1.0623927009957177, 0.2641345209309033, 0.16340317470686777, 0.5303582240428243, 2.0370316079684665, 12.011654019355774, 15.565215519496373, 17.510579109191895, 16.231464385986328, 22.614965506962367, 29.49715621130807, 29.455077920641216, 30.018615041460308, 46.510602133614675, 58.271522590092246, 59.19899940490723, 61.24010222298758, 53.48635033198765, 56.09109449386597, 60.843367031642366, 59.78704629625593, 52.79598079408918, 51.52692706244332, 52.31848669052124, 56.46586990356445, 59.724922452654155, 56.77001340048653, 54.04575327464512, 51.95456089292254, 50.106548513684956, 53.985230990818565, 59.07908044542585, 55.71048954554966, 47.82551397596087, 44.45384502410889, 45.726393699645996, 51.234303678785054, 56.47215802328927, 53.872194222041536, 58.35480717250279, 51.667016642434255, 51.24052579062325, 47.197817189352854, 49.400267601013184, 49.389490944998606, 53.632432733263286, 55.07434722355434, 57.66408675057547, 58.39197308676583, 59.951350348336355, 35.10943855558123, 43.67055375235421, 56.9898544039045, 55.18024819237845, 56.27436017990112, 53.84275470461164, 56.09030934742519, 54.59999023165022, 50.28319604056222, 49.07083266122, 50.54565382003784, 50.172063078199116, 52.74137837546212, 53.496223722185405, 54.88220521381923, 54.26156432288033, 53.27423572540283, 53.82520355497088, 54.94046238490513, 53.97965506144932, 54.96627494267055, 52.476221220833914, 53.1152400970459, 50.20065491540091, 48.462260791233604, 50.239057609013145, 49.54140288489205, 49.77239227294922, 55.35678802217756, 56.36210550580706, 55.00444834572928, 52.61822850363595, 51.273689542497905, 55.685924189431326, 57.23284680502755, 60.33314691271101, 58.401846476963584, 40.251220158168245, 38.850980963025776, 25.098962136677333, 19.28021580832345, 12.706278460366384, 15.922477994646345, 16.219067062650407, 10.406265786715917, 4.571633270808628, 2.075785185609545, 0.24138465310846055, 0.46395754707711084, 0.16713297313877515, 1.0280590461833137, 9.513596841267177, 52.25735296521868, 66.6002413885934, 37.30698353903634, 24.89313738686698, 31.836451394217356, 46.80651896340506, 51.38328347887312, 57.96496459415981, 63.053998947143555, 51.647294180733816, 9.759398920195443, 0.18219674910817826, 0.08095185365527868, 0.25649313096489224, 0.19975344916539534, 0.1797744333744049, 0.15269309654831886, 0.1303971686533519, 0.13155910558998585, 0.07733379637024232, 0.16694797735129083, 0.16090646439364978, 0.18079414937113011, 0.11532576595033918, 0.08654336897390229, 0.19106206697012695, 0.16045631069157804, 0.11686601330127035, 0.12431858054229192, 0.09453529013054711, 0.15140434141669953, 0.15674503626567976, 0.08304575844002621, 0.11280126284275736, 0.174324738660029, 0.18361647506909712, 0.13014271802135877], [0.0211500875053129, 0.033984999771096876, 0.020457876613363624, 0.03743600173454199, 0.0661459481343627, 0.0482387508132628, 0.03966105716036899, 0.01650149328634143, 0.05387398414313793, 0.03530496072822383, 0.036291476006486585, 0.05501804168203047, 0.0689434123092464, 0.03875219003696527, 0.008436707646719046, 0.08757692708500794, 0.039343431525464566, 0.06367413327097893, 0.010202451692228871, 0.02837090619972774, 0.06473713980189391, 0.03354139053928001, 0.04561276940096702, 0.08277526724019221, 2.469907202890941, 37.17462730407715, 56.27390854699271, 54.95790236336844, 43.41696187428066, 32.227040903908865, 21.965098755700247, 23.23327006612505, 50.658635003226145, 41.16607557024275, 37.66193573815482, 22.639864376613072, 1.9509901106357574, 0.1776239387691021, 0.060070087734077654, 0.0860036350786686, 0.1673419890659196, 2.443022451230458, 6.258404016494751, 7.81085044997079, 8.010612896510533, 10.394646661622183, 4.220020115375519, 12.066111394337245, 30.18473604747227, 49.134026527404785, 57.45936155319214, 57.44279704775129, 59.91756820678711, 57.659254278455464, 53.30751412255423, 53.15137072971889, 52.805913243974956, 52.38386229106358, 45.80241046633039, 41.820307527269634, 48.09938417162214, 50.14423554284232, 55.820837361471995, 52.94433178220476, 50.94467149462019, 52.133240767887656, 51.904773575919016, 50.334654399326865, 52.26398502077375, 50.11167975834438, 43.701963084084646, 36.245159830365864, 42.34542805807931, 44.625347409929546, 49.14348302568708, 51.33524015971592, 53.54300594329834, 48.22008827754429, 44.508791378566194, 39.60280384336199, 44.86028337478638, 42.14516707829067, 47.32862050192696, 46.774956771305625, 53.52301597595215, 50.86016402925764, 59.482416425432476, 31.73121050425938, 36.765868255070274, 56.37519938605172, 47.06587437220982, 51.40605967385428, 45.81604283196585, 50.58485555648804, 47.00392075947353, 47.21545171737671, 42.58992821829659, 43.24204444885254, 44.32475791658674, 46.71215895244053, 45.83312150410244, 47.599186829158235, 44.51267194747925, 46.162716252463206, 49.284736428942, 48.78677293232509, 48.133937563214985, 50.22708238874163, 49.70421654837472, 53.452071394239155, 48.914209842681885, 48.167281968253, 50.44111122403826, 49.7202147756304, 47.876920223236084, 50.671239035470144, 54.77640151977539, 53.33112757546561, 52.612996510096956, 48.749541010175435, 46.63227203914097, 55.157847200121196, 54.19913475854056, 51.58723395211356, 48.590409891945974, 35.93005902426583, 20.17840596607753, 8.967365077563695, 9.853309035301208, 14.471209492002215, 3.725800395011902, 6.171157223837716, 5.0659672021865845, 1.0793915774141039, 0.13428748132927076, 0.043182789614158015, 0.025741917180961797, 0.013076021202972956, 1.5604965729372842, 11.923961673464094, 34.793441431862966, 34.47616236550467, 23.24523660114833, 18.475267001560756, 24.006291900362285, 37.96039908272879, 50.38352108001709, 47.62528773716518, 47.304663113185335, 17.0197913646698, 0.7134700726185526, 0.08354512628700052, 0.026315974770113826, 0.051926849875599146, 0.021314739116600583, 0.061931947113147805, 0.047035653942397664, 0.01572747990888144, 0.04783851353983794, 0.07496186864695378, 0.036544461002839465, 0.06188324186950922, 0.036820953844913414, 0.02692874787109239, 0.016587282165086696, 0.049006553898964605, 0.06482921700392451, 0.04498069028237036, 0.0784953533272658, 0.01842184577669416, 0.028362492365496497, 0.01757660148931401, 0.0507674336965595, 0.010610900935716927, 0.03844210971146822, 0.02711384543882949, 0.08122777313526187, 0.06617840924965483, 0.0549850954142, 0.030129923418696438, 0.05029903079516121, 0.06613606866449118, 0.059860359345163615, 0.014979954842211944, 0.049961408733257225, 0.011107304432828511, 0.018459304302398647, 0.02496770872468395, 0.10476674325764179, 0.014409474828945739, 0.03721384597676141, 0.027345980750396848, 0.01020629728944706, 0.06032714394054242, 0.022438067410673414, 0.04705630176301513, 0.05337227535034929, 0.030778999839510237, 0.042700056053165875, 0.07522888574749231, 3.9607328857694353, 47.33775390897478, 64.5082152230399, 61.881059646606445, 49.89974580492292, 40.320087228502544, 29.31795174734933, 30.685718536376953, 56.78800228663853, 44.508843490055625, 34.379241943359375, 19.929031644548687, 2.3287784329482486, 0.176570825278759, 0.1133531764415758, 0.5458309394972665, 1.3684514037200382, 3.7323616657938277, 7.458544645990644, 9.729314957346235, 11.405811922890798, 9.128965411867414, 5.249011414391654, 16.752268348421367, 33.337630544389995, 48.94166217531477, 56.80600159508841, 59.225631850106375, 61.15356935773577, 58.10809748513358, 54.219746589660645, 53.965390409742085, 55.19422449384417, 54.28743594033377, 46.9828051839556, 43.851686341421946, 49.364140442439485, 52.63987909044538, 55.39298118863787, 53.27235276358468, 52.32394797461373, 52.935577051980154, 51.62758214133126, 52.21305472510201, 54.181197983878, 51.88215371540615, 44.88527257101876, 40.19209793635777, 44.870021275111604, 47.89891821997506, 52.317882197243826, 53.46590525763375, 54.94363423756191, 51.06922490256173, 47.24462372916085, 41.283475807734895, 46.551815373556956, 44.83259827750069, 49.14821127482823, 49.73782845905849, 56.440495082310264, 52.86384732382638, 60.582406588963096, 33.347722802843364, 39.46559081758772, 58.10054479326521, 49.771996225629536, 53.63247789655413, 48.62138843536377, 52.09298985345023, 48.44755840301514, 48.88424226215908, 45.26955311638968, 45.07704980032784, 46.2823885508946, 48.605365889413015, 47.84872790745327, 48.93617309842791, 47.18988234656197, 48.49291276931763, 51.898916244506836, 51.63361317770821, 50.897263935634065, 52.031237738473074, 51.90216105324881, 54.04463114057268, 50.62696858814785, 48.934463841574534, 51.54929678780692, 48.286728450230186, 47.469425746372764, 49.120758942195344, 56.758799007960725, 55.27360766274588, 55.236146450042725, 50.411136695316856, 49.39454575947353, 55.063448974064414, 56.28756523132324, 54.450746400015696, 49.291656834738596, 36.3453493799482, 17.937446900776454, 5.363033090318952, 7.543000868388584, 10.660612412861415, 11.882763198443822, 10.996796659060887, 8.376392126083374, 3.8582430481910706, 0.7534388250538281, 0.11978750010686261, 0.06328875252178737, 0.023655176029673645, 1.422472019280706, 14.217619350978307, 41.44752972466605, 38.809121540614534, 23.502550976616995, 24.494147505078995, 32.743535246167866, 45.61683797836304, 56.42533758708409, 54.309701442718506, 54.82254103251866, 22.404129368918284, 0.9317902347871235, 0.08913622769926276, 0.03046496704752956, 0.04758186784705945, 0.05984592690531697, 0.037435855849512985, 0.03143235103094152, 0.025896087122548903, 0.05502148524725011, 0.004743982247808682, 0.050753547477402856, 0.02133759556870375, 0.0755916644952127, 0.008261463255621493, 0.028640033544174263, 0.07815651329500334, 0.030756194277533462, 0.046964903096003194, 0.0494943289751453, 0.031109422644866363, 0.04606698752780046, 0.0352844961120614, 0.018322462448850274, 0.018038738119815077, 0.026748907253412262, 0.026673008022563796, 0.20711556768843106, 0.11916346502091203, 0.18121560104191303, 0.13749545919043676, 0.16945137801979268, 0.14473606566233294, 0.14755708857306413, 0.13193909877112933, 0.12738163689417498, 0.11658326775899955, 0.1485363503119775, 0.18787688788558754, 0.21257947092609747, 0.11225484537758998, 0.42244534460561617, 0.18113613102052892, 0.07149651566786425, 0.11517164350620337, 0.13800969373966965, 0.13872302403407438, 0.0933061239442655, 0.09790241159498692, 0.1653617253260953, 0.1433967189597232, 6.067625156470707, 56.68908078329903, 72.15458270481655, 70.33619049617222, 59.215341567993164, 45.79367658070156, 31.887322630201066, 34.72790602275303, 62.367544719151084, 54.85510376521519, 49.1646785054888, 27.224681854248047, 2.726373463869095, 0.4205157538609845, 0.1511773443115609, 0.5463259986468724, 1.2696230496679033, 8.314423748425074, 14.18096239226205, 13.587505459785461, 17.51713820866176, 24.440609897886002, 14.600994893482753, 19.728786298206874, 34.33930369785854, 52.349121298108784, 61.068405287606375, 61.3494599206107, 63.88553156171526, 59.06850528717041, 54.09713172912598, 55.50928361075265, 56.0534838948931, 57.24859142303467, 49.350438594818115, 45.15124961308071, 53.77606242043631, 54.81431783948626, 58.133753708430696, 54.06745597294399, 51.33680350439889, 52.838746956416536, 51.98683874947684, 53.95332486288888, 56.54275172097342, 56.04055677141462, 47.76874371937343, 41.84936836787632, 46.596113613673616, 49.93389272689819, 54.20050702776228, 54.262940066201345, 57.15830653054373, 54.11275127955845, 49.37628589357649, 44.232704707554404, 48.84972013745989, 47.2852463722229, 50.88361419950213, 51.785525117601665, 57.47388676234654, 57.082393986838206, 61.213532311575754, 37.175405502319336, 42.21860606329781, 58.77857085636684, 52.08394677298409, 55.09464985983712, 49.859435830797466, 55.68307890210833, 51.794272899627686, 50.761364119393484, 47.79103701455252, 47.778839451926096, 49.656847204480854, 51.66461603982108, 50.306194577898296, 51.43333830152239, 49.121422495160786, 50.59314128330776, 54.81196240016392, 54.88846206665039, 52.15763241904122, 54.62277684892927, 53.2488226890564, 56.468659605298726, 52.03200898851667, 50.163047790527344, 51.72902931485857, 49.93822145462036, 47.91042096274239, 49.33947433744158, 57.6958087512425, 56.990191391536165, 57.9628940309797, 54.28769997188023, 51.420515401022776, 59.3920134135655, 59.93796116965157, 56.9211436680385, 52.68575457164219, 40.93585743222918, 23.779443638665335, 15.100207328796387, 17.517737490790232, 29.3949099949428, 14.686435154506139, 11.902926870754786, 14.749151332037789, 4.552524856158665, 0.6908840845738138, 0.18216252380183764, 0.1502956830497299, 0.1322396762136902, 2.413069201367242, 16.522461891174316, 46.28326402391706, 45.95218930925642, 34.369389397757395, 27.48275010926383, 35.89881297520229, 48.64743375778198, 62.51228264399937, 60.76299721854073, 62.00204862867083, 28.994431461606705, 1.272237743650164, 0.2948376605553286, 0.16450382636061736, 0.13417959426130566, 0.23621174639889173, 0.13571771101227828, 0.15430541788893087, 0.08782094184841428, 0.1333316426192011, 0.13131716714373656, 0.0996168999533568, 0.08590783271938562, 0.1274293243352856, 0.06823411251285247, 0.10442155213760478, 0.18488904035517148, 0.15355379107807363, 0.13127751355724676, 0.12709399232906954, 0.20290182451052324, 0.1409266750727381, 0.1430052313953638, 0.14459992439619132, 0.20615770694400581, 0.08154150058648416, 0.0965356860043747], [0.015909997347210134, 0.038190895691514015, 0.03948725720069238, 0.06470911630562373, 0.04965647170320153, 0.052777369772749286, 0.08035073948225804, 0.03995323773207409, 0.025563893340794102, 0.06186397826032979, 0.04661775779511247, 0.016539715163941895, 0.024744774347969463, 0.039317331675972254, 0.07296534042273249, 0.03482087688254459, 0.024428605867017592, 0.06946817093661853, 0.037492218360837014, 0.038687841168471744, 0.02096275077201426, 0.026473795230101262, 0.040215053861694675, 0.13163474867386477, 10.440973775727407, 55.53538451875959, 58.60034261431013, 50.938331263405935, 41.085816928318565, 31.7914548601423, 23.388855866023473, 27.880211387361797, 33.735692841666086, 40.91013172694615, 26.535088777542114, 6.6167877571923395, 0.3546254980776991, 0.0528701865779502, 0.009094705954859299, 0.4477455270077501, 1.197342785341399, 3.8867601922580173, 5.323419673102243, 10.17988305432456, 8.606466957501002, 6.259742847510746, 4.535732797213963, 31.682270867483957, 59.803548267909456, 58.44005462101528, 57.64696291514805, 51.89828743253435, 55.382722173418315, 53.78489358084542, 55.31778430938721, 53.68180315835135, 57.29132979256766, 51.859881264822825, 47.178678376334055, 42.962233543395996, 48.01890318734305, 48.51351417813982, 55.18192965643746, 52.329346724918906, 53.39174713407244, 51.52235862186977, 50.9647205216544, 52.05221782411848, 52.46396459851946, 48.20935678482056, 40.42646067483084, 37.09225640978132, 41.7496269771031, 47.73159864970616, 51.824455874306814, 51.74592385973249, 51.570631231580464, 48.573279108319966, 44.86929171425955, 40.370114258357454, 40.35050644193377, 40.031917640141074, 45.61018507821219, 45.59349550519671, 52.92789929253714, 51.251993792397634, 60.31021785736084, 34.491524832589285, 39.27400813783918, 56.16597523008074, 46.72623252868652, 51.379635674612864, 44.70352854047503, 50.888912200927734, 45.375641686575754, 46.98184633255005, 40.07323857716152, 40.29725544793265, 40.49175637108939, 45.005577155521934, 43.08675568444388, 43.87186043603079, 43.319176401410786, 43.481048583984375, 43.40335382734026, 44.91565009525844, 44.93616812569754, 47.12487847464425, 49.72332756859915, 52.27813502720424, 51.58226599012102, 53.16178955350603, 48.962110723767964, 47.92530400412423, 48.995861598423545, 49.15187644958496, 49.58137934548514, 53.91521746771676, 52.522246088300435, 52.66055345535278, 47.022274426051546, 46.21537664958409, 53.08299003328596, 61.523310797555105, 54.09238610948835, 46.02493347440447, 26.0105744770595, 13.327455231121608, 10.064262424196516, 9.121719309261866, 11.676874177796499, 10.949412550245013, 4.2981139591762, 5.296526670455933, 0.7896749292101178, 0.21772492410881178, 0.0851869774716241, 0.07712574396282434, 0.041815829928964376, 4.8115163530622205, 24.564204454421997, 43.102444716862266, 37.20392785753523, 16.93168646948678, 13.920378020831517, 26.933663504464285, 33.40015043531145, 41.25400849751064, 45.89842414855957, 32.59848812648228, 2.1204160707337514, 0.24153466363038334, 0.045290611152138026, 0.058558108152023385, 0.04425815226776259, 0.009026100127292531, 0.03991890386013048, 0.02783801363381956, 0.10613839501248938, 0.010444781144282647, 0.05442628789959209, 0.04188130855826395, 0.03483964176848531, 0.0332121076727552, 0.03948286707912173, 0.04628512975094574, 0.05412155443004199, 0.06394541157143456, 0.028065497587834085, 0.053416794032922814, 0.010357423153306757, 0.012893364664965441, 0.044683366415223906, 0.042539300929222784, 0.018614015375663127, 0.021884815401530693, 0.06893269145595175, 0.02272393930304263, 0.057164560072124004, 0.006769601388701371, 0.03486907661759427, 0.11618407203682832, 0.03015977217416678, 0.029370283109268973, 0.03821189635034118, 0.029138614290526936, 0.04881933590929423, 0.007131951811191226, 0.023550260945090225, 0.04078330997643726, 0.021251311359394873, 0.06581358132617814, 0.05997727771422692, 0.06945637799799442, 0.0032396879230093744, 0.013143732212483883, 0.04838222025760582, 0.022290248556860855, 0.05691264716110059, 0.10809521536741938, 14.050876481192452, 65.2048624583653, 64.46279484885079, 58.8479277747018, 48.44280236107962, 36.78052200589861, 30.787009375435964, 25.07165571621486, 38.10701649529593, 43.42156852994646, 28.67789932659694, 7.658872502190726, 0.4950660435216767, 0.13769226148724556, 0.10808409417846374, 0.9805127403565815, 2.78628517474447, 6.089034727641514, 9.222207631383624, 9.572584441729955, 9.631498217582703, 10.673218182155065, 11.579586369650704, 32.87525224685669, 52.86227355684553, 60.79104709625244, 57.95607784816197, 55.503374167851035, 56.76749815259661, 56.57039860316685, 53.60663059779576, 57.06171267373221, 56.48726340702602, 54.774254526410786, 48.33513307571411, 45.15403931481497, 48.98285109656197, 51.31725822176252, 56.317074230739046, 53.79787628991263, 51.824584415980745, 51.29300206048148, 49.70952844619751, 53.143432412828716, 54.0519232749939, 49.109124183654785, 41.63542985916138, 40.20820733479091, 43.540945529937744, 48.850623403276714, 53.86194910321917, 53.45045593806675, 52.409577574048726, 51.00272716794695, 46.86516523361206, 41.27498510905674, 43.421707493918284, 41.808276721409385, 48.52063260759626, 48.148170948028564, 54.6580285344805, 52.92699255262102, 61.59511348179409, 35.83874579838344, 40.97558375767299, 57.605711460113525, 48.851637840270996, 53.86388070242745, 47.23860658918108, 51.632921831948416, 48.406230517796104, 48.83242607116699, 41.89871794836861, 41.97778150013515, 42.724073614392964, 46.81049680709839, 44.46940551485334, 46.345116887773784, 45.99449341637747, 45.62067685808454, 46.16237579073225, 47.548121043613975, 47.93421854291643, 48.48454713821411, 51.32781948362078, 54.11624274935041, 53.38918324879238, 53.77167115892683, 50.735527242933, 48.44095066615513, 48.61473553521292, 48.92258242198399, 50.83396584647042, 54.42184884207589, 54.658428055899485, 54.719388076237266, 48.484369959150044, 48.28197935649327, 54.67270312990461, 61.472915513174875, 55.54724856785366, 46.20590278080532, 27.42146873474121, 12.069988489151001, 7.616779446601868, 7.930692979267665, 10.143619537353516, 9.211126123155866, 7.202850503580911, 7.1258818336895535, 3.301291516848973, 1.056004375219345, 0.17374452336558274, 0.07503069245389529, 0.14265855428363594, 5.102530794484275, 27.418305567332677, 46.02705267497471, 34.432312284197124, 16.680139098848613, 22.291004010609218, 32.56675917761666, 38.49043893814087, 49.27826765605381, 52.656148297446116, 40.170614106314524, 2.947565891913005, 0.28557582039918217, 0.034279137916330776, 0.04719220554190023, 0.03154022452820625, 0.019897213305479715, 0.06486433119113956, 0.017546427037034715, 0.045671649277210236, 0.04000357485243252, 0.07463251453425203, 0.021342691366693804, 0.02478654496371746, 0.03780305864555495, 0.03889588000518935, 0.016372895633269633, 0.007452642728042389, 0.021465967608881847, 0.02305832475290767, 0.013730259578941124, 0.04358304385095835, 0.049594945540385585, 0.033207900755639584, 0.028910748660564423, 0.04709513771480747, 0.059977413421230655, 0.11548277895365443, 0.11363421886094979, 0.10539159937096493, 0.13198633837912763, 0.12450259923934937, 0.16548658934022697, 0.14738586704645837, 0.17348547226616315, 0.17322313705725328, 0.1391911453434399, 0.16540260027561868, 0.05227809013532741, 0.10473852977156639, 0.12235867285302707, 0.16326718271843024, 0.09849413484334946, 0.17465560590582235, 0.18259589054754802, 0.17937203496694565, 0.09597766559038844, 0.12243316242737429, 0.1287969116653715, 0.12516636933599198, 0.24255841012511933, 19.561692544392177, 75.1508126940046, 72.92457512446812, 68.49645342145647, 54.25100653512137, 43.35796124594552, 32.48976271493094, 40.322814396449495, 44.16917732783726, 53.404847962515696, 34.546971457345144, 8.6386536189488, 0.5296649783849716, 0.28932298932756695, 0.18774645988430294, 1.1846007662160056, 5.606816717556544, 15.876126561846052, 17.347065414701188, 21.87512653214591, 22.42074772289821, 13.797394905771528, 13.082909907613482, 34.27032198224749, 63.006904057094026, 63.01359517233712, 61.74269321986607, 56.194921425410676, 59.39566816602434, 55.74193014417376, 56.20565639223371, 56.46768685749599, 59.89981555938721, 56.9459730557033, 51.99608332770211, 46.79712847300938, 51.63043090275356, 52.66759545462472, 60.047701018197195, 54.63764599391392, 53.359705516270225, 51.43432147162301, 50.33182995659964, 55.38216284343174, 57.76429714475359, 52.885893957955496, 43.895418303353445, 42.8617730140686, 46.317984172276084, 51.152975014277864, 56.077698366982595, 55.028961590358186, 55.21897745132446, 54.150962897709434, 49.6378994669233, 44.69250174931118, 44.03213105882917, 44.13140344619751, 50.78057241439819, 50.682568073272705, 57.03997870853969, 57.193801403045654, 62.757005146571565, 38.606140341077534, 46.05346972601754, 59.65839345114571, 52.109985147203716, 56.16739961079189, 49.17961365836007, 54.62436103820801, 50.256535802568706, 50.49454287120274, 44.87014981678554, 44.11543301173619, 45.66015304837908, 49.011126790727886, 47.100274903433665, 48.83574731009347, 48.69041531426566, 48.77764647347586, 47.801699025290354, 50.65947573525565, 49.60376991544451, 50.69615180151803, 55.27757855824062, 58.217302322387695, 55.7183062689645, 56.32742704663958, 51.99253627232143, 48.887963022504536, 49.949783257075715, 49.71340206691197, 51.02934224264962, 57.94513096128191, 56.99843890326363, 57.45782947540283, 51.376720905303955, 50.17405721119472, 57.82291909626552, 64.09588132585797, 55.20847872325352, 49.00611366544451, 28.896889175687516, 18.349723475319998, 15.414733171463013, 17.211057901382446, 20.3032876764025, 21.713825838906423, 13.628971440451485, 12.24141618183681, 2.7862278521060944, 0.8652742068682397, 0.24098217327679905, 0.25254690700343674, 0.2665427231362888, 6.070642845971244, 32.98725025994437, 57.70391729899815, 50.3803596496582, 26.35617787497384, 23.022237641470774, 37.35288681302752, 45.31189891270229, 56.193479674203054, 60.70333998543875, 45.927985259464805, 4.962441648755755, 0.5903514676860401, 0.14250686099486692, 0.151331005351884, 0.11926230043172836, 0.11762313624577862, 0.18043418654373714, 0.10180774025086846, 0.29007754740970476, 0.08989251604569809, 0.17200104120586598, 0.11041866854897567, 0.07107551183019366, 0.10827597709638731, 0.15246479665594442, 0.08775995512093816, 0.1329471303948334, 0.15205295304102556, 0.0873378791979381, 0.09219597280025482, 0.14492805036050932, 0.11994546305920396, 0.12383319730205194, 0.09861519906137671, 0.11105159244367055, 0.15737957507371902], [0.011002959317660757, 0.03103343690080302, 0.026090880955702493, 0.07136376707681588, 0.03124664956703782, 0.013009892028224255, 0.026909718356494392, 0.01752291919131364, 0.019700646799589907, 0.0287890669756702, 0.047341259329446723, 0.03838877007365227, 0.08204783698809998, 0.011212444282136858, 0.02657203353010118, 0.031313536156501086, 0.0599873811006546, 0.028702689467796257, 0.035457023818578036, 0.10728965859327998, 0.041191906801291873, 0.033919782377779484, 0.08069174404123, 0.7943220255630357, 32.89240040097918, 58.7741448538644, 53.03150040762765, 47.91156046731131, 38.28691577911377, 26.274984700339182, 21.01771014077323, 33.62816252027239, 45.46715988431658, 32.498375007084434, 13.494851231575012, 1.3216962154422487, 0.10779285337775946, 0.05900000408291817, 0.1634718288800546, 1.4517499910933631, 2.819119755710874, 3.4700652148042406, 5.166728241103036, 5.211707838944026, 11.185185773032051, 9.308326210294451, 17.290022441319056, 44.79529339926583, 55.82956429890224, 58.39788600376674, 52.999524797712056, 53.77835532597133, 54.262415477207725, 56.61320645468575, 53.41720533370972, 53.9184935433524, 52.95302397864205, 50.95890487943377, 43.89886113575527, 40.61206095559256, 44.40442943572998, 48.90614298411778, 53.04412528446743, 52.214927264622276, 51.30365712302071, 51.43316459655762, 52.20381709507534, 52.54458802086966, 51.08578940800258, 44.58821971075875, 38.611156940460205, 37.856975146702354, 42.39332546506609, 44.51504128319876, 49.26334292548043, 50.95331852776663, 53.18864434106009, 49.47345297677176, 45.66308866228376, 38.42805453709194, 39.593076365334646, 40.32651778629848, 43.624230112348286, 44.79733616965157, 53.74569879259382, 47.6555540902274, 59.30805832999093, 31.76233148574829, 31.998375688280376, 59.05280930655343, 46.13211638586861, 51.309646470206125, 43.46215295791626, 47.451568875994, 43.61872019086565, 47.06632947921753, 40.60601602281843, 38.92840126582554, 38.03829186303275, 40.87218066624233, 39.965211459568565, 41.660655294145855, 41.88242442267281, 42.19195277350289, 40.97392313820975, 41.934890270233154, 42.49778815678188, 43.9142826625279, 44.43072141919817, 47.71071236474173, 50.73288345336914, 50.836105891636436, 49.62871394838606, 49.120220456804546, 48.37042645045689, 48.899726322719026, 51.03033930914742, 52.40791000638689, 54.04347773960659, 53.56799166543143, 49.70555407660348, 45.50524990899222, 51.307054792131694, 50.82241794041225, 53.07892881120954, 55.54019267218453, 45.04988234383719, 18.70547124317714, 14.86498475074768, 9.068677629743304, 10.300150292260305, 9.242870705468313, 8.889393261500768, 3.973359499658857, 1.5575807179723467, 1.030160767691476, 0.06373613101563283, 0.12292964650051934, 0.05912534985691309, 0.500481404364109, 10.138573408126831, 41.48896183286394, 38.740796429770334, 35.937378951481406, 17.943276439394268, 40.92261069161551, 36.60127237864903, 41.396290234157014, 50.95282520566668, 41.197648184640066, 13.294808251517159, 0.08878912989582334, 0.027385381582592214, 0.08597916032054595, 0.06997817142733506, 0.03926534232284341, 0.04661679766806109, 0.012779813525932176, 0.00951154189117785, 0.023344880269308175, 0.025679474995870675, 0.09022769877421004, 0.01577507235508944, 0.04817474799762879, 0.01390866085421294, 0.07188324670174293, 0.03865425029237356, 0.045889686327427626, 0.02067888734330024, 0.045483857925449095, 0.06957118612314973, 0.03935951619808163, 0.019023830170876214, 0.06513206753879786, 0.02884625390704189, 0.08063162583857775, 0.058607647993734906, 0.042036292741873434, 0.017582241811656525, 0.05203894046800477, 0.011033512053212948, 0.02902741597167083, 0.028675992507487535, 0.01596294852372791, 0.025218980420114737, 0.025050093053973148, 0.027067438732566576, 0.006934792859413261, 0.02329984420378293, 0.0135447336859735, 0.024644854977460842, 0.00863652433534818, 0.046877443324774504, 0.07237055019608565, 0.030005853290536573, 0.03523692741457905, 0.00773116693432842, 0.028544329572468996, 0.09020657597907952, 1.3192058290754045, 39.537567206791465, 66.50615583147321, 60.8016083581107, 53.802941526685444, 46.34649610519409, 33.8201516696385, 29.29328911645072, 39.09147201265608, 47.57299559456961, 35.072863238198416, 16.713328906467982, 1.5814908806766783, 0.09733422672642128, 0.07223707557256732, 0.3180913270584175, 1.8965086340904236, 4.983800411224365, 7.212926260062626, 9.204410689217703, 11.593137962477547, 11.074725917407445, 13.700475352151052, 22.597212859562465, 46.32796178545271, 58.08632183074951, 60.798467772347585, 55.43884972163609, 56.39644350324358, 56.22432620184762, 57.68359729221889, 52.8274040222168, 55.332778521946494, 55.41439553669521, 51.82736716951643, 46.312498569488525, 42.74765232631138, 47.10441255569458, 52.317392349243164, 55.314164297921316, 52.26040322440011, 51.38952990940639, 51.71161018099104, 52.379561356135774, 53.48021159853254, 52.817266600472585, 47.32255819865635, 40.03488104684012, 39.694339411599294, 42.786593505314414, 47.55251577922276, 52.91457264763968, 52.0339857510158, 55.07108504431588, 51.94765090942383, 47.883430685315815, 41.022741181509836, 41.10071039199829, 41.79559278488159, 45.748329162597656, 46.40596921103341, 55.079134532383506, 49.79388999938965, 59.81872313363211, 33.28283705030169, 34.34450789860317, 60.60039547511509, 48.70415537697928, 52.54626601082938, 46.85618816103254, 49.31127854755947, 44.819688524518696, 48.459064619881765, 42.81309046064104, 40.70865133830479, 40.27076544080462, 42.98808431625366, 42.17801816122872, 43.880806241716655, 44.0334130014692, 44.7226117679051, 43.95030559812273, 43.70171294893537, 43.97755643299648, 45.67780147280012, 45.11181858607701, 50.358076776777, 52.43262127467564, 54.110100541796, 50.72741869517735, 50.706125940595356, 48.25739662987845, 49.63985538482666, 49.40551349094936, 52.85006209782192, 54.81586728777204, 55.67721809659685, 52.53801849910191, 48.29709168842861, 53.26848609106881, 55.84100798198155, 55.710989815848215, 59.22242178235735, 43.651275975363596, 24.478786775044032, 12.153846297945295, 7.444181850978306, 8.394397514207022, 12.623314363615853, 10.383498276982989, 9.726716331073217, 4.307647321905408, 1.9949819786208016, 0.11588987282344274, 0.1182664552969592, 0.04256379943607109, 0.42152177702103344, 11.001618708883013, 40.32898787089756, 38.978192056928364, 32.660327093941824, 18.05865475109645, 44.219423225947786, 43.01838541030884, 46.81925501142229, 59.06669875553676, 47.77149173191616, 17.086980445044382, 0.13660849178475992, 0.06803067414356129, 0.06309419617589031, 0.03973328382042902, 0.003954569094016084, 0.06748091828610216, 0.02389826120010444, 0.04982835140877536, 0.04452464011098657, 0.07870621486966099, 0.0713999465640102, 0.10549481133265154, 0.04212570330128074, 0.03445819312972682, 0.028661655062543492, 0.07697819652301924, 0.03600511387256639, 0.06777681383703436, 0.019053991052455137, 0.028111302094267945, 0.0170397852946605, 0.014597788652671235, 0.0630827560754759, 0.028698608079659085, 0.05575489339285663, 0.15336433053016663, 0.20392422750592232, 0.12665265958224023, 0.196796447836927, 0.1178234126418829, 0.13233961085123674, 0.23857136549694197, 0.11405865608581475, 0.09089699893125466, 0.1823136199797903, 0.11537668321813856, 0.10329677856394223, 0.20586869173816272, 0.140640862552183, 0.09780747097517763, 0.0990513681567141, 0.12000060081481934, 0.16041103883513383, 0.10469930366213832, 0.13693353720009327, 0.1268138930733715, 0.12977899610996246, 0.19289782989237989, 1.727079308458737, 47.35970326832363, 74.58152593885148, 68.95233167920793, 62.95508439200265, 52.4115890775408, 38.493642057691304, 29.973125185285294, 46.38782051631382, 60.00091879708426, 42.871764523642405, 18.593269995280675, 1.957993894815445, 0.2062917718929904, 0.1253219438450677, 0.5889552054660661, 3.112704813480377, 7.893498403685434, 10.334879125867571, 14.16510226045336, 14.858979770115443, 21.962402854646953, 16.152218444006785, 24.290702513286046, 48.02210978099278, 60.13237176622663, 61.996670722961426, 58.164607184273855, 58.20327043533325, 58.16945355279105, 58.353382791791645, 53.96204137802124, 56.04177270616804, 57.85945272445679, 54.743407998766216, 48.98345558983939, 44.04439115524292, 48.220220293317524, 53.29437855311802, 56.305995328085764, 53.949878556387766, 51.961172103881836, 51.627964292253765, 53.77583312988281, 55.137085982731406, 55.42799663543701, 48.57842077527727, 42.987452030181885, 41.760789258139475, 44.570800576891216, 49.75371898923601, 54.66534151349749, 53.404229572841096, 56.948095730372835, 53.92798825672695, 51.23631518227713, 42.47935111182076, 42.86340931483677, 43.74646977015904, 47.150003160749165, 48.20111969539097, 56.71388932636806, 52.442932401384624, 60.95082787105015, 36.08042846407209, 37.324732712336946, 60.389086859566824, 51.50990744999477, 54.94303321838379, 48.82017292295183, 51.38200153623308, 47.377587931496755, 50.441819940294536, 44.8128410748073, 43.07553781781878, 41.616555077689036, 43.60702289853777, 45.18174178259713, 45.55920614515032, 47.607076508658274, 45.961350509098594, 46.53998606545584, 45.46264008113316, 46.37382337025234, 48.1334616116115, 49.410387652260916, 52.17982496534075, 55.58311169488089, 56.05844838278634, 53.707157135009766, 51.71980905532837, 50.19453355244228, 48.528292996542795, 50.88508026940482, 52.66108499254499, 58.31924629211426, 57.90511975969587, 55.88061271395002, 50.248628752572195, 57.31286573410034, 55.23867212023054, 59.09308106558663, 60.03536796569824, 48.01634625026158, 21.60507263456072, 22.08964695249285, 15.037452936172485, 24.07254992212568, 20.218615191323416, 14.844468457358223, 13.884764160428729, 6.583630953516279, 2.23857952441488, 0.1459085334624563, 0.39657861260431154, 0.20647944110844815, 0.9133143233401435, 13.616481184959412, 53.291818141937256, 50.722735609327046, 49.35017456327166, 24.991754906518118, 51.06455223900931, 48.09446832111904, 54.800028869083945, 65.58673545292446, 57.050682408469065, 20.357629537582397, 0.3199042369212423, 0.173837061971426, 0.21125703331615242, 0.12565438529210432, 0.10929764048861605, 0.14672730809875897, 0.14146699250808784, 0.11930958075182778, 0.13544020376035146, 0.23311529255339078, 0.17016556326832089, 0.188363234645554, 0.14059561783713953, 0.14474869998438017, 0.15730055288544723, 0.1636973467788526, 0.10308004090828554, 0.13449096041066305, 0.0674573052674532, 0.14394478526498589, 0.1028460141803537, 0.1393405587545463, 0.13478530890175275, 0.13936457889420645, 0.19842166134289332], [0.04833307057353003, 0.023923506095473255, 0.03423135208764246, 0.023699721853647913, 0.042491918828870566, 0.053132216446101665, 0.05621394268902285, 0.02586928498931229, 0.04607510280662349, 0.03665177810138889, 0.019056968124849454, 0.027864037148122276, 0.05349237604865006, 0.030175042604761462, 0.04733290995604225, 0.04591077519580722, 0.022814357486952628, 0.0910434200029288, 0.10143573342689446, 0.04899181951103466, 0.04188239760696888, 0.05553498697866287, 0.10354723941002573, 3.9799615911075046, 44.103016580854145, 60.85708972385952, 50.61580630711147, 39.07860047476632, 28.46712919643947, 13.947712234088353, 15.231309413909912, 24.85286041668483, 43.35689469746181, 20.929685149874004, 5.762750795909336, 0.12118182171668325, 0.1093039915763906, 0.03964263154193759, 0.3662627264857292, 1.3827759836401259, 3.2680148567472185, 1.6372446375233787, 6.535642351422991, 7.675187741007123, 9.193925857543945, 28.311407906668528, 37.715565408979145, 61.662872314453125, 55.324781145368306, 59.31602096557617, 49.9055232320513, 51.916272844587056, 53.15201691218785, 54.71241903305054, 52.374100072043284, 52.22329636982509, 53.802503790174214, 48.75800739015852, 43.34591654368809, 42.285444259643555, 45.700167724064414, 49.915035315922324, 54.1907239641462, 53.930771010262625, 52.631784439086914, 50.861762114933555, 51.2271157673427, 52.25576530184065, 48.918076515197754, 40.920154503413606, 38.13056741441999, 38.37368835721697, 41.059372084481375, 46.54252563204084, 50.22694342476981, 50.888252122061594, 50.67231600625174, 49.85320677076067, 46.08395494733538, 37.635007994515554, 39.24384600775582, 38.49601834160941, 40.49343088694981, 45.13290636880057, 55.10179955618722, 49.079462323869976, 58.75217464991978, 30.802034854888916, 30.07812636239188, 57.80351972579956, 45.08897985730852, 52.143729073660715, 42.06803165163313, 45.59607676097325, 40.40726975032261, 46.788891383579795, 40.52581296648298, 39.289297648838584, 37.44219200951712, 40.127740246909006, 42.13605451583862, 44.98962756565639, 43.25108058112008, 41.053490434374126, 38.92426708766392, 38.89914240155901, 37.96196937561035, 38.31295762743269, 38.66101026535034, 44.80640704291207, 47.81312533787319, 51.57602303368704, 48.16332496915545, 47.83238574436733, 47.900835922786165, 51.46707527978079, 47.05561883108956, 48.47949579783848, 51.042912074497764, 52.36293779100691, 52.58900090626308, 47.08135148457119, 43.74745641435896, 50.56312159129551, 52.65276452473232, 54.09216029303414, 51.25776774542672, 37.964116368974956, 21.858504704066686, 11.67937205518995, 7.817531142915998, 6.645369606358664, 4.849908624376569, 5.287358088152749, 4.634555288723536, 2.657950209719794, 0.3376736305654049, 0.11119236131863934, 0.012463875746886646, 0.04729096970653959, 2.354178875684738, 21.898053850446427, 45.40677656446184, 39.35684108734131, 24.876307112830027, 23.43956208229065, 33.969475405556814, 39.149618012564524, 44.38845900126866, 44.043133531297954, 23.048797130584717, 1.971793668610709, 0.009233088082900005, 0.038751860947481225, 0.02912998671776482, 0.035987461784056256, 0.06339246659938778, 0.015542424749583006, 0.01768480407606278, 0.04879836239186781, 0.044597100865628035, 0.022013399483902112, 0.027383554627054503, 0.04755427861320121, 0.038720655121973584, 0.04354884907869356, 0.014592411262648446, 0.023945566965267062, 0.04989497336958136, 0.044702426463897736, 0.013755022714446698, 0.024838407091530304, 0.021240405605307648, 0.04855737728731973, 0.05313369904511741, 0.0903431379369327, 0.04405717019523893, 0.054053398980093856, 0.016733136660020267, 0.03380498103797436, 0.03998600758079972, 0.05020861600392631, 0.013592444027640989, 0.011780800480794693, 0.023494436172768474, 0.05906035298747676, 0.03802198457664677, 0.05527534555377705, 0.040590066595801284, 0.048147335182875395, 0.08271812102092163, 0.07529184022652251, 0.01788090239278972, 0.03842057640265141, 0.07805625296064786, 0.011346705158108046, 0.042731787743312974, 0.053274837721671374, 0.1383186171629599, 5.5092475073678155, 53.415051392146516, 66.5535911832537, 57.09532458441598, 46.85533700670515, 36.114026478358674, 21.628785099302018, 18.09450398172651, 27.145408119474137, 47.28973143441336, 23.970805713108607, 6.725627379758017, 0.23599787216101373, 0.09440251439809799, 0.05110002102862511, 1.64261885200228, 4.545802908284323, 7.269912779331207, 8.199180926595416, 10.120559334754944, 11.012100066457476, 15.947597469602313, 24.482950483049663, 36.913194383893696, 58.45161642347063, 58.69775635855538, 59.05837481362479, 54.2049434525626, 53.10082605906895, 56.0112110546657, 54.73623398372105, 52.918745040893555, 53.681233406066895, 56.14476237978254, 50.24380670275007, 45.23869269234793, 42.661671842847554, 48.91185440335955, 51.082044328962056, 55.15470661435808, 54.24080310549055, 52.90475136893136, 50.97256851196289, 53.42175987788609, 53.554619857243125, 51.667454378945486, 42.97048800332205, 40.10725348336356, 40.63102953774588, 43.24992718015398, 49.310066086905344, 52.97188833781651, 53.08699566977364, 52.35347434452602, 52.046391759599956, 47.47789907455444, 39.10532324654715, 41.64594595772879, 40.96871198926653, 42.81575856889997, 46.003275939396445, 55.75222737448556, 51.80173873901367, 59.17031029292515, 32.971220765795024, 31.710501398359025, 58.75179944719587, 47.25452143805367, 53.50031621115548, 43.79700749261038, 48.411677905491416, 42.41707093375069, 47.356312547411235, 42.61664751597813, 41.67462812151228, 38.75469977515084, 41.785844462258474, 44.44595881870815, 44.78158460344587, 45.344916752406526, 43.358534472329275, 41.422325134277344, 40.53670426777431, 39.33879314150129, 40.43759168897356, 41.04902969087873, 45.2825288772583, 49.480505398341585, 52.155089378356934, 50.36080741882324, 49.405068806239534, 48.20638642992292, 51.12657880783081, 47.05041115624564, 49.16182974406651, 52.07855844497681, 52.79730442592076, 56.121954917907715, 49.14220108304705, 46.27383531842913, 52.44607298714774, 55.796671526772634, 55.240586348942344, 54.149625369480674, 40.373744692121235, 24.06923736844744, 13.0224848985672, 4.291139704840524, 8.916843857084002, 15.776242733001709, 13.895773581096105, 7.142757705279759, 5.901621401309967, 1.0142463530812944, 0.30609865486621857, 0.04333120557878699, 0.2246263852076871, 2.8068051593644276, 24.9215190410614, 43.38267251423427, 41.18709734507969, 26.658077103751047, 27.727972882134573, 38.4519806589399, 44.077530588422505, 51.71797473090035, 51.98234326498849, 28.58868966783796, 2.386851259640285, 0.06591986026614904, 0.036943439593804736, 0.021455762442201376, 0.03334678330325654, 0.03901999763080052, 0.11823023509766374, 0.05317629747358816, 0.0210656981050436, 0.07709458563476801, 0.0420990640164486, 0.06141685760979142, 0.05496291410444038, 0.042161166934030395, 0.027771481578903537, 0.04758647170716098, 0.011937987358708466, 0.024495441566354463, 0.09925496937440974, 0.026079564687928984, 0.023691810135330473, 0.04123031866869756, 0.02626315251524959, 0.042492163101477284, 0.029061179874198775, 0.14895388005035265, 0.08556438543434654, 0.07091940127845321, 0.16443897198353494, 0.12576996694718087, 0.13983747709010327, 0.1054079317088638, 0.156557367050222, 0.09393598764602627, 0.15079858606415136, 0.14954089426568576, 0.16395862347313336, 0.1525172609835863, 0.18629524989851884, 0.1485533272581441, 0.11693731376102992, 0.18079945551497595, 0.20172806749386446, 0.17195643431374005, 0.15265181447778428, 0.18704497681132384, 0.1427578375275646, 0.1974946739418166, 7.654812148639134, 61.620391028267996, 74.28589398520333, 66.02068519592285, 53.00503471919468, 40.89998040880476, 22.690402099064418, 23.182718447276525, 36.16040570395333, 55.662720680236816, 27.120391130447388, 8.627752763884407, 0.32984678340809687, 0.3449559397995472, 0.13569587575537817, 1.5525100529193878, 6.744723200798035, 10.941816432135445, 13.538759504045759, 14.228470700127737, 14.188426494598389, 16.548321349280222, 32.671485900878906, 40.77731343678066, 64.58397838047573, 60.91857433319092, 65.28596183231899, 56.54605211530413, 56.09027113233294, 56.2767607825143, 55.370416913713726, 52.59609154292515, 55.32067476000105, 58.257629667009624, 52.913610322134836, 47.29184021268572, 46.56394692829677, 50.6706553867885, 53.888008322034565, 57.202438013894216, 56.08641488211495, 53.294774600437705, 53.04720681054251, 54.36510637828282, 56.240171568734304, 53.57884475163051, 45.36598021643502, 41.378506319863455, 41.7248774937221, 45.97044917515346, 52.41345814296177, 55.140257835388184, 55.737445081983296, 53.03412682669503, 54.50829832894461, 49.75578260421753, 42.02420241492135, 44.010129587990896, 42.17085109438215, 45.36074474879673, 47.72300720214844, 59.168170247759136, 54.4394451550075, 59.68308734893799, 34.38730532782418, 34.431259632110596, 61.0589279447283, 50.84853969301496, 57.25614064080374, 46.63664593015398, 50.72690800258091, 45.75299487795149, 49.0809075491769, 44.94113261359078, 43.554115840366904, 40.37697907856533, 42.670443943568635, 46.42898164476667, 48.51477180208479, 47.17405087607247, 45.00933265686035, 43.13340241568429, 42.60953256062099, 42.26397432599749, 42.33017328807286, 42.77466344833374, 47.98729930605207, 52.63774599347796, 54.71703263691494, 51.21763842446463, 48.36927652359009, 49.403227533612935, 53.7104366847447, 48.15514693941389, 50.838523864746094, 52.48226615360805, 54.4811760357448, 58.245824677603586, 51.152301039014546, 49.25173595973423, 54.96715041569301, 57.538439001355854, 58.82808371952602, 56.07537766865322, 41.30541474478585, 27.047535794121877, 17.505873441696167, 16.546427965164185, 14.647928237915039, 17.541707038879395, 17.786608457565308, 14.361321125711713, 6.890135535172053, 1.1723632514476776, 0.39458909364683287, 0.18698016314634255, 0.26844663811581476, 3.4005510934761594, 29.61945492880685, 58.279401847294395, 51.25480086462838, 36.14112792696272, 30.690696920667374, 43.442138671875, 52.81426150458199, 58.79157093593052, 61.912187576293945, 35.977973801749094, 3.4496846284185136, 0.26955541861908777, 0.1387105525604316, 0.14340426426913055, 0.1611991436885936, 0.1630667434739215, 0.13248926853494986, 0.13687702880374022, 0.13332748998488697, 0.15518820551889284, 0.11845620082957403, 0.15467235605631555, 0.13476757199636527, 0.13354205632848398, 0.07886413710990123, 0.1522850798709052, 0.10483145514237029, 0.11342611217073031, 0.14857233980936663, 0.05411042645573616, 0.11994612802352224, 0.06765032812420811, 0.11219474753098828, 0.1915417369455099, 0.18207195294754847], [0.05000036342867783, 0.0334403329262776, 0.04840087657794356, 0.024784563641463007, 0.004872275832375246, 0.04750298475846648, 0.05369142768904567, 0.031088900353227342, 0.013804257215399827, 0.04342050417991621, 0.04735140682065061, 0.026353523201708282, 0.012907992183629955, 0.012861847561517996, 0.0530571467243135, 0.04834087372624448, 0.06033644665564809, 0.03826264737706099, 0.030556779620902877, 0.053776407414781194, 0.03529989546430962, 0.026909224722268324, 0.09402258228510618, 8.735350830214363, 45.27264159066336, 57.466236795697895, 46.27054534639631, 36.65189347948347, 28.717922687530518, 19.722534656524658, 38.259925501687185, 50.551674434116904, 33.40511492320469, 11.602914946419851, 0.7868631343756403, 0.13026907481253147, 0.055944323406687806, 0.09924823152167456, 0.7922315948775837, 2.235533824988774, 4.508055516651698, 6.0697300263813565, 10.458382487297058, 18.37665469305856, 27.7255688054221, 38.87713050842285, 50.04246180398123, 56.61499908992222, 53.9710636138916, 51.9987792287554, 48.614283902304514, 55.490419251578196, 54.77411208833967, 53.80591882978167, 51.994391441345215, 52.17684071404593, 52.540158544267925, 47.07764114652361, 41.2088417325701, 42.2330652645656, 46.17542450768607, 51.77920920508248, 53.6460268838065, 53.00180728094918, 49.24774421964373, 52.68374654224941, 53.310442788260325, 49.866863455091206, 45.199240820748464, 37.92927115304129, 39.58241435459682, 39.272038323538645, 42.86529575075422, 44.95468160084316, 48.51251016344343, 51.36506530216762, 51.51927709579468, 51.22539956229073, 45.840698514665874, 38.028481006622314, 42.36589397702898, 36.551446846553254, 41.42597988673619, 46.016630377088276, 53.703384263174875, 48.74164438247681, 57.17149421146938, 29.983207021440776, 26.933580126081193, 59.652160917009624, 45.212550095149446, 48.57569013323103, 40.54630320412772, 42.953812326703755, 39.45672491618565, 43.89139182226998, 39.900624479566304, 38.858936650412424, 35.74079009464809, 39.2896728515625, 42.04103095190865, 47.058516229902, 46.53466721943447, 45.83204800742013, 40.38801629202706, 39.550199031829834, 37.1937244279044, 38.37716245651245, 37.013102531433105, 40.08783674240112, 45.14366912841797, 50.99244383403233, 47.059732164655415, 48.765216146196636, 49.72430379050118, 53.31081451688494, 49.48417057309832, 50.73539522715977, 50.4091842515128, 50.27363879340035, 53.07510035378592, 53.992634296417236, 49.343723160879954, 42.27954523903983, 47.55265474319458, 53.586185523441856, 53.554140431540354, 57.009093965802876, 36.40804992403303, 27.07427246229989, 6.646870851516724, 8.59355286189488, 13.084372503416878, 10.652000989232745, 3.0578420545373644, 1.8141197179044997, 0.47549888491630554, 0.1529466515140874, 0.039333833647625785, 0.007390409192469503, 0.17490116772907122, 6.063438866819654, 33.37123550687517, 40.579692772456575, 26.886269841875347, 20.114758729934692, 27.203799043382915, 37.41913441249302, 42.67987959725516, 46.13367278235299, 38.73923308508736, 6.532988573823657, 0.07598008508128778, 0.03465529398194381, 0.03705170664138027, 0.04469668945031507, 0.040433861049158235, 0.032976343895175626, 0.004439063029297228, 0.05450890971613782, 0.021463650411793163, 0.04841972628076162, 0.04036152921617031, 0.06348757006760154, 0.07382460324359791, 0.013513637274237615, 0.027778270321765115, 0.010588879929855466, 0.07648549867527825, 0.01627321375001754, 0.023003478767350316, 0.056812950010810576, 0.004205097793601453, 0.02199323003047279, 0.04578089002253754, 0.044338321180215905, 0.01740658436236637, 0.007937366941145487, 0.048828499524721077, 0.032888565212488174, 0.026386902035613145, 0.05263501312583685, 0.03207518832225885, 0.01697171466158969, 0.016808778047561646, 0.0081381853170959, 0.009804303458492671, 0.005317784962244332, 0.05212983023375273, 0.024548901644136225, 0.04546520499778645, 0.0394684210685747, 0.017320010079337016, 0.058962738939694, 0.055138980371079276, 0.0008580256076779083, 0.03015695625383939, 0.02535305215444948, 0.07670452977929797, 11.375854764665876, 54.88657563073294, 64.85850865500313, 52.06022909709385, 42.94242422921317, 35.651936531066895, 19.522318840026855, 25.398542404174805, 47.96332107271467, 38.4103227342878, 12.496653045926776, 1.3479422756603785, 0.10492659253733498, 0.031168265201683556, 0.1956153626420668, 1.0601816539253508, 7.932698403085981, 6.803711235523224, 6.507370131356375, 13.332255567823138, 12.311807513237, 22.759072882788523, 36.89907217025757, 50.20975358145577, 59.90148312704903, 56.24865531921387, 53.32689959662301, 51.39988272530692, 56.235050746372764, 56.17628288269043, 54.22192832401821, 52.33653116226196, 53.66832365308489, 53.86484997613089, 50.372977188655305, 44.20420667103359, 44.32391718455723, 49.739958081926616, 52.97417776925223, 55.10251522064209, 52.16227728979928, 50.657981872558594, 52.92395618983677, 53.665207386016846, 51.99863679068429, 47.21933576038906, 39.76328638621739, 40.53384855815342, 40.82876484734671, 44.11381755556379, 47.01936313084194, 51.80438600267683, 53.89663103648594, 52.30451038905552, 52.202066149030415, 47.75220005852835, 40.164749826703755, 42.82332863126482, 38.84802450452532, 43.71397304534912, 47.768163544791086, 55.6129264150347, 50.41257149832589, 55.556694643838064, 31.65234497615269, 28.261096000671387, 59.78200190407889, 47.831704820905415, 52.09816626140049, 42.965721539088655, 45.07114035742623, 40.58216633115496, 45.32402351924351, 41.580685002463206, 40.46272679737636, 37.6229841368539, 41.01333679471697, 43.28278521129063, 49.57420533043997, 47.496422971997944, 47.7988989012582, 43.30732972281319, 42.093396050589426, 39.63068001610892, 39.496142046792166, 38.75741652079991, 42.067607811519075, 46.660367080143516, 52.558536529541016, 49.291663782937185, 47.31916400364467, 49.769498348236084, 53.93177849905831, 51.25145183290754, 51.44694982256208, 50.31959417888096, 52.087827341897146, 54.94126490184239, 55.63814837591988, 50.7882536479405, 45.9910123688834, 49.82803692136492, 55.11959736687796, 55.657565116882324, 55.76078755514962, 38.17058556420462, 21.45796537399292, 7.616702147892543, 11.77958071231842, 13.478932908603124, 11.763095242636544, 8.43122296673911, 9.298705560820443, 3.3205977380275726, 0.8144139360104288, 0.19348157356892312, 0.0103344326905374, 0.2162403166294098, 7.17908375603812, 37.215802328927175, 44.94585738863264, 30.86564561298915, 26.531434025083268, 35.134844643729075, 42.73596545628139, 48.21564490454537, 52.46417304447719, 45.5653726713998, 8.454224109649658, 0.04908676691619413, 0.03241289180836507, 0.06563710793852806, 0.055038818424301486, 0.022454211455104605, 0.08146093133836985, 0.0845951863697597, 0.023927511148420826, 0.0190092280972749, 0.016894039365329912, 0.06870180634515625, 0.028117617558954016, 0.029429509038371698, 0.010392537340521812, 0.01749212896850492, 0.0674932404820408, 0.0458553083507078, 0.04252991000456469, 0.039775481913238764, 0.006700086324209613, 0.028189856093376875, 0.06272448280027934, 0.03116615835045065, 0.05946832895278931, 0.12230804056993552, 0.1230141105396407, 0.1770548921610628, 0.205819253676704, 0.134772728862507, 0.07430559636226722, 0.09073262382298708, 0.08782166109553405, 0.08062970558447496, 0.08159396491412606, 0.14847951621881553, 0.09241998435131141, 0.11858851515821048, 0.09530202113091946, 0.1730828567274979, 0.08003794162401132, 0.10225764289498329, 0.1244570966809988, 0.1275419747190816, 0.09898563168410744, 0.16138643292444094, 0.16410129224615438, 0.2513252996972629, 14.652772869382586, 65.97409752437046, 70.2992330278669, 61.468558992658345, 48.268454687935964, 40.921801226479666, 29.75359685080392, 51.147763865334646, 62.58293192727225, 44.05220093045916, 15.683515548706055, 1.5752207828419549, 0.2995474806853703, 0.214323455201728, 0.21215907776994364, 2.292445433991296, 8.105495759419032, 14.21957961150578, 16.79172543116978, 19.232530321393693, 25.87001415661403, 37.01431846618652, 45.8048666545323, 52.1009316444397, 63.19463743482317, 57.1132161957877, 56.01807587487357, 53.50338384083339, 59.5926148550851, 56.99939775466919, 54.788633823394775, 51.999210017068044, 55.61280829565865, 55.32834209714617, 51.69271455492292, 45.965064321245464, 46.44704348700387, 49.282040527888704, 54.92536742346627, 56.617104394095286, 54.51762975965227, 50.08893830435616, 55.54743269511631, 55.35912609100342, 54.304247106824604, 50.04573440551758, 42.51438045501709, 42.71930020196097, 42.532838344573975, 46.833071504320415, 49.45512362888881, 52.955841473170686, 55.23279047012329, 53.484151227133616, 54.83582598822457, 49.83894211905343, 43.02318661553519, 45.47286088126046, 40.048718384334016, 45.61170673370361, 49.625684533800396, 56.625237260546, 52.92567934308733, 57.24212612424578, 33.6246953691755, 31.500700541904994, 62.19000434875488, 51.220282214028494, 54.11461687088013, 44.684139592306956, 47.256043093545095, 42.95004987716675, 48.14464473724365, 43.79175465447562, 43.47374255316598, 39.12923894609724, 43.15621682575771, 45.889836175101145, 51.38385670525687, 50.6814945765904, 50.61336054120745, 44.14817987169538, 43.83736263002668, 40.67602954592024, 41.36903592518398, 40.62309122085571, 43.57065255301339, 49.30658156531197, 57.22094454084124, 49.761129243033274, 48.84345981052944, 51.60365949358259, 57.10266883032662, 53.28411258969988, 53.953231062207905, 51.732823031289236, 52.08883135659354, 57.14684547696795, 60.121817452566965, 53.32778549194336, 47.89947754996163, 51.70688540594918, 57.19391604832241, 59.007507051740376, 63.323387554713655, 39.42644814082554, 31.90383849825178, 11.901712673051016, 18.647841147014073, 26.89612933567592, 20.003356524876185, 12.053258963993617, 10.338294165475027, 2.8471980776105608, 0.7946199838604245, 0.507121276642595, 0.0920954749786428, 0.49140141159296036, 8.61892855167389, 43.63761234283447, 50.185136113848, 36.35728638512747, 29.797488621303014, 38.634582792009624, 49.52044711794172, 55.86334644045149, 60.175464493887766, 53.388227871486116, 11.830479741096497, 0.18985453248023987, 0.08983018581888505, 0.10777442436665297, 0.142040436023048, 0.12424048116164547, 0.13021827968103544, 0.1219977465059076, 0.092001898214221, 0.07603074450578008, 0.12667761610022613, 0.18856246609772953, 0.10165070689150266, 0.15065422095358372, 0.10647491445498806, 0.09486009127327374, 0.12590095134718077, 0.1690165184970413, 0.11084467997508389, 0.10472335094319922, 0.12114629362310682, 0.09389973351997988, 0.08895162546208926, 0.13572157866188458, 0.12936207705310412], [0.058424049988389015, 0.08106553541230303, 0.056626807499144755, 0.04550843107114945, 0.038048756175807545, 0.06617199030837842, 0.09082444318171058, 0.04126403846644929, 0.024222083556066667, 0.024113032800544585, 0.0711616382801107, 0.027107270434498787, 0.007901462260633707, 0.09536973892578057, 0.024465774319001606, 0.05204811765413199, 0.028316051732482653, 0.06219076072531087, 0.05351898819208145, 0.012089255714922078, 0.03078502183780074, 0.009504539409785398, 0.43588503343718393, 17.525752237864904, 55.934141635894775, 52.588316508701865, 50.27806479590279, 30.73806973866054, 20.223435504095896, 27.903150865009852, 36.28423997334072, 34.99745791299002, 25.959374938692363, 4.966987073421478, 0.02182716876268387, 0.17253442401332514, 0.0684247129995908, 0.36158292474491255, 1.8543523933206285, 6.627434568745749, 3.92885194505964, 5.859641253948212, 10.760800225394112, 20.466877801077707, 41.100217069898335, 47.682297706604004, 56.69370828356062, 57.86058875492641, 52.02473769869123, 47.017643451690674, 50.27906881059919, 54.770693574632915, 55.29978500093733, 51.39811093466622, 50.53394957951137, 52.51531178610665, 52.304117815835134, 46.39858675003052, 42.110134260995046, 44.55172429765974, 49.49683713912964, 51.077034677777974, 52.72626256942749, 51.40861661093575, 50.42133665084839, 51.46113109588623, 49.51727873938424, 44.11867087227957, 39.27953542981829, 36.94582312447684, 39.662996087755474, 41.69049085889544, 46.22747346333095, 48.089396136147634, 50.5758889062064, 50.47998292105538, 53.09137303488595, 48.85390642711094, 43.69383021763393, 38.479655333927695, 40.435423851013184, 39.20744092123849, 44.30455950328282, 48.052713121686665, 56.00450256892613, 49.041618960244314, 54.80382605961391, 33.45890440259661, 24.56310142789568, 58.688362394060405, 44.791395459856304, 51.52920607158116, 41.343348434993196, 45.71872983660017, 42.535895551954, 46.540847642081125, 43.41960913794381, 41.02365486962454, 35.756930759974885, 38.655840805598665, 41.35742201123919, 47.01422841208321, 46.69246775763375, 48.078265122004915, 44.310594013759065, 42.5775534766061, 39.07737759181431, 37.961326667240684, 36.20091022763933, 38.3725905418396, 44.90163210460118, 50.624581881931846, 48.45609426498413, 47.003476074763704, 51.137164388384136, 48.21600273677281, 47.14201273236956, 50.79254068647112, 50.94912876401629, 49.2423871585301, 50.16694572993687, 51.58139399119786, 49.39045327050345, 48.9022832598005, 43.47075135367257, 48.717058181762695, 50.91003472464425, 53.360452447618755, 52.6750682422093, 35.210177012852256, 12.290538208825247, 9.093005010059901, 14.311775258609227, 13.691216009003774, 3.1369344847542897, 10.325666683060781, 2.836274206638336, 0.46885906692062107, 0.10513155082506792, 0.20816494923617157, 0.023774710151233842, 1.4346527542386736, 15.885706390653338, 44.65328959056309, 26.097128186907085, 11.850194386073522, 16.95017910003662, 25.870095797947474, 36.347829886845176, 45.83159637451172, 39.061087540217805, 19.945856707436697, 0.6093348690441677, 0.16590004786849022, 0.0390277363226882, 0.023627637685941796, 0.06579330669982092, 0.03330289565825036, 0.07747681119612285, 0.01571830441909177, 0.049832046031951904, 0.018756407645664046, 0.08118436725011893, 0.01776781435390668, 0.07524599161531244, 0.02941317670047283, 0.05502259125933051, 0.009261106490157545, 0.023618743788184862, 0.03448292573115655, 0.08381530536072594, 0.02259775553829968, 0.014165639029150563, 0.017755950169105614, 0.045550123655370305, 0.023686325876042247, 0.0482325761445931, 0.025709054033671106, 0.05151944048702717, 0.057140316015907695, 0.022011100946526443, 0.06679098387914044, 0.03972872745777879, 0.08914577468697514, 0.03399782747562442, 0.029929548635014465, 0.06174250013594117, 0.021570767342512096, 0.01520101137326232, 0.029885369219950268, 0.06295557825693063, 0.03143905156425067, 0.023883362267432467, 0.024752677584599172, 0.03939148537548525, 0.09248338666345392, 0.03859678176896913, 0.01864881574043206, 0.5409299081989697, 23.903693062918528, 66.77836540767125, 58.628197942461284, 57.52658537455967, 38.47277314322335, 27.843260867255076, 35.26947641372681, 44.95985800879342, 42.952096121651785, 25.59033874103001, 5.3436949508530756, 0.13001338924680436, 0.024991029973274896, 0.13796972802707128, 0.9931427197796958, 4.523178270884922, 9.847692285265241, 11.241392357008797, 5.902288428374699, 7.224740368979318, 11.935557348387581, 29.67837565285819, 47.594746930258616, 58.60353183746338, 59.297656876700266, 54.20065988813128, 50.01385259628296, 51.975131034851074, 56.5271634374346, 56.07465158190046, 52.178285939352854, 50.08752087184361, 54.49414484841483, 52.51499216897147, 48.50119502203805, 44.53026131221226, 46.202435629708425, 50.702735219682964, 52.685963017599924, 53.60118668419974, 51.977111271449495, 51.41384860447475, 53.52215092522757, 50.76614795412336, 46.89806842803955, 43.065779072897776, 38.69206871305193, 40.91956390653338, 42.74335833958217, 48.553323881966726, 49.7561161177499, 52.338229996817454, 52.332563740866526, 54.1533739226205, 51.15634836469378, 45.81843648638044, 40.601458004542756, 42.106309277670725, 38.93149321419852, 45.15058953421456, 50.82240751811436, 57.10260282244001, 50.32037237712315, 55.07525396347046, 33.79380757468087, 26.175319739750453, 60.26158046722412, 48.00279378890991, 52.69268192563738, 42.34242991038731, 47.3362009865897, 45.26191009793963, 48.39896617616926, 45.677711146218435, 41.90162924357823, 37.30256448473249, 40.33629390171596, 44.11350836072649, 48.139113971165244, 48.55847249712263, 50.48308181762695, 46.464869090488975, 45.19286584854126, 40.684850284031455, 40.11322546005249, 36.85420070375715, 40.29418434415545, 47.119208744594026, 52.582622459956575, 48.6303585597447, 48.979133810315815, 52.07967710494995, 50.28668751035418, 50.760311467306956, 53.30203546796526, 52.75739049911499, 48.94906200681414, 50.20858975819179, 54.27009323665074, 51.303111689431326, 50.96044043132237, 45.27996151787894, 50.2017388343811, 52.74840300423758, 57.264565331595286, 52.07643229620797, 38.178787912641255, 14.487484778676714, 9.104208111763, 9.955137491226196, 9.356762971196856, 11.355086599077497, 7.429943255015782, 4.690114387444087, 1.8210949493306023, 0.21804589831403323, 0.2053464911878109, 0.08738746653710093, 1.3786222636699677, 19.35098668507167, 42.875005858285085, 33.20146322250366, 19.441910811832972, 20.76236731665475, 32.472058704921174, 42.25440665653774, 51.41416474751064, 46.56763642174857, 23.415179116385325, 0.8900887753282274, 0.05711357495082276, 0.08608221621917826, 0.03923500162948455, 0.04043721979750054, 0.0036257162490593536, 0.03183136015598263, 0.039246211027992625, 0.05700644784207855, 0.01825820348624672, 0.037155274833951674, 0.019107812450134327, 0.03213835993249502, 0.052144320349075964, 0.050852823935981305, 0.004378992324096284, 0.01968184289788561, 0.06292244539197002, 0.033580504690429995, 0.0381623361525791, 0.0096720154230882, 0.03272716208760228, 0.0716696913753237, 0.033769659897578616, 0.1800346786954573, 0.19316472485661507, 0.16385407479746, 0.11768914413239275, 0.1017930635384151, 0.1361825889242547, 0.15042342405234063, 0.1162385041160243, 0.15368633610861643, 0.08287379052489996, 0.16180522473795073, 0.17570695520511695, 0.08570544607937336, 0.24558413348027638, 0.1420419830828905, 0.16270570856119904, 0.11181754312877144, 0.17302868249160902, 0.2177891678043774, 0.24861756499324525, 0.09195770522845642, 0.1446513437799045, 0.7326191993696349, 31.467811243874685, 77.64371517726353, 66.27085508619035, 65.49673543657575, 42.194408961704795, 30.801048210689, 38.38453796931675, 48.88372114726475, 46.49971430642264, 34.11173629760742, 6.5791124531200955, 0.2074815287653889, 0.2945472204259464, 0.21304039976426534, 1.1093719686780656, 7.640222668647766, 16.982976334435598, 15.025349174227033, 15.112814835139684, 21.856896196092876, 27.732890469687327, 50.38310766220093, 54.462895325251985, 61.68889331817627, 62.45639133453369, 55.510871274130686, 51.04236664090838, 54.46320104598999, 57.48031037194388, 57.95333678381783, 52.4949883052281, 50.868682520730154, 54.82509102140154, 55.820444788251606, 50.379529339926584, 46.995520387377056, 49.53302683149065, 53.87868731362479, 54.1352356501988, 56.24817936761038, 53.16469737461635, 52.726540497371126, 55.659795488630024, 53.49813447679792, 48.19609614780971, 44.4128680229187, 40.33696092878069, 42.89418983459473, 45.02865212304251, 50.31704418999808, 52.1664913722447, 54.67942203794207, 53.80925049100603, 57.0217535836356, 53.56084196908133, 47.08922726767403, 42.48752219336373, 44.145838328770225, 43.03112145832607, 47.64141798019409, 52.14623737335205, 60.58177430289132, 54.18215683528355, 54.65731634412493, 36.21931600570679, 29.90876749583653, 62.58298751286098, 50.783667836870464, 54.387229442596436, 45.649379866463796, 50.56591476712908, 47.115150996616904, 49.93157202856881, 46.74478421892439, 43.8356533731733, 39.920888900756836, 42.891014507838655, 45.19000319072178, 50.92490039552961, 50.76356669834682, 51.329890046800884, 48.8640056337629, 46.755567823137554, 43.610611643110005, 41.93679755074637, 39.93322542735508, 41.99368940080915, 50.23564256940569, 54.45059353964669, 50.66837290355137, 48.54107073375157, 54.680405208042686, 52.64805712018694, 52.488665444510325, 54.98966952732631, 55.96144805635725, 51.743505886622835, 51.94738687787737, 54.87274524143764, 54.49605907712664, 53.64515488488333, 48.42040831702096, 53.43830006463187, 57.252037729535786, 56.76624747685024, 59.76993983132498, 40.148497990199495, 16.37212371826172, 14.80707151549203, 23.10735481125968, 20.646730184555054, 13.76371090752738, 18.172329017094203, 6.909411575113024, 1.9599131175449915, 0.14545083445097717, 0.4631594813295773, 0.12309919883097921, 2.2247226451124464, 22.13303324154445, 56.769099712371826, 35.90208210263933, 19.225959062576294, 24.361044338771276, 39.33897726876395, 49.73911387579781, 60.13250378199986, 54.91679334640503, 28.23267960548401, 1.4646459562437875, 0.2655690796673298, 0.1309199527438198, 0.1769203386668648, 0.11744780279695988, 0.08382382097520999, 0.12763709175799573, 0.15691827982664108, 0.1889153178781271, 0.11173073135848556, 0.1929988230445555, 0.1070597166461604, 0.11445034721067973, 0.11682203066136156, 0.22860550454684667, 0.09887865385306732, 0.09798547785196986, 0.20708720492465155, 0.12985421850212983, 0.14700113769088471, 0.060998941106455665, 0.10317127672689301, 0.18249238681580338, 0.21710406456674847], [0.02553671631695969, 0.02324261486397258, 0.06829520102058138, 0.02953633080635752, 0.10492145602724381, 0.02500617826756622, 0.04743211516844375, 0.08777267765253782, 0.0469217211274164, 0.0581391059926578, 0.04245316769395556, 0.04683072618874056, 0.03815440068553601, 0.018342348613909314, 0.04471889790147543, 0.02102736766184015, 0.04261263020868812, 0.10646407825074025, 0.03299732419795223, 0.04784526496327349, 0.03798653112192239, 0.09155221948666231, 2.0756542554923465, 40.05392953327724, 56.06550775255476, 47.62235907145909, 42.757987771715435, 25.707824093954905, 16.806075198309763, 18.328552314213344, 25.908885853631155, 34.77965273175921, 17.480172055108206, 0.5029103968824659, 0.0215431798049914, 0.04793990024232438, 0.08194657242191689, 0.8955282920173236, 0.5689457505941391, 7.8426662513187955, 5.267730729920523, 2.9819056263991763, 20.30165137563433, 26.95269809450422, 38.13283600125994, 51.208477224622456, 58.2641818182809, 54.834905351911274, 49.70353215081351, 46.14831611088344, 49.760941641671316, 55.30705976486206, 54.785580090114046, 52.006397928510395, 51.84742314474923, 50.78407778058733, 51.90633692060198, 44.672939096178325, 42.47192348752703, 43.5911671093532, 49.79117325374058, 51.05314677102225, 53.792616503579275, 51.309448446546284, 53.464505195617676, 48.46189601080758, 46.12448031561715, 40.10367168698992, 37.968507630484446, 37.29982342038836, 40.963757923671174, 44.24881758008684, 50.320361954825266, 49.652052947453086, 49.82549735477993, 50.12001064845494, 51.37940290996006, 46.328368255070274, 40.898844378335134, 35.99751213618687, 38.99426671436855, 39.09033945628575, 41.864230564662385, 45.578615937914165, 51.93781573431832, 48.370645318712505, 52.051397936684744, 34.59235709054129, 24.53215762547084, 56.344266005924766, 46.18387699127197, 50.46334893362862, 45.69589805603027, 49.11711113793509, 48.72375624520438, 50.141456263405935, 48.940210001809255, 45.4390926361084, 38.12196554456438, 36.54509966714041, 40.39891454151699, 49.14367757524763, 48.207289695739746, 50.01437023707798, 46.873812266758506, 43.946682112557546, 40.114934716905864, 39.57710940497262, 35.57762554713658, 37.69710751942226, 43.383728640420095, 49.689132009233745, 50.36213799885341, 49.727892535073416, 49.94458947862898, 48.907289436885286, 43.72481223515102, 46.64172158922468, 49.29141017368862, 52.044411523001536, 48.95849418640137, 51.80974653788975, 51.66857998711722, 49.8092211995806, 47.254250458308626, 47.156520571027485, 48.211979729788645, 52.89166791098458, 52.612336431230815, 43.61803926740374, 27.59169786317008, 22.001753977366857, 8.414826086589269, 8.321368472916738, 10.725714428084236, 7.0497938479696, 3.769339544432504, 2.67147096991539, 0.6031246994222913, 0.050346239869083674, 0.10682719626596995, 0.06873006732868296, 6.1201114143644055, 40.07750129699707, 32.7976895059858, 18.677212919507706, 25.655043840408325, 25.942357063293457, 33.449906485421316, 41.85357550212315, 44.9874666758946, 21.24639446394784, 2.8388096477304186, 0.028206556536523358, 0.056897699034639766, 0.0436730820552579, 0.08960919374866144, 0.06253287129636322, 0.03204716821866376, 0.027725044338564788, 0.027376333318118538, 0.018734402755009275, 0.02107274129853717, 0.06393662454294306, 0.037099156595234356, 0.020247926004230976, 0.05537578230723739, 0.030665043275803328, 0.04007982861782823, 0.034288047081125636, 0.009307808359153569, 0.015111329399847558, 0.05023619505975928, 0.0427944267035595, 0.03511122201702424, 0.04417591043082731, 0.028543243916439157, 0.03151270654052496, 0.038772753040705404, 0.06318037012325865, 0.05178781805027809, 0.015061514751453484, 0.05106724778722439, 0.04239869490265846, 0.017236663926658884, 0.035635997607771835, 0.028068525550354804, 0.014921848495889987, 0.0564338558885668, 0.03999917794551168, 0.03971689719972866, 0.04105868323573044, 0.08452302417052643, 0.06245404588324683, 0.025636688273932253, 0.022676206060818264, 0.015451178752950259, 0.09861230850219727, 3.7815067086900984, 47.852274962833945, 63.64287267412458, 52.9783501625061, 51.59869153159005, 32.057897431509836, 22.357503482273646, 22.992919717516216, 24.465015445436748, 33.23848669869559, 18.484266655785696, 1.06486919096538, 0.1401874925941229, 0.029374001481171166, 0.25234937188880785, 2.0853799964700426, 5.11903406892504, 11.297175969396319, 12.109898941857473, 9.769482493400574, 13.290793061256409, 26.48788445336478, 36.495760508946006, 54.94726814542498, 58.41470064435686, 57.5088848386492, 51.23903540202549, 48.44136755807059, 52.40737846919468, 57.4411746433803, 55.65959051677159, 52.09447676794869, 52.35758420399257, 52.50952046258109, 52.89039986474173, 46.85762643814087, 43.36690705163138, 45.547873633248464, 50.76360838753836, 53.930934292929514, 54.275957516261506, 53.02185978208269, 54.279292651585166, 49.99202135631016, 47.54051971435547, 42.97995492390224, 39.979986803872244, 39.65784052440098, 42.53828225816999, 46.61345631735665, 51.48727369308472, 52.26779610770089, 51.18501663208008, 52.701884814671104, 53.76322562353951, 47.59811333247593, 41.82784979684012, 37.37736531666347, 39.12951339994158, 40.169637884412495, 43.68134430476597, 48.1356120790754, 53.58812754494803, 49.35633066722325, 52.46404797690255, 35.185976437159944, 26.41317915916443, 58.15194409234183, 48.427335671016145, 52.90047822679792, 46.470264366694856, 49.98451035363333, 50.303227697099956, 51.15995447976248, 49.89773082733154, 48.73241022654942, 40.12988724027361, 37.41429846627371, 42.26583296912057, 50.948691027505056, 49.37589679445539, 50.88085923876081, 49.19143949236189, 45.913407938820974, 41.637212072099956, 40.40937852859497, 37.58948687144688, 40.03247002192906, 45.121764932359966, 52.05211360113961, 49.93555334636143, 49.27991437911987, 52.39968681335449, 50.65253448486328, 46.72266115461077, 48.68050023487636, 51.755967480795725, 54.3069360596793, 49.348218645368306, 52.49706929070609, 53.729398318699424, 52.461525780814036, 48.38039016723633, 49.607487201690674, 50.259450571877615, 56.77171918324062, 53.7867556980678, 45.59116785866873, 26.96875364439828, 15.854390859603882, 4.60663959809712, 8.944171122142247, 13.676781126431056, 9.116445626531329, 12.184891717774526, 3.6069764282022203, 1.0625542466129576, 0.12670421467295714, 0.07264830850596939, 0.12859340544257844, 6.58765526328768, 38.783569540296284, 27.169839722769602, 19.15986258643014, 27.176193850381033, 30.948881558009557, 39.73633779798235, 47.8815963608878, 52.95423991339547, 26.710541214261735, 3.512558877468109, 0.04727847109149609, 0.08091826617185559, 0.018452491810811416, 0.03328208838190351, 0.07033266526247774, 0.039924674800464084, 0.022405830211937428, 0.0325001310557127, 0.04198532797662275, 0.008753723448275455, 0.040896459083471975, 0.010452821784253632, 0.0225887581639524, 0.09276155887969903, 0.013768848713620432, 0.10968340121741806, 0.01088647690734693, 0.0076799180325386775, 0.05999536067247391, 0.028607752240662063, 0.04196820853810225, 0.006670951726846397, 0.03757974598556757, 0.11126330215483904, 0.0968489113396832, 0.22685427351721696, 0.09938142794583525, 0.20061119885316916, 0.16881094952779158, 0.1209583937057427, 0.17981407339019434, 0.1531643391187702, 0.13637886196374893, 0.11525903881660529, 0.09897126031241246, 0.13166687052164758, 0.11123747711202928, 0.14583405745880945, 0.0998246470200164, 0.16054287818925722, 0.18144753788198742, 0.09412966189639908, 0.09846116482679333, 0.07005150749215058, 0.150664018999253, 4.851752502577646, 57.833039147513254, 68.89703096662248, 61.193500655038015, 55.429198673793245, 35.04834999356951, 25.24240074838911, 26.998151472636632, 37.05374254499163, 45.953721387045725, 23.382213388170513, 1.1521186977624893, 0.24900609414492333, 0.10012909211218357, 0.5730264601962907, 1.8055753878184726, 5.618841878005436, 19.17923242705209, 15.382351091929845, 10.948071547916957, 31.429901872362407, 34.72114542552403, 41.77882330758231, 58.68957832881382, 60.372126306806294, 59.67963409423828, 52.584852831704275, 50.09317670549665, 54.10720314298357, 60.78564139774868, 55.26477650233677, 51.92324883597237, 53.53086396626064, 53.9569205556597, 56.275440624782014, 49.05149582454136, 45.74836042949131, 48.44314629690987, 52.9575958933149, 53.89863559177944, 55.92418139321463, 54.460814339774, 55.92411538532802, 52.07647745949881, 49.2702876499721, 43.66612080165318, 41.59829521179199, 42.40611015047346, 45.34268290655953, 48.81091097423008, 54.80526433672224, 54.69855737686157, 52.005206312452046, 53.54128279004778, 55.477467809404644, 50.97080019542149, 44.673533167157856, 39.61490413120815, 41.768025806971956, 42.25152662822178, 44.80726514543806, 50.181040150778635, 54.65315089906965, 51.251868724823, 52.499119009290425, 36.58691392626081, 29.767288276127406, 58.30301530020577, 51.03261137008667, 54.28364222390311, 50.65985441207886, 52.92760051999773, 52.07361480167934, 53.683616638183594, 54.25613777978079, 50.73046548025948, 42.66556978225708, 39.36547769818987, 45.736906324114116, 53.11718906675066, 51.10761717387608, 51.60220037187849, 51.985866001674104, 48.87828418186733, 43.45314114434378, 43.221203327178955, 39.390470368521555, 42.38619661331177, 47.665893009730745, 54.16557843344552, 52.91690724236624, 51.423114027295796, 53.86829628263201, 53.13675519398281, 48.026678221566335, 51.066487312316895, 54.82196085793631, 55.80647890908377, 51.40250219617571, 54.7109877041408, 54.549317019326345, 54.32775633675711, 52.83704464776175, 52.22465821674892, 52.91152238845825, 59.07632201058524, 56.98803397587368, 47.731657709394185, 31.21098150525774, 26.832461254937307, 14.284488814217703, 16.007127898080007, 20.10505035945347, 17.57788978304182, 14.323803458895002, 6.7266005618231635, 1.4997059149401528, 0.17875349601464613, 0.25730932716812405, 0.3686722586197512, 8.552427342959813, 49.48646695273263, 42.905258314950125, 27.262738874980382, 36.447894368852886, 38.14918858664376, 47.24605853216988, 55.548325538635254, 61.08066190992083, 32.54967703138079, 4.292908021381923, 0.17179860706840241, 0.19710045866668224, 0.13835483736225537, 0.16576666145452432, 0.16614436118730477, 0.12514719393636498, 0.06460572792483227, 0.10410969065768377, 0.0976683712963547, 0.11179846272404705, 0.1461521139634507, 0.13084633169429644, 0.09374052206320421, 0.2296422789139407, 0.06905800330319575, 0.19834151278649056, 0.1105945108990584, 0.08319271555436508, 0.12530297200594628, 0.1339356337807008, 0.1154420804232359, 0.1481956850205149, 0.15814828739634582], [0.07582961315555231, 0.026665267634338567, 0.009735331222015833, 0.03576632043612855, 0.06307260519159691, 0.0174426400169198, 0.05591852550527879, 0.014527142979204655, 0.04048209471095886, 0.01729234790296427, 0.01812478993088007, 0.028013808486450995, 0.04685206272240196, 0.03431013000330754, 0.02710270050114819, 0.0023780964547768235, 0.00811763503588736, 0.01541566931908684, 0.03736172929140074, 0.02054425242490002, 0.03630721801891923, 0.046257306422506056, 4.499281244618552, 50.79058824266706, 53.645620414188926, 49.31358534949166, 39.796856607709614, 26.878845691680908, 22.146992172513688, 38.7546580859593, 49.106320585523335, 35.909252643585205, 6.677028638975961, 0.08991317743701593, 0.08198716238673244, 0.01653439036038305, 0.11769166828266212, 2.0149022468498776, 5.9807031920978, 6.661516785621643, 16.46223837988717, 12.382173657417297, 13.873165879930768, 30.916690553937638, 45.14432225908552, 58.56906877245222, 53.854927948543, 54.33798408508301, 45.92561592374529, 47.930935519082205, 52.815859590257915, 53.98320211683001, 53.032494000026155, 50.160588128226145, 48.79462439673287, 52.15656934465681, 50.3328617640904, 45.657411984034944, 42.468876702444895, 44.80090406962803, 50.89563110896519, 51.34512744631086, 52.974605083465576, 51.85183525085449, 48.88797344480242, 44.42176866531372, 41.277938093457905, 37.01294272286551, 37.888526916503906, 39.91494124276297, 43.23316465105329, 46.62796415601458, 50.53541564941406, 50.76756886073521, 51.2217378616333, 49.49628823144095, 49.26154334204537, 40.21676056725638, 38.09663936070034, 37.357594217572895, 39.308474676949636, 38.506211348942344, 40.680347851344514, 44.94231380735125, 51.63399185453142, 49.21005024228777, 54.65868861334664, 37.779304708753315, 26.619231462478638, 55.18166215079171, 46.75749247414725, 51.859957695007324, 47.49961566925049, 51.097608293805806, 48.52543728692191, 50.721978255680625, 49.30176298958914, 49.57348619188581, 42.17782013756888, 36.82348619188581, 37.119288376399446, 47.170969349997385, 47.26490204674857, 49.61122185843331, 49.11230298451015, 45.769705295562744, 41.46337161745344, 40.221506186894004, 37.17522484915597, 37.645805495125906, 41.78179713657924, 48.87080444608416, 48.37662076950073, 50.5338488306318, 49.698161193302695, 47.67865685054234, 41.93817676816668, 43.69180481774466, 48.83281864438738, 50.74972241265433, 47.79719311850411, 46.16945253099714, 49.01469121660505, 51.93731198992048, 49.570126737867085, 47.371661118098665, 44.64520883560181, 48.8381096976144, 51.99990483692714, 53.572740759168354, 38.95674296787807, 19.49805573054722, 7.75678391116006, 5.624297082424164, 13.251389827047076, 4.380073172705514, 6.888459716524396, 1.5846546994788306, 1.3264610511916024, 0.18275326995977334, 0.04758391363014068, 0.07102992784764085, 1.601625023143632, 19.819257055010112, 61.84776387895857, 29.962772369384766, 14.24503173146929, 16.450924975531443, 32.769764695848735, 42.800215448652, 44.84957620075771, 29.647049699510845, 4.285171636513301, 0.12104702394987855, 0.031825551896223, 0.014045709660942, 0.005909866561913597, 0.060482365611408434, 0.04897691548935004, 0.038877142260649374, 0.032510091949786456, 0.051618672840829403, 0.022583860837455307, 0.031529442606759925, 0.02066512665312205, 0.04894170291455729, 0.018552516354247928, 0.024115400887759667, 0.07033791712352208, 0.03029257504801665, 0.049786699536655626, 0.07964473736605474, 0.029850153252482414, 0.02516586469885494, 0.02105428684236748, 0.02214044498811875, 0.04297629783728293, 0.034876286052167416, 0.03988820015053664, 0.04957347669239555, 0.06791870908013412, 0.03477347442614181, 0.08265992985772234, 0.020513842181701745, 0.05131290460537587, 0.013564915861934423, 0.04171056200617126, 0.03670501595895205, 0.03374824193971498, 0.02789439310851906, 0.027327205686430846, 0.02012768281357629, 0.012033428398094006, 0.030934842369918312, 0.05791507408555065, 0.024819080717861652, 0.07096723121191774, 0.08489656448364258, 6.8895458068166455, 60.82940810067313, 58.51189204624721, 57.319810458592, 45.669640813555034, 31.698126656668528, 26.381248712539673, 29.32972546986171, 40.13313552311489, 35.772213322775706, 7.9537045444761, 0.09084490779787302, 0.05072575807571411, 0.1453736035951546, 0.8710370862058231, 4.802886256149836, 7.670546344348362, 6.511980261121478, 8.953182935714722, 6.5518933194024225, 18.332962683268956, 32.25776236397879, 47.16405241830008, 58.128361906324116, 57.09688445499965, 55.93165765489851, 48.6108341217041, 50.361488342285156, 54.678431919642854, 56.10634578977312, 53.286989143916536, 50.14273125784737, 49.95563364028931, 53.60840586253575, 52.47588075910296, 48.05098302023751, 45.318350315093994, 45.80173996516636, 52.14645276750837, 53.639592851911274, 55.018490655081614, 52.86554268428257, 51.52695138113839, 46.16747924259731, 43.41613851274763, 39.02632917676653, 39.8714212008885, 40.4123523575919, 45.03605195454189, 48.8007492337908, 51.33477463041033, 52.82676478794643, 51.658852509089876, 52.940510272979736, 49.813813958849224, 42.260079860687256, 38.522685527801514, 38.83939136777605, 40.943674155644004, 41.38928297587803, 41.94400978088379, 45.923201424734934, 53.87296894618443, 50.55015972682408, 55.94996615818569, 38.09248433794294, 27.58006657872881, 57.5544615473066, 48.45116799218314, 52.493751525878906, 49.53642450060163, 53.19455030986241, 50.95176560538155, 52.503517218998496, 49.70193059103829, 51.986168248312815, 44.48376744134085, 38.268433570861816, 38.878846713474815, 49.050297260284424, 48.89795453207833, 51.162299496786936, 51.8278500693185, 48.777983461107524, 42.73221342904227, 41.62308985846383, 38.10172891616821, 39.46218620027815, 44.122447218213765, 51.60740457262312, 49.61433465140206, 51.21964645385742, 52.432232175554546, 49.88845150811331, 44.10304437364851, 46.0346679006304, 50.58880908148629, 53.85788093294416, 50.93983902250017, 47.045213903699604, 50.4375433240618, 53.97132764543806, 51.24111986160278, 49.27033976146153, 47.734238965170725, 51.11350577218192, 54.493217263902935, 53.5795430455889, 38.39714200156075, 18.963218144008092, 8.03975190435137, 7.208489835262299, 15.343373434884207, 8.247751440320696, 8.480382340294973, 6.881858493600573, 2.5281324556895663, 0.4232706603194986, 0.1841284433113677, 0.07047040787126337, 1.8443196288176944, 20.73540309497288, 49.09315374919346, 26.726099967956543, 21.513705560139247, 23.474872827529907, 37.53778532573155, 47.48695257731846, 51.003203119550435, 36.63781990323748, 5.187786493982587, 0.06752770327563797, 0.07041239312716893, 0.02211615682712623, 0.04443063247682793, 0.11902952220823083, 0.05389813659712672, 0.033480397026453695, 0.02621942602231034, 0.01059804015260722, 0.024476444282169853, 0.08092927879520825, 0.051652144973299334, 0.03503406919272883, 0.053531381634197066, 0.01912679785995611, 0.037566847034863064, 0.050510940674160204, 0.006962371067077453, 0.06393859229449715, 0.042516217167888365, 0.01856536271848849, 0.03486305122662868, 0.03460146579891443, 0.1503219287842512, 0.11897947346525532, 0.11742249344076429, 0.12379099242389202, 0.14055254443415574, 0.07931545110685484, 0.22350347760532582, 0.11081743000873498, 0.12430234998464584, 0.10027495678514242, 0.09383363063846316, 0.18784009771687643, 0.14637600337820394, 0.08678483244563852, 0.13036135557506764, 0.07016241404094867, 0.13071413950196334, 0.14557371714285441, 0.16738830586629255, 0.14359616754310472, 0.16540032039795602, 0.14566124816026005, 10.187374080930438, 72.56107316698346, 66.30804184504917, 65.45138454437256, 50.97060217176165, 37.76742328916277, 29.639410155160085, 51.23554393223354, 62.10601452418736, 44.12915917805263, 9.24220975807735, 0.3705424096967493, 0.22644618898630142, 0.31323016647781643, 0.5978347318513053, 5.449050051825387, 14.801047427313668, 13.836586219923836, 31.24538551058088, 19.980166912078857, 16.64692497253418, 34.43635613577706, 46.56847367967878, 59.99491555350167, 56.98351764678955, 60.42941420418875, 49.8112222807748, 54.11483921323504, 56.21564095360892, 57.896702017102925, 52.52517127990723, 49.66012328011649, 50.466284547533306, 55.834685121263774, 53.93385601043701, 50.96496370860508, 47.75973537990025, 48.09773744855608, 53.65785966600691, 55.79114423479353, 57.102449962071006, 57.108161381312776, 53.53761414119175, 47.97681794847761, 45.762941224234446, 40.907119682856965, 42.63973985399519, 43.19117668696812, 47.753249236515586, 51.10507413319179, 53.363857064928325, 54.73079701832363, 53.057851450783865, 54.04884869711739, 52.98241138458252, 43.35627630778721, 42.551334449223106, 41.42618833269392, 43.279797485896516, 42.62536055701119, 43.47602156230381, 49.190657820020405, 55.557149750845774, 54.0307799066816, 57.023216179439, 39.51304701396397, 30.75464814049857, 56.90617030007498, 49.76766054970877, 54.76388086591448, 51.92808130809239, 54.76381138392857, 52.23770693370274, 52.41245412826538, 51.4161137172154, 54.45465128762381, 46.15719590868269, 40.18663665226528, 40.604734080178396, 51.69239493778774, 50.95985678264073, 52.570240770067485, 53.65344408580235, 50.32152577808925, 45.01579795564924, 43.472867080143516, 41.37450763157436, 41.56465550831386, 46.10050903047834, 53.63247094835554, 50.22169753483364, 52.71014622279576, 53.452241625104634, 53.43778589793614, 45.545497349330354, 48.58749859673636, 53.634027344839915, 55.807288374219624, 51.54028844833374, 47.39245360238211, 50.78889288221087, 56.14535992486136, 52.808897495269775, 51.65667077473232, 49.151688848223, 53.66292837687901, 56.65843227931431, 56.899784905569895, 43.69028663635254, 23.12777382986886, 11.651369946343557, 11.365646992410932, 22.947382961000713, 12.78629391533988, 13.946426817349025, 6.301432039056506, 4.538339240210397, 0.4704867367233549, 0.4329985183264528, 0.1375875635338681, 2.5066657790115903, 26.34325769969395, 75.01012556893485, 38.366712365831646, 21.95697978564671, 25.633603436606272, 44.44744920730591, 55.536235673086985, 58.55765288216727, 44.92652402605329, 6.956933345113482, 0.33791171493274824, 0.19482478792113916, 0.15553766462419713, 0.17498527892998286, 0.2498176491686276, 0.14598258877439158, 0.09961018245667219, 0.13526976933436735, 0.06994986294635705, 0.15727003238030843, 0.1800122056156397, 0.10863217405442681, 0.12261961027979851, 0.1034567364092384, 0.11360289768448897, 0.10638893049742494, 0.15334525012544223, 0.11440130269953183, 0.14497750199266843, 0.09693020662026745, 0.11829449236392975, 0.20979526532547815, 0.1314033953739064], [0.03863637089463217, 0.053474958054721355, 0.0741031893662044, 0.020723782612809112, 0.028605465577649217, 0.038014391769788096, 0.021610166478369917, 0.032462048277791054, 0.013018830030757402, 0.029616648996514932, 0.012903818345096494, 0.06289548719567911, 0.03641899987789137, 0.059496298166257996, 0.03254229522177151, 0.023790677776560187, 0.04210743713857872, 0.0545198612713388, 0.017329638491251638, 0.013908408099918492, 0.10068100571100201, 0.018284997137795602, 11.966106840542384, 49.0212607383728, 53.63456235613142, 40.23171656472342, 36.46450751168387, 17.848582914897374, 16.755292551858084, 35.03309869766235, 35.93509299414498, 22.82044632094247, 1.6359086292130607, 0.09336322945143495, 0.04285399190017155, 0.03483629319816828, 0.2764237943504538, 4.975937221731458, 4.595881615366254, 7.8557566574641635, 8.203811900956289, 16.71114022391183, 32.494723728724885, 43.378402846200125, 51.66665186200823, 58.09645577839443, 52.72893067768642, 51.87763391222273, 42.664972237178254, 50.81985752923148, 53.91032246180943, 53.672134740012034, 53.93784080232893, 49.94175808770316, 50.43456949506487, 53.27839422225952, 49.05218022210257, 44.30781473432268, 37.40140955788748, 42.027666091918945, 44.9782429422651, 48.53945875167847, 47.917817320142476, 44.82353435243879, 40.96062428610665, 38.59062153952462, 37.057571002415244, 38.44177375520979, 39.418037346431184, 40.81706755501883, 42.06883764266968, 47.21256474086216, 50.02274629047939, 49.23693282263619, 50.68745265688215, 49.83663879122053, 43.287186895098, 36.39644643238613, 36.804260526384624, 36.89657081876482, 41.027747358594624, 42.31260129383632, 41.77727038519723, 41.22746985299246, 49.0939701625279, 47.52250303540911, 53.99291917255947, 37.88355548041207, 22.55547329357692, 55.43167223249163, 47.93368353162493, 52.19591004507882, 48.80838530404227, 51.784198011670796, 46.18734066826956, 51.36101450238909, 49.90587411608015, 48.87755114691598, 45.70682062421526, 38.62846490315029, 35.01378270557949, 45.589694840567454, 48.403909819466726, 49.16680465425764, 49.16426508767264, 48.25173037392752, 44.83670466286795, 42.41272483553205, 36.077249663216726, 38.308778285980225, 39.323764187949045, 45.512278011866975, 49.15651089804513, 51.215679032461985, 49.68735327039446, 46.47304017203194, 41.07170513698033, 39.95709596361433, 45.219623361315044, 51.566239970070974, 48.78424378803798, 50.67567546027047, 49.530396938323975, 50.07938800539289, 50.17174693516323, 53.60735321044922, 48.6765501839774, 48.35579007012503, 47.97701249803816, 55.138371399470735, 47.36124229431152, 32.40784345354353, 11.377844555037361, 11.051881977490016, 15.426256758826119, 7.4105959960392545, 13.786741580281939, 6.546955321516309, 0.9590350985527039, 0.2840186096727848, 0.14322605383183273, 0.03576995059847832, 0.14270966154124054, 7.208546723638262, 33.81992585318429, 44.364928926740376, 16.888079575129918, 17.708420378821238, 34.58849041802542, 42.70644950866699, 42.09876353400094, 39.9116130556379, 10.268693191664559, 0.14864415595574038, 0.021238001895004084, 0.0824150669255427, 0.04120486682014806, 0.03536688383402569, 0.04905026173219085, 0.055854207170861106, 0.030834945051797798, 0.07317109259643725, 0.019235580594145825, 0.02108308726123401, 0.008784578980079718, 0.017429354301254665, 0.04384053431983505, 0.023040889795603495, 0.06713713173355375, 0.055766825431159565, 0.01456521897177611, 0.022942335976819907, 0.002153568156895095, 0.029192109991397177, 0.026797507324122956, 0.02070284471847117, 0.028747370998774256, 0.03564370915825878, 0.04137742506074054, 0.017005076532119086, 0.015818023621769886, 0.03179902796234403, 0.07248251525951283, 0.007265783513763121, 0.05197611491062811, 0.025575126488027827, 0.06844930310866662, 0.05650170260508146, 0.020619890419766307, 0.01400671255708273, 0.04223990413759436, 0.02199011725107474, 0.09584244034652199, 0.05606183549389243, 0.03906621604359575, 0.03821942808904818, 0.04311098703848464, 0.05446686090103217, 17.785997016089304, 57.68633835656302, 58.60360826764788, 48.859260014125276, 43.03662095751081, 28.13539787701198, 17.0450393812997, 32.789563587733674, 38.03201763970511, 27.834221260888235, 2.0630209105355397, 0.061157467242862494, 0.05356366972305945, 0.1102526310299124, 1.3117622456380298, 7.389133010591779, 6.484277359076908, 7.6366139480045865, 7.52382036617824, 9.629270451409475, 24.066581419536046, 37.73088271277291, 51.61727448872158, 57.128554344177246, 55.99956239972796, 53.80061388015747, 46.34781973702567, 50.996720450265066, 55.80250801358904, 55.155856541224885, 55.9607184955052, 49.866741861615864, 50.334828104291645, 54.74391869136265, 50.68496520178658, 45.794162954602925, 40.49488306045532, 43.36417293548584, 47.79232937949044, 49.73229421888079, 51.24000467572893, 47.28014292035784, 43.51844031470162, 39.72383451461792, 39.23998975753784, 39.398676191057476, 40.9466028213501, 42.03597961153303, 45.699045589991975, 50.06589807782854, 51.79061467306954, 51.36642367499215, 51.88435282026018, 50.999343395233154, 45.82658324922834, 38.399657249450684, 39.350302832467214, 38.70855678830828, 41.84191295078823, 42.0493757384164, 43.62695728029524, 43.87105791909354, 52.073309080941335, 49.835297788892476, 55.188245568956646, 38.896571568080354, 24.10368480001177, 55.50263071060181, 49.344605582101, 53.13738053185599, 50.32486091341291, 53.3418173789978, 48.168365887233186, 53.32574272155762, 50.71021148136684, 51.75984804970877, 47.91583013534546, 40.992881298065186, 38.35535553523472, 46.17812040873936, 50.62524543489729, 49.69650752203805, 50.786971705300466, 49.54271262032645, 46.56383923121861, 44.23836401530674, 37.81787415913173, 39.97124597004482, 41.203366552080425, 48.78963906424386, 51.97632959910801, 51.53597709110805, 51.30699225834438, 47.980962548937114, 43.49659170423235, 41.99018056052071, 47.91175849097115, 53.32694475991385, 50.7794954436166, 51.96902356828962, 49.96608025687081, 50.58861105782645, 51.944576331547324, 54.86145789282662, 51.971031597682405, 49.11196947097778, 52.36013419287545, 55.239901951381135, 49.122082574026926, 29.599944387163433, 12.189719847270421, 5.588366644723075, 10.49647685459682, 7.195858444486346, 10.148105468068804, 9.201859831809998, 3.0357309324400763, 0.6769349245088441, 0.3975064685302121, 0.04042728265215244, 0.13267800983573708, 9.696801730564662, 41.03703710011074, 35.19251816613333, 17.02059040750776, 21.289547988346644, 37.99980231693813, 47.781976563589915, 48.361341680799214, 47.147335052490234, 13.395757760320391, 0.21473905790065015, 0.07635234296321869, 0.04473081636907799, 0.04442145189802561, 0.0368034917462085, 0.04975049630073564, 0.043346034961619546, 0.024353400438225696, 0.027552055228235464, 0.008532739011570811, 0.03251010552048683, 0.042431064415723085, 0.0316376384081585, 0.031807937127138884, 0.03602741053327918, 0.029696173300700526, 0.043575800489634275, 0.03166541763182197, 0.02065644140488335, 0.023464568757585118, 0.02889486076310277, 0.01508610146785421, 0.04282465543864029, 0.2196960411965847, 0.23702346427100046, 0.1205555610358715, 0.11881270312837192, 0.08913552202284336, 0.09225341757493359, 0.12757831705468042, 0.10622417540954691, 0.1384683291294745, 0.10522882560534136, 0.16453269124031067, 0.10641802607902459, 0.17317604672695908, 0.17050162809235708, 0.11858307330736093, 0.1253015742238079, 0.15927340702286788, 0.1437925084361008, 0.1498200571430581, 0.0902353458638702, 0.1312352136841842, 0.15010774242026464, 24.601042066301616, 65.85090596335274, 65.81194046565464, 54.47631229673113, 47.10810899734497, 27.005325487681798, 25.104916742869786, 48.97696944645473, 45.586686270577566, 30.85599456514631, 2.5827274918556213, 0.20247518883219787, 0.1515713967382908, 0.16159044126314775, 2.366216629743576, 10.439283626420156, 10.843302266938345, 16.337830884116038, 12.734453405652728, 21.08138690676008, 35.80171537399292, 45.942718914576936, 54.07347311292376, 60.981281825474326, 56.707503931862966, 56.478074414389475, 46.583919525146484, 54.295172759464805, 57.40141705104283, 55.84122337613787, 55.39965493338448, 50.11930193219866, 50.95928355625698, 57.900672912597656, 51.45592342104231, 48.793832302093506, 41.70844152995518, 45.89543642316546, 49.01206827163696, 51.81589569364275, 51.97491564069475, 48.98912879398891, 45.24793379647391, 42.0109417779105, 40.184507029397146, 41.303448404584614, 43.044587067195344, 45.98154892240252, 46.99832745960781, 52.604036808013916, 53.079102516174316, 51.74549307141985, 52.76158026286534, 53.45076165880476, 47.39289828709194, 40.69650936126709, 41.34481797899519, 40.82111488069807, 45.78015538624355, 45.253641741616384, 45.86398540224348, 45.83039781025478, 53.47302368709019, 52.839459146772114, 57.08515242167881, 41.06092153276716, 26.47903765950884, 56.30186114992414, 51.04428434371948, 55.59490973608834, 53.49273920059204, 54.34834732328142, 48.11454166684832, 54.0195620400565, 53.87711354664394, 53.04127652304513, 49.940146105630056, 43.857689585004536, 39.74913985388619, 49.327551228659495, 52.5470164162772, 51.58640711648123, 52.2674035344805, 51.76560810634068, 49.64966624123709, 46.2936863218035, 39.648033142089844, 41.855972630637034, 42.842547348567415, 51.30737788336617, 53.86858115877424, 55.29335444314139, 52.96522501536778, 49.81151063101632, 46.04829331806728, 44.46050139835903, 50.6024831363133, 56.94956527437483, 52.179307324545725, 54.59940310886928, 51.50157308578491, 53.00504514149257, 53.00800507409232, 57.442421845027376, 54.623346601213726, 53.821986539023264, 52.8578371320452, 60.12832791464669, 51.65763310023716, 35.29480259759085, 15.17797156742641, 16.601167610713414, 22.405003104891094, 14.844805444989886, 23.457012483051844, 17.18287774494716, 5.9950586046491345, 0.4402978723602635, 0.4956446981855801, 0.19953745789825916, 0.4162244541304452, 11.254977822303772, 44.72781944274902, 54.40744522639683, 27.742181948253087, 28.435426303318568, 46.34816367285592, 53.4751672063555, 55.322901657649446, 53.946696281433105, 18.951076166970388, 0.8384727793080466, 0.15754566687558377, 0.14323723608894007, 0.14410193397530488, 0.11267732842160122, 0.07931469793298415, 0.09756427723914385, 0.14678520070655005, 0.18126087289835724, 0.11426974833011627, 0.10059114053313221, 0.11728827921407563, 0.13101182638534478, 0.11660371880446162, 0.12968653892832144, 0.13183984266860144, 0.1487322569425617, 0.15172266933534825, 0.10753912877823625, 0.11130623306546893, 0.14958749605076654, 0.10072264740509645, 0.13776998088828155], [0.06720712262072734, 0.053946027598742924, 0.05511049547099641, 0.10973190290055104, 0.014088248717598617, 0.03690593696332403, 0.029695084251995598, 0.037309600838593075, 0.047297110448458364, 0.05054571559386594, 0.05684663248913629, 0.06360536374683891, 0.015232067921065857, 0.03302511699231608, 0.026974006156836237, 0.01714610494673252, 0.021209730733452097, 0.03526930371299386, 0.06186461608324732, 0.05558719007032258, 0.04347179803465094, 1.152861395052501, 38.500055244990754, 55.57356834411621, 47.97785670416695, 40.718177318573, 25.590066024235316, 16.95564385822841, 40.04233646392822, 41.84082555770874, 43.16772999082293, 14.339752180235726, 0.2523845471441746, 0.06622233760676213, 0.11917619433786188, 0.24191578317965778, 0.9859904178551265, 6.56501499244145, 7.366922225270953, 3.4365156207765852, 13.690095611980983, 10.967785324369158, 36.304052761622835, 43.20919336591448, 57.34388249261038, 54.92703151702881, 53.99810600280762, 47.074514457157676, 42.67803485052926, 50.137777192252024, 54.78018133980887, 52.07909345626831, 53.00607347488403, 51.03146491731916, 53.50516605377197, 50.52035542896816, 48.86949471064976, 44.30970117024013, 39.40332106181553, 38.232355049678254, 38.62494216646467, 38.55140243257795, 38.66877487727574, 37.63010951450893, 38.41862235750471, 40.91768789291382, 42.21788345064436, 45.610251086098806, 45.58163840430123, 46.02905723026821, 44.951058115277974, 46.44497292382376, 50.78281668254307, 48.79473556791033, 50.91248049054827, 45.846823351723806, 37.93647990907942, 36.60017803737095, 36.65103537695748, 39.58692373548235, 46.57438312258039, 45.287257126399446, 46.87687642233712, 45.21048648016793, 50.41029943738665, 47.797144481113975, 54.04473883765084, 38.258209296635215, 22.376091650554113, 49.91217960630144, 42.97251340321132, 51.75649206978934, 46.86664867401123, 49.07576240812029, 45.86690711975098, 48.72626107079642, 45.774499552590505, 52.424821921757285, 48.4546594619751, 40.90545211519514, 35.41747999191284, 43.680566106523784, 49.28524364743914, 47.45847191129412, 49.8103016444615, 48.62795100893293, 46.28952782494681, 44.994147368839805, 38.55462987082345, 37.54787758418492, 37.43934324809483, 41.20384250368391, 46.36632973807198, 47.85106250217983, 46.79316105161394, 42.75618471418108, 38.09867170878819, 36.593980244227815, 41.55428532191685, 47.04886865615845, 49.82234287261963, 49.08278008869716, 49.73914861679077, 50.31491109303066, 48.943715367998394, 49.243564878191265, 48.55093370165144, 48.03768764223371, 49.400997161865234, 50.08789954866682, 53.48466191973005, 38.493582998003276, 24.039565086364746, 9.673255154064723, 13.583557145936147, 6.982401098523821, 6.119744896888733, 7.968190670013428, 1.0629748297589166, 0.9866892546415329, 0.05804136302322149, 0.08383553248963185, 0.07945811987987586, 2.832172163895198, 24.17382686478751, 50.84016711371285, 37.86164433615548, 20.679680279323033, 29.434764862060547, 37.940329211098806, 42.06035041809082, 44.67883464268276, 18.33887038912092, 0.789807596376964, 0.040133056297366104, 0.08379122415291411, 0.06062769424170256, 0.01623463903420738, 0.030968250041561465, 0.08359182985233408, 0.025471086713618467, 0.08501764905772038, 0.07165736239403486, 0.015969262292076434, 0.04906571536724057, 0.01260164549707302, 0.043186864216945, 0.03193000896966883, 0.009191158011422625, 0.025971957515659075, 0.02148974347593529, 0.04960309135328446, 0.06510806775518826, 0.012935830779107553, 0.03232846848134484, 0.049102206980543475, 0.09515371373189346, 0.01977906339535756, 0.022149997064843774, 0.01799288102691727, 0.0777351294777223, 0.02541397781377392, 0.025429015846124718, 0.02073803524087582, 0.0037544852322233574, 0.03914813896907227, 0.0017109155534334214, 0.05889523149068866, 0.06477823866797344, 0.10476622078567743, 0.03161572511973126, 0.027120369553033794, 0.05525904714262911, 0.08390359633735248, 0.017682853287884166, 0.03436917612063033, 0.045180685086441894, 2.2817065588065555, 46.923505783081055, 61.11372838701521, 54.67651421683175, 45.59305082048689, 35.53307022367205, 19.048328365598405, 28.16514311517988, 41.89554956981114, 46.275221484048025, 16.74123808315822, 0.262556465608733, 0.018007561132045727, 0.06183735254619803, 0.7239282514367784, 4.094432294368744, 8.29664591380528, 9.184762920652117, 4.861122148377555, 6.442998545510428, 13.660004700933184, 36.29312324523926, 46.35787378038679, 58.096792766026084, 57.570741176605225, 55.526758330208914, 48.88637883322579, 43.93421009608677, 52.561597211020334, 56.55962889535086, 53.386195523398264, 53.20082800728934, 51.69635888508388, 52.5819866997855, 52.31760079520089, 50.30546849114554, 45.069653442927766, 40.521355697086875, 39.10203327451433, 40.551319803510395, 41.319422313145225, 40.145711762564524, 40.00463553837368, 39.86038746152605, 41.712450640542166, 43.656796319144114, 46.88009343828474, 47.44543709073748, 46.869216033390586, 47.252878189086914, 49.31868185315813, 51.90729577200753, 50.85621745245797, 51.96508741378784, 48.26123898369925, 39.87653507505144, 38.0329521724156, 37.88766533987862, 40.566710063389365, 48.391413484300884, 48.15370518820626, 47.428285462515696, 46.34278229304722, 51.436899253300254, 50.47806869234358, 53.579959937504356, 39.193343026297434, 24.70290092059544, 51.055286816188264, 45.38811370304653, 51.448075430733816, 48.30455405371529, 49.07804141725813, 46.46814169202532, 49.83007969175066, 46.43508563722883, 52.7576128414699, 50.48223066329956, 43.39776400157383, 37.07304116657802, 45.52728612082345, 50.36748811176845, 49.47790329796927, 50.44344234466553, 50.534842423030305, 47.866612570626394, 46.841808864048545, 39.433010714394705, 39.76885536738804, 37.6921569279262, 42.660574027470176, 48.30197974613735, 50.34253018242972, 48.82261521475655, 45.77148403440203, 41.21073511668614, 38.87362514223371, 43.37303188868931, 50.00757489885603, 51.29962716783796, 50.549103600638254, 51.36975186211722, 51.160447801862446, 51.52153526033674, 51.544648442949565, 52.05794313975743, 49.756421838487896, 50.44973741258894, 52.70939929144723, 54.51788336890084, 39.83791698728289, 22.457727772848948, 8.67354052407401, 5.680397272109985, 5.9667342730930875, 9.365665350641523, 12.524632573127747, 5.223818114825657, 3.559309180293764, 0.25526080280542374, 0.06658572025064911, 0.0672896731910961, 2.9051080558981215, 25.786832060132706, 47.012932573046, 34.08249480383736, 27.596052646636963, 35.48428692136492, 43.28795119694301, 47.61541434696743, 51.62846803665161, 23.07676362991333, 1.3103169117655074, 0.02574720636143216, 0.027185095008462667, 0.05228767104979072, 0.015763126746086136, 0.09523931092449597, 0.06738141112561737, 0.05767296600554671, 0.09238089394888707, 0.06325190807027475, 0.025580334244295955, 0.035084609873592854, 0.06571660510131291, 0.05034245703635471, 0.029168361265744482, 0.037537212017923594, 0.09277695483927216, 0.06488468724169902, 0.011259174140702401, 0.07524145221603767, 0.039716724173298905, 0.035674314480274916, 0.034904404543340206, 0.17748650828642504, 0.13660420344344207, 0.11015950209860291, 0.16076792111354216, 0.1903879288583994, 0.11572312962796007, 0.10760394244321755, 0.11128665733018092, 0.20572252172444547, 0.11257009274725403, 0.09830804661448513, 0.18279660120606422, 0.12745054891066893, 0.18014652840793133, 0.11975835024246148, 0.09669301791914872, 0.16193344071507454, 0.1926897774849619, 0.1312568046684776, 0.10656454893095152, 0.14294615813664027, 3.1760806356157576, 57.05354854038784, 70.0633625302996, 60.71809101104736, 53.0990959576198, 36.010946478162495, 24.653990813664027, 51.82061004638672, 53.2645707811628, 52.711886746542795, 18.947873047419957, 0.4445620578314577, 0.1726171374320984, 0.22220332308539323, 0.956134768468993, 4.1656157204083035, 13.32015267440251, 17.35627177783421, 10.185451166970388, 21.421419586454117, 16.37597128323146, 37.91468341009957, 47.21770988191877, 60.36083548409598, 59.701889174325125, 58.72431237357003, 50.16749463762556, 47.241139207567485, 54.74826826368059, 59.20641313280378, 52.574083123888286, 54.08985349110195, 51.887872082846506, 54.140502384730745, 53.16175481251308, 52.72682537351336, 46.95501586369106, 42.95339890888759, 42.23602172306606, 42.024185044424875, 42.53196634565081, 42.48695591517857, 41.83137253352574, 42.22716971806118, 45.18500396183559, 46.66663435527256, 51.91065870012556, 48.96235391071865, 50.072092396872385, 49.7385128566197, 50.96489770071847, 53.308274950299946, 52.238363538469585, 54.76212297167097, 49.102391379220144, 43.05925471442086, 40.356603486197336, 42.1387608391898, 43.34887300218855, 51.71993064880371, 51.303188119615825, 51.0301273890904, 49.69295004435948, 54.34854187284197, 53.895713874271934, 55.453597273145405, 39.905484744480674, 28.497942720140728, 50.91943563733782, 45.008227893284385, 51.898117201668875, 48.08180175508772, 49.914298806871685, 46.934327602386475, 50.92195783342634, 47.21137659890311, 55.42164250782558, 54.92955371311733, 46.58825520106724, 39.422251428876606, 47.61138091768537, 53.7853730065482, 50.32351296288626, 53.24032851627895, 51.29785885129656, 50.58966718401228, 49.76268563951765, 42.125739915030344, 42.1399177142552, 39.7895644732884, 45.96620382581438, 49.782877104622976, 51.16247320175171, 50.45509794780186, 48.828295367104666, 42.988317080906455, 40.11814478465489, 46.23943478720528, 51.359534536089214, 55.224431787218364, 52.9534478187561, 53.21647882461548, 54.50940309252058, 53.29394776480538, 52.64592749731881, 53.86914396286011, 52.30531638009207, 53.60779789515904, 54.77440391268049, 58.96487290518624, 43.83529206684658, 27.32411057608468, 14.384527240480695, 22.016444206237793, 15.850857700620379, 13.448555384363447, 17.362653698240006, 6.587425538471766, 3.4979535468987057, 0.339532979364906, 0.38297767671091215, 0.22146884963980742, 4.0873342752456665, 32.91211244038173, 64.51757444654191, 45.7138660975865, 31.638198443821498, 39.19789409637451, 49.51235246658325, 54.94223070144653, 58.825728280203684, 29.239530903952463, 1.9523795332227434, 0.12334252148866653, 0.1631137388093131, 0.16971112122493132, 0.11021027008869819, 0.1452826934733561, 0.17208721515323433, 0.09398374972598893, 0.29850975636925015, 0.12245598834540163, 0.09792343260986464, 0.11990785864847046, 0.08611817857516663, 0.14336204582027026, 0.11018256550388676, 0.10615009974156107, 0.12375720137996332, 0.11268311632531029, 0.10908753890544176, 0.12616152236504213, 0.10291591007262468, 0.12348907148199421, 0.12436721793242864], [0.06559564944888864, 0.04105511414153235, 0.02109822877017515, 0.040006244887730906, 0.03983278080288853, 0.06495175364294223, 0.041597898051674874, 0.035811996020908864, 0.06047691697520869, 0.030570882971265485, 0.03460300946608186, 0.07368747131632906, 0.05990161427429744, 0.01782952032850257, 0.0429559316086982, 0.02455247413100941, 0.004973388152263526, 0.025804506947419474, 0.039285813724356036, 0.03756708452211959, 0.05243007180147937, 4.734900304249354, 42.994115352630615, 51.092932156154085, 43.01005104609898, 38.15814134052822, 22.627517427716935, 33.327538285936626, 43.383530616760254, 40.41628156389509, 32.35593693596976, 5.172641592366355, 0.163399836314576, 0.05295787365841014, 0.0537581819641803, 0.18664313480257988, 1.8792315040315901, 5.6751157726560315, 4.751260706356593, 7.950952189309256, 12.662108761923653, 25.11564302444458, 44.85976573399135, 49.14138119561331, 56.65426683425903, 50.84775454657418, 52.34651572363717, 42.25482702255249, 47.35658352715628, 49.870650223323274, 54.71631349836077, 51.069283962249756, 51.08483403069632, 47.08379030227661, 51.342316899980815, 48.906139510018484, 48.78512273515974, 44.09094408580235, 38.270010811941965, 37.49621425356184, 38.71410492488316, 36.35468775885445, 37.59834235055106, 40.942423479897634, 46.88994598388672, 47.5953687940325, 52.082439013889854, 50.239891392844065, 50.69121510641915, 48.677269322531565, 49.20432840074812, 45.82627752849034, 50.49107919420515, 49.016313620976035, 48.817556926182334, 38.64510236467634, 38.70631946836199, 36.70214285169329, 39.726221220833914, 46.43038170678275, 50.17828171593802, 49.907680647713796, 50.85640157972063, 47.57507658004761, 50.28796945299421, 46.99541616439819, 53.509421825408936, 37.10966164725167, 16.66046006338937, 49.237870829445974, 43.6874726159232, 46.44526127406529, 46.754452637263704, 48.45584065573556, 46.87855093819754, 49.67896679469517, 49.04864706311907, 51.35951369149344, 50.34743561063494, 41.85071979250227, 34.736542633601594, 40.62054818017142, 49.47139630998884, 47.143315519605366, 47.866087981632774, 51.11058405467442, 46.898593017033164, 45.67830869129726, 41.063600063323975, 37.71001727240426, 35.71604061126709, 33.69152661732265, 35.13554988588606, 38.87176997320992, 37.678937980106895, 35.93271671022688, 35.235996518816265, 34.451437200818745, 36.91583469935826, 39.706036703927175, 44.2499292918614, 47.98924132755825, 47.83527619498116, 48.11255100795201, 49.98242241995675, 49.94556222643171, 52.46100466591971, 48.44429622377668, 50.13343456813267, 50.35146903991699, 51.741056646619526, 46.56106342588152, 30.179566587720597, 15.424043757574898, 8.144961527415685, 5.070963391235896, 8.142649514334542, 9.356168031692505, 3.413611318383898, 2.4202126009123663, 0.45398563359464916, 0.056359420597021065, 0.03111230641869562, 0.24829963062490734, 14.142557093075343, 46.097337177821565, 60.220773696899414, 21.316819667816162, 28.35400036403111, 35.44152423313686, 38.87772110530308, 49.49659047807966, 27.056009122303553, 3.4773990384169986, 0.17375941042389187, 0.057126860666487894, 0.028444997134751508, 0.10213925210492951, 0.03726542481620397, 0.03534254139023168, 0.08136459972177233, 0.05043420175622616, 0.026606538732137, 0.029247373275990998, 0.0255364584736526, 0.03391316666134766, 0.022928005317226052, 0.04681369495977249, 0.05061914326090898, 0.009517235648153084, 0.08161217679402658, 0.06934884376823902, 0.03196273132094315, 0.06723241162087236, 0.04803964149739061, 0.053714972854192765, 0.09119638215218272, 0.04073248091819031, 0.05221970219697271, 0.056122978284422836, 0.014646979048848152, 0.030013103437210833, 0.019948775181546807, 0.01809137886656182, 0.01883549938377525, 0.030180545523762703, 0.03227275057828852, 0.03763448679819703, 0.03371342630790813, 0.034032588824629784, 0.03929725043209536, 0.02965711343235203, 0.009552745930185276, 0.0181573307740369, 0.05840363965502807, 0.05060831384201135, 0.054777938673006635, 6.891541676861899, 50.952488218035015, 57.079281193869456, 51.439046246664866, 45.57206726074219, 29.024640492030553, 28.33262770516532, 43.12596436909267, 45.257011617933, 38.81117473329817, 6.474413522652217, 0.1258962151727506, 0.05022574562047209, 0.11363522987812757, 0.8474156537226268, 6.309176240648542, 7.244224854878016, 7.652560063770839, 6.34887694461005, 13.676127995763506, 26.375380958829606, 44.13803897585188, 52.643697125571116, 58.95305401938302, 53.164725167410715, 53.38310010092599, 44.677073274339946, 48.67031764984131, 52.632256916591096, 55.901922839028494, 52.020794595990864, 50.79800197056362, 48.31540713991438, 51.11188336781093, 50.95866864068167, 50.97007758276803, 45.6215558052063, 39.52630417687552, 38.68797969818115, 40.61835254941668, 37.4207672391619, 38.51263495853969, 42.57480893816267, 46.93214239392962, 49.32048143659319, 52.47622469493321, 51.86340052740914, 52.18841641289847, 50.99409750529698, 50.011886256081716, 49.46505955287388, 52.05245058877127, 50.43002537318638, 50.99420520237514, 40.687921387808665, 38.768665654318674, 38.84945930753435, 40.535172189985005, 48.689470359257285, 52.90763487134661, 51.81513833999634, 52.0341351372855, 49.64214481626238, 52.87572526931763, 48.91068363189697, 54.968439306531636, 37.61489643369402, 18.573882784162247, 50.46456834248134, 44.24645171846662, 47.92592934199742, 46.68384156908308, 50.26495007106236, 48.06008168629238, 50.85199989591326, 49.44057410103934, 52.95747429983956, 50.7847934450422, 42.67233732768467, 35.96566506794521, 44.411259514944895, 51.33501781736101, 49.712644713265554, 48.69806180681501, 51.59497424534389, 48.552670751299175, 48.52664279937744, 42.064574922834126, 38.87388569968087, 37.79229784011841, 36.24249867030552, 37.300209045410156, 40.51855557305472, 40.42570332118443, 38.2862035887582, 37.36065142495291, 37.09081465857369, 39.84296832765852, 44.39125565120152, 46.59126724515642, 49.84976741245815, 51.559191022600444, 51.32590178080967, 51.85271767207554, 51.089749881199424, 54.999358790261404, 49.98286015646798, 51.743439878736226, 51.45568370819092, 53.69932998929705, 49.34190273284912, 33.74293981279646, 18.533725670405797, 10.352414642061506, 5.973692893981934, 11.355491331645421, 8.236180084092275, 7.681337765284947, 6.117718194212232, 0.7909779878599303, 0.16460173896380834, 0.04109699332288333, 0.6642794321690286, 15.21786117553711, 49.359290599823, 50.913446290152415, 21.130548885890416, 34.99397339139666, 40.16871724809919, 47.325459071568076, 53.40692547389439, 32.96044758387974, 4.45086532831192, 0.2616353678916182, 0.07787713328642504, 0.04348737719867911, 0.029941769050700322, 0.05023786086323006, 0.020802889617958238, 0.029457077916179384, 0.021764702828867093, 0.04289735368053828, 0.01499094202050141, 0.036344059077756743, 0.01777898982566382, 0.013554303574242761, 0.002438400830474815, 0.024985391347269927, 0.046300800517201424, 0.06132596105869327, 0.03644486563280225, 0.03455229236611298, 0.016005178846951042, 0.026620647171512246, 0.02337239316797682, 0.1887106310044016, 0.09208657938454833, 0.17965779320469924, 0.10593249356108052, 0.11782991300736155, 0.12353850954345294, 0.1307994584952082, 0.11832616637860026, 0.12580541361655506, 0.08191854214029652, 0.15791215720985616, 0.12513743660279683, 0.15752129389771394, 0.12483444357556955, 0.08237799177212374, 0.0883138771834118, 0.16817794420889445, 0.09258600151432411, 0.16887531535966055, 0.1476650842066322, 0.19780969060957432, 10.569558875901357, 59.84183284214565, 64.96984658922467, 57.14781127657209, 49.70651987620762, 32.62105587550572, 42.990863595690044, 55.71265043531145, 48.812971115112305, 40.48524938310896, 7.831622089658465, 0.3255665030862604, 0.1755728902561324, 0.16454212287706987, 1.5600354948214121, 7.412314806665693, 15.47313278062003, 12.205635564667837, 15.294338260378156, 21.429439544677734, 28.403594868523733, 47.43484803608486, 54.93361840929304, 60.82079928261893, 56.05973379952567, 55.224553380693706, 48.03253902707781, 52.27787446975708, 53.77042048318045, 57.75834601266043, 52.08210550035749, 51.66591535295759, 47.30954769679478, 51.957423550742014, 52.8813533101763, 52.73684120178223, 47.552856240953716, 42.25803361620222, 40.90532009942191, 42.437491689409526, 39.474317755017964, 41.62145355769566, 44.75776965277535, 50.34790808813912, 50.1872101511274, 56.13904401234218, 53.66318546022688, 55.80581188201904, 52.89133439745222, 53.207341943468364, 50.333796296800884, 53.803525175367085, 52.37599345615932, 53.17390373774937, 42.53296341214861, 40.59834173747471, 40.4170423916408, 44.016723428453716, 51.23597124644688, 54.1254734311785, 54.198592799050466, 55.753839356558665, 51.833401679992676, 55.25415965488979, 50.89523506164551, 58.096837929316926, 38.340858118874685, 21.366530554635183, 50.31867701666695, 44.17968995230538, 47.73580230985369, 48.4009290422712, 51.14291054861886, 50.602733271462576, 53.63661207471575, 51.54789325169155, 55.696607044764924, 53.70149435315813, 43.99535771778652, 38.552458558763774, 45.722207409994944, 54.905863830021445, 50.882353101457866, 49.94975199018206, 54.2992513520377, 49.9058324268886, 51.10202387401036, 44.986834389822825, 41.55313886914934, 38.86909144265311, 37.04464735303606, 39.77567502430507, 42.50690071923392, 42.46720566068377, 39.46255098070417, 38.709880420139854, 38.325141293661936, 42.30386740820748, 45.29546294893537, 48.98640857424055, 51.977121693747385, 53.744434220450266, 53.88647971834455, 54.62821728842599, 53.710853576660156, 57.23808227266584, 53.46749986921038, 53.88280759538923, 54.71484048025948, 57.19726855414254, 52.00810023716518, 35.99728979383196, 20.850192546844482, 17.76185723713466, 11.622078946658544, 17.111625705446514, 18.555827890123638, 9.948988335473196, 3.9625611305236816, 1.3699675223657062, 0.14390244467982224, 0.15493726969829627, 0.751471996307373, 18.69921612739563, 55.132899693080354, 64.76831408909389, 30.78607484272548, 39.28210973739624, 45.998749188014436, 52.657843657902305, 60.070880208696636, 41.140005929129465, 6.91762912273407, 0.3500530134354319, 0.18955225870013237, 0.17173046858182975, 0.13108702163611138, 0.15361228079668113, 0.06809741484799556, 0.17379963397979736, 0.136831865512899, 0.13021093793213367, 0.10924899631312915, 0.07041562973920788, 0.12381703459790774, 0.13745092015181268, 0.12120329056467329, 0.10299217740872077, 0.11648485303989478, 0.13186298071273736, 0.1265699325927666, 0.16735401270645006, 0.149517579802445, 0.16220177417354925, 0.09248236886092595], [0.046405956481716464, 0.019373937277123332, 0.021901938232726285, 0.0374335420450994, 0.04039230417194111, 0.05089528326477323, 0.06669176848871367, 0.02341074396723083, 0.01311753482358264, 0.0628630667924881, 0.08159290639949696, 0.04440274129488638, 0.05007179620276604, 0.04363675668303456, 0.026069081321890866, 0.018285190520275916, 0.014609244020123566, 0.06868248166782515, 0.028383033316848532, 0.08273205813020468, 0.16932404413819313, 11.231634480612618, 50.557069710322786, 47.974455560956685, 34.05841929571969, 26.01693207877023, 21.2476156098502, 33.58305134092058, 46.702198709760395, 45.80035727364676, 25.059716973985942, 2.158253788948059, 0.02215152546497328, 0.027748202738751258, 0.14741535617836884, 0.8081466065985816, 7.356167282376971, 6.317957895142691, 4.7327229125159125, 6.757030631814684, 20.22691134044102, 37.01292187826974, 54.9314922605242, 54.80073063714163, 51.65161943435669, 49.7581067766462, 45.38778713771275, 42.399297441755024, 47.344597884586875, 50.64473165784563, 53.66627740859985, 50.492156164986746, 48.60518871034895, 49.82347890308925, 48.22931548527309, 51.92652838570731, 49.32149934768677, 47.88126632145473, 46.74603142057146, 41.826595646994456, 38.09722300938198, 37.677398954119, 40.84323794501168, 45.17091996329171, 49.52880580084664, 48.83101906095232, 49.29877526419503, 49.99815661566598, 50.837290559496196, 49.601226874760215, 51.644591331481934, 48.15930543627058, 48.69833626065935, 50.399147578648154, 45.78489753178188, 36.06682736533028, 37.318833691733225, 35.702401297433035, 45.667636258261545, 49.77633884974888, 50.85758624758039, 46.50164590563093, 49.907833508082796, 49.078871726989746, 50.376235893794465, 48.83216551371983, 53.394488198416575, 34.44269636699131, 17.886822325842722, 52.57231133324759, 42.36969116755894, 48.24796445029122, 46.56882803780692, 50.2321788924081, 48.73079824447632, 48.937997000558035, 49.30914545059204, 49.10922145843506, 48.640867710113525, 42.28702844892229, 34.75487545558384, 39.64159911019461, 49.37313835961478, 49.71059846878052, 46.34123631886074, 48.59560367039272, 49.514853818076, 47.76085751397269, 43.20470135552542, 38.59128161839077, 35.245925494602744, 34.66935007912772, 34.40404353822981, 32.34169660295759, 34.192234652382986, 32.734130859375, 34.69977971485683, 37.09955549240112, 36.224683489118306, 36.6826878956386, 37.481949601854595, 38.75702742167881, 40.41373157501221, 43.76014035088675, 44.80049065181187, 44.598534311567036, 46.70010730198452, 45.20314570835659, 48.544044562748496, 50.565303325653076, 53.992530073438374, 47.579679761614116, 36.90038537979126, 20.17165752819606, 7.713786721229553, 3.310704154627664, 7.254292794636317, 8.094877174922399, 6.371342641966684, 10.333601525851659, 0.933437392115593, 0.0873749814927578, 0.12129270790943078, 0.05988670685993774, 5.115197794778006, 26.748909166881017, 45.90380900246756, 32.60149669647217, 26.379002707345144, 35.512041500636506, 37.38693993432181, 49.859324659620015, 35.88439546312605, 9.759661214692251, 0.029485508533460752, 0.04647004072155271, 0.07461033322449241, 0.02743309616510357, 0.05538195697590709, 0.017049812345898578, 0.034676091080265384, 0.047103188532803736, 0.09147308194743735, 0.039125954266637564, 0.08143801721079008, 0.02461014112590679, 0.026746103207447698, 0.023452434855114137, 0.052437057319496355, 0.06660186938409295, 0.047102201264351606, 0.030785988750202314, 0.008358458140199738, 0.021693076672298566, 0.07263190831456866, 0.015382054694262999, 0.049925042648932764, 0.016525818766759973, 0.0356047408921378, 0.05459878507203289, 0.021108177789886082, 0.02742894013811435, 0.040540567466190884, 0.01904387239898954, 0.0066521177151506496, 0.024837192513846924, 0.015803394406767826, 0.11045999811696154, 0.04716695725385632, 0.04283536611390965, 0.009353282079765839, 0.05513894644432834, 0.009055322086039399, 0.06620924866625241, 0.025353420259697095, 0.13165648893586226, 0.1818883820836033, 16.262759072440012, 55.46079560688564, 55.9915337562561, 38.73066248212542, 33.04082087108067, 22.737491777965, 32.50935663495745, 50.614830085209434, 49.44095277786255, 28.782506193433488, 2.1846712742533003, 0.024970405901383077, 0.03584825014695525, 0.2459610461124352, 1.8408131769725253, 5.997284633772714, 8.290309156690325, 6.050186915057046, 6.536599900041308, 19.56497209412711, 37.123471191951204, 56.212903363364084, 58.657123293195454, 53.68127509525844, 51.88083355767386, 48.68897008895874, 44.06590972627912, 49.58273424421038, 53.48929289409092, 55.23632710320609, 50.14995043618338, 49.81211512429373, 48.621186937604634, 49.24115037918091, 53.52914081301008, 50.55742754255022, 49.20858417238508, 47.402559757232666, 43.02945736476353, 40.28379331316267, 39.4379300389971, 42.87203202928816, 47.330698013305664, 52.32901668548584, 49.65254626955305, 50.78471006665911, 50.90314558574131, 52.52364615031651, 51.54732002530779, 51.12078748430525, 49.90228189740862, 50.05396454674857, 51.72637857709612, 48.5207576751709, 38.500131675175254, 39.29143074580601, 37.66023342950003, 47.30087981905256, 50.649063859667095, 52.46124785287039, 50.36104713167463, 51.26969085420881, 50.48817137309483, 52.87526321411133, 49.763026101248606, 53.50067751748221, 34.59462915148054, 18.90726430075509, 52.267872537885395, 44.59635952540806, 49.71632725851876, 49.49241461072649, 50.783480235508506, 50.07900585447039, 51.465275696345735, 50.35309491838728, 50.87826408658709, 50.33469261441912, 44.25501537322998, 37.9395614351545, 41.16445663997105, 50.54045309339251, 50.07923167092459, 45.82952233723232, 50.64705583027431, 50.66035120827811, 48.27258539199829, 45.50048344475882, 40.34984288896833, 37.13352523531233, 36.14011001586914, 34.97343451636178, 34.43101644515991, 35.74275990894863, 34.45379958833967, 36.51808507101876, 37.96037128993443, 37.22651297705514, 38.52448858533587, 38.9295095035008, 40.98860468183245, 42.60239328656878, 46.13768536703927, 46.011877809252056, 46.27285214832851, 49.02192081723894, 48.2040969984872, 49.92670828955514, 53.61234201703753, 54.55610540934971, 50.37868513379778, 37.26075717381069, 22.570309434618267, 9.832146559442792, 4.960957774094172, 10.198818632534572, 12.962153690201895, 9.793550184794835, 5.9205187644277295, 2.921664310353143, 0.28560385746615274, 0.29829248945627895, 0.055274616128632, 6.582775890827179, 32.830544063023154, 51.10623795645577, 31.803655896868023, 34.199137687683105, 42.21006325313023, 41.48274319512503, 56.88031952721732, 42.757713317871094, 12.66366081578391, 0.024289397622591684, 0.08075815226350512, 0.02833600914371865, 0.05155393720737525, 0.03672877146995493, 0.04691797900678856, 0.022348544892988036, 0.06342716688024146, 0.05810973899705069, 0.030820512611951147, 0.04273084457963705, 0.01821492482641978, 0.02435576343642814, 0.0298945905108537, 0.019469561520963907, 0.02969311989311661, 0.04281433831368174, 0.014017570813718652, 0.04180507854159389, 0.02432505803049675, 0.04836728909452047, 0.05834085480975253, 0.14760174974799156, 0.14363997376390866, 0.07501308447016136, 0.1784692034125328, 0.10873972864023276, 0.2613160221704415, 0.13097537548414298, 0.07986034186823027, 0.07382763629513127, 0.14822397993079253, 0.10907410391207252, 0.13389526094709123, 0.15462593069033964, 0.08642545315836157, 0.13039389811456203, 0.12469416324581419, 0.1602462362498045, 0.10677192280335085, 0.12811693815248354, 0.16901657277984278, 0.3857495736862932, 21.94697264262608, 65.88036632537842, 62.971746172223774, 45.72812032699585, 35.38811690466744, 29.458524227142334, 45.816226959228516, 55.88080031531197, 54.06184182848249, 32.155516147613525, 2.9611693790980746, 0.16727258850421223, 0.08181204606911965, 0.6537863495094436, 2.1065778647150313, 14.22289650780814, 16.039219890322002, 9.678385530199323, 10.028120500700814, 24.0621953691755, 39.14853409358433, 61.20912020547049, 59.22893919263567, 55.692816802433555, 53.03747238431658, 50.416170665196006, 47.440392698560444, 52.17004190172468, 57.09942749568394, 57.10400288445609, 51.29342590059553, 49.4076361656189, 48.16080624716622, 48.58510146822248, 55.95580611910139, 52.33409581865583, 52.37540633337838, 49.182799407414024, 45.772140639168875, 42.04244491032192, 42.07432671955654, 44.67194202968052, 49.003435134887695, 54.48771776471819, 52.103801250457764, 53.049756799425396, 51.844515323638916, 53.14430788585118, 53.174636772700715, 53.71718685967581, 51.36251878738403, 51.893659932272776, 54.19625473022461, 51.08985410417829, 40.007241112845286, 40.41423879350935, 41.912562234061106, 48.66775376456124, 52.858358246939524, 54.28869703837803, 51.14364010947091, 51.73634924207415, 53.40347916739327, 53.26896204267229, 52.04681212561471, 55.62900454657418, 35.780419145311626, 22.060422829219274, 51.03760712487357, 45.497391496385845, 51.24352046421596, 51.41501590183803, 53.623410497392925, 52.66533381598336, 52.530510970524375, 53.74067177091326, 54.25546727861677, 52.97586965560913, 46.91671391895839, 39.21982608522688, 43.011788095746724, 52.904740946633474, 52.42560706819807, 47.87755945750645, 50.75678525652204, 52.08817475182669, 50.78334127153669, 47.84417683737618, 43.1488413129534, 39.29331023352486, 37.800785064697266, 37.71752827508109, 36.81343214852469, 38.316271918160574, 35.369426250457764, 38.71528959274292, 41.297118595668245, 39.67873723166329, 40.72104345049177, 40.84090682438442, 42.38130508150373, 45.36900615692139, 47.4088374546596, 48.86603103365217, 47.859230109623496, 51.84135389328003, 49.73763738359724, 53.689293316432405, 55.548092773982454, 57.2002979687282, 50.50636175700596, 40.03183078765869, 23.900797401155742, 10.153572831835065, 7.727627532822745, 17.325484309877666, 18.31068328448704, 15.714263064520699, 16.87597233908517, 2.8655762800148556, 0.4581293655293328, 0.5683418001447404, 0.13277453822749002, 7.184529406683786, 36.385673250470845, 57.30550411769322, 40.49591486794608, 35.83871105739048, 44.391526630946565, 49.335618087223594, 63.12487057277134, 51.04676832471575, 16.762470041002544, 0.22973694811974252, 0.14777208917907306, 0.16055175342730113, 0.10122046819222824, 0.11493853958589689, 0.1254711944077696, 0.09793973780636277, 0.15330556939755166, 0.242248319621597, 0.16649980497147354, 0.14791188096361502, 0.0947561872058681, 0.16052577910678728, 0.1205091763819967, 0.161515313865883, 0.22293789152588162, 0.15283222336854252, 0.1399079497371401, 0.10548630250351769, 0.18150296062231064, 0.24553576750414713, 0.10370538556682211], [0.05204261812780585, 0.01479925078872059, 0.039799759896206, 0.01424538470538599, 0.0221935335679778, 0.06774756219238043, 0.036123090756258795, 0.023269764746406248, 0.0236010798253119, 0.06784189213067293, 0.0573124128526875, 0.056750897983355184, 0.04965691614363875, 0.02245571101749582, 0.012017760176344641, 0.02941862872934767, 0.056294769780444245, 0.03706026975331562, 0.07257717089461428, 0.07592753932944366, 0.6427427306771278, 18.706523895263672, 53.49665451049805, 42.8494017464774, 44.279535566057476, 23.9492141859872, 37.10637862341744, 49.436697006225586, 49.304809774671284, 40.72743926729475, 10.409900563103811, 0.530130399124963, 0.0755695646096553, 0.09577173699757882, 0.14035156236163207, 1.4314034943069731, 5.88420878137861, 3.447604945727757, 8.660313759531293, 14.383967910494123, 27.84803601673671, 48.52166788918631, 53.342668533325195, 53.99564981460571, 48.43747309276036, 45.898556164332796, 45.563500131879536, 43.742384229387554, 46.39803784234183, 52.12199510846819, 51.93565484455654, 50.56857245309012, 47.77569191796439, 52.165063517434255, 49.477969305855886, 48.35448380878994, 49.4849522454398, 47.85522447313581, 47.035118171146934, 46.51983281544277, 42.79058524540493, 40.61217212677002, 42.95567444392613, 47.33654144832066, 49.59583854675293, 49.5645786012922, 47.249518735068186, 47.1692670413426, 47.604443141392295, 47.343124866485596, 51.11439514160156, 49.69332524708339, 48.76915577479771, 48.19916377748762, 41.02989782605852, 36.4033077784947, 37.03291531971523, 37.23014341081892, 46.462510177067344, 48.074262959616526, 44.47649267741612, 46.339773723057334, 50.37109422683716, 46.209390776497976, 52.370817048209055, 44.24557971954346, 52.158024992261616, 30.570875235966273, 20.5219509601593, 50.90515014103481, 44.99901805605207, 51.87736293247768, 45.03282799039568, 48.97733770098005, 41.78584098815918, 45.44517925807408, 42.56726319449288, 46.048442704336985, 40.76392078399658, 38.92133494785854, 35.31096758161272, 38.30658612932478, 45.87797907420567, 50.44174003601074, 45.604049818856375, 47.72902086802891, 48.276250566755024, 49.19364901951381, 44.37677213123867, 40.8716630254473, 35.82731253760201, 34.97048500605992, 35.93973091670445, 38.62610598972866, 40.95332867758614, 39.73953396933419, 37.81143317903791, 37.125746726989746, 36.22830350058419, 38.363314696720664, 38.72640323638916, 40.171163014003206, 40.46632249014718, 40.56594228744507, 39.47624935422625, 41.99460308892386, 43.99846008845738, 47.443797315870015, 48.495921339307515, 50.72159957885742, 49.89025109154837, 51.32604421888079, 40.19582564490182, 27.081217186791555, 17.0895790713174, 5.4336676086698255, 12.731305871691022, 6.770070663520268, 7.974657705851963, 6.4683659843036105, 0.9327457206589835, 0.3397744835487434, 0.015533473176349486, 0.06020341307989188, 0.6657297600592885, 20.64946951184954, 40.92852013451712, 32.342884744916645, 15.34323968206133, 23.637493678501674, 42.75913769858224, 46.314881801605225, 43.74366617202759, 19.24049816812788, 0.89844447267907, 0.06743458112967865, 0.064221012139959, 0.02684124229874994, 0.032749608026019165, 0.04616621309625251, 0.018834586754175167, 0.051698088579412015, 0.006045398418791592, 0.05628284792016659, 0.01763370699648346, 0.09141870415104286, 0.03827506796057735, 0.009685899097738522, 0.037343985600663085, 0.04718344904748457, 0.008827025586340045, 0.02178354574633496, 0.012788467391926264, 0.031577068979718854, 0.004861635131029678, 0.04601448927340763, 0.05923108596886907, 0.028075151444811906, 0.10828126288418259, 0.027111643592693975, 0.016920977205570256, 0.020216331717425158, 0.04449560559753861, 0.0267292348268841, 0.026664539905531064, 0.007406221602910331, 0.025423009114872133, 0.04642157296517065, 0.015974066320008466, 0.024619345453434756, 0.04612658325848835, 0.024562887947208116, 0.0008730903573450632, 0.04113193109099354, 0.033687173788036616, 0.04967648170090147, 0.7509099521807262, 23.78838770730155, 59.053656986781526, 49.61436244419643, 50.074895995003835, 32.344958782196045, 34.610196590423584, 45.20419488634382, 54.04222706386021, 47.69730234146118, 12.418146218572344, 0.8178237101861409, 0.03793569527832525, 0.14194621465035848, 0.5735101742403848, 5.466987260750361, 6.144526081425803, 7.447385839053562, 6.405052695955549, 12.585460577692304, 30.2327515738351, 46.664087840488975, 55.351559502737864, 54.20420346941267, 51.82407372338431, 47.24224049704415, 48.65603910173689, 46.051499911717, 49.70511981419155, 52.025939737047466, 53.38874551228115, 50.317051138196675, 49.2230989592416, 51.10951055799212, 50.30691719055176, 49.447834968566895, 50.61077928543091, 48.77435997554234, 50.15368161882673, 49.07009267807007, 44.71736240386963, 41.4673181942531, 45.43487855366298, 48.043270519801546, 52.114376408713206, 50.87669031960623, 47.86709199632917, 47.02006489889962, 49.061073916299, 49.053976331438335, 52.32834618432181, 50.83849259785244, 51.194695472717285, 50.38109963280814, 44.016191891261506, 36.69305113383702, 37.67141308103289, 38.54028878893171, 48.69292361395699, 49.92086485454014, 48.13949612208775, 47.607795647212434, 52.491844245365684, 48.615517207554404, 52.63336168016706, 45.33743354252407, 51.90521131243025, 31.456412724086217, 21.387929269245692, 51.32887213570731, 43.75011410032, 53.97394016810826, 46.09175082615444, 50.969466141292024, 44.86068637030465, 46.619018350328716, 45.83822495596749, 47.76685380935669, 42.723472595214844, 40.40817996433803, 36.77108287811279, 39.43560586656843, 49.01064041682652, 51.38343286514282, 46.66635642732893, 48.316956588200156, 49.79702363695417, 51.079084396362305, 46.64418472562517, 41.92719166619437, 38.57435580662319, 36.710525853293284, 37.78809070587158, 40.36868987764631, 42.61432334354946, 42.691611630576, 39.4206394468035, 36.78842905589512, 37.817401681627544, 39.33877229690552, 40.54549026489258, 42.03859908240182, 42.13494280406407, 42.53349494934082, 42.392668860299246, 43.851179122924805, 45.2404088973999, 49.333898408072336, 51.703564167022705, 52.61072097505842, 52.541402271815706, 50.15823268890381, 42.99267707552229, 27.301011289869034, 15.375924008233206, 7.70859728540693, 7.06637007849557, 5.7874186379568915, 12.738770842552185, 11.484646184103829, 3.2032671996525357, 0.6012975946068764, 0.09944058262876102, 0.12044452556541987, 1.17201367020607, 20.491979905537196, 45.99653966086251, 36.10794333049229, 18.372598682131084, 29.94759750366211, 47.43172482081822, 50.51412289483206, 49.26453454153878, 25.17579879079546, 1.4007553160190582, 0.012067406039152826, 0.017569098588345305, 0.058577358190502436, 0.02735023686130132, 0.011824373455185975, 0.005227589846721717, 0.04642005983207907, 0.07055118067988328, 0.03484965694536056, 0.026800182448433976, 0.09896020697695868, 0.04904876556247473, 0.025900987841721092, 0.015694459002198916, 0.030119321309030056, 0.039632385663155995, 0.05164988884436233, 0.032012640964239836, 0.024356489468898092, 0.01776253365512405, 0.011803839289184128, 0.1928124837577343, 0.13344353304377624, 0.19086913232292446, 0.12110772569264684, 0.17403801690254891, 0.19545935387057917, 0.1168736671762807, 0.09402790199965239, 0.10761418153664895, 0.14678027454231465, 0.13163344588662895, 0.11756061602916036, 0.1012879145730819, 0.17366730608046055, 0.10953470705343143, 0.07634049574179308, 0.1381147445312568, 0.18301796647054808, 0.10331569612026215, 0.14827330942664826, 1.4275564721652438, 30.134507519858225, 67.2739039829799, 55.80849041257586, 56.43657977240426, 34.826455797467915, 47.41055713381086, 58.38860321044922, 57.38238593510219, 48.01235451017107, 15.499845130102974, 0.9264184087514877, 0.22167798770325525, 0.2126854309546096, 0.9217370599508286, 5.691204760755811, 12.224594593048096, 11.868575845445905, 14.505165338516235, 17.748971802847727, 30.21135459627424, 50.52651500701904, 56.9744849886213, 57.37540299551827, 51.65815074103219, 50.21076454435076, 49.66437905175345, 48.57659339904785, 51.62522670200893, 54.682472297123496, 56.2161203793117, 53.42818348748343, 47.74144772120884, 51.489156654902864, 51.24889142172677, 51.27407169342041, 51.569397926330566, 51.57314995356968, 51.12760714122227, 52.01597949436733, 47.88146087101528, 44.815707206726074, 46.844699314662385, 51.13653905051095, 53.065021991729736, 53.26212501525879, 48.27159874779837, 48.56042841502598, 49.18107278006417, 48.94719294139317, 53.92924588067191, 52.64164740698678, 52.73815093721662, 52.91809885842459, 44.793608461107524, 39.46230779375349, 39.21654306139265, 40.42502587182181, 50.972863810403005, 52.04010016577584, 50.28402287619454, 48.86488110678536, 51.50693709509713, 48.85107503618513, 53.01815986633301, 45.317905630384175, 51.93032210213797, 33.50608614512852, 24.360705614089966, 49.33692782265799, 45.679246698107036, 54.678664684295654, 48.213369369506836, 53.58060959407261, 45.203750201633994, 49.117587089538574, 46.96542773927961, 49.81923355375017, 44.38175746372768, 42.67965030670166, 38.07480812072754, 41.75613396508353, 50.6794934953962, 55.40252801350185, 47.25814144951956, 48.609145709446494, 50.45395496913365, 52.589612347739084, 48.29781430108206, 43.91236843381609, 39.93779386792864, 38.55992439814976, 39.94256033216204, 43.56639330727713, 45.41352326529366, 45.466485909053254, 41.81075028010777, 40.17127765927996, 41.21400771822248, 42.582222666059224, 42.337368147713796, 44.02539478029524, 45.31785351889474, 45.255872113364084, 44.42789350237165, 47.10177918842861, 47.954271044049946, 51.95722900118147, 53.53631830215454, 55.3751277923584, 52.62579161780221, 51.55403198514666, 46.73847525460379, 29.153602531978063, 21.912205593926565, 11.412445715495519, 23.605497223990305, 13.753024578094482, 18.289691039494105, 15.618753126689366, 4.505036958626338, 0.570225359073707, 0.22491573968103953, 0.25543222789253506, 1.3041514711720603, 26.38263487815857, 54.1758166040693, 39.66655356543404, 23.744681801114762, 35.236416884831016, 54.68751321520124, 55.94904204777309, 56.9678008215768, 33.30818060466221, 2.125718197652272, 0.1618482574288334, 0.10838984205786671, 0.1655397050614868, 0.08061701019427606, 0.09682654004011836, 0.13625600641327246, 0.14230817237070628, 0.17780635612351553, 0.11526956968009472, 0.0865915110334754, 0.2267544474452734, 0.17313648813537189, 0.10845792626163789, 0.0925868157563465, 0.08958794203187738, 0.2100929386381592, 0.10140084315623556, 0.08253293524363212, 0.1252241940902812, 0.1656320672482252, 0.1081233135025416], [0.04286950999604804, 0.027643932262435555, 0.02792791273844029, 0.03462278536920037, 0.052986741930778535, 0.04681929626635142, 0.03699796666790332, 0.07223394074078117, 0.07611759698816709, 0.0038012808238688323, 0.03673751100099512, 0.01568061688781849, 0.01585518698474126, 0.00992640498692968, 0.04745484269889338, 0.06815454071121556, 0.0805877721203225, 0.025092640592317497, 0.0709359236061573, 0.03592636988365224, 0.7552445424454552, 30.952362605503627, 50.92444181442261, 47.66837699072701, 32.92179822921753, 23.007611683436803, 42.96554783412388, 51.409168992723735, 43.03638819285801, 24.8789005279541, 7.017199848379407, 0.15148321432726725, 0.04150191927328706, 0.10184147701199565, 0.3626795730420521, 3.7752333538872853, 4.893558076449803, 7.514823317527771, 7.323557649339948, 15.59871278490339, 36.39887482779366, 51.26931912558419, 52.15905679975237, 49.16303873062134, 47.569097655160085, 47.322165625435964, 45.791262081691194, 46.04803276062012, 48.55729130336216, 48.58653974533081, 50.835087980542866, 48.700653484889436, 49.442800998687744, 46.444066183907644, 49.83375876290457, 43.417660168239046, 49.49069840567452, 50.071783202035085, 49.85213327407837, 48.63768196105957, 48.53639807019915, 42.63811050142561, 44.039127894810264, 45.57968943459647, 49.469694001334055, 47.88547345570156, 46.72341850825718, 47.379001889910015, 50.36500065667288, 50.196089948926655, 50.48390865325928, 50.12370014190674, 50.10784782682146, 42.08771937234061, 38.92275585447039, 33.820415701184956, 37.89716352735247, 36.97416482652937, 45.35640559877668, 46.85110207966396, 51.22282525471279, 48.90492010116577, 49.59548071452549, 45.34741810389927, 52.919036865234375, 47.49502638408116, 52.35760504858834, 29.57574381147112, 23.992265224456787, 51.756300994328086, 44.61317069189889, 51.59096166065761, 46.21108613695417, 46.09641306740897, 38.34053155354091, 38.895018645695274, 34.68171092442104, 37.926540510995046, 36.92731312343052, 38.95828199386597, 36.32773917061942, 37.427027566092356, 40.83849927357265, 51.51197453907558, 46.89763763972691, 48.33451468603951, 48.42367744445801, 50.20527894156319, 46.59808690207345, 41.5359524999346, 36.445219312395366, 38.77766357149397, 42.12696974618094, 47.066805430821006, 49.20706599099295, 48.10904564176287, 44.90185444695609, 41.681048257010325, 40.64855636869158, 44.366558279309956, 46.479988370622905, 46.95969894954136, 47.41097749982561, 49.25250373567854, 47.39901965005057, 50.48954364231655, 47.80044487544468, 50.05805008752005, 49.80601808003017, 51.917318548474995, 50.5734327180045, 47.02233695983887, 47.08755275181362, 31.32297257014683, 18.682224307741436, 7.607040677751813, 4.254954355103629, 10.205945747239248, 9.02134997504098, 5.536445362227304, 2.8457806450980048, 0.5265808467354093, 0.1140056625008583, 0.03347782877140811, 0.24901814492685453, 8.892756189618792, 33.29698010853359, 34.01625762666975, 31.82829073497227, 22.867680174963816, 29.09298297337123, 42.30555234636579, 47.208364554813926, 33.70121588025774, 2.957399764231273, 0.14015762348260197, 0.06477160259549107, 0.02590706921182573, 0.029766941110470464, 0.0861224058483328, 0.011472257885283657, 0.04346662081245865, 0.03579148390729513, 0.04335797717794776, 0.030084407289645503, 0.0244065636569368, 0.06486022605427674, 0.07696318054305655, 0.03285890644682305, 0.08955863610442195, 0.009568272507749498, 0.005694253153965941, 0.015118932384731514, 0.04948400167216148, 0.04545397524322782, 0.014448797629613961, 0.027718138548412492, 0.01568933606280812, 0.002121682312073452, 0.011098214608084942, 0.029434092542422668, 0.06076140635247741, 0.04803527173187051, 0.0683087988623551, 0.10009823912488562, 0.0053900082296292695, 0.04134921836001532, 0.012785425010536398, 0.013481798714825084, 0.042729260200368505, 0.013075184060393699, 0.048229536307709556, 0.07040118372866086, 0.03360690309533051, 0.05618907777326448, 0.03004441104297127, 2.005321115255356, 38.218566349574495, 59.07366779872349, 52.70155477523804, 41.18984883172171, 26.679785013198853, 43.31147084917341, 54.215817383357454, 49.30724859237671, 32.08853898729597, 6.8677818775177, 0.2391930664224284, 0.07450277185333626, 0.15120859763451985, 1.1502900187458311, 4.801090581076486, 8.88517917905535, 4.050784145082746, 7.124000174658639, 17.006086042949132, 35.63121700286865, 52.31948028291975, 54.283246176583425, 51.59206642423357, 50.09347200393677, 49.086726665496826, 47.6032133102417, 46.04098033905029, 50.045334884098594, 51.06700495311192, 53.87740537098476, 50.46019097736904, 49.77076986857823, 47.70319441386631, 50.238227299281526, 45.99453163146973, 49.88964659827096, 50.948475633348735, 50.634889534541536, 51.153277260916575, 50.519066538129536, 44.19568123136248, 45.27385752541678, 46.98147112982613, 50.9946220942906, 49.018408502851216, 46.06380864552089, 47.86163418633597, 52.48744950975691, 49.760580335344585, 52.67649957111904, 50.70521225248064, 51.067807470049175, 44.473498003823416, 40.40381302152361, 35.67309726987566, 38.86303608758109, 39.37058809825352, 47.52948250089373, 48.50825439180647, 52.64150844301496, 49.52663448878697, 50.806642055511475, 46.299925804138184, 52.599833147866384, 47.822501931871685, 52.68335049492972, 30.894942692347936, 25.380444083895, 51.423645564488, 46.03985125677926, 53.51130131312779, 47.27427169254848, 47.53488819939749, 40.344767229897634, 40.15536628450666, 37.45547349112374, 39.38718734468733, 39.46327359335763, 41.139783586774556, 37.46197353090559, 38.995437485831125, 42.40851422718593, 53.17217711039952, 48.778723444257466, 47.12250566482544, 49.20870923995972, 51.661065510341096, 48.03334501811436, 43.92192915507725, 38.65890496117728, 39.60196658543178, 44.098854609898154, 49.1752849306379, 50.69615527561733, 49.75413588115147, 47.149256229400635, 42.882843426295686, 42.159000941685264, 45.44192402703421, 47.74799987248012, 49.90771886280605, 49.85217843736921, 49.60760184696743, 48.51586961746216, 50.95531266076224, 49.779997076307026, 52.499786036355154, 51.498359543936594, 53.95450258255005, 50.148762294224326, 49.112622601645334, 48.77940089362008, 32.51152099881853, 19.218797206878662, 10.551189575876508, 8.77145540714264, 12.547926408903939, 10.288519007819039, 8.321622950690132, 7.047351121902466, 1.5007021129131317, 0.3154916694121701, 0.05515790810542447, 0.11009437630751304, 11.177148444311959, 38.26359415054321, 40.7326990536281, 32.04427548817226, 26.867702518190654, 34.13713543755667, 47.520859786442344, 53.48985569817679, 39.63626984187535, 5.454243396009717, 0.07641260365822486, 0.1281450159315552, 0.031721759787095447, 0.071825469444905, 0.06906401512346097, 0.047838099633476565, 0.04053831133725388, 0.012069283884816935, 0.045872773842087815, 0.04624288755335978, 0.0157260956974434, 0.013826463970222642, 0.03896056135584201, 0.06354232105825629, 0.10789613997829811, 0.008024891173200948, 0.003371501832069563, 0.005644799401384911, 0.05011756678244897, 0.024814973884661282, 0.024881848599761724, 0.09335155186376401, 0.11899786176426069, 0.09830818910683904, 0.09717164973595313, 0.11888253795249121, 0.1234816483088902, 0.12737704999744892, 0.14821961016527244, 0.16378265220139707, 0.10330473777971097, 0.19828484154173306, 0.07676379302782671, 0.09235586957739932, 0.09281791799834796, 0.11531644287918295, 0.15637178772262164, 0.18165550886520318, 0.08630252296903304, 0.15611874844346726, 0.11629871731357914, 3.7804384231567383, 47.46230731691633, 66.16487421308244, 60.865198271615164, 44.68094342095511, 31.732898916516984, 51.976725646427695, 57.32648767743792, 48.523620332990376, 33.44854811259678, 9.59767438684191, 0.3374417615788323, 0.20194940561694757, 0.35991239867040087, 2.5426487624645233, 7.325726355825152, 13.795737760407583, 11.970467703683035, 11.077559913907733, 17.571521759033203, 39.51155662536621, 55.21941518783569, 55.47993094580514, 53.036499636513845, 51.805869443076, 52.63735689435686, 49.746652671269004, 49.21508421216692, 52.23397922515869, 52.38225725718907, 56.67938109806606, 50.71081597464425, 48.81769936425345, 46.96265888214111, 50.53640924181257, 46.14784363337925, 50.80676712308611, 54.14290993554251, 54.0843574660165, 53.69815921783447, 52.882934025355745, 46.65856402260916, 48.79690687997, 48.41895614351545, 52.47826051712036, 49.59994840621948, 47.19469744818551, 49.833307129996165, 55.17921985898699, 54.46573713847569, 54.68581090654646, 54.227636269160676, 54.06743165424892, 45.02488967350551, 43.4521301814488, 37.3319935798645, 41.551186425345286, 41.58701481137957, 49.98877307346889, 52.136020047324045, 55.05352347237723, 51.653485025678364, 53.6537880216326, 49.24299512590681, 55.121334416525706, 49.74952575138637, 53.500913756234304, 31.689166954585485, 28.042424031666346, 51.83651794706072, 47.6116657938276, 56.24041128158569, 50.54319763183594, 48.22337130137852, 42.82120943069458, 41.664584500449045, 38.698478426252095, 41.86746147700718, 40.814868450164795, 42.918970584869385, 39.524973596845356, 40.940828868321006, 44.45570714133126, 54.936897959027974, 50.47988912037441, 48.456688335963655, 50.53829567773001, 54.49376964569092, 50.72441012518746, 46.220153536115376, 40.64154216221401, 42.95495530537197, 47.268897260938374, 50.75482586451939, 53.054231439317974, 51.98244053976876, 49.86525494711739, 46.898370674678254, 45.2943686076573, 48.2812636920384, 51.36334214891706, 52.125437940870015, 50.45820031847273, 53.359622137887136, 50.758473668779644, 54.41979912349156, 52.38977173396519, 56.39502607073103, 53.77720192500523, 55.25831815174648, 50.26654815673828, 52.50832189832415, 50.5531405040196, 36.53044244221279, 21.083697182791575, 12.598912290164403, 12.56103071144649, 19.30603184018816, 16.080601624080114, 12.277871642793928, 10.344273958887372, 1.298830236707415, 0.5170936786702701, 0.1372479431863342, 0.4267839246562549, 12.909435101917811, 44.41405963897705, 44.34260436466762, 40.095684732709614, 32.87288638523647, 40.415023939950125, 54.169049058641704, 60.086735997881206, 47.706831795828684, 8.65970492362976, 0.1220311304288251, 0.29071116341011866, 0.15906873371984276, 0.1368094738572836, 0.14358851366809436, 0.14259749970265798, 0.16337973810732365, 0.11340505722910166, 0.08868846922580685, 0.1464529763907194, 0.10770353781325476, 0.1434354361678873, 0.10840920744729893, 0.14576382908437932, 0.2440114521554538, 0.0846023109874555, 0.0743017422833613, 0.10817155734236751, 0.10071535993899618, 0.17808123065957002, 0.1585057396441698], [0.020527748756908944, 0.04514287032985261, 0.0401976697945169, 0.06243434801165547, 0.052118485128240924, 0.034462230413087776, 0.05026270881561296, 0.010818896515827094, 0.021803128266973153, 0.03040201256849936, 0.027199016850707785, 0.06520968515958105, 0.051033053014959605, 0.02631155581080488, 0.10040649079850741, 0.08110815419682435, 0.012979718424113733, 0.036774932207273583, 0.06498420797288418, 0.03496948962232896, 8.140215907778058, 40.10712146759033, 44.14624827248709, 40.27403804234096, 26.02207895687648, 24.64872407913208, 38.90757751464844, 46.61564152581351, 42.684448037828716, 25.514351504189626, 1.891022379909243, 0.045979422583643875, 0.0585203476782356, 0.03688642229618771, 0.44288032235843794, 7.480765853609357, 5.125186698777335, 6.329525777271815, 9.183441025870186, 20.75086804798671, 43.78426797049386, 50.053509439740864, 54.64699479511806, 48.37038476126534, 50.01995311464582, 46.956547941480366, 51.969478675297324, 47.94217423030308, 49.72067335673741, 49.068709986550466, 53.232383251190186, 49.23066554750715, 50.56121778488159, 50.212115968976704, 47.94473116738455, 45.79887383324759, 44.24387393678938, 44.28786645616804, 47.65722860608782, 48.53687402180263, 47.124850681849885, 45.20096049989973, 45.70263433456421, 45.367564405713765, 49.60464538846697, 47.05423961366926, 46.595085280282156, 47.32992328916277, 48.94715472630092, 44.139557157244, 47.94521059308733, 46.79087509427752, 44.3489202771868, 35.63972854614258, 36.857316970825195, 35.2967654636928, 38.8930036681039, 34.37500006811959, 40.36241912841797, 43.28624194008963, 47.79948949813843, 45.01502323150635, 49.87535762786865, 45.3455559866769, 51.27182395117623, 45.41871356964111, 55.17205974033901, 26.47332624026707, 23.34085771015712, 50.27776254926409, 44.527513299669536, 51.94637244088309, 44.208386012486045, 44.25164549691336, 40.361290046146934, 41.16212204524449, 37.503464698791504, 39.06521477018084, 35.3461080959865, 38.28237860543387, 34.80172368458339, 36.91874252046858, 37.99120044708252, 47.46992949077061, 47.72922236578805, 46.49726506641933, 46.31951625006539, 49.76975195748465, 45.01224742616926, 42.869155475071494, 39.41992725644793, 43.76092202322823, 46.719638688223704, 49.42514215196882, 47.75768218721662, 50.2786797114781, 49.0834436416626, 47.13441835130964, 46.39749240875244, 47.289703641619, 48.47228356770107, 51.090541975838796, 49.14891651698521, 49.501037325177876, 49.625257219587056, 49.06914077486311, 48.152680328914094, 48.60171808515276, 49.42639977591378, 49.21264886856079, 47.16490704672677, 45.330210890088765, 48.333069460732595, 41.75825663975307, 24.929439987455094, 19.131604262760707, 5.887970796653202, 5.231748614992414, 9.690292137009756, 13.634079234940664, 3.648158618382045, 1.5476776893649782, 0.22176782573972428, 0.03065730458391564, 0.012650908835764443, 2.4451403490134647, 25.72855404445103, 37.12199122565133, 19.001930032457622, 14.03955612863813, 21.72585490771702, 36.60151209150042, 45.30617012296404, 41.78979798725673, 13.076482823916844, 0.3481159588055951, 0.07719758725059883, 0.024840712414256165, 0.04256992321461439, 0.04018677252211741, 0.045383902931852, 0.037587834122989855, 0.008707103851650442, 0.05728869805378573, 0.05884694015341146, 0.07998883604471173, 0.036055942930813344, 0.052835716999002864, 0.10511871972786528, 0.04918890679255128, 0.053193759572293074, 0.026554177881085446, 0.053222648200712035, 0.009804375552838402, 0.050331576727330685, 0.04079089939062085, 0.02052793026502643, 0.04111555125564337, 0.018336246887754117, 0.05672245718804853, 0.01620406933527972, 0.05020557616704276, 0.04011216081146683, 0.06263376945363623, 0.08522150811872312, 0.007879087568393775, 0.045034481145973713, 0.04469819240538137, 0.06608872049088989, 0.02192302710110588, 0.047274080969925435, 0.06561924211148705, 0.07618808320590428, 0.04941854339891246, 0.07998991491539137, 0.05021402392802494, 11.16192580972399, 46.29658024651663, 50.35257380349295, 46.334913458142964, 29.386019774845668, 24.201581444059098, 42.59402070726667, 52.515822478703086, 46.413966587611604, 25.205955709729874, 2.7148774521691457, 0.05338565606091704, 0.24737885860460146, 0.7681342650737081, 2.4261302947998047, 7.186796256474086, 9.357500348772321, 4.1131642035075595, 7.793062193053109, 23.705777100154332, 43.13221079962594, 53.90201589039394, 54.62711252485003, 50.97707789284842, 49.55949599402291, 50.54572677612305, 52.33535691670009, 50.41721289498465, 51.13585465294974, 51.00054890768868, 53.550881726401194, 51.33111292975289, 49.588657583509175, 50.061930656433105, 48.368734564099995, 45.78251082556588, 45.12314762387957, 46.53645985467093, 48.95642709732056, 50.62983124596732, 49.26307541983468, 46.735178334372385, 46.948699951171875, 47.84689358302525, 51.038635458265034, 47.85883058820452, 46.8760461126055, 48.80162818091256, 50.469560623168945, 46.27258811678205, 49.94458253043038, 48.11313465663365, 45.136401312691824, 38.70020852770124, 37.77391290664673, 37.121226923806326, 38.98182596479143, 35.1964612688337, 41.41371979032244, 46.35865545272827, 51.01778391429356, 47.16799552100045, 52.56281661987305, 47.90640490395682, 52.83360528945923, 48.42882258551461, 56.30889620099749, 27.69929071835109, 25.399787868772233, 51.99272387368338, 45.15745782852173, 54.23402166366577, 46.61322007860456, 46.46394845417568, 42.49247625895909, 42.45426116670881, 39.39079693385533, 38.82715906415667, 37.06007930210659, 39.877247265407014, 35.82115295955113, 38.51644604546683, 40.99956546510969, 50.37743445805141, 49.65764624731881, 46.52689218521118, 47.77181134905134, 51.24866907937186, 46.10107183456421, 45.076125689915244, 41.617583411080496, 46.068001883370535, 49.91025842939104, 49.97566877092634, 50.1426374571664, 52.004997866494314, 49.434629917144775, 48.845273290361675, 47.17934192929949, 48.430337292807444, 51.251754079546245, 52.979447977883474, 51.3471736907959, 51.37366369792393, 52.24415833609444, 51.17286075864519, 49.089641434805735, 50.98193120956421, 50.636647428785054, 47.92212520326887, 47.35428367342268, 47.3813920702253, 50.96304600579398, 40.99677923747471, 23.247635466711863, 13.3001766034535, 6.814012808459146, 7.076966515609196, 7.415529217038836, 11.071949243545532, 8.344912443842206, 3.532036632299423, 0.2926322588963168, 0.03340800751798919, 0.024579566337966492, 3.007619172334671, 27.860615730285645, 38.693941252572195, 30.46668004989624, 18.430588347571238, 24.966524260384695, 41.45194183077131, 49.71095977510725, 46.52213961737496, 17.624022347586497, 0.829615943133831, 0.01948826533875295, 0.0658056221104094, 0.03094629943370819, 0.05640221240797213, 0.03405156744910138, 0.010889137612788804, 0.03626650931047542, 0.048137289471924305, 0.025589416435520564, 0.004304116832957203, 0.08061690841402326, 0.0422193988093308, 0.047435623194490156, 0.0670041117284979, 0.04416940327999847, 0.015139344414430005, 0.026519721872838478, 0.03967834283996906, 0.039164528982447724, 0.036751644885433574, 0.09175759846610682, 0.13990598198558601, 0.13441714937133448, 0.1856230523969446, 0.20937430219990866, 0.14038067151393208, 0.16453602963260242, 0.2059407928692443, 0.164779216583286, 0.12786687085671083, 0.15735522923724993, 0.31137716876608984, 0.15818372049501964, 0.09122256681855236, 0.22446175904146262, 0.1396790255925485, 0.17468618069376263, 0.08240762339638812, 0.1945888748658555, 0.1422439965286425, 14.761067492621285, 56.54425253186907, 56.47986010142735, 53.434416021619526, 36.09092024394444, 35.95551722390311, 48.813398429325645, 52.85663856778826, 50.63336787905012, 32.882228238242014, 2.9268038059983934, 0.1733062168849366, 0.3652077673801354, 0.8562675501619066, 1.2248791477509906, 17.66010434286935, 12.616890754018511, 12.547891667910985, 11.998673047338213, 23.07202843257359, 47.28580222811018, 54.78227274758475, 58.285207067217144, 53.58785309110369, 53.41905008043562, 51.32445308140346, 56.356366293770925, 51.779744216373985, 54.69466985974993, 53.285762786865234, 54.94775104522705, 50.898670945848735, 51.56566674368722, 49.92114973068237, 47.20806925637381, 45.48164687837873, 44.70929901940482, 45.740171977451865, 50.15996626445225, 52.15925482341221, 51.09978307996477, 48.423066002982004, 50.16072709219796, 49.29610368183681, 53.03531844275338, 48.345777715955464, 49.55872474397932, 51.138262203761506, 54.23313576834542, 48.26633548736572, 52.68567814145769, 52.67158719471523, 47.39263425554548, 40.275292192186626, 39.674255643572124, 39.040816170828684, 43.106714384896414, 36.457472460610525, 45.08017996379307, 48.779116017477854, 53.431987626211985, 49.316427162715364, 54.829492705208914, 51.44471945081438, 55.61541039603097, 52.33214684895107, 56.80353845868792, 29.542281287057058, 27.715228148869105, 50.17752436229161, 47.96820913042341, 55.723010199410574, 48.731909956250874, 48.47751208714077, 44.948143345969065, 45.54219348090035, 41.17657082421439, 41.2372077533177, 40.08220870154244, 40.715637751988, 37.831902572086875, 40.13623789378575, 42.255629539489746, 50.4199435370309, 51.86230271203177, 47.79549775804792, 47.05727250235421, 52.9413058417184, 49.82764434814453, 47.75363833563668, 43.77389778409685, 48.24256917408535, 52.09395912715367, 52.55097688947405, 51.46823910304478, 55.802143233163015, 52.713540417807444, 52.37429462160383, 49.77142994744437, 51.334006854466026, 53.22610207966396, 55.214485440935405, 53.12681926999773, 53.669820989881245, 53.897638525281636, 53.10590519223894, 50.915478638240266, 52.57332229614258, 52.673925263541086, 50.77256114142281, 49.82741853169033, 48.4768693787711, 50.51049940926688, 44.49356092725481, 28.939132486070903, 24.85181818689619, 13.312983870506287, 11.814015984535217, 19.743849992752075, 22.878991842269897, 10.879611815725054, 5.471963907991137, 0.5543519279786518, 0.16267334244080953, 0.12824891321361065, 3.5163297951221466, 34.80558688299996, 49.06726128714425, 28.003064223698207, 21.46876461165292, 31.187381948743546, 48.89384119851248, 56.67943320955549, 53.07518025806972, 24.130466631480626, 1.2337033599615097, 0.16417534755808966, 0.17304382739322527, 0.1006546514108777, 0.11826693027147225, 0.13905261563403265, 0.1555767482412713, 0.11971686461142131, 0.15021272535834992, 0.19493775043104375, 0.11560239110674177, 0.15029068903199264, 0.09623047416763646, 0.21683354622551373, 0.16920866604362214, 0.15528554815266812, 0.08225623544837747, 0.16958525297897203, 0.11987165201987539, 0.17385907364743097, 0.14168796422226088], [0.01366387595356043, 0.02128330598186169, 0.07776617924017565, 0.06725515611469746, 0.018742826767265797, 0.03452371247112751, 0.04499511932954192, 0.028245411148028712, 0.019143708648958375, 0.07840408358190741, 0.04905073331402881, 0.005625661321183932, 0.05373727630025574, 0.09959468471684627, 0.03941997027556811, 0.022305556306881563, 0.06943081758384194, 0.06690577843359538, 0.04017987860632794, 0.12279957133744444, 12.518221122877938, 43.301896231515066, 44.95436198370797, 40.88054977144514, 26.816369227000646, 32.363361086164204, 32.48557642527989, 35.45646980830601, 32.04697486332485, 16.78235752241952, 0.4746989735535213, 0.10095689804958445, 0.03272302980933871, 0.8141474074551037, 2.497682192495891, 3.188208499125072, 7.503344893455505, 1.215311695422445, 7.584379128047398, 26.405463184629166, 41.03284386226109, 55.674209526606965, 54.80169643674578, 52.86015088217599, 49.44911691120693, 50.11564370564052, 49.09130900246756, 50.83898591995239, 50.22560937064034, 51.87055369785854, 49.83951881953648, 47.61760997772217, 51.952038696834016, 44.8238331249782, 47.03913075583321, 49.3056400844029, 49.37021664210728, 44.7684941973005, 44.4782714162554, 48.63131741115025, 48.7597861289978, 47.824739251817974, 47.44826848166329, 46.654151916503906, 50.24336896623884, 46.40664666039603, 48.681865555899485, 47.04837185995919, 46.47250863483974, 39.14925670623779, 37.15226105281285, 37.42167745317732, 36.12941326413836, 34.12207869121006, 36.909935678754536, 34.623252255576, 36.70711081368582, 35.78077350343977, 37.44168479101998, 35.32391207558768, 38.11336714880807, 38.785480294908794, 40.66193512507847, 40.759491307394846, 47.68288830348423, 45.96130187170846, 53.408200468335835, 29.509089742388042, 22.751438549586705, 52.103981903621126, 42.280229636601035, 50.87842042105538, 45.95965167454311, 49.87016384942191, 46.61569363730294, 49.42527069364275, 44.368469033922466, 45.44237913404192, 39.01483685629708, 37.25919382912772, 34.563007899693076, 37.48421818869454, 36.65728875568935, 44.86537293025425, 50.38468490328108, 48.4909360068185, 45.2140474319458, 49.87276594979422, 45.64484964098249, 45.53587409428188, 45.90102972303118, 48.15169021061489, 46.93640511376517, 47.56728417532784, 44.59369141714913, 49.52272612707955, 48.61357518604824, 48.93846947806222, 46.14316749572754, 49.57867302213396, 49.468714305332725, 50.31729085104806, 49.54262229374477, 50.970272132328574, 46.90557248251778, 48.79003858566284, 47.76654461451939, 46.19198553902762, 42.77506991795131, 49.20063195909773, 51.96324961526053, 54.23608180454799, 52.44695193426949, 41.62896456037249, 33.6762683732169, 17.69035506248474, 14.300809264183044, 14.828400748116628, 6.074255909238543, 5.960348010063171, 6.868247406823294, 1.6363920718431473, 0.4791445721473013, 0.04758647509983607, 0.032531754180256806, 0.620694848043578, 18.8548401423863, 45.39409262793404, 21.032277039119176, 23.133664165224346, 31.512390886034282, 35.35669367653983, 41.66841295787266, 43.56594514846802, 27.456011704036168, 4.029890477657318, 0.09868630274598088, 0.04555942637047597, 0.025840786518529058, 0.032376949808427265, 0.04450327643592443, 0.054399655400110145, 0.05192021719579186, 0.03390953649899789, 0.0680738425414477, 0.02787140434208725, 0.04390251510111349, 0.11329410318285227, 0.049904408399015665, 0.04503770757998739, 0.02030571174275662, 0.09188846751515355, 0.027517003805509636, 0.06671011607561793, 0.05947877839207649, 0.038698015801076374, 0.04203612989346896, 0.008683714749557632, 0.10226955796991076, 0.02664321694257004, 0.02141537094887878, 0.10842214711010456, 0.02491931730349149, 0.02473345468752086, 0.036660181757594855, 0.022117390064522624, 0.05012657094214644, 0.039025364842798026, 0.036362454162112305, 0.031018444669565985, 0.07659249686236892, 0.014844353011410152, 0.04147803484063063, 0.03451416548341513, 0.02020066264750702, 0.12284259045762674, 15.70207245009286, 50.28578424453735, 52.20677702767508, 47.128925800323486, 32.52538960320609, 35.356787477220806, 38.59747246333531, 43.65198121752058, 38.06353119441441, 17.74942864690508, 0.8469311797193119, 0.10657203317220722, 0.1619847651038851, 1.545582264661789, 3.982939762728555, 7.515463420322963, 9.332194140979222, 4.41209785427366, 9.989007353782654, 26.068152461733135, 43.99357897894723, 58.33651256561279, 56.734403882707866, 55.085318429129465, 52.92052377973284, 52.21272815976824, 52.061920983450754, 52.03140449523926, 52.55912365232195, 52.42355040141514, 50.0358818599156, 47.806732995169504, 51.80500091825213, 46.414921964917866, 46.27799381528582, 48.74755035127912, 48.743298053741455, 45.88404485157558, 44.98517724445888, 49.59238876615252, 51.63994298662458, 49.865077768053325, 48.814075878688264, 48.12696852002825, 51.109979561397004, 48.561255250658306, 47.65362596511841, 48.90980468477522, 48.7537898336138, 41.128506660461426, 39.33300529207502, 40.112707819257466, 37.4744907106672, 36.31148386001587, 37.623852661677766, 36.94061197553362, 37.12884214946202, 36.79168776103428, 39.102693353380474, 37.92047473362514, 40.46565893718174, 41.60082088197981, 42.619388580322266, 42.14991964612688, 50.11016852515084, 47.67749997547695, 55.32929400035313, 30.267377921513148, 24.428049291883195, 51.77391120365688, 43.922557967049734, 53.10175711768014, 47.65400464194161, 51.22123759133475, 48.652992316654746, 51.695393085479736, 46.59779507773263, 47.12815455027989, 40.20565734590803, 38.309945583343506, 36.67019156047276, 38.364878041403635, 39.2785279410226, 46.45357479367937, 52.159359046391074, 48.51640462875366, 45.17498465946743, 50.070591585976736, 47.377733843667166, 47.800034931727815, 46.57386895588466, 49.896042415073936, 49.60314457757132, 49.3218606540135, 45.64982107707432, 50.64039945602417, 50.77903686250959, 49.468964440482004, 47.930661065237864, 52.92003393173218, 51.54818507603237, 51.53597361700875, 49.417203835078645, 51.32701349258423, 47.40015568052019, 50.24467175347464, 47.76134736197335, 47.00840582166399, 44.93803024291992, 49.828307901109966, 51.118942737579346, 54.86809689658028, 50.48406498772757, 44.49932445798601, 32.32802949632917, 16.283836432865687, 10.370877742767334, 7.882984910692487, 11.77220172541482, 12.879939130374364, 8.431530424526759, 5.585697667939322, 0.7065901617918695, 0.1479267951633249, 0.08364527127040283, 0.7919589323656899, 20.674373592649186, 42.78370305470058, 22.8858288696834, 23.288067034312657, 34.685692242213655, 39.69498906816755, 48.74336058752877, 50.57961661475045, 32.71843140465872, 4.5491098165512085, 0.017499204392411878, 0.05405630310997367, 0.03866369549983314, 0.01732362836732396, 0.03785312095923083, 0.026761153114161322, 0.01889520707274122, 0.027985628927126527, 0.05362692954284804, 0.021466232237539122, 0.10703020037284919, 0.008926653186790645, 0.013840430765412748, 0.03371134659807597, 0.09661668951490096, 0.06082720389323575, 0.0956553750272308, 0.030288351167525564, 0.04461132295961891, 0.05201337666117719, 0.11229092986988169, 0.062301477284303734, 0.18877030137394155, 0.24728785348790033, 0.12018645155642714, 0.130393314574446, 0.11240130037601505, 0.09992699045687914, 0.14404231788856642, 0.12231017116989408, 0.1325055126632963, 0.1926147315118994, 0.11559251163687025, 0.17304021758692606, 0.1392869816294738, 0.1580243461898395, 0.1297507147703852, 0.1430086919239589, 0.17429991784904683, 0.3427860662341118, 21.782216957637242, 57.46304757254464, 60.013675689697266, 54.92306409563337, 39.762813908713206, 42.743083885737825, 41.977878774915425, 40.26407432556152, 41.84319141932896, 21.188093866620743, 0.9762830244643348, 0.17367211010839256, 0.28494833835533684, 1.9491299475942339, 6.961091407707759, 6.502979738371713, 17.976459298815044, 5.7705844555582315, 9.747009413582937, 29.328818729945592, 43.37840979439871, 60.28300871167864, 59.03264563424246, 56.857216766902376, 55.53101410184588, 55.07301664352417, 53.65790830339704, 54.20542982646397, 55.34695284707205, 54.86688791002546, 50.04551553726196, 48.995809486934114, 51.65633378710066, 47.085610730307444, 47.42749684197562, 49.91112000601632, 49.706186362675254, 45.180341720581055, 44.307849475315635, 50.10515192576817, 52.39375652585711, 51.51222120012556, 51.076492718287874, 49.52990709032331, 53.08722496032715, 48.461569445473806, 50.16087300436837, 50.681136744362966, 51.279803957257954, 43.56267254693167, 41.360934325626914, 40.95446818215506, 39.942369256700786, 37.313865729740684, 40.17090940475464, 39.01250573566982, 40.69568599973406, 39.46742166791643, 40.21493666512625, 40.0400470324925, 41.409464018685476, 43.350696904318674, 43.600147656032014, 44.244349888392854, 51.761522565569194, 51.46585239682879, 56.321604456220356, 32.81975698471069, 26.89623703275408, 51.205868176051546, 45.200845854622976, 54.55982616969517, 49.54402582986014, 52.659688404628206, 51.16759055001395, 53.22387865611485, 48.981207847595215, 49.495103563581196, 43.27414512634277, 41.01789828709194, 38.209735189165386, 41.608123438698904, 41.22015339987618, 47.83837161745344, 54.63878549848284, 49.25211811065674, 46.00926181248256, 52.364212785448345, 50.16699436732701, 50.07540668760027, 49.822520051683696, 52.567753314971924, 52.88009568623134, 50.31176355906895, 45.741895130702424, 52.363938331604004, 54.17976318086897, 51.630625452314106, 49.74215718678066, 55.037605149405344, 54.233816691807334, 51.85754667009626, 49.934149810246055, 52.159421580178396, 47.007071767534526, 49.030960423605784, 48.88779973983765, 46.63671888623919, 45.80013493129185, 49.762588364737375, 53.170881271362305, 54.15275205884661, 54.3738819531032, 44.643072264535085, 35.40933322906494, 20.95494532585144, 19.612883397511073, 21.058393580572947, 14.706472022192818, 17.502630370003835, 16.08888908794948, 6.605314978531428, 2.205063585724149, 0.14947355645043509, 0.15438429079949856, 1.290507163320269, 25.346849543707712, 58.79403059823172, 28.195350408554077, 32.39526721409389, 41.53130068097796, 46.93944147654942, 54.36944900240217, 58.40261772700718, 39.246972697121755, 6.694331390517099, 0.25434035648192677, 0.18919362580137594, 0.12675528121846064, 0.12589469525430882, 0.14225853074874195, 0.1725925337523222, 0.18836700730025768, 0.14205522808645452, 0.22177952368344578, 0.17428626572447165, 0.16794109477528504, 0.1450022549501487, 0.10989285140697445, 0.10704179653631789, 0.1567093181822981, 0.1937841730458396, 0.1310448438993522, 0.16660248089049542, 0.17898351938596793, 0.16461017993944033], [0.019455123992104615, 0.016232279428680028, 0.031790091656148434, 0.043654239137790034, 0.04054594485621367, 0.007077824648669255, 0.031847041100263596, 0.03388821014336177, 0.032028277803744586, 0.0417165670410863, 0.08559394920510904, 0.01667482844953026, 0.06487197149544954, 0.047356451728514264, 0.11845947136836392, 0.05318955944052764, 0.15255046848739895, 0.1168881199721779, 0.06112128097031798, 1.1233514185462679, 16.377508572169713, 47.75039005279541, 44.71566356931414, 36.97035721370152, 21.81136291367667, 24.86303605352129, 33.97786882945469, 31.2800327028547, 30.56561197553362, 7.7384858301707675, 0.1345148855554206, 0.02462342514523438, 0.14950787675167831, 1.0461143744843346, 4.471251342977796, 8.863316672188894, 5.71791580745152, 3.5836374291351865, 10.780725921903338, 29.267414024897985, 39.321078709193635, 52.54466445105416, 53.911639145442415, 52.95428507668631, 54.65620115825108, 51.4366317476545, 51.61080224173409, 51.472890922001426, 49.714308806828086, 50.45269039699009, 47.84127943856375, 52.7411664554051, 46.65520109449114, 46.27302237919399, 52.48477792739868, 48.104796818324495, 49.90018006733486, 48.34731674194336, 46.402998856135774, 44.80233192443848, 47.92526578903198, 48.09679249354771, 47.90272583280291, 47.537479877471924, 47.536486285073416, 44.155169759477886, 45.394954204559326, 48.9217312676566, 47.108661379132954, 39.185779912131174, 34.19451366152082, 34.1620204108102, 35.31915603365217, 33.5356194632394, 35.10804891586304, 36.77390384674072, 37.084849630083355, 38.3260897227696, 41.831362111227854, 40.16044889177595, 40.531218664986746, 38.262840270996094, 42.071537017822266, 40.33554349626814, 48.29151575905936, 45.21032319750105, 53.34646919795445, 26.325241020747594, 23.38808982712882, 50.86826910291399, 41.7750678062439, 49.55082811628069, 45.76091929844448, 50.86881453650338, 48.313645771571565, 49.85232087544033, 48.8219655581883, 48.43683385848999, 48.228433064052034, 41.32009628840855, 34.932641642434255, 36.320603370666504, 32.26853207179478, 42.347443035670686, 47.847557135990684, 48.84590210233416, 43.92803314753941, 48.40906885692051, 48.83611209051949, 48.47629962648664, 46.002984115055625, 47.65792690004621, 48.854021072387695, 46.501993315560476, 43.92446872166225, 42.831881863730295, 48.27092824663435, 47.89095211029053, 50.202013288225444, 47.91795628411429, 45.34476736613682, 46.289069243839805, 47.09151322501046, 45.77925212042672, 45.48299830300467, 45.1832252229963, 44.5864896093096, 44.64280475888933, 48.75656911305019, 44.75094999585833, 47.04107625143868, 50.691229002816335, 57.83378607886178, 55.31075620651245, 38.507826805114746, 23.0163768359593, 10.15095944064004, 4.24189738716398, 5.792925085340228, 9.907570123672485, 7.779239620481219, 3.506104652370725, 0.0683818431571126, 0.04539465092654739, 0.025141364495669092, 0.1431397306067603, 8.27958721773965, 32.62348427091326, 45.85206576756069, 23.850452491215297, 25.479950972965785, 33.577530997140066, 41.48475122451782, 46.07635709217617, 33.80995866230556, 7.173928192683628, 0.5317609459161758, 0.040752901429576535, 0.016931755734341483, 0.027500054000743797, 0.041320730067257366, 0.019672275554122667, 0.04737062293237873, 0.07023146176444632, 0.03754528658464551, 0.026962345532540764, 0.04077408868553383, 0.012283348960668912, 0.0556074613040047, 0.03640943253412843, 0.029301337166024104, 0.04641219561121293, 0.08299233737800803, 0.11521008930036, 0.052595118659415414, 0.04672160418704152, 0.020031459762581756, 0.028287923063284585, 0.048690692455108674, 0.029484219316925322, 0.028864394540765455, 0.0601021960111601, 0.030659292691520283, 0.0961165481380054, 0.007652748642223222, 0.0706342537222164, 0.008184732819375182, 0.060560919610517364, 0.0329191773198545, 0.04254114654447351, 0.07033103677843298, 0.050110398059976954, 0.037649122798549275, 0.05067691033972161, 0.06742328352161817, 1.1914168404681342, 21.513094118663243, 53.81482989447457, 50.4635990687779, 42.03274175098964, 26.281729664121354, 29.72314637047904, 38.32456111907959, 34.465628896440776, 33.370481627328054, 8.828248245375496, 0.020540849571781497, 0.018807311342763047, 0.36144206087504116, 2.6921234045709883, 10.127205286707197, 7.9245577199118475, 9.480104787009102, 5.803752984319415, 12.160325493131365, 31.261536598205566, 42.15594720840454, 53.89223630087716, 54.31044142586844, 54.625576972961426, 54.90027053015572, 53.09365551812308, 53.07404770169939, 52.20519978659493, 51.82025916235787, 50.069115093776155, 47.47336884907314, 52.766655921936035, 47.951019287109375, 45.910715511866975, 52.87051412037441, 49.14318772724697, 51.14634990692139, 49.59625196456909, 45.82086140768868, 45.687838145664756, 49.299365861075266, 49.98185614177159, 50.63179063796997, 47.90985121045794, 48.805397578648154, 45.51598834991455, 46.76549679892403, 49.76389810017177, 48.704280444553916, 41.37345150538853, 35.71498448508126, 35.3356545312064, 36.83554826463972, 35.17180906023298, 37.84424952098301, 37.155029909951345, 38.45449938092913, 39.24579150336129, 41.90617683955601, 41.61682953153338, 42.09289230619158, 39.70915991919381, 43.43167468479702, 42.276491505759104, 49.675645555768696, 46.52063880647932, 55.05503123147147, 27.178137608936854, 24.955879620143346, 51.81907449449812, 41.223234925951274, 49.306953293936594, 46.27519716535296, 52.63730130876814, 49.01186677387783, 51.84008584703718, 50.97093915939331, 50.8960097857884, 48.36969688960484, 42.29503624779837, 37.09155464172363, 37.75124440874372, 34.78586094720023, 44.15307835170201, 51.034518650599885, 50.440155846732004, 45.054270131247385, 49.90528351919991, 50.44243138177054, 49.402164459228516, 48.36745956965855, 49.374395983559744, 50.7495174407959, 47.93509749003819, 44.1278737613133, 44.771263054439, 48.583336625780376, 49.09855597359793, 50.784098625183105, 48.49420860835484, 45.6869661467416, 46.529004437582834, 47.15226479939052, 46.122923919132774, 45.60408803394863, 45.87161105019705, 44.77385125841413, 45.33016572679792, 48.064118589673726, 47.60796935217721, 49.77740887233189, 51.80038036618914, 56.83094562802996, 54.199725355420796, 39.53524998256138, 23.758275951657975, 11.022676961762564, 5.517985301358359, 7.216589263507298, 8.804856266294207, 7.157827479498727, 6.636663947786603, 1.5340780019760132, 0.5163820311427116, 0.13406880306346075, 0.13664750754833221, 9.999454838888985, 37.690454619271414, 37.16739770344326, 26.381651708057948, 32.94607523509434, 37.56332342965262, 47.720346042088096, 52.1573440687997, 40.389951365334646, 8.97522349017007, 0.7176009395292827, 0.025424218603542874, 0.030204714941126958, 0.029216377796339135, 0.013109997995863003, 0.015697458126981343, 0.04380643793514796, 0.0877261980037604, 0.04129962423550231, 0.06747890982244696, 0.031233876145311763, 0.02263513094346438, 0.051765962437327416, 0.06687237415462732, 0.050406425925237794, 0.027180828719532917, 0.0544411953139518, 0.031885819376579354, 0.02107436808624438, 0.05389810945572598, 0.19245123171380588, 0.08690880757889577, 0.10474119641418968, 0.0765927072082247, 0.10779178129242999, 0.12685774000627653, 0.10548470794622387, 0.1242381062890802, 0.10564130704317774, 0.12597018906048366, 0.1779146096003907, 0.21050693999443734, 0.10390229642923389, 0.16202436440757342, 0.22810037593756402, 0.14914078930658953, 0.23718701835189546, 0.22310937089579447, 0.18342834444982664, 2.537051771368299, 28.406467948641094, 61.350752285548616, 57.58912263597761, 48.34016009739467, 32.783563818250386, 34.27228137425014, 41.099855763571604, 39.82757459368025, 40.139194352286204, 11.207317522593907, 0.2821797526308468, 0.16185713266687735, 0.8396607041358948, 2.75216126867703, 10.595531242234365, 20.871297700064524, 13.08407633645194, 9.368719952447073, 14.920417479106359, 31.71533387047904, 42.83092301232474, 55.365084171295166, 56.11994341441563, 55.56047098977225, 56.31542403357369, 52.69104215076992, 54.16758646283831, 53.12961939402989, 51.7768919808524, 50.81393766403198, 48.21956716264997, 52.04480062212263, 48.40781470707485, 46.99214703696114, 55.84895672116961, 51.48560265132359, 52.887307916368755, 50.32564953395298, 47.36555017743792, 44.52186094011579, 48.833919933864046, 51.92696959631783, 52.17743131092617, 50.3110339982169, 49.95109646660941, 46.07459224973406, 46.73780822753906, 51.33263805934361, 51.50797585078648, 44.11161845070975, 36.91661637169974, 37.972065108163015, 39.345595427921836, 37.421024322509766, 39.34799255643572, 39.82942976270403, 40.95460714612688, 43.00636502674648, 45.08167382649013, 46.149750913892476, 44.229157652173726, 42.44576351983206, 45.80904599598476, 45.40048149653843, 52.66187013898577, 48.886632442474365, 55.617157867976594, 29.93596621922084, 26.515029328210012, 50.318353925432476, 41.27685764857701, 49.556654180799214, 47.59685918263027, 53.64427246366228, 51.908202511923655, 54.09462342943464, 52.852313314165386, 52.76607922145298, 52.06869895117623, 45.220901829855784, 38.3912672996521, 39.502068860190256, 36.83905710492815, 47.02490431921822, 53.41340814317976, 53.159913539886475, 45.370298521859304, 51.92754282270159, 52.18057189668928, 51.99848740441458, 50.708714144570486, 51.71299287251064, 51.49326304027012, 48.56529910223824, 45.00969743728638, 45.391427993774414, 50.422361510140554, 49.85607985087803, 52.31429692677089, 48.47942631585257, 47.14988504137312, 47.419975417000906, 47.216021469661165, 45.775159631456646, 46.5420184135437, 46.542021887642996, 44.09433133261544, 45.308619362967356, 49.029067039489746, 49.393041474478586, 53.86478049414498, 53.959071023123606, 58.27024064745222, 57.26010806219918, 42.299000195094514, 25.00512671470642, 14.805374417986188, 8.34928286075592, 12.768232941627502, 16.773755652563914, 15.0060053893498, 13.243885772568838, 1.8276884640966142, 0.5411841145583561, 0.2349072763962405, 0.20243629520492895, 12.50034601347787, 45.17426552091326, 61.17469882965088, 32.77840478079659, 36.30656453541347, 42.87354326248169, 53.274280888693674, 58.242513860974995, 49.284340381622314, 11.696774687085833, 0.9948626160621643, 0.15090766735374928, 0.1041618903566684, 0.16035953802721842, 0.215606958472303, 0.07331641444138118, 0.11689912581018039, 0.18368825050336973, 0.0970368180423975, 0.11926890936281, 0.0909407576546073, 0.14691873639822006, 0.1207861000938075, 0.13227315513151033, 0.11724242381751537, 0.17062630211668356, 0.14346633665263653, 0.17674397384481771, 0.13176760583051614, 0.12773094672177518], [0.010500543152115174, 0.04382718753601823, 0.04181793338752218, 0.02363711003480213, 0.08604581960077796, 0.026540971893285, 0.02035720237264676, 0.06084641321961369, 0.048898202034511735, 0.0791381091943809, 0.0032985143646198723, 0.0783642196495618, 0.03225613325568182, 0.08099457422005278, 0.014014479238539934, 0.044913654415202994, 0.05334072347198214, 0.01787917552116726, 0.07850791979581118, 2.975528048617499, 23.57934594154358, 50.06377192905971, 46.507190568106516, 38.28412955147879, 21.589034455163137, 16.74696339879717, 27.66140913963318, 35.30046190534319, 31.95152051108224, 3.2187030570847646, 0.12121059160147395, 0.027549293590709567, 0.9097912066749164, 4.392858726637704, 6.00985392502376, 9.440936054502215, 6.311981575829642, 4.545121116297586, 11.614735569272723, 24.03305983543396, 42.89374514988491, 47.15142059326172, 48.25419698442732, 45.75875493458339, 45.653170108795166, 46.52175399235317, 45.91652420588902, 47.85226801463536, 49.767705712999614, 47.50347191946847, 50.57751478467669, 43.894765172685894, 47.02999040058681, 50.6420704977853, 48.21360213415963, 45.71329287120274, 47.92835078920637, 47.33324800218855, 48.99335329873221, 45.45936400549752, 44.82907554081508, 45.81369434084211, 48.80774259567261, 47.163267271859304, 46.596593039376394, 44.545161724090576, 48.3616578238351, 47.80131687436785, 46.699308259146555, 38.51535170418875, 35.00151913506644, 36.76094198226929, 34.76750728062221, 34.781546115875244, 35.848240511757986, 39.2641521181379, 45.93640300205776, 44.11162887300764, 48.63899169649397, 45.542308126177105, 47.420413153512136, 46.51628923416138, 49.951867716653005, 45.83567844118391, 49.32071420124599, 45.13274656023298, 53.2377472605024, 24.108406100954326, 22.680872644696915, 49.567872047424316, 39.50789492470877, 46.79460627692086, 43.01892042160034, 46.246167591639924, 45.480490003313335, 48.671318190438406, 46.11465903690883, 49.92697579520089, 47.65635313306536, 48.92417355946132, 36.08264493942261, 36.50086048671177, 34.70832599912371, 39.60779959814889, 47.6863693509783, 48.974537576947895, 46.43419974190848, 46.29349177224295, 48.164961269923616, 49.40433577128819, 48.285116468157085, 48.58774178368704, 45.50986351285662, 44.704153878348215, 43.097344739096506, 47.249355452401296, 46.420313767024446, 43.96207584653582, 43.34395020348685, 45.00334678377424, 46.19501147951399, 44.84706095286778, 46.8619829586574, 50.11877734320504, 47.83176040649414, 47.39649050576346, 44.62378059114729, 46.19668252127511, 42.46638229915074, 42.60283102308001, 40.88421147210257, 45.6170985358102, 39.47588804789952, 50.09495197023664, 48.15454939433506, 27.205859184265137, 14.462067399706159, 10.71246073927198, 12.993076648030963, 8.044133612087794, 6.551226726600102, 7.6424113512039185, 1.1658847076552254, 0.40407270618847435, 0.055322317140442986, 0.1081004197310124, 4.194158051695142, 27.64469872202192, 34.90275396619524, 21.08711048534938, 20.001989466803415, 28.821516854422434, 38.129316738673616, 42.682853426252095, 41.14780180794852, 12.080685240881783, 1.0180958722318922, 0.0311413341467934, 0.04269909931878958, 0.030960894721959318, 0.05234886812312262, 0.0586273322946259, 0.007279356758642409, 0.012462684917928917, 0.031393552398575206, 0.049270707581724436, 0.022349873125287037, 0.060867895638304095, 0.03495612248246159, 0.0836890164230551, 0.09982302532132183, 0.031604756601154804, 0.02691317379607686, 0.0846887156367302, 0.02196903686438288, 0.03563881352809923, 0.005735645062356655, 0.027392133006027768, 0.024967525520228913, 0.01955919599692736, 0.07677010340350014, 0.0592434217355081, 0.07021514978259802, 0.04110786345388208, 0.033530893602541516, 0.07622049003839493, 0.039754135201552084, 0.07394368613937072, 0.10569856182805129, 0.09631794411689043, 0.06403417752257415, 0.059136450689818175, 0.016681247390806675, 0.04396274865471891, 0.030407919215836694, 3.8349895988191878, 29.319862501961843, 55.78672170639038, 52.21229042325701, 42.80819892883301, 26.6502742767334, 23.90533283778599, 34.540513106754844, 37.41996124812535, 32.1023485319955, 3.7872493948255266, 0.1836282272956201, 0.07993629029286758, 0.8641955533197948, 2.9986051874501363, 7.874421255929129, 11.273638078144618, 11.623082961354937, 6.700301195893969, 12.730335729462759, 25.81996280806405, 42.00734608513968, 49.626723289489746, 50.178594384874614, 49.060194969177246, 47.68342331477574, 47.609570911952424, 46.91312517438616, 48.444376128060476, 49.79367460523333, 47.311840602329795, 50.704340253557476, 46.67309965406145, 47.70595632280622, 52.196038586752756, 50.12302616664341, 47.620326723371235, 49.47030891690935, 50.1480153628758, 50.10975858143398, 46.48973321914673, 44.41326754433768, 46.071055616651265, 49.212221554347444, 46.48758969988142, 48.48420320238386, 44.28977721078055, 47.90281615938459, 49.76580885478428, 48.82398053577968, 39.70045035226004, 36.67621564865112, 37.64743832179478, 36.68835762568882, 36.438743591308594, 37.79139110020229, 39.75170373916626, 47.34817968096052, 45.49610260554722, 49.96223095485142, 47.70070001057216, 50.193421840667725, 48.032552923474995, 50.87163897923061, 48.33854464122227, 51.863355364118306, 45.57889386585781, 54.34496355056763, 24.662618739264353, 22.85699037143162, 50.12006623404366, 40.976698943546836, 47.80252586092268, 42.94137505122593, 47.035601070949006, 46.615929876055034, 49.39267321995327, 46.69429165976388, 53.1170848437718, 48.964445318494526, 49.63066291809082, 36.74202898570469, 38.54063967296055, 36.01874930518014, 41.069200311388286, 49.574987002781455, 49.923216819763184, 45.578341484069824, 46.7473133632115, 49.885307448250906, 50.57788303920201, 49.650302001408164, 49.726725237710134, 44.43378210067749, 44.508176462990896, 44.31101090567452, 45.48640986851284, 46.043398312159944, 43.88411011014666, 45.13717603683472, 45.72430229187012, 45.5490756716047, 44.57135990687779, 47.23423269816807, 49.24624340874808, 50.30491610935756, 48.0756630216326, 45.06488003049578, 47.12563930238996, 44.53821005140032, 45.299802098955425, 46.63906390326363, 47.51298747743879, 42.744497844151084, 49.654318060193745, 48.143925598689485, 25.985913583210536, 14.540071351187569, 8.255921653338842, 5.0624865889549255, 7.470234990119934, 6.5060538819858005, 6.693765980856759, 3.650217456477029, 0.7275969545756067, 0.26612984814814156, 0.049779198332024474, 4.583341419696808, 32.21077517100743, 36.48677996226719, 26.05573603085109, 26.687351601464407, 36.21364974975586, 44.64109550203596, 47.46738992418562, 48.42087384632656, 16.438977548054286, 1.1080507252897536, 0.04159256137375321, 0.037738319619425705, 0.004582613049673715, 0.04193373895915491, 0.06462125959140913, 0.06107108973498855, 0.06131277033793075, 0.013080623366736939, 0.02923723935548748, 0.046529687342367, 0.057511942860271247, 0.02891087418954287, 0.035343169035123925, 0.05834569954978568, 0.03511726437136531, 0.03575263438480241, 0.03674377727189234, 0.030364391194390397, 0.006942637148313224, 0.06770759647978203, 0.08713488187640905, 0.08328131187175002, 0.15486590138503484, 0.2434187111045633, 0.24007258351360047, 0.1249081731906959, 0.11410103738307953, 0.16334890547607625, 0.18457595072686672, 0.1327070647052356, 0.1876136977225542, 0.23690083942243031, 0.1848800429808242, 0.20374338435275213, 0.21271843489791664, 0.17535225780946867, 0.071410090662539, 0.16485666457031453, 5.4403713175228665, 36.15418011801583, 62.769998277936665, 58.39600304194859, 50.79719597952706, 31.693655490875244, 25.276750905173166, 35.724850927080425, 45.833041599818635, 39.58282777241298, 4.465255916118622, 0.4305494954543454, 0.20558648902390683, 1.3961574541670936, 7.71782796723502, 11.825831396239144, 14.257522855486188, 15.493319034576416, 9.241085886955261, 13.734520656721932, 26.951110431126185, 45.3123505456107, 50.70679644175938, 49.94398151125227, 49.77928488595145, 49.72815656661987, 47.590904576437815, 46.17351375307356, 49.86091579709734, 49.49298436301095, 47.15113571711949, 50.7471342086792, 45.04151323863438, 49.907472201756065, 54.441852705819265, 53.17027677808489, 49.91878734316145, 52.201336588178364, 52.11936868940081, 51.29065009525844, 47.724375997270855, 44.39093255996704, 46.52466876166207, 50.44835124697004, 48.21844850267683, 47.96344266619001, 45.63269376754761, 51.156518595559255, 50.938605717250276, 50.42727388654436, 42.60502665383475, 38.58611910683768, 39.998802525656565, 38.62057869774954, 37.589344433375764, 39.89044884272984, 43.71611656461443, 50.31130845206124, 47.107744216918945, 52.49603748321533, 49.93153728757586, 51.99333878925869, 50.363072531563894, 53.34018455232893, 49.95197193963187, 52.874693461826865, 47.79794699805123, 54.84339257649013, 26.685216767447336, 27.069874252591813, 49.66362517220633, 43.07976232256208, 48.42088079452515, 43.33420535496303, 47.34243699482509, 46.730210372379844, 49.397404943193706, 49.504431520189556, 53.85061659131731, 50.54696355547224, 51.667325837271555, 38.835587229047505, 40.766248430524556, 38.0948224067688, 43.42533097948347, 52.27054064614432, 51.410086154937744, 46.874104091099326, 47.31166689736502, 51.439421449388774, 53.41950518744332, 51.10000889641898, 51.099220275878906, 44.97120789119175, 45.57466241291591, 43.701170989445274, 45.11441026415144, 47.356312547411235, 45.10835490907942, 44.66592141560146, 46.503063338143484, 46.70253917149135, 46.000343799591064, 48.51823895318167, 51.93473768234253, 50.22487980978829, 48.90382923398699, 45.90171412059239, 47.33485998426165, 43.907518591199604, 47.367023195539204, 46.9359951700483, 51.850310121263774, 44.67970664160592, 52.8903477532523, 49.791982718876426, 31.74619082042149, 18.579434394836426, 13.512433648109436, 19.315688099179948, 16.97112618173872, 13.93042424746922, 12.91560857636588, 5.299467495509556, 0.7963075275932039, 0.5117647360478128, 0.3108610478895051, 5.731061364923205, 37.01005574635097, 45.60325425011771, 29.691031796591624, 28.290834290640696, 40.36191538402012, 51.350352491651265, 53.07914767946516, 57.159168107169016, 22.35896781512669, 1.5689436282430376, 0.10301182099751063, 0.1319133008697203, 0.10565584126327719, 0.30555607112390654, 0.233626337988036, 0.18797876313328743, 0.12406438775360584, 0.09836608849998031, 0.1462553327104875, 0.10890717072678463, 0.15814741887152195, 0.13851442879864148, 0.23701393763933862, 0.2772437632083893, 0.1072694111083235, 0.21348181393529686, 0.15191173633294447, 0.09320825205317565, 0.10403649708522217], [0.017918779913868223, 0.11558970250189304, 0.062889115751854, 0.0694076931104064, 0.05444968378703509, 0.014223451060908181, 0.03923475057152765, 0.04167849104851484, 0.02721342384549124, 0.05288910074159503, 0.03859536023810506, 0.021296835970133543, 0.045428635352956395, 0.01657117883275662, 0.053971347132963796, 0.05664123993899141, 0.03896188110645328, 0.02059392288460263, 0.03277356031217745, 6.8840532558304925, 33.93621785300118, 46.10125943592617, 45.14916862760271, 33.02582318442208, 11.106857861791338, 15.522322552544729, 19.040782621928624, 30.04458393369402, 22.15212515422276, 0.921019658446312, 0.028708653790610175, 0.10210075881332159, 0.6797424310020038, 1.1009045030389513, 12.882999811853681, 6.57841329063688, 12.984602451324463, 5.840891974312918, 13.126942379134041, 32.87880277633667, 40.65097434180123, 47.11110019683838, 50.030476161411826, 48.7221268926348, 46.94699764251709, 45.583340712956016, 43.7288943018232, 47.761284828186035, 47.50392355237688, 47.31801755087716, 44.832455839429585, 47.2352888243539, 47.785739013126914, 45.609976632254465, 43.955933638981406, 43.236861092703684, 45.542318548474995, 47.27992752620152, 49.44918291909354, 48.742234979357036, 46.80257586070469, 44.64635181427002, 46.45108733858381, 44.901767594473704, 45.85691213607788, 43.191840239933555, 46.801505838121685, 47.324173654828755, 46.61187907627651, 36.572440828595845, 34.73360007149832, 33.32912942341396, 34.30084889275687, 33.06627907071795, 42.51151084899902, 49.46891580309187, 50.63011612210955, 48.58838449205671, 49.19951677322388, 47.9971935408456, 51.28019305637905, 47.087153230394634, 50.10114976337978, 46.269579546792166, 51.06324945177351, 43.98667246954781, 48.44088813236782, 23.79894549506051, 27.47919610568455, 50.817463874816895, 40.482734135219026, 48.126732281276155, 42.46277270998274, 44.9894642829895, 43.97855002539498, 47.897862093789236, 43.129396779196604, 45.44834763663155, 47.10618782043457, 46.92440210069929, 39.824406215122764, 33.914320605141775, 36.722772053309846, 35.46046502249581, 44.57922526768276, 49.07446656908308, 47.450964382716585, 49.79647472926548, 44.53454140254429, 46.06358977726528, 47.64860936573574, 45.060665948050364, 44.85945306505476, 46.1363582611084, 47.064008780888145, 46.01819372177124, 41.818810190473286, 43.612866333552766, 44.59812784194946, 45.2090482030596, 46.75795105525425, 47.51965079988752, 48.9915954044887, 46.94338805334908, 47.940360750470845, 47.36831208637783, 49.640605790274485, 48.80284758976528, 48.95573227746146, 45.76184688295637, 46.46419164112636, 39.38701711382185, 37.728134700230186, 29.12411958830697, 26.114905153002056, 31.760121958596365, 25.67859649658203, 8.77816562993186, 3.068250673157828, 4.49352639913559, 3.5236512422561646, 3.3382222780159543, 2.4048086617674147, 0.6751676936234746, 0.18175663772438252, 0.01879076356999576, 1.082571029663086, 16.285278184073313, 40.226317814418245, 27.23365718977792, 14.312388437134878, 21.877820696149552, 38.05943523134504, 48.059588364192415, 44.07648835863386, 25.86825278827122, 2.723732497010912, 0.048773853706994226, 0.02276789819422577, 0.03684742349599089, 0.016385855652125816, 0.057710991107991765, 0.019409350019746592, 0.030918689843799387, 0.020054407816912447, 0.04402452926816685, 0.04615924793428608, 0.008733015407675078, 0.06418708538902657, 0.028572865362678255, 0.0755435631477407, 0.037972183498953066, 0.03450056424896632, 0.07366598889763866, 0.006254631901226405, 0.04073440795764327, 0.03451850810753448, 0.04604073500792895, 0.058792345225811005, 0.05177791483168091, 0.03861285626356091, 0.01901299227029085, 0.013933966817733432, 0.0701388553051012, 0.06774539088032075, 0.009583782970107027, 0.009117449600515621, 0.03184682057638254, 0.03575718056942735, 0.020135843893513083, 0.001929542186969359, 0.036680490310703, 0.012161027756519616, 0.04192619704242263, 0.051547029720885415, 7.728712320327759, 38.7671023096357, 52.32887077331543, 50.04689475468227, 39.172203132084434, 16.69769719668797, 22.195871012551443, 29.181256362370082, 33.024739265441895, 24.131187507084437, 1.4386450371571948, 0.038136975906257115, 0.34439131723982946, 1.6487142677818025, 3.46202397772244, 11.53687231881278, 6.669082939624786, 13.579231892313276, 6.23346562896456, 14.010737606457301, 31.719735554286412, 45.97584097726004, 48.9789913722447, 50.47751631055559, 49.333828926086426, 49.14327457972935, 47.04892424174717, 45.57736873626709, 46.7626063483102, 46.75750289644514, 46.917870794023784, 45.73435633523123, 47.09106159210205, 50.03025729315621, 46.882157053266255, 46.51405886241368, 46.040407112666536, 47.59970794405256, 48.529046876089915, 51.47050421578543, 48.628048283713206, 47.41954115458897, 43.71853106362479, 46.61014550072806, 45.47263159070696, 46.738940783909385, 43.07026066098894, 47.780176980154856, 48.519381931849885, 48.520222663879395, 38.25005211148943, 37.338399818965364, 34.69233472006661, 36.90215369633266, 35.12908111299787, 43.58842257090977, 51.34018380301339, 51.061137199401855, 50.68401329857962, 51.730557918548584, 50.46796601159232, 52.922021116529194, 48.6057584626334, 50.964150769369944, 46.94807808739798, 52.37858166013445, 45.4290976524353, 49.69267559051514, 25.58764805112566, 28.830337592533656, 51.76771341051374, 40.89329276766096, 48.795340061187744, 43.84010716847011, 47.9239456312997, 44.55934647151402, 47.017094544001985, 43.41742740358625, 46.83461747850691, 47.42266436985561, 48.98324366978237, 41.83809838976179, 36.427133151463096, 37.208392075129915, 37.63977445874895, 47.150955063956125, 50.81280510766165, 49.1925060408456, 48.43028518131801, 45.43039001737322, 46.814721311841694, 47.97214528492519, 44.550331183842246, 45.08634301594326, 46.984149660382954, 47.4252838407244, 47.64538887568882, 45.128091267177034, 44.99010351725987, 44.49194894518171, 45.71542249407087, 47.27723857334682, 48.53190605981009, 49.56695141111101, 49.108359881809776, 49.41020005089896, 50.59493391854422, 51.08354861395699, 51.02111210141863, 48.65363155092512, 46.915494510105674, 45.19215018408639, 43.930465017046245, 41.63182026999337, 31.446282250540598, 27.726204565593175, 32.83440726143973, 24.538037538528442, 10.009715591158185, 5.065528162888118, 6.308194807597569, 7.369881289345877, 7.1018549629620145, 4.607905038765498, 1.4891640863248279, 0.47263861554009573, 0.07116964499333076, 1.241616923894201, 19.566443375178746, 41.69923169272286, 26.258739812033518, 19.828793457576207, 27.887925624847412, 43.39829206466675, 52.67588118144444, 50.52448960712978, 31.204783712114605, 3.7237923656191145, 0.036954849160143306, 0.03245976161477821, 0.063585937289255, 0.018892767739349177, 0.020536795325045074, 0.061003901197441986, 0.023141256999224424, 0.02113459655083716, 0.06590581459126302, 0.01489322110345321, 0.045422145165503025, 0.022917937553886856, 0.021698852701644813, 0.003197698691760057, 0.019798718858510256, 0.03877054101654461, 0.04245182419461863, 0.059555744619241784, 0.030880471358874013, 0.17568294863615716, 0.19571965347443307, 0.14858497413141386, 0.12997567627046788, 0.08910308804895196, 0.16130157533500875, 0.14663278817066125, 0.154300328876291, 0.15982208400964737, 0.11885270955307142, 0.0823726449161768, 0.1238104799496276, 0.09996789254780326, 0.10648140124976635, 0.10336980928799935, 0.15386599861085415, 0.09771102400762693, 0.07885592683617558, 0.20082006550260953, 11.078974740845815, 47.4184433392116, 57.70970862252371, 57.824944496154785, 44.38632590430123, 21.192926338740758, 22.74347243990217, 28.141651255743845, 40.380696364811485, 29.181509971618652, 1.7677106367690223, 0.16312786590840134, 0.4012433780091149, 1.7419256546667643, 4.805219113826752, 23.909512179238455, 13.944514325686864, 20.084367309297832, 12.246561322893415, 15.103012663977486, 35.69737774985177, 45.38668237413679, 50.030271189553396, 52.014499528067454, 50.54379170281546, 48.0406163079398, 50.60957724707467, 50.27802310671125, 48.33107532773699, 48.16586800983974, 48.67219018936157, 46.26135287966047, 49.277496406010215, 51.10500465120588, 49.301019532339915, 47.31147582190377, 48.447812012263704, 48.37466485159737, 50.77559750420706, 54.321499483925955, 50.76241329738072, 48.57904611315046, 45.40374020167759, 47.74719040734427, 44.81529378890991, 47.13511317116873, 45.164416449410574, 49.34423385347639, 51.083527769361226, 51.3665383202689, 40.7363155909947, 38.95966468538557, 36.90738568987165, 38.31414229529244, 36.27984871183123, 45.3752977507455, 53.45699071884155, 52.965360505240305, 52.57731403623308, 53.11218983786446, 51.40271759033203, 55.25547286442348, 50.08431427819388, 54.641807964869905, 49.17690733500889, 53.58917324883597, 45.82575641359602, 49.1576886177063, 27.656717368534633, 30.83172450746809, 51.643364974430625, 41.99149029595511, 51.122948374067036, 46.997844559805735, 48.95646183831351, 45.90092202595302, 48.55345589773995, 44.578287260872976, 47.27706834248134, 50.907331875392366, 50.875123500823975, 43.93184423446655, 38.95030198778425, 39.41640451976231, 39.60176508767264, 49.663423674447195, 53.60803065981184, 51.673534052712576, 50.587999616350444, 46.4477869442531, 47.20791987010411, 48.32631581170218, 44.35000767026629, 44.109540939331055, 48.291856220790315, 49.28168964385986, 49.72201088496617, 46.28283323560442, 44.07331303187779, 45.50586135046822, 45.169648442949565, 48.04316977092198, 49.04733385358538, 52.96881723403931, 51.29031310762678, 52.284225123269216, 51.67177268436977, 54.204380648476736, 52.54530021122524, 50.87247971126011, 47.50258255004883, 46.707649571555, 45.04996224812099, 47.1264557157244, 35.21432508741106, 29.772120748247417, 34.36422341210501, 30.488143035343715, 13.995283075741359, 6.9732464126178195, 9.903673921312604, 11.474413224628993, 11.218733412878853, 5.786303452083042, 2.5340167113712857, 0.5275149451834815, 0.15990973716335638, 1.6701982063906533, 23.584204469408306, 53.14009380340576, 35.21155275617327, 23.08199041230338, 33.82594646726336, 51.14814601625715, 58.44058963230678, 56.78935023716518, 38.745872088841026, 5.308511010238102, 0.15350557437964849, 0.08197822608053684, 0.14139588203813347, 0.11091526797307388, 0.12742542954427855, 0.13471571835024015, 0.1144166240202529, 0.1474446960325752, 0.17162765695580415, 0.09761368815920182, 0.1371063193572419, 0.14118263205247267, 0.05181448108383587, 0.15089006615536554, 0.1354681865445205, 0.12589458668870585, 0.13875366667551653, 0.12374145936753068, 0.04824986182419317], [0.036007478567106385, 0.04820742963680199, 0.039335479095046005, 0.013640013573292111, 0.030913091929895536, 0.051839356177619526, 0.026736176240124872, 0.013546608138962515, 0.023068601165765097, 0.0038120326353237033, 0.03400180029815861, 0.019498324620404413, 0.042723350160356076, 0.001800191360026864, 0.04324413935786911, 0.05786095413246325, 0.04436485868479524, 0.0411919407280428, 0.06139793326812131, 9.84327323096139, 29.701752867017472, 49.23166608810425, 40.74009541102818, 34.13057633808681, 22.722052880695887, 15.881982156208583, 20.36483829362052, 42.0548300743103, 14.158164484160286, 0.570633131478514, 0.02804818137415818, 0.13886505498417787, 0.42249846032687594, 2.5214580595493317, 7.247866579464503, 6.384428705487933, 10.41842860834939, 5.892339910779681, 14.530182327542986, 27.32784696987697, 45.253332546779085, 52.53807061059134, 52.05712672642299, 51.02898441042219, 50.42436606543404, 47.08318928309849, 44.75619241169521, 49.604718344552175, 48.42717933654785, 44.37755380358015, 48.59124714987618, 47.548732485089985, 45.8406012398856, 46.09753867558071, 42.61950322559902, 37.18064096995762, 37.26158748354231, 42.71080602918352, 46.32192380087716, 49.508134910038535, 48.730631487710134, 48.06047773361206, 49.43900728225708, 44.607163974217, 45.750719342912944, 44.868221691676546, 46.268481731414795, 45.9108510017395, 43.879347120012554, 34.76346690314156, 34.17959240504673, 33.826186180114746, 35.90969385419573, 38.83086245400565, 47.62078530447823, 46.530995096479145, 50.30748694283621, 44.642988886152, 50.574297768729075, 45.587679862976074, 47.75357927594866, 48.15227038519723, 47.55336345945086, 44.3459256035941, 46.63010420118059, 39.86679022652762, 51.07077782494681, 20.328500952039445, 22.12182927131653, 47.96211903435843, 45.50416946411133, 49.42547219140189, 46.76270014899117, 51.177269390651155, 46.389578410557334, 51.01308693204607, 46.74601405007498, 46.48177753176008, 41.926083428519114, 48.068138122558594, 39.78447144372122, 36.450802189963206, 35.309932300022666, 34.55660513469151, 37.848237786974224, 45.57781342097691, 47.821466650281636, 46.79546437944685, 46.58012580871582, 46.90676062447684, 45.771907874516074, 48.44317061560494, 48.8233517238072, 47.05131094796317, 43.70087569100516, 41.913823332105366, 46.783635071345735, 44.769150802067344, 43.53340673446655, 46.09007978439331, 46.606431688581196, 48.312832832336426, 47.61682483128139, 46.60202653067452, 45.12923424584525, 45.28218494142805, 45.7253931590489, 46.60199873788016, 47.43690817696707, 49.25448744637625, 49.08298853465489, 47.45716912405831, 39.23337507247925, 36.63939019611904, 24.768220935549053, 17.999301501682826, 21.816568851470947, 15.002975974764142, 6.90363849060876, 6.231833670820508, 4.050626942089625, 3.3879563978740146, 4.5915941425732205, 1.5294404051133563, 0.17052830808929034, 0.0650221991485783, 0.17802825064531394, 10.724263991628375, 34.25913190841675, 36.53649779728481, 27.008393117359706, 22.717312472207205, 35.000282355717246, 40.610084193093435, 46.236023221697124, 32.186480794634136, 6.072251353945051, 0.18012659304908343, 0.07074275825704847, 0.008840970329142042, 0.04280606357912932, 0.030698936099984815, 0.044469200407287905, 0.007734918384812772, 0.03412047268024512, 0.021530501378167952, 0.04100691440648266, 0.021894362389243076, 0.07529299373605422, 0.025298835510121923, 0.03392602150727596, 0.02658398083544203, 0.0573339970516307, 0.03289416991174221, 0.019688227912411094, 0.013449104353120285, 0.037454094870814254, 0.0072320908574121335, 0.029034679689045464, 0.0202214817982167, 0.027223591692745686, 0.0633757339258279, 0.049911495697285445, 0.05807459766843489, 0.03622016536870173, 0.016866209251540046, 0.06206722663981574, 0.0322756716715438, 0.026746566307597926, 0.013706614329878773, 0.023174154073266045, 0.07500599377921649, 0.03160969294341547, 0.04181234904431871, 0.07984947173723153, 12.08262118271419, 35.7666061265128, 54.806365626198904, 46.26066153390067, 37.53468990325928, 21.254216398511613, 15.92768393244062, 19.12771848269871, 40.67082534517561, 17.011371885027202, 0.7367223820516041, 0.11096537099885088, 0.19467951357364655, 0.4017330903027739, 3.105146041938237, 9.279773456709725, 12.405533501080104, 14.943103347505842, 7.839804462024143, 14.039859243801661, 30.57471064158848, 44.75864165169852, 51.995788029261995, 52.65705851146153, 49.68800640106201, 50.06426872525896, 48.747963769095286, 46.92190074920654, 49.44718531199864, 49.83614894321987, 44.172988414764404, 49.75069304874965, 49.34264966419765, 47.79089805058071, 47.726238114493235, 44.73717519215175, 39.41739463806152, 39.17712245668684, 44.84418439865112, 48.562318325042725, 51.005381379808696, 49.75853756495884, 49.312904426029746, 48.166514192308696, 45.8627347264971, 46.12806906018938, 44.503399576459614, 48.71703386306763, 48.53538710730416, 46.60508026395525, 37.93358251026699, 36.36464105333601, 35.97213384083339, 37.11144038609096, 39.14245094571795, 49.79281997680664, 48.95022930417742, 51.433480739593506, 46.65357869012015, 50.818130901881624, 47.85089921951294, 49.95014803750174, 49.3616703578404, 48.45953709738595, 45.47611263820103, 47.17067057745797, 39.92960888998849, 51.982447487967356, 20.83998564311436, 24.640594686780656, 48.982458523341585, 46.00697585514614, 50.51589468547276, 48.06912129265921, 52.47613089425223, 48.17769036974226, 52.01242201668875, 47.01012202671596, 46.97896977833339, 44.10740784236363, 49.339898177555625, 42.56377867289952, 37.884990283421104, 36.471466132572715, 35.84683697564261, 39.490062373025076, 48.92774493353707, 49.99284471784319, 49.17712272916521, 47.942254134586875, 47.110342843191965, 46.86046477726528, 49.87451342173985, 49.53793225969587, 47.91175501687186, 45.56211396626064, 45.95272084644863, 46.648603779929026, 45.28372744151524, 43.917423248291016, 45.28239686148507, 48.18868589401245, 51.15758861814226, 50.126774719783235, 48.6433482170105, 47.951036657605854, 47.18881579807827, 48.41063914980207, 50.311965056828086, 50.50470808574131, 51.047886984688894, 49.27045440673828, 47.016212122780935, 43.506020409720286, 42.013661997658865, 27.389253411974224, 21.18095632961818, 23.384136302130564, 16.92693737574986, 6.822057519640241, 9.511954460825239, 12.786597899028234, 10.842227901731219, 5.915058348860059, 1.6853089098419463, 0.14421178879482405, 0.12089949686612401, 0.3344584602330412, 12.20573457649776, 40.457404477255686, 33.48309108189174, 24.245931795665197, 26.85161222730364, 40.54057788848877, 46.39226736341204, 51.92492682593209, 37.8838403565543, 7.9210731983184814, 0.19013807869383267, 0.026813205231779387, 0.006566647323779762, 0.036403383394437175, 0.03657344801883612, 0.05525686904521925, 0.001938081974263436, 0.05962749969746385, 0.06357651243784598, 0.03800019681719797, 0.08048105891793966, 0.08268220616238457, 0.054622649148638756, 0.029454435022281747, 0.019101788755506277, 0.03931666331897889, 0.04052147688344121, 0.04949307368536081, 0.04224311360823257, 0.08590626530349255, 0.12189113508377757, 0.1220957948161023, 0.08459560706147126, 0.06085545130606208, 0.20877880629684242, 0.13131837493606976, 0.1532648844378335, 0.10222437432301895, 0.07255350359316383, 0.12279710146997656, 0.10232032596000604, 0.1280989841158901, 0.14606087814484323, 0.0989294218431626, 0.18986190137054237, 0.1264414723430361, 0.12526756604867323, 0.44435909443667954, 14.582868780408587, 42.4791704586574, 61.24064418247768, 52.27279186248779, 45.046192850385395, 33.42368745803833, 25.4003141948155, 29.633570194244385, 52.76070826394217, 20.718216725758143, 0.9540988377162388, 0.198559186820473, 0.6857054510286876, 1.4363436635051454, 7.234342345169612, 11.02324845109667, 15.993947165352957, 20.44397132737296, 9.185972775731768, 19.489448649542673, 32.41691085270473, 48.77045856203352, 51.85681710924421, 52.33125747953142, 50.2318696975708, 49.940847873687744, 48.237705435071675, 47.04732615607125, 52.167370319366455, 48.84787539073399, 45.394669328417095, 50.087989875248496, 50.757737159729004, 51.19873237609863, 51.90494728088379, 47.77515343257359, 41.27809790202549, 40.528019019535606, 46.06125865663801, 50.592828614371165, 53.63256822313581, 52.33832032339913, 51.68352903638567, 51.28729064123971, 47.7927427973066, 46.42318684714181, 45.70234251022339, 50.298572404044016, 48.909999234335764, 48.06525114604405, 38.98833295277187, 37.321123123168945, 37.53127833775112, 40.17706550870623, 42.95494835717337, 51.77048226765224, 50.78755535398211, 53.59839350836617, 46.82514360972813, 52.50316980906895, 47.97301033564976, 49.63780219214303, 49.464788573128835, 48.50885888508388, 45.04460866110665, 48.3298385483878, 40.56351389203753, 53.20414229801723, 23.461945704051427, 28.53941478048052, 52.840855734688894, 49.44275236129761, 54.178001812526155, 49.376379694257466, 55.90674141475132, 49.15261990683419, 54.90863963535854, 48.08136401857649, 47.36117281232561, 44.637600558144705, 51.601425647735596, 45.10733699798584, 40.26619700023106, 38.72286660330636, 37.3844906943185, 41.696904046194895, 50.62473821640015, 52.6321804864066, 50.18632425580706, 49.52396985462734, 48.18398543766567, 48.19482462746756, 51.78569882256644, 52.761837346213206, 50.483505657741, 49.05809661320278, 47.205870151519775, 47.70447635650635, 46.035751819610596, 45.00117894581386, 46.532520226069856, 49.745144912174766, 52.98009416035244, 53.265053680964876, 51.997247150966096, 50.19656242643084, 48.08723177228655, 49.87881783076695, 51.150178364345, 51.85840824672154, 52.631037507738384, 51.954953466142925, 48.98288583755493, 46.69866902487618, 47.424502168382915, 32.76036378315517, 24.595983777727398, 28.615084137235367, 18.411868163517543, 10.432124376296997, 9.949505976268224, 12.369345545768738, 13.03370189666748, 9.901112641607012, 2.893435516527721, 0.5914169305137226, 0.22874870257718222, 0.593458506677832, 14.982332876750402, 48.18251241956438, 46.89666141782488, 36.429526805877686, 34.61687380926949, 46.11228622709002, 53.682484081813264, 57.8014144216265, 47.34217643737793, 11.282998170171465, 0.4295111468860081, 0.09044571207570178, 0.10461662417011601, 0.10181056295654603, 0.12998554216963903, 0.138023278010743, 0.09285715089312621, 0.21489062905311584, 0.09951450223369257, 0.12182447580354554, 0.1409936057669776, 0.11024380328931979, 0.12899956293404102, 0.1377476163740669, 0.11393281498125621, 0.14069818519055843, 0.1659067246530737, 0.15234169683286122, 0.22965183268700326], [0.03715068115187543, 0.029752176188464676, 0.06071685374315296, 0.042934747745415995, 0.03390718198248318, 0.015236508932762911, 0.04089475596057517, 0.0427703319250473, 0.03174897921936853, 0.04402050894818135, 0.10939510525869471, 0.027709322682182704, 0.052130722507302246, 0.021551276424101422, 0.0787847756541201, 0.01291438567984317, 0.043025026829647164, 0.048312690774244924, 0.10249794607183763, 7.689860599381583, 35.25508669444493, 46.25334855488369, 43.46455356052944, 33.27391903741019, 17.482539653778076, 14.510851570538112, 34.20500891549246, 34.98219966888428, 7.4440949984959195, 0.09583370760083199, 0.041522696015558073, 0.07462313718029431, 0.9551216342619487, 3.575971611908504, 10.021981767245702, 7.377692801611764, 12.16375356061118, 8.733143040112086, 13.86683520248958, 38.17732879093715, 49.418482303619385, 50.10921662194388, 50.126031262534006, 48.98808309010097, 47.668130329677034, 49.42728567123413, 48.16504464830671, 46.17911747523716, 46.66962208066668, 49.54006883076259, 49.49246324811663, 44.2747482572283, 44.149107456207275, 43.00224821908133, 43.46262543542044, 40.616403579711914, 35.66204616001674, 34.52420221056257, 40.736464977264404, 43.51081466674805, 47.11577633449009, 47.17175449643816, 47.83275399889265, 44.2144900049482, 45.29685953685215, 45.73340443202427, 46.38145249230521, 44.16168022155762, 37.62195232936314, 33.47351993833269, 32.95621265683855, 34.797693729400635, 38.46287196023123, 42.491979462759836, 47.77766520636422, 51.55371931621006, 46.81877905981881, 44.89339501517159, 45.683224541800364, 41.77354267665318, 44.15337017604283, 43.54917567116873, 47.446455001831055, 44.89933225086757, 44.75099515914917, 40.412571225847515, 45.07023014341082, 21.665096385138376, 22.41610632623945, 52.895009994506836, 43.79005581992013, 48.645832198006765, 41.99502692903791, 45.59294312340872, 42.3862487248012, 45.4327906199864, 46.96296807697841, 51.08643906457083, 46.23622471945626, 48.312933581215994, 40.47918013163975, 35.24301072529384, 34.3464047568185, 35.38455247879028, 34.26723003387451, 38.944892815181184, 44.634171622140066, 47.90748882293701, 48.425595147269114, 47.61397954395839, 50.033168588365825, 49.51191473007202, 47.11066593442644, 45.97960690089634, 48.6335894720895, 49.79458829334804, 48.20420816966465, 47.77031748635428, 47.57872438430786, 49.28487539291382, 47.981160572596956, 46.15657751900809, 44.46470158440726, 40.48854282924107, 36.776082106998985, 40.82458550589425, 41.151307174137656, 42.38797882625035, 45.63420500074114, 48.364051478249685, 49.76647588184902, 48.44757924761091, 46.57114526203701, 39.009285245622905, 36.66502210072109, 22.302072490964616, 13.234232119151525, 11.564494013786316, 7.593559435435703, 9.424606050763812, 11.42322063446045, 12.13491940498352, 6.094221992152078, 2.2638453458036696, 0.2942464937056814, 0.12213595051850591, 0.014945434373138207, 4.5045479791505, 30.4101425579616, 36.86564786093575, 27.39200837271554, 20.33792618342808, 36.37132522038051, 42.14354119982038, 45.76853799819946, 42.33238281522478, 14.147280999592372, 0.14680786377617291, 0.03801819835124271, 0.05147269620959248, 0.021251123065927198, 0.037166053362722905, 0.013970321027695068, 0.017045099920194064, 0.02339421315783901, 0.036421422247907946, 0.03183381645275014, 0.03599008092922824, 0.07277562203151838, 0.009766568429768085, 0.021007033663668802, 0.008601237969872142, 0.05082759600398796, 0.02183304657228291, 0.028864727022924593, 0.027139176847413182, 0.02279730759827154, 0.04201984505302139, 0.007559679930896631, 0.03358354791998863, 0.03563555656000972, 0.011854363854841461, 0.037146284244954586, 0.010864737493518208, 0.06870006929550852, 0.04132317957867469, 0.03812797513923474, 0.09845629294535943, 0.025105760066903064, 0.009129189952675785, 0.01774637434365494, 0.07794932941240923, 0.07014882298452513, 0.07991486894232885, 0.2300587637083871, 10.071981872831072, 41.56559351512364, 52.53362028939383, 47.86013337544033, 39.791426590510774, 24.667072534561157, 17.54656904084342, 28.652611357825144, 38.96381275994437, 9.124216318130493, 0.25040072788085255, 0.021625494584441185, 0.26334831597549574, 2.703968780381339, 6.711268927369799, 9.895193644932338, 8.061587486948286, 8.965585470199585, 6.434041014739445, 14.511548127446856, 37.17522137505667, 50.46714265005929, 51.1630985396249, 50.42246225902012, 49.72639519827706, 48.68110472815377, 47.60627746582031, 46.39111048834664, 47.05321128027779, 48.051055976322715, 48.78542498179844, 50.77354431152344, 46.696261474064414, 46.260456562042236, 44.126442432403564, 46.53065463474819, 41.31270340510777, 37.224942684173584, 36.71905476706368, 43.6382029397147, 45.95586143221174, 48.6738612311227, 50.47034229551043, 50.14312383106777, 46.760139737810405, 46.59455026899065, 46.84040880203247, 48.42117261886597, 44.93713045120239, 39.28228691646031, 35.1959297316415, 35.6221148627145, 36.357168265751426, 39.22900118146624, 43.54330791745867, 50.654691900525776, 50.51826054709298, 47.04885475976126, 43.225344453539165, 44.49055583136422, 42.406860555921284, 45.06911148343767, 43.05866411754063, 47.25689424787249, 45.45908955165318, 44.60686520167759, 39.993382930755615, 47.81732899802071, 22.36569193431309, 24.320352213723318, 55.62521430424282, 45.755385058266775, 52.464551721300396, 44.69556590488979, 47.35075051443917, 44.15524966376168, 48.40402446474348, 49.311549527304514, 52.997902393341064, 46.27341842651367, 50.54373959132603, 42.45943757465908, 36.78691782270159, 35.96417120524815, 36.266254561288015, 36.2970107623509, 40.30993243626186, 46.649281229291645, 48.614919662475586, 49.36462681634085, 50.20950692040579, 51.134162766592844, 50.76706511633736, 48.86555508204869, 49.62270375660488, 48.8198150907244, 51.16273375919887, 49.21301017488752, 49.21324988773891, 49.231766836983816, 49.6003166607448, 50.134699140276226, 48.11756413323538, 47.21699769156319, 42.591887610299246, 40.20926693507603, 42.722350461142405, 44.490698269435335, 45.27615737915039, 47.63992411749703, 50.36800575256348, 50.65972587040493, 50.8574229649135, 46.5331768308367, 43.5665739604405, 41.36947366169521, 25.585462842668804, 15.337040151868548, 12.527000171797615, 7.608659608023507, 12.010361654417855, 11.79806465762002, 7.290623188018799, 8.170590826443263, 6.563044309616089, 1.8429638615676334, 0.13506544886955194, 0.021488391494910632, 5.632830338818686, 33.03476899010794, 41.67433977127075, 34.13048253740583, 26.479359013693674, 39.402695723942344, 46.17151614597866, 50.67363268988473, 47.39246055058071, 16.17219451495579, 0.507682343678815, 0.06616622276071991, 0.03276280892480697, 0.02934392202379448, 0.036669033246913126, 0.05121912428044847, 0.04874559272346752, 0.02581362476173256, 0.01848005729594401, 0.026819300172584395, 0.029941826726176908, 0.023678560042753816, 0.05353818394775901, 0.010737292501809341, 0.025547823935214962, 0.029749998091054813, 0.05901989872966494, 0.038467992429754565, 0.037115824807967455, 0.10441138089767524, 0.10159150471112557, 0.11123363660382372, 0.13155607932380267, 0.10940607038459607, 0.10450602296207633, 0.12406022154859134, 0.12146150028066975, 0.2092553142990385, 0.1175330810781036, 0.16284056061080524, 0.17876767739653587, 0.1342395767569542, 0.11715213794793401, 0.13249005563557148, 0.15005531880472386, 0.1812225899526051, 0.1587044961218323, 0.638252891600132, 13.92008011681693, 49.50348309108189, 58.002870491572786, 52.16823884419033, 44.44398900440761, 27.833604608263286, 21.115584203175136, 44.400583607809885, 46.54392916815621, 10.334062712533132, 0.4847100249358586, 0.09049783035048417, 0.32414356086935314, 2.988577199833734, 8.739747302872793, 22.909081016268047, 15.256854466029576, 17.91275474003383, 14.41794547012874, 19.063928808484757, 40.95162984303066, 49.20291444233486, 50.738587924412315, 50.91455800192696, 50.45530639375959, 48.33766916819981, 49.38914006096976, 46.49861649104527, 48.00928340639387, 47.44711855479649, 50.24846199580601, 53.041620458875386, 47.44141755785261, 48.723429679870605, 47.027641909463064, 50.08181987489973, 44.007169655391145, 38.61126116343907, 37.76177440370832, 45.97530944006783, 47.701902048928396, 52.20215994971139, 51.975096293858115, 50.223639556339805, 48.432602405548096, 48.093023095812114, 48.241016251700266, 51.101912702832905, 46.83555548531668, 41.52890355246407, 37.84042453765869, 37.2562894821167, 37.63337516784668, 42.39504861831665, 46.249214376722065, 52.303947584969656, 51.1248903955732, 46.504974092756, 44.79800319671631, 45.46491214207241, 42.55312361036028, 44.83927549634661, 43.33583470753261, 47.78643035888672, 46.25040946687971, 45.533664567129954, 40.24721104758126, 47.927746295928955, 25.448239394596644, 27.6088216985975, 58.32494381495884, 47.38622106824602, 55.955948557172505, 46.807946818215505, 48.11016082763672, 46.48722839355469, 50.099617685590474, 51.42857878548758, 55.24020072392055, 48.90510422842843, 52.9390754699707, 45.45116860525948, 38.15359721864973, 37.201079096112935, 38.74474648066929, 37.311107294900076, 41.87469802583967, 48.13819680895124, 51.49193246023995, 51.721768447331016, 51.43101412909371, 53.63296774455479, 53.660308906010215, 50.82805640356881, 51.78529582704817, 52.41710942132132, 53.85865913118635, 51.14434535162789, 52.40142386300223, 51.35814837047032, 52.03814424787249, 51.874312673296245, 49.65057298115322, 48.97769553320748, 44.45218440464565, 42.42082296098982, 44.83142750603812, 45.85431350980486, 46.596155302865164, 49.51461410522461, 51.14780902862549, 51.80099180766514, 52.987115315028596, 49.19090795516968, 46.55089126314436, 45.97995431082589, 30.86356462751116, 17.278024639402116, 14.75627497264317, 11.705677935055324, 16.33664447920663, 18.285615921020508, 20.64512688773019, 12.253900357655116, 4.409351578780583, 0.9184318887335914, 0.26575692530189243, 0.2690551211791379, 6.388659724167415, 40.09212725503104, 47.948403290339876, 38.50764962605068, 30.133229051317485, 45.3256459236145, 52.30586181368147, 59.35998221806118, 54.08924552372524, 21.887417895453318, 0.8164685400468963, 0.15993419156542846, 0.14450920426419803, 0.08726763046745743, 0.20438271361802304, 0.07876532884048563, 0.18430845865181514, 0.14918847674770014, 0.08273252631936755, 0.11533335197184767, 0.15610426850616932, 0.11549450403877667, 0.10032258315810136, 0.11302661110780068, 0.06735063277717147, 0.14503641240298748, 0.13592249288090638, 0.10632645777825799, 0.11462166373218809], [0.04688003872122083, 0.044705866636442285, 0.04606768302619457, 0.07387818715402059, 0.05194004059636167, 0.029864426236599684, 0.022395051683166196, 0.037100914000932655, 0.023508081511993493, 0.056123856987271986, 0.029387741815298796, 0.015735617240092585, 0.01810211668323193, 0.034492231838937314, 0.025352146310199584, 0.04932511251951967, 0.07433203887194395, 0.02086789666541985, 1.0472094757216317, 14.281749486923218, 36.529879638126914, 44.43970891407558, 39.08477742331368, 27.51317800794329, 13.203638332230703, 18.65006457056318, 28.642303705215454, 29.62950897216797, 4.654424965381622, 0.04353099003700273, 0.14993239540074552, 0.08984872339559452, 1.508709586092404, 3.321540955986295, 6.355347454547882, 12.442679439272199, 12.777479256902422, 10.146101781300136, 21.112419298716954, 38.895390374319895, 49.594257831573486, 51.26232576370239, 48.89871883392334, 47.37651790891375, 48.84059715270996, 47.342395305633545, 45.72787366594587, 47.53944274357387, 46.51432636805943, 46.90783412115914, 47.984530448913574, 43.68288680485317, 43.4277663230896, 41.15207495008196, 46.85887016568865, 43.74472229821341, 43.420415128980366, 36.10947888238089, 35.173132692064556, 37.54284014020647, 42.29083606175014, 45.67954894474575, 47.202535016196116, 48.423288345336914, 48.704461097717285, 47.3219050679888, 46.880416529519216, 40.242208344595774, 35.08982726505825, 32.668894222804475, 33.48344891411917, 34.59778710774013, 37.75993660518101, 45.92595291137695, 46.62880836214338, 33.06517430714199, 42.442636830466135, 44.698348658425466, 48.6896892275129, 46.3255090713501, 47.76674958637783, 46.20719167164394, 50.74457727159773, 45.48421771185738, 46.29722990308489, 40.28668376377651, 44.97389684404646, 23.095403909683228, 30.52545486177717, 55.943900380815776, 41.99132701328823, 46.63199063709804, 36.595644337790354, 40.60909060069493, 37.978308064596995, 42.66125842503139, 43.04825571605137, 45.1343481200082, 44.25788845334734, 44.39436844417027, 37.90238509859358, 36.289579663957866, 33.561445917402, 34.42780985151018, 34.37241881234305, 35.81514971596854, 34.85561738695417, 43.64318479810442, 47.633497033800396, 48.15022414071219, 46.26146752493722, 46.89944069726126, 42.71868528638567, 45.76837471553257, 46.988558292388916, 46.47305406842913, 46.77102061680385, 48.20810610907418, 46.68669033050537, 48.45758465358189, 45.082035132816856, 43.35811063221523, 35.994361128125874, 36.878950187138145, 33.95481123243059, 36.203800678253174, 36.77490438733782, 37.59263093130929, 40.01736811229161, 45.09280136653355, 46.79170192990984, 49.534263610839844, 46.99177530833653, 45.78712442943028, 39.297291551317485, 42.53551687513079, 27.35504743031093, 21.603629146303447, 7.044067229543414, 12.414778079305377, 18.373323031834193, 8.037346959114075, 6.620138960225241, 3.786804710115705, 0.7135674016816276, 0.017557392162936072, 0.1282446248722928, 2.203316765172141, 22.290467262268066, 34.98155696051461, 15.638694456645421, 15.136523825781685, 27.035128048488072, 32.20185368401663, 46.64360107694353, 44.64489616666521, 20.143923793520244, 1.632825908916337, 0.03515490610152483, 0.11632823358689036, 0.04279144454215254, 0.005964210431557149, 0.03194355592131615, 0.036982736949409754, 0.04942894873342343, 0.025491257863385335, 0.11745762798402991, 0.02690311790710049, 0.05058963377294796, 0.06435724161565304, 0.037372005704258165, 0.02226287136519594, 0.0440588427840599, 0.02886103918509824, 0.10359266054417406, 0.06660374214074441, 0.12277195496218545, 0.10585942891027246, 0.011886151524127593, 0.03913677690018501, 0.07079091388732195, 0.006308696723343539, 0.004955771686841867, 0.0059085519003149655, 0.03578359593770333, 0.041421119323266406, 0.06778771110943385, 0.043763751297124794, 0.055793111877782006, 0.028260209996785437, 0.057810722185032706, 0.03789309345717941, 0.09424687203552042, 0.007448189841982509, 1.218670932309968, 16.282853262765066, 43.495952469961985, 50.32972117832729, 43.16354717527117, 32.188641684395925, 16.363518374306814, 18.062257392065867, 32.06878873280117, 33.00448874064854, 5.548340243952615, 0.08179342706820794, 0.11555896486554827, 0.3229736036487988, 2.679326559816088, 6.748919478484562, 7.191070701394763, 7.851354105131967, 4.058329888752528, 8.244777611323766, 21.653815984725952, 40.83455269677298, 48.36497211456299, 51.20259557451521, 50.01871633529663, 47.51194524765015, 48.19455712182181, 47.19657346180507, 47.36758599962507, 47.321418694087434, 46.72515903200422, 49.32163831165859, 49.337077208927695, 45.66150794710432, 44.84556014197213, 43.749638148716514, 48.62653705051967, 46.03417805262974, 44.38467918123518, 37.23305818012783, 36.89909996305193, 40.31582450866699, 43.98955249786377, 48.91398402622768, 49.15079600470406, 50.30341182436262, 50.57189021791731, 47.21829005650112, 48.130737917763845, 42.86182165145874, 35.886948926108225, 34.09182970864432, 35.29355539594378, 35.507625920431956, 40.21793481281826, 47.28808123724801, 50.75486060551235, 35.2358158656529, 42.625562054770334, 45.41767828805106, 49.35912036895752, 46.66701650619507, 49.27379649026053, 47.05665758677891, 52.07194723401751, 46.37824589865548, 46.56325558253697, 40.39849417550223, 46.39924335479736, 23.204474994114467, 31.44099119731358, 56.88887275968279, 43.839832714625764, 47.80203601292202, 38.56776544025966, 42.42117731911795, 38.966032709394185, 45.01709379468645, 46.81064619336809, 47.317486013684956, 47.011393547058105, 46.55382687704903, 40.33664131164551, 38.32968888963972, 36.51880768367222, 36.53554589407784, 38.06471586227417, 36.59230572836739, 38.21186828613281, 47.46521861212594, 49.49631255013602, 52.09274666649954, 48.909151554107666, 48.471626962934224, 45.26057256971087, 48.4299065044948, 48.584656783512656, 47.94996663502285, 48.97404078074864, 48.936419759477886, 50.754169259752544, 49.736202580588206, 47.56399072919573, 45.44589144842965, 38.150119645254954, 38.49451405661446, 35.675553458077566, 37.86641427448818, 38.976680823734824, 40.12481158120291, 42.160487856183735, 47.31912578855242, 48.798411164964946, 50.870725291115896, 48.38251631600516, 45.74541439328875, 44.11000299453735, 45.62439414433071, 31.025784220014298, 20.71775119645255, 7.5186517749513895, 7.965057032448905, 9.552030801773071, 11.573794177600316, 5.421427922589438, 5.273417396204812, 2.04547757761819, 0.26216899497168406, 0.22640425552214893, 2.5682700276374817, 26.70229717663356, 38.47502783366612, 19.514696666172572, 21.577437911714824, 34.093542439596995, 39.89637565612793, 52.10160909380232, 49.72709001813616, 24.82002670424325, 1.8916859328746796, 0.028043726791760752, 0.046335578829582245, 0.0554311982622104, 0.037229567633143494, 0.033499911693590026, 0.021972638188994358, 0.014867270531665002, 0.023759080097079277, 0.09978208930364676, 0.018643443439421908, 0.021917366422712803, 0.06831295149666922, 0.04805865404861314, 0.016515014792925546, 0.04538408613630703, 0.041045312703187974, 0.040515987535140345, 0.05551888194999524, 0.20784141016857965, 0.18002676697713987, 0.12640021741390228, 0.2109773683228663, 0.24097107244389399, 0.2214853244700602, 0.10186445899307728, 0.05725810290979488, 0.09849308989942074, 0.17892944014498166, 0.10111076943576336, 0.12357200203197342, 0.12303365234817777, 0.12027775522853647, 0.21816779034478323, 0.15115154641015188, 0.14492536336183548, 0.11914177904171602, 1.8967448728425162, 22.49338592801775, 48.891649041857036, 56.1603159223284, 50.32478795732771, 37.0393146106175, 20.68107339314052, 25.85068253108433, 37.497068881988525, 39.16150638035366, 6.074226379394531, 0.2224470800054925, 0.2469751574099064, 0.5260144057018417, 3.3442995633397783, 10.701156888689313, 13.417902537754603, 25.227898120880127, 24.699666534151348, 12.55638757773808, 25.570835147585186, 41.87848479407174, 50.44278573989868, 52.1395879473005, 49.88009282520839, 47.65185764857701, 48.5990742955889, 47.731949533735005, 47.261136123112266, 48.196544306618826, 46.898363726479666, 49.89922816412789, 52.07194723401751, 46.350213391440256, 47.78939029148647, 43.67137016568865, 52.08613198144095, 48.03089230401175, 47.04049607685634, 39.97465058735439, 39.326901299612864, 41.19158240727016, 46.205315658024375, 50.78584609712873, 51.22762993403843, 52.908197675432476, 52.73319339752197, 50.22709628513881, 50.01725026539394, 44.21147448675973, 37.85722875595093, 35.0154641696385, 37.720880780901226, 38.07221644265311, 41.93347978591919, 49.755462987082346, 51.02931097575596, 36.2543488230024, 42.51534972872053, 46.526996408190044, 50.43816518783569, 47.746182918548584, 49.45883396693638, 49.37515333720616, 53.08304214477539, 48.22205114364624, 47.84904752458845, 41.34359162194388, 47.242629596165244, 26.370041268212454, 33.932174001421245, 58.5892949785505, 46.44518831798008, 49.46550076348441, 40.23028870991298, 43.90638950892857, 41.52746180125645, 46.11755990982056, 48.56224536895752, 49.16986533573696, 48.09350946971348, 47.81142997741699, 42.72399718420846, 39.051141193934846, 38.678015981401714, 38.609843730926514, 39.390230655670166, 38.680222034454346, 38.12535973957607, 49.41125965118408, 53.93031937735421, 53.937055655888145, 51.078914165496826, 50.59635482515608, 46.57874311719622, 50.72495208467756, 51.59498119354248, 51.7838054384504, 52.86204774039132, 51.742967401232036, 52.88332312447684, 52.693783215114046, 50.032741274152485, 48.601394993918284, 39.30959333692278, 40.73855291094099, 37.13018315179007, 40.25689336231777, 40.87929214750017, 41.395571095602854, 43.97010449000767, 49.8989189692906, 52.61855854306902, 52.904904229300364, 49.448991843632285, 47.82397147587368, 45.876645020076204, 47.70900658198765, 34.50884321757725, 23.870060307638987, 9.351221782820565, 18.118539537702286, 29.52465718133109, 16.51911285945347, 14.657627923148018, 11.01189683164869, 0.8202559596725872, 0.2641007570283753, 0.45196110223020824, 2.997670654739652, 30.609972749437603, 44.59981972830636, 25.007905994142803, 23.737676279885427, 38.28745079040527, 43.548553807394846, 59.4823955808367, 55.2440048626491, 29.88737051827567, 3.029189420597894, 0.09139857880238976, 0.16922489660126822, 0.16890146609927925, 0.11770897092563765, 0.12984689032392843, 0.14958441550178186, 0.12625448166259698, 0.0951075122824737, 0.1933623549661466, 0.08639951954994883, 0.1287937904042857, 0.19907640692378792, 0.10779507897262063, 0.05378648365980812, 0.11161746350782258, 0.13887169105666025, 0.16424592877072947, 0.1361936219036579], [0.054840197653642724, 0.004417313861527613, 0.037648803887090514, 0.02521121289048876, 0.017024401209450195, 0.025322957430034876, 0.0744291100917118, 0.011099592034172798, 0.02654276492207178, 0.04484871182856815, 0.04230628861114383, 0.03746893782434719, 0.04480886146692293, 0.03681243144507919, 0.04708153648035867, 0.01802684848995081, 0.03519082435273698, 0.026278019217508178, 1.0549481404679162, 12.890734893935067, 36.6544816834586, 44.311340945107595, 39.90300076348441, 29.139615808214458, 20.18931290081569, 29.655988556998118, 38.195071016039165, 23.12799964632307, 2.282373368740082, 0.10498705679284674, 0.08114089351147413, 0.6241268781679017, 3.6348432643072943, 6.287483964647565, 6.0374447873660495, 1.7615638694592883, 3.36885558281626, 16.814803872789653, 29.40464094706944, 47.21595893587385, 50.91149384634835, 49.52870157786778, 51.01270825522286, 47.67497083118984, 45.07920374189104, 48.70441593442644, 45.867042609623496, 45.382013184683665, 45.86336006437029, 48.23902211870466, 44.795178753989084, 43.426699774605886, 42.52371188572475, 43.63988440377371, 46.85001121248518, 46.86481434958321, 43.82096488135201, 42.87003789629255, 36.942321232386995, 31.737588950565883, 34.36044706617083, 37.07392011369978, 40.85871853147234, 45.055409635816304, 47.542187282017295, 45.61149828774588, 41.98825938361031, 34.48171745027815, 31.75692926134382, 33.064271041325156, 33.270708969661165, 33.78815521512713, 37.97048091888428, 49.1985752923148, 40.71331705365862, 35.50947414125715, 47.70778022493635, 46.82115534373692, 49.59526184626988, 44.97781910215105, 46.64056124005999, 43.3098588671003, 48.2190842628479, 44.30940934589931, 49.616502489362446, 42.43548713411604, 47.34099524361746, 26.72458699771336, 30.876870427812847, 53.07338067463466, 43.21566908700125, 45.34103618349348, 38.532958439418245, 39.10192557743618, 35.30232054846627, 38.27703891481672, 35.00662953513009, 41.780039242335725, 39.70097146715437, 41.65610769816807, 35.97601440974644, 34.97848585673741, 33.8584258215768, 35.33429268428257, 34.123718466077534, 36.27307769230434, 33.46710327693394, 35.804463386535645, 36.76926939828055, 41.38564906801496, 40.10547127042498, 41.010922295706614, 39.13435976845877, 39.51541634968349, 40.34106731414795, 42.00344467163086, 40.90835298810686, 43.74132810320173, 42.17410979952131, 42.03643124444144, 39.93145711081368, 35.826965127672466, 34.0046124458313, 36.63053124291556, 35.52010835920061, 38.36433955601284, 39.12398263386318, 42.73623643602644, 40.1979135785784, 44.12899936948504, 46.21930932998657, 49.71977009092058, 46.95938628060477, 46.283805983407156, 43.080158369881765, 45.290849345070974, 38.453801086970735, 25.0144807270595, 14.489319971629552, 10.543976477214269, 6.900721115725381, 4.16012794630868, 5.905497627598899, 23.342591285705566, 31.422095571245464, 2.4066282212734222, 0.03384786105847784, 0.3949584338281836, 15.965456077030726, 44.652059759412495, 32.91736875261579, 15.880274636404854, 16.805788585117885, 38.825269154139924, 44.776109422956196, 50.412175451006206, 30.351339953286306, 4.15031144448689, 0.02853914556492652, 0.08012800357703652, 0.007471700232209904, 0.011500605382025242, 0.01389025813633842, 0.058806038062487326, 0.04831367125734687, 0.04354766503508602, 0.05926891429615872, 0.0340313267494951, 0.02693267828518791, 0.061426336744001934, 0.013074749797981764, 0.05800778232514858, 0.025402824394404888, 0.03201206081679889, 0.06397699737655264, 0.014317533333918877, 0.03101767453231982, 0.044088572795901976, 0.028139656376359717, 0.03369650364454303, 0.03387793033782925, 0.05047157546505332, 0.011706813022361269, 0.012432183072503124, 0.04180006077513099, 0.0085844408354855, 0.04781098537413137, 0.006265045717425112, 0.015415703245837773, 0.023764800147286484, 0.04551795431013618, 0.016900532945458378, 0.02461072805869792, 0.09656052038605724, 1.3913094571658542, 17.738052708762034, 41.96954788480486, 50.934944016592844, 45.093603883470806, 32.121480396815706, 21.339941535677227, 28.776930264064244, 35.27059159960066, 27.981090545654297, 2.702592602797917, 0.09464598633348942, 0.1537547188677958, 1.030347066266196, 6.197401872703007, 8.659250685146876, 6.931588053703308, 4.02883391720908, 3.0954567790031433, 11.52740626675742, 32.88410425186157, 44.80572264535086, 53.01743377958025, 48.67417737415859, 52.18640143530709, 47.72330250058855, 46.66265303747994, 48.355647632053916, 46.94426352637154, 45.92329175131661, 46.63114643096924, 48.285707065037315, 47.049389771052766, 44.867714473179404, 45.06534555980137, 44.43751675742013, 48.0107182094029, 48.60803747177124, 46.42633785520281, 43.56317976542881, 38.14541571480887, 34.27133641924177, 36.12600864682879, 39.228827476501465, 43.37552629198347, 46.69862733568464, 49.709910597120015, 47.839823790958945, 44.17584759848458, 36.205395289829795, 34.58853210721697, 33.92701843806675, 34.212481703077046, 34.04114607402256, 40.425769329071045, 50.51093714577811, 44.91986417770386, 37.616762025015696, 47.47442497525896, 48.33849252973284, 50.90390988758632, 48.14357124056135, 48.51016167231968, 44.814460005079, 49.59315306799752, 45.40385832105364, 51.474666186741416, 42.592856884002686, 46.47152893883841, 28.106717450278147, 32.723604338509695, 55.17993899754116, 45.16297469820295, 47.638531003679546, 40.63398252214704, 40.700862407684326, 37.0712867464338, 40.19804559435163, 37.174238204956055, 42.04223646436419, 42.432277066367014, 42.87035403932844, 37.76890325546265, 35.98400483812605, 35.29925986698696, 36.831813607897075, 35.37147944314139, 36.79293496268136, 34.32499040876116, 37.7275128364563, 39.61934750420706, 43.30575942993164, 43.061988830566406, 43.10523441859654, 41.226504053388325, 42.556170395442415, 43.22340243203299, 44.52905927385603, 43.70972769601004, 43.79992921011788, 44.65594032832554, 44.9255165372576, 41.66873604910714, 37.25411122185843, 35.1687970161438, 39.256182534354075, 37.87605142593384, 41.1204571723938, 40.78394896643502, 43.55911159515381, 42.55121980394636, 45.429931436266216, 48.46968494142805, 50.30878278187343, 49.36513403483799, 44.68759284700666, 46.146113531930105, 48.55769429888044, 39.40252201897757, 27.131952932902745, 16.94058190073286, 11.510757514408656, 7.388127258845738, 8.590407933507647, 9.52285531588963, 9.649825828416006, 15.342982598713466, 1.852758216006415, 0.017326619010418653, 0.704369669514043, 18.723513977868215, 46.29723685128348, 31.212902682168142, 18.79283962930952, 20.433335372379847, 42.92843055725098, 48.75896276746477, 55.50446850912911, 35.43351296016148, 5.093888972486768, 0.013232252194679208, 0.03341041970998049, 0.014410457008385232, 0.016061056205736737, 0.05009195547817009, 0.0320192363246211, 0.006585773529617914, 0.04446722926305873, 0.039029032324573824, 0.11027723470968859, 0.01752597090256001, 0.0682256104690688, 0.019688139702858667, 0.025932108850351403, 0.013619617658800312, 0.017304590371038233, 0.033279906891818554, 0.035117522214672396, 0.1526342947036028, 0.07315121830574103, 0.10995780077895947, 0.1314731352031231, 0.09539878022457872, 0.09330435975321702, 0.23724491095968656, 0.08337101420121533, 0.11739411710628442, 0.09043602938098566, 0.11452229906405721, 0.14302285973514828, 0.1058705026017768, 0.19077735367630208, 0.07559092489204236, 0.08392207284591027, 0.1680315706346716, 0.3699960261583328, 1.858004323073796, 22.014153037752422, 50.89332430703299, 56.951740060533794, 50.298294476100374, 38.894000734601704, 29.435011523110525, 38.7241415977478, 48.516672134399414, 30.889001982552664, 3.7160433871405463, 0.28194378529276165, 0.15749588954661572, 1.1965923798935754, 9.335085460117885, 15.104040997368948, 14.332219464438301, 10.75632471697671, 9.050344807761055, 23.115362610135758, 35.55780233655657, 49.906297956194194, 52.600493226732524, 50.05403055463518, 51.74931458064488, 50.30106333323887, 46.9666679927281, 49.887475286211284, 45.51204524721418, 45.8824919291905, 46.08790847233364, 49.82269375664847, 47.84426368985857, 46.99129588263375, 47.157041685921804, 47.43071733202253, 49.28830780301775, 51.768515927451, 48.695327690669465, 46.61701379503523, 40.68364824567522, 35.08145815985543, 37.428295612335205, 41.49958215441023, 45.01411301749093, 49.48344448634556, 52.17518009458269, 49.734760829380576, 45.00694595064436, 36.47588171277727, 36.262248924800325, 36.413181168692454, 36.27444648742676, 37.16454546792166, 43.201043128967285, 53.02755730492728, 47.31892081669399, 39.69524615151541, 48.300826345171245, 50.75915111814226, 53.24060991832188, 50.97470160893032, 50.9362016405378, 47.00552579334804, 52.947514057159424, 48.05462040219988, 53.562408787863596, 44.91101912089756, 47.019008772713796, 30.275479521070206, 35.71768733433315, 54.490774972098215, 47.29906633922032, 48.91392844063895, 42.34631742749895, 43.27800137656075, 39.468564646584646, 42.20659262793404, 37.71565226146153, 43.479985509599956, 44.87853281838553, 45.25358963012695, 40.8403822353908, 38.083027839660645, 36.720635482243125, 38.83552816935948, 36.959952286311555, 39.63994196483067, 36.96932888031006, 40.052585056849885, 41.33081388473511, 44.43134675707136, 44.02174002783639, 45.86952659061977, 42.6905311856951, 44.57146412985665, 45.1374956539699, 45.47416366849627, 46.06535114560808, 46.253748076302664, 45.78788178307669, 46.80560180119106, 43.586112294878276, 39.6496763910566, 38.38975954055786, 41.239931447165354, 40.12711490903582, 42.98785849979946, 42.93066092899868, 47.32411112104143, 45.60918453761509, 48.75849028996059, 51.51776933670044, 53.14143827983311, 50.08538430077689, 45.98923710414341, 47.70493146351406, 50.90450395856585, 41.72044454302107, 27.860683475221904, 19.04745636667524, 15.970806189945765, 12.569457139287676, 11.319946084703718, 14.397455232483999, 33.40620926448277, 39.38475547518049, 3.7437384724617004, 0.1509285255202225, 1.0011678891522544, 22.315161160060338, 56.78930854797363, 43.64561319351196, 24.400758504867554, 26.97056017603193, 49.953358105250764, 57.26318958827427, 61.772035462515696, 43.164874281202046, 7.069623572485788, 0.18147571065596171, 0.14344560062246664, 0.08439547994307109, 0.1550644135900906, 0.1431255763662713, 0.15173401444086007, 0.11236771967794214, 0.13191350443022593, 0.18061798810958862, 0.1498453529285533, 0.15797983429261617, 0.219389248373253, 0.10609121647264276, 0.08319848988737379, 0.14036270390663827, 0.0911203319472926, 0.16163639165461063, 0.08612716237881354], [0.06416080572775432, 0.03574879726927195, 0.12425292549388749, 0.040028185317558904, 0.09435478624488626, 0.061907567349927764, 0.07833186031452247, 0.04912424919062427, 0.0176873044776065, 0.05657583934121898, 0.11926464816289288, 0.045264928601682186, 0.028736612826053585, 0.037753793610525985, 0.0301521318698568, 0.015688050238947784, 0.060607487468847206, 0.03267737797328404, 0.9642074895756585, 15.73933390208653, 38.73439366476876, 45.55762890407017, 38.621471541268484, 34.865403924669536, 18.024222952978953, 28.86574908665248, 35.63063335418701, 19.000785316739762, 0.8904510587453842, 0.08429394396288054, 0.09203155019453593, 0.3917489903313773, 3.524048809494291, 3.9378793920789446, 2.709405528647559, 3.312900653907231, 6.546134999820164, 20.19852273804801, 39.22800064086914, 46.9378399167742, 52.421188013894216, 53.09645216805594, 48.88342932292393, 46.108169419424875, 48.06784977231707, 45.360421657562256, 46.03734990528652, 45.87516852787563, 46.191544328417095, 46.83432218006679, 46.615700585501536, 43.81268262863159, 41.86578696114676, 41.579885959625244, 43.61358199800764, 44.83461672919137, 47.68972185679844, 45.485610825674875, 43.29300948551723, 35.34817518506731, 33.113662311008994, 33.1860625403268, 33.56091785430908, 36.16667992728097, 37.2798091343471, 35.982149669102256, 33.797517912728445, 32.84407567977905, 36.09474522726876, 32.24593652997698, 34.473431723458425, 32.8550260407584, 37.565498215811594, 47.96518666403634, 48.25123357772827, 47.52187769753592, 47.334324972970144, 46.05712447847639, 46.649055412837434, 43.4621216910226, 42.85867759159633, 41.959500789642334, 44.02893836157662, 42.18631778444563, 46.80798155920846, 44.15087924684797, 48.96395199639456, 24.901562077658518, 27.298061779567174, 51.73996925354004, 42.208413055964876, 46.50619002750942, 40.54031038284302, 43.26290988922119, 34.85300833838326, 35.53269154684884, 34.89699043546404, 36.99160133089338, 35.420363494328086, 38.13622324807303, 33.085511684417725, 34.01434339795794, 35.489376476832796, 35.40164157322475, 34.328415870666504, 35.41564219338553, 34.999552794865195, 35.05423859187535, 34.38604422977993, 35.263351576668875, 33.58432286126273, 36.3098475592477, 35.55606528690883, 36.14912877764021, 35.23096602303641, 35.20629644393921, 34.170160225459504, 35.595673492976594, 35.34283896854946, 35.658283710479736, 34.330173764910015, 36.0345321382795, 35.93788269587925, 38.99563203539167, 40.685614585876465, 44.00602320262364, 41.87841183798653, 42.61356598990304, 42.44803210667202, 43.607207025800435, 46.18920973369053, 49.0184953553336, 49.2054123197283, 48.79108081545149, 43.70229312351772, 43.31185647419521, 41.82291657584054, 28.50452961240496, 19.183548995426722, 13.382923568998065, 3.6287696702139716, 13.407455052648272, 5.805198209626334, 20.14566605431693, 66.11784880501884, 5.727201206343515, 0.055612109268882444, 0.2877667285501957, 13.5828640631267, 34.468175411224365, 27.840314831052506, 23.740304436002457, 26.342345748628887, 28.797637632914952, 45.31325728552682, 47.33211544581822, 39.03232547215053, 5.493657052516937, 0.128300848283938, 0.009350700254019882, 0.019601853797212243, 0.010753203299827874, 0.024266061106962816, 0.09022210764565639, 0.07403178034084183, 0.05231376411393285, 0.03707008136968527, 0.02178658388688096, 0.08537991890417677, 0.021242824582649127, 0.007489717033292566, 0.04757338955200144, 0.012623876848790263, 0.05333181769986238, 0.021056693945346133, 0.022714684085388268, 0.07124211931867258, 0.06226048698382718, 0.0731343159984265, 0.02513442138609077, 0.035338290368339846, 0.019554006900372248, 0.11233670384223972, 0.025816053917099322, 0.057874382340482304, 0.014621069189161062, 0.05771543551236391, 0.02856301303420748, 0.01754439143197877, 0.007253460469655693, 0.014270247924806816, 0.013117774855345488, 0.05460167223853724, 0.025808199874258468, 1.266639558332307, 18.678376742771693, 46.021695613861084, 50.04849978855678, 44.860530035836355, 36.47526332310268, 22.333771909986222, 27.707090071269445, 37.4562725339617, 20.81743700163705, 1.1892360832009996, 0.09748152989361968, 0.35595168120094706, 1.648764425090381, 5.013308107852936, 7.928532089505877, 8.496354511805944, 5.870754897594452, 7.933915206364222, 24.648666756493704, 40.578963211604524, 50.68640347889492, 50.33174310411726, 53.32151126861572, 50.13958024978638, 49.330413886478965, 48.69628306797573, 47.7144261768886, 46.95065239497593, 46.439598492213655, 46.506888321467805, 49.23721422467913, 47.785638264247346, 45.07476036889212, 43.45849125725882, 44.68521656308855, 45.554331983838765, 47.572877475193565, 50.205143451690674, 47.83410542351859, 45.51729808534895, 37.570146560668945, 35.546077251434326, 36.02486719403948, 35.575867652893066, 38.54320355824062, 41.46501834051949, 38.20563922609602, 34.72269139971052, 33.16555840628487, 37.925227301461355, 34.857941559382844, 34.974820681980674, 34.831993511744905, 39.194784777505056, 49.50866297313145, 49.55010550362723, 49.99457829339163, 48.75871958051409, 48.10565839494978, 47.74106557028634, 46.03103746686663, 45.5118020602635, 44.0305711882455, 45.67561279024397, 43.915432589394705, 47.86738382066999, 46.692036969321116, 48.63241522652762, 25.761848075049265, 28.77123100417001, 53.62738486698696, 45.004250049591064, 48.996882983616416, 41.79892444610596, 44.44220331736973, 37.09592158453805, 37.24601657049996, 36.960244110652376, 39.06906407220023, 38.16300507954189, 39.59539358956473, 34.797537394932334, 36.15006331035069, 35.90587581907, 36.47865056991577, 36.47658348083496, 37.028141907283235, 36.526092869894846, 36.23378562927246, 36.85970715114048, 36.6942913872855, 36.01734576906477, 37.16962112699236, 37.536385263715474, 38.55547407695225, 37.591936111450195, 37.73449925013951, 36.008809907095774, 37.886973994118826, 38.263166836329866, 38.09906775610787, 36.37116541181292, 38.89137431553432, 37.85426187515259, 39.8446741104126, 43.63307516915457, 45.595750195639475, 44.46304791314261, 43.93742363793509, 44.006544317517964, 46.11664622170584, 47.78868852342878, 51.187851497105186, 50.41547931943621, 48.64231293542044, 43.962510108947754, 45.59945705958775, 42.82530886786324, 29.145976884024485, 21.294505528041295, 12.676000816481453, 6.005931666919163, 4.244348364216941, 7.708627683775766, 23.548391716820852, 59.902831077575684, 8.067328436034066, 0.05487996319841061, 0.28901154175400734, 14.615434987204415, 40.514615944453645, 29.904435294015066, 21.86820786339896, 28.184671027319773, 36.07440784999302, 51.15691811697823, 53.524909360068186, 44.27689872469221, 7.365382330758231, 0.17837157579404966, 0.049736474374575276, 0.026134912789400135, 0.03577003202268055, 0.07475515973887273, 0.024227825658661977, 0.03358316794037819, 0.01652118606892015, 0.021583004721573422, 0.03763031380783234, 0.018858756171539426, 0.02440219558775425, 0.03245892023135509, 0.012595249456353486, 0.02907586337200233, 0.052025977056473494, 0.0367158351998244, 0.025319819205573628, 0.21153810966227735, 0.1327752981867109, 0.15570238578532422, 0.11354421797607626, 0.1898046601563692, 0.16257825254329614, 0.2599485298352582, 0.09805093612521887, 0.12209628336131573, 0.12440221676869051, 0.17972089696143353, 0.14378279181463377, 0.1294633009071861, 0.0972844697535038, 0.10643723540540252, 0.10679440945386887, 0.14066940173506737, 0.15059927318777355, 1.8960533099515098, 25.055919783455984, 52.97561257226126, 58.747804233006065, 50.30469724110195, 45.10143797738211, 26.303385462079728, 38.79647929327828, 45.86051825114659, 25.64409521647862, 1.2939434817859103, 0.31020286892141613, 0.43002224660345484, 2.260390571185521, 9.290352957589285, 14.469800744737897, 14.248168843133108, 7.579068967274257, 9.739824107715062, 23.639173405511038, 42.461466448647634, 48.36691066196987, 55.17863621030535, 53.557982785361155, 53.17594998223441, 48.445387090955464, 49.13522856576102, 46.79656914302281, 48.99229717254639, 47.33176108769008, 47.21817888532366, 49.30013711111886, 51.218121324266704, 47.24349464688982, 46.00837244306292, 46.21719707761492, 48.084577560424805, 48.78514357975551, 51.755220549447195, 48.63350261960711, 48.13270773206438, 38.283035210200715, 36.493266105651855, 37.8558669090271, 36.9104220526559, 39.93562602996826, 41.30065522875105, 38.920129435403005, 37.80191762106759, 35.737218720572336, 40.290856157030376, 36.42103263310024, 38.515045983450754, 36.97401891435896, 40.775284562792095, 51.98580346788679, 52.14769302095686, 50.03634738922119, 51.1956022126334, 51.079959869384766, 51.64650208609444, 48.069030966077534, 47.04820857729231, 46.8439940725054, 48.56457996368408, 46.12526546205793, 49.41721773147583, 48.23542642593384, 49.238308565957205, 27.866242034094675, 32.11806535720825, 54.45449842725481, 47.46220309393746, 50.49213532039097, 45.88601466587612, 48.918823446546284, 38.86977236611502, 39.20306008202689, 38.437038557870046, 40.85943419592721, 40.157690456935335, 42.22544309071132, 36.67393316541399, 36.89033828462873, 37.496158667973106, 39.28199856621878, 37.448146615709575, 38.17810698917934, 38.677793639046804, 38.68132332393101, 38.21437311172485, 39.5211694581168, 36.90033326830183, 39.514082295554026, 39.76456832885742, 39.4442355292184, 38.86119481495449, 39.588890075683594, 38.42723117555891, 39.13643727983747, 40.126468726566856, 40.10794135502407, 37.10826505933489, 39.74055882862636, 39.96173388617379, 42.6396530015128, 45.40810367039272, 47.485139097486226, 47.27644647870745, 46.484987599509104, 46.53779738289969, 47.09719337735857, 50.62235151018415, 54.16873638970511, 52.92861843109131, 49.80072702680315, 45.580554485321045, 45.76675925936018, 43.80181564603533, 32.18403502873012, 24.271509851728165, 19.838171788624354, 10.137435640607562, 23.260930844715663, 11.967099564416067, 25.240820033209665, 71.68210520063127, 7.588416031428745, 0.31746221653052736, 0.6267114994781358, 17.36428826195853, 45.00691468375069, 36.07285492760794, 35.53558547156197, 36.48522009168352, 40.66515908922468, 55.93064669200352, 59.35598700387137, 50.357131821768625, 10.21881902217865, 0.3019564428499767, 0.14254590389983995, 0.09713015053421259, 0.10163209467594113, 0.13692521836076463, 0.15289681990231785, 0.13020888875637734, 0.12881881477577345, 0.11030249656843287, 0.14198623464575835, 0.24250306880899838, 0.12706928008369037, 0.10848876567823545, 0.08309529149638754, 0.10505244042724371, 0.07796858623623848, 0.09488335823906319, 0.04311089204358203], [0.08361340048057692, 0.034918972690190585, 0.05197583671127047, 0.0851482670488102, 0.010175300961626428, 0.036041656375995705, 0.07262002038104193, 0.02903568052819797, 0.0760849051709686, 0.051141089360628805, 0.028824805415102413, 0.04861148027703166, 0.011292848137340375, 0.03888076224497386, 0.07702766172587872, 0.010105237131938338, 0.048823597109211345, 0.0357780421285757, 1.9736266902514865, 17.050651788711548, 36.94386373247419, 45.43007040023804, 38.03885119301932, 31.165863377707346, 20.154148067746842, 27.276086364473613, 32.3084842136928, 13.24875819683075, 0.41028073163969175, 0.013784215835455273, 0.07923356550080435, 1.611544879419463, 5.054834016731807, 6.907856047153473, 7.627890484673636, 4.8577883158411295, 9.737261090959821, 23.220382894788468, 42.073312282562256, 49.115117004939485, 56.36972073146275, 46.55204813820975, 44.63110399246216, 48.27482271194458, 48.36801889964512, 44.751960958753315, 46.719666481018066, 46.00249079295567, 47.31090954371861, 47.1672659601484, 46.512901987348286, 44.16689484460013, 43.121864931924, 40.20707477842058, 43.04019233158657, 43.1409273147583, 44.98233890533447, 45.48057338169643, 45.78806243624006, 42.6092198916844, 32.82752507073538, 32.41791486740112, 33.60106454576765, 32.58186108725411, 32.65372283118111, 33.16045495441982, 35.30113935470581, 32.47415358679635, 34.78216103145054, 33.28230898720877, 34.107407569885254, 32.54388223375593, 34.42632988521031, 44.35723727090018, 48.09627137865339, 45.80521753856114, 46.741591521671836, 42.091189997536794, 39.65448801858084, 35.69038438796997, 37.981625829424175, 37.17968211855207, 40.92225285938808, 40.1788581439427, 43.8500257219587, 41.37313536235264, 50.217268058231895, 27.045348848615372, 27.524840559278214, 53.5235892023359, 41.08891929898943, 46.315472398485454, 40.19582911900112, 41.55020325524466, 39.44262702124459, 37.40392827987671, 32.68666771480015, 36.030873911721365, 34.66735594613211, 34.46569837842669, 33.642760685511995, 34.65902158192226, 33.521587576184956, 34.72733627046858, 34.085232394082205, 35.42462968826294, 38.49266930988857, 38.697655064719065, 33.794860226767405, 35.088795457567485, 34.52813836506435, 35.13372598375593, 34.96843876157488, 37.19357851573399, 34.46708801814488, 34.4701452255249, 34.08744886943272, 33.992380142211914, 34.10388830729893, 36.018089226314, 37.52599423272269, 41.431962285723, 41.7560054234096, 43.9587094443185, 44.36748933792114, 42.21647644042969, 41.8446227482387, 43.53000559125628, 41.155020986284526, 42.55667066574097, 43.62584556852068, 48.567404406411306, 49.306397438049316, 45.674914496285574, 45.4249495778765, 46.0159980910165, 46.79243149076189, 36.61504718235561, 23.627159970147268, 13.603370802743093, 4.227239293711526, 4.944824056965964, 9.671086447579519, 1.663794789995466, 3.3392139162336076, 1.024649760552815, 0.050364913152796884, 0.11117368124957595, 6.576585914407458, 33.46906961713518, 40.99896444593157, 29.169670241219656, 25.360483646392822, 30.00488887514387, 40.764883109501426, 43.442427022116526, 39.237512724740164, 9.827161226953779, 0.30445999279618263, 0.0343543331670974, 0.056024763733148575, 0.04872766922094992, 0.022149664582684636, 0.019485245857919966, 0.03014798602089286, 0.04902805667370558, 0.023206338685538088, 0.02582166200902845, 0.06200303044170141, 0.017167733250451938, 0.05475256824865937, 0.048136088464941294, 0.02521537570282817, 0.06323997942464692, 0.042493225008781464, 0.019537659295435463, 0.025494567417938794, 0.024974422828693475, 0.036229742890489955, 0.012161221987168704, 0.031918185496968884, 0.07302070209490401, 0.05065208274338927, 0.022524410991796424, 0.04723467504871743, 0.03567027719691396, 0.028379426903224418, 0.05843952737216439, 0.027314074337482452, 0.04011327700157251, 0.026737823383882642, 0.01902392177310373, 0.04335882534672107, 0.03659542576809015, 2.618044751031058, 20.966522761753627, 42.52514321463448, 52.21201944351196, 42.74415390832083, 37.49141304833548, 23.088316747120448, 28.164715800966533, 36.70720114026751, 14.948946782520839, 0.5750400264348302, 0.03838506866512554, 0.049922199587204626, 1.7796985592160905, 6.498712241649628, 10.082262601171221, 6.901615696293967, 7.715780854225159, 11.352666020393372, 24.46979580606733, 41.781616483415874, 50.600527218409944, 53.92237063816616, 49.0380197933742, 47.008006300245015, 48.92319386345999, 48.828920704977854, 45.9324494770595, 47.065561703273225, 47.595445224217, 47.62819555827549, 47.789077622549875, 48.12206309182303, 46.18979338237217, 44.189208984375, 42.142915861947195, 45.98622506005423, 45.973794732775005, 47.66386760984148, 47.493754863739014, 48.04341295787266, 44.768852029527935, 35.82138572420393, 34.445364475250244, 35.452391215733115, 35.07700783865792, 34.790095874241416, 34.49890034539359, 36.89233589172363, 34.40215015411377, 37.38347625732422, 34.72828817367554, 35.47743252345494, 33.42291620799473, 36.774310316358296, 47.695332527160645, 50.78958075387137, 48.23644781112671, 49.41871159417288, 45.2924439566476, 41.99893181664603, 38.66038840157645, 39.533082144601, 39.533724852970664, 42.820313113076345, 41.62933281489781, 45.664891719818115, 43.31996502195086, 51.24238095964704, 28.119444813047135, 28.695872579302105, 54.60477406638009, 42.838552134377615, 48.79441247667585, 42.15567970275879, 44.01122740336827, 40.983327525002615, 39.152953147888184, 34.94432156426566, 38.08265611103603, 35.276970045907156, 35.8390827860151, 35.13270807266235, 36.55849926812308, 35.02858584267752, 36.58252613885062, 36.24840463910784, 36.876473154340474, 39.69852570125035, 40.204469203948975, 34.64451026916504, 36.98888805934361, 35.84079899106707, 35.5680787222726, 35.37609304700579, 37.60539129802159, 36.243058000292095, 35.97573300770351, 35.62805904660906, 35.858391829899375, 36.5873829296657, 36.72631563459124, 39.65516546794346, 41.92005239214216, 42.5733254977635, 46.50636373247419, 45.67284393310547, 44.52417121614729, 43.963666984013145, 45.99798836026873, 43.6329778943743, 44.505122729710166, 45.810539858681814, 49.42713281086513, 48.846534388405935, 46.271868978227886, 47.26863322939192, 46.58171694619315, 47.878181321280344, 37.488251617976594, 21.33605922971453, 17.674440213612147, 7.836487565721784, 8.05548870563507, 9.371099710464478, 3.505498856306076, 7.4478826352528165, 1.8186229105506624, 0.05434290612382548, 0.0470976856138025, 7.4175068480627875, 37.657881464277, 39.68656437737601, 30.6829149382455, 28.045264107840403, 31.60284948348999, 45.64556530543736, 47.73923819405692, 45.398073945726665, 12.242357662745885, 0.23720829721008027, 0.03359953759770308, 0.03463956893288663, 0.045629983834390125, 0.03677280839266522, 0.0383952297270298, 0.012969983991102448, 0.014604097332007118, 0.019534699186416607, 0.03109348046460322, 0.021006248259384717, 0.05764893229518618, 0.013362326509585338, 0.025504372248958265, 0.008925991615147462, 0.01627113064751029, 0.025071275220917802, 0.043282371413494856, 0.136662272470338, 0.1355412376246282, 0.13201362905757769, 0.13182822614908218, 0.06393458215253693, 0.10492069606802293, 0.2090994276638542, 0.11677458749285766, 0.14276382220642908, 0.1311809987361942, 0.09180995422814574, 0.11848126591316291, 0.21498179701822145, 0.08781993761658669, 0.2390979900956154, 0.13817525628421987, 0.1570065708032676, 0.13133457835231507, 3.629690957920892, 25.21369252886091, 51.001917702811106, 57.42522157941546, 49.87251928874424, 42.08172655105591, 27.833806106022426, 36.83168159212385, 43.935130732400076, 18.023738316127233, 0.713497702564512, 0.08939736868653979, 0.23492242129785673, 4.4290918452399115, 13.40981570311955, 17.651262760162354, 14.04966402053833, 11.122028384889875, 13.645031332969666, 24.997646978923253, 44.09287221091134, 50.29516083853585, 54.13711861201695, 50.03542675290789, 49.08937392915998, 49.33074392591204, 49.278500420706614, 45.36602190562657, 47.762879439762656, 47.79767254420689, 48.83375665119716, 48.28387968880789, 50.869696957724436, 47.95877695083618, 46.591044902801514, 43.193695408957346, 47.993285179138184, 47.81094012941633, 49.48769678388323, 50.71811853136335, 50.24988637651716, 47.62738609313965, 36.95653029850551, 35.53788185119629, 36.27718755177089, 36.850730078560964, 36.36147614887783, 35.975573199135916, 38.95032630647932, 35.21100732258388, 38.63646922792707, 37.05448947634016, 37.27891976492745, 35.174626554761616, 36.97468246732439, 48.05184459686279, 53.052852221897666, 51.041251455034526, 51.358756337847026, 46.80030379976545, 44.25317757470267, 38.17055777141026, 41.00021859577724, 41.52088533129011, 44.19711603437151, 43.66534955160958, 46.533788272312705, 43.994051456451416, 52.51388045719692, 31.44213765008109, 31.694082805088588, 56.7958641733442, 45.88942970548357, 50.72262443814959, 45.31923968451363, 45.8463647706168, 43.473725182669504, 39.462106295994346, 37.18109260286604, 39.35937717982701, 38.95755590711321, 38.68725708552769, 37.34296825953892, 38.49420486177717, 37.141234261649, 39.76682996749878, 36.79804883684431, 38.682890142713276, 41.948439257485525, 41.153794629233225, 37.31223290307181, 37.88555656160627, 37.67415761947632, 37.11245134898594, 38.597392559051514, 39.87284558159964, 38.65736940928868, 36.648975236075266, 37.85284096854073, 37.007630825042725, 38.27744191033499, 39.01607016154698, 41.33194644110543, 45.35632569449288, 47.26662867409842, 48.072581495557515, 48.70584031513759, 47.125965867723735, 45.988535336085725, 48.2527482850211, 45.42092309679304, 46.53550100326538, 48.760192598615376, 51.975586141858784, 51.5931190763201, 47.319115366254536, 48.67912449155535, 50.3452399798802, 50.0585503578186, 40.055183683122905, 28.21211814880371, 20.659870965140207, 9.019046647208077, 12.740139637674604, 18.881278038024902, 3.9576999970844815, 5.335505196026393, 2.3352873751095364, 0.2967764793762139, 0.43931519080485615, 8.671588948794774, 43.38392318998064, 51.02055971963065, 37.32989869798933, 36.351182392665315, 40.352913992745535, 52.614118644169395, 55.96656540461949, 53.706854888371055, 16.077716384615215, 0.5076562879340989, 0.12233975529670715, 0.05912412849387952, 0.13353330322674342, 0.1535051129758358, 0.1177761187510831, 0.15350241240646156, 0.13524602060871466, 0.14279073290526867, 0.08291715569794178, 0.1237488825406347, 0.09906867758503982, 0.12503340361373766, 0.2005446617092405, 0.1659090316721371, 0.11512179832373347, 0.09031385915087801, 0.16133276080446585], [0.06689342909625598, 0.025182965477662425, 0.09226540050336293, 0.05411787677024092, 0.01907950566549386, 0.031842905429324934, 0.060788690245577266, 0.016177073819562793, 0.01538413270775761, 0.03891552020130413, 0.006662830510841948, 0.050607272290757725, 0.0706763703908239, 0.008477787004916795, 0.07086352391966752, 0.04544301351000156, 0.014840688922309449, 0.025283576953890066, 1.7408684428249086, 14.542293906211853, 37.25398962838309, 41.30228458132063, 43.06041506358555, 24.765016078948975, 22.621594088418142, 26.31841615268162, 31.598503385271343, 8.370575615337916, 0.4379233797746045, 0.21943551089082444, 0.6644085166709763, 1.146983110478946, 3.558656701019832, 6.800807757037027, 4.359576855387006, 7.853723440851484, 12.899421879223414, 33.85133171081543, 41.91306250435965, 57.583331312452046, 46.79367521830967, 42.46263027191162, 44.09121853964669, 48.380282470158164, 46.79908439091274, 49.600910731724326, 45.85222905022757, 47.83503648212978, 44.73354128428868, 49.562125887189595, 49.37970093318394, 45.91363722937447, 43.41199738638741, 41.125821181706016, 40.99083505358015, 46.193621839795796, 45.80082975115095, 45.36548342023577, 47.35842827388218, 44.348541600363596, 44.107619762420654, 33.70576695033482, 33.38047661100115, 33.07546806335449, 35.34171683447701, 33.06352063587734, 33.43561404091971, 31.936877182551793, 33.296882833753315, 34.335774012974326, 34.31788240160261, 34.09563732147217, 34.845052650996614, 35.04299293245588, 40.84969629560198, 41.41702018465315, 41.36366844177246, 35.449803011757986, 35.08698892593384, 34.15226513998849, 37.91465561730521, 38.331717763628276, 41.27679858888899, 39.79868745803833, 46.2358842577253, 42.2794132232666, 47.79687697546822, 29.0156113079616, 27.514032636369976, 51.40509040015084, 39.98668834141323, 46.07135091509138, 38.54968622752598, 42.594031129564556, 38.14069788796561, 40.12662158693586, 33.97752489362444, 34.335440499441965, 35.14100422177996, 35.45508016858782, 32.506229945591514, 35.34125477927071, 34.47323022569929, 35.853660106658936, 35.30467251368931, 34.29368530000959, 34.538730893816265, 34.81015532357352, 34.816884653908865, 35.24459491457258, 34.02051339830671, 35.319083077566965, 34.880693435668945, 34.18677684238979, 34.07585232598441, 34.36760023662022, 33.19425794056484, 34.787233216421946, 33.967786993299214, 40.61313097817557, 43.21151059014456, 44.93147461754935, 45.24608904974801, 43.13298552376883, 41.48832259859358, 43.23197998319353, 42.21569129398891, 41.2252915927342, 41.858543464115684, 41.17116165161133, 43.92346470696585, 48.93273721422468, 47.087639604296, 47.846435001918245, 45.746741499219624, 46.958236353737966, 50.484224796295166, 40.94511938095093, 27.085813420159475, 17.676354442323955, 10.012413229261126, 2.703345396689006, 4.043053405625479, 2.3860576450824738, 1.708056009241513, 0.94614206467356, 0.10801721098167555, 0.06874599933092083, 3.409950703382492, 26.878008433750697, 32.91071932656424, 31.88196209498814, 29.80403729847499, 27.728709391185216, 41.550363063812256, 44.78068133762905, 40.53230605806623, 14.282915915761675, 0.33340966222541674, 0.09411075112542935, 0.03837709927133151, 0.07953342369624547, 0.009308076380485935, 0.04642977984622121, 0.08753026423177548, 0.06157119718513318, 0.04931552142703107, 0.04762301421059029, 0.017035366335351552, 0.03823403016264949, 0.027294264507613013, 0.051135718755956204, 0.01477244695914643, 0.05836004378007991, 0.007452276319132319, 0.04897060511367662, 0.050155293329485824, 0.03599425731226802, 0.05524038403694119, 0.06616822443902493, 0.07820989364492041, 0.049693109201533456, 0.05005310595567737, 0.03328709936301623, 0.012694072144638215, 0.008588430621395153, 0.08527193005595889, 0.029077152588537762, 0.050928219354578426, 0.02006104728206992, 0.020591098482587507, 0.02370869887194463, 0.03992687325392451, 0.03096429757507784, 2.2733830511569977, 17.492899417877197, 44.78427355630057, 47.53893205097744, 49.60138668332781, 29.101315600531443, 23.59707600729806, 32.11901031221662, 36.44816187449864, 9.799795746803284, 0.5751115711671966, 0.16546688468328544, 1.7690485992601939, 3.521978897707803, 4.575755289622715, 8.591559597424098, 11.278780613626752, 11.705616269792829, 13.177127480506897, 32.97247838973999, 43.93424136298043, 55.05799116407122, 49.377981254032676, 46.2218975339617, 45.8821063041687, 48.854396275111604, 47.58402238573347, 48.470907824380056, 45.468254225594656, 48.39875773021153, 45.921613761356895, 49.68065520695278, 48.97849110194615, 48.50785834448678, 44.564411708286826, 43.468913555145264, 43.50163957050869, 46.374691895076204, 47.33345297404698, 47.089213371276855, 49.04541615077427, 47.28373513902937, 44.42326600211007, 34.99902820587158, 34.92807667595999, 34.74096516200474, 36.92603465488979, 35.14449569157192, 34.9619699886867, 33.3949670791626, 36.07823978151594, 34.75010551725115, 35.0883264541626, 36.08767543520246, 36.04165404183524, 38.539844104221885, 44.76678841454642, 44.04918541227068, 44.01279422215053, 38.68314375196184, 37.720582008361816, 36.102753026144846, 39.082362924303325, 41.125744751521516, 42.6623284476144, 42.03081015178135, 47.81146819250924, 44.86700575692313, 50.67897238050188, 29.82706015450614, 29.31944908414568, 53.97079610824585, 42.757678576878135, 47.83127055849348, 40.669751848493306, 43.479704107557026, 38.68681934901646, 40.32366207667759, 35.615910121372764, 35.678047861371724, 37.322151456560405, 37.19357851573399, 34.61278479439871, 36.70617280687605, 35.93685783658709, 36.68548801967076, 37.214256354740684, 36.85104274749756, 36.57633876800537, 38.11663627624512, 36.39113106046404, 36.67527069364275, 37.3217727797372, 36.90286588668823, 35.82115990774972, 36.52466154098511, 35.73230634416853, 36.064454555511475, 34.86834301267351, 35.79389517647879, 35.066929476601736, 41.81097609656197, 45.097255161830354, 46.3232786996024, 46.983909947531565, 45.87577649525234, 45.420388085501536, 45.183471884046284, 45.314038957868306, 43.532937731061665, 43.29727220535278, 42.859605176108225, 46.45558977127075, 50.00446905408587, 49.51667077200753, 49.19198145185198, 46.71451786586216, 47.30423927307129, 52.74733992985317, 40.7968760899135, 27.75394003731864, 17.91215545790536, 8.370374986103602, 8.878547992025103, 7.832815442766462, 6.952025311333792, 4.104617050715855, 1.0192307084798813, 0.13079048826226167, 0.05425271524914673, 3.9009336488587514, 30.885896137782506, 41.75368472508022, 36.87646273204258, 35.127667154584614, 35.13997936248779, 46.28868014471871, 51.05228519439697, 47.51311254501343, 16.946044921875, 0.3714342218424593, 0.04981923529079982, 0.021385990382571305, 0.013525252945588102, 0.0665525398882372, 0.020232448620455604, 0.10201722436717578, 0.044325954879501035, 0.027282220511032, 0.015273663814046552, 0.067595963898514, 0.007845437320481454, 0.06184386648237705, 0.018458437473912324, 0.037696579537753544, 0.01901807789025562, 0.02551611090478088, 0.06009148194321564, 0.1567424035498074, 0.10350340604782104, 0.21414937025734357, 0.192671769165567, 0.10064684147281305, 0.17012240844113485, 0.19441507490617888, 0.129893193553601, 0.057633651686566215, 0.224525921312826, 0.18279417205069745, 0.07460027055016585, 0.10505628093544926, 0.13044621316449984, 0.12367944126682621, 0.08602154840316091, 0.09063244491283383, 0.10981212609580585, 2.450418157236917, 23.17571813719613, 52.11141300201416, 56.79821266446795, 55.33525902884347, 34.78161212376186, 30.129911286490305, 35.0589633669172, 42.106583731515066, 11.61942994594574, 0.6513817299689565, 0.4820767119526863, 1.211116177695138, 3.4257730543613434, 8.978050538471766, 11.033053227833339, 10.340870210102626, 11.047787751470294, 16.40863823890686, 35.89775684901646, 43.09761919294085, 54.670552662440706, 49.77430650166103, 48.09950229099819, 46.007264205387656, 48.155049664633616, 47.02060685838972, 49.25344869068691, 45.597018241882324, 49.42170279366629, 44.62148073741368, 51.467488697596956, 51.18110479627337, 50.0627818107605, 48.101864678519114, 45.015568665095735, 46.92660467965262, 50.2729891368321, 48.97005251475743, 50.61133861541748, 51.48880924497332, 49.855242592947825, 49.1502297265189, 37.77367319379534, 37.23625782557896, 36.980866364070344, 38.79002094268799, 36.93321909223284, 36.957697595868794, 34.717782497406006, 37.24873679024832, 37.282647473471506, 37.36709240504673, 38.59091336386544, 37.72649145126343, 40.0418952533177, 44.47794485092163, 44.974424907139365, 45.709867409297395, 41.40780687332153, 38.39396667480469, 38.16100399834769, 40.12560020174299, 43.49345459256853, 45.04456697191511, 44.62414537157331, 49.12375708988735, 46.72871650968279, 51.71711662837437, 31.278868879590714, 32.739074502672466, 53.972373349326, 45.49705103465489, 49.70291723523821, 42.681265762874055, 45.57303306034633, 41.480679580143516, 44.27460234505789, 37.83898973464966, 38.03135756083897, 39.71326283046177, 38.335900579180034, 36.63760450908116, 37.91379404067993, 37.91284908567156, 38.61936623709542, 39.775994641440256, 37.86825902121407, 37.50865152903965, 38.311435971941265, 37.92478609085083, 39.72373723983765, 38.14277539934431, 38.3134057862418, 38.11344357899257, 37.98662158421108, 37.23420115879604, 37.93636873790196, 37.39146668570382, 39.00455699648176, 37.19444009235927, 45.06963954653059, 48.34301233291626, 48.86941480636597, 50.43812002454485, 46.55953482219151, 46.7375476700919, 47.32603577205113, 47.102348940713064, 45.286777700696675, 45.53776053019932, 44.90548140662057, 49.01324946539742, 52.38167708260672, 52.45157596043178, 49.3924890926906, 47.23294380732945, 50.007536683763774, 54.615929399217876, 44.49309539794922, 30.51613732746669, 20.871605157852173, 19.102797031402588, 8.183359878403799, 10.059423872402736, 8.707254920686994, 5.7445456470761975, 2.3469156197139194, 0.18396368143813951, 0.29539921613676207, 4.7499184012413025, 35.72385733468192, 44.26011882509504, 41.68333421434675, 40.331614289964946, 39.65073251724243, 52.45219782420567, 56.734035628182546, 53.84235518319266, 21.898785148348125, 0.6528181071792329, 0.15869127825966903, 0.1060846686097128, 0.13446585461497307, 0.16780850903264113, 0.14235014654695988, 0.24293695124132292, 0.1509961076080799, 0.15684554087264196, 0.17600423496748718, 0.1448263515319143, 0.08399534105722394, 0.2035239189863205, 0.11293072732431547, 0.15625103563070297, 0.1671612137662513, 0.05258139528866325, 0.19844511151313782], [0.04513209858643157, 0.03601777872868946, 0.0545048011865999, 0.06440024037978478, 0.07603590137192182, 0.06431434463177409, 0.050006477029195855, 0.03025541507772037, 0.02177661790379456, 0.04176622223375099, 0.08126299588807992, 0.03471166327861803, 0.02288847217070205, 0.029944646039179394, 0.04508404473641089, 0.015390804403328469, 0.03227544096963746, 0.07754896661000592, 1.368012581552778, 14.83710857800075, 37.06267098018101, 37.8109815461295, 31.567014149257115, 25.252670185906545, 23.565169879368373, 25.512600558144705, 31.318574360438756, 5.867481861795698, 0.29277279706937925, 0.197645580129964, 0.14694081592772687, 2.041385522910527, 5.601312441485269, 10.9473089831216, 10.13214806147984, 12.028300166130066, 16.897798367909022, 33.5417651448931, 49.055966990334646, 55.780440534864155, 39.63491841724941, 40.37250791277204, 47.60722936902727, 48.63555581229073, 49.059232643672395, 48.839940547943115, 46.58009106772286, 44.48023080825806, 43.28363636561802, 42.49456071853638, 48.95755965369088, 45.952161516462056, 43.6751708303179, 42.67086778368269, 40.75524943215506, 42.44411679676601, 47.34218685967581, 44.16836091450283, 44.843121324266704, 46.269854000636506, 43.554487568991526, 41.69564642224993, 35.38701214109148, 35.12315777369908, 34.62438481194632, 32.95484733581543, 33.46833658218384, 35.04346193586077, 34.569705963134766, 33.23804896218436, 33.43459265572684, 33.93052380425589, 33.30848979949951, 33.56023693084717, 33.90169225420271, 33.53059591565813, 34.727864333561485, 33.056141648973735, 35.552980286734446, 37.79981926509312, 41.32761076518467, 39.942831311907085, 41.286494800022666, 39.490903105054585, 43.8100596836635, 43.4952507019043, 50.88773100716727, 28.63664960861206, 25.67895953995841, 53.091185433524, 41.37941653387887, 44.29255301611764, 37.87174006870815, 37.737566879817415, 33.57290349687849, 35.465321813310894, 33.43858092171805, 34.72750997543335, 35.39141729899815, 37.039342403411865, 34.138664041246685, 35.25097336087908, 34.349177088056294, 36.89623383113316, 35.93734768458775, 37.55829988207136, 34.315742356436594, 34.3909044946943, 35.225869519369944, 35.578549657549175, 34.8721992628915, 37.40943125316075, 37.421538489205496, 36.99476970945086, 34.725123269217356, 34.3700008392334, 33.56954056876046, 33.221143995012554, 38.665179184504915, 45.59547574179513, 45.907095500401084, 47.26712547029768, 44.82216903141567, 43.389346258980886, 44.36645058223179, 44.1660749571664, 40.60248981203352, 39.604301180158345, 38.51008496965681, 39.53684459413801, 43.33659553527832, 47.784721102033345, 48.31212411608015, 47.32553897585188, 45.56915943963187, 46.83025400979178, 50.206071036202566, 46.07747575214931, 31.477358068738663, 27.4232439994812, 6.413491717406681, 11.358518140656606, 9.716926319258553, 6.408418229648045, 7.739039949008396, 0.6316746303013393, 0.04339784789564354, 0.03143668347703559, 1.5239602306059428, 21.284889221191406, 34.38464764186314, 35.77069514138358, 32.25693205424717, 24.250859805515834, 30.44857999256679, 42.21584415435791, 40.33410174506051, 18.522280250276836, 0.4484526962041855, 0.0773366122905697, 0.06399538567555801, 0.04689284606969782, 0.03827867776687656, 0.020808909919911196, 0.02666405475299273, 0.04127616388723254, 0.014542077534965106, 0.011507247391689037, 0.04437474494001695, 0.019057583895378878, 0.05796957401824849, 0.013957359312501336, 0.03451407388118761, 0.03886709315702319, 0.04591217637062073, 0.04627693983327065, 0.05401276830317719, 0.020572204674993242, 0.025782205197694044, 0.09171314763703517, 0.06198461500129529, 0.020253856400293962, 0.01787976415029594, 0.029160687034683566, 0.014430926713560308, 0.01635593395414097, 0.09386370331048965, 0.05946739935981376, 0.03655937859522445, 0.04093871485175831, 0.07520339997219187, 0.027078264758789113, 0.01278920445059027, 0.006702178332488984, 1.5765213987657, 18.66216833250863, 43.10847922733852, 46.57119042532784, 37.621726512908936, 28.120252541133336, 25.726485218320573, 30.937163421085902, 35.63804708208357, 6.946964417185102, 0.28845948566283497, 0.24143871877874645, 0.6047957954662186, 4.49553963967732, 5.938634020941598, 4.734757431915828, 9.3146299634661, 9.362859146935598, 17.75456510271345, 34.889705249241416, 48.42781162261963, 54.23128407342093, 44.0414069039481, 43.921282972608296, 48.46291739600045, 47.36439677647182, 49.419295242854524, 49.528597354888916, 47.82170288903372, 45.303137234279085, 45.18762690680367, 44.648071493421284, 49.260542801448274, 48.32319607053484, 45.17155919756208, 42.889617919921875, 42.1023314339774, 43.878662722451345, 47.97438260487148, 45.05142831802368, 46.39407042094639, 47.91671255656651, 45.56937483378819, 43.562846251896445, 37.77023383549282, 36.44131442478725, 36.11701420375279, 34.48931877953665, 35.6962035042899, 35.92419127055577, 36.04701457704817, 35.21179246902466, 34.774625710078645, 35.86765725272042, 35.22108915873936, 36.083767073495046, 35.92250633239746, 34.836607115609304, 36.194566522325786, 34.92401892798287, 37.09206880841936, 39.355395862034385, 43.13329471860613, 41.76970379693167, 43.14242465155465, 41.54279300144741, 45.88192565100533, 45.80038506644112, 51.14856290817261, 29.935587542397634, 27.400318418230327, 55.035538060324534, 43.659704140254426, 46.29953670501709, 39.77367394311087, 40.584205627441406, 36.43339695249285, 36.926903179713655, 34.76815346309117, 36.079837867191856, 36.89546605518886, 39.198050430842805, 36.330139773232595, 37.04659284864153, 36.28142595291138, 37.46182761873518, 37.52508749280657, 38.71944808959961, 36.425215448652, 36.15534394127982, 35.85942363739014, 36.57122489384243, 37.37201867784773, 39.03221777507237, 39.42259536470686, 38.657633440835134, 36.053917612348286, 36.2132363319397, 35.818269457135884, 34.26713275909424, 40.704565797533306, 47.86916255950928, 48.348178318568635, 47.56458132607596, 46.228324617658345, 45.671801703316824, 45.87725993565151, 45.19170549937657, 42.64531230926514, 41.01283999851772, 39.70520639419556, 40.664637974330354, 45.591299874441965, 50.926102433885845, 51.47711542674473, 46.664664540972026, 45.31238528660366, 48.709793840135845, 52.247246810368125, 47.790192808423726, 32.40991054262434, 22.250487327575684, 13.432499834469386, 8.160902432032994, 8.539183207920619, 8.339811597551618, 3.5151218942233493, 1.1176268628665378, 0.11170514380293232, 0.06416246813855, 1.9115738485540663, 24.663791247776576, 36.053855078560964, 35.56330530984061, 32.95646626608712, 28.13648874419076, 35.23736183983939, 47.33449520383562, 46.2636388369969, 22.442756141935075, 0.7152546740003994, 0.06813807266631297, 0.05719100258180073, 0.07377903961709567, 0.03129444557375141, 0.046152659359255006, 0.016970824084377716, 0.08581675296383244, 0.03104757417791656, 0.024524725441421782, 0.055422682647726366, 0.06325122953525611, 0.0996358310803771, 0.04728786201615419, 0.028153905611751334, 0.005191895512065717, 0.01819482322649232, 0.003741091375039624, 0.17118753200130804, 0.10845309509230511, 0.09318980947136879, 0.18645368782537325, 0.12614184484950133, 0.26446773590786116, 0.08960428115512643, 0.11133944735463176, 0.08105758298188448, 0.08263105819267885, 0.19813683948346547, 0.17581710858004435, 0.12406522913702897, 0.07928199254508529, 0.12666827945836953, 0.08072172171835389, 0.10073294756667954, 0.10582123417407274, 2.252571676458631, 22.731987067631312, 51.681121485573904, 54.22546148300171, 44.99872970581055, 34.98849473680769, 32.67299018587385, 33.97430787767683, 42.161808013916016, 8.966832671846662, 0.5416247280580657, 0.37621536957366125, 0.6010691725781986, 4.631839845861707, 12.268971000398908, 17.493644612176077, 15.94586910520281, 16.809361696243286, 19.12700629234314, 37.09146778924124, 50.37613861901419, 54.87058435167585, 45.66498899459839, 44.277777671813965, 48.383412633623394, 48.33518866130284, 50.56971890585763, 50.723479066576274, 48.89916351863316, 47.525688784463064, 45.64012139184134, 44.6522091456822, 50.99757507869175, 50.15976129259382, 46.821238722120015, 45.31231580461775, 44.273146697453086, 45.87587724413191, 50.90364238194057, 47.40715946469988, 48.167869091033936, 50.368287154606406, 46.299599238804404, 46.593584469386506, 39.04980713980538, 39.240531717027935, 37.82474940163748, 36.51480552128383, 37.45685270854405, 38.462350845336914, 38.31138733455113, 36.95206608091082, 36.78531973702567, 38.16054194314139, 36.971152782440186, 38.04588624409267, 37.18570620673043, 37.102223600660054, 37.56749929700579, 36.9167240687779, 39.05985076086861, 41.50284085954939, 45.29731464385986, 45.11853402001517, 44.12299960000174, 43.73906993865967, 47.93224178041731, 48.96766233444214, 53.77478742599487, 31.87765073776245, 30.701119218553814, 57.87891810280936, 47.940041133335654, 47.778992312295095, 41.16553708485195, 42.845576763153076, 37.93793208258492, 40.0863915170942, 37.03039312362671, 38.37404618944441, 39.509843894413535, 40.6958075932094, 37.89022922515869, 39.53700787680489, 38.1903531891959, 40.84323794501168, 38.84309128352574, 41.172103132520405, 37.98418276650565, 38.1969678742545, 38.63346413203648, 38.80072464261736, 39.1980539049421, 40.85994141442435, 43.06196103777204, 40.52278355189732, 37.76383107049124, 37.30291884286063, 36.7791497366769, 35.626040594918386, 43.079275948660715, 50.620996611458914, 50.72462204524449, 49.68871511731829, 49.52004412242344, 47.56897953578404, 47.38950061798096, 49.20031929016113, 45.44189970833914, 43.006413664136616, 42.20818376541138, 42.525730337415425, 46.86008957454136, 53.82424470356533, 53.793002128601074, 48.16445057732718, 45.74178048542568, 50.22756181444441, 53.10983787264143, 49.69184875488281, 34.290461335863384, 32.49557140895298, 11.811259286744253, 17.62477101598467, 19.28503785814558, 15.51774195262364, 15.456081901277814, 2.597511087145124, 0.26221280119248797, 0.2514384521969727, 2.060741032872881, 28.755944967269897, 43.0486170223781, 45.557264123644146, 41.79439769472395, 35.27591044562203, 42.87510660716465, 54.05520282472883, 53.84944929395403, 27.86845850944519, 1.2985760846308299, 0.18118755040424211, 0.2003183024270194, 0.18258578037577017, 0.09279627951660327, 0.18894967889147146, 0.11160362139344215, 0.15232680977455207, 0.1014175894004958, 0.09466822192605052, 0.15765299754483358, 0.209111682006291, 0.16617081048233168, 0.10875704485390868, 0.14725927955337934, 0.08447555386062179, 0.11567628357027258, 0.11348150776965277], [0.02954508051542299, 0.0005460322905232065, 0.06908165024859564, 0.0481053610066218, 0.021952682474095906, 0.02234137786685356, 0.05001425982585975, 0.05656663840636611, 0.036589841424886665, 0.02361949356938047, 0.09042698450918708, 0.05796573351004294, 0.01404251206466662, 0.031609489382909875, 0.059339054461036406, 0.035952564728047164, 0.05669870167704565, 0.035499561178897104, 2.335462817123958, 15.86315427507673, 39.89366933277675, 40.608809198652, 36.55234316417149, 20.169305562973022, 21.132709775652202, 33.89661659513201, 28.62389097894941, 3.46369588800839, 0.22006173085953507, 0.8280620436583246, 22.49152033669608, 8.444804957934789, 10.93666694845472, 9.554020592144557, 12.135549085480825, 14.309285197939191, 23.496248960494995, 38.04676171711513, 50.23808833530971, 41.85616718019758, 33.037120955330984, 48.30837903703962, 46.30827406474522, 51.91046067646572, 47.858201776232036, 48.325016498565674, 44.55517060416085, 47.99750968388149, 45.220592635018484, 45.55323764256069, 42.89279324667794, 47.41083853585379, 44.9203644480024, 43.25492640904018, 42.22512347357613, 45.18382971627371, 46.54223380770002, 46.27611780166626, 42.21162659781319, 46.62045662743704, 46.414852482931956, 43.77498517717634, 42.80092069080898, 44.35851573944092, 40.889050892421174, 37.46486745561872, 33.96883617128645, 32.21321398871285, 36.16644368852888, 31.985980101994105, 33.99366555895124, 33.4383863721575, 32.052210330963135, 34.60707337515694, 33.504845891680034, 34.004994596753804, 35.16645547321865, 35.1404309953962, 38.68001011439732, 41.726169858660015, 43.51967361995152, 41.95374420710972, 43.31421538761684, 39.659285749707905, 42.01327289853777, 41.67398541314261, 49.9486437525068, 34.16954183578491, 26.75334906578064, 52.22310529436384, 40.992867401668, 46.246389933994834, 37.06875760214669, 37.07481990541731, 33.99975912911551, 33.99159499577114, 31.85744537625994, 34.93516036442348, 33.292877197265625, 34.87235559735979, 34.1343492099217, 36.35597317559378, 33.879058497292654, 36.94207457133702, 35.33146129335676, 36.39475802012852, 35.567797320229666, 35.90598004204886, 35.97844280515398, 39.13004493713379, 41.04472180775234, 42.99233661379133, 43.008411271231516, 42.25331231525966, 41.29124736785889, 37.98755611692156, 36.42994717189244, 38.26412221363613, 43.14299440383911, 46.48039831433977, 44.82430560248238, 44.81745120457241, 46.29557623182024, 45.13939251218523, 42.91594464438302, 39.71926259994507, 38.80884708677019, 37.32926293781826, 36.44861350740705, 38.4442264693124, 44.55594185420445, 45.93578461238316, 48.06468139375959, 48.11052213396345, 47.198904582432334, 48.084449018750874, 48.37386580875942, 49.923157760075156, 40.88858188901629, 25.08966370991298, 15.970083577292305, 11.180911762373787, 4.452029151575906, 4.414379903248378, 1.9064367413520813, 0.9662058566297803, 0.1462486152138029, 0.03246523399970361, 0.6439206131867, 16.45171012197222, 48.88594109671456, 71.1521383013044, 50.73015628542219, 23.583789314542496, 31.780674730028423, 40.996199062892366, 45.82773665019444, 21.31562978880746, 0.8961381050092834, 0.04209014467362847, 0.019472068707857813, 0.048747095678533824, 0.011398745401363288, 0.04495975408436997, 0.07510947036956038, 0.055846594007951875, 0.029513542207756212, 0.06142282871795552, 0.04329551463680608, 0.018491203929962854, 0.04123031188334737, 0.024523985838251453, 0.05928989459893533, 0.050987353681453636, 0.04590298900646823, 0.07784251442977361, 0.0316423101217619, 0.06365946334387575, 0.013172234924110984, 0.028679968722696816, 0.016873579838180115, 0.02570292686245271, 0.006699850109206247, 0.03980592777952552, 0.05093578502003636, 0.029890346274312054, 0.007297506722222481, 0.036257162490593534, 0.0960405318598662, 0.008848452025891414, 0.03163250529074243, 0.03493347976888929, 0.07100721049521651, 0.020197556653459157, 2.4019119143486023, 19.21154155050005, 45.84503419058663, 47.85011059897286, 41.72018051147461, 25.617704221180507, 22.623668125697545, 30.150915690830775, 33.19165931429182, 4.096847661903926, 0.13956879079341888, 1.0777531053338731, 12.846914342471532, 5.95864439862115, 10.657892193113055, 9.14901009627751, 13.939973677907672, 12.990535344396319, 23.749561173575266, 39.417516231536865, 50.79196398598807, 45.673267773219514, 36.72692360196795, 48.945612226213726, 47.85167741775513, 51.06243651253836, 49.89013992037092, 49.6948538507734, 47.19476693017142, 50.14379780633109, 45.95645202909197, 46.697883878435405, 45.01196602412632, 48.44232293537685, 47.45338235582624, 44.21026202610561, 43.91273321424212, 47.10707718985421, 47.82529510770525, 47.31289325441633, 44.55843278339931, 48.63940511431013, 47.46222046443394, 45.837134088788716, 44.685338156563894, 44.03754023143223, 39.78428036825997, 38.72085509981428, 35.14974505560738, 33.807756083352224, 35.97561141422817, 34.30948550360543, 35.229635443006245, 35.1132287979126, 33.09288024902344, 37.31832299913679, 34.830440589359824, 34.15091718946184, 36.31160545349121, 36.91684218815395, 40.12903956004551, 42.880355971200125, 45.02553238187517, 42.91677148001534, 45.04873936516898, 41.22772693634033, 44.47094801494053, 44.42269972392491, 51.65919644492013, 35.14739656448364, 28.277745621544973, 53.10746853692191, 43.63483306339809, 48.43770238331386, 40.05194929667881, 37.98834473746163, 36.12869412558419, 35.75026396342686, 33.700514112200054, 36.706488949911936, 34.8436074256897, 38.49279090336391, 36.805504253932405, 37.26860169001988, 35.976309708186555, 39.013495853969026, 38.16390487125942, 38.48393889835903, 35.26439380645752, 37.57706696646554, 37.83966370991298, 39.517639773232595, 42.30107423237392, 43.969628538404194, 43.70436716079712, 43.960102558135986, 42.07585184914725, 38.64237519672939, 37.655828271593364, 39.79139184951782, 46.289156096322195, 49.24391923631941, 47.34334026064192, 47.37510742459978, 46.85809196744646, 46.601859773908345, 44.900259835379465, 42.66381883621216, 40.232904706682476, 39.06237990515572, 37.614882537296836, 40.99397563934326, 46.088599818093435, 48.03590542929513, 49.71679973602295, 48.57674625941685, 46.73128386906215, 50.36530637741089, 51.83981834139143, 49.05603994641985, 40.45632750647408, 23.61165506499154, 13.60627167565482, 7.977810450962611, 7.356948954718454, 10.390657527106148, 6.828229691301074, 2.86292793069567, 0.24170722865632602, 0.05281706407134022, 0.8172192711915288, 18.55967719214303, 40.430640016283306, 58.58235372815813, 52.66960348401751, 32.297012737819124, 36.54547486986433, 46.68518257141113, 50.72488955089024, 25.55380858693804, 1.2148207617657525, 0.01110251312742808, 0.04021794442087412, 0.058508961860622676, 0.05091294892398374, 0.15933516728026526, 0.04201833191992981, 0.09627939654248101, 0.05573180963152221, 0.01930901504653905, 0.028990948107093573, 0.05365784699097276, 0.02356953812497003, 0.006746576575096697, 0.04563294563974653, 0.0323166891134211, 0.0490706177827503, 0.0607558423653245, 0.1083219749853015, 0.1283777534429516, 0.10781288373150996, 0.2093582209199667, 0.22793809750250407, 0.08776156324893236, 0.088669517742736, 0.1042196743988565, 0.11844780056604318, 0.13512859333838734, 0.25136071922523634, 0.10166753455996513, 0.18183439783751965, 0.0965873021632433, 0.12972402120275156, 0.20967243691640242, 0.07640607615134545, 0.10483108873346023, 4.1232399599892755, 24.768782002585276, 55.23830386570522, 54.85096263885498, 52.147630487169536, 31.37493119921003, 31.632983820778982, 42.18462242398943, 38.14411987577166, 4.816466076033456, 0.35529713918055805, 1.3020479040486472, 27.95284264428275, 19.182781219482422, 18.126840897968837, 16.83452112334115, 19.811112029211863, 21.03933640888759, 26.356650352478027, 41.28222165788923, 50.371709142412456, 47.11268786021641, 41.622787611825125, 51.23241376876831, 47.05137695584978, 54.555612087249756, 51.460019384111675, 52.42797640391758, 48.89590828759329, 53.12923724310738, 48.87945147923061, 49.344720227377756, 45.376902784620015, 51.54780639920916, 48.85272523335048, 46.05352183750698, 46.01067924499512, 48.381897926330566, 49.85750423158918, 48.14825780051095, 44.838594572884695, 50.06227111816406, 49.62027883529663, 48.384444441114155, 46.57615838732038, 46.98360422679356, 43.66094439370291, 42.84497921807425, 37.504715374537874, 34.443839345659526, 38.91350085394723, 36.327551569257466, 37.28373486655099, 37.76893104825701, 34.54294497626168, 38.830167634146555, 36.98140484946114, 36.131459508623394, 39.41457714353289, 39.053329876491, 42.68444108963013, 45.5092624936785, 46.51326676777431, 46.2026093346732, 47.65873636518206, 44.92393234797886, 45.97517395019531, 47.78957789284842, 52.471079553876606, 37.99052994591849, 32.825819287981304, 55.35995292663574, 45.96197237287249, 50.45848866871425, 41.68905258178711, 39.63591200964791, 38.022686208997456, 36.53575086593628, 35.46627024241856, 38.407477446964805, 36.79767363412039, 39.34705454962594, 37.4524301801409, 39.29464776175362, 37.26920965739659, 40.75635766983032, 40.06969846997942, 40.651443345206125, 38.25433915002005, 39.750824792044504, 40.32922410964966, 42.320987769535606, 45.872865200042725, 46.247258458818706, 47.07330894470215, 45.53566564832415, 44.08382913044521, 41.19941650118147, 40.161824635096956, 42.000439575740266, 48.24267339706421, 50.293739931924, 48.71886818749564, 47.57684489658901, 47.74208000728062, 49.44081728799002, 48.128962653023855, 43.558208329336985, 43.74144969667707, 41.908195291246685, 40.41977998188564, 42.49375820159912, 49.542684827532085, 48.42169025966099, 50.53940044130598, 49.959343978336875, 47.33336264746529, 50.72694274357387, 52.545560768672395, 52.09045723506382, 42.241180760519846, 25.945341314588273, 20.300900970186504, 21.959642682756694, 11.175702350480215, 11.67760373864855, 8.669429796082632, 3.609168584857668, 0.4132950284651348, 0.22893611394933291, 1.0428694571767534, 22.577964612415858, 60.199998583112446, 76.23594066074916, 58.01694059371948, 35.172927720206125, 42.87003442219326, 53.0161657333374, 59.26192923954555, 31.232315949031285, 1.707205397742135, 0.17208736443093844, 0.14330266043543816, 0.10628915192293269, 0.09428417110549552, 0.22899221522467478, 0.1333846633455583, 0.18217551096209458, 0.12954343589288847, 0.10382516735366412, 0.12104169066463198, 0.14112311096063682, 0.1180980700467314, 0.07745962390410048, 0.09971474470304591, 0.11131020249532801, 0.27132172669683186, 0.41012732844267574], [0.04662381372015391, 0.018988941596554856, 0.02031556746390249, 0.020216452157390968, 0.020837878276194845, 0.02726746067803885, 0.0256716056859919, 0.03616958058306149, 0.03730917675420642, 0.018930411165846244, 0.0673883661095585, 0.0498965068587235, 0.016210734245500395, 0.058575322585446496, 0.026760542432644537, 0.031788615842482874, 0.05877519864588976, 0.0646158109552094, 3.1933738333838324, 21.28879063470023, 39.53549664361136, 44.00057234082903, 31.54961585998535, 16.737230709620885, 16.090402058192662, 31.143375532967703, 24.99826189449855, 2.1491664137159074, 0.025387769398678626, 0.47879271102803095, 4.294089215142386, 6.787054666451045, 5.305309193474906, 2.496071513210024, 9.214733106749398, 11.045746718134199, 27.18925298963274, 45.64585018157959, 50.45850951331002, 33.48176050186157, 38.151648248944966, 49.366884980882915, 49.2697491645813, 48.26693998064314, 44.94236939293997, 42.727228096553254, 44.38982432229178, 47.00933688027518, 46.89273568562099, 45.75525999069214, 41.309125082833425, 45.413293974740164, 46.31824472972325, 44.493897914886475, 46.18051406315395, 46.781408173697336, 46.134683745247976, 44.36835091454642, 44.918113231658936, 43.27190433229719, 46.27494355610439, 45.25040735517229, 48.666155678885325, 44.52582141331264, 48.063430718013215, 45.71342141287667, 38.149143423352925, 31.520836421421595, 33.81764336994716, 32.21903657913208, 33.4104129246303, 33.810493673597065, 33.97609009061541, 31.9703049659729, 32.34697723388672, 32.76138169424874, 35.003565379551475, 36.82119676045009, 42.51225083214896, 43.99187667029244, 43.364374433244976, 41.01438249860491, 42.00948960440499, 38.97644805908203, 43.4117819922311, 41.61221245356968, 48.83759205681937, 35.804591928209575, 25.85516585622515, 49.91291611535208, 45.015061446598594, 44.917606013161794, 38.28664479936872, 35.42148215430123, 32.616688932691304, 32.7976964541844, 32.741749559129985, 32.959363664899556, 33.86228901999337, 33.63931090491158, 33.76370103018624, 35.11839130946568, 34.10117850984846, 35.74261399677822, 36.74083389554705, 39.108981473105295, 40.53039877755301, 43.069722175598145, 45.17889996937343, 46.426410811288015, 45.391900471278596, 47.797377245766775, 45.78684302738735, 46.21724224090576, 43.87359748567854, 43.7566454069955, 42.4657986504691, 43.295688016074045, 44.59891993658883, 47.32553897585188, 46.44330188206264, 45.99008131027222, 44.86158616202218, 44.33281782695225, 41.13511439732143, 38.78820398875645, 35.6305638722011, 35.83030721119472, 35.29080738340105, 39.53569119317191, 45.69805199759347, 47.065888268607004, 49.24315840857369, 45.62648902620588, 46.66646065030779, 49.18718024662563, 50.5229366847447, 51.7870328766959, 41.26199892589024, 30.075701441083634, 25.578717878886632, 3.32709647502218, 6.544012759413038, 11.007862533841815, 1.175006932445935, 1.0542579889297485, 0.190114004271371, 0.09377789577203137, 0.29537628165313173, 12.252178941454206, 51.45228951317923, 65.6777707508632, 24.340404714856827, 18.304310049329484, 33.287474972861155, 42.84049762998308, 50.862502098083496, 17.752873216356548, 0.5785453926239694, 0.07281154367540564, 0.042387566928352625, 0.018107241318960274, 0.013058766057448727, 0.03832300306696977, 0.047621840345008035, 0.033881587641579766, 0.07449867350182363, 0.03483814559876919, 0.11499523797205516, 0.09628785108881337, 0.01576481120926993, 0.04357549514887588, 0.06309840309300593, 0.004604212939739227, 0.07077433727681637, 0.03188575491575258, 0.10159983712115458, 0.018569686682894826, 0.04579398235572236, 0.02572298266126641, 0.008685991234545196, 0.02551526782502021, 0.024551722653476254, 0.030135690966354947, 0.06453624593892268, 0.018280576482149105, 0.018132182569908242, 0.06273790422294821, 0.04363766931263464, 0.02246759895102254, 0.03200377929689629, 0.02889267248766763, 0.062449750756578784, 0.023661751034004346, 4.072867691516876, 25.379127400262014, 46.58328376497541, 49.17965187345232, 38.66677727018084, 20.195571490696498, 20.68751437323434, 34.85418953214373, 27.812146833964757, 2.7473437786102295, 0.054506042905684025, 0.6413179699863706, 8.00409722328186, 9.995747106415884, 6.835255188601358, 6.860270440578461, 9.069938727787562, 10.84541278226035, 27.383444717952184, 45.06282683781215, 51.551318713596885, 36.34457812990461, 40.835601874760215, 51.02315139770508, 49.57717221123831, 49.55684525626046, 46.567754541124614, 45.54325655528477, 46.545228481292725, 49.02270596367972, 49.04298428126744, 47.32775545120239, 44.21444484165737, 46.87134565625872, 48.608624594552175, 45.63831833430699, 46.41280623844692, 48.43219246183123, 47.23719957896641, 45.585741315569194, 45.20048107419695, 44.332032680511475, 47.030945777893066, 48.25731325149536, 48.83671310969761, 47.75098759787423, 48.00978715079171, 45.980398995535715, 38.45926931926182, 32.98209817068917, 35.08948680332729, 33.99449586868286, 34.598655632564, 34.50852360044207, 35.74195391791207, 33.949898856026785, 33.734713145664756, 33.75375468390328, 36.07166678564889, 39.638576643807546, 43.927216734204976, 44.53995752334595, 43.73892402648926, 44.29598542622158, 43.61264399119786, 40.476175035749165, 46.73612328938076, 44.24489879608154, 50.57718474524361, 36.80709886550903, 29.240378584180558, 50.4107198034014, 46.706871373312815, 46.54355049133301, 41.453334944588796, 39.06121955599104, 34.73707069669451, 35.849122932979036, 35.17995234898159, 34.869732652391704, 34.63651289258684, 36.21302441188267, 35.21679169791085, 36.410231658390586, 35.94469540459769, 36.82422270093645, 39.78062561580113, 41.19748837607247, 42.59052923747471, 44.596158027648926, 46.13650417327881, 48.284980978284565, 47.28558335985456, 50.47547354016985, 47.47696801594326, 47.5961400440761, 45.7799573625837, 44.740743092128206, 44.787459305354524, 46.00447450365339, 47.15376213618687, 48.26732560566494, 46.826752117701936, 46.776610442570274, 47.19784498214722, 46.34619385855538, 43.22822795595442, 41.11678157533918, 37.42925098964146, 37.8552519934518, 37.28212635857718, 41.81040634427752, 47.126900400434224, 50.23258536202567, 50.40867008481707, 44.94291830062866, 46.774897711617605, 50.221635001046316, 51.92925207955496, 53.06121785300118, 43.024624892643516, 27.458533900124685, 17.64738392829895, 6.473228420530047, 4.060341826507023, 8.021358285631452, 4.758333103997367, 2.6992005790982927, 0.5329934369240488, 0.10330766226564135, 0.3582988695374557, 13.006879244531904, 51.244027682713096, 68.81240190778459, 32.505486488342285, 20.88145249230521, 36.71652562277657, 47.32664373942784, 58.27350630078997, 22.28242298534938, 0.8994270456688744, 0.0324032871451761, 0.05208259401842952, 0.021437336823769977, 0.024813883139618804, 0.043799486343881915, 0.04491998514692698, 0.034734872568930895, 0.05907403903880289, 0.02387581017267491, 0.051157947563167126, 0.026555107474060993, 0.09491106282387461, 0.06797331757843494, 0.0904892808092492, 0.023134246036144238, 0.031079275333987813, 0.01287830458022654, 0.19273754635027476, 0.06931398742433105, 0.13144836867494242, 0.12582988158932754, 0.0871144240455968, 0.122553697388087, 0.088886594665902, 0.10071407750781093, 0.13556364285094397, 0.11855707184544631, 0.1521359107324055, 0.18912991136312485, 0.1838586985000542, 0.15278254103447708, 0.15200371854007244, 0.13048592103379114, 0.24647822550364903, 0.1685550468308585, 5.014479313577924, 31.499908447265625, 52.958224705287385, 56.826776708875386, 44.78992938995361, 25.6170563016619, 24.018758705684117, 40.37863622392927, 33.4357773235866, 3.7202305453164235, 0.19155462911086424, 0.9757796057632991, 5.825588132653918, 12.45443492276328, 10.027298876217433, 6.775074235030583, 15.063892568860735, 12.966729947498866, 31.750738416399273, 45.71909809112549, 53.65564319065639, 40.223455156598774, 43.95863996233259, 50.74964598246983, 51.93415403366089, 51.720243317740305, 48.916575704302105, 46.34069783346993, 47.8733696937561, 51.83108792986189, 51.01873581750052, 49.62734515326363, 45.71866382871355, 47.807240213666645, 50.46295288630894, 47.55512482779366, 48.803917612348286, 50.393762724740164, 48.01333768027169, 45.443504742213655, 45.73006929670061, 44.67700726645333, 48.469441754477366, 49.47481482369559, 51.700107438223704, 48.58792243685041, 51.0404280935015, 50.53279617854527, 41.83151844569615, 34.752784047807964, 36.65710810252598, 35.0987765448434, 37.05310678482056, 36.859168665749685, 37.8216678755624, 35.50101818357195, 35.368439606257844, 36.75609213965279, 38.36261987686157, 40.485211168016704, 45.912970202309744, 48.62555040631975, 46.05823966435024, 46.38841111319405, 45.51662411008562, 44.0859865461077, 48.00581972939627, 46.3188978603908, 50.734891482761924, 38.36497531618391, 33.557891913822715, 50.597268513270784, 48.86178568431309, 49.025686740875244, 42.879876545497346, 39.64966596875872, 37.26399156025478, 37.31551592690604, 37.63879476274763, 36.69068874631609, 37.653521469661165, 38.19454295294625, 37.53422784805298, 38.77784422465733, 38.76961408342634, 39.37795318875994, 41.47012874058315, 43.93940387453352, 45.98518977846418, 46.23584951673235, 48.56095995221819, 50.787124565669465, 50.072759423937114, 53.03104877471924, 48.55713496889387, 49.94984926496233, 48.38721677235195, 47.27647427150181, 46.679509367261616, 46.955370221819194, 49.58039270128523, 49.71147741590227, 48.694837842668804, 48.12557193211147, 48.59866782597133, 48.15782894407, 44.26227971485683, 42.51084729603359, 38.577131611960276, 39.79366738455636, 39.641713755471365, 44.48135641642979, 50.743177209581646, 51.58502789906093, 52.231418813977925, 45.62809753417969, 46.15371138708932, 52.521638120923726, 54.19193989889962, 56.39153112683977, 46.73100594111851, 36.14682197570801, 33.473794392177034, 9.617596609251839, 14.978111846106392, 21.347268411091395, 7.665282215390887, 5.0519136020115445, 0.6132554443819183, 0.22466279539678777, 0.535970957151481, 17.147436720984324, 57.86830472946167, 67.29979991912842, 31.370362758636475, 27.393165247780935, 44.6466749055045, 54.49406147003174, 63.774527141026084, 29.191723823547363, 1.6804944596120288, 0.11828767987234251, 0.12065222513462816, 0.17191728284316404, 0.15561496333352157, 0.10053448285907507, 0.16739503693367752, 0.08798291494271585, 0.2027319057711533, 0.14730565063655376, 0.11765278822609357, 0.18107779057962553, 0.1327579276902335, 0.12902538797685079, 0.15772983485034534, 0.15610376639025553, 0.1912853999861649, 0.14910044361438068], [0.06720997925315585, 0.017287589676145996, 0.04570671935964908, 0.05276480669687901, 0.009064567973837256, 0.014353485511881965, 0.049269136773156266, 0.030172854329326322, 0.01516359016698386, 0.05131544232634561, 0.0836017703903573, 0.03329968618761216, 0.04647926201245614, 0.035436613485217094, 0.11473283490964345, 0.03939383649932487, 0.01982544974556991, 0.03141154036191957, 2.4024186985833302, 17.37292660985674, 42.272923605782644, 40.65259327207293, 30.20759562083653, 21.030708483287267, 25.238129343305314, 28.7156297819955, 20.642109632492065, 1.4242806136608124, 0.6905913374253682, 0.7942988468067986, 1.2539357542991638, 4.567876900945391, 4.056671874863761, 7.2361167413847785, 11.898839592933655, 21.124260766165598, 28.716034514563425, 50.50429119382586, 35.92739091600691, 34.29234082358224, 47.64614970343453, 49.57483761651175, 47.77142224993025, 46.02092088971819, 42.88516412462507, 38.8809346471514, 40.336759431021555, 45.14940486635481, 46.91663748877389, 44.537904330662315, 43.805206366947715, 45.89606523513794, 44.823767117091585, 44.982974665505544, 45.57408223833357, 46.63439471381051, 47.697073050907676, 46.00011450903756, 46.164036410195486, 47.11116273062569, 46.81903961726597, 46.6431633404323, 46.829673835209434, 45.75779260907854, 47.53215755735125, 44.695055212293354, 39.39895064490182, 36.02841077532087, 32.88550778797695, 32.195603779384065, 34.28311014175415, 33.5744286264692, 32.513949394226074, 33.2346373966762, 33.046820640563965, 33.28649180276053, 36.1282251221793, 40.14163664409092, 42.94867760794503, 41.751072202410015, 41.652286188943044, 37.99177367346627, 37.82924836022513, 36.370442799159456, 41.531745365687776, 41.97419275556292, 47.57641063417707, 37.67051328931536, 28.04999930518014, 50.4698281288147, 43.92270040512085, 45.176346506391255, 38.015095302036826, 36.068776335035054, 35.19095482145037, 37.417105538504465, 37.30204684393746, 36.955818108149934, 33.39194113867623, 34.78860895974295, 35.2189039502825, 34.02961553846087, 32.366008349827354, 36.671192101069856, 39.291298730032786, 42.83258710588728, 44.2039669581822, 47.827605383736746, 48.246963909694124, 48.18493734087263, 46.94373893737793, 46.5206527028765, 44.178675515311106, 47.42150749479021, 49.1132618359157, 47.918769223349436, 46.06048393249512, 45.28056948525565, 45.95207118988037, 46.49619156973702, 44.25024543489729, 44.93112373352051, 45.51655462809971, 43.91511992045811, 40.79565668106079, 38.37232303619385, 35.50828947339739, 34.09113141468593, 35.76231561388288, 45.24662058694022, 47.197862352643696, 50.417098249707905, 45.87798949650356, 46.84887170791626, 48.76782519476754, 47.287608759743826, 50.6260792187282, 48.2036384173802, 47.90652649743216, 26.527784483773367, 15.463354928152901, 7.648010730743408, 2.977264881134033, 9.583880475589208, 7.713386331285749, 3.5048539766243527, 0.22715725297374384, 0.06818817569208996, 0.12644747059260095, 9.424101437841143, 36.577516487666536, 36.20989424841744, 28.264854976109095, 30.06532778058733, 39.08276244572231, 45.55474887575422, 42.79165874208723, 24.517806121281215, 0.8092610325132097, 0.0555865793888058, 0.03223964824740376, 0.06191530264914036, 0.00765840507977243, 0.06356252783111163, 0.024371642852202058, 0.029393234556274753, 0.019560218888467977, 0.07564863429537841, 0.03915746882557869, 0.04315075258325253, 0.06530759097742182, 0.07898701980177845, 0.005922296899370849, 0.0777199235079544, 0.02057507148544703, 0.012765095253208918, 0.018517692240753343, 0.01909316796809435, 0.03728271388847913, 0.04916761775634118, 0.060964145830699375, 0.056127371798668585, 0.05011216225102544, 0.011449901852756739, 0.01356999554471778, 0.09705667197704315, 0.04069310213838305, 0.07060772978833743, 0.060928115621209145, 0.03712133451231888, 0.023126542967345034, 0.03882520379764693, 0.04990485283945288, 0.008812198748013802, 3.228441825934819, 21.54365403311593, 49.725755964006694, 48.524065017700195, 34.952311992645264, 23.355443716049194, 22.878149373190745, 29.74368871961321, 22.92692051615034, 1.6999578837837492, 0.47272139681237085, 1.694074062364442, 1.5882374729428972, 4.541874136243548, 8.981389147894722, 6.5244171023368835, 6.52232699734824, 15.360129015786306, 31.52019371305193, 51.4939717565264, 39.92092711584908, 37.24266059058053, 48.520007269723074, 48.965199198041645, 50.74960776737758, 47.21971443721226, 45.690454142434255, 41.63951192583357, 42.68004635402134, 45.35744088036673, 48.12603051321847, 47.0641963822501, 46.123948778424946, 45.750795773097444, 47.49108328138079, 46.832779679979595, 47.32777629579817, 47.78102118628365, 47.80754940850394, 47.519070625305176, 48.920220034463064, 47.07343053817749, 46.78230449131557, 47.37102535792759, 47.20802756718227, 46.84170811516898, 48.88782753263201, 45.81195381709507, 41.247769015175955, 37.13471337727138, 35.78387587411063, 33.25676393508911, 34.95841251100813, 35.99098082951137, 34.531178201947895, 34.54904549462454, 34.62620176587786, 34.564369746616904, 37.940294470105854, 41.929960523332866, 44.235237325940815, 44.282509395054404, 45.61970411028181, 40.91317503792899, 41.10442420414516, 38.77651711872646, 43.0447017124721, 44.1882848739624, 49.278184277670725, 38.26720721381051, 30.14849771772112, 52.53781700134277, 45.891097273145405, 47.684201513017925, 39.739787578582764, 38.16085461207798, 38.74890497752598, 39.07780490602766, 38.540729999542236, 37.32898848397391, 35.42220476695469, 35.7393969808306, 37.1247044972011, 36.42762647356306, 34.43576553889683, 36.71776587622506, 41.177074568612234, 43.68183067866734, 45.85967404501778, 49.030394145420615, 49.271041529519216, 48.83804368972778, 47.27240262712751, 46.47193193435669, 47.98144197463989, 48.60182925633022, 51.98578609739031, 48.54890830176217, 47.3492705481393, 46.60364546094622, 49.09194476263863, 47.58819825308663, 45.14127547400338, 46.58252988542829, 48.41582945414952, 46.41384846823556, 43.33548034940447, 40.4905230658395, 38.312106473105295, 35.73410940170288, 37.47405644825527, 47.40047877175467, 49.9113701411656, 51.698082038334434, 46.69635874884469, 46.354250294821604, 48.88785185132708, 49.80991949353899, 53.37563426154, 51.591281277792795, 48.74657760347639, 32.06460244315011, 23.090955325535365, 10.29050966671535, 10.791406171662466, 10.79023974282401, 6.227915321077619, 2.926158274923052, 0.26255272009543007, 0.08218471785741192, 0.10269714359726224, 10.194218056542532, 45.480500425611226, 47.291166237422395, 27.52041803087507, 31.795946870531353, 43.474221978868755, 51.4614611353193, 49.227691718510215, 28.81018434252058, 1.539141284567969, 0.08261216777775969, 0.03961593458162887, 0.08342121222189494, 0.013809879726198102, 0.04737506055140069, 0.03184214547010405, 0.006968882882834545, 0.04862818241651569, 0.03686337246160422, 0.03289661942315953, 0.042544074423078976, 0.008787388963225697, 0.06212625240108796, 0.015008960517921617, 0.03614558419212699, 0.006201205750195575, 0.04390084929764271, 0.08878282630550009, 0.12078570654349667, 0.20566867318536552, 0.21684438921511173, 0.10736098619444029, 0.19714719615876675, 0.12311209099633352, 0.11228637689990656, 0.14063291012176446, 0.11495281596268926, 0.17088155341999872, 0.19043936181281293, 0.1490649969450065, 0.10091908329299518, 0.15461827681532928, 0.18429819920233317, 0.07592884890202965, 0.10389378081474986, 4.735414905207498, 27.71100538117545, 56.80473007474627, 54.086007663181846, 42.31190299987793, 29.386328969682964, 34.85812568664551, 36.648690359933035, 29.12402926172529, 1.8899590883936201, 1.0340574043137687, 1.608571593250547, 3.054972665650504, 8.583761113030569, 9.272849576813833, 16.922919579914637, 17.5455459186009, 25.316795110702515, 31.28874921798706, 53.844863482883994, 40.63572999409267, 42.24406426293509, 48.6264363016401, 53.85537263325283, 52.39039012363979, 49.74293885912214, 46.51722376687186, 42.73562152045113, 43.33657816478184, 48.39291429519653, 50.69949041094099, 49.180725370134624, 47.50925282069615, 48.343693256378174, 48.35426494053432, 49.24441255841936, 47.96940074648176, 50.179452487400596, 49.60885599681309, 49.719214235033306, 50.507650647844585, 48.57257039206368, 48.550020013536724, 48.51344122205462, 47.975688866206575, 47.51572159358433, 49.43242038999285, 47.47952842712402, 42.91115386145455, 39.28985350472586, 36.48464339120047, 35.33794396264212, 36.229397841862266, 38.62507765633719, 36.9630685533796, 36.34560646329607, 36.53006376538958, 36.152873856680735, 39.79419544764927, 44.64207172393799, 46.87475374766758, 45.96625246320452, 46.91330582754952, 43.025781767708914, 42.587023871285574, 40.16323511941092, 44.86660623550415, 47.287838050297324, 51.16167068481445, 40.11437191282, 34.67279985972813, 53.10792016983032, 48.573414598192485, 50.18553910936628, 42.4980765070234, 40.42267738069807, 41.2567252431597, 40.978474208286826, 40.95215790612357, 40.706983770642964, 36.896504810878206, 37.60739932741438, 38.68835142680577, 38.706983021327424, 35.72874539239066, 39.80932862418038, 43.340879099709646, 45.32339470727103, 48.09633043834141, 51.51047372817993, 51.65764699663435, 51.31805031640189, 49.807588372911724, 47.79200628825596, 46.188570499420166, 49.20582226344517, 54.27439417157854, 52.51797294616699, 50.45873532976423, 48.34057698931013, 52.93811661856515, 50.19365113122122, 46.21996940885271, 46.7535320009504, 49.35839080810547, 48.90238053458077, 45.43644537244524, 43.656650406973704, 40.18957921436855, 37.126997402736116, 39.16420922960554, 50.26521062850952, 53.21141358784267, 53.44799280166626, 45.95910971505301, 46.27783400671822, 49.565864018031526, 52.01917219161987, 55.95945392336164, 51.821989263807026, 53.18679959433419, 33.37322269167219, 22.016418150493077, 11.877571157046727, 9.5188627072743, 16.645623922348022, 15.960708720343453, 9.033335617610387, 0.9802454518420356, 0.3078223509447915, 0.18735106395823614, 12.79160841873714, 44.772677012852256, 44.31718438012259, 35.24074213845389, 40.19748279026577, 48.161626134599956, 55.84850856236049, 55.12160192217146, 35.242958613804404, 2.4446533237184798, 0.18269573019019195, 0.11380060921822276, 0.19399069196411542, 0.11321008697684322, 0.08710098226687737, 0.09540043585002422, 0.07923724994595562, 0.06533791470740523, 0.16837476007640362, 0.08639378592904125, 0.1284996997565031, 0.19396140639271053, 0.15147020002560957, 0.057777365403515954, 0.1979766237948622, 0.10799373367003032, 0.10521397925913334], [0.07564507877188069, 0.03921703402219074, 0.04736825145248856, 0.019350731379485557, 0.04069982302774276, 0.018282713867457848, 0.04066715156659484, 0.030090039130300283, 0.04393720859661698, 0.00963704627273338, 0.04999829050419586, 0.04366022381665451, 0.021620242723396847, 0.03589679254218936, 0.019238416870523776, 0.0895122243091464, 0.02158589188807777, 0.07694645465484687, 1.9718915947846003, 17.96178296634129, 46.335618700299946, 40.152673857552664, 29.7859685080392, 13.712058867727007, 22.44044065475464, 38.270976611546104, 16.112697090421403, 1.1207140343529838, 0.1847560474915164, 2.761526788984026, 18.465423141207012, 23.314756802150182, 7.299363153321402, 5.075983464717865, 6.597053570406778, 15.129931722368513, 32.40902117320469, 40.95471831730434, 28.841272320066178, 40.19750016076224, 47.37219612939017, 49.64580304282052, 45.51860434668404, 44.3859680720738, 39.704337869371685, 35.948509965624126, 35.71171883174351, 41.656812940325054, 44.8931622505188, 45.68218231201172, 44.12610197067261, 43.92714030402047, 46.68664864131382, 45.07387099947248, 46.15591744014195, 46.29780660356794, 46.03272587912423, 45.471846444266184, 45.885813168116975, 45.79629952566964, 45.66792460850307, 45.719129358019146, 46.50589125497, 47.204299858638215, 46.390624114445274, 43.14937285014561, 38.571444511413574, 33.12763513837542, 31.790047849927628, 32.10324484961373, 33.36587497166225, 33.75698907034737, 32.809338160923545, 31.92793137686593, 32.17934152058193, 32.660601547786165, 36.67283187593733, 39.91677556719099, 40.885844298771445, 39.9941611289978, 40.467444624219624, 35.53847592217581, 36.74558993748256, 37.68521220343453, 42.885449000767295, 41.95300769805908, 46.82027987071446, 40.03997755050659, 28.915056977953228, 49.55413893290928, 42.60172973360334, 42.70412186213902, 38.79099369049072, 41.611059052603586, 41.69984313419887, 45.31326423372541, 43.987704277038574, 43.246560777936665, 39.64479180744716, 33.81636837550572, 34.40906013761248, 34.09044701712472, 33.427807739802766, 34.903327192579, 40.03425223486764, 42.17267847061157, 46.14585992268154, 46.37244415283203, 46.72059753962925, 45.293652943202424, 42.02276413781302, 44.03861720221383, 44.08312388828823, 45.011514391217915, 46.26799535751343, 46.210641452244346, 45.98704842158726, 46.230106830596924, 45.63755750656128, 42.04398741040911, 46.44324629647391, 45.61027193069458, 44.31063222885132, 42.22444602421352, 39.276745728084016, 35.639766761234824, 35.39086144311087, 35.816890239715576, 40.63822092328753, 45.63053982598441, 47.891257831028526, 49.67561081477574, 40.791150774274556, 38.1820570400783, 47.31729146412441, 46.15407269341605, 50.48961659840175, 51.37227405820574, 45.984901428222656, 36.074828216007774, 25.341061694281443, 9.283864208630153, 6.45688886301858, 7.12827114548002, 3.1904338768550327, 1.621510116117341, 0.6015763367925371, 0.021419426891952753, 0.23891570844820567, 5.487312044416155, 24.448188645499094, 30.29648392541068, 25.281286341803415, 21.65582401411874, 37.627052307128906, 41.86909082957676, 45.87844112941197, 24.17195085116795, 1.1892859148127692, 0.023663666199094484, 0.026753280411607454, 0.034355106697018654, 0.006112836742041898, 0.010488025029189885, 0.04023271952090519, 0.027962424725826298, 0.025435064985815967, 0.03088695815365229, 0.02202135361065822, 0.042563701048493385, 0.03137718274125031, 0.011097743026246982, 0.08638331613370351, 0.0559351394352104, 0.025982476504785672, 0.0788521473961217, 0.0732631901545184, 0.010173071974090167, 0.022593731825639094, 0.026780961247693216, 0.03191656040559922, 0.014439642495874847, 0.07931817881762981, 0.01885056625386434, 0.03220119906057205, 0.042142741315598996, 0.06863560168338673, 0.023987498733081987, 0.008822418333563422, 0.029531258757093122, 0.025605701275968125, 0.01424961197855217, 0.03723816806450486, 0.05402628132807357, 2.464274602276938, 23.887472493307932, 51.937701089041575, 47.33294228145054, 34.62141793114798, 20.480574437550136, 29.868405410221644, 39.84565033231463, 19.759059599467687, 1.326757326722145, 0.04016371590218373, 3.225126883813313, 18.77509914125715, 21.799375534057617, 8.249616163117544, 4.5689690709114075, 8.943854110581533, 17.271291834967478, 35.73038169315883, 43.44981643131801, 30.061926637377056, 42.52550452096121, 49.02496412822178, 49.669263635362896, 47.076685769217356, 44.669920103890554, 42.083779743739534, 36.67736210141863, 38.41923032488142, 43.27150133677891, 47.60953964505877, 47.62554134641375, 45.99216576984951, 45.316880771092, 47.63793345860073, 46.249513149261475, 48.07275867462158, 47.68221780232021, 47.67466163635254, 47.9624525478908, 47.96910892214094, 47.970665318625315, 49.03116192136492, 48.7555581501552, 48.11638641357422, 48.7461051259722, 48.81552805219378, 44.862854208265034, 41.20030239650181, 35.4468708719526, 33.17968756811959, 32.993962219783235, 35.76889555794852, 34.44338771275112, 34.9376026562282, 33.248627594539094, 34.23773840495518, 34.9797226360866, 38.982763971601216, 40.212470054626465, 41.904929637908936, 42.31172234671456, 42.31216355732509, 37.96134056363787, 38.82977853502546, 38.675761290958945, 45.35816696711949, 43.50490869794573, 48.63987064361572, 41.178182806287495, 29.944793905530656, 50.605578558785574, 44.61828456606184, 45.03947394234793, 41.09694446836199, 42.99831901277815, 42.17043072836739, 47.0629700251988, 46.24708475385393, 45.76595674242292, 40.540932246616904, 35.45964513506208, 35.66091012954712, 35.408440385546, 35.56885344641549, 36.312070982796804, 42.692997796194895, 43.84567614964077, 47.69241428375244, 49.08856446402413, 48.63111591339111, 45.75749731063843, 42.14171382359096, 43.130220140729634, 43.25281763076782, 45.13216291155134, 46.16592979431152, 47.338254179273335, 47.72278485979353, 48.81090750013079, 47.42928947721209, 42.41723769051688, 47.095140184674946, 47.64112268175398, 45.924438204084126, 43.602232115609304, 42.26229633603777, 38.26573419570923, 37.05282538277762, 36.98725175857544, 41.89290925434658, 47.57872438430786, 50.308887004852295, 50.47684580939156, 42.24146563666207, 39.86616836275373, 48.12763554709298, 47.51967511858259, 52.051151275634766, 54.50029053006853, 48.649785723005024, 36.669726031167166, 22.913435799734934, 12.879711576870509, 11.022355607577733, 8.093414579119, 4.357567523206983, 2.9290875920227597, 0.6885831994669778, 0.038609982667756934, 0.11919558686869484, 6.882266700267792, 30.870478085109166, 34.21006372996739, 29.92161124093192, 27.467517920902797, 41.25179549625942, 48.79312705993652, 51.7153274672372, 29.668648174830846, 1.4124230785029275, 0.07749391027859279, 0.014777383301407099, 0.02355288857194994, 0.01993377446862204, 0.02593614613371236, 0.01564522789392088, 0.049435072511966736, 0.020940913818776608, 0.04277488489502242, 0.021366572406675135, 0.0378635771838682, 0.02767042735857623, 0.04027927380853465, 0.056130035048616786, 0.028263634902292063, 0.022345532197505236, 0.00894666403265936, 0.1885585713067225, 0.1122197854731764, 0.11674318489219461, 0.12495512781398636, 0.12064094788261823, 0.07815136999956199, 0.15998178401163646, 0.12114545223968369, 0.18377802068633692, 0.20096684619784355, 0.1281380813036646, 0.09665696056825773, 0.08458132389932871, 0.09953786419438464, 0.12570185560200894, 0.20559806483132498, 0.1351495057876621, 0.12450846178191048, 3.404299863747188, 30.96720395769392, 60.638402121407644, 52.83034658432007, 40.489327975681846, 22.567992210388184, 32.406373909541536, 48.84861189978463, 22.702359948839458, 1.6540850081614085, 0.273214405136449, 4.006261391299112, 25.990666151046753, 30.456532205854142, 15.412127596991402, 9.702939595494952, 9.563074963433401, 19.382733004433767, 35.10683298110962, 45.53017309733799, 35.25254365376064, 45.96032912390572, 49.789543901171, 52.0137699672154, 49.30015100751604, 47.13113185337612, 44.656183515276226, 39.390178544180735, 39.56928225925991, 45.879389558519634, 48.8145865712847, 50.35393565041678, 48.09454127720424, 46.20682341711861, 49.10121365955898, 48.146809101104736, 49.733763762882774, 50.49264601298741, 49.628522872924805, 51.488472257341655, 49.14228098733084, 51.05426543099539, 51.18303639548165, 50.16882174355643, 49.871758460998535, 51.57445274080549, 49.66879115785871, 47.40726716177804, 42.48161622456142, 35.851412364414756, 34.06473520823887, 35.10859782355172, 37.73893567493984, 37.25950649806431, 38.28314290727888, 35.28718737193516, 36.03144366400582, 37.085228306906565, 39.92019755499703, 42.498941557747976, 44.90979971204485, 44.06450619016375, 44.051221234457834, 39.98873805999756, 41.41418184552874, 43.081735610961914, 47.91597604751587, 46.37260396139962, 50.54331227711269, 45.24737446648734, 33.296427726745605, 51.611378942217144, 46.20360292707171, 47.215962409973145, 43.37925747462681, 45.7197790145874, 44.67038563319615, 49.705717359270366, 47.759381021772114, 47.36165223802839, 43.96421936580113, 37.3050206729344, 38.19659614562988, 36.2640380859375, 37.61155435017177, 37.62216772351946, 43.85427801949637, 44.948914596012656, 48.61999879564558, 50.30578810828072, 49.84090845925467, 46.18033340999058, 41.8725197655814, 44.052920069013325, 44.95750604357038, 47.8468588420323, 48.33968761989048, 49.1183374949864, 48.08102355684553, 49.18787506648472, 46.76337759835379, 43.09213359015328, 49.189626012529644, 49.09087126595633, 48.03456442696707, 44.867853437151226, 44.151035581316265, 40.239891120365684, 39.17501367841448, 40.18414224897112, 44.03310380663191, 49.45595393862043, 53.131842817579, 51.842823437282014, 42.64939437593733, 41.708351203373496, 47.964946951184956, 50.825471673692974, 53.30221612112862, 54.40559005737305, 49.64344065529959, 37.21250540869576, 29.16165896824428, 15.785209383283343, 9.861634714262825, 12.904466271400452, 8.72485557624272, 6.23908976146153, 1.6621556665216173, 0.11550249718129635, 0.450481325920139, 7.45226868561336, 33.48595026561192, 40.65383005142212, 32.950522082192556, 32.09897518157959, 48.372927801949636, 54.67082364218575, 60.979162624904085, 35.81355510439192, 2.112563737801143, 0.2033313371773277, 0.15754416052784237, 0.15070345545453684, 0.09260242206177541, 0.1375844151313816, 0.09745829006923096, 0.16114724933036736, 0.10434013472071715, 0.09244084930313484, 0.10682232438453607, 0.13095393377755368, 0.06274730871830668, 0.11465831819389548, 0.13006471363561495, 0.11179181308086429, 0.057833093484597545, 0.14916147105395794], [0.06690134759992361, 0.02494761730278177, 0.028051562174888592, 0.01501954736055008, 0.03982281990881477, 0.06405555816101176, 0.01954167283007077, 0.038836291059851646, 0.05855426085846765, 0.007782759344471353, 0.04599415357889874, 0.003501375555060804, 0.09106615771140371, 0.026647101555551802, 0.048542473265635114, 0.03585694896589432, 0.025395394435950687, 0.05183352416913424, 2.394246748515538, 20.143932478768484, 43.214977741241455, 35.71555423736572, 25.380772386278423, 13.117194056510925, 18.193918807165964, 35.466867787497385, 15.935280050550189, 0.7610137728708131, 0.04653853204633508, 0.1422189585864544, 3.798937133380345, 7.651040145329066, 8.226106933185033, 3.971394896507263, 9.784208331789289, 18.68192379815238, 38.43879992621285, 26.774316992078507, 28.45028328895569, 46.907486711229595, 46.45861223765782, 48.57037476130894, 43.42941304615566, 42.70592144557408, 37.97688715798514, 34.35244621549334, 34.13474873134068, 34.01562534059797, 39.20707614081246, 45.2328770501273, 45.45127282823835, 45.24806581224714, 43.370582648685996, 46.845679010663716, 45.12144878932408, 43.136171272822786, 42.64785187585013, 40.10164281300136, 39.11837196350098, 38.69355910164969, 38.64872932434082, 41.00941106251308, 39.87921360560826, 39.81679793766567, 37.81271859577724, 35.70523616245815, 34.21629279000418, 31.879085540771484, 33.32459919793265, 36.50631134850638, 32.63484457560948, 31.57158258983067, 30.385010923658097, 32.7083044052124, 31.977364335741314, 32.94046456473214, 36.266091278621126, 36.88834762573242, 38.77830280576433, 38.80175992420742, 36.221251079014365, 32.56691551208496, 33.81766768864223, 36.06268276487078, 42.379404749189106, 41.2428913797651, 45.873455796922954, 39.488888127463206, 27.616152048110962, 48.944205215999055, 43.77162919725691, 44.60419709341866, 41.37644965308053, 43.13052238736834, 44.504024914332796, 47.361277035304475, 46.85954066685268, 46.086900983537944, 44.62747703279768, 37.663547720227925, 34.39668539592198, 34.23646341051374, 33.79976565497262, 35.78655093056815, 37.3068584714617, 43.25296006883894, 46.15563603809902, 46.88669075284685, 46.18320301600865, 44.9279796736581, 45.74288524900164, 44.39885350636074, 45.529419217790874, 45.89685385567801, 47.50269372122628, 45.847507749285015, 45.10112183434622, 45.09958628245762, 45.14600372314453, 45.6469202041626, 46.52428661073957, 45.47937134334019, 42.034534386226106, 40.85605737141201, 37.397879873003276, 33.4890387398856, 34.51385286876133, 34.48947858810425, 39.23353835514614, 45.411862645830425, 48.083170550210134, 46.58237355095999, 48.307378496442524, 47.87359203611101, 46.5782914842878, 44.09576613562447, 49.38776084354946, 50.27458027430943, 51.148364884512766, 35.4698485646929, 20.34318596976144, 9.332001328468323, 20.608176367623464, 10.018171548843384, 5.523133482251849, 1.8643999227455683, 0.40547911929232733, 0.025584636156314185, 0.06105810936008181, 3.42842618056706, 31.398805209568568, 47.12279054096767, 29.17130654198783, 19.25103858539036, 37.23896414893014, 45.49923276901245, 47.24369614464896, 24.2657584803445, 0.22511510684021882, 0.03350175052349057, 0.05888796438063894, 0.0683427866814392, 0.01824867006923471, 0.06417735519685916, 0.016721696559605852, 0.014385067924324955, 0.017810580719794546, 0.04339260621262448, 0.0426247895562223, 0.028861697364066328, 0.02850964286231569, 0.03294978942722082, 0.04832910792902112, 0.01966221796880875, 0.037796816123383384, 0.04615457961335778, 0.025542431278154254, 0.06482076924294233, 0.024498014910412685, 0.036322909141225476, 0.07088626162814242, 0.04574182676151395, 0.026256584296269075, 0.014313377306929656, 0.07954801219914641, 0.012326217954978347, 0.060094501424048624, 0.051262859255075455, 0.051461256109178066, 0.0473234477852072, 0.07744046207517385, 0.05814042913594416, 0.028717325468148504, 0.034279833414724896, 3.171474848474775, 25.816770110811504, 49.072208404541016, 42.095966884068076, 29.56241021837507, 16.619802679334367, 19.055358205522808, 39.584293842315674, 18.74240091868809, 1.0053242146968842, 0.028405703171821575, 0.2722749869738306, 2.7119726708957126, 7.89533793926239, 4.907133119446891, 4.165627011231013, 12.479325107165746, 18.403625862939016, 39.212363719940186, 29.535583223615372, 31.972736835479736, 47.475731236594065, 45.375641686575754, 51.79522827693394, 45.65389272144863, 44.57105418613979, 39.299605301448274, 36.7029835837228, 35.64105565207345, 36.02928277424404, 41.483827114105225, 46.84477227074759, 47.22269174030849, 46.77304949079241, 45.71534258978707, 47.86043562207903, 46.203481333596365, 44.5525997706822, 44.39497293744768, 42.617165156773154, 42.26307800837925, 41.04776859283447, 40.89553008760725, 43.7082199369158, 42.910344396318706, 42.59609127044678, 42.53843511853899, 38.420599120003835, 36.610298088618684, 33.63110508237566, 34.99173954554966, 38.49752262660435, 34.68411152703421, 32.87276826586042, 33.58410399300711, 35.31914561135428, 34.698966775621685, 34.87951224190848, 39.19676501410348, 39.71867547716413, 39.76967525482178, 40.90342671530587, 38.10268081937517, 34.10908555984497, 35.021352767944336, 36.95126356397356, 44.242560727255686, 42.227802004132954, 48.15473004749843, 40.77588905606951, 29.08575337273734, 49.16102375302996, 45.08810785838536, 45.11578253337315, 43.700667245047434, 44.72795145852225, 45.552528926304404, 49.75347580228533, 47.612669808524, 47.919814927237375, 46.022987978799, 39.78767108917236, 36.852779797145296, 35.20786326272147, 35.06128753934588, 37.09074170248849, 38.76431608200073, 45.203013692583355, 47.371737548283164, 48.67327758244106, 47.620771408081055, 46.37348290852138, 47.00691543306623, 46.98617506027222, 47.47415052141462, 47.547540869031636, 47.66083819525582, 45.53161832264492, 46.338644640786306, 46.39843388966152, 45.222503389631, 45.643915108272004, 47.158337524959016, 48.26114170891898, 44.37519836425781, 42.780051776341026, 38.314993449619834, 35.87557472501482, 36.453862871442524, 36.72384554999215, 40.73440483638218, 46.502507482256206, 50.19130264009748, 48.52869946616036, 48.30441856384277, 49.679963861192974, 45.745456082480295, 47.79408727373396, 50.745490959712434, 52.593683992113384, 51.77590881075178, 37.7158329146249, 20.63024037224906, 11.67722853592464, 18.178592818123953, 10.769578405788966, 7.196812953267779, 3.6736737063952853, 0.9041053546326501, 0.06912542254264865, 0.057747543789446354, 4.001171835831233, 29.606715406690324, 50.1145806312561, 29.590383665902273, 22.593763078962052, 44.2432416507176, 48.32178211212158, 53.257740701947895, 27.547081742967876, 0.7427460902503559, 0.036020384303161075, 0.05532088543155363, 0.03942029597237706, 0.017944862799985067, 0.039494232540684085, 0.015216654998117259, 0.0387405294126698, 0.06656709446438722, 0.060842057024793963, 0.018340309616178274, 0.010294078516640832, 0.036347672276731045, 0.05388159052069698, 0.05722623211996896, 0.03154474696410554, 0.027835667598992586, 0.048170211991029124, 0.17859575019351073, 0.20195002986916474, 0.09482596096183572, 0.09329114867640392, 0.14266816233950003, 0.09115125278809241, 0.13042844911771162, 0.1007262911381466, 0.13155394872384413, 0.08321875094303063, 0.15156713553837367, 0.1300721096673182, 0.21881917039198534, 0.14901863943253243, 0.21765854981328758, 0.1256479663508279, 0.15222650872809546, 0.2051761924688305, 4.727189106600625, 31.7730073928833, 57.53191811697823, 48.286488737378804, 35.70356164659773, 21.79177246774946, 25.379988976887294, 45.99973930631365, 22.01436495780945, 1.3296014198235102, 0.16891708597540855, 0.41015091431992395, 6.456512791769845, 11.672641856329781, 14.606671571731567, 9.259776541164943, 14.834289346422468, 19.087273018700735, 43.40135622024536, 32.838416372026714, 36.94443348475865, 49.24432570593697, 47.62830672945295, 53.00038637433733, 46.56664282935006, 46.041914871760774, 41.18584319523403, 37.522502762930735, 36.99322720936367, 37.21894291469029, 43.0508508682251, 50.307024887629915, 49.08543430055891, 50.58564070292881, 48.40872144699097, 51.17117234638759, 47.676673139844624, 46.570568561553955, 46.36162233352661, 45.1591705594744, 43.65595211301531, 41.77604750224522, 41.631354740687776, 45.67185034070696, 44.50013044902256, 42.81023127692086, 42.50590017863682, 39.474293436322895, 38.11665712084089, 35.248604025159565, 37.43742554528372, 39.7214651788984, 36.97384173529488, 35.11799873624529, 34.567270619528635, 37.20687389373779, 36.19445187704903, 36.84111377171108, 41.589217390332905, 42.20505360194615, 42.26059750148228, 42.49091986247471, 39.73723758969988, 35.714268820626394, 38.42564698628017, 38.518665994916645, 46.160982676914756, 45.48337697982788, 48.697436468941824, 42.140473570142476, 32.04640163694109, 49.842767102377756, 48.04626519339425, 47.79488631657192, 46.423659324645996, 46.903251784188406, 47.43402814865112, 51.00289045061384, 50.35477638244629, 50.76955951963152, 49.811875411442344, 41.01479591642107, 39.14106478009905, 37.50559432165963, 37.15979984828404, 39.05350705555507, 41.08608095986502, 48.096264430454795, 50.23936332975115, 50.31078038896833, 50.57471118654524, 48.5466570854187, 48.95472478866577, 47.75975622449602, 49.77360125950405, 49.31259175709316, 49.39213473456246, 47.55568068368094, 47.71775088991438, 46.25977911267962, 45.55682986123221, 46.50694738115583, 47.99671411514282, 48.851363386426655, 45.196326051439556, 45.48877573013306, 41.339651993342805, 37.362662928445, 37.86448614937918, 37.16291958945138, 42.241795676095144, 48.81938430241176, 52.89410325459072, 50.218838351113455, 51.78586210523333, 50.30066728591919, 47.5225898878915, 49.098601136888774, 53.24184669767107, 55.29449394771031, 54.25077029636928, 42.26698637008667, 25.643551519938878, 12.92110460145133, 28.65664999825614, 17.090049811771937, 13.12510371208191, 6.6725926484380444, 1.2501814471823829, 0.3433778573359762, 0.18317316100001335, 5.072202776159559, 38.91511631011963, 57.01922443934849, 36.41632522855486, 28.232219287327357, 49.014187472207205, 55.8012364932469, 58.49869046892439, 36.094321387154714, 1.560062201959746, 0.1713924767183406, 0.16365839886878217, 0.12149720479335104, 0.11919211276939937, 0.13188868361924375, 0.17162563492144856, 0.08080227061041764, 0.1222933977842331, 0.14389295876026154, 0.14230673387646675, 0.07615854657654252, 0.10621339348810059, 0.14118618757597037, 0.10191453487745353, 0.0842141414593373, 0.15483360311814717, 0.08368062973022461], [0.014956611541232892, 0.0567655984445342, 0.05536157039127179, 0.034585119890315194, 0.020449135385985886, 0.04938153609899538, 0.04918938855241452, 0.034389572883290906, 0.024093553756496737, 0.07323233716722045, 0.03224829617621643, 0.04541386025292533, 0.03119648547310914, 0.03273876164374607, 0.04814807139337063, 0.05992350381399904, 0.03769882548866527, 0.04686312623588102, 1.9272976219654083, 23.579288618905203, 43.09064667565482, 38.590548583439414, 22.45963157926287, 17.61109869820731, 40.645311559949604, 36.54476615360805, 13.877745611327034, 0.9574730566569737, 0.22228724429649965, 5.624117297785623, 5.975988405091422, 10.858960900987897, 9.348503300121852, 3.2203280670302252, 13.570069823946271, 21.4940664768219, 28.345035450799124, 18.416738850729807, 40.05022266932896, 45.024924414498464, 50.3320939881461, 43.5933210509164, 45.1187424659729, 42.071304253169465, 39.2115090915135, 35.044177600315635, 34.63497734069824, 31.694624764578684, 33.52510683877127, 35.091539996010916, 40.12408896854946, 40.05571869441441, 43.193205560956685, 41.39974348885672, 42.05324935913086, 36.95856612069266, 37.26490177427019, 32.953402110508506, 33.235860279628206, 31.47236578805106, 33.89427505220686, 31.273824487413677, 31.42093869618007, 31.586879049028667, 34.116669518607004, 32.65463651929583, 33.90898091452462, 32.4497515133449, 33.9582644871303, 35.54641423906599, 31.61736079624721, 33.15519864218575, 33.67854390825544, 31.488909448896134, 30.248120989118302, 31.30704035077776, 33.65249163763863, 35.88002504621233, 34.79535566057478, 34.74879578181675, 32.1280950818743, 31.170549937656947, 35.04275669370379, 41.54849747249058, 41.90675701413836, 42.0923364503043, 46.529786109924316, 38.65677533830915, 27.697781222207205, 48.37914643968855, 45.16467353275844, 44.845608779362266, 45.894123213631765, 44.898759024483816, 48.550381319863455, 46.85888058798653, 44.070085593632285, 45.907904965536936, 45.495452948978965, 41.274095739637104, 33.08985778263637, 33.665057454790386, 34.657506874629426, 37.72657830374581, 34.750324385506765, 36.50339657919747, 38.96542821611677, 44.47340072904314, 46.940990924835205, 45.489863123212544, 44.9358936718532, 45.06496688297817, 44.94098670142037, 46.03589078358242, 46.44858251299177, 47.34676572254726, 46.93898984364101, 46.10107183456421, 46.31706701006208, 43.05711119515555, 43.91362605776106, 45.91929653712681, 44.11601318631853, 39.817016805921284, 37.570445333208355, 34.8790397644043, 34.97392783846174, 34.72599874223982, 35.91668374197823, 39.24590267453875, 43.5917820249285, 44.7458222252982, 48.409492697034565, 47.405398096357075, 49.27360541479928, 41.659557478768484, 46.45218167986189, 46.342212540762766, 37.08308826174055, 31.317573819841655, 25.27012406076704, 18.357795545033046, 13.81427902834756, 5.401274672576359, 3.561758203165872, 1.5946673793452126, 0.3767677242202418, 0.0475347537680396, 0.052528537410710535, 2.3025617940085272, 27.062290293829783, 37.07785974230085, 29.544296264648438, 22.112438780920847, 28.751650980540685, 47.67974076952253, 42.511298928942, 22.20653476033892, 0.9090165910976273, 0.03467014372082693, 0.03776809034336891, 0.010019748504938824, 0.06707331551504986, 0.023315409797110727, 0.03615354680057083, 0.007050578074995428, 0.024125107331201434, 0.014590713228764278, 0.04071912395634821, 0.052913392295262644, 0.047988337464630604, 0.038352885749191046, 0.02694433042779565, 0.0413397426184799, 0.10285674181899854, 0.021303380440388407, 0.01666814148692148, 0.038264713516192775, 0.06992153410932847, 0.015568336305607642, 0.022820072448147193, 0.005018421673282448, 0.01115084093596254, 0.09471624184932027, 0.009564403161805655, 0.04131331028682845, 0.06471639698637383, 0.048242818630699597, 0.016673364510227526, 0.028453760414517353, 0.02219624092270221, 0.021152311403836523, 0.028815662155726125, 0.06802111358514853, 2.6297548541000912, 28.482307536261423, 49.30864865439278, 43.73717655454363, 29.96169192450387, 19.592638083866664, 32.51165301459176, 38.90356840406145, 15.822587217603411, 0.7555277358208383, 0.32500193480934414, 4.313926322119577, 6.1241913097245355, 10.409156237329755, 4.3185164758137295, 5.3978995851108005, 11.582357832363673, 22.880230358668737, 29.339185442243302, 19.72646733692714, 41.060487270355225, 46.064263752528596, 49.55658122471401, 46.23991073880877, 47.34801639829363, 42.7930657523019, 39.44847045625959, 36.89746366228376, 35.65079355239868, 34.12226281847273, 35.96640852519444, 38.158388001578196, 42.61009536470686, 43.61897380011422, 45.68160561152867, 45.18296119144985, 44.649315220969065, 40.680785587855745, 38.0557770047869, 35.15168012891497, 35.49779074532645, 33.16482189723423, 35.92795024599348, 33.442280837467735, 33.53045000348772, 32.99844380787441, 36.11056627546038, 34.701343059539795, 33.559556007385254, 33.24460458755493, 34.73374250956944, 36.76317235401699, 32.717899867466514, 34.725946630750386, 35.66633667264666, 33.3486191204616, 33.39979607718331, 33.71797840935843, 37.004670892442974, 38.598636286599294, 36.318939277103965, 35.782013756888254, 33.76736967904227, 33.60311426435198, 37.66132429667881, 43.26449407849993, 42.67183010918753, 45.74462924684797, 48.15001916885376, 39.65196234839303, 29.762626034872874, 49.63485615594046, 48.09204339981079, 46.442996161324636, 48.3836349759783, 46.214827741895405, 50.58254875455584, 46.70658997126988, 45.34968669073922, 48.675827571323936, 47.55308205740792, 43.88959223883492, 34.37872430256435, 34.594118458884104, 36.36887945447649, 39.25607483727591, 37.325865268707275, 38.608728545052664, 42.67161124093192, 47.288369587489534, 48.97182083129883, 48.23826823915754, 47.247013909476145, 46.54950509752546, 44.661755970546174, 49.14942373548235, 48.17981999261038, 47.430119786943706, 49.52463688169207, 47.43601185934884, 47.1143866947719, 44.736608913966585, 45.96599537985665, 47.394996643066406, 45.79229736328125, 41.08487892150879, 39.001465048108784, 36.78340550831386, 36.31352663040161, 35.7456989969526, 37.73136561257498, 41.666151319231304, 45.03495066506522, 47.16555322919573, 49.20957776478359, 49.572801794324604, 49.376060077122276, 43.72565296718052, 47.60235868181501, 49.687863962990896, 40.85640825544085, 36.30568558829171, 25.9032039642334, 14.869110243661062, 13.444593174116951, 8.129832693508693, 6.760366635663169, 3.6157250787530626, 1.071608835033008, 0.14976554363965988, 0.07416060699948243, 2.596022652728217, 30.51934392111642, 42.85410567692348, 31.715128898620605, 23.355666058404104, 33.66339683532715, 52.363424164908274, 50.18462542125157, 28.25886389187404, 1.7416121172053474, 0.02789019128041608, 0.05918841290154627, 0.04788875566529376, 0.05262666375243238, 0.05111455524872456, 0.060057222710124085, 0.0538690274448267, 0.05881861810173307, 0.05658996983298233, 0.06059498206845351, 0.061267098145825524, 0.0448257943083133, 0.021853104067434157, 0.0517300272227398, 0.025063707859122326, 0.042017999437770674, 0.03385351664785828, 0.10504239132361752, 0.12651187713657105, 0.1546649464539119, 0.12556039462132113, 0.10038494731166533, 0.1230589888457741, 0.10335993660347802, 0.27608528680035044, 0.09186622513724224, 0.14555992931127548, 0.16337675255324158, 0.14468244782515935, 0.1391343248209783, 0.11823393989886556, 0.1544075102678367, 0.1559400630316564, 0.17190169010843548, 0.1355840124722038, 4.36453526360648, 36.00991119657244, 55.00779390335083, 52.51216772624424, 32.78226797921317, 25.383371012551443, 51.02180344717843, 47.2128461429051, 19.11405658721924, 1.531627459185464, 0.3145538797335965, 10.089261174201965, 11.571303248405457, 15.685723338808332, 15.351714747292654, 10.237297756331307, 21.680144446236746, 26.155689341681345, 33.170877252306255, 24.203443561281475, 46.65147686004639, 46.801592690604075, 53.05075734002249, 47.15974453517369, 50.13170446668352, 46.05170488357544, 42.07951007570539, 39.121825218200684, 38.85315922328404, 34.935153416224885, 37.82372454234532, 39.24841792242867, 43.853107248033794, 45.25517381940569, 48.0279358455113, 45.97958953039986, 46.41064534868513, 41.394747734069824, 40.66414812632969, 35.438088348933626, 36.847745827266145, 34.569268226623535, 36.747323513031006, 34.09682546343122, 34.508513178144185, 33.8940874508449, 37.41319717679705, 35.8626059123448, 36.18351193836757, 35.690995829445974, 36.34188222885132, 38.68552698407854, 35.27266216278076, 37.64668096814837, 38.37814910071236, 35.325624806540354, 34.167863845825195, 35.29696348735264, 37.98405769893101, 41.5480249949864, 38.425862380436485, 38.13522618157523, 36.34426546096802, 35.16712250028338, 38.660225118909565, 45.553724016462056, 46.06966945103237, 47.991596766880576, 49.0759847504752, 39.84589351926531, 32.79241929735456, 50.32588924680437, 49.08225202560425, 47.770015239715576, 51.31998886380877, 47.58927869796753, 51.35813447407314, 47.45783615112305, 46.04536812646048, 49.77311141150338, 49.86757564544678, 45.84499944959368, 37.059554713112966, 37.50453472137451, 37.72418812343052, 40.9617394719805, 38.79145574569702, 39.78989451272147, 43.41028118133545, 49.11420331682478, 51.37358726773943, 50.721550941467285, 49.87202596664429, 49.077044350760325, 47.51102808543614, 50.86318302154541, 49.99280302865164, 50.319323199135916, 50.71789966310774, 49.92160831178938, 50.17917455945696, 44.112292425973074, 45.754599911826, 48.282149587358745, 48.46368517194475, 43.572580678122385, 42.03170299530029, 38.43472480773926, 38.3821964263916, 38.40117195674351, 38.97037533351353, 43.50260884421212, 46.96098436628069, 49.660811151777, 51.796065534864155, 52.362121377672466, 52.346359389168875, 45.830453395843506, 50.121209212711875, 48.538642338344026, 43.585014479500906, 38.8130646433149, 29.017195497240337, 28.83904889651707, 24.634608813694545, 12.805083581379481, 8.888596824237279, 6.345334231853485, 2.1086002247674123, 0.32959189851369175, 0.16465642888631138, 3.5547796062060764, 33.73254530770438, 45.72759573800223, 38.18622248513358, 31.892314910888672, 39.39377423695156, 58.33843721662249, 56.63880014419556, 34.510055678231375, 2.747647328036172, 0.14315999166241714, 0.14120715430804662, 0.14466161680008682, 0.1842432107244219, 0.11392236554196902, 0.16216236485966615, 0.09897475476775851, 0.16049642568188055, 0.1745253407529422, 0.13476869836449623, 0.1885326648397105, 0.1411061068730695, 0.07300166240228073, 0.17328191176056862, 0.07336214770163808, 0.19590355003518717, 0.14671064327870095], [0.09870927115636212, 0.08171625728053705, 0.06939512664186102, 0.058130210398563316, 0.04452997000355806, 0.0046154838304833645, 0.07138104257839066, 0.061347205990127156, 0.03516532839941127, 0.12860587691622122, 0.06741917838475533, 0.04968308384663292, 0.05115742848387786, 0.024274006752031188, 0.11135972198098898, 0.05759832715349538, 0.040723636214222224, 0.04198247134419424, 3.688841623919351, 22.462438651493617, 44.78897401264736, 36.05251407623291, 17.0280145577022, 16.663345302854264, 33.29202951703753, 37.96978957312447, 13.202772412981306, 0.6067025331514222, 0.8640188628009388, 10.240102222987584, 7.5071195023400445, 1.664502746292523, 2.6566580619130815, 1.8125206551381519, 12.849666697638375, 19.851184027535574, 16.83755053792681, 27.824806451797485, 44.945305006844656, 45.18805422101702, 48.848525047302246, 44.24198055267334, 44.511244092668804, 41.10972567967006, 40.155032770974294, 36.552777426583425, 37.47221170152937, 34.87080267497471, 34.582834584372385, 32.12823404584612, 32.771484375, 32.59564283915928, 34.990266527448384, 34.87360279900687, 33.61176824569702, 32.816171714237754, 33.61310577392578, 31.86587701525007, 32.06844827107021, 31.775178704942974, 30.75689240864345, 29.979795455932617, 30.296501295907156, 31.667655331747874, 31.972653457096644, 30.18962757928031, 32.29895823342459, 32.04935114724295, 32.237424986703054, 30.6856038911002, 33.058173997061594, 33.70359563827515, 32.60245554787772, 31.866502353123256, 32.774941103799, 33.546281473977224, 33.81836250850132, 31.83927583694458, 32.939870493752615, 31.651622363499232, 32.20807926995413, 33.12325429916382, 39.16904864992414, 41.49845307213919, 44.61896896362305, 45.07081726619175, 44.35436071668352, 40.037458828517366, 22.526249170303345, 42.466646330697195, 45.81559814725603, 47.28084468841553, 45.29443808964321, 45.19638163702828, 42.95056404386248, 40.93129941395351, 37.720863410404746, 43.159958430698936, 44.13547509057181, 44.016455922807964, 33.94774144036429, 32.82152877535139, 33.641749722617014, 36.96175534384591, 34.74988317489624, 33.42977408000401, 33.421523094177246, 35.77393995012556, 37.101681641169954, 40.25927659443447, 39.915938309260774, 39.896868978227886, 41.27613156182425, 42.22856283187866, 43.1072598184858, 42.08654165267944, 43.06010586874825, 45.68679244177682, 46.083478995731895, 44.061650480542866, 44.48167603356497, 45.50686536516462, 45.699862003326416, 43.44716569355556, 40.99669238499233, 34.945759841373985, 34.406374658857075, 34.06737552370344, 37.27085985456194, 40.035607133592876, 39.30870049340384, 40.96125309807913, 42.84885631288801, 47.44855335780552, 47.33279636928013, 44.58351925441197, 40.673152991703574, 41.70922320229666, 48.23456137520926, 46.7968818119594, 34.35537140710013, 19.082129614693777, 19.49471538407462, 7.099873857838767, 6.720334155218942, 2.8289436399936676, 0.8646643938762801, 0.09467985880162035, 0.06540585641882249, 1.5940332476581847, 20.50986977985927, 54.30977439880371, 36.34540149143764, 27.86305628504072, 40.90421186174665, 46.361420835767476, 45.20178733553205, 23.8513331753867, 1.4653532611472266, 0.025469020574486682, 0.08070179314485618, 0.04759312474301883, 0.029481484820800166, 0.015845743473619223, 0.009322043175676038, 0.005867883055803499, 0.009515921834723225, 0.06478169241121837, 0.03317180608532258, 0.021115125988477042, 0.04454008356801101, 0.020021259684913924, 0.10654442358229842, 0.03255469544923731, 0.017467716974871497, 0.003940259214557175, 0.02129553827191038, 0.06263354553708009, 0.043785193003714085, 0.03677455222766314, 0.012117329253149884, 0.02653224254027009, 0.025192202035603777, 0.06872826242553336, 0.011404264435571219, 0.05623918419171657, 0.03687933499791792, 0.01745255341354225, 0.042847844372902594, 0.014263243747076817, 0.07428364575441394, 0.04313502414152026, 0.03261191291468484, 0.1202705627573388, 5.339186438492366, 28.323028768811906, 52.01771306991577, 41.481871196201865, 21.894272293363297, 17.74834646497454, 34.890716212136404, 40.233950410570415, 15.896050521305629, 0.5495435574225017, 1.090733643089022, 15.442816053118024, 13.861106412751333, 3.379850889955248, 6.8235922030040195, 3.8561590228761946, 13.200642790113177, 23.21966896738325, 16.200900997434342, 31.44454172679356, 46.58407585961478, 47.60003103528704, 49.979059491838726, 46.39534541538784, 44.67259863444737, 43.0024288722447, 40.93800095149449, 37.95508023670742, 39.070957456316265, 36.166867528642925, 36.4959967476981, 33.45730979101998, 35.4917562348502, 35.183148520333425, 37.862328733716694, 36.24639660971505, 36.71493795939854, 35.277484212602886, 34.69018077850342, 33.71072449002947, 33.78438581739153, 33.47022649220058, 32.19224779946463, 31.38446065357753, 32.08342858723232, 32.382166385650635, 33.59723261424473, 31.835006168910436, 33.15995121002197, 32.66992255619594, 32.58375794546944, 32.67970214571272, 35.50804628644671, 35.80636024475098, 34.61485883167812, 33.6238511630467, 34.46864441462925, 35.648059436253135, 34.17581605911255, 34.1955315726144, 34.59606395448957, 33.596610750470845, 33.54262672151838, 34.37773071016584, 40.23934916087559, 43.55449104309082, 47.58385910306658, 48.72537170137678, 45.0780086517334, 41.02915436880929, 23.927789415631974, 43.37768370764596, 47.641067096165244, 48.098032746996196, 46.7252528326852, 46.954126494271414, 43.53907299041748, 42.386234828404014, 39.09297282355172, 46.79693044934954, 45.82804584503174, 47.0481390953064, 34.748462268284385, 34.07807922363281, 35.02806125368391, 38.6694974899292, 36.07996988296509, 34.38917786734444, 35.94102675574166, 36.88144111633301, 39.78707006999424, 43.48543984549386, 43.155244077954976, 42.332883085523335, 44.01500374930245, 45.26046139853341, 45.13583156040737, 44.4765065738133, 45.68777213777815, 46.29919276918684, 48.01912552969796, 45.59871012823922, 45.72847121102469, 47.53143147059849, 47.65272617340088, 46.180131912231445, 41.89370482308524, 36.30618238449097, 36.80157157352993, 35.079602990831646, 38.85337461744036, 41.35451071602957, 40.49043621335711, 42.53479078837803, 46.14006165095738, 50.11322920663016, 49.79025609152657, 46.257642541612896, 43.777938161577495, 43.9224294253758, 50.90568515232631, 47.64189740589687, 33.302285058157786, 17.23785710334778, 10.162819147109985, 8.928137285368782, 8.82414880820683, 9.944610101836068, 2.3234011786324635, 0.10099733195134572, 0.02552303026563355, 1.8384470982210976, 22.38085811478751, 47.10407556806292, 34.02338300432478, 29.419054985046387, 42.76779167992728, 51.62326731000628, 50.3552245412554, 29.382910455976212, 2.4165387409073964, 0.04908295015671423, 0.0954486932605505, 0.03537008312663861, 0.015783842420205474, 0.0625570271430271, 0.02983487264386245, 0.010319266584701836, 0.030994197220674584, 0.033745113893279007, 0.030029985388474803, 0.02855675694133554, 0.020613072839166437, 0.02183900071707155, 0.027588292390906384, 0.03291727402912719, 0.02402707259170711, 0.0253642886943583, 0.22036260685750417, 0.23611463446702274, 0.122830919655306, 0.19418802351823874, 0.20304111417915138, 0.10873919938291822, 0.11101458514375345, 0.14258539463792527, 0.11423864428486143, 0.1589656099677086, 0.2003905392651047, 0.08168321262512888, 0.17639467758791788, 0.10329175740480423, 0.15481339634529181, 0.09176382063222782, 0.0967733021825552, 0.176061571176563, 7.004558035305568, 37.82298108509609, 58.87217698778425, 47.66932194573538, 27.234199149268015, 25.786790370941162, 42.547054358891074, 48.86943565096174, 19.1651188986642, 0.8300895605768476, 1.115101084113121, 16.612811054502213, 14.192868999072484, 2.502622578825269, 6.36975063596453, 5.3492417846407205, 18.534550768988474, 23.930742400033132, 20.5656829220908, 35.41375923156738, 50.52246420724051, 48.446092333112446, 53.80146503448486, 48.53675937652588, 46.74580560411726, 45.2816047668457, 43.56446170806885, 39.498146602085654, 41.80121040344238, 39.132553236825125, 39.59773513248989, 35.45674078805106, 36.813908100128174, 36.41555397851126, 38.209589276994976, 39.04529775891985, 38.56260987690517, 36.80831132616316, 37.34049122674124, 35.42961154665266, 35.39240394319807, 35.6378629548209, 33.48280620574951, 32.84862674985613, 33.41341802052089, 34.61615814481463, 34.85507542746407, 32.93471840449742, 34.91469097137451, 35.262510844639365, 33.69241598674229, 35.56059203829084, 36.54949787684849, 38.37664481571743, 35.686177253723145, 34.63905593327114, 36.08409363882882, 37.144791739327566, 37.570730209350586, 35.87016555241176, 37.50234603881836, 35.51683923176357, 36.185526915958945, 37.25387845720564, 43.332843508039204, 45.52665730885097, 49.95081853866577, 48.94031769888741, 45.22707183020455, 41.50209392820086, 28.295955113002233, 42.541704245976035, 49.813813958849224, 50.16852991921561, 47.38222237995693, 46.887986591884065, 43.417326654706685, 42.99355254854475, 40.87852437155587, 47.79137052808489, 48.325068610055105, 48.854389326913015, 37.562361104147776, 36.468971729278564, 38.270146301814485, 41.17338507516043, 38.346062319619314, 35.303001471928184, 37.07383673531668, 38.167149680001394, 41.21272577558245, 44.57663706370762, 44.10660185132708, 43.124407972608296, 44.463371004377095, 45.61253704343523, 47.487890584128245, 46.80120359148298, 47.8282585144043, 49.25633219310215, 49.71482297352382, 48.00647286006382, 47.22162866592407, 48.16396072932652, 49.55036606107439, 47.661581652505056, 44.87382541384016, 38.238118580409456, 38.498957429613384, 37.216538837977815, 41.184182575770784, 44.49117422103882, 42.35516595840454, 45.37069804327828, 47.983707087380544, 50.92963906696865, 50.40373338971819, 46.42887394768851, 44.31500611986433, 47.24154915128435, 51.6317024230957, 46.09061826978411, 37.046321868896484, 23.967109271458217, 24.871387788227626, 9.711604867662702, 12.122763531548635, 6.60335602079119, 2.836867626224245, 0.4653409442731312, 0.25945509916969706, 2.0646541714668274, 27.616143362862722, 66.11041423252651, 47.296801226479666, 36.58752884183611, 50.79147066388811, 56.77392871039254, 58.12820209775652, 34.6107246535165, 3.576529856239046, 0.1445244305900165, 0.32489062792488504, 0.15089154536170618, 0.20587398431130818, 0.1354763832475458, 0.11115963557468993, 0.16574007645249367, 0.12778351961502007, 0.13052116414265974, 0.09146626267049994, 0.11940183437296323, 0.10139914003333875, 0.08467851047004972, 0.19734307564795017, 0.12755443262202398, 0.10816401203296014, 0.09726523328572512], [0.05553579782801015, 0.024014936992898583, 0.015481041079120976, 0.005878551322634199, 0.03773160890809127, 0.060502015985548496, 0.08656861047659602, 0.01042360661085695, 0.056236775392400365, 0.012114856841175683, 0.031658449077180455, 0.050399708428553174, 0.02410065971447953, 0.0485886170395783, 0.016839676835973347, 0.04409843869507313, 0.045073527443621836, 0.10069817264697381, 3.9711451956204007, 25.48111479622977, 43.481503690992085, 39.330410139901296, 30.92472267150879, 22.538700342178345, 43.00467314038958, 44.308450494493755, 9.5789680991854, 0.21722837218216487, 1.7093696530376161, 1.6398550974471229, 1.116617528455598, 5.283705507005964, 2.985327179942812, 3.588696369103023, 10.850800241742816, 12.303518312317983, 19.439972264426096, 36.331974097660606, 44.58277232306344, 49.436686583927695, 43.937659876687185, 44.14177015849522, 42.10752521242414, 42.934020383017405, 39.50442082541329, 39.43130840573992, 38.969489438193186, 39.191480909075054, 39.9957731110709, 35.80778462546212, 32.202378273010254, 31.915723391941615, 30.39217104230608, 31.598166397639684, 30.81628908429827, 32.3589767728533, 31.813001223972865, 32.62589182172503, 33.2640734400068, 32.559286390032085, 32.607385294778005, 34.5003525188991, 35.70901598249163, 35.622649874006, 35.67344467980521, 34.157538822719026, 32.23971094403948, 32.04394197463989, 32.32463182721819, 35.46622507912772, 36.92952265058245, 36.4592581476484, 34.845869064331055, 34.225617272513254, 32.97096368244716, 31.035094806126185, 31.66760322025844, 31.592767647334508, 31.210248470306396, 32.98194183622088, 32.38304533277239, 36.46579640252249, 39.77617876870291, 44.27701684406826, 44.9155250276838, 46.673454012189595, 42.74499464035034, 41.556057112557546, 21.876573494502477, 41.41285473959786, 39.69644471577236, 40.855386870247976, 40.5943534714835, 41.62130764552525, 42.17606224332537, 41.90943207059588, 38.09753220421927, 40.85738100324358, 45.07003211975098, 43.62082896913801, 34.189035006931846, 33.89057513645717, 35.045834745679585, 33.257323265075684, 32.80882746832711, 32.90871129717146, 32.98282773154122, 33.228099141802105, 33.78820037841797, 33.08782196044922, 32.5139285496303, 32.7146828515189, 33.48829528263637, 34.69276898247855, 35.34644855771746, 37.611477919987266, 40.398052964891704, 43.32541240964617, 44.292980330330984, 46.262169292994905, 45.3791435786656, 44.05384765352522, 48.17551210948399, 46.585111141204834, 40.973030294690815, 36.685692991529194, 33.215793882097515, 40.11586924961635, 45.312201159340994, 44.940340518951416, 45.581530707223074, 43.25359582901001, 45.5264036996024, 46.46543189457485, 50.82602405548096, 45.492642402648926, 45.15387603214809, 55.85536296027047, 51.901504448481965, 45.2533985546657, 34.58022206170218, 20.44045032773699, 11.516254408018929, 12.829292842320033, 7.74102018560682, 8.874302642686025, 1.2197754787547248, 0.1093374297821096, 0.051888438008193455, 0.6952554785779544, 21.666254997253418, 34.8078658921378, 33.3639155796596, 29.486327443804058, 38.11260632106236, 44.94294956752232, 42.7207419531686, 24.67725338254656, 1.9334754390375954, 0.062791528845472, 0.03454546630382538, 0.0779835886455008, 0.07695775904825755, 0.027815791611958827, 0.034331761699702056, 0.02896114006372435, 0.05605448017429028, 0.018663461918809583, 0.052896462846547365, 0.03953178945396628, 0.025560432812198997, 0.030502863228321075, 0.024202473894027726, 0.07619663274713925, 0.007497241986649377, 0.010259063565172255, 0.04422075481020978, 0.018119524499135356, 0.05221795496929969, 0.013980913807504942, 0.040597187820822, 0.02005308467362608, 0.026917804797579135, 0.051032058961157284, 0.026268049841746688, 0.01789491414092481, 0.03925650440422552, 0.050729595191244564, 0.037241333430366855, 0.027302274613508155, 0.021706204628571868, 0.006123686516990087, 0.030495853961578438, 0.055588723559464724, 5.312128850391932, 30.163512774876185, 49.34291022164481, 43.83494813101632, 30.964629650115967, 26.599337032863072, 42.8730742590768, 47.23381233215332, 12.517990095274788, 0.30052907658474787, 2.1506793839590888, 4.876288328851972, 2.9478464254311154, 4.404908205781664, 3.760699893747057, 5.0149882691247125, 12.302474345479693, 12.569003769329615, 19.495441470827373, 39.05044984817505, 46.315232685634065, 49.479539598737446, 47.40519659859793, 46.537804331098286, 44.630336216517854, 43.201498235974995, 41.29368271146502, 41.31085171018328, 40.107131889888215, 41.13045563016619, 40.746602399008616, 36.3519640650068, 33.328455448150635, 32.420086179460796, 32.66817855834961, 33.95913996015276, 32.340345178331646, 32.30055979319981, 32.83659594399588, 33.704974855695454, 34.73563936778477, 34.02749981198992, 33.48153468540737, 34.952200821467805, 36.40505525044033, 37.44759770802089, 36.413577216012136, 34.61844410215105, 33.240321023123606, 31.980570929391043, 33.84985521861485, 37.453361238752095, 38.40390607288906, 39.81395265034267, 35.98787498474121, 36.537008489881245, 34.361166204724995, 33.9323650768825, 33.731558663504465, 34.420917238507954, 31.200041566576274, 34.82092155729021, 34.02070099966866, 39.300935881478445, 42.55144214630127, 46.276534693581716, 45.07033436638968, 47.87796592712402, 44.36134365626744, 41.53921815327236, 23.584114142826625, 40.971407890319824, 40.68965148925781, 40.511888776506694, 41.80431972231184, 42.28664977209908, 42.84311362675258, 41.84111043385097, 39.455623626708984, 42.846400124686106, 47.44896330152239, 45.684767041887554, 34.66000822612217, 35.95148032052176, 35.313885825020925, 34.83680166516985, 35.02930498123169, 34.36097512926374, 34.21541036878313, 33.9985362461635, 34.61862128121512, 34.720329012189595, 34.8596681867327, 35.186414173671174, 35.67107881818499, 37.121449266161235, 37.74914605276925, 39.914156096322195, 42.31697865894863, 45.17190660749163, 45.09959670475551, 48.34595142092024, 48.18820994240897, 45.25677537918091, 49.03833246231079, 48.930572850363596, 43.559313092912944, 38.23368910380772, 34.30063349860055, 41.14480018615723, 47.07001549857003, 46.273171765463694, 45.90140145165579, 45.134316853114534, 47.27742617470877, 49.39528226852417, 50.99981934683663, 45.44695104871477, 45.28582579748971, 54.76902948107038, 51.07182352883475, 45.86881440026419, 35.48517976488386, 21.38548697744097, 8.976419448852539, 10.963474835668292, 12.065276741981506, 11.757258755820137, 3.816243359020778, 0.21330582909286022, 0.04787069645577243, 0.7870801570160049, 23.614390918186732, 46.39841651916504, 39.74766336168562, 31.899937084742955, 42.55220644814627, 50.97262062345232, 48.32842458997454, 29.773569447653635, 2.473020430122103, 0.024121190487806286, 0.03651997267401644, 0.07306107492851359, 0.04485261340492538, 0.019843826170212457, 0.040110684997801266, 0.032674735079386404, 0.0036392229126899368, 0.021368239906483462, 0.08288588201893227, 0.02465061573976917, 0.024661194100709896, 0.041384525929710696, 0.0069279600117754725, 0.049908337116773636, 0.018247592894892608, 0.04654472367838025, 0.1412025402699198, 0.07828533316829375, 0.12325154351336615, 0.07321859683309283, 0.15057618942643913, 0.11461759252207619, 0.10308652091771364, 0.09057822317949363, 0.11552111618220806, 0.13733392714389733, 0.08461675021265234, 0.10899159405380487, 0.08279089390167169, 0.09489653538912535, 0.11651001311838627, 0.08550688637686626, 0.06536243696297918, 0.3587618204099791, 7.621444293430873, 37.69534962517874, 56.129080295562744, 51.09512431280953, 39.516739981515066, 34.17583690370832, 50.655737604413716, 53.18890489850725, 13.995475888252258, 0.43618179751294, 3.2138610311916898, 3.9874191795076643, 1.3636327194316047, 11.873601998601641, 6.818112245627812, 7.000727406569889, 15.172472068241664, 15.394816160202026, 24.68044260569981, 42.61392729622977, 50.410931723458425, 52.988984380449565, 49.09245892933437, 48.43278305871146, 47.562013966696604, 46.78482321330479, 43.99664660862514, 43.548981121608186, 42.58928203582764, 43.976899828229634, 44.30159957068307, 38.31678261075701, 35.875011920928955, 34.32908289773123, 33.393976960863384, 35.76202031544277, 35.070059640066965, 35.94024855749947, 34.8130909374782, 36.99382128034319, 38.2795159476144, 36.41815955298287, 35.7437743459429, 37.583264759608674, 38.80563007082258, 39.66342340196882, 39.26309251785278, 38.05402258464268, 35.87328181947981, 34.77947555269514, 35.970299516405376, 38.375474044254844, 41.14195837293352, 40.92092227935791, 38.605351720537456, 38.25696904318673, 36.24912377766201, 35.22492803846087, 35.83540371486119, 36.42230415344238, 34.0887725012643, 36.5727778162275, 36.64256204877581, 40.594898905072895, 44.61237859725952, 48.247849805014475, 46.32130193710327, 49.108154909951345, 44.401149885995046, 42.58668688365391, 26.499243021011353, 41.2584171295166, 40.539598192487446, 40.43093531472342, 41.9114157812936, 43.00735167094639, 42.74653019223894, 42.61571645736694, 41.32500171661377, 44.29894535882132, 49.45854214259556, 47.16240222113473, 37.00679704121181, 37.867414815085276, 38.84251805714199, 35.99662276676723, 36.64352090018136, 35.16766445977347, 36.436617442539756, 35.227394648960654, 36.07922642571585, 36.38517992837088, 36.55221462249756, 36.5831549508231, 37.06069074358259, 38.76108864375523, 40.24835055215018, 41.185075419289724, 44.13999489375523, 45.71310874394008, 47.677315848214285, 51.08096388408116, 48.52254336220877, 45.552959714617046, 50.54692186628069, 50.96129853384835, 44.95774575642177, 41.30719000952584, 37.60462352207729, 45.03294610977173, 48.9177360534668, 48.4022387777056, 49.06574310575213, 47.02425813674927, 50.49419546127319, 51.73160014833723, 55.08320270265852, 47.35347768238613, 48.94631746837071, 54.07916021347046, 50.43160956246512, 46.617465427943635, 37.155964442661826, 24.275468587875366, 18.594369547707693, 27.714642763137817, 15.232191835130964, 15.955230065754481, 3.26348853962762, 0.5719307618481773, 0.11843973957002163, 1.407336562871933, 28.64797864641462, 47.911428451538086, 41.146384375435964, 38.42211035319737, 48.53379596982683, 56.206059387751985, 55.425665514809744, 35.63106414249965, 3.6781001431601386, 0.19025581809026854, 0.17109158714967115, 0.1413321133170809, 0.22196057039712155, 0.11331038123794965, 0.11404789452041898, 0.10439375934324094, 0.15930023629750523, 0.0561059809822057, 0.21327118309480803, 0.07878252291785819, 0.09046028700790235, 0.15636083616742066, 0.13855011974062237, 0.19853542452411993, 0.11950619305883135, 0.14347575471869536], [0.07084348678056683, 0.02237332838454417, 0.025939265698460594, 0.03133585656593953, 0.07772745524666139, 0.045077028684318066, 0.030115837031709294, 0.03269661104838763, 0.035683070974690576, 0.03818360483273864, 0.020067014997558932, 0.07299185757126127, 0.07564930604504687, 0.04373441483559353, 0.058211756737104485, 0.026645710558763573, 0.00930637919477054, 0.03180192530687366, 1.7349478176661899, 29.407479286193848, 44.68039798736572, 39.60112237930298, 26.30557414463588, 25.299831083842687, 53.510019370487754, 35.142227104731965, 10.040986827441625, 0.3087017594703606, 3.253274904830115, 7.546979580606733, 1.852386053119387, 1.322356185742787, 3.8715775098119463, 2.791739727769579, 10.966480800083705, 16.310467141015188, 27.731584208352224, 42.61253070831299, 44.545203413282124, 45.422163350241526, 43.411375522613525, 42.28003508704049, 38.49872466496059, 42.59609474454607, 42.95847804205758, 44.60018450873238, 40.798720836639404, 43.87336819512503, 41.254877022334504, 38.823796136038645, 33.47163002831595, 33.29493733814785, 33.84929241452898, 31.438038212912424, 34.81832987921578, 40.47620282854353, 43.50843143463135, 43.24619599751064, 42.46876553126744, 42.59320081983294, 41.42845344543457, 42.493924958365305, 42.50765112468174, 44.068695953914094, 44.1018944467817, 41.83188322612217, 35.326552391052246, 31.03734254837036, 32.33920567376273, 36.09390796933855, 39.7124742099217, 38.27566317149571, 34.672563620976035, 32.43416322980608, 32.47479976926531, 31.772562708173478, 32.199574674878804, 31.68175322668893, 31.20761510304042, 31.950339317321777, 33.531943866184776, 39.26203291756766, 40.03780623844692, 41.15708807536534, 42.11627994264875, 44.388062953948975, 44.3019608770098, 43.99174812861851, 23.46812960079738, 39.96569088527134, 41.471761567252024, 41.08529233932495, 40.00597654070173, 40.458200045994346, 44.52575193132673, 42.99860388892037, 44.59849262237549, 45.06981325149536, 43.93383836746216, 41.34223672321865, 34.044679233006065, 33.27734797341483, 33.076763902391704, 34.90080499649048, 32.790286200387136, 32.31925739560808, 32.32065050942557, 32.65205178941999, 33.6609719140189, 31.6963791847229, 31.272598130362375, 32.03159849984305, 31.326352868761333, 34.11804526192801, 32.60107980455671, 32.707081522260395, 33.32006549835205, 36.79912233352661, 41.90943207059588, 43.202304227011545, 46.14425836290632, 44.77189881461007, 44.18538400105068, 48.724756785801475, 43.46843065534319, 37.03555563517979, 33.56161962236677, 43.30146196910313, 47.897948946271626, 50.41727890287127, 48.03235837391445, 48.60464675085885, 47.773023809705464, 50.230236870901926, 46.310594763074604, 49.47831671578543, 52.691802978515625, 47.365102018628804, 45.855543340955464, 49.624374798366, 43.29483686174665, 29.61375740596226, 12.837006211280823, 9.311435529163905, 11.339744976588658, 19.097412177494594, 4.079494535923004, 0.06428831602845873, 0.04643124887453658, 0.8993731971297945, 14.860871417181832, 38.29801205226353, 21.71174659047808, 26.189296041216167, 39.0059848512922, 41.94326632363455, 49.01384701047625, 28.814886535917008, 2.4657836641584123, 0.0014411074475252203, 0.039625824229525666, 0.01484943354236228, 0.009951230038755705, 0.03983468748629093, 0.03748172142409852, 0.03239336357052837, 0.02751531934232584, 0.05344806431925722, 0.1076731462297695, 0.03753310688106077, 0.047295855158673863, 0.10669310417558465, 0.023411322418334227, 0.03018227239538516, 0.014342606899195483, 0.03939433861523867, 0.016770678306264535, 0.05053692517269935, 0.014295435144699045, 0.03279240322964532, 0.005030374915804714, 0.05681838168363486, 0.07397070540381329, 0.05079901271632739, 0.05924887037170785, 0.010304895213006862, 0.07926281714545828, 0.06130848878196307, 0.09610288244272981, 0.013576334758129503, 0.057146823166736534, 0.02363503541398261, 0.012126431800425053, 0.11794601034905229, 3.387564476047243, 35.21984543119158, 49.86713443483625, 45.577726568494526, 33.90583338056292, 28.33006729398455, 54.269714559827534, 41.057468278067454, 10.554227675710406, 0.2594982539968831, 3.393871486186981, 8.257808089256287, 3.381035340683801, 6.323178597858973, 7.988954492977687, 4.9695978590420316, 12.214823688779559, 13.624938879694257, 30.95667048863002, 45.418852533612935, 47.01707369940621, 46.97501277923584, 44.704237256731304, 44.09541525159563, 40.7972617149353, 45.02135304042271, 43.708796637398855, 45.09912075315203, 43.647107056209016, 45.55792072841099, 42.91681316920689, 40.24662045070103, 35.386293002537315, 35.45592090061733, 34.5927357673645, 33.00087915148054, 36.12660966600691, 40.94583851950509, 44.372346128736226, 45.34611531666347, 44.1314868245806, 43.195460251399446, 42.857246262686594, 45.34006690979004, 43.92311382293701, 45.82390819277082, 45.36113732201712, 42.54652629579817, 36.969221183231895, 32.226825509752544, 33.64014121464321, 38.365416526794434, 40.674202169690815, 40.4785270009722, 37.07949256896973, 34.63985497610909, 33.6750420161656, 34.23682819093977, 34.45573466164725, 33.37823234285627, 33.75760398592268, 34.454824447631836, 35.983660902295796, 41.05451529366629, 42.91087245941162, 44.21027592250279, 44.27327176502773, 46.4417906488691, 46.250680446624756, 44.81144101279122, 25.655764716012136, 40.49967731748308, 40.572602135794504, 40.78591878073556, 40.625731536320274, 41.080373014722554, 44.53156409944807, 44.67979349408831, 45.742916515895296, 46.534715856824604, 45.593144621167866, 42.73847028187343, 35.577351093292236, 34.38388334001814, 34.25737401417324, 36.3403570992606, 34.1325808933803, 33.60914182662964, 32.76747179031372, 35.42977830341884, 34.962928840092246, 32.252019677843364, 32.86923163277762, 33.6148567199707, 34.70249646050589, 34.92087139402117, 34.24742071969168, 34.6170266696385, 35.638755798339844, 39.57032796314785, 44.1672283581325, 47.04843439374651, 49.32380267551967, 45.02556364876883, 44.946573053087505, 49.964079175676616, 44.55671310424805, 39.88026973179409, 35.93901525224958, 46.2980671610151, 49.00628389630999, 51.65008735656738, 50.159782137189595, 50.08443587166922, 48.64255264827183, 52.19242899758475, 48.36340182168143, 48.767317976270405, 50.44143778937203, 47.38391426631382, 45.495310510907856, 49.65255321775164, 42.51587431771414, 30.52191128049578, 11.318988101822988, 9.489740201405116, 10.249448418617249, 17.12739290509905, 4.578041246959141, 0.21843070909380913, 0.14485942332872323, 0.7887902823942048, 18.91534158161708, 40.42358064651489, 26.704027278082712, 31.05359091077532, 42.92230919429234, 47.89995697566441, 55.28984212875366, 32.101115226745605, 3.115984146084104, 0.018210263290841664, 0.02740587164381785, 0.07669048410441194, 0.006712944986897388, 0.13044169412127563, 0.05238819940547858, 0.03854465331616146, 0.062266302028937, 0.028257107395412664, 0.07022749233458724, 0.059070415661803315, 0.030685982866478816, 0.05433516064658761, 0.017762213047327738, 0.03554175587903176, 0.049473294389567206, 0.007736343308351934, 0.11282228385763508, 0.10603954603097268, 0.10842906138194458, 0.13003146541970118, 0.13602092117071152, 0.13971330518169062, 0.11872465642435209, 0.1679494543267148, 0.13739722089043685, 0.09860259188073021, 0.14313247028206075, 0.1452820963625397, 0.24779577766145977, 0.08539679407009057, 0.11753690801560879, 0.1042653126642108, 0.06428856030106544, 0.24332159917269433, 5.709530200277056, 44.44737277712141, 55.81028304781233, 51.938138825552805, 34.90575558798653, 35.04106828144619, 60.0503899710519, 41.95196199417114, 14.22014762674059, 0.5394869627697128, 3.5745044563497816, 9.015764491898672, 5.222013754504068, 8.608154501233782, 11.788688932146345, 6.477879370961871, 16.918771505355835, 18.22971592630659, 32.1930433682033, 48.65020261492048, 47.822939668382915, 50.10444320951189, 47.87776442936489, 46.0719449860709, 42.263936110905235, 47.15318543570382, 46.72898054122925, 49.99515846797398, 44.38000999178205, 47.969970498766216, 44.60723693030221, 42.46627460207258, 35.90036242348807, 36.12467459269932, 37.41051517214094, 34.013544355119976, 40.158513818468364, 44.55580636433193, 47.55900192260742, 47.79724175589425, 47.03498615537371, 46.51727587836129, 46.07453319004604, 48.16895301001412, 46.33809920719692, 49.26716096060616, 47.56609255926949, 45.200946603502544, 40.722589424678254, 33.579476492745535, 35.64045115879604, 40.22926385062081, 43.19577986853463, 42.51895236968994, 39.02729150227138, 36.26689032145909, 36.539964948381694, 35.08685343606131, 35.83861378261021, 36.04678528649466, 34.590981347220286, 36.92045872552054, 38.8824736731393, 43.46129138129098, 45.20970828192574, 45.82877540588379, 47.0994029045105, 49.71789060320173, 48.98223270688738, 45.79267604010445, 28.93031348500933, 41.38499246324812, 41.299779755728586, 40.30866091591971, 40.70366253171648, 40.962062563214985, 45.97376693998064, 48.22564683641706, 47.95808560507638, 48.743437017713276, 47.17328657422747, 44.089516230991904, 37.02065174920218, 36.366986070360454, 35.558021204812185, 39.09044715336391, 36.55953107561384, 35.93554810115269, 34.969956942967, 36.487811769757954, 37.94787842886788, 34.08852584021432, 34.183486870356965, 35.271866594042095, 36.28200612749372, 36.83151830945696, 36.46497304098946, 36.064093249184744, 36.49949516568865, 41.140467984335764, 45.98035730634417, 47.84830754143851, 50.593453952244346, 46.231437410627095, 46.06929772240775, 51.55483797618321, 47.8212616784232, 41.857233728681294, 38.586907727377756, 46.98046364103045, 50.831707681928364, 53.93907758167812, 51.1328877721514, 53.62887872968401, 51.34163250241961, 53.995736667088096, 49.43215635844639, 48.77550295421055, 48.63793904440743, 45.92907612664359, 48.82846212387085, 51.73038073948452, 46.81430441992623, 33.59720829554966, 17.330691984721593, 19.007054328918457, 19.31279070036752, 31.862135410308838, 8.152897238731384, 0.16564700858933584, 0.21388772715415272, 1.1282626007284438, 19.74353732381548, 47.61077989850725, 30.460721969604492, 37.614368370601106, 49.45838580812727, 53.92472260338919, 62.24897371019636, 38.55719723020281, 4.177489757537842, 0.12644869195563452, 0.17137744038232736, 0.11636229604482651, 0.13312357664108276, 0.14220739634973661, 0.1023561322529401, 0.1379984300583601, 0.23935621338231222, 0.10371104454887764, 0.25298263505101204, 0.1936702605869089, 0.2098296263388225, 0.19265802204608917, 0.10618237765239817, 0.17819400317966938, 0.11227248728807483, 0.1401598762188639], [0.007119272536199007, 0.010885473523688103, 0.04124641012666481, 0.03834563220984169, 0.018049367370882204, 0.061930732535464425, 0.06486225487398249, 0.033907290548086166, 0.01623429128501032, 0.022746961996225373, 0.051262988176728995, 0.02239988454883652, 0.03953429664086018, 0.07197395326303584, 0.06283756744648729, 0.01946330882076706, 0.0373853423100497, 0.14970032285366738, 3.4144001560551778, 32.05143213272095, 46.021671295166016, 35.989671094076975, 17.187760591506958, 43.17086362838745, 45.60459872654506, 33.171992438180105, 10.929964542388916, 0.37101040886981146, 0.6484831912176949, 11.965805462428502, 11.252432176045009, 3.50290869815009, 5.421228161879948, 4.020459166594914, 7.535693969045367, 17.090935707092285, 34.98900542940412, 40.249788829258506, 48.32592323848179, 44.679334912981304, 43.72689322062901, 38.03000961031233, 38.496581145695274, 37.990151269095286, 40.95419372831072, 42.28693464824131, 44.04264368329729, 45.98087494713919, 42.92886481966291, 40.353153705596924, 32.13244118009295, 34.76822989327567, 36.01733882086617, 31.732982294900076, 40.41437775748116, 44.48539679391043, 46.29100431714739, 44.1154990196228, 45.05644144330706, 43.85032796859741, 44.82909985951015, 46.26146057673863, 44.8531163079398, 43.51503917149135, 45.040943486349924, 44.09442860739571, 43.51124198096139, 37.20081853866577, 35.38222483226231, 42.05217238834926, 42.47998339789254, 38.08775608880179, 33.93044737407139, 31.98912763595581, 31.80822433744158, 32.616730621882844, 32.254027707236155, 32.624047074999126, 31.25687435695103, 32.39211620603289, 34.404418740953716, 34.20876094273159, 36.29749713625227, 39.169451645442415, 38.91891697474888, 40.92139475686209, 42.569601263318745, 47.70819364275251, 26.587896823883057, 38.14041648592268, 43.41347387858799, 39.46147748402187, 44.08299534661429, 45.2766124861581, 42.39056355612618, 45.81112003326416, 44.64972863878523, 42.4424318586077, 42.70122446332659, 35.230055809020996, 32.09011275427682, 34.12409714290074, 33.08595984322684, 34.49331051962716, 34.939930302756174, 33.58394071034023, 35.5785288129534, 37.07376377923148, 37.605526787894114, 33.18336663927351, 30.731656551361084, 30.788669994899205, 33.173177106039866, 33.59947688238961, 33.03804506574358, 33.42518479483468, 33.39709670203072, 33.35049860818045, 35.03376572472708, 41.24175187519619, 44.56172275543213, 46.303097656794954, 45.86483308247158, 47.194617543901714, 42.82706676210676, 37.37544066565377, 34.57907213483538, 42.101462909153526, 48.170241900852744, 48.81470816476004, 47.1988594191415, 49.00998033796038, 47.028510434286936, 47.85497086388724, 46.73861421857561, 47.05442374093192, 44.59476143973214, 49.68042939049857, 49.35716792515346, 50.975684779030935, 44.11482851845877, 32.950522082192556, 11.20098076547895, 2.654791602066585, 13.71049986566816, 10.864337069647652, 6.592114703995841, 0.4142236443502562, 0.12508166102426393, 0.40958466327616144, 14.69012985910688, 43.59892129898071, 40.2399571282523, 26.798022508621216, 39.201343876974924, 47.177493708474294, 49.545068059648784, 32.47544595173427, 2.5276313168661932, 0.05417511459173901, 0.012715108426553863, 0.018840434029698372, 0.048763489084584374, 0.05445440639076488, 0.020884610679266707, 0.06408090144395828, 0.047480932370360406, 0.08096349731619869, 0.017884154271866595, 0.04298202467284032, 0.0541286824404129, 0.11568739797387805, 0.06388950028589793, 0.04542689151795847, 0.0009612569182146606, 0.04365253262221813, 0.038026469693120034, 0.016269902499126535, 0.03010992020634668, 0.032275369723460505, 0.036536786771778546, 0.018965679719778042, 0.007772683947613197, 0.022130421329555765, 0.005320417254032301, 0.04610083285453064, 0.06551723794213363, 0.06267794208335024, 0.04201649309002927, 0.04806082536067281, 0.05830436319644962, 0.022916968945147734, 0.04180848139471241, 0.1389999748872859, 5.428031316825321, 38.06310040610177, 52.722923960004536, 41.82505662100655, 18.99794524056571, 41.58456209727696, 53.69527571541922, 38.079376561301096, 12.043690426009041, 0.2502731904387474, 1.3405371244464601, 8.62152109827314, 6.801228557314191, 4.321778220789773, 7.245544144085475, 4.845690633569445, 8.466967974390302, 19.940784522465297, 36.17696673529488, 44.45961897713797, 49.56992176600865, 47.28454460416521, 43.62496314729963, 40.16490963527134, 39.617669514247346, 40.78456040791103, 42.44717053004673, 43.74871751240322, 45.602340562003, 48.63560792378017, 45.090501512799946, 42.39976644515991, 33.551291125161306, 36.400045599256245, 36.7570857320513, 34.236585003989084, 40.9198557308742, 47.21346453257969, 47.02760716847011, 46.022998401096885, 45.96922281810215, 46.12740898132324, 46.52006210599627, 47.03863048553467, 44.889754159109934, 46.04081358228411, 47.319765022822786, 45.807632037571494, 45.263932023729595, 38.37796149935041, 36.135680539267405, 43.321240016392295, 44.79024205889021, 40.77879687717983, 35.5969033241272, 33.35493155888149, 34.062192167554585, 33.61638879776001, 33.81428044182913, 33.7683459009443, 32.98641300201416, 34.868242263793945, 34.98760884148734, 36.59679079055786, 37.70013345990862, 40.57950864519392, 42.43500076021467, 44.24695198876517, 43.89716924939837, 49.12583807536534, 28.832144124167307, 39.101932525634766, 42.5095340864999, 39.83153159277779, 43.66963659014021, 45.970219884599956, 45.33060346330915, 47.814657415662495, 45.64930691037859, 44.268310751233784, 45.34895018168858, 38.04127958842686, 34.67679507391793, 36.03842312949044, 34.1524110521589, 35.78073876244681, 37.23193952015468, 35.44931663785662, 37.39119918005807, 38.857710293361116, 37.90688405718122, 34.10292598179409, 32.65214559010097, 32.35186876569475, 32.88994421277727, 34.50899955204555, 34.683823176792686, 34.25436544418335, 34.781066690172466, 35.144078799656455, 37.63593210492815, 43.53173916680472, 46.03335469109671, 47.90589421136038, 45.89621809550694, 48.817824431828086, 44.67857755933489, 38.98063434873308, 36.50805187225342, 43.57997356142317, 50.23120961870466, 49.574260916028706, 48.69724191938128, 49.39065129416329, 48.53585263660976, 48.527323722839355, 46.51628576006208, 46.891606603349956, 46.33745302472796, 51.05408130373274, 50.739258425576345, 50.468469755990164, 45.366928645542686, 33.909116404397146, 14.556498629706246, 11.492038198879786, 12.203850746154785, 8.913332411221095, 3.3787797817162106, 0.8328180855938366, 0.20652408871267522, 0.4388935220028673, 16.508690561567033, 45.97353070122855, 34.237887791224885, 32.14097009386335, 44.34664821624756, 52.082373006003245, 56.98404918398176, 38.044850962502615, 3.5111807457038333, 0.06396502801882369, 0.028552326107663766, 0.022486881219914982, 0.0655282980629376, 0.05229577275791338, 0.004244726783196841, 0.03920635388099721, 0.055563621156449826, 0.05419493120695863, 0.025871773516493182, 0.04953340919954436, 0.048447980478938134, 0.10001292691699096, 0.0483655147254467, 0.011236867301964333, 0.004650052221092794, 0.03156543888949922, 0.09751571448785917, 0.09745152507509504, 0.15826654247939587, 0.19024732283183507, 0.09551110491156578, 0.14866509554641588, 0.15202651731669903, 0.18920711507754667, 0.14707934563713415, 0.08339293088231768, 0.1007963295227715, 0.08844241885734455, 0.09360744098999671, 0.14725566974708013, 0.18206794959093842, 0.14206634249005998, 0.17480599640735558, 0.34109759969370707, 8.517164366585867, 47.026467663901194, 58.9400053024292, 48.25564220973423, 24.21913433074951, 49.51071963991438, 52.391508783612935, 41.24734517506191, 14.715308393750872, 0.6470106073788234, 1.3808082320860453, 16.431754895618983, 17.820183890206472, 8.466555425098964, 10.270293014390127, 8.044777188982282, 10.18713002545493, 19.597196102142334, 39.06061853681292, 45.236465794699534, 53.45683091027396, 49.989426204136436, 46.408095359802246, 40.63443068095616, 42.962987422943115, 41.69861330304827, 45.447235924857004, 45.6034939629691, 48.50394650868007, 50.43721328462873, 46.044728892190115, 44.188364778246196, 34.89501714706421, 36.67506572178432, 38.233779430389404, 35.246894768306184, 44.14811733790806, 48.38136638913836, 48.928074972970144, 46.43727431978498, 47.06116001946585, 46.672168595450266, 47.90915639059884, 50.109015124184744, 46.57554694584438, 46.1865450995309, 49.163069997514995, 48.40384381158011, 48.093599796295166, 40.391382694244385, 39.34735679626465, 45.86454473223005, 46.98477847235543, 42.875023228781565, 37.56669330596924, 34.97077335630144, 35.68939079557146, 35.30113240650722, 35.979672636304585, 36.455843108040945, 34.033506529671804, 36.308374541146414, 38.17893729891096, 38.63911301749093, 40.909992762974326, 41.924599988119944, 43.46795817783901, 44.59611633845738, 46.987606389181956, 49.29765313012259, 32.96137169429234, 40.218403816223145, 43.45439529418945, 39.74718393598284, 44.543310029166086, 47.92596755708967, 46.868847778865266, 49.84307629721505, 47.59982606342861, 47.226683480399, 47.264120374407085, 39.0394161088126, 36.338449818747385, 38.30274030140468, 35.520667689187185, 38.98578643798828, 40.17609970910208, 36.87715407780239, 38.5999425479344, 41.122083050864084, 40.57358877999442, 36.666912010737825, 35.75500610896519, 33.33806480680193, 36.19729716437203, 37.750018051692415, 37.35040978022984, 36.453546728406636, 37.15757989883423, 37.2673544883728, 39.097704546792166, 44.65076044627598, 48.64138535090855, 49.90224020821707, 48.05986976623535, 50.511715344020296, 47.707853181021555, 41.413125719342915, 39.00182982853481, 44.9817031451634, 53.103660924094065, 52.477259976523264, 50.68785217830113, 52.12257875714983, 50.28359208788191, 49.32054744447981, 47.054732935769216, 48.41203226361956, 48.29294013977051, 52.55018479483468, 50.968267577035085, 54.05774586541312, 48.238681656973704, 37.17797633579799, 13.612588456698827, 13.504556996481758, 23.356723921639578, 18.017997367041453, 11.836058276040212, 0.9318660135780061, 0.3648106615458216, 0.7817062682339123, 20.01720254761832, 53.815649781908306, 49.35885286331177, 36.661235332489014, 49.04016331263951, 58.10269178662981, 62.13505799429757, 44.17393684387207, 4.37685398544584, 0.17551039718091488, 0.08457450462239129, 0.09769037618700947, 0.09512178187391587, 0.14211436919867992, 0.08921778082315411, 0.12306979112327099, 0.14937305184347288, 0.1796874858971153, 0.11624017331217017, 0.14238605462014675, 0.17538178765348025, 0.2837777297411646, 0.20610864886215755, 0.18300457218927996, 0.10744947394622223, 0.1001416314393282], [0.041356156380581, 0.0043490748669553015, 0.039251184689679315, 0.009756755117060882, 0.004934414373045521, 0.03301982781184571, 0.03773349184276802, 0.015609051799401641, 0.056586068256625106, 0.04249235987663269, 0.05298075046656387, 0.053280924180788655, 0.026800503056230288, 0.014778485920812403, 0.021593717093180333, 0.05170430735285793, 0.036046535042779784, 0.268925955252988, 5.808745699269431, 33.389794145311626, 44.59359414236886, 37.002940790993826, 34.04917124339512, 28.13099271910531, 29.776689188820974, 33.45874111992972, 11.950321401868548, 0.34826746210455894, 1.9478766662733895, 9.091448613575526, 5.932477048465183, 4.043905862740107, 8.146795851843697, 2.027136721781322, 8.059602907725743, 18.545615775244578, 34.05004671641758, 46.125293254852295, 47.528759888240266, 43.84013148716518, 42.893158027103965, 38.407557351248606, 38.37225702830723, 39.743150506700786, 42.327032702309744, 44.47215352739607, 45.546306814466206, 45.220797606876914, 42.461699213300435, 36.70030157906668, 30.88104976926531, 32.70235674721854, 30.985105991363525, 32.49328892571585, 37.80194541386196, 42.07925646645682, 44.78346061706543, 43.65904058728899, 42.13300425665719, 46.703852381025044, 45.281451906476704, 45.67905214854649, 44.54313285010201, 44.14297219685146, 46.60360377175467, 43.52641337258475, 42.77940559387207, 42.850256374904085, 42.96914005279541, 43.85777991158621, 41.92176512309483, 40.289233752659385, 34.13301862989153, 33.022508893694194, 30.701873098100933, 33.00969294139317, 31.802179404667445, 33.47432940346854, 32.26704168319702, 34.34014790398734, 31.76687213352748, 34.63305268968855, 34.236060414995464, 35.862407888684956, 35.88349914550781, 42.47871535164969, 41.04717452185494, 46.58545855113438, 27.927872555596487, 34.09277466365269, 44.63082259041922, 42.327779633658274, 46.70907742636544, 44.26685510362898, 45.47993414742606, 44.21607419422695, 43.60244403566633, 41.98598732267107, 36.9357899257115, 31.750085285731725, 33.75311892373221, 33.75613096782139, 34.058057989392964, 31.934889997754777, 35.49089118412563, 37.600322587149485, 38.342143535614014, 42.6241272517613, 44.39338527406965, 39.27554021562849, 31.921118668147496, 31.92762565612793, 33.32020793642317, 31.863497257232666, 31.053278241838726, 30.065570967538015, 30.877217837742396, 32.865455286843435, 33.255968366350444, 35.088882310049875, 44.59154789788382, 46.468617643628804, 46.80451440811157, 47.95344420841762, 44.16168369565691, 39.21512562888009, 35.45720979145595, 38.5069374356951, 43.91580779211861, 47.69557571411133, 47.859084197453086, 46.47165053231375, 43.64818402699062, 46.59845168249947, 46.690028939928325, 50.66007328033447, 51.3178140776498, 51.404847213200156, 50.30247729165213, 52.31860480989729, 50.86102213178362, 36.48736361094883, 21.803011178970337, 11.136200972965785, 8.089348145893641, 19.85666789327349, 0.9225410968065262, 0.8263130517942565, 0.12729680644614355, 0.21383896762771265, 12.059071132114955, 40.058775901794434, 36.887347085135325, 16.83997893333435, 24.46758106776646, 41.15091807501656, 45.44068029948643, 27.00753848893302, 2.0282034873962402, 0.047549606899597814, 0.028229273888947706, 0.0187122265342623, 0.03601283220840352, 0.045569560290979486, 0.04471240092867187, 0.1051243312124695, 0.04296502737062318, 0.014371829706111124, 0.04531000029029591, 0.053676116546349864, 0.05887397977390459, 0.058730781743569035, 0.024155239375042062, 0.027904883259907365, 0.016627073154917786, 0.04372304258868098, 0.05175262243886079, 0.05730368010699749, 0.04858363998521652, 0.0069486451518189695, 0.042997156003756185, 0.043885056395083666, 0.015527206905452269, 0.05663071586085217, 0.060153452546468804, 0.03647127760840314, 0.024802095290007334, 0.017380129978326813, 0.049887865715261014, 0.16635501916919435, 0.049810607718037705, 0.030032160093209574, 0.014064608557548906, 0.2656108502830778, 7.008627074105399, 39.18911852155413, 50.954357283455984, 40.583715779440745, 33.459578377859934, 36.973028796059744, 38.32579789842878, 35.46863957813808, 14.320632474763052, 0.3290437507842268, 2.0944397960390364, 9.536361745425634, 9.659996254103524, 6.41439585174833, 8.382499592644827, 5.655867525509425, 6.324105748108455, 19.266326359340123, 35.35020753315517, 46.53831502369472, 49.64722047533308, 46.5413305418832, 44.7239909853254, 41.2890864780971, 40.02450738634382, 41.123865263802664, 43.748741831098286, 46.43793439865112, 47.64510747364589, 46.84266001837594, 45.63905484335763, 39.29079845973423, 32.718031883239746, 33.73164551598685, 32.97067880630493, 34.44692781993321, 39.85215732029506, 46.062530176980154, 45.78482804979597, 43.97973121915545, 43.02851240975516, 45.09639358520508, 46.93825680868966, 46.58697325842721, 45.69593974522182, 45.52624389103481, 47.044963768550325, 44.09999064036778, 44.83086470195225, 45.10052081516811, 44.78889063426426, 44.98426703044346, 44.09384495871407, 41.669934613364084, 35.31041519982474, 33.82947615214756, 32.37159817559378, 33.75747544424874, 33.96132516860962, 34.98877961294991, 34.35551037107195, 35.77442979812622, 32.46733045578003, 36.58557639803205, 37.12027849469866, 38.206493854522705, 39.640761852264404, 44.12083176204136, 44.78965493610927, 48.987426485334126, 29.573221615382604, 36.49892193930489, 45.02956928525652, 44.645326954977854, 47.89864376613072, 45.61680323737008, 46.694659914289204, 45.87086064474923, 46.65848759242466, 43.142355169568745, 39.070787225450786, 32.55702475139073, 34.794219630105154, 35.11411469323294, 35.327803066798616, 33.16709395817348, 36.84148550033569, 37.72286796569824, 41.180076190403526, 43.36055292401995, 46.29075070789882, 41.00710426058088, 33.37717969076974, 34.73525374276297, 34.16611637387957, 33.5106372152056, 32.65562663759504, 33.07480798448835, 32.728193623679026, 34.319199085235596, 34.84685570853097, 38.06481313705444, 46.14762476512364, 47.6686966078622, 46.40435375486101, 49.08102566855294, 46.62516403198242, 41.33548654828753, 37.78517246246338, 40.184652941567556, 47.00788470676967, 49.222821031297954, 49.123176915305, 47.47264623641968, 45.690676484789165, 46.828329358782085, 46.94783837454659, 50.15295900617327, 51.90318938664028, 52.22842066628592, 51.93749959128243, 55.33400140489851, 52.25748150689261, 38.30167375292097, 21.31575311933245, 12.112462827137538, 10.059465561594282, 10.216621654374258, 4.46956466776984, 0.2519981078803539, 0.26297221758535927, 0.2730228139885834, 13.153725947652545, 41.58932856151036, 42.261056082589285, 26.070857048034668, 30.128556387765066, 47.79615783691406, 50.227884905678884, 32.17197643007551, 2.6823429465293884, 0.08442061288016182, 0.01657556216897709, 0.01891890830094261, 0.10300853688802038, 0.00886026447239731, 0.035788542457989285, 0.03555442752050502, 0.025547713673274432, 0.035102662297763994, 0.057296412996947765, 0.030119803068893294, 0.041007694721754105, 0.009387126558327248, 0.05675436868997557, 0.010051489524942423, 0.020610436730618988, 0.024085592844390442, 0.14193913074476378, 0.16543751768767834, 0.13956178831202642, 0.08984737311090742, 0.13583779813987867, 0.13465751361634049, 0.07627593313476869, 0.17026107385754585, 0.15687692990260466, 0.2111759212400232, 0.09245363290288619, 0.08099775654929024, 0.2294184709233897, 0.22822405930076325, 0.11875624901482038, 0.1500973744051797, 0.09553176630288363, 0.45026308191674097, 9.496256743158613, 46.45623595373971, 56.76530252184187, 47.134807450430735, 43.730739048549104, 37.61043569019863, 36.775929246629985, 42.94883394241333, 17.086177928107126, 0.5034840032458305, 2.6229451852185384, 12.423714331218175, 11.20029810496739, 9.15874365397862, 17.365210635321482, 7.737532189914158, 10.048407503536769, 21.610509599958146, 36.74043437412807, 50.498072556086946, 52.11098916190011, 48.70257813589913, 46.929696628025596, 42.90344830921718, 42.60909135001046, 44.01646981920515, 46.651191983904155, 48.884916237422395, 49.49962684086391, 49.76923779078892, 47.440427439553396, 41.62609148025513, 33.99036169052124, 36.484233447483604, 34.824284485408235, 35.72505242483956, 41.65453740528652, 46.29624325888497, 47.25021702902657, 45.78683260508946, 42.11818374906267, 46.9667409488133, 48.63258893149239, 50.30836588995797, 46.30995552880423, 47.31592961720058, 48.98243073054722, 45.068128313337056, 45.78181600570679, 46.94129317147391, 46.66104105540684, 46.33378437587193, 46.1103789465768, 43.54074055807931, 37.16778332846505, 36.251666818346294, 34.51228257587978, 36.15249170575823, 35.759098597935264, 37.17799718039376, 36.07932717459542, 37.45986475263323, 34.8540609904698, 39.54237188611712, 39.144799436841694, 40.60192353384835, 41.43992839540754, 46.91750948769705, 45.438574995313374, 49.89202635628836, 33.454732009342735, 36.34710380009243, 44.81225047792707, 45.767356804439, 49.407007353646414, 49.48769678388323, 49.70607171739851, 49.26942259924752, 48.533163683755056, 44.871713161468506, 41.17213787351336, 34.51311983380999, 37.22121844972883, 37.783445835113525, 37.91282476697649, 34.154981885637554, 38.39843436649868, 40.17368173599243, 42.910608427865164, 45.93499599184309, 49.38368919917515, 43.28223977770124, 35.80343852724348, 36.38248750141689, 35.70102208001273, 35.253780433109824, 34.8432218006679, 34.055212702069966, 33.24221788133894, 36.80515684400286, 36.339419092450825, 39.70469222749983, 49.154426438467844, 48.747223785945344, 48.25616332462856, 51.11298813138689, 49.09276465007237, 44.210942949567524, 41.17805773871285, 42.99554320744106, 48.005385466984336, 52.42263323920113, 50.93873773302351, 49.669274057660786, 46.28963899612427, 47.79422623770577, 47.64878307070051, 52.98668105261666, 52.858785561152864, 55.853893416268484, 54.46860327039446, 59.68422685350691, 53.753418241228374, 42.402542250497, 27.29873401778085, 20.854081801005773, 17.305718421936035, 28.522657462528773, 6.517900126320975, 0.9339159492935453, 0.5020819870488984, 0.42152196701083866, 15.52431321144104, 51.986133507319856, 49.20256355830601, 25.617533990315028, 34.83669049399239, 53.36417668206351, 58.592484201703755, 39.87291158948626, 4.387972840241023, 0.29784794045346125, 0.12824409561497824, 0.12484257242509297, 0.16862971282431058, 0.08672788300152336, 0.1221038286707231, 0.17926048380987986, 0.1261673170541014, 0.1472411219562803, 0.21927570232323237, 0.12780260001974447, 0.12047176196106843, 0.09874328611684696, 0.1768151250268732, 0.11785447597503662, 0.15195295054997715, 0.1588504897164447], [0.07236523048153945, 0.01309209400122719, 0.05884308607450553, 0.02490511047653854, 0.03903027743633304, 0.03336976867701326, 0.04857029998674989, 0.030074188552264656, 0.006609160935373178, 0.03349564031564763, 0.03978967347315379, 0.05654241470620036, 0.02066905706721757, 0.043958799580910375, 0.0723923718822854, 0.050627268717757294, 0.0525890525563487, 0.05866645662380116, 5.102492145129612, 31.44984667641776, 47.30995069231306, 35.06676271983555, 20.75700851849147, 12.995429481778826, 24.855900253568375, 37.002732345036094, 12.135160854884557, 0.39843863993883133, 3.4736745868410384, 19.18010790007455, 12.634113601275853, 4.415724379675729, 6.50199830532074, 2.4314474037715366, 2.838759707553046, 16.43747673715864, 30.99703257424491, 47.14371504102434, 46.1705572945731, 45.300000122615266, 39.55955825533186, 39.92012807301113, 39.6021020753043, 40.991561140332905, 43.26622765404837, 45.3226512500218, 46.073397159576416, 44.00675276347569, 39.553447314671104, 33.43017707552229, 31.123691286359513, 31.20713915143694, 32.498222146715435, 31.388094561440603, 35.9585987499782, 41.03713437489101, 44.28469112941197, 43.57249729973929, 42.47091599873134, 45.55481488364083, 41.80593865258353, 42.41095651899065, 39.81741632734026, 41.57226725987026, 43.41755247116089, 45.753738335200715, 42.43480968475342, 42.89438785825457, 44.63882344109671, 44.022073541368755, 42.05972508021763, 39.44791112627302, 33.81927967071533, 31.499832017081125, 31.288485186440603, 32.560342516217915, 31.88959469114031, 32.37589563642229, 31.321669782911027, 32.4709643636431, 32.15510272979736, 31.611927304949077, 30.703464235578263, 34.55672672816685, 33.87342698233468, 42.030049324035645, 38.25431483132498, 46.5329510143825, 28.03678730555943, 38.93997696467808, 47.819260597229004, 42.74706867762974, 42.649133818490164, 41.59001643317086, 43.25384596415928, 40.762989725385395, 38.79551349367414, 33.69027246747698, 33.69545929772513, 34.713203634534565, 32.92292731148856, 34.6635240146092, 34.618642125810894, 32.91643074580601, 33.53187785829817, 38.03152084350586, 40.89206641060965, 46.29372453689575, 47.66709157398769, 42.68179382596697, 32.5149290902274, 32.2338536126273, 32.380227838243755, 33.64688791547503, 34.870625495910645, 34.90389347076416, 34.00252798625401, 32.67458479745047, 32.13780518940517, 32.77953733716692, 34.210028988974436, 40.38097429275513, 44.72828149795532, 46.17195735658918, 43.82632194246565, 39.243585450308665, 35.92573029654366, 36.03395196369716, 39.76722601481846, 44.59267003195626, 47.00281252179827, 48.12543296813965, 45.351006848471506, 43.47150523321969, 45.81528895241873, 49.155677114214214, 45.722558294023784, 47.97134624208723, 47.98955052239554, 51.13279744556972, 49.23105812072754, 41.72880670002529, 21.622814859662736, 18.220257690974645, 6.981533442224775, 8.869416322026934, 2.807979187795094, 0.6557953559926578, 0.07155602318899972, 0.2878132217696735, 10.32686264174325, 40.73864671162197, 30.716815199170792, 24.308971064431326, 27.635587896619523, 44.14415339061192, 47.668321405138286, 29.40252522059849, 2.1155397381101335, 0.07400036416947842, 0.0406095880482878, 0.06618864155773606, 0.03402044304779597, 0.036368513479828835, 0.022165557569158927, 0.05363366061023303, 0.004070804263132491, 0.06284217469926391, 0.030185305446918522, 0.03282193985900708, 0.025733462634629438, 0.036709663923829794, 0.024098595271685293, 0.008203848847188056, 0.028659164839025055, 0.029531672663454498, 0.034193211634244235, 0.039219422465456386, 0.028523512118096863, 0.07384730702532188, 0.017043742850156765, 0.07629599741527013, 0.09988767613789865, 0.06300334712224347, 0.028037496143952012, 0.020364486446071948, 0.03773638240194746, 0.034456150739320686, 0.03665154739948256, 0.05518781114369631, 0.052840694053364654, 0.07023758893566472, 0.03522871374817831, 0.1810978887868779, 6.8134408848626276, 37.22534220559256, 49.77188852855137, 41.5272707257952, 28.318656614848546, 18.41184037072318, 29.401816504342214, 41.2991509437561, 13.91558723790305, 0.4352735105369772, 3.5967415145465305, 19.309080362319946, 10.114444919994899, 7.124106568949563, 7.8034679889678955, 6.073755204677582, 7.496249045644488, 19.295870099748882, 33.35336821419852, 50.01419653211321, 47.406287465776714, 47.44498198372977, 42.719658034188406, 40.389718600681846, 42.10692419324602, 42.581149169376914, 45.020321232931956, 46.66599859510149, 47.590029103415354, 46.75531768798828, 42.62529454912458, 35.28022180284773, 32.82955047062465, 32.79978438786098, 33.11384643827166, 32.84266172136579, 36.124188218797954, 42.495543888636995, 45.90132849557059, 44.011550494602744, 43.39800718852452, 47.48183870315552, 45.58135005405971, 44.802925995418, 43.00858845029558, 43.94703647068569, 44.4723584992545, 46.84862504686628, 43.297095026288716, 45.82147632326399, 45.974757058279856, 45.53233398709978, 44.83649621691023, 40.971015317099436, 35.821142537253245, 33.823757784707205, 33.41489451272147, 33.26782546724592, 32.80379697254726, 34.35763651984078, 33.70542301450457, 33.627353055136545, 32.7093049458095, 33.69726930345808, 33.4977239881243, 36.34755890710013, 36.75830166680472, 43.48662798745291, 42.428597995213096, 49.34765931538173, 31.77881956100464, 38.8701753616333, 48.27267919267927, 46.058225767953054, 45.17043011529105, 44.35539599827358, 45.93215765271868, 42.63869415010725, 40.65428168433053, 36.69769600459507, 34.93227686200823, 36.15041766847883, 34.85136161531721, 35.73569706508091, 36.55972215107509, 34.49229955673218, 35.68779270989554, 39.86070013046265, 43.00823756626674, 48.853430475507466, 48.46235111781529, 44.5992499760219, 35.028321811131065, 33.91950396129063, 34.39344753537859, 34.17998150416783, 36.20836564472744, 36.24553155899048, 34.74301488058907, 33.64034966060093, 33.92559058325631, 34.132448877607075, 36.91236407416207, 42.731525557381765, 46.461902209690635, 48.3284523827689, 46.7608380317688, 42.0207839012146, 37.29914944512503, 38.88704211371285, 42.69467578615461, 46.95741646630423, 47.80474581037249, 49.22787931987217, 47.379602909088135, 43.85356930324009, 47.22029113769531, 51.354107992989675, 48.6402701650347, 48.69262831551688, 50.39506203787667, 52.30183185849871, 52.103801250457764, 44.19613633837019, 22.26823650087629, 12.52999918801444, 4.156484484672546, 10.501547302518572, 3.7260236058916365, 0.3407628376569067, 0.15856048384947435, 0.27203861251473427, 11.401828868048531, 44.65831661224365, 34.53375598362514, 23.409460748944962, 30.850001743861608, 47.957818099430625, 53.6998267854963, 35.72013657433646, 3.09251269698143, 0.12033076238419328, 0.08492656930216722, 0.11550574057868548, 0.0213411375215011, 0.030569502152502537, 0.06282406459961619, 0.0543555981213493, 0.040382994671485255, 0.05491243788440313, 0.047891598727021895, 0.029933972683336054, 0.02327345767324524, 0.07117717673203774, 0.013396260045867945, 0.03832557471469045, 0.011858711567973452, 0.019725177536851594, 0.11503113247454166, 0.16492906425680431, 0.10985819183822189, 0.13341692090034485, 0.14718834550252982, 0.2012839527534587, 0.22937860020569392, 0.1133337499839919, 0.08871495244758469, 0.08616929261812142, 0.11416196982775416, 0.1356182106371437, 0.08776432488645826, 0.1435121784784964, 0.14771487510630063, 0.12471816981477396, 0.10352066797869545, 0.38616190584642546, 9.705643313271658, 43.99185235159737, 58.57306398664202, 45.29843330383301, 30.837453297206334, 20.790017672947474, 32.625606945582796, 46.57895156315395, 16.146943024226598, 0.6581994869879314, 4.232335797377995, 21.59568735531398, 17.478212663105555, 13.897819825581141, 13.304756334849767, 7.957902124949864, 6.372563787869044, 18.061018875667028, 33.426265239715576, 51.64273268835885, 50.77697672162737, 49.440702642713276, 43.6898523739406, 44.64875936508179, 43.868834495544434, 45.02041850771223, 47.62055253982544, 48.2665821484157, 49.62404128483364, 49.37243659155709, 43.30900771277291, 36.704404490334646, 34.89436401639666, 34.24999850136893, 34.94261230741228, 34.639841079711914, 38.22609124864851, 44.426496914454866, 47.60435281481062, 43.95030559812273, 44.235087939671104, 48.64148609978812, 47.57780722209385, 46.755619934626985, 45.34821367263794, 45.82409232003348, 47.40755551201956, 48.88997105189732, 43.95265061514718, 45.74779415130615, 48.577211788722444, 47.46181052071707, 46.132178919655935, 43.162258284432546, 37.16278062547956, 35.46479722431728, 35.94905192511422, 35.348348890032085, 35.110456466674805, 35.8662120274135, 34.94143111365182, 35.96663434164864, 35.65130771909441, 35.64761822564261, 33.989430631910054, 38.42873198645455, 38.62058217184884, 45.585518973214285, 43.83323540006365, 50.997533389500205, 34.21380533490862, 40.70755352292742, 50.6023337500436, 48.123011520930696, 45.98997361319405, 45.18028960909162, 47.479573590414866, 45.479023933410645, 42.613322802952354, 37.514338629586355, 36.63042007173811, 38.53186409814017, 35.917468888419016, 36.96636199951172, 38.79962682723999, 36.136837414332796, 37.20865958077567, 41.95055498395647, 44.147693497794016, 53.19439050129482, 50.097567967006135, 46.10243715558733, 36.04275185721261, 36.67751496178763, 37.06422390256609, 36.133443219321116, 37.7718631880624, 39.457697663988384, 37.58714880262102, 36.672487940107075, 36.56507921218872, 35.09889466421944, 38.090556212833945, 45.09793608529227, 48.88533660343715, 50.050233364105225, 47.96713215964181, 44.12470538275582, 39.72871562412807, 41.84368821552822, 43.66570390973772, 49.36637428828648, 50.47909355163574, 51.17895432880947, 47.366929394858225, 45.71085057939802, 48.69593218394688, 52.87252214976719, 49.430554798671174, 52.322933537619456, 51.56594467163086, 56.46551207133702, 53.10219138009207, 47.257321562085835, 23.983055387224468, 24.55095945085798, 14.56863452707018, 13.211902345929827, 6.13411420583725, 0.9390292806284768, 0.4248137032347066, 0.40339004567691256, 14.3080301795687, 50.83103718076433, 40.3738489151001, 32.181575366428916, 37.5923147882734, 56.34217112404959, 59.31534699031285, 42.32923528126308, 4.740701615810394, 0.24917950055428914, 0.18726543283888272, 0.1790402177721262, 0.19027008089636052, 0.11554059013724327, 0.09539960803730146, 0.113463723366814, 0.14558469583945616, 0.15654199144669942, 0.10803584355328764, 0.10114642645099334, 0.14366533740290574, 0.11635726131498814, 0.06727076920547656, 0.12247928923794202, 0.1463118139654398, 0.10587435668068272], [0.012817020145510989, 0.07369205142770495, 0.009345607000536152, 0.027376737046454633, 0.02985846869913595, 0.04391631989606789, 0.03154494373926094, 0.018183864885941148, 0.07948325960231678, 0.019450811902061105, 0.03373939723574689, 0.03635370445304683, 0.04434815654531121, 0.05020164744928479, 0.030618770580206598, 0.016869518806093504, 0.025864316416638236, 0.15557863456862314, 6.736803122929164, 34.344855308532715, 49.16926084245954, 29.67750017983573, 39.39101927621024, 45.06151362827846, 26.171645879745483, 35.30474546977452, 13.91778200013297, 0.5455005200845855, 1.6985985338687897, 27.29167812211173, 38.04945761816842, 6.799124121665955, 5.277874665600913, 4.931889116764069, 3.5782899217946187, 15.397552013397217, 35.92902026857649, 50.81674126216343, 45.57187271118164, 43.5385171345302, 38.243187291281565, 40.78534208025251, 39.72585644040789, 44.43791627883911, 46.52747930799212, 47.85894175938198, 45.65055411202567, 44.334391593933105, 33.29101160594395, 31.183011531829834, 30.36243622643607, 32.79917989458357, 32.72768293108259, 35.65499373844692, 37.002520424979075, 42.13825709479195, 44.83318887438093, 43.04726907185146, 42.400291034153526, 44.79615150179182, 39.70172187260219, 39.86639070510864, 36.20449897221157, 38.73045056206839, 42.125868456704275, 44.79565470559256, 43.98624862943377, 44.14448343004499, 42.37812280654907, 43.411434582301546, 40.86624690464565, 35.57239702769688, 31.506971291133336, 31.831723145076207, 32.849384103502544, 32.053377628326416, 32.2846553666251, 32.578571115221294, 30.964014734540665, 31.628234727042063, 30.765247617449077, 31.708347456795828, 31.250433376857213, 33.644244125911165, 32.81642532348633, 40.388912609645296, 39.77348634174892, 46.324810777391704, 31.987050124577113, 40.72781447001866, 45.47599451882498, 39.56230279377529, 39.94655554635184, 38.100856917245046, 37.23062631062099, 35.51753057752337, 33.54519408089774, 32.267277921949116, 35.364326272692, 35.457845551627024, 34.336183956691194, 32.28859499522618, 32.99904135295323, 31.996593475341797, 33.847760336739675, 35.787037304469514, 42.77726207460676, 45.44043711253575, 45.05159160069057, 43.780175481523784, 38.93929951531546, 33.88646180289132, 37.22094399588448, 40.73738561357771, 43.33722087315151, 45.278193201337544, 42.94729839052473, 40.10829223905291, 34.43920142310006, 32.35248368127005, 32.18649469103132, 32.29392426354544, 36.30470936638968, 44.268946511404856, 42.05048050199236, 39.50112737928118, 35.393036229269846, 36.120005403246196, 37.79559128625052, 43.51262467248099, 45.62985890252249, 47.45781878062657, 44.632045473371235, 44.19571597235543, 46.43467569351196, 48.21510294505528, 48.57807683944702, 46.17732484000069, 47.99755137307303, 51.374723298209055, 50.626992906842915, 45.56468479973929, 24.651303597858973, 10.793282185282026, 2.8892103603907993, 1.724807573216302, 4.534800001553126, 0.38381135197622435, 0.21179071467901978, 0.1687405447342566, 8.231872200965881, 35.02824190684727, 42.024768693106516, 32.820392744881765, 27.002574001039775, 43.98871176583426, 45.93751123973301, 30.525159563337052, 2.5739284668649947, 0.09544983998473201, 0.06875888471092496, 0.033355543190347295, 0.04248624288343957, 0.04769468107925994, 0.020589285097750168, 0.049233720637857914, 0.03504293764542256, 0.06935054689113583, 0.026770859557603086, 0.054946344279284985, 0.05632942595652171, 0.035810353966163735, 0.03411743284336158, 0.02997878992131778, 0.008157157156217312, 0.03149893567232149, 0.03746565371485693, 0.019256060477346182, 0.0354438398831657, 0.022449641521754007, 0.006491734937299043, 0.06041728053241968, 0.06238350538270814, 0.03066328926278012, 0.0923441309215767, 0.06007436929004533, 0.023846117480258857, 0.07780551391520671, 0.054073449689894915, 0.01489852724729904, 0.1443506306303399, 0.04385834586407457, 0.01804734024751399, 0.17149308989090578, 7.602452261107309, 39.79609925406319, 54.60448571613857, 35.0425899369376, 39.81282704217093, 42.435073716299875, 28.072853667395457, 41.49930770056588, 15.052007675170898, 0.6356141503368105, 2.0422418883868625, 29.75483363015311, 27.482381854738506, 7.620587059429713, 8.974017109189715, 8.814670596803937, 7.9940562077931, 17.007083109446935, 35.45846046720232, 52.28227962766375, 48.03572825023106, 45.294670854296, 39.612489632197786, 41.946226256234304, 41.97736113412039, 46.57424415860857, 46.72641665594918, 49.47064937864031, 47.4690957069397, 45.64332103729248, 36.767688683101106, 31.57800967352731, 32.32552467073713, 34.38581146512713, 33.77952207837786, 36.2063958304269, 38.92034830365862, 43.25326231547764, 46.55383382524763, 44.734295163835796, 42.20769044331142, 45.363458020346506, 42.48504516056606, 42.15020799636841, 37.90510531834194, 40.27897473743984, 43.71757221221924, 46.95170852116176, 44.971270424979075, 45.33102035522461, 43.87756143297468, 45.4573073387146, 42.97976732254028, 38.22254071916853, 32.391643728528706, 33.31397540228707, 33.25987672805786, 33.48377547945295, 33.21284784589495, 35.06117636816842, 32.430334772382466, 33.04988827024187, 32.24764231273106, 33.031617982046946, 32.71677425929478, 36.73116200310843, 34.624707903180806, 41.23944854736328, 43.69219739096505, 48.27453783580235, 34.325494153159006, 41.692960943494526, 46.83098357064383, 42.28515590940203, 42.25918006896973, 38.926559993198936, 39.54593978609358, 38.9703232220241, 34.9358343396868, 34.343757493155344, 35.78439351490566, 35.88377707345145, 35.86471469061715, 33.71842656816755, 34.525758607046946, 33.70949813297817, 34.88170092446463, 37.62338365827288, 44.77268048695156, 46.75833320617676, 48.12772239957537, 46.31054612568447, 38.59999465942383, 36.65748677934919, 37.82892526899065, 40.73414775303432, 45.56850283486502, 46.3289658001491, 43.53353527614048, 41.486793994903564, 35.722947120666504, 34.30800206320626, 33.32560668672834, 35.38402441569737, 39.29929263251168, 45.573436055864605, 43.241592815944124, 41.56810528891427, 36.92976583753313, 37.87276145390102, 40.08397701808384, 44.71772371019636, 49.31623261315482, 49.44486461366926, 46.62812049048287, 45.2043581690107, 47.889003140585764, 50.17710052217756, 49.37848499843052, 48.85779741832188, 49.101852893829346, 53.73432459150042, 52.24057306562151, 46.85786962509155, 26.298184735434397, 14.916568177086965, 2.063180067709514, 2.8772991938250403, 3.640237454857145, 0.8262328218136514, 0.3650391378573009, 0.30194686193551334, 9.354029723576136, 38.66071496691023, 42.31889636175973, 32.18065473011562, 31.113866533551896, 49.36956351143973, 52.596105439322336, 36.81487042563302, 3.2721876842635016, 0.13468160160950252, 0.05561686579936317, 0.061914250919861455, 0.06257441799555506, 0.030160457494535615, 0.009635322793786014, 0.020494897483981082, 0.03967133018055132, 0.05629055607797844, 0.09911525222871985, 0.04729308673579778, 0.04658084888277309, 0.1173876438822065, 0.04116515555818166, 0.03131030972248741, 0.027907451514952948, 0.02950586119134511, 0.12299340165087155, 0.11712135959948812, 0.09708407122109618, 0.15980312574122632, 0.11146342248788901, 0.14591673016548157, 0.11108384321310691, 0.11174888895558459, 0.09711207436131579, 0.136700623269592, 0.12682601170880453, 0.14941142978412764, 0.14017108561737196, 0.10504212669496026, 0.18768957150833948, 0.1776363831013441, 0.10970843915960618, 0.3205079159566334, 11.719713296209063, 46.59127766745431, 60.29316002982003, 41.11652449199131, 46.328437737056184, 52.12774126870291, 34.193297726767405, 45.538458824157715, 18.965684754507883, 0.8876055542911802, 2.1706743453230177, 30.090372562408447, 44.323903288160054, 12.787642734391348, 14.279821361814227, 12.563724875450134, 6.152895620891026, 17.98357946532113, 39.563893931252615, 54.134061404636924, 50.176760060446604, 47.47292763846261, 42.560485226767405, 45.075159890311106, 44.017425196511404, 49.18959127153669, 49.52426167896816, 51.8273081098284, 50.68996443067278, 48.258911337171284, 36.954122747693745, 35.04019628252302, 34.206461088997976, 36.058958530426025, 35.32759462084089, 38.70358187811715, 41.08289173671177, 45.868550368717735, 48.6847699029105, 44.39007445744106, 45.16152947289603, 49.284785066332134, 43.242308480399, 43.91617604664394, 38.90707377025059, 42.69005523409162, 46.12488331113543, 49.88228498186384, 47.2218405859811, 45.16053588049752, 44.62441635131836, 47.46764700753348, 44.49858100073678, 40.22093643460955, 34.20663479396275, 34.39458009174892, 35.91912603378296, 35.21528393881661, 35.026178291865754, 35.727321011679514, 34.842311586652485, 34.43121794291905, 32.66715022495815, 34.93962805611746, 34.89777905600411, 37.697677271706716, 36.71974263872419, 43.31698077065604, 45.58948639460972, 50.96491159711565, 37.332219396318706, 44.29172618048531, 49.15890455245972, 44.16919469833374, 43.29081038066319, 41.45695843015398, 39.73478487559727, 40.29713385445731, 37.182044506073, 35.301236629486084, 38.37388638087681, 38.65808159964425, 38.045650005340576, 35.80567932128906, 36.79392160688128, 35.07045221328735, 37.42381402424404, 39.56853532791138, 48.08392790385655, 49.1991936819894, 50.453551973615376, 49.744707175663535, 41.28597021102905, 38.112724440438406, 41.420372690473286, 44.08038977214268, 49.28494834899902, 49.98502452032906, 47.22718027659825, 44.84216594696045, 38.38789394923619, 37.2070232800075, 35.504787581307546, 36.87219653810774, 39.89492348262242, 47.52233280454363, 45.264831815447124, 43.55786439350673, 38.09150116784232, 39.805038111550466, 43.29450682231358, 47.95767566135952, 50.52740785053798, 51.31325953347342, 47.192380223955425, 48.40321499960763, 50.277759075164795, 51.293328625815256, 51.25320972715105, 50.183558872767854, 52.12915175301688, 56.60893678665161, 54.850090639931814, 49.69893591744559, 27.375674894877843, 12.935393571853638, 8.926643422671727, 7.005552930491311, 8.72266341958727, 1.28460108595235, 0.639428331383637, 0.38211303310734884, 10.28699995790209, 45.84119183676583, 52.64605951309204, 42.55652127947126, 37.128189018794465, 55.538681438991, 60.43743937356131, 44.9040709223066, 5.417283322129931, 0.19202448746987752, 0.18678621069661208, 0.16873059741088323, 0.11706494619803769, 0.15558843261429242, 0.17808927808489117, 0.13449276531381266, 0.11765761939542634, 0.18186862314386026, 0.14489866979420185, 0.1113576999466334, 0.13542830225612434, 0.17966371003006185, 0.18160482229931013, 0.19098525680601597, 0.1072209229958909, 0.114988791889378], [0.08262803871184587, 0.03468515970078962, 0.024494345732299343, 0.056907066210572205, 0.021704572751852017, 0.023524729368676032, 0.035142980848572085, 0.02166916340190385, 0.04781096501808081, 0.04406312434002757, 0.0478867811283895, 0.014201039897410997, 0.025848321649911146, 0.030874948083822216, 0.03104966745844909, 0.061446407809853554, 0.02694931935652026, 0.19736283458769321, 6.832043818065098, 33.48595373971121, 49.10384702682495, 37.88171073368618, 33.58472238268171, 20.82622994695391, 23.892393554959977, 39.87389128548758, 16.069152729851858, 0.766310797205993, 0.08712485312883343, 14.881009033748082, 36.712714535849436, 16.260865688323975, 3.999055240835462, 6.614916086196899, 8.677750263895307, 18.019032648631505, 35.75675358091082, 49.327895164489746, 43.71655082702637, 44.62545163290841, 40.11549057279314, 43.6714118548802, 44.053955350603374, 46.77861499786377, 46.79330348968506, 43.60920810699463, 41.87395109449114, 36.91661637169974, 32.12990856170654, 32.50821713038853, 35.16351638521467, 41.90205308369228, 41.75853109359741, 40.93917519705636, 40.93816423416138, 45.08610677719116, 43.41203212738037, 42.14440277644566, 43.65233210154942, 41.1820946420942, 39.24229655947004, 34.295332023075645, 32.07171392440796, 34.25564391272408, 36.75899996076311, 40.644634110586985, 42.48610128675188, 45.33697148731777, 42.96217448370797, 42.76404660088675, 37.601111207689556, 34.15752492632185, 31.99308463505336, 32.25429173878261, 32.116522857121055, 32.46023981911795, 32.700338295527864, 32.4237721988133, 31.644166946411133, 32.20596006938389, 30.816389833177837, 31.881475721086773, 32.976727213178364, 32.027530329568044, 33.536831923893516, 38.06923566545759, 38.26848568235125, 45.96489756447928, 36.154718603406636, 41.82582439695086, 44.57286071777344, 37.92662736347744, 35.61986364637102, 32.624217305864605, 34.49267128535679, 30.794457844325475, 33.19179480416434, 32.537812982286724, 32.218782969883506, 32.13080140522548, 30.768822465624126, 33.96197829927717, 32.593012945992605, 32.395732743399485, 32.36852707181658, 35.557677268981934, 42.74609592982701, 46.49094220570156, 45.854841572897776, 44.54255962371826, 43.27943965366909, 41.9257846559797, 43.81180020741054, 45.131110259464805, 46.958476066589355, 45.39768137250628, 46.59310851778303, 46.049325125558035, 45.024041993277415, 39.14985772541591, 33.156195708683555, 31.51408624649048, 31.894409792763845, 32.13645029067993, 36.824834142412456, 37.6299010685512, 36.2478974206107, 37.21777561732701, 38.86203554698399, 43.262492997305735, 46.53295796258109, 47.858792373112266, 45.92576878411429, 44.52809347425188, 46.62627574375698, 50.3969658442906, 47.73510748999459, 46.590075629098074, 46.816486154283794, 49.29838963917324, 51.10808270318167, 42.88971866880144, 25.797792843409947, 14.137620397976466, 0.8049320876598358, 2.294895325388227, 1.8002782549176897, 0.4144747294485569, 0.034905167895236185, 0.18489368153469904, 8.476912583623614, 38.407949924468994, 34.455696446555, 22.560726131711686, 31.009011268615723, 45.45063359396798, 52.143968786512104, 30.625929287501744, 2.7653274536132812, 0.046215159219822714, 0.05015113390982151, 0.021388414448925426, 0.02973502960854343, 0.05622624792158604, 0.08864965702274016, 0.03555386433643954, 0.02781716564537159, 0.058028911905629296, 0.07705622126481362, 0.014683747165171164, 0.022953862590449195, 0.035392121944044314, 0.07549304621560232, 0.011089579401803868, 0.013463656384763973, 0.036492841451295784, 0.07157714598413024, 0.04225538491404482, 0.08925216219254903, 0.0308624562541289, 0.028891654685139656, 0.03106101934931108, 0.03789856244942971, 0.005943124955852649, 0.05578501016965934, 0.0583891665030803, 0.025418199997927462, 0.019095804076641798, 0.06309176702052355, 0.0172834455235196, 0.05439052910410932, 0.042308096906968524, 0.020972920315606252, 0.3042267124567713, 9.311989648001534, 39.491674355098176, 53.51424387523106, 42.860796792166575, 41.32844107491629, 29.55449969427926, 28.310492481504166, 44.75841236114502, 17.196946110044205, 0.7556734308600426, 0.10636273904570512, 17.71413353511265, 40.13401099613735, 11.196874380111694, 5.419769474438258, 8.008788125855581, 6.601906452860151, 19.480087688991002, 37.7000744002206, 51.49926280975342, 46.17767224993025, 45.67034605571202, 42.61081797736031, 44.451270716530935, 46.54701764242989, 47.15671164648873, 47.93502105985369, 45.65215219770159, 43.92259965624128, 39.894603865487234, 33.474499634334016, 33.9312082018171, 35.781249455043245, 42.53997761862618, 42.472819805145264, 41.38920654569353, 42.23423951012747, 46.884832109723774, 44.39417042051043, 42.65641205651419, 46.24299921308245, 42.687046664101736, 41.768557344164165, 36.976374353681294, 33.86553382873535, 36.45246628352574, 39.16337891987392, 42.26982123511178, 44.241692202431814, 47.65214599881853, 44.73331199373518, 44.288960797446116, 40.23471123831612, 35.49819026674543, 32.29782567705427, 33.886357579912456, 33.09441580091204, 34.897508076259065, 34.774257455553325, 32.824936866760254, 33.08346196583339, 33.938260623386924, 31.971222128186906, 34.139417920793804, 33.89495250156948, 34.35746281487601, 34.79556063243321, 40.043812956128804, 40.38326719829014, 49.317379065922324, 38.396415914808, 43.10344525745937, 47.40543631144932, 40.10537052154541, 37.862596239362446, 34.485351358141216, 35.594971724918906, 33.39994546345302, 33.25854614802769, 34.2850730078561, 34.49479396002633, 33.80949660709926, 32.906710215977256, 35.76092944826399, 35.05049351283482, 33.799421719142366, 33.506562096732004, 37.79770701272147, 43.56777599879673, 46.91849960599627, 46.428682872227256, 46.28094679968697, 44.90761797768729, 44.08676127025059, 44.95637001310076, 47.03481592450823, 46.82680770329067, 46.85596581867763, 48.233227321079795, 47.30811289378575, 46.48774256025042, 40.31660270690918, 34.98366573878697, 33.286067962646484, 32.517413071223665, 34.767611503601074, 39.03215871538435, 40.39505481719971, 38.60107510430472, 38.822354384831016, 40.51177065713065, 44.33656638009207, 49.182511057172505, 49.85198041370937, 47.28740726198469, 46.47120237350464, 48.82383114950997, 51.14838572910854, 50.06295204162598, 47.35055596487862, 47.74791301999773, 50.58913564682007, 53.62393161228725, 45.09649780818394, 27.371050868715557, 14.860930476869855, 3.209843669618879, 4.121102954660143, 1.8201920092105865, 0.3142970949411392, 0.07766214625111648, 0.14247482057128633, 10.355562176023211, 42.34232916150774, 44.95758594785418, 27.677902426038468, 34.21407978875296, 51.3951301574707, 56.750360420772004, 37.25801958356585, 3.524671107530594, 0.04181527692292418, 0.02513867410432015, 0.015005759528971143, 0.0217486096745623, 0.038204853156847615, 0.023826838604041507, 0.02095073730950909, 0.011875938723928161, 0.06750267211880003, 0.035780233796685934, 0.021290099813735912, 0.048853489969457896, 0.01365452998184732, 0.008807047819053488, 0.04277757189369627, 0.013736402017197438, 0.031989275610872676, 0.11072603134172303, 0.06971060471343142, 0.17111209247793469, 0.12666677311062813, 0.09371037475232567, 0.0806254240285073, 0.129428003515516, 0.12522392267627375, 0.07978448843849556, 0.14841369832200663, 0.10367536039224692, 0.13478099341903413, 0.1887852427150522, 0.13615128131849424, 0.09901188420397894, 0.14445763560278074, 0.07574525089668376, 0.4528365752526692, 11.45714955670493, 46.15714727129255, 61.28448731558663, 50.277811186654226, 43.296803201947895, 28.221143858773367, 31.72320965358189, 49.34842709132603, 21.337049348013743, 0.9193976883377347, 0.2956543453037739, 17.65199405806405, 43.390228680201936, 23.449953113283428, 13.85124431337629, 13.275434068271093, 12.495147023882184, 20.704414129257202, 38.614860330309185, 54.845178263528005, 48.16286291394915, 49.035153661455425, 44.135902404785156, 47.05203356061663, 48.925632681165425, 48.297508580344065, 51.12741606576102, 48.345753397260395, 45.83841950552804, 42.14947148731777, 35.60177748543875, 36.124344553266255, 38.274092878614155, 46.36551332473755, 45.13752344676426, 44.04936606543404, 44.859776156289236, 49.893391677311485, 44.78978000368391, 43.21401194163731, 47.11764192581177, 45.646590164729524, 44.1086550440107, 37.28109802518572, 34.87334224155971, 38.543429374694824, 41.21625893456595, 43.39877496446882, 45.680841309683665, 50.65086691720145, 45.919925349099294, 46.772601331983296, 41.94373532703945, 38.09280048097883, 33.55349717821394, 35.232876777648926, 36.45878219604492, 35.55696855272566, 36.89433697291783, 34.51582268306187, 35.62293127604893, 35.641781738826204, 33.9511147907802, 36.45060069220406, 36.84694331032889, 35.139284542628694, 37.713557379586355, 42.671336787087576, 43.1360844203404, 51.36039958681379, 41.89701563971383, 46.005832876477925, 48.705395630427766, 42.59134217670986, 38.93735401970999, 35.99704313278198, 38.82724939073835, 35.45487519672939, 35.78953865596226, 35.67840221949986, 35.26760387420654, 35.57443284988403, 33.00648634774344, 38.50573887143816, 35.246071406773154, 36.26389217376709, 35.51046773365566, 39.42173031398228, 47.239666189466206, 49.24074043546404, 47.82954740524292, 48.20913096836635, 48.842890058244976, 46.471893719264436, 50.310241903577534, 51.022463526044575, 49.37100873674665, 47.99089847292219, 48.918059144701274, 49.21278435843331, 49.502072606767925, 43.72381516865322, 38.17162431989397, 35.722106388636995, 34.49215711866106, 35.61908197402954, 41.197946957179475, 41.822742870875764, 40.74669272559029, 42.86504214150565, 41.82659217289516, 47.81399386269705, 50.95402029582432, 52.791996002197266, 48.674146107264924, 48.36371449061802, 50.07959297725132, 53.667000021253315, 52.16606753213065, 50.96608931677682, 51.09752491542271, 53.63154683794294, 55.86918292726789, 47.29600913184029, 28.898872886385234, 21.404273169381277, 5.36696012531008, 7.9975433349609375, 6.295733647687094, 1.079350973878588, 0.25415712488549097, 0.40523867362311905, 11.882038848740713, 49.26058101654053, 47.31186492102486, 32.01369299207415, 42.269400869097026, 57.6389342716762, 66.28523785727364, 43.971539293016704, 5.072165863854544, 0.2329200373164245, 0.18184414160038742, 0.12267628152455602, 0.19511524162122182, 0.20474146865308285, 0.21120085061660834, 0.1882912963628769, 0.306591406996761, 0.17553616794092314, 0.15793647590492452, 0.11394878769559519, 0.10319317983729498, 0.10266588348895311, 0.17129896102207048, 0.12664215586015157, 0.1451730015022414, 0.19539258602474416], [0.022237670574603335, 0.04622118461078831, 0.054978523802544386, 0.021662315287228142, 0.017143390806657926, 0.08196829911321402, 0.020898186468652317, 0.05577068290274058, 0.03705635799893311, 0.012756617806319679, 0.01710936057913516, 0.0750542851164937, 0.06512775205607925, 0.02442982723005116, 0.056347865145653486, 0.015090596762352755, 0.02055725485219487, 0.1395016565386738, 4.850008938993726, 30.399709837777273, 44.2334794316973, 34.97477204459054, 21.25928337233407, 15.118515832083565, 23.79106102670942, 37.40371983391898, 17.35135245323181, 1.2396702340670993, 0.00496653961350343, 3.0856361516884396, 26.701586723327637, 24.876444339752197, 3.687256131853376, 6.654932498931885, 7.36986826147352, 16.36169794627598, 39.573207991463796, 50.10540900911604, 46.43705197743007, 43.599574429648264, 45.1385726247515, 45.72524724687849, 47.18831900187901, 45.98911203656878, 45.08135073525565, 40.52136264528547, 36.06240483692714, 30.93409926550729, 30.914533138275146, 35.16920348576137, 44.387614795139854, 44.71431214468819, 43.25169202259609, 40.774763447897776, 45.394453934260774, 44.05829102652413, 45.73497819900513, 42.40994208199637, 43.30258410317557, 39.91735226767403, 38.42744656971523, 34.26574659347534, 31.98404155458723, 30.216294765472412, 32.459677015032085, 34.059447629111155, 35.23663922718593, 38.79505491256714, 37.627496991838726, 36.10466030665806, 34.659528800419395, 31.998816898890905, 30.85594940185547, 31.605812890189036, 31.31432901109968, 33.126843043736045, 31.273414543696813, 31.876688412257604, 33.37914603097098, 31.93465723310198, 33.11022990090506, 37.807653359004426, 36.45653445380074, 37.23255443572998, 37.34935017994472, 40.04392760140555, 40.23971741540091, 45.47674492427281, 36.03572375433785, 41.9018793787275, 45.84850828988211, 39.92166709899902, 34.761240005493164, 31.878109318869456, 31.726082733699254, 30.178117888314382, 32.16831472941807, 31.42336709158761, 32.2293199130467, 32.83806896209717, 33.32284825188773, 33.1434839793614, 32.26377950395857, 32.22212157930647, 32.369482449122835, 33.785580907549175, 39.153863361903596, 45.62025996616909, 45.52365568705967, 43.34871666772025, 46.22959613800049, 44.00189944675991, 46.810392584119526, 44.90664175578526, 46.40749086652483, 44.57906198501587, 45.87579386574881, 46.309146063668386, 46.14933054787772, 45.65616478238787, 42.26829957962036, 37.23350633893694, 34.67883437020438, 31.568059853145055, 32.5717271396092, 35.37197276524135, 33.464869431086946, 35.14012180055891, 36.62538957595825, 41.54646512440273, 44.54916041237967, 47.837826183864046, 46.09836203711373, 44.02928229740688, 45.13559184755598, 49.02572843006679, 50.71837561471121, 48.70292207172939, 45.74519205093384, 50.69123247691563, 53.74196066175188, 44.4369226864406, 26.444605861391338, 17.940181016921997, 1.241898000240326, 3.292909166642598, 1.368005524788584, 0.5109097819243158, 0.014308452839031816, 0.18422779440879822, 8.131127664021083, 36.3252169745309, 33.590881960732595, 22.979384626661027, 30.51062740598406, 42.78759752001081, 49.26496185575213, 27.36075016430446, 2.876660176685878, 0.01975207805766591, 0.03659983963838645, 0.045459915817316086, 0.06659492118550198, 0.021739574980788996, 0.00034175881955889054, 0.08297911951584475, 0.025575726991519332, 0.030468454717525413, 0.03248909129095929, 0.03270207325528775, 0.04849049409053155, 0.05294308838035379, 0.07436355003820998, 0.04469218737046633, 0.05618786658825619, 0.04203006039772715, 0.012935916444153657, 0.0835616554000548, 0.06560180376150779, 0.039388184302619526, 0.016052267480907694, 0.1162499984992402, 0.03492321692673223, 0.09627119983945574, 0.010773740858504815, 0.054605587385594845, 0.041259770481182, 0.048096244888646264, 0.02755652677400836, 0.08490256951855761, 0.045530313825500865, 0.03615357054929648, 0.03686150988297803, 0.18627143331936427, 6.317942261695862, 37.38122851508004, 51.63151134763445, 40.6644503729684, 25.53573284830366, 17.153737000056676, 25.393445900508336, 39.591078758239746, 20.16158264023917, 1.2167123002665383, 0.0058662274303579965, 4.69590961933136, 31.39310768672398, 19.407883746283396, 5.235845880849021, 10.597124116761343, 8.316342319761004, 19.377101489475795, 40.59760175432478, 51.04885973249163, 48.77747624261038, 47.46166113444737, 45.51964657647269, 46.07967833110264, 49.45622491836548, 47.896309171404155, 46.89896821975708, 43.80044337681362, 37.8145946093968, 32.89565215791975, 33.036262852805, 36.619174412318635, 45.56049851008824, 46.16285869053432, 44.59721415383475, 43.079713685171946, 47.22036756787981, 46.31137296131679, 44.99542236328125, 43.68863296508789, 45.1846843447004, 42.12959616524832, 40.341421672276084, 36.50470284053257, 32.27816922324044, 32.500150271824424, 33.90668453489031, 37.25707810265677, 37.5639522416251, 40.419012205941335, 41.434588704790386, 37.86656018665859, 36.4866166796003, 33.088350023542134, 32.39391578946795, 32.36133221217564, 33.72696590423584, 34.930025645664756, 32.45261417116438, 33.41065263748169, 34.73196724482945, 32.88749497277396, 33.40156439372471, 38.38508687700544, 36.018561703818186, 37.4306058883667, 39.458725997379844, 40.578313555036274, 42.4663336617606, 47.299271311078755, 39.229359013693674, 43.582450594220845, 46.47402681623186, 41.513753005436485, 36.79487003598894, 33.29967948368618, 32.661956446511404, 32.58771841866629, 34.036904198782786, 33.190307889665874, 33.73557472229004, 33.66362612588065, 34.850868293217246, 34.38008962358747, 33.83287034715925, 34.70657505307879, 33.19976091384888, 35.67883995601109, 41.795127255576, 48.39153160367693, 47.14267628533499, 44.49915075302124, 47.36936126436506, 45.79023027420044, 48.19557850701468, 46.01147133963448, 46.752903188977925, 45.74015460695539, 47.16924967084612, 47.62898070471627, 47.61838470186506, 47.34731810433524, 43.09791101728167, 38.24526480266026, 34.37750141961234, 33.9784767968314, 33.88719136374337, 35.91734034674508, 35.43046964917864, 37.44191060747419, 38.35420560836792, 44.07206930433001, 46.50419936861311, 49.653630188533235, 47.59458712169102, 45.30561426707676, 47.37450293132237, 50.10680907113211, 52.95541068485805, 50.7704245703561, 48.09476361955915, 51.47294998168945, 55.58384125573294, 46.11143854686192, 27.065800871167863, 16.73823298726763, 3.1967675941331044, 4.640183329582214, 1.918756114585059, 0.7190345483166831, 0.03624084711607013, 0.19140949047037534, 9.685241665158953, 40.050021171569824, 37.26186888558524, 28.8707309450422, 36.73891271863665, 49.883994238717214, 56.185086250305176, 34.02915695735386, 3.8813696929386685, 0.0821511439446892, 0.04415852975632463, 0.0511956639321787, 0.021214193797537258, 0.0427505017391273, 0.04166622313537768, 0.026365258464855806, 0.024038210744038224, 0.06524623105568544, 0.02312718757561275, 0.01960250179815505, 0.011611762988780226, 0.058518407068082264, 0.03606877742069108, 0.012880461473417069, 0.062428614390747886, 0.010938212658012552, 0.11131103709340096, 0.16068230356488908, 0.15351873795901025, 0.0898569675960711, 0.12192489898630551, 0.16939834372273513, 0.13352229738874094, 0.2957717590034008, 0.11263663667653288, 0.10265939669417483, 0.0804960545418518, 0.10926054497914654, 0.16968081785099848, 0.2860124712543828, 0.15083302850169794, 0.15962469817272254, 0.16728051379323006, 0.37870852436338154, 8.316270232200623, 44.079201630183626, 57.23005015509469, 46.399931226457866, 30.831248555864605, 23.70303429876055, 31.484789167131694, 46.88356753758022, 23.778020995003835, 2.227153863225664, 0.114504535017269, 4.547917766230447, 31.293074471609934, 31.283812522888184, 10.563037122998919, 12.19702500956399, 13.538558874811445, 19.284504583903722, 42.5295865876334, 53.94151987348284, 51.326575756073, 49.38438401903425, 48.84606191090175, 48.108382088797434, 50.58207975115095, 48.84345981052944, 48.69596345084054, 45.88061244147164, 38.96468823296683, 34.988439151218955, 34.8375312260219, 39.84557042803083, 48.40589353016445, 48.433655057634624, 47.17094850540161, 42.65944147109985, 49.15225165230887, 45.50322103500366, 45.975740228380474, 44.10997520174299, 46.12994507380894, 44.46946457454136, 42.53841427394322, 38.146183490753174, 35.01575946807861, 33.38884571620396, 36.07382072721209, 38.46286153793335, 38.9088316644941, 43.150105885096956, 42.891341073172434, 39.442571435655864, 37.626597200121196, 35.42124938964844, 35.02272156306675, 34.893933228084016, 35.90056044714791, 36.23538024084908, 33.307180064065115, 34.87399189812796, 36.19274262019566, 35.5241139956883, 36.65565940311977, 41.336935247693745, 40.55211189814976, 40.48902225494385, 40.99543128694807, 43.03196913855416, 45.332698345184326, 50.0099789755685, 42.48455878666469, 47.57068531853812, 49.13182047435215, 44.98897443498884, 38.6549688066755, 35.31445905140468, 34.723080498831614, 34.689482484545024, 36.24424614225115, 35.86927270889282, 34.880022934504915, 35.35734333310808, 36.07009996686663, 37.17436327253069, 33.72063609531948, 36.54852860314505, 35.360602038247244, 37.64993967328753, 42.702242374420166, 50.41733448845999, 50.01742744445801, 45.73133734294346, 49.731321471078054, 47.1493604523795, 49.77872208186558, 46.99906744275774, 48.957486697605674, 46.35856860024588, 48.00062247685024, 49.403724329812185, 49.75636625289917, 50.22904178074428, 46.930252483912874, 41.80702257156372, 38.01629386629377, 35.20697389330183, 35.06285088402884, 38.82468897955758, 36.24848454339163, 38.56715399878365, 41.36174726486206, 45.94972617285592, 49.551356179373606, 52.09863526480538, 49.73545912333897, 48.50143820898873, 48.88864047186715, 51.93381009783064, 54.08599029268537, 52.98983553477696, 50.14120612825666, 54.952058928353445, 57.73315184456961, 49.35333946772984, 28.96632947240557, 20.998484475272043, 5.0653301392282755, 6.888112306594849, 5.929083721978324, 1.0152955310685294, 0.20514715117003235, 0.3535492329725197, 11.124494995389666, 46.65802901131766, 43.60509477342878, 32.35687146868025, 41.51760925565447, 55.46478387287685, 61.74401337759835, 41.5676189150129, 5.484187960624695, 0.16083018348685332, 0.14054674974509648, 0.13420075098318712, 0.09954113473317452, 0.18635809581194604, 0.11483452016753809, 0.13418669173760073, 0.13959195597895555, 0.18236290876354488, 0.13047688294734272, 0.15401676909199782, 0.0649716957871403, 0.26176371957574573, 0.1615783226277147, 0.14542530796357564, 0.13495745323598385, 0.1447680110910109], [0.01057020919064858, 0.021200333023443818, 0.07093687355518341, 0.05624216974579862, 0.039895063532250266, 0.020107493004096404, 0.03124250711074897, 0.009465410839766264, 0.028110766051603214, 0.06095227146787303, 0.03676470329186746, 0.05214133479499391, 0.012084522084998233, 0.0456393340469471, 0.0010238330079508679, 0.030140182868178402, 0.05458672750475151, 0.046477382470454486, 4.373908383505685, 26.308113711220876, 41.87297139848982, 36.21913882664272, 26.731986829212733, 22.927104643413, 34.64688655308315, 36.734854970659526, 20.605576004300797, 2.0663365040506636, 0.033428655338606665, 0.45279659596937044, 10.562843441963196, 18.364966085978917, 3.6708653313773016, 11.027706589017596, 6.373472264834812, 18.8692124911717, 40.310589041028706, 50.19713912691389, 48.19555418831961, 47.95551824569702, 47.66052205221993, 47.1572709764753, 45.86222403390067, 46.08990955352783, 43.198368072509766, 37.41271775109427, 31.387966019766672, 31.510765007564, 34.75597327096121, 41.751065254211426, 45.49147163118635, 43.356887749263215, 42.12805019106184, 43.72449609211513, 42.27854469844273, 45.676811354500906, 42.1578996522086, 42.15559632437569, 42.80084426062447, 41.267258712223594, 37.68616758074079, 34.42678499221802, 31.674673012324742, 30.976469380514963, 30.423333712986537, 32.337600639888215, 32.57627126148769, 33.49916573933193, 31.309496538979666, 31.59560251235962, 29.69095536640712, 31.556859357016428, 30.282358237675258, 32.074291706085205, 32.046471118927, 32.297648497990195, 31.12624822344099, 33.18907458441598, 33.68826791218349, 36.57763460704258, 42.209406648363384, 43.83495855331421, 41.18197304861886, 44.36216006960188, 40.18588277271816, 42.40586348942348, 39.0544068472726, 48.485620634896414, 32.69041974203927, 39.82438884462629, 45.448719365256174, 37.92812817437308, 36.88679470334734, 31.24458646774292, 33.202279635838096, 32.52774504252842, 32.33702393940517, 31.69740751811436, 33.37811074938093, 31.62080362864903, 31.159599576677593, 34.273782185145784, 32.25318002700806, 32.67635311399187, 33.53126294272286, 31.94018452508109, 37.64680256162371, 43.90825162615095, 47.6053637777056, 46.72564888000488, 43.16278287342617, 43.480600425175254, 44.68465723310198, 46.93159348624093, 45.9059351512364, 45.21211583273751, 43.95404372896467, 47.0449846131461, 44.47743763242449, 45.67099918637957, 46.80859994888306, 46.54481158937727, 42.40164245877947, 35.95753220149449, 31.08533375603812, 32.52678271702358, 34.01586157935006, 35.61939811706543, 36.33087280818394, 39.57065800258091, 44.5738855770656, 46.276850836617605, 48.23854269300188, 44.766399315425325, 45.096786158425466, 46.101506096976145, 48.89881958280291, 51.122903210776194, 48.40449694224766, 48.99681002753121, 51.901521818978445, 41.599660532815115, 25.805364642824443, 11.415621042251587, 3.484985602753503, 4.974169339452471, 0.6438021681138447, 0.1897361281194857, 0.11440673097968102, 0.14932050609162875, 7.503773944718497, 39.12545912606375, 40.75025715146746, 27.142647947583878, 24.783194303512573, 40.35946266991751, 46.61350148064749, 28.88094653402056, 2.8674983254500797, 0.06096007462058749, 0.0346276368945837, 0.0468627360782453, 0.007433350281124669, 0.03287070617079735, 0.07511180453002453, 0.018303985940292478, 0.038110248411872556, 0.0576841143359031, 0.02381559697512005, 0.0317721851170063, 0.05397000702630196, 0.05377035148973976, 0.02228374988771975, 0.11124211150620665, 0.04724019493109413, 0.027007763274013996, 0.04845978359558752, 0.053167232245739014, 0.03490361405004348, 0.05686867469921708, 0.04581443000850933, 0.016990589809470942, 0.021670406817325523, 0.036989512121570964, 0.06767803949436971, 0.05443669662677816, 0.06765699133809124, 0.10093688126653433, 0.02110294798122985, 0.02224846606675003, 0.01861639364090349, 0.06915741546877793, 0.04840144994003432, 0.06613030111683266, 5.43417135306767, 31.58175822666713, 48.332854066576274, 42.19606263296944, 31.507871082850865, 27.525780303137644, 35.74943017959595, 40.43496526990618, 24.38616555077689, 1.9322883827345712, 0.055479065515100956, 0.1364733683211463, 13.160072258540563, 17.299930572509766, 4.360049767153604, 11.15962769304003, 6.3822712898254395, 15.86202345575605, 42.16234997340611, 51.346774169376914, 49.04681968688965, 49.39223895754133, 49.248487676892964, 49.52090917314802, 46.94462830679757, 47.61631761278425, 46.18821961539132, 39.974921567099436, 32.581367765154155, 32.825794969286235, 35.38751935958862, 43.25301912852696, 46.726705006190706, 44.12283284323556, 43.608211040496826, 44.26648684910366, 42.79447971071516, 46.23548126220703, 42.61392729622977, 42.52014398574829, 44.50236429486956, 42.25173854827881, 39.99926110676357, 35.76971891948155, 33.47862686429705, 31.51796681540353, 33.466832297188894, 32.94569655827114, 35.438397543770925, 35.835111890520366, 32.6125408581325, 32.98787907191685, 30.712993689945765, 33.354438236781526, 33.1243451663426, 34.28989158357893, 33.65007366452898, 32.92462614604405, 33.75091634477888, 34.45954574857439, 33.816288471221924, 38.19986874716622, 43.874281883239746, 45.39109795434134, 42.90515756607056, 46.21286140169416, 43.02420800072806, 44.91400337219238, 42.24076039450509, 50.156728403908865, 34.894318853105815, 42.54266309738159, 46.755706787109375, 39.581069878169465, 38.705061844417024, 32.09628275462559, 33.86241756166731, 33.39172574451992, 34.22295263835362, 33.02647631508963, 34.24817112513951, 34.02250753130232, 33.54530872617449, 35.32378700801304, 34.76861204419817, 32.97402088982718, 35.3924560546875, 33.69058861051287, 40.96277822766985, 45.34553861618042, 48.34442629132952, 46.66851731709072, 43.69543177740914, 43.73040206091744, 44.336097376687185, 48.18911320822579, 47.672643184661865, 46.19813469478062, 45.08809743608747, 47.11677687508719, 45.909016677311485, 47.12240491594587, 47.127473626817974, 48.415485518319265, 43.3632036617824, 37.060246058872764, 33.12444938932146, 33.793814522879465, 35.829605443137034, 36.716039248875205, 38.767251695905415, 40.68257474899292, 46.1054561478751, 48.27878318514143, 49.69274507250105, 47.288567611149375, 48.266637734004426, 47.7374837739127, 50.82379715783255, 52.05147784096854, 49.65693405696324, 50.61694928577968, 53.37659658704485, 43.69027968815395, 27.100719043186732, 13.297721283776418, 5.431866722447531, 3.1908179819583893, 2.5321250643048967, 0.8986223031367574, 0.09845564155174152, 0.11834227479994297, 8.483113850866046, 42.306212425231934, 41.630795410701204, 26.03043416568211, 28.280243498938425, 45.53944894245693, 52.924970626831055, 34.915104389190674, 3.7583613906587874, 0.039867094318781576, 0.04788304240043674, 0.019039212559748973, 0.00568488216127402, 0.041096314787864685, 0.013751462950105113, 0.015218749974987336, 0.06476539400007043, 0.06153430523616927, 0.05829291631068502, 0.053018487191626, 0.032888599139239104, 0.1350186299532652, 0.05878694408706256, 0.04237410479358264, 0.023105024925566146, 0.014400589412876537, 0.11928414925932884, 0.10321183276495763, 0.15356326342693397, 0.12937089800834656, 0.1780825470175062, 0.08663674896316868, 0.12404035404324532, 0.12032637904797282, 0.10678185655602387, 0.1579585825758321, 0.14279192712690147, 0.16598456619041307, 0.20563425788921968, 0.21696124651602336, 0.14397468151790754, 0.11608923998262201, 0.1325257465775524, 0.20275208540260792, 6.879311544554574, 36.46373973573957, 54.57591124943325, 47.10967581612723, 37.13757950919015, 33.12252473831177, 44.619806221553254, 46.079577582223074, 27.322524649756296, 2.783176290137427, 0.1819157406155552, 1.0254834358181273, 13.799559269632612, 23.520128182002477, 12.45388080392565, 21.077204091208323, 9.882123214857918, 22.51114204951695, 42.17792436054775, 51.32843439919608, 51.344828673771445, 52.15924787521362, 50.366143635341096, 50.54272862843105, 47.941218852996826, 48.89237512860979, 48.635885851723806, 41.44584131240845, 34.67975500651768, 35.07003879547119, 37.505375453404014, 45.60390043258667, 49.46793610709054, 46.102621282849995, 44.12899589538574, 45.29898568562099, 43.890512875148225, 46.79932062966483, 42.10128573008946, 44.79574155807495, 46.03910085133144, 45.539796352386475, 42.44100052969796, 37.414729254586355, 35.30065298080444, 34.47171899250576, 35.36254405975342, 34.9405243737357, 37.09170750209263, 36.93066562925066, 34.484482833317344, 34.40548528943743, 31.52860450744629, 34.39745317186628, 33.53564725603376, 34.9962489264352, 35.64905650275094, 35.08867038999285, 34.686199460710796, 35.579963615962434, 37.16504226412092, 39.81950078691755, 47.82214757374355, 48.10368858064924, 45.421357359204976, 49.005731514522004, 45.27679661342076, 46.75136763708932, 44.8947742325919, 50.862210273742676, 37.65186085019793, 44.95770059313093, 48.87712035860334, 42.056289196014404, 40.78645726612636, 34.21444456917899, 36.79357072285244, 36.70861509868077, 36.378867489951, 35.2581786428179, 36.71447243009295, 36.11219910212925, 35.24255561828613, 37.56386538914272, 35.97073725291661, 36.66911458969116, 37.81518868037632, 35.34843921661377, 42.85036754608154, 47.81187118802752, 51.74620526177542, 48.99762644086565, 43.38498279026577, 43.64989675794329, 44.74257394245693, 50.36249583108084, 50.44596801485334, 48.6460406439645, 49.10909986495972, 49.734632287706646, 47.55345378603254, 47.61861399241856, 49.298146452222554, 50.566133635384695, 45.93745912824358, 40.07160922459194, 35.65003967285156, 35.67946529388428, 37.11255209786551, 39.816672870091026, 39.63513381140572, 42.73612526484898, 48.8721523966108, 49.76266132082258, 51.210398401532856, 48.89312553405762, 49.84747798102242, 47.11820125579834, 51.659453528267996, 54.62051173618862, 51.59302180153983, 52.73768540791103, 56.5079516683306, 45.18677922657558, 30.68135506766183, 20.011963605880737, 7.750316006796701, 9.323776398386274, 3.4192795285156796, 0.9412963475499834, 0.44320876044886454, 0.3799527404563767, 10.248718857765198, 48.29587575367519, 51.311213288988384, 37.28409964697701, 36.71602882657732, 53.0847236088344, 60.5888614654541, 41.31198079245431, 5.369402417114802, 0.2694862623299871, 0.0952861298407827, 0.1613321229815483, 0.10007398828331913, 0.11113020072558097, 0.12241816680346217, 0.10945339141679661, 0.14349016680249146, 0.15790393336543015, 0.13977437333336898, 0.07141915589038815, 0.14535702019929886, 0.239125484334571, 0.1451796240040234, 0.2806791860078062, 0.1801107424710478, 0.10990851878055505], [0.016615738227431263, 0.0276665766723454, 0.06610055414161511, 0.049609405121632984, 0.0318318758425968, 0.012870245280542543, 0.06836936489811965, 0.0678423128223845, 0.03289470595440694, 0.04324909944885543, 0.033456397242844105, 0.018253955857029984, 0.03288625819342477, 0.04552933334239891, 0.02328621582793338, 0.01742140356717365, 0.037372511212847064, 0.0207781824615917, 2.6609670306955064, 21.974018505641393, 42.517496722085134, 40.35533543995449, 27.926745210375103, 19.804290635245188, 21.30041323389326, 31.007541724613734, 22.83974494252886, 2.7829988939421515, 0.09387578123382159, 0.5856041109987667, 0.32665020493524416, 7.273595758846827, 11.19503571305956, 10.206823825836182, 8.600626996585301, 16.201844215393066, 38.88933501924787, 50.43251977648054, 48.80748551232474, 50.543221950531006, 49.40576362609863, 44.725721086774556, 46.54787227085659, 44.20124326433454, 40.44800009046282, 34.14449010576521, 30.784542764936173, 34.51047951834542, 42.05385037830898, 45.245488030569895, 44.47563110079084, 42.17541258675711, 45.3798314503261, 44.729295934949604, 45.891472475869314, 43.68035071236746, 44.99333095550537, 44.173262868608745, 42.73797695977347, 43.51808943067278, 40.533438614436555, 36.693839754377095, 32.514258589063374, 30.70668125152588, 31.048508303506033, 31.14584561756679, 31.87883540562221, 33.26185349055699, 30.269757679530553, 32.463210174015586, 31.461227825709752, 31.797051634107316, 31.567573479243688, 33.11652496882847, 32.22245856693813, 33.247797284807476, 32.857395376477925, 33.26659563609532, 33.92599705287388, 40.64940404891968, 43.63752549035208, 46.1591830934797, 45.057570525578086, 45.21810517992292, 44.648912225450786, 43.98917382104056, 42.952954224177766, 45.61205414363316, 27.282932077135357, 34.937845843178884, 48.49756806237357, 38.257920946393696, 39.73963124411446, 39.39154733930315, 40.951678480420796, 38.91612032481602, 38.75740262440273, 36.01419823510306, 33.112856319972444, 31.53432982308524, 34.24795920508248, 32.046189716884065, 33.33360753740583, 32.64976930618286, 33.99993283408028, 32.51649938310896, 34.07066202163696, 39.98435027258736, 44.68005057743618, 45.19680200304304, 46.559739794049946, 46.700114250183105, 45.44798285620553, 42.2961688041687, 42.589761461530415, 40.119659491947715, 40.600342818668906, 41.92307833262852, 45.89568655831473, 45.85892711366926, 44.58066701889038, 46.488281045641216, 45.21856376102993, 41.51267950875418, 35.00259263174874, 33.305001803806846, 33.245869159698486, 33.63561793736049, 35.11169672012329, 36.8725335257394, 42.19861262185233, 44.89563580921718, 46.58312743050711, 47.11202778135027, 46.71568863732474, 47.206624031066895, 49.00046477999006, 52.91261672973633, 50.70317990439278, 48.80183662687029, 52.98128925051008, 40.61877291543143, 26.12610912322998, 11.315189174243383, 4.404335413660322, 6.839626474039895, 1.103664783494813, 0.901837690600327, 0.03146176552399993, 0.14674668705889157, 8.418046576636177, 33.50093752997262, 36.61722196851458, 34.074931689671104, 36.69992985044207, 42.57937043053763, 54.28384024756295, 24.350698471069336, 2.7897607939583913, 0.022749196072774272, 0.05319156790418284, 0.01813111387725387, 0.035151435394904444, 0.06222169513681105, 0.04529734900487321, 0.03816355073026248, 0.061948428728750775, 0.05487235003550138, 0.03536583889009697, 0.01818686570706112, 0.06261926916028772, 0.10267870101545538, 0.05372114073751228, 0.060513422159211974, 0.06477746513805219, 0.031303978990763426, 0.009780295193195343, 0.00956000795122236, 0.012911987906721021, 0.06486994946109396, 0.0186182460415044, 0.02610381383315793, 0.048551694556538544, 0.03474941696705563, 0.05939301156571933, 0.06849502279822316, 0.03173148658658777, 0.0207499435304531, 0.0367129242845944, 0.05317534073921187, 0.06896583789161273, 0.05563373078725167, 0.027992733188771775, 0.09886223330561604, 3.386238021509988, 27.653231109891617, 49.717053345271516, 44.59466763905117, 33.6023325920105, 21.274996723447526, 26.816499505724224, 40.10117728369576, 27.212529454912456, 3.2469672432967593, 0.10122638501759086, 0.20968637402568543, 1.621751131755965, 12.231807691710335, 15.006726264953613, 9.233869314193726, 6.523946796144758, 17.953318323407853, 38.88328313827515, 51.0430406161717, 50.4197872025626, 51.353593826293945, 49.13524941035679, 45.51156234741211, 47.52172483716692, 46.64611285073416, 42.47330617904663, 35.273805141448975, 32.87167045048305, 35.59837286812918, 42.47666563306536, 46.657212597983225, 45.62612077168056, 43.32942846843174, 46.54415498461042, 45.86022642680577, 46.554386207035606, 45.96303544725691, 44.82330853598458, 45.714411531175884, 45.24324376242501, 45.705434458596365, 43.07706642150879, 38.55272259031023, 33.28590815407889, 31.924926280975342, 32.71006577355521, 32.55330746514456, 33.73372302736555, 34.82328394481114, 31.69447190420968, 32.593475001198904, 33.02822378703526, 33.74758120945522, 32.73226179395403, 35.02252006530762, 35.36029631750924, 34.287265164511545, 33.59700332369123, 35.491092681884766, 36.0491372517177, 43.32106631142752, 46.00140687397548, 47.714214256831575, 46.76004246303013, 47.51211200441633, 46.103048597063335, 47.12350273132324, 44.924106052943635, 46.532614026750835, 29.82513897759574, 37.86668178013393, 50.03889042990548, 39.523205280303955, 40.15194082260132, 40.50702851159232, 41.73347588947841, 39.37083823340279, 40.33168029785156, 36.19082839148385, 34.26153598512922, 33.51412868499756, 34.463579177856445, 32.23340892791748, 34.743164266858784, 32.82296357836042, 34.74820518493652, 33.950843811035156, 36.0408376285008, 41.80002920968192, 46.2701666695731, 47.57603195735386, 46.76678916386196, 47.60981409890311, 47.10159158706665, 44.89412457602364, 44.3078008379255, 42.1050238609314, 43.71035998208182, 42.98535714830671, 48.45330803734915, 46.17851298195975, 46.23346281051636, 47.73305777141026, 46.258431162152974, 43.86772625786917, 36.44653252192906, 34.603206702641074, 35.01875066757202, 35.872343812670024, 36.900388853890554, 39.63464396340506, 44.176900250571116, 45.870009490421836, 49.69540623256138, 49.62918642589024, 49.305977072034565, 45.88524341583252, 50.88645601272583, 52.66980150767735, 53.70642410005842, 50.31450809751238, 55.84589603969029, 40.72589329310826, 28.66298154422215, 10.428249887057714, 6.820423824446542, 9.660789217267718, 1.5112326507057463, 0.7634887429220336, 0.014716532280934709, 0.21056682749518327, 8.658386502947126, 39.190820830208914, 43.052810260227744, 37.38783972603934, 42.21460737500872, 47.90601927893502, 58.54884951455252, 30.411660739353724, 3.940061560698918, 0.03108383508931313, 0.030686033756605217, 0.01502212748995849, 0.06104063708335161, 0.03604729500200067, 0.04213563026860356, 0.07618363201618195, 0.0486866110669715, 0.054283422351415665, 0.020084624677630405, 0.03707963853542294, 0.03886658086308411, 0.06937835325620004, 0.025376814450802546, 0.018201036910925592, 0.0629052852413484, 0.016294087183528712, 0.1133778276188033, 0.16259323459650787, 0.15447385742196015, 0.08815966652972357, 0.08855360360550028, 0.1461694844599281, 0.1310134277279888, 0.12067640812269279, 0.09882374679935829, 0.09420106413641147, 0.15935270062514714, 0.08144767954945564, 0.1398617686437709, 0.1657931786030531, 0.18326192695115293, 0.11829305386969022, 0.15555948631039687, 0.2417827903160027, 4.674944298607962, 32.44846609660557, 56.592997619083945, 52.1894725390843, 38.969857692718506, 27.201791013990128, 28.827785866601126, 41.73303815296718, 31.93074539729527, 3.8919739467757086, 0.26336704354201046, 1.369795771581786, 2.5538913820471083, 9.8165009532656, 20.206348146711075, 15.141107899802071, 13.228959304945809, 18.805113622120448, 42.05392680849348, 52.2078401020595, 52.24607603890555, 54.47584329332624, 51.07481472832816, 46.50607190813337, 49.31018073218209, 49.20559644699097, 44.29671498707363, 37.24064908708845, 34.80299173082624, 38.68999120167324, 45.277567863464355, 48.16452700751168, 45.96426180430821, 43.074749197278706, 48.230295181274414, 49.20089251654488, 48.60556738717215, 48.096490246909006, 47.650634765625, 47.18995182854788, 47.15849038532802, 48.15368434361049, 46.17375694002424, 40.45522969109671, 36.4086092540196, 33.38861642565046, 34.198408126831055, 34.16797501700265, 35.564754009246826, 35.558483260018484, 33.74784524100167, 35.370874949863975, 35.71079819543021, 34.74515839985439, 34.79460525512695, 36.98994071143014, 36.94718497140067, 35.50908156803676, 35.817668437957764, 36.996569292885916, 38.83324221202305, 45.90584135055542, 48.780797481536865, 48.52144207273211, 49.06943954740252, 48.23350177492414, 48.84981393814087, 47.445402349744526, 46.75893422535488, 47.57575055531093, 32.55472837175642, 39.97872570582798, 53.11148459570748, 43.25480134146554, 42.794861861637656, 43.81720590591431, 45.05378375734602, 43.44403205599104, 42.70947892325265, 39.155235631125315, 36.16123948778425, 35.82408857345581, 37.839705399104524, 35.048457690647666, 37.18345846448626, 35.28214297975813, 37.44087879998343, 36.08032424109322, 37.579801082611084, 42.9885915347508, 49.219829831804546, 50.00627211162022, 49.255349023001536, 50.5517578125, 49.716066701071604, 47.94219160079956, 48.04413209642683, 44.55107464109148, 44.83575970785958, 45.97849866322109, 51.36471094403948, 48.44029753548758, 47.146810463496614, 49.737890992845806, 48.94882576806204, 44.868537834712434, 39.5051086970738, 36.8569278717041, 36.767567089625764, 38.19318110602242, 38.79348461968558, 40.34363119942801, 46.38058049338204, 47.88020672116961, 51.13841853822981, 51.486457279750276, 50.892994267599924, 48.1750431060791, 51.75436592102051, 54.998476369040354, 55.64808777400425, 52.44777876990182, 58.421245847429546, 43.84335545131138, 32.85601963315691, 16.61377685410636, 8.743912747928075, 11.28531105177743, 3.2256045724664415, 1.270794689655304, 0.13832122273743153, 0.31399354551519665, 11.179243326187134, 45.793853759765625, 48.74860300336565, 45.34868615014212, 49.521197523389546, 53.56442723955427, 66.91235446929932, 37.28486047472273, 6.183174567563193, 0.220253552709307, 0.14573851972818375, 0.09514798689633608, 0.13223152022276605, 0.18791754570390495, 0.15198499097355775, 0.1926761389310871, 0.12279208031083856, 0.10039676739169018, 0.13710991559284075, 0.18131092164133275, 0.1719627854015146, 0.15384630752461298, 0.14974165920700344, 0.13833908177912235, 0.19109524733253888, 0.14295450411736965], [0.05559571247015681, 0.051825469958462884, 0.03749051184526511, 0.09011877354766641, 0.05317390563764742, 0.054020975184227736, 0.0523959177413157, 0.07892182615718671, 0.01998484610313816, 0.04430025875834482, 0.007093989473235394, 0.07371861607368503, 0.01996935684499996, 0.031012066440390687, 0.04759253441755261, 0.029480070075286285, 0.016133464373914257, 0.12168635321514946, 1.527292543223926, 17.407625913619995, 38.31756428309849, 41.53095327104841, 33.203061308179585, 27.800795214516775, 27.611922332218715, 36.24674054554531, 24.80594617979867, 3.967539514814104, 0.04099803577576365, 0.18214007786342076, 2.039220290524619, 3.693940733160291, 8.992844121796743, 6.9705431291035245, 1.2027289420366287, 11.273579018456594, 38.536310945238384, 45.17244856698172, 48.882779666355674, 47.902114391326904, 46.28734956468855, 46.63144520350865, 44.12486866542271, 42.73165757315499, 35.43420778002058, 31.540260110582622, 32.25012281962803, 40.59203972135271, 48.14334542410714, 46.074963978358674, 43.55811105455671, 44.56323051452637, 40.33390719549996, 40.120809418814524, 40.18099471500942, 42.74304914474487, 43.36524643216814, 44.194152627672466, 44.0727675982884, 42.80406127657209, 40.224622453962056, 39.787810053144185, 33.834801946367534, 31.388685158320836, 29.898623125893728, 31.23127371924264, 29.21872799737113, 29.41127300262451, 31.525001866476877, 32.264307567051475, 32.242511068071636, 36.724488258361816, 41.07992485591343, 34.43023477281843, 32.689561639513286, 31.607039247240337, 31.916904585702078, 33.65516669409615, 34.46071999413626, 41.43140295573643, 45.619467871529714, 46.57116263253348, 45.73166390827724, 46.63930709021432, 43.12444618770054, 46.49891178948538, 38.80444540296282, 45.37505108969552, 31.37562949316842, 32.10641322817121, 50.20545959472656, 39.684577192579, 44.16351107188633, 38.33227709361485, 43.5679601260594, 43.990361962999614, 44.69692775181362, 42.35409940992083, 36.96094587871006, 30.251800060272217, 33.16220242636544, 31.113706724984304, 32.21884550367083, 31.16974742071969, 32.4284587587629, 32.87066296168736, 32.08215011869158, 33.70163624627249, 40.887129715510774, 43.2140223639352, 45.631165163857595, 43.630625929151265, 41.558019978659495, 41.061018807547434, 39.11507851736886, 37.74239935193743, 40.06353889192854, 39.294950008392334, 40.16658762523106, 46.53901331765311, 44.290357385362896, 44.04865040097918, 49.04821627480643, 43.83238771983555, 39.94473164422171, 34.33484295436314, 32.56829125540597, 33.565465450286865, 35.5558568409511, 34.778815473829, 38.49855443409511, 41.32630797794887, 44.59219755445208, 46.36842461994716, 47.56641217640468, 50.34627178737095, 47.498747144426616, 49.05608510971069, 50.6023302759443, 51.39799976348877, 51.70682634626116, 40.89987618582589, 23.518646478652954, 8.546835780143738, 4.967266304152353, 8.839096120425634, 0.3515356124511787, 1.0768577648060662, 0.17038337300930703, 0.08684537134000234, 6.4668890578406195, 39.979267665318076, 39.37905100413731, 25.768480130604335, 35.12353992462158, 44.503225871494834, 49.4446804864066, 22.242870364870342, 2.0625638493469785, 0.038579282350838184, 0.022191467428846017, 0.06651977343218667, 0.022936875466257334, 0.040765338976468356, 0.043194090614893606, 0.08053816442510911, 0.013232494770948375, 0.10516917559185199, 0.02187252034699278, 0.10949352676314966, 0.03540886818830456, 0.07913631786193166, 0.017899256765044162, 0.0054098664051187885, 0.006246309245138296, 0.048387000536812205, 0.03748884943446942, 0.019268603197165897, 0.016713613511196206, 0.03251698925825102, 0.023430798069706986, 0.0435776427122099, 0.00726943403216345, 0.047722243171717436, 0.022054761282301376, 0.06598526425659657, 0.05678671445431454, 0.03841278003528714, 0.024849426500233154, 0.07426182406821422, 0.016351933990206038, 0.01690359822740512, 0.03316735828827534, 0.03847802457000528, 2.170212072985513, 22.49520114489964, 45.75089999607631, 46.84965338025774, 37.765950271061485, 29.793059144701274, 27.5530207157135, 40.76635612760271, 28.249092987605504, 4.265705823898315, 0.08490648466561522, 0.056216853604252846, 0.9307269432715007, 5.2947344694818765, 12.8415390423366, 11.74446885926383, 4.703550900731768, 15.706972667149135, 40.48887981687273, 47.29100642885481, 50.09664733069283, 49.99900082179478, 47.09535557883126, 47.043119021824424, 45.33711045128958, 44.085701669965474, 37.91294288635254, 33.410287857055664, 33.38554532187325, 41.61341449192592, 48.511964729854036, 45.91432857513428, 44.388723032815115, 46.833981718335835, 42.928128310612266, 42.93896402631487, 42.392172064099995, 43.819741998400005, 45.248378481183735, 44.786517824445454, 45.158166544778005, 43.80881595611572, 43.36864757537842, 41.41860784803118, 35.12071200779506, 32.616810526166645, 31.495235783713206, 32.33516877038138, 31.692818232945033, 31.91986451830183, 32.329544203622, 33.140221800122944, 33.42134591511318, 37.949170793805806, 40.79453454698835, 35.89143051419939, 33.96852002825056, 33.00642728805542, 34.436807768685476, 34.21102952957153, 35.25971072060721, 44.1177259172712, 47.401812825884136, 48.8620844568525, 47.0200822693961, 48.30102436883109, 44.61550528662545, 46.65606614521572, 40.16168219702584, 45.94538702283587, 32.90476124627249, 34.31086819512503, 52.003000259399414, 40.73872661590576, 45.287298815590994, 40.444644110543386, 45.07403775623867, 45.3187289919172, 45.9699558530535, 43.889185769217356, 37.60006202970232, 32.29724202837263, 34.69442612784249, 34.157993929726736, 34.54696103504726, 33.00832067217146, 34.797523498535156, 34.032085623059956, 32.93856075831822, 36.49857452937535, 43.43056992122105, 45.16460405077253, 47.52211046218872, 45.29961797169277, 44.60347448076521, 42.676815441676546, 42.02850334984915, 39.083881105695454, 41.659335136413574, 42.08796255929129, 44.07482426507132, 47.31842054639544, 44.16550520488194, 45.89399119785854, 49.91583088466099, 45.47400038582938, 40.346455642155235, 36.28519535064697, 34.48124844687325, 36.61169467653547, 36.906958375658306, 36.64739104679653, 41.13793536594936, 44.84156492778233, 46.39280237470354, 49.57232584272112, 50.18323578153338, 51.44338887078421, 48.76696361814226, 50.98194858006069, 53.99902663912092, 52.42812926428658, 52.01883520398821, 43.70703179495675, 26.35414378983634, 8.55388559613909, 8.59288844040462, 12.734957150050572, 0.490668702338423, 0.655356153845787, 0.1613535511174372, 0.1792362465390137, 7.701939174107142, 43.033928530556814, 41.61981725692749, 29.694221019744873, 42.0825777053833, 49.124986921037944, 54.932030745915, 27.439370768410818, 3.4048559367656708, 0.03900941926985979, 0.026042684613327895, 0.002669632842298597, 0.08950948302767106, 0.048087844625115395, 0.024672093069446937, 0.05000372896237033, 0.05554740756217923, 0.07545310085905449, 0.07331659764583622, 0.06039912972067084, 0.01819390890055469, 0.05523781238922051, 0.029400579697851623, 0.047961850850177665, 0.022577852409865175, 0.023828056574399983, 0.18008331608559403, 0.05945621710270643, 0.07149070062275444, 0.1888564888920103, 0.10310628664280687, 0.14925934294504778, 0.11052247083612851, 0.197434433602861, 0.11377760688109056, 0.18578359378235682, 0.09376065419720751, 0.16145948400454863, 0.11375110330326216, 0.19135541122938904, 0.08026117964514665, 0.1504774625812258, 0.16014379103268894, 0.2419089978294713, 2.8370849745614186, 27.65679727281843, 52.46215111868722, 53.18945728029524, 42.931883811950684, 37.21752895627703, 35.7559997013637, 46.21224648611886, 32.1817421231951, 5.422580889293125, 0.18243910824613913, 0.3760434830827372, 4.296901064259665, 6.478067406586238, 12.912886619567871, 15.60747446332659, 3.991189880030496, 14.383838500295367, 41.89607763290405, 47.10493714468819, 52.87270975112915, 50.458450453622, 48.415117263793945, 48.11800534384591, 47.61856188092913, 46.63810505185808, 40.24590131214687, 34.888899258204866, 35.90069246292114, 44.279004028865266, 51.18919249943325, 46.812980788094656, 45.20821441922869, 49.365186146327424, 45.70120300565447, 43.32447787693569, 45.11461523600987, 45.84750427518572, 47.20156921659197, 45.9430559022086, 46.827016149248394, 45.17327192851475, 45.392164502825054, 44.16456372397286, 37.38744020462036, 34.51207412992205, 32.579377106257844, 33.93456418173653, 32.42875058310372, 32.76322296687535, 34.67212241036551, 36.26102951594761, 34.88942037309919, 39.83349445887974, 42.071630818503245, 37.19540589196341, 35.68197706767491, 35.080537523542134, 35.931469508579795, 36.827363286699565, 37.31897265570504, 46.34640230451311, 50.20397962842669, 50.083341530391145, 48.29192222867693, 48.753244400024414, 45.594402245112825, 47.063720430646626, 40.4283366884504, 46.703397274017334, 36.82432344981602, 37.154293400900706, 53.788551807403564, 45.16775853293282, 46.489635944366455, 42.99613380432129, 47.126052720206125, 48.54819958550589, 48.32581206730434, 46.436642033713206, 40.42337220055716, 34.78858811514718, 35.30470725468227, 35.40027277810233, 36.21402842657906, 34.24415506635393, 36.087428774152485, 35.76794712884085, 34.696986539023264, 37.371243953704834, 44.907607555389404, 46.477056230817524, 49.51448556355068, 49.32682514190674, 46.638629640851704, 44.26874501364571, 44.16413293566023, 40.53168419429234, 44.27018676485334, 43.68994964872088, 44.48656409127371, 50.441271032605854, 44.72617966788155, 46.27724340983799, 53.14207056590489, 48.82906314304897, 42.72037022454398, 38.82379961013794, 36.003793307713096, 38.21608236857823, 38.442190647125244, 37.79669604982649, 42.55018104825701, 45.74236413410732, 48.7156720161438, 50.884385449545725, 51.62073816571917, 53.88356147493635, 51.230635029929026, 52.92505400521414, 55.83134651184082, 55.15448079790388, 53.78906944819859, 45.8877968788147, 24.229716437203543, 10.613481044769287, 10.046630501747131, 11.896435516221182, 6.171038235936846, 1.7387659613575255, 0.33725470304489136, 0.35176338308623856, 9.38194237436567, 49.61581809180123, 48.53156212397984, 34.32936429977417, 48.68409245354788, 56.34291458129883, 62.744484492710654, 35.08825697217669, 4.658919147082737, 0.11935566685029439, 0.15599695140761988, 0.11378374762300934, 0.20503349655440875, 0.11663787625730038, 0.14834245214504854, 0.2089250034519604, 0.13587340765765735, 0.16467853555721895, 0.13968686945736408, 0.19498946837016515, 0.07109817489981651, 0.14148653431662492, 0.08215820749423333, 0.1593762050781931, 0.1539953545268093, 0.11803170932190758], [0.02705656351255519, 0.015912287402898073, 0.055913002230226994, 0.032425926466073306, 0.012426647923088499, 0.05139995047024318, 0.029544948201094354, 0.021127741650811264, 0.0236419954869364, 0.05810415465384722, 0.009799406980164349, 0.044061244798025916, 0.06692787153380257, 0.04906539984845689, 0.03627238203106182, 0.01903863071597048, 0.049617849489940066, 0.05705118365585804, 1.1322902760335376, 16.022948946271622, 38.17841965811593, 46.52524893624442, 33.47265836170742, 17.940575327192033, 21.11694778714861, 30.774127415248326, 29.98138311931065, 6.719175977366311, 0.05277367854224784, 0.036534934371177635, 1.0361040830612183, 4.6353113395827155, 11.942560264042445, 10.842098491532461, 5.21375321490424, 9.497596876961843, 30.87453235898699, 46.93018995012556, 48.187727042606895, 47.62778214045933, 46.96784918648856, 47.03341933659145, 44.73947504588536, 40.96365717479161, 31.88426194872175, 31.332085132598877, 35.83173506600516, 44.71101175035749, 46.123260906764436, 44.43133633477347, 45.56984731129238, 40.490974698747905, 39.02339356286185, 40.47338880811419, 36.0619740486145, 39.11240346091134, 39.904063837868826, 41.842086655753, 42.975282260349815, 44.54212188720703, 42.459590435028076, 41.721514565604075, 35.33900703702654, 32.10464143753052, 29.925759315490723, 32.39318970271519, 31.362122195107595, 31.894479274749756, 31.3883273260934, 31.962179047720774, 31.522288594927105, 36.077798570905415, 32.93517351150513, 32.613166196005686, 29.32955871309553, 32.00959702900478, 31.905471324920654, 32.55577407564436, 33.97656604221889, 38.87850625174386, 40.99160977772304, 43.5669595854623, 43.03154182434082, 46.13030638013567, 41.54630878993443, 46.41014507838658, 43.233800411224365, 44.48462206976754, 30.876842635018484, 30.740477289472306, 47.3343631880624, 42.97830820083618, 47.07807540893555, 43.411142757960725, 47.07364593233381, 44.758245604378835, 45.61207151412964, 41.97551638739449, 42.36056123461042, 32.28251879555838, 32.87209776469639, 31.46539327076503, 33.47915145329067, 32.60942806516375, 33.77731602532523, 32.66584743772234, 32.26375865936279, 32.17323405402047, 35.047384193965364, 38.66752072743007, 40.59399216515677, 40.77222735541207, 39.713745730263845, 36.528698444366455, 35.66383184705462, 33.36928653717041, 36.036748613630024, 39.46271078927176, 40.63369417190552, 43.53015497752598, 47.12535442624773, 43.769072260175435, 46.879172801971436, 44.777238505227224, 40.50124761036464, 35.00289140428816, 32.86949566432408, 33.00357852663313, 33.401018960135325, 34.848443371909006, 35.04800258363996, 35.21637828009469, 40.83306230817522, 45.023590360369, 46.85264457975115, 48.948895250047954, 48.92311743327549, 47.53006614957537, 49.29051385607038, 52.949400493076865, 52.41096373966762, 37.705709389277864, 22.800122840063914, 7.848510554858616, 6.751049969877515, 6.926707812717982, 0.9472422684941972, 0.7659397199749947, 0.08832184996988092, 0.26936998856919153, 9.236399327005659, 40.80409179415022, 39.74134744916643, 28.63122480256217, 34.172321115221294, 45.98301499230521, 46.61646488734654, 27.099218232291086, 3.891272178718022, 0.019775747055453912, 0.04773805982300213, 0.046683803001152616, 0.040513873898557255, 0.034830657964838405, 0.01766552180717034, 0.04882255895063281, 0.022809924956943308, 0.027662690363026092, 0.06909423707319157, 0.030706678184547594, 0.028919539081731012, 0.05876705622566598, 0.048937787767499685, 0.024578509519674947, 0.07772270550153085, 0.026609081542119384, 0.06335524895361491, 0.0034581870131660253, 0.023701272306165526, 0.029518146067857742, 0.018288535697917854, 0.010169243340247443, 0.01419535801479859, 0.005490961941956941, 0.004607363462647689, 0.07704184310776846, 0.03982504889635103, 0.01658935678590621, 0.03452678962743708, 0.04712218072797571, 0.03790636220946908, 0.022732239482658248, 0.03626408354778375, 0.03402014109971268, 1.5514710800988334, 20.590487991060527, 45.12127161026001, 52.609293120247976, 37.025869846343994, 23.408897944859095, 25.452925954546245, 35.86770241601126, 32.62590571812221, 7.804259215082441, 0.08223270385393075, 0.18335388201688016, 2.056558217321123, 4.264178088733128, 12.241610731397357, 8.52799139704023, 5.903510008539472, 12.447798524584089, 33.720042024339946, 49.10235316412789, 49.94095209666661, 48.71349375588553, 48.069802216121126, 47.92500523158482, 46.79504401343209, 43.284633432115825, 34.21166181564331, 32.30248097011021, 37.7676282610212, 46.46640116827828, 46.5017466545105, 44.13437032699585, 46.71905851364136, 42.988841669900076, 41.611802509852815, 41.916435854775564, 38.15266963413784, 41.2822459765843, 43.45313767024449, 44.92961597442627, 44.9500402041844, 46.802304880959646, 44.82733849116734, 43.0427770614624, 37.183274337223594, 33.173312595912385, 31.873033659798757, 34.15989078794207, 32.731688567570274, 33.80196475982666, 31.856816564287456, 34.165404183524, 33.43912982940674, 38.61894587108067, 35.970768519810264, 34.15049682344709, 32.73037188393729, 34.49095855440412, 34.3600093296596, 33.91701998029436, 34.78000361578805, 41.522139481135774, 44.25685664585659, 46.239959376198904, 45.94954204559326, 46.476284980773926, 44.205926350184846, 47.923372404915945, 43.09397486277989, 45.24605778285435, 33.73887511662075, 32.52516031265259, 48.085098675319124, 44.54615879058838, 49.79113156454903, 45.41458633967808, 48.14861215863909, 45.708231108529226, 48.12758343560355, 45.06711040224348, 44.48600476128714, 33.7312251499721, 34.58272688729422, 33.04967982428414, 34.116155351911274, 34.57935701097761, 34.053374903542654, 33.682910851069856, 33.62447302682059, 32.914589473179404, 37.28331797463553, 40.39703157969883, 42.887224265507285, 43.15364251817976, 40.82032626015799, 39.77691180365426, 36.96282189232962, 35.488184860774446, 37.65648487636021, 41.65145240511213, 43.40033483505249, 45.5459246635437, 47.06224046434675, 45.58695725032261, 48.7329626083374, 46.136320046016145, 42.078936849321636, 37.65497711726597, 34.81676653453282, 34.17237670081002, 35.493382113320486, 36.61871235711234, 37.00980561120169, 37.79336091450283, 43.10820824759347, 47.05093574523926, 49.09569331577846, 51.102638789585654, 50.44957760402134, 48.43176862171718, 51.492724554879324, 54.51270696095058, 53.58718606403896, 40.65457698277065, 23.893467051642283, 9.522102304867335, 9.59826672077179, 8.332831263542175, 3.4005439281463623, 0.6061391862375396, 0.1139515018356698, 0.34411461065922466, 10.037876640047346, 46.310594763074604, 43.555894579206196, 33.79390484946114, 41.13831751687186, 50.126125063214985, 53.62256976536342, 31.281345912388392, 4.133409082889557, 0.06136044420834098, 0.04307904500248177, 0.03641428066683667, 0.02320880855300597, 0.04435796816168087, 0.0342548802894141, 0.013473989624929215, 0.02034734495516334, 0.025186269943203245, 0.04415459425321647, 0.08550052850374154, 0.01624832847820861, 0.036511854002518315, 0.05587683292105794, 0.02857553879065173, 0.062443114684096405, 0.029979390424809287, 0.14834630622395448, 0.09467762642140899, 0.23377116450241633, 0.08639786392450333, 0.23741012066602707, 0.15719970901097569, 0.07806258369237185, 0.09363414134298052, 0.08298013731837273, 0.12602228697921547, 0.08954995764153344, 0.11112562739955527, 0.148619145154953, 0.2378327665584428, 0.07793432700314692, 0.1592748455171074, 0.12373958661087922, 0.2279109289603574, 1.9823164982455117, 24.118076256343297, 51.96530628204346, 58.40684917994908, 44.7412086214338, 27.71258088520595, 29.866692679268972, 41.12382010051182, 39.08181054251534, 9.418776512145996, 0.23434623650142125, 0.5382647854941232, 3.051279915230615, 8.711829440934316, 17.13250504221235, 17.677813564028057, 9.571475335529872, 12.552773645945958, 34.74901465007237, 49.1707547051566, 51.551634856632774, 50.994146142687114, 50.18402092797415, 50.166195324489046, 48.640120778764995, 44.23758929116385, 35.89537361689976, 34.33036484037127, 39.9601913860866, 48.78072452545166, 48.14712177004133, 45.0682499068124, 50.60364348547799, 44.059711933135986, 43.27251577377319, 44.80387095042637, 39.31435980115618, 44.2321696962629, 46.30049555642264, 45.90156473432268, 46.122256892068044, 48.23143815994263, 46.49753604616438, 46.43868827819824, 38.826978410993306, 35.46764598573957, 32.834772041865754, 34.82902315684727, 34.575803007398335, 35.23587492534092, 34.35697296687535, 35.93906388963972, 35.39096566608974, 38.68830973761422, 36.191898414066856, 35.5118156841823, 34.5010403905596, 36.38679885864258, 36.00623559951782, 36.41968815667288, 37.67323350906372, 43.40795700890677, 46.6015054157802, 47.546571595328196, 46.25699635914394, 49.51876217978341, 43.738663469042095, 49.589831829071045, 45.46574592590332, 44.419680731637136, 35.122914586748394, 36.050339290073936, 49.712019375392366, 48.1336144719805, 52.69390480858939, 48.51892335074288, 51.04161276136126, 48.75938660757882, 50.001578603472026, 47.092624936785015, 47.973924023764475, 35.74558782577515, 36.118845054081504, 34.467626503535676, 35.83294405255999, 36.22127192361014, 36.03059250967843, 36.22623988560268, 34.31698955808367, 34.44426665987287, 38.160486357552664, 42.12176554543631, 45.28426592690604, 44.881367683410645, 44.35014663423811, 40.27481624058315, 38.782728808266775, 37.37685809816633, 39.561656611306326, 44.21616104670933, 44.972444670540945, 47.89694840567452, 48.358708313533235, 44.270284039633616, 50.32691758019583, 49.13973099844796, 44.86035633087158, 39.226881980895996, 35.97316912242344, 35.86169917242867, 38.22064733505249, 38.18693814958845, 38.24977765764509, 38.53905895778111, 44.107824734279085, 50.623390265873496, 51.459376675742014, 53.567526136125835, 51.50630828312465, 49.872943128858296, 51.461047717503135, 56.92784867967878, 55.07601131711687, 41.31210238592965, 27.122506856918335, 11.551290699413844, 11.563902548381261, 15.391298634665352, 5.0881015573229105, 1.711375619683947, 0.4982482099107334, 0.4648537018469402, 12.499732834952217, 52.59908274241856, 50.12286983217512, 36.88239649363926, 47.419975417000906, 58.29679666246687, 62.20642294202532, 37.82068817956107, 5.836138537951878, 0.18757651400353226, 0.12942557436014923, 0.10651753323950938, 0.09522053586052996, 0.1926543443862881, 0.09440604278019496, 0.10016659474266426, 0.07625105125563485, 0.09073655932609524, 0.15479827858507633, 0.1606695471065385, 0.07981875445693731, 0.14910910172121866, 0.16383472297872814, 0.1321820550199066, 0.17410261343632424, 0.1696225181221962], [0.016072569248665656, 0.05480689176225236, 0.010863738350703247, 0.0533238245573427, 0.03943703203861203, 0.012362695149412113, 0.009288677064302777, 0.047052403579333, 0.027726932362254177, 0.049483279032366614, 0.00628979188955522, 0.04141130092154656, 0.021099731725241457, 0.026259527441912463, 0.063058199893151, 0.040829097519495657, 0.0243645928733583, 0.047233094062123976, 0.3708736704928534, 7.726527111870902, 33.535056659153526, 48.45873458044869, 37.24271617616926, 22.465838057654246, 29.309652124132427, 46.196578298296245, 37.79476792471749, 9.978948967797415, 0.22158737613686494, 0.020211610810032914, 1.2920101455279758, 1.3555184176989963, 7.9175843341009955, 10.801887529236929, 6.455152681895664, 12.545577917780195, 25.148709501538956, 44.79267045429775, 49.03246470860073, 49.31461020878383, 49.191026074545725, 46.022261892046245, 42.92666571480887, 35.23433937345232, 31.870337758745464, 31.985809871128627, 38.38122715268816, 46.1116053036281, 44.9033830506461, 44.84254462378365, 40.99526800428118, 40.98583582469395, 36.56964417866298, 35.493482862200054, 34.68602228164673, 37.591223921094624, 38.70184135437012, 39.99595029013497, 42.526081221444265, 45.708453450884136, 42.12825863701956, 40.67947585242135, 37.05894327163696, 30.993051256452286, 30.994090012141637, 32.0325608253479, 30.85806860242571, 30.513166972569056, 32.74395908628191, 31.52070787974766, 33.56028209413801, 31.75814519609724, 31.117455278124126, 32.758446080344065, 31.013385159628733, 31.807404450007848, 31.428616455623082, 31.841360296521867, 31.38799728666033, 34.48400340761457, 35.04453195844378, 39.38565526689802, 39.15763623373849, 41.57928146634783, 42.86074468067714, 43.05602380207607, 44.7242237499782, 43.94793626240322, 33.037680285317556, 31.450607504163468, 40.38937813895089, 45.12648623330252, 44.69099051611764, 44.891717025211875, 46.24086611611502, 44.68636996405465, 44.65670115607125, 42.95278746741158, 40.82430410385132, 32.49499818256923, 32.37156343460083, 31.490253925323486, 33.32553373064314, 32.73298788070679, 32.240968567984446, 32.867977482931956, 31.57610239301409, 33.104754720415386, 31.303423813411168, 32.86070966720581, 34.05458389009748, 32.55102498190743, 33.736526625497, 32.71696533475603, 33.59263290677752, 32.575381892068044, 35.3806163242885, 37.449664797101704, 41.817684582301546, 44.74486684799194, 46.25300809315273, 44.779906613486155, 45.81172105244228, 45.249775069100515, 41.12195450919015, 36.77042627334595, 38.24159267970494, 36.20361655099051, 33.872600146702354, 33.38960654394967, 34.43514714922224, 35.76358713422503, 35.34294319152832, 41.12804807935442, 46.15097379684448, 46.25441510336739, 48.98623834337507, 45.87978213174002, 47.76231663567679, 53.20058829443795, 46.89123140062605, 36.29315798623221, 20.737193993159703, 6.5892112255096436, 11.576153091021947, 8.225346105439321, 1.1215498809303557, 0.0795469129724162, 0.044165260823709626, 0.3815908596983978, 10.044757962226868, 40.63538605826241, 39.86601550238473, 20.35519766807556, 28.203615290778025, 42.94187184742519, 49.07028375353132, 25.413145780563354, 3.0092111783368245, 0.008647677754717214, 0.006716933924638267, 0.05051092031810965, 0.050902007546808035, 0.008394250862433441, 0.03796014289504715, 0.006056905524539096, 0.026047926296346953, 0.04428710196433323, 0.08659756356584174, 0.04417871956580451, 0.043097555437790494, 0.0697428961949689, 0.012275233681845878, 0.023942874877580574, 0.04663886362686753, 0.07473086139985494, 0.020542549302003214, 0.021122671297884414, 0.03236034266384585, 0.03428929897823504, 0.03356941742822528, 0.023347631728808795, 0.05810787302574941, 0.053393991863621135, 0.030633450685335056, 0.015667833288067153, 0.06031775301588433, 0.020341375543336784, 0.009713951431746994, 0.03470011121992554, 0.020173690880515745, 0.03509883536025882, 0.06380514481237956, 0.030114245867090564, 0.8157447874546051, 11.5382593529565, 40.23036166599819, 54.72723259244646, 41.15274545124599, 25.63295030593872, 26.673788717814855, 40.82190350123814, 39.575153487069265, 11.322835666792733, 0.11438971332141332, 0.06641911954752036, 1.3408402396099908, 1.7260534720761436, 9.492549879210335, 8.494613119534083, 10.309176002229963, 8.846743481499807, 29.398800986153738, 47.702596868787495, 49.313828536442344, 51.02248089654105, 51.34863976069859, 48.51795060294015, 45.21155650275094, 36.654710974012104, 33.84052726200649, 33.91675247464861, 39.71885960442679, 48.31045307431902, 45.42611687523978, 46.51614679609026, 42.91804647445679, 41.30025918143136, 40.17300081253052, 37.45096411023821, 37.85367127827236, 39.7032504762922, 40.80045441218785, 42.519032273973735, 45.13270834514073, 47.431165490831646, 45.13674872262137, 44.01574373245239, 38.64291020802089, 32.41315882546561, 32.6981600352696, 32.54975346156529, 31.692304066249303, 30.97639642442976, 34.092486313411165, 33.09914057595389, 34.147797448294504, 33.54725769587925, 32.831951073237825, 34.20185443333217, 33.48989684241158, 34.79260069983346, 33.74222762244088, 33.18651417323521, 32.93901933942522, 36.47326224190848, 38.80120406832014, 41.438962595803396, 40.95372472490583, 44.34286492211478, 44.227594307490754, 45.003520488739014, 45.76673494066511, 43.96597031184605, 34.66414587838309, 34.42692048209054, 41.89363881519863, 43.679513454437256, 46.20426648003714, 46.11011838912964, 47.789147104535786, 45.93850135803223, 46.363769326891216, 45.814837319510325, 42.06788921356201, 33.77014895847866, 34.314311027526855, 33.56977333341326, 34.22262259892055, 33.25245605196272, 34.18736743927002, 34.37272800718035, 33.676504611968994, 33.908894062042236, 33.73012733459473, 35.101041657584055, 35.23818867547171, 35.980607169015066, 35.833524227142334, 33.12659290858677, 36.10876669202532, 34.496180125645225, 37.00010592596871, 39.26621573311942, 44.131056036267964, 48.073731422424316, 47.747041021074565, 43.83484738213675, 48.437351499285015, 47.388486180986675, 42.58435923712594, 37.77523306437901, 38.56062616620745, 36.87416982650757, 35.55518633978707, 35.552104813711985, 37.10338742392403, 36.545523507254465, 38.34085464477539, 43.29804345539638, 48.662358488355366, 48.939713205610005, 51.50915357044765, 46.3364177431379, 48.989594323294504, 53.52871697289603, 50.06071819577898, 36.700853960854666, 21.887298039027623, 6.943617122513907, 8.75909890447344, 13.912622094154358, 5.088792034557887, 0.21313094347715378, 0.11849817500582763, 0.40033259402428356, 10.478241307394844, 48.001122747148784, 42.664895806993755, 22.87071827479771, 32.83874293736049, 48.68774373190743, 55.400825704847065, 31.220517907823833, 3.705024412700108, 0.022263819617884498, 0.021269716621775712, 0.01941219138513718, 0.04548621244196381, 0.09583793487399817, 0.09428612528634922, 0.03236810849713428, 0.03262273554823228, 0.07823373736547572, 0.10656548530927726, 0.007855224339956684, 0.03789105445944837, 0.047917885173644335, 0.04677565289395196, 0.08309694712183305, 0.03755302866920829, 0.018349620812971677, 0.0649277199325817, 0.165425643324852, 0.07247311754950456, 0.13472477000738892, 0.23769944799797876, 0.12482071002679211, 0.11024953691022736, 0.10286394786089659, 0.15758640611810343, 0.14084408379026822, 0.17618461671684468, 0.09746740279453141, 0.1304451817912715, 0.08782803253935915, 0.17429142259061337, 0.1057638708235962, 0.10207514411636762, 0.19203653825180872, 1.229446176971708, 13.659183076449803, 46.23229203905378, 60.14523983001709, 48.76023081370762, 33.23908076967512, 37.08766712461199, 54.366013118198936, 46.54511383601597, 13.394803251538958, 0.4341232036905629, 0.14601920252399786, 2.3775487073830197, 4.174109893185752, 13.195577553340367, 22.11002949305943, 13.563547202519008, 15.730822358812604, 29.85340772356306, 49.08040033067976, 51.54507228306362, 52.26277256011963, 53.742735385894775, 50.29967369352068, 46.775182587759836, 38.674621786390034, 35.86770241601126, 36.25267430714199, 42.23172426223755, 50.75306102207729, 45.51946939740862, 48.05615247998919, 44.94085815974644, 45.17289672579084, 40.65081105913435, 39.86139495032174, 38.97053166798183, 42.34517444883074, 43.23073625564575, 44.10299573625837, 45.86369705200195, 50.9804026058742, 46.469242981501985, 45.32894284384591, 40.923781463078086, 34.18202427455357, 34.44723006657192, 34.75746018545968, 33.08010598591396, 32.53444658006941, 36.43571765082223, 35.70791121891567, 37.0061091695513, 34.50074161802019, 34.0202875818525, 35.77743836811611, 34.918328353336875, 35.678905963897705, 35.80568626948765, 35.01482146126883, 34.94100032533918, 38.328003951481406, 39.352199690682546, 42.77897480555943, 42.22620044435774, 46.463472502572195, 45.45969751902989, 46.912923676627024, 48.08602973393032, 46.265709400177, 37.92482778004238, 38.7307562828064, 42.81175293241228, 46.39854506083897, 47.30504526410784, 47.744588306971956, 50.13930927004133, 47.9142598424639, 48.61970002310616, 47.768462317330496, 45.178232942308696, 36.019134930201936, 36.01711647851126, 34.893811634608674, 36.2656500680106, 35.12976898465838, 35.39201831817627, 35.694817338671, 34.2001382282802, 36.67666033336094, 34.920739378247944, 36.793122564043315, 35.678287574223106, 36.586573464529856, 37.441552775246755, 35.78213882446289, 37.819701535361155, 36.91743278503418, 38.47274187632969, 40.98858731133597, 46.61224733080183, 50.26303584235055, 49.252260548727854, 44.55602175848824, 48.64675978251866, 50.838662828717915, 44.43322971888951, 41.146728311266216, 42.05155052457537, 39.054639611925396, 37.45786019733974, 37.791464056287495, 37.833789008004324, 39.215337548937114, 38.53178766795567, 46.74965143203735, 51.25326183864048, 50.9571921484811, 53.069677284785676, 48.788360595703125, 49.68761035374233, 56.06694950376238, 50.66399901253836, 39.56254598072597, 21.86837809426444, 8.570239050047737, 19.707870483398438, 17.557807752064296, 3.8686623062406267, 0.7379648610949516, 0.3242088630795479, 0.666571089199611, 13.68179338318961, 51.3041330746242, 49.740291595458984, 28.616854190826416, 40.43364858627319, 55.345458984375, 61.73938587733677, 37.415097509111675, 4.735509140150888, 0.06304387601890735, 0.07504132509763752, 0.17568673486156122, 0.11857874425394194, 0.14946462692958967, 0.19405953612710747, 0.11373277607240848, 0.16494405988071645, 0.1419680499072586, 0.2620060922844069, 0.11155720281281642, 0.15200726049286978, 0.2622092456689903, 0.15432646604520933, 0.11950744156326566, 0.15443884501499788, 0.11187778346772705], [0.03272121812083891, 0.06544634460338525, 0.06991763931832143, 0.03760796964966825, 0.05733069258608988, 0.008038410983447517, 0.0258587880525738, 0.057620929154966555, 0.0292893406668944, 0.04788957329999123, 0.014588877791538835, 0.0489456112762647, 0.059452776930161884, 0.045568420352148156, 0.030165193668965782, 0.06550026099596705, 0.030218278856149743, 0.07987645707492318, 0.16379196170185292, 9.061423710414342, 32.77427060263497, 45.20074510574341, 39.77256223133632, 29.872303349631174, 38.67927360534668, 51.91696419034685, 40.89426898956299, 13.211231844765798, 0.36890570180756704, 0.1324359628238848, 1.8605636485985346, 1.9711909123829432, 8.117973855563573, 3.6195068529673984, 8.217208896364484, 9.579530903271266, 23.33140642302377, 42.10495090484619, 50.31243406023298, 46.258764675685335, 42.952936853681294, 40.40469544274466, 36.548549447740825, 31.785093784332275, 32.612957750047954, 33.15251316343035, 41.016136918749126, 44.46502467564174, 44.22716004507882, 43.73588766370501, 42.58211496898106, 36.803447587149485, 35.74118266786848, 32.34604270117623, 32.26249408721924, 32.971307618277415, 35.41944285801479, 38.95121914999825, 40.72838074820382, 43.75691638674055, 42.35737895965576, 40.814858027866904, 33.23985549381801, 31.52223300933838, 30.98420967374529, 31.305299827030726, 34.46784537179129, 32.45129748753139, 31.904001780918666, 31.49242523738316, 33.54340839385986, 32.19199766431536, 31.9630024092538, 32.01733037403652, 30.913379737309047, 31.158609458378383, 32.15466151918684, 30.823984214237758, 32.13294492449079, 31.735553128378733, 31.58967569896153, 33.984577315194265, 35.19083322797503, 38.77023594720023, 41.91173539842878, 40.649296351841514, 45.95971768242972, 43.565695013318745, 33.048380511147634, 33.271817207336426, 45.480215549468994, 45.05797699519566, 45.1278862953186, 42.10651077542986, 45.722224780491416, 41.83611815316336, 42.929629121507915, 40.70204707554409, 35.000136443546836, 32.947416237422395, 34.06266464505877, 32.75476353509085, 33.367573806217735, 30.985943249293737, 34.043643951416016, 33.5018755367824, 32.32106045314244, 32.514970779418945, 33.039181096213206, 33.536387239183696, 32.762416975838796, 32.887460231781006, 32.63758563995361, 33.09671565464565, 34.06089285441807, 32.192560468401226, 35.34677512305123, 38.331964424678254, 42.648174967084614, 44.640310355595176, 45.41803959437779, 41.976805278233115, 44.100511755262104, 45.144092968532014, 43.04002210072109, 43.078056539808, 43.24274969100952, 41.70774323599679, 46.23010335649763, 41.12837464468819, 35.510078634534565, 33.97291128976004, 36.153370652879985, 35.05185883385794, 44.61507102421352, 44.199339457920615, 49.331820896693635, 49.14496994018555, 49.3580572945731, 49.31664603097098, 48.56999955858503, 31.954230308532715, 18.400961228779384, 4.599993646144867, 10.433634740965706, 13.354621819087438, 6.726265745503562, 0.5581387504935265, 0.07445733714848757, 0.41907777530806406, 11.006588407925197, 38.502132756369456, 46.29397119794573, 35.29827322278704, 33.42599425997053, 46.66090209143502, 47.94732631955828, 23.23661388669695, 1.737058441553797, 0.044666789804718325, 0.07376193374927555, 0.017500159430450628, 0.011380287552518504, 0.05049587380407112, 0.01988143058094595, 0.09932983214301722, 0.038166220765560865, 0.04212433605321816, 0.05918298462139709, 0.045736808995051045, 0.008980816396485482, 0.056734976159142594, 0.05672835705003568, 0.02023615681433252, 0.018119069880672863, 0.04144813858770898, 0.07496631305132594, 0.026341031372014965, 0.03419944058571543, 0.08597954708550658, 0.027892567849318897, 0.06832312952194895, 0.01370476617012173, 0.07686874203916107, 0.028869313919650655, 0.01997787076314645, 0.04125720222613641, 0.060516061660434516, 0.054668331518769264, 0.07710141169705562, 0.028855685543801104, 0.0630943997363959, 0.004786349550288702, 0.03448113100603223, 0.3244981904114996, 10.312419942447118, 38.72625037602016, 50.83243029458182, 43.91122892924717, 32.02946192877633, 39.41500793184553, 54.15951613017491, 43.60879468917847, 15.533821821212769, 0.5781320833734104, 0.02302578730242593, 0.20067487257931912, 1.0505087843963077, 10.917004414967128, 5.378603569098881, 6.337234369346073, 10.745335272380284, 24.829660381589616, 45.564587524959016, 51.027497495923726, 48.892420291900635, 44.9182139805385, 44.04843153272356, 37.942969526563374, 35.15979215076992, 34.151827403477256, 34.65004103524344, 42.024390016283306, 46.72782366616385, 45.190941197531565, 45.73797287259783, 43.948790890829905, 38.725197723933626, 37.60505778448922, 34.20211846487862, 33.23821224485125, 35.69454288482666, 38.63700771331787, 39.91286720548357, 42.93420451028006, 45.897889137268066, 45.57391548156738, 42.70663363592965, 33.91423722675869, 33.00770575659615, 32.65968091147286, 33.05098955971854, 35.06146819250924, 33.37887505122593, 34.48537915093558, 33.63180685043335, 34.563049588884624, 34.263106278010774, 33.55968107495989, 33.75459541593279, 32.977112838200156, 32.23255777359009, 33.34629494803292, 33.21054451806204, 33.82589088167463, 33.97827182497297, 34.19482980455671, 34.85325499943325, 38.41990777424404, 40.320431164332796, 44.52095420019967, 43.682212829589844, 47.99802385057722, 44.909518310001914, 34.40167767660958, 35.90439932686942, 46.96321473802839, 45.099398681095664, 47.24623223713466, 44.55720295224871, 45.48950529098511, 44.19760588237217, 45.15081187656948, 44.00907693590437, 38.09455837522234, 35.15057536533901, 34.23346873692104, 34.10195670809065, 35.530537605285645, 32.996981212071006, 34.01769937787737, 34.26929712295532, 35.07697657176426, 34.2813001360212, 34.14900990894863, 35.06584555762154, 34.12084191186087, 34.401854855673655, 34.07415696552822, 34.37179000037057, 35.58164855412075, 33.57345240456717, 36.525894846235005, 40.67531735556466, 44.81469624383109, 46.07441854476929, 45.874185357775005, 41.98706429345267, 45.51864603587559, 47.907791069575715, 46.06981883730207, 46.137984139578684, 45.66250501360212, 43.75918844767979, 47.58582196916853, 41.64535883494786, 37.86775875091553, 35.33598804473877, 37.5870098386492, 36.44322517939976, 47.29390730176653, 46.560406821114675, 52.13009670802525, 51.213525090898784, 49.59681476865496, 50.209885597229004, 51.04833514349801, 33.894365378788535, 18.332085473196848, 5.687493988445826, 9.60315912110465, 13.465822526386805, 4.705813407897949, 0.8377482667565346, 0.00033551256014366766, 0.45740523295743124, 12.121281828199114, 43.98721790313721, 48.780060972486226, 34.36539765766689, 37.09293385914394, 52.34418460300991, 53.70409297943115, 28.856370755604335, 2.7076925805636813, 0.01678193689856146, 0.03267510827364666, 0.04626038018614054, 0.02080435355726097, 0.02213713034455265, 0.01870742080999272, 0.060454457466091426, 0.06509703477578503, 0.07114179791616541, 0.04395774106628128, 0.06802324418510709, 0.01859577974703695, 0.06623147747346333, 0.044456773038421354, 0.0499076009062784, 0.03303860626848681, 0.07992375775107316, 0.16902008759123938, 0.09186227606343371, 0.15768330091876642, 0.20401882885822228, 0.11278459802269936, 0.10636255584125008, 0.1265273205935955, 0.18290614389947482, 0.08927869291177817, 0.08058821316808462, 0.0902892690418022, 0.22670521294432028, 0.20271266251802444, 0.14097067128334725, 0.23121601875339234, 0.11333839794886963, 0.08185852571789708, 0.21822883135506085, 0.491173369543893, 13.534063390323094, 43.87743983949934, 56.67547968455723, 50.995560101100374, 39.0210520199367, 46.604798861912315, 59.70944881439209, 49.73438910075596, 17.62838407925197, 0.782125820006643, 0.29522095141666277, 2.7315796187945773, 5.791326131139483, 13.125861065728323, 9.373538528169904, 13.188685808862958, 12.675447566168648, 26.997540031160625, 46.2740854535784, 53.98523793901716, 50.78038133893694, 46.71649810246059, 46.01237460545131, 40.14105646950858, 36.4668664251055, 35.84827525275094, 36.01025513240269, 45.49771111352103, 49.16718680518014, 46.6696047101702, 45.65291997364589, 46.29932478496006, 40.02527516228812, 40.42873968396868, 36.120408398764475, 34.88530009133475, 36.52442530223301, 40.998599665505544, 42.20671074731009, 45.35092347008841, 48.71676983152117, 47.21195329938616, 45.24341746738979, 36.4906188419887, 34.232561997004915, 34.390216623033794, 34.73971101215908, 38.14299079350063, 35.959227561950684, 35.58243022646223, 34.761361598968506, 37.444175720214844, 35.37882716315133, 34.44137273515974, 35.92125218255179, 35.6032782963344, 33.8818655695234, 36.68554013116019, 33.36005238124302, 36.874079499925884, 35.45059858049665, 35.791935784476145, 35.43000759397234, 40.001922266823904, 42.421788760593955, 46.03542872837612, 44.54836484364101, 50.600245816367014, 45.636445794786724, 37.284738881247385, 39.02623537608555, 48.44553647722517, 47.050213132585796, 49.33470439910889, 46.61830963407244, 49.26322133200509, 46.84968812125069, 47.18820088250296, 47.00911453792027, 39.32895449229649, 36.75065170015608, 36.302527632032124, 35.776507309504915, 36.68527957371303, 33.990570136478965, 36.09916428157261, 36.58151170185634, 36.91302415302822, 36.906555380140034, 36.91929142815726, 36.869028159550254, 36.12253107343401, 36.41548449652535, 35.862192494528635, 37.07714407784598, 38.07967185974121, 33.93874699728829, 39.14995847429548, 42.26097617830549, 47.474247796194895, 49.166954040527344, 47.18639782496861, 41.37112385886056, 45.37243161882673, 49.34878144945417, 48.06645665849958, 48.41039596285139, 48.90099784306118, 47.164517947605674, 50.34749467032296, 44.623117038181846, 40.93357147489275, 37.67751359939575, 39.122547830854145, 38.25873735972813, 49.4139347076416, 48.616239820207866, 53.831898144313264, 52.89106341770717, 50.115139961242676, 50.495706694466726, 52.41435098648071, 36.118494170052664, 21.491704089300974, 8.156783018793378, 16.443552936826432, 19.399483374186925, 10.076858639717102, 1.157022931746074, 0.153661651004638, 0.8511910225663866, 14.706496340887886, 50.35509947368077, 55.34230102811541, 47.10656302315848, 44.156448228018625, 58.734692982264924, 61.434610094342915, 34.406527519226074, 3.575028176818575, 0.10079227866871016, 0.17065999816570962, 0.1383349969983101, 0.12408068616475378, 0.10760135043944631, 0.11065612187875168, 0.14961493600692066, 0.15960637772721903, 0.1588882298341819, 0.11878191120922565, 0.19010065070220403, 0.07048000235642705, 0.11908159298556191, 0.1937749721109867, 0.12138226096119199, 0.1780072839132377, 0.17016985160963877], [0.031546609542731724, 0.08468511261578117, 0.020810448498065983, 0.01422366819211415, 0.05238902721820133, 0.06700029157634292, 0.08589017723820039, 0.04322297924331256, 0.056100006481366496, 0.025031228084117174, 0.039039624256214926, 0.03730621494885002, 0.01187563592767609, 0.05205382074096373, 0.026890237616108995, 0.03678173112816044, 0.01566483416328473, 0.01097443709815187, 0.13337126906429017, 6.74236124753952, 29.436630453382218, 48.04045302527291, 42.54255887440273, 32.18100561414446, 27.60385721070426, 28.215276105063303, 37.98556545802525, 17.119372946875437, 1.2673577197960444, 0.0852524968130248, 0.6161187535950116, 0.9696504260812486, 11.880187153816223, 4.4577609811510355, 11.106145671435765, 6.214008067335401, 20.591728244509014, 42.825312341962544, 45.859719208308626, 43.58069269997733, 41.07218108858381, 36.69826923097883, 34.08748361042568, 36.245399543217246, 33.603642327444895, 36.61247287477766, 42.36151661191668, 47.10889414378575, 46.0289808000837, 43.76230124064854, 41.50271579197475, 39.639271463666645, 35.01699277332851, 30.28830589566912, 31.77090208871024, 31.451840809413365, 33.06311069216047, 35.10373408453805, 38.355254786355154, 38.33929130009243, 37.48644856044224, 33.23501607349941, 31.303774697440012, 29.241313116891043, 31.60565308162144, 32.36311789921352, 33.904982226235525, 32.82270996911185, 31.848280702318462, 33.089781352451865, 33.42333657400948, 32.385640484946116, 31.76486757823399, 31.203317642211914, 31.934007576533727, 32.40208339691162, 31.126185689653667, 31.26835972922189, 30.176141125815256, 30.852541310446604, 30.66101769038609, 31.833345549447195, 31.002532073429652, 33.71644285746983, 37.87163584572928, 40.94404935836792, 40.760193075452534, 43.47601808820452, 32.14465263911656, 37.423355443137034, 44.29358829770769, 42.62583303451538, 42.04379633494786, 41.73764828273228, 40.56728328977312, 38.410291467394146, 37.61865540913173, 35.80903877530779, 33.75664166041783, 33.514170374189106, 33.068985394069124, 32.11092260905674, 32.660973276410786, 31.398190293993267, 31.93920135498047, 33.4238646371024, 32.73370007106236, 33.05084364754813, 33.62500803811209, 33.59598193849836, 32.399721009390696, 34.75650828225272, 33.45439154761178, 32.23581995282854, 33.085365772247314, 33.66377898624965, 39.098072801317485, 40.885896410260884, 43.379646573747905, 42.886341844286235, 43.67252009255545, 43.24483067648751, 42.54635259083339, 45.64896297454834, 48.57702071326119, 45.69230236325945, 46.36597885404314, 48.347156933375764, 49.131667613983154, 47.61049154826573, 43.85090119498116, 35.47405569893973, 33.2498539515904, 33.90296030044556, 38.25011464527675, 45.56627593721662, 46.86512007032122, 48.93705204554966, 48.40397930145264, 45.09097399030413, 43.8370395387922, 27.21297935077122, 13.622714587620326, 3.2029666900634766, 7.29104094845908, 12.882937278066363, 5.8656562226159235, 0.35113215552909033, 0.0358844228487994, 0.43657732914601055, 10.368429371288844, 39.4339382989066, 33.19660643168858, 27.102037463869365, 35.9366910798209, 47.199668884277344, 48.045851775578086, 23.26805795942034, 2.187143747295652, 0.0476523812061974, 0.02409220177547208, 0.06343942800802843, 0.049174640593784194, 0.014355351483183247, 0.04617209938753929, 0.03383851423859596, 0.0393814193084836, 0.050009452405252626, 0.04977949349475758, 0.015621262037062218, 0.012177607759700289, 0.08788296673446894, 0.03779525549284049, 0.041754765169961114, 0.04357313045433589, 0.04802483247060861, 0.01744190719909966, 0.07619091269693204, 0.0593782195023128, 0.04644699767231941, 0.02029768467348601, 0.030897512765867368, 0.03244563451568995, 0.03255872594724808, 0.03849741370816316, 0.032526254653930664, 0.020605424053168724, 0.02139021595939994, 0.03453748333933098, 0.023092785850167274, 0.024964709599901522, 0.019244913843327334, 0.04591677344537207, 0.04463131260126829, 0.13166529632040433, 9.387725012642996, 34.86633150918143, 54.0073366846357, 47.16142947333199, 36.11726781300136, 33.09964779445103, 38.95001711164202, 44.93651900972639, 19.159767048699514, 1.2252138555049896, 0.032683077667440684, 0.7021951004862785, 3.1076241603919437, 9.850358656474523, 6.4511600732803345, 2.9692588193075995, 8.064308575221471, 24.3725905077798, 43.15848888669695, 50.20736340114048, 45.258967535836355, 43.80955593926566, 38.23110089983259, 35.89927155630929, 36.15485756737845, 36.00635371889387, 37.441577093941824, 44.09243794849941, 48.03742013658796, 44.979632581983296, 44.632764611925396, 43.54801532200405, 40.373136724744526, 36.47854287283761, 32.57528461728777, 33.87817260197231, 33.13885300500052, 35.285485063280376, 36.6407207761492, 40.39073651177542, 40.0870099067688, 39.846987860543386, 36.06367983136858, 32.29977464675903, 31.85293252127511, 32.98612812587193, 33.84702035358974, 36.53532702582223, 34.750821181706016, 33.72025741849627, 34.83758333751133, 35.909158842904226, 34.34753383908953, 32.21595505305699, 33.43188285827637, 33.62370525087629, 33.910624163491384, 34.06628465652466, 32.54002250943865, 32.69340399333409, 33.41306366239275, 32.48808472497122, 32.97505964551653, 33.14830950328282, 34.67364753995623, 42.24281358718872, 43.25126470838274, 43.21392508915493, 44.038981982639854, 33.822336878095356, 38.40797771726336, 47.160515785217285, 44.51432909284319, 43.806870460510254, 43.73222943714687, 42.3907789502825, 40.15447691508702, 39.7784160886492, 38.50775384902954, 34.880401611328125, 33.78458384105137, 34.602685587746755, 33.79025704520089, 34.18445266996111, 33.83394384384155, 33.634683404650005, 35.33518205370222, 34.33523552758353, 34.86334030968802, 34.91068186078753, 34.54998002733503, 35.018959113529746, 36.750443254198345, 35.11839130946568, 33.54670531409127, 34.78723669052124, 35.04965278080532, 40.11484439032418, 42.95421184812273, 45.59036534173148, 45.13869769232613, 43.634697573525564, 44.354972158159526, 42.9440153666905, 46.166770526341026, 49.41227756227766, 47.95766176496233, 48.62016902651106, 49.59196145193917, 51.52345643724714, 49.72145502907889, 45.126514026096885, 36.494384765625, 35.94248240334647, 35.13518510546003, 40.861397062029155, 47.38287551062447, 48.99114377158028, 50.5600574357169, 48.94472285679409, 48.58887781415667, 46.0271430015564, 29.377643721444265, 19.231637477874756, 5.68633450780596, 10.650399429457527, 11.39089240346636, 3.9727428470339095, 0.7061479198081153, 0.014157417729230863, 0.37541306976761135, 12.865709219660078, 45.86402709143502, 39.78972428185599, 32.03834172657558, 39.95513309751238, 53.02736970356533, 54.32142652784075, 28.23532165799822, 2.995982676744461, 0.0634519944765738, 0.01577792559484286, 0.042290346430880685, 0.06611050825033869, 0.04624519796509828, 0.019747296082121984, 0.08462650076087032, 0.012344398452634258, 0.012870931449080152, 0.012899321354260402, 0.05965698882937431, 0.00881704009537186, 0.038574139055396826, 0.033315414629344425, 0.036512132201875956, 0.0186889069820089, 0.04437441245785781, 0.07653488245393548, 0.18039263305919512, 0.12908448837697506, 0.12882264171327862, 0.10500619148037263, 0.10719826671161822, 0.1448528686804431, 0.126452274620533, 0.15493633331997053, 0.13045105790453299, 0.16429949232510158, 0.10527392782803092, 0.1274169071444443, 0.1972151446555342, 0.11042319437755005, 0.07084198721817561, 0.06964632709111486, 0.12728575989603996, 0.307212945073843, 10.484213284083776, 41.329156739371165, 60.891483306884766, 53.6207389150347, 42.45861073902675, 39.1434063230242, 38.3204790524074, 46.83614955629621, 22.098005635397776, 1.7741874435118266, 0.3477709916021143, 2.4303209270749773, 3.1075833397252217, 19.61453706877572, 12.936425379344396, 18.62240900312151, 8.800111515181404, 23.229177577154978, 46.08957256589617, 51.74633380344936, 48.28236845561436, 45.45713710784912, 40.249403204236714, 37.58357048034668, 39.00359467097691, 37.89258119038173, 40.87593616758074, 46.704185894557405, 51.48976114818028, 45.08832672664097, 45.788896220070974, 46.46167639323643, 43.63460029874529, 38.22215509414673, 33.83135911396572, 35.03571122033255, 34.68443809236799, 36.41795458112444, 39.07388612202236, 42.12495476858956, 41.670285497392925, 41.06729303087507, 36.80047723225185, 34.33068445750645, 33.153836795261924, 34.673258440835134, 35.23680945805141, 37.57806750706264, 36.49594463620867, 36.12811395100185, 37.21495812279837, 38.017933641161235, 37.27120379039219, 34.37070608139038, 34.289554595947266, 36.23869105747768, 36.33012935093471, 36.187844140189036, 34.903587750026155, 34.56447049549648, 34.76903588431222, 34.02757624217442, 33.8591935975211, 33.270802770342144, 36.81005532400948, 43.031920501164024, 44.01456601279122, 45.116275855473106, 46.28126989092146, 35.542749064309255, 42.06141349247524, 46.588720730372835, 47.7653078351702, 44.13199404307774, 45.67580039160592, 44.08308219909668, 42.00639418193272, 41.76881095341274, 40.09479883738926, 37.2741949898856, 36.59822906766619, 35.41109459740775, 35.46701717376709, 36.444232668195454, 35.956972871507915, 35.34645898001534, 37.58477946690151, 36.45064238139561, 36.5225944519043, 37.61637987409319, 36.38163982118879, 35.86829996109009, 38.05294213976179, 37.08254977634975, 36.300811426980154, 34.97247913905552, 36.88019044058663, 42.998711585998535, 44.9428106035505, 47.943671567099436, 47.53746945517403, 45.705281598227366, 44.56299427577427, 42.31575925009591, 47.73997122900826, 52.47555071966988, 48.77718441826956, 50.5721229825701, 51.6702093396868, 53.5876133782523, 51.894028186798096, 47.89339440209525, 39.4701384135655, 37.59502458572388, 38.24937118802752, 42.95041813169207, 49.96961688995361, 51.604451588221956, 52.183611733572825, 51.953779220581055, 50.662185532706125, 46.36652428763253, 30.21300826753889, 16.38952895573207, 6.771097259862082, 14.973453078951154, 19.379569837025233, 10.794749992234365, 1.315535551735333, 0.1807180448834385, 0.6889762069497789, 14.748281070164271, 51.236884934561594, 44.20391832079206, 37.25702946526663, 49.26843248094831, 59.46217632293701, 60.847035680498394, 34.94338355745588, 4.649905596460615, 0.15713832873318875, 0.10604217874684504, 0.09838136910860028, 0.1049981236990009, 0.11042822232203824, 0.09803859357322965, 0.18919944763183594, 0.09371393027582339, 0.20210322950567516, 0.11932902756546225, 0.10094239097088575, 0.06791414253945861, 0.14067944405334337, 0.11329223042620079, 0.18411795315997942, 0.06943820683019501, 0.16699787681656225], [0.027376279035317044, 0.08227952955556767, 0.03838534686448319, 0.07306963125509874, 0.06301634106785059, 0.027460264707250253, 0.01746103510127536, 0.057514209167233536, 0.054957892945302386, 0.04085386744035142, 0.024972373652937155, 0.024416500802284906, 0.011333287976283048, 0.008115371273431395, 0.037976020614483526, 0.007888759236915835, 0.0170720665981727, 0.031565038553838215, 0.05575884585934026, 4.162144226687295, 24.268683671951294, 49.42799091339111, 42.7085200718471, 29.950845786503383, 21.397712332861765, 31.18286909375872, 36.64601182937622, 25.75343554360526, 2.0719810468809943, 0.15940010308154992, 0.23200355363743647, 1.6938166533197676, 7.605144688061305, 3.349811439003263, 0.8560053099478994, 9.273159640175955, 19.2137736592974, 36.53741148539952, 47.33590568814959, 43.773366246904644, 40.53817728587559, 37.71579817363194, 33.57014158793858, 33.959014892578125, 31.174517359052384, 37.30612196241106, 44.47419629778181, 46.41696473530361, 41.99213300432478, 44.13400207247053, 42.693067278180806, 40.09016786302839, 36.55815880639212, 32.08197293962751, 30.965706620897564, 29.74953215462821, 31.316885948181152, 32.70297513689314, 33.5424599647522, 32.689106532505576, 32.22818388257708, 31.62472936085292, 31.22533300944737, 30.183315140860422, 31.186364037649973, 32.58644689832415, 30.45997851235526, 33.09250157220023, 34.16552577699934, 33.47311346871512, 36.34730529785156, 36.11346020017351, 33.50919893809727, 32.2307060786656, 30.634027412959508, 32.24586704799107, 32.738473483494346, 32.816105706351145, 31.075998851231166, 30.58019277027675, 28.8287672996521, 31.415863037109375, 32.74892010007586, 35.769784927368164, 36.053476401737754, 42.377250807625906, 42.52857909883772, 45.15472023827689, 35.99731411252703, 36.018429688044954, 47.89562477384295, 42.990995611463276, 42.300862312316895, 37.37897035053798, 37.55076803479876, 34.446007183619905, 33.54850837162563, 32.322912148066926, 33.640068258558, 33.44174582617623, 33.47229010718209, 32.1477758543832, 33.0029080254691, 31.359554835728236, 32.80101074491228, 31.95069020135062, 35.51011684962681, 34.065714904240195, 33.960050174168174, 33.36485358646938, 32.166647161756245, 32.04740912573678, 31.882104533059255, 31.972507544926234, 32.23737287521362, 33.377957889011924, 36.223637785230366, 41.537411621638704, 45.16771684374128, 42.111565589904785, 43.395630904606406, 44.81543622698103, 45.50363097872053, 45.52512870516096, 44.98966925484793, 48.21417188644409, 47.1676515851702, 48.82756928035191, 43.32522133418492, 47.858966078077046, 46.661652496882844, 41.098799637385774, 33.88587815420968, 34.76009007862636, 35.455907004220144, 42.504670347486226, 46.76086235046387, 47.00819737570626, 49.45795849391392, 47.36302103315081, 45.464641162327354, 24.016576971326554, 10.267386930329458, 3.2181382988180434, 8.129176088741847, 10.566763963018145, 2.266868680715561, 0.5466408931783268, 0.08365100489131042, 0.7158257833548954, 10.221622620310102, 38.27499614443098, 39.327234813145225, 21.611517088753835, 35.10402590887887, 50.898413862500874, 48.10039513451712, 23.68315029144287, 3.316091396978923, 0.02497317093158407, 0.04056747477235539, 0.07729259572391, 0.028903237277907983, 0.026260545244440436, 0.07304566539824009, 0.03768459660932422, 0.04350466287827917, 0.08730422386101314, 0.020616982897211398, 0.059091049911720414, 0.01901309913955629, 0.035543099378368685, 0.04001304041594267, 0.05773655830749443, 0.019192620845777646, 0.03651456135724272, 0.035037580611450334, 0.046117056626826525, 0.049144917367292304, 0.022543065615796616, 0.02177856699563563, 0.03693255589210561, 0.054607287115816555, 0.040949758009186814, 0.0315400447164263, 0.026308721230764474, 0.033493346867284605, 0.03166167211851903, 0.04036950200263943, 0.07419502229562827, 0.02334738745620208, 0.0820495808230979, 0.04618271506790604, 0.05410252830811909, 0.07413212209939957, 4.8590772066797525, 30.138374192374094, 53.87980249949864, 47.44202552522932, 34.77992023740496, 28.939926317759923, 35.802705492292134, 39.871143272944856, 26.68184862818037, 2.204464303595679, 0.14874960029763834, 0.16788145154714584, 2.966259151697159, 6.173586487770081, 6.167835984911237, 3.5325751176902225, 9.28880785192762, 16.708767414093018, 40.45611558641706, 48.75697905676705, 45.9763308252607, 41.152061053684776, 40.07198442731585, 35.636039052690776, 35.66247347423008, 32.944921834128245, 39.46018859318325, 46.381049496786936, 48.257931641169954, 42.96278592518398, 44.78043467657906, 43.65449299131121, 41.7513883454459, 37.742395877838135, 33.62663739068167, 33.688948835645405, 30.991748469216482, 31.97210454940796, 34.791836397988455, 34.63359464917864, 34.482127393995015, 34.547298022678916, 33.97795915603638, 31.512133802686417, 31.336479868207658, 31.1404572895595, 34.00441094807216, 32.5830249105181, 35.39557926995413, 35.69558164051601, 35.59049013682774, 38.40865169252668, 37.510419845581055, 34.853397437504356, 33.94034855706351, 32.53928600038801, 33.91020032337734, 33.20588575090681, 34.631385122026714, 33.21582514899117, 31.871220179966517, 31.032520498548234, 33.182452951158794, 34.532077993665425, 36.54249061856951, 37.96196590151106, 43.75337280545916, 44.87368644986834, 46.53562607084002, 37.69017321722848, 38.689987727573936, 49.95975044795445, 45.27627549852644, 43.913219588143484, 40.078901359013145, 39.445840563092915, 37.40795823505947, 34.73153993061611, 34.187575885227744, 35.95694507871355, 34.79851014273507, 35.74622706004551, 33.31765447344099, 34.21487883159092, 33.29995046343122, 34.47561345781599, 34.31788240160261, 36.40140744618007, 35.339389187949045, 35.85095378330776, 35.01265014920916, 34.73087637765067, 32.76641913822719, 33.32390785217285, 33.694417067936485, 34.16133253914969, 34.594333853040425, 38.78757865088326, 42.99084275109427, 47.67736448560442, 43.93467909949166, 43.55746487208775, 45.201471192496165, 46.3009089742388, 45.37834453582764, 46.12649529320853, 47.80192484174456, 47.80610418319702, 48.58245767865862, 45.64100728716169, 49.92640604291643, 49.27146884373256, 42.939988885607036, 35.62365388870239, 37.17182718004499, 38.05693735395159, 45.46546104976109, 48.9267270224435, 48.958216258457725, 52.577400888715474, 49.98672335488455, 45.69331680025373, 25.97589601789202, 14.073976635932922, 6.871338486671448, 14.038640703473773, 10.055137702396937, 5.011362612247467, 0.8184887287872178, 0.05095361692032643, 0.8844210537416595, 11.705113393919808, 44.19657754898071, 39.36527272633144, 26.85722463471549, 43.809719221932546, 54.751596450805664, 55.33580446243286, 27.245274577822002, 3.8412694675581793, 0.04285689942272646, 0.021796034183353186, 0.0226808065282447, 0.060059896138097556, 0.05162132591275232, 0.0506664744711348, 0.017298083220209395, 0.04464257288990276, 0.054880064978663406, 0.05265894505594458, 0.002890131278296134, 0.00471415596881083, 0.08744476881942578, 0.030805218432630812, 0.04329702098454748, 0.023176579835957715, 0.03836271432893617, 0.11289274293397154, 0.10540487830127988, 0.1248477292912347, 0.13283785911543028, 0.09100369856293712, 0.08345108133341585, 0.1336501333862543, 0.20142018901450293, 0.11644735719476428, 0.17438214272260666, 0.13025538197585515, 0.12567054799624852, 0.1670278680643865, 0.1354532723448106, 0.11432325760168688, 0.12188990015004363, 0.16432898145701202, 0.1487030935074602, 0.11967935519559042, 6.308153552668435, 35.48736497334072, 60.92154121398926, 52.02996621813093, 39.46753978729248, 30.698968751089915, 43.14222315379551, 45.497384548187256, 30.934477942330496, 3.1289140922682623, 0.2653390834374087, 0.35700539180210655, 3.5192567237785886, 15.935419014522008, 11.838563970157079, 5.381174836839948, 15.414800916399274, 23.732789959226334, 40.21245615822928, 50.484464509146555, 48.642128808157786, 43.542988300323486, 42.01246690750122, 37.17122616086687, 38.91701316833496, 34.07060991014753, 41.63898386274065, 49.878995009831016, 49.17606660297939, 45.5413874898638, 46.84191656112671, 47.14064393724714, 44.25371953419277, 39.889170374189106, 35.22193683896746, 35.04263857432774, 32.1770555632455, 33.72265454701015, 36.3451999936785, 36.256162302834646, 35.59523228236607, 36.1379143851144, 34.802932671138215, 33.74391256059919, 32.79158203942435, 33.706138678959434, 35.34717117037092, 33.82400791985648, 38.08120741162981, 38.43823364802769, 36.7427898134504, 41.884693009512766, 39.1065218108041, 36.58227252960205, 35.65012305123465, 33.98260750089373, 34.94285202026367, 36.522858483450754, 35.92287458692278, 33.770600591387065, 32.943636417388916, 32.997453689575195, 35.37941428593227, 36.39229835782732, 39.41254826954433, 40.4167331968035, 45.51854181289673, 45.85315663473946, 49.04343938827515, 40.40139504841396, 40.84364441462925, 50.86582681110927, 48.00406183515276, 46.34606531688145, 42.370066370282856, 41.70886189596993, 39.11960179465157, 36.78843252999442, 34.96992220197405, 37.640239988054546, 37.02203444072178, 37.49676316125052, 34.7836583682469, 37.40759692873274, 34.90756559371948, 36.00423799242292, 36.2150810786656, 39.0452595438276, 37.42421007156372, 37.931967054094585, 36.369431836264475, 36.08231142589024, 35.21520056043352, 35.79138340268816, 34.94425555637905, 35.75498873846871, 37.40911858422415, 40.9524427822658, 46.555140086582725, 50.92739827292306, 45.93171991620745, 45.359605244227815, 46.13287026541573, 47.3368958064488, 46.909494740622385, 47.86884989057268, 49.65484264918736, 49.22771256310599, 50.76703037534441, 46.914553029196604, 50.80553034373692, 51.61611761365618, 46.050680024283274, 39.06644112723214, 37.68581322261265, 39.39101927621024, 47.57550736836025, 51.99375915527344, 52.284471784319194, 56.376064436776296, 51.3909021786281, 47.30215828759329, 26.064841645104543, 16.023935590471538, 6.404003517968314, 12.908966098512922, 16.987060138157435, 9.857743723051888, 1.7359199140753065, 0.18998912668653897, 1.4567175188234873, 13.889510648591177, 49.51555558613369, 51.64643260410854, 33.44811037608555, 47.889739649636404, 62.64693873269217, 59.80381229945591, 33.55424758366176, 5.086219898291996, 0.18883421937269823, 0.14057463753436292, 0.15220517558710916, 0.19153659365006856, 0.07652213956628527, 0.29520233241575106, 0.11235089879482985, 0.15035835254405225, 0.1824634133705071, 0.09270110819488764, 0.08257471943008048, 0.13000724171953543, 0.22306937804179533, 0.1309035729084696, 0.10514539972479854, 0.11089652683585882, 0.08937194397939102], [0.07334817666560411, 0.04148600084174957, 0.03116070292890072, 0.03198997789461698, 0.036692344317478795, 0.03374116821214557, 0.04417286720126867, 0.019128743559122086, 0.04311641871130892, 0.011061926555287625, 0.016207813152245114, 0.08191847428679466, 0.10324685874262027, 0.0346403390701328, 0.10370227787643671, 0.021566782645615082, 0.06975262638713632, 0.0477863240188786, 0.01602196749964995, 2.030755430459976, 12.917910167149135, 46.27959190096174, 43.80175311224801, 33.56421477454049, 20.202345984322683, 27.008240256990703, 39.38691636494228, 28.243850571768625, 5.30120758499418, 0.16364229044743947, 0.15275549462863378, 3.091959229537419, 2.069180488586426, 4.179204659802573, 0.22653426283172198, 4.832282781600952, 12.15444210597447, 28.9683427129473, 45.56570618493216, 43.99760546003069, 43.162994793483186, 40.58907631465367, 35.651464053562705, 34.59051929201399, 32.34453494208199, 36.877546651022776, 43.69814157485962, 43.949124404362266, 40.12786184038435, 45.38386140550886, 42.08275835854666, 40.21857404708862, 39.58398117337908, 34.2371095929827, 30.273089340754918, 31.887204510825022, 31.05318444115775, 31.890685558319092, 32.05599362509591, 32.64239031927926, 30.85089806147984, 31.96728249958583, 32.572904859270366, 31.230578899383545, 31.80013316018241, 32.72475773947579, 32.33784730093819, 32.2454640524728, 33.08910737718855, 34.70746442249843, 36.46046366010393, 36.07944529397147, 35.571115085056846, 34.24673284803118, 31.306515761784144, 31.943147931780132, 31.27600622177124, 32.3044090952192, 31.74596847806658, 33.379743576049805, 30.481469290597097, 32.02884006500244, 29.777842589787074, 35.03487048830305, 38.827106952667236, 40.28400175912039, 42.4922365461077, 45.87837164742606, 37.43166896275112, 37.79213455745152, 47.212995529174805, 39.93180104664394, 40.57678147724697, 34.77372939246041, 34.83708306721279, 32.44188962663923, 32.44939368111746, 33.079525811331614, 31.757599762507848, 33.294704573495046, 33.88018757956368, 30.27739027568272, 34.264443806239534, 31.55453518458775, 32.81487587520054, 33.23544338771275, 32.21224818910871, 32.372828006744385, 34.198237895965576, 32.97104011263166, 32.30882814952305, 32.10063232694353, 31.29701410021101, 33.23887579781668, 32.414485931396484, 34.908177035195486, 40.67592879704067, 43.684338978358674, 43.85014731543404, 41.9532230922154, 46.301332814352854, 45.8680431502206, 46.876591546194895, 46.1338221686227, 45.79833882195609, 45.34884595870972, 46.15419428689139, 44.84824562072754, 49.950384276253835, 45.20823526382446, 49.64891236168997, 47.38207646778652, 39.90690565109253, 31.207104410443986, 34.147231170109336, 36.825991017477854, 43.56130027770996, 45.05906438827515, 49.32152019228254, 50.81483050755092, 42.08163275037493, 22.68166995048523, 10.334783588136945, 6.171056474958148, 12.577644722802297, 7.2771927544048856, 3.1534153946808408, 0.2980199083685875, 0.04649805064712252, 0.49191926951919285, 12.51460371698652, 38.15120356423514, 39.64494119371687, 30.63899884905134, 29.01908540725708, 45.888919012887136, 51.806508677346365, 19.547108275549753, 3.669013636452811, 0.027721244542460357, 0.07314758135804109, 0.06575642832155738, 0.053891052691532035, 0.01991901463562889, 0.07389771539185729, 0.01877435320056975, 0.07218922528305224, 0.0609661407236542, 0.05636987342898335, 0.09860363682465893, 0.05043799137430532, 0.020242221221061688, 0.014721382109980499, 0.04085037637768047, 0.05510718082743032, 0.06596802268177271, 0.027404975977593234, 0.02699820780461388, 0.025829114019870758, 0.03671831863799265, 0.08021664060652256, 0.07663124121193375, 0.03661948322717633, 0.0503409574739635, 0.027656929600717764, 0.004361453890201769, 0.01450101429197405, 0.03887865200106587, 0.039184064005634615, 0.023571339635444537, 0.06706530201647963, 0.0160181269914444, 0.020043206900092106, 0.01915325563667076, 0.024447460658848286, 3.225085411752973, 19.804346220833914, 53.618247985839844, 50.41237694876534, 37.40426526750837, 24.36481547355652, 34.87782730375017, 42.19780315671648, 29.865994385310582, 5.468483294759478, 0.1954687312245369, 0.10828792609806571, 4.14245650597981, 3.5886509886809757, 4.3472233925546915, 4.03937737430845, 8.574843100139073, 13.176233768463135, 31.5900821685791, 48.60125950404576, 46.30431359154837, 45.4058107648577, 42.17053147724697, 36.83795581545149, 35.277425152914866, 33.041394097464426, 38.24581371034895, 45.55797283990042, 45.81762702124459, 41.863441944122314, 46.13629572732108, 44.09307370867048, 41.08319050925118, 40.42522389548165, 35.51713800430298, 32.030618803841726, 33.24059200286865, 34.49408524377005, 33.37886462892805, 33.2505452973502, 32.38395207268851, 31.909942490713938, 34.58450215203421, 33.340392453329905, 32.334710189274375, 33.711096218654085, 33.935321535382954, 34.07895122255598, 34.412374428340364, 35.78187131881714, 36.64481326511928, 37.58592244556972, 37.748364380427766, 36.7166611126491, 34.55027879987444, 32.977428981236045, 34.642999035971506, 31.413149765559606, 32.549690927777974, 33.61509643282209, 35.49277414594378, 32.09529611042568, 33.972212995801655, 32.538987227848594, 37.03444044930594, 39.82300615310669, 43.72867543356759, 45.4775196484157, 47.614101137433735, 38.76965577261788, 39.52458449772426, 48.933306966509136, 42.454066617148264, 42.05764756883894, 37.271335806165425, 36.128433568137034, 34.35637194769723, 34.36868762969971, 33.6150095803397, 34.51563508169991, 34.30939517702375, 34.30938475472586, 33.23733677182879, 35.40542834145682, 32.787774426596506, 33.97142090116228, 35.21807711465018, 34.839924880436485, 34.09925038473946, 35.412828172956196, 35.37461655480521, 32.689047472817556, 34.299372400556294, 34.63732235772269, 34.503847462790354, 33.23888274601528, 36.58782066617693, 41.83388083321707, 45.68916872569493, 45.91385609763009, 44.587625639779226, 46.682285172598704, 46.73600517000471, 47.22225052969796, 48.42236770902361, 47.78973422731672, 48.26034614018032, 47.39787319728306, 47.776695932660786, 50.36031757082258, 46.04267569950649, 50.30248423985073, 50.20177704947335, 39.90326132093157, 34.135106563568115, 35.9831154687064, 39.745533738817485, 45.30447128840855, 49.10165139607021, 50.82790354319981, 53.96243395124163, 42.4176024709429, 25.5624451977866, 11.081825239317757, 7.813528112002781, 12.984528626714434, 5.7983164531844, 3.7680115699768066, 0.2046197937535388, 0.14456841322992528, 0.6079363812293325, 14.081789885248456, 43.12350123269217, 46.78339188439505, 31.08237382343837, 35.17711400985718, 53.57061461039952, 57.49364396503994, 25.559724978038243, 3.978294457708086, 0.04267172721613731, 0.06485415316585984, 0.026265186423967992, 0.09685989003628492, 0.04141765200932111, 0.02583476960925119, 0.03374939884192177, 0.034862494827913384, 0.014686288278816002, 0.05314710350441081, 0.06321671924420766, 0.017373412481642196, 0.04351376881822944, 0.015502335204343711, 0.028646181071443216, 0.031173354214323417, 0.028333200008741448, 0.14069977296250208, 0.10060593259653874, 0.12609468666570528, 0.10209967994264194, 0.21042827064437525, 0.14306594670883246, 0.12841728489313806, 0.14898729111467088, 0.12893198084618362, 0.08365394294794117, 0.08293175777154309, 0.15244730402316364, 0.2618403397500515, 0.08837713700320039, 0.20686088635453156, 0.13879192247986794, 0.11687126516231469, 0.13111896706478937, 0.13040772665824207, 3.236802028758185, 23.124367475509644, 59.133088793073384, 55.725900650024414, 44.78608356203352, 30.367112364087784, 36.47168847492763, 48.26779808316912, 34.8875686781747, 7.170500993728638, 0.33213032515985624, 0.5459252287234578, 6.964975016457694, 7.200682665620532, 10.243421724864415, 5.088955751487187, 9.548182368278503, 14.201146909168788, 31.6222106388637, 50.466593742370605, 48.759171213422505, 48.126471723829, 46.16205964769636, 38.338558265141074, 37.517830099378315, 35.01154885973249, 40.062454972948345, 47.557779039655415, 48.25069856643677, 43.562710762023926, 46.84236471993582, 47.08688225064959, 44.33211953299386, 43.72862332207816, 36.636301721845356, 33.703713757651194, 34.922059535980225, 35.67961468015398, 35.14044141769409, 34.158431666237966, 35.47669948850359, 32.4681190763201, 35.4019125529698, 35.22939920425415, 34.387739590236116, 35.549342904772075, 36.288926533290315, 35.72370447431292, 35.832151957920615, 37.44701058523995, 38.525704520089285, 40.45903035572597, 40.059272697993684, 39.861478328704834, 37.35411317007882, 34.39750180925642, 35.80877474376133, 34.182399477277485, 34.55815805707659, 35.86007329395839, 37.87443944386074, 34.910327502659385, 35.33241319656372, 32.93255056653704, 39.45043332236153, 43.122657026563374, 44.57945803233555, 47.14852319444929, 48.24447992869786, 42.16687672478812, 42.50701536451067, 50.674987588609966, 45.343742506844656, 44.46904420852661, 39.740270478384836, 37.967691217150005, 36.429096017565044, 35.38624436514718, 36.219691208430696, 36.28254461288452, 37.044077600751606, 36.843288557870046, 34.75168623243059, 38.2880448613848, 34.81137473242623, 35.0324455669948, 37.17841059820992, 35.15399735314505, 35.70213379178728, 37.942177431924, 37.722371169498985, 35.37561362130301, 35.66035427365984, 34.958127634865896, 36.65734086717878, 35.8024240902492, 37.79481308800833, 43.5538900239127, 48.298887797764365, 48.844606263296946, 47.2452768598284, 48.59050716672625, 48.27535424913679, 49.5961720602853, 49.23938206263951, 50.13507434300014, 50.92857599258423, 50.09214489800589, 49.02082995006016, 51.314909730638774, 46.352217946733745, 50.90919746671404, 52.37827941349575, 44.651364939553396, 36.65635769707816, 37.490190165383474, 41.354830333164756, 49.028174195970806, 51.86741311209542, 53.946077891758506, 55.05650077547346, 44.78416238512312, 26.81691987173898, 14.553585597446986, 10.83433995928083, 22.287224190575735, 13.716000233377729, 6.177128766264234, 0.7743930720857212, 0.18508954745318207, 0.9552076182195118, 18.180206537246704, 49.40972409929548, 52.68932247161865, 41.02403702054705, 40.469032287597656, 59.80836336953299, 64.92257799421037, 31.228150503976003, 5.246131386075701, 0.17146338362778935, 0.1613971402070352, 0.12113975254552704, 0.162035628088883, 0.15818557968097074, 0.132105841966612, 0.10572617141796009, 0.1604697863970484, 0.13845972530543804, 0.1519747722361769, 0.17775347110416206, 0.13460760058036872, 0.0855703294011099, 0.09462876511471612, 0.12268363684415817, 0.07784526928194932, 0.12381756385522229], [0.048184152492987256, 0.021508124989590476, 0.021039530402049422, 0.019145969866908023, 0.01826075817059193, 0.04050502580191408, 0.08521972357162408, 0.058186596658613, 0.055385224122021876, 0.021370441752618978, 0.045337864330836704, 0.035732885623084645, 0.05547245658401932, 0.05358516571245023, 0.021452500385099223, 0.04662407495613609, 0.07375308565263237, 0.047748451586812735, 0.06710710655897856, 1.3789916038513184, 10.037594369479589, 40.310689789908274, 45.42687422888619, 32.57158817563738, 22.81782511302403, 32.40845489501953, 36.1973249571664, 32.61732121876308, 8.676609022276741, 0.09779457202447311, 0.13316540153963224, 1.5764056678329195, 3.3761889721666063, 3.3742441279547553, 2.753473392554692, 5.065446087292262, 7.1612381764820645, 25.104447739464895, 37.607875279017854, 49.7071521622794, 41.81942163194929, 43.50620801108224, 38.24213811329433, 33.46395574297224, 32.16802985327584, 35.392681871141704, 41.30782924379621, 46.634669167654856, 45.237949235098704, 44.26425995145525, 45.954534326280864, 43.2705077443804, 41.9104881967817, 37.068618638174875, 32.7574177469526, 32.257765838078086, 30.950695037841797, 31.90946306501116, 31.081831863948278, 32.46621526990618, 32.11397634233747, 33.2483948298863, 30.523043836866105, 31.70477260862078, 33.13350289208548, 32.60058995655605, 32.190382208142964, 33.05727767944336, 32.34628241402762, 33.87980195454189, 36.01808227811541, 37.699820790972026, 37.479747022901265, 35.962701661246165, 32.85145814078194, 31.36208745411464, 33.56787994929722, 32.199043137686594, 31.446792943137034, 31.353700978415354, 31.405079432896205, 33.162303175245015, 32.356235708509175, 34.372467449733186, 38.06334359305245, 42.75497920172555, 42.43423645836966, 46.2023800441197, 39.86185353142874, 34.58411652701241, 44.94356795719692, 41.405844007219585, 40.977900981903076, 36.403672558920725, 33.53111008235386, 32.498798847198486, 31.9848301751273, 31.405402524130686, 30.67074864251273, 31.462117195129395, 32.62920611245291, 33.364023276737754, 33.80799927030291, 33.14495004926409, 32.60223320552281, 34.51317889349801, 33.16798332759312, 34.05798503330776, 34.13128852844238, 34.41394819532122, 33.23851449148995, 32.65757213320051, 32.23267936706543, 31.84889214379447, 33.34058700289045, 32.99443122318813, 39.41411508832659, 44.29432133265904, 45.01315416608538, 46.580653871808735, 46.182136467524934, 45.61000442504883, 43.05477660042899, 42.98065321786063, 41.25656196049282, 42.35652780532837, 41.389216967991416, 42.743177686418804, 46.48887511662075, 49.91232551847185, 44.01074797766549, 48.48131969996861, 45.13663060324532, 36.26151588984898, 32.86382246017456, 36.13000038691929, 37.85198981421334, 44.21768617630005, 45.68635123116629, 48.827558858054026, 42.06426920209612, 19.477751357214792, 4.612938574382237, 7.097612219197409, 15.250092131750923, 6.046975978783198, 4.136588752269745, 0.44471361541322296, 0.02636699890717864, 0.7905247264674732, 13.024466872215271, 34.884987422398154, 28.476132324763707, 33.47115407671247, 34.88025917325701, 48.06677280153547, 47.28284576960972, 19.59452451978411, 2.4115214901311055, 0.11144888826778956, 0.0779404134622642, 0.03722402400204113, 0.005838620809039899, 0.012162031140178442, 0.09442282295120613, 0.06483688444963523, 0.047359111585787365, 0.05302920125957046, 0.06728175468742847, 0.027995189485539283, 0.0537140534392425, 0.028192093562600867, 0.04738916050908821, 0.04756301135889121, 0.013120970755283321, 0.006397877429013273, 0.04188934241288474, 0.025264423606651168, 0.07242697038288627, 0.013906143489293754, 0.05384400646601405, 0.04891774045037372, 0.05126074901116746, 0.032613731388534815, 0.0492549621766167, 0.02319291726286922, 0.011620700143144598, 0.06084803491830826, 0.0676256837323308, 0.028785155221287693, 0.09323392781828131, 0.06687062353427921, 0.054866182152181864, 0.03800025788534965, 0.05480559915304184, 1.338862608586039, 12.817474825041634, 47.91088996614729, 49.46717527934483, 35.68918234961373, 22.76289960316249, 32.19638892582485, 43.432942731039866, 36.63525601795742, 9.657767619405474, 0.13073478053723062, 0.1793186478316784, 2.122335293463298, 2.1127215921878815, 5.270888251917703, 4.8159410527774265, 7.731469018118722, 9.525803089141846, 27.557523148400442, 42.019425528390066, 51.48233004978725, 43.62096445901053, 44.91658810206822, 40.450456278664724, 35.25826896939959, 35.43587187358311, 37.120445251464844, 43.1580685206822, 47.8482380594526, 45.839937686920166, 44.359148025512695, 46.853249073028564, 44.56004129137312, 43.49358313424246, 38.01332351139614, 33.731582982199534, 33.858015877859934, 32.400971685137065, 32.92619296482631, 32.941114221300396, 34.29827805927822, 33.59236887523106, 34.273330552237375, 32.51247290202549, 33.2128860609872, 34.11085735048567, 33.80257967540196, 33.92676135471889, 34.9178524017334, 33.4077274458749, 36.55142947605678, 37.264001982552664, 39.06189005715506, 40.06076308659145, 36.01472977229527, 34.285712242126465, 33.30313968658447, 34.970078536442344, 33.079636982509065, 32.98734406062535, 32.84867191314697, 33.570214544023784, 33.32003075735909, 33.93723576409476, 36.693874495370046, 39.969303948538645, 43.17752695083618, 45.356853757585796, 47.4806227684021, 42.07664394378662, 37.85951123918806, 47.71247720718384, 43.89102356774466, 43.66866384233747, 38.10621050425938, 33.770489420209614, 33.94099473953247, 33.99017408915928, 34.112271308898926, 32.79921810967581, 33.796437467847554, 34.85677773611886, 34.80595861162458, 35.78366047995431, 33.176741531917024, 33.79237971987043, 35.649261474609375, 35.590399810246055, 35.2285133089338, 36.10735273361206, 35.406171798706055, 34.20957735606602, 34.3396441595895, 34.34784998212542, 33.935870443071636, 34.49649626868111, 33.793196133204866, 41.30348661967686, 45.913004943302695, 47.03587899889265, 48.84077780587332, 48.732861859457834, 47.432228565216064, 44.783464091164724, 45.176311765398296, 44.48706783567156, 45.033078125544954, 44.444659505571636, 46.06054299218314, 48.834743295397075, 50.415611335209434, 46.003883906773154, 51.13589981624058, 45.99020985194615, 37.13211475099836, 34.642029762268066, 38.20093182155064, 41.00295966012137, 48.01485586166382, 48.41367898668562, 51.62776279449463, 43.80940307889666, 24.28346422740391, 8.872370174952916, 9.271495546613421, 16.099471194403513, 3.894552162715367, 4.7294889603342325, 0.8977697374565261, 0.04019674698689154, 0.6905747268881116, 15.012887580054146, 40.14837639672415, 38.63812289919172, 37.8522538457598, 37.48535074506487, 52.598704065595356, 54.34467172622681, 23.343986136572703, 3.324062934943608, 0.11240800430199929, 0.008280084801039525, 0.031461928372404406, 0.08364306603159223, 0.015303478642765964, 0.017029821007911648, 0.025867590348103216, 0.014122900652832218, 0.074638553495918, 0.036197861922638755, 0.016484886141760007, 0.042941332927771976, 0.04314493753814271, 0.004773023122522447, 0.028771625233015845, 0.052910644228437116, 0.024191373061122637, 0.0913458973435419, 0.07946801292044775, 0.13487199853573525, 0.0790711852854916, 0.13144467744444097, 0.10813720989972353, 0.16327114536293916, 0.10685829352587461, 0.18764488319201128, 0.1375917840216841, 0.12025843055120536, 0.21488646284810134, 0.16548394305365427, 0.10347564718020813, 0.16570780532700674, 0.14181077906063624, 0.1707637325993606, 0.17800832885716641, 0.16896085148411139, 2.2174027178968703, 17.992553063801356, 54.26761620385306, 56.12835420880999, 42.665403025490896, 31.208226544516428, 40.34260286603655, 46.52175399235317, 41.531787054879324, 11.899764571871076, 0.19693960515516146, 0.44691016897559166, 5.006453709942954, 8.799307261194501, 9.798122099467687, 10.178403088024684, 10.901028769356863, 8.840109688895089, 28.150604009628296, 42.458416189466206, 55.0138110433306, 47.06800052097866, 48.66373423167637, 42.14485788345337, 37.02800989151001, 36.54012475694929, 38.543290410723, 45.52985348020281, 49.227545806339805, 45.56376763752529, 44.153470924922395, 48.39966794422695, 47.4834680557251, 46.782467773982454, 40.29702615737915, 36.258330140795024, 35.850675855364116, 34.348989486694336, 34.32755429404122, 34.699498312813894, 36.15408631733486, 34.459403310503276, 36.19484792436872, 33.54385307856968, 33.820638043539866, 34.976658480507986, 35.7028876713344, 36.02597543171474, 36.2782541002546, 36.99924782344273, 39.02059343882969, 40.17839956283569, 41.51049082619803, 42.180766173771445, 40.42766618728638, 36.264239583696636, 36.10309001377651, 36.921775409153526, 35.834715843200684, 34.7224760055542, 33.821777548108784, 34.607452051980154, 35.67037010192871, 35.86941514696394, 38.13631704875401, 41.42482648577009, 45.540463379451204, 45.54443427494594, 48.703599521092, 44.614327566964285, 39.680380480630056, 49.57763079234532, 45.04317038399832, 45.88438878740583, 40.94346570968628, 36.31758090427944, 37.094052519117085, 35.1451210294451, 35.65595953805106, 33.58497946602957, 34.956359318324495, 36.56157037190029, 37.65370907102312, 37.67189598083496, 35.41590622493199, 36.454206807272776, 37.77579934256417, 36.740715776171, 37.58131578990391, 38.789982727595735, 38.423583371298655, 36.04511077063424, 37.794114794049946, 36.6867630141122, 35.958859307425364, 36.05166292190552, 35.30625670296805, 43.06657116753714, 49.79355648585728, 48.57376200812203, 50.482386997767854, 51.28937857491629, 48.577642577035085, 46.597089835575645, 46.26028633117676, 45.54858929770333, 48.34987367902483, 45.18483373097011, 47.051637513296946, 50.443397181374685, 52.97295488630022, 47.62559693200247, 51.73293767656599, 49.13689613342285, 39.650982652391704, 36.59067637579781, 40.427895477839876, 42.2950154032026, 49.265552452632356, 52.00835037231445, 54.019044399261475, 49.22429404939924, 22.729669843401226, 8.317995122500829, 12.152633837291173, 23.213198457445415, 10.88433311666761, 9.248791439192635, 2.0811502805777957, 0.11115400373403515, 1.254755967429706, 17.755060161863053, 46.23709324428013, 42.16368750163487, 45.44718381336757, 45.536280563899446, 59.74798352377755, 61.736481530325754, 29.43539019993373, 4.190878501960209, 0.26260716574532644, 0.11532569809683732, 0.09926730514104877, 0.19491193895893438, 0.11929516866803169, 0.0981514271614807, 0.13102972613913672, 0.11334139028830187, 0.1595067416450807, 0.11673349541212831, 0.11548602235104356, 0.17048519397420542, 0.14255221427551337, 0.1891755767698799, 0.20623348573488848, 0.11993532574602536, 0.2377134801021644], [0.11161959410778113, 0.05013178548376475, 0.02980385341548494, 0.09658399091235229, 0.0346763828503234, 0.06505290285817214, 0.028331678393962126, 0.06678674982062408, 0.03329864802903362, 0.046599528951836486, 0.027122685053784932, 0.05857735140515225, 0.023086821527353356, 0.017659182593758618, 0.07837682004485812, 0.04284867897097554, 0.02168927517985659, 0.04352574835398367, 0.029842146539262364, 0.8181153716785567, 11.49122873374394, 36.29192468098232, 50.19747611454555, 38.817254407065256, 33.53898239135742, 41.86903871808733, 33.12483154024397, 33.12879548754011, 16.20699977874756, 0.5455039399010795, 0.14461903194231646, 0.9775866802249635, 1.1510948155607497, 3.0099752630506242, 4.518858228410993, 8.342427594321114, 9.021678277424403, 20.021953378404888, 32.48863710675921, 46.48449775150844, 46.271893296922954, 43.02204711096627, 39.313404423849924, 35.65495204925537, 32.62763581957136, 35.2080717086792, 41.40702172688076, 43.79787254333496, 46.22081014088222, 39.850201402391704, 40.04492814200265, 45.15000935963222, 43.44128404344831, 38.67135960715157, 33.22485433306013, 31.14788838795253, 29.741632052830287, 30.240220887320383, 31.710650784628733, 31.457503591264995, 31.588994775499614, 30.27659818104335, 31.15545497621809, 30.22219726017543, 32.78592620577131, 34.670420101710725, 34.068733896527974, 33.8197660446167, 33.33026545388358, 32.78833723068237, 33.84362963267735, 35.76654011862618, 36.759934493473594, 36.00705548695156, 33.41935178211757, 33.06130068642752, 31.314252580915177, 31.164501530783518, 31.21019983291626, 32.29970516477312, 31.717143876211985, 33.21513032913208, 33.27232789993286, 36.7659273147583, 37.72658177784511, 41.03165919440133, 44.51083067485264, 47.39204018456595, 41.66905566624233, 35.24021407536098, 46.86637422016689, 41.59746837615967, 43.357367174965994, 40.922631536211284, 38.36039992741176, 34.39701196125576, 33.108201026916504, 31.858195781707764, 32.93153265544346, 30.146326405661448, 33.087269578661235, 33.27009752818516, 33.03183337620327, 33.35087728500366, 33.3086530821664, 33.47325938088553, 34.90514414651053, 37.465374674115864, 37.83487640108381, 36.65035792759487, 34.25173555101667, 33.309108189174104, 33.17580352510725, 32.839385645730154, 31.387556076049805, 33.746393067496165, 36.191617012023926, 42.573294230869834, 43.286186354500906, 45.82705225263323, 42.87681586401803, 41.594980921064106, 41.38100419725691, 40.754533767700195, 37.40122890472412, 40.833830084119526, 39.88938924244472, 42.68742881502424, 43.27195644378662, 48.79809154782976, 45.198639801570344, 45.85245486668178, 46.348160198756624, 42.334710461752756, 34.062490940093994, 35.71157986777169, 35.24660641806466, 43.911805629730225, 45.27910688945225, 53.32708372388567, 37.64361681256975, 24.52906220299857, 8.502897109304156, 8.974547777857099, 9.604870983532496, 1.0722812903778893, 2.547979550702231, 0.26677255651780535, 0.06077581165092332, 0.7964038252830505, 14.710604463304792, 41.039364746638704, 34.12808540889195, 27.712674685886928, 39.129871232169016, 44.54713153839111, 48.45986018862043, 21.106862476893834, 2.0814119236809865, 0.1879511196166277, 0.1088486470814262, 0.06699598966432468, 0.04895569430664182, 0.04698131007275411, 0.04373897798359394, 0.03787446427824242, 0.018249016122094223, 0.05747530196926423, 0.06696810866040842, 0.07575190053986651, 0.02757801258537386, 0.035705309959926775, 0.01278266082850418, 0.07307828257658652, 0.038177029828407934, 0.024776794415499483, 0.029806811828166246, 0.043013732614261765, 0.01613867382651993, 0.04675095421927316, 0.07148693475340094, 0.05889637142951999, 0.04488822292270405, 0.022303827738921558, 0.03834817332348653, 0.05062888363110168, 0.03326985100284219, 0.015850350726395845, 0.011781572314378406, 0.009908674866892397, 0.06082655928496804, 0.035359799928430996, 0.033099141770175526, 0.08535097938563142, 0.12064827606081963, 1.0634281997169768, 13.845426065581185, 41.816142082214355, 55.79456622259957, 42.90217678887503, 33.07681948798043, 40.21455104010445, 37.611898286002024, 39.42067766189575, 15.61951916558402, 0.3995406622333186, 0.2112809041781085, 1.1492182591131754, 2.600270607641765, 6.079198684011187, 4.6261544823646545, 4.740578285285404, 11.296726942062378, 21.688176563807897, 35.019448961530415, 50.30727154867989, 47.95463235037667, 44.987862723214285, 41.909696102142334, 36.38708373478481, 34.95230157034737, 36.93850319726126, 42.93680313655308, 46.08995124271938, 46.36052451814924, 39.45039510726929, 42.15886892591204, 47.44431843076433, 43.823917865753174, 40.769350801195415, 35.07137284960066, 32.261187825884136, 31.39379208428519, 32.349707875932964, 33.42258269446236, 32.846038545881, 32.82014955793108, 32.90617520468575, 33.08328478676932, 31.4180725642613, 34.252114227839876, 35.51129804338728, 36.05884388514927, 36.65782724108015, 33.6195467540196, 34.77298593521118, 36.0661255972726, 38.662952286856516, 37.75618805204119, 38.02514239719936, 36.43377215521676, 34.11334480558123, 32.48314455577305, 33.96934338978359, 32.33905976159232, 33.70025702885219, 33.35387543269566, 34.16774225234985, 35.36486823218209, 38.5960237639291, 40.28260169710432, 43.69146088191441, 45.24766976492745, 48.876401220049175, 43.38591037477766, 36.79399108886719, 49.508642128535676, 44.47199371882847, 45.16563238416399, 43.11170319148472, 39.584200041634695, 36.200969287327354, 34.577689443315776, 34.785020215170725, 33.58592789513724, 32.28643410546439, 33.78242642538888, 36.03134291512625, 34.46285656520298, 34.12292637143816, 34.792051792144775, 35.267433643341064, 35.24724217823574, 38.549210275922505, 39.170257636478965, 38.20637573514666, 35.70982197352818, 34.67431804112026, 35.10226454053606, 34.98097331183297, 33.09560741697039, 35.13831179482596, 38.02230058397566, 45.26755550929478, 44.9723995072501, 48.252890723092214, 46.60064731325422, 44.6279182434082, 41.63938685825893, 42.77968004771641, 39.77174929210118, 42.731824329921174, 42.13919162750244, 45.197670527866904, 44.08547585351126, 50.33694730486189, 45.05485030582973, 47.70209659848894, 50.88419437408447, 41.98208243506295, 35.20649446759905, 37.205400875636506, 36.780320508139475, 45.84904677527291, 48.38913794926235, 53.52516991751534, 41.88325125830514, 24.482368571417673, 10.289450066430227, 11.67953620638166, 11.042024220739092, 3.1082872790949683, 3.1179570002215247, 0.2697317562997341, 0.09624934422650508, 0.889146697308336, 17.67841805730547, 42.399064677102224, 37.85940701620919, 37.06663492747715, 43.69999326978411, 50.47880172729492, 55.59256819316319, 25.64975799833025, 3.253688539777483, 0.2335248834320477, 0.040733332479638715, 0.03775502175890973, 0.06819743090974432, 0.05894201648022447, 0.027797391438590627, 0.05836136692336627, 0.0538709884110306, 0.0062846562276328245, 0.028009284354214157, 0.06718380137213639, 0.02905657601409725, 0.04240678982543094, 0.0466464598264013, 0.09048670916152851, 0.016766725839780908, 0.006290752864775381, 0.16426389637802327, 0.07661050518176385, 0.08317199988024575, 0.195286042456116, 0.15833426027425698, 0.21066552719899587, 0.15912426502576896, 0.15006081493837492, 0.09460327933941569, 0.30163712427020073, 0.11543026034321104, 0.12273243708269936, 0.13070830410080297, 0.14507941795246942, 0.12806296747710022, 0.13969183633370058, 0.1534628809562751, 0.18021960662943975, 0.17036564967461995, 1.2513636180332728, 16.566873039518082, 47.85634660720825, 61.938111305236816, 50.29807560784476, 43.26802723748343, 51.411347252982004, 42.470189911978586, 42.49096155166626, 20.317462001528057, 0.6989962149943624, 0.5367637031844684, 2.647017219236919, 5.190809394632067, 9.28805570943015, 10.20775922707149, 14.875311510903494, 11.264110360826765, 21.56520560809544, 35.10720123563494, 51.943092891148154, 50.12082011359078, 47.75999941144671, 44.8872458594186, 38.92537532533918, 37.02795778002058, 39.82978759493147, 44.57641124725342, 47.859171049935476, 47.0562059538705, 40.92532048906599, 41.93119730268206, 48.87973288127354, 47.582208905901226, 41.66201366697039, 37.02606092180525, 34.97582817077637, 32.5290652002607, 33.611351353781565, 34.61030428750174, 33.82504667554583, 34.639740330832346, 33.67147759028843, 33.798744269779746, 33.33857549939837, 36.45120171138218, 37.630102566310335, 38.096146038600374, 38.39863933835711, 36.10476105553763, 36.818959440503804, 36.97457824434553, 39.59091894967215, 41.073247637067524, 41.55310065405709, 38.07342890330723, 36.060792854854036, 34.460403851100374, 35.09187003544399, 34.46229028701782, 36.100890908922466, 35.14900854655674, 36.97272307532174, 37.83375426701137, 40.87087093080793, 41.3727080481393, 45.69947290420532, 48.371340138571604, 50.72019256864275, 45.739470209394185, 40.91130249840872, 50.583910601479666, 46.74849803107125, 47.19427708217076, 44.8163811819894, 42.40989691870553, 39.23429570879255, 36.68143721989223, 36.692182609013145, 35.36328751700265, 33.006052085331504, 35.900084495544434, 37.33920233590262, 36.438778332301546, 37.214377948216026, 36.92492989131382, 37.793888977595735, 37.76142004558018, 40.526278495788574, 42.04298339571272, 40.43328380584717, 38.68641287939889, 36.06081369944981, 36.34278896876744, 38.043874740600586, 34.1952223777771, 37.62835856846401, 39.740492820739746, 47.52415670667376, 46.600213050842285, 50.821837765829905, 48.192135674612864, 46.61348411015102, 44.99660355704171, 45.94730125154768, 41.225312437329976, 45.43096671785627, 44.423675945826936, 47.288723945617676, 48.65862730571202, 52.27457060132708, 46.97773994718279, 49.77517850058419, 53.42659929820469, 46.07107298714774, 37.71090316772461, 40.15995904377529, 39.852046149117605, 47.38069030216762, 49.9424911226545, 56.14207342692784, 43.05341475350516, 27.39877244404384, 15.58153510093689, 17.755265133721487, 16.971956491470337, 5.264204519135611, 6.7210307121276855, 0.9408081280333656, 0.2240115510565894, 1.216380415218217, 20.0956529208592, 51.03161430358887, 44.10517052241734, 38.46223620006016, 51.64779792513166, 57.94270951407296, 62.7951021194458, 30.94899272918701, 4.181976556777954, 0.4012155852147511, 0.2124425425593342, 0.1395594405808619, 0.17402965735111917, 0.1815998147108725, 0.20638777102742875, 0.1475040271346058, 0.1138978839984962, 0.11295367537864617, 0.1300361201699291, 0.15926259117467062, 0.08514432476035186, 0.12055272475949355, 0.11727332430226461, 0.1874608373535531, 0.08980198590351002, 0.09474558848887682], [0.07138102222234011, 0.052602117748132775, 0.0799944678853665, 0.013385045558347233, 0.02942896621035678, 0.03150321722828916, 0.02400323565650199, 0.016053463398878063, 0.05238697125709482, 0.02490345824376813, 0.05157359775954059, 0.035801298916339874, 0.04904248232820204, 0.04110026386167322, 0.025392897427082062, 0.025853498872103434, 0.03260228450277022, 0.043688437302729914, 0.0315699681107487, 0.053644503599831035, 4.8300697803497314, 33.4774352482387, 48.31101240430559, 40.32699373790196, 27.202378136771067, 29.179946626935685, 30.205636228833878, 36.38275500706264, 19.816173791885376, 1.718488837991442, 0.09880818120603051, 0.24530666694045067, 1.8401515781879425, 4.014652209622519, 1.3789257045303072, 2.337205077920641, 6.412248424121311, 17.343481881277903, 25.20304615156991, 41.85694537843977, 46.35081788471767, 44.68055084773472, 40.698520864759175, 36.327020032065256, 34.606569630759104, 40.03472818647112, 43.82215649741036, 46.21519252232143, 44.82831123897007, 43.78928109577724, 45.379251275743755, 44.882910183497835, 42.42463404791695, 40.26451553617205, 31.45600278036935, 29.51474905014038, 32.58157621111189, 30.8373247555324, 31.305153914860316, 31.519168853759766, 32.40933036804199, 31.165786947522843, 30.292266368865967, 30.923218386513845, 34.153199672698975, 37.46139683042254, 40.162863390786306, 36.62718915939331, 32.892570631844656, 31.65857056209019, 33.92633056640625, 33.48791313171387, 35.761123997824534, 34.5700603212629, 34.022959164210725, 31.56274448122297, 32.88605669566563, 30.97775479725429, 32.162047454289024, 31.13825123650687, 33.198676994868684, 32.037539209638325, 33.8392835344587, 37.02142994744437, 38.64884396961757, 39.84683847427368, 44.05492115020752, 43.676390239170615, 43.04078640256609, 29.535142013004847, 43.67183916909354, 45.37931033543178, 44.20370987483433, 42.283960819244385, 42.19212300436837, 39.5087182862418, 36.754063265664236, 33.806255272456575, 31.739933967590332, 35.61150843756539, 32.45302758898054, 31.66031108583723, 31.79005479812622, 33.58047355924334, 31.751266479492188, 34.775456019810264, 37.47278145381382, 41.512589182172505, 42.06415803091866, 39.39821066175188, 36.51597629274641, 34.35478775841849, 32.07879761287144, 31.966744014195033, 31.01589345932007, 32.395885603768484, 32.38405976976667, 35.89653744016375, 39.9245297568185, 40.8290045601981, 38.67119632448469, 36.35516718455723, 35.39236920220511, 35.997491291591096, 35.770643029894146, 37.20000907352993, 36.93177386692592, 40.57478387015206, 40.66257783344814, 47.71165384565081, 48.21073947634016, 45.77986008780343, 49.30603960582188, 45.81342683519636, 38.369849477495464, 35.5255765914917, 37.03183140073504, 44.70662743704659, 44.09057930537632, 52.383771964481895, 42.36442790712629, 25.340755973543438, 9.068283319473267, 9.965172427041189, 17.021144526345388, 2.6376807945115224, 2.5135321191379, 0.5576120987534523, 0.068573719289686, 1.1464933710438865, 16.105948652539933, 40.24192694255284, 41.702365330287385, 30.32850817271641, 34.44446120943342, 43.35575519289289, 42.71442256655012, 18.545923233032227, 1.4540729693004062, 0.0650305315586073, 0.037463489188147445, 0.0302401378617755, 0.08545563662690775, 0.04224803977246795, 0.10236900406224386, 0.01511017419397831, 0.05323296193299549, 0.03432849794626236, 0.017612423049286008, 0.015145885492009776, 0.018383883438738327, 0.06054551686559405, 0.00942537812183478, 0.08531281857618264, 0.04783027273203645, 0.03966582386887499, 0.008980429631524851, 0.024529524380341172, 0.033689565623977354, 0.0375776730610856, 0.015006412618926592, 0.014282598958483763, 0.01724591405530061, 0.0036680267242315623, 0.03213568311184645, 0.031056052472974573, 0.066103424344744, 0.056384550141436715, 0.047732902956860404, 0.011826713552831538, 0.05659699606310044, 0.04426709535930838, 0.02659563297804977, 0.051277413831225464, 0.020508111953469257, 0.19232868828943797, 7.100836183343615, 37.9643908228193, 53.94001906258719, 46.35220752443586, 34.30005332401821, 37.457141058785574, 36.69356182643345, 38.842584065028596, 23.30516481399536, 1.6041085698774882, 0.33320197622690884, 0.03645888077361243, 1.104045957326889, 4.254523566790989, 4.448781737259456, 5.092808527605874, 8.601615377834865, 19.893161569322857, 28.183184112821305, 45.3211886542184, 47.2904714175633, 47.15217447280884, 42.744053159441265, 37.98994977133614, 36.51651477813721, 40.7107948575701, 45.14682708467756, 47.02393157141549, 44.83595078332083, 43.75299412863595, 45.51069034848894, 45.95813001905169, 44.5240808895656, 41.30766248703003, 33.86190686907087, 31.842722143445695, 32.618523257119314, 32.15360539300101, 32.60248681477138, 33.2654561315264, 34.19296768733433, 32.07212734222412, 32.426464625767295, 33.314100469861714, 36.25753109795706, 40.03679527555193, 41.19798517227173, 37.907116821834016, 33.73002658571516, 32.612617288317, 35.20596293040684, 36.03285762241909, 36.659706728799, 36.631437982831685, 35.51478603907994, 33.2683014188494, 34.2640095438276, 33.01406683240618, 32.768041542598176, 33.23013843808855, 33.96197829927717, 33.61130271639143, 35.74630001613072, 38.03746502740042, 40.18225233895438, 42.428931508745464, 45.420516627175466, 45.22256244931902, 44.9375820841108, 33.325849873679026, 45.3412481035505, 46.32036393029349, 45.69783660343715, 43.646488666534424, 43.453676155635286, 42.12768888473511, 36.48717948368618, 34.167203766959055, 33.15733173915318, 36.98277711868286, 33.33779035295759, 33.20082746233259, 33.08793660572597, 34.85410615376064, 34.00798232214791, 36.13955068588257, 38.402530329568044, 43.91069391795567, 44.07990687234061, 41.342935017177034, 36.698279653276714, 36.230613776615684, 32.76697499411446, 33.83225890568325, 33.00510018212454, 34.1291241645813, 34.06587471280779, 38.14463751656668, 41.97492231641497, 44.04497480392456, 41.62133543831961, 40.44979967389788, 38.13145330974034, 37.94301468985421, 36.84229496547154, 39.36363295146397, 38.9468799999782, 42.90719338825771, 44.45147221429007, 49.575056484767366, 48.27370057787214, 48.18170642852783, 50.72719635282244, 48.32415839603969, 39.80642427716936, 36.660165309906006, 38.98552588054112, 45.998398303985596, 47.307338169642854, 54.86208323069981, 43.406616006578716, 23.72219569342477, 6.961923888751438, 11.604836123330251, 9.543829321861267, 2.8942330394472395, 3.196783878973552, 0.4114222718136651, 0.012595269812404044, 1.654141787971769, 18.225805827549525, 47.38083274023873, 41.84850331715175, 36.124028410230366, 40.73210845674787, 49.42589603151594, 50.86230060032436, 22.96357226371765, 2.098193560327802, 0.15081489804599965, 0.07585239157612834, 0.0033673820642954005, 0.031717077895466766, 0.005639989012187081, 0.0745193688198924, 0.040984834876975844, 0.044801088848284314, 0.03357978205063513, 0.04566879943013191, 0.02278606596935008, 0.08054154352950198, 0.04523987369611859, 0.03608989682314651, 0.045232375884162526, 0.04962729469739965, 0.03876369459820645, 0.15409955036427292, 0.16270292656762259, 0.1973297085080828, 0.11065175211323158, 0.12303081607179982, 0.11512367108038493, 0.1309425343892404, 0.07454618452382938, 0.16880668832787446, 0.10605931854141609, 0.15691373364201613, 0.1383793731885297, 0.1664157887654645, 0.08969477737056357, 0.06453813226627451, 0.14441483361380442, 0.10336181614547968, 0.10896865957017456, 0.13745258934795856, 0.32054292836359566, 8.210972019604274, 44.840463638305664, 60.254062516348704, 53.11371496745518, 37.285468442099436, 38.94282920019967, 40.342547280447825, 45.15819433757237, 26.38490867614746, 2.4911969176360538, 0.38484975482736317, 0.78618052814688, 4.399951534611838, 11.42211673940931, 9.067620635032654, 7.59514536176409, 9.066868492535182, 21.12751599720546, 28.6610221522195, 45.52938447679792, 49.725300856998985, 47.978502886635916, 45.98812191826956, 40.0634902545384, 38.34712191990444, 43.73752743857247, 49.16674212047032, 49.11104188646589, 45.733671937670024, 46.352680001940044, 49.34244816643851, 47.600062302180696, 46.648020131247385, 43.25308861051287, 33.85995442526681, 33.46468530382429, 35.33169058391026, 33.65683078765869, 34.4335629599435, 34.47251456124442, 36.44820008959089, 33.36965479169573, 32.82452344894409, 34.63236829212734, 37.77282203946795, 42.48930440630232, 43.915116446358816, 40.191125188555034, 35.474635873522075, 35.06245136260986, 38.58000816617693, 36.8171146937779, 38.267617157527376, 38.3534517288208, 37.749007088797434, 35.62360872541155, 36.36419289452689, 34.08808462960379, 34.87735135214669, 34.33213663101196, 35.09893635341099, 36.17085926873343, 37.37083748408726, 42.095855712890625, 42.182798521859304, 44.78114686693464, 47.122776644570486, 48.0147933278765, 45.99409736905779, 36.17669228145054, 49.56112882069179, 47.95043216432844, 48.41878938674927, 46.95909445626395, 46.83284568786621, 42.849297523498535, 38.81134843826294, 36.28254461288452, 34.70833989552089, 40.059203216007774, 35.989156927381245, 35.29755061013358, 36.32492167609078, 37.162214347294395, 35.48890399932861, 38.78346879141671, 39.408170904432026, 46.78263800484793, 45.65189511435372, 43.639894826071604, 39.215056146894185, 37.939161913735525, 34.62871701376778, 36.02497836521694, 34.31926161902291, 36.60524327414376, 35.88684817722866, 39.40768453053066, 44.39120701381138, 45.440992968423025, 42.28296722684588, 41.05837154388428, 39.32897533689226, 39.03208228519985, 39.356820242745535, 41.044228485652376, 41.19928795950753, 44.54755885260445, 46.605306080409456, 51.77230269568307, 50.305096762520925, 50.410031931740896, 52.60799380711147, 50.98870570319039, 42.32919011797224, 39.02464771270752, 40.864836420331685, 50.06953198569161, 49.129044669015066, 56.702435220990864, 45.47312491280692, 28.768510784421647, 13.724799258368355, 19.529399054391043, 28.105866295950754, 9.169893775667463, 8.150758062090192, 1.0701972650630134, 0.25133797473141123, 1.8855934483664376, 22.19128520148141, 52.59876659938267, 51.397892066410606, 40.830717291150776, 48.06473003114973, 55.954576287950786, 58.2503479548863, 27.305793387549265, 3.1085130955491747, 0.181056158883231, 0.08358662548874106, 0.14810503274202347, 0.20630246560488427, 0.1583024098404816, 0.28461468911596705, 0.18106625548430852, 0.12816154504460947, 0.10182120917098862, 0.15308902173170022, 0.08433222690863268, 0.19021057337522507, 0.21509846432932786, 0.22378124270055974, 0.1546696147748402, 0.17132418895406382, 0.12382235431245395], [0.06511044262775353, 0.054160984099975655, 0.009742343881433564, 0.025295961914317946, 0.07957356582794871, 0.005492845300718078, 0.0650443397462368, 0.04587132856249809, 0.04433286915134106, 0.030891650223306248, 0.03332402523873108, 0.12568223236926965, 0.01762032967859081, 0.07778626387672764, 0.05905145739338227, 0.051141900209976096, 0.01377838128246367, 0.03730970261884587, 0.0197093099954405, 0.1006807071555938, 3.664865561894008, 30.392862388065883, 46.73426464625767, 38.37951442173549, 23.739347321646555, 23.370931250708445, 27.87151919092451, 36.477993965148926, 22.319873775754655, 3.5573890890393938, 0.0663805448317102, 0.39603836302246365, 0.5555643343499729, 4.334609372275216, 3.971676298550197, 1.7204307509320123, 6.958684725420816, 13.820911083902631, 24.538411004202707, 35.805185999189106, 49.114106042044504, 45.82109417234148, 41.81491225106375, 38.15616805212838, 39.3701434135437, 42.12768888473511, 46.013875416346956, 44.33407545089722, 42.993747098105295, 47.05871425356184, 44.529014110565186, 42.800667081560405, 39.47202484948294, 34.350250584738596, 31.425100667136057, 31.02589191709246, 30.13273572921753, 31.278584003448486, 31.896070412227086, 32.373686109270366, 31.338310718536377, 31.81676367350987, 31.552346502031597, 31.60165786743164, 36.139383929116384, 41.82297216142927, 44.75847142083304, 42.59854398454939, 37.10559000287737, 32.50164760862078, 31.202483858380997, 31.929105622427805, 33.34471075875418, 33.56078583853585, 32.975466115134104, 32.08668034417288, 31.839321000235422, 31.386003153664724, 31.2930223601205, 31.92513472693307, 31.440720217568533, 32.28123337881905, 33.59477642604283, 35.90212379183088, 37.14897802897862, 40.03657293319702, 41.50024223327637, 45.34029620034354, 42.810005460466655, 32.28778900418963, 33.77881683622088, 41.97294207981655, 45.502786772591726, 44.21244723456246, 44.9659481048584, 43.61087914875576, 39.93573372704642, 36.645337854112896, 35.200032642909456, 37.00359392166138, 31.75797496523176, 32.46622569220406, 31.610006128038677, 34.09879527773176, 32.50674063818795, 38.78330203465053, 42.277273178100586, 45.066575390951975, 43.99588925497872, 40.90951681137085, 37.19551706314087, 34.28692470278059, 32.13198954718453, 33.32629108428955, 32.456571170261924, 33.26165199279785, 31.901597704206193, 32.57140752247402, 32.779231616428916, 33.83270011629377, 34.12423958097185, 33.18277604239327, 33.52959190096174, 32.830811568668906, 33.29400975363595, 34.03610168184553, 34.454164368765696, 39.44292231968471, 41.305112498147146, 43.42198889596121, 47.47108636583601, 46.05093363353184, 49.04987689426967, 47.14522974831717, 43.400921957833425, 37.447872161865234, 35.455375467027935, 41.36860166277204, 46.88645798819405, 51.014754499707905, 43.28217376981463, 22.40159501348223, 7.276867491858346, 10.132345216614858, 6.2493930714471, 2.6291284305708746, 2.0930416882038116, 0.22095703067524092, 0.06795019989034959, 0.8559733373778207, 21.47594210079738, 40.483564444950645, 39.052520411355154, 30.513986860002788, 33.749113287244526, 49.950613566807334, 43.17745746885027, 17.82139461381095, 1.4456146231719424, 0.056201247298823934, 0.0307993491047195, 0.035570257742490084, 0.06759780272841454, 0.011427575506136885, 0.04328658850863576, 0.059977264143526554, 0.03050421012033309, 0.03634717355349234, 0.044370646588504314, 0.061235403775104454, 0.012319894008604544, 0.04600254027172923, 0.030932216439396143, 0.03928996975134526, 0.08089894827987466, 0.013026989414356649, 0.04432407533749938, 0.017563035877953683, 0.04714135952027781, 0.02524839830584824, 0.0896146898823125, 0.03561178069295628, 0.03935040347278118, 0.022385233281446353, 0.06070512865803071, 0.012766387862419444, 0.053381846086787324, 0.07269472708659512, 0.05136488378047943, 0.06150890767042126, 0.08751028816082648, 0.04129630959193621, 0.03291371850562947, 0.04703419169943247, 0.019911832342456495, 0.10716653841414622, 5.387890270778111, 35.25019516263689, 52.82329068865095, 44.04112550190517, 27.70135085923331, 28.168872560773575, 33.32205268314907, 40.21716356277466, 24.977677856172832, 4.028135623250689, 0.25325749601636616, 0.1525920626840421, 1.2069101291043418, 2.3483445601803914, 5.835580945014954, 3.957943618297577, 6.4151458229337415, 14.58406560761588, 26.73563984462193, 39.63540826525007, 50.79638304029192, 48.61984246117728, 43.76857893807547, 39.357626233782085, 40.551027979169575, 43.53499787194388, 48.53900711877005, 44.90082958766392, 44.09378589902605, 49.173606940678184, 46.77567938395909, 44.5716586794172, 40.955329758780344, 37.644037178584504, 32.17857721873692, 32.258589199611116, 32.28708723613194, 32.51363672528948, 33.12348358971732, 34.13840695789882, 33.38599348068237, 33.3099558694022, 33.15560858590262, 33.90819576808384, 37.110738618033274, 43.799085003989084, 44.66663013185774, 43.373730182647705, 38.78400380270821, 33.46001264027187, 32.685754026685444, 34.670364516122, 35.7907372202192, 35.91985559463501, 34.607778617313926, 33.33748115812029, 33.74321774074009, 32.83347967692784, 32.87372016906738, 32.78213248934065, 32.89958136422293, 32.951626845768516, 35.8769713129316, 37.48115055901663, 39.27279567718506, 41.180378437042236, 43.112314632960725, 46.550828729357036, 45.41861629486084, 35.85574804033552, 35.40387541907174, 42.48118543624878, 46.67189414160592, 46.75551918574742, 45.940172399793354, 43.97010449000767, 40.858506611415315, 37.973256724221365, 35.67397969109671, 38.1958144732884, 32.84690012250628, 33.38836976460048, 32.94562360218593, 35.33245835985456, 34.91452074050903, 39.87325552531651, 44.60994325365339, 45.568749495915, 45.09472254344395, 43.58816548756191, 38.746292454855784, 35.985140868595664, 34.784780502319336, 35.00250925336565, 33.17009210586548, 34.93681056158883, 34.41545595441546, 34.526210239955354, 35.645262786320274, 35.937396321977886, 35.83839838845389, 35.11027928761074, 35.81346130371094, 34.024682317461284, 35.75498526436942, 35.62580435616629, 35.90062992913382, 39.76301540647234, 43.84542601449149, 46.09425217764718, 49.081039564950125, 47.38192013331822, 50.825165952954976, 49.84020669119698, 45.18578563417707, 38.29174130303519, 38.794349670410156, 43.0987309047154, 49.61320556913103, 52.064349378858296, 47.189052036830354, 20.839707715170725, 5.7633205481937955, 5.957433240754264, 10.078933545521327, 6.043878819261279, 1.941280654498509, 0.4126000186162335, 0.0430824410702501, 1.6755458222968238, 23.160034315926687, 47.19525677817208, 43.33852366038731, 33.40669216428484, 40.187206404549734, 54.347336360386436, 48.55614137649536, 21.457199335098267, 1.8478243436132158, 0.041433668828436306, 0.018978229224947945, 0.011478346888907254, 0.027441077433260422, 0.018667889359806265, 0.024476742837578058, 0.046246721276215146, 0.009944832301698625, 0.046031320334545205, 0.0535273477435112, 0.05850382535053151, 0.05723391992173024, 0.04103666816705039, 0.028910321183502674, 0.051430440441306145, 0.08172641494976622, 0.05045410318832312, 0.22343855537474155, 0.15019734975482735, 0.14328887260385922, 0.0852516418589013, 0.16627195291221142, 0.17611651894237312, 0.14056333314095223, 0.16365309272493633, 0.1253888202565057, 0.06592340900429658, 0.1478112813617502, 0.15756675574396337, 0.07789137573646647, 0.16163031198084354, 0.15774945808308466, 0.13150187794651302, 0.16325769679886953, 0.15970381535589695, 0.056171859947166274, 0.22857673466205597, 6.1036407096045355, 39.37694569996425, 59.591037614004954, 50.10526309694563, 33.487704685756135, 31.70231989451817, 37.199672085898264, 46.956186635153635, 29.797422613416398, 5.117419915539878, 0.28635092452168465, 1.1145110300609042, 4.521780380180903, 11.610088961465017, 12.296216624123709, 5.51467969587871, 12.005756735801697, 16.629373822893413, 29.156294958932058, 40.79973527363369, 54.753114632197786, 51.36119515555245, 45.813103743961875, 41.496260915483745, 43.12174333844866, 46.576054164341514, 49.61034985951015, 45.4599163872855, 45.29425743647984, 50.82749012538365, 47.89677817480904, 47.63724558694022, 43.191360814230784, 37.901575633457725, 33.95178529194423, 34.27765233176095, 33.919851371220176, 35.02626861844744, 34.33019460950579, 36.098233222961426, 34.232638427189414, 35.81821387154715, 35.00036226000105, 35.881914956229075, 38.768665654318674, 45.9710293497358, 48.093950680324006, 47.056216376168386, 40.194359574999126, 36.10268007005964, 33.667749881744385, 35.52446140561785, 37.93032727922712, 37.80134439468384, 35.78598812648228, 36.32327842712402, 34.96878964560372, 35.278700147356304, 34.1801552091326, 37.1303151675633, 35.07231085641043, 34.64706373214722, 38.14345632280622, 39.74459573200771, 41.243815490177695, 43.04944038391113, 45.75839015415737, 49.5042439188276, 46.185183252607075, 40.524638720921104, 36.3771721294948, 43.073366505759104, 48.48296989713396, 48.48740632193429, 49.0121169090271, 47.55753585270473, 43.114030838012695, 40.50394698551723, 38.248158727373394, 39.30685574667794, 33.80802011489868, 35.83484785897391, 34.46635845729283, 38.00932829720633, 36.698932783944265, 42.00489337103707, 46.59527635574341, 47.5077554838998, 46.548580987112864, 45.69449799401419, 41.00519003186907, 36.683882985796245, 35.915186405181885, 36.940108231135774, 35.859524386269705, 37.52108185631888, 35.734112875802175, 36.98287091936384, 36.28930173601423, 37.29998670305525, 36.748678411756245, 36.15988111495972, 38.34121247700283, 35.54505934034075, 38.007125718253, 37.17255326679775, 37.62878588267735, 42.66612216404506, 46.7796676499503, 47.88104050500052, 51.050110408238, 49.27323021207537, 51.55967044830322, 53.225563594273154, 47.5848457472665, 42.37506907326834, 40.11378131593977, 45.57703522273472, 51.41966424669538, 55.680726936885286, 47.413662978581016, 26.05958706992013, 11.595865998949323, 16.224123614174978, 17.884552001953125, 7.827167425836835, 5.446076222828456, 0.5436482280492783, 0.6544183641672134, 1.842999905347824, 28.613142115729197, 50.67308725629534, 51.07730565752302, 40.45590019226074, 45.85991375786917, 62.61201013837542, 56.42492069516863, 25.802903243473597, 2.368600078991481, 0.18700326047837734, 0.10392097649829728, 0.11614200286567211, 0.1382396492574896, 0.14901572173195227, 0.10757859916027103, 0.10931287359978471, 0.07450697877045188, 0.200130538216659, 0.09181519930383988, 0.1680734905281237, 0.16208051996571676, 0.1089834448482309, 0.16098612440483911, 0.14284004883042403, 0.1930706799030304, 0.15174648591450282], [0.022240464442542622, 0.08533353425030198, 0.056764478861753426, 0.0382143458617585, 0.05379147767754538, 0.01857555770714368, 0.024053545635459677, 0.04053109511733055, 0.014239735901355743, 0.07588538194873504, 0.03085411705874971, 0.03140430717862078, 0.0402925527388496, 0.059542540327778885, 0.038488104207707305, 0.026034562549154674, 0.020624916667916944, 0.057884967486773214, 0.023915319570473263, 0.03508909838274121, 1.6285080377544676, 20.670762266431534, 40.64109747750418, 45.46977935518537, 29.125163555145264, 26.721885885511124, 39.874582631247385, 36.244833265032085, 26.679437603269303, 5.588721437113626, 0.23263469977038248, 0.06253064570150205, 0.5179798454046249, 0.3519854268857411, 2.578647379364286, 4.523778855800629, 3.5901554908071245, 9.214502947671072, 19.552746738706315, 34.78003140858242, 42.03221368789673, 45.59572587694441, 42.59032079151699, 41.68173265457153, 43.083038398197715, 46.845213481358115, 44.26688289642334, 44.75338881356375, 45.87261506489345, 42.857975823538645, 42.20413643973214, 37.544882910592214, 33.866642066410606, 30.87742280960083, 30.489550045558385, 31.104868616376603, 33.47301966803414, 39.24821295057024, 39.72637755530221, 38.98966700690133, 35.7603805405753, 31.416154861450195, 31.429307801382883, 31.84713772365025, 38.24134949275425, 44.417012623378206, 43.82001992634365, 46.31281818662371, 41.994821957179475, 36.08119624001639, 30.230208533150808, 33.22004270553589, 31.40835898263114, 31.79615879058838, 31.673731531415665, 32.24386944089617, 30.591396740504674, 30.72710200718471, 31.812285559517996, 31.5715617452349, 30.51041201182774, 32.100170271737234, 32.559585162571494, 34.02226781845093, 31.987831796918595, 38.71660280227661, 40.07239784513201, 45.94506393160139, 42.3382887840271, 33.62095376423427, 34.46740763528006, 41.6173471723284, 44.94572189876011, 44.19717509405953, 45.98972347804478, 46.365322249276296, 42.03406885692051, 37.24436984743391, 34.235177993774414, 33.80200644901821, 31.09806980405535, 31.6057607786996, 32.133476461683, 34.2134370803833, 33.793119703020366, 39.86468144825527, 43.900990758623394, 46.48219442367554, 44.747663497924805, 44.54752063751221, 38.58314527784075, 34.2524790082659, 33.98253801890782, 32.69348042351859, 32.013286522456575, 32.185178007398335, 31.84944452558245, 31.57106147493635, 33.50834430967058, 31.28365966251918, 33.259925365448, 31.108804770878383, 32.43997539792742, 31.751961299351283, 31.54233067376273, 32.890375001089915, 33.83238397325788, 34.75218997682844, 41.320203985486714, 43.04590722492763, 47.54605048043387, 48.557249614170615, 48.22851644243513, 48.94365978240967, 46.99760832105364, 41.248505524226594, 37.26899773733956, 41.311952999659944, 46.729268891470774, 49.851236956460134, 46.3421882220677, 21.274545090539114, 4.296913657869611, 6.736054454530988, 4.013745469706399, 1.7618610135146549, 2.08665303673063, 0.4687499042068209, 0.032952975149133375, 2.0766250491142273, 23.372913224356516, 42.62461709976196, 35.07726839610508, 29.99870845249721, 32.18000159944807, 48.563509941101074, 40.88763345990862, 17.143528359276907, 0.8810784816741943, 0.014184435297335898, 0.04382189835554787, 0.036205699002104144, 0.05149265192449093, 0.023198080914361135, 0.0013482567155733705, 0.0279617444944701, 0.048889618566525836, 0.05764009776924338, 0.01257509018094944, 0.05925182878438916, 0.03190064536673682, 0.010744384889091765, 0.03819388463827116, 0.009700122039898165, 0.033219371390129836, 0.1150165575423411, 0.013638772702376758, 0.09759584947356156, 0.0356727674204324, 0.04794926063290664, 0.04185991434912596, 0.024699100459526693, 0.027976969123951027, 0.03568229065941913, 0.010169782775587268, 0.04543041990005544, 0.0213707810201283, 0.06606425930346761, 0.037071394334946356, 0.03948745397584779, 0.019904229357572537, 0.08353756740689278, 0.0019271556520834565, 0.047518163586833646, 0.07319057333682265, 0.02940778573974967, 2.158115476369858, 26.366494212831768, 48.185208320617676, 51.04179688862392, 34.0379672731672, 28.9172717162541, 40.296070780072895, 43.72760888508388, 30.897280761173793, 6.425674515111106, 0.16238786918776377, 0.017176935881642357, 0.6430797725915909, 2.42931495819773, 5.359854289463588, 5.394669541290828, 3.737816001687731, 12.091586095946175, 21.110324416841777, 36.03549098968506, 45.232230867658345, 47.861349310193745, 43.83660527638027, 43.95115327835083, 44.011112758091514, 47.845382349831716, 45.25282532828194, 45.68946055003575, 48.42827715192522, 45.40131180627005, 44.11215346200125, 39.8791059085301, 34.79194756916591, 33.26364265169416, 31.45136833190918, 32.695641313280376, 34.38061421258109, 40.27428470339094, 40.84059068134853, 40.648681436266216, 36.584822518484934, 34.06593377249581, 32.68205411093575, 34.43574816840035, 39.68314586366926, 44.606524739946636, 45.7861864226205, 48.243673937661306, 43.4070155279977, 37.227746282305034, 31.43189947945731, 34.23830468314034, 33.5360016141619, 33.78873191561018, 33.53386156899588, 33.80035277775356, 32.419099535260884, 33.10503612245832, 32.58874675205776, 33.876522404806956, 32.37192474092756, 33.637681552342, 34.43169042042324, 36.484143120901926, 34.60160166876656, 39.49054527282715, 41.510126045772004, 48.34201526641846, 44.383105414254324, 35.57127141952515, 35.130651405879426, 41.582449844905305, 44.45336559840611, 45.16972834723336, 46.72158418382917, 47.347856589726035, 44.26388127463204, 38.410291467394146, 35.58986827305385, 33.970427308763774, 32.56556756155831, 33.57960850851876, 33.92718172073364, 34.53228643962315, 35.953714166368755, 41.71142578125, 46.77092681612287, 48.40950311933245, 47.21654953275408, 46.63999496187483, 41.02620833260672, 34.453382696424214, 34.974660873413086, 35.35570355824062, 34.62670203617641, 34.0070686340332, 32.72963884898594, 32.47084971836635, 34.369337286267964, 33.29045575005667, 35.02865879876273, 33.831501552036826, 33.342758314950125, 33.393959590366904, 33.280624049050466, 34.21791866847447, 35.464620045253206, 36.70414045878819, 43.389825684683665, 45.774214676448274, 49.23381655556815, 49.83356073924473, 48.704315185546875, 51.330199241638184, 49.71416984285627, 42.54573767525809, 40.05154282706124, 42.84866176332746, 48.50067390714373, 50.8581143106733, 48.09135205405099, 22.751513242721558, 4.91629866191319, 6.626934732709612, 8.208764229501996, 7.960166369165693, 1.4812836349010468, 0.30648552839245113, 0.12171065833951746, 2.0977321565151215, 26.938433442796978, 44.769032682691304, 39.60195616313389, 34.07965299061367, 37.70588656834194, 55.218584878104075, 49.01020268031529, 20.17467130933489, 1.1283783316612244, 0.010512006153086466, 0.013182908279954322, 0.054754312083657296, 0.0485603017732501, 0.08718569057860545, 0.02861785901976483, 0.004822206309264792, 0.0134091352478468, 0.048957353324762413, 0.0007440140190218309, 0.03641684552920716, 0.029158407157020907, 0.05630895794768419, 0.030355590595198528, 0.02438488955210362, 0.01908186696735876, 0.02267892868258059, 0.09646082323576723, 0.15774766675063542, 0.1443044359662703, 0.16499942833823816, 0.20705554448068142, 0.1351254042237997, 0.1810805590025016, 0.09286608719932181, 0.09968236501195601, 0.10843681703720774, 0.09677047947687761, 0.14112692432744162, 0.1749498594020094, 0.17415216006338596, 0.14966867598039763, 0.20103232482714312, 0.05950114969164133, 0.1279283325587, 0.11957482009061746, 0.13950777692454203, 2.5029450186661313, 30.46674953188215, 53.84275470461164, 57.67335912159511, 39.61810030255999, 35.64054148537772, 48.472846371786936, 47.6248847416469, 35.525934423719136, 8.218410066195897, 0.6821405366063118, 0.07002158409782819, 2.1600822508335114, 5.5307656441416055, 9.905893870762416, 11.554657101631165, 7.17914194720132, 12.544844014304024, 21.589821338653564, 38.82737793241228, 46.816176959446494, 50.866743973323274, 46.56343623570034, 46.550561223711284, 46.01960073198591, 49.749911376408164, 46.714938231876914, 46.51009838921683, 49.29744121006557, 47.07556710924421, 46.873836585453574, 40.541825090135845, 37.295473848070415, 34.49682630811419, 32.76231622695923, 34.45090218952724, 36.636308670043945, 43.795954840523855, 43.5125412940979, 42.91705635615757, 40.11147798810686, 34.55174139567784, 34.46472215652466, 35.78528635842459, 42.55019841875349, 48.20007399150303, 46.80852004459926, 51.011992590767996, 46.511349064963206, 40.53338997704642, 33.402332169669016, 36.407591342926025, 34.58287279946463, 35.20420503616333, 35.83714076450893, 35.7867420060294, 34.900714669908794, 34.875944341932026, 34.38395282200405, 34.61785697937012, 34.481224128178184, 35.35901437486921, 36.646255016326904, 38.74949557440621, 35.154900618961875, 43.01401846749442, 44.17541333607265, 49.10115807397025, 46.50555426733834, 37.22040898459298, 36.17973211833409, 41.25837196622576, 45.810300145830425, 46.60333626610892, 47.79065833772932, 51.09335252216884, 44.33179644175938, 40.00739744731358, 37.907648359026226, 37.12791109085083, 33.27947064808437, 35.74266610826765, 35.51247576304844, 36.369706290108816, 37.02456358500889, 44.4974171774728, 47.81150640760149, 50.9843943459647, 49.2890408379691, 49.49484300613403, 43.34453732626778, 37.550587381635395, 37.281983920506065, 36.094665322984966, 35.34358589989798, 35.655837944575715, 34.87954350880214, 33.86421367100307, 37.45463623319353, 34.494029658181326, 37.549847398485454, 34.42927939551217, 34.771144662584575, 34.64167887823922, 34.67070845195225, 35.894588470458984, 38.365263666425435, 38.343460219247, 45.22490399224417, 47.56266014916556, 51.99235214505877, 50.15468910762242, 50.30756337302071, 53.20831816537039, 51.31759173529488, 44.33111899239676, 42.5968451499939, 45.2713075365339, 51.94247450147356, 52.572231428963796, 50.99129043306623, 25.216855696269445, 7.045089483261108, 13.599365166255406, 12.141633970396859, 8.753057445798602, 5.3319273080144605, 1.4301291512591499, 0.22249202616512775, 3.1378384019647325, 30.746789727892192, 54.297625473567415, 44.66837412970406, 42.5633339881897, 43.74837357657296, 62.13296658652169, 55.72222852706909, 23.34946652821132, 1.4737830545221056, 0.11026464109974247, 0.10090287987674985, 0.15455096614147934, 0.13959909416735172, 0.18459532968699932, 0.1284206368561302, 0.11109596184853997, 0.1096553166529962, 0.11522922398788588, 0.09638657114867653, 0.1479074026324919, 0.13796823525003024, 0.12868312134274415, 0.15259109916431562, 0.10583699654255595, 0.11908137585435595, 0.2384708066071783], [0.05214543993185673, 0.006750995534405644, 0.04244282003492117, 0.034913401917687485, 0.036889224645814726, 0.019731445504086356, 0.03748669508578522, 0.03973395557009748, 0.04380327596196106, 0.017468181771359274, 0.050004041088478904, 0.018684060545638204, 0.06182378184582506, 0.06937959497528416, 0.03619644378444978, 0.039049306950931034, 0.03796866190220628, 0.03649261753473963, 0.03914981834324343, 0.0547074219211936, 0.323546612901347, 17.025659118379863, 42.81874629429409, 41.92988756724766, 29.333665098462784, 25.981854098183767, 28.73232282911028, 36.21498032978603, 34.18477576119559, 9.287129861967903, 0.5953511308346475, 0.05537724455020257, 0.23514180524008615, 1.271601332085473, 3.799965466771807, 2.162148037127086, 0.15413051870252403, 4.040979368346078, 11.619498559406825, 26.300097227096558, 43.30341788700649, 45.31748526436942, 43.81386729649135, 43.624348231724326, 47.438669545309885, 46.1652558190482, 45.34613616125924, 47.59667158126831, 43.960102558135986, 41.82490028653826, 35.64705542155674, 32.30313062667847, 31.715511049543107, 30.458126817430767, 33.84886857441494, 37.65087768009731, 42.004393100738525, 41.95146172387259, 44.50453560692923, 42.569729804992676, 39.524094649723594, 35.84056275231497, 33.25072595051357, 33.70421750204903, 40.271561009543284, 42.6554844720023, 46.979320662362234, 44.99398756027222, 43.06125579561506, 37.354745456150596, 31.800206116267614, 31.40890094212123, 32.47070033209664, 31.622974940708705, 32.160265241350444, 32.03545127596174, 30.279808248792374, 31.768432004111155, 31.00520712988717, 30.754658562796457, 30.88701479775565, 31.5787079674857, 32.13170467104231, 33.06743941988264, 33.49802623476301, 36.54691662107195, 42.943487303597585, 44.13032994951521, 46.277003696986604, 32.718038831438335, 42.755826881953645, 47.719908305576865, 45.04615463529314, 46.32213919503348, 44.12720326014927, 43.54142495564052, 41.79218121937343, 36.47912999561855, 32.05075120925903, 33.34960229056222, 31.83390835353306, 31.871932370322092, 32.262507983616416, 33.247599261147634, 34.83800022942679, 41.39063440050398, 46.1132242338998, 46.77773952484131, 46.55649845940726, 43.08049883161272, 41.17896100452968, 34.98644849232265, 34.51897716522217, 33.5694363457816, 36.5803131375994, 35.33052676064627, 35.317811557224815, 32.64091730117798, 32.217615672520225, 33.15050860813686, 32.25446196964809, 31.21411861692156, 33.03923320770264, 32.98570775985718, 32.42919874191284, 32.5150055204119, 34.07449047906058, 33.654906136649, 37.721481800079346, 44.19121701376778, 45.465252603803364, 48.577489716666086, 48.474628584725515, 49.88873291015625, 49.402334690093994, 45.79006699153355, 43.14579800197056, 40.36550065449306, 47.37924855095999, 49.45902156829834, 41.647210529872346, 21.451583453587123, 5.671246060303279, 3.8642693076814925, 7.621487719672067, 12.016749654497419, 0.7310075429933411, 0.16817928770823137, 0.05600932027612414, 2.3790658031191145, 22.52421682221549, 39.72039515631539, 36.16318498338972, 26.45827991621835, 30.85058191844395, 46.10081475121634, 39.92020797729492, 11.128934894289289, 0.5909347363880703, 0.027470001684767858, 0.031045443577958003, 0.020836879133379886, 0.0336783969375704, 0.028199235143672143, 0.030264269959713732, 0.027862160998795713, 0.016523810303104774, 0.02729578103337969, 0.037645404426647086, 0.09050954186490603, 0.016014690211574947, 0.01586816566331046, 0.008808722952380776, 0.08963797720415251, 0.02619126851537398, 0.018209820546741997, 0.09791511377053601, 0.01813582969563348, 0.02799866528117231, 0.013805279258771666, 0.040694605093449354, 0.04300341548930321, 0.06570137877549444, 0.014621489880872625, 0.009334109224645155, 0.014862454629370143, 0.005734633197010095, 0.049046231234180074, 0.04685554699972272, 0.0580026526004076, 0.011254544835537672, 0.050069763990385194, 0.01796149369329214, 0.01711367436551622, 0.01418283480286066, 0.05229830030085785, 0.8488732555082866, 20.882538148335048, 48.40694618225098, 47.85116672515869, 33.937002999441965, 29.876691137041362, 40.232869965689524, 42.97130789075579, 37.94299731935774, 9.249546187264578, 0.6471384433763367, 0.05347648136583822, 0.20051080281180994, 0.8905819345797811, 5.840013895715986, 5.667299483503614, 2.553406310932977, 6.1780155301094055, 12.289770432880946, 29.427417142050608, 43.38813727242606, 47.72097485406058, 45.658631392887656, 45.529214245932444, 48.068926743098665, 47.5715468951634, 45.67670018332345, 49.387920652117046, 45.24167694364275, 44.06341184888567, 38.63945695332119, 33.66461624417986, 32.97813769749233, 31.226819923945836, 35.17399774278913, 38.202335357666016, 43.61525303976876, 43.4852557182312, 46.51026862008231, 44.59673820223127, 41.144362449645996, 36.64090142931257, 33.57561329432896, 34.763890743255615, 42.58974756513323, 45.07515294211251, 47.032429218292236, 47.007380962371826, 44.93208605902535, 39.877094405038015, 32.79697036743164, 32.864347049168174, 34.447507994515554, 33.72328335898263, 33.212330205099924, 34.15027795519148, 32.435511180332725, 33.54513502120972, 33.01770074026925, 31.995495659964426, 32.65999010631016, 33.427550656454905, 33.983316217150005, 34.35661513464791, 34.546276637486045, 38.41805607931954, 44.783825397491455, 45.81574405942644, 46.466310841696604, 34.97782230377197, 41.539086137499126, 47.220756667000906, 46.66687406812395, 47.21648352486746, 46.23279578345162, 46.398301873888286, 45.29066869190761, 37.82419701984951, 33.61894226074219, 34.9432168006897, 34.453177724565776, 33.312676089150564, 34.194934027535574, 34.699105739593506, 36.74208457129342, 43.30038847242083, 48.34975208554949, 49.90987627846854, 48.41277919496809, 44.991482734680176, 42.305739947727744, 36.88361937659127, 35.41870634896414, 34.969171796526226, 36.93321909223284, 36.96788018090384, 36.644917488098145, 34.79239920207432, 34.67233780452183, 35.377941267830984, 34.208201612745015, 32.49182980401175, 35.19656549181257, 33.70614562715803, 33.93410907472883, 35.11192601067679, 35.95287343433925, 36.55965614318848, 39.35842180252075, 45.22589063644409, 48.116504532950266, 50.358493668692454, 49.081974097660606, 50.6473684992109, 51.410412720271516, 47.638968740190776, 42.12322814123971, 43.02970402581351, 48.694848264966694, 51.22978734970093, 45.398622853415354, 23.386430944715226, 5.178239234856196, 6.244610105242048, 10.322396687098912, 11.645586439541407, 2.0844207108020782, 0.22283389924892358, 0.09889843314886093, 2.8960276288645606, 26.449964659554617, 46.943509646824424, 40.02889517375401, 31.6780880519322, 35.049135140010286, 51.88670131138393, 45.96346970966884, 15.20556286403111, 0.8013124561735562, 0.07105566468089819, 0.02040685247629881, 0.007299556746147573, 0.021370831910254698, 0.03360050790277975, 0.020112765221191303, 0.05937946800674711, 0.018270564697948948, 0.01931141536416752, 0.008569438426223184, 0.08819114376923867, 0.06315001925187451, 0.027801681476246034, 0.0024959266052714413, 0.04198697342404297, 0.044313646254262755, 0.01463799863787634, 0.13851228462798254, 0.0753497803317649, 0.08667958487889596, 0.11242066576544728, 0.12883265689015388, 0.10077434498816729, 0.1511821619101933, 0.11562760546803474, 0.10519656805055481, 0.052107730348195345, 0.11235592673931803, 0.12421757381941591, 0.17975468800536223, 0.1822719443589449, 0.10824472377342836, 0.17778612220925943, 0.16359205171465874, 0.09297465280230556, 0.07841144568685975, 0.11997860270951476, 1.3060850245612008, 24.917430026190623, 54.05879851749965, 53.63719572339739, 39.56681912285941, 35.53307022367205, 38.12670421600342, 45.79863064629691, 43.16903625215803, 13.159571119717189, 1.1586237315620695, 0.2310774890439851, 1.3426735869475772, 5.746779058660779, 8.35157663481576, 6.08737758227757, 3.349523740155356, 6.0541829977716715, 13.972268904958453, 30.280992916652135, 46.32001304626465, 49.99244172232491, 47.86739076886858, 48.35268422535488, 50.43444095339094, 48.337658745901926, 46.93325063160488, 51.765434401375906, 47.9277080808367, 46.974046979631694, 39.497403144836426, 35.90794290815081, 34.836051259722026, 34.28361736025129, 37.50278377532959, 41.38995000294277, 45.33968823296683, 45.82544027056013, 47.64543056488037, 46.395289829799104, 43.79510021209717, 38.98731851577759, 36.16277156557356, 36.97961916242327, 46.2745475087847, 46.07449497495379, 50.761690684727256, 48.91730179105486, 47.255528926849365, 41.485800402505056, 33.868194988795686, 34.13529763902937, 35.508386748177664, 34.54408795492989, 35.257125990731375, 36.57337188720703, 33.49798107147217, 34.66983297892979, 35.35890667779105, 33.50477988379342, 35.6099659374782, 35.7997316632952, 35.149592195238384, 37.29693296977452, 36.4246734891619, 40.70567750930786, 48.17228467123849, 49.39386831011091, 50.37135478428432, 37.03934587751116, 43.66154541288103, 49.96612194606236, 48.216704504830496, 51.177741868155344, 47.62236949375698, 48.3362204687936, 47.502193450927734, 40.55400875636509, 35.23816088267735, 37.65268073763166, 35.88002504621233, 35.69875349317278, 36.496910435812815, 35.56443786621094, 38.5291508265904, 45.65071392059326, 50.909725529806956, 50.219929218292236, 50.88985368183681, 47.217265197208945, 44.967643465314595, 38.90448209217617, 37.87396696635655, 37.63501494271414, 40.822945731026785, 38.81165415900094, 39.718890871320454, 36.59253849302019, 35.20041479383196, 36.89746366228376, 35.72613286972046, 33.56184891292027, 38.06455257960728, 36.81798321860177, 35.96035664422171, 36.98808554240635, 39.2641521181379, 38.185124669756206, 41.360618182591026, 49.01437854766846, 50.1355676651001, 52.868186473846436, 50.03064291817801, 51.996441159929546, 53.37082610811506, 50.27842262813023, 46.98014054979597, 46.117952483040945, 51.50284113202776, 54.4537410736084, 46.016877038138254, 24.588808025632584, 8.669185740607125, 7.400728685515268, 15.746188299996511, 22.16718884876796, 1.8612916895321436, 0.9338407133306775, 0.20537280477583408, 3.7875564183507646, 30.104376656668528, 51.41197606495449, 45.908752645765034, 36.34146186283657, 44.54095458984375, 59.74230684552874, 53.51768323353359, 18.059938430786133, 1.0799946593386787, 0.1259035569216524, 0.07230845067117896, 0.12341591183628355, 0.090728545827525, 0.1328685696103743, 0.1117874433153442, 0.1432138266307967, 0.0802513612434268, 0.11179379440311875, 0.10839872408126082, 0.1504773133035217, 0.14470964350870677, 0.08755299515490021, 0.06631589401513338, 0.1312628707715443, 0.16628489936036722, 0.08544506505131721], [0.03800345039261239, 0.045385249823864014, 0.009497247702841247, 0.02800511136384947, 0.02972928580961057, 0.052238891167300086, 0.034973693146769486, 0.01956899743527174, 0.060346868953534534, 0.059371366298624446, 0.04882719334481018, 0.021410629685435976, 0.03204347698816231, 0.06944769274975572, 0.034100350724267106, 0.024254392000979612, 0.009857931473691548, 0.04065813044352191, 0.03909175270902259, 0.03556639687823398, 0.1731116808950901, 9.791771445955549, 35.07386030469622, 46.235269342150005, 39.169812951769146, 26.223878962653025, 23.539159297943115, 36.04712227412632, 36.26845714024135, 13.489343915666852, 1.2729840236050742, 0.03675565842006888, 0.25827062129974365, 1.3567191532679965, 6.753545241696494, 6.866317544664655, 3.4807517613683427, 3.543285765818187, 5.290707988398416, 16.434230191367014, 31.62833547592163, 46.86049257005964, 43.85488946097237, 46.80020652498518, 46.82889911106655, 46.92753921236311, 46.75096811567034, 42.33353969029018, 40.98712471553257, 36.84216642379761, 32.69925437654768, 30.919435092381068, 31.58679219654628, 36.49073348726545, 40.312388624463765, 42.45644637516567, 42.95232193810599, 45.99329137802124, 44.50180843898228, 43.72049740382603, 42.94902849197388, 38.531982217516216, 37.14632381711687, 39.87207085745675, 40.906261580330984, 43.985560757773264, 44.735219274248394, 46.219489983149934, 42.70377792630877, 39.93810306276594, 32.34492751530239, 32.50650439943586, 31.66429935182844, 33.69913142068045, 31.37729706083025, 31.30920124053955, 31.117920807429723, 32.013578346797395, 31.534402779170446, 30.54803303309849, 32.26085083825247, 32.39339467457363, 33.17172493253435, 33.78088045120239, 33.53678676060268, 36.49485724312918, 41.50353567940848, 45.40240614754813, 47.34653295789446, 38.84336573737008, 44.90928554534912, 44.62451710019793, 42.48725816181728, 41.80322538103376, 43.98510217666626, 41.893155915396555, 37.96293864931379, 33.05329288755144, 33.46262516294207, 32.741450786590576, 33.04678937367031, 33.393000738961355, 32.658329486846924, 33.296907152448384, 34.7646724155971, 43.46892745154244, 45.983209541865754, 46.931266920907156, 47.59602887289864, 44.83968196596418, 41.17802994591849, 36.42742150170462, 35.039727279118125, 38.183794089726035, 41.264601026262554, 43.24669279370989, 42.75551768711635, 41.00287280763899, 36.44768244879586, 35.38771390914917, 32.49811444963728, 32.14979083197457, 31.83196633202689, 32.74539736339024, 31.992914404187882, 32.35773304530552, 33.51543147223336, 33.97897011893136, 34.11247975485665, 40.14382880074637, 43.63473926271711, 47.54734631947109, 48.97853626523699, 48.49696356909615, 50.977098737444194, 52.385404791150776, 44.29218476159232, 42.98570455823626, 44.94159466879708, 51.98285048348563, 37.879522051130024, 18.385979175567627, 4.816124745777675, 6.6379150577953885, 9.503070320401873, 10.552896227155413, 1.7319162317684718, 0.10192509288234369, 0.06780584835048233, 3.4012367938246046, 22.410070078713552, 43.11000435692923, 38.498356410435264, 35.240217549460276, 38.15104028156826, 48.441124371119905, 38.73757593972342, 7.5065158775874545, 0.21357192338577338, 0.012069932733928519, 0.048644284052508216, 0.05752056704035827, 0.006380794037665639, 0.03354151946093355, 0.038549796611602814, 0.02485639675121222, 0.022688781011051366, 0.02103353724149721, 0.11437786609998771, 0.14377824563000882, 0.058254314453474114, 0.03646821741546903, 0.048254458898944516, 0.023222201137936542, 0.06589648473475661, 0.0763725225946733, 0.025211139947974255, 0.017683652262868624, 0.02818791548322354, 0.045239300334027836, 0.02114955655166081, 0.06679179133581263, 0.033511083772672076, 0.01434710219369403, 0.07633937615901232, 0.014910506783053279, 0.047516233154705594, 0.016083875338413885, 0.08977476986391203, 0.013723050992536758, 0.0316657026165298, 0.03911911802632468, 0.05051538847120745, 0.006573449637341712, 0.02048059057311288, 0.015642730885052254, 0.27234932727047373, 12.53027537890843, 41.849576813834055, 50.966193539755686, 41.60831798825945, 29.107122557503835, 23.845970903124126, 39.292181151253835, 40.30506869724819, 15.731553656714302, 1.1572681814432144, 0.025753945910504887, 0.31280141377023285, 1.3165514000824519, 4.305555045604706, 6.360020118100302, 4.483963072299957, 3.946987177644457, 6.816579299313681, 20.570044653756277, 36.36498498916626, 47.695718152182444, 46.580619130815776, 47.220464842660085, 48.555800914764404, 47.28799091066633, 48.70851884569441, 44.21339218957083, 44.32904495511736, 38.221748624529155, 34.68736675807408, 32.365546294621055, 33.282639026641846, 36.13119895117623, 40.22309037617275, 44.48412527356829, 45.105394976479666, 47.61746059145246, 45.542002405439106, 45.110283034188406, 43.9558606828962, 40.35708291190011, 38.09087930406843, 41.04422153745379, 42.40275069645473, 44.20830610820225, 46.362671511513845, 48.31076226915632, 44.77321202414376, 42.17264025551932, 34.066117899758474, 35.08588416235787, 32.40332017626081, 35.672277382441926, 33.201841899326865, 33.38753598076956, 32.2472254208156, 33.75282709939139, 32.97155775342669, 32.0288713318961, 33.619866371154785, 33.844279289245605, 36.40674366269793, 35.589843954358784, 36.310149805886404, 39.01210274015154, 43.742516245160786, 47.15862934929984, 48.9420234816415, 40.54997532708304, 44.811555658067974, 46.95856291907174, 43.71455669403076, 44.778954710279194, 44.1103504044669, 44.13591282708304, 39.51373141152518, 35.33563368661063, 33.84320231846401, 34.35430138451712, 34.38201427459717, 35.55672189167568, 33.07393251146589, 34.5578419140407, 37.01251540865217, 45.581582818712505, 47.42462376185826, 47.58482142857143, 48.27033417565482, 46.769710881369456, 43.75194495064871, 37.70429195676531, 35.611470222473145, 39.730577741350444, 42.315800939287456, 45.13456004006522, 43.69682489122663, 41.65776136943272, 37.05324574879238, 34.70166615077427, 33.66214615958077, 33.74973862511771, 33.334236349378315, 34.32665797642299, 33.559187752859934, 33.57984127317156, 34.819472857883994, 35.732250758579795, 36.97775704520089, 42.71300860813686, 45.923708643232075, 49.16172899518694, 51.560803004673545, 49.19927706037249, 52.35275173187256, 52.570859159742085, 47.202774729047505, 43.854882512773784, 48.07179634911673, 53.15454953057425, 41.67878314426967, 22.037340913500103, 4.7024535196168085, 5.114869492394583, 6.608631440571376, 8.876457452774048, 2.8232122446809496, 0.2694323052253042, 0.011383159451984932, 4.0091383797781805, 24.606414760862076, 47.77259649549212, 41.44086987631661, 37.378852231161936, 44.280803612300325, 55.96857690811157, 44.93032816478184, 10.430792927742004, 0.28887236065098215, 0.035702056384512355, 0.06098563503473997, 0.09068862082702772, 0.03925532714596816, 0.029648482466914823, 0.05225948131244097, 0.022205803177452514, 0.019370573439768383, 0.0405578260043902, 0.017900841144312705, 0.03171680308878422, 0.10749990266880818, 0.012035893176549246, 0.032620655838400126, 0.006176311996698911, 0.05811950311596904, 0.031640691815742424, 0.1509064052786146, 0.17187720856496266, 0.07486043444701604, 0.10845379398337432, 0.1349953833435263, 0.15290600726647036, 0.13349077265177453, 0.07950644514390401, 0.13639248694692338, 0.17482578248849936, 0.18052741725529942, 0.15877104683646134, 0.11259426894996848, 0.11662738610591207, 0.1502487827092409, 0.09676181458468948, 0.17213047854602337, 0.13004077492015703, 0.14788680230932577, 0.14173350749271257, 0.5348440461925098, 13.985458322933741, 47.43279831750052, 57.91201932089669, 50.51921592439924, 37.73534345626831, 31.5411216872079, 43.996862002781455, 47.47248990195138, 19.226344687598093, 1.8489158621856143, 0.1003259215503931, 0.8342525629060609, 4.084003482546125, 13.931410891669136, 14.548553364617483, 4.706727530275073, 5.560605985777719, 6.690539845398494, 19.033361945833477, 35.68457221984863, 52.71608345849173, 48.075082847050254, 49.44247790745327, 47.946704455784385, 48.59906039919172, 50.89359528677804, 46.57667602811541, 44.77896860667637, 39.71743522371565, 36.379068987710134, 33.648548534938264, 35.427214418138774, 39.45189591816494, 42.7049104826791, 47.07164485113961, 47.25830125808716, 49.51382895878383, 48.07623277391706, 48.76914882659912, 46.862715993608745, 42.652392523629324, 42.74262877873012, 43.05978972571236, 45.04548413412911, 47.2568872996739, 47.06621135984148, 49.83630527768816, 47.218300478799, 44.457110677446636, 35.54360021863665, 36.79671825681414, 34.2607056753976, 37.356194155556814, 34.899821826389854, 34.24976921081543, 34.469290597098215, 36.32247938428606, 35.25194263458252, 33.38469764164516, 35.46149335588728, 35.397031443459646, 37.99241638183594, 37.968445096697124, 37.92985132762364, 40.43542037691389, 44.767146246773855, 49.81546763011387, 51.07370301655361, 42.64047288894653, 46.629993030003135, 48.51928465706961, 45.70158863067627, 45.346358503614155, 48.210725579942974, 45.509106159210205, 40.04618924004691, 37.106639180864605, 35.93088238579886, 36.13771983555385, 36.785420485905235, 35.952324526650564, 34.585492270333425, 36.63937629972185, 39.58102124077933, 47.226346492767334, 49.5816433770316, 49.64245401109968, 50.87180573599679, 49.69012907573155, 44.798635482788086, 40.16945028305054, 38.253560951777864, 42.70043236868722, 45.5486136163984, 48.0767365183149, 46.1522661617824, 44.268300328935894, 41.262134415762766, 38.113863945007324, 35.26567922319685, 35.53681877681187, 35.10015228816441, 36.12788118634905, 35.249503816877095, 34.53222737993513, 36.82041161400931, 37.725633348737446, 38.83968666621617, 44.07926416397095, 48.70250170571463, 51.82975387573242, 53.149838651929585, 49.430572169167654, 53.820701122283936, 56.564701080322266, 48.3095463344029, 46.61249051775251, 50.209138665880474, 54.982200213841026, 42.67407437733242, 21.23177719116211, 6.6708938138825555, 11.836152076721191, 15.658105986458914, 16.35321593284607, 4.960442304611206, 0.40180767487202373, 0.20661516168287822, 4.79135354927608, 29.133004597255162, 55.92331286839077, 50.181210381644114, 44.91287776402065, 51.69809940883091, 63.55977916717529, 51.3685359273638, 13.796647105898176, 0.6442530410630363, 0.14050294352429255, 0.20066917288516248, 0.16016417422464915, 0.1359144454555852, 0.17388658145708696, 0.13111139461398125, 0.13451842750821794, 0.10007248193557773, 0.13847762505922998, 0.17454968658941133, 0.16661592945456505, 0.21624571776815824, 0.10876599473080464, 0.12905204083238328, 0.06330489486988101, 0.1507498129670109, 0.17103857999401434], [0.01951469258139176, 0.02020931905800743, 0.018456678371876478, 0.05839719357235091, 0.022130346690703715, 0.027397897161011184, 0.061400796685900004, 0.05145162430458835, 0.019111429041783725, 0.0289328994362482, 0.06589843891561031, 0.005684270207504076, 0.008274231588334909, 0.04149321706167289, 0.08269475227487938, 0.08208579423704318, 0.05794216798884528, 0.07120740546711854, 0.04115816325481449, 0.07046350717012372, 0.06661317377750363, 5.709844606263297, 27.85819775717599, 45.113996846335276, 44.01735571452549, 36.471990721566335, 40.68891845430647, 34.568924290793284, 38.93619367054531, 18.36035943031311, 2.6611600603376115, 0.12301423267594405, 0.11410433506327015, 0.4604599433285849, 2.308999082871846, 5.190106758049556, 5.093115551131112, 1.576255087341581, 1.021490284374782, 9.897357140268598, 22.884704998561315, 37.935302189418245, 47.00450440815517, 44.91768939154488, 45.33007887431553, 48.338763509477886, 40.52183164869036, 41.86516509737287, 35.7144182068961, 31.415665013449534, 32.71446745736258, 33.49095644269671, 38.739382471357075, 41.35608795710972, 42.73230028152466, 43.198503562382285, 45.0424998828343, 39.50907959256853, 42.48599706377302, 45.50488860266549, 43.80423361914498, 41.283778054373606, 40.95114346912929, 39.741976261138916, 42.35508952822004, 43.061248847416465, 44.45934452329363, 44.28624405179705, 40.51895162037441, 38.2476167678833, 32.15147577013288, 30.508442197527202, 31.59308726446969, 31.334374564034597, 38.26241295678275, 33.0896006992885, 31.325008392333984, 31.231808730534144, 32.260406153542654, 32.02605383736746, 32.071686131613596, 33.567178181239534, 35.78554344177246, 36.872804505484446, 35.95832429613386, 37.252711159842356, 42.11047124862671, 43.08703013828823, 46.34565884726388, 35.99283947263445, 46.33841535023281, 45.34884248461042, 42.23780393600464, 40.71883044924055, 39.376355103084016, 36.40795612335205, 32.678045000348774, 32.377038615090505, 32.52025835854666, 31.30601896558489, 31.9298004422869, 33.18506894792829, 31.977388654436382, 32.645732402801514, 35.02271808896746, 43.961815289088655, 45.38064786366054, 47.27269792556763, 45.37913315636771, 44.511442116328645, 42.53069829940796, 41.42137323107038, 40.18340226582119, 42.833261081150596, 44.62043155942644, 43.45916870662144, 45.45891237258911, 45.335227489471436, 43.06713049752371, 40.21205316271101, 39.524671350206646, 36.10259321757725, 37.655331475394114, 36.53025484085083, 37.09698118482317, 33.35235030310494, 31.1742741721017, 31.96284260068621, 34.73932886123657, 33.924096720559255, 41.22620528084891, 45.05105658939907, 47.04165990012032, 48.17712409155709, 48.08046075275966, 51.88882051195417, 46.30371257237026, 46.713003158569336, 49.14173207964216, 46.052747113364084, 35.83303437914167, 18.000220400946482, 3.3848264515399933, 2.031465232372284, 4.726302342755454, 8.21213584286826, 4.055203199386597, 0.5780071786471775, 0.052882003265299966, 4.236581580979483, 25.250326905931743, 39.121526445661274, 33.3986496244158, 28.954649550574167, 37.62968567439488, 47.358706201825825, 33.56859908785139, 6.070798746177128, 0.22794170730880328, 0.06825123195137296, 0.06460087639944893, 0.006477272387460938, 0.014665952584307109, 0.025623679061287215, 0.023465381303269948, 0.03758044148396168, 0.011202854037817036, 0.022390608975131596, 0.04932507180741855, 0.09225657276277031, 0.023239765016894256, 0.025726324446233254, 0.06427872832864523, 0.002716853154457307, 0.03596848655225975, 0.0686275406873652, 0.01765783061273396, 0.04074617714754172, 0.020899477381525294, 0.03509029938972422, 0.057484848956976614, 0.043246822963867865, 0.03830440781478371, 0.06638937257230282, 0.012421590292693248, 0.02200864295342139, 0.00469655858718657, 0.07092622055539063, 0.014925573653142368, 0.03209400749100106, 0.03440817152815206, 0.04831517421241317, 0.043637102735894065, 0.03530016348564199, 0.06873332429677248, 0.0476990169180291, 0.10331607609987259, 7.52252105304173, 34.38427243913923, 50.85560948508126, 48.02699089050293, 38.806661878313335, 35.64385577610561, 38.65048374448504, 44.347228390829905, 19.953612634113856, 2.480881665434156, 0.11032748701316969, 0.17617328518203326, 0.7055312671831676, 3.6052932270935605, 7.410272904804774, 6.211538851261139, 3.815743522984641, 2.9466580663408553, 12.230263454573494, 26.23632492337908, 40.47218329565865, 49.52525527136666, 46.309917313711985, 46.20971734183175, 49.340335914066856, 43.79054914202009, 43.325606959206716, 38.64686720711844, 33.830327306474956, 33.84172582626343, 33.92564616884504, 41.23122188023159, 43.17497001375471, 45.22931262425014, 45.98031561715262, 47.62755632400513, 42.58349766050066, 43.305901868002756, 47.25837074007307, 44.74138927459717, 42.826983383723665, 43.38928025109427, 42.207349981580464, 44.61479657036917, 44.894565786634175, 45.90438222885132, 45.4897450038365, 43.29436438424246, 40.26887900488717, 34.61678695678711, 31.969488552638463, 33.28435523169381, 33.79475252968924, 39.334294182913645, 34.45826033183506, 33.973842348371235, 33.050044604710166, 34.283019815172466, 34.287039348057334, 33.95571449824742, 34.99567570005144, 38.43482903071812, 37.62059048243931, 37.4355252129691, 39.460872990744456, 43.30949756077358, 45.762638977595735, 48.457442215510774, 38.152614048549104, 47.44280024937221, 47.39764390672956, 42.7062132699149, 43.334299155644004, 41.50903170449393, 38.10789891651699, 36.29075738361904, 33.95439781461443, 33.82163511003767, 33.84747893469674, 33.508636134011404, 34.67660052435738, 33.543443134852815, 34.66453150340489, 37.41293314525059, 45.597671372549875, 47.66782113483974, 48.48385926655361, 46.59714889526367, 45.31563704354422, 44.351713453020366, 42.63337182998657, 41.84242016928536, 45.384722982134136, 46.17612280164446, 46.70968886784145, 47.59197807312012, 46.537210260118755, 43.89626598358154, 40.71023552758353, 40.24427195957729, 37.27838475363595, 39.83634669440133, 38.674597467694966, 37.694804191589355, 34.77949987139021, 34.1086026600429, 34.66926670074463, 35.01778834206717, 37.25921467372349, 44.070259298597065, 46.07911900111607, 49.93786014829363, 49.68996579306466, 49.8674054145813, 53.8895959854126, 48.58822815758841, 47.81090538842337, 50.61283942631313, 48.91200726372855, 37.39353377478463, 18.381838049207413, 6.721310377120972, 3.867116332054138, 5.636894600731986, 6.710648800645556, 3.6108619911330084, 0.1307017087404217, 0.05497939232736826, 4.7676341363361905, 26.53208715575082, 47.35415860584804, 41.44008125577654, 34.35422495433262, 42.70119319643293, 52.7710610798427, 40.11219365256173, 8.176691344806127, 0.20236830599606037, 0.010752996346647186, 0.04577349399083427, 0.016674416239506433, 0.028917764712657248, 0.03673391815807138, 0.03974269849381276, 0.03260025568306446, 0.023369599300037538, 0.1013522193367992, 0.06234900866236005, 0.07824643954102482, 0.023640239777575647, 0.05109533913699644, 0.01617301787648882, 0.04001941864511796, 0.009782913490198553, 0.05870463100395032, 0.15458376652428082, 0.10687309915998153, 0.19710296924625123, 0.11946347249405724, 0.08537719119340181, 0.15237095526286534, 0.1602601326469864, 0.12747116280453546, 0.08853243331291846, 0.06806190711046968, 0.17755660095385142, 0.1484889749969755, 0.062210261821746826, 0.13208890573254653, 0.14339392339544638, 0.1733192718986954, 0.11663787625730038, 0.14335459550576551, 0.1017266892428909, 0.13637888910514967, 0.17445079689579351, 9.089435373033796, 39.3676038469587, 58.502400806971956, 55.69562387466431, 47.4651769229344, 50.17378623144967, 43.634742736816406, 49.54770490101406, 24.634716510772705, 4.218413344451359, 0.24815640545317105, 0.30684683471918106, 2.2413755229541232, 9.73603560243334, 14.092821019036428, 13.203423806599208, 3.626455920083182, 2.4922530438218797, 11.694362793649946, 26.180616004126414, 41.00062159129551, 48.298700196402415, 48.11646284375872, 46.15905802590506, 51.451111793518066, 44.64256852013724, 45.17754854474749, 40.03265067509243, 34.204255035945344, 36.06848103659493, 36.128183432987754, 43.68299797603062, 46.661569118499756, 47.173936230795725, 47.527276447841096, 49.380889075142996, 45.00109904153006, 44.232808930533274, 50.40181221280779, 47.83336891446795, 45.934606892721995, 45.624355929238455, 43.70096601758684, 47.42591960089547, 46.6467729296003, 47.160376821245464, 47.58824341637747, 44.399457999638145, 42.25478533336094, 35.90008796964373, 33.22977713176182, 34.74088873182024, 34.49616970334734, 41.48760346003941, 36.61376871381487, 35.52260276249477, 35.03159441266741, 35.582374640873496, 36.17063692637852, 36.4144492149353, 36.77411924089704, 40.39866440636771, 39.84238815307617, 39.177650519779746, 42.30936690739223, 45.59011173248291, 47.465791838509695, 50.52681030545916, 40.02929122107369, 48.70730638504028, 49.18207679476057, 46.537828649793354, 44.211200032915386, 42.60846948623657, 39.874349866594585, 37.23004266193935, 35.71012422016689, 36.04129620960781, 34.4762214251927, 35.235183579581125, 36.84689814703805, 35.01520013809204, 36.86943115506853, 39.33380086081368, 48.576089654650005, 50.66230017798287, 50.58216312953404, 46.940681729997905, 47.83272968019758, 45.98244524002075, 45.391410623277935, 43.80255215508597, 47.0667359488351, 48.69948271342686, 47.82940149307251, 50.13385146004813, 49.29897676195417, 47.049535683223176, 44.59650196347918, 42.779485498155864, 39.78467641557966, 42.680775914873394, 40.041839667728965, 41.49178627559117, 36.49045555932181, 35.57375192642212, 35.585487433842246, 37.30116094861712, 38.51924269539969, 45.591744559151785, 48.90169266292027, 51.29304027557373, 50.7942464692252, 49.85114662987845, 54.332752091544016, 51.06865167617798, 50.240926674434114, 53.51446621758597, 50.549961703164236, 40.72971132823399, 19.806986536298478, 5.46953420979636, 8.175750732421875, 10.914537804467336, 13.590244787079946, 9.24953750201634, 1.3590195498296191, 0.28818560178790775, 6.176082628113883, 32.91560043607439, 51.79001365389143, 45.51982028143746, 41.267911842891145, 49.08956847872053, 61.44064113071987, 45.0573273386274, 11.940387214933123, 0.4166491627693176, 0.16918015400213854, 0.22064144403806754, 0.07012581386204277, 0.08636537566781044, 0.09006208873220853, 0.18080706867788518, 0.12470873817801476, 0.1017057564375656, 0.17691598247204507, 0.23314718369926724, 0.24438347933547838, 0.11372562431331192, 0.11719846831900732, 0.14322751946747303, 0.13325837440788746, 0.14610624499619007, 0.21767046488821507], [0.030651520072881664, 0.013228552482490028, 0.013021023395205182, 0.04735680117404886, 0.0483300205586212, 0.022075865417718887, 0.025772000031013573, 0.05083497167964067, 0.032790628860571554, 0.03686478381444301, 0.07311516774020024, 0.01014342762729419, 0.03143016275550638, 0.03813532028081162, 0.009424594413888241, 0.03019601951486298, 0.04462736013478466, 0.033554072358778546, 0.04337736970878073, 0.04096533378053989, 0.0791006540613515, 2.7117683504308974, 20.916417564664567, 42.3364440373012, 45.76946210861206, 28.73862658228193, 25.282809734344482, 30.972408158438547, 33.45316171646118, 20.68821266719273, 4.281305832522256, 0.2291774010019643, 0.14886807251189435, 1.0230915184531892, 2.3261941373348236, 4.732066742011479, 4.766252747603825, 3.328430963414056, 0.7278376445174217, 4.054387654576983, 16.494314738682338, 32.676679679325645, 41.26001174109322, 43.41260535376412, 47.473810059683665, 44.84643908909389, 40.90056753158569, 39.241500990731375, 34.50099522726876, 33.599542890276226, 35.88149111611502, 40.32629196984427, 43.17787436076573, 43.99632699148995, 44.221601486206055, 45.85108954565865, 41.55178049632481, 41.763071741376606, 43.201195989336284, 43.542901447841096, 44.24991886956351, 42.97710268838065, 42.65668651035854, 42.76883043561663, 43.1046507699149, 43.00790752683367, 43.76214490618025, 42.59672008241926, 42.790960448128835, 38.11499997547695, 32.41864095415388, 32.47831208365304, 31.7372693334307, 31.957565443856375, 35.43246030807495, 35.522244930267334, 31.224693775177002, 34.02171891076224, 31.27290037700108, 32.18616465159825, 33.58025469098772, 37.406318460192, 39.10842561721802, 39.58297715868269, 39.30108526774815, 39.087414264678955, 42.28766768319266, 44.224783761160715, 45.10460983003889, 37.616261754717144, 44.372130734579905, 44.69812979016985, 39.94679178510393, 38.12160423823765, 34.638357639312744, 32.80621494565691, 32.17987653187343, 31.079267978668213, 32.61186688286917, 32.201422895704, 32.54746750422886, 32.31922960281372, 32.630897998809814, 33.290938649858745, 34.357153620038716, 42.68912764957973, 44.536302770887104, 46.43630157198225, 46.12586995533535, 46.51992661612374, 43.60265595572335, 41.88398429325649, 42.11267730167934, 42.92580761228289, 47.51715987069266, 45.20540387289864, 46.45538132531302, 47.1686555998666, 45.549263272966655, 44.420639583042686, 43.12162174497332, 42.93823446546282, 43.56190129688808, 45.444543497903005, 42.0715092250279, 42.43529258455549, 38.24277039936611, 34.77722781045096, 32.633093629564556, 34.07636301858084, 37.34254094532558, 42.80851854596819, 45.37517615727016, 50.36787026269095, 48.24553952898298, 50.90785993848528, 49.98874875477382, 47.78072936194283, 46.783120904650005, 43.35947595323835, 30.273943969181605, 12.681541136332921, 3.6880534376416887, 4.161640048027039, 3.408133315188544, 3.073908026729311, 1.2668158688715525, 0.3020824332322393, 0.05797499551304749, 5.355980234486716, 26.768801859446935, 35.973968165261404, 28.047949586595806, 27.14915493556431, 41.925482409340994, 42.87218836375645, 26.76021909713745, 6.015859774180821, 0.03803869350148099, 0.01911444173726652, 0.04367331275716424, 0.06387066415378026, 0.010326604092759746, 0.042769056279212236, 0.07018055128199713, 0.06668249291500875, 0.03044678909437997, 0.04325220035389066, 0.05750931692974908, 0.018891324156097004, 0.0032597988527933402, 0.010428093423667763, 0.047093516016112905, 0.04305985942482948, 0.02903452023331608, 0.05422842369547912, 0.015057991458369153, 0.03575988453147667, 0.05212169459887913, 0.03897754169468369, 0.06653810066304036, 0.030008699744939804, 0.029332563347582306, 0.05603167461231351, 0.03917084275079625, 0.020140332402661443, 0.04425732784771493, 0.06530170807881014, 0.008159027368362461, 0.09131534291165215, 0.024481248310101882, 0.05646580470991986, 0.016471139022282193, 0.032127479623470984, 0.03683207842654415, 0.01734068164868014, 0.012606887180092079, 3.6249596689428603, 26.452433007104055, 48.8041364806039, 51.339221477508545, 35.58368437630789, 31.17219318662371, 36.7384854044233, 43.01637738091605, 24.069497925894602, 4.604337573051453, 0.25945105510098593, 0.1378677035016673, 1.1034766393048423, 2.302170957837786, 7.781788740839277, 6.562881895474025, 7.228431165218353, 4.921661368438175, 6.733866206237248, 19.34417050225394, 33.86748627253941, 42.75230067116873, 44.75274610519409, 48.83135257448469, 46.501322814396445, 43.99420779091971, 41.06970405578613, 36.798979895455496, 35.23049701963152, 38.33484097889492, 42.45438970838274, 43.390649046216694, 45.629629611968994, 45.20171437944685, 46.64204815455845, 42.184445244925364, 43.09978008270264, 43.20321444102696, 45.53079496111189, 45.27340589250837, 43.96223565510341, 44.92208760125296, 44.36642278943743, 44.77405275617327, 43.1771309035165, 45.50468710490635, 43.948627608163015, 44.913746288844514, 39.39033487864903, 34.03433336530413, 33.461079188755576, 33.548411096845356, 32.15039879935128, 36.67309938158308, 36.12502895082746, 34.14125919342041, 35.57628107070923, 32.88511521475655, 34.550059931618826, 34.44784845624651, 38.134892668042866, 40.17548131942749, 40.31563343320574, 41.105713094983784, 40.82161167689732, 43.524773597717285, 46.18618726730347, 47.22745820454189, 38.99874135426113, 45.82444667816162, 46.30065883908953, 42.33624948774065, 39.18482106072562, 36.038499559674946, 36.029630184173584, 34.61424739020211, 34.48920413425991, 33.44768306187221, 33.09802886417934, 33.68209443773542, 34.547985894339426, 33.88676404953003, 35.2274398122515, 36.51158503123692, 44.41232606342861, 47.40552316393171, 48.124383790152415, 47.570973668779644, 48.48067699159895, 45.705434458596365, 45.00263459341866, 44.84957620075771, 44.713269914899556, 49.65378999710083, 48.08830179486956, 48.78039448601859, 49.3061021396092, 46.847221510750906, 44.98105001449585, 44.69790049961635, 44.9518780027117, 45.64749343054635, 47.678559575762065, 44.77493517739432, 42.09301042556763, 38.85251304081508, 35.390976088387625, 35.37158366612026, 35.18734523228237, 38.91002675465175, 46.41342115402222, 47.47261149542672, 51.65067447934832, 48.576475279671804, 51.54786545889718, 52.62207433155605, 50.627729415893555, 49.98412472861153, 45.81086989811489, 32.01575313295637, 12.811854600906372, 4.816185108252934, 4.565405947821481, 2.5924525814396993, 5.549249155180795, 1.5175675622054507, 0.15665647387504578, 0.2440182375056403, 5.693568451063974, 29.924126488821848, 38.94442728587559, 32.61613655090332, 31.45896966116769, 45.59349550519671, 49.78387764522007, 33.17715147563389, 7.445636630058289, 0.009937905307326998, 0.0254343711837594, 0.04061187131862555, 0.05125366510557277, 0.03812080980943782, 0.07660057142909084, 0.06715245305427484, 0.027056482088352953, 0.01373749615491501, 0.045874867122620344, 0.05688087136617728, 0.049168228437857966, 0.027240483822034936, 0.02678754473371165, 0.012033628565924508, 0.07446744732026543, 0.019342714488240223, 0.033889869161482365, 0.10489174976412739, 0.11313605202095849, 0.08448151818343572, 0.1329082367675645, 0.19688176683017186, 0.14145574239747866, 0.10202111237283264, 0.10791674708681447, 0.12596553431025573, 0.11082980648747512, 0.15370450727641582, 0.17018533577876432, 0.1346881426870823, 0.15472099344645227, 0.12041415433798518, 0.22480197649981293, 0.09416461323520967, 0.08572707099041768, 0.14476825536361762, 0.1758790723979473, 0.22120798006653786, 4.236657576901572, 29.588875906808035, 55.67985493796212, 58.27958597455706, 41.314096518925254, 35.23701095581055, 40.503290380750386, 43.68379007066999, 27.62400003841945, 6.291177366461072, 0.4338040479591915, 0.7383916324802807, 2.9248329060418263, 5.311676783221109, 9.194551195417132, 13.33241537639073, 8.130235689026968, 3.246774647917066, 6.371229733739581, 18.82884693145752, 35.13141918182373, 44.308165618351524, 47.64623655591692, 48.605570861271445, 49.5368344443185, 44.22955369949341, 42.450120040348594, 37.781722681862966, 37.34133890696934, 39.79180179323469, 44.77075931004116, 45.66793155670166, 47.968063218253, 47.46199812207903, 48.85027251924787, 43.02530929020473, 42.31053767885481, 43.001789637974326, 46.76697676522391, 47.23687301363264, 46.01644624982561, 46.517352308545796, 46.58282518386841, 47.403827803475515, 43.13567795072283, 46.21448380606515, 46.42407274246216, 46.595238140651155, 42.46246698924473, 35.90442711966378, 36.60681356702532, 34.67084741592407, 34.171567235674175, 36.80801255362374, 39.32630722863333, 35.505704743521555, 37.23095287595476, 33.902220317295615, 36.233636243002756, 37.26640258516584, 40.34921407699585, 43.328580788203645, 42.20618615831648, 43.556853430611746, 42.620048659188406, 46.075419085366384, 46.97157689503261, 48.16425602776663, 42.671336787087576, 48.01829521996634, 49.232322692871094, 42.93129668916975, 41.003849029541016, 37.85076345716204, 37.984137603214805, 35.565344606127056, 34.7891891343253, 36.267883913857595, 35.41404063361031, 36.41801364081246, 36.730891023363384, 36.89499705178397, 37.40345927647182, 37.807910442352295, 46.6109619140625, 48.71362924575806, 49.53350625719343, 49.503059250967844, 50.145666871752056, 47.72367075511387, 46.918225152151926, 46.07983813967024, 45.635386194501606, 52.777984959738596, 49.1722138268607, 51.70350858143398, 51.988919734954834, 50.424334798540386, 47.74665192195347, 47.238575322287424, 46.25974089758736, 47.66696998051235, 51.37005410875593, 45.9937082699367, 45.43843603134155, 42.02890634536743, 37.62806674412319, 38.12527983529227, 37.72232600620815, 41.809280736105784, 47.09095389502389, 50.10258804048811, 53.01377207892281, 49.4952529498509, 51.02410330091204, 53.56287431716919, 51.266581535339355, 52.54634938921247, 46.8385397366115, 33.36242519106184, 13.60152953011649, 6.812162850584302, 7.426800063678196, 6.03484833240509, 9.468349303518023, 3.765068139348711, 0.6342622371656554, 0.5309874159949166, 7.459167378289359, 35.07926252910069, 47.0143916947501, 39.04722588402884, 38.46933031082153, 54.4904761995588, 55.273739678519114, 38.238573687417166, 8.950198684419904, 0.3299020433000156, 0.09727933324341263, 0.1301464635346617, 0.26244043612054413, 0.09083770175597497, 0.11923304200172424, 0.19910371117293835, 0.10279774319912706, 0.11773608518498284, 0.10984075348824263, 0.12311665075165884, 0.1755724831351212, 0.11178941106689827, 0.10876437981746026, 0.1598044013870614, 0.14240893482097558, 0.13967827920402798, 0.133567053558571], [0.048541747233165164, 0.0244404751408313, 0.0354198434922312, 0.05144821127344455, 0.03218949433150036, 0.024627097716022815, 0.019227027660235763, 0.050605399534106255, 0.07068961539438792, 0.038430561045450826, 0.08483521813260657, 0.023604440269991755, 0.012496082411546792, 0.01378179176910115, 0.02388979308307171, 0.025318762387282083, 0.03530493358682309, 0.039458243043294976, 0.007035160063034189, 0.015175016696697899, 0.030672323956553425, 1.1149759079728807, 13.576640214238848, 41.0073960849217, 42.34717900412423, 33.784913880484446, 28.00951041494097, 28.398619958332606, 36.28107854298183, 24.152223178318568, 7.727584975106375, 0.5518438454185213, 0.037313393849347315, 0.4017821348139218, 2.026996237891061, 10.197908418519155, 3.582195460796356, 8.173192926815577, 6.343341835907527, 3.3265377964292253, 14.348070042473928, 26.547123057501658, 41.33981875010899, 48.92974601473127, 46.72721569878714, 43.812599250248496, 41.06105702263968, 39.29131262642996, 37.28535727092198, 39.23367037091936, 41.58494772229876, 42.13583217348371, 44.0964401108878, 46.586733545575825, 45.73116711207798, 44.39120006561279, 46.44726930345808, 46.18510682242257, 46.372979164123535, 44.56295953478132, 41.43591928482056, 43.20470482962472, 43.239056723458425, 44.058596747262136, 46.10045344488961, 43.25206027712141, 42.30044889450073, 43.9248161315918, 41.02568374361311, 39.955539567129954, 37.11887843268258, 32.516961438315256, 32.51451219831194, 33.59596109390259, 31.841124057769775, 31.680186407906668, 32.919943060193745, 31.713975497654506, 32.4494423185076, 31.86529336656843, 33.79917853219168, 38.56136267525809, 39.52236802237374, 41.11112574168614, 40.711246490478516, 40.72773109163557, 43.19337231772286, 45.39316156932286, 47.51687152045113, 39.05534137998308, 46.10108573096139, 43.784549372536794, 41.963266713278635, 37.52505275181362, 32.44430412564959, 32.466305596487864, 30.970132623400005, 34.1314240183149, 32.63848195757185, 33.40371486118862, 32.78172949382237, 32.741544587271555, 32.68030316489083, 32.26026371547154, 34.39102608816964, 39.57444477081299, 44.45624910082136, 44.32164512361799, 47.301018783024375, 46.9776530947004, 46.14436953408377, 43.888525690351216, 45.25131409508841, 44.07436568396432, 43.245831217084614, 43.48662798745291, 45.11872509547642, 45.84356812068394, 45.41051122120449, 46.78562225614275, 46.33718204498291, 43.049398694719585, 46.54652779442923, 43.82550205503191, 47.50701550074986, 44.794647216796875, 44.475711005074636, 39.85004506792341, 36.87504529953003, 33.9541893686567, 35.280169691358296, 39.96171304157802, 44.99771179471697, 47.40994916643415, 49.712266036442344, 46.78522620882307, 52.98446110316685, 48.68056624276297, 47.39264815194266, 36.394778864724294, 24.154137407030376, 8.634636691638402, 4.42202205317361, 3.8104958959988187, 4.236740955284663, 3.739898289952959, 1.1662660986185074, 0.1324567124247551, 0.1458039576453822, 5.701609688145774, 27.920490094593593, 42.704479694366455, 39.457364150456016, 32.531608240945, 44.05940621239798, 47.67958443505423, 22.910531452723912, 3.472960659435817, 0.016230498274256076, 0.0157223552731531, 0.051127600084458075, 0.022284821973049214, 0.0681730986439756, 0.02325015508436731, 0.03668975231370755, 0.03907320834696293, 0.0399426899052092, 0.02376051859131881, 0.043636186713618894, 0.05116345726751855, 0.03230501491842525, 0.0866081758535334, 0.0065876242338812774, 0.05386656775538411, 0.027968996337481906, 0.028091315845293657, 0.041396342617060454, 0.06393302152199404, 0.04606012414608683, 0.01000113204853343, 0.01928372265371893, 0.045051882176526954, 0.034366258420050144, 0.0401934560920511, 0.05461214881922517, 0.011407942095372294, 0.04409553795786841, 0.03639602468215993, 0.006756302102335862, 0.0056463663931936026, 0.02022352588496038, 0.03335167893341609, 0.04010869689019663, 0.03697620604985526, 0.023930756242147515, 0.030522252366478955, 0.04829515064401286, 1.4740428520100457, 17.984309026173182, 47.41998583929879, 48.44604022162301, 36.676208700452534, 30.583378519330704, 29.68427814756121, 39.429359436035156, 27.784911632537842, 8.630527700696673, 0.445356405207089, 0.05869827313082559, 0.5305716097354889, 1.6814144445317132, 7.862886377743312, 5.300077634198325, 7.927025198936462, 7.758134467261178, 5.83255717584065, 14.61924433708191, 31.012606961386545, 43.20788710457938, 50.97120319093977, 47.80725411006382, 46.10367393493652, 42.463088853018625, 41.59379277910505, 37.89946338108608, 39.88372646059309, 43.67534800938198, 43.79468332018171, 47.002878529684885, 48.23143121174404, 47.240503447396414, 45.60074247632708, 46.59682927812849, 46.652512141636436, 46.904321806771414, 45.63182176862444, 44.25087424686977, 44.68307651792254, 45.14212315423148, 45.431793553488596, 45.533852168491904, 44.199818883623394, 44.270589760371614, 45.735009465898784, 43.43255363191877, 42.49575580869402, 38.09315831320626, 33.64695739746094, 33.43840026855469, 34.294321060180664, 34.87088605335781, 34.33545092173985, 33.869626317705425, 32.97419459479195, 33.76620238167899, 33.48914991106306, 35.3912262235369, 41.28541782924107, 41.1491254397801, 43.71358394622803, 40.36310352597918, 43.6564975466047, 44.20682266780308, 45.66220276696341, 48.837050097329275, 42.83394547871181, 47.057286398751394, 45.32460369382586, 42.933624335697715, 39.688172885349815, 34.1569447517395, 34.24737555640084, 32.03621210370745, 35.36685194287981, 34.11207675933838, 35.39298064368111, 34.10393694468907, 34.45872586114066, 33.602516719273154, 34.04771212169102, 35.575565406254356, 42.5999926839556, 46.606678349631174, 47.385237898145405, 48.4216103553772, 48.26351799283709, 49.06473561695644, 47.28641019548689, 46.994481631687705, 45.86705650602068, 45.41448211669922, 44.89078944069998, 46.58693504333496, 48.08502571923392, 49.163080419812886, 48.98184013366699, 47.2249116897583, 45.661546162196565, 47.836822169167654, 47.86801610674177, 49.08513552801949, 48.48665591648647, 46.17039401190621, 44.06352302006313, 37.398206438337056, 36.251110962459016, 36.923286642347065, 43.26423699515206, 45.75010790143694, 48.8218856539045, 49.863017627171104, 49.249491691589355, 55.27984367098127, 52.627848284585134, 50.64207744598389, 39.84641810825893, 27.389329842158727, 10.12813287121909, 5.173514894076756, 7.139324426651001, 4.597790198666709, 6.106071710586548, 1.2793543274913515, 0.1719722713210753, 0.20411125889846257, 6.510745653084346, 32.782250608716694, 48.640068667275564, 38.88661479949951, 36.19688374655587, 49.2057979447501, 52.799069268362864, 28.37884364809309, 5.1089969617979865, 0.05024932131969503, 0.01902573006892843, 0.008618942644846226, 0.02731342633653964, 0.06876446905412845, 0.008578767434560826, 0.05261386658198067, 0.10354124116046087, 0.018608225775616508, 0.03317467289577637, 0.05056642787531018, 0.08969164253877741, 0.013628399598279169, 0.05895024032465049, 0.026970516790502837, 0.014292349506701742, 0.022672085656917522, 0.006916597942888204, 0.09175431435661656, 0.10204315119023834, 0.13991614644016537, 0.15632202396435396, 0.18767408733921392, 0.09894878723259483, 0.09625482678945575, 0.1017240293856178, 0.11707596560674054, 0.14820062475545065, 0.16802623734942504, 0.11403838145945754, 0.0769254539960197, 0.07874726623828922, 0.07096315321645566, 0.18842305429279804, 0.07612438233835356, 0.1489473254020725, 0.05906275500144277, 0.1003017249916281, 0.10701852957052843, 1.8481804387910026, 20.504669053213938, 53.89010320390974, 54.095064640045166, 43.907372679029194, 37.39276599884033, 37.58376850400652, 46.75293792997088, 35.63912057876587, 11.748603905950274, 0.9344694167375565, 0.21827084624341556, 1.7922122648784091, 5.571736999920436, 22.411020244870866, 10.448126077651978, 13.814001100403921, 9.990646260125295, 5.528623427663531, 16.74150037765503, 30.44258369718279, 44.062470367976594, 52.79716198784964, 51.351724760872976, 46.76512507029942, 45.923705169132774, 42.487185205732075, 41.6723803792681, 43.694149834769114, 45.267492975507466, 46.13579545702253, 47.99301072529384, 48.57737507138933, 48.475615228925435, 45.8893324307033, 48.73177099227905, 49.603002139500205, 49.50802026476179, 46.380267824445454, 43.97450269971575, 45.543260029384065, 47.04923343658447, 46.40168912070138, 46.99253613608224, 44.70446307318551, 46.052069664001465, 47.46772343771798, 45.50045912606375, 44.041625772203716, 40.7635247366769, 36.55250644683838, 35.75298070907593, 37.57657364436558, 36.96852288927351, 36.149031502859934, 36.04143517357962, 34.70984418051583, 36.19863469260079, 34.832653590611045, 37.183354241507395, 42.89026410239083, 44.94943223680769, 45.273423263004844, 43.66965396063668, 44.11043030875069, 45.76811763218471, 48.452839033944265, 50.16143233435494, 44.64858913421631, 49.80187347957066, 47.91681677954537, 44.95310435976301, 40.654691628047395, 35.15646743774414, 35.45497941970825, 33.897787366594585, 37.89221640995571, 36.03664091655186, 37.31870515005929, 36.44383314677647, 36.71285349982125, 35.47454554694039, 34.785423210689, 37.338163580213276, 44.07435178756714, 49.25377525602068, 48.01603705542428, 51.38378722327096, 49.19618511199951, 50.76249667576381, 47.43090145928519, 50.138652665274485, 48.33304861613682, 45.42585284369332, 45.0252058165414, 46.993838923318044, 48.3628876549857, 50.15005465916225, 50.394877910614014, 50.962417193821494, 47.52764817646572, 50.493879318237305, 49.57906559535435, 53.33830853870937, 50.140949044908794, 49.875256878989084, 45.91975164413452, 41.11402314049857, 37.704861709049766, 39.24898420061384, 45.7469152041844, 48.24848903928484, 50.714262281145366, 52.01240117209298, 47.864597593035015, 56.46505349023001, 52.78900827680315, 51.28477539334978, 40.46210493360247, 27.747837781906128, 10.715893149375916, 8.99846955708095, 6.811706440789359, 13.633315801620483, 12.214841059276036, 3.286969108240945, 0.41182879571403774, 0.3514630634869848, 8.773691858564105, 38.77783032826015, 53.72552817208426, 47.2773288999285, 42.9975130217416, 54.590349606105256, 60.090550558907644, 33.89819731031145, 6.187826820782252, 0.16956861530031475, 0.09764946731073515, 0.10672209119158131, 0.13509409661803926, 0.1353221929499081, 0.1174474363880498, 0.10607536589460713, 0.20063429618520395, 0.13336968129234655, 0.09621176017182213, 0.12901936258588517, 0.19502605497837067, 0.10535419173538685, 0.19866524184388773, 0.058140381638492854, 0.19543230746473583, 0.09264075929032904, 0.0918993376461523], [0.037205618739660294, 0.005971674740846668, 0.03164177407909717, 0.03332506000463452, 0.018688460845234137, 0.025280878080853393, 0.04018161226330059, 0.019787791052034924, 0.0407429778549288, 0.04855689213478139, 0.014949052661125149, 0.04678576985108001, 0.0284815243711429, 0.02758379709640784, 0.07484330822314535, 0.009997676608950963, 0.07178010937890836, 0.04171024648738759, 0.012463633170617478, 0.1102897876075336, 0.0344579013596688, 0.28820753203971045, 7.838669300079346, 32.00503901072911, 48.20715420586722, 36.71436473301479, 28.19473201887948, 29.578821863446915, 32.81983341489519, 31.216960430145264, 13.793232934815542, 0.9673618631703513, 0.10638103234980788, 0.299143698066473, 0.8442088972244943, 1.901007809809276, 4.174555880682809, 7.839078375271388, 12.090309364455086, 7.281778131212507, 11.146327103887286, 30.60358735493251, 41.34654113224575, 47.52792957850865, 46.381622723170686, 44.9786250931876, 42.05257190976824, 40.478961263384136, 40.83360774176461, 43.10946934563773, 42.37844589778355, 45.16297122410366, 45.53508199964251, 47.09816265106201, 44.74149349757603, 43.613689695085796, 41.80247497558594, 43.085998330797466, 44.80941561290196, 46.934987681252615, 43.0452367237636, 42.63593918936593, 44.85295649937221, 43.998345443180625, 43.90451349530901, 45.62982416152954, 44.13980729239327, 43.74649408885411, 44.436255659375874, 42.90962873186384, 42.66165794645037, 38.599477018628804, 32.01332473754883, 32.70742198399135, 31.691626616886683, 32.17067016874041, 30.634253229413712, 31.28726577758789, 32.03905739103045, 34.364414487566265, 36.44603225163051, 38.72012901306152, 42.712480545043945, 43.40288482393537, 42.346199308122905, 42.75410025460379, 45.61260999952044, 45.697572571890696, 46.84409829548427, 37.34839480263846, 45.77209547587803, 44.02141693660191, 40.58558137076241, 36.52010004861014, 33.70502001898629, 33.63921710423061, 31.241570949554443, 32.39823409489223, 33.43174042020525, 32.980319431849885, 35.621906416756765, 33.40088694436209, 32.32140438897269, 33.5549875668117, 34.85108716147286, 36.307387896946494, 43.341066701071604, 43.57101385934012, 45.12685448782784, 45.17280987330845, 45.43512174061367, 45.054999692099436, 45.88831451960972, 47.5747708593096, 46.48116956438337, 45.74039084570748, 45.91220590046474, 46.20899820327759, 42.94199691499983, 43.64011369432722, 47.344042028699604, 46.99203586578369, 47.27093308312552, 45.92043604169573, 47.04036406108311, 47.21855408804757, 46.335993903023855, 43.25589220864432, 44.07302468163626, 40.89716638837542, 40.70119939531599, 42.032946722848074, 45.536648818424766, 47.80062552860805, 50.72178370612008, 44.214639391217915, 51.91861438751221, 51.720285006931846, 42.3664220401219, 28.064446347100393, 17.856976338795253, 4.631274436201368, 2.717215520995004, 3.466034825359072, 1.7693199047020503, 5.930247110979898, 0.6133829003998211, 0.20669069620115416, 0.41386266372033526, 6.906428626605442, 27.015659196036204, 27.797652891704015, 26.46297342436654, 37.08894211905343, 44.59543194089617, 47.43632105418614, 20.13221434184483, 1.5104344763926096, 0.15228761759187492, 0.030167789065412114, 0.025598461307319145, 0.0019889894881219205, 0.021956853768123046, 0.07464761193841696, 0.021001111749293547, 0.021483768975096088, 0.06859794298985175, 0.0231987272189664, 0.05250223060803754, 0.08578385080077819, 0.03222683411357658, 0.048245213859315426, 0.02038091717154852, 0.024957444186189344, 0.05596404841967991, 0.011039878408025419, 0.0753412443612303, 0.06088336623672928, 0.031833029352128506, 0.1460805828017848, 0.0624818251069103, 0.026859096251428127, 0.08207524980285338, 0.024855931954724447, 0.08296238684228488, 0.07554249106241123, 0.03268458740785718, 0.038006982167384455, 0.04609987612015434, 0.05708829273602792, 0.05579405164878283, 0.030038338154554367, 0.01366303117746221, 0.031191851078931774, 0.07254890991108758, 0.042760445669825585, 0.054302278839583905, 0.3797262454671519, 10.778305343219213, 38.235221181597026, 53.356311321258545, 42.40590865271432, 31.53537552697318, 32.51726368495396, 38.582248960222515, 33.88070174625942, 15.294791630336217, 0.95809948018619, 0.13043353813035147, 0.28682644186275347, 2.0199062526226044, 5.904179206916264, 8.536516836711339, 9.591506123542786, 8.848956482751028, 6.3913087248802185, 15.080163512911115, 32.08053813661848, 41.98387507029942, 50.48324857439314, 46.95924036843436, 46.33360719680786, 43.1969575881958, 41.393684659685405, 42.379488127572195, 45.758404050554546, 45.35342134748186, 46.39851031984602, 47.8061215536935, 47.780423641204834, 46.27886234010969, 46.14497402736119, 44.19795676640102, 44.73759208406721, 46.31226927893502, 46.958191190447124, 44.7338296345302, 41.47948101588658, 45.1899163382394, 46.03307328905378, 46.25420318331037, 46.963009766169954, 43.97865424837385, 45.132364409310476, 46.33088002886091, 44.334238733564106, 43.483174732753206, 39.7196169580732, 34.984426566532676, 34.831951822553364, 33.00855343682425, 33.606668267931255, 32.58901425770351, 32.39019502912249, 32.75802224023001, 35.56379863194057, 39.65743405478341, 40.90150553839547, 43.132012775966096, 44.885216985430034, 44.24206740515572, 43.33574785505022, 46.16415105547224, 45.88032409123012, 48.09616020747593, 39.060719285692485, 47.24165684836251, 46.1136828150068, 41.35046339035034, 40.04381990432739, 35.26522411618914, 35.0113855770656, 33.252727031707764, 33.85721683502197, 34.38312946047102, 34.06544739859444, 35.761982100350515, 35.62996285302298, 34.19028568267822, 34.651170117514475, 35.58907617841448, 37.76515122822353, 45.846677439553396, 46.02408579417637, 46.7593024798802, 46.115183625902446, 47.946405683244976, 45.71236181259155, 47.6671575818743, 48.32694809777396, 47.66036571775164, 45.637957027980256, 45.52816506794521, 46.7177974155971, 42.86003943852016, 46.001827239990234, 48.64383806501116, 48.61971391950335, 48.11735916137695, 48.35780157361712, 48.78956263405936, 48.837633746010916, 48.406053338732036, 45.323349543980186, 45.22220114299229, 42.6693947655814, 42.689412525721956, 44.00996283122471, 46.59936189651489, 51.39322287695748, 51.55997616904122, 44.017324447631836, 51.60234975814819, 52.966472217014854, 45.09010199138096, 31.76626069205148, 21.06517502239772, 7.176096899168832, 5.26478339093072, 9.369032621383667, 4.6942872149603705, 5.289762599127633, 1.0213189678532737, 0.12943816797009536, 0.609278740627425, 7.380359172821045, 31.612378937857493, 35.14395720618111, 32.79197113854544, 42.52903767994472, 50.67817333766392, 54.47243867601667, 24.943181787218364, 2.326778654541288, 0.0348876888331558, 0.05309376386659486, 0.03108897838475449, 0.026169390850035206, 0.044899249116757085, 0.06432235813034431, 0.05562041114483561, 0.029759972555828944, 0.05385841176445995, 0.035083585285714695, 0.058547278733125756, 0.047792247629591396, 0.05349593496482287, 0.022111459668459635, 0.07905559933611325, 0.05761368240096739, 0.051200284755655696, 0.025933145312592387, 0.23325412081820623, 0.17411252004759653, 0.15908723058445112, 0.18587675664041722, 0.15529451838561467, 0.08091255969234876, 0.19844855847103254, 0.07296032604894467, 0.2125354611447879, 0.23365470075181552, 0.19809244972254547, 0.08569521377129213, 0.09183651208877563, 0.0983654981745141, 0.11591409652360848, 0.15238866502685205, 0.13312156817742757, 0.11863002793065139, 0.2555571326187679, 0.21091734511511667, 0.10694317825670753, 0.40015169658831184, 10.951475296701703, 43.43282461166382, 59.944207600184846, 48.72242219107491, 39.01396485737392, 39.48824541909354, 43.16632298060826, 40.38917316709246, 19.365209647587367, 1.3875184548752648, 0.31950048144374577, 1.3459706157445908, 3.8823771817343573, 7.966490966933114, 12.42553997039795, 16.0946752003261, 21.64350312096732, 11.503256934029714, 14.3680374281747, 33.60287455150059, 44.212992668151855, 51.501531396593364, 49.66796432222639, 49.56607246398926, 46.15046657834734, 44.3025757925851, 44.58683007104056, 48.36084835869925, 47.545765604291645, 47.52047068732125, 48.667329924447195, 49.380666732788086, 49.12796769823347, 47.60955701555525, 46.75951439993722, 48.01276445388794, 48.58518484660557, 48.660228865487234, 46.70394965580532, 43.025191170828684, 46.08261741910662, 47.95714412416731, 47.07058525085449, 50.0790753364563, 45.64838974816458, 47.66972494125366, 48.37373726708548, 47.05311400549752, 45.95663963045393, 43.93712139129639, 35.78716237204415, 37.00971875871931, 34.699731077466694, 36.10393074580601, 33.828697953905376, 34.7649051802499, 34.47812523160662, 36.335705280303955, 40.633117471422466, 42.34373617172241, 45.567880971091135, 47.212693282536094, 46.30441434042794, 47.30201237542288, 49.549938746861045, 48.50557238715035, 49.64730385371617, 41.12909378324236, 49.5035525730678, 48.5446594783238, 43.47760575158255, 40.40377133233206, 38.10345901761736, 36.15571219580514, 34.692657811301096, 35.22195768356323, 36.25503322056362, 36.779486724308555, 39.135433265141074, 37.27484117235456, 36.412871973855154, 36.186659472329275, 38.24422952107021, 39.12129715510777, 48.39850412096296, 47.935660294124055, 48.93523856571743, 47.05639702933175, 48.267648696899414, 46.755508763449534, 48.6383489881243, 49.323323249816895, 47.714909076690674, 47.71758413314819, 46.520892415727886, 47.10306807926723, 45.34261689867292, 47.14025831222534, 49.54893473216465, 49.55586903435843, 49.39191934040615, 48.913549763815745, 49.032718317849294, 50.729857512882774, 50.37246649605887, 49.10309314727783, 47.25906555993216, 44.633237089429585, 45.40391738074166, 46.584280831473215, 49.954865864345, 53.996348108564106, 53.33885049819946, 44.79164906910488, 52.82651117869786, 55.231439045497346, 47.27018962587629, 30.803264686039515, 21.954586131232126, 6.832852414676121, 3.971462207181113, 10.662742904254369, 8.625090735299246, 13.57718130520412, 2.661030215876443, 0.36021388534988674, 0.856471870626722, 9.691167610032217, 35.87815250669207, 40.07575729915074, 38.06982626233782, 48.51490034375872, 56.683192184993196, 59.81797272818429, 28.34848349434989, 2.706785623516355, 0.2709612346121243, 0.14938000004206384, 0.1920507467750992, 0.09103200025856495, 0.17275486647018365, 0.22667214114751133, 0.11107764140303646, 0.12080416269600391, 0.12140417764229433, 0.1465118189475366, 0.16452150898320334, 0.2186436876654625, 0.09958238287695817, 0.14719450660049915, 0.12330845903073039, 0.08073212366018977, 0.09904678125998803, 0.08442458909537111], [0.015701732897598828, 0.005925136144339506, 0.10537074798984186, 0.040333213949842114, 0.015152160244594728, 0.013180613983422518, 0.04327274978693042, 0.008187617441373212, 0.06037168297916651, 0.014961846438901765, 0.03576426108234695, 0.0637662240437099, 0.05770269262471369, 0.03506382295329656, 0.026719608111307025, 0.016528217388050895, 0.03931814591799464, 0.030826833165649856, 0.026037266511203985, 0.04507202109588044, 0.041534390566604476, 0.05301225484747972, 2.749482738120215, 20.398417200360978, 43.27297782897949, 41.14969866616385, 32.20568561553955, 24.11604564530509, 35.61900554384504, 36.831907408578054, 20.942252704075404, 2.370375995125089, 0.10133497776197535, 0.1922152236636196, 1.2238657964127404, 5.70940990958895, 5.753537050315312, 4.819618821144104, 3.9770320568765913, 6.388152939932687, 16.470906257629395, 27.475180046898977, 39.63810069220406, 49.056568009512766, 47.605634757450645, 45.46175071171352, 41.72310222898211, 42.941437585013254, 42.51255307878767, 43.97375576836722, 44.78623294830322, 46.68979964937483, 44.28670610700335, 42.23854391915457, 42.120629514966694, 41.480603149959016, 41.641096115112305, 40.85063777651106, 41.85480533327375, 45.907098974500386, 47.8513126373291, 45.72181831087385, 43.58525766645159, 43.745920862470356, 42.62831701551165, 44.40220948628017, 44.68607813971383, 43.160139083862305, 44.23946877888271, 45.33206953321184, 43.184638432094026, 44.904922076633994, 37.21064329147339, 31.874027252197266, 32.41281488963536, 31.085285118647985, 31.041396822248185, 30.872461795806885, 31.509747096470424, 32.50813027790615, 33.25719819750105, 39.969456808907644, 44.62498262950352, 43.58333996364048, 46.40987409864153, 43.63357196535383, 45.16460057667324, 46.55504281180245, 44.549817017146516, 39.87724379130772, 44.62439203262329, 43.04067523138863, 41.36054522650582, 36.67897060939244, 35.2036908694676, 34.729556219918386, 31.650420325142996, 34.03288813999721, 32.19738599232265, 33.57998023714338, 34.38871233803885, 32.27787045070103, 33.26868009567261, 32.49774966921125, 32.4925593648638, 34.53276933942522, 38.02638612474714, 42.972603729793, 43.03640903745379, 45.23758445467268, 42.59720645632063, 46.16181993484497, 46.35411480494908, 46.781140668051584, 46.69553191321236, 46.26783902304513, 46.68311200823103, 47.171928201402935, 45.64667354311262, 47.05940907342093, 46.594612802777974, 46.403745787484304, 45.21241113117763, 47.15448127474104, 45.34343678610665, 46.298588275909424, 46.21741941996983, 47.921409538814, 47.33043050765991, 47.254889692579, 45.16025447845459, 45.06076669692993, 47.46355104446411, 49.197765827178955, 47.693988050733296, 42.997853483472554, 47.46281453541347, 46.71286766869681, 37.211153984069824, 24.1387870992933, 10.311406373977661, 4.292002584253039, 7.817922847611563, 12.48000863620213, 4.192513065678733, 3.5932009731020247, 0.686317109635898, 0.05174469714984298, 0.37987652740308214, 7.011042441640582, 34.58162212371826, 37.98812239510672, 28.503049646105083, 31.817944867270334, 42.889110701424734, 38.126127515520366, 13.187504615102496, 1.0690469039337975, 0.04608451408733215, 0.08094645930188042, 0.0633803615346551, 0.032497729041746685, 0.05111526092514396, 0.03937439986371568, 0.07060672555650983, 0.08534819060670477, 0.0364531234039792, 0.07580119610897132, 0.010457276366651058, 0.06311128847301006, 0.015541559617434229, 0.0793454966374806, 0.04004514190767493, 0.025449293865157024, 0.04583596331732614, 0.019036661268078854, 0.044457750128848214, 0.017142579957310642, 0.053462852989988666, 0.041412980295717716, 0.01699533955460148, 0.00865525529453797, 0.07555106095969677, 0.07983664742537908, 0.06926066814256565, 0.038781920048807345, 0.03514421238963093, 0.03793971559831074, 0.02629839053510555, 0.03126179786132915, 0.010499048678736602, 0.06791775913110801, 0.05897201451339892, 0.08003396540880203, 0.015129644756338425, 0.0358333664813212, 0.03486318354095731, 0.05546990868502429, 4.917125931807926, 26.647932733808243, 48.55330651147025, 45.55751773289272, 35.95626762935093, 28.161910465785436, 37.27671718597412, 40.88251263754708, 22.82860176903861, 2.5734010551656996, 0.08077052195689507, 0.04782002346057977, 1.1587542274168559, 6.081682230745043, 6.752800915922437, 7.772466863904681, 6.46478853055409, 5.990942665508815, 15.832316432680402, 29.279847826276505, 41.6392548424857, 50.11225993292672, 48.33883646556309, 46.86290706907, 42.88211039134434, 44.37852307728359, 44.46045970916748, 45.30307470049177, 46.66229867935181, 48.296532358442036, 46.302343777247835, 44.79276772907802, 45.10729878289359, 43.33850976399013, 44.23084953853062, 42.56365360532488, 44.466313566480366, 48.51881912776402, 49.675822734832764, 47.59476430075509, 45.12508269718715, 44.791586535317556, 44.49747971126011, 46.938409669058665, 46.44520568847656, 43.77477673121861, 45.66323110035488, 46.87203352791922, 46.092004435403005, 45.3018205506461, 38.8486567905971, 33.82966027941023, 34.688593115125386, 33.4617531640189, 33.03570352281843, 33.51069280079433, 33.41651691709246, 34.88511943817139, 35.22270114081246, 42.27582447869437, 46.48703384399414, 45.463004861559185, 46.336223193577354, 46.25984512056623, 45.95673343113491, 47.832312788282124, 45.83531713485718, 42.40477957044329, 46.52099663870675, 44.494318280901226, 43.906823771340505, 38.42168303898403, 36.56013904299055, 35.75858095714024, 33.783857754298616, 35.24915640694754, 33.84815985815865, 34.98312725339617, 35.69132586887905, 33.745715618133545, 34.45171512876238, 34.30717175347464, 34.73257868630545, 35.14382866450718, 40.408926895686555, 44.73464257376534, 45.56452151707241, 47.68236024039132, 44.99565512793404, 46.33732795715332, 49.262019293648855, 47.24490513120379, 49.29319586072649, 48.35569626944405, 48.534963267190115, 49.220899854387554, 47.28630944660732, 47.05856139319283, 47.264797823769705, 48.628836904253276, 47.463724749428884, 49.08398560115269, 46.88422761644636, 48.068405628204346, 48.99762296676636, 49.63094432013375, 48.895008495875764, 47.610738209315706, 46.80369104657854, 46.137073925563264, 49.17370074135916, 50.24532488414219, 49.37684869766235, 43.79946020671299, 48.26120771680559, 49.5233063016619, 39.83868476322719, 27.030573504311697, 12.505876779556274, 4.566396066120692, 6.62215610912868, 7.487762689590454, 5.067349459443774, 5.334428225244794, 0.608748017677239, 0.06691147134240184, 0.42855973222426, 8.364092077527728, 36.79615197862898, 38.46901764188494, 32.98372752325875, 39.19769607271467, 49.84395524433681, 45.05541658401489, 18.361969675336564, 1.6668234446219035, 0.03196404428620424, 0.011313077810752605, 0.01374416530597955, 0.03418196830898523, 0.012952124949411621, 0.037264155955719094, 0.03201627791193979, 0.015447529930887478, 0.036510971906994066, 0.019919669421921884, 0.0038597896262737258, 0.025342677354014347, 0.027402797880183374, 0.0707587581127882, 0.036983283170099766, 0.05740181662674461, 0.057695968342678886, 0.06695856845804624, 0.10353949054011277, 0.06967542267271451, 0.1918580699712038, 0.09085896704345942, 0.10031879014734711, 0.13825947605073452, 0.18129732379955904, 0.13228394383830683, 0.17314248638493673, 0.12814599302198204, 0.10476974238242422, 0.14667833144111292, 0.13068315759301186, 0.13489251743469918, 0.08684496421899114, 0.21166342150952133, 0.09309134725481272, 0.13365292895053113, 0.1560794748365879, 0.17355169728398323, 0.13672224139528616, 0.2596124921526228, 5.496803283691406, 29.66411794934954, 54.88510261263166, 52.00440379551479, 43.48896953037807, 34.00594997406006, 45.833402906145366, 47.32285349709647, 27.60254052707127, 3.3041389754840305, 0.32633066922426224, 0.733964707170214, 4.523934321744101, 9.494771565709796, 12.922456894602094, 15.279972859791346, 11.603459511484418, 10.118703297206334, 19.486711059297832, 31.516931533813477, 42.278301511492046, 52.546898296901155, 50.38914564677647, 50.40909045083182, 43.59989057268415, 48.150606291634695, 47.214975765773225, 48.10069390705654, 47.22538764136178, 50.448875835963655, 47.35719149453299, 47.16665799277169, 45.67377151761736, 46.24928385870797, 45.654584067208425, 44.22398124422346, 45.67387574059622, 50.92310081209455, 51.9412898336138, 49.935480390276226, 47.181593145642964, 49.0678379876273, 47.10372815813337, 48.93176099232265, 47.31589487620762, 45.31533479690552, 47.51776436397007, 49.98548310143607, 47.055726528167725, 48.55253873552595, 42.015642234257285, 35.65920434679304, 36.992855480739046, 34.421330656324116, 34.42506531306675, 34.42581919261387, 34.723389693668906, 36.84310095650809, 36.79847962515694, 44.16162116186959, 49.46418407985142, 47.19668115888323, 48.471369879586355, 47.060461725507466, 46.785153252737864, 50.07589306150164, 47.51338005065918, 44.33463825498308, 48.80269472939627, 46.87181118556431, 45.05316884177071, 40.05026435852051, 39.04161868776594, 38.81555209841047, 35.015419006347656, 37.04722513471331, 35.24667590005057, 36.52522781917027, 37.66176898138863, 35.12812920979091, 35.80377204077584, 36.48203781672886, 36.21395199639456, 38.56775849206107, 41.97639186041695, 45.311815534319194, 47.42642681939261, 48.13056073869978, 45.975132261003765, 47.62236949375698, 48.85709912436349, 50.21805667877197, 51.23596429824829, 51.164588928222656, 50.77835593904768, 50.06795127051217, 48.6022287777492, 48.34281430925642, 49.27876445225307, 50.64969961983817, 48.245157378060476, 50.31743328911917, 49.328878334590364, 48.5555716242109, 48.795923709869385, 53.13881186076573, 52.887196745191304, 50.834931646074565, 51.30354595184326, 49.1182575907026, 51.484570843832834, 52.47718702043806, 49.660859789167134, 44.63753455025809, 50.427979128701345, 49.18537024089268, 39.554631982530864, 28.008775642939977, 12.894461733954293, 6.980076057570321, 15.068497487476893, 19.77415977205549, 12.974175810813904, 9.31111764907837, 2.3617626173155646, 0.22151699848473072, 0.8116059409720557, 10.387794000761849, 44.96300901685442, 47.59632069723946, 38.09393303734915, 45.2980511529105, 56.64717272349766, 52.280073574611116, 21.407297372817993, 2.263091031994138, 0.0961694128013083, 0.11976905752505575, 0.1451753628041063, 0.13953711677874836, 0.13490017130970955, 0.1815177933978183, 0.14335809674646172, 0.12581701656537397, 0.18826149510485785, 0.253986514040402, 0.11625932157039642, 0.17371248294200214, 0.12224562891892024, 0.15125376092536108, 0.10683873136128698, 0.11976300499268941, 0.2740404265267508, 0.16727927885949612], [0.11595275944897107, 0.04475645820743271, 0.01799063677234309, 0.010529736273123749, 0.015708905012745942, 0.02822916193066963, 0.014996819830100452, 0.02717222998450909, 0.06104710352207933, 0.057997780718973706, 0.05848147440701723, 0.0460786617227963, 0.024302179526005472, 0.019663008462105478, 0.014815539021843245, 0.03797975255708609, 0.01365008981831904, 0.03273256661902581, 0.016105045630995716, 0.038847530992435556, 0.01867433713882097, 0.03746950440108776, 1.274226991193635, 17.00484926359994, 43.95297370638166, 42.68074812207903, 32.51230614525931, 25.62716940471104, 27.524772814341954, 36.8145021711077, 27.005372388022288, 4.747048795223236, 0.1732641477137804, 0.17892800165074213, 0.8806981220841408, 7.780745642525809, 6.3151873009545465, 8.377678411347524, 5.188552532877241, 6.274972430297306, 13.221824373517718, 24.089897836957658, 39.2151186806815, 46.77452598299299, 48.748794078826904, 46.535719871520996, 45.29816927228655, 45.27516378675188, 45.971196106501985, 47.32685565948486, 46.73395892551967, 45.692451749529155, 43.355105536324636, 41.837295872824534, 40.70490278516497, 37.227874823978965, 35.380790029253276, 37.777897698538645, 41.32511636189052, 43.94659178597586, 45.30191782542637, 42.37368638174874, 42.85858726501465, 41.41172565732683, 41.41544989177159, 41.991340909685405, 45.64827857698713, 44.75142594746181, 44.403446265629356, 45.48928642272949, 47.2553447995867, 44.99811131613595, 43.017242431640625, 33.80720370156424, 32.09515367235456, 32.32417672021048, 31.760750770568848, 30.558684621538433, 31.846717357635498, 33.22368703569685, 31.64483744757516, 39.218735218048096, 43.96074526650565, 42.71983173915318, 42.59556668145316, 44.71430172239031, 46.38480847222464, 45.47597714832851, 41.853426115853445, 37.99677637645176, 45.87368161337716, 43.594067982264924, 39.8011714390346, 37.682026454380576, 33.09002453940255, 32.83838163103376, 31.550074441092356, 31.35451739174979, 32.21116427012852, 32.86757448741368, 32.83775976725987, 32.01991162981306, 32.54982641765049, 33.37629726954869, 33.26125247137887, 35.430601664951865, 38.92048726763044, 43.455819674900596, 42.16405575616019, 46.74966532843453, 44.289183139801025, 45.26688500813076, 45.90694611413138, 45.229632241385325, 45.76769379207066, 43.07408217021397, 42.8261912890843, 44.5120188168117, 45.57161215373448, 44.44887706211635, 45.53040586199079, 44.603377205984934, 42.957269055502756, 43.578900064740864, 47.886540004185264, 46.648603779929026, 44.62474986485073, 47.83100305284773, 48.214859758104595, 48.827763829912456, 47.61655385153634, 48.831098965236116, 49.263999530247276, 49.23988580703735, 47.44989783423287, 45.47140523365566, 47.80835887363979, 42.956615924835205, 31.134690284729004, 17.52484028679984, 6.551956287452152, 1.9574108975274223, 5.689847690718515, 7.997458219528198, 3.182615416390555, 3.656323620251247, 0.5313657128385135, 0.05381138928766761, 0.7209215813449451, 10.023488657815115, 31.601960114070348, 25.640850407736643, 25.99534055164882, 36.53164100646973, 45.56340633119856, 38.75703089577811, 11.916018145424978, 0.44763435583029476, 0.0524451183155179, 0.021045588023428406, 0.037465304269322326, 0.013896709308028221, 0.05084435921162367, 0.08729634606944663, 0.020620809834716574, 0.05313318335850324, 0.06411077734082937, 0.02923782289560352, 0.036984294187277555, 0.06439813692122698, 0.06443486602178641, 0.03880635070215378, 0.027456989079447727, 0.07496333428259407, 0.0247223402839154, 0.08119444349514586, 0.05389771590541516, 0.09716172955398049, 0.013780358363874257, 0.0631690996565989, 0.022548135968723466, 0.034370634970920425, 0.01456534450075456, 0.030453659261443784, 0.03422468548108425, 0.06750304531306028, 0.048859098061387024, 0.06145343743264675, 0.0400622240267694, 0.02336438136574413, 0.01516226532735995, 0.050696859269269874, 0.026832007437146137, 0.010151765126335834, 0.027358603198081255, 0.02272747447048979, 0.03839433066813009, 0.041921973161931546, 1.610502106802804, 19.779129471097672, 48.88038601194109, 49.1828202520098, 38.161191599709646, 27.373307296207972, 36.29526329040527, 43.88502727236067, 29.80528450012207, 5.098015333924975, 0.157611824039902, 0.14261071756482124, 0.9481408659900937, 5.390218351568494, 5.060834654739924, 6.4748495221138, 5.867654263973236, 3.957983136177063, 14.253769959722247, 25.535460131508962, 39.533735275268555, 48.33157212393624, 50.17669752665928, 48.13756104878017, 46.39469575881958, 47.452388763427734, 46.91820778165545, 47.47492177145821, 48.72665711811611, 47.32434388569423, 46.288555077144075, 43.807162284851074, 42.35307455062866, 39.174134731292725, 37.663005760737825, 40.78539419174194, 44.241591453552246, 45.49142299379621, 47.36713089261736, 45.12249796731131, 44.328603744506836, 43.88301576886858, 44.39929124287197, 44.35881451198033, 46.120978423527305, 46.741462979997905, 45.47047764914376, 46.516157218388145, 48.44385848726545, 46.962710993630544, 44.689927441733225, 34.83913278579712, 34.694523402622764, 33.931437492370605, 32.84947443008423, 32.71961259841919, 32.18108899252755, 34.29195172446114, 33.360587392534526, 40.016475268772666, 45.71392168317522, 44.71189417157854, 45.639089584350586, 45.11252382823399, 47.22728449957711, 47.45621722085135, 43.52517659323556, 40.71120827538626, 47.76349435533796, 45.20072773524693, 41.35961764199393, 39.46572978155953, 34.607188020433696, 34.89000054768154, 32.75753934042794, 33.68981736046927, 33.29713296890259, 35.19442892074585, 35.142675263541086, 32.69049964632307, 34.584387506757466, 33.74915497643607, 34.70653336388724, 35.851454053606304, 39.853091853005544, 46.41585649762835, 45.055159500667024, 47.17960596084595, 45.64091001238142, 47.08502360752651, 47.59619910376412, 47.85600961957659, 46.950551646096365, 45.4499248777117, 45.8535144669669, 44.80613258906773, 48.53311504636492, 46.3568628174918, 47.961403369903564, 46.453772817339214, 45.323082038334434, 47.095282622746055, 49.45549883161272, 46.604937825884136, 45.75162260872977, 47.478020668029785, 50.79861341203962, 49.40369653701782, 49.32904161725725, 49.64521244594029, 50.902659211839946, 50.489342144557405, 47.12996455601284, 45.47637666974749, 49.271871839250835, 44.510927949632915, 34.192474365234375, 19.457723174776348, 9.096031819071088, 4.872717823301043, 6.959555421556745, 7.823334625789097, 6.366982213088444, 5.88832254920687, 0.7810419010264533, 0.0020211028542170034, 0.7207898369857243, 11.316594447408404, 39.04960911614554, 31.485456194196427, 28.78227342878069, 39.43608181817191, 50.70120661599295, 45.19637468882969, 14.70311951637268, 0.6156092552202088, 0.04629263434825199, 0.07142447560493435, 0.055848181779895506, 0.07292151384587799, 0.028890480819557394, 0.07131184557718889, 0.05351207052756633, 0.03539281065708824, 0.07046274721090283, 0.016046815452032855, 0.06452946737408638, 0.022621480515226722, 0.024136109776528816, 0.04307356583220618, 0.028117302040170346, 0.02435434190556407, 0.018162996541442614, 0.010519168938377073, 0.16612068031515392, 0.22924134614212172, 0.09054964328450815, 0.14159222293112958, 0.10545492025890521, 0.09735333427254643, 0.0720892431480544, 0.20191242545843124, 0.2041255081338542, 0.11741557238357407, 0.2190269242439951, 0.13856937656445162, 0.13198050297796726, 0.09148441348224878, 0.16044160005237373, 0.13278958813420363, 0.12162311375141144, 0.11735774762928486, 0.17703446825700148, 0.0946646189051015, 0.055041152584765635, 0.2113408459616559, 2.1114188049520766, 23.212142331259592, 54.998733452388215, 54.50160026550293, 42.41881840569632, 34.80029582977295, 37.03863368715559, 47.26678153446743, 35.39255680356707, 7.004751716341291, 0.36895032227039337, 0.355107095092535, 3.3652603243078505, 15.125802755355835, 16.77378691945757, 13.839997785431997, 12.068610140255519, 9.755663394927979, 17.548493691853114, 25.639085565294536, 41.524018968854634, 50.8910869870867, 51.907076903751914, 49.41200658253261, 48.575815200805664, 48.620346205575125, 48.08166626521519, 50.925741127559114, 48.88784490312849, 49.68364988054548, 48.42034578323364, 46.678804125104634, 45.29546989713396, 40.407836028507774, 38.42150238582066, 43.305478027888704, 46.948845863342285, 47.614802905491416, 49.02807692119053, 46.26411826269967, 47.131583486284526, 45.57502371924264, 45.883825983319966, 46.237096718379426, 48.99293988091605, 49.59010280881609, 46.65097311564854, 46.98873199735369, 51.765236377716064, 49.61886487688337, 48.28496013368879, 37.3857934815543, 36.35646997179304, 35.54358284814017, 35.72130734579903, 34.14791556767055, 34.00972979409354, 36.24634797232491, 33.42307601656233, 42.271662507738384, 47.36265625272478, 48.2348393031529, 46.70606190817696, 46.33464595249721, 47.43746403285435, 48.417191301073345, 43.717002459934776, 42.7847626549857, 51.26258979524885, 47.042382512773784, 42.487622942243306, 41.83131347383772, 36.14580059051514, 36.36715977532523, 34.013603414808, 34.742316586630686, 34.62450293132237, 35.407210554395405, 37.13016925539289, 34.192106110709055, 35.65566423961094, 35.210340295519146, 36.50252458027431, 39.470972197396414, 42.49802439553397, 47.87753513881138, 45.927721227918354, 48.77443987982613, 47.65824999128069, 48.63800157819475, 49.96213715417044, 48.403385230473106, 50.03072282246181, 46.877817903246196, 45.11106818062918, 47.35216447285244, 50.689161913735525, 48.55696473802839, 49.68619292122977, 48.84136145455496, 46.763474873134065, 47.38136427743094, 52.54545654569353, 49.074952942984446, 45.72512565340315, 49.22059760774885, 51.087512561253135, 52.1687981741769, 51.04660504204886, 52.2037684576852, 51.57447011130196, 50.001060962677, 48.562457289014546, 44.435046672821045, 48.14365461894444, 45.44479710715157, 33.70588854381016, 19.612490824290685, 9.119937096323286, 6.595677392823355, 12.032315356390816, 18.01158765384129, 8.981760876519338, 7.204908907413483, 1.607210397720337, 0.34034081601670807, 1.1262990832328796, 14.699287584849767, 42.53656952721732, 36.37242998395647, 35.519323212759836, 49.986921378544395, 57.892293385096956, 51.67100143432617, 19.045981611524308, 0.9673884617430824, 0.16655343637934752, 0.17877952461796148, 0.14400494417973927, 0.1508244653897626, 0.08187316171824932, 0.2874564209154674, 0.14415465614625386, 0.11316083890518971, 0.13358432906014578, 0.16853439222489083, 0.1768505038427455, 0.1521799883672169, 0.1031228903947132, 0.12285515692617212, 0.15009128116071224, 0.14009492684687885, 0.15578231721052102, 0.1491752860269376], [0.013577160026345934, 0.028417952425245727, 0.03467110384787832, 0.044844118146491904, 0.008843451222803975, 0.017997883526342254, 0.04211512154766491, 0.06650853689227786, 0.084777271242014, 0.05833957916391747, 0.01787643593602947, 0.03932864624740822, 0.03795434820598789, 0.017368167405948043, 0.046620661924992285, 0.02564474248460361, 0.043926603094275506, 0.02924828590559108, 0.003924717369955033, 0.004645733345699097, 0.0889606431924871, 0.02606995154305228, 0.644020384975842, 11.174974526677813, 37.22701324735369, 44.26299885341099, 36.992118971688406, 28.532671553747996, 24.467157227652415, 39.093400137765066, 31.38184813090733, 9.190960713795253, 0.14332742696361883, 0.09668060751365763, 0.3814460060426167, 1.9741000362804957, 2.7528734590326036, 5.130624966961997, 3.2830079836504797, 2.932338914700917, 9.81097366128649, 24.098431961877004, 34.65853173392159, 49.07141978400094, 48.72463171822684, 44.966510908944265, 46.34375156675066, 46.894570010049, 47.04079137529646, 46.150994641440256, 44.9265900339399, 41.44767911093575, 41.82051249912807, 36.72455774034773, 34.95425401415144, 33.41896963119507, 32.134334564208984, 32.49389689309256, 36.331102098737446, 39.07551894869123, 39.741013935634065, 39.35094206673758, 36.73609175000872, 35.92298575810024, 37.340400900159565, 40.8785000528608, 42.68574387686593, 43.06316655022757, 44.504403591156006, 42.31213576453072, 45.998638016836985, 45.87066609518868, 42.25156831741333, 34.68882587977818, 31.005624021802628, 33.07126440320696, 32.3293149130685, 31.34717661993844, 30.17279209409441, 32.70302030018398, 31.644712380000524, 34.82116821834019, 42.52332626070295, 44.57290588106428, 45.03569064821516, 44.29856320789882, 44.635130473545615, 43.87181527273995, 41.17444120134626, 37.91824088777815, 44.05322231565203, 43.20423582621983, 41.88372026171003, 36.39917360033308, 33.91626957484654, 33.20078924724034, 34.7008011000497, 34.15338727406093, 32.71446050916399, 32.510596888405935, 32.78401892525809, 33.51397582462856, 31.63670458112444, 32.38471984863281, 33.778764724731445, 37.62223373140608, 43.79867853437151, 43.26678350993565, 46.595130443573, 46.10212448665074, 46.903217043195454, 47.19353362492153, 43.76147093091692, 42.675700255802695, 42.14887046813965, 40.600033623831614, 41.61298022951399, 42.31379638399397, 42.79285383224487, 43.524773597717285, 42.59750870295933, 40.748606954302105, 39.005050318581716, 42.88404199055263, 44.1195741380964, 45.52432271412441, 47.06986263820103, 45.057098048073904, 44.4283173424857, 46.24835974829537, 46.59418548856463, 47.89034761701311, 45.08505065100533, 46.22573641368321, 47.02527952194214, 47.52714443206787, 47.113521644047324, 38.20060873031616, 24.26170768056597, 11.042956147875104, 3.663289189338684, 2.191225379705429, 3.516087693827493, 3.5166691711970737, 4.261260279587336, 9.234226277896337, 0.09419561550021172, 0.07217595313808747, 0.8254411071538925, 10.238974009241376, 32.252228123801096, 33.41586031232561, 34.56959479195731, 42.02520990371704, 47.62241118294852, 29.818162986210414, 9.115523253168378, 0.2352028733917645, 0.07068980538419314, 0.033786039732928784, 0.05816464605075972, 0.05351073381357959, 0.06170215444373233, 0.0666121356189251, 0.05036910989188722, 0.08191695436835289, 0.03156393254175782, 0.039019960311374495, 0.03303955961018801, 0.015818401905042783, 0.019712366795699512, 0.011524909658224454, 0.05151959655008145, 0.024058717768639326, 0.06237910169043711, 0.08518374764493533, 0.02082273337457861, 0.03769818427307265, 0.011954297644219227, 0.026785575285820023, 0.04318973781274898, 0.0057332786714791185, 0.05190248707575457, 0.019408556133774773, 0.030306858210159198, 0.045556132082960436, 0.025909612021808113, 0.03385289918099131, 0.013223458380837525, 0.08902311591165406, 0.04865573433094791, 0.03049994892041598, 0.032124680666519065, 0.04334503072979195, 0.09664020753864731, 0.0299170805540468, 0.057068866278444014, 0.03355947010485189, 0.9337684086390904, 14.655604260308401, 45.02940600258963, 49.97690207617623, 40.331725461142405, 30.93154580252511, 29.180339200156077, 41.991597993033274, 34.92866379874093, 9.745922020503453, 0.40428326917546137, 0.06042703786598785, 0.41725208184548784, 1.6569501629897525, 4.103909637246813, 4.471209219523838, 4.182453376906259, 3.420990739549909, 10.66413254397256, 25.467970541545323, 36.45526988165719, 49.505324363708496, 48.20137677873884, 47.05356216430664, 47.536142349243164, 48.821135248456685, 48.766699586595806, 47.153397355760845, 46.98386825834002, 44.72582878385271, 43.00656999860491, 39.05605009623936, 37.02492141723633, 34.82534408569336, 33.94979115894863, 35.15020363671439, 38.590711866106304, 41.68996279580252, 41.77422707421439, 41.7907464163644, 39.421709469386506, 38.46592221941267, 40.155995096479145, 42.95566054752895, 44.7278368132455, 44.38824708121163, 46.083190645490376, 42.9519293648856, 46.68462324142456, 47.840897287641255, 45.020613057272776, 36.79501942225865, 33.317248003823416, 34.13818808964321, 33.393963064466206, 33.362539836338584, 31.80294370651245, 34.47419949940273, 33.691238267081125, 37.337579931531636, 43.24975347518921, 46.82649850845337, 45.96973351069859, 46.132331780024934, 46.28444174357823, 45.75751468113491, 41.40654230117798, 39.64564643587385, 46.85774803161621, 45.196437222617014, 43.74150875636509, 37.837468079158235, 36.63328620365688, 35.75087193080357, 35.7647613797869, 34.764988558632986, 35.056194509778706, 34.68806505203247, 34.48798472540719, 34.05221108027867, 33.415502480098176, 34.03456265585763, 35.65606723512922, 38.35179805755615, 45.285259519304546, 45.10161515644619, 48.674069677080425, 47.83234058107649, 47.75510093144008, 47.99359089987618, 45.537173407418386, 44.160537242889404, 44.54856981549944, 42.49215316772461, 45.26009661810738, 45.40453577041626, 45.48507234028408, 45.72488246645246, 45.1217371395656, 43.05627046312605, 43.28592927115304, 44.87132058824812, 45.53308439254761, 47.44529465266636, 49.18497766767229, 46.15606335231236, 46.32244838987078, 46.379374980926514, 48.07736880438668, 48.665460859026226, 45.81084557941982, 46.672620228358674, 48.00569813592093, 48.84584999084473, 48.146534647260395, 38.92256130490984, 26.45352734838213, 13.613094806671143, 4.607518545218876, 3.689868220261165, 6.355006558554513, 5.667681634426117, 6.140586452824729, 4.6647795183318, 0.20169770983713015, 0.03156766448436039, 0.9490654106651033, 13.019445930208478, 36.53208916527884, 32.14401340484619, 33.70046894890921, 46.85876941680908, 54.44051170349121, 35.44139916556222, 12.904577442577907, 0.24381359134401592, 0.024235326863293136, 0.04548354579934052, 0.04711077116163714, 0.023544227072436894, 0.05383690220436879, 0.05473243272198098, 0.031773874669202735, 0.02730147394218615, 0.04067962643291269, 0.02076559224432068, 0.037183210120669434, 0.02336681561012353, 0.033951232475893836, 0.02229165142801191, 0.03272981515952519, 0.054384313723338504, 0.01714399131014943, 0.013545008492656052, 0.11168575127209936, 0.09253875512097563, 0.13677911620054925, 0.212351388164929, 0.1216561176947185, 0.10043357791645185, 0.17924054845103196, 0.16108323633670807, 0.12141001304345471, 0.11779201004121985, 0.13336605791534695, 0.15073282245014394, 0.11654729183231081, 0.20846934004553727, 0.18969294615089893, 0.12756058014929295, 0.07300117385706731, 0.12470921315252781, 0.17741421716553823, 0.0908753943762609, 0.29547784477472305, 0.11602769685643059, 1.2680598135505403, 16.019619022096904, 49.712953908102854, 56.184631143297466, 47.100514616285054, 37.7552604675293, 34.88545642580305, 49.06859881537301, 38.80944810594831, 12.871001141411917, 0.5166511652725083, 0.6714557270918573, 1.3116392408098494, 7.598928655896868, 10.451033898762294, 11.483065468924385, 10.174165555409022, 5.301465971129281, 12.592934233801705, 26.378556285585674, 37.170044967106406, 49.555598054613384, 49.945034163338796, 47.32878031049456, 46.573670932224815, 50.02432700565883, 50.83190223148891, 48.32420355933053, 49.306112561907085, 47.1071640423366, 46.09789303370884, 40.131228242601665, 37.86932209559849, 36.44060918263027, 36.01936422075544, 36.91359737941197, 39.612222126552034, 42.96274423599243, 42.866490840911865, 42.881179332733154, 40.52064003263201, 40.199487345559255, 41.40033408573696, 43.17460175922939, 44.989981923784526, 45.7170865876334, 47.652062620435444, 42.10621200289045, 47.59591770172119, 50.081059047154014, 46.3756993838719, 39.95112746102469, 34.40670122419085, 37.73675741468157, 35.13634545462472, 33.85427079881941, 33.01409462520054, 36.81723976135254, 35.628125054495676, 38.128743512289866, 44.8900911467416, 48.51639420645577, 47.50707803453718, 48.96877752031599, 46.56498220988682, 47.555308955056326, 41.47414132526943, 41.950377804892405, 47.54170090811593, 46.61228901999337, 45.49051972797939, 39.480088233947754, 38.62137426648821, 37.505524839673726, 37.367290428706575, 36.78595897129604, 35.293784686497276, 35.9286207471575, 35.04771075929914, 35.983719961983816, 35.86652817044939, 35.96826369421822, 36.38721227645874, 41.11922039304461, 48.22726576668875, 47.91192524773734, 51.04164750235421, 49.85891819000244, 49.22952604293823, 50.14331143242972, 47.417849268232075, 45.640065806252615, 46.46476486751011, 43.89302464893886, 46.22189058576311, 46.02415527616228, 47.13591568810599, 48.14715998513358, 44.44657373428345, 43.39933776855469, 44.134606565747944, 47.31137159892491, 47.21020582744053, 49.337129320417134, 51.67685876573835, 47.690006732940674, 46.15644202913557, 47.02568251746041, 47.57905094964163, 48.787999289376394, 46.0479667527335, 48.452126843588694, 49.68510205405099, 51.40882853099278, 49.86307668685913, 41.86877816064017, 27.519667625427246, 14.355069484029498, 5.648415148258209, 5.642976880073547, 10.451053006308419, 11.233454040118627, 12.757264341626849, 15.771457161222186, 1.3171038904360362, 0.2687936680657523, 1.236780543412481, 14.98509304864066, 43.795603956495015, 43.49167585372925, 44.47540875843593, 53.50936276572091, 61.25927925109863, 41.54892826080322, 13.882938521248953, 0.5569605965699468, 0.1430789745811905, 0.13617193592446192, 0.15983474547309534, 0.17915475448327406, 0.1136425987684301, 0.15415098331868649, 0.14726679772138596, 0.12370168364473752, 0.09736642999840633, 0.13779341748782567, 0.10114075389823743, 0.09254533012530633, 0.12391897769910948, 0.0840338614902326, 0.20872702050421918, 0.2106433798159872, 0.10025392219956432, 0.10762477346829005], [0.021535400401002595, 0.031541805514799695, 0.06995310634374619, 0.14292683345930918, 0.022535876537274038, 0.03354111233992236, 0.05458106852269598, 0.02967834140041045, 0.006722822760431362, 0.04048286484820502, 0.04588188996006336, 0.05324852413364819, 0.02814769192731806, 0.04972914280369878, 0.059159541236502786, 0.02283571437666459, 0.028661437931337526, 0.01285462370807571, 0.021110890233623128, 0.05870323322181191, 0.008514773100614548, 0.07073177277509655, 0.10302140869732414, 6.81169775554112, 30.687132494790212, 42.87472445624215, 40.37018721444266, 23.918807131903513, 24.03508176122393, 31.377053873879568, 36.42547600609915, 12.622206994465419, 0.6185986090983663, 0.025012319009484987, 0.5256236238139016, 1.4352497564894813, 2.1196294043745314, 2.314509004354477, 3.2265451848506927, 1.5460195669106074, 6.491034482206617, 24.26324496950422, 37.92541490282331, 47.01533317565918, 40.87700271606445, 46.593806811741416, 50.074982847486226, 46.03826011930193, 44.73470858165196, 43.20036915370396, 41.49903324672154, 40.16973863329206, 34.11014168603079, 32.71625314440046, 32.631679671151296, 33.294179984501426, 33.69580670765468, 32.70228031703404, 31.415161269051687, 32.35491207667759, 32.41467353275844, 31.959924357278005, 32.284151622227256, 32.272044386182515, 35.64164277485439, 38.5318397794451, 40.952286447797505, 44.51573610305786, 46.11528090068272, 44.09202800478254, 43.110865933554514, 45.914144447871614, 42.38256965364729, 34.67392199380057, 31.983249459947857, 32.140313489096506, 30.881452764783585, 30.15304183959961, 30.23894589287894, 31.944117205483572, 30.543495859418595, 32.861460072653635, 38.87981251307896, 41.7309502192906, 43.03159046173096, 45.62359857559204, 45.128598485674175, 44.51925883974348, 44.168246269226074, 37.626468658447266, 45.028259549822124, 44.98036214283535, 40.04250322069441, 40.0560348374503, 34.53192513329642, 35.811710357666016, 33.18370015280587, 32.44198342732021, 32.64518002101353, 33.48543609891619, 33.24323231833321, 33.0691556249346, 32.52650131498064, 32.40822907856533, 32.2979542187282, 42.54111017499651, 45.702752453940256, 45.44115277699062, 47.02650587899344, 42.61771753856114, 46.95089905602591, 44.3902724811009, 44.95980937140328, 43.33844723020281, 37.45526851926531, 36.624173641204834, 34.91101884841919, 36.39308697836739, 36.00644751957485, 34.73199503762381, 35.90750864573887, 32.93241855076381, 33.89317028863089, 36.80555983952114, 41.65701443808419, 45.522953919001985, 44.885234355926514, 46.542939049857004, 46.40547241483416, 47.02328191484724, 47.31204557418823, 45.55125740596226, 46.42072371074131, 48.83197791235787, 49.51596552985055, 49.85040317262922, 49.06581606183733, 35.60234376362392, 20.47793412208557, 7.020627481596811, 2.4712134642260413, 4.116105897086007, 5.32580029964447, 3.998608819075993, 3.0167983940669467, 6.146054685115814, 0.6824736158762659, 0.0489491260876613, 1.5329319834709167, 14.176906381334577, 38.994801725660054, 35.342578411102295, 36.92313378197806, 49.62308243342808, 44.915306159428184, 29.264975207192556, 4.699121858392443, 0.31494436306612833, 0.036615768247949224, 0.015203560968594891, 0.0106386767667053, 0.0791306724505765, 0.05774592887610197, 0.07528916679854904, 0.06065029624317374, 0.014096145168878138, 0.013475925994238682, 0.06292646910463061, 0.10028710256197623, 0.015859799326530526, 0.02138956626211958, 0.0734086273504155, 0.016560632702229277, 0.003209189894343061, 0.049701913193400414, 0.045742624040160856, 0.11757643946579524, 0.03719180715935571, 0.01986646040209702, 0.06722840147891215, 0.0038110839585507555, 0.019176079858360544, 0.019450761011934707, 0.03837636306083628, 0.03194004110991955, 0.029835717419960668, 0.04742268692435963, 0.03970220013122473, 0.05648155350770269, 0.10353261698037386, 0.058801681867667606, 0.059643818464662345, 0.0065050859619597235, 0.038131177824522765, 0.013679121787260686, 0.005288409484949495, 0.04455569326611502, 0.035226769745349884, 0.22509411296674184, 8.566182170595441, 36.73480633326939, 49.09593997682844, 45.30893203190395, 28.937159197671072, 28.6512599331992, 37.68629959651402, 40.14752524239676, 14.006414089884077, 0.7433090029018266, 0.09221032381589923, 0.5499011182359287, 2.2184712205614363, 2.393021911382675, 4.425442738192422, 5.8400477681841165, 3.4810579163687567, 9.146960377693176, 23.656001942498342, 38.931413309914724, 47.65579727717808, 45.41059807368687, 47.48163373129708, 50.64681959152222, 48.14677783421108, 47.503221784319194, 46.07615906851632, 43.22940567561558, 42.93633760724749, 37.58456754684448, 33.855993952069966, 34.60712201254708, 34.57578911100115, 35.36953394753592, 34.199307918548584, 33.96791900907244, 35.78511960165841, 34.87034409386771, 33.659380776541575, 33.686416217258994, 36.10205125808716, 39.12339203698294, 40.97844988959176, 42.41851268495832, 45.35342134748186, 47.74398728779384, 44.036018575940815, 44.97953183310372, 47.572526591164724, 43.721393721444265, 36.5844646862575, 33.23320606776646, 32.99918726512364, 31.497011048453196, 32.461143084934776, 32.13482788630894, 33.35745375497, 31.977927139827184, 34.7155555997576, 41.34618330001831, 43.460895333971294, 44.177713189806255, 48.699778011866975, 46.10643236977713, 46.66568940026419, 44.85967888150896, 39.37844998495919, 47.05963488987514, 45.546734128679546, 41.93845469611031, 40.9026380947658, 36.5246650150844, 36.59295538493565, 37.24227843965803, 34.149333000183105, 34.691657270704, 34.56286893572126, 34.86642183576311, 35.11563287462507, 34.248563698359895, 34.34252071380615, 34.32477501460484, 42.856124128614155, 48.084542819431846, 47.39575399671282, 49.53846379688808, 44.60442638397217, 47.90931967326573, 46.24135249001639, 45.90330178397042, 43.94860676356724, 38.75427940913609, 38.37977845328194, 38.104688848767964, 38.99252271652222, 38.319436822618755, 37.33561359133039, 38.68960210255214, 35.84429046085903, 36.03617191314697, 39.59819023949759, 44.76319966997419, 47.61937134606497, 47.06423807144165, 48.26439346585955, 48.5219076020377, 48.26805516651699, 49.65906367983137, 46.981363432747976, 48.13203723090035, 51.0269763810294, 50.20520598547799, 51.54881041390555, 50.4134122303554, 36.88170167378017, 23.327520642961773, 8.668752346720014, 3.7927137187549045, 3.8130267773355757, 5.937904025827136, 6.308995587485177, 5.114838225500924, 7.545000212533133, 0.6195449754595757, 0.08716717335794653, 1.4780840980155128, 14.856395040239606, 40.62282371520996, 38.79868534633091, 40.01926497050694, 53.42237131936209, 51.09905004501343, 33.29005970273699, 6.084207032408033, 0.3190911348376955, 0.07805495017341205, 0.017222910021830882, 0.0851756323661123, 0.05372326455212065, 0.02719367847644857, 0.054398233869246075, 0.028976152651011944, 0.06614867584513766, 0.06093087047338486, 0.06604391682360854, 0.04818590311333537, 0.05246409015463931, 0.03933374883074846, 0.025339086207428148, 0.03772156658981528, 0.02016301922100995, 0.12033035526318209, 0.05570081415187035, 0.1833863974149738, 0.15792240308863775, 0.2098491002938577, 0.3282065742782184, 0.09012235621256487, 0.09750725315617663, 0.10467562278998749, 0.0899516978700246, 0.11093712358602456, 0.07306496293417045, 0.09001801109739713, 0.10073779909206287, 0.15160484851471015, 0.15232913036431583, 0.1896805153893573, 0.18064356887979166, 0.08128577430865594, 0.08422248744006668, 0.09479521654014077, 0.10248530496444021, 0.1046928372234106, 0.10752580913582019, 0.4095393642783165, 9.660605958529882, 40.755784443446565, 55.0236496925354, 52.5081273487636, 34.60725055422102, 34.84781108583723, 39.24833454404558, 45.46038539069039, 16.588905777250016, 1.1373231602566582, 0.21809851191937923, 1.3031932711601257, 4.122951175485339, 6.9206277046884805, 8.70459462915148, 8.515184129987444, 4.655237036091941, 8.701548712594168, 27.073846885136195, 39.57748808179583, 50.02531017575945, 47.10227945872715, 48.11846045085362, 52.2900025503976, 50.069646630968364, 48.35913215364729, 48.216919898986816, 45.62256676810128, 44.78162281853812, 38.10424068995884, 34.89160558155605, 34.618933950151714, 36.49185562133789, 38.203877857753206, 35.66078158787319, 35.613537311553955, 36.80792222704206, 35.3129825592041, 34.522291455950054, 34.95262118748256, 37.743417263031006, 39.82066808428083, 43.34909187044416, 44.443929944719585, 47.44815731048584, 49.597026688711985, 46.22339139665876, 47.19598286492484, 50.08400508335659, 46.89654677254813, 37.86902332305908, 35.6260266985212, 34.93544176646641, 33.311005047389436, 33.25709397452218, 32.99400390897478, 35.82458536965506, 32.70655345916748, 36.86941031047276, 42.851757185799734, 44.350348131997244, 47.871417249952046, 49.24501705169678, 46.501649379730225, 48.235096386500764, 44.93726594107491, 41.24634116036551, 49.04534319468907, 47.512431621551514, 44.285907064165386, 45.35014874594552, 37.52305861881801, 40.006553241184776, 38.11989845548357, 35.57475594111851, 36.95436246054513, 35.94552224023001, 35.88949196679251, 36.915720054081504, 36.52356025150844, 35.84602403640747, 35.61535079138619, 45.52244322640555, 50.0836889403207, 50.17756257738386, 50.04948990685599, 44.61273642948696, 49.838493960244314, 48.198920590536936, 48.897068636757986, 45.49632147380284, 40.668918064662385, 39.95146097455706, 38.00185203552246, 40.70529188428606, 39.8900910105024, 37.90611975533621, 40.71349423272269, 36.66185024806431, 36.82310404096331, 40.62353590556553, 47.10252264567784, 49.304372038160054, 48.30081244877407, 50.26969221660069, 50.45155784061977, 51.19619975771223, 51.76258216585432, 49.29072230202811, 49.904352460588726, 53.29922144753592, 51.28403888429914, 52.421657017299104, 53.10591214043753, 39.610078607286724, 24.68770694732666, 9.69137692451477, 4.906824793134417, 9.010235462869916, 14.820726462772914, 11.952417152268545, 10.566603285925728, 13.336471387318202, 2.6715678104332516, 0.2776424161025456, 2.442780349935804, 19.431269645690918, 49.513863699776785, 47.453340666634695, 48.683811051504954, 62.57706069946289, 58.182776723589214, 40.520893641880576, 7.5096703597477505, 0.4699875520808356, 0.24264154423560413, 0.08583602335836206, 0.10623069613107614, 0.12753805278667382, 0.11612430667238575, 0.1750313514577491, 0.14789342481110776, 0.25001873980675426, 0.15090419325445378, 0.13707095411206993, 0.16524159748639378, 0.1461839915386268, 0.07232415197151047, 0.14652488753199577, 0.11358509292559964, 0.09620475769042969, 0.19831004233232566, 0.13241255336574145], [0.03967270760663918, 0.0683051347732544, 0.06242026841001851, 0.03171694218846304, 0.015967815316149166, 0.03333237461213555, 0.05817010825765984, 0.056802045953060896, 0.015908119501546025, 0.06833564849304301, 0.021516912018081973, 0.059928701392241886, 0.04123013885691762, 0.012277680648756879, 0.03213652788794466, 0.034954704344272614, 0.02199044803689633, 0.03914841716842992, 0.006700110072935266, 0.0384242981672287, 0.016986226829301034, 0.04380226833745837, 0.046237120005701265, 3.0980818952832903, 25.948304721287318, 46.371040616716655, 46.25712142671858, 25.034901482718332, 23.139306102480205, 30.850686141422816, 39.18231623513358, 16.990650619779313, 1.911809218781335, 0.04648326876174126, 0.3311597758105823, 1.602828255721501, 1.7329537932361876, 2.273974516562053, 3.627698127712522, 2.265471875667572, 8.790549056870596, 20.4507406098502, 39.65007938657488, 41.50562708718436, 46.655788217272075, 52.070109435490195, 45.57621186120169, 44.958871364593506, 42.617363180433, 40.48190035138811, 38.53515059607369, 33.50512729372297, 31.99480778830392, 31.977440765925817, 32.24635342189244, 33.55969844545637, 33.97639581135341, 32.74254860196795, 33.81711530685425, 32.31022473743984, 32.40565129688808, 31.953215871538433, 32.82762581961495, 33.09072978155953, 36.850646700177876, 41.06596939904349, 43.481965746198384, 44.657830238342285, 45.190270696367534, 43.6259880065918, 46.56540952410017, 44.42115027563912, 41.001319885253906, 33.62650537490845, 31.818441663469585, 31.0921916280474, 31.74535356249128, 31.282026835850306, 32.11346217564174, 31.107578413827078, 32.718236855098176, 31.54966449737549, 36.14794063568115, 39.467689173562185, 41.84271546772548, 42.611370359148296, 45.70026847294399, 44.093136242457796, 45.40291336604527, 33.59108345849173, 43.185795307159424, 45.14378377369472, 41.739941188267295, 41.32575907026018, 37.3374479157584, 35.31735645021711, 31.98602179118565, 31.111799444471085, 32.42299747467041, 32.343534401484895, 31.456412724086217, 33.160065855298726, 32.354793957301546, 32.27000161579677, 36.54209457124983, 41.84423017501831, 44.92564855303083, 45.67438643319266, 45.07131058829171, 44.30263485227312, 44.14608498982021, 47.05811670848301, 43.39116668701172, 40.86616700036185, 36.24219989776611, 36.28685597011021, 33.518697125571116, 32.66967242104666, 34.051050731113975, 33.85522617612566, 34.65287937436785, 32.04896204812186, 32.432638100215364, 33.90940475463867, 34.27748557499477, 38.998762198856895, 41.648718288966585, 45.18429177148001, 44.16379247392927, 45.576875414167134, 45.66173723765782, 45.701077938079834, 46.06757456915719, 46.884453432900564, 45.3101931299482, 49.25251415797642, 47.994803360530305, 35.05176503317696, 18.39392270360674, 5.921146273612976, 2.0131513008049557, 2.2189838673387254, 3.5235376826354434, 3.6939611434936523, 3.8231663703918457, 3.7863552485193526, 0.5323441603354045, 0.026566856307908893, 1.9281040472643716, 15.916705778666906, 31.83407163619995, 37.38304546901158, 43.81374222891671, 45.901241643088206, 40.09329802649361, 24.086812836783274, 3.201760960476739, 0.11088662022458655, 0.0953291557463152, 0.029840372170188596, 0.038779677490570715, 0.053375620527991226, 0.03981773768152509, 0.032270413025149276, 0.053640015090682676, 0.013755427290951567, 0.024780743489308015, 0.012927846966444381, 0.02693955014858927, 0.027331293859918202, 0.1187483508672033, 0.024512113171762655, 0.01924418781085738, 0.004272449603636882, 0.03699266391673258, 0.048851227055170705, 0.022633726375975778, 0.028317953326872418, 0.053740736828850846, 0.030632884108594487, 0.03618960075878671, 0.029778221755155494, 0.07714607965733324, 0.03983793766903026, 0.07295447707708393, 0.016986260756051967, 0.033601661412311454, 0.03665602233793054, 0.013365740388897913, 0.011996041966735252, 0.08042256919933216, 0.007559880946895906, 0.018184579044048275, 0.045033605835799656, 0.017317813322214142, 0.0880718030301588, 0.021278495168579475, 0.018364375556952188, 0.09758350013622216, 4.503606063979013, 30.649452413831437, 51.648690768650596, 51.47796310697283, 27.88972520828247, 26.542743955339702, 33.381209645952495, 42.01377316883632, 18.746621949332102, 1.5693930898393904, 0.05920794792473316, 0.38908568610038075, 1.3794714638165064, 3.4231661771024977, 4.392932116985321, 4.918164687497275, 2.7264084219932556, 8.599220854895455, 21.969186033521378, 39.436047077178955, 45.480858257838655, 45.88991955348423, 52.4243529183524, 48.60540410450527, 47.04923691068377, 45.15064859390259, 42.689728668757844, 40.42760017939976, 36.068776335035054, 32.80039235523769, 33.110636370522634, 32.997460637773784, 34.70523057665144, 34.982720783778596, 33.92328725542341, 35.4809969493321, 33.63281086512974, 34.06806339536394, 33.25191409247262, 33.95431096213204, 34.70759296417236, 37.801375661577495, 42.2982428414481, 45.78325080871582, 46.12240627833775, 46.848524297986714, 43.1858161517552, 47.380930015019004, 46.025680405753, 42.572627203805105, 34.47082267488752, 34.269832134246826, 32.259155477796284, 33.28058583395821, 33.742679255349294, 32.79678624016898, 33.20953355516706, 34.02782637732369, 33.19399043491909, 37.882318701062886, 42.564317158290315, 42.99547372545515, 44.393458230154856, 47.21810245513916, 46.77775342123849, 45.40889923913138, 37.17040627343314, 45.84672260284424, 47.129995822906494, 42.985308510916575, 43.95588500159127, 38.86117049625942, 36.65089293888637, 33.62295137132917, 33.439102036612375, 34.03462518964495, 34.462523051670615, 33.22570548738752, 35.09703254699707, 33.119519642421174, 33.55889940261841, 36.99460295268467, 45.00826958247593, 47.10522549492972, 47.541520254952566, 45.93630920137678, 44.087150369371685, 46.094241755349294, 49.291715894426616, 44.481123651777, 42.78395318984985, 38.94248526436942, 37.27160678591047, 33.44743292672293, 34.219297885894775, 34.83203520093645, 34.892835412706646, 35.941495759146555, 33.678127016339985, 34.03279086521694, 37.08042015348162, 37.973927225385395, 42.25019257409232, 43.22489282063076, 46.95974063873291, 45.36754356111799, 46.81060103007725, 47.23802294049944, 47.95801264899117, 47.76616593769619, 48.40220056261335, 47.73918955666678, 51.314534527914866, 49.62061582292829, 37.30907494681222, 19.715716736657278, 7.314668297767639, 3.174872951848166, 3.7723455088479176, 6.413848681109292, 6.668625661305018, 3.604465740067618, 5.795749093805041, 0.9327971807547978, 0.026397359956588064, 2.2482631419386183, 18.90304674421038, 37.29721784591675, 38.3277017048427, 47.93244675227574, 53.298599583762034, 47.32181126730782, 31.220101015908376, 4.487328605992453, 0.16042732367558138, 0.0738789267571909, 0.04203452515814986, 0.08313200024089643, 0.02083018877809601, 0.02687698752353234, 0.04863860132172704, 0.04882951732724905, 0.03741640903587852, 0.03252961000959788, 0.030616253215287412, 0.038711355799543004, 0.03616835243467774, 0.02668871441190796, 0.06691829061933927, 0.004386364182989512, 0.03286910143547824, 0.05149068417293685, 0.039071176134582074, 0.10917738372726099, 0.10158792204622712, 0.11667826266161033, 0.12996589179549897, 0.13774351802255425, 0.1213441544345447, 0.20470933323459967, 0.08962748026741402, 0.16031126704599175, 0.14320671558380127, 0.1901114665504013, 0.12614911874490126, 0.10709625575691462, 0.08120128991348402, 0.15117496943899564, 0.14151713624596596, 0.1164656640695674, 0.08204035953219448, 0.17233798812542642, 0.15801966429821082, 0.0976902065532548, 0.18439079209097795, 0.12972769886255264, 4.8019855959074835, 34.411346094948904, 58.898163250514436, 56.55377851213728, 35.848924909319194, 32.62999473299299, 40.71375479016985, 48.811908040727886, 22.8912102494921, 2.3857163148266927, 0.3055430161101477, 0.9460902788809368, 5.04312630210604, 6.27879741362163, 8.437903659684316, 7.260220042296818, 3.8020312530653815, 10.194325753620692, 22.23338607379368, 40.5168011529105, 46.84556089128767, 47.843839849744526, 53.19281326021467, 49.6986197744097, 48.91377558026995, 47.56314999716622, 44.60481200899397, 42.08328642163958, 38.71809319087437, 34.60273422513689, 34.87264742170061, 35.34216846738543, 36.36908442633492, 37.922628675188335, 35.413898195539204, 37.8795359475272, 35.20770345415388, 34.804947648729595, 35.72521570750645, 36.340148653302876, 36.34880610874721, 40.463560581207275, 44.82219682421003, 47.84131070545742, 47.66402047021048, 47.31624576023647, 42.95782143729073, 48.747970717293875, 49.04417242322649, 45.39639595576695, 36.56140014103481, 36.35343360900879, 34.98437098094395, 35.335838658469065, 35.36785248347691, 34.260278361184255, 34.29379647118704, 35.9828861781529, 34.43246514456612, 39.43133272443499, 43.69400044849941, 45.05697992869786, 45.71480757849557, 48.387341839926584, 47.53526340212141, 47.88139138902937, 38.76171050752912, 47.01341894694737, 48.79945339475359, 45.713789667402, 44.63950089045933, 41.49216495241438, 37.48101854324341, 36.08845363344465, 33.97362000601632, 36.22972788129534, 35.8119535446167, 35.01624584197998, 35.20385415213448, 34.85999822616577, 35.77901908329555, 40.15653705596924, 46.44042532784598, 48.435937540871755, 48.89236123221261, 47.010361739567344, 44.90635340554373, 46.79193122046334, 51.16744116374424, 45.816887038094656, 44.145480496542795, 40.93406479699271, 39.28508356639317, 35.29918691090175, 35.552257674080984, 38.477581296648296, 37.03897067478725, 37.62894221714565, 35.87680803026472, 35.47348942075457, 38.51529264450073, 39.82337440763201, 43.248627867017476, 45.2838386126927, 50.782184396471294, 49.05508804321289, 48.999266215733115, 48.8670836857387, 49.534076009477886, 50.64955023356846, 50.72832543509347, 50.3016539301191, 53.44270869663784, 52.756886754717144, 38.54456193106515, 21.312741075243267, 8.417612314224243, 5.623377748898097, 7.2247872693198065, 9.260272468839373, 13.051311237471444, 10.303666949272156, 8.298154541424342, 1.3203290488038744, 0.16322816695485795, 3.0358720677239552, 22.41411566734314, 43.785219873700825, 50.066082205091206, 56.27200474057879, 58.54435403006417, 52.86622360774449, 36.224825927189414, 5.513418597834451, 0.3153906762599945, 0.1679642599608217, 0.12341049712683473, 0.13791632732110365, 0.1435437032154628, 0.13208084473652498, 0.09657019629542317, 0.13331040447311743, 0.14399982802569866, 0.07941650532718215, 0.07128205110452004, 0.10709966878805842, 0.15676408952900342, 0.1924898810684681, 0.10123941967529909, 0.07831860852560826, 0.09459036003266062, 0.12035501322575978, 0.16322269796260766], [0.04694310515852911, 0.016123030201664994, 0.053474696818739176, 0.024444130748244267, 0.012355975108221173, 0.04374494230640786, 0.030028872591044222, 0.04001340003950255, 0.07963734811970166, 0.055709370478455505, 0.04348524659872055, 0.05360642421458449, 0.023330013567049588, 0.022794583280171667, 0.10007206124386617, 0.06541741187019007, 0.015144089070547904, 0.02420836697066469, 0.017959276580118706, 0.04239338197346244, 0.01382075240170317, 0.04169573601601379, 0.05166276065366609, 1.0199421388762338, 20.50052445275443, 42.4248320715768, 42.29775646754673, 34.557786328451975, 26.218818937029155, 30.617181505475724, 37.23935324805123, 25.64384855542864, 6.239926585129329, 0.1458469903362649, 0.15643368368702276, 1.3634978809526987, 1.809113649385316, 3.9643207618168423, 5.275154880114964, 2.9639757999352048, 5.303649008274078, 20.760249853134155, 37.002958161490305, 39.094831466674805, 51.427553926195415, 46.1153747013637, 44.77804797036307, 42.61810663768223, 39.0671637398856, 34.6028801373073, 35.69002308164324, 32.94677700315203, 37.37540592466082, 37.122856276375906, 41.04690701620919, 41.11271340506417, 41.902278900146484, 38.05719791139875, 33.33791889463152, 31.54971660886492, 31.642280510493688, 30.763076305389404, 33.933657441820415, 37.94675629479544, 43.36411387579781, 43.26817314965384, 42.360741887773784, 43.84235838481358, 45.3747592653547, 47.22928210667202, 44.745905603681294, 43.14969246728079, 36.40093844277518, 31.498355524880544, 32.032505239759175, 30.820426736559185, 31.040031501225062, 30.253377301352366, 31.115353448050364, 32.77180746623448, 34.5389358656747, 32.3678947857448, 33.02821683883667, 35.13075910295759, 40.74647385733468, 40.60945538112095, 45.6491505759103, 43.47224521636963, 47.567989417484824, 35.37524536677769, 42.482595920562744, 46.10910742623465, 41.51644543239048, 43.68143810544695, 40.90189116341727, 40.227426052093506, 35.96101672308785, 33.2427077293396, 33.38444403239659, 32.63585206440517, 33.289344038282124, 31.135617869240896, 31.242029530661448, 32.28974839619228, 34.69269602639334, 42.544841357639854, 45.731820242745535, 46.16287953513009, 45.35748951775687, 44.372714383261545, 46.508382184164866, 44.517188276563374, 44.456707681928364, 41.22956820896694, 35.21036114011492, 34.81240653991699, 32.833521366119385, 31.989582742963517, 33.77168798446655, 35.77220984867641, 38.00779274531773, 34.866974217551096, 34.71903664725167, 33.81040334701538, 34.01440593174526, 33.76264142990112, 34.48502131870815, 37.39652497427804, 39.219179902757915, 40.996532576424734, 41.2795535496303, 43.593776157924104, 43.67836005347115, 43.75227151598249, 44.97997651781355, 48.181355544498985, 48.042971747262136, 33.609850542885916, 16.257820640291484, 5.854410997458866, 2.6819010845252444, 1.7322461626359393, 3.9394223264285495, 3.6052178825650896, 2.0812271450247084, 6.4126284037317545, 4.854778008801596, 0.07060696304376636, 2.3561176402228217, 17.09728636060442, 36.46355560847691, 44.601876395089285, 38.62635612487793, 43.84129878452846, 39.91889476776123, 19.002430302756174, 1.0348404880080904, 0.12448972064469542, 0.03936033044010401, 0.08725437189319304, 0.06024443730711937, 0.06296477919178349, 0.032244113007826466, 0.04210735910705157, 0.004620183533656278, 0.023249965094562088, 0.017691379080393484, 0.013411831576377153, 0.020111450559592674, 0.03918078328881945, 0.018143147695809603, 0.014672461431473494, 0.04707560269162059, 0.029089820837335925, 0.015754502565999116, 0.06855452353400843, 0.028188466792926192, 0.026687572776739086, 0.03444997267797589, 0.021196156640404036, 0.027120849616559486, 0.07072221900203399, 0.033759386877396276, 0.0385714927688241, 0.014198335935361683, 0.012423349394729095, 0.025064471211018305, 0.06841133228902306, 0.021404193780784096, 0.013535643013061156, 0.03591563206698213, 0.09918015410325356, 0.038195774358298094, 0.07386013133717434, 0.06746351386287383, 0.06078849347042186, 0.038675644501511536, 0.015345629238124405, 0.04179866638566766, 1.7153723537921906, 24.734211240495952, 49.77064480100359, 48.4070851462228, 34.76993915012905, 28.542049884796143, 36.60030657904488, 40.67407015391758, 25.902052300316946, 5.388327573026929, 0.2711790714945112, 0.13954049588314124, 1.47617084639413, 3.0197070837020874, 5.102750965527125, 4.965931815760476, 3.695487141609192, 6.38433837890625, 21.813683612006052, 38.85584817613874, 42.29459503718785, 51.636788504464285, 48.29667132241385, 47.068598066057476, 45.16101878029959, 40.86830357142857, 38.142890044621055, 36.88563435418265, 34.68498352595738, 37.485798903873985, 37.40190635408674, 42.0527560370309, 41.31428064618792, 43.58677584784371, 39.66474008560181, 33.90955414090838, 32.80685765402657, 32.13528994151524, 32.91408225468227, 33.83492006574358, 38.0493950843811, 43.94165856497628, 44.90831627164568, 44.46996831893921, 46.23923676354544, 46.49531609671456, 47.272301878247944, 46.819581576756065, 44.24681649889265, 38.3107967376709, 33.04763010569981, 33.810559681483674, 31.761198929377965, 33.292731285095215, 32.81095014299665, 32.70551470347813, 34.59814493996756, 36.94220658711025, 33.814617429460796, 34.892818042210166, 37.08377960750035, 42.99887834276472, 42.93722350256783, 46.72231374468122, 45.82547153745379, 47.499938760484966, 37.86049440928868, 45.557719230651855, 45.81405912126814, 44.52655444826399, 45.81091158730643, 41.78842919213431, 40.74842630113874, 37.352560247693745, 34.65632220676967, 34.395313126700266, 33.98500462940761, 34.69269255229405, 32.236295904432026, 33.959966795785085, 32.97419459479195, 35.98569325038365, 43.670216764722554, 46.593035561697825, 47.154342310769216, 46.16600969859532, 45.20861046654837, 47.17608322416033, 47.00364283152989, 46.27053492409842, 43.24940606525966, 36.43534592219761, 37.05466318130493, 35.56198515210833, 33.58877318246024, 35.14827898570469, 37.37524611609322, 38.14688525881086, 37.55699014663696, 35.90468420301165, 35.14371401923043, 35.187616212027415, 35.16846350261143, 37.392262254442485, 40.328164509364534, 43.01829508372715, 43.69688047681536, 43.46883365086147, 45.30127164295742, 46.62787382943289, 45.99962813513619, 45.74363565444946, 50.6504465511867, 49.32351779937744, 36.57072114944458, 18.575885602406093, 6.886375691209521, 2.2563165383679524, 5.394702979496547, 7.719882896968296, 6.255143574305943, 3.9477167384965077, 6.390509247779846, 4.625449674470084, 0.1502613898898874, 2.821386822632381, 20.623924459729874, 37.273333413260325, 50.08015578133719, 46.16580125263759, 49.180186884743826, 45.310554436274934, 22.725457498005458, 1.9101225435733795, 0.19941401880766663, 0.03971679202680077, 0.03652974697096007, 0.017955315631947348, 0.018215995215411698, 0.053112365904131105, 0.0525764996585037, 0.021761077755529965, 0.0840525890567473, 0.03720267050500427, 0.0734657057161842, 0.023100059745567184, 0.009821448342076369, 0.023536469720836197, 0.06555790254580122, 0.035733038293463845, 0.04729842341371945, 0.02115058453221406, 0.019848530114229237, 0.10609296030764069, 0.07494320214859077, 0.08174255051250968, 0.17663253125335487, 0.14956642075308732, 0.10421926049249512, 0.12479533281709466, 0.19210329252694333, 0.11715078087789671, 0.15145156745399746, 0.08521392888256482, 0.1506745634334428, 0.10632267155285392, 0.19307100559983933, 0.1817086517278637, 0.18840828937079224, 0.10755151882767677, 0.16667098578597817, 0.1521270897771631, 0.20517255552113056, 0.16850841790437698, 0.0830994848428028, 0.14106341344969614, 2.1629251497132436, 27.30592887742179, 55.38863161631993, 53.846854141780305, 44.02989373888288, 34.8277724811009, 39.61173227855137, 46.70700338908604, 32.3637501852853, 7.644445436341422, 0.41280846457396236, 0.5982137343713215, 3.652575067111424, 6.619790247508457, 10.927989516939435, 11.19077820437295, 5.841324499675205, 7.868847063609532, 23.13495305606297, 41.65145240511213, 45.78135395050049, 52.71440199443272, 50.423761572156636, 48.82148960658482, 46.94820315497262, 42.370879309517996, 39.01887375967843, 39.0488726070949, 37.0679064478193, 40.52134527478899, 39.84158216203962, 44.737484386989046, 44.75990274974278, 45.903770787375315, 42.135790484292166, 35.968558992658345, 34.534718309129985, 34.10024050303868, 33.389304297310964, 35.687205587114605, 40.68982172012329, 48.19080856868199, 46.68047864096505, 45.18355178833008, 48.30035039356777, 46.9834200995309, 48.816340991428916, 49.2356196131025, 46.569814682006836, 39.66334697178432, 34.57477814810616, 34.66670976366316, 34.25703007834298, 35.17510250636509, 33.73761749267578, 33.68673930849348, 36.290052141462056, 38.530971254621235, 36.953521728515625, 36.98006732123238, 39.59393099376133, 43.71209008353097, 45.99875961031233, 48.80277810777937, 47.279333455221995, 49.86673491341727, 40.55019072123936, 45.863648414611816, 48.30590547834124, 45.764508043016704, 47.948945249829976, 44.49498530796596, 43.28443888255528, 40.376339844294954, 36.54438052858625, 36.30977112906319, 35.817077841077534, 36.03343432290213, 34.72881276266915, 35.7104229927063, 34.17368991034371, 37.28674691064017, 46.14376851490566, 48.842007637023926, 50.14904022216797, 46.49955449785505, 46.307902336120605, 49.47878571919033, 47.07298585346767, 49.5226149559021, 44.87539570672171, 37.07331909452166, 39.26787635258266, 36.77354254041399, 35.22373989650181, 37.6139132635934, 39.304691382816856, 41.14753082820347, 38.27002818243844, 39.27888577325003, 36.872905254364014, 37.378928661346436, 36.683017935071675, 37.86234957831246, 40.9842655318124, 45.29485845565796, 45.530878339494976, 44.69557632718767, 47.82054601396833, 48.60525124413626, 48.053414889744346, 48.2273074558803, 52.23912436621529, 52.10728577205113, 37.61843654087612, 20.988314049584524, 8.918745926448278, 6.863011070660182, 7.939144594328744, 11.216721040861946, 9.327857596533638, 9.066561034747533, 12.913309591157095, 7.294788633074079, 0.2749739278640066, 3.3793614762169972, 24.2280592918396, 45.756361280168804, 56.45241124289376, 50.68792860848563, 55.55011122567313, 53.50717755726406, 27.50227975845337, 2.293594492333276, 0.25505284539290835, 0.13810078028057302, 0.13372356444597244, 0.12798241179968628, 0.09625418896653823, 0.11149587681783096, 0.1381266460354839, 0.07302680891007185, 0.14605032013995306, 0.10095520849738802, 0.17531487052994116, 0.1425049610968147, 0.12954918986984662, 0.0770017688295671, 0.19166797160037927, 0.09940082047666822, 0.08847068662622146, 0.0765290470527751, 0.10093551741114684], [0.027295187315238372, 0.02190722232418401, 0.05060471421373742, 0.04836818476074508, 0.023158881946333816, 0.0800594308280519, 0.05225528118067554, 0.06992800054805619, 0.10539972143513815, 0.040837477426975965, 0.059119819796511104, 0.05172780502055373, 0.06983837285744292, 0.056949464471212456, 0.02493034180120698, 0.06721451186708041, 0.0666326138057879, 0.040397807090942345, 0.04301789203392608, 0.05322192216824208, 0.026525226488177265, 0.0851050918655736, 0.055319284088909626, 0.3561422952583858, 8.80968005316598, 36.919270583561485, 45.43159205572945, 32.8891521181379, 28.127131257738384, 24.17926730428423, 35.745921339307515, 33.28277104241507, 9.888158593858991, 0.7247821199042457, 0.07032674165176493, 0.6840770212667329, 3.273426417793546, 2.6163009703159332, 3.1230548066752295, 2.5057360231876373, 4.848076036998203, 17.880772181919642, 29.256474086216517, 43.019035066877095, 51.15255464826311, 47.017233507973806, 45.94100965772356, 40.10384539195469, 36.64873204912458, 36.60021277836391, 38.083920683179585, 41.048053468976704, 43.61239038194929, 45.029958384377615, 44.71302672794887, 45.70383289882115, 46.43243489946638, 43.087356703622, 37.63794013432094, 30.272745404924663, 32.273656368255615, 30.69153765269688, 37.693748065403526, 42.41589668818882, 45.60343490328108, 46.21132237570626, 46.548598357609336, 43.5511975969587, 46.15800537381853, 43.892076219831196, 43.71876730237688, 38.74360350200108, 33.54719516209194, 32.12064661298479, 31.33437803813389, 31.012346403939382, 32.441052368709016, 34.128648212977815, 36.74945313589913, 38.39234774453299, 37.00921848842076, 34.69959558759417, 32.38894087927682, 31.94092103413173, 36.56873049054827, 38.541775703430176, 44.20633976800101, 42.4032335962568, 48.85782868521554, 34.83791337694441, 38.83434002740042, 49.998636041368755, 43.35131876809256, 44.88090910230364, 43.82638447625296, 43.73758997235979, 39.92180258887154, 38.3303177016122, 32.34661592755999, 32.971144335610525, 33.74515628814697, 32.62610721588135, 31.90150042942592, 32.82325192860195, 33.37346935272217, 40.57417590277535, 43.55731201171875, 45.941339697156636, 47.27503252029419, 44.86101640973772, 46.01846817561558, 44.946152687072754, 44.18280969347273, 39.87681647709438, 35.740689345768516, 33.514715807778494, 33.12615517207554, 34.47884784426008, 38.99611840929304, 43.961540835244314, 43.56632382529122, 43.16170937674386, 41.43115282058716, 39.80719552721296, 36.835294655391145, 36.25430713381086, 33.40870714187622, 33.43655899592808, 32.43287781306675, 35.17665195465088, 36.02933488573347, 39.37856463023594, 40.620089599064414, 43.86612817219326, 45.19057641710554, 49.05171816689627, 46.63795913968767, 34.04350846154349, 16.954434871673584, 5.271219594138009, 1.7458458500249046, 2.9521931750433783, 5.968100896903446, 4.377418526581355, 2.6388311556407382, 2.6919998569147925, 1.6744831821748187, 0.12880736110465868, 3.2531782814434598, 20.966455016817363, 43.15448325020926, 33.7267609323774, 35.0164612361363, 47.80664961678641, 37.574596881866455, 15.588877609797887, 0.4533005303570202, 0.0330740020477346, 0.040889256434249024, 0.03698506432452372, 0.030570092477968762, 0.011209615639277866, 0.012467918967429017, 0.05860419425048998, 0.009147834398650696, 0.025851461570709944, 0.015113175015098282, 0.047247292407389195, 0.06757179448114974, 0.018070978711226156, 0.06271995018635478, 0.032570817441280396, 0.03122272781495537, 0.030890357614095722, 0.033095677848905325, 0.057394603799496374, 0.03888013120740652, 0.03322119325665491, 0.03103744365008814, 0.03465346193739346, 0.027131265129095743, 0.044894570617803504, 0.0181328322671886, 0.027233959707830633, 0.12517231330275536, 0.007805430895781943, 0.02705554910270231, 0.015289818036503025, 0.021203316881188324, 0.030317348361547505, 0.04329992511442729, 0.046990721353462765, 0.023984618351927826, 0.07439257776630775, 0.03757600047226463, 0.031235351958977323, 0.03754517123369234, 0.013274348507236158, 0.04123386740684509, 0.6244865560105869, 13.180978519575936, 42.038727624075754, 49.72526264190674, 40.16143206187657, 30.06144026347569, 26.624206372669764, 41.170619692121235, 37.512580735342844, 10.950507760047913, 0.8457600825599262, 0.098302584407585, 0.7567912223083633, 2.5178515102182115, 4.893955860819135, 4.8874601636614114, 3.6227484047412872, 5.165173581668308, 18.755715404238018, 33.30006510870797, 45.69167355128697, 52.09910079411098, 49.29148312977382, 47.40298012324742, 42.45621708461216, 37.75537163870675, 36.962999071393696, 39.25509514127459, 42.38534893308367, 44.94951214109148, 46.392677307128906, 46.72538832255772, 47.62286628995623, 48.53247581209455, 45.67647784096854, 38.961419105529785, 32.643418652670725, 33.58310692650931, 33.461558614458355, 38.75395631790161, 43.952716623033794, 45.7680481501988, 47.12318658828735, 47.68473999840872, 46.20076806204659, 47.03478465761457, 44.74062497275216, 44.729063170296804, 42.630672454833984, 34.5533846446446, 33.40709168570382, 32.332121985299246, 32.61098793574742, 34.21701192855835, 34.57922152110508, 38.066470282418386, 39.76086146490914, 37.83543573107038, 37.45523030417306, 33.27516276495797, 34.01297460283552, 39.0598646572658, 40.95206410544259, 46.38979033061436, 45.38117592675345, 48.80879872185843, 39.43282658713204, 40.43728596823556, 49.75959369114467, 44.85292523247855, 45.68811954770769, 45.179511410849436, 42.82529844556536, 43.068728583199636, 39.51182413101196, 34.60792800358364, 34.79485886437552, 36.660019397735596, 35.41157749720982, 33.49373919623238, 33.622388567243306, 35.1048457963126, 40.96392815453665, 44.90287583214896, 47.97826664788382, 46.99658693586077, 44.949171679360525, 48.31189135142735, 46.08121040889195, 46.30909047807966, 41.75765562057495, 37.2123247555324, 34.587944984436035, 34.38865327835083, 35.26438685825893, 39.738158226013184, 45.161828245435444, 45.46822990689959, 44.32775953837803, 42.28218902860369, 40.81574739728655, 38.31542771203177, 36.8876736504691, 34.79775973728725, 33.70473861694336, 34.505768639700754, 37.8696208681379, 38.21683972222464, 41.94210597446987, 42.784648009708945, 44.7430533681597, 47.06040266581944, 51.08335059029715, 48.48569706508091, 34.018946579524446, 18.69819474220276, 5.9313444920948575, 3.1673953873770575, 6.177038873944964, 8.530269537653242, 6.678450848375048, 4.004898675850459, 3.756524460656302, 2.1388103408472876, 0.18829814956656524, 3.8707871522222246, 22.640861443110875, 48.631623131888254, 43.744736194610596, 41.06139401027134, 54.5174560546875, 44.47706242970058, 18.495267391204834, 0.8343832758920533, 0.05775743004466806, 0.06625384198767797, 0.027479421447164247, 0.019635095227775828, 0.020264774028744017, 0.009983560536056757, 0.01909882525381233, 0.013794535504920142, 0.028363036889848963, 0.011281955105784749, 0.03291688387149146, 0.038995380380323956, 0.013405457588045724, 0.048587388891194544, 0.05497189451541219, 0.0665760850533843, 0.06525362030203853, 0.035592690110206604, 0.036242909862526825, 0.16405154205858707, 0.08708234290991511, 0.10733193132494177, 0.12630102916487626, 0.09043925242232424, 0.12874602153897285, 0.10251889923321349, 0.12486583260553223, 0.2248772531747818, 0.07468951826116868, 0.1151645053178072, 0.11730045213231019, 0.16781522652932576, 0.08040900528430939, 0.15722033647554262, 0.1606130794222866, 0.21681601288063185, 0.13932309326316628, 0.11645790162895407, 0.11836174875497818, 0.1393382517354829, 0.18044048334871018, 0.2350522114762238, 0.764630907348224, 14.578083208629064, 48.61289078848702, 56.65315859658377, 44.470763887677876, 37.54847860336304, 34.34127698625837, 45.355026381356375, 42.97737366812569, 12.946344801357814, 1.2908297117267336, 0.3436012310641152, 1.7128260561398096, 8.048011575426374, 8.516467809677124, 7.810611605644226, 5.041952056544168, 5.8797584601811, 20.356554303850444, 35.799120221819194, 48.211215427943635, 54.18743746621268, 50.97891916547503, 49.22930022648403, 44.82054315294538, 41.06747020993914, 39.928983552115305, 41.99117067881993, 45.207012380872456, 47.73205028261457, 48.77742065702166, 48.90111596243722, 48.95359223229544, 49.63573510306222, 46.97907052721296, 40.88994721003941, 33.9998459815979, 35.6097331728254, 35.5344876561846, 42.80724007742745, 46.37251016071865, 47.59830788203648, 50.23372139249529, 49.24402345929827, 45.957459517887656, 48.35710327965872, 47.23557022639683, 46.867072514125276, 43.41999128886631, 35.900779315403526, 35.693337372371126, 33.783378328595845, 34.39031389781407, 36.16591909953526, 37.95289850234985, 40.02008138384138, 42.15765299115862, 40.37840345927647, 39.67316130229405, 35.55123281478882, 35.28095136369978, 40.12014239174979, 42.84868260792324, 49.35581997462681, 47.86181831359863, 49.794803687504356, 40.85665144239153, 41.46638713564192, 52.64333929334368, 47.026964460100444, 46.91528606414795, 46.413514954703196, 45.41635465621948, 45.63068573815482, 41.865206786564414, 35.987055097307476, 36.330233573913574, 37.660792759486604, 36.541448388780864, 35.605817862919395, 35.974277360098704, 37.82579163142613, 42.57157455171858, 47.415462562016074, 48.767324924468994, 49.38176802226475, 45.63829401561192, 51.51174872262137, 47.23407288960048, 48.10530751092093, 43.200306619916645, 38.59007610593523, 36.807272570473806, 36.478671414511545, 38.28937544141497, 44.221181120191304, 48.37714188439505, 48.257942063467844, 46.57152393886021, 44.64424303599766, 43.34047263009207, 40.28476258686611, 40.937452043805806, 37.44114283152989, 36.41671780177525, 37.09875644956316, 39.386318819863455, 39.473407541002544, 42.48548984527588, 43.93909815379551, 48.01959105900356, 49.595543248312815, 52.05759572982788, 51.231208256312776, 36.179388182503835, 19.847324303218297, 8.552519406591143, 4.233598632471902, 10.762389625821795, 13.720031925610133, 12.717889768736702, 9.830821190561567, 6.976346177714212, 2.608279492173876, 0.5369139579789979, 5.253230707986014, 28.023017713001796, 54.39885377883911, 46.54768814359392, 47.03758825574602, 58.825068201337544, 52.08416911533901, 21.552089146205358, 1.4318667437349046, 0.1622174076203789, 0.2781559314046587, 0.14048213964062078, 0.10385888375874076, 0.11204521876892873, 0.1377108669174569, 0.14546101247625692, 0.07895554934761354, 0.1124891299488289, 0.1080597076298935, 0.09453285418983016, 0.12641841572310242, 0.1295175701379776, 0.22616925170379026, 0.11081320952091898, 0.15068676349307808, 0.10874371164079223, 0.21002789427127155, 0.2223017785165991], [0.00569096692405375, 0.03875310266656535, 0.03151375148445368, 0.048421738137091906, 0.06283758780253784, 0.012221655708604624, 0.04733009064303977, 0.02017020321051989, 0.024428417573549917, 0.0502963234404368, 0.04474439046212605, 0.03599504780556474, 0.03577500229169216, 0.02429387086470212, 0.04352702060714364, 0.043212275353393385, 0.04794592563328998, 0.07139172271958419, 0.05971525463142565, 0.04305712492870433, 0.047858150343277624, 0.005601073756614434, 0.03430666608203735, 0.009475616006446736, 6.024484659944262, 30.73581157411848, 41.82076958247593, 38.22608082635062, 29.25286102294922, 27.383097308022634, 33.77778155463082, 35.02090113503592, 16.793130704334803, 0.8982201218605042, 0.05600866209715605, 0.6803580522537231, 0.9595912801367896, 3.4723446582044875, 4.868746059281485, 2.438104212284088, 4.406838936465127, 12.081131662641253, 29.598068373543875, 47.96901164736067, 48.56618847165789, 45.80236530303955, 44.050613267081125, 36.507621083940776, 38.90373168672834, 41.98498330797468, 43.100471428462434, 45.62279258455549, 46.35779387610299, 46.670890126909526, 46.35176978792463, 42.34101595197405, 40.468361786433626, 45.789042132241384, 38.776947907039094, 32.00995486123221, 31.622471196310862, 33.63255030768258, 42.39274181638445, 43.058532101767405, 46.95964683805193, 45.08581147875105, 41.64710283279419, 45.6623660496303, 43.632922308785574, 43.30220890045166, 38.73992790494646, 32.124318735940115, 32.233791078839985, 29.980903693607875, 31.143535341535294, 31.093629905155726, 36.85250186920166, 41.328322955540244, 42.51073612485613, 40.27912412370954, 42.791655267987935, 39.77822501318795, 38.16613176890782, 34.96259185246059, 33.027845110212056, 35.89793402808053, 42.59695284707205, 42.11582483564104, 47.80115359170096, 36.217262813023154, 40.92900650841849, 43.124904768807546, 42.2353720664978, 45.364142417907715, 45.64684724807739, 44.0702280317034, 41.676941871643066, 41.415981428963796, 36.20611442838396, 31.511654376983643, 32.22997999191284, 33.81660461425781, 32.21962022781372, 33.35305207116263, 33.25175428390503, 38.1749837739127, 44.65562765938895, 45.60435553959438, 46.52421365465437, 45.24557140895298, 47.77980177743094, 45.70865494864327, 44.1511606488909, 38.94946820395333, 35.563072545187815, 33.640891620091026, 33.42497287477766, 34.38500199999128, 44.27349410738264, 47.07620981761387, 45.435153007507324, 47.161432947431294, 44.481290408543174, 45.561182907649446, 44.245819432394846, 43.17083930969238, 39.762445654187886, 39.268119539533345, 39.54957716805594, 38.91984803336007, 37.33838939666748, 40.22457729067121, 42.22995941979544, 45.81087684631348, 46.43446724755423, 49.46158197947911, 45.99442046029227, 31.634651388440812, 15.306511504309517, 4.322100009237017, 1.7915305814572742, 4.676094659737178, 7.891446079526629, 5.862361039434161, 2.9721599093505313, 2.761605824742998, 0.20621325182063238, 0.11402436292597226, 4.307975190026419, 22.47683358192444, 32.868404797145296, 26.11550964627947, 33.12098223822457, 41.59983771187918, 38.23079865319388, 11.737306135041372, 0.14922143997890608, 0.07348136630441461, 0.05977740165378366, 0.03154317615553737, 0.03319825877302459, 0.02536990526797516, 0.02773021307906934, 0.018368404358625412, 0.08350960497877427, 0.032752227171191146, 0.03399814638708319, 0.06631621292659215, 0.06426371913403273, 0.04960424825549126, 0.06804760359227657, 0.0063897782653969315, 0.04392320363383208, 0.01811015053785273, 0.021791717004297034, 0.018763647614313022, 0.024800263245456984, 0.027961844578385353, 0.015722329828089902, 0.03178544708394578, 0.011950235763963844, 0.004422462670065994, 0.021319777239114046, 0.024319278608475412, 0.026298061445621506, 0.022858056838491132, 0.03952319920063019, 0.05099691763254149, 0.010618697303081197, 0.029632309584745338, 0.025606920942664146, 0.06436462407665593, 0.014712905511260033, 0.041198101826012135, 0.0695784328771489, 0.01960201494927917, 0.08160430578781025, 0.023796701471188238, 0.03666905699563878, 0.12967888505331107, 7.9150082894733975, 36.55829429626465, 47.99314621516636, 41.83056306838989, 32.579755783081055, 29.917918273380824, 42.198286056518555, 39.94636099679129, 17.530829633985245, 1.440555140376091, 0.04418762533792427, 0.5973769649863243, 2.7383808195590973, 4.3911051750183105, 5.484343860830579, 2.9041448618684496, 4.997161362852369, 13.168861729758126, 31.637333393096924, 49.70222588947841, 51.05713503701346, 47.57787670407976, 46.00937645775931, 39.17212322780064, 40.01359871455601, 43.77651378086635, 45.39182751519339, 48.23263325010027, 47.57888766697475, 48.12655162811279, 47.68920074190412, 45.08034324645996, 42.86535133634295, 47.87147978373936, 41.71110616411482, 34.228851658957346, 33.973154476710725, 35.06284046173096, 42.673421246664866, 44.372756072453086, 47.36473723820278, 46.870595250810894, 43.403975691114155, 47.645079680851524, 45.18039035797119, 43.85712330681937, 42.64428744997297, 34.53328003202166, 33.015908105032786, 32.05216864177159, 33.06395489828927, 32.23160239628383, 36.916880403246196, 41.746938024248394, 44.3019574029105, 41.84404952185494, 43.15357998439244, 40.71126038687569, 39.85351916721889, 34.444575854710166, 34.838959080832346, 38.824987752096995, 42.00254487991333, 44.00249351773943, 49.482350145067485, 38.681087085178916, 42.22017288208008, 45.92359747205462, 43.89383063997541, 47.08099365234375, 46.461749349321636, 47.15496070044381, 43.13897487095424, 43.26792301450457, 37.03065368107387, 33.68147604806082, 34.59979861123221, 35.23045533043997, 33.01063094820295, 34.62630598885672, 34.25450440815517, 39.92202145712716, 45.36211354391915, 48.02269690377371, 47.23375327246529, 45.69686038153512, 49.215702601841514, 47.21083811351231, 46.00910200391497, 41.01937130519322, 36.57295846939087, 34.595730440957205, 35.75803204945156, 35.089851583753315, 45.658871105739046, 49.17584426062447, 48.1094833782741, 49.046447958265034, 45.79240158626011, 47.01617738178798, 44.637367793491904, 44.21720675059727, 41.30434124810355, 39.39522641045706, 38.56627852576119, 40.144349915640696, 39.49699320111956, 41.25721509116036, 43.65135587964739, 47.20493561880929, 47.64149441037859, 51.64216641017369, 48.235697405678884, 33.953063760484966, 16.818790401731217, 5.344322894300733, 3.8654357365199496, 7.73667756148747, 7.642216801643372, 7.128337153366633, 4.227189353534153, 1.867355729852404, 0.32637474685907364, 0.12892182996230467, 4.911431014537811, 25.91290191241673, 39.61892713819231, 32.15068367549351, 37.94510609763009, 48.34081670216152, 44.00468567439488, 14.323178989546639, 0.2619313177253519, 0.03925312190715756, 0.01873467586535428, 0.06432685003216777, 0.033972073678991625, 0.02816505903112037, 0.00729234391889934, 0.025212244263717105, 0.03262037763904248, 0.013395260903052986, 0.048022576341671605, 0.02634134010544845, 0.022308116080239415, 0.05607924670247095, 0.03698567161336541, 0.01693829002657107, 0.08583746863795177, 0.017653379423011626, 0.042647021756108315, 0.01772260695828923, 0.09663317791585412, 0.1751356694315161, 0.09633126375930649, 0.08895052623535905, 0.07651741017720529, 0.07172161287495069, 0.09503442727561508, 0.15809857792087964, 0.05510032083839178, 0.10550426332546131, 0.2121014158640589, 0.10277104963149343, 0.12418109577681337, 0.10417008705969368, 0.0875703181539263, 0.1516020122383322, 0.13705437071621418, 0.10331899380045277, 0.11572330604706492, 0.15724366450948374, 0.24903366980808123, 0.14774167723953724, 0.11246291814105851, 0.2787593661674431, 9.437345572880336, 40.63272142410278, 54.39634895324707, 48.86342545918056, 39.363886560712544, 36.72774001530239, 44.24814360482352, 44.36319882529122, 21.607983929770334, 1.699538060597011, 0.22341173967080458, 2.4254472000258307, 4.951669769627707, 12.853724445615496, 10.849125725882393, 5.9510743362562994, 6.657144631658282, 14.505208764757429, 36.85883862631661, 52.285715511866975, 52.00538696561541, 49.80692829404558, 47.86228731700352, 39.81165279660906, 43.070958954947336, 46.68258394513811, 46.02801847457886, 49.68971913201468, 49.60155691419329, 49.79324729101998, 50.44535657337734, 45.56592852728707, 46.40222065789359, 48.51588698795864, 43.64032561438424, 36.30242688315255, 35.849046502794536, 36.8725335257394, 44.52543926239014, 46.126092297690256, 50.408701351710725, 48.48808029719761, 43.30237218311855, 48.95319618497576, 48.166601044791086, 45.81702600206648, 43.57298714773995, 35.623320375170024, 35.33146824155535, 32.8699403490339, 34.37024055208479, 33.47752904891968, 39.985889298575266, 44.92727790560041, 45.684193815503804, 43.69419847215925, 45.76767642157418, 43.364683628082275, 42.615692138671875, 36.78420455115182, 35.73633977345058, 40.38119316101074, 45.981194564274375, 46.36356088093349, 49.84562976019723, 42.24578046798706, 43.12059341158186, 44.9462708064488, 46.09675700323922, 49.465636253356934, 49.5021698815482, 48.46236848831177, 45.899827684674946, 45.2432541847229, 39.547867911202566, 35.38954823357718, 35.62308761051723, 37.752832072121755, 35.12427643367222, 36.95687076023647, 36.015841484069824, 41.94125829424177, 48.906132561819895, 48.68416888373238, 49.12720339638846, 46.39213534763881, 51.14894853319441, 49.07123218263899, 48.17506047657558, 42.377851826804026, 38.281061921800884, 36.1469783101763, 36.473456791469026, 36.732127802712576, 49.30952065331595, 50.87138189588274, 48.75235850470406, 51.688239915030344, 48.48320960998535, 49.7059987613133, 47.222830704280305, 45.80016272408621, 43.357033661433626, 41.85131386348179, 42.77829040799822, 43.475476128714426, 41.95151036126273, 44.265250069754465, 47.09251376560756, 50.699417454855784, 49.77685301644461, 53.47945771898542, 49.13079561505999, 35.365156582423616, 18.02571507862636, 6.735793462821415, 6.403236610548837, 10.443086896623884, 15.099338803972516, 10.83358781678336, 8.055690203394208, 6.18712374993733, 0.7647395815168108, 0.5312625212328774, 6.507247235093798, 29.632201399121964, 45.27820014953613, 36.58293260846819, 44.04582595825195, 55.266725472041536, 49.46521588734218, 16.161987611225673, 0.40958406616534504, 0.13890759912984713, 0.11192777792790107, 0.17113239424569265, 0.19426939343767508, 0.1212001693035875, 0.11678334059459822, 0.07483813100095306, 0.13240388168820313, 0.10859665953155075, 0.1665698704974992, 0.19941562015031064, 0.15780655001955374, 0.08936456830373832, 0.13856069131621293, 0.08455746660807303, 0.10178975907287427, 0.11964640553508486, 0.19025889863925322, 0.1107382517574089], [0.036696042333330424, 0.055534138809889555, 0.06158348545432091, 0.029573487383978705, 0.037394570386303325, 0.015596244450924652, 0.012055730995988207, 0.06222274686608996, 0.026943336373993328, 0.015683003634746586, 0.012568866318490888, 0.03350412200338074, 0.036915388956133804, 0.06973689116005387, 0.01240458874963224, 0.019285547912919095, 0.05477444761033569, 0.018771218368783593, 0.059971354103514125, 0.0177274415202971, 0.05263219042015927, 0.03960513569680708, 0.002588801085948944, 0.023638528172991106, 1.599447522844587, 17.674787623541697, 42.46882111685616, 38.93231310163225, 26.924832344055176, 20.109889779772075, 23.852158273969376, 35.43604210444859, 21.054568597248622, 3.168320583445685, 0.10900669824331999, 0.1943330807345254, 2.1972197209085738, 1.788238872374807, 2.664402046373912, 1.209949097463063, 3.362344252211707, 13.437849947384425, 36.46719299043928, 49.36231306621006, 51.690161091940745, 46.38613210405622, 42.85412999561855, 44.7680356161935, 44.719432967049734, 46.029988288879395, 48.53061716897147, 47.55239765984671, 46.13016046796526, 46.27734415871756, 45.563291685921804, 44.387694699423655, 44.26551410130092, 46.29885925565447, 36.35820007324219, 31.363775866372244, 32.84811953135899, 35.67777688162667, 45.88895375388009, 44.80201230730329, 47.5153602872576, 43.06136696679251, 44.85321705681937, 44.73340579441616, 42.38042613438198, 40.67749908992222, 32.96220547812325, 31.50544616154262, 33.88270630155291, 31.004192692892893, 31.428574766431534, 32.538295882088796, 40.60552270071847, 43.072473662240164, 45.30768135615757, 44.57362501961844, 44.431103570120676, 41.99850797653198, 41.82080084936959, 40.21348796572004, 39.468648024967735, 37.93852267946516, 41.53494848523821, 42.001561709812705, 47.77539314542498, 34.18752724783761, 35.48990453992571, 45.692166873386924, 42.4711765561785, 44.660050187792095, 44.46199526105608, 45.71275091171265, 43.105522768838064, 42.5109133039202, 36.53428132193429, 32.28820242200579, 32.169252736227854, 33.44754409790039, 32.218491145542686, 33.381056785583496, 33.288287912096294, 38.38268280029297, 43.024350438799175, 46.051614556993755, 47.001179695129395, 44.79325410297939, 46.11948108673096, 44.25722142628261, 43.85350329535348, 36.536004475184846, 33.002185412815635, 33.057711941855295, 31.685036250523158, 34.745075021471294, 46.189779485974995, 46.907170568193706, 43.46398033414568, 45.34764739445278, 45.43128286089216, 47.09181547164917, 45.94892365591866, 44.72595385142735, 45.22632837295532, 44.27424103873116, 45.432769775390625, 45.41454117638724, 43.5618109703064, 41.91912133353097, 43.93872989927019, 44.59268045425415, 46.086449350629536, 50.03185885293143, 44.17141464778355, 29.222174303872244, 11.378753900527954, 3.7258568491254533, 3.712332614830562, 7.31120548929487, 5.756408393383026, 5.258720219135284, 2.910447746515274, 4.349933624267578, 0.4402894042432308, 0.33528537728956764, 4.891858807631901, 27.054701123918804, 34.45659623827253, 35.4660895892552, 42.85853862762451, 45.43254395893642, 31.835284096854075, 4.380156551088605, 0.092449005294059, 0.011808522028981574, 0.022411199120272483, 0.037289146400455914, 0.01933732352751706, 0.08767592534422874, 0.03116472324888621, 0.020747551694512367, 0.04688079868044172, 0.04561561246269515, 0.039235897295709164, 0.08904946342642818, 0.01546365870828075, 0.025804920853780847, 0.025655283526118313, 0.04225440103826778, 0.04837510921061039, 0.07142765114882163, 0.026924021874687502, 0.019346342954252447, 0.04304687226457255, 0.04644091799855232, 0.01798250961915723, 0.050098740828356574, 0.05448736622929573, 0.008548704940559608, 0.0074410652242867005, 0.026719633556370224, 0.02985880457397018, 0.02952769984092031, 0.010203556856140494, 0.054783736754740985, 0.027796309175235883, 0.0420627182881747, 0.029482478874602487, 0.016762622399255633, 0.035382829406963925, 0.06143482521708522, 0.01050327340739646, 0.03267997336973037, 0.03570589689271791, 0.027643319884581224, 0.025368653370865753, 0.049488293406154425, 2.2884916918618337, 22.617503336497716, 46.81880685261318, 45.005768230983186, 29.621233667646134, 23.333697591509136, 29.430769647870743, 42.72045360292707, 24.07523192678179, 2.439970454999379, 0.12894684076309204, 0.21450535686952726, 3.0953149923256467, 4.1363221151488165, 5.32792340857642, 5.152498330388751, 4.139138741152627, 14.428151505334036, 37.844065393720356, 51.682563236781526, 52.76673582621983, 48.02761622837612, 44.21592480795724, 45.59985310690743, 46.51508024760655, 47.770974091121126, 50.22352838516235, 49.22566631862095, 46.89865902491978, 47.45942381450108, 46.14075299671718, 45.094305651528494, 45.49122497013637, 47.52331944874355, 39.42323112487793, 34.05991315841675, 33.823087283543174, 37.00010245186942, 47.509575911930625, 46.36492967605591, 47.77234288624355, 43.20867919921875, 46.854621342250276, 46.699162346976145, 44.65699992861067, 40.79851933888027, 35.03643383298601, 33.21270888192313, 35.901536669049946, 32.59120294025966, 33.92530918121338, 34.89193909508841, 41.567101274217876, 45.18558413641793, 46.315559250967844, 45.930490085056846, 45.698395933423726, 44.11985901423863, 43.926553181239534, 41.39979212624686, 41.31798751013619, 39.3100380216326, 43.90172726767403, 44.17562525612967, 49.11411646434239, 37.40064525604248, 38.26856558663504, 46.38277612413679, 43.296886580330984, 45.862995283944265, 45.552237101963584, 47.21341242109026, 45.35279253550938, 44.29086460386004, 38.813172340393066, 34.52136387143816, 33.50209787913731, 34.08057015282767, 34.797075339726035, 34.024904659816194, 35.675699370247976, 40.848963260650635, 45.2118170601981, 48.03352567127773, 47.28068140574864, 46.10281235831124, 48.368630341121126, 47.111061981746126, 44.93315955570766, 38.58954109464373, 35.364315850394114, 34.83819130488804, 33.60347209657942, 36.986852237156455, 48.08682877676827, 49.662162576402935, 43.283295903887065, 46.73570639746529, 46.035536425454275, 49.50777360371181, 48.26870134898594, 46.79003436224801, 47.06240374701363, 46.79778855187552, 47.45732198442732, 45.71660368783133, 44.63994904926845, 42.974632603781565, 46.04155356543404, 47.701704025268555, 47.96357815606253, 53.062131541115896, 44.862374782562256, 30.936086450304302, 13.35602274962834, 4.333053844315665, 4.3642933794430325, 4.659625257764544, 5.727230736187526, 7.236867581095014, 4.3514392120497565, 4.843037290232522, 0.2660471483000687, 0.4222361115472657, 5.957303830555507, 29.957512583051408, 38.23645101274763, 32.61810636520386, 44.97953183310372, 50.6789550100054, 36.88392162322998, 6.6515070370265414, 0.1522154893193926, 0.012956420076079667, 0.049477253641401014, 0.016400060782741224, 0.08095386890428406, 0.09441136928009135, 0.037817789640809805, 0.020965417414637547, 0.04850418014185769, 0.055019643024674485, 0.048456404491194656, 0.06942132487893105, 0.03338693900566016, 0.01778795666593526, 0.03997962595894933, 0.03163240011781454, 0.004664597467386297, 0.06391208193131856, 0.03595269025702562, 0.019387299327978065, 0.10424309742770024, 0.19098890732441628, 0.12159380103860583, 0.12134682786251817, 0.08741892342056547, 0.15251001422958715, 0.07186141144484282, 0.1715047335518258, 0.15074187410729273, 0.12630676957113401, 0.1578400425080742, 0.10090676109705653, 0.11192783221070256, 0.13364969912384236, 0.1369116340896913, 0.15064154591943535, 0.0969998175278306, 0.0904697457860623, 0.22768394542591913, 0.09744661248156003, 0.18472554055707796, 0.12213031867785112, 0.11184627230146102, 0.10154435331267969, 2.8131136894226074, 24.57603897367205, 54.61818061556135, 52.30297136306763, 36.63784074783325, 29.769536018371582, 32.955719334738596, 46.3723121370588, 28.85729660306658, 4.5786522541727335, 0.2850636893085071, 1.2869778041328703, 5.47259749685015, 5.618421511990683, 9.802538548197065, 6.682180293968745, 5.324096253940037, 15.747814178466797, 39.88742985044207, 51.60413891928536, 55.17448813574654, 49.36882700238909, 45.944977079119, 49.560975960322786, 49.02077783857073, 49.016605445316856, 52.388798986162456, 50.9199914932251, 48.34389475413731, 47.442577907017295, 45.663887705121724, 46.589554514203755, 46.57002312796456, 49.385099683489116, 40.187251567840576, 35.94301741463797, 35.87615142549787, 38.2272481237139, 50.945310728890554, 49.4869498525347, 49.6648028918675, 43.16432884761265, 47.411543778010774, 49.01118932451521, 46.32562024252755, 43.398410184042795, 35.96652317047119, 34.46580260140555, 38.33736317498343, 35.77861261367798, 35.43940155846732, 36.91077988488333, 43.57221589769636, 45.84028162275042, 48.14019094194685, 48.64617613383702, 48.63263062068394, 46.56795951298305, 46.06522607803345, 44.730108874184744, 43.63759497233799, 41.37924630301339, 45.258401257651194, 46.66064500808716, 51.16183396748134, 40.21334900174822, 40.7595260483878, 46.95833362851824, 44.739808559417725, 46.72789314814976, 47.11122179031372, 48.8155106816973, 46.65453059332711, 45.88753979546683, 40.445613384246826, 35.64559282575335, 34.832577160426546, 36.346954413822715, 35.66126101357596, 35.202415875026155, 36.67741073880877, 42.321512358529226, 46.412177426474436, 49.878077847617014, 48.326242855616975, 44.755803312574116, 51.20841121673584, 48.510592460632324, 48.93460627964565, 40.06063107081822, 36.17117888586861, 37.01678507668631, 35.43443012237549, 38.753212860652376, 51.04020922524588, 51.19389295578003, 44.22446066992623, 47.140508447374614, 46.62927736554827, 50.18291963849749, 49.957964760916575, 48.066706793648855, 50.03381824493408, 48.47662271772112, 50.81441708973476, 50.3742869240897, 48.138592856270925, 46.37155130931309, 48.376280307769775, 48.517273153577534, 50.483724525996614, 55.23086929321289, 48.003936767578125, 32.089699336460654, 14.498032144137792, 6.338934940951211, 8.88549792766571, 14.952818666185651, 13.275910019874573, 12.268330897603716, 9.846400788852147, 8.443303278514318, 1.062610700726509, 0.8674380279013089, 7.418159978730338, 35.22673109599522, 44.77841622488839, 45.35706915174212, 53.700639724731445, 57.43550491333008, 41.13769217899868, 8.258029563086373, 0.3461453845458371, 0.12592054743851933, 0.1574765241571835, 0.11119141136961323, 0.19604366751653807, 0.2314846371965749, 0.177633831809674, 0.1453797918345247, 0.1630270898874317, 0.09821385916854654, 0.17141158426446573, 0.1441424289452178, 0.10912148601242475, 0.07534482702612877, 0.13599437688078198, 0.14652917587331363, 0.10696293041110039, 0.23797574745757238, 0.07906127188886915, 0.06492845953575202], [0.029677859640547206, 0.060891447588801384, 0.038303400190281015, 0.054987633135169744, 0.024405043738495027, 0.08047794444220406, 0.030120661415691887, 0.03131700347044638, 0.08469799121043511, 0.025099181669897268, 0.07316217664629221, 0.03822748569239463, 0.0369391376817865, 0.007570064061188272, 0.031988915987312794, 0.007897659071854182, 0.05221572258908834, 0.021128598301272308, 0.0367697040949549, 0.02013738077533032, 0.04491045172991497, 0.044552222559494634, 0.047581827134958336, 0.012216274925906743, 0.3295398684484618, 12.63166262422289, 32.406530244009836, 45.46896294185093, 40.425401074545725, 26.905802965164185, 35.42070395605904, 40.40253107888358, 28.179734332220896, 6.964329702513559, 0.1572045266096081, 0.41397622334105627, 2.540031897170203, 3.4314838222094943, 3.14637838942664, 4.659181007317134, 2.884694899831499, 13.57844066619873, 31.535361630576, 43.82913596289498, 50.15553331375122, 47.219367027282715, 47.76486662455967, 45.334445817129954, 47.90383407047817, 47.408066204616, 46.45080941064017, 46.272108691079275, 48.58026204790388, 46.98916278566633, 47.25064434323992, 45.724986689431326, 47.349888937813894, 42.28434297016689, 32.35883433478219, 33.024874755314414, 33.80340998513358, 39.0973675591605, 45.14596898215157, 46.02838325500488, 45.48412391117641, 42.83819777624947, 44.35818222590855, 43.28966045379639, 42.51283795492989, 36.26115458352225, 31.565405641283306, 30.93316125869751, 31.26872103554862, 30.65818977355957, 30.647489547729492, 33.1591591153826, 42.59021656853812, 43.67047037397112, 45.07105350494385, 44.32545621054513, 45.732275349753245, 45.90656396320888, 43.100155285426546, 41.41680131639753, 42.904295989445274, 40.81973218917847, 43.17354563304356, 42.89052465983799, 47.571685859135215, 32.49220153263637, 34.642842701503206, 47.20852088928223, 44.69075427736555, 48.864259243011475, 44.8315213067191, 46.34209442138672, 41.36890043531145, 41.07514796938215, 36.57410144805908, 34.528353759220664, 33.363408361162456, 32.71866416931152, 32.200870513916016, 34.09440401622227, 33.17667204993111, 41.12799596786499, 43.73044375010899, 47.20197916030884, 45.3560790334429, 45.73808751787458, 46.33362109320504, 43.95436334609985, 42.246958187648225, 35.700771944863455, 34.361148834228516, 32.94046803883144, 31.44741828101022, 32.96877152579171, 42.34335402079991, 47.44297048023769, 45.32196337836129, 45.821406841278076, 45.28515182222639, 47.3347418648856, 46.789620944431846, 47.351535660879954, 46.69937079293387, 46.07123974391392, 46.063843386513845, 46.935950006757466, 44.123089926583425, 45.200929233006065, 45.37950141089303, 45.255083492824006, 49.233642850603374, 49.55025141579764, 40.391254152570454, 26.392494371959142, 8.329139164515905, 2.994472094944545, 2.17003185408456, 3.82222923210689, 4.181409410067967, 6.798376756055014, 6.638317619051252, 1.0072544025523322, 0.20936390704342298, 0.7028645702770778, 6.485438576766422, 29.077196666172572, 35.24648829868862, 35.35340370450701, 33.902915137154714, 42.62109783717564, 25.555470943450928, 3.4311218644891466, 0.060956179829580445, 0.02769342121402068, 0.025484358858583227, 0.011426997055033488, 0.011286005111677306, 0.03792027896270156, 0.030627618676849773, 0.03787984845361539, 0.07145737098263842, 0.002838583184971607, 0.049030054959335496, 0.05745740221547229, 0.03109179769775697, 0.029148904274084737, 0.06754594908228942, 0.04003569330754025, 0.05210879225549953, 0.011855717532203665, 0.04459390157301511, 0.039198540550257475, 0.05287458687754614, 0.0172643939565335, 0.0016199019550445623, 0.025447536459458724, 0.05581809214449354, 0.07753350958228111, 0.057689854742160866, 0.01802793923499329, 0.052677618339657784, 0.03872670765433993, 0.024177278192447763, 0.07156716473400593, 0.07796233014336654, 0.06689179382686104, 0.05932297996644463, 0.033754257152655294, 0.06260305217334203, 0.03194013949749725, 0.03477000032684632, 0.029450519875224148, 0.029184062566076006, 0.057317834347486496, 0.05999911975647722, 0.028463689078177725, 0.5642823694007737, 15.736023085457937, 41.565041133335654, 48.819436413901194, 42.71046904155186, 28.529183558055333, 32.70990596498762, 40.52375282560076, 30.53547763824463, 7.150022915431431, 0.16673968067126615, 0.350797067795481, 2.349982815129416, 2.6518475200448717, 3.7731406433241705, 3.1939620418207983, 3.6876278604779924, 15.035187823431832, 35.773206915174214, 45.625874110630576, 52.12405872344971, 48.45908893857683, 48.6217497416905, 48.68597541536604, 47.64370741162981, 49.57392392839704, 48.05523531777518, 47.81953852517264, 49.16581106185913, 47.988904339926584, 48.076191084725515, 48.36299882616316, 48.372257300785606, 42.78466190610613, 35.8422337940761, 33.972622939518516, 35.184948103768484, 40.51993131637573, 46.327906199863975, 48.21928923470633, 47.0426013810294, 42.964470863342285, 46.84572417395455, 44.93497998373849, 44.06067773274013, 37.29922934940883, 32.267646176474436, 32.65545640672956, 33.85752602985927, 32.99766560963222, 32.08269902638027, 34.79388959067208, 44.25825670787266, 45.41337387902396, 46.24089738300869, 45.22422654288155, 47.47846187864031, 46.64367403302874, 45.44489090783255, 43.968086038317, 43.94761664526803, 42.876291275024414, 43.88858127593994, 44.436880997249055, 49.30392040525164, 34.42669466563633, 36.108051027570454, 46.76086582456316, 45.74413592474801, 48.96199607849121, 45.77967248644148, 48.173142773764475, 44.14488295146397, 44.48332275663103, 38.166625091007774, 35.46302890777588, 34.23979159763881, 33.452727454049246, 33.118421827043804, 35.53604057856968, 36.08284296308245, 43.04112686429705, 45.508512088230674, 49.23490047454834, 46.26045308794294, 46.36639922005789, 49.6628851890564, 45.533879961286274, 42.879157406943186, 37.267469133649556, 34.82879039219448, 34.49844871248518, 33.16195576531546, 35.243337290627615, 46.165974957602366, 48.253241607121055, 46.90838302884783, 46.18579816818237, 46.970180307115825, 48.79246698107038, 49.00718368802752, 49.63046489443098, 48.7332718031747, 47.600454875401084, 48.468635763440815, 48.48499877112252, 46.102819306509836, 45.913008417402, 46.91803755078997, 46.853610379355295, 51.22395086288452, 51.547650064740864, 43.38146700177874, 29.33175434385027, 10.389190588678632, 3.879133675779615, 4.030210094792502, 5.407610126904078, 4.720458907740457, 6.965767111097064, 4.016325422695704, 1.5405360268695014, 0.12068360059389047, 0.581170128924506, 7.502873284476144, 32.62650326320103, 39.09107249123709, 38.52806690761021, 41.795766489846365, 48.411497252328054, 30.72356537410191, 4.068808206490107, 0.07402031309902668, 0.02949691131444914, 0.010135241102294197, 0.048573417855160575, 0.058220285922288895, 0.02110795726600502, 0.047938991005399396, 0.09509954628135477, 0.0312555485538074, 0.0617429343983531, 0.040508560969361236, 0.08957624408815588, 0.006919682732716734, 0.08607812465301581, 0.06589589440929038, 0.00545256958243304, 0.03190194136862244, 0.09755764116666146, 0.02537018177099526, 0.04306700100590076, 0.14186354194368633, 0.1321893289153065, 0.11113754247448274, 0.12229088720466409, 0.1069272801812206, 0.24996782253895486, 0.19116736203432083, 0.04512064152264169, 0.15396438618855818, 0.1003833052569202, 0.10676766160343375, 0.1163237416850669, 0.13321433748517716, 0.11089151924742119, 0.1332582522715841, 0.19604364037513733, 0.1964842403041465, 0.13814454578927585, 0.0852977754548192, 0.11074824657823358, 0.1898841437484537, 0.18661855826420443, 0.20737707508461817, 0.08398835893188204, 0.6626658216118813, 18.157753433500016, 45.67080463681902, 55.86744935171944, 50.93127189363752, 36.112185205732075, 45.37447786331177, 50.433416094098774, 35.03834111349923, 9.14931321144104, 0.4762117266654968, 1.0784040646893638, 4.185979587691171, 9.183096221515111, 9.425332137516566, 10.32331211226327, 4.855587908199855, 15.464081014905657, 35.002384185791016, 46.778757435934885, 53.202530315944124, 50.85326099395752, 52.03594514301845, 49.55414240700858, 49.38297006062099, 51.23238250187465, 47.900450297764365, 47.30875907625471, 50.765060561043875, 49.26831088747297, 50.35837207521711, 50.14153616768973, 51.1281977381025, 44.054334027426584, 37.47152035576956, 36.0646664755685, 37.72164855684553, 42.339331013815745, 49.273654052189414, 50.84370027269636, 48.410222257886616, 43.191850662231445, 48.07736185618809, 46.81454413277762, 45.71089574268886, 38.414380482264924, 34.230786732264924, 34.44938053403582, 34.20033972603934, 33.89714118412563, 33.98083571025303, 36.99090303693499, 45.63921812602452, 46.01818677357265, 47.44017730440412, 46.52807337897164, 48.66380023956299, 48.22211020333426, 46.92479814801897, 45.72598375592913, 46.490810189928325, 43.90670565196446, 46.48103754861014, 47.59700162070138, 50.8722608430045, 37.77200910023281, 39.817600454602925, 48.17676625932966, 47.51160478591919, 52.2305919783456, 47.943824427468435, 50.15331336430141, 45.6531457901001, 45.41139364242554, 39.5942645072937, 38.247307573046, 36.52418211528233, 34.814379828316824, 35.045285837990896, 37.42212561198643, 37.20522369657244, 45.32096283776419, 47.12154333932059, 51.78732122693743, 48.05161878040859, 46.98546634401594, 52.42652423041207, 48.78043270111084, 44.79535245895386, 38.62298277446202, 37.11912509373256, 36.36826801300049, 34.92008972167969, 35.821441309792654, 46.84111057009016, 50.569625105176655, 48.44523770468575, 47.20611681256975, 46.88682276862008, 49.641102586473735, 49.834224292210166, 51.20384625026158, 49.940444878169465, 48.36041062218802, 50.39763634545462, 51.13639661243984, 48.43612861633301, 48.486367566244944, 48.81500693729946, 48.566598415374756, 53.137745312282014, 52.69084760120937, 44.47805254799979, 32.05724082674299, 10.453355465616498, 5.0602054085050305, 7.587244391441345, 10.570967623165675, 10.756662573133196, 12.528901372637067, 14.774230854851858, 2.873314401933125, 0.3192250776503767, 1.2541591823101044, 9.009943638529096, 38.15950666155134, 45.986760071345735, 46.54672581808907, 46.51510804040091, 56.03517886570522, 34.77682828903198, 5.271021136215754, 0.22888120689562388, 0.13544445138956818, 0.08688218186476401, 0.11231659884963717, 0.09152203824903284, 0.08375390472688846, 0.08876732856567417, 0.1816628777555057, 0.1841580138674804, 0.14315395270075115, 0.31341746928436415, 0.25912391979779514, 0.09810483216175012, 0.20318290085664817, 0.1728478121970381, 0.13328673717166695, 0.14245352814240114, 0.2546080249760832, 0.11146301536687783, 0.12626467325857707], [0.026248446965057935, 0.03044482134282589, 0.007104003377857485, 0.03810643843774285, 0.030454086738505533, 0.01840819195578141, 0.03327157448178955, 0.04487932054325938, 0.03607936256698199, 0.027673467195459774, 0.0673628192661064, 0.029885325115174055, 0.02660859638958105, 0.03857745369896293, 0.04252737228359495, 0.03395950721044626, 0.0423279915537153, 0.04510150004976562, 0.05185290312926684, 0.06164620244609458, 0.010065212895694588, 0.05034438068313258, 0.06519417384905474, 0.02446972339281014, 0.0434331622506891, 4.297914198466709, 29.52596344266619, 45.443744455065044, 37.64616332735334, 28.829244988305227, 35.267673356192454, 38.22942290987287, 28.88079193660191, 10.296374814850942, 1.524392538837024, 1.452084481716156, 6.128443607262202, 2.9360292766775404, 3.3380120950085774, 2.457665345498494, 4.255313055855887, 10.550628508840289, 27.104391166142054, 46.33145325524466, 54.24223443440029, 51.721066679273335, 47.313959802900044, 49.610214369637625, 49.30235011237008, 47.31809050696236, 45.82843494415283, 45.86102546964373, 47.5461025919233, 45.028158800942556, 45.34090764181954, 44.52424417223249, 39.815849508558, 33.88743455069405, 33.04101194654192, 33.197099753788535, 34.66393395832607, 41.54442235401699, 45.33354255131313, 45.30887644631522, 45.58099569593157, 43.689150605882915, 46.13852957316807, 43.06417751312256, 40.907213483537944, 33.4176355770656, 32.027436528887065, 31.075255393981934, 32.3674327305385, 31.98493787220546, 33.64122860772269, 31.271281446729386, 40.41867521830967, 43.07227911267962, 42.63271175112043, 46.60984672818865, 43.29459367479597, 42.93779672895159, 44.91971131733486, 44.419996874673025, 46.7749011857169, 44.12042876652309, 43.754880564553396, 45.10040269579206, 42.55865785053798, 32.83955587659563, 38.0932799066816, 45.44981370653425, 42.36067935398647, 42.76722192764282, 42.06883069447109, 41.82737384523664, 40.217924390520366, 38.30347681045532, 35.1641069820949, 33.781491892678396, 32.51482139314924, 32.768753732953755, 31.79102407182966, 32.01244579042707, 34.7256304877145, 40.59499965395246, 44.3280166217259, 47.78305006027222, 45.37935202462332, 45.10382120949881, 47.2221428326198, 45.32416248321533, 41.06797742843628, 35.972460406167166, 35.89110394886562, 33.501281465802876, 33.244771344321116, 31.328079496111187, 36.28093957901001, 45.36129713058472, 45.54221085139683, 49.13938358851841, 45.35664183752877, 46.635621070861816, 46.96938821247646, 46.10581398010254, 47.37003523962838, 46.841312067849294, 45.994135584150044, 49.97453621455601, 48.72828994478498, 45.86130339758736, 46.558193819863455, 46.845265592847554, 48.64297301428658, 47.78096907479422, 38.67918675286429, 24.722399302891322, 6.77713828427451, 1.647895900266511, 2.6975675352982114, 2.178848249571664, 2.2040665192263464, 4.668617529528482, 2.319008831466947, 1.7694331386259623, 0.16340010772858346, 0.5500296056270599, 9.356355633054461, 32.133657114846365, 36.434637205941335, 26.83763071468898, 38.60577556065151, 38.576204027448384, 19.42661087853568, 1.8131070179598672, 0.009925976661699159, 0.049149463551917245, 0.04110230625207935, 0.12194798274763993, 0.04860704944335988, 0.0573870109926377, 0.04880569057006921, 0.029287966633481637, 0.015904114448598454, 0.0684883731550404, 0.03170065056266529, 0.05240397534466215, 0.03521196411124297, 0.016146485460922122, 0.03625156796936478, 0.08439471319850002, 0.07277925219386816, 0.042656938545405865, 0.04957145805071507, 0.023453505244106054, 0.0378234146961144, 0.021166019507550766, 0.029921518173068762, 0.02703517778510494, 0.02968238546912159, 0.03164227619501097, 0.030706332131688083, 0.04905701654830149, 0.03840867489842432, 0.004489485814701766, 0.0931374876360808, 0.030444387080413953, 0.0679870443418622, 0.049957927848611555, 0.024989448986681442, 0.02121152715491397, 0.03892093491075294, 0.015837492487792457, 0.0661858595641596, 0.05412666379873242, 0.05780517855393035, 0.03923815003197108, 0.05239883544189589, 0.03689171486933317, 0.12940733533884796, 6.865592326436724, 33.77381065913609, 51.09980045046125, 43.957622051239014, 31.90450552531651, 40.29595960889544, 43.58095325742449, 34.685230187007356, 10.125337958335876, 1.6347049623727798, 0.5346646415335792, 1.5458208918571472, 2.9892394500119344, 4.901330070836203, 3.0150287747383118, 3.797121047973633, 13.38567158154079, 28.22395440510341, 46.83387402125767, 53.48620441981724, 51.054970673152376, 49.05501161302839, 52.22516196114676, 49.43142679759434, 48.78766230174473, 46.23763172967093, 46.048817907060894, 49.40197685786656, 47.358490807669504, 47.65215989521572, 44.48216240746634, 42.84288781029837, 36.391874517713276, 34.14516060692923, 35.211128916059224, 35.19005502973284, 44.162072794778005, 46.916234493255615, 48.30319568089077, 46.95858028956822, 44.23992388589041, 47.12935658863613, 44.56672198431832, 42.94766664505005, 35.24902786527361, 33.23822266714913, 32.65056140082223, 33.36571863719395, 33.68213612692696, 35.07798753465925, 32.45380578722273, 42.27545622416905, 44.50304521833147, 44.813528946467805, 46.5122731753758, 43.43647589002337, 43.262989793504985, 46.59815290996006, 46.39232989719936, 47.26552391052246, 45.490582261766704, 45.71025650841849, 45.1832252229963, 45.422531604766846, 35.30131305967058, 40.07823085784912, 47.457440103803364, 45.73647206170218, 45.96177087511335, 43.24247176306588, 43.646634578704834, 42.581725869859966, 40.47834982190813, 37.05526072638375, 34.863045011247905, 34.13660042626517, 34.713203634534565, 33.59261553628104, 34.669322286333355, 35.41640649523054, 43.10212857382638, 46.83666372299194, 49.34787470953805, 45.74141917909895, 46.21235070909773, 47.7765291758946, 46.563391072409495, 43.58987821851458, 38.02534736905779, 37.990800925663535, 35.79014662333897, 34.00527599879673, 32.69803844179426, 38.765990597861155, 46.45953287397112, 46.6808295249939, 50.71326868874686, 46.5468613079616, 46.61324439729963, 46.58321080889021, 48.145770345415386, 49.552391460963655, 48.28458145686558, 47.87515538079398, 51.72289752960205, 50.571629660470144, 47.81059619358608, 47.53710467474801, 47.666118826184956, 50.40568930762154, 49.920826639447895, 40.56736666815621, 27.767700944628032, 8.426554645810809, 2.9700090076242174, 3.1605627025876726, 4.441541280065264, 6.270967662334442, 8.643323676926748, 5.190958780901773, 1.117685813988958, 0.13085067431841577, 0.5110302897436279, 10.552966577666146, 34.96960258483887, 39.624013219560894, 32.21338421957833, 42.13744068145752, 45.22116238730294, 24.04750861440386, 2.5182527686868394, 0.04474320302584341, 0.04855748246024762, 0.017372744124648825, 0.012586792365514805, 0.025864056876993606, 0.06585049363119261, 0.02393049670250288, 0.014185989142528601, 0.08575445666377034, 0.013823225661846144, 0.008745902484016759, 0.025918085227853487, 0.09840239690882818, 0.030984114190297465, 0.017382760997861624, 0.05741918033787182, 0.014244638316865479, 0.0648993978809033, 0.02860570985025593, 0.05160217086917587, 0.19366063896034444, 0.12136992519455296, 0.1738443494375263, 0.10918025393038988, 0.15178463315325125, 0.08244421000459365, 0.1462309325912169, 0.14464748970099858, 0.10319991090467998, 0.11490685200052601, 0.22806539067200252, 0.13374653964170388, 0.13500695915094443, 0.10157433777515378, 0.13208084473652498, 0.07992391381412745, 0.12701772499297345, 0.11395086401275226, 0.11308847993080105, 0.2146197035908699, 0.12574986873992852, 0.19849273110074656, 0.14114215065326008, 0.10067579456205879, 0.20509468684239046, 7.497390287263053, 39.01326656341553, 55.974538462502615, 48.674809660230366, 41.31064326422555, 45.858923639569966, 48.18143197468349, 38.08957304273333, 12.986324736050197, 2.2755471978868758, 2.4415064411503926, 11.178221072469439, 8.23812471117292, 10.45242006438119, 6.308481855051858, 7.072631708213261, 13.622945615223475, 29.693866661616735, 48.79726818629673, 57.82325608389718, 53.71752037320818, 50.4671357018607, 53.322438853127615, 50.79250941957746, 48.92953756877354, 46.44468109948294, 48.96208987917219, 51.34871619088309, 48.727355412074495, 50.008710929325645, 46.604190894535606, 42.514196327754426, 37.00491060529436, 37.168526785714285, 38.355814116341726, 37.60478333064488, 46.455822535923545, 49.444027355739046, 49.020781312670024, 47.90398345674787, 44.29245574133736, 48.75458887645176, 46.771645954677034, 44.57864856719971, 37.05503838402884, 34.84341982432774, 33.67239475250244, 36.552169459206716, 36.0624361038208, 36.506891523088726, 33.42138065610613, 43.38268641063145, 45.932522433144705, 45.10073273522513, 49.00832666669573, 44.00926801136562, 43.45324189322335, 47.09387561253139, 47.807778699057444, 50.0132863180978, 48.26656130381993, 47.47329241888863, 47.62016691480364, 46.06360714776175, 38.37732573917934, 42.20491811207363, 48.388710635049, 47.29373359680176, 46.119265692574636, 45.66921697344099, 45.50147703715733, 44.96795613425118, 42.14043882914952, 38.6007832799639, 36.38525635855538, 35.41537468773978, 36.01566777910505, 35.98133672986712, 36.341708523886545, 37.83544615336827, 44.591002464294434, 47.927252973829, 50.51407773154122, 46.97339732306344, 46.992553506578716, 50.575993129185264, 49.200656277792795, 45.645408970969065, 40.63408327102661, 39.52490758895874, 36.71662984575544, 36.84319128308977, 34.289992332458496, 40.116762093135286, 49.076658725738525, 49.49099023001534, 52.86537592751639, 48.29997519084385, 48.10293470110212, 47.930952889578684, 48.692885398864746, 49.131726673671174, 48.715967314583914, 51.26360075814383, 53.71502249581473, 53.282563141414094, 49.40743119376046, 48.993804931640625, 49.68582466670445, 51.09447118214199, 52.39326320375715, 41.82545961652483, 30.71654074532645, 10.43614477770669, 3.9198700955935886, 6.941928710256304, 7.578666840280805, 10.124862006732396, 13.604459932872228, 8.214206406048365, 3.8602128624916077, 0.5383685742105756, 1.1571147782461983, 12.761771985462733, 39.85046543393816, 47.68513951982771, 38.293085779462544, 51.0481927054269, 53.55654450825283, 26.839190585272654, 2.9459135234355927, 0.1216004371110882, 0.14220754562744073, 0.1452703984188182, 0.2360237921987261, 0.12395150666790349, 0.15967771889907972, 0.0839114198461175, 0.10826125288648264, 0.17364822567573615, 0.2187836965812104, 0.0766083677964551, 0.20320373188172067, 0.14647459451641354, 0.09653947222977877, 0.09715540560760669, 0.1551217090870653, 0.1555334712777819, 0.11822650315506117, 0.10536085494926997, 0.27947147509881426], [0.03256005587588463, 0.05234457978180476, 0.03986455659781184, 0.02679285596657012, 0.04528595979458519, 0.05556632511849914, 0.019149544050118754, 0.057548868735986095, 0.045415970496833324, 0.017524508659594824, 0.036119067043598206, 0.034428480081260204, 0.07626390270888805, 0.02004201946380947, 0.01887808763422072, 0.01751770973870797, 0.052738157234021595, 0.050468121721808396, 0.05562882837174194, 0.027583147399127483, 0.030494829373700277, 0.029808402992784977, 0.10429598244705371, 0.03673030835177217, 0.005660902733714985, 1.775572957737105, 22.633367810930523, 41.58908884865897, 46.40773752757481, 37.197500773838584, 30.6863751411438, 24.762384448732647, 37.58101006916591, 15.646264519010272, 2.606217397110803, 6.095999428204127, 10.036420123917715, 1.9897458595888955, 2.4760426793779646, 1.3002433265958513, 3.010652495282037, 15.035957336425781, 23.215024096625193, 40.63187721797398, 47.39173098972866, 50.57548243658883, 48.98484522955758, 46.19010605130877, 46.46767963681902, 50.20908655439104, 49.2826589175633, 47.40065942491804, 43.88941158567156, 43.67396184376308, 41.07736791883196, 38.156980991363525, 33.183627196720664, 33.42190524509975, 33.98621709006173, 32.5668877192906, 33.274130957467214, 41.22592735290527, 44.74747242246355, 47.225599561418804, 43.702220167432515, 40.907557419368196, 45.13020004544939, 42.997353213174, 40.13065849031721, 33.39134706769671, 33.12319871357509, 30.419727597917827, 30.894841943468364, 31.866919245038712, 33.728077616010395, 30.70971414021083, 33.36857782091413, 41.691619941166465, 44.18072523389544, 44.683597632816856, 46.42383650371006, 44.84032120023455, 42.431443282536094, 43.12525912693569, 43.26215253557478, 45.74116904394967, 44.018599442073274, 41.09967163630894, 34.61354562214443, 29.618975503104075, 41.4972197668893, 47.54562316622053, 41.9207124710083, 41.38136897768293, 38.84881659916469, 37.618380955287385, 36.74208457129342, 36.42099789210728, 33.81199448449271, 34.44636501584734, 33.031461647578645, 33.356779779706685, 32.48546872820173, 33.06901666096279, 32.83268410818917, 41.11654881068638, 45.86970376968384, 46.21092285428728, 44.29721178327288, 46.17518479483468, 44.725641182490754, 44.66470548084804, 41.5799936567034, 41.054817540305, 36.374173981802805, 32.243136405944824, 33.028126512254985, 32.20616156714303, 31.969929763248988, 36.69640711375645, 41.67062248502459, 43.855553013937815, 46.07536697387695, 47.07079369681222, 46.17676551001412, 45.40065172740391, 41.99589892796108, 40.678857462746755, 40.885639326913015, 47.51180975777762, 46.83139698845999, 48.752174377441406, 46.94372156688145, 48.283796310424805, 48.36347825186593, 44.282829012189595, 36.25176409312657, 22.94506573677063, 7.817127278872898, 1.755749530025891, 2.5068653225898743, 3.7241710424423218, 5.108805017811911, 5.931700587272644, 0.3595229738524982, 0.2088700421154499, 0.07229019129382712, 0.7850882496152605, 11.988134367125374, 33.1347188268389, 46.53273214612688, 24.33766712461199, 40.58801324026925, 39.83902175085885, 11.852403913225446, 0.9026814624667168, 0.036651879881641695, 0.09296026107456003, 0.043300274559961896, 0.04810301327545728, 0.00979666315418269, 0.05786572423364435, 0.04401183727064303, 0.026843483160649027, 0.036924186162650585, 0.04555310581677726, 0.09363201074302197, 0.031537408607878854, 0.05208496889099479, 0.06694903504103422, 0.024372874393260906, 0.03638601629063487, 0.15786989804889473, 0.046846410525696616, 0.04565066558175853, 0.017861318175813982, 0.04287228181159922, 0.03557891924200313, 0.08228185014533144, 0.022380816018474952, 0.01226720746074404, 0.034206982502447705, 0.01995909569918045, 0.08212112555546419, 0.0741349651611277, 0.020452332982261266, 0.017203649805326546, 0.022013055127380148, 0.0361178660366152, 0.028862386077110256, 0.03477431580956493, 0.018747683381661773, 0.033603551132338386, 0.028937465976923704, 0.030633379439158098, 0.029540575042899166, 0.02669234966327037, 0.04931619996204972, 0.04366741968052728, 0.028798291659248725, 0.01171150678835277, 2.246493956872395, 28.047657762254985, 47.310169560568674, 48.29796716145107, 39.93565034866333, 35.12497125353132, 32.282692500523154, 38.96833951132638, 17.384912252426147, 2.8292313388415744, 5.859734620366778, 8.805484209741865, 2.958621995789664, 2.8986525280135016, 3.360190962042127, 3.700250566005707, 15.736608471189227, 23.947218315941946, 42.529280866895405, 48.459116731371196, 51.18371384484427, 48.99777582713536, 48.22062676293509, 46.55941670281546, 51.179294790540425, 50.512340681893484, 50.59947804042271, 45.78936174937657, 45.66279683794294, 43.3412195614406, 41.25130564825875, 35.714939321790425, 34.415188448769705, 34.49755239486694, 34.33914041519165, 35.80552298682076, 44.790050983428955, 47.007697105407715, 48.542397839682444, 44.296909536634175, 43.283605098724365, 47.980594294411794, 45.303224086761475, 42.08154589789254, 35.92083181653704, 34.79685994556972, 32.347651209150044, 32.733147689274375, 34.22632598876953, 34.6381630897522, 32.79692867824009, 34.797857012067524, 45.535783767700195, 44.44772366115025, 46.3046748978751, 46.83762257439749, 44.942817551749094, 42.925932679857524, 44.35058784484863, 44.345136983054026, 47.11097165516445, 45.75762932641165, 44.109370708465576, 36.689677783421104, 33.0009069442749, 43.56382942199707, 49.01737322126116, 44.30575459344046, 43.626946857997346, 39.85058355331421, 40.22723845073155, 39.27124275479998, 38.487534591129844, 35.2607216835022, 36.16134023666382, 34.709402969905305, 33.90834515435355, 34.4111202784947, 33.62037011555263, 34.768066610608784, 43.293749468667166, 47.786916732788086, 48.08010639463152, 44.78719527380807, 45.65077992847988, 46.324213232312886, 47.108327865600586, 43.68776791436331, 42.89549262183053, 37.15517234802246, 34.733815465654644, 34.37803643090384, 33.12217732838222, 33.24581010001046, 40.480632305145264, 44.230484758104595, 46.20440891810826, 47.27915975025722, 48.39018365315029, 46.8450745173863, 46.335479736328125, 42.95629283360073, 43.46386568886893, 44.11092710494995, 48.48975133895874, 48.52742794581822, 49.749619552067344, 47.8453927721296, 49.203546728406636, 49.85506888798305, 45.54529932567051, 38.64203820909773, 26.151942525591167, 8.036011167934962, 2.788452361311231, 3.6017055681773593, 6.926258785384042, 7.628164069993155, 6.730693919318063, 4.209712028503418, 0.9145591365439552, 0.03221813190196242, 1.089418045112065, 13.136523944990975, 39.527937003544395, 47.834035941532676, 30.725198200770787, 46.48128768375942, 45.32054941994803, 15.754712002617971, 1.2251876911946704, 0.06404091537530933, 0.05674615163089974, 0.012344702097055103, 0.05222515083317246, 0.050343155927423916, 0.03758850247998323, 0.054384503713143725, 0.006575578116878335, 0.011522639110418302, 0.027906415052711964, 0.02477525923001979, 0.01689010895123439, 0.04383772857753294, 0.03512837877497077, 0.0315519428279783, 0.022289049246215394, 0.07057364697435073, 0.024314403334366422, 0.02246166855495955, 0.021965438932446495, 0.114164656826428, 0.1278980563261679, 0.13616633122520788, 0.15145388804376125, 0.14373411371239594, 0.1757929255919797, 0.09639000453587089, 0.2882966101169586, 0.14762309645967825, 0.08948660961219243, 0.10617349562900406, 0.06565591014389481, 0.1914049849978515, 0.12525801227561065, 0.2066975086927414, 0.12682199478149414, 0.15400390406804426, 0.14012214967182704, 0.1805219211216484, 0.12224131343620163, 0.06017069412129266, 0.20206363020198687, 0.19289891554840974, 0.14412836969963141, 0.08930246877883162, 2.844745146376746, 29.688777106148855, 52.65153816768101, 56.188987663814, 45.43625429698399, 41.04412773677281, 35.027234418051584, 47.49030160903931, 20.050355877195084, 3.755865684577397, 7.731819902147565, 13.987110257148743, 6.527959815093449, 7.0137544104031155, 5.04655567237309, 4.578383445739746, 19.289950234549387, 26.65893520627703, 44.24372107642037, 49.01004981994629, 51.48807968412127, 50.493663924080984, 48.60933331080845, 46.08450385502407, 51.106567995888845, 53.95318242481777, 52.485750675201416, 47.57429838180542, 49.013562134334016, 44.130593981061665, 42.653406960623606, 36.24660505567278, 36.34643677302769, 36.33164405822754, 35.36354807444981, 36.48744004113333, 46.70968886784145, 48.89565120424543, 51.27302598953247, 44.227156570979524, 42.93296773093087, 49.054216044289724, 48.47243642807007, 42.801438331604004, 37.09816932678223, 36.61544322967529, 34.116436753954204, 33.533017362867085, 35.54028940200806, 36.12796803883144, 34.288310868399485, 36.042272431509836, 46.39607497623989, 46.723703384399414, 49.35792875289917, 48.464491162981304, 45.84252936499459, 43.60145391736712, 44.46672003609793, 46.15475361687796, 48.35296562739781, 46.41105876650129, 44.17517014912197, 38.540274892534526, 38.66792024884905, 46.811153411865234, 51.00989770889282, 46.122291633060996, 44.09095450810024, 41.22822720663888, 41.03269100189209, 40.41329383850098, 39.60843883241926, 35.89094066619873, 38.221029485974995, 37.25116865975516, 36.567389488220215, 36.46552889687674, 35.288920947483604, 36.00060755865914, 44.994373185294016, 48.350064754486084, 49.60319668906075, 46.33491693224226, 46.02349867139544, 48.11879743848528, 49.11945268086025, 45.74266638074602, 45.19780601773943, 39.94020141874041, 36.6756181035723, 36.771308694567, 35.10445669719151, 35.55226809637887, 41.32117673328945, 45.98837552751814, 48.039591448647634, 49.14510543005807, 50.341328144073486, 49.47662135532924, 47.074979986463276, 44.81842395237514, 45.014599391392295, 46.32083988189697, 48.08233329227993, 49.50863170623779, 51.90174068723406, 50.187925815582275, 51.5472366469247, 51.62633841378348, 47.43026917321341, 39.728375162397114, 27.64043947628566, 11.051481587546212, 4.862015426158905, 6.242887386253901, 11.817893947873797, 11.724922708102635, 13.458645905767169, 5.310522947992597, 1.5305685102939606, 0.5279729291796684, 1.3411074195589339, 16.240735019956315, 42.51565197535923, 55.52201965876988, 36.76832444327218, 51.08027948651995, 52.317666803087505, 18.609738962990896, 1.501628177506583, 0.12765379729015486, 0.15700077611420835, 0.14313819711761816, 0.16409537542079175, 0.07873249453093324, 0.17057279284511292, 0.09332513649548803, 0.08555825147777796, 0.13920106552541256, 0.15891797680939945, 0.19862663320132665, 0.12873587065509387, 0.13453548587858677, 0.13746074533888272, 0.2185919697263411, 0.1086265015016709, 0.17468643853706972, 0.14058355348450796, 0.11897507655833449, 0.07519518969846622], [0.017980540171265602, 0.04426842189526983, 0.05962529445865324, 0.07107728280659233, 0.051045327713446956, 0.04967650884230222, 0.0326062607179795, 0.05352805681260569, 0.03307639727635043, 0.023795101824881773, 0.03577079198190144, 0.01822672115771898, 0.05076377639280898, 0.039778067131659815, 0.08622913940676621, 0.05302835987614734, 0.03730153984257153, 0.05316351048116173, 0.11679787481469767, 0.007256718285913978, 0.04009645611846021, 0.05425126996955701, 0.04292413545772433, 0.01666107284836471, 0.03576708718069962, 0.5370030360562461, 10.730647649083819, 39.09788519995553, 41.794686044965474, 30.253999165126256, 39.936407702309744, 44.05864538465227, 43.919212409428184, 15.756660972322736, 3.2680278846195767, 3.922585104193006, 12.792471732412066, 6.94846088545663, 1.3901069845472063, 1.884240938084466, 2.172468500477927, 15.05093765258789, 26.81160797391619, 42.23234960011074, 51.83838701248169, 52.427806173052105, 43.78872871398926, 48.11304433005196, 49.39145728519985, 48.05078847067696, 46.43963670730591, 44.49718441282, 42.97321169716971, 39.48614706311907, 34.37662942068917, 32.12081684385027, 32.844652380262104, 37.5822433744158, 34.04199375425066, 33.38586146490914, 34.440521580832346, 40.96523094177246, 43.54734134674072, 46.82533121109009, 44.21081788199288, 42.47742646081107, 45.573891162872314, 43.98062058857509, 39.217533179691856, 32.43041467666626, 32.50511475971767, 33.496709551130024, 32.312913690294536, 30.412960052490234, 29.905387197222026, 30.636921337672643, 32.357976232256206, 38.65718180792672, 42.854640688214985, 41.287867069244385, 45.121275084359304, 45.88912398474557, 46.630097252982004, 43.922919273376465, 45.650658335004536, 44.822651931217735, 45.79137325286865, 41.70982769557408, 42.2918643951416, 35.164541244506836, 40.09428119659424, 46.434557574135916, 40.68024015426636, 42.054618154253276, 35.37095832824707, 33.9362838608878, 32.91088955742972, 32.336975302015034, 32.28623955590384, 33.33667516708374, 32.115074157714844, 33.9081575529916, 32.53125040871756, 32.50241191046578, 34.61469554901123, 37.93171344484602, 44.772093364170615, 42.45535898208618, 44.278729575020925, 45.982466084616526, 47.77339901242937, 47.56548459189278, 44.12174892425537, 42.61677605765206, 43.312047549656455, 39.69177205221993, 32.2033405985151, 32.338948590414866, 31.393413407461985, 33.02537849971226, 35.547852516174316, 39.65223332813808, 41.45217112132481, 44.29776069096157, 43.68710436139788, 45.19988700321743, 45.40291336604527, 45.58700936181204, 44.89126886640276, 45.81827667781285, 46.51994398662022, 48.336164883204866, 48.619352613176616, 48.26874303817749, 45.155130181993755, 42.33073956625802, 29.585606779370988, 13.185516561780657, 5.084988330091749, 1.9489199817180634, 1.5394210581268584, 4.315598232405526, 7.499578969819205, 6.600558936595917, 4.207562863826752, 0.417655240212168, 0.10658485069870949, 1.43082885657038, 14.616989646639142, 30.312846933092388, 40.731858321598594, 38.19972978319441, 40.21784101213728, 37.58271585191999, 7.8781289884022305, 0.275899558195046, 0.0470831276449774, 0.036748727184853384, 0.05721806934369462, 0.06617023290268012, 0.04478108224325946, 0.03425433746139918, 0.018894630317975367, 0.00927187399273472, 0.023523234895297458, 0.06273019606513636, 0.0434107705950737, 0.019474435098735348, 0.040608441324106286, 0.02546529032822166, 0.06503223468150411, 0.010143790643529167, 0.028125069569796324, 0.023775191911097084, 0.047949423481311114, 0.05270019319972821, 0.04832553883482303, 0.018110593281952397, 0.0333020746308778, 0.034383849440408606, 0.018242291840059415, 0.03677161417103239, 0.059040648330535205, 0.05885405120040689, 0.020929987708638822, 0.011543236889078148, 0.02829078139205064, 0.03689154184290341, 0.012260160874575377, 0.02681407206026571, 0.02970646328425833, 0.007130878877692989, 0.045899409734244855, 0.028374225932306478, 0.07160605836127486, 0.027630709311259643, 0.021415610132472854, 0.014137063375008958, 0.030258475270654474, 0.01850032852962613, 0.02369387966713735, 0.7741897829941341, 14.400877220290047, 46.172728606632774, 47.90698160443987, 37.59998559951782, 42.14741134643555, 39.239743096487864, 46.57259048734392, 18.411835159574235, 3.53893706202507, 5.57377108505794, 11.546393956456866, 7.632526670183454, 2.7896344235965183, 2.714288592338562, 3.801467146192278, 18.04633559499468, 31.375987325395855, 43.198135307856965, 51.23763534000942, 52.271728788103374, 46.90096582685198, 45.55149711881365, 49.789623805454795, 50.59716429029192, 49.369476658957346, 46.77265691757202, 45.096209457942415, 42.23249898638044, 37.24042674473354, 34.60137932641165, 35.44939306804112, 38.12770128250122, 36.619122300829204, 34.86365645272391, 35.7397826058524, 44.27422366823469, 46.40553147452218, 47.89708736964634, 45.0956848689488, 42.75049761363438, 46.04299879074097, 45.92743982587542, 40.997998646327424, 34.23497997011457, 35.22963891710554, 35.81926652363369, 33.98894425800869, 31.264048371996196, 32.74251038687569, 32.709756578717915, 33.433929102761404, 40.78858688899449, 43.896165234701975, 43.519663197653635, 46.67524317332676, 46.528900214603965, 47.30145999363491, 43.558215277535574, 45.29522671018328, 46.18714959280831, 46.711321694510325, 42.272555351257324, 44.21016822542463, 38.368633542742046, 42.88002940586635, 48.97793524605887, 43.28473765509469, 43.41777828761509, 37.50449650628226, 35.809368814740864, 35.59065341949463, 35.7689858845302, 33.72720561708723, 34.8476026398795, 34.00217015402657, 34.95292690822056, 33.9554226739066, 34.691264697483604, 36.38431140354702, 39.42528779166085, 47.04064546312605, 44.385394845690044, 46.30359445299421, 47.63434818812779, 47.88557767868042, 49.20923382895333, 45.858767305101665, 44.11390093394688, 45.19420337677002, 39.83059706006731, 34.55001824242728, 33.87337487084525, 33.65114368711199, 34.85833065850394, 37.598109585898264, 42.20269468852452, 43.69601195199149, 46.054300035749165, 46.12102011271885, 47.23748792920794, 46.58262368610927, 47.18989624295916, 45.005441665649414, 46.68563073022025, 47.80437755584717, 49.33501359394619, 48.58266612461635, 49.72825036730085, 46.763759749276296, 45.68131726128714, 31.079928057534353, 16.94622383798872, 5.7203515853200635, 2.0138191963945116, 4.0360444102968485, 5.5662683333669385, 9.13927914415087, 6.405512579849788, 3.5297704339027405, 0.6519558248775346, 0.066282550804317, 1.8538877325398582, 16.12258611406599, 35.205393178122385, 47.67860126495361, 40.86016723087856, 43.44742277690342, 43.506027357918875, 9.773691364697047, 0.5619635166866439, 0.03039569201480065, 0.03655999945476651, 0.06760502234101295, 0.04993030808067747, 0.026534332428127527, 0.04453735246456095, 0.015695690543257763, 0.014877750505028027, 0.03592168799202357, 0.029072511409010206, 0.03468102402985096, 0.011412087944336236, 0.03491108811327389, 0.06440226919949055, 0.002220083884562233, 0.02595640379669411, 0.04174989668120231, 0.03055883218933429, 0.025242834318695322, 0.04571123840287328, 0.15531787356095655, 0.17201606397117886, 0.14633316067712648, 0.18940246530941554, 0.12909615917929582, 0.10098821244069509, 0.12148363409297806, 0.14923616418881075, 0.1862900930323771, 0.09530989892248597, 0.15394477652651922, 0.18946400843560696, 0.09608778503856488, 0.14459525607526302, 0.119711395619171, 0.08731923984097582, 0.12059625956629004, 0.14710875334484236, 0.1802497607256685, 0.06691345945000648, 0.0980297794033374, 0.13497789071074554, 0.13391297071107797, 0.0562499118303614, 0.09591912158897944, 0.9146906094891685, 16.425876719611033, 52.09613043921334, 54.962641034807476, 40.72677918842861, 50.939755644117085, 51.28819043295724, 53.10055160522461, 21.768079110554286, 4.637688057763236, 5.899131340639932, 14.659576892852783, 11.40929731300899, 7.530461975506373, 6.534968376159668, 4.499945666108813, 22.42143385750907, 37.71773672103882, 49.430485316685264, 54.286734172276084, 55.614534923008506, 45.072516100747244, 46.85166835784912, 51.565194266183035, 52.34613357271467, 51.68969208853585, 48.8113556589399, 46.96273878642491, 44.03489991596767, 38.03321967806135, 35.36221054622105, 36.044971806662424, 40.53145490373884, 37.46120922906058, 36.170501436506, 37.67706891468593, 45.77238382611956, 48.33415685381208, 49.66114813940865, 45.06176028932844, 43.676862716674805, 49.25192356109619, 48.35104097638811, 42.56347295216152, 35.809591157095774, 37.37932818276541, 37.601093837193076, 36.417676653180806, 33.40333618436541, 33.79124368940081, 34.528662954057964, 35.79510416303362, 40.734588963644846, 46.69574383326939, 45.48424203055245, 49.354270526341026, 48.141816820417134, 48.50125060762678, 45.852698053632466, 47.59101227351597, 47.61401081085205, 47.139754567827495, 43.527577195848735, 44.61781208855765, 40.42818035398211, 46.66096115112305, 50.957470076424734, 45.00665760040283, 45.22715173448835, 38.934432302202495, 37.538073675973074, 37.4106228692191, 36.50563737324306, 35.556013175419395, 37.23893288203648, 35.52655281339373, 35.7724460874285, 35.37415449959891, 36.33768899100167, 38.716682706560405, 40.37771211351667, 48.811855929238455, 44.296899114336284, 46.66651276179722, 48.808298451559885, 49.20966461726597, 50.22183649880545, 47.260218960898264, 45.7816492489406, 47.12444421223232, 43.60491064616612, 35.46810456684658, 35.90590361186436, 35.5442533493042, 36.994964259011404, 39.412926946367534, 43.60991334915161, 45.273176601954866, 46.69009494781494, 48.6291252544948, 49.09523820877075, 48.71879523141043, 48.24718277794974, 44.66236741202218, 46.49041066850935, 47.7807571547372, 49.20922340665545, 49.543945925576345, 49.99832337243216, 47.17794186728341, 47.22094774246216, 32.31626967021397, 17.030257088797434, 7.0532097561018805, 3.754896410873958, 5.577452761786325, 11.21203361238752, 16.116030488695415, 16.35733621461051, 10.332507184573583, 2.138843996184213, 0.2920260014278548, 2.207766434976033, 18.615196772984095, 42.19011844907488, 51.3165807723999, 49.17437124252319, 51.44752999714443, 47.58229923248291, 12.437150410243444, 0.6085907061185155, 0.08242154693497078, 0.06240078766963311, 0.1515250527965171, 0.2342396793620927, 0.12266664632729121, 0.10259554654892002, 0.1801774560340813, 0.15170022339693137, 0.17339331363993032, 0.09753566341740744, 0.08934113848954439, 0.10212441932942186, 0.09683774943862643, 0.13532620987721852, 0.10680088946329695, 0.1281139797398022, 0.10906039071934563, 0.14658320083149842, 0.06937933713197708, 0.0810547602762069], [0.07120846398174763, 0.06819994827466351, 0.07074340965066638, 0.03572348112772618, 0.011449903549094285, 0.028987416332321506, 0.026852329560954655, 0.051563504551138194, 0.015326480979898145, 0.013045544802610363, 0.04553552158176899, 0.014500318793579936, 0.040714604913124015, 0.007576129316086215, 0.04837896328951631, 0.027269511550132717, 0.0880453469497817, 0.06662064444805894, 0.025643738252776008, 0.03690431187195437, 0.0245227322448045, 0.01673908910847136, 0.044592072921139855, 0.031038318960262195, 0.017550291293965917, 0.11830298762236323, 8.953949843134199, 27.817066158567155, 44.647376673562185, 34.96599299567086, 43.61934552873884, 61.58814443860735, 46.127582686288015, 21.37253032411848, 4.700916230678558, 4.068100793021066, 8.553301947457449, 5.187451243400574, 2.4576544889381955, 0.8790012417095048, 10.527608258383614, 17.747616904122488, 23.453071117401123, 40.31787422725132, 39.28932891573225, 44.50465720040457, 45.09821401323591, 52.0578111239842, 47.428386211395264, 47.867703437805176, 42.879817485809326, 43.001817430768696, 38.6443623815264, 35.32129955291748, 33.9043846811567, 33.983764375959126, 33.02425289154053, 34.06739984239851, 32.23789746420724, 32.147789750780376, 32.70686960220337, 38.0828332901001, 43.17115545272827, 45.676311084202354, 44.9122246333531, 45.11678654806954, 44.58524588176182, 42.196510791778564, 42.08769505364554, 37.85285486493792, 34.401260784694124, 33.833749294281006, 32.592498779296875, 33.0666230065482, 32.33373049327305, 31.03639759336199, 31.01713718686785, 33.67650808606829, 39.81627682277134, 43.609631947108674, 43.568807806287495, 43.52005577087402, 44.21302046094622, 44.906544481004985, 46.00217464991978, 45.45193290710449, 44.559138025556294, 44.13624634061541, 48.104661328451975, 37.005007880074636, 36.675291538238525, 46.50338295527867, 42.63061686924526, 40.83460133416312, 34.48765468597412, 35.313878876822336, 32.21875865118844, 34.00791284016201, 32.32426009859358, 32.97681406566075, 32.47110332761492, 35.56101935250418, 32.20209339686802, 32.74528966631208, 32.504756927490234, 34.302648476191926, 41.843333857400076, 45.10854251044137, 44.22837945393154, 45.0771609715053, 44.52212497166225, 46.986842087336946, 46.060077462877544, 47.03484719140189, 43.964420863560264, 44.822978496551514, 36.187389033181326, 31.34093713760376, 31.54868480137416, 32.57166460582188, 32.64862632751465, 33.020872592926025, 35.239383765629356, 40.59658036913191, 42.28015668051583, 43.2798878124782, 43.09586477279663, 45.196249621255056, 45.93696928024292, 44.46949931553432, 43.805456502096995, 47.185727323804585, 47.4125269481114, 46.63706282206944, 45.907526288713726, 37.59562907900129, 22.60993501118251, 8.426434789385114, 1.38351694388049, 1.4410047105380466, 4.210695198604038, 4.323950835636683, 7.7388723237173895, 3.3414838058607916, 3.32074972987175, 0.38721938910228865, 0.10963053655411516, 3.052240937948227, 18.49584582873753, 32.13600908006941, 30.704318864004954, 44.83663170678275, 44.797287532261436, 29.05820550237383, 4.090282482760293, 0.08650879761470215, 0.03535054471077664, 0.02325025856095765, 0.04397158318066171, 0.043232305707143884, 0.02801508752496115, 0.04832534545234271, 0.05376599868759513, 0.05914453204189028, 0.0843264457902738, 0.037377735932490656, 0.03298246767371893, 0.02667423277827246, 0.04442606593615242, 0.03303732044462647, 0.10630117556346314, 0.017652902752161026, 0.07919562860791172, 0.012001105534311916, 0.014878196641802788, 0.03169418751661267, 0.035604513582906554, 0.05451063658776028, 0.07367006689310074, 0.016092672544930662, 0.009358137845993042, 0.04097815130704215, 0.042470025896493874, 0.08218967794839825, 0.07363500698868718, 0.015213462490854519, 0.013524871269640113, 0.017379436176270247, 0.028060515444459658, 0.004923455184325576, 0.026843639223703315, 0.025705769924180846, 0.04440863097884825, 0.00543437127323289, 0.06928911911589758, 0.06182672668780599, 0.0708967110674296, 0.04596260170053158, 0.014329748660592096, 0.016120455161269222, 0.06845377465443951, 0.1604387094931943, 11.273884739194598, 35.366226605006624, 48.415784290858674, 36.84495612553188, 46.9579757962908, 58.49043600899832, 47.36062043053763, 24.476924657821655, 5.356084023203168, 4.501881607941218, 9.388653465679713, 5.113295725413731, 5.158271414893014, 3.42405880349023, 12.746205415044512, 22.26698235103062, 29.061328717640468, 44.19281162534441, 45.50753934042794, 49.21774884632656, 47.06964724404471, 54.16124275752476, 49.71460410526821, 48.30917113167899, 44.76340464183262, 44.718307358878, 41.301544598170686, 37.20738806043352, 34.58020469120571, 35.801916871752056, 35.8594514301845, 35.146600995744976, 33.129743916647776, 33.56069551195417, 35.3628636768886, 39.61972618103027, 44.81542580468314, 47.95151260920933, 45.93689979825701, 46.853429726191926, 45.74880511420113, 45.13458088466099, 42.64085851396833, 38.69979510988508, 34.92050313949585, 35.100603921072825, 34.177681650434224, 34.83942461013794, 32.942830426352366, 33.29915142059326, 32.77861670085362, 34.73651484080723, 41.92843539374215, 44.90020424979073, 44.966889585767476, 45.937761374882285, 45.95847742898123, 46.95409175327846, 46.96532004220145, 47.38203477859497, 46.749762603214805, 46.773011275700156, 48.177937030792236, 39.70459842681885, 40.706820487976074, 47.46274157932827, 44.14521646499634, 42.89305033002581, 36.09267813818795, 35.76388938086373, 33.865915979657856, 35.42541830880301, 34.85900115966797, 34.34212119238717, 32.83323301587786, 34.74820171083723, 33.55400439671108, 34.59616470336914, 34.439173630305696, 35.717374665396555, 43.821406091962544, 46.75146838596889, 45.90965591158186, 47.284579345158164, 46.70485292162214, 47.292291845594136, 48.227672236306326, 48.64298343658447, 45.29782881055559, 47.25980206898281, 36.75236790520804, 32.95956516265869, 33.816656725747244, 33.529748235430034, 33.791163785117014, 35.64749663216727, 38.19976452418736, 42.375704833439414, 45.298909255436485, 44.999775409698486, 45.82769496100289, 46.72434261866978, 47.97742591585432, 45.22134304046631, 45.976410729544504, 47.02425118855068, 48.733487197331016, 47.2432792527335, 47.96413401194981, 38.464622906276155, 25.634313889912196, 9.490960478782654, 3.166539021900722, 2.11991970879691, 5.595605364867619, 7.129689012254987, 7.769762277603149, 5.668997015271868, 3.9496448636054993, 0.40567128040960854, 0.146490730079157, 2.7658446601458957, 20.246486152921403, 35.52631310054234, 35.6755291393825, 49.554545402526855, 49.090892110552105, 34.697337423052105, 5.698617620127542, 0.10079279435532433, 0.07103066066546099, 0.017017247754016092, 0.05657405818679503, 0.049586901507739506, 0.08366926426866225, 0.02077174316426473, 0.07575719989836216, 0.06037061767918723, 0.03435609735814588, 0.0687794986047915, 0.032235950231552124, 0.04832720463829381, 0.028535359339522462, 0.00911299925896206, 0.06417554350835936, 0.0298177803467427, 0.035524236104850254, 0.03632325180140989, 0.01420993888418057, 0.042003930014158995, 0.13815428955214365, 0.10507654877645628, 0.1428435365004199, 0.1078112552474652, 0.10725392693919794, 0.19683895127049514, 0.11835151644689695, 0.1873915046453476, 0.12107496602194649, 0.07860106908317123, 0.08270203295562949, 0.0817548930644989, 0.1081650909036398, 0.051896485433514626, 0.10446913779846259, 0.16577514314225741, 0.18137076842997754, 0.18648880879793847, 0.16084534195916994, 0.17808754103524344, 0.08280621522239276, 0.17774804282401288, 0.1212224659643003, 0.0898912064731121, 0.16761287381606443, 0.2712206249790532, 13.565181766237531, 40.80488736288888, 56.68160104751587, 45.152069500514436, 52.59128686359951, 64.7919032233102, 51.085584436144146, 27.154426881245204, 6.618689392294202, 5.587117271763938, 10.477779252188546, 11.481503861291067, 8.256512250219073, 4.509484674249377, 14.467786635671343, 31.278976576668875, 32.62927906853812, 45.323443344661165, 45.99508401325771, 49.42957162857056, 47.83337238856724, 53.548060757773264, 50.93921715872628, 52.08341523579189, 46.43674625669207, 47.061875683920725, 42.72319119317191, 38.94101224626814, 37.365157331739155, 38.48296267645699, 36.50210074016026, 36.43926818030221, 35.316560881478445, 35.80078431538173, 36.87172406060355, 41.328701632363455, 46.85520151683262, 50.916180406297954, 47.869562080928254, 46.78767197472708, 47.55418334688459, 47.76009668622698, 44.69768510546003, 40.917142459324424, 38.743367263248985, 36.696257727486746, 35.08396298544747, 37.43970455442156, 36.645449025290354, 34.72890656335013, 35.58438614436558, 36.6797696522304, 41.61434555053711, 47.447868960244314, 48.16248076302664, 47.89301919937134, 46.935887472970144, 48.45921400615147, 49.364956855773926, 49.181892667497905, 48.598111970084055, 49.25450134277344, 50.64496442249843, 41.05896214076451, 43.153406279427664, 49.44800172533308, 46.87755734579903, 44.48829766682216, 37.6754013470241, 37.577529021671836, 35.87004395893642, 36.935418197086875, 36.399580069950645, 36.45756278719221, 34.9181615965707, 37.08184453419277, 35.60211099897112, 35.97821351460048, 35.59535040174212, 37.16739770344326, 46.049669061388286, 48.54779658998762, 48.25462777273995, 48.82943834577288, 48.98127038138253, 48.000625950949534, 48.39418581553868, 49.18127775192261, 46.617184025900706, 49.49643414361136, 39.47558580126081, 34.71992254257202, 35.91021496909005, 35.675998142787385, 37.26323768070766, 37.58383103779384, 38.0618497303554, 44.03944056374686, 46.82073845182146, 47.45291335242135, 46.65004900523594, 49.47045135498047, 50.6602782521929, 45.014919008527485, 47.20044708251953, 48.73036745616368, 48.70291859763009, 47.292128562927246, 47.706644194466726, 39.47983462469918, 26.183912924357823, 10.522428376334053, 2.89410753761019, 3.4034893129553114, 9.38981294631958, 14.629777806145803, 15.277761595589773, 9.296666264533997, 7.654576778411865, 1.2880860418081284, 0.30104365040149006, 4.299064993858337, 24.222492047718593, 41.91595295497349, 40.95104966844831, 54.91413218634469, 56.05380003792899, 39.527085849217, 6.742809840611049, 0.2471794235919203, 0.096994993143848, 0.05045872401180012, 0.15935757250658103, 0.13276077753731183, 0.1573882603219577, 0.12170258377279554, 0.10973917679595095, 0.17094734417540686, 0.1012412313637989, 0.11089656076260976, 0.08236733198698078, 0.09655509210590806, 0.1932783659015383, 0.12883389182388783, 0.20839383266866207, 0.09336108528077602, 0.16128226422837802, 0.17404644430748054, 0.09189129022083112, 0.09640843354697738], [0.03275944339111447, 0.06046208419970103, 0.04218338217054095, 0.01264651447334992, 0.014101623490984951, 0.016924622634957944, 0.008523157248938722, 0.013993895030580461, 0.04135837858276708, 0.05893911235034466, 0.05425185690234814, 0.042625491839966605, 0.04450777851577316, 0.03061424135895712, 0.024078899096431475, 0.05285172364009278, 0.03830182598903775, 0.05058929111276354, 0.03609172208234668, 0.017878527520224452, 0.028114706643724015, 0.04911256481760314, 0.06561874678092343, 0.05903473150517259, 0.048953926722918234, 0.09744839702865907, 4.2198264343397955, 26.349163668496267, 42.39291899544852, 39.1616974558149, 55.598321301596506, 60.7916168485369, 38.80877413068499, 23.1190208366939, 8.418752687317983, 1.339294699685914, 5.379904619285038, 1.9144721158913203, 4.431541953768049, 6.843201322214944, 11.524076342582703, 8.167669108935765, 11.18532473700387, 23.02658200263977, 38.9893022264753, 47.469943387167795, 51.14188568932669, 50.86974906921387, 48.00880398069109, 44.65459932599749, 42.48143557139805, 39.44134855270386, 36.249961035592214, 36.49099404471261, 35.154344763074604, 34.16635956083025, 36.88099990572248, 38.76573698861258, 39.70301423754011, 40.22990655899048, 36.79399108886719, 37.922809328351704, 41.778211866106304, 45.21629170009068, 46.48941012791225, 42.52832201548985, 44.34987218039376, 44.2668342590332, 43.26068646567208, 42.1914872441973, 42.10519756589617, 38.80718994140625, 35.430111816951204, 33.06941270828247, 32.143280369894846, 31.658077239990234, 32.37805652618408, 30.96156202043806, 34.247896671295166, 38.84890692574637, 40.65140513011387, 43.12789944240025, 42.88595969336373, 42.881967953273225, 41.590912750789094, 41.54343223571777, 43.13647699356079, 42.82001781463623, 45.9835604258946, 37.59110927581787, 36.2914765221732, 48.06962851115635, 42.1538210596357, 42.96687841415405, 38.98209694453648, 37.38182953425816, 33.774105957576204, 33.41090972082955, 33.027035645076204, 32.28760140282767, 34.100914478302, 34.51846994672503, 31.745197228022985, 32.52978433881487, 32.44407136099679, 32.346605505262104, 32.386978013174875, 38.26315641403198, 42.510600634983604, 45.5444655418396, 44.14046042306082, 45.14046948296683, 43.112470967429026, 46.29296023505074, 47.48579570225307, 43.90633739743914, 41.44479560852051, 32.70660209655762, 32.60376875741141, 32.52137007032122, 34.00279549189976, 33.17801652635847, 33.307180064065115, 34.193683351789204, 35.16182797295706, 39.74112858091082, 40.353876318250386, 42.69506141117641, 45.2068247795105, 47.84143229893276, 43.14647197723389, 45.98053795950753, 47.30968318666731, 48.90550027574812, 40.79917246954781, 33.45736190250942, 17.32102530343192, 4.140539237431117, 1.6228578495127814, 0.4313975013792515, 2.343297562428883, 3.9426241431917464, 4.153350412845612, 5.950323496546064, 1.8924786789076669, 0.2913459464907646, 0.3604715386671679, 3.0904781775815144, 18.82385638781956, 32.17133024760655, 37.505813189915244, 42.84109517506191, 41.757805006844656, 19.768762758799962, 2.7270693693842207, 0.02020028266789658, 0.06550807771938187, 0.04380660756890263, 0.005652880753457014, 0.03374048289177673, 0.04681977802621467, 0.04120450719658818, 0.1139606349170208, 0.03210560365446976, 0.03339342919311353, 0.054903542290308645, 0.033164840923356156, 0.054246659324105294, 0.025537985177444558, 0.013003863244583564, 0.018761131945731382, 0.04349027454320874, 0.018006131119493927, 0.013077047487188662, 0.03272706370002457, 0.04872248860608254, 0.0460906616146011, 0.09903707820922136, 0.04748941745076861, 0.016137869762522832, 0.0229393521190754, 0.05948173001940761, 0.02840206283144653, 0.042234241762863736, 0.04632035928911396, 0.08361283051116125, 0.04519255944926824, 0.013436074784424688, 0.10416245354073388, 0.008461569169802325, 0.011785125293369805, 0.05692329337554319, 0.04091263535831656, 0.04275399958714843, 0.05045171135238238, 0.03957564317222152, 0.068595405268882, 0.01795507814469082, 0.07041534475450005, 0.014145987806841731, 0.06386178891573634, 0.12724172297332967, 5.559389182499476, 29.627212592533656, 50.533504894801546, 44.4987199647086, 56.786154065813335, 62.59695339202881, 48.83932563236782, 28.386806283678325, 9.14297992842538, 2.5333881165300096, 6.0022139464105875, 3.5747383066586087, 6.110709198883601, 8.2031136069979, 13.884997793606349, 13.228458166122437, 14.303263715335301, 27.555683612823486, 41.24271420070103, 48.77701766150338, 51.10372618266514, 53.11706052507673, 49.08020578111921, 47.654171398707796, 43.813019616263254, 41.15285662242344, 38.80167654582432, 37.28597566059658, 36.66683210645403, 35.3724730355399, 36.485557079315186, 39.05239186968122, 40.16042457308088, 40.09367322921753, 38.873816217694966, 39.0151321547372, 44.31331423350743, 47.56599875858852, 47.17407519476754, 43.170446736471995, 46.346284185137065, 45.613509791237966, 44.94752148219517, 43.9866828918457, 43.38639327457973, 40.74960402079991, 36.593104771205354, 34.35763651984078, 33.54250512804304, 32.92088801520211, 33.031538077763145, 32.802608830588206, 36.43252842766898, 41.35312802450997, 42.782379422869, 45.042871611458914, 45.914738518851145, 44.854655333927695, 43.42698465074812, 42.7277318409511, 44.92222656522478, 44.88289628710066, 47.84824848175049, 40.63890879494803, 40.08243104389736, 48.36994702475411, 43.69157205309187, 43.721692493983674, 39.902149609157014, 38.67375326156616, 35.27909619467599, 35.594492299216135, 34.90464735031128, 34.557108879089355, 35.03305006027222, 35.56443786621094, 32.36982985905239, 33.40950965881348, 33.11213370731899, 34.10447890417916, 34.89578839710781, 40.959901673453196, 45.4809763772147, 45.81449685777937, 46.04148060934884, 47.42339045660836, 44.1968207359314, 47.53036492211478, 48.717718260628835, 46.594640595572336, 43.306971890585764, 34.12649427141462, 33.46914604731968, 33.801342896052766, 35.374057224818635, 35.00638287408011, 34.103266443525044, 35.47365617752075, 38.00610433306013, 42.25515011378697, 43.497477599552695, 45.42966740471976, 46.874413285936626, 49.98783506665911, 45.279770442417686, 48.27387775693621, 46.677570819854736, 48.78180497033255, 43.4212315423148, 36.81147623062134, 18.19695864404951, 6.572654971054622, 2.2567432011876787, 3.1372165381908417, 6.636197549956186, 7.017839516912188, 5.376665455954416, 5.245461319174085, 3.3375400517668043, 0.25195397596274105, 0.2557690255343914, 3.8782052227428983, 20.83541199139186, 36.18674285071236, 39.991350582667756, 46.967984676361084, 47.69979327065604, 24.37863370350429, 3.653651169368199, 0.02851317124441266, 0.02584875251964799, 0.06151781004986592, 0.02622438102428402, 0.023921187202047025, 0.07969395829630749, 0.03792971399213586, 0.030508335613246475, 0.038111971890819926, 0.020370276046118567, 0.06306112437908139, 0.022368646492915492, 0.07537620927074126, 0.0424069085690592, 0.020983552959348475, 0.014684172945895364, 0.03093740383961371, 0.011577221315487154, 0.023848723054730465, 0.01746123357276831, 0.05538145825266838, 0.18476117721625737, 0.13724696609590734, 0.14488024078309536, 0.07202157285064459, 0.1520382288311209, 0.11940452137163707, 0.08830028612698827, 0.0938469570662294, 0.10874559796814408, 0.20369267064545835, 0.2507806803498949, 0.12925769122583525, 0.17691157199442387, 0.10529142724616186, 0.0907800602061408, 0.16668199162398065, 0.1593947290842022, 0.11263259260782174, 0.17502380614834173, 0.1437456895198141, 0.12913609775049345, 0.2429811917245388, 0.2124118727764913, 0.11118508063788925, 0.17361758303429398, 0.19493533484637737, 6.136338932173593, 37.169051374707905, 56.92604909624372, 51.412882804870605, 61.7006288255964, 63.54561873844692, 46.980995178222656, 32.29233660016741, 11.359233805111476, 2.7948496980326514, 6.8943235618727545, 5.9019966040338785, 12.704985226903643, 13.709779858589172, 17.64858249255589, 12.75107957635607, 13.544792277472359, 28.557335921696254, 43.45247064317976, 48.199278422764365, 52.88947575432913, 54.31404406683785, 51.89907257897513, 49.14121443884713, 47.397171429225374, 43.60590771266392, 39.61917379924229, 39.32276364735195, 38.01672812870571, 38.09625026157924, 40.018146310533794, 42.415281772613525, 43.91508517946516, 42.98771258762905, 40.62834753308977, 41.7855178969247, 46.118091447012766, 49.58038575308663, 48.75968885421753, 43.32680899756295, 47.9744416645595, 48.09417997087751, 47.534068311963765, 46.62421212877546, 46.052514348711284, 42.5670234816415, 39.85348095212664, 36.99167081287929, 35.28333806991577, 34.76454734802246, 35.59094524383545, 33.704933166503906, 37.89147990090506, 43.89766604559762, 45.004962239946636, 47.34587287902832, 47.28675760541643, 47.029358114515034, 45.41928679602486, 45.21431146349226, 47.374423027038574, 46.72571836199079, 47.95150913511004, 44.44178989955357, 42.23582022530692, 51.57461254937308, 46.86741644995553, 45.19234125954764, 42.47862849916731, 40.501341411045615, 36.62365252631051, 36.369129589625764, 35.92309692927769, 35.7524665423802, 36.73600837162563, 36.60512515476772, 33.547810077667236, 34.88374716894967, 34.59901693889073, 35.225636754717144, 34.89014993395124, 41.76365539005825, 47.324003423963276, 48.51498024804251, 47.4658647945949, 50.151454721178325, 44.967257840292795, 47.48032052176339, 49.32988234928676, 47.222326959882466, 45.433207511901855, 36.777791363852366, 35.58208976473127, 34.57503523145403, 38.14963674545288, 37.04290335518973, 36.270996706826345, 36.923731327056885, 39.36480024882725, 44.020228794642854, 44.959941387176514, 47.12082420076643, 48.70251212801252, 50.87722880499703, 46.779038837977815, 48.45540986742292, 49.4429086957659, 49.88468558447701, 43.76018898827689, 38.42641476222447, 20.614721570696148, 5.9679732237543375, 3.2339465362685065, 3.1878515354224612, 9.886240022523062, 11.667576619556971, 13.331774405070714, 15.319449050085884, 5.711539098194667, 0.5202687882951328, 0.7471002766064235, 4.643328257969447, 24.487310477665492, 42.440535000392366, 48.018145833696636, 52.05333995819092, 54.39659561429705, 28.03026815823146, 4.490740605763026, 0.14726766624620982, 0.14665758184024266, 0.15551827209336416, 0.1039258890918323, 0.11462006238954407, 0.17439819686114788, 0.11277522066874163, 0.20234550721943378, 0.10924255023045198, 0.0829278901219368, 0.14720995005752358, 0.1761755786303963, 0.11544323393276759, 0.10503268148750067, 0.09741218361471381, 0.08198463145111289, 0.11197492254099675, 0.1141755540988275, 0.049657916982791254, 0.08672774050916944, 0.1490438130817243], [0.05605343183768647, 0.026432375756225417, 0.04338180732780269, 0.02881264267489314, 0.046393647856478176, 0.07697798617716346, 0.05070275573858193, 0.08108787957046713, 0.036027308753026385, 0.04744785718087639, 0.08232055378279515, 0.05298894716958914, 0.03798218171245285, 0.014939353003033569, 0.04104915660406862, 0.03007229883223772, 0.018488764596570815, 0.03780045646375843, 0.06260563060641289, 0.049804192169436386, 0.006363590630436582, 0.04296850825526884, 0.06212026772222348, 0.03183867137080856, 0.023365916551223824, 0.05463388568854757, 3.5652976589543477, 23.70456290245056, 43.625258445739746, 45.14865446090698, 46.08745336532593, 33.8725654057094, 29.238929884774343, 29.95987844467163, 12.343545147350856, 1.5378353489296777, 1.8614052491528648, 0.659431706581797, 2.6477680589471544, 3.0095870324543545, 1.4405502549239566, 1.2749004236289432, 5.9365903820310315, 19.959164244788035, 34.89579881940569, 47.36961487361363, 52.02177081789289, 49.271510532924104, 45.99875613621303, 43.38721316201346, 42.312052386147634, 40.54012972967965, 37.23867579868862, 35.822848320007324, 35.74644940240042, 37.92362921578543, 43.59803540366036, 44.274578026362825, 45.829741205487935, 43.163456848689485, 43.620651790073936, 43.45732395989554, 43.79132386616298, 44.96570839200701, 47.12683091844831, 44.336833885737825, 43.364527293613975, 45.50312376022339, 44.06790733337402, 44.33405460630144, 45.64634697777884, 45.595072746276855, 43.84713179724557, 37.019533089229036, 32.71274777821132, 31.524188927241735, 31.57428891318185, 31.229362964630127, 32.239141191755024, 34.66417714527675, 37.265016419546946, 39.02838931764875, 40.982882840292795, 40.24170807429722, 39.48119299752371, 37.39356504167829, 42.048948424203054, 43.18846688951765, 44.58227900096348, 34.78998817716326, 34.70485884802682, 47.5146689414978, 41.68009287970406, 45.226286683763774, 41.373079776763916, 42.98230341502598, 40.54382617133004, 36.14464371544974, 31.194229398454937, 32.82048307146345, 33.35805477414812, 32.1670640536717, 32.07149158205305, 33.47450310843331, 31.064940793173655, 33.349112442561555, 33.27802194867815, 33.03208351135254, 36.44183553968157, 41.573472772325786, 43.43827199935913, 44.84405933107649, 44.652848379952566, 41.913819858006065, 43.39497429983956, 45.699875899723594, 45.096278939928325, 35.93704196384975, 30.41850471496582, 33.32747575214931, 32.610643999917166, 34.37459707260132, 33.59619733265468, 33.149817262377056, 32.35586397988455, 35.96745075498308, 35.8544556753976, 41.84235416139875, 41.91745376586914, 46.502594334738596, 46.034337861197336, 42.79325335366385, 43.20129673821585, 44.48494863510132, 42.97326728275844, 24.69123489516122, 10.5796137877873, 2.4302238694259097, 1.1003283453839166, 3.8437868867601668, 5.013532621519906, 4.320838911192758, 3.7301443219184875, 2.9098499843052457, 2.394887285573142, 0.5606120377779007, 0.4717797530548913, 5.551892510482243, 23.60180425643921, 33.30971963065011, 36.55103342873709, 47.667918409620015, 40.327188287462505, 16.493427106312343, 1.466231882572174, 0.07033847352223736, 0.018691541394218802, 0.02112571452744305, 0.015566151422847594, 0.02926711525235857, 0.02007853821851313, 0.05018031430829849, 0.03045576611267669, 0.03873954553689275, 0.04161852551624179, 0.013256588701291807, 0.014811257465875574, 0.016267688778628196, 0.039338322156774144, 0.024322013104600564, 0.021843792870640755, 0.04545430772538696, 0.05539207054036004, 0.07436581634517227, 0.022953311280746545, 0.053218736446329525, 0.03716449273218002, 0.015960490530622855, 0.03032657304512603, 0.06673224988792624, 0.04386558583272355, 0.007785248719821019, 0.050769035039203506, 0.046970195669148646, 0.008612404111772776, 0.06280013945485864, 0.037056168009127886, 0.0822712853550911, 0.0060120094068614495, 0.027749900772635425, 0.09080009055989129, 0.020294726260804703, 0.03876599822459476, 0.028788184880145958, 0.06179707470749106, 0.04451904558975782, 0.04244272504001856, 0.043327324358480315, 0.041604696972561736, 0.03021707445649164, 0.039919704531452486, 0.08530963624694518, 4.5518673828669955, 29.950699874332972, 49.45464767728533, 47.77217960357666, 54.179537364414756, 43.215252195085796, 33.15503535951887, 33.08978482655117, 13.188053522791181, 1.7429337948560715, 2.753918077264513, 0.6407318785786629, 3.44017037323543, 4.871921386037554, 3.1119665673800876, 2.6868303971631184, 8.394496526036944, 23.130431515829905, 37.578824860709055, 48.77959891727993, 52.87216084344046, 51.91755478722708, 48.86022581372942, 46.68952866962978, 43.75342491694859, 41.53652572631836, 37.34330177307129, 37.01621185030256, 36.767431599753245, 39.71127217156546, 44.31121935163225, 46.626946244921, 47.03541694368635, 44.92071533203125, 44.52371263504028, 44.89122370311192, 46.36239358357021, 45.53244168417794, 47.70934009552002, 44.5846518107823, 44.0097439629691, 46.97956384931292, 45.442907197134836, 46.54439469746181, 47.024949482509065, 46.53105068206787, 45.12062195369175, 39.54411588396345, 34.12498303822109, 33.066765444619314, 34.01583726065499, 32.357375213078086, 33.39942782265799, 37.653153215135845, 39.51637520108904, 40.1463440486363, 43.02754313605172, 43.64763164520264, 41.50133310045515, 40.08703422546387, 44.13707317624773, 44.99945231846401, 46.49116802215576, 38.4454528263637, 37.837398597172324, 48.104713439941406, 44.14194733755929, 45.95380476542881, 42.66857835224697, 44.657913616725374, 42.75144256864275, 37.00203405107771, 31.73693929399763, 34.93728998729161, 34.126264980861116, 32.25458703722273, 34.24751452037266, 34.49541234970093, 32.935145718710764, 34.24865402494158, 34.71176535742623, 34.09864936556135, 38.35119356427874, 43.19374057224819, 45.66084092003958, 46.94018145969936, 46.08860329219273, 43.60940613065447, 45.14945002964565, 47.75074093682425, 45.867007868630544, 38.23027753829956, 32.22056865692139, 35.04838126046317, 33.2679157938276, 35.966627393450054, 34.63363981246948, 34.83898687362671, 34.55528497695923, 37.725115707942415, 39.368072850363596, 44.01234606334141, 44.68625184467861, 49.31247016361782, 46.79286575317383, 45.92077302932739, 47.79951729093279, 47.007690157209126, 44.614671502794536, 27.99862085069929, 12.408619369779315, 3.7361410515648976, 3.068539240530559, 5.275817998817988, 8.604301725115095, 7.736463904380798, 7.5465791906629285, 5.051405514989581, 2.0737895326954976, 0.36165658650653704, 0.4299930967390537, 5.512281264577593, 27.22142141205924, 37.86181109292166, 39.41942351205008, 51.46079063415527, 44.35796683175223, 20.502419573920115, 2.140640756913594, 0.06766974779644183, 0.0417952838885997, 0.02676378922270877, 0.03581612490649734, 0.028315256150173287, 0.08417515283716576, 0.036786477480615885, 0.02816716248967818, 0.018929062577496682, 0.02893499271678073, 0.02776081670474793, 0.02248801098072103, 0.05268212381218161, 0.012400954346438604, 0.03456069941499403, 0.01988265703299216, 0.01583898696117103, 0.02539858694321343, 0.03458286376137819, 0.06347718848181622, 0.05064892416287746, 0.11141554505697318, 0.11659155945692744, 0.0804942903508033, 0.13523999521774904, 0.12168013783437864, 0.170119721442461, 0.1617905276694468, 0.15641780596758637, 0.09165698529354163, 0.13159504080457346, 0.14192739208894117, 0.22237523671771797, 0.11491735572261469, 0.10376406527523484, 0.12766629590519837, 0.1949417944997549, 0.13333050268036978, 0.21365627885929175, 0.1769905670412949, 0.1356640931751047, 0.09581402329994099, 0.13991758493440493, 0.2125811536929437, 0.12230139092675277, 0.17053807899355888, 0.2355940081179142, 5.196808295590537, 34.4181865964617, 56.482892990112305, 55.2499976839338, 53.7749958719526, 42.49452945164272, 40.846854482378276, 40.29832199641636, 16.445863212857926, 2.8074680609362463, 2.4842048585414886, 0.9561091469866889, 6.99669441155025, 7.039867912020002, 4.9208084770611356, 1.946423624243055, 7.467253344399588, 24.059410878590175, 38.301034518650596, 50.539285796029226, 55.944077559879844, 52.43244062151228, 49.441960266658235, 48.297765663691926, 45.732171126774375, 43.57885142735073, 40.0920021874564, 39.432249886649, 38.02505554471697, 41.64338207244873, 47.414152826581685, 48.839141505105154, 49.92377267565046, 47.21433653150286, 45.58322606767927, 48.9563923563276, 47.80467632838658, 47.09308699199131, 48.73922988346645, 44.82174171720232, 42.81663751602173, 48.23164313180106, 46.456937721797395, 48.33873919078282, 49.53992986679077, 49.467970848083496, 46.990434306008474, 41.518644537244526, 35.25660834993635, 35.54076535361153, 35.67702300207955, 33.975377900259836, 35.04838126046317, 39.51972770690918, 41.35225255148751, 41.49284587587629, 44.41361495426723, 44.74142401559012, 41.95480033329555, 42.324684211185996, 46.496024812970845, 46.81503745487758, 49.17159196308681, 41.15111609867641, 40.62828847340175, 51.071048804691856, 46.18245955875942, 48.26477214268276, 44.20731251580374, 46.04347474234444, 45.27624075753348, 39.80053915296282, 33.57068007332938, 36.700801849365234, 36.22862311771938, 34.62629209245954, 34.99545335769653, 35.84576347896031, 34.298899923052105, 36.380389145442415, 36.99916097096035, 36.60840123040335, 38.7722613470895, 44.789852959769114, 47.342756611960276, 47.924306937626426, 46.94954068320138, 43.25716025488717, 45.044605187007356, 48.42610583986555, 49.099424498421804, 39.90785755429949, 33.46830531529018, 36.914007323128835, 35.77207783290318, 37.51102433885847, 37.21809523446219, 35.60099581309727, 35.58293744495937, 38.89996228899275, 40.66884510857718, 44.5508314541408, 46.37555347170149, 50.81639732633318, 48.741505418504985, 46.05679096494402, 48.838370255061555, 48.43473897661482, 46.25257730484009, 28.257416929517472, 12.751442619732448, 4.150924623012543, 3.4529808972563063, 6.94353244134358, 10.562778302601405, 13.414044550486974, 13.190468890326363, 9.011411445481436, 4.603643187454768, 1.3292446732521057, 0.800375155040196, 7.321964774812971, 29.856339863368444, 44.41845090048653, 46.537957191467285, 57.37846367699759, 50.06018318448748, 23.98267149925232, 2.3523868918418884, 0.25944969803094864, 0.23952261731028557, 0.07084142403411013, 0.10269428017948355, 0.14618386940232345, 0.1405321341007948, 0.08767791345183339, 0.19831988109009607, 0.1382807141968182, 0.11470923546169486, 0.08923223361905132, 0.22086514346301556, 0.1032828821667603, 0.14398262037762574, 0.13681460358202457, 0.10706132477415459, 0.09172222643558468, 0.14119221296693596, 0.14078074933162757, 0.13582999498716422, 0.17669320585472242], [0.028033708222210407, 0.04936266264745167, 0.12205107935837337, 0.01760693878999778, 0.011758078887526478, 0.041738605858492, 0.01878703841274338, 0.017070940230041742, 0.06733046671641724, 0.04789030272513628, 0.0428431760519743, 0.027933972056156824, 0.0015459977231720196, 0.03041518971856151, 0.09892780014446803, 0.05960145073809794, 0.02808929550727563, 0.06405540209795747, 0.06601337596241917, 0.01564923973221864, 0.02500111300365201, 0.04348529748884695, 0.025632235387872373, 0.038617745108370266, 0.02772658970206976, 0.05599028736885105, 1.3357987787042345, 11.648779136793953, 33.79480116707938, 46.48816292626517, 31.597582748958043, 25.61438298225403, 31.351192678724015, 29.01117835726057, 16.65734553337097, 1.7617625445127487, 0.6388535850814411, 2.0986853625093187, 3.5539966310773576, 2.1831459275313785, 2.9800061626093726, 1.2989676807607924, 3.2584304681846072, 11.632701005254473, 28.3798702444349, 44.1022800718035, 50.83268390383039, 50.55442244665963, 48.89357021876744, 46.70209101268223, 43.38957902363369, 39.51314428874424, 38.14228555134365, 37.65074913842337, 38.370579038347515, 42.35833086286272, 45.98331029074532, 46.981526715414866, 45.86069195611136, 47.02973679133824, 46.60172080993652, 46.74496834618704, 43.783350808279856, 45.998130798339844, 43.41455432346889, 43.17467124121529, 44.88007531847273, 43.28614466530936, 45.08085741315569, 43.91580431801932, 46.166513442993164, 44.839417934417725, 43.26821483884539, 41.455811977386475, 38.589214529309956, 33.743023191179546, 33.81340149470738, 31.825007711138042, 32.42636387688773, 31.636353697095597, 33.91510227748326, 33.78473670142037, 34.63848965508597, 35.035474981580464, 36.25541884558541, 35.37645435333252, 42.07108538491385, 42.45504978724888, 46.35910013743809, 33.561289582933696, 32.93258878162929, 46.018857274736675, 41.772201674325125, 45.4376335144043, 42.81717600141253, 44.20966100692749, 42.54048831122262, 41.5523294040135, 33.8105423109872, 33.19252436501639, 32.61444466454642, 34.10710532324654, 31.81673240661621, 32.04809699739729, 31.513579027993337, 32.24600601196289, 32.701498644692556, 33.37304898670742, 32.92968790871756, 35.817651067461284, 41.570033414023264, 44.50466067450387, 45.450647490365164, 43.99746649605887, 43.36507967540196, 44.595299925122944, 43.915741784232004, 36.53129012244088, 31.951895713806152, 31.37410088947841, 32.169252736227854, 37.305986472538535, 36.551377364567344, 36.81118440628052, 32.958342279706685, 34.64421149662563, 34.80231080736433, 38.05127804619925, 41.8656792640686, 42.61470896857125, 46.5343337059021, 44.57425035749163, 40.261090074266704, 38.314274311065674, 33.25606216703142, 21.160853454044886, 5.763513360704694, 2.764562500374658, 1.6949864476919174, 4.4699424760682245, 12.287986482892718, 8.948882869311742, 4.471399860722678, 1.9340163128716605, 1.0173774936369486, 0.1835675798356533, 1.1143386278833662, 6.4505564485277445, 19.402856724602835, 24.053930486951554, 32.972061497824534, 41.00266783578055, 34.967097759246826, 9.996697272573199, 0.5389826212610517, 0.04846041124047978, 0.0802890131516116, 0.07946259821099894, 0.04312453059745686, 0.07069189527205058, 0.03527471163709249, 0.060714770640645704, 0.07239495710070644, 0.025247275330392376, 0.057103424066943784, 0.08266701376331703, 0.029102207494101355, 0.03064477882747139, 0.056915938055941036, 0.022179637170795883, 0.043227053846099546, 0.01749637320504657, 0.030593033746949265, 0.10569869074970484, 0.04507179717932429, 0.04135261782045875, 0.06832209136337042, 0.047356248168008666, 0.07637526387614862, 0.02971369307488203, 0.05252714302124722, 0.04409198243437069, 0.03565844354618873, 0.014211461347128664, 0.02331883130994226, 0.054584206747157235, 0.02867419778236321, 0.061725319629268985, 0.032897097790347676, 0.0731508858235819, 0.013531425917920257, 0.03491137309798172, 0.0015883591944917238, 0.08164000351514135, 0.04757225300584521, 0.042186517002327104, 0.04100982532171266, 0.02590506922985826, 0.003760277800860682, 0.016179592880819525, 0.021664401782410483, 0.08608152411345925, 1.7501733835254396, 15.433755602155413, 41.05190624509539, 52.57460771288191, 36.709230014256065, 30.320066111428396, 37.05609451021467, 32.02697447368077, 17.84584879875183, 2.2291714463915144, 0.9434262961149216, 1.1950069963932037, 2.1853228850024085, 5.275386341980525, 4.436553342001779, 3.5358149324144637, 5.919780518327441, 14.272258247647967, 30.426060880933488, 45.84144197191511, 52.11763163975307, 51.503153800964355, 48.69697788783482, 48.14834465299334, 44.46669224330357, 41.027507645743235, 39.015003613063264, 39.24559000560215, 39.54966402053833, 44.68739134924752, 47.84929765973772, 48.98810740879604, 47.758693150111604, 48.50317178453718, 48.18504156385149, 48.949332986559185, 46.09550632749285, 46.827207224709646, 44.01773091724941, 45.36669588088989, 43.57863255909511, 42.93349231992449, 45.58613736288888, 45.97153656823294, 46.699384689331055, 46.22954750061035, 46.50709329332624, 43.7342791557312, 39.19151912416731, 35.54703957693917, 33.46140227999006, 33.31110232216971, 31.967327662876674, 33.82057898385184, 35.88492005211966, 35.060231413160054, 38.20674746377127, 37.67534923553467, 38.40815837042672, 37.06915364946638, 43.971883228846956, 44.71728597368513, 48.678735392434255, 37.38388272694179, 35.623973505837576, 48.32646172387259, 44.50598430633545, 46.71138422829764, 44.987880093710764, 45.96622814450945, 44.17962047031948, 43.674333572387695, 35.19529744556972, 34.95726605824062, 33.98104763031006, 35.18048388617379, 32.563375404902864, 33.95645448139736, 33.20409311567034, 33.145606654030935, 34.38293143681118, 35.1779408454895, 34.73673718316214, 37.1533762386867, 44.1729154586792, 46.02938379560198, 47.720578806740896, 44.236470631190706, 44.567979608263286, 46.307429858616416, 46.42806795665196, 37.50716461454119, 33.488844190325054, 33.59378283364432, 34.0746294430324, 38.545736176627024, 37.49799646650042, 38.07128190994263, 35.3654796736581, 36.44062655312674, 35.71236848831177, 40.7761287689209, 44.05190563201904, 45.42531088420323, 49.08372504370553, 44.779649530138286, 42.33019413266863, 41.97775370734078, 37.75153623308454, 21.917288201195852, 7.324875201497759, 3.345143986599786, 4.307353760514941, 8.368669203349523, 16.32957121304103, 11.97032266003745, 5.833102175167628, 4.0214623127664835, 0.09464412036218814, 0.15130709377782686, 0.9198546409606934, 8.766865253448486, 22.86098211152213, 30.85013028553554, 37.81602593830654, 47.430428981781006, 39.73560128893171, 12.502806544303894, 0.7301885240844318, 0.060961940591888766, 0.019731698258380805, 0.0277967536156731, 0.07478962253246989, 0.11671544638063226, 0.06896652321198157, 0.04320497770926782, 0.04641604969011886, 0.027633403095283678, 0.008033084483551127, 0.025026875281972543, 0.06761005028550114, 0.019685223698616028, 0.01075467572081834, 0.018681814594726478, 0.021083511345620667, 0.10254046986145632, 0.013616293685377708, 0.04239622503519058, 0.040321705995925834, 0.020628395856225064, 0.16005503865224974, 0.14938903812851223, 0.17161830674324716, 0.07540556948099818, 0.1397204976528883, 0.13753319930817398, 0.11487204315406935, 0.08011526068938629, 0.25676335075071877, 0.15844469863389218, 0.09809635725936719, 0.1053918165021709, 0.1161458705152784, 0.12648074594991549, 0.13047009759715625, 0.16410818616194384, 0.10853197478822299, 0.1347402406058141, 0.1257523793194975, 0.11701157263347081, 0.17840369764183248, 0.1782081981322595, 0.14778168366423675, 0.0949909399662699, 0.19371289972748074, 0.1484351128871952, 2.2575392041887556, 18.316283532551356, 46.7081880569458, 58.00404126303536, 42.69999115807669, 35.96027326583862, 42.336603845868794, 38.39988654000418, 22.914957455226354, 2.960543606962476, 1.1791697719267435, 3.6085821134703497, 7.071421418871198, 8.703057340213231, 6.224613623959677, 2.985836352620806, 4.560246476105281, 13.622234293392726, 31.195653779166086, 46.63549600328718, 53.153507300785606, 53.73758329663958, 51.54319279534476, 50.49664470127651, 47.3594149180821, 43.15013367789132, 40.33160386766706, 42.022013732365195, 40.77139009748186, 45.43273850849697, 48.406550134931294, 50.751650537763325, 48.61340148108346, 50.22584560939244, 50.524628571101594, 50.63121741158621, 47.511163575308665, 49.47391503197806, 44.44684818812779, 47.70295817511422, 45.76741239002773, 42.7543225969587, 45.312100410461426, 45.86363104411534, 48.37124286379133, 47.21207141876221, 47.96069465364729, 45.36004992893764, 41.50617946897234, 37.521394525255474, 35.51407037462507, 34.86457708903721, 33.43323080880301, 35.663856165749685, 36.74699347359793, 36.69222777230399, 38.77895941053118, 39.134825297764365, 41.30287865230015, 39.01451029096331, 45.85109649385725, 46.58897433962141, 50.79583413260323, 41.99415840421404, 38.64318813596453, 48.90180730819702, 46.1528776032584, 48.5542688369751, 46.40606301171439, 47.54255901064192, 46.819901193891255, 44.45676326751709, 38.13737664903913, 36.427015032087056, 35.555009160723, 36.10990619659424, 34.953340326036724, 35.47350331715175, 34.02473095485142, 34.783526352473665, 36.04950898034232, 36.95267057418823, 35.878037861415315, 38.19577278409685, 45.47367034639631, 48.0259382384164, 47.95125552586147, 44.90875400815691, 45.50981140136719, 47.528638294764924, 48.083462374550955, 38.734973839351106, 34.92637436730521, 34.278295040130615, 35.02890893391201, 41.180103983197895, 40.45117541721889, 39.49575294767107, 37.13283388955252, 37.91170263290405, 38.018294947487966, 42.6177453313555, 47.05002553122384, 47.025936126708984, 50.719768728528706, 47.677409648895264, 43.000948905944824, 45.90415293829781, 39.47612081255232, 25.5171377318246, 8.10264526094709, 4.361178415162223, 4.301203736237117, 10.412876997675214, 23.294379472732544, 19.000615085874283, 11.058348144803729, 6.4815297807965955, 4.624736615589686, 0.6873048394918442, 1.8505790872233254, 9.867006540298462, 27.03903988429478, 34.425659384046284, 43.370016370500835, 51.90789679118565, 44.03359712873186, 15.380610568182808, 0.9197720225368227, 0.1446886903473309, 0.32995420907224926, 0.09894356929830142, 0.1274568321449416, 0.1422725628529276, 0.15776638074644975, 0.13314243991460117, 0.13577056889023098, 0.1527120005339384, 0.12655911674456938, 0.19838320197803633, 0.1651401293597051, 0.11170783080160618, 0.14319503121078014, 0.12061424074428422, 0.10035936654146228, 0.2602563947439194, 0.11055520336542811, 0.2530809412045138, 0.12182244019848959, 0.24963002066527093], [0.007143637032381126, 0.056197508570871184, 0.026892956845196228, 0.03867007712168353, 0.055295406441603384, 0.06093258038163185, 0.02492375492251345, 0.015118642311011041, 0.02296886669604906, 0.023997237406937138, 0.07928873039782047, 0.026604031545243094, 0.05635774461552501, 0.023280455065625053, 0.03505353296973875, 0.03434516615899546, 0.010631032221551453, 0.07072570667202983, 0.02199922488736255, 0.029694514282579933, 0.05987350256847484, 0.04124408953690103, 0.06241335413817849, 0.10079972219786473, 0.1387074991528477, 0.08992327403809343, 0.45587424082415445, 7.907605852399554, 25.44165771348136, 44.560534613473074, 37.98712880270821, 29.180516379220144, 22.658865962709697, 28.29623304094587, 16.963927847998484, 4.102629431656428, 0.21217879599758557, 0.3616263781275068, 4.414877133710044, 4.413858788354056, 4.027342660086496, 5.2434528555188855, 2.957413660628455, 6.294124271188464, 18.732117584773473, 36.70572117396763, 50.32907499585833, 53.52702161243984, 48.22068929672241, 46.79242106846401, 43.89529323577881, 40.6022744178772, 38.92913777487618, 39.94815363202776, 44.37402064459664, 47.63010631288801, 47.4828496660505, 47.08857413700649, 45.91061128888811, 47.38163873127529, 48.03123276574271, 48.01330988747733, 47.926888193402974, 47.074180943625315, 45.222572871616904, 46.197686535971506, 46.43001692635672, 47.401222229003906, 46.94539955684117, 45.25527456828526, 45.575075830732075, 45.508043084825786, 45.774791376931326, 44.64626496178763, 41.936286858149934, 36.47528764179775, 33.57724959509713, 32.874494893210276, 32.72670323508126, 32.68871395928519, 32.09556014197213, 33.08066184180123, 34.21747745786394, 33.66640887941633, 33.91722495215279, 40.83832904270717, 45.04856218610491, 44.107755252293174, 46.3928336415972, 33.18260581152779, 34.64712974003383, 45.40082890646798, 41.84618261882237, 43.382783685411724, 43.16075052533831, 47.69024297169277, 45.4885881287711, 41.264587129865376, 35.07160561425345, 31.885488305773052, 31.243936811174663, 32.92079768862043, 32.4118595123291, 32.692330496651785, 31.911988735198975, 35.6651520047869, 37.420301709856304, 35.27261005129133, 35.37578385216849, 37.184844630105154, 42.90099559511457, 44.41500459398542, 46.197273118155344, 44.96416589191982, 44.269356455121724, 45.46178545270647, 43.22434738704136, 37.3532828603472, 32.889982427869526, 34.13156645638602, 35.16361713409424, 41.11395713261196, 41.151043142591206, 41.34451920645577, 39.53599343981062, 36.248786790030344, 36.33485065187727, 38.225399902888704, 40.50828613553728, 43.67050164086478, 43.81995391845703, 44.46429164069039, 44.77336835861206, 41.85433980396816, 25.75717714854649, 11.955020121165685, 2.7230033704212735, 1.37240731716156, 4.457904287746974, 7.949897800173078, 10.453542198453631, 6.481038195746286, 3.808387986251286, 2.2801644929817746, 0.5079973467758724, 0.0726727018398898, 1.2927808527435576, 11.415101664406912, 23.517029285430908, 28.438141311917985, 31.145449570247106, 41.2061562538147, 23.823021003178187, 4.451868040221078, 0.08826458839965717, 0.012700089902084852, 0.06742903071322612, 0.09277794550039939, 0.05982346061084952, 0.06230072411043303, 0.04876383853011897, 0.05627028823697141, 0.060080700021769316, 0.010345932162765945, 0.045592216575252156, 0.05351193821323769, 0.04265951358580163, 0.07308981767190353, 0.022798971705404774, 0.04553000169939228, 0.0377489149437419, 0.020453281234949827, 0.04572931118309498, 0.033877170378608365, 0.022639884081270014, 0.006000565489687557, 0.037596383664224825, 0.02582157719215112, 0.021570741897448897, 0.06680111440696887, 0.059833611494728496, 0.010134923039004207, 0.05424267632354583, 0.02766892101083483, 0.006040608809728707, 0.018738655473238656, 0.09467314130493573, 0.02353421359189919, 0.03037266932161791, 0.039153509573744874, 0.04716201073357037, 0.10556096171161958, 0.05718264303037098, 0.021950424648821354, 0.04778751145516123, 0.024413732379408817, 0.06541996316186019, 0.028208186716905663, 0.03455016515882952, 0.05771688757730382, 0.019687590089493563, 0.04031535151547619, 0.8531929180026054, 9.970461743218557, 31.126925672803605, 50.69497755595616, 41.24401698793684, 33.659870624542236, 25.883445024490356, 33.78095688138689, 20.273875951766968, 4.833030147211892, 0.2027431558817625, 0.8405084929295948, 2.3294283066477095, 5.965387625353677, 5.9490311316081455, 3.608747784580503, 5.050770623343332, 8.450809070042201, 21.63029112134661, 39.03386449813843, 51.46641867501395, 53.44630438940865, 51.63596166883196, 47.40233046667916, 46.229182720184326, 42.92207990373884, 40.459923199244905, 40.85373319898333, 44.76421063286917, 48.90585115977696, 49.36902502604893, 50.061631883893696, 47.474522250039236, 48.885645798274446, 49.41581072126116, 48.22749505724226, 49.10724122183663, 48.15675892148699, 46.778295380728586, 47.22235822677612, 47.19502053941999, 46.63320309775216, 47.11977154867989, 46.47571175439017, 46.31012575966971, 46.59470312935965, 48.305165495191304, 46.24558741705758, 44.138792855399, 37.966096605573384, 33.84014858518328, 34.2896796635219, 34.26267201559884, 33.95851809637887, 33.09405449458531, 34.34989970070975, 35.18032060350691, 36.42469085965838, 36.90664570672171, 41.66451154436384, 46.61398090635027, 45.582037925720215, 48.24601200648716, 37.12044177736555, 36.946781975882395, 46.161524636404856, 43.75965397698538, 44.429540225437705, 44.39286763327462, 48.51523733139038, 46.50649922234671, 43.19993141719273, 37.159042494637625, 33.98060989379883, 32.762389183044434, 33.921650954655235, 33.91753414699009, 33.61869559969221, 34.47369228090559, 35.584493841443745, 37.7053029196603, 36.01418086460659, 36.68890305927822, 38.70931414195469, 44.377772671835764, 46.64744690486363, 46.39158296585083, 44.47440126964024, 44.38038172040667, 47.916014262608115, 46.44208247320992, 37.80166053771973, 33.39264290673392, 35.43547235216413, 36.60122374125889, 43.36291183744158, 41.68053756441389, 42.59562921524048, 40.006956236703054, 37.62615251541138, 37.643352781023296, 39.27886840275356, 42.300646918160574, 45.737660203661235, 46.75017949513027, 45.536982331957134, 46.078636101314, 42.83620711735317, 29.211342062268937, 14.363175426210676, 4.206366905144282, 3.830586177962167, 8.136157291276113, 10.44446177142007, 9.953603676387242, 6.85201815196446, 3.0866905408246175, 1.6538369357585907, 0.5533460676670074, 0.17119377452347959, 1.8500844623361314, 12.221614684377398, 23.86805054119655, 31.115617479596818, 35.72182846069336, 46.04515273230416, 28.406728506088257, 6.654416595186506, 0.07936829541410718, 0.033532254065253904, 0.031224427545177083, 0.0323249197431973, 0.01735276126834963, 0.01765265847955431, 0.05040248702945454, 0.015497671972428049, 0.07731847504952125, 0.024324545736557672, 0.06153400668076106, 0.03126789110579661, 0.02977997237550361, 0.036717595998197794, 0.022984491661190987, 0.0034690007409413476, 0.04662505883191313, 0.03134503035939165, 0.04430038767999836, 0.03864632500335574, 0.040487848687916994, 0.06558887766940252, 0.10753911520753588, 0.13197439616279943, 0.11203172270740781, 0.16451925624694141, 0.2594961098262242, 0.1385661738791636, 0.1237321634377752, 0.12172049709728786, 0.1130995536223054, 0.13975723353879793, 0.2718224312577929, 0.09430748556873628, 0.18636161062334264, 0.0728970594438059, 0.10932428655879838, 0.22029336914420128, 0.08158133059207882, 0.19955967313476972, 0.09656301060957567, 0.157382302784494, 0.16282176519078867, 0.13350157492927142, 0.15227301551827363, 0.21176790233169282, 0.20068454848868506, 0.1458132535751377, 1.0041312958512987, 10.663071206637792, 34.39093228748867, 55.824978487832205, 49.059764180864605, 38.737023557935444, 32.90144348144531, 38.374713216509136, 24.263033049447195, 5.719917322908129, 0.47059660511357443, 0.8911548895495278, 9.552571024213519, 9.674581391470772, 9.822627527373177, 9.569312708718435, 5.58990523644856, 9.477041499955313, 20.1631737777165, 41.903592109680176, 53.297449656895225, 56.063624790736604, 53.06838491984776, 50.7060112953186, 47.49826424462454, 44.92535325459072, 42.9405516896929, 44.11616257258824, 47.900981834956575, 52.028062411717, 51.458938939230784, 50.19563831601824, 49.122544629233225, 51.3161986214774, 51.23216710771833, 49.16883700234549, 51.218861307416645, 49.26185253688267, 47.70617866516113, 48.70036513464791, 48.791112082345144, 49.50328506742205, 48.31286757332938, 47.91293273653303, 47.761145864214214, 47.81435169492449, 49.026013306209016, 47.0458288192749, 45.30726099014282, 39.26865802492414, 37.04398727416992, 35.7064277785165, 35.737354210444856, 37.112402711595806, 33.959522111075266, 35.13519900185721, 37.85930279323033, 36.91398300443377, 37.99643244062151, 45.03017030443464, 48.09433283124651, 48.85502508708409, 49.64404514857701, 40.6112619127546, 39.33299139567784, 46.45284523282732, 46.02956097466605, 45.68151528494698, 46.23016936438424, 50.68250553948538, 49.02421024867466, 44.79609939030239, 38.55066244942801, 36.34588091714041, 34.51222351619175, 34.930223669324604, 35.389638560158865, 35.5781501361302, 35.856995241982595, 39.20978593826294, 40.705458641052246, 37.649911880493164, 38.17142629623413, 40.71574197496687, 46.436152185712544, 47.75913436072213, 49.22179617200579, 45.238439083099365, 44.926961762564524, 48.15561594281878, 47.56527962003435, 39.725158146449495, 36.37935038975307, 37.040971755981445, 38.2218702180045, 45.07957894461495, 44.22406462260655, 44.19325631005423, 42.56775304249355, 39.27126012529646, 39.4207193510873, 41.319158281598774, 44.11340413774763, 46.80590057373047, 47.77147436141968, 47.88249615260533, 47.13565165655953, 45.63975313731602, 30.43946395601545, 13.92556311403002, 4.27008318901062, 3.688891564096723, 9.281104036739894, 16.126032420567103, 21.458238090787614, 16.574858256748744, 9.266187122889928, 6.928755794252668, 2.106023963008608, 0.2710868450147765, 2.064155203955514, 15.294609240123204, 32.021794591631206, 37.246568952287944, 42.88900300434658, 53.032056263514924, 31.536667891911097, 7.646296262741089, 0.26669213654739515, 0.11889099249882357, 0.12591035584253923, 0.19925225605922087, 0.16573090265904153, 0.15177076389747007, 0.15391445958188602, 0.18005287700465747, 0.15698318848652498, 0.13014520145952702, 0.1655375880322286, 0.07915700639465026, 0.1394034182386739, 0.23661425337195396, 0.11675150373152324, 0.12909740768373013, 0.06520479970744678, 0.0839914937636682, 0.15673416613468102, 0.09360195842704602, 0.08719040639698505, 0.15705083842788423], [0.009887139861738043, 0.07345754293990986, 0.04205443676827209, 0.024804563461137668, 0.03452219933803592, 0.00636626745108515, 0.008582418801129928, 0.019207596113639216, 0.03879917519433158, 0.017754440428689122, 0.0816908800708396, 0.07145882304757833, 0.014827788275267397, 0.07607534461255584, 0.01654402555764786, 0.06576308475009032, 0.022260131780058146, 0.05904129972415311, 0.034189418623489995, 0.01161248647674386, 0.05483471169801695, 0.09485405909695796, 0.03913595248013735, 0.03724953691874232, 0.0292266372458211, 0.013297818185362433, 0.07413580654455082, 1.7850617000034876, 14.174735069274902, 37.114546230861116, 38.54258516856602, 34.469064780644004, 27.58655445916312, 24.952664341245377, 19.649901662554058, 5.904387218611581, 0.5263411338840212, 0.016961360217205117, 1.50653176009655, 5.897752123219626, 4.437627272946494, 2.0682611550603593, 3.1141046583652496, 4.250704663140433, 14.108979054859706, 31.285240377698624, 47.79815196990967, 53.46757629939488, 53.406835147312705, 47.56022480555943, 45.8861015183585, 43.238823958805625, 43.729634284973145, 45.201728275844026, 45.44237913404192, 45.993517194475444, 48.85351037979126, 45.800364221845356, 43.351982321058, 44.530702522822786, 47.02235433033535, 46.368372508457725, 47.828282833099365, 45.741596358163015, 44.733110495976035, 44.81459896905081, 46.29144205365862, 45.581798212868826, 45.84963389805385, 45.528081689562114, 47.119604791913716, 44.87541307721819, 46.06292275020054, 44.85441214697701, 43.07410648890904, 38.788749422345845, 35.66218164988926, 32.98301880700247, 32.34038686752319, 31.322517463139125, 34.84797784260341, 33.99983903339931, 33.63610431126186, 33.23406764439174, 37.41614668709891, 40.65342705590384, 45.18765122549874, 43.04363863808768, 44.70743342808315, 31.96553155354091, 34.71367958613804, 45.63348586218697, 39.60950190680367, 45.971043246132986, 42.261723109654014, 45.61566720690046, 40.60648502622332, 41.986977440970286, 33.48976830073765, 32.892904145377024, 33.04318673270089, 32.7262932913644, 31.81657954624721, 36.21510887145996, 40.340952668871196, 44.19397892270769, 42.0060259274074, 44.447952951703755, 43.32710429600307, 43.96207237243652, 42.881022998264854, 45.50647626604353, 46.00662497111729, 44.893655572618755, 44.17247077396938, 44.44703926358904, 43.0699896812439, 37.624220916203086, 31.330139636993408, 33.66761439187186, 37.58043336868286, 44.621289661952424, 46.566889490400044, 46.32946607044765, 42.986406326293945, 43.243677275521414, 39.770581994737896, 38.66654450552804, 40.51041923250471, 41.613595145089285, 43.95764636993408, 45.45324959073748, 42.342871120997835, 38.9316599709647, 30.139395577566965, 11.782353043556213, 3.1142920425959995, 4.800853908061981, 7.831919125148228, 9.922837053026472, 6.875282023634229, 2.482015524591718, 1.2279531827994754, 0.5446806869336537, 0.3523871467581817, 0.4533199635999543, 2.8130780799048285, 14.731513329914637, 19.869145120893204, 30.415662901742117, 39.83296986988613, 35.75631931849888, 12.834834030696324, 1.7183266409805842, 0.020042518187048178, 0.037011269346943924, 0.026315413282385895, 0.007076006598903665, 0.04150142055004835, 0.029397526290267706, 0.10759261090840612, 0.032925195925469906, 0.0496055306866765, 0.03660758850829942, 0.060817270140562735, 0.08759565465152264, 0.025694185635074973, 0.06328468809702567, 0.03056849113532475, 0.020243878542844738, 0.04141920246183872, 0.037652335661862574, 0.04033745140103357, 0.05739422381988593, 0.06387756485491991, 0.024848025325419645, 0.013423651656402009, 0.014835089312068053, 0.018147166319457547, 0.02174563260216798, 0.07125457043626479, 0.08373449184000492, 0.020714281426210488, 0.036484763491898775, 0.035647108618702204, 0.0061898979641098, 0.03780953526230795, 0.06952960549720696, 0.02932993063170995, 0.04808090999722481, 0.018019199703953097, 0.058675440427448065, 0.03067924840641873, 0.017869106061490517, 0.03337944458637919, 0.0982993206541453, 0.007937573046157402, 0.06351218053272792, 0.0064219128357113475, 0.014474746505064624, 0.02480898581312171, 0.030602970892297368, 0.13712875172495842, 2.991352136645998, 18.45564181464059, 43.58139794213431, 46.84896550859724, 37.15118408203125, 29.540832587650844, 28.142728226525442, 22.211071934018815, 6.263770631381443, 0.576995672924178, 0.12359956412443093, 1.24534495813506, 6.4341630424771985, 6.245672311101641, 5.408502536160605, 4.305604117257254, 4.114046190466199, 15.586056641169957, 32.894422326769146, 48.36746651785714, 52.613528047289165, 53.54736246381487, 49.18379299981253, 47.91576065335955, 43.31949601854597, 44.06412751334054, 47.391324520111084, 48.416875158037456, 47.74317782265799, 49.94194916316441, 48.84760093688965, 46.53106805256435, 46.108235427311485, 48.402151925223215, 47.51617670059204, 48.47570555550711, 47.52778714043753, 46.228522641318186, 47.208614689963206, 48.099259104047505, 47.12838384083339, 47.225293840680806, 47.05569873537336, 46.75562340872628, 48.088034289223806, 47.27518885476248, 46.77983093261719, 45.88311031886509, 41.352797985076904, 36.044575759342735, 33.717630999428884, 34.438437121255056, 32.65306970051357, 37.3483670098441, 36.78407253537859, 35.62429659707205, 34.17290128980364, 37.80101088115147, 42.030771936689106, 46.96347529547555, 44.66195052010672, 45.28227874210903, 35.19928223746163, 37.02719347817557, 45.24431031090872, 42.05972160611834, 47.096769537244526, 43.93369592939104, 47.08591645104544, 43.40568494796753, 43.28043324606759, 35.168501717703684, 34.321057728358674, 33.5815018926348, 34.33791753223964, 32.59676149913243, 37.817325251443044, 41.04195989881243, 44.31376934051514, 45.03010777064732, 45.20384052821568, 45.09335722242083, 44.57351732254028, 44.140873840876985, 46.944815908159526, 49.059746810368125, 45.42827429090227, 45.83320140838623, 45.2919054712568, 45.19896289280483, 37.90864542552403, 33.14065606253487, 34.699842248644146, 39.5251646723066, 46.56051451819283, 47.445416246141704, 47.3513445854187, 44.8267548424857, 44.73479890823364, 41.051715169634136, 39.43674189703805, 42.85327884129116, 44.305997780391145, 47.36281953539167, 46.59616919926235, 44.74175752912249, 41.63572515760149, 31.232347215924943, 12.112805894442968, 3.0873104504176547, 3.1865949971335272, 7.462153366633824, 8.764680913516454, 3.814659604004451, 1.4228167150701796, 0.42085160155381474, 1.4956208084310805, 0.23762388633830206, 0.26404112737093655, 3.566960015467235, 16.944705656596593, 23.648558684757777, 36.629593236105784, 42.88064432144165, 42.25937114443098, 17.255231073924474, 2.7951775661536624, 0.07314402583454337, 0.016395419603213668, 0.05329287318246705, 0.10061853977718524, 0.04576998935746295, 0.03070189111999103, 0.06500574467437607, 0.06404154641287667, 0.03865982785022684, 0.0658978893022452, 0.029360712372830937, 0.0720566056136574, 0.01011583924160472, 0.08645166496613196, 0.007193307492083737, 0.04829800727644137, 0.03877856130046504, 0.07017390842416457, 0.08367273158260755, 0.06588657133813415, 0.03803911419319255, 0.07452045447592225, 0.09267464532916035, 0.19036420727414743, 0.13774281234613486, 0.12510445980089052, 0.1830035408160516, 0.13587992159383638, 0.12597773436989101, 0.1588270938290017, 0.1287555753120354, 0.1799033007451466, 0.13197749028248446, 0.16422811044113977, 0.13571074924298696, 0.12055558817727224, 0.1665875395493848, 0.12620197662285396, 0.13847155895616325, 0.11675619919385229, 0.16165264935365745, 0.1978242519710745, 0.13653864338994026, 0.17797905685646193, 0.06451532670429774, 0.10865099661584411, 0.09199254800166402, 0.077988107688725, 0.2174513523599931, 3.2525386129106795, 20.312309912272863, 49.664299147469656, 52.582709312438965, 45.28535679408482, 37.964880670819966, 35.06562668936593, 27.783994470323833, 8.78369813305991, 0.8549615059580121, 0.5790975572807449, 2.9100312888622284, 12.782641768455505, 11.962340048381261, 7.89571487903595, 5.927557289600372, 5.1556719200951715, 18.049853120531353, 32.3595986366272, 49.29869883401053, 55.22239249093192, 57.161756311144146, 51.070423466818674, 50.17497089930943, 46.12120076588222, 47.174165521349224, 49.95001254762922, 50.419172286987305, 49.96568768365042, 50.37429734638759, 49.8481102670942, 47.714662415640696, 48.361317362104145, 51.51702240535191, 49.303069250924246, 50.26505776814052, 49.78158821378435, 47.919300760541645, 49.55019235610962, 50.53627027784075, 48.92890528270176, 48.78856904166085, 48.518860816955566, 50.266714913504465, 49.274050099509104, 49.4175512450082, 48.02150181361607, 47.529538086482454, 43.1594477381025, 38.21919863564627, 35.847966057913645, 35.85226699284145, 34.08113990511213, 38.639300618852886, 38.383613858904155, 36.925044536590576, 36.36276503971645, 40.00251286370413, 43.87207235608782, 48.3365991456168, 45.83375031607491, 47.304586683000835, 37.80548899514334, 38.942648547036306, 45.14473567690168, 43.492471422467915, 48.590764250074116, 44.77398674828665, 48.17291348321097, 44.15612861088344, 44.37156445639474, 36.856132302965435, 36.42750835418701, 36.38553428649902, 35.34957524708339, 35.58769001279558, 39.219336237226216, 43.38612576893398, 46.743220874241416, 46.28960425513131, 48.63562876837594, 47.45337193352835, 46.1885427066258, 46.54475252968924, 50.032963616507395, 49.726356983184814, 44.63664518083845, 48.209989070892334, 47.378574575696675, 46.1137627192906, 39.91599389484951, 34.864698682512554, 35.881237506866455, 42.17428003038679, 47.450134072984966, 49.4760342325483, 48.33787761415754, 47.49751731327602, 47.27661670957293, 43.93744100843157, 41.6915990965707, 44.92497110366821, 44.56632246289934, 50.23734835215977, 47.01698684692383, 45.79552132742745, 41.787018707820344, 36.11203581946236, 16.29882022312709, 5.47806008372988, 7.450714026178632, 14.55340494428362, 15.969420024326869, 17.152576650891984, 12.838808400290352, 5.6271388956478665, 6.278752250330789, 0.5170964470931462, 1.2386498259646552, 3.9650924461228505, 21.17470642498561, 29.103801318577357, 42.315602915627615, 49.53515992845808, 47.15521083559309, 18.707206555775233, 3.1885183453559875, 0.14047101166631493, 0.09630693149353776, 0.09998992457985878, 0.17310100075389656, 0.1598034921501364, 0.15117366665175982, 0.16473473182746343, 0.15404013783804008, 0.10926414800009557, 0.20123827377600328, 0.12207383742289883, 0.2720528617501259, 0.10201267818255083, 0.20595110660152777, 0.08998646600438015, 0.1185369464967932, 0.13790283804493292, 0.19960981687264784, 0.11475814426583902, 0.1485768181404897, 0.11330524472785847, 0.20133083952324732], [0.10341770707496575, 0.01410164384703551, 0.03869426689509835, 0.04532910105107086, 0.002996615687152371, 0.09756306944681065, 0.050326114520430565, 0.08439160550811461, 0.029584713745862246, 0.0466185448957341, 0.023415352916345, 0.025172775578019873, 0.036504457970815044, 0.06979829857924155, 0.06187870247023446, 0.06937226001173258, 0.04795563546940684, 0.07324377048228468, 0.03748633206955024, 0.00765937114400523, 0.05195852049759456, 0.09586152753659657, 0.007365814842549818, 0.10349461901932955, 0.024628929760573164, 0.023631383199244738, 0.034686547304902754, 0.03034495795145631, 6.129075459071568, 24.777227537972585, 41.72147287641253, 40.40629352842058, 29.028349093028478, 30.497985158647808, 20.949424982070923, 11.204115271568298, 0.4583240236554827, 0.5549058839678764, 0.22881951449172838, 5.1118318268230984, 12.114230275154114, 14.921433653150286, 12.789238214492798, 5.406516219888415, 12.485948477472578, 26.44622826576233, 44.21188790457589, 46.44150924682617, 52.246948037828716, 46.98881537573678, 47.019317967551096, 45.70673377173287, 45.56099878038679, 45.51927137374878, 47.9118766103472, 49.219093322753906, 46.86763184411185, 46.335427624838694, 43.638532979147776, 40.81944036483765, 42.826778411865234, 44.46501425334385, 44.22642353602818, 43.95427301951817, 41.70979642868042, 40.946283204214915, 42.5632506098066, 42.53589902605329, 43.261951037815635, 42.36283676964896, 45.25701856613159, 43.38834919248308, 44.562292507716585, 45.238432134900776, 45.316481249673025, 41.62737342289516, 38.00913722174508, 34.277040890284944, 34.30368375778198, 33.396808351789204, 35.03328282492501, 33.26741899762835, 34.60316848754883, 35.1588784626552, 38.98712049211775, 42.66078247342791, 45.618269307272776, 43.82369899749756, 43.72889082772391, 33.12290688923427, 34.6252498626709, 43.962193965911865, 45.381710938044954, 46.35959693363735, 42.77796384266445, 44.259608132498606, 39.72664853504726, 36.679672377450125, 31.98934997831072, 33.95446034840175, 34.87054211752755, 31.927830627986364, 33.65899167742048, 42.78507879802159, 45.58125277927944, 46.20152888979231, 46.248672417231965, 45.6360045841762, 44.615425382341655, 43.22218997137887, 44.416943141392295, 45.14222737721035, 45.26109715870449, 43.61538852964129, 45.70303038188389, 43.07107360022408, 42.59651858466012, 36.24048369271414, 32.61827312197004, 32.345420837402344, 40.52607004983084, 47.0449846131461, 46.315458502088276, 46.30172538757324, 45.13366024834769, 43.68273394448416, 44.03658832822527, 42.2743375641959, 41.61431428364345, 43.03383125577654, 45.17345258167812, 44.5291565486363, 40.739629881722585, 30.06520618711199, 15.553863900048391, 3.435247357402529, 1.6932137885263987, 1.9188490467412131, 7.803116236414228, 7.344339711325509, 3.399120633091245, 0.49578083945172174, 0.352777358676706, 0.44013988226652145, 0.20012443140149117, 0.5179097663078989, 7.182490110397339, 15.948785611561366, 22.61793065071106, 26.75823712348938, 34.93454197474888, 25.523458855492727, 9.37914833000728, 0.4548204759401934, 0.024883122549259236, 0.037316372618079185, 0.015758994467822567, 0.03645959323538201, 0.01600870892538556, 0.024968248160023774, 0.04438423425225275, 0.038833892438560724, 0.019313394990084425, 0.03480540967679449, 0.09007968314524208, 0.06893186364322901, 0.04162890710202711, 0.03914662244330559, 0.023351646959781647, 0.02465192531235516, 0.03553856337176902, 0.03730339224317244, 0.01745424296573869, 0.03889406831668956, 0.031963755908821306, 0.04801203190748181, 0.0800488388964108, 0.031245994780744826, 0.01840802571470184, 0.038152935049895725, 0.07160712366125413, 0.008617361658252776, 0.027044071682861874, 0.03952772502920457, 0.016690836786957722, 0.013904274125317377, 0.032050469291529486, 0.03260779420712164, 0.07985843518482787, 0.035254104528576136, 0.039584046828427484, 0.05180752949256982, 0.04898203503606575, 0.06690400067184653, 0.02803708054125309, 0.027882120106369257, 0.07358852733990975, 0.0821327149335827, 0.03244517989722746, 0.07000770127134663, 0.028040181446288313, 0.025517585022108893, 0.10396156646311283, 0.4628929527742522, 8.99903496674129, 30.53012752532959, 45.44369234357561, 45.163148403167725, 33.20629569462368, 34.0097610609872, 24.729159900120326, 11.924514055252075, 1.2523629644087382, 0.08078831314508404, 0.21807601169816085, 3.6004870278494696, 11.755730152130127, 10.9993223292487, 8.314415063176837, 5.913614426340375, 15.283047437667847, 31.74061836515154, 45.62975467954363, 49.05313907350813, 52.380575793130056, 49.81341096333095, 49.41930913925171, 48.845203808375764, 45.877906118120464, 47.07904815673828, 50.40241323198591, 51.33532701219831, 48.83879062107631, 48.83363505772182, 45.32996422903878, 43.734067235674175, 44.80294336591448, 47.172675132751465, 47.5523281778608, 45.984189237867085, 43.96077653339931, 41.83691719600132, 44.380260126931326, 45.45983648300171, 45.03259175164359, 44.55484403882708, 47.43486540658133, 44.82031733649117, 47.26999160221645, 46.69287075315203, 47.037848813193186, 42.950459820883616, 38.86316115515572, 34.82911000932966, 35.01826081957136, 34.12476764406477, 36.273543221609934, 35.311134338378906, 36.457993575504844, 36.41822208677019, 41.127829211098806, 44.42115374973842, 47.217147077832905, 45.61399269104004, 44.064401967184885, 36.175108092171804, 35.18852990014212, 44.919217995234895, 46.490511417388916, 47.09203781400408, 43.91073560714722, 46.001226220812114, 41.2558810370309, 38.86857032775879, 33.94678953715733, 35.136678968157085, 35.54849869864327, 32.66558688027518, 35.805922508239746, 43.69655391148159, 47.62498549052647, 48.111529622759136, 47.588149615696494, 46.68048211506435, 47.5161315373012, 45.84258495058332, 46.45289734431675, 47.05725860595703, 44.90354633331299, 43.089298725128174, 47.36308009283883, 45.38522325243269, 46.23990726470947, 38.078938824789866, 33.62734610693795, 33.34994970049177, 42.622053214481895, 49.20981052943638, 47.965006010872976, 47.246138436453684, 47.23850931440081, 46.04852260862078, 46.086035932813374, 43.834552083696636, 43.69457367488316, 44.693401541028706, 46.70456804547991, 45.032171385628835, 42.85325104849679, 33.03079114641462, 20.07748338154384, 5.930621010916574, 3.4697136793817793, 3.5058241188526154, 7.5848811353955945, 3.8952083332198004, 0.35822705339108196, 0.4707611905676978, 0.40207746039543835, 0.30380270949431826, 0.12033468431660108, 0.7815325089863369, 6.631499264921461, 17.1224753175463, 27.418274300439016, 31.421379906790598, 42.78767395019531, 31.53334665298462, 11.132197942052569, 0.8100962819797652, 0.06700889540037938, 0.04501898340614779, 0.03869114224133747, 0.069619843869337, 0.03183741947369916, 0.028330494350354587, 0.0682520122666444, 0.06190018488892487, 0.0028289727966434187, 0.0027865370045349535, 0.08562848663755826, 0.031795964376734834, 0.05963666670556579, 0.03138048042144094, 0.024539463222026825, 0.03334275959059596, 0.08646165978695665, 0.027076341112011244, 0.020108878911871995, 0.016736140873815333, 0.029286626526819806, 0.0651220048644713, 0.18023077531584672, 0.07356655637600593, 0.1456618317003761, 0.11049119037176881, 0.18111376650631428, 0.1245368652577911, 0.1342436886791672, 0.1759474551571267, 0.07411323168448039, 0.12333680822380952, 0.10017625708132982, 0.11139221702303205, 0.1332517247647047, 0.15932458213397435, 0.11722422550831522, 0.13829405419528484, 0.1553599698735135, 0.14887797912316664, 0.11982986783342701, 0.11243776484791722, 0.1952675184501069, 0.16361536617789949, 0.16244310193828174, 0.12772022586848053, 0.08279149101248809, 0.10236264618911914, 0.21282728548560823, 0.5696332422750336, 10.20576422555106, 35.46983119419643, 54.71694925853184, 51.24230105536324, 39.18244825090681, 40.37463753564017, 28.841588463102067, 14.21894906248365, 1.4323846016611372, 0.9445332310029438, 0.47135667290006367, 11.713492052895681, 22.0281206539699, 18.892421211515153, 19.119545664106095, 11.114902138710022, 17.64072929109846, 33.806203160967144, 50.47363574164254, 50.16573674338204, 54.717348779950825, 50.47469186782837, 51.427630356379915, 51.619157450539724, 48.42899629047939, 49.68658896854946, 51.73818356650216, 52.60403333391462, 49.60756015777588, 51.119189398629324, 47.21842207227434, 45.28849737984793, 46.285622937338694, 47.80087913785662, 48.99000774111067, 47.79317705971854, 46.25889669145857, 44.801953247615266, 46.347920485905235, 47.1759546824864, 46.67279393332345, 45.603365421295166, 50.03699357169015, 47.16234316144671, 49.727162974221365, 48.43959576742989, 49.1536864553179, 44.44959272657122, 41.45730584008353, 36.656604358128135, 37.858760833740234, 35.83623055049351, 38.015814440590994, 35.94093295506069, 37.418040071214946, 38.816163539886475, 42.28609044211251, 46.22158833912441, 48.71084649222237, 47.47222587040493, 45.94017934799194, 38.03558553968157, 38.46388987132481, 45.4463917187282, 47.469856534685405, 50.17833730152675, 46.13643816539219, 47.70960760116577, 42.57859918049404, 40.85456698281424, 35.138256209237234, 36.18274416242327, 37.83792666026524, 33.79875816617693, 37.81422288077218, 46.83955069950649, 49.81403282710484, 49.70339666094099, 51.084702014923096, 49.6301383290972, 49.26427398409162, 46.407973766326904, 46.81552035467965, 46.91383041654314, 45.79567071369716, 43.893385955265586, 48.89184706551688, 47.26270294189453, 47.60573203223092, 38.79425239562988, 35.61968299320766, 35.38102279390608, 43.347584111349924, 51.12108973094395, 49.12807192121233, 49.117062500544954, 49.1025060244969, 47.049476623535156, 48.373091084616526, 45.733004910605295, 45.66536767142159, 46.31539249420166, 48.19984817504883, 45.35386603219168, 43.819981711251394, 32.6279867036002, 19.790580102375575, 4.630247405597141, 3.085184953042439, 5.210563557488578, 17.59946915081569, 16.902425868170603, 10.38370064326695, 3.1787122658320834, 1.576422278370176, 1.8792886095387595, 0.6851724482008389, 0.9048096739820072, 9.106905749865941, 22.66567346027919, 34.221990312848774, 38.428933484213694, 46.59343160901751, 36.20910562787737, 11.802787695612226, 0.9582896871226174, 0.20624917346451963, 0.13506307399698667, 0.14800448742296013, 0.10536103136837482, 0.11191193413521562, 0.09699880651065282, 0.11893934490425245, 0.1497462053916284, 0.1135573001312358, 0.14158963092735835, 0.1807231338960784, 0.15276901104620524, 0.1740122325718403, 0.11322855670005083, 0.19539183963622364, 0.15142857868756565, 0.19686500701521123, 0.12034645011382443, 0.08478810066091162, 0.16308495535382203, 0.13157251344195434, 0.21635881598506654], [0.014170655099275922, 0.02499550660806043, 0.038025672414473126, 0.018272339067022716, 0.04077788848163826, 0.023389731434040835, 0.05242677751396384, 0.06220296757029636, 0.027758485936958874, 0.015106070753453034, 0.03757780198273914, 0.03050447814166546, 0.0800372970157436, 0.02983646041580609, 0.02232981563013579, 0.03935271727719477, 0.02703852465908442, 0.02774682191998831, 0.0714694828327213, 0.018675534753128886, 0.05666786226044808, 0.021247296128422022, 0.04102549608796835, 0.05616924758734448, 0.025627192176346267, 0.03316379937210253, 0.026747456884809902, 0.10936693248472043, 1.4228174750294005, 15.362079722540718, 40.06686360495431, 39.26565987723214, 33.29014655521938, 20.575717857905797, 27.407297883714946, 12.474700212478638, 2.9392680057457516, 0.08952244304652725, 0.36593236135584967, 1.7113236167601176, 15.047399282455444, 34.367450850350515, 46.20022957665579, 33.56640345709664, 10.155951721327645, 12.53574274267469, 27.868460246494838, 41.267157963344026, 49.126136847904746, 52.396824155535015, 49.685049942561555, 47.35259526116507, 47.224453108651296, 48.19642618724278, 46.948397704533164, 45.3337961605617, 47.125621931893484, 44.82314872741699, 42.588844299316406, 36.803558758326936, 33.59654474258423, 36.34190307344709, 34.99116631916591, 34.22579445157732, 33.412862164633616, 33.21346276147025, 35.02482686723982, 37.385821274348665, 39.129579407828196, 40.4428653717041, 41.429023197719026, 41.56871325629098, 42.78910527910505, 42.389170442308696, 44.47608273369925, 43.211350781576975, 38.86998776027134, 34.552067961011616, 33.79836559295654, 32.82840401785714, 32.08608627319336, 34.09785032272339, 34.95244400841849, 34.836815561567036, 43.22820711135864, 42.44355746677944, 46.443697929382324, 42.437352725437705, 42.28592368534633, 37.93467685154506, 32.8436553137643, 46.95352547509329, 44.272271224430625, 45.409719126565115, 42.38733264378139, 38.91566521780831, 33.41773632594517, 33.3689842905317, 32.170420033591135, 32.57408257893154, 33.02998168127877, 32.57714326041085, 39.27064520972115, 44.81171894073486, 47.75369739532471, 48.80158996582031, 43.4967827796936, 46.1810108593532, 44.87864746366228, 47.714377539498464, 45.41161945887974, 47.018317426954, 47.043438638959614, 44.66560179846627, 45.17657232284546, 42.705653939928325, 40.67823559897286, 35.083615575517925, 31.7272013936724, 32.780593463352744, 38.31059871401106, 45.44104160581316, 44.423985140664236, 44.98837341581072, 46.12960461207798, 46.99062885556902, 43.501646518707275, 45.23365177427019, 44.83639546803066, 44.91671664374215, 47.16913849966866, 43.71656819752285, 31.699099404471262, 18.656925916671753, 6.388172916003636, 3.3309034364564076, 10.44860029220581, 14.824568816593715, 8.79209589958191, 5.302000548158373, 2.0753806701728275, 0.1966427732259035, 0.08747661925320115, 0.3058619275689125, 0.19710522198251315, 2.178238328014101, 9.603409256253924, 21.492619514465332, 30.464015415736608, 36.73017883300781, 36.00123984473092, 18.553745167596, 3.100532655205045, 0.10067922116390296, 0.03017445227929524, 0.043967067530112605, 0.013136584694231195, 0.015169008269107767, 0.0350128446173455, 0.03776130499318242, 0.03512132879612701, 0.008669385786301323, 0.031283415987023284, 0.056196741826300106, 0.03563728343163218, 0.0537264027765819, 0.051939436700195074, 0.046008406206965446, 0.0358209662538554, 0.08343159380768027, 0.06284074977572475, 0.07625430822372437, 0.015555813941838486, 0.05137205250295145, 0.04175178640122924, 0.06882830562868289, 0.02824510071825768, 0.01996091247669288, 0.03692652710846492, 0.04179834408153381, 0.06775976903736591, 0.015714557209451283, 0.026428767646263753, 0.0502068111007767, 0.09754217735358647, 0.024100216970379864, 0.014137640129774809, 0.018463923429538096, 0.08656569277601582, 0.019209083801667606, 0.026399142807349563, 0.03433282021433115, 0.06118597249899592, 0.05924156933490719, 0.018381978451673473, 0.03000590078798788, 0.05091415671631694, 0.011489394287179624, 0.03546781591804964, 0.014808556896501353, 0.04794700111129454, 0.022525184521717683, 0.005091785303583103, 0.007383237077322389, 2.2364160290786197, 19.613560846873693, 46.21639108657837, 43.32612460000174, 37.24986934661865, 26.283049821853638, 27.058222123554774, 14.489942703928266, 2.4979605547019412, 0.12563693337142467, 0.3735228883368628, 1.5286464648587363, 14.067672882761274, 32.964481013161794, 44.02539478029524, 27.77790437425886, 13.002986516271319, 19.130324057170323, 33.06314890725272, 45.74858624594552, 50.431324686322895, 54.45918846130371, 51.41292101996285, 48.41503388541085, 48.43600354875837, 50.70645250592913, 48.34674004146031, 48.11027547291347, 48.038837569100515, 47.3239026750837, 44.602984632764546, 40.048436982291086, 37.14579575402396, 39.35867541176932, 37.305857930864605, 36.451493535723, 35.81021996906826, 36.115485600062776, 38.404229164123535, 39.48180096490042, 41.21783964974539, 43.06574433190482, 44.45974404471261, 43.35841635295323, 45.0108299936567, 46.34529406683785, 46.05836125782558, 45.85329907281058, 41.10667542048863, 36.248161452157156, 36.017283235277446, 34.69544056483677, 33.853232043130056, 35.06978171212332, 35.76621355329241, 37.830116885049, 44.453945772988455, 45.60081890651158, 47.503378118787495, 44.533120495932444, 43.77826125281197, 38.228095803942, 35.07995387486049, 48.44606106621878, 46.91957310267857, 47.04369919640677, 45.14511087962559, 40.73558950424194, 35.90262753622872, 34.803540638514924, 34.38381733213152, 34.6001946585519, 33.76179722377232, 33.6798015322004, 40.28692695072719, 47.323204381125315, 48.715359347207205, 48.92194318771362, 45.482643944876536, 47.61124542781285, 44.93890224184309, 47.76315041950771, 47.253969056265696, 47.445228644779746, 47.4856914792742, 46.681812695094514, 46.871797289167134, 45.28061464854649, 41.185718127659385, 37.171434606824604, 34.13416508265904, 34.652858529772075, 40.43482283183506, 46.81685788290841, 47.174502508980886, 46.71765150342669, 47.53195605959211, 48.49505628858294, 45.2158157484872, 45.9870206287929, 45.530954769679475, 46.13437802450997, 48.639467648097444, 45.73352949959891, 33.321312699999126, 21.38804391452244, 7.713511398860386, 3.113273697240012, 5.559516421386173, 9.683015636035375, 7.866326604570661, 0.17599048784800939, 0.8756779943193708, 0.4052085466682911, 0.08332964392112834, 0.10149819936071124, 0.40428709611296654, 2.2807715918336595, 10.652765291077749, 23.88170722552708, 33.76057781491961, 39.227479525974815, 39.39486163003104, 22.06210776737758, 5.050974292414529, 0.06824908099536385, 0.037707900894539695, 0.054579524855528555, 0.03656072887991156, 0.020883704835016812, 0.00899314707411187, 0.006671601000042366, 0.03263707299317632, 0.01202365240481283, 0.010822878668217786, 0.054711550806782076, 0.04668542130717209, 0.020121830449040447, 0.04002596990072301, 0.020938727239679013, 0.013346586193490242, 0.02256413412812565, 0.04488269625497716, 0.03723468717985919, 0.030221729206719568, 0.058241612277925014, 0.01153859740588814, 0.045873089360871484, 0.10776532521205288, 0.06682704123003141, 0.1681593387786831, 0.12846361526421138, 0.1920763953988041, 0.05670136492699385, 0.1581871131701129, 0.12982388798679623, 0.16296835589621747, 0.11581270982112203, 0.14632421758558067, 0.11313183153314249, 0.15067849893655094, 0.1252779612051589, 0.18558737502566405, 0.09529452331896339, 0.18666216092450277, 0.09717658268553869, 0.10235848676945482, 0.1301508333001818, 0.08600183017551899, 0.22214562046740735, 0.18451986302222523, 0.09348797132926327, 0.09688370661543948, 0.18216446441199097, 0.07651219224291188, 0.1254770162382296, 2.3402800900595526, 22.213225875582012, 52.62811231613159, 50.367290088108604, 45.12354367119925, 30.011218684060232, 36.91781146185738, 17.899447202682495, 4.25394252368382, 0.2896816357970238, 0.8614198022655079, 4.6306273852075845, 24.99965500831604, 38.78533785683768, 48.93580136980329, 34.68557412283761, 14.90965645653861, 19.567244155066355, 33.131665093558176, 48.88334941864014, 51.84789909635271, 57.42516599382673, 53.48367180143084, 51.822305406842915, 49.00724622181484, 52.68152659279959, 48.28723566872733, 50.758456298283164, 50.393731457846506, 49.165745053972515, 46.89381265640259, 41.58227266584124, 36.76421110970633, 40.799766540527344, 37.464012827192036, 37.50806440625872, 37.02788482393537, 37.410216399601524, 39.96222373417446, 41.835124560764854, 42.51164633887154, 44.327874183654785, 45.91080583844866, 44.45736081259591, 46.798017842429026, 47.28897755486624, 47.504354340689524, 48.78090865271432, 42.531782218388145, 38.88843870162964, 36.893572671072825, 36.010859625680105, 35.36461114883423, 38.03527634484427, 37.40469952992031, 38.80396250316075, 47.329787799290244, 47.57734169278826, 49.14064816066197, 46.29529135567801, 43.82884413855416, 40.40752335957119, 39.563164370400564, 48.40618535450527, 48.34852572849819, 49.89450338908604, 47.43188462938581, 40.772147451128276, 37.65566151482718, 36.47476305280413, 36.37180117198399, 34.95956938607352, 35.22292348316738, 34.79658201762608, 42.68864822387695, 48.0977200780596, 49.631705147879465, 48.99994713919503, 44.48830114092146, 48.56883920942034, 46.246101583753315, 48.539250305720735, 47.51414435250418, 49.67320326396397, 49.17665719985962, 48.59629849025181, 47.117683615003315, 46.0826278414045, 43.681302615574424, 39.149454729897634, 35.090803486960276, 36.99371705736433, 42.28822701317923, 50.01131650379726, 49.33017069952828, 47.41440643583025, 47.44035448346819, 50.09887770244053, 47.6490158353533, 48.17324352264404, 48.984021868024556, 47.380930015019004, 50.87994902474539, 46.61009338923863, 33.67094257899693, 21.859593834195817, 8.605443835258484, 5.627322588648115, 13.234407561165945, 21.872543539319718, 14.989133426121303, 12.77705020563943, 3.6311242410114835, 0.6269453497869628, 0.30125345342925614, 0.8384523689746857, 1.1599865555763245, 3.0266865491867065, 12.222287791115896, 31.817983082362584, 40.311763286590576, 47.4963778087071, 47.09044320242745, 25.574927636555262, 5.109597546713693, 0.15345891831176622, 0.13592942750879697, 0.1500348134764603, 0.08692923148295709, 0.06901963214789118, 0.13514349396739686, 0.1315095318215234, 0.10170321871659585, 0.09563343120472771, 0.14551549883825438, 0.16465660530541623, 0.10626341508967535, 0.1453838494739362, 0.15211628749966621, 0.06122302051101412, 0.08289827885372297, 0.09753130043723754, 0.11233396256076437, 0.09449350594409875, 0.0914912870419877, 0.16517647169530392, 0.10581427919013159, 0.15851203644914286], [0.029409410831119333, 0.07297119617994342, 0.015363761390160238, 0.036083443955119164, 0.02997769069458757, 0.036364751003150425, 0.0644815628017698, 0.036839155546788654, 0.06821824836411647, 0.03717267925718001, 0.024488405158211077, 0.05410465890807765, 0.047579221560486724, 0.00991192674596927, 0.037367479875683784, 0.0628249602658408, 0.07393055648675986, 0.03257252734952739, 0.04120858858472534, 0.021147498894216757, 0.015350453622106994, 0.06576136805649314, 0.04588576778769493, 0.04200634220615029, 0.05976811929472855, 0.010960677256142455, 0.0374097933194467, 0.02888752919222627, 0.16613020694681577, 6.930221429892948, 29.451030594961985, 46.41766650336129, 31.65344626562936, 35.830095291137695, 34.31730570111956, 14.864642551967076, 5.069563329219818, 0.20479971409908362, 0.4863237983414105, 0.7991831590022359, 5.165503621101379, 11.36495738370078, 29.237814698900493, 19.98741909435817, 6.02081253698894, 5.277857729366847, 14.853283984320504, 35.217295442308696, 44.9685571534293, 50.342019489833284, 50.94841309956142, 50.72010224206107, 48.16545806612287, 48.939626353127615, 47.10524633952549, 48.40543842315674, 46.97603069032942, 44.38272673743111, 40.01959848403931, 34.40353284563337, 33.60061291285923, 31.43027707508632, 33.592622484479634, 34.57047373907906, 35.45047351292202, 33.09524263654436, 34.24449552808489, 33.8436713218689, 35.10170521054949, 34.81509549277169, 39.03540005002703, 39.908601011548726, 42.68406936100551, 43.769371032714844, 43.19970212663923, 41.51887730189732, 41.66840600967407, 35.08736412865775, 33.96196092878069, 33.05228539875576, 33.070583479745046, 31.628839220319474, 36.413886410849436, 40.59346757616316, 43.535133361816406, 42.96517610549927, 46.43697207314627, 44.79991742542812, 42.9679970741272, 34.84887416022164, 34.03760249274117, 50.549781050000874, 43.30370276314871, 44.216703006199424, 40.601867948259624, 36.19831507546561, 32.42924043110439, 33.61954327992031, 31.08493423461914, 31.317598138536724, 32.182252815791536, 33.86059365953718, 42.59966959272112, 47.479434626443044, 46.010196345193044, 43.39927870886666, 44.768560205187114, 45.1358072417123, 44.55579594203404, 44.26297106061663, 45.72903054101126, 44.415185247148784, 44.74998072215489, 44.11971657616751, 42.823801108769004, 43.27186264310564, 37.48754637581961, 34.22769478389195, 31.139675617218018, 33.01163496289934, 35.412386962345664, 42.747218063899446, 42.44463096346174, 45.97763361249651, 46.639727456229075, 47.47245863505772, 45.169665813446045, 46.87610517229353, 44.75233963557652, 47.55284234455654, 44.021851199013845, 36.560486452920095, 25.180516617638723, 11.603461248534066, 8.990993295397077, 13.145539232662745, 24.98251553944179, 24.008075850350515, 10.84338390827179, 7.084104921136584, 4.435235355581556, 1.0471378224236625, 0.1293802617916039, 0.030137187136071067, 2.8851895247186934, 4.217362429414477, 11.769818493298121, 17.05287347521101, 30.771007674080984, 35.36712987082345, 28.1121335710798, 10.14665937423706, 0.7325664907693863, 0.035829885596675534, 0.06368295422622136, 0.03814455514241542, 0.021223360805639198, 0.04447064229420253, 0.029949663805642297, 0.04431195670206632, 0.05069941734629018, 0.009735102216447038, 0.044893020165285895, 0.06215506299797978, 0.03065649712724345, 0.024201379756310155, 0.020590184156649878, 0.03085019512634192, 0.034507257996925285, 0.06467312002288443, 0.05959578497069223, 0.060621288871126514, 0.03228276914783886, 0.053220252972096205, 0.058518617413938046, 0.030616365173565488, 0.08009909798524209, 0.04599183298913496, 0.04258701211905905, 0.05073845685858812, 0.03897064099354403, 0.055477131690297804, 0.07034122837441308, 0.03568725414308054, 0.04461219148444278, 0.05100008639107857, 0.02329902656908546, 0.006487376622057387, 0.06396124179341964, 0.03364952187985182, 0.0036439841080989155, 0.059305344841309955, 0.06915574627263205, 0.045773921467896016, 0.05554191482120326, 0.030062521142618995, 0.05435603577643633, 0.03927992404039417, 0.032587913131075244, 0.011636251317603248, 0.01813517660567803, 0.05505450615393264, 0.04970063076221517, 0.0313904922056411, 0.24447917991450854, 9.684539897101265, 35.78246886389596, 51.40508345195225, 35.36329793930054, 32.212977749960764, 36.45700693130493, 16.252303770610265, 6.462722309998103, 0.30585226523024694, 0.07721084582486323, 1.0813707283564975, 5.837673221315656, 16.506055457251414, 41.43352910450527, 25.728913613728114, 7.8140474898474555, 7.947744727134705, 17.415519067219325, 37.11482763290405, 47.76682254246303, 52.4759259223938, 52.84008795874459, 52.66788380486624, 48.08897924423218, 48.252803870609824, 46.74313054765974, 50.43450001307896, 47.37927286965506, 46.25176436560494, 41.70713526862008, 37.22482803889683, 35.492659500667024, 33.09700747898647, 35.72969729559762, 34.04676021848406, 36.24472556795393, 34.60228606632778, 35.04433740888323, 35.531506878989084, 36.80894708633423, 37.47739505767822, 41.49626438958304, 42.13967800140381, 44.75899600982666, 43.95979683739798, 45.40998663221087, 43.651557377406526, 43.5328300339835, 36.4011538369315, 34.59540387562343, 34.38105194909232, 34.72843755994524, 33.60799537386213, 38.12922641209194, 42.70756816864014, 44.17342962537493, 46.912538051605225, 46.869636399405344, 46.23892756870815, 43.29185261045183, 36.34972674506051, 36.17223848615374, 50.64500263759068, 45.62300797871181, 46.08621311187744, 42.377730233328684, 37.28052479880196, 34.80280760356358, 34.92419958114624, 32.433711596897666, 33.010881083352224, 34.379679679870605, 35.7120349747794, 43.86558621270316, 48.57072564533779, 47.63741929190499, 44.23365661076137, 44.032030309949604, 45.952383858816965, 46.112824712480815, 45.597858973911826, 48.0655186516898, 46.55489342553275, 46.96621288572039, 46.767737592969624, 44.750185694013325, 44.42348139626639, 39.072131701878135, 36.9286402293614, 33.39399433135986, 34.003750869206016, 38.327197960444856, 44.528645856039866, 44.43710681370327, 47.91568769727434, 46.607647623334614, 48.625435761043, 46.658101967402864, 49.19932222366333, 46.74587161200387, 49.55125543049404, 46.32671110970633, 39.42551360811506, 26.72644564083644, 13.840479816709246, 8.670947977474757, 14.021771345819745, 26.828247172491892, 26.585960013525828, 11.459368637629918, 7.314202768462045, 5.156317234039307, 1.4615727897201265, 0.11728312234793391, 0.06360743327864579, 3.40340376326016, 5.8461669598306925, 14.301685605730329, 23.06199175970895, 36.32930598940168, 39.46063675199236, 33.94682775224958, 13.244179333959307, 1.3062353879213333, 0.013384226227312215, 0.07778507644044501, 0.09274571508701358, 0.07261835797024624, 0.02570791748751487, 0.08317710246358599, 0.06374656688421965, 0.027925176545977592, 0.07073708570429257, 0.01381257690289723, 0.05816262401640415, 0.0887161602399179, 0.052193822871361456, 0.026860845175438693, 0.026684236080784882, 0.018662501791758195, 0.052135848839368136, 0.07125540503433772, 0.05476737727544137, 0.030698159177388464, 0.03667760653687375, 0.018172723340934942, 0.08870611792164189, 0.1256189386227301, 0.1485879732561963, 0.18274894090635435, 0.10471381074083702, 0.12432607156889779, 0.16504900210670062, 0.21709263803703444, 0.08392063435167074, 0.11124819796532393, 0.12554638965853623, 0.15831543771283968, 0.19967245922556945, 0.12299425660499505, 0.12469590029546193, 0.08346222287842206, 0.1235279922506639, 0.11234644760510751, 0.12231695652008057, 0.14704509318939277, 0.1720220757914441, 0.15112800124500478, 0.19321229016142233, 0.10052484087646008, 0.18307180143892765, 0.1085279578609126, 0.10344591377569096, 0.14148263952561788, 0.15326283526207718, 0.3626240145947252, 10.10035571030208, 39.729935032980784, 59.75839192526681, 42.95412152154105, 46.21194076538086, 46.0404383795602, 20.73366951942444, 6.997892107282366, 0.6958019435405731, 0.9093239946024758, 2.0191421679088046, 8.503224543162755, 14.521348561559405, 35.56888471330915, 22.46870071547372, 8.381103873252869, 6.884286454745701, 15.482115064348493, 37.60278919764927, 47.305625438690186, 53.742888246263774, 53.2658040864127, 52.86977066312517, 49.51266166142055, 48.736763272966655, 47.23986768722534, 51.65060499736241, 49.45587056023734, 47.55251925332205, 43.82333769117083, 38.87928097588675, 37.60205616269793, 34.897483757564, 36.79248332977295, 38.22605650765555, 38.954231194087434, 37.89324474334717, 36.954678603581016, 36.829833371298655, 39.40697234017508, 39.29954276766096, 43.19063820157732, 43.82357740402222, 46.95241723741804, 46.1265995161874, 46.210057803562705, 46.37783595493862, 46.67524317332676, 39.291159766060964, 37.2823417527335, 36.47628123419625, 36.429766518729075, 34.63737446921212, 38.576607022966655, 46.37380599975586, 46.816298552921836, 46.91815219606672, 50.046804428100586, 48.471644333430696, 42.89226518358503, 37.0509980065482, 39.538758822849815, 51.231680733816965, 48.27329758235386, 48.70777538844517, 45.04539033344814, 39.21944740840367, 35.85566813605172, 37.44006586074829, 34.04507180622646, 33.84630816323416, 35.27743557521275, 37.40452929905483, 45.6599063873291, 50.803623063223704, 46.86580794198172, 44.551977906908306, 44.56596115657261, 47.28626775741577, 48.06130804334368, 45.834372179848806, 49.81911890847342, 48.886913844517295, 49.667721135275706, 46.671901089804514, 46.56654902866909, 45.031278542109895, 40.515286445617676, 38.363325119018555, 34.36971596309117, 35.80350800922939, 39.84563643591744, 45.81397226878575, 44.874627930777415, 49.62965195519583, 47.21315533774239, 48.639537130083355, 47.178164209638325, 48.96270826884678, 48.08935792105538, 49.782602650778635, 46.41809729167393, 39.79131541933332, 28.357893092291697, 14.753365414483206, 11.978782091821943, 17.163858788354055, 27.80890202522278, 32.32542392185756, 16.14150779587882, 10.734975508281163, 6.308791049889155, 1.700073397585324, 0.21862010178821428, 0.1962240764072963, 8.829242706298828, 7.55839547089168, 16.212688616343907, 26.857737064361572, 43.07089294706072, 44.96798392704555, 38.720344407217844, 13.974787626947675, 1.3929026573896408, 0.150993854871818, 0.15003475919365883, 0.1890759135463408, 0.13092926224427565, 0.1577879853014435, 0.2172834827963795, 0.13614877073892526, 0.09163463435002736, 0.09767310068543468, 0.13920433606420243, 0.19413515206958565, 0.1962361271892275, 0.2068770762000765, 0.11366475293678896, 0.10237807607544319, 0.06418357736298017, 0.1667797685201679, 0.1047359649091959, 0.10956215379493577, 0.12458467483520508, 0.12615693546831608, 0.14120273025972502, 0.2179278875035899], [0.010618565836921334, 0.04750502375619752, 0.02900615068418639, 0.03094399580731988, 0.09570969175547361, 0.034352921814258607, 0.0345699546326484, 0.013965165857890887, 0.024600721363510405, 0.05073722531752927, 0.027700325307835425, 0.07620456482150725, 0.023045899080378667, 0.056457618184919865, 0.028179623785295656, 0.012535054070342864, 0.06177052363221135, 0.013486795277068657, 0.08323244377970695, 0.04176503819014345, 0.03627979502614055, 0.030414887770478214, 0.08263134996273688, 0.07315265001463038, 0.03250772725524647, 0.019670910002397637, 0.05590026952060206, 0.08359957872224705, 0.015378546668216586, 1.6538690711770738, 13.785111359187535, 36.63191393443516, 48.04182529449463, 36.36701038905552, 20.053482566561016, 14.719911575317383, 8.757415703364781, 1.3364336703504835, 0.43220601656607216, 1.1966766268014908, 1.4745648354291916, 0.42328344391924994, 2.059098652430943, 0.3683906937284129, 4.31852559532438, 4.544522268431527, 5.417035358292716, 22.82873031071254, 42.32530607495989, 49.60963419505528, 49.201170444488525, 48.87509148461478, 47.56493221010481, 49.87168550491333, 51.40383972440447, 44.386631625039236, 45.76794045312064, 42.23772750582014, 36.12140893936157, 35.516210419791086, 35.11769648960659, 39.27080501828875, 42.12312739236014, 45.02915586744036, 44.68787424904959, 41.096847193581716, 36.31548949650356, 33.98876360484532, 35.77134132385254, 34.11014516013009, 35.74756111417498, 37.90885387148176, 43.12614849635533, 42.79678651264736, 43.36830363954817, 43.21378265108381, 41.131001063755576, 36.57986845288958, 34.404495171138215, 32.35858767373221, 32.61714056559971, 37.66198784964425, 41.13817507880074, 41.37618909563337, 44.647762298583984, 45.18325301579067, 45.2138216154916, 44.5021002633231, 48.10467869894845, 40.491044180733816, 30.95232786451067, 47.98738268443516, 41.87003231048584, 45.48618057795933, 39.05920805249895, 37.557396616254536, 33.5464517048427, 33.26340293884277, 31.67186941419329, 32.968469279153005, 31.42593445096697, 36.65146269117083, 44.718130179813926, 47.44014603751046, 41.28205837522234, 44.13175433022635, 46.86173282350813, 46.33018520900181, 44.16629729952131, 44.081911427634104, 43.1576828956604, 43.85142230987549, 43.11275931767055, 42.64043467385428, 39.30634157998221, 38.148181097848074, 34.62684447424752, 32.11850656781878, 32.84376995904105, 34.16906935828072, 33.25598921094622, 39.844250270298545, 43.00640671593802, 45.7805757522583, 45.5637572152274, 44.77495949608939, 46.7051169531686, 45.587370668138774, 48.44655091421944, 46.386493410382954, 45.16737290791103, 31.439942019326345, 17.35909274646214, 6.197104837213244, 5.608137309551239, 1.8619925890650069, 2.533366620540619, 2.9711172452994754, 1.2635046179805483, 1.5783433467149734, 0.6804265028664044, 0.18964705004223756, 0.050537620671093464, 0.0814847479175244, 2.091971231358392, 8.798490847860064, 17.169195004871913, 20.446014097758702, 30.251362323760986, 32.17120170593262, 17.354015350341797, 3.49334146295275, 0.09762134881956236, 0.0735865935151066, 0.029892127428736006, 0.031870986601071696, 0.01210566099533545, 0.030706678184547594, 0.09447078859167439, 0.03513114719784685, 0.023635413697255508, 0.055338608766240735, 0.03185870172455907, 0.0726528682612947, 0.023113699995779564, 0.04360342365024345, 0.023288641590625048, 0.01507293788849243, 0.04874767582597477, 0.04065936876993094, 0.021250069640310745, 0.03214132173785141, 0.040081860830209086, 0.030331790979419435, 0.03139145911804267, 0.04044989822432399, 0.050444498525134156, 0.024948784383013844, 0.036264969035983086, 0.0344637231901288, 0.06578010240835802, 0.04322861786931753, 0.05370160571432539, 0.04463355515950492, 0.023586391238495708, 0.008020854738008763, 0.02995946185131158, 0.05198472212733967, 0.011574821846027459, 0.05496824399701186, 0.026695686359224573, 0.03154729147042547, 0.040534355478095155, 0.028319551276841333, 0.06858330020414931, 0.03863840310701302, 0.05238660824085985, 0.061196584786687575, 0.07546656299382448, 0.02348955750598439, 0.07550506307078259, 0.04417814281103866, 0.04379363737202116, 0.0321531248545008, 0.04161697845639927, 2.6282223420483724, 18.955898216792516, 43.9643166405814, 48.34017399379185, 42.605151721409385, 27.43798633984157, 18.64653488567897, 10.569975767816816, 1.4154683436666216, 0.31489111163786476, 0.7938393971749714, 2.2486641832760403, 1.8387013588632857, 4.1377781970160346, 2.3279800415039062, 4.0808746218681335, 5.300327335085187, 8.85796308517456, 26.31665825843811, 43.492804936000276, 51.2546306337629, 50.120712416512625, 48.97753572463989, 48.14687510899135, 51.717557838984895, 51.301319054194856, 47.06867102214268, 47.67651680537632, 44.49762562343052, 38.77624961308071, 36.40372119631086, 37.131301811763215, 40.330662386757986, 42.37276921953474, 46.22901943751744, 44.8986165864127, 42.537201813289094, 37.84331498827253, 36.044183186122346, 36.083430085863384, 36.17216553006853, 37.13563748768398, 39.26879698889596, 43.45379427501133, 44.129332883017405, 45.18315921510969, 45.20277050563267, 42.29021767207554, 37.35308831078665, 36.12782907485962, 33.367730140686035, 35.627909660339355, 39.08966548102242, 41.336077145167756, 43.40288829803467, 46.59263604027884, 46.84897593089512, 47.550497327532085, 46.072949000767295, 47.12033435276577, 41.18730231693813, 35.437890325273784, 49.75155462537493, 43.97633007594517, 46.46194737298148, 41.02821288790022, 38.825269154139924, 35.002332074301584, 34.72138166427612, 32.92121458053589, 33.76026167188372, 32.045300347464426, 38.45001779283796, 45.8242312840053, 49.35523285184588, 42.811600072043284, 42.86505603790283, 47.55298825672695, 48.185705116816926, 46.07875769478934, 46.26176629747663, 45.40572043827602, 45.02319778714861, 45.074326106480186, 43.98225688934326, 41.028459548950195, 38.55316380092076, 35.70372840336391, 33.345228399549214, 35.34156397410801, 35.649424757276265, 35.17022834505354, 41.29534680502755, 45.134976931980674, 47.65672138759068, 46.80411488669259, 45.515349115644185, 46.49293981279646, 46.643079962049214, 47.924185344151084, 48.62878826686314, 46.4563193321228, 32.51691974912371, 17.990626675742014, 8.063593779291425, 8.204179286956787, 5.385624723775046, 5.517988341195243, 4.796803108283451, 1.829480882201876, 2.8463675507477353, 1.1088796236685343, 0.1377581065254552, 0.05917335620948246, 0.10515307395585946, 3.3652307944638387, 10.22954877785274, 19.23463041441781, 24.12182307243347, 33.25544377735683, 36.48699535642351, 21.55120846203395, 5.143360580716815, 0.19094484326030525, 0.003942496259696782, 0.019565820195046917, 0.07852189083184515, 0.07274985805686031, 0.026176793667088662, 0.03452101529442838, 0.05599846710850086, 0.02068605606577226, 0.010623298618676407, 0.018157829497275606, 0.010657171934976109, 0.07624331595642225, 0.015514715075758951, 0.028749817117516483, 0.010068478345471834, 0.033876325602510145, 0.04692746153367417, 0.08090808814657585, 0.034648274537175894, 0.018742842034303715, 0.009173304906913211, 0.05901472829282284, 0.034770739930016656, 0.10176723171025515, 0.13597374941621507, 0.07120845719639744, 0.15737553100500787, 0.23693273056830677, 0.12488423447523798, 0.1118336244087134, 0.11269647667982749, 0.18600004645330565, 0.21918644782687935, 0.10035344293074948, 0.1692928858101368, 0.14505811195288384, 0.15764725713857583, 0.175354089854019, 0.1285709866455623, 0.12360550809119429, 0.1025953565591148, 0.13805457204580307, 0.14859171876949923, 0.1324242241680622, 0.1479636531855379, 0.1802394198519843, 0.16287171893886157, 0.2147059996745416, 0.18350087984332017, 0.1329054140618869, 0.16232462972402573, 0.1626131563846554, 3.190665121589388, 21.545179162706646, 49.196744441986084, 59.42000075748989, 47.42996345247541, 29.76138230732509, 20.954125438417705, 12.412425245557513, 1.87742714371, 0.7493491045066288, 2.1325400258813585, 3.9770073039191107, 2.82940656372479, 3.8158837897436957, 1.257275557943753, 5.2003041080066135, 7.4218833446502686, 7.5851964099066596, 26.07336708477565, 44.13953283854893, 52.12508010864258, 49.487168720790315, 49.1229441506522, 47.41414587838309, 52.146001134599956, 54.09385912758963, 49.21197836739676, 49.011237961905344, 46.52293866021292, 39.80727195739746, 39.707752908979145, 38.88400575092861, 44.057370390210835, 45.646489415849956, 48.774544102805, 48.48200757162911, 45.01138584954398, 39.53076492037092, 37.82401289258684, 39.23869044440133, 37.93947458267212, 38.2674434525626, 40.67307308741978, 46.13479144232613, 46.70811857495989, 46.109430517469136, 47.47137819017683, 43.37796858378819, 39.438996587480815, 37.92501538140433, 34.675902230399, 36.25753804615566, 41.870445728302, 43.97759812218802, 46.45801816667829, 48.29007053375244, 49.56610025678362, 47.63725600923811, 46.97562074661255, 46.03672456741333, 43.864839281354634, 37.52628605706351, 50.35295595441546, 47.176833629608154, 48.51725230898176, 44.82194668906075, 41.54587452752249, 36.86462300164359, 35.8582215990339, 35.58696740014212, 35.776611532483784, 32.79044600895473, 40.1966107913426, 49.75120026724679, 50.003388609204976, 42.219047273908345, 43.195331709725515, 48.376707621983115, 49.37374285289219, 46.886965206691194, 47.677110876355854, 47.35840742928641, 47.51777826036726, 47.50614697592599, 45.6377729007176, 41.98563296454293, 40.674639906202046, 37.85056890760149, 36.16639505113874, 36.87658779961722, 36.8633827481951, 37.16369431359427, 43.62887845720564, 46.6897405896868, 50.45316982269287, 47.30701160430908, 45.50942925044468, 47.262473651341026, 46.350074427468435, 49.33675064359392, 47.52417755126953, 47.94880281175886, 33.59068741117205, 21.060448510306223, 9.424692034721375, 7.821614946637835, 4.203173339366913, 5.238047157015119, 6.370540993554251, 4.909784725734165, 3.1493474415370395, 1.3720392797674452, 0.4009834719555718, 0.25281780532428194, 1.6669361357178007, 6.156916890825544, 14.733116626739502, 23.641848461968557, 29.762792791639054, 40.388707637786865, 42.923695359911235, 24.353211981909617, 6.298122090952737, 0.24994046400700295, 0.14611744082399777, 0.1591968954141651, 0.1530411443007844, 0.16406998464039393, 0.1575378230107682, 0.22215836335505756, 0.15117715432175569, 0.07107148811753307, 0.12154373872492995, 0.13521303023610795, 0.18310502251344069, 0.18853955875549996, 0.10077702520149094, 0.14399746672383376, 0.07560991030186415, 0.14293568155595235, 0.15261593354599817, 0.15071032222892555, 0.11208882142922708, 0.07471471905176129, 0.194959409268839, 0.13337551669350692, 0.15181740639465197], [0.014024277284209217, 0.06133413740566798, 0.015179820724629929, 0.09779751008110386, 0.011673379057486142, 0.03902045224926301, 0.009803461226900774, 0.04521256605429309, 0.04236336697691253, 0.048289515410682986, 0.020519570713596683, 0.029421570178653513, 0.1287120133638382, 0.056626458053610156, 0.07318440545350313, 0.04942550516820379, 0.010613929746406419, 0.026810089059706246, 0.06701921591801302, 0.036351621350539584, 0.06214879333440747, 0.1293484792113304, 0.04316054045089653, 0.11084015414650951, 0.01484882116450795, 0.0983443007405315, 0.006549409989799772, 0.030687563853072267, 0.03403108586956348, 0.4208486702825342, 4.234696447849274, 22.176872900554113, 38.479825564793174, 32.70849895477295, 29.6360923903329, 19.948248624801636, 13.609603336879186, 4.668954082897731, 0.4068298653832504, 0.3821124631379332, 0.2149331731987851, 0.22535233625343867, 0.3046124189027718, 0.6210639710937227, 0.3256740915988173, 2.945905923843384, 3.0318232221262793, 7.997886402266366, 29.236310413905553, 47.28019503184727, 51.41924040658133, 50.06729466574532, 50.23519788469587, 49.14133603232247, 47.24576670782906, 44.51355784279959, 43.76769651685442, 39.13114275251116, 35.98267425809588, 40.16244649887085, 43.72418342317854, 43.605490820748464, 46.970472131456646, 45.20890229088919, 45.772981371198384, 44.47903571810041, 39.67067732129778, 35.86681999479021, 34.90723555428641, 34.40441179275513, 34.88437250682286, 38.513107436043875, 39.797791140420095, 40.136126722608296, 43.9245798928397, 42.3170724596296, 39.964165755680625, 35.83413566861834, 34.09606810978481, 35.50706311634609, 36.291841302599224, 40.55925464630127, 44.9967668397086, 44.20562062944685, 45.548655305589946, 45.21320669991629, 47.27015141078404, 45.438265800476074, 42.05486828940255, 38.99382202965872, 33.00007316044399, 46.17127643312727, 43.54231432506016, 44.992493697575156, 42.432259695870535, 42.465454714638845, 40.06680454526629, 34.933617864336284, 30.3739424433027, 31.85553114754813, 32.72602578571865, 40.69217715944563, 45.405939306531636, 46.122239521571565, 43.64571394239153, 44.275331905909944, 43.628833293914795, 44.8015433038984, 42.989887373788015, 37.88802317210606, 38.727831091199604, 37.01735135487148, 34.695402349744526, 34.304371629442485, 35.46419620513916, 32.848640646253315, 32.514988149915425, 32.6865565436227, 32.7875520842416, 33.78712340763637, 34.68655034473964, 40.04031106403896, 42.46197019304548, 44.266243662152974, 45.12884862082345, 45.51836463383266, 45.95320374625069, 45.0209778376988, 45.4951958656311, 45.75202560424805, 35.02567107336861, 21.76486383165632, 8.852546095848083, 4.296886733600071, 0.09212364775261708, 1.6863109703574861, 1.8399125167301722, 0.2421512348311288, 0.36998180406434195, 0.009852368334707404, 0.09427066825862442, 0.08980018778571061, 0.15464282621230396, 0.4859690602336611, 3.7584117650985718, 10.537803871291024, 22.225793429783412, 31.697272028241837, 31.948296546936035, 31.299004759107316, 9.327534505299159, 1.7484854055302483, 0.014126259401174528, 0.023794458912951604, 0.03971405074532543, 0.058396528608032634, 0.021948711347899268, 0.08887587381260735, 0.06271202489733696, 0.007941328737485622, 0.04747662706566708, 0.028126162011176348, 0.03798480764297502, 0.05239774978586605, 0.026941212559384958, 0.04925664494346295, 0.0470823235809803, 0.012175771474306072, 0.011403675806442541, 0.01471835414745978, 0.042145865969359875, 0.01057100562112672, 0.040391483144568543, 0.023778243622343456, 0.03943460627592035, 0.034676338745547194, 0.017091650815148438, 0.06767132878303528, 0.02383847039059869, 0.03027374230857406, 0.02206347367194082, 0.049609177812401734, 0.019753253619585718, 0.01158456051988261, 0.012556982625808035, 0.010192211750628693, 0.007417062048002013, 0.024384568944307308, 0.008934179836485003, 0.02395066785226975, 0.06541570196194307, 0.042233810893126895, 0.047542702805783064, 0.027838218890662705, 0.03183228635628309, 0.03407156387610095, 0.056484654412737915, 0.0662551922723651, 0.037721797291721613, 0.034722167000706704, 0.032153640541114976, 0.0746629061177373, 0.026702152797952294, 0.05077805955495153, 0.03282319514879158, 0.41445974739534513, 6.367216280528477, 29.054161650793894, 46.164352553231375, 37.2718881879534, 28.45631606238229, 21.552420922688075, 15.004740817206246, 3.9975631151880537, 0.39296896915350643, 0.11330457297819001, 0.7124208946313176, 0.7822430708578655, 0.6540562435984612, 1.0344994834491184, 1.294340180499213, 3.547929985182626, 3.8917720147541592, 12.788462621825081, 31.584641729082378, 47.561621393476216, 50.240627901894705, 52.13748959132603, 50.38376079286848, 51.51845373426165, 49.145223549434114, 47.76078455788748, 46.09327942984444, 40.1652500970023, 37.17237956183297, 40.472367422921316, 44.416352544512065, 45.36486503056118, 48.23169524329049, 47.39917598451887, 49.70904554639544, 45.99703993116106, 41.73057849066598, 36.67889417920794, 37.558279037475586, 36.565777506147114, 37.1375412940979, 40.73015601294381, 40.93472834995815, 42.75561843599592, 45.86195305415562, 44.207590443747385, 41.605278151375906, 36.96906137466431, 35.91621821267264, 35.60982002530779, 36.93981988089425, 42.03814050129482, 46.5264162336077, 47.12684481484549, 47.61014413833618, 46.094849722726, 47.99938222340175, 44.96343285696847, 43.035036768232075, 40.567380564553396, 37.34450381142752, 48.49126604625157, 44.77539028440203, 47.18710306712559, 44.444642135075156, 43.29669203077044, 39.314140932900564, 36.46139471871512, 32.406478132520405, 32.87417180197579, 33.98202732631138, 43.31593854086739, 47.749115058353965, 48.21086801801409, 45.21637855257307, 45.621885844639365, 45.54910693849836, 46.80485486984253, 43.777417046683176, 40.58421604973929, 40.21471084867205, 39.47610344205584, 36.160075664520264, 38.00480849402291, 36.061126368386404, 35.864342961992534, 33.25783395767212, 33.83000421524048, 34.35426664352417, 36.00270938873291, 36.154715129307334, 40.666277749197825, 44.39151273454939, 45.920800822121755, 47.131899629320415, 46.785504136766704, 46.71534470149449, 45.44927522114345, 46.39898974554879, 45.748183250427246, 36.495281083243235, 22.7579733303615, 11.078290343284607, 2.6782224476337433, 0.18669521915061132, 1.0511669090815952, 1.8693073051316398, 0.5974409644092832, 0.10394682189715759, 0.08100161062819616, 0.03954887157306075, 0.01847962472986962, 0.1441554839589766, 0.46272581602845875, 5.347738368170602, 16.28611544200352, 23.187250409807476, 34.234799316951204, 35.05256060191563, 36.93169048854283, 12.825031859534127, 2.344153493642807, 0.034556794445961714, 0.04218431515619159, 0.015455406026116439, 0.04593374360618847, 0.01655677523064826, 0.04084932464840157, 0.03064441241856132, 0.018702554017571465, 0.006033524055965245, 0.03531857553337302, 0.012569467670151165, 0.006430708345890577, 0.03166565851175359, 0.04193980845489672, 0.014791150776935475, 0.03470590930165989, 0.06280986964702606, 0.04699803935363889, 0.0314051994521703, 0.03364772715472749, 0.048970337092344246, 0.04622903526095407, 0.07040871546736785, 0.04123528554503407, 0.13356207311153412, 0.13281603742923054, 0.20654871953385218, 0.2335315602166312, 0.07700443547219038, 0.14956890419125557, 0.10923147653894764, 0.20219552383891173, 0.14199908609901155, 0.09985182913286345, 0.06351900659501553, 0.10313828635428633, 0.3306763603218964, 0.1770365581448589, 0.14677023222403868, 0.15494615850704058, 0.12008088507822581, 0.11879269991602216, 0.2884162494114467, 0.10980852307485682, 0.14684151911309787, 0.12774219683238439, 0.16457500468407357, 0.1981747153082064, 0.16728218298937592, 0.1731827642236437, 0.07103891843663794, 0.08390513661184482, 0.0848601542945419, 0.5297215410641262, 6.840709090232849, 33.699899196624756, 49.64603928157261, 43.544440473829, 38.88427325657436, 27.824231488364084, 17.389234031949723, 5.467160965715136, 0.7228104057056564, 1.2731614198003496, 1.5975670580353056, 2.272584008319037, 1.4657286810023444, 1.7932509120021547, 1.5858970156737735, 4.635579279490879, 5.850303743566785, 11.403864690235682, 31.887214933122905, 49.26338114057268, 51.35607433319092, 53.02472938810076, 52.11684649331229, 53.30933107648577, 51.48624535969326, 49.88198273522513, 47.332782472882954, 41.94445446559361, 39.76205308096749, 43.18190084184919, 47.838684286390034, 48.04637636457171, 49.932537828172954, 48.29620579310826, 50.53509603227888, 48.42162077767508, 43.46336889266968, 39.170566831316265, 39.10738338742937, 38.772584438323975, 39.42239734104702, 41.80060938426426, 41.802937030792236, 44.22523886816842, 47.37656307220459, 46.272393567221506, 42.494491236550466, 39.035004002707346, 38.04260669435774, 38.28639466421944, 38.85936049052647, 43.87491416931152, 48.22242634637015, 48.938796043395996, 48.56219673156738, 48.741668701171875, 48.46751362936837, 46.856730120522634, 43.5817905153547, 41.58427027293614, 39.95056118283953, 47.99384798322405, 47.19609751020159, 49.04854284014021, 46.04811266490391, 44.80089364733015, 44.01172072546822, 38.49815838677542, 33.119828837258474, 34.44932842254639, 36.09234462465559, 46.360743386404856, 49.97396298817226, 49.036216735839844, 43.48374795913696, 46.17833232879639, 46.593129362378804, 47.9959602355957, 45.31502907616751, 41.85158484322684, 42.87615925925118, 40.51492166519165, 38.25012159347534, 38.77489471435547, 37.99580710274832, 36.854555061885286, 35.12472806658064, 35.08708272661482, 36.70483180454799, 37.47677666800362, 38.37523085730416, 43.326180185590474, 46.5149690764291, 48.8515544618879, 48.126621110098704, 46.736720834459575, 45.75601734433855, 45.52115086146763, 47.23631715774536, 46.69122403008597, 36.61892080307007, 24.584234373910085, 12.64884204523904, 6.773739312376295, 1.1293598732778003, 4.712414196559361, 6.047066305364881, 1.8527256463255202, 1.3150388641016824, 0.21310313711208956, 0.39525538789374487, 0.20946114111159528, 0.927412001149995, 1.10386552129473, 8.779404146330696, 22.07014857019697, 29.492407117571148, 42.79384742464338, 41.61235836574009, 41.06473956789289, 14.797644547053746, 2.8445462541920796, 0.17087479521121296, 0.08328254680548396, 0.11486744268664292, 0.25814229675701683, 0.20746896229684353, 0.10906910989433527, 0.09584862180054188, 0.11988512772534575, 0.13235257087009294, 0.14568498331521237, 0.13299299936209405, 0.11436475680342742, 0.1533432145203863, 0.164037713514907, 0.10344203934073448, 0.15394206238644464, 0.10824035400790827, 0.08554429401244436, 0.14414150613759244, 0.11563878772514206, 0.16502704471349716, 0.1284755574805396, 0.14551321896059172, 0.15190917147057398], [0.04497802024707198, 0.051121075970253775, 0.05127221964565771, 0.017848242806004624, 0.02945367167038577, 0.07034626310425145, 0.051305345725268126, 0.023187950386532714, 0.045325213045414, 0.050118292814918926, 0.04833127245573061, 0.02197964575939945, 0.037286642606237104, 0.022995953813993504, 0.03671439331290977, 0.07793946351323809, 0.01747720459076975, 0.04106908178489123, 0.04479156221662249, 0.06765714740114552, 0.04989953651758177, 0.015305307294641222, 0.06360198464244604, 0.13050710489707334, 0.02816390891426376, 0.018811214615457823, 0.023070429817640355, 0.0267873683146068, 0.05215056626392262, 0.06493789117251124, 0.6777614344443593, 10.943843569074359, 31.987762314932688, 39.85627065386091, 33.72617033549717, 26.520193576812744, 33.678707190922324, 9.07716919694628, 1.186634742787906, 0.14021153987518378, 0.184625008808715, 0.09307191401187863, 0.12963913647191866, 0.3608713043587548, 0.3834254555404186, 1.3709804394415446, 2.976717927626201, 4.069587707519531, 13.914920210838318, 33.24295439038958, 49.56869193485805, 47.07391691207886, 48.84706939969744, 50.359369141714915, 46.584718567984446, 44.38614872523716, 41.28096055984497, 40.26105880737305, 43.12177807944161, 47.5618645804269, 46.05356700079781, 48.364763668605256, 43.94605677468436, 44.19767189025879, 47.393957887377056, 43.569836139678955, 43.787207058497835, 37.796504974365234, 37.18413938794817, 35.183019978659495, 36.45751414980207, 37.943990911756245, 39.452399662562776, 42.44018759046282, 41.26481989451817, 42.83017955507551, 38.01055465425764, 35.93383537020002, 35.278144291469026, 35.4081311907087, 36.594143526894705, 41.06543091365269, 44.37675823484148, 46.20150457109724, 45.75580195018223, 45.47881201335362, 44.58624989645821, 43.65156779970442, 40.607641901288716, 35.775829860142295, 32.78844492776053, 45.878197942461284, 43.96081127439226, 45.541133880615234, 44.621074267796104, 45.54105397633144, 45.520674909864155, 41.64994812011719, 32.41836302621024, 32.04059989111764, 32.394978863852366, 38.59450558253697, 46.632112230573384, 43.31252350125994, 40.43902996608189, 48.495320320129395, 44.678376061575754, 44.65519687107631, 38.7086193220956, 36.006562164851594, 35.38751588548933, 32.35810129983084, 31.812393256596156, 32.35674640110561, 32.01516253607613, 31.46035930088588, 29.6330977167402, 31.85269628252302, 33.00492647715977, 33.740365505218506, 35.74207551138741, 39.62897770745413, 42.924140044621055, 44.43203115463257, 45.84538854871477, 44.29333816255842, 45.291940212249756, 47.10623298372541, 43.369964259011404, 41.711637701307026, 26.003869465419225, 12.007396510669164, 1.7948429180043084, 0.43203564999358995, 1.1542299730437142, 0.316728123064552, 0.5218021145888737, 0.06323279373879943, 0.017313139912273203, 0.056121051244969876, 0.033400143297123056, 0.064890617637762, 0.14966531044670514, 1.3851264289447238, 2.9404151099068776, 9.910401514598302, 24.92161110469273, 32.18039069856916, 31.120071274893625, 19.190889767238072, 5.343190337930407, 0.4127630298691136, 0.050938265065529516, 0.036646041087806225, 0.08639990631490946, 0.02089442399197391, 0.02459572395309806, 0.06644921257559742, 0.019703116667057787, 0.026863031754536287, 0.011178220672133778, 0.0418237993227584, 0.03214609183903251, 0.05992199068090745, 0.010149107813569052, 0.06640962684260947, 0.015427769294806888, 0.04219234561813729, 0.041546247966055355, 0.03348167945763894, 0.031154514689530646, 0.03558859515136906, 0.0050726938726646555, 0.006544906637697879, 0.03200839672769819, 0.038546522680137835, 0.028927108139864037, 0.017670154505010163, 0.036061333891536505, 0.039348893732364686, 0.03690629658688392, 0.08427612563329083, 0.0037362254307871418, 0.007700772806336837, 0.01960118204754378, 0.05031141745192664, 0.03776466374152473, 0.02085480772491012, 0.03881300713068672, 0.055162661243230104, 0.03624967146398766, 0.03418899793177843, 0.0047101602457197645, 0.017052545145686184, 0.02459395976204957, 0.038807924903397045, 0.012845859580141093, 0.03652493276500276, 0.02212600745925946, 0.06233982129820755, 0.1473062341766698, 0.0466520848817059, 0.024349929731605307, 0.055654731446078846, 0.036718444166971106, 0.057071342931262085, 1.3736066413777215, 15.061422484261648, 37.34546613693237, 43.0669880594526, 37.76037086759295, 22.576491594314575, 26.75440866606576, 10.905033537319728, 1.4248200761420386, 0.10745788778045348, 0.2069340188588415, 0.4053838258343083, 0.2013640334563596, 0.12155996928257601, 0.16558163852563926, 2.0378013380936215, 3.1327614401068007, 5.508385062217712, 17.271668774741038, 36.32948316846575, 49.78129986354283, 48.083083697727744, 51.2201224054609, 51.36044127600533, 49.99947329929897, 46.3130544253758, 43.745187827519004, 41.35212400981358, 45.54099839074271, 48.86030224391392, 48.793926102774485, 48.7535640171596, 45.844679832458496, 45.767485346112935, 48.9621593611581, 46.1010023525783, 44.830520766122, 39.378762653895784, 38.636667251586914, 37.19150447845459, 37.69770506450108, 40.73871271950858, 42.30832120350429, 43.59079885482788, 43.7342027255467, 43.96815552030291, 39.857139178684776, 37.5767126083374, 36.25789935248238, 36.54240724018642, 37.47975744519915, 42.296255656651084, 46.618459020342144, 47.13570029394967, 47.650777203696116, 46.86535978317261, 44.549549511500764, 44.35073028291975, 39.53281116485596, 36.69187341417585, 34.45512669427054, 47.73305777141026, 46.70996332168579, 47.349496364593506, 46.67675788061959, 46.61339725766863, 46.90834133965628, 42.792280605861116, 33.235200200762065, 34.49555478777204, 35.43282161440168, 40.85874285016741, 47.99197891780308, 45.02526487622942, 41.87653235026768, 49.043428965977256, 46.564412457602366, 44.8654910496303, 41.987112930842805, 39.06711857659476, 37.316888196127756, 34.06912646974836, 33.24882909229824, 33.8867883682251, 33.248849936894004, 33.64482430049351, 32.346348421914236, 34.473723547799246, 34.93825231279646, 34.55633415494646, 36.580354826790945, 42.123287200927734, 44.631913457598, 45.63925634111677, 46.55865240097046, 45.30616317476545, 46.69251639502389, 47.06468970435006, 47.263314383370535, 42.71275847298758, 28.316051040376934, 12.324785011155264, 3.5003993128027235, 1.5061235534293311, 3.361695464168276, 1.8296485074928828, 0.961845970579556, 0.13474420325032302, 0.031959956112716875, 0.04317765988941703, 0.09403193249766316, 0.11680656006293637, 0.9887962958642414, 1.3894266039133072, 5.361334255763462, 13.532818794250488, 28.854433945247106, 37.49669367926461, 35.40474394389561, 24.187801429203578, 7.397005319595337, 0.6277073174715042, 0.024629338577921902, 0.06882629716502768, 0.07901173204715763, 0.02575015968510083, 0.047729425464889834, 0.07255798870963709, 0.006761065418166774, 0.03978348523378372, 0.03774795142401542, 0.05471848543467266, 0.02421976805531553, 0.015375440674168723, 0.03152225352823734, 0.0404423597002668, 0.03604654182812997, 0.007552663030635033, 0.028196366636880806, 0.00831981557088771, 0.02335804045599486, 0.014710413591404046, 0.010657694406940468, 0.06737202698630945, 0.02367079251312784, 0.07498507454459157, 0.18783395018960747, 0.14406420742826803, 0.16989299575132982, 0.13872477465442248, 0.10950501436101538, 0.17246899966682705, 0.13576170722288744, 0.0832591780594417, 0.1532723754644394, 0.1520302492593016, 0.12037549141262259, 0.08439203977052655, 0.18515855446457863, 0.1819074217762266, 0.08983953603144203, 0.1339190232434443, 0.11481211494122233, 0.19697646317737444, 0.08377991297415324, 0.14544407624219144, 0.10564207378774881, 0.2134572916797229, 0.09581760596483946, 0.20923137558358057, 0.1733246458960431, 0.14874452485569886, 0.1805968178170068, 0.21901635266840458, 0.20750343187579087, 0.14909619598516397, 1.4564484932592936, 17.99895235470363, 42.33016633987427, 50.291179520743235, 43.73234755652291, 34.67893859318325, 37.733366693769185, 12.265382255826678, 2.5521506411688666, 0.3769938392298562, 1.9515922154699052, 1.7007869992937361, 0.5281136844839368, 0.5184363094823701, 0.9959001775298799, 4.098433153969901, 4.949389023440225, 6.71023017168045, 17.724906717027935, 36.6114410672869, 49.900082792554585, 50.52960000719343, 51.031638622283936, 53.766751834324424, 50.71574224744524, 47.64131375721523, 45.525851317814414, 44.98500006539481, 48.091369424547466, 52.34121077401297, 49.16126346588135, 51.749811376844136, 46.65785878045218, 49.30990975243704, 49.98201595033918, 48.69633865356445, 46.9024145262582, 40.93581574303763, 40.389537947518484, 38.782471724918906, 39.147741998944966, 42.295974254608154, 42.94973373413086, 46.02402326038906, 44.49645832606724, 46.14019019263131, 42.070807456970215, 38.83415937423706, 37.86737659999302, 38.578243323734824, 38.706614766802105, 44.494797706604004, 47.459712164742605, 48.66697556631905, 47.82123041152954, 48.45628186634609, 45.381019592285156, 43.321344239371165, 41.67088304247175, 39.487481117248535, 39.05897528784615, 47.87177855627877, 48.05490527834211, 48.99255772999355, 47.772165707179475, 47.82126862662179, 49.99274396896362, 45.454694816044395, 34.72635310036795, 36.60339157921927, 36.35789782660348, 43.13991982596261, 50.884607791900635, 46.446477208818706, 41.937266554151265, 50.293152809143066, 48.871641704014365, 46.96780749729702, 42.7713109425136, 40.4930556842259, 38.90503447396414, 36.65039266858782, 34.67888995579311, 35.24263899666922, 35.984748295375276, 35.34778608594622, 33.715153966631206, 35.109282221112935, 36.44000816345215, 36.267453125544954, 38.591750621795654, 44.032509735652376, 46.18751784733364, 47.607993670872276, 48.633005823407856, 46.22691413334438, 47.997249126434326, 46.92603145326887, 46.68383462088448, 44.259246826171875, 30.546730245862687, 15.576122454234532, 3.552569861922945, 1.349628625171525, 2.4459634934152876, 2.131775289773941, 1.1037145065409797, 0.33910704936300007, 0.11623310297727585, 0.14774831331201962, 0.2348284577684743, 0.8501309880188533, 2.6374267510005405, 1.5943949882473265, 9.17459683758872, 21.68842669895717, 34.94089610236031, 43.43866804667881, 41.102291107177734, 26.950829029083252, 8.423707621438162, 0.776350618473121, 0.16425131633877754, 0.11465116643479892, 0.22015679361564772, 0.12399477006069251, 0.10443019667374236, 0.19609123282134533, 0.16253929106252535, 0.12632727489939757, 0.09225959224360329, 0.1373581915561642, 0.0700806098591004, 0.15737068626497472, 0.13988673873245716, 0.1455351627830948, 0.09750830488545553, 0.155591146754367, 0.11528884007462434, 0.06063774334532874, 0.09158960676618985, 0.10071523101734263, 0.10912884133202688, 0.12715062286172593, 0.0980066413592015, 0.14661372133663722], [0.042917611343520026, 0.02883252375093954, 0.07664822494345051, 0.04011606578049915, 0.025140986212396195, 0.017146354308351874, 0.021234743230577027, 0.03349147071795804, 0.031293851855610094, 0.04005161513175283, 0.0696575975577746, 0.06153168609099729, 0.031939528815980466, 0.05506404974896993, 0.043296722429139275, 0.030905604295964752, 0.02297274791635573, 0.023141603052083935, 0.011455062959742333, 0.07823117250310523, 0.022525756187470894, 0.0158584558271936, 0.028176494042522142, 0.0163976621614503, 0.03297051867204053, 0.02509228096875761, 0.011693465390375682, 0.02732381470767515, 0.02015529409982264, 0.02677740911687059, 0.19613585328417166, 4.506543414933341, 20.458732775279454, 40.6849684034075, 30.81450687135969, 39.76841415677752, 31.285771914890834, 9.608316421508789, 2.956317365169525, 0.38880013142313274, 0.05441786049466048, 0.48566339377846035, 0.19366857782006264, 0.11443710220711571, 0.34704875892826487, 1.9645319325583321, 0.6686519118291991, 1.4138275917087282, 3.8325933388301303, 15.553021430969238, 36.00874737330845, 49.29599598475865, 52.507891110011506, 50.066012723105295, 48.797622544424875, 45.68041052137102, 42.63101291656494, 43.34304346357073, 46.60430553981236, 47.000509193965364, 48.0152519089835, 46.20936645780291, 44.14898238863264, 46.49369369234358, 49.012780461992534, 44.012957504817415, 43.54029587336949, 41.76206425258091, 39.30510827473232, 36.14260441916329, 37.535989216395784, 38.91853829792568, 39.15495075498308, 39.882402828761506, 40.40012352807181, 38.75439405441284, 35.15430307388306, 34.66546951021467, 35.8333956854684, 36.68079451152256, 35.62640537534441, 41.57067264829363, 46.88297346660069, 45.916135106767925, 45.764424664633616, 43.81478793280465, 45.78114203044346, 44.22087887355259, 44.9789377621242, 41.54066685267857, 32.549572808401926, 47.02752031598772, 40.87971946171352, 46.79804910932268, 45.26476580756051, 47.03818580082485, 45.99218314034598, 45.342224325452534, 34.97464002881731, 31.612114906311035, 31.553086485181534, 40.369412490299766, 45.116619791303364, 45.37632608413696, 42.583792958940776, 49.2864283152989, 44.12643895830427, 44.638879026685444, 41.943318435123985, 42.367241927555625, 41.97869866234915, 41.11571502685547, 39.53018821988787, 39.91749470574515, 37.697906562260215, 36.11659036363874, 33.112977913447786, 32.622091157095774, 34.12152630942208, 35.41140726634434, 36.914118494306294, 40.214210578373496, 43.30966084344046, 45.898368562970845, 44.76198026112148, 45.58614778518677, 45.49557801655361, 47.64230734961373, 41.17954812731062, 27.659538337162562, 13.074304563658577, 2.0540720650127957, 2.666080904858453, 0.9234294891357422, 1.5462593883275986, 1.2174744307994843, 0.8146278102483068, 0.1659134014376572, 0.025075034304921116, 0.03364759484039886, 0.03796761356560247, 0.1219062799853938, 0.19031565130821296, 2.0385274248463765, 5.9945717964853555, 17.69805714062282, 25.993492330823624, 28.464603526251658, 27.023540190288, 14.593961579459053, 2.0065448667321886, 0.05185323900410107, 0.03169813319774611, 0.05150121503642627, 0.0445174476397889, 0.021903941607368842, 0.005726708756161055, 0.04085203878847616, 0.048884003689246516, 0.0471889553591609, 0.0260716733256621, 0.021255262129540955, 0.16458892822265625, 0.06768811573939663, 0.06784371738987309, 0.05799069002802883, 0.04870208166539669, 0.04909794917330146, 0.027634029043838382, 0.057222649455070496, 0.04991299525967666, 0.08041721555803504, 0.01652544387616217, 0.019374215476480976, 0.015073750434177262, 0.03823297843337059, 0.02913659225617136, 0.011492071955996965, 0.04335336313982095, 0.031793833776776276, 0.025225428199129443, 0.031779075640120676, 0.006701157985454691, 0.03381544404796191, 0.013840420587387468, 0.03809960559010506, 0.05845245346426964, 0.05056133207732013, 0.027284320576914718, 0.008409511963171619, 0.022780461270096045, 0.03446247468569449, 0.02067809515366597, 0.009473491343669593, 0.03269720137385385, 0.038682378961571624, 0.018773847691980854, 0.04045592022261449, 0.03370894458410995, 0.026046248618513346, 0.018702082435733507, 0.021582348238942877, 0.01944920207772936, 0.023980184125580957, 0.0508896276753928, 0.06128023458378656, 0.23189466233764375, 7.374621697834559, 28.376981530870708, 44.79801709311349, 32.07058136803763, 37.21860245295933, 37.9706963130406, 15.309363739831106, 4.040826073714665, 0.18162699682371958, 0.1397710892238787, 0.2734127273516995, 0.3425811757998807, 0.2470505562211786, 0.053063314607633014, 0.7381096333265305, 1.0156433752604892, 1.992255027805056, 6.392418699605124, 17.443235431398662, 39.43612003326416, 50.76520299911499, 54.207448278154644, 49.55455929892403, 49.856416838509695, 47.276443004608154, 44.068018504551475, 44.06711523873465, 47.393169266836985, 48.923325879233225, 49.333262647901265, 48.241478306906565, 45.02298934119088, 48.65537902287075, 51.312689781188965, 45.905990736825125, 45.60376146861485, 43.15624809265137, 40.727675506046836, 39.47994926997593, 38.886694703783306, 39.54535961151123, 41.1524327823094, 42.399992261614116, 42.016646248953684, 41.43609298978533, 37.48491995675223, 35.20764786856515, 37.94016592843192, 38.017120701926096, 37.552644048418315, 43.80839559010097, 48.17732906341553, 47.410181931086946, 46.917735304151265, 43.403597014290945, 46.34204925809588, 42.99914237431118, 45.86731011526925, 41.490549496241975, 36.13001428331648, 46.24494818278721, 42.9926666532244, 48.12978948865618, 46.204443659101216, 47.295043332236155, 48.570412976401194, 46.39121471132551, 35.40804433822632, 33.41277878625052, 33.95292132241385, 42.06357090813773, 47.4465765953064, 45.99483387810843, 43.770767620631624, 49.85593393870762, 45.34712627955845, 44.6772643498012, 42.940245968954905, 43.36402702331543, 41.813018866947715, 42.887147835322786, 40.87649897166661, 41.05737100328718, 37.744984081813264, 36.79056910106114, 34.187405654362266, 34.00305257524763, 36.60196025030953, 37.1124061856951, 38.58920758111136, 40.11688021251133, 44.48925651822771, 47.015371390751426, 47.01908867699759, 45.686406816755024, 45.39924471718924, 47.84482649394444, 42.96052428654262, 31.186523846217565, 14.924306733267647, 2.792956965310233, 3.3595063473497118, 1.8714592925139835, 3.4205603854996816, 1.7947464031832558, 1.524180184517588, 0.22349708580545016, 0.062391288179372034, 0.05752398007150207, 0.03285482166601079, 0.25278094730206896, 0.5183436487402234, 3.289126523903438, 6.438437053135463, 16.63160072054182, 28.05113707269941, 32.77004957199097, 32.545369148254395, 17.542669364384242, 3.1955301633902957, 0.1745929228407996, 0.05529784916767052, 0.007298437163366803, 0.011054639089187341, 0.022333306692806736, 0.032244258892855475, 0.05596760055050254, 0.03557664275701557, 0.022847553116402457, 0.03249946269871933, 0.06417063091482435, 0.04273770796135068, 0.07247788086533546, 0.05178439144843391, 0.08945298141666821, 0.047064725775271654, 0.05592824551942093, 0.03342958493158221, 0.05361254460045269, 0.03919443880606975, 0.058842217549681664, 0.03162917707647596, 0.030569301984672035, 0.03164432876344238, 0.026362247465710555, 0.03905935605455722, 0.12666504963168077, 0.19196925471935952, 0.11452442966401577, 0.08758726795869214, 0.13847064971923828, 0.11472869584602968, 0.18220987197543892, 0.08379083738795348, 0.1415551206363099, 0.12425075418182782, 0.12543536775878497, 0.14279700256884098, 0.11640576299812112, 0.06857023161969014, 0.13749472637261662, 0.0844305194914341, 0.085296167326825, 0.18311555337693008, 0.14154439978301525, 0.12482119857200555, 0.1742693159197058, 0.12916902026959828, 0.12339176956032004, 0.09299502920891557, 0.08404718791799885, 0.1304442047008446, 0.11233620172632591, 0.18424762120204313, 0.14833668459739002, 0.4371809538986002, 9.038524184908185, 32.98474196025303, 52.8818153653826, 39.919610432216096, 47.083877154758994, 37.437915393284385, 16.15252069064549, 4.670476172651563, 1.314285853079387, 0.28634004081998554, 1.7592179839100157, 0.9094195323331016, 0.46033020743301933, 0.8684690754328455, 6.283291595322745, 2.8905441973890578, 2.8952472593103136, 6.465894162654877, 19.32470859800066, 38.131255286080496, 51.25898020608084, 55.73547874178205, 52.28469065257481, 52.39363145828247, 49.21269750595093, 45.88676159722464, 46.637385913303916, 49.42288051332746, 51.46342747552054, 51.737916060856406, 49.10103300639561, 46.11371060780117, 48.54018136433193, 52.84310695103237, 47.98398848942348, 46.74973133632115, 45.78165967123849, 43.24471255711147, 40.295382908412385, 41.175650187901084, 41.77545690536499, 42.99592883246285, 43.793536867414204, 42.74226747240339, 42.66224159513201, 38.580921854291645, 37.15416138512747, 40.15550177437918, 39.32732513972691, 38.50490508760725, 45.112520354134695, 49.409126554216655, 50.11403867176601, 48.05553061621529, 44.83366135188511, 47.61273234231131, 44.77978154591152, 44.91273880004883, 42.1839519228254, 39.16176346370152, 44.8696425982884, 42.82644142423357, 48.860159805842805, 47.59610182898385, 50.08465821402413, 50.45243331364223, 49.93928452900478, 38.04613290514265, 34.98995385851179, 36.3000818661281, 43.02108131136213, 48.56662968226841, 48.18636519568307, 44.5891056060791, 52.62123359952654, 46.39307682854788, 46.61730561937605, 45.834285327366416, 46.80146414893014, 46.44804055350167, 45.27781105041504, 44.33591672352382, 43.844696453639436, 39.808672019413535, 39.15851170676095, 36.060466289520264, 36.18310546875, 38.09350572313581, 39.15311990465437, 40.63127619879586, 42.005282470158164, 47.1472864151001, 50.03445053100586, 47.30012246540615, 45.33285467965262, 45.593749114445274, 49.05698490142822, 46.37127685546875, 33.89313554763794, 15.40749488558088, 2.992574368204389, 4.880279200417655, 2.9469464165823798, 4.161948374339512, 3.8079585007258823, 3.1202583738735745, 0.4589026783193861, 0.19644996071500437, 0.19379663094878197, 0.10223365668207407, 0.7096123567649296, 0.9183444934231895, 2.878337949514389, 10.848255464008876, 24.66382772581918, 36.82855837685721, 38.522042819431846, 36.17980160032, 19.6223555292402, 3.3376314640045166, 0.2681932459984507, 0.11946185758071286, 0.22626393448029244, 0.10411211981305055, 0.10643213282206229, 0.1185404070253883, 0.17973188922873565, 0.12663534336856433, 0.1232203987560102, 0.1363655762480838, 0.21720266927565846, 0.2410169956939561, 0.20320940443447658, 0.2662378709231104, 0.17174127085932664, 0.11695093874420438, 0.19610215723514557, 0.10912082783345665, 0.12742412675704273, 0.21699795526053223, 0.18281431097005094, 0.11228171536432845, 0.045711384287902286, 0.11657583101519517, 0.12068768537470273], [0.04183909689475383, 0.017308200177337443, 0.036682729476264546, 0.042294329431440146, 0.03480089741892048, 0.024094422281320606, 0.037610039181475124, 0.0887776015858565, 0.004781419993378222, 0.04009105837238686, 0.03412702732852527, 0.0315356274534549, 0.02976541101400341, 0.013386700335623962, 0.04419905526031341, 0.04669709889484303, 0.07171866803296975, 0.07712411547877959, 0.024647430017856613, 0.02891063330961125, 0.017375782265194824, 0.0034498808963689953, 0.016048162344044874, 0.022580476644049798, 0.040408731504742584, 0.07935430402202265, 0.06753037670361144, 0.00907512428238988, 0.03137918781223042, 0.074999316994633, 0.06412826318825994, 1.3470329301697868, 10.127945269857134, 37.20664460318429, 40.00134556634085, 30.50357845851353, 12.988204223769051, 13.647382429667882, 7.144202062061854, 1.31079221197537, 0.08035779624645199, 0.16680902695017202, 0.3393303416669369, 0.09562568912016493, 0.05488241270982793, 0.11203907802700996, 0.8927838621394975, 0.9196876670633043, 0.7514623339687074, 6.447511400495257, 22.222109147480555, 37.00534834180559, 52.24100385393415, 50.16417339869908, 47.87233441216605, 46.01758228029524, 44.42538867677961, 44.657823290143696, 47.69881010055542, 48.664887632642476, 49.97699587685721, 49.42881774902344, 48.83674437659127, 46.749620165143696, 47.308745179857524, 47.7753757749285, 46.122326374053955, 42.032845973968506, 39.32640102931431, 37.829838957105366, 39.25520978655134, 37.91822004318237, 39.65093748910086, 38.64000586100987, 35.93234845570156, 35.93203926086426, 33.83414534160069, 33.861764430999756, 35.17120804105486, 37.4312972341265, 36.67516647066389, 37.53381095613752, 46.04326629638672, 46.132436003003804, 48.46667637143816, 47.47748565673828, 47.740447180611746, 45.95832109451294, 46.96952370234898, 40.007119519369944, 31.5049980027335, 43.21419606889997, 41.72483580453055, 44.747534956250874, 47.65821525028774, 47.594350882938926, 44.706658703940256, 46.06363494055611, 33.95302207129342, 32.519292558942524, 33.07673263549805, 38.80265276772635, 46.69170345578875, 47.03018147604806, 46.63271672385079, 45.48333529063633, 44.597228050231934, 42.66124105453491, 45.45421191624233, 44.09100661958967, 43.220525877816335, 43.60018934522356, 42.981980323791504, 44.122874532427105, 44.86837455204555, 40.88905436652047, 38.97867495673043, 34.32870422090803, 34.54804842812674, 35.953432764325825, 39.406409536089214, 41.34509590693882, 43.780647959027974, 44.15307835170201, 45.84153577259609, 44.93648426873343, 44.44327333995274, 41.15055676868984, 31.34042297090803, 14.166019422667366, 3.0048233909266333, 0.19988291364695343, 1.2964221430676324, 2.294804347412927, 3.7556585414069037, 1.4668346387999398, 1.452592134475708, 0.08611602083380733, 0.08784044973020043, 0.03705777952979718, 0.044667967062975676, 0.05083491400416408, 0.7660293951630592, 3.394980158124651, 14.056755525725228, 19.418405055999756, 28.891646759850637, 27.358095952442714, 16.70756537573678, 6.295159987040928, 0.45790501471076694, 0.05118899732562048, 0.05169505552787866, 0.011591966729611158, 0.0315820155000048, 0.01576043465839965, 0.048623208754829, 0.016508378720443164, 0.05568177785192217, 0.02102265184346054, 0.07014909439853259, 0.009526571441840912, 0.017444784187578728, 0.04893414742712464, 0.027480937972930924, 0.06468878061111484, 0.020298868717093552, 0.02574158809147775, 0.04868524042623384, 0.02804371152472283, 0.05050902720540762, 0.01378665432067854, 0.05905879235693386, 0.03193084017506667, 0.031551047161753686, 0.040168737061321735, 0.02832671151762562, 0.03696529859943049, 0.05276355140709451, 0.04409561598939555, 0.015258803897138153, 0.05224279613633241, 0.014456324279308319, 0.04838941951415368, 0.0784237678827984, 0.01737895611274455, 0.015581874775567224, 0.03971464785614184, 0.025830547425097654, 0.019630935808111514, 0.03855744030858789, 0.018075933713199835, 0.06691166811755725, 0.05101831184167947, 0.024295597736324583, 0.03298141933711512, 0.0816338492025222, 0.03114280996045896, 0.04765045755941953, 0.002909948317600148, 0.05488648052726473, 0.04874634589733822, 0.0360798104000943, 0.025449544923113923, 0.010727650519194347, 0.0630781827494502, 0.09263944971774306, 1.4767401644161768, 13.509355596133641, 43.229958057403564, 41.01209306716919, 36.62042161396572, 20.520570005689347, 14.951800755092076, 6.5854717918804715, 0.8130728793995721, 0.24613787233829498, 0.3534179500171116, 0.2842233915414129, 0.17157957596438272, 0.03290233268801655, 0.5821388055171285, 0.9649141430854797, 1.076357277376311, 1.7985568387167794, 6.972142951829093, 24.849782364709036, 39.729247161320274, 56.29456901550293, 52.96284178325108, 50.53110081808907, 46.82737398147583, 45.10765661512102, 45.79216534750802, 49.45354291370937, 51.21915660585676, 52.381277561187744, 50.069500718797954, 49.05229139328003, 46.65781361716134, 47.66260303769793, 48.55564110619681, 47.00379916599819, 44.45780897140503, 41.10096052714756, 39.501551219395225, 39.68778378622872, 40.49791594914028, 40.97000435420445, 40.39072956357683, 39.21601152420044, 38.161132540021626, 35.742197104862754, 35.198479720524375, 36.12272562299456, 38.96849584579468, 37.89972046443394, 39.868714877537315, 47.39175878252302, 46.44026551927839, 49.155670166015625, 48.47529213769095, 49.34483139855521, 46.37499066761562, 48.22642503465925, 41.10602576392037, 35.50575338091169, 42.67781598227364, 41.657413959503174, 46.595324993133545, 49.402077606746126, 49.61286858149937, 47.83062437602452, 46.9252393586295, 35.88337060383388, 34.26027488708496, 34.39204747336251, 40.34198447636196, 47.88624470574515, 47.35781683240618, 48.29660531452724, 46.69300971712385, 45.87979255403791, 44.34510224206107, 46.540830271584646, 46.329674516405376, 45.64943545205252, 45.79342991965157, 45.0908454486302, 45.27732467651367, 44.95506722586495, 42.1133964402335, 39.32742241450718, 35.6804449898856, 36.57565784454346, 37.590984208243235, 39.46085214614868, 42.781785351889475, 44.838132517678396, 44.82788392475673, 46.350991589682444, 45.07515294211251, 45.62730891363961, 41.27907064982823, 33.51589700153896, 16.172538450786046, 4.620836070605686, 0.8777119166084698, 3.867071168763297, 5.205176098006112, 5.215041671480451, 3.6822178193501065, 1.4003856501408984, 0.5180504673293659, 0.1359999951507364, 0.16222964839211532, 0.036676985677331686, 0.04085179451586945, 0.6542055213025638, 4.471629151276179, 13.524672031402588, 22.042103903634207, 32.784675530024934, 31.789783818381174, 23.19577237537929, 9.330349394253322, 1.0072830638715198, 0.11440104485622474, 0.04356430949909346, 0.05089488971446242, 0.024533695674368312, 0.0055671898382050646, 0.023261137173644135, 0.017242818239278028, 0.045199897805494924, 0.01798053677859051, 0.016377407891143645, 0.024535794043913484, 0.05524105578660965, 0.05310031512219991, 0.04557606404913323, 0.025297902524471283, 0.010038083369311477, 0.04169358845267977, 0.027152645767533352, 0.030828023994607583, 0.04140816269708531, 0.030219768240515674, 0.04485921555065683, 0.03998670647186892, 0.0056005071798738626, 0.017622908111661673, 0.09994565695524216, 0.10975038619445902, 0.2668412785444941, 0.08446597294615847, 0.10174419544637203, 0.11391716796372618, 0.15499004615204676, 0.1638920320464032, 0.16415049960570677, 0.09288915738995586, 0.09477828709142548, 0.10164609963872603, 0.08432263920881919, 0.06752444630754845, 0.18383326700755528, 0.1564120112785271, 0.19477952963539533, 0.15081867070070334, 0.09933335373976401, 0.1465140716837985, 0.1537944267370871, 0.09287660449211087, 0.10209209392113344, 0.08323158204023327, 0.13553882203996181, 0.2261899063097579, 0.19128411076962948, 0.1444912909397057, 0.08643415876265083, 0.17951597938580172, 0.19994931508387837, 1.9054668162550246, 18.106842245374406, 50.05166469301496, 49.491698946271626, 42.16009528296334, 23.021874598094396, 20.126570667539323, 10.077610782214574, 3.6415439333234514, 0.8905360113297189, 0.9468592490468706, 1.0469462041343962, 0.39024779945611954, 0.17853392208261148, 2.0579209327697754, 6.333739859717233, 1.988920543875013, 1.775046305997031, 8.023251669747488, 26.179382698876516, 39.02686766215733, 59.35034506661551, 54.501527309417725, 52.42714262008667, 48.89386204310826, 47.67929955891201, 47.91519090107509, 51.098344802856445, 52.83494281768799, 52.94721181052071, 51.54581921441214, 49.317809854234966, 47.429383277893066, 47.89747994286673, 50.46465172086443, 49.5567410332816, 45.81220742634365, 42.226669447762625, 42.01421437944685, 42.25763756888253, 41.04750108718872, 43.1918854032244, 42.28012541362217, 40.027922425951274, 39.55161993844168, 37.50320414134434, 36.62484414236886, 37.63799571990967, 40.58252763748169, 40.050820214407786, 41.257381847926546, 48.76713037490845, 49.212430000305176, 50.78366436277117, 49.583957127162385, 49.665883336748394, 47.59588990892683, 48.69871841158186, 42.91009773526873, 38.249756813049316, 43.4544335092817, 43.592223235539024, 46.138411453792024, 51.869990893772666, 50.09059892381941, 49.59353869301932, 49.71281147003174, 38.26308693204607, 36.27075004577637, 36.285678250449045, 41.69774825232369, 50.44856316702706, 49.5138498033796, 47.6054367337908, 48.332256521497456, 47.807153361184255, 45.86681331907, 48.67645985739571, 49.485480308532715, 47.62677812576294, 47.361270087105886, 46.41472741535732, 47.29366064071655, 47.89047268458775, 45.5156374658857, 41.866547788892476, 37.39906106676374, 38.426164627075195, 40.715095792497905, 40.772772789001465, 44.490107672555105, 46.2746239389692, 47.44885560444423, 47.38363981246948, 45.23958206176758, 45.3948951448713, 43.70424904142107, 34.05386822564261, 16.74747235434396, 3.7445127623421803, 1.1029393481356757, 3.9421017255101884, 7.788363473755973, 10.094408052308218, 5.17070825610842, 3.645221701690129, 0.6470546307308334, 0.2101544410522495, 0.2876396525119032, 0.16660115096185887, 0.16336964150624617, 0.8468897619417736, 5.725015563624246, 19.109022617340088, 29.013875995363506, 39.352755546569824, 39.191258566720144, 25.68026580129351, 9.609783359936305, 1.0234954910618919, 0.1643936187028885, 0.15657806236829075, 0.14975221721189363, 0.21108426472970418, 0.129496481269598, 0.20344347187450953, 0.10347530791269881, 0.12971283894564423, 0.07521144061216287, 0.13165239058434963, 0.11602385634822504, 0.18350911725844654, 0.10560352621333939, 0.17515483126044273, 0.1332754192075559, 0.1271788092064006, 0.0641893313399383, 0.11447442163314138, 0.16651789471507072, 0.14650033813502106, 0.07686322554945946, 0.22149045419480118, 0.11455841069774968, 0.0966964920184442, 0.16314966045320034], [0.06179377702730043, 0.03506810790193932, 0.02942406718752214, 0.015426108580348747, 0.060890999755689075, 0.07847513976906027, 0.012430178849691791, 0.025081208973590816, 0.028810451006782905, 0.07268579756574971, 0.007344077973227415, 0.04527535429224372, 0.017091543945883, 0.032396260915058, 0.037913402010287554, 0.036272324355585236, 0.1024134141792144, 0.015251297603494354, 0.05438568436407617, 0.01876224983217461, 0.06635592079588346, 0.028389789829296724, 0.0324349679451968, 0.04249941324815154, 0.03544964475025024, 0.07761881500482559, 0.013154390301289303, 0.0386293277011386, 0.07570597728980438, 0.0398280785552093, 0.016729491230632578, 0.22504721262625285, 5.992271942751748, 26.268819911139353, 32.80632264273507, 33.88796261378697, 22.74048818860735, 21.66856701033456, 11.979707939284188, 2.061350303036826, 0.7898196471588952, 0.06859848581786666, 0.2319876216351986, 0.16505954654089042, 0.10101806119616542, 0.13157448119350842, 0.43847956135869026, 1.0802760613816125, 1.2897331991365977, 0.707491853407451, 9.105179991040911, 26.08111606325422, 42.24853195462908, 50.74270125797817, 50.75484323501587, 49.20068407058716, 49.08077900750296, 47.30579914365496, 47.9591452053615, 46.60921444211687, 47.552401133946006, 49.059326444353374, 48.12184769766671, 48.59651735850743, 47.14241920198713, 47.03634105409895, 45.003940854753765, 44.01839794431414, 44.86954184940883, 40.15888902119228, 40.297474316188264, 39.295002119881765, 38.715181895664756, 36.20486722673689, 36.61317811693464, 34.04663167681013, 35.78519255774361, 33.94316257749285, 34.72482797077724, 34.754913670676096, 37.043344565800254, 33.91094378062657, 41.203144209725515, 45.312406131199424, 46.56835903440203, 46.86730180467878, 47.59157855170113, 45.27393395560128, 49.529135840279714, 43.5794871875218, 31.927799361092703, 45.82583284378052, 42.39456919261387, 49.131813526153564, 45.22426128387451, 45.76550510951451, 45.23817157745361, 40.77991901125227, 30.608881882258824, 33.56375271933419, 33.5775796345302, 39.61597762789045, 46.053400244031636, 45.70073400224958, 46.16743407930647, 44.752204145704, 42.58419248035976, 43.88462080274309, 43.93131617137364, 44.83689226422991, 46.81344631740025, 45.59058420998709, 44.9702525138855, 45.5811242376055, 45.18511860711234, 44.19472585405622, 41.28979172025408, 37.194457462855745, 35.61772360120501, 36.15208523614066, 38.682487147195, 40.48265423093523, 44.48981932231358, 44.285264355795725, 45.29035949707031, 45.39304344994681, 43.03565863200596, 29.842575481959752, 16.37000104359218, 4.019233678068433, 0.7247613838740757, 0.2992332646889346, 4.25188672542572, 2.262736890997205, 4.199309272425515, 2.503339546067374, 0.6360380447336605, 0.4994696815099035, 0.06490187453372137, 0.15747608989477158, 0.046899180194096904, 0.1254180786865098, 1.1471491072859084, 8.281605669430324, 13.808182852608816, 20.11579748562404, 28.46018968309675, 25.6719331741333, 13.37763512134552, 3.765702162470136, 0.15987796815378325, 0.10711057963115828, 0.0532598149563585, 0.014280342829546757, 0.032704967207142284, 0.019454196095466614, 0.04525058437138796, 0.06821539851703814, 0.05833901597985199, 0.029660835196929317, 0.007295728112304849, 0.060348911343940666, 0.04041729122400284, 0.03304305745820914, 0.01267589079881353, 0.022112714958244135, 0.0614065710189087, 0.043304742713059695, 0.04353057273796626, 0.07142715581825801, 0.04565592083547797, 0.037993849122098515, 0.021406414286632622, 0.016744251063625728, 0.026465827532644783, 0.06707571752901588, 0.05463023517014725, 0.019897377850221734, 0.02707906543011112, 0.045649461182100434, 0.023613152659631202, 0.06792900245636702, 0.022066944378561208, 0.008164061250032058, 0.03603482013568282, 0.06810370486761842, 0.04106356190251453, 0.0640722569078207, 0.004817798800234283, 0.03109495627826878, 0.028938422711299996, 0.030324958131781647, 0.06031735268022333, 0.05779987241008452, 0.054083536112947125, 0.014133847967189337, 0.020031641270699244, 0.020973264672128216, 0.01397669840870159, 0.011406162637285888, 0.08919817794646535, 0.022854923703042523, 0.012605543680755156, 0.03914022385807974, 0.03624374106792467, 0.023686617646100264, 0.029878458340785334, 0.41579309584839, 8.22538605758122, 30.388040338243755, 38.57666260855538, 38.18590981619698, 22.50699050085885, 22.648078884397233, 12.96840706893376, 3.4522889001028876, 0.7616062153662954, 0.09629120983715568, 0.19676374244902814, 0.1581225437777383, 0.11536271896745477, 0.14423583607588494, 0.375294950391565, 1.0028777973992484, 1.3768422220434462, 1.7109310435397285, 9.895059023584638, 27.129076378686086, 43.594429288591655, 52.11025612694876, 52.34816939490182, 50.7189279964992, 50.40408427374703, 48.224291937691824, 49.36741304397583, 49.8179794039045, 49.305977072034565, 50.3367805480957, 50.221565519060405, 47.99328865323748, 47.15301867893764, 49.37231499808175, 47.28006649017334, 45.47704369681222, 45.57931770597185, 40.91437360218593, 41.46997935431344, 40.107065882001606, 40.33737087249756, 38.79227563313076, 37.618638038635254, 35.98389714104788, 36.631111417497905, 35.418786253247944, 36.07129853112357, 35.86526359830584, 38.721939018794465, 36.58433267048427, 44.41127341134207, 46.41771166665213, 46.56426307133266, 47.959833077022004, 48.70909554617745, 47.873772689274375, 50.47298608507429, 44.74538796288626, 36.007607868739534, 45.173445633479524, 44.25808300290789, 49.03902728216988, 47.74221549715315, 47.119500568934846, 46.53394113268171, 42.98170934404646, 31.851136411939347, 33.94869681767055, 34.42521469933646, 41.21180166516985, 47.420420101710725, 47.70155463899885, 48.18571553911482, 47.411974566323416, 44.33811930247715, 45.88785941260201, 46.34546777180263, 46.149869033268516, 47.486535685403005, 46.34362302507673, 46.15538590294974, 47.215430872780935, 48.04731089728219, 45.03354712894985, 43.20240497589111, 39.09503296443394, 36.57651942116873, 36.634773118155344, 39.643412590026855, 41.783454281943186, 45.4639185496739, 45.33281299046108, 48.538736139025005, 45.326952184949604, 44.907736097063335, 32.050118923187256, 19.809373242514475, 5.068714780466897, 0.8616184773189681, 2.661566747086389, 5.918112082140786, 5.191344840185983, 3.609271070786885, 2.096441311495645, 1.5596262024981635, 1.515935712627002, 0.13411814613001688, 0.19789806301040308, 0.1780822891741991, 0.0807447104847857, 1.283665576151439, 8.029782976422991, 16.990563767296926, 25.750774383544922, 33.13847432817732, 30.48182017462594, 16.199592999049596, 4.873741379805973, 0.2551442304892199, 0.03818802548838513, 0.023373909693743502, 0.042139372389231405, 0.05982569299106087, 0.008607881675873483, 0.047584911076618094, 0.025712604468156184, 0.04798900242894888, 0.02946832463411348, 0.04719310799347503, 0.023632126195090156, 0.02257428501200463, 0.020121333422139287, 0.05897390762610095, 0.05515993692513023, 0.01029114130817886, 0.0699606787945543, 0.007502479428824569, 0.05382855283096433, 0.019354597332754304, 0.04999267901959164, 0.017403568274208477, 0.005981552938465029, 0.07258059749645845, 0.027529746693159853, 0.12720266649765627, 0.14588215202093124, 0.09447213209101132, 0.12482126642550741, 0.1137216684541532, 0.16368264971034868, 0.0941641925434981, 0.0453375623827534, 0.14166254630046232, 0.1539666253541197, 0.09872187833700861, 0.1563977756138359, 0.09513956627675466, 0.1556231736072472, 0.1080480639689735, 0.12784613482654095, 0.1859814003109932, 0.17308042757213116, 0.18898972602827208, 0.1051820677572063, 0.09475943738860743, 0.06468376623732702, 0.08725509114031281, 0.10560756349670035, 0.2350996003619262, 0.1471807730517217, 0.11281391752085515, 0.12890869352434361, 0.1779354406254632, 0.14973543025553226, 0.140338643054877, 0.4735069232327597, 8.707114219665527, 36.253511565072195, 44.90949746540615, 45.830828598567415, 33.000479630061555, 30.84680904660906, 17.905700581414358, 7.521155732018607, 2.9234484774725775, 0.18965291258479866, 0.88723295714174, 0.8999118996517999, 0.33160655040826115, 1.0635020243270057, 1.3142348272459847, 3.471185177564621, 3.6109221364770616, 1.4582455796854836, 11.198999660355703, 28.62502006122044, 45.01247671672276, 54.35852643421718, 56.19405290058681, 52.148040430886404, 54.03434433255877, 50.22679056440081, 51.93525879723685, 51.8965608051845, 50.14156743458339, 52.6566972051348, 50.31777375085013, 50.42373725346157, 47.00953837803432, 51.642430441720144, 48.778653962271555, 48.10152074268886, 47.45845454079764, 44.108787059783936, 43.46203136444092, 41.937530585697715, 42.40259436198643, 40.2737774848938, 39.18403591428484, 37.417036056518555, 38.38618469238281, 36.52162517820086, 37.891493797302246, 36.62677921567644, 40.68013245718819, 38.19782945087978, 44.95311825616019, 47.838166645595, 48.483734198978965, 51.49739721843174, 50.34830066135952, 48.41907773699079, 50.45888124193464, 45.80595752171108, 39.3912034034729, 44.53068862642561, 46.325842584882466, 51.077489784785676, 49.50968435832432, 49.05164173671177, 49.042570863451274, 43.8992919240679, 33.02610458646502, 36.01503896713257, 37.0373204776219, 43.20896407536098, 49.24024363926479, 49.107192584446494, 51.01078013011387, 47.9276351247515, 45.17465114593506, 47.19227600097656, 47.76737492425101, 48.40894378934588, 48.60742255619594, 48.7115968976702, 47.58143765585763, 48.15530327388218, 49.791333062308176, 48.86192464828491, 46.08340603964669, 41.28448677062988, 39.20601306642805, 39.111792019435335, 42.50524009977068, 43.761714117867605, 47.89871324811663, 47.20165606907436, 46.955585615975515, 45.72440651484898, 45.656470503125874, 33.11517701830183, 19.074043648583547, 5.235518881252833, 1.7095723450183868, 1.7868588949952806, 8.902033771787371, 5.686773547104426, 7.6961539302553446, 3.9146867394447327, 2.6947954211916243, 2.6015297515051703, 0.2373725026845932, 0.28456814161368776, 0.33005465939641, 0.3756742243255888, 1.6775933695690972, 11.385762027331761, 20.059056758880615, 30.880330630711146, 37.411901337759836, 35.402312074388774, 18.680944102151052, 5.414091927664621, 0.29822526020663126, 0.16323328310889856, 0.1006955670725022, 0.08597010187804699, 0.25207475519606043, 0.0805208549967834, 0.10661430590386901, 0.1720432596547263, 0.15896400862506457, 0.13168857007154397, 0.10845833338264908, 0.13354478403925896, 0.10183259498860155, 0.12072743395609514, 0.12916441980217183, 0.10461842228791543, 0.09535177810383694, 0.18182333771671566, 0.14580049711678708, 0.1672796859805073, 0.16988675322915825, 0.07878442960126059, 0.10436012436236654, 0.12806099972554616, 0.2026695619736399, 0.14054704830050468], [0.03284923732280731, 0.10177441061075244, 0.02895846324307578, 0.016828715102747083, 0.062449214713914056, 0.028327807351680737, 0.01467986764120204, 0.04969832035047667, 0.03589076715122376, 0.07774720061570406, 0.02832271664270333, 0.04033255577087402, 0.05644793209752866, 0.029303471158657755, 0.023477586451917887, 0.029607173254979507, 0.0440689834899136, 0.014997952983581593, 0.01867274258152715, 0.029594756064138243, 0.022524424562496797, 0.02388263284228742, 0.003620128089096397, 0.07523383905312844, 0.02862880378961563, 0.00407330593692937, 0.012067054897280676, 0.012271947876018072, 0.06859993109745638, 0.06396987954420702, 0.01562770133438919, 0.08440537298364298, 1.6338673787457603, 16.51972256387983, 31.757346153259277, 33.90751484462193, 21.143300567354473, 16.56862919671195, 13.822168707847595, 5.277604988643101, 0.8592504986694881, 0.30415324068495203, 0.03073141417865242, 0.06299225307468857, 0.05252048320003918, 0.1280470083334616, 0.014036212715187242, 0.655737327677863, 1.3616699618952615, 0.6240960998194558, 1.4858489270721162, 11.685304079736982, 30.308198588235037, 44.68728365216936, 51.237287930079866, 50.395169734954834, 47.2215313911438, 47.835116386413574, 47.10807773045131, 46.00474548339844, 47.946311882564, 47.915826661246165, 47.81943082809448, 49.25590140478951, 48.076448168073384, 46.743762833731516, 48.11115094593593, 46.172860622406006, 44.67460666384016, 44.272073200770784, 42.65291363852364, 43.922867161887034, 42.99101298195975, 41.022685595921104, 39.523281710488455, 37.72815554482596, 35.81750862939017, 34.4204933983939, 34.45110021318708, 33.58870717457363, 33.44254486901419, 33.60968031202044, 33.27891479219709, 39.17802919660296, 44.11001689093453, 43.05231693812779, 45.211254256112234, 45.413036891392295, 48.48307064601353, 42.77442026138306, 32.40257324491228, 41.42783505575997, 45.704319272722515, 45.89228541510445, 44.84331587382725, 45.77261311667306, 40.805623871939524, 34.60036488941738, 32.39032704489571, 32.87628752844674, 31.979431424822124, 35.941033703940256, 45.42599180766514, 45.78285476139614, 47.09837109701974, 46.112129892621724, 41.19349316188267, 41.28665460859026, 43.52613544464111, 44.996721676417756, 44.81448432377407, 45.927550997052876, 45.40886102403913, 44.496555600847515, 46.583756242479595, 45.442459038325715, 43.35281957898821, 40.795993668692454, 36.86050271987915, 35.75032649721418, 38.91445623125349, 42.102449553353445, 43.662695339747835, 45.10331399100167, 47.09726285934448, 43.30385562351772, 32.825058460235596, 15.24718257359096, 7.051221702780042, 0.28532601094671656, 1.793690059866224, 3.88773250579834, 5.105181097984314, 5.666585556098393, 3.4280149340629578, 2.822654868875231, 1.4034581652709415, 0.8102722668222019, 0.3598150967487267, 0.16854659228452615, 0.19424409765217984, 0.6419219747185707, 5.155614597456796, 11.6150986126491, 20.578794172831945, 25.63331856046404, 25.097608975001744, 18.78349777630397, 8.02195930480957, 1.5135084028754915, 0.040048500656017234, 0.05669984840122717, 0.06517107651701995, 0.04203551921195217, 0.01843304160450186, 0.050457892806402276, 0.02930451270991138, 0.13543767961008207, 0.03139857695038829, 0.04269267698483808, 0.023520876986107657, 0.07876742551369326, 0.03875891771167517, 0.03938665759882756, 0.016929116233118942, 0.013348034865755056, 0.0432165331606354, 0.047906940403793535, 0.009652919751325888, 0.04202382466090577, 0.03213802405766078, 0.04034896953297513, 0.046005692066890855, 0.039991629243429215, 0.0482382011998977, 0.014267031668818422, 0.030832353048026562, 0.015883805895490304, 0.008960459497757256, 0.02779806827727173, 0.02377524958657367, 0.03688626962580851, 0.027105569007939527, 0.04273037639047418, 0.03668606108320611, 0.033724381255784204, 0.023690276646188328, 0.04177460892658148, 0.03169940205823098, 0.003508023077821625, 0.0038617103044608875, 0.013416964693793228, 0.06693078923438277, 0.03192782747958388, 0.01237024215515703, 0.026888766891456077, 0.03399871296382376, 0.028359808759497743, 0.0391552568014179, 0.015635967587253878, 0.01870785846507975, 0.04623492494491594, 0.012298891653439828, 0.037857541614877324, 0.01647676577392433, 0.015516160355348672, 0.0766093720282827, 0.0781913764242615, 2.3336491201605116, 20.78746768406459, 37.66316556930542, 39.699776376996724, 25.899448462894984, 20.00931113106864, 16.520580666405813, 3.4681420837129866, 1.637221621615546, 0.4168697680745806, 0.01868456435788955, 0.055385095200368335, 0.07162999029138259, 0.10439477036041872, 0.19517757184803486, 0.2783407914851393, 0.27135155509625164, 0.8584825598767826, 2.292024850845337, 13.12335102898734, 32.994931493486675, 46.70835828781128, 52.55049746377127, 49.8374274117606, 49.03651550837925, 50.242927755628315, 48.58252716064453, 48.548828397478374, 49.55693905694144, 48.792817865099224, 49.35793570109776, 49.89219658715384, 47.64919301441738, 47.013929639543804, 49.521871498652864, 48.06628295353481, 46.033246994018555, 46.276711872645784, 43.65850905009678, 44.28817565100533, 44.85225125721523, 43.09086206981114, 40.77079255240304, 39.97311156136649, 37.807858330862864, 35.92113058907645, 35.785897799900596, 35.76781511306763, 34.73840822492327, 34.81383439472744, 34.67923389162336, 42.12508678436279, 45.43762656620571, 45.18421186719622, 47.20888566970825, 46.40946415492466, 50.091880866459434, 43.96573754719326, 36.359551497868125, 44.38283790860857, 47.53784465789795, 47.984665938786094, 46.113589014325825, 46.477236883980886, 42.161008971078054, 36.61088868549892, 34.579961504255024, 33.67572293962751, 33.864206722804475, 37.752773012433735, 46.84763145446777, 46.632129601069856, 47.51878227506365, 47.53097288949149, 42.8868282181876, 44.16450466428484, 44.18787840434483, 46.76527098246983, 45.08336918694632, 47.398192814418245, 46.301075731004985, 46.009379931858604, 46.32640191486904, 46.87350307192121, 44.423255579812185, 41.779174191611155, 38.4102532523019, 38.12252834865025, 40.70460401262556, 43.705940927777974, 44.432944842747276, 46.00311960492815, 47.545626640319824, 45.09537220001221, 34.391529832567485, 16.711030789784022, 6.379891097545624, 1.2523733867066247, 4.158311860901969, 5.305189337049212, 5.570302631173815, 4.203088223934174, 5.790633482592447, 4.585964798927307, 3.79289220060621, 2.3572890630790164, 0.39897435690675465, 0.40618376433849335, 0.1737421213516167, 0.5921592478241239, 4.457141722951617, 14.608203649520874, 20.928830521447317, 30.05917862483433, 30.508657591683523, 22.75838848522731, 11.670064943177358, 2.3662207552364896, 0.048432452205036364, 0.03889502165839076, 0.020535287280966128, 0.04633786888527019, 0.043409698509744236, 0.039692215488425324, 0.023008259046556692, 0.061983427565012655, 0.01264940672886691, 0.005774579825811088, 0.05573109716975263, 0.06791832231517349, 0.07731492631137371, 0.021420003646718602, 0.018769610240789394, 0.06078031033809696, 0.05188750162986772, 0.029816046689770052, 0.03315211160640631, 0.007004545835245932, 0.035835066211542914, 0.03714944621814149, 0.02824331447482109, 0.02968819033620613, 0.0689208781612771, 0.08272251792784248, 0.1747754623315164, 0.17101246996649674, 0.11554923467338085, 0.11866529818092074, 0.1464424998100315, 0.2076207912926163, 0.1142679298562663, 0.22201338756297315, 0.10937261182282652, 0.21693377941846848, 0.19570332792188438, 0.15636830005262578, 0.16502870033894265, 0.06762820109724998, 0.10757068744195358, 0.12328148047838892, 0.14729264990559646, 0.11402300585593496, 0.08621481553252254, 0.11919965807880674, 0.10519700231296675, 0.06706725619733334, 0.08140464685857296, 0.11861705434109483, 0.12587220860379084, 0.10049988435847418, 0.16672909552497522, 0.08865915651300124, 0.12524783425033092, 0.14464686544878141, 0.10423100593366794, 0.19747439931545938, 2.5569620515619005, 23.070180211748394, 44.0963636807033, 48.01353570393154, 34.38884435381208, 28.00712197167533, 19.714526857648575, 8.511431234223501, 3.2607281506061554, 1.3679892399481364, 0.14028685726225376, 0.2865620574780873, 0.2786283274846417, 0.2481473945081234, 0.613226945911135, 2.0703325867652893, 3.7421125939914157, 2.148213424852916, 2.66710033587047, 14.263282912118093, 33.13863066264561, 46.77309117998396, 54.62265872955322, 52.52874265398298, 50.711903367723735, 51.62845761435372, 50.91907780511038, 50.0348778452192, 51.76309980664934, 51.55953843252999, 51.88437366485596, 52.590623310634065, 49.90161487034389, 47.04063156672886, 50.439005919865195, 50.47297913687569, 49.477392605372835, 48.32886580058506, 45.57895639964512, 47.22420644760132, 47.14970438820975, 45.594746180943076, 43.53440727506365, 42.751772608075825, 38.8693276814052, 37.20543214253017, 38.43711846215384, 38.08148881367275, 36.51325259889875, 36.63488776343209, 34.91323184967041, 42.901940550122944, 48.19501570292881, 46.37787069593157, 49.63046489443098, 48.19859055110386, 50.92179455075945, 46.765482902526855, 39.20500210353306, 47.0115498815264, 47.94121190479824, 50.06953545979091, 47.9661420413426, 48.31486518042428, 43.54070929118565, 38.48115267072405, 35.555207184382844, 35.13905872617449, 35.633131231580464, 38.62981285367693, 49.373558725629536, 48.72165788922991, 50.12338399887085, 49.35334294182913, 43.94719975335257, 45.22903817040579, 46.264691489083425, 48.83879409517561, 46.869747570582796, 49.42885249001639, 47.15402964183262, 46.8787385395595, 47.83634969166347, 49.04091371808733, 46.31567737034389, 44.706432887486045, 40.01646137237549, 38.88065324510847, 42.73252957207816, 45.30894940240042, 47.26053162983486, 47.9216423034668, 49.11452988215855, 45.61468751089913, 35.69122164590018, 17.720223631177628, 9.529241578919546, 0.929469210760934, 4.661066140447344, 10.352636984416417, 12.895034091813223, 12.171495590891157, 8.409578459603445, 5.376196452549525, 3.6280698563371385, 3.9734155195099965, 1.2645846285990305, 1.1882886311837604, 0.8530562881912503, 0.9756780969245094, 6.296043276786804, 16.918203490121023, 27.801587309156144, 35.6188839503697, 36.33816146850586, 25.840081317084177, 12.509449890681676, 1.9606038119111742, 0.1470958883208888, 0.12845695205032825, 0.10778214609516518, 0.11062482105834143, 0.1317908660109554, 0.15643106454185077, 0.12538453191518784, 0.23934858664870262, 0.09975880876715694, 0.14955401713294642, 0.0964953742389168, 0.15337406072233403, 0.18506471307149955, 0.16502570121416024, 0.07796476608408348, 0.1182278466543981, 0.2006574070879391, 0.14743510154741152, 0.09114275074430875, 0.10739521150078092, 0.1574054001165288, 0.16745970132095472, 0.09188799932599068, 0.13428623282483645, 0.1698370708950928, 0.13796923948185785], [0.01970498263835907, 0.03303275729662605, 0.02641845221764275, 0.012686819453457636, 0.030706301597612243, 0.04184670666498797, 0.02114924442555223, 0.055418750537293296, 0.007383450815853263, 0.08951145077922515, 0.03575170479182686, 0.023432604669194137, 0.02570095911089863, 0.017344998827736293, 0.012061747905266072, 0.020613439248076508, 0.015036225751308458, 0.044859456430588446, 0.04834605773378696, 0.02254632088754858, 0.0745382456641112, 0.010647380674657012, 0.06167032436600753, 0.10416383096682173, 0.10659120857183423, 0.06834669504314661, 0.011710919007392866, 0.06459913256445102, 0.021243715159861103, 0.04372375505045056, 0.01620024748678718, 0.0379811537318996, 0.3590814375451633, 5.851359435490199, 15.823924745832171, 37.7023777280535, 29.735062531062535, 20.252534559794835, 19.498420510973247, 14.436063766479492, 2.272883866514478, 0.2098629152668374, 0.6206292201365743, 0.08847291900643281, 0.09326758994055645, 0.11687190298523221, 0.019952556317938224, 0.07618652257536139, 0.38812596617000444, 0.8534847966262272, 0.28048498928546906, 2.3961742222309113, 12.542719602584839, 29.19984974179949, 43.63396801267351, 51.538756370544434, 52.86457341057913, 51.927591460091726, 49.006992612566265, 47.95129721505301, 46.36046893256051, 44.219218254089355, 47.99614783695766, 48.06819370814732, 50.10663884026663, 46.48982354572841, 45.868935993739534, 49.41982678004673, 46.85102564947945, 45.8441378729684, 46.285751479012625, 46.983840465545654, 45.39544405255999, 45.90804740360805, 44.618916852133616, 41.690129552568706, 38.43321704864502, 36.22603143964495, 35.115052700042725, 35.75639574868338, 34.89212669645037, 33.38298143659319, 33.06729698181152, 34.508058071136475, 37.206575121198384, 41.44032791682652, 43.02097014018467, 44.149336746760774, 47.40471717289516, 46.29503427233015, 29.634862559182302, 43.015012059892925, 46.742414883204866, 44.56134755270821, 43.024531091962544, 42.37842852728707, 34.70128747395107, 32.3320768220084, 30.958477020263672, 33.12785053253174, 32.632089614868164, 32.65451839991978, 40.52720260620117, 46.101134368351524, 44.991190910339355, 43.60507045473371, 40.541877201625276, 38.79455116816929, 39.85684388024466, 42.66937392098563, 43.35624156679426, 43.98573793683733, 44.65160812650408, 46.20206042698452, 44.81729487010411, 46.22672653198242, 44.23064456667219, 43.6299067905971, 40.87609250204903, 38.514521394457134, 38.38206441061837, 40.65927049091884, 43.08103731700352, 43.93601662772042, 43.992439474378315, 34.29004444394793, 19.0171674319676, 5.540979930332728, 0.38717425295284813, 2.1874535935265675, 1.7066930766616548, 4.889621921948024, 4.642339442457471, 5.1734983921051025, 4.053186919007983, 3.157807307583945, 3.959332389490945, 0.9773129863398415, 0.4282010586134025, 0.1967214968587671, 0.24268551330481256, 2.169990599155426, 12.75525631223406, 18.479580095836095, 18.7861294065203, 26.810907942908152, 21.715924194880895, 14.387797236442566, 3.548990671123777, 0.402959691626685, 0.0420326422234731, 0.030640232642846446, 0.010672101401723921, 0.033001856811876805, 0.04201396554708481, 0.05018893848838551, 0.06804095394909382, 0.027648446216647114, 0.035780851263552904, 0.008676480718090065, 0.04067657981067896, 0.04760787948699934, 0.014576479260410582, 0.015463293995708227, 0.02855880611709186, 0.0409471524347152, 0.003383150157917823, 0.034046831274671216, 0.07993885515523808, 0.03408760783661689, 0.09708825099681105, 0.01328165887389332, 0.03260964660772255, 0.05693997855165175, 0.027611150539347103, 0.009703066881879099, 0.0205804590534951, 0.031217859326196567, 0.016552013611154895, 0.033831691568983455, 0.022317769937217236, 0.06937358315501894, 0.00509596847197307, 0.005087558030416923, 0.008991735721273082, 0.04193867190874048, 0.056498323500688584, 0.03638791958136218, 0.04770351221252765, 0.02913537767848798, 0.008860456158540078, 0.041072030019547255, 0.0680025624377387, 0.023440618167764375, 0.04190949151026351, 0.01516742558617677, 0.03542721238253372, 0.006048661748146904, 0.10570226662925311, 0.05151725899694221, 0.03122838001166071, 0.03552579673539315, 0.03568013970341001, 0.03271763545594045, 0.07458801620772906, 0.009662789891340902, 0.08897578809410334, 0.024105058317737918, 0.7194770617144448, 8.492864779063634, 22.711264065333776, 44.273789405822754, 32.17110790525164, 24.46977322442191, 22.815997736794607, 19.005586521966116, 3.3010259653840746, 0.596808135509491, 0.4484004218663488, 0.04302798863500357, 0.07075618646506752, 0.15205463580787182, 0.06557954102754593, 0.32025783509016037, 0.43681603776557104, 1.258603315268244, 0.515327044895717, 3.9951677237238203, 13.03967821598053, 29.10008750643049, 44.89628199168614, 53.49409409931728, 52.20079115458897, 53.066144125802175, 48.646516595567974, 48.858617305755615, 47.739512647901265, 46.120106424604145, 49.29681587219238, 50.25712987354824, 50.47312157494681, 46.203842639923096, 46.948029450007844, 49.80813728060041, 48.38229397365025, 48.025160040174214, 47.56284775052752, 47.86072397232056, 46.2287415095738, 46.72361305781773, 44.901357650756836, 42.368280683244976, 39.59358358383179, 36.80636583055769, 35.42710324696132, 37.314921855926514, 35.73934486934117, 35.100423267909456, 34.68717220851353, 37.1250136920384, 39.89511455808367, 43.65722710745675, 44.13850450515747, 46.59749283109392, 49.85816083635603, 46.91439322062901, 33.38733100891113, 45.70963117054531, 48.636417388916016, 46.17336089270455, 45.06149278368269, 43.930996554238455, 37.54674155371529, 33.82654748644148, 32.37686491012573, 34.70771108354841, 35.75135135650635, 34.78078876222883, 43.3226991380964, 47.860154220036094, 47.15136500767299, 45.839284556252615, 43.17853443963187, 40.97100836890084, 42.23650114876883, 43.99564259392874, 45.97424636568342, 46.9602096421378, 45.71266753332955, 47.05022355488369, 46.12384802954537, 47.5137483051845, 45.44008622850691, 43.79652459280831, 41.45523527690342, 39.231280190604075, 39.92027398518154, 41.653092179979595, 43.88191100529262, 44.605888979775564, 45.62566566467285, 35.27322844096592, 21.970127514430455, 6.164084826196943, 1.7138675259692329, 2.378541214125497, 4.376699388027191, 8.250845125743322, 6.280795889241355, 6.805863440036774, 4.812720562730517, 6.410110550267356, 9.505976404462542, 3.124660926205771, 0.485525515462671, 0.1653562020510435, 0.17602498456835747, 2.1533922212464467, 11.790445957865034, 18.941162824630737, 26.92990800312587, 33.98680073874337, 27.686068296432495, 17.852863005229406, 4.910878198487418, 0.6329124953065599, 0.020614921847092252, 0.012379024094635887, 0.04036388712536011, 0.01653787972671645, 0.05248179652595094, 0.033080275103982, 0.1071074583700725, 0.04566086396308882, 0.022438605149675692, 0.032039558448429616, 0.024889073301372782, 0.010734157670023186, 0.012118364019053323, 0.011387070358198668, 0.020660095315958773, 0.03805731589506779, 0.02306777674571744, 0.03639504759173308, 0.03315869678876229, 0.022016054252162576, 0.09293463280690567, 0.06395210871206862, 0.036066293982522826, 0.05664863936336977, 0.024285519794960107, 0.04660132367696081, 0.10274339932948351, 0.12021338939666748, 0.13181415333279542, 0.10780835111758538, 0.14272368007472583, 0.10754849934684378, 0.12007084275994982, 0.17484992476446287, 0.08877538956169571, 0.2441428979592664, 0.09339818079024553, 0.07186092968497958, 0.20952751540711947, 0.12273608760109969, 0.08455186869416918, 0.13367846900863306, 0.10385230875441007, 0.11913350091448852, 0.16583287290164403, 0.07358364867312567, 0.17061222930039677, 0.1296756009438208, 0.30574027981076923, 0.2481403648853302, 0.15162197473858083, 0.13834119880838053, 0.11047722612108503, 0.0906465652265719, 0.18175863261733735, 0.10227377845772676, 0.1491695727620806, 0.15574315216924461, 0.7547776017870221, 9.190073949950081, 27.367795637675695, 52.41355889184134, 40.20143631526402, 33.50465134211949, 28.213990688323975, 19.215033020292008, 3.6375096355165755, 2.3417448571750095, 1.5787586101463862, 0.31014063368950573, 0.24757001549005508, 0.46533486459936413, 0.17083964709724697, 1.032358461192676, 1.4354878408568246, 3.0026668437889645, 1.4410872203963143, 3.3711584763867513, 14.428923623902456, 30.776986598968506, 46.922091824667795, 54.944023336683, 56.06299597876412, 55.14174474988665, 51.548730509621755, 49.55199888774327, 50.45172112328665, 47.45959057126726, 50.47299998147147, 51.15151241847447, 52.20323692049299, 47.635136808667866, 47.95469488416399, 51.63756670270647, 50.4190229007176, 49.50937168938773, 49.608234133039204, 49.5354448046003, 49.005662032536094, 49.93995155606951, 47.96474545342581, 45.64881706237793, 42.15638494491577, 39.53940847941807, 38.322104930877686, 40.001227446964805, 37.542346818106516, 37.84489917755127, 36.38560724258423, 38.76274926321847, 40.09598003114973, 44.86767973218645, 46.47070210320609, 48.12699283872332, 51.851487840924946, 49.13540574482509, 37.54632118770054, 47.39683444159371, 49.43033593041556, 48.289584159851074, 46.92005600248064, 46.23196547372, 38.503022125789094, 35.353476660592214, 34.117322649274556, 35.96148572649275, 37.4000928742545, 35.83922522408621, 45.07254389354161, 49.78868579864502, 49.38507536479405, 47.28800480706351, 44.40000690732683, 42.14808879579817, 41.936158316476, 46.704383918217246, 47.356031145368306, 48.2444486618042, 47.294039317539756, 48.444699219294954, 46.38980075291225, 48.27997132710048, 48.0746624810355, 46.29746266773769, 44.560809067317415, 42.04916729245867, 41.26663337435041, 44.65949433190482, 45.928662708827424, 46.48649883270264, 44.77444880349295, 35.59689290182931, 21.667509147099086, 6.885508469172886, 1.4261404510055269, 4.692729081426348, 4.174066032682147, 9.61157078402383, 10.05020100729806, 9.759686401912145, 8.869740281786237, 7.636167526245117, 11.280147671699524, 7.087451781545367, 0.9455711181674684, 0.4456298276782036, 0.8554278495056289, 3.5722599710736955, 14.502313102994647, 23.77635169029236, 28.57033600125994, 37.96910864966256, 32.1623740196228, 19.69726405824934, 5.755600665296827, 0.5438324095947402, 0.08538762706198863, 0.1314925548753568, 0.07328343763947487, 0.12192451900669507, 0.18107768201402255, 0.12815849163702556, 0.18535820660846575, 0.09631181016032185, 0.08331314194947481, 0.11993790417909622, 0.10629064469997372, 0.09435728325375489, 0.0888242915804897, 0.12505308112927846, 0.1414338257163763, 0.1847205058272396, 0.08375792843954903, 0.08997511411351816, 0.1985918650669711, 0.14674824768943445, 0.2786050944456032, 0.12383243734283106, 0.1322282768253769, 0.13416370297116892, 0.2187262246651309, 0.16747238992580346], [0.02760885369830898, 0.09437168176685061, 0.01142058744361358, 0.0432317968058799, 0.05145759202007737, 0.036839141976088285, 0.043210965780807395, 0.02613788646911936, 0.04390479497877615, 0.044310762480433495, 0.02808253899482744, 0.045001819862851074, 0.029749099032155106, 0.040236641453312974, 0.00839062494092754, 0.043715018912085464, 0.016262397901820283, 0.012949827260204723, 0.03619722070704613, 0.06253095782761063, 0.00341140541630531, 0.054633108765951226, 0.02659185862700854, 0.05719210859388113, 0.0066501529321872765, 0.029120151352669512, 0.020610049965658357, 0.017647455812298825, 0.08541706191109759, 0.010928555408359637, 0.005101698700205556, 0.013814365690840142, 0.09031168105346815, 1.3781133081231798, 11.7323477268219, 25.133112532751902, 34.83832679476057, 26.968166521617345, 17.647863354001725, 10.186632360730853, 6.4921422856194635, 0.5060223756091935, 0.19400970451533794, 0.17912534677556582, 0.0797724173005138, 0.07336465828120708, 0.037288474650787454, 0.031417450401932, 0.17406788601406983, 0.2275476955941745, 0.7639048748782703, 0.4474730002028601, 2.810249294553484, 11.645992040634155, 26.782352583748953, 36.43861852373396, 48.34430122375488, 48.919407095227925, 51.64847190039498, 51.1113726752145, 49.143055711473735, 45.230789116450715, 45.43332215717861, 49.21788781029837, 48.19021102360317, 47.801751136779785, 46.6008175441197, 46.660763127463206, 46.79246275765555, 46.8778144291469, 48.55471352168492, 48.02537890842983, 47.58449486323765, 46.89082840510777, 45.52810253415789, 43.859899112156455, 42.42560679571969, 38.4429931640625, 38.02972820826939, 34.61121450151716, 34.05067900248936, 33.509563718523296, 32.99860709054129, 33.24576146262032, 34.63883706501552, 37.16524723597935, 42.512379373822895, 46.470375537872314, 45.899362155369346, 45.98741667611258, 33.77720832824707, 48.328334263392854, 45.63386106491089, 43.171235357012065, 44.72992822102138, 38.54283530371529, 34.67698614937918, 34.15873738697597, 35.953286852155415, 39.78639609473092, 34.04925462177822, 32.66889769690377, 33.87937811442784, 40.08904572895595, 42.35961627960205, 41.26784930910383, 37.90228087561471, 37.62146942956107, 37.72249971117292, 37.69909470421927, 40.6606114932469, 42.524166992732454, 43.06234318869454, 43.34312684195382, 47.97246490206037, 41.616940702710835, 44.60433605739048, 42.80611446925572, 42.56918089730399, 41.0083132471357, 41.940223012651714, 41.08616086414882, 43.499579429626465, 44.361152580806184, 38.26212460654122, 24.24250112261091, 7.459258573395865, 0.5420961199062211, 0.2952684217265674, 2.087019988468715, 7.207298219203949, 4.869315377303532, 3.619048271860395, 1.9592410964625222, 4.530118652752467, 7.5078638281141, 10.493945973260061, 1.7725364863872528, 0.2908951821071761, 0.09865876779492412, 0.45183519327214783, 3.4474462228161946, 16.22795728274754, 35.617806979588096, 24.346934284482682, 26.3863000529153, 22.134447199957712, 8.68138677733285, 2.0406579162393297, 0.02416500519029796, 0.07179251978439943, 0.02975995559245348, 0.0489227175047355, 0.04881655730839286, 0.05376933029453669, 0.02302520885132253, 0.02783014771661588, 0.14770556560584477, 0.11134422424116305, 0.038432223456246514, 0.01823785082836236, 0.05694283518408026, 0.05471726407163909, 0.053677151312253306, 0.04622422444767185, 0.035130142966019254, 0.018630899023264647, 0.04403837138254728, 0.06507397137050118, 0.025518462028620497, 0.021658350946381688, 0.026231347882587994, 0.053777944296598434, 0.050769543940467496, 0.07468592881092004, 0.025290531937831214, 0.04113916766696742, 0.06583170499652624, 0.009023854176380804, 0.019808477888415967, 0.04390023183077574, 0.006117426607358668, 0.01244363165460527, 0.053594963758119514, 0.04721981852448412, 0.030936959399176494, 0.03699467238038778, 0.08396183499800307, 0.029954586577202593, 0.005471870935122881, 0.04046827634530408, 0.09027826998914991, 0.027941301930695772, 0.03410862885149462, 0.033958245135311566, 0.008312232093885541, 0.018190346591706787, 0.021613632095977664, 0.014412859022351248, 0.04769405682704278, 0.017195850045287182, 0.0477938523649105, 0.03836819349921175, 0.015377187901841742, 0.02421898434736899, 0.03322333403463874, 0.0006100962803299938, 0.030448926479688714, 0.040852272883057594, 2.384912929364613, 13.387898479189191, 34.93336425508772, 41.46546302522932, 32.213405064174104, 22.44134565762111, 13.14919137954712, 8.15710871560233, 1.0906789260251182, 0.6253823850836072, 0.35204234240310533, 0.10103053945515837, 0.10493511493716921, 0.033398738729634454, 0.12338639556297235, 0.24187965797526495, 1.1530003590243203, 1.134772302848952, 0.9476735996348518, 3.7688405769211903, 13.281438180378505, 29.344914231981548, 38.47774110521589, 51.367538860866, 50.39770235334124, 52.70221832820347, 51.492314611162456, 49.90217072623116, 46.80254806791033, 47.73837661743164, 50.17258766719273, 51.28961133956909, 48.67079707554409, 47.14607742854527, 46.85140780040196, 46.88399485179356, 47.77187040873936, 50.12131690979004, 49.49616663796561, 49.113435540880474, 47.628977230616975, 46.9882629939488, 44.090846811022075, 43.616639205387656, 39.409463269369944, 38.518596512930735, 37.835178647722515, 36.7818386895316, 35.65647370474679, 34.40577711377825, 34.93840517316546, 35.68173735482352, 39.19564288003104, 43.5588058744158, 47.25576169150216, 47.93949569974627, 48.106502601078574, 36.07295915058681, 49.02069098608834, 47.65734325136457, 45.59137977872576, 47.155912603650776, 40.046085017068044, 35.72718204770769, 35.804960182734895, 36.70931339263916, 41.34343181337629, 35.340837887355256, 33.53136369160244, 36.460328170231406, 42.381416252681184, 44.08507285799299, 43.08345529011318, 40.683832372937886, 40.33946228027344, 38.606432165418354, 40.532632623400005, 42.21949543271746, 44.62080676215035, 44.659688881465364, 45.63322877883911, 46.01125594547817, 43.938490186418804, 45.5813570022583, 46.053990840911865, 43.788416045052664, 43.4062442779541, 42.051512309483115, 42.86045633043562, 44.418308462415425, 45.62125703266689, 39.27389349256243, 26.934453862054006, 8.870044265474592, 1.8745673085962022, 1.7247116012232644, 4.8957163606371195, 5.784731422151838, 6.4874900324004035, 5.968196000371661, 4.684746469770159, 6.273250145571573, 7.547009978975568, 8.36297949722835, 3.219456719500678, 0.43272026468600544, 0.09307772227163826, 0.6994485535791942, 3.9043829951967512, 18.01238669667925, 36.01010227203369, 26.593774999891007, 30.112603323800222, 25.76264364378793, 11.24603635924203, 2.712477283818381, 0.12698153193507875, 0.018931551104677573, 0.03879319390814219, 0.08228501211851835, 0.0630164835602045, 0.039269389784229655, 0.03404798817687801, 0.04262495579730187, 0.07607136839734656, 0.019559693023828522, 0.04899031316329326, 0.02691507539046662, 0.025654800069917525, 0.06644229830375739, 0.104504883023245, 0.05296771241618054, 0.013029719669637936, 0.010810911006826376, 0.04584378682609115, 0.031869578640908, 0.02429352481184261, 0.0665339141019753, 0.014594767475500703, 0.020843671268916557, 0.04197659183825765, 0.11881039610930852, 0.047690888068505695, 0.09707854116069418, 0.20442889471139225, 0.14557079944227422, 0.1359107949371849, 0.1371759506208556, 0.09540346890155758, 0.221835747095091, 0.20044935468052114, 0.1312889400869608, 0.17532989329525403, 0.09635170801941838, 0.1985210802938257, 0.11419581515448433, 0.13998056655483587, 0.14559758800481046, 0.15626048083816255, 0.18523871659168176, 0.11008960620633193, 0.08081042660134179, 0.1319123102085931, 0.08622990615133728, 0.11966426457677569, 0.11704522797039577, 0.16889189875551633, 0.06717418653092214, 0.135146737364786, 0.11716611576931817, 0.08911144760038171, 0.17030007605041775, 0.1104203648865223, 0.2370838267462594, 0.08709533007017203, 0.25468274525233675, 2.485363470656531, 17.42479838643755, 41.866777079445974, 51.40869998931885, 38.50868490764073, 30.131439890180314, 16.621819393975393, 9.163940906524658, 1.206253198640687, 1.0620304175785609, 0.49362776641334805, 0.3044561387172767, 0.17372302737619194, 0.2944899249289717, 0.27767832417573246, 0.7498780904071671, 2.188959615571158, 2.1577889110360826, 1.3721413314342499, 3.7582154784883772, 13.110319682529994, 28.682120357240947, 38.82138163702828, 50.833027839660645, 49.593688079289024, 53.543534006391255, 54.206996645246235, 52.19398886816842, 50.45069973809378, 49.41217681339809, 52.123652253832134, 52.51765332903181, 50.54776954650879, 48.25508287974766, 47.66035182135445, 48.24920470373971, 48.917743001665386, 51.08598048346383, 51.806345394679475, 50.858718803950715, 49.28449324199131, 48.772994654519216, 47.39356878825596, 44.915521553584504, 41.27032286780221, 40.522481305258616, 38.72442994798933, 38.354493958609446, 37.22432082039969, 35.27830062593733, 36.13584729603359, 37.200161933898926, 40.36182853153774, 46.15846742902483, 49.48444850104195, 49.135714939662385, 50.25595562798636, 39.6276193346296, 48.76399673734392, 49.08595541545323, 47.220867838178364, 49.24802214758736, 41.38818168640137, 37.83928503308977, 37.89545774459839, 38.91478279658726, 42.05151578358242, 37.3279254095895, 35.75366858073643, 37.77748775482178, 43.893549237932476, 46.50425842830113, 42.67002010345459, 40.69298315048218, 41.60117871420724, 40.283696038382395, 40.053040163857595, 43.784379141671316, 45.86934246335711, 46.54313012531826, 47.853932108197895, 48.78000538689749, 44.41806180136544, 46.67915153503418, 48.627002579825266, 45.695255347660606, 43.94768612725394, 44.33908857618059, 45.55913666316441, 47.15133721487862, 45.65960414069039, 40.86014986038208, 27.134617567062378, 9.606018304824829, 1.208104350737163, 2.9788903253419057, 6.621389201709202, 12.047023824283055, 10.475279637745448, 10.3192925793784, 8.407464470182147, 10.901489087513514, 17.202310119356426, 16.18538566998073, 5.327243787901742, 0.8667634555271694, 0.36448871025017326, 0.9155712936605725, 5.395289233752659, 20.776072638375418, 40.771237237112864, 31.246139390128, 36.0498285974775, 31.191147872379847, 12.514417852674212, 2.87601877110345, 0.20738847447293146, 0.19618845331881726, 0.1632880273142031, 0.18505749345890113, 0.1373128518462181, 0.16580616576331003, 0.08537730654435498, 0.1477116317089115, 0.2466321172458785, 0.266704974429948, 0.11923420908195631, 0.08596178982406855, 0.14933271972196444, 0.13428179520581449, 0.1502092784004552, 0.14104046539536544, 0.1385478534336601, 0.08296084656779255, 0.1650681503649269, 0.2135281307356698, 0.1396819975759302, 0.12558228416102274, 0.14147319431815827, 0.17008920093732222, 0.09741269251597778, 0.18564705896590436, 0.17675920017063618], [0.046527180155473094, 0.07874489136572395, 0.020823349145108035, 0.04477140972656863, 0.027513297307970266, 0.012133440218998917, 0.06049713731876441, 0.04033692892906921, 0.008279348590544291, 0.10191870786781822, 0.040289852169475386, 0.023273113316723278, 0.0575988699815103, 0.010540667472274175, 0.03489988550011601, 0.023796784591728022, 0.01192199598465647, 0.010801989967668695, 0.05394059931859374, 0.009552517772785254, 0.0697541938030294, 0.004971360180726541, 0.011460658329139863, 0.03464155704049127, 0.013041819645357984, 0.08931956107595138, 0.08152229126010622, 0.04240190776597176, 0.05376705720222422, 0.023116928126130785, 0.029713384341448545, 0.03097944926204426, 0.00384810270874628, 0.31630539574793404, 5.364376698221479, 21.056936195918492, 30.37961217335292, 31.584836278642925, 23.703809022903442, 18.146855184010096, 7.30385342666081, 4.023166792733329, 0.37045566577996525, 0.020994818336995583, 0.27159593626856804, 0.046575987179364474, 0.07811844748045717, 0.01403991666822029, 0.2802169408117022, 0.8919038836445127, 0.8891982659697533, 0.6148321969168526, 0.2607293879347188, 1.496692459498133, 10.307853238923208, 19.714797837393625, 33.578541960035054, 40.96613768168858, 48.63034813744681, 51.17463949748448, 48.55259779521397, 46.145710536411826, 46.098452363695415, 45.94852066040039, 48.37415415900094, 50.14264440536499, 49.99845886230469, 48.77572529656546, 46.00468989780971, 46.53591094698225, 46.91027293886457, 46.32008600234985, 46.581105504717144, 46.82853780473982, 46.77677719933646, 45.32836961746216, 43.87788105010986, 43.36402702331543, 40.629139627729145, 40.33343819209507, 38.64596741540091, 34.97078030450003, 35.46403987067086, 35.55381754466465, 34.628505093710764, 36.77396638052804, 39.90965018953596, 44.8599533353533, 45.87227112906319, 48.6422677721296, 34.63024909155709, 47.67790297099522, 47.566756112234934, 44.00918115888323, 42.82628856386457, 38.7115410396031, 35.048690455300466, 35.343898568834575, 39.53991222381592, 35.688911369868684, 33.616222040993826, 34.517472880227224, 33.22354807172503, 34.05179418836321, 35.499024050576345, 35.75178909301758, 36.307749203273225, 36.303333623068674, 36.46462910515921, 35.57028477532523, 37.25088030951363, 40.440888609204976, 43.50073283059256, 44.24856744493757, 45.01975148064749, 44.637763840811594, 44.026680197034565, 44.361975942339214, 42.521467617579866, 41.269155570438926, 42.21283558436802, 40.60552270071847, 44.956939765385215, 39.53391592843192, 28.39195489883423, 12.31406741482871, 2.3117605575493405, 0.7966166138648987, 1.6316405896629607, 2.2894548858915056, 4.478615999221802, 8.929161276136126, 6.7935421126229425, 5.3585341317313055, 4.077129542827606, 4.082954738821302, 6.78969498191561, 1.8127398490905762, 0.5467562441314969, 0.16840601339936256, 1.5262761520487922, 5.1653624858175, 11.93114697933197, 23.63332823344639, 32.94681869234358, 28.86693549156189, 18.45730069705418, 4.788942090102604, 0.13371436351111957, 0.10587684011885098, 0.02882688512493457, 0.053201152211321254, 0.03406974540225097, 0.0469552068305867, 0.03361415324200477, 0.026314585469663143, 0.041782266194266934, 0.0627777681552938, 0.01905541427965675, 0.02707399846985936, 0.005145888717379421, 0.044615869144243855, 0.026339750637167265, 0.058603549642222266, 0.031012161435293298, 0.016499020026198456, 0.049256207288375924, 0.019992549171937362, 0.04896796900512917, 0.02120756620674261, 0.0390214123763144, 0.0968470521537321, 0.024560658959671855, 0.04326554713770747, 0.037203956328864606, 0.05204814818820783, 0.034636678373707194, 0.04814949631690979, 0.004553586593829095, 0.04540174501016736, 0.06695950483637196, 0.028732541615941694, 0.04944454825350216, 0.008924198586360683, 0.05322955907987697, 0.04248122511697667, 0.016605846883196915, 0.015617095832047718, 0.044683814248336215, 0.06050870634083237, 0.01853046057346676, 0.03713358206940549, 0.03304754936003259, 0.03783624579331704, 0.015292013097288353, 0.024912396246301274, 0.04808278953922646, 0.03991310577839613, 0.03622058606041329, 0.03819714839171086, 0.05053620253290449, 0.08780011760869197, 0.028912950506699935, 0.013994076538697948, 0.026838445038135563, 0.06315252304609333, 0.006413823426035898, 0.13220120327813284, 0.006048727057142449, 0.5046953239611217, 8.256775413240705, 24.542196035385132, 37.862200192042756, 35.87527595247541, 27.050964730126516, 19.939886467797415, 10.449138777596609, 4.731090520109449, 0.5794379647289003, 0.11193593391882521, 0.19641223416796752, 0.10690272399889571, 0.046264268191797395, 0.06383628278438534, 1.0503452845982142, 1.284741135580199, 1.156442648598126, 2.268416826214109, 1.6784001205648695, 1.8798036447593143, 12.119098356791906, 23.4687306199755, 34.979694843292236, 41.74712215151106, 49.01628582818167, 51.88023253849575, 50.00361442565918, 47.50070653642927, 46.3041398865836, 48.35619306564331, 49.433222906930105, 51.28033896854946, 50.36601856776646, 47.03748403276716, 46.81475952693394, 45.62572125026158, 47.95427451814924, 48.19231980187552, 47.416140011378694, 48.14772278921944, 48.92793948309762, 47.085190364292686, 45.89833729607718, 43.67703294754028, 43.60181174959455, 41.13825498308454, 39.97570323944092, 35.725031580243794, 36.8497816494533, 36.64684908730643, 36.4224465915135, 37.54557078225272, 41.89659527369908, 45.89927182878767, 47.04758671351841, 48.79210914884295, 37.109126635960166, 49.6249098096575, 48.43746961866106, 45.32799094063895, 44.18684312275478, 39.8330636705671, 36.69712972640991, 37.108344963618684, 40.89211504799979, 37.37406839643206, 34.49719456263951, 35.37218121119908, 34.52293069022042, 35.69241673605782, 37.342936992645264, 37.66559049061367, 38.07623250143868, 38.25377287183489, 38.28368139266968, 36.57896171297346, 39.61406339917864, 42.24717705590384, 45.178034918648855, 46.11094522476196, 46.30244105202811, 43.49362482343401, 44.678289209093364, 44.96236630848476, 43.509070668901714, 42.771151133946006, 43.90326281956264, 42.312128816332134, 44.51306104660034, 41.631500652858186, 30.49209656034197, 15.176569768360682, 3.3800549932888577, 1.9623871105057853, 4.3583478927612305, 5.257648025240217, 5.602897499288831, 8.346898760114398, 8.407243864876882, 6.751445148672376, 5.547005321298327, 5.835716000625065, 5.812807355608259, 1.5908133004392897, 0.16889594282422746, 0.3496756393994604, 1.709864929318428, 8.099211113793508, 18.804615088871547, 31.099403858184814, 34.68046372277396, 32.60073239462716, 23.758317640849523, 6.548431379454477, 0.44087405715669903, 0.06290918681770563, 0.027852413843252828, 0.04397946436490331, 0.0476503218524158, 0.042892447872353454, 0.07249692055795874, 0.021953116736507843, 0.0357197050803474, 0.021479205827095678, 0.04427129888374891, 0.022241151459249, 0.007625005889817008, 0.04090978890391333, 0.016822923806362917, 0.0648180754589183, 0.006816290535165795, 0.062301660488758764, 0.05966350955090352, 0.05175276493121471, 0.012816440846238817, 0.012978469071510648, 0.01824624091386795, 0.05061630019918084, 0.02874706226534077, 0.03909009708357709, 0.027853826892429163, 0.037630157744778056, 0.08415347364331995, 0.17816706533942903, 0.20049945770629815, 0.1122418242905821, 0.22740504039185389, 0.1215931089328868, 0.2004199605435133, 0.08247943954276186, 0.14017641890261853, 0.17804444049085888, 0.0963068161425846, 0.08570900838822126, 0.11472105554171971, 0.0997539097443223, 0.10127110726066998, 0.1187810833965029, 0.16402734549982206, 0.12077090090938977, 0.11116896543119635, 0.08368193251746041, 0.20546986242490156, 0.06543345243803092, 0.08566301728465728, 0.1118073176060404, 0.2441033257969788, 0.17931383023304598, 0.1597680997635637, 0.1876678719584431, 0.1341972497424909, 0.13677340293569223, 0.11505448764988355, 0.12584710280810082, 0.07478678625609193, 0.6333287358283997, 8.60875117778778, 28.380936792918614, 46.47554152352469, 43.88764326913016, 36.45100368772234, 29.146765504564556, 12.582795075007848, 5.408466926642826, 0.9117162376642227, 0.508657697056021, 0.6444031330091613, 0.27943212006773266, 0.18786836548575334, 0.16945148658539566, 0.5802409702113697, 3.4087851430688585, 2.3465553990432193, 3.101114783968244, 1.0245601939303535, 2.219821776662554, 11.550382222448077, 22.0600163596017, 36.39821127482823, 42.77231495720999, 49.96919999803816, 54.68575184685843, 51.87358658654349, 48.87567513329642, 50.43064376286098, 49.764054434640066, 51.13116809300014, 54.039503370012554, 52.53143160683768, 48.81211996078491, 47.35434968130929, 47.00725589479719, 48.7267404964992, 50.12801149913243, 48.30013847351074, 49.29862240382603, 49.145817620413645, 50.01901510783604, 48.53802047457014, 46.43459231512887, 44.572290965488975, 43.67227690560477, 43.410430567605154, 38.52442952564785, 38.85439600263323, 38.92122377668108, 38.2192507471357, 39.96754952839443, 42.40202113560268, 48.40601164954049, 48.32309879575457, 51.446994985852925, 40.83030734743391, 50.20167630059378, 50.55642352785383, 48.209089279174805, 45.83123854228428, 42.57688644954136, 38.52893890653338, 38.52410296031407, 42.450054032461985, 38.7637220110212, 37.066937174115864, 37.87958805901663, 35.87220137459891, 38.32545048849923, 38.35720028196062, 38.028335094451904, 39.55156782695225, 40.06009953362601, 40.56357295172555, 38.88668080738613, 41.627891063690186, 44.03354501724243, 46.900601046425955, 48.093933309827534, 47.45924663543701, 43.94093247822353, 45.48104933329991, 48.3236129624503, 44.823339802878245, 44.22309534890311, 45.28868498120989, 45.33615159988403, 47.99156897408621, 42.210952622549875, 30.862498079027446, 14.972822529929024, 3.4654700670923506, 1.9764452704361506, 5.285186776093074, 7.437477707862854, 9.250766464642115, 16.797902379717144, 11.62059029511043, 11.30565277167729, 10.32206664766584, 13.802976046289716, 19.420147316796438, 5.349534477506365, 1.0336824187210627, 0.7129845672420093, 2.8053371352808814, 8.862894569124494, 19.841251577649796, 33.57268115452358, 40.768374579293386, 38.456271171569824, 25.852999755314418, 7.391914027077811, 0.5518583932093212, 0.14380959394787038, 0.15555503512067453, 0.10897234401532582, 0.10730521061590739, 0.1631578164441245, 0.09545007747198854, 0.19054443974580082, 0.09793589729815722, 0.08626833837479353, 0.09757754259875842, 0.1806607629571642, 0.14983688481152058, 0.13786243806992257, 0.11377331175442253, 0.1564914948706116, 0.14536547474563122, 0.1474613065698317, 0.12271012685128621, 0.09515472474907126, 0.20617761516145297, 0.14334554384861672, 0.06820603473378078, 0.1405910173697131, 0.10303506082189934, 0.12233719043433666, 0.08259436980422054, 0.09107722461755786], [0.02555005461908877, 0.03757398183058415, 0.023156734382999793, 0.03643799885841353, 0.005633118845123265, 0.015473390596785715, 0.09406119771301746, 0.0381085690377014, 0.04433660109394363, 0.03234775583924992, 0.006763257510361395, 0.04101706529036164, 0.04356491678793516, 0.012037423273016299, 0.0027707052982545322, 0.025644564369161214, 0.0517106957600585, 0.05796219155724559, 0.09288117103278637, 0.013231462549551256, 0.045054745594305654, 0.007776331073338432, 0.024264162905248146, 0.03397793282887765, 0.07439819603626217, 0.015569021625976478, 0.061541911613728316, 0.09405407988067184, 0.051583955596600256, 0.03545475751161575, 0.02780383582493024, 0.03663305392754929, 0.05622748285531998, 0.06428077071905136, 1.5262545474937983, 8.513156993048531, 25.369410344532557, 33.5270071710859, 22.788345643452235, 16.881556953702653, 13.22645708492824, 5.598678205694471, 2.007303306034633, 0.18865457044116088, 0.08178022277674504, 0.07683220292840685, 0.07442811943058457, 0.4359138576047761, 0.8038902921336037, 0.842788099178246, 0.5053770616650581, 0.8756335367049489, 3.287061606134687, 0.5751413181424141, 1.205926633306912, 7.696450965745108, 12.984188164983477, 22.58158983503069, 36.49265466417585, 48.455566201891216, 49.98934282575335, 49.63694061551775, 46.81852545057024, 45.83578961236136, 46.06953396115984, 49.266931670052664, 48.66381761005947, 48.91289663314819, 47.16413232258388, 46.86056900024414, 46.144251414707725, 46.668857778821675, 46.76613255909511, 47.396177836826865, 48.21969223022461, 47.57394054957798, 45.316335337502615, 45.50351980754307, 45.15046099254063, 45.58457749230521, 44.419034549168174, 40.98701701845442, 35.43727193559919, 33.24496589388166, 35.21472808292934, 35.40387541907174, 40.927818366459434, 46.22394725254604, 45.33787475313459, 47.44884170804705, 34.7726593698774, 48.71778426851545, 46.03091239929199, 44.20953941345215, 41.134096486227854, 38.405934946877615, 35.51815244129726, 35.260607038225444, 33.28028358731951, 34.51135499136788, 34.4408620425633, 35.23218890598842, 34.6126423563276, 36.14919131142752, 37.961260659354075, 33.68416847501482, 33.45594099589756, 34.697490283421104, 34.651854515075684, 36.84745052882603, 36.34000621523176, 41.50166661398751, 41.48244789668492, 44.89538219996861, 45.7138591493879, 43.46000943865095, 43.41025686264038, 43.04748099190848, 43.28238568987165, 44.65254265921456, 40.63503517423357, 44.15295328412737, 40.60084308896746, 31.281905242374965, 17.655228444508143, 4.704775954995837, 0.729966290295124, 2.397529338087354, 2.2298788598605563, 4.392858292375292, 4.309144224439349, 5.184645908219474, 5.94576460974557, 2.1620234038148607, 4.581139275005885, 4.791166382176535, 2.3092409670352936, 0.9200888169663293, 0.14793676962809904, 0.807993257684367, 3.47877955862454, 11.363223808152334, 13.687237296785627, 22.445438146591187, 23.52352237701416, 24.599840027945383, 14.112740635871887, 2.0348222979477475, 0.030846432649663517, 0.052311385848692486, 0.0427009992168418, 0.015244195038186652, 0.008414519551609243, 0.01108631310385785, 0.05674550362995692, 0.018480274427149977, 0.07410280260124377, 0.055637272740049024, 0.04726796058405723, 0.06904876165624176, 0.0648147574226771, 0.005558050819672644, 0.04610129765101841, 0.026353160185473304, 0.04062452938939844, 0.018089312727430036, 0.058142179756292274, 0.026405531214550138, 0.059346240146883895, 0.09391175716051034, 0.03787124802225402, 0.003734723323889609, 0.020152237299563627, 0.03252052103302308, 0.053033923863300254, 0.02568775481943573, 0.028928424497800212, 0.07709188506539379, 0.039400974687721045, 0.03593491942488721, 0.04311307014099189, 0.023591924691572785, 0.07805707398802042, 0.08963359386793204, 0.021957257496459142, 0.015422992408275604, 0.025520073549289788, 0.06335474683770112, 0.02192918141372502, 0.03484331264293619, 0.024098885345405767, 0.03233041926952345, 0.06254258113248007, 0.022054674769086496, 0.02249931707046926, 0.032571095640638044, 0.009299212168636066, 0.02419050283996122, 0.01738348194131894, 0.021049333536731343, 0.002032598085601681, 0.04454704194462725, 0.10566183951284204, 0.0684521800971457, 0.12770219040768488, 0.026156536004106914, 0.03830329501735313, 0.029226450648690974, 0.05939623460705791, 0.10966854130050965, 1.9674866540091378, 14.286006127085004, 30.733383178710938, 39.942838260105674, 27.451761143548147, 20.33281057221549, 15.74884946005685, 7.381877354213169, 2.119746220963342, 0.20899348120604241, 0.17969997094145843, 0.10429729880498988, 0.16745568439364433, 0.5728732741304806, 1.9341363864285606, 1.8942378759384155, 1.6230239548853465, 6.068135414804731, 4.391822142260415, 1.4117139279842377, 2.6157386004924774, 8.766195620809283, 18.25769805908203, 26.077508211135864, 39.41637672696795, 49.58319282531738, 52.18260077067784, 50.58484166009085, 47.82689666748047, 46.910943440028596, 47.20718336105347, 50.12719508579799, 51.54514176504952, 49.59592192513602, 47.70849241529192, 47.20219802856445, 47.49494647979736, 47.6211952481951, 46.16126407895769, 48.090733664376394, 49.33231769289289, 49.56682634353638, 47.12359305790493, 46.94323519298008, 46.94264112200056, 47.454316888536724, 45.50003181185041, 41.03761380059378, 35.46671492712838, 36.31467655726841, 37.510659558432444, 37.307918071746826, 42.051477568490164, 47.53541278839111, 47.44740343093872, 48.86549949645996, 36.813452993120464, 49.99347700391497, 48.88785532542637, 46.47832775115967, 42.77462870734078, 40.940273012433735, 37.902871472494944, 37.821004322596956, 35.70931128093174, 34.34887831551688, 35.769819668361116, 36.091020992824006, 36.10145718710763, 37.29034955160958, 38.40669230052403, 34.839188371385845, 35.038997718266074, 36.003157547542024, 35.50635092599051, 38.42681775774275, 37.16438218525478, 43.45030280521938, 42.91609055655343, 46.624444893428254, 46.52585342952183, 44.078051703316824, 42.896673815590994, 45.14211968013218, 44.314144543239046, 47.00747128895351, 42.15552684238979, 46.71570948192051, 43.58372211456299, 33.2088109425136, 20.404821702412196, 6.589635065623692, 1.7258199474641254, 3.2512167181287492, 6.597466119698115, 7.435491391590663, 6.182236560753413, 8.047287225723267, 7.639103140149798, 5.188115664890834, 4.476925415652139, 2.8896702442850386, 1.0999294753585542, 0.7812812338982309, 0.1680923673723425, 0.874404139816761, 4.024633731160845, 11.362885083471026, 15.815230812345233, 25.1599760055542, 29.066885539463588, 31.07229893548148, 16.57662657329014, 3.42071932554245, 0.04525750203590308, 0.060839275031217506, 0.02814281326053398, 0.0168129425562386, 0.03476503684318491, 0.026106210758111308, 0.013016756258106657, 0.030091833855424608, 0.06474712783736841, 0.04362776270136237, 0.039034175620015175, 0.02635896165988275, 0.055874858384153674, 0.003342304682259315, 0.021868596718247448, 0.05233821512332984, 0.014672783735607351, 0.010555519755663616, 0.07259913507316794, 0.0121224038469206, 0.02686596641849194, 0.019196524118472422, 0.021330162217574458, 0.01277386786283127, 0.02889598373855863, 0.02656608956333782, 0.030066147912293673, 0.037919468113354275, 0.10488700680434704, 0.1791838500648737, 0.12617064187569277, 0.13574327821178095, 0.08718115796468087, 0.1533629870308297, 0.20012031947927816, 0.17914041025297983, 0.187304557168058, 0.12256144625799996, 0.14853371759610517, 0.13608611481530325, 0.12469911655145031, 0.11647447145410947, 0.06963384883212191, 0.11463283241859504, 0.13354607325579437, 0.2334439477750233, 0.1473400659326996, 0.08352333852755171, 0.14228420651384763, 0.16544941919190542, 0.08227111572133643, 0.1461934367460864, 0.17322937957942486, 0.1332168887768473, 0.3141797626657145, 0.15157913203750337, 0.16330713486032827, 0.16332462749310903, 0.09603273549250194, 0.13973687748823846, 0.1663896380258458, 0.15812225879303046, 2.1097525400774817, 16.105771473475865, 38.536957127707346, 48.28551251547677, 33.98160696029663, 28.174837589263916, 22.060176168169292, 9.292594620159694, 3.0396260491439273, 0.4538098930248192, 0.3420519727681364, 0.20435137887086186, 0.25330778903194834, 1.1987003982067108, 1.7008618009941918, 1.723124154976436, 1.8913654472146715, 3.0629040343420844, 5.054763666221073, 1.2032161844628197, 1.818979874253273, 9.29581424168178, 14.333373733929225, 24.847776072365896, 38.124154227120535, 49.92522137505667, 55.01007291248867, 53.73706565584455, 50.020786898476736, 50.176895550319124, 49.72748606545584, 53.88520124980381, 52.14413901737758, 50.93552419117519, 48.9688435282026, 49.58246326446533, 48.51802008492606, 48.67283289773123, 47.70500094549996, 49.52663101468767, 50.88005324772426, 52.057727745601106, 48.980829170772004, 50.05665002550398, 50.04366731643677, 49.222470147269114, 46.15718896048409, 43.614530427115305, 37.747780731746126, 37.490089416503906, 39.07298633030483, 39.111354282924104, 44.03045654296875, 48.99086584363665, 48.31976366043091, 50.03586448941912, 41.057975496564595, 52.07095711571829, 49.992118631090435, 48.869678837912424, 44.72824675696236, 42.594065870557515, 38.66461985451834, 39.688826016017366, 35.94795410973685, 37.76682921818325, 36.110013893672395, 37.249768597739084, 37.906105858939036, 39.38194840294974, 40.22467109135219, 36.689688205718994, 36.01134252548218, 38.5621999331883, 35.41219936098371, 39.89391251972744, 38.41211536952427, 44.54203503472464, 43.904763630458284, 48.85449007579258, 48.20430891854422, 44.76676409585135, 43.25580188206264, 45.14233160018921, 45.6906521660941, 48.28812851224627, 44.382789271218435, 48.31880480902535, 44.25029059818813, 33.41603749138968, 20.75348057065691, 6.746749469212123, 1.4902915401118142, 6.692696392536163, 7.040943145751953, 10.969023840767996, 11.50158589226859, 13.342845491000585, 12.613632917404175, 10.325523376464844, 11.255055121013097, 8.508685827255249, 6.848186220441546, 2.998260817357472, 0.45763110369443893, 1.210407895701272, 5.4901781763349256, 15.73104817526681, 20.919257640838623, 31.497956003461564, 33.371503012520925, 36.01443099975586, 20.13004650388445, 3.5492028083120073, 0.11840030311473779, 0.12377596965857915, 0.1411421913653612, 0.16000935967479432, 0.14238997655255453, 0.11352543612676007, 0.25841056236198967, 0.1547489898013217, 0.18307005081857952, 0.1460911272359746, 0.09904857937778745, 0.2231795856995242, 0.2861070047531809, 0.06321089062839746, 0.10003422613122634, 0.1325604739998068, 0.08584685277725969, 0.08691320448581662, 0.1864001378417015, 0.13247625423329218, 0.16516085181917461, 0.154706974912967, 0.10897091909178666, 0.08458505584193127, 0.09559170808643103, 0.09266019253326313, 0.09180002726082291, 0.1238561182149819], [0.07736118882894516, 0.09310725211564984, 0.03364983739863549, 0.017984699590929916, 0.09327954572758504, 0.023145633550094705, 0.07980269353304591, 0.06589366202907902, 0.004728497654598738, 0.021495416028691188, 0.04604290971266372, 0.010930588468909264, 0.018630396907350848, 0.02086689921894244, 0.08067897401217904, 0.04092026548460126, 0.1040570634816374, 0.0058172015789231014, 0.04894309391134551, 0.07260429193930966, 0.05646086158230901, 0.05160416236945561, 0.019430474511214664, 0.02245009783655405, 0.07450855297169515, 0.05575216568208166, 0.01362169227961983, 0.016778807155787945, 0.02699461156901504, 0.014840595623744386, 0.06421033878411565, 0.03701943551589336, 0.025666179102180258, 0.03390758231814418, 0.10462127213499375, 3.5468560542379106, 13.420271873474121, 34.28274883542742, 26.76593225342887, 21.587085485458374, 11.743384940283638, 8.824632576533727, 4.209136630807604, 0.7532013920801026, 0.16483025598738874, 0.11744101744677339, 0.1785169994192464, 0.6223939540130752, 2.7215931032385146, 2.1722932755947113, 1.4032105271305357, 10.38814401626587, 3.7751317364828925, 2.0985129603317807, 0.8946948881660188, 1.2495904160397393, 4.774353912898472, 8.47297121797289, 19.45866118158613, 32.8918445450919, 48.20215845108032, 50.06975780214582, 49.77700240271432, 46.47122321810041, 47.181850228990825, 45.57120221001761, 46.07582555498396, 48.0235550062997, 51.27301556723458, 48.72667448861258, 48.42217663356236, 47.57049076897757, 47.55203635351998, 47.209667342049734, 45.940867219652446, 46.35942670277187, 47.72114161082676, 47.336683886391775, 46.77686057771955, 46.5212676184518, 46.94509383610317, 46.77873659133911, 42.18192999703543, 35.39094829559326, 34.67386988231114, 35.79585804258074, 42.95150899887085, 45.97648368562971, 47.838340350559776, 48.509470326559885, 34.313564096178325, 48.03945943287441, 48.16537121364048, 43.27924510410854, 42.662547315870015, 40.19018023354666, 35.55286564145769, 34.16828768593924, 36.079031876155305, 35.6216493334089, 37.86699444907052, 37.23268297740391, 37.1456880569458, 34.082036222730366, 36.052291733878, 35.153504031045095, 34.522805622645784, 34.52530697413853, 37.86935683659145, 38.15547670636858, 42.00006437301636, 43.80144044331142, 44.895868573869976, 44.59397976739066, 46.692568506513325, 43.86878933225359, 44.56608969824654, 43.54129293986729, 45.80518627166748, 41.044700963156565, 41.33013643537249, 41.90512071337019, 32.250313895089285, 22.09026881626674, 9.95189094543457, 2.44813762818064, 1.495884731411934, 2.3174192139080594, 6.988577612808772, 4.681340115410941, 3.35823460987636, 6.637721811022077, 7.827510493142264, 4.719226905277797, 2.7065248489379883, 1.539784318634442, 0.9690576578889574, 0.4916848763823509, 0.30835719938789097, 2.4365695289203098, 6.959490716457367, 17.48404393877302, 23.183699880327495, 21.02644750050136, 26.060259308133805, 20.361332927431377, 8.185005732945033, 0.06537034868129663, 0.05436419176736048, 0.09123801706092698, 0.030182547202067714, 0.011107402820406216, 0.022014508888657604, 0.04663085012829729, 0.024562396009319594, 0.06647781282663345, 0.05446583631315401, 0.03382345076118197, 0.03019561239385179, 0.07578643797231571, 0.04958668437653354, 0.05118661906038012, 0.045883586297609975, 0.04067046960283603, 0.033546940955732546, 0.017687709902280142, 0.06559690473867313, 0.06395313329994678, 0.0498318458641214, 0.10308122155921799, 0.02788329736462661, 0.06809671595692635, 0.030109326488205364, 0.015292550836290632, 0.020739368562187468, 0.033407403621822596, 0.024838111928797195, 0.021890345461932675, 0.009826684087914015, 0.04015845725578921, 0.09311268039579902, 0.03827831814331668, 0.026000759630863155, 0.019099927873217633, 0.03221164171450904, 0.014153083586799247, 0.046887679025530815, 0.0740606112937842, 0.03380110999569297, 0.009364403268721486, 0.0782569432631135, 0.015601742280913251, 0.053010276917900355, 0.017031887147043432, 0.015431246786777462, 0.05223249597474933, 0.05295204843527504, 0.03652297179879887, 0.04998098786122032, 0.040723788884601424, 0.01787025448200958, 0.02263582813819604, 0.020586760947480798, 0.022591321329985346, 0.05382278189063072, 0.017146859816940765, 0.08433356362261943, 0.030479331633874347, 0.04544197195874793, 0.03706739776368652, 0.472800432571343, 4.716128877231053, 19.883447987692698, 41.54935210091727, 31.654019492013113, 25.815243244171143, 21.502433844975062, 14.132027966635567, 4.449304589203425, 0.7012794581907136, 0.0472359473018774, 0.07634272812200443, 0.3479759634605476, 1.1891645384686333, 5.042041080338614, 4.519212586539132, 3.8241612655775885, 8.435115694999695, 8.062139868736267, 4.729918445859637, 2.8557728060654233, 2.180484550339835, 6.750992212976728, 11.213488391467504, 22.072266033717565, 37.474146774836946, 49.31864363806588, 51.856382846832275, 49.79354953765869, 48.95991161891392, 47.79117945262364, 47.98124047688076, 49.73823145457676, 50.40393141337803, 51.644556590488975, 49.28970439093453, 48.78971202032906, 49.73135273797171, 47.9418546131679, 46.96060568945748, 47.19620868137905, 49.42148739950997, 49.812195028577534, 48.36525699070522, 48.17329216003418, 46.54923759187971, 49.28983988080706, 47.5726203918457, 43.31448289326259, 35.96312550136021, 35.517245701381135, 36.94465582711356, 43.63856424604143, 48.74972513743809, 49.41327115467617, 48.371176855904714, 37.491736139569966, 49.185373714991975, 49.56313337598528, 45.112298011779785, 46.145529883248464, 40.078679016658235, 37.72279500961304, 35.78752367837088, 36.24898828778948, 36.95301798411778, 38.41760792051043, 38.83507306235177, 38.02594838823591, 35.93879985809326, 37.698518003736226, 36.106095109667095, 36.09737859453474, 35.998484883989605, 38.26465375082833, 39.747385433741975, 42.912734576633994, 44.981116022382466, 46.69615725108555, 46.280408314296174, 46.720059054238455, 43.49937445776803, 44.81565162113735, 43.96950347082955, 46.709581170763286, 43.43363755089896, 43.84219857624599, 43.22452456610543, 33.625181743076865, 24.524267945970806, 13.307822227478027, 3.6627155286925177, 2.380269144262586, 3.095045098236629, 7.931559767041888, 6.862393983772822, 6.575568437576294, 8.639778358595711, 7.685233099120004, 6.250776631491525, 4.085561181817736, 1.4936614164284296, 0.4595175396118845, 0.15416896449668066, 0.22843296666230473, 2.184093705245427, 8.944437759263174, 19.938109466007777, 25.209177936826432, 25.870288610458374, 30.389568941933767, 25.317608049937657, 11.68302767617362, 0.44352731906941956, 0.10934792671884809, 0.02131838454598827, 0.024181941424363425, 0.02738697444354849, 0.020519365456753542, 0.03331224587080734, 0.016359330021909306, 0.015948583937383125, 0.016538895832906877, 0.008670428185723722, 0.06752640727375235, 0.0368031897981252, 0.023472904560289214, 0.027872252510860562, 0.019307357724756002, 0.022364273334720304, 0.012539901354882334, 0.028888974471815994, 0.05490158132410475, 0.015094698506540485, 0.024763600302061865, 0.03227215346747211, 0.03873079243515219, 0.026269551100475446, 0.0540577449968883, 0.010998638745929514, 0.02027345249163253, 0.06664661198322262, 0.18736311474016734, 0.16942593295659336, 0.09685212759567158, 0.08764433953911066, 0.21246596558817796, 0.08649591223469802, 0.1127237266461764, 0.14570790422814234, 0.11981911983873163, 0.09648457196141992, 0.10644799697079829, 0.10887772230697529, 0.16801083460450172, 0.10064288561365434, 0.23201036612902368, 0.17446633534772055, 0.15676000474819116, 0.14421225019863673, 0.13069480125393185, 0.11506340360002858, 0.259657764009067, 0.11440928227135114, 0.11028385042612042, 0.10288368644458906, 0.1467189621180296, 0.11478520424238273, 0.10834755575550453, 0.07012238047484841, 0.10609842251454081, 0.09355230323438134, 0.1630522906780243, 0.10733752923884562, 0.16118211245962552, 0.21674288037632192, 0.5645259906138692, 5.411621843065534, 23.413381269999913, 49.637680598667686, 40.779074805123464, 32.73842832020351, 22.768359150205338, 15.655762706484113, 6.363391731466566, 1.1635720431804657, 0.4224334295306887, 0.2190534413925239, 0.8364632842796189, 2.4194157293864658, 7.1065445627485, 4.998128030981336, 3.6088850115026747, 18.276440824781144, 9.019117866243635, 4.174763458115714, 2.3904426097869873, 2.494476250239781, 5.620621919631958, 10.138463973999023, 21.09977184023176, 35.969184330531526, 50.61428117752075, 54.22751814978463, 52.51345314298357, 50.56122473308018, 51.224013396671836, 48.71832970210484, 50.42868784495762, 51.55448014395577, 53.548060757773264, 51.586108343941824, 50.197802679879324, 48.84901489530291, 48.915161745888845, 48.34448535101754, 48.120319093976704, 50.21255717958723, 51.91030781609671, 50.54765142713274, 50.69268117632185, 48.87355593272618, 49.83960567201887, 49.96245329720633, 45.2186610358102, 37.84382220676967, 37.9386442729405, 39.17202247892107, 46.03869090761457, 50.371973173958914, 50.712587765284944, 50.115525586264475, 41.29190744672503, 51.54791062218802, 51.72762925284249, 47.09972946984427, 46.7554601260594, 43.115066119602744, 38.82761417116438, 37.898674760546, 38.96738760811942, 39.33949143545968, 40.75779594693865, 40.52805723462786, 40.71704476220267, 37.57283203942435, 38.570218154362266, 38.1042754309518, 37.84009449822562, 37.36405951636178, 40.29393073490688, 41.80183226721627, 44.517323766435894, 45.865163121904644, 48.37504352842058, 47.42149012429373, 48.29186316898891, 44.396998337336946, 45.53727068219866, 45.44575943265642, 48.22831147057669, 46.07250084195818, 44.68989617483956, 44.55792556490217, 32.69653763089861, 25.222480263028825, 12.480071169989449, 3.528312397854669, 3.110094896384648, 4.699459280286517, 13.182035514286586, 8.3911292552948, 9.021321313721792, 13.315537333488464, 18.45899953160967, 12.961202655519758, 10.65771153994969, 6.323777445725032, 1.6526343545743396, 0.64921144928251, 0.6436025702527591, 3.61344541822161, 11.330433521951948, 25.185243129730225, 31.805518014090403, 30.13162054334368, 36.634849548339844, 28.828119380133494, 12.283933077539716, 0.6773312432425362, 0.1358846306268658, 0.17723489393080982, 0.12131311824279171, 0.1241941372198718, 0.07091921807399817, 0.20108643120953015, 0.0772769758477807, 0.13407443490411552, 0.23430099178637775, 0.08030735395316567, 0.1928633874548333, 0.1250563652387687, 0.15679499001375266, 0.18310173840395041, 0.11505722893135888, 0.11985063100499765, 0.1655924679445369, 0.0838905345382435, 0.17038101170744213, 0.15713185550911085, 0.09653103125414678, 0.2227522036326783, 0.14485957260642732, 0.13911562439586433, 0.07686036891703095, 0.07352091132530145, 0.04784988917942558, 0.14578631573489734], [0.10648130625486374, 0.03663190381069269, 0.03367206620584641, 0.042730736014034064, 0.04280986676790884, 0.03963909976716552, 0.05107393814250827, 0.03073091884808881, 0.03810712375811168, 0.03594253258779645, 0.015450646102960621, 0.05501289160123893, 0.05590193532407284, 0.05330689850130251, 0.018559371254273822, 0.0442891714961401, 0.03742256334849766, 0.05824444855430296, 0.06861523206212691, 0.013529096846468747, 0.02245077128256006, 0.050640476401895285, 0.03881139561001744, 0.08116941233830792, 0.05522758347381439, 0.060756188418184004, 0.004194024950265884, 0.02977125659318907, 0.053639322984963655, 0.030949787103704045, 0.00943344590320651, 0.029035592318645546, 0.011328417791186698, 0.055774757505527565, 0.0956607490245785, 0.46652675207172123, 6.3023539781570435, 22.46351214817592, 32.15918479646955, 25.092844247817993, 12.122767005647932, 9.551445416041783, 8.208364708083016, 2.1912097462585995, 0.39744143773402485, 0.391607257936682, 0.2001127198870693, 0.3443615702646119, 4.526903808116913, 4.426930086953299, 3.7800349933760504, 11.43587851524353, 8.18155334677015, 5.004374461514609, 3.605675595147269, 0.5514302104711533, 2.0219824612140656, 1.421383974807603, 5.5605378065790445, 14.886534588677542, 30.166215624128068, 46.13830375671387, 51.25612449645996, 48.7457229750497, 47.672188077654155, 45.21525641850063, 46.34654474258423, 44.45347676958357, 47.374482086726594, 48.11801924024309, 49.74736138752529, 46.80200958251953, 47.28355795996529, 47.05883584703718, 45.54544523784092, 46.1358962059021, 47.76571430478777, 47.56971604483468, 49.19658810751778, 47.25413581303188, 46.94090059825352, 46.08062676021031, 45.614347049168174, 39.48176622390747, 35.10643693378994, 37.37743827274868, 43.034091813223704, 49.132859230041504, 46.65988418034145, 48.38262401308332, 35.31688397271292, 47.813257353646414, 46.7363942691258, 45.584994384220664, 41.69329098292759, 37.097352913447786, 34.81308398927961, 33.78828028270176, 33.945455483027864, 38.43635416030884, 42.28325210298811, 42.222580432891846, 41.12564400264195, 40.377944878169465, 36.300120081220356, 34.39340584618704, 34.78456163406372, 36.8314071382795, 39.61874301092965, 42.68109553200858, 42.847511836460654, 46.00265407562256, 44.073191438402446, 45.88347509929112, 44.2062702860151, 43.38544831957136, 43.76383679253714, 42.681213651384624, 42.01806368146624, 42.16236386980329, 44.97126695087978, 36.56656265258789, 23.344458614076885, 14.654336214065552, 5.240274054663522, 1.6439322786671775, 1.4120172602789742, 2.11649837238448, 5.529986577374594, 10.046343020030431, 6.168265036174229, 6.56541234254837, 6.380961988653455, 3.654020292418344, 3.0073690371853963, 0.958199034844126, 0.2829827852547169, 0.34433624733771595, 2.0500837990215848, 6.290175523076739, 14.559999653271266, 18.661798340933665, 21.02468613215855, 20.417641128812516, 25.359672444207327, 15.22384878567287, 2.5333748715264455, 0.13617802916892938, 0.02550807874649763, 0.012661574558088822, 0.031211209683013812, 0.07560604265225784, 0.016828255395271947, 0.07403114251792431, 0.07950493201081242, 0.035803541474576504, 0.10824954815741096, 0.026010462681629827, 0.010400365938299468, 0.07480119833988802, 0.024932923626952937, 0.03864010962258492, 0.04098807488168989, 0.05082548236740487, 0.016289853125012348, 0.03789070501391377, 0.04718865001840251, 0.04932721597807748, 0.06336326923753534, 0.014510549405323607, 0.04804662023005741, 0.01713271575447704, 0.04028665626953755, 0.04970589619395988, 0.02231359016150236, 0.047034724349422116, 0.026172751294715062, 0.08706820224012647, 0.01922990125603974, 0.03155588850911174, 0.036489662514733415, 0.048102945421955416, 0.07048751373908349, 0.06661104996289526, 0.058687355502375534, 0.049311755557677577, 0.049042529825653346, 0.015227396207462465, 0.09018120555473225, 0.060644603334367275, 0.017822517847110118, 0.038363226622875245, 0.04690314283860581, 0.05877348195229258, 0.03980127302929759, 0.006321239019078868, 0.04134474681424243, 0.03195508762395807, 0.016053985870842422, 0.06666600451405559, 0.02592913686696972, 0.04285081974895937, 0.03832524223253131, 0.0728310379864914, 0.06320162184004273, 0.030677324759640863, 0.014576408014233624, 0.018057414796203375, 0.035772020130285194, 0.019837605700428997, 0.07269264398408787, 0.950898540871484, 10.072258932249886, 29.168857301984513, 38.120082582746235, 28.49585131236485, 15.204734291349139, 18.124115467071533, 10.21187082358769, 2.5097907313278744, 0.3763667643070221, 0.17271137237548828, 0.3949694260954857, 1.5630780458450317, 3.9540278741291592, 6.137829755033765, 7.341296400342669, 11.0550651209695, 10.072938118662153, 5.9934040648596625, 5.278197756835392, 1.274374857544899, 3.001440921000072, 2.893815496138164, 8.19124434675489, 19.31767875807626, 32.12327650615147, 47.733697005680625, 51.65377337591988, 49.62011207853045, 48.43945680345808, 47.383077008383616, 47.555934292929514, 46.98120362418038, 48.597194807870046, 50.35708318437849, 49.55710581370762, 48.00589268548148, 46.9095572744097, 46.97794839314052, 45.33377531596592, 47.66159207480294, 48.9671516418457, 49.722479888371055, 50.34986400604248, 49.60877261843, 49.05502898352486, 48.374960150037495, 46.40593447004046, 40.550701413835796, 36.752201148441856, 39.50351408549717, 45.68201208114624, 50.2516199520656, 49.686012268066406, 47.393408979688374, 36.450124740600586, 49.73445510864258, 48.495810168130056, 48.28678403581892, 43.64032908848354, 39.765117236546104, 37.168533733912874, 35.471575192042756, 35.37906340190342, 39.53939458302089, 43.21726369857788, 43.15410109928676, 42.93724087306431, 40.057858739580425, 37.079294545309885, 35.32227577481951, 36.20181696755545, 38.60632446834019, 41.232135568346294, 42.41436461039952, 45.12752498899187, 47.426895822797505, 46.99285922731672, 46.644813537597656, 45.28733703068325, 44.44569478716169, 43.03027377809797, 43.76932239532471, 43.70579848970686, 44.25699213572911, 46.03415025983538, 38.0376422064645, 25.943831818444387, 15.608485426221575, 6.845177216189248, 2.3848506127085005, 2.77740016579628, 4.152475808347974, 8.703232782227651, 8.970378858702523, 6.603773346969059, 9.47171744278499, 5.538977546351297, 4.760337659290858, 2.864750312907355, 0.6712852790951729, 0.1594626640102693, 0.45394095884902136, 1.8995024391583033, 6.8265126177242825, 15.673122780663626, 23.20778407369341, 25.05643916130066, 24.41993727002825, 30.111731324877056, 18.53812735421317, 4.010501095226832, 0.156958082690835, 0.03682019727836762, 0.03661083529836365, 0.05218592472374439, 0.03542450163513422, 0.06264271254518203, 0.04126266782571163, 0.04654082549469812, 0.05328856109242354, 0.04988200317269989, 0.016397685910175954, 0.029175105903829848, 0.010866706941409834, 0.04418747606022017, 0.042993078008294106, 0.07708804455718823, 0.044053085414426665, 0.03797258383461407, 0.03879216592758894, 0.02309602076586868, 0.03203000467536705, 0.024356950872710774, 0.07446670093174491, 0.031427910019244464, 0.030729405714997222, 0.026725085585245063, 0.057525900325604847, 0.035982555975871425, 0.03544769735474672, 0.28667162731289864, 0.16715460483516964, 0.17230784759989806, 0.18644654963697704, 0.1263864974358252, 0.16517037845083646, 0.20591456070542336, 0.1219144631177187, 0.09984552554254021, 0.1422873820577349, 0.10283872671425343, 0.13577542720096453, 0.10406884284956114, 0.1309675451900278, 0.15029755580638135, 0.10761217307299376, 0.18478579446673393, 0.16727461053856782, 0.11706846100943429, 0.1118315209501556, 0.09612152858504228, 0.2036541434270995, 0.15451135326709065, 0.21967116610280105, 0.1312340194625514, 0.1671767793595791, 0.09792810771614313, 0.1403771431318351, 0.20053217666489737, 0.12399979121983051, 0.16140829532274178, 0.09170844538935594, 0.1789600420743227, 0.1262479812971183, 0.25371694564819336, 1.086304166487285, 12.353453278541565, 36.14290319170271, 44.100459643772666, 35.95946727480207, 21.39362679209028, 18.81804769379752, 12.035541926111494, 3.1532827275139943, 0.6836500327501978, 0.7467473298311234, 0.578544904078756, 2.995186456612178, 11.46412902218955, 14.109590496335711, 12.741765516144888, 21.228653975895472, 15.294998339244298, 9.048827494893755, 7.596028651509966, 2.24623361655644, 4.0672600609915595, 2.3346040632043565, 6.843196111066001, 17.28313330241612, 32.30137620653425, 48.74758856637137, 56.20154653276716, 51.911221504211426, 51.37063775743757, 50.62926149368286, 50.77550022942679, 47.35464150565011, 50.926248346056255, 50.01142420087542, 53.362005370003835, 48.79054927825928, 48.3296092578343, 47.262206145695274, 45.65642533983503, 47.78320639474051, 49.60595859800066, 48.79595845086234, 52.029052530016216, 51.06705011640276, 50.82075037275042, 48.92070293426514, 48.17575877053397, 43.933654240199495, 40.32438816343035, 40.671464579445974, 46.75518567221505, 51.55751303264073, 50.540501730782644, 48.78256927217756, 40.82877179554531, 51.12970549719674, 50.18686274119786, 50.52785948344639, 45.3133476121085, 41.192947728293284, 37.498336928231375, 37.04507466724941, 37.45161376680647, 42.37770244053432, 45.36833218165806, 45.603716305324006, 44.59844398498535, 43.89734295436314, 39.587003639766145, 36.68451527186802, 38.61163289206368, 41.09354679925101, 43.90857124328613, 44.633716515132356, 45.818867274693076, 48.60283327102661, 48.29204382215227, 47.7497820854187, 46.18353305544172, 45.0006856237139, 44.241136346544536, 44.439024516514365, 44.15174429757254, 44.25050599234444, 46.768373353140696, 38.903519766671316, 25.088562420436315, 16.78218902860369, 7.51603056703295, 2.881675039018903, 4.152707704475947, 6.176582898412432, 10.63434648513794, 19.59322346959795, 13.03752601146698, 13.875884362629481, 12.984040515763418, 9.370191233498709, 6.036307454109192, 2.7574347342763628, 0.77176198469741, 0.8164316277418817, 2.876353587423052, 9.529522980962481, 20.69669120652335, 28.01877236366272, 28.922884123665945, 29.750550065721782, 35.02947173799787, 20.43162611552647, 4.509298375674656, 0.40356464630791117, 0.12792124865310533, 0.05062845954671502, 0.14539533028645174, 0.10321663679288966, 0.14468299065317425, 0.18110233997660025, 0.17133176140487194, 0.17010365373321942, 0.20317279068487032, 0.09140414957489286, 0.07221943366208247, 0.16957245580852032, 0.12518331914075784, 0.2855935980166708, 0.1396816447377205, 0.12471952688481126, 0.15158704375582083, 0.11419797289584364, 0.11220635047980718, 0.07107275697801795, 0.10646256511764866, 0.15739337647599833, 0.09502371320767061, 0.13940842582711152, 0.1662399803421327, 0.14555735087820462, 0.183289000498397, 0.19718242569693498], [0.024634013684200387, 0.033166018181613514, 0.013347968708590736, 0.03410073070387755, 0.02732017606363765, 0.029815687066210166, 0.07190259173512459, 0.04118097220946636, 0.017744659346395304, 0.05269749941570418, 0.01623072219081223, 0.042055040664438686, 0.05716960158731256, 0.014611902181059122, 0.06006910385830062, 0.006719843567615109, 0.024716720317623446, 0.045454826804676225, 0.04089592982615743, 0.03976428608543106, 0.0439574798302991, 0.03875775063144309, 0.033349558511482816, 0.05291725315951875, 0.018907734525523016, 0.01742473687045276, 0.05913382475929601, 0.034212692374629636, 0.02339744976987796, 0.024728262198290656, 0.03308536072394677, 0.04000280471518636, 0.05487087082916072, 0.04073710852701749, 0.030979456047394445, 0.11841928852455956, 1.8698562128203255, 11.471493244171143, 28.164738382611954, 29.838007041386195, 22.973254578454153, 14.682585852486746, 10.103306089128766, 5.327963360718318, 1.4475267891372954, 0.14002062726233686, 0.25290153654558317, 0.8024584203958511, 3.1596996060439517, 3.0920358768531253, 5.296020320483616, 4.280829446656363, 8.928880742618016, 8.250010473387581, 5.75996196269989, 1.5091945486409324, 1.9998613510813033, 1.3416573043380464, 0.9316791721752712, 4.426944417612893, 10.78170301233019, 23.69962099620274, 39.907141889844624, 50.26383488518851, 49.927924224308555, 49.5957030568804, 48.97567360741751, 48.06005736759731, 46.492533343178884, 47.695238726479666, 49.70003720692226, 48.62511266980852, 46.983541693006245, 45.15730496815273, 45.97021641050066, 47.97381285258702, 44.63792712347848, 46.433015074048726, 47.49592270169939, 47.700425556727815, 47.213725090026855, 48.55218437739781, 47.1265321459089, 41.00671168736049, 35.74747078759329, 38.85867261886597, 44.00508172171456, 47.99500833238874, 47.88608142307827, 50.618700231824604, 35.28924403871809, 46.40241868155343, 47.98523221697126, 44.57205125263759, 43.75492572784424, 37.66933904375349, 35.542252268110005, 33.63748352868216, 35.92058515548706, 39.90411942345755, 44.192756039755686, 44.034809589385986, 45.62136125564575, 43.386000701359336, 41.711550848824636, 36.9018931388855, 37.06227493286133, 37.8640901020595, 41.35669592448643, 43.81963777542114, 45.99409736905779, 46.52972705023629, 47.68363870893206, 45.24077020372663, 44.89432259968349, 46.35485478809902, 44.09806598935808, 43.26921885354178, 42.45308344704764, 42.857736110687256, 37.1101063319615, 25.717648846762522, 16.44286506516593, 7.762796708515712, 2.8147306655134474, 1.4911435629640306, 2.3787112278597693, 3.4760222094399587, 9.054948857852391, 5.4960172687258035, 5.399204109396253, 8.414723600660052, 2.9538088483469824, 4.4910406810896735, 2.0778642169066837, 0.6006748080253601, 0.37532971852592056, 0.9950858269418988, 5.792706651347024, 15.359571422849383, 18.35600812094552, 14.217916386468069, 22.838466473988124, 28.690763916288102, 21.462096078055247, 8.675269756998334, 1.1823236026934214, 0.03611563026372876, 0.04938761577276247, 0.010011455958842166, 0.06109971034207514, 0.014708710468507238, 0.1042375470112477, 0.037442067837608714, 0.029672770627907345, 0.023006827337667346, 0.018281266891530583, 0.018800103604527454, 0.03680207360801952, 0.026647746163819517, 0.011859653035311826, 0.10593619836228234, 0.06291591109974043, 0.015499093503292118, 0.030618478810148578, 0.023244791265044893, 0.03798901116741555, 0.03983878923047866, 0.027636751665600708, 0.012429611424782445, 0.007998185731204492, 0.014392538594880273, 0.030643136772726263, 0.041409631725400686, 0.09947094707084553, 0.07017996095653091, 0.030951870206211294, 0.0864537548539894, 0.05442125656242881, 0.014907416056043335, 0.006857262175929333, 0.04304674334291901, 0.03192028895552669, 0.0388471577981753, 0.03509390241067324, 0.02740846195125154, 0.007064840457003031, 0.07157867947327239, 0.005007033311163208, 0.011053459286423666, 0.014897024292232735, 0.031050763292504207, 0.03298127005941101, 0.04664548612864954, 0.03343357811016696, 0.014920242064233338, 0.029577589128166437, 0.01167632983664849, 0.05994206853210926, 0.026022192855764712, 0.052151227835565805, 0.0874619289700474, 0.04655581433326006, 0.024607964724834477, 0.03239209131736841, 0.02947058415572558, 0.06481852329203061, 0.039988246746361256, 0.03564005185450826, 0.050963682987328084, 0.04594791820272803, 0.249257070677621, 3.470496437379292, 16.333279814038956, 34.93732820238386, 34.513255323682515, 22.51549162183489, 16.292007514408656, 16.5026821068355, 7.473333018166678, 1.546637196625982, 0.11960725406450884, 0.14127674485955918, 1.2349657607930047, 3.146620273590088, 4.331573009490967, 6.630983795438494, 7.439959951809474, 7.384802545819964, 7.012487666947501, 7.436108044215611, 4.208022313458579, 3.5080749009336745, 1.4447470754384995, 2.685758203268051, 5.434289472443717, 14.616873264312744, 27.182799850191387, 44.43173933029175, 53.820186955588206, 51.701618671417236, 50.57268926075527, 51.19680077689034, 48.96854822976248, 48.24950347627912, 48.59688213893345, 51.20969663347517, 49.62235287257603, 47.19724743706839, 43.76277371815273, 46.30727005004883, 48.1350735936846, 47.004490511757986, 47.30974572045462, 47.289175578526084, 47.712515422276084, 47.97461884362357, 48.828569820949006, 48.42576885223389, 43.29177965436663, 37.4415215083531, 40.987298420497346, 45.72094283785139, 51.01616498402187, 49.15021235602242, 50.283685888562886, 38.062113761901855, 47.64282499040876, 50.59724766867501, 46.75812128611973, 44.51683391843523, 39.24174417768206, 36.95318821498326, 35.24839557920183, 36.01275300979614, 41.387219360896516, 45.208933557782856, 46.16996669769287, 48.129191943577354, 44.897070612226216, 42.20977142878941, 38.53875323704311, 38.02692461013794, 39.823225021362305, 42.40917430605207, 45.840913908822195, 46.77385548182896, 47.06645802089146, 47.91884912763323, 46.89322553362165, 45.19923734664917, 47.10076127733503, 43.88846663066319, 43.69536576952253, 43.813231536320274, 44.04410975319998, 38.645269121442524, 27.19206874711173, 18.20120746748788, 11.156898788043431, 2.935510984488896, 2.7648161096232275, 2.6620752683707645, 6.873574938092913, 7.341620360101972, 8.084087491035461, 7.413145984922137, 7.775807210377284, 6.227773317268916, 3.1728558029447282, 1.7278095207044055, 0.21385078770773752, 0.3716285271303994, 0.8706390304224831, 5.733622210366385, 16.3921605859484, 22.660875729152135, 20.105550629752024, 26.143304177692958, 30.892569882529124, 25.972724165235245, 11.867808938026428, 1.6600652358361652, 0.033931456572775326, 0.03913187109200018, 0.03577317703249199, 0.09250236528792552, 0.019177867798134685, 0.022668866008254032, 0.01748533344029316, 0.02514049088183258, 0.08186983689665794, 0.0313343128987721, 0.051362386771610806, 0.024555666638272147, 0.08982395008206367, 0.043553127241986136, 0.05614312059645142, 0.03510233320827995, 0.011028372150446688, 0.03854767618966954, 0.022924493898504546, 0.05646371482206242, 0.018099314333604913, 0.0628998094637479, 0.05893485115042754, 0.020349005669621483, 0.014316868369600602, 0.020255466224625707, 0.0434678014633911, 0.08664065732487611, 0.0696591106908662, 0.11784606214080538, 0.12655276565679482, 0.1489169948867389, 0.11357388352709157, 0.15677843375929765, 0.16791293557201112, 0.15844205234731945, 0.15892837196588516, 0.13233783308948788, 0.10829780556793724, 0.1073611286867942, 0.1760971128408398, 0.168742960318923, 0.10127593164465257, 0.12788513701941284, 0.06726095080375671, 0.11378112169248716, 0.22703770867415837, 0.1594960479331868, 0.07678193026887518, 0.08318688015320472, 0.07473206240683794, 0.2126572717513357, 0.08820267207920551, 0.2121087033301592, 0.18132061112139905, 0.1361221314540931, 0.18502393311687879, 0.11954158544540405, 0.06741611819182124, 0.2126974817365408, 0.11337155116988079, 0.16148923097976617, 0.077921231277287, 0.10450187711311237, 0.30462590817894253, 3.662279963493347, 20.449922459466116, 44.79575892857143, 41.23047842298235, 32.615035261426655, 24.077627318246023, 18.618365151541575, 8.426142965044294, 1.937071566070829, 0.46705644364867893, 0.5649811519043786, 2.8377326769488196, 9.353310585021973, 9.569206748689924, 12.951978921890259, 12.00508884021214, 18.244228976113455, 16.636796236038208, 12.721290911946978, 5.300531438418797, 4.946824703897748, 3.490615163530622, 2.690288863011769, 5.927645879132407, 12.347874743597847, 25.80136595453535, 44.11393914903913, 55.00107152121407, 54.67582981927054, 52.781799520765034, 53.646315234048025, 52.47556461606707, 50.23302657263619, 49.77830171585083, 53.11582721982683, 48.704513209206716, 47.71963732583182, 44.81238944189889, 46.31730672291347, 48.71975408281599, 46.11248772484915, 47.93637595857893, 48.368414946964805, 50.0831469808306, 49.41738101414272, 50.68167870385306, 50.467802728925435, 46.20704228537423, 40.08751712526594, 42.05766841343471, 48.35382372992379, 51.93202093669346, 51.22315182004656, 50.346240520477295, 41.88037122998919, 48.71408435276577, 51.971246991838726, 49.15531928198678, 47.165918009621755, 41.78187009266445, 38.879312242780415, 36.89312103816441, 38.49384355545044, 43.51412895747593, 47.298069272722515, 47.84868621826172, 52.12416294642857, 46.71262100764683, 44.15372453417097, 40.54961749485561, 39.62386383329119, 40.868084703172954, 44.319862910679404, 47.38474805014474, 48.92433336802891, 48.99264805657523, 51.00319617135184, 45.71882363728115, 46.55483436584473, 47.44758408410208, 44.55612598146711, 43.711985860552105, 44.240267821720664, 44.94773687635149, 38.90384980610439, 27.700548342296056, 17.165628841945104, 10.672573736735753, 4.269423544406891, 3.955403617450169, 5.713327390807016, 6.877341295991625, 19.4772823538099, 15.705522230693273, 12.98177627154759, 17.840265921183995, 9.838206257138934, 11.092861584254674, 5.504000314644404, 1.8629887870379855, 0.652476885489055, 1.6880632191896439, 8.308119995253426, 21.05936632837568, 25.94495047841753, 22.91298590387617, 32.49731888089861, 38.29792519978115, 29.336545126778738, 12.50392780985151, 1.9196554720401764, 0.13793046799089226, 0.20707903536302702, 0.11218613013625145, 0.14968068605022772, 0.1558373464005334, 0.21737812486078056, 0.12082960775920323, 0.09387719937201057, 0.15920385718345642, 0.16149813335921082, 0.11200872037027564, 0.2622820389057909, 0.15641163129891666, 0.1452244615980557, 0.2504331347133432, 0.12979956929172787, 0.11819826252758503, 0.12509747089019843, 0.13050432290349687, 0.11406191305390426, 0.0658004516735673, 0.12327796566699233, 0.09431271707373005, 0.09171932230570487, 0.14581993035972118, 0.1127332668485386, 0.12509206975144999, 0.2099499577390296, 0.1700243465602398], [0.17167011967727117, 0.07236057573131152, 0.029173660624240125, 0.06692589699689831, 0.03380558493414095, 0.026257607187809687, 0.04270420529480491, 0.027482001576572657, 0.05383048326309238, 0.08629483516727175, 0.07117685782057898, 0.030963557971907512, 0.06919214289103236, 0.052770635312689204, 0.05193394735189421, 0.047465275174805095, 0.03224396033744727, 0.05462170937763793, 0.019787143051092113, 0.036581478480781825, 0.042914374731481075, 0.014668341027572751, 0.059582641747381, 0.013347677786701491, 0.017810531526005695, 0.04483683407306671, 0.0421503205517573, 0.0715302252875907, 0.015317719396469849, 0.035263773652591875, 0.0570738942229322, 0.05975604137139661, 0.045938062481582165, 0.02723867891888533, 0.044851073130433045, 0.029226338690412895, 0.41544462740421295, 4.982855456215995, 18.254550525120326, 27.94547929082598, 22.420829364231654, 21.87508658000401, 9.839927673339844, 6.5123441730226785, 4.560186547892434, 1.119082619036947, 0.31849540823272293, 1.4391217487198966, 1.424577106322561, 3.0336471242564063, 4.936906150409153, 10.95378383568355, 6.832423797675541, 4.276975802012852, 4.565272629261017, 1.1359035564320428, 2.465624072722026, 1.1469141713210513, 2.013896495103836, 0.9550808135952268, 1.7638817450829913, 6.975824628557477, 16.3889696257455, 30.772623130253383, 42.167766094207764, 48.59587117603847, 48.826082365853445, 49.06637191772461, 46.83012546811785, 48.691203934805735, 48.552705492292134, 48.38468415396554, 44.59181887762887, 46.51982934134347, 45.057160581861226, 44.44485752923148, 46.4371839932033, 48.25513846533639, 47.01340505055019, 50.380328382764546, 47.37415552139282, 48.553261348179404, 42.62040301731655, 40.766991887773784, 35.750885827200754, 38.85892275401524, 44.77178069523403, 50.67663778577532, 47.17596857888358, 49.39788784299578, 35.84509645189558, 47.09276737485613, 49.04475954600743, 45.00528533118111, 42.594837120601106, 37.97802318845476, 36.34550224031721, 36.22120591572353, 37.734377656664165, 41.51181098393032, 43.64351831163679, 47.57325267791748, 48.40359020233154, 44.5921801839556, 42.61145026343209, 39.965128081185476, 36.36529418400356, 37.832117966243196, 42.519556862967356, 45.11811712809971, 44.619601249694824, 46.82690497807094, 41.89132159096854, 43.82710708890642, 43.13848154885428, 45.448941707611084, 45.22332327706473, 45.19785812922886, 40.07847057070051, 36.058503423418315, 25.965117624827794, 18.50973527772086, 11.265039682388306, 5.950475922652653, 0.9636003907237733, 0.8907403317945344, 1.3998524844646454, 7.521913954189845, 4.670825319630759, 6.038240356104715, 5.718541145324707, 5.782314317567008, 4.005534436021533, 1.5996446779796054, 1.4955452467714037, 0.15302609439407075, 1.2290755340031214, 4.5669697267668585, 10.012203914778572, 16.66413392339434, 18.586130721228464, 18.117639745984757, 22.330796343939646, 24.623872109821864, 14.463781867708478, 3.5709589208875383, 0.08815700667245047, 0.0355007180811039, 0.016519900245059813, 0.02009043633006513, 0.01682363966080759, 0.04826279130897351, 0.027004767541906664, 0.019969494248341237, 0.0914231553407652, 0.08043919330728905, 0.00934508622490934, 0.08271990556802068, 0.03887350192027433, 0.04018859438864248, 0.10236329079738685, 0.021063467421169792, 0.01895826163568667, 0.051866137954805575, 0.016616706836170385, 0.0689884466784341, 0.0689490916473525, 0.007311516774020025, 0.0928142335531967, 0.031242815844182457, 0.030324679932424, 0.055832056395177326, 0.049315155018121004, 0.09975563322326966, 0.033060285462332625, 0.06974337795483214, 0.020797295096729482, 0.04944265853347523, 0.022517301641138535, 0.00996545552542167, 0.03245566665594067, 0.05559860981468644, 0.03317646083555051, 0.019566055985965898, 0.039933017388518365, 0.07617470928068672, 0.07580272959811346, 0.03251019712271435, 0.03917848305510623, 0.07573380401091916, 0.04276833703209247, 0.023263815690630248, 0.034658343996852636, 0.02762222083817635, 0.0472542202499296, 0.028301558224484324, 0.048765093819903474, 0.013839927801330174, 0.09851028397679329, 0.0340450297641967, 0.02248699657086815, 0.03715023331876312, 0.025842906940462332, 0.006835546086741877, 0.01065079540213836, 0.0439151629938611, 0.06740284604685647, 0.059915252828172276, 0.04211722839889782, 0.08122377656400204, 0.038619950347180874, 0.017563205511708344, 0.5002314863460404, 8.032829761505127, 25.627202408654348, 34.40155608313424, 26.639549732208252, 21.629426070622035, 18.70379499026707, 12.264273149626595, 6.930154987743922, 1.4940894906009947, 0.14497488284749643, 0.20105429579104694, 1.195524962885039, 2.719018795660564, 5.458308092185429, 4.623387362275805, 6.178805019174304, 6.852435912404742, 8.926748514175415, 6.172546863555908, 5.846674178327833, 2.6195798686572482, 1.6406792189393724, 2.3301441882337843, 3.692627957889012, 9.333602888243538, 20.61345178740365, 34.957328592027935, 46.73066895348685, 51.85299212591988, 50.24356004170009, 50.77009105682373, 49.83024297441755, 50.286718777247835, 49.744700227464946, 48.7105199268886, 45.667549405779155, 47.05256509780884, 45.22859695979527, 46.0180721282959, 45.91339751652309, 48.44742291314261, 47.91865805217198, 51.1660167830331, 48.11697701045445, 49.89491333280291, 45.748488971165244, 41.86629070554461, 37.20098182133266, 40.11090128762381, 46.527159690856934, 51.59051350184849, 48.890342780521934, 50.27711636679513, 38.274537563323975, 48.52873420715332, 50.940568583352224, 46.17737347739083, 43.880309445517405, 38.6288401058742, 38.6200019972665, 37.81787763323103, 38.24686983653477, 43.012569768088206, 45.284324986594065, 48.49734572001866, 48.60405962807791, 47.067138944353374, 43.62417105266026, 40.374797344207764, 38.07807724816458, 39.388684681483674, 43.69688742501395, 48.058337688446045, 46.86046825136457, 47.35327965872628, 43.74691098076956, 42.87886905670166, 43.779567514147075, 45.56464311054775, 44.95720379693167, 44.698081152779714, 41.941484110695974, 36.75504296166556, 30.019688538142614, 19.78016127858843, 14.129857523100716, 5.940737588065011, 1.432258774127279, 3.026100294930594, 3.620211660861969, 7.731342213494437, 6.482473433017731, 5.599933224064963, 6.550894950117383, 7.270302746977125, 3.459722604070391, 1.0705843014376504, 0.38615151068993975, 0.2984294449644429, 0.8057936100023133, 5.246704612459455, 13.096364225660052, 22.295827797480992, 23.056601694652013, 22.20540394101824, 26.225292921066284, 30.091442584991455, 18.83685299328395, 4.757811554840632, 0.15928074877176965, 0.04975162945421679, 0.049804640002548695, 0.01735474428694163, 0.04229129637990679, 0.03327288405437555, 0.03278044744261673, 0.03980506264737674, 0.03666823596826621, 0.01718055077695421, 0.03346472965287311, 0.02909552731684276, 0.03444637304970196, 0.08122551361364977, 0.06577361561357975, 0.03831974949155535, 0.010193578150522496, 0.021526894964543835, 0.020875136634068828, 0.027534644019656947, 0.06912316302103655, 0.012671037577092648, 0.07373251247086696, 0.04071300357048001, 0.01836493025932993, 0.03852775100884693, 0.007729504523532731, 0.06495364675564425, 0.03028398479468056, 0.039035393590373654, 0.25404114968010355, 0.19990340540451662, 0.08100764280451195, 0.14241843431123666, 0.18031333945691586, 0.1323849777025836, 0.23975397061024392, 0.08148519575063672, 0.2296616578740733, 0.1524731833487749, 0.1839882715472153, 0.06863208008663994, 0.18704003707638808, 0.1177884680884225, 0.15998375176319055, 0.13466807162123068, 0.11775003586496625, 0.11290815246424504, 0.13724471335964544, 0.07863414766533033, 0.17936777376702853, 0.12214608783168451, 0.21291223806994303, 0.09025207853743009, 0.13060376899582998, 0.22377912567130157, 0.11825715936720371, 0.13091902993619442, 0.10680013628942625, 0.15724447875150613, 0.15098704238023075, 0.20657121975507053, 0.11815309923674379, 0.13079344667494297, 0.09713867293404681, 0.16577161476016045, 0.9022165845547403, 9.020357251167297, 31.578575951712473, 45.920074735369, 35.61224494661604, 31.37440661021641, 20.648114613124303, 12.825304576328822, 6.801929022584643, 1.9848868974617548, 0.7062626736504691, 3.0552679640906195, 3.161510697432927, 6.831486225128174, 14.518274852207728, 17.83675708089556, 13.56866715635572, 11.596132636070251, 12.35688829421997, 6.00639545917511, 7.24526230778013, 4.580730199813843, 3.8873403668403625, 2.381880909204483, 2.6206535824707577, 8.547534942626953, 20.13219002314976, 35.84043768474034, 46.36830302647182, 54.36705534798758, 52.44643081937517, 51.417416504451204, 51.36898756027222, 52.20325429098946, 51.9359119279044, 50.30712563650948, 45.983932154519216, 47.63634926932198, 46.30923639025007, 48.350269726344514, 46.713885579790386, 49.2483035496303, 49.11160121645246, 53.46084349496024, 49.15329735619681, 52.7333254132952, 46.546635491507395, 43.36505535670689, 38.429079396384104, 41.74797330583845, 48.7252014705113, 54.118799686431885, 49.33778245108468, 51.87917641230992, 41.29282113483974, 50.493295669555664, 53.09352002825056, 49.020208086286274, 46.8647518157959, 41.9176413672311, 39.77394492285592, 39.768525327954976, 40.073283740452354, 45.384670870644705, 46.48752021789551, 50.83970158440726, 51.21543237141201, 49.07451868057251, 46.19305903570992, 42.70806843893868, 39.65103823798043, 41.811056000845774, 46.00134086608887, 50.26028782980782, 47.63331985473633, 48.829862185886924, 43.102924142565044, 44.73999963487898, 42.642369747161865, 45.13583850860596, 44.85883467538016, 46.630920614515034, 42.2473646572658, 36.56261954988752, 27.395465101514542, 20.296073709215435, 13.705269609178815, 8.07713234424591, 1.555661278111594, 3.3964351543358395, 5.278686736311231, 15.160085167203631, 12.113848992756434, 13.442405360085623, 12.359137773513794, 17.467283146721975, 12.641887766974312, 5.079689460141318, 3.3961274794169833, 0.5590321911232812, 1.8379262004579817, 7.123277127742767, 14.313946570668902, 24.08606764248439, 27.53619044167655, 26.812394857406616, 32.42798628125872, 33.45002460479736, 20.290456090654644, 4.9518195901598245, 0.18136930279433727, 0.12901160014527185, 0.17122297867068223, 0.10841523283826453, 0.12013416364789009, 0.12381646462849208, 0.09587384294718504, 0.07706238914813314, 0.20308759382792882, 0.08476459620786564, 0.05355151716087546, 0.1437715824161257, 0.1089615145964282, 0.09442352862762553, 0.14373502294932092, 0.09189986011811666, 0.14261449021952494, 0.10207520518451929, 0.10368466989270278, 0.15602838114968368, 0.11891946382820606, 0.15763307575668606, 0.17031394530619892, 0.10121974894510848, 0.10007337760180235, 0.2001801391265222, 0.13354472975645745, 0.18917288977120603, 0.18182470835745335, 0.22372339080486978], [0.01146683469414711, 0.03700963068487389, 0.051100757239120345, 0.04025388642081192, 0.058115092638347826, 0.06443983968347311, 0.05909199307539633, 0.027389719117698923, 0.013905582849734595, 0.032754619007131884, 0.023156975262931416, 0.08164985584361212, 0.015972690590258156, 0.02605263363303883, 0.019707043688478212, 0.03335572639480233, 0.024820705809231316, 0.046591240646583695, 0.026107647556013296, 0.039709127973765135, 0.020686658265601312, 0.08137715261961732, 0.06992676561432225, 0.011786433169618249, 0.0417841898410448, 0.006785637715698353, 0.02915423077398113, 0.02246341747897012, 0.029451805699084486, 0.018171798836972033, 0.03507187716396792, 0.027489857315751057, 0.029784542308854203, 0.08268914757562534, 0.06150251587054559, 0.01125862792001239, 0.12104015717548983, 1.1529404308114732, 8.78186467715672, 26.127250364848546, 27.292211396353586, 19.711606877190725, 11.744623456682477, 6.400799095630646, 6.927410449300494, 4.37296473128455, 0.792226220880236, 0.37689200469425743, 1.2171206154993601, 2.45237255522183, 3.9715994341032843, 2.9183871490614752, 4.101717480591365, 3.9800892642566135, 6.563747380461011, 7.918386851038251, 5.760701077325003, 1.4835679637534278, 0.928748009460313, 1.7292583286762238, 1.2419121137687137, 0.7971954313772065, 3.2542860848563055, 10.405010768345424, 20.1156359400068, 32.613986083439414, 46.493134362357004, 49.31279672895159, 51.82929182052612, 49.295589515141074, 50.72121395383562, 48.85788427080427, 47.45841979980469, 46.687027318137034, 44.0368766784668, 47.08563504900251, 49.612726143428254, 47.986211912972585, 49.10845715659005, 47.13795151029314, 46.75811781202044, 45.21173368181501, 43.24264546803066, 37.696131297520225, 35.09432274954659, 38.78256899969918, 45.56351055417742, 48.56835283551897, 49.93691866738455, 49.62474652699062, 37.98950856072562, 47.21817193712507, 50.253534180777415, 44.070401736668174, 43.81099074227469, 37.77659491130284, 37.10484307152884, 35.80184391566685, 40.53654098510742, 41.452949319567, 43.72186967304775, 45.69730159214565, 47.959329332624165, 45.837210518973215, 43.69584172112601, 40.55011429105486, 39.3467001914978, 38.18437426430838, 41.958284854888916, 44.54411949430193, 47.941594055720735, 46.86224004200527, 42.46305411202567, 43.45445782797677, 45.93439844676426, 45.13513674054827, 43.008512020111084, 40.48878254209246, 34.48677921295166, 27.362952743257793, 20.146044731140137, 10.177213209015981, 7.391077637672424, 2.4198269758905684, 0.9786833013807024, 1.8333060826574052, 2.8744877789701735, 7.751502411706107, 4.561904489994049, 3.5860736412661414, 5.878893843718937, 3.158822613103049, 2.7684795473303114, 1.444696375301906, 0.1344115582427808, 0.6002523249813488, 3.744120623384203, 14.806993348257881, 21.869323049272808, 17.37611930710929, 14.043745892388479, 20.031111104147776, 25.288748707090104, 22.218723637717112, 7.452861888068063, 0.7805315884096282, 0.028954741478498493, 0.03785493604040571, 0.040474824208234034, 0.06913542414882354, 0.03067464115364211, 0.021865355017195855, 0.029425895839397396, 0.06009834871760436, 0.017510230586464916, 0.03709950264809387, 0.057861700520983765, 0.05905552181814398, 0.040776154824665616, 0.007924562985343593, 0.010041985793837478, 0.005442193933829133, 0.04501211323908397, 0.016297595209575126, 0.015124560832711203, 0.047986932897142, 0.015886676098619188, 0.049876737740955183, 0.07126076546098505, 0.016512470286605612, 0.10036129358091525, 0.01899711794352957, 0.02764433599077165, 0.052235501884881935, 0.04092415349025812, 0.06044974843306201, 0.023254082105787735, 0.03628979663231543, 0.029102176960025514, 0.04013317504099437, 0.05453765245952776, 0.030737860261329582, 0.04674212647868054, 0.08361199591308832, 0.018225674517452717, 0.030411685085190193, 0.04617946149249162, 0.042934428833957226, 0.008520452438720634, 0.017951726181698695, 0.011163326828474445, 0.021041416729401265, 0.02832387524124767, 0.011340977474381881, 0.038435683984841616, 0.04449088638648391, 0.06799035559275321, 0.07725139507757765, 0.09056773302810532, 0.02776531539192157, 0.01233243927293058, 0.07269989073808704, 0.012187925732827612, 0.01660305301525763, 0.0858709950532232, 0.03382648381271532, 0.015930098947137594, 0.022895472955756953, 0.00675712016111772, 0.024418558459728956, 0.08998104450958115, 0.017112220604238764, 0.14785252272018365, 2.177165048463004, 14.232420751026698, 33.712725571223665, 32.99763086863926, 21.42211788041251, 15.756817306791033, 11.37192382131304, 12.444981030055455, 6.059400660651071, 0.6286831593939236, 0.1851683525102479, 0.36385807980384144, 1.716691534434046, 2.645574382373265, 3.8164474623543874, 5.709856765610831, 5.239780732563563, 6.882827333041599, 9.179465787751333, 4.9470961179052075, 3.9165123786245073, 4.08693562235151, 3.8712192433220998, 2.3965937197208405, 2.0270322816712514, 5.12260457447597, 14.257092067173549, 24.670046363558086, 38.085008076259065, 50.104127066476, 50.69804171153477, 52.594712325504844, 50.799877984183176, 51.21345213481358, 48.86326217651367, 47.46078218732561, 46.36460311072213, 44.92245932987758, 47.755719321114675, 49.24136577333723, 48.736464500427246, 49.74034718104771, 50.12442970275879, 48.925528458186555, 46.50787843976702, 46.062207085745676, 39.87343617847988, 36.394830976213726, 39.65712833404541, 48.43970346450806, 50.379435539245605, 51.42715787887573, 49.41330589566912, 40.32680613654, 49.00507490975516, 50.4060332434518, 46.142160006931846, 45.63318361554827, 38.761213711329866, 38.616566113063264, 37.538657324654714, 41.11389112472534, 42.38844435555594, 45.77010134288243, 46.97885513305664, 50.28794166019985, 47.36097131456648, 45.816105365753174, 42.62549952098301, 40.16334629058838, 39.41420194080898, 43.14720153808594, 46.52822971343994, 49.293508529663086, 47.74190282821655, 43.37079804284232, 45.01216752188546, 46.11316517421177, 46.10068620954241, 44.17098385947091, 42.12924528121948, 35.89507137026106, 29.191831520625524, 22.92393105370658, 13.011045558112007, 8.636194825172424, 3.4998621301991597, 1.120745626943452, 3.928512351853507, 5.499322874205453, 9.349874700818743, 5.661171172346387, 6.692006349563599, 6.5751389520508905, 5.546112477779388, 1.9043637897287096, 0.699930584856442, 0.08489349750535828, 0.5051127044217927, 3.7361432228769575, 12.756170868873596, 19.671724217278616, 18.916809388569423, 17.58659761292594, 22.80858748299735, 28.005633320127213, 24.682084117616924, 10.060938579695565, 1.2246807983943393, 0.014906550923894559, 0.027017926032255803, 0.026720481725143533, 0.02339640143327415, 0.06210086162069014, 0.009809051507285662, 0.013591592466192586, 0.0030745011172257364, 0.046271772789103646, 0.0447680102661252, 0.048955073447099755, 0.08888983806329114, 0.01582358930526035, 0.04875173685806138, 0.02893078579966511, 0.025716799510908977, 0.02323680660421295, 0.04410306630390031, 0.07098206398742539, 0.10279608078833137, 0.007637338263780943, 0.09903950057923794, 0.01229936832429043, 0.03857817973143288, 0.04605524887197784, 0.010110944459613944, 0.031097056344151497, 0.06015840585210493, 0.05502419260197452, 0.03862462545345936, 0.1474925870341914, 0.12155246468526976, 0.24721655302814075, 0.12875537175152982, 0.16578076141221182, 0.16630034281739167, 0.16380895221871988, 0.10164978408387729, 0.0944613976670163, 0.08454832674137183, 0.16198336732174667, 0.21591246207909925, 0.12016415489571435, 0.1730873214879206, 0.08663440801735435, 0.07039514476699488, 0.08659479514296566, 0.13561651429959706, 0.19428053498268127, 0.08872701001486608, 0.12933123085115636, 0.16250574429120335, 0.1263281162828207, 0.1532277007188116, 0.07919952339891877, 0.11664299241134099, 0.1127855276156749, 0.14596990016954287, 0.18327522623751843, 0.11629750952124596, 0.1767425760626793, 0.09399630940918412, 0.057883813977241516, 0.18966870888003282, 0.15890492179564067, 0.09157347798879657, 0.2974410908562796, 2.9479925547327315, 17.612469230379375, 43.09014640535627, 41.67092473166329, 30.01520347595215, 24.137237651007517, 15.465291738510132, 12.424138171332222, 5.843207461493356, 1.3110389815909522, 0.7750148815768105, 3.100721125091825, 6.389763619218554, 9.776922277041844, 9.704683593341283, 12.960103971617562, 11.405961309160505, 12.72484404700143, 17.241433688572474, 14.061319623674665, 5.176340205328805, 5.883429280349186, 3.817165298121316, 3.0302342559610094, 1.5496078772204263, 4.611383046422686, 12.102526034627642, 24.574117796761648, 37.10849434988839, 49.01025479180472, 51.34428324018206, 56.417635508946006, 52.10168899808611, 53.74634844916207, 50.104773248944966, 49.03485141481672, 47.63429607663836, 47.37812989098685, 47.62324844087873, 51.170022419520784, 49.6708721433367, 52.036751134055, 50.42623165675572, 50.58126333781651, 48.54447535106114, 48.85243340900966, 40.740296908787315, 38.312259333474294, 41.5825332232884, 50.5732798576355, 52.19873101370675, 52.76342153549194, 50.367376940590994, 44.63839265278408, 50.41349908283779, 54.270134925842285, 47.398495061056956, 47.90415716171265, 41.11846303939819, 39.44491992677961, 39.8322229385376, 44.05019290106637, 44.25336517606463, 47.84360361099243, 48.19139569146292, 51.842747007097515, 49.189250809805735, 48.646499225071494, 44.22832039424351, 42.422389779772075, 39.729334013802664, 45.420693806239534, 49.276999609810964, 51.20930058615548, 49.883935179029194, 46.252685001918245, 43.97920315606253, 46.2239020892552, 46.489326749529155, 45.146253858293804, 42.609397070748464, 35.216548510960166, 28.970446280070714, 23.34371863092695, 12.079864484923226, 9.860806141580854, 3.2637664675712585, 3.2409828901290894, 6.683268989835467, 8.176713926451546, 14.137763704572405, 10.103310431752886, 13.10312569141388, 11.53407393183027, 9.828010644231524, 7.8377087116241455, 2.7957384160586765, 0.2540679925254413, 1.1027963672365462, 5.031624427863529, 17.62987446784973, 27.278281995228358, 24.947746753692627, 21.406241246632167, 29.08672090939113, 34.8921023777553, 29.481717314038956, 10.91234999043601, 1.1193901853902, 0.11954956501722336, 0.10389540251344442, 0.18551885655948094, 0.14867121593228408, 0.1925959632332836, 0.08893449245286839, 0.17796292129371846, 0.15190518168466433, 0.21418844030371734, 0.10451804660260677, 0.13550019982670033, 0.21924470684358052, 0.10611994564533234, 0.2524677355374609, 0.11367654587541308, 0.06028736821774926, 0.1378283348998853, 0.11435756433222975, 0.14077703095972538, 0.1566728265689952, 0.07448649379823889, 0.1767691203526088, 0.21081422136298247, 0.1003194008288639, 0.21715355691100868, 0.08375101416770901, 0.09289672305541379, 0.17995320021041802, 0.14875553069370134, 0.09402216159339462], [0.025723303269062723, 0.03126669688416379, 0.008433701736586434, 0.05126837235210197, 0.030662434308656623, 0.034986995825810094, 0.0558173627193485, 0.024542109508599554, 0.0116962422949395, 0.0049775607185438275, 0.03328759469357984, 0.06486381550452539, 0.023669764532574585, 0.004632034571841359, 0.05439891579693981, 0.012988720039304878, 0.05144479824230075, 0.025570220679843, 0.08871858260993447, 0.02182157593779266, 0.04285002247031246, 0.09225432681185858, 0.023292091941194873, 0.07027709324445043, 0.09963458936129298, 0.044060718933386464, 0.030005164577492645, 0.06733849378568785, 0.022209063538217118, 0.032880782415824275, 0.03304344083049467, 0.04490774098251547, 0.02496433301296617, 0.050255550271166224, 0.08250075232769762, 0.06098991659070764, 0.03921914426609874, 0.7610979112131255, 3.025407863514764, 16.530007634844097, 24.897843054362706, 27.34430377823966, 23.46229658808027, 15.288595574242727, 15.320487805775233, 12.147679771695818, 5.2599422335624695, 0.9326715703521455, 0.1651982662401029, 0.5841618712459291, 1.4301859310695102, 1.98226112978799, 4.420551206384387, 3.8416511842182706, 7.895694034440177, 5.6784122586250305, 3.9515204429626465, 2.663968869618007, 2.5554314936910356, 4.582938424178532, 1.7315331037555421, 1.3565914801188876, 0.70764900211777, 2.9537821412086487, 8.526250873293195, 18.61991286277771, 30.724121229989187, 41.41279220581055, 46.24938808168684, 50.79236698150635, 49.63002715791975, 49.23118666240147, 47.67322335924421, 47.66094241823469, 46.09511375427246, 48.15473699569702, 47.06770174843924, 49.02985913412911, 48.298853056771414, 47.55313764299665, 45.34776898792812, 42.64407900401524, 38.20795297622681, 37.69657250813076, 36.18434224809919, 40.837995529174805, 44.67514862333025, 48.19181258337838, 47.437415395464214, 51.00484636851719, 38.75853170667376, 46.69040066855294, 48.88808809007917, 44.92148658207485, 44.88425465992519, 37.964561053684776, 37.96456452778408, 40.69085005351475, 43.53853797912598, 41.91892678397042, 45.640708514622276, 46.613702978406636, 48.55270896639143, 45.47617517198835, 45.01332439695086, 41.379253251211985, 39.66958992821829, 38.62006453105381, 43.17141948427473, 43.20788363048008, 43.727619307381765, 43.48565871374947, 42.40643324170794, 42.6276604107448, 44.672140053340364, 42.27407700674874, 38.11292593819754, 30.69402858189174, 27.309965780803136, 20.695994649614605, 15.923629658562795, 7.704128725188119, 4.350078233650752, 0.936756568295615, 0.9332077758652824, 3.432676306792668, 5.72713302714484, 7.808218819754464, 4.526776134967804, 4.8483869688851495, 4.268042589936938, 4.5615023630005975, 0.5884084690894399, 0.24150098115205765, 0.6005074541483606, 3.19380744440215, 13.361679451806204, 32.71186883108956, 43.25373479298183, 29.47811119897025, 19.644548075539724, 20.852014711924962, 27.233909061976842, 14.221303633281163, 2.4108596742153168, 0.07870772121740238, 0.06581573228218726, 0.04204849958685892, 0.020570016399558102, 0.025752078242866055, 0.028707676700183322, 0.02794250293767878, 0.06658312146152769, 0.04627981682174972, 0.02547889156267047, 0.035360790589558225, 0.01681984156104071, 0.03265257751835244, 0.01534024506275143, 0.050182142960173745, 0.029648000707051585, 0.028650937601923943, 0.023313045102570738, 0.03334747540897556, 0.07654377804802996, 0.03069388779944607, 0.014724625507369637, 0.009831274377315171, 0.01710068720525929, 0.054771261888423135, 0.01217774601121034, 0.048266967692013295, 0.0755320687645248, 0.04186272009142807, 0.03574603223907096, 0.0035987974926164107, 0.010544587708344417, 0.02005011777925704, 0.009385709268307047, 0.06950179913214274, 0.010445010149851441, 0.008043142917033817, 0.021324415025966506, 0.0441442873062832, 0.025091336108744144, 0.04533884142126356, 0.053927527341459475, 0.040337719422365935, 0.042918975198907514, 0.03309442934447101, 0.018747179569410424, 0.016980666234823208, 0.025003966243405427, 0.013717766901079034, 0.009875860065221786, 0.04568718433646219, 0.03868386834593756, 0.04214780657951321, 0.040386003974292956, 0.10037748342646019, 0.03439568987648402, 0.058989615711782656, 0.06181771574275834, 0.03708373688693557, 0.026505917077884078, 0.019084620123196925, 0.015945360896044543, 0.021014848690746084, 0.023981449593390738, 0.02669663630825068, 0.08318790474108287, 0.03649422905540892, 0.06742796541324683, 0.9693455738680703, 6.068339952400752, 23.295072555541992, 32.53143801007952, 31.320950644356863, 23.54172318322318, 18.29552057811192, 15.426899467195783, 13.167440823146276, 5.467204826218741, 0.5978382602334023, 0.10071732769055025, 0.25428981919373783, 1.1724615033183778, 2.490295388868877, 4.604740134307316, 7.534959197044373, 6.267401933670044, 6.49024282182966, 4.878069239003318, 6.646406624998365, 5.00848605803081, 4.564296407358987, 3.914471345288413, 2.3468598169939856, 2.222058445215225, 4.51872056722641, 11.568623849323817, 22.396847656794957, 35.29482691628592, 44.4081050327846, 48.669480391911094, 52.11374759674072, 51.477219649723594, 49.66860008239746, 48.314177308763774, 45.1931403023856, 47.47033248628889, 47.66875566755022, 48.218153204236714, 50.427920069013325, 49.19705016272408, 49.68990673337664, 47.62745904922485, 45.552831172943115, 40.317505972726, 39.70529672077724, 38.90725094931466, 41.90166745867048, 47.37622955867222, 49.58844913755144, 50.295063563755576, 51.211048058101106, 40.640791756766184, 48.10929230281285, 51.22597973687308, 46.446366037641255, 45.79294007165091, 38.51783568518502, 39.19792536326817, 41.038610867091585, 45.1909134047372, 43.29284272875105, 45.74620648792812, 47.32952724184309, 49.34135382516043, 46.98668575286865, 45.38309710366385, 42.4675669670105, 40.99507692881993, 40.28474521636963, 44.237655299050466, 45.66432891573225, 45.03099019186837, 45.13832596370152, 43.0981125150408, 43.733236925942556, 45.26449482781546, 43.28536646706717, 39.05022750582014, 33.65102209363665, 30.485808440617152, 22.382673331669398, 18.053466183798655, 9.294567908559527, 5.46034174306052, 1.5203897250550134, 2.35254995737757, 3.4809128727231706, 4.8494943380355835, 8.355543187686376, 6.941868782043457, 4.713935852050781, 5.380031858171735, 2.743486442736217, 0.5506495152200971, 0.1269222144037485, 0.29913563707045143, 2.7373036316462924, 12.403888515063695, 34.746249267033164, 43.469257490975515, 28.59050488471985, 19.81220289639064, 22.5871171270098, 31.37261050088065, 17.950344494410924, 3.65683822120939, 0.07087263664496796, 0.07929111884108611, 0.05085752618366054, 0.052029905774231465, 0.017776983058346168, 0.02276468024189983, 0.04851870757660695, 0.04161572655928986, 0.05567512142338923, 0.01936372023608003, 0.022445426122950654, 0.02485337048502905, 0.034030047710984945, 0.009466905313144838, 0.02780445329179721, 0.04513652263475316, 0.06295451974230153, 0.011204847234434314, 0.045096146408468485, 0.06694947608879634, 0.022302884575245634, 0.029933684305953126, 0.03741540480405092, 0.03477016996060099, 0.04149054702637451, 0.1036096578463912, 0.031611884611525705, 0.025976069437872087, 0.04012179261605654, 0.030681389184402566, 0.05089823149942926, 0.11435943708888122, 0.17638820436383995, 0.1634737966316087, 0.13335416998182023, 0.0845951863697597, 0.1607115212827921, 0.1384071252707924, 0.1282258973057781, 0.1089443408751062, 0.1773091120911496, 0.16812402781631264, 0.1442745261426483, 0.17091119182961328, 0.08997475448995829, 0.21326814325792448, 0.0774252764614565, 0.14218869592462266, 0.12276810088327952, 0.1315019050879138, 0.13574713229068688, 0.13770150313419954, 0.1393559207873685, 0.1291504284100873, 0.14525053091347218, 0.14354660734534264, 0.13530465960502625, 0.18346969437386307, 0.15558324860674994, 0.1152795170034681, 0.20929840127272265, 0.07296963554940053, 0.19288344494998455, 0.18776505174381392, 0.10902933417154209, 0.19689330192548887, 0.1559527244951044, 0.11687480711511203, 1.3819580503872462, 7.164648004940577, 29.760319232940674, 42.60926505497524, 40.869877338409424, 34.11180925369263, 25.151455777032034, 24.432414497647965, 16.195113148008073, 7.099532527582986, 1.2608122995921542, 0.540817705648286, 1.8381079392773765, 4.023234103407178, 8.526711191449847, 10.916555387633187, 12.37273279258183, 17.58859522002084, 13.051998240607125, 13.02847511427743, 11.278889179229736, 7.769201210566929, 10.588979959487915, 5.023171944277627, 2.736913881131581, 1.4228965107883726, 4.151266387530735, 10.502782344818115, 20.7663243157523, 34.79360124043056, 44.543865885053364, 49.38614191327776, 53.678704261779785, 52.95459427152361, 51.96634503773281, 48.87472670418875, 46.52319574356079, 46.53376047951834, 48.3355256489345, 48.81584766932896, 52.1242220061166, 51.7481438091823, 50.87916040420532, 50.30449226924351, 46.88348763329642, 41.98575803211757, 41.83842495509556, 40.06005784443447, 44.040072849818635, 50.63775566646031, 51.03399406160627, 52.145212514059885, 52.89236967904227, 43.23052086148943, 49.468141078948975, 53.28580447605678, 48.062548296792166, 48.4999235016959, 41.57395567212786, 40.890183448791504, 44.81869493212019, 47.22705520902361, 44.484139169965474, 47.0014055115836, 48.61678525379726, 50.565386704036165, 48.09980801173619, 48.19981343405587, 43.83170679637364, 43.23914705004011, 42.930459431239534, 47.16056094850813, 46.38078546524048, 47.53907101494925, 44.9552652495248, 43.379448550088064, 44.24387046269008, 44.91316958836147, 44.126418113708496, 40.04410825456892, 32.81451456887381, 29.63183661869594, 23.227518694741384, 17.199134792600358, 9.973828145435878, 6.7352432523454935, 2.1250251148428236, 3.342818945646286, 9.089114018848964, 11.89374656336648, 15.279802628925868, 12.222080213682991, 11.276016099112374, 11.37245796407972, 8.838268416268484, 1.5597332481827055, 0.8069484766040529, 0.8607879504561424, 3.833890046392168, 15.755250488008771, 37.871701853615896, 48.30073601858956, 35.56191914422171, 27.48398515156337, 29.040287835257395, 37.10916485105242, 19.497124671936035, 3.744707311902727, 0.17846511863172054, 0.13881948457232543, 0.11511700786650181, 0.1129360334681613, 0.10376832647515194, 0.0900266013507332, 0.14190364336328848, 0.14049940157149518, 0.15836997835763864, 0.09922522918454238, 0.10008803395820515, 0.07816950045526028, 0.1043081282238875, 0.1101574529228466, 0.11825512376214777, 0.12432544731668063, 0.14221813077373163, 0.09377174145941224, 0.12224866875580379, 0.1470738495034831, 0.0850421916693449, 0.15557676181197166, 0.100330393096166, 0.08869209260280643, 0.14607212825545243, 0.17628525703081063, 0.12470210210553237, 0.19087290497762815, 0.12167646017457757, 0.13087812784527028, 0.0922320301511458], [0.041214566478239636, 0.045972878113389015, 0.021136279317683408, 0.040247253741004636, 0.03811388196689742, 0.09465424410466637, 0.05725795363209077, 0.047204510774463415, 0.06579505732016903, 0.07750517395990235, 0.04350904621449964, 0.055243532439427714, 0.02668117079883814, 0.019926056132784913, 0.030105228136692728, 0.059897380215781074, 0.0525190684545253, 0.032989677108292065, 0.03447729728317686, 0.03114749863743782, 0.07752056991947548, 0.06032445015651839, 0.02729425941860037, 0.05083762475156358, 0.03551802072407944, 0.020042540239436284, 0.05388155998662114, 0.06507998997611658, 0.014865652225645525, 0.05237505618216736, 0.062158964574337006, 0.01999760595416384, 0.007874861991565143, 0.026954803615808487, 0.02079517297845866, 0.035408142155834606, 0.024649594544566104, 0.15312951670161315, 1.5031525471380778, 10.094426291329519, 18.938750062670024, 23.660002367837087, 21.287727560315812, 16.38973045349121, 17.771831376211985, 16.01644022124154, 9.434642723628453, 3.846262616770608, 0.5277406530720847, 0.28418656066060066, 1.2319929088865007, 1.044035017490387, 4.189560515539987, 3.8136612347194125, 3.8158551284245084, 5.104730333600726, 2.0300269552639554, 4.94120317697525, 3.3907371972288405, 3.7046565924371992, 3.471858935696738, 1.3457733520439692, 1.4255641847848892, 1.297713530915124, 2.822661165680204, 8.96737549986158, 17.260683672768728, 28.02927109173366, 38.62885400227138, 46.8105662890843, 49.77575520106724, 50.88868291037423, 48.17159332547869, 47.83534220286778, 48.077622413635254, 48.99700805119106, 50.70089047295706, 50.33618300301688, 47.66273157937186, 46.633713790348594, 43.79148020063128, 41.242068018232075, 40.22857250486101, 39.90856279645647, 38.22088009970528, 43.87123509815761, 47.42990786688668, 48.78819036483765, 50.084626947130474, 50.50470808574131, 39.15767444883074, 46.32411595753261, 51.068321636744905, 45.7735789162772, 44.27976485661098, 42.00759622028896, 41.50333765574864, 44.48436151232038, 45.36303070613316, 46.38589586530413, 46.20564917155674, 48.250354630606516, 48.992516040802, 46.35285718100411, 45.706685134342735, 42.91211271286011, 41.49803270612444, 40.701039586748394, 43.13944387435913, 44.545349325452534, 44.61169767379761, 43.304057121276855, 39.909243719918386, 39.82893296650478, 41.7375544820513, 34.363789149693076, 30.174633366721018, 24.183920860290527, 17.609304325921194, 13.265436479023524, 11.035205432346888, 3.368683397769928, 1.1854285789387566, 1.4971895813941956, 0.9978182060377938, 2.550726043326514, 2.5715571769646237, 6.233062633446284, 5.364740610122681, 3.6692038433892384, 5.019604912825993, 3.5000050025326863, 0.6617471394794328, 0.26067328665937695, 1.4148336691515786, 8.02673705986568, 14.689678226198469, 16.631777899605886, 14.970606054578509, 27.926251888275146, 39.56639528274536, 25.06444869722639, 20.569377626691544, 5.29778516292572, 0.5985709694879395, 0.02108812877642257, 0.005105027338556413, 0.023215989149840813, 0.024430787357102548, 0.09778562214757715, 0.03884356834792665, 0.0322391257754394, 0.027155556682763354, 0.037072836221860986, 0.016958590097991482, 0.030560134976570095, 0.030286773573607206, 0.026731767458841205, 0.03186835049252425, 0.04621651628986001, 0.06354310137352773, 0.03491457239059465, 0.023435676736491065, 0.04439833081726517, 0.049307260263179026, 0.02321231997172747, 0.019812172511592507, 0.05884411744773388, 0.0693181807707463, 0.00558509722551597, 0.09408586246094533, 0.042368371172675064, 0.05673702872757401, 0.031741790140845945, 0.026071347628853152, 0.009675368234249098, 0.02968528281365122, 0.09605346473732165, 0.03273982015837516, 0.025494662412841405, 0.03272499416821769, 0.04358581227383443, 0.053563500089304786, 0.04784514282697013, 0.055364684867007394, 0.013803229234846575, 0.007106899450133953, 0.008454923767463436, 0.0387247127613851, 0.050418432602392774, 0.0626416743866035, 0.089863549385752, 0.045676975777106624, 0.024491409372006143, 0.07440133086804833, 0.06455679197928735, 0.04840028964515243, 0.12586919590830803, 0.07923111598938704, 0.03122258871527655, 0.028617574035057, 0.03309527412056923, 0.09972695833338158, 0.04970907173784716, 0.04210750159940549, 0.023857455800420473, 0.025831398986546055, 0.020928454219496677, 0.0528863526747695, 0.010450081350947065, 0.06448406659598861, 0.014698160945304801, 0.03494716242754033, 0.3588121405669621, 2.4340731714453017, 13.197025384221758, 26.716082402638026, 32.13813175473894, 26.089043957846506, 19.229902165276663, 22.021921123777116, 20.96585747173854, 13.477698734828405, 5.693530670234135, 0.40887415568743435, 0.2575046366878918, 0.2672432426895414, 1.0572212870631899, 1.9345115891524722, 4.086121380329132, 4.774857223033905, 6.871551275253296, 4.114870854786464, 5.470680662563868, 6.335089113031115, 4.5414155551365445, 5.215032117707389, 3.758371812956674, 1.508202693292073, 2.8706284889153073, 4.5374880858830045, 11.27658498287201, 19.703599078314646, 30.58167621067592, 41.69215495245797, 49.39116546085903, 49.851914405822754, 52.79269082205636, 48.66624253136771, 47.88540744781494, 48.796163422720774, 49.235855851854595, 51.30064855303083, 51.774275984082905, 49.02935191563198, 47.76118060520717, 45.559682096753804, 42.905859334128245, 41.33917604173933, 40.46849380220686, 39.76530136380877, 45.515408175332205, 47.90390355246407, 51.490125928606304, 50.42809724807739, 50.37740666525704, 41.27902896063668, 47.92026308604649, 53.13074847630092, 47.360043730054585, 45.46758025033133, 42.460719517299104, 42.86398254122053, 46.39917734691075, 47.09851006099156, 47.57737643378121, 47.24080221993582, 50.15770809991019, 49.604923316410606, 46.993085043770925, 46.93781907217843, 43.44527578353882, 43.38553169795445, 42.322342668260845, 44.317222595214844, 46.087613173893516, 46.626487663814, 45.17051696777344, 42.662658487047466, 42.43578938075474, 42.01654897417341, 37.57336357661656, 32.17580836159842, 26.374547174998693, 18.964988197599137, 15.566191741398402, 12.616106476102557, 5.26687262739454, 2.38499869619097, 1.3582206155572618, 2.8698839460100447, 4.178152441978455, 6.070941618510655, 8.224449787821088, 7.3671402250017435, 3.9324615342276434, 4.19670934336526, 0.8137959805982453, 0.14050871107195104, 0.3546676215316568, 1.7801979609898158, 8.12061938217708, 18.46975186892918, 23.602903808866227, 24.800979954855784, 32.86836658205305, 40.33475487572806, 28.16944578715733, 25.12502482959202, 7.741055795124598, 0.8532866644007819, 0.0394861952933882, 0.023309521809486405, 0.038087140901812484, 0.04332240837227021, 0.04900323586272342, 0.01721287618524262, 0.015336793015844055, 0.04837114656610148, 0.040247548903737745, 0.10479478710996253, 0.038529969818357906, 0.029492069967091084, 0.023784097683216845, 0.018347522443426505, 0.019254798402211497, 0.016840314658890878, 0.0148053711745888, 0.0340771108998784, 0.015066301816010048, 0.0298166743346623, 0.012027386891921716, 0.02672085491940379, 0.04638913220592907, 0.05445865062730653, 0.054235399035470824, 0.07334354227142674, 0.028465497374002422, 0.045308307345424376, 0.022099727797987204, 0.03472002622272287, 0.03143196765865598, 0.17067143826612405, 0.29136698107634273, 0.21556353223110947, 0.10141771832214934, 0.10624362900853157, 0.19453598984650203, 0.12822607372488293, 0.23013120410697802, 0.14195447920688561, 0.1439935312207256, 0.09703764585512024, 0.14993008838168212, 0.06740873573081833, 0.1353157197258302, 0.14679584013564245, 0.24887983234865324, 0.0865616894194058, 0.18431985804012843, 0.13814103097787925, 0.11847116931208543, 0.12605241393404348, 0.20592509156891278, 0.1271031525518213, 0.1461947259626218, 0.11962085190628256, 0.1431234729077135, 0.18636754101940564, 0.11555988767317363, 0.09864151943475008, 0.11878303757735661, 0.13845333350556238, 0.14167466493589537, 0.12676098091261728, 0.09822554354156766, 0.13963425585201808, 0.20746157983584063, 0.17599503403263433, 0.44387144488947733, 3.0158117498670305, 16.106141465050833, 34.94288328715733, 41.4338869367327, 35.357989515577046, 25.194888966424124, 28.296415431158884, 23.243390117372783, 13.421619824000768, 5.608515986374446, 0.6954070361597198, 0.6230565298880849, 3.2854821937424794, 3.5756470007555823, 9.83307501247951, 11.631306154387337, 8.746516585350037, 12.710010511534554, 7.103361853531428, 10.456031390598842, 9.672739250319344, 9.631348831312996, 9.433338199343, 4.369807643549783, 2.9493474534579684, 2.8044744729995728, 3.9878573502813066, 11.111053705215454, 18.817637750080653, 30.659298011234828, 41.38305044174194, 50.353647300175254, 50.94707209723336, 52.30324234281267, 49.33038261958531, 46.9272334916251, 49.51553126743862, 50.33715575081961, 52.18042598451887, 54.03751965931484, 51.40007380076817, 49.66166925430298, 49.055657795497346, 43.862223284585134, 43.3608204296657, 42.42738206045968, 42.25525433676583, 48.44977140426636, 51.595731598990305, 52.73032031740461, 52.93146371841431, 50.00519861493792, 44.21124519620623, 50.33784362248012, 55.191222872052876, 50.06871904645647, 47.076050009046284, 45.35022865022932, 44.84576163973127, 48.23394645963396, 48.98530728476388, 50.48337711606707, 49.57166576385498, 52.3395779473441, 50.89083685193743, 50.02317360469273, 48.32829257420131, 45.8591251373291, 44.69803946358817, 42.939644949776785, 45.93710824421474, 49.42730304173061, 49.135357107434956, 47.14781100409371, 43.07745552062988, 42.72298622131348, 42.54264920098441, 35.254391874585835, 31.97014515740531, 26.89190830503191, 19.479997362409318, 14.66150849206107, 12.300930108342852, 4.819835952350071, 2.045147103922708, 4.496792486735752, 2.549222409725189, 7.031717240810394, 9.598148601395742, 13.548768384116036, 13.114146402903966, 8.400543195860726, 11.828400492668152, 7.205335787364414, 1.6436597790036882, 0.8883745244571141, 2.4590810409614017, 10.522994654519216, 19.62270815031869, 24.704479898725236, 23.32823804446629, 33.125446455819265, 46.89861733572823, 34.20576626913888, 27.979655742645264, 8.627303736550466, 0.780024587043694, 0.12939058909458773, 0.13308674576027052, 0.11698063143662044, 0.16229458419339998, 0.222980584949255, 0.13121381268969604, 0.10396594301398311, 0.17721358793122427, 0.1184108339782272, 0.1876423183296408, 0.1509650849870273, 0.13757011161318847, 0.10929964895227126, 0.08001772128045559, 0.10307229203837258, 0.14975399497364247, 0.14244218303688935, 0.08930417868707861, 0.06657983056668725, 0.1813923322728702, 0.14185724513871328, 0.07519864344171115, 0.2096241930765765, 0.11785527664635863, 0.15183522472424166, 0.2634454279073647, 0.15053397097757884, 0.16971808299422264, 0.09353446454874106, 0.10228880800838981, 0.07462908793240786], [0.055053318717650006, 0.06129755079746246, 0.029754344107849256, 0.04249518936766045, 0.04260786010750702, 0.02397470665164292, 0.032011480669357946, 0.027369420742616057, 0.04691810453576701, 0.06517393993479864, 0.07893403978752238, 0.0717032245759453, 0.054773246603352685, 0.062318277811365466, 0.0280684526078403, 0.01601592175263379, 0.012503531877882779, 0.05281438046534147, 0.07882446995271103, 0.01976005593314767, 0.025720148081226007, 0.04978057575811233, 0.011816212375249182, 0.057808530516922474, 0.020270256591694694, 0.01484463969245553, 0.032382286486348937, 0.027907729714310596, 0.038644085837794204, 0.03738390042313507, 0.01325475496040391, 0.040092391693698506, 0.03569140677739467, 0.03285271142210279, 0.005785468192438462, 0.053081122759197436, 0.025556845058287894, 0.05235741766435759, 0.6825118309685162, 3.6212095958845953, 15.274629695074898, 25.007150377546036, 27.081854684012278, 21.58730956486293, 11.848122085843768, 15.014428343091692, 14.869367327008929, 8.146303398268563, 3.822863689490727, 0.40221449732780457, 0.1540127114525863, 0.6679861875517028, 1.1024708875588007, 3.5345336411680495, 2.804759349141802, 5.524450600147247, 3.1330702006816864, 3.83012455701828, 4.512991777488163, 2.8010969970907484, 3.641152445759092, 4.983582845755985, 1.3568357527256012, 0.5701047969715936, 1.9199279717036655, 3.7482673951557706, 9.771601693970815, 17.39266296795436, 27.239061151232036, 35.3580207824707, 43.01791640690395, 45.05807426997593, 47.69078145708357, 49.34010314941406, 49.24617392676217, 49.440914562770296, 48.716679504939485, 50.33927147729056, 46.101617268153596, 46.74633714130947, 44.93260717391968, 43.54970373426165, 42.09477179391043, 44.08102553231375, 45.62176077706473, 48.4329845564706, 46.91819735935756, 49.6608042035784, 49.727753571101594, 48.923478739602224, 40.06706510271345, 46.114332471575054, 51.0542619568961, 46.29987021854946, 46.12229858125959, 44.22540215083531, 43.8833840233939, 46.39849642344883, 46.53686285018921, 47.59983648572649, 49.57976041521345, 48.51995515823364, 47.72330597468785, 46.80352428981236, 46.18423134940011, 46.34521763665335, 43.88449920926775, 41.96500723702567, 42.76363665716988, 45.67175306592669, 44.34780509131295, 44.39809615271432, 39.43119723456246, 35.893765108925955, 32.264165128980366, 25.653362376349314, 20.543160336358206, 13.72923047201974, 9.830704808235168, 7.279452655996595, 5.890452172074999, 2.230526779379163, 1.6761332707745689, 0.3615286962262222, 3.701043963432312, 2.0653166387762343, 4.0652272786412915, 5.0837016105651855, 4.840998428208487, 2.645900296313422, 1.8788880024637495, 0.3314418563885348, 0.346906022301742, 1.0061810144356318, 5.255342960357666, 16.52544961656843, 21.30978635379246, 24.803759234292166, 22.65113956587655, 26.92850967815944, 44.85307461874825, 27.379393918173655, 11.457615954535347, 2.0328885274274007, 0.03202007092269404, 0.03892829023035509, 0.014500064342947943, 0.055105226646576605, 0.04307618497737816, 0.0385621052368411, 0.07913019747606345, 0.023496658374954547, 0.007436059332186622, 0.01582564865904195, 0.028666710148432424, 0.043425389632050476, 0.014944143460265227, 0.00490506476489827, 0.043658490159681866, 0.03390776552259922, 0.07113636285066605, 0.04681513684668711, 0.03734707972034812, 0.04093311354517937, 0.03868583949016673, 0.04042157956532069, 0.041945413154150755, 0.08383009742413249, 0.03281872360301869, 0.06861666377101626, 0.04125753131562045, 0.043816883981760056, 0.053255238237657716, 0.0301298419944942, 0.04494640730055315, 0.04089482042140194, 0.0212163566279092, 0.06917064690164157, 0.008060322575537222, 0.08471508350755487, 0.0033316173316312154, 0.0164380502620978, 0.04680297410647784, 0.048163664128099165, 0.029787799276943718, 0.01696245096224759, 0.05882872827351093, 0.026952362586078898, 0.020070906395890882, 0.03103978798857757, 0.016262026403897574, 0.05796712450683117, 0.03806319200832929, 0.0466208587001477, 0.015564388928136655, 0.07083005178719759, 0.0565966635809413, 0.03264467937073537, 0.016043578839993904, 0.02458254510669836, 0.07638179816837821, 0.03434340536062207, 0.04080173220219357, 0.02450768742710352, 0.03784752983067717, 0.014570838938068067, 0.007966814512786056, 0.040949869967464886, 0.029795768670737743, 0.042394582980445454, 0.04368128893630845, 0.03330421880153673, 0.051745942261602194, 0.06852469513458864, 1.198318030153002, 6.27798056602478, 21.187887157712662, 32.3321567262922, 30.906369004930767, 23.679940223693848, 16.76772461618696, 17.072352749960764, 16.35984104020255, 10.212767141205923, 4.87444749048778, 0.37288039709840504, 0.15637553323592457, 0.4398951211145946, 0.904172339609691, 2.89556405373982, 4.93346505505698, 6.4222842284611295, 5.712713778018951, 7.13669627053397, 5.760696734700884, 5.259639986923762, 5.652997919491359, 5.293450789792197, 2.5448383135454993, 2.4786964569772993, 2.9674696581704274, 6.04879640681403, 11.94037766116006, 20.997621161597117, 29.032933167048864, 39.50729043143136, 44.027586936950684, 47.52983685902187, 48.11799144744873, 49.73137010846819, 47.80310950960432, 49.53739030020577, 48.953331674848286, 52.427893025534495, 48.29608767373221, 48.65105029514858, 46.28777340480259, 46.34807334627424, 43.58275284085955, 45.05079255785261, 45.00381926127842, 50.299986362457275, 49.636520249503, 51.287572043282644, 52.503722190856934, 50.41095951625279, 41.67559044701712, 49.215713024139404, 51.64017227717808, 49.89826931272234, 47.05478504725865, 45.8705028125218, 46.85051495688302, 48.26856585911342, 47.63200317110334, 49.38382468904768, 49.22684751238142, 50.29454592296055, 49.511265073503765, 46.85402032307216, 47.98956789289202, 46.60825211661202, 44.06243562698364, 43.80501181738717, 43.580803871154785, 46.70932756151472, 45.856186049325125, 46.276652812957764, 41.817410128457205, 39.03960371017456, 34.45209380558559, 28.61121051652091, 21.99477972303118, 17.766665390559606, 11.97606360912323, 7.241791682583945, 4.935380152293614, 2.9687943756580353, 2.123658925294876, 1.2007152672324861, 4.181961791855948, 4.817323744297028, 4.7272264531680515, 6.712747156620026, 4.930815620081765, 3.1368382956300462, 1.375285716993468, 0.4476048531276839, 0.08280165546706744, 0.8181446301085609, 3.752358147076198, 18.586342641285487, 24.431679725646973, 23.334338562829153, 20.306374413626536, 29.061915840421403, 48.006910596575054, 31.096965040479386, 14.37584286076682, 2.909807426588876, 0.006317416746501944, 0.06181879461343799, 0.020470434600221257, 0.047846818808466196, 0.03240575701264398, 0.017431931037987982, 0.03653408959507942, 0.007207741628267935, 0.08424177140529666, 0.0684673860669136, 0.010454631776415875, 0.03675861683275018, 0.02003983118837433, 0.02705129299179784, 0.019738992509831275, 0.0671284736267158, 0.023205549888578907, 0.04563881157498274, 0.06851272577685968, 0.029180174560419152, 0.04216943827590772, 0.029015175199934413, 0.05899679461227996, 0.0865796570266996, 0.016182909220723168, 0.052086010442248414, 0.040837548673152924, 0.046770404425582716, 0.01456526986190251, 0.01684238249436021, 0.029148785530456474, 0.020522327262109945, 0.1304917971470526, 0.16398121868925436, 0.06371049596262829, 0.16941579564341477, 0.11119938415608235, 0.13999925340924943, 0.13587965017982892, 0.17477745722447122, 0.16178129959319318, 0.08038824889808893, 0.14867167733609676, 0.1514979928199734, 0.15427199325391225, 0.19174429321927683, 0.07496047086481537, 0.1463808345475367, 0.11586601553218705, 0.10539516167981283, 0.10900592471339873, 0.12361892951386315, 0.14072544872760773, 0.1459649604346071, 0.16882249819380896, 0.1763366221317223, 0.11594898679426738, 0.13675376613225254, 0.13643670028873853, 0.235947633428233, 0.08568753954023123, 0.0806538410750883, 0.09204470698854753, 0.13161481331501687, 0.08565123113138334, 0.11410981762622084, 0.1679250949195453, 0.09966553055814334, 0.13725115944232258, 0.14503762019532068, 1.0867884776421954, 7.400707840919495, 24.376783745629446, 43.57919883728027, 42.06979649407523, 30.13046714237758, 20.616482939038956, 24.628308534622192, 22.8733412197658, 11.998837198529925, 5.585404975073678, 0.7678829357028008, 0.39338100275823046, 2.405004296983991, 4.883551801953997, 9.773979714938573, 11.177813734327044, 14.178307311875479, 11.785491023744855, 10.931487934929983, 11.486204317637853, 8.953422648566109, 10.243660569190979, 10.610811199460711, 3.3517534605094363, 1.9778342587607247, 2.637535099472318, 4.897879421710968, 11.785410250936236, 18.994535412107194, 29.518025125776017, 37.512188162122456, 44.20769814082554, 47.121918542044504, 49.10912765775408, 50.272287368774414, 48.801232133592876, 49.02896629061018, 50.277602740696494, 52.11751699447632, 50.9789400100708, 50.1024421283177, 49.38108362470354, 47.732324736458914, 45.68531942367554, 47.50554248264858, 48.83752604893276, 52.4456421988351, 52.281299931662424, 52.200297832489014, 54.57612664358956, 52.409181526729036, 45.37150056021554, 51.62886755807059, 53.17623485837664, 51.911614077431814, 49.66251346043178, 47.834671701703755, 47.497211592538015, 50.02037695475987, 49.79328203201294, 52.515256200517925, 51.3240396635873, 50.929805823734824, 49.5645786012922, 48.26430661337716, 48.50356435775757, 49.501464639391216, 46.5533891405378, 45.965074743543354, 45.41981485911778, 50.13692603792463, 47.828949860164094, 47.25020660672869, 42.801865645817344, 39.238158907209126, 33.40390246255057, 27.55061490195138, 21.590788875307354, 14.94677894456046, 11.762226717812673, 8.343664373670306, 7.778738481657846, 3.8782942465373447, 4.1077993256705145, 1.6007510700396128, 7.703868167740958, 6.970600886004312, 9.081272108214241, 11.935336743082319, 10.836147359439305, 8.657719475882393, 5.868524960109165, 1.3706793870244707, 0.9284151473215648, 1.5726672112941742, 7.099093922546931, 21.25492685181754, 28.832684346607753, 31.85913031441825, 31.54409204210554, 34.775098187582834, 51.61336612701416, 35.81866203035627, 15.852160487856183, 3.31719377211162, 0.124547558969685, 0.21294514701834746, 0.38193913815276964, 0.202438371522086, 0.09946551879069634, 0.17288818503064768, 0.2084748904619898, 0.1039097670997892, 0.166609415518386, 0.12275432662240096, 0.12797741778194904, 0.10463487676211766, 0.1581075888659273, 0.0721763874004994, 0.10117495206317731, 0.13301767089537211, 0.18630389443465642, 0.11551376086260591, 0.20138639797057423, 0.13517788212214196, 0.1344479684318815, 0.08811400112296854, 0.1544281920152051, 0.2249495442956686, 0.0852486766608698, 0.10898940917104483, 0.1526911695088659, 0.17100272620362894, 0.11323953539665256, 0.178929562281285, 0.10157264143760715, 0.18606053106486797], [0.045308585544782023, 0.03438802582344838, 0.03976094430046422, 0.034253692853131464, 0.08619800822011062, 0.02941904602838414, 0.02151890521469925, 0.02140922342160983, 0.02983426535502076, 0.04427398248974766, 0.08223971990602356, 0.0355523274546223, 0.0014354368031490594, 0.022921559234548892, 0.0390847196935543, 0.036992636775331836, 0.09573975085679974, 0.03331535695386784, 0.05287626964439239, 0.09954633909676756, 0.038504002283194234, 0.08088234452796833, 0.10261677112430334, 0.018182283899347697, 0.021667171901624118, 0.047625117669148107, 0.048592145421675274, 0.07979765201785735, 0.01940050022676587, 0.012385674585987414, 0.05300932018352406, 0.02664557485175984, 0.04022351519337722, 0.02589835342951119, 0.01941841185492064, 0.04886468918994069, 0.04722507717087865, 0.049857375744198046, 0.10545997534479414, 0.8586083331278392, 5.449859082698822, 16.957354852131434, 25.86991340773446, 23.391219990594045, 24.544709546225413, 19.95998760632106, 11.871207475662231, 10.218461189951215, 7.102717408112117, 2.764545564140592, 0.6646727653486388, 0.14612409046718053, 0.5325091257691383, 1.3645889652626855, 3.1958654139723097, 5.258987724781036, 3.7492423142705644, 4.683600885527475, 4.685944599764688, 3.7182012370654514, 2.822919551815305, 2.968723156622478, 2.196429363318852, 2.7126596740313937, 1.9454508764403207, 2.118947829518999, 3.56088707276753, 12.125030381338936, 19.355075699942454, 26.94322943687439, 33.74030644553048, 41.58763320105416, 45.84725066593715, 50.597167764391216, 50.264262199401855, 51.67523636136736, 48.509459904261995, 51.942220892224995, 50.39020872116089, 47.69870587757656, 45.26539461953299, 50.38622392926897, 48.94129392078945, 51.07812901905605, 48.7879193850926, 51.72123343603951, 48.593505314418245, 51.63671554837908, 48.14319256373814, 50.64751441138131, 40.164023739951, 44.03427110399519, 52.42909158979143, 46.782683168138774, 48.470873083387104, 47.09803063528878, 47.277283736637656, 48.127941267830984, 47.99313579286848, 49.665139879499165, 49.51820632389614, 48.76141200746809, 48.5232138633728, 49.00180230821882, 48.03034687042236, 46.517890793936594, 44.913721970149446, 43.91553681237357, 43.69272892815726, 44.36970581327166, 46.99260909216744, 41.017807960510254, 32.14578172138759, 28.95798989704677, 22.004158054079326, 16.804044587271555, 11.211420433861868, 8.431356719561986, 3.5589548221656253, 2.0605041427271704, 0.9629834124020168, 0.8847671066011701, 0.7793933323451451, 1.3182047456502914, 3.0808386376925876, 4.77609269959586, 4.136920094490051, 6.686009185654776, 3.6024210155010223, 2.397592523268291, 1.103157673563276, 0.12379332658435617, 0.7492515583123479, 5.100197068282536, 12.209637727056231, 18.25956538745335, 31.06534378869193, 17.710720232554845, 19.77230634008135, 26.856383902685984, 27.42784718104771, 20.815620047705515, 6.052490677152361, 0.12221267925841467, 0.02093912418266492, 0.026928568059312444, 0.03040812277634229, 0.027067396324127913, 0.04704563858519707, 0.03202441693948848, 0.05004970310255885, 0.03266728476488164, 0.036666427672441514, 0.017968923651746342, 0.07267689518630505, 0.015559961487139975, 0.010454165283590555, 0.06812647650284426, 0.028539590005363737, 0.005696712419324155, 0.08267527153449399, 0.012114071436891598, 0.07867752640907254, 0.06245139281132391, 0.028880031380270208, 0.00971620247167136, 0.02428797439539007, 0.030943636183759997, 0.03970776751105275, 0.06088458759976285, 0.04335532410602484, 0.017414317965241413, 0.04100700600871018, 0.00807637841041599, 0.009605659787277026, 0.026598201233095357, 0.04129014849396689, 0.015111231012269855, 0.031931036950222084, 0.022005455535171286, 0.05142254229368908, 0.016808431994702135, 0.034168519744915624, 0.04268957268712776, 0.012474178452976048, 0.06410264170595578, 0.06890908522265297, 0.06584302296063729, 0.06610406895301171, 0.04203737161255308, 0.03402412410027214, 0.02676324300201876, 0.035304092203399966, 0.028597404581627676, 0.02119832795246371, 0.049445901930864365, 0.04027067676984838, 0.07102878112345934, 0.028743913862854242, 0.016341213136911392, 0.03853252450270312, 0.019469592055039744, 0.02715544811716037, 0.08808067148285252, 0.018391276077766503, 0.05743504448660782, 0.016539218137040734, 0.02786776569804975, 0.01920860882715455, 0.041800467896142175, 0.012806447721751673, 0.011888606972726328, 0.04694555466994643, 0.04570237334285464, 0.21981976527188504, 1.5240178789411272, 8.718490157808576, 24.515278714043752, 31.10335738318307, 28.06504910332816, 24.519619601113455, 19.882037503378733, 16.326691184725078, 14.623599120548793, 11.376238652638026, 4.495206126144954, 0.8217877660478864, 0.1395146029868296, 0.24338530004024506, 0.9014544540217945, 3.013401593480791, 4.2523205535752435, 4.237399731363569, 6.298791289329529, 5.291688118662153, 5.72919316802706, 4.860323539802006, 4.67729800088065, 4.011350512504578, 4.330595050539289, 3.4981856601578847, 3.6961037942341397, 6.151952402932303, 14.776456015450613, 20.681629249027797, 30.178722381591797, 33.9321323122297, 43.321601322719026, 46.76971435546875, 49.97405331475394, 50.795639583042686, 51.736269337790354, 48.1009509904044, 52.22698933737618, 51.37570299421038, 49.394024644579204, 46.866499287741526, 50.31831571034023, 49.22467967442104, 52.69869906561715, 49.43481404440743, 52.414781774793354, 50.09737341744559, 54.08045605250767, 49.05527217047555, 51.43775735582624, 42.32259975160871, 46.60669572012765, 53.16739674976894, 48.945862361363, 49.501933642796104, 48.5585697719029, 48.035509381975444, 49.37185294287545, 50.564410482134136, 49.70872245516096, 49.71489940370832, 48.95754228319441, 48.70540952682495, 50.24096836362566, 48.45763676507132, 47.76105553763253, 47.020895208631245, 46.18834120886666, 45.948308740343364, 45.283140318734304, 47.803877285548616, 42.92330278669085, 36.40473563330514, 31.345988477979386, 24.92355833734785, 19.036938531058176, 14.340028371129717, 9.303221021379743, 5.3141403538840155, 3.025766347135816, 1.889866156237466, 2.6529501123087744, 3.054088290248598, 2.836628781897681, 6.393579483032227, 5.5180699825286865, 5.7176417878695895, 6.285360421453204, 4.688369521072932, 2.1149248225348334, 0.6480945806418146, 0.28336914309433525, 0.5704249026519912, 5.502990654536656, 14.012728265353612, 23.67465959276472, 33.32335894448416, 24.528457709721156, 25.803118637629918, 31.427174704415457, 32.45217990875244, 25.173782076154435, 7.51167665209089, 0.5602544226816722, 0.02603062704604651, 0.0699289979945336, 0.064008447474667, 0.02576155398440148, 0.019476872735789845, 0.034807492779301744, 0.06842550010021244, 0.02292330306954682, 0.017581724428704808, 0.06430027860083751, 0.08666729660970823, 0.03766688005998731, 0.01769778784364462, 0.061719239955501895, 0.05333828753126519, 0.02934161839740617, 0.051616301360939226, 0.01599774888849684, 0.050016536310847313, 0.048286482359149625, 0.05835379447255816, 0.03637913255287068, 0.02053410154102104, 0.01613825143847082, 0.052816188761166165, 0.05369256084252681, 0.03309634620589869, 0.026197621299486076, 0.02432386889787657, 0.012007547376145209, 0.03255315517474498, 0.07752568607351609, 0.15084175446203776, 0.11927911452949047, 0.13258792752666132, 0.12202973264668669, 0.13553276950759546, 0.12933470495045185, 0.1826028794582401, 0.1492565745221717, 0.1686338654586247, 0.16271656512149743, 0.14151295647025108, 0.18558958704982484, 0.13206413920436585, 0.10403785415525947, 0.1133970030184303, 0.11535857990384102, 0.19130059917058262, 0.08117082369114671, 0.11399156254317079, 0.2835868442697184, 0.06883357106042759, 0.15013127401471138, 0.13866053095885686, 0.11961465009621211, 0.12936754604535444, 0.09149328193494252, 0.15610801401947225, 0.17683184412973268, 0.1601716381098543, 0.12025396579078265, 0.11389890180102416, 0.11776993051171303, 0.14029905732188905, 0.10226830946547644, 0.06381609636758055, 0.17380907918725694, 0.18219560916934693, 0.12142792636794703, 0.24895816243120603, 1.7479679818664278, 9.658295682498387, 30.301840986524308, 39.683441162109375, 38.46004056930542, 34.3047468321664, 29.20284788949149, 22.37511542865208, 16.66860682623727, 11.26013251713344, 4.139484414032527, 0.9629791783435004, 0.4242953567632607, 1.238665025149073, 3.3936541378498077, 7.8547873837607245, 10.355279905455452, 9.332047360283987, 12.77474514075688, 11.032380989619664, 9.401831592832293, 8.062678354127065, 6.940907759325845, 7.507286259106227, 6.55362993478775, 4.041553463254656, 3.581375139100211, 4.307496198586055, 15.223791463034493, 22.91465868268694, 28.592591081346782, 35.22507742473057, 43.53487280436924, 47.198984486716135, 50.348085267203196, 51.18434265681675, 52.81335823876517, 49.061539445604595, 55.4309982572283, 54.098347663879395, 51.13241182054792, 48.35415724345616, 52.12646280016218, 52.46712255477905, 56.267662116459434, 53.06860031400408, 56.55275712694441, 52.48567077091762, 56.8324533871242, 51.46542508261544, 53.30755581174578, 45.32703903743199, 50.703172956194194, 56.55305242538452, 51.01842662266323, 51.01672083990914, 51.77759027481079, 49.27909101758684, 51.999734606061665, 51.47179658072335, 52.15545415878296, 48.5129201071603, 50.20474393027169, 49.64411810466221, 50.86083105632237, 50.33402211325509, 49.87504843303135, 48.36932863507952, 48.014157567705425, 47.31241730281285, 48.2901782308306, 48.62639808654785, 44.321655545915874, 37.965547697884695, 31.250110285622732, 24.76632755143302, 18.177567958831787, 12.679723313876561, 10.171787534441266, 4.4881220034190585, 3.6151983184473853, 2.2179012511457716, 2.5660515981061116, 5.463810196944645, 4.300467661448887, 9.998123390333992, 10.72702155794416, 11.797548753874642, 13.427358167512075, 10.315938336508614, 4.825985108103071, 3.8475753920418874, 0.5132603900773185, 1.2080072930880954, 7.229105574744088, 16.908611501966202, 25.994192361831665, 38.55071108681815, 26.23481890133449, 29.8594457081386, 37.594576426914756, 36.37058523723057, 26.457006658826554, 7.971652609961374, 0.8258800921695573, 0.14083246727074894, 0.147470996049898, 0.14177058264613152, 0.0886719808248537, 0.17857109223093304, 0.08040183316916227, 0.1225234754383564, 0.0922579298328076, 0.11527220239596707, 0.10907561704516411, 0.17877937534025737, 0.16941084233777864, 0.08147890573101384, 0.08863548921155077, 0.08362418240202324, 0.11892057662563664, 0.1151279051389013, 0.07233439785029207, 0.12130291307611124, 0.13618481451911585, 0.1553503753883498, 0.0885060518713934, 0.13570760084050043, 0.09861978595810277, 0.09000630636832543, 0.11113734569932733, 0.0912178713562233, 0.13715206618819917, 0.08085052123559372, 0.0964791097545198, 0.16404561166252407, 0.14756300539842673], [0.03736258763819933, 0.0343603042752615, 0.051188420570854626, 0.029969480420861925, 0.0515812753832766, 0.039877815172076225, 0.0690861896478704, 0.017725003883242607, 0.08158623640026365, 0.031668287834950855, 0.031399309768208435, 0.04407055429848177, 0.061628356975104125, 0.039544159147356234, 0.09533654499266829, 0.05060656661433833, 0.023969822895846198, 0.03465884272009134, 0.06118187414748328, 0.031037755776196718, 0.02670231055734413, 0.013089259421186787, 0.020520710652428012, 0.004959621100819537, 0.0285964376692261, 0.0051405045420064455, 0.028821582373763834, 0.03222353982606104, 0.002999401921572696, 0.06761895945029599, 0.10571786614933185, 0.10464435589632817, 0.028378393833658526, 0.012045602164497333, 0.019619066534297805, 0.03156079092462148, 0.08161599016083138, 0.024618999400575246, 0.005119032301341316, 0.2778022518115384, 2.4949178951127187, 11.582031267029897, 21.819912672042847, 26.58893210547311, 26.062804085867747, 21.834524733679636, 15.406952926090785, 25.256354468209402, 18.391021830695017, 7.402320691517421, 1.912824741431645, 0.9854432472160884, 0.20571303580488476, 1.1016621823821748, 2.1724437475204468, 3.100439940180097, 2.3590317581381117, 7.317075848579407, 4.085053963320596, 3.3427021290574754, 5.143816121986934, 4.458115773541587, 2.3378905611378804, 2.8885678691523413, 2.4774392672947476, 2.8398655567850386, 2.128281648669924, 4.50751051732472, 7.7700671298163275, 15.653780732836042, 21.95070035117013, 30.740039552961075, 37.73310613632202, 45.99803352355957, 45.88353763307844, 50.45412867409842, 50.72963169642857, 52.08902938025338, 49.05955226080758, 50.027029854910715, 49.547607626233784, 50.372032233646934, 48.47489261627197, 52.346581731523784, 51.056780678885325, 52.751467159816194, 51.3690778868539, 51.93906988416399, 49.31988736561367, 51.858620166778564, 37.8757769720895, 41.901104654584614, 51.62505299704415, 48.545048577444895, 49.96509708677019, 48.049728870391846, 50.510197162628174, 49.95500830241612, 49.052732603890554, 47.66269336427961, 48.691339424678254, 48.63928004673549, 50.347140312194824, 47.48960331508091, 48.71625566482544, 46.559454917907715, 46.23952163968767, 47.549330030168804, 47.077370166778564, 47.38369539805821, 42.03687245505196, 31.632719789232524, 24.437556164605276, 16.616608245032175, 11.3324693441391, 6.003551474639347, 4.268799943583352, 2.6559437002454485, 1.2222781330347061, 0.8960552151714052, 1.8473473063537051, 2.651743297066007, 1.9272752574511935, 1.4193782252924783, 4.595443444592612, 2.5330554715224674, 2.892158133643014, 3.6292697233813147, 3.0367544889450073, 1.466773082103048, 0.27997236964958055, 0.6113156484706062, 4.193092805998666, 10.152844139507838, 15.704853466578893, 22.72079004560198, 23.22859045437404, 14.62137222290039, 21.737296853746685, 22.6999454498291, 16.184802021299088, 5.950138935020991, 0.7122223281434604, 0.020135918532365134, 0.03848665892811758, 0.06538981585098164, 0.004104906585000987, 0.03182989791301744, 0.020559821410902908, 0.019374865173761333, 0.05787681149584906, 0.023777639726176858, 0.024562122898974588, 0.025766003477786268, 0.014895880960726311, 0.026961136043870022, 0.03024536936676928, 0.007115659337224705, 0.003929966262408665, 0.07930001443518059, 0.04577649990096688, 0.025868089071341922, 0.058303236828318665, 0.04682887039546456, 0.047193399763533046, 0.024165057776761905, 0.015254873483042632, 0.022810623848012516, 0.043482352646866014, 0.05634633844186153, 0.04910195931526167, 0.01964534619557006, 0.009085063124075532, 0.03833797833483134, 0.04927539965137839, 0.040931295071329386, 0.027914749159078513, 0.030681019382817403, 0.04884874022432736, 0.019929496305329458, 0.04603736947423645, 0.013492174363428993, 0.027259145231385316, 0.03276756884796279, 0.041531730709331374, 0.005129848997707346, 0.030582604663712636, 0.04574379112039294, 0.04542327831898417, 0.03884921036660671, 0.040768948782767565, 0.038466757496020625, 0.026269681718466536, 0.04773991900895323, 0.03201060535918389, 0.018393203117219464, 0.0315234273938196, 0.03972808963486126, 0.027135987732825533, 0.008200173731893301, 0.011962599520172392, 0.010246518300846219, 0.03765269528542246, 0.0022612319444306195, 0.03786634560674429, 0.010466976024742638, 0.0160147139603006, 0.06505009372319494, 0.06232801478888307, 0.03549820410885981, 0.02347356952460749, 0.05100556216867907, 0.03828119173912065, 0.035669242431010516, 0.061201639872576506, 0.6911816086087907, 3.7000021679060797, 14.868198292595999, 28.281688724245342, 33.528327328818186, 29.44917890003749, 25.284875086375646, 17.08691791125706, 20.038919142314366, 16.59854292869568, 7.806411419595991, 2.3307964503765106, 0.5235680426870073, 0.11781793007893221, 0.3368605827646596, 1.0784173096929277, 2.133385969059808, 2.695424884557724, 4.93478000164032, 5.728095352649689, 5.952550394194467, 6.671159148216248, 5.196334949561527, 3.9838656101908003, 3.7806651081357683, 3.614031672477722, 3.9677579488073076, 4.068944564887455, 5.323937313897269, 10.047552875110082, 17.975960765566143, 24.958419186728342, 32.82191440037319, 40.868136814662385, 49.20927551814488, 47.92508166176932, 51.53832558223179, 51.12222923551287, 53.274975708552766, 50.676213945661274, 51.247064045497346, 51.5635266985212, 52.113723278045654, 50.426426206316265, 53.96162101200649, 52.170851366860525, 52.402768339429585, 53.0228533744812, 52.727690424237935, 49.68842329297747, 51.78382975714547, 40.2992912701198, 45.37713554927281, 52.88023117610386, 49.524761949266704, 50.930775097438264, 49.99503340039934, 50.425269331250874, 49.567493370601106, 49.85314771107265, 47.990061214991975, 49.773434502737864, 48.495921339307515, 49.28103303909302, 47.2229905128479, 48.787168979644775, 47.90241316386631, 46.145599365234375, 47.40395287105015, 47.03943995067051, 48.848233222961426, 45.44028425216675, 35.69969844818115, 28.51604277747018, 18.933148077556066, 13.575980135372706, 8.34897540296827, 6.369885257312229, 4.0737718258585245, 3.1695050341742377, 2.4092752678053717, 1.6968476963894707, 4.451452451092856, 3.8621640035084317, 3.7713988167898993, 4.779300596032824, 4.468408226966858, 5.277718765395028, 5.664799000535693, 2.7756581221308028, 0.9198466071060726, 0.1648708866643054, 0.5355676902191979, 4.043967528002603, 10.738698874201093, 19.492938382284983, 26.484370401927404, 28.21682207924979, 17.408525705337524, 23.63907786778041, 28.453199795314244, 19.661697966711863, 8.244269524301801, 1.2028159030846186, 0.029790594841220548, 0.0298797305939453, 0.05624264132763658, 0.03992663576666798, 0.054755136503704956, 0.009591493672425193, 0.025216502070959126, 0.03639254040483918, 0.04341635154560208, 0.04240663715505174, 0.02125289913133851, 0.042384350672364235, 0.04329502269891756, 0.01160282498624708, 0.01724385639785656, 0.04220487815993173, 0.07832369753824812, 0.03041326267910855, 0.05154672438012702, 0.03327840732942734, 0.035957996400871446, 0.024745186557993293, 0.02545955840365163, 0.028466182694371258, 0.04302651282133801, 0.03510051812710507, 0.04772687417321971, 0.03490047582558223, 0.009312696355794157, 0.02180742678631629, 0.03726984886452556, 0.05056748299726418, 0.008851506281644106, 0.09320390264370612, 0.08980801129447562, 0.1247538471860545, 0.14793846596564564, 0.1520269787205117, 0.07841996808669396, 0.11998434311577252, 0.08234314899891615, 0.13907936348446778, 0.11723732123417513, 0.10168272695903267, 0.14493950403162412, 0.15804486508880342, 0.1461557780525514, 0.15037934641752923, 0.1640925934272153, 0.1221021187624761, 0.1960038917937449, 0.1867876084787505, 0.1737807435648782, 0.2110633115683283, 0.10154581216296979, 0.141643615173442, 0.13596511845077786, 0.2174500631434577, 0.04648159956559539, 0.0822102375594633, 0.12689700004245552, 0.08880500082990953, 0.09826233371027879, 0.25020704684512957, 0.1670065756355013, 0.12053854337760381, 0.19470622071198054, 0.102889942537461, 0.16179231900189603, 0.1451280689133065, 0.15049183395292076, 0.2257866800895759, 0.6365602995668138, 4.083931394985743, 16.393972328730992, 34.34933342252459, 41.81663193021502, 38.59860849380493, 32.26569720676967, 24.432530879974365, 33.987492084503174, 25.781589644295828, 11.772723708833967, 3.2241810602801184, 1.4677894732781818, 0.5501004989658083, 2.6091430229800086, 4.827334361416953, 8.340353557041713, 8.869386792182922, 14.13504695892334, 12.275656035968236, 10.543001123837062, 13.726257511547633, 12.461238946233477, 7.8581303358078, 7.342228327478681, 5.784124757562365, 6.8549016543797086, 3.8651955894061496, 6.134843332426889, 9.44535163470677, 16.840387140001567, 23.87048762185233, 33.3847393308367, 40.663713863917756, 48.48615217208862, 48.216273716517854, 51.260665144239155, 51.910252230507986, 53.906323773520334, 52.21600423540388, 54.50202757971627, 54.11567299706595, 54.14114161900112, 52.509037562779014, 56.980682781764436, 55.94996615818569, 55.09511538914272, 55.81812061582293, 52.971183095659526, 49.19996493203299, 49.93151991707938, 43.52412394114903, 47.063133307865684, 53.14503049850464, 54.53495856693813, 52.49446024213518, 51.20168536049979, 52.40047890799386, 50.88411099570138, 50.585522583552766, 47.72020707811628, 49.56501633780343, 48.71108967917306, 50.696495737348286, 47.158601556505474, 48.929926667894634, 47.88206189019339, 49.04328652790615, 50.62629461288452, 49.80286012377058, 48.85953794206892, 47.346029213496614, 37.56078038896833, 27.085365261350358, 18.420105252947124, 13.947683572769165, 6.9491713387625555, 5.2034043073654175, 3.689139093671526, 2.4100387011255537, 1.562727921775409, 4.849192959921701, 5.938429049083164, 5.707724971430642, 5.89744336264474, 8.84161571093968, 8.611236027308873, 7.623161367007664, 10.980094058173043, 6.278001844882965, 2.882566145488194, 0.9522990371499742, 1.3410515082733971, 5.720534409795489, 13.506889854158674, 21.813608918871196, 29.828328200748988, 31.51626103264945, 22.393806082861765, 30.396256583077566, 34.32514326913016, 22.53061090196882, 9.3172607251576, 1.5447194938148772, 0.14294997150344507, 0.12481696451348917, 0.13291472356234277, 0.1688021421432495, 0.16527943259903363, 0.06946948729455471, 0.12244989510093417, 0.12516039822782787, 0.20812376216053963, 0.15258691938860075, 0.15291756950318813, 0.07581976082708154, 0.09740494364606482, 0.10759829024651221, 0.10646833266530718, 0.11428224694515977, 0.15075461699494294, 0.14981872721442155, 0.2367023000759738, 0.08433702415121452, 0.09316806920937129, 0.13748066712703022, 0.08304420459483351, 0.09000233693846635, 0.10337398227836404, 0.1394372092826026, 0.1798374421362366, 0.1070680965536407, 0.1422762405127287, 0.19996167799191816, 0.12672880478203297, 0.16362512351146766, 0.12183056904801301], [0.029918264597654343, 0.02621811644972435, 0.06518015531556946, 0.04523726812164698, 0.01187161136684673, 0.04261106957814523, 0.010595114818508071, 0.0675522391019123, 0.06268360785075597, 0.025697742854910235, 0.009484664270920413, 0.04913566893498812, 0.011221345813412751, 0.005551904988741236, 0.04478259198367596, 0.05165591762800302, 0.017402258701622486, 0.07797918495322977, 0.06665331590920687, 0.0062494983597259435, 0.022194425841527324, 0.01933333374160741, 0.010650214406528642, 0.011700087043988918, 0.032054153736680746, 0.06470696534961462, 0.009715853026136756, 0.05691294910918389, 0.031655846895383935, 0.0693864074668714, 0.057773287408053875, 0.013000100767905158, 0.05668876113902245, 0.00968089999098863, 0.04093865378360663, 0.006044305553327182, 0.027907310718936578, 0.04233074301321592, 0.02067813925844218, 0.06109765438096864, 0.5802747341138976, 4.670978614262172, 18.476319653647288, 30.292422703334264, 35.610716342926025, 25.562433038439067, 27.31296740259443, 34.52139861243111, 32.30219609396798, 32.27221114294869, 14.856613908495222, 2.7467397195952277, 0.41828977902020725, 0.21543117719037191, 0.5819339965070996, 1.5153615091528212, 1.7473341758762087, 4.040574201515742, 3.3235965371131897, 4.254331188542502, 2.560320637055806, 3.5151262368474687, 2.4446811165128435, 3.2317841265882765, 3.393210538796016, 2.8944675411496843, 5.417586871555873, 1.68619176532541, 2.404906153678894, 6.564592889377049, 10.039089100701467, 18.482392379215785, 24.03753273827689, 31.491921492985316, 37.72239201409476, 46.6896641595023, 46.66974714824131, 51.82188504082816, 50.372334480285645, 52.25880513872419, 50.36594908578055, 51.908768790108816, 52.20878158296858, 53.172580105917795, 50.7336824962071, 53.89886140823364, 50.55702107293265, 51.776256220681326, 48.11796018055507, 52.84232527869088, 39.2387911932809, 43.697408539908274, 51.640648228781565, 47.084349632263184, 49.30221809659685, 49.66963883808681, 51.26244388307844, 48.77176482336861, 48.90542731966291, 49.417968136923655, 48.78296184539795, 48.11425331660679, 48.72567394801548, 50.5316219329834, 48.38017477308001, 48.65904419762747, 47.61405944824219, 48.20666435786656, 47.34271492276873, 40.14132397515433, 31.30522687094552, 23.64802019936698, 15.83056548663548, 8.120656728744507, 4.318178185394832, 3.0320918134280612, 1.51766722542899, 0.522474895630564, 1.5875411331653595, 2.9988653106348853, 1.1722488233021326, 4.4353717139789035, 2.091323963233403, 3.480694438729967, 3.641133555344173, 4.124429838997977, 4.269224217959812, 3.4022927028792243, 2.8560998056616103, 0.9729141252381461, 0.7093851289578846, 4.200785764626094, 10.228364978517805, 17.907076324735367, 14.279393179076058, 17.430553231920513, 19.836132492337907, 23.848840509142192, 23.978584221431188, 17.447320972170147, 6.890683574335916, 1.384470909833908, 0.03655984678438731, 0.010299441487794476, 0.034767835800136836, 0.038012274740529914, 0.04848722355174167, 0.03334827947297266, 0.011334510187485387, 0.03809781086498073, 0.11388522253504821, 0.027854193301339234, 0.052673333391015015, 0.009551333729177713, 0.03967338614165783, 0.015183722300987159, 0.04686058172956109, 0.0708020350762776, 0.021427518422050134, 0.032209290590669425, 0.02894686029425689, 0.06874404515006713, 0.011717073320012008, 0.05265320125701172, 0.037781253922730684, 0.01239404346727367, 0.030338735785335302, 0.04284778330475092, 0.04893545699971063, 0.060783282321478636, 0.008885974164253898, 0.03430896631575056, 0.05115752347878047, 0.08410722469644887, 0.08259731464620147, 0.058221032310809405, 0.018132669418784123, 0.014682208587016379, 0.025881050786535655, 0.017892880232206414, 0.01617891264946333, 0.025447346469653503, 0.00550711149948516, 0.022712260019034147, 0.03275978944397398, 0.03403489584369319, 0.0662566918347563, 0.027569759903209548, 0.0506044224436794, 0.05692984123847314, 0.04590859370572226, 0.03280639801440494, 0.037069450332117934, 0.03341979367126312, 0.005230482526323093, 0.09937386228037731, 0.055674928040908914, 0.05098803560914738, 0.0105570837788816, 0.029245480163288966, 0.04658977161826832, 0.03374386538884469, 0.011468637900959169, 0.008371983039458948, 0.04960534069687128, 0.08546353477452483, 0.07438993147973504, 0.051926507215414724, 0.021229320039440478, 0.011217406069460725, 0.01051163804783885, 0.042816682652171166, 0.031200305625264133, 0.022677831152187924, 0.04423678180735026, 0.1757021647478853, 1.0294086251940047, 7.6865732329232355, 22.514904499053955, 36.081640924726216, 39.1465608051845, 26.825436626161846, 29.483162539345876, 40.61302675519671, 36.88769449506487, 30.405900682721818, 10.137558102607727, 3.6568686195782254, 0.8331685896430696, 0.1012729596612709, 0.27306572454316275, 1.102115769471441, 2.3466891518660953, 3.130447255713599, 4.552378509725843, 6.410132263387952, 6.398770221642085, 5.0768411329814365, 3.952077601637159, 4.36697929246085, 3.2727900062288557, 4.4589912465640476, 3.3869903811386655, 2.6099153586796353, 3.962036107267652, 6.169662492615836, 13.497276152883257, 21.43396282196045, 28.01336666515895, 35.49945831298828, 40.86429098674229, 48.65680340358189, 48.23849752971104, 52.218873841421946, 51.05756235122681, 53.93852867398943, 51.68357767377581, 52.545185565948486, 54.57040480204991, 53.106172697884695, 52.33229276112148, 54.90859794616699, 50.67140926633562, 51.31507648740496, 49.11967849731445, 52.679720061165945, 40.50754267828805, 46.12733602523804, 52.958995955330984, 50.93060139247349, 52.37706695284162, 50.2716064453125, 52.37328365870884, 50.40560940333775, 49.64276320593697, 50.58846861975533, 49.53313452856881, 48.80070059640067, 48.25906767163958, 49.83264357703072, 48.70991890771048, 49.528597354888916, 49.097958428519114, 49.91663687569754, 48.50690991537911, 44.18087462016514, 35.93265070234026, 27.592639344079153, 18.52489972114563, 10.938772252627782, 5.001242126737322, 4.8432522501264295, 3.2815158580030714, 2.8501651755401065, 2.9489991750035967, 6.230240796293531, 5.940495703901563, 6.651019794600351, 5.400062211922236, 3.9731614759990146, 6.0749320558139255, 4.478948209966932, 4.515523961612156, 2.9389462172985077, 1.0930944021259035, 0.35952017828822136, 0.6165526360273361, 4.133523293903895, 13.243606107575552, 21.342559269496373, 17.471356528145925, 18.850476673671178, 23.57374743052891, 25.117939404078893, 29.37213032586234, 21.49652440207345, 9.541349683489118, 2.045924867902483, 0.08749341978026287, 0.03314030509708183, 0.010954848640332264, 0.048955222724803855, 0.025629110734111497, 0.027277299435809255, 0.09065249562263489, 0.0868530184296625, 0.04140401684812137, 0.01719022838265768, 0.11398450577897684, 0.015111219137907028, 0.007802262137244854, 0.01693770139744239, 0.0025713570108304596, 0.04670841685895409, 0.06691573254231896, 0.019429807850558842, 0.05412802426144481, 0.03561523782887629, 0.03431636234745383, 0.03482842219195195, 0.055325136453445466, 0.05152013598542128, 0.08819553389080934, 0.08729688211211137, 0.04172497069729226, 0.07888971788010427, 0.01854317631971623, 0.009366109784293388, 0.0029306601749600042, 0.03855832918946232, 0.07135510218462773, 0.03894593214083995, 0.1150599295007331, 0.0871103596208351, 0.21839581882315023, 0.1945058357502733, 0.11467673363430159, 0.14648919659001486, 0.08126495685428381, 0.12525529813553604, 0.11961010391158716, 0.09188674403620617, 0.13248655439487525, 0.18138466482715948, 0.11802052706480026, 0.12260225335402147, 0.14019244589975902, 0.11676299811473914, 0.15581275629145758, 0.21538386972887175, 0.15857761007334503, 0.16243718511291913, 0.10565704905561038, 0.11125723605177232, 0.11101008645657982, 0.09012258691447121, 0.15134726305093082, 0.15585093067160674, 0.11693736804383141, 0.15292112502668584, 0.13775858149996825, 0.17112327473504202, 0.1319973984999316, 0.09511914915804352, 0.11980683835489409, 0.11408325976559094, 0.11162584341530289, 0.0898607334654246, 0.07849567223872457, 0.176066592335701, 0.13490971151207173, 0.14777356838541372, 1.2421596433435167, 7.459431409835815, 26.342377015522548, 43.131463868277415, 49.2372350692749, 34.81183678763253, 37.30676119668143, 44.212905815669465, 40.55890028817313, 37.599996021815706, 17.055984531130107, 4.344544861997877, 0.6689738631248474, 0.679360497210707, 1.9800856922354018, 4.932909633432116, 8.664923889296395, 10.227678843906947, 9.249383773122515, 10.392274720328194, 9.531245265688215, 8.892095242227827, 5.813294163772038, 8.097120574542455, 6.6278184567178995, 6.295555165835789, 9.327723843710762, 3.4558908896786824, 4.492605762822287, 8.514173167092459, 12.59213866506304, 20.329737731388636, 27.47790026664734, 34.49725014822823, 39.58571474892752, 48.85689067840576, 47.994282245635986, 54.97105182920183, 54.22097989491054, 56.55605752127511, 53.70164026532854, 54.39327437537057, 54.97197593961443, 55.41328035082136, 53.38799510683332, 55.42283412388393, 51.79219191414969, 51.747341292245046, 48.903301170894075, 54.01501791817801, 44.67868178231375, 48.17828444072178, 52.37007359095982, 51.60955851418631, 53.977257932935444, 53.360299587249756, 53.40755081176758, 52.713943413325715, 50.9097706930978, 51.850431714739116, 50.855630329677034, 48.66988338742937, 48.94945110593523, 50.591345173971995, 47.4501827103751, 50.66230712618147, 49.07422685623169, 49.10278047834124, 50.80017328262329, 45.855063915252686, 37.565532956804546, 26.47911408969334, 18.94792342185974, 10.945169806480408, 5.200123020580836, 4.008304161684854, 3.4941726412091936, 1.8425626030990054, 4.482618161610194, 8.605296186038426, 5.312946566513606, 10.600566080638341, 5.317915831293378, 9.451228942189898, 10.329026137079511, 11.021774564470563, 11.402331743921552, 9.650960990360804, 6.7132374388831, 2.0104304296629767, 1.4193705171346664, 4.968477027756827, 14.339029567582266, 23.452411038534983, 21.35486626625061, 25.910431827817643, 29.532223769596644, 32.15057250431606, 34.79009240014212, 23.278160640171595, 9.787704144205366, 2.1739747396537235, 0.15848739205726556, 0.10709339912448611, 0.1918982392443078, 0.16525326828871453, 0.07887451191033636, 0.08309893522943769, 0.2472441286912986, 0.16599386212016853, 0.14532959381384508, 0.08286927826702595, 0.27471475462828365, 0.1386735588312149, 0.09443040218736444, 0.18788778515798704, 0.11324665322899818, 0.15164150297641754, 0.20771332989845956, 0.08521114010363817, 0.09910035838506051, 0.11127959378063679, 0.0798445116462452, 0.10232337936758995, 0.10935121761368853, 0.2186072910470622, 0.10515559810612883, 0.22073665607188428, 0.1452386701213462, 0.18490434810519218, 0.10724909576986517, 0.17055620944925717, 0.16235690084951265, 0.23850565616573605, 0.2270585668406316, 0.08951273999576058], [0.051652538523610146, 0.04385736198829753, 0.05243703017809561, 0.06810962169298104, 0.018150918618110672, 0.005873820661301059, 0.03229614985840661, 0.018802244382511293, 0.019306372152641416, 0.022353214910253882, 0.05421741785747664, 0.017663711815008094, 0.0176010304463229, 0.04267546255141497, 0.05412387162713068, 0.0768471374841673, 0.004782671890487629, 0.030313704628497362, 0.03046296876189964, 0.027380521575521146, 0.02411011340362685, 0.0034519101401591407, 0.08005665561982564, 0.05590344506448933, 0.0406811259953039, 0.041809373668261936, 0.0035905554125617656, 0.027351488758410727, 0.013538103550672531, 0.11020781379193068, 0.04102010512724519, 0.06690870291952576, 0.0305490884264665, 0.006994730826201183, 0.024530903502766575, 0.039175789271082194, 0.04923799880115049, 0.029018774828208343, 0.06688969715365342, 0.029885962938091586, 0.14948460300053867, 1.2974908628634043, 8.03320322717939, 20.071898766926356, 35.866712297712056, 37.71555846078055, 26.17813549722944, 9.471116423606873, 6.990795390946524, 17.51562523841858, 21.743010010038102, 9.286957025527954, 3.2265666808400835, 0.7178279502051217, 0.2368483750947884, 0.3706467140998159, 1.211857680763517, 1.1898447019713265, 4.458839688982282, 3.9762655837195258, 5.637090018817356, 3.853255544389997, 4.330626751695361, 2.2121329435280392, 2.8368189888341084, 3.0019846175398146, 2.776724453483309, 2.492698379925319, 0.8215175462620599, 1.3325165148292268, 3.210920206138066, 5.827942269189017, 10.19261736529214, 19.617491790226527, 24.642430748258317, 31.02430772781372, 45.23978008542742, 50.46279307774135, 53.06472669328962, 53.013747760227744, 52.059322357177734, 50.6460657119751, 50.72067199434553, 51.58608055114746, 51.32489776611328, 50.25359671456473, 51.264900071280344, 52.58069780894688, 50.979457650865825, 52.53792469842093, 44.786184310913086, 45.585657937186106, 51.54931763240269, 47.91878659384591, 49.104990005493164, 47.44294963564192, 48.47409357343401, 50.31315319878714, 51.37886095046997, 50.06967789786202, 51.6877326965332, 51.09059408732823, 49.354298319135395, 47.450748988560264, 46.63434607642037, 49.16140937805176, 46.2946069581168, 43.09667076383318, 38.63671588897705, 31.836121354784282, 22.571756396974834, 14.297863227980477, 6.150513257299151, 3.2275029506002153, 0.7964313466634069, 1.4095314336674554, 0.986655165042196, 3.50938680768013, 2.745888565267835, 6.580954594271524, 3.5478539892605374, 5.074953394276755, 5.048163311822074, 2.3759048070226396, 2.8823831038815633, 2.594619985137667, 3.382056725876672, 2.3649240476744513, 0.3603294262928622, 0.9183730461767742, 3.6798975552831377, 11.251953618867056, 12.348504424095154, 11.381686040333339, 10.766695771898542, 17.947292498179845, 22.243851797921316, 26.9542874949319, 14.219307763235909, 7.366172688347953, 1.3133033343723841, 0.161583791619965, 0.01897106389515102, 0.0432214525395206, 0.038949921926749606, 0.00879351019726268, 0.04829750855320266, 0.016345301310398748, 0.03171919831740005, 0.052069993623133214, 0.02020323938424034, 0.049560618453792164, 0.02827282396278211, 0.053390999524188895, 0.006761536151835961, 0.017937505784045373, 0.05088929519323366, 0.009109626939919378, 0.03153906423332436, 0.014349631432976042, 0.06600741842495543, 0.02883630319099341, 0.02823928228047277, 0.023218730431316153, 0.03065758617594838, 0.12038245318191391, 0.03490913053974509, 0.022362163090812306, 0.05827190886650767, 0.04447796707972884, 0.06853302754461765, 0.04045073621507202, 0.043876975043011565, 0.0538154096076531, 0.029855198160346066, 0.04048878845891782, 0.03596017110560622, 0.02187751097205494, 0.0032470400619786233, 0.03703554393723607, 0.057474433444440365, 0.039189614422087155, 0.04234574202980314, 0.020771212210612636, 0.011332580603526106, 0.06070042641035148, 0.05366533123222845, 0.044753068925014565, 0.04274485293509705, 0.044618634174444845, 0.04534136557153293, 0.03217036982199975, 0.04869300965219736, 0.018186402606910894, 0.043846590244876485, 0.009542445768602192, 0.02734594851998346, 0.03557401004114321, 0.056203215050378015, 0.008398278815937894, 0.10185592302254268, 0.06387468786644084, 0.053531530911901166, 0.026121113083458374, 0.0407495562519346, 0.08517333213239908, 0.028625071847013066, 0.03106712277180382, 0.031035709993115494, 0.03839533829263278, 0.012146988018815006, 0.025443923260484422, 0.028595491112875085, 0.022281800795878683, 0.044463127518871, 0.020317034795880318, 0.24377714044281415, 2.4540034277098517, 11.640796525137764, 26.219319207327707, 41.20163297653198, 39.45539781025478, 30.405858993530273, 14.131226318223135, 13.75236623627799, 28.030520030430385, 28.07797622680664, 8.456140075411115, 4.173261778695243, 1.250988198178155, 0.14815481007099152, 0.13675624957042082, 0.5067142641970089, 1.3364337789160865, 3.833310306072235, 6.553692902837481, 5.239259617669242, 5.786661718572889, 5.732741960457393, 3.823618003300258, 4.484683947903769, 3.647850726331983, 2.920728909117835, 2.4490408939974646, 1.7115915566682816, 3.0632464502538954, 5.763678380421229, 7.569091354097639, 13.040734342166356, 23.172923224312918, 28.625463008880615, 34.89573975971767, 47.00366367612566, 51.110194955553325, 54.787897314344136, 54.73723105021885, 54.114957332611084, 53.33752686636788, 52.59993737084525, 52.99639810834612, 53.473318985530305, 52.021343503679546, 52.11193411690848, 51.432143211364746, 50.797946384974885, 51.140141691480366, 45.655973706926616, 47.19789709363665, 51.98281921659197, 49.45120137078421, 49.945711612701416, 49.27933420453753, 49.6021614074707, 51.60151250021798, 52.086163248334614, 51.10599824360439, 51.962586062295095, 51.52045134135655, 49.02563462938581, 49.0415494782584, 47.96187237330845, 51.377690179007395, 46.701229436056956, 46.338967732020784, 41.337105478559224, 36.33746664864676, 25.947175639016287, 17.316133771623882, 8.768683075904846, 4.958964509623391, 1.9022682564599174, 3.589736644710813, 3.3353869787284305, 5.6705134596143445, 3.9521622828074863, 7.3913573026657104, 5.192410954407283, 8.00644224030631, 8.151603136743818, 6.3000237260546, 4.854261236531394, 4.195667113576617, 3.584368944168091, 1.044622574533735, 0.31311182997056414, 0.5263216463582856, 3.2830192744731903, 10.654342532157898, 15.388599259512764, 15.87715663228716, 12.835842388016836, 18.258266074316843, 24.970727920532227, 29.92052732195173, 19.101838179997035, 9.599178671836853, 2.5022154578140805, 0.1906365712306329, 0.04461915325373411, 0.019222130333738666, 0.01331627688237599, 0.00859965443877237, 0.04230633271592004, 0.02075750580323594, 0.02819790012602295, 0.04102247999981046, 0.0358921004725354, 0.10560139561338083, 0.044050710541861396, 0.03763940956975732, 0.007980697339267602, 0.04780414913381849, 0.06240928971341678, 0.04946047347038984, 0.02766915171274117, 0.012488102839727486, 0.09351474632109914, 0.032483771576413085, 0.030229807166116576, 0.030649752489158084, 0.05646992002480796, 0.01310488099365362, 0.05229556919740779, 0.02754981436633638, 0.04716542376471417, 0.017108500535999025, 0.13685950902955873, 0.036007512493857315, 0.042357616392629485, 0.07752385402896575, 0.019387365485142385, 0.031188210738556724, 0.14147817476519517, 0.10363860415028674, 0.08953032762344394, 0.1461716014891863, 0.11714945094926016, 0.07735603196280343, 0.11975250127060072, 0.12241248068000589, 0.08503216970711946, 0.16218649356492928, 0.14191805544708455, 0.16890105897826807, 0.1382057767893587, 0.1922561257545437, 0.13791277179760592, 0.23148642852902412, 0.12746806868485042, 0.07835685754460947, 0.11194903643003531, 0.07089238879936081, 0.1383419180555003, 0.15685331688395568, 0.1771428302994796, 0.1339731431965317, 0.16209894897682325, 0.17856460543615477, 0.08247462872947965, 0.09812328152890716, 0.12213994030441556, 0.16961234009691648, 0.1524879482707807, 0.17391315288841724, 0.13538311182388238, 0.09007202248488154, 0.08151690369205815, 0.29743178135582377, 0.10768208932131529, 0.10045111126133374, 0.0866782074528081, 0.1648934818804264, 0.37493524540747913, 2.6081687552588324, 10.640004924365453, 28.770572662353516, 45.951421533312114, 49.46352400098528, 35.945438861846924, 16.656327622277395, 12.707774928637914, 24.848458732877457, 28.743255819593156, 12.542215858186994, 4.559286321912493, 1.199414108480726, 0.9871064722537994, 1.2831801793404987, 3.509139278105327, 6.7525308047022135, 12.203401718820844, 13.759995358330862, 12.749966127531868, 10.282583509172712, 10.699072429112025, 5.861776087965284, 7.412432057516916, 6.22263686146055, 5.47155396427427, 4.496064228670938, 2.5187269832406725, 3.2016830103737965, 4.212239870003291, 7.263298528535025, 12.377832770347595, 22.3970456804548, 28.79222846031189, 32.906856128147666, 46.711175782339915, 51.523682253701345, 54.967692375183105, 56.953369413103374, 55.149057728903635, 55.45752995354788, 54.04728882653372, 55.191966329302105, 54.83376237324306, 52.52689790725708, 52.4495609828404, 51.940358775002615, 50.556340149470735, 52.99761751719883, 47.74858352116176, 51.340489523751394, 51.44680738449097, 49.070089203970774, 51.820460660117014, 51.211614336286274, 50.7844112941197, 52.62307834625244, 54.05635275159563, 53.35122176579067, 53.70440564836775, 51.983944824763704, 48.77540567943028, 48.43088272639683, 48.73212882450649, 51.81298439843314, 48.360056264059885, 47.165865898132324, 43.276788915906636, 35.377677236284526, 24.987810066768102, 15.739521503448486, 7.698288764272418, 5.099668570927211, 1.9086210812841142, 3.005146482161113, 2.997199914285115, 6.835606506892613, 5.737072425229209, 13.624623605183192, 6.818865256650107, 11.022585766656057, 13.039652160235814, 9.59933066368103, 9.185631445475988, 7.518825479916163, 7.8507218190601895, 4.2661340066364835, 1.3935119275535857, 1.7187042321477617, 4.882067927292415, 14.464930057525635, 17.279985768454416, 17.743084941591533, 18.42007746015276, 25.74793083327157, 32.015937260219026, 34.6612936428615, 22.706421170915874, 10.300826873098101, 2.4318512678146362, 0.2169231264186757, 0.11795424776417868, 0.13388631785554544, 0.08899832902742283, 0.16182909559990677, 0.12884431412177427, 0.11937280664486544, 0.12652352079749107, 0.1874758872602667, 0.14779980054923467, 0.27388414634125574, 0.08394443057477474, 0.14795057103037834, 0.09901006573012897, 0.15798104208494934, 0.136514582538179, 0.08906348874526364, 0.10746917860316378, 0.14529747196606227, 0.19713889089013847, 0.12678589671850204, 0.19641543685325555, 0.10767308516161782, 0.11944638698228768, 0.23060856706329755, 0.1797606184014252, 0.11740312805133206, 0.14760165475308895, 0.15188793332449027, 0.16387605933206423, 0.15407623590103217, 0.14599420529391083, 0.1024192902924759, 0.10973456275782414, 0.1677977203258446], [0.037588471945907385, 0.04055717121809721, 0.010188154111217176, 0.013413832406513393, 0.02855036174878478, 0.09956885288868632, 0.07523734029382467, 0.0546965755389205, 0.014395008462348154, 0.057501690196139474, 0.00799333505398993, 0.001714178458704347, 0.02463942500097411, 0.03869320838046925, 0.04936179072995271, 0.038577860819974115, 0.019412252453288863, 0.002303319563257641, 0.10262695593493325, 0.06420792319944926, 0.03522853393639837, 0.04821188082652433, 0.039092858721102984, 0.05435959808528423, 0.017469075741246343, 0.03355175855436495, 0.041616313492080996, 0.13041954673826694, 0.06684827937611512, 0.01923572308649974, 0.04547576978802681, 0.04498399474791118, 0.033892043866217136, 0.0232450389303267, 0.03468274750879832, 0.05704616249672004, 0.12316790728696755, 0.042572996978248866, 0.05303442597921405, 0.043377145792224577, 0.01630294036918453, 0.10531284181135041, 2.1744752270834784, 9.559362019811358, 22.927492005484446, 36.0291542325701, 29.901155744280132, 26.647734710148402, 23.071248497281754, 16.567812783377512, 5.39783661706107, 9.566224234444753, 11.49209725856781, 4.684247067996433, 1.1867605703217643, 0.4171971747917788, 0.6529189103416034, 0.5112506236348833, 1.587223470211029, 4.9610932639666965, 3.97053462266922, 3.822996573788779, 3.918344531740461, 3.4550809902804236, 2.676833676440375, 3.580994290964944, 1.6042206095797675, 2.125221401453018, 2.366556440080915, 1.4645837481532777, 2.024282966341291, 1.8238263513360704, 3.261070783649172, 6.745082335812705, 12.888030307633535, 19.91082215309143, 30.945192064557755, 44.824093682425364, 49.93848548616682, 53.160590989249094, 51.98636279787336, 52.70785331726074, 53.32130977085659, 54.07689510072981, 50.965703691755024, 52.485021114349365, 52.08958871023995, 52.804231779915945, 50.50832462310791, 52.783102308000835, 49.83306394304548, 51.78498663221087, 52.74936532974243, 55.51035015923636, 56.32953235081264, 49.845601967402864, 50.502102511269705, 50.780541147504536, 50.66321039199829, 51.324446133204866, 50.813579831804546, 52.182041440691265, 50.18339559010097, 46.9606716973441, 48.10080507823399, 47.79652956553868, 43.959466797964915, 41.187142508370535, 29.032940115247452, 22.762005022593907, 11.470847061702184, 6.032329610415867, 2.6678598608289446, 1.150663050157683, 0.7161236330866814, 4.558821661131723, 2.522203688110624, 5.999616188662393, 2.76597797870636, 5.650969045502799, 8.260134867259435, 6.895075270107814, 8.24770540850503, 3.53828501701355, 2.958226816994803, 2.5101885156972066, 2.332155474594661, 0.7333161362579891, 0.34635054639407564, 3.20498839872224, 10.071962765284947, 18.45913675853184, 19.391265392303467, 24.308818204062327, 22.15764376095363, 22.571000780378068, 28.065691811697825, 18.508244889123098, 8.2941905941282, 1.6207662246056964, 0.08583556195454937, 0.017151981059994017, 0.02731097343244723, 0.04194942329611097, 0.06450003252497741, 0.04447474743106535, 0.05426785336541278, 0.04829973754073892, 0.023383882462180088, 0.03459729280854974, 0.009121784591116011, 0.004873336043341884, 0.03437337964507086, 0.03487090526946953, 0.049754584474223, 0.06915934250823089, 0.013967243023216724, 0.03867859273616757, 0.03515556428049292, 0.0236451574601233, 0.04589864977502397, 0.02876821220187204, 0.02825975537832294, 0.04596452534730945, 0.05574493249878287, 0.03646993410906621, 0.03039297108937587, 0.07447163388133049, 0.05353134770744613, 0.030293555531118597, 0.06091328963105168, 0.03523276460223964, 0.0898485809032406, 0.025684604720611657, 0.03316566873607891, 0.05432922346517444, 0.009475387000877942, 0.035803809495908875, 0.024727191809298735, 0.04959716774257166, 0.05481452188853707, 0.12558915093541145, 0.020063780081857528, 0.08516594967139618, 0.07551874912210874, 0.05221598382507052, 0.027594480630276457, 0.023619035558242883, 0.043119780852326324, 0.039460448282105584, 0.019854899861716797, 0.02306621102616191, 0.05119776399806142, 0.046486776787787676, 0.05016619399456041, 0.06591497481401477, 0.07914121009941612, 0.02897511449243341, 0.030151731534195796, 0.07501550684017794, 0.026928271200241785, 0.06437038483896426, 0.03155844997880714, 0.04901158184345279, 0.035451351265822134, 0.038208215297865014, 0.029710246116987298, 0.08836214816463844, 0.05445174992616687, 0.02287027216516435, 0.01817827545372503, 0.022101437706234198, 0.06439478495823485, 0.09833405486174993, 0.01476098650268146, 0.018296376170058335, 0.10309662430414132, 0.29880103788205553, 3.0172122461455206, 12.19420838356018, 29.69124719074794, 43.64167703901018, 33.280655315944124, 22.47334906033107, 12.581890940666199, 12.713253583226885, 15.501519645963397, 16.00616036142622, 9.116444758006505, 4.43618335042681, 1.56953498508249, 0.15305407717823982, 0.16494267566927842, 0.897002070077828, 0.6842642969318798, 2.4896952382155826, 4.494838305882045, 6.10559185062136, 5.5123646429606845, 4.468920222350529, 4.812908164092472, 4.024002313613892, 3.590572382722582, 2.035892754793167, 2.8332326327051436, 2.0086768780435835, 2.553520521947316, 2.457742427076612, 4.4790554727826795, 9.070034265518188, 17.75425590787615, 21.588898965290614, 33.67659841264997, 45.00338847296578, 50.92551531110491, 53.22079365594046, 52.70674507958548, 52.72578314372471, 54.17322145189558, 53.813530581338064, 51.44525793620518, 53.60841628483364, 51.87087678909302, 51.830580711364746, 51.26943724496024, 51.20579521996634, 47.74876764842442, 50.863554750170024, 53.965981006622314, 54.77452550615583, 56.07476970127651, 51.36662517275129, 51.22194978169033, 51.67701162610735, 52.615980761391775, 52.47186470031738, 51.44521624701363, 52.24681602205549, 49.60654919488089, 47.4997615814209, 48.35687051500593, 47.91615670067923, 44.37549713679722, 43.24646350315639, 32.1476160458156, 26.902728387287684, 14.975365570613317, 9.014737027032034, 4.076812531266894, 2.696847311088017, 1.8149494848081043, 2.8462324951376234, 5.6102191635540555, 10.034723026411873, 6.733259107385363, 7.6884388242449075, 5.0302243658474515, 11.668247120720999, 9.39725272996085, 3.6075956864016394, 4.208986810275486, 1.7172840854951312, 1.1578542185681207, 0.19666103938860552, 0.2946274775479521, 2.7993864374501363, 10.966793469020299, 22.528823477881296, 18.51046657562256, 18.934735740934098, 21.260117156164988, 25.566911152430944, 31.32731866836548, 24.086673872811453, 10.806096400533404, 2.672553151845932, 0.13443468271621636, 0.055506390120301924, 0.044976395155702314, 0.054804842586496046, 0.07087812599326883, 0.05085099528410605, 0.055613493480320485, 0.08550039279673781, 0.04606157621102674, 0.006327029891378645, 0.015651506039180925, 0.03468413511291146, 0.04082635284534522, 0.030819786579481194, 0.01094627789487796, 0.02466288874191897, 0.028052495160539235, 0.005939885799307376, 0.044948222381728034, 0.021895766956731677, 0.038921253822211704, 0.017416216166956083, 0.02410326528895114, 0.03407446461330567, 0.07085038748170648, 0.02339011480632637, 0.02412532106973231, 0.06534498504229955, 0.029144266487232277, 0.04035288807270782, 0.043146308178880384, 0.06683881381260497, 0.04738765416134681, 0.03744975903204509, 0.03671163846073406, 0.09094189759343863, 0.12643664117370332, 0.13911411804812296, 0.17302134074270725, 0.11751478777400085, 0.06880942878446408, 0.2629406792776925, 0.17879362457564899, 0.22392517354871544, 0.16015353479555675, 0.05025742302781769, 0.10289484834564583, 0.09938860684633255, 0.15963579900562763, 0.11647734844258853, 0.07295321500194923, 0.18401864277465002, 0.11368788419557468, 0.1361844888223069, 0.1340601449566228, 0.21092248841055802, 0.2970076155449663, 0.2275867520698479, 0.12016682832368783, 0.11484810443861143, 0.07415074110031128, 0.12394142363752637, 0.10190425507192101, 0.23407558245318277, 0.10936984339995043, 0.09499082461531673, 0.14002605554248604, 0.10651336024914469, 0.13998891253556522, 0.09912529454699584, 0.12887425108679704, 0.19079352995114668, 0.28223210839288576, 0.2465385336961065, 0.12187561020255089, 0.12666580959090165, 0.14345951059034892, 0.39763083042843, 3.199030101299286, 14.08854353427887, 33.32573522840227, 48.59701068060738, 40.38117926461356, 35.17400121688843, 30.561359677995952, 23.084206887653895, 13.42137142590114, 16.44975767816816, 14.178411534854344, 6.320275987897601, 2.0696362469877516, 0.6905010108436856, 1.53568868126188, 2.6977436287062506, 6.585186915738242, 9.939338156155177, 12.017599071775164, 10.216053639139448, 10.981119785990034, 9.40425911971501, 8.404085040092468, 8.422477790287562, 5.260438161236899, 5.261961988040379, 5.158957115241459, 3.1115614005497525, 4.35574666091374, 3.30720009122576, 4.358187649931226, 8.5478641135352, 16.27405858039856, 23.54744849886213, 32.42006186076573, 47.395097391945974, 52.17233828135899, 55.28424882888794, 54.33218233925955, 54.52296597617013, 54.938322339739116, 55.07778658185686, 53.34247398376465, 53.14181695665632, 53.26690884998867, 54.04181017194475, 52.12788370677403, 52.9494560786656, 50.72783211299351, 53.998901571546284, 53.499961853027344, 54.62337786810738, 55.69937242780413, 52.352525915418354, 50.964880330221995, 52.952155453818186, 53.21097585133144, 54.09402935845511, 53.35014826910836, 54.238972255161826, 50.85388633183071, 47.96232400621687, 48.43433598109654, 50.244126319885254, 45.05303682599749, 43.60662685121809, 29.58910867146083, 25.329454728535243, 13.66752004623413, 8.449007749557495, 3.6560383098466054, 2.874328621796199, 1.734159631388528, 9.23593987737383, 6.717627397605351, 11.533901963915143, 8.501788871628897, 9.74084722995758, 16.439172097614833, 10.92110732623509, 17.671037333352224, 10.274845821516854, 8.607415386608668, 6.607246577739716, 5.073863395622798, 2.893427916935512, 0.5788629470126969, 4.062429325921195, 13.178056802068438, 23.93217372894287, 26.502567734037125, 30.88992609296526, 29.6081189428057, 31.545658860887798, 38.248005867004395, 25.549771683556692, 11.620703203337532, 2.3926154417651038, 0.27995776757597923, 0.09018026239105634, 0.11415333886231695, 0.12594874735389436, 0.176857180627329, 0.13654305386756146, 0.25757235448275295, 0.16213731334677764, 0.11872253939509392, 0.14857919301305497, 0.13480759199176515, 0.11541633680462837, 0.17803025910896914, 0.07420805695333652, 0.09985379009906735, 0.1469895076006651, 0.06200418395123311, 0.08765261766633817, 0.14628317978765282, 0.09723746084741183, 0.315649360950504, 0.0747516584981765, 0.14298019345317567, 0.07929237413087062, 0.24712793635470526, 0.2060810053454978, 0.11981800704130105, 0.18307577765413693, 0.09444939438253641, 0.18442930573863642, 0.18961927081857408, 0.19822028572005884, 0.15744118605341229, 0.1965363925056798, 0.10930304841271468, 0.14943581633269787], [0.05853121102388416, 0.026681845941181694, 0.05061436637437769, 0.05950193679226296, 0.023847791765417372, 0.015324918653017707, 0.01171878831727164, 0.035564446090055366, 0.01907238783314824, 0.043456154409796, 0.036382990024451695, 0.04015778550612075, 0.060296250241143365, 0.016581825047199215, 0.03333308028855494, 0.019766729325056076, 0.05621251776548369, 0.024153848378253833, 0.023952045278357606, 0.040959674798484356, 0.07325541414320469, 0.0615629529846566, 0.05338290460141642, 0.022099522541144064, 0.03260379085051162, 0.02196714884069349, 0.05619154764073236, 0.027436156358037676, 0.03917796736849206, 0.02690107042768172, 0.06792366238577024, 0.054704643320292234, 0.012925701947616679, 0.03784788266888686, 0.0891082856271948, 0.1165263115295342, 0.03040241968951055, 0.03099752204226596, 0.05985006596893072, 0.02238268538245133, 0.019758305312799554, 0.04034169903025031, 0.24003594262259348, 2.11408018214362, 7.293733375413077, 21.429283210209437, 33.00608335222517, 32.277891295296804, 26.40482916150774, 24.103398186819895, 18.61165840285165, 9.608012437820435, 5.739422219140189, 9.40742576122284, 7.288559573037284, 1.3750561007431574, 0.4369259061557906, 0.3921095095574856, 0.6231909341045788, 1.5401498590196883, 3.112725006682532, 4.7083950979369025, 4.049371923719134, 2.4318295546940396, 4.419815131596156, 3.9658263495990207, 3.649255565234593, 1.0748507125037057, 2.032186325107302, 1.4695353167397636, 1.6308568545750208, 0.3490057353462492, 0.33124939671584536, 1.7026851602963038, 4.13059983934675, 12.852406893457685, 21.661820309502737, 31.957773889814103, 44.011672088078086, 50.578859261104036, 52.15783739089966, 50.60327870505196, 51.472342014312744, 52.44963046482631, 49.941740717206685, 51.810059206826345, 50.98668377740042, 53.37029109682356, 48.86210182734898, 51.966428416115896, 47.830287388392854, 49.87150832584926, 49.71312066486904, 56.51018551417759, 58.37893826620919, 50.74293402263096, 51.78446899141584, 49.628661836896626, 53.266630922045024, 50.63214847019741, 52.455223764692036, 48.46767691203526, 50.383319582257954, 49.51863363810948, 49.44009467533657, 45.57616669791085, 40.2577931540353, 29.001033987317765, 17.106089728219168, 8.619829211916242, 4.609094049249377, 4.42446608202798, 1.6250905011381422, 1.6972724050283432, 1.6434829256364276, 1.6644600800105502, 7.595336437225342, 10.822058149746486, 6.67516131060464, 7.210460952350071, 2.071041303021567, 14.113319073404584, 7.219888355050768, 3.6606731925691878, 4.731378870350974, 2.2930518814495633, 1.06682565169675, 0.1648451973284994, 3.4559373557567596, 8.338543551308767, 17.388063260487147, 12.70794689655304, 13.939179846218654, 18.84365701675415, 17.936753817967006, 25.17967414855957, 21.99931342261178, 8.329657673835754, 1.9733746009213584, 0.053072664820189984, 0.027640968760741607, 0.048406026658735106, 0.0115618991465973, 0.05547134378658874, 0.04066234414598771, 0.04040709284267255, 0.03509782434308103, 0.03579661023936101, 0.06870034070951597, 0.04030299200011151, 0.04728772630915046, 0.03944801073521376, 0.041546078332300694, 0.021312255678432326, 0.08066391732011523, 0.034725390042045286, 0.050717985457075496, 0.02114601120618837, 0.029129325146121637, 0.04615105123126081, 0.02669090438368065, 0.015388707730120845, 0.03486613856096353, 0.029701442125120332, 0.05767209069537265, 0.0328144522250763, 0.02983731876260468, 0.018207846009837728, 0.019845980518896664, 0.04031606397724577, 0.022501549450680614, 0.03623073355161718, 0.04009457996913365, 0.020325229802568043, 0.01839591725729406, 0.07428479247859546, 0.01514723408035934, 0.028870715094464164, 0.021536036527582576, 0.07226541798029627, 0.07066257577389479, 0.014666089987648385, 0.040078844742051194, 0.033414473956716914, 0.013395650212519934, 0.003034911143393921, 0.03702984085040433, 0.057929567593548975, 0.01664630962269647, 0.005769796578014004, 0.06490926378007446, 0.023074434870587926, 0.017873740455667888, 0.02491981941940529, 0.011525616182812622, 0.05052074211250458, 0.04105942962425096, 0.0693986007411565, 0.02222018303083522, 0.027791223555271114, 0.00989828649575689, 0.05351544623928411, 0.03172160033136606, 0.036312951639826806, 0.0628061852018748, 0.027759123759876405, 0.0408941384937082, 0.03620297807667937, 0.0026427931775937653, 0.037477870737867694, 0.00769076611114932, 0.04451334589560117, 0.06749607675841876, 0.06527255821440901, 0.01199150426379804, 0.05772596637585333, 0.0385096951920007, 0.031093728129885027, 0.46469036489725113, 3.8087254081453596, 12.209320715495519, 28.753572157451085, 39.026273591177805, 35.321087632860454, 27.193807533809117, 20.785704578672135, 12.387146830558777, 13.422618627548218, 14.656279972621373, 15.560603652681623, 6.298878576074328, 0.9908025882073811, 0.21383876406720706, 0.1639658837978329, 0.3828681340175015, 1.2803751698562076, 2.8113686059202467, 3.9995220729282925, 4.903412793363843, 3.507643026965005, 3.3733560613223483, 6.53029180424554, 4.2473443405968805, 3.39314409664699, 3.7979166167122975, 2.7971812529223303, 2.911014676094055, 1.7128466836043765, 1.7969437709876468, 2.9944497304303304, 5.654998566423144, 14.793340138026647, 24.498252153396606, 35.455736773354666, 45.65033176967076, 50.64693076269967, 52.41974973678589, 53.2395920072283, 52.537431376320974, 53.01319537843977, 50.03329018184117, 52.39974239894322, 51.744020053318565, 53.42642559323992, 51.36007302148001, 53.826728684561594, 49.220590659550254, 49.810617787497385, 51.852516174316406, 55.73481518881661, 55.75983565194266, 51.427425384521484, 51.40322828292847, 50.80361264092581, 54.07265669958932, 52.83040911810738, 51.328760964529856, 50.49874653135027, 51.128048351832796, 49.26887369155884, 50.21771274294172, 47.919564792088096, 43.4721097264971, 32.628052711486816, 20.21319385937282, 10.869490895952497, 6.788704863616398, 5.35560633455004, 1.973745461021151, 2.2020111552306583, 2.7351614151682173, 2.9056819336754933, 5.100559243134089, 10.323810645512172, 13.189135704721723, 10.712817702974592, 6.547761746815272, 9.678720780781337, 8.261578355516706, 2.8977088757923672, 2.6019820358072008, 0.8477689804775375, 0.6041196488908359, 0.28424032777547836, 2.4286431542464664, 8.83237373828888, 18.46404913493565, 18.23195324625288, 17.34486630984715, 21.143892901284353, 21.523792607443674, 29.090116841452463, 26.275714261191233, 10.951400603566851, 3.064817611660276, 0.08306969715548412, 0.037563332223466465, 0.03641303555507745, 0.0549721930708204, 0.06542661280504294, 0.02154264036965157, 0.043640505589012585, 0.040114783349313905, 0.007688318296069545, 0.046946100890636444, 0.017294749916930283, 0.04576992828931127, 0.03539024918739285, 0.022638433712667654, 0.0315981307066977, 0.017550703503989747, 0.01955957428020026, 0.03055329534358212, 0.00973818700627557, 0.04610496174011912, 0.039088892683918984, 0.07229435071349144, 0.06032341878329005, 0.030202852362500768, 0.027099843868719678, 0.04367766895198396, 0.05845636861132724, 0.02327828884257802, 0.01701770576515368, 0.028701651309217726, 0.024825319847358123, 0.08993495162576437, 0.007469422899053565, 0.017508502018504908, 0.07502724549600057, 0.028484021380011524, 0.0840897388490183, 0.11929700071258204, 0.07990659081510135, 0.10894145710127694, 0.11421663260885648, 0.12274918332695961, 0.08953979318695408, 0.18387319200805255, 0.12980820025716508, 0.08792447272155966, 0.13258313706942967, 0.14677419486854756, 0.16498331991689547, 0.26200364955833977, 0.14268530213407107, 0.07627874905509607, 0.14182638536606515, 0.15528177549796446, 0.1567914616316557, 0.07784215480621372, 0.0950716177799872, 0.11914218616272722, 0.20052125225109713, 0.14344477280974388, 0.11259067949971982, 0.15655814058014325, 0.2422574662736484, 0.12922845993723187, 0.12265049719384738, 0.15824005247226783, 0.11523866919534546, 0.15631489934665815, 0.18425112244273933, 0.21688473490732058, 0.10180176914270435, 0.1649441955877202, 0.23957804005060876, 0.22147195733019284, 0.24973627924919128, 0.1483790251825537, 0.13506938437266008, 0.1592453835265977, 0.11735231934913568, 0.4330314137041569, 3.6701878820146834, 13.685818127223424, 32.687640462602886, 44.435758863176616, 45.11780098506382, 36.98039736066546, 32.23280096054077, 23.562984670911515, 18.341326577322825, 12.91899495465415, 13.554623109953743, 9.105786221367971, 1.9859004659312112, 0.7605674053941454, 0.8061915029372487, 2.5284177660942078, 4.903251247746604, 6.379478548254285, 10.80463467325483, 9.544268795422145, 7.424272656440735, 9.70104273727962, 9.417531047548566, 9.0690450157438, 5.712160527706146, 4.370945411069052, 4.305535069533756, 5.076877611024039, 1.5150983461311884, 1.4057420598609107, 2.9744723566940854, 6.313281757490976, 14.624342577798025, 24.510289907455444, 34.036695752825054, 45.30000359671456, 51.800891058785574, 54.45634664808001, 53.653808866228374, 52.728684016636436, 53.34606967653547, 50.963612283979145, 52.233982699257986, 52.42293895993914, 52.283742223467144, 51.643090520586284, 54.59701292855399, 49.86118677684239, 53.037545340401785, 51.99227918897356, 55.55584348951067, 56.77249043328421, 51.84129135949271, 51.634610244206016, 51.561410972050254, 54.93140540804182, 54.14481374195644, 52.622651032039094, 51.224100249154226, 51.21717289515904, 50.452210971287315, 50.97535821369716, 46.79355362483433, 41.622040680476594, 31.2177004132952, 19.570761680603027, 11.037403668676104, 6.614686795643397, 7.201162091323307, 3.11264488526753, 4.15174103634698, 3.7583948288645064, 5.450262946741922, 17.310028042112076, 17.131745951516287, 13.945860539163862, 14.658935921532766, 10.367249046053205, 22.09217435973031, 16.415282453809464, 8.681534426552908, 10.031902926308767, 4.866068397249494, 2.1281313938753943, 0.48942090358052937, 4.433707620416369, 10.942834343229022, 22.559758595057897, 19.76656017984663, 21.965724093573435, 26.184371505464824, 27.337963547025407, 34.89634425299508, 29.72059985569545, 11.616309336253575, 3.03837993315288, 0.2439064420759678, 0.11631471716931888, 0.2110612488218716, 0.17170876903193338, 0.11985330443297114, 0.1046767762995192, 0.14619666657277516, 0.18344118233237947, 0.09279638129685606, 0.12175845434623105, 0.08096237773341791, 0.16326921832348618, 0.13961071068687098, 0.1774113673184599, 0.15842412545212678, 0.10125771297940186, 0.08852540369012526, 0.206839688920549, 0.12394434133810656, 0.09010549461735146, 0.1297708944018398, 0.13583710603415966, 0.0952359861029046, 0.12405059992202691, 0.19730005652776786, 0.1473280694335699, 0.1042854447982141, 0.11431017544652734, 0.08333612393055644, 0.08038195209311587, 0.17324702148990972, 0.22650223597884178, 0.1410692895629576, 0.11041096039116383, 0.11925276022936616, 0.15434865414031915, 0.15494751557707787], [0.08104198346180574, 0.0670742518933756, 0.002286150930948289, 0.01763603606793497, 0.03981937634359513, 0.01909853857276695, 0.040734265465289354, 0.016492338152602315, 0.06624806765466928, 0.0860377178926553, 0.007670821422444922, 0.05062845615403993, 0.03448848293295928, 0.008360877965709992, 0.009026397834531963, 0.03295146201604179, 0.028554019052535295, 0.01696776898045625, 0.04803820300315108, 0.04153448895418218, 0.0621755343994924, 0.017673109525016377, 0.035127829161605666, 0.024219783322353448, 0.02699498985228794, 0.011099983039977295, 0.03661408208842788, 0.006975587656987565, 0.08934907056391239, 0.07572714758238622, 0.04728239302390388, 0.04183924277978284, 0.041315010017050166, 0.030758813422705446, 0.09209239442965814, 0.03931510608111109, 0.057866117783955166, 0.05868205614387989, 0.04036050123561706, 0.03520717704668641, 0.03599094266870192, 0.0744074716099671, 0.043327565238411934, 0.15840135381690093, 1.7250934264489581, 7.722481523241315, 19.009199585233414, 32.15331356866019, 31.174176897321427, 20.0914249420166, 24.146107026508876, 20.780934640339442, 11.20460251399449, 7.396089894430978, 13.618840966905866, 7.762595210756574, 2.1232552783829823, 0.624832771718502, 0.14435367046722344, 0.6456593998840877, 1.8792951234749384, 3.5115209903035844, 3.808497420379094, 3.528484800032207, 2.165775213922773, 3.0989350037915364, 2.9854314029216766, 2.4047689267567227, 3.3705895926271165, 2.092882965292249, 1.6193459693874632, 2.1244835896151404, 1.3352171927690506, 1.0679659162248885, 1.7964502317564828, 2.562622879232679, 9.989257488931928, 20.264963150024414, 31.40809495108468, 41.042710304260254, 45.86254712513515, 52.304479122161865, 54.83538825171334, 52.90862498964582, 51.70422077178955, 51.273012093135286, 50.689623968941824, 52.57947145189558, 47.609358991895405, 48.69198560714722, 44.211276463099885, 46.178888184683665, 50.52284983226231, 49.149006843566895, 53.16279704230172, 52.09450456074306, 50.85170807157244, 49.29869188581194, 53.19854899815151, 55.87319203785488, 53.76551505497524, 52.388670444488525, 45.478860650743755, 47.9222537449428, 46.073550019945415, 37.71789305550711, 26.08161633355277, 15.13881152016776, 9.182703648294721, 3.9841504863330295, 1.804572350212506, 1.1385690591164996, 1.2055969195706504, 1.3901384685720717, 2.586682536772319, 1.2559280416795184, 2.6378165015152524, 12.789956484522138, 11.81174566064562, 7.903935466493879, 3.424909306424005, 12.512396795409066, 5.529391203607831, 0.9508814960718155, 1.5207576538835252, 0.18856306320854596, 0.664060618196215, 2.1743510280336653, 8.748070376259939, 15.793693133762904, 21.779385566711426, 18.534180777413503, 18.386370011738368, 25.68674499647958, 23.669712475367955, 21.898607969284058, 9.660745791026525, 2.3696210299219405, 0.07854232152125665, 0.03501721777554069, 0.029883567709475756, 0.05799482909164258, 0.018688192823901772, 0.08151957033468143, 0.06664441352976219, 0.042656059842556715, 0.07062101550400257, 0.050019437048052035, 0.06392492659922157, 0.04823878134733864, 0.013215669646992214, 0.024089136493525336, 0.07448794586317879, 0.033678342654768906, 0.04677449259907007, 0.0740909893065691, 0.033999910578131676, 0.02304425702563354, 0.10007543356290885, 0.02101427363231778, 0.05260185990482569, 0.03934570801045213, 0.0493120439350605, 0.053507772008223195, 0.023096846882253885, 0.06041086159114327, 0.07497639608170305, 0.01719631314543741, 0.03558637294918299, 0.03911227500066161, 0.037781447305211, 0.02910757131342377, 0.01629070468646075, 0.05418387787150485, 0.01750768268746989, 0.06367356330156326, 0.057029979436525276, 0.04564041970297694, 0.05363659866686378, 0.025322394245969396, 0.008047851101894463, 0.039169865660369396, 0.05965254442500217, 0.007222458204653646, 0.061045956797897816, 0.07592122216842004, 0.009069731625329171, 0.03629072283261588, 0.008820569325637604, 0.034027988357203345, 0.0543225670366415, 0.009096870481568788, 0.010649901432251292, 0.017121945707393543, 0.018140048487111926, 0.01101115856519235, 0.0028554015235775815, 0.020874743083758012, 0.07346760561423642, 0.02097961406356522, 0.08642852692199604, 0.04117056008960519, 0.03966309955077512, 0.06965502591005393, 0.10458137427589723, 0.023871686376099075, 0.020724724080147486, 0.06752273639930145, 0.10051747877150774, 0.03750730897965176, 0.07752328405955008, 0.03287217519911272, 0.029604374298027585, 0.012385936670138367, 0.010295550089462526, 0.030883674044162035, 0.027482483336435895, 0.07204965062971626, 0.0824490479592766, 0.3490852867918355, 3.148524297135217, 11.660931536129542, 24.800139222826274, 37.890402930123464, 33.267304352351594, 23.69671838624137, 16.576689107077463, 17.675696100507462, 9.914204784802028, 13.720726745469229, 19.97704369681222, 9.50772213935852, 2.8322566279343198, 0.3455957168979304, 0.15514184800641878, 0.5449498753462518, 0.6884346274392945, 1.507412769964763, 2.965722837618419, 3.9234054258891513, 2.6148702927998135, 6.163679659366608, 7.711400883538382, 1.8472621909209659, 4.205752858093806, 2.796930032117026, 3.307502120733261, 2.665907634156091, 3.2741140723228455, 2.418531571115766, 2.674248512302126, 4.140279114246368, 12.135259866714478, 21.8431613445282, 34.3495522907802, 42.97764464787075, 47.73084477015904, 50.64231368473598, 54.17745290483747, 52.480998107365195, 52.2675598689488, 52.30605983734131, 51.445810317993164, 52.0870178767613, 51.18218871525356, 50.993006638118196, 44.57433720997402, 45.92995507376534, 53.378229413713726, 52.44366543633597, 56.12101691109793, 52.290019920894075, 52.24791036333357, 51.2768474987575, 54.27137170519148, 55.01582602092198, 54.349222796303884, 51.73510204042707, 48.657699721200125, 48.73423760277884, 47.20969860894339, 38.83735901968819, 29.101786340985978, 17.302972146442958, 12.077865140778677, 5.129538876669748, 2.9889187472207204, 2.747662744351796, 2.940925802503313, 3.4045645466872623, 4.185717293194362, 2.369081893137523, 5.056534154074533, 6.763610575880323, 9.847318819590978, 11.961511475699288, 8.856924329485212, 8.004633103098188, 4.9947303618703565, 2.0985856992857794, 0.7724618528570447, 0.274388352142913, 0.27546412870287895, 1.7633456481354577, 7.715652312551226, 17.573032992226736, 24.41029143333435, 18.265321969985962, 16.379150084086827, 27.59607870238168, 24.195319380078995, 26.56606558391026, 13.469842927796499, 3.94217164175851, 0.10598465933331422, 0.017178864617432867, 0.007537217029104275, 0.0320909235493413, 0.032008634214954715, 0.16348291614225932, 0.029935438318976333, 0.0072186261781358296, 0.10997116113347666, 0.022220091428607702, 0.05009570099147303, 0.079293989044215, 0.02361481507042689, 0.020814819959923625, 0.07945420473281826, 0.04928495003176587, 0.033492559766662974, 0.03762430198756712, 0.048986462477062426, 0.031224736278610568, 0.057107413852853436, 0.013700242886053664, 0.01580932649916836, 0.04515100257205112, 0.0552788298310978, 0.018647889540131603, 0.0443468571507505, 0.04932099041928138, 0.0229559948867453, 0.01767404081432947, 0.07661832190517869, 0.0450075806251594, 0.07554706438843693, 0.029851218552461693, 0.02221767245126622, 0.10796825468008008, 0.01682277113598372, 0.008988175956931497, 0.2063654607960156, 0.14199251788003103, 0.13333409891596862, 0.0996991858950683, 0.16723989668701375, 0.11376586143991776, 0.12159382818000657, 0.07981380793665137, 0.15642798399286612, 0.2017610850078719, 0.07094059871243578, 0.21123852288084372, 0.11912320075290543, 0.10673644899257592, 0.08203837820994002, 0.15067742685122149, 0.11411136468606335, 0.09234092823628869, 0.12109521350690297, 0.10272499745977776, 0.157249459198543, 0.09946148829268557, 0.15069645297314438, 0.11998449239347662, 0.28430951120597975, 0.07734569787446942, 0.08325373620859214, 0.09941169739301715, 0.17463199288717338, 0.14666340367070266, 0.10692907151366983, 0.1335100701877049, 0.2242249096078532, 0.15668532518403872, 0.18594919703900814, 0.08249076429222311, 0.1646525069539036, 0.2324294564979417, 0.1177797828401838, 0.15688155751143182, 0.13560312001832894, 0.17621045533035481, 0.20486665836402349, 0.3476276035819735, 3.1099116376468112, 13.596565042223249, 28.664075885500225, 44.3480795451573, 42.80749021257673, 31.160492420196533, 33.00001062665667, 26.95262861251831, 17.65436339378357, 12.550083824566432, 20.899628979819163, 9.83804644857134, 2.628687871353967, 0.9302348153931754, 0.43943035176822115, 2.3167940931660786, 5.502101285117013, 8.181408303124563, 10.342433554785591, 10.3837970495224, 6.763118122305189, 6.474250674247742, 8.662359135491506, 6.295215138367244, 7.562114494187491, 5.3155755911554605, 4.077122160366603, 6.151306654725756, 4.459851954664503, 3.143698990345001, 4.162586305822645, 3.961501964500972, 11.422669989722115, 23.19175979069301, 34.09439706802368, 43.11178656986782, 47.314988136291504, 52.92151389803205, 56.125488076891216, 53.15230873652867, 51.961623736790244, 54.7072217805045, 52.049966607775005, 53.99898842402867, 52.0467461177281, 53.13168995720999, 45.21523904800415, 48.180122239249094, 53.879371711185996, 53.93082659585135, 55.242149693625315, 51.47935274669102, 53.090379442487446, 53.66261223384312, 56.48878158841814, 57.71349539075579, 55.006584916796, 52.55133124760219, 48.122514724731445, 50.01548542295183, 48.16956097739083, 39.57293006352016, 28.45434624808175, 17.268097400665283, 10.616973383086068, 5.867401957511902, 3.41264790722302, 2.6616210298878804, 3.864519008568355, 4.555117837020329, 6.474556394985743, 6.011626149926867, 8.063764878681727, 24.745140756879533, 19.031588418143137, 13.306013090269905, 6.973162599972316, 22.511166368212017, 14.25060852936336, 4.531539559364319, 3.973800276006971, 1.1162059562546867, 1.305201300552913, 3.253444484301976, 11.632873841694423, 21.225808688572474, 29.8654420035226, 26.24931284359523, 25.223663193838938, 35.06379583903721, 32.230094637189595, 30.831457001822336, 14.429628866059439, 3.6460046768188477, 0.18125834874808788, 0.14185911789536476, 0.09457155782729387, 0.22874680267913, 0.1643536529902901, 0.294417891651392, 0.17640112367059502, 0.16887992939778737, 0.27804071615849224, 0.12011563964188099, 0.22093402833810874, 0.12613546662032604, 0.10203897141452346, 0.08646567671426705, 0.21356194892099925, 0.17090914265385695, 0.15735715627670288, 0.14358725159295968, 0.13052913014377865, 0.09850891333605562, 0.21516513718026026, 0.07347209751605988, 0.16601706801780633, 0.19509822396295412, 0.1265974132610219, 0.09976069509450879, 0.1336770440850939, 0.18351503408380918, 0.13215048957083905, 0.07233316291655813, 0.15719179729265825, 0.19783197369958672, 0.12295837567320891, 0.12260812946728297, 0.08334767938192401, 0.19195569758968695, 0.11250837998730795, 0.10430970921048097], [0.02320579585752317, 0.07286552113613912, 0.07499842132840838, 0.007092855047501091, 0.040042926490839036, 0.02713955852336117, 0.03807330557278224, 0.04151389880904129, 0.054249692375638654, 0.05530288729018398, 0.01706364088957863, 0.02389373367519251, 0.026656231244227717, 0.01927427914259689, 0.053466574754565954, 0.04051874917266624, 0.040938687710357566, 0.020203894170533334, 0.049625479616224766, 0.014484349471916045, 0.04252380658207195, 0.09761362709105015, 0.047236686905047724, 0.02742744905741087, 0.039585356401013475, 0.06539637728461198, 0.02328052631180201, 0.02817691982324634, 0.06453435961157084, 0.08690173724400145, 0.022064126761896268, 0.04462134152916925, 0.0280195794267846, 0.040381664742848704, 0.016298996384388635, 0.11116871437323944, 0.07645566349050828, 0.04670722602999636, 0.0363946370780468, 0.05385321079354201, 0.04992640989699534, 0.01769166236876377, 0.03912737579750163, 0.037819363842053075, 0.009958816908432968, 1.4699690363236835, 8.067837391580854, 23.211355447769165, 34.92660018375942, 33.2151893888201, 23.416012900216238, 17.927347694124492, 28.65252103124346, 27.89794145311628, 9.387670295579092, 13.065443873405457, 7.546040705272129, 2.6510754014764513, 0.5483511271221297, 0.2839751834315913, 0.25807330331632067, 0.8127921830330576, 1.4423470156533378, 0.6021909809538296, 0.6611621880105564, 6.880476670605796, 4.201326421328953, 0.9677282720804214, 2.8152239876134053, 2.654993099825723, 3.4912194396768297, 2.9519189383302415, 4.872058612959726, 2.270735136100224, 0.49858242911951883, 1.9530185503619057, 2.3706886640616824, 5.696013782705579, 14.587857586996895, 25.90403774806431, 35.962392466408865, 44.052166189466206, 48.244153363364084, 48.54062604904175, 51.64918409075056, 47.07798855645316, 50.47455985205514, 47.799083028520855, 51.01257971354893, 43.59832027980259, 38.17662354878017, 40.804946422576904, 50.014999049050466, 40.15320886884417, 43.36613927568708, 52.46941893441336, 42.98293917519705, 50.70941938672747, 56.37470953805106, 51.314909730638774, 48.58592135565621, 51.00047247750418, 45.47518852778843, 42.083550453186035, 34.95822490964617, 21.917687722614833, 13.728753651891436, 7.491810015269688, 3.0010982879570554, 1.012452632188797, 0.786421652351107, 1.3135195970535278, 1.7084781123059136, 2.470168628862926, 3.611974137169974, 3.4359111274991716, 3.5237871663911, 3.2846510154860358, 13.56530509676252, 16.71330111367362, 12.967820814677648, 3.143281012773514, 4.932101036821093, 1.8328025553907668, 0.6179073176213673, 0.803360709122249, 2.9718785073075975, 6.875956433159964, 12.64235155923026, 17.99691653251648, 13.43040929521833, 15.48576807975769, 20.754901477268763, 28.308350699288503, 24.62374356814793, 10.90286135673523, 1.9620027882712228, 0.10306765085884503, 0.06521248072385788, 0.049619114957749844, 0.008681903909226614, 0.026352352728801112, 0.06502052995243243, 0.028240379810865437, 0.06372266209551267, 0.022487848132316555, 0.02856233449918883, 0.029251644653933387, 0.03463763850075858, 0.08009464679551975, 0.017242438259667585, 0.008786938585607069, 0.0188810596176024, 0.04824243865108915, 0.04982431073273931, 0.054913326765277555, 0.09974690047757966, 0.014138287282548845, 0.07654298416205815, 0.06341029849967786, 0.1276343504765204, 0.03796221242685403, 0.039666081712182076, 0.009525434047515904, 0.020443849598190615, 0.058757210682545385, 0.11713117121585778, 0.05639447371608444, 0.03744937565975955, 0.0044003212242387235, 0.06452145387551614, 0.018004049713324224, 0.010336983134038746, 0.027386969354535853, 0.004242234863340855, 0.0716913773545197, 0.03068525344133377, 0.04090118168720177, 0.09264512227049895, 0.024393040454015136, 0.04105336352118424, 0.045433028867202144, 0.03834886882188065, 0.008818028211992766, 0.04921598373247044, 0.021222685663295642, 0.048837256019136736, 0.09330614430031606, 0.04602796158620289, 0.032890661885695796, 0.023727373851995383, 0.05582813785544463, 0.050072162611676116, 0.03186678307663117, 0.052989062520542314, 0.008914061273182077, 0.0445335628464818, 0.037992614188364575, 0.04377940510000501, 0.022145664618749703, 0.06546311798904624, 0.05180403842989888, 0.014457226730883121, 0.04085584197725568, 0.01413670544778662, 0.08606325795075723, 0.032461359564747126, 0.04211519618651696, 0.033098520910633464, 0.03769461517887456, 0.016788108174556067, 0.04801742286820497, 0.050709900712328296, 0.10162226270352091, 0.006703125737008772, 0.08150912089539425, 0.02939820143261126, 0.016405297376747643, 0.04289988122348275, 0.08073799977345125, 0.10506867098488978, 2.884562666927065, 11.460423026766096, 28.168797867638723, 41.0935572215489, 35.45331532614571, 25.165075983319962, 15.73319343158177, 18.326017958777292, 16.261652571814402, 13.463372417858668, 16.965685742241995, 8.530576126916067, 3.0518416336604526, 0.3043033869138786, 0.018015730693670254, 0.2700573174016816, 1.0751186524118697, 1.9327591231891086, 4.206901482173374, 3.0981012199606215, 9.075852513313293, 8.191592625209264, 2.524212586028235, 5.176704551492419, 4.499999948910304, 3.5068468068327223, 4.026179271084922, 3.987386175564357, 2.7176326300416673, 2.3239744050162177, 2.028616253818784, 3.737160699708121, 8.014793106487819, 18.43928575515747, 27.83672261238098, 38.79976231711251, 44.23622744424002, 50.58168370383126, 50.42007555280413, 54.06198079245431, 50.03220278876168, 52.224147524152485, 50.06031172616141, 53.60410492760794, 47.93192911148071, 40.31442444665091, 39.3350966998509, 53.42400762013027, 44.42835208347866, 45.8907915524074, 54.39598764692034, 45.71539470127651, 51.48886483056204, 56.755283219473704, 53.89177424567086, 51.323073863983154, 53.08297266278948, 48.732201780591694, 45.83229466847011, 37.73436376026699, 25.146567719323293, 16.25435870034354, 9.439529912812368, 4.779920722757067, 2.3570819199085236, 1.9190870225429535, 1.8286097518035342, 4.079882332256862, 3.510240350450788, 4.215114252907889, 4.626428067684174, 5.238573917320796, 6.598419325692313, 8.726854920387268, 7.987514478819711, 6.11728002343859, 4.81287168604987, 2.1586038044520786, 1.383028507232666, 0.47629988193511963, 0.6544631474784443, 3.2356686038630347, 6.852614828518458, 17.09992493901934, 21.291017532348633, 17.617973940713064, 17.549508128847393, 23.493473155157908, 32.38289942060198, 28.592252356665476, 13.903110878808157, 2.9462548536913733, 0.2658657623188836, 0.01095562895560371, 0.07176811287977866, 0.062028570499803336, 0.031560458442462344, 0.009890086400056524, 0.03550283171768699, 0.05170544050633907, 0.06363950084362711, 0.06324588267930917, 0.036663153740976534, 0.035144324347909005, 0.07407288599227156, 0.026679696681510125, 0.01578345226256975, 0.001985404914843717, 0.012519380759580858, 0.021864325340305055, 0.052182464195149283, 0.04958556818642786, 0.048038623694862635, 0.013385784313348787, 0.0403520432966096, 0.09998204678829227, 0.061861101271850724, 0.012924967433458992, 0.022174556639843752, 0.026705898311255232, 0.047218179862414084, 0.0012053271306545607, 0.0816140699067286, 0.07661008449005229, 0.022097295249945352, 0.08908054711563246, 0.01831937172184033, 0.014923799284068602, 0.02225031507467585, 0.05715805970664535, 0.05370780413172074, 0.18458908716482775, 0.1421868095972708, 0.13302894814738206, 0.07040570277188506, 0.12298816336052758, 0.09969101633344378, 0.1819231773593596, 0.14074883104435035, 0.2285414236996855, 0.0915859630331397, 0.08802769825394664, 0.16340480319091252, 0.13457710721663066, 0.15485302279038088, 0.14299030362495355, 0.1487398293933698, 0.12982931626694544, 0.1438294614532164, 0.10669189638325147, 0.07554652834577219, 0.18214649680469716, 0.19431123190692492, 0.11114776799721376, 0.10152545611241034, 0.19944878694202217, 0.23845710019980157, 0.16733145820243017, 0.12475239512111459, 0.1755134913005999, 0.1685756200126239, 0.10380869252341134, 0.19248822544302258, 0.07325379244451012, 0.13134071230888367, 0.14945850654372148, 0.2875399892883641, 0.20941003385399068, 0.22350708741162503, 0.10603499984634773, 0.23521318712404796, 0.20499513218445437, 0.1326394554759775, 0.11090386858476059, 0.13305853227419512, 0.1640407940638917, 2.5768679891313826, 12.264245356832232, 32.38427863802229, 46.55655404499599, 44.18655129841396, 33.168355056217735, 26.160129240580968, 37.252864020211355, 39.003650256565635, 17.014109475272043, 19.149082456316265, 10.27255812713078, 4.135611227580479, 0.9685538049255098, 0.7339243750487054, 1.1591241104262215, 2.3825429422514777, 7.177651992865971, 6.822055348328181, 6.091894345624106, 14.254892093794686, 7.5837242603302, 5.837214640208653, 7.531932388033185, 8.408728173800878, 8.461930530411856, 7.881573557853699, 9.235681925501142, 6.081620565482548, 2.0481723930154527, 3.326392535652433, 3.358988706554685, 7.392274464879717, 16.89760034424918, 28.946780715669902, 39.91415957042149, 45.894543579646516, 50.39386347361973, 51.01659229823521, 53.05549601146153, 50.088017668042866, 54.16173260552542, 50.69423757280622, 57.29735735484532, 51.108756678445, 41.72135475703648, 42.321897983551025, 55.662300314222065, 48.48584992544991, 49.870813505990164, 56.397638593401226, 48.940018926348, 52.97871494293213, 57.664159706660676, 53.60300363813128, 51.2719281741551, 54.27968522480556, 49.72652721405029, 45.072620323726106, 37.095747879573274, 23.30404962812151, 15.476193462099348, 9.178859557424273, 4.412737957068852, 1.826140318598066, 2.4661234744957516, 4.595708778926304, 6.083177830491747, 7.232771618025644, 9.066705209868294, 10.114960823740278, 8.503121188708715, 11.886113098689489, 25.153667041233607, 27.94481921195984, 22.163382972989762, 9.062883700643267, 10.44524083818708, 4.707587369850703, 2.124287303004946, 1.3167604974337985, 3.997145789010184, 9.053744213921682, 18.413655587605067, 25.39475563594273, 20.79800115312849, 23.504036154065812, 30.694653919764928, 38.100478240421836, 31.162733214242117, 15.587124926703316, 2.8534436396190097, 0.32802798386131016, 0.1696627281074013, 0.17320970206388406, 0.20306368225387164, 0.13809570483863354, 0.12863065701510223, 0.2189343584967511, 0.2071932056652648, 0.11217580283326761, 0.11959631608000823, 0.08518900629132986, 0.09961714422596352, 0.13827546233577387, 0.05852339430046933, 0.15494938833372934, 0.13245592532413347, 0.12675640758659157, 0.1358700692653656, 0.13916663665856632, 0.21394252564225877, 0.11028962475912911, 0.25833915333662716, 0.1480525005608797, 0.24134448383535656, 0.16994448298854486, 0.09695445067648377, 0.114654735528997, 0.1230082344263792, 0.19518396364791052, 0.10608862446887152, 0.12459569424390793, 0.1517562839601721, 0.1720073108694383, 0.18890309067709105, 0.10985426312046391, 0.08833101019263268, 0.07829286490700074, 0.16347661933728627, 0.13785167650452682], [0.003168109687976539, 0.019565594582153217, 0.04464600966977222, 0.00786698589633618, 0.03279514790379575, 0.06379546890301363, 0.0996143418763365, 0.017902262675176774, 0.02926457074603864, 0.015566799423790403, 0.07087706747863974, 0.033265806934131045, 0.05785842319684369, 0.04872825276106596, 0.04290476667561701, 0.1340372104729925, 0.05252211846943412, 0.04376632633752056, 0.05922495201230049, 0.025828247191384435, 0.05641173903963395, 0.009616718211743449, 0.03895990996222411, 0.03975787053682974, 0.006089428556151688, 0.048798267396965196, 0.08152128702827863, 0.04916316656661885, 0.027580197468133907, 0.03113169894952859, 0.06821974114115749, 0.07217646203935146, 0.09851008720163788, 0.027687238063663244, 0.0821310660934874, 0.044426001475325654, 0.05184174122821007, 0.11977916769683361, 0.024772787666214362, 0.016887148842215538, 0.03156383754685521, 0.04772554085190807, 0.04592991666868329, 0.019200490155656422, 0.062393690193338056, 0.010145035755288388, 0.8096021456377847, 6.177483992917197, 21.74776257787432, 31.665414537702286, 29.56543963296073, 33.42873879841396, 21.05049521582467, 19.734808649335587, 22.69718180383955, 17.760172298976354, 18.67951624734061, 11.326860410826546, 3.6828713842800687, 1.0021009019442966, 0.06823238903390509, 0.8581466579011509, 0.8186225901756967, 2.888175513063158, 2.383383457149778, 7.348755291530064, 10.476235883576528, 0.37435002252459526, 4.904444166592189, 1.3842018842697144, 2.4194272373403822, 1.816354975104332, 2.2775745519569943, 2.1677378628935133, 3.5355537235736847, 0.8887153661676815, 1.6818648832184928, 0.3869861901870796, 4.159300676413944, 7.233522457735879, 17.632146528788976, 26.675393751689366, 40.04168333326067, 36.727031299046104, 46.84289625712803, 44.15470423017229, 47.22007574353899, 47.04165295192173, 52.353255476270405, 42.19819572993687, 32.762785230364116, 33.58110237121582, 45.9385986328125, 50.18616444723946, 45.417344774518696, 45.29275662558419, 46.75998340334211, 58.24478939601353, 48.343599455697195, 50.338840688977925, 50.266516889844624, 43.542540141514365, 44.22372416087559, 30.773074763161794, 17.916925396238053, 9.755883131708417, 5.2323053394045145, 1.8875528403690882, 1.7021835872105189, 1.7024312253509248, 2.2070182008402686, 1.4942175980125154, 3.1969495500837053, 3.9292831676346913, 2.5190272756985257, 3.4096132814884186, 4.101778711591448, 2.9102241013731276, 3.1838702176298415, 5.431485440049853, 7.1043285216603955, 4.463330396584102, 1.0913787399019514, 1.3025616364819663, 0.5675304893936429, 3.9295828086989264, 8.273625663348607, 11.781584399087087, 12.379048705101013, 14.083886504173279, 13.765090124947683, 22.631431000573293, 23.642604078565324, 23.654794692993164, 10.074462379728045, 2.0831407223429, 0.09226467447089297, 0.07608331739902496, 0.03874915359275682, 0.0187586400258754, 0.018669426241623502, 0.012605485157109797, 0.05968949744211776, 0.017587688751518726, 0.04167046058656914, 0.0690201749759061, 0.04282603965007833, 0.08143643622419663, 0.0018471508602877812, 0.026412945905966417, 0.03514930818762098, 0.030973942950367928, 0.025514116011826054, 0.04365388290690524, 0.05764627243791308, 0.046870339063129256, 0.034765084340636215, 0.04894368423681174, 0.05393305400918637, 0.035991366753088574, 0.05337554249646408, 0.045043804217129946, 0.07116209968392338, 0.03578929223918489, 0.005764400104193815, 0.01340065271194492, 0.054197777661361864, 0.03612706697146807, 0.025517837776403342, 0.05109088455459901, 0.014145064999216368, 0.02417351571576936, 0.033402161938803535, 0.014792163490450807, 0.08615812393171446, 0.02916045972545232, 0.017660638051373617, 0.05624612221228225, 0.028985238234911646, 0.03631105513444968, 0.11372398225856678, 0.0406461373370673, 0.019925475985343968, 0.05017671807269965, 0.04116269247606397, 0.017989910739873136, 0.07492181472480297, 0.0415682189299592, 0.08846794534474611, 0.03148812321679933, 0.08597243603851114, 0.02379417053556868, 0.008985896927437611, 0.046061776378857236, 0.017491693009755442, 0.007221302150615624, 0.04845871490293315, 0.04708426079845854, 0.02784346735903195, 0.04640866044376578, 0.023923952232248018, 0.005908920429646969, 0.04610433748790196, 0.022091892414859364, 0.08761558322502033, 0.0403093736219619, 0.09880309219339065, 0.007994247683590012, 0.11428622316036906, 0.05964774718242032, 0.05166820250451565, 0.04031176885057773, 0.02892308442720345, 0.0695286826895816, 0.0009265932146393295, 0.024988314136862755, 0.07810928047235523, 0.04372260154091886, 0.043236312456429005, 0.019808954559266567, 0.098981431552342, 0.10408152466905968, 1.8887815858636583, 10.005055086953298, 27.70040590422494, 36.97641256877354, 33.13297830309187, 29.659212521144322, 20.4951673916408, 17.31449920790536, 18.85805889538356, 18.02763625553676, 18.510784455708094, 10.781337363379341, 3.925265806061881, 0.9641533153397697, 0.11198879179677793, 0.5447714477777481, 0.24765787220426969, 0.7012549223644393, 1.5767048746347427, 8.732473407472883, 10.982205442019872, 2.169549171413694, 4.109026551246643, 4.061540825026376, 4.4550220881189615, 2.597352147102356, 4.650822758674622, 3.994387354169573, 5.532336371285575, 2.398915720837457, 1.6509228178433009, 1.04876999769892, 3.824966388089316, 9.716928924833026, 21.43618277141026, 28.984295776912145, 39.77915259769985, 39.611443928309846, 49.34370231628418, 46.548330851963584, 50.03433241162981, 49.66555329731533, 57.73921067374093, 47.56824650083269, 35.20674460274832, 35.32216460364205, 48.658377170562744, 53.41964067731585, 47.3591057232448, 50.1606228692191, 50.33713143212454, 57.76114961079189, 50.32677514212472, 52.31163229261126, 51.03258357729231, 48.85984713690621, 45.578007970537456, 33.63908161435808, 22.274880715778895, 12.393787571362086, 6.844858033316476, 4.35078912121909, 3.3448324033192227, 3.080214168344225, 3.696944526263646, 3.8191364152090888, 3.9528861982481818, 5.1434674092701504, 4.289961116654532, 8.260864428111486, 6.0844814862523755, 3.7046726601464406, 4.987803442137582, 4.824973710945674, 3.2998365206377844, 1.8485096096992493, 0.883696052644934, 0.0931420541767563, 0.36364439555576866, 2.8946195329938615, 8.440379823957171, 14.678806032453265, 16.45473779950823, 17.66416209084647, 15.71523928642273, 22.221893753324235, 27.745096717561992, 27.55794698851449, 13.69216183253697, 3.262057427849088, 0.1909326296299696, 0.06047007055687053, 0.04780624241435102, 0.039662057999521494, 0.015743554403473223, 0.0020721596457795905, 0.058484514243900776, 0.08819388505071402, 0.07759645727596112, 0.04330430166529758, 0.04717752204409667, 0.0951328691361206, 0.02914261764713696, 0.014576177312327283, 0.04332740578268256, 0.0448987402154931, 0.10181527877492563, 0.044649368418114524, 0.026760382976915156, 0.03069882414170674, 0.08274798334709235, 0.0087969257729128, 0.05182689827467714, 0.03800080410603966, 0.033555717806198766, 0.03850444672363145, 0.028591806667723825, 0.08069592381694488, 0.03554095520770975, 0.05610339576378465, 0.031883800734898875, 0.012476064780327891, 0.05611656952117171, 0.05048838277746524, 0.07140050974807569, 0.03815577132627368, 0.0324140351398715, 0.04141163679638079, 0.04190688932846699, 0.01820581210111933, 0.10383338441273995, 0.17973332772297518, 0.13585096171924047, 0.19263558967837266, 0.19564254475491388, 0.16986833778875216, 0.1993367336690426, 0.130186171403953, 0.19670449277119978, 0.08116940555295774, 0.21921804041734763, 0.13462030275591783, 0.161288194624441, 0.16382227864648613, 0.1530832541840417, 0.15445123506443842, 0.10884603472160441, 0.09995489181684596, 0.15453715116849967, 0.11221065917717558, 0.15378671857927526, 0.13405956141650677, 0.09680163780493395, 0.11923457549086638, 0.09718761566494193, 0.09964691834258181, 0.21187154177044118, 0.10023854659604174, 0.1282317598483392, 0.11924638200019087, 0.17941368344639028, 0.18813165064368928, 0.14929689307297977, 0.16026961856654712, 0.19266552664339542, 0.1896670532545873, 0.19307580962777138, 0.21999507157930306, 0.08158546965569258, 0.12529033768389905, 0.24319756297128542, 0.11349957715719938, 0.13490363183830464, 0.15519789499895914, 0.14042994672698633, 0.2125570114169802, 1.6034939799989973, 10.204899174826485, 31.021490233285085, 45.81125552313668, 42.357639517102925, 42.723003591809956, 29.905084950583323, 29.27219091142927, 31.993303503308976, 27.3506509576525, 24.864502123423986, 14.16037835393633, 4.910219422408512, 1.5649576421294893, 0.4239429256745747, 1.6247987853629249, 1.6875166999442237, 6.232703932694026, 4.955581171172006, 17.223481280463083, 22.043493543352398, 3.9020753247397284, 11.204336745398384, 5.294783975396838, 7.545794912746974, 5.323331083570208, 7.731325711522784, 5.930311816079276, 8.72959772178105, 2.423423320055008, 3.26545335991042, 0.9769999917064394, 4.776934734412602, 8.268125295639038, 19.47267917224339, 30.000911031450542, 42.4598822593689, 40.14815058026995, 50.397810050419395, 47.79222863061087, 53.67101608003889, 53.844488280160085, 59.013155937194824, 51.608370372227256, 38.885666370391846, 38.09073339189802, 50.80594028745379, 58.022217750549316, 51.428610052381245, 54.716695649283274, 53.16771984100342, 60.251790455409456, 53.572507994515554, 53.62001282828194, 52.21973194394793, 50.52798107692173, 47.814365591321675, 31.73976026262556, 20.84302200589861, 11.397588729858398, 6.742390777383532, 3.4612540304660797, 3.22671063882964, 4.890925577708653, 6.518694826534816, 6.972097788538251, 8.839329753603254, 9.40595361164638, 8.356019139289856, 9.668942059789385, 10.283430320875985, 6.805077859333583, 9.645847984722682, 13.0064788545881, 15.24409236226763, 10.531149234090533, 3.6263636393206458, 2.7537365555763245, 1.0162504741123743, 4.639687401907785, 11.14173608166831, 16.62533518246242, 19.519798380987986, 22.549160855157034, 21.366167511258805, 30.161251136234828, 33.88071911675589, 33.47085877827236, 15.781179428100586, 3.159873528139932, 0.3374168729143483, 0.20405116783721106, 0.20373273135295936, 0.06736813219530241, 0.12841838411986828, 0.12898945276226315, 0.12375595287552901, 0.13472760628376687, 0.2015172873756715, 0.14731646648475102, 0.16916929744184017, 0.2332048320344516, 0.11499025752501828, 0.23976108165723936, 0.1374319347419909, 0.19760824713323796, 0.21305812309895242, 0.1335467110787119, 0.11812981191490378, 0.17239027603396348, 0.1944071360464607, 0.12536204526466982, 0.2172656644667898, 0.11522342929882662, 0.18650966696441174, 0.12423343796815191, 0.15783484492983135, 0.16246740706264973, 0.18208327091165952, 0.16133992613426276, 0.08854555618017912, 0.06756219321063586, 0.0990447388695819, 0.12311143960271563, 0.12119866295584611, 0.08335083456976072, 0.11625748952584607, 0.15713769091027124, 0.2079202559377466, 0.12719518904175076], [0.03710467308493597, 0.026622920263824717, 0.028147700409005796, 0.03530436022473233, 0.05204507442457335, 0.036916216768856557, 0.02184079883487097, 0.03181027128760304, 0.006799740217892187, 0.028972268038030182, 0.04556954672027912, 0.01421107373399926, 0.024727525987795422, 0.039040743838995695, 0.008596435638277658, 0.03981773428885, 0.007473913952708244, 0.03551830570878727, 0.005173885920417628, 0.050852549129298756, 0.028010554911036576, 0.03898807255817311, 0.01983624354137906, 0.032519611796098094, 0.019422235399750725, 0.019632671161421707, 0.01357474020083568, 0.052142732577132325, 0.10469192120113543, 0.015014806097107274, 0.008195617369243076, 0.04005447515685644, 0.10523163474031857, 0.01468903464930398, 0.05929918374334063, 0.028379423510549322, 0.03178703824856451, 0.056295889363225014, 0.027957761493910636, 0.03264189398448382, 0.13718832709959575, 0.04778871924749442, 0.04211871778326375, 0.028619592676737478, 0.020192962971382906, 0.024785863036023717, 0.02050429519398936, 0.7589701882430485, 5.194040306976863, 17.478789363588604, 34.234406743730815, 36.31531579153878, 35.6908985546657, 29.34017903464181, 15.652186121259417, 12.291728087833949, 15.007125786372594, 15.94168107850211, 10.875638314655848, 5.223857198442731, 1.804390502827508, 0.5056041266236986, 0.5122019297310284, 1.7472304957253593, 1.8727479662214006, 7.330468501363482, 10.879240955625262, 2.198187691824777, 4.340845380510602, 3.469528032200677, 2.543042855603354, 2.070701709815434, 3.2408799699374606, 3.8574431368282864, 4.768194769109998, 2.5148574880191257, 1.818632572889328, 1.780631029180118, 0.7382811669792447, 1.1863577919346946, 6.936643736703055, 10.152848482131958, 19.325113330568584, 23.825345175606863, 27.9527644770486, 29.89527756827218, 39.74057272502354, 44.98286696842739, 53.01852117265974, 42.21101515633719, 29.532428741455078, 23.111323969704763, 37.709416253226145, 52.78456490380423, 44.1465539932251, 52.3991413797651, 53.616080147879465, 42.996026107243125, 47.32829393659319, 48.51195778165545, 46.255867276872905, 36.3623411996024, 26.558672700609478, 16.102380752563477, 6.157134022031512, 2.867725661822728, 1.308240594608443, 1.9243194503443581, 0.98249351978302, 1.2493218247379576, 2.0935979783535004, 1.9889246693679263, 3.4987106834139143, 3.3322268511567796, 2.323924247707639, 4.894732322011675, 3.7849860191345215, 3.768101896558489, 3.5420422554016113, 2.4641022000994, 1.1334071989570345, 1.231069558433124, 0.4903182525719915, 0.816574228661401, 3.2240225544997623, 8.03044044971466, 12.621670246124268, 15.44593232018607, 15.499523775918142, 16.219631603785924, 20.900163991110666, 27.3980359349932, 24.23377071108137, 11.582494190761022, 2.7083509223801747, 0.08619215246289968, 0.05979053809174469, 0.0444554465024599, 0.03326854482293129, 0.024220726486029368, 0.05123956514788525, 0.016769821655803492, 0.03268036352736609, 0.007721412993435348, 0.03171943241198148, 0.013809427652241928, 0.03743266673492534, 0.05440346537423985, 0.023407193532745754, 0.00979101435015244, 0.07946967533124344, 0.01872767847297447, 0.02850123242075954, 0.031902640259691646, 0.09169243196291582, 0.004392906108738056, 0.05011115462652274, 0.03624066051894, 0.012165523899186934, 0.044388417420642715, 0.060119539366236756, 0.08654947578907013, 0.0078076378309300965, 0.015606488633368696, 0.018398611041318094, 0.01352743782834815, 0.010629787109792233, 0.04856399978910174, 0.04807547153905034, 0.06465056551886456, 0.0069500090072064525, 0.011639709301692034, 0.05493623410750713, 0.10298603666680199, 0.05545306405318635, 0.01001953985542059, 0.027862315365512456, 0.04924647031085832, 0.032020644284784794, 0.0747399130570037, 0.08714567736855575, 0.034058084777955494, 0.028791862539947033, 0.01719965153772916, 0.021479497597153698, 0.013037172528649015, 0.024766763971586312, 0.03548536283363189, 0.04057623465944614, 0.07679831010422536, 0.01322278069398765, 0.011285964399576187, 0.02310141172659184, 0.01690120978413948, 0.029818282462656498, 0.04868748298447047, 0.02996555170310395, 0.042415648100099394, 0.02115966333076358, 0.039807057540331564, 0.025617806340700815, 0.009879905830270477, 0.05435658538980143, 0.007009830350788044, 0.057356985818062506, 0.023351368760424, 0.0036053542613184875, 0.06802829927099602, 0.04925749311223626, 0.05754023777054889, 0.07450698555580207, 0.03757665865123272, 0.01792927854694426, 0.056138818684433184, 0.01393579038059605, 0.046978897880762815, 0.017547972400539687, 0.044287414090441804, 0.02163860897001411, 0.052865447010844946, 0.14247902748840197, 0.05475337231265647, 0.08003125126872744, 1.2939911420856203, 8.845802869115557, 23.30293791634696, 38.27863700049264, 43.032052516937256, 35.87741947174072, 27.444571495056152, 16.281831877572195, 14.912321090698242, 19.718330996377126, 26.24968978336879, 17.93688062259129, 7.533400194985526, 2.323674112558365, 0.4046615660190582, 0.21256600879132748, 0.9256568210465568, 1.1692187573228563, 7.514176266533988, 6.708637297153473, 2.2004940594945634, 3.993251757962363, 3.4810679044042314, 3.9227027893066406, 4.030207054955619, 4.022097638675144, 5.6231111117771695, 5.543731416974749, 4.852004374776568, 3.1603040993213654, 1.4929214332784926, 2.4418701359203885, 2.240956893989018, 7.153726305280413, 12.837213788713727, 24.59503882271903, 27.72004325049264, 33.89005749566214, 34.86946514674595, 44.79799277441842, 49.825441769191194, 56.7010942186628, 47.453847885131836, 32.578512055533274, 28.408951929637364, 42.031018597739084, 55.97591767992292, 48.21249042238508, 56.56065375464303, 54.90376199994768, 48.308733395167756, 50.96737125941685, 51.173805713653564, 47.90656818662371, 40.596879141671316, 31.6204423223223, 19.377485377447947, 9.927737270082746, 5.71589822428567, 3.582082335438047, 3.7604901450020924, 1.8914866064276015, 3.12579283118248, 3.0499061260904585, 4.134100862911769, 4.485774380820138, 3.781990477016994, 4.2510776945522855, 4.91117045709065, 6.572390939508166, 6.3401565211159845, 3.791701887335096, 3.6586295536586215, 0.9328844674995967, 0.8864495477506092, 0.25222886406949585, 0.625984924180167, 4.023807764053345, 10.368947880608694, 17.856800896780832, 17.2958311353411, 16.39492075783866, 17.730607713971818, 21.333417177200317, 30.181682314191544, 29.12557349886213, 15.614898613521031, 3.784500513757978, 0.15549336985817977, 0.07697318214923143, 0.06638838869652577, 0.01008331451365458, 0.07235267079834427, 0.027326041998873864, 0.03033483081630298, 0.026339550469336764, 0.01618846133351326, 0.0291945086126881, 0.021402711181768348, 0.05717899251197066, 0.017084578783916574, 0.03237501598362412, 0.016057838253410797, 0.07457332592457533, 0.01680527171785278, 0.02128598280251026, 0.04597611811810306, 0.06115533664290394, 0.03503775703055518, 0.03033606575003692, 0.08647451124020986, 0.0405426166419472, 0.057186544606728215, 0.027217495055603128, 0.045089859781520705, 0.02185527029048119, 0.017729619617706964, 0.004204966751525977, 0.04450222470664552, 0.03494669423837747, 0.000334670752636157, 0.053665738353239636, 0.025877742928319743, 0.04821195546537638, 0.04105221340432763, 0.03771913404177342, 0.07498313393443823, 0.04095726599916816, 0.013050566809917135, 0.16935376397200994, 0.1311441542846816, 0.1422559523156711, 0.15193780564836093, 0.13961509402309144, 0.12849013241274015, 0.15972961325730595, 0.20350752558026994, 0.07024505282086985, 0.15180208507393086, 0.09946802258491516, 0.11032036239547388, 0.13257937798542635, 0.14195872683610233, 0.09320332588894026, 0.13324382661708764, 0.10431547675813947, 0.09292194420205695, 0.1470028475991317, 0.12996958302600042, 0.10984660246010337, 0.15690031221934728, 0.10227522373731647, 0.11947568612439291, 0.15223114990762301, 0.1145242125328098, 0.08965447917580605, 0.10189626871475152, 0.18929651885160378, 0.15138555956738337, 0.190888036308544, 0.0992535851629717, 0.30677591423903194, 0.1793629697390965, 0.21974512641983374, 0.2121084454868521, 0.12410378349678856, 0.18644353694149426, 0.20122562588325568, 0.18201081694236823, 0.27259853961212294, 0.10308404426489558, 0.10247515408056122, 0.14265323456908974, 0.15065226677273, 0.12137805404407637, 0.13201214985123702, 1.4612981187445777, 8.949319737298147, 25.40924436705453, 47.441559995923726, 52.247719287872314, 46.93800319944109, 39.595313685280935, 24.080132143838064, 20.640956231525966, 22.78263075011117, 24.312408685684204, 15.74379985673087, 6.80104660136359, 2.605080932378769, 1.1418639166014535, 1.2292452220405852, 3.176958062819072, 4.641833092485156, 9.946809206690107, 15.74565849985395, 6.524764946528843, 8.552887661116463, 10.132259232657296, 7.266373106411525, 6.352920361927577, 8.378311565944127, 8.385453445570809, 8.593838606561933, 7.059770592621394, 5.538171121052333, 4.12901999269213, 2.0669512024947574, 1.9877132943698337, 8.690990924835205, 11.137872014726911, 22.30124739238194, 27.05041582243783, 32.78471721921648, 34.921218803950715, 47.46606976645333, 50.55779927117484, 59.921500887189595, 49.58623266220093, 37.42248344421387, 32.40652676991054, 43.346461977277485, 60.901995931352886, 50.2530061176845, 58.36297825404576, 58.413852964128765, 50.21390513011387, 52.991058417728965, 52.11616904394967, 49.892818450927734, 40.133277961185996, 31.680394853864396, 17.29639220237732, 8.64700882775443, 4.3065855503082275, 3.512450311865125, 4.90372633082526, 3.305366418191365, 4.938684020723615, 5.940249042851584, 6.463153966835566, 11.598762529236929, 8.640322055135455, 7.905641249247959, 10.255227582795278, 8.872248581477574, 9.753573724201747, 11.657915149416242, 7.029674470424652, 3.6298555433750153, 4.296675682067871, 1.339502494250025, 1.5019099052463258, 5.104194888046809, 10.912809440067836, 18.431574991771154, 22.262274946485245, 24.35944972719465, 23.478755133492605, 29.770401069096156, 36.78324917384556, 33.33326360157558, 16.84681248664856, 3.9788151383399963, 0.25514501758984154, 0.26405236391084536, 0.18418805939810617, 0.11026747059077024, 0.1760960950383118, 0.09965464685644422, 0.09298515652439424, 0.14448294495897634, 0.11927614254610878, 0.11228981707245111, 0.10367941124630825, 0.1563383223755019, 0.08444327594978468, 0.1458854361304215, 0.09228194997246776, 0.19410237882818493, 0.17598537169396877, 0.12739399980221475, 0.08248098660260439, 0.21926823843802723, 0.07350353404347386, 0.18202938166047844, 0.17965011218828814, 0.22670781851879188, 0.1045040280691215, 0.11967518899057593, 0.17880587891808578, 0.08331091635461364, 0.09915395586618356, 0.14498421948935303, 0.15531579724379949, 0.09552512344505106, 0.2034115535872323, 0.12478621330644403, 0.13257909300071852, 0.2061070610902139, 0.10227305921060698, 0.15514942045722688, 0.18721790824617657, 0.08649123034306935, 0.10848514908658606], [0.06120174843817949, 0.06885883970452206, 0.028020866946982484, 0.020827707036265304, 0.014470790645905902, 0.05120562821892755, 0.03667194076946803, 0.04261333588510752, 0.0168900037783065, 0.011788037904937352, 0.024652681878900955, 0.030321202440453426, 0.04157553353746023, 0.0240943238937429, 0.041584765006388934, 0.022157773076157485, 0.001221872040852239, 0.03345477893682463, 0.024854410339945128, 0.06997522658535413, 0.039065734283732514, 0.021754377222220813, 0.0758550242920007, 0.025485459781650985, 0.039574411631162675, 0.03363121161237359, 0.049546942580491304, 0.07059370446950197, 0.030430069991520474, 0.016991963842883706, 0.011050021658385438, 0.06006223029856171, 0.04014305451086589, 0.04139900586700865, 0.023024891636201313, 0.03839758085086942, 0.0034385705657768995, 0.04289163023765598, 0.02766988961957395, 0.03036259986194117, 0.021015818995822753, 0.038642664306930134, 0.021321816236845086, 0.009368766248891396, 0.09031252243689128, 0.024823592975735664, 0.015431938892496484, 0.05626387608104518, 0.4294811827795846, 3.9682933943612233, 11.986986177308218, 29.137404544012888, 36.44452796663557, 30.4961473601205, 23.920565026147024, 22.835407529558452, 15.101890529905047, 12.05330412728446, 13.277958001409258, 10.644180791718618, 6.071206518581935, 3.1341454344136372, 0.33916336776954786, 0.24781222535031183, 0.33869924981679234, 7.468636904444013, 5.696805443082537, 0.8551610495362962, 1.744846829346248, 2.8572731826986586, 3.822668271405356, 2.528541748012815, 3.2902080544403622, 3.9956797191074918, 3.912860231740134, 3.507637164422444, 1.8060527507747923, 0.9385081657341549, 1.1295057854482105, 0.9602986936058316, 0.38929850182362963, 2.0548761018684933, 6.064942283289773, 7.968958445957728, 11.50024402141571, 17.505619832447596, 25.182013954435075, 34.07008184705462, 39.519046783447266, 39.83386966160366, 27.722176347460064, 23.617484603609356, 28.31609967776707, 47.95106445040022, 48.28169795445034, 48.437959466661724, 44.62227978025164, 32.899491037641255, 40.35619354248047, 42.81477539879935, 34.35583346230643, 21.099851744515554, 9.59362098148891, 5.513189741543361, 2.3747607426983968, 1.5040640639407294, 1.1934723130294254, 1.8117356172629764, 2.626703292131424, 1.593629166483879, 3.437961063214711, 4.263679989746638, 2.074296534061432, 2.035558372735977, 4.4810865180833, 6.686393942151751, 6.7413455077580045, 2.81889654483114, 2.235454572098596, 2.3885570423943654, 0.806036579821791, 0.5102989375591278, 1.3854620052235467, 4.372417560645512, 8.428771989686147, 12.371046117373876, 14.217015726225716, 15.972883701324463, 13.035242659705025, 17.75312682560512, 25.11108500616891, 25.882626874106272, 14.30404886177608, 3.2581340840884616, 0.113447859218078, 0.07910159722502742, 0.02784046993058707, 0.10359789204916783, 0.01319809050099658, 0.03701788506337574, 0.0757244945104633, 0.04414552563269224, 0.033495294262788126, 0.04170474356838635, 0.008048438034685594, 0.06331367511302233, 0.0321024213252323, 0.031386499027056355, 0.030375196864562373, 0.011047494115440972, 0.059099056624940464, 0.04607191029936075, 0.03428229310416749, 0.03247277591643589, 0.009761433616014463, 0.03449828776397875, 0.017582684555756192, 0.018722414737567306, 0.045445171251360855, 0.03831251970093165, 0.01888320378826133, 0.08087746586118426, 0.09290619540427413, 0.02214027874703918, 0.059278963399784904, 0.021923547876732688, 0.05513668692271624, 0.015613903324784977, 0.0223976352052497, 0.027712369304416434, 0.06427368681345667, 0.07908792474440166, 0.025087127495290976, 0.05484390924019473, 0.030145312592919384, 0.01426732852788908, 0.014763634485591735, 0.029074655579669133, 0.01988500476415668, 0.039123508147895336, 0.01915043971634337, 0.03848831116088799, 0.02664147819658475, 0.026895102712192705, 0.012947845089781498, 0.05336146628750222, 0.03690367065636175, 0.04401174906109061, 0.08176812449736254, 0.06476385372557811, 0.020186092804319093, 0.03377688629552722, 0.024027949598218714, 0.03900554483490331, 0.06380760110914707, 0.04825564294255205, 0.04550839375172343, 0.042977081545229466, 0.030762657323586087, 0.011814394749567976, 0.06204350505556379, 0.016047566929566007, 0.015882877998852303, 0.09131507828299489, 0.04218622523226908, 0.04542735631444624, 0.012214059509070856, 0.06710339497242655, 0.07825032754668168, 0.024174414774669067, 0.017516963350187455, 0.025475322468472377, 0.023821412020229867, 0.06844256525593144, 0.05590400146320462, 0.039346953122211356, 0.080449561322374, 0.04098203592002392, 0.031364945362188985, 0.05218929365011198, 0.07658058178744145, 0.021641786210238934, 0.02198090444185904, 0.018092474700616937, 0.8204418239848954, 6.841585431780134, 19.33416335923331, 34.15224082129342, 43.55866343634469, 34.96561084474836, 25.125269753592356, 19.46278841154916, 14.413545523371015, 18.471092871257238, 16.830835103988647, 14.420909745352608, 9.726758888789586, 2.4022091669695715, 0.3515229916998318, 0.2594121071909155, 0.42807338546429363, 1.537921007190432, 1.5656896999904086, 1.0992613626377923, 2.8278223744460513, 2.033929454428809, 5.25360243661063, 3.8991774916648865, 5.822774546486991, 5.328153567654746, 6.740048365933554, 4.188207353864398, 3.41529495375497, 2.664829794849668, 4.066734169210706, 2.335410705634526, 1.329437485763005, 2.0494489073753357, 7.33455056803567, 10.344071592603411, 14.040357777050563, 20.83090955870492, 30.078539780208043, 37.84033421107701, 45.050615378788535, 46.106178760528564, 30.24311133793422, 27.307506118501934, 31.433709485190256, 53.28556823730469, 51.15735237939017, 52.38099615914481, 49.43297971997942, 40.08829879760742, 43.332808767046245, 46.64228439331055, 38.07188292912075, 25.176863602229528, 13.51225299494607, 7.827883958816528, 3.7225447297096252, 2.785189530679158, 1.439453199505806, 3.6396333958421434, 3.350939218487058, 3.048951183046613, 4.596946861062731, 5.2195762395858765, 3.153426251241139, 2.9084670756544386, 3.4301667043140958, 4.6355432357106885, 6.388965444905417, 4.8270090988704135, 2.8591170608997345, 1.7806393887315477, 0.5410458562629563, 0.46403419439281735, 1.1667645233018058, 3.9421364665031433, 9.899902786527361, 14.529120990208217, 15.13531310217721, 18.705693585532053, 15.618205956050328, 19.59772069113595, 28.077121598379954, 30.151884964534215, 18.17738209451948, 4.4327205419540405, 0.3453952505120209, 0.16331051396472113, 0.007398071549167591, 0.06959346921316215, 0.04650400818458625, 0.007246681056650621, 0.11202946318579571, 0.027747276538450803, 0.055801468036536656, 0.01642622339672276, 0.04839901060664228, 0.07215899654797145, 0.03349445627204009, 0.024164772792054073, 0.0766165034313287, 0.02090782336225467, 0.026341789634898305, 0.02496341529435345, 0.02370288043415972, 0.03622999055577176, 0.032510953689260144, 0.0625662620046309, 0.03341249941981264, 0.014753113800127591, 0.06013433821499348, 0.03279434723247375, 0.02599328217495765, 0.11029363490108933, 0.0718115119795714, 0.04528235338096108, 0.04742797610482999, 0.014217267910550748, 0.04634815886882799, 0.05711166148207017, 0.019988813836659704, 0.023144710742469345, 0.045535999948957136, 0.011967048165388405, 0.01337437644334776, 0.02227919182873198, 0.023061924381181598, 0.03266363424648132, 0.16322539853198187, 0.10849489284945385, 0.1109065827248352, 0.07946010120213032, 0.12432185108108179, 0.09103972198707716, 0.24078376963734627, 0.14736678664173397, 0.07476939540356398, 0.13811767580253737, 0.1429466466818537, 0.1374431848526001, 0.10737387835979462, 0.18255321069487504, 0.15132626917745384, 0.13139956843640122, 0.10369019995310477, 0.10111566167324781, 0.16858292104942457, 0.1374066932392972, 0.20851663393633707, 0.09820400005472557, 0.21236581381942543, 0.09981087275913783, 0.14261697365769319, 0.09797023795545101, 0.21710798649915627, 0.2645279626761164, 0.16635033727756568, 0.10705105175397225, 0.098469558304974, 0.20527573355606624, 0.21964459467147077, 0.13543009358857358, 0.1494434294956071, 0.1806299438966172, 0.08755494933575392, 0.18409462512603827, 0.12045992831034319, 0.17933160785053456, 0.28941963985562325, 0.17234822043350764, 0.17264472666595662, 0.136939494737557, 0.1436666130487408, 0.06608643382787704, 0.06713905198765652, 0.15989318090890134, 0.9274204692670277, 7.642076100621905, 20.264025143214635, 41.22432231903076, 50.39875847952706, 42.20071792602539, 31.418948037283762, 32.042253562382285, 22.763519729886735, 19.931328024183, 18.970576286315918, 15.424663884299141, 9.238849435533796, 4.105360507965088, 0.7096682137676648, 0.6857271641492844, 0.8266154612813676, 10.539242148399353, 10.396303806986127, 5.019163267953055, 7.68763370173318, 7.459288971764701, 9.652299387114388, 8.334547468594142, 11.751480460166931, 9.336247546332222, 13.00458720752171, 7.58723657471793, 4.409246487276895, 3.148546878780637, 3.6979285648890903, 2.5049721556050435, 1.1478428414889743, 2.769148745707103, 7.572991030556815, 9.435905558722359, 12.940390195165362, 20.65689366204398, 28.75667973927089, 39.328968388693674, 47.36919103349958, 48.244222845349995, 36.46385785511562, 33.3107271194458, 35.0252229145595, 58.54754325321743, 54.9598582812718, 54.46762704849243, 51.04243264879499, 43.76084906714303, 48.17403561728341, 48.33553259713309, 37.78870562144688, 24.372013807296753, 12.420148168291364, 8.120428306715828, 4.795925898211343, 3.252347537449428, 2.9024946647030965, 5.097777792385646, 6.600948904241834, 6.3019444687025885, 8.06098907334464, 10.353053876331874, 6.796059097562518, 6.36036752802985, 9.785982728004456, 13.624931062970843, 13.515954647745405, 8.07453806059701, 4.932974772793906, 4.997090143816812, 2.4691157596451894, 1.0559204540082385, 2.070389040878841, 5.957217412335532, 10.68955773966653, 17.959067957741873, 21.10747912951878, 24.84290885925293, 20.364695855549403, 24.389446837561472, 34.266510895320344, 35.04832220077515, 20.53853283609663, 4.899295551436288, 0.26027482375502586, 0.20179187692701817, 0.09303210436233453, 0.12673974276653358, 0.10787419615579502, 0.10120956413447857, 0.11702537403575011, 0.14030000727091516, 0.12936922881220067, 0.1396326409386737, 0.18526546444211686, 0.12797425580876215, 0.0755511966667005, 0.13554883721683705, 0.21336465807897703, 0.1299192357276167, 0.11408148200384208, 0.08925220290465014, 0.15400883023227963, 0.07343051689011709, 0.16732280009559222, 0.1972417432282652, 0.08737063208328825, 0.08270874366696392, 0.11244830249675683, 0.10670577242438282, 0.12448729148932866, 0.18143357363130364, 0.19815212009208544, 0.08614784412618194, 0.1385096926242113, 0.10231700113841466, 0.18866165434675558, 0.11746395193040371, 0.11397580696003777, 0.1019548602136118, 0.1597111706754991, 0.1778824741819075, 0.07729052619210311, 0.13083664221423014, 0.2016097174159118, 0.1878456888454301], [0.015405842435679265, 0.08756233858210699, 0.038032478120710166, 0.041850112910781584, 0.044462370952325206, 0.023397828053150858, 0.01625863033612924, 0.07975211553275585, 0.024897385355351225, 0.026262473980230943, 0.019842184115467325, 0.03150606368269239, 0.03388501424342394, 0.05727051331528595, 0.011555570111210858, 0.037248278236282725, 0.043000467254647186, 0.0353749109032963, 0.04373596189543605, 0.077197302265891, 0.03292262088507414, 0.027975398315382854, 0.03387167085228222, 0.021304065760757242, 0.05408934098003166, 0.0312859706713685, 0.04347443075052329, 0.05078636482357979, 0.038761848982955725, 0.009008956940046378, 0.012761177561644996, 0.03475147971351232, 0.052412830226655514, 0.03757632616907358, 0.02539163874462247, 0.03908244999391692, 0.007169457834347018, 0.055438821603144915, 0.06334545090794563, 0.02357134472445718, 0.03299309013943587, 0.054862294146525006, 0.03685920964926481, 0.014349904543321048, 0.00840872825522508, 0.025278528653351322, 0.08116791277591671, 0.03649866667443088, 0.024430778875414814, 0.2615800808582987, 1.4676595202514102, 10.175438812800817, 28.12663619858878, 34.00970547539847, 30.703023024967738, 23.953641925539287, 19.71389283452715, 20.181079285485403, 29.05013690676008, 20.202243498393468, 16.92895061629159, 9.447786109788076, 5.10191240480968, 1.8960374593734741, 0.7857458857553345, 2.9778748026915958, 1.217803276010922, 0.7724961595875877, 1.7150049677916934, 0.9820286418710436, 4.079883635044098, 2.7603833760534013, 2.6016639385904585, 5.705340002264295, 3.551951906510762, 2.737648436001369, 1.910232194832393, 1.6207680702209473, 5.221463544028146, 1.8584989479609897, 0.05166197016036936, 0.09109717354710613, 0.8814536843981061, 2.449287989309856, 3.7498585326331, 4.535782303128924, 7.527669668197632, 11.493611965860639, 15.777559416634695, 23.603105306625366, 23.555722066334315, 20.4416332585471, 27.321480682918004, 32.05183512823922, 41.07630137034825, 42.96581186567034, 34.61390345437186, 30.951678207942418, 24.74749445915222, 21.212049518312725, 16.496612855366298, 8.134142313684736, 3.369216020618166, 1.4191968121698924, 1.5310502158743995, 2.383584303515298, 1.0283532589673996, 2.683347395488194, 2.5344718183789934, 3.2848746606281827, 1.688749136669295, 3.383801592247827, 3.5012426504067014, 1.2614936573164803, 2.1961837879249027, 1.8010831602982111, 4.928639531135559, 5.426121865000043, 2.2765034437179565, 2.239648678473064, 0.6742024368473462, 1.041950666478702, 6.580953291484287, 10.884893315179006, 17.74200275966099, 18.3283143384116, 22.745171274457658, 16.098300422940934, 17.860801322119578, 26.16466988836016, 23.919693027223857, 15.637045996529714, 5.6163904666900635, 0.6059369285191808, 0.04497984889894724, 0.027217132039368153, 0.07139167522213288, 0.030314668148223842, 0.02726191026158631, 0.03541754325851798, 0.05235694268984454, 0.06212357897311449, 0.08628108126244374, 0.016799382033890913, 0.05693351211292403, 0.021807058681068674, 0.03894180325525148, 0.059432142680244784, 0.01263361467447664, 0.06606508711619036, 0.04329463254128184, 0.013637819360675556, 0.06025603347058807, 0.05079794741634812, 0.023993137359086956, 0.01139593287371099, 0.04103578267885106, 0.05140543642586895, 0.05848177296242543, 0.09167844735618148, 0.03599304273458464, 0.07511092921985046, 0.036821520421653986, 0.07142623979598284, 0.014635567786172032, 0.035389563867024014, 0.03848085406103304, 0.04307949283559408, 0.03387287525194032, 0.018277823326310942, 0.03406447657783117, 0.0049690641878571895, 0.034640552808663676, 0.0615901147414531, 0.04041697231254407, 0.016371838814978088, 0.04897023531209145, 0.06464857741125993, 0.054436523600348403, 0.06858491511749369, 0.07651698948549372, 0.06025962970618691, 0.028546483921153203, 0.05615913063021643, 0.07844907723899398, 0.019843524222129157, 0.02927831108016627, 0.033602000679820776, 0.01744897583765643, 0.029108344843345027, 0.025012251155983125, 0.05746370580579553, 0.0215614018629172, 0.026996177288570573, 0.06019835799400296, 0.06745729169675282, 0.007975040901718395, 0.03439497062936425, 0.04108411812090448, 0.07129048529480185, 0.060547599968101294, 0.05493876504312668, 0.04010848993701594, 0.021491227771288583, 0.05318632622116378, 0.04677918806139912, 0.07304453903010913, 0.06267277843185834, 0.05919589714280196, 0.05906475667974778, 0.038944622568253956, 0.03866191773808428, 0.03261810115405491, 0.003899083165119269, 0.0036884586858962265, 0.05091225003291454, 0.03718428899134908, 0.0731213695502707, 0.0703391588426062, 0.014444256534001656, 0.04570413753390312, 0.033267001155763865, 0.04879438956933362, 0.026939823258934275, 0.039041059357779365, 0.5990985440356391, 2.8354706040450504, 16.49498871394566, 33.56020566395351, 38.05698251724243, 33.41527666364397, 26.556563922337123, 18.972928251538956, 13.557142700467791, 23.12125641959054, 19.00791069439479, 20.787337405341013, 13.35636407988412, 5.88978818484715, 1.8165793802056993, 0.3536445807133402, 0.32027015728609903, 0.20446041944835866, 0.7509592409644807, 1.3943249753543308, 1.120492126260485, 2.7874880816255296, 3.439896136522293, 4.363873881953103, 4.541462021214621, 5.113598840577262, 4.79614085810525, 5.408491245337895, 3.7984216638973782, 5.528850981167384, 3.784747609070369, 1.979962795972824, 1.4569392097847802, 2.4788343352930884, 4.382769073758807, 6.304391537393842, 7.647507854870387, 10.234515871320452, 16.910633427756174, 20.089121614183696, 28.256187098366873, 26.358022621699742, 23.974880831582205, 29.113469736916677, 38.19123213631766, 45.306097166878835, 48.16803584780012, 38.191239084516255, 33.29334967476981, 29.365831783839635, 24.740829399653844, 18.74656115259443, 11.27634266444615, 5.229389701570783, 2.329188810927527, 2.5072036130087714, 2.818946267877306, 3.347816003220422, 4.2776979804039, 6.469221481255122, 4.903778008052281, 4.568610370159149, 5.469846444470542, 4.309059543269021, 2.900788447686604, 3.406832265002387, 4.110727991376605, 5.600975453853607, 2.29713351385934, 0.19248574200485433, 0.3978194631636143, 0.7104933666331428, 1.7755856599126543, 6.416253626346588, 12.595880270004272, 17.2498688016619, 19.55652482169015, 22.658869436808995, 16.649111918040685, 19.125667027064733, 26.973539216177805, 27.971175466264995, 19.45211945261274, 7.465077689715794, 1.0001535607235772, 0.0662622151098081, 0.051663293303655725, 0.03762453268947346, 0.05164956993290356, 0.025592552963644266, 0.024180674260216098, 0.018925040561173643, 0.03395979219515409, 0.06763746988560472, 0.012868493812025657, 0.018319003616592715, 0.017742133499788384, 0.006208183634693601, 0.03821925845529352, 0.0051142172472152326, 0.03632336715236306, 0.00285992438356126, 0.08147436633173909, 0.06411112339368888, 0.00896054261829704, 0.01671562027851386, 0.029968364230756248, 0.019691094722864882, 0.023400917083823254, 0.05225446693865316, 0.08850493907396283, 0.03465928716052856, 0.05814203047858817, 0.013193143980710633, 0.04890111294974174, 0.03475486560325537, 0.08176466396876744, 0.0637130540396486, 0.10875078876103673, 0.01708410889841616, 0.02396782291387873, 0.025540850291560804, 0.008182535214083535, 0.05735651084354945, 0.05767282351319279, 0.021236831422096918, 0.06678266503981181, 0.1178140217172248, 0.2890837107385908, 0.12185681478253432, 0.1337777115404606, 0.123690094266619, 0.11523902203355517, 0.11681980506650039, 0.22634790997420037, 0.14017457328736782, 0.15017229824193887, 0.07840268579976899, 0.1729564592242241, 0.1081892806770546, 0.11471927777997085, 0.16367405945701258, 0.13756323126809938, 0.09274144710174628, 0.11712264881602355, 0.1639441435358354, 0.20187175406941346, 0.07010618384395327, 0.12045200302132539, 0.13370802599404538, 0.09057623507188899, 0.15880040026136807, 0.18599265042160237, 0.16676760917263372, 0.13904887012072972, 0.0886525475819196, 0.20278715209237166, 0.11263882155929293, 0.1723565799849374, 0.21035471744835377, 0.1330992986581155, 0.13208532306764806, 0.09768453400049891, 0.10046293134135859, 0.16079122200608253, 0.1970298367419413, 0.14942639826663903, 0.09996840144906725, 0.17853299927498611, 0.22708887021456445, 0.10239144321531057, 0.137784515108381, 0.22755958352770123, 0.1295220348984003, 0.14083021453448705, 0.08217848890594073, 0.5379505966390882, 3.6268085411616733, 18.754195485796245, 38.45163324901036, 47.80698660441807, 42.29003701891218, 34.94962303979056, 27.447547061102732, 28.48715216772897, 38.305957317352295, 28.452181884220668, 22.753526483263286, 13.089564544813973, 6.3481538976941785, 2.3908199838229587, 1.2850415366036552, 3.5553267768451144, 2.8749224756445204, 2.880195506981441, 5.329417705535889, 4.863243520259857, 9.377662284033638, 10.087484172412328, 9.3359956741333, 14.318076406206403, 8.69106388092041, 9.493566921779088, 6.839832748685565, 6.69926461151668, 10.371108770370483, 5.060053416660853, 1.2802654100315911, 1.0072234613554818, 1.7840488914932524, 3.409283459186554, 5.07622925724302, 6.1719697288104465, 10.11303096158164, 13.941175716263906, 19.948507445199148, 28.451577390943253, 29.920648915427073, 28.8713093825749, 34.000134331839426, 40.72150550569807, 48.82529721941267, 51.347847666059224, 39.5493027142116, 34.819764682224815, 27.61362985202244, 23.63185521534511, 18.45523360797337, 10.154212066105433, 4.922047427722386, 2.9594599051134924, 3.745151996612549, 5.503698068005698, 4.498247265815735, 7.340863874980381, 7.3941609007971625, 10.961557132857186, 5.235728195735386, 7.641553248677935, 10.52913338797433, 5.152526123183114, 8.003198300089155, 5.738132894039154, 10.988035849162511, 10.745292714663915, 5.288084609167917, 3.5463273397513797, 1.402265789253371, 1.694326477391379, 8.580539754458837, 14.807710749762398, 22.995471443448746, 25.361659629004343, 31.354406220572336, 22.463710171835764, 25.36227454457964, 35.65123476300921, 32.26625306265694, 21.233816487448557, 7.986001508576529, 1.0308721980878284, 0.16380190902522632, 0.17548371718398162, 0.22358319189931664, 0.09596589300781488, 0.10419918942664351, 0.1026403841429523, 0.16098851284810475, 0.19527913496962615, 0.19694792399449007, 0.09397978029612984, 0.1562504113784858, 0.105278406159154, 0.16712157375046185, 0.11474738270044327, 0.060409837003265104, 0.1105880376749805, 0.19123754969664983, 0.19032196168388638, 0.17878856270440988, 0.14298773876258306, 0.10185675762061562, 0.1427828347576516, 0.1033555736233081, 0.07739274070731231, 0.19296473344521864, 0.26852450679455486, 0.14738218938665731, 0.11552722299737589, 0.1314573117664882, 0.18385135675115244, 0.12610734812915325, 0.10065145551093987, 0.206929635522621, 0.1878556768809046, 0.12583822757005692, 0.07393222568290574, 0.11133824634764876, 0.08415513605411563, 0.18990372626909188, 0.17985341485057557, 0.18661885681961263, 0.10132178025586264], [0.04132777665342603, 0.02775399912414806, 0.03963371219911745, 0.027654405450448394, 0.026354948125247444, 0.02181004762782582, 0.05945278371551207, 0.034620814224971194, 0.01623220309349043, 0.05487497935869864, 0.047058011671262126, 0.037492574591721804, 0.021319761972076127, 0.1006375862551587, 0.0965760995500854, 0.028879189996847084, 0.07976717222481966, 0.07368274192724909, 0.054411288883004866, 0.06280799689037458, 0.030309999827295542, 0.03504956014720457, 0.06047369393387011, 0.03977795856605683, 0.024556080544633523, 0.07866306682782513, 0.033063783310353756, 0.013895926448250455, 0.04351754147293312, 0.004396493014480386, 0.01974131309959505, 0.0371951726930482, 0.012271846095765275, 0.043847428235624514, 0.05866897398872035, 0.04917503075141992, 0.09047375592802252, 0.03055221986557756, 0.0375078891270927, 0.05678724031895399, 0.03836726051356111, 0.011622437192792339, 0.03057221629257713, 0.013579164249157267, 0.04947579139843583, 0.0365747134866459, 0.016800910434020416, 0.05667925825608628, 0.0410946998745203, 0.03330156572961381, 0.07046523064907108, 1.8155487669365746, 8.928053906985692, 23.293576955795288, 38.48779514857701, 34.02686405181885, 24.46692967414856, 23.430102109909058, 16.08470800944737, 17.72083854675293, 13.460937074252538, 12.811627047402517, 10.183095727648054, 5.333723417350224, 2.6368843572480336, 0.6336237628545079, 0.16957901045680046, 0.07447792390095336, 0.3861302046903542, 0.6435306998235839, 2.615828709942954, 1.8902426617486137, 3.7669089777129035, 2.9909078861985887, 3.38881602031844, 3.1624460986682346, 4.443885862827301, 3.2886998610837117, 4.357711264065333, 2.5057077961308614, 2.8496959550040106, 1.4860279517514365, 0.9735123217105865, 0.5370343572327069, 0.6038819987859044, 1.0564891206366676, 1.151386097073555, 2.6615348287991116, 3.8581027814320157, 7.672395433698382, 10.280231543949672, 10.304370454379491, 11.301357047898428, 19.324065889630997, 20.17870647566659, 22.75181027821132, 20.09840440750122, 15.54901579448155, 8.734893986157008, 4.5027627263750345, 2.487542382308415, 1.1096114643982478, 0.44484525120684076, 1.1889187459434782, 1.4228618783610207, 1.5610296300479343, 2.0155961981841495, 4.027104250022343, 5.794961776052203, 2.1513650843075345, 5.164530004773821, 3.840656723294939, 1.800796547106334, 2.714687462363924, 1.6499793827533722, 2.3298875391483307, 4.082133548600333, 1.4170113865818297, 0.5937869176268578, 0.4655005357095173, 1.9034857111317771, 5.658253797463008, 21.86823739324297, 23.097302504948207, 14.939995765686035, 14.71672408921378, 10.153373939650399, 23.4062055179051, 27.630451440811157, 26.09215153966631, 17.23141438620431, 5.825019248894282, 0.6312964963061469, 0.04028420675812023, 0.03344482143542596, 0.05971999080585582, 0.013081939724673117, 0.021720196020656397, 0.02497751864471606, 0.020290899323299527, 0.03716097452810832, 0.030538119907890047, 0.046959980324442895, 0.01186991248479379, 0.009596133155615201, 0.04815622738429478, 0.01881682949273714, 0.032543954239892106, 0.03768252368484225, 0.07281296181359462, 0.03145181480795145, 0.03709354171795504, 0.0327526512555778, 0.02983615846772279, 0.03081858896517328, 0.02383707430479782, 0.042386091114687066, 0.09513373087559428, 0.07486078728522573, 0.009547654373039092, 0.09963697780455862, 0.049009176436811686, 0.07872108835726976, 0.033336316900593896, 0.01608770227591906, 0.01553631793441517, 0.02769767732492515, 0.03658598395330565, 0.051596695091575384, 0.04492874503401773, 0.03310258872807026, 0.017265817183735113, 0.024913605734972016, 0.020991600384669643, 0.023448317843888487, 0.0636621028450983, 0.06846653111279011, 0.051371119517300806, 0.036941305601171086, 0.018613116316763417, 0.017106020490505865, 0.026476655255204866, 0.026876794141052023, 0.01805951995109873, 0.07185224443674088, 0.06194365184221949, 0.017738169158941934, 0.03769827926797526, 0.04745009973911302, 0.07592363096773624, 0.027368486060627868, 0.027118213508012037, 0.08856694360396691, 0.03896223394466298, 0.035866984498820136, 0.019827916220362698, 0.056077051641685624, 0.028203311442796673, 0.03104180663025805, 0.048531810087817054, 0.04747081541323236, 0.010509454013247575, 0.16631487703749112, 0.047085007186979055, 0.018649258484531726, 0.020796604687348008, 0.07821161033851759, 0.07258065856461014, 0.029853946263236657, 0.05420026109953012, 0.015661575498857667, 0.06050830600517137, 0.05113658728078008, 0.03680683353117534, 0.050820332286613326, 0.041093749925494194, 0.022519596785839115, 0.014607057441025972, 0.046253862857286415, 0.013317572884261608, 0.023477467708289623, 0.08641461016876356, 0.0695546298686947, 0.0598807018250227, 0.02949574084154197, 0.015498106234839984, 0.26393546589783257, 3.1454944482871463, 13.685053825378418, 29.99039145878383, 41.57339286804199, 35.96837139129639, 25.79227771077837, 20.426887444087438, 18.345314843314036, 19.6249680519104, 18.50393874304635, 20.597382341112407, 15.287773949759346, 7.934979149273463, 2.4495717797960554, 0.3247637961591993, 0.199253789548363, 0.16370147227176599, 0.17347025951104506, 0.36730995029211044, 1.3609798103570938, 1.7420118557555335, 3.8376225318227495, 3.046736010483333, 3.5714313983917236, 3.333372869661876, 3.8511793357985358, 3.9806351321084157, 4.6220641647066385, 3.5889666974544525, 5.06838560955865, 4.088208879743304, 4.635148925440652, 1.43972005375794, 1.4163782319852283, 2.020368959222521, 1.9066710259233202, 3.8420832753181458, 4.334654101303645, 10.885171243122645, 12.77417278289795, 13.23806665624891, 14.667780978339058, 23.365469966615947, 24.895536252430507, 27.861154215676443, 23.18910731588091, 20.025644608906337, 12.142490335873195, 6.449806911604745, 4.705813842160361, 3.2997435884816304, 1.548341568027224, 1.9536089301109314, 3.0559632182121277, 3.4478807023593356, 4.065362768513816, 5.827538839408329, 4.437715428216117, 3.9762430020741055, 6.145543992519379, 4.862086645194462, 2.9663483926228116, 3.4103819259575436, 2.7119741908141544, 3.6641455548150197, 0.7540247536131314, 0.8545644815479005, 0.9228145735604423, 1.0107307817254747, 2.81973597407341, 6.389762316431318, 22.164586748395646, 24.64479660987854, 19.19680789538792, 15.949285881859915, 13.869524155344282, 22.705180917467388, 30.213515486036027, 32.09808928625924, 21.326571464538574, 7.7594146728515625, 0.9741219175713403, 0.031220573466271162, 0.03763849015480705, 0.14638270730418818, 0.026060531780655895, 0.03480840880157692, 0.053741761416729004, 0.029282053200794116, 0.0595909266599587, 0.025153662942882096, 0.008105211059695907, 0.0040868910561714855, 0.06478352445576872, 0.01652003595206354, 0.09389783362192766, 0.03005334734916687, 0.07491532793002469, 0.003981678688433021, 0.04433900310790964, 0.023483472743204663, 0.028402929659932852, 0.03152555799377816, 0.04315035564026662, 0.05626878188923001, 0.015279114146583846, 0.027475491033068726, 0.13319874475044863, 0.024265852457444583, 0.014273194463125296, 0.048046423454902, 0.07718929555267096, 0.04717336601710745, 0.07013299954789025, 0.05379792036754744, 0.023607184944142188, 0.041797828394919634, 0.010994319870535816, 0.04825274559802242, 0.05421999289787241, 0.03216178635401385, 0.047439921713833294, 0.023450640129989812, 0.07253421962793384, 0.02943973456110273, 0.15925131392266068, 0.13356210025293486, 0.13677224942616054, 0.09184111255620207, 0.11699009021478039, 0.11590211359517914, 0.12867957938994679, 0.10233156928526503, 0.12642864803118364, 0.1456472296267748, 0.2865500609789576, 0.11830794092799936, 0.08884661538260323, 0.15972965396940708, 0.18809856527618, 0.15376105638486998, 0.14887028453605516, 0.2075684762426785, 0.15949850422995432, 0.19955672829278878, 0.11081875993737153, 0.06762173465852227, 0.16073422506451607, 0.12758669017681054, 0.22516690620354243, 0.11980564413326127, 0.17864668103201048, 0.08747298230550118, 0.147778345271945, 0.16927381897611277, 0.10370121257645742, 0.10023704024830035, 0.23083845472761563, 0.15116578207484313, 0.07333762544606413, 0.22880005410739354, 0.2886168786457607, 0.11578266429049627, 0.14316627489668982, 0.1461021059325763, 0.08250134943851403, 0.10412683045225483, 0.14238540322652884, 0.10419667206172432, 0.1701123389814581, 0.2291830192719187, 0.2147532935653414, 0.17749443357544287, 0.12841613138360636, 0.08940743814621653, 0.2691671337400164, 2.9463208615779877, 14.904132638658796, 34.37354442051479, 49.452184540884836, 46.43846246174404, 33.91678374154227, 32.10180309840611, 24.768153190612793, 27.46996021270752, 21.734276124409266, 19.211293152400426, 14.776836429323469, 8.708389214106969, 3.471466579607555, 1.1550077370234897, 0.4640325116259711, 0.5514745052371706, 0.8721589488642556, 2.8120486608573367, 5.026038076196398, 6.744488264833178, 9.763982125691005, 9.355592199734279, 11.409244332994733, 8.85914775303432, 11.263420752116613, 8.441907559122358, 12.37167579787118, 6.985203393868037, 8.078439474105835, 1.8692732155323029, 2.7048125522477284, 1.961212430681501, 1.5541411425386156, 1.8549091177327293, 2.1313586149896895, 3.8203423619270325, 4.781540087291172, 9.791371924536568, 12.986481939043317, 13.487130914415632, 15.332237209592547, 23.24397029195513, 24.569516352244786, 27.10833947999137, 24.253882271902903, 19.273964166641235, 11.674462284360613, 5.58147359745843, 3.457218212740762, 1.890359478337424, 1.5380836384637016, 2.974973495517458, 3.181715190410614, 4.991544612816401, 6.196339666843414, 10.570031353405543, 12.271803259849548, 6.034646834645953, 13.457117302077156, 8.882094178880964, 5.825243762561253, 9.80007801737104, 5.189977782113211, 6.775198868342808, 7.984718697411673, 2.96940364582198, 1.506491156561034, 0.7658444536583764, 2.7225612912859236, 7.00100142615182, 25.231818641935075, 29.350267818995885, 22.07052550997053, 21.854853425707134, 16.91640738078526, 31.868659768785747, 37.888790948050364, 35.74269042696272, 23.578803982053483, 8.278499824660164, 1.1096961455685752, 0.15740898278142723, 0.12295454873570374, 0.21422157995402813, 0.07132637301193816, 0.10816534196159669, 0.18758576922118664, 0.1624087816370385, 0.18647636446569646, 0.10458576439746789, 0.12162936984428338, 0.07807642580675227, 0.15815481490322522, 0.15391368605196476, 0.23197456662143978, 0.0810016920523984, 0.14048942710672105, 0.09801396275205271, 0.18904133540179047, 0.12334708124399185, 0.1452192911612136, 0.0922271582697119, 0.11120934505015612, 0.08544600142964295, 0.07735842719141926, 0.13049284209098133, 0.2975500635802746, 0.12715207492666586, 0.210347375699452, 0.10457778482564858, 0.20672870773289884, 0.10876785391675574, 0.140539855829307, 0.100254383603377, 0.13516961756561482, 0.16165526849882944, 0.20265798616622174, 0.143515693289893, 0.2457987405359745, 0.1531702966562339, 0.15377434210053512, 0.1286056326436145, 0.12200996013624327, 0.20025205026779855], [0.030531850244317735, 0.02153843005986086, 0.06668136654687778, 0.029372356033750942, 0.06814067145543438, 0.023947427847555706, 0.06637447872864348, 0.07056395070893423, 0.030923409054854085, 0.04896517004817724, 0.06078903629843678, 0.02113964994038854, 0.027042519534006715, 0.04518045099186046, 0.025223960867151618, 0.018241553933226635, 0.04589769982599786, 0.056309548273150406, 0.02585239116368549, 0.05805181924785886, 0.06874384837491171, 0.034834230451711586, 0.09869068608220134, 0.024117005623078773, 0.039153981155582836, 0.07079114458922829, 0.0623501418158412, 0.005202724930963346, 0.07045387875820909, 0.07002072914370469, 0.029122349806129932, 0.07267842867544719, 0.010318979903656458, 0.01118222063606871, 0.03102447006053158, 0.04048963323501604, 0.09260782320052385, 0.04721503145992756, 0.024843899832506264, 0.05488824811098831, 0.014626952087772744, 0.032000366265752485, 0.02742333204618522, 0.02902193340872015, 0.10240813517676932, 0.0162094246729144, 0.10603875214500086, 0.05328105988779238, 0.05608332809060812, 0.06806564583842244, 0.03149936993473342, 0.09760572215808289, 0.7068066416042191, 7.456959588187082, 20.83260144506182, 27.8794800894601, 37.87485980987549, 26.841240303856985, 21.944453920636857, 17.04629179409572, 19.88694987978254, 21.702566283089773, 25.719372000013077, 18.620103938238962, 11.907863565853663, 5.06412375824792, 1.6572895390646798, 0.652082792350224, 0.6176735215953418, 0.16206282377243042, 0.2769228161445686, 0.6841778244291032, 1.7912614473274775, 1.5638061953442437, 3.3695842751434872, 2.34909149152892, 3.3822119746889387, 3.517938954489572, 1.80765800178051, 3.709435216018132, 4.46817763362612, 10.79315277508327, 5.533072446073804, 3.2054450256483893, 1.5743824392557144, 0.7860759794712067, 0.2990755188677992, 0.7226997773562158, 0.2400614283978939, 0.980509374822889, 1.1859717326504844, 2.2220682161194936, 2.8787298713411604, 4.774564964430673, 5.803055558885847, 6.54275426694325, 4.006971844605037, 2.640590569802693, 1.423521088702338, 0.1448100802621671, 0.2744962934936796, 1.1471277198621204, 1.0473931687218803, 1.3708288818597794, 2.319758802652359, 3.17132111958095, 3.7068973864827837, 3.1197670059544698, 2.742056199482509, 2.8476937881537845, 3.495499747140067, 4.637238161904471, 1.7699055075645447, 1.7253855764865875, 1.548794612288475, 3.5744404026440213, 1.059584977371352, 0.5981539147240775, 1.7093828980411803, 2.3510641285351346, 7.09836653300694, 14.391807215554373, 43.93714223589216, 24.477593421936035, 13.415079832077026, 19.00231565747942, 23.56073866571699, 30.688852173941477, 26.446983882359095, 11.79685914516449, 5.178462445735931, 0.6132655952657972, 0.011243287939578295, 0.013005808943749537, 0.0500040919786053, 0.03691256625045623, 0.026747896236234477, 0.047414731101265976, 0.03537253263805594, 0.02395469326126788, 0.09851646543081317, 0.06652226365570511, 0.014209924465311425, 0.015559440711513162, 0.03581089340150356, 0.02190108667127788, 0.05883807170071772, 0.03580288329560842, 0.0258009531202593, 0.012725346671816493, 0.06838061500872884, 0.03239690213065062, 0.012283693317190876, 0.021347176483167068, 0.093855493036764, 0.015734024379136305, 0.027001106845481054, 0.04434828207428966, 0.06984022525804383, 0.019557548853169595, 0.010172492674817997, 0.04074873522456203, 0.03812604470710669, 0.017187780567577908, 0.057826226710208824, 0.03910452273807355, 0.039914910681545734, 0.04907568304666451, 0.05602241939465914, 0.04014451675383108, 0.032879435523812256, 0.02002783808191972, 0.04669012016217623, 0.03895280570057886, 0.0536451244593731, 0.03808230294712952, 0.011305485852062702, 0.04341696561979396, 0.056239676129605086, 0.015130196066041077, 0.05815644934773445, 0.021605479497728602, 0.03989954186337335, 0.042030341989759884, 0.05289161132116403, 0.029717967845499516, 0.021640536009467075, 0.02019555158247905, 0.037651684268244674, 0.033377300415720255, 0.03398449765518308, 0.03907799541151949, 0.010421111298325871, 0.018100995404113616, 0.05464939360639878, 0.030190329998731613, 0.042896430872912915, 0.0554130745918623, 0.022648070606270006, 0.0396826888567635, 0.05507517093792558, 0.04465192649513483, 0.0363383084934737, 0.05308240858305778, 0.027835869463160634, 0.05764221479850156, 0.05528590016599212, 0.058285723839487345, 0.010726006768111671, 0.035699980067355294, 0.022989460233865038, 0.019196273060515523, 0.030341928292598044, 0.07358890053417001, 0.053505994246474335, 0.04524176002347043, 0.05192766072494643, 0.03682721672313554, 0.061528313771954606, 0.03633069533056446, 0.043781006442649026, 0.02516458396400724, 0.07488184222685439, 0.03542167892945664, 0.032264367278133116, 0.05116963193618825, 0.04061478901920574, 0.0800730897379773, 1.470814762370927, 9.811057908194405, 26.85202043397086, 35.187324387686594, 39.69403369086129, 28.491220338003977, 21.34467499596732, 16.741295405796595, 14.910019499914986, 18.042998722621373, 23.304925101143972, 19.37933186122349, 13.418072768620082, 5.190783773149763, 1.3962770934615816, 0.5563367786152023, 0.3446972279676369, 0.25706717159066883, 0.15459520662469523, 0.4173643658203738, 1.303111955523491, 1.5470696134226662, 2.5465364967073714, 1.8779454358986445, 3.643964077745165, 2.9170394156660353, 3.0018714921815053, 5.8485462835856845, 6.072138445717948, 14.150619609015328, 15.2692483152662, 3.2138212961809973, 3.072112568787166, 3.7186567783355713, 1.9657506900174277, 1.766082912683487, 0.6415166450398309, 1.7730190604925156, 2.66802270923342, 2.9049931934901645, 3.976958232266562, 6.862458688872201, 9.724326150757925, 8.676855683326721, 5.272037744522095, 3.7840784106935774, 2.9163018209593634, 0.9415409458535058, 1.7151808440685272, 2.9490734338760376, 1.76506749859878, 2.43699597460883, 5.52977682862963, 5.788373146738325, 5.074255534580775, 5.732652936662946, 3.795568125588553, 4.1671365073749, 4.306791390691485, 2.8084225697176795, 2.8505909698350087, 2.4714134420667375, 1.2629602700471878, 0.9628797322511673, 0.45476866300616947, 0.1907577711556639, 0.9967275559902191, 2.9000106837068285, 9.347200512886047, 15.492483513695852, 43.14947707312447, 31.646494592939103, 13.982707704816546, 17.767824002674647, 19.79914549418858, 32.7645639692034, 31.291153294699534, 16.840044941220963, 7.6748281717300415, 1.1517224333115985, 0.05044753496934261, 0.03072782133572868, 0.011102061901640679, 0.03555966581084898, 0.013562326402669507, 0.013058822036587765, 0.016503403362418925, 0.017476061259263327, 0.04156779145289745, 0.04492047029946532, 0.04712219090600099, 0.0384357450529933, 0.046066359882908206, 0.07667831797152758, 0.054776649456471205, 0.030318691860884428, 0.03269606143502252, 0.0010613901332752512, 0.06738620836819921, 0.019443137671000192, 0.029350792190858295, 0.03638157527893782, 0.0937375704358731, 0.02971648863915886, 0.07317048870027065, 0.0030226065469573116, 0.022330762186486806, 0.027871607902592847, 0.03923690831288695, 0.06395189836621284, 0.017145365343562195, 0.04602569527924061, 0.030230163397001367, 0.018463299177320938, 0.03701715903090579, 0.053669589039470465, 0.024262352913085903, 0.07048709983272211, 0.027739897470123002, 0.03425447316840291, 0.00768725893327168, 0.03861840668001345, 0.05950391811451741, 0.07082209935677902, 0.12084150926343032, 0.12389680317470006, 0.1922796709196908, 0.07646086106875113, 0.1888242991907256, 0.06845567455249173, 0.2079228615122182, 0.1122715509097491, 0.11558952608278819, 0.15603758208453655, 0.1644597758672067, 0.0883919969201088, 0.08204269369265862, 0.10194561178130762, 0.14322931079992227, 0.08566373653177704, 0.10583635871963841, 0.12470503337681293, 0.20176701540393488, 0.13831622871969426, 0.14414544164070062, 0.08405731166047709, 0.24682742676564626, 0.08144271945846931, 0.17971407089914593, 0.1827688491238015, 0.13359329929309233, 0.15590570201831205, 0.18328781984746456, 0.1462787150272301, 0.13972439244389534, 0.14321006754679338, 0.07852940899985177, 0.163713916604008, 0.23417985971484864, 0.105089345946908, 0.25255198244537624, 0.12645900568791799, 0.13078959259603704, 0.16050851717591286, 0.12690477605376924, 0.13078541282032216, 0.12689548012401375, 0.14903018809854984, 0.19731731845864228, 0.10379533895424434, 0.21832648611494473, 0.06901248038879462, 0.09941610108528819, 0.2058938518166542, 0.10754489632589476, 0.2122849595866033, 1.4456722715071268, 11.60267870766776, 31.404850142342703, 42.35068784441267, 50.30110502243042, 36.180055209568565, 30.56861707142421, 25.596922159194946, 28.284172705241613, 30.397020884922572, 34.029288973127095, 23.963306869779313, 15.548317500523158, 6.500977788652692, 2.386371833937509, 0.9946739290441785, 1.0520446619817188, 0.9091192398752485, 2.620476620537894, 3.0202234217098782, 5.030790209770203, 6.393325439521244, 8.894952688898359, 7.310323936598642, 10.018245373453412, 10.001831991331917, 8.272198677062988, 8.514149716922216, 11.598097239221845, 18.71676206588745, 14.006193484578814, 7.8317045995167325, 7.014004111289978, 3.003178187779018, 0.6050861541713987, 1.4145834254367011, 0.46905187943152016, 1.6677599315132414, 1.7419434594256538, 3.204644028629575, 4.221978638853345, 6.31197679894311, 8.039879577500479, 9.084078311920166, 5.629208590303149, 3.8398624573435103, 2.661852708884648, 0.4023526470576014, 1.1433878519705363, 2.401692394699369, 3.415316015481949, 5.025071408067431, 8.177096077374049, 7.96082557950701, 8.231334584099905, 8.88032238824027, 8.34928286075592, 9.566707134246826, 9.325166038104467, 11.799137285777501, 6.332059698445456, 4.541162380150386, 5.94740047625133, 6.328745407717569, 2.171946734189987, 1.1712306950773512, 2.256993987730571, 3.5954059404986243, 10.307124546595983, 17.6995301587241, 50.51368515832083, 31.655429976327078, 21.61949188368661, 26.178667034421647, 30.294076374598912, 39.01310675484793, 35.94679723467146, 20.460766860416957, 8.4919867004667, 1.1043561292546136, 0.11595958551125866, 0.1529998622302498, 0.10220935834305626, 0.1199392748198339, 0.1847523291196142, 0.10739407834729978, 0.10629444449607815, 0.14571155474654265, 0.14278831732060226, 0.11695551207023007, 0.10176020208746195, 0.07507530613137142, 0.13626196395073617, 0.10376145291541304, 0.13130100443959236, 0.10685225456420865, 0.09516671446285077, 0.09370817629886524, 0.19549087860754558, 0.16632208307938917, 0.07406174444726535, 0.08038162639630692, 0.27960302946822985, 0.10531771369278431, 0.12301102999065604, 0.1537389090018613, 0.161131263045328, 0.0740337073802948, 0.1319716548813241, 0.27995315353785244, 0.08388922496565751, 0.14648524751620634, 0.13815217252288545, 0.16498602048626967, 0.1322379663054432, 0.124899080821446, 0.22885889666421072, 0.19672844505735806, 0.18571268687290804, 0.14658385222511633, 0.18230861239135265, 0.10653142285134111, 0.16407112457922526, 0.14405017532408237], [0.07621905832950558, 0.06228866654315165, 0.024876467817063843, 0.03529143752530217, 0.021972075004928877, 0.0607119615056685, 0.05342236480542591, 0.05058414442464709, 0.014972801386777843, 0.04333760755668793, 0.025044732627325823, 0.02260457311889955, 0.03200857314680304, 0.01485021216129618, 0.07419101893901825, 0.04713068277175937, 0.059671943741185327, 0.02585780417679676, 0.02199974735932691, 0.042820387453372986, 0.0253039940726012, 0.03678740028824125, 0.025518514615084444, 0.04250749120754855, 0.01795690510022853, 0.1019518543034792, 0.08518859917031867, 0.02924694919160434, 0.01237415730221463, 0.044771589538348575, 0.011527292164308684, 0.01814692374318838, 0.039811305169548304, 0.01709297565477235, 0.04172456018360598, 0.054326600927327356, 0.05201039110709514, 0.0689069681933948, 0.06186720130166837, 0.01761869610553341, 0.04790927795693278, 0.040486053962792666, 0.06183896067419222, 0.023473912184791904, 0.044935601630381176, 0.035273347781705, 0.031169846188277006, 0.03481196093239954, 0.03357078467628785, 0.027243050380742977, 0.05343294995171683, 0.04941041115671396, 0.05603516906765955, 0.49695975333452225, 7.086079512323652, 18.84121298789978, 34.0857743535723, 39.0445681980678, 33.39455018724714, 24.24017173903329, 16.202118669237407, 15.337224279131208, 19.740869215556554, 18.207882949284144, 13.776570286069598, 12.207649673734393, 8.496450049536568, 2.9119413920811246, 0.914726978966168, 0.20518893535648072, 0.34187655789511545, 0.20259207327451023, 1.1125732426132475, 0.9374155615057264, 0.9676001646689006, 1.0377275730882372, 1.8786806421620506, 1.537553186927523, 1.930653384753636, 3.7770911284855435, 3.9809569205556596, 13.128237349646431, 19.483756337847026, 2.3640444491590773, 2.578520791871207, 6.152953812054225, 5.029749282768794, 2.234785156590598, 0.4309002437761852, 0.8740892995681081, 0.45245382721935, 0.13515626399644784, 0.15410687854247435, 0.5162207569394792, 1.1511642975466592, 0.8799556419253349, 0.14368103870323726, 0.3920325365449701, 0.3599783794156143, 2.154727578163147, 2.349163579089301, 4.322998932429722, 1.2814464952264513, 1.8574061266013553, 3.844098687171936, 3.1413600529943193, 2.3554475733212064, 6.8335511428969244, 2.13257172703743, 2.563444286584854, 3.3200041013104573, 2.257775660072054, 1.678863478558404, 2.425600494657244, 0.7103617308395249, 1.3122505737202508, 0.7254565294299806, 2.4339789365019118, 4.57969057559967, 9.010263255664281, 12.148188727242605, 31.368507589612687, 55.86320052828108, 16.36224511691502, 16.40804590497698, 23.401642288480485, 31.583891323634557, 29.483701024736675, 15.591391120638166, 4.456868137632098, 0.3767610474356583, 0.08569672690438372, 0.13474596744137152, 0.026105040285204138, 0.04723491932132414, 0.06593385844358376, 0.026412453968077898, 0.052963135697479756, 0.018826259433158805, 0.04955707310831972, 0.008159007860480674, 0.034663239627012184, 0.0588244263614927, 0.04386948062373059, 0.058225056023469994, 0.025927567754739096, 0.018169825996405313, 0.034328491160912175, 0.035855775100312064, 0.029483489891780273, 0.030582265396203314, 0.013092408671842089, 0.048004110011139085, 0.05893749065165009, 0.021325554964797835, 0.06268495135009289, 0.031385840848088264, 0.04248092316889337, 0.01380623344864164, 0.031777915345238786, 0.04930882428639701, 0.01363262941595167, 0.03441619181207248, 0.011245848561104919, 0.022459648216941526, 0.011606571347718793, 0.014835978192942483, 0.031538436588432105, 0.02274569822475314, 0.0628931869619659, 0.02605639780605478, 0.02403603434296591, 0.01971927428218935, 0.028249696096671478, 0.014156828251933413, 0.05253717516149793, 0.0314427529727774, 0.022194802428462675, 0.020975980508540357, 0.0051577507817585555, 0.05198248974712832, 0.09959613678178617, 0.01938719754772527, 0.05984995061797755, 0.03845559898763895, 0.023329116204487424, 0.018144757520141344, 0.010327880586763578, 0.052750560854162486, 0.12747805672032492, 0.026734724175184965, 0.04505576678950872, 0.05233121942728758, 0.027999800130990998, 0.04868296733392136, 0.03695914428681135, 0.02377682039514184, 0.039453679895294566, 0.02244155338433172, 0.029486231173255613, 0.052083920554390976, 0.029414058795997074, 0.022025798015030365, 0.052001397125422955, 0.05677980018247451, 0.025193793200222508, 0.03730504108326776, 0.009824334660411944, 0.006668138351025326, 0.04396824139569487, 0.03783259866759181, 0.01849330060317048, 0.05364380470876183, 0.01914144743100873, 0.04754308278539351, 0.07341502593564135, 0.010687493120453187, 0.025072175976155058, 0.03900090026270066, 0.04213289237980332, 0.04400724019589169, 0.04287458883066263, 0.032763633344854624, 0.052630158207778416, 0.030456139306936945, 0.0050215179133894184, 0.04225013983835067, 0.029824307853622094, 0.08039924116539103, 1.3344440971102034, 10.452887330736433, 23.508774825504847, 39.93265914916992, 42.27247544697353, 37.48698704583304, 24.683544976370676, 14.917989083698817, 15.165867805480957, 22.864958218165807, 26.823968819209508, 24.638320888791764, 15.941613333565847, 10.803902506828308, 3.3791732234614233, 0.4898859443409102, 0.19610438283000672, 0.12902135747884, 0.1700597796589136, 0.1784967247928892, 0.31145967862435747, 0.8309837611658233, 1.2842690923384257, 1.3489322853939874, 2.447147075619016, 2.8685807245118276, 3.668992357594626, 5.7312711136681695, 16.040331602096558, 10.385239669254847, 4.776362376553672, 3.274063046489443, 6.284800222941807, 6.094753963606698, 4.252301011766706, 1.8239918053150177, 2.6148542250905717, 1.6138978217329298, 0.44959762905325207, 0.6570160133498055, 0.7869527552809034, 2.194104105234146, 1.0918337383440562, 0.3513505623808929, 1.1698005603892463, 0.7754810622760228, 4.22763968365533, 3.8633734243256703, 7.144010118075779, 3.136599451303482, 4.717238851955958, 7.3984852858952115, 5.846633791923523, 5.177719857011523, 4.522239829812731, 3.342384466103145, 2.9074717462062836, 3.0600389880793433, 2.1860976091453006, 1.324880878840174, 0.8325385291661535, 0.4618414949093546, 0.20164037362805434, 0.4374784236507756, 3.3071872804846083, 7.513497080121722, 13.785236426762172, 16.29932049342564, 26.371262414114817, 59.8350305557251, 20.11944702693394, 16.62298842838832, 23.568397317613872, 34.39418057032994, 33.84385544913155, 19.707660300391062, 6.582370289734431, 0.8705439269542694, 0.13499224851174013, 0.1167657801083156, 0.011742352142131754, 0.027576243305312734, 0.0815735613661153, 0.058119340267564566, 0.030134391571794237, 0.05322847342384713, 0.09047222243888037, 0.013089925233673836, 0.016520517711926783, 0.08656896331480571, 0.021065655696604933, 0.03829578024202159, 0.03662632964551449, 0.040748467203229666, 0.019198435890887464, 0.0309670286785279, 0.08918538756136384, 0.019198200099968483, 0.009470123265470778, 0.02016518374771944, 0.019550288528470055, 0.023364456004596183, 0.05615948007575103, 0.045878928154706955, 0.026282875831904154, 0.013370530846129571, 0.0333955530077219, 0.07785774075559207, 0.040278737765869925, 0.06430364413452999, 0.02796286916626351, 0.02249400583761079, 0.025180816217990856, 0.01223384728655219, 0.04820021341687866, 0.030227398366800377, 0.02995284613487976, 0.027315226150676608, 0.041801380525742254, 0.00488386648274692, 0.026935696069683348, 0.013469550309569707, 0.04691753795902644, 0.17478793380515917, 0.1194679643958807, 0.0946339423369084, 0.087085613448705, 0.11911633397851672, 0.20474437278296265, 0.13504370860755444, 0.15403553737061365, 0.16954272240400314, 0.1232180374541453, 0.11234388274273702, 0.08607714756258897, 0.1659067246530737, 0.21827043912240437, 0.11441604048013687, 0.11882122552820615, 0.12819126487842628, 0.11040220050407307, 0.08088781352021865, 0.09160184075257607, 0.09892929292150907, 0.075807587908847, 0.1226871380848544, 0.15032199663775309, 0.1326952310545104, 0.23329016459839685, 0.14892971063298838, 0.16568552223699434, 0.20193712413311005, 0.16751159567918095, 0.1300289955522333, 0.12676331507308142, 0.10381426329591445, 0.1910314243286848, 0.09791365492024592, 0.1712938312973295, 0.16493328474462032, 0.11624049900897912, 0.19298947283199855, 0.13464125591729367, 0.16459077383790696, 0.10160937053816659, 0.11094610738967146, 0.21455761763666356, 0.10086830851754972, 0.08884837957365171, 0.10326062621814863, 0.18084959925285407, 0.12515484781137534, 0.07833610115838902, 0.1237879932991096, 0.1073668555223516, 0.20632974271263393, 1.1294862436396735, 10.197199702262878, 26.808007069996425, 45.179080622536794, 50.202899183545796, 45.24445622307913, 33.88315098626273, 25.680792127336773, 23.112527745110647, 28.729781525475637, 25.73850907598223, 21.106449059077672, 18.408684151513235, 11.618158425603594, 4.09786948135921, 1.4885272404977252, 0.5065323625292096, 0.7377501183322498, 0.6463707217148372, 2.3115803386483873, 3.614387333393097, 4.072911552020481, 5.203964940139225, 5.580586399350848, 6.6697200025830945, 7.69896273953574, 8.132995860917227, 11.381190981183734, 22.425514187131608, 30.582447460719518, 6.008363970688411, 5.45644119807652, 11.597123622894287, 9.604358553886414, 5.04546263388225, 1.673559506024633, 3.048899071557181, 1.6101532855204173, 0.6100760464157376, 0.7119645391191755, 0.8583331193242754, 1.753744540469987, 1.8210131994315555, 0.8615709255848611, 1.0524529772145408, 0.7444954078112329, 5.351073503494263, 6.881422928401402, 11.44383680820465, 4.849948576518467, 6.499265926224845, 11.45422089099884, 7.1392145582607816, 8.326319932937622, 14.086032629013062, 8.440181800297328, 7.99004362310682, 7.013469534260886, 6.425627614770617, 5.291551760264805, 5.671046733856201, 1.50245620736054, 2.373915885175977, 1.1378176765782493, 3.5188886863844733, 6.731628886290959, 11.980501770973206, 15.732807806559972, 36.48678691046578, 63.15378202710833, 22.48084442956107, 23.972098078046525, 31.76505865369524, 41.9906565121242, 40.2190499986921, 24.10797357559204, 8.037824647767202, 0.886942164174148, 0.22548329351203783, 0.25733101314732004, 0.14893158338963985, 0.18395738463316644, 0.22281352962766374, 0.13489614081169876, 0.1741629351994821, 0.10178354369210345, 0.1412879406873669, 0.17685104667076043, 0.11163881021950926, 0.15523461731416838, 0.14097520389727183, 0.1303054035774299, 0.08752949748720441, 0.09584709509674992, 0.07512749904500586, 0.11652240316782679, 0.1814852101462228, 0.1023506632606898, 0.08204797269510371, 0.07623222869421754, 0.09637799446604081, 0.1770656265850578, 0.17859176040760108, 0.09485253917851619, 0.1701324371887105, 0.1298760673297303, 0.11327148761068072, 0.1808506849088839, 0.11218688331012215, 0.12163449956902436, 0.2300858236849308, 0.12818028618182453, 0.13568971465740884, 0.15757744945585728, 0.10059314899678741, 0.12320681448493685, 0.22679924432720455, 0.0794644777530006, 0.0670336347871593, 0.11784332085933004, 0.13190975891692297, 0.10898824887616293, 0.1121255641004869], [0.01887863385491073, 0.0074993522305573735, 0.02821811198789094, 0.09245044378829853, 0.020927129379872764, 0.03730816573702863, 0.0916690496461732, 0.040863305862460814, 0.033785334056509395, 0.05196096322366169, 0.022631102141791155, 0.05500742939433881, 0.04486581091103809, 0.052116055972874165, 0.00834459058075611, 0.04483976195167218, 0.03259590288091983, 0.022428092945899283, 0.012004783194112991, 0.024894942629284093, 0.027651709970086813, 0.013165949993500752, 0.06730124899851424, 0.04267035996807473, 0.0683243033875312, 0.033894221963627, 0.06399518211505242, 0.013859394122846425, 0.02649505203589797, 0.010993099355671023, 0.04449456404628498, 0.03432984483827438, 0.012602025476683463, 0.045969733103577576, 0.025202887265809944, 0.03896599981401648, 0.02537790689218257, 0.052020273969641755, 0.05902807507663965, 0.051428981591016054, 0.04419151673625622, 0.04068526505891766, 0.016828346997499466, 0.059568711423448155, 0.04896761955959456, 0.05355297261849046, 0.0448757989465126, 0.04047816599320088, 0.04672891879454255, 0.01644897128322295, 0.04683864129973309, 0.05983251905334847, 0.018489227696721042, 0.023659654360796725, 0.6890342895473752, 5.499557375907898, 15.000255755015782, 31.232545239584788, 36.53232887813023, 33.12810066768101, 27.875264269965037, 18.280776500701904, 20.185354164668492, 13.563840763909475, 16.47247655051095, 28.1553270476205, 16.948407309395925, 12.353038123675756, 7.882700034550258, 2.9581314963953833, 0.7485325826065881, 0.16831304053110735, 0.2712617442011833, 0.15152828262320586, 0.44218189269304276, 0.3813537524214813, 1.2250430818114961, 1.1558392409767424, 1.5538019835948944, 4.429975134985788, 4.039616218635014, 16.89167353085109, 9.094167964799063, 2.956852376461029, 2.393350430897304, 6.885278744356973, 8.183304292815071, 5.574193622384753, 1.9115289023944309, 2.261348988328661, 1.5181056133338382, 1.1235075358833586, 0.9631629799093518, 0.2677597706871373, 2.026191766772951, 1.0190273651054926, 0.6439184961574418, 1.0557361096143723, 0.616857216826507, 2.1680472748620168, 2.3414041783128465, 4.50554895401001, 1.7108979310308183, 2.992454946041107, 6.60700078521456, 8.916635411126272, 4.696197535310473, 1.9687319014753615, 2.2660036299909865, 2.367430393184934, 2.6812401371342793, 0.8678416205304009, 1.2672704330512454, 0.7644187701599938, 0.6632477875266756, 1.277400255203247, 3.989164480141231, 6.10480409860611, 9.831795675413948, 10.880237153598241, 16.437633071626934, 45.32151869365147, 42.96797970363072, 18.60452433994838, 22.681857551847184, 36.46243347440447, 29.619625159672328, 18.210778611046926, 5.707064458302089, 0.5366997037615094, 0.04030277826158064, 0.08029938795204673, 0.04983551673857229, 0.019395417999476194, 0.02689955390191504, 0.037454712337681224, 0.05662846990994044, 0.015053073775821497, 0.02625088969112507, 0.07951418044311659, 0.07098689515675817, 0.040859346610627005, 0.04176534692357693, 0.024394726613536477, 0.043412877446306605, 0.06537195002394063, 0.04468790581449866, 0.027531923094232167, 0.026285255793482065, 0.03564939867439015, 0.02837857703811356, 0.030950173868664672, 0.0517108009329864, 0.01348932197184435, 0.02375065438848521, 0.0204865548959268, 0.011122751282528043, 0.0394421651560281, 0.03167542941602213, 0.039881424978375435, 0.027267092572791234, 0.005150135074343, 0.05365761289639132, 0.023662502511537502, 0.012049743772617407, 0.046139136156333346, 0.06777331938168832, 0.03800689735050712, 0.017973770088117038, 0.027183359655152475, 0.04285820220996227, 0.03202111247394766, 0.022473373284031237, 0.01550731056236795, 0.01328040867312146, 0.06793083450091736, 0.008650986461101897, 0.04820060696718948, 0.0031633660920696066, 0.05067585861044271, 0.02861486668033259, 0.020909166861591593, 0.0914820453950337, 0.022429841869909848, 0.01691379491239786, 0.04380852443033031, 0.015838805453053544, 0.032130723020860126, 0.03687095169776252, 0.014161264174617827, 0.0329317743224757, 0.0619556958388005, 0.010332706667083715, 0.03192564259682383, 0.09935933484562806, 0.02444502471813134, 0.01873757829889655, 0.03662067744880915, 0.030699173587241342, 0.02999040644083704, 0.027472337541569556, 0.0061155589397198385, 0.029635057651570866, 0.05666692588212235, 0.03488989067929132, 0.008632941670449716, 0.025528614608837024, 0.07929153953279768, 0.03363966955138104, 0.0181085084831076, 0.03601784997486642, 0.022782128769904375, 0.08237986452877522, 0.035665595305285284, 0.06475624056266886, 0.057472004289073605, 0.06799916297729526, 0.04314696296517338, 0.051837368070014885, 0.04739615959780557, 0.043722669394420724, 0.013980786582188947, 0.05487707263923117, 0.07936819363385439, 0.022887437404798608, 0.014398653891735842, 0.055477491313857694, 0.0326053073762783, 0.03658547505204167, 0.03326229551540954, 1.1464220434427261, 8.533334561756678, 20.582391602652415, 35.63451739719936, 39.06647934232439, 35.449066502707346, 29.92294876916068, 19.5099093573434, 16.695522410529, 15.229379551751272, 18.348580496651785, 31.73492431640625, 20.797987256731304, 13.599978344781057, 9.117434876305715, 1.9839471536023277, 0.6941072344779968, 0.11137395764568023, 0.19157134821372374, 0.2293990919632571, 0.2650230218257223, 0.3787873972739492, 0.32454112810747965, 0.10456576118511812, 1.7353270373174121, 0.870923960847514, 4.169313899108341, 8.004369071551732, 3.9283143281936646, 5.151784402983529, 3.0781740035329546, 5.726822963782719, 5.505244476454599, 3.943406249795641, 4.441307212625231, 3.039348555462701, 2.7139778775828223, 1.663780893598284, 2.4548623987606595, 1.4289152792521884, 1.3428809472492762, 2.254080738340105, 1.3465544815574373, 1.7416172197886874, 3.281851325716291, 5.646731078624725, 5.001223453453608, 7.583514945847647, 5.047546659197126, 4.85705006974084, 4.557768140520368, 4.101757866995675, 3.4615816814558844, 4.384523493903024, 2.7419519765036444, 0.5940879157611302, 1.266572030527251, 0.668976468699319, 0.00718998012598604, 0.2326337226799556, 0.2908128079559122, 1.7917094975709915, 5.482439620154245, 8.842736107962471, 13.274629814284188, 12.424930265971593, 14.180550711495535, 41.372065339769634, 53.05166755403791, 19.55279885019575, 21.04418625150408, 38.99720927647182, 32.81962149483817, 22.220733404159546, 7.500138299805777, 0.9662942290306091, 0.008814250468276441, 0.05123185020472322, 0.04961237710501466, 0.02187501565952386, 0.05576159392616578, 0.008953831058793833, 0.05709185504487582, 0.006948135826470596, 0.04324934032878705, 0.05061522811385138, 0.057373168878257275, 0.018267019352476512, 0.06083275430968829, 0.016757460444101265, 0.03237530096833195, 0.052396952507219145, 0.06689946805792195, 0.04537341617313879, 0.024113463670281426, 0.0024587774491270204, 0.03409003020663347, 0.045900139159389904, 0.023521538557750837, 0.03885285409965685, 0.07759265747985669, 0.04275334819353052, 0.03689907018893531, 0.04586039736334767, 0.03949463626902018, 0.030763356214655296, 0.03171847228493009, 0.018041014604802643, 0.035281059332191944, 0.08388679581029074, 0.06112685174282108, 0.011155877362138458, 0.018309887498617172, 0.008947211101518145, 0.0424202621382262, 0.014423488273418375, 0.050082001369446516, 0.06876739354005881, 0.08785159127520663, 0.045241017027625015, 0.0028170127687709673, 0.047837499129985056, 0.15351659378835134, 0.1500390339642763, 0.14478539515818867, 0.17376428230532578, 0.11256329382636718, 0.19456845096179418, 0.19641060568392277, 0.14716836943158082, 0.1554638942969697, 0.21054911773119653, 0.12984907520668848, 0.16033967052187237, 0.12969252360718592, 0.1406350000096219, 0.10814606478171689, 0.24404410326055118, 0.11429646903915064, 0.06717259197362832, 0.13535364983337267, 0.12625659869185515, 0.1057327464222908, 0.13301670737564564, 0.3114356856260981, 0.17197964021137782, 0.15950782730111054, 0.1385399145739419, 0.18804512385811123, 0.08102086066667523, 0.17876345690871986, 0.12351953770433154, 0.11325752335999693, 0.21682129188307694, 0.07721655908972025, 0.08842974382319621, 0.09407696008150067, 0.1352631604032857, 0.13377355890614645, 0.06970583461225033, 0.14883463430617536, 0.1335391386279038, 0.13384411297738552, 0.14331686895872864, 0.09841009149593966, 0.1064947344628828, 0.2092069076108081, 0.10969739260950259, 0.13250940745430334, 0.13531871885061264, 0.12605257678244794, 0.15848819272858755, 0.16926695220172405, 0.1519632235701595, 0.2597293087414333, 0.15828949053372654, 1.19318211717265, 8.413096853664943, 23.635869537081035, 42.77087320600237, 48.98689842224121, 43.947213649749756, 38.69441373007638, 28.60777463231768, 27.217735392706736, 21.157966477530344, 22.34850035394941, 37.799548285348074, 24.110688584191458, 15.959932259150914, 10.472839951515198, 4.110388832432883, 1.293432029230254, 0.4972004975591387, 0.5084212954555238, 0.5700952974813325, 1.2595161348581314, 1.254769972392491, 2.9253885447978973, 5.236642752374921, 5.850653324808393, 9.336428199495588, 8.904618501663208, 26.801727635519846, 18.195110423224314, 11.001526645251683, 8.195919615881783, 13.195660063198634, 17.758815663201467, 12.535318902560643, 7.959836329732623, 6.360620703016009, 4.509089061192103, 2.095009982585907, 1.9995211064815521, 1.4518774471112659, 4.08199371610369, 2.864201622349875, 1.0861694365739822, 3.374887704849243, 4.083613949162619, 6.48993536404201, 9.265348996434893, 11.821102278573171, 9.210623247282845, 7.194865720612662, 12.700990012713842, 16.26374397959028, 10.803079145295278, 7.0896439382008145, 6.967668746198926, 4.5407450539725165, 7.807292972292219, 2.9948976721082414, 2.405954246010099, 1.4649483114480972, 1.32027248612472, 2.0842787069933753, 6.13399521793638, 9.388918365750994, 14.183005162647792, 15.160542011260986, 22.143177611487253, 51.52416515350342, 51.29276234763009, 24.967253821236746, 30.213181972503662, 45.918681621551514, 40.276157242911204, 23.871750456946238, 8.301208274705068, 1.008939449276243, 0.09277631701635462, 0.20085650283311093, 0.12127474030213696, 0.10580390438969646, 0.11830684170126915, 0.059628218944583616, 0.23232680772032055, 0.1905069981834718, 0.10908106568136386, 0.17203701713255473, 0.15718079145465577, 0.12029404006898403, 0.1326127347669431, 0.08733283768274955, 0.1119100342371634, 0.1280630353306021, 0.13485363737813064, 0.11884728127292224, 0.08642714949590818, 0.16988611540624074, 0.12214063241013459, 0.11019633976476532, 0.16906739505273954, 0.12202074884303979, 0.21643272201929772, 0.12052783609500953, 0.10041406324931554, 0.12359252093093735, 0.1419268085488251, 0.13554919005504676, 0.1764229724981955, 0.14539077053112642, 0.2035085026706968, 0.11748905772609369, 0.2013067922421864, 0.08831541745790414, 0.15194355962531908, 0.12480956848178591, 0.1713125588638442, 0.12988878307597979, 0.1538076853113515, 0.13577767993722642, 0.1270822672439473, 0.17387264434780392, 0.09509464047316994, 0.17046430866633142], [0.058239963437829695, 0.026649483213467256, 0.04097489094627755, 0.05257624520787171, 0.03652470206309642, 0.06365740059741906, 0.027516404998355677, 0.05706938875040837, 0.015808588592335582, 0.01902022714992719, 0.026183056545310786, 0.0533666469023696, 0.03790372610092163, 0.010648568110939647, 0.05745977708803756, 0.0620776353670018, 0.011318013304844499, 0.06681701248245579, 0.05314069813383477, 0.08035033914659705, 0.02407837492812957, 0.014685574120708873, 0.059892610114599974, 0.10329017641821078, 0.006754799147269556, 0.025649283580215912, 0.021570305938699415, 0.04194299756948437, 0.04923906749380486, 0.015622654730187995, 0.02398925953145538, 0.047413394387279234, 0.05622438195028475, 0.03963944921270013, 0.010056369039895279, 0.0665921527626259, 0.02412180625833571, 0.020827717214290584, 0.03008734873895134, 0.03539553836786321, 0.0237820111880345, 0.03288904357967632, 0.0503689673995333, 0.017749575332605412, 0.01314805872139654, 0.11736819706857204, 0.04624708768512521, 0.08370635977813176, 0.05085681711456605, 0.03390410143349852, 0.02225781458296946, 0.01350785106686609, 0.05810443963855505, 0.023438166960009506, 0.05147538999361651, 0.558762677013874, 4.213445816721235, 15.644991261618477, 27.445988927568706, 36.79740612847464, 33.58664355959211, 35.312659467969624, 29.593920298985072, 26.30761865207127, 25.126214708600724, 15.870767763682775, 26.650091886520386, 22.108841351100377, 15.682139805385045, 10.555942143712725, 6.009684996945517, 3.585369267633983, 1.3508440170969283, 0.9642787086112159, 0.2028923657323633, 0.5648777431675366, 0.17435850256255694, 0.34405815654567307, 1.1852758271353585, 0.2850468344986439, 3.537489014012473, 8.597406506538391, 2.844499788114003, 5.42897366625922, 2.9903822115489413, 4.285859942436218, 2.820771038532257, 1.921147597687585, 3.850028540406908, 2.533484522785459, 2.4502314243997847, 1.1118498700005668, 2.6447136742728095, 0.7097432325993265, 0.38568014598318506, 1.7729686860527312, 1.6049554901463645, 1.6877644466502326, 2.908091655799321, 3.4860356492655615, 3.052816769906453, 6.371990127222879, 3.015211816344942, 4.34804197720119, 4.329670940126691, 2.961332444633756, 2.471576290471213, 2.665731106485639, 2.149563546691622, 1.0057805159262247, 1.1615143993071146, 0.897723379944052, 0.48265075257846285, 1.7335209399461746, 3.55300412433488, 6.277747801371983, 8.43488814149584, 14.666019609996251, 14.582821880068098, 21.589913402284893, 19.851453270230973, 39.63687433515276, 37.363097190856934, 24.80142637661525, 37.11842679977417, 30.414971555982316, 18.662665128707886, 4.643742544310434, 0.4367915019392967, 0.015378812993211406, 0.04081013246572443, 0.04594663577154279, 0.03653303108045033, 0.03614784371373909, 0.05015885903100882, 0.06890908522265297, 0.0548468337261251, 0.054685277930860005, 0.015056062722578645, 0.014256249747372099, 0.057518151455691884, 0.029244933942598954, 0.14273214819175856, 0.06373093343738999, 0.02072057992752109, 0.022092453902587295, 0.03973738895729184, 0.02893653299127306, 0.017116122180595994, 0.06313338835856744, 0.01950722360717399, 0.027674255992418954, 0.021397659488554512, 0.029889179194079976, 0.017092188554150716, 0.04648685821198991, 0.049035778402217796, 0.00959286346499409, 0.018468696923394288, 0.02823395069156374, 0.13924389465578965, 0.07658311272306101, 0.03903420954676611, 0.029577243075306927, 0.040335829702339, 0.04187642649880477, 0.0273190717478948, 0.02793007217613714, 0.05706069671681949, 0.014857182412275245, 0.0327822218116905, 0.03931208320760301, 0.0790505510355745, 0.012453535721371216, 0.027200117773775543, 0.06152306191091027, 0.09317765012383461, 0.05575093074834772, 0.0415589772830052, 0.024548423276948075, 0.02707768970036081, 0.05047031678259373, 0.03368413055847798, 0.0237858754449657, 0.011158182684864317, 0.02193412114866078, 0.006456977829137551, 0.01568972791678139, 0.07387718970754317, 0.03504623871828828, 0.06874589076531784, 0.08594726917466947, 0.010065215440200908, 0.05452816653996706, 0.04165398914899145, 0.09574557268725974, 0.024376645351627042, 0.02982774463349155, 0.04313899017870426, 0.01249414773857487, 0.010039361559652855, 0.06154476824615683, 0.006973809895238706, 0.026570450847170184, 0.07370524214846746, 0.062043091149202416, 0.02038143285816269, 0.019856368890032172, 0.03221162135845848, 0.031198992660003047, 0.029553121155393974, 0.061799178166048865, 0.06535628943571023, 0.03303677761661155, 0.024231688219255636, 0.046923858512725146, 0.02462700441745775, 0.05812093482485839, 0.03437709462429796, 0.07930885574647359, 0.028707283149872507, 0.02845781296491623, 0.0389305972494185, 0.04090355316709195, 0.07798367006970303, 0.05744707491248846, 0.021140618549127663, 0.011208833627668875, 0.036388920420514684, 0.060865296849182675, 0.10330306179821491, 0.7992999755910465, 6.140850918633597, 19.948863540376934, 33.662260804857524, 40.83383355821882, 37.708297593253, 37.75044536590576, 31.10284321648734, 19.7244645186833, 14.512131776128497, 23.23892068862915, 30.511068616594585, 24.1775233064379, 22.32224484852382, 13.964328851018633, 5.703486570290156, 4.237044070448194, 1.188231417110988, 0.5749331978814942, 0.1851689089089632, 0.11397748972688403, 0.09087750462016889, 0.2403289611850466, 0.3519496002367565, 0.2298793319080557, 0.8860882414238793, 1.2662409054381507, 1.7011177986860275, 2.7110724449157715, 2.3404881017548695, 1.819394269159862, 2.4417628731046404, 2.4273201738085066, 3.5531882515975406, 3.0742869206837247, 3.6691526004246304, 2.0500894444329396, 4.32198840379715, 2.429069382803781, 2.337165342909949, 1.4029413930007388, 3.0472888265337263, 3.5497947079794745, 4.3788628833634515, 6.553145732198443, 3.457444897719792, 5.70876806974411, 3.0238362678459714, 4.423024765082768, 3.8953772612980435, 2.0318198076316287, 1.7580405899456568, 0.9876251987048558, 0.560639884855066, 0.5331592708826065, 0.11404222196766309, 0.2885924513850893, 0.6980827440108571, 2.152950576373509, 3.988388018948691, 6.764880359172821, 12.942925419126238, 18.01404731614249, 17.026915005275182, 18.6738760471344, 17.638365166527883, 41.9153276171003, 40.87322984422956, 23.293408461979457, 37.523221901484895, 35.15898963383266, 23.520426954541886, 6.402511826583317, 0.7967395101274762, 0.05876175008182015, 0.011747665071327771, 0.02251209897388305, 0.05121331602068884, 0.060202368135963163, 0.06103193147906235, 0.04858333125178303, 0.01333214866463095, 0.019978517067751715, 0.019529106361525397, 0.024849820050543973, 0.011000693010698472, 0.0382442692560809, 0.017588867706113627, 0.00720249061539237, 0.040065823655043326, 0.02900987584143877, 0.04486554288970573, 0.04486143096749272, 0.008135553449392319, 0.05016959684767893, 0.021170043220211352, 0.030187069637967006, 0.07247176726481744, 0.02617071568965912, 0.013543905025081975, 0.02996908008520092, 0.03443509240501693, 0.025289447978138924, 0.029701913706958294, 0.008574181386003537, 0.08203986420163087, 0.021619560795703104, 0.037819363842053075, 0.03588671629716243, 0.05972513410129717, 0.02528287297380822, 0.07617333863994905, 0.0454737647170467, 0.04097530485263892, 0.09716069818075214, 0.024700233613007834, 0.07048163762582199, 0.03302860805498702, 0.01876389019058219, 0.025832732307857702, 0.053923639335802624, 0.31293356525046484, 0.13375778975231306, 0.22903314445699963, 0.15901031185473713, 0.12927470888410295, 0.1580194743084056, 0.09289818190570388, 0.15216032442237648, 0.08494462511901345, 0.1246449558862618, 0.09959663889769997, 0.14942562473671778, 0.15749403036066464, 0.18754604778119496, 0.1492500470152923, 0.16796655340918473, 0.07829874102026224, 0.131904629192182, 0.1361644584685564, 0.17060829379728862, 0.0684532318264246, 0.1180300944085632, 0.22087568789720535, 0.11759056656488351, 0.12939581381423132, 0.18250898378235952, 0.04651381980095591, 0.11482903760458742, 0.14223008656076022, 0.21071142330765724, 0.1267699918576649, 0.10041375112320695, 0.17114513713334287, 0.10720783405538116, 0.13019116542169026, 0.1930760946124792, 0.22137716598808765, 0.11212868536157267, 0.12146778351494245, 0.17042308087859834, 0.09782238517488752, 0.15546005378876412, 0.18815485654132708, 0.1284549300159727, 0.1361409133034093, 0.23462329592023576, 0.10284814478031226, 0.2113757362323148, 0.1932654601654836, 0.2051334719040564, 0.07482908612915448, 0.0627486522176436, 0.16297164000570774, 0.13311263865658216, 0.12782275250979833, 1.0181762107781, 6.033306700842721, 21.050024475370133, 36.888229506356375, 48.05430425916399, 45.003058433532715, 46.6294059072222, 41.59302152906145, 34.44459669930594, 32.13021775654384, 26.099004200526647, 35.98614835739136, 29.022663729531423, 22.740439551217214, 16.63591034071786, 8.190189957618713, 5.23267011983054, 1.8101453483104706, 1.4812583391155516, 0.40278891793319155, 1.1633683741092682, 0.8458630027515548, 1.2213214529412133, 2.458229669502803, 2.718095770903996, 6.326615784849439, 14.190644706998553, 5.258002817630768, 10.48272636958531, 7.156428720269885, 8.542559163911001, 9.516224997384207, 8.932183742523193, 9.690517953463964, 8.946122697421483, 10.22451480797359, 6.031315607683999, 7.66901079245976, 4.917350011212485, 3.5646067474569594, 4.932739836829049, 5.285466875348773, 5.7113219669887, 6.6293414149965555, 7.290119443620954, 12.216149926185608, 13.81068159852709, 11.235296181270055, 12.73797527381352, 8.328752670969282, 8.272932580539159, 8.766814879008702, 6.125962231840406, 4.982831571783338, 2.0234507024288177, 2.2586750175271715, 1.5065609642437525, 1.1137412999357497, 2.485137871333531, 4.704902759620121, 9.284798741340637, 12.399085572787694, 20.13812725884574, 21.330818550927297, 28.4639538696834, 26.87820645741054, 47.67586020060948, 43.72456904820034, 31.923616545540945, 46.28152697426932, 40.730548586164204, 26.843057257788523, 7.7825747558048795, 0.863245929990496, 0.08842150640806981, 0.12715793746922696, 0.15827779259000505, 0.1602257037801402, 0.13382161275616714, 0.21540285513869353, 0.09674904455563851, 0.1701907640589135, 0.14017084134476526, 0.15052338583128794, 0.14281281243477548, 0.09157881127404315, 0.11374594643712044, 0.20430960825511388, 0.11624495019870144, 0.17555218136736325, 0.08379633352160454, 0.06411233797137227, 0.14522858709096909, 0.07044753445578472, 0.1227108868105071, 0.1358108195875372, 0.04610307541276727, 0.1152939290872642, 0.08900339768401214, 0.14544882598732198, 0.12163150044424192, 0.12048967528556075, 0.09302798565477133, 0.17201849312654563, 0.19058527398322309, 0.2835090841565813, 0.26956616661378313, 0.11473455838859081, 0.14069893157907895, 0.10241703077086381, 0.09318516829184123, 0.12403181807271071, 0.09529256913810968, 0.1874402913131884, 0.1402442181216819, 0.10015388578176498, 0.11076356789895467, 0.1225105697023017, 0.2213171020682369, 0.10447898334158318, 0.29895017987915445], [0.026575295587203333, 0.07329280142273221, 0.05154158787003585, 0.009570074866392782, 0.08381259800600153, 0.017072943604684303, 0.017897161788174083, 0.02702061303092965, 0.051774026826024055, 0.07745348316218172, 0.05758231372705527, 0.021852296610761966, 0.021982047773365463, 0.03282968194356986, 0.058500826225749085, 0.06999265136463301, 0.03594365556325231, 0.011610221017950347, 0.033423674891569784, 0.11433301493525505, 0.030757734552025795, 0.019082304622445787, 0.02707292468819235, 0.03430296467351062, 0.030542723767991577, 0.03340828911002193, 0.012936573774952973, 0.08421848408345665, 0.04836202705545085, 0.03580017594088401, 0.030649701599031687, 0.017022441939583847, 0.04244342393108776, 0.021268731049661125, 0.10715450120291539, 0.06437378429940768, 0.03498784060190831, 0.0028923526323134346, 0.023850475371416126, 0.07588780431875161, 0.05326797773263284, 0.020465822258431996, 0.03791085411129253, 0.050650820668254576, 0.0449928699859551, 0.07630558511508362, 0.012598754089724804, 0.099474930071405, 0.03883359727582761, 0.03444995232192533, 0.020211086641731005, 0.04699748295492359, 0.015692151983135512, 0.018878001121005843, 0.07355658869658198, 0.07181754415588719, 0.15286860641624245, 2.337747037410736, 11.41235886301313, 22.807597364698136, 35.486604145595, 36.65173019681658, 41.51503842217581, 40.08164242335728, 33.85680341720581, 23.120160341262817, 18.15776559284755, 27.719009705952235, 27.614934376307897, 20.43346217700413, 17.71077581814357, 13.98706683090755, 10.102825794901166, 6.561320287840707, 3.7413925869124274, 1.8769998294966561, 1.2491889404399055, 0.5498881989291736, 0.37245807690279825, 0.06864657359463827, 0.8364593759179115, 0.9313406646251678, 1.44296529676233, 1.5814738358770097, 0.8557834018554006, 2.0073530290807997, 1.5941853480679649, 1.792173398392541, 2.179200653518949, 1.2336091250181198, 1.6665375913892473, 2.05940089906965, 4.359115234443119, 2.2434387036732266, 1.0546368828841617, 1.9589783677033015, 3.0013449490070343, 1.2151627434151513, 5.180405335766928, 11.553030354636055, 1.62338102715356, 7.441455551556178, 1.700914672442845, 3.0260203906467984, 2.591887606041772, 1.1084862904889243, 0.7211280731218201, 1.5998530153717314, 0.8600050838930267, 0.42427825768079075, 1.030787625483104, 2.1872264742851257, 4.033715026719229, 6.801874305520739, 8.018723181315831, 10.236774904387337, 10.00791687624795, 8.502044217927114, 11.407338789531163, 10.724501098905291, 18.437493119921, 37.45419502258301, 28.814242090497697, 29.860505308423722, 26.52294680050441, 16.57188442775181, 5.205394531999316, 0.4325686799628394, 0.0554193544334599, 0.05939013457724026, 0.0220248277099537, 0.0353514132356005, 0.014891402629603232, 0.055632261758936305, 0.050307800860277245, 0.06231925490179232, 0.02416547168312328, 0.11714333056339196, 0.040725118813237975, 0.03822407605392592, 0.022180232585274746, 0.041125481615641286, 0.020983205210151415, 0.011646509070747664, 0.013375930288540465, 0.004938292624761483, 0.0544091650683965, 0.03965774251680289, 0.019413339805656245, 0.04526766649048243, 0.03049784546185817, 0.04385991327996765, 0.02892469594787274, 0.037698642284210236, 0.029838434952710356, 0.024886555936453596, 0.048895861088697395, 0.0366311404587967, 0.055624940366085084, 0.01944249645540757, 0.02967506068359528, 0.05476211862904685, 0.03277815060157861, 0.016454643835978847, 0.03920277800144894, 0.06037975076053824, 0.04045318572648934, 0.05434632254764438, 0.010654061700084379, 0.030344272631087472, 0.04178257492770042, 0.048382562917790244, 0.056114917288401296, 0.06367365829646587, 0.028761891648173332, 0.020311528484203985, 0.0022949776113299386, 0.044700876011380127, 0.038144874053874185, 0.03758832606087838, 0.021647582595635737, 0.07095042389950582, 0.021466753013165932, 0.028471064753830433, 0.012167907253439938, 0.06830904992031199, 0.0801122954913548, 0.057630286152873716, 0.04813198672075357, 0.024140638997778296, 0.02922620637608426, 0.056358280658189736, 0.04047013892393027, 0.01213576759411288, 0.014819165791517921, 0.008031503496957677, 0.03705720956038151, 0.046774760620402436, 0.05240590238411512, 0.0669216832944325, 0.04888311820104718, 0.02821759630127677, 0.0518632134688752, 0.02896975745846118, 0.023385499071862017, 0.004127915283398969, 0.04538736006777201, 0.042746413565639935, 0.014603635928194438, 0.05296884896233678, 0.04216065124741622, 0.031639908107795885, 0.04334644886798092, 0.032130180192845206, 0.03954740593742047, 0.08109858006771122, 0.016885125111522417, 0.016325019898691347, 0.019182405501071895, 0.055980370579553504, 0.055440019217452834, 0.082532385630267, 0.02931714363928352, 0.022706948786175678, 0.017434192255937626, 0.0019665403690721306, 0.05893671712172883, 0.012584836488323552, 0.025525908950450163, 0.005692542821634561, 0.0523581165554268, 0.08306864542620522, 0.41171930730342865, 4.06040392603193, 15.14660392488752, 28.489669152668544, 41.968745367867605, 40.179660660879954, 46.7244086265564, 37.25874219621931, 30.58483416693551, 18.21736376626151, 19.55690697261265, 30.47218302318028, 27.757068463734218, 27.04645013809204, 20.377953018460953, 16.268427065440587, 10.076104760169983, 6.793871283531189, 3.2393696052687506, 2.18346836737224, 0.6487927117518016, 0.39041083785040037, 0.18414007340158733, 0.08371855305241686, 0.3808528035879135, 0.09412506821432284, 0.12582525398050035, 0.22246113925107888, 0.640670756144183, 0.46678367257118225, 0.8375665822199413, 0.48175172082015444, 0.7837096835885728, 1.1533258387020655, 1.293432029230254, 1.6174399916614806, 2.433049180677959, 2.1433334009987965, 1.5305419117212296, 1.236773703779493, 2.0863583896841322, 1.9114379244191306, 2.765299443687711, 5.249354047434671, 1.4924605722938264, 1.0784671413046973, 0.9687059053352901, 1.0882050416299274, 0.8569975452763694, 0.1434349747640746, 0.7268610969185829, 0.3230451483811651, 0.24793846000518116, 0.18895859484161648, 0.8490794758711542, 2.0209745381559645, 4.349980090345655, 7.755660908562796, 12.556705457823616, 15.70830498422895, 14.398157000541687, 11.397084985460554, 12.117229291370936, 14.425148146493093, 19.78083872795105, 42.32479190826416, 32.99945477076939, 32.163148743765696, 31.78930786677769, 20.650249447141373, 6.247363763196128, 0.681735424058778, 0.06696553022733756, 0.13299701628940447, 0.036088570287185054, 0.030284972063132694, 0.043220584014696736, 0.019333186160240854, 0.005527392911192561, 0.057792774933789454, 0.017704637654657875, 0.050038595484303575, 0.08533033835036413, 0.017099028187138692, 0.06354027866785016, 0.09552979855132954, 0.038717679745916805, 0.012797781981394758, 0.05221798211070044, 0.028722183778882027, 0.057964010031095574, 0.019103471522352526, 0.0496661781466433, 0.008924452188823904, 0.09705766942352057, 0.014977213560736604, 0.006874991023713457, 0.02014092103179012, 0.020363424538767765, 0.017248682478176694, 0.0643184497686369, 0.02239421708509326, 0.02809866437954562, 0.022529991942324808, 0.06306401493826083, 0.06051461638084479, 0.07585264941943543, 0.024549664996032203, 0.05240544776565262, 0.047513298490749936, 0.05204617365130356, 0.021595818855400597, 0.0077891095840771285, 0.027307105782840933, 0.05695139151066542, 0.056299916468560696, 0.004823906887655279, 0.1040167585015297, 0.043906474352947304, 0.04969149428818907, 0.10360933214958225, 0.16589752371822084, 0.14430786935346468, 0.07241637845124517, 0.19615960200982435, 0.15521303990057536, 0.09701540347720895, 0.14290455036929675, 0.13318853958376817, 0.30055743934852736, 0.1620799499963011, 0.20344514107065542, 0.08203873104814972, 0.0814872584970934, 0.1763786913028785, 0.10253745038062334, 0.10860981632556234, 0.0939285441168717, 0.18058278571282113, 0.1284725990678583, 0.10655684077313968, 0.15025178183402332, 0.06670084728726319, 0.16220938733645848, 0.17021379353744642, 0.1014978668785521, 0.14310693022395882, 0.24802015562142643, 0.10535919932382447, 0.193465668708086, 0.10794276211942945, 0.10016830465091126, 0.14965521384562763, 0.12613602301904134, 0.14338791157518113, 0.07702074745403868, 0.33858759009412354, 0.20930327315415653, 0.11148402281105518, 0.1939408467816455, 0.11270665470510721, 0.07186868534024272, 0.09060225010450397, 0.09727751476956265, 0.17373222831104482, 0.2806338598685605, 0.1717350554785558, 0.1317587305924722, 0.09660147675978285, 0.08769598283937999, 0.09814776307237999, 0.11753943216587816, 0.06040043250790664, 0.12927023055297987, 0.18479267481182302, 0.21730759793094226, 0.3841102330812386, 3.5093301364353726, 16.225349971226283, 31.06256103515625, 48.33954518181937, 47.667984417506624, 55.64801134381975, 49.7559597832816, 45.04978854315621, 31.422887665884836, 27.66808635847909, 37.11050932747977, 36.34660005569458, 29.782716751098633, 25.659501109804424, 19.017700706209453, 13.278982860701424, 8.803060156958443, 4.881076940468379, 2.8940638942377905, 1.5298333040305545, 1.0590493146862303, 0.7714213601180485, 0.19068982265889645, 1.2460140479462487, 2.709372307573046, 3.3806551439421515, 5.228946319648197, 3.7231118764196123, 4.471343840871539, 7.572166800498962, 6.512158742972782, 6.050796185220991, 7.607159665652683, 7.1339647599628995, 7.4436980826514105, 12.148071476391383, 5.17357873065131, 6.325853654316493, 5.948571681976318, 7.9734765120915005, 7.880558252334595, 11.036214658192225, 22.644028084618704, 5.645955051694598, 12.78659268787929, 5.6229356697627475, 8.862428171294075, 5.926162438733237, 4.560193061828613, 2.6879206129482816, 3.193651109933853, 1.6937096076352256, 0.808764670576368, 1.5548414992434638, 3.261639233146395, 5.802287348679133, 9.901357565607343, 12.90725771018437, 16.007944311414445, 15.832339014325823, 13.390181830951146, 17.2393023286547, 17.73274949618748, 27.043809822627477, 46.60839455468314, 37.70669603347778, 38.857665130070274, 34.95615087236677, 23.20085324559893, 7.366397636277335, 0.9068425648978778, 0.12005577928253583, 0.19695104525557586, 0.07410350827766315, 0.1292488702705928, 0.22035021680806363, 0.13436890553150857, 0.1255856632654156, 0.2232679852417537, 0.16452080330678395, 0.2165530669902052, 0.20321276996816906, 0.12300716234104973, 0.1129930711218289, 0.2214269840291568, 0.08909631626946585, 0.08761412437473025, 0.09758555609732866, 0.14853629602917603, 0.17806289664336614, 0.09477753391755478, 0.1974038045321192, 0.12574256770312786, 0.1541107733334814, 0.1608880760946444, 0.11815707545195307, 0.10813161877116986, 0.14454906141119345, 0.09953679889440536, 0.17531440912612847, 0.12243776289480073, 0.13567876310220786, 0.11185201270771877, 0.15452200626688345, 0.09948700120938675, 0.17396189884415694, 0.1260509482984032, 0.10514563721205507, 0.16936167569032737, 0.1112735141068697, 0.18522308314485209, 0.18880972425852502, 0.1702242429767336, 0.17254479202841008, 0.16986011394432612, 0.12310413856591497, 0.1728434967143195, 0.2488741326544966, 0.10837310938430683], [0.03821650021044271, 0.056595099557723315, 0.02184668173348265, 0.03308639209717512, 0.029658154983605658, 0.05857452869947467, 0.03158581529610923, 0.010339262163532632, 0.02518787467852235, 0.025256657773362737, 0.04732244016070451, 0.006762796954717487, 0.0030061262036075015, 0.0688945102904524, 0.028704589365848472, 0.015264162627447928, 0.03032982662054045, 0.03531701151015503, 0.086582072611366, 0.022554163056026613, 0.08088940807751246, 0.0714544193553073, 0.04730789915525487, 0.06934991585356848, 0.018918185661147748, 0.03291444114542433, 0.042294777264552455, 0.06706559378653765, 0.03815797656508429, 0.06584609672427177, 0.014336174387218696, 0.06026587901370866, 0.037238568400165865, 0.02740285385932241, 0.02950490784964391, 0.06973094719329051, 0.03971476320709501, 0.03316020992185388, 0.04459881077387503, 0.050979441963136196, 0.052207651415041516, 0.024274228972249796, 0.01847673756336527, 0.05591832873012338, 0.02736596021402095, 0.03316889517009258, 0.026856246404349804, 0.040131169970014265, 0.05129094042682222, 0.036273779813200235, 0.06258594630552189, 0.03918193679835115, 0.01808905488412295, 0.05329052545130253, 0.06030706608934062, 0.03631222900003195, 0.0714467451242464, 0.04549217676477773, 1.342741874711854, 5.560827025345393, 16.063267605645315, 34.115255560193745, 38.91941029684884, 46.400754587990896, 43.213313647678916, 44.3746703011649, 38.52334213256836, 19.71897370474679, 19.831454617636545, 20.32147111211504, 26.689024380275182, 32.47056136812483, 20.95555329322815, 17.432797500065394, 11.092052119118826, 10.523732032094683, 7.743265322276524, 5.668023398944309, 3.4512160548142026, 2.114255407026836, 0.8041138829929488, 0.5407616857971463, 0.14729928597807884, 0.2927660388605935, 0.6032423845359257, 0.4431262234491961, 0.11038872479860272, 0.5446626107607568, 0.608643957546779, 0.6152119051132883, 1.474722472684724, 0.3144139658127512, 1.7778432816267014, 1.4398568464176995, 1.3127204456499644, 0.29959340393543243, 2.0320834049156735, 2.082993507385254, 2.1072301268577576, 1.9662872212273734, 0.8779191140617643, 0.8142283431121281, 0.7663330531546048, 1.115481823682785, 1.7473292904240745, 0.3538497968443802, 0.763435382928167, 0.7860591518027442, 1.5089182491813387, 3.3601560039179663, 4.483685578618731, 8.11135048525674, 9.252538255282811, 13.14512060369764, 15.538887057985578, 12.513686554772512, 12.843489749091011, 16.617568833487375, 16.390701464244298, 18.621835776737758, 31.327315194266184, 32.11537293025425, 26.218780721936906, 21.4570186819349, 12.076305270195007, 3.739540457725525, 0.47790448154721943, 0.06297954411378928, 0.09040133588548217, 0.020019388624600003, 0.01538064843043685, 0.06969648439969335, 0.04100059724545904, 0.018747803821627582, 0.048656850521053584, 0.06450955237128905, 0.039445143924759965, 0.062295058343027315, 0.024627167265862226, 0.06511825256581817, 0.00795001398572432, 0.03228908630886248, 0.020959931459011774, 0.06868194562516042, 0.03510450112766453, 0.031036792256470238, 0.06805928117994751, 0.030432000423648527, 0.026310400604935627, 0.10670247474419219, 0.026847484820921506, 0.04219338716939092, 0.0747817854530045, 0.0851264317919101, 0.023303518470908915, 0.02517732515531991, 0.025721354177221656, 0.024175893981009722, 0.05397092304857714, 0.024351729545742273, 0.05685641017875501, 0.034931318634854894, 0.0158732394089124, 0.05527381545730999, 0.04153100806953652, 0.03972368933526533, 0.031470664510769505, 0.029917945686195577, 0.02380185155197978, 0.01345542405865022, 0.02425356418825686, 0.0153720632661134, 0.016479067703975097, 0.031934124284556935, 0.0564331536048225, 0.012316671815434737, 0.00219624864569466, 0.035307308459388356, 0.019349233513431888, 0.036921397383723936, 0.03390966881332653, 0.05269948073795863, 0.0254558824401881, 0.04284129311729755, 0.0637014035933784, 0.038964995582188876, 0.08698738871940545, 0.046816331068319936, 0.02195560187101364, 0.07553140380020652, 0.06332394134785448, 0.019423497474885414, 0.005339477302706135, 0.03144741450835552, 0.03573835461533495, 0.03993870011929955, 0.09486621844449214, 0.05545448897672551, 0.007057605153282306, 0.02615995073158826, 0.04451278949688588, 0.030648436131221906, 0.01664727314242295, 0.02368177629874221, 0.07630952740354197, 0.04693920697484698, 0.022116233162315826, 0.08781985619238444, 0.027913132549396584, 0.012763043532946279, 0.048240762669593096, 0.07490040694496461, 0.05948231355952365, 0.054414040342505486, 0.02392538054846227, 0.028266925797132508, 0.025213363846497874, 0.03190788194271071, 0.016506129376856343, 0.04622261971235275, 0.04436349822208285, 0.04840814368799329, 0.029348346072116067, 0.012723396731806653, 0.025148185468944054, 0.013476618948126478, 0.041186956888330836, 0.015945997022624527, 0.06217579224279948, 0.01924943458288908, 0.15004290161388262, 0.047215771063097885, 0.06848512297230107, 0.17014429798083647, 2.6317023038864136, 8.926666004317147, 23.366882187979563, 38.821350370134624, 46.11947761263166, 50.14100463049752, 48.44787107195173, 42.42047207696097, 31.45500918797084, 21.191574914114817, 22.936427388872417, 26.075361217771256, 30.73346308299473, 37.508644580841064, 29.103264570236206, 21.656579630715505, 14.418190394129072, 11.731237752096993, 7.702251843043736, 4.897715704781668, 2.519218134028571, 1.5947946182319095, 0.6468453705310822, 0.34273132202880724, 0.21906271018087864, 0.20923706170703682, 0.2904790772923401, 0.25703251202191624, 0.2220617535391024, 0.29873196301715715, 0.3834384562713759, 0.46391998337847845, 0.17006226309708186, 0.231908097331013, 0.20996544190815516, 0.0866581770990576, 0.6621149597423417, 0.2948109262755939, 0.5509272260325295, 0.5388629276837621, 0.2666691749223641, 0.9250641614198685, 0.5442872994712421, 0.3057724695120539, 0.1578519440123013, 0.15456855376916273, 0.1699709729956729, 0.1775232306016343, 0.3467764492545809, 0.6160179504326412, 1.678529639329229, 3.6566532254219055, 5.441912514822824, 8.605375221797399, 13.807286534990583, 19.127001081194194, 18.95624041557312, 14.194301196507045, 12.812089102608816, 11.995327489716665, 15.147338696888514, 16.35056345803397, 32.00230142048427, 36.9352444921221, 29.253163269587926, 26.913802078792028, 15.06577205657959, 5.285320094653538, 0.44642916907157215, 0.025549359120694653, 0.10328216970499073, 0.026766944410545484, 0.06086571075554405, 0.03279939892568758, 0.03506539036918964, 0.060061022506228516, 0.12179665586778096, 0.020570662704163363, 0.03928562034187572, 0.011581009237228759, 0.023312305499400412, 0.08077158725687436, 0.019055989338085055, 0.0253892893171204, 0.012860107967363936, 0.03729581979236432, 0.05365497339516878, 0.05898088975144284, 0.08907848436917577, 0.03580678487196565, 0.04652283074600356, 0.05680620537272521, 0.07577714882791042, 0.04208765445011003, 0.024283190723508596, 0.10111127833702735, 0.02407616120763123, 0.04618744784966111, 0.09352173523179122, 0.029340098478964398, 0.030537081749311516, 0.03663344069250992, 0.013630528501900179, 0.04086922947317362, 0.05163687454270465, 0.06317544395902328, 0.009425738593563437, 0.042371760455093214, 0.0447691128855305, 0.0065645010326988995, 0.03314156377954142, 0.01258307823445648, 0.03310730115377477, 0.02976964846519487, 0.040343653211104016, 0.048214588181248734, 0.07162849751434155, 0.04128993136276092, 0.07789815430130277, 0.17478421543325695, 0.1421769844102008, 0.19088800916714327, 0.15420677246791975, 0.18975864191140446, 0.0976242936615433, 0.11207905052495853, 0.09878628488097872, 0.15079034864902496, 0.14068681294364588, 0.1047932943329215, 0.07181803948645081, 0.17519718541630677, 0.216108572270189, 0.19314052829785006, 0.0800827317205923, 0.13216837575393064, 0.31800195042576107, 0.079909379594028, 0.1829528542501586, 0.1397413286779608, 0.07632007862308196, 0.13287501569305146, 0.16726049701017992, 0.21134061525974954, 0.11106487137398549, 0.16125221869775228, 0.1718562011207853, 0.15599454939365387, 0.18938437556581839, 0.243682932640825, 0.18157916010490485, 0.11543692355709416, 0.09527397049324852, 0.22356732775058064, 0.1119120427008186, 0.14069787306444986, 0.1183175625545638, 0.14309988703046525, 0.09890086230422769, 0.13758075104228087, 0.06926316515143428, 0.09830402968717472, 0.12695288418659142, 0.13228986066366943, 0.11906545742281846, 0.12826875357755593, 0.16513326258531638, 0.09148083760270051, 0.12094854137727193, 0.0853653032598751, 0.15190800439034188, 0.10189527805362429, 0.2585163866834981, 0.10944672820291348, 0.16954669861921243, 0.18211297717477593, 2.3177707493305206, 8.726108857563563, 24.561739580971853, 44.86789512634277, 52.58021143504551, 57.99067987714495, 54.33147014890398, 55.762559345790315, 48.77804946899414, 30.60769374029977, 28.71438431739807, 29.711258002689906, 37.42401204790388, 44.31543343407767, 27.867468391145977, 23.601977961403982, 15.817226682390485, 15.027320725577217, 10.129825626100812, 7.33148033278329, 4.871485820838383, 3.0994139952319006, 1.2009144851139613, 0.8619657786829131, 0.9927855389458793, 1.0830617461885725, 1.2859962625162942, 1.2988300195762088, 0.8450277532849992, 1.497080255831991, 1.9344012864998408, 2.919613940375192, 3.1453320341450826, 2.2041535888399397, 4.841337587152209, 3.768864461353847, 4.46853893995285, 1.8582868107727595, 4.806078519139971, 5.144339408193316, 5.525685208184378, 5.9350391966956, 3.541048663003104, 3.000523107392447, 1.4287997654506137, 2.1286926780428206, 2.0577811002731323, 0.7550242628370012, 1.2515379743916648, 1.5258326615606035, 3.0512584192412238, 4.026582700865609, 6.418952567236764, 11.350727472986494, 13.836107662745885, 20.405122212001256, 22.11317876407078, 20.10698195866176, 19.461028780255997, 24.223056588854107, 23.409151554107666, 25.66585350036621, 40.88897098813738, 44.165109157562256, 35.2879238809858, 31.841732025146484, 17.734936441693986, 6.116130530834198, 0.6765057646802494, 0.22338367546243326, 0.1586781825338091, 0.10197694652846881, 0.1141006031206676, 0.1671327424368688, 0.12688102732811654, 0.1538743581622839, 0.17662415813122476, 0.15723222440906934, 0.10772859611149345, 0.17564797694129602, 0.09216559478746993, 0.24228031933307648, 0.09857435125325407, 0.1269217258585351, 0.14610449437584194, 0.15973162172096117, 0.15142264829150268, 0.17194076015480927, 0.18674190235989435, 0.10320259111800364, 0.14076770788856915, 0.2284209430217743, 0.1286270743502038, 0.12747268272297724, 0.16910630225070886, 0.1967195833900145, 0.04325668886303902, 0.08340561270181622, 0.10926777816244534, 0.21779360542339937, 0.17109066434204578, 0.1105405470090253, 0.09281671020601477, 0.21118137666157313, 0.14052722150725977, 0.24071246917758668, 0.10962611929114376, 0.1343663813812392, 0.15626970891441616, 0.1567902538393225, 0.16640323586761951, 0.1219548766634294, 0.17019711514668806, 0.15416764813874448, 0.10876081072326217, 0.16990743497652666, 0.13022792844900064, 0.16682147128241404], [0.08983531554362603, 0.03417840600013733, 0.03050844417884946, 0.03226587701854961, 0.0182243021803775, 0.017581507297498838, 0.009806399283531522, 0.03926553570532373, 0.01164676945856107, 0.024945272964292338, 0.03483354173866766, 0.059430364918495925, 0.04934997743527804, 0.07239527601216521, 0.014787196614114302, 0.03680859772222383, 0.04999786302713411, 0.0300303891168109, 0.02144105010665953, 0.02346960688009858, 0.033368991754416905, 0.04091354798791664, 0.09997915622911283, 0.04974530890051808, 0.04716570196407182, 0.026798421650060585, 0.03509246052375861, 0.007908621653249221, 0.045041761826723814, 0.05567645135202578, 0.023876429335879426, 0.018176239848669087, 0.027597737598365972, 0.05727150397641318, 0.029471622314304113, 0.011616912221402993, 0.013671367828335081, 0.013032937621963876, 0.07653154406164374, 0.009047992211500449, 0.0304285500730787, 0.048520268207149844, 0.022275258021961366, 0.005975974108358579, 0.013982465108191329, 0.009327257717294353, 0.08050670075629439, 0.04104135684402926, 0.06049392106277602, 0.06521681656262704, 0.01948767670962427, 0.09294664287673575, 0.05539849965966173, 0.0641804493165442, 0.03964135589610253, 0.012293505781729306, 0.04765248977180038, 0.03325489269835608, 0.12950288664017404, 0.5185233248131615, 4.024700173309871, 14.061350890568324, 25.26293788637434, 31.861506598336355, 38.021525859832764, 41.35750886372158, 50.93744536808559, 42.503065313611714, 26.35338991028922, 15.504965952464513, 27.06844813483102, 28.205418348312378, 19.046674694333756, 29.011649097715104, 23.619654178619385, 21.65885169165475, 18.70082116127014, 16.316555500030518, 12.723186033112661, 8.9360990524292, 6.87583874804633, 5.316842334611075, 3.215081742831639, 1.8227422152246748, 1.3696304261684418, 1.0485994411366326, 0.8780432045459747, 0.6826485150626728, 0.1318654641509056, 0.2532717452517578, 0.3387388491204807, 0.46333009217466625, 0.18890895321965218, 0.5001494107501847, 0.2908497745437281, 0.28439696079918314, 0.5531347447207996, 0.2816517709621361, 0.3837846719792911, 0.926703610590526, 0.8201183527708054, 0.35413860848971773, 0.7624997645616531, 1.1364175059965678, 1.5289973488875797, 2.4104469077927724, 3.7384743435042243, 6.614423632621765, 8.674422076770238, 8.96837864603315, 11.793027213641576, 14.130261387143817, 13.266483051436287, 12.102169070925031, 18.235267536980764, 18.39740722520011, 17.985721247536794, 24.365791695458547, 23.89163793836321, 28.74913920675005, 28.066711459841045, 24.330477476119995, 17.62690758705139, 7.630460449627467, 1.040059887937137, 0.09044442285916635, 0.07828130267028298, 0.10153258073010615, 0.033725073361503224, 0.0014934081846149638, 0.04366920083495123, 0.05656377498858741, 0.10257251707038709, 0.027845996598313962, 0.02512641467287072, 0.015686476037704518, 0.05622333700635603, 0.025950710887887647, 0.017561955310936486, 0.07481660787016153, 0.030550822083439146, 0.056468522242669544, 0.0528898165960397, 0.06975532695651054, 0.08109017980418035, 0.03281391957508666, 0.0022732823022774285, 0.027303645254245827, 0.06282980500587396, 0.0215836662932166, 0.018741445948502848, 0.02594406803005508, 0.01736118188793106, 0.06551935497139182, 0.028399954283876077, 0.05970711221120187, 0.04518367742587413, 0.025611455252926265, 0.024066162994131446, 0.05570319241711071, 0.02649613599559026, 0.021178733557462692, 0.03267178684473038, 0.012072142213582993, 0.013135426943855626, 0.031173968288515295, 0.01575038725111101, 0.03505887643301061, 0.014298381683017527, 0.03145598779831614, 0.09648531834994044, 0.058032419931675704, 0.027968170221096704, 0.022254108085430095, 0.014055356732569635, 0.027665506283353482, 0.01818151885111417, 0.032465322209256034, 0.01332297402301005, 0.01063980143849871, 0.03516158288610833, 0.04725179109456284, 0.06660857331007719, 0.011869004096037574, 0.039625715663922687, 0.022093799098261764, 0.04306109096588833, 0.024498628984604563, 0.04293864253642304, 0.049181157922638316, 0.04328383704913514, 0.050400478565799336, 0.014739259811384338, 0.03257797259305205, 0.12046330741473607, 0.05990208924881049, 0.032637673496667824, 0.03637471528989928, 0.02861580645133342, 0.028184996086305807, 0.03310930961742997, 0.041424145589449575, 0.047270827394511016, 0.04133995296433568, 0.047552565312279124, 0.0600943114342434, 0.032143160567751954, 0.0365844538568386, 0.028017820324748755, 0.016433448098333817, 0.05216356360220483, 0.05448958503880671, 0.03472395833315594, 0.03732648278985705, 0.007474527178731347, 0.03025674500635692, 0.04419901794088738, 0.06912879486169134, 0.03361902851611376, 0.041543778098587475, 0.03642131368230496, 0.06757201161235571, 0.1335484752697604, 0.050798425783536265, 0.013422448953081454, 0.03814211920169847, 0.04467191952945931, 0.10182059848947184, 0.06282939109951258, 0.04703380154179675, 0.022753336832725575, 0.02650627330876887, 0.0147654597447919, 0.04128250479698181, 0.12497120909392834, 0.855674076293196, 5.616446052278791, 19.25941116469247, 32.238762514931814, 39.593983105250764, 42.3166903087071, 47.073493071964805, 54.53894335883004, 39.57290574482509, 24.715513638087682, 14.9267646585192, 32.18386827196394, 33.129681382860454, 24.10913392475673, 36.30744348253523, 27.987726075308665, 25.480958461761475, 22.06880930491856, 19.391248021806987, 15.12828152520316, 12.248012627874102, 7.2894393886838635, 5.06101747921535, 2.900289914437703, 1.2795024109738213, 1.2200035750865936, 0.7072906813451222, 0.6253213712147304, 0.6159930346267564, 0.08759340870061091, 0.2284381506698472, 0.09234896209090948, 0.2288393277142729, 0.18539568888289587, 0.191931867439832, 0.09645165622766529, 0.39817124285868233, 0.35313448522772106, 0.2776781884687287, 0.3219627764608179, 0.44390401457037243, 0.43208363599010874, 0.26827784574457575, 0.38997277564236094, 0.8927266480667251, 1.2225155660084315, 2.3186657641615187, 4.34893308367048, 6.598106222493308, 9.156155450003487, 11.960697667939321, 13.956894278526306, 18.44362316812788, 16.0806884765625, 14.824685198920113, 19.735182115009852, 19.599191972187587, 15.961867332458496, 24.50220741544451, 25.530323675700597, 31.53000804356166, 32.93282502038138, 28.129630872181483, 22.18104703085763, 9.810879860605512, 1.9147984640938895, 0.14212184665458544, 0.0565893320100648, 0.09705416818282434, 0.024035299828808223, 0.04398896724783948, 0.030748160422912667, 0.04582202960071819, 0.022817015647888184, 0.06442386018378393, 0.12326678340988499, 0.0530590025175895, 0.02035073932659413, 0.025497172992410402, 0.020086346460240226, 0.06619535226907049, 0.04800318041816354, 0.026090830065576092, 0.030395118652709892, 0.014525349950417876, 0.04386977239378861, 0.0359949188839112, 0.04025904667962875, 0.05291176720389298, 0.014082443002345306, 0.030799047156636204, 0.050635234718876224, 0.0071403614045786, 0.04636188563225525, 0.013960386426853282, 0.09568379207381181, 0.05995883513242006, 0.06896883701639515, 0.031189842615276575, 0.09709393712026732, 0.046452802539403946, 0.045364286484462876, 0.04378033130030547, 0.012261591735295951, 0.01258554301291172, 0.0025390824926684475, 0.047994420531072786, 0.09846602992287704, 0.10500735856060471, 0.023274913130860244, 0.026387300674936602, 0.09743802901357412, 0.09846083912998438, 0.06944052063460861, 0.021865531436300704, 0.027002423203417232, 0.06752741150557995, 0.12324869366628782, 0.12387731564896447, 0.08390810859522649, 0.1117656012730939, 0.1535505476806845, 0.11626397632062435, 0.09860484461699213, 0.11925205455294677, 0.12972665391862392, 0.12569619661995343, 0.09510952753147908, 0.08106729960335152, 0.15860908052750997, 0.15737407894006797, 0.09073648468724319, 0.1367067436554602, 0.11100353859364986, 0.18101252908153193, 0.2038834204099008, 0.1313632939543043, 0.21895115902381285, 0.14664703740605287, 0.15832066243248327, 0.13110507066760743, 0.1464210581034422, 0.16396587022713252, 0.16369916525270256, 0.14388704193489893, 0.16585795155593328, 0.24912722621645245, 0.10340660624206066, 0.14207464775868825, 0.1552030382944005, 0.09273979147630078, 0.16120519622095994, 0.18909776237394127, 0.09008948797626154, 0.11780790133135659, 0.14687415664749487, 0.13175653213901178, 0.1772061511874199, 0.20341472913111958, 0.08198138805372374, 0.14556260273924895, 0.127814189397863, 0.20150306528168066, 0.2736331426671573, 0.14330674521625042, 0.1386958962040288, 0.12828449558998856, 0.12426295424146311, 0.22189798232700142, 0.19035873828189714, 0.1052467253591333, 0.08529774152806827, 0.08360655406223876, 0.13287190800266607, 0.12235487305692264, 0.19080585214708531, 0.7468992673924991, 6.042687203202929, 20.320206539971487, 35.482046127319336, 44.62703929628645, 49.044940199170796, 48.66259125300816, 60.06786469050816, 52.80440548488072, 37.86499336787632, 25.473671538489207, 37.97237777709961, 39.65788221359253, 27.89571976661682, 42.20564419882638, 32.55762924466814, 29.716639382498606, 25.794066871915543, 22.810852595738, 16.984588316508702, 12.304533617837087, 10.005139333861214, 6.466411803449903, 4.572853548186166, 2.3111730005059923, 2.0678603308541432, 1.613594489438193, 1.6026732240404402, 1.5301543325185776, 0.7647237309387752, 0.6881154988493238, 0.9340590387582779, 0.8873762637376785, 0.5618138590029308, 1.3082994371652603, 0.9817468055656978, 1.369815421955926, 1.4933496160166604, 1.2802634558507373, 1.1500906922987528, 1.7206420195954186, 1.7078648252146584, 0.6023212053946086, 1.1735862429652895, 1.7984505529914583, 2.6606322143759047, 3.536452863897596, 5.101481182234628, 9.000938773155212, 11.919089249202184, 12.922367436545235, 17.60796853474208, 22.796214478356497, 20.47074099949428, 17.499889305659703, 28.20915995325361, 26.212296315601893, 25.15983009338379, 33.65074416569301, 33.1793019430978, 39.37610149383545, 38.1224866594587, 32.775354521615164, 23.620251723698207, 10.562955481665474, 2.2021034359931946, 0.34033370496971266, 0.20385935955813952, 0.21677660356674874, 0.13551785530788557, 0.0948489632989679, 0.11608622728713922, 0.1875629433031593, 0.17592317717415945, 0.15029891287641867, 0.24124750761049135, 0.12850352669400827, 0.11388239982937064, 0.10367831201957804, 0.08153649978339672, 0.22503356050167764, 0.142478701791593, 0.1857900127236332, 0.20212121068366937, 0.1518937958670514, 0.18880939856171608, 0.12822969710188253, 0.14787614930953297, 0.08830481874091284, 0.1482615572001253, 0.09713162295520306, 0.10292434426290648, 0.14996120599763735, 0.17479955032467842, 0.1427225401358945, 0.16066315530666284, 0.31699153035879135, 0.11838153483612196, 0.14373095173920902, 0.1981973648071289, 0.19190782015877111, 0.07015813248498098, 0.11851232924631663, 0.09707405604422092, 0.11965937912464142, 0.09846402145922184, 0.13744155636855535, 0.20745798360024179, 0.19518570069755825, 0.09247681165912322, 0.10022503017847027, 0.13393883646598884, 0.27443185980830875, 0.2433433122932911, 0.12792499416640826, 0.12166451795824937, 0.12613244035414287], [0.04506107632602964, 0.04595952793689711, 0.051133832428604364, 0.06468725390732288, 0.045998055155255964, 0.051293970085680485, 0.034480489790439606, 0.03094582785187023, 0.028371832400028194, 0.07401344632463795, 0.014494620795760835, 0.021217087749391794, 0.04670636768319777, 0.08739925269037485, 0.028193996853328178, 0.0103126576536202, 0.029737078784299747, 0.04298410777534757, 0.09321338177791663, 0.0308236983338637, 0.04537261889449187, 0.02267821622081101, 0.007918633437449378, 0.0361829273668783, 0.08766232071710484, 0.06906056816556624, 0.06381790805608034, 0.06666793833885874, 0.04512545233592391, 0.09140031585203749, 0.028637275299323455, 0.00870768230275384, 0.08661132425601993, 0.011989353307788926, 0.03515380008944443, 0.06519407885415213, 0.024941861629486084, 0.0315716746263206, 0.09931993910244533, 0.05809399698461805, 0.011929480225912161, 0.03990009826208864, 0.03405907543908272, 0.025738750118762255, 0.05638414980577571, 0.07094435101108891, 0.05010787730238267, 0.020745388864140426, 0.08787261229008436, 0.013033488931666528, 0.014031063482564474, 0.03778803927291717, 0.027745017016838704, 0.015585143618019564, 0.022159423612590348, 0.09510378033987113, 0.05110121185758284, 0.018023757762940865, 0.04176898726395198, 0.05518840146916253, 0.15826602679278168, 1.543230842266764, 5.546083382197788, 19.43477327483041, 30.093877928597585, 31.76510034288679, 41.113043444497244, 51.964444705418174, 47.43361473083496, 28.32878187724522, 26.424963303974696, 41.050832748413086, 18.23025267464774, 19.694137368883403, 21.64495529447283, 16.270176274435862, 18.944438900266373, 22.46194359234401, 19.1543196610042, 19.88985422679356, 18.773365565708705, 13.869439908436366, 12.43478194304875, 11.45661541393825, 9.478798525674001, 7.730365123067584, 5.671304251466479, 3.8763604760169983, 3.8513057061604092, 2.955952367612294, 2.2031335064343045, 1.7481965124607086, 1.82088965177536, 1.7245960874216897, 2.090106074299131, 1.8637140052659171, 2.1135421310152327, 2.1669416427612305, 2.1039677304880957, 2.5301684950079237, 3.0426031351089478, 4.0362489478928705, 4.885919834886279, 7.333245175225394, 10.83298419203077, 10.967833093234471, 14.58831443105425, 16.43918251991272, 17.53859077181135, 19.048945018223353, 13.953612991741725, 15.23568504197257, 21.23611113003322, 21.022330692836217, 16.980909245354788, 20.3122421673366, 30.015422344207764, 30.246397835867747, 26.644621917179652, 24.192861454827444, 20.119834389005387, 11.121094720704214, 4.433486146586282, 0.649882330426148, 0.0484323877442096, 0.03367359290963837, 0.08256180012332541, 0.02355590126743274, 0.07485035141663891, 0.01957168782662068, 0.019655412262571708, 0.06433729947145496, 0.03448841168678232, 0.031031526824725524, 0.020091917232743332, 0.08459835512829678, 0.033532515301236084, 0.050294630495565276, 0.039153665636799166, 0.005958154082431325, 0.056378799557153664, 0.009231902342954916, 0.08225572654711348, 0.06768624298274517, 0.03712471700938685, 0.03884421634886946, 0.0318101898634008, 0.024525622803983942, 0.02367319113441876, 0.09360244018690926, 0.02529077960311302, 0.022278330089258294, 0.06116406938859394, 0.02004142235299306, 0.024071274059159414, 0.057688076980412006, 0.0545792534415211, 0.06845310290477105, 0.022037506136777144, 0.040110688390476365, 0.02426868534114744, 0.06315698780651603, 0.005570039261199001, 0.06615616687174354, 0.02902362296091659, 0.012892140757425554, 0.028879580154482807, 0.029442642083657638, 0.06005205227328198, 0.02967471463073577, 0.013300462775597615, 0.09532030086432185, 0.03235506366140076, 0.10197151146296944, 0.012858625368348189, 0.05282252627824034, 0.041826337043728144, 0.030792641786060164, 0.06093783224267619, 0.033131952331002266, 0.030233830878777162, 0.026227256316425543, 0.013262532668055167, 0.05117058867056455, 0.0464778269108917, 0.10155582055449486, 0.05487708281725645, 0.03280230984091759, 0.025020575084324394, 0.035917341975229125, 0.045128098622496636, 0.03626854491553136, 0.026893587882763574, 0.04024363714935524, 0.05191481266436832, 0.029715582794908966, 0.041415728362543244, 0.05046824385811176, 0.02637384193284171, 0.03700780542567372, 0.013479103234463503, 0.06932001960064683, 0.009366503334604204, 0.02686755758311067, 0.042422721827668805, 0.025220403647316352, 0.028176595822774937, 0.038607139606028795, 0.04494378476270607, 0.008489156707323023, 0.010416765281531428, 0.011194535198488405, 0.016163487852151905, 0.027698798604043465, 0.03306694528354066, 0.045041313993611505, 0.014761648074324642, 0.029973290394991636, 0.008844539423340132, 0.011529721319675446, 0.06343663244375161, 0.03675080010933535, 0.035338548211646933, 0.008366883848793805, 0.07429165925298419, 0.02604871678964368, 0.04213869385421276, 0.0348779009655118, 0.058553358406892846, 0.00375847501813301, 0.07128944035087313, 0.010735206854795771, 0.0845408628561667, 0.03923823145617332, 0.07135835915271725, 0.08422465196677617, 0.41368686886770384, 2.6595678372042517, 9.52096106324877, 25.407839093889507, 36.53959321975708, 37.672292028154644, 46.32748930794852, 56.25827857426235, 51.008528913770405, 26.03327771595546, 28.95832167352949, 40.470668588365825, 16.18893619946071, 25.856737886156353, 24.315451996667043, 21.198498794010707, 28.26696375438145, 30.252328123365128, 23.780656099319458, 24.968200513294764, 21.090082577296666, 18.761612687792095, 14.938434158052717, 13.626379762377058, 11.92208913394383, 7.425880295889718, 6.131702312401362, 4.098767970289503, 3.1844032747404913, 3.0943726428917477, 2.1051804082734242, 1.5150431948048728, 2.088294114385332, 1.9592710605689456, 2.274937059198107, 1.8380677700042725, 2.4155822779451097, 2.7710304047380174, 1.8584394540105547, 2.7952917771680013, 3.5756207278796603, 4.692829830305917, 5.892748985971723, 7.408746038164411, 11.781123212405614, 11.740709015301295, 17.000550065721782, 21.43359977858407, 24.072145189557755, 20.41241260937282, 20.27562689781189, 21.286004407065256, 18.908624410629272, 17.4927430834089, 18.910580328532628, 24.093029737472534, 30.930236067090714, 32.58822216306414, 31.36660725729806, 29.75724118096488, 23.782495634896414, 14.846134287970406, 5.982484970773969, 1.2687303147145679, 0.04771432127537472, 0.016227397369220853, 0.03612282612760152, 0.07566053579960551, 0.018955142070938433, 0.01002433370532734, 0.0584148694095867, 0.04798747233248182, 0.0025776559362254503, 0.05917070313755955, 0.02551953072127487, 0.1327091274516923, 0.030098571708159785, 0.038841057768357654, 0.0825543294527701, 0.052214233204722404, 0.036922730705035586, 0.09426260047725268, 0.06688408566904919, 0.0276911006242569, 0.0804881631795849, 0.02067999674805573, 0.0390135311920728, 0.0408499081885176, 0.02670496702194214, 0.048090670723468065, 0.023014969757891128, 0.00679279286747, 0.12502853173230374, 0.02525452886974173, 0.00896646877351616, 0.06981209319617067, 0.07356850377150945, 0.013336113853646176, 0.020123754095818316, 0.021898218164486543, 0.01446283482281225, 0.019856187381914685, 0.026321637144844447, 0.03225758192794664, 0.026754515345341394, 0.06378182356378861, 0.025809495876144086, 0.06462332233786583, 0.044655353096979, 0.03467540575989655, 0.07229751268667833, 0.019823207187333276, 0.074168851199959, 0.04089380940422416, 0.0788441678243024, 0.011781387413585824, 0.17404614575207233, 0.13640027652893746, 0.13956790869789465, 0.10942901843892676, 0.08953002228268556, 0.15185696498623916, 0.15542440355888434, 0.14186331124178, 0.07811293777610574, 0.25629190461976187, 0.15755832833903177, 0.10767706816217729, 0.11319176653133971, 0.1786235836999757, 0.10474064680082457, 0.08898169813411576, 0.09152199075158153, 0.09418049095464603, 0.16219998284110002, 0.13893398057137216, 0.09702513366937637, 0.11693480318146092, 0.13601401368422167, 0.18758156230407103, 0.24425075788583073, 0.17262868609811577, 0.13161543756723404, 0.13448859910879815, 0.11960812258933272, 0.1841028896825654, 0.10710430996758596, 0.09032694809138775, 0.15978671876447542, 0.1539926946695362, 0.09336711745709181, 0.1414579679923398, 0.09385706723800727, 0.168468248631273, 0.29612747420157703, 0.21313167629497393, 0.11762266127126557, 0.10461204405874014, 0.10547025515032665, 0.1652195043861866, 0.09293607130114521, 0.12068008578249387, 0.13219179878277437, 0.0723882531747222, 0.13259700632521085, 0.25618206337094307, 0.09490836225450039, 0.12148623966744967, 0.12153981679252215, 0.19011300003954343, 0.21208051698548452, 0.15416449973625795, 0.1624886452087334, 0.0845902602055243, 0.21917901108307497, 0.22297886147030763, 0.369740788425718, 2.891430309840611, 9.953824281692505, 28.958478007997783, 41.54039239883423, 42.85259444372994, 49.94493341445923, 62.677649770464214, 58.304821831839426, 40.69170468194144, 35.98406737191336, 50.74504974910191, 28.253942830221995, 30.155247892652238, 31.90607234409877, 26.320750747408184, 30.420509270259313, 32.4968637738909, 27.764610733304703, 28.047536168779644, 27.271846226283483, 19.177236557006836, 16.877754552023752, 15.779353788920812, 13.141041142599923, 10.433723330497742, 8.006200790405273, 4.741468088967459, 4.944307284695761, 4.065037940229688, 2.8814181728022437, 2.626881991113935, 2.9002037133489336, 2.85119611450604, 2.9643166959285736, 2.4890486214842116, 2.9056528380938937, 2.872445442846843, 3.1060034930706024, 3.789505822317941, 3.8438663567815508, 5.802152293069022, 7.395101513181414, 9.355875338826861, 13.574754646846227, 14.725530930927821, 20.318935019629343, 23.684901237487793, 26.970332622528076, 27.200396163122996, 21.822250740868704, 24.437740291867936, 29.34007133756365, 28.730005604880198, 25.319098438535416, 30.954540865761892, 38.074940136500764, 39.102849687848774, 36.63189656393868, 33.04757799421038, 25.487953560692922, 15.143861123493739, 6.283930829593113, 1.2637569244418825, 0.20834161261362688, 0.11759872255580765, 0.21219345235398837, 0.1884644313582352, 0.1577831677028111, 0.1229560279420444, 0.1246561517140695, 0.14920238671558245, 0.06245377446923937, 0.1585888737546546, 0.09176410561693565, 0.22629243295107568, 0.1117099274748138, 0.15159735748810427, 0.2125947515347174, 0.10135635840041296, 0.13256732720349515, 0.2437276073864528, 0.21332864144018718, 0.18674586500440324, 0.21508701065821306, 0.1809387451836041, 0.11796175236148493, 0.10644263654415097, 0.17937826391841682, 0.17118553710835321, 0.09423340990075044, 0.09757970034011773, 0.15923843532800674, 0.2296125590801239, 0.10999958496540785, 0.18127753771841526, 0.18801817244717053, 0.26920817153794424, 0.10684098409754889, 0.07326761420283999, 0.13255149019615992, 0.12915874724941595, 0.08131687835391078, 0.2216557724667447, 0.12295064037399632, 0.21230907472116606, 0.16583538348121302, 0.1079602547522102, 0.15517124214342662, 0.11900461997304644, 0.11097101641020604, 0.18218248630208628, 0.14357347733208112, 0.25030513586742537, 0.15834033994802407, 0.12008160432534558], [0.012794065305830112, 0.07879649395389215, 0.03959621296131185, 0.05871974876416581, 0.026297637361234853, 0.022316691066537584, 0.05807805819703, 0.04344775075359004, 0.02055851014197937, 0.015869040973484516, 0.14146019358720097, 0.015548300862844502, 0.03946036346522825, 0.03983689272510154, 0.04211794764601758, 0.05729413311928511, 0.05165488964744976, 0.024903890809842517, 0.042609251104295254, 0.08246297828320946, 0.03219809476286173, 0.013534879661165178, 0.025167031779087017, 0.06545238356505122, 0.02745503998760666, 0.051072750706225634, 0.040096751281193325, 0.03434591254751597, 0.03974823533956494, 0.03339594655803271, 0.043522969753082306, 0.054762244158025296, 0.04804179245339973, 0.05193340791655438, 0.039908603698547394, 0.030857557231294255, 0.03458544897979923, 0.07086295395025186, 0.0012773847930865096, 0.04594618793843048, 0.049306364596954415, 0.03548154607415199, 0.03489410438175712, 0.04923924730558481, 0.02792538858817092, 0.007889393667158271, 0.010996330878697336, 0.05591628973239234, 0.01902979110101504, 0.0667740340743746, 0.036908562893846204, 0.032515367559556446, 0.014307569047170026, 0.024611230174611722, 0.04908905697188207, 0.033681297674775124, 0.02495835003043924, 0.05477350105398467, 0.022147798611383353, 0.04734429916633027, 0.0032990684308710373, 0.026655734217326556, 0.05563535587862134, 2.6562046919550215, 11.246046781539917, 23.386291980743408, 32.35382815769741, 42.38168028422764, 40.70101179395403, 45.206640652247835, 36.47318581172398, 45.38608830315726, 30.03497110094343, 18.394339595522197, 22.035987751824514, 20.80764525277274, 14.538882340703692, 19.83382569040571, 24.463283606937953, 30.20876291819981, 22.170998198645457, 25.013521875653947, 21.063894816807338, 15.2733599117824, 16.86633345058986, 14.396845528057643, 17.372375965118408, 14.014118773596627, 11.054705551692418, 7.456874472754342, 8.54370127405439, 10.47854094845908, 8.722454973629542, 8.631696735109601, 7.248350782053811, 8.755969609533038, 7.984649215425764, 7.320681963648115, 10.797940952437264, 11.747657213892255, 10.347433652196612, 15.730016367776052, 16.86938544682094, 19.84925763947623, 19.413702862603323, 21.156215531485422, 22.357079642159597, 14.528024911880493, 14.193573372704641, 22.061600548880442, 17.210244962147303, 21.85081304822649, 24.858881030763897, 26.808915546962194, 25.72814757483346, 28.485701731273107, 24.392596108572825, 22.710425070353917, 15.546255622591291, 10.091019068445478, 4.568092729364123, 1.5311794089419501, 0.17766606222305978, 0.11039804786975894, 0.02421774941363505, 0.035761526586221795, 0.016648842254653573, 0.030487928672560623, 0.011837034918633955, 0.01689629040525428, 0.0609166415940438, 0.026808262104168534, 0.06107985640742949, 0.08304545309926782, 0.0839170856135232, 0.03859068173915148, 0.06109969677137477, 0.02288798871450126, 0.0026666269321659847, 0.04653856597308602, 0.00924825673324189, 0.04912802863067814, 0.02080324584884303, 0.009797308610619178, 0.014424887751894338, 0.022272236844790832, 0.04808714573404618, 0.0043087715831851316, 0.012937874017682458, 0.0460046640863376, 0.05550247158056923, 0.03392101391883833, 0.0235988711938262, 0.026857912207820585, 0.054844279041779895, 0.0387058359171663, 0.011875371299018818, 0.032151733857712576, 0.017175582204280154, 0.02183466318196484, 0.021591878263279796, 0.03752213836248432, 0.042216033275638304, 0.03534546248348696, 0.05678981535934976, 0.015442164415227515, 0.019300765757049834, 0.03488892037421465, 0.03953296331954854, 0.05996113536613328, 0.07551144129995789, 0.05057126582999315, 0.08473177546901361, 0.05221652326041034, 0.010304495725514633, 0.11487692860620362, 0.005399763866859887, 0.0552387216261455, 0.04018602952627199, 0.02245122081200991, 0.010231158812530339, 0.008679597738331981, 0.06382412343685116, 0.007774866285866925, 0.07677699731928961, 0.03324643815202372, 0.05913769919425249, 0.016487177893785492, 0.05269585057560887, 0.025365825576175536, 0.08446980666901384, 0.01687571213447622, 0.09811776503920555, 0.03153642812477691, 0.05491383566654154, 0.009852689790672489, 0.027603201501603638, 0.036768838962806125, 0.04173502319359353, 0.03803772319640432, 0.013479964125768414, 0.019535091040389876, 0.023861705125974755, 0.027240353204043846, 0.046074213925749063, 0.10991531091609172, 0.01604509536576058, 0.0309347473750157, 0.04075576824003032, 0.10373569572610514, 0.03884267607437713, 0.02368126909381577, 0.015591543899582965, 0.028846084273287227, 0.02589167494859014, 0.04043521811919553, 0.005150370017093207, 0.017025860059740286, 0.030304089787283113, 0.029478407664490596, 0.008484574051440825, 0.08428914672029869, 0.029445943156523362, 0.05717796113874231, 0.04377084198806967, 0.002981543728050643, 0.006806878830372755, 0.038521698476480584, 0.018088691867887974, 0.05851143851344075, 0.014447966424216117, 0.08698839973658323, 0.04669620662129351, 0.04514633425112281, 0.06440843708281006, 0.12709287953163895, 0.09358406545860426, 0.06001837658030646, 0.1773976201989821, 4.617407134601048, 15.349748407091413, 29.34717239652361, 39.10225214276995, 48.43286991119385, 47.01338073185512, 48.712013789585654, 38.66216714041573, 51.01616498402187, 29.522048132760183, 17.774497747421265, 22.28562089375087, 21.169076647077286, 17.34335855075291, 23.46726107597351, 25.56070293698992, 29.728798730032786, 33.74108116967337, 27.370663506644114, 25.03650825364249, 22.09518814086914, 24.885999849864415, 19.705735649381364, 18.26665255001613, 15.677958726882935, 15.342881849833898, 10.75016861302512, 13.311800071171351, 13.973072290420532, 11.908793755940028, 11.91677463054657, 9.802808659417288, 10.83245439188821, 12.13930458681924, 9.189224532672338, 12.648385201181684, 12.639590518815176, 15.08850656236921, 18.394878080913, 21.77777358463832, 24.1845566204616, 24.313958133969987, 26.92734238079616, 25.790547609329224, 22.070091247558594, 22.067108733313425, 26.16111935888018, 17.603420938764298, 21.836188827242168, 24.935973031180247, 28.428575379507883, 28.529169661658152, 32.053745882851736, 29.90498767580305, 29.436265672956193, 21.54185097558158, 14.084237388202123, 7.198136585099356, 2.322738059929439, 0.45231847305383, 0.04508382760520492, 0.008861629175953567, 0.021316223411953876, 0.04287944035604596, 0.04060631750949791, 0.014211160247214139, 0.03091492736712098, 0.06775296333112887, 0.014773401997185178, 0.02825652215895908, 0.04837116352947695, 0.07011022112731423, 0.022124709761036292, 0.04359613957681826, 0.04565014989514436, 0.08666715411735432, 0.034214337822049856, 0.04011929560718792, 0.03265198380021112, 0.03919705116589155, 0.019979568797030618, 0.031763136852532625, 0.0497899802534708, 0.05259506776928902, 0.06128020065703562, 0.030988673945622783, 0.012964943324082663, 0.06976779164480311, 0.01881605087380324, 0.0648229473403522, 0.026781146148485795, 0.01209564327395388, 0.018840793653258255, 0.010780265820877892, 0.05210948096854346, 0.0438486937034343, 0.04845795833638736, 0.022040919167920947, 0.024899580416136553, 0.0764569594923939, 0.022972259371142303, 0.05319075705483556, 0.056973050348460674, 0.061980923770793846, 0.023767646601689712, 0.04144984510328088, 0.052918613622231145, 0.006356788316874632, 0.003932957329587745, 0.029524751606264284, 0.07859268239034073, 0.031164004001766443, 0.0785718649359686, 0.08565870180193867, 0.14923260866531304, 0.10334544309547969, 0.09720757137984037, 0.1334404932068927, 0.12006933641220842, 0.13859334242131027, 0.07788208659206118, 0.15928663845573152, 0.09504527026521307, 0.18056846862392767, 0.0595628624515874, 0.16328350827097893, 0.11870989150234632, 0.15073708365006105, 0.16995786369911262, 0.19716813574944222, 0.17785700197730744, 0.20168740967554705, 0.14710962186966622, 0.12705853208899498, 0.20456830651632377, 0.11801694439990179, 0.12741002679935523, 0.09625157660671643, 0.08891283361507313, 0.07553661494914975, 0.0692245022260717, 0.14202515541442803, 0.2024867103568145, 0.13698053253548487, 0.11087636756045477, 0.12353173776396684, 0.3051224872469902, 0.11577772455556051, 0.14464179000684194, 0.09982430096715689, 0.18489241945956433, 0.07171480038336345, 0.09046051770980869, 0.0888834869755166, 0.12611633193280014, 0.1643975270645959, 0.08100686927459069, 0.09839200853769269, 0.2156643218227795, 0.06081965858382838, 0.1318213322332927, 0.0780923781650407, 0.13343700553689683, 0.07202113180288247, 0.0985378867813519, 0.05542362920407738, 0.22347526411925042, 0.10836992026971919, 0.1954293761934553, 0.11563166310744626, 0.1315853784659079, 0.19139376202864306, 0.2010569827897208, 0.11967540612178189, 0.18583980362330163, 0.4757957032748631, 5.306747470583234, 16.32689789363316, 33.632883821214946, 44.72842393602644, 56.098605496542795, 51.320544719696045, 56.37557806287493, 46.83966187068394, 57.11319882529122, 40.32153592790876, 27.61604608808245, 33.17757878984724, 31.005551065717423, 22.837097678865703, 29.58749668938773, 38.00107383728027, 39.45478984287807, 34.55808162689209, 33.741049902779714, 30.423410143171036, 23.51775884628296, 25.608657666615077, 21.526905400412424, 24.487812485013688, 19.77014892441886, 16.015750612531388, 12.295584338051931, 13.017126968928746, 13.955421260425023, 12.6192626953125, 12.96798322881971, 10.842909693717957, 11.521107724734716, 12.49590698310307, 10.366310170718602, 14.81105283328465, 16.01038486616952, 14.421986716134207, 21.11761655126299, 24.358377967561992, 28.631865773882183, 27.294525146484375, 30.562773636409215, 30.949121270860942, 24.673206056867325, 23.773773908615112, 33.53198902947562, 23.80096047265189, 29.772336142403738, 34.062817505427766, 36.45121560777937, 35.095896516527446, 38.81424931117466, 34.405335903167725, 31.917474337986537, 22.626648902893066, 14.496625133923121, 7.074893346854618, 2.1721124053001404, 0.5126196901713098, 0.17037015514714376, 0.12569854435111794, 0.08463977969118527, 0.20199479960969516, 0.08004458448184387, 0.18924010545015335, 0.108196608855256, 0.23210384111319268, 0.09201974368521146, 0.11083391162433795, 0.19954097270965576, 0.12156300911945955, 0.13624258499060357, 0.13904432393610477, 0.1725715941616467, 0.21696671550827368, 0.22062064015439578, 0.10025603244347231, 0.20760556496679783, 0.10153514559247664, 0.12906715859259876, 0.20354654134384223, 0.14390239039702074, 0.15025676228106022, 0.11071581938969237, 0.1088702923485211, 0.12732848046081408, 0.1664462685585022, 0.1146262777703149, 0.10341900986220155, 0.09956311926777874, 0.12253966528390135, 0.08887712231704167, 0.10882251669785806, 0.1513573189399072, 0.07684958699558463, 0.11938359535166196, 0.09180468879640102, 0.0837740640022925, 0.150682502293161, 0.11543279806418077, 0.13015133541609558, 0.12007214554718562, 0.13276041112840176, 0.11295122586722885, 0.19140851337994846, 0.1624478381127119, 0.1525313202291727, 0.12063737878842012, 0.17654082046023437, 0.216870960646442, 0.06165096576192549, 0.17871473809438093], [0.024257677806807414, 0.0347800053256963, 0.05254340750564422, 0.048004693551255126, 0.03544354472043259, 0.04374878281461341, 0.03427976216854794, 0.019768371379801204, 0.0635735879519156, 0.05068199256701129, 0.015038846592817987, 0.03318195018385138, 0.018236500543675253, 0.0357911446397858, 0.04824058625048824, 0.02402819726350052, 0.039714814097221406, 0.02063276053273252, 0.020246007446465746, 0.0383771060566817, 0.015111346363223024, 0.009806864928188068, 0.0519625170688544, 0.043019344098865986, 0.0267551887913474, 0.0595349000234689, 0.047247312763439756, 0.048136186852519, 0.059170519933104515, 0.05402259349024721, 0.0328308659871774, 0.06606425930346761, 0.01544269367254206, 0.02571564769771482, 0.07965597390596356, 0.028003450649391328, 0.03719656368983643, 0.031072964958314384, 0.03268551700083273, 0.09784304656620536, 0.025824937636830976, 0.03784714985106673, 0.04664772190153599, 0.053375189658254385, 0.0367214568624539, 0.054006678451384814, 0.050428295108888826, 0.026693208010068963, 0.03230239577325327, 0.010818763353329684, 0.035976086144468615, 0.012798151782979923, 0.029206824023276567, 0.08437976507203919, 0.03631144189941032, 0.022461054480767677, 0.03230571720216956, 0.021611476050955907, 0.02363731698798282, 0.10495879580932004, 0.07464358822575637, 0.02685251276540969, 0.029914936383387873, 0.10749877630067722, 0.983896513070379, 5.871444072042193, 17.35284284182957, 29.216164112091064, 37.22301108496529, 35.84694119862148, 37.96479729243687, 39.10019547598702, 42.0178656578064, 36.49381501334054, 32.47321905408587, 24.719145808901104, 25.5242474760328, 24.649347679955618, 22.1743837084089, 19.643153224672588, 12.458475300243922, 26.03494007246835, 22.140294109072002, 26.388412305286952, 22.63428497314453, 13.726762992995125, 19.33298737662179, 16.52728567804609, 13.835239137922015, 18.725066900253296, 13.700872267995562, 11.367311085973467, 18.449305057525635, 18.299644333975657, 20.484743356704712, 18.253843545913696, 19.587697914668492, 20.826419285365514, 29.22308451788766, 30.57223013469151, 15.905293362481252, 20.709046840667725, 18.080143792288645, 22.624745096479142, 23.244112730026245, 26.52109510557992, 23.14679626056126, 17.91877361706325, 20.408825601850236, 18.519622564315796, 29.08294803755624, 30.95769534792219, 29.720026629311697, 28.421194655554636, 27.396809577941895, 19.27849612917219, 11.336422869137355, 6.208674890654428, 2.702343987567084, 0.9853211109127317, 0.26686141746384756, 0.03101424453780055, 0.08375862733061824, 0.08189252710768155, 0.03305956621521285, 0.03353046612547977, 0.01205398716099028, 0.04013767372816801, 0.016870534912283932, 0.07328649783240897, 0.01080872951674142, 0.06364100040601832, 0.006456127539942307, 0.03974201995879412, 0.08328707263405834, 0.06416430018310036, 0.039889211167714426, 0.02937612190310444, 0.05412843477513109, 0.01939243753440678, 0.01802711990395827, 0.020421035554526106, 0.06765337474644184, 0.0901399166988475, 0.049295026276792796, 0.048944576510361264, 0.012139138216818017, 0.034008344768413475, 0.027845984723951136, 0.0533271358082337, 0.056084851401724985, 0.04457404424569436, 0.05748742739004748, 0.020020776228713136, 0.06475264432707004, 0.003714748949278146, 0.04238967717226062, 0.07332493005586521, 0.013139238614322883, 0.016589823278731534, 0.019165257224813104, 0.042055318863796334, 0.04358593441013779, 0.07144540841025965, 0.045075196639767716, 0.08862769962953669, 0.018270320425342237, 0.0195742136732276, 0.03074174148163625, 0.012170656168434237, 0.06644262400056634, 0.020475769581805383, 0.021048595629898564, 0.042956036781626086, 0.05214100570550986, 0.009059476416691073, 0.03777024469205311, 0.014591252664104104, 0.025573453899206858, 0.01592999038153461, 0.036468638107180595, 0.04753596834572298, 0.01719045569188893, 0.04907637854505863, 0.04876018461904355, 0.04522417239578707, 0.037211006307708364, 0.019519786683044264, 0.08671106890376125, 0.02053674273858113, 0.03829056570040328, 0.08197169178830725, 0.015028868735368763, 0.03929541838754501, 0.02896194752039654, 0.027549870345475416, 0.036790670827031136, 0.11445572120802742, 0.03772474552637764, 0.028209421650639603, 0.034866443901721916, 0.028303407232410142, 0.008133584849669464, 0.014186470054223068, 0.016046701797417233, 0.053094798632498295, 0.045723899866321256, 0.026856897797967707, 0.03143378273983087, 0.014852846573506082, 0.02642403995352132, 0.027392341655546, 0.027261019684374332, 0.0220580878002303, 0.008638392851155783, 0.04558328705440674, 0.019087176503879682, 0.039467498260949335, 0.04169795821819987, 0.058792569142367156, 0.03153133232678686, 0.07276859240872519, 0.05712483184678214, 0.05604622240311333, 0.04158720773245607, 0.026529438494305526, 0.028004590588222657, 0.019903788309810416, 0.012479174167050846, 0.015950938453897834, 0.042117113047944646, 0.07040590633239065, 0.0378372737738703, 0.040192363650671074, 0.006363702588714659, 0.05047405890322157, 0.06527398313794817, 0.06277458582605634, 0.07759147004357406, 0.1087825849120106, 1.5929889551230838, 8.534471460751124, 21.333441495895386, 35.7721403666905, 42.90249293191092, 43.265963622501914, 43.72204337801252, 44.75779744556972, 44.436273029872346, 36.293970925467356, 32.780662945338655, 26.792943375451223, 21.429422174181255, 23.461157083511353, 27.311153922762188, 23.28697443008423, 18.164713791438512, 28.35895095552717, 25.06252752031599, 26.90806634085519, 23.2766580922263, 23.744786024093628, 27.434185675212316, 24.731367690222605, 20.570060287203106, 22.428482804979595, 18.09283815111433, 20.02153127534049, 22.29012680053711, 22.029529401234218, 24.953767367771693, 23.450819901057653, 20.926219735826763, 24.41903053011213, 33.50695466995239, 34.219836371285574, 18.706965105874197, 28.355282306671143, 25.17552259990147, 27.464828968048096, 25.6847699710301, 30.170846598488943, 26.123883962631226, 18.096350465502056, 18.836427416120255, 21.705201387405396, 26.57270458766392, 34.0215938431876, 35.21513107844761, 33.499811921800884, 31.567764554704937, 24.353489909853252, 15.006281580243792, 9.586978503635951, 4.642666876316071, 1.8298701984541756, 0.6315296952213559, 0.05496071904365506, 0.029314239509403706, 0.0437367388180324, 0.04018748837656208, 0.03914402026150908, 0.024776984405304705, 0.03042329821203436, 0.05081578270931329, 0.025080845957355838, 0.029445173019277196, 0.05925864127597638, 0.02433248798895095, 0.06776476984045335, 0.04446273057588509, 0.04254397603550127, 0.011612789272995932, 0.04679553057732327, 0.05051766834887011, 0.03304757310875824, 0.10113769370530333, 0.0343318431239043, 0.02188823012901204, 0.03585367164175425, 0.026283303308965902, 0.028514575811901262, 0.03902863538158791, 0.035164290240832737, 0.0025796851800155957, 0.09415250817047698, 0.09106815938970872, 0.08470997413886444, 0.03210164779531104, 0.027373463114989654, 0.02309834983732019, 0.003931902207633746, 0.04262301179447344, 0.11092043840991599, 0.032874689171356816, 0.029077702201902866, 0.03906603283914072, 0.043712457442390065, 0.04701512486540845, 0.017777040733822753, 0.07269361428916454, 0.018212802708148956, 0.039783617548112354, 0.025788300138499056, 0.024590589139344435, 0.04912545698295746, 0.04730044884075012, 0.04778406788994159, 0.029222834057041576, 0.011569642927497625, 0.023932539092909013, 0.009304543757545096, 0.1496964552040611, 0.11299273185431957, 0.18494979638074124, 0.11265291473163025, 0.09265650808811188, 0.15644748508930206, 0.1256174458456891, 0.103231021735285, 0.09106163866817951, 0.2891381292470864, 0.13700935670307704, 0.14244719062532696, 0.10398647548364741, 0.13509404233523778, 0.13280560156064375, 0.1772639216589076, 0.16248389546360287, 0.16290365079683916, 0.09723804438752787, 0.15870341046580247, 0.11024546570011548, 0.15785403390015873, 0.10004236176609993, 0.19486577143626554, 0.09773230965116195, 0.08816729326333318, 0.10408662046704974, 0.15402417869440146, 0.13934172583477838, 0.09717554452696017, 0.1427246435944523, 0.13596353067883424, 0.07639080911342587, 0.1576656997203827, 0.15415333104985102, 0.1177755623523678, 0.22072495812816278, 0.10576373511659247, 0.07998270887349333, 0.19664009979793004, 0.17825809759753092, 0.12764290001775536, 0.16048208145158632, 0.20754033061010496, 0.0871847609856299, 0.24548232608607837, 0.19130232264953, 0.10920105781406164, 0.11297895080809083, 0.12471986615232059, 0.08698104441698108, 0.12788783758878708, 0.11092887938554798, 0.11108889829899583, 0.17123105323740415, 0.12590682746044227, 0.16336095625800745, 0.09186531590031725, 0.10343014462185757, 0.1739501737590347, 0.1359312595533473, 0.15846424044242927, 0.14733732465122426, 0.22969843447208405, 1.613061975155558, 8.074947135789053, 23.630383934293473, 38.93087135042463, 48.725427286965505, 48.068791253226145, 49.97482109069824, 51.441127232142854, 54.40039280482701, 47.63833992821829, 44.381691455841064, 35.267270360674175, 33.895327704293386, 37.67143739972796, 33.468086447034565, 30.6528639793396, 21.53950422150748, 38.8757825578962, 33.18358898162842, 36.937947341373985, 32.65824610846383, 24.54045377458845, 32.422247069222585, 26.31008005142212, 22.74650185448783, 27.739446095057897, 21.450322355542863, 20.215709107262747, 27.967713526317052, 27.15283748081752, 29.252562250409806, 27.70398075239999, 26.271738154547556, 28.186003344399587, 39.41782195227486, 40.946519442967, 22.120764459882462, 30.707893712180002, 29.218932969229563, 34.75895404815674, 34.02975450243269, 37.23472227369036, 33.4122576713562, 24.884306226457866, 29.288474014827184, 28.36854120663234, 37.68942975997925, 42.28682347706386, 42.28826175417219, 40.105064800807405, 36.62784229006086, 28.04878510747637, 17.85429780823844, 9.51378617967878, 5.124040246009827, 1.7154921016522815, 0.7187598230583327, 0.1070967103753771, 0.18471574251140865, 0.2122739130364997, 0.2189785854092666, 0.10469783124114786, 0.11653452180325985, 0.09761243286941733, 0.10826067613171679, 0.17971681218062127, 0.12939096907419817, 0.14625763972955091, 0.09853887744247913, 0.1311873769653695, 0.13197484399591172, 0.11490891474698271, 0.09790973298783813, 0.12140686464096818, 0.11553381835775715, 0.08471399785152503, 0.21625487799090998, 0.13296874852052756, 0.09662128998232739, 0.1769697902990239, 0.14611662658197538, 0.10229088432554688, 0.10855285331074681, 0.15207368907119545, 0.12001491790371281, 0.12722617095070227, 0.2610450152839933, 0.14502080609755857, 0.08649146783032588, 0.07238823281867163, 0.12583277214850697, 0.06623416447213717, 0.15536619882498467, 0.1770010707633836, 0.1396769221339907, 0.15400078280695847, 0.15848897982920918, 0.12863342543797834, 0.17573553510010242, 0.11558450492365019, 0.20438542775809765, 0.20513277979833738, 0.07874280147786651, 0.06392301991581917, 0.1332779297871249, 0.1864867324807814, 0.14789600324417862, 0.16995311395398208, 0.12369525113276073, 0.10316926826323781, 0.1568099856376648, 0.08093035088053771], [0.01824572353091623, 0.04626686019556863, 0.039838175156286786, 0.03866695246792265, 0.04520187573507428, 0.02516257210767695, 0.06357537249901465, 0.015195309982768126, 0.02783623417573316, 0.026034168998843858, 0.010888641434056419, 0.011505494226834603, 0.03370590474722641, 0.017316834535449743, 0.04285573573516948, 0.05359981867617794, 0.022628035163506866, 0.016547063698193858, 0.01537431769871286, 0.024744687834754586, 0.015076681705457824, 0.015535602079970496, 0.06537888465183121, 0.01697581131676478, 0.04444879346660205, 0.03312489217413323, 0.0223375916414495, 0.021050230899293507, 0.057456621900200844, 0.09590046187596661, 0.0196981650577592, 0.009248519665561616, 0.010663036173874778, 0.08226634562015533, 0.010954303267811025, 0.02927356812038592, 0.046075048523822, 0.050937403326055834, 0.05337809718080929, 0.0412950576948268, 0.05972472698028598, 0.026028068969026208, 0.018723122110324245, 0.024925746422793185, 0.011083063769287296, 0.02781031413802079, 0.025824352400377393, 0.02210662849912686, 0.040268973646951575, 0.010644945582108838, 0.09034585886235748, 0.029985941680414335, 0.03999534422265632, 0.02166474104991981, 0.05024967076522963, 0.023759141165230955, 0.018848282983526587, 0.007542856503278017, 0.005677629894177828, 0.05762756522744894, 0.02803294826298952, 0.04841895953619054, 0.03356170927041343, 0.03764244940664087, 0.06565588300249406, 0.03206934952842338, 0.9930855057069233, 6.326210183756692, 15.52715676171439, 24.550702367510112, 35.63003928320748, 38.34864010129656, 46.45344625200544, 42.828536306108745, 44.48176636014666, 40.81484065737043, 39.969689573560444, 40.89912578037807, 28.802025420325144, 25.192693335669382, 25.74555802345276, 23.494843687329972, 25.414519786834717, 26.733586651938303, 22.954360689435685, 22.74286620957511, 22.97169644492013, 22.336671045848302, 18.638167517525808, 21.53966576712472, 25.717018297740392, 22.117941754204885, 27.004788739340647, 24.114928722381592, 23.279150758470806, 29.90132597514561, 32.64052472795759, 24.075186763490947, 62.4417792728969, 58.35747528076172, 23.771121433803014, 17.382370948791504, 17.787124361310685, 24.423979384558542, 31.08140802383423, 35.00248146057129, 26.508548395974294, 31.917192935943604, 35.827520983559744, 33.886812686920166, 34.692869731358115, 29.12898506437029, 22.96817023413522, 18.100587129592896, 12.159259813172476, 6.9262787614549906, 2.5991801747253964, 0.46419628283807207, 0.12959530310971396, 0.039253410284540484, 0.028313887205773165, 0.027706340520775745, 0.03897056296201689, 0.03265481668391398, 0.042295174207538366, 0.10032457126570599, 0.018016858758138757, 0.04733738489449024, 0.05058030391644154, 0.01036619406659156, 0.03812905740258949, 0.06365639636559145, 0.03375587545867477, 0.06138966192624398, 0.03694314782374671, 0.043237828982195685, 0.013282240717671812, 0.028593771026602814, 0.08086918773395674, 0.020223335895155157, 0.07722750385957104, 0.02357032522559166, 0.014122435856344444, 0.06587982670004879, 0.0740355122834444, 0.030230794434568713, 0.028665967152587006, 0.023642935257937227, 0.005495059445300805, 0.024404897853466015, 0.042543477312262566, 0.003754731625252004, 0.023870994270380055, 0.017389181635475585, 0.05707295105925628, 0.05139880035338657, 0.044941993430256844, 0.04404891920941217, 0.039533723278769424, 0.05545978154987097, 0.06758733293307678, 0.03869676390396697, 0.05462580094380038, 0.01003092821753983, 0.09036808088421822, 0.09364852628537587, 0.03504213358142546, 0.033240979337798696, 0.025815548408510428, 0.016078447058264698, 0.05949471039431436, 0.043015283066779375, 0.03510461308594261, 0.042619500375751934, 0.07407739146479539, 0.03798995093841638, 0.05751798182193722, 0.03895297872700861, 0.011231737577223351, 0.02434577200827854, 0.03540478680016739, 0.06800224352627993, 0.019396200011085187, 0.022064745925100784, 0.015061548678204417, 0.07886367570608854, 0.022466564185119102, 0.015954639862424562, 0.05294999247416854, 0.006078954095885689, 0.014295160338016493, 0.051752096574221335, 0.037382580672523806, 0.031068381454263414, 0.047686599727187834, 0.03512194287031889, 0.02186957041599921, 0.0027908420971860842, 0.052339931816927025, 0.02852668087663395, 0.00848615334169673, 0.0398691434945379, 0.03635916326727186, 0.04248472975034799, 0.05301836505532265, 0.035539879729705195, 0.01707054498339338, 0.015420573430934122, 0.020930242159270813, 0.02943721380350845, 0.032705886622092555, 0.051023964038384814, 0.014093277510255575, 0.029350897363786186, 0.016869842806564908, 0.04396356289674129, 0.058804599568247795, 0.023935955516727905, 0.04483585019728967, 0.07707363925874233, 0.04482814543215292, 0.05307739081659487, 0.056865930025066645, 0.07328313229871647, 0.04304382564233882, 0.04320058758769717, 0.01319742129583444, 0.018605637164520364, 0.04143493090357099, 0.08886116995875325, 0.03853477384628994, 0.05208439892157912, 0.06116029673389026, 0.03212096568729196, 0.009817444985466344, 0.03371827783329146, 0.01449436804146639, 0.03731020473475967, 0.04363657687125461, 0.05919200235179492, 0.06673199204461915, 0.08963748865893909, 1.9731485673359461, 8.721203429358345, 21.58916299683707, 31.695628779275076, 41.50801379340035, 43.67628254209246, 50.979568822043284, 47.03730337960379, 49.03402805328369, 41.5129782812936, 41.82016856329781, 41.00683675493513, 29.7298618044172, 26.247674805777415, 22.210048811776296, 24.63154465811593, 27.77854708262852, 28.043514898845128, 22.327230181012833, 20.984409161976405, 26.67071066583906, 23.732576302119664, 20.136067117963517, 23.940846817834036, 27.407721723828995, 20.580360991614207, 31.19225263595581, 31.414709636143275, 29.038806131907872, 33.1999763080052, 33.902915137154714, 26.315892219543457, 60.17685413360596, 60.99410820007324, 19.658720663615636, 17.855892419815063, 19.604748794010707, 27.748499597821915, 31.752784660884313, 35.691357135772705, 29.194767134530203, 31.120053904397146, 36.40524632590157, 34.5380152293614, 39.378387451171875, 33.94109548841204, 27.190946613039287, 22.676693303244456, 16.792456729071482, 9.98288425377437, 3.9199491313525607, 1.0657369558300291, 0.45902313185589655, 0.08473747516317026, 0.06405605349157538, 0.029074740396546464, 0.05227629201752799, 0.03500221875895347, 0.041694653752659044, 0.01251015522783356, 0.042248511354305913, 0.031072442486350025, 0.07893365302256175, 0.051415044481733015, 0.019888402528262565, 0.01356170978397131, 0.03944207016112549, 0.03261995355465582, 0.03739592406366553, 0.061407419187682014, 0.048184098210185766, 0.03451852167823485, 0.014600626625386732, 0.01881892277326967, 0.06242619202073131, 0.018388568723042096, 0.01211252183254276, 0.04598706967330404, 0.03145718201994896, 0.033973685199660916, 0.016223326159108962, 0.03073111901591931, 0.027243718737736344, 0.07240022931780134, 0.021134569409436414, 0.03086230019107461, 0.04011637790660773, 0.02288195484184793, 0.024699483831812228, 0.030084037488060336, 0.051932346009250195, 0.04096538806334138, 0.032932995685509274, 0.02799689769744873, 0.050453475543430874, 0.07916183077863284, 0.020228855777531862, 0.011643660071838115, 0.05054153921082616, 0.053368601083223305, 0.003463139682675579, 0.041127239021339586, 0.016181184045438255, 0.021206417786223546, 0.04640009733183043, 0.019298506235437732, 0.029464487518583025, 0.08471100551209279, 0.0682492506291185, 0.044433787664664645, 0.09187535143324307, 0.12133031232016427, 0.11896731411772114, 0.12960605110440934, 0.10997907963714429, 0.17588371357747487, 0.15068932835544857, 0.14996853417583875, 0.12781087814697198, 0.15039189931537422, 0.09757452311792544, 0.11111162243677036, 0.12519714768443788, 0.11960246360727719, 0.07075018821550266, 0.15182719086962088, 0.14922221350882733, 0.10273411697042839, 0.14076430164277554, 0.09386274657611336, 0.08391776414854185, 0.08871622809341975, 0.1759132162800857, 0.10641962063631841, 0.12933862688285963, 0.18834255289818558, 0.19906169628458364, 0.12906532654804842, 0.131147153409464, 0.14364654198288918, 0.13024428114295006, 0.07001724825905901, 0.09511093888431787, 0.1978011003562382, 0.12552283092268876, 0.09883276452975613, 0.07485504687896796, 0.1221753191202879, 0.10162260197103024, 0.12977960679147924, 0.14481807340468678, 0.12263228531394686, 0.15569204491164002, 0.12729407873536858, 0.09908648234392915, 0.15656185895204544, 0.14484293492777006, 0.17527698113449983, 0.15847745830459253, 0.09983874697770391, 0.1256750670394727, 0.07637385930866003, 0.1361425824995552, 0.1592365490006549, 0.10821402684918471, 0.09941712567316634, 0.059639367274940014, 0.06545833431716476, 0.12727201277656214, 0.17175793567938463, 0.09804443575974021, 0.17242398565368994, 0.10291945202542202, 0.15458797344139644, 0.2227408585271665, 0.15325653845710413, 2.20309550847326, 9.632356320108686, 22.619162218911306, 36.7138922555106, 48.01615170070103, 50.76009954724993, 59.31991195678711, 55.60298701695034, 58.03111144474575, 52.372060775756836, 52.47432436261858, 52.499084268297466, 39.88119731630598, 37.13752392360142, 36.74323449816023, 35.800895486559185, 37.497343335832866, 38.0550092288426, 33.8552748135158, 33.37189211164202, 36.24553850718907, 35.52604212079729, 27.934369121279033, 33.9033910887582, 38.88927248546055, 33.79706627982003, 40.646770681653706, 35.1241374697004, 32.85181597300938, 43.33803381238665, 45.83866964067732, 32.02297578539167, 71.13952037266323, 69.3397354398455, 32.740943568093435, 26.109971932002477, 27.749029397964478, 34.829120431627544, 40.64281020845686, 47.63986505780901, 38.969058649880544, 41.2272127696446, 45.97785595485142, 44.58323090417044, 47.45309747968401, 41.2382048198155, 34.01415579659598, 27.962462425231934, 17.25214954784938, 9.677257316453115, 3.633466435330255, 0.8538100048899651, 0.3711583566452776, 0.20875097279037746, 0.18108412809669971, 0.11029318028262683, 0.12095766088792256, 0.1196242445813758, 0.14584195560642652, 0.27146595610039576, 0.13004095133926186, 0.09953524504921266, 0.10612460718091045, 0.1003363642043301, 0.1526326255074569, 0.12538416550627776, 0.13007866431559834, 0.1566323180283819, 0.13262023936424935, 0.14250122915421212, 0.18280513717659883, 0.11777031049132347, 0.13794923626950809, 0.09947594108858279, 0.20048807188868523, 0.13280950992235116, 0.12284716378365244, 0.2100427406174796, 0.1143104468605348, 0.11748502722808293, 0.09605590746338878, 0.11098143192274229, 0.09151747170835733, 0.12026683081473623, 0.12143559381365776, 0.2044851995472397, 0.1066241039495383, 0.08965040796569415, 0.12693760357797146, 0.0983304518408009, 0.12982060387730598, 0.15767179296485015, 0.08373920087303434, 0.1613133411322321, 0.17869993246027402, 0.24561719170638494, 0.15758221277168818, 0.07512838114053011, 0.17274699546396732, 0.12964527042848722, 0.10358807364744799, 0.09565344120242766, 0.060638116539589, 0.07414557066346918, 0.21508753991552762, 0.12463452001767499, 0.07685449280376945, 0.13097513121153626, 0.19162951223552227, 0.11355179042688437], [0.07191702417497124, 0.04292259857590709, 0.03874124187443938, 0.021043118155960525, 0.0445144858344325, 0.032432437009577236, 0.023070679179259708, 0.023921762260475328, 0.018641543541369692, 0.010058917787059076, 0.010442127224190958, 0.010915542803039508, 0.025694482494145632, 0.031053759024611542, 0.073091290092894, 0.06935841111200196, 0.053563276172748635, 0.08124859737498419, 0.0331529699532049, 0.02122744558645146, 0.016659810773230026, 0.03682104544714093, 0.025123052531853318, 0.07814151767109122, 0.043815516733697484, 0.026935743567134653, 0.022350762006161467, 0.02615971663700683, 0.012193486327305436, 0.016325245511585047, 0.004457717229213033, 0.03623341037226575, 0.013945071043313613, 0.03698413133887308, 0.007195846909391028, 0.03709697510514941, 0.027789691762466515, 0.03813299969104784, 0.0652296408744795, 0.005324651312548667, 0.017934873068173016, 0.01706909970380366, 0.020973537782473222, 0.04971295974350401, 0.03808503065790449, 0.04233184223994613, 0.028804272945438112, 0.015037815219589641, 0.08476119674742222, 0.034317468359534226, 0.042527351927544386, 0.024016814838562692, 0.014554253845874752, 0.052648152956472974, 0.07050722518137523, 0.03474816167727113, 0.04803056609151619, 0.006974463833362928, 0.058188130147755146, 0.11109668109565973, 0.01082791424622493, 0.04794249903144581, 0.04496731296447771, 0.09486742623682533, 0.055503530095198324, 0.034594395464020114, 0.012646020839123853, 0.1177300326526165, 1.008190672312464, 6.237855587686811, 13.145057201385498, 21.30788254737854, 31.54316098349435, 37.884007113320486, 44.955338205610005, 45.87658248628889, 44.97215979439871, 47.201940945216585, 42.38464021682739, 44.79566165379116, 43.125530106680735, 38.186694962637766, 30.61514915738787, 36.83542319706508, 27.620783022471837, 29.82833514894758, 25.907713345118932, 29.94384547642299, 20.106770038604736, 22.09951686859131, 19.014494112559728, 23.088728427886963, 20.64895360810416, 18.988269874027797, 22.6657064642225, 25.80176200185503, 24.5383015700749, 23.158790588378906, 67.65217781066895, 80.58562414986747, 32.72110298701695, 29.614862169538224, 25.79667592048645, 21.844632625579834, 35.10825388772147, 40.226234436035156, 36.64598751068115, 36.40200499125889, 33.63892180579049, 32.40742656162807, 19.407136814934866, 17.741116864340647, 10.71078622341156, 6.063972141061511, 1.4200379784618105, 0.36910565250686234, 0.04882384816716824, 0.019747922030676688, 0.09017579763063363, 0.0747199302007045, 0.021275172043325644, 0.013681730754407389, 0.04275718530906098, 0.04312197930578675, 0.05577041148873312, 0.015792239291061248, 0.09655693772115878, 0.061807802346135886, 0.06806684684540544, 0.09858649703008787, 0.028059638437948058, 0.06267105495291096, 0.07901307554649455, 0.03063304695699896, 0.030571385087179284, 0.027165843273646066, 0.01770117542972522, 0.02319179768008845, 0.05185526103845664, 0.044383894984743426, 0.00926783586120499, 0.02235434127838484, 0.010816223087853618, 0.003273974297501679, 0.05270450868244682, 0.031925388146191835, 0.09274277703038283, 0.03398934239521623, 0.07663480352078166, 0.04310403883989368, 0.05320637353828975, 0.02063499460928142, 0.03149227245843836, 0.0423566053754517, 0.021307124257353798, 0.026391049580914632, 0.04805437588532056, 0.023824132945654646, 0.03635823028162122, 0.021795693219506314, 0.03052307678652661, 0.04111173788883856, 0.05961829876261098, 0.040890474404607496, 0.019414917399574603, 0.0452810370230249, 0.053902065314884694, 0.043070244403289895, 0.029105087875255516, 0.01942880531506879, 0.038922434473144155, 0.04220154994566526, 0.0246740709990263, 0.039240110998174975, 0.02659600617231003, 0.026750759654013172, 0.06217217565115009, 0.018557513764660274, 0.03982269437983632, 0.054142348135688474, 0.05401219494108643, 0.04925563053361007, 0.03630537918901869, 0.024986909569374154, 0.05432868402983461, 0.035576042253524065, 0.037400683986821344, 0.016865724099001715, 0.028023769380524755, 0.03833667215492044, 0.057238995363669734, 0.044470676220953465, 0.048760398357574425, 0.015703627706638405, 0.027293083856680563, 0.008730182523972221, 0.02765919590768005, 0.022038671520671675, 0.029012657835015228, 0.028027840590636646, 0.03178091107734612, 0.08452368234949452, 0.04316998226568103, 0.005700731467056487, 0.021838430747655884, 0.05603453124474202, 0.03385648523856487, 0.018420371659366146, 0.01746785268187523, 0.03599368395017726, 0.04000116266044123, 0.015106326900422573, 0.06944090739956923, 0.03210306932617511, 0.02832915254735521, 0.03388318559154868, 0.044531703660530705, 0.06273744281913553, 0.03663134741197739, 0.09739925752260856, 0.022703459419842278, 0.03939776182440775, 0.02634759959099548, 0.04582931028146829, 0.044207631942949126, 0.04939704740952168, 0.05909689888358116, 0.03990266651713422, 0.036244372105492015, 0.06640544028154441, 0.03265820935900722, 0.043643894871430736, 0.02407522652564304, 0.04966018328975354, 0.04794825300840395, 0.0073375190841034055, 0.0447708702912288, 0.056322854344866106, 0.06433121301233768, 0.013922063617168792, 0.03508735794041838, 0.0699338223785162, 0.03896412366468992, 0.17364777784262383, 2.1457489856651852, 9.293147870472499, 19.32420137950352, 27.472445930753434, 39.51430116380964, 44.80012239728655, 49.593184334891184, 51.466373511723106, 49.09046827043806, 52.51945986066546, 44.721253395080566, 47.19694171633039, 42.70458044324602, 39.77722447259085, 33.69311080660139, 36.69076517650059, 29.790026256016322, 27.550227539879934, 29.879887308393204, 31.48543187550136, 20.001303332192556, 25.67522314616612, 26.139350652694702, 28.732411418642315, 25.253146137510026, 20.429819583892822, 22.51993499483381, 28.279387133462087, 26.716426338468278, 24.03404995373317, 72.36602333613804, 83.38584545680455, 30.33950022288731, 25.812865223203385, 25.01784191812788, 24.33900465284075, 38.83017805644444, 45.17379651750837, 40.27261018753052, 41.96885653904506, 38.67921107155936, 37.39457947867257, 26.28762694767543, 24.120068652289255, 15.72094202041626, 8.572926265852791, 3.101777468408857, 0.8406514195459229, 0.07217851800045796, 0.030553855134972503, 0.0724774601736239, 0.09575509931892157, 0.027730233435119902, 0.05414742697030306, 0.008980673904131566, 0.018336798197456768, 0.11336701855595623, 0.05373294385416167, 0.01621562139397221, 0.024206986151901737, 0.010455050771789891, 0.04760016454383731, 0.05030765497524824, 0.06847452425530978, 0.01945215031238539, 0.06572890694120101, 0.029804311426622525, 0.03746619654287185, 0.01337304905921753, 0.021240739783804332, 0.04334926478830831, 0.061709774391991754, 0.010402204768200005, 0.03745536712397422, 0.03529030776449612, 0.015639986210901822, 0.044888304346906285, 0.029384152365050147, 0.08363805844315461, 0.06332915928214788, 0.03624936273055417, 0.024530672800860236, 0.03418839742828693, 0.028341846241216575, 0.019411668913172822, 0.02362110509004976, 0.013430482807702251, 0.033710498429302654, 0.03263804329825299, 0.01880707555184407, 0.023897421513018862, 0.027159743243828416, 0.02531728657361652, 0.025590278174994246, 0.07522229038711105, 0.05647624397118177, 0.016243838272722702, 0.04944385954045823, 0.032251332620424886, 0.10164818274123327, 0.04410202135997159, 0.07486641234053032, 0.04438323341310024, 0.06885764548288924, 0.047968279969479354, 0.02640125135492001, 0.07683890006904091, 0.029043212266904966, 0.20625762801085198, 0.12015058419534139, 0.11267928938780512, 0.1830398560102497, 0.1539565830358437, 0.12974392942019872, 0.13137176207133702, 0.128033559769392, 0.1507871188223362, 0.09635976223008973, 0.0999056233891419, 0.1293139960616827, 0.07401063040431057, 0.1057905779619302, 0.13967438441302094, 0.1464831033455474, 0.13471953171704495, 0.19153335025267942, 0.12828104863209383, 0.07266021001019649, 0.1139387453773192, 0.09853556619158813, 0.20140095933207444, 0.14308846050075122, 0.15807177578764303, 0.17532565923673765, 0.10863703236516033, 0.10205259639769793, 0.12657316241945538, 0.1374151749270303, 0.11773409029202801, 0.11551609502307006, 0.11745365176882062, 0.15869654369141373, 0.08175859786570072, 0.08413701238376753, 0.12309687824121543, 0.14473918692341872, 0.12771238200366497, 0.12585576091493877, 0.09013912959822587, 0.09055219457617827, 0.10167396028659173, 0.17893172002264432, 0.0705773246341518, 0.12094490442957197, 0.09389679546334914, 0.1620645879634789, 0.11498550777988774, 0.11526848402406488, 0.11979530325957707, 0.07221251939024244, 0.12688959044005188, 0.16513653312410626, 0.09333828650414944, 0.06256913220775978, 0.10787697814937149, 0.07617130982024328, 0.16288739309779235, 0.18812413247568266, 0.0880603018615927, 0.16236622392066888, 0.14390495525939123, 0.21042795851826668, 0.20251752941736154, 0.2017035045261894, 0.09580585373831646, 0.3512274761285101, 2.085240815367017, 9.66079877104078, 21.065063851220266, 30.840152672358922, 43.86345658983503, 50.52335705075945, 57.42609010423933, 58.4046813419887, 59.88464764186314, 60.99107878548758, 55.55357142857143, 59.400788988385884, 54.90291779381888, 50.86300931658064, 41.92607995441982, 49.834832259586875, 39.843239307403564, 41.933372088841026, 38.422443866729736, 42.106274536677766, 29.965721879686626, 34.85039234161377, 31.120192868368967, 36.57260758536202, 31.717935970851354, 29.29866702216012, 31.97843435832432, 38.23003087724958, 34.79197883605957, 32.151229109082905, 75.00423349652971, 90.01956163133893, 42.537073271615164, 39.649047579084126, 34.16212810788836, 32.508085114615305, 47.00200653076172, 52.26653848375593, 48.14475243432181, 48.93850769315447, 45.60167700903756, 41.681235858372276, 30.065063749040874, 25.280546358653478, 15.350285155432564, 8.451330184936523, 2.818232123340879, 0.5494641416839191, 0.12398563697934151, 0.19440906308591366, 0.20291131043008395, 0.18218768388032913, 0.12342591344245843, 0.18595651164650917, 0.12851071916520596, 0.13566736371389457, 0.19925326029104845, 0.11359124723821878, 0.11994341388344765, 0.12916265561112336, 0.0985582699733121, 0.191268993009414, 0.15457012797040598, 0.1941580186997141, 0.11977409225489412, 0.15338483585843019, 0.14248385865773472, 0.11021784932485648, 0.093893151730299, 0.10313371981361083, 0.1076650105948959, 0.16257738401847227, 0.058524764941207, 0.10005277727863618, 0.08924908164356436, 0.06939340316291366, 0.1776549071073532, 0.14492121072752134, 0.14671175607613154, 0.09234068396368197, 0.24889988984380448, 0.13592967178140367, 0.19321495001869543, 0.08339036601994719, 0.12314126800213542, 0.14495076771293366, 0.10551084511514221, 0.10657626723072358, 0.13435452058911324, 0.07291958680642502, 0.11762871380363192, 0.18951279510344776, 0.11229960833277021, 0.14022702404430934, 0.16781657002866268, 0.17028803883918694, 0.06295279626335416, 0.20357771324259893, 0.12173085154167243, 0.13155544150088513, 0.1676619726100138, 0.16731344988303526, 0.11638248924698148, 0.1557408044380801, 0.11280143247651202, 0.10273563688887016, 0.1105714678498251, 0.15924189585660184], [0.055983909139675755, 0.04776365416390555, 0.03351921940754567, 0.05908263607748917, 0.10655672542218651, 0.0635622903438551, 0.029526773640619855, 0.027998312442962612, 0.0275487999564835, 0.057062963023781776, 0.019297686904402714, 0.04500715314809765, 0.046703110715108256, 0.0296830334700644, 0.0009022364579972678, 0.024468257757169858, 0.03051055103008236, 0.042048326560429165, 0.06051133905670472, 0.021732038153069358, 0.059426531195640564, 0.030677725095301867, 0.050581789908132384, 0.043270195102585216, 0.0340202801993915, 0.07833975167678935, 0.047225949088377614, 0.0473854998126626, 0.0327311654442123, 0.025136482436209917, 0.08254648558795452, 0.028449560282751918, 0.03118080452882818, 0.022936403884419372, 0.06713214450116668, 0.023802424914070537, 0.0530035763845912, 0.03956935993794884, 0.06763864375118699, 0.03525257782478418, 0.038967618120035956, 0.022769267138625895, 0.014975880239424961, 0.04060393585158246, 0.019166086733873402, 0.0374499558072005, 0.028821487378861223, 0.009847121562675705, 0.04385454946064523, 0.02784854280097144, 0.04940732042970402, 0.038739755882748535, 0.028791194182953665, 0.0331964979746512, 0.02648376121318766, 0.06877158688647406, 0.006394851586914488, 0.06051536276936531, 0.03393442855615701, 0.043352576039199314, 0.020218267238565853, 0.03689552145078778, 0.00455439489867006, 0.04440551989578775, 0.054060706802244694, 0.03644886898941227, 0.08778651976691824, 0.07339149434119463, 0.06541853823832103, 0.09512694552540779, 1.3060012119156974, 4.490150008882795, 7.856703349522181, 13.323968972478594, 21.134184530803136, 27.524057149887085, 31.805538858686173, 37.38319138118199, 44.926961762564524, 42.68535130364554, 45.33245863233294, 51.91132572719029, 50.720942974090576, 52.428775446755544, 44.21831498827253, 41.89690099443708, 41.479084968566895, 43.14760800770351, 38.79161902836391, 35.30252552032471, 32.68875217437744, 37.63087381635393, 43.63424594061715, 36.56951216288975, 34.21426044191633, 35.212296213422505, 34.61042935507638, 28.209149530955724, 47.513710090092246, 63.48647567204067, 36.60182128633772, 40.6020381791251, 34.654522623334614, 34.120081084115164, 32.41265855516706, 33.21754135404314, 24.980750696999685, 24.480146884918213, 22.020746878215245, 12.6753693989345, 8.465239609990801, 3.0370337196758816, 0.8930715609874044, 0.24592220676796778, 0.022508662194013596, 0.04993599420413375, 0.014054298217940544, 0.10403233766555786, 0.05465217559997525, 0.049762190851782045, 0.06990693203572716, 0.021694007961611663, 0.020805848030639545, 0.013685929189835275, 0.08024148177355528, 0.04046911094337702, 0.03881521915484752, 0.015049241749303681, 0.020332563069782088, 0.049813433816390376, 0.016579760604404976, 0.016632535361817906, 0.013268119555764964, 0.033367984129914215, 0.011297108489088714, 0.04732209750052009, 0.02108256139659456, 0.01692588810276772, 0.02511657082608768, 0.05077962018549442, 0.030574082263878415, 0.029616788096193756, 0.06174753486577954, 0.02482189833452659, 0.020246053247579505, 0.05606693807723267, 0.0505851452637996, 0.06405618241322891, 0.011517178599855729, 0.007168356911279261, 0.011675361227909369, 0.014981652876096112, 0.017418199185548083, 0.011888872449552374, 0.023995432503787533, 0.0819195599428245, 0.03322709651131715, 0.05067810456135443, 0.010704715187395257, 0.05014563099082027, 0.04890518415985363, 0.032760525654469214, 0.020177392289042473, 0.025082348912422146, 0.02113828608500106, 0.060946001804300716, 0.02424165080966694, 0.04307194074083652, 0.0543539933860302, 0.00827899744867214, 0.03134519660047122, 0.031147817548896586, 0.02760362728232784, 0.03493166468771441, 0.028780167988900627, 0.034369023450251134, 0.039863131674272675, 0.027981004710974436, 0.07884969109935419, 0.05190117750316858, 0.06657344555216176, 0.030328035288091217, 0.02297153333867235, 0.017963434303445474, 0.017791478262682046, 0.05450139154813119, 0.06343572320682661, 0.03889149666896888, 0.04052386532670685, 0.023283406692956175, 0.02959955669939518, 0.06914119169648204, 0.03417074194710169, 0.03584997023322752, 0.011101843074097164, 0.02057290865507509, 0.01737581958462085, 0.04120271247146385, 0.031698519962706735, 0.029720373252140622, 0.022712797758036425, 0.028948308966521705, 0.07284211846334593, 0.06494861881115607, 0.048899287690541575, 0.03679580055177212, 0.029045906050929, 0.07902292108961514, 0.028840659385813133, 0.06009553958262716, 0.06734879394727093, 0.07830083769346986, 0.06694110296666622, 0.05587150642116155, 0.014677280726443444, 0.05137349099719098, 0.05818458140960761, 0.04267269752121397, 0.05112820737329977, 0.019068425188639333, 0.02775625355674752, 0.04923094542963164, 0.019241141188623648, 0.06961153860070876, 0.049474427543048344, 0.013462909148074687, 0.06610227762056248, 0.01792883071383195, 0.0364029694880758, 0.016876176930963993, 0.03407875295462353, 0.0458707212736564, 0.03548911852496011, 0.03329963529748576, 0.023920976856191243, 0.011970668997881668, 0.010684015628482615, 0.022589238227478096, 0.040112333837896585, 0.018495641548984816, 0.04347546212375164, 0.07605447966073241, 0.07025454552578074, 0.0254936361286257, 0.05880247575363942, 0.14892593797828468, 1.8175884974854333, 6.5888894370624, 12.039029053279332, 18.67389862877982, 28.395192759377615, 33.36303315843855, 40.18018524987357, 44.5577449117388, 50.42661033357893, 49.74278252465384, 51.038315841129844, 54.75392409733364, 52.63780505316598, 56.41582202911377, 46.34676013674055, 44.59714467184884, 44.01115097318377, 44.443509578704834, 39.472045694078716, 39.65434905460903, 35.908342429569785, 38.90371084213257, 42.761555671691895, 38.906107970646445, 35.83180454799107, 38.967780181339805, 37.23129333768572, 30.17904199872698, 51.253452914101736, 68.28057983943394, 41.11424548285348, 44.781431743076865, 38.38393695013863, 37.92242022923061, 40.68054240090506, 41.02243546077183, 32.80502332959856, 30.38380193710327, 27.735796553747996, 17.757241896220616, 11.35047733783722, 5.195641432489667, 1.8044143872601646, 0.6668336551104272, 0.047435022690998654, 0.05210148782602378, 0.03193667896890214, 0.03572282973410828, 0.06800286777849708, 0.06945641192474536, 0.038189603082303486, 0.0327819707537336, 0.025637704380122677, 0.04428449299718652, 0.022812169211517488, 0.03682284356494035, 0.023148787041593875, 0.07027311702924115, 0.01921836276804762, 0.08407207658248288, 0.08936032745987177, 0.036884359549731016, 0.028484146908989975, 0.04322920819478376, 0.02368327586113342, 0.022941177378275564, 0.02374392671377531, 0.025335325427087288, 0.09140340318637234, 0.020617401892585412, 0.01952492997848562, 0.10794873322759356, 0.01362863538919815, 0.01649905225661184, 0.05291036942175456, 0.11499161459505558, 0.08048044823642288, 0.058455683290958405, 0.025615059970212833, 0.03386147925630212, 0.03490645032642143, 0.01663760910741985, 0.024056495566453253, 0.045389483882380385, 0.07155881196792636, 0.048212437225239616, 0.009155922536072987, 0.0362671708821186, 0.015580890899790185, 0.05996188854000398, 0.020303404723693217, 0.035937453753181865, 0.043233710274632485, 0.015896893139662485, 0.05695688085896628, 0.055554525394524844, 0.020120810950174928, 0.02910729989941631, 0.08651518941457782, 0.01300180473897074, 0.02313254969859762, 0.030363003590277264, 0.001902689375648541, 0.02777969354896673, 0.012465579717952226, 0.050917851339493475, 0.09303046909293958, 0.15458531358412334, 0.16556981844561441, 0.21588031308991568, 0.2523879941020693, 0.10909439889448029, 0.18121002348405973, 0.11894809800599303, 0.10462621186992951, 0.19606135013912404, 0.10741142848772661, 0.12415175592260701, 0.08641902064638478, 0.1193654920373644, 0.11941590718924999, 0.08860165067017078, 0.17172003271324293, 0.22842316861663545, 0.12587853255016462, 0.08674975897052459, 0.12348483742347785, 0.13201227198754037, 0.12068908315684114, 0.08136810096246855, 0.12349004857242107, 0.2253135104796716, 0.1638984509876796, 0.15238645300269127, 0.10576160451663391, 0.11587814773832049, 0.15872565284371376, 0.18011454226715223, 0.09605269799275057, 0.2049866369260209, 0.13858709989913873, 0.20692477721188748, 0.19265803561678954, 0.1417953898864133, 0.12147173258875098, 0.1299770333405052, 0.12597820934440407, 0.10805437434464693, 0.16153044519679888, 0.11822108844561235, 0.08692650377218213, 0.12232926514531885, 0.14728905366999762, 0.11266680434346199, 0.12858320027589798, 0.09240624401718378, 0.13475231852914604, 0.09533443474876029, 0.2121201977133751, 0.13159007392823696, 0.07161573427064077, 0.15037632015134605, 0.11207188519516162, 0.19396089070609637, 0.11034473537334374, 0.17871046332376345, 0.07335747938070979, 0.13175427940274986, 0.13483800393130096, 0.113350163746093, 0.1080492174785052, 0.22541668851460728, 0.23631691932678223, 0.11376244162342378, 0.1330867593309709, 0.18485922552645206, 2.0286714051451002, 6.769890444619315, 12.511936477252416, 20.189498765128, 29.436088493892125, 36.17850923538208, 44.12629999433245, 49.88411235809326, 57.78905010223389, 56.04669550486973, 59.83385631016323, 64.41596399034772, 64.4909142085484, 65.5286763054984, 56.82598114013672, 54.48549781526838, 55.053940364292686, 56.82871873038155, 50.21961654935564, 49.376018387930735, 44.75044277736119, 51.26409755434309, 55.97452456610543, 48.578087261744905, 46.167698110852925, 49.145817620413645, 45.739289556230815, 39.58211210795811, 56.90942553111485, 71.18987396785191, 51.21081529344831, 56.907167366572786, 46.216679436819895, 48.71135718481881, 49.573229108537944, 48.40614366531372, 39.788914816720144, 34.94409922191075, 30.480225563049316, 18.32351313318525, 12.482965963227407, 4.891307294368744, 1.5935789006096976, 0.43156811222434044, 0.14460772754890577, 0.14373766923589365, 0.16115818731486797, 0.12577455384390696, 0.2011100442281791, 0.101868815187897, 0.12086086108216218, 0.07440593133547477, 0.11706293773438249, 0.16454664192029408, 0.19473824756486074, 0.13811729582292692, 0.09985518788120576, 0.09351516701281071, 0.12982196094734327, 0.1675887858229024, 0.24313462206295558, 0.07333333031939608, 0.10174209198781423, 0.1377594635954925, 0.1515729437981333, 0.1464651357382536, 0.13562400532620295, 0.13084249118609087, 0.13863262959889003, 0.1284976370100464, 0.11006538250616618, 0.22948933712073735, 0.09655121767095157, 0.15995152134980473, 0.12170125384415899, 0.18900937640241214, 0.18601721338927746, 0.14863833412528038, 0.0783029750787786, 0.08671666003231492, 0.06546018671776567, 0.12830445809023722, 0.12277840104486261, 0.08280827796884946, 0.14089436323515006, 0.1507468545543296, 0.13234752256955418, 0.10430400273097412, 0.12960058211215905, 0.11693430106554713, 0.10631842392363719, 0.12470050076288836, 0.16098106253359998, 0.11209787308637585, 0.15656926855444908, 0.17256319389811584, 0.1450500645275627, 0.10165803506970406, 0.14901497534343175, 0.16031809310827935, 0.11705137549766473, 0.08380374312400818, 0.14810211504144327, 0.20384954794176988, 0.14892160892486572, 0.09923364301877362], [0.01550243528825896, 0.010463308542966843, 0.006877648336480239, 0.06721211663846459, 0.0942831736590181, 0.05848161689937115, 0.03441653786493199, 0.03079495219779866, 0.03666441920878632, 0.016641359709735428, 0.007628340889433665, 0.03681701834180525, 0.03845297984246697, 0.04717491986230016, 0.04453762387856841, 0.07137518003582954, 0.025384400472311035, 0.07158887785460268, 0.04247134564710515, 0.053306325139211755, 0.015956212367330278, 0.039508919431162734, 0.09995659493974277, 0.02825574014735009, 0.01967045199126005, 0.01020784180478326, 0.024245951025347625, 0.027282878690000092, 0.006305667064485273, 0.06562245158212525, 0.03607548473935042, 0.04368339239486626, 0.056841234743062935, 0.06013188870357616, 0.07027845709983792, 0.05619086232036352, 0.018358984596229026, 0.02440032792011542, 0.042430969420820475, 0.031481215730309486, 0.022189173980482986, 0.042986506396638494, 0.010709348733403852, 0.04303688762177314, 0.032947540083634, 0.021614324201696684, 0.0704085933310645, 0.10913389641791582, 0.04378688594858561, 0.03299461005787764, 0.029368484991469553, 0.04590398984562073, 0.014953646343201399, 0.0303350716962346, 0.043127170098679404, 0.05969963475529637, 0.026513771120724932, 0.05520456756598183, 0.027859859068744948, 0.015745791872697215, 0.04941559855693153, 0.010535718407481909, 0.01903164859062859, 0.04266800545156002, 0.03236517383317862, 0.04817856475710869, 0.06858071498572826, 0.01190388758134629, 0.03136306921286242, 0.016431402315252593, 0.05465579219162464, 0.030025683476456573, 0.080791549757123, 1.5079971786056245, 2.592437816517694, 6.167108595371246, 6.043256955487387, 13.38496286528451, 16.05055066517421, 21.486300127846853, 26.77178089959281, 31.17303044455392, 35.9374623298645, 36.8757574898856, 43.95068427494594, 45.55728496823992, 47.72916330610003, 44.21055037634713, 45.7975606237139, 44.859046595437185, 46.85211999075753, 49.65443965366909, 46.64683198928833, 47.63104084559849, 46.23933751242501, 43.747692653111045, 44.760423864637104, 47.292753900800435, 43.84563793454851, 39.497420515332905, 36.9536919593811, 37.37451655524117, 37.379776341574534, 31.197769505637034, 25.767467430659703, 15.788610526493617, 11.330080900873456, 7.000624920640673, 3.7977967602866034, 1.770525417157582, 0.4906805359891483, 0.08125821900154863, 0.009792066079431345, 0.019642121457893933, 0.016345199530145953, 0.08794417737850121, 0.035069699066558054, 0.03484258661046624, 0.02715835055070264, 0.03031114994415215, 0.027234407540942942, 0.04784890530364854, 0.013619799166917801, 0.04069497828770961, 0.02889997691714338, 0.0584090475791267, 0.030914618633687496, 0.05064113797353847, 0.028355645947158337, 0.04441907363278525, 0.023607834641422545, 0.046954141530607424, 0.05035696750772851, 0.034662008085953336, 0.01833985499771578, 0.019950926137555922, 0.01359066881039845, 0.011899682360568216, 0.0482789675838181, 0.0298168745024928, 0.025445283723196814, 0.048483226980481825, 0.010394543259670692, 0.012437120262932564, 0.05820591455059392, 0.028672976419329643, 0.03457400548670973, 0.009591996636507767, 0.021066678588145545, 0.02140092324199421, 0.030967934522777796, 0.09242759751422064, 0.054821660076933246, 0.07459158530192715, 0.07628284740660872, 0.0933517554242696, 0.05071420601702162, 0.005893554580065289, 0.020095228483634334, 0.04944276370640312, 0.038670799761478386, 0.07301642053893634, 0.03909760168088334, 0.004705179798682886, 0.08644674558724676, 0.029109871547136987, 0.08630727949951376, 0.1055717436330659, 0.027191430829199295, 0.06118826594735895, 0.06155964851911579, 0.03336451003061874, 0.04594581813684531, 0.01997944835706481, 0.061352742835879326, 0.03521282924339175, 0.08341178737048592, 0.029054207926882163, 0.06085044371762446, 0.014764642110094428, 0.11311330752713339, 0.03882232341649277, 0.08176750703049557, 0.06035811906414373, 0.021697792490678172, 0.05035668930837086, 0.017198157064350586, 0.04415294202044606, 0.01355903550782906, 0.07150761650076934, 0.032188571523875, 0.03427738051063248, 0.03953155196670975, 0.04787210102326103, 0.035063358156808784, 0.040902280913931985, 0.05490686711190002, 0.09904990252107382, 0.03588538297585078, 0.0418370511116726, 0.025257448266659464, 0.02193865885159799, 0.05713084366704736, 0.01693176760870431, 0.005556644979930882, 0.10021924906011138, 0.037139600675020895, 0.06541952211409807, 0.04489379708788224, 0.06130791881254741, 0.023149036403213228, 0.02592655334488622, 0.010845242334263665, 0.0405663144774735, 0.01698869330409382, 0.03125364187040499, 0.01871894233460937, 0.05490345747343131, 0.04397973917158587, 0.004059050340271954, 0.017005821224302053, 0.027231347348008837, 0.033013510650822094, 0.0043189250115704325, 0.07485253629939896, 0.04667451385674732, 0.050946868889565976, 0.054162500625742335, 0.01969275713366057, 0.03522290209574359, 0.03347260065908943, 0.07184970671577112, 0.028161956429747597, 0.06474109566105263, 0.06339393902037825, 0.041702531544225555, 0.024683621379413774, 0.0057043438178620166, 0.058238077110477855, 0.014674122145931636, 0.02146559441462159, 0.0004841998857695476, 0.05755581693457706, 0.004600228666926601, 0.070782147214881, 0.01855898618565074, 0.07346506789326668, 0.04297172451125724, 0.31103279867342537, 2.2621306606701443, 4.103284299373627, 9.2030497108187, 10.14752789906093, 18.75335475376674, 22.674575839723857, 27.05134688104902, 34.19431216376168, 39.59400394984654, 44.54973016466413, 45.67717266082764, 49.44477776118687, 51.76007386616298, 54.603881222861155, 51.15154021126883, 51.587532724652974, 50.40960461752755, 52.63106877463204, 56.234008516584126, 54.45821918760027, 53.31342356545584, 51.92064673560006, 49.894885540008545, 48.79124757221767, 50.41439192635672, 49.84838819503784, 45.249938351767405, 42.94925083432879, 42.97807196208409, 43.651411465236116, 38.75749295098441, 30.300621577671595, 21.949223858969553, 15.038715771266393, 9.983811838286263, 6.28965527670724, 2.918297039610999, 0.8842733502388, 0.18982652255467006, 0.03455042300213661, 0.045682424413306374, 0.01765421571742211, 0.029154424156461443, 0.02230881666764617, 0.017796689411625266, 0.03772494230153305, 0.011117690259457698, 0.05723281390964985, 0.05469295894727111, 0.035682731707181246, 0.11881574296525546, 0.01141587841058416, 0.01770155201666057, 0.0544957664928266, 0.013892150400871677, 0.0322475599657212, 0.06563828180411033, 0.0330741004353123, 0.008418879139104059, 0.058108789048024585, 0.02697153459303081, 0.060405426525643895, 0.026510025607421994, 0.04122876821617995, 0.02933459895263825, 0.06615938312773194, 0.007670328636387629, 0.047363359215004106, 0.024194077023171952, 0.025102952628263404, 0.05542037562866296, 0.05284010712057352, 0.015994790475815535, 0.03505732258781791, 0.02021313412114978, 0.052948075612740855, 0.030878954833107333, 0.12981589484427655, 0.1097381997055241, 0.04977103216307504, 0.015694299546469535, 0.04305027172501598, 0.03266532379867775, 0.024368601318980967, 0.04654105280392936, 0.04926192055323294, 0.03240517686520304, 0.08011547103524208, 0.05786507284002645, 0.0198276651624058, 0.06296973928276982, 0.042027275011475594, 0.03309474825592978, 0.05199630811278309, 0.020387027379391447, 0.03893072956374713, 0.029816915214593922, 0.01745160007184105, 0.01961151952855289, 0.015246905785586153, 0.0325994312630168, 0.08107873291841575, 0.019935397863654152, 0.14703233673104218, 0.12319700286856719, 0.15465303137898445, 0.14288008239652428, 0.18906413417841705, 0.10180529073945113, 0.15578551989580902, 0.13822450435587338, 0.13300211887274468, 0.08282891900411674, 0.06722904608717986, 0.09147910733840295, 0.24227860942482948, 0.16678673028945923, 0.1075837831678135, 0.13749763050249644, 0.08290612950388875, 0.1679626043353762, 0.08500124208096947, 0.1324949546584061, 0.11898794158228806, 0.1390808698322092, 0.21222651058009692, 0.06897470634430647, 0.08503128082624503, 0.15735064234052384, 0.1504728349723986, 0.06186419539153576, 0.09263026235359055, 0.26989702028887613, 0.12714535742998123, 0.2035061413688319, 0.08496842812746763, 0.18575471533196314, 0.16612055817885057, 0.10690558063132422, 0.1114589577274663, 0.14775712069656166, 0.09987998833613736, 0.16465177413608345, 0.09713479171374015, 0.1225388374711786, 0.11809824646583625, 0.1364886217883655, 0.13122395000287465, 0.12017335583056722, 0.13008915446698666, 0.19715985762221472, 0.14149257327829087, 0.12866357953420707, 0.18870483631534235, 0.06567496340721846, 0.09922169401709523, 0.10443491249212197, 0.10158393904566765, 0.16397619753011636, 0.1074232349970511, 0.1618492752313614, 0.0903020187148026, 0.09658719359764031, 0.17342000720756395, 0.11504753945129258, 0.11540653875895909, 0.1473495111401592, 0.1479590662888118, 0.09107546042650938, 0.14292227370398386, 0.0978046211280993, 0.12981643767229148, 0.05989608421389546, 0.22879706855331147, 0.1751086094549724, 0.4058761979852404, 2.4978971523897986, 4.123072334698268, 8.721645508493696, 10.874133161136083, 17.8803448677063, 22.448281696864537, 28.33023578780038, 36.49609054837908, 41.868173667362754, 47.16887099402291, 51.48340007237026, 55.490485259464805, 58.478450366428916, 61.240741457257954, 57.38466147014073, 61.206181117466514, 58.38972187042236, 60.77359322139195, 62.65151064736502, 61.41988686152867, 62.9227613721575, 60.683155468532014, 59.05974360874721, 57.67668036052159, 59.522556168692454, 59.669329915727886, 54.180214813777376, 49.58300869805472, 49.677941935403005, 51.126495429447715, 45.47940608433315, 37.05822760718209, 24.37988611630031, 16.84057821546282, 10.195347138813563, 5.6897165434701105, 2.5977295211383273, 0.7114952643002782, 0.36011362501553124, 0.10151215004069464, 0.16028419349874767, 0.1393414679914713, 0.12957839401704924, 0.1002816471404263, 0.16069557570985385, 0.14078628617737973, 0.10227043328008481, 0.14574583433568478, 0.10503147369516747, 0.10594883946967976, 0.1940431562917573, 0.13946489351136343, 0.18135807982512883, 0.18314711882599763, 0.10330697694527251, 0.08925968036055565, 0.16702010562377317, 0.08932261448353529, 0.12207558804324695, 0.11549208845411028, 0.07041681717549052, 0.09089710071150746, 0.1744277538465602, 0.12920697751854146, 0.12297908456197806, 0.14944570937326976, 0.05206662808944072, 0.1370158027857542, 0.11458438501826354, 0.09476079445864473, 0.09708510937967471, 0.14275563907410416, 0.10763211521719183, 0.17521869497639792, 0.14230115631861345, 0.16323350024010452, 0.11414922694010393, 0.18898317137999193, 0.17982034305376665, 0.11274057467068944, 0.11599344440868922, 0.14770266147596495, 0.2035924917353051, 0.11870078556239605, 0.11967669533831732, 0.13252700865268707, 0.1271042517785515, 0.16976380268377916, 0.1239006979657071, 0.09871180209198169, 0.11951141777847495, 0.17018625858638967, 0.18252689710685185, 0.17094002956790583, 0.2212691974959203, 0.08842099750680582, 0.23755255873714173, 0.13395585412425653, 0.15576569310256413, 0.13294379200254167, 0.09351673442870378, 0.1606421885745866, 0.12249110931796686], [0.08120775635221175, 0.03212461620569229, 0.015535619043345963, 0.022814213298261166, 0.033914489804634025, 0.03520455790151443, 0.03868018729346139, 0.11848030239343643, 0.01591956808364817, 0.025701001519337296, 0.04533886177731412, 0.03133120860106178, 0.03371503104322723, 0.037318951051150046, 0.07911638928843395, 0.022904729869748865, 0.027801410062238574, 0.02220121628072645, 0.06220689628805433, 0.028470650847469057, 0.038458503117518764, 0.09426102627600942, 0.018373800408361212, 0.014470941619947553, 0.014377123975594128, 0.018150657382128493, 0.016639393654518893, 0.04483099188655615, 0.04608939953946641, 0.04110476594152195, 0.026748907253412262, 0.03403934703341552, 0.09965020245207207, 0.05968178249895573, 0.09913457690605096, 0.07064354965197188, 0.011047727361853634, 0.023092867274369513, 0.012029701544504081, 0.019041037818949138, 0.005684471647587738, 0.04206524922379425, 0.008064419230712312, 0.007835998050203281, 0.006479347856449229, 0.0014525774458888918, 0.053448987126882584, 0.08153314103505441, 0.03338385167132531, 0.008959557894351227, 0.02453303410272513, 0.029860182000058036, 0.0409273731389216, 0.0530748666663255, 0.09199045811380659, 0.020014767801123004, 0.03651469027889626, 0.02294005949183234, 0.05174266493746212, 0.042107233578073125, 0.02718397372934435, 0.050009001179465225, 0.07975465325372559, 0.004299118150291699, 0.026918037195823023, 0.06504889950156212, 0.031014230967100178, 0.030238980959568704, 0.03263134955029402, 0.053709737956523895, 0.028375657641195824, 0.025920012267306447, 0.026045049307867885, 0.05671620448785169, 0.09070937721324818, 0.06539954604314906, 0.2690895364752838, 0.7266861977321761, 1.4287747953619276, 3.1719232244150977, 3.3145934087889533, 5.6759578074727735, 7.642361845288958, 9.578147343226842, 15.287285838808332, 16.785459893090383, 18.87310869353158, 19.277229819978984, 24.908713511058263, 23.333777495792933, 27.568758385522024, 26.16738142286028, 22.981192895344325, 29.406840051923478, 24.947614737919398, 27.311278990336827, 25.25995363507952, 27.382612671170914, 30.828358105250768, 26.1726325239454, 22.69364517075675, 20.574111086981638, 13.945464491844177, 8.380915403366089, 6.7959301216261725, 3.0240890085697174, 0.8719437175563404, 0.25756280070969034, 0.04182979417964816, 0.04345066166882004, 0.054500936929668696, 0.05392943402486188, 0.03608150673764093, 0.017620448422219073, 0.022620208262066756, 0.03203496815902846, 0.030237077668841397, 0.04088144310350929, 0.08921364175954036, 0.01014293568940567, 0.06346616228776318, 0.05201699325282659, 0.05269179632887244, 0.007825077877246907, 0.09878475817718677, 0.03305519984236785, 0.06333327120436089, 0.06314499130738632, 0.06551174859383277, 0.0164541400237275, 0.04235588273565684, 0.04978376826537507, 0.05021160834335855, 0.06926703280104057, 0.008455934784641224, 0.03379503032192588, 0.03631878364831209, 0.029278266975390058, 0.048551083875021765, 0.08767121631119933, 0.011796984389158232, 0.028966368176043034, 0.03388266311958432, 0.06955557303237063, 0.059030965635819097, 0.035311152360269, 0.02184260543435812, 0.014719897814627205, 0.009938070700237793, 0.07171140092292003, 0.015847217590947236, 0.047167150636336634, 0.034649658748613935, 0.044472996810717244, 0.03518842573144606, 0.029389522969722748, 0.08492971091930356, 0.055723402582641156, 0.031501975509205034, 0.042429768413837464, 0.043145544826984406, 0.04152840928041509, 0.07937547431460448, 0.020430348447657058, 0.050684964550392966, 0.03710418114704745, 0.04210238205268979, 0.049893796111324, 0.08740112544702631, 0.037293268500694206, 0.0005202484369095016, 0.07958812040409871, 0.037412585491048436, 0.05198307328724435, 0.06623893457331828, 0.026557989551552703, 0.04180205227541072, 0.03279709190662418, 0.04119367099234036, 0.06600073485502175, 0.05794942831354482, 0.03514395115364875, 0.04380440911544221, 0.04787033683221255, 0.02799367974512279, 0.02349514693820051, 0.011619734078911799, 0.023167699508901154, 0.023626772553793023, 0.04038976305829627, 0.07841470265494925, 0.048178391730678935, 0.03083507058077625, 0.06263018000338759, 0.03691170790365764, 0.0033815770168855253, 0.036904807202517986, 0.046515007237238545, 0.04050494098503675, 0.03656588913872838, 0.04023217669289027, 0.07176918496510812, 0.05896834363894803, 0.028134815029001663, 0.03211760015359946, 0.048688242943691354, 0.018639704711469154, 0.07780077774077654, 0.07711857863302742, 0.02664170041680336, 0.07800912191825253, 0.055426231385873895, 0.045971361587622335, 0.006802621023130736, 0.052450583915093114, 0.002162686819376956, 0.02017161456335868, 0.06796389951237611, 0.02329229380536292, 0.06529728403048855, 0.05682745708950928, 0.06187682292823281, 0.054826033235128434, 0.0759828399334635, 0.07863854457225118, 0.07765319637422051, 0.08603878319263458, 0.07332662639341184, 0.038576459645160606, 0.03978888297985707, 0.013527409838778632, 0.04348880212221827, 0.048155114586864195, 0.035695695118712525, 0.07545231375843287, 0.02503437818294125, 0.04402369467009391, 0.021162085700780153, 0.0448650543444923, 0.0469245370477438, 0.07014903333038092, 0.0303035944567195, 0.07006301544606686, 0.03240747031356607, 0.03410441514902881, 0.04100224608555436, 0.05824852654976504, 0.03791007040334599, 0.010221633877206062, 0.17807031981647015, 0.1530139214758362, 0.2751088749085154, 0.5305757895112038, 1.4686964303255081, 2.2343445973736897, 4.991791273866381, 5.880022491727557, 8.647656747273036, 11.750182015555245, 14.453324828829084, 21.336663722991943, 23.265900543757848, 24.95320803778512, 26.058732441493444, 33.087717737470356, 30.60895136424473, 34.410790239061626, 32.60973031180245, 30.291668823787145, 37.548280579703196, 33.430507114955354, 35.48511028289795, 34.401347637176514, 36.25861849103655, 36.25274726322719, 32.4864935874939, 27.99873549597604, 26.26673718861171, 18.590789488383702, 12.515881317002432, 9.672611577170235, 4.178660094738007, 1.7531348360436303, 0.49128182658127373, 0.0914611600871597, 0.05585159481103931, 0.11751374283007213, 0.0599818578256028, 0.03680611089138048, 0.041368037528757534, 0.0447544056390013, 0.044125217079584084, 0.10706808976829052, 0.02561779785901308, 0.0810830687571849, 0.04101408991430487, 0.03629820368119648, 0.022545099524515014, 0.012464611109213104, 0.025421389112515107, 0.021764804609119892, 0.01957598464962627, 0.025872999968539392, 0.0618822987058333, 0.04252084477671555, 0.05802349719618048, 0.06520687602460384, 0.062604870647192, 0.061619529234511514, 0.022973825090697834, 0.03108114469796419, 0.025229669042996, 0.03379545779898763, 0.037276691890188625, 0.015482995259974684, 0.014343616220035722, 0.061832195680056296, 0.03200250365106123, 0.014138446738278227, 0.05706493077533586, 0.08091654269290821, 0.019578907439219098, 0.06818736145006758, 0.007077978591301611, 0.022708994569256902, 0.043358509827937396, 0.048876746757222075, 0.04334223177284002, 0.023911116046032736, 0.010144451367003577, 0.04905857378616929, 0.06556949192391974, 0.04883224843069911, 0.024482680018991232, 0.02044936439155468, 0.0533582127120878, 0.038316682513271055, 0.14419644033270224, 0.042800893142287216, 0.06362588943115302, 0.05569374720965113, 0.05157302100477474, 0.042700578525130234, 0.05219968880659767, 0.054131593355642896, 0.008255617676435836, 0.05907998300556626, 0.011553560799386884, 0.02137176998491798, 0.06722403171339206, 0.020716703796227063, 0.03659991088456341, 0.10010684973427228, 0.1014445000993354, 0.08114691890243973, 0.16950943347598824, 0.10372410634798662, 0.16549204476177692, 0.12754855650876248, 0.16441518254578114, 0.1628824533628566, 0.06337922838117395, 0.11773903002696377, 0.07000673096626997, 0.1388686919318778, 0.12436735363943235, 0.15081305243074894, 0.13183260948530265, 0.13321409321257047, 0.23857891080634935, 0.1066767175548843, 0.1036713095381856, 0.14004870504140854, 0.17445467811610016, 0.07478507634784494, 0.13203844986855984, 0.10729476117662021, 0.13926264936370508, 0.1486590023019484, 0.12853995045380934, 0.17780381840254578, 0.14243020010846003, 0.08106518935944353, 0.1622546049101012, 0.20180341202233518, 0.1334888320416212, 0.2836929128638336, 0.22186009293156012, 0.1304640450647899, 0.09304092531757695, 0.13258203784269945, 0.06940518931618758, 0.21366480125912599, 0.11893515155783721, 0.13670872497771466, 0.1475880161992141, 0.1760694964655808, 0.1226872873625585, 0.22859958772148403, 0.19361611349242075, 0.17519305992339337, 0.17271929766450608, 0.11195284301148993, 0.21518169343471527, 0.15075419630323136, 0.30556139083845274, 0.17257270695907728, 0.09012519248894282, 0.15374034749610083, 0.17072429614407675, 0.25483954112444607, 0.16964877742741788, 0.2053964449358838, 0.1149073134043387, 0.14458910854799406, 0.11050773305552346, 0.1369360884917634, 0.10166779240327221, 0.15779230078416212, 0.039447875028210025, 0.12170243449509144, 0.19416062427418573, 0.11516511599932398, 0.08603535659079041, 0.11763070869658675, 0.2144637626728841, 0.28441994956561495, 0.3546568192541599, 0.5817581745130675, 1.3210962819201606, 2.280827828816005, 4.312265702656337, 5.802808029311044, 8.831773587635585, 13.163149441991534, 14.95271270615714, 21.77430295944214, 23.000468935285294, 25.287593569074357, 27.184423991612025, 35.33438995906285, 34.90525531768799, 36.743627071380615, 36.9600704056876, 32.72949641091483, 39.16176693780081, 35.647187437329976, 41.477952412196565, 41.186114174979075, 39.196969985961914, 41.06890501294817, 37.2180118560791, 31.89595229285104, 28.783906255449565, 20.923562049865723, 14.987684726715088, 10.22892083440508, 3.9528019513402666, 1.4298114883048194, 0.42043487248676165, 0.16513383255473205, 0.14808398458574498, 0.206867088164602, 0.1344892912145172, 0.16873574070632458, 0.15810924449137279, 0.11136263968156916, 0.1189767728958811, 0.18142924457788467, 0.09641782447163548, 0.2655878886580467, 0.15133050323597022, 0.16057744276310715, 0.1455099619925022, 0.17786745141659463, 0.10246779876095907, 0.1673054431698152, 0.12150849561606135, 0.1732625870832375, 0.16548249098871434, 0.11223282691623483, 0.1118578277528286, 0.21298777258821897, 0.259366971041475, 0.21707959659397602, 0.1220301261969975, 0.08121281143810068, 0.158547008144004, 0.04977090324142149, 0.09529830275901727, 0.11392053349741868, 0.1284074325646673, 0.15820760492767605, 0.13715273115251744, 0.13500223654721463, 0.11240528337657452, 0.1544487244848694, 0.1120179213051285, 0.20476236753165722, 0.12726412819964544, 0.12856816393988474, 0.12402017441179071, 0.1649114494877202, 0.17449192968862398, 0.2620066893952233, 0.16995704945709023, 0.23506909342748777, 0.12928675966603415, 0.14428085008902208, 0.15872483860169137, 0.14404957821326597, 0.10462984881762948, 0.22966939317328589, 0.21651470262025083, 0.20969917119613715, 0.1591243871620723, 0.1676039578659194, 0.17003486385302885, 0.13599379334066594, 0.14684478965188774, 0.22721020584659918, 0.09987493325024843, 0.16596510580607823, 0.12152027498398509, 0.079666796539511, 0.1930023514266525, 0.08975668012031487, 0.1528735597218786], [0.042767668675099096, 0.066046990587243, 0.014966002465890986, 0.012817295800362314, 0.027408017510814325, 0.09583758203578846, 0.0297502559343619, 0.021453253558969924, 0.04100446828774043, 0.030217495148203204, 0.021562658849039247, 0.0353897708202047, 0.018581747642851303, 0.05473725710596357, 0.0390886823380632, 0.02489476281750415, 0.02211036892341716, 0.0028382869620275286, 0.010073730206516172, 0.039756472754691324, 0.023636097321286798, 0.017582648932667713, 0.02806113121498908, 0.05314254714176059, 0.07387151036943708, 0.028548271860927343, 0.028878409681575637, 0.03112917479925922, 0.009436680818907917, 0.031918107465441735, 0.049327595957687924, 0.018358031254527823, 0.012400198628061583, 0.09750518362436976, 0.01937055478005537, 0.022334738401696086, 0.02880380814895034, 0.024367571642090167, 0.06531038654169866, 0.03407870884984732, 0.025220293385375823, 0.0940746869891882, 0.019245823080252324, 0.006882003683131188, 0.04916879840727363, 0.0614975422088589, 0.04244715587369033, 0.05034139852172562, 0.007160411266210888, 0.08147273784769432, 0.054719011299312115, 0.02680734608189336, 0.06942913481699568, 0.020362652705184052, 0.02710916524353836, 0.0454849130474031, 0.026898933042372977, 0.034298744185694625, 0.03911912141899977, 0.031975470815918276, 0.06871818618050643, 0.013207661237434616, 0.03442646483225482, 0.029535455496183464, 0.0349965801329485, 0.04753448574670723, 0.020414793032354543, 0.03731031669303775, 0.01070047858437257, 0.03179631042959435, 0.014001331774384847, 0.05125996869589601, 0.023579522767769437, 0.038074571040592024, 0.01939486668977354, 0.03355094770501767, 0.036874385084956884, 0.049919563478657177, 0.03190956131688186, 0.051769422965922525, 0.06873142439872026, 0.23184002669794218, 0.15115101715283735, 0.5049899710076196, 0.582883456987994, 0.9476608974593026, 1.5506326279469898, 2.264751217194966, 2.4912010431289673, 2.603385789053781, 2.9733947345188687, 3.215398971523557, 3.5255507060459683, 3.460482129028865, 4.758425601891108, 5.867724180221558, 5.001096648829324, 4.678228625229426, 7.650658862931388, 4.897637971809932, 4.958133765629359, 1.7642327376774378, 0.788171512739999, 0.25697904346244677, 0.09897920595748083, 0.03901994674067412, 0.013387753761240413, 0.03390277150486197, 0.037146128181900294, 0.021670788493273512, 0.02045225495073412, 0.06384194855179105, 0.039177923263715844, 0.03995710198900529, 0.04026705000017371, 0.016166352966268147, 0.022979965832616602, 0.016382128798535893, 0.09030386433005333, 0.03454417708728995, 0.04035664715671113, 0.05273410637996026, 0.0634319641228233, 0.03732023348233529, 0.04143973493150302, 0.05194359951253448, 0.03621083551219531, 0.03250136938212173, 0.023126451365117515, 0.027407018367999365, 0.01371463037295533, 0.007591526971996895, 0.027537151206550852, 0.04993334113221083, 0.024285024464396492, 0.0235005463806114, 0.04364268707909754, 0.04110034867855055, 0.04975993472284504, 0.025955184129998088, 0.0039172301601086345, 0.028928743409258977, 0.03864007569583399, 0.022648109622033577, 0.07450584561697074, 0.04491424474066921, 0.08674209831016404, 0.016575251739206057, 0.025893747873072113, 0.04545784289283412, 0.04986180318519473, 0.015110552477251207, 0.011494130461609789, 0.031213146900492053, 0.01811184178638671, 0.12695790534572943, 0.02646261466933148, 0.024865407696259872, 0.02277178959255772, 0.07183764914848975, 0.05451142029570682, 0.0411117718155895, 0.05716295872947999, 0.059187544376722405, 0.03687910090333649, 0.026503253827935884, 0.027704481334824647, 0.0830610254779458, 0.022843441194189445, 0.03104881928967578, 0.06073210721037217, 0.04523042170330882, 0.05101907180090036, 0.027106551187379018, 0.02016630333050021, 0.06269678500081811, 0.03741392220503517, 0.03528890658968261, 0.045300863816269805, 0.05392255707244788, 0.031006604233490567, 0.056935880200139115, 0.04674670659005642, 0.016482389132891382, 0.03541493768404637, 0.07300867845437356, 0.007683160581759044, 0.03326027687372906, 0.019287561465586935, 0.05424679163843393, 0.045361979465399466, 0.03699519485235214, 0.0278372655489615, 0.061581816258175034, 0.03856907379148262, 0.04829531009974224, 0.05493685496704919, 0.020142634332712208, 0.06105375995061227, 0.054572566478912315, 0.03734938673941152, 0.041098221471267085, 0.02103958129217582, 0.037039347126015594, 0.04565231781452894, 0.0700561690277287, 0.01843415100925735, 0.04009361984208226, 0.04362506891733833, 0.036057422137154, 0.020658707711845636, 0.037913815916648934, 0.04106406062575323, 0.034095180287425, 0.07164180358605725, 0.038417407644114325, 0.029222304799727032, 0.04120482950072203, 0.030101424947913204, 0.016169328342324922, 0.04889139972094979, 0.018538289171244417, 0.08134454222662107, 0.029962172598711083, 0.04222825708399926, 0.05771698257220643, 0.06894153276724474, 0.01564931946008333, 0.07043655575918299, 0.03925261300589357, 0.05255815885694964, 0.029646748809942176, 0.06176414540303605, 0.014146695179598672, 0.04977949010208249, 0.029614399652928114, 0.06642422891621079, 0.05314679816365242, 0.0682585940563253, 0.01532728165122015, 0.02600503949049328, 0.023689425084739923, 0.026214350580370853, 0.02420076398578073, 0.03327514357598765, 0.035843880381435156, 0.0306816741691104, 0.02072667995733874, 0.04478449866707836, 0.08225218459431614, 0.04387166889916573, 0.012656551702613277, 0.037954127682106834, 0.08951757795044354, 0.05091331194021872, 0.05556196553100433, 0.20123617031744548, 0.26711866366011755, 0.34287780416863306, 1.035130249602454, 1.2226707062550952, 1.9362482045378004, 3.021520346403122, 3.6345353722572327, 4.679929631096976, 4.425147005489894, 5.513679155281611, 5.669317500931876, 6.54895727123533, 6.418876137052264, 7.54889988899231, 9.034376978874207, 7.362773282187326, 7.057221906525748, 10.453064509800502, 7.8208141667502264, 7.035188734531403, 3.132285705634526, 1.5150833640779768, 0.5017887513552393, 0.25760451704263687, 0.06856561758156333, 0.014514908992818423, 0.070491171042834, 0.051346892424459965, 0.02031495508604816, 0.03780044289305806, 0.015457392437383533, 0.059501665378255506, 0.035525752630616934, 0.08224655953901154, 0.03693218269784536, 0.029553406140101806, 0.03811631451493927, 0.1332076471298933, 0.003189738839864731, 0.05839341413229704, 0.06995694006660155, 0.015433292569858688, 0.0243474479897746, 0.07154311745294503, 0.06158270513904946, 0.017122237477451563, 0.0664693039974996, 0.018626144189121466, 0.010409262380562723, 0.022814337130902067, 0.03723712990592633, 0.04371994507632085, 0.02955327382577317, 0.061105742518390925, 0.04145984670945576, 0.013276168677423681, 0.05762191981609378, 0.03917201661637851, 0.0121154887269118, 0.029384824114718607, 0.024202628260744468, 0.01993564552893596, 0.07188946886786393, 0.044088087643363645, 0.11878068984619208, 0.03219960789595332, 0.027898442266242843, 0.023232772713527083, 0.04962593084201217, 0.055059418747467656, 0.04957211622968316, 0.015067163555483733, 0.032222254002200704, 0.007903324839259897, 0.04237771120720676, 0.08555277570017747, 0.10190619568207435, 0.019927046793912138, 0.028070131982011453, 0.039509014426065345, 0.025730848578470092, 0.04531346421156611, 0.08756057439105851, 0.0554709129168519, 0.03766697505488992, 0.03972825926861592, 0.05482948019302317, 0.04156000865623355, 0.012819288148810821, 0.017431793634646704, 0.04560256762696164, 0.026930751245734946, 0.029887062164821794, 0.022400133910455873, 0.014980882738849946, 0.08269188885710069, 0.17758664648447717, 0.15240387778197015, 0.0873721723577806, 0.10625592406306948, 0.12716282292136125, 0.1803971521024193, 0.12901672987001284, 0.1647887703563486, 0.11863705755344459, 0.1522362253495625, 0.10825525463691779, 0.07805442770144769, 0.1621681595487254, 0.18585751338728837, 0.08122013961630208, 0.0975012481212616, 0.13090069591999054, 0.2098006121814251, 0.15663387865892478, 0.14517715413655552, 0.1046833513038499, 0.15102626170430863, 0.16686995939484664, 0.14829806238412857, 0.24317693550671848, 0.16241969248013838, 0.16706212051212788, 0.09513303876987525, 0.18367529048451356, 0.17494850233197212, 0.12713003610926016, 0.10482024574386221, 0.22735157183238439, 0.27450128751141684, 0.11957154955182757, 0.09202070041958775, 0.0984714717737266, 0.20360290046249116, 0.06727493541049105, 0.11570308570350919, 0.2527424065130097, 0.08688033624951329, 0.06504115741699934, 0.10392234035368476, 0.23795335580195698, 0.14607961928205832, 0.1313068534114531, 0.1439873022692544, 0.1459888584379639, 0.11168897431343794, 0.26779660156794954, 0.14692643098533154, 0.14952623790928296, 0.11649984866380692, 0.13377434600676807, 0.10233465661959988, 0.06638013092534882, 0.0957716487880264, 0.1653657015413046, 0.1784091666340828, 0.10365322657993861, 0.19668347175632203, 0.13870516499238356, 0.0842554099591715, 0.15967731177806854, 0.11249323508569173, 0.17867927785430635, 0.06773534177669457, 0.09853536263108253, 0.08382838751588549, 0.12539006876094, 0.18676520325243473, 0.12854320742189884, 0.10163513451282467, 0.06939246678458792, 0.12706645737801278, 0.21114948551569665, 0.11579494577433382, 0.16241708690566675, 0.1917068109448467, 0.34669279945748194, 0.5345099355493272, 1.1159323709351676, 1.1921517210347312, 1.5916278681584766, 2.7471715935638974, 3.1449034171445027, 4.521729137216296, 5.030290807996478, 4.959169915744236, 5.128923526832035, 5.7718129839215955, 5.430873130049024, 6.877752976758139, 9.082764233861651, 8.330239585467748, 7.43703476020268, 10.207965935979571, 8.25115258353097, 7.092829252992358, 3.58517558659826, 1.962414686168943, 0.8117449592266763, 0.35928282673869816, 0.10338914753603083, 0.09487409623605864, 0.14280504999416216, 0.10772295748548848, 0.08962717492665563, 0.10049373683120523, 0.13216711367879594, 0.2201521388654198, 0.10146134812384844, 0.1486003225935357, 0.17549907921680383, 0.15980548704309122, 0.18123502071414674, 0.24008710416299955, 0.13649976333337172, 0.1856764666736126, 0.11721780656703881, 0.13445472664066724, 0.11553543327110154, 0.1617515254765749, 0.09218352846801281, 0.08366986137947865, 0.26978810184768265, 0.09941863202090774, 0.10599970924002783, 0.07035973880972181, 0.11658253494117941, 0.09543565860284225, 0.22711727369044507, 0.1538467417870249, 0.12579709477722645, 0.11782913947744028, 0.12203475380582468, 0.08430106858057634, 0.20513196555631502, 0.14033522323838302, 0.04928970656224659, 0.09463683968143803, 0.1904560944863728, 0.08273289272827761, 0.18334557674825191, 0.16379270809037344, 0.08719438261219434, 0.07608546156968389, 0.16819701104291848, 0.13562082978231565, 0.1401834756668125, 0.11984793043562345, 0.21134920551308564, 0.06558038919631924, 0.15529383985059603, 0.19642090584550584, 0.14440808897571905, 0.09829818750066416, 0.1551289829824652, 0.19021305681339332, 0.0849794407508203, 0.196308771148324, 0.25359149809394566, 0.1945563866091626, 0.12937545776367188, 0.12467084878257342, 0.20491677496050084, 0.12533294968307018, 0.11913401660110269, 0.11317361571959086, 0.14082714755620274, 0.13160668446549348, 0.09694811994475977, 0.11147379728832416, 0.10132228915712663], [0.023089430494500057, 0.04313999441053186, 0.027004504609586935, 0.012908264445806188, 0.05682214416031327, 0.058646168426743576, 0.027813050330483487, 0.00960632729610162, 0.023859311593696475, 0.021455869311466813, 0.042570866378290315, 0.02115348187674369, 0.015565878312502588, 0.04388285115627306, 0.08412776395146336, 0.04636379231565765, 0.02615854107508702, 0.06693581717887095, 0.025650784838944674, 0.09804857482335397, 0.024752163594322543, 0.02679814345070294, 0.020557047899014184, 0.030867233140660182, 0.033105201087892056, 0.04439602040552667, 0.010698456550017, 0.03348196444234677, 0.04175912815013102, 0.021059984840186577, 0.022099169702934365, 0.04040588505033936, 0.04832998323919518, 0.015529306971334984, 0.0230429966468364, 0.027539178329919065, 0.03596924990415573, 0.033496454557670016, 0.03953672240355185, 0.00645377132709005, 0.012401539582892187, 0.06535172968038491, 0.05495722798098411, 0.009857991693674453, 0.04395870797868286, 0.1196835892541068, 0.12541821439351353, 0.00671411758022649, 0.022761670939092125, 0.040907162973391156, 0.060913506762257645, 0.07022555850978408, 0.018012024196130887, 0.03243580593594483, 0.06562435148017746, 0.004742033580052001, 0.02157310998466398, 0.07260232418775558, 0.025875488495720283, 0.038106411296342096, 0.05945800843515566, 0.022916697531140277, 0.010810878776412989, 0.023501097690314054, 0.022768759933699454, 0.06461723587874856, 0.06490950805268117, 0.042781924695840905, 0.02091515832580626, 0.026446492677288394, 0.03706135880202055, 0.07501229058418955, 0.05345196928828955, 0.02515964931808412, 0.01968393787475569, 0.028049117752483914, 0.016536931474027888, 0.05926675655479942, 0.08904154492276055, 0.03640794993511268, 0.05476288876629301, 0.07330449936645371, 0.05281570360862783, 0.04265995463356376, 0.046346896793693304, 0.013968578040865915, 0.02274791873060167, 0.09245945473334619, 0.004059767466969788, 0.046937388500997, 0.016529452321784835, 0.007022498175501823, 0.051192654629371, 0.07381551765969821, 0.07063575328460761, 0.058396582890834124, 0.12432525732687541, 0.2131349875458649, 0.07343666441738605, 0.2150680659604924, 0.032588157403681955, 0.017509762397302047, 0.020791435946843455, 0.03455687587016395, 0.04072115956140416, 0.01822874997742474, 0.02177558822690376, 0.03526369562106473, 0.018048051012946025, 0.05222244008577295, 0.031769050285220146, 0.03230068925768137, 0.02226710203103721, 0.09000802306192261, 0.07790457324257918, 0.01563216439847435, 0.034724809894604344, 0.03920874910961304, 0.044534170135323486, 0.04561170070831265, 0.02100551883423967, 0.019110716580014144, 0.0310592008754611, 0.04623813441555415, 0.043928882971938164, 0.08639415233795132, 0.008660585187109453, 0.04003453979800854, 0.04333937853308661, 0.05199070680620415, 0.04706097347661853, 0.046811649176691256, 0.023821208459724273, 0.037217591490064345, 0.013365176356663662, 0.03837391354941896, 0.015687968814745545, 0.0049226744449697435, 0.07312966124819857, 0.015585043534104313, 0.039412421573485644, 0.018965270902429308, 0.05680850560643843, 0.023736096419660107, 0.015158742034275616, 0.038067721229578765, 0.019410859760163084, 0.01945210451127163, 0.04451975126617721, 0.03110819449648261, 0.042804804896669726, 0.03550071468842881, 0.04636690679139324, 0.042680850119463036, 0.04662063139091645, 0.07999967903430973, 0.0820465749129653, 0.09970937070569821, 0.006510597786733082, 0.012889395235106349, 0.0399035825394094, 0.013969982608354517, 0.016647010210103223, 0.0036828624683299233, 0.03771846568478005, 0.055390727041023116, 0.022119837879602398, 0.027666564797982574, 0.028309810906648636, 0.011025830188633075, 0.03620720534984555, 0.042832061648368835, 0.031420361317162, 0.0047232161076473335, 0.05103262893057295, 0.019177676111991917, 0.015210731387404459, 0.06378751647259508, 0.03904827557770269, 0.01644278474019042, 0.007677621191500553, 0.024710716979045953, 0.05863850776638303, 0.03911324191306319, 0.07323465775698423, 0.03267265536955424, 0.0031306488298079266, 0.03594423231801816, 0.02771986202735986, 0.03480114847687738, 0.07449031395039388, 0.07670518117291586, 0.020900233948071088, 0.07436758732157094, 0.05085575181458678, 0.040069752372801304, 0.04158742147098694, 0.08437527995556593, 0.005037122522480786, 0.014305148373490997, 0.02148363666076745, 0.01925009785086981, 0.044865780376962254, 0.03593489567616156, 0.01949975802563131, 0.022630311648494432, 0.06114485327686582, 0.01495021634868213, 0.036268334569675584, 0.012342738586344888, 0.042538893808211596, 0.07440985326788255, 0.017466873895110827, 0.010451565646300358, 0.05641125049442053, 0.016266986494883895, 0.04875093957941447, 0.09848214512956993, 0.05584367291469659, 0.031546911490815024, 0.062097394306744845, 0.04114362903471504, 0.05635638415281262, 0.015640467970765064, 0.043919173135821304, 0.0018130088865291327, 0.08090920094400644, 0.035917979798146656, 0.04815157263406685, 0.03904743419427957, 0.020152417111343572, 0.012552562818330313, 0.04279874897162829, 0.05657389873106565, 0.006479316898289004, 0.026736311947128603, 0.06139383491660867, 0.04461727371173246, 0.03103078043620501, 0.038813125874314985, 0.02236862783320248, 0.02559406270406076, 0.03396351056705628, 0.07499787171504327, 0.03592968113454325, 0.049362951024834595, 0.059646424039133956, 0.03563643526285887, 0.08614664990454912, 0.035412403355751715, 0.014761157832773668, 0.05094592911856515, 0.05019106908834406, 0.027084939847035066, 0.021184338256716728, 0.02169170942423599, 0.021926918499437825, 0.019558371576879705, 0.011585361191204615, 0.033293240104935, 0.017573677003383636, 0.060271476927612505, 0.042050514835864305, 0.08294545739356961, 0.026745667248698216, 0.027896805300510356, 0.023020111356994936, 0.05630809281553541, 0.04919940372928977, 0.07294066888945443, 0.1127811171380537, 0.08405442110129765, 0.1712461302855185, 0.4102572543280465, 0.21796576332833084, 0.310105349868536, 0.1781880185008049, 0.021636488548080837, 0.007771031714842788, 0.06635329486536128, 0.027571647926898937, 0.02711583354643413, 0.010014835063235035, 0.015810247610456178, 0.028182595768677335, 0.09061792426343475, 0.004025428081929151, 0.026569117525858537, 0.02678780596969383, 0.04749465234843748, 0.028522022733730928, 0.027836244353758435, 0.02288708965560155, 0.03838559452976499, 0.027772392512166073, 0.027595456024365764, 0.03283848932811192, 0.020672042621299624, 0.05024280059816582, 0.04421280577246632, 0.01868708341914628, 0.025723016588017344, 0.021848666448412195, 0.008756753107133721, 0.05008072911628655, 0.03375788392232997, 0.11189583928457328, 0.044015687956873856, 0.08704076906932251, 0.022898986070816005, 0.07314322516322136, 0.014053688384592533, 0.025288922113499472, 0.015919093109135116, 0.032665849663317204, 0.024800680544493452, 0.05145636047901852, 0.05408052681013942, 0.027390021065782224, 0.031180767209402153, 0.01175673199551446, 0.03667058030675564, 0.011264443813290979, 0.01040775009563991, 0.018860793472932916, 0.05303685513458081, 0.01337587006855756, 0.04223065909796527, 0.03806284934814487, 0.013328588052120591, 0.07727504202297755, 0.03136347294119852, 0.03636499527575714, 0.08554400902773653, 0.027970986141424094, 0.019633956985282044, 0.02345828552331243, 0.023322839755564928, 0.029072606403912817, 0.007370995457417199, 0.02785154531842896, 0.04403968095513327, 0.03611760140795793, 0.06652725767344236, 0.006484922021627426, 0.040150959443833144, 0.020389137623299445, 0.03468131919258407, 0.029293435625731945, 0.030854269729128907, 0.045379621375884326, 0.02997720893472433, 0.07620522300047533, 0.12387446580188614, 0.09203019312449864, 0.10222781449556351, 0.10860085966331617, 0.23025160336068698, 0.18955042665558203, 0.122214728434171, 0.13445712865463325, 0.14512314274907112, 0.11769488453865051, 0.1588953680225781, 0.12741574006421225, 0.097218801134399, 0.21440820422555718, 0.18723800645342895, 0.17471508628555707, 0.23366756577576908, 0.09996262033070837, 0.17673541073288235, 0.1365441938063928, 0.16717909994934285, 0.083768988560353, 0.08778765970574957, 0.20022062052573475, 0.09307265361504895, 0.2038997731038502, 0.10308514349162579, 0.14283969599221433, 0.09072264257286276, 0.14145838868405136, 0.12707161424415453, 0.18321498589856283, 0.08331057708710432, 0.11161924126957144, 0.23945454667721475, 0.09363617016268627, 0.11055432126990386, 0.12340111977287702, 0.167602451518178, 0.1521017397088664, 0.2366323566862515, 0.09640601796231099, 0.15811304428747722, 0.10466030146926641, 0.18249143686677727, 0.2201816958508321, 0.0655069106391498, 0.07505350480122225, 0.0796774902514049, 0.18364505496408257, 0.1354433928749391, 0.16612652928701468, 0.10559954999813012, 0.16706384399107524, 0.12681575225932257, 0.16274043598345347, 0.21123954068337167, 0.10142904985696077, 0.11230158286967448, 0.15526877476700715, 0.1119487446599773, 0.14090873460684503, 0.08842032575713736, 0.10671833889292819, 0.15734583831259183, 0.1233408794339214, 0.1637401623385293, 0.13501624150999955, 0.15413783331002506, 0.17053563626749174, 0.13317726233175822, 0.2353069878050259, 0.14460550195404462, 0.06998119769351822, 0.1097418637946248, 0.08313327588673149, 0.11396642960608006, 0.1268807016313076, 0.1317026564585311, 0.16642247912074837, 0.13344806565770082, 0.09933485330215522, 0.12334967324776308, 0.15203050710260868, 0.1151181613760335, 0.09814531356096268, 0.18414646520146302, 0.09528752762292113, 0.12049473715679986, 0.13523187993892602, 0.1555716727993318, 0.10519395569073302, 0.14151185724352086, 0.3012363000639847, 0.166061810616936, 0.15662641477371964, 0.4682624989322254, 0.3199448947395597, 0.49368052929639816, 0.14646775488342556, 0.1356763339468411, 0.13024181127548218, 0.16543910545962198, 0.1483236431543316, 0.17040987658713544, 0.05899053851940802, 0.11378260768417801, 0.11538336000272206, 0.11705482245555945, 0.08369048205869538, 0.10524777030306202, 0.10445218120834657, 0.10854652257902281, 0.10601601443652596, 0.10145685622202498, 0.04683486864502941, 0.0839794904791883, 0.1306479959083455, 0.14376770119581903, 0.11005578802100249, 0.10170438579682793, 0.1767155567982367, 0.13570453386221612, 0.10188074383352484, 0.1435536912509373, 0.07102566664772374, 0.13653886052114622, 0.09013066826654331, 0.09791520198008843, 0.17416339660329477, 0.15712489373981953, 0.10639172606170177, 0.07278318091162614, 0.08403409219213895, 0.08310447207518987, 0.10189819575420447, 0.060977241556559286, 0.14415404546473706, 0.147964603134564, 0.08923117510442223, 0.15727255653057778, 0.1391626333019563, 0.07122161399040904, 0.08473024197987147, 0.11629392685634748, 0.0855836286874754, 0.11924239221428122, 0.08373614068010024, 0.12244510464370251, 0.05896305785115276, 0.08375858661851712, 0.14857896231114864, 0.08796901176018374, 0.1949614313031946, 0.17617521222148622, 0.16216976089136942, 0.32255242339202334, 0.10676447927419629, 0.08598321117460728, 0.16105978616646358, 0.05730268266052008, 0.08497809725148336, 0.10636805197490112, 0.1297246047428676, 0.14340716839901038, 0.13301764375397138, 0.11996625337217535, 0.11542320357901709, 0.12617172753172262, 0.10760819007243429, 0.15570060802357538, 0.12394947106284754, 0.14790367068988935, 0.09609576461038419, 0.1279382255992719], [0.03458556093807731, 0.09112474242491381, 0.05601304204070142, 0.020687430099185024, 0.042021202123058696, 0.027559817668848803, 0.04722955210932663, 0.011548064665735831, 0.016818406459476267, 0.05265140653188739, 0.03562548031498279, 0.022773452003353407, 0.01142398435955069, 0.032363328217927895, 0.009137095733811813, 0.054252572756792815, 0.024802616065634147, 0.0290557956988258, 0.06096817632871015, 0.010089490878661829, 0.058626633403556686, 0.02403845840932003, 0.03295442382139819, 0.11387950927019119, 0.07351407169231347, 0.028609713206865957, 0.07882947075579848, 0.025814542480345284, 0.03365821052076561, 0.10543515453381197, 0.05324940622917243, 0.02816352554197822, 0.05616126462285008, 0.020747156447864006, 0.049358560903263946, 0.031154389160552194, 0.012535057463017958, 0.01292961455016796, 0.039141336655510325, 0.025828550835805278, 0.010898617595168096, 0.04927526394437466, 0.016552196815609932, 0.04787110696945872, 0.012731085381736713, 0.04497561823310597, 0.019559184122564535, 0.009779000039478498, 0.08925225718745164, 0.01227592833207122, 0.08482593577355146, 0.029433464897530418, 0.04396523209288716, 0.02207511563652328, 0.0312712091420378, 0.034280501771718264, 0.11996299640408584, 0.001268032460107601, 0.08410405593791179, 0.03455343230494431, 0.05345889373815485, 0.07303562307996408, 0.045922049055142064, 0.041184748256845136, 0.012696816818788648, 0.02478117266270731, 0.07227379788777658, 0.004911345030580248, 0.010949452590596463, 0.07925949910921709, 0.03044763726315328, 0.040038380306214094, 0.0369729253330401, 0.014952162047848105, 0.042573970676000626, 0.010517757585538285, 0.033939130803836245, 0.016682024313403026, 0.056147113775036166, 0.07121102205876793, 0.03720910980233124, 0.03242434887215495, 0.06469486707023211, 0.03983700468337961, 0.036658461671322584, 0.013907306328681963, 0.026765592429520826, 0.03224799422813313, 0.05200552261833634, 0.021885069852162684, 0.06488489080220461, 0.07859089105789151, 0.021308133578194038, 0.02862068172544241, 0.06032656718577657, 0.0083104823217062, 0.062321046234241555, 0.06146654672920704, 0.04657626537872212, 0.004317253695002624, 0.05292937518762691, 0.029948720641966377, 0.015352587614740645, 0.043721254648906846, 0.05433296897847738, 0.0226663469469973, 0.02164874967586781, 0.04772492677771619, 0.03973300901374646, 0.04435133548187358, 0.019281866860442927, 0.03636289181719933, 0.04100040386297873, 0.029220571142754385, 0.03186654558937464, 0.04142143823472517, 0.02426323670494769, 0.05665928218513727, 0.016618647446323718, 0.02462386110398386, 0.03504956014720457, 0.023604916940842356, 0.04086789954453707, 0.04499961123136537, 0.04027181670867971, 0.016551272311647023, 0.02581353485584259, 0.033919314188616614, 0.022757954263527478, 0.009758115579773272, 0.018125836571146334, 0.04845314413043005, 0.04233577774305429, 0.051808445514844995, 0.05452958467815604, 0.08544094634375402, 0.048671031902943335, 0.03778968472033739, 0.03254432404147727, 0.03948515374213457, 0.0031499978919912663, 0.043978046226714335, 0.04382551494719727, 0.04371597903913685, 0.030230567125337462, 0.02582393679767847, 0.026648350059986115, 0.06490946055522986, 0.035317652725747654, 0.1068208519635456, 0.027557427529245615, 0.052989381432001076, 0.05758783021675689, 0.03588837531528302, 0.021882560968931233, 0.0047951493013118, 0.02545101904044194, 0.00452972506172955, 0.020012766122817993, 0.04181290205035891, 0.02402271470054984, 0.05517211323603988, 0.018759790142732005, 0.04859170437391315, 0.03963213799787419, 0.055663084212158404, 0.02433779413279678, 0.027242404076137712, 0.023788360579471503, 0.048418175828244, 0.019485486737851585, 0.0314931036638362, 0.032366347698760886, 0.05650454566680959, 0.027792282069900205, 0.018341259565204382, 0.04013041340346847, 0.04530431755951472, 0.04172819373863084, 0.017585838047255362, 0.015805865970573256, 0.0010978902282658964, 0.03131891693919897, 0.06219463516026735, 0.037554104147212844, 0.045215724634804895, 0.0030513295704232796, 0.01788902954597558, 0.03146214550361037, 0.05954608228057623, 0.01081962339646582, 0.011664801526681652, 0.03262765153444239, 0.002657140164436506, 0.011837436950632503, 0.026151911787954823, 0.018640191560345035, 0.008076084944020425, 0.056177661421575716, 0.029465512106461183, 0.05399859031396253, 0.08855095053357737, 0.025617412790389996, 0.025170485522331934, 0.044569715192275386, 0.06051228900573083, 0.0565086609816977, 0.019225363553102528, 0.10504264916692461, 0.016534778821681227, 0.06238033662417105, 0.05712307444108384, 0.025879276417461888, 0.07145089097321033, 0.023213510800685202, 0.045271825910146744, 0.03272780669586999, 0.015455014172143169, 0.02681444864720106, 0.02592320816724428, 0.024074532723586475, 0.031444734295031855, 0.018208941843892847, 0.04709855753130146, 0.022464509920350144, 0.02534834312142006, 0.02452058807414557, 0.03401253132947853, 0.03596307523548603, 0.06402778572269849, 0.06063633877784014, 0.016758746267961602, 0.02450193345014538, 0.053476691711694, 0.03970040201342531, 0.08673376590013504, 0.021305980925847377, 0.054526005405932665, 0.04411352252853768, 0.0027322406323427068, 0.016114560388294712, 0.03920734793479953, 0.026353166970823492, 0.022917996925700988, 0.10766467132738658, 0.07225678701485906, 0.057596535821046145, 0.04369854408183268, 0.025064995379320214, 0.011955779395066202, 0.032617904378899505, 0.018920492680211152, 0.0420064880911793, 0.026571299015943493, 0.015067891284291233, 0.025684521600071872, 0.020828796084970236, 0.032960364395486455, 0.06314178183674812, 0.05671545131398099, 0.048500719613262584, 0.024100512133112977, 0.03182568081787654, 0.05219985504767724, 0.04206320344071303, 0.023290227666231136, 0.10351830667683057, 0.017371186886781027, 0.020829004734488468, 0.044328234757163694, 0.008264344484944428, 0.01692105014808476, 0.10159765902374472, 0.055902322089033465, 0.003707567080190139, 0.014616794418543577, 0.025428383112219826, 0.034755907154509, 0.03175508264186127, 0.01734095984803779, 0.029684397325451885, 0.04950695990451744, 0.03951564032052245, 0.08327933054949556, 0.061104432945804935, 0.01035790321683245, 0.03519209999857204, 0.008965992950834334, 0.0033113422811896142, 0.05059079746050494, 0.016550619221691574, 0.062470629279102595, 0.01030586042907089, 0.0177222201933286, 0.017864821112847755, 0.0071225956614528385, 0.02658340916968882, 0.019615443157298223, 0.05027639147426401, 0.027567724298153604, 0.0448224287746208, 0.025995590890358602, 0.03504047117062977, 0.01030335748302085, 0.032090126270694394, 0.0335239216552249, 0.05947060204510178, 0.06224494853190013, 0.040202392398246696, 0.042077523922281604, 0.03615665788363133, 0.03734260138922504, 0.04158958260502134, 0.04169011774605938, 0.023213950152109777, 0.03385639702901244, 0.025408222140478234, 0.07305505632289819, 0.034180319468889914, 0.013902409850353641, 0.06140655066285815, 0.009127750610267478, 0.03630440888394203, 0.024948456989867345, 0.024615766181211387, 0.03521805735571044, 0.03068673943302461, 0.0667975317420704, 0.06652689804988247, 0.02805328056482332, 0.030100664988692318, 0.05157607101968356, 0.03589632435302649, 0.0845408153587154, 0.044436688401869366, 0.03816660753052149, 0.032874797736959796, 0.041381733758108954, 0.020405866904184222, 0.020572284402857934, 0.033345589081623724, 0.04827055374958685, 0.005696205214397716, 0.0065753851584824064, 0.03419642110488244, 0.04019511850284679, 0.036644673839743645, 0.0642344132065773, 0.04043952342388885, 0.011746950065051871, 0.04335944959893823, 0.023219899207885777, 0.13001709404800618, 0.2177914341113397, 0.13324603864124843, 0.10195292638880865, 0.0563890250798847, 0.13514491889093602, 0.11450693703123502, 0.07327685584979397, 0.06226970148938043, 0.1578008910374982, 0.0973136874714068, 0.09241372147308928, 0.11134037016225712, 0.16102310456335545, 0.09173944086900779, 0.10616333117442471, 0.09127923806330987, 0.09845254743205649, 0.10826397381190743, 0.09877749106713704, 0.1879201919904777, 0.08842844782131058, 0.14752474959407533, 0.22852112193192753, 0.10414439772388764, 0.1337519543511527, 0.11338166134165865, 0.08272360358387232, 0.17677628568240575, 0.2419481628707477, 0.13751506885247572, 0.08339132275432348, 0.19633152921284946, 0.10695241990366153, 0.15645315764205797, 0.10449129196682147, 0.20331122539937496, 0.14166994233216557, 0.13754644431173801, 0.051548016989337545, 0.14204802204455647, 0.08217063147042479, 0.12824177502521447, 0.15065008188996995, 0.06432030216923781, 0.10184484933103834, 0.06921834791345255, 0.09536778474492685, 0.14320758410862514, 0.1459114375923361, 0.1632339616439172, 0.13670502017651284, 0.15639377225722584, 0.11905016324349812, 0.12184139846691064, 0.10214423933731658, 0.16986090104494775, 0.16369888026799473, 0.14346400249217237, 0.16866112899567398, 0.15732287668756076, 0.13246595407170908, 0.0971837140885847, 0.12449675026748862, 0.1949024801807744, 0.18057013782007353, 0.1449545675090381, 0.10881107659744364, 0.1956777200102806, 0.11983188986778259, 0.13371687409068855, 0.13453332813722746, 0.18766532066677297, 0.1034872636997274, 0.0950467155448028, 0.08928577003202268, 0.1104183021400656, 0.11919099997196879, 0.12149580701121263, 0.1382081245205232, 0.21814974131328718, 0.09442236154739346, 0.21322593837976456, 0.14689927601388522, 0.23870291986635753, 0.19966300044740948, 0.14103103375860623, 0.18687699868210725, 0.12970073388091155, 0.08722812615867172, 0.26966224717242376, 0.12271141606782164, 0.10975651336567742, 0.1670642782534872, 0.1404747436089175, 0.13918113016656466, 0.23439001558082445, 0.10019355972430535, 0.07270828421626772, 0.1508932959820543, 0.08667023466633898, 0.09354422188230924, 0.13836121559143066, 0.1805343654538904, 0.15167643395917757, 0.12737307378223964, 0.11197127202259642, 0.2151131478271314, 0.14106604616556848, 0.1194387466779777, 0.12366220647735254, 0.18602215312421322, 0.10942132385181529, 0.14302588600133145, 0.08666889116700206, 0.11965325873877321, 0.07743955962359905, 0.1077138108334371, 0.09749244073671953, 0.06945175038916723, 0.11842053702899388, 0.10261495943580355, 0.14167670054095133, 0.08624935975032193, 0.09254988309528146, 0.10455527781908001, 0.15239819165851387, 0.0963722812011838, 0.08847433714462177, 0.09038044379225799, 0.118109116596835, 0.2335749864578247, 0.15672583372465201, 0.15198761011872972, 0.11675013309078557, 0.19887564198247024, 0.10140928413186755, 0.09637580279793058, 0.11127025035343, 0.13933580900941575, 0.11090234188096863, 0.14414868503808975, 0.13896797517580645, 0.12931058981588908, 0.1408794761768409, 0.12193287855812482, 0.059129142867667336, 0.15586891184960092, 0.10911239364317485, 0.21245156707508223, 0.14542734356863157, 0.15885115468076297, 0.13929485263569014, 0.11202594837439911, 0.08409663276480776, 0.12457478179463319, 0.11105950416198798, 0.14440613479486533, 0.11351299179451806, 0.10315006572221007, 0.14023554644414357, 0.10027583888066666, 0.09845387736069304, 0.12683453410863876, 0.12461413682571479, 0.1871305943599769, 0.06827217154204845, 0.10645897566740002, 0.16478967959327356, 0.12691857745604856, 0.1253597925284079, 0.11930189973541669, 0.11688111749078546, 0.07710529291736228, 0.07677625771611929, 0.09222920744546823], [0.013715325871349444, 0.009645666211976536, 0.031688419968954155, 0.008787957236303814, 0.07218978846711771, 0.027035678204681193, 0.027910258953592608, 0.10486207064241171, 0.025717193061219792, 0.012957846695956374, 0.04669899879289525, 0.020800382431064333, 0.019833123976630822, 0.05799344488020454, 0.032920534389891794, 0.04157156410760113, 0.03782034432515502, 0.05881128992353167, 0.013031059776299765, 0.029234606639615128, 0.008094779431952961, 0.03077862664524998, 0.015055160271003842, 0.01608951057174376, 0.01601627459084349, 0.03260042531681912, 0.015744421231959547, 0.027014545231525387, 0.07120655051299504, 0.05121842199670417, 0.05477083441136139, 0.04006639701713409, 0.05141503430370774, 0.03605079963537199, 0.011667562316038778, 0.022956980458859886, 0.012011332753380495, 0.039044390964720926, 0.02995091231007661, 0.018170557117887905, 0.03051427618733474, 0.020563100431380526, 0.02960313597161855, 0.02966899797320366, 0.05734958300100906, 0.011578920197540095, 0.019988126819953322, 0.022050510260409543, 0.035600662896675725, 0.09055606901113476, 0.04868338802563293, 0.07407009721334491, 0.018817847295265113, 0.09036544138299567, 0.043415547481604984, 0.00875195671272065, 0.08015799482486077, 0.0910889564880303, 0.05141284942094769, 0.045714020396449735, 0.07911196524011237, 0.0595685892871448, 0.019706475415400097, 0.05025077677731003, 0.012514873590719486, 0.05071908129113061, 0.028709288220852613, 0.09370425436645746, 0.022814284544438124, 0.07308485758091722, 0.02401346796458321, 0.043424941798938174, 0.022256211543987905, 0.03290724867422666, 0.019093135737680962, 0.0727353034807103, 0.03924924747220107, 0.01548549735785595, 0.07204226138336317, 0.028604502057922736, 0.04337916782658015, 0.038099079725465605, 0.017972102588308708, 0.06753552678440299, 0.046316084518496475, 0.05856225400098732, 0.01420663865948362, 0.03281853022053838, 0.027579724189958403, 0.03245403817189591, 0.06896123742418629, 0.015935389823945503, 0.07127267375056233, 0.017358737465526377, 0.02876357441501958, 0.01768514503990965, 0.0704066798623119, 0.0240225348887699, 0.01331945157809449, 0.02575770838718329, 0.033403827742274315, 0.034182721482855935, 0.04489317283566509, 0.020106831432453225, 0.06690184293048722, 0.021893473508368646, 0.07979509394083704, 0.03241701051592827, 0.015462683314191443, 0.04374809410156948, 0.03917916498279997, 0.07094602020723478, 0.014807211700826883, 0.020283381155292903, 0.08420682006648608, 0.03466917680842536, 0.0183747350903494, 0.02142645312207086, 0.04647083460752453, 0.06313230948788778, 0.058622060077531, 0.09373305817799908, 0.057935050156499655, 0.005543961888179183, 0.022163135199142352, 0.019824160529034476, 0.03679322211870125, 0.08279667502003056, 0.11621961370110512, 0.006536988558114639, 0.0297037186101079, 0.010625595459714532, 0.029766405067805733, 0.029762544203549623, 0.06608988757112197, 0.03134137984099133, 0.007773750943930021, 0.057445887476205826, 0.034788812710238357, 0.027814256426479136, 0.03631411872005888, 0.05001946079677769, 0.01841771349843059, 0.004577728869792606, 0.039862432783203464, 0.00472474578003, 0.05220778372937015, 0.03863278144438352, 0.026133774546906352, 0.03260936501568981, 0.06701976553137813, 0.030796777456998825, 0.03030595915125949, 0.002855326672683337, 0.06469130476138421, 0.010407181822561791, 0.019433539793161408, 0.02616305842197367, 0.012010971433483064, 0.03758071968331933, 0.03681020585021802, 0.021098647765549164, 0.027261515014937947, 0.026070477407691733, 0.032230321783572435, 0.03737005491607955, 0.03555319597944617, 0.03587310827736344, 0.050826208399874825, 0.058137335016259124, 0.011512991190621895, 0.05585444465811763, 0.027508394892460535, 0.014719064912891813, 0.020300515860851322, 0.042684548135314665, 0.008975875813380947, 0.060546982501234324, 0.060852947511843274, 0.042039698987667046, 0.03291041064741356, 0.10830320670668568, 0.03576317881899221, 0.09477956952261073, 0.022632040216454437, 0.050095019063779285, 0.05677482991346291, 0.06278150009789638, 0.0241126986220479, 0.04767980759165116, 0.08825203550181218, 0.026069361217586056, 0.030080427681761127, 0.0481903543030577, 0.024411459287096347, 0.022571046703628132, 0.025652611794482385, 0.008372571668587625, 0.015387208167729633, 0.02088995583887611, 0.045439841358789375, 0.05290341104513832, 0.04953284262280379, 0.03130823679800544, 0.05206635667543326, 0.0347587705722877, 0.013039477851374872, 0.0008678538693597407, 0.009923324437945016, 0.005531266497980271, 0.03781781678221055, 0.03708058509177395, 0.026710946611793976, 0.07940984211329903, 0.021704976480188112, 0.03994590616119759, 0.02318573327335928, 0.010588908767593759, 0.012902129641068833, 0.04159423735524927, 0.0473102943838707, 0.007364529866858253, 0.04191874672791787, 0.021971292993319885, 0.040545150970241854, 0.04931778094864317, 0.04367454429822309, 0.04850259576258915, 0.021922979603654573, 0.06586837981428419, 0.03206949541345239, 0.01612599370335894, 0.04140170982905796, 0.034764042789382596, 0.006794204644393176, 0.0739027772630964, 0.03847390246976699, 0.05827712680080107, 0.032029007228889635, 0.01272795394262565, 0.06633056394223656, 0.0319930279095258, 0.030045086185314825, 0.07148080079683236, 0.025914992804505994, 0.0420772219741983, 0.04082307891388025, 0.040566104131617715, 0.013925809978640505, 0.005714707592103098, 0.06368024008614676, 0.09262363985180855, 0.061884463232542784, 0.02963428072897451, 0.0364938863952245, 0.08790931424924306, 0.06713058387062379, 0.08211436056132827, 0.026044241851195693, 0.026218398041757088, 0.019874095617394363, 0.024986320940245475, 0.0700876394818936, 0.0034459233408727285, 0.029788830650172064, 0.06962510930108172, 0.03457908092864922, 0.034608166332223585, 0.04304885019415191, 0.06837019271084241, 0.06161678795303617, 0.06332776150000946, 0.11328052569712911, 0.01091422135609069, 0.030038036206471067, 0.06829462426581553, 0.0123589487879404, 0.036204691377601454, 0.10609628512923207, 0.02598735347523221, 0.04710140398570469, 0.044466462518487654, 0.026473155710846186, 0.09904327323394162, 0.041452545672655106, 0.03356824695531811, 0.008471736168887998, 0.035994661040604115, 0.05211676164929356, 0.013393480596797807, 0.057623046184224744, 0.029903906796659743, 0.010625506401993334, 0.0870778781494924, 0.0342865576967597, 0.0518262672371098, 0.08932839560189418, 0.06281832419335842, 0.08680938184261322, 0.028214393615988747, 0.05548459218282785, 0.032960048876702785, 0.03947527427226305, 0.03261574324486511, 0.08375928550958633, 0.015386656858026981, 0.03290074830874801, 0.04813417499618871, 0.006149527675006539, 0.01653532843504633, 0.05993320007941552, 0.04839557382677283, 0.06203082323606525, 0.020055089744606187, 0.03481328407568591, 0.02298924819167171, 0.016968895348587205, 0.018412928130211573, 0.0308929801519428, 0.012662436297562505, 0.04406570616577353, 0.01987730848070766, 0.02186368073203734, 0.038748831288622956, 0.028171025050271834, 0.01329408963543496, 0.04310425936377474, 0.042790379242173264, 0.024655114426942806, 0.027124369516968727, 0.010950672257292484, 0.022895722317376306, 0.02205500385857054, 0.055967067900512896, 0.04814164905941912, 0.05276826722547412, 0.005715985782444477, 0.031797480902501514, 0.03571351684097733, 0.047432084634367905, 0.040832015220075846, 0.028299734661621705, 0.03811321700257914, 0.018243838899901936, 0.06804915065211908, 0.08655769963349615, 0.025370232661121657, 0.05572288350335189, 0.016665919284735407, 0.023119630391842554, 0.04754406326849546, 0.06246572347091777, 0.12996070778795651, 0.09975366547171559, 0.1373929732612201, 0.09847563119339091, 0.2737715095281601, 0.18493820700262273, 0.09105870739689895, 0.14870491198131017, 0.13726885563560895, 0.09134054370224476, 0.13041757898671286, 0.13495627258505138, 0.08267191278615169, 0.15530291864914553, 0.15852123738399573, 0.10112648430679526, 0.1565464697778225, 0.18188702501356602, 0.12333428407354013, 0.11430473359567778, 0.07704973447003535, 0.09889944416603871, 0.09031462589544909, 0.06715398654341698, 0.07500465027987957, 0.13449870928057603, 0.14625339210033417, 0.1284334883093834, 0.25056398340633934, 0.1109118956540312, 0.17326398486537592, 0.1105636375557099, 0.1493775708866971, 0.09907575470528432, 0.16489319689571857, 0.1950184553861618, 0.0756906627544335, 0.15273451432585716, 0.14781053497322968, 0.11220124111111675, 0.10259589938712971, 0.21085230074822903, 0.07028404144304139, 0.09511253344161169, 0.12955304394875253, 0.06804820748844317, 0.10114120851669993, 0.11821944639086723, 0.10820591157036168, 0.14009211771190166, 0.07948402634688786, 0.1615948924528701, 0.10519789797919137, 0.16402058729103633, 0.07383824179747275, 0.15335283614695072, 0.12845327439052717, 0.2670531986015183, 0.10290510779512779, 0.16103029703455313, 0.10327190347015858, 0.2554980729307447, 0.18480207930718148, 0.08188271549131189, 0.09550064190157823, 0.09354883592043604, 0.09813679794647864, 0.1626423741025584, 0.193821411047663, 0.2106266471424273, 0.055283118172415664, 0.1302295569330454, 0.12744194508663245, 0.09627324222986187, 0.1605584980653865, 0.21143014117011003, 0.13976610877684184, 0.10929375926830939, 0.15067986957728863, 0.1974878885916301, 0.1756621040403843, 0.14688425324857235, 0.09700369874813727, 0.15566214865871839, 0.1529281817908798, 0.10006887212927852, 0.1048114247886198, 0.15260163002780505, 0.10123410674610309, 0.17717947119048663, 0.24902723729610443, 0.1316182195608105, 0.1850035363542182, 0.14854468272200652, 0.0927025331184268, 0.12883698594357285, 0.19202144763299397, 0.07605032702641827, 0.08663507976702281, 0.17986452925418103, 0.1554011298077447, 0.17129845890615666, 0.1878302725298064, 0.15095470340124198, 0.23152754775115422, 0.1374005185706275, 0.15853263677230903, 0.12174960624958787, 0.1316889500511544, 0.1596181978072439, 0.0829343158485634, 0.20128290780952998, 0.10699911668364491, 0.07217216691268341, 0.14054468699863978, 0.10986467863300017, 0.1337009420884507, 0.09394594854010002, 0.07441899991993393, 0.1426654074873243, 0.26575434686882154, 0.14726132872913564, 0.1422979264919247, 0.14433327370456286, 0.1025229636579752, 0.1623353234359196, 0.11656554442431245, 0.1384835283138922, 0.2030332296022347, 0.12213251713131155, 0.09949985266263996, 0.09885350734527622, 0.12270996400288173, 0.12033248586314065, 0.11190174253923552, 0.1387761126139334, 0.12015568677868162, 0.12075570172497205, 0.08351330977997609, 0.11698529975754873, 0.11257339042744466, 0.1956800813121455, 0.09263729197638375, 0.07881775245602642, 0.12874395879251616, 0.06959399847047669, 0.12015275550740105, 0.134347708097526, 0.10086311772465706, 0.06062985198306186, 0.19198410106556757, 0.11515754354851586, 0.12211281247437, 0.09029932493077857, 0.12816793684448513, 0.10800673440098763, 0.08739976837698903, 0.11123299199555602, 0.09591405971774034, 0.13255584639097961, 0.0873833139027868, 0.11161863737340484, 0.11149971054068633, 0.15710521622427873, 0.10058915921087776, 0.09176881464996509, 0.10739475688231842, 0.09382357474948678, 0.08215298277458974, 0.15723744912871293, 0.09285717124917678, 0.16908069433910505, 0.14970417693257332, 0.10622523392417602, 0.10445222870579787, 0.10360409385923829], [0.0478824622529958, 0.06005401323948588, 0.026337136581007923, 0.018027177579434853, 0.035445013748747964, 0.07234238420746156, 0.01780497093152787, 0.024583082845700637, 0.06822565796652011, 0.0646102808948074, 0.02303001457559211, 0.026726244183789407, 0.05226676199319107, 0.03476880271253841, 0.0031722099478689154, 0.05625667003914714, 0.018940336436831524, 0.03321794307391558, 0.023734685066821318, 0.0191473116699074, 0.016840153506823947, 0.03448995535394975, 0.00904894555320165, 0.003774694973669414, 0.019357569316135984, 0.018183932739443014, 0.04067822186542409, 0.026155540253967047, 0.016807556684528078, 0.010215370150815164, 0.048996956021125825, 0.06992105234946523, 0.10358928143978119, 0.03295087847592575, 0.049366903491318226, 0.06924700923264027, 0.026444068610934273, 0.025912436423823237, 0.07966109684535436, 0.05927953336920057, 0.015541663094024574, 0.014300529246351548, 0.06212446785398892, 0.04530930479190179, 0.04115391901827284, 0.0427742436794298, 0.017476334369608333, 0.05632191796654037, 0.09677692555955478, 0.016662024493728365, 0.014306245903883661, 0.02915327064692974, 0.05068257271445223, 0.05729453345494611, 0.021485658695123026, 0.05188910975786192, 0.073386486752757, 0.053748183750680516, 0.06466307091925826, 0.027856013471526758, 0.057657393626868725, 0.0055457706080882675, 0.03508517984300852, 0.04142484448051878, 0.01119163615762123, 0.04177262421165194, 0.038148670457303524, 0.02444795429307435, 0.027368016175127456, 0.01263931521680206, 0.05457096513626831, 0.017901462003854767, 0.07401056933615889, 0.02754524104031069, 0.08115550237042563, 0.04298648604058793, 0.03982211083972028, 0.0361311212182045, 0.08568812986569745, 0.0048205303277687305, 0.006405232324531036, 0.09599901230207511, 0.07402842837784972, 0.05680479062721133, 0.06397135875054769, 0.02790474416022854, 0.028361912218055556, 0.023276958913941468, 0.01847447464907808, 0.08451885796551194, 0.025469000218436122, 0.041382035706192255, 0.0459395518659481, 0.03332013723307422, 0.018734112681288804, 0.05997436001364674, 0.045121489691415, 0.03493816166051796, 0.036593020361449034, 0.02200763363258115, 0.01979342967803989, 0.03595806425437331, 0.03713835895593677, 0.04064698550584061, 0.003233611853959571, 0.04120445291378668, 0.0037595916323230733, 0.006791498986006315, 0.04694659622120006, 0.042949919788432975, 0.04722404240497521, 0.0394168625851827, 0.08433914118047271, 0.007380883408976453, 0.011912334494159689, 0.028585665925805057, 0.05215396911704114, 0.08239190852535622, 0.07295475527644157, 0.06048687108393226, 0.011396771712627794, 0.032704967207142284, 0.024831689594845687, 0.04858420995463218, 0.06155791146946805, 0.039941064813839536, 0.011637047748081386, 0.03733008920348116, 0.04342218694676246, 0.010313747550493904, 0.02827103093399533, 0.024542847415432334, 0.05055792583152652, 0.02046104706823826, 0.02092777907715312, 0.016206291537465792, 0.027018187268237983, 0.10265231957393033, 0.04172632437465446, 0.024330040173871175, 0.08836022791053567, 0.03965770180470177, 0.03168442339769431, 0.0764933086133429, 0.033302376578961096, 0.03299420293686645, 0.03408894794327872, 0.010737772565335035, 0.037382573887173615, 0.0508374177983829, 0.051370841317943165, 0.0466026332495468, 0.04969104306240167, 0.037879807741514275, 0.10330079549125262, 0.03911790005596621, 0.03706702456942626, 0.039923911448568106, 0.018804627736764293, 0.02221582513967795, 0.011924532009288669, 0.031995636876672506, 0.04275131258847458, 0.05244427353941968, 0.069824876795922, 0.003906456720350044, 0.037312426936945746, 0.050512793074761114, 0.0278368652133005, 0.003933972587609398, 0.04817693966573902, 0.009036959232097226, 0.014788935360099589, 0.04426118192662086, 0.05118796595239213, 0.05738012386219842, 0.03444695319714291, 0.06453955040446349, 0.037367052398622036, 0.051205987842487435, 0.016054045242656554, 0.1546264870890549, 0.08642509353480168, 0.020540098094248345, 0.029390649337853705, 0.07918264823300497, 0.043177547931138954, 0.04242411621713212, 0.027345685587663735, 0.02645738994968789, 0.01137804499428187, 0.034670242108404636, 0.0020673348377126134, 0.07780848589858838, 0.02603707991407386, 0.0455762811803392, 0.02362799222048904, 0.039289477813456736, 0.05089776670294149, 0.08910699641065938, 0.023705991517220224, 0.03825853206217289, 0.028777443670800755, 0.03270907912935529, 0.04454628877075655, 0.037601625347243886, 0.029968242094452893, 0.06014208708490644, 0.06774243925298963, 0.03349170820521457, 0.05901708959468773, 0.0900281619812761, 0.02972314167501671, 0.06526350655726024, 0.06553542946598359, 0.0909369375024523, 0.0909732866234013, 0.0369996833615005, 0.015044229071853417, 0.029307050430881124, 0.04018362072695579, 0.053249565684901815, 0.02300892231453742, 0.04178173354427729, 0.044579007729355774, 0.031894650509847064, 0.03285013638170702, 0.04423683948282685, 0.02023849606380931, 0.0343573424699051, 0.012321257863992026, 0.053771450716469965, 0.013553602986836007, 0.02993848154853497, 0.0416702298846628, 0.0080174722409408, 0.055491336820913215, 0.048893934049244435, 0.04538563658882465, 0.10441081771360976, 0.04221841832622886, 0.0050832455162890255, 0.04061462277812617, 0.009597235775020505, 0.027822161359446387, 0.02543582155236176, 0.03149987205064722, 0.055567417559879165, 0.014853491181773799, 0.04436555079051426, 0.03661385477919664, 0.026831720756100755, 0.056286708784422705, 0.053679539755518944, 0.05876359569707087, 0.023086611181497574, 0.052012321539223194, 0.08676458496068205, 0.03986912653116243, 0.03079035851572241, 0.07678932630057846, 0.05542888445779681, 0.018954081859971796, 0.016212069263149585, 0.01972478229020323, 0.035262056958994696, 0.04659509811816471, 0.011951071210205555, 0.01124371711297759, 0.0587645863581981, 0.06239415838250092, 0.03906863841361233, 0.0221113782442574, 0.1338800210505724, 0.020501626855028526, 0.01849593162270529, 0.010510954423807561, 0.027934874507731626, 0.014465326742668237, 0.042689735535532236, 0.005934169141775263, 0.016051349762294973, 0.018066264589184096, 0.04795844799705914, 0.039539545109229426, 0.02645528988380517, 0.05159522606326001, 0.058901731856167316, 0.04085873253643513, 0.025567370832764676, 0.0255511691128569, 0.011640194454230368, 0.05366250513387578, 0.035367396127964766, 0.034611440263688564, 0.025558256411126683, 0.05850188474037817, 0.007088838968359466, 0.04666929592245391, 0.016955439999167408, 0.032347019628754685, 0.08949330675282649, 0.058054105910871706, 0.03791633667424321, 0.047425669085766585, 0.06610083234097276, 0.010080827682811235, 0.020744496590590904, 0.021907042512404065, 0.04069426243326493, 0.005019014543254993, 0.04986263778326767, 0.03759495195533548, 0.05319598177447915, 0.04573587940207549, 0.022397077110196863, 0.04542596871033311, 0.011330545846638935, 0.02064223288159285, 0.026381124309929352, 0.04192948115191289, 0.04487214842811227, 0.018611677822523882, 0.0796593665810568, 0.05865736425455127, 0.0380072094766157, 0.040328477775411944, 0.04606801211567862, 0.013756664769191827, 0.049976804692830355, 0.04825943934598139, 0.07525517219411475, 0.024812899263841764, 0.06629027253282921, 0.029536853278321878, 0.019758424056427817, 0.07228458659457308, 0.029921470675617456, 0.08760322710233075, 0.017216236629922475, 0.03262062191164919, 0.036166092913065634, 0.06963012367486954, 0.02126904996111989, 0.031415207843695364, 0.04609652754983731, 0.05207527941092849, 0.022599955688097646, 0.014313216154862727, 0.017663867878062383, 0.03407558758876153, 0.025260189548134804, 0.12231581658124924, 0.24735494703054428, 0.18339008864547524, 0.16675163645829472, 0.21487108724457876, 0.17104505321809224, 0.13967076103602136, 0.08015542996249028, 0.12073088091398988, 0.14398110045918397, 0.11288507548826081, 0.10491754088018622, 0.10756019729056529, 0.11367529737097876, 0.04975383808570249, 0.22906408565385, 0.11812575427549225, 0.10968974551984242, 0.08298143332025834, 0.09907665037150894, 0.09411531088075467, 0.11880545637437276, 0.15506480714040144, 0.13704476266035012, 0.12386241501995496, 0.06644698698073626, 0.12821381938244614, 0.1281936533216919, 0.24204386344977788, 0.10456605974052634, 0.18882543912955693, 0.11406523787549563, 0.12912023360175745, 0.16997789405286312, 0.12777716852724552, 0.16037747849311146, 0.1623722900237356, 0.13000451400876045, 0.21747526393405028, 0.2846594995685986, 0.1326018917773451, 0.09840574887182031, 0.18978731680129254, 0.15018223199461186, 0.111830917053989, 0.13200284035078116, 0.12477747377540384, 0.11010645423084497, 0.13899693505040236, 0.19214874080249242, 0.07860136763857943, 0.11928161153835909, 0.0749440910294652, 0.08981006725558213, 0.1526013586137976, 0.12518843529479845, 0.12706284757171357, 0.12196890876761504, 0.12319879420101643, 0.19799594847219332, 0.11288120783865452, 0.11828122021896498, 0.09282509689884526, 0.16464604730052607, 0.14412830184612954, 0.13599762027817114, 0.11927687536392893, 0.12631287638630184, 0.11836396077913897, 0.16521635598370008, 0.12621013261377811, 0.1456099237714495, 0.09231809553291116, 0.16056761757603713, 0.20812619131590637, 0.10036210782293763, 0.21338048151561193, 0.19002884812653065, 0.15966026697840008, 0.13817791614149297, 0.13859180893216813, 0.19737191338624271, 0.12510801532438823, 0.12095987291208335, 0.10363884163754326, 0.19206427676337107, 0.09014510749174015, 0.08325801097920962, 0.11085323630166904, 0.14174321054347924, 0.10532016998955182, 0.10332132117556674, 0.1022053753424968, 0.1553836100335632, 0.1835633729185377, 0.13716605758028372, 0.09004509142999138, 0.1911964847573212, 0.12439995046172823, 0.09528596020702805, 0.08893777656235866, 0.11039997490921191, 0.15715943117226872, 0.23918022853987558, 0.061293588152953556, 0.09645103876079832, 0.08931791223585606, 0.1022355022973248, 0.08661524618842772, 0.1630450574947255, 0.18622986626412186, 0.1287337536258357, 0.16333063931337424, 0.06395933511001722, 0.09370819665491581, 0.07287236755447728, 0.11941246023135525, 0.16316281046186173, 0.11427212320268154, 0.10280969220080546, 0.09969242090093237, 0.10289519439850535, 0.13515637256205082, 0.1035070972783225, 0.12442350919757571, 0.2073073216847011, 0.13178241146462305, 0.11608401526297842, 0.10992924802537475, 0.08174765988120011, 0.16366838690425667, 0.0962466165157301, 0.12136045284569263, 0.15476127128515924, 0.23450099676847458, 0.1559634046362979, 0.12573510381792272, 0.2131669329745429, 0.08682050981691905, 0.13005572983196803, 0.17912225265588078, 0.16692067310214043, 0.09938046442610876, 0.23447705805301666, 0.1404095906764269, 0.11469941027462482, 0.07834228261240891, 0.15321708843111992, 0.19627944486481802, 0.09874828013458423, 0.09198814430939299, 0.13036438184125082, 0.14782825830791677, 0.13675523176789284, 0.1639313870774848, 0.1671383742775236, 0.1085553096075143, 0.2147924043238163, 0.13417622872761317, 0.1115133830213121, 0.10788632836192846, 0.07570442344461169, 0.14587809438151972, 0.19245756923088006, 0.1380830162337848, 0.1187216437288693, 0.13563015285347188, 0.12700532137283257, 0.09824792841183287, 0.07477338518947363, 0.1876588745840958, 0.0790388055944017, 0.1156182416847774, 0.09139066029872213, 0.1475534244839634, 0.168898181989789], [0.011295192475829805, 0.03913205090378012, 0.019915196179811443, 0.021441896579095295, 0.04645777280841555, 0.007307376862237496, 0.008835711682747518, 0.0849914847474013, 0.032751660594450574, 0.05348832858726382, 0.018978821246751716, 0.030944233294576406, 0.021598599152639508, 0.054078274073877504, 0.0628324377217463, 0.028443175268226435, 0.032441963641239066, 0.0662117117483701, 0.045059159464601956, 0.03254905682323234, 0.027129058193947588, 0.03560877139014857, 0.03573827658380781, 0.06720110401511192, 0.09626833642167704, 0.041959014388599565, 0.044463113948170624, 0.0381386925998543, 0.024035941044400846, 0.05141040330220546, 0.05029274756088853, 0.06505888075168643, 0.036895043083599637, 0.02842805750801095, 0.04748802984665547, 0.03546878283045121, 0.049895614585173984, 0.030249935907444785, 0.020682731244180883, 0.04519646102562547, 0.010162408796272107, 0.07716285982834441, 0.033328028595341105, 0.027446168142237833, 0.03396752749436668, 0.04243666572230203, 0.024625647347420454, 0.06488888737346445, 0.061539943862174235, 0.038968747880842, 0.037115393938230615, 0.028821592551789114, 0.021941473075587834, 0.035450289358517954, 0.013388335605018904, 0.02489948711757149, 0.017119433431487, 0.02144500257314316, 0.010129690685841655, 0.06838365484561239, 0.04998057395485895, 0.035765027826918025, 0.024863528154258217, 0.030400679247187715, 0.093552072532475, 0.029566963269774402, 0.06557070650160313, 0.014187463259856616, 0.028877357952296734, 0.04002688931567328, 0.015282557711803486, 0.01955017657019198, 0.02114728854836098, 0.02104958120201315, 0.053506479399012666, 0.016850485898820416, 0.07794271369597741, 0.06843017520649092, 0.04219991128359522, 0.009841886665006834, 0.04942302851538573, 0.02842878014780581, 0.03816409695095249, 0.016654041529233967, 0.03779868209468467, 0.002398151617463944, 0.02134684400100793, 0.09618866962513753, 0.007506751654935735, 0.010695862849908215, 0.014949371572583914, 0.027520381213564957, 0.01640009131681706, 0.0025854735078090535, 0.018490537269307033, 0.07484640912818057, 0.027184701458151852, 0.050786958541721106, 0.0416390512005559, 0.0487659318106515, 0.010162631016490715, 0.02222278181995664, 0.029333570972085, 0.013182580886807824, 0.01922833384014666, 0.008774426399863191, 0.033304402005991766, 0.039172969958079715, 0.03151940028848393, 0.08187733470861401, 0.03797709269981299, 0.01587812995005931, 0.027615552535280585, 0.019400393357500434, 0.010533723514527082, 0.04330532286050064, 0.04881604501445379, 0.012936036035950695, 0.05490579841924565, 0.006905871576496533, 0.02481312826941056, 0.038947390991130044, 0.018322055327839086, 0.09593200696898357, 0.031053331547549794, 0.005847328109666705, 0.07591876587165253, 0.03405917721933552, 0.026365684245580008, 0.02803726713838322, 0.010038054531573184, 0.058594138361513615, 0.03253829186516149, 0.028551474546215365, 0.07052991539239883, 0.03492038404302938, 0.029729591150368963, 0.03544028435966798, 0.017155516227441173, 0.015960271703079343, 0.0382789084687829, 0.06110406653689487, 0.023303476062470248, 0.04342734381290419, 0.03430025731878621, 0.057559386028775146, 0.009777064518337803, 0.029740736088050262, 0.03854159312322736, 0.025238741056195328, 0.033550455767129145, 0.010267703860465969, 0.023856244615412185, 0.04831282648124865, 0.04292592339749847, 0.048643853182771375, 0.10699825494417123, 0.024532167274238806, 0.06689047068357468, 0.03607964076633964, 0.02661315444856882, 0.031929089554718564, 0.06778770432408367, 0.010795978995572244, 0.0630800419354013, 0.014003119714158987, 0.05819556010620935, 0.0354032261696245, 0.06364973315170833, 0.03785291739872523, 0.015304416717429246, 0.007621739591870989, 0.018277925106563737, 0.07339435097362314, 0.015539040556177497, 0.04223219597978251, 0.03731681027316621, 0.025637249761660184, 0.0173073435268764, 0.01347788017509239, 0.038172147768948755, 0.04947809502482414, 0.02501301111520401, 0.04089824363057103, 0.0486475545912981, 0.0300267250277102, 0.028565761101033007, 0.0367676447411733, 0.03638867614790797, 0.07625310721674136, 0.04125935657482062, 0.05350465753248759, 0.008310680793199157, 0.08263035251625947, 0.036932935871716054, 0.0571967429880585, 0.05001082643866539, 0.03102762864104339, 0.013962168429446007, 0.07717457812811647, 0.09000601459826742, 0.023428798087739518, 0.04081894324294158, 0.0672468983435205, 0.0614210848829576, 0.014651666029489465, 0.016511920673240508, 0.053009476246578355, 0.017333529889583588, 0.03149511891284159, 0.06712335747267519, 0.03735995492232697, 0.04940136967759047, 0.060555606681321344, 0.013616887403519025, 0.01582114997186831, 0.011456350479940218, 0.0361968373347606, 0.02171757348280932, 0.020790857495740056, 0.04181309204016413, 0.021760322885321717, 0.06921620374279362, 0.03324289280655129, 0.031758773872362714, 0.02422395970539323, 0.015264707151800394, 0.009732915637349444, 0.046758692911160846, 0.049025396816432476, 0.03340930351987481, 0.06179788216416325, 0.026423463198755468, 0.03845196543261409, 0.06100772134959698, 0.03635971966598715, 0.01338246203626373, 0.07940889216427292, 0.033813805385891876, 0.030631547394607748, 0.03399209385471685, 0.03460022068715521, 0.03613243418346558, 0.0194084187304335, 0.035402886902115176, 0.042914971842297485, 0.023863126656838825, 0.06925279035099915, 0.007735328898499054, 0.033902143859969716, 0.05097479060558336, 0.044284574421388764, 0.027075024754075066, 0.020666590592424785, 0.12000175432435103, 0.026809490252552286, 0.06832186744681426, 0.023374367704881088, 0.030541705965463604, 0.0650916811344879, 0.049139020897980244, 0.04517790648554053, 0.03155579012153404, 0.08581333314733845, 0.024937885414276804, 0.010149027237535586, 0.006356307829264551, 0.007049634063150734, 0.03067045459257705, 0.018011684928621565, 0.04487008907433067, 0.07872813155076333, 0.04186238082391875, 0.033780468960425684, 0.0025971404933703263, 0.039618306061519046, 0.09476648736745119, 0.06462327484041452, 0.043809718651963134, 0.018105638279978718, 0.026218062166922858, 0.0020118932256342043, 0.06598035166306154, 0.008848932089417108, 0.02779279775651438, 0.022123088062341725, 0.05055253826347845, 0.06526748277246952, 0.08134901377239398, 0.0265097202666636, 0.035928436022784026, 0.033174696644502025, 0.018497309048793147, 0.0188024920477931, 0.043905877242130895, 0.01165387880921896, 0.053533081364418776, 0.022806406752871614, 0.0673072404627289, 0.026385712902992964, 0.03965778322890401, 0.01663440981480692, 0.016104424771453654, 0.018736265333635465, 0.04322642959388239, 0.043757390031324964, 0.046388674194791486, 0.04621045357946839, 0.025879312040550367, 0.04146781949592488, 0.0514780057461134, 0.01731348766147026, 0.02693780800992889, 0.01280814830014216, 0.03880999443520393, 0.0341199841350317, 0.05629871885425278, 0.05948627620403256, 0.03608038376218506, 0.04957816536937441, 0.01645739359914192, 0.08980429292257343, 0.014475399595020073, 0.02294152003845998, 0.009799715713597834, 0.028885680184300457, 0.03750339722526925, 0.053839195652731826, 0.07463463156351022, 0.05626693627397929, 0.04507085740832346, 0.00903329683933407, 0.047566800976970365, 0.048235093509512286, 0.05467118475852268, 0.02940734808466264, 0.038643858528562954, 0.029546519009662525, 0.04725319226937635, 0.034045569199536524, 0.060336039534636905, 0.017624310982812728, 0.020177907975656644, 0.04289482953026891, 0.01220835981491421, 0.027453124822516526, 0.035216707071023326, 0.011933520901948214, 0.012813446810469031, 0.01490983842605991, 0.03532274513106261, 0.03145330758499248, 0.07626696290182215, 0.10798650048673153, 0.14576439905379499, 0.10730205542807068, 0.23467728016631945, 0.19554246083966323, 0.10009859874844551, 0.24668265453406743, 0.13740586542657443, 0.1698778915618147, 0.10092307307890483, 0.16029807632522924, 0.10508213311965976, 0.1486829003053052, 0.13887383522731916, 0.1335792536182063, 0.08043266580040966, 0.18535663240722247, 0.14843220875731536, 0.1617964037827083, 0.13898949830659799, 0.08403628386024918, 0.16511540354362556, 0.14725174781467232, 0.15732278169265815, 0.12444132752716541, 0.10170001603130784, 0.09016616243336882, 0.0941155958654625, 0.15842751812722, 0.10803771630993911, 0.13186578984771455, 0.1351410105292286, 0.08784630548741136, 0.15757264542792523, 0.09849535620638303, 0.14663337171077728, 0.13281835801899433, 0.08584456611424685, 0.1436653509736061, 0.10870539476828915, 0.15273581711309298, 0.09161182878805058, 0.16474504555974687, 0.1389323113752263, 0.07509526184626988, 0.21938098381672586, 0.15204672408955439, 0.15548161763165677, 0.1596538887492248, 0.1546470738415207, 0.13845474485840115, 0.10761047673544713, 0.18644387620900357, 0.1522757296583482, 0.11832711632762637, 0.06694085190870933, 0.13147652787821634, 0.15371792869908468, 0.1228973346629313, 0.13319446997983114, 0.16808159223624639, 0.15582275789763245, 0.14313694861318382, 0.12495789623686246, 0.10613304815654244, 0.19109501663063252, 0.12283245314444814, 0.11597344119633947, 0.10695866242583309, 0.08852585152323757, 0.12369484401174954, 0.07542006977434669, 0.1213506819414241, 0.10908111317881516, 0.21544822199004038, 0.15554177654641016, 0.1794057445866721, 0.13589676283299923, 0.08506587254149572, 0.1930423035685505, 0.163762201155935, 0.1809981848512377, 0.19232775191111223, 0.14107515210551874, 0.15703814982303552, 0.06454784210239138, 0.18175260722637177, 0.11445726826786995, 0.12787205486425332, 0.07278394765619721, 0.06116919232798474, 0.10609249211847782, 0.1793771375502859, 0.1247035405997719, 0.14883048167186125, 0.09532658409859453, 0.22144811360963754, 0.13256751719330037, 0.10313839491988931, 0.14270153269171715, 0.16844701048518929, 0.09408671062971864, 0.11427649296820164, 0.09520774547542844, 0.07267918863466807, 0.18807402944990567, 0.13689855193453176, 0.1196349382932697, 0.10487645558480706, 0.12534609969173158, 0.15781652448432787, 0.13714380163167203, 0.08674341466810022, 0.08459466389779534, 0.13993830739387444, 0.09887980057724885, 0.1376480481454304, 0.11090206368161099, 0.07867775032562868, 0.19545932672917843, 0.07595011418951408, 0.13204024120100907, 0.11646423914602824, 0.1382499901311738, 0.13216149540884153, 0.11557504614549023, 0.12011802808514663, 0.2766354429934706, 0.14893842302262783, 0.10463443571435553, 0.10021603280412299, 0.11396153058324542, 0.21867122261651925, 0.19941076183957712, 0.09299152118286916, 0.1522068583539554, 0.13607244912002767, 0.15235115561102117, 0.09108266646840743, 0.1966232449880668, 0.12722888509077684, 0.13754816779068538, 0.11071533762982913, 0.12413285193698746, 0.17232272108750685, 0.06729616677122456, 0.08116421476006508, 0.09731682230319295, 0.1088302723531212, 0.07317711798740284, 0.11178636444466454, 0.18359959311783314, 0.07793941601578679, 0.09415653188313756, 0.18190769319023403, 0.2229936263923134, 0.17684987959052834, 0.2208323837923152, 0.13779005195413316, 0.10374834361885275, 0.1953975393303803, 0.10174144059419632, 0.13557998197419302, 0.18226644822529384, 0.12276782946927206, 0.09008003598345177, 0.10420663974114827, 0.14049489609897137, 0.20764839409717492, 0.18736836660121167, 0.08701697963156871, 0.12887844443321228, 0.156204827395933, 0.10833752700792891, 0.06593573798558541], [0.09723678231239319, 0.015366653645677226, 0.03474409046715923, 0.036140559640313895, 0.03612416284158826, 0.015205654249127423, 0.05471903504803777, 0.05566781360123839, 0.028824211696961095, 0.044546085210250955, 0.05850850045681, 0.03574396949261427, 0.06825490282582385, 0.013894360728694924, 0.007791576058869916, 0.06110352370887995, 0.02318475109391979, 0.013162709988786705, 0.05298041459172964, 0.01868296810425818, 0.06069787511868136, 0.06035896723291703, 0.09356867628438131, 0.008147630524555487, 0.10662900975772313, 0.009683050946997744, 0.03917997922482235, 0.07575555784361702, 0.01594078417734376, 0.024768560393048183, 0.02400063686738057, 0.02592016663402319, 0.022828969738579223, 0.03839054783540113, 0.03204031501497541, 0.05932452702628715, 0.05099362673770104, 0.023641569706212198, 0.029336108693054745, 0.05022278381511569, 0.028178353228473237, 0.03655118528487427, 0.0330731470936111, 0.023231989005580544, 0.027135260004018034, 0.018388611131480763, 0.08721314410545997, 0.0209935308167977, 0.02315585907282574, 0.031093768841986145, 0.037790943402796984, 0.025113670088882958, 0.04076108116922634, 0.0349147522023746, 0.042319102744971, 0.017482032367427434, 0.035082292676504166, 0.0695659817595567, 0.02225731416339321, 0.027389132184907794, 0.017570202904088155, 0.022593870925317918, 0.05193826622728791, 0.048689352348446846, 0.00653310352104849, 0.001347330621294012, 0.043082692128207, 0.01578512485139072, 0.05595628258639148, 0.041031341667154005, 0.02243917342275381, 0.04136602906510234, 0.012194507522508502, 0.02973084304747837, 0.023497895005026033, 0.04808190744370222, 0.009322451144856001, 0.041180761863610575, 0.04410547171054142, 0.028924845225576843, 0.020570481196045876, 0.048793120708848746, 0.030418711315308298, 0.014690795447677374, 0.13226635621062346, 0.014870749719973122, 0.02104580176195928, 0.046694171016237566, 0.02270190727098712, 0.03183355860944305, 0.012853877319555198, 0.015048988995009234, 0.0415587771151747, 0.04065311946240919, 0.0039622327229673305, 0.044451331187571795, 0.04471186488600714, 0.008170123112254908, 0.03935815912804433, 0.04108624532818794, 0.05883267056196928, 0.008921969598824424, 0.01893441961146891, 0.07203339293066945, 0.031103614385106733, 0.037780317544404945, 0.04063507043091314, 0.06985336169600487, 0.023265264362895062, 0.012805457908793219, 0.02976927187825952, 0.05620463997391718, 0.010894159620095576, 0.03449127171188593, 0.013638663288605, 0.030585481652191708, 0.041821587298597605, 0.022354868839361837, 0.034269224519708326, 0.03084382028984172, 0.022585574138377393, 0.012741319386155477, 0.044499863404780626, 0.010723972859393274, 0.0373832829562681, 0.021292727440595627, 0.023805323954937712, 0.06173121609858104, 0.020087225163089376, 0.012844200562020498, 0.04200450337624975, 0.019890529735546027, 0.024322309963671223, 0.0356702568408634, 0.020927124290860126, 0.050497271586209536, 0.033667102722185, 0.050460698548704386, 0.05464897970003741, 0.04779460893145629, 0.021312978318227187, 0.017206837223576646, 0.04189996827127678, 0.07407690291958195, 0.06226723840726273, 0.05501081528408187, 0.025281614291348627, 0.05263053479471377, 0.08051624774400677, 0.043266656542462964, 0.05362740791003619, 0.059398358421666284, 0.019420033553615212, 0.042347404440598826, 0.009373438810663564, 0.010946515382134488, 0.06056321984423058, 0.059153271572930474, 0.03988090589908617, 0.06943401348377977, 0.019754429181505526, 0.013682054754878794, 0.02430878845708711, 0.06848666324679341, 0.07498307965163674, 0.016271756596064994, 0.024783762970141003, 0.039597576816699336, 0.054252579542143006, 0.0378286360230829, 0.0478960668801197, 0.0647414620699627, 0.03676391279857073, 0.011732386159045356, 0.09532883004950625, 0.07835977524518967, 0.05478500561522586, 0.057256582991353104, 0.059811871232731004, 0.033505801377551894, 0.014503623259120753, 0.04812387822728072, 0.018306240372891937, 0.04328087863645383, 0.056030972328569205, 0.027320154011249542, 0.024403332133910487, 0.023038696431155716, 0.0723896034594093, 0.04663746923740421, 0.04990007595292159, 0.024836513978828276, 0.03501674619370273, 0.03899916321305292, 0.07030611418719802, 0.112695513160101, 0.03571864317304321, 0.08974595926702023, 0.07180540516440358, 0.04301518467920167, 0.07365503734243767, 0.05513756562556539, 0.0131326534319669, 0.026049890655225942, 0.0303229225267257, 0.01749062940611371, 0.02404593925790063, 0.007280645975177842, 0.02748894807882607, 0.0427505017391273, 0.021275696211627552, 0.011193110274949243, 0.014141403454621988, 0.049730503266411166, 0.02950861265084573, 0.046650184983653684, 0.04004699091560074, 0.03621923916840127, 0.05731969353343759, 0.057811115735343525, 0.009644262492656708, 0.015202544862404466, 0.0242892636119255, 0.030070941762200425, 0.07943222019821405, 0.08599913639149495, 0.03939526142286403, 0.010148511550921415, 0.03117378508406026, 0.013079496998605984, 0.026542819204873273, 0.01648520674955632, 0.013499499997124076, 0.011547800885247332, 0.06992998865566083, 0.07286824884691409, 0.019289164504568492, 0.03816795442253351, 0.033274875554655275, 0.049212709801005464, 0.02320445914353643, 0.032430228378091536, 0.035937379114329815, 0.04249072799991284, 0.037661489099264145, 0.06048864884568112, 0.02374904795682856, 0.03295362315007618, 0.05827604114477124, 0.006356161520151156, 0.03746712952852249, 0.013501365120256585, 0.00694702726988388, 0.051478741956608634, 0.05986727361700364, 0.038621171710214446, 0.045242625155619214, 0.034354570654353926, 0.04180068163467305, 0.019684838629992943, 0.04140827804803848, 0.0274311979633889, 0.015223475971392222, 0.0384083831283663, 0.0392245352268219, 0.02491478468956692, 0.017577222348856072, 0.07080039302153246, 0.041859208672706566, 0.015240878698283007, 0.029549752229026387, 0.1153701828526599, 0.039539456899677, 0.016876804575856243, 0.04659006338832634, 0.06060160457023552, 0.01496911863796413, 0.03315815396074738, 0.058887116211865626, 0.046907678845205476, 0.018805199402517507, 0.043636057791965346, 0.02936918388253876, 0.0640177366190723, 0.05852116870560816, 0.012339463806711137, 0.011803137005439826, 0.07107972553265945, 0.00711162162977936, 0.03902652174500482, 0.023805639473721385, 0.042120258057756085, 0.0026550396744694027, 0.044925515207328966, 0.020802852298532213, 0.035632201204342503, 0.05658336429457579, 0.038836657468761714, 0.03984718270865934, 0.022385754057073166, 0.026780896786866442, 0.006362875624160681, 0.01491649485459285, 0.061943020804652145, 0.016018264394785677, 0.026161976158618927, 0.05296721708561693, 0.057223884388804436, 0.05944181180426052, 0.021414024056866765, 0.028646401595324278, 0.056190679115908485, 0.009639120045384126, 0.07892865221947432, 0.013446072997924472, 0.02030068210193089, 0.024414473678916693, 0.0432309927418828, 0.03856259038937943, 0.029233286889003854, 0.035873057387237034, 0.02937914477661252, 0.025104448797979524, 0.01960114303178021, 0.06154106344495501, 0.032050805166363716, 0.07627388395901237, 0.04098031583375164, 0.08680056088737079, 0.05331235392285245, 0.0397988574446312, 0.01686674020519214, 0.024941298445420604, 0.04759271422933255, 0.06412323524377175, 0.05226986289822629, 0.042001103915806325, 0.006554091881428446, 0.036675038281828165, 0.04679418707798634, 0.010207601773020412, 0.02187338039012892, 0.03298868644716484, 0.06788659401770149, 0.027444500642429506, 0.021139064703934958, 0.08920309732535056, 0.09684611577540636, 0.00977158110721835, 0.025170249731412957, 0.040797141912792406, 0.05517536002610411, 0.17345629526036127, 0.15819419707570756, 0.15995779101337704, 0.1160904477749552, 0.10906134745372192, 0.0757428692387683, 0.11162763474775211, 0.12357325053640775, 0.1369518983576979, 0.11652305456144468, 0.0978473009807723, 0.11494714340993337, 0.16039871663919517, 0.10298228436814887, 0.10108018786247287, 0.19082376547157764, 0.10092376518462386, 0.08279138244688511, 0.24512093833514623, 0.16931834444403648, 0.14475654384919576, 0.1667709204235247, 0.16141973542315619, 0.09433508837329489, 0.22362532892397471, 0.17565377163035528, 0.09317416923918895, 0.2058614178427628, 0.09056655237717287, 0.10012382668043886, 0.1887963842600584, 0.14257688580879144, 0.08607927137719733, 0.10979649264897619, 0.10278209618159703, 0.1335896352039916, 0.14574529150766985, 0.09383745757596833, 0.08475554455071688, 0.11785238608717918, 0.1251746610339199, 0.13358088210225105, 0.16730344827686036, 0.15646444846476826, 0.13241405971348286, 0.05103493934231145, 0.1725983555827822, 0.10910846492541687, 0.10767365513103348, 0.19790043788296835, 0.11785719011511121, 0.11630513625485556, 0.09321188900087561, 0.11346721103680985, 0.12727847242993967, 0.08598298725805112, 0.12514614899243626, 0.12219317816197872, 0.08731258341244288, 0.1952303618724857, 0.10845359042286873, 0.1176348477602005, 0.13733236651335443, 0.20272871665656567, 0.07498698801334415, 0.16538250206836633, 0.1937955452927521, 0.18386859154062613, 0.11735191222812448, 0.16854672799152987, 0.17096406327826635, 0.11041012579309088, 0.11768812632986478, 0.15519830211997032, 0.11479904635676316, 0.10615894783820425, 0.06263474654406309, 0.15987978662763322, 0.07957096703882728, 0.11605471612087317, 0.10613276995718479, 0.17247615142592362, 0.06452855135181121, 0.08864409982093743, 0.30058547641549793, 0.12925390500043119, 0.07742522217865501, 0.10473134408571891, 0.08583930746785232, 0.14896857711885655, 0.09409157572580235, 0.09519002892609153, 0.1561669244297913, 0.08282182831317186, 0.1180429458618164, 0.19462623500398227, 0.20688031959746564, 0.1249247837279524, 0.12627703616661684, 0.18011136672326497, 0.14318542315491609, 0.12100218635584627, 0.10036148357072047, 0.12454221211373806, 0.09181177270199571, 0.1120202826069934, 0.20211264757173403, 0.1139057142926114, 0.11560639446335179, 0.16423961839505605, 0.088964714402599, 0.13673360007149832, 0.0828245220971959, 0.09597641030060393, 0.09792375830667359, 0.14898681614015782, 0.05646799637803009, 0.180994412196534, 0.17057151719927788, 0.08633076359650918, 0.1600497325084039, 0.10673747358045407, 0.153668164940817, 0.1030834810808301, 0.0955366517550179, 0.099072904858206, 0.09947200558547463, 0.11176434598330941, 0.14761092354144367, 0.07532047440430947, 0.15647225161748274, 0.1090709012267845, 0.110296606884471, 0.09698123245366982, 0.18023909415517533, 0.13939229026436806, 0.07772962655872107, 0.13802474364638329, 0.11706111926053252, 0.09509343946618692, 0.08835732378065586, 0.10103336894618613, 0.13615718457315648, 0.13492828980088234, 0.10220219979860953, 0.2660248652100563, 0.10063265330557312, 0.06358352170458861, 0.14320392001952442, 0.1863955238035747, 0.19061783009341784, 0.1381492276809045, 0.22087363872144902, 0.17413358177457536, 0.13567159777241095, 0.07182981206902436, 0.14727160174931797, 0.15687916906816618, 0.1557208147964307, 0.1476596152143819, 0.0813664724784238, 0.11904192582837173, 0.10374054725148849, 0.11118988466582128, 0.14833892376295157, 0.1379128803632089, 0.13301404751837254, 0.13296408019959927, 0.10816833430102893, 0.08816240781119891, 0.13267106163714612, 0.181544744808759, 0.13309883725430283, 0.07335499594254152, 0.18979410215147904, 0.11421364705477442], [0.028747791690485816, 0.04797166585922241, 0.047446472969438346, 0.08547013692025628, 0.046792341462735615, 0.02952040558946984, 0.03734444361180067, 0.0409629690859999, 0.02351588805738304, 0.04303669763196792, 0.13192689871149405, 0.014309331541880965, 0.04624718946537801, 0.02598702099307307, 0.028763744048774242, 0.05322810362226196, 0.034892781238470755, 0.03906927962920495, 0.0192151600827596, 0.057238547530557425, 0.06560778165502207, 0.0018575877890855605, 0.006336111658518868, 0.050355841139597554, 0.03186689842758434, 0.04643181205860206, 0.019983852049335837, 0.03608742695567863, 0.04762784537992307, 0.016985531330906918, 0.029682850265609365, 0.031033559037106376, 0.02297474959466074, 0.017607288235532384, 0.004173399606120906, 0.02739673008077911, 0.03324759166155543, 0.03451587539166212, 0.028832421970686743, 0.039062782656401396, 0.017920842660324912, 0.03722066864637392, 0.01107363891787827, 0.05433577472077949, 0.022169745826561536, 0.018623623431527188, 0.015172889489414436, 0.046480279814984114, 0.03880949231929012, 0.008293669072112866, 0.08698716480284929, 0.015665850269475153, 0.022444547420101504, 0.030954811655517136, 0.02673293962808592, 0.022332594231037155, 0.02548058790021709, 0.02825650349924607, 0.05506522700722728, 0.019995843459452902, 0.06857539527118206, 0.055155180394649506, 0.029884344632072107, 0.023021940008870194, 0.04762397433764168, 0.10719640074031693, 0.03619917828057494, 0.08134154988718884, 0.035871004818805625, 0.036413388393287144, 0.05692933912255934, 0.025457315845414996, 0.05773033614137343, 0.03143304313666054, 0.021349235836948668, 0.05147776486618178, 0.029771884238081317, 0.052576357166149786, 0.01334379317371973, 0.027343517668279152, 0.023601967009848783, 0.03652927538912211, 0.029618460685014725, 0.02771325988162841, 0.07398858480155468, 0.04696691495233348, 0.07473286307815995, 0.0849534800010068, 0.016734125624809946, 0.07417120571647372, 0.01597366259167237, 0.05925050564110279, 0.02690832396703107, 0.02511095255613327, 0.029795185130621706, 0.019500928498538475, 0.018320116414023296, 0.04440447834453412, 0.008535034156271389, 0.012660383729131093, 0.030591859881367003, 0.02287556473830981, 0.01769458346201905, 0.03172167157754302, 0.030841900035738945, 0.01333535134991897, 0.027958222897723317, 0.037088754653398476, 0.06359289227319614, 0.05488744404699121, 0.03521803021430969, 0.02896100774939571, 0.0294358838748719, 0.035269476739423614, 0.03255606948265007, 0.09204225747713021, 0.012433295869933707, 0.03173904207402042, 0.039994703007063696, 0.018939272833189795, 0.03397557491968785, 0.03143946207793696, 0.020325375687597052, 0.036340584978461266, 0.028002197055944374, 0.006434488634113222, 0.06881366284298045, 0.03793355110766632, 0.04428352608478495, 0.02828845232059913, 0.02492645549188767, 0.0163601595309696, 0.045085727503257136, 0.12044562479215008, 0.032754676682608466, 0.03264355639527951, 0.023392688150384595, 0.04555034417925136, 0.021598400681146553, 0.02892003780496972, 0.04490601411089301, 0.038473227327423434, 0.021770210836880972, 0.062315095482128005, 0.04668599806193795, 0.02363559859804809, 0.09780494003955807, 0.04694319676075663, 0.0587423439802868, 0.05772484679307256, 0.05328959925100207, 0.06576903550220387, 0.009791397722437978, 0.03303963424904006, 0.019447061299745525, 0.11234975207064833, 0.008080087452461677, 0.022600739396044185, 0.02682975978989686, 0.022891213452177386, 0.015661633174334253, 0.09601027598338467, 0.04225594470543521, 0.043362082314810584, 0.009372633898497691, 0.047866028134844134, 0.01603254416425313, 0.06401760091206857, 0.05483682194192495, 0.043103299236723354, 0.04540696294446077, 0.060713481424110274, 0.02057596036632146, 0.023757339654756442, 0.03166599099391273, 0.0321032728866807, 0.017447929197390164, 0.026721435066844736, 0.061013027493442805, 0.058243166123117716, 0.011802187904582491, 0.010273713984393647, 0.047365801941071234, 0.012022888204748077, 0.05794366755123649, 0.03640662679182632, 0.025579245195591023, 0.03151884049709354, 0.04114237374493054, 0.05320425990170666, 0.028523763176053762, 0.04437809351033398, 0.03943366989759462, 0.057170341190482886, 0.0730421980842948, 0.019262486203972782, 0.014450935014922704, 0.004216409820531095, 0.033550849317439964, 0.08663265739700624, 0.0287072356524212, 0.017930406611412764, 0.041238081109310896, 0.044846394631479464, 0.08579052758536168, 0.025739642392311777, 0.06768907247377293, 0.02731399460961776, 0.07311729155480862, 0.026006673063550676, 0.016573457014081732, 0.05687576199748686, 0.010988636291585863, 0.02500559642378773, 0.07169836626521178, 0.07936515379697084, 0.024087828617276888, 0.0853851775505713, 0.023438470604430352, 0.06897290144115686, 0.03718104559395995, 0.061178067566028664, 0.056266912525253635, 0.03998338504295264, 0.03252604430807488, 0.02110742631235293, 0.0619806930688875, 0.05867592218731131, 0.016950707217412334, 0.05661295520673905, 0.047887992313397784, 0.022204347719837512, 0.02506259166901665, 0.03978451999968716, 0.04782162819589887, 0.020577690630619015, 0.02945003133001072, 0.03983546780156238, 0.02735657268203795, 0.028295407304540277, 0.027808612711461525, 0.05986263243747609, 0.021267584325479608, 0.014935939971889769, 0.10790389563356127, 0.05635737142126475, 0.018207888418276395, 0.01819695552278842, 0.02679059305228293, 0.01489421515725553, 0.05023709072598389, 0.035086519949670346, 0.033865601356540403, 0.047035318067563434, 0.017449751063915234, 0.03634892078116536, 0.0340616979769298, 0.01776845726583685, 0.06757112951683146, 0.030940165477139608, 0.09124991856515408, 0.07070385784442935, 0.037323605801377974, 0.026750676533473388, 0.015145714161917567, 0.08079745979713542, 0.026675303167264377, 0.061121593096426556, 0.0065900326091130924, 0.03635985876566597, 0.030909417662769556, 0.023286670446395874, 0.02644601770277534, 0.042825418790536265, 0.02000034723563918, 0.018981160496228507, 0.07051859742828778, 0.03365107572504452, 0.07076101084905011, 0.010401935050530093, 0.010849395816746567, 0.03875257001657571, 0.01345088126670037, 0.03895801006417189, 0.02849411458841392, 0.06159632333687373, 0.05328908695706299, 0.03709594373192106, 0.05914679156350238, 0.0347432558690863, 0.02725822581643505, 0.034592102015657086, 0.018782819621264935, 0.016087032222588147, 0.021708996800173606, 0.012922764739154704, 0.023950235286195363, 0.031552020859505446, 0.03408189117908478, 0.045294017397931645, 0.037168784466172965, 0.036445289717188904, 0.10823227265583617, 0.03957586030342749, 0.03748207426230822, 0.023470085247286727, 0.011553896674221116, 0.043203529037003, 0.018369284757812108, 0.04207121693928327, 0.02609026857784816, 0.06146488431841135, 0.037248838027673106, 0.0031546948386156665, 0.013594606858012932, 0.014780860793377672, 0.03300699332196798, 0.03876685317871826, 0.02817281468638352, 0.05905254304941211, 0.06885826294975621, 0.03671453580526369, 0.03135413969201701, 0.03127037115128977, 0.04318767845896738, 0.033925227621304135, 0.039086168365819116, 0.04220364322619779, 0.007499397183502359, 0.028885398592267717, 0.04390094429254532, 0.03714299335011414, 0.0194799821225128, 0.030019498629761592, 0.030198896503342048, 0.02481354896112212, 0.02174756133795849, 0.0014807842526352033, 0.06790643438164677, 0.07304892915167979, 0.041267336146639924, 0.09650355058589152, 0.03555245637627585, 0.049629371014556715, 0.022509435723934854, 0.0638208936101624, 0.04685962838785989, 0.04577599099970289, 0.004419715027324855, 0.0506226445016052, 0.022028500280742134, 0.05306852914925132, 0.09738257234649998, 0.10325369837560824, 0.176958295915808, 0.14362280682793685, 0.08660433534532785, 0.14311374271554606, 0.10496938774096114, 0.11726743461830275, 0.17772269275571617, 0.13944404891559056, 0.1704591518001897, 0.11845867069704191, 0.1379663489226784, 0.19304184216473783, 0.1415433684097869, 0.11988598267946925, 0.12642999153052056, 0.15720862496112073, 0.10088552973632302, 0.11867044147636209, 0.1379961230392967, 0.0918329633506281, 0.06274022481271199, 0.12132968806794711, 0.21148506179451942, 0.129712648955839, 0.09731465777648346, 0.16467322941337312, 0.26820600245680126, 0.13847248176378862, 0.1422891869608845, 0.08020236422973019, 0.1249487902969122, 0.08126068886901651, 0.0723774576825755, 0.17355451998966082, 0.11464512747313295, 0.08588778200958457, 0.13989021283175263, 0.19282993567841394, 0.09857499586152178, 0.14071965403854847, 0.09283119692866292, 0.16179463959165982, 0.14447742168392452, 0.1487901766917535, 0.24605465680360794, 0.1069455531292728, 0.10457105375826359, 0.11431578014578138, 0.18096055329910346, 0.10056642828775303, 0.08167882250355822, 0.13150057515927724, 0.14523993219648088, 0.07441190922898905, 0.11059985775500536, 0.120023766000356, 0.13557449941124233, 0.09155322371848992, 0.15511079824396543, 0.10912162171942846, 0.09779460595122405, 0.09237540460058621, 0.1869740563311747, 0.1746674802686487, 0.13126858403640135, 0.1524102831525462, 0.1912277787923813, 0.12808069081178733, 0.09981638246348926, 0.17598173474626883, 0.12146090316985335, 0.11726568399795465, 0.10166832166058676, 0.1598452627658844, 0.08982798736542463, 0.13864811376801559, 0.11319334073258297, 0.11826584461544241, 0.11876341434461729, 0.14883468858897686, 0.13819721367742333, 0.10256006595279489, 0.1785838079771825, 0.11792053814445223, 0.17431371925132616, 0.14199265358703478, 0.11478960114930357, 0.2398917946432318, 0.12110501155257225, 0.14556447549590043, 0.11285635988627161, 0.1271608415991068, 0.10562758027975049, 0.10676422821623938, 0.11566990534109728, 0.16812273859977722, 0.09166303782590798, 0.15341216724898132, 0.1618519350886345, 0.20480894217533724, 0.18127034524721758, 0.09703115227499179, 0.13412809345339025, 0.08948622963258199, 0.04729974655700581, 0.1057022191318018, 0.09143986765827451, 0.23103251574294908, 0.14941750945789473, 0.12757267164332525, 0.1562895628490618, 0.1762888261250087, 0.08946748849536691, 0.17289297548787935, 0.1261479380939688, 0.09099204133131675, 0.10865669631000076, 0.07437656433986765, 0.14085356970982893, 0.14320691914430686, 0.1245296863572938, 0.10778111472193684, 0.14828151970037393, 0.11852271083210196, 0.20592800926949295, 0.14702819766742842, 0.20036331644015654, 0.07946483737656049, 0.12194359941141945, 0.1751183939299413, 0.10745529577668224, 0.16016828614686215, 0.08920697176030704, 0.1314488843615566, 0.11658621260098048, 0.13253896443971566, 0.09356896805443934, 0.10628191195428371, 0.07954713688897234, 0.15454484575561114, 0.09810836732919727, 0.07726003282836505, 0.15813390245395048, 0.09947847202420235, 0.18584008860800946, 0.08183286352349178, 0.1189732580844845, 0.1360445749014616, 0.14373941985624178, 0.1200393723057849, 0.09890864510089159, 0.12510325200855732, 0.11058159159230334, 0.2248672108565058, 0.046572791279426644, 0.07686658429780177, 0.05810990184545517, 0.0693132138944098, 0.07235974113323859, 0.16247035190463066, 0.1453638734029872, 0.2070571051112243, 0.19391567313245364, 0.31546496227383614, 0.1168061393712248, 0.17266375278787954, 0.12346638127097062, 0.12437651386218411, 0.14205767081252166, 0.148935736023954, 0.12959087906139238, 0.1776561148996864, 0.12960579326110228, 0.1678916567138263], [0.02840866836985307, 0.01650666881219617, 0.01618552497322006, 0.024565873501290168, 0.020455014891922474, 0.03578387413706098, 0.05841287451663187, 0.020192253902288418, 0.08969460095145873, 0.04689204879105091, 0.05276326981506177, 0.028712982844029154, 0.018244425832693065, 0.042383695886071236, 0.03247448243200779, 0.03353765181132725, 0.016272312994780283, 0.0854888984135219, 0.021002696128562093, 0.016694383828767707, 0.008195909139301096, 0.016175969503819942, 0.028918718054358448, 0.03376016379999263, 0.018246469919436743, 0.006581783319623875, 0.011380936401630086, 0.048313331989837546, 0.03393673218254532, 0.061218643960143836, 0.031172852098409618, 0.07820084877312183, 0.055741380367960246, 0.03217409837192722, 0.01675109748196389, 0.014056140440516174, 0.10855040379932948, 0.0812492962660534, 0.03520017456529396, 0.029601436241396835, 0.05797625758818217, 0.049717577174305916, 0.02594887714699975, 0.04115753221724715, 0.07146786791937691, 0.05776002883378949, 0.03863283572718501, 0.028221467343558158, 0.05323074312348451, 0.04797574046200939, 0.031849266695124764, 0.04348553158342838, 0.06788566442472593, 0.06020105177802699, 0.009458074179877127, 0.06411199870386294, 0.04059095886935081, 0.010796420891503138, 0.005352669719806207, 0.03587359003722668, 0.04211996289502297, 0.024945140649963702, 0.052305849002940316, 0.030361069765474116, 0.02267647408215063, 0.013062062041301812, 0.027156981606302515, 0.0535992894188634, 0.041244981810450554, 0.10532021748700313, 0.02320801805970924, 0.02659403333174331, 0.039228582688208134, 0.046842315566859076, 0.018221250469131128, 0.03080120150532041, 0.0015471757235770512, 0.045760601825479946, 0.022989070076229315, 0.0689386489934155, 0.040809565888983865, 0.03620376856997609, 0.014664510697392481, 0.013685272707204734, 0.04610516190794962, 0.05221006360703281, 0.07189494464546442, 0.03208838922104665, 0.008647640435291188, 0.051292155004505596, 0.0026254612727955517, 0.03842895631013172, 0.06111271785838263, 0.04288631391578487, 0.00903786507634712, 0.040595735755882094, 0.017153797837506448, 0.031810166114675145, 0.04833175760826894, 0.0588464176814471, 0.052046594343015125, 0.01622730746333088, 0.018669304105320146, 0.01143906734484647, 0.00440602219064853, 0.05811811211918082, 0.027072772017813156, 0.030178530274757316, 0.013326732258844589, 0.027324382980753268, 0.05737954032208238, 0.07807050898138966, 0.06397870049944945, 0.023902705604476587, 0.04198491067758628, 0.018513700758506144, 0.04709248125020947, 0.1160340750856059, 0.07420134624200207, 0.03191367323909487, 0.09108738907213722, 0.06372140002037797, 0.014333509440932955, 0.0009139699187861489, 0.04087115651262658, 0.062371101762567244, 0.04593445946063314, 0.05312528521088617, 0.06318391886140619, 0.05477084798206176, 0.05129656548212681, 0.02027739308375333, 0.07377502268978528, 0.08605314099362918, 0.07140143934105124, 0.02941035060212016, 0.04699600035590785, 0.029497447357113873, 0.027637621886762123, 0.01891463522666267, 0.034282449167221785, 0.05868460065019982, 0.011777251742647162, 0.09051347058266401, 0.03551369506333556, 0.061577059727694304, 0.020641396587182368, 0.07839445516999279, 0.0499757292148258, 0.0478039421806378, 0.011494179655398642, 0.02367778481649501, 0.037670449154185395, 0.03305716420124684, 0.06598653990243163, 0.031459326190607886, 0.0859337459717478, 0.07037785569471972, 0.05668454743655665, 0.029024467737014805, 0.07432975220893111, 0.03567897601585303, 0.004952971033552396, 0.0173751919397286, 0.10022472483771187, 0.0216196880210191, 0.0037165088994827655, 0.024943943035655787, 0.05414151693029063, 0.03708197948123727, 0.026126422619979297, 0.010797646495380571, 0.05182529693203313, 0.031584644823202064, 0.06843315397522279, 0.06818255063678537, 0.07196166499384812, 0.06999909066195999, 0.018764399091846178, 0.0445977217251701, 0.02710495832642274, 0.03817597809912903, 0.01744938804768026, 0.019399227973605906, 0.033863253625375886, 0.030354084247457128, 0.07418498676270247, 0.040280980324106555, 0.03960970223748258, 0.02906641477186765, 0.00279819275185998, 0.028833490663341114, 0.019880222788612758, 0.04454277056668486, 0.00805445748846978, 0.06126753240823746, 0.02411116174023066, 0.025561021441327672, 0.03038896434009075, 0.02323992786529873, 0.05543991065184985, 0.10312141118837254, 0.05318082330216255, 0.005480140580662659, 0.06930669317288057, 0.06328767365110771, 0.08667251454400164, 0.03745374881795474, 0.03890058903821877, 0.03728448825755289, 0.10143428136195455, 0.034543457840170176, 0.04022815637290478, 0.05880817544779607, 0.03182678682995694, 0.04310041885556919, 0.03730074256392462, 0.027179758330540996, 0.0798599279618689, 0.07396612529243742, 0.019668207736685872, 0.03864523595465081, 0.07938624945070062, 0.05024469031819275, 0.026019453270626918, 0.01575446015756045, 0.03349092788994312, 0.03091892393838082, 0.07023537691150393, 0.04332043044269085, 0.01737137687658625, 0.04192202405205794, 0.037283582413303, 0.001768706486992804, 0.026990920338513594, 0.061830085436148305, 0.03340503553460751, 0.03427615914759891, 0.07029385984476123, 0.012956394631016468, 0.02002252176004861, 0.02014352151724909, 0.026332115421869924, 0.017950477677264383, 0.05888778796153409, 0.06379052916807787, 0.025635702701817666, 0.008073419997734683, 0.04572671917932374, 0.027798948676458428, 0.02234373747238091, 0.037616814353636334, 0.04868795117363334, 0.01702873535188181, 0.022311591875872443, 0.022280881380928413, 0.05744963298950877, 0.07029892171600036, 0.04633012001535722, 0.004166804669824029, 0.04047642894355314, 0.016365033108741045, 0.08167124326739993, 0.039905445118035586, 0.06090044496314866, 0.008758904063142836, 0.05052604486367532, 0.0334135274003659, 0.024732207879424095, 0.034281590820423195, 0.04007666325196624, 0.05756210695419993, 0.018500133450808268, 0.03192169352301529, 0.05836463067680597, 0.027735924647588815, 0.006215523263173444, 0.023156451094629507, 0.03160667685525758, 0.013446060275392873, 0.09599034062453679, 0.04142286655093942, 0.05657595469217215, 0.006377235969661602, 0.012259674025699496, 0.06298612590347018, 0.0363857516619776, 0.0493328783528081, 0.042070585901715925, 0.025237400949533497, 0.05165187695196696, 0.02940434556720512, 0.13766004464456014, 0.042976803345871825, 0.016452340209590535, 0.022056138708389232, 0.06534691886710269, 0.025754561681034308, 0.007219029906471925, 0.036786195888583145, 0.03267376816698483, 0.07165597818259682, 0.030540929042867253, 0.012066740226665778, 0.03746629832312465, 0.019826224971828715, 0.016137125070339868, 0.012473272608726152, 0.020760586352220604, 0.0661800377336996, 0.03676190772759063, 0.07243703305721283, 0.018383798621860997, 0.02524041703769139, 0.003861432953272015, 0.029577952144401412, 0.02742779002125774, 0.02452322418269302, 0.11532275325485639, 0.04590488551184535, 0.050040074690644226, 0.00760621895148818, 0.01997351287198918, 0.05325101096449154, 0.03251186631886022, 0.0062798377808316475, 0.06796814035624266, 0.0253722207687263, 0.03064936911687255, 0.011416582390666008, 0.020614835333877375, 0.02051316195034555, 0.012183311694700803, 0.07544202038219996, 0.04103821183421782, 0.009957265607746584, 0.02919608959928155, 0.03109393169039062, 0.03413030804534044, 0.045858405863067934, 0.013566481581489955, 0.04595036432147026, 0.004294847196433693, 0.024106434047488228, 0.04343072630997215, 0.03286841272243431, 0.006759118022663253, 0.027818412453468357, 0.07437406733099904, 0.028991423081606627, 0.014724781570423926, 0.04548875016293355, 0.14323263562151364, 0.24038321684513772, 0.10572336906833307, 0.12592813346002782, 0.11377606660659824, 0.0836727994361094, 0.14730293649647916, 0.11064728735280888, 0.12368339034063475, 0.12032339349389076, 0.197212335520557, 0.08480983413755894, 0.13401874074978487, 0.10020265887890543, 0.1194173049713884, 0.11219204017626387, 0.11838567389973573, 0.2200315496219056, 0.0715181337935584, 0.19033794796892575, 0.08561875644539084, 0.12925884473536695, 0.11424494108983449, 0.13416681066155434, 0.13249601317303522, 0.1785443986632994, 0.06258669947939259, 0.14638515003025532, 0.16107913798519544, 0.1399040820875338, 0.20331634155341557, 0.16845436580479145, 0.11295514101428644, 0.0988519602854337, 0.15005347318947315, 0.0624152540362307, 0.15701668097504548, 0.20861023105680943, 0.10253023076802492, 0.08975424417959792, 0.1884752336357321, 0.15795308644218103, 0.14443885375346455, 0.1798300596752337, 0.15346039751810686, 0.11545624823442527, 0.1207935232669115, 0.13818308657833508, 0.15641169915241854, 0.10764962142067296, 0.10860510729253292, 0.11152832436242274, 0.13884381683809416, 0.18470521164791925, 0.0745293093579156, 0.18388052018625395, 0.08831969222852162, 0.0699098768777081, 0.10046175747577633, 0.13333517100129808, 0.11110161404524531, 0.1561987070100648, 0.12554207417581761, 0.08090057676391942, 0.10641714398350034, 0.1433362207774605, 0.07327512558549643, 0.06808502479855504, 0.12734184760068143, 0.23488871167813027, 0.19516368902155332, 0.11694469622203282, 0.15922337185059274, 0.13693792053631373, 0.07661910222045012, 0.16052826254495553, 0.1176476449306522, 0.0902204384495105, 0.12172265483864717, 0.10624820233455726, 0.14556725748947688, 0.15276137074189527, 0.1347599181213549, 0.11447645723819733, 0.09180624942694392, 0.09424048702099494, 0.1240844859608582, 0.12153613913272109, 0.07554739687059607, 0.12732196652463504, 0.13765525418732846, 0.09561434401465313, 0.12699289061129093, 0.15280399631176675, 0.1344649318073477, 0.14421348513237067, 0.10176394760076489, 0.07636803747820002, 0.0854507918868746, 0.08645136641072375, 0.2264504094741174, 0.09879762998649053, 0.10144550433116299, 0.07305594520377261, 0.13391147793403693, 0.21851209258394583, 0.18173568456300668, 0.11192367279103824, 0.11298832816204854, 0.0894985179017697, 0.12002116042588439, 0.12926420516201428, 0.1322807954358203, 0.11325910434659038, 0.1588287494544472, 0.09247483712221895, 0.1705267746001482, 0.2074125488953931, 0.20205573205436977, 0.08784148110342876, 0.20054554380476475, 0.12021471932530403, 0.0899989917608244, 0.1408600022218057, 0.08712901254849774, 0.14011361370129244, 0.14454584515520505, 0.29503047306622776, 0.17336415020482882, 0.15059590765408107, 0.1504266131669283, 0.1219189821609429, 0.1803325012858425, 0.1692311391234398, 0.12830201536417007, 0.22957176555480274, 0.10176714350070272, 0.09309418353119067, 0.10698441961514098, 0.1405994990574462, 0.2554383889905044, 0.07757806897695575, 0.16222755850425788, 0.1200114166630166, 0.13914975470730237, 0.11090108659118414, 0.1219414688114609, 0.16834618018141814, 0.08074508367904595, 0.10506287629583053, 0.15327909296112402, 0.07798482357923474, 0.11471922349716936, 0.07787191535213164, 0.09547227235244853, 0.13022098025040968, 0.2169129212519952, 0.16659432489957127, 0.1870156233864171, 0.16068131290376186, 0.11352561254586492, 0.08439214155077934, 0.06192737378712211, 0.14130954524236067, 0.22497802919575147, 0.14837899804115295, 0.12894262027527603, 0.0806536375145827, 0.14509737198906286, 0.09415754968566553, 0.08937069547495671, 0.1064203263127378, 0.1934682742825576, 0.14354028339896882, 0.11101529082017285, 0.08215941528656653], [0.01020261793330844, 0.06048123924327748, 0.008208534979660596, 0.046649981423148086, 0.027416064936135496, 0.02752715808206371, 0.025138970963390808, 0.07145492147122111, 0.03838651055204017, 0.04105860859687839, 0.01750011362933687, 0.03882036923563906, 0.07612417877784797, 0.02172914080853973, 0.01897485860224281, 0.06378193891474179, 0.03378620597400835, 0.07119141918207918, 0.024947060904066478, 0.04827631451189518, 0.048916379987661324, 0.04451904898243291, 0.10372448632759707, 0.04825689823233655, 0.05563361204362341, 0.05361923495573657, 0.026067035538809638, 0.04513020547372954, 0.021704643998028975, 0.006046866174853806, 0.06400631008935825, 0.03949138269360576, 0.04626580846628972, 0.029199947070862566, 0.05555477984515684, 0.021858847866367017, 0.03783860709518194, 0.08124095028532402, 0.023224016219111424, 0.01823922655811267, 0.025033450286303247, 0.03993603347667626, 0.042761443116303, 0.07224414590746164, 0.03558905655518174, 0.043390852199601274, 0.015642839450655237, 0.008446632069535553, 0.033155745161431174, 0.04473416493939502, 0.03173089626112154, 0.059058276670319695, 0.03949035471305251, 0.05513800328065242, 0.053258284859891446, 0.06412153212087494, 0.020021339412778616, 0.04350230836176446, 0.04769233674077051, 0.053953233640640974, 0.040650045698774714, 0.021092573180794716, 0.031294716987758875, 0.04771766984569175, 0.034152655596179624, 0.040358770971319506, 0.08137548342347145, 0.055669448870633326, 0.04818618131269302, 0.021537883839170848, 0.06978586781769991, 0.024258310540712306, 0.05160461359524301, 0.04578118518527065, 0.025227124536676065, 0.03523635405248829, 0.008438572769851556, 0.022201669202851396, 0.019728342902713587, 0.02706516394391656, 0.02394119550340942, 0.07416716843311276, 0.029475316937480654, 0.04615924454161099, 0.06568491751594202, 0.03858182007180793, 0.016354264757995094, 0.009376834878431899, 0.07284974519695554, 0.07137571607849427, 0.039892800617963076, 0.026091347448527813, 0.015492672865678157, 0.057734882325998375, 0.036315648816525936, 0.08688261612717595, 0.0030843735897048774, 0.024170299459780966, 0.05239628075755068, 0.02716654386105282, 0.008220438180225236, 0.005253545507522566, 0.025846391217783093, 0.025745718673403774, 0.008781133718522531, 0.004370924542724554, 0.032090723381510804, 0.018193011537992528, 0.014838378510570951, 0.04968800661819322, 0.05864025838673115, 0.025906494153397422, 0.09068220188575131, 0.026212793342503052, 0.04880450652646167, 0.028749559274209396, 0.023950866323762705, 0.07604983848120485, 0.05995746449168239, 0.04277464062241571, 0.04539927514269948, 0.04034947164888893, 0.042430969420820475, 0.08414304456008331, 0.04450960377497332, 0.020596150175801346, 0.02057010291277298, 0.038398310276014466, 0.014386067067139914, 0.012904827665936733, 0.02234278921969235, 0.053930672351270914, 0.03054998070001602, 0.05453046677368028, 0.03889594446601612, 0.07995442074856587, 0.059666230476328304, 0.025030598742887378, 0.0350918159154909, 0.026782119846237556, 0.024888739122876098, 0.03130235050671867, 0.03501318049217973, 0.007790833911193269, 0.014207660702855458, 0.0060339269361325675, 0.04365623063806977, 0.04282939500574555, 0.024575262729610716, 0.03948335223166006, 0.021859650234026567, 0.03122547927445599, 0.04950585728511214, 0.03042868578008243, 0.01797827216796577, 0.027105792924495678, 0.02974186584885631, 0.04284166970423289, 0.018736977795405046, 0.01453124133071729, 0.06590166874229908, 0.03810337145945855, 0.06143342064959662, 0.015552110836974211, 0.05137592015255775, 0.04766928351351193, 0.06692234825875078, 0.031981061944471936, 0.0212524767432894, 0.042626988009682724, 0.060029009224048684, 0.05402329916666661, 0.03582181442262871, 0.00956802993148033, 0.04755515053070017, 0.013914866905127252, 0.013089943893386849, 0.05498320908684816, 0.076698382252029, 0.020153972652873824, 0.02179254312068224, 0.08064334413834981, 0.04744569943951709, 0.05462366695116673, 0.03252958965354732, 0.04532885677846415, 0.04302105061443789, 0.021061933932027647, 0.022482385925416435, 0.020063172793015838, 0.028377101224448, 0.04229992055999381, 0.056863799425108094, 0.044120039857391796, 0.02606086935182767, 0.032415395602583885, 0.03201129746490291, 0.013914078108168073, 0.042791386866675954, 0.043246246209102016, 0.018282315228134394, 0.05683743155428341, 0.03884476935490966, 0.0392950689420104, 0.03526393650099635, 0.02218293654732406, 0.03397026877584202, 0.022407799659829055, 0.051014630789203305, 0.025465230956407528, 0.036835135226803165, 0.05060982697510293, 0.020670510828495026, 0.038480321411043406, 0.014058560266026428, 0.008479970191339297, 0.026949473723237003, 0.04149922548926302, 0.011811523698270321, 0.015154742070340683, 0.029978118171649318, 0.05590592510998249, 0.0053980785555073196, 0.0357996806103204, 0.010167788730801215, 0.00892755139752158, 0.03373475605621934, 0.02156019237424646, 0.010927654653122383, 0.02034865113507424, 0.0021790314557230367, 0.015498800036896552, 0.007998127207559134, 0.0017083682905649766, 0.030780221202543805, 0.02966695897547262, 0.052577571743833165, 0.03848555970138737, 0.03639869471745832, 0.02642843346776707, 0.034211525294397555, 0.06579367989408118, 0.033935816160270145, 0.08915614270206008, 0.024812453127067004, 0.03867532219737768, 0.05496485471459372, 0.015454242338559456, 0.0068435396533459425, 0.018185015002797757, 0.02999219438061118, 0.011206605488301387, 0.025206729470353042, 0.03574612723397357, 0.015503855122785484, 0.03651468688622117, 0.033792757229613404, 0.00630404070086245, 0.02438488107041589, 0.10117886042488472, 0.07259527420891182, 0.010427589611416417, 0.023525759045566832, 0.01648435179543282, 0.02751900039480201, 0.05142846590440188, 0.020689492845641713, 0.05429404481713261, 0.033354555921895165, 0.015198183578572102, 0.04558898674856339, 0.03932296012395194, 0.05398329613464219, 0.0833967374637723, 0.013148803413579506, 0.015109712790165628, 0.05289526523223945, 0.07251183475766863, 0.02837918941596789, 0.0432146773673594, 0.034931654509689124, 0.1197596937417984, 0.08231083037597792, 0.04848066551078643, 0.04830806655809283, 0.08930162739540849, 0.006512378092988261, 0.03299835217850549, 0.09098375641873904, 0.005161725724714675, 0.021851823332586458, 0.05407604508634124, 0.03068972159443157, 0.005172060661217464, 0.06985370774886437, 0.08109583200088569, 0.020222133191834604, 0.019577450285266553, 0.032819008587726524, 0.049724087717809846, 0.053589691541024616, 0.021607045217284133, 0.015573455852323344, 0.052139014205230136, 0.005852276750374585, 0.02470058814755508, 0.0779261981536235, 0.07182681972959212, 0.0051907907722384804, 0.02387382715408291, 0.04873920092359185, 0.020765324222988317, 0.013467570683652801, 0.01661427428812853, 0.024992724614483968, 0.06388656901461737, 0.0205711224116385, 0.023393461680305854, 0.09685315218354974, 0.02078024690438594, 0.060542836652270386, 0.023355892892660837, 0.04021231936556952, 0.06981791502663068, 0.047331183084419796, 0.05846564418503216, 0.034032721138958416, 0.03330703472186412, 0.025045365361230712, 0.019438331946730614, 0.04597741411998868, 0.012282194602968437, 0.04850730140294347, 0.023919324623420835, 0.024646200173135315, 0.03682375619454043, 0.048978476119892936, 0.02058607223443687, 0.031357647718063424, 0.0066884244276609805, 0.05308908197496619, 0.04373138517673526, 0.0742155886920435, 0.014205064458240355, 0.0056578009805109885, 0.015263923443853855, 0.07472683768719435, 0.02981811961425202, 0.03315383169267859, 0.017518050702554838, 0.020885998283379843, 0.05010486799957497, 0.07666541223547288, 0.15591151027807168, 0.1148653935108866, 0.09327398174043212, 0.0950362728908658, 0.15595222237919057, 0.10562613500016076, 0.201437111677868, 0.12374204290764672, 0.07329586840101651, 0.12447572925261088, 0.14873284048267774, 0.13208412884601525, 0.1268593142075198, 0.10030827963990824, 0.14804277036871227, 0.2307581433228084, 0.10234858015818254, 0.1449675275278943, 0.09519328589418105, 0.11144183828894581, 0.17243451651717934, 0.1567801029554435, 0.19872298517397471, 0.08774504770657846, 0.15722067574305193, 0.15617208129593305, 0.185365494074566, 0.1041767977710281, 0.08397078487489905, 0.16065795772841998, 0.10649570476795946, 0.1199018196868045, 0.1108223358169198, 0.12346408782260758, 0.1212557413216148, 0.128830987694008, 0.18052911359284604, 0.08092973341367074, 0.08666695055684873, 0.11326569970697165, 0.1329847348055669, 0.11609420685895852, 0.10788106971553393, 0.1616186818906239, 0.16205717836107525, 0.140798703368221, 0.10051555173205477, 0.07185942333723817, 0.1293880920857191, 0.12575250145580086, 0.13139655574091844, 0.1047264247068337, 0.1615711980100189, 0.10399146271603447, 0.18239425708140644, 0.07400389933692557, 0.1412412574780839, 0.1080842095294169, 0.18184414160038742, 0.10002719650843314, 0.11143309875790562, 0.14933821585561546, 0.09322448261082172, 0.13201973587274551, 0.1304095722734928, 0.16765340949807847, 0.14512740394898824, 0.20336082630923816, 0.12663132644125394, 0.24262832637344087, 0.11017451129321541, 0.1516666766256094, 0.17501411666827543, 0.11575416581971304, 0.10579055082052946, 0.1523421582366739, 0.17724463769367763, 0.19187717751732894, 0.10317897131400448, 0.11618933746857302, 0.21165637831602777, 0.09535500114517552, 0.1891884689352342, 0.17130092877362454, 0.12299455516040325, 0.11485725109066282, 0.12058336740093571, 0.13161653679396423, 0.1504410252507244, 0.10900901204773358, 0.09389880392700434, 0.0673467990543161, 0.11266793071159295, 0.09299835403050695, 0.1131681806540915, 0.11257839801588229, 0.10976374654897622, 0.15222630516758986, 0.11320602255208151, 0.14173897648496286, 0.11572231538593769, 0.12305626113499914, 0.12367744637387139, 0.15539559296199254, 0.1448414692921298, 0.14900529943406582, 0.11078459569918257, 0.07436124301914658, 0.15943316130765847, 0.14675810001790524, 0.1059673431196383, 0.2879593239298889, 0.17567502334713936, 0.0727884666994214, 0.12113664485514164, 0.15853349172643252, 0.13980682087796076, 0.1562005119132144, 0.203421148072396, 0.1294178662023374, 0.11789316604179995, 0.11496497531022344, 0.21667789029223578, 0.14927463712436811, 0.13441797718405724, 0.12624677350478514, 0.11946754370416914, 0.07409770680325371, 0.12589953999434197, 0.17570771516433784, 0.13822337798774242, 0.09756798204034567, 0.09948354746614184, 0.14710601206336701, 0.1567806593541588, 0.08579504662858588, 0.14141275041869708, 0.09747428992497069, 0.12406197216893945, 0.19426965128098214, 0.15560473102544034, 0.1565127330166953, 0.15426345728337765, 0.1323902431343283, 0.06037228008998292, 0.19863605126738548, 0.12748944253793784, 0.09186280532074825, 0.10602425863700253, 0.16280846590442316, 0.09521402870970112, 0.07878715731203556, 0.09565481184316532, 0.096727813194905, 0.09875433266695056, 0.11347967572510242, 0.10261898314846413, 0.0718649805390409, 0.16584972771150724, 0.1414670060787882, 0.1090503687571202, 0.10543910360762052, 0.15384697248893126, 0.08910732889281851, 0.15726668041731628, 0.1882290882723672, 0.08411588958863701, 0.11401854109551225, 0.12003853092236177, 0.14899419860116073, 0.13428628710763796, 0.12144288127975804, 0.0781702943412321, 0.06405436393937894, 0.08754395028310162], [0.04038462315553001, 0.010021304894637848, 0.047133417267884524, 0.0171163189557514, 0.07040900723742587, 0.04688568752525108, 0.04804743107940469, 0.03440202060820801, 0.035413550079933236, 0.0434991769226534, 0.02000610121259732, 0.043198297532009225, 0.04144911228546074, 0.07440606704247849, 0.015804064460098743, 0.019395282292472463, 0.03425195919615882, 0.016281566516097103, 0.021116435561063032, 0.03612963183383856, 0.020308710867539048, 0.02197485021315515, 0.025204478430428674, 0.017138471427772726, 0.02008143556304276, 0.050264544252838404, 0.03143672079646161, 0.056408604207847796, 0.011335097120276518, 0.007514534451599632, 0.0026415453092860325, 0.047728828354073424, 0.06886081424142633, 0.026513586219932352, 0.021203929259042655, 0.033055701958281655, 0.044364716192441325, 0.04050607753119298, 0.025106092549062202, 0.034271674031125646, 0.03122752845021231, 0.06793512284223523, 0.004491896734439901, 0.024847253491835933, 0.03962477928559695, 0.03536323331562536, 0.1088649658486247, 0.0348437604760485, 0.04857930753912244, 0.08426844461687974, 0.03202946863270231, 0.06612158872719322, 0.022537939283730726, 0.047729557779218466, 0.12030736649675028, 0.04669039836153388, 0.04683804418891668, 0.04510403098538518, 0.02588747481682471, 0.015738370395930748, 0.034461385636989555, 0.03708163682105286, 0.0585144715649741, 0.029731928703508208, 0.0806952045698251, 0.037385681577559025, 0.05969516999487366, 0.13803022620933397, 0.05317087937146425, 0.024040017343525375, 0.018073082169783965, 0.02379188047988074, 0.04727146861010364, 0.02044644160196185, 0.0936599528150899, 0.09673622702913624, 0.009823675633275082, 0.0010082597811041133, 0.004106613100572888, 0.01826820339608405, 0.06146789022854396, 0.01862554029295487, 0.05137236462906003, 0.021596139463196908, 0.021051141832556044, 0.025500206043943763, 0.019685581625838364, 0.08701189061892883, 0.05446996519874249, 0.013172538568531829, 0.05413356789254716, 0.10898310558072158, 0.06685952270137412, 0.026614553927044784, 0.03406786246757422, 0.030687679204025438, 0.03199095159236874, 0.04642686214564102, 0.07849502763045685, 0.03456969339666622, 0.03581288829445839, 0.03245600592344999, 0.09220221532242638, 0.03407592346359577, 0.02684887412137219, 0.06133820183042969, 0.04026999484215464, 0.017663621909118125, 0.014627388046522225, 0.004745315993204713, 0.00907418960040169, 0.02479372386421476, 0.016041507611849477, 0.10387383188520159, 0.05100371316075325, 0.044738324359059334, 0.048488204034843614, 0.05819900706410408, 0.06025201654327767, 0.044631821502532275, 0.03263049120349543, 0.0404551127659423, 0.03804821674046772, 0.029428219821836268, 0.033444685728422234, 0.02775759875242199, 0.10389245767146349, 0.03548359185723322, 0.04161684274939554, 0.0033353005045293166, 0.06780502053775958, 0.021878706890025308, 0.02709941808799548, 0.03209475387952157, 0.05156411523265498, 0.055731748563370535, 0.015565089515543409, 0.01803889248653182, 0.09175852127373219, 0.020075308391824365, 0.03225958360625165, 0.02605389061916087, 0.08064202099506344, 0.029808989925576106, 0.026054072127278362, 0.025993943746600832, 0.025950978909220015, 0.04403194226324558, 0.017556662737791027, 0.01071181775270296, 0.03616691054776311, 0.009656622856190162, 0.027839738809104477, 0.019710858751620566, 0.0159581088727074, 0.04292594036087394, 0.05337778505470071, 0.044870513158717325, 0.016276233230850527, 0.00679058296373114, 0.06292029443596091, 0.04381596117413469, 0.03398216010204383, 0.012054222103740488, 0.028543722283627306, 0.0279454545650099, 0.009549152239092758, 0.03077353423993502, 0.02026546952713813, 0.006025769672955253, 0.024593299886743938, 0.024381295012842332, 0.031171288075191633, 0.0316772987799985, 0.031968410659049235, 0.027294663146936467, 0.029760518776518956, 0.037520336852009804, 0.019108200911432505, 0.014637058866875512, 0.015930348308756948, 0.04330305316086326, 0.067839747960014, 0.026507598148392778, 0.0529243065310376, 0.015912382397800684, 0.004533839952533266, 0.03191049090985741, 0.014850872036601816, 0.009369585579926414, 0.08273534902504512, 0.015241248499868172, 0.012882501319316881, 0.031174545043281147, 0.036177977453917265, 0.02040459125834916, 0.030940684556428875, 0.04419823423294084, 0.038388987204858234, 0.04374610260128975, 0.08470704965293407, 0.030677840446255038, 0.013754640190329934, 0.03256460206050958, 0.03222002162198935, 0.03924199054017663, 0.03575323149561882, 0.015494280993672354, 0.05446023161389998, 0.02905859126310263, 0.031044320602502142, 0.025008252888385738, 0.05204314059977021, 0.022931138452674662, 0.0092505858046934, 0.01297013072430023, 0.03454188024625182, 0.032664838646139414, 0.0428531674801239, 0.018975348843793784, 0.051007821690291166, 0.023621217048327838, 0.0885527418660266, 0.021624434373474548, 0.021712475988481725, 0.04430257595543351, 0.039112668550972424, 0.07736472399639231, 0.04914917517453432, 0.027935320644506385, 0.043036443181335926, 0.03904874715954065, 0.01594603943106319, 0.06799585851175444, 0.02189739713711398, 0.03904757668663349, 0.007147113676182926, 0.02519274825629379, 0.008118925948760338, 0.01534219245825495, 0.05722408116395984, 0.03946847874405129, 0.016464365546458533, 0.022190651490486095, 0.06222713698766061, 0.009118436020798981, 0.05644789817077773, 0.03443951645333852, 0.0381217733291643, 0.05104632515992437, 0.049388955879424296, 0.05315691851345556, 0.023860380286350846, 0.02519555908760854, 0.048033609321074824, 0.037584899459034204, 0.02927410077037556, 0.049120446001844745, 0.047327006701380014, 0.04879784670525363, 0.038574478322906156, 0.01806808984838426, 0.003831610066949257, 0.03018889489716717, 0.028561147062906196, 0.007141418222870145, 0.023100359997312938, 0.029649720793323855, 0.019111208517902663, 0.0559149564110807, 0.03685189504176378, 0.033291845715471675, 0.04655551238517676, 0.030019407027534077, 0.04567386808672121, 0.037497761991939375, 0.01955844960840685, 0.04120521287300757, 0.02746707889517503, 0.05062490063054221, 0.040016738431794305, 0.040690286218055656, 0.06855581275054387, 0.04676502025020974, 0.041370734705456665, 0.02033294304939253, 0.03573048360911863, 0.00409615263509165, 0.03868159864630018, 0.015678543963336518, 0.010537931279811476, 0.03406051393332226, 0.02053286151827446, 0.06640029698610306, 0.03741323009931615, 0.002913676019358848, 0.0198922752668815, 0.025247707896466767, 0.11127711034246854, 0.021796994310404574, 0.025730256556666324, 0.051922134057219536, 0.031158304307609797, 0.06583209176148687, 0.00835673466125237, 0.0571043672306197, 0.029152771923691034, 0.0292259349620768, 0.07551719527691603, 0.03802570973389915, 0.08590684884360858, 0.07387665366487843, 0.03996063715645245, 0.013921899072426771, 0.09063980023243598, 0.036427722445556095, 0.008803780672938695, 0.0073156329370769, 0.03595029842108488, 0.02977827943063208, 0.017752525263598988, 0.02811083729778017, 0.021120328655732528, 0.05227614952517407, 0.023367787611537745, 0.022950062794344764, 0.0371568185011191, 0.029259325670344487, 0.048071607282119136, 0.06697593895452363, 0.03672963320942862, 0.0007709079665281543, 0.038740763507251225, 0.030434215840484415, 0.024941661461655582, 0.05355336956147637, 0.0481227823932256, 0.018247684497120123, 0.016504085290112665, 0.026434579298698475, 0.055862244418157, 0.0211893984316183, 0.011430008902347513, 0.024179902426632385, 0.0839067990226405, 0.03280861682391592, 0.018441828632993356, 0.07080003339797258, 0.031152567294027125, 0.037868547452879806, 0.048146717716008425, 0.034864123311958144, 0.15981702213840826, 0.11565196487520422, 0.16067595247711453, 0.09590822431657996, 0.17420769136931213, 0.09269375966063567, 0.19888727207268986, 0.11543309661958899, 0.08275386624570404, 0.14741239776568754, 0.12042423736836229, 0.0945305743121675, 0.17041048726865224, 0.1370693120573248, 0.1111094511247107, 0.0884170416476471, 0.06242215473737035, 0.07994842249900103, 0.08943292392151696, 0.09266178030520678, 0.09625611600599118, 0.20623409641640528, 0.13814996049872466, 0.1406079807451793, 0.19212117871003492, 0.17328052754913056, 0.06184649919824941, 0.09211486072412559, 0.1280858205365283, 0.09043152390846185, 0.10033775520111833, 0.15061395668557712, 0.1318083450730358, 0.12249725684523582, 0.07486988643982581, 0.08653661076511655, 0.11724869348108768, 0.0934476934905563, 0.07831339059131485, 0.14349977485835552, 0.17189803959003516, 0.16712968902928488, 0.12913628774029867, 0.10982813952224595, 0.11239974653082234, 0.08093726515237774, 0.2189837015633072, 0.0889408163992422, 0.1103941530787519, 0.182328819164208, 0.1432243710649865, 0.1303272931171315, 0.09359550555901867, 0.1087833855833326, 0.14561753693435872, 0.19398374376552446, 0.14514812640845776, 0.18255937179284437, 0.15734761607434067, 0.06734097722385611, 0.16522666971598352, 0.0781004595171128, 0.16050178610852786, 0.08295182205204453, 0.08290246541478805, 0.11686682754329272, 0.13825334209416593, 0.20571052522531577, 0.14939504994877748, 0.1238874936742442, 0.09468570777348109, 0.09901804530194827, 0.09903221989848784, 0.1472231407782861, 0.12547187294278825, 0.22549656565700257, 0.07408502498375517, 0.1749103550932237, 0.17615793671991142, 0.15948242295001233, 0.09898812190762588, 0.0789411101224167, 0.23744692440543855, 0.08815725094505719, 0.1114244202950171, 0.09798089774059397, 0.11511738784611225, 0.17419402567403658, 0.15536705377910817, 0.1155872190637248, 0.1383571715227195, 0.1134328975209168, 0.11801545162286077, 0.12428480306906359, 0.18247314356267452, 0.1305154644485031, 0.15338862208383425, 0.1649902274033853, 0.14513954972582205, 0.12536152957805566, 0.09248381414051567, 0.11242304063801255, 0.13961343839764595, 0.09994364849158696, 0.19894948016319955, 0.1419112565261977, 0.133040116833789, 0.1484326294490269, 0.12916953595621244, 0.15880521786000046, 0.1107612948066422, 0.2158140337892941, 0.17751394824257918, 0.1665753394897495, 0.09535015640514237, 0.11108507136149065, 0.09036559066069977, 0.18099882267415524, 0.1530918851494789, 0.13600038870104722, 0.10516581005815949, 0.11008888695921216, 0.24637620097824506, 0.0896231783553958, 0.1132843933467354, 0.13125558330544404, 0.22334938230259077, 0.1244896799325943, 0.06350473700357334, 0.13741474066461834, 0.1301235697631325, 0.07750516038920198, 0.10846744610794953, 0.13284169962363584, 0.12446222640573978, 0.1482354878847088, 0.0917280889781458, 0.08714420494756528, 0.20907700886683805, 0.09406582532184464, 0.10200078346367393, 0.23542079169835362, 0.24753448739647865, 0.1723187177308968, 0.0865568243233221, 0.08378591800906829, 0.15576562524906226, 0.15703364435051168, 0.14327108141567024, 0.0822487376364214, 0.15572936433766568, 0.13737733981439046, 0.09248055717242615, 0.19406071677803993, 0.11339169687458447, 0.10628320795616933, 0.06958071275481156, 0.1307863491986479, 0.11386003531515598, 0.13489068539014884, 0.20817832994673932, 0.0850477149443967, 0.11067150426762444, 0.14106384771210806, 0.09769743295120341, 0.12322449710752283, 0.08095688838511705, 0.13540812262466975, 0.123930567077228, 0.09724246165049927, 0.06031742731907538, 0.18073403116847786, 0.1597706103431327, 0.18963049378778252, 0.16503579781523772, 0.10209524910897017], [0.03751660151673215, 0.03221244238583105, 0.05100414403049009, 0.04707071045413613, 0.05136694313426103, 0.015681612637958357, 0.019790615454050045, 0.028363759529643824, 0.09840331293110337, 0.04749918835503714, 0.028953676178519214, 0.08073996752500534, 0.014418039637218629, 0.0228874916876001, 0.0677508395165205, 0.05766363614904029, 0.03570813266560435, 0.0373684264320348, 0.03748008615470358, 0.03417095907830766, 0.01238831747988505, 0.040243864458586485, 0.03733271513400333, 0.06433021556586027, 0.032911672722548246, 0.005557100022477763, 0.04495822059522782, 0.07294812598930937, 0.028882714986268963, 0.026144810918984667, 0.019830019678920507, 0.019850211184737936, 0.028217998333275318, 0.038283963554671833, 0.05071849096566439, 0.09611656849405595, 0.037392263367239914, 0.054796011453228335, 0.01178972576079624, 0.02905101202694433, 0.053379976722810946, 0.036401866868670495, 0.012747163269003587, 0.06431570848716156, 0.08750458846666984, 0.035809441336563656, 0.0263494231538581, 0.05447001608886889, 0.044894631685955186, 0.03453453849735005, 0.02478601231372782, 0.10875362503741469, 0.029111527172582488, 0.018320961190121512, 0.032048891697611125, 0.03445351802344833, 0.007792816929785269, 0.03820694304470505, 0.008845601330644317, 0.017117903335019946, 0.03165120232318129, 0.011091575142927468, 0.04064483794250658, 0.05453445655958993, 0.04798432732267039, 0.025071570383650914, 0.037601516781640906, 0.025224060951066867, 0.03791519673541188, 0.0408332399757845, 0.04395887761243752, 0.03199690912983247, 0.015012551664507814, 0.01695091925960566, 0.008394957387021609, 0.04709729884884187, 0.05526339315942355, 0.08226513104247195, 0.04793943544583661, 0.019083866949326227, 0.08317039175225155, 0.024945149131651436, 0.034938036131539514, 0.058547122670071464, 0.012301942516517426, 0.06872531079820224, 0.10845732915082149, 0.01604743461523737, 0.012560444850740688, 0.04060314196561064, 0.010812104380290424, 0.014913088608799236, 0.012981516541913152, 0.014597383227997592, 0.10145287322146551, 0.03766113965372954, 0.0634224782032626, 0.07796323938029152, 0.06060627967651401, 0.02935149786727769, 0.07647285078253065, 0.07929165488375084, 0.033741670328059366, 0.030030080383377414, 0.021394497515367608, 0.08199759146996907, 0.0642361231148243, 0.004838074274760271, 0.015612944894071137, 0.03797472121992281, 0.030349765372063433, 0.03856367265273418, 0.03743618833167212, 0.0032126436375879814, 0.03674238288242902, 0.05397017666005662, 0.05599352398089, 0.018348195889432515, 0.035730246121862104, 0.009985876036807895, 0.013196070162978555, 0.022857298575607792, 0.018636471492105296, 0.06898071816457169, 0.024350238465038792, 0.01735834391521556, 0.018398071605978266, 0.026711640413850546, 0.06098864773022277, 0.02511822814787073, 0.014266064756416848, 0.06454250203179461, 0.05454746407589742, 0.007230322425519782, 0.030054724775254726, 0.03581349219062498, 0.054803288741303344, 0.05597411109400647, 0.069908818363079, 0.06744285925690617, 0.023887582755248462, 0.022173099485891204, 0.048517686381403885, 0.048051777096199136, 0.07240630220621824, 0.0480115331842431, 0.026562243966119628, 0.023495257200141038, 0.018385698519913212, 0.062139958808464665, 0.06892796206687178, 0.013979348936118186, 0.03453237397064056, 0.0325665019585618, 0.02570938312315515, 0.03470231645873614, 0.04850170009636453, 0.04655718497399773, 0.06549828645906278, 0.0036024106915907134, 0.01101770218727844, 0.03528716954003487, 0.029106336379689828, 0.03965222941977637, 0.04974254047764199, 0.028435328010735766, 0.020831457638580884, 0.038993280314441235, 0.027393985406628678, 0.014724264187472207, 0.028522904829255173, 0.05389676934906414, 0.03856629179790616, 0.03523063060960599, 0.03594599311639156, 0.03420386802671211, 0.05424052197486162, 0.016313730772318583, 0.1214876374495881, 0.044094747464571676, 0.05304316211757915, 0.036048970983496735, 0.05643433425575495, 0.05273631840412106, 0.04868830740451813, 0.013683584851345845, 0.02173975988158158, 0.08631275527711425, 0.0077156454457768375, 0.02688896536294903, 0.016245644872209856, 0.041909885060574324, 0.04463963144059692, 0.015486070719946708, 0.057638292866093774, 0.05416248705504196, 0.0292680550233594, 0.03175201905625207, 0.016287664849577204, 0.013835061008908918, 0.011860491026059856, 0.054875705391168594, 0.014585271377914717, 0.05038025822224362, 0.027183308765026074, 0.03688792525125401, 0.04041557113773056, 0.03258367907255888, 0.07392001205257007, 0.015431854075619152, 0.04561998901356544, 0.016341053681182008, 0.036609936239463944, 0.019799673896549002, 0.020889647105442624, 0.027054633080427135, 0.08516195988548653, 0.007381680687623364, 0.011164284411019512, 0.030530272650399377, 0.02882450007434402, 0.022872942200462733, 0.012581484525331428, 0.06612196870680366, 0.041043762250670364, 0.01356010589682098, 0.007324241001957229, 0.03688890912703105, 0.05030311896864857, 0.04543359883661781, 0.04787483551938619, 0.04304089437105826, 0.03485062385776213, 0.026547762332484126, 0.027273769357374737, 0.03921998564952186, 0.006309209865451391, 0.03897541109472513, 0.034530287475458214, 0.016799134368609105, 0.05385332614449518, 0.04654769226908684, 0.04590027825906873, 0.030319421286029474, 0.045876682203795226, 0.04292671728347029, 0.03345607154603515, 0.07434434749718223, 0.006880177999846637, 0.01196130775913064, 0.06069744085626943, 0.041572123898991516, 0.025882316254345433, 0.05588272260501981, 0.03663862809272749, 0.010253002551118178, 0.02184294130919235, 0.059094137246055264, 0.011700086195820143, 0.04756434128752776, 0.03925401757338217, 0.055846943453486474, 0.05833007288830621, 0.01805977100905563, 0.033910486448023996, 0.08379032170133931, 0.04418526742873447, 0.010137844980428261, 0.028422839573717544, 0.004479186925371843, 0.06847487030816929, 0.03277578590703862, 0.029824674262532165, 0.03777599188366106, 0.06302493132118668, 0.03158651079450335, 0.04845836545739855, 0.042712011840194464, 0.05145594996533223, 0.01644215709529817, 0.03501254945461239, 0.03255131634484444, 0.08897496706673078, 0.06684003517563854, 0.0166860293663506, 0.015069535035373909, 0.025221675900476317, 0.04251379479787179, 0.03100743204621332, 0.0159371251772557, 0.07518339675984212, 0.050338928654257736, 0.028093080036342144, 0.03928638708644679, 0.005052620686391103, 0.0227088198464896, 0.041430561138050895, 0.020980007613876035, 0.02447713808422642, 0.019761285777868967, 0.06881736085883208, 0.0705803848270859, 0.022778669937646816, 0.03827681179557528, 0.05868248362094164, 0.05402708539207067, 0.020641181152313948, 0.04168467250253473, 0.05757539266986506, 0.022417763946577907, 0.052271817079080005, 0.021144638869113157, 0.06290460670632975, 0.023800715005823543, 0.06378945708274841, 0.01986558678826051, 0.01789294130035809, 0.0076443627975615, 0.036672788938241344, 0.04249360498839191, 0.021303422848827074, 0.04558396898210049, 0.0637634556208338, 0.022338105631726127, 0.054632484513734064, 0.03973809124103614, 0.024610090235780393, 0.020066029425444346, 0.03696778543027384, 0.09627396147698164, 0.05108368529805115, 0.06077915682856526, 0.06195941421070269, 0.01054109919017979, 0.01885884947010449, 0.0188177014102361, 0.028366782403151904, 0.030826843343675137, 0.048646041458206515, 0.027481233135664036, 0.044892456981220415, 0.04143771628982254, 0.03398978005030325, 0.007647255901247263, 0.009774297791799265, 0.01703480484762362, 0.02613301289134792, 0.04122243409178086, 0.03946900800136583, 0.026445675042590926, 0.022395891370251775, 0.043430383649787734, 0.19343433396092483, 0.14277085182922228, 0.14536875885512146, 0.1436541551457984, 0.09099808029298272, 0.07854696948613439, 0.13799992283540113, 0.11435001902282238, 0.15601548898432935, 0.05871279378022466, 0.056333958570446284, 0.23946619033813477, 0.12346206578825202, 0.14184204595429556, 0.11105429301304476, 0.1165715426738773, 0.2070979257779462, 0.09154007370982851, 0.12639284852359975, 0.0976543188361185, 0.0656599270712052, 0.0950611751260502, 0.1015742699216519, 0.21520793916923658, 0.1788516936025449, 0.08956884805645261, 0.17397369178278105, 0.10594368938888822, 0.09985771203147513, 0.16470187716186047, 0.1431756115385464, 0.21396851353347301, 0.13044645743710653, 0.1053570212264146, 0.16360414320869104, 0.18062056654265948, 0.09276685145284448, 0.12180815025099687, 0.07560142861413104, 0.10063550993800163, 0.19513855608446257, 0.11074573599866458, 0.09862767732036964, 0.15253942193729536, 0.1606029285384076, 0.14408426492341928, 0.10242648954902377, 0.1670920303357499, 0.15138003629233154, 0.1369394811668566, 0.07017878030559846, 0.20626287987189634, 0.11157268019659178, 0.1870677891586508, 0.10803388258708374, 0.17554519245667116, 0.10306608344295196, 0.06864286200808627, 0.16807358552302631, 0.1261162097964968, 0.0817183403830443, 0.08164969299520765, 0.11556234396994114, 0.09702965949795075, 0.13551250845193863, 0.062132006378046105, 0.15684284030326776, 0.10821359258677278, 0.11491751857101917, 0.1483048613050154, 0.11459274456969329, 0.1602439156600407, 0.07329494559339114, 0.07048101337360484, 0.13726524582930974, 0.10903856224779572, 0.19117300744567597, 0.24674480834177562, 0.10817917729062693, 0.11154073476791382, 0.11684211529791355, 0.17403353857142584, 0.12554862882409776, 0.16972652396985463, 0.16839765384793282, 0.16213937609323434, 0.3035898394882679, 0.10699813280786787, 0.0810539121074336, 0.10627766432506697, 0.09944459277072124, 0.10524918165590082, 0.13489363023212977, 0.04904035512091858, 0.15347808014069284, 0.0863227229565382, 0.15152478138250963, 0.23205620795488358, 0.1027463102447135, 0.10145405387239796, 0.16566718822079046, 0.16594301270587103, 0.10732479313654558, 0.06869012875748531, 0.09262241848877498, 0.17633358229483875, 0.195030506168093, 0.14596607323203767, 0.06945597766233341, 0.1646917127072811, 0.12455361150205135, 0.1049147385305592, 0.09722425655594893, 0.10431803483515978, 0.1237790502075638, 0.19372837032590592, 0.1280388930546386, 0.11470718628593854, 0.1167417328272547, 0.08350555412471294, 0.10541153472981282, 0.058223542890378406, 0.10098687572670834, 0.16808566344635828, 0.13222400205475943, 0.13123062678745814, 0.11160831007042102, 0.09299937861838511, 0.10603057579802615, 0.12703664254929337, 0.06418658327311277, 0.10051644739827939, 0.1876515464058944, 0.09026753556515489, 0.1357832167829786, 0.07760744275791304, 0.11919091854776655, 0.12621660583785602, 0.12422549910843372, 0.1710144920008523, 0.13392746421907628, 0.14440673190568173, 0.1587689026658024, 0.15582206579191343, 0.13956200544323238, 0.08459359859781605, 0.1398589052259922, 0.06558756809681654, 0.1127291006435241, 0.1879450399428606, 0.16323867067694664, 0.06546168628015689, 0.12679755395012243, 0.17462744670254843, 0.0989112506753632, 0.13957191205450467, 0.10266228046800409, 0.13776124135724135, 0.14107830050800527, 0.0875739890283772, 0.08055014735353844, 0.2527587456362588, 0.14050913176366261, 0.12606940445091042, 0.13908350254808152, 0.09199450218251773, 0.12201819755136967, 0.10660443321934768, 0.1304559569273676, 0.10756306749369417, 0.13795351104012557, 0.14879142519618782, 0.11570943679128375, 0.08831624527062688, 0.183334082365036, 0.145514576030629], [0.04322096060163208, 0.02746463956178299, 0.04362225978236113, 0.02708726213313639, 0.028341133779446994, 0.04497080741982375, 0.016614793367417793, 0.015226907662249036, 0.03050257485093815, 0.061110648326575756, 0.06260491135929312, 0.015931203262880445, 0.05884609876998833, 0.08304845900940043, 0.03591614096824612, 0.029145294467785528, 0.028328326430970004, 0.0531997747852334, 0.023118519290749515, 0.046856995671987534, 0.008227894431911409, 0.0335036402435175, 0.0035479054578380393, 0.04469663856018867, 0.03385900938883424, 0.03782344523019024, 0.044703549439353604, 0.06499200434024845, 0.015719440965248004, 0.012146354436741343, 0.0340480933498059, 0.051626418318067274, 0.042689297880445204, 0.04892423063782709, 0.06549687510622398, 0.03278276463970542, 0.04882123241467135, 0.034091685832078965, 0.019788020057603717, 0.03398300148546696, 0.06577021615313632, 0.03420087907995496, 0.0277260417850422, 0.10604747810534068, 0.02326322197248893, 0.022975875962791697, 0.050501627781029255, 0.044433333046202145, 0.04236785548606089, 0.061341553793421814, 0.03413069820297616, 0.0337941142996507, 0.024883775639214685, 0.006590607243457011, 0.019722909533551762, 0.02360258956572839, 0.017998244846239686, 0.00731553285316165, 0.049384409694799354, 0.033228253413523944, 0.04681017675570079, 0.045626954175531864, 0.05005132819392851, 0.060635979154280255, 0.06258705910295248, 0.03220974520913192, 0.03892704511859587, 0.04641571381528463, 0.059869641704218726, 0.057756900787353516, 0.036102453113666604, 0.02160554565489292, 0.03261207915576441, 0.017937980758558427, 0.031097931654325554, 0.01534551558350878, 0.012665053746396942, 0.04564249262745891, 0.05967619137040206, 0.04098097401271973, 0.013994825471724783, 0.02008106915413269, 0.022632313326799443, 0.04403309238010219, 0.024828924564644694, 0.009966024646668561, 0.052817349056048055, 0.05344486841931939, 0.024803917156532407, 0.03019193812672581, 0.061168486651565344, 0.025691083033702204, 0.02366182397651885, 0.06852596399507352, 0.013732378304536854, 0.0601592268794775, 0.021816437731363943, 0.03346255834081343, 0.022925372601353695, 0.0381188624139343, 0.021884708532265255, 0.026323258843539015, 0.047736251527177434, 0.024187257746234536, 0.008443548127875795, 0.04969046291496072, 0.046740165512476645, 0.01630048067974193, 0.009844013872290296, 0.018474226983796273, 0.05073084030300379, 0.028570979035326412, 0.020813228795304894, 0.0438200255988964, 0.025318404460059743, 0.04298950891409602, 0.026896848243528178, 0.052018214615860155, 0.044328631700149605, 0.05595213334475245, 0.03181674111900585, 0.06338315031358174, 0.03436756120728595, 0.06665054748633079, 0.022595859032922556, 0.05662814760580659, 0.04050658643245697, 0.0250869900919497, 0.024389220301860144, 0.032720532800470076, 0.03804369091189333, 0.04065220004745892, 0.026099773157121878, 0.053766904531845024, 0.041182984065796645, 0.09298109888498272, 0.08241973524647099, 0.0836828417543854, 0.007905133135084595, 0.04863945288317544, 0.010638345132714935, 0.012519212822163743, 0.017258412670344114, 0.015535094875044056, 0.011298339181978787, 0.03427303110116294, 0.015560904650815895, 0.03425611861582313, 0.004657921955055956, 0.16889393436057226, 0.0290263269229659, 0.014470047650060483, 0.03525358884196196, 0.02729890907981566, 0.011721869714425077, 0.03349677346912878, 0.0506863012643797, 0.029153684553291117, 0.0466146331413516, 0.08876469584980182, 0.027118925969781618, 0.04697509469198329, 0.023448809781777005, 0.05764982796141079, 0.0868268134072423, 0.03353638295084238, 0.04306179664230772, 0.021233442139678767, 0.011938519160529333, 0.01117304599444781, 0.022421680789973055, 0.03077697441247957, 0.042091841011175087, 0.0404384954433356, 0.06054576113820076, 0.0362198294938675, 0.06449444139642374, 0.03246236718924982, 0.046835859306156635, 0.04731665564967053, 0.04878147365525365, 0.03449613002261945, 0.03800689735050712, 0.02048521818194006, 0.012565639036308442, 0.010460699575820138, 0.04550961511475699, 0.04184417572936841, 0.03519690741917916, 0.017865784632574235, 0.023981858410739472, 0.02869849612138101, 0.02517794262218688, 0.029049363186849014, 0.053200531351779184, 0.03224248452378171, 0.06426082857485328, 0.024902123226118938, 0.06476764673633234, 0.057256732269057205, 0.03634425246023706, 0.05073316428544266, 0.06454121960060936, 0.05107778204338891, 0.02447261395198958, 0.027462334239057133, 0.029348373213516812, 0.00609977197434221, 0.01397719543560275, 0.03124911604183061, 0.045619680280131955, 0.006943954778502562, 0.044772020408085415, 0.04157525194542749, 0.026318230899050832, 0.008176324922325355, 0.06957523697721106, 0.05712358334234782, 0.012142355320975184, 0.019926822877355983, 0.04036924755200744, 0.012229828662904245, 0.027862788643687963, 0.06503427707191024, 0.02897673279845289, 0.03817797977743404, 0.02096104425644236, 0.02279201163245099, 0.027042448287829757, 0.047087755253804583, 0.028842525357114415, 0.020644015732354352, 0.025965708208137324, 0.047710477374494076, 0.044471575279853175, 0.021450033910306435, 0.026606131611125808, 0.05559264888454761, 0.041044176157031736, 0.023597425914236476, 0.09460313006171159, 0.05587492963033063, 0.050189868081361055, 0.02305427729152143, 0.029278555352772986, 0.07091963198035955, 0.0604191804304719, 0.040584302440817864, 0.01400507559135024, 0.0321179869185601, 0.042487952791686566, 0.019071336103869335, 0.03312486842540758, 0.055005129160625596, 0.05954334778445108, 0.010478345727148865, 0.032629636249371936, 0.028069568797945976, 0.030001398708139147, 0.02642289492567735, 0.011190482648089528, 0.04183862870559096, 0.03946156447221126, 0.06994929297694139, 0.024659143228616034, 0.03623678608398352, 0.04178266313725284, 0.02875490952283144, 0.0067932169518566555, 0.015774604165926576, 0.025531620518969636, 0.012763559219560452, 0.09864770088876997, 0.09238099572913987, 0.02490459818259946, 0.03139116395530956, 0.03263605858332344, 0.03849213470571807, 0.07313193434051105, 0.03399232794929828, 0.0328004438696163, 0.026992162057597722, 0.0987526566854545, 0.015875666867941618, 0.038086842346404276, 0.0107450320418658, 0.016645291820168495, 0.04597264401880758, 0.05478733977569001, 0.023408640508673022, 0.030490286581750427, 0.08524151133107287, 0.02865737011390073, 0.007638530789076218, 0.017184533777513673, 0.03811010931219373, 0.01824167776586754, 0.008996996912173927, 0.05371800929840122, 0.06515996211341449, 0.06437807942607573, 0.06094429189605372, 0.02213164947793952, 0.004527030853621129, 0.06456794709499393, 0.02924870320462755, 0.06282459385693073, 0.05868240898208959, 0.03736964440239327, 0.050632038818938394, 0.049359436213437996, 0.10147428778665406, 0.021898464133430804, 0.03704728598573378, 0.017144244064443877, 0.032448111168508015, 0.002965016311333914, 0.05637460960341351, 0.0206476560727294, 0.03121075506455132, 0.05882172579211848, 0.0007953312514083726, 0.04520297496180449, 0.05050233345744865, 0.01907553114662213, 0.02299927524290979, 0.014855402954188841, 0.008372002547340733, 0.041729829008025784, 0.004815100775366383, 0.033955887226121764, 0.020391563385991112, 0.016281556338071823, 0.04096214466595224, 0.05396733020565339, 0.05733275533254657, 0.014057702767396612, 0.02770790284765618, 0.01623923610895872, 0.06697179989090987, 0.03505375688629491, 0.01465149809207235, 0.038181202818772624, 0.047077879176608155, 0.018571734162313596, 0.018470155773684382, 0.02023722550698689, 0.08504814242145844, 0.042075115122965405, 0.009393459834557558, 0.029404705190765004, 0.008958430678051497, 0.14962880526270184, 0.11267937759735755, 0.15200203577322619, 0.1494483556598425, 0.20346875408930437, 0.12656130162732943, 0.0959008214995265, 0.09725280930953366, 0.08922010141291789, 0.16849078956459249, 0.17386338913014956, 0.08481886543865715, 0.16804552131465503, 0.151448093354702, 0.10301017894276551, 0.05991141910531691, 0.1339808784957443, 0.15792226738163403, 0.08703930343368224, 0.14782481135002204, 0.11105423194489308, 0.11192003584333829, 0.10124429834208318, 0.1318291760981083, 0.16647875681519508, 0.1077488571671503, 0.10728689017040388, 0.1399748804313796, 0.12368196541709559, 0.08887098836047308, 0.10834580513515643, 0.25836007935660227, 0.08885075444621698, 0.1316359836075987, 0.11468167336923735, 0.06254811119288206, 0.14320222368197782, 0.1132917758077383, 0.09229043166020087, 0.24114890290158136, 0.14951591060629912, 0.2046751214989594, 0.12062033398875169, 0.2215539515018463, 0.13030768345509255, 0.13068340186561855, 0.1004133779289467, 0.1412664989807776, 0.08946583286992141, 0.12315539510122367, 0.10911269898393325, 0.10154869593679905, 0.14233555804405892, 0.10900123603641987, 0.19223331340721675, 0.14793847953634603, 0.13319522993905203, 0.16888752898999623, 0.17119621724954673, 0.09972028154879808, 0.143393109153424, 0.14554186670907907, 0.11404152986194406, 0.10410802824688808, 0.22523893948112214, 0.12405081705323287, 0.14998940591301235, 0.13295029236802033, 0.1425950298351901, 0.1157429428505046, 0.11882312542625836, 0.2011899213705744, 0.1816859615168401, 0.08005126805177756, 0.10266764089465141, 0.10090311736400638, 0.10118594433047942, 0.12674789875745773, 0.16152623827968324, 0.12109027377196721, 0.09203690383583307, 0.09953960802938257, 0.09471169566469533, 0.10788842503513608, 0.13404202807162488, 0.12328737016235079, 0.14984844704823835, 0.2635961169643061, 0.07885737890111548, 0.1133761719933578, 0.20772344007023744, 0.1458672106798206, 0.13734432230038301, 0.12743305627788815, 0.09424378470118557, 0.12731337627129896, 0.1408641684268202, 0.187064776463168, 0.08483580167272262, 0.12625558088932717, 0.1405190248042345, 0.11500324468527522, 0.11380984407982656, 0.09962031298450061, 0.10703606291541032, 0.16593698731490544, 0.18075510646615708, 0.17417077906429768, 0.1210681399596589, 0.10973549913614988, 0.15050965228251048, 0.06536275587443795, 0.11229837339903627, 0.14476011294339383, 0.12933501707656042, 0.12168338123176779, 0.06840349520955767, 0.14020908357841627, 0.1463244075753859, 0.0929275421159608, 0.1398464608937502, 0.13243219016918115, 0.11949328732277666, 0.2132601094033037, 0.19439606235495635, 0.15821869218988077, 0.08193549873041255, 0.06146101666880505, 0.14824756580804074, 0.14299084645296845, 0.13210143148899078, 0.2416194805077144, 0.09939586717103209, 0.14432525342064245, 0.11184714761163507, 0.18142689684672014, 0.13786725566855498, 0.19738920245851788, 0.12919739660407814, 0.1528326440602541, 0.05564835321690355, 0.17759121981050285, 0.12979355747146265, 0.12371823989919253, 0.14874282851815224, 0.13171708211302757, 0.09930463135242462, 0.15963556830372128, 0.13667012990585395, 0.2698069379798004, 0.0833454809284636, 0.07117721744413887, 0.21170623706919806, 0.06598495213048798, 0.12436158609177385, 0.07876221436475005, 0.10066192530627761, 0.09103245487702744, 0.0792794276827148, 0.17327234441680567, 0.10685981344431639, 0.14029586820730142, 0.09105114173144102, 0.17606218185807976, 0.13616524556917803, 0.10198743667985712, 0.14505906190190995, 0.1179559441017253, 0.06724756330783878, 0.10012906497078282, 0.08543353674135037, 0.13381173328629561, 0.18030765333345958, 0.1729600147477218, 0.08977926855108567, 0.12419493789119379], [0.0484106949796634, 0.0266761445506875, 0.03630845295265317, 0.10338086940880332, 0.0638424778091056, 0.05266773886978626, 0.040670211759528944, 0.10273860208690166, 0.028824740954275643, 0.037562263530812094, 0.048443566608641825, 0.012050015186624867, 0.028476269117423465, 0.04162873746827245, 0.030936406393136297, 0.04375986668414303, 0.025398398649745753, 0.01320348315805729, 0.10004575444119317, 0.06450107068355594, 0.03143384720065764, 0.0710888993261116, 0.04373275242479784, 0.023680402265329446, 0.039752788309540064, 0.011351903584519667, 0.04805049805768898, 0.037678330338427, 0.023885728658310006, 0.022786054094987254, 0.01368586896985237, 0.0490020382484155, 0.01985531546441572, 0.07414768769272737, 0.04599711538425513, 0.03932712972164154, 0.08764268391366516, 0.0425840774551034, 0.008657045778818429, 0.06018868886998721, 0.014714969954054271, 0.09220824071339198, 0.00807139287436647, 0.05362016794138721, 0.03296726170395102, 0.027982076796303903, 0.047453336351151974, 0.005095976529576416, 0.032972784979002814, 0.015884384346593703, 0.04383156747956361, 0.04286417331812637, 0.030350996913122277, 0.03311944014525839, 0.027642736344465187, 0.014161883337822343, 0.04117335565388203, 0.02294352510944009, 0.030512372896607434, 0.0336716726555356, 0.03827482368797064, 0.08505536881940705, 0.03084716886015875, 0.059775128561471186, 0.01594695884601346, 0.04192050074094108, 0.013971422798931599, 0.06875357856707913, 0.0628535265901259, 0.016077941549675803, 0.004564776908539767, 0.034323191802416525, 0.013988343765959144, 0.04884315588112388, 0.07187063273574625, 0.01702298646393631, 0.02339127001219562, 0.029275793715247085, 0.05261210239093218, 0.04704307033015149, 0.03841945342719555, 0.005250380565744958, 0.009546609429110373, 0.0030996821878943592, 0.010217612709051796, 0.05373374452548368, 0.07831647114029952, 0.051714777148195674, 0.03610764051388417, 0.04167064379102417, 0.04449215524696878, 0.04705625426556383, 0.054556739649602344, 0.03222988073581031, 0.06100170274398156, 0.03553672114919339, 0.0927532875378217, 0.04701729957014322, 0.02705364072296236, 0.012289903608949056, 0.0447100260561066, 0.039099148740725856, 0.05872021016797849, 0.020894096598827412, 0.04137561676491584, 0.0432497711985239, 0.055085267539003065, 0.025928928217451488, 0.00821767739086811, 0.06443690162684236, 0.06454829672085387, 0.0658345412729042, 0.023782421701720784, 0.01606429960312588, 0.054888424530093155, 0.0360530048741826, 0.03568389539473823, 0.01595965932522501, 0.05382606939279607, 0.03706549447295921, 0.011165012987995786, 0.03489977693451302, 0.05699236145509141, 0.01585138209962419, 0.014812092063948512, 0.00978795500538711, 0.011110787013811725, 0.030285698095602647, 0.06469804261411939, 0.019686942088550756, 0.04200313612818718, 0.05313211127317377, 0.019826499778511267, 0.034009786655328104, 0.034204061409192424, 0.05254979930551989, 0.03144638313512717, 0.03312643923397575, 0.04873990999268634, 0.11304768640547991, 0.030286346096545458, 0.015873588854447007, 0.03653159597888589, 0.028632613763745342, 0.031171654484101703, 0.032275926122175794, 0.045797327533364296, 0.043820252908127647, 0.05374257905142648, 0.022791577370039055, 0.01717663393355906, 0.03276648997728314, 0.014607081189751625, 0.03631273111594575, 0.06423752768231289, 0.018278973443167548, 0.013816967024467885, 0.008087273986477937, 0.02506789442018739, 0.02013211534358561, 0.022690596092226248, 0.014485969474273068, 0.03228312198604856, 0.03944687079638243, 0.018227114708029797, 0.02519910952209362, 0.02518880257516035, 0.03722287727785962, 0.018284308424751674, 0.04322279603885753, 0.07026594491409403, 0.019347844212981205, 0.028508862547044243, 0.0725091409736446, 0.020791006773444157, 0.032708994312477965, 0.04238249487908823, 0.06715364049055747, 0.04379586635955742, 0.01576563562931759, 0.02390779461711645, 0.047862869554332325, 0.02500200697353908, 0.04175750305876136, 0.034300260711461306, 0.08267533938799586, 0.005491962357025061, 0.01020793425517955, 0.03917967388406396, 0.022096396191045642, 0.0007643534772796556, 0.02823293797804841, 0.04178505836586867, 0.03015040499823434, 0.08301728032529354, 0.0293488312246544, 0.008346300489003105, 0.01523339276068977, 0.035920134146830866, 0.0106771200163556, 0.029133542241262536, 0.02381678101872759, 0.011311062561747218, 0.05661853276459234, 0.03225425710635526, 0.029813576822302172, 0.021858708766688193, 0.05349518179095217, 0.04269524184720857, 0.03997551064406123, 0.0318586338710572, 0.017714237228834202, 0.009325697934920234, 0.03608481798853193, 0.0329245479245271, 0.038860104246331115, 0.019148453305076276, 0.017947619348498325, 0.0302995775294091, 0.02819053123572043, 0.026252889673092535, 0.023272784227239232, 0.007844822398120803, 0.017128510533698967, 0.016101832767682414, 0.0419310349971056, 0.005102725832590035, 0.021501739975064993, 0.09873519119407449, 0.07985633172627006, 0.044159401673823595, 0.0459618417413107, 0.07022023879523788, 0.03177072287404111, 0.005726444551588169, 0.04402916705501931, 0.015049711634804095, 0.052710622282964845, 0.03193311666005424, 0.02917070560423391, 0.03375533941601004, 0.07435061037540436, 0.02857800865811961, 0.039003417627619844, 0.019009601291535155, 0.03995512405942593, 0.03536946226709655, 0.021362443521086658, 0.10448975169232913, 0.03749251691624522, 0.04796274312372718, 0.021176331543496678, 0.036743020705346546, 0.014134184690192342, 0.04129033169842192, 0.05705594018633876, 0.04674839614225285, 0.057457449712923596, 0.025409185660204718, 0.03470813489652105, 0.07854974469436066, 0.06571865427706923, 0.03533731327791299, 0.007138298658121909, 0.05630645415346537, 0.025732263323983977, 0.07190041363771472, 0.01860006299934217, 0.011166969713355814, 0.04257567719157253, 0.03316183501322355, 0.01395441362235163, 0.0360317667280989, 0.012524162735124784, 0.05793232923107488, 0.04311946194086756, 0.017398031428456306, 0.054345888285232444, 0.03170818230137229, 0.04145973475117769, 0.06006064252661807, 0.04064894307936941, 0.022767287512708987, 0.025065684092364142, 0.021553613977240663, 0.05233575204121215, 0.041765431740454266, 0.05211939097249082, 0.04475464312625783, 0.02937534837318318, 0.061916700431278775, 0.022956398615081395, 0.017671810130455663, 0.03388608293607831, 0.02648442787384348, 0.023532608856580088, 0.08549598231911659, 0.04185648774728179, 0.04899614856445363, 0.049089416595441956, 0.03969885834625789, 0.04635855741798878, 0.030991717175181423, 0.005649096648474889, 0.021363228925370743, 0.03072594857907721, 0.057930185060415945, 0.07481233988489423, 0.031298079128776274, 0.014335830030696732, 0.03268785455397197, 0.0063446226080746525, 0.030573966912925243, 0.015186485634850604, 0.07067018215145383, 0.06334956283015863, 0.05865740496665239, 0.038740950104381354, 0.0387330451714141, 0.06762647761830262, 0.009483709232881665, 0.11092978862247296, 0.039725908144776306, 0.048507342115044594, 0.020496190093191605, 0.04250820366931813, 0.00948404086687203, 0.08840060074414526, 0.01847779777433191, 0.012182082698148276, 0.06259927273328815, 0.026959477025749426, 0.016063649905845523, 0.07716159775320973, 0.03180052413206015, 0.01582506681526346, 0.04549210551860077, 0.013059609137209398, 0.0369946622023625, 0.03418749836938722, 0.028140470618382096, 0.05983229513679232, 0.019522426184266806, 0.020902946391808133, 0.035613588988780975, 0.020945292065984437, 0.045594927322651656, 0.03272078385842698, 0.07575680634805135, 0.047154149905379326, 0.02128933646183993, 0.037305312497275214, 0.17546167836657592, 0.12859614672405378, 0.14981278324765818, 0.1748401674308947, 0.09104897041938134, 0.08569090507392373, 0.1127200150596244, 0.29385584752474514, 0.15690613404980727, 0.16456177325120994, 0.15659726490931852, 0.12277986668050289, 0.08028703861470733, 0.11411920855087893, 0.13508883118629456, 0.20722462183662824, 0.12153049372136593, 0.11628346384635993, 0.14100902208260127, 0.1791851528521095, 0.10094349698296615, 0.20180904386298998, 0.15782630895929678, 0.11687079018780164, 0.1459324857486146, 0.0996098228331123, 0.192083085754088, 0.15762031929833548, 0.10596346189933163, 0.09153406867491347, 0.1134457014767187, 0.10851569673312561, 0.13795623875090054, 0.16050747223198414, 0.12994161381253175, 0.12099063768982887, 0.23891462279217585, 0.12378514345203127, 0.18297516448157175, 0.11088873725384474, 0.17265417187341622, 0.15856615640223026, 0.10314862044262034, 0.1385524674717869, 0.1291045865842274, 0.07471487511481557, 0.08940971802387919, 0.07659704983234406, 0.10922452834035669, 0.11916296290499823, 0.08438393806240388, 0.15315422894699232, 0.1980033852159977, 0.12996464329106466, 0.10307943701211895, 0.07381421487246241, 0.12501819085861954, 0.14314452106399195, 0.16864457274121897, 0.08665523225707666, 0.11713782085904054, 0.19044514293117182, 0.09207101379122053, 0.15001422672399453, 0.06900092493742704, 0.2370000955249582, 0.14417691209486552, 0.3019906138735158, 0.09369985745953661, 0.142310927222882, 0.10481712448277644, 0.12588059529662132, 0.15883640332945756, 0.14934496049370083, 0.1643190205629383, 0.09846176193760973, 0.12110281309911183, 0.10448829284203903, 0.2236745769956282, 0.2543927122439657, 0.10588524038238184, 0.12091578170657158, 0.07072776941848652, 0.09246188388871295, 0.14530903420278005, 0.12126973271369934, 0.16607392925236905, 0.06882614788732358, 0.11419584229588509, 0.13581224451107637, 0.1414856929332018, 0.10458312489624534, 0.1467932617025716, 0.1587686583931957, 0.1443962010421923, 0.13260870426893234, 0.12727668109749044, 0.08036101250244038, 0.1459731842790331, 0.1513991845505578, 0.11628847143479756, 0.14487774377422674, 0.10744890397680656, 0.1369576116225549, 0.1260795553347894, 0.11993417223649365, 0.15273661778441497, 0.11415404453873634, 0.16851984443409102, 0.2001464973602976, 0.18016981572977134, 0.11671529710292816, 0.17410131064908846, 0.10271680075675249, 0.15392884452428135, 0.06953703545566116, 0.12103614024817944, 0.09005387845848288, 0.12023020349442959, 0.13618128613701888, 0.11431639082729816, 0.05291873915120959, 0.14181428030133247, 0.1507339488182749, 0.17242512559252127, 0.12140397408178874, 0.13936753730688775, 0.15371502456920488, 0.1132056290017707, 0.06100709709737982, 0.08318529238126107, 0.14311106928757258, 0.06776501411306006, 0.15087939958487237, 0.1473283679889781, 0.15697059487657888, 0.10962824310575213, 0.21148023062518664, 0.16870075544076307, 0.20313601408685955, 0.1596626147095646, 0.12274623848497868, 0.1185040646897895, 0.1323121708950826, 0.1730404482888324, 0.186161429222141, 0.16852983246956552, 0.14606627928359167, 0.09808151091315917, 0.0873755311061229, 0.07255476566829852, 0.1341642050870827, 0.11026833233024393, 0.11466359719634056, 0.18407897810850823, 0.12172764885638442, 0.07476964646152087, 0.10690265614539385, 0.15966332038598402, 0.09553560681108918, 0.1469328227852072, 0.14574643144650118, 0.09276730607130698, 0.11615731061569282, 0.11136509597833667, 0.12129501492849418, 0.10909302146839243, 0.17206890827843122, 0.11589421544756208, 0.12615546983267578, 0.14650375795151505, 0.16319478303194046, 0.13488847336598805, 0.24443024396896362, 0.061947926612836976, 0.1586776261350938], [0.045046121414218626, 0.010085809826185661, 0.037663697730749846, 0.06354063829141003, 0.0037741877687429743, 0.016658453703192726, 0.017028311267495155, 0.01031225816612797, 0.017905358491199355, 0.07363700866699219, 0.042048357094505, 0.02237317062515233, 0.022068732318335345, 0.06869404390454292, 0.046994032604353767, 0.027280853262969425, 0.046941028841372044, 0.05171109609571951, 0.04254965876628246, 0.008183078890267228, 0.009977962622152907, 0.028250299992838075, 0.04978580047775592, 0.0648618545383215, 0.017573078196229677, 0.033821734067584784, 0.08018260528998715, 0.03198773194370525, 0.004557716327586344, 0.022359856071748903, 0.04611317201384476, 0.05917818737881524, 0.028156672338289872, 0.11787380065236773, 0.030288877032165016, 0.0450202319105821, 0.045247775236410756, 0.009493607362466199, 0.0368187011086515, 0.009392520911725504, 0.015949350681954196, 0.02058776857198349, 0.03841137207512345, 0.05505588697269559, 0.08871308647628341, 0.0989456931129098, 0.03340590066675629, 0.033245528915098736, 0.02128686659437205, 0.03456550344292607, 0.07785914532308068, 0.06067691517195531, 0.05033901686381016, 0.003160098097786041, 0.025257407554558346, 0.013745185653013843, 0.021071905004126684, 0.00927229638078383, 0.03909008690555181, 0.03685658371874264, 0.04482788758884583, 0.07801980205944606, 0.017078176806015626, 0.013927801478920239, 0.017041876878855482, 0.007816365487607462, 0.02870932893295373, 0.03169467606182609, 0.03191537296931658, 0.02828465591716979, 0.035935431718826294, 0.019561879602926116, 0.052304407116025686, 0.03251058388767498, 0.050064189825206995, 0.015463048026763966, 0.033914825679468255, 0.02345422449122582, 0.055801468036536656, 0.03796184262526887, 0.06996892299503088, 0.017732654365577867, 0.018952580601243035, 0.012070049781219234, 0.02201297539951546, 0.03744341812229582, 0.013251922076701053, 0.06806939813707556, 0.05150020062657339, 0.01252226622974766, 0.018048317337940847, 0.023806898156180978, 0.02736648098964776, 0.05601771714697991, 0.06239760534039565, 0.01906556007452309, 0.030160379463008473, 0.035705330315977335, 0.024504391443250433, 0.02449128553936524, 0.022086492972448468, 0.07634586973914079, 0.039007465089006085, 0.052060735012803755, 0.051611344662628005, 0.06425086089542933, 0.06560067739337683, 0.04579870495945215, 0.09960413670965604, 0.030913465124155794, 0.02353733654932252, 0.05301083670929074, 0.018008943647146225, 0.017254171826477562, 0.07294054675315108, 0.03718274532418166, 0.030320947989821434, 0.014079191123268433, 0.022767760790884495, 0.055616244939821105, 0.07133628640856061, 0.0022967275955514716, 0.054977210837283304, 0.09354209806770086, 0.05143597050170813, 0.05166818214846509, 0.018995162066338316, 0.009403089094640953, 0.04003829548933676, 0.025998561177402735, 0.03939084415989263, 0.022768096665718725, 0.02399809405739818, 0.030769395176321268, 0.0367075027897954, 0.02607658422285957, 0.049206650483288934, 0.03840177080460957, 0.032280234819544215, 0.022857910953462124, 0.0032580762220147464, 0.023619722574949265, 0.09660241992345878, 0.048879138593162806, 0.06295683354671512, 0.06278607342392206, 0.06657031750572578, 0.028503332486642257, 0.03738413451771651, 0.033782711518662314, 0.014504025291119303, 0.03504374510209475, 0.013462641974911094, 0.009157384779038174, 0.0384388052459274, 0.0077998753903167585, 0.028033564033518945, 0.03390065786827888, 0.029457281476684978, 0.03267306249056544, 0.08110465295612812, 0.04589886351355484, 0.04368816588872245, 0.0244079682244254, 0.013831720072110849, 0.01247746086612876, 0.05503626373995628, 0.04493223609668868, 0.03068647819704243, 0.03067653426634414, 0.006240503953969372, 0.05148286744952202, 0.002380989770504779, 0.0335496788445328, 0.06409703700670175, 0.03879010996648243, 0.03046085512531655, 0.04275437617408378, 0.06308614196521894, 0.03519603210900511, 0.03153419913724065, 0.03157236673203962, 0.02360817899794451, 0.028474318329244852, 0.005201610013110829, 0.043365359638950655, 0.022735118167474866, 0.032164134085178375, 0.012689655729835587, 0.05081813383315291, 0.009851766134878355, 0.03760511301723974, 0.05350723596555846, 0.0340129520211901, 0.05814121623656579, 0.03638025213565145, 0.04246255861861365, 0.0634431124531797, 0.047966858438615284, 0.07344088490520205, 0.020382165675982833, 0.07168250890182597, 0.03382590027259929, 0.02354474106271352, 0.06965204035597188, 0.03497603069990873, 0.03166588582098484, 0.046583210184637985, 0.006880249246023595, 0.02546652017294296, 0.027706433819340806, 0.06876730533050639, 0.028250244013699036, 0.04271101439371705, 0.006565266505016812, 0.027111256827733347, 0.04097481970010059, 0.039614750538021326, 0.05573993848104562, 0.016887240444443057, 0.017374116461724043, 0.07705075227256332, 0.032183004144046984, 0.06669246737978288, 0.017317511374130845, 0.03785766714385577, 0.10122824420354196, 0.021829694609290788, 0.028952848365796462, 0.02561109732570393, 0.028984529165817157, 0.031613085618508716, 0.035503398294427564, 0.09083801388208355, 0.07929414510726929, 0.03913812718487211, 0.027517863848645772, 0.019162967169125165, 0.022226354306829826, 0.027935359660269957, 0.03734915264483009, 0.05635407713374921, 0.022227387376395718, 0.01802723525491144, 0.04817391000688076, 0.0429971967158573, 0.03369935688429645, 0.028765345391418253, 0.02912434469908476, 0.03149180766195059, 0.056792017205485275, 0.010207705249610757, 0.08205211175871746, 0.02055571288136499, 0.0790454280961837, 0.04366225263636027, 0.014357946879629577, 0.026925514651728526, 0.019920064668570246, 0.05888391352657761, 0.0926892813295126, 0.05339570177186813, 0.031867373402097394, 0.04343059738831861, 0.07880289253911801, 0.11031239639435496, 0.019177547190338373, 0.016924010257103612, 0.034229937342128584, 0.10245957491653306, 0.052749909460544586, 0.039934856218418906, 0.04296274410028543, 0.04124986047723463, 0.012906237322437977, 0.004587910711831812, 0.025735404941120317, 0.018752397503703833, 0.019098638656682203, 0.039090745084519894, 0.03422275844163128, 0.03831542383081146, 0.02496374268749995, 0.026516783816207732, 0.07123895734548569, 0.057739218164767535, 0.03790609079546162, 0.0512944654162441, 0.018297324422746897, 0.035074567555316856, 0.08749805417444025, 0.10338303393551282, 0.05236084765887686, 0.024106261021058475, 0.030462313975606645, 0.07479085068085364, 0.05447632985721741, 0.01798521018853145, 0.019215981110132167, 0.051020354232085605, 0.033052556948470216, 0.0792266647996647, 0.017917141251798187, 0.01842347426073892, 0.031860564303185256, 0.05742196911679847, 0.019474124668964317, 0.014857684528189046, 0.08876185957342386, 0.032586813904345036, 0.009135960883993124, 0.01635129107827587, 0.03636571452287691, 0.040616241084145646, 0.02965990899662886, 0.04013646254315972, 0.04469736119998353, 0.02396017243154347, 0.0064795336054105845, 0.06034784604396139, 0.07376730774662324, 0.06457196402230433, 0.00369067961582914, 0.027782853825816085, 0.05879714246839285, 0.03333572657512767, 0.027707885884280716, 0.05351952423474618, 0.01440892182290554, 0.03760269743257335, 0.037608990844871314, 0.023366547588791167, 0.04348357740257468, 0.08737388226602759, 0.01477003815983023, 0.09063785283693246, 0.08494605004255261, 0.01783265176761363, 0.027923788941864456, 0.02479323871167643, 0.044053102377802134, 0.09295609486954552, 0.0819422569391983, 0.06202164265726294, 0.035866105795970986, 0.03381426339702947, 0.026804024652977074, 0.0984095147411738, 0.01884710742160678, 0.05076659231313637, 0.03285741027710693, 0.014343533099495938, 0.13988675230315753, 0.12754050908344133, 0.11584043476198401, 0.09250395984521934, 0.12016023296330657, 0.07957595427121435, 0.13409451954066753, 0.11597747169435024, 0.11281099982027497, 0.11652321740984917, 0.1423775457910129, 0.1454574569527592, 0.1131829320053969, 0.19733827162001813, 0.05830031234238829, 0.12206076883843966, 0.10846135286348206, 0.10365898055689675, 0.14239271783402987, 0.08381425363144704, 0.11825768862451826, 0.1713826922433717, 0.1261471374226468, 0.1174899669630187, 0.22418414322393282, 0.11449093717549529, 0.11031842857067074, 0.10866799391806126, 0.16933362505265645, 0.109959239273199, 0.13028795165675028, 0.20589439464466913, 0.13249899872711726, 0.19490486862404005, 0.1834219390792506, 0.181529681331345, 0.10484373662620783, 0.14224980478840216, 0.11743614556533949, 0.1616154249225344, 0.06815293258322136, 0.13974978322429316, 0.14628164629851068, 0.12774086690374784, 0.21254779691142694, 0.1938321047595569, 0.1288235102381025, 0.1550455910286733, 0.1312674576682704, 0.1850590133773429, 0.16245142077761038, 0.1442324569714921, 0.09378664887377194, 0.08137880824506283, 0.1576840201658862, 0.09853490801262003, 0.11233576746391398, 0.18127403647771903, 0.12888803891837597, 0.09432995864855391, 0.11907782033085823, 0.22229321540466376, 0.1207755013768162, 0.07957771167691265, 0.09543938376009464, 0.0954308749309608, 0.15863147218312534, 0.07907486294529267, 0.14615003764629364, 0.1486928476286786, 0.18287704831787518, 0.17433780724448816, 0.13347726980490343, 0.08643179067543574, 0.20251314608114107, 0.10655977204442024, 0.0945851488837174, 0.12807495040552958, 0.11288828495889902, 0.08175139860915286, 0.17040865522410187, 0.07945795703147139, 0.1268460149211543, 0.0954455245020134, 0.18838513775595597, 0.1005701127329043, 0.12178878486156464, 0.14460888105843747, 0.14181200042366982, 0.21299580644283975, 0.07450854618634496, 0.09221055451780558, 0.15550643844263895, 0.14401261162544998, 0.12365569254117352, 0.224593706961189, 0.08946329514895167, 0.077272911423019, 0.0859932399221829, 0.0746953333062785, 0.10001915586846215, 0.09084914864173957, 0.10400295709925038, 0.1471522610102381, 0.12114124532256808, 0.17005830045257295, 0.12300880439579487, 0.08534815667995385, 0.21101528485970839, 0.12290011665650777, 0.11733836866915226, 0.1786981818399259, 0.14629073866776057, 0.12711086070963315, 0.27990625319736345, 0.18578157174800122, 0.23426307524953568, 0.09267130693686859, 0.1564957153584276, 0.12839288477386746, 0.11563498792903763, 0.08434455588992153, 0.1058857628543462, 0.20399144318486961, 0.09930782046701227, 0.12720500065812043, 0.04016500511871917, 0.08309075888246298, 0.12409213983586856, 0.21556353223110947, 0.07245492602565459, 0.11040676025939838, 0.17572663272065775, 0.17869143720184053, 0.08658871546919857, 0.08912849918540035, 0.08518966447029795, 0.19997853280178138, 0.11658701327230249, 0.1168997229209968, 0.11726978234946728, 0.08356358922485795, 0.22375738540930407, 0.12002053617366723, 0.20112869037049158, 0.13094788124518736, 0.20223711803555489, 0.16050610159124645, 0.12341291271150112, 0.07555222125457865, 0.08709597467843976, 0.10657052682446581, 0.12316891151879515, 0.2154234554618597, 0.14356046303042344, 0.09272230562887021, 0.1652264797261783, 0.2020393522190196, 0.13472903120730603, 0.2111660824822528, 0.19317531000290597, 0.11357365282518522, 0.14237521163054875, 0.11139958591333457, 0.13026397222919123, 0.2318918396319662, 0.21820166281291417, 0.1927726130400385, 0.12359465153089591, 0.07927984158907618, 0.10994356511426823, 0.18851955554315022, 0.082362500817648, 0.10578007423984152, 0.12216710884656225, 0.1077827907034329], [0.027448627831680433, 0.01865690727052944, 0.0270324365036296, 0.040378652047365904, 0.009131217076043998, 0.07344283230070557, 0.02456508470433099, 0.017981079606605426, 0.05898816364684275, 0.011352882371284068, 0.022368739791480557, 0.03322565462440252, 0.011057197166207646, 0.025183845876849124, 0.04438006465456315, 0.022243222687393427, 0.03732130556766476, 0.03594563688550677, 0.023212158819660544, 0.03607668235365834, 0.003964672904528145, 0.06633593115423407, 0.06125789042562246, 0.013108919973352125, 0.053691532861973555, 0.0186301187079932, 0.004402239782003952, 0.07056959612028939, 0.06862450763583183, 0.024404774020825113, 0.003398365033457854, 0.010608248711962785, 0.05994783607976777, 0.032387748693249056, 0.022569698115278567, 0.025111469939084988, 0.06038796103426388, 0.029028362528021847, 0.03495199020419802, 0.04264671302267483, 0.05142135485740645, 0.07348536966102463, 0.010744078700164599, 0.01663403831688421, 0.04958365811035037, 0.04203572955780795, 0.018305314172591482, 0.08616691774555615, 0.03661036371652569, 0.02506001153960824, 0.033895161734627824, 0.04939257586374879, 0.004862707640443529, 0.029880829820675508, 0.03970709915405937, 0.07119866593607835, 0.06310930036540542, 0.027118289843201637, 0.02396854555367359, 0.07227486318775586, 0.029646864160895348, 0.04529008189482348, 0.022917515165837746, 0.022286750708839724, 0.07559674672250237, 0.028938429496650184, 0.024257864403937544, 0.057740975570465834, 0.022275985750768865, 0.012917188029470188, 0.0202321246199842, 0.03386575063424451, 0.0019704676025347517, 0.006460482038424483, 0.021334476003955518, 0.02839987794868648, 0.015531520691833325, 0.04149328152249966, 0.0641642255442483, 0.04424344502123339, 0.02319486635471029, 0.03618420301271336, 0.049342635686376264, 0.025122713264343993, 0.036477241931217055, 0.023864945130688802, 0.009680308817353631, 0.08526669855096511, 0.05292780777173383, 0.04827120853587985, 0.04021884008709874, 0.01967335951381496, 0.0636483896523714, 0.048575215972959995, 0.040786902819361, 0.0580185167491436, 0.0685685963502952, 0.043369417278362174, 0.026179909839161804, 0.020411673467606306, 0.020454327875216092, 0.019519038598186204, 0.03886144435299294, 0.04533694152321134, 0.04164965670289738, 0.033209081406572034, 0.052632519509643316, 0.042365589179098606, 0.005434076534584165, 0.05057764745184353, 0.01700304601607578, 0.018281806326870407, 0.04490120669028588, 0.06423091875123126, 0.03917662726183023, 0.098572675271758, 0.04688714298286608, 0.07546443239386592, 0.060858104377985, 0.0412553532182106, 0.010175878564561052, 0.02979213172303779, 0.035938427450933626, 0.008765957434661686, 0.03131462520520602, 0.10145602840930223, 0.06339653780949966, 0.020686570056048886, 0.07162372062781028, 0.04623602417164615, 0.04582068270870617, 0.045999625963824134, 0.02417725953273475, 0.06782435878579106, 0.04617217402639134, 0.02778426348231733, 0.031440320424735546, 0.09425050898322038, 0.023095752744536315, 0.020501693012192845, 0.021356238318341117, 0.02306625004192548, 0.04692139543060746, 0.031655080150812864, 0.09713189436921052, 0.032343630346336534, 0.027643862712596143, 0.030103402877492563, 0.011608690921483296, 0.03412675591451781, 0.025022301955946853, 0.009032145874308688, 0.03877706513074892, 0.02040246914007834, 0.02761079091578722, 0.05016022967174649, 0.02456353255547583, 0.040358614908265214, 0.037258564827165434, 0.07483993590410266, 0.03013941951628242, 0.040683785852577, 0.03349438502586313, 0.023803561460226774, 0.03774902690201998, 0.09107578612331833, 0.04010827959116016, 0.04711088651259031, 0.07441784641040222, 0.023913872594545995, 0.06461628592972245, 0.0590993416096483, 0.02203309565915593, 0.019957163570714847, 0.029862930066883564, 0.011778029513412287, 0.020210055268502662, 0.01580179306412382, 0.004349286060979856, 0.021697329390527945, 0.03093587713582175, 0.03013769943001015, 0.059594224340149334, 0.022938977228477597, 0.035213375464081764, 0.03705141147864716, 0.0738434393757156, 0.027410467022231648, 0.025237307650968432, 0.019878351728298833, 0.028729545883834362, 0.028916037841034786, 0.03227919666096568, 0.031191854471606866, 0.09613308403640985, 0.0279009257044111, 0.041422819053488116, 0.02119358499268336, 0.05112667727683272, 0.0054723255535853756, 0.039441198243626525, 0.03198361662881715, 0.04154894175007939, 0.07226889207959175, 0.02625087951309979, 0.009898741114219385, 0.029715925455093384, 0.10879800122763429, 0.042294326038765054, 0.028528214365776097, 0.02022917808166572, 0.07494422673646893, 0.02911756274157337, 0.019761940564161966, 0.07106543558516673, 0.027194887965119312, 0.040788124182394574, 0.03480114847687738, 0.021624680342418805, 0.028627080310668265, 0.01958047824778727, 0.033374270756861994, 0.061911407858133316, 0.02485571991253112, 0.05810315042201962, 0.031065599460686957, 0.02385363564826548, 0.0298523686693183, 0.03287401742168835, 0.042015940083989074, 0.016032165880980234, 0.041007453841822486, 0.026088207527729015, 0.03413367018635784, 0.05948375205376318, 0.060806929266878536, 0.014684995669605476, 0.011860362952575088, 0.0027953535068913227, 0.02666435161206339, 0.036787115303533416, 0.05185360541301114, 0.006444293041048306, 0.012034296922917877, 0.013450875329518957, 0.010807198572105594, 0.06740619122449841, 0.026448007506717528, 0.0350663606742663, 0.03958024024697287, 0.03907797166279384, 0.03644951020500489, 0.04252529935911298, 0.02840698729934437, 0.044979523202138286, 0.02226865926890501, 0.027257167301805954, 0.0032438753322432084, 0.012638206660215343, 0.06437718375985112, 0.021828288345464637, 0.03339042667565601, 0.024941736100507633, 0.06043480709195137, 0.0337712205281215, 0.02571676897683314, 0.0356358652934432, 0.035190702216433625, 0.022154034348204732, 0.05979532854897635, 0.06058885489723512, 0.0760845523327589, 0.039522140686001093, 0.047463646690760336, 0.03472840613020318, 0.08603723613279206, 0.07620100251265935, 0.030881363632423536, 0.02249687264806458, 0.03302527305537036, 0.02626530177492116, 0.021967866391475712, 0.021918163701359714, 0.06848928917731557, 0.029805729564811503, 0.013684326999022492, 0.011339062309291745, 0.012938105567757572, 0.026066865905054977, 0.05094535914914949, 0.029782944358885288, 0.006924054194574377, 0.01662666773024414, 0.03208086426768984, 0.018124063898410116, 0.01785322155670396, 0.011813756926650447, 0.05190055325095143, 0.08656793872692756, 0.0699346230498382, 0.04224057249458773, 0.061945918149181774, 0.03231324554820146, 0.03514259408361145, 0.04965692971433912, 0.04926308084811483, 0.021224000324894274, 0.05200049128117306, 0.037186782607542615, 0.035971706200923236, 0.031246591891561235, 0.004208579102331507, 0.02847333106079272, 0.012454851231138622, 0.04602599722732391, 0.01034091439630304, 0.03231715051723378, 0.036179975739547184, 0.0616739545283573, 0.03754426199676735, 0.026885689735146504, 0.015606295250888382, 0.0385992041389857, 0.032759467139840126, 0.013786424466940974, 0.034420249451483996, 0.05992028755801065, 0.10915382499141352, 0.02918894123286009, 0.004053544028595622, 0.025756938249937127, 0.046991505061409304, 0.03172367664852312, 0.03454799045409475, 0.02335760280090783, 0.05495016443143998, 0.0302697084178882, 0.05331514270177909, 0.04324455665690558, 0.014844444613637668, 0.0666390395324145, 0.04962088932682361, 0.04033067622887237, 0.014288247762514012, 0.028676620152379786, 0.01933979000230985, 0.011741786413559956, 0.08420948670910937, 0.023356225374819975, 0.003588885792331504, 0.04371519872386541, 0.08625833676861865, 0.08067453639315707, 0.15670868035938057, 0.07938257179089955, 0.11308822887284414, 0.10104400837527854, 0.10257754501487527, 0.1062739866652659, 0.17303880623408727, 0.17225866738174642, 0.1623792110809258, 0.11623971190835748, 0.10387632210872003, 0.07074693124741316, 0.10998005672757115, 0.15880487859249115, 0.1876491443919284, 0.1098231455045087, 0.13489147249077046, 0.21816336629646166, 0.13750470083739075, 0.18496863251285894, 0.12953978537448815, 0.0846258629379528, 0.07195024524948426, 0.1136439015556659, 0.1365710095103298, 0.11586198503417627, 0.13653812770332607, 0.1328162681311369, 0.13376914842852525, 0.07875620254448482, 0.12394360852028642, 0.1258630755224398, 0.13412459221269402, 0.0733741916982191, 0.12501924937324865, 0.10227770039013453, 0.07821553905627557, 0.12217774827565465, 0.1383072720574481, 0.08638767232852322, 0.12107466746653829, 0.07884606093700443, 0.115530683525971, 0.09131936662431274, 0.12264662954424109, 0.10336236575884478, 0.10709503439388104, 0.13304824568331242, 0.11232420522719622, 0.13952137476631574, 0.1296288770224367, 0.07625817587333066, 0.08458103212927069, 0.09083764747317348, 0.16142380663326808, 0.15884335152804852, 0.1582806831491845, 0.15155919667865547, 0.16890103183686733, 0.12314098301742758, 0.1409137693366834, 0.06059002876281738, 0.08200206301574196, 0.16704475001565047, 0.13910708842532976, 0.17837438492902688, 0.11138108226337604, 0.07394817125584398, 0.17227546790880816, 0.10940999910235405, 0.07195618921624762, 0.10776397492736578, 0.06558826020253555, 0.10154630070818321, 0.09366670423852545, 0.06692342034408025, 0.14293463661202363, 0.11023520625063352, 0.11850280261465482, 0.10305307592664446, 0.16577601166708128, 0.13815920214567864, 0.1295162673507418, 0.077265780019973, 0.10810203464435679, 0.10499268863350153, 0.109052071880017, 0.12104901884283338, 0.10112898810101406, 0.10570591036230326, 0.12453829018133027, 0.16153889974313124, 0.1930680607578584, 0.09772893054676907, 0.14854799397289753, 0.13821501843631268, 0.14474157536668436, 0.09081712857420955, 0.24210734718612262, 0.1445494413908039, 0.16154265882713453, 0.09082854153322321, 0.11347059692655291, 0.15132662201566355, 0.11649299546011857, 0.0989507142720478, 0.11579930196915354, 0.07002724307988371, 0.1130107876711658, 0.11350216916097061, 0.08286781941673585, 0.08545478167278425, 0.1841896471700498, 0.13491338917187282, 0.24224272849304335, 0.07643902581185102, 0.13470433253262723, 0.18560694397560187, 0.13551501903150762, 0.09289122013641254, 0.18572108713643892, 0.3241317000772272, 0.2510005799787385, 0.13585930769996984, 0.28558352855699404, 0.14632078419838632, 0.15733343469245092, 0.15131398769361631, 0.12399802702878203, 0.13340136887771742, 0.08952836665724005, 0.12255977706185409, 0.1374162605830601, 0.11626963530267988, 0.17436638713947364, 0.10930648858525924, 0.13290099001356534, 0.1928078561489071, 0.1095129396500332, 0.04856737210814442, 0.11047642544976302, 0.13438000636441366, 0.06393000882651124, 0.13221602248294012, 0.10208923050335475, 0.10034009614693266, 0.14210079849830695, 0.06445965969136783, 0.11365036120904343, 0.10666174907237291, 0.17423362497772488, 0.11394688779754297, 0.05100004907165255, 0.11906913508261953, 0.1909779014864138, 0.1315381388579096, 0.11709011984722954, 0.06465172581374645, 0.1148981803229877, 0.15632486024073192, 0.14142500476113387, 0.10063335219664232, 0.09448746019708258, 0.10792213465486254, 0.1326709259301424, 0.171308731926339, 0.16895553176956518, 0.1708421983889171, 0.08312920467661959, 0.10598026242639337, 0.14159173438591616, 0.11786252340035779, 0.09874832084668533, 0.15426986265395368, 0.1315514381442751], [0.015534531690978577, 0.08034578617662191, 0.02243333462891834, 0.008689629030413926, 0.06466874347201415, 0.024867897919778312, 0.10662744234183005, 0.023701489437371492, 0.014609440795278974, 0.016300933601866876, 0.07097284269652196, 0.011410258444292205, 0.027220348295356547, 0.01141509470263762, 0.030853903320218836, 0.01373294657761497, 0.022900682408362627, 0.030329141300171614, 0.055109324998089244, 0.012818998923259122, 0.04683844791725278, 0.0330578359509153, 0.05698394083550998, 0.020288290356152823, 0.0185411084842469, 0.022948290121608546, 0.03236145885395152, 0.03285486916346209, 0.012624336556265396, 0.051981231064668725, 0.040547379957778115, 0.030430093740246127, 0.03486899858606713, 0.036159324526254616, 0.05852549097367695, 0.08068034465291671, 0.03205062196190868, 0.06173478519277913, 0.019903598320005194, 0.028919383018676723, 0.01466250223373728, 0.015141276542895606, 0.020557538140565157, 0.04168460125635777, 0.0025517098173233016, 0.04593130088012133, 0.057534069887229373, 0.013491253252141178, 0.022170870498354946, 0.02333299063944391, 0.04252539435401559, 0.02520138431074364, 0.039952416704701524, 0.020967263029888272, 0.04079915037644761, 0.058185639924236705, 0.012406194333120115, 0.03555645973288587, 0.03431696624362043, 0.02081008378549346, 0.05865122351263251, 0.00595150571150173, 0.018876426919762577, 0.034979759249836206, 0.04892614410657968, 0.030050317690308605, 0.029789875594100783, 0.02702331868931651, 0.08169909034456525, 0.04388392663427761, 0.03638717997819185, 0.013679444091394544, 0.005463067367340305, 0.08347201413874115, 0.0236303484333413, 0.058833898710353036, 0.032376464655888934, 0.03393123604889427, 0.026608352116974335, 0.05979762199733939, 0.06653987163943903, 0.027701451675966382, 0.04282550021473851, 0.03091171450380768, 0.040624488677297316, 0.014911136124283075, 0.023757857037708163, 0.03346870247540729, 0.03729839822543519, 0.01316706363910011, 0.032043670370642624, 0.01999041687564126, 0.01480921168279435, 0.07629933580756187, 0.09812981582113675, 0.02148266974836588, 0.050781516690871546, 0.1356497760862112, 0.021280447653095638, 0.03524332939248, 0.025826790037431886, 0.06116211520774024, 0.06201003970844405, 0.038184313901833127, 0.05965069202440126, 0.014096436938936157, 0.023119733868432895, 0.002800923431225653, 0.03645346945683871, 0.05329182145318814, 0.04939146985166839, 0.00958502893003502, 0.053301239519246986, 0.061043093380119116, 0.04362798661791852, 0.07263188795851809, 0.0060336347419901615, 0.049656794007335386, 0.04387025076097675, 0.026037146071238176, 0.06371148662375552, 0.008432374352456203, 0.06624933651515416, 0.08194896086518254, 0.055804708041250706, 0.011434959663477327, 0.04274631517806223, 0.020091829023190906, 0.03859573343236532, 0.02256149293056556, 0.028962062871349708, 0.042137988177793365, 0.0643654926014798, 0.03357339025075946, 0.012512362162981714, 0.08198982224400554, 0.0556521428349827, 0.030335733267877783, 0.0431571443831282, 0.024796863785013556, 0.036551225996975384, 0.017350871548322693, 0.024635521728279333, 0.027458040808726634, 0.02242274778628988, 0.05485540362341063, 0.03058720173846398, 0.040540211235306094, 0.013709039244401668, 0.0055553273497415435, 0.0072366752096318775, 0.011385239161817091, 0.03353004204109311, 0.08282188259597335, 0.01411474381373929, 0.03893363708630204, 0.0379230677416282, 0.08229554298200778, 0.03269169845485261, 0.01895207678899169, 0.046261068899184465, 0.05047646430986268, 0.03083881948675428, 0.02579785051888653, 0.009729092940688133, 0.03684173058718443, 0.06402370094188622, 0.005160085790391479, 0.0137462611310184, 0.07055401017091104, 0.03406000163938318, 0.03257522791890161, 0.039942506700754166, 0.024684654448979666, 0.027975905520309294, 0.024616816214152744, 0.06844338628330401, 0.09153203985520772, 0.03651209827512503, 0.010156190870994968, 0.0017326762775025728, 0.03560193854251078, 0.03471460133524878, 0.07764399543936763, 0.03784167407346623, 0.0050046830354923645, 0.011587495183838266, 0.02806516849835004, 0.018899663351476192, 0.007599360658787191, 0.0028190683057930854, 0.03784803533926606, 0.03099914374096053, 0.015097923244216611, 0.04925435149509992, 0.013536728669090994, 0.04886570020711847, 0.0513344786262938, 0.016743932152166963, 0.02210625700120415, 0.013929041501666819, 0.04363117912518127, 0.022284153616055846, 0.04668541452182191, 0.01891847064585558, 0.03967677203140088, 0.010728841348152076, 0.03075082367286086, 0.019188966934702227, 0.06195368058979511, 0.031781861026372225, 0.04861297983942287, 0.04510067902239306, 0.027813206393537775, 0.011004882964438625, 0.030094700665878396, 0.03714801111657705, 0.05146613816863724, 0.02726375248416194, 0.042968681281698604, 0.041201972868293524, 0.05961350152002914, 0.07690704534096376, 0.021072463099179522, 0.012278691665934665, 0.00393103453097865, 0.017118234120841538, 0.017050378922639147, 0.07753072758870465, 0.02227408585271665, 0.03263707977852651, 0.023262468798618232, 0.025758956891617606, 0.05419672253940787, 0.03464591323531099, 0.03771621973386832, 0.012322000011668673, 0.02297138575730579, 0.03578909546402948, 0.03692273409771068, 0.03795470443687268, 0.04263571057734745, 0.03336762111367924, 0.03688696173152753, 0.055041098301964145, 0.01697399962826499, 0.02242946019396186, 0.035359464053596766, 0.00723321722554309, 0.05328770613830004, 0.04069846256503037, 0.018802982289344072, 0.03956891210483653, 0.026555468793958426, 0.026225593905629854, 0.061830791112567694, 0.05860250469829355, 0.019380512281454036, 0.06155278853007725, 0.05475067513595734, 0.07757061866245099, 0.03631479725507753, 0.023919981106051376, 0.026020420183028494, 0.04584013291501573, 0.002506413363984653, 0.019413942005485296, 0.014770234934985638, 0.003715667940144028, 0.03719006332435778, 0.07511901735727276, 0.10491552563118083, 0.06832631185118641, 0.028296969631420713, 0.047591309661843946, 0.032188004947134426, 0.04701489077082702, 0.03461178970922317, 0.043409749399870634, 0.03417924738356045, 0.02036321080023689, 0.034916149984513006, 0.014169765370232719, 0.031069921728755747, 0.034605112924639664, 0.020846804404365163, 0.03794395983485239, 0.02996143638821585, 0.05398898904344865, 0.02492864546366036, 0.046029389902417145, 0.018926283976595317, 0.03760770841368607, 0.022919867986014912, 0.018634578379403268, 0.017188874705295478, 0.006687492290179112, 0.01293594782639827, 0.05402932455763221, 0.03906320674078805, 0.029469308509890522, 0.00408672566326069, 0.04563839088327118, 0.03330216623310532, 0.07090492812650544, 0.04338037222623825, 0.022334758757746646, 0.020884602197578976, 0.02415010965030108, 0.04044835116448147, 0.04268381531749453, 0.07296894344368152, 0.06747285729008061, 0.010643771716526576, 0.014903539924749305, 0.020084268446745615, 0.04145648796111345, 0.01486857162256326, 0.04058289108797908, 0.03692888841032982, 0.029468891210854053, 0.046958915024463616, 0.03758442448452115, 0.03500277176499367, 0.039855810281421454, 0.06172571996492999, 0.042068662254938056, 0.007451843753057931, 0.035602830816060305, 0.09724067710340023, 0.08732365031859704, 0.024928406280066286, 0.05263698427006602, 0.06528344870145832, 0.029710310577814068, 0.0512388900055417, 0.017188353929668665, 0.04596138373017311, 0.02144226129166782, 0.02949041434164558, 0.035832016196634085, 0.0636467340269259, 0.024061051929103475, 0.019839731211374913, 0.09632757931415524, 0.009242851353649582, 0.056990108718829494, 0.010941949689627757, 0.04725263587066105, 0.062069187606019635, 0.025022001704201102, 0.08057042197989565, 0.1357843702925103, 0.2774840188877923, 0.09850030951201916, 0.10452424162732703, 0.12973447064203875, 0.14151568418102606, 0.14166065997311048, 0.15111717182610715, 0.1673337516507932, 0.1083887428311365, 0.15851141219692572, 0.06045473566544907, 0.09963531539376293, 0.061541518063417504, 0.09923097637615033, 0.13639893302960054, 0.13762959199292318, 0.09193079452961683, 0.25657048395701815, 0.09462949793253626, 0.15864995547703334, 0.12491163371929101, 0.07528112615857806, 0.12323723999517304, 0.08709207988743271, 0.09830867086670228, 0.11312594184918062, 0.09105424942182642, 0.09156699119401829, 0.09804999974689313, 0.12248342830155577, 0.08791502072874989, 0.07689115405082703, 0.16550142211573465, 0.1156510692089796, 0.19942099414765835, 0.1064995995589665, 0.1849429024649518, 0.12420202179678849, 0.11555125670773642, 0.08779971727303096, 0.11205144772039992, 0.09217930798019681, 0.08999207748898438, 0.1359418582703386, 0.12714925222098827, 0.14431582178388322, 0.06270829295473439, 0.10259573653872524, 0.05766444360571248, 0.11119425443134137, 0.11516963504254818, 0.2012760274644409, 0.0803404732474259, 0.09558557412986245, 0.09144761652818748, 0.1612730361521244, 0.12128209562173911, 0.1011940324679017, 0.14968192098396166, 0.10342768832509007, 0.10276239831000566, 0.16819813741104944, 0.11507238740367548, 0.12861495571477072, 0.10262851656547614, 0.1566889892731394, 0.11645625957420894, 0.16767557045178755, 0.10614308368946825, 0.10933119404528822, 0.11092609739197151, 0.06249912774988583, 0.21213895242129052, 0.07449635969741003, 0.11918486601540021, 0.14117831656975405, 0.06345868483185768, 0.08022061003638165, 0.14902592689863273, 0.14577307073133333, 0.07940149613256965, 0.15049424953758717, 0.11838180625012942, 0.16597532454345906, 0.15044572071305343, 0.1517883108130523, 0.14044412810887608, 0.11435737434242453, 0.1338441265480859, 0.14958897525710718, 0.12753251594092163, 0.14909440465271473, 0.1428722521024091, 0.20948206713157042, 0.15598053086016858, 0.1460342795721122, 0.18490608515483992, 0.13201939660523618, 0.10393886268138885, 0.07980157395026513, 0.16035694602344716, 0.1561923287808895, 0.11773411743342876, 0.13146046016897472, 0.14141980718289102, 0.08897120119737727, 0.08496746460774116, 0.12042863427528314, 0.09689421033752815, 0.1199052802153996, 0.14455396043402807, 0.16857315014515603, 0.11642071790993214, 0.14566363660352571, 0.18458311605666364, 0.10610079738710608, 0.10445976722985506, 0.17723870729761465, 0.13377260895712034, 0.11504371251378741, 0.061127665984843454, 0.12748527633292334, 0.20100606552192143, 0.18907469218330725, 0.09394215552934579, 0.13574789224990777, 0.07587856267179761, 0.12669339882475988, 0.08679464406200818, 0.12109733053616115, 0.09244838782719203, 0.17197085996823652, 0.1500445572393281, 0.08384159180734839, 0.15565809101930686, 0.14044477950249398, 0.07373776433191129, 0.17798623575695924, 0.11138202542705194, 0.13160771583872183, 0.13191283946590765, 0.1522265358694962, 0.15537121998412268, 0.07788028847426176, 0.10567891823926143, 0.1434567150260721, 0.10034341418317386, 0.09818779663848025, 0.11484431821320738, 0.11985702280487333, 0.10664851763950926, 0.11639129663152353, 0.23467261184539112, 0.15108977258205414, 0.1075499514117837, 0.15709028845386847, 0.20751789824238845, 0.10264244688940899, 0.09392107344631638, 0.14030633121728897, 0.12045170446591717, 0.09234643115528993, 0.23752682868923458, 0.12861822625356062, 0.12102489013757024, 0.176931480211871, 0.14520004790808472, 0.14734154513904027, 0.128738313381161, 0.06460372624652726, 0.08376543303685528, 0.1379472278058529, 0.08096526150724717, 0.11026109236159495, 0.1887930730091674], [0.03278504451736808, 0.03199180315381714, 0.035705686546862125, 0.05599862317155514, 0.08047732697533709, 0.03023649412872536, 0.032421495632401535, 0.007573790066609425, 0.019402254239789078, 0.08274214794593197, 0.032486970869026015, 0.0384382522398872, 0.020502269766958695, 0.011053036050205784, 0.020119146843041693, 0.018081490915002565, 0.026942147241373147, 0.030562876258045435, 0.04407742785822068, 0.01297875405621848, 0.08085199365658419, 0.029014937712677887, 0.05748227730925594, 0.01825299403364105, 0.021661875935803567, 0.015262883588937777, 0.03938411987785782, 0.029018025047012737, 0.020726449255432402, 0.05448957825345652, 0.04307102132588625, 0.012877098484230893, 0.03565210263643946, 0.020777965330385735, 0.012830347421446016, 0.016135091161621467, 0.01725533721037209, 0.03317736328712531, 0.03764729414667402, 0.08151829468884639, 0.07736855771924768, 0.010922474886423774, 0.04143202677369118, 0.01871207556022065, 0.01654065154226763, 0.03883149042459471, 0.06020657505307879, 0.05453609861433506, 0.0420423825936658, 0.03525210624294622, 0.011257040996237524, 0.040032341344548125, 0.015490499857280935, 0.0624468805534499, 0.04931879535849605, 0.08796238247305155, 0.027325131065611328, 0.10077349003404379, 0.03973246957840664, 0.04751182606975947, 0.024999055346207957, 0.030328788461961916, 0.03026107745245099, 0.02366974756919912, 0.037685753511531014, 0.037068754833723815, 0.025663539600957717, 0.03248819901740976, 0.021077065262943506, 0.012060279725119472, 0.04120791683505688, 0.001792000382140811, 0.023316761778135384, 0.04430980235338211, 0.036220402855958254, 0.021954770665615797, 0.030218333138951232, 0.03811257917966161, 0.01285799517894962, 0.01895404284420822, 0.025816327027444328, 0.04047435601907117, 0.019329125128154243, 0.015980532758736184, 0.00926292157133243, 0.013692040245846977, 0.049483238320265494, 0.018288581499031613, 0.024948679210085953, 0.05309091741219163, 0.04902676745717015, 0.02044965955428779, 0.013813446275889874, 0.0828156400738018, 0.04376030773190515, 0.007896175624669662, 0.03809839440509677, 0.026672436356810585, 0.016410947877115438, 0.03790316630953124, 0.023228346968867948, 0.028906433177845817, 0.029870896068002497, 0.030374538685594286, 0.012921648549049028, 0.04224890151194163, 0.0280531669102077, 0.0350347850471735, 0.011364889048439051, 0.039320330800754685, 0.05155728917036738, 0.028394040851188556, 0.021520448881866674, 0.03875476507736104, 0.036050931949700625, 0.023726829327642918, 0.037446970253118446, 0.06482796849949019, 0.051850205952567716, 0.04871082119643688, 0.0562600016460887, 0.02910601068288088, 0.046678001526743174, 0.04021909114505563, 0.03724215445773942, 0.021680712067921246, 0.04890616125028048, 0.007566227793826589, 0.06501799223146268, 0.009719552738325936, 0.03840010839381388, 0.0074584993334220985, 0.016512575459533503, 0.0246886035227882, 0.02438418726835932, 0.05335990904963442, 0.01338951286327626, 0.013775616252262677, 0.010815853286268455, 0.039266129423465045, 0.03830324751990182, 0.03548060630315116, 0.025432635830449205, 0.057631934992969036, 0.046009824345154424, 0.07023392484656402, 0.027680579938792756, 0.03249490633606911, 0.007928508666477032, 0.054164386953094175, 0.0082514684347968, 0.042284846904554536, 0.025211385916918516, 0.003552357495729146, 0.019189947417804172, 0.0638826402968594, 0.033202068747154305, 0.05802104089941297, 0.010101298236155083, 0.08040728180536202, 0.023328664978700023, 0.04897047619202307, 0.0479829193625067, 0.05442685786900776, 0.023149757346670543, 0.08677389446113791, 0.028297147746863108, 0.06633939846817936, 0.037578833355967484, 0.03966517247525709, 0.019888487345139896, 0.03855385425101433, 0.02274204770635281, 0.03795346611046365, 0.046445392937000306, 0.09510903220091547, 0.05856275611690112, 0.016088172161419476, 0.049508557854486365, 0.039318458044103215, 0.10625717256750379, 0.03664657373779586, 0.017415803956932256, 0.016688672260248234, 0.04331216588616371, 0.08850607222744397, 0.013991531184209245, 0.0648863021550434, 0.06887030694633722, 0.03456294197323067, 0.030544847582599947, 0.04918315281559314, 0.009466946025245955, 0.03719880624807306, 0.0383026063043092, 0.0357781914062798, 0.04451199561091406, 0.024720343694623028, 0.05615006879504238, 0.014869421487674117, 0.008167839841917157, 0.04267841078607099, 0.05353735613503626, 0.0549737978061395, 0.041120823472738266, 0.03606667056945818, 0.004843479654352579, 0.07057057999606643, 0.0525315670695688, 0.010185384840172316, 0.007887491224599736, 0.06337546251182045, 0.02396614014703248, 0.06302625446447305, 0.063890267030469, 0.051829028874635696, 0.014607157524941223, 0.04784663899668625, 0.09589795808174781, 0.017188572757212178, 0.014138264381991965, 0.028480788160647665, 0.08021227084100246, 0.04383141141650932, 0.04298724260713373, 0.06400391486074243, 0.037103947052466016, 0.0662486104826842, 0.055778777825513055, 0.019092024636587927, 0.009590707419972335, 0.020233247595440065, 0.0855264960389052, 0.018724776039432203, 0.06440954988024064, 0.016212973411061933, 0.04595480872584241, 0.09350089742136852, 0.02725464484787413, 0.027697375376841853, 0.06700109224766493, 0.015439954087404268, 0.02924227747800095, 0.010517130788814808, 0.05612182477489114, 0.04810894027884517, 0.01970971202743905, 0.03205262703288879, 0.031142260347093855, 0.0987460273983223, 0.046972516258912425, 0.037112496593700986, 0.04051186543490205, 0.03891868217449103, 0.017725772324151227, 0.050523629279008934, 0.03230388176494411, 0.03216277701514108, 0.02936768771282264, 0.05700021889060736, 0.017093596514314413, 0.05941224803349801, 0.020218642129163657, 0.08194605673530272, 0.07418377897036926, 0.07904792510505233, 0.02320022338868252, 0.020342900550791194, 0.023073128690677028, 0.07196467768933092, 0.046992010569998195, 0.025419356900134256, 0.020820933560441648, 0.023698556469753385, 0.04911294140453849, 0.011150742548384836, 0.048371977771499326, 0.05108664710340755, 0.037953248979257684, 0.0444582590301122, 0.037643602916172574, 0.03792531029986484, 0.044207818540079255, 0.029218935873359442, 0.016962033663211123, 0.039434908224003654, 0.06701276304998569, 0.020054786100185344, 0.029820382528539215, 0.039879257058990855, 0.03514104023841875, 0.04099248196663601, 0.03409842029213905, 0.023788014526611993, 0.025658143551221917, 0.03985743537279112, 0.02124536908896906, 0.022702214308083057, 0.06292616376387221, 0.030150513563837324, 0.021622592150898914, 0.04786845729021089, 0.020316167967393994, 0.007936435651832392, 0.022266815349991833, 0.029548463012490953, 0.06107299641839095, 0.015358465424339687, 0.03301533930269735, 0.0222518451711429, 0.034017030016652176, 0.021529992476903966, 0.0010793705691217578, 0.026416180821667825, 0.009020236736562635, 0.016545810104746903, 0.03375550565708961, 0.03346313848825438, 0.016326689094837223, 0.02235866354645363, 0.010378460283391178, 0.012102369252326233, 0.047456148878804276, 0.09930640232882329, 0.07711000873574189, 0.04644716730607407, 0.03818179653691394, 0.012384932438310767, 0.06839326968682663, 0.012402190128341317, 0.049957368057221174, 0.02101480119329478, 0.03399588686547109, 0.007903401174449494, 0.03620588220655918, 0.053560823268656216, 0.08787914658231394, 0.01632416494456785, 0.01138686849403062, 0.07518766474510942, 0.03010118067530649, 0.03857622215790408, 0.03014314128085971, 0.054140329494007995, 0.017559566867670844, 0.012010114783022021, 0.0514316685896899, 0.02610095720072942, 0.03895505843684077, 0.07745764936719622, 0.07891825706298862, 0.01308173786050507, 0.09952699406338589, 0.09999630959438426, 0.11906283827764647, 0.14748212402420385, 0.3060394051883902, 0.1124515798208969, 0.12387325800955296, 0.06385509856045246, 0.11407249820019517, 0.15123936241226538, 0.07940889216427292, 0.0982368207935776, 0.11825652154428618, 0.10019782770957265, 0.09276801853307656, 0.10310086514800787, 0.08938603715172835, 0.07985736309949841, 0.13818415866366454, 0.13231466790395124, 0.15377115298594746, 0.059107789370630465, 0.13618305032806738, 0.1049184501171112, 0.11548336249377046, 0.14665120361106737, 0.1541663317808083, 0.10371198092720338, 0.10331964519407068, 0.15273566783538886, 0.08071421033569745, 0.23739828701530183, 0.1646043173968792, 0.1656938275056226, 0.12930695286818913, 0.20698025423501218, 0.13380298018455505, 0.16333912100110734, 0.15551060464765343, 0.1749626701431615, 0.10048177425882646, 0.1218101858560528, 0.19115964030580862, 0.10418070613273553, 0.11539074246372495, 0.12638216838240623, 0.1604701392352581, 0.1519393662789038, 0.12644998117216996, 0.1355441553252084, 0.07863261417618819, 0.10627217497676611, 0.16156695038080215, 0.13133369625679084, 0.04173452786302992, 0.13815517164766788, 0.13288836926221848, 0.21713690566165106, 0.13694630722914422, 0.08603239139275891, 0.10427067309085812, 0.1343627172921385, 0.13456912764481135, 0.11923663823732308, 0.10984426829963923, 0.09066523172493492, 0.0795444498902985, 0.10698453496609416, 0.14996932127646037, 0.11212352849543095, 0.0968562870153359, 0.12322711625269481, 0.08089682446526629, 0.1541630748127188, 0.12695046860192502, 0.10446201318076678, 0.15951926740152494, 0.16553429035203798, 0.09250511335475103, 0.13009114935994148, 0.11306708572166306, 0.10353321409119026, 0.13179355300962925, 0.09031042576368366, 0.12425489324544157, 0.06956437363156251, 0.12400797435215541, 0.13446843304804393, 0.21777449787727424, 0.19264541486544268, 0.10822917853615113, 0.09245823337031261, 0.05412434660164373, 0.23509609912122997, 0.21389197478336947, 0.07843221564378057, 0.12640952691435814, 0.08601641189306974, 0.1050027377371277, 0.13597588001617364, 0.17444992837096962, 0.10764732118695974, 0.12844389703656944, 0.14886746183037758, 0.13147806136735848, 0.2070583536156586, 0.09648724538939339, 0.07394901942461729, 0.10950443760624953, 0.10626443967755352, 0.1405592890722411, 0.09090641021196331, 0.08056662218379122, 0.21123719295220716, 0.09361972925918442, 0.10668319756431238, 0.1073960732402546, 0.13210717189524854, 0.12094524369708129, 0.11031697650573083, 0.1216877374265875, 0.14090641401708126, 0.13963004893490247, 0.10089058482221194, 0.1176108004791396, 0.11811029724776745, 0.1208484438913209, 0.1102435454460127, 0.18923858553171158, 0.12533733301929065, 0.13667573460510798, 0.13819329174501555, 0.10438490446124758, 0.11959696747362614, 0.059946316161326, 0.20253669124628815, 0.1513744315930775, 0.06895368532942873, 0.13056900086147444, 0.10140108064349208, 0.08363596855529717, 0.0639335439939584, 0.06480589575533356, 0.1313139373170478, 0.12683097858514103, 0.10898809281310864, 0.1621391318206276, 0.11830836161971092, 0.19540515249328955, 0.14862166930522236, 0.1384660221104111, 0.09633920940437488, 0.1526570256267275, 0.0957385634205171, 0.107155797204801, 0.10740429029933043, 0.12373717102621283, 0.09650735038199595, 0.11424059846571513, 0.14878333705876554, 0.11541564469890934, 0.11028916335531644, 0.1845853959343263, 0.20349528480853352, 0.14209478667804173, 0.15983247916613305, 0.11966684300984655, 0.1422966101339885, 0.08165208822382347, 0.20196864887007646, 0.13384591788053513, 0.06173026614955493, 0.10035836909498487, 0.117780882066914, 0.1519133241048881, 0.20633324395333016], [0.03255616108487759, 0.05396981364382165, 0.04700636158564261, 0.043493707930403094, 0.023655958041282635, 0.011542836553417146, 0.078888652580125, 0.02816969681797283, 0.041322168561496904, 0.019690952230510966, 0.04783627776695149, 0.036766813535775454, 0.0799358831718564, 0.025320292483749132, 0.07275195473006793, 0.02426750469021499, 0.02619787405378052, 0.04656937824828284, 0.005556610629095563, 0.028688257027949606, 0.031170694357050315, 0.06586725344615323, 0.12709585151502065, 0.049699185482625446, 0.034677292087248394, 0.024823000953931893, 0.010783057144310857, 0.017867411420281445, 0.06754056151424136, 0.029759836848825216, 0.03089755687064358, 0.008235460097369338, 0.02274762187153101, 0.04519354332504528, 0.018021589843556285, 0.009027905878610909, 0.023283576326710836, 0.023918727512604425, 0.030658603978476355, 0.06992137804627419, 0.02457759010472468, 0.02715785352380148, 0.020719977727692043, 0.03638087299519351, 0.021870520365025316, 0.035864965857139657, 0.03896535859842386, 0.06673355946051222, 0.02653481758066586, 0.037612885635878356, 0.02292651423652257, 0.03945037882242884, 0.016441213931622248, 0.055474851812635145, 0.033743573618786674, 0.09791874393288579, 0.059882323523717265, 0.03510930176292147, 0.027664932921262722, 0.03237007285601326, 0.009598050017042883, 0.04138862767389842, 0.02694019814953208, 0.023633145693955675, 0.05060183383258326, 0.030864882016820566, 0.03701832950381296, 0.029165640340319703, 0.021279950626194477, 0.06128575785883835, 0.05785586511982339, 0.028617716527410915, 0.023600660829937885, 0.06448469763355595, 0.03387166406693203, 0.049919427771653445, 0.02531751218651022, 0.020790575903707316, 0.010796948452480137, 0.03878118383831211, 0.0617103511467576, 0.04014149048764791, 0.005150461619320724, 0.02428241549724979, 0.02007602254993149, 0.024863324593752623, 0.03255311106996877, 0.03501709224656224, 0.08958716171660594, 0.02686000888102821, 0.01673288899473846, 0.03802746713959745, 0.03965414288852896, 0.012600436008402278, 0.023150217054145675, 0.023046061928783144, 0.018155115357201015, 0.03469675925693341, 0.06214892904141119, 0.03212302164839847, 0.030645443791789666, 0.08625458446996552, 0.05730736455214875, 0.01970606659805136, 0.019176872047994818, 0.039260351697781255, 0.021311913018247912, 0.04682612572131412, 0.015396797563880682, 0.04160778091422149, 0.008487438317388296, 0.03424713481217623, 0.022903769742697477, 0.01973059054996286, 0.009216940645793719, 0.045169682641114504, 0.023194460930036645, 0.04574539924838713, 0.023618141588355814, 0.041906075086444616, 0.012780963642788785, 0.052978528264377794, 0.02741454671403127, 0.062222366886479516, 0.02308936942634838, 0.010654052370227873, 0.046777803849961073, 0.023401324204834442, 0.032537257099258046, 0.01862227823585272, 0.01651980185748211, 0.03089722099580935, 0.015898441895842552, 0.03544688650539943, 0.03263961410682116, 0.02077681351719158, 0.05261935593028154, 0.025306336714753082, 0.03950576424332602, 0.02438179373608104, 0.04416500298040254, 0.027522635646164417, 0.026526335892932754, 0.027452154517439858, 0.04768221978364246, 0.025054089625232985, 0.034676823898085525, 0.09668162531618561, 0.009525473063279475, 0.020026170582111393, 0.02543060022539326, 0.024382127914577723, 0.12623587623238564, 0.08149690726505858, 0.02399869795356478, 0.024181113611640673, 0.01789109907778246, 0.05083596234076789, 0.03921164306146758, 0.07562294495957238, 0.020852633020175353, 0.024759875144809484, 0.05528036332023995, 0.060677525853472095, 0.019520745113758103, 0.028528149904949323, 0.007812736173426467, 0.06137699367744582, 0.01767267526260444, 0.004214492535019028, 0.00938159819426281, 0.05776711952473436, 0.017050780954637697, 0.04814458033069968, 0.02636936360171863, 0.0065163004494804356, 0.04200283418010388, 0.024466924435858215, 0.014838013797998428, 0.049974952292229445, 0.01109085335130138, 0.05243146958361779, 0.03466731762247426, 0.049443957928035936, 0.046688104913170846, 0.006749942108789193, 0.03827341912048204, 0.031034322389002358, 0.08097897469997406, 0.042760150507092476, 0.05759428987013442, 0.05591633722984365, 0.0317142992945654, 0.1883074997791222, 0.03213792906275817, 0.013967354981494802, 0.0448573190452797, 0.017616485777710165, 0.026046043361670206, 0.022024557992283787, 0.017962762553777014, 0.017415194971753017, 0.05926313317779984, 0.0646247947588563, 0.021830944810062647, 0.02330110458258007, 0.03572119785738843, 0.01835041300260595, 0.035676445080233474, 0.03576415590941906, 0.021833144959860613, 0.00878120242019317, 0.005675305063570184, 0.06248094979673624, 0.05681842239573598, 0.08303418263260808, 0.011058684854236032, 0.04620762748111572, 0.050080165932221074, 0.047106367469366105, 0.048111678167645416, 0.012108187690111143, 0.054751859179564884, 0.08542364370077848, 0.021876752709171603, 0.034351442607917955, 0.06415771160806928, 0.02782575589870768, 0.03889067564159632, 0.014425588339301092, 0.03520519233175686, 0.045509750821760724, 0.03199886670336127, 0.03551491981904421, 0.03091340744867921, 0.03927125914820603, 0.04438871597605092, 0.022910137793847492, 0.007902873613472496, 0.020828066659825187, 0.023104996087827852, 0.06978077201970986, 0.02141347444350166, 0.018998432605128204, 0.08790861535817385, 0.061275925886418135, 0.04816573705258114, 0.016526090180767432, 0.030310074466147592, 0.01965091357539807, 0.005091277250487889, 0.010832649572486324, 0.02713292584355388, 0.03682938124984503, 0.037162840499409606, 0.02271794105347778, 0.045087074395269156, 0.043857497695301256, 0.010791785649156995, 0.020566309902018735, 0.04617865064314433, 0.04763174017093011, 0.05073617698092546, 0.03310234784813864, 0.03922378883830138, 0.017580710018851926, 0.03370590474722641, 0.028908207546919584, 0.10183117685041257, 0.059071202762424946, 0.029932378126042228, 0.05664912112323301, 0.03607061964326671, 0.04471184113728149, 0.059681008969034464, 0.03997095088873591, 0.018433572558153952, 0.06897033657878637, 0.06224671272294862, 0.035859500257564444, 0.05303718761673995, 0.04084716351436717, 0.0632497231875147, 0.03609308933040925, 0.02243402673463736, 0.05684875291106956, 0.030589379835873842, 0.0547337253311915, 0.032372495226029835, 0.03557782680062311, 0.04576400467859847, 0.0031095629300190403, 0.024557325656392744, 0.04081255144306591, 0.013149034115485847, 0.049489172109003575, 0.013851110906606274, 0.041210820964936695, 0.06631220278463193, 0.05222596168251974, 0.03408497851341963, 0.012354486572024013, 0.02083342369379742, 0.021502917233322347, 0.050168053180511506, 0.05373139679431915, 0.008672101622713464, 0.06864529116345303, 0.06077561487576791, 0.036911616301430125, 0.021268449457628385, 0.034018224238284996, 0.01196834586361157, 0.03853725049910801, 0.046280373220465014, 0.02424252781617854, 0.03452569718605705, 0.03762767091393471, 0.020607005039762174, 0.026341177257043973, 0.06515876789178167, 0.016276027974007384, 0.022996661186750447, 0.040049233473837376, 0.027888752786176543, 0.016323712022442902, 0.0061390125026394215, 0.035495622283113856, 0.0940632401034236, 0.07229746518922703, 0.032032840951744995, 0.022692375550312654, 0.04556419307898198, 0.010251856675105435, 0.013371014302330357, 0.04685749778790133, 0.018261679281879748, 0.027995245464678322, 0.05848782549479178, 0.01322921659863953, 0.001790114478873355, 0.05523197359538504, 0.04513695350449, 0.009343109991667526, 0.03625446531389441, 0.04076252644881606, 0.05152292476434793, 0.03392531583085656, 0.03562330221757293, 0.015569008055276104, 0.01962246429840369, 0.01886857796593436, 0.15347988504384244, 0.09643915761262178, 0.1123376673619662, 0.15434964480144636, 0.11256940742688519, 0.1383243439985173, 0.12799735314079694, 0.10966393404773303, 0.10824579585875783, 0.1552106650280101, 0.12236806377768517, 0.1669314210968358, 0.1473370125251157, 0.09699537990880863, 0.17404364874320372, 0.13532808263386997, 0.15552961719887598, 0.26565519933189663, 0.13414281766329492, 0.15906361756580217, 0.08011826659951891, 0.1701463742979935, 0.22943038599831717, 0.060456235227840285, 0.15228779401097978, 0.056679658591747284, 0.14971329644322395, 0.18724635243415833, 0.12842402953122342, 0.16065911123795168, 0.10268949650760208, 0.09686455157186304, 0.09622368203209979, 0.10139072619910751, 0.07384852160300527, 0.11510072302605424, 0.09649777625288282, 0.16081602924636432, 0.12668664061597415, 0.1684748168502535, 0.09518909933311598, 0.12260810232588223, 0.11257689166814089, 0.13893274563763822, 0.11307142834578242, 0.08412667829543352, 0.09400931014014141, 0.23377423148070062, 0.1256666939173426, 0.08288680482655764, 0.10330570129943745, 0.1597906814089843, 0.11701314683471407, 0.12305554188787937, 0.12415794416197709, 0.17494943871029786, 0.13871519373995916, 0.10071467461862735, 0.12547974394900457, 0.12838310029889854, 0.10664127767086029, 0.12754619520689758, 0.08987821931285517, 0.13090398002948078, 0.07161518465727568, 0.1513781092528786, 0.17369211332074233, 0.12052916602364608, 0.17188613808580808, 0.10299803995128189, 0.12301261776259967, 0.10088504797645978, 0.059398025939507146, 0.16978455228464945, 0.10567609553358384, 0.16241658478975296, 0.09292950986751489, 0.12249242567590304, 0.12466627545654774, 0.21714951284229755, 0.14923125159527573, 0.09825110395572015, 0.08014172355511359, 0.0876526515930891, 0.08101724407502583, 0.10621308136199202, 0.07465154065617494, 0.1477142915661846, 0.21303023530968598, 0.1011087406160576, 0.0859619119603719, 0.06415036307381732, 0.18674821273556777, 0.11310184028531824, 0.09379850288054772, 0.18106014866914066, 0.1136971190571785, 0.14697747038943426, 0.1090922886505723, 0.08967183610158307, 0.13305018629346574, 0.15514476570699895, 0.14725273847579956, 0.09075282381049224, 0.09913980162569455, 0.15007125080696174, 0.12459961617631571, 0.12457513463284288, 0.0949715677914875, 0.2062125868563141, 0.10484205385936157, 0.09232859925499984, 0.09613452931599957, 0.10201237284179245, 0.15188190793352468, 0.10059567993240696, 0.15395956858992577, 0.09540117545319454, 0.06445497101438896, 0.1553663888147899, 0.13426656887999602, 0.17670292247618946, 0.13133497190262589, 0.14117697307041713, 0.12185549842459814, 0.06346076793436493, 0.10151230610374894, 0.07721483561077289, 0.14196412797485078, 0.13322056643664837, 0.1462105493992567, 0.11639776985560145, 0.15567080676555634, 0.062294983704175265, 0.08837669595543828, 0.08224933474723782, 0.21718455239066056, 0.10647941314216171, 0.13507786606039318, 0.06410272313015801, 0.15792365159307206, 0.10315634217113256, 0.10072986023234469, 0.1308632679283619, 0.23054068642003195, 0.11750498972833157, 0.13838432649416582, 0.3066256051617009, 0.14157702374671186, 0.06830734679741518, 0.10650983186704771, 0.07358680386096239, 0.1855006446795804, 0.14385771565139294, 0.20724869625908987, 0.15902029989021166, 0.16399493866733142, 0.08910936449787446, 0.10604133057807173, 0.2186643694128309, 0.10191655012645892, 0.07808395076010909, 0.1062308589794806, 0.11560115617300783, 0.10305967128702573, 0.14526585223419325, 0.1502428658838783, 0.14439568535557815, 0.15557092641081127, 0.09475410410336085, 0.09473406696426016, 0.12930326163768768, 0.16939412323491915, 0.12838449808103697, 0.12108568687524114, 0.13824836164712906], [0.05231019162705966, 0.010457836158041443, 0.02181282453238964, 0.060042254227612696, 0.05193928063714078, 0.03500939426677568, 0.034739435716931305, 0.07998322456010751, 0.025254871529926146, 0.04133377829566598, 0.10389137201543365, 0.016896095326436416, 0.030578153473990302, 0.034873307283435545, 0.05701307712921074, 0.024214170141411678, 0.01702082872257701, 0.07191937869148594, 0.04771169534485255, 0.01871515780554286, 0.019801516119124632, 0.02765053271182946, 0.03909616997199399, 0.08764877037278243, 0.05494005425966211, 0.033303367240088325, 0.06161057257226535, 0.0707841149664351, 0.019084764311888387, 0.05194608973605292, 0.08961189431803566, 0.05195132463372179, 0.021874929146308984, 0.08982300013303757, 0.026464334755603756, 0.018399347251813327, 0.015906394326261113, 0.038817074948123524, 0.029636516501860957, 0.05569847320605602, 0.01834729513419526, 0.03185016575402447, 0.1107918628092323, 0.030795963214976445, 0.02380343932392342, 0.020813534136063287, 0.013598041941544839, 0.017702349295307482, 0.012210559964712177, 0.03183367056772113, 0.029513199547571794, 0.058411999206457815, 0.02050618830669139, 0.028479407341884713, 0.02899912784674338, 0.011983504335928177, 0.04746545159390994, 0.02450638124719262, 0.00964612846395799, 0.0712336783430406, 0.012910275453967708, 0.06333066562988929, 0.05625570991209575, 0.08083757478743792, 0.027764665694641213, 0.013244177447631955, 0.029259905817785432, 0.03853227683742132, 0.01762830755407257, 0.01292620406353048, 0.05261567148513027, 0.009049878538852292, 0.012106776337272354, 0.060065229423344135, 0.06332993281206914, 0.024730465740763714, 0.02704567981085607, 0.035994213207491806, 0.03601264900394848, 0.031888604762830904, 0.10693042179835693, 0.03676444205588528, 0.03153703880629369, 0.08742454169051987, 0.020260887719424706, 0.04253018481124725, 0.017571012057097893, 0.04393936973065138, 0.02366274848048176, 0.023990343491147672, 0.0694227023050189, 0.023363636673561165, 0.04707363494006651, 0.0215395886584052, 0.048739784463707886, 0.03614294469090445, 0.016845391797167913, 0.009706178813108375, 0.043038743415049145, 0.07566313458872692, 0.026745175310809697, 0.003746669356977301, 0.043443625260676653, 0.0768527082566704, 0.03958366345614195, 0.0681322847626039, 0.008702560211531818, 0.028436579907845174, 0.013565646983417017, 0.06690117796616894, 0.0531419364602438, 0.022669206972100904, 0.012340993055009415, 0.06208492961845227, 0.034643826740128655, 0.04259558540901967, 0.020239257719367743, 0.0674737733123558, 0.04792274348437786, 0.06393194943666458, 0.041414588423711915, 0.030315234724964415, 0.04154912156185933, 0.04269750476149576, 0.04417652450501919, 0.03781413572973438, 0.026783134256090437, 0.041797662153840065, 0.016611217487869517, 0.003293596045945638, 0.04263270127453974, 0.016505140412066664, 0.019260331855288575, 0.026953738315829208, 0.060126134726618014, 0.026007154823413918, 0.0121107313482623, 0.008020762287612473, 0.0504290143560086, 0.06793162838688918, 0.0476981144664543, 0.01935278734059206, 0.04130053686510239, 0.019185843977278898, 0.028617434935378175, 0.09059524083776133, 0.09520343677806002, 0.03772181086242199, 0.03196590347215533, 0.03427695981892092, 0.03901833861267992, 0.05962553194590977, 0.02583357029860573, 0.020047334089343036, 0.03641037230512925, 0.03829310002869793, 0.007058690809312144, 0.02649357622223241, 0.03186025896242686, 0.01592138146848551, 0.058409570051091056, 0.05411531190787043, 0.03331212712717908, 0.00432757251629872, 0.05339079935635839, 0.027829408113445555, 0.01607142761349678, 0.041166410847966156, 0.01955344371630677, 0.025271690716700893, 0.028188263232420598, 0.023512032282139574, 0.042988341833863936, 0.01669224474712142, 0.03860461884843452, 0.08602655599159853, 0.025584225642627904, 0.034898491110652685, 0.03720982565677591, 0.023474188687812005, 0.05863386658685548, 0.041055046288030486, 0.0427751461310046, 0.028592722689999, 0.05943436827510595, 0.02543083262363715, 0.05612101053286876, 0.032866302478526316, 0.029705859388091733, 0.013909285954598869, 0.03877665800973773, 0.0579634943444814, 0.041509657965174744, 0.08476043678820133, 0.09075224705572639, 0.035287369707865376, 0.03839364874043635, 0.04574976562123213, 0.04967483625348125, 0.0031253592252531753, 0.054728548108999214, 0.07289978715458087, 0.051071050976003916, 0.07540915214589664, 0.010135831427760422, 0.035658840489174636, 0.04675136134028435, 0.012237881177238055, 0.01789897008399878, 0.05021202903507011, 0.05026084962966187, 0.031113853478538137, 0.02236909093335271, 0.03479467525279947, 0.016996908666832105, 0.03196421731263399, 0.025723964840705906, 0.023060458745541315, 0.06404521050197737, 0.04974592297470995, 0.032280570694378445, 0.01264405732841364, 0.03843971787552748, 0.021564317867159843, 0.022105446151856865, 0.03605242472674165, 0.04794017844168203, 0.029203726510916437, 0.012361193890683353, 0.035359179068888934, 0.013041340430001063, 0.022566492037315453, 0.02156812614495201, 0.027099217920164977, 0.013932579213620296, 0.04398888921631234, 0.03327101129772408, 0.05507091313068356, 0.041757608231689246, 0.05552357741232429, 0.03570260260520237, 0.07558746436344725, 0.017141195745872598, 0.015435380761378577, 0.0365051331131586, 0.029915513138153722, 0.045193726529500315, 0.02903144307700651, 0.04378118286175387, 0.01782273837099118, 0.02028976277714329, 0.05831403232046536, 0.01784989164609994, 0.02260916001562561, 0.013555924424768558, 0.04942194285935589, 0.05605700771723475, 0.0051205776648462886, 0.032694605977407525, 0.04835411533713341, 0.022625490657186935, 0.03687887020143015, 0.08855265365647418, 0.029686232762677327, 0.03448901558294892, 0.07132699047880513, 0.021675300751147524, 0.045957370195537806, 0.040375082953167815, 0.033856756652572324, 0.03754412289708853, 0.031198955340577022, 0.05542123397546155, 0.040361495289419375, 0.08123346604406834, 0.023759787469836216, 0.08483198152056762, 0.03169875744996326, 0.021860366088471243, 0.061126621040914736, 0.017266103864780495, 0.05391320346721581, 0.04761283279263547, 0.07781000581703015, 0.021288184648645774, 0.05138826948989715, 0.03818117567737188, 0.04014534117387874, 0.01759639265947044, 0.026003329582246285, 0.0449646056097533, 0.008294793743906277, 0.009170621300914457, 0.01078123103694192, 0.02730939244585378, 0.04204609078754272, 0.023620954116008112, 0.058297326788306236, 0.011270091769152453, 0.060615847020276954, 0.03428318877039211, 0.01881201359044228, 0.04244104227317231, 0.021066934735115086, 0.026837238942139914, 0.0380345680085676, 0.02346307089153145, 0.012072385638020933, 0.038253653395388804, 0.030957919345902543, 0.05154061756495919, 0.031053440113152777, 0.035771144820111136, 0.08850597723254136, 0.03160186943465045, 0.04297179915010929, 0.013262290939954775, 0.01585280193415071, 0.08246076625904866, 0.011374905073483075, 0.021680488151365092, 0.03934396078277912, 0.08062051143497229, 0.04147474733846528, 0.04633151440482054, 0.004297848865722439, 0.03561118018946477, 0.03261727334133216, 0.05444815708324313, 0.018705224052869847, 0.04215938238693135, 0.030751217223171676, 0.05645276326686144, 0.00993133454384016, 0.020701033029971377, 0.013250077309619104, 0.030131450122488395, 0.06551569088229112, 0.051095359493047, 0.03222467637221728, 0.01853945625147649, 0.027502661271552955, 0.01667645523723747, 0.014084786492665964, 0.017058399206559573, 0.03278903769595282, 0.04222039964848331, 0.04340637029547777, 0.014852729526215365, 0.05078039710809078, 0.03628608165308833, 0.061251552908548286, 0.2225219224180494, 0.10142528398760728, 0.17877740758870328, 0.1427676220025335, 0.12048629618116788, 0.136747523610081, 0.16820363354470047, 0.15806779957243375, 0.10946630393820149, 0.12365092922534261, 0.16730526675071034, 0.11129607539623976, 0.12196744313197476, 0.13658000688467706, 0.1605590951762029, 0.1539839415677956, 0.1172344713870968, 0.3072590854551111, 0.21765670419803687, 0.1001615057300244, 0.11671204013483864, 0.1386446396687201, 0.13022627282355512, 0.14378271039043153, 0.1224466652742454, 0.1342278245304312, 0.19425518491438457, 0.11877824712012496, 0.09064431927566018, 0.14778249790625914, 0.3436094549085413, 0.09828037595642464, 0.09319153295031615, 0.1901348488671439, 0.1327840241470507, 0.08103375961737973, 0.0592392555304936, 0.12446631118655205, 0.12172507042331354, 0.1330645712358611, 0.1095166037391339, 0.14253233319946698, 0.1571446391088622, 0.15610529987939767, 0.18975311863635266, 0.16258085811776773, 0.11857617939157145, 0.08971023439828839, 0.10036094752805573, 0.09282799424337489, 0.1542712604360921, 0.12416728080383369, 0.1009720836633018, 0.05575396040720599, 0.07850201654114894, 0.10120089924229042, 0.2957387550600937, 0.16121308079787663, 0.06296255359692232, 0.13455205570374215, 0.1375719029456377, 0.2175111584365368, 0.1380507315375975, 0.14389082816030296, 0.10987096865262304, 0.1338039165628808, 0.17638730869761535, 0.13407115079462528, 0.08536025495933634, 0.10514229203441314, 0.09215245156415872, 0.08460162566708666, 0.17968754017991678, 0.124794762847679, 0.1386646293103695, 0.08751010495637145, 0.13110793408538612, 0.1361100806721619, 0.16762419178017549, 0.08817639241793326, 0.2165382613560983, 0.1562650270227875, 0.1282196140715054, 0.19854469331247465, 0.1447557567485741, 0.08881526706474167, 0.16848914750984736, 0.10483075625130109, 0.10711558043424572, 0.13573181096996578, 0.18032308321978363, 0.1473489004586424, 0.19439481385052204, 0.11408863376293864, 0.14190350765628473, 0.07548285461962223, 0.15758337985192025, 0.12457916513085365, 0.09462858869561128, 0.17801539919206075, 0.18466851647411073, 0.06586367756660495, 0.10265511513820716, 0.3296662930931364, 0.13326479334916386, 0.2474249175616673, 0.2078034257782357, 0.14578704855271749, 0.0862557515501976, 0.15130283257790975, 0.14196757493274553, 0.11350957876337425, 0.1191063052309411, 0.1924924866429397, 0.12572820990213326, 0.2614087371953896, 0.14923524138118538, 0.08514231629669666, 0.09476629737764597, 0.08706157973834447, 0.11227545927145652, 0.10565947821097714, 0.06299535397972379, 0.14232767346714223, 0.203777691083295, 0.10818984386112009, 0.11769014836422034, 0.18305030544953688, 0.10953322784709078, 0.12246020883321762, 0.09438274188765458, 0.08109292108565569, 0.10963549664510147, 0.15486298368445464, 0.11797583874847208, 0.1074280525956835, 0.09349129615085465, 0.21016711608639785, 0.08244300899761063, 0.1292199646787984, 0.11704444086977414, 0.07695064800126211, 0.24920580057161196, 0.13513711573822157, 0.1607038809784821, 0.15348920811499867, 0.23011559780154908, 0.12982801347970963, 0.14794339212988103, 0.12115203402936459, 0.1794750772948776, 0.1285422167607716, 0.08891338322843824, 0.09308455511927605, 0.14801201916166715, 0.1226786021143198, 0.1279305038707597, 0.11368103099188634, 0.07244930775570017, 0.08189841000629322, 0.11997622783694949, 0.09659642845924411, 0.10274400322565011, 0.09383280961109058, 0.11566303856670856, 0.13869650688554558, 0.0740823515557817, 0.11009124826107707, 0.23598080021994455, 0.08016595404062953, 0.13196980926607335, 0.08190637600741216, 0.143008949767266, 0.19046089851430484, 0.0806855625872101, 0.19081791649971688], [0.02694497164338827, 0.027148886683530042, 0.029712858476809094, 0.05234500386619142, 0.04245375801942178, 0.04468330195439713, 0.0457989831588098, 0.01537484017067722, 0.05099155720589416, 0.0686785868768181, 0.023692436083885174, 0.026308439638731734, 0.008040883395421718, 0.009159180352331271, 0.07646683896226542, 0.03220564346494419, 0.028639880873795067, 0.022243975861264125, 0.04773774091154337, 0.0525973849663777, 0.04410784997578178, 0.052841779709394486, 0.031448815683169026, 0.04112064366095832, 0.03426161135679909, 0.07271872687020473, 0.0339369425284011, 0.031078525552792207, 0.036056923413915296, 0.038258935790508986, 0.03516323851155383, 0.05170259065926075, 0.06483961894576039, 0.040754024405032396, 0.030720459230776345, 0.016362061125359366, 0.03684638533741236, 0.08800666366836854, 0.03580994005980236, 0.06815135159662791, 0.03318095273737397, 0.07904504133122307, 0.010499754355155995, 0.03750468983447977, 0.08723628214959588, 0.05299834148692233, 0.03425100924713271, 0.013785928288208587, 0.053386806177773645, 0.0348435128107667, 0.0635503956249782, 0.06782934601817812, 0.027632180035912564, 0.05651883900697742, 0.0180638523971928, 0.011183726135641336, 0.042200521965112, 0.02945341043440359, 0.0037976515096878366, 0.020081408421642015, 0.0391582152140992, 0.018333295260422995, 0.04945882123761943, 0.010114237050791937, 0.06450956594198942, 0.10115249933941023, 0.032790333697838445, 0.01901147574452417, 0.025897413658510362, 0.07484440744987556, 0.0659668148894395, 0.048984331877103875, 0.033982207599495134, 0.04064167596931968, 0.025928090226703455, 0.12498420982488564, 0.015591180883347988, 0.02031793724745512, 0.03048757922702602, 0.037467132921197584, 0.04343813930505088, 0.019297125416674783, 0.047024295266185484, 0.035045414298240624, 0.012089386332913168, 0.039624585903116634, 0.11018675885030202, 0.060310764105192254, 0.06932157344583954, 0.017038372245484164, 0.08836668077856302, 0.03469106974080205, 0.01605586371650653, 0.048555982897856405, 0.10479373538068362, 0.037317098650549135, 0.019821376839120473, 0.03675207236249532, 0.033113435110343356, 0.014412519754841924, 0.06293153097586972, 0.07159000422273364, 0.095191101011421, 0.040947495094899616, 0.04890325712040067, 0.020387795820300068, 0.08622843373034682, 0.003614081917995853, 0.02641429110164089, 0.013616499790389622, 0.013267855775276465, 0.023887883006994213, 0.06171423236706427, 0.013504195459453123, 0.08723979017564229, 0.028413896482171755, 0.025200777021901946, 0.12321723678282329, 0.0491955225089831, 0.051654014337275705, 0.03713814861008099, 0.04903501844299691, 0.01111492607742548, 0.052182749179857116, 0.04369419467236314, 0.048740849763687165, 0.1439288125506469, 0.05137330779273595, 0.05437876669956105, 0.03351486999807613, 0.038669171277433634, 0.04393785999023488, 0.029392579769981757, 0.029421047706689154, 0.013252595522707062, 0.04893325176090002, 0.028472951081182276, 0.028032936388626695, 0.038295468115913014, 0.058730910665222576, 0.02827813519564058, 0.02150023871633623, 0.010042604108873223, 0.09152729011007718, 0.031173354214323417, 0.022507534129545093, 0.017850471793540885, 0.0647278099453875, 0.025747257251558558, 0.07189755700528622, 0.04538316332868167, 0.011065890047965305, 0.041941413190215826, 0.04846146296975868, 0.03728267317637801, 0.03949345222541264, 0.04739481270579355, 0.12446952744254045, 0.04087385029665061, 0.0327587275366698, 0.047992157616785595, 0.034541741146573, 0.061921545171311924, 0.03177824443472283, 0.05655995822910752, 0.024456770159304142, 0.04660697926634124, 0.0567709215517555, 0.030729799265308038, 0.01923375703128321, 0.04956199587988002, 0.04913373850286007, 0.019170529441908002, 0.04106294443564756, 0.08896934879677636, 0.032354388519057205, 0.028760473509984355, 0.04083925179604973, 0.018320090968960097, 0.01327377260063908, 0.04052289162895509, 0.03265968856534787, 0.03397123908091869, 0.024496469546907713, 0.05855394873235907, 0.08189812502158539, 0.02129395049996674, 0.016312991169148257, 0.05359814948003207, 0.043699717947414944, 0.08614426146128348, 0.04155792894640139, 0.025736461759411862, 0.03977893226380859, 0.019867591859240617, 0.029740525742194483, 0.04153019722018923, 0.032533423376402686, 0.027227783342823386, 0.05623791872390679, 0.052516642691833634, 0.05148768504815442, 0.030278810965163366, 0.026482297273884927, 0.06539895571768284, 0.030834911125046865, 0.01108018253996436, 0.01515847910195589, 0.0177587440370449, 0.023124427634424398, 0.03455327624189002, 0.01852915100088077, 0.04070210290540542, 0.05259776494598814, 0.026231061201542616, 0.054292273840733936, 0.023402241923447167, 0.029748983681201935, 0.017647386262459413, 0.015633711458316872, 0.0372605902541961, 0.06403677631169558, 0.028937601683927432, 0.025856275776667253, 0.05770271298076425, 0.01956765223959727, 0.012384584689113711, 0.07516226039401122, 0.055280461707817655, 0.013950897962786257, 0.016145194548049142, 0.034563284633415084, 0.026645428966730833, 0.040085317966129096, 0.03819305343287332, 0.0416308205707797, 0.04586361361933606, 0.04769484732033951, 0.009226663204442178, 0.05238530884629913, 0.04206976487434336, 0.018059080599674156, 0.021764355079670037, 0.020761107127847414, 0.02682209912953632, 0.04276008265359061, 0.03851256539512958, 0.04362479071798069, 0.059260337613523006, 0.05305160987856133, 0.06236021127551794, 0.04230005965967264, 0.09087185242346354, 0.013410136086999305, 0.02853065709184323, 0.058723616413772106, 0.02921440665210996, 0.025783484236204197, 0.04153341347617762, 0.0452481518233461, 0.012187874842701214, 0.030160026624798775, 0.03845619270578027, 0.02038876442903919, 0.0338703239602702, 0.06836185351546321, 0.04741913140086191, 0.027897717930110436, 0.053382524621805975, 0.10108158564461128, 0.05970198927181108, 0.037314740741359334, 0.030389432529253618, 0.06889921932348184, 0.014288427574293954, 0.052721299031483274, 0.05286034442750471, 0.035949874336698225, 0.03879180630402906, 0.06979662259774548, 0.019546558282205036, 0.06130480433681181, 0.07696100923099689, 0.025024931279144118, 0.04489750528175916, 0.044662783055433204, 0.013545168796554208, 0.014833815362570541, 0.045614849110799174, 0.036217227312070985, 0.05173751824934568, 0.1227293565337147, 0.012933561927638948, 0.07857472835374729, 0.026893172280064652, 0.06623898885611977, 0.043737169687769244, 0.033910228604716916, 0.04278558199959142, 0.015723434143832753, 0.03885853343776294, 0.049554447177797556, 0.023777541338599155, 0.01253781994871263, 0.08897265326231718, 0.0911073312163353, 0.024074186670726964, 0.03175491300810661, 0.02214820233971945, 0.05308121096874986, 0.03441060068351882, 0.025593565677159598, 0.023528546128155928, 0.025342107384598682, 0.025642976597217575, 0.05907585072730269, 0.06090896736298289, 0.022432031841682534, 0.07196130537028823, 0.05678772207881723, 0.03336737005572234, 0.039588331777070246, 0.06094618500875575, 0.039296985803438086, 0.04073599572958691, 0.042591405633304796, 0.02933867694810033, 0.023624065199068615, 0.021420353092253208, 0.010459779312701097, 0.03682297248659389, 0.08195805323443242, 0.026619627672646726, 0.007530685281381011, 0.027272249438932965, 0.007725881146533149, 0.010310019848735204, 0.03405049875644701, 0.027349984107006873, 0.04862685927322932, 0.024710630465831076, 0.02994703108976994, 0.04239198419132403, 0.04970427788794041, 0.04340772736551506, 0.03743983545739736, 0.03489417902060917, 0.02893489772187812, 0.02297644253953227, 0.010074336647189088, 0.042830806358584335, 0.07303597591817379, 0.12078048182385308, 0.11006152164191008, 0.0722373402012246, 0.12187124043703079, 0.18522513232060842, 0.2574193041239466, 0.19020566078169004, 0.10176862949239356, 0.10313228131937129, 0.13984015051807674, 0.0867987966963223, 0.12079045628862721, 0.1580731871404818, 0.10989676655403205, 0.30672931245395113, 0.1241518102054085, 0.17458798310586385, 0.10753782599100045, 0.0875616871884891, 0.19277709137116159, 0.17756752536765166, 0.09028468893042632, 0.07629531209490129, 0.15140896902552672, 0.1884629792932953, 0.10430094253804002, 0.14928391948342323, 0.12515977397561073, 0.1415540078388793, 0.10740569486681904, 0.08738739189824887, 0.15598325857094356, 0.1538096937750067, 0.0943021047860384, 0.15202676158930573, 0.05088856237541352, 0.14215102366038732, 0.12215528876653739, 0.09461298239018236, 0.19923146574624948, 0.12172141990491323, 0.12460429806794439, 0.13594242823975428, 0.1665041475955929, 0.11783255929393427, 0.13084250475679124, 0.13807517236896924, 0.13148494171244757, 0.12356166115828923, 0.15056869839983328, 0.11929572506674699, 0.1536288641925369, 0.09429319562124354, 0.07866635093731539, 0.08948098455688783, 0.11569008497255188, 0.1219828865889992, 0.08647211601159402, 0.06929690191256148, 0.1360606833228043, 0.08970592570091997, 0.15364242132220948, 0.09112815545605761, 0.08815047238022089, 0.12088988881025996, 0.2068140810089452, 0.08687598005469356, 0.08942871700440135, 0.14845092275312968, 0.16783616612000124, 0.16302960046700068, 0.13250321921493324, 0.15989457869103976, 0.23609644972852298, 0.13759451173245907, 0.20061166025698185, 0.17155079250889166, 0.10785932266818625, 0.11423808788614613, 0.1536391507834196, 0.09898337894784552, 0.11072856906269278, 0.12328103264527661, 0.16728291580719606, 0.09216611725943429, 0.10014651010611228, 0.25322318928582327, 0.09010731309120144, 0.15158285040940556, 0.11953503079712391, 0.1330636619989361, 0.0963852751467909, 0.10655927671385662, 0.1953413566308362, 0.19006227276154927, 0.1163474904107196, 0.1311132266585316, 0.09286543580570392, 0.061627033831817765, 0.13489390164613724, 0.15791286288627557, 0.19185891135462693, 0.260203767567873, 0.14053730453763688, 0.09539122812982116, 0.12276256403752736, 0.15220809328768933, 0.14225177253995622, 0.13538636879197188, 0.08194776664354972, 0.20952310492949827, 0.07504391031605856, 0.20838624664715358, 0.1026640310883522, 0.19506652280688286, 0.1660186286483492, 0.12560098458613667, 0.20611703555498803, 0.19569256635648863, 0.11729068122804165, 0.14593359854604515, 0.10337238093572003, 0.12392163755638258, 0.06807842265282359, 0.08462168316223792, 0.15864935836621694, 0.23462923988699913, 0.2071463731782777, 0.21256070264748164, 0.10794135755194084, 0.17350945169372217, 0.13827371171542577, 0.18046069012156554, 0.12774377103362763, 0.09855285526386329, 0.15454038099518844, 0.09578092436173133, 0.13111329451203346, 0.10942353587597609, 0.18242377335471766, 0.20144130502428326, 0.14109507389366627, 0.16634218128664152, 0.1496716479637793, 0.13536992110311985, 0.09880959934421948, 0.16868672333657742, 0.10762803043637957, 0.12238422648182937, 0.17623349837958813, 0.09989100095949002, 0.0928836137588535, 0.09574657013373715, 0.11289091088942119, 0.05854643734970263, 0.1747154662651675, 0.17110096450362886, 0.19388281846685068, 0.07109822239726782, 0.0954484422025936, 0.1094982290108289, 0.07761134433427028, 0.1566780512886388, 0.1314020925866706, 0.13484039237456663, 0.12101784694407668, 0.11199033207127027, 0.13258787324385984, 0.12925949612898485, 0.140111523813435, 0.20059263413505896, 0.23027372360229492, 0.09775480987238032, 0.18038618697651795, 0.25154199664081844, 0.16185601986944675], [0.0434328603026058, 0.028186912947733487, 0.05218230134674481, 0.06695751672876732, 0.013160758352439319, 0.05216330236622265, 0.034958358255348036, 0.005703021522744426, 0.09900682233273983, 0.03631178455959473, 0.11062085162848234, 0.03789240474413548, 0.03644340678251215, 0.013088256885696734, 0.02864367388454931, 0.03318962441491229, 0.036221905811024566, 0.03247218559096966, 0.06541072830025639, 0.006927370534478021, 0.022264744121847407, 0.011763201826917273, 0.043447238459650955, 0.009480284327375037, 0.011941368159438883, 0.03942827893687146, 0.04271813561873777, 0.07456758551831756, 0.04091490166527884, 0.0678488335439137, 0.015556575597396918, 0.049978097302040884, 0.10875693628830568, 0.051659944733338695, 0.024884488100984266, 0.01984421123883554, 0.07467969985944883, 0.014231149040694748, 0.025799368740990758, 0.04148333759180137, 0.019210719071062546, 0.023926466204492108, 0.018898111202621033, 0.03704950140256967, 0.01889237079636327, 0.01258541239492063, 0.015206141098003303, 0.037725678512028286, 0.0622923034908516, 0.03186309863147991, 0.08402197355670588, 0.01624366863896804, 0.047097614367625544, 0.007181101495267025, 0.025596033848289932, 0.053362914959767034, 0.03670847648754716, 0.06887808295765094, 0.03843436762690544, 0.06447391571210963, 0.050441170310867686, 0.03869526773425085, 0.05050564131566456, 0.05522293211626155, 0.04626882116177252, 0.02836600039154291, 0.03744134519781385, 0.050489621103874276, 0.009159903840294905, 0.05970861177359309, 0.043474926081086905, 0.029836195787148814, 0.0487676892163498, 0.04382078895079238, 0.009089498198591173, 0.009848588046484759, 0.02713286647173975, 0.02724129976039486, 0.08448449695216757, 0.04348107700103095, 0.04754265191565667, 0.0413534456331815, 0.1052884009799787, 0.04251719765099032, 0.04225427211661424, 0.0272124399697142, 0.02442222085249211, 0.022277086673836623, 0.036230207686977725, 0.048272772559097836, 0.036498720957232375, 0.05496902431228331, 0.02363025343843869, 0.031437246661101065, 0.04990665434992739, 0.004619539773557335, 0.03322680813393422, 0.04552197463012167, 0.049133110857967816, 0.048065853305161, 0.05289226271478193, 0.018940492499885813, 0.043817111290991306, 0.014107517415790685, 0.01491555169091693, 0.0527608949424965, 0.0241554225794971, 0.01716595548870308, 0.05704330586429153, 0.040776395704597235, 0.05934220964887312, 0.01403647564750697, 0.030828756812427725, 0.02971651578055961, 0.03032053747613515, 0.04240346500383956, 0.028072209995506064, 0.014039101578029138, 0.08557274498577629, 0.031526263670197556, 0.02627369525310184, 0.04355635367599981, 0.05168224139405148, 0.014608129526355436, 0.006966103857848793, 0.03608860421393599, 0.06505468740527119, 0.0272173593485994, 0.01853728324307927, 0.0802350424762283, 0.025224871800414154, 0.03896519914269447, 0.024083774370540465, 0.05991396361163684, 0.02212450959320579, 0.01878362538159958, 0.05350036919116974, 0.030532284506729672, 0.020815172798133323, 0.0547363885811397, 0.057279123924672604, 0.028121749837217585, 0.0454862158346389, 0.0331006074058158, 0.04496189146967871, 0.0468898435522403, 0.010120937584101089, 0.07018735698823418, 0.002945551262070824, 0.03589423446516905, 0.052374577814979215, 0.05803331559790032, 0.05541941550161157, 0.03792774624058178, 0.016352179959150295, 0.0393988881925387, 0.06894169561564922, 0.06385275082928793, 0.035676428116858006, 0.07396152482501098, 0.015715395200199316, 0.066015262289771, 0.04676661480750356, 0.009002537998769964, 0.025225619885272214, 0.02111213534538235, 0.0163613164331764, 0.04460352659225464, 0.0201712294947356, 0.03394931222179106, 0.0082623750370528, 0.044300346967897246, 0.04421081766486168, 0.07270250309790884, 0.047390504008425136, 0.035723738971033266, 0.01740777349498655, 0.05392979704109686, 0.012803536806521671, 0.025892808102071285, 0.012834287165398044, 0.049652414063790014, 0.0482771050051919, 0.017632850346022418, 0.03211894365293639, 0.0460634014702269, 0.028789083939045668, 0.030148759550814117, 0.03544099682143756, 0.029698348005435297, 0.037927997298538685, 0.08370177288140569, 0.013416135184732931, 0.026017487215410386, 0.020447951342378343, 0.006316393006792558, 0.016891795110755732, 0.021817039931192994, 0.023475403265495385, 0.031715941349310536, 0.019496080365830233, 0.0541148742527834, 0.019287700565265756, 0.027519030928877846, 0.04505746651973043, 0.08903703266488654, 0.03560115483456424, 0.03847763441236956, 0.021465935378468463, 0.018851365228848796, 0.008223184550713216, 0.017023149312340786, 0.019729011259706955, 0.056730297660189014, 0.023269240578104342, 0.028511909169277976, 0.016410671374095336, 0.053228259685316255, 0.02124108244398875, 0.07506308571568557, 0.038808969847325764, 0.02684306925428765, 0.017889923515862653, 0.04462399460109217, 0.04764505981334618, 0.07289072192673172, 0.03841634573681014, 0.032423887468342266, 0.01492976869589516, 0.03367955723245229, 0.05644157761707902, 0.05006622203758784, 0.006547276845334896, 0.05963812555585589, 0.12226257872368608, 0.043891787462468655, 0.05445447763694184, 0.035321822323437245, 0.01797269800278757, 0.005050066002045891, 0.019327371115131036, 0.02988701466737049, 0.03445179793717606, 0.06083046764667545, 0.054299439170530865, 0.009364581384163882, 0.03147766359948686, 0.01641672390646168, 0.011159745859913528, 0.005269307876005769, 0.047661161449338706, 0.030318566331905977, 0.013213404188198703, 0.0063075122556516105, 0.06820735787706715, 0.0877780584352357, 0.0338653536912586, 0.04426605041537966, 0.1003592579758593, 0.018463704601994584, 0.030414626534496034, 0.010394712893425353, 0.022309491809989725, 0.026438675953873565, 0.0420786808244884, 0.05265119618603161, 0.023306068066241484, 0.04354578549308436, 0.06571496304656778, 0.03305703867226839, 0.08386441772537571, 0.0283529776081975, 0.05595929528187428, 0.0017457225975314422, 0.03365024791232177, 0.048815305411283455, 0.06686804510120835, 0.027332959663388983, 0.03879234573936888, 0.012249989634645837, 0.04110298139442291, 0.021255562381286706, 0.04595067644757884, 0.011527667054906487, 0.04878456438226359, 0.042508756675358327, 0.07044463032590491, 0.017450134436200773, 0.049405118583568504, 0.02090518386103213, 0.022649103675835898, 0.03768679167010954, 0.01686267917310553, 0.04375463517914925, 0.0627631592963423, 0.0222246868070215, 0.05328629817813635, 0.014966055052354932, 0.054439088462718895, 0.06656054660145726, 0.026377789310312698, 0.0568081188414778, 0.06192757056227752, 0.05425131407433322, 0.005323383300232568, 0.04530853804733072, 0.025718850383002843, 0.007199224317446351, 0.01202574314083904, 0.010924501161623214, 0.04666837311482855, 0.03813674859702587, 0.031862060472901375, 0.017809517116152813, 0.02434595860540867, 0.044246634135821035, 0.07689645340932266, 0.08136995336306946, 0.020687072171962688, 0.01505270567057388, 0.055792097467929125, 0.020884174720517228, 0.016635161292340075, 0.006066703994292766, 0.03500473612387266, 0.025548122490623167, 0.008810130064375699, 0.00903417045317058, 0.036709087169063945, 0.03213923524266907, 0.03896822540887764, 0.01939897352297391, 0.039882076371993334, 0.04178543495280402, 0.07478509670389549, 0.035631923004984856, 0.018853068351745605, 0.041727528774312565, 0.017837847649518932, 0.03656353801488876, 0.03007457870990038, 0.015370443263756377, 0.01615521651027458, 0.06134654102580888, 0.019831008643710187, 0.04861043533310294, 0.02940831838973931, 0.05317249767748373, 0.01383593462274543, 0.01001752884725907, 0.019834209632660662, 0.007532499514387122, 0.10669771142836128, 0.13155709712633065, 0.10181026440113783, 0.18744068486349924, 0.12989887967705727, 0.11322992055543832, 0.16563064232468605, 0.06600300116198403, 0.2034096944012812, 0.15060559713414737, 0.18671884573996067, 0.12986987909036024, 0.07552118506282568, 0.09277846118701355, 0.09215494857302733, 0.2180279849895409, 0.15085936923112186, 0.0635439156155501, 0.1028350219130516, 0.0533558005200965, 0.06983258495373385, 0.14991942181118897, 0.15022073207157, 0.24940300998943193, 0.04870895861781069, 0.18282948301306792, 0.117750063006367, 0.10946911307317869, 0.15436861664056778, 0.15036493433373316, 0.11319742551339523, 0.1079938490209835, 0.14459560891347273, 0.10028702792312418, 0.11904829048684665, 0.07654939631798438, 0.16802356392145157, 0.11566065012344293, 0.11046805911298309, 0.10964309623731033, 0.12429149342434746, 0.16735467767076834, 0.12330695268298898, 0.1951850764453411, 0.12201283712472234, 0.12068977526256017, 0.0791323348613722, 0.10351112099098307, 0.17422428833586828, 0.10154466543878828, 0.20027057427380765, 0.09434385504573584, 0.18650985695421696, 0.10282871153737817, 0.14308513567915984, 0.1952157597988844, 0.1882369185664824, 0.13125768676400185, 0.2692536876669952, 0.11574185719447476, 0.12297574616968632, 0.09519363873239074, 0.09689106872039181, 0.20407043823174068, 0.08310029229947499, 0.13249959583793366, 0.1772820521146059, 0.14250454040510313, 0.137731792937432, 0.19033838223133767, 0.1282108881111656, 0.13645673064248903, 0.09963444008358888, 0.12203270463006836, 0.16133958686675343, 0.08673409838229418, 0.08606682704495532, 0.11239408754876681, 0.27590153951730045, 0.23644562384911946, 0.14289826713502407, 0.2318095469049045, 0.20363057112055166, 0.12476116179355554, 0.13159831134336336, 0.08611905388534069, 0.1533957738429308, 0.08657506334462337, 0.11095268917935235, 0.0955064230199371, 0.16864469487752232, 0.11570087367934839, 0.11351761261799506, 0.11831608334822313, 0.1948556476937873, 0.1476046945899725, 0.0856623048228877, 0.0585249142189111, 0.1234280304717166, 0.135832207011325, 0.22701382424150193, 0.09085423765437943, 0.08206703274377755, 0.2664520979991981, 0.10799091096435275, 0.19282810363386357, 0.06511980641101088, 0.13259929977357388, 0.12510056500988348, 0.1221680316541876, 0.16169937327504158, 0.15596542667065347, 0.09291127084621362, 0.09885478977646146, 0.07125976122915745, 0.11133790708013944, 0.15996756191764558, 0.12038780003786087, 0.23635942276035035, 0.11783141935510294, 0.13916450605860778, 0.12774064977254185, 0.10178555215575866, 0.22727877859558376, 0.10834325384348631, 0.14341148388172897, 0.21391313150525093, 0.16079396328755788, 0.11066140766654696, 0.15569555972303661, 0.09542564342596702, 0.09828199086976902, 0.11356926948896476, 0.16775893526417868, 0.12032086934362139, 0.06925074796059302, 0.17092303905103887, 0.062334650861365457, 0.09088677340852362, 0.12488502157585961, 0.19787430071405002, 0.10975981104586806, 0.12638668742563042, 0.10762024763971567, 0.137395334563085, 0.0813378586566874, 0.09918466636112758, 0.13957620039582253, 0.0756373434726681, 0.16404266682054314, 0.0657037061506084, 0.11293236937906061, 0.1541684488100665, 0.16570505047483103, 0.14512724110058375, 0.07666326806481395, 0.14480306421007427, 0.12894081537212643, 0.15441185289195605, 0.12102943632219519, 0.09860594384372234, 0.19846531828599318, 0.08216172230562993, 0.07415416091680527, 0.11762921591954571, 0.1378665499921356, 0.07769872607397181, 0.09787794362221446, 0.17459712975791522, 0.08767627818243844, 0.1262855449957507, 0.15472697812531674, 0.10471561564398663, 0.12645633225994451, 0.11432707096849169, 0.07357974031141826], [0.04159327383552279, 0.02645448242713298, 0.016585981074188436, 0.042807512251394134, 0.026971118990331888, 0.016780639200338295, 0.042326190043240786, 0.023973125665049468, 0.024511985946446657, 0.02258576582452016, 0.01637024256134672, 0.037200495800269504, 0.005940320485803697, 0.032142397215855975, 0.021017915669030378, 0.007319348764472774, 0.09915778958903891, 0.03084615445030587, 0.028550178544329743, 0.049202389283371825, 0.02355906493695719, 0.0226984026376158, 0.02196439907753042, 0.00907358994507896, 0.031018254679760764, 0.02666619892365166, 0.028141702159440944, 0.022138209215232303, 0.08224704808422498, 0.04237473922382508, 0.0160005817721997, 0.038416115034903796, 0.037463221166815074, 0.020696245965414813, 0.019627658483971442, 0.019452633768586174, 0.03513023117557168, 0.009603312904281276, 0.015233899965616209, 0.041317995571132214, 0.017510278083916222, 0.05541797361469694, 0.027431934173884134, 0.0617418826690742, 0.032221789205712933, 0.03321344099406685, 0.034930311010352204, 0.018085682565080266, 0.03507820111034172, 0.02961143784757171, 0.008265358894797308, 0.02827655420904713, 0.03507274229611669, 0.018043302964153032, 0.02359509005743478, 0.036274437992168326, 0.028016578605664626, 0.030703431394483362, 0.04537994368001819, 0.0475565415274884, 0.04675735280449901, 0.04724879196978041, 0.03302027903763311, 0.04069518863356539, 0.021134062204509974, 0.027335629698687365, 0.0762631698910679, 0.012026937362471861, 0.05344623906005706, 0.02357596724427172, 0.03457084012084773, 0.02298669859633914, 0.06840524582990579, 0.00610422231589577, 0.030026416294276714, 0.057062101284308095, 0.0254583930197571, 0.026265907367425304, 0.028183449026463286, 0.014126853967484618, 0.037094742724938054, 0.027432359954608337, 0.018337458072762405, 0.009408614066030298, 0.022519678210041354, 0.07390862623495714, 0.02800137093955917, 0.024007927726155946, 0.035854876041412354, 0.030651564177657877, 0.04182870513094323, 0.02029902478014784, 0.04499268338882497, 0.07077785208821297, 0.05009387573227286, 0.0025317967229057103, 0.07605205729071583, 0.03774740520332541, 0.04023184081805604, 0.02261416081871305, 0.037342034812484465, 0.004771496418730489, 0.025164577178657055, 0.010409599103565727, 0.020857070639197315, 0.02955590993432062, 0.04387694450893572, 0.02470324291581554, 0.023317859308528047, 0.0425039526474263, 0.033855691352593045, 0.043331612699798176, 0.02519981689485056, 0.008936721798298615, 0.011933620985863464, 0.03001695412344166, 0.03846472867631486, 0.01403542052555297, 0.027676535870081613, 0.008963225376127022, 0.03571574243583849, 0.03513944228844983, 0.011412134593618768, 0.03287919464388064, 0.03845169062593153, 0.01184227320897792, 0.013214960577897727, 0.027785946249163578, 0.007351892152135926, 0.021900962838636975, 0.04828993610239454, 0.015766505850479007, 0.05079435118074928, 0.0462942865810224, 0.02570534075078155, 0.04810580883973411, 0.009568203806078859, 0.047570034196334224, 0.04175218673689025, 0.05274484419663038, 0.02724784762332482, 0.03611105354502797, 0.044126044892306836, 0.026361519736903052, 0.02184722456149757, 0.004714271319764001, 0.01579664637600737, 0.009947196996238614, 0.10787279158830643, 0.018251786241307855, 0.021579006453976035, 0.04097344566668783, 0.016198629180767705, 0.011097482638433576, 0.00812146027705499, 0.03122064471244812, 0.03340204658785036, 0.027119058284110258, 0.01798124924036009, 0.05300565270174827, 0.03689582339887108, 0.03532831929624081, 0.0013880265011851276, 0.022968317082683955, 0.01710319608849074, 0.0403569660681699, 0.03415427729487419, 0.03294880555144378, 0.03502037296337741, 0.028148448493863856, 0.05354509821959904, 0.021121750186596597, 0.048829469829797745, 0.019752386791099395, 0.051943457020180564, 0.02586888295731374, 0.02299910391281758, 0.03677129525957363, 0.011471335077658296, 0.0449332810406174, 0.0471253494865128, 0.021055041712575724, 0.056836281437426805, 0.019979590849418725, 0.058825905567833355, 0.013101443365615393, 0.016485405221049274, 0.03235430709485497, 0.03755877925349133, 0.05104739724525383, 0.024488617200404406, 0.04851010714524558, 0.0230167407342898, 0.035761563905647824, 0.01457019941881299, 0.06766486234430756, 0.03457960340061358, 0.020527914997988513, 0.013411724707111716, 0.0489067040782954, 0.020519460451656153, 0.04014152780707393, 0.04175335381712232, 0.017023466527462006, 0.07874179724603891, 0.01981644897854754, 0.022710434759833982, 0.01684603470909808, 0.011241196355383311, 0.030004652283553566, 0.04700750830982413, 0.011147925779888672, 0.11610435774283749, 0.033255964783685546, 0.02183514494182808, 0.021497668764953102, 0.04295430651732853, 0.017284548142924905, 0.014816711191087961, 0.01640481222420931, 0.02234060942594494, 0.025419704649331312, 0.06315263839704649, 0.018274791971115128, 0.028442632440211515, 0.03264909663370677, 0.024942082153367143, 0.041885305129523785, 0.04248908594516771, 0.032363463924931626, 0.013241334385903818, 0.017005193579409803, 0.04812879082081573, 0.02524357901087829, 0.028081044521448866, 0.09983025850462061, 0.035911764417375834, 0.011849614109710922, 0.0358733288012445, 0.08982151414134673, 0.04655711372782077, 0.05510102990748627, 0.02388863787720246, 0.0249660259578377, 0.056949891948274205, 0.015561211687911834, 0.05359646671318582, 0.029780956251280646, 0.07583107200584241, 0.06246300933084317, 0.08270425176514046, 0.026992760864751678, 0.037038448067115884, 0.04155155750257628, 0.08732641195612294, 0.02515490466196622, 0.04291855111452086, 0.02899851037987641, 0.05942236499062606, 0.016657203502420868, 0.06031943578273058, 0.08014464125569377, 0.014175132582230228, 0.04803381288158042, 0.012596159541447247, 0.007313500640780798, 0.02020685767222728, 0.036250729978616746, 0.020035212061234882, 0.011623695027083158, 0.03049087690721665, 0.031027465792638913, 0.025576999244679297, 0.03450071352667042, 0.00497397593322343, 0.07211791125259229, 0.02718486769923142, 0.025860833835655024, 0.00801175388707114, 0.026065515620367866, 0.028819858894816468, 0.011164423510698336, 0.02089733660354146, 0.017312005062454512, 0.03320325279076185, 0.0075239007793633, 0.019409850439322845, 0.03253072280702846, 0.032701995223760605, 0.03250260431585567, 0.02631702649939273, 0.0035509995775230762, 0.027718672894739678, 0.037269173722182, 0.044899154121854475, 0.028765589664024965, 0.038022113498300314, 0.053609257098287344, 0.04471104046595948, 0.03740202748615827, 0.01387213361782155, 0.02297987592672663, 0.057097642948584895, 0.04348749594230737, 0.03276463418400713, 0.024453752374808704, 0.022242476298872913, 0.030133448408118317, 0.021327247909669365, 0.014065543239537095, 0.0574813952137317, 0.01099368544029338, 0.05472188489511609, 0.012330153458086508, 0.017368026609931673, 0.021772660348298292, 0.024894959592659558, 0.028413465612434914, 0.023407480213791132, 0.04376033826598099, 0.02752019970544747, 0.07780105594013419, 0.019572228958298053, 0.04036869454596724, 0.07029571224536214, 0.018314479484355876, 0.03539170464500785, 0.05091227038896509, 0.021060648108167306, 0.01648538147232362, 0.05237037429053869, 0.029273629188537598, 0.022211709824789847, 0.03311147075146437, 0.0102948232088238, 0.04474153043702245, 0.026330849954060147, 0.03919407578983477, 0.033283503127417395, 0.002054049334089671, 0.02031221380457282, 0.07933373084025723, 0.018791063821741512, 0.03983522013628057, 0.047745832441640754, 0.025799631673310484, 0.0606182354635426, 0.00817961836167212, 0.008309563754924705, 0.031872818645622046, 0.033232952268528085, 0.021358550426417162, 0.08432396235210554, 0.10060619722519602, 0.1727242102580411, 0.10573773365467787, 0.24888376785176142, 0.11497288702854089, 0.12678266689181328, 0.11469744252307074, 0.19056216308048793, 0.07684776852173464, 0.061565504276326725, 0.08500318269112281, 0.21989482481564793, 0.09531929663249425, 0.11384708886700017, 0.11100277863442898, 0.12303682789206505, 0.11977402440139226, 0.12770118617585727, 0.23239517690879957, 0.08953593232269798, 0.11246194105063166, 0.10584729670413903, 0.20389068073460034, 0.09081383089401893, 0.13975696212479047, 0.09605628065764904, 0.1609324115727629, 0.18945457679884775, 0.05832469889095851, 0.07283903791436128, 0.17731878800051554, 0.10159263107925653, 0.11686871387064457, 0.1953400131314993, 0.0647533635741898, 0.26901628183467047, 0.11034813483378716, 0.12887368111738137, 0.08702041301876307, 0.10119500955832855, 0.13318859386656964, 0.11706113283123289, 0.09526523774755852, 0.09158142363386494, 0.21267327160707541, 0.15975446120968886, 0.09564329031854868, 0.12793533504009247, 0.08062746641891343, 0.12454511624361787, 0.19187898242047854, 0.07228711753019265, 0.14785910450986453, 0.12211016618779727, 0.07924083261085407, 0.09320980589836836, 0.10040792929274694, 0.20975847515676702, 0.14851283228823117, 0.14172251522541046, 0.12666947368000234, 0.14228116667696408, 0.10702374750482184, 0.1245591619185039, 0.17157273633139475, 0.10116942200277533, 0.1438521109521389, 0.25765638425946236, 0.1029532023572496, 0.20663080870040826, 0.07463214812534195, 0.24030857799308641, 0.13836164985384258, 0.12222057740603175, 0.0900642600442682, 0.08417606207409076, 0.11419787790094103, 0.10366836469620466, 0.14837789881442273, 0.12520516796835832, 0.12604538431125029, 0.13575956305222853, 0.06470910952027355, 0.18313118682375976, 0.20488178969493934, 0.06632235366851091, 0.16877406436417783, 0.09122507061277117, 0.13355821903262818, 0.12474681756326131, 0.08491590951702424, 0.11872218655688421, 0.13761745978678974, 0.1685719152114221, 0.11258049468908991, 0.18497691064008645, 0.1066245042851993, 0.16390716337731906, 0.13984908003892216, 0.10918769745954446, 0.12168279769165175, 0.06540388188191823, 0.10533545738352196, 0.20012623630464077, 0.19335756450891495, 0.11774858380002634, 0.083249183238617, 0.13808085849242552, 0.08492714605693306, 0.12012296782008239, 0.09969119275254862, 0.08257959809686456, 0.08054942810641867, 0.0965659079541053, 0.08324671337114913, 0.07929796525942427, 0.09415830285953623, 0.1492883435317448, 0.15634913822369917, 0.08397536498627492, 0.12014740865145411, 0.10231295028435332, 0.1437524612993002, 0.1411535907536745, 0.11309808798666511, 0.12822345457971096, 0.12534255773893424, 0.18403916167361395, 0.11867011577955314, 0.11933776709650244, 0.07851091213524342, 0.11800336012882845, 0.09775449096092156, 0.1471190263650247, 0.14368356285350664, 0.12481791446251528, 0.15434432508690016, 0.13268501231712954, 0.09342212629105363, 0.07939944695681334, 0.17500380293599196, 0.10783065456364836, 0.11166485917887517, 0.09351152327976056, 0.17467031654502663, 0.17293499037623405, 0.14962885954550334, 0.1324949682291065, 0.1414615913693394, 0.16895266835178646, 0.12926518225244113, 0.1277325480644192, 0.07544837146997452, 0.14098000792520388, 0.07764584783996854, 0.08053167763033084, 0.08683892525732517, 0.16565337324781076, 0.11930002697876521, 0.10385579642440591, 0.07019714824855328, 0.1205933147243091, 0.11460964009165764, 0.17181791817503317, 0.11877587224755969, 0.12970043532550335, 0.20287545663969858, 0.1052443708426186, 0.191905051735895, 0.17273725170109952, 0.09242698004735367, 0.09611717917557273, 0.08187835929649216, 0.10466410805072103, 0.11320767817752701], [0.01378784854231136, 0.026778772972258072, 0.054223019164055586, 0.022589701327628324, 0.03101771863709603, 0.01878164236300758, 0.03137883497402072, 0.01745773572474718, 0.02417258103378117, 0.036697317979165485, 0.023159212732155408, 0.00475197030131572, 0.0133250571255173, 0.03257155365177563, 0.07065969878541571, 0.055775782093405724, 0.02286162423635168, 0.06556962763092347, 0.046854508841144185, 0.02701491842578564, 0.05450221936085394, 0.0172990840593619, 0.03952746379322239, 0.028815387349043573, 0.03796458051406911, 0.04914197252531137, 0.053211557545832226, 0.05882448064429419, 0.13481202961078712, 0.044205908464001756, 0.028839281959725276, 0.05869884988559144, 0.02086755061256034, 0.010448023693503013, 0.028522711446774856, 0.03399072660665427, 0.07534203824720212, 0.06211888351078544, 0.016353168923939978, 0.019037957269964472, 0.023806080521483506, 0.004081261760023023, 0.04091529182291456, 0.019804703537374735, 0.01664670995835747, 0.017231568128668835, 0.04184825711750558, 0.03883738010855658, 0.026153847309095517, 0.01783556437918118, 0.05191790678405336, 0.02793874724635056, 0.013758788583800197, 0.07656934524753264, 0.00799874637076365, 0.06050552401159491, 0.026953728137803928, 0.030794002248772552, 0.008943112750005509, 0.02945172766755734, 0.06086549362433808, 0.03114194143563509, 0.03242181793653539, 0.021045915416574905, 0.0515963354680155, 0.014261664456820913, 0.03117213285128985, 0.02098486422827201, 0.033259835825966935, 0.06818151926355702, 0.030798073458884443, 0.07767785433679819, 0.02172081688019846, 0.021413445605763366, 0.04043234791606665, 0.025043329756174768, 0.006649441318586469, 0.01489610826995756, 0.06543558303798948, 0.009936510917863675, 0.05328847627554621, 0.05723866966686078, 0.015604872023686767, 0.046685991276587756, 0.05056517258552568, 0.0444035385735333, 0.027782694370086704, 0.03889421759439366, 0.013111752008886209, 0.03463147061743906, 0.06803762912750244, 0.042935046300824196, 0.01402925094589591, 0.018214519401746135, 0.05042013572528958, 0.039888624234923294, 0.04785602992134435, 0.02030605440294104, 0.03946698257433517, 0.01890828074621303, 0.06385370077831404, 0.06261908595583268, 0.03750773645671351, 0.0170584365259856, 0.11312837778989758, 0.022582013525867035, 0.059037113163088045, 0.024553795577958226, 0.03767613527764167, 0.09295496850141458, 0.05243319306256516, 0.02037312589319689, 0.016536610866231576, 0.07134346530905791, 0.03888541699520179, 0.05844762908028705, 0.04672740566145096, 0.039216874566461356, 0.007989450441008168, 0.018568621382915547, 0.07270911202899047, 0.03011240025183984, 0.017072587373799512, 0.04536941960187895, 0.07696623395064048, 0.09313025445278202, 0.027633599870439087, 0.05669505115864532, 0.019969285598823, 0.05909859522112778, 0.0778484380404864, 0.025512730104050467, 0.03431044212941613, 0.013851909881590732, 0.008877669743794416, 0.014629852824977465, 0.04003454658335873, 0.059857950545847416, 0.03525783307850361, 0.03566645025940878, 0.06664938719144889, 0.045706607401371, 0.002755276048057047, 0.02862487846453275, 0.04625277041590639, 0.03188801783003977, 0.06065526311951024, 0.040812928030001264, 0.040221869745957, 0.007712658195357237, 0.030592216112251793, 0.05448199562462313, 0.06699961304132428, 0.029781611037573645, 0.06196598242968321, 0.029971071585480655, 0.05079828329118235, 0.027759600430727005, 0.024056378519162536, 0.009409101763074952, 0.0032799269579949653, 0.06272904934095484, 0.0248499557575477, 0.00431193525270958, 0.03861805723447885, 0.023187743433352028, 0.04403655630137239, 0.0023614886740688235, 0.024866617184930613, 0.029605945106595755, 0.05883268413266965, 0.028768999302493672, 0.024094030427347337, 0.018171602061816623, 0.014572338500459279, 0.021284167721335377, 0.04326543517942939, 0.01757095947063395, 0.019270445419741527, 0.02663476069990013, 0.034970605812434635, 0.026803407186110104, 0.01949826185591519, 0.03557930939963885, 0.026665971614420414, 0.020476230985618064, 0.0343713508253651, 0.060288352093526294, 0.03407198456781251, 0.008889355813153088, 0.06687371086861406, 0.04659470796052899, 0.01700111897662282, 0.010438473313115537, 0.024527280125766993, 0.015040571768102902, 0.03246166151283043, 0.061412250357014794, 0.011543986670273756, 0.03956910548731685, 0.03489694744348526, 0.026812021188171845, 0.01022216398268938, 0.07818571065685578, 0.05711090152284928, 0.01636981508428497, 0.010251469910144806, 0.033347723074257374, 0.01424802081393344, 0.008032416974726533, 0.03190255205013922, 0.07164065686187573, 0.044903381395020654, 0.016141623757513504, 0.013222380358326648, 0.004614578834402242, 0.015799626841076782, 0.036116261301296096, 0.021037303110850707, 0.01943338881911976, 0.022837822924235036, 0.04593313631734677, 0.026333860953205397, 0.055010231743965826, 0.039449069249842844, 0.05277492365400706, 0.015506085806659289, 0.022915141989610026, 0.018435686194737042, 0.04002413785617266, 0.007352404446075005, 0.03152002454070108, 0.014959741284006407, 0.05027987575158477, 0.017070602658869963, 0.003986129878155355, 0.054988362560314794, 0.08220276688890797, 0.0030681612676874337, 0.03804388090169855, 0.048053911088832786, 0.058900510493133745, 0.04801101071227874, 0.012048402817786803, 0.06109842112553971, 0.1277244056441954, 0.06897254860294716, 0.024389949727005193, 0.028053182177245617, 0.020818521368450353, 0.01308408983251346, 0.0011941424350620114, 0.008968467059146081, 0.02907773952132889, 0.03701973746397665, 0.02803227142430842, 0.045318821245538335, 0.09932293822722775, 0.037796931474336555, 0.06000739109835454, 0.01283546696816172, 0.015329193423635193, 0.09265012307358639, 0.03807216563395091, 0.025111929646560123, 0.024435754233439053, 0.02649726575639631, 0.029210131881492477, 0.03530821430363825, 0.01846215923848961, 0.05984830177788224, 0.011485084741642433, 0.04849455512261816, 0.029150841491562978, 0.025670467443498116, 0.013658514678744333, 0.0725395596985306, 0.02553167819444622, 0.038714293856173754, 0.01982923597097397, 0.05445616379646318, 0.0682098006031343, 0.04342285869643092, 0.026430257030629685, 0.06852023037416594, 0.06550283264368773, 0.04047375890825476, 0.03254141991159745, 0.043945008356656344, 0.017551039378823977, 0.013960142154246569, 0.020917355082929134, 0.00932424417364278, 0.05379985758502569, 0.07305490704519407, 0.026337095868906805, 0.028900631703436375, 0.02013459030006613, 0.021740887946050082, 0.04568535229191184, 0.049483801504330974, 0.037108717153647115, 0.021411377770294036, 0.026022905317534293, 0.031075831768768172, 0.038128297443368604, 0.08250220439263753, 0.013197383976408412, 0.03987137587474925, 0.029563251683222394, 0.022511004836165478, 0.03545494071607079, 0.09072420320340566, 0.025484326628169844, 0.01829015739661242, 0.06833144836127758, 0.0076961604645475745, 0.03243664053401776, 0.06419608954872404, 0.06639704001801354, 0.0174382227539484, 0.03213614112298403, 0.04121842394982066, 0.07638905170772757, 0.01945410279690155, 0.04756755754351616, 0.019765131375087158, 0.06694591377994843, 0.0315373848591532, 0.025380980655817047, 0.021076424047350883, 0.02436768020769315, 0.044092895063970766, 0.018799411498808434, 0.054892393959952254, 0.004989424479260508, 0.03726488198818905, 0.029220985049115758, 0.03291352512314916, 0.010165100883958595, 0.03756271814927459, 0.03063242949013199, 0.03546251995222909, 0.01530239129039858, 0.023242243366049867, 0.0333138743548521, 0.008436476944812706, 0.03542322938197425, 0.02785208814644388, 0.03774738823994994, 0.01602387079037726, 0.022707949625328183, 0.12310203510735716, 0.12052238067345959, 0.23186735808849335, 0.08956072599227939, 0.10414951387792826, 0.09149026923945972, 0.09569561893918685, 0.1155601048043796, 0.09088802869830813, 0.08386826501893145, 0.10944237879344396, 0.12245824108166353, 0.11792523360678128, 0.06282259217862572, 0.19202516600489616, 0.07573079131543636, 0.09351236466318369, 0.08788606763950416, 0.11172192397394351, 0.12912085785397462, 0.1251730461205755, 0.13457355169313295, 0.15887408916439327, 0.12776922966752732, 0.13361315322773798, 0.13987007391239914, 0.08627215852694851, 0.17060829379728862, 0.267122246325016, 0.13309486103909357, 0.13009538341845783, 0.15139898099005222, 0.10330157580652408, 0.08902004214801959, 0.16705480590462685, 0.11944194936326571, 0.21430881241602556, 0.16502036792891367, 0.09673531779221126, 0.13296374093208993, 0.0956956392952374, 0.14093237476689474, 0.1579881395612444, 0.21311152380492004, 0.10390015225857496, 0.1610814585749592, 0.12055185623466969, 0.11600556304412228, 0.0588200090985213, 0.08345368012253727, 0.186555522360972, 0.16598438977130822, 0.060736096996281824, 0.1125902384519577, 0.054516519486371956, 0.1933901070484093, 0.07159173448703118, 0.18263577483594418, 0.09615107878510441, 0.05815811175853014, 0.15272589693112032, 0.15902523962514742, 0.09525267806436334, 0.10571910108306579, 0.13921707895185265, 0.11666927885796342, 0.12770687229931355, 0.07871234204087939, 0.15734072215855122, 0.1661033776721784, 0.1863079113619668, 0.18092792933540686, 0.06712890110377755, 0.10712479493979897, 0.09958076117826359, 0.11126403497265917, 0.08761647210589477, 0.11900698127491133, 0.2439491626407419, 0.10100255667098931, 0.12779191987855093, 0.12253441342285701, 0.1351618958371026, 0.2014923987111875, 0.15457369706460408, 0.09771109186112881, 0.1731594769018037, 0.13805618695914745, 0.11591297015547752, 0.0821371932647058, 0.15331466176680156, 0.11067387235483953, 0.1420675367116928, 0.1339934721056904, 0.21822568295257433, 0.10837722809187003, 0.12949133797415666, 0.12545303681067058, 0.1068330452378307, 0.06330248607056481, 0.2449887597135135, 0.15623324444251402, 0.11028762986617428, 0.09998656583151647, 0.2582079518054213, 0.17523229281817163, 0.12663689042840684, 0.07744912696736199, 0.11936498992145061, 0.24145253375172615, 0.13853448629379272, 0.11754112850342478, 0.1468824619161231, 0.14472174857343945, 0.07835407555103302, 0.11897914776844637, 0.15893659581031117, 0.13791159114667348, 0.12658207836960042, 0.062407159113458226, 0.16684292655970367, 0.16170700000865118, 0.11404727026820183, 0.18361483301435197, 0.11111669109335967, 0.17581926632140363, 0.09469188922750098, 0.12653817715389387, 0.13376754708588123, 0.15237867699137755, 0.16112109859074863, 0.1158340158207076, 0.16649498737284116, 0.1687271911650896, 0.05164836553324546, 0.10698795478258814, 0.1908027580274003, 0.1351764164865017, 0.08564383509968009, 0.1948397292622498, 0.1674327634807144, 0.15455045045486518, 0.1374830419995955, 0.1609763806419713, 0.19107058936996119, 0.11035061148660523, 0.16550808532961778, 0.19505907249237808, 0.1704304769103016, 0.12472832069865294, 0.126138085765498, 0.16116368344851903, 0.17591295843677862, 0.10563355138791458, 0.17017154794718536, 0.07317374566836016, 0.26107924059033394, 0.08400932566395827, 0.12143635377287865, 0.11070373468101025, 0.1375101019761392, 0.12401279195078782, 0.11167245198573385, 0.07267911399581603, 0.13276843141232217, 0.11097000539302826, 0.11745146688606058, 0.09899285808205605, 0.0993345615320972, 0.17684902463640484, 0.15796950698963233, 0.09507458976336888, 0.08297610682036195, 0.16771579400769301, 0.10251699254981109, 0.046791971661150455], [0.01990799861960113, 0.05495443920205746, 0.04387398948892951, 0.017397324055699364, 0.06058027142924922, 0.009582833869249692, 0.05843595827796629, 0.04192911135032773, 0.027539665178794945, 0.007932042985755419, 0.02110068845961775, 0.007691141001747123, 0.018239326642027924, 0.017968891421332955, 0.01760997693054378, 0.0749695428780147, 0.029682351542370658, 0.04150854856041925, 0.06816219458622591, 0.04085622874221631, 0.05350286280736327, 0.035499340655016046, 0.04343766433053783, 0.06859704732362713, 0.012941085184658212, 0.04464717675000429, 0.011089402134530246, 0.028277614420013766, 0.027411727401028787, 0.027886352468548075, 0.018083589284547737, 0.04905576465119209, 0.03452070995366999, 0.057602093022848876, 0.04507196002772876, 0.03705127237896834, 0.017129599582403898, 0.026849030184426477, 0.030368635430932045, 0.023770893391753947, 0.05129526269489101, 0.037302527111023664, 0.02002838599894728, 0.02785413562586265, 0.03775686737416046, 0.04339662653260997, 0.03902202305783119, 0.031587732157536914, 0.0053770176766972455, 0.11246584941233907, 0.013520487085250872, 0.03695260320923158, 0.06371183267661504, 0.022995987740744437, 0.061935312646840296, 0.048179022768246274, 0.05359891961727824, 0.02069832567524697, 0.06951346314911332, 0.01895339653960296, 0.01990259748085269, 0.010549502846385752, 0.035123693490667005, 0.042844685792390785, 0.028792123775929213, 0.009696801459150655, 0.006211596665837402, 0.048072988100882084, 0.10861375861402069, 0.011148578021675348, 0.022600062557363083, 0.048495579710496325, 0.04569642598341618, 0.01971721153573266, 0.018100011528336575, 0.06430071964859962, 0.03787396216232862, 0.01244870200753212, 0.022755265568516085, 0.04825869635013597, 0.05452580184542707, 0.017470726277679205, 0.03849339678085276, 0.03259946518976774, 0.024391815698306476, 0.0210075357795826, 0.04070548879514847, 0.054906690692795176, 0.03411358215713075, 0.008131930072392737, 0.0190047344991139, 0.02581300220585295, 0.05395096394100359, 0.02569364959241024, 0.05669222166761756, 0.021120985138363073, 0.02491741910177682, 0.016123369469174316, 0.07737118364976985, 0.060262703469821384, 0.03452077441449676, 0.038549630370523245, 0.021028103872335384, 0.04157473625881331, 0.018307772165696536, 0.03115224838256836, 0.05165747147319572, 0.03634053748100996, 0.04259033354797533, 0.02929819215621267, 0.04512397312958326, 0.019012349358360683, 0.03539466984303934, 0.03229398872437222, 0.0155728502598192, 0.042072153317609, 0.05102761794946023, 0.040074284986725876, 0.049980037912194214, 0.06926121775593076, 0.028848082558917146, 0.022571304546935216, 0.080928797035345, 0.058890766730265956, 0.028067231244806732, 0.021310023298220973, 0.05773672115589891, 0.005288430265084441, 0.11249355399715048, 0.027019888694797243, 0.019417170135836517, 0.054346936621836255, 0.03470556664147547, 0.006248603541670101, 0.024628839854683195, 0.05860794654914311, 0.0596077950405223, 0.04179870370509369, 0.05862190401447671, 0.016622367514563457, 0.013398513630298632, 0.03879467311448284, 0.0157072188532246, 0.011751112029222506, 0.007614460607458438, 0.019586764874735048, 0.0138724338695673, 0.03519634423511369, 0.01842064137703606, 0.0375913794684623, 0.019436905326853906, 0.020941395578639846, 0.019723750916974883, 0.06026048466031041, 0.02187223536228495, 0.02300267300701567, 0.11354492365249566, 0.017859455597187792, 0.006187395442144147, 0.009029250226116605, 0.04521525305296693, 0.020488498898755227, 0.08688231078641755, 0.045241539499589374, 0.004633004028749253, 0.010087861546448298, 0.0751394819734352, 0.03339733416214585, 0.02508316485078207, 0.014886254245149238, 0.03562671524871673, 0.02687318772742791, 0.03227334090375474, 0.05871168776814427, 0.03421900953565325, 0.09325413459113666, 0.03257746369178806, 0.025194290227123668, 0.018126001115888357, 0.030906218370156627, 0.02959445072337985, 0.028725511993148496, 0.022037187225318382, 0.028381091010357653, 0.05540163449144789, 0.0387443427794746, 0.013538526786890413, 0.018257871004087583, 0.05079347247790013, 0.05224372912198305, 0.04521951764555914, 0.04832218347915581, 0.07561024956937347, 0.01885356198597167, 0.04998986649193934, 0.054134772292205265, 0.009704370517283678, 0.02182503816272531, 0.016831157828814218, 0.018334469126005257, 0.022550697438418865, 0.03878650016018322, 0.06843077231730733, 0.044642566104552577, 0.028358704443754892, 0.0731520936159151, 0.047360438121748824, 0.018899846555931226, 0.015579330269247293, 0.03378731877143894, 0.03747862730441349, 0.036222146690956185, 0.04024645306968263, 0.03768920725477593, 0.023779078220416392, 0.044709330557712486, 0.042973057832568884, 0.06748125755361148, 0.009712268664900745, 0.02894378313794732, 0.02915415952780417, 0.06080848989742143, 0.045377748619232855, 0.05650159403947847, 0.02625528659804591, 0.10502870527229138, 0.015352769122858132, 0.0615208363160491, 0.05499671193371926, 0.09026375612510101, 0.015149690377126847, 0.0311838070462857, 0.017647786598120416, 0.0144823393119233, 0.015337804033021842, 0.07454589953912155, 0.032505586477262635, 0.011213775058942181, 0.022309707244858146, 0.04484107152425817, 0.037743032045130215, 0.028645655206803764, 0.031005555896886756, 0.007047916945469166, 0.0024963746504259427, 0.011976061654942376, 0.021377410307260494, 0.034029504882970026, 0.028609638568013906, 0.04258607913340841, 0.03906731866300106, 0.014830210645283972, 0.02648439394709255, 0.02757521193208439, 0.04494728261072721, 0.005512517727246242, 0.06067118155104773, 0.04830914882144757, 0.05709355816777263, 0.04993906796776822, 0.0026212388765998185, 0.028713736017899852, 0.02242019649461976, 0.016635079868137836, 0.029649052436330488, 0.021349809199039425, 0.029239305494619266, 0.040986514251146994, 0.05213473604193755, 0.03789869476375835, 0.08262761802013431, 0.03177274151572159, 0.0413639391772449, 0.07033688575029373, 0.01711754540779761, 0.05374699631439788, 0.050389123282262256, 0.022122535056301525, 0.06672007018434149, 0.03006388499800648, 0.03418476048058697, 0.058933399085487635, 0.05428419588133693, 0.002530955975609166, 0.013649578372548734, 0.034489449845360856, 0.06676406639495067, 0.053408166460160694, 0.042718186508864164, 0.038860267094735584, 0.03261011479688542, 0.04553045292517968, 0.06080143313322749, 0.03581627079152635, 0.010395476245321333, 0.03606681306181209, 0.0345811979579074, 0.02095708839728364, 0.06770279923720018, 0.11110957326101405, 0.03273413064224379, 0.05654808047360607, 0.0329070756477969, 0.03068552485534123, 0.03995774659727301, 0.029426404740661383, 0.013555899827874132, 0.09152656407760722, 0.052317892999521325, 0.043311572168022394, 0.035744671776358566, 0.011648622707330754, 0.08617734004344259, 0.029865498321929147, 0.02271737447673721, 0.018776220868208578, 0.04475363210908004, 0.0813404710165092, 0.08437940544847931, 0.009336396735826773, 0.022806556030575718, 0.0652901865541935, 0.027282213725681816, 0.010453755618073046, 0.05770381899284465, 0.02764491953088769, 0.010756551870144904, 0.024989365866141658, 0.025036464678123593, 0.0497640228963324, 0.07009019755891391, 0.013391573065226632, 0.039210194389202764, 0.008750375726127198, 0.016060866215931516, 0.033030667408768616, 0.05321919445746711, 0.024616212317986146, 0.06710239752594914, 0.037579196372202466, 0.03668806615418621, 0.0453424817616386, 0.018161671701818705, 0.06787670776247978, 0.06069862150720187, 0.010079051617399921, 0.04533084827874388, 0.01903531776874193, 0.03261235056977187, 0.014390197649065937, 0.028703038913330862, 0.012397982363056923, 0.102887940859156, 0.13565310090780258, 0.1053056154134018, 0.11481736680226666, 0.0743267870108996, 0.10971526522189379, 0.12767529327954563, 0.12390509487262794, 0.14589595342321054, 0.15390534007123538, 0.18956492016358034, 0.0964958288573793, 0.12287568939583642, 0.2128713359790189, 0.11837450521332876, 0.10374552091317517, 0.148659205862454, 0.12542110495269299, 0.19657358979540213, 0.1164077850324767, 0.1609491849584239, 0.11414997332862445, 0.10687601686056171, 0.20798418750720365, 0.14969904720783234, 0.10062601723309074, 0.16988029357578072, 0.1726893742701837, 0.09077718321766172, 0.2078074969883476, 0.12127091336463179, 0.12001666852406093, 0.08104166455034699, 0.15953218670828, 0.0893059903755784, 0.11628711436476026, 0.10573956569922821, 0.1780578483428274, 0.11376068421772548, 0.10330563344593559, 0.1721039613974946, 0.13717782337750706, 0.10118625645658799, 0.10471794301910059, 0.09125529256250177, 0.12703113284494194, 0.1229050699621439, 0.20735012367367744, 0.1428365475897278, 0.28410489218575613, 0.22965772237096513, 0.18672440972711357, 0.20260352694562503, 0.14925938365714891, 0.23270640735115322, 0.13929816388658114, 0.1309119596013001, 0.08893928291010005, 0.11110164118664605, 0.16896549266363892, 0.11786725957478796, 0.10249820391514472, 0.050068230501243045, 0.1450465361454657, 0.10102146744195904, 0.1915107143244573, 0.12144738675228187, 0.09615036632333483, 0.14520941169134208, 0.10125178936868906, 0.08560182021132537, 0.1928079104317086, 0.13096626954419271, 0.09112191293388605, 0.1444654930382967, 0.11062467856598751, 0.0559181183842676, 0.13515074072139605, 0.10310397283839327, 0.10569050761737994, 0.21373038845402853, 0.10114931701017277, 0.08426055325461285, 0.14585001660244806, 0.07479997019150428, 0.15245399437844753, 0.09842406253197364, 0.14424423633941583, 0.11205409400697265, 0.12801799417606421, 0.06590103091938154, 0.14492799607770784, 0.1151649531509195, 0.11677783089024679, 0.17534535032297882, 0.0850377269089222, 0.18996016681194305, 0.13800995158297674, 0.1394516077956983, 0.07221987470984459, 0.06635294881250177, 0.1608521273093564, 0.1779840508741992, 0.1293480313782181, 0.15837390029004642, 0.0910985916852951, 0.20115731097757816, 0.10196254123002291, 0.10320417888994728, 0.08992393221706152, 0.13715801015496254, 0.11190919963909046, 0.1777546246136938, 0.11960711835750512, 0.0839597654661962, 0.13344300378646168, 0.11646442913583346, 0.24251539100493702, 0.08062615684632744, 0.10688851547560521, 0.06945422025663511, 0.1036432928272656, 0.21567270851561002, 0.18021259057734693, 0.08540507898266826, 0.09140870254486799, 0.27301662574921337, 0.11624759648527418, 0.14596415976328508, 0.1467275930834668, 0.14904701576701232, 0.16498608833977155, 0.1369814553431102, 0.14181228540837765, 0.11846688097076756, 0.10411845733012472, 0.16868672333657742, 0.14209828791873796, 0.09422538283147983, 0.1426843386143446, 0.2229721846857241, 0.1386097493980612, 0.14443233981728554, 0.09024230084781136, 0.14891312723713263, 0.0874142347435866, 0.08999627083539963, 0.09068836298372064, 0.12412190038178648, 0.0806587604539735, 0.11960576128746782, 0.0832875408232212, 0.08611945422100169, 0.11651884764432907, 0.12803256910826477, 0.17182832690221922, 0.31443141773343086, 0.12109201082161494, 0.16011217130081995, 0.0778906089918954, 0.13267240513648304, 0.12177980105791773, 0.23752541733639582, 0.18175350289259637, 0.13355865329504013, 0.11652401808117117, 0.1443265697785786, 0.1563240731401103, 0.1558804333742176, 0.15333674129630837, 0.14228067813175066, 0.19810141995549202, 0.12436351313122682, 0.20865977768387112, 0.09401260103498187, 0.13560799189976283], [0.0484858020208776, 0.04102062759920955, 0.05912570269512279, 0.05360024954591479, 0.032731721842927594, 0.04353543783404997, 0.05055415317682283, 0.048152872028627565, 0.02991813906867589, 0.03828968360487904, 0.021538689599505494, 0.026726374801780497, 0.023918030317872763, 0.032146719483924766, 0.03150066593661904, 0.009316525837805654, 0.04662122171638267, 0.05576584155538252, 0.026546332319932323, 0.02474778195443962, 0.01583740088556494, 0.07128904001521212, 0.03487284587962287, 0.014536311683644141, 0.008572275550769908, 0.055491821973451545, 0.05660243791395, 0.031945964720632346, 0.028898019343614578, 0.040224631383482895, 0.05144695259098496, 0.021737954978431975, 0.04317580070346594, 0.01228589007431375, 0.022340602640594755, 0.047244018475924215, 0.028124011055167233, 0.025162263374243463, 0.008809570272985314, 0.0354655801451632, 0.036351414397358894, 0.027646403826240982, 0.02704681466067476, 0.017755432786153894, 0.03871258055525167, 0.02237538943466331, 0.006477225738178406, 0.027063835711617554, 0.059423443861305714, 0.015374660358897277, 0.04065336712769099, 0.04080798150971532, 0.037462423888168166, 0.004819545603822917, 0.027661830319889953, 0.04082755045965314, 0.05989493748971394, 0.04278276947193912, 0.030901977526290075, 0.007816752252568091, 0.048643140721001794, 0.043128968216478825, 0.018921503697388938, 0.025587743846699595, 0.05207283668486135, 0.03368698719090649, 0.0451799285198961, 0.02592019207908639, 0.014537604292854667, 0.02504384544278894, 0.03573315025174192, 0.03849079120638115, 0.058717923504965644, 0.06545418846820082, 0.05266451582844768, 0.051086443542901955, 0.04968411521986127, 0.08314185935471739, 0.05720825772732496, 0.008416812151803501, 0.05176778430385249, 0.030922516781304563, 0.03257079029987965, 0.07511195380772863, 0.006464136797668678, 0.05848753372473376, 0.033909645064600875, 0.042063949829233546, 0.013128173404506274, 0.019107557999502336, 0.06377421040087938, 0.00508518230968288, 0.012504172245306628, 0.03422895685902663, 0.026401037616389136, 0.034089161681809595, 0.07908738191638674, 0.006395504252785551, 0.04530081292614341, 0.011527219221794179, 0.05099975051624434, 0.07488047158611671, 0.05634846564914499, 0.019705216732940505, 0.0699744326993823, 0.0697151848248073, 0.02194590221292206, 0.0440799757572157, 0.022317608785150305, 0.07468054802822215, 0.013736444425636103, 0.050303909461945295, 0.03645115904510021, 0.06164425505059106, 0.04918124273951564, 0.06734133684741599, 0.029428640513547828, 0.017049155863268033, 0.007059862978556859, 0.027254758502489755, 0.06413438357412815, 0.038964792021683285, 0.052126848072345765, 0.016420228539833, 0.026039312294285213, 0.06427967827767134, 0.02078874725183206, 0.05206969167504992, 0.030544165654906204, 0.04581466071041567, 0.04003803764602967, 0.10046373201268059, 0.003785679183368172, 0.06574255906577621, 0.04940934246405959, 0.029411778918334415, 0.01583714982760804, 0.02087022573687136, 0.019465776991897395, 0.012080601848927992, 0.14496900673423493, 0.053779460822365115, 0.07206783536821604, 0.03867518309769886, 0.04574513801240495, 0.040110369479017596, 0.028794888806130205, 0.027963902235829403, 0.03381617347310696, 0.04168402450159192, 0.032756318737353594, 0.04740831894533975, 0.05548934871330857, 0.06461948861501046, 0.06219078108136143, 0.05812744876103742, 0.03224534454888531, 0.012910014217985528, 0.0985126927761095, 0.017889088917789713, 0.023241132264956832, 0.08820761181414127, 0.0036954815233392374, 0.034127546407814534, 0.017582844011485577, 0.04717006155156663, 0.024866450943851044, 0.034634988821510754, 0.05129281318347369, 0.062469340062567165, 0.035988415125757456, 0.013491537388680237, 0.0732874884935362, 0.03660686247582946, 0.05010140407830477, 0.05627624238176005, 0.016588640931461538, 0.020703348530722514, 0.06181557157209941, 0.0548108408360609, 0.026742320374718735, 0.03228858419294868, 0.024324535558532392, 0.03836061426305345, 0.04579027076917035, 0.03330149109076176, 0.02355230672817145, 0.053171781823039055, 0.03855272109753319, 0.047168232899691374, 0.022517551002757888, 0.03183161460661462, 0.014558979842279638, 0.024746128025331667, 0.00818608480039984, 0.014295336757121342, 0.04286450580028551, 0.059887901081570556, 0.09830027060317141, 0.036567466732646735, 0.021448254452220032, 0.05851301271468401, 0.05146032651620252, 0.022558183376012102, 0.045758094638586044, 0.010578419464374227, 0.015557350823655725, 0.026475489871310334, 0.04291143328217523, 0.018266376440546343, 0.03467368906629937, 0.046083509855504544, 0.04614539224920528, 0.05450617861268776, 0.07086932539407696, 0.08799631600933415, 0.043310001359454224, 0.03701558143698743, 0.006835740317390966, 0.030634064759526933, 0.013241466700232454, 0.05648784692000065, 0.042992925337914906, 0.030373551417142153, 0.06365826912224293, 0.018695118970104625, 0.00250453594240493, 0.02517628699674138, 0.013668378033409161, 0.02931014115789107, 0.008942533450733339, 0.028186909555058395, 0.0622889922399606, 0.04240470672292369, 0.06179824857307332, 0.016975517850369215, 0.013190144855928208, 0.03223257451983435, 0.05475866149312683, 0.021120391420221755, 0.03612513993201511, 0.03676049637475184, 0.022194909297728112, 0.06113010871091059, 0.06442787032574415, 0.052982494301561794, 0.03756058415664094, 0.04001165620450463, 0.031526443481977494, 0.05890822543629578, 0.02753253886476159, 0.02971761839996491, 0.02941859480259674, 0.02961074574185269, 0.02636480893540595, 0.03118123539856502, 0.018353980400466492, 0.04924081811415298, 0.0668788066666041, 0.0731693080493382, 0.026883214778665985, 0.020387244510597417, 0.02717645386500018, 0.013345250327672278, 0.04942486395261117, 0.0829343158485634, 0.04478054280791964, 0.00802927281308387, 0.012890198450934674, 0.023299135134688446, 0.029861908871680498, 0.03970661060884595, 0.08632777804242713, 0.009180715357485627, 0.0662868662870356, 0.02684746616120849, 0.02328017008091722, 0.06179347847189222, 0.027538174098091464, 0.049181598970400434, 0.02392687671817839, 0.06421239474522215, 0.025474652415141463, 0.035373533477208445, 0.0207976377569139, 0.010759733351213592, 0.026117316680029035, 0.022542122452120696, 0.04155331490827458, 0.0990668794672404, 0.05381392700863736, 0.03603463353855269, 0.008176957656230246, 0.007595547291982386, 0.018095536589888588, 0.08736876611198698, 0.042497625308377404, 0.07263046982032911, 0.02751138383921768, 0.020967205354411687, 0.0328564738987812, 0.07077699713408947, 0.025979175431919948, 0.02253016157607947, 0.07991152376468692, 0.031057731847145727, 0.05963150305407388, 0.03869666890906436, 0.026835948029266934, 0.01829607761465013, 0.03186560581837382, 0.06384064576455525, 0.0428786668261247, 0.010549675872815507, 0.022514957302649106, 0.019109822610127072, 0.0500316540710628, 0.05381864282701697, 0.11370812489518098, 0.05896292214414903, 0.09816504535930497, 0.054458959360740015, 0.04830538973744426, 0.01531775841223342, 0.020534912390368323, 0.03914891928434372, 0.05647003537576113, 0.00940939098862665, 0.012943826466133552, 0.03584115945601037, 0.06892686284014157, 0.03857951644541962, 0.025272240330066, 0.011602421257910984, 0.031949947721191814, 0.03306367474475077, 0.019628238631412387, 0.07934218538658959, 0.02117358856568379, 0.03342410915398172, 0.03825774835422635, 0.021309916428955536, 0.025969697994046977, 0.02965710325432675, 0.01894685885469828, 0.04251597968063184, 0.046240393937166245, 0.025930365015353476, 0.03950210015422531, 0.03933374883074846, 0.04532726900652051, 0.027315407658794096, 0.1313174521284444, 0.18200599934373582, 0.1753756944090128, 0.13625355011650495, 0.1073362807344113, 0.14621508201318129, 0.13797766688678945, 0.19093416311911174, 0.1129116401342409, 0.16853542359811918, 0.12217590266040393, 0.10996958014688321, 0.12242854838924748, 0.14006668621940271, 0.11155024782887527, 0.07094587771488087, 0.07191756700298615, 0.13839094899594784, 0.16271619871258736, 0.12108097784221172, 0.09713578237486736, 0.17679445685020515, 0.11178126186132431, 0.19931245568607533, 0.11856224228228841, 0.112945119052061, 0.15945952917848313, 0.0805128618542637, 0.08463070767798594, 0.11621704883873463, 0.11873692433748927, 0.07815915958157607, 0.1354487668722868, 0.06286033229636294, 0.0916264783591032, 0.13677982187696866, 0.15552551884736332, 0.0975001421091812, 0.24009538229022706, 0.14054949102657183, 0.09030813231532063, 0.06534724456391164, 0.081211440797363, 0.07750221554722105, 0.13661212873245987, 0.08121165792856898, 0.1677278990724257, 0.09892391892416136, 0.1295960766396352, 0.09545509863112654, 0.1356649345585278, 0.18188433801489218, 0.12030362098344735, 0.06197728682309389, 0.11621666885912418, 0.10122642572969198, 0.20480633660086564, 0.164986468319382, 0.18907543857182774, 0.1417298705450126, 0.08831357184265341, 0.09087993377553565, 0.1778855954429933, 0.12629049830138683, 0.18347580118903092, 0.14139863689030918, 0.14272537641227245, 0.16001105601234095, 0.1673143726906606, 0.21213558688759804, 0.08176074882170983, 0.20094148255884647, 0.1382577390010868, 0.11954089333968503, 0.19030707462557725, 0.13640856822686537, 0.11386232876351901, 0.15664326958358288, 0.20305286640567438, 0.0914061851799488, 0.1076227989313858, 0.11354062852582761, 0.0967254043955888, 0.15961933774607523, 0.059305826601173194, 0.1863324200468404, 0.06867585916604314, 0.11157652749014751, 0.144266329439623, 0.19940059738499777, 0.15835229573505266, 0.0961051012522408, 0.06452117567615849, 0.0847625131053584, 0.18005443763520035, 0.09416954618479524, 0.23795813268848828, 0.10541454063994543, 0.1159985741334302, 0.12320715375244617, 0.15734928527048656, 0.19985676290733473, 0.09760043637028762, 0.0721797054367406, 0.12243382739169256, 0.13149806457970822, 0.14186405763030052, 0.07700303769005196, 0.07518122544778244, 0.14917555744094507, 0.12094779498875141, 0.15577931808573858, 0.10868260277701275, 0.22379123073603424, 0.2720824187355382, 0.18951445072889328, 0.13470923155546188, 0.13532128371298313, 0.15066536249858992, 0.20794298686087132, 0.11765654731009688, 0.16479208160723957, 0.14133702591061592, 0.13986123938645634, 0.15214760867612703, 0.15193677427513258, 0.09638526836144072, 0.1027139848364251, 0.15787342643099173, 0.0783060352717127, 0.1463600985173668, 0.16910921995128902, 0.12739067498062337, 0.12967838293739728, 0.10748279680098806, 0.14552590756544045, 0.08013470071767058, 0.09006723881300006, 0.09897725856197731, 0.14705638401210308, 0.20420324110559054, 0.1199470508311476, 0.17541297312293733, 0.1180132260279996, 0.11022518428840808, 0.13647776522806712, 0.0883788401260972, 0.07573451647268874, 0.12311287809695516, 0.11031777717705284, 0.26294955451573643, 0.13580666695322308, 0.16605231112667493, 0.147619703784585, 0.1316725430744035, 0.17668845610959188, 0.09213629564536469, 0.06524047029337712, 0.17194854973682336, 0.08936295339039393, 0.11459653079509735, 0.2056851073035172, 0.07354299085480825, 0.17847460455128125, 0.2128475872533662, 0.14758607558906078, 0.11792269588581153, 0.15790477474885328, 0.08071203902363777, 0.14141631951289518, 0.08713753494833197, 0.12434321136346885, 0.13314447551965714, 0.0912974974406617, 0.14838897250592709, 0.1991777257727725], [0.016645895716335093, 0.06640868367893354, 0.055734533949622085, 0.016703281119199734, 0.04043892631307244, 0.027894827370930995, 0.02089843413393412, 0.040976563535098515, 0.042055787052959204, 0.047977541972483904, 0.044003901803599935, 0.06364446093461343, 0.019123751237722378, 0.034250496953193627, 0.022649868724069426, 0.014593591913580894, 0.00510540307732299, 0.025022934689851742, 0.02821648520018373, 0.013743446058859783, 0.016291203409699456, 0.05060404585674405, 0.04619313058044229, 0.020241420549739684, 0.06762454379349947, 0.048624453866588216, 0.018471970854859267, 0.07134385207401854, 0.02551067583928151, 0.0452218959107995, 0.012149178838756467, 0.03721491466941578, 0.03335185195984585, 0.06547368956463677, 0.04665797795834286, 0.06762168716107096, 0.023209471820986698, 0.06969987707478659, 0.005837361278411533, 0.0272691688899483, 0.028526182153395245, 0.046261048543133905, 0.02476722028638635, 0.03663832614464419, 0.010613193535911185, 0.05012018592762096, 0.025763504772580097, 0.06923071082149233, 0.022393767555643405, 0.010506781433442873, 0.03258564343143787, 0.02109866133624954, 0.025729225183437978, 0.011507162574811705, 0.0095280209622745, 0.03877487685531378, 0.07789451056825263, 0.025484450460810746, 0.02450664757218744, 0.056978098648999415, 0.025767087437478558, 0.05186707094045622, 0.032354015324796946, 0.05744888660098825, 0.0574160794328366, 0.029003453507487263, 0.050978298631629775, 0.05591335506843669, 0.021937832735212784, 0.05725257284939289, 0.02891249249556235, 0.05456627645928945, 0.024328459187277725, 0.03510305584807481, 0.05188061449942844, 0.014237045510006803, 0.03194113355129957, 0.016735000934984003, 0.02003451995551586, 0.006721117093028235, 0.06721609963902406, 0.043778516219130585, 0.007367952227858561, 0.05237382124843342, 0.0028412979611727807, 0.026380474612649, 0.07513007069272654, 0.043593215090887885, 0.058564974926412106, 0.01666941713275654, 0.0049983417016587085, 0.007055147160177252, 0.042657854567681036, 0.10245825855859689, 0.04609976076920118, 0.04577922421906676, 0.033701127860695124, 0.031174188812396357, 0.06604781161461558, 0.011811055509107453, 0.04488526790269783, 0.069498861075512, 0.09833841105656964, 0.05907274982226746, 0.03867864362629397, 0.0043564085582537306, 0.04177703129659806, 0.012273982632905245, 0.06172586924263409, 0.021909086599147747, 0.043487689324787686, 0.012178373656102588, 0.06655520653086049, 0.061769173347524235, 0.06400434233780418, 0.03868432974975024, 0.02962830283546022, 0.03501563000359705, 0.05147407024300524, 0.041047114213662486, 0.07868083765996353, 0.09041447232344321, 0.015084439057058521, 0.07818210763590676, 0.036703903161521466, 0.03483792168221303, 0.05147411095510636, 0.10583795327693224, 0.04016171083120363, 0.04474921484610864, 0.02411632369538503, 0.06915485739175763, 0.025344740100471035, 0.06448433800999608, 0.02973810337217791, 0.06594027738486018, 0.02465635444968939, 0.07591088808008603, 0.011447132581711879, 0.03261832846328616, 0.016157096052276235, 0.030004723529730524, 0.036012747391526184, 0.02216884846399937, 0.05223378858395985, 0.06876765138336591, 0.047642959747463465, 0.11703251222414629, 0.05458978430501052, 0.0129978081677109, 0.05473761672952345, 0.015483651742605227, 0.028869259636849165, 0.06951840288404908, 0.04196335022736873, 0.016201696159051995, 0.037985319936914105, 0.04034779906006796, 0.01413572157200958, 0.015729320435119525, 0.05350259139335581, 0.005090108473918268, 0.024902114744431207, 0.05022239705015506, 0.058043018648667, 0.01644699674631868, 0.034973170674805126, 0.018720182357355952, 0.051279737813664336, 0.04884410922282508, 0.027080502228013108, 0.01710131485015154, 0.047543249026473076, 0.024728477633159076, 0.04858820991856711, 0.031344463782651086, 0.08306963608733245, 0.05351890676787921, 0.014149425434879959, 0.026217773789539933, 0.025968290033883283, 0.016553024628332684, 0.04894025424229247, 0.03565703219334994, 0.032429929822683334, 0.013142823823727667, 0.03040770547730582, 0.015575298074898975, 0.04286505202097552, 0.016769604524597526, 0.03448041175891246, 0.02149920734310789, 0.034782505727240016, 0.06604121625423431, 0.04066460027492472, 0.03912703313731721, 0.02156103036499449, 0.09100706409662962, 0.03927336599943893, 0.030456519286547388, 0.06300568806805781, 0.057373711706272194, 0.024605460930615664, 0.015554399196324604, 0.04140391506786857, 0.032826007676443884, 0.006910289263552321, 0.049590552026139836, 0.025246070930734277, 0.0794793851673603, 0.044098581187427044, 0.0037735732704667108, 0.017608920112252235, 0.017594058499006287, 0.02055946348368057, 0.007058660275236304, 0.04306348958717925, 0.04215440193989447, 0.027535906094791632, 0.05195313971489668, 0.0365376145845013, 0.040622113804732046, 0.048689070756414106, 0.049578012698995214, 0.038523082687918625, 0.012660926557146013, 0.04380574582942894, 0.05487678086917315, 0.019145581405609846, 0.028485280062471117, 0.02257966240202742, 0.028685597170676504, 0.07747801898845605, 0.03034681374473231, 0.030827891680278947, 0.005898992190070982, 0.051508882482136996, 0.053312486237181086, 0.024213160820571438, 0.043342347123793194, 0.06208488212100097, 0.04951884105269398, 0.027803862966330986, 0.011236222693696618, 0.05920177325606346, 0.07689821081502096, 0.024058190207662325, 0.0735510043533785, 0.006246568784782929, 0.0657848860802395, 0.014483611565083265, 0.030207062672291483, 0.042350132151373794, 0.03144821517967752, 0.022519981854462197, 0.0542531834383096, 0.02775931714235672, 0.01517883684885289, 0.008199825982696243, 0.033259727260363955, 0.03058685568560447, 0.005136399829228009, 0.052307453738259416, 0.02032818821524935, 0.011404213545444821, 0.01639390816645963, 0.05935210268944502, 0.022240612023909177, 0.04716113542339631, 0.043163950089365244, 0.09852738305926323, 0.02561741109405245, 0.06879125761666469, 0.009466175039831017, 0.030322016682475805, 0.02886304086340325, 0.040485660412481854, 0.0457090670908136, 0.101993217798216, 0.014684634349708046, 0.025071154780951992, 0.01298906100315175, 0.03591787462521877, 0.021165081432887485, 0.02024919486471585, 0.04100516717880964, 0.010643021087162197, 0.03395952756649681, 0.0048245981452055275, 0.060752578611884794, 0.014166389658514942, 0.041213311188455136, 0.018550660560971925, 0.02740428556821176, 0.02213186152013285, 0.10325425477432353, 0.05991349542247398, 0.06554984833512988, 0.04596474587119051, 0.07478112727403641, 0.03185794855068837, 0.033518561228577576, 0.01510881882027856, 0.11767835542559624, 0.03381666541099548, 0.022951609854187285, 0.0661834439794932, 0.04615303594619036, 0.03268069600952523, 0.015135926294273563, 0.018577162442462783, 0.015711741289123893, 0.04018842475488782, 0.010579679843171366, 0.08865117015583174, 0.0190637992761497, 0.053931459451892545, 0.03267600393987127, 0.02248246395694358, 0.06828764892582383, 0.010272292453529579, 0.02951311133801937, 0.06264164724520274, 0.038227353378065994, 0.03020466065832547, 0.04608603400577392, 0.024707648304424117, 0.02896333851718477, 0.025801163466115083, 0.0491686627002699, 0.027446906049070612, 0.051709912052111964, 0.008954118588007987, 0.05121101578697562, 0.03428650341395821, 0.048514941707253456, 0.022479894005560448, 0.014500958312835013, 0.049807276111096144, 0.046150691607700925, 0.04338714739839945, 0.01792839475508247, 0.018306416791996787, 0.054111929410802465, 0.016424030032274977, 0.04760063612567527, 0.015334952489605971, 0.031260630781097073, 0.03847758691491825, 0.026403588908059255, 0.019075805953304683, 0.018251501256600022, 0.10685560652720076, 0.19110573748392717, 0.166883435100317, 0.09956343139388732, 0.16245792114308902, 0.1690032192106758, 0.15803969465196133, 0.07951419401381697, 0.12464370738182749, 0.09318445583007165, 0.146166023931333, 0.15874344403190271, 0.20041555006589207, 0.11978192254900932, 0.114006015339068, 0.15685411755527767, 0.1984767855278083, 0.13065744111580507, 0.11698576116136142, 0.05704583679991109, 0.07837412626083408, 0.15110385896904127, 0.10406607442668506, 0.14727035324488366, 0.23718074868832315, 0.10355753278625862, 0.10985052439251117, 0.178905582853726, 0.15452074419174874, 0.18468257571969712, 0.10660439929259674, 0.10490886920264789, 0.12369173632136413, 0.1519892793148756, 0.09831633831241302, 0.22395227423736028, 0.060950846544333866, 0.12437530606985092, 0.09886519171829734, 0.13248013545359882, 0.12440199963748455, 0.16173168511262961, 0.05732404972825732, 0.12236153627080576, 0.06741166021674871, 0.08383372758648225, 0.10283567330666951, 0.2362593524158001, 0.1064815233860697, 0.08489328037415232, 0.13368084388119833, 0.10433974795575653, 0.05528894678822585, 0.06025881546416453, 0.09798234980553389, 0.11700566937880856, 0.1435434046600546, 0.08875998681677238, 0.09300388409090893, 0.21343111379870347, 0.11321836510407073, 0.16975880866604193, 0.13093371343399796, 0.12857243871050222, 0.141922655914511, 0.19666926323303155, 0.1393321313496147, 0.10657842497208289, 0.11989834558750902, 0.21476322731801442, 0.1314107235521078, 0.15764444800359861, 0.12248671241104603, 0.07813563477247953, 0.10630998973335538, 0.07504381532115595, 0.08808217104524374, 0.1062623430043459, 0.06716580662344183, 0.16897721774876118, 0.11449521194611277, 0.09177183413079806, 0.05535903945565224, 0.08858964738569089, 0.05956208213631596, 0.07540949141340596, 0.18653223503913197, 0.09172310853110892, 0.0853735813871026, 0.11393585481813975, 0.11435083326484476, 0.07416260867778744, 0.13472886835890158, 0.21643231489828654, 0.21349860089165823, 0.16253462274159702, 0.168859722624932, 0.22168935995016778, 0.10405401007405349, 0.10466812497803143, 0.16604567505419254, 0.1272360911326749, 0.20159717808876718, 0.11093913204967976, 0.19672349175172194, 0.09171905767704759, 0.15138808371765272, 0.08163333351590804, 0.09159927589020558, 0.18458797436739716, 0.13162572415811674, 0.07710483829889979, 0.10948752851358481, 0.13991968839296273, 0.12534352125866072, 0.09803292102047376, 0.09092087657856089, 0.1672739048621484, 0.11932768406612532, 0.2378178116466318, 0.15265129879117012, 0.19209312807236398, 0.19059680907854012, 0.14094887673854828, 0.15658207929560117, 0.14178293198347092, 0.09108949931604521, 0.14708305043833597, 0.10161213217569248, 0.11062243940042597, 0.1578760998589652, 0.1598216633179358, 0.10548801241176468, 0.09828728344291449, 0.1044823353045753, 0.10920699499547482, 0.10414882177220923, 0.12362168436603886, 0.12210830700184618, 0.09737303892948798, 0.1848306456314666, 0.1952450182288885, 0.09815699114863362, 0.16294567925589426, 0.08696962467261724, 0.15848592642162526, 0.20952200570276805, 0.24993362437401498, 0.1481607404670545, 0.1203239227512053, 0.09990379812994174, 0.18855029317949498, 0.18399577614452156, 0.19456182846001216, 0.14837897089975222, 0.11241792448397193, 0.10340398709688868, 0.12301705538162164, 0.2155831554638488, 0.09757228395236389, 0.0820325156673789, 0.1889187784067222, 0.24635139373796328, 0.11955269984900951, 0.13692037362073148, 0.05972026900521346, 0.13577853489134992, 0.12513230687805585, 0.11371917823063475, 0.11146557344389812, 0.10992725313241992, 0.125082135998777, 0.1080257740936109, 0.08018290384539536, 0.08835218048521451, 0.12401173343615872], [0.027168331800826957, 0.031006896003548588, 0.04810318290921194, 0.04000233652602349, 0.012806599543962096, 0.03877468008015837, 0.06387121376714536, 0.0501548556743988, 0.029529189225286245, 0.05914780258068016, 0.034164482461554666, 0.05002260919926422, 0.0534759385378233, 0.02380495924236519, 0.0343374613938587, 0.06698978106890406, 0.09444269045655217, 0.08581335350338902, 0.0805912869317191, 0.058382727205753326, 0.07519070458199296, 0.038242060624595196, 0.06101236252912453, 0.024868898758930818, 0.03372266795486212, 0.002793352676755083, 0.02153784821608237, 0.051341844123921225, 0.02243251699422087, 0.014948033162259629, 0.007123358165180045, 0.013233690688918744, 0.022827838281435624, 0.0756847323583705, 0.02151124964335135, 0.05521954622651849, 0.03526300351534571, 0.003999392269179225, 0.030627398152968714, 0.014939020520874431, 0.07236205493765217, 0.0435199638429497, 0.014562913649050253, 0.029639006725379398, 0.02708781005016395, 0.10592093810971294, 0.02898769113900406, 0.018219350571078912, 0.009594608996329563, 0.022769813359315907, 0.0332891213973718, 0.06213551440409251, 0.048237617659781656, 0.013166647188232412, 0.0426061637699604, 0.04273168596306017, 0.016359078963952403, 0.043589907232671976, 0.0313768875785172, 0.06097902610365834, 0.05041453102603555, 0.04162815392815641, 0.04781483945303729, 0.05357804788010461, 0.017383246150399958, 0.00551988831388631, 0.02949370862916112, 0.07773951281394277, 0.01768545207700559, 0.020344462877671634, 0.002082742883690766, 0.0006891262611523935, 0.062007651265178404, 0.13392412582678453, 0.06923564377107791, 0.011021165260379868, 0.02012759630036141, 0.02434523426927626, 0.10961184969970159, 0.021396814712456295, 0.030661908444017172, 0.02708302977095757, 0.040769437327980995, 0.0609896858888013, 0.007607950063954506, 0.03797629542116608, 0.018402979110500643, 0.03313346885676895, 0.05882752048117774, 0.06153623227562223, 0.02324023999140731, 0.03194253472611308, 0.031285590691758056, 0.08519486883389098, 0.07416711415031127, 0.023424959275871515, 0.07289325286235128, 0.06295057745384318, 0.013666763120064778, 0.023559675618473972, 0.04947000688740185, 0.044553589807557206, 0.10897533635475806, 0.08354100757943732, 0.04310272926730769, 0.025494994895000542, 0.027701319361637746, 0.05051444870020662, 0.08003937333290066, 0.044600059278309345, 0.05285447849226849, 0.027021844571988498, 0.025478957719834786, 0.05714784096926451, 0.0322376669251493, 0.019613495761794702, 0.006084321307883198, 0.011336866400337644, 0.01570553608637835, 0.03935925156942435, 0.02348929287732712, 0.053341591996806006, 0.06153974708701883, 0.06985221497182335, 0.03542112931609154, 0.02578426624781319, 0.028729871580643312, 0.013697619500037814, 0.01873252321300762, 0.009283658449671097, 0.014883440021159393, 0.06563338278127567, 0.0031120062922127545, 0.04979340685531497, 0.023101359140127897, 0.053540769166180065, 0.049554857691483836, 0.032298395809318335, 0.04253177597586598, 0.033795695286244154, 0.042777093526508124, 0.06399729914431061, 0.08332107402384281, 0.05927930945264442, 0.034423954252685816, 0.029880405736288855, 0.04797648345785482, 0.02915216124217425, 0.07131959444710187, 0.013769415290361004, 0.007734609651379287, 0.0481987376032131, 0.012994565618490534, 0.055217402055859566, 0.07518108295542852, 0.022292986445661103, 0.027332340500184467, 0.03284956980496645, 0.022954585230244056, 0.050259811471083334, 0.011955422316012638, 0.01984649959818593, 0.013511824737569051, 0.012508975425069886, 0.0701096782992993, 0.06518697459250689, 0.06538507967655148, 0.03684713172593287, 0.021579196443781257, 0.032194159259753566, 0.05029016912781766, 0.03152241298396673, 0.020552518677764704, 0.07257634986724172, 0.043559264591229815, 0.05926524342170783, 0.04772191747490849, 0.03654291394299694, 0.01003683656121471, 0.02285543769331915, 0.046760277290429385, 0.07279894328010933, 0.09060091339051723, 0.05264034301840833, 0.039227873619113646, 0.03272301623863833, 0.02898729419601815, 0.07133216091564723, 0.035166400484740734, 0.039273430460265706, 0.06636019556650094, 0.04379294865897723, 0.04883113224059343, 0.05552640011800187, 0.07707055192440748, 0.006635133135465107, 0.04758679061861975, 0.02791180770977267, 0.07508010337395327, 0.013875726460745292, 0.04941314226016402, 0.041740471829793284, 0.028648355776177983, 0.07132629158773593, 0.035537165589630604, 0.027740749031571404, 0.026000535714307, 0.005944323418329337, 0.03282068117654749, 0.028480828872748783, 0.039368815520512204, 0.03163455446649875, 0.017491905051948767, 0.04167129857731717, 0.07761344779282808, 0.01637742485451911, 0.0358749335365636, 0.013252357187281762, 0.013109438204472619, 0.022549974798624004, 0.020446801225521734, 0.004359943301616502, 0.04380654989342604, 0.036534072631703954, 0.035408569632896354, 0.031827506077076705, 0.06380101253411599, 0.01701169733756355, 0.025791859054671865, 0.05086158382307206, 0.025280090980231762, 0.029215085187128613, 0.04066137384091105, 0.018564534905765737, 0.07668594470513718, 0.013668855552428534, 0.04994683719373175, 0.059909057803452015, 0.02585322067274579, 0.07031123712658882, 0.0263701049012265, 0.005150953133124858, 0.05789493516619716, 0.04076003961797271, 0.018239097636459128, 0.03252643107303551, 0.013670674026278513, 0.012504364779618169, 0.012776491248847117, 0.07285048480012588, 0.06547702795692853, 0.028570561736289943, 0.0487880758009851, 0.04974599761356201, 0.06013089804244893, 0.007233516629120069, 0.03815665002912283, 0.025692692858033946, 0.04752610244655183, 0.05537501216999122, 0.007870506644914193, 0.007139662513509393, 0.020952382756929313, 0.043833684508821795, 0.05866495706140995, 0.04978103716192501, 0.03899524128064513, 0.003992913532004292, 0.04652152117341757, 0.024971220143405453, 0.09943740029952355, 0.01774082562353994, 0.05878339534891503, 0.023874787281134298, 0.03401461782466088, 0.06609758894358363, 0.06560926086136273, 0.07039724144020251, 0.023370486484574418, 0.05315782775038055, 0.020915477237265025, 0.03205001467306699, 0.03470289660617709, 0.02623945807239839, 0.016322792607492635, 0.03438808010624988, 0.016829502203368714, 0.015212376834824681, 0.07079288842422621, 0.027176012817238058, 0.06167094861822469, 0.006914190415825162, 0.034605024715087244, 0.04217378090002707, 0.0234094293056322, 0.03347983044971313, 0.046995172543185096, 0.044815310942275186, 0.04182060681549566, 0.021308330353349447, 0.04166920190410955, 0.02958475106528827, 0.03497930123869862, 0.026115874793114405, 0.025081139423751404, 0.012119853403419256, 0.006467000215447375, 0.024775790183671882, 0.05024727214393871, 0.022576471591102223, 0.016375065248991762, 0.046718710235186985, 0.028315067856705615, 0.031906100788286755, 0.05801077466458082, 0.012270474606858832, 0.0299192891855325, 0.03304075383182083, 0.06816600795303072, 0.0800513494759798, 0.023839354182460477, 0.0634254434012941, 0.05811988988092967, 0.03666883647175772, 0.08689299771296126, 0.017392062016629746, 0.019362600653299263, 0.04642150511166879, 0.02024267244684909, 0.019429024142612304, 0.019535243710769073, 0.02524180124912943, 0.037912916857749224, 0.00576581442562331, 0.11064407788217068, 0.10014958386974675, 0.04420359805226326, 0.031866453987147124, 0.026562861432986598, 0.04673811972939542, 0.017258726492790238, 0.08663100177156073, 0.02508986708042877, 0.050642851274460554, 0.029499554208346775, 0.053238305396267345, 0.03726607281714678, 0.023774779701073254, 0.0296254495957068, 0.021659209293180277, 0.012361143000556954, 0.04495975747704506, 0.1468903464930398, 0.10251957776823215, 0.11749721371701785, 0.1342653746583632, 0.13708814818944248, 0.10776062296437365, 0.1624558719673327, 0.11348454082118613, 0.18865865522197314, 0.1186234461409705, 0.16469043706144604, 0.20425438907529625, 0.16539736198527472, 0.12370979892356054, 0.17434468758957727, 0.15021834362830433, 0.22651601023972034, 0.19167221922959599, 0.20305297497127736, 0.11935910023748875, 0.10588922338294131, 0.11926700946475778, 0.16333190138850892, 0.11849592226956572, 0.14785265842718737, 0.09599715311612401, 0.08241280740393059, 0.10577672227684941, 0.10339254699647427, 0.15932869405618735, 0.07285449494208608, 0.06411089947713272, 0.12266284653118678, 0.23102051924381936, 0.08783527929335833, 0.11894011843417372, 0.11321012768894434, 0.09015641188515083, 0.16296444753451006, 0.18171360503349984, 0.21171454233782633, 0.13341234757431916, 0.13839971566838877, 0.10216283119682755, 0.1790742530886616, 0.17455846683255263, 0.10073684235768658, 0.07295328964080129, 0.07630202280623571, 0.07386023311742715, 0.14567251184156962, 0.13383018943880284, 0.13840850948223046, 0.10755814132945878, 0.1270570121705532, 0.12002497379268919, 0.08499263825693301, 0.09521917879049267, 0.1173841833536114, 0.14129586597638472, 0.12531324502612862, 0.17840478329786233, 0.14595470098512514, 0.20583585064326013, 0.06597440769629818, 0.09303475743425743, 0.1734831923885005, 0.11052616206662995, 0.09095423336007766, 0.11240863533956663, 0.08741729493652071, 0.15862242052597658, 0.14935272293431417, 0.2683715650013515, 0.15634673620973313, 0.12562975447092736, 0.12701079036508287, 0.09279976718659912, 0.21214651130139828, 0.07892515776412827, 0.16962228742028984, 0.0753805043974093, 0.1354530280722039, 0.15226948713617666, 0.15562898186700685, 0.10399096738547087, 0.13038034098488943, 0.1838333077196564, 0.21824989308203968, 0.1319414329315935, 0.15212646552494594, 0.10769813667450633, 0.1268591242177146, 0.2620952789272581, 0.22627511673739978, 0.14476497125412735, 0.187643417556371, 0.17147372450147355, 0.1320248655974865, 0.13711462462587015, 0.11908624773578984, 0.11343062442860433, 0.20764010239924702, 0.22362705240292208, 0.07736728207341262, 0.08450051037860767, 0.16477325904582227, 0.1699137317814997, 0.2787752167454788, 0.1302220251943384, 0.16912386273699148, 0.09238501944180046, 0.11299682342048202, 0.1829558126628399, 0.18170833960175514, 0.09729818973158087, 0.17002696570541176, 0.11260320525616407, 0.06382746182914291, 0.17978699984295027, 0.12249759611274515, 0.19563894851931504, 0.114004413996424, 0.2362672777048179, 0.10276256794376032, 0.06535658799111843, 0.07555567499782358, 0.10658075234719686, 0.10211192071437836, 0.10333699533449751, 0.12196787739438669, 0.14373884988682611, 0.17057337638522896, 0.1445989201643637, 0.14323438624186174, 0.14482747790004524, 0.14826493630451815, 0.070343372545072, 0.1217934260410922, 0.0830268408837063, 0.11640545087201254, 0.14623276463576726, 0.13492858835629054, 0.09788481718195335, 0.14947614845420631, 0.17275421507656574, 0.16271404097122805, 0.1459989957511425, 0.281094775136028, 0.07942183182707854, 0.1270964757672378, 0.18347850175840513, 0.0859944409291659, 0.10537275645349707, 0.10393660994512693, 0.12495389288025242, 0.18228907058281557, 0.07142892679465668, 0.1777408096407141, 0.2025205014007432, 0.17370698680835112, 0.1061841214873961, 0.15879267853285584, 0.12306494638323784, 0.14154292057667459, 0.12606443757457392, 0.06953146468315806, 0.14608983801943914, 0.1036858641143356, 0.09552167648715632, 0.1499192589627845, 0.18035501507776125, 0.09341407208038227, 0.13369776654456342, 0.16987610022936547, 0.16055374832025596], [0.011886212592279273, 0.04600327987489956, 0.011557816910291356, 0.026475160781826292, 0.019558914404894625, 0.027439433682177748, 0.006744626211002469, 0.01955820363946259, 0.04080983391031623, 0.0801553213968873, 0.035982691682875156, 0.07337780828986849, 0.0359559099056891, 0.019137332116120627, 0.043663012595581155, 0.0286654684293483, 0.006063469926760132, 0.00494945961483089, 0.018881441293550388, 0.07696314661630563, 0.05268759619710701, 0.012445682526699134, 0.015213784794988377, 0.015765954540776353, 0.066205632074603, 0.029898322453456264, 0.0383621477521956, 0.024914458992757967, 0.01452967052214912, 0.03873908752575517, 0.043831940673823865, 0.02871359691822103, 0.015302964652489339, 0.05721016441072736, 0.03799713323158877, 0.029418845860553638, 0.019074608338996768, 0.030997712032071183, 0.010938508668914437, 0.05744496466858046, 0.019618876544492583, 0.02175122033804655, 0.053560317760067325, 0.06413025808121477, 0.12317910311477524, 0.0382520995501961, 0.008532278455926903, 0.012468801911122032, 0.056426958580102236, 0.025175547393571054, 0.03077926446816751, 0.049655094277113676, 0.021981372631021907, 0.014786540131483759, 0.04195545547242675, 0.024834697201315845, 0.009418935431832713, 0.028470888334725584, 0.07926158899707453, 0.049856106883713176, 0.0326457175293139, 0.008381483377888799, 0.021024310861581137, 0.006232004878776414, 0.03488195860492332, 0.024495343178776757, 0.07807415949978999, 0.025365057135266916, 0.01900194911286235, 0.021505387100790228, 0.023685202900586382, 0.038590135518461466, 0.02417075747091855, 0.060859848212982924, 0.06925669871270657, 0.019005575882537023, 0.020784774429297874, 0.02179251767561904, 0.052189164728458436, 0.049564866083008904, 0.039574058792952976, 0.048909462323146205, 0.04630199473883424, 0.03776318792785917, 0.040788147931120226, 0.03744500928691455, 0.0532742745376059, 0.03365890262648463, 0.030207483364003043, 0.08218924368598632, 0.04045018320903182, 0.11958402102547032, 0.07229044235178403, 0.044700652094823976, 0.006820493635521936, 0.061369611216442924, 0.09331883290516478, 0.009892742016485758, 0.010478695172683468, 0.013799593983484166, 0.024680176117856587, 0.08311638036476714, 0.012968417423378144, 0.003456026939342597, 0.027080341075946177, 0.06261610718710081, 0.061219688904072554, 0.03300579910033515, 0.02735938860236534, 0.04189977828147156, 0.01702296101887311, 0.018311661867690936, 0.036658610949026685, 0.10004983243665524, 0.017809868258024966, 0.017310069541313818, 0.0099484717939049, 0.04162250512412616, 0.06961148431790726, 0.012572614376300147, 0.07286687820617642, 0.04530588158273271, 0.034986490317221196, 0.07082411460578442, 0.01696482583481286, 0.04612305826906647, 0.059180901518889835, 0.07558529305138759, 0.011688749571996076, 0.010446548728006226, 0.018157268009547676, 0.047449054795184305, 0.03478389333135315, 0.046370713372847865, 0.01500913015167628, 0.04152588513014572, 0.037696565967053175, 0.06930159058954034, 0.016547601437196136, 0.036945251282304525, 0.02484966398748968, 0.028510090695427995, 0.03908824468297618, 0.05682241218164563, 0.055449657807392735, 0.0524462718250496, 0.05686895968392491, 0.01804754211168204, 0.031530585938266346, 0.0476403304242662, 0.015247080508353454, 0.051337128305541616, 0.017531290617106215, 0.03136714042297431, 0.046385732745485644, 0.03898489362161074, 0.013888504123315215, 0.003065456881553733, 0.0185212782983269, 0.009275564375067396, 0.02109794208912977, 0.10291103819119078, 0.02434568040605102, 0.042974146881273816, 0.04785895440727472, 0.030310444267732755, 0.02381388028152287, 0.01849819453699248, 0.05789329989680222, 0.05448464869654604, 0.019562507247818366, 0.02531784466866936, 0.05096307909116149, 0.03285235858389309, 0.028682615009269545, 0.031109928153455257, 0.046190613215523105, 0.037588000364069424, 0.0544443063970123, 0.021833455389631645, 0.025961384243730987, 0.012761837436950632, 0.033182971379054446, 0.014582765887358358, 0.03558959938319666, 0.03647284163162112, 0.01676507869602314, 0.07334686709301812, 0.05390789732336998, 0.03886357834562659, 0.01724113547243178, 0.11163042352667876, 0.005598195919966591, 0.03322009742259979, 0.030137187136071067, 0.03142552836132901, 0.018147022130766084, 0.10598571106259312, 0.05171160838965859, 0.031727744465959926, 0.03619868295001132, 0.0659050749880927, 0.0052757573513580215, 0.04676165132384215, 0.02523113807131137, 0.06597319311861481, 0.04997112196204918, 0.010191643477550574, 0.03635485117722835, 0.017981551188443388, 0.07166730293205806, 0.02078482531942427, 0.04604166799357959, 0.016819090083507553, 0.01889648611125137, 0.04215372679755092, 0.01785378813344453, 0.006351822288706899, 0.05299348317618881, 0.07445060608110257, 0.050031189274575026, 0.019710336279656206, 0.018328886479139328, 0.01611563586629927, 0.035434689838439226, 0.04606995272583195, 0.016515119965853434, 0.06991259101778269, 0.005581665110574769, 0.0208189742905753, 0.07029739501220839, 0.031008188612759113, 0.040216987686497827, 0.03073534628908549, 0.015364694375810879, 0.05992378879870687, 0.0510868710199637, 0.08276679912315947, 0.002926581543371347, 0.03497980335461242, 0.02427885658107698, 0.0331718467974237, 0.05007083607571466, 0.06203646186207022, 0.01561586429098887, 0.018985296167167168, 0.03102513841752495, 0.04166662686371377, 0.015319643043247717, 0.03932201696027603, 0.04990103268729789, 0.029510315773742538, 0.0027990345593674904, 0.047370151350540776, 0.0816535810008645, 0.039395512480820925, 0.03359539174873914, 0.01879594079218805, 0.02641649803678904, 0.057192095023180754, 0.05391695576586893, 0.046967128690864356, 0.002826117436468069, 0.023126809292339852, 0.0064277749541880825, 0.0627249577747924, 0.08978141950709478, 0.020022428461483548, 0.03853819027010884, 0.007949319335498979, 0.04213809674339635, 0.02285781765489706, 0.031239423169089214, 0.08201387631041662, 0.004179659091667938, 0.03152546978422573, 0.03716496431401797, 0.019108572409355214, 0.025559716957754323, 0.008801573737790542, 0.03158918422247682, 0.05905951838940382, 0.03746026275413377, 0.07446007164461271, 0.0322160318360797, 0.02723092326362218, 0.009432545147969254, 0.024733397012044276, 0.004800856628987406, 0.06673610396683216, 0.07554799398141247, 0.041105776958699734, 0.03299874233614121, 0.02034505150680031, 0.03435867239854165, 0.0322139215921717, 0.005349139217287302, 0.04269263966541205, 0.03823481387059603, 0.08657671218471867, 0.017915480537340045, 0.025958632784230367, 0.05845651110368116, 0.03113604835899813, 0.030832553215857064, 0.030092916118779352, 0.04906016834346311, 0.0498656844055014, 0.04471929484446134, 0.07359631013657365, 0.0161175289790013, 0.04002948471211961, 0.02077964979356953, 0.09982886750783239, 0.03994386037811637, 0.04664758958720735, 0.022895467866744314, 0.05475520096453173, 0.029049427647675787, 0.008941043218198632, 0.03150312562606164, 0.028960020480943576, 0.026005368579977324, 0.01954968293596591, 0.028944963788879768, 0.0054580712291811195, 0.03625296914417829, 0.05966801502342735, 0.02512557668212269, 0.06508563538747174, 0.0320514158478805, 0.03490093383671982, 0.13029122219554015, 0.0585282797526036, 0.022675536007487347, 0.058656882494688034, 0.05104045922468815, 0.08273671966578279, 0.023680860276467035, 0.01789610496988254, 0.0787243317546589, 0.02182595418500049, 0.05156568264854806, 0.023676261505378143, 0.031554059857236486, 0.037063930449741225, 0.0382346781635923, 0.012920409374471222, 0.04772007525233286, 0.016808630466195087, 0.009598896489478648, 0.0143231702635863, 0.13451451914651052, 0.18224203453532287, 0.11380916554480791, 0.07326266089720385, 0.11424009634980134, 0.09732333623937198, 0.1545355905379568, 0.07851216742502791, 0.09331775403448514, 0.16285783611238003, 0.07763239927589893, 0.14888583655868257, 0.09312663107578244, 0.15459042973816395, 0.13943201170435973, 0.11458298723612513, 0.07099824704762016, 0.16098354597176823, 0.11873099394142628, 0.17733568352247986, 0.1057873209938407, 0.11829867213964462, 0.1513857359864882, 0.07032948971859046, 0.11317240114190749, 0.18057019210287503, 0.2564416437276772, 0.07929867772119385, 0.10250018523739916, 0.10940626037440129, 0.09461910277605057, 0.09704401729894535, 0.10582424686955554, 0.1008597861177155, 0.16852907251034463, 0.0855239447472351, 0.15733074769377708, 0.06983414558427674, 0.0645651515307171, 0.2019184779907976, 0.11261570387120758, 0.07753776399684803, 0.0999560724677784, 0.2902047320136002, 0.3163473292120865, 0.122959434187838, 0.07613267403628145, 0.10128855239599943, 0.17787933935012135, 0.1755807748330491, 0.0721034516713449, 0.17404489724763803, 0.09134834685495921, 0.07971240087811436, 0.09207929870379822, 0.09497263309146677, 0.13417910571609223, 0.13224442595882074, 0.29346026160887306, 0.12764105440250464, 0.1180688523288284, 0.2075170161468642, 0.14921257831156254, 0.1461587364652327, 0.12182743421622685, 0.14083770556109293, 0.1806818111134427, 0.17215744352766446, 0.08959277998656034, 0.1360281000712088, 0.12562991731933185, 0.1538261550345591, 0.09842973508472953, 0.11138790832566363, 0.18279457917170866, 0.0858839957841805, 0.09280043215091739, 0.12661192033972057, 0.23688007625085966, 0.11973186023533344, 0.20290482363530568, 0.11545200060520854, 0.12054022614445005, 0.08877616309161697, 0.17438206129840442, 0.16568331021283353, 0.11629436111875943, 0.10393612139991351, 0.07929696781294686, 0.15471838787198067, 0.10778661085558788, 0.20927643030881882, 0.17299346652414116, 0.1713356969079801, 0.07202841248363256, 0.10554404583360467, 0.14736376037555082, 0.12231467664241791, 0.06207530799188784, 0.12468418878104005, 0.2294281061206545, 0.1815147671316351, 0.06525548627333981, 0.06546104845723935, 0.16349780320056848, 0.1486419846436807, 0.12412248392190252, 0.11297667771577835, 0.11056315579584666, 0.2573427382324423, 0.06633637898734637, 0.13275477928774698, 0.11566493846476078, 0.22789537693772996, 0.1772355724658285, 0.06936653996152536, 0.1061967218826924, 0.1450633095311267, 0.15525415912270546, 0.08113845757075719, 0.15578770477856907, 0.13711511317108357, 0.1841921577496188, 0.1525935283196824, 0.10403665993362665, 0.05425879831558891, 0.2807590631502015, 0.10235223067658288, 0.06465435174426862, 0.14327823317476682, 0.10327847847448927, 0.13123057250465664, 0.09487652539142541, 0.27842444128223826, 0.09944288286247424, 0.11215261050633021, 0.1417434819574867, 0.17197951807507447, 0.2728762775659561, 0.08039103767701558, 0.13574713229068688, 0.08563513628074101, 0.11236628118370261, 0.09368431900760957, 0.13256092183291912, 0.11797214751797062, 0.09605227051568882, 0.1171534543058702, 0.07418369076081685, 0.08928174631936209, 0.10322581058634178, 0.11136645983372416, 0.1148680533681597, 0.12839428255600588, 0.11551078887922422, 0.0907611765765718, 0.19722954316862992, 0.11731073872319289, 0.09698943594204527, 0.1744799739015954, 0.1761278369064842, 0.11069109357361283, 0.09895640718085424, 0.1673464538263423, 0.21403705914105686, 0.07506328249084097, 0.10953592163111482, 0.12623692117631435, 0.22250577328460558, 0.13925232206072125, 0.10314338893762656, 0.12096463622791426, 0.14414187254650251, 0.18053642820034707, 0.12689672862844809, 0.06912407225796155], [0.012377942679449916, 0.03147978062874504, 0.033765666718993864, 0.05203535780310631, 0.0018254212003999523, 0.031420615767793994, 0.0342338932012873, 0.02359212825207838, 0.08909372426569462, 0.025908075139990876, 0.025441064931718365, 0.05939712348793234, 0.031338716591043134, 0.05817658148173775, 0.03112025206376399, 0.024928491096943617, 0.03242664571319308, 0.018743054076497043, 0.052869579289108515, 0.018344058522156308, 0.1187428275921515, 0.03965464161176767, 0.030213970158781325, 0.026884290256670544, 0.02649883826130203, 0.023567017367375747, 0.027194674226588438, 0.018225279270804355, 0.01863341129917119, 0.03871993926752891, 0.023530856539894427, 0.055904937841530354, 0.04024336234267269, 0.021054816099682024, 0.009478236847956265, 0.016491902193852832, 0.044228635994451385, 0.02355994194346879, 0.06758417095988989, 0.030472441110759974, 0.015367995448676603, 0.0375202893545585, 0.005615795846097171, 0.06899805473429815, 0.04041121155023575, 0.05432259078536715, 0.02796506761972393, 0.05382765377206462, 0.04907764062019331, 0.03032953485048243, 0.03417792084759899, 0.046190131455659866, 0.028852886586849178, 0.030193115384983163, 0.03656388067507318, 0.04567810893058777, 0.03714893053152731, 0.060281899225498946, 0.015168312770713652, 0.008826018810006124, 0.032563088927417994, 0.06589108359600816, 0.03324994957074523, 0.013951938665871109, 0.05967412183859518, 0.07084854186645576, 0.024202550229217325, 0.04293351620435715, 0.0256329749910427, 0.023804156874705638, 0.017079282818096023, 0.024527604126238396, 0.03776274688009705, 0.055725533182599714, 0.00808665482327342, 0.09510718658566475, 0.06991474875914198, 0.009590905043296516, 0.019279987318441272, 0.027300642736788307, 0.007623575029096433, 0.039643591668988974, 0.07405154606593506, 0.0063927527932849315, 0.013182482499230121, 0.07215985828744513, 0.008366895723156631, 0.018921610566654375, 0.04118013421871832, 0.03058831114321947, 0.060581648855337074, 0.032117922457733324, 0.046733044287455935, 0.07096792331763677, 0.04503084419827376, 0.04372363969949739, 0.020520098274573684, 0.030198428314179182, 0.016777633290205683, 0.036486334300466945, 0.016388242399053912, 0.07107487400727612, 0.02004218570488904, 0.06365554819681815, 0.0716830992272922, 0.011276947517347122, 0.023900627590981976, 0.0020103056657327606, 0.03707512627754893, 0.0653104679659009, 0.02607935094939811, 0.03297496307641268, 0.021280671569651792, 0.012128799887640136, 0.034812493582389185, 0.024889493993084346, 0.03910769149661064, 0.027362421653898697, 0.037278771600020785, 0.011025641046996628, 0.007625527513612593, 0.0044694418902508914, 0.013345915291990553, 0.012485647391128753, 0.04312135844624468, 0.02837186463044158, 0.03810718482626336, 0.10399554749684674, 0.04673453027914677, 0.04377643311662333, 0.04170426180852311, 0.05391103554783123, 0.007835870824887283, 0.01488513296603092, 0.06931107650910105, 0.039807827677577734, 0.011388522423138576, 0.03688500755067382, 0.018693169878263558, 0.033779424016496966, 0.06188594922423363, 0.03072496809597526, 0.07512719370424747, 0.07227266473429543, 0.06162554784012692, 0.020541049739612, 0.04275278500946505, 0.03972729914156454, 0.03007025644183159, 0.0581170671752521, 0.06340328923293523, 0.014804673979857137, 0.033707679116300175, 0.02827785869262048, 0.04022191045805812, 0.014655401364767125, 0.01456090179271996, 0.013393931822585208, 0.025952144293114543, 0.03827265576858606, 0.05148863838985562, 0.014283818625179785, 0.056571571355951686, 0.029769360087811947, 0.05091589715863977, 0.039139016065746546, 0.027928620111197233, 0.03881481203383633, 0.02991995754252587, 0.037538131432873864, 0.051086731920284886, 0.02502066668655191, 0.0371449203895671, 0.02966599545574614, 0.013779207398848874, 0.04251186436574374, 0.024401113324399506, 0.02234024810604751, 0.07745031440364462, 0.08434368736509766, 0.0236669961096985, 0.0200623381949429, 0.02217855830011623, 0.03614461388705032, 0.08456676932317869, 0.029129504957901578, 0.028793928679078817, 0.06575052506689515, 0.07101270662886755, 0.08015364541539124, 0.015971396284710084, 0.02934273798018694, 0.04093310675982918, 0.015321882208809257, 0.04531370509149773, 0.047444790202592096, 0.061383195487516265, 0.02483729599043727, 0.041028233976768594, 0.014626081866611327, 0.06779174160744462, 0.031182612824652876, 0.015974242739113312, 0.04258784671713199, 0.04282086582056113, 0.05308136363912906, 0.04732493716957314, 0.042136698961257935, 0.013680994543912155, 0.012440254246549947, 0.033255628908851316, 0.048853238911501, 0.04148119342114244, 0.051588406786322594, 0.03838668018579483, 0.030296456268323318, 0.04512856002630932, 0.015016863754551326, 0.0439340364454048, 0.007871713589078613, 0.024436090108273283, 0.05691686764891658, 0.031531573206718476, 0.04137525035600577, 0.017287494681243385, 0.045190880075097084, 0.01644363290896373, 0.024267440229388218, 0.018900418221684437, 0.01576540492741125, 0.011467722726852765, 0.026021073272983943, 0.010466217761859298, 0.017636472026684454, 0.04262530185016138, 0.05073576307456408, 0.007931696932895907, 0.022971048186134015, 0.03438761191708701, 0.005749934161680618, 0.0491977820305952, 0.019005619987313236, 0.024735697245757495, 0.04442115334261741, 0.026143416529521346, 0.020555734933753098, 0.037290069208081277, 0.04777842926393662, 0.04398898081853986, 0.07804874836334161, 0.049210541881620884, 0.020027290164892162, 0.03623087604397109, 0.03046486187460167, 0.005590571730863303, 0.019170388645891632, 0.061842434773487706, 0.07808408646711282, 0.09294576078121151, 0.07638579473963805, 0.040502722175525765, 0.05344939085521868, 0.04456958966329694, 0.07530578412115574, 0.01819513365626335, 0.060604359422411234, 0.04100551323166915, 0.015465329600764173, 0.052030862508607764, 0.006776797676658524, 0.05149214302322694, 0.05499939553971801, 0.014819474524951406, 0.045972335285374095, 0.009675238464426781, 0.06207771000585385, 0.044317910846854956, 0.08048090285488538, 0.04344960993954113, 0.042665596652243815, 0.04276829292731626, 0.04660361712532384, 0.013672680793596166, 0.034093986065792184, 0.06409306757684265, 0.0189782275286104, 0.043746971126113615, 0.0260221233059253, 0.02325530007614621, 0.019417621361623918, 0.03034371623237218, 0.09609517428491797, 0.051107172787721665, 0.029975088512791053, 0.05481598073882716, 0.032376647860343964, 0.01403780557614352, 0.007222412403539887, 0.04734742382009115, 0.02615655296748238, 0.015610927948728204, 0.009888398544197636, 0.024600378703325987, 0.05779073932873351, 0.06777632529182093, 0.007424465713224241, 0.0176853469040777, 0.046556330019874234, 0.052589710735316784, 0.017416289109470587, 0.00244553541415371, 0.07194366345980338, 0.01849920385783272, 0.018233759262199913, 0.02805052062363497, 0.028727452603301833, 0.01885050518571266, 0.07238040930990662, 0.07353902142494917, 0.050219930575362275, 0.040830946527421474, 0.00593698421393388, 0.024927295178973248, 0.023095511864604693, 0.02484818478114903, 0.04281918305371489, 0.014189397084659763, 0.028315016966579214, 0.027774370441745435, 0.009032128910933222, 0.017286283496235098, 0.028460038559777395, 0.03533782896452716, 0.03161426966211625, 0.019409986146326576, 0.04840902578351753, 0.05630921918366637, 0.020841552543320825, 0.01870468631386757, 0.07882474815206868, 0.11324267022843872, 0.0879885128566197, 0.05911603357110705, 0.010761623071240527, 0.05837421837661948, 0.02379553099828107, 0.03503921927352037, 0.023239215403529148, 0.04073125955515674, 0.02832014499498265, 0.018526899960956404, 0.05451450084469148, 0.07433439338845865, 0.1902745592274836, 0.1013289320149592, 0.21242690911250456, 0.12139190972915717, 0.1625359390995332, 0.10910279237266098, 0.08728746404605252, 0.3192246976707663, 0.15377719194761344, 0.12302306720188685, 0.19256394995110376, 0.17268435311104569, 0.14668017705636366, 0.11072573957166501, 0.1411374687616314, 0.1499275913728135, 0.0560057240405253, 0.18076723867229053, 0.13436250016093254, 0.27222507393785883, 0.14620109062109674, 0.2066447322389909, 0.1117626903578639, 0.17344410877142633, 0.0924378569637026, 0.0957455930433103, 0.08762249749686037, 0.096953331093703, 0.1048514312133193, 0.15836164594760962, 0.14335189493639128, 0.12442398417208876, 0.12227875499853066, 0.11749813652464322, 0.07278633609946285, 0.16557862583015645, 0.22997364827564784, 0.15422499791852065, 0.10548803276781525, 0.15775384141930512, 0.12714998503880842, 0.16140210708337172, 0.1597227193415165, 0.0881611118093133, 0.21619549260607787, 0.09509566506104809, 0.15790223702788353, 0.12313195850167956, 0.1935803818383387, 0.05001994255664093, 0.10559555342687027, 0.12653467591319764, 0.11622261282588754, 0.15156201938433306, 0.14931464354906762, 0.10817469217415367, 0.1426851935684681, 0.20886310748755932, 0.10905884365950312, 0.059445577673614025, 0.09672228313450303, 0.17353287472256593, 0.08761114560599838, 0.12136258344565119, 0.14339327200182847, 0.1343716468129839, 0.1258880863232272, 0.10531165437506777, 0.08302232862583228, 0.12751066711332115, 0.09259562992623874, 0.1509218080235379, 0.1726513220263379, 0.1288812942802906, 0.11172311141022614, 0.15572331180529936, 0.11556410816098962, 0.07723808222051178, 0.11657049772994858, 0.18362015272889817, 0.13110010379127093, 0.18459499041948998, 0.20362564495631627, 0.09027417842298746, 0.15212725262556756, 0.10662670273865972, 0.10293676823909793, 0.0781358519036855, 0.14736088338707173, 0.1129578755104116, 0.1325599176010915, 0.14902446126299246, 0.11680240742862225, 0.22340784487979753, 0.07486906541245324, 0.12157109725688185, 0.08271083355482135, 0.1018105765272464, 0.1543285830744675, 0.1190536373427936, 0.1978635120072535, 0.0944777639316661, 0.0731393371575645, 0.11900415856923376, 0.1978005032454218, 0.06488440225699119, 0.094073078861194, 0.08800014973218952, 0.12503212796790258, 0.2142264654061624, 0.17633363657764026, 0.1560740058443376, 0.16327417162912233, 0.1209119004862649, 0.14679839142731257, 0.1052185661558594, 0.15565806387790612, 0.1389094583157982, 0.10701813602021762, 0.1311244224863393, 0.10070597579968826, 0.0960818546425019, 0.10863454892699208, 0.08922850167644875, 0.09473315772733518, 0.1533378405230386, 0.15489821322262287, 0.12151576951146126, 0.19737667670207365, 0.16377943594540867, 0.1901390693549599, 0.14621759259275027, 0.13769773047949585, 0.1863231241170849, 0.1579604417617832, 0.10234050559146063, 0.07298448189560856, 0.2096699806196349, 0.1346806109483753, 0.11885996987777096, 0.19710960531873362, 0.14335230205740246, 0.10290020877229315, 0.14957825440381253, 0.07304539398423263, 0.12393378333321639, 0.09323089476674795, 0.126974081620574, 0.1354867105505296, 0.20555583281176432, 0.15164045803248882, 0.16434337997010776, 0.13580760333154882, 0.12158073245414666, 0.15110160623277935, 0.18432592414319515, 0.08766626979091338, 0.16547320862965925, 0.13601020031741687, 0.2529301164405686, 0.07026110017406088, 0.07906225576464619, 0.16064859394516262, 0.1468453731920038, 0.12927115336060524, 0.12383397083197321, 0.07687533061419215, 0.10527075228414365, 0.07809009828737803, 0.11301201581954956, 0.09068001700299126, 0.1219070806567158, 0.1361835795853819, 0.11399815790355206, 0.1477731205523014], [0.055692929574953656, 0.03607451104159866, 0.05118567928937929, 0.05958372740341084, 0.009560579616975571, 0.11304575936602694, 0.03262006890560899, 0.05121712938749364, 0.03715496610051819, 0.02990105694958142, 0.02044986141845584, 0.016355628613382578, 0.024205350882506797, 0.04771775466256908, 0.05600190388837031, 0.05213448159130556, 0.043777169327118566, 0.05092695727944374, 0.05430275381409696, 0.025270464264654686, 0.05760148912668228, 0.025361620355397463, 0.028100264025852084, 0.07816844872598137, 0.02239048683882824, 0.04738674831709691, 0.0495928285111274, 0.03507545643619128, 0.06941186610077109, 0.04939197196758219, 0.07115792669355869, 0.04118221392855048, 0.04961718452562179, 0.10372318354036127, 0.020511236607230136, 0.09189183304884604, 0.035408756230026484, 0.028691184906555072, 0.01903545347574566, 0.07359880036009209, 0.016459556429513862, 0.006853077735286206, 0.03405156744910138, 0.008192366338334978, 0.05059036998344319, 0.01442054343143744, 0.024758289069203392, 0.017910676509408013, 0.025862177334991947, 0.01989217009395361, 0.021111058171040246, 0.04476538094292794, 0.03838231381294983, 0.05514688869672162, 0.026758571288415363, 0.07494922753955637, 0.0510316993375974, 0.024350530235096812, 0.030515989488256828, 0.021740767506084273, 0.04963926066245351, 0.07047250454447099, 0.04469577682071498, 0.05704540932284934, 0.012218457264160472, 0.05291200129847441, 0.04673854381378208, 0.030604148150554726, 0.05276725281562124, 0.045179976017347405, 0.05964166750865323, 0.043539020498948436, 0.03067375227276768, 0.09531872666307858, 0.03749246941879392, 0.05487672997904675, 0.07625104447028466, 0.055121694691479206, 0.04789668434698667, 0.027399735990911722, 0.019642732139410715, 0.07588555158248969, 0.05491893485720668, 0.06999037148697035, 0.04117145236315472, 0.02137102698907256, 0.05031887794445668, 0.012959350499191453, 0.036553641581641774, 0.05355319653504661, 0.0462838948172118, 0.03094666584261826, 0.028360597556456923, 0.08578135379190956, 0.02466354861722461, 0.012709849780159337, 0.010392197224843715, 0.03222957878772702, 0.062263085772948604, 0.04294873235215034, 0.014922642381861806, 0.05414237527708922, 0.07468631557588067, 0.029726259543427398, 0.011661765930641974, 0.15256006297256264, 0.0036263031818504843, 0.051259887271693776, 0.0489000781838383, 0.03165947027238352, 0.05008851530562554, 0.024692849455667392, 0.03713585855439305, 0.05302509951538273, 0.03629573042105351, 0.05419678021488445, 0.02936528230618153, 0.04770917797993336, 0.010385227822033423, 0.05656992590853146, 0.07768121987049069, 0.018043718566851955, 0.046411286374287944, 0.03443774547693985, 0.022393009292760065, 0.053734935354441404, 0.028342482367796556, 0.052487313015652556, 0.042972515004553964, 0.0516183742854212, 0.03972097519519074, 0.031286798484091244, 0.07372456004044839, 0.051343655812421014, 0.050241779402962754, 0.06625162996351719, 0.023932591679372957, 0.02434602306623544, 0.03548761217721871, 0.1467175507651908, 0.023549628211185336, 0.012900844665377267, 0.04421966915417995, 0.02257111286079245, 0.08104082995227405, 0.02074304791832609, 0.07479169884962694, 0.0471336310064154, 0.03520660029192056, 0.0185550659495805, 0.02062068769841322, 0.04315891535952687, 0.017943307258454815, 0.04494666175118514, 0.027039245602541735, 0.05263111833482981, 0.07064227400613682, 0.11535155028104782, 0.02390306013902383, 0.02021249969090734, 0.031531800515949726, 0.01797169037828488, 0.038248421890395026, 0.011392641978870546, 0.010260588572626668, 0.0220855226673718, 0.030910252260842493, 0.06689251985933099, 0.041372003565941534, 0.030471477591033493, 0.024328221700021198, 0.048986092675477266, 0.011891138756514659, 0.03186293578307543, 0.020569940064368502, 0.03006442104067121, 0.059265684469469955, 0.00651154137449339, 0.05490333872980305, 0.030260222498327494, 0.018907128933018873, 0.15243962300675257, 0.006301858786693109, 0.01412048506816583, 0.05987887656582253, 0.014312566457582372, 0.04252917040139437, 0.043861667292990854, 0.04069230146706104, 0.0351755030320159, 0.04507331370509096, 0.023096085226695453, 0.05547214445791074, 0.031665336207619736, 0.07273683696985245, 0.036215619184076786, 0.027788100597847785, 0.03225886096645679, 0.0691922650273357, 0.12228586604552609, 0.028789569091584002, 0.03775537459711943, 0.030832536252481595, 0.035803415945598056, 0.051503759542746205, 0.010889376796382879, 0.03981851460412145, 0.024375400239867822, 0.021394073430980955, 0.06602368969470263, 0.006800558700758431, 0.01725222443097404, 0.06450387981853314, 0.021877775600712215, 0.023863761087081263, 0.012390169032317187, 0.06202566636992352, 0.037212505870099576, 0.056249928793736866, 0.02472149720415473, 0.04840750925775085, 0.0790822318355952, 0.04944657028785773, 0.01625796197913587, 0.09443215280771255, 0.024122963160542504, 0.03226915095001459, 0.008909558345164572, 0.02700237400962838, 0.010528289297196482, 0.04867477063089609, 0.05321268052128809, 0.03041901665606669, 0.0014788674972286181, 0.01190510215902967, 0.014042423006945422, 0.024381880249295915, 0.061271155785237036, 0.0307389052052583, 0.02890128648972937, 0.025799882731267383, 0.06169804252151932, 0.03791706270671316, 0.038849329110234976, 0.012366628108013953, 0.06252887472510338, 0.011484101714034165, 0.03466949911255922, 0.005672063362518591, 0.07468868366309575, 0.04688379441254905, 0.02956412360072136, 0.02642157856774117, 0.02567954793838518, 0.07143998013011046, 0.026232560763933828, 0.041341438956026516, 0.07356472433145557, 0.008065326771299754, 0.0438021529865052, 0.012160828436857887, 0.04762059523324881, 0.023833461105823517, 0.04889954553384866, 0.01355280401185155, 0.058325927039342265, 0.020395146050889577, 0.0036629996279121508, 0.03659546308751617, 0.02551501676706331, 0.05986516337309565, 0.0323199019767344, 0.0520788383271013, 0.0320605523219066, 0.03481880056538752, 0.0402645903107311, 0.01709846330673567, 0.04879088154328721, 0.029044104540454488, 0.06654498779347964, 0.042526005035532374, 0.0532084057506706, 0.03305219732491033, 0.08580335868256432, 0.03977016559136765, 0.02230386675468513, 0.03639279824814626, 0.026871854406116263, 0.023065983716930662, 0.03257602519754853, 0.020126213785260916, 0.02398593640620155, 0.048030898573675325, 0.019500897964462638, 0.03659862506070307, 0.053150153519319634, 0.01181179511227778, 0.03538674455402153, 0.0601807635809694, 0.05570865123133574, 0.029718520851539712, 0.029172513900058608, 0.02011708070390991, 0.0220456112375749, 0.005321461349792246, 0.02897279050999454, 0.023095048764454465, 0.02326606333787952, 0.03891571019110935, 0.06310261001012155, 0.06578013633510896, 0.03127684437536767, 0.017889319619696056, 0.021458298466833572, 0.0327694212485637, 0.0517365513369441, 0.0355767784640193, 0.044054822464074404, 0.07169606603149857, 0.019887573019202267, 0.025152071778263365, 0.036021483529891284, 0.07688600397003548, 0.051184305255966525, 0.03809382786442127, 0.011222121039671558, 0.003944032717429633, 0.017959838067846637, 0.035223872400820255, 0.01086933711277587, 0.04684158953438912, 0.013673328794538975, 0.06590870515044246, 0.020770209675122584, 0.03318512233506356, 0.044649015579904826, 0.053190282080322504, 0.08416975848376751, 0.03560063236259988, 0.0276387889669942, 0.026376282962571298, 0.04350943637213536, 0.02380990406631359, 0.07032717591417686, 0.01449433750739055, 0.010238358917246972, 0.004144488925313843, 0.020310410597760762, 0.03198636130296758, 0.0502823693677783, 0.040547902429742474, 0.02668308257125318, 0.2252206461770194, 0.15322377878640378, 0.13365393318235874, 0.2082569043018988, 0.08775658280189548, 0.34431787260941094, 0.0797134322513427, 0.12204749669347491, 0.19236839615872928, 0.10243767859148127, 0.11079883136387382, 0.06857074730630432, 0.1346620326595647, 0.07899090102208511, 0.24485299842698233, 0.13263649706329617, 0.08986080810427666, 0.08850561760898147, 0.18897994155330317, 0.1188316885381937, 0.18333961921078817, 0.08879069731171642, 0.17764425410756043, 0.226194276075278, 0.05626248508425696, 0.18320315224783762, 0.16908848392111914, 0.09736722388437816, 0.12120120067681585, 0.13702716146196636, 0.12445123413843767, 0.15643867770476, 0.14823320800704615, 0.14679840499801294, 0.13975147956183978, 0.1153406665793487, 0.1470342773411955, 0.09021304920315742, 0.08938152489385434, 0.09201354866049119, 0.1265566875892026, 0.06580027525446244, 0.20486914180219173, 0.1532015364084925, 0.15168703267616884, 0.18512936388807638, 0.13183798348265036, 0.08437249796198946, 0.16017000962580952, 0.08728801365941763, 0.10987974211041417, 0.09342440616871629, 0.09421471626098667, 0.18568572189126695, 0.3447601960173675, 0.16142909920641355, 0.12268275474863392, 0.08523466491273471, 0.10857503462050642, 0.09343786151813609, 0.15867825038731098, 0.17549253813922405, 0.06526004602866513, 0.08622451858328921, 0.06342961639165878, 0.09926423137741429, 0.20066382602921554, 0.17360083679003374, 0.2083186645592962, 0.09147399796971253, 0.09653620847633906, 0.13733080588281155, 0.14122244848736695, 0.1781066350106682, 0.08537501309599195, 0.16738329827785492, 0.1581577461745058, 0.16958523940827164, 0.15462266015154974, 0.22648911311158113, 0.14095762984028884, 0.17595372482069901, 0.12771068566611835, 0.1656061607812132, 0.08565576374530792, 0.1036871194041201, 0.10169988710965429, 0.0834524587595037, 0.11191662959754467, 0.15499305884752954, 0.14869269835097448, 0.08327009568789176, 0.08324646231319223, 0.17573107033967972, 0.1790897643991879, 0.08314679230430297, 0.13044021491493496, 0.14664398399846895, 0.13976564737302916, 0.13433259033731051, 0.09445329595889364, 0.1260606377784695, 0.10783397938523974, 0.12099477675344263, 0.12194263589169298, 0.17914486144270214, 0.1060249236013208, 0.15058752096125058, 0.1059178982728294, 0.10580332084958043, 0.10220150090754032, 0.14791778421827725, 0.11778815596231393, 0.18218271700399263, 0.07883880061230489, 0.19839485920965672, 0.126938933506608, 0.09574610194457428, 0.11059934885374137, 0.09675139907215323, 0.13710372735347065, 0.1278075533253806, 0.14638913981616497, 0.1288991261805807, 0.12999368458986282, 0.09278608792062316, 0.18890136719814368, 0.09810279655669417, 0.12551014231784002, 0.16807613681469644, 0.09786594712308475, 0.1812978530568736, 0.1551676323371274, 0.16572816137756619, 0.08401457073965243, 0.1535940282046795, 0.19001857510634831, 0.10540651357067482, 0.21775951582406247, 0.20332934228437288, 0.10489469460610833, 0.13934328646532126, 0.14459168698106492, 0.08583071721451623, 0.19739920406469277, 0.17883820432637418, 0.18631048979503767, 0.10170877591839858, 0.14609681335943087, 0.08665283024311066, 0.07872771085905177, 0.13258499625538075, 0.15237756419394696, 0.08323052352560417, 0.10921428924692528, 0.17700044651116642, 0.15991080924868584, 0.18074749330324785, 0.09308501652308873, 0.12942702642508916, 0.15335918723472527, 0.16231857719165937, 0.15955911097782, 0.11451961206538336, 0.11144643875637225, 0.07609363113130842, 0.08913754405719893, 0.157060690756355, 0.0949901392949479, 0.10376641979174954, 0.12293705610292298, 0.25751617178320885, 0.09528933931142092, 0.10860085966331617, 0.08923251860375915, 0.13423041653420242], [0.05171449894883803, 0.014703763948221291, 0.06296576306756053, 0.031752473674714565, 0.022800885174157362, 0.08439364789852075, 0.0485825950412878, 0.02431210140431566, 0.010409794182383587, 0.026141638767772486, 0.03506081365048885, 0.07811885460146836, 0.07233304078025476, 0.047506879549473524, 0.019166135927662253, 0.10295441014958279, 0.024059728785817112, 0.07972871964531285, 0.0221604007030172, 0.06037401035428047, 0.02660428769221263, 0.04370228620246053, 0.03303965799776571, 0.04443108370261533, 0.008987952888544117, 0.0846095916682056, 0.03957824196134295, 0.042929414460169416, 0.01739754797225552, 0.04584728467411228, 0.021627577686948434, 0.018346172158739397, 0.03364181372203997, 0.02890998191599335, 0.03725992189720273, 0.03944857391927924, 0.032775721446211846, 0.013256865204311907, 0.053212171620024104, 0.051821110370968065, 0.053197691682726145, 0.020385612633877566, 0.013268135670971657, 0.020399310559566532, 0.017168723911579167, 0.012283909600228071, 0.040549602159964185, 0.020676320784592202, 0.0619336570213948, 0.05230250382529838, 0.0122982283854591, 0.01999738034127014, 0.013011012459173799, 0.014511607919952698, 0.04568379505404404, 0.0313457597845367, 0.027850437610011016, 0.03868079458230308, 0.010575685816417848, 0.012453753700745957, 0.0254086428321898, 0.019105429095881324, 0.06628901724304471, 0.07170200999826193, 0.0342145685239562, 0.015594946752701486, 0.05185386664899332, 0.012100263249262102, 0.009841793366441769, 0.020769090092341815, 0.015062067757493683, 0.02169136337137648, 0.012184219235288245, 0.03735781414434314, 0.007010903284286282, 0.02090260203528617, 0.03156559155987842, 0.012106199582506503, 0.08235529477574996, 0.025117335874321203, 0.037520248642457385, 0.01783229553672884, 0.01667721858913345, 0.019174970453605056, 0.02560894636969481, 0.05354312029001968, 0.016629110456311276, 0.0043744949091758046, 0.040234456570552926, 0.009688016975165477, 0.014573081496304699, 0.06416936205433947, 0.017158852923395376, 0.031861894231821807, 0.05666103959083557, 0.1301952094904014, 0.016146767052954862, 0.007457932756681527, 0.023458402570603148, 0.03687166076685701, 0.035205948898302655, 0.0427815752503063, 0.05419055465608835, 0.034227053568299325, 0.005435009096150419, 0.06555140218032257, 0.04673574146415506, 0.0770554273788418, 0.04490062654284494, 0.014936891617253423, 0.04684488721457975, 0.021053516705121313, 0.02822974886346076, 0.0345879765227437, 0.020943705990378345, 0.028205889875867536, 0.03128282226888197, 0.03671407440145101, 0.044653823000511954, 0.023303477758807794, 0.020988538495397994, 0.07142373600176402, 0.027679864084348083, 0.06146866375846522, 0.04235785387988601, 0.023465932612972598, 0.015885709186217616, 0.020851291217175976, 0.046534850993858914, 0.034612281647111685, 0.023292507543893795, 0.04062275162764958, 0.012493017977768821, 0.02236602734774351, 0.03615176903882197, 0.030604280464883362, 0.02687174584051328, 0.08618652740759508, 0.03842784012002604, 0.018394994449668696, 0.014493396040052176, 0.06337949979518141, 0.0731723750276225, 0.01649320837376373, 0.008581691072322428, 0.032132032593446117, 0.03533741845084088, 0.04563405165182693, 0.020493754152474657, 0.007614599707137261, 0.0045474017471341145, 0.03077925429014223, 0.025966369779780507, 0.038280804974160025, 0.046309428089963536, 0.03965717933273741, 0.04903996835595795, 0.05734523359153952, 0.033382348716259, 0.035348481964319944, 0.012967489526740142, 0.005519645313532757, 0.05564790199111615, 0.06851073766925506, 0.04250556756077068, 0.09828025382012129, 0.03045467027862157, 0.014314829371869564, 0.08880253096244164, 0.00978001020848751, 0.027763803955167532, 0.02575680084659585, 0.032635807525366545, 0.014030316245875188, 0.008225981811327594, 0.02814898792920368, 0.0675303495622107, 0.018178429820441773, 0.013375461251208825, 0.05190751162756767, 0.030801880040339062, 0.03269484346466405, 0.028377806900867393, 0.02215146609315915, 0.031429898126849105, 0.0453404766906585, 0.024088793833340918, 0.04222368715064866, 0.00243784421971733, 0.0543803985762809, 0.06284055300056934, 0.09706347089793001, 0.02839319607509034, 0.04988544673791953, 0.020997844603178755, 0.04652386890458209, 0.025569284301517264, 0.017993150744587183, 0.02576562180183828, 0.024687964003533125, 0.0287032696152372, 0.03425428996394787, 0.04461952984066946, 0.007653729125325168, 0.03172773089525955, 0.09220837642039571, 0.0456659936878298, 0.036631802030439885, 0.02128616770330284, 0.06841272328581129, 0.05788223299064806, 0.026402002832453166, 0.02297408802301756, 0.0038024763177548137, 0.0373251494685454, 0.03657314946342792, 0.011723722963194762, 0.0616366011755807, 0.005613618172771696, 0.023249698769567267, 0.06404364308608429, 0.011770100831719381, 0.03381802587370787, 0.02777001085425062, 0.023337504593655467, 0.016291761504752294, 0.10736456885933876, 0.01009788690134883, 0.07610102716301169, 0.057476170494088104, 0.021052203739860227, 0.06432089249470405, 0.026846997972045625, 0.04299695922860077, 0.011691374654349471, 0.04115063151610749, 0.023552922498700873, 0.010527211274685604, 0.06701777742377349, 0.023874424264899323, 0.02832427218423358, 0.019893603499180505, 0.06621205101587943, 0.04032616736367345, 0.018694896749886017, 0.008725193595247609, 0.011727325984143784, 0.01459618391735213, 0.03496996120416692, 0.05066216238109129, 0.020895375637337565, 0.03392500031207289, 0.06789994758686849, 0.03545789234340191, 0.025360928249678442, 0.05033128156459757, 0.006804581141165856, 0.011284173915295728, 0.07822680952293531, 0.047510360434119187, 0.0491955733991095, 0.04220368054562381, 0.016838869379301156, 0.0253871790732124, 0.014541916382898177, 0.02403553731606475, 0.026664395716839602, 0.04133505394150104, 0.041493155993521214, 0.036633430514484644, 0.002373355403376211, 0.10295926167496613, 0.006770356258909617, 0.029045563390744582, 0.028283188585191965, 0.011713988530183477, 0.08484632575086185, 0.055803547746368816, 0.011844828741491904, 0.011444787395053675, 0.04268904003713812, 0.07048819905945233, 0.05153055149795754, 0.03169837747035282, 0.012035732024482318, 0.07650512869336776, 0.018337210407480597, 0.03568775625899434, 0.0525603335616844, 0.021618721108617525, 0.019068087617467557, 0.022048120120806352, 0.020738942781463265, 0.06778621833239283, 0.06255191777433668, 0.011147815517948141, 0.03441805439069867, 0.029542111924716404, 0.012396379324075366, 0.055219983881605525, 0.026915947307965586, 0.04396251456013747, 0.04929761828056403, 0.04920557839795947, 0.04018520849889942, 0.03847903558718307, 0.040718550594257455, 0.012410378349678857, 0.0160978989609118, 0.027234936798257486, 0.08980057455067124, 0.03837789994265352, 0.042171534949115345, 0.033545159801308594, 0.07689000732664551, 0.0360457241934325, 0.013352423290988165, 0.03503762132355145, 0.05232764694041439, 0.051079186610877514, 0.02455903895731483, 0.06211228815040418, 0.028098437070314373, 0.006310937585242624, 0.004963105378140296, 0.027553176507353783, 0.03244127832087023, 0.057651985702770095, 0.03257138741069606, 0.07705717799918992, 0.03652143491698163, 0.019001499583412493, 0.05258054711988994, 0.0892492173505681, 0.044823833342109404, 0.01052970319454159, 0.02405588997394911, 0.011070399761332997, 0.029607882324073995, 0.01736524292001767, 0.012464683203558837, 0.05562661634758115, 0.03748998258795057, 0.03292927052825689, 0.026722956681624055, 0.030518364360822097, 0.15223701245018414, 0.01267082553489932, 0.07665192974465233, 0.05116300943440624, 0.027735161295692836, 0.04400917062801974, 0.19937194963651045, 0.0929741778277925, 0.09085260917033468, 0.14294611742453917, 0.0746030118316412, 0.13627822164978298, 0.10544259127761636, 0.07726132883025066, 0.03971366058768971, 0.09870151550109897, 0.10589937426682029, 0.1221104511725051, 0.21191874066633837, 0.2046015275908368, 0.11641987652650901, 0.19206559312130722, 0.1219772140362433, 0.17853584912206444, 0.12180398404598236, 0.12646068845476421, 0.1208490002900362, 0.08787563855626754, 0.12350309001547949, 0.09482535706566912, 0.12299356449927602, 0.1419830591018711, 0.13755545525678567, 0.12081831693649292, 0.11270275991410017, 0.16412023694387504, 0.09746681246906519, 0.1520101103399481, 0.16931280759828432, 0.11301412606345755, 0.13579728959926538, 0.09171117988548108, 0.1346303043620927, 0.23789141912545475, 0.19755388290754386, 0.15529751751039708, 0.11815323494374752, 0.17500616423785686, 0.06369370222091675, 0.06014908278094871, 0.13676079575504574, 0.1014263764289873, 0.12511439355356352, 0.08590131199785642, 0.1247949121253831, 0.08992895337619952, 0.19386432160224232, 0.06341200162257467, 0.1867175293820245, 0.13273993294153894, 0.10389413365295955, 0.13782293376113686, 0.0953275001208697, 0.13078706844576768, 0.0674782855702298, 0.10381684172898531, 0.19689759026680673, 0.07153667137026787, 0.21968356972294195, 0.1659582526023899, 0.1108580267589007, 0.0901433297299913, 0.12448650438870702, 0.1171826720237732, 0.10386203216122729, 0.08959132113627025, 0.13458311903689588, 0.0961278932435172, 0.11152258395616498, 0.11956153437495232, 0.14154312413718018, 0.14691853283771447, 0.10156058387032577, 0.1287980651749032, 0.21218556777707168, 0.1946728639304638, 0.11240529694727489, 0.0728793836065701, 0.19209067177559647, 0.08922819633569036, 0.17651260697415896, 0.09941980588649, 0.10167771258524486, 0.10125399460749966, 0.14114247635006905, 0.11963952518999577, 0.06536313585404839, 0.22703295892902783, 0.1613535511174372, 0.1586169515337263, 0.13185459401990685, 0.42389564535447527, 0.22804967580097063, 0.06842642290783779, 0.16824857970433577, 0.1211338492908648, 0.1660382654517889, 0.1096567212204848, 0.0975337770900556, 0.10153859255037137, 0.16397251987031528, 0.24216456125889504, 0.15093497160289968, 0.13462700668190206, 0.07589866087904998, 0.14668536106390612, 0.06970064381935767, 0.11602537626666681, 0.25678224116563797, 0.10090123782200472, 0.06841269614441053, 0.07840875190283571, 0.1370148528367281, 0.1476666448371751, 0.16687803396156856, 0.09305191758487906, 0.20072033442556858, 0.1205428588603224, 0.13327754980751447, 0.13982425922794, 0.084153948617833, 0.10710542276501656, 0.16535361004727228, 0.16684399864503316, 0.20740243872361525, 0.14018100579934462, 0.08643885422497988, 0.09229581244289875, 0.11209977976977825, 0.131966375878879, 0.1324068129594837, 0.16163392178714275, 0.09352530432598931, 0.20071984588035516, 0.13931402803531714, 0.14498919993638992, 0.05911208449729851, 0.15966811084321567, 0.20318641566804477, 0.14125477389565536, 0.07334558466183287, 0.16033809632062912, 0.11182082045291152, 0.13500349862234934, 0.06298723191555057, 0.10120995768478938, 0.05855083425662347, 0.20830494458121912, 0.12441920728555747, 0.155389133308615, 0.09280746855906077, 0.08528740065438406, 0.12123634879078184, 0.17227994623993123, 0.1482051166572741, 0.07558905892074108, 0.08698603843471833, 0.11040473143969264, 0.10376927642417805, 0.1798903542969908, 0.07313629053533077, 0.16305683686264924, 0.13473034756524221, 0.11774244984345776, 0.13830279372632504, 0.15405862113194807, 0.17882224518273557, 0.08133053047848599, 0.16990306521100657, 0.12791491113603115, 0.1030912095946925, 0.10002769862434693], [0.022892650250079374, 0.06086147669702768, 0.023240141603829603, 0.023916980284931402, 0.04116547786231552, 0.013188729262245553, 0.020545399149081538, 0.03736378185983215, 0.012346271209285727, 0.07443470800561564, 0.013554475752503743, 0.035275576769241264, 0.012858588048922164, 0.07182574085891247, 0.040626341077898226, 0.010158402895155762, 0.013433935702778399, 0.011170493006440145, 0.12319074677569525, 0.024605130144794072, 0.02280846780299076, 0.03897016941170607, 0.018467082010049905, 0.021331319119781256, 0.006237065053677985, 0.04184982453339866, 0.07741253357380629, 0.03840829152613878, 0.00740442518144846, 0.0072286684964118254, 0.023625507085983242, 0.051698784077806134, 0.007547605400239783, 0.032438106169658046, 0.07053349805729729, 0.0819708164781332, 0.062110286472099166, 0.01700232337628092, 0.018204677251300642, 0.046047272692833624, 0.05754070595971175, 0.01144859567284584, 0.01907164992631546, 0.018084483254434805, 0.04108919017016888, 0.051053392102143595, 0.05242579363818679, 0.016336607580472316, 0.030231038707175424, 0.05032778371657644, 0.027846627635881305, 0.035985266723270924, 0.05582649240802441, 0.036397005165261884, 0.02023879631555506, 0.01735783671028912, 0.012892050851535584, 0.07128534199936049, 0.03925985636721764, 0.026885649023045386, 0.015514843997412493, 0.006483961894576038, 0.03504259837791324, 0.02458758492554937, 0.0609396846432771, 0.09526973643473216, 0.05073647553633366, 0.011314456085009235, 0.04849702159741095, 0.035119184625468085, 0.018012948700093796, 0.014553955290466547, 0.027008791254567246, 0.03997136479509728, 0.02648314883533333, 0.053728333208709955, 0.0320904723235539, 0.03956864069082907, 0.039669878115611415, 0.04980094877204724, 0.011904983415401407, 0.03888412777866636, 0.012941697562512542, 0.06266263433332954, 0.0053243031392672235, 0.03897706332749554, 0.001979430414004517, 0.017696999046685438, 0.03729079524055123, 0.03962513551648174, 0.026470175245776772, 0.04496046654613955, 0.041026273010564704, 0.018055621767416596, 0.07687712873199157, 0.04227425158023834, 0.0679510955565742, 0.04352199944800564, 0.054974069220146964, 0.05839771604431527, 0.03824489350829806, 0.020368881656655242, 0.04312164682362761, 0.050568188673683574, 0.024571795415665423, 0.04402997111901641, 0.06076081602701119, 0.04263921181804367, 0.0050116783074502435, 0.01647908297101302, 0.017504770075902343, 0.062168185865240436, 0.02910575283957379, 0.055205632865961106, 0.009950724530166813, 0.05174163695690887, 0.012380534683221152, 0.021782605975334133, 0.05888976928378854, 0.019796715483867695, 0.032751555421522686, 0.024272457995851125, 0.003667961839320404, 0.049719897764069695, 0.03128134645521641, 0.06151086185127497, 0.0357793449158115, 0.018865305730806928, 0.024707892577030828, 0.047060535821531496, 0.01675709742786629, 0.020763873854385953, 0.059890859494251866, 0.05045993519680841, 0.06957278068044356, 0.02701160547855709, 0.0254846743773669, 0.051724856785897694, 0.046863394257213385, 0.054607195513589044, 0.02642570066797946, 0.038540558357323916, 0.028906219439314942, 0.02337890031880566, 0.03672712602253471, 0.05101671049903546, 0.009890401070671422, 0.027645019614802938, 0.05847873312554189, 0.049148374503212314, 0.049145456802632125, 0.013789568628583635, 0.08206288010946342, 0.022124740295112133, 0.03621934434132917, 0.048014583199151924, 0.016948503674939275, 0.08317700746868338, 0.045063614046999385, 0.005516720827602382, 0.023401895870587656, 0.04682649891557438, 0.03497553197667003, 0.09905867597886495, 0.023728330586371676, 0.026121823848890405, 0.017083540625338043, 0.004210582476974065, 0.041920120761330636, 0.020682239306292365, 0.021698766188429933, 0.0029773840963441345, 0.04746354830318263, 0.002004107884463987, 0.035967088770121336, 0.022394556352602582, 0.07003230495112282, 0.053374741825142076, 0.01541197978492294, 0.06540413293987513, 0.015258049026929905, 0.05329011493761625, 0.05365253745445183, 0.03855881094932556, 0.0313233681289213, 0.03962368005886674, 0.003905191252540265, 0.04955393149118338, 0.016228584805503488, 0.03199264453724027, 0.0655191649815866, 0.021837071981281042, 0.040604041024510346, 0.05702506684299026, 0.09176120148705584, 0.020858161384239793, 0.05386027095041104, 0.017491204464542012, 0.015039002655872276, 0.011422271058628601, 0.04298792453482747, 0.026670516102707813, 0.06672536954283714, 0.06022773856031043, 0.04703571501054934, 0.028192580411476747, 0.03822655609941908, 0.04358741022380335, 0.034914107594106875, 0.023389258155865327, 0.02851080654987267, 0.027404387348464558, 0.023590813590479747, 0.04207413124718836, 0.023490113904699683, 0.0389794924828623, 0.025794049026444554, 0.06778460341904845, 0.03973639151081443, 0.0379033902260874, 0.04580893387485828, 0.04101366922259331, 0.011289443587884307, 0.053483616161559305, 0.018437557255050967, 0.10572659210967165, 0.017936330222125565, 0.03325107593887618, 0.08090630359947681, 0.03035949556423085, 0.040122674711580784, 0.05009482568129897, 0.05209417321852275, 0.05790587993604796, 0.03079175969053592, 0.031146511368985687, 0.011241072522742408, 0.030522723948316913, 0.0703323327803186, 0.04161060701257416, 0.01834128501026758, 0.08594538963266782, 0.03363134731937732, 0.042810528339552026, 0.04702497719387923, 0.018512649029227238, 0.03024323537413563, 0.024460145871021917, 0.06475398782640696, 0.06560170876660518, 0.019878294052822248, 0.03262224021766867, 0.015454067615792155, 0.0941884433850646, 0.02249044013608779, 0.03727318386414221, 0.01818604807236365, 0.05185814820496099, 0.01156290592293122, 0.02279039841544415, 0.031143556348979473, 0.012089389725588262, 0.029312817978539636, 0.012059399325932776, 0.045305749268404076, 0.033465055349682055, 0.03732671009908829, 0.020903974372361387, 0.023169154966516153, 0.017638902878388762, 0.029855819019888128, 0.03990603544350181, 0.03149199765175581, 0.03627331501671246, 0.06142987869679928, 0.02336736352715109, 0.022590522355000888, 0.0448155043247555, 0.018056987319141626, 0.06483788189611264, 0.028186030852209245, 0.04239152618018644, 0.020069986980940615, 0.07431336558823075, 0.015257065151152866, 0.027612521180084774, 0.056303468599383316, 0.03689876484817692, 0.05436701447303806, 0.05814020521938801, 0.02623655054984348, 0.032817437779158354, 0.07565719740731375, 0.022411112607057606, 0.06636922008224896, 0.048603368390883715, 0.03127219301781484, 0.03657934109547308, 0.04268117581627198, 0.02106610352971724, 0.040604434574821165, 0.03468475936512862, 0.029446184036454985, 0.005742484271260244, 0.022508779241304313, 0.10396829074514763, 0.014150224409864416, 0.0572327392707978, 0.05355508964774864, 0.00645699182392231, 0.10960032817508493, 0.050613983002092154, 0.0286275654632066, 0.07383577193000487, 0.03965097412999187, 0.01102753755237375, 0.03258374353338565, 0.05461358052811452, 0.03955229478222983, 0.048731869352715354, 0.044848453985261064, 0.03494826843962073, 0.02000039303675294, 0.0361718333193234, 0.011734532874210604, 0.04979222620438252, 0.09938947537115642, 0.06153949602906193, 0.16485631173210485, 0.02301978226751089, 0.06517176183738879, 0.015359428944066167, 0.028546439816376994, 0.05227432426597391, 0.038211061752268245, 0.05148335599473544, 0.09571457720760788, 0.013833478325977921, 0.02945494053087064, 0.10189943068793841, 0.019651665052931224, 0.025708372105977366, 0.029394282892878567, 0.04471825668588281, 0.04513134541256087, 0.02305047071006681, 0.009968515718355775, 0.058354398368724754, 0.07237527958516564, 0.021623793157881925, 0.011271601509568947, 0.01845744511644755, 0.2003671840897628, 0.19977282812552793, 0.13220444667552197, 0.1819662507623434, 0.09392415399530105, 0.16000266931951046, 0.1550713482179812, 0.14216409224484647, 0.0932606417419655, 0.1495592961353915, 0.05925834272056818, 0.08429635276219674, 0.061768644090209684, 0.12890456803143024, 0.1666886412671634, 0.12513740946139607, 0.08998111914843321, 0.13282821034746511, 0.17829659767448902, 0.11562859612916197, 0.09773760900965758, 0.14955800691885607, 0.0862931998978768, 0.05926374385931662, 0.13783968000539712, 0.05635666235217026, 0.1622772001262222, 0.13024267980030604, 0.18647166900336742, 0.13777485276971543, 0.1746129531945501, 0.1500768826476165, 0.11305380000599793, 0.19112747774592467, 0.15911007007317884, 0.16867032993052686, 0.125235539195793, 0.06626866119248526, 0.08076976878302437, 0.18858886110995496, 0.09052320077483143, 0.13449683652392455, 0.14625044725835323, 0.20725873857736588, 0.16863596891718252, 0.07930860468851668, 0.09748977409409625, 0.10859643561499459, 0.09312149456569127, 0.15566607059112617, 0.11621989868581295, 0.11106737516820431, 0.1112967064338071, 0.09715624020567962, 0.09674087499401399, 0.1190295357789312, 0.12344907862799508, 0.1345700097403356, 0.07014453464320727, 0.0954490935962115, 0.10328276003045694, 0.09893277380615473, 0.13717706341828617, 0.09723753548626389, 0.06960687027978045, 0.1426275588039841, 0.15926906439874852, 0.13675156767879212, 0.09633379469492606, 0.07635249902627297, 0.16302384649004253, 0.09832476571734462, 0.09383312852254935, 0.1451892727719886, 0.1066620544131313, 0.12001003245157854, 0.07517469794090305, 0.1376449947378465, 0.13487839033561094, 0.13975656857447966, 0.12193651550582477, 0.1282525501613106, 0.11557325481304101, 0.19366955491048948, 0.09832324579890285, 0.1464604131345238, 0.09730084958885397, 0.10330662410706282, 0.2010501974395343, 0.08656155371240207, 0.13049611262977123, 0.11957973268415246, 0.1592845349971737, 0.06442125460931233, 0.18882096079843386, 0.21171718862439903, 0.0832084236400468, 0.1169426470462765, 0.22351767255791596, 0.10661981560822044, 0.08471829976354327, 0.08724439742841891, 0.14142887241074018, 0.14736338039594038, 0.07845204922237567, 0.14098485266523703, 0.16027120633849076, 0.16627276715423378, 0.0709893921656268, 0.10877414393637862, 0.07499011605978012, 0.12761138885148934, 0.12659321991460665, 0.1208095909761531, 0.15503275314612047, 0.09438426859144654, 0.20554216711648873, 0.10625951351331812, 0.1806700588869197, 0.10038605332374573, 0.08424249065241643, 0.13589410297572613, 0.15540250044848236, 0.12239576157714639, 0.11801758222281933, 0.17790981914315904, 0.18915454218430178, 0.16539658845535346, 0.14453322440385818, 0.21179215317325933, 0.09136309142091445, 0.1307595470654113, 0.18397806638053485, 0.08870845208210604, 0.18930457984762533, 0.1708662999527795, 0.1464054517980133, 0.14537694198744638, 0.228564765304327, 0.148420334394489, 0.15301138375486645, 0.14286317330385956, 0.15000328873949392, 0.11865018042070524, 0.19615330520485127, 0.10425267155681338, 0.14147932827472687, 0.09903702392641987, 0.13633892339255127, 0.14646254373448236, 0.18029024212488107, 0.1304092737180846, 0.1892745750291007, 0.20516651655946458, 0.17421644447105272, 0.12967558737312043, 0.09128555522433349, 0.14690071450812475, 0.18454712655927452, 0.09238259707178388, 0.19427680304007872, 0.134748640869345, 0.1748178843408823, 0.2883748316339084, 0.06555703402097736, 0.0973493309159364, 0.11111012287437916, 0.09772279659020049, 0.17479238499488148, 0.1302919550133603, 0.12969751762492315, 0.14678469859063625, 0.27078671540532795, 0.03567391414461391, 0.18650398084095546, 0.16928618188415254], [0.03056107135489583, 0.02102414462050157, 0.004892359620758465, 0.01684696599841118, 0.009946675372443028, 0.08013747592589684, 0.03958120037402425, 0.03719036187976599, 0.03789512227688517, 0.00908897487845804, 0.13431615621915885, 0.024327650034267987, 0.05244002930287804, 0.012826734222471714, 0.032772484834172895, 0.029881243727036884, 0.10050174354442529, 0.08262362144887447, 0.026102119191948856, 0.03645986464938947, 0.012252192328950124, 0.020005600793021064, 0.015962951916403005, 0.016292691097727845, 0.054568508839500804, 0.02353778268609728, 0.03201228134067995, 0.016591884328850677, 0.04746231336944869, 0.021023528849972144, 0.01928716791527612, 0.020493453900728906, 0.02392035090763654, 0.037947155734790225, 0.06533012512539114, 0.04835656484855073, 0.012355063326789864, 0.040663005717630894, 0.08732848827328, 0.012294596526771784, 0.015492852677458098, 0.023385066505787627, 0.05579558853060007, 0.043448439466633966, 0.018169754750228355, 0.00871304442573871, 0.05484295929116862, 0.014515039610809513, 0.01815907969804747, 0.11327754014304706, 0.09560991996633154, 0.025991858947756033, 0.03202125496630158, 0.04819682752713561, 0.022743157111108303, 0.017346050557015196, 0.02923328349632876, 0.02221458002791873, 0.06649648611034666, 0.022431109034057175, 0.02937782502600125, 0.059740631841123104, 0.024262183279331242, 0.0052188948445421246, 0.0003681022790260613, 0.03318506126691188, 0.06726436383490052, 0.044653843356562514, 0.04032227935801659, 0.037228970522327084, 0.03434201775650893, 0.0418217433616519, 0.024365529251684035, 0.06061929397817169, 0.047258444130420685, 0.029904717646007026, 0.03319465235940047, 0.016851585125550628, 0.06360788789710828, 0.05270363337227276, 0.03668639695804034, 0.06228122979934726, 0.02528184838593006, 0.01241067351241197, 0.03205245400645903, 0.05162523088178464, 0.01773820647836796, 0.03388550618131246, 0.028359978393252407, 0.054321980103850365, 0.05162116984969803, 0.04141595567177449, 0.03408189457175987, 0.07912101689726114, 0.03014342626556754, 0.014089846667567534, 0.017317972777943526, 0.05869749281555414, 0.04935166698747447, 0.06003180478832551, 0.03825060338047998, 0.014691229710089309, 0.04640315073941435, 0.014448049544755901, 0.033549224226070304, 0.015195913878934724, 0.02378548019831734, 0.03795003950861948, 0.06988275583301272, 0.041340200629617484, 0.06291033354188715, 0.040099065085606914, 0.00016653636157570872, 0.06307680532336235, 0.009515993080900183, 0.05029177386313677, 0.027168981498107314, 0.020203188494113938, 0.0289176866811301, 0.025477673592311994, 0.043270117071058066, 0.05176353667463575, 0.06854467799088784, 0.01137331560520189, 0.05556246764691813, 0.06870118887828928, 0.0356474614569119, 0.0030820052904476014, 0.04923000565863081, 0.06832650184099164, 0.04930152664227145, 0.03532978832455618, 0.020736537374822155, 0.010677962247947497, 0.016737389378249645, 0.03099209036944168, 0.015326355450919696, 0.0828923891697611, 0.010592533840930887, 0.037914711582873545, 0.050504094255822043, 0.038786310170378, 0.04698436348033803, 0.027758606376924684, 0.01104007094233696, 0.06525264321161167, 0.0038711504229078336, 0.01991809013166598, 0.05910057654338224, 0.014374621877712863, 0.04295744474178978, 0.05219735464613352, 0.061093359254300594, 0.014401902378137623, 0.033122371416538954, 0.00824418945038425, 0.021418020628126602, 0.0319255068898201, 0.064058150164783, 0.030789184650140147, 0.006485798179970256, 0.030573193383003985, 0.047300462411450486, 0.01888576865063182, 0.017596279004854814, 0.006388632389384189, 0.05669063728834901, 0.02847908843042595, 0.03458560165017843, 0.010288841922634413, 0.04884906252846122, 0.041380030635212145, 0.07005665757294212, 0.07074683625251055, 0.052359385415911674, 0.06199384307754891, 0.04764203015448792, 0.058991203483726294, 0.04240528008501444, 0.053327787201851606, 0.025987214375553385, 0.03765852729390774, 0.04846308466845325, 0.04422919239316668, 0.05642926899184074, 0.03185795872871365, 0.04789330863526889, 0.06429930829576083, 0.08563217108270951, 0.05474077531003526, 0.03225841652601957, 0.07904089548225914, 0.060686672505523474, 0.04243490492392864, 0.03607710643804499, 0.03763510087238891, 0.06415212047951561, 0.04270318749227694, 0.053498638926872184, 0.013347845724118608, 0.0607858132570982, 0.05757260389093842, 0.015079210944739836, 0.037645472280148945, 0.02463579653496189, 0.038708156506930075, 0.01316508062050811, 0.0017017984812680098, 0.019331544105495726, 0.03660490829497576, 0.0645334232332451, 0.041299118726913414, 0.044622488253350766, 0.0026455367915332317, 0.018623021231698136, 0.013364171276667287, 0.060057310919676504, 0.029418584624571458, 0.044575455598533154, 0.07420142766620431, 0.05156668348770056, 0.017808426371110336, 0.02996143978089094, 0.033915239585829635, 0.06251086640570845, 0.04007687359782202, 0.050460773187556436, 0.024137198825233748, 0.025765877948807817, 0.0528061803696411, 0.004607118765956589, 0.011371929697426302, 0.01961122266948223, 0.03836721980145999, 0.09163749776780605, 0.020214993307100873, 0.035498146433383226, 0.07241363038441964, 0.01978916338911014, 0.05393096072865384, 0.019982091250962446, 0.022045253310352564, 0.03051859506272844, 0.02500694670847484, 0.008640693084869002, 0.014163435486677502, 0.026373321157214896, 0.024606879068804637, 0.07515776170683758, 0.048389694320836237, 0.08841604420116969, 0.04150956297027213, 0.06931009941867419, 0.05346205571134176, 0.017672407241272073, 0.06234028948737042, 0.040085463851158104, 0.03783731448597141, 0.034081772435456514, 0.04593798445005502, 0.05232149602047034, 0.04092660639435053, 0.02118790226190218, 0.03508081686283861, 0.046165395461555035, 0.009064204109433507, 0.03704190859571099, 0.06179108324327639, 0.0251438207924366, 0.033737568583871634, 0.025716002232262065, 0.014659250354660409, 0.05076325052816953, 0.02021762602297323, 0.01118531814842884, 0.038088250306567976, 0.017034170417381183, 0.010490941881601299, 0.0642848147877625, 0.032467999029904604, 0.03535660742116826, 0.04927535554660218, 0.01637346899536039, 0.056911144206034284, 0.03351983008906245, 0.06144147486026798, 0.02984525422964777, 0.04678584448993206, 0.009292104514315724, 0.0200347506574222, 0.030579951591789722, 0.03768084770334618, 0.046988078459565125, 0.04685277857684663, 0.019596797014985765, 0.013128039393840092, 0.04108993995136448, 0.0463539264164865, 0.019523333724854246, 0.009919772307122392, 0.0160911237887506, 0.0557583233873759, 0.04912496843774404, 0.024960731688354696, 0.11201007065496274, 0.029993626089500527, 0.008804142841004899, 0.04229614790529013, 0.05423454747402242, 0.032493573014757464, 0.04078491131908127, 0.07008649954306227, 0.06839157334928002, 0.061843215088759146, 0.023661087766023617, 0.052044199114399295, 0.04503879662869232, 0.0408461966019656, 0.011827008715564651, 0.01740493891494615, 0.00962701837332653, 0.0034441489717989627, 0.018202215865520493, 0.03792011611429708, 0.037317451488758833, 0.030069299707455293, 0.04518440006566899, 0.05353150037782533, 0.01998851358491395, 0.01485093480109104, 0.022544220821665864, 0.026223826321906278, 0.046611756152872524, 0.02184463764673897, 0.04245448065921664, 0.028418617389564003, 0.04127922408016665, 0.02918692259117961, 0.022374726166682582, 0.021814006879659634, 0.05226050929299422, 0.009911169331254703, 0.020872955143983875, 0.03298896125384739, 0.03994574331279312, 0.06598058236496789, 0.05050974305985229, 0.07589357186641012, 0.017799099907279015, 0.018282796987997632, 0.0619208055681416, 0.06952781416475773, 0.11225637208138194, 0.135709622874856, 0.07564306352287531, 0.07901568790631634, 0.1453817053032773, 0.17654357531241008, 0.09251061627375227, 0.08271785639226437, 0.16199319250881672, 0.14872910854007515, 0.2371934237224715, 0.19436676321285112, 0.12318956612476281, 0.11395750008523464, 0.07090403246028082, 0.17412093388182776, 0.1461146588304213, 0.18404468494866574, 0.10714477779609816, 0.08052348771265574, 0.14254335260816983, 0.10922245202319962, 0.10361453651317529, 0.1259367779961654, 0.11624409524457795, 0.08154644032141992, 0.08367853305701699, 0.1882505299789565, 0.13496087305247784, 0.06941189324217183, 0.09832992936883654, 0.08004292207104818, 0.09788185198392187, 0.11252969955759388, 0.11405339065407004, 0.15994740942759172, 0.13587218629462378, 0.11921854849372591, 0.15002637250082834, 0.12497518530913762, 0.1522026378661394, 0.12196520396641322, 0.15872112022978918, 0.20134922782225267, 0.08899528919053928, 0.08137945285333054, 0.24326826632022858, 0.1159258351794311, 0.10471448927585568, 0.20178296097687312, 0.19753181694873742, 0.08585578908345529, 0.10596369938658816, 0.17073645549161093, 0.0910518066957593, 0.07093083459351744, 0.06631386519542762, 0.09271643630095891, 0.15270722364740713, 0.12111308611929417, 0.12097416285957609, 0.17627468545522007, 0.10119939289454903, 0.09646524049873863, 0.06315603785748992, 0.09884186368435621, 0.15251727455428668, 0.11997134238481522, 0.08169116505554744, 0.11211863625794649, 0.1208081796233143, 0.21624354645609856, 0.1402789048318352, 0.17653871700167656, 0.13777831329831056, 0.14012961355703218, 0.12299011754138128, 0.11346278698848826, 0.12066502230507986, 0.16221055441669055, 0.13264083968741552, 0.14643441167260918, 0.21333720455212252, 0.16641972426857266, 0.16772409927632126, 0.1016971729695797, 0.07717072404921055, 0.08170846091317278, 0.12557598735604966, 0.09725754548396383, 0.11399705867682185, 0.19061442384762423, 0.08223587939781801, 0.16152091856513703, 0.12385117848004613, 0.10901393142661878, 0.13937049571956905, 0.1351667677185365, 0.10917971110237495, 0.12785464365567478, 0.09335311927965709, 0.10869862977415323, 0.17344982203628334, 0.1321185441421611, 0.12459637277892657, 0.11095756784613643, 0.1298748052545956, 0.12057074664958886, 0.10886897599058491, 0.11705579954598631, 0.17294398775058134, 0.14898771180638246, 0.08149558412177221, 0.0919880425291402, 0.12566691104854855, 0.1007408050021955, 0.23050830672894204, 0.15601604538304464, 0.12730940005608968, 0.08040608758372919, 0.11452274689716951, 0.22673624913607324, 0.12561923717813833, 0.10884276418281452, 0.16660685065601552, 0.17613188097519533, 0.17443052226943628, 0.14453106666249887, 0.1957901804042714, 0.1398517806082964, 0.12569084976400646, 0.08759228233247995, 0.07747907071773495, 0.1469630990177393, 0.07620977597045046, 0.18490670940705708, 0.12971752083727292, 0.1462801263800689, 0.11943952020789896, 0.0972982236583318, 0.13863657867269857, 0.1362493431993893, 0.06486515221851212, 0.098721783342106, 0.1482785205755915, 0.17500431862260613, 0.0665867787652782, 0.08435669488140515, 0.12536745997411863, 0.08591548659439598, 0.21709555573761463, 0.23261371946760587, 0.18809245846101216, 0.0994137329980731, 0.13080960937908717, 0.0536396520744477, 0.09525923271264349, 0.0890954884567431, 0.21721839771739074, 0.11250744360898222, 0.10577493772975036, 0.08593156787433795, 0.10059823122407709, 0.08615234281335558, 0.10877116516764675, 0.11828366294503212, 0.20320958085358143, 0.06962967584175722, 0.24099691105740412, 0.16355835566563265, 0.10749520042112895, 0.10633353489850249, 0.10380895036671843, 0.12153726550085203, 0.0984932052503739, 0.15476338831441744], [0.05820548028818198, 0.022826883243396878, 0.038190593743430715, 0.05581287421020014, 0.0506734498111265, 0.04390041842790587, 0.031204135955444405, 0.03563367701800806, 0.010211688250170221, 0.06316306069493294, 0.014435815558369671, 0.05059998482465744, 0.06770986278674432, 0.04895885627982872, 0.034532380755990744, 0.020994602902127162, 0.07476463208773307, 0.04128495091572404, 0.044462503266653845, 0.07912801937865359, 0.029418068937957287, 0.07031545082905463, 0.008234506755668138, 0.0399290852780853, 0.02329961519821414, 0.04647616110742092, 0.007997391845232673, 0.051435885684830804, 0.003212513867765665, 0.03581558547115751, 0.029235176609030793, 0.02509109692515007, 0.044615977709846835, 0.019604447497321025, 0.04031219972031457, 0.02836816831092749, 0.022836888242246847, 0.035120097255068164, 0.0259909225694303, 0.05049613843272839, 0.03015389266823019, 0.035789081893329105, 0.035873135418764183, 0.02277253258840314, 0.07500631947602544, 0.0246310196484306, 0.04896120401099324, 0.007219057047872671, 0.025155544181221297, 0.022343316780669347, 0.0347480734677187, 0.07923176738300494, 0.05953104594456298, 0.03216960647010377, 0.06549553839223725, 0.052386513245957236, 0.010186901365938996, 0.01580130960792303, 0.02578767079726926, 0.026411882302324687, 0.03699904893125806, 0.07273366142596517, 0.051381687700216255, 0.04178537727732744, 0.04246732532711966, 0.03413667270381536, 0.036384492979518006, 0.04584339327578034, 0.06461224864636149, 0.01768586937604206, 0.032076843947704346, 0.05800267295645816, 0.013118722259865274, 0.054300728387066295, 0.04007114336958953, 0.0377480599896184, 0.021425019716843963, 0.04201351432129741, 0.03161490409235869, 0.03107184198285852, 0.03313250533704247, 0.03214048035442829, 0.0890589357752885, 0.05543889284932187, 0.086945238124047, 0.04195973363571933, 0.028492353790040528, 0.033066979210291586, 0.04026686679571867, 0.04857128725520202, 0.03392337182802813, 0.04993634704234345, 0.027070989167051654, 0.04593767571662154, 0.02304188215306827, 0.035724281799048185, 0.010106371981757028, 0.048231198718505244, 0.008449827969473387, 0.025050120195373893, 0.04361262119242123, 0.0477017310581037, 0.027171721083245108, 0.04075979195269091, 0.04915927177561181, 0.017705361990790282, 0.07355799326407057, 0.05815581152481692, 0.019153243762307932, 0.057642146944999695, 0.0859592996005501, 0.009307598861466562, 0.048686957119831016, 0.042262302578559945, 0.0432595081760415, 0.04245015839114785, 0.047908701202166934, 0.008621666114777327, 0.05788526604218142, 0.04491938803611057, 0.015762952023318837, 0.033661491237580776, 0.006180884050471442, 0.01435727852263621, 0.01123107091656753, 0.03279801132157445, 0.055765247837241204, 0.0503328761218914, 0.05169447538043771, 0.047364217561802695, 0.052299979675029, 0.0468799572970186, 0.018603935737961104, 0.03721582390634077, 0.027458093395190578, 0.019432961342058012, 0.031033063706542765, 0.009132966000054563, 0.014088261440130216, 0.004564675552371357, 0.03249406834532108, 0.01137086863829089, 0.07745869431112494, 0.08689504010336739, 0.008597662938492638, 0.026027797555018748, 0.044756078227822266, 0.016240939231855527, 0.030055413488298655, 0.03374523602958236, 0.0885575662500092, 0.04334005367543016, 0.03638934111222625, 0.01824699917675129, 0.07315498417509453, 0.02597434426258717, 0.06961062936378376, 0.020190464266176735, 0.033148861423666985, 0.020175455071564232, 0.022590127108352523, 0.04489270464650222, 0.03229186151708875, 0.06135893786059959, 0.07545251053358827, 0.041220798822385926, 0.03619572453733001, 0.03539628814905882, 0.04060195113665291, 0.01038258323179824, 0.02227653027512133, 0.03679472168109246, 0.024073141726798246, 0.0442763200428869, 0.03268560521038515, 0.08069785085639783, 0.09463263276432242, 0.015240861734907542, 0.04634268309122749, 0.06067728836621557, 0.01816243675005223, 0.009514835330524614, 0.08851592455591474, 0.05600072323743786, 0.04708751776654806, 0.02689305184009884, 0.03257481740521533, 0.07796461680637938, 0.026866161497309804, 0.058996645334575853, 0.041167231875338724, 0.07598613761365414, 0.019486509629392197, 0.01517313885103379, 0.031871003564447165, 0.06595838069915771, 0.01164394844922104, 0.15825664943882398, 0.04530728275754622, 0.02501270916712071, 0.0066181723045052165, 0.019940091629645655, 0.06772382025207792, 0.022617207440946783, 0.013099639310634561, 0.042837411896990876, 0.005796818386962903, 0.021824831209544624, 0.04854467171909554, 0.029603997711092234, 0.03165357719574656, 0.004008370135644717, 0.05384141106956771, 0.015609224825831396, 0.04211410374513694, 0.0322055382920163, 0.0042653720593079925, 0.029431337690246955, 0.023292778957901255, 0.02115000268843557, 0.016895725524851253, 0.030412180415753807, 0.025654038414359093, 0.011348141107841261, 0.02858912984707526, 0.04918266427037971, 0.04888880093182836, 0.00938884325192443, 0.06070594968540328, 0.027172448812052608, 0.028155893719355975, 0.014486288385731834, 0.03577864941741739, 0.08214171230792999, 0.0144496322276869, 0.04234687179060919, 0.02225506312346884, 0.05934443524373429, 0.021262033909027065, 0.03788938865597759, 0.03644747120727386, 0.06737820165497915, 0.07760987191327981, 0.03874455651800547, 0.02100377669557929, 0.048204657821250815, 0.02770350594073534, 0.032789153046905994, 0.05047551096816148, 0.03457468741440347, 0.054109856486320496, 0.027639513303126608, 0.04233683625768338, 0.049935834748404365, 0.09143509755709342, 0.042370393207030635, 0.022903376192386662, 0.014629016530566981, 0.01237790790453021, 0.12215811147221498, 0.049496747952486785, 0.06486765601273094, 0.05534808790045125, 0.03008249382089291, 0.019213387410023382, 0.017485957692510316, 0.02584006727140929, 0.04738944210112095, 0.026801992440596223, 0.05210128426551819, 0.0174268267583102, 0.07946334459951945, 0.040411337079214196, 0.03956468483167035, 0.03525235390822802, 0.04461961805022188, 0.0478684538975358, 0.02880054439551064, 0.013634201072688614, 0.04188892850652337, 0.026430720130779913, 0.05339836502181632, 0.008977215920042778, 0.08689427335879632, 0.04523139200838549, 0.05453602058280792, 0.042440492659807205, 0.014684274726148163, 0.022010575081886988, 0.0051351199425490835, 0.030742582865059376, 0.0231750548285033, 0.03252014105341264, 0.027408080275303552, 0.07843336236796208, 0.04983677202835679, 0.05795608474207776, 0.0348202153109014, 0.015381861311782683, 0.01666839254487838, 0.02790423865163965, 0.064897640475205, 0.0495700874099774, 0.058555726494107924, 0.004497234260530344, 0.05416737250717623, 0.04513397134308304, 0.053859341357435496, 0.0378629766803767, 0.035957714808838706, 0.07328438080315079, 0.09581415222159453, 0.037241801619529724, 0.014547203867030995, 0.011479672576699938, 0.027782190557835356, 0.07021946526531662, 0.01189644490036049, 0.018881787346409898, 0.03529944423852222, 0.03266632803050535, 0.023962908624006168, 0.03178978292271495, 0.016504943636911254, 0.026801381759079437, 0.09037506979491029, 0.028367438885782446, 0.023919166864029, 0.05653353946815644, 0.00993347108098013, 0.08179806146238532, 0.023944807006046176, 0.048903046774544885, 0.011402915847221655, 0.08706227184406348, 0.01936307902048741, 0.027724067248137932, 0.034251206022288115, 0.03293395920523575, 0.04287254983293159, 0.02583118185534009, 0.026343621679448655, 0.04058081816349711, 0.07575614138373307, 0.011711226044488805, 0.038835894116865735, 0.030063793395778964, 0.029389947054109404, 0.04199520066114409, 0.004161583766939917, 0.03496616819341268, 0.012172137071112437, 0.23849716090730258, 0.06562810377883059, 0.16787130066326686, 0.12722334824502468, 0.09849577689809458, 0.10875219332852534, 0.10536348766514234, 0.14522272454840796, 0.09520927896457058, 0.21138683706521988, 0.13593457080423832, 0.15155152923294476, 0.1601040153098958, 0.13352148314671858, 0.08389647850500685, 0.10344159150762217, 0.27880406805447167, 0.1016118268349341, 0.16851153916546277, 0.19256091011422022, 0.10215510268296514, 0.20877739494400366, 0.122786638459989, 0.26358306195054737, 0.06773289905062743, 0.21292530665440218, 0.1309101411274501, 0.154541710923825, 0.24166830788765634, 0.08528558896588427, 0.10849006846547127, 0.1513467337936163, 0.15330129462693418, 0.09578692939664636, 0.12131926577006068, 0.20131374044077738, 0.17315989759351524, 0.2260792643896171, 0.1135613713413477, 0.15838800024773392, 0.09291562704103333, 0.17941521693553242, 0.10008911961423499, 0.0904120160266757, 0.1823693277048213, 0.08689926737653357, 0.07389371882059745, 0.08911353748823915, 0.14042925462126732, 0.14470705150493554, 0.11326410514967782, 0.11367896146007947, 0.13366506115666457, 0.1277992616274527, 0.2085802669503859, 0.11385548913053103, 0.07527032388108117, 0.12076434626110963, 0.16939807230872767, 0.08308098797819444, 0.10272547243429081, 0.10074869636446238, 0.1599015404603311, 0.22022647916206292, 0.1256181922342096, 0.15742775106004306, 0.13854477288467543, 0.18381031895322458, 0.1280169899442366, 0.1423500379813569, 0.09847873209842614, 0.1389088069221803, 0.11830443968730313, 0.18566559654261383, 0.11300990557564156, 0.09339893396411623, 0.15645743241267546, 0.10966888056801898, 0.18648450688592025, 0.10865706271891083, 0.12226659565099648, 0.13423587195575237, 0.10098502332610743, 0.18337400736553328, 0.1751622680042471, 0.13592148864907877, 0.1236963232180902, 0.10632712952792645, 0.08847857120313815, 0.0992672915703484, 0.1459815709718636, 0.15890208551926271, 0.11724606076521532, 0.16576820851436683, 0.14277774574501173, 0.12123545312455722, 0.06770537767027106, 0.08964238089642354, 0.09468161620731864, 0.14617458704326833, 0.10163875788982425, 0.11185041815042496, 0.10760955392782177, 0.10761918233973639, 0.17670042546732084, 0.09405914853726115, 0.18952306812363012, 0.14364846902234213, 0.1988573893904686, 0.16921786697847502, 0.15877771005034447, 0.14553212294621126, 0.18009204204593385, 0.14036099399839128, 0.08165565731802157, 0.23147055080958776, 0.09078716446778604, 0.1921520656240838, 0.14811489864119462, 0.15133696288934775, 0.11467477945344788, 0.1374708419399602, 0.09792958692248378, 0.11190337780863047, 0.07498236040451697, 0.1827807913401297, 0.15246847431574548, 0.19068024174443313, 0.09208317992410489, 0.12463906620229993, 0.1162581816315651, 0.2470021631036486, 0.0940689058708293, 0.08416390951190676, 0.10879201654876981, 0.1706859724862235, 0.13048545962997846, 0.07917147276124784, 0.17352116320814404, 0.08705371551747833, 0.14946075927998337, 0.15591060104114668, 0.12951531740171568, 0.13573936985007354, 0.10349963339311735, 0.12060888031763689, 0.11216071221445288, 0.09713856436844383, 0.13255763772342885, 0.16175512171217374, 0.17651310909007276, 0.11717908935887472, 0.1967086996883154, 0.15340397054595606, 0.12752526918692247, 0.06717230020357029, 0.16859300407980168, 0.09627837195460286, 0.18688455756221498, 0.07972713187336922, 0.11946774726467473, 0.16823473758995533, 0.16375491368983472, 0.12922100962272712, 0.17831687230084622, 0.1839955590133156, 0.07802702845739466, 0.20535860982324394, 0.09084866688187633, 0.07628455731485571, 0.09426336722182375, 0.1077200397849083, 0.1596179806760379, 0.16692410648933478, 0.10142702103725501, 0.1930839249065944], [0.0665762886138899, 0.03327594424730965, 0.0123559488149892, 0.0684548399544188, 0.028744276879089217, 0.030494571530393193, 0.01522072111921651, 0.01600724159340773, 0.024161330923171978, 0.04505125453163471, 0.015904139893661653, 0.04069238628393837, 0.11804825200566224, 0.042639798750834804, 0.02003246738708445, 0.0303771917575172, 0.028250194819910184, 0.033465282658913305, 0.015656335512176156, 0.019252425225983773, 0.04086371298347201, 0.08346477417009217, 0.04015901026182941, 0.05249491260786142, 0.027069031593522856, 0.024213902120079314, 0.012334190741447466, 0.039379217462348085, 0.010428070523110884, 0.01777510860535715, 0.029294911439397504, 0.07619159123195068, 0.03468544129282236, 0.032292804680764675, 0.0552598579919764, 0.025730219237240295, 0.012139729390453016, 0.050098252283143144, 0.024594058149627278, 0.014909907975899321, 0.007376575559776808, 0.05893277483327048, 0.0375474986088063, 0.014080739879448499, 0.017742301437205503, 0.025495710749445216, 0.020449070925159112, 0.06509341818413564, 0.03907542037112372, 0.05258733247007642, 0.07052523350077015, 0.00826010194474033, 0.03329563533355083, 0.1047487145821963, 0.01870744116604328, 0.03363769840715187, 0.03077250286670668, 0.0281033428784992, 0.11464296973177365, 0.04273688014862793, 0.04669589788786002, 0.004081208749474692, 0.040093456993677785, 0.057509472992803366, 0.02689599328940468, 0.011760403718134122, 0.061047395292137346, 0.03374721056648663, 0.02268011442252568, 0.05142340064048767, 0.06706352425473076, 0.011510515385972602, 0.018507833126932383, 0.03605325932481459, 0.10082284667130027, 0.0706363639661244, 0.014359152975625225, 0.038059005447264226, 0.03588562385578241, 0.034702004332627566, 0.020294283516705036, 0.02055720565840602, 0.027033920798982893, 0.046148947772703, 0.04091696780441063, 0.025837086806339876, 0.015974858509642736, 0.014609238931110926, 0.03489944105967879, 0.05927185235278947, 0.030652398775730814, 0.04525257587166769, 0.019538816197642257, 0.038984876658235273, 0.022725781525618265, 0.01447762518988124, 0.058107981591352394, 0.028082116606778333, 0.07795428950339556, 0.018133576959371567, 0.05239304414551173, 0.05245450245482581, 0.07661762979945966, 0.026080579097781862, 0.027071537084079215, 0.023725204236273254, 0.029328590525048118, 0.0055436510343237645, 0.013116547555130507, 0.05180009614144053, 0.0008508801038260572, 0.01480063160748354, 0.010698503199299532, 0.05046025750094226, 0.02195874348814998, 0.014732389644320523, 0.018115404095234613, 0.04557540587016514, 0.029088185567940985, 0.014232721545600464, 0.04829215491190553, 0.03537770646757313, 0.027232536480629017, 0.04805369056495173, 0.055134451149829795, 0.04156156250142625, 0.08433608098753861, 0.003261942175283496, 0.01489383857032018, 0.031141133978962898, 0.021510822166289603, 0.06004082251872335, 0.022718210771147693, 0.01528430324313896, 0.005767709658747273, 0.039841109820242436, 0.012513418981273259, 0.012780011149256356, 0.014133478165604174, 0.022744317405990193, 0.03269944053941539, 0.0356102132770632, 0.03745481072525893, 0.02420710150285491, 0.1257046918783869, 0.061333526724151204, 0.04604258740852986, 0.09076623844781093, 0.0248335386027715, 0.03748488678996052, 0.052692478256566186, 0.05529079918882676, 0.030022643639573028, 0.08082321020109312, 0.07288140564092568, 0.05747342921261277, 0.09401041615222182, 0.00493194959459028, 0.0533047984354198, 0.029116850279803787, 0.10128626573298659, 0.02602125478110143, 0.0516804229202015, 0.047124270615833144, 0.040168153521205695, 0.09849999738591057, 0.033105764271957536, 0.05510756080704076, 0.015370258362963796, 0.056713280001921315, 0.08786945031689745, 0.02179222590556102, 0.07605832695428814, 0.027356379299557636, 0.01048487747487213, 0.06663077497588736, 0.023651087856186286, 0.021234164779473628, 0.017953800802518214, 0.03286773418741567, 0.02026604119289134, 0.03541968064382672, 0.017750024862055267, 0.016809868792604123, 0.03675346675195864, 0.05299621767231396, 0.04180948223386492, 0.027253313222900033, 0.08265055928911481, 0.019685978568824272, 0.02319235916781638, 0.00836850724382592, 0.04872814080278788, 0.03029617467629058, 0.017700118611433675, 0.04072886432654091, 0.046924438660166094, 0.04386869013043387, 0.04314734973013401, 0.05423719036792006, 0.023804538550653627, 0.010572645979534303, 0.01878077383818371, 0.033364113087632825, 0.03456387495888131, 0.054344429434942346, 0.039727757152702124, 0.03452434350869485, 0.009251637533972306, 0.028581313123660426, 0.038333591605935774, 0.010503538884222507, 0.018925600352564027, 0.06280924539480891, 0.07578038543994937, 0.023691652375938635, 0.055998344972197495, 0.025444228601242815, 0.016058613479669605, 0.07629683879869324, 0.03351169784686395, 0.022054961450131874, 0.06293670141271182, 0.0645170569685953, 0.02615919755771756, 0.037742977762328725, 0.046920828853866885, 0.045721094124019146, 0.014315251759918672, 0.08549957176936523, 0.03044252789446286, 0.06054576113820076, 0.029054377560636828, 0.03398278774693608, 0.04827180903937135, 0.021847672394609878, 0.0077561862168035334, 0.04356768521081124, 0.1113893264638526, 0.028915620541998317, 0.03103109256231359, 0.017969213725466813, 0.06212099375469344, 0.02165719404417489, 0.048002125296209536, 0.026771348102816513, 0.03942661652607577, 0.024213990329631736, 0.036564457429839034, 0.03127969761512109, 0.03797520637246115, 0.03127676295116544, 0.04812538118234702, 0.030640459952077696, 0.017313701400001134, 0.051917475914316516, 0.08172402650650058, 0.04195605258324316, 0.050456861433173926, 0.03807361091354063, 0.0337282489053905, 0.029228642316801206, 0.05911292588072164, 0.018194081926984445, 0.05639664842081921, 0.014701570583773511, 0.026982372493616173, 0.029543089015143256, 0.07225292615060296, 0.035990769642272165, 0.01975257508456707, 0.011624357446895113, 0.04113607693995748, 0.02397713071799704, 0.002473706703832639, 0.0487909358260887, 0.04372322579313602, 0.03094700850280268, 0.03298048974413957, 0.018043779635003636, 0.031027004388826232, 0.02405040062564824, 0.0981261720880866, 0.02729205078711467, 0.016109981973256384, 0.02800384080702705, 0.061337156886500974, 0.07323305641434022, 0.033161790908447335, 0.02387226652354002, 0.005283453634807042, 0.03496187985209482, 0.0778016462656004, 0.07546414062380791, 0.11243783948676926, 0.01576228196998792, 0.03883512058694448, 0.020636158296838403, 0.021363468108964816, 0.06204904190131596, 0.04425792495853134, 0.020393546404583112, 0.11034753772297076, 0.008255802577228417, 0.019250961286681037, 0.014909992792776652, 0.027408397490424768, 0.042550506935055764, 0.010396880812809935, 0.0037910383377623346, 0.03734202802713428, 0.010169708136735218, 0.03608545920412455, 0.015318289365885513, 0.05217944132164121, 0.013891944295859762, 0.014521847013384104, 0.012877977187080043, 0.015123468391331179, 0.023362174430595975, 0.07154983494962965, 0.035270511505327055, 0.01981610631836312, 0.18756491105471337, 0.03285338995712144, 0.07341429311782122, 0.06208959115403039, 0.03352811500164015, 0.03790892707183957, 0.0374212402052113, 0.04688269518581884, 0.057897825725376606, 0.024068095122597048, 0.04226416176451104, 0.023929807989458953, 0.02547753618897072, 0.016633380137916123, 0.027573999050738554, 0.020243203400501182, 0.043558901574994834, 0.07381327849413667, 0.035308970870184045, 0.0237319590523839, 0.028076216744791185, 0.05387291884315865, 0.06427466390388352, 0.11421687688146319, 0.012415217152530593, 0.03549654169806412, 0.014190707505414528, 0.04103022547704833, 0.06639222241938114, 0.14350243471562862, 0.16794725587325438, 0.08472643539841686, 0.1637594463037593, 0.0799073236329215, 0.12430545767503125, 0.14768237327890738, 0.09262736500906092, 0.12038929281490189, 0.16609959144677433, 0.1479757853916713, 0.08388972029622112, 0.2567096379186426, 0.10277182994676487, 0.07134263071098498, 0.10079298434512955, 0.1781136646334614, 0.1041857408625739, 0.12102600293500082, 0.10063676522778613, 0.11044616957328149, 0.18111403792032174, 0.15220791686858448, 0.1567300677831684, 0.08493564131536654, 0.09903169742652349, 0.07436786552092858, 0.0851898883868541, 0.195711755326816, 0.08487363000001226, 0.1251121951001031, 0.1342302808271987, 0.10001955620412316, 0.10554003569164447, 0.13227907195687294, 0.130601258416261, 0.08832248100744826, 0.15774820957865032, 0.1539435280220849, 0.08686633128672838, 0.11046055451567684, 0.13909819961658546, 0.1597352043858596, 0.09511604825300829, 0.1323926451482943, 0.06539863680622407, 0.1948107693876539, 0.17478574892239912, 0.12039801877524171, 0.11702093641672816, 0.1280589234083891, 0.12472228173698698, 0.14736268829022134, 0.26443258779389517, 0.19284798470991, 0.11459216102957726, 0.07385373953729868, 0.13480166159570217, 0.22526724796210015, 0.07639578956046275, 0.14547338895499706, 0.08884185206677232, 0.2287226196910654, 0.1468120842639889, 0.10054531906332288, 0.0850485156157187, 0.14844624086150102, 0.07975913158484868, 0.09497730819774525, 0.1581038569233247, 0.19904321299067565, 0.08682430961302348, 0.11425396560558251, 0.12875140910702093, 0.11796872770147664, 0.17673314442592009, 0.1343462017497846, 0.10803604711379323, 0.09830116626939603, 0.12878814499293054, 0.12908855958708695, 0.1037339111790061, 0.13013849753354276, 0.11718852099563394, 0.20718234910496644, 0.08905481706772532, 0.3380102925002575, 0.12262533711535589, 0.13560223792280468, 0.12416612729430199, 0.08553919821445431, 0.1510574607444661, 0.08983620442450047, 0.09378595676805292, 0.05634724089343633, 0.16491816698440484, 0.18715352884360723, 0.11681022415203707, 0.15861605586750166, 0.09540092439523765, 0.16680203803947993, 0.1479399994547878, 0.12132036499679089, 0.10889720983271088, 0.1118798665702343, 0.06909940751003367, 0.13225723669997283, 0.11299992432551724, 0.12518470335219586, 0.11779191504631724, 0.08154159558138677, 0.15357501565345696, 0.07948311032461268, 0.12483665559973035, 0.09160359137292419, 0.15942393323140486, 0.16800600343516894, 0.2310802846082619, 0.29575612555657116, 0.06327410973608494, 0.11741650876189981, 0.08819048559027058, 0.14187015087476798, 0.13650022473718437, 0.20924186573496886, 0.1066649721137115, 0.2621576227247715, 0.06781686097383499, 0.061324027233890126, 0.13635128630059107, 0.1321108088429485, 0.19070187344082765, 0.10603494556354624, 0.0883703516530139, 0.10850247887096234, 0.16712207586637565, 0.09376057277300529, 0.12158242879169327, 0.08890399230378014, 0.10527065050389085, 0.09996310887592179, 0.08252009736107928, 0.10451926118029015, 0.09449212851801089, 0.22572398345385278, 0.18726430647075176, 0.14035846984812192, 0.23860010824033193, 0.15263394186539309, 0.13112317398190498, 0.15184160295341695, 0.1426672259611743, 0.06523804113801036, 0.13197603821754456, 0.24281915756208555, 0.24833418162805693, 0.12643022223242692, 0.2240838421774762, 0.1166505648621491, 0.15414281375706196, 0.36505140577043804, 0.12119950433926922, 0.12480567369077887, 0.07039880207074539, 0.1261250036103385, 0.16881753131747246, 0.11121574363538198, 0.1427482973252024, 0.18838032015732356, 0.20382767197276863, 0.18768809230199882, 0.0755579684461866, 0.24649437463709287, 0.1317423100450209, 0.14544223062694073, 0.18410405676279748], [0.04148807715890663, 0.02387656843555825, 0.05285731137597135, 0.03939896961674094, 0.04540114789935095, 0.02914075167583568, 0.01910549186037055, 0.02326762905743505, 0.05174184391008956, 0.036024184099265506, 0.03762404414426003, 0.08872174458312136, 0.10853947938552924, 0.057059387144233496, 0.03067422385460564, 0.055976910050958395, 0.07606520729937724, 0.025623638349186097, 0.015949767980990664, 0.059447966116879664, 0.04092825523444584, 0.01923280199324446, 0.0850826594978571, 0.020377660203459005, 0.04427006734269006, 0.01748567440414003, 0.008933413091913929, 0.016924320686874644, 0.04257723442944033, 0.05229403231559055, 0.10000439773180655, 0.03218432389465826, 0.010830153411786472, 0.013838509663141199, 0.03392272043441023, 0.03288301818871072, 0.01083397610844778, 0.04033423514504518, 0.0667361311082329, 0.04683381013040032, 0.06261038713689361, 0.04759754539866533, 0.0439150103234819, 0.02714241006677704, 0.029629324030663286, 0.08171373991561787, 0.02951475678543959, 0.004289558440047715, 0.017798160136278187, 0.031008992676756213, 0.01177175306448979, 0.03264947322064212, 0.029307471122592688, 0.0641802389706884, 0.02756555807510657, 0.044378880610955615, 0.015535330665963036, 0.016776305057906678, 0.05742549749889544, 0.0614256514236331, 0.03375550226441451, 0.07814628098692213, 0.04698151024058461, 0.049138328792261224, 0.018109855375119617, 0.028362463527758206, 0.01946148186522935, 0.014628192110519325, 0.023334534306611334, 0.06179011972354991, 0.02997198760775583, 0.035856677551886866, 0.06502142561865704, 0.06275560041623456, 0.051789439748972654, 0.02953759966684239, 0.04423702268728188, 0.010135979857295752, 0.017969854941059436, 0.0439327845482954, 0.016449816059321165, 0.027673660577940087, 0.08353668531136853, 0.010625453815529389, 0.0630525816231966, 0.012538393310803388, 0.037011103105864356, 0.027474386717325876, 0.029554135565246855, 0.02850072691217065, 0.06279243808239698, 0.02749259350821376, 0.07265891400831086, 0.03817120121259775, 0.03573260063837681, 0.03442622734499829, 0.005241235185946737, 0.010173535922409167, 0.053907849825918674, 0.018847740155511668, 0.02502203732728958, 0.13634756792868885, 0.045143287628889084, 0.03307041599016104, 0.010030242897170995, 0.05481991284926023, 0.011968600314243563, 0.05402016094220536, 0.0777752919654761, 0.003426755786806877, 0.04936067793252213, 0.04556291064779673, 0.0768312733354313, 0.038369754129754644, 0.014959195063316395, 0.044182410796305964, 0.045408771240285466, 0.010039896754148816, 0.05755477199064834, 0.03639557006369744, 0.028230369723002826, 0.04757399344816804, 0.017109966171639304, 0.05194391163864306, 0.05376019382051059, 0.02611582899200065, 0.008914508258125611, 0.012808647871549641, 0.013075428333000412, 0.07559059919523341, 0.02675260866193899, 0.01637590323973979, 0.02290259418077767, 0.009106077353603073, 0.010287679083246206, 0.043872143873678784, 0.0541497136333159, 0.032773156583841355, 0.03152506605588964, 0.04692057440323489, 0.023763017296524983, 0.011178489541634917, 0.08557357958384923, 0.07888570095279387, 0.0756922165996262, 0.055330262785511355, 0.021775196372930492, 0.012809198333083518, 0.017909058203388537, 0.04209201403760484, 0.035869020103876076, 0.028052766574546695, 0.03771281348807471, 0.05115075848464455, 0.062193217022078376, 0.05966249853372574, 0.029436375812760422, 0.027068821247667074, 0.05912646943969386, 0.014491850676547204, 0.01663882707777832, 0.03528125950002244, 0.07965305620538336, 0.009333002364395984, 0.0014364591645841885, 0.03111349046230316, 0.02757416868449322, 0.013385865737551024, 0.01765723350191755, 0.01994087703392974, 0.09182738579277482, 0.010357753939128347, 0.038214953150600195, 0.025934858613514473, 0.014895634991782052, 0.011615634031061615, 0.024392333081258193, 0.04029527027159929, 0.058747337998024056, 0.07164356777710573, 0.05928794720343181, 0.06625971810093947, 0.00802961377693074, 0.03841663072151797, 0.004560449551458338, 0.01622488678965185, 0.02546924788371793, 0.02368817658030561, 0.05221115265573774, 0.05421138907383595, 0.015238395260114754, 0.015557961505172508, 0.0674013261284147, 0.036214173904487064, 0.05080565896683505, 0.055527814863515754, 0.0844308655442936, 0.04267286715496864, 0.007227210494290505, 0.006816025482424135, 0.12181041655795914, 0.01771676816445376, 0.040553809077079804, 0.023964742364894067, 0.0425891461116927, 0.045768968162259886, 0.012974832971979464, 0.0610479245494519, 0.024467798049694726, 0.027707139495760202, 0.03374345487515841, 0.038862122888011594, 0.03198789818478482, 0.06293929341648306, 0.07638574724218675, 0.0297090892147805, 0.06339681600885731, 0.05347206071019173, 0.041380668458129675, 0.025611636761043752, 0.045137618468808274, 0.01494963959391628, 0.051780367735773325, 0.011226932701122547, 0.04324978476922427, 0.028768005248691355, 0.030873652081936598, 0.01568208591613386, 0.011508772399143448, 0.04724569445742028, 0.025941776278029596, 0.024231932491862347, 0.02741719639327909, 0.00046844287135172635, 0.10582917303379093, 0.025575223179267983, 0.017399924541158334, 0.048990523509149037, 0.027827771147713065, 0.04180703950779779, 0.09672970630760704, 0.02475709654390812, 0.017268529627472162, 0.0069164575709562215, 0.0158056420540171, 0.036070874093898704, 0.024330140257786428, 0.052403256097542386, 0.03587202601400869, 0.03859113296493888, 0.03248216344841889, 0.011295317156639482, 0.06791564888720002, 0.04910408312987004, 0.04154746254373874, 0.028994971819754158, 0.08848587902528898, 0.04556354507803917, 0.024798390488805513, 0.036428770782159905, 0.0845098877325654, 0.03146576888060995, 0.03576786071062088, 0.018271965872762457, 0.02503848840881671, 0.041148524664874585, 0.020130943174340894, 0.04069052031263709, 0.007723072011555944, 0.05239418408434306, 0.022296674283487455, 0.016034099705783383, 0.029375707996743064, 0.08870969380119018, 0.05013474728912115, 0.12534550258091517, 0.05038490957979645, 0.013481377174944749, 0.01752481230401567, 0.024111175310931036, 0.05503651819058827, 0.011832162189031286, 0.06821161229163408, 0.015535630917708789, 0.004809162745784436, 0.012572247119221305, 0.018531169642561247, 0.04011367394455841, 0.028290679611797844, 0.08157466737819569, 0.04485532415232488, 0.09505597076245717, 0.02104236837476492, 0.022230947988906076, 0.047704343417925496, 0.02640690015895026, 0.023043346092371002, 0.03763885995639222, 0.03324990546596902, 0.04241593987015741, 0.014752216437565429, 0.058718635966735225, 0.010501050357041615, 0.04715541198051401, 0.03941797198993819, 0.03432514937594533, 0.010523848285499428, 0.03148571441748312, 0.05675146116742066, 0.008980196385112191, 0.028179323533549905, 0.051390949703220806, 0.029137966289584125, 0.06137731937425477, 0.021952619709606682, 0.058519770923469744, 0.053967476090682406, 0.05228016645248447, 0.04158716702035495, 0.026324196918202297, 0.012937721347303262, 0.05114670763058322, 0.013189032906666398, 0.009029568289406598, 0.07467220883284297, 0.03297533287799784, 0.01892986155248114, 0.04785023523228509, 0.04089796543121338, 0.0015125994874064677, 0.041651464998722076, 0.04309623568717923, 0.028667005311165537, 0.0067503844288044745, 0.025621748629159162, 0.046755829493382146, 0.03599902062809893, 0.050131687096187046, 0.03585872333496809, 0.030758972878434827, 0.02368395439615207, 0.0542194500698575, 0.01001716752736164, 0.05794024094939232, 0.06741936158921037, 0.01659381645731628, 0.04631185045998011, 0.03128991974517703, 0.08239660398768527, 0.045393989354904206, 0.04386960954538413, 0.030875718221068382, 0.1108480930062277, 0.13356718926557473, 0.1462370529770851, 0.1855472328939608, 0.15437545627355576, 0.1203466672450304, 0.10027077700942755, 0.14808520594877855, 0.18558204174041748, 0.10768427420407534, 0.1266984199838979, 0.15330267883837223, 0.20520636013575963, 0.07413531121398721, 0.09903257273669754, 0.15593596468014376, 0.21493007907910006, 0.09719178865530662, 0.09812486930085079, 0.16946205816098622, 0.12777480722538062, 0.11227725060390574, 0.1322199037032468, 0.14107800195259707, 0.24317679979971477, 0.09758930839598179, 0.1970293346260275, 0.0832317109618868, 0.14470139252288, 0.10811837376760584, 0.12843492680362292, 0.11093261132815055, 0.07864392535494906, 0.09853196995598928, 0.11246520480407135, 0.15482346580496856, 0.13634304888546467, 0.20320690742560796, 0.12534220490072454, 0.08021090020026479, 0.1876280148114477, 0.08432286991072552, 0.1719609262155635, 0.13789141151521886, 0.19081793007041725, 0.13286196067929268, 0.10469559207558632, 0.11069573475314037, 0.14745165780186653, 0.08910128993115254, 0.11796203734619276, 0.17116906227810041, 0.12553237112505095, 0.14253549517265388, 0.12461330901299204, 0.10040870282266821, 0.07433616436485734, 0.09680110176226922, 0.27020024401800974, 0.14706255868077278, 0.09649805445224047, 0.14727488585880824, 0.2210092507302761, 0.11560178042522498, 0.17803162974970682, 0.0949284401057022, 0.07975508751613752, 0.06923465310995068, 0.10879065269338233, 0.1375011588845934, 0.10062803926744632, 0.12300949650151388, 0.12097900759960924, 0.12919916079512664, 0.13889634901923792, 0.09166414383798838, 0.15715868478374823, 0.10698398535272904, 0.11956377354051385, 0.1452856111739363, 0.2371096382183688, 0.12043608458978788, 0.16854694512273583, 0.10218530427664518, 0.11761652731469699, 0.08699266093650035, 0.11226275709590741, 0.11815460558448519, 0.11793856003454753, 0.09576102292963437, 0.10554083636296646, 0.1678883997457368, 0.11108435889972107, 0.10659912707550184, 0.14156839278127464, 0.09986096899956465, 0.12465274546827589, 0.11854469536670617, 0.1334023866802454, 0.23707818133490427, 0.07147096882441215, 0.2684200666844845, 0.1840772817709616, 0.095325037038752, 0.15063332207500935, 0.08738894574344158, 0.1470711353634085, 0.12559452493275913, 0.07583833911589213, 0.1353294397039073, 0.06872309877404145, 0.10745785385370255, 0.1484722423234156, 0.1074575756543449, 0.09140727083597865, 0.1538450318787779, 0.07884280396891491, 0.1049492284655571, 0.10969418313886438, 0.1408370134553739, 0.09645030594297818, 0.14605892396398953, 0.1237253373754876, 0.10574939767164843, 0.13721458640481743, 0.14962339055325302, 0.09125555040580885, 0.103347600836839, 0.08739258947649173, 0.1758375053427049, 0.061120073177984784, 0.07125541860503809, 0.10829207194702965, 0.08089961324419294, 0.1279682439884969, 0.13241236337593623, 0.20943850518337317, 0.08852491514491183, 0.09234974240618092, 0.13320771498339518, 0.1551129695560251, 0.0745753954563822, 0.20655213935034616, 0.12712847547871725, 0.18769825675657817, 0.15074817091226578, 0.08039707663868155, 0.10892057857875313, 0.18985344682421001, 0.10417676384427718, 0.08772829467696802, 0.14910960383713245, 0.1708974718515362, 0.15081320170845303, 0.22945861305509294, 0.19160006381571293, 0.1199416768337999, 0.09707326894359929, 0.10670411679893732, 0.15277306868561677, 0.10475515387952328, 0.10704504671905722, 0.1428067870438099, 0.12936466905687535, 0.12819890518273624, 0.13928296470216342, 0.20087829737790994, 0.1895557056580271, 0.15667600211288246, 0.17050411153052533, 0.2493230514228344, 0.11935725462223802, 0.19379057841641562, 0.11146248610956327, 0.10950006105537925, 0.15202233754098415], [0.09497643967292138, 0.020131916872092655, 0.011351368390023708, 0.06941329102431025, 0.010615581131008054, 0.00484657971121903, 0.03973000310361385, 0.039032360538840294, 0.03514983065958534, 0.02218260576150247, 0.02925233675965241, 0.03977003327703901, 0.04211385947253023, 0.003662302009096103, 0.0714670740334051, 0.055896635965577195, 0.01764194101893476, 0.06805006667439427, 0.019719579622947743, 0.029507150407880545, 0.018281375457133566, 0.024539152792255794, 0.013932008396035858, 0.016078430094889233, 0.025832874800211618, 0.022721082670614123, 0.05871711604829345, 0.04081814596429467, 0.04608023253136447, 0.07148051581212453, 0.02746357426180371, 0.02699542072202478, 0.027370677728738104, 0.06956535072198936, 0.01996367920323142, 0.020881869397791367, 0.03927513697583761, 0.018302060597177063, 0.014628148005743111, 0.017204935629186884, 0.0213325252157769, 0.03523791468303118, 0.07001119572669268, 0.03297725313210061, 0.00855569724392678, 0.03923250462061592, 0.026561701138104712, 0.0580613390941705, 0.039191076665052345, 0.08779325083430324, 0.03036482206412724, 0.03990932973101735, 0.04190961703924196, 0.055492049282682795, 0.03131183981895447, 0.056459697894752026, 0.012512966907317085, 0.04074886753889067, 0.04126964655837842, 0.0818932056427002, 0.03722617156537516, 0.025464571081101894, 0.04327277692833117, 0.031949893438390324, 0.0340547701343894, 0.018810754907982688, 0.025805560373035923, 0.06792761145957879, 0.03975060681945511, 0.012093185280848826, 0.009213278253030564, 0.028398839790107946, 0.03253997123933264, 0.09058800086911235, 0.048584583148892434, 0.05716261946197067, 0.029379175310688357, 0.05482195523966636, 0.006363338724310909, 0.0296266064979136, 0.03187135640265686, 0.02340712907191898, 0.05186564940959215, 0.022575036489537785, 0.037465168562318595, 0.019235687463411262, 0.028717685091708387, 0.018523374971534525, 0.05856393676783357, 0.03875554199995739, 0.038644102801169665, 0.056855660397559404, 0.019207243275429522, 0.04729625888700996, 0.018014178544815098, 0.028750319233430282, 0.03010399659563388, 0.0541773266158998, 0.012876983981446495, 0.03354496981150337, 0.029279193175690513, 0.039888627627598386, 0.0035782378815513638, 0.010538284966189946, 0.0293159494176507, 0.026293544098734856, 0.059843694525105615, 0.016684641762237464, 0.11110943076866013, 0.035951787805450816, 0.07233616204134055, 0.024981574587790028, 0.012862147813263749, 0.02123988313334329, 0.026073423946010213, 0.052743548194744756, 0.04793661613283413, 0.022909886735890592, 0.059849862408425124, 0.022067643269630413, 0.03450053371489048, 0.043192893000585694, 0.024227918957227042, 0.06889812009675161, 0.06968984832721097, 0.03740905371627637, 0.027073774553303207, 0.019531951119591082, 0.038466309662908316, 0.04576420145375388, 0.08174418578190462, 0.03187748357387526, 0.02754612483217248, 0.025662370824388096, 0.03841890042115535, 0.029430499699498926, 0.04886447545140982, 0.025649649989125983, 0.046266605744936636, 0.016120358470029066, 0.05868035302098308, 0.04042870079034141, 0.03977292722889355, 0.03168439964896866, 0.02149230833830578, 0.0389808495528996, 0.04213659718100514, 0.0335582623125187, 0.023662198867116655, 0.01998231007850596, 0.0746635982234563, 0.02888654192377414, 0.030774341696607213, 0.05202350379633052, 0.03348548264641847, 0.03778184424819691, 0.02511130539434297, 0.04932489199563861, 0.03022396158693092, 0.042528919343437464, 0.03258836096418755, 0.012686978061018246, 0.13325357037995542, 0.022667142529306666, 0.04338905408180185, 0.02192083204032055, 0.015808245932151164, 0.07606819963880948, 0.02181861243609871, 0.0573813384398818, 0.0429411700793675, 0.036569339489298205, 0.04247701819986105, 0.02774400599966092, 0.05275296965347869, 0.038385920226573944, 0.006278853056885834, 0.03562680685094424, 0.017344927581559335, 0.03508480664874826, 0.008390686857247991, 0.013465452806225844, 0.029063439395810877, 0.029648424791438237, 0.015190695944641317, 0.03380264348483511, 0.025257838424295187, 0.009001143609306641, 0.01054359450271087, 0.05960793074752603, 0.0395064258149692, 0.05162209944267358, 0.027193615711959343, 0.037811163746352704, 0.014759843171175038, 0.03386709413358143, 0.036946727095970085, 0.04830378500212516, 0.06768228033823626, 0.0539548756953861, 0.04090019441874964, 0.011690485773475041, 0.01471163156176252, 0.06159255068217005, 0.053135212178209, 0.04404237134648221, 0.035207054910383055, 0.027174877967419367, 0.040530911912875514, 0.03536944869639618, 0.040185313671827316, 0.07902838329651526, 0.02446375398098358, 0.0760827949270606, 0.06311339193156787, 0.056169688635106595, 0.020052304358354638, 0.02911043812387756, 0.040036660219941816, 0.015781632092382227, 0.012516678493869091, 0.033934543907110176, 0.032624716870486736, 0.017916457627766898, 0.028833317636911358, 0.054746210375534635, 0.05017527618578502, 0.02816249416874988, 0.095143508565213, 0.08579225784965924, 0.04054331214034131, 0.023552579838516455, 0.02916912461764046, 0.030526326969265938, 0.019603709590488246, 0.06465618378881897, 0.03249121171289256, 0.026357714851785983, 0.02281541939425681, 0.03654686301680548, 0.01938995748891362, 0.03822801494970918, 0.019668794669477, 0.0692459371473108, 0.05742897159819092, 0.046024657120662074, 0.05028819798358849, 0.056223903583096604, 0.021549573301204612, 0.03234987626118319, 0.035617761979145665, 0.012782950054055877, 0.0324995305522212, 0.11393765972128936, 0.05939324226762567, 0.04022832939933453, 0.013745010082077767, 0.02129595217827175, 0.01129938242956996, 0.028993601179016486, 0.019007592827879956, 0.0035015683014145388, 0.06886847490178687, 0.037644128780812025, 0.05393274527575288, 0.03982470962884171, 0.014702076092362404, 0.04371210460418037, 0.03903434525376984, 0.009494229070177036, 0.08904681035450526, 0.007440388385605599, 0.028609241625027995, 0.004171808441502175, 0.036693131418100426, 0.04902868092592273, 0.019320455146953464, 0.03821796923875809, 0.03437423799186945, 0.033904854607369216, 0.02927838232634323, 0.05653006876153605, 0.020789520781753317, 0.012693633641382413, 0.04649019321160657, 0.07498492526688746, 0.017669850860589316, 0.05483889825908201, 0.003990662492079926, 0.05030481530619519, 0.05059797975367733, 0.05941661779901811, 0.04207434159304414, 0.023811437555455735, 0.07142214822982039, 0.05793664471379348, 0.009209013660438359, 0.040611396344112496, 0.01048100643259074, 0.08608791591333491, 0.049309899764401574, 0.05364922281088574, 0.03765854425728321, 0.008777540875598788, 0.02102187492086419, 0.01589438595276858, 0.013962790985325617, 0.023036925454757044, 0.032385889507297955, 0.008060841654826487, 0.03767003185514893, 0.02698416043339031, 0.016730339399405887, 0.01901966566219926, 0.08437781767653567, 0.032724220638296435, 0.030366593040525913, 0.034096255765429566, 0.007415989962672549, 0.004378928711438286, 0.02425524525876556, 0.03467292910707848, 0.06900251949472086, 0.04620624326967767, 0.012245240737684071, 0.01768157764204911, 0.10899572633206844, 0.030164881542857205, 0.012898566484052156, 0.06421736840690885, 0.028881805749343972, 0.022042060803089823, 0.06613604830844061, 0.057776971853205135, 0.02730561130946236, 0.04592816944101027, 0.008875135415499764, 0.05593620812786477, 0.06578794627317361, 0.012373554254216807, 0.07509402012718575, 0.029538912632103478, 0.03379877244255372, 0.06141469308308192, 0.03082621909145798, 0.03542332098420177, 0.055855459067970514, 0.016540598955803683, 0.020795815890388827, 0.005464177196180182, 0.03540194034576416, 0.01598387454370303, 0.17223384657076427, 0.2127142958343029, 0.0995829189196229, 0.213223916345409, 0.04001601918467453, 0.11279611276196581, 0.09170858109635965, 0.0905996241739818, 0.1371196729264089, 0.1055367583675044, 0.11211935550506626, 0.12008332780429296, 0.11091950203159026, 0.16990975556629045, 0.20315349314893993, 0.14565159939229488, 0.10370938892343215, 0.1328344935817378, 0.11331038802329983, 0.1319092432303088, 0.11180700547993183, 0.12645859856690678, 0.11330763317112412, 0.07223449035414628, 0.10763989801385573, 0.11543861989464078, 0.20143183267542294, 0.13204839719193323, 0.10798617478992258, 0.17227967482592377, 0.10848991240241698, 0.13218257070652076, 0.1262024108852659, 0.17025207648319857, 0.10730924789926835, 0.16174279951623508, 0.11969040174569402, 0.1458402049860784, 0.09173789380916528, 0.09443307561533791, 0.0933733939060143, 0.1460428698254483, 0.12159062549471855, 0.21246232864047798, 0.09974897679473672, 0.12909809978944914, 0.12726137334746973, 0.13066132233611175, 0.09049221208052975, 0.12035592246268477, 0.0858779703932149, 0.1227405523615224, 0.16218882772539342, 0.14483986794948578, 0.10902203992009163, 0.06938967122031109, 0.08916828169354371, 0.1158046895372016, 0.1236584202519485, 0.1597275233694485, 0.16158433444797993, 0.128568028232881, 0.1147337577172688, 0.1195208765566349, 0.13047876927469457, 0.13139183313718863, 0.20981464428561075, 0.1260886069919382, 0.19037448029432977, 0.1241454862590347, 0.10883923580071755, 0.1218269592417138, 0.16281649975904397, 0.12620720134249755, 0.1069970064397369, 0.11121997769389834, 0.06312886931534324, 0.1707806959748268, 0.13428765774837562, 0.07795180606522731, 0.09936734834419829, 0.13076137910996163, 0.16612386942974158, 0.1323299349418708, 0.11328796922628369, 0.08202544533248458, 0.16301123930939607, 0.09658437767731291, 0.09817328277443137, 0.12927422033888952, 0.12855394184589386, 0.17669449507125787, 0.10279954810227666, 0.10014807752200536, 0.1393864955753088, 0.09019177034497261, 0.09890265363667693, 0.0980929374428732, 0.07765825146010943, 0.10910988306360585, 0.12150759994983673, 0.13911917991936207, 0.13173590467444488, 0.0870013190433383, 0.1408342450324978, 0.1421625723264047, 0.10543083905109338, 0.1212369187601975, 0.17812780530325004, 0.20420368893870286, 0.18628036284020968, 0.12913269150469983, 0.09007910639047623, 0.08299848490527698, 0.09958159577633653, 0.12108109997851507, 0.1343287226877042, 0.10256089376551764, 0.11751195149762289, 0.10137990356556006, 0.0764959209731647, 0.087026268775974, 0.20635106228291988, 0.20819036715797015, 0.141086877190641, 0.10639463019158159, 0.15151803674442427, 0.05035956968952503, 0.12449841946363449, 0.14206282767866338, 0.17306984242584023, 0.076196150987276, 0.11978982069662639, 0.06277103030255862, 0.16173135941582067, 0.10239649151584931, 0.13057375060660498, 0.09257083625665732, 0.10470641470913376, 0.11036906085376229, 0.17968258687428065, 0.12937000234212193, 0.16755537475858415, 0.15154668449291162, 0.10076817710484777, 0.12478189782372542, 0.1374113615602255, 0.07660183350422553, 0.10408526339701243, 0.11403369956782886, 0.16651459703488009, 0.10788533091545105, 0.19684672728180885, 0.13483343060527528, 0.0839700995545302, 0.12219969209815774, 0.19627093603568418, 0.1934835956032787, 0.0705707428444709, 0.11940023303031921, 0.10074850637465715, 0.09153113061828272, 0.29138961700456484, 0.15427677014044353, 0.16421847524387495, 0.14096331596374512, 0.08263552295310156, 0.183984512463212, 0.13159525793577942, 0.1646117812820843, 0.20823835315448896, 0.06224644130894116, 0.15625672175415925, 0.12185690977743693, 0.1238031517714262, 0.062372621681009016], [0.03413620790732758, 0.04934038634278944, 0.03253499757764595, 0.02029696712270379, 0.020586660863565545, 0.03906700314421739, 0.03927607674683843, 0.009194527785958988, 0.027626314100676348, 0.012590729564960514, 0.01618656313179859, 0.05517383332231215, 0.05549860732363803, 0.02854957464816315, 0.06470333518726484, 0.026153134847325937, 0.004151945177000016, 0.06512159095810992, 0.03337831482557314, 0.03590457194617816, 0.012744410113165421, 0.010408281897460776, 0.03514622763863631, 0.051987069858504195, 0.032044576214892526, 0.03301964460739067, 0.033222346766186614, 0.0707417336691703, 0.04349935673443334, 0.007754794371846531, 0.03827798905383263, 0.032867615443787405, 0.0611285480803677, 0.03220823886139052, 0.021341062882649045, 0.014241293139223541, 0.043197792023420334, 0.0036456053827090985, 0.0923752621082323, 0.02894958800503186, 0.007042038711785738, 0.019489352691120336, 0.05113066706274237, 0.07508634589612484, 0.013679261735108281, 0.0358391883117812, 0.02073073759675026, 0.03587707092187234, 0.03723494841584137, 0.035369170497038534, 0.017277995190982307, 0.020555198891088367, 0.04073169381756868, 0.029094641828643422, 0.03333063416981271, 0.0622131863076772, 0.03376949026382395, 0.06299613429499523, 0.00890207410390888, 0.05800839979201555, 0.031710815017244647, 0.03596408285998872, 0.020521056705287526, 0.02853288947205458, 0.03957144982580628, 0.015228682031322802, 0.0259742798017604, 0.027170000996972834, 0.02729476662352681, 0.03992290721674051, 0.04798883618786931, 0.012074484007566102, 0.03181485479165401, 0.010870472810763334, 0.02742905040005488, 0.0501253360084125, 0.0157062909565866, 0.036523765684770684, 0.04605773231014609, 0.037214731464960744, 0.018451241610039557, 0.028170244735000387, 0.051299394973154576, 0.022336573838921528, 0.011209438372004246, 0.022031545206638317, 0.0357640846632421, 0.05259253344099436, 0.015463819860347679, 0.0698148412629962, 0.03466252377256751, 0.025680338431681906, 0.01623946681086506, 0.03271672621901546, 0.030795501811163764, 0.01833725451225681, 0.019678679228361164, 0.03540701578770365, 0.03915769274213484, 0.056655937007495334, 0.027510350769651786, 0.0686818506302578, 0.06057795762483563, 0.02909428220508354, 0.0517783728428185, 0.06850068178027868, 0.04509373760915228, 0.047420281517718516, 0.026893893223521963, 0.06288007766540561, 0.013082930385800344, 0.08126582537910768, 0.09092076801295791, 0.02870043333885925, 0.046665526660425324, 0.04726880196748035, 0.05724476969667843, 0.05699745725308146, 0.004950341286270746, 0.023382084344380667, 0.06167777468051229, 0.0663791877616729, 0.01456089161469468, 0.020694683638534377, 0.023099983410377587, 0.06072535578693662, 0.018649009122912372, 0.010988151139047529, 0.0533103692079229, 0.05628689877422793, 0.01538475017462458, 0.05052481332261648, 0.058911869169345925, 0.03497997638104217, 0.04956438432314566, 0.03454318303348763, 0.07352077561829772, 0.04346312974978771, 0.01820555086513715, 0.016686801199934313, 0.061891106090375354, 0.04574911422761423, 0.056951947909380705, 0.015287073362352592, 0.030259221659174988, 0.01464332513777273, 0.05036180546241147, 0.03555360310045736, 0.029483075985418897, 0.02911844483709761, 0.027700620470568538, 0.04594173335603305, 0.045988494596843205, 0.048885550749089034, 0.04822559401925121, 0.08077348036957638, 0.02548912387075169, 0.10728039659027543, 0.05427684395440987, 0.0836211425651397, 0.026324726175516844, 0.03279191468443189, 0.06425743589976005, 0.0260098503037755, 0.03208306272115026, 0.01540273304895631, 0.03697484897981797, 0.039468624629080296, 0.012215464076559459, 0.040214779055012126, 0.058147641963192394, 0.014116636078272547, 0.07793075790894882, 0.04935238962726934, 0.028212878786559616, 0.03995332594162651, 0.007978185063361056, 0.012367913931874292, 0.03861924806343658, 0.021601591492071748, 0.05416251080376761, 0.026234609939690148, 0.042615425772964954, 0.044022761684443266, 0.06328071188181639, 0.015773961253996407, 0.03943147822948439, 0.029955818118261437, 0.026359048173097626, 0.03064267536891358, 0.03386808479470866, 0.011715809548539775, 0.024599516963852302, 0.03649806956361447, 0.04418277041986585, 0.022030976933560202, 0.01874773427178817, 0.03950280583064471, 0.0170018823285188, 0.07726928804601942, 0.029657853035522357, 0.009989384062854307, 0.04712189235059278, 0.022358063042962124, 0.011572033915269588, 0.06308992819062301, 0.015908670811248676, 0.04773115912186248, 0.0458668570167252, 0.0320645658565419, 0.033318654634058475, 0.016540602348478775, 0.08215848569359098, 0.03483672406790512, 0.011043853775065924, 0.04021317092701793, 0.05834322289696761, 0.0500682542499687, 0.039003156391637664, 0.03956851176917553, 0.02562383173166641, 0.04417259578726121, 0.06040432729891368, 0.03930971512038793, 0.030431732402316163, 0.03413883723052485, 0.005160187994728663, 0.016226881682606678, 0.03288204109828387, 0.04853885328131063, 0.014657192697216357, 0.04096017352172306, 0.018825039766462784, 0.04287416135360088, 0.037871210702828, 0.006165103446359613, 0.005823036555999092, 0.01213185753606792, 0.01766289587664817, 0.03743786092049309, 0.012864789858992611, 0.02693483093753457, 0.03580329720196979, 0.10136112850159407, 0.0492216291438256, 0.04035468279783215, 0.0715013671932476, 0.02539365060095276, 0.057402949780225754, 0.08682944612311465, 0.01856714387291244, 0.01553507282265595, 0.02413864410482347, 0.01687417525265898, 0.06872961949557066, 0.046195593662559986, 0.062327926579330645, 0.037295772294913015, 0.0850212588640196, 0.04073188720004899, 0.05998790357261896, 0.04028876990612064, 0.05253943129043494, 0.01926183820302997, 0.03960478285859738, 0.04635319359866636, 0.03154202943135585, 0.013075605600274034, 0.05674946288179074, 0.011779743662503148, 0.05947045276739767, 0.05151476538074868, 0.016048286176685776, 0.044555493098284514, 0.014902986918709107, 0.06602993900222437, 0.043355741405061314, 0.05619017360731959, 0.0909862941397088, 0.026511445441948514, 0.0524451692056443, 0.017426326338733946, 0.03950510606435793, 0.07343712582119874, 0.019339165750092695, 0.05466345285198518, 0.036962160374969244, 0.0495632613476898, 0.021432156208902597, 0.03804088177691613, 0.06719036280576672, 0.04203718840809805, 0.055607135607195754, 0.03977857942559889, 0.03921490002955709, 0.03012660877513034, 0.04941562909100737, 0.04400587973317929, 0.05683127045631409, 0.009074393160907286, 0.04498889037807073, 0.031338177155703306, 0.03861929216821279, 0.040042644898806296, 0.06516960409602948, 0.054896112331854444, 0.005471383238078228, 0.029990012890526226, 0.03250323874609811, 0.0050633491732047075, 0.05027537027906094, 0.07292479117001806, 0.05268631376592176, 0.02496747632644006, 0.06266840866633824, 0.09338853880763054, 0.037988010328263044, 0.05007642720426832, 0.04493049904704094, 0.013378891245728093, 0.03882032173818775, 0.01196684714938913, 0.03943079969446574, 0.07658841886690684, 0.039690383443874974, 0.01951570699124464, 0.04797024432835834, 0.031455282121896744, 0.01972202574168997, 0.04880733262481434, 0.028168299035834413, 0.029112453372882943, 0.022400630937357034, 0.02993120765313506, 0.01241157341948045, 0.05193812034225889, 0.01994120273073869, 0.05771747790277004, 0.01826453421797071, 0.0355851617641747, 0.05492122830556972, 0.029219465130673986, 0.04158274297203336, 0.03862998927278178, 0.025511088049305335, 0.003955463063903153, 0.0322320486551949, 0.03819449531978794, 0.027394636800246577, 0.02372834924608469, 0.022364219051918814, 0.022195789696914808, 0.1834153572895697, 0.20038904648806366, 0.2088870597737176, 0.0717381691294057, 0.15216907752411707, 0.10403845126607589, 0.13330798888845102, 0.08606103914124624, 0.1844406644148486, 0.09978175682148763, 0.08731847988175494, 0.10263262170233897, 0.12763979232736997, 0.20679605911884988, 0.09451253885137183, 0.14414533307509764, 0.085175876638719, 0.13386251484709127, 0.14919139444828033, 0.12547935039869376, 0.0831875858296241, 0.10658977686294488, 0.16337169068200247, 0.21957321278750896, 0.08346925928656544, 0.0914033285475203, 0.16783951808299336, 0.17203019107026712, 0.07674945558288268, 0.08244271044220243, 0.11800995548920971, 0.18613618771944726, 0.1336696209119899, 0.13361265111182416, 0.10999432631901332, 0.11679456356380667, 0.1449944925095354, 0.21532966835158213, 0.1231986584940127, 0.170492128602096, 0.20290609928114073, 0.11845286243728229, 0.11560027407748358, 0.1531502663024834, 0.145090464502573, 0.12358490776802812, 0.12044164857694081, 0.18061618320643902, 0.17828404477664403, 0.13702735145177158, 0.09302256415997233, 0.10933501419744321, 0.13836456755442278, 0.08474060999495642, 0.17060612248522894, 0.1549779682287148, 0.07792357222310134, 0.09849763608404569, 0.1006750821002892, 0.15848117667649472, 0.1604923816131694, 0.16515843623450824, 0.09556050904627357, 0.09321626555174589, 0.09850697272590228, 0.16261658977184976, 0.07708216844392674, 0.19540192266660078, 0.16580179599778994, 0.1368729304522276, 0.19551355524786881, 0.10224420111626387, 0.12466506766421454, 0.15234613445188316, 0.07990071470183985, 0.22265895935041563, 0.11939291842281818, 0.08619340775268418, 0.12520971415298326, 0.09919500723481178, 0.2515731006860733, 0.17311803198286466, 0.1840465169932161, 0.1352430350546326, 0.12648863052683218, 0.19043474777468614, 0.0637742036155292, 0.13575752744717257, 0.14161941861467703, 0.11227332188614778, 0.11326386766242129, 0.14756966861230986, 0.13360803707369737, 0.10851672132100378, 0.1557090761406081, 0.11793638872248785, 0.11886351183056831, 0.17420572361775807, 0.13021933819566453, 0.17695373616048268, 0.1094151423977954, 0.12207619872476373, 0.13075844783868107, 0.10375325621238776, 0.1922430843114853, 0.1926944458058902, 0.1309182428355728, 0.12546681107154914, 0.1629555994378669, 0.19791573206228869, 0.12778612518949167, 0.2185276174651725, 0.16160006288971218, 0.10768900359315531, 0.13898862978177412, 0.11250296527785913, 0.11981043459049293, 0.16212748815970762, 0.1112309835319008, 0.152794944654618, 0.187522434762546, 0.16105001526219503, 0.15018771455756255, 0.10641207532691103, 0.1477630782340254, 0.2026366258838347, 0.12080811176981245, 0.1009600328813706, 0.12015750525253159, 0.1944840004933732, 0.14779301519904817, 0.12634134771568434, 0.18445598573556968, 0.08121045013623578, 0.12246817483433656, 0.23070475618754113, 0.10194794594177178, 0.13053753040730953, 0.0902513592903103, 0.1140572718743767, 0.1782864196492093, 0.10085118229367904, 0.26168576947280336, 0.07604514980422598, 0.11689717162932668, 0.08926770064447608, 0.09605702704616956, 0.1706295862261738, 0.07765008189848491, 0.13597217521497182, 0.11752641786422048, 0.0846021074269499, 0.19367042343531335, 0.19894873377467903, 0.15129935847861425, 0.12435868196189404, 0.0820650989189744, 0.1964542626270226, 0.12543216507349694, 0.1162544632596629, 0.0736914271754878, 0.11534146725067071, 0.10544278126742158, 0.1026165879198483, 0.13236193465335028, 0.1049050015530416, 0.1837623600981065, 0.12028284424117633, 0.06694383746279137, 0.11845130180673939, 0.12865881621837616, 0.07766345582370247, 0.16372562811842986, 0.0889866446544017, 0.210359711466091, 0.09670850887362446], [0.018480751098000577, 0.014446395615647947, 0.053816987201571465, 0.02249592948438866, 0.04242057087165969, 0.03987808658608368, 0.021536404632830193, 0.06345843377390079, 0.018000904703512788, 0.03611408320388623, 0.03651880220110927, 0.01908786012791097, 0.021042193651997616, 0.056390256620943546, 0.03706678368949464, 0.04099593231720584, 0.04802247116874371, 0.06728790900004761, 0.04223632825804608, 0.0483249519020319, 0.0006219043799709262, 0.01561495166138879, 0.04401047341525555, 0.039878022125256915, 0.05200039967894554, 0.023444236455751315, 0.07216426876506635, 0.036514846341950555, 0.015077989581706268, 0.019245080084406903, 0.05749410417463098, 0.00929991275604282, 0.03544332758922662, 0.03472076921856829, 0.021653446834534407, 0.045484930010778565, 0.03890676709956356, 0.05046931594344122, 0.03138011401253087, 0.05588162677096469, 0.058550881754074774, 0.04306894840140428, 0.043634748219379356, 0.03962014149874449, 0.031909710594585965, 0.006274488380378378, 0.011957071156107953, 0.07304136348622185, 0.03774315418143358, 0.03875817810850484, 0.004525067342910916, 0.030605457723140717, 0.025362002031345452, 0.024123607768810222, 0.017998495904196585, 0.0017318098731006362, 0.029984530327575545, 0.04827743748735104, 0.02724189687121127, 0.04018552741035819, 0.00686382530589721, 0.02543664936508451, 0.07874022304479565, 0.09401643475783722, 0.016111284760492187, 0.08374500913279397, 0.013598289606826646, 0.06639349127986602, 0.009549884208744126, 0.03268011246940919, 0.025381827128252814, 0.04145024883161698, 0.046617672978235145, 0.006662189295249326, 0.015532165300101042, 0.022512066743469665, 0.015709161159715483, 0.029676370256181275, 0.03251174418255687, 0.05241781406636749, 0.0249742090901626, 0.023956650834796683, 0.07632262991475207, 0.0189904275882457, 0.06558195661221232, 0.010250360505389315, 0.01573981567552047, 0.0963016932031938, 0.04004278399848512, 0.040972763738994084, 0.018889660048963766, 0.09205990617296525, 0.05086781955989344, 0.015250035528359669, 0.020904564697827612, 0.02201395418627986, 0.01958661898970604, 0.03917698688539011, 0.014689982901992542, 0.08222352327512843, 0.033856179897806475, 0.04927247855812311, 0.07037056822861944, 0.04575191657724125, 0.05339624459988304, 0.037262941378035715, 0.006611686357895711, 0.07611127982714347, 0.03756056719326547, 0.01219363306050322, 0.04086515487038663, 0.011689888662658632, 0.0527075824460813, 0.016614873095282486, 0.023951846806864654, 0.04688786901533604, 0.04089625213029129, 0.05791805285428252, 0.04059090119387422, 0.015508499694988132, 0.070982158982328, 0.08517880790999957, 0.054147080917443545, 0.037471811420151165, 0.032167424980018816, 0.026446282331432616, 0.049193856705512316, 0.0583326377506767, 0.05197947026629533, 0.01597564052125173, 0.0552047846971878, 0.014086713532118924, 0.018116666170369302, 0.014693626635042685, 0.04774318276239293, 0.03944322706333228, 0.08891869615763426, 0.022767197606819015, 0.05996520657624517, 0.02141146089083382, 0.05999000703117677, 0.04202242348609226, 0.0194033721262323, 0.022849826208714927, 0.014009848237037659, 0.03128847446558731, 0.017166264222136567, 0.02214184107391962, 0.007980869517528584, 0.03506297478452325, 0.023056199241961752, 0.021056091745517085, 0.03523980440305812, 0.025899612111970782, 0.03111090524388211, 0.07954353386802332, 0.03174225154465862, 0.01648338488303125, 0.02875165255474193, 0.0350372956267425, 0.03143101092427969, 0.013917587830552032, 0.028736351590071405, 0.057936006890875955, 0.060553869631673606, 0.0248742795416287, 0.061278830016297955, 0.07059792495731797, 0.03969000685693962, 0.060380659997463226, 0.0437145473302475, 0.07401467447302171, 0.017995790245809724, 0.03746061898501856, 0.019175009469368627, 0.026506697393155525, 0.043550297750958374, 0.020886890556929365, 0.05301645497924515, 0.05269617966509291, 0.02276811532543174, 0.030081587976643016, 0.0520139771646687, 0.029930237348058393, 0.048102046363055706, 0.019885600178635547, 0.06084629108331033, 0.09698810601340872, 0.027284391823091676, 0.06612487962203366, 0.029146631181772267, 0.04108287640182035, 0.05868738942912646, 0.03650658517809851, 0.03304609390241759, 0.050757513514586856, 0.04733058597360339, 0.03581880172714591, 0.03550817518095885, 0.032570427283644676, 0.07518342390124287, 0.01140710071194917, 0.0480418535215514, 0.02757681836374104, 0.033967771766973395, 0.033012557309120893, 0.054158273352576156, 0.03042667392375214, 0.05667222524061799, 0.03714822485510792, 0.04004421231469937, 0.047814157525343556, 0.027359926341367618, 0.05409324594906398, 0.0069767441351099736, 0.05230252078867384, 0.020898223788078343, 0.03368138249165245, 0.023822982828798037, 0.05009448980646474, 0.05427859118208289, 0.01530973643197545, 0.017299145127513578, 0.06655323877930641, 0.011709525466098316, 0.07048186154237815, 0.03692166540505631, 0.048429310587900024, 0.03316711740834372, 0.028437161751623665, 0.031846739152180295, 0.008279150119051337, 0.0356924449359732, 0.02685202082752117, 0.045210130113576136, 0.06199943420610257, 0.058132435993424485, 0.02087506708422942, 0.012245907398339893, 0.05266848186563168, 0.028318570793739388, 0.045990201112415106, 0.009933540630819542, 0.008928245199578149, 0.04916716992322888, 0.14800143401537622, 0.01683895249984094, 0.04234554525464773, 0.017811171045260768, 0.014256382061700736, 0.05333320530397551, 0.02985551707180483, 0.01128858863376081, 0.024118942840557014, 0.04379696558628764, 0.019439259843368615, 0.022457364946603775, 0.03299816558137536, 0.023463479708880186, 0.044982474829469404, 0.04164933439876352, 0.0351978946876313, 0.029623084901166812, 0.0402308535496039, 0.03525433862315757, 0.04728621656873396, 0.03747311760006206, 0.035086296033114195, 0.0364941408458565, 0.009093818770322417, 0.0015597012679791078, 0.0204719460369753, 0.05496652730341468, 0.03575852746143937, 0.024875673931092024, 0.02316743488024388, 0.011566670095947171, 0.08632400538772345, 0.06894951233906405, 0.02364552386903337, 0.011174289409869483, 0.01894205143409116, 0.04127560070316706, 0.04543502036748188, 0.023448741928275143, 0.022062803618609905, 0.020102509164384434, 0.019684088848797337, 0.11333341750183276, 0.018540294242224524, 0.020752711953329187, 0.01574184449522623, 0.02785935016748096, 0.024685758764722517, 0.04990440500634057, 0.00790533160657755, 0.050256598607770035, 0.030957166172031845, 0.055880598790411434, 0.03074665068249617, 0.007206878192456705, 0.045436642066176446, 0.0393806661346129, 0.007010668341536075, 0.03539686490382467, 0.010319911192969551, 0.023337350226938725, 0.019269727868959308, 0.02120590379594692, 0.06200689130595752, 0.05961357615888119, 0.022928219055756927, 0.08533732047570602, 0.06995876532580171, 0.06732001727713005, 0.027934267218889933, 0.01778235535935632, 0.007748927588441542, 0.05894829292914697, 0.00271984634205832, 0.016444759277094687, 0.08590963083718504, 0.029607817863247225, 0.051964335542704375, 0.012200262347635413, 0.025168105560754026, 0.05859750389520611, 0.02544228799108948, 0.04174532674785171, 0.025463940043534552, 0.01715201498674495, 0.09162980318069458, 0.050362273651574335, 0.032463269640824625, 0.08053859868752104, 0.020135536856417145, 0.040852591794516356, 0.016086160305089185, 0.004150432467992816, 0.03236818652866142, 0.03813647039766822, 0.046762370570961914, 0.02748845105192491, 0.05150804788406406, 0.0215710658979203, 0.05807108964238848, 0.027947446065289632, 0.05628798782293286, 0.07917857702289309, 0.06417120088424001, 0.023140086526317254, 0.0028449436026026626, 0.062300425555024824, 0.10431483214987175, 0.0896265913865396, 0.14034202215926989, 0.10226615850946733, 0.11136943860245602, 0.1243916859052011, 0.15981476940214634, 0.09113744460046291, 0.1601503999637706, 0.13996087546859468, 0.20693186111748219, 0.10475386466298785, 0.11684531798320157, 0.1085581255278417, 0.12196103776139872, 0.15879778111619608, 0.10714101192674466, 0.09763149291809116, 0.18051896270896706, 0.1370224388582366, 0.15676467306911945, 0.15241999977401324, 0.14536270632275514, 0.14585989607231958, 0.12425551749765873, 0.1422995821173702, 0.15808888844081334, 0.08481503850115196, 0.12618934230080672, 0.2063432727009058, 0.10434668258364711, 0.18290546536445618, 0.13966575344758375, 0.10466888493725232, 0.16869078097598894, 0.1104754822860871, 0.17786983985986027, 0.05448629414396627, 0.11500644737056323, 0.109840258157679, 0.11306498226310525, 0.15152609774044581, 0.15152404856468948, 0.15065074685428823, 0.09991356903421027, 0.13769998321575777, 0.11632925138941833, 0.11575176380574703, 0.32636294034974916, 0.09562640158193451, 0.13053451771182673, 0.09888924578470842, 0.12612124452633516, 0.21347844840160438, 0.12414757614689213, 0.12471598493201391, 0.17071888143462793, 0.10628030382628952, 0.09694275951811246, 0.15636395742850645, 0.11712925774710518, 0.13506063127091952, 0.18698970334870474, 0.0732102304963129, 0.11566993248249803, 0.10783472577376024, 0.11764292232692242, 0.14538167816187653, 0.30864769380007473, 0.143843927819814, 0.16550376984689916, 0.13624406419694424, 0.07515302553240742, 0.1367690060287714, 0.06217690504023007, 0.10176486362304006, 0.16584872347967966, 0.08796247746795416, 0.13088251118149075, 0.09295334680272, 0.1166121054972921, 0.1285857515675681, 0.09045500800545726, 0.24053925275802612, 0.14346379893166677, 0.1353802891182048, 0.2421117169516427, 0.08153437596878835, 0.18880485237709113, 0.07420766340302569, 0.20051025998379501, 0.08632494176604918, 0.06574526642050062, 0.08893792584006276, 0.15103866532444954, 0.15431635587343148, 0.13681480714253016, 0.08397887979767152, 0.28713669521468027, 0.09419234496142183, 0.23569063150456973, 0.17580163798161916, 0.1460173704794475, 0.13150919255401405, 0.11927211204809801, 0.08590408720608268, 0.1867227948137692, 0.17372519868825162, 0.0903554397768208, 0.12639366276562214, 0.1570666754352195, 0.18265492309417042, 0.08910193453942027, 0.14865337046129362, 0.13915096249963554, 0.12128402266119208, 0.1358325191374336, 0.151704321748444, 0.14040348386125906, 0.1886057159198182, 0.1667902586715562, 0.08708593914551394, 0.1462477059768779, 0.11445988741304193, 0.0967323797355805, 0.09012452752462455, 0.11522066087595054, 0.10244273367737021, 0.108761496043631, 0.11689805372485093, 0.1041826738842896, 0.10519956717533724, 0.07231162621506623, 0.11476212048104831, 0.17550876869687013, 0.1983386765101126, 0.24236497336200305, 0.2686558711741652, 0.11493296202804361, 0.11362671426364354, 0.13787180185317993, 0.07881306377904755, 0.0983842664531299, 0.08400056577686753, 0.17441319248506001, 0.12381509398775441, 0.11057533549943141, 0.09938257467001677, 0.14448359635259422, 0.12587374209293298, 0.17243592787001813, 0.14244890053357395, 0.11184265570981161, 0.11751264360334192, 0.24215962152395928, 0.10997711188559021, 0.12467496070478644, 0.22833859601191112, 0.11615779916090624, 0.10935388425631182, 0.12594999585832867, 0.040351283337388716, 0.17821393853851727, 0.11824844697756426, 0.12594164987759932, 0.1299597035561289, 0.21652448709521974, 0.12659752182662487, 0.119101935465421, 0.07207132303821188, 0.13321963005832263, 0.10890392054404531, 0.1245484139238085, 0.14391935377248696, 0.07670896739831992], [0.01400543182223503, 0.00944061971469117, 0.024020151534516896, 0.018725934637976543, 0.05532951300431575, 0.022280508186668158, 0.021353810859311904, 0.058511933844004355, 0.0642203064635396, 0.0918258319475821, 0.10165457454110895, 0.018066776883123175, 0.04402646987832018, 0.03451736138335296, 0.051044218308691464, 0.07089424798531191, 0.028723204974085093, 0.0408633160404861, 0.016426786580788236, 0.02820136913630579, 0.07977830019912549, 0.013288320391438901, 0.03641655036647405, 0.042888088284858635, 0.065131891119693, 0.03667350479268602, 0.051010006573051214, 0.06295635178685188, 0.024248023949829594, 0.04369061879281487, 0.05671814509800502, 0.023166362794914415, 0.011063955374993384, 0.00837242154271475, 0.04933893767052463, 0.025336066726595163, 0.021832982111456137, 0.04839722266686814, 0.04707054082038147, 0.04161510230707271, 0.03283628069662622, 0.0166939359956554, 0.01935724022665194, 0.04430373625031539, 0.06138506145881755, 0.010329222389762955, 0.04925321155626859, 0.023011141124048402, 0.012728182948194444, 0.027972792740911245, 0.04379794267671449, 0.002162649924035317, 0.08147533663681575, 0.04513435471536858, 0.05036281987226435, 0.03147881371634347, 0.01906277977728418, 0.05413098267412611, 0.010326245317368634, 0.041042510353560956, 0.04071038442530802, 0.03879626427910157, 0.0655701704589384, 0.05680105868460877, 0.03244986518153122, 0.031925072627408166, 0.027633448896397437, 0.05366762468059148, 0.008372796433312553, 0.01611176143134279, 0.031229845647300993, 0.03102094167843461, 0.07600113323756627, 0.05886873469821044, 0.008518527943773993, 0.010114503375786756, 0.008849243367356914, 0.03070542968011328, 0.01708505884744227, 0.03387607115187815, 0.030842286800699573, 0.055047761515847275, 0.035319874927933724, 0.11321434817676033, 0.0029413765753685895, 0.029796901824218885, 0.021708811899381023, 0.02879272767209581, 0.03823709374825869, 0.011120465467683971, 0.028837707758482014, 0.049229808883475404, 0.034944753628224134, 0.028912852119122232, 0.07557440934968845, 0.02399706098783229, 0.029256913478353193, 0.04156609172267573, 0.0414160506666771, 0.007964733106616353, 0.08472925131874424, 0.018206843474347676, 0.0287588450259396, 0.003723885847388634, 0.003275145194493234, 0.03584440624607461, 0.0383109353216631, 0.017951471731066704, 0.033391648038689575, 0.028109269881887094, 0.093651369347104, 0.08837310650518962, 0.02861503292141216, 0.031024330960852758, 0.0664155911654234, 0.020292098633944988, 0.052464395495397706, 0.017670836432703903, 0.028401251982099245, 0.010184365341306796, 0.016123732485409294, 0.06682038480149848, 0.03660409405295338, 0.02889044350013137, 0.039790952511663945, 0.06809525710663625, 0.05767412630042859, 0.04234694303678615, 0.032069475057401826, 0.01456919518698539, 0.03119497573269265, 0.03276297855856163, 0.0225662426756961, 0.06185867890183415, 0.03007156940709267, 0.08770505485257932, 0.005138887932324516, 0.03435178187542728, 0.044714677413659434, 0.046730031591973135, 0.006909167136265231, 0.015127400501764246, 0.06729360190885407, 0.07761404490364449, 0.020940442236938646, 0.029976605038557733, 0.027461268939077854, 0.03635854919307998, 0.03951707202941179, 0.006614129932131618, 0.009348183737269469, 0.07418614705758435, 0.030422507718737637, 0.018397486369524683, 0.06542531001780715, 0.0647400032196726, 0.033727509302220175, 0.04293091741523572, 0.03878359263762832, 0.05332685421620097, 0.03898416419646569, 0.054491400119981596, 0.02899256980578814, 0.04262737477464335, 0.03488785846691046, 0.0205658247494804, 0.04061162365334375, 0.03754938832883324, 0.008396771620027721, 0.030728937525834357, 0.03484304462160383, 0.03779406127120767, 0.05868929611252887, 0.010285675708603646, 0.05657276218490941, 0.02445453777909279, 0.05097946231918676, 0.044045641885272095, 0.019445541381303753, 0.0536503932837929, 0.026327939038830142, 0.02050547584492181, 0.044623438202376874, 0.03144975884684494, 0.04657110172723021, 0.016496816483725394, 0.04658641286992601, 0.048893452289381197, 0.007348282345836716, 0.039807963384581466, 0.02221957404565598, 0.03486151434481144, 0.016894745041749308, 0.020746593263798525, 0.04674298821815422, 0.06484134921005794, 0.025547360835064734, 0.02524863409676722, 0.05952629619943244, 0.05401849174605949, 0.043057749180921485, 0.040261136567486186, 0.030762779459889446, 0.011655329177821321, 0.03468506131321192, 0.06097333998020206, 0.08426271778132234, 0.05672319000586867, 0.01577728777192533, 0.0009819705779331603, 0.019565111125952432, 0.01666032985251929, 0.03222519205883145, 0.025745818757319024, 0.020179463517186896, 0.042094236239790916, 0.04771115251683763, 0.04325422578092132, 0.039410046700920374, 0.007866706000640988, 0.03350636116894228, 0.0189010899713529, 0.04348101932555437, 0.006386956407888127, 0.04030718873920185, 0.05715009370552642, 0.0670763621372836, 0.0010367025908115985, 0.033970913384109735, 0.05136457843972104, 0.007584677160983639, 0.03448213863053492, 0.009955759260005184, 0.05351438093930483, 0.018301974083962183, 0.02611262969938772, 0.05187851104087063, 0.01709802565164864, 0.02552584957863603, 0.04950301083070891, 0.020907709707639048, 0.01022178485124771, 0.039699418137648275, 0.05052433156275323, 0.001578547154037681, 0.05426782283133694, 0.029636865947395563, 0.034190500886844735, 0.07033039895551545, 0.04428886276270662, 0.02764092804864049, 0.05665123815249119, 0.04967735701107553, 0.04768751574946301, 0.01772090553172997, 0.05727505271456071, 0.014628483880577343, 0.05336977155613048, 0.016571755587522472, 0.0791569317557982, 0.016617141098582318, 0.006985810635212276, 0.014850614193294729, 0.0413233763538301, 0.04323275354025619, 0.082588419052107, 0.06901315213846308, 0.045560206685747416, 0.01744468749633857, 0.08946746135396616, 0.06156876124441624, 0.049321404325642755, 0.04654075764119625, 0.057088570935385566, 0.050646742672792504, 0.07162690974239792, 0.008118623152508267, 0.04820168583786913, 0.03473742386060102, 0.023485669500327537, 0.04254420334473252, 0.05567972867616585, 0.06117064439292465, 0.003584770901527788, 0.03283724760902779, 0.027481496067983762, 0.03464932965912989, 0.04401016128914697, 0.05313093401491642, 0.02989806461014918, 0.00892874731549195, 0.03220183349081448, 0.020300643086167316, 0.05289429831983788, 0.036793870119644065, 0.018406763639567152, 0.023741970836584057, 0.057405195731137476, 0.10868651113872017, 0.030830575286277702, 0.028118798209886466, 0.06208714164261307, 0.055113236752471755, 0.09267113730311394, 0.024557189949389015, 0.049071096149938445, 0.03849671481709395, 0.05908501773540463, 0.09089720927711044, 0.05122673065800752, 0.06224274329308953, 0.07373084327472107, 0.024097268735723834, 0.0405216804439468, 0.018038251270939196, 0.06917973927089147, 0.021629570883565714, 0.0490193069646401, 0.04109267105481454, 0.02546630982708718, 0.05119514485288944, 0.043904642308396954, 0.0568342254763203, 0.06460843527955668, 0.00482324616418087, 0.053279329623494825, 0.018442273073430573, 0.025764081527345946, 0.03421170171350241, 0.04276752957542028, 0.010498423578350671, 0.058342951482960155, 0.023076292360201478, 0.019259663498295203, 0.08685977663844824, 0.048243096830057244, 0.019870146543585827, 0.012834538223354943, 0.03829929844609328, 0.02721862990542182, 0.03652398620865174, 0.045243561533944945, 0.014340486477262207, 0.02170164996225919, 0.04050810295822365, 0.01153480778780899, 0.04179312953991549, 0.037384317722171545, 0.01872774802281388, 0.04999219047437821, 0.028882056807300875, 0.016869534073131423, 0.11240206033523593, 0.12038706722004072, 0.11354149026530129, 0.16915002704731055, 0.10539008623787335, 0.07684075925499201, 0.1278660837560892, 0.186273387500218, 0.11221946656171765, 0.1266996277762311, 0.11988063582352229, 0.09084357108388628, 0.09952055476605892, 0.09330455652837243, 0.1566913912871054, 0.07509293447115592, 0.07872454888586487, 0.09631846658885479, 0.1986038208539997, 0.139165605285338, 0.1037166899602328, 0.1930031113858734, 0.1339074202946254, 0.13953266558902605, 0.16733034540499958, 0.11263593778546367, 0.09846130053379706, 0.22762123521949562, 0.16393202490040235, 0.11488321184047631, 0.09720932878553867, 0.13703315971153124, 0.13748024643531867, 0.061976547219923565, 0.15165183027940138, 0.07661487494728395, 0.15310556441545486, 0.08793287977044072, 0.09671519922890834, 0.18843343587858336, 0.1566763820924929, 0.14221809006163053, 0.09591783237244401, 0.11325972181345735, 0.15301656776240893, 0.05249377266903009, 0.10893215438617126, 0.1690426149538585, 0.13813025584178312, 0.15982464887201786, 0.18367314631385462, 0.0699750365955489, 0.16036618767040117, 0.12324078194797039, 0.18461796561522142, 0.1249550599604845, 0.0699037497064897, 0.14373856490211828, 0.06892221487526383, 0.10779682280761854, 0.1264725492468902, 0.08642265080873456, 0.07997354865074158, 0.1846558821520635, 0.12933686269181116, 0.11086116159068686, 0.1453810946217605, 0.14828206252838882, 0.08145848182695252, 0.16420958643513067, 0.08577259390481881, 0.10409745667129755, 0.17582325610731328, 0.13997846309627804, 0.12011373974382877, 0.08210662526211568, 0.15199729959879602, 0.11362062101917607, 0.059594862163066864, 0.09276765212416649, 0.09371754686747279, 0.10494618184332337, 0.09950713334339005, 0.1733250394463539, 0.11016875053090708, 0.07778768201491662, 0.06228851726544755, 0.09939247449593884, 0.10183750079678637, 0.15327369182237557, 0.1551778239331075, 0.10807164984622172, 0.1483554257346051, 0.15560737731201307, 0.16349910598780426, 0.1053620423855526, 0.11310519224831037, 0.13167156598397664, 0.13496327506644384, 0.15191825026912348, 0.1327965363327946, 0.09075217920222453, 0.18052790580051287, 0.13381527523909295, 0.11769401601382665, 0.163847560861281, 0.1594819886876004, 0.10707440692931414, 0.06758678331971169, 0.09801133682153054, 0.13777219291244233, 0.20456370604889734, 0.1378380786627531, 0.14973905363253184, 0.08318596413092953, 0.12740809975990228, 0.09165922445910317, 0.10625380024846111, 0.11791399706687246, 0.048283490019717386, 0.061984961054154804, 0.1389745298240866, 0.19011671841144562, 0.12380473954336983, 0.2435212784579822, 0.26639672954167637, 0.17074085239853176, 0.11538927682808467, 0.10624878587467329, 0.11007766399000372, 0.1066234050584691, 0.11216109219406332, 0.157899889296719, 0.21283183167023317, 0.20267748726265772, 0.20459220451968058, 0.11869412234851293, 0.14803240235362733, 0.14327238420290606, 0.1948239193963153, 0.0702457313558885, 0.15001352104757512, 0.15015690906771592, 0.1109973978517311, 0.12107835869703974, 0.23467896293316567, 0.1539812952812229, 0.1857165680932147, 0.08586919693542377, 0.19356233280684265, 0.15546483067529543, 0.24992037937045097, 0.15381419924753054, 0.11162688835923161, 0.13605157738285406, 0.1906095655368907, 0.1729870340121644, 0.06573369061308247, 0.14853899659855024, 0.16510143929294177, 0.13635254837572575, 0.20187635453683989, 0.14636012565876755, 0.16018334962427616, 0.1341547327382224, 0.11946527739720685, 0.09898510921214308, 0.15782708248921803, 0.1766460205295256, 0.12220901516931397, 0.14758303575217724, 0.12062322454793112, 0.2367247731557914, 0.11761252395808697, 0.1575594547071627, 0.06570341438055038], [0.05040690429242594, 0.04180350434035063, 0.017267304871763502, 0.04677704389074019, 0.04616750231278794, 0.09226017578371934, 0.05261849079813276, 0.03396111533844045, 0.047388821241578886, 0.08309957305235521, 0.010570311819070151, 0.03358604832153235, 0.010614588773543281, 0.04031788584377084, 0.012249594387997473, 0.030090826230921915, 0.03166272384779794, 0.028528187224375348, 0.02024065380516861, 0.04389024040262614, 0.039998943850930245, 0.02102006832137704, 0.04102008816386972, 0.024834281598616923, 0.037217798443245034, 0.023683092656678388, 0.03232454994161214, 0.02034357569313475, 0.00760952680970409, 0.031138389304812466, 0.025644769626004354, 0.03590895528239863, 0.0294896509897496, 0.05582417181826063, 0.028149094798469117, 0.010607868732352341, 0.03189145800258432, 0.06019906367042235, 0.03204932935269816, 0.03350809143323984, 0.023568142039169158, 0.039460115799946446, 0.047210980605866225, 0.04627022572926112, 0.021103382243641784, 0.008592683339624532, 0.026180442489151443, 0.04687825417412179, 0.03133184303130422, 0.0065720565201315495, 0.0598160374377455, 0.07391891961119004, 0.030625348977212394, 0.014523789319874985, 0.051805602453116856, 0.023725024424493313, 0.024297840294561217, 0.037531186626957994, 0.013230430328154137, 0.044661999347486665, 0.08789975369083029, 0.06343001672731978, 0.02201416453213564, 0.03730609281254666, 0.01989351868230317, 0.09150472203535692, 0.04055655375123024, 0.026508670233722244, 0.027117718177448426, 0.03858595574274659, 0.13204851932823658, 0.0465586540023131, 0.0385489009453782, 0.07686490153095552, 0.04601499138932143, 0.08631243636565548, 0.06325099883334977, 0.014272312367601054, 0.048486314314816675, 0.04895503952034882, 0.019119501912168095, 0.02083141353380467, 0.03437577148101159, 0.026572783311296786, 0.04308170485975487, 0.006322143591075603, 0.01911077255915318, 0.07834226904170853, 0.0684896284448249, 0.03437273842947824, 0.055062143065567525, 0.046869721596262286, 0.04711986353088703, 0.014683379059923547, 0.0220922248970185, 0.04559398415897574, 0.03988553690058844, 0.02340134625722255, 0.024911978947264806, 0.05784075414495809, 0.06975139823875257, 0.03596157906576991, 0.018204068266121403, 0.08962727670690843, 0.0447713757998177, 0.02986739143463118, 0.011511059910325068, 0.03498385760134884, 0.0968609010534627, 0.06852770783007145, 0.016270129808357785, 0.07571531393166099, 0.07402929690267358, 0.0019072947200454238, 0.03347879907648478, 0.019374005130625198, 0.07664582971483469, 0.04066200827115348, 0.05559205516640629, 0.06458111067435571, 0.0482147544223283, 0.013400075109010296, 0.05141086131334305, 0.06210977078548499, 0.03489553609064647, 0.025803964119404554, 0.004267125224162425, 0.07174283066498381, 0.021806246135383844, 0.018024246308154294, 0.026124885738162056, 0.07774986047297716, 0.04215571490515556, 0.04186177353507706, 0.06148030063403504, 0.033317565585353544, 0.017164747696369886, 0.023041352895753722, 0.028228651333068098, 0.015216744904007231, 0.06383551603981427, 0.03514134897185223, 0.013685277796217372, 0.021750736881845763, 0.013220885036779302, 0.07908069834645305, 0.06343359939221825, 0.049964007522378645, 0.022589906584471464, 0.08135970748428788, 0.062331482102828364, 0.051392333914658854, 0.04928091274840491, 0.02436676248908043, 0.03109029135001557, 0.05674972411777292, 0.016313384719459072, 0.03077416867017746, 0.03595489549583622, 0.040696457494050264, 0.06694339641502925, 0.03437392247308578, 0.022806332114019563, 0.00826304593855249, 0.02184737383920167, 0.037705861896808655, 0.0350346323767943, 0.03268975105934909, 0.06943713474486556, 0.0887501412736518, 0.09287280469600644, 0.02310429380408355, 0.006134420092816332, 0.03584937312241111, 0.03342378684984786, 0.03660063352435827, 0.018167907438640083, 0.018841626554993645, 0.025391711687136973, 0.048048822076192925, 0.007742534940397101, 0.07750589320702211, 0.06463713731084551, 0.025405511393078735, 0.030470191767173152, 0.059999492950737476, 0.0341545215674809, 0.03912315870236073, 0.01879434793123177, 0.020182040253920213, 0.03833190883908953, 0.04761581834671753, 0.04103754686989954, 0.03700467059388757, 0.020262178632297685, 0.07845193387142249, 0.033670858413513215, 0.051300704545740566, 0.022589272154229026, 0.014324157532038433, 0.0167085957447333, 0.08519224290336881, 0.07768966763147286, 0.024309638322197964, 0.05342626298910805, 0.05824702698737383, 0.05424739892727562, 0.026146352889814546, 0.039416730270854065, 0.0033764258758830173, 0.025118107707904916, 0.024623331846669316, 0.024544648925906846, 0.021028220919626098, 0.0622056545689702, 0.0839838602447084, 0.02989877707191876, 0.11605080775916576, 0.022350461754415716, 0.05601736091609512, 0.031830237180526764, 0.03480989818594285, 0.013335085873092924, 0.04560215711327536, 0.0307451307640544, 0.037452188187411854, 0.04379057378641196, 0.05916148863200631, 0.03755429752969316, 0.022479378318946277, 0.021491733279877474, 0.03400307594399367, 0.03783662238025239, 0.03408921257193599, 0.01892597015414919, 0.03833495546132326, 0.024618105430688177, 0.0352466915334974, 0.060414498538843224, 0.05458675464615226, 0.039614153427204916, 0.018845835168446814, 0.016425327730498145, 0.04140374543411391, 0.01959408287491117, 0.02114370757980006, 0.08191921388996498, 0.04433733730443886, 0.0492374390097601, 0.05411568170945559, 0.03738710989377328, 0.01334356501631971, 0.01770275302364358, 0.0965513533779553, 0.0348445645400456, 0.018043894985956804, 0.03350473947024771, 0.016350273275747895, 0.10835335044456379, 0.04236971806468708, 0.03306906231279884, 0.011274924634822776, 0.009578568428488714, 0.04413060125495706, 0.03386145211490137, 0.04469574289396405, 0.06772285673235144, 0.02026435503337, 0.03191810407276664, 0.04991446428799203, 0.03326222426923258, 0.01688993931747973, 0.06852586221482072, 0.046074403915554285, 0.01999974503581013, 0.05650247613500271, 0.024614848462598662, 0.0865480780069317, 0.03334206069952675, 0.031822929358375926, 0.0170318277752293, 0.06886536721140146, 0.0230531882428165, 0.01841426993321095, 0.023221972132367746, 0.03188914759084582, 0.04168928314798644, 0.09196627512574196, 0.043989876484764476, 0.038227356770741086, 0.022698117652907968, 0.03270954392584307, 0.019407309325678006, 0.056288483153496466, 0.05504462668406112, 0.01874475211038121, 0.008824715174601545, 0.01905270353225725, 0.05548834787415607, 0.049266517627984285, 0.07355709759784596, 0.002578088078215452, 0.05105698494506734, 0.02323204668105713, 0.0026256088541621076, 0.10113302538437502, 0.019068202968420725, 0.03163306847480791, 0.02742662124468812, 0.014397469848128302, 0.03469258287389364, 0.015487527873899256, 0.03070882914055671, 0.08199708935405527, 0.04142258495890668, 0.0008428204860787705, 0.0021184071083553135, 0.059845004097691605, 0.02138394968850272, 0.027326764638668725, 0.041626091181699715, 0.09055076286728893, 0.09971668531319924, 0.01812924281693995, 0.04482269001060298, 0.03164604545703956, 0.060109809174069335, 0.029619264749011824, 0.06744799576699734, 0.03354090877941676, 0.015311999346262642, 0.016635332622432282, 0.03469484578818083, 0.020391741501433507, 0.06501690657543284, 0.01842851407958993, 0.01543141302785703, 0.03651697015655892, 0.012365577226903821, 0.03203966362135751, 0.043685821550233025, 0.014330252472843443, 0.01419463791951005, 0.061862017294125896, 0.014184735549081649, 0.09636055611606155, 0.040320793366325755, 0.006188259302039764, 0.04381996113806963, 0.010702905195233012, 0.044217280710914304, 0.023411078145727515, 0.11692227742501668, 0.1003101591819099, 0.1563849648726838, 0.16045344727379934, 0.12213324994913169, 0.14192655070551805, 0.19624946718769415, 0.13825326066996368, 0.20729539303907327, 0.1883625289691346, 0.11610389633902482, 0.15396213345229626, 0.14340129228574888, 0.11655776841299874, 0.13396818989089557, 0.11513656324573926, 0.11457320276115622, 0.12142304091581277, 0.08982904588005372, 0.20348503892975195, 0.15205591145370687, 0.11000729312321969, 0.10392903749431882, 0.06996702309697866, 0.17230583913624287, 0.18221037409135274, 0.1108183188896094, 0.08715366372572524, 0.08593899104744196, 0.1821409056761435, 0.14147622058434145, 0.11343861078577382, 0.08183014938341719, 0.13284943492284843, 0.13401453383266926, 0.07117736672184297, 0.10536054960851159, 0.17140968436641352, 0.09776046206908566, 0.1164326872676611, 0.15392767744404928, 0.3133530355989933, 0.15878665314189025, 0.13148822582193784, 0.1173232373382364, 0.0425308599535908, 0.10893799657268183, 0.1354130623596055, 0.10244131553918123, 0.07391169999859162, 0.12013101524540357, 0.17374115783189023, 0.0811620909454567, 0.14798099654061453, 0.1564118755715234, 0.11652879496770245, 0.12874838284083776, 0.17881292211157934, 0.07215611277414219, 0.2128397976713521, 0.15479270102722303, 0.20518088793115957, 0.15465508055474075, 0.1391179992684296, 0.10138478223234415, 0.14484814607671329, 0.13750179670751095, 0.1085091285141451, 0.11045466483171497, 0.0670155179021614, 0.19696097900824888, 0.09661208904747452, 0.08140886056103877, 0.17929518409073353, 0.182814677378961, 0.1460060660860368, 0.12636349509869302, 0.1630605280931507, 0.12402862895812307, 0.13029460129993303, 0.18312145663159235, 0.11792675352522305, 0.19429113369967255, 0.10661499122423784, 0.21796264206724508, 0.059689409232565334, 0.0815219519925969, 0.15214891146336282, 0.1338776190366064, 0.09541488186057125, 0.09740733208933047, 0.10559642195169415, 0.158473400665181, 0.07968451308884791, 0.10674279329500028, 0.1320956503706319, 0.11676853496049132, 0.0887965327128768, 0.15592594950326852, 0.19369398217116082, 0.17858184022562845, 0.1840311006775924, 0.12455419504216739, 0.15692452234881266, 0.1628946398517915, 0.13373671445463384, 0.08159623122108833, 0.07160989886948041, 0.2016882374882698, 0.17185316128390177, 0.1526472004396575, 0.21613791212439537, 0.16826514952949115, 0.13864235979105743, 0.12173864112368651, 0.14728486032358237, 0.13696019005562576, 0.11829864499824387, 0.16030449526650564, 0.11376831773668528, 0.14697126857936382, 0.0874976266973785, 0.1767295074782201, 0.11267782375216484, 0.1433515828102827, 0.1005732272086399, 0.12651636903839453, 0.1449195822434766, 0.09722933878323861, 0.17569224456591265, 0.09438346792012453, 0.22915728922401155, 0.10884095249431473, 0.08672446318502937, 0.07780529678400074, 0.144824885896274, 0.06143988708832434, 0.31809034996799057, 0.1063332227723939, 0.14174550399184227, 0.12501912723694528, 0.15200947251703056, 0.1563317948686225, 0.19744520873895713, 0.1121343986264297, 0.1346109661140612, 0.22215271794370242, 0.05614768374445183, 0.1115822611110551, 0.1475146258515971, 0.22634708216147764, 0.1594469491392374, 0.14188792849225657, 0.09436537139117718, 0.13253599245633396, 0.12670125626027584, 0.17628779475178036, 0.1383356891040291, 0.19791228510439396, 0.16603884899190494, 0.1800805748041187, 0.14645460487476417, 0.09718931200248854, 0.07458751409181527, 0.08984601604087011, 0.10071436927786895, 0.11562478276235716, 0.12953036730842932, 0.14176282020551817, 0.290700551122427, 0.2917015259819371, 0.19764140035424912, 0.15013582019933633, 0.11535403371921607, 0.13861186642731937, 0.16596248666090624], [0.019215740230200545, 0.054024958184787204, 0.0575353116063135, 0.04204999914925013, 0.04718242445960641, 0.022197145070614557, 0.016643478435331156, 0.017261496612003872, 0.063670679527734, 0.037585069092788866, 0.028693342647914375, 0.042560352478176355, 0.035988825639443736, 0.07400051344718252, 0.026723211132256047, 0.019034140510484576, 0.046609215039227686, 0.0057399211052273, 0.024518749244245033, 0.043963705389095206, 0.025443880852045755, 0.045286461910498996, 0.03494878073355981, 0.007028453592543623, 0.04512950318998524, 0.04932066472247243, 0.045720307023397515, 0.04974310026903238, 0.030522106481449943, 0.04659077585009592, 0.03860491740384272, 0.016245814505964518, 0.013604825595393777, 0.05989142267831734, 0.053290349032197676, 0.02618735676099147, 0.026020313313763057, 0.01207165451653834, 0.012810549465939403, 0.01353393734565803, 0.059722297824919224, 0.009306293529724436, 0.04268128438187497, 0.015531905760456408, 0.0165793721431068, 0.027108420551355396, 0.011775799677707255, 0.042033134161361625, 0.044918702715741735, 0.09981007887316601, 0.027633308100381067, 0.00848476997842746, 0.009913603575634105, 0.009219943163251238, 0.018004735033693056, 0.07214889316154377, 0.021436995859923105, 0.04934257461822458, 0.0348099253273436, 0.04186646221205592, 0.0265501847025007, 0.052660502293812375, 0.08175665725554739, 0.05627762659319809, 0.02656741440296173, 0.06468515044876508, 0.03954477322154811, 0.05120436953646796, 0.03992483425619347, 0.031258384830185344, 0.01148899395151862, 0.05684585217386484, 0.028891664863164936, 0.0418190801117037, 0.023580143627311503, 0.028009140165522695, 0.035693805398685594, 0.04582806856238416, 0.045965845097920725, 0.029868762075368847, 0.022348594086776887, 0.01929693542686956, 0.004516735356966299, 0.033535100519657135, 0.01347788271959871, 0.025143184665856615, 0.03994731412136129, 0.01496815511823765, 0.060819740008030615, 0.04027806940887656, 0.03546185498791082, 0.026951712888798544, 0.06200130696275404, 0.01782594614529184, 0.05030906293541193, 0.012907762329892387, 0.025154472095891833, 0.051703557571662326, 0.03521731775254011, 0.08284435567579099, 0.031790451279708316, 0.06194065271743706, 0.019622927398553917, 0.03290326567366719, 0.03254542326820748, 0.07323819970978157, 0.04250619859833803, 0.0261770498140582, 0.04154693328642419, 0.014360940915399363, 0.05475196435249277, 0.02874195628932544, 0.04750135627442172, 0.019307834395606602, 0.032608828973025084, 0.042845625563391616, 0.03394441659163151, 0.013121429614589682, 0.012095845986290701, 0.05536673065008862, 0.05421464604192546, 0.10389055098806109, 0.034127621046666584, 0.011508915739666139, 0.03145000651212675, 0.07858521171978541, 0.054722132560397894, 0.08791471538799149, 0.044272510068757195, 0.023250433283724954, 0.04012375018958535, 0.038587309420108795, 0.023345226322167685, 0.05855941093925919, 0.05765461163329227, 0.03760118769215686, 0.02754332248254546, 0.003990790565564696, 0.05171452269756368, 0.027636967100469128, 0.02715309020797057, 0.04164861515164375, 0.04203594329633883, 0.05856805547539677, 0.036319580926959, 0.05925616462315832, 0.04868400888517499, 0.02503217294413064, 0.016431655069547038, 0.025161613676963106, 0.08167347564761128, 0.03324329653488738, 0.018539610618193234, 0.004060169498968337, 0.043713953612106185, 0.007190674776211381, 0.04089719529396721, 0.05283322338280933, 0.09005704721701996, 0.048732184871499024, 0.05347041187009641, 0.040176608067538054, 0.04022419033572078, 0.05331180091681225, 0.021559081273153424, 0.016849049100918428, 0.011027490054922444, 0.057917835723076544, 0.027960930252447724, 0.019942208658903837, 0.04927063972822257, 0.019852413030873452, 0.03493202770394938, 0.03209303718592439, 0.02987348467909864, 0.01550707477144897, 0.05001637346244284, 0.01455158381057637, 0.01738276778321181, 0.025020878728745238, 0.003797166357149503, 0.05084069512252297, 0.0411299938735153, 0.020490222377702594, 0.09190904069691896, 0.017672076455450485, 0.04156814089843205, 0.045271920905049355, 0.011504662173267986, 0.02862030853118215, 0.04179711593315005, 0.02842527551443449, 0.010553792884041156, 0.02400843832375748, 0.04960520838254264, 0.04883950875539865, 0.018345310419265713, 0.04234393034130335, 0.05521645210683346, 0.06014714217079537, 0.04436142869027598, 0.0338745410554111, 0.0036799710609817077, 0.04726495128124952, 0.01684675904523049, 0.01323332088733358, 0.018153542852295295, 0.024894013036308543, 0.028614289925566742, 0.08607920352369547, 0.03154677578381129, 0.04245818206774337, 0.05935936979949474, 0.025811977617974793, 0.009643483025554036, 0.013000245804765394, 0.04567301991794791, 0.025335306767374277, 0.027801340512399162, 0.07716609644038336, 0.019019908238468424, 0.08495075229023184, 0.012238815011057471, 0.009093101219540196, 0.018739239013354694, 0.05643492118854608, 0.05502921036843743, 0.034965632150747945, 0.03908434649929404, 0.02262636596736099, 0.005045402346045843, 0.05233448657340237, 0.024464719197047607, 0.03552473482808896, 0.03758231084793806, 0.024688839313707182, 0.012616429926960595, 0.05107281516705241, 0.07607258297502995, 0.02288761212756591, 0.05295040298785482, 0.04149041131937078, 0.041878719947167804, 0.038618494889565876, 0.027537190222314427, 0.021232373447024395, 0.015369288057887127, 0.03741400362923741, 0.02539008150675467, 0.04111737312216844, 0.04653907148167491, 0.08428994060627051, 0.03190082857119186, 0.06525718261088644, 0.05939842627516814, 0.01293296820949763, 0.05701895324247224, 0.03738038900441357, 0.028640905461673225, 0.039809103323412795, 0.001953659441954057, 0.016278280710269297, 0.03662806669516223, 0.04775959652449403, 0.03130286280065775, 0.03249251450012837, 0.025309061032852957, 0.019779741930376207, 0.04221080177064453, 0.039747000405831, 0.029221042724592344, 0.014974521473050117, 0.05424053893823709, 0.025559187700439776, 0.028615935372986963, 0.07806438859552145, 0.07440669808004584, 0.06471091442342315, 0.020453225255810788, 0.05531590159184166, 0.025723761280200312, 0.03986808158723371, 0.06434762677443878, 0.0259987783086087, 0.05589709058403969, 0.012656998687556811, 0.054075061210564206, 0.0034305144467258026, 0.03524924621784261, 0.025134881093565906, 0.03307892481929489, 0.030546961219183037, 0.04111731205401676, 0.015531746304727026, 0.049381288433713574, 0.04100933338382414, 0.05061770137399435, 0.06862463655748538, 0.03789921045037253, 0.035419690821852, 0.04757424111344984, 0.017350674773167287, 0.05904028192162514, 0.05191778125507491, 0.006702150342919464, 0.025039855656879287, 0.06181983955736671, 0.02604590426199138, 0.010219866293482482, 0.014444293853427683, 0.01712654617481998, 0.041601697847779305, 0.05764230979340417, 0.013693883316591382, 0.041938173185501776, 0.03166901386742081, 0.057444706825273376, 0.030901064896689992, 0.04546896068911467, 0.02842911602264004, 0.004448080335610679, 0.05501022495861564, 0.10805550071277789, 0.01523226808889636, 0.015293687382446868, 0.016594325358580266, 0.07135137024202517, 0.015061580908617802, 0.03557673775191818, 0.03341023311285036, 0.017067471219758903, 0.02825507687936936, 0.06037598489118474, 0.03505129719685231, 0.056356750561722686, 0.08187012188136578, 0.04782241190384541, 0.033002196079386134, 0.044775725209287236, 0.0374693347673331, 0.028492642167423452, 0.030506093055009842, 0.0605977504913296, 0.05273880184228931, 0.013207448347072517, 0.05086500703224114, 0.0223083484784833, 0.03550912852266005, 0.02232419736018138, 0.043115105746047835, 0.06707155132400137, 0.025555769580283334, 0.11116588488221169, 0.1018718278833798, 0.11813525376575333, 0.1501299576567752, 0.13254279137722083, 0.12353622966579028, 0.16742616812033312, 0.09049637828554426, 0.1867378040083817, 0.08302365855446883, 0.11140502776418414, 0.12530168278941087, 0.19336658902466297, 0.2251053223652499, 0.06657318770885468, 0.09247398216809545, 0.10776318782674414, 0.07117209450474807, 0.1339476438505309, 0.19895861324455055, 0.06906252913177013, 0.1813275186078889, 0.13869151286780834, 0.1551706993154117, 0.12358174579484121, 0.16275651726339543, 0.1049062500574759, 0.0905400827260954, 0.0935170261987618, 0.16304607529725346, 0.15595695855362074, 0.14230551251343318, 0.1161046562982457, 0.12730811083955423, 0.12373453831034047, 0.09451508335769176, 0.08988685706364256, 0.10590096882411412, 0.0801743950162615, 0.1528068325881447, 0.10660870798996516, 0.18026433565786906, 0.14908434876373836, 0.11001667047717742, 0.08524387263293777, 0.1439134098057236, 0.07815329025366477, 0.12769013962575368, 0.19042694462197168, 0.26952274037258966, 0.22227636059480055, 0.1015617713066084, 0.08973506199462072, 0.14010131864675454, 0.11055527800428015, 0.22817827175770486, 0.06588672061583825, 0.09682003288928952, 0.1776478232017585, 0.11800236946770123, 0.07421497801052672, 0.1943814874227558, 0.27408189858709064, 0.17661065528435366, 0.13357822224497795, 0.17322108788149698, 0.0886706237548164, 0.12049298653645174, 0.08782569159354482, 0.1231319856430803, 0.10905716767800705, 0.13118990111563886, 0.10952112956770829, 0.09421878068574838, 0.11270790320954152, 0.23677047927464756, 0.09849866745727402, 0.09256194066256285, 0.22986150000776562, 0.08325010604624238, 0.1657585868878024, 0.15425792043762548, 0.08655373698898725, 0.09632628331226961, 0.11004425971103565, 0.12846989849848406, 0.1178724028702293, 0.08573502342083625, 0.1680403644485133, 0.10576962480055434, 0.1347696211721216, 0.12730037554034165, 0.15790017428142683, 0.09853277741266148, 0.10744534845330886, 0.1285602386508669, 0.08945623159940753, 0.14432374707290105, 0.08310641947069339, 0.18755986275417463, 0.170169824468238, 0.25434936742697445, 0.0932692252099514, 0.19646986893245152, 0.10196918408785548, 0.11815077864698001, 0.11400680243968964, 0.10822370275855064, 0.1054539703098791, 0.06908253912947007, 0.11874871727611337, 0.06452604077224221, 0.10188400080161435, 0.09328939805605582, 0.161823463759252, 0.14144575436200413, 0.17350726681096212, 0.0620208555566413, 0.11781187754656587, 0.13837661833635398, 0.10606609032090221, 0.25493890579257694, 0.17201505973935127, 0.10627016651311091, 0.14755205384322576, 0.09636872567768608, 0.10357136132993869, 0.19335144412304672, 0.10495450746800218, 0.19820994484637464, 0.12573053049189703, 0.07862660235592298, 0.08727792384369032, 0.14512458124331065, 0.08834472338535956, 0.08795162090765578, 0.11254553656492915, 0.07070878400866475, 0.11608119255730084, 0.08136473542877606, 0.24974043188350542, 0.1163451291088547, 0.14926587045192719, 0.09849944777254548, 0.09753295606268303, 0.13382311910390854, 0.1684589119894164, 0.09133221807756595, 0.07007505944264786, 0.12597451811390264, 0.12231117540172168, 0.07767189679933445, 0.16412680516285555, 0.07024944294244051, 0.11231367436370679, 0.08536111669881002, 0.11908892116376332, 0.1486616757299219, 0.17449571591402802, 0.11107534795467343, 0.1702567312334265, 0.1519031867917095, 0.22950079079185212, 0.11778602536235537, 0.16934011184743472, 0.06568957905152015, 0.10950474973235812, 0.14642294443079404, 0.13584021372454508, 0.09710203882838998, 0.12692115588911942, 0.18235144152172975, 0.16859030351042747, 0.11890738590487412, 0.21628492352153572, 0.0743518453091383], [0.0286668729968369, 0.015968135923945477, 0.02238151490954416, 0.01994546901966844, 0.011276865244976111, 0.03327542516802039, 0.03585451641785247, 0.022523016602333103, 0.03593965220664229, 0.008644637917833669, 0.012278487257260298, 0.022957770952156613, 0.02547914601330246, 0.02995806067649807, 0.040279053284653595, 0.012566638179123402, 0.012600588678781475, 0.05983212550303765, 0.007908737852371164, 0.055371100415608714, 0.01250681938004813, 0.004693554797475892, 0.0548984430996435, 0.02713524134430502, 0.0443717051031334, 0.03405090927013329, 0.032880928300853283, 0.020624821673014333, 0.04450153599360159, 0.030787026908780848, 0.013604675469520901, 0.014557697411094393, 0.008088393569258707, 0.08589607370751244, 0.018543308634044867, 0.031065022705921104, 0.04897855754409518, 0.05990365666470357, 0.04775347274595073, 0.024528850934335163, 0.04181802159707461, 0.029163363855332136, 0.049921619439763684, 0.017115287582523057, 0.034301098702209334, 0.026005276977749806, 0.06372180035603897, 0.03491679798545582, 0.05231706179412348, 0.04504796702946935, 0.003140781053973894, 0.05759804895413773, 0.02214821082140718, 0.040338733832218816, 0.019457756707976972, 0.05401657149195671, 0.07321225253066846, 0.005305025959387422, 0.032880500823791535, 0.003178090938100857, 0.12321830886815276, 0.004318945367620992, 0.005837245503373976, 0.04943510304604258, 0.027199103363922665, 0.09352426616741077, 0.04435925059286611, 0.013958567953003305, 0.02433844213373959, 0.01280996507765459, 0.03810840618929692, 0.054335262426840406, 0.0448616379206734, 0.05027806067040988, 0.04384800838306546, 0.058603997475334575, 0.04079662622617824, 0.03593039359631283, 0.03313329583033919, 0.029306551707642417, 0.01851411466486752, 0.013407460962688285, 0.03689529074888144, 0.02509867276863328, 0.01038915993246649, 0.04026750122596111, 0.04805927151548011, 0.05879504579518523, 0.01657511942487742, 0.0572683827153274, 0.025358359994632856, 0.020493323282737817, 0.058208051935902665, 0.0576700075928654, 0.10546472508992467, 0.020328895588006293, 0.042021558353943486, 0.02754253877459892, 0.01483801719067352, 0.027451377594843507, 0.023943212448752353, 0.05121858823778374, 0.0644619802811316, 0.041482923685439994, 0.02477441106124648, 0.0065946152649952895, 0.04736020402716739, 0.044913766373481066, 0.03436218381726316, 0.06163337813424213, 0.02966368504400764, 0.01788723312451371, 0.020782918636021868, 0.02780512334512813, 0.01417257365704115, 0.004594033642206341, 0.037323551518576484, 0.036510768346488476, 0.04390785517171025, 0.06759308012468473, 0.020538028562441468, 0.023031010325731974, 0.024379501984055554, 0.03837939611236964, 0.014129328923965139, 0.00950916192959994, 0.0365434364149613, 0.019658947430018867, 0.025916738335841467, 0.07484229042061738, 0.032004016784152815, 0.021177452822614993, 0.0294027510099113, 0.08127425956938948, 0.032041207288524935, 0.0886329175638301, 0.06558475896183934, 0.017196798297975744, 0.053299889234559875, 0.014226999799055713, 0.037374217728418965, 0.02800522671480264, 0.03729275281408003, 0.017041254322975874, 0.011549682971755309, 0.06949546161506857, 0.029308706056326628, 0.04949746380693146, 0.017813342357320443, 0.024947759795135686, 0.039160583301314285, 0.021857477225629345, 0.009378617729193397, 0.02114978216455451, 0.019947238299729567, 0.02604181269582893, 0.040910097637346814, 0.050208161385463815, 0.01655969802024109, 0.019411438211266483, 0.01993639361379402, 0.06014493014663458, 0.05319702332573278, 0.09221323473112923, 0.007453387420225356, 0.023667666163029413, 0.06297537790877478, 0.03384453962956156, 0.035155401432088444, 0.021669633287404264, 0.03268965945712157, 0.031413586145000796, 0.0689596835789936, 0.07313388173601457, 0.06765574283365693, 0.07249721911336694, 0.025253175192379525, 0.011472294356540909, 0.019127724060256566, 0.038770303529288085, 0.025869072947118963, 0.05030453710683754, 0.03966921315129314, 0.04824013163202575, 0.01792933961509594, 0.03997953435672181, 0.03137536087472524, 0.08069668377616576, 0.05525853484869003, 0.03390050180522459, 0.024240156336288367, 0.02537459903396666, 0.010826424013690224, 0.01291113464893507, 0.04386316007003188, 0.052956699792827876, 0.04120954531910164, 0.046138230312083445, 0.03693829629836338, 0.05079897539690137, 0.04653878649696708, 0.04514052259868809, 0.028110443747469356, 0.014523806283250451, 0.01125783403404057, 0.00803037203981408, 0.012597396171518734, 0.06938372725354773, 0.06968564819544554, 0.03884802632299917, 0.015156304397221123, 0.03471174131014517, 0.026952287947226847, 0.023301092708217244, 0.04511490450905902, 0.03918414203716176, 0.07838095232312169, 0.04211777122691274, 0.03028362856379577, 0.04597683057987264, 0.07345900857555014, 0.011886352540126868, 0.011045159954976822, 0.021165403737021343, 0.025704613021974052, 0.03732547177267926, 0.047407409708414755, 0.059535218934927664, 0.07837285061499902, 0.010873225966601499, 0.04053314768576196, 0.043522837438753674, 0.018126749200746417, 0.038490292483142445, 0.03272626302870257, 0.06237332735742841, 0.05542510162506785, 0.06247579293059451, 0.044156690926424096, 0.03773558173062546, 0.04526471147047622, 0.029827982120748078, 0.005090685228684119, 0.03163989453709551, 0.029711165531937565, 0.025585772702470422, 0.028482650739273856, 0.05140386900997587, 0.05557254049926996, 0.01496422809681722, 0.09481285166527544, 0.05505908626530852, 0.06493869184383325, 0.0061210957854720095, 0.037479109064276726, 0.042114381944494586, 0.018566543369420936, 0.02680290167752121, 0.06420227100274392, 0.021068799010078822, 0.04455419370372381, 0.06286514989499535, 0.05476842221937009, 0.01904639315658382, 0.0447119836296354, 0.007697339419142476, 0.01210096722934395, 0.03839935861261828, 0.05964530445635319, 0.018455614768234745, 0.02041230789784874, 0.032482852161462815, 0.029593778973711387, 0.024713112207661782, 0.03502593355785523, 0.0593718412731375, 0.007385360891930759, 0.06708380566643816, 0.008433363317245883, 0.0569247929379344, 0.011805967344636363, 0.025542460115892545, 0.0055980101710052365, 0.02122336589465184, 0.020347935280629566, 0.03193983754941395, 0.008614983393012412, 0.0963554128206202, 0.04518463076757533, 0.016193950681814125, 0.02409694473525243, 0.011467505595646799, 0.008261570973055703, 0.014866013545542955, 0.04272490061287369, 0.06881592914994274, 0.028993947231875997, 0.0305674122646451, 0.02703897588487182, 0.034347049093672206, 0.060951274021395614, 0.023962693189137747, 0.07162378848131214, 0.03805799103741135, 0.042746847828051875, 0.06787815982741968, 0.035642022998737435, 0.06730742366718394, 0.011338840937241912, 0.026533530060467974, 0.033391685358115604, 0.008120693532483918, 0.03775571047195366, 0.009085758622469646, 0.04517647816932627, 0.01861407474747726, 0.029814709975783314, 0.06451888222779546, 0.02582872555857258, 0.06431464318718229, 0.04947730792420251, 0.027719298843294382, 0.036224165332636664, 0.028199993406555483, 0.028214705742097328, 0.0491492328500109, 0.0276870836969465, 0.05126621800341776, 0.028788398618676832, 0.020953168161213398, 0.047411582698779445, 0.009538729941206319, 0.014901872424940978, 0.011208336600767714, 0.014497901512576001, 0.026605298709390417, 0.02992741803505591, 0.06132060741739614, 0.03076749188559396, 0.04488558342148151, 0.025182504073849747, 0.02713195384213967, 0.033054280427417586, 0.04209957970306277, 0.02237954715799008, 0.019832730426320007, 0.016980718821287155, 0.05109085062784808, 0.05595152944858585, 0.08162730133959226, 0.03986388145546828, 0.05104477131473167, 0.12898302025028638, 0.05844876901911838, 0.08956569965396609, 0.137292617931962, 0.09765220180686031, 0.10730246933443205, 0.13497557012098177, 0.17024567111262254, 0.057576410472393036, 0.12163325106459004, 0.11557287483343057, 0.09390687849372625, 0.09787559589104992, 0.1444376188197306, 0.09998929354229144, 0.10460409162832157, 0.15474840626120567, 0.14649679618222372, 0.1811735047293561, 0.19950429110654763, 0.10723117566002266, 0.17214043944009713, 0.10146383834736687, 0.08641878315912825, 0.14432222715445928, 0.14207128222499574, 0.08422187675854989, 0.10253354880426611, 0.1795379232083048, 0.17307045310735703, 0.15004112385213375, 0.16258134666298116, 0.21574030417416776, 0.1412981187126466, 0.11083344343517508, 0.1921685675957373, 0.16763384054814065, 0.09472249794219222, 0.1926261309002127, 0.09018739379410233, 0.14694237655826978, 0.16124809320483888, 0.1335178054869175, 0.09299233542489153, 0.10643922351300716, 0.128887021115848, 0.10083619345511709, 0.1397595541285617, 0.14560598826834134, 0.15408482615436825, 0.13133026286959648, 0.10825608923499073, 0.09613105521670409, 0.1459870399641139, 0.10192743382815804, 0.12467952046011176, 0.09300800958382231, 0.09307812260729925, 0.11169238734458174, 0.18630051533026354, 0.21554427540728024, 0.1598260873662574, 0.10236846123422895, 0.11439096182584763, 0.1265971147056137, 0.25016611761280466, 0.20421005359717778, 0.06622814586652176, 0.0917762853205204, 0.1278116109647921, 0.1704827376774379, 0.19048839275326046, 0.11540500526981694, 0.1685397797929389, 0.22485598788729735, 0.1549352883760418, 0.2468958773783275, 0.08467194903641939, 0.14699067468089716, 0.16836554557085037, 0.05801190781806197, 0.1045759120689971, 0.15068805270961352, 0.08041264901735953, 0.058126444529209814, 0.15181907559079783, 0.1282955149986914, 0.20244882096137318, 0.12207832932472229, 0.16140703324760708, 0.15368165421698773, 0.13322941453329154, 0.15642398063625607, 0.2454517377274377, 0.2001248113811016, 0.13709916759814533, 0.10295960094247546, 0.12642585246690682, 0.04517135522993548, 0.19808919275445597, 0.12509437677051338, 0.15392885809498175, 0.148625659091132, 0.1849952039441892, 0.06855038447039467, 0.09437871138964381, 0.08228463213890791, 0.11080996612352983, 0.11353323927947453, 0.10443665632711989, 0.08147961819278342, 0.16261428275278636, 0.1369067622082574, 0.1502058178718601, 0.05015070643275976, 0.09460361860692501, 0.10809396007763487, 0.09246242671672787, 0.1276558871780123, 0.13740129210054874, 0.10387702099978924, 0.15580023053501332, 0.15470264585954802, 0.18060612731746264, 0.09809553623199463, 0.11323087050446443, 0.1459413202745574, 0.1643138908381973, 0.13037377276590892, 0.18494890071451664, 0.12736643770975725, 0.0783392224194748, 0.22468420996197633, 0.14786943181284837, 0.12452716220702444, 0.1479786623801504, 0.17864384475563252, 0.15206823364964553, 0.13672218711248466, 0.10805945657193661, 0.16121435644371168, 0.12072105572691985, 0.19514589783336433, 0.11994573447321143, 0.18933770592723573, 0.13192312605679035, 0.13263074308633804, 0.16191008553973266, 0.08665663003921509, 0.06738531948732478, 0.13477168391857827, 0.12369392120412417, 0.1997686212084123, 0.10716659269694771, 0.12440094112285546, 0.10332828973020826, 0.1454910851482834, 0.08697912416287831, 0.09847434197685548, 0.0669270030089787, 0.07369625155947038, 0.13659904657730035, 0.11260676756501198, 0.1499546920614583, 0.08575549482234887, 0.1979053776179041, 0.1292730804000582, 0.19238130189478397, 0.07638806104660034, 0.13457093254796096, 0.17009434423276357, 0.08783982547798327, 0.25358340995652334, 0.14767588648412908, 0.15184788618768963, 0.13871420307883195]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.041385177323328595, 0.03105997440538236, 0.07903161312320403, 0.03130810448367681, 0.03815930988639593, 0.030633040171648775, 0.013633810066884118, 0.07037026288786105, 0.014192158722185662, 0.05431768836985741, 0.06266768941921846, 0.016766373001571213, 0.03695649800023862, 0.01933400209860078, 0.02440805982665292, 0.01905265773114349, 0.0403590763120779, 0.029125416784414222, 0.025898309324734976, 0.0156355791259557, 0.026602694831256355, 0.013050420924888124, 0.024475635129160116, 0.03460398655650871, 0.009357779918770705, 0.0169468853689198, 0.12459418789616653, 0.05822593133364405, 0.006664382659697107, 0.050404573524636884, 0.013896433653176894, 0.043783059011080434, 0.01957821024448744, 0.011602665530517697, 0.06343233053173337, 0.06291057102914367, 0.036796804783599715, 0.03636468654232366, 0.010164264589548111, 0.015648686726178442, 0.05389417055994272, 0.0020983258644784136, 0.04764511748882277, 0.029522169780518328, 0.07964295960430588, 0.021240955218672752, 0.010218397265167108, 0.06411993077823094, 0.07734425259487969, 0.03197293648762362, 0.08260922293577876, 0.07440513066415276, 0.02022642153315246, 0.03965203603729606, 0.05369292725143688, 0.004640931438189, 0.06226482282259634, 0.05267270913879786, 0.020231106817456226, 0.04286516058657851, 0.053512779596660814, 0.07367751042225532, 0.02939202676394156, 0.0217067152261734, 0.04561710863241127, 0.07235460462314741, 0.06767437540526901, 0.04710368047069226, 0.013414400679591511, 0.025861271490742053, 0.01663194503635168, 0.06486716746751751, 0.07877905560391289, 0.030134428891220262, 0.03544961760884949, 0.005643262095483286, 0.039461947844496796, 0.0695716068148613, 0.03746078522609813, 0.0346584627404809, 0.011793044645206203, 0.027274152729660273, 0.04093851129125271, 0.030429299854274307, 0.019331735791638494, 0.030966686018343483, 0.05688902735710144, 0.03718963245462094, 0.022912020728524243, 0.02084242446081979, 0.009469949390872248, 0.006191093457995781, 0.02066259571750249, 0.005363801086787134, 0.01929713220202497, 0.03795630917219179, 0.041888558704938204, 0.009039360397894467, 0.017958799909268106, 0.007391939288936555, 0.018528911817286695, 0.04286534379103354, 0.05175834588174309, 0.028139366302639246, 0.03468856594658323, 0.04446199097271476, 0.03644719300791621, 0.026037120626174977, 0.04016882187819906, 0.03766018970470343, 0.023896273092499802, 0.06052024822149958, 0.007532474917492696, 0.011872203388650502, 0.044255149750305076, 0.021691602554970553, 0.028108486173940555, 0.014644958710830127, 0.025737596609230553, 0.026644443394616246, 0.04430029268509575, 0.02980920027143189, 0.019379893118249517, 0.01776211296341249, 0.028776473365724087, 0.023457279595147287, 0.07447251597685473, 0.04595490372074502, 0.01847056968004576, 0.033225227147340775, 0.059216952084430625, 0.029756182937749794, 0.02720584800200803, 0.02423764406038182, 0.06807351005928856, 0.049418590896363766, 0.016689238836988807, 0.07836493889668159, 0.023461455978187065, 0.019072350513722216, 0.02146007792491998, 0.04300459274756057, 0.03195551170834473, 0.08132006068314825, 0.03739901479067547, 0.03944951029760497, 0.03319276263937354, 0.018554786053885306, 0.01974069563272808, 0.06259347804422889, 0.0326419041625091, 0.02496528296199228, 0.02904211643284985, 0.017052061689485396, 0.017557381984910796, 0.01805786941466587, 0.05842989217489958, 0.029001713065164428, 0.021570451823728423, 0.05780684096472604, 0.03188161585213883, 0.079564079908388, 0.036609688574182134, 0.040818281671298404, 0.026846936903893948, 0.03787815211606877, 0.044034639439944706, 0.03247906932873385, 0.06781958189925977, 0.03145331437034266, 0.05034170046980892, 0.004374533076770604, 0.013585737557150424, 0.029786822186516862, 0.0550600972824863, 0.047872572605098994, 0.059027030132710934, 0.030932983183967214, 0.10104941629937716, 0.041629575459020476, 0.03546547157956021, 0.0674697495996952, 0.03580069162749818, 0.033473177413855276, 0.020050010909991603, 0.04406884778290987, 0.043942619913390706, 0.038890689212296686, 0.00976925203576684, 0.033916844321148734, 0.05251230685306447, 0.10803522608642067, 0.05889464116522244, 0.015408091779266084, 0.06388975812920503, 0.004027248676201063, 0.04841868472950799, 0.04842439120901482, 0.05942103506198951, 0.04416672306667481, 0.04381887887471488, 0.04523408918508461, 0.04569563888279455, 0.053064383300287385, 0.024953362798052173, 0.03130346669682434, 0.007835773285478354, 0.03928386972152761, 0.02138079110799091, 0.020341368757986596, 0.09181954871330943, 0.04313392491479005, 0.03331535356119275, 0.014418948874143618, 0.052190470908369334, 0.05368829285725951, 0.0485699912533164, 0.05510069742532713, 0.029065145911382775, 0.0306295626796782, 0.03425329591014555, 0.03513141521917922, 0.007339669191943747, 0.0557940177220319, 0.03720350171040211, 0.021950429737833992, 0.028893591902617897, 0.059165003443402905, 0.021252073014953306, 0.005265439802315086, 0.030191490293613503, 0.01971727599655943, 0.007509245271129268, 0.032512412539550235, 0.04640378856233188, 0.08552286587655544, 0.04830392410180398, 0.05061862078894462, 0.03256556558023606, 0.020541131163814237, 0.04343918764165469, 0.04664701622511659, 0.10859408109847989, 0.04416268578331385, 0.043719582060085874, 0.023198572852249657, 0.009305161224412066, 0.005297443330554026, 0.023850309130336558, 0.04561428931940879, 0.010845389067461448, 0.010542016908792513, 0.0304740831655051, 0.03158347774296999, 0.021406929973246794, 0.05438139263008322, 0.028487563332808868, 0.02130405219005687, 0.051873588269310336, 0.017598728516272137, 0.05036801066515701, 0.04474042781761714, 0.06630315791283335, 0.03393135818519762, 0.07187610851334673, 0.010205121727527251, 0.06478114279785327, 0.035761424805969, 0.023953041028497473, 0.024433021433651447, 0.010338237575654472, 0.07703929181609835, 0.02857469062187842, 0.02465950115583837, 0.02871356638414519, 0.021090004925749133, 0.0421190468727478, 0.028520126228353808, 0.0777662063815764, 0.022582486804042543, 0.041439151391386986, 0.024893884114655, 0.017290013742500117, 0.031058430738214935, 0.022609375450494032, 0.017845026550016234, 0.02278323478198477, 0.027190843896408166, 0.0165110725044672, 0.06274439101772648, 0.03508052848545568, 0.024402334687433073, 0.028355335517387305, 0.003273656446253881, 0.0476154824718833, 0.040620264796806235, 0.03930640386949692, 0.020635995448433926, 0.01340675019725625, 0.06453355894024883, 0.07849315487380538, 0.02476678941664951, 0.04705902608111501, 0.006145242726363773, 0.046196319695029936, 0.018473421223461628, 0.02384609542787075, 0.01533306616225413, 0.02200925363493817, 0.046618551681084294, 0.021852747836549367, 0.010771347326226532, 0.036824567043887715, 0.04596642524536167, 0.023700553059045757, 0.009409754004861628, 0.02893231250345707, 0.047717449321810684, 0.03251612412610224, 0.045623775238969495, 0.06362667653177466, 0.02580862056597003, 0.002201034437998065, 0.021601550779970627, 0.05803785499717508, 0.05929395902369704, 0.005475789050771189, 0.05131936086607831, 0.05064044586781945, 0.06421675094004188, 0.017737137785713588, 0.02089798290814672, 0.04033065587282181, 0.038054588184292824, 0.07790903800300189, 0.014762034839285272, 0.04116422935788121, 0.016772710518645387, 0.033913346473127604, 0.04569980508780905, 0.0780045757336276, 0.04459838329681328, 0.028303992468863726, 0.034551817391599925, 0.015155746302168285, 0.06613517978361674, 0.02521162849318768, 0.028293157960953455, 0.06105272179203374, 0.012067466259135731, 0.02031126894455935, 0.06060502438672951, 0.30589794420770233, 0.2035402852509703, 0.1891509730901037, 0.16847711029861653, 0.11478790481175695, 0.14893656383667672, 0.13228508377713816, 0.15716211817094258, 0.06580357972000327, 0.15508322258080753, 0.11135531150336776, 0.12653158179351262, 0.13689336792698928, 0.12145472850118365, 0.09793989386941705, 0.16554505191743374, 0.12656739487179688, 0.08854620078844683, 0.13430460755314144, 0.10899201474551644, 0.07847872243395873, 0.14349005823688848, 0.1557812722665923, 0.10943440600697484, 0.08499315394354717, 0.12073926760682038, 0.24204750039747783, 0.14947792621595518, 0.09707724515880857, 0.1320137647645814, 0.08941781294665166, 0.11708006395825318, 0.101261356712452, 0.12274726985820703, 0.1839700596673148, 0.10712026911122458, 0.07873615862003394, 0.11249873121934277, 0.13627552108040877, 0.10177626979670354, 0.14117258973419666, 0.1457419531153781, 0.12992213985749654, 0.1725972020732505, 0.1453911369400365, 0.12312529528779642, 0.1572948396205902, 0.2606818090592112, 0.12195634229906968, 0.11225632458393063, 0.18540841819984571, 0.1911747037832226, 0.10590004601648875, 0.10421737416514329, 0.09857332666537591, 0.09161880412804228, 0.14077351614832878, 0.09415765825126853, 0.09811989563916411, 0.1540817048932825, 0.2122000748557704, 0.1398074451301779, 0.12448486233396189, 0.08890098639364753, 0.12814513806785854, 0.17242853183831486, 0.1783529839345387, 0.1614330889923232, 0.08024021969842059, 0.0938729178160429, 0.07604908530733415, 0.10843858801360641, 0.09295420175684349, 0.16111329543803418, 0.14890385844877788, 0.05570449859702161, 0.1113903849784817, 0.15514225512742996, 0.11737950146198273, 0.13554714087929043, 0.09973907696881465, 0.09892704697059733, 0.15407611376472882, 0.11335350213838474, 0.11404143486704145, 0.10410482556160007, 0.20547458502863133, 0.1284323755119528, 0.27632722524659975, 0.054279106868697066, 0.18042130794908318, 0.10725771994995219, 0.12679855818195002, 0.07688144421471016, 0.1390400491654873, 0.16365573901150907, 0.1590514446475676, 0.10085085659687008, 0.14014698405350956, 0.09839843426431928, 0.15865676796862058, 0.09491479476647717, 0.13286555691489152, 0.09496776799538306, 0.14378636090883187, 0.11221310868859291, 0.08343163451978139, 0.0752670940543924, 0.1244874679084335, 0.11790859592812401, 0.15354639504637035, 0.12621729794357503, 0.09643180907836982, 0.11797543162746088, 0.15556619023638113, 0.09848747162946633, 0.07709983071046216, 0.11916134799165384, 0.11522949540189334, 0.09711713623255491, 0.10037724593920366, 0.08685137637491737, 0.08637739930834089, 0.19328105290021214, 0.21911326103976794, 0.09409163679395403, 0.14727228028433664, 0.13232804861451897, 0.11850535390632493, 0.1542080074016537, 0.09765961140926395, 0.09372144844383001, 0.06007627597344773, 0.10062952525913715, 0.1450050233730248, 0.10084584900843245, 0.10946713853627443, 0.20027925952204637, 0.11383578447358948, 0.07536766651485648, 0.11685282258050782, 0.10610207303294114, 0.12008757543350969, 0.1857795768550464, 0.15515038397695335, 0.1656060250742095, 0.12181760902915682, 0.16086389310657978, 0.06951985494898898, 0.2114874366670847, 0.12642919085919857, 0.09875600186309644, 0.10057429929396935, 0.1709797102957964, 0.08667189707713467, 0.11895094785307135, 0.1346211712807417, 0.20777769573032856, 0.09747709227459771, 0.11765205540827342, 0.14089209692818777, 0.15487236103841237, 0.10562291874417237, 0.17040845166359628, 0.14376521775765078, 0.1679455866771085, 0.07955656852573156, 0.15625636891594955, 0.20277586126966135, 0.17671452542500837, 0.11582832969725132, 0.12101134657859802, 0.09668126569262572, 0.07150563517851488, 0.13464749843946525, 0.12095694164080278], [0.040615230066967864, 0.049434271840644736, 0.04984301455052836, 0.06729506754449435, 0.032257849949279, 0.006580749825973595, 0.014467279227184398, 0.09882804871137653, 0.025520144795466746, 0.013026991958862968, 0.035205894615501165, 0.034237285876380544, 0.04703861914042916, 0.05214583008949246, 0.023230547118665915, 0.030313375539013317, 0.04167376844478505, 0.010060687067120202, 0.014391910949988025, 0.010614699883652585, 0.07023277133703232, 0.04593600652047566, 0.031214256305247545, 0.037960624654910395, 0.04629328574186989, 0.03534096718898841, 0.08784786611795425, 0.037501816238675795, 0.026196133611457686, 0.011657777841069868, 0.01610642814609621, 0.0767997418131147, 0.07010460285735981, 0.02708804075207029, 0.09668838352497135, 0.03493625158444047, 0.023816351845328296, 0.03462490579113364, 0.054230615363589356, 0.07194565835275821, 0.023553806290562664, 0.029462533337729316, 0.05574095967624869, 0.05910367066306727, 0.002820118550776637, 0.02757648757791945, 0.048401779029518366, 0.015456829253318054, 0.027895234491942183, 0.044431036205164025, 0.010540853221235531, 0.03437877739114421, 0.012755738255301756, 0.015039611641051514, 0.03708985388012869, 0.005915999246229018, 0.04774973401799798, 0.028830406721681356, 0.029738320503383875, 0.03418476726593716, 0.024127853701689413, 0.031763618612395864, 0.007935575608696257, 0.017695957495431815, 0.07944355851837567, 0.08518786635249853, 0.08665324414947204, 0.04092728153669408, 0.009415809929903065, 0.022075217416776077, 0.018245022943509475, 0.0331051773391664, 0.027157168203432645, 0.03337368043139577, 0.008959721590924476, 0.04497706012002059, 0.07330167666077614, 0.0009301870117529429, 0.047200860256063085, 0.007946709520183504, 0.04013599096132176, 0.03202301576467497, 0.008341468471501554, 0.0450292191069041, 0.10976880842021533, 0.0275789710160877, 0.018685375207236836, 0.04885738476046494, 0.024489160028419325, 0.055366893498493094, 0.007008692108294261, 0.034718899854591916, 0.01608209079131484, 0.07003803178668022, 0.05196595045604876, 0.07487654965370893, 0.0312378252191203, 0.022601212674219693, 0.028158981053690826, 0.025754975587395684, 0.03577157908252307, 0.04561274565224137, 0.01992307397137795, 0.009026871960876244, 0.04689625570816653, 0.05236940737813711, 0.022768442718578235, 0.04955356168959822, 0.027218037883618047, 0.01040697656571865, 0.05105631319539888, 0.01793223526328802, 0.0674429406811084, 0.03048803045281342, 0.036618560419550965, 0.03768439983416881, 0.031578755139240196, 0.06659737748226949, 0.028281848478530134, 0.04697881984923567, 0.0561340417979019, 0.022709769795515707, 0.03835125726514629, 0.03897544502147606, 0.01159769102066223, 0.042750474597726545, 0.06458097496735198, 0.011305663119336324, 0.03137787484696933, 0.017416831937485507, 0.02670551833164479, 0.06139087650392737, 0.02907815682036536, 0.03578234064791884, 0.038777509571186135, 0.007452066821445311, 0.005912125235356922, 0.03233578648152096, 0.014519646863586136, 0.045258302707225084, 0.05274163133331707, 0.09642709325999022, 0.04914748562233789, 0.07273220257567507, 0.0039825221922780785, 0.02111025749971824, 0.018470554413007836, 0.1081239716815097, 0.07021932277296271, 0.049417413638106415, 0.023004011417339956, 0.053576147982052395, 0.030650539589779716, 0.017108088325975195, 0.02226516481355897, 0.05244198348373175, 0.05124780934836183, 0.059147992570485385, 0.058767524414828846, 0.028847641511155025, 0.04103153844230941, 0.01453226082958281, 0.07066604987319026, 0.010985992549519454, 0.013617135068800832, 0.02194258587301842, 0.07434630167803594, 0.03525347688368388, 0.023454589203798344, 0.03595762320661119, 0.034137184997754436, 0.03331388792555247, 0.06222629560423749, 0.03394034877419472, 0.01955016130315406, 0.04083245287516287, 0.006838499410410545, 0.03471811953932047, 0.06320791864501578, 0.036339702882937024, 0.01831358381813126, 0.026028024864249995, 0.05692851130983659, 0.07635272972817932, 0.01970495210428323, 0.01349521504848131, 0.02210072015545198, 0.02930852285187159, 0.022611894511750767, 0.0438124972528645, 0.01841976776319955, 0.028743432102991, 0.11573921090790204, 0.015254778488140022, 0.039323849004826376, 0.02612315208118941, 0.06800847247775112, 0.01933672641670065, 0.06291943948183741, 0.06930516646908862, 0.018039883147659044, 0.0382780060172081, 0.07567252551338502, 0.022816567814775875, 0.03657192470771926, 0.02222853579691478, 0.029288119303860834, 0.018710509840665118, 0.04246624645644, 0.06633227385048356, 0.11204671154596976, 0.056528630267296515, 0.02433082727449281, 0.028009884857705662, 0.04158168785007937, 0.034690774578068934, 0.051863413636705706, 0.05314505432865449, 0.04930695831509573, 0.014566131601376193, 0.014301083948729294, 0.038385323115757534, 0.0553019271631326, 0.026668914760063802, 0.0506657212972641, 0.011905643290707042, 0.031634126989437, 0.011136398318090608, 0.02164836460724473, 0.011228681625133114, 0.03366436144070966, 0.07250042179865496, 0.04312359082645603, 0.022874653805047274, 0.028323525795713067, 0.04136445147118398, 0.014350080962425895, 0.052588214565600665, 0.019176341094342724, 0.050633175365094624, 0.060756249486335685, 0.11252304991441113, 0.047022897484047074, 0.015653129434213042, 0.03440635305430208, 0.022321461167718683, 0.044814673119357655, 0.010596975700796714, 0.014030395125571107, 0.028554619556026797, 0.03464759260948215, 0.02999669306778482, 0.047692350311470885, 0.03446965019351669, 0.02095275934386466, 0.036233763210475445, 0.015614342676209552, 0.026638814946636558, 0.05419939936005643, 0.03786877815478614, 0.023831542548058287, 0.051613027429474254, 0.022379981420402015, 0.0629553339843239, 0.012147597003994244, 0.012187800203849162, 0.049035252537578344, 0.006374777128387774, 0.026226718577423265, 0.04630299897066184, 0.047180826509637494, 0.05746796700571265, 0.033820709479706626, 0.028909808889563595, 0.021996544674038887, 0.0542426898942462, 0.03473003122157284, 0.011828830582089722, 0.016609039390459657, 0.009476651620518948, 0.016286255193075964, 0.026575293890865784, 0.02247707638889551, 0.03784445945971778, 0.010981988344740654, 0.012830517055200679, 0.04022113692813686, 0.02047865165929709, 0.025002548105216453, 0.027589724099795734, 0.07089498758848224, 0.015205540594511797, 0.016001150045277815, 0.023976207910371677, 0.010815921987939094, 0.03441789832764438, 0.04630330091874514, 0.06635457051119634, 0.047761364108217616, 0.043352280876466205, 0.04079971695318818, 0.028181331997205104, 0.056423331810427566, 0.03947413772610681, 0.013428084186411329, 0.050955360755324364, 0.05330856769744839, 0.05496795561962894, 0.04024682965661798, 0.025426216889172792, 0.04137448700410979, 0.02954141642632229, 0.013554629271051713, 0.012714327263113643, 0.0391864287001746, 0.04652477814150708, 0.03440907058705177, 0.008153930722203637, 0.006779341758894069, 0.03893593392734017, 0.10404932818242482, 0.018532501267535344, 0.04374259118256824, 0.05264215809958322, 0.03570609027519822, 0.044985755546284575, 0.02721373936427491, 0.038753004278987646, 0.028847828108285154, 0.016919771109574606, 0.0241940278293831, 0.037122857823435745, 0.019602550991943905, 0.005613309863422598, 0.07758938015571662, 0.06139897821205003, 0.032030635712934394, 0.006679358351643064, 0.017534793554139987, 0.02796981397217938, 0.020881570842383162, 0.04846988019666501, 0.043085867672094276, 0.025968480023688505, 0.011077481122421367, 0.07527501934341022, 0.03232184937223792, 0.04139405595404761, 0.045231120594378026, 0.0313190492535276, 0.022598082931446176, 0.039044034733836136, 0.13014885197792733, 0.0724532636148589, 0.18633180936532362, 0.1682350497160639, 0.09679545635091406, 0.08180346260113375, 0.11079947597214154, 0.14352486708334514, 0.0906288418918848, 0.07859879599085876, 0.14265289530158043, 0.1516547208385808, 0.10651593868221555, 0.14492099359631538, 0.1025443442964128, 0.13981178775429726, 0.19195035073373998, 0.10026233603379556, 0.11177908376391445, 0.2239240336098841, 0.19778413698077202, 0.14961363321968488, 0.1548673670206751, 0.11102662914033447, 0.11393722545887743, 0.11732759353305612, 0.1290069996778454, 0.1612013964248555, 0.18705838466329233, 0.12790693156421185, 0.050473234483173916, 0.18305217820618833, 0.1558671069464513, 0.230580529996327, 0.1966760621539184, 0.11066568243716444, 0.12270047808332102, 0.1429952433598893, 0.16245608909853868, 0.17285185626574925, 0.15646204645080225, 0.14202660747936793, 0.13127089105546474, 0.1593254642294986, 0.08794094755181245, 0.12334618557776723, 0.12594257268522466, 0.06815629133156367, 0.1348735320248774, 0.09287312360746519, 0.09164732295487608, 0.2063429198626961, 0.1431034832660641, 0.13082632848194667, 0.09029319097420999, 0.09703195294631378, 0.1221250125340053, 0.10799647495150566, 0.08089901613337652, 0.10997383456145014, 0.09027415128158671, 0.15982676590127604, 0.09467577402080808, 0.09516910969146661, 0.17886462648000034, 0.1801666130444833, 0.14289632652487072, 0.13981442047016962, 0.10853030559207712, 0.13442649958389147, 0.1157579520451171, 0.12071462321494307, 0.18678376797054494, 0.1053086348942348, 0.07057256131832089, 0.19913258962333202, 0.15669418685138226, 0.12394306569227151, 0.12706822156906128, 0.1304705725716693, 0.1676573042890855, 0.10928554899458374, 0.10864859460187809, 0.15815123223832675, 0.17041997318821295, 0.16248917446604796, 0.12112524546682835, 0.13357349964124815, 0.11011282567467008, 0.07824881441359009, 0.1680187870349203, 0.09811237747115747, 0.13714243099093437, 0.21631055857454026, 0.10142940269517046, 0.1756029086453574, 0.12211973353156022, 0.05913790275475808, 0.062000323086977005, 0.12970750566039765, 0.13706040967788014, 0.13457017258874007, 0.21467549274010317, 0.10910976771265268, 0.09277666306921414, 0.12163702371929373, 0.14937938936054707, 0.08899853937327862, 0.1241428264017616, 0.07270267951701369, 0.15208940394222736, 0.0699797049164772, 0.12373026353972298, 0.12625710080776895, 0.18920461806867803, 0.10507365821727685, 0.1778473396386419, 0.1311565443341221, 0.1274554886456047, 0.14287644544882433, 0.18125906799520763, 0.09535568646554436, 0.09941745136997529, 0.09892557454960686, 0.18696568320904458, 0.12502162424581392, 0.1611341128924063, 0.10126366373151541, 0.23951754186834606, 0.16037252518747533, 0.1377688002373491, 0.1386226144220148, 0.0658480441197753, 0.09604705936674561, 0.13526648522487708, 0.0644253393901246, 0.15057481878570148, 0.06637174423251833, 0.11137433083994047, 0.15807463920542172, 0.15750450694135257, 0.1702118529272931, 0.12256387541336672, 0.19536563461380346, 0.17183288665754454, 0.09091877990535327, 0.18150781893304416, 0.10894337735537972, 0.1540138242500169, 0.22532268427312374, 0.15410602358835085, 0.22659371607005596, 0.07993519106613738, 0.11144970929516212, 0.15522320435515471, 0.19323219837886946, 0.11701894152377333, 0.1601226750229086, 0.16207225540918963, 0.09363184789461748, 0.1417808828077146, 0.11815536554370608, 0.10061330827219145, 0.13699243403971195, 0.0931424612977675, 0.09932040050625801, 0.12036927603185177, 0.11710252346737043, 0.18856310392064707, 0.05761141609400511, 0.060340287163853645, 0.161522737038987, 0.18033506614821299, 0.13782032818666526, 0.06642967755241053, 0.16296204552054405], [0.03304848913103342, 0.02093116835957127, 0.005393183773516544, 0.057695703714021614, 0.015120828890108635, 0.06959901284426451, 0.05020194600469299, 0.00939425456869815, 0.0034141117108187503, 0.026053427519010644, 0.030964796298316548, 0.020540148984374743, 0.09918417103056397, 0.02869919840512531, 0.0720593740365335, 0.009383272479421325, 0.05318006334294166, 0.023316992480041723, 0.03356696452413287, 0.01712107039721949, 0.035398296612714014, 0.044772128973688395, 0.13434070561613354, 0.04922183609700628, 0.005171153120630021, 0.02458139498984175, 0.08393016098333256, 0.04186884726264647, 0.035911655851772854, 0.038981589156069925, 0.05118569964542985, 0.024735977141452686, 0.03792773266988141, 0.020327138182307993, 0.05541875392996839, 0.0356440518184432, 0.033848488703370094, 0.048204807098954916, 0.016874507734818116, 0.05283210040735347, 0.019789093839270726, 0.03049523988738656, 0.028352358444992985, 0.008811336160371346, 0.022055136172899177, 0.02845242030785552, 0.09308632609567472, 0.06659519259950944, 0.08402456556047712, 0.040994897551302395, 0.08339782311980214, 0.05992464375283037, 0.03804639826661774, 0.020084891002625227, 0.025271690716700893, 0.04542142591838326, 0.06319745563502822, 0.02332562005280384, 0.025275380250864794, 0.05342813574575952, 0.06704912574163505, 0.04457370497818504, 0.010215177616503621, 0.0076652896657053915, 0.022606503551027606, 0.015745123515703847, 0.05587520782968827, 0.07659310075853552, 0.05585272117917027, 0.010511893346639616, 0.023962901838655983, 0.018695005315489004, 0.053413204582674165, 0.045577024176184616, 0.01999934809282422, 0.013526086695492268, 0.037069297661738734, 0.0664655449134963, 0.024764489182936292, 0.0392207693574684, 0.03636563988402486, 0.0209381046837994, 0.03267454508958118, 0.047840416830565245, 0.0823418665677309, 0.0910238917650921, 0.01187042986774551, 0.0695487605407834, 0.06324835933212723, 0.041898302467806, 0.0457086192577013, 0.01617093138130648, 0.016510989383927414, 0.06848446479333298, 0.06309733779302665, 0.04417919793299266, 0.05908551985131843, 0.04605563224426337, 0.04926412918471864, 0.023102212397913848, 0.01004433776584587, 0.09437340524579797, 0.03356487124360033, 0.026954739154981713, 0.040112890236611874, 0.01841058548805969, 0.023125011174540435, 0.07490985893777438, 0.09028886192079101, 0.016199484134891202, 0.07893857918679714, 0.026000530625294362, 0.03454365800800068, 0.027641626939709698, 0.08064155959125076, 0.03845814688663397, 0.03707993369815605, 0.06525631408606257, 0.07307458456073489, 0.061338751443794796, 0.053503544735057015, 0.020575631276837418, 0.05440513796306082, 0.04495778294014079, 0.021402702700080614, 0.07080070514764104, 0.04694792614983661, 0.06313982087054423, 0.02398245721789343, 0.005759873851535043, 0.05857876275799104, 0.024649260366069417, 0.032513030006417205, 0.06051564775407314, 0.04150620082925473, 0.03126639832875558, 0.014540476192321097, 0.01916001214911895, 0.036281823845846314, 0.045007251535675356, 0.04095751366444996, 0.010851318615355661, 0.047960965361978324, 0.027792331263689057, 0.07602206604289156, 0.08251724072865077, 0.03305334744176694, 0.017198084121836082, 0.03395422142265098, 0.010959725610778799, 0.012288903617965323, 0.052511309406587055, 0.026764018228277564, 0.07167245301284961, 0.018687378581879393, 0.047876633637185605, 0.07692921308002301, 0.016406746049012457, 0.029316600811268603, 0.05847502832434007, 0.007509431868259395, 0.023348154200773154, 0.03292292283315744, 0.026128953555598855, 0.03147465090400406, 0.0482870964333415, 0.08236844478441135, 0.053724798041262796, 0.04621368679883225, 0.009951119776815176, 0.0310652771565531, 0.0059256276581436396, 0.05757394739027534, 0.0431233092344233, 0.04139302458081927, 0.046236298978328705, 0.06716211539294038, 0.05377832766888397, 0.022743221571935073, 0.030314359414790357, 0.07620399485209159, 0.02804531286736684, 0.008428410859778523, 0.024318583110081296, 0.03409574347149048, 0.014316785249060817, 0.01043510777942304, 0.07440067947443042, 0.09021301527640649, 0.03333826090342232, 0.03956795197778514, 0.03409287666103669, 0.019099320584375943, 0.0643427006102034, 0.06146944407373667, 0.01725494026738618, 0.0165821083355695, 0.03267657730196204, 0.0551836008339056, 0.062114398394312174, 0.03429742104240826, 0.026573433008577143, 0.05470301144357238, 0.07112851220050029, 0.010087272069150848, 0.06514045423162834, 0.020842185277225714, 0.012713165271894207, 0.007895163759323103, 0.08261696502034153, 0.03995043198977198, 0.08500829205981322, 0.050003518616514545, 0.021483782545796463, 0.01919833241429712, 0.01880527743404465, 0.02082306585673775, 0.029421929802213396, 0.040755574857550006, 0.026397804397025278, 0.030493787822446654, 0.0062582696970951346, 0.013561328956192093, 0.049569632791514905, 0.02605577525017517, 0.034509592157389433, 0.027123261808550785, 0.06510578109217541, 0.01931345266556101, 0.056179082952439785, 0.017960560707641498, 0.01841595609273229, 0.07643013021775655, 0.04116853126989944, 0.031366777406739335, 0.006361118218462382, 0.019394814103309597, 0.030819688191903487, 0.020971977151930332, 0.06436009824808155, 0.07121362084788935, 0.029455069452524185, 0.030766575863318782, 0.01652570002313171, 0.055345455184578896, 0.02766190156606691, 0.029305299810533012, 0.021291100652888417, 0.045162785332649946, 0.026480380412457243, 0.0491985352044659, 0.05254138886396374, 0.014942413195967674, 0.044410622479127984, 0.051982696700309, 0.0463110531813332, 0.025707130386893238, 0.03650857667837824, 0.007481557649693319, 0.021406409197619984, 0.05353845196909138, 0.03626198348190103, 0.061111001164785454, 0.030579473224601576, 0.06969012652656861, 0.018020017338650565, 0.03259060352242418, 0.08394049507166658, 0.07401309348642826, 0.017980158495317613, 0.025498526669772606, 0.060243908049804826, 0.030848502181470394, 0.017233815775918107, 0.05087354300277574, 0.017767636238464286, 0.008837209548801184, 0.014522333862259984, 0.06783638921167169, 0.032909369096159935, 0.06967809610068798, 0.029677042005849735, 0.026474838477692435, 0.01944835390895605, 0.10011811341558184, 0.019094755740037987, 0.08460154424288444, 0.07286862204117434, 0.03644526596846325, 0.029303566153560365, 0.1597958654165268, 0.03289526574579733, 0.007131143506350262, 0.026055446160691123, 0.01858762205977525, 0.043661648740193675, 0.024287518080590025, 0.015229911876044102, 0.019825892489669577, 0.010465850504780454, 0.06612017737435442, 0.012487669425484325, 0.06421956007501908, 0.035402771551162004, 0.020596916920372417, 0.05278234343443598, 0.1403731940580266, 0.03884158024032201, 0.0038397397646414383, 0.021041667787358165, 0.022675195043640475, 0.034709020384720395, 0.015109543156410967, 0.009637538210621901, 0.055621411983988116, 0.040042349736073186, 0.04288432580818023, 0.04298796185425349, 0.047264768076794486, 0.028604084758886268, 0.07850753981620073, 0.0304568144492805, 0.07187082272555147, 0.04019884705277426, 0.04855804903698819, 0.009604985493102243, 0.04012192153771009, 0.04060379335922854, 0.023399794108367393, 0.08052470907568932, 0.019810265828190104, 0.03138139644371612, 0.05167367149676595, 0.02436777520259576, 0.07847183530351945, 0.03089313960767218, 0.04841637771044459, 0.015078242336000715, 0.04112704224618418, 0.02488711742418153, 0.03794639238289424, 0.03425353679007717, 0.04839942790567875, 0.0472065769135952, 0.05246627164472427, 0.056291533168405294, 0.03094096275578652, 0.035277127221758874, 0.034696949246738634, 0.02923361937116299, 0.018085290711106997, 0.008029841086161988, 0.163787306951625, 0.14788070906485828, 0.10133221612444945, 0.1769591915820326, 0.1550063852752958, 0.16646540324602807, 0.12077155230300766, 0.07818850622113262, 0.09900395891496114, 0.09030090591737203, 0.1470874473452568, 0.13534736659909996, 0.18349577725997993, 0.12520847921924932, 0.29742852438773426, 0.08277126388358218, 0.11037843820772, 0.1979888238544975, 0.14314788659768446, 0.08078881526099783, 0.193777238417949, 0.17381202402923787, 0.2737311231238501, 0.1732996350952557, 0.1733845876795905, 0.08302143974495785, 0.13161165134182998, 0.16336000630898134, 0.1170807560639722, 0.1363988516053983, 0.13712978309818677, 0.1132511654868722, 0.15999122921909603, 0.13227797273014272, 0.17607473475592478, 0.12721815066678183, 0.10632406933499233, 0.11771214646952492, 0.11244155785867146, 0.10664848371275834, 0.09192566480487585, 0.17407361284962722, 0.14676580817571708, 0.08515301679394074, 0.07949104918433086, 0.16466056794992515, 0.13673726416059903, 0.09629096556454897, 0.1336550052676882, 0.20026150904595852, 0.1448514573276043, 0.13473152821617468, 0.10611792361097676, 0.1284738882843937, 0.13047441307987484, 0.13185934376503738, 0.1828032372785466, 0.14259353705814906, 0.14980275450008257, 0.190490631918822, 0.13889774680137634, 0.12911977219794477, 0.1318976945642914, 0.1617713522698198, 0.10791375474738223, 0.09606814144977502, 0.12653046899608203, 0.09639358720076935, 0.2040479380105223, 0.08845326184694256, 0.0719120233718838, 0.16174309807164328, 0.1923128512821027, 0.0930534985714725, 0.13720986380108766, 0.14443911159677164, 0.11505839601159096, 0.16222336515784264, 0.13209427972989424, 0.2989262140222958, 0.13852217766855443, 0.13144809726093495, 0.10918748032833848, 0.13204300962388515, 0.2602487680103098, 0.20635765764330113, 0.13999444938131742, 0.10640852658876351, 0.14348157654915536, 0.13780811455632958, 0.11858049487429005, 0.21727401044751915, 0.13553202311907495, 0.1608023771217891, 0.1350327841937542, 0.142860133466976, 0.1503393535635301, 0.1635260031159435, 0.1460075724337782, 0.10932598968169518, 0.1690291663897889, 0.2055626588740519, 0.11895013361104897, 0.1514181156775781, 0.15323310185756, 0.09878914151340723, 0.13573847418384893, 0.10074555474732604, 0.2976023922009127, 0.11367885967982666, 0.21931626514664718, 0.08668999360608202, 0.08224478856261287, 0.08861827477812767, 0.21828719893736498, 0.07598252780735493, 0.10359032638370991, 0.15332672611943313, 0.208763362839818, 0.11696330165224415, 0.18007928558758327, 0.14201622589358262, 0.11436261263276849, 0.12134996269430433, 0.11147518828511238, 0.22757570551974432, 0.15347923365022453, 0.16202204381780966, 0.13133487690772327, 0.11053426377475262, 0.16916070718850407, 0.17458055993275984, 0.11274826925780092, 0.20810018985399178, 0.058753546593444686, 0.11018366473061697, 0.11163639463484287, 0.07929392797606331, 0.08914462796279363, 0.22244549223354884, 0.11814613746745245, 0.06952837056347302, 0.1530524351234947, 0.3006590838943209, 0.21561538587723458, 0.16729818284511566, 0.12573658302426338, 0.12709224170872144, 0.16225096796240124, 0.1806533397840602, 0.13691350684634276, 0.10149919002183846, 0.10860194531934601, 0.1596473612423454, 0.07126409028257642, 0.1655638473374503, 0.17567357128219946, 0.1830523003424917, 0.20425326270716532, 0.15015544343207562, 0.14266870516751493, 0.14127009521637643, 0.143970841009702, 0.1506839543581009, 0.13753629342785903, 0.06336126755923033, 0.12033068095999104, 0.19287089205213956, 0.1379608663597277, 0.12968256271311215, 0.11193980156843152, 0.09370489218937499, 0.125400111079216, 0.13011445025248186, 0.20083123418901647, 0.0949559004179069], [0.017455528789599026, 0.056927384941705635, 0.027805655995117765, 0.018223014660179615, 0.02271725912578404, 0.030165135993489196, 0.02212656385797475, 0.03115706258852567, 0.03554814428623233, 0.029320207224892716, 0.021552233158477714, 0.006820553431420454, 0.004647312635955001, 0.03955174516886473, 0.028806515503674746, 0.019325315154024532, 0.0371634986783777, 0.027764626678877642, 0.042507762621556006, 0.023818960812475, 0.016009937073769312, 0.018004731641017964, 0.06897892683212246, 0.01536178176424333, 0.03992349075685654, 0.04465999088383146, 0.03884897966470037, 0.026025022346792475, 0.010603718642544533, 0.01701807726307639, 0.029310548278902258, 0.04325564731178539, 0.01678048144094646, 0.01794192474335432, 0.01945331908895501, 0.060480628561760695, 0.04209972219541669, 0.05945892445743084, 0.03979513228737882, 0.018953430466353893, 0.07290100173226424, 0.05686352461842554, 0.061125915364495347, 0.016457498772069812, 0.013424116452889783, 0.024133741689313735, 0.041386151021080356, 0.019792288042871014, 0.05768117627927235, 0.053651855526758094, 0.03140420539836798, 0.03131135466641613, 0.03310687706938811, 0.04233623914686697, 0.014818039423386966, 0.038221931883266995, 0.09583216054098946, 0.044429370401693244, 0.033230618108063936, 0.025283351340996366, 0.016789729873250638, 0.024604180195767964, 0.03922842323247876, 0.052903682459145784, 0.048015672247856855, 0.052082349745822806, 0.030913448160780326, 0.025234313615198647, 0.04874421529737966, 0.02702737463239048, 0.012580110491918666, 0.05785825356308903, 0.0026909129727365716, 0.03376107642959271, 0.008123487400423204, 0.04311290729258742, 0.03308745400447931, 0.005431906070693263, 0.024770948836313825, 0.02561109732570393, 0.04191620561427303, 0.05410235867436443, 0.06380891746708325, 0.07477476261556149, 0.030746297844286476, 0.03425924326958401, 0.05035613290965557, 0.04303617176732846, 0.01634452778047749, 0.025293493743187616, 0.05601955258420535, 0.00478176647032212, 0.0858253567878689, 0.015578974038362503, 0.0681594397340502, 0.032593063211866787, 0.01808189633967621, 0.06451525885079588, 0.023552837681823542, 0.04086488006370408, 0.021616985755307332, 0.01337910837693406, 0.03827261844916003, 0.025832572852128317, 0.06366344634443521, 0.04668271055977259, 0.08047972898930311, 0.02138883344429944, 0.02107248515156763, 0.003887095147677298, 0.03456965607724019, 0.018556794517540505, 0.023591456502409916, 0.02813700500077435, 0.010901371599175036, 0.03568385807531221, 0.028876604778426032, 0.026806579337322285, 0.032897599906261475, 0.02195713366381824, 0.031513385075543604, 0.01988633469279323, 0.015316029844273413, 0.04654977876426918, 0.03678197540076716, 0.0210287230355399, 0.012644345705796565, 0.052343110753489394, 0.02561519228454147, 0.013975152197027845, 0.0717516719762768, 0.09573597820209605, 0.056391450842576366, 0.03849134421242135, 0.029056145144360404, 0.057051902902977805, 0.0306603885255754, 0.042507728694805076, 0.012448221095837653, 0.025608732631163936, 0.015323313917698604, 0.02018945324899895, 0.011477089902785207, 0.039865391195884774, 0.027379281552774564, 0.020397941615166407, 0.0223879966153098, 0.022334458506000892, 0.024424271724585975, 0.056833418019648106, 0.0589674547580736, 0.03893753866265927, 0.016906202105539184, 0.0638724961983306, 0.07058183689202581, 0.03790463873052171, 0.01643053887944136, 0.029898227458553653, 0.06734328424291951, 0.05331123773274677, 0.04935982637107372, 0.05843790567346981, 0.05150108950744782, 0.01691424104917262, 0.016956856441018835, 0.02144109590777329, 0.03733843518421054, 0.01365417375096253, 0.03597984862114702, 0.03982113374929343, 0.016500672258968865, 0.058321102655359676, 0.03016349733141916, 0.04162014042958617, 0.013907336862757802, 0.05327379617041775, 0.059511259863419194, 0.02058331568592361, 0.062314050538199287, 0.05552671902946063, 0.053799647239169905, 0.026535306125879288, 0.03497456845694354, 0.051097313673900704, 0.05589406771053161, 0.01803635137288698, 0.006788337012819413, 0.023609444465754286, 0.03948028864605086, 0.06807958294770547, 0.06198301365865128, 0.026522439405588166, 0.008040245572504188, 0.0550276192038187, 0.030419057368167808, 0.03721039562619158, 0.04082171845116785, 0.04391923759664808, 0.0322241131881518, 0.02147009310179523, 0.05309318371915391, 0.05065991643017956, 0.034778631292283535, 0.014432813040912151, 0.012052376488489764, 0.01937909753594015, 0.029270514712802002, 0.04627834100808416, 0.01517709979920515, 0.01646276081113943, 0.017143853906808153, 0.033178031644118686, 0.13330929167568684, 0.09082917935614075, 0.07134405563452415, 0.027932630253157446, 0.052614406017320495, 0.07309690157749824, 0.02304380919252123, 0.06891819116260324, 0.06372884354953255, 0.04895693602572594, 0.06834108355854239, 0.054483030390526564, 0.021013820710192834, 0.04387291740360005, 0.030267703346908092, 0.019822002787675177, 0.013167913504210966, 0.06937166290091616, 0.022172410772847276, 0.00852060002008719, 0.04434377660176583, 0.021812083232881765, 0.029863462716873204, 0.08000288850494794, 0.020493457293404, 0.01597231230698526, 0.03172121695908053, 0.04404983862436243, 0.024951530753501823, 0.043915302093539915, 0.059914764282958846, 0.0196523300172495, 0.027838531016771282, 0.07259606130953346, 0.068025496921369, 0.04065083958474653, 0.014972404443791934, 0.028686279098370245, 0.030989837633179765, 0.032688509340264967, 0.06403600278177432, 0.026325667642855217, 0.03506944800860115, 0.019643863596554314, 0.054459983948618174, 0.0013995711384008505, 0.05318668584472366, 0.027883617972422923, 0.022558700758963823, 0.02507177903316915, 0.03532671795359679, 0.005614798399619758, 0.023359674029052258, 0.07029628900012799, 0.06799343614173786, 0.050033710032169304, 0.06216978720788445, 0.0404466276855341, 0.017721214265163456, 0.026711214633126344, 0.00945846433751285, 0.04480728726567967, 0.02498890276599143, 0.05145110522529908, 0.047079639974981546, 0.025102323287033608, 0.04091466757069741, 0.047566088515200784, 0.032106065058282444, 0.023425010165997913, 0.01057174607246582, 0.015482428683234113, 0.04689651355147362, 0.033672262981001816, 0.03612236472378884, 0.0431851068112467, 0.037489677247192175, 0.02431364676782063, 0.017512795448835407, 0.035168721074504514, 0.042505801655352116, 0.014159617879028832, 0.006927658911860947, 0.05392124749986189, 0.055391531105020216, 0.018229808492053832, 0.04802249491746936, 0.03029394568875432, 0.014253148842336876, 0.058110770370279036, 0.032274243355329545, 0.03176978310304029, 0.0063046212723877814, 0.051122721417673996, 0.07363837252237967, 0.07181651956800904, 0.09189892373979092, 0.02804926872652556, 0.02660740047161068, 0.011425460173216249, 0.012673839078550892, 0.018803671002388, 0.015626917626442652, 0.0374236998946539, 0.019410744409209917, 0.009197721989559276, 0.022835085035434792, 0.04482651694810816, 0.03745105503393071, 0.005810704182035157, 0.0629066423113857, 0.026033938296937516, 0.020446740157370056, 0.013053895872352379, 0.03207065910100937, 0.08528534469327756, 0.01165811880491674, 0.02583185869402119, 0.03323307779750653, 0.027148915521268333, 0.029839449362563233, 0.03485094616189599, 0.03450870327651501, 0.021110917375023876, 0.04503790774781789, 0.022115113579535058, 0.02867529700909342, 0.022679895594982163, 0.033384075587881465, 0.00883696782070079, 0.020816054893657565, 0.041016580137823305, 0.044159903789737394, 0.0403219740172582, 0.06860958665077176, 0.03546116966754198, 0.030685487535915205, 0.03410505636462143, 0.05981221728559051, 0.07555422293288366, 0.07589693740010262, 0.09799307065882853, 0.11148425351296153, 0.09654094465076923, 0.13877470126109465, 0.11546725407242775, 0.14287386701575347, 0.10418517089315824, 0.14698311580078943, 0.112796119547316, 0.1779923697135278, 0.10490859100329024, 0.09566852503589221, 0.19484343406345161, 0.1943222784570285, 0.12554972805082798, 0.11067358058478151, 0.13256345955388887, 0.20272936805018357, 0.09440416323819331, 0.1630616273198809, 0.10829530177371842, 0.12814212537237576, 0.09947182916636978, 0.12487554922699928, 0.1259894458843129, 0.13186991534062795, 0.11657931868519102, 0.10573609159993273, 0.13257818376379354, 0.10628962011209556, 0.12302096374332905, 0.10273041216922657, 0.07880933183644499, 0.08014276849904231, 0.12424532590167862, 0.1726381584469761, 0.17110906621175154, 0.11822771094739437, 0.1192444549607379, 0.18726020811923913, 0.20397756035838807, 0.09175477576042924, 0.13140138691025122, 0.10463527709777866, 0.1310390220688922, 0.1709212748599904, 0.10986172022031886, 0.115766135177442, 0.17134207513715538, 0.1101392274722457, 0.10752708478165524, 0.19925856643489429, 0.17158874975783484, 0.18557501211762428, 0.07920630874910525, 0.17600705767316477, 0.08325292875191995, 0.13610377029648849, 0.13347220793366432, 0.06519643337066684, 0.08525968928422246, 0.17246643480445656, 0.16904679472957337, 0.1190916895866394, 0.1660783261592899, 0.16703373060694762, 0.07309017051011324, 0.1434337126889399, 0.19651073031127453, 0.19510196947625705, 0.14440179217074597, 0.09077644361449139, 0.09165290051272937, 0.10970808632139649, 0.14134032359080656, 0.12696432428700583, 0.09429103109453406, 0.09910443638052259, 0.07143999370081083, 0.16595490063939775, 0.1697204035839864, 0.18279330352587358, 0.1905307061970234, 0.13841045009238379, 0.09176862466015986, 0.11374627213392939, 0.11788216020379748, 0.17319283368332045, 0.13073456340602466, 0.1288327925971576, 0.15362054535320827, 0.17303786985576153, 0.08584666957280465, 0.14044471164899214, 0.15869323244052275, 0.07928636231060539, 0.14191277644463948, 0.10815552355987684, 0.12784787187618868, 0.2157168947160244, 0.12559536631618226, 0.0859666345641017, 0.14696297688143595, 0.18388148370598043, 0.10995367528604609, 0.20360657812229224, 0.07612626188035522, 0.1533863286354712, 0.10572803738926138, 0.08893517098788704, 0.1390686154897724, 0.11556807080549852, 0.12281063145824841, 0.15193951555660792, 0.10676756660853114, 0.11118719088179724, 0.19747209229639598, 0.14203238859772682, 0.10472769356731858, 0.18721566908061504, 0.07840025664440223, 0.14458715436714037, 0.08654659880059105, 0.16232689603098802, 0.1309767732662814, 0.1346738798809903, 0.06943364028951951, 0.172041794019086, 0.09166346530296973, 0.1591114814260176, 0.15974300753857407, 0.15093027614057064, 0.11365809650825602, 0.09427993026162897, 0.15977982484868594, 0.09180747757532767, 0.14922456123999187, 0.08564215911818401, 0.07228189959589924, 0.16128997238618986, 0.22293540808771337, 0.08334438848708357, 0.06573519017547369, 0.18415437691978045, 0.0754678047129086, 0.16564770069505486, 0.13547867669590882, 0.13544702982263906, 0.08036405912467412, 0.13918313863021986, 0.23738067224621773, 0.09645027880157743, 0.25179576873779297, 0.11916168725916318, 0.12284149123089654, 0.13237625174224377, 0.1325399415301425, 0.15808868488030775, 0.11767967178353242, 0.22145036634589943, 0.09359029441007546, 0.07930667764906373, 0.11435540659087044, 0.08739403475608144, 0.07032689771481923, 0.11775602054383073, 0.0935738602919238, 0.11159982838268791, 0.09391909212406192, 0.14001392333635262, 0.1484087450163705, 0.09320857096463442, 0.12218096453164305, 0.12545805796980858, 0.14159500492470606], [0.04144389095849224, 0.03673992319298642, 0.04663790010714105, 0.06115964534027236, 0.0396045216226152, 0.04237906149189387, 0.005741309133424822, 0.02861712620194469, 0.03509374974029405, 0.019334828214985982, 0.010814251095455672, 0.03930491448513099, 0.026667667951967036, 0.007814751422431852, 0.04829561883317573, 0.05703073261039598, 0.008096850660097386, 0.029914865137210915, 0.012104013003408909, 0.04533843769292746, 0.06644657985972506, 0.033164074178785086, 0.033220362051257064, 0.033006090870393176, 0.01893030938559345, 0.03470201111797776, 0.04344240389764309, 0.053271302554224215, 0.03504237446135708, 0.03365270420908928, 0.019739525159820914, 0.018842847918027213, 0.034424904201711924, 0.12447760200926236, 0.04956273887572544, 0.04136451253933566, 0.007352521493365722, 0.07427477051637002, 0.01549099518784455, 0.033139450142958334, 0.013964710391259618, 0.05255883399929319, 0.05849176099789994, 0.03316390115235533, 0.01780334414382066, 0.028454647599054233, 0.05828477389046124, 0.021446379999231015, 0.06478725639837128, 0.012528200866654515, 0.0510162864146488, 0.024565393437764475, 0.007620460553360837, 0.036584979721478054, 0.004092724336909929, 0.03529913889776383, 0.022494872666097114, 0.014117690352057772, 0.04080017835700086, 0.04921333744589772, 0.020218185814363614, 0.010922591085545719, 0.021281397602121745, 0.010492890125273593, 0.03936761790620429, 0.02694453907731388, 0.03897119399958423, 0.022867408747385656, 0.04874396423942276, 0.013942949773211564, 0.01319121100407626, 0.028494776160057102, 0.038259366660245826, 0.028799814970365593, 0.015175649430602789, 0.04043510616091745, 0.05782598243760211, 0.07035072107932397, 0.039491562505385706, 0.006806489944990192, 0.019752955064177513, 0.0344142749506448, 0.021396392324407185, 0.025137909056086625, 0.04107499521757875, 0.03721479931846261, 0.06148534893457379, 0.022756203643179367, 0.01950531522743404, 0.04385989631659218, 0.11189214126872164, 0.007988922031862395, 0.06661850027740002, 0.06741047956581626, 0.06812913636011736, 0.008387611397275967, 0.08468811174056359, 0.025646085983940532, 0.028880706522613764, 0.05998189175235374, 0.009088779799640179, 0.048535742198250124, 0.04749787538977606, 0.06322878359683923, 0.038510553538799286, 0.013545253613431538, 0.08567195359085288, 0.019702986049066697, 0.0900063199390258, 0.027719156350940466, 0.05029449139588645, 0.014199763403407164, 0.022448694965402995, 0.02332306876113372, 0.0258208850864321, 0.03561992311318006, 0.06467485707253218, 0.017726857980181063, 0.05328415400747742, 0.05845960522336619, 0.019314214321119443, 0.03204150923660823, 0.02614954370073974, 0.043831248568104844, 0.04701080259733966, 0.08319456116961581, 0.09556118079594203, 0.05253803011562143, 0.03317276621237397, 0.09516833616154534, 0.04549185785331896, 0.04677896075216787, 0.06974523035543305, 0.02966884191014937, 0.04740263282188347, 0.0625172107081328, 0.02870484042380537, 0.024725868666012372, 0.021051016303577592, 0.023162681742438247, 0.04094250446983746, 0.02675766883684056, 0.043899963809443374, 0.027467046664761643, 0.02549728155801339, 0.02161223940285189, 0.02039673551917076, 0.0265616570333285, 0.05534959424819265, 0.023782012884372046, 0.039089248914803774, 0.05689666087606123, 0.042099301503705125, 0.0751052905938455, 0.022927881484585147, 0.05831217313451426, 0.04241937665002687, 0.02639943966642022, 0.03347584744915366, 0.05683490061866386, 0.03574985239122595, 0.029633330779948404, 0.09036367719194718, 0.04096499790570565, 0.05977970188749688, 0.05055795297292726, 0.020797474908509424, 0.024067087498094355, 0.059981043583580425, 0.02579712787909167, 0.023610738771302358, 0.00910567447343575, 0.05300996479179178, 0.03877474454098514, 0.0665590198976653, 0.014685479125806263, 0.02015531275953565, 0.04208740678482822, 0.06946416079465832, 0.06455356893794877, 0.0023247595735093845, 0.07149230196539845, 0.028402710832389336, 0.027808919748557464, 0.027977657836994956, 0.05420715840799468, 0.021264076299433197, 0.018598666913541298, 0.01592558838560113, 0.06594376505485602, 0.04670253396034241, 0.03005128799538527, 0.03214489761739969, 0.029348176438361406, 0.025327937877071754, 0.039053561365497966, 0.07630656899086066, 0.025428413646295667, 0.0349961289071611, 0.03993007254653743, 0.01364127140758293, 0.03603423320289169, 0.058256261848977635, 0.03846762941351958, 0.02071132810254182, 0.04758541997788208, 0.01631111671615924, 0.014093378442339599, 0.0058179225223804155, 0.05030258292598384, 0.0111505975115246, 0.0038094219718394534, 0.03678670139717204, 0.023466994520276785, 0.034099020795630555, 0.04485136490049107, 0.01753494283184409, 0.06111822077738387, 0.029853776629481996, 0.014407508773729205, 0.0156592990138701, 0.03856333338522485, 0.027662558048697453, 0.015614878718874283, 0.018419805082625577, 0.027436984170760428, 0.037713946641555855, 0.039905411191284657, 0.02014428995815771, 0.043867448411349735, 0.02724654653242656, 0.06125526449510029, 0.007699274940283171, 0.052219111871506484, 0.0036262785849560586, 0.037745298352092505, 0.012878831293034767, 0.019590335665270686, 0.017862278302865367, 0.020773617617253746, 0.009297341956490917, 0.014975966752639838, 0.039056998145367415, 0.046781227059130154, 0.005979969407365258, 0.023091072549245188, 0.02600873581000737, 0.09113491366484336, 0.07060360429542405, 0.042703150172850916, 0.04158089735678264, 0.05895907485059329, 0.06182520676936422, 0.05175364363406386, 0.05877415370196104, 0.048987083336604495, 0.01962071537439312, 0.03871829042743359, 0.04191309453121253, 0.020514544465446045, 0.010217006268378879, 0.040724816865154674, 0.06631138854260955, 0.010491673851252666, 0.04500512432839189, 0.034814963449857066, 0.05053780726822359, 0.019286041547145163, 0.012393708440608211, 0.007596258905583194, 0.04163107502141169, 0.01800440764054656, 0.03405115015006491, 0.042911755586309094, 0.06439336003469569, 0.03401469246351293, 0.006473301261264298, 0.010435824482036489, 0.0414007904141077, 0.047853543090501, 0.027986236215968217, 0.10136454831808805, 0.02093426926460649, 0.02431884773873857, 0.0842023960181645, 0.06742714438587427, 0.030430365154253583, 0.035228920701358996, 0.022348161520702497, 0.04951118039233344, 0.0631535951314228, 0.018371900510308996, 0.024471010913008025, 0.03642208721222622, 0.0349547111296228, 0.05178784179900374, 0.01834894227795303, 0.016057407383673956, 0.05351219605654478, 0.030846598890743086, 0.02959479338356427, 0.023207965473245298, 0.026460173639601896, 0.04607419017702341, 0.04567782733855503, 0.02252765099651047, 0.013442173966073563, 0.049914976581931114, 0.020991646185783402, 0.03930950816720724, 0.02571357986224549, 0.015212059619703462, 0.0033622154442127794, 0.03392888831772974, 0.03970632901681321, 0.03644713533243962, 0.029184127026902776, 0.02032387612520584, 0.03834796976298094, 0.04332719882950187, 0.05649187741801143, 0.07445428374090365, 0.030843301210552454, 0.036371695809066296, 0.0641731618504439, 0.0164130496393357, 0.053522285872272084, 0.03541293939841645, 0.032433129115296264, 0.06079229326652629, 0.030629396438598633, 0.022898694300757985, 0.08033088554761239, 0.012708967684635093, 0.026966793329588006, 0.03996995683493359, 0.031669878999569585, 0.04723939425977213, 0.02109959941091282, 0.0788450227784259, 0.07277756264167172, 0.03946018026077321, 0.011991829960606992, 0.04886993087295975, 0.04999765607395342, 0.07513275769140039, 0.028275471945692385, 0.026821646207411374, 0.04006275328408394, 0.04387074948421546, 0.046072493839476786, 0.017516612208315303, 0.08003053202160768, 0.0888837855309248, 0.13473013043403625, 0.22535306907125882, 0.11768127312617642, 0.15605656749435834, 0.10125560952084404, 0.14108500443398952, 0.09934093976127249, 0.17195547079401358, 0.13858718132334097, 0.14167401354227746, 0.10383989156356879, 0.18076923356524535, 0.11617036562945161, 0.17069142790777342, 0.1068867105724556, 0.09911287735615458, 0.061154902380492, 0.11689281543450696, 0.1847948054117816, 0.10329606610217265, 0.12112922168203763, 0.213309751025268, 0.09425349453730242, 0.11364501435309649, 0.13615495897829533, 0.12719434765832766, 0.14305707147078855, 0.15815374281789574, 0.13533182814717293, 0.13511773677808897, 0.12950729711779527, 0.1399225653814418, 0.145467200715627, 0.21658365534884588, 0.11890676165265696, 0.12298696913889476, 0.15528995863028935, 0.15893928280898503, 0.08798391917454344, 0.13997204415500164, 0.10629186606300728, 0.10892433087740626, 0.06269682571291924, 0.16949502139219216, 0.1216556155788047, 0.1275066908981119, 0.07998555193522147, 0.12739152993474687, 0.2146028894931078, 0.10849109305334942, 0.161204761958548, 0.08146986085921526, 0.07868528206433568, 0.12854491733014584, 0.12695002076881273, 0.15569885740322725, 0.16700445860624313, 0.10991477487342698, 0.09606411095176424, 0.09626075040016856, 0.08409454287695033, 0.095429063242461, 0.09597428648599557, 0.0786896925419569, 0.17537848997328961, 0.16751063215945447, 0.10524186704839979, 0.09799826823707138, 0.16613282609198773, 0.17284387669392995, 0.10656257439404726, 0.11811150504010064, 0.10343684176249163, 0.16931307901229176, 0.19620970503560134, 0.19105129183403083, 0.18197299540042877, 0.09911218525043555, 0.1498973151402814, 0.09527772957725184, 0.12693133391439915, 0.11005371170384542, 0.141401649585792, 0.18616919166275434, 0.18937096771384987, 0.0828794902190566, 0.06763822305947542, 0.12291878994022097, 0.16621051835162298, 0.07356076168694667, 0.11682034789451531, 0.12226671778729983, 0.12795755027660302, 0.10306875008557524, 0.1654963195323944, 0.12708583633814538, 0.21988582744130067, 0.12246111807014261, 0.06328375171869993, 0.18589055804269655, 0.09496801905333996, 0.14820314890572003, 0.10116822778114251, 0.09963403296257768, 0.17853013585720742, 0.11801469166363988, 0.20686695245759829, 0.10969151649624109, 0.11772043816745281, 0.09685532349560942, 0.14860345742532186, 0.19395395607820579, 0.09410412862364735, 0.11520498671701976, 0.11252006436032908, 0.10464143819574799, 0.12597426027059555, 0.12687359058431216, 0.13346011643963201, 0.09523400478065014, 0.17190377999629292, 0.15627928982887948, 0.1438618004322052, 0.19067015871405602, 0.1907197596239192, 0.1043114462601287, 0.11072304578764097, 0.17890896195811884, 0.10969518058534179, 0.10383392045540468, 0.12690857584987367, 0.10950529256037303, 0.10657215530851058, 0.1429466466818537, 0.15110913797148637, 0.07475781959614583, 0.10859319900295564, 0.0986427136563829, 0.12154280234660421, 0.14119437070829527, 0.1700211845870529, 0.11901259954486575, 0.20665401459804603, 0.11621086059936456, 0.10199264104345016, 0.12967344320246152, 0.12239027901419572, 0.10587248392403126, 0.1299910925860916, 0.1388147348271949, 0.21454000286757946, 0.1989134635244097, 0.08400213997811079, 0.2766671170081411, 0.13988614162164076, 0.11321970860340766, 0.1288582512310573, 0.09620979242026806, 0.10958875915301697, 0.17510426683085306, 0.13984420815748827, 0.13472616778952734, 0.12687439125563416, 0.10220155519034181, 0.10274850869817392, 0.13983306661248207, 0.27967530701841625, 0.269041116216353, 0.15691133162805013, 0.09794261479484183, 0.19758783679987701, 0.1660815288445779, 0.15404536255768367, 0.06305537040212325], [0.06919179005282265, 0.03807276953011751, 0.01219603422630046, 0.023908435832709074, 0.11663622063185487, 0.04832925720672522, 0.0675963099513735, 0.03050904468234096, 0.026393151343134896, 0.042475494888744185, 0.07073828671127558, 0.02161508076824248, 0.06834375020116568, 0.06832184030541352, 0.009454935107247105, 0.05778881907463074, 0.04634335144822087, 0.020175845229199955, 0.04728670511394739, 0.06550406757742167, 0.039734121811177046, 0.049259650853595564, 0.018762551780257906, 0.007668180224884833, 0.06321101955005101, 0.05516928035233702, 0.055540031886526516, 0.020683542093528167, 0.03341175303129213, 0.019109675028760518, 0.05456792190670967, 0.01964319184688585, 0.044416522341115136, 0.042379336298576424, 0.08272803441754409, 0.07379352633974381, 0.008606829098425806, 0.03189387358725071, 0.05331136665440031, 0.01631370702359293, 0.008761542716196604, 0.05409181424017463, 0.01062527485191822, 0.012048032168032867, 0.013576251637589718, 0.022431383840739727, 0.011848737951368093, 0.011883730850448566, 0.034178100659378936, 0.02740714728965291, 0.03464857987793429, 0.05413100642285176, 0.03410075105992811, 0.0455579573421606, 0.029032674618065357, 0.035783785927508555, 0.0498201004229486, 0.040123407529400926, 0.009147175371513834, 0.018215337036443607, 0.04833680930148278, 0.010860045423864253, 0.052455021534115076, 0.08495736800666366, 0.04975820106587239, 0.04654183990455099, 0.015692908549681306, 0.04158570138471467, 0.04256445422236409, 0.048901906835713556, 0.047610647909875424, 0.027019261049904993, 0.017996950540691614, 0.03610252435984356, 0.03366263796176229, 0.07926423528364726, 0.0494464888636555, 0.05474689230322838, 0.008822125715336629, 0.04347194731235504, 0.04218381643295288, 0.026823936263099313, 0.012477164007058101, 0.0311710030904838, 0.053392570332757065, 0.04352852016953485, 0.038087778724730015, 0.04311464434223516, 0.05048545829153486, 0.0655149919912219, 0.031015781419617788, 0.03518734346809132, 0.0261533299261438, 0.02919354848563671, 0.03112774309036987, 0.02958360094843166, 0.07705164115343775, 0.05738177948764392, 0.010733882863340634, 0.031709162784474235, 0.005896694924948471, 0.051301138808152506, 0.028868879657238722, 0.03960492874362639, 0.052486766794962544, 0.017482870358175466, 0.009806864928188068, 0.0481480340739446, 0.0663564975506493, 0.02006682161507862, 0.035084820219448636, 0.038301849737763405, 0.05773013936621802, 0.037544360384345055, 0.030896335507610014, 0.03309501288458705, 0.029744556240205253, 0.03551850248394268, 0.026864644971543124, 0.027984536485746503, 0.05911770955260311, 0.016362819388242703, 0.006767502595071814, 0.07642721251717635, 0.03189971238108618, 0.03556273618180837, 0.034844500079218826, 0.03588029057053583, 0.02845624046001051, 0.0036529110844380087, 0.0349462260492146, 0.02063810738867947, 0.040891054552048445, 0.01515381078102759, 0.040005647776914496, 0.02352730610540935, 0.023605481821245382, 0.015533698789243187, 0.02920149073802999, 0.021896752528846264, 0.043124964859868796, 0.019097447827724472, 0.017184316646307707, 0.04186136641406587, 0.0315207166464201, 0.013785628884631609, 0.043856615599777014, 0.08076090711568083, 0.01171450930581029, 0.03074587375989982, 0.046699460196707926, 0.032644560627107105, 0.04539538713704262, 0.04756488411554268, 0.04244922201282211, 0.01344489913234221, 0.007497828919440508, 0.015046262980571814, 0.04528462647327355, 0.0351458849784519, 0.053099046261715035, 0.03165478838075485, 0.04223013662600091, 0.04984312311613134, 0.056526689657143185, 0.005414314626250416, 0.05350777540089829, 0.027002547036058137, 0.047590000089257956, 0.014394601341336966, 0.014839301318196314, 0.016078087434704815, 0.010674553457647562, 0.09104734872068677, 0.04870328606505479, 0.08447312470525503, 0.09021027399493114, 0.07135564501264266, 0.012952406541444361, 0.0698492769151926, 0.11007242569965975, 0.0414871373879058, 0.02172834861890546, 0.038965070221040926, 0.06545936569039311, 0.03585568689075964, 0.0036915133657333043, 0.0492543616731252, 0.07019967918417283, 0.040496455904628546, 0.022078426887414286, 0.022865398587392907, 0.03777366790122219, 0.011966439180209168, 0.06160122914505856, 0.08162312156387738, 0.007092642157138991, 0.032694005473916016, 0.02909060793795756, 0.056567937800926824, 0.0472815787818815, 0.05319330834650567, 0.015872143574857285, 0.01756445740881775, 0.016827568378565565, 0.02218029704610152, 0.006324477327455367, 0.04055075906217098, 0.016290536749043634, 0.042042447054492574, 0.04453150010002511, 0.0624902592971921, 0.05568419343658856, 0.079532751946577, 0.04786576350618686, 0.052794916688331535, 0.015368112495967319, 0.036250729978616746, 0.026476202333079915, 0.015539566420816948, 0.019680339942819307, 0.041921708533274274, 0.049857508058526685, 0.023126622695209723, 0.01780825504101813, 0.030654872035873786, 0.012988120383982147, 0.045410467577832084, 0.04663081280887127, 0.0945282740784543, 0.03272832577515926, 0.02313978797090905, 0.026746033657608286, 0.014723030950075813, 0.012499159567856362, 0.022721231948318224, 0.004750786681792566, 0.015792040819568292, 0.08428133678223405, 0.06571263567145381, 0.026715106031458293, 0.020790843925039684, 0.03664709960243531, 0.009692709044819432, 0.03440667875111103, 0.03416499814816883, 0.04682290607265063, 0.031269821537924666, 0.014396733637633068, 0.05203403465981994, 0.0759984530242426, 0.06662375892379455, 0.025030705612152815, 0.052094509093356986, 0.016013736869873743, 0.058163098990917206, 0.003138167845983324, 0.015017002854230148, 0.013837430792461549, 0.01847729565841811, 0.021078405369605337, 0.07248224384550538, 0.0542215535284153, 0.03039071835311396, 0.0038662590335921516, 0.0685583572568638, 0.017039490131927387, 0.055058875919452736, 0.04351922423977937, 0.018335218907200863, 0.032566661414291175, 0.02710800155598138, 0.021194802963041832, 0.05826180548007999, 0.0497363624162972, 0.03371346702000924, 0.047075853749577484, 0.030861967708915472, 0.06376871426722833, 0.02715338028169104, 0.03393638612968581, 0.0414875920063683, 0.04891896859875747, 0.06751517751919371, 0.011493166093714535, 0.061808752295161994, 0.007170192348504705, 0.02912982726203544, 0.010790323406191809, 0.015934997969972234, 0.05286448009844337, 0.01237068829193179, 0.026309328519606164, 0.09402315903987203, 0.014740613488746541, 0.01588620960579387, 0.028844018134155443, 0.013775199801394982, 0.0101445777441508, 0.00935388682410121, 0.045438307869647226, 0.017817759620291845, 0.031251110934785435, 0.01695629664962845, 0.013438933113190745, 0.01214627894972052, 0.010283945444306093, 0.018123909531693374, 0.008764394259612476, 0.01740997364478452, 0.09009125895266022, 0.036619272881320546, 0.04075751546770334, 0.041960008442401886, 0.013159210444428027, 0.03693641336368663, 0.01927783975510725, 0.009061244000414652, 0.03184487657355411, 0.044264445680060556, 0.05063862739396947, 0.01933683837497873, 0.031781620146440606, 0.03750409272366336, 0.027770333158384477, 0.03586741876123207, 0.026536118671564118, 0.023872514188821827, 0.044134781030671935, 0.04165143785732133, 0.02469775526385222, 0.02783988639047103, 0.008539611723140945, 0.027107641932421496, 0.08440073180411543, 0.053200008879814825, 0.0562620101097439, 0.016415938502177596, 0.05182784143835306, 0.014239469576360924, 0.052252285448568206, 0.018888231732749512, 0.03317940228485635, 0.010732512222602963, 0.04447051337254899, 0.015305845033643501, 0.03653864935040474, 0.051275052529360564, 0.038471137439566, 0.03130569229168551, 0.018023352338267223, 0.04466992802917957, 0.23709737030523165, 0.20504963211715221, 0.11616241319903306, 0.15717695094645023, 0.16196174919605255, 0.1060759833614741, 0.09146254429859774, 0.14730219010795864, 0.15406619358275617, 0.10738912504166365, 0.11003567624304976, 0.19193277667675698, 0.10846855890538011, 0.17838057316839695, 0.1137353680761797, 0.1968737601169518, 0.10341214308781282, 0.0985180124906557, 0.14460308636937821, 0.1370716326470886, 0.09731411494846855, 0.13139314949512482, 0.19651828919138226, 0.1889750561011689, 0.14696543317820343, 0.18243066727050714, 0.14899794411446365, 0.2344006278685161, 0.1671609152108431, 0.13591398405177252, 0.1287200336477586, 0.0892598499943103, 0.12542639752583845, 0.09633353006626878, 0.17917549051344395, 0.18378712662628718, 0.1607764842254775, 0.11557201987930707, 0.17575876813914093, 0.09425062433417354, 0.10759432081665311, 0.1554824183029788, 0.06800640294594423, 0.06205998667116676, 0.08488445941890989, 0.13938595274729387, 0.1345659385302237, 0.04730516126645463, 0.07932381744363479, 0.05537278318245496, 0.15489004366099834, 0.11600666227085249, 0.12886952848306724, 0.19321982190012932, 0.1806404340480055, 0.12646204552480153, 0.1549954880028963, 0.08125952857413463, 0.09212368167936802, 0.0853501380022083, 0.0986109378614596, 0.06680483956422124, 0.23073336322392735, 0.1253944928092616, 0.11160436778196267, 0.12879445536860398, 0.13015105043138775, 0.12873703773532594, 0.11681914010218211, 0.116973520389625, 0.16013013890811376, 0.11394861127649035, 0.07528468846742596, 0.11919298129422323, 0.16380741872957774, 0.1833352358745677, 0.10087069696081535, 0.1480741865400757, 0.08853106945753098, 0.22494792938232422, 0.09538682443755013, 0.09749566377805811, 0.09529624679791075, 0.09481123675193105, 0.1481620432542903, 0.15178554239017622, 0.18634673713573388, 0.11769705585071019, 0.15155843671943459, 0.11710077284702233, 0.12782600947788783, 0.09677327504115445, 0.1420313436537981, 0.1490661504545382, 0.09194395810897861, 0.10592908731528691, 0.08793002313801221, 0.16235092974134854, 0.09176462130354983, 0.11422352652464594, 0.05895438617361443, 0.15262928711516516, 0.1682518231017249, 0.09550389208431755, 0.19274768366345338, 0.14256837697965757, 0.13248669010187897, 0.18340621063751833, 0.2165567853621074, 0.11113423122359173, 0.12910367734730244, 0.09641561244747468, 0.11616989065493856, 0.08199890104255506, 0.13440762273967266, 0.10335192989025797, 0.12242230586707592, 0.20678533826555523, 0.0824454313676272, 0.0691373986857278, 0.1887454262801579, 0.12033901337002005, 0.13953083354447568, 0.1391068577234234, 0.1369448687349047, 0.13123539010328905, 0.0830273429996201, 0.15269704562212738, 0.10512026000235762, 0.11521050999207155, 0.1512299443462065, 0.09367838861154658, 0.1807603176151003, 0.09635332971811295, 0.1878829404179539, 0.08772168574588639, 0.09879548581583159, 0.12776036800018378, 0.14241406454571656, 0.0850834601691791, 0.12613786863429205, 0.1270253924386842, 0.08547804185322352, 0.09581554321838276, 0.11639166304043361, 0.07948845718055964, 0.12919070624879428, 0.11139345195676599, 0.16096723398991994, 0.1514722763427666, 0.13573258449988707, 0.0953682122219886, 0.14483089771653923, 0.11199442363743271, 0.12333380909902708, 0.08617680400077786, 0.11938560381531715, 0.08611168499503817, 0.19258634160671914, 0.10339505079069308, 0.11475814426583902, 0.2219114444617714, 0.1265502143651247, 0.13883935207767145, 0.10085372679999896, 0.05635200081659215, 0.15798680963260786, 0.11850208336753504, 0.12637968494423799, 0.1951069092111928, 0.07677671233458178, 0.11733007697122437, 0.09334602180336203, 0.1458474245986768, 0.14290057415408747, 0.2032912221870252], [0.03724007474790726, 0.05650622843365584, 0.050557620490768125, 0.017914980117763792, 0.02626375641141619, 0.017256521253979633, 0.01497946968967361, 0.0772814948910049, 0.009828233692262853, 0.016514494017298733, 0.00817649794875511, 0.023808066932750598, 0.03525428773303117, 0.028096683057291166, 0.02266788891782718, 0.05701592019093888, 0.02553119813092053, 0.08011429038430963, 0.03643531525241477, 0.025074812084702507, 0.030604372067110877, 0.057055607704179626, 0.04890526558405586, 0.02835053318579282, 0.061625887107636244, 0.08125545736402273, 0.026526363034333502, 0.012721174529620578, 0.055509874397622685, 0.032788311663482866, 0.0348151975444385, 0.010757776625853564, 0.01775434543378651, 0.0037205966488857356, 0.04682288232392498, 0.012424790433474948, 0.057159939248647006, 0.08904097495334488, 0.029474523051508834, 0.07245423391993557, 0.07910338177212647, 0.039142605515995195, 0.020006504940933416, 0.008064655021631291, 0.023765577069882835, 0.017901845376140306, 0.042703204455652406, 0.011930170635293637, 0.014597654642005051, 0.04040783583851797, 0.028177019907161593, 0.038818890029298406, 0.0288999667391181, 0.011813668717098023, 0.018020704355356947, 0.022528538181047355, 0.022466847473489385, 0.022112619963341525, 0.06104776170104742, 0.036534147270556004, 0.04254050532888089, 0.045305803551205566, 0.024345502290608625, 0.05022893812773483, 0.022156253157715713, 0.03756736611415233, 0.05468162062710949, 0.0171312297627862, 0.003048570053319314, 0.020584645614560162, 0.07549108524939843, 0.02007710650962378, 0.06646929721214942, 0.04911113650138889, 0.06108002604118415, 0.08419917297682591, 0.015457370384995426, 0.055659650824964046, 0.05514693619417293, 0.05209272115358284, 0.015700477607814328, 0.050068264427993975, 0.0814968461969069, 0.024953473059992706, 0.04333505626501782, 0.028291331005415747, 0.0431978055941207, 0.05747608228453568, 0.02980865744341697, 0.013146643975882657, 0.04088741760434849, 0.013347081524053854, 0.01585290371440351, 0.044452847713338475, 0.027158733922988176, 0.036966516569788964, 0.01808161474764347, 0.02936642224501286, 0.025782863376662135, 0.01678887491912714, 0.0039510033924930864, 0.04239814528929336, 0.06312259286642075, 0.02758864014010344, 0.04259749887777226, 0.02877934356885297, 0.04249166777091367, 0.04151803787265505, 0.03800731464954359, 0.013880911316456539, 0.00496802942195375, 0.034168105838554244, 0.013646966012726938, 0.025488251953252723, 0.012672335275315812, 0.03683042958644884, 0.029078998203788484, 0.030292819320623363, 0.02888147665985993, 0.03039070817508868, 0.051747445216668506, 0.0039031916946571854, 0.07391091289797, 0.005889373956181641, 0.05800371790038688, 0.019004266309951032, 0.02714759237798197, 0.04206155799329281, 0.09488434890019042, 0.018321692311604108, 0.013891828944906592, 0.03386122141299503, 0.03348523498113666, 0.025428311866042868, 0.07027873529919557, 0.06144052491124187, 0.004885254510944443, 0.007812898173662168, 0.04422705500785794, 0.019217467101823007, 0.05677323874884418, 0.030462113807776144, 0.04093110847419926, 0.026552737690508366, 0.05628216599247285, 0.02749531782631363, 0.01020048902968743, 0.016395005696852292, 0.02811145137197205, 0.05487025336229375, 0.02983841798933489, 0.055489837258521996, 0.03768788071881447, 0.0475174816591399, 0.04704475988234792, 0.019549998454749584, 0.019454311446419785, 0.010946583235636353, 0.033707903032856326, 0.03473886235484055, 0.040153001834239276, 0.06091088083173547, 0.04660084191709757, 0.017133608028026562, 0.071512406958001, 0.017098987475037575, 0.024543281677844267, 0.037240173135484965, 0.04020795638539961, 0.037750950548797846, 0.08531784652067081, 0.02233083512900131, 0.03862439135887793, 0.04449275914313538, 0.07985424183841262, 0.03909819879169975, 0.0035112003180464463, 0.038534288693751605, 0.013103886091682528, 0.059016797824629715, 0.07117134133087737, 0.048951891117862294, 0.012135163697946285, 0.08030541334301233, 0.012605880403758159, 0.04277861683762499, 0.019634725426190665, 0.02538411209492811, 0.03335132948788149, 0.02853877915601645, 0.010127953636193914, 0.03405271417328289, 0.030850378330796957, 0.05378485856843846, 0.04486388047891004, 0.017632222701130167, 0.021196104053940092, 0.02316670206242374, 0.05926779471337795, 0.037056578522814174, 0.05787122715264559, 0.0411494712212256, 0.06512634748859064, 0.008154419267417064, 0.04132132717807378, 0.058161097312612195, 0.05001791373693517, 0.037373688471104415, 0.08763664495199919, 0.051141523623040745, 0.03740436164662242, 0.034288773113595586, 0.07064848938690764, 0.01930169535002538, 0.05594809606139149, 0.018672669639012644, 0.012161318678408861, 0.02497057892781283, 0.05366478840421353, 0.02357576198742858, 0.03763601350198899, 0.032328872209680934, 0.012536389936160828, 0.03686445811763406, 0.013456865097396076, 0.06660760979035071, 0.03308003083137529, 0.04235469190669911, 0.06637877385531153, 0.004016917556457753, 0.017577400464298468, 0.048393656965345144, 0.04483129722731454, 0.042704921149249585, 0.01092593202234379, 0.020078470365011265, 0.0031328947807196528, 0.045399241215948544, 0.06927472060280186, 0.05995445858154978, 0.0074408616637811065, 0.03533509446840201, 0.12041377435837473, 0.049757495389453, 0.03134523391989725, 0.026483462657779455, 0.07831358736647026, 0.027842195105871985, 0.027067501497055804, 0.02506077998051686, 0.016816133367163793, 0.1094659985974431, 0.006658551075296211, 0.0328698274679482, 0.02648424806206354, 0.08088802386607442, 0.060917286202311516, 0.03593539100672517, 0.033051023459328074, 0.02134186864298369, 0.012122061186736184, 0.02953671078596796, 0.06620517745614052, 0.07949612462627036, 0.010325217336815382, 0.01802284682967833, 0.047845166575695784, 0.03449251003829496, 0.03977462017376508, 0.021571557835808823, 0.05826954077929258, 0.06087175650256021, 0.012090900314173527, 0.027445323366139616, 0.014339485638109701, 0.03893409849011472, 0.0191445500323815, 0.09438426859144654, 0.03822802173505936, 0.07437121748392071, 0.027273280812161307, 0.04978788018758808, 0.011549035818981273, 0.01349224815411227, 0.058989296800323894, 0.01321413615785007, 0.012019664315240723, 0.05554632529882448, 0.015256501967087388, 0.012420625076629221, 0.0031255948041299625, 0.06359229516237974, 0.06800188390272004, 0.004215080740063318, 0.01065059014529522, 0.03577873423429472, 0.05196112267939108, 0.07519915234297514, 0.03353675614510264, 0.053033160511404276, 0.03524700026693089, 0.060574463169489584, 0.035929667563842874, 0.04684116205732737, 0.05623530975676008, 0.010213063979920532, 0.030993372800626924, 0.008053139434196055, 0.07227455106164728, 0.041680971094008, 0.04227100479017411, 0.05558370240032673, 0.03192140853830746, 0.04611523476030145, 0.0357588124461472, 0.012720015931076236, 0.042421371542981694, 0.06705929698156458, 0.04224633664957114, 0.014553649949708154, 0.05387358380747693, 0.0109346232077639, 0.033083929015057426, 0.0312520303497357, 0.09880392000611339, 0.04846936451005084, 0.037193819015686, 0.08531136651124273, 0.06716949785394327, 0.031463139557412693, 0.013220484701118298, 0.0419118053146771, 0.02278874787901129, 0.052737709400909286, 0.05350298833634172, 0.07091229023145777, 0.031551271078309844, 0.03152480821258255, 0.03395328165165015, 0.025560765294358134, 0.010464953142218292, 0.020292315765150955, 0.04576321418530174, 0.05024962666045342, 0.08176433827195849, 0.059571310212569575, 0.05102078170914735, 0.062202180469674725, 0.05712827880467687, 0.044235838643674336, 0.03497189502897007, 0.03409122782094138, 0.10893978790513106, 0.13401198254099914, 0.10823006063167538, 0.0887018431510244, 0.27472083430205074, 0.10055803480957236, 0.15597628323095186, 0.17815189329641207, 0.1550555926348482, 0.16300798234130653, 0.07218728467289891, 0.09107711605195488, 0.10376737652612583, 0.12071903369256429, 0.0971166341166411, 0.17127708505306924, 0.10061221583081142, 0.16137462641511643, 0.16551913187972137, 0.10602529001023088, 0.11475378807101931, 0.09625293367675372, 0.11802755668759346, 0.14085878085877213, 0.21477971571896756, 0.12519865403217928, 0.10447322936462504, 0.13986187720937387, 0.1431536270039422, 0.1023318406992725, 0.058518535989735804, 0.1196887054081474, 0.22285297965364798, 0.1394690732870783, 0.12594886949019773, 0.15860241731362684, 0.09680715429463557, 0.1392509921320847, 0.0910126959372844, 0.14502110465296678, 0.15939685968416079, 0.12954140028783254, 0.1868593974837235, 0.17423044943383761, 0.12767781742981502, 0.11623470431991986, 0.1538741953138794, 0.1311174471463476, 0.11306408659688064, 0.18958594117845806, 0.1086460297395076, 0.12052456555621964, 0.15230608731508255, 0.11493346414395741, 0.11879004005874906, 0.11882388538547925, 0.08821714523115329, 0.11065296669091497, 0.12177738547325134, 0.0964097770463143, 0.08577170502394438, 0.1141871977597475, 0.24848131516150065, 0.14507392181881837, 0.06200882513076067, 0.12030117825738021, 0.25488983414002825, 0.11311214044690132, 0.12509957434875624, 0.10079392750880548, 0.14805668033659458, 0.14347992092370987, 0.16271575087947504, 0.160788182169199, 0.1722922277237688, 0.22988628010664666, 0.09424831052975995, 0.09859178281788315, 0.1654683638896261, 0.20018072266663822, 0.11773186469716684, 0.12367771778787885, 0.13894813481186116, 0.11814505181142262, 0.26026605708258493, 0.08284802655024187, 0.14985821795250687, 0.11035930352019412, 0.06604901940694877, 0.13414539609636578, 0.1564919427037239, 0.06154692598751613, 0.17785184511116572, 0.25906944700649803, 0.15179505545113767, 0.14050413774592535, 0.06097549772156136, 0.08887261005916766, 0.08273643468107496, 0.09899346197822265, 0.10770096616553408, 0.14780632805611404, 0.11920109657304627, 0.18294399258281502, 0.0846982015562909, 0.1488820096211774, 0.1317721927272422, 0.13882232084870338, 0.12345335339861256, 0.10001107451639005, 0.11786943088684763, 0.1444868804620845, 0.12634379044175148, 0.10844676436058112, 0.11773132186915193, 0.10929135725434337, 0.131311725292887, 0.13825944890933378, 0.1372371951916388, 0.18332185516399996, 0.1276864212538515, 0.11284217850438186, 0.1482634435274771, 0.21221398482365267, 0.20474347711673804, 0.15298376737960748, 0.08818873496992247, 0.18511983725641454, 0.18671362102031708, 0.1741700598171779, 0.1490646576774972, 0.13441516804908002, 0.1820402517914772, 0.08960261874433074, 0.12858163964535507, 0.10971509558813912, 0.23324703691261156, 0.22776368686131068, 0.1597118763519185, 0.09064689770873104, 0.1748494633606502, 0.16626735244478497, 0.09239319578877517, 0.0831110810062715, 0.14794507489672729, 0.1292842219450644, 0.12893055592264446, 0.09747399136956249, 0.18718749630664075, 0.1374832319894007, 0.0867253045684525, 0.17360963060387544, 0.17521043041987078, 0.17550078912505082, 0.08439294222210135, 0.16170712214495453, 0.14065230265259743, 0.1446240802428552, 0.14768504670688085, 0.1965707806604249, 0.12883655168116093, 0.1263709861252989, 0.06222200047756944, 0.10747927520424128, 0.177791564060109, 0.11037862819752522, 0.08793543784746102, 0.14248375009213174, 0.18182461336255074, 0.11598579053367887, 0.1677029561251402, 0.180580451552357, 0.17570565241788114, 0.17880818593714917, 0.16076479985245637, 0.10319150385579892], [0.05111961711996368, 0.0264988772770656, 0.05881407870245831, 0.062157675357801576, 0.023794655688107014, 0.042503406426736286, 0.08562071741159473, 0.02378822147979268, 0.02119871980643698, 0.020058645268103907, 0.03769044218850987, 0.08573642120297466, 0.01166726545696812, 0.004865390822357897, 0.022341410097266947, 0.016549440267096673, 0.015450981977794851, 0.04075371567159891, 0.030274424236267805, 0.01568680173451347, 0.06378339097968169, 0.037230314021664004, 0.02599747891404799, 0.07885963842272758, 0.046670222122754366, 0.054570551229906936, 0.012860290323650199, 0.03886177344247699, 0.026610023009457758, 0.020449834277055094, 0.009373012181770588, 0.05509071956787791, 0.07340713457337447, 0.023423403734341264, 0.048441792239568064, 0.03231132868677378, 0.0342357489945633, 0.01007008901797235, 0.05321558125849281, 0.05142119200900197, 0.03428800297634942, 0.03796503173985651, 0.0250056099944881, 0.01652647355305297, 0.023425491925861155, 0.02927806680755956, 0.036098670280937634, 0.03641869453713298, 0.050160087179392576, 0.02636180302527334, 0.026637931154774766, 0.015250059277085322, 0.04668680551861014, 0.008479449415712484, 0.03180647149149861, 0.018747249119249836, 0.042844577226787806, 0.021554351884073446, 0.06152498895036323, 0.005280179703342063, 0.02431046952759581, 0.03039679802688105, 0.040561707224696875, 0.06034609542361327, 0.04751818394288421, 0.01529532265184181, 0.036844156349876096, 0.041229212656617165, 0.042023651634476016, 0.06315615320844309, 0.009573075687512755, 0.03938303082915289, 0.07099553969289575, 0.022844297844650488, 0.005574741508878235, 0.015670474485627243, 0.040910134956772835, 0.02019962279259094, 0.059793740777032714, 0.030485357024839947, 0.0738889758608171, 0.014410311123356223, 0.0365068396287305, 0.017079121666029096, 0.025239365308412483, 0.013890252199157007, 0.03586906420865229, 0.05712196842900344, 0.05322824611461588, 0.05637368679578815, 0.058282507583498955, 0.05162435557161059, 0.015332918580887573, 0.018146533585552658, 0.052727361741874895, 0.014461520161213619, 0.027042553460757648, 0.037923939659127166, 0.04634869830416782, 0.007969698286615312, 0.02104140485503844, 0.015904353632192527, 0.024996902693861296, 0.04448424692132643, 0.03302794987601893, 0.0569375426109348, 0.05819300202918904, 0.024683972521285926, 0.012240553757042756, 0.023321501345240643, 0.02278706680850259, 0.006995028109356228, 0.014538656022133572, 0.021913531003519893, 0.0677610853953021, 0.09352462579097066, 0.04349814894210015, 0.027021393346201097, 0.03000810941947358, 0.022344446541475396, 0.014499221263187272, 0.059813214732067924, 0.020810458676091263, 0.06615326952721391, 0.039009297133556435, 0.038351745810359716, 0.04851612914353609, 0.01305421902465501, 0.030215011710034947, 0.029316990968904326, 0.01638171828484961, 0.10858513800693409, 0.051368385021175654, 0.056672998770539246, 0.060019916854798794, 0.01958223056447293, 0.03285566304943391, 0.012097158951551785, 0.07202491802828652, 0.0656185092936669, 0.046771015107099495, 0.013104930187442472, 0.021685343069423522, 0.04100235125848225, 0.10927479421453816, 0.01916682464070618, 0.06284172008080141, 0.015290798519604971, 0.04043654126248189, 0.06890970268951994, 0.008988296396897306, 0.06917592590408665, 0.04382799838536552, 0.06095626125378268, 0.043509626361940584, 0.026227258012763092, 0.02388592543346541, 0.03468988569719451, 0.04251724514844162, 0.039764503216637034, 0.007342669164894947, 0.026468443285141672, 0.027789138756426315, 0.038610298186540604, 0.006585712037381849, 0.024927441064002256, 0.05175903120211192, 0.04232202044555119, 0.027941771816196184, 0.042965851790670834, 0.015483653438942773, 0.03674124294359769, 0.039426083876086135, 0.0417810244751828, 0.020618228008970618, 0.05081679711916617, 0.048608250450342894, 0.038111093187970776, 0.0301168887609882, 0.03384961507150105, 0.022483218827151825, 0.007447761516751987, 0.0510404354759625, 0.02647049246089799, 0.017512327259672538, 0.019273123936727643, 0.04752924406368818, 0.026019090254391943, 0.06940134202263185, 0.024874237133190036, 0.013543402060999401, 0.04026937058993748, 0.0036575344524213244, 0.005602696727562163, 0.020451286341995, 0.031190453296793357, 0.024265053482460122, 0.039941929945988316, 0.012156133822697614, 0.06478790779198919, 0.049415839436863146, 0.03588719805702567, 0.015905659812103425, 0.051495115006608624, 0.024873048000569855, 0.03832983930728265, 0.0102430391125381, 0.023876163010884608, 0.024638844853533164, 0.012373773081760322, 0.05510206128071461, 0.05291982480723943, 0.03370665113574692, 0.024547554752124206, 0.017318741218852143, 0.028910073518220867, 0.05551266996189952, 0.013290337336781834, 0.03133528659652386, 0.04061024961993098, 0.017948440375870893, 0.03313795058056712, 0.021423647379768745, 0.059423654207161496, 0.10074581259063312, 0.03689499219347324, 0.03914678529171007, 0.022072637287367667, 0.045492539781012704, 0.0905743216031364, 0.03294050706816571, 0.04410942078434995, 0.00992074515670538, 0.04307489915351782, 0.08745616820773908, 0.01742198201827705, 0.042435084735708575, 0.010775534735460366, 0.004722457420679608, 0.03544707310252956, 0.04048664428825889, 0.07923574359821421, 0.01480745936610869, 0.00939752341115049, 0.007968856903192188, 0.024713677088064805, 0.005990296710349087, 0.01759392618467765, 0.03487538020791752, 0.040223226815994294, 0.05566693829106433, 0.0037765151438569383, 0.06251508010817425, 0.04007874635447349, 0.04049049497448972, 0.021264161116310527, 0.06190456822514534, 0.036700239072420766, 0.03862961947119661, 0.04533486859872937, 0.022475614145930325, 0.021529015386477113, 0.04039666036676083, 0.0648680767044425, 0.034832337339009554, 0.0499485674580293, 0.019320994582293288, 0.1102316982245871, 0.027183829540652887, 0.03525175340473652, 0.012137707356097443, 0.0178199156653136, 0.010960959696343966, 0.041374514145510535, 0.01310206761783255, 0.02229704917408526, 0.038174563353615146, 0.005984542309306562, 0.005659172469417432, 0.037914005906454155, 0.011434355767310729, 0.0030034103671953616, 0.009970509763141828, 0.03082254821700709, 0.0668217350861856, 0.027951968501188924, 0.047242074473095794, 0.011449984973296523, 0.07654861600271293, 0.048058470844158103, 0.05343184733231153, 0.045878161410135884, 0.02311708079650998, 0.0029150542936154772, 0.03904402455581086, 0.013695393057007874, 0.020517297621284212, 0.02382983433614884, 0.08032374057386603, 0.040887237792568545, 0.05519265927640455, 0.032026520398046286, 0.05129041116950767, 0.04989819980359503, 0.02308372062231813, 0.03467382816597819, 0.005662911621454571, 0.10281328843640429, 0.030242193822882006, 0.021092713976811086, 0.06008372628795249, 0.044689720895673544, 0.04986410681158304, 0.025319960001589994, 0.03298422847209232, 0.04677298964400377, 0.0787364843168429, 0.024274776889277355, 0.03565185497115765, 0.036573190175529034, 0.030523331237158606, 0.03530607691832951, 0.09388413399990116, 0.008514885907061398, 0.029288224476788725, 0.066412775245096, 0.06271259486675262, 0.07675537919359547, 0.028669736414615597, 0.0403640940785408, 0.028379023174888322, 0.08779311512729951, 0.029445756559393237, 0.0711964742679681, 0.08581402525305748, 0.04378288598465068, 0.013208465301431715, 0.03073600446805358, 0.014632112346589565, 0.04099521307008607, 0.033699445093848875, 0.029611420884196247, 0.021312075866652385, 0.056505302233355384, 0.07729213432009731, 0.020640575559809804, 0.05202922045386263, 0.04152763235781874, 0.024738609857325043, 0.026727443494434868, 0.03281327496681895, 0.05176174873486161, 0.12170642428100109, 0.08690431567707232, 0.10685490763613156, 0.09580888678984982, 0.11357879612062659, 0.054079308839780946, 0.15958618452506407, 0.20412892795034818, 0.09765864110418729, 0.1338664639208998, 0.1059930460261447, 0.13206430205277034, 0.1445634327828884, 0.09300506474184138, 0.10520367909755025, 0.12661333169255937, 0.11059457196721009, 0.11142676802618162, 0.09727852578674044, 0.11830446682870388, 0.17013535488929066, 0.107719483386193, 0.06635872993086066, 0.15959598257073335, 0.10494859742798976, 0.2136022403304066, 0.05692706603024687, 0.10452895066035645, 0.07732258018638406, 0.10708527706031289, 0.12836273067763873, 0.1462297790816852, 0.21686097261096748, 0.14974316555474484, 0.1837113071233034, 0.13069972741816724, 0.12696342862078122, 0.10811667064470903, 0.08870544617197343, 0.13909017933266504, 0.13462190409856184, 0.09071395053927388, 0.10536789135741335, 0.1392551583370992, 0.19754835963249207, 0.10629792538072382, 0.09722541006548063, 0.1329854540526867, 0.20044605700033052, 0.1851820182055235, 0.08434458981667246, 0.1439444324267762, 0.19452012569776603, 0.1480996994567769, 0.11783638623143945, 0.12185191575969968, 0.10949765904141323, 0.10737119814647095, 0.13240925568555081, 0.07159977512700216, 0.16185261362365314, 0.10048866138926574, 0.09588691831699439, 0.10500453585492713, 0.07479085746620383, 0.1666834708303213, 0.17552702128887177, 0.12098102963396482, 0.06645415909588337, 0.13332541366772993, 0.10816403917436089, 0.08174482360482216, 0.1797034586114543, 0.13797014871878283, 0.1526116587753807, 0.08833565815751042, 0.09411721756415707, 0.13632171574447835, 0.1364185834037406, 0.12588649855128356, 0.1489693506487778, 0.09823890389608485, 0.17429807223379612, 0.10770218074321747, 0.1589936198932784, 0.14356631200228417, 0.1387755697859185, 0.16316515819302627, 0.07839352557701723, 0.11546795974884715, 0.17485462022679193, 0.17625968983130796, 0.10565601768238203, 0.08192131056317262, 0.0901189296107207, 0.15233621426991054, 0.06962666314627443, 0.1675405419830765, 0.1126963681142245, 0.06370021615709577, 0.11853942993496146, 0.13326271703200682, 0.04919171253485339, 0.12322502636483737, 0.17481835931539536, 0.15779042802751064, 0.1361171645777566, 0.08088615110942296, 0.1401200597839696, 0.0787593238055706, 0.17190728123698915, 0.17288262104349478, 0.18688880519143172, 0.18347722611257009, 0.2253139176006828, 0.15121101321918623, 0.1952877930764641, 0.06576368186090674, 0.18805631968591893, 0.09747179970145226, 0.19796430159892353, 0.05342617817223072, 0.14967392784144196, 0.1228994924042906, 0.17972912080585957, 0.10066312631326062, 0.1020229851294841, 0.10580332763493061, 0.07486859043794018, 0.15733464248478413, 0.09933749280337777, 0.24944133364728518, 0.10593465130243983, 0.18311110218720777, 0.1477709628109421, 0.1015386807599238, 0.09141468722373247, 0.08090245630592108, 0.14234572249863828, 0.09797608014196157, 0.15648894357894147, 0.064383365213871, 0.11934709016765867, 0.14033298407282147, 0.21753699705004692, 0.19711321512503283, 0.17342767465327466, 0.20718506324504102, 0.3068525886961392, 0.16805614717304707, 0.1808642013264554, 0.18526532873511314, 0.09653731448841946, 0.15381851473024913, 0.10470040288886853, 0.2113856699849878, 0.07114583519952637, 0.2197824865579605, 0.14206731958048685, 0.12489365254129682, 0.17336246743798256, 0.10430227246667657, 0.0733678609664951, 0.10617591799902064, 0.08197360525705985, 0.08001460680471999, 0.13761139368372305, 0.15923204352813108, 0.12836902748261178, 0.1735960463328021, 0.13976158973361763, 0.09631854122770683, 0.17469752579927444, 0.09902024375540869, 0.10341850774628775, 0.1249019985220262], [0.04437805958358305, 0.016585019250799502, 0.04120902284713728, 0.04275583163169878, 0.015472189589802707, 0.0421396777299898, 0.006030918905578021, 0.043511933381003995, 0.06867262933935438, 0.015780166456741945, 0.06102719530463219, 0.03162794214274202, 0.0368268367435251, 0.06885175579892737, 0.06742269998150212, 0.024328596590619003, 0.031603470777294466, 0.035587397537061145, 0.02325505410720195, 0.014946906794128674, 0.02952897548675537, 0.029904517478176525, 0.03438319465411561, 0.008041949543569769, 0.059844535908528736, 0.0555718687496015, 0.04621733731723257, 0.05685337373454656, 0.018142302919711386, 0.03829515598980444, 0.0730313008118953, 0.04619999056948083, 0.014086511667950876, 0.02694257641477244, 0.014136308504800712, 0.01870472532963114, 0.010390632353456957, 0.03871203772723675, 0.04209624809612121, 0.03842187240453703, 0.022332107382161275, 0.02173997531645, 0.044103727875543494, 0.03079953570184963, 0.02985115409163492, 0.025567684655210803, 0.010745299215029393, 0.040177937996174605, 0.08364096257303442, 0.07301570807716676, 0.029066282457539012, 0.023487788225923265, 0.013155277485826185, 0.09276631541017975, 0.023964316584169865, 0.025759825416441475, 0.013993575270952923, 0.04346419844244208, 0.04474740315760885, 0.03862702068207519, 0.03160015952640346, 0.025038490105154257, 0.016108168588419045, 0.041062849440744946, 0.023298426065593958, 0.019699808808841875, 0.04911542145003166, 0.05543258925899863, 0.03973499372867601, 0.01896884508564004, 0.01613393934842731, 0.017741436305056726, 0.011113774264231324, 0.014107620044212257, 0.05573343472289188, 0.04163897656170385, 0.03543858802212136, 0.0589750882770334, 0.03140859551993864, 0.05131387151777744, 0.04612622024225337, 0.03739267048825111, 0.03323188018319862, 0.019703191305909837, 0.029669089575431178, 0.016136572064299668, 0.06792642402329616, 0.02109811850823462, 0.04201882385781833, 0.058434465500925264, 0.07624050682144505, 0.027950972751049057, 0.028050871765507118, 0.015529059306053179, 0.00927539389314396, 0.042416228247540336, 0.007889645573283945, 0.04463701568810003, 0.026119203007380878, 0.004104732286318072, 0.01910079809437905, 0.02293253453847553, 0.006283207131283624, 0.014480966974848082, 0.07617013595466103, 0.0249035227045949, 0.04434508956702692, 0.012484415001901132, 0.026847645972988436, 0.05222512708444681, 0.04958314920908638, 0.03359459447009223, 0.0164745741058141, 0.039884451244558604, 0.029587997855352502, 0.07061774496521268, 0.0478351174720696, 0.021296003068398153, 0.020387185138783286, 0.032594145475221534, 0.07982908175992114, 0.09081488262329783, 0.029053699025618177, 0.06983558407851628, 0.06110595286424671, 0.022599099037636603, 0.019876367013369287, 0.026493464263954332, 0.044866642116435936, 0.01310057908163539, 0.005197436174577368, 0.026168659728552614, 0.0023403796616808643, 0.011219402658753097, 0.01504172188495951, 0.019425583970067755, 0.01580871921032667, 0.030499514658004045, 0.015203187774334635, 0.026221755093761852, 0.03158989329157131, 0.04816402714433415, 0.028050505356597047, 0.07098812330514193, 0.03052997070231608, 0.03404559294826218, 0.03475551699687328, 0.04077438384826694, 0.05630504619330168, 0.03803649165534547, 0.09869072679430246, 0.00646689546660387, 0.04651381640828081, 0.03560957206147058, 0.020106081651257615, 0.010473524735841368, 0.01317112721569304, 0.06253808923065662, 0.04137176607868501, 0.06901815972690072, 0.016490073541977575, 0.026520554774573872, 0.056964704367731295, 0.057838949241808484, 0.07624574511178903, 0.02827754826284945, 0.02498118273381676, 0.013477727504713195, 0.02449445938691497, 0.018042593895058547, 0.04527290817350149, 0.01437124955867018, 0.07567722097571407, 0.04546604977388467, 0.03822401159309915, 0.027811387919687798, 0.028641441504337957, 0.00838181416371039, 0.023104819668723003, 0.011810118282612945, 0.025358380350683416, 0.025148100652066723, 0.0289279291672366, 0.024028047985796417, 0.05846491815256221, 0.049162070732563734, 0.06144448077040059, 0.02236066522475864, 0.029140392052275792, 0.08518258056470326, 0.019138334651610682, 0.004609668785373547, 0.016597555185269033, 0.022415132927043096, 0.004946616129018366, 0.04693343603451337, 0.015380086942708917, 0.08208547532558441, 0.07409679078097854, 0.025995650262172734, 0.03852319125352161, 0.1036722119897604, 0.03932228498160839, 0.04943633797977652, 0.035659271358911476, 0.035512436380875964, 0.07003641008798565, 0.015385613610435809, 0.07758696457105023, 0.029869559354015758, 0.031051204340266328, 0.051099559624812434, 0.024813769485003183, 0.06214141087340457, 0.03129804180935025, 0.044526858920497556, 0.026365049815337573, 0.007827804739853101, 0.02047674497589469, 0.07814128696918488, 0.0163140988775662, 0.03675320551597646, 0.041624761253063164, 0.07163324047412191, 0.047227540252996345, 0.07308596359299761, 0.07041172816285066, 0.01592008546659989, 0.011518146360426076, 0.05500968891595091, 0.05381670900221382, 0.06902471437518086, 0.011159360791290445, 0.04179428983479738, 0.02960764822949256, 0.06557923568678753, 0.003917354840918311, 0.008017928555740841, 0.00637766980798915, 0.009903428094860698, 0.010893042581821126, 0.051840645394154956, 0.01976547233893403, 0.07691442101661648, 0.018100087863526175, 0.03449617073472057, 0.04807620435687048, 0.030627398152968714, 0.008051090258439737, 0.01863203726575843, 0.028255843623940433, 0.04712729009666613, 0.04818143496023757, 0.021170268833105053, 0.014985335624909826, 0.06107649765908718, 0.05542427720502019, 0.011305314521970493, 0.037036860295172246, 0.01667592767626047, 0.07230416232986109, 0.008053220010229518, 0.05975207194153752, 0.0808512404827135, 0.046940994914621115, 0.025986021850258112, 0.04186041646503976, 0.05327301585514631, 0.052984797927950106, 0.012674697425349482, 0.04319334761904819, 0.03895693119349224, 0.021005595169429268, 0.014009741367772222, 0.061933182046881745, 0.047804763208010366, 0.021493331229846393, 0.0676914541316884, 0.007602011186203786, 0.036042267057512484, 0.04020595131441951, 0.02462506211096687, 0.012320279077227627, 0.023995737844545926, 0.02232287421689502, 0.025013860980314866, 0.014787688552002822, 0.033452244608529975, 0.03312769791643534, 0.06150506716221571, 0.047119412305099626, 0.06277193275413342, 0.0324868283766721, 0.07384210944707904, 0.011228807154111564, 0.021980587226737822, 0.03260636928358248, 0.07284775030400072, 0.03946628707594105, 0.09465102784867797, 0.035393027788294215, 0.038584110127495866, 0.057361023101423464, 0.008973498396309358, 0.012288643230151917, 0.004669458322626139, 0.004363198573368469, 0.02738949520114277, 0.021408936740564447, 0.04488001943432859, 0.09335581984903131, 0.09145971480756998, 0.02890420758298465, 0.04568531157981072, 0.023473973252943585, 0.06902229879051447, 0.06632896938494273, 0.01631376639540706, 0.04028576738866312, 0.07950812791075025, 0.026887939078733325, 0.09774503896811179, 0.04829150012561253, 0.05165685061365366, 0.04034867437024202, 0.010344528443446117, 0.04796617651092155, 0.031827356799372604, 0.03663770528510213, 0.027368961035140922, 0.02452607572610889, 0.04140181839466095, 0.024758633425725356, 0.05702626784997327, 0.020725153253546784, 0.014836151219372238, 0.07264342305383512, 0.06220855191349983, 0.020270807901397347, 0.04658677588616099, 0.05907601357570716, 0.019139279511624148, 0.07736079527863435, 0.05106090348480003, 0.027582292445003986, 0.026948301553992287, 0.05291676461430533, 0.025919778172725012, 0.03973838979644435, 0.017820517865142653, 0.03538422040375216, 0.1220012613173042, 0.08680799763117518, 0.08297365730894463, 0.08376512091074671, 0.12211092614701816, 0.09695927506046635, 0.11318967664348227, 0.07592728827148676, 0.18405004537531308, 0.09117904558245625, 0.19294730866593973, 0.1349790577909776, 0.14055645279586315, 0.08072811351822955, 0.12331063034279005, 0.14459091345114367, 0.12835173841033662, 0.1504803259990045, 0.06403133446084601, 0.1238672054771866, 0.12278168515435287, 0.10534296876617841, 0.1554195588188512, 0.15673337903405937, 0.10905390392456736, 0.11017072506781135, 0.2273646675582443, 0.15697111056319304, 0.1620638415749584, 0.0818101190296667, 0.12541073693760804, 0.20174954991255487, 0.12031103058585099, 0.21428187457578524, 0.09909214132598468, 0.05177066129233156, 0.12226726061531476, 0.11630297851349626, 0.13038500930581773, 0.056299706122704914, 0.10633684614939348, 0.09651621883468968, 0.1342755119715418, 0.1486154810658523, 0.19011488636689527, 0.07179820590785571, 0.10297189599701337, 0.09665656023259674, 0.09673812014183827, 0.1596643789006131, 0.13857272852744373, 0.14618890413216182, 0.14212795346975327, 0.1776865404099226, 0.19196613345827374, 0.07418303258184876, 0.24243274543966564, 0.16970820352435112, 0.13958503492176533, 0.12247449878071036, 0.20201002593551362, 0.0814864578257714, 0.11103316343256406, 0.1005324540393693, 0.13122745124357088, 0.09301358035632543, 0.10224745129900319, 0.0781800245333995, 0.11407958210578986, 0.08884435586099114, 0.18092801075960907, 0.12307863921991416, 0.10223717827882085, 0.1156109542186771, 0.18734459073415824, 0.18133321830204555, 0.1167659293860197, 0.08193380917821612, 0.14573661983013153, 0.1580484477537019, 0.16958424874714442, 0.1020285151898861, 0.10366535200072186, 0.09180331137031317, 0.12401423044502735, 0.16286713204213552, 0.12546867025750025, 0.18021694677216665, 0.07996332312801055, 0.14190715817468508, 0.14593220076390676, 0.1559944408280509, 0.16344274686915533, 0.10325017677886145, 0.08070365233080727, 0.15294627153447696, 0.1337598796401705, 0.09716562434498753, 0.06829666665622167, 0.15040211805275508, 0.11114591559661285, 0.08551303390413523, 0.13024151272007398, 0.09610133538288729, 0.09616411344281264, 0.18167439928012236, 0.10528278949537448, 0.11344016463096653, 0.15873367312763417, 0.1340348898832287, 0.15793460314827307, 0.12336932362190314, 0.10620409077299492, 0.12932291201182775, 0.19667893914239748, 0.16026949643024377, 0.1530371680855751, 0.08951296391231672, 0.11254280206880399, 0.16290442432676042, 0.1327593254723719, 0.13983118028513022, 0.17902629423354352, 0.1022838954148548, 0.20589938866240637, 0.13513833710125514, 0.1155633617724691, 0.10980323050171137, 0.08679244560854775, 0.1674819029867649, 0.05598374629127128, 0.11390401795506477, 0.05923562536814383, 0.10983746259340219, 0.1716428289988211, 0.12115848011204175, 0.1374757681041956, 0.0987690229501043, 0.15545371627168997, 0.143555753997394, 0.12025351795767035, 0.22275528418166296, 0.10883470997214317, 0.1384790228413684, 0.18985379966241972, 0.11164206718759877, 0.15572808869183064, 0.19030939521534102, 0.14659717865288258, 0.1437590295182807, 0.10365891948874507, 0.1718622807945524, 0.10591345386845724, 0.12878467089363507, 0.23057979717850685, 0.12020227499306202, 0.08841854799538851, 0.06494732280927044, 0.09386130129652363, 0.156360266198005, 0.12420446452285562, 0.13277471464659485, 0.14135367715997355, 0.08265546509729964, 0.14994114850248608, 0.15101711505225726, 0.08897431567311287, 0.20045392800654682, 0.1243482053812061, 0.13869652045624598, 0.06426939168678862, 0.13768228702247143, 0.07479273022285529, 0.18888356243925436, 0.15181815278317246, 0.07214856067938463, 0.15519622580281325], [0.02623588388918766, 0.007431957587998892, 0.09241138052727495, 0.009213913531441773, 0.034141544585249255, 0.035870092189205546, 0.04408875260768192, 0.032726873710219345, 0.028189057118392417, 0.009572004450352063, 0.023208815338356153, 0.016813056210854223, 0.054334441399467845, 0.027950041461735964, 0.03417221097541707, 0.11360030568071774, 0.030162605057869638, 0.062272951672119756, 0.06128179521432944, 0.038533728902361224, 0.021792746681187834, 0.013788515202967184, 0.03783216779785497, 0.06750316744936363, 0.030863548695508922, 0.029891784768551588, 0.04985903136964355, 0.017266478755378296, 0.09421663651508944, 0.04963355418294668, 0.03880183844427977, 0.10199494127716337, 0.048744666523167064, 0.037231006127383025, 0.024694686589230384, 0.012640655323463892, 0.02675074099430016, 0.01026900325502668, 0.08596540641571794, 0.046412392386368344, 0.030328703645084585, 0.04377261296446834, 0.022197433447997485, 0.03321708472711699, 0.013876832472825689, 0.03255549951323441, 0.03941381935562406, 0.05362410344449537, 0.05394888762384653, 0.09268941703651633, 0.060529442371002266, 0.0312016762660018, 0.029673679864832332, 0.02595902972721628, 0.013777774841790753, 0.025602050757567798, 0.03092372796631285, 0.05542081328374999, 0.05724299193492957, 0.03549235513699906, 0.0234692472565387, 0.021282503614202142, 0.04434293182566762, 0.030538262400243963, 0.04981235494571073, 0.03079575965447085, 0.0070954534125381285, 0.042480784069214544, 0.038190838016037426, 0.008335505845025182, 0.069272542505392, 0.01776774989307991, 0.042623432486185005, 0.038515021691897085, 0.03706766917769398, 0.022213513031601906, 0.08666213974356651, 0.05568913656419941, 0.06207385592694793, 0.037598761929465194, 0.046534107998013496, 0.034624610628400526, 0.04864877595433167, 0.023494351355891143, 0.015286308314119066, 0.047635926731995175, 0.061031157949141095, 0.016199813224375248, 0.0465600076796753, 0.06857265398970672, 0.037632810816700966, 0.050833159991140874, 0.010835300099902918, 0.059468661434948444, 0.037481541612318585, 0.05499208771756717, 0.03035566523405058, 0.006726791766206068, 0.008286756496610386, 0.015314106197495545, 0.025867485175175325, 0.03728235765759434, 0.024798220855050852, 0.015509882210088628, 0.07234727644494601, 0.014494805696553417, 0.03219742301319327, 0.049914569460919926, 0.038789784269673486, 0.028959576040506363, 0.011952076290201927, 0.07704968697258405, 0.04182542780680316, 0.028900037985295057, 0.0021401407970448156, 0.012662466831638344, 0.018131207175818936, 0.0681956395772951, 0.006352446540924055, 0.06696509596492563, 0.07687461136707238, 0.013208751134308321, 0.06610130053013563, 0.0412559028315757, 0.01172381456542228, 0.0455355656865452, 0.02609812092435147, 0.04668362658204777, 0.04817673949790852, 0.03227769709857447, 0.06766326100166355, 0.03266236538599644, 0.10367526539734431, 0.027957732656172345, 0.01896962370457394, 0.04530807325084295, 0.09654601330735854, 0.03408958915887134, 0.03778923688722508, 0.05331310031137296, 0.04944693669676781, 0.03826593827190144, 0.03993808604510767, 0.04686812025361827, 0.01954166604472058, 0.006923221292838986, 0.07245379965752363, 0.023297248807336603, 0.07565549428441695, 0.02216480439528823, 0.01960022192049239, 0.0369167494188462, 0.0247825840155461, 0.0636170616905604, 0.035310243123344014, 0.02811015537008643, 0.019603655307686756, 0.04529646351667387, 0.01970577652433089, 0.07422491176319973, 0.012983591162732669, 0.07186089575822864, 0.07687724408294473, 0.04589152855000325, 0.03849020766626511, 0.07004968223295041, 0.08325918484479189, 0.017906133717458163, 0.02116051658854953, 0.04044636305687683, 0.026983571804261634, 0.03350195747667125, 0.04566183766084058, 0.009203188437303262, 0.03933064792571323, 0.03157344221004418, 0.01066358493907111, 0.020590864388006072, 0.01808435602911881, 0.03924170894814389, 0.013712682977451809, 0.0653909422191126, 0.011259288643486798, 0.018759842729195952, 0.022931129970986928, 0.053035179153084755, 0.01110782181578023, 0.06873267290315457, 0.021961532267076627, 0.03724921461460846, 0.03017787548846432, 0.012255333097917693, 0.04406081732096417, 0.028730679037315503, 0.024749790418094823, 0.03774097269134862, 0.053168619849852154, 0.048399604324783595, 0.021324204680110728, 0.027455433537917476, 0.016412097993972044, 0.04578347524095859, 0.03496348798008902, 0.023493874685040543, 0.053608432678239684, 0.01125311736749219, 0.04714641460616674, 0.026186350832826326, 0.028553028391408067, 0.10963993426412344, 0.06466466547655207, 0.03057169382061277, 0.0752335608537708, 0.030427959747612476, 0.048312337936035225, 0.064391297288239, 0.0063112365647352165, 0.009155126953763621, 0.007980963664262422, 0.03848334428455148, 0.035420542383300405, 0.03511986994583692, 0.012952467609596039, 0.029835446005953208, 0.05682958090411765, 0.059624405577778816, 0.030681887907641273, 0.07038879367922034, 0.02747775903636856, 0.03255456992025886, 0.07533149381301232, 0.03459613251366785, 0.006766209985861289, 0.04018048928784473, 0.013774815580940672, 0.055686100119990964, 0.026800167181396058, 0.023499465813594203, 0.05545999528840184, 0.020419922757095525, 0.02927501339997564, 0.018156896511624967, 0.05611975524308426, 0.07123310837362494, 0.04321625156860266, 0.037693739868700504, 0.02727566077373922, 0.048615697372172556, 0.053117400633969476, 0.03224576524059687, 0.029875449037977626, 0.01269270574474441, 0.11809128469654492, 0.08367924551878657, 0.0715054791154606, 0.009434343265768672, 0.017510927781196575, 0.04828471477542605, 0.036926764595721445, 0.018004982698974863, 0.020295815309509635, 0.036379661810185225, 0.0459192670615656, 0.031628681745912345, 0.046784568844097, 0.08723614644259214, 0.03703292139938899, 0.021657048159145882, 0.03886955284646579, 0.0380546526451196, 0.0254044257370489, 0.04912776400202087, 0.09736710853342499, 0.04163594690284558, 0.02090089043070163, 0.05736509431153536, 0.03901367029175162, 0.008929157829178231, 0.07486716551440102, 0.038917192790125094, 0.09413019793906383, 0.036770090859915526, 0.07507528577532087, 0.02443523345781224, 0.012554569585647966, 0.0777617416211537, 0.02846363140270114, 0.04519113791840417, 0.020997021879468645, 0.05952864393059697, 0.015152370590450508, 0.023775619388158833, 0.03931863107053297, 0.06071833294949361, 0.007060368487145752, 0.052388491175536595, 0.03623267416177051, 0.0443717084958085, 0.03853778654177274, 0.05943468040121453, 0.021181936242750714, 0.01451679871284536, 0.03535815108833568, 0.019035853811406662, 0.037573632385049544, 0.034051502988274605, 0.049255888376917155, 0.02603897811578853, 0.07736509040530239, 0.04387808444776705, 0.05704551788845232, 0.12188643962144852, 0.06636873153703553, 0.024379405292815397, 0.001888682080399511, 0.02820572872380061, 0.030902520354304994, 0.010066882940009236, 0.06288839650473424, 0.03962901673678841, 0.014081219942974193, 0.011313928524032235, 0.03112836055723684, 0.04057716425242169, 0.012188197146835071, 0.13793227289404186, 0.01206434499804995, 0.009148344148083456, 0.049794984449233325, 0.04847060962181006, 0.013351469949286963, 0.07710427511483431, 0.052033763245812485, 0.060246371131922515, 0.01271048590673932, 0.012388180076543773, 0.023265079462102482, 0.04296550913048642, 0.03541071380355528, 0.04694448258461697, 0.037124469344105036, 0.01960771973244846, 0.016673595212133865, 0.009115724425230707, 0.04646170152617352, 0.06267940771899053, 0.017502001653026258, 0.019788608686732392, 0.02119236532598734, 0.030896793518747603, 0.043802756882671795, 0.01815143091204975, 0.08527351104255233, 0.12517957362745488, 0.19078416616788932, 0.15304069646767207, 0.08885675948113203, 0.23729968230639184, 0.11997656710445881, 0.09453004505485296, 0.07368688099086285, 0.10709143137293202, 0.0729561462732298, 0.1290601696819067, 0.11791782400437764, 0.12391055029417787, 0.12841507286897727, 0.24972338708383696, 0.15885105968586036, 0.07888084942741053, 0.0678003861435822, 0.0882890767284802, 0.1314065030642918, 0.13693454143192085, 0.22042030947549002, 0.1567324697971344, 0.11545444333127566, 0.19557342917791434, 0.1351395584642887, 0.14454638798321995, 0.15390284306236676, 0.10719623110656228, 0.12216659315994807, 0.18979373574256897, 0.12421234909977232, 0.14059407077729702, 0.13713659558977398, 0.0872523362881371, 0.11773250252008438, 0.09859952490244593, 0.13906858834837163, 0.16966610721179418, 0.0761776744787182, 0.11633580603769847, 0.08394382667860814, 0.12676305722977432, 0.11160200648009777, 0.15406658713306698, 0.15241533145308495, 0.12754737585783005, 0.15672732650169305, 0.13187773206404277, 0.10888342200113194, 0.15029275177844933, 0.10397484539342777, 0.11831597478262015, 0.224660474807024, 0.14977478528661387, 0.11394859770578997, 0.14468503982893058, 0.11630539409816265, 0.11682156925754887, 0.10765500220337085, 0.10775053993399654, 0.09504967395748411, 0.14505668702934468, 0.14016442240348884, 0.10884443337896041, 0.12711588186877115, 0.1848607047327927, 0.18324812554887362, 0.154418108984828, 0.12114788139505045, 0.0956566371023655, 0.1726360549884183, 0.11344722818051066, 0.06438968237489462, 0.11522435210645199, 0.1824887227267027, 0.16852711832949094, 0.15450135166091578, 0.1419305812035288, 0.11654727826161043, 0.09581567892538649, 0.05861399908150945, 0.0972415456282241, 0.12458851534341063, 0.17771928650992258, 0.07939138596079179, 0.09974324995917933, 0.16603241647992814, 0.17632062227598258, 0.11250582191028766, 0.10677230278296129, 0.055375090201518366, 0.09821717041943755, 0.14174888309623512, 0.10449616384825536, 0.2066060828843287, 0.08646060805767775, 0.11947394907474518, 0.0888246444186994, 0.12524723713951452, 0.08384699973144702, 0.10879447963088751, 0.1717234118176358, 0.23350905999541283, 0.09129549576235668, 0.12993515415915421, 0.09700416015194994, 0.11361068726650306, 0.15796376658337458, 0.04684372013434768, 0.1541295416120972, 0.246742311332907, 0.18813763532255376, 0.06936455185392074, 0.13106057234108448, 0.08844000327267817, 0.20771273278764316, 0.15822079564843858, 0.12190442079944269, 0.12105740553566388, 0.06407641632748501, 0.1508019244564431, 0.1304506372128214, 0.09759713190474681, 0.11242964956909418, 0.11817781148212296, 0.18077482469379902, 0.23175746255687305, 0.07346916624477931, 0.06572174839675426, 0.12694688593702658, 0.17733553424477577, 0.1549138059573514, 0.08820923351283584, 0.17572366073727608, 0.13690768501588277, 0.14163981537733758, 0.10842260172856705, 0.25841550209692543, 0.1272394023835659, 0.11250512980456863, 0.11091232313109295, 0.18404594702380045, 0.11024763022682496, 0.07974219535078321, 0.14822265000215598, 0.13751870580017567, 0.13646803503589972, 0.24284396480236733, 0.10119583058570113, 0.122440137767366, 0.078183898968356, 0.16549281829169818, 0.0969360555921282, 0.10879089018063885, 0.15184537560812064, 0.0989654656233532, 0.11580973783774035, 0.1746973900922707, 0.13672093860805035, 0.23099288929786, 0.11876417430383818, 0.1314556561410427, 0.11423920068357672, 0.10936125314661435, 0.13900134552802357, 0.07475724284137998, 0.06964936014264822, 0.08816149857427392, 0.13487647686685833, 0.12355582575712885, 0.19378721288272313, 0.05672893041212644, 0.18187616845326765, 0.09008691632854086], [0.03406211866864136, 0.05264581540333373, 0.049000626895576715, 0.049968031235039234, 0.04233378285009946, 0.060914795978793075, 0.048059129023126194, 0.05144158877166254, 0.0185497428423592, 0.012201816192828119, 0.020252884398879747, 0.036124078024710925, 0.05415485353608217, 0.06882255843707494, 0.03953889710828662, 0.06968785343425614, 0.026016472805557505, 0.014262531285307236, 0.031197415066084692, 0.006271561349941683, 0.02520681598356792, 0.029872276886765445, 0.02997648629492947, 0.0036762874639992204, 0.01868252027114587, 0.033810178616217205, 0.017867676048938717, 0.009625374622243856, 0.07533428937728916, 0.03482494469998138, 0.03694569233006664, 0.05931422007935388, 0.025654347147792578, 0.07923302267278944, 0.014950579364917107, 0.03423167099910123, 0.040984756845448694, 0.01813254558614322, 0.015167094800355179, 0.010097076052001544, 0.015567645896226168, 0.07880311645567417, 0.027754506329074502, 0.020263042068108916, 0.02988317415916494, 0.03325805467154298, 0.03935011509539826, 0.010529566639369088, 0.033221115225127766, 0.033295676045651944, 0.05577068290274058, 0.07930876075157098, 0.031843974121979306, 0.03641570898305092, 0.005489762207227094, 0.012695870262437632, 0.003836054471321404, 0.04050768905186227, 0.019656506400289278, 0.02963927135403667, 0.035171791445463896, 0.048014450884823284, 0.06084258628210851, 0.046055954548397234, 0.02022944949567318, 0.0523274433799088, 0.04553494482700314, 0.05624307898272361, 0.02028930137333061, 0.034586412499525716, 0.010132788198201783, 0.013759428103055273, 0.033426165115088224, 0.07075522973069123, 0.061058245067085536, 0.025139725833599056, 0.04267625643738678, 0.020915928463052427, 0.046305797927613766, 0.02756889646739832, 0.034578066518796344, 0.02777961891011468, 0.02821052087736981, 0.08163777792028018, 0.049102804091359885, 0.025291643038924252, 0.044019596318581274, 0.03703637853530901, 0.0622685072677476, 0.009804663930221327, 0.0396534677461854, 0.024932380798938017, 0.03553605279220002, 0.02012885667915855, 0.0428188268228301, 0.05539425881579518, 0.037125341261604, 0.019766196675066437, 0.02061272339363183, 0.027646673543910896, 0.005400567506772599, 0.01922100905462035, 0.05338313869599785, 0.03449092905170151, 0.01983089159641947, 0.02347753386545394, 0.047048077918589115, 0.06271354481577873, 0.01742464187555015, 0.059723743104508946, 0.014325551921501756, 0.040952170201178105, 0.028979976195842028, 0.016229846880638173, 0.014723814658022352, 0.0476172873750329, 0.0458372898532876, 0.03232803761160799, 0.10042464161025626, 0.02685198520443269, 0.025877547849501883, 0.051080553858940086, 0.04360682311068688, 0.02245625214917319, 0.008786508564039, 0.025281101997409548, 0.01698654404442225, 0.028074766376188824, 0.06057475493954761, 0.006268172491607922, 0.05503607035747596, 0.06196898833981582, 0.02840773368786488, 0.02827145332204444, 0.015732378931716084, 0.05156911942841751, 0.08238434964524848, 0.029725899919867516, 0.03127987742690103, 0.015303653365533267, 0.010619509000597256, 0.07413263778601374, 0.05774517570223127, 0.06017431749829224, 0.03436392765226109, 0.009846521059184201, 0.024156917052875673, 0.043564669122653346, 0.01848191478555756, 0.04276749564866934, 0.031859030814043114, 0.029039955298815454, 0.06397146053080048, 0.02064497416306819, 0.05059148956622396, 0.07874478958547115, 0.06309621142489569, 0.05210326898044773, 0.051931111075516255, 0.04130423488095403, 0.03339065059221216, 0.03775006166792341, 0.04790130177778857, 0.028635707883430377, 0.011521881695703735, 0.03564940885241542, 0.02542104136331805, 0.03493196324312261, 0.05439313467858093, 0.04836078533636672, 0.04086615570953914, 0.043240909531180344, 0.006622014084963926, 0.01929100333446903, 0.02419353080248194, 0.07831256277859211, 0.04693514933543546, 0.04517366224899888, 0.04145085272778358, 0.013807650738661843, 0.00580200705943363, 0.0431385694869927, 0.12308162477399621, 0.018151529299627458, 0.04447898148958172, 0.04815998986097319, 0.01876081133793507, 0.04470778689054506, 0.06650414677070719, 0.013593329515840327, 0.03392299184841769, 0.036708449346146414, 0.07062011983777795, 0.05405121409733381, 0.05301137614463057, 0.024531575252435038, 0.013702692397470986, 0.02152574315134968, 0.10541483241000346, 0.008763251776274825, 0.020860073156654835, 0.031098946064178432, 0.007592990911299629, 0.02154695924504527, 0.03667010872491768, 0.05978155428809779, 0.04321514216384717, 0.04638494564486401, 0.029358116976384605, 0.028078528852867227, 0.03434823652995484, 0.04020361715395536, 0.06220486746834857, 0.07042253722569772, 0.07681789941021375, 0.02234570692027254, 0.019821629593414918, 0.004479095747228712, 0.060536661983600686, 0.062409608624875546, 0.027477597884301628, 0.012499691369677228, 0.09460256009229592, 0.028732005573276962, 0.013057425950786896, 0.015201119938865304, 0.027909617737999985, 0.07280323840677738, 0.04698572733572551, 0.03118751524016261, 0.007488085156572717, 0.06420228457344429, 0.024019164266064763, 0.03395126300996967, 0.03482518218723791, 0.036244555309947045, 0.03292064634816987, 0.04091427741306169, 0.04733491163434727, 0.023812621599063277, 0.010712509010253208, 0.03190323058515787, 0.0234443959114807, 0.02531369712336787, 0.017694323922374418, 0.034543793715004406, 0.01840337605348655, 0.028791991461600577, 0.0474737568625382, 0.027459155302494764, 0.024530608340033462, 0.05323668709024787, 0.05150846518310053, 0.02871148328163794, 0.02706767282714801, 0.039030209582831175, 0.0307536158444626, 0.005104204190761915, 0.062290736074958525, 0.026887565884473066, 0.06843177654913493, 0.047170221007296016, 0.0757320805319718, 0.06623037824673311, 0.027667959187445895, 0.0654535438599331, 0.04435715391965849, 0.0228379162228001, 0.05169927940836974, 0.04079822078347206, 0.07529709208756685, 0.01445184594818524, 0.07086935932082788, 0.05454581184312701, 0.00716589976634298, 0.029936520582331077, 0.024150048582149402, 0.05874511918851307, 0.028047869248049598, 0.021574148143242513, 0.02634835785387882, 0.008757703056159829, 0.018146374129823277, 0.06905363353767566, 0.06254347679870469, 0.11186728653098856, 0.03988936044541853, 0.05095232091844082, 0.03433981930304851, 0.020076716351988058, 0.023192338811765825, 0.01862451570507671, 0.01968670799396932, 0.07178687437304429, 0.048496604298374484, 0.02543719728211207, 0.06613767679248538, 0.03201017788212214, 0.006327936159712928, 0.067190518868821, 0.038842723571828434, 0.022279347891786268, 0.03561593332727041, 0.048790033374513896, 0.06740597409329244, 0.03541418451017567, 0.046718262402074676, 0.04984360148331948, 0.01078936327914042, 0.024118148954585195, 0.05493690924985068, 0.06357949120657784, 0.08881332645458834, 0.021909066243097186, 0.03145414557574051, 0.02374409804386752, 0.011772450259221452, 0.019983999630702392, 0.036528858090085645, 0.05519783649859684, 0.02630564577079245, 0.03311952496213572, 0.048626693032149754, 0.04011579775916679, 0.014004633695419346, 0.015663819753431847, 0.05039208508761866, 0.05191056164247649, 0.012541188026911445, 0.02659961597860924, 0.07068032624998263, 0.0656789599784783, 0.030303499461816888, 0.10101321645613227, 0.03586578688451222, 0.04855460547176855, 0.03188569045492581, 0.0702915663963982, 0.03755093878135085, 0.03955120234084981, 0.027646826214290092, 0.03364570851304701, 0.018544719986883656, 0.028386899270117283, 0.07479521366102354, 0.025415348454511592, 0.019303174556366036, 0.017072114095624005, 0.029961215864334787, 0.028686204459518194, 0.05171727076438921, 0.058081939417336664, 0.10098013787397317, 0.1677448217357908, 0.1266803845231022, 0.11673794660185065, 0.0818333588540554, 0.12119326181709766, 0.11425621834184442, 0.2120829461408513, 0.13817906965102467, 0.12225601050470557, 0.09387488556759697, 0.1087831345253757, 0.17602427889193806, 0.19111746256904943, 0.12927606595414026, 0.12625159110341752, 0.19260525916303906, 0.1454370194779975, 0.1457765448306288, 0.137861216706889, 0.09751815721392632, 0.08262417106223957, 0.13723160406308516, 0.10766695799039942, 0.08850787713059358, 0.07544418490890946, 0.1377327564571585, 0.11285012414945023, 0.10913614236882754, 0.20675198148403848, 0.08761935587972403, 0.1428617483803204, 0.06791554032159702, 0.13320710430187838, 0.10253203567117453, 0.1109881562047771, 0.10239069004143987, 0.2243577531938042, 0.15444227840219224, 0.13832768239080906, 0.10008520446717739, 0.1934844369867018, 0.1957898682781628, 0.1251630445144006, 0.10714346143816199, 0.0994902921042272, 0.14165014268032142, 0.13037407132131712, 0.09047847174640213, 0.08177051294062819, 0.15351457175399574, 0.18894667976668902, 0.08547378065330641, 0.10195012403918163, 0.08412545693239995, 0.11384125346583979, 0.11145451332309417, 0.11840440146625042, 0.13151596433350018, 0.08591860107013158, 0.11743410996028356, 0.11642793752253056, 0.16488847429198877, 0.0784896332770586, 0.06892919021525554, 0.10747050174645015, 0.12931867795331137, 0.14509544494960988, 0.13409153398658546, 0.10095916435654674, 0.08694704981254679, 0.12361597110118185, 0.1127244323225958, 0.10744519917560474, 0.11694910669965403, 0.15132662201566355, 0.12354965108845915, 0.1288565413228103, 0.1304920549903597, 0.1490928711635726, 0.09125586253191743, 0.10725247487425804, 0.11954664731664316, 0.18530690936105593, 0.1529412910874401, 0.09909576470298426, 0.12805401081485407, 0.11480845085212163, 0.09742904520992722, 0.17590028340263025, 0.12976926591779503, 0.15711437644703047, 0.09268483013979026, 0.13914113731256553, 0.13872975510145935, 0.15604188399655478, 0.16242930053600244, 0.16352315326886518, 0.14450984208711556, 0.11536331607827119, 0.12088546476193837, 0.11756699425833565, 0.11404862733823912, 0.16540185388709816, 0.09590202929185969, 0.13273576673652443, 0.0998747500457934, 0.13943526867244924, 0.11184719510908638, 0.17561441659927368, 0.06620802730321884, 0.2160557143922363, 0.10241067968308926, 0.11510380357503891, 0.13307206226246698, 0.10894571830119405, 0.13987438939511776, 0.13383230646806105, 0.18649563486022608, 0.09524498347725187, 0.10389642710132257, 0.17132155623819145, 0.12025722275887217, 0.11477696682725634, 0.08109930610018116, 0.16724759127412522, 0.14595339819788933, 0.11733055194573742, 0.16657320888979094, 0.12767183275095054, 0.19244984750236782, 0.18372197369379656, 0.07280564042074339, 0.1208698313151087, 0.09130802151880094, 0.12624304156218255, 0.1601507528019803, 0.09953214414417744, 0.11614103934594563, 0.10429073737135955, 0.1031131534171956, 0.12819001637399197, 0.0757480396756104, 0.12262213443006788, 0.14048973923282965, 0.12457590816276413, 0.1281591701720442, 0.12829144378857954, 0.13504001737705298, 0.07971647887357644, 0.0906674980318972, 0.1394674719444343, 0.14375191847128527, 0.2480610848537513, 0.13003694798265183, 0.21277240557329996, 0.1902257182768413, 0.18705367563026293, 0.12102464586496353, 0.18173237331211567, 0.08704766298511199, 0.1469873362886054, 0.13636092149785586, 0.1293434037693909, 0.13949168207389967, 0.19436499902180263, 0.1081827599555254, 0.10391069669276476, 0.17672045582107135, 0.18653676765305655, 0.06886179133185319, 0.0726944895993386, 0.13928441676710332, 0.18674247232931002, 0.17872691101261548, 0.15173767852996076], [0.02079428409758423, 0.009117909307990755, 0.037299083545804024, 0.0757963852956891, 0.007803360515806291, 0.028004242839025598, 0.02455298642494849, 0.01859396805853716, 0.02190043018864734, 0.03609786960961563, 0.06231059679495437, 0.010490905410344047, 0.04900441990633096, 0.053156287475888214, 0.06881347963852541, 0.024549000031713928, 0.03961822124464171, 0.04954525642096996, 0.028631446683513265, 0.014544862921216657, 0.06007949901478631, 0.033286851697734425, 0.05686999444982835, 0.036731685777860026, 0.06545008333133799, 0.010176945560877877, 0.015828783490828106, 0.009130673399860305, 0.010591594918098832, 0.07025124784559011, 0.02028013945424131, 0.03160265653527208, 0.05059207310634, 0.05785353095935924, 0.018618975466649448, 0.0649847982983504, 0.02738932047837547, 0.063016537843006, 0.03156162552269442, 0.060792238983724795, 0.03350830517177071, 0.019803821441850493, 0.03694350066195641, 0.028557974911694015, 0.019528000349445, 0.01239014443542276, 0.035091646281736236, 0.015122070609192764, 0.0014939938451529347, 0.03786394020010318, 0.041922044408108504, 0.08236624633095094, 0.051843675053013225, 0.0333086530278836, 0.01878316737046199, 0.04605956096202135, 0.09387676510959864, 0.041728963875877004, 0.05252129744206156, 0.014088621911858874, 0.03246340874050345, 0.07789001866642918, 0.022255224275535772, 0.058964530272143226, 0.0387645224109292, 0.03621843171172908, 0.035010357786502154, 0.03057952072205288, 0.046652115415781736, 0.027107862456302558, 0.04676029086112976, 0.006919180616802935, 0.045645529071667364, 0.03460002051932471, 0.06004950776696205, 0.04809092178142496, 0.02345106251803892, 0.041816291332777054, 0.0690121886187366, 0.06312675907143525, 0.023421074662889754, 0.05092689621129206, 0.046254856911088736, 0.046670354437083006, 0.07925054923232112, 0.052908228643770726, 0.009329531657775598, 0.06996930297464132, 0.03022092514272247, 0.012755305689227368, 0.05513752491346427, 0.023770530375518968, 0.05229330967579569, 0.025561011263302395, 0.044209630228579044, 0.026879487925076058, 0.017181008788091794, 0.02817190036044589, 0.00907741773075291, 0.07446746767631598, 0.028404877055436373, 0.03804539742746523, 0.0870988652376192, 0.01862515352799424, 0.03667145222425461, 0.02841481759345957, 0.0011926545349914314, 0.010324358141848018, 0.039349606194134266, 0.0316443694755435, 0.04481960946161832, 0.023620160230036293, 0.04136446164920926, 0.06245338770427874, 0.015648327102618556, 0.010257716673160238, 0.026247485141669, 0.03475364424022181, 0.021093533307846104, 0.006446411766644035, 0.0886383390586291, 0.017192740658564225, 0.07973797486296721, 0.058015999384224415, 0.055739867234868665, 0.01923296823432403, 0.06433799157717399, 0.06997420878282615, 0.040924879522728067, 0.02036133804358542, 0.02799857367894479, 0.014467033258240138, 0.007887217266085957, 0.003607821160195661, 0.011187642979036485, 0.03761894156091979, 0.04287547092618687, 0.04099867020600608, 0.05740586748080594, 0.06836097820528916, 0.04682767617383173, 0.07503832597285509, 0.02564673568122089, 0.05658680107444525, 0.056415467589561424, 0.032270901570362706, 0.027648390237508074, 0.03080127275149737, 0.01282342551608703, 0.009234269582001227, 0.013276300143583544, 0.024408502570752586, 0.036702593588935475, 0.03214096550696662, 0.03791970220793571, 0.093128252774477, 0.07397546871964421, 0.011789468765657927, 0.015062841287414943, 0.007350765784004969, 0.0552801902938102, 0.0223468553407916, 0.04729496627779944, 0.017127643705212643, 0.030716058931180408, 0.0717444455783282, 0.04917459648900798, 0.04797086179522531, 0.04876798437908292, 0.009193674528173037, 0.03431296967236059, 0.007312516765003758, 0.007061941416135856, 0.039163450111768076, 0.032683362652148516, 0.04004358466980713, 0.023641902188371335, 0.01710553194529244, 0.043808225874922106, 0.03656465759766953, 0.05097258536677275, 0.034534647062953026, 0.03974874084815383, 0.009275761150222803, 0.07653331503804241, 0.04837602862556066, 0.07884515848542963, 0.014794494258239865, 0.014652400543647153, 0.010685627997320677, 0.057076187671295235, 0.03486643372369664, 0.02444813580119184, 0.039306132455489466, 0.027362613340041468, 0.04466966679319739, 0.006252572971529194, 0.03550681471824646, 0.059667465410062244, 0.07268311735242605, 0.05657882828797613, 0.07081482546137911, 0.029886560048907995, 0.033658458186047416, 0.03532424469345382, 0.01631879433989525, 0.05331050491492663, 0.02264049815546189, 0.0471901088686926, 0.06915552914142609, 0.028815994637885263, 0.02000023697369865, 0.038145942746528556, 0.047615306052778444, 0.022023433320490376, 0.023171864017578106, 0.028998914108212506, 0.04011340931590114, 0.039794731951717816, 0.03636021499655076, 0.01863349272337343, 0.007554608729801008, 0.03295474612553205, 0.0400096613115498, 0.019575560565239618, 0.03841021517291665, 0.004953462547356529, 0.03501608122938445, 0.0413072102570108, 0.019743981438555887, 0.07145599355655056, 0.03553473982693894, 0.01932185801810452, 0.03695301033024277, 0.008548861003613897, 0.02189153289821531, 0.021974461751856973, 0.009618803010588246, 0.03932713311431663, 0.03251917753368616, 0.06254298146814108, 0.07818955116506134, 0.0441347504965961, 0.025202361401170492, 0.0386836444293814, 0.015422810900158115, 0.013010862333300923, 0.022978712239169648, 0.0445237206960363, 0.020404564116948416, 0.022957150092614547, 0.0941083694675139, 0.02523041543151651, 0.05957883516592639, 0.04341697579781924, 0.12998508076582635, 0.006557460383711649, 0.047182675517563305, 0.058505949165139876, 0.010160682772818421, 0.021390672274199978, 0.013742547848128846, 0.006165678504787917, 0.09729303286543914, 0.027040914798687612, 0.03465937876275607, 0.017178705161703483, 0.06264854116099221, 0.01967516272062702, 0.004315479325928858, 0.02587889813418899, 0.018655119330755303, 0.022429020842537284, 0.0077558113262057304, 0.021926082205027342, 0.01449338416568935, 0.026858161569439938, 0.03810958005487919, 0.03604769194498658, 0.02866720887167113, 0.0690248975796359, 0.026357244966285567, 0.020900909090414643, 0.017369941775021807, 0.019920110469684005, 0.054866853901850324, 0.07940314497266497, 0.038248045303459675, 0.026607909372874668, 0.0604546203144959, 0.02008592407219112, 0.009246084573013442, 0.0437945228602205, 0.03782932812880192, 0.02452887637939836, 0.008862444266144718, 0.03174640417897275, 0.08861252080116953, 0.08404118288308382, 0.037143566712204895, 0.07113878522068262, 0.06253823172301054, 0.0295985422895423, 0.034992831226970465, 0.03655948716082743, 0.04086324479430914, 0.02219496527686715, 0.014349809548418437, 0.05403508871261563, 0.03772577689960599, 0.0066237447733458665, 0.0036587740510835177, 0.024913259682112505, 0.010510611763623143, 0.07059978414326906, 0.05360161679397736, 0.020110875501164367, 0.03504290032599654, 0.018351675077740635, 0.03812265881736364, 0.034249238270734034, 0.01740703049914113, 0.06838454372648682, 0.0568628392980567, 0.021137695759534836, 0.039836824871599674, 0.042126018820064406, 0.03383832085611565, 0.04535624584449189, 0.05781384344611849, 0.034070138952561786, 0.1011854015024645, 0.05611037449645145, 0.09397340885230474, 0.04297858789297087, 0.042652134517473836, 0.019038138778081963, 0.005264473738082285, 0.07097357551434211, 0.03752776002511382, 0.0015941467801375048, 0.04032896292795028, 0.03670146722080452, 0.01918492286599108, 0.0030017717051253256, 0.01425799188603248, 0.09190077614039183, 0.03792867583355733, 0.032093624118715525, 0.004472835413512907, 0.0472765067326171, 0.020240178830655556, 0.11853225103446416, 0.06893681016351495, 0.1725731005093881, 0.1100544852337667, 0.13693394432110445, 0.06704607911940132, 0.08297694820378508, 0.07798497964228902, 0.09771449810692243, 0.183001953044108, 0.1762321005974497, 0.10795842270765986, 0.19376510621181556, 0.0924854086978095, 0.1265655221151454, 0.13551143636660917, 0.1280827671289444, 0.17728806393487112, 0.21882765207971844, 0.07885183527001313, 0.07418869834925447, 0.1787417573588235, 0.21053011875067437, 0.12368469312787056, 0.17567790033561842, 0.130643721137728, 0.062097278955791674, 0.09854796981172902, 0.09280024894646235, 0.15845209466559546, 0.11073458766830818, 0.13674864997821196, 0.12715032430631773, 0.15956064446696214, 0.07834693057728664, 0.11272958918873753, 0.1469718385487795, 0.12386739546699183, 0.13284435948090895, 0.10987027654690401, 0.1062421090900898, 0.1287705437945468, 0.09946696407028607, 0.14176729853664125, 0.08050693824355092, 0.08352543520075933, 0.1203219685703516, 0.06539428061140434, 0.09441353380680084, 0.07566559088549443, 0.15610284358263016, 0.15476569533348083, 0.1576846715595041, 0.17429880505161627, 0.12965747048812254, 0.14719418090369019, 0.21101540699601173, 0.11525443834917885, 0.0856391057106001, 0.07990636689854519, 0.13147838706416742, 0.1360565306884902, 0.12360658017652375, 0.1296600896332945, 0.06786139322710888, 0.13388417368488653, 0.156355937144586, 0.1347273891525609, 0.2503369727305004, 0.12265270921800818, 0.14403127133846283, 0.09700397016214472, 0.10688866475330931, 0.1460917786295925, 0.12180041495178427, 0.127920000148671, 0.11201363296381064, 0.13218934248600686, 0.0913576427847147, 0.16044003942183085, 0.07713761154030051, 0.08926829775529248, 0.12159495454813753, 0.19494980121297495, 0.12199619944606509, 0.13285945009972366, 0.04724180305908833, 0.17612799975488866, 0.08926859631070069, 0.11783596553972789, 0.13128849225384848, 0.1518104039132595, 0.1989878173917532, 0.08085879257747106, 0.10827365650662354, 0.11392868948834282, 0.13631643674203328, 0.11452594958245754, 0.09459886886179447, 0.18536974170378276, 0.06319571858538048, 0.15926459963832582, 0.1770584883966616, 0.13557705070291245, 0.15824139597160475, 0.12200525110321385, 0.06662381320659604, 0.18462040834128857, 0.07979932799935341, 0.1229024101048708, 0.18914923604045594, 0.1638777828110116, 0.13107995130121708, 0.14946485763149603, 0.07632585295609065, 0.10824793324406658, 0.14346527813800744, 0.07784639565008027, 0.15235186128744058, 0.11507541366985866, 0.13733225794775145, 0.17383879902107374, 0.22614018326359137, 0.1592173736010279, 0.11204918819878783, 0.15100768341549806, 0.15012632070907525, 0.17271300085953303, 0.1017391946432846, 0.1518231060888086, 0.10226583959800856, 0.10135646696601595, 0.1336439587175846, 0.0977318278912987, 0.10512211240295853, 0.08673595078289509, 0.07050022269998278, 0.14214236555354937, 0.1069254209952695, 0.16631062940827437, 0.15248340208615574, 0.14562405087053776, 0.09298386052250862, 0.16022978856095246, 0.10741199845714228, 0.08807152483080115, 0.1591936791581767, 0.15201810348246778, 0.12737061748547213, 0.11340095887758903, 0.13989075565976755, 0.15485062077641487, 0.14892715934131825, 0.08930204808712006, 0.09425408486276865, 0.20878295893115656, 0.19365472213498183, 0.3407489684011255, 0.09781843610107899, 0.09885413838284356, 0.12717928418091365, 0.14224201520638807, 0.13350033999553748, 0.1212200503796339, 0.11624413595667907, 0.15167262059237274, 0.11256266278879982, 0.2045500267829214, 0.12525214973304952, 0.14035644781376633, 0.15158301325781004, 0.12350340214158807, 0.09966513022248234, 0.11805701867810317, 0.09506747193102326, 0.13566166401973792], [0.023151548679119775, 0.018789165620026842, 0.03139059737856899, 0.046791913985673866, 0.04993116303480097, 0.04201215725126011, 0.003979109161134277, 0.013612477774066585, 0.05640387481876782, 0.013588381299216832, 0.04171972222892301, 0.06037719268351793, 0.06896902022085019, 0.01251697280843343, 0.053701819452856264, 0.009478180868817227, 0.09546567020671708, 0.04679903521069458, 0.04382856835478118, 0.02175953408836254, 0.014108038191417498, 0.029705839032041173, 0.042539117724767754, 0.06761283227907759, 0.041438028415931125, 0.037884018051304987, 0.026152605590011393, 0.027428958797827363, 0.026284165048439587, 0.04511553893930145, 0.016493925924545953, 0.057223097288182805, 0.04073287446850112, 0.02070519923498588, 0.03701662298824106, 0.022200644614973238, 0.03993939561769366, 0.015369520456131016, 0.01320702426268586, 0.052523339832467694, 0.018485458434692452, 0.0408023700251111, 0.01923185882956854, 0.030754416515784602, 0.027409423774640475, 0.0253733997233212, 0.028367450760145272, 0.03245807884793196, 0.03035690016778452, 0.01400420961103269, 0.021193371254152486, 0.04278952428804977, 0.058590562481965335, 0.009619264414400926, 0.01763735242587115, 0.022902833364371742, 0.01445576618425548, 0.028163208326857005, 0.059355278233332295, 0.01841614268986242, 0.02583327004685998, 0.05667214381641575, 0.06217292882502079, 0.05323933676949569, 0.04353963118046522, 0.04494639712252787, 0.0654911007732153, 0.021408387127199342, 0.05476565379649401, 0.012180460999453706, 0.03210456210321613, 0.0498956552972751, 0.030704103144151822, 0.008268548857553728, 0.03600880510306784, 0.0515335302666894, 0.00888582827922489, 0.049030367085444074, 0.04374526121786662, 0.02171208243817091, 0.030755363072135618, 0.025755833934194276, 0.015117064717092683, 0.012912591802887619, 0.027786731653447663, 0.03558555192181042, 0.020614323039938296, 0.03264389227011374, 0.0312317489380283, 0.018374280471886908, 0.03719676046499184, 0.031016164791903326, 0.021065545434664403, 0.03425139940476843, 0.0094162060247202, 0.04538353652294193, 0.04853746906987258, 0.05914896287556205, 0.021402431286073158, 0.029981202113309076, 0.021746538446417878, 0.03598123283258506, 0.07770908051835639, 0.015591387836528676, 0.01763653309483613, 0.042698285076767206, 0.03560542281983154, 0.04374260814594371, 0.0609860217997006, 0.04434418372277703, 0.08376725829605546, 0.03381106749709163, 0.021592609384762387, 0.04065826954320073, 0.013101287302561104, 0.015120800052370344, 0.027984694245138338, 0.009093590612922395, 0.044207190895187, 0.015298494803053992, 0.015165624075702258, 0.0026461527741048485, 0.05838398928088801, 0.04408170941418835, 0.05299326943765793, 0.012436008313670754, 0.050377503370067904, 0.017122742986040454, 0.031937435535447936, 0.017053859807284813, 0.024335086778072373, 0.04318103560113481, 0.01839590199025614, 0.014674050899754678, 0.021929654691900526, 0.017137521478746618, 0.02236669061572424, 0.013092036325750607, 0.05161868641152978, 0.023214331828057766, 0.019508019189483354, 0.004557343133326087, 0.023453556134232452, 0.06267446798405477, 0.033188484476080964, 0.05679824276428137, 0.01466563028017325, 0.007160135611359562, 0.03371569261487041, 0.06536386867186852, 0.038706344818430286, 0.009352459356055727, 0.06861185295773403, 0.04835823743737169, 0.03490287783954825, 0.027599388134798834, 0.038032624005739174, 0.032044851021575074, 0.026771412563643286, 0.029446859178798537, 0.07393962171460901, 0.032915825356862376, 0.03519467503896781, 0.03811975468748382, 0.002841751731466502, 0.07583943834262234, 0.03448902236829911, 0.02894679583343012, 0.040442600580198426, 0.057749939018062184, 0.04979068592989019, 0.03044691801603351, 0.01718983143967177, 0.024056726268359592, 0.02827245755387204, 0.01865818800537714, 0.037769359203853776, 0.034101256568517, 0.03779499764953341, 0.042559775723410506, 0.028565143634166037, 0.004602107360759484, 0.017702111808050956, 0.024576984512220536, 0.021771018293553164, 0.02687249392537134, 0.013245078202869211, 0.023959364974871278, 0.054344843341303725, 0.028290564260844673, 0.05258514419464128, 0.03971182854313936, 0.019324159948155284, 0.02934379649481603, 0.030012709886900017, 0.06389315758964845, 0.03926713026261755, 0.030483202676155736, 0.012903892135779773, 0.030254488877419914, 0.03284666228241154, 0.008038961444981396, 0.018454043959666575, 0.04970718201782022, 0.06933631801179477, 0.010747202505756701, 0.046100144141486714, 0.039458368572273424, 0.0688954195273774, 0.02489265087725861, 0.02330983054291989, 0.02492828923277557, 0.029774591592805724, 0.009459278579535229, 0.024684198134179627, 0.02021424861491791, 0.003410048346268013, 0.06903929609273161, 0.034201089425810745, 0.007595733889112515, 0.018724423201222504, 0.01613313698076776, 0.028981489328933612, 0.021637396088668277, 0.03173010576782482, 0.003994908849043506, 0.0022333081079913037, 0.024892471065478664, 0.06078143670622792, 0.04925329637314592, 0.07742638925888709, 0.004743290566174048, 0.045278713040586026, 0.06481371247874838, 0.0337488831553076, 0.03900895108069692, 0.02981008236695613, 0.035352227477622886, 0.04825455050117203, 0.02567943767644465, 0.06944717027779136, 0.02262244912396584, 0.053479612804949284, 0.02472063885735614, 0.05107419937849045, 0.043691806229097505, 0.042438884531813006, 0.03311771327363593, 0.02519963199405798, 0.018907108576968312, 0.06113504844584635, 0.02755481856209891, 0.013487116733033742, 0.08470571972429752, 0.026406209749568785, 0.023817481606134346, 0.03350441377343876, 0.01968992085728262, 0.036704391706734896, 0.050937834195792675, 0.036445289717188904, 0.03006650075050337, 0.03286649925368173, 0.008311359328217804, 0.0515687224854316, 0.04341521839212094, 0.03546857926994562, 0.044473258046699424, 0.0009723361228160293, 0.04100366083106824, 0.038109909144363234, 0.022148127700867395, 0.028853687258171182, 0.06008240993001631, 0.03809506958350539, 0.051539989920066934, 0.03285323728674224, 0.015825626606653844, 0.05549924175388046, 0.02038482722959348, 0.08205361810645886, 0.02027944565218474, 0.024924621750999774, 0.04902976318927748, 0.0141074851853773, 0.0584208948005523, 0.04254508204758167, 0.0398360072369022, 0.013346201973035932, 0.028240971832669208, 0.026702057803049684, 0.06406589224934578, 0.031025715172290802, 0.03665211397622313, 0.049941168033650944, 0.020096704297299896, 0.09814071309353624, 0.026274943757536154, 0.032550441034670384, 0.041641096983637126, 0.05267832740875227, 0.046662137378007174, 0.04978281831634896, 0.029379528148898056, 0.03259688336402178, 0.006744718237314373, 0.02873003782172288, 0.03531987153525863, 0.028494793123432567, 0.08994320261159114, 0.022090635428737317, 0.05764245907110827, 0.021101358512948667, 0.03970031380387289, 0.03189580062670367, 0.026248513122222254, 0.058925507723220756, 0.011891590830470835, 0.03888447383152587, 0.08014922136706965, 0.02793919338312532, 0.01835261654507901, 0.024883946969306896, 0.05763688151325498, 0.02981540547417743, 0.02898458344861865, 0.027806239535233805, 0.011368483587700342, 0.04053450136312416, 0.02360109000333718, 0.04903762062479343, 0.0062993079191073775, 0.022496036353654096, 0.004592101937825126, 0.0491038015378373, 0.021453275611358028, 0.009447422876421894, 0.0599448573110359, 0.025312614860013127, 0.0777703725865909, 0.05744470003992319, 0.016478998154135685, 0.01455535476894251, 0.03659417387098074, 0.09728264449430363, 0.024495071764769297, 0.030912118232143775, 0.024245274186666523, 0.03585514745541981, 0.025064890206392323, 0.05434337431298835, 0.011099720955826342, 0.10002029580729348, 0.1405818842883621, 0.08914726067866598, 0.19494627283087798, 0.12808322853275708, 0.07701885434133665, 0.0534787035680243, 0.089708219149283, 0.13380593859723636, 0.1698121279478073, 0.12172868022961275, 0.13473979277270182, 0.27081852512700216, 0.06279615645429917, 0.13058673776686192, 0.09151400439441204, 0.16737508800412926, 0.11677655524441174, 0.11042421896542821, 0.12818566017917224, 0.08325256912836007, 0.09420071129820176, 0.08085261790880136, 0.18263061796980246, 0.1482529669467892, 0.08051915865923677, 0.10607055508132492, 0.11918154119380883, 0.2643712753696101, 0.09700188027428729, 0.10590145736932755, 0.07968322387231247, 0.13699467320527348, 0.0960136754438281, 0.07629516281719718, 0.10790745115705899, 0.10719170527798788, 0.17187370732426643, 0.09401947459472076, 0.09366045493100371, 0.09501035963850361, 0.09373045938887767, 0.07829842210880347, 0.1036046366872532, 0.0939605709697519, 0.133222045642989, 0.07013087573328189, 0.09554208682051726, 0.15788842205490383, 0.10775560859058585, 0.07689662304307733, 0.10630473108696085, 0.15759137299443993, 0.14132287167012691, 0.1584057371531214, 0.10808108826833111, 0.11254722611712557, 0.13062035239168576, 0.13648330207381928, 0.12047926655837468, 0.06470414264393703, 0.21462445333600044, 0.16220583181296075, 0.20050753227302007, 0.12049304081925324, 0.10918714106082916, 0.16098222961383207, 0.09338838274457625, 0.1272145001483815, 0.12400960283620016, 0.12539628414171083, 0.14729931311947958, 0.08854173602802412, 0.11472841086132185, 0.19207646325230598, 0.12407285587063857, 0.07859914882906846, 0.18199519706623896, 0.06923077188964401, 0.2238755047853504, 0.09344995301216841, 0.09067805603678737, 0.1836709885724953, 0.18080708224858555, 0.1922360004058906, 0.0914590498432517, 0.0954823282414249, 0.10433938833219664, 0.12312403321266174, 0.10713664216122457, 0.10134458581783942, 0.1084642434226615, 0.12619505556566374, 0.10784000477620534, 0.08343725957508598, 0.08232180907257966, 0.13286956027150154, 0.1545987350067922, 0.1140298590596233, 0.14052682795694896, 0.12048351418759141, 0.06307270697184972, 0.17451322211750916, 0.09124052085514579, 0.20542754898113863, 0.08610747129257236, 0.08723391406238079, 0.11410790415746824, 0.08184677349137408, 0.09101868740149907, 0.19094662102205412, 0.16340145122792038, 0.16594253773135798, 0.10892490084682192, 0.11519658645348889, 0.12118220169629369, 0.08837571886501142, 0.1464028869356428, 0.14736530743539333, 0.08130928554705211, 0.12272293759243828, 0.14750128585313046, 0.08079625879015241, 0.11959270627370902, 0.1758577935397625, 0.09695085444088493, 0.12686889512198313, 0.1671583910605737, 0.08427151159516402, 0.09755830613097974, 0.1642438117414713, 0.13450449039893492, 0.11220538696008069, 0.19996665843895503, 0.16343967989087105, 0.1907432505062648, 0.100804607649999, 0.07308474222996406, 0.13843392740402902, 0.09825945672179971, 0.13179439439305238, 0.0681917719276888, 0.08543551127825465, 0.13330558687448502, 0.11759180149861745, 0.11161715816706419, 0.15510987543634006, 0.1265682905380215, 0.11286122498235532, 0.21264708015535558, 0.12507385787154945, 0.09795291495642491, 0.11420314333268575, 0.11764236592820712, 0.18878661335578986, 0.07564659869032246, 0.0707109078232731, 0.06293744101588215, 0.1072209229958909, 0.10842630652976887, 0.13173564683113778, 0.1069056416994759, 0.10283281667424099, 0.1272232396794217, 0.07780756309096303, 0.12592630141547748, 0.08752957891140666, 0.1887478825769254, 0.1881063412874937, 0.16914469376206398, 0.21483032086065837, 0.1243143193423748, 0.12512272596359253, 0.12940190705869878, 0.1714676855398076, 0.05337789701297879], [0.03851528971322945, 0.017917241335713437, 0.02134680498524436, 0.0025704390801755445, 0.080922174533563, 0.027462347809757506, 0.032394700284515104, 0.05956002617520945, 0.034360575689268966, 0.03126260192532625, 0.01423052478847759, 0.07895835848259074, 0.01482220393206392, 0.06398481409996748, 0.047273840089993815, 0.018623453797772527, 0.020369709469377995, 0.031493039203009436, 0.07483876882387058, 0.04953807073512247, 0.09202770968633038, 0.014074712792145354, 0.0507446892027344, 0.06033174440796886, 0.04135983743305717, 0.07347015012055635, 0.044108514940100055, 0.07573191089821713, 0.02730923129378685, 0.021143451432830522, 0.031697135751268694, 0.023708525845514875, 0.020035239202635627, 0.02755382450829659, 0.03573046664574316, 0.028935067355632782, 0.05030898490388479, 0.07594648402716432, 0.07111447331096445, 0.03754210764808314, 0.041121776814439466, 0.0279012751499457, 0.05098450383437531, 0.03287046868354082, 0.05082378942253334, 0.01893705063100372, 0.05586669560787933, 0.029520185065588782, 0.02235712157562375, 0.04242692535210933, 0.018288544179605584, 0.03877959945904357, 0.056726039852947, 0.017111623493422354, 0.04507384296240551, 0.04140670723947031, 0.02519839027497385, 0.08537397493741342, 0.031629170291125774, 0.05697470597390618, 0.034454936161637306, 0.013800798383142267, 0.013019940283681666, 0.040298191364854574, 0.043518464280558486, 0.02929204802161881, 0.06754280746515308, 0.05000583581360323, 0.08005868443953139, 0.02409109745972923, 0.057331113277801445, 0.016267290139304738, 0.005675842378488076, 0.04004278739116021, 0.0591541604538049, 0.015022904412554843, 0.011639284369136606, 0.031095139482723813, 0.01407180102874658, 0.05342748435214162, 0.05314765311777592, 0.06625807604619435, 0.050623753906360695, 0.058235512248107364, 0.01847039326094091, 0.0329255521563547, 0.01314125640783459, 0.01934868050739169, 0.04798378788733056, 0.035771908172007115, 0.043186755651342015, 0.06455958754356418, 0.040701957020376406, 0.039070093871227334, 0.02224038471467793, 0.02543766377493739, 0.04829595810068505, 0.07212574833205768, 0.06421114624078784, 0.09914501955998795, 0.03935217784185495, 0.02245058129275484, 0.07297725549765996, 0.029928588507963077, 0.020251408585214188, 0.02905249801863517, 0.053312822112015316, 0.06483963251646076, 0.03168903404314603, 0.06512438652238675, 0.017321472322302203, 0.02598887848268662, 0.028324396016874483, 0.0409850554008569, 0.054765908247126, 0.02793210438851799, 0.026914902364036868, 0.02831297118349799, 0.05852699053606816, 0.04210529975326998, 0.08257918419050318, 0.014180152045030679, 0.0464079954794475, 0.030518662916230302, 0.04718296050227114, 0.03850588182519589, 0.06334958997155939, 0.08063038411949362, 0.0030974230903666466, 0.034138813481799195, 0.0457579657169325, 0.06904139955128942, 0.038696821579443555, 0.0256130430248699, 0.028312988146873455, 0.00739661100253995, 0.01972889930142888, 0.05212053769667234, 0.055609795464468856, 0.055351551821721454, 0.07876872830092907, 0.007836803810537925, 0.008388864142554147, 0.01513070666364261, 0.020639683286260282, 0.02359027924415256, 0.014883994723537138, 0.04225267077397023, 0.01710298574263496, 0.03194226331210562, 0.029467205051332712, 0.039575480323817046, 0.04583258760560836, 0.015128574367346508, 0.041009458912802596, 0.02136643839600895, 0.026863796802769815, 0.030517136212438345, 0.031260518822818995, 0.02296542313082942, 0.010904721017660839, 0.04744935335059251, 0.04239253380468913, 0.016008128777944615, 0.03889604963894401, 0.0605450351057308, 0.01715576389272298, 0.007436709877635751, 0.006278460354743791, 0.03481084813496896, 0.03983466373756528, 0.005643926211632788, 0.033956148462103944, 0.029928931168147495, 0.025505707266607454, 0.038973039614834955, 0.04372939367645553, 0.023234594580052153, 0.056347227322735956, 0.04507095918857625, 0.04862783636365618, 0.03883066939722214, 0.021646408730053475, 0.036013626094375334, 0.02361454874543207, 0.05117590159976056, 0.016451833004664098, 0.07204222067126206, 0.013722129881248941, 0.0923045723299895, 0.035348241084388325, 0.06793470893587385, 0.015618091582187583, 0.021407282811456492, 0.050863673710929494, 0.029029753524810076, 0.043940652161836624, 0.04728858804862414, 0.021820373234472105, 0.02729583701251873, 0.017157392376767736, 0.009031620009669235, 0.03493596659973264, 0.009776363930931049, 0.031960705893912485, 0.015058249301676239, 0.03601273721350091, 0.0301205053526376, 0.022500197469655956, 0.01770748071638601, 0.01627673873943942, 0.012171564557190453, 0.05531083293525236, 0.03767309544075813, 0.03108539232718093, 0.040138077456504107, 0.019605149781065326, 0.02238308741444988, 0.037999609884406836, 0.02039952090542231, 0.017943076556548476, 0.022191725272153105, 0.015749642558928047, 0.04799026789675866, 0.047364312556705306, 0.05728757847100496, 0.047949202957430055, 0.03421344215582524, 0.03981438571853297, 0.03767701398049082, 0.036185407412371466, 0.013177593654420759, 0.025598386668467095, 0.03854612573715193, 0.0608286356021251, 0.018951937689312866, 0.03562554816848465, 0.061854030936956406, 0.004373931725110326, 0.017268960497209003, 0.044458048684256415, 0.02192654530517757, 0.11294402661068098, 0.015878124861046672, 0.012180014014510172, 0.039940053796661754, 0.078310812158244, 0.03287880787892001, 0.0499717122875154, 0.05795453768223524, 0.029391103956316198, 0.04448520026302763, 0.05572443056319441, 0.03560376040903585, 0.021220590686425567, 0.06541988852300815, 0.016149852690952163, 0.08674273613308157, 0.04757723345288208, 0.1101071938340153, 0.048870514413075786, 0.010751874219360096, 0.014992327928276998, 0.020391748286783695, 0.045662685829613886, 0.018626181508547494, 0.008401459448837807, 0.06558002957275935, 0.0376378659025899, 0.024384757237774984, 0.06757531607789652, 0.052684749742703776, 0.043481809818851094, 0.010301698464900255, 0.04330437969682472, 0.04302412098539727, 0.01751045280668352, 0.03586523387847202, 0.046210127882659435, 0.025277397196207727, 0.06151962173836572, 0.07521809025534562, 0.059782897787434716, 0.025360349798575044, 0.04299578197034342, 0.054024120194039175, 0.03143344007964645, 0.008671399338969162, 0.05029184850198882, 0.07706553076526948, 0.036790932063013315, 0.013680893611828131, 0.049626633125756464, 0.008212848766041654, 0.03987128087984664, 0.006538444863898414, 0.0038402066815511455, 0.016145822192941393, 0.015126598134104694, 0.020504744723439217, 0.07871200277337007, 0.061030805110931396, 0.061458024329372814, 0.0380777974746057, 0.02968424804774778, 0.048434586197670014, 0.05682657838666013, 0.020432516367041638, 0.04063905003879752, 0.01979366546895887, 0.07280536222138576, 0.08656265972448246, 0.025515546024377857, 0.028109946720568196, 0.02787849842570722, 0.02221594049063112, 0.03830280986481479, 0.04056307447275945, 0.042540481580155234, 0.036306949997586865, 0.02510438094447766, 0.02033537220475929, 0.03005538634689791, 0.06736380314188344, 0.03210605488025716, 0.025505717444632734, 0.025304664125932113, 0.04181975864672235, 0.05167908959888986, 0.057268762694937844, 0.04470444171290312, 0.05151320814288088, 0.04226872151983636, 0.023638502727927904, 0.02961407056344407, 0.0277440636751375, 0.026355445152148604, 0.04820873581671289, 0.016894158108958175, 0.05890984034964016, 0.021042480333042995, 0.027412712973143374, 0.027999450685456395, 0.030036193983895437, 0.031910551978009086, 0.022620360932445953, 0.0621559043814029, 0.0427901078281658, 0.052086872181722095, 0.03819161833130887, 0.032587858848273754, 0.054337060544639826, 0.11664265314383165, 0.13336486369371414, 0.18136740289628506, 0.09384910123688833, 0.15991665822054657, 0.1397233067878655, 0.06972855196467467, 0.17302967315273626, 0.11121955700218678, 0.15343336468296392, 0.06648974825761148, 0.1695901927139078, 0.08777506609580346, 0.215546704562647, 0.12502006361527102, 0.10222382470965385, 0.058870315684803894, 0.16637335318539823, 0.18338993936777115, 0.14753941952117852, 0.1592936273664236, 0.12626639673752443, 0.23443835441555294, 0.13642312958836555, 0.13363656268588134, 0.1421055889555386, 0.07880707910018307, 0.11031842857067074, 0.16327034469161714, 0.0946495079302362, 0.08076286808188472, 0.1397470419428178, 0.14457058454198496, 0.1742224291499172, 0.10087309218943119, 0.08706323536378996, 0.10792525591594831, 0.1840967150138957, 0.16284619245146, 0.16422200362597192, 0.07749256677925587, 0.1424299965479544, 0.1095162509009242, 0.14150489547422954, 0.10921713230865342, 0.08691077533044986, 0.1721427600298609, 0.07353800362242119, 0.12145022302865982, 0.09799956423895699, 0.11791786471647875, 0.14077373327953474, 0.09334857988038234, 0.22991163017494337, 0.10901366001261131, 0.12071585814867701, 0.1524385373507227, 0.15227460329021725, 0.15624053190861428, 0.24554339423775673, 0.10119648876466922, 0.21293612250259944, 0.12176369263657502, 0.1204154978373221, 0.13834039813705853, 0.08486436121165752, 0.20317412061350687, 0.09012341472719397, 0.09769917678620134, 0.10503393677728516, 0.132929067792637, 0.07953888590314559, 0.11482554993459157, 0.17621148670358316, 0.09780103846320085, 0.13254318492753164, 0.11328433227858373, 0.14068713864045485, 0.19661096350422927, 0.21663337839501245, 0.18248431224908146, 0.1257529900010143, 0.16546297632157803, 0.22075013177735464, 0.09816000384411641, 0.10732293395059449, 0.07015467195638589, 0.14777757174202374, 0.17130417217101368, 0.09963050458048071, 0.10449592636099883, 0.08250866404601506, 0.09820866837565388, 0.14792600806270326, 0.11084993862147842, 0.41442983757172314, 0.14774535489933832, 0.17935940064489841, 0.11436957440205983, 0.2384406253695488, 0.1408174309347357, 0.11468392610549927, 0.16870318459612982, 0.05869348945894411, 0.1538003978452512, 0.14519470105213778, 0.2315476866705077, 0.12852553837001324, 0.09826199444276945, 0.16079658243272985, 0.0626350925969226, 0.132291299157909, 0.18286307049649103, 0.1065541198477149, 0.10157178648348365, 0.1760924445199115, 0.14919264295271464, 0.09215834803347077, 0.18300377151795796, 0.1349329309804099, 0.22352063097059727, 0.06905304321220943, 0.10632522284452404, 0.08901023731700011, 0.12714210046189173, 0.09690787603280374, 0.21377547032066754, 0.17241937161556312, 0.11648483946919441, 0.11934029124677181, 0.20235687946634634, 0.13837074222309248, 0.17467662692070007, 0.11711175154362406, 0.10653537871049983, 0.13090095376329763, 0.09079527296125889, 0.11473457195929118, 0.11459077681813921, 0.12073892833931105, 0.17409623520714895, 0.19794120426688874, 0.14429345726966858, 0.10231894853391818, 0.109646977457617, 0.16711879175688538, 0.1068139241210052, 0.11786434187420777, 0.06425576670361416, 0.08638047307197537, 0.2003683511699949, 0.11024112307599612, 0.1603611936526639, 0.14218527610812867, 0.16269288424934658, 0.11584441097719328, 0.10929301287978888, 0.08810378238558769, 0.12916043001626218, 0.08113881719431706, 0.13012560536818846, 0.1778735446610621, 0.091669952097748, 0.1059755737494145, 0.1418092862835952, 0.09192432130553893, 0.20452458171972207, 0.11082467676273414, 0.11004233945693288, 0.2489010297826358, 0.07993481787187712, 0.10652296830500875, 0.12070394307374954, 0.18154946741248879, 0.09758679781641279, 0.15514557994902134], [0.02622261344056044, 0.024202419611226236, 0.035157572744148116, 0.0548530592849212, 0.02095645566337875, 0.10423450717436415, 0.015412213879504373, 0.03927756952387946, 0.015145871921309402, 0.05061562844951238, 0.07342658138700894, 0.025137189808966856, 0.03718397007989032, 0.020795174674796205, 0.019415777442710738, 0.042705484333315065, 0.06870580291641609, 0.015377082728913851, 0.024700306555522338, 0.03556616956900273, 0.08351900947413274, 0.03095703385770321, 0.007073851826135069, 0.018624212060655867, 0.02501506537997297, 0.05367519034604941, 0.007402957849470633, 0.10262144623058182, 0.028585472543324743, 0.0341056263340371, 0.03117596996682031, 0.01943099359050393, 0.04458999999665788, 0.0446579654568008, 0.016453112043174248, 0.016225794330239296, 0.050406313966959715, 0.008102652982675602, 0.01595211910483028, 0.05786940189344542, 0.09710693785122462, 0.035543696489185095, 0.03561080699520452, 0.05251650019947972, 0.05149332367415939, 0.08854565117508173, 0.014536454175998057, 0.03604744427970477, 0.03901297479335751, 0.020070672301309447, 0.02952560316771269, 0.02604682876595429, 0.022625293882031525, 0.004700568305062396, 0.030031322102461542, 0.02008796306992216, 0.03422464137630803, 0.021745992225727866, 0.032732522514249594, 0.019823624486369745, 0.015574453298800757, 0.018137624420757805, 0.02859080582857132, 0.037928818325911245, 0.015770512599764124, 0.03685417491942644, 0.023878510742049133, 0.04007728750418339, 0.05831283809883254, 0.014182425985511924, 0.08536730493818011, 0.015164129602323686, 0.013823049242741295, 0.022689834436667815, 0.02595495682076684, 0.0210158206921603, 0.009925188712908753, 0.04629600327461958, 0.03128995027925287, 0.04688481900042721, 0.024861570580729415, 0.019737601513043046, 0.027388764079660177, 0.05837497833584036, 0.02078783801490707, 0.018566031075481857, 0.05348209963579263, 0.019642701605334878, 0.01673784399671214, 0.04815195600635239, 0.021804985756586705, 0.011050497481067265, 0.06076059889580522, 0.036982570708330186, 0.03553468893681254, 0.0817274327522942, 0.08916297554969788, 0.01767832406663469, 0.10649626116667475, 0.01994371331030769, 0.04095073849228876, 0.0369385846757463, 0.044391019602439234, 0.014559683822361487, 0.03407385732446398, 0.09347456347729478, 0.025847305543720722, 0.012844546614880008, 0.024680145583780747, 0.006378920432845396, 0.007493115645567221, 0.03414980914177639, 0.022888753762734786, 0.03593187280265348, 0.019867620696978908, 0.02980887457462294, 0.06122948694974184, 0.03406064624765089, 0.022387316383953606, 0.023844823174710785, 0.07858665021402494, 0.03149281867912837, 0.0495869082930897, 0.016287390042894652, 0.05623372537749154, 0.01566410813081477, 0.015377338875883391, 0.04661199703280415, 0.022903057280927896, 0.022346125915646553, 0.03129340062982269, 0.02457085734100214, 0.02759026692781065, 0.06196532425071512, 0.05794678881232228, 0.040096561291388104, 0.039635734233473024, 0.044390928000211716, 0.017537867317774465, 0.023237490228244236, 0.03940373293257185, 0.04531781701371074, 0.026160946481728127, 0.07739918000463929, 0.03173003791432295, 0.05516661370971373, 0.045096594241580794, 0.00880369755239891, 0.027628315778981363, 0.03226177188168679, 0.04877690711457815, 0.034547461196780205, 0.047288255566465, 0.019785137980112007, 0.010912695500467504, 0.022396459643329893, 0.03027208668312856, 0.05693066905119589, 0.004340314131695777, 0.05596156498151166, 0.027747486884306585, 0.020247308537364006, 0.022420576474230205, 0.026743580753515874, 0.09468992826129709, 0.028120625165424178, 0.04321865358256868, 0.06822533226971116, 0.016508293903565834, 0.03241373658446329, 0.008988968994734543, 0.012740782495321972, 0.02096084239227431, 0.029164422369961227, 0.01093209651298821, 0.040101239790341685, 0.05289119741480265, 0.04407175191278968, 0.07258185278624296, 0.05571157232459102, 0.011150204809382558, 0.025632951242317046, 0.015123487051044191, 0.03249909628980926, 0.0237851731612214, 0.02534793091139623, 0.03063934376197202, 0.034883414062538316, 0.03116103880373495, 0.051466507970222404, 0.027392784399645667, 0.010870450758375227, 0.05930014726306711, 0.02901275282991784, 0.03876589983701706, 0.029570322018116713, 0.02730471733957529, 0.0123862470999094, 0.024312494954626476, 0.024320572914023484, 0.01728260753277157, 0.021288691853572215, 0.05420253419184259, 0.07624239993414708, 0.0032862169776178363, 0.04531132682625737, 0.05966162322355168, 0.0040284170286862975, 0.03580745662163411, 0.03793936954545123, 0.010225267432230924, 0.06261299271136522, 0.06902525720319577, 0.049322082860661406, 0.029890946777803556, 0.07977325868393693, 0.041172341244029145, 0.02893285872414708, 0.03192081482016614, 0.10261374485812016, 0.023775061293105994, 0.055928024995539866, 0.03524915800829019, 0.026977364905178547, 0.05899980052241257, 0.028081587349463786, 0.05350905783208353, 0.027060758555307984, 0.009836738280552839, 0.04171516925894788, 0.02750622358040086, 0.024017685059724108, 0.04469897272065282, 0.002891011253398444, 0.019945782842114568, 0.0433175907736378, 0.01962356691780899, 0.028202595588352, 0.006485442373169852, 0.05831326557589429, 0.04202786872961691, 0.006684431249076235, 0.055252383928745985, 0.03600521904549428, 0.031180068318332945, 0.010918848116749098, 0.07419547012874059, 0.012988044048792549, 0.04880855059517281, 0.0038883165107108653, 0.02228269137309066, 0.04728567034804395, 0.036435617200498066, 0.016664255177602172, 0.015366180367501718, 0.03319288816835199, 0.044428230462861915, 0.019526115718430707, 0.06243915882493768, 0.04268358800826328, 0.009972033074258693, 0.04005219867186887, 0.01842019354392375, 0.04559321062905448, 0.039608389272221496, 0.021845497689875107, 0.03472777848531093, 0.04713984299451113, 0.09597881909992013, 0.07283131618584905, 0.11386197592530932, 0.007330217199133975, 0.02639793331867882, 0.02078482023041163, 0.077598927143429, 0.11521967021482331, 0.04861227755567857, 0.04248738960762109, 0.02752039987327797, 0.03995313934449639, 0.018878806881340485, 0.04562519337715847, 0.03263395173209054, 0.04967967760083931, 0.02637630162228431, 0.013961778271810284, 0.00960028070091669, 0.04330097005835601, 0.01406395886026855, 0.05034609737672976, 0.011322223614635212, 0.03533163054713181, 0.006458343804946968, 0.03489658781992538, 0.025922483831111873, 0.018658009889934744, 0.0574863620900682, 0.04837072587438992, 0.019040725692840557, 0.07241434284618922, 0.06571995027895484, 0.03835700784942933, 0.016777438211387823, 0.03486456775239535, 0.058740023390523026, 0.03312622210276978, 0.06641230027058295, 0.03479800346706595, 0.02363587001205555, 0.09119115743253912, 0.036965451269809685, 0.049971715680190494, 0.05376216835741486, 0.03171042485960892, 0.020211459835991263, 0.0494048675256116, 0.010810387686693242, 0.017478436131828597, 0.03128016580428396, 0.010293686662667563, 0.01656170648389629, 0.0607580001066838, 0.045905234957379956, 0.007234667594145451, 0.014585362980142236, 0.06350249105266162, 0.0719573087990284, 0.054878120975834985, 0.07605787912117583, 0.015271952209462012, 0.022997862193733454, 0.011832923844589718, 0.01018367153925023, 0.08133781115923609, 0.024120629000078355, 0.0766490324001227, 0.04254159777026091, 0.035400861475084505, 0.013857484894937702, 0.022323732563693608, 0.033204087388834784, 0.03721026670453804, 0.14533784479967185, 0.044735352375677655, 0.04179771304396646, 0.021784341328644326, 0.09679321040000234, 0.02256059047899076, 0.026836253370025327, 0.08020853889839989, 0.009001799243768411, 0.048204881737806966, 0.16805632359215192, 0.18973521888256073, 0.18515045275645597, 0.15333348432821886, 0.047869325815034766, 0.13301051913627557, 0.06078218988009861, 0.08758435704346214, 0.0508692444834326, 0.11873513300504003, 0.12203704725418772, 0.13602478882031782, 0.10306530991303069, 0.12107211617486817, 0.07606191640453679, 0.1187001070273774, 0.11078123695084027, 0.2085944211908749, 0.10759150489632573, 0.1330377555319241, 0.18141750592206204, 0.070554627637778, 0.06483575808150427, 0.1229696800666196, 0.0942425090553505, 0.11142091905432087, 0.10013207088091544, 0.24367728722946985, 0.08684301682348762, 0.1016623776938234, 0.10253350130681481, 0.07231625382389341, 0.1612526122480631, 0.11442252727491514, 0.09406325367412396, 0.14079322080527032, 0.18488800898194313, 0.1247077068047864, 0.20874524595482008, 0.183425263900842, 0.09362671138452631, 0.14242893803332532, 0.13364382301058086, 0.18508398346602917, 0.17906414291688375, 0.17913521267473698, 0.10956401298088686, 0.08287113066762686, 0.14302813873759337, 0.10399638209491968, 0.0744972350075841, 0.10607009367751223, 0.0941717785650066, 0.07166274317673274, 0.11148544773459435, 0.09230824998979058, 0.11212409846484661, 0.09746147239846842, 0.09302181777145181, 0.17315221657710417, 0.10799102631530591, 0.09695279505103827, 0.12925519421696663, 0.09613934691463198, 0.1446402429469994, 0.14013718600784028, 0.0693613016711814, 0.1421904872570719, 0.3577991692083222, 0.13291810266673565, 0.17040461115539074, 0.08957913464733533, 0.10481525851147515, 0.07705991249531507, 0.06436756891863686, 0.1178027716066156, 0.09636904458914484, 0.11011096648871899, 0.12382343996848379, 0.09773199073970318, 0.12115230544337205, 0.1828754741166319, 0.15409854613244534, 0.10209486234400954, 0.13341612022902283, 0.10329336553279843, 0.11770806168871266, 0.10328031730438982, 0.09051275812089443, 0.103446497315807, 0.10140015105051653, 0.0928527879129563, 0.1836736077176673, 0.14939315005072526, 0.2238419580140284, 0.10810371741120305, 0.16782606951892376, 0.10779367440513202, 0.18250607965247972, 0.14133433891194208, 0.21262011517371449, 0.21212242330823625, 0.10926676714526755, 0.11440607958606311, 0.1343362137143101, 0.19289449150008814, 0.11551859203193869, 0.14226310407476767, 0.21062269806861877, 0.10823630993919713, 0.09637565352022648, 0.1377610649381365, 0.06563764398119279, 0.19476908019610814, 0.09185976548386471, 0.18285604087369783, 0.10995927998530013, 0.12338868901133537, 0.12327930916632925, 0.08595279923507146, 0.16491299654756272, 0.1924599983862468, 0.10420239889728171, 0.15974825939961843, 0.21540327583040508, 0.09510316965835434, 0.11663162016442843, 0.10338021122983523, 0.13523333200386592, 0.08848678147686379, 0.11718978307076863, 0.1441440845706633, 0.07127567966069494, 0.23035145657403128, 0.13561746424862317, 0.143972333786743, 0.09163067170551845, 0.17036695246185574, 0.09976127863462482, 0.12672439430441174, 0.14160088103796753, 0.07559300120919943, 0.0926139232303415, 0.1698534914425441, 0.12752573059073516, 0.11979682317801885, 0.17598206044307776, 0.06841187511703797, 0.10229043649243456, 0.1470483908695834, 0.07673023268580437, 0.14250227409814084, 0.11842779735369341, 0.08406447699027401, 0.0598555485318814, 0.08432189960564886, 0.11487364449671336, 0.15517684684268065, 0.1045600479202611, 0.1131415752960103, 0.13297858727829798, 0.11903081142476626, 0.12744079157710075, 0.125767497079713, 0.213021794334054, 0.13912986006055558, 0.3433586412242481, 0.2388843058475426, 0.12431013956665993, 0.09353943142507758, 0.212158290669322, 0.1544871838497264, 0.10494557794715677, 0.1532112258885588, 0.11722958593496255, 0.1139206692044224], [0.05317381064274481, 0.025636218388431838, 0.014078632180046822, 0.03470956660541041, 0.023957765328564813, 0.017776796461216042, 0.1010059222046818, 0.0032399858422909994, 0.0463485049216875, 0.0657941277271935, 0.07042369073522942, 0.05152849214417594, 0.09068085838641439, 0.069293427813266, 0.0174389504827559, 0.017816456833056042, 0.06475856793778283, 0.044997931857194216, 0.043914124835282564, 0.08283896132239274, 0.06804776644068104, 0.051576342433691025, 0.06976594602955238, 0.03720354920785342, 0.04617578722536564, 0.039109211415052414, 0.032008861524185965, 0.02617164358629712, 0.04104941105470061, 0.036791417215551646, 0.014854420774749346, 0.01225147392999913, 0.06231635755726269, 0.02378963283263147, 0.023499530274420977, 0.020523375598713756, 0.013097002353918339, 0.0899722371250391, 0.010493266712208944, 0.027016017652515854, 0.020211032358929515, 0.0470569192298821, 0.021589700165869932, 0.06245032072599445, 0.024998490465804935, 0.029060840606689453, 0.004930873692501336, 0.018307156395167112, 0.01627609582750925, 0.02690779131704143, 0.02366080108497824, 0.008950750509809171, 0.037206314238054414, 0.011112874357162841, 0.03254705175225224, 0.03348263619201524, 0.09861563332378864, 0.028480598170842444, 0.023166081202881675, 0.061105125051523955, 0.03376271848433784, 0.036428811494261026, 0.03981531531150852, 0.06251564329223973, 0.047596395281808715, 0.0022450221669194953, 0.023802803197343434, 0.03550851784114327, 0.03057559539697, 0.06375431575413261, 0.018922986296404685, 0.0612985346732395, 0.016518309080441083, 0.02503123486946736, 0.06632077946726765, 0.019089042475180965, 0.045446501179997406, 0.04088460507669619, 0.04198327201551624, 0.015458394972873586, 0.021598885833684887, 0.006164507607796362, 0.0341557293598141, 0.022775072005710432, 0.023305973071338873, 0.034628573272909434, 0.03355340400178518, 0.04840323787980846, 0.06750274675765208, 0.08190009955848966, 0.009242487489245832, 0.06544326405440058, 0.011307818316189306, 0.025617344936888133, 0.016645247715392282, 0.06704415886529855, 0.021942843716325502, 0.011943826152543937, 0.060699713948581896, 0.014422048082841294, 0.04501380279128041, 0.03361139160447887, 0.05623383055041943, 0.034832754638046026, 0.006380918718475316, 0.05006745357864669, 0.04571043773155127, 0.03627509617113641, 0.04256640161786761, 0.05569914495572448, 0.04770059451194746, 0.041071846815092225, 0.04390281704919679, 0.08784966423575367, 0.04625790353332247, 0.006541932533894266, 0.050010531275932274, 0.05061983197395291, 0.048645033833703825, 0.028386392065190842, 0.015268115093931556, 0.08600796413208757, 0.021844052410285388, 0.034208068158477545, 0.017512764914759567, 0.02376101222554488, 0.04704238500978265, 0.005131601314393005, 0.015383611932130796, 0.013048750880573477, 0.06418126355856657, 0.008446951829163092, 0.018099672260827253, 0.026883179155577506, 0.02551538996132357, 0.03036759387967842, 0.03330662760085293, 0.02009957280409123, 0.02468110401449459, 0.03229355785463538, 0.10909783906702485, 0.03656804009473749, 0.018475288891100457, 0.016271814271541576, 0.025408895586484244, 0.01612913701683283, 0.009898135521715241, 0.01734782662242651, 0.0321685920602509, 0.036591340987277884, 0.012130479261811291, 0.042555657015847306, 0.026601023938772932, 0.032805593950407844, 0.005483858104396079, 0.04692007228732109, 0.023654131085744927, 0.06932493897953204, 0.04024838689448578, 0.0488108677922615, 0.04034992966002651, 0.01969251625372895, 0.027782497594931295, 0.0397256604794945, 0.04928171681240201, 0.0478080099980746, 0.01788362840722714, 0.047342721572411914, 0.11712486084018435, 0.03448630144287433, 0.015822157596371005, 0.050606749818793366, 0.04341636850897755, 0.028089373538802778, 0.02769237627009196, 0.05300178165946688, 0.03372685790860227, 0.014843621889927557, 0.020582470909825394, 0.07328520183052335, 0.032655617355235984, 0.07085112029952662, 0.02205020152697606, 0.014739093570304769, 0.042730905647788725, 0.039056492636778524, 0.06432499084621668, 0.005989524028596601, 0.056877950272922, 0.002907187528243022, 0.005196706749432321, 0.038786785144891055, 0.10956414868789059, 0.0386181318733309, 0.040005752949842384, 0.04652000804032598, 0.012353995482304266, 0.06093270251793521, 0.0827516745775938, 0.012827653637421983, 0.01177475303744099, 0.04938131896778941, 0.010991738892958632, 0.026719200990295837, 0.020248931932396123, 0.06055876865450825, 0.056856237152325254, 0.049481894820928574, 0.07088066371423857, 0.02796113381295332, 0.04601836031568902, 0.03796824799584491, 0.013721702404187193, 0.05725013690867594, 0.03418879437127283, 0.028263896138274243, 0.04997764268357839, 0.01723995482149933, 0.04109512735158205, 0.022199231565796902, 0.059843151697090695, 0.05025501422850149, 0.019276606517710855, 0.028093751786010604, 0.024312031854476248, 0.020054221219782318, 0.02240110930454518, 0.04416046358112778, 0.05705814542514937, 0.029688729771545956, 0.029184147382953336, 0.03474328640316214, 0.04088798418108906, 0.014905712933146527, 0.05576974991708994, 0.10384755222392933, 0.018868262447150688, 0.02509384329563805, 0.030669860874435732, 0.023420821908595305, 0.047978685303990326, 0.012096352343048369, 0.024089531740173697, 0.103281525096723, 0.03982563582914216, 0.016151060483285358, 0.01606562783542488, 0.06484396835522992, 0.036425720767251084, 0.013450683643376189, 0.022995512766231383, 0.025766103561701517, 0.04538487323692866, 0.019243984250351787, 0.052080904466233084, 0.02876877538593752, 0.03378573439217039, 0.04162620992532798, 0.06428010575473309, 0.034642235575509925, 0.028686669256005968, 0.03330723149701953, 0.08679794852754899, 0.10297467120523963, 0.05773525552025863, 0.05880193292562451, 0.04499189628820334, 0.10167672870946781, 0.015840359298246245, 0.06398419663310051, 0.03970747234831963, 0.031769423479480405, 0.08452446945011616, 0.028419423149898648, 0.05070049621696983, 0.0025602328532841057, 0.043651433395487924, 0.05969175696372986, 0.013205282124025481, 0.026413334367264594, 0.051911657476531606, 0.012622367956542542, 0.03910863805296166, 0.06110262804265533, 0.014730143693408795, 0.002020887631390776, 0.03365283991609301, 0.002167226430693907, 0.0240891280118376, 0.047863836466733894, 0.044626043776848486, 0.042684609203466346, 0.06255678965577058, 0.04372630973479577, 0.022974937888128415, 0.008031585769328688, 0.005742674261065466, 0.05757475484694753, 0.009404942343410636, 0.04149189731106162, 0.011168975632504692, 0.0680237463010209, 0.06256502028554678, 0.03772337149296488, 0.028725698590278625, 0.012864771199279597, 0.10627578478306532, 0.015609119652903505, 0.028217767631368976, 0.022334227804094553, 0.025615584138514738, 0.03813894705048629, 0.019173335184210112, 0.03887737635523081, 0.04301631444000772, 0.026571256607504826, 0.08071184224848237, 0.03819212723257286, 0.04760160982342703, 0.016140994416283708, 0.030580212827771902, 0.06042585042970521, 0.03691356708960874, 0.03365934028157166, 0.036677708317126544, 0.1300666406750679, 0.013252491197947944, 0.03684880092207875, 0.02901145682803222, 0.020486532843538692, 0.008278695500588842, 0.02596033251445208, 0.01036374455517424, 0.03834249059270535, 0.09421330490814787, 0.04235249345323869, 0.05952982458152941, 0.01564390814330961, 0.009842476142304284, 0.04130677260192377, 0.028989567288330624, 0.040619379308606894, 0.05693932037268366, 0.041576704010367393, 0.08486047999135085, 0.05811879065419946, 0.05199608080355184, 0.03224036410184843, 0.04452534918008106, 0.04602109820448926, 0.020516943086736968, 0.052184974774718285, 0.12557528167963028, 0.1000338393662657, 0.07152407776032176, 0.13958914684397833, 0.17906965262123517, 0.14463712168591364, 0.16631490417889186, 0.08244568242558412, 0.09455835353583097, 0.1287410818040371, 0.12409855877714497, 0.1353529848690544, 0.15185582504740783, 0.15978864580392838, 0.10227017543677773, 0.09458558993147952, 0.26440403504031046, 0.13023117184638977, 0.06712775437959603, 0.1374736646456378, 0.1890607957861253, 0.12437785736152104, 0.13426164271576063, 0.09353021691952433, 0.09795328136533499, 0.1519597087587629, 0.07838838906692606, 0.08893668412097863, 0.08932420225547892, 0.16169271006115846, 0.21071983714188847, 0.1859039794653654, 0.1166448380265917, 0.08775578891592366, 0.12162571932588305, 0.1837692947259971, 0.08859802050782101, 0.16818648017942905, 0.10684869225536074, 0.10502968914806843, 0.10543511382171086, 0.1536328268370458, 0.1522281372121402, 0.13157796886350426, 0.11939164277698312, 0.09288144923214402, 0.07623910903930664, 0.0748813401109406, 0.06964680206562791, 0.0678567656182817, 0.13190034085086413, 0.11855815750147615, 0.13722180601741585, 0.10207215177693538, 0.0964198736473918, 0.10739211738109589, 0.1666514439774411, 0.12753448369247572, 0.17492298941527093, 0.2486166421856199, 0.1257529900010143, 0.10595995387328522, 0.09877985915435211, 0.1219271110104663, 0.15906896442174911, 0.14234375474708422, 0.1508562343993357, 0.19406543938176973, 0.1331452897616795, 0.12088104071361677, 0.13423843681812286, 0.14552399409668787, 0.09137887414544821, 0.09954081582171576, 0.16044891465987476, 0.08945981426430599, 0.11039126930492264, 0.11267282973442759, 0.13941660895943642, 0.14665579050779343, 0.11758285840707165, 0.13314222278339521, 0.09179762524685689, 0.10484350592430149, 0.09313976751374346, 0.12492983202849116, 0.19561393771852764, 0.12907960292484078, 0.11813454808933394, 0.26785270284329143, 0.17711283905165537, 0.17645238020590373, 0.052558359024780135, 0.1280290000140667, 0.06976825983396598, 0.09740043138819081, 0.10990076991064207, 0.08627885566758257, 0.15912883835179464, 0.1013758187847478, 0.13544290432972567, 0.08405811911714928, 0.20729651940720423, 0.08605376524584633, 0.0936371133263622, 0.0473319837557418, 0.131049566503082, 0.09569294551121336, 0.1509179946567331, 0.15162217829908642, 0.12549191686723912, 0.11059768644294568, 0.11998392242406096, 0.15137824495988234, 0.14329659433237144, 0.10601446059133325, 0.23576920585972921, 0.10627322670604501, 0.09061864351055451, 0.10270820371806622, 0.07974960495318685, 0.19261561360742363, 0.05437835957854986, 0.0668003408770476, 0.06028987201196807, 0.13621502289814608, 0.1150264912950141, 0.08056981808372907, 0.08288197365722486, 0.14421622641384602, 0.1278002251471792, 0.11356535434190716, 0.10476703502769981, 0.05206512513437441, 0.09982025689844574, 0.10359838059438126, 0.12029577711863176, 0.12561378175658838, 0.0987229368516377, 0.1897166134523494, 0.13343292075608457, 0.10347302803503615, 0.07961160450109414, 0.10172309300729207, 0.09774589392223529, 0.13336445657270296, 0.1693170823689018, 0.21257337768162998, 0.10667293811483042, 0.2409902885556221, 0.10153722869498388, 0.12313233848129, 0.10527066407459122, 0.08242502781961646, 0.0927043923043779, 0.09971097883369241, 0.1566118262708187, 0.12241516767867974, 0.17254400492778846, 0.08613785609070744, 0.2006683043603386, 0.10169348852442843, 0.08122233128441231, 0.08430359273084573, 0.0919542039877602, 0.16472201608121395, 0.15465067007711955, 0.12971620447933674, 0.24152676548276628, 0.17383608488099916, 0.17657485577676976, 0.10402522661856242, 0.13418070705873625, 0.1975485496222973, 0.07708090636879206, 0.26127457725150244], [0.019688713064949428, 0.011710568713689489, 0.03716589390699353, 0.015117585492719497, 0.05663279557068433, 0.04990316667993154, 0.05037569168156811, 0.029332665127835104, 0.01152383502838867, 0.03882553967248116, 0.032375643628516367, 0.03406015430976238, 0.02742698765359819, 0.049066624604165554, 0.017791351037366048, 0.09605910336332661, 0.0576808505824634, 0.06774494304720845, 0.02745616974841271, 0.009782887196966579, 0.029287868245903934, 0.009054120230887617, 0.02123288404462593, 0.052862149330654314, 0.07391244638711214, 0.047387264003711085, 0.029228421792920147, 0.07663763301180941, 0.054823176602699926, 0.03649523667991161, 0.007980792334170213, 0.05062030694846596, 0.07375369633414916, 0.02724696722413812, 0.018406239471265247, 0.043004728454564295, 0.03987178299576044, 0.021170623367652297, 0.06408774107694626, 0.025192906015685627, 0.026370038744062185, 0.0151080452903573, 0.016989093639754822, 0.06437707519424812, 0.014141686742992272, 0.03649068031726139, 0.03970947402662464, 0.02509327502255993, 0.11138818652502128, 0.028538897899644713, 0.08110801848982062, 0.024704030016437173, 0.015081858927650111, 0.016607122529031973, 0.025140384012567144, 0.03849042479747108, 0.08450729572879416, 0.049394044892064164, 0.020626216062477658, 0.04811505727203829, 0.021729176431628208, 0.06672175295118775, 0.01782256704089897, 0.047318813391029835, 0.058464958864663324, 0.03905672673135996, 0.04002725233190826, 0.0511925019589918, 0.07315345068595239, 0.017394815172467912, 0.05733075365424156, 0.0432386737582939, 0.0032964662490745206, 0.022281895790781294, 0.0634079711245639, 0.03662306249939969, 0.011369316489435732, 0.05136080239234226, 0.05220971416149821, 0.04702522485916104, 0.012230392695138497, 0.04932658154783504, 0.0286447323991784, 0.0956151650420257, 0.019259102010567273, 0.09756407367863826, 0.010980945945318257, 0.01333063468337059, 0.07031961703406912, 0.009604380748766874, 0.016725381004757116, 0.029821064456232955, 0.026490651736302034, 0.025367988406547477, 0.030999544076621532, 0.06621283133115087, 0.013749831073385264, 0.021544742131871835, 0.016906027382771884, 0.009703386641506637, 0.10644681631986584, 0.03535801538133195, 0.013273951564250248, 0.02853035514375993, 0.04512764400403414, 0.02528097477209355, 0.027332060604489276, 0.028711408642785888, 0.023401532854352678, 0.06269114637481314, 0.021688323534492935, 0.014385400406484092, 0.023420698075954403, 0.05219063375677381, 0.036433727480471134, 0.03718825163585799, 0.0206632691635085, 0.04925642441958189, 0.05466478956597192, 0.012156936190357166, 0.023978402971157005, 0.01062783716978239, 0.0529839497591768, 0.04178308043628931, 0.06155003367790154, 0.014651772898754903, 0.022110597928985953, 0.031954029109328985, 0.03917107345270259, 0.040184414612927606, 0.05101504808823977, 0.10892428337995495, 0.03938777378893324, 0.02569227046998484, 0.02722457387218518, 0.05193656988974128, 0.05711967498064041, 0.014171207257147347, 0.017066992852570753, 0.02508709696121514, 0.04174989328852721, 0.0767574215840016, 0.027534618574593748, 0.037447886275393624, 0.06495092583021947, 0.021535695563735704, 0.05164873533483062, 0.029347626824996302, 0.030601186345198324, 0.05419704484354172, 0.054767611370022805, 0.056752187199890614, 0.0220503304486296, 0.023365261764930825, 0.01899528080996658, 0.023518295160361698, 0.022454150386952927, 0.030781523989779607, 0.02522443075265203, 0.048969536421022246, 0.0336573114618659, 0.05303842255047389, 0.024122294803549136, 0.08570317298706089, 0.02966656203248671, 0.04845439263486436, 0.027062734788549796, 0.014406078761177403, 0.009686044134598757, 0.015086047185052718, 0.0541914842490639, 0.021095044744600142, 0.0435344234241971, 0.015118579546521817, 0.009490452174629484, 0.015697149393547858, 0.019013044856754795, 0.030768502902771746, 0.06491714835699115, 0.09050997612731797, 0.028383508291361586, 0.044078940991312265, 0.01773505637954388, 0.023328412224405577, 0.05125211126038006, 0.025105821135054742, 0.020196301363674656, 0.009097686419928712, 0.0125659231728475, 0.023042436855446016, 0.03605547813432557, 0.04173809356455292, 0.11046228477997438, 0.0334726651199162, 0.019361881406179497, 0.023400745753731047, 0.029941416212490628, 0.023874437835599695, 0.021854417032695243, 0.04516740615612694, 0.02514705740447555, 0.030910045307661806, 0.04904743563383818, 0.043062573564904075, 0.07420115625219685, 0.053866374372903786, 0.01695686831538166, 0.04324159145887409, 0.012677189345205469, 0.02448843399594937, 0.04820624559319445, 0.043988970640514574, 0.054274872810180695, 0.027927374999438013, 0.0199622084785785, 0.015635190664657524, 0.045942028518766165, 0.04461220844781824, 0.03434709319844842, 0.03493671638092824, 0.03201745856287224, 0.0055187890871561, 0.09096135119242327, 0.034918697883508036, 0.010330108726131064, 0.035709520269717486, 0.0863166975655726, 0.02171842674059527, 0.012254133787272232, 0.03213767121945109, 0.033872566518506834, 0.12683582332517418, 0.09355138042675597, 0.04085668336067881, 0.04148811787100775, 0.016114811446251612, 0.03182822532419648, 0.016564910865521858, 0.021741374794925963, 0.012062182167678006, 0.07208129750298602, 0.022815858745681386, 0.05279546290902155, 0.033267588088555, 0.03176753715212856, 0.03767887316644192, 0.03791575991947736, 0.04526142057563577, 0.006215595357519175, 0.044518404374165196, 0.02341974643059075, 0.02532517284687076, 0.05639830743893981, 0.061574684855129035, 0.08623459482831614, 0.036791658095483265, 0.012749030088473643, 0.04067016765475273, 0.057195704829479964, 0.1226346737572125, 0.058603807485529354, 0.007630428232784782, 0.012678559985943139, 0.033770250223044834, 0.007891057774291506, 0.06922996443297182, 0.02294635460046785, 0.00640990785489391, 0.02797350859535592, 0.028283799266708747, 0.03424105513840914, 0.06352934746869973, 0.03665842774457165, 0.017423138920483843, 0.0639697370518531, 0.059137726335653236, 0.03145995044282504, 0.03845458118511098, 0.04754651277991278, 0.08024610938238246, 0.004100778971665672, 0.05092785973101854, 0.05878320535910981, 0.05583405468080725, 0.025587486003392508, 0.05283307071243014, 0.041768417294536314, 0.01407152198122016, 0.028018950085554804, 0.0636017064430884, 0.04336818912997842, 0.032745017736618004, 0.04420348270131009, 0.051181947346776724, 0.024926599680579135, 0.09727912289755684, 0.019548115520072833, 0.03036380765427436, 0.017466232679518204, 0.03010503136153732, 0.04558009115446891, 0.06495127866842917, 0.07246609471206154, 0.04726864929710116, 0.04240832670724817, 0.020763748325407505, 0.022637989272230437, 0.046135278684752326, 0.0813685284395303, 0.050619526633194516, 0.05477101422314133, 0.05135644959019763, 0.04292539074750883, 0.004696859687101096, 0.035613717910434516, 0.051045555022678206, 0.015519790517698442, 0.06460652859615428, 0.04330814217350312, 0.01584318370026137, 0.07038122122841221, 0.046310866584203074, 0.043309048017753024, 0.030627822237355367, 0.11954759726566927, 0.06572541248585496, 0.02612704687219645, 0.01808475636477981, 0.045254580942647796, 0.09540831364159073, 0.04034513241744467, 0.004699179852780486, 0.04034111888280936, 0.032061352993228605, 0.03356405021622777, 0.007311271653244538, 0.048144865315407515, 0.020715463773480484, 0.03802445444411465, 0.03229571898866977, 0.050540389093969545, 0.018990507316110388, 0.03985645828236427, 0.026223878908370222, 0.036776940670928786, 0.014562971324526837, 0.013408281990060849, 0.005832869800672467, 0.08000085968524218, 0.027060656775055186, 0.05930500557380063, 0.016980060642319064, 0.1509608644992113, 0.1259302097771849, 0.12644782343081065, 0.1361371949315071, 0.14054007296051296, 0.22958259497370037, 0.13729858904012612, 0.14708948295031274, 0.15512111197624887, 0.06521220930985042, 0.08722244003521544, 0.08594365936837026, 0.07823442268584456, 0.11684907706720488, 0.11407979923699584, 0.21240831725299358, 0.1655888445675373, 0.15195999374347074, 0.11089111891176019, 0.09158166112112147, 0.07582508732697793, 0.1347891494099583, 0.125517891187753, 0.15895127930811473, 0.1339534113981894, 0.11814203911593982, 0.1517459430864879, 0.21161376631685666, 0.10889164584555797, 0.12964479545397417, 0.11970299535564013, 0.10429119198982205, 0.11482966185680457, 0.1094765430316329, 0.0687058504138674, 0.10336879148547139, 0.23153208036507877, 0.061608659103512764, 0.13620435632765293, 0.13309404679707118, 0.2926534834717001, 0.10909021233341523, 0.12026370955365044, 0.1473427800727742, 0.1376815406339509, 0.09236753359436989, 0.18583347967692784, 0.13254659117332526, 0.2537463397852012, 0.1442292407155037, 0.1450266550694193, 0.06836170423775911, 0.07296863810292312, 0.12773390513445648, 0.1025120731709259, 0.230034200740712, 0.13213941587933473, 0.11598824683044638, 0.13441842501716955, 0.08477518135415656, 0.12987233538712772, 0.1849523883845125, 0.08299302269837686, 0.08432772143610887, 0.23280278646520206, 0.06882286377783332, 0.09892742695020777, 0.20518771399344715, 0.11610327208680765, 0.06481897112514291, 0.1661448904446193, 0.07429558797074215, 0.08398736827075481, 0.07823100286935057, 0.18271585553884506, 0.12775268698377268, 0.09688456835491316, 0.12048826393272195, 0.155954420832651, 0.10292889044753142, 0.07601061237177678, 0.13072981366089412, 0.20507401866572245, 0.18020123190113477, 0.1283931154757738, 0.20861488580703735, 0.1119007450927581, 0.10202540071415049, 0.1979849562048912, 0.1726425824952977, 0.13020778952964715, 0.06669963949492999, 0.08193136645214898, 0.12572230664747103, 0.08496796672365495, 0.17372487299144268, 0.08166709063308579, 0.08894979341753892, 0.18435705532985075, 0.16320331900247506, 0.1541026716253587, 0.13178101368248463, 0.13284471231911862, 0.16994589434138366, 0.13928424034799847, 0.10050069860049657, 0.11366714138005461, 0.1301624769611018, 0.13564786261745862, 0.2841513582638332, 0.13578886219433375, 0.06519149363573108, 0.13072297402790614, 0.2005801083786147, 0.10258080876831498, 0.10469416036669697, 0.09094802476465702, 0.10771991764860493, 0.08674125692674092, 0.19522671135408537, 0.12370715263698782, 0.13108698092401028, 0.08731259019779307, 0.09247658774256706, 0.12471316222633634, 0.15435553448540823, 0.15727508068084717, 0.13471950457564422, 0.11367058155259915, 0.14020457810589246, 0.13516409429056303, 0.2771446428128651, 0.19651423155197076, 0.11123586219868489, 0.10029314830899239, 0.12254163303545543, 0.205981097849352, 0.10190848913043737, 0.13603517040610313, 0.2534303867391178, 0.16105724844549382, 0.1696421006428344, 0.10437779341425214, 0.09375851002654859, 0.15839356423488685, 0.09379542911691324, 0.16470441488283022, 0.06910225057176181, 0.17430035211145878, 0.21385827873434338, 0.1682714056223631, 0.17683018850428717, 0.08495536632835865, 0.18174352842782224, 0.1471457335033587, 0.16351486157093728, 0.196366514478411, 0.11188178682433707, 0.17173067214233534, 0.08365765453449317, 0.15479228033551148, 0.13727131193237646, 0.10054276777165276, 0.15340679325163364, 0.14744502172938415, 0.13809578626283578, 0.10482714644500188, 0.0776273509753602, 0.08210429788700171, 0.07155142272157328, 0.14266050846448966, 0.11845141037234239, 0.10816838858383042, 0.1353140098175832, 0.21545795218220778, 0.10031957046261855], [0.04594937366034303, 0.04142971296927758, 0.09908119655613389, 0.04164781787299684, 0.07872615022850887, 0.07944779257689204, 0.037085311088178835, 0.03306618871699486, 0.04369262047111988, 0.026541290804743767, 0.024550214609397308, 0.036193353057439835, 0.010187464550004473, 0.03481720940076879, 0.06673821421074015, 0.04610401179109301, 0.018370129533910325, 0.004892148426733911, 0.05016020931569593, 0.02488408437264817, 0.020310137487415756, 0.06440834887325764, 0.046464571729302406, 0.039156841180686436, 0.019243127599890743, 0.03179732144677213, 0.04125935996749571, 0.014824778972459691, 0.05037118960171938, 0.001699865292591442, 0.040777233695345264, 0.05916642836694207, 0.0060030196660331315, 0.04647615432207074, 0.01920402532310358, 0.027315775764041712, 0.07232710359884159, 0.041999889338122945, 0.040196909835296016, 0.00873854207540197, 0.08182219016764845, 0.03590521316177078, 0.03445007445822869, 0.021180056700749055, 0.011853072941968483, 0.0508124646730721, 0.05125989744971905, 0.03125241372202124, 0.04906242786507521, 0.030415247394038097, 0.03386276847283755, 0.025942778813519647, 0.027165256340854933, 0.042662414323006354, 0.03152428574061819, 0.05608493961127741, 0.0518253613928599, 0.030147880847964968, 0.0261426107691867, 0.02399307968361037, 0.041880277185035605, 0.047458445719842396, 0.021522004423396926, 0.04965074147496905, 0.020175465249589512, 0.028775435207145553, 0.04203864386571305, 0.046234765489186556, 0.07738604356667825, 0.03729544659810407, 0.03246142063289881, 0.016539443749934435, 0.025417852248730402, 0.07275765442422458, 0.02830262522080115, 0.03749997401610017, 0.046585228826318464, 0.05448749175827418, 0.016653992335445116, 0.024129393976181746, 0.029781746744577373, 0.033091470931789706, 0.013074793054589202, 0.046829908554043086, 0.06209734680929354, 0.04251519258001021, 0.04064997784527285, 0.09327148473156349, 0.04143055435270071, 0.06121523092900004, 0.017423410334491303, 0.02647065870197756, 0.017364857851394584, 0.005611077483211244, 0.019725118165037463, 0.04481074779427477, 0.004013996463202472, 0.1070721677637526, 0.07634057038064514, 0.020524786951552545, 0.06696266680955887, 0.015573706910280245, 0.017609296699187586, 0.031074410237904106, 0.06510669711445059, 0.05385916833100574, 0.00927207331239645, 0.07801679614931345, 0.026890571794605682, 0.028043514749567424, 0.023964079096913338, 0.05224745427923543, 0.061276638348187716, 0.013267284957692027, 0.029998097635273422, 0.03600095445290208, 0.03539305832237005, 0.018240900843271186, 0.034917456164423905, 0.04167836891221149, 0.033226516363876205, 0.019624572845974138, 0.02274188316161079, 0.045098243081676107, 0.06391628206308399, 0.047433377243578434, 0.030744927203548805, 0.023023088429389254, 0.014044122737167137, 0.026417948405391405, 0.03285146291766848, 0.026200201428894485, 0.030133936953331743, 0.027172084099480083, 0.07205847837030888, 0.03463875129818916, 0.08967311853276831, 0.017313825232642036, 0.0024144082562997937, 0.04033737336950643, 0.01857544744520315, 0.06639602221548557, 0.013240746604943914, 0.018020604271441698, 0.03202837958399739, 0.04925230910469379, 0.0010997042492298143, 0.05400112124958208, 0.016054387902840972, 0.009178023269799138, 0.041468766052275896, 0.05228158459067345, 0.030621559359133244, 0.03450375675622906, 0.026379633229225874, 0.04886566288769245, 0.1126232695366655, 0.008370816807395645, 0.03437112012345876, 0.06820059966828142, 0.020163757127842734, 0.05087809258007577, 0.028798960016242096, 0.06261086889675685, 0.03572794928082398, 0.026422197730945687, 0.03387552832386323, 0.05484111706859299, 0.060293291828462055, 0.0252124987143491, 0.019838966163141385, 0.01638840524745839, 0.039118663407862186, 0.010395402454638054, 0.029363592753985097, 0.022161940977509533, 0.0258037402028484, 0.04110384313389659, 0.05119298371885504, 0.06911642516830138, 0.026262779320989336, 0.032824884700988016, 0.01965620445220598, 0.06315670960715838, 0.03731740738398262, 0.027951025337513005, 0.03056165828768696, 0.02942445734515786, 0.029171502882880822, 0.02320423522698028, 0.024054259793566804, 0.03839691249387605, 0.07341098186693021, 0.049722079254154644, 0.10067243581371647, 0.02591746097563633, 0.03758481803483196, 0.07483420228319508, 0.018344614920871596, 0.0326268949678966, 0.014186275823573982, 0.04718639049679041, 0.018134944207434143, 0.03840695141947695, 0.03785633042986904, 0.018994100159034133, 0.05749629584274121, 0.08582302941275494, 0.02574567117595247, 0.03629411890038422, 0.019806813781282732, 0.029626443649509122, 0.09674445087356226, 0.015475193803597773, 0.02571631096569555, 0.08185478698994432, 0.04166078128452812, 0.015832693548873067, 0.016300677454897335, 0.05688813169087682, 0.015289436360555035, 0.025496087336380566, 0.01759669291121619, 0.02146359782532922, 0.031099695845374038, 0.0035770924296230078, 0.05189047022057431, 0.039147731848061085, 0.025704294110515287, 0.06623329594731331, 0.05374781055642026, 0.03404057178912418, 0.03278444740655167, 0.02560209995135665, 0.023904999052839618, 0.039404045058680434, 0.043119238024311404, 0.02119401246974511, 0.06557105255446263, 0.040911746477442126, 0.04634677465738995, 0.081416473723948, 0.06786627189389297, 0.022717181094256893, 0.0283882207170661, 0.015057960924293314, 0.06683831848204136, 0.02049484659385468, 0.0062522328558510965, 0.03990715841895767, 0.015920299205130765, 0.03499031046937619, 0.039426769196454964, 0.04330254765227437, 0.01192013340603028, 0.0443855132907629, 0.06044812673436744, 0.06449391892445938, 0.007577393087558448, 0.030784356873482466, 0.06561886891722679, 0.07070859401885952, 0.035035541613719294, 0.039289087655821016, 0.051011187223983664, 0.06115059368312359, 0.011542213149368763, 0.03637558381472315, 0.005893729302832591, 0.02287110167422465, 0.01531294929528875, 0.0332245621830225, 0.037358859088271856, 0.06059070051248584, 0.02806349760586662, 0.08336401171982288, 0.03686526218163116, 0.040527363174727986, 0.06255886597292763, 0.06462516795311656, 0.026864996113415276, 0.026754016622102687, 0.021025949523651173, 0.056573288049548864, 0.057571491093507836, 0.06943222893668072, 0.01750694986964975, 0.013465082156471908, 0.024571099917271307, 0.038106675924999375, 0.016368897365672246, 0.022299541093941246, 0.020871625215347325, 0.018399552508656467, 0.0263900114223361, 0.03782620008236595, 0.0545282954616206, 0.051399254971849065, 0.04494017495640686, 0.03327371186709829, 0.009581905124442918, 0.03548827714153698, 0.06646478495427541, 0.0468334674702159, 0.06650436390191317, 0.010378362743982246, 0.041730707710874934, 0.030334006396255324, 0.018881750026983873, 0.0344318422222776, 0.02923469145649246, 0.03303771060226219, 0.029915401179875647, 0.024387507000938058, 0.07066115763570581, 0.044962817669979165, 0.03411253721320203, 0.025396395275103192, 0.05356744916311332, 0.02704742703852909, 0.0837042834609747, 0.045449775111462386, 0.01693292281457356, 0.022119361208751798, 0.017082108916448693, 0.018577549207423414, 0.07325246930122375, 0.031071858946233988, 0.015546567205871855, 0.02743237352530871, 0.08298543667686836, 0.040263942309788296, 0.06659272273204156, 0.03226046570177589, 0.037155261263251305, 0.07484220899641514, 0.033341307525656054, 0.06606063592646803, 0.01487124674687428, 0.06212808444563832, 0.017232306035501615, 0.04053705944014447, 0.024296264396980405, 0.02939347204353128, 0.00898210222034582, 0.008922159588629646, 0.04626227669151766, 0.021166767592408826, 0.057507206685841084, 0.014549448121605175, 0.08272051624953747, 0.05228016645248447, 0.10138506721705198, 0.10912708392632858, 0.24140251215015138, 0.11438949619020734, 0.11586783400603703, 0.16537023415522917, 0.12830026474382195, 0.12194326014391013, 0.12577289821846144, 0.10186414008161851, 0.16168238275817462, 0.10515086193169866, 0.1362608375826052, 0.09993887160505567, 0.1239160057157278, 0.15258320101669856, 0.17085737043193408, 0.0811561673347439, 0.25590986226286205, 0.13378320767411164, 0.08816231960164649, 0.16111663383032593, 0.17106979260487215, 0.10209274531475135, 0.10298322753182479, 0.11348304804414511, 0.07483020571193524, 0.12118568936628954, 0.1689515555543559, 0.07340661210141011, 0.1174073756805488, 0.1892376627240862, 0.08233038575521537, 0.19111915890659603, 0.10049342470509665, 0.07852003843124424, 0.161273931818349, 0.09815015151564564, 0.11288806782769305, 0.13771310608301843, 0.2041189127734729, 0.12807828879782132, 0.1138681098818779, 0.1174406646085637, 0.10415986153696265, 0.09579478004681212, 0.09905980234699589, 0.13276243316275732, 0.08849809944097485, 0.10181688690291983, 0.11540789582899638, 0.09887628576585225, 0.12916281845952782, 0.12307656290275709, 0.13433085328766278, 0.12481425037341458, 0.14378870863999638, 0.17718628368207387, 0.08575183751859836, 0.08319094457796641, 0.12114789496575083, 0.0828349579657827, 0.19083691548023904, 0.13449718936213426, 0.13427927105554513, 0.1650869729263442, 0.12363658499504838, 0.07474566024861165, 0.178121291367071, 0.19993642291852406, 0.1861349120736122, 0.13242659904062748, 0.094846710562706, 0.14584499544331006, 0.0859011627201523, 0.1041846823479448, 0.08239685504564218, 0.11990134471229144, 0.11293409964335815, 0.1476249285042286, 0.13427004297929152, 0.11834169125982694, 0.10948038353983845, 0.13721605204045773, 0.2097428688513381, 0.14937975576945714, 0.26126936610255924, 0.1640832025025572, 0.11782307337437357, 0.2673842694078173, 0.17440654284187726, 0.13197286267365727, 0.09285174975437777, 0.08678630486662899, 0.061693577761096616, 0.0915988619838442, 0.09895420872739383, 0.12441068488572325, 0.1360853005732809, 0.14839625997202738, 0.1633391345718077, 0.11150097261582102, 0.20117996047650064, 0.15214478597044945, 0.13217801095119544, 0.1364976463041135, 0.09153980229582105, 0.09290274844637939, 0.11725264255489622, 0.1524971356349332, 0.10206270656947579, 0.0765800050326756, 0.1325567013451031, 0.08945539700133459, 0.07692579326352902, 0.14785784243472985, 0.06837367359548807, 0.09371289890259504, 0.17684854966189179, 0.11526319145091943, 0.08254851440766028, 0.10125681052782706, 0.15840822059128964, 0.11114141012408904, 0.16346120302166256, 0.1936700027436018, 0.10102408658713102, 0.1257721111178398, 0.13563003071716853, 0.0734264524653554, 0.15572404462311948, 0.11021174929503884, 0.11158006265759468, 0.12529149119343075, 0.2977369049830096, 0.20349166143153394, 0.14062545980725968, 0.18776336897696766, 0.1292169519833156, 0.1163964399269649, 0.07052358466067485, 0.166818377162729, 0.1060967668890953, 0.11536863579281739, 0.15351370322917188, 0.15884880694959844, 0.08118604323161499, 0.13280851926122392, 0.10569267214408942, 0.09105345553585462, 0.13823019047932966, 0.1262673602572509, 0.07896983250975609, 0.15931650756725244, 0.13319862261414528, 0.11856961117259093, 0.1840996327144759, 0.1226022397833211, 0.0913345522380301, 0.20766720308789186, 0.07932981569319963, 0.1437540626419442, 0.0708393341462527, 0.15294857855354035, 0.0724496470232095, 0.1992151401937008, 0.07245810835489205, 0.10501290897705726, 0.16603069300098078, 0.07131595749940191, 0.17100025633616106, 0.07902586593159608, 0.13168125546404294, 0.13515889671232018, 0.1311051928039108, 0.12903882297022], [0.02101294370368123, 0.01632511319725641, 0.02821731979825667, 0.05636807870385902, 0.004244514741003513, 0.06369954440742731, 0.03761929779180458, 0.06192455108144453, 0.07038789122764554, 0.07944450168205158, 0.06462056070033993, 0.02488500209126089, 0.042428574192204645, 0.03674032013597233, 0.024613540586350218, 0.05395034308146153, 0.060480350362403054, 0.033834195363202264, 0.02551955447000052, 0.028387752527903234, 0.020417994021305015, 0.026983858485307013, 0.0375981546406235, 0.012362821526559336, 0.032021824935717244, 0.012177268492190965, 0.06163822965962546, 0.0562221970675247, 0.06430615471409899, 0.0653918921681387, 0.017117643795375313, 0.03963680971147759, 0.0777036522382072, 0.02079744098175849, 0.06567353169832911, 0.052569714308317216, 0.021592085216460482, 0.07084603128688675, 0.03316376205267651, 0.015883120575121472, 0.010083966755441256, 0.026386881679562584, 0.044478255457111766, 0.0846761152414339, 0.02960837086928742, 0.021808098535984755, 0.05777842391814504, 0.06589946350348846, 0.022348772202219282, 0.015810171275266578, 0.05488436010533145, 0.042596080739583285, 0.02725984581879207, 0.023514851595142057, 0.041986756292837005, 0.0278106347458171, 0.016922437752197896, 0.03480729600414634, 0.030014151773814644, 0.03623659948685339, 0.029951156582683325, 0.004788147244003734, 0.011038733380181449, 0.09061924740672112, 0.013001852236422045, 0.02906766327630196, 0.013756758915925664, 0.03064867022580334, 0.028550232827131237, 0.04867504883025374, 0.005696463481789189, 0.07825089751609735, 0.016751792980358005, 0.13804003782570362, 0.033795919202800305, 0.023584028240293264, 0.02195556285525007, 0.03253571682476571, 0.024926156936479465, 0.07110362353601626, 0.022739694886175648, 0.04033739033288189, 0.04152147125984941, 0.01056971216374742, 0.029549178866935626, 0.07813064754009247, 0.10423127734767539, 0.05454071943781205, 0.00507117183380095, 0.02663935438197638, 0.03320647243942533, 0.004836395324673504, 0.05244965432211757, 0.029403331157352244, 0.05084446777722665, 0.09517584075885159, 0.06363667135259934, 0.035030530632606575, 0.02967057895979711, 0.01745328792769994, 0.03688505165545004, 0.03236678196117282, 0.013714371681479471, 0.04521905963442155, 0.036863314786127636, 0.07695345713623933, 0.036849374284169505, 0.06459709017404489, 0.033901879231312444, 0.04350693257791655, 0.04573107198146837, 0.06071561202406883, 0.05601146783945816, 0.005753071537973093, 0.03002794299806867, 0.004650699797951217, 0.028149542631581426, 0.015504801679136497, 0.06410509800272328, 0.04605822764070971, 0.045718919419284375, 0.0194723519962281, 0.049792137994830094, 0.012018519287396754, 0.009209227398969233, 0.017906267728124346, 0.022724254821826304, 0.00818146312875407, 0.017991439140002643, 0.020270974142476916, 0.06763445040477173, 0.03737459092267922, 0.044942390373242755, 0.030475562371845757, 0.0032739187424470273, 0.005291543044482491, 0.06344389955380134, 0.012817356020345219, 0.02035859167309744, 0.0428676711661475, 0.05424450497542109, 0.008879906364849635, 0.023480147921613286, 0.06631910348577158, 0.05737536054636751, 0.03700057224237493, 0.022505948053939, 0.04505711368152073, 0.002141181076045281, 0.02068263285660318, 0.09862365360770907, 0.02684033815083759, 0.04308698386219995, 0.018430629412510564, 0.02351751145241516, 0.01940826097104166, 0.023476052962775742, 0.030714413483760188, 0.0657332767067211, 0.043937904095011096, 0.052838319180799384, 0.06321225448378495, 0.01932871461446796, 0.037264905736914704, 0.009001466761609274, 0.0462509587274066, 0.018198449996166995, 0.0230656139153455, 0.024766516306304505, 0.05375608868364777, 0.006816882556969566, 0.05850706874792065, 0.049867492701326094, 0.016319103073328733, 0.08064989200127975, 0.016400696909321204, 0.02604576346597501, 0.020067133741187196, 0.02183808130212128, 0.011980400886386633, 0.004507054358587733, 0.0901201374030539, 0.017672134130927067, 0.03213866188057831, 0.0570194214316351, 0.05302403082272836, 0.0600824167153665, 0.005382051134282457, 0.02064544235223106, 0.09799010546079703, 0.026660222726474916, 0.008802156429737806, 0.04917069151997566, 0.03999832299138818, 0.009758187674119003, 0.019440099530454193, 0.0758437809667417, 0.06842291488179139, 0.05948191322386265, 0.011725062221687819, 0.007584056301441575, 0.020023838117984787, 0.009438676560031516, 0.032155062071979046, 0.046706438929374726, 0.011258162275355841, 0.04480042388396604, 0.04685799651114004, 0.047083996169801266, 0.045417710939156156, 0.004505618832938905, 0.007547001504073185, 0.013513236938576614, 0.02252396655135921, 0.060977112634905746, 0.0580590795725584, 0.00928160418490214, 0.028439467074349523, 0.05275635215054665, 0.05837326164224318, 0.0486897764328335, 0.012248016794079115, 0.008998940915002354, 0.030450059633169855, 0.03931531642696687, 0.02383375966123172, 0.0215393376004483, 0.14019970622445854, 0.12115210188286644, 0.03463790312941585, 0.02064406662248075, 0.008373876152160977, 0.11971267126500607, 0.020436877650874, 0.017299192624964883, 0.01660564841170396, 0.015343571580680353, 0.01171941596216389, 0.024060621059366634, 0.03361179533281496, 0.00973042456566223, 0.03751006383182747, 0.01663729189229863, 0.021700890003038303, 0.024195077862324457, 0.04307535377198032, 0.025588607282510827, 0.05071819241025618, 0.028079290508425662, 0.11581451472427164, 0.005275200528558344, 0.027968027728742788, 0.02111157725032951, 0.016363085713237524, 0.05464904076818909, 0.028698435053229332, 0.03604433658931937, 0.00657850641956819, 0.01445405457967094, 0.027250571941424693, 0.010782570295434977, 0.011937928835063108, 0.022420925919764807, 0.08166877339993205, 0.04672774153628519, 0.031149554598544325, 0.01359354579887752, 0.04043168295174837, 0.015475013991817832, 0.012570234414722239, 0.012465527979657054, 0.05200385342219046, 0.053936975941594155, 0.03132110521463411, 0.031630157559577904, 0.013748770014249852, 0.07012184443218367, 0.017701172037050128, 0.042244803160429, 0.06007676451866116, 0.03978935795437012, 0.030089625223938907, 0.04528701491653919, 0.03247886237555316, 0.07665794156491756, 0.03129382132153426, 0.03334088683394449, 0.05240908132067748, 0.06001501104661396, 0.0679565713341747, 0.006147435666727168, 0.011897144639598472, 0.009318630144532238, 0.0746452302805015, 0.005667727099665041, 0.026841924226443683, 0.03366113839937108, 0.02777305238747171, 0.0704994627407619, 0.10416142216750554, 0.0139128601378096, 0.03987758107749479, 0.012250300912585641, 0.047781448744769604, 0.01497973092565579, 0.033170615256364853, 0.01720721720318709, 0.027257513354665468, 0.036731702741235495, 0.016544252866879106, 0.07308242164020028, 0.02701914569895182, 0.006900035327167383, 0.04670557040455086, 0.049634548236749, 0.023751544965697185, 0.030488044023513794, 0.004971715563442558, 0.046461294405162334, 0.05584074164341603, 0.03988248349300452, 0.04728349225063409, 0.031540852173098495, 0.024572251730465462, 0.04183542262762785, 0.03258035085829241, 0.01264701658926372, 0.02509118683104004, 0.036843179259449244, 0.061557456851005554, 0.05021473978246961, 0.0695321975009782, 0.036596799801502905, 0.018981940811499953, 0.033524980169853995, 0.036665498079465966, 0.06956785451620817, 0.020969883871397803, 0.029280723272157565, 0.062383973571871004, 0.04038482332336051, 0.04707386224929776, 0.007539509629298533, 0.056532508094928095, 0.03153214317613414, 0.049839174042322805, 0.05817333808434861, 0.02116874891466328, 0.02197820896149746, 0.035765920100467544, 0.0458375375185694, 0.014300137392378278, 0.12350626555936677, 0.0812989039612668, 0.16361419909766742, 0.11513509761009898, 0.06182807018714292, 0.24483717499034746, 0.11316383124462195, 0.12871756378029073, 0.135636816067355, 0.1132888648925083, 0.11230206462953772, 0.07823430733489138, 0.12489046342670918, 0.14330583597932542, 0.16528695076704025, 0.12155387603810855, 0.19749466037111624, 0.14855339511164597, 0.09432314615696669, 0.18548106215894222, 0.15742883671607288, 0.09062822442501783, 0.1738360170274973, 0.06090009891028915, 0.07823438875909362, 0.10458571011466639, 0.11686730251780578, 0.1519969603312867, 0.13967982626387052, 0.09247654024511576, 0.14469342652176106, 0.14919950972710336, 0.1450307262795312, 0.08770444417106253, 0.14156096960817063, 0.15166369107152733, 0.09464851726910897, 0.16842364173914703, 0.13245288548724993, 0.17754392591970308, 0.0928329611197114, 0.09498695696571044, 0.2268327096743243, 0.1341669870806592, 0.19146200908081873, 0.11887292989662715, 0.1337730839316334, 0.15549472692821706, 0.06587804215294973, 0.12521075909691198, 0.15062403971595423, 0.18582619221082755, 0.23574545713407652, 0.09640658114637647, 0.12136389980358736, 0.13613927124866418, 0.17460082098841667, 0.14454076971326554, 0.12003413401544094, 0.11948321786309991, 0.11562221789998667, 0.1757961825600692, 0.10859575029462576, 0.30188896932772225, 0.06489050228680883, 0.22352695491697105, 0.07624740752258471, 0.19177140747862204, 0.12515036948025227, 0.14235838396208628, 0.16056278640670435, 0.1506800324256931, 0.09393524125750576, 0.2291722169944218, 0.15531817211636476, 0.1938043391065938, 0.10356900002807379, 0.10855511961770908, 0.1973241445209299, 0.15953358449041843, 0.09877017645963601, 0.13042972476354667, 0.10587484522589616, 0.08980644387858254, 0.12249112288866724, 0.19280177647514002, 0.1590673630791051, 0.2668299062975815, 0.0974115322210959, 0.09694005216338805, 0.08221862425229379, 0.09045843460730144, 0.14132576222930635, 0.11602263498519148, 0.19932135806552, 0.14034225286117621, 0.1627792753279209, 0.16033428295382432, 0.10031602172447102, 0.08898696356586047, 0.14030572053577217, 0.095271222426423, 0.0844286128080317, 0.06852482405624219, 0.16960407554038934, 0.16890628369791166, 0.11472359326268945, 0.07474965681987149, 0.15567323592092308, 0.09424128090696675, 0.11382336728274822, 0.11148781582180943, 0.18292891553470067, 0.14737913597907337, 0.12826211750507355, 0.10240605885961226, 0.070594796910882, 0.14902154356241226, 0.08585485949047975, 0.1281279575611864, 0.13321820513478347, 0.07929147167929582, 0.1911121971373047, 0.13226331637373992, 0.12395054314817701, 0.15661648102104664, 0.1919890000884022, 0.13375115367983068, 0.15694410486945085, 0.11115878062056643, 0.21863779798150063, 0.1011238990883742, 0.15435227751731873, 0.11687589277114187, 0.18106522411108017, 0.12499873047428471, 0.17134621420076915, 0.15546708341155732, 0.14872955637318747, 0.1122663736875568, 0.15277312296841825, 0.09692886990628072, 0.15044945265565599, 0.21251670643687248, 0.15203037139560494, 0.13596102009926522, 0.15678927674889565, 0.08831857943109103, 0.14249842001923493, 0.08848558725523097, 0.23663398517029627, 0.15988408853965147, 0.1668528603123767, 0.13823215823088372, 0.16031148417719773, 0.11359463312796184, 0.09857992881110736, 0.05907616285341127, 0.1618338453450373, 0.12035220409078257, 0.20304636604019574, 0.12430400561009135, 0.08618308723505054, 0.197722498859678, 0.20677393887724194, 0.13758175527410849, 0.11802470684051514, 0.08436327667108603, 0.10999921855649777, 0.13656339634742054, 0.13919533868985517, 0.14956480583974294, 0.1079524312434452, 0.11859350917594773, 0.11058289437953915, 0.09696810958640915], [0.014097650668450763, 0.018219320037003075, 0.01625146670266986, 0.036749870516359806, 0.012261576468258031, 0.0377847619487771, 0.02878476506365197, 0.03857785064194884, 0.04116263480058738, 0.02553125241372202, 0.020115740597248077, 0.028959850847188915, 0.04813301470130682, 0.04707016762612121, 0.013286716504288571, 0.03275904305545347, 0.0160057522090418, 0.04640737122723034, 0.022500684318531836, 0.03100495200072016, 0.07581976761243173, 0.01595274335704744, 0.036253142170608044, 0.0382792613069926, 0.021855942040149654, 0.03540092593591128, 0.04500078848962273, 0.03493927785062364, 0.03538620851135679, 0.05702645783977849, 0.022677705623209476, 0.04069033371550696, 0.031042631050305705, 0.02962908654340676, 0.01824099923084889, 0.05312458971249206, 0.013072324035290097, 0.044184656747217686, 0.04183476784133485, 0.058846648383353434, 0.006515049824624189, 0.04974882710458977, 0.05018690627600465, 0.031822383137685914, 0.005794918912995074, 0.04278326140982764, 0.08003285939672164, 0.023609047522768378, 0.05505579537046807, 0.10611691259379898, 0.013871248129622211, 0.052361091931483576, 0.0159783393942884, 0.04553719077791486, 0.02968934384573783, 0.02115244371816516, 0.021432358073070645, 0.034066620748490095, 0.029844755506409065, 0.06436720929507699, 0.039206116393740685, 0.008811758548420454, 0.04098611730816109, 0.07874762586184911, 0.009590056026354432, 0.04331008278365646, 0.06774647653635059, 0.028724344912916422, 0.025711167670254196, 0.014523697717647468, 0.04816116372655545, 0.0452794322877058, 0.039188515195356946, 0.020456629805266857, 0.01623482393499996, 0.011674960892248367, 0.045094663809452734, 0.04282263001160962, 0.036508464720100164, 0.024521845060267618, 0.048501672954963784, 0.02450306321095143, 0.027565223896609883, 0.05914942427937474, 0.04164477803611329, 0.07494257111102343, 0.009116363944485784, 0.027877892833203077, 0.04448439280635544, 0.050475962193948884, 0.08433148730546236, 0.03853449903960739, 0.038193284134779654, 0.017323348471628766, 0.006557062168472579, 0.012612254392089588, 0.04456169830103006, 0.05541973102039524, 0.0410366138842489, 0.010357237404345401, 0.038180643027382236, 0.04697241108598454, 0.051695472826915126, 0.016733448786128844, 0.0616659206737365, 0.04414412785055382, 0.030608785937407186, 0.06756625763539757, 0.018733714041965346, 0.027722996859146014, 0.07751439525080578, 0.043850352721554894, 0.010529272324804748, 0.03327303672475474, 0.012001041921653917, 0.0771724000307066, 0.040897660090454986, 0.026829934512664164, 0.05491819525403636, 0.03872130312291639, 0.021889804330255305, 0.035325506768588505, 0.024498091245602285, 0.05611090375376599, 0.029947886043893437, 0.03113803985927786, 0.06624661558972937, 0.06202781732593264, 0.029360892184610878, 0.03688284980931452, 0.08820976277015039, 0.025282645664576973, 0.05017690806250487, 0.05740015421594892, 0.015675288691584553, 0.0353968513331243, 0.014251852840451258, 0.04952291565548096, 0.08429082270179476, 0.0664246224665216, 0.009991640191791313, 0.0543153338533427, 0.05579554442582386, 0.05677380871825984, 0.041532276930021386, 0.011520949558221867, 0.031933340576610396, 0.03382357629016042, 0.0218448751339955, 0.04877948554764901, 0.02358631320696856, 0.08014759288302489, 0.05411702860146761, 0.008957119409127958, 0.03297773489196386, 0.004620014748070389, 0.03887326104034271, 0.05366494785994291, 0.04323162717212524, 0.013280801375263503, 0.06794245780578681, 0.03458950322653566, 0.026832796234105314, 0.028192003656710898, 0.03192689110125814, 0.04613828459488494, 0.04007318236732057, 0.05815154353954962, 0.027518820583022068, 0.06139257962682417, 0.04055621787639601, 0.04490043316036463, 0.06306643052292721, 0.06115138078374522, 0.10047945366906268, 0.040302422030695846, 0.039317050083939514, 0.05588623063106622, 0.03323633137292095, 0.033726444002240896, 0.03293369457657848, 0.023552681618769254, 0.016674144825498973, 0.04720300781939711, 0.027115694446755306, 0.08164125201957566, 0.14721790248794214, 0.011250088556802698, 0.06516488827764988, 0.04869145919967975, 0.04363530122541955, 0.0246941013527768, 0.0302962153883917, 0.040136089348899465, 0.02202608130340065, 0.0462022127716669, 0.023389085129435574, 0.022760010224633982, 0.008753538547482873, 0.045862972403743436, 0.03619265416637063, 0.04196297703310847, 0.04039383426840816, 0.006398891838866153, 0.033414043086980066, 0.04530590533145836, 0.023557365206735473, 0.0267723336749311, 0.025226958295596496, 0.037225452318255386, 0.04351179428132517, 0.0343296344924186, 0.02966266724147967, 0.03260690193357212, 0.04500587071691241, 0.03150614171421953, 0.05794340292257922, 0.03683869753565107, 0.007300680569772209, 0.03144889032202108, 0.037033141923270056, 0.0008435075557957004, 0.004334096206418637, 0.07794213694121156, 0.039414993221206326, 0.07645446248352528, 0.010818896515827094, 0.035403090462620766, 0.03318201464467815, 0.012637450093669551, 0.010509504055205201, 0.045453201713306565, 0.015196999534964561, 0.018854315159842372, 0.04156352686030524, 0.05640502154294934, 0.04054031640823398, 0.018702654101486717, 0.014612424653023481, 0.06154752988368273, 0.06646000128239393, 0.04820970272911446, 0.033418195721294196, 0.08980997226067952, 0.028559369301157336, 0.021059735478567224, 0.05649290879123977, 0.020042901559333717, 0.014894720665844423, 0.025362061403159584, 0.05380257851045046, 0.04761627635785511, 0.0831517456099391, 0.01878698243360434, 0.004472938041934478, 0.029615183360874653, 0.03345745575747319, 0.06783484893717937, 0.03289448203785079, 0.035370670059429746, 0.04706797935068607, 0.010257872736214526, 0.014688503695651889, 0.03918762631448252, 0.0763740696545158, 0.019446655875071883, 0.011689538368955255, 0.00908914620855025, 0.028603440150618553, 0.020665817062503526, 0.03877274625535522, 0.025175666137199317, 0.0558278528707368, 0.05154722310336573, 0.04340157983824611, 0.022165720417563404, 0.004901237827393093, 0.03939561765374882, 0.03651464617412005, 0.014382068799542529, 0.02730093789952142, 0.04544733577807035, 0.08000756361122642, 0.07424940687737294, 0.043724857669855864, 0.049460904340126684, 0.05807917099446058, 0.05550866660528949, 0.0770100469567946, 0.023519231538687433, 0.04745565354824066, 0.0400703053788415, 0.02558343006031854, 0.019797336343409758, 0.033562801711793454, 0.04269496704052601, 0.056151507289281914, 0.04265158151143363, 0.005518858636995512, 0.03979814159018653, 0.040159213822335005, 0.03444008981542928, 0.02676425571553409, 0.015072546034519161, 0.03354990276108895, 0.03774441625656826, 0.1210171819797584, 0.023185159911268523, 0.06383440324238368, 0.055662042660904784, 0.02241392174203481, 0.04338611263249602, 0.013823519128241708, 0.04083446133881807, 0.02511787191698594, 0.054635592204119475, 0.05437053946245994, 0.0814443343718137, 0.049373634558703215, 0.03830653162939208, 0.06080906665218728, 0.10056347666042191, 0.017792928631284406, 0.0368628296335893, 0.005559278119887624, 0.04757661598601511, 0.008769543492235243, 0.0011765414487204648, 0.054057076639894924, 0.018428600592804805, 0.029029773880860636, 0.01162875265747841, 0.04809001593717507, 0.03298101560877902, 0.016554720965879302, 0.02929063666878002, 0.059905393714351315, 0.023191626349996244, 0.03212022947679673, 0.04591831711253949, 0.03910754561158163, 0.023694855061226656, 0.03679853504789727, 0.021978892585528747, 0.01915436504142625, 0.06063690196190562, 0.05652120030884232, 0.0469380873920662, 0.0625948826117175, 0.036968575923570564, 0.07840977649071387, 0.030255187768489122, 0.09829768538475037, 0.1442217496888978, 0.11614173145166465, 0.14304739556142262, 0.13777322428567068, 0.12509987290416444, 0.09115372944091048, 0.10786058474332094, 0.15826628463608877, 0.15612298250198364, 0.20982532442680427, 0.1376192375485386, 0.1360989934099572, 0.15610744405005658, 0.08466565223144633, 0.11856796911784581, 0.12306799979082175, 0.11164280000541892, 0.07394637313804456, 0.11437968457383768, 0.16635653908763612, 0.14239522841359886, 0.12471639205302511, 0.15259897017053195, 0.10375724599829741, 0.1774115301668644, 0.16012078869555676, 0.14692682453564235, 0.09821044613740273, 0.2348509579896927, 0.1139103826135397, 0.13477612153760024, 0.17228317606662, 0.16737583439264977, 0.07747400884649583, 0.14064684723104748, 0.08910516436610903, 0.14220873984907353, 0.16027693317404815, 0.12040436986301627, 0.08744016156664916, 0.20193446427583694, 0.16122545727661677, 0.1261267542306866, 0.07615630741098098, 0.18142439983785152, 0.13856274049196923, 0.1455410796084574, 0.204824724899871, 0.21140656886356218, 0.11907583900860377, 0.10653556870030505, 0.14366805154298032, 0.1178913882800511, 0.10886976987655674, 0.12357268056699208, 0.16923758520611695, 0.1471385953149625, 0.13000796096665518, 0.23028436303138733, 0.1372691270496164, 0.08765197305807046, 0.13648638262280396, 0.1513087765446731, 0.16815082994954927, 0.13700076644974096, 0.11178431526890822, 0.2127314084874732, 0.1530313326844147, 0.0946051792374679, 0.09560717189950602, 0.12799489684402943, 0.08441603276878595, 0.14104890637099743, 0.10703659217272486, 0.19940958118864469, 0.16528444018747124, 0.1159709170460701, 0.10093676591558115, 0.08601637796631881, 0.10683247526841504, 0.12806577661207744, 0.12284317399774279, 0.15252867394259997, 0.09817106396492038, 0.15112897833543165, 0.08520858202661787, 0.1344149780592748, 0.12058213246720177, 0.08876386803707906, 0.14438220965010778, 0.10233946743288211, 0.13810863771608897, 0.07919972017407417, 0.17367988611970628, 0.11107531402792249, 0.14676887515400136, 0.14456310708607945, 0.12368964643350669, 0.06609003006347589, 0.057807424504842074, 0.15114273902560982, 0.12273801464055266, 0.0682725515216589, 0.17233122991664068, 0.17557527869939804, 0.20000768266618252, 0.1119437709982906, 0.08106840561543192, 0.11181410974157707, 0.0968869093007275, 0.20318277872034482, 0.09362257232091256, 0.15381641127169132, 0.1281518419938428, 0.12409564107656479, 0.1591114407139165, 0.14902124500700406, 0.13081767037510872, 0.11430761058415685, 0.1026151290695582, 0.13008813666445868, 0.07386101343269859, 0.1056762176698872, 0.0931363341265491, 0.06736499057816607, 0.13098514638841152, 0.1494813324617488, 0.14020512093390736, 0.07110198826662131, 0.1887037642300129, 0.1425472338284765, 0.26318085353289333, 0.180185449176601, 0.0733577711507678, 0.14714616776577064, 0.0897088230454496, 0.09494813797729355, 0.1527554267751319, 0.16472458094358444, 0.14054734685591289, 0.1397137123027018, 0.09965271303164107, 0.11965374728398663, 0.10359336622059345, 0.11224243497209889, 0.1124801936426333, 0.09003882176641907, 0.11302258060978991, 0.19607055107397692, 0.12429039419761725, 0.15768719570977346, 0.12457660026848316, 0.08141804113984108, 0.07181235336299453, 0.09174462487655026, 0.09705190866121224, 0.17059166968933173, 0.11963633607540812, 0.11209835484623909, 0.12564696211900028, 0.10732951574027538, 0.08986195482845817, 0.1269250235387257, 0.13984327177916253, 0.12854305814419473, 0.09091928202126708, 0.10214425969336714, 0.09484416605638606, 0.1963291543402842, 0.29278414217489107, 0.17323341007743562, 0.18360435643366405, 0.1658683738538197, 0.16386079229414463, 0.11348281055688858], [0.014293967812721218, 0.08068805281072855, 0.04429613665810653, 0.026931424691740955, 0.05466608217518244, 0.06458313949406147, 0.012440722435712814, 0.10187162432287421, 0.02251738476167832, 0.06616836693137884, 0.03064870075987918, 0.006486851181502321, 0.04824851153950606, 0.027873346648578132, 0.07054779479014021, 0.04235150618478656, 0.07130721118301153, 0.04734085899378572, 0.029472022649965117, 0.047522652095982006, 0.012835829136227923, 0.06306344496884517, 0.06856744284076349, 0.010783730590316867, 0.04458689909162266, 0.03961234173870512, 0.036641362588852644, 0.04715685386742864, 0.037221652522150955, 0.030033286461340528, 0.043631168947155984, 0.021067124724920307, 0.1467486819518464, 0.010683756937006754, 0.03922234016603657, 0.0296280110654022, 0.027553129009902477, 0.05769694543310574, 0.07010308972426824, 0.06961698045155831, 0.04147730541548558, 0.01808063087186643, 0.021007914062855498, 0.06052472655262266, 0.013011195663628834, 0.07467612397990056, 0.009957450508539165, 0.01687739829399756, 0.00561161055728527, 0.03907794452139309, 0.03240876970812678, 0.04040138975584081, 0.019347528694197536, 0.01644246413239411, 0.03322473520945225, 0.06370659438627106, 0.03233265843508499, 0.07202219710286174, 0.04755642278386014, 0.02862928554947887, 0.012964548077434301, 0.03389077161305717, 0.031384870543011596, 0.008672898901360375, 0.04759054630994797, 0.038957904891244004, 0.036616334824689796, 0.041889254203332324, 0.015753021663320915, 0.04560616046988538, 0.01901996082493237, 0.027138990250283053, 0.028257584066263268, 0.006600252194662711, 0.05359644974981036, 0.04098558805084654, 0.0592867461964488, 0.03812708625836032, 0.024241693218105605, 0.018989099355946695, 0.09248252492398024, 0.04083558092159884, 0.00821041367349348, 0.022875605450410928, 0.027945125475525856, 0.05016639755506601, 0.06989929173141718, 0.025058481443141187, 0.04488914573032941, 0.019774327220927392, 0.01949314909454967, 0.06877689303031989, 0.02841879889768149, 0.03352468839979597, 0.016137060609513094, 0.05823632649012974, 0.045408991764166524, 0.022997434716671705, 0.005365953739133796, 0.018380292292152132, 0.0584822411515883, 0.024138057172032337, 0.0273566727659532, 0.04415639915636607, 0.04940307280048728, 0.07429084501096181, 0.06706172613693134, 0.029931954041655575, 0.10066351307822125, 0.02394021162763238, 0.045011095436556, 0.051559351916824064, 0.03505719705883946, 0.0076641268263171825, 0.027213568034182702, 0.027388558822817037, 0.03451119350003345, 0.024438305525109172, 0.019998016467850124, 0.01812595022576196, 0.008752630158726658, 0.032616839078920226, 0.012272035237401724, 0.007837305078282952, 0.05460263236558863, 0.016398634162864516, 0.023819576583004425, 0.006610045151319355, 0.049930206300424676, 0.01031164578827364, 0.04710095954526748, 0.025070430444819585, 0.028538758799965893, 0.021422521011637788, 0.015246145826365267, 0.06343912945262023, 0.042312473457838805, 0.0498214066028595, 0.09362339334828512, 0.037532764220876355, 0.021764997991600206, 0.00659323699073866, 0.031105934974870512, 0.044318239936339, 0.07803436342094626, 0.03320057597011328, 0.03147118019738367, 0.07289333428655352, 0.016855924356994883, 0.053943785040506294, 0.06829236474420343, 0.024895622860640287, 0.04346194231350507, 0.018336774448731115, 0.03223680179300053, 0.05070755298116377, 0.01668869431263634, 0.03337319527885743, 0.052508764900267124, 0.06310582626610994, 0.04803251348701971, 0.01918161500777517, 0.06884982875947442, 0.017255566215940883, 0.06108304552201714, 0.029241507340754782, 0.02051343336435301, 0.03498427490038531, 0.06776669687990632, 0.05091404136536377, 0.02377101722439485, 0.014967615682897823, 0.05001591884398034, 0.040038736537098885, 0.007723640284634062, 0.03537110432184168, 0.03337259138269084, 0.04219937863360558, 0.009869648925294834, 0.026845701970160007, 0.05252874775656632, 0.046938674324857335, 0.012507621747707682, 0.017747916314484816, 0.025229899744902338, 0.05737898392336709, 0.016737464017101696, 0.02682452489222799, 0.08056348056665488, 0.043592322817338366, 0.029032118219350065, 0.05978181891675506, 0.01948369201272726, 0.030080437859786407, 0.048093958225633414, 0.018522475912634815, 0.05213219492829271, 0.023459303325840404, 0.05106158201981868, 0.06725717136370284, 0.039318305373724015, 0.04763396915846637, 0.04354398058993476, 0.0550597444442766, 0.04204527654552034, 0.035886383815003295, 0.0629290814644524, 0.07738493076924767, 0.033849818632006645, 0.029984547290951014, 0.07359789790851728, 0.09256407804787159, 0.017629265984786407, 0.000454698084338036, 0.057402990492326875, 0.07710531327341284, 0.018564880958625248, 0.033689453665699275, 0.10208226873406342, 0.04655084067157336, 0.03748741772558008, 0.014608436563451375, 0.02227365498297981, 0.046742730374847136, 0.03069932625762054, 0.024952504451253583, 0.0473210898760174, 0.03714031992214067, 0.005803748774009624, 0.02289955604023167, 0.04321830413703408, 0.04265028890222311, 0.05795290919819048, 0.026914340876308934, 0.013038542321217912, 0.07437686289527587, 0.03857422047959907, 0.011189347798270839, 0.014838012101660882, 0.003595207194198987, 0.047563079212393077, 0.04132831948144095, 0.03480217645743063, 0.007836858093339418, 0.043166365674031634, 0.032057909428008964, 0.009267270132633192, 0.06898808705487422, 0.0241216349282435, 0.06090964589800153, 0.032657340834183354, 0.041526455099561384, 0.11215933478836503, 0.019379782856308987, 0.04479122973446335, 0.03744727898655193, 0.020630970896620835, 0.04073960892856121, 0.00807634278732751, 0.021956287191382477, 0.049656488666577, 0.03947039221280387, 0.02135210095106491, 0.05362633243203163, 0.017314381631357328, 0.009901553641871681, 0.019069071493244598, 0.039804180551852496, 0.05618935597262212, 0.0716238631201642, 0.024599596691716994, 0.0421142258814403, 0.027549941591652374, 0.03415861652631845, 0.029347002572779144, 0.05278055549466184, 0.07970232463308743, 0.03357389236667326, 0.05726741919560092, 0.04213608827974115, 0.012459429646176952, 0.05503493381131973, 0.08419337150241647, 0.01453498175500759, 0.05645306182226964, 0.0019881665523696157, 0.005222944850434682, 0.013405785829360996, 0.013715963694266975, 0.019065402315131257, 0.039606326525764804, 0.029459276369639804, 0.01651497238448688, 0.020817445890445794, 0.06814861710050277, 0.06786874854671103, 0.015130548904250776, 0.0516873032652906, 0.011958976991341581, 0.026595500663721135, 0.02152646579114454, 0.095608990373356, 0.06248695483165128, 0.00763545702544174, 0.017902176161961894, 0.028731296504182473, 0.026789242767595818, 0.04560195694544485, 0.040931447741708586, 0.008144991023332944, 0.08990171019520078, 0.029747039678373506, 0.03095045206802232, 0.055917453419949324, 0.028540947075401033, 0.02721657564065286, 0.03909077222592064, 0.039855569401489835, 0.020744213302220618, 0.07587723274316106, 0.08226911404303142, 0.02897565732044833, 0.007963186046773834, 0.022508592644174184, 0.018540307812924896, 0.027017537570957626, 0.045447006688586304, 0.0432775300661368, 0.11605801380106381, 0.029651389989469732, 0.05217379251761096, 0.030578231505517448, 0.01908613834530115, 0.036304741366101165, 0.05169601226225495, 0.012840254032718284, 0.01261454784045262, 0.012912963300810328, 0.03859565540083817, 0.03817934024014643, 0.025048301721523916, 0.027834970404260924, 0.04512539466044732, 0.0213018520402589, 0.03815369500911661, 0.08996181482715265, 0.013853524794935115, 0.04017892187195165, 0.0033179174975625104, 0.025182007046948587, 0.07666514760681561, 0.026113871418471848, 0.07313791901937552, 0.1158578595412629, 0.19511742650398187, 0.1550473959318229, 0.12364136188157968, 0.16675139218568802, 0.07725317283932652, 0.2857498239193644, 0.09951354549931628, 0.1341602017304727, 0.08623213853154864, 0.16378969539489063, 0.21421018056571484, 0.11230054471109595, 0.1497307483639036, 0.1518037814114775, 0.10676458105444908, 0.10966993908264808, 0.10736866042550121, 0.10961976141801902, 0.14772149760808262, 0.2057078517973423, 0.1662758748446192, 0.12303130461701325, 0.14980553649365902, 0.14072528587920324, 0.08861144871584006, 0.14222446829080582, 0.08883571811020374, 0.09890751873276063, 0.17299065738916397, 0.15334102963762625, 0.2251536747706788, 0.1006987290456891, 0.12496388091572694, 0.19010692036577634, 0.07277999179703848, 0.1867299737142665, 0.12714022770524025, 0.1674126245613609, 0.1858638237629618, 0.17528278939425945, 0.23501543487821305, 0.13380152811961515, 0.10811048919068915, 0.1047567484368171, 0.10899858296449695, 0.0883600175646799, 0.1555676558720214, 0.17517339597855294, 0.1272322777658701, 0.11386361798005444, 0.10355301374303442, 0.0702727370496307, 0.1180257246430431, 0.14670175446995667, 0.10735380729394299, 0.12332680661763464, 0.07606814535600798, 0.11976490489074162, 0.07340497004666499, 0.09616964350321464, 0.17324087396264076, 0.09023020935377904, 0.09675308862434966, 0.11071652506611177, 0.12955725086586817, 0.0859939930960536, 0.08163945390177624, 0.18060261250606605, 0.13027486950159073, 0.10805329547396728, 0.09621180766927344, 0.16091234050691128, 0.2202977660511221, 0.08125731654997383, 0.2429137182022844, 0.11785097473434039, 0.12899064698389598, 0.07632252134914909, 0.15383473171719483, 0.15153436229697295, 0.17069062723645143, 0.08068367625985827, 0.14782295216407093, 0.07450372180236237, 0.11070201798741307, 0.09957780276558229, 0.16132278633969171, 0.09156859932201249, 0.0954761535727552, 0.11438917049339839, 0.18696796308670724, 0.14514492372316973, 0.1378973690526826, 0.09645069270793881, 0.13955132530203887, 0.10181519056537322, 0.08381215017288923, 0.14298676167215618, 0.14942026431007044, 0.13151149957307748, 0.12840496269719942, 0.10965823435357638, 0.13962338572101934, 0.1018242829346231, 0.149398198351264, 0.14084758503096445, 0.11987607606819697, 0.09098647055881363, 0.15490892050521715, 0.13129202063594544, 0.1095529460747327, 0.09979160914995841, 0.13079777572836193, 0.11247829374458108, 0.08574279943214995, 0.11149570039872612, 0.08370794755007539, 0.18428971751460008, 0.057448187709919045, 0.1239508959863867, 0.05929035600274801, 0.11252959777734109, 0.08862612542829343, 0.15102429395275457, 0.10136536256011043, 0.12503949685820512, 0.07831204709197793, 0.12980905521128858, 0.12499387216355119, 0.1483676800770419, 0.1076087803979005, 0.10220954833286149, 0.13158727836396011, 0.17858374012368067, 0.17622546452496732, 0.16914138251117297, 0.08485134690999985, 0.1620735310550247, 0.08718209434300661, 0.11186145112982818, 0.11671870334872178, 0.156159053423575, 0.13984552451542445, 0.12387526647320815, 0.11694975809327193, 0.16303439092423233, 0.12448916424598012, 0.17497534517730984, 0.1804029332207782, 0.13713968970945903, 0.18436070584825107, 0.09593188483268023, 0.15172051159398897, 0.14038740258131707, 0.09660348522343806, 0.10641540014850241, 0.14641979602830751, 0.1690068154462746, 0.15845882573298045, 0.061188116669654846, 0.20026384320642265, 0.16982552222907543, 0.06208763697317668, 0.1321324948221445, 0.11833658867648669, 0.14955730124243669, 0.19765448250940867, 0.1336396975176675, 0.12659024793122495, 0.11639770200209958, 0.21749028669936316, 0.13395816114331993, 0.180733162643654, 0.11766236914055687], [0.06859212794474193, 0.04433556632804019, 0.019637632948745574, 0.019912278479231254, 0.0700373396809612, 0.01910997019149363, 0.027236728130706718, 0.04466384835541248, 0.10121678374707699, 0.08645555297178881, 0.0675269365310669, 0.017801513795607855, 0.02307613968982228, 0.04785090358927846, 0.04021683840879372, 0.02000059829359608, 0.01970012772030064, 0.0323083024205906, 0.02862811168389661, 0.013763763941824436, 0.032786686572113206, 0.03642741031944752, 0.05215411839474525, 0.02878768276423216, 0.06585850712976285, 0.0716056376695633, 0.0717263761907816, 0.06045723945966788, 0.04307350137137941, 0.024047231867111156, 0.0323598642966577, 0.022404454482187117, 0.02622772959460105, 0.01669497924324657, 0.018290335512054817, 0.034385678092283864, 0.07332103526485817, 0.025775067009297863, 0.06009233011198895, 0.0172608282550105, 0.049316936172544956, 0.02837628698242562, 0.0188423525874636, 0.013287054923629122, 0.04536212195775338, 0.032011161757899184, 0.01883553500686373, 0.03466242538498981, 0.0381139430350491, 0.018220705944778662, 0.01080455822271428, 0.06872261022882802, 0.037700565930988104, 0.007306872201817376, 0.008789868160550083, 0.034935810536678345, 0.020138658117502928, 0.07609768198536974, 0.0387082447164825, 0.012536523098658239, 0.04612950774441872, 0.03477519790508917, 0.07791619654744864, 0.04410292720422149, 0.03975273741941367, 0.07017129606434278, 0.019920057883220058, 0.036528054026088545, 0.038848558972988806, 0.01087609532156161, 0.026741163472511938, 0.02728885827985193, 0.027663105965725014, 0.034783082482005866, 0.06509957928210497, 0.018333256244659424, 0.035789587401918004, 0.006922614428081683, 0.012544641770156366, 0.006110050083537186, 0.05126797540911606, 0.044342114190970144, 0.07134342459695679, 0.02332819170052452, 0.012537309351111097, 0.016311763020764505, 0.025169606819482784, 0.05036082158663443, 0.028662669472396374, 0.06598913190620286, 0.012745807047135063, 0.061397112240748744, 0.02501621549682958, 0.030047522126031772, 0.043083041573741605, 0.05840562776263271, 0.027697889367118478, 0.0063229120319842225, 0.056955469506127496, 0.008954505352968616, 0.011421024250531835, 0.008155820442230573, 0.057654414858136854, 0.03757397165255887, 0.0555328597713794, 0.06071491313299962, 0.018853740101414065, 0.03962096252611705, 0.01863178620780153, 0.05248926719650626, 0.0202901851651924, 0.05616097624546715, 0.0303916004486382, 0.010566904725107764, 0.0056353232357650995, 0.023611829516344836, 0.03994356182270816, 0.02726346580311656, 0.015933503496593664, 0.028627470468303988, 0.03866498810904367, 0.01749665310074176, 0.011682326389875795, 0.041752220663641176, 0.01752186576569719, 0.023364975083885447, 0.04598742590418883, 0.09972787435565676, 0.013580506900325418, 0.009537699416146746, 0.036444746889173985, 0.007117508345150522, 0.011628520259234523, 0.1155876668968371, 0.014892841123842766, 0.03955105984849589, 0.020612796336146336, 0.015480559319257736, 0.019128310993047695, 0.06147150003484317, 0.01376537885516882, 0.006992496749652284, 0.015376694267615676, 0.03910145915246435, 0.04345115360670856, 0.031322123017162085, 0.0316671105766935, 0.04545405327475496, 0.0468613281180816, 0.015966485387512615, 0.03627659573352762, 0.08124856344823327, 0.04381974400686366, 0.08286306288625513, 0.025911252380215695, 0.017623048907678043, 0.048063539500747404, 0.036369018988417726, 0.022636727197095752, 0.017874605587816665, 0.014497608046180435, 0.03301769721188715, 0.01345778111967125, 0.05120990638222013, 0.04745822858863643, 0.06807374754654509, 0.055033844762614796, 0.02916332653590611, 0.014119956659020057, 0.03876577430803861, 0.007283765539926077, 0.03253953358424561, 0.042386277711817195, 0.07785658724606037, 0.06972072845590965, 0.026667937669636946, 0.06311462007995162, 0.03796182905456849, 0.015790201989667754, 0.03218678358410086, 0.03731260335605059, 0.01950695219316653, 0.008260740615826632, 0.011445290359136249, 0.05438844260892697, 0.010742671588169677, 0.05738353689334222, 0.014676878694444895, 0.059388105757534504, 0.05915773633335318, 0.006173332379798272, 0.008748122989865286, 0.03429411657686744, 0.048428231717220376, 0.06851183689598526, 0.02183404062608523, 0.031268579818840535, 0.04973286796095116, 0.05707907823047467, 0.015401364104556186, 0.04630725338522877, 0.022839756749038185, 0.019575440125273805, 0.02256670068683369, 0.022431673914460198, 0.046955213615936894, 0.034217140171676874, 0.027013386632981043, 0.039057130459696054, 0.06813571136444807, 0.023215249546670487, 0.021027574615020837, 0.05527220054396561, 0.04946643100785358, 0.06120149738022259, 0.03923697616638882, 0.03173549672854798, 0.01580537572902228, 0.03758081807089703, 0.009537636651657522, 0.013464983768894203, 0.04353947851008602, 0.0524023468606174, 0.06548258515873126, 0.03516272282493966, 0.01955992202939732, 0.014250036062938827, 0.04285890110103147, 0.027773199968838265, 0.013780460144127054, 0.07811643901680197, 0.0015168925996736757, 0.04284409885959966, 0.018975971399673393, 0.022837643112455095, 0.02420797342035387, 0.06658162868448667, 0.06273575326693909, 0.03330912460972156, 0.019508450059220195, 0.08472301558192287, 0.021980872211445655, 0.03269528790510126, 0.061331491119095256, 0.028752266628933803, 0.01929907450851585, 0.03133776324934193, 0.05061041051521897, 0.02727965564866151, 0.06754007296902792, 0.027827665974785174, 0.0155855524353683, 0.04575836944526859, 0.007514096796512604, 0.0038230643424737665, 0.03684856682749731, 0.044381048530340195, 0.009119794787173825, 0.014383184989648206, 0.04118961674560394, 0.01796628923953644, 0.09359944106212684, 0.06414114178291389, 0.03850485045196755, 0.010536539434854473, 0.076739352196455, 0.02550172426604799, 0.04083055976246085, 0.026565154881349633, 0.07741874895457711, 0.03539419826120138, 0.029859578103891442, 0.022694937020008053, 0.034480544073241096, 0.042067895510366986, 0.03857911950243371, 0.026081713947600553, 0.04349632029022489, 0.02752710210292467, 0.017477007815614343, 0.04115577141887375, 0.005624259722286037, 0.027443905227950642, 0.013537004323942321, 0.036081276035734584, 0.02374465953159545, 0.03809723750288997, 0.056963415151195865, 0.04453997839508312, 0.022922867110797336, 0.020748752701495374, 0.02454711540069963, 0.030335621309599707, 0.04391826729157141, 0.030677087272384336, 0.059807230053203445, 0.007698930583761207, 0.015721313721899475, 0.025882862475035445, 0.0469245845451951, 0.038104219628231864, 0.035739453842065165, 0.058485674538782666, 0.06793552317789622, 0.10113777512950556, 0.011892355030535586, 0.03769515461421438, 0.06740525484617267, 0.009727173534754132, 0.042155538486050706, 0.06614130016948495, 0.023322064529306123, 0.03730353134285126, 0.08441009558737278, 0.007859045340280448, 0.001994580828717777, 0.06197791786066123, 0.011836409818248024, 0.04415760016334908, 0.030211218699280704, 0.04467504079054509, 0.012755847669073513, 0.021696913787829022, 0.020665454046268548, 0.02846533791827304, 0.030006535218230317, 0.02313325707135456, 0.05227273988670536, 0.02803847153804132, 0.057312874256500175, 0.02596403901199145, 0.01659693941473961, 0.04163330061627286, 0.011557244396369373, 0.02522326197608241, 0.007216428572844181, 0.004715485473362995, 0.04016258614137769, 0.01980389268802745, 0.038528551680168936, 0.04605807497033051, 0.0028366281559491263, 0.019844638715897287, 0.06847021555794136, 0.08406590191381318, 0.0117557837428259, 0.03065897717273661, 0.03601663539718304, 0.018153683648311665, 0.01572525770669537, 0.05836499708571604, 0.04629656985136015, 0.15230141899415425, 0.11157699567931038, 0.09233113697596959, 0.11151209380477667, 0.1210772730410099, 0.07704634858029229, 0.07812745164015464, 0.18278399402541773, 0.12152072281709739, 0.13309912223901066, 0.09929137277816023, 0.11227138806134462, 0.09501073283276387, 0.1370465811342001, 0.113383201616151, 0.16973307861813478, 0.12735495689724172, 0.09011764717953545, 0.11997352726757526, 0.0762041305590953, 0.08586922407682453, 0.16412194685212203, 0.16718418896198273, 0.1281896499650819, 0.14007248090846197, 0.1630582617861884, 0.13403434705521378, 0.09232136607170105, 0.0497183880236532, 0.11923952879650251, 0.13536167011729308, 0.10284918972424098, 0.13847306530390466, 0.14232440292835236, 0.08050885849765368, 0.1060082587812628, 0.173318566222276, 0.1138977347207921, 0.13936888080622467, 0.13532137870788574, 0.1109089372413499, 0.19888051386390412, 0.10874154032873255, 0.0735345838059272, 0.13845061936548778, 0.1361605908189501, 0.11759575057242598, 0.14987956466419355, 0.10112125280180148, 0.10983837861567736, 0.1506284773349762, 0.10133691837212869, 0.12137665626193796, 0.053660608628498654, 0.10877509388540473, 0.1349073230688061, 0.05695242966924395, 0.12007256623889719, 0.11217823198863439, 0.15223086492291518, 0.13893493052039826, 0.12380047834345273, 0.24258918847356523, 0.07506645803472825, 0.14988785636212143, 0.08674908722085611, 0.11829693508999688, 0.141782280589853, 0.08791853554014649, 0.10418242282633271, 0.09404475680951561, 0.11720251238771848, 0.17524233513644763, 0.1751802491822413, 0.15118560886808804, 0.13160695587950094, 0.10152139847299882, 0.13747171046478407, 0.10206991261137383, 0.0975277042016387, 0.1245683492826564, 0.10992918695722308, 0.14463993082089083, 0.11336664536169597, 0.1024258177993553, 0.15513457411101886, 0.132823949147548, 0.11104993681822505, 0.20180643828851835, 0.15199985089046614, 0.09396332582192761, 0.15849161254508154, 0.12573789938219956, 0.1853357742407492, 0.08888452513409512, 0.09511712033833776, 0.10051357719515051, 0.1641410815396479, 0.1527012661099434, 0.17603271986757005, 0.1096678152680397, 0.10443308044757162, 0.12013938836753368, 0.122686432408435, 0.08859187298055206, 0.11571938411465713, 0.10862116821642433, 0.10177379992923566, 0.13150569131331785, 0.11968513631394931, 0.07921782348837171, 0.11508105908121381, 0.11642366275191307, 0.061866916316960535, 0.07980358241392033, 0.13817246071994305, 0.10253694826470953, 0.23011462071112224, 0.12184389547577926, 0.17929157428443432, 0.0791550250723958, 0.1222808448863881, 0.06471536561314549, 0.12283013255468436, 0.14392711621310028, 0.13398455615554536, 0.17285864161593573, 0.18091825342604093, 0.11971275268920831, 0.08317415762160506, 0.09929114886160408, 0.17731831302600248, 0.0723755984966244, 0.18207588845065661, 0.10839006597442286, 0.12361945877117769, 0.12308280542492867, 0.1510864341897624, 0.12524330163640635, 0.1611079621527876, 0.2048370335251093, 0.08017147731568132, 0.13030467075960978, 0.09239153337797948, 0.11732612789741584, 0.10678855369665793, 0.08461572562477418, 0.10410406560237918, 0.2071575147232839, 0.12724130228161812, 0.08265456264572484, 0.15520675666630268, 0.09597189804272992, 0.17758443446031638, 0.12461185694805213, 0.05195862227784736, 0.08766584909920182, 0.07651091659707682, 0.06809696022953306, 0.10539039157863174, 0.06347952942763056, 0.15878906872655663, 0.07751187110053641, 0.09124553522893361, 0.14155912399291992, 0.09434494070176568, 0.10503117513975926, 0.14882912460182393, 0.15715028452021734, 0.1162543682647603, 0.0961560999442424, 0.10391701385378838, 0.18243994962956223, 0.09967330656945705, 0.17414921522140503, 0.11758116206952504], [0.018966673773580363, 0.018142180783408027, 0.013413041065047895, 0.01973755401559174, 0.022849390249965445, 0.024234889208206108, 0.041504718230238984, 0.06269601147089686, 0.0439881563984922, 0.055874244309961796, 0.033644110563078096, 0.07905079530818121, 0.07331988854067666, 0.028583121419485127, 0.03480355727619358, 0.023355809772121053, 0.026411778825734342, 0.0510978666799409, 0.04377076395654252, 0.03139006133590426, 0.03106273604290826, 0.023327204432072382, 0.012050011793949773, 0.029645700473338366, 0.03632904649046915, 0.029751534972872053, 0.021506925678945014, 0.023187287118551985, 0.017890183055507283, 0.04553494143432804, 0.01842643945877041, 0.042825439146586826, 0.03231915898088898, 0.05041986770395722, 0.03114940532084022, 0.03239134492884789, 0.0332191406882235, 0.025609416255195225, 0.02581352976682995, 0.012371060638023275, 0.06681862061044999, 0.03204575347314988, 0.045611802488565445, 0.02955493962924395, 0.03614542134372251, 0.021138162252360156, 0.048537428357771466, 0.008747510612010956, 0.06990587352109806, 0.024088481707232337, 0.08925273216196469, 0.06460044892238719, 0.04247680106865508, 0.010163122954379235, 0.04311781310077224, 0.013683109876832791, 0.053584266653550525, 0.027861345060435787, 0.014999422011896968, 0.03337410112310733, 0.03729254586089935, 0.016887410078197718, 0.0669462326914072, 0.020764029917440245, 0.060088421750281534, 0.05187773072559919, 0.0543359681032598, 0.050492016332490106, 0.04720992209123714, 0.013957548454137785, 0.03730272049350398, 0.04662987982322063, 0.0195520985206323, 0.040180909979556284, 0.02413430487337921, 0.03370565029659441, 0.047461685724556446, 0.004481452808249742, 0.043640620939965756, 0.02806542464531958, 0.0473469963430294, 0.0375115532161934, 0.023855635630232946, 0.02770264250492411, 0.027891314255871942, 0.02518308422129069, 0.013833955844997295, 0.018100890231185725, 0.026756578091798083, 0.0743207209078329, 0.01912788860499859, 0.05005714323903833, 0.014241403401164072, 0.011611036956310272, 0.013599918939040175, 0.04597299685701728, 0.03169403484623347, 0.04955600780834045, 0.021006429767502204, 0.016174030590004156, 0.048372205080730576, 0.04469008730458362, 0.03257945519206779, 0.05130868751023497, 0.026978433597832918, 0.08829877299389668, 0.002913109230576083, 0.05459358749379005, 0.07538921678704874, 0.01545837800949812, 0.02503517037257552, 0.047299844944583516, 0.030299112732921327, 0.029141145226146494, 0.04331371294600623, 0.015257523162290454, 0.050109587210629664, 0.06348735293639557, 0.019193333307547227, 0.050866666050361733, 0.048124699254653285, 0.0699608348576086, 0.023586621940402046, 0.03425776406324335, 0.03284485737926193, 0.037065413048756976, 0.04736214802999582, 0.01106570175449763, 0.026095199831096188, 0.0323917927619602, 0.06242208688386849, 0.03720620906512652, 0.03342583941827927, 0.043278276454657316, 0.06516243198088237, 0.03430511562951973, 0.07236301845737866, 0.03981683522995029, 0.03845498491344707, 0.0189371371442186, 0.041815751897437234, 0.0761519715722118, 0.034859203933072944, 0.043684508584971936, 0.03647552863029497, 0.029014873251851116, 0.02786443069843309, 0.02621805029256003, 0.03454125599403467, 0.035899550787040165, 0.04570607814405646, 0.0313692540595574, 0.01266056438907981, 0.02223107182154698, 0.039182415165539296, 0.007841358476850604, 0.04237093942772065, 0.039286763673382144, 0.012372949509881437, 0.044213446988058944, 0.058198457450738976, 0.011255282742370452, 0.014606875932908483, 0.028812279658658162, 0.028177505059699928, 0.029115143764231886, 0.02871947981683271, 0.015137429249339869, 0.03295717528089881, 0.011862245039083064, 0.029148978912936788, 0.03288587821381433, 0.008376508868033332, 0.0055411417270079255, 0.05058758120451655, 0.03108761113669191, 0.04072931894500341, 0.029369618144950697, 0.03359197871759534, 0.017394648931388344, 0.01463876707878496, 0.026095676501946788, 0.07991602923721075, 0.05668865257341947, 0.02771176371191229, 0.029010439025504247, 0.01267277293040284, 0.038603071788592, 0.04794100625440478, 0.05877870667193617, 0.019933068792202642, 0.061581476990665705, 0.017409010125058036, 0.029026130147810494, 0.02838977286592126, 0.027186974550464323, 0.008602450851217976, 0.029984184274716035, 0.04626771514969213, 0.04468509328684636, 0.050909698741244416, 0.06655393088502543, 0.04170357648815427, 0.009204847455423857, 0.021140613460115025, 0.03463686497083732, 0.013889032532460988, 0.038360139288540394, 0.04811948471303497, 0.0306623460991042, 0.055340661334672143, 0.06173947386975799, 0.01596060927425112, 0.015773727159414972, 0.026265551136540513, 0.02032244441631649, 0.03915620335776891, 0.014816602625484978, 0.0038780333125032485, 0.05380087199487856, 0.020147283993927494, 0.01946846568690879, 0.030760872776487043, 0.02723025999564145, 0.04191255170319762, 0.028565299697220325, 0.055880059355071614, 0.047831945320857425, 0.06907204897808177, 0.06802080145903996, 0.08550861664116383, 0.039141519859965355, 0.052300264659736834, 0.03852187150291034, 0.030173434476767267, 0.03618097657869969, 0.06886003392615489, 0.05540896266964929, 0.06786659080535173, 0.05026852725339787, 0.06175290207777705, 0.03435279628528016, 0.024753744580915997, 0.005591824476141483, 0.08446222743285553, 0.052549585566989014, 0.030964511313608716, 0.07619421037712268, 0.08096389765185968, 0.0445034392843289, 0.025598824323554124, 0.0579529499102916, 0.01827485134292926, 0.02339713255475674, 0.05163526641471045, 0.0493323253467679, 0.023614596242883375, 0.017965488568214432, 0.020940961316227913, 0.0276211928576231, 0.030085635438029255, 0.0371048121846148, 0.020860219041683843, 0.024969084454434257, 0.057397697919181416, 0.12242445003773485, 0.0590155493201954, 0.05864014982112816, 0.038595020970595736, 0.016178072962377752, 0.02478575107774564, 0.02097806870006025, 0.019676996461514915, 0.029085003238703524, 0.020032691303640604, 0.02608580212108791, 0.010471271999579455, 0.10516619003776993, 0.05143966851755977, 0.029918770106243234, 0.013362612342461944, 0.036236192365842204, 0.03876031210113849, 0.03161636972799897, 0.031506620081407685, 0.031210917912955796, 0.05280568164640239, 0.0393982876890472, 0.06071260611393622, 0.026022708542378883, 0.040757427258150916, 0.06842670789254562, 0.019004956719332507, 0.05937267587121044, 0.012796678513820683, 0.024524627053844075, 0.007206133500273738, 0.09065024288637297, 0.045439746363886764, 0.058702832886150906, 0.02915308065712452, 0.008287122057351683, 0.02884107329217451, 0.012132435987171317, 0.02096192804830415, 0.03106959942462189, 0.07454582490026951, 0.06342131112303052, 0.06500459116484437, 0.07832658809742757, 0.014296982204541564, 0.045516451355069876, 0.006793806853238493, 0.03182733305064695, 0.06803260118301425, 0.03240698855370283, 0.017183078319898674, 0.05463858793622681, 0.021660615557006428, 0.029144313984683583, 0.027657068700396588, 0.027712869723992686, 0.01683410775980779, 0.034016514330038, 0.013491579797118902, 0.01177928819587188, 0.05573920227055039, 0.09266655719173805, 0.044760217291436026, 0.009393942442589572, 0.10592449363321066, 0.036736510161842616, 0.07305626411523138, 0.005982479562849871, 0.030951849850160734, 0.013824945748118418, 0.03661384799384645, 0.03168586867728403, 0.03341887764898794, 0.006784603373879301, 0.021327543072402477, 0.010158645471424928, 0.024428878977362598, 0.02537424280308187, 0.04562790412455797, 0.043357797366167815, 0.021863416103380065, 0.04204251490799444, 0.04955192642020328, 0.02976014218958361, 0.04598334451605167, 0.008204384041684014, 0.16891788664673055, 0.12159616234047071, 0.13826985763651983, 0.07855243169303451, 0.0862501739923443, 0.09692430336560522, 0.17380726071340696, 0.1510591163699116, 0.22141186626894133, 0.1834925745746919, 0.11405142290251595, 0.13935507940394537, 0.12815097346901894, 0.12322916542845112, 0.08959168754518032, 0.10053550066160304, 0.09898382678095784, 0.07839162567896502, 0.08909095584281854, 0.0819877323561481, 0.1422105583229235, 0.2165402833904539, 0.13797910538102898, 0.11666015934731279, 0.12654754093715123, 0.15586805689547742, 0.09960429277271032, 0.09945980552583933, 0.14200089100216115, 0.10557289035724741, 0.1311468141419547, 0.1812409103981086, 0.08701123922531094, 0.15081800573638507, 0.1358609768961157, 0.13433082614626202, 0.20753986920629228, 0.07995811876441751, 0.13248264603316784, 0.16370535349207266, 0.1552044360765389, 0.15480517250086578, 0.18204515081431183, 0.13611111204539025, 0.06783564960850136, 0.08868152781256608, 0.18860201111861638, 0.12977158650755882, 0.1716036775282451, 0.11894699877926282, 0.13394346407481603, 0.09418793448380061, 0.1698663971785988, 0.12372810579836369, 0.20241880257214817, 0.08310161544276135, 0.13648703401642187, 0.1643227253641401, 0.11521758032696587, 0.10309613575892788, 0.16184627610657895, 0.09425211032586438, 0.14293363238019602, 0.12958470439272268, 0.16699570550450257, 0.09803424416376011, 0.1501996839152915, 0.09325626519109521, 0.14235537126660347, 0.13413029190685066, 0.1481417686279331, 0.08851976506412029, 0.13385810436947004, 0.13605583858277115, 0.11182314782802548, 0.1227085255086422, 0.1608458576457841, 0.08726269751787186, 0.12400228822869913, 0.10888947453349829, 0.10702406641628061, 0.07140414669577565, 0.11814849876931735, 0.16945340005414827, 0.08653453444795949, 0.09672708037708487, 0.08286133262195758, 0.07581921121371643, 0.06984921584704093, 0.18310228123196534, 0.11390016387615885, 0.10227753075637988, 0.13821150362491608, 0.07325110544583627, 0.18954388557800225, 0.1520054420190198, 0.12629507162741252, 0.13338530116847583, 0.1111393134508814, 0.13620777614414692, 0.12136999304805483, 0.15306264029017516, 0.13181342051497527, 0.11913515653993402, 0.05714298944388117, 0.22145777594830307, 0.11405788255589348, 0.13898535924298422, 0.1163558228207486, 0.10185647942125797, 0.10047418823731796, 0.0858242032783372, 0.1378159448504448, 0.13755043409764767, 0.13274789894265787, 0.13884482106992177, 0.1257809999265841, 0.123283448229943, 0.11112934577145747, 0.06578215836946454, 0.12923991360834666, 0.30752607541424887, 0.15668132182742867, 0.14318137908620493, 0.10928035141634089, 0.09596019331365824, 0.15671689063310623, 0.0804654797539115, 0.07823568476097924, 0.06902321481278964, 0.18028205899255617, 0.11326966913683073, 0.12878347667200224, 0.1714328359812498, 0.14800161043448107, 0.10002002439328603, 0.15014485828578472, 0.07179279798375708, 0.18357600724058493, 0.06591428949364594, 0.110410166505192, 0.24960798184786523, 0.1326434724032879, 0.12358440565211432, 0.08495045373482363, 0.09454556315072946, 0.12253019293504101, 0.13772404406751904, 0.1935417324836765, 0.11392125274453845, 0.12036762040640626, 0.19086735456117562, 0.17471294211489813, 0.10844674400453057, 0.11401091436190264, 0.1348454135337046, 0.1481782059584345, 0.08534952732069151, 0.05871239344456366, 0.0994151375655617, 0.1285859958401748, 0.07176435379577534, 0.16537400680993283, 0.12148786815149443, 0.10409416577645711, 0.09653103125414678, 0.09256328416189977, 0.09311930289758102, 0.06499754118600062, 0.08884855599275657, 0.14721708824591978, 0.120897094852158, 0.13556399568915367, 0.11272445946399655, 0.08172579069754907, 0.10117433459631034], [0.022627156460657716, 0.031003961339592934, 0.021743807342967818, 0.11237984509872538, 0.044446303243083615, 0.0478092143977327, 0.02677395537362567, 0.025722036104915396, 0.03290729277900287, 0.02722143564772393, 0.02089954862770225, 0.0375345487679754, 0.002414786327530497, 0.03570387146568724, 0.0263107161237193, 0.011545840767212212, 0.08153016226632254, 0.024188574104170715, 0.047829081903078725, 0.03311951817678554, 0.0046344043553939885, 0.020649617038933293, 0.005378182636507387, 0.05396334720509393, 0.03627800030101623, 0.04546629065381629, 0.07568868821752922, 0.02865185701687421, 0.01613071291441364, 0.02294424774923495, 0.035318975869034014, 0.026563300784411173, 0.029124646647168056, 0.043361352889665535, 0.04497355209397418, 0.027974857183705484, 0.011567346934628273, 0.03998436552605458, 0.05796779625649963, 0.03913070061909301, 0.04392132409183042, 0.03409375536388584, 0.06891597235309226, 0.022981294064915607, 0.049476768488862684, 0.04752940012674246, 0.02845123965692307, 0.026095815601625612, 0.03626173581661923, 0.03524745827806847, 0.0021781336690764874, 0.054122914892754385, 0.029458533373794386, 0.03743046149611473, 0.033658478542097976, 0.037540017760225704, 0.06531105829136712, 0.05392018898523279, 0.048086195785020075, 0.07985774986445904, 0.028692881244101694, 0.01590467423998884, 0.04643655501838241, 0.028641173483005593, 0.0399351581665022, 0.026807089934923818, 0.01644133267525051, 0.03893123846501112, 0.006654699964980994, 0.027914262310202633, 0.03689570126256772, 0.007386449092466916, 0.033746813623500724, 0.055894352695239444, 0.03885064546817115, 0.041120915074965785, 0.08057386215244021, 0.056865444872528315, 0.08228940902543919, 0.032065641334546466, 0.03937719203531742, 0.037946612906775305, 0.009241881048572915, 0.016625984106212854, 0.06547883964542832, 0.05780012346804142, 0.05724620819091797, 0.08320627946938787, 0.026394001208245754, 0.025157021691224406, 0.023417815998462693, 0.035158322525343726, 0.0457430040197713, 0.05713482666760683, 0.015478832447635276, 0.057607439878795824, 0.011867558816447854, 0.01498115245651986, 0.03174515228186335, 0.022080740691827874, 0.05147769362000482, 0.02672570474844958, 0.026609617584784116, 0.03859155365665044, 0.02172545636338847, 0.07305703764515263, 0.050587662628718784, 0.039552359243056605, 0.03985962704090135, 0.007750467862933874, 0.030653810128569603, 0.02632875328085252, 0.018069446918421557, 0.08280278862054859, 0.027114172831975987, 0.005534375036534454, 0.03131999580987862, 0.028315198474696705, 0.001982293831783214, 0.03603496941338692, 0.05979693667697055, 0.0301172415991979, 0.10045768626566444, 0.026504958647170236, 0.04854060050898364, 0.015410441206768155, 0.04041074675374797, 0.04632216079958847, 0.034467000514268875, 0.05058835134176271, 0.03137292832668338, 0.036614499387464354, 0.0361724881056164, 0.033368862832763364, 0.021000931937513605, 0.04452734746571098, 0.05389749198885901, 0.06670358856873852, 0.044732024161411185, 0.03701002084250961, 0.011445311563355582, 0.027140323571594696, 0.016369396088910953, 0.04701963033793228, 0.02523707186004945, 0.0387482579265322, 0.022376992473644868, 0.013856037919010435, 0.024886415140437226, 0.037460123654454947, 0.02483378626805331, 0.042413235908108096, 0.03232219542509743, 0.008169073927482324, 0.015743769838341644, 0.008805923147260078, 0.07323292070733649, 0.047521451088998995, 0.02773782963465367, 0.06669859455100127, 0.04494048708251544, 0.05242000912715282, 0.019507115041571002, 0.025487754926351563, 0.020507385920999304, 0.08281260023691825, 0.02459532192109951, 0.06393579673022032, 0.0528999098044421, 0.029058330027120452, 0.09451076787497316, 0.03759108430572918, 0.017135343381336758, 0.025150078581646085, 0.02583740232512355, 0.04892541468143463, 0.03355291884924684, 0.045802172273397446, 0.04711521556600928, 0.03022996322917087, 0.09823688864707947, 0.007653047197631427, 0.05145890498533845, 0.02535313188231417, 0.013255763433075376, 0.024963534037981714, 0.04032719195155161, 0.025569664281127707, 0.021904762634741407, 0.02437537140212953, 0.0316477316165609, 0.006595532135439238, 0.02571723886233355, 0.04995928152597376, 0.08679405373654195, 0.01810117012688092, 0.012961316554407989, 0.021388263474883776, 0.01822035649924406, 0.04052248790061899, 0.02839824098295399, 0.013267607261825885, 0.06427412786121879, 0.03327439379479204, 0.08644939187381949, 0.017561894242784808, 0.02657841006293893, 0.04445534811488219, 0.015963272524199316, 0.04037198204813259, 0.014923234403665577, 0.028491587045469453, 0.019241483848808066, 0.048341389412858655, 0.024126954642789702, 0.010635587736032903, 0.02248941724454718, 0.002715673775778019, 0.04798751982993313, 0.0561312326629247, 0.042635815750275335, 0.16132052003272943, 0.03248897933268121, 0.06699328230960028, 0.10041388683021069, 0.030425299890339375, 0.008477223820851316, 0.019518351581479822, 0.020905400992238095, 0.033514164321656735, 0.04225365464974727, 0.02496702510065266, 0.06553297316921608, 0.018032142759433815, 0.030138876688267504, 0.05600555779944573, 0.06372490804642439, 0.03304746115048017, 0.07140269463083573, 0.06856027072561638, 0.07383693901023694, 0.006220870119120393, 0.018903497074331557, 0.018029827258682678, 0.008837776125541754, 0.021960801145594035, 0.06952613139791147, 0.01793550749841545, 0.01756431152378874, 0.046243182716092894, 0.04666007463155048, 0.06613247242889234, 0.045618669262954166, 0.008640722770776068, 0.022582161107233593, 0.03258604037442377, 0.05450461458946977, 0.005333380241479192, 0.05250080229182329, 0.048393409300063334, 0.04037793280024614, 0.025884589346657907, 0.01807388453744352, 0.039577817876956294, 0.05362221711714353, 0.06037966255098581, 0.04686265126136797, 0.04054817384374993, 0.0266456460979368, 0.03425701767472284, 0.031756008842161725, 0.03377610258758068, 0.04469131545296737, 0.0064129752572625875, 0.03797630559919136, 0.030504970079553977, 0.04086227109655738, 0.05644952326214739, 0.05536660851378526, 0.02794127139661993, 0.03894627819369946, 0.05484178542558636, 0.015479170018807054, 0.023830860620364547, 0.10465845585401569, 0.017098180018365383, 0.02140685703073229, 0.015045419900811144, 0.03729666796113763, 0.04608075161065374, 0.026333477580919862, 0.0360196684487164, 0.05748506608818259, 0.056836094840296676, 0.018821791280061007, 0.037275382317602634, 0.03209858760237694, 0.09484588274998323, 0.006021609405122165, 0.017359310827617134, 0.02529448440431484, 0.06686790939420462, 0.040747754741460085, 0.05327402687232409, 0.060112930435155115, 0.04839448817074299, 0.011488725930186254, 0.027531475261119858, 0.027261774554582577, 0.012111711831364249, 0.02282764489895531, 0.018926183892680064, 0.06967576872557402, 0.04075937465365444, 0.007892315608582326, 0.03616513617868934, 0.0412514346784779, 0.056076973610158475, 0.01975494995713234, 0.022788352632362927, 0.04472130670079163, 0.02560322462315006, 0.1278088018298149, 0.030417849575834613, 0.012303743178823164, 0.007727394279624734, 0.03953011686514531, 0.03396212974829333, 0.008650207842167999, 0.037600220779755285, 0.05952851500894342, 0.0158165359337415, 0.04499274445697665, 0.01782408356666565, 0.06432081785585199, 0.014943352966968502, 0.07396303795810256, 0.015401772921904922, 0.010333129903301597, 0.06341073276208979, 0.02434906629579408, 0.036206693055906465, 0.025732751869197403, 0.016821229165153842, 0.03259217093831726, 0.0431911830923387, 0.062508885083454, 0.03428181812965444, 0.023380045346649628, 0.07127361691423825, 0.019340239531759704, 0.025131320481055548, 0.1614782251417637, 0.1424396860280207, 0.09842945688537189, 0.2247673169310604, 0.19433385426444666, 0.16971406606691225, 0.11059065682015248, 0.1453755713467087, 0.08117502382291214, 0.07228818961552211, 0.12575098153735909, 0.14993095690650599, 0.07041648469333138, 0.12498885100441319, 0.23378736791866167, 0.1543140895664692, 0.16948116570711136, 0.08243533476654973, 0.1785715672054461, 0.09581586891519171, 0.05590169444414122, 0.10404963352318321, 0.11295539207224335, 0.1024789335206151, 0.09121219201811723, 0.10174762883356639, 0.11567468222762857, 0.1308604045105832, 0.14556736605507986, 0.0882323512009212, 0.17908101129744733, 0.1832936281072242, 0.10700605809688568, 0.1440491575215544, 0.19894284409071716, 0.11866922011332852, 0.08220252261630126, 0.1096008438616991, 0.11292282239134822, 0.14715635936175073, 0.14789639679448946, 0.07911463188273565, 0.16783331627292292, 0.20409126925681317, 0.10759594251534768, 0.24351012334227562, 0.07835515442171267, 0.1364800858178309, 0.30816948946033207, 0.11838992152895246, 0.056358786166778634, 0.07496295430298362, 0.1424557130251612, 0.13229477325720446, 0.11505508476069995, 0.22649910114705563, 0.14029508110667976, 0.09269054340464727, 0.09634659865072795, 0.12481039629450866, 0.15204162150621414, 0.09175899624824524, 0.19738431700638362, 0.18616685750229017, 0.14772643734301838, 0.09561861878527061, 0.10583089651273829, 0.16006848721631936, 0.06621044967323542, 0.0818220612459949, 0.18315960387034075, 0.08797518642885344, 0.13445612442280563, 0.16728100233844348, 0.12145086085157734, 0.12230259871908597, 0.13945152637149605, 0.11853229174656527, 0.13051132538488933, 0.09441207495651074, 0.11144724621304444, 0.0769146110064217, 0.10439991365586009, 0.11172194432999406, 0.16612704497362885, 0.15248082365308488, 0.193574315735272, 0.19249121099710464, 0.11064360290765762, 0.12348650661962372, 0.09217867694262948, 0.19967900030314922, 0.08992594068071671, 0.1570501056100641, 0.1450959334948233, 0.20352712167160852, 0.17901167858924183, 0.1377923996852977, 0.10772943070956639, 0.07287161438060658, 0.2346730732492038, 0.11568327248096466, 0.08582617102989129, 0.16605716943740845, 0.10992871876806021, 0.12017806486359664, 0.10425575889114823, 0.23488968876855715, 0.18329917852367672, 0.07643442534442459, 0.1036427364285503, 0.07755945676139422, 0.1116727301850915, 0.11699726911527769, 0.1167714526610715, 0.07619599492422172, 0.245812148387943, 0.15139169352395193, 0.08139830255614859, 0.1374823363231761, 0.11968745690371309, 0.1360315741705043, 0.17750326810138567, 0.08115105796605349, 0.09392162984503166, 0.17122212371655873, 0.1591329231326069, 0.10173344745167665, 0.18961034129772866, 0.0928315022694213, 0.17108054059956754, 0.08478405659220048, 0.15730950954769338, 0.0972073067511831, 0.1038730244285294, 0.12658514534788473, 0.2514715918472835, 0.1616885167147432, 0.08925408923200198, 0.14700556173920631, 0.09515617002866097, 0.12514238990843296, 0.11074175299810511, 0.08934297053409473, 0.08429097197949886, 0.040665777533182075, 0.19933317814554485, 0.09984077579740967, 0.0479592215269804, 0.06900686211884022, 0.06369231800947871, 0.1360219254025391, 0.13898480284426892, 0.1103800463357142, 0.14147216294492992, 0.06173352311764445, 0.23160867339798383, 0.10593224250312362, 0.18576099856623582, 0.13907074608973094, 0.20240190705018385, 0.14997930931193487, 0.10364838183990546, 0.16157568991184235, 0.10393348189869098, 0.14422037904816015, 0.09566154291055032, 0.16796142368444375, 0.0944444750036512, 0.0936173340305686, 0.16690764522978238, 0.0922825335125838, 0.08250220439263753, 0.177204481991274, 0.09329146080251251, 0.15504857658275537], [0.015552127800349678, 0.07590400773499693, 0.07043278310447931, 0.06474566220172814, 0.03129947691091469, 0.0846554742061666, 0.0319468909209328, 0.030776204275233403, 0.032512276832546504, 0.05187863656984908, 0.10030266815530402, 0.019271656604749814, 0.03788689843245915, 0.014716910564207604, 0.033789785246231725, 0.03553764734949384, 0.04563328151458076, 0.02431050006167165, 0.018924933691908206, 0.01658666809089482, 0.04841057623603514, 0.012757131796596306, 0.00961926271806338, 0.028605920196111714, 0.0028185668260058655, 0.04537944495677948, 0.03828352250690971, 0.008531112223863602, 0.027098133960472684, 0.02594455487893096, 0.08045013129178967, 0.029622460648949658, 0.03617071034386754, 0.023857462585770657, 0.03276355531332748, 0.051542279975754876, 0.04449298305969153, 0.007950287096069326, 0.03815245668270758, 0.030187456402927637, 0.037436978824968846, 0.033770477532276084, 0.026169451918186884, 0.029484046290495565, 0.023162298370152712, 0.0057682669056313375, 0.05184512711795313, 0.029875384577150856, 0.008838832095664526, 0.0390995796104627, 0.050621016017560444, 0.006355177644374115, 0.12277540192008018, 0.02283811130161796, 0.01967821443187339, 0.0402295032649168, 0.02600154503514724, 0.05695143900811672, 0.08305006035204444, 0.018827719979786446, 0.04438767781747239, 0.005112500977702439, 0.024596015723156076, 0.0488841631449759, 0.027577252626152973, 0.021425784765077487, 0.027478383288585713, 0.043258707504719496, 0.050340238226843734, 0.02599530590565077, 0.04112857234265123, 0.04511165771899479, 0.07223762518593244, 0.02032176757763539, 0.0076517198135011965, 0.03304982923769525, 0.00577795977837273, 0.01555959677456745, 0.0043134250611599, 0.0327514468559197, 0.020110083311530094, 0.039951263195169825, 0.024252487013914754, 0.014364323412467326, 0.014069272637633341, 0.03188595847625818, 0.034342146678162475, 0.08747900769646678, 0.08792013688279049, 0.006990431882773659, 0.03264079475775361, 0.026095272773610692, 0.04292777240542429, 0.024613426931734596, 0.06182336115411349, 0.02339468982868961, 0.01585198599579079, 0.0705682390502521, 0.04747959226369858, 0.05602941169802632, 0.07004313437002045, 0.04896485452939357, 0.06904063959206853, 0.05897849452282701, 0.015440924392480935, 0.06975467556289264, 0.07118924108466931, 0.0843763927529965, 0.050238441010671, 0.04056331535269107, 0.02307591407692858, 0.03951164035658751, 0.05039428014840398, 0.040738753974437714, 0.04202420464051621, 0.01610815162504358, 0.03356129875672715, 0.02397825030077781, 0.08466257846781186, 0.045678251422941685, 0.05254670518583485, 0.012604216296624924, 0.02552552897083972, 0.014088068057649901, 0.033480098471045494, 0.019432477885857224, 0.02172777695315225, 0.005558491019265992, 0.09049357593591724, 0.041564337709652524, 0.04572672935734902, 0.013514052876936538, 0.02929489447602204, 0.02638321419778679, 0.06676787297640528, 0.007955674664117396, 0.010232819526988481, 0.030362023107175316, 0.029739640253995146, 0.025974086419280087, 0.007189265967878912, 0.004917644804144012, 0.03483006424669709, 0.021141707597832595, 0.034632003267428706, 0.01748766590441976, 0.035313615442386696, 0.011666727717965841, 0.034243667498230934, 0.05394750001973339, 0.03283430276704686, 0.04109021815072213, 0.018783964649108902, 0.06380895817918436, 0.05751553909587009, 0.02334023908978062, 0.039650967344641685, 0.05290730922882046, 0.042783437828932486, 0.031169774942100048, 0.027785189682617784, 0.020703428258587207, 0.04878454402621303, 0.10840584191360644, 0.0433596124473427, 0.05054886738902756, 0.024776811378874948, 0.01543446134642831, 0.023149767524695823, 0.06564920621791057, 0.0070617794159001535, 0.0262894050351211, 0.06326074938156775, 0.07526074296661786, 0.005139689875899681, 0.016340176674670408, 0.03490299319050141, 0.03994651684271438, 0.05312939713309918, 0.007290544104762375, 0.037290069208081277, 0.07061807066202164, 0.007307312401410724, 0.05331155664420553, 0.018880506611562202, 0.0422757273939039, 0.052529606103364906, 0.029716637916862965, 0.013143624495049673, 0.02785283962397703, 0.052596784462886195, 0.0028563601663336158, 0.020201980701780746, 0.010507745801338127, 0.012177703602771674, 0.022231500994946276, 0.04586844478866883, 0.020724949693041186, 0.03197972862316029, 0.06738537377012627, 0.03384778641962579, 0.04292940088946905, 0.004872587534399437, 0.024881421122699976, 0.008051308237814477, 0.023606548817562203, 0.03210348662521158, 0.049884167699409385, 0.022303225539092506, 0.0275008292270026, 0.0770721532670515, 0.0511578627462898, 0.049664461453046115, 0.049060097097286155, 0.0424239771174533, 0.040864693466573954, 0.06608718021639756, 0.06441957862781626, 0.07883278200668947, 0.02757625009066292, 0.017241457776565636, 0.02059507809047188, 0.05114121149693217, 0.02498285871531282, 0.03016727677147303, 0.03492876055783459, 0.06744743936828204, 0.011980750331921237, 0.03516912480284061, 0.05042215097429497, 0.01610060122662357, 0.01778768694826535, 0.06075981179518359, 0.06918583251535892, 0.08666497601994447, 0.008641644730232656, 0.02005343751183578, 0.041040997220469375, 0.06708237395754882, 0.05743029474147728, 0.03644463153822081, 0.03994651684271438, 0.03398058929347566, 0.028903719037771225, 0.018221728836319277, 0.05864282324910164, 0.04605402750894427, 0.014781235683975475, 0.07645311219883816, 0.05643218329974583, 0.04577186211411442, 0.07146780685122524, 0.031169500135417496, 0.009059727474647974, 0.034601041714527776, 0.02353624750061759, 0.037316613498010805, 0.03707007458433509, 0.06048637575336865, 0.010813716749128486, 0.020689793097387468, 0.02814590568388147, 0.06764865214271204, 0.06710845684366566, 0.06180481679205384, 0.007201097074097821, 0.004916286461853555, 0.0552788841138993, 0.004180623883647578, 0.029213049582072666, 0.031270323653838465, 0.03294014744460583, 0.08417222835123539, 0.0784492672287992, 0.034791482745536735, 0.011644302135599511, 0.09134520523782287, 0.053552029454814534, 0.03942216194367834, 0.00774749503138342, 0.008951325568237474, 0.0737904254347086, 0.08107773547193833, 0.09155554430825369, 0.01702809752896428, 0.047258128611637015, 0.07119924947619438, 0.018762144659246718, 0.03091614873015455, 0.03822382499596902, 0.022683856543153524, 0.02316220846426274, 0.012161309348552354, 0.052520008225526126, 0.06523494023297514, 0.03754205336528165, 0.007676110602915287, 0.015815073690776314, 0.03153698791616729, 0.07410120125859976, 0.034513581943299086, 0.043617703419710906, 0.019546580334593142, 0.025185738989551152, 0.018366290722042322, 0.04856074621368732, 0.02650720120540687, 0.0427451752392309, 0.004919590503309986, 0.051090524931039126, 0.028400678620008484, 0.057224406860768795, 0.020670700818300247, 0.020406830423910702, 0.049843085796705315, 0.01972081625301923, 0.03875527397862502, 0.057200800627470016, 0.02701188367791474, 0.05103314122451203, 0.04838535848206707, 0.03065559806834374, 0.008725211406791849, 0.04360373916902712, 0.06528647496764149, 0.03536109932299171, 0.008197371382266283, 0.03877148078754544, 0.06475899541484458, 0.04238667465480311, 0.042282037769577334, 0.034231396192418675, 0.011423844411703092, 0.04002896902550544, 0.16080578336758272, 0.005667095213928925, 0.024211020042587603, 0.01937739610938089, 0.01890612130851618, 0.10096753747867686, 0.05300307087600231, 0.02759911332811628, 0.010150557334002639, 0.022124935373929993, 0.01472992486586528, 0.09161391867590801, 0.016449554823338985, 0.029721659076000963, 0.09589111844875983, 0.046083173980670314, 0.022166288690641522, 0.03711830824613571, 0.09802302119455167, 0.18282714885260376, 0.1281191094645432, 0.11583736778369971, 0.09613079058804683, 0.214939646422863, 0.09337739047727414, 0.12130211240478925, 0.10664395788418395, 0.15786978948329175, 0.1756770589521953, 0.27335830884320395, 0.1359505028064762, 0.08280166903776781, 0.11116268219692366, 0.11199303264064447, 0.11728050320276193, 0.1372999053980623, 0.0748114035065685, 0.09570700475679976, 0.15787244934056485, 0.08289935093905244, 0.11906192904072148, 0.16323719147060597, 0.10913040874791996, 0.1121868086712701, 0.24062713661364146, 0.11903637541191918, 0.10876334165888173, 0.06765369365790061, 0.14152675787253038, 0.10084301273205451, 0.11495443087603364, 0.14370429888367653, 0.12610286979803018, 0.16041444508092745, 0.11810435328100409, 0.09242136177739926, 0.12243936423744474, 0.11638466055904116, 0.24693257255213602, 0.20392581527786596, 0.15448072419634887, 0.1107397038223488, 0.13459525124302932, 0.11676803284457751, 0.14928246741848333, 0.12493546386914593, 0.1213250740298203, 0.14530444730605396, 0.12081415073147841, 0.060282292775809765, 0.21090807632676192, 0.16072750756783144, 0.07350603783769266, 0.12844942031162127, 0.14196837560406753, 0.13542618522686617, 0.19223074854484626, 0.07977633244757142, 0.11894486817930426, 0.13985655749482767, 0.09950450741286788, 0.11210619871105466, 0.12877196871808597, 0.08388971351087093, 0.09683447211448636, 0.12881782411464623, 0.09225771948695183, 0.11665976579700198, 0.11986481238688741, 0.07422887440770864, 0.1494805317904268, 0.12615861823516233, 0.14768571167119912, 0.15065469592809677, 0.12475201514150415, 0.08458770891385418, 0.12443861338709082, 0.1494178351547037, 0.1531628327710288, 0.06732365422483001, 0.13198091009897844, 0.0892767726576754, 0.08454504263188158, 0.10174106061458588, 0.13519716608737195, 0.16649037333471434, 0.2266971655189991, 0.10116906916456563, 0.15300461197538034, 0.16501237478639397, 0.11539113601403576, 0.0813932813970106, 0.20115581820053713, 0.06223790533840656, 0.13589987052338465, 0.11833002045750618, 0.15405521488615445, 0.11122064265821661, 0.19983521263514245, 0.21401789731213025, 0.22256050391920976, 0.12887163194162504, 0.12254925976906504, 0.20104114578238555, 0.16455087597881043, 0.15779605986816542, 0.16210242307611875, 0.08868867278631244, 0.17619152420333453, 0.0911680736712047, 0.303934779550348, 0.10141670051962137, 0.1273416576108762, 0.0540374601925058, 0.14254428898649557, 0.12961172365716525, 0.16786830153848442, 0.13093870745173522, 0.06689401263637201, 0.13459905103913375, 0.12810909428766795, 0.1511510850063392, 0.12732558990163462, 0.10248409038675682, 0.11072481676403965, 0.1955216840973922, 0.2602802248937743, 0.10694108158349991, 0.0832331698121769, 0.08923282394451754, 0.1705014245318515, 0.18752319472176687, 0.14755570436162607, 0.13217894732952118, 0.07839816675654479, 0.12421454755323273, 0.10853052272328309, 0.12969164151166165, 0.07681196222880057, 0.1409034284629992, 0.13998032228222915, 0.12904388484145912, 0.13520952899541172, 0.09616297350398131, 0.09734418083514486, 0.10630645456590823, 0.18886786113892282, 0.15911682828196458, 0.13045036579881394, 0.15690708399883338, 0.14132080892367022, 0.13301236475152628, 0.14198955946734973, 0.07644464408180543, 0.11646635617528643, 0.1448458390576499, 0.25943558450256077, 0.08142403938940593, 0.10272649023681879, 0.061357397586107254, 0.17054856914494718, 0.24356359190174512, 0.16868436203471251, 0.13097180638994488, 0.11872795410454273, 0.09680912883153983, 0.09065055501248155, 0.14332620560058526, 0.12774058191904, 0.15907189569302968, 0.22053625753947667, 0.15783952682146005, 0.11573808453977108, 0.16619686622704777], [0.017895299209547893, 0.028865890710481575, 0.08285888989589044, 0.036669328409646235, 0.019126826697694402, 0.029502536369753734, 0.08964812130268131, 0.027826685491683226, 0.055992753843643835, 0.017151390734527792, 0.05216965006132211, 0.004014919270827834, 0.03838376587788973, 0.005977840079659862, 0.07535563608897583, 0.041276323342961926, 0.021211784998221055, 0.01059204529571746, 0.007213841658085585, 0.021044037570910792, 0.04586642275431326, 0.05475129260282431, 0.032303562853485346, 0.010921494403321828, 0.0047405997507407194, 0.026261976953329783, 0.045136926363089254, 0.07136677298694849, 0.014890607047293867, 0.05626052751072815, 0.03523185536531465, 0.02084099275193044, 0.03751494589128664, 0.05125863537458437, 0.015264198250536407, 0.016386264469474554, 0.0320255602709949, 0.027273338487637893, 0.03712319030559488, 0.020141604655821408, 0.0235224868104394, 0.06564729274915797, 0.03512151878593223, 0.03213779674842954, 0.012690277437546423, 0.02385394777437406, 0.0446959668105202, 0.05505223645429526, 0.03631262255034276, 0.012959714363595205, 0.03015115138675485, 0.0022400972749372678, 0.017082655137138705, 0.07124126436454908, 0.011601575633643993, 0.02721532035086836, 0.04740851232782006, 0.07122510166040488, 0.04211413427921278, 0.006516476444500897, 0.020866093458607793, 0.030865570729864494, 0.030281986509050642, 0.012755326045277928, 0.05308689030685595, 0.009734097984619439, 0.0077001943552334395, 0.052237652840891054, 0.06358101112501961, 0.0221966734887766, 0.008343038431900953, 0.023792270637516464, 0.04895578930154443, 0.02260080216053341, 0.04460823562528406, 0.026667752768844366, 0.04882713906200869, 0.04302920999803713, 0.06350366491824389, 0.08910973090678453, 0.04763026096458946, 0.013206471256645662, 0.054651212080248764, 0.02155855031950133, 0.021753936174458692, 0.05432829387219889, 0.04628341984269874, 0.02752426582654672, 0.026948513596185615, 0.013140175840817392, 0.020141657242285352, 0.07245864439755678, 0.04096546270219343, 0.0500890377775899, 0.03876247662784798, 0.04237492582095521, 0.03673143471990313, 0.030956562275865247, 0.05089297624570983, 0.00994840478857181, 0.03729149752429553, 0.03462458009432469, 0.04914917517453432, 0.025542685728786246, 0.00799047333254878, 0.01471759588457644, 0.01010501491171973, 0.10879304792199816, 0.06344294281942503, 0.031136336736381054, 0.03510182769969106, 0.05560956136988742, 0.10249061110828604, 0.04056253503741963, 0.03479764723618116, 0.027201983745076826, 0.029386316891759634, 0.001995489853600572, 0.03170802963099309, 0.01346860799406256, 0.017483587908957685, 0.01579707215673157, 0.041553735599986145, 0.027909856921594058, 0.07288332589502845, 0.03402518600757633, 0.02323278458788991, 0.02958089020103216, 0.024775381366323148, 0.044648360793611834, 0.034220712658550055, 0.04707054760573166, 0.02391550107859075, 0.042731261878673515, 0.03933251050433942, 0.014576392747195703, 0.0233302832847195, 0.04380453125174556, 0.09084676698382411, 0.012829059901248132, 0.050550533192498345, 0.017697409560371722, 0.047609850631228516, 0.004398210980330727, 0.06379375220941645, 0.10174401902726718, 0.05572541783164654, 0.027513921560187424, 0.087551495592509, 0.009237095680353897, 0.01807383364731712, 0.034996424069894214, 0.02272826326744897, 0.01751989122879292, 0.025869598811758415, 0.021136221642206823, 0.01905255425455315, 0.03998803300783038, 0.03000502547781382, 0.0190024749775018, 0.03419675358704158, 0.05861259451402085, 0.07776391971856356, 0.032352668432784934, 0.03796014289504715, 0.019226148957386613, 0.01500815645392452, 0.010348608983414513, 0.008878302477699305, 0.03635346357311521, 0.018452668229916265, 0.021071930449189882, 0.0088457480638421, 0.025889535866943852, 0.023696877095582228, 0.011573759938723274, 0.04427891204665814, 0.01952744564706726, 0.054424876546753306, 0.04882525273465684, 0.04765809786372951, 0.05735696546201195, 0.05396466017035501, 0.03632241041798677, 0.017557934990950992, 0.031231053439634185, 0.03661387852792229, 0.03659681337220328, 0.07527725850897175, 0.04016502547476973, 0.04825213830918074, 0.03131205016481025, 0.009804754684280072, 0.06949774827808142, 0.02898155039708529, 0.029371606252555336, 0.031798061049942455, 0.034192580596676896, 0.02530088638221579, 0.01001492072828114, 0.06115289391683681, 0.029058350383171012, 0.015279638314885753, 0.02998855404023613, 0.04386138230828302, 0.016805208953363553, 0.007220075698569417, 0.012147454511640328, 0.015136341896972485, 0.013617311487905681, 0.006737042309915913, 0.03915217964510832, 0.019716397293710282, 0.06460081533129726, 0.017894395061635544, 0.025623663794249296, 0.00759605280057128, 0.02910934228982244, 0.041559119775359116, 0.06257204312298979, 0.016584394998582344, 0.04990059842488595, 0.015790994179302027, 0.017217038997582028, 0.05745262532894101, 0.04717965264405523, 0.03939526142286403, 0.05033532563330872, 0.016818559129855463, 0.05329427435728056, 0.02064746947559927, 0.05905153203223433, 0.10947842257363455, 0.048191222827881575, 0.019313756309981858, 0.027254772073190128, 0.017884018564862863, 0.03798926901072264, 0.10212506393768958, 0.016101990527074252, 0.020948089326598814, 0.010323040935743068, 0.03862360765093139, 0.017469345458916256, 0.061385495721229484, 0.0793381209618279, 0.03686310104759676, 0.01220099431728678, 0.035040162437196286, 0.03088536359635847, 0.05501738689573748, 0.022473193472251296, 0.11058592064572231, 0.060086535422929695, 0.05992354452610016, 0.047865373348551135, 0.037240902560630014, 0.0067085921847527576, 0.050465824880770276, 0.01598625789795603, 0.02148025586003704, 0.0858098997601441, 0.021741532554317797, 0.051548111984240155, 0.03737459770802941, 0.010852819025915648, 0.02423979840906603, 0.01579261927067169, 0.03760223263608558, 0.00921945461803781, 0.023227458087993518, 0.05126700510403939, 0.05234353483787604, 0.01185891597664782, 0.03333195731309908, 0.03027642930724791, 0.08104910129415137, 0.04251702462456056, 0.045076000703764815, 0.01809509384578892, 0.06913089153489896, 0.009924852838074523, 0.0333852087413626, 0.03185322255428348, 0.059315482154488564, 0.06581258387970072, 0.044342321144150834, 0.06842915740396295, 0.04923246195539832, 0.05801636579313448, 0.027449299581348896, 0.008050405786239674, 0.05620204457747085, 0.007229673576408199, 0.010692594007455876, 0.054927864378052096, 0.041137115098536015, 0.03513741007606898, 0.06086543934153659, 0.07172814038183008, 0.05646223222304668, 0.14844439524625028, 0.11397743544408254, 0.00962343655659684, 0.041848260510180674, 0.05892508703150919, 0.02654007283438529, 0.007126752536610833, 0.01999108523263463, 0.023885818564199975, 0.020866704140124575, 0.045219524430909326, 0.0074668410733076075, 0.02540430868975818, 0.03452143259346485, 0.029146753318075622, 0.008665127130890531, 0.04289318747552378, 0.06824228885982718, 0.024916825383635502, 0.08713724996362414, 0.028151910718796507, 0.06197898316064051, 0.030879884426082884, 0.01258466939907521, 0.016117998864501715, 0.05329164842675839, 0.04709692904725671, 0.02454466588928231, 0.01276934881960707, 0.041711888542132716, 0.034051482632224045, 0.08923764154314995, 0.028412342636979053, 0.019496129559619085, 0.028971080601747547, 0.026640714844688773, 0.08354377600231341, 0.04500721421624933, 0.00710577138566545, 0.04074044691930924, 0.06986581959894725, 0.022765199321189096, 0.012894825211593082, 0.05645282094233802, 0.0354880667956812, 0.06314335603799139, 0.04585972222100411, 0.019524880784696767, 0.04820498351805976, 0.06638332682528666, 0.027525130958695496, 0.1492487849401576, 0.13428358653826372, 0.20516416882830008, 0.16019981088382856, 0.1121736518772585, 0.1261427676571267, 0.23480935022234917, 0.12725780425327166, 0.10144960946802582, 0.08160914374249321, 0.1505599588687931, 0.18443587395761693, 0.2026973683387041, 0.11560623161494732, 0.13316384090908936, 0.09948976963226284, 0.11423392168113164, 0.12353057068373476, 0.11086581634091479, 0.1260769904724189, 0.07830896654299327, 0.15079224854707718, 0.12456730433872767, 0.11856098020715372, 0.17410041498286383, 0.1116017893488918, 0.1126010814415557, 0.11234091075935534, 0.11276097143335001, 0.1810235892023359, 0.11969481222331524, 0.09746065137109586, 0.12323657503085476, 0.10366958605923823, 0.08835566136986017, 0.12913826906255313, 0.10958255734294653, 0.16216480758573326, 0.09718761566494193, 0.11961675355476992, 0.05905975587666035, 0.10171724403543131, 0.1287120133638382, 0.08908393300537552, 0.07663767372391053, 0.20288549895797456, 0.08936424939227955, 0.10488936810621194, 0.11299034341105393, 0.15639732778072357, 0.18463805025177343, 0.08582424399043832, 0.13649099666093076, 0.19953208390091146, 0.06402293419731514, 0.13006662710436753, 0.1428557229893548, 0.19434651572789463, 0.19269061886838504, 0.14552951737173966, 0.09238202031701803, 0.07109402905085258, 0.18263884181422846, 0.03611022912498031, 0.15167095139622688, 0.11117633432149887, 0.1212595139763185, 0.07994249888828822, 0.15474295083965572, 0.2633006828171866, 0.17105095647275448, 0.0828663877078465, 0.12938410229980946, 0.10102610862148659, 0.16367553866335324, 0.11895647112812315, 0.23310601019433566, 0.14059284941426345, 0.14397047460079193, 0.22125360476119177, 0.10708356715206589, 0.05053075050402965, 0.18844600234712872, 0.11014682027910437, 0.07655504851468972, 0.23943695904953138, 0.0890493548608252, 0.09848542245371, 0.09948539986674275, 0.08089024267558541, 0.05191439875800695, 0.17810032463499478, 0.10179818647780589, 0.0932503958631839, 0.15347765944898129, 0.18872694298624992, 0.16773616362895283, 0.11129837562995297, 0.11823921890131064, 0.15588797868362494, 0.13577412441372871, 0.14333569152014597, 0.1516445428133011, 0.16262095953736985, 0.13017279069338525, 0.0601837762764522, 0.06475525668689183, 0.15089297028524534, 0.09510440459208828, 0.14478154107928276, 0.1491216274776629, 0.195589863296066, 0.15904094092547894, 0.14975734693663462, 0.11724022536405496, 0.056049421695726256, 0.23059439925210817, 0.11590979461159025, 0.08978500217199326, 0.13811482595545904, 0.139950371746506, 0.08118174131959677, 0.1574263804193054, 0.13133206777274609, 0.10058700825486865, 0.3292132488318852, 0.14711868709751538, 0.0909693171935422, 0.07071084675512143, 0.12416878715157509, 0.11217285799128668, 0.0899539098941854, 0.16326365433633327, 0.11295727839959518, 0.14619594732565538, 0.10685486013868026, 0.12241984957030841, 0.14182839382972035, 0.19253376871347427, 0.1318558832364423, 0.15363763086497784, 0.05941855162382126, 0.28483800856130465, 0.10496263631752559, 0.18612861526863916, 0.1816935475383486, 0.16521617956459522, 0.10261660149054867, 0.11760732637984411, 0.1273644156754017, 0.14666400078151906, 0.17065439346645558, 0.08606550390166895, 0.08452700038573571, 0.13619770668447018, 0.10264821443706751, 0.11017727293074131, 0.10338794652904783, 0.12530656824154512, 0.11673512389617306, 0.04955183821065085, 0.1772335504314729, 0.14876125752925873, 0.14498032469834599, 0.12594939874751226, 0.2026958619909627, 0.058987186556415896, 0.0874681579215186, 0.15569904739303247, 0.15689919942191669, 0.09750053565949202, 0.10458362701215915, 0.08795666920819453, 0.18811309949627944, 0.15696526159133228, 0.09782976085054022], [0.030445506663194725, 0.05799112429044076, 0.033286509037550004, 0.010675641658183719, 0.03481183879609619, 0.010115576309284993, 0.02688076696358621, 0.021332348796672056, 0.02204068676967706, 0.046007225556032996, 0.04802830656990409, 0.02109750613038029, 0.06812335524175848, 0.05387602314086897, 0.009935556727993702, 0.043723792369876585, 0.03528367508468883, 0.02464564547075757, 0.05549039365723729, 0.04542350562821541, 0.03577354683407715, 0.05651891703850456, 0.00962233224085399, 0.0368439561820456, 0.05656098960233586, 0.026087286416441202, 0.0070271016115189665, 0.05065759244774069, 0.04902713725875531, 0.030877523124217987, 0.025629370273756127, 0.030172294537935938, 0.016936267992215495, 0.06680099227066551, 0.03948859391467912, 0.01764092660908188, 0.06132617818989924, 0.0210454166933362, 0.046321302452789884, 0.02752252368788634, 0.058876754982130866, 0.062227917302932055, 0.021352097558389817, 0.033543202227779796, 0.01853786508685776, 0.10348975392324583, 0.004978148499503732, 0.027470356219315102, 0.007458290683903864, 0.04810517440949168, 0.010817342670634389, 0.012788568324010288, 0.061482030898332596, 0.008904530400676387, 0.007789551480008023, 0.036400899956268926, 0.02425048703194729, 0.03585193119943142, 0.009193659261135119, 0.005666816590486893, 0.03606918793437736, 0.02203872749981071, 0.06155548909945147, 0.01442935420865459, 0.01067749914779727, 0.013010636720407222, 0.02021694409527949, 0.05371708309810076, 0.022240432212129235, 0.03828991769946047, 0.03165597581703748, 0.018346664096627916, 0.01891952576780958, 0.058579563429313045, 0.06896577682346106, 0.042905825190246105, 0.03337866427110774, 0.07176783468042101, 0.05038556097341435, 0.02205153145561261, 0.04732763434627226, 0.06061731265591724, 0.032251400473926745, 0.055556974905942164, 0.02855988159509642, 0.00847872592774885, 0.10165017084883791, 0.0353625615659569, 0.040987755970231125, 0.028739330358803272, 0.007473024223665041, 0.06587735004723072, 0.020146245835348964, 0.0465504708699882, 0.022054613700934818, 0.0024058076128962314, 0.02154054369644395, 0.03496511985680886, 0.03646373569167086, 0.03938661688672645, 0.022910302338589515, 0.0344181900977024, 0.03518448344298771, 0.06178279833069869, 0.05054208882419126, 0.028537286378975426, 0.04294951945277197, 0.029742968468261615, 0.03048552665859461, 0.03128370436440621, 0.035197097408984385, 0.020471640696216906, 0.016596856294199824, 0.026362713958535875, 0.034319755022547076, 0.012062888692266174, 0.03389122283884457, 0.03384329791047743, 0.055455377857599936, 0.06469112834227936, 0.02010248541565878, 0.035420247220567296, 0.05002025129007442, 0.033862493666155, 0.022834074018257003, 0.025561852646725516, 0.03612543848742332, 0.05657116762761559, 0.016648382547178438, 0.11901626363396645, 0.03211258238713656, 0.03346895692603929, 0.04268909092726452, 0.04583594635395067, 0.03141404754881348, 0.017704632565645233, 0.03408703786720123, 0.05996868067554065, 0.04975220960165773, 0.041081831457891634, 0.024161115488303558, 0.06079187257481473, 0.030537298880517483, 0.05481322588665145, 0.04329155199229717, 0.03646187311304467, 0.018778677164976085, 0.022527583143008605, 0.07713879897658314, 0.09019350060927016, 0.0230682483275554, 0.046164201239922216, 0.0038982536560589714, 0.07729765080979892, 0.019868401012250354, 0.07050622773489781, 0.0490122298443956, 0.042490985843219926, 0.0345935506879219, 0.05801490694284439, 0.026774569447817545, 0.05399902118369937, 0.024639704896669303, 0.027305865760094354, 0.03984506567940116, 0.00804318193279739, 0.029075066093355417, 0.036515779327601194, 0.040115085297397206, 0.025602542695456317, 0.016821926359885504, 0.0335246748290956, 0.05776160303503275, 0.05401084126372423, 0.00891444634180516, 0.06775619315781764, 0.11442377577934947, 0.03133976832032204, 0.036362545764339824, 0.02036100047241364, 0.010826793815275388, 0.06977555408541646, 0.03243945984702025, 0.04185007559135556, 0.03579381467508418, 0.020139358704909682, 0.03632168438551681, 0.051146985829940865, 0.019905525359458158, 0.037191216833889484, 0.026963298874241964, 0.04845772763448102, 0.009644505917094648, 0.028447115860347236, 0.054774067630725246, 0.07863749962832246, 0.010830862480880958, 0.05851107888988086, 0.034741213478680165, 0.03170796177749123, 0.05752749488289867, 0.01960291400817888, 0.020035344375563518, 0.022924370065863644, 0.03231220738962293, 0.010078153406668986, 0.028799662299986397, 0.02519220033926623, 0.05240463352363024, 0.08137343424771513, 0.010416620244671191, 0.040084605504359515, 0.0202467080338725, 0.01879219358254756, 0.05430552223697305, 0.0913302842527628, 0.010509839930039431, 0.028598513986383165, 0.03684858039819768, 0.01057166125558849, 0.05751140003225633, 0.014462325921548265, 0.04385708039626479, 0.01630558495941971, 0.030864841304719448, 0.01502534035327179, 0.060569604858756065, 0.026460745305355107, 0.13196273893117905, 0.031247100792825222, 0.035397607899670086, 0.08369023100073848, 0.018811594595068266, 0.024906041765851632, 0.020696100080385804, 0.035199940470712524, 0.029468161785709004, 0.02005853670250092, 0.060622252390853, 0.02022416370787791, 0.0740528284971203, 0.03442289913073182, 0.057398084684142044, 0.018130004472498382, 0.023801169624286037, 0.03237850365361997, 0.022330090436818342, 0.05681591520884207, 0.02837077558173665, 0.015099161570625646, 0.08178020920604467, 0.025978205126843283, 0.008023881004191935, 0.04816290077620319, 0.010627135734206863, 0.05062633573210665, 0.021752433219392384, 0.03820405927087579, 0.030381232433553253, 0.025405550408842306, 0.035157776304653714, 0.03135882836899587, 0.09453616544072117, 0.03551947957436953, 0.0301997243160648, 0.03414970736152359, 0.02177925401234201, 0.046990029247743745, 0.04063686854871256, 0.02828597736411861, 0.06875893220837627, 0.008183279906266501, 0.027076741447672248, 0.03649746906012297, 0.0227258629498205, 0.07747056867395129, 0.024726598091157417, 0.02138899968537901, 0.011851223934042667, 0.049251175951212645, 0.05923984585595982, 0.050387566044394455, 0.04289829345153911, 0.02369432071489947, 0.013818464042352778, 0.030506693558501344, 0.017511993081175854, 0.08467936542417322, 0.029599458311817477, 0.03888128471693822, 0.020083120026226555, 0.06301619179014649, 0.08132685281868492, 0.0496083907117801, 0.02860655801902924, 0.05105672370908516, 0.08253109641373158, 0.026629332419750944, 0.037200417768742354, 0.04659778172416346, 0.030119090607123714, 0.024628744859780585, 0.03078872663900256, 0.09181555892739977, 0.02156522710408483, 0.09268207528761455, 0.024759663102616156, 0.01381092467012682, 0.006618372896420104, 0.032655471470206976, 0.0608312954593982, 0.02411802512194429, 0.050023949305926046, 0.054743404633232524, 0.01475759213125067, 0.06788159321461405, 0.02661009255929717, 0.007929987872817686, 0.02971093143735613, 0.04308688547462225, 0.08005968867135899, 0.060992949642241, 0.04710675423432674, 0.02912529804078596, 0.019994857887338315, 0.06561045508299555, 0.04194355057552457, 0.04204627059932266, 0.05263312001313482, 0.039758196233638694, 0.0326462739280292, 0.04847580041470272, 0.02328230407355087, 0.05484587359907372, 0.06408730681453433, 0.017869874502399137, 0.043736440262624195, 0.020848158081727367, 0.04629237311226981, 0.050912036294383664, 0.03623050624238593, 0.02558965901178973, 0.052211186582488675, 0.06670725944318942, 0.022959776023136716, 0.03197813067319138, 0.027035798644647002, 0.05521605516384755, 0.07830697165003844, 0.02886874395023499, 0.01982705617722656, 0.03663640249786632, 0.14925247617065907, 0.08358513271170002, 0.11190299782902002, 0.12170380513582911, 0.14610057244343416, 0.13463072505380425, 0.07076720587377038, 0.13347421639731952, 0.07039450694407735, 0.11959729317043509, 0.10656743270478078, 0.10633008794060775, 0.10297874241535153, 0.1609777919948101, 0.20252002642623015, 0.1595952090408121, 0.05330534465610981, 0.12374839399542127, 0.16574466334921972, 0.21847135334142617, 0.2262809792799609, 0.1499340645968914, 0.11772058744515691, 0.11864425002464227, 0.1870143205991813, 0.08407515713146754, 0.07601800840348005, 0.1275012083351612, 0.21350974243666443, 0.15446039528719016, 0.15994750442249434, 0.13714548439851829, 0.17043875503752912, 0.1872252771364791, 0.10864998559866633, 0.20635900114263805, 0.154335476990257, 0.10863406038177864, 0.129175887043987, 0.17197787602032932, 0.16647801042667457, 0.10634941261793886, 0.16547329005386147, 0.110411476077778, 0.12487697415053844, 0.2209431749901601, 0.137794340295451, 0.11810357975108282, 0.06722017763448612, 0.20522849394806794, 0.11609701599393572, 0.12564906557755812, 0.20860310643911362, 0.18962877030883515, 0.09626598190516233, 0.10941856899963957, 0.14319914313299315, 0.08327713888138533, 0.11915825387196881, 0.10888937275324549, 0.09153992443212441, 0.1293824195329632, 0.13770773208567075, 0.10786584338971547, 0.08464988307761294, 0.14451130772275583, 0.18052626374576772, 0.1404734408216817, 0.0856629494311554, 0.11093945774648871, 0.09482601524463721, 0.08240328077226877, 0.14805191702076367, 0.10657799749502114, 0.1461991500109434, 0.18862497274364742, 0.06598514890564339, 0.12163853006703512, 0.10704457852989435, 0.11003788826721055, 0.09484466817229986, 0.1704351995140314, 0.0841000322252512, 0.16546841817242758, 0.1226268434630973, 0.13383515631513937, 0.17239689853574547, 0.09928732192409889, 0.12340857008738176, 0.15865503091897282, 0.0499047917713012, 0.12024453415402345, 0.10016481019556522, 0.12569517881742545, 0.14256319297211512, 0.20193587562867574, 0.10243022149162632, 0.13960757585508482, 0.11891681754163333, 0.139560390529888, 0.13602607803685324, 0.20901965908706188, 0.09805116004177503, 0.16973778765116418, 0.1280616782605648, 0.10048629330205065, 0.16067950800061226, 0.10482810996472836, 0.06966259157551186, 0.13977852596768311, 0.07224300596863031, 0.2023819445499352, 0.1126916522958449, 0.1095883452466556, 0.10769793311400072, 0.1485201876078333, 0.18279770043279442, 0.10271846316754818, 0.23194009704249247, 0.13707939508770192, 0.14623245250965866, 0.10425329580903053, 0.19490180164575577, 0.08931667730212212, 0.11039005472723927, 0.10259950919342892, 0.11358875701470034, 0.15501281778727258, 0.10914904810488224, 0.2373718512909753, 0.12836446772728646, 0.10927164581205163, 0.13698651721434935, 0.09405707222010408, 0.08397757022508553, 0.15010182559490204, 0.10863522067666054, 0.2876767819481236, 0.12367138027080468, 0.15986259255026067, 0.09692593184964997, 0.16212345766169683, 0.08477873009230409, 0.12748371570238046, 0.1490900891699961, 0.14800587163439818, 0.09049601866198437, 0.08121538308582135, 0.18691838931824478, 0.22527597392243998, 0.14840915213738168, 0.12702520244887897, 0.1799218790339572, 0.10472483693489007, 0.13531292416155338, 0.13054690776126726, 0.208740767623697, 0.1550521592476538, 0.13622307032346725, 0.21657336875796318, 0.07838940686945405, 0.17672141934079783, 0.1351764164865017, 0.15804551648242132, 0.15619485293115887, 0.10743742994964123, 0.17547843818153652, 0.15525341273418494, 0.0864751422777772, 0.10796127934008837, 0.11470585635730199, 0.13215665066880838, 0.1585013155958482, 0.11615954978125435, 0.09643113732870136, 0.1402431596070528], [0.04058792242514236, 0.027244103806359426, 0.0520859663374722, 0.05791624116578272, 0.006995080695820174, 0.04956979563991938, 0.04469512542709708, 0.05741685296275786, 0.015646964943568622, 0.017780886331040944, 0.042822646974985085, 0.05292309534602931, 0.0683877192703741, 0.07358516180621726, 0.011355366657621093, 0.012606644603822912, 0.009894412060800408, 0.019593769052465047, 0.02432091218153281, 0.04521794344431587, 0.00754805832236473, 0.027216082006426792, 0.026503984949418476, 0.07412693130650691, 0.03547571406566671, 0.024002877729279653, 0.04596951257969652, 0.030150598380714655, 0.020526138932577202, 0.07309766153671912, 0.018313655064308217, 0.03705612729702677, 0.02600305138288864, 0.043483814889831204, 0.022866022839610065, 0.048840886181486506, 0.0299582472736282, 0.08492073390100684, 0.042038671007113795, 0.026896268096087233, 0.035650704854301045, 0.03354133286380342, 0.03880537361172693, 0.05225320825619357, 0.022416727484336922, 0.04194410018888967, 0.02849815526444997, 0.012321273131029946, 0.06356064150375978, 0.043923722713121345, 0.007525864290073514, 0.01909554284065962, 0.024739296874031425, 0.03096696761037622, 0.0016950198104106157, 0.02708042419648596, 0.022179615118407776, 0.012927036117097097, 0.019276089134759138, 0.02814945611836655, 0.04944989171677402, 0.006781040216862623, 0.01205068948079965, 0.022681330696546605, 0.027356228325515985, 0.06975337956100702, 0.04749019776604005, 0.021976753503882458, 0.010631135698141796, 0.0037767746835015714, 0.01843941644100206, 0.03643204132094979, 0.05694782920181751, 0.05152995438714113, 0.04917732759245804, 0.015016714476847222, 0.03615519224799105, 0.022013930437554206, 0.029417074884154966, 0.030634193681180477, 0.031950263239975484, 0.08623965669955526, 0.010785996049110378, 0.04921893196712647, 0.018905254480029856, 0.034938375399048836, 0.0025134423506512705, 0.017238166881725192, 0.008337464266722756, 0.025944351318425367, 0.038300133044166226, 0.040319894307426045, 0.03940035382817898, 0.04204098820420248, 0.03327339295563953, 0.03151377862585442, 0.03888465025063072, 0.01880149120864059, 0.06927569090787854, 0.020413802371227315, 0.022092192666605115, 0.04577551941786494, 0.05336365117026227, 0.02464014764076897, 0.03693284087681344, 0.013456139913094895, 0.04017420266089695, 0.031456201536847014, 0.031520926992275884, 0.026860029237078767, 0.02011226480161505, 0.02109678179424788, 0.05385494784318975, 0.03055161257673587, 0.020250957359426787, 0.04658680981291192, 0.060613587498664856, 0.05178962295342769, 0.01793368563189038, 0.02900284282597048, 0.06303354193057333, 0.0072350323067179746, 0.02727762682895575, 0.04891530450965677, 0.03961803464751158, 0.05930619301008327, 0.01882227643259934, 0.011030028624060963, 0.028014195251411626, 0.047790055961481163, 0.04272432725078293, 0.08211362774350814, 0.026457065949216485, 0.06097373353051288, 0.07004305973116841, 0.056750073563307524, 0.07034339968647275, 0.01906701722847564, 0.017016910182844316, 0.027003737865015864, 0.028370646660083106, 0.051723944156297615, 0.01848207593762449, 0.02211740702789809, 0.07758760917931795, 0.03474849076675517, 0.013069336784870496, 0.06691129492329699, 0.03177423429276262, 0.02860783027218921, 0.01564892421343497, 0.03523779593940292, 0.02011576434597373, 0.07806091449622597, 0.03215736909104245, 0.046684909013233016, 0.02550869112435196, 0.03254970482417515, 0.04259087298331516, 0.027401476433234553, 0.008582923461550047, 0.014705022630680884, 0.04418734713856663, 0.04140183875071151, 0.035420376142220836, 0.025949226592534354, 0.013498087796116514, 0.04221724446064659, 0.04226544080302119, 0.01621843222528696, 0.07219324221036263, 0.035165090912154744, 0.016877274461356655, 0.0200187626760453, 0.03614828476150121, 0.05554087326994964, 0.03026487385588033, 0.02019844892700868, 0.060571864380368164, 0.00869155946254198, 0.05375800554507545, 0.0237964453242187, 0.03534097058166351, 0.052555420968149386, 0.06434472942990915, 0.038195292598434856, 0.008509266788938215, 0.05560172429042203, 0.03734498643981559, 0.0527069276597883, 0.021351164572739174, 0.020060365354376178, 0.021698279339554052, 0.025390793968524252, 0.08120276911982469, 0.033841571038854976, 0.028209842342351164, 0.01900035116289343, 0.04408833530864545, 0.053046402122293196, 0.08754552448434488, 0.02896674137030329, 0.028259753681985394, 0.011495717385384654, 0.013628466603612261, 0.007300192872727556, 0.028833775648048947, 0.025076952862686346, 0.009625481491509293, 0.05792489927262068, 0.02809666100490306, 0.022818735734160458, 0.05545382061973214, 0.04321195644193462, 0.013477599431228424, 0.0514383453742734, 0.06363511072205645, 0.02972102803843362, 0.025448208209127188, 0.018202923238277435, 0.047250532412103245, 0.03187689324840903, 0.023708033907626356, 0.022360563444505845, 0.04989844746887684, 0.09700844170791761, 0.0160990558631186, 0.029483659525534937, 0.03122751827218703, 0.048721358845276494, 0.06363671206470047, 0.048969271792364974, 0.049988271934645515, 0.049922589744840346, 0.0380223713416074, 0.040107302500733306, 0.06021633238664695, 0.048900254602943144, 0.11009270711136715, 0.02012358106938856, 0.08223524157490049, 0.03423614933022431, 0.031027591321617365, 0.026933110851262296, 0.024683938594534993, 0.05820985005370208, 0.03785025754145213, 0.04363810357504657, 0.09317929896392993, 0.03615211169900639, 0.045449920996491394, 0.002942820158620764, 0.05410013307950326, 0.036126978761915646, 0.08157468094889607, 0.0246238916380597, 0.04453795636072755, 0.0432833552892719, 0.03709905481498156, 0.05919654853641987, 0.050483629639659605, 0.040091638519827805, 0.032631183309214454, 0.012951059649432344, 0.02857086368437324, 0.02107786084525287, 0.05411849084443279, 0.040236621097262414, 0.02831429771945945, 0.020573091859530126, 0.05996702505009515, 0.044381950981915, 0.004187160720383483, 0.05018950845780117, 0.021686109813994596, 0.041642705111631324, 0.02086172199675015, 0.0430259632079729, 0.03504094953781792, 0.028937791673732654, 0.013793951964804103, 0.027956431565274085, 0.03538144858820098, 0.048929723378803046, 0.04024587292224169, 0.0529304303095809, 0.05719319424991097, 0.004733178273974252, 0.005210683722647705, 0.009610319626517594, 0.04547287583617227, 0.01841917065238314, 0.06714755403144018, 0.06986288832766668, 0.040517442992755344, 0.015122596473832215, 0.03920494931350861, 0.031875848304480314, 0.06215421482920647, 0.020361200640244142, 0.07538719475269318, 0.03368545709443944, 0.05396551512447851, 0.00652889024266707, 0.026521335089845315, 0.033649121544190815, 0.03465210147468107, 0.026583984228117124, 0.0030246508457431836, 0.11554886826447078, 0.028698278990175043, 0.12112824459161077, 0.06531812862626143, 0.04563560210434454, 0.016832404636910984, 0.024996098629864197, 0.07701259824846472, 0.038629137711333375, 0.0691721328933324, 0.016350554867780635, 0.03270926233381033, 0.01746819873473474, 0.026069720841145942, 0.09517938949699913, 0.12013934765543256, 0.03662943055054971, 0.07305971107312612, 0.04962883497189198, 0.046346374321728945, 0.07314612250775099, 0.009088320940333818, 0.010877247982924538, 0.031675096933862994, 0.03243200953251549, 0.00999352736731193, 0.00726990815850773, 0.020231290021911263, 0.013019791005977562, 0.04682638017194612, 0.010573030199988611, 0.0636722401582769, 0.0384904146194458, 0.030088719379689013, 0.03411912578823311, 0.00929299763603402, 0.05184347488518272, 0.05249466494257961, 0.023937624712873782, 0.017864731206957783, 0.06310239966426577, 0.052256736638290543, 0.05760201159864664, 0.11576707155576774, 0.09951100777834654, 0.13373671445463384, 0.1906226205506495, 0.1859845622841801, 0.09974593695785318, 0.2199085990765265, 0.1435394555862461, 0.1060722717749221, 0.15829867789787905, 0.17689935836408818, 0.16557626452829155, 0.2449189248893942, 0.14105164765247277, 0.0758659215644002, 0.10285904883806195, 0.11876568065157958, 0.1595040817878076, 0.15406685854707444, 0.14250505609171732, 0.07571891695261002, 0.10655174497514963, 0.13774277163403376, 0.2582651658781937, 0.25434478053024834, 0.08046470622399024, 0.1733385015811239, 0.10826128002788339, 0.10714117477514915, 0.13484645847763332, 0.11784507147967815, 0.10952498364661421, 0.19098721098686966, 0.11406461362327848, 0.11954472027719021, 0.07929110527038574, 0.11633163983268396, 0.17242136650851794, 0.17074553429016046, 0.15435261678482803, 0.12353845526065145, 0.14151767907398088, 0.13524587133101054, 0.10662107768335513, 0.0902506129017898, 0.08424810213702065, 0.11330575362912246, 0.1666639968752861, 0.06527006799089057, 0.1377589071967772, 0.0837774770334363, 0.11161264590919018, 0.12088561403964247, 0.06594487106693642, 0.14592917449772358, 0.19213374517858028, 0.141511680824416, 0.1197576852781432, 0.10518641038132565, 0.10527331714651414, 0.07578997992511306, 0.13514960078256472, 0.18964193388819695, 0.06014583259820938, 0.21969059934573515, 0.17921067933951104, 0.11510368143873555, 0.11810547964913504, 0.06236262007483414, 0.11411969709609236, 0.14724614311541828, 0.15517327774848255, 0.14519406322922024, 0.1022925738777433, 0.12734867366296904, 0.10464103786008698, 0.12791629534746918, 0.1240902127964156, 0.2425058643732752, 0.09778296229030405, 0.14095011167228222, 0.11008677671530417, 0.10298060160130262, 0.16620380085493835, 0.06787824803697211, 0.14532211635793957, 0.0973470713943243, 0.12683874102575438, 0.08871029769735676, 0.06884006464055606, 0.09778801059084279, 0.07846735697239637, 0.05598029594070145, 0.09073769926492657, 0.1640581102775676, 0.18206165278596537, 0.18875058314629964, 0.14450834931007453, 0.17956274401928696, 0.0681242441226329, 0.09165978085781847, 0.1389296922300543, 0.14661068149975368, 0.11973838774221283, 0.20487665997019835, 0.14320444927683898, 0.12133173724370343, 0.1135952030973775, 0.09579264266150338, 0.12868591690702097, 0.08775888303560869, 0.11032501714570181, 0.05814247152635029, 0.085336336599929, 0.2204209744398083, 0.09146878682076931, 0.13840902516884462, 0.20512204537434237, 0.10594868340662547, 0.1452042412545, 0.13610473381621496, 0.12321638182869979, 0.16176076712352888, 0.10155829042196274, 0.22327308782509395, 0.11249516891049487, 0.1427895522543362, 0.13649835198053292, 0.11055831105581351, 0.13221486897340842, 0.13354350839342388, 0.1658226405935628, 0.07387196498789958, 0.11477844603359699, 0.16012640696551117, 0.16651549270110472, 0.1806761385606868, 0.09806728881916829, 0.10968186094292573, 0.13318104855716228, 0.11869395950010844, 0.21437095265303338, 0.1362688850079264, 0.0781054263934493, 0.19025404032851967, 0.1135884313178914, 0.07264427800795861, 0.16718114912509918, 0.13687162766499178, 0.1899859375719513, 0.14080103752868517, 0.08598332652556044, 0.12049464216189724, 0.18612877811704362, 0.08436901029199362, 0.09592950317476477, 0.13408949838152953, 0.1090905787423253, 0.11777617303388459, 0.07691734550254685, 0.08471433711903435, 0.05954024687941585, 0.10168320193354573, 0.08620441359068666, 0.16380823297160013, 0.10952833560960633, 0.14326958863862924, 0.10092115961015224, 0.17732352417494568, 0.11003782719905887, 0.11199818950678621, 0.15772930559303078, 0.08042053359427623, 0.11335338678743158, 0.12674955438290322, 0.11925333019878183], [0.010720423273076969, 0.020272185327485204, 0.021973187802359462, 0.036802643577435186, 0.008769703796133399, 0.005248107049348099, 0.028929086069443395, 0.022500134705166732, 0.043023201570447, 0.015305933243195926, 0.059933675053928576, 0.023640982773421065, 0.021110133667077337, 0.026583093650905148, 0.012583459910404469, 0.06322930606880359, 0.01533460134773382, 0.022492245039237396, 0.004710171695998204, 0.008931057727230447, 0.021135712740942836, 0.003078917319986171, 0.036314600479922125, 0.07231647774044957, 0.02573464498189943, 0.04695078617494021, 0.0346900417602488, 0.04033836742330875, 0.039763977351997576, 0.03654851185690079, 0.016709912102669477, 0.02806241873518697, 0.032909253745206764, 0.03573899243825248, 0.054361776182694097, 0.01103991487928267, 0.07560189001794372, 0.018684018137199537, 0.05058479581826499, 0.040036979131400585, 0.047051803075841496, 0.05082539076517735, 0.03742243103416903, 0.07045034359076194, 0.10378406848758459, 0.008027564601174422, 0.041640296312315125, 0.04327375741143312, 0.005223339248914272, 0.12755133850233896, 0.060812221840023994, 0.020468690765223334, 0.11235136698399271, 0.051567378986094675, 0.012401389457019312, 0.015513809231509055, 0.015082354258213724, 0.026087355966280614, 0.008576313682299639, 0.05224730160885623, 0.050816834438592196, 0.03159107733517885, 0.024176458861412745, 0.025288889883086085, 0.024625682970508933, 0.008834046727445508, 0.027164944214746356, 0.03753003651010139, 0.04306004602195961, 0.035495266052229066, 0.055960031492369514, 0.021454201811658483, 0.012956428557767399, 0.029897911939769983, 0.06257912702858448, 0.015150674252903886, 0.025369562607790743, 0.0236479699877756, 0.03514564409852028, 0.03202588936047895, 0.04457672106634293, 0.02923167876100966, 0.050840159079858234, 0.013561378998149718, 0.013801733065130455, 0.023772404828507985, 0.02096673716524882, 0.05192281598491328, 0.010463362825768334, 0.05898845541690077, 0.021988958652530397, 0.03644782743815865, 0.028882541959839206, 0.026556722387405376, 0.04512942855113319, 0.062352245274399004, 0.009590596309863031, 0.03728942459981356, 0.0306922661007515, 0.029283695255539248, 0.037359133894954405, 0.0436172555865986, 0.022617243064035262, 0.04381580511108041, 0.042568766312407594, 0.0919719748198986, 0.014661910211933511, 0.06512961802738053, 0.02512098300004644, 0.04723254105608378, 0.02922189428604075, 0.025939581217244267, 0.013783031791847731, 0.03359344435323562, 0.008424955420196056, 0.024922465705978017, 0.012415900776561881, 0.04976672685838171, 0.036446205739464076, 0.07080462708004884, 0.017050212681559578, 0.014661289352391447, 0.03161707201174327, 0.015749759606218765, 0.009852409894977297, 0.06741167378744908, 0.0310185871619199, 0.06168553712112563, 0.03206026394452367, 0.06703866273164749, 0.03280610963702202, 0.03650198810334716, 0.07307106974933829, 0.03279404189171536, 0.028858491286103214, 0.043850091485572715, 0.030039532376187186, 0.012771420047751494, 0.0822865456076605, 0.03799816121214202, 0.011921469271848244, 0.024922966125554273, 0.038295549540115256, 0.09470780087368828, 0.08510883737887655, 0.05625873278560383, 0.037166389237557135, 0.06911903074277298, 0.016631375066936016, 0.007447489254575754, 0.06484017534447567, 0.020016453960644345, 0.05523842985608748, 0.04568278403686626, 0.03309327244226422, 0.01646387530490756, 0.030605708781097616, 0.04034002644142934, 0.03222731926611491, 0.013553361258735614, 0.02161965748694326, 0.02741273502553148, 0.022247078462636898, 0.033056129435343404, 0.009442991194581347, 0.06395940974886928, 0.049413596878626516, 0.011316682528039175, 0.016357562438185726, 0.08744646515697241, 0.0035022794909309596, 0.024882910507065908, 0.017711253371089697, 0.07696681749075651, 0.00822312941974295, 0.025413658902315155, 0.10306623950600624, 0.0371543588116765, 0.06298162721629653, 0.055110614214624674, 0.0668874444173915, 0.06517479488892214, 0.05027244579313057, 0.07009675220719405, 0.017935215728357434, 0.05006603883313281, 0.019375732002247657, 0.06941167611096587, 0.012567824767237263, 0.03538775557119932, 0.044501746339457374, 0.04831522510253957, 0.021552229765802622, 0.0562731041572988, 0.03590191208890506, 0.06846657182489123, 0.008125510282947548, 0.010949689229684216, 0.008065312352430607, 0.021085519809275866, 0.007974375089231347, 0.04562866408377886, 0.014710788482001849, 0.016131444035896232, 0.019980900422004715, 0.039858470138694556, 0.02805879875086248, 0.016630611715040038, 0.04491351531552417, 0.030295988079160452, 0.05883472652307578, 0.08713087173444883, 0.017265282837407928, 0.028676501408751522, 0.08303761601980243, 0.021802336077338884, 0.03363196139356919, 0.045977495544190915, 0.03402945399284363, 0.00771355301341308, 0.026038260565006306, 0.05190269063626017, 0.04951420665851661, 0.018939308456278274, 0.04263361729681492, 0.07120450812258891, 0.05034993788493531, 0.016287990546386157, 0.022908740011709075, 0.04725244588085583, 0.03499254284958754, 0.07058974182499306, 0.018034029086785655, 0.023684799172250286, 0.036626567132771015, 0.03998879635972636, 0.030878042203507254, 0.05094612928639565, 0.09987726741071258, 0.03880159756434815, 0.02813774799661977, 0.018670808756724, 0.07433550618588924, 0.015921751270070672, 0.03993422178817647, 0.031101575387375693, 0.06279988839690175, 0.05060665821656585, 0.03313797093661768, 0.014006350389016526, 0.03497095865064433, 0.06393467714743954, 0.038286752333598476, 0.0358437073550054, 0.039877197705209255, 0.02128854427220566, 0.021614641416817904, 0.05467232469735401, 0.016875182877161672, 0.03051072744918721, 0.038676207685577016, 0.010436233299385225, 0.028764687212450162, 0.07399087824991771, 0.005511579228498573, 0.10100561007857323, 0.0256591036782733, 0.03612631719027247, 0.01223174891700702, 0.047543065822018046, 0.06945963496608393, 0.027426064845972827, 0.03170303222058075, 0.01653449553331094, 0.05338629049115947, 0.0285438240638801, 0.027307775836171846, 0.025186213964064206, 0.05014955631590315, 0.021739754792568938, 0.02312638860062829, 0.09329353711966958, 0.01414536779546844, 0.02285418749254729, 0.05709962427083935, 0.07558561196284634, 0.0730111143950905, 0.005446817301812449, 0.034672179325882874, 0.03866594823609505, 0.050414025517446656, 0.024972894428563968, 0.04004071107400315, 0.06341583534543004, 0.029833668244204352, 0.116424097014325, 0.044155710443322144, 0.04795654470633183, 0.10804910212755203, 0.02913024116839681, 0.05393500140468989, 0.026826916728168726, 0.042566262518188784, 0.026904351144496883, 0.04519311245530844, 0.035372742983911715, 0.045700364879199436, 0.008670613934685076, 0.039543843628572564, 0.012759380292014351, 0.0573005588459117, 0.03642840776592493, 0.02836002080169107, 0.012246896363129573, 0.022164611012807915, 0.020674283483198712, 0.02538749628833362, 0.04035974466907127, 0.052228278879608424, 0.06814318203500339, 0.03442994910957558, 0.047163730819842646, 0.06258889793285302, 0.026913105942574993, 0.04588042771709817, 0.048374447638967207, 0.03487765669290509, 0.02969428358067359, 0.05098913822855268, 0.07801324741116591, 0.05346272746101022, 0.051810708429132185, 0.04135596299810069, 0.02738021284208766, 0.028747289574572017, 0.03060328301840595, 0.06138284264930657, 0.05196416251627462, 0.025716796118233885, 0.03384719270148447, 0.07441561403019087, 0.007900346918696803, 0.002721491365394156, 0.012176666292361915, 0.040064629433410506, 0.06859710160642862, 0.003043526629751016, 0.040540231591356654, 0.029521552313651358, 0.05553851196808474, 0.07023638792868171, 0.03971344684915883, 0.1997468809464148, 0.09504627449704067, 0.13337023769106182, 0.1066620544131313, 0.15154797370944703, 0.16550984952066625, 0.1412569044956139, 0.17652070868228162, 0.10205653868615627, 0.1292006400014673, 0.13778788064207348, 0.1804974531488759, 0.07052112836390734, 0.2557574361562729, 0.11431051471403667, 0.14065184124878474, 0.08082217882786479, 0.09928513025598866, 0.09540035442582198, 0.0949959611254079, 0.13551264415894235, 0.03753990240927253, 0.11479702432240758, 0.09025484017495598, 0.05780266797436135, 0.15342687788818563, 0.08981950567769152, 0.11336799564638309, 0.09348280089242117, 0.10000464200441327, 0.08922828454524279, 0.11611364010189261, 0.10221070862774338, 0.136187949350902, 0.12734819868845598, 0.16912763539169515, 0.14225159612085136, 0.12011717313102313, 0.10432413486497742, 0.08579594908016068, 0.11279566492885351, 0.10710502921470574, 0.11884383431502751, 0.08285929701690163, 0.16517404253993714, 0.19504894874989986, 0.12305228491978985, 0.07205039701823678, 0.13842498431248323, 0.13934741195823463, 0.17639775813690253, 0.0916411822129573, 0.14283889532089233, 0.12156414905829088, 0.13872651170407022, 0.17752998881042004, 0.07492452207952738, 0.16509192623198032, 0.10010366061968462, 0.13130645986114228, 0.13259123877755233, 0.15215626678296498, 0.16998974127428873, 0.10790914070925542, 0.09283917650048222, 0.08942323444145066, 0.11432628386787005, 0.17487085078443798, 0.11210880428552628, 0.11781255608158452, 0.14046219071107252, 0.12676898762583733, 0.113557707252247, 0.09956085296081645, 0.15512347327811377, 0.08345048422259943, 0.11247496213763952, 0.12197030654975347, 0.08367630067680563, 0.1014725643077067, 0.12482090001659733, 0.10618940727519137, 0.13242170001779283, 0.09820385077702147, 0.09262279846838542, 0.12835629816566194, 0.09555506041007382, 0.2859729533748967, 0.0782508160918951, 0.1570388554994549, 0.18015600075679167, 0.14913967650915894, 0.11359877897692577, 0.09355783329478332, 0.16382321502481187, 0.0785225625815136, 0.14432631193527154, 0.08692986930587462, 0.10918929201683827, 0.13297116410519394, 0.10136436511363302, 0.1190737626914467, 0.13318482121186598, 0.1407558335257428, 0.11449932386832577, 0.15676182322204113, 0.07682511902281217, 0.11313314789107867, 0.2559942991605827, 0.16800954538796628, 0.13490891084074974, 0.08316692443830626, 0.12059345043131284, 0.05734793416091374, 0.09895332663186959, 0.09240635936813694, 0.10972460186375038, 0.150014498138002, 0.10792600230446883, 0.14421682352466242, 0.14248707491372312, 0.09336457973612206, 0.16517571173608303, 0.19042565540543624, 0.20914141541080816, 0.19485678763261863, 0.11798547394573689, 0.15013358103377478, 0.16255867002265795, 0.1188860120517867, 0.17244009407503263, 0.08866710215806961, 0.12937549847577298, 0.13394923162247452, 0.16776783764362335, 0.11287441570311785, 0.11920932041747229, 0.1288227095667805, 0.16752047091722488, 0.14434030332735606, 0.09998954460024834, 0.05361231389854636, 0.1158334594219923, 0.1392713753240449, 0.19228824760232652, 0.12875219620764256, 0.19929579086601734, 0.10734223148652486, 0.10405465468232121, 0.10223276101584945, 0.12128623468535286, 0.12494645613644804, 0.07993990688451699, 0.08820573227213961, 0.1929780598729849, 0.12338445495281901, 0.14519992577178137, 0.0639230470572199, 0.14022425562143326, 0.11908418498933315, 0.10887010914406606, 0.07733077688940934, 0.0801622017419764, 0.1580767019518784, 0.20184368986104215, 0.2043503067855324, 0.1799133430634226, 0.08944462186523847, 0.13444773772997515, 0.21964696954403604, 0.139703384999718, 0.15000584003116402, 0.07982149573841266, 0.2135711227144514, 0.19067896609859808, 0.15194498454885824], [0.038292441849729845, 0.020533692723672305, 0.0433114669950945, 0.027247057130028094, 0.06073416317147868, 0.0010197718698431604, 0.03941683544378195, 0.055615071074238846, 0.025821631474952613, 0.04571227316877671, 0.03138469412390675, 0.02854603948071599, 0.004592148163023272, 0.022108643748132244, 0.03738387328173433, 0.023053301897432123, 0.04158277011343411, 0.06383353471755981, 0.09192639762269599, 0.018666593357920647, 0.04711431650710957, 0.025040959972622137, 0.020269579753013592, 0.03088792845872896, 0.02861266483419708, 0.027959269537989582, 0.015362599398940802, 0.016435975641278282, 0.033762660808861256, 0.028570738155394793, 0.06531476309256894, 0.04645593058583992, 0.02488422516866454, 0.038395222941679616, 0.07506034443421022, 0.08300691909555878, 0.03220685804262757, 0.022845926328695247, 0.058958335247422965, 0.04749280673318675, 0.06862118959959064, 0.03280701548127191, 0.054950310316468985, 0.002042638707540131, 0.019146125929962312, 0.11572184041142464, 0.009265302381079112, 0.044530187134764025, 0.012162039621866174, 0.040123183612844775, 0.038650650664099624, 0.055860548080610375, 0.03714049634124551, 0.027758406209094182, 0.0018021667450999043, 0.01802446343936026, 0.03083387975181852, 0.02620366874283978, 0.092363062048597, 0.008667062652031226, 0.050743498373776674, 0.01624095449889345, 0.03514956942360316, 0.02946462661826185, 0.04271327391532915, 0.011248006302464222, 0.01041345063796533, 0.023904278109382306, 0.015604826222573007, 0.034168105838554244, 0.057096218025045734, 0.042315526865422726, 0.01996006430791957, 0.008788437299829508, 0.004708911317201065, 0.03826705106933202, 0.010576873252700483, 0.031702618314219375, 0.022093352961487005, 0.03472466740225043, 0.09158216323703527, 0.04479360460702862, 0.017271111453218118, 0.0418845960604293, 0.04799646292147892, 0.05167935422754713, 0.02226764994806477, 0.09738662320056132, 0.056464766551341326, 0.03628345232989107, 0.02801919775083661, 0.01805425451935402, 0.05050634020673377, 0.030347037661288465, 0.0729868228414229, 0.03821742980341826, 0.06601045147648879, 0.03418331180832215, 0.05069761583581567, 0.03781542494626982, 0.0347089661019189, 0.021436542937798158, 0.03460450902847307, 0.00699894580092015, 0.06278099119663239, 0.03275298713041203, 0.027067425161866204, 0.05522791934864862, 0.022055443209995116, 0.04468316964006849, 0.0602209260687232, 0.05470479938334652, 0.012675831426999398, 0.0582470405580742, 0.020633143905018057, 0.010724329938446837, 0.04146371435906206, 0.039575385328914435, 0.02770874253474176, 0.06689148170075246, 0.056022314221731255, 0.04291504308847444, 0.044791999871709516, 0.048771363483475785, 0.03405690751969814, 0.012452923343516886, 0.009029982195767974, 0.024554413044825196, 0.012206631246954203, 0.0332340481025832, 0.01856794624057199, 0.015734467123235975, 0.00806336580509586, 0.016226937661745718, 0.014392750637073601, 0.016396400086315613, 0.06883134546556643, 0.006029591945532177, 0.01585543804269816, 0.03730775183066726, 0.022321715618350675, 0.028259925012077605, 0.026093525545937673, 0.013660942137773548, 0.035310752024608, 0.043552750655050786, 0.03606190725362726, 0.002379879941664902, 0.04987676827503102, 0.024136713672695414, 0.08324046406362738, 0.05337627870695932, 0.019243399013898203, 0.058298222454530854, 0.01669361029884645, 0.002674554553647925, 0.09194880963436194, 0.08892579363392931, 0.04347339937729495, 0.03721425988312278, 0.04134532017633319, 0.04179299383291176, 0.06747391580470971, 0.020032927094559585, 0.012994483346119523, 0.060222839537475786, 0.06785653491637536, 0.017366367591811076, 0.051758254279515574, 0.0287441343867353, 0.08339888841978141, 0.026489639022786702, 0.0051653881174778295, 0.05297984801498907, 0.022881851365257586, 0.03549733219136085, 0.011415047205186315, 0.019594581598149877, 0.032786852813192775, 0.03496892304558839, 0.05442446942574211, 0.03651127724775246, 0.007605592154764703, 0.017597537687314407, 0.023045758284362297, 0.09974232715155397, 0.017253618820437362, 0.030805924109050205, 0.0368517355860344, 0.017203300359791944, 0.08262547384947538, 0.026937127778572694, 0.022912872289972644, 0.032274606371564526, 0.034491638120795996, 0.056508369211639674, 0.045375204112912924, 0.01700764648350222, 0.018986753321119716, 0.007345282372885517, 0.004964926396496594, 0.037189479784241745, 0.024466839618980885, 0.004930543330764132, 0.03315734989675028, 0.02655934153257736, 0.027971649409404824, 0.04306522663682699, 0.021753191482275724, 0.018946103984490037, 0.04379304704655494, 0.04495864807228957, 0.046641014582876644, 0.0297214385521199, 0.019716071596901332, 0.04023877205327153, 0.01597080087023122, 0.07255098622824464, 0.01637988963297435, 0.04604315059259534, 0.047733316863221784, 0.04059132867093597, 0.05987881549767085, 0.05049291878406491, 0.03627556775297437, 0.014489772663052593, 0.028261183694537197, 0.05169414968362876, 0.04721047170460224, 0.019727357330599, 0.03128295119053551, 0.05216447962448001, 0.009038408752530813, 0.016792457584025602, 0.03974612509565694, 0.0331544796936214, 0.0362774608656764, 0.032316244672983885, 0.008792974154597946, 0.02750046451443008, 0.012460375354359192, 0.03773912029074771, 0.02402191742190293, 0.047082500000085147, 0.0823765057804329, 0.061767897701689174, 0.029010863109890903, 0.02269694548366325, 0.03536739952063986, 0.014119633506717426, 0.015011852773438607, 0.006692261967275823, 0.018082361136163985, 0.038111873503242216, 0.08693134172686509, 0.024400002223306468, 0.022035024394946437, 0.02311054989695549, 0.06934728313769613, 0.07272241131535598, 0.03737459092267922, 0.0345532864199153, 0.015127073108617748, 0.021237947612202594, 0.06804007185356957, 0.029463615601084063, 0.02609721677643912, 0.03845088316925934, 0.04642507081319179, 0.04684363192479525, 0.04477330283927066, 0.025118820169674497, 0.01604232863922204, 0.024212957260065844, 0.051884383761457036, 0.08270427212119102, 0.03707228660849588, 0.006721800717059523, 0.027376099223537103, 0.04729038616642356, 0.008927402967986251, 0.05921086562531335, 0.06652936791735035, 0.05511015959616218, 0.025299899113763655, 0.03959544621674078, 0.07958067008959395, 0.046769617324961085, 0.016830326623416374, 0.03593777266464063, 0.01253784793828215, 0.032997592219284604, 0.0963407496788672, 0.04588984239048191, 0.03605600060628993, 0.05099838666085686, 0.047360777389258146, 0.03912845466818128, 0.004210380612806017, 0.042630713166935105, 0.059860861461077414, 0.03818123674552355, 0.030483660687293326, 0.051714159681328704, 0.0642966620091881, 0.05965069880975144, 0.047786629359636984, 0.032336994273854155, 0.06577321527791874, 0.042554642605994425, 0.04890832916966506, 0.027370983069496493, 0.07924263751400368, 0.0647587850689888, 0.032720851711928844, 0.026673099624791315, 0.012222147646493145, 0.06068393122404814, 0.03467265430039593, 0.019676719958494817, 0.018964181853724376, 0.012928862224466034, 0.06571687651532036, 0.012433075346052647, 0.013024314290045627, 0.0455344121770135, 0.09827931744179555, 0.02156633311616523, 0.03368502961737769, 0.07238209207675286, 0.04325576266273856, 0.030519741786909953, 0.106377252909754, 0.07453230848269803, 0.1064234407884734, 0.03161593885826213, 0.021791717004297034, 0.056570556946098804, 0.10869331005960703, 0.06931913750512259, 0.0279789911583066, 0.05318834825551935, 0.014967634342610836, 0.03328914175342236, 0.04714249945910914, 0.02657561280232455, 0.0676888892693179, 0.021546489359544854, 0.00953307859266975, 0.032402954663016965, 0.02520149457268417, 0.03249240254185029, 0.14042332422520432, 0.09534670944724764, 0.1095328207260796, 0.11205036206437008, 0.16001140885055065, 0.08628975293998208, 0.08560154201196772, 0.10781092276530606, 0.13436786058757985, 0.21034964200641426, 0.11156422565025942, 0.16986091461564812, 0.10459387289094073, 0.12769806491477148, 0.1607267747500113, 0.08877399856490747, 0.07440958185387508, 0.1474008626703705, 0.17566679950271333, 0.1007949724527342, 0.1181844746960061, 0.052105582784861326, 0.09103775423552309, 0.2412891425192356, 0.12268417967217309, 0.07379075113151755, 0.16498109432203428, 0.12417283122028623, 0.09476223973823444, 0.10795455505805356, 0.154917320768748, 0.1358162478676864, 0.10848504730633327, 0.10465184692293406, 0.15303582458623818, 0.16641311533749104, 0.16497413255274296, 0.10229731005217348, 0.15586836902158602, 0.15938879868813924, 0.11064214405736753, 0.18093589533652576, 0.14625812827476434, 0.13462007205401147, 0.10447979079825537, 0.16339655220508575, 0.11625668885452406, 0.143675936119897, 0.10015210123466593, 0.07977464289537498, 0.16289609191673143, 0.12266390504581587, 0.13440285942384175, 0.09792911194797073, 0.10938291198440961, 0.07658944345478501, 0.1111926870154483, 0.11895389269505229, 0.22377201462430613, 0.12326736695000104, 0.15657268837094307, 0.1510562122400318, 0.15358812495001725, 0.0790244002959558, 0.10392671690455504, 0.1321762196187462, 0.08182921979044165, 0.12317105568945408, 0.10202295120273318, 0.11856046452053956, 0.14662845911724226, 0.09011134358921222, 0.11112306253718478, 0.10564871664558138, 0.14027156308293343, 0.08962259481527976, 0.08168915659189224, 0.09649491962045431, 0.12068049290350505, 0.1130939760644521, 0.12321870241846357, 0.10779219519879137, 0.15042577178350516, 0.17579539545944758, 0.06359037490827696, 0.14152613362031324, 0.09056651166507176, 0.22993608457701548, 0.20034966431558132, 0.13998018657522543, 0.12287292097296033, 0.10050522442907095, 0.0897282020055822, 0.19205008181078093, 0.260811626378979, 0.14623808435031346, 0.1385983500097479, 0.08657671897006886, 0.15139898099005222, 0.17183941416442394, 0.11387205895568643, 0.10788720367210251, 0.17559802319322312, 0.08101114404520818, 0.11565125919878483, 0.09585521037557296, 0.14021653389292105, 0.1316055716680629, 0.0944176728704146, 0.1466562519116061, 0.15364489118967736, 0.1544941727604185, 0.14552699322147028, 0.13889121929449694, 0.1099993542635015, 0.08616013239536967, 0.15472001635602542, 0.12153288216463157, 0.08842126892081328, 0.10337565147450992, 0.19261125741260393, 0.1784109172544309, 0.12065075949898788, 0.08192510357392685, 0.13763945789209434, 0.10926612253699984, 0.1645941258008991, 0.09199580496975354, 0.11694039431001459, 0.14924164675176144, 0.1280134344207389, 0.1152817290276289, 0.24292218631931714, 0.08934380513216768, 0.12552927700536592, 0.1775239905608552, 0.1325387880206108, 0.16997170581349305, 0.12784799401249203, 0.1419622687888997, 0.18248040388737405, 0.175578807081495, 0.13365748870585645, 0.05718591356916087, 0.15394312090107373, 0.06667329876550607, 0.12239027901419572, 0.08869116979518107, 0.08916936734957354, 0.1185416148177215, 0.22598330596727983, 0.1669194788805076, 0.09676011146179267, 0.16969373715775354, 0.16792704910039902, 0.08715786385749068, 0.1735588897551809, 0.21311921839203152, 0.173903029145939, 0.15357094444334507, 0.12569809651800565, 0.16419260948896408, 0.2281380482017994, 0.15962368037019456, 0.05771873997790473, 0.10583468952349254, 0.08564358404172318, 0.09425902459770441, 0.09622165321239404, 0.15575152529137476, 0.1865669217492853, 0.12387773634067603, 0.09638068146471467, 0.12246650563819067, 0.08413981473339455, 0.14643506306622708], [0.1327181655381407, 0.04500040511733719, 0.049221544326948266, 0.03212309628725052, 0.058730646036565304, 0.03058265894651413, 0.028374527880389775, 0.021326601605064104, 0.046802560200116465, 0.03429487653608833, 0.038344706009541235, 0.056101204095674415, 0.019064333622476885, 0.04577316490135022, 0.01594004118149834, 0.02093535492063633, 0.038408522228045125, 0.015887436057840074, 0.04741745202669075, 0.020629824172439318, 0.06839985147650753, 0.06568226444401912, 0.08755718850131546, 0.003348777482252834, 0.015665315923147967, 0.031038169682558094, 0.03776927438697644, 0.024321412601109062, 0.007309064718096384, 0.006266136038383203, 0.04664570325985551, 0.017394095925348144, 0.06071749835142067, 0.0699944087703313, 0.07964547696922507, 0.04599227064422198, 0.03504732098164303, 0.03868813293852976, 0.035903988406062126, 0.05274055924798761, 0.05426148531426277, 0.02176827022672764, 0.011477519076184502, 0.01660225573661072, 0.04146366346893566, 0.01004355151339301, 0.023011856978493075, 0.03240702926580395, 0.03240883077627846, 0.012693432625383139, 0.01319283270277083, 0.03815246007538267, 0.03244531899690628, 0.02127844258211553, 0.01410916880039232, 0.02813438415926482, 0.02091989789291152, 0.08203992526978254, 0.0237569087850196, 0.025283163047528694, 0.04015541063355548, 0.05622078910736101, 0.04853706194886139, 0.06415463105908462, 0.04141945351979562, 0.10157237680894987, 0.044124155172279904, 0.043645469072674, 0.018498815396534543, 0.00906988768838346, 0.022926207199426632, 0.04070481026012983, 0.032044365869036744, 0.0468965712269502, 0.05401519745854395, 0.008452633711775499, 0.06754431381289448, 0.0321742103302053, 0.05700847666178431, 0.03458571021578141, 0.04403014075277107, 0.02491561759130231, 0.04348978599799531, 0.02190575159953109, 0.019605631540928568, 0.025575036582137858, 0.01902565373373883, 0.06262874150914804, 0.017079852787511687, 0.03025717587609376, 0.012409888108127883, 0.02524540087740336, 0.03127626083525164, 0.01715547381900251, 0.021425119800759212, 0.020368359184690883, 0.02655798615887761, 0.11800091740276132, 0.04313146522534745, 0.03632567756410156, 0.09652634936251811, 0.08749459364584514, 0.02645879621351404, 0.03160916707877602, 0.03609845993508186, 0.04711020797757166, 0.02328713863555874, 0.022489739548681036, 0.03531189874878951, 0.0023283153090492953, 0.04085661889985204, 0.02636329919498946, 0.0278881980837988, 0.021549169572868516, 0.011573083948210945, 0.04073928662442735, 0.01797704741225711, 0.041518767297800095, 0.05737624264189175, 0.040606473572552204, 0.046786299108394554, 0.057126433189426146, 0.04454617002712829, 0.011424137878098657, 0.04031565685623458, 0.04567007507596697, 0.03160709754696914, 0.0485896721615323, 0.03564960562757083, 0.014862956745283944, 0.04021521671009915, 0.03064203415332096, 0.0350717855617404, 0.05337852126519595, 0.10268345754593611, 0.06257880133177553, 0.02742726246028074, 0.024380599514448216, 0.04410464729049376, 0.0423996278883091, 0.03470021978552852, 0.025012385166649307, 0.0630918959421771, 0.05878681516540902, 0.029108154853539805, 0.05290642713329621, 0.05234338556017194, 0.029825471541179076, 0.0007094335950179291, 0.043776684174580235, 0.015498331847733684, 0.062067911960184574, 0.022052668001768843, 0.08122866201613631, 0.04100576428962605, 0.041954471596649716, 0.05166542390361428, 0.016007723353270973, 0.05422908865979739, 0.017990733463583247, 0.03754512373624103, 0.051983548261757405, 0.020093822219808186, 0.047314175604177375, 0.01155162527824619, 0.03897377582533019, 0.03046878719968455, 0.09712669000561748, 0.020822485709296804, 0.06655262809778963, 0.057427594172103066, 0.03637622163764068, 0.0259561052412859, 0.03125731274485588, 0.028700813318469694, 0.02247011461960418, 0.06429614632257394, 0.04344060238716858, 0.055159648547747304, 0.07033337772424732, 0.03347654973289796, 0.039109065530023406, 0.028730706178716252, 0.04044987108292324, 0.02769955517058926, 0.02798233294327344, 0.044122231525502036, 0.049416680820286274, 0.006953912279901228, 0.03367687023377844, 0.020700218787949, 0.02430899710660534, 0.08897396283490316, 0.05736232588865927, 0.014973546078960811, 0.042629573228103776, 0.06712949821459395, 0.014743870456836053, 0.03373524460143276, 0.007304130072173263, 0.023735930178580538, 0.05364250531420112, 0.040241357271692584, 0.03954711077468736, 0.025010497142959918, 0.02759871638513037, 0.04796619347429701, 0.025351094580920677, 0.017637243860268166, 0.03268765777881656, 0.12277217209339142, 0.06987656080829245, 0.02965368004515767, 0.016903886604788046, 0.013145164769542004, 0.04562236388613071, 0.03495672298595309, 0.015915188140102794, 0.05019772212420191, 0.021581771484177028, 0.0308026128581592, 0.046956743712403944, 0.016092373989522457, 0.043177459721586535, 0.05216818781835692, 0.013435319914216442, 0.06211454767201628, 0.023480161492313658, 0.03121379150875977, 0.01334941738085555, 0.022301320552027652, 0.028168178595868603, 0.05111853824928403, 0.023036704930875982, 0.01936803402246109, 0.045108773945165534, 0.041905047105891366, 0.0161411759244012, 0.04650409300146358, 0.016458299443391815, 0.024162869501326765, 0.07516988712762084, 0.05156873605613198, 0.05635321878695062, 0.03331961136843477, 0.04903482845319169, 0.01012849307153374, 0.029264808233295168, 0.024279828582491194, 0.06823159514793328, 0.10929808153637818, 0.02419900318740734, 0.0642129240025367, 0.035167974685983996, 0.010306542356764632, 0.023859455782387937, 0.07961185555905104, 0.006467879766465298, 0.030472271477005312, 0.04763398951451693, 0.023555633246100376, 0.03172626525961927, 0.035985192084418874, 0.031091760378330946, 0.009902435737395925, 0.02517691464163363, 0.02247658445100699, 0.032303617136286836, 0.03311372688040137, 0.03908033975000892, 0.01924103431935821, 0.03429669161726322, 0.014447956246190836, 0.02948939653911761, 0.03735746130613344, 0.03911209858155676, 0.07197532390377351, 0.014764547115191817, 0.032682205749941726, 0.05691778027851667, 0.08550242840179376, 0.05829622756157603, 0.015106913833213704, 0.03454599556113992, 0.048044272498892884, 0.0188899704787348, 0.014861679403111339, 0.012362359274577881, 0.026464706253526465, 0.03375785678092923, 0.04722876161602991, 0.01063183883005487, 0.049575977093939266, 0.09201685312603201, 0.03372751269489527, 0.08781369509441511, 0.0381671571438866, 0.022821834942858134, 0.040687928308865855, 0.051610052053417475, 0.054409965739718506, 0.05786915083548852, 0.041706402586506944, 0.027366274036467075, 0.0308328348078898, 0.03876639177490558, 0.014677867659234574, 0.025153752848772064, 0.004483082564547658, 0.007196617894805968, 0.11656500159629754, 0.08032757429672138, 0.020114090060815215, 0.001777357278375088, 0.03523099362584097, 0.027529086817854216, 0.08633515371807984, 0.022351347242615054, 0.035197195796562095, 0.016479900605710487, 0.032239770383707116, 0.03626655002257653, 0.019243611056091528, 0.07992787645863635, 0.05732934908675296, 0.019806230241166692, 0.015254635995786105, 0.06984601994710309, 0.03915398794093302, 0.06140443363359996, 0.04919506110517042, 0.034180923365056515, 0.05348817930955972, 0.0479936096817255, 0.028064910655042956, 0.04017127138961639, 0.019628080872020552, 0.05618741875514388, 0.03113287960046104, 0.0064574612853383374, 0.02256882789411715, 0.05466435191088489, 0.07906216755509377, 0.010785103775560856, 0.047585993339972835, 0.035779897921851704, 0.0757587333875043, 0.025551918894052505, 0.043942222970404794, 0.05363561479108674, 0.028909886921090738, 0.024606984241732528, 0.23409946688583919, 0.14748479745217732, 0.2138343807309866, 0.09862779267132282, 0.1277633806956666, 0.14098714611360005, 0.12315080820449761, 0.10239776037633419, 0.09370793202625853, 0.07769802718290261, 0.1321052991385971, 0.136516984552145, 0.14377260021865368, 0.1116058062762022, 0.07629387360066175, 0.0724094370380044, 0.1440670301339456, 0.08395923620888165, 0.18258613321397985, 0.1490306630730629, 0.18010573488261017, 0.15654404062245572, 0.12387430295348167, 0.061144079746944566, 0.11695963756314345, 0.1748536295656647, 0.11219586032841887, 0.11125672715050833, 0.07067355447049652, 0.0968603039426463, 0.11477311274835042, 0.09058588383985416, 0.12407836557499, 0.1619474728192602, 0.25927167758345604, 0.15124526566692761, 0.08435921224632434, 0.07367954602731125, 0.07928483560681343, 0.2054683832185609, 0.18141846944178852, 0.08032983381833349, 0.12641188821622304, 0.09304820599832705, 0.13737780121820314, 0.11567308088498456, 0.15456934086978436, 0.19316777826419898, 0.10291631040828568, 0.09561225412679569, 0.11170690799398081, 0.09544619625168187, 0.10992976371198893, 0.09547974302300385, 0.17182391642459802, 0.1561118545276778, 0.09504934826067515, 0.1694488674402237, 0.1868468038737774, 0.10435576138219663, 0.15249655209481716, 0.18251168435173376, 0.21679752958672388, 0.17304388167602675, 0.15467390311615808, 0.1585089016173567, 0.14662281370588712, 0.19433297216892242, 0.08866039144673518, 0.14696398111326353, 0.10172483684228999, 0.1757448853126594, 0.16864214358585222, 0.1889174756194864, 0.1487742175481149, 0.0853364315948316, 0.1387586064104523, 0.10347582359931298, 0.10467320041997091, 0.15281212516129017, 0.13660018651613168, 0.160402312874794, 0.16678675743085997, 0.09531469616506781, 0.1185701811420066, 0.11398762704006263, 0.09800250229558774, 0.09812575818172523, 0.1482645156128066, 0.08900159956621272, 0.06267849169671535, 0.13643949585301535, 0.13584418993975433, 0.12612975335546903, 0.08305521721818618, 0.12066263386181422, 0.09475966809051377, 0.12773774564266205, 0.13701532781124115, 0.08906773637448039, 0.20467784920973436, 0.17145103429044994, 0.0972843204757997, 0.14384053514472075, 0.11240343776132379, 0.12656355436359132, 0.07385620940476656, 0.16772232151457242, 0.06872820814273187, 0.10542596716965948, 0.14961238471525057, 0.11010365866656814, 0.08810128537671906, 0.13469883639897617, 0.1571657686893429, 0.12417615604187761, 0.09041073359549046, 0.16191650448100908, 0.24731347497020448, 0.16085803056401865, 0.11980059583272253, 0.11104636772402696, 0.0697131220783506, 0.15993837134114333, 0.14953040411429747, 0.14220084170145647, 0.1713003045214074, 0.15909671650401183, 0.13301248688782963, 0.04053061335746731, 0.09881837958736078, 0.12979324534535408, 0.09006473501878125, 0.11421423059489046, 0.21528548215116772, 0.14557554918740476, 0.1671919242611953, 0.09314491759453501, 0.12907003558107785, 0.17177955380507878, 0.10291422730577843, 0.11318698964480843, 0.14571741728910378, 0.07995843767587628, 0.1074164089347635, 0.17238198433603558, 0.1252136089439903, 0.11590636122439589, 0.12251051541950021, 0.12521985146616185, 0.11759885826281138, 0.22483546898833343, 0.0946285208421094, 0.1292704205427851, 0.17346023076346942, 0.10502168922019856, 0.12582547111170633, 0.16976422337549074, 0.14183919610721724, 0.11286087214414563, 0.12001114524900913, 0.1588088140955993, 0.15140592918864318, 0.14487371327621595, 0.11833736220640795, 0.1500385454190629, 0.17948009845401558, 0.19118074274488858, 0.12263151178402559, 0.09406643600336143, 0.1710282934031316, 0.19033047051302024, 0.20409871957131795, 0.18975211440452508, 0.06679052247532777, 0.16632295160421304], [0.03847608056717685, 0.03504073919196214, 0.020631349179893732, 0.03303602783541594, 0.053200497425028255, 0.03909826325252652, 0.022301278143588985, 0.03624481993860432, 0.03658380924857088, 0.02576965738886169, 0.05836821334170444, 0.04964327419708882, 0.015052595408633351, 0.025438956384147917, 0.03015901900029608, 0.05219142085739544, 0.049853969498404434, 0.04410431141565953, 0.05879885237663984, 0.05723150433706386, 0.05388633008780224, 0.01383066495015685, 0.035948619046913724, 0.05415123015908258, 0.0670435753251825, 0.04934388419081058, 0.014521818175645811, 0.041070611881358285, 0.06251257631395545, 0.04163008096760937, 0.046810149614300044, 0.031140187422611883, 0.042148335836827755, 0.017551639882315482, 0.021844569793237106, 0.02349489418390606, 0.055197151178228, 0.01401422478790794, 0.046503363576318534, 0.04333708169204848, 0.03324777825868555, 0.03680645694423999, 0.02555188157462648, 0.022012987273878286, 0.017277172467272197, 0.04978034844888108, 0.08158432293151106, 0.04727158396105681, 0.061174104921519756, 0.01601268514059484, 0.02823794387014849, 0.045514744839497974, 0.03716999565118125, 0.02881977068526404, 0.012056580012930291, 0.050679688940622976, 0.016666416311636567, 0.02359225208471928, 0.006368809836983148, 0.05720709743244307, 0.04132000742746251, 0.011845640439007963, 0.005635039947394813, 0.03318550570734909, 0.03939193660127265, 0.01655331300571561, 0.014777234023702996, 0.004667365042093609, 0.026660533156245947, 0.01636996096931398, 0.09528967179358006, 0.054936108578528674, 0.014702245726117065, 0.014249142093051757, 0.026522410567849874, 0.022613512817770243, 0.05728149879723787, 0.03559045772999525, 0.04239411818395768, 0.03473714226856828, 0.06300897217754807, 0.014169554176208164, 0.05335486074909568, 0.0266379141913993, 0.021627947488533597, 0.026154427456536462, 0.06259442120790482, 0.014580592878961136, 0.0095178675338892, 0.0483690804269697, 0.02856077386864594, 0.07347519163574491, 0.03126582157398973, 0.037143346188323836, 0.01794965156087918, 0.01272956800780126, 0.012787990721075662, 0.04262151901743241, 0.04545048078788178, 0.02501510948474918, 0.0681154095966901, 0.029862197249063423, 0.036782195924648216, 0.07493271878255264, 0.023735416188303913, 0.04562980741528528, 0.003256683104804584, 0.026058789641995515, 0.016191831956218396, 0.0192340369269784, 0.03957329883373209, 0.07920749618538789, 0.0656428619154862, 0.05897254377071347, 0.008664649611871158, 0.0159087081306747, 0.050692747347056866, 0.049486647958734205, 0.03929972029956324, 0.0616230983287096, 0.032527733860271316, 0.024254671896674802, 0.011056980883170451, 0.029198712137128626, 0.024587968297834908, 0.024410958867520094, 0.022689400174255882, 0.05746353617204087, 0.004125805887659746, 0.04722619675365942, 0.02141268564654248, 0.01264687833775367, 0.08835159015974828, 0.05484453009973679, 0.014843721973842807, 0.03361249083120908, 0.017238635070888058, 0.06529727724513837, 0.033477984834462404, 0.04871305018397314, 0.03643060961206045, 0.06345548214656965, 0.022124572357695018, 0.055028287560812066, 0.07789200677403382, 0.03681755777714508, 0.027041494946128557, 0.047945416732026, 0.05533205072528549, 0.030036241481346742, 0.031668006242918115, 0.0377831538207829, 0.027423499983602335, 0.04813617667449372, 0.04999269259029201, 0.03798515030315944, 0.021984341221728494, 0.0185816967527249, 0.009735322740328099, 0.04640622789572392, 0.05140865946720753, 0.04464336677587458, 0.021800921331825, 0.03231063658105476, 0.03405505172642214, 0.035817068070173264, 0.03349606779270938, 0.01896496386533337, 0.02022827902276601, 0.044934641503329785, 0.03598594865096467, 0.03111029795504042, 0.05033500672184995, 0.010498703474045863, 0.010381786801320101, 0.029707494657486677, 0.008466181511591588, 0.04294634730155979, 0.02145180319036756, 0.01793642352069063, 0.05467544935111489, 0.04374104751540082, 0.018354828569239805, 0.05019315219085131, 0.0380183069168457, 0.015810503757425716, 0.058274874064539156, 0.03319863875263503, 0.03333492251113057, 0.04161672739844237, 0.0277819445888911, 0.03452909664650049, 0.04562624849911247, 0.02215335750952363, 0.06711901484855584, 0.08849504603339092, 0.03188897795709116, 0.013180714915506542, 0.012942955396803362, 0.021895224128716757, 0.05644350804920707, 0.0972450604396207, 0.032212645946336646, 0.05009286132241998, 0.016583346661978533, 0.031999993071492226, 0.008916146072026874, 0.02535872470720538, 0.045286869031510184, 0.02851570218003222, 0.02659853541159204, 0.02619588764251343, 0.038187642116099596, 0.0408408734947443, 0.03012634753914816, 0.014340472906561834, 0.02980386359351022, 0.04602323219712291, 0.013152183366141148, 0.016238355709772025, 0.049531638223145685, 0.051214873258556635, 0.048013070066060336, 0.055615271242069345, 0.052676681961332045, 0.01193570832921458, 0.013414776418358088, 0.06350880821368524, 0.01836719486995467, 0.015083879265668136, 0.06063346178936107, 0.005876423691266349, 0.03563010792380997, 0.03569246868469885, 0.026104092032515576, 0.0046638243615494245, 0.058663355718765936, 0.054130992852151394, 0.02789585874415934, 0.012559367676398583, 0.02763829194009304, 0.1288432963192463, 0.013265273101361734, 0.040710954394723685, 0.027333685695858936, 0.05031568882986903, 0.02189538867345878, 0.05840370750852993, 0.05195701075717807, 0.00832455004898033, 0.022575888050986186, 0.005770239322113672, 0.04125203178929431, 0.04503863378028784, 0.05056070103975279, 0.062316839317125935, 0.04464026587083936, 0.049851984783474884, 0.05686197755858302, 0.0075224979082122445, 0.008622054576075502, 0.0460456781355398, 0.06585370310183082, 0.027138935967481563, 0.006789497731785689, 0.041068084338413816, 0.029014048831803457, 0.02456351898477546, 0.05297877253698451, 0.030645772881273712, 0.02125237157036151, 0.03167216566258243, 0.07051578150796038, 0.02077494245687766, 0.008031411046561385, 0.038746042509696314, 0.05784458786781345, 0.026653255868170942, 0.07215563779962914, 0.08494292199611664, 0.016575217812455127, 0.11260732396372727, 0.03422886186412402, 0.0508035283668765, 0.04757793912930148, 0.07735968926655394, 0.018044794044856514, 0.050866031620119295, 0.03807892384273665, 0.034645651999328814, 0.025646009648750936, 0.023411519193489636, 0.0642864229157567, 0.03790128676752959, 0.049446895984666686, 0.0391938111611775, 0.06487883826983826, 0.021568826732358763, 0.026250350255785242, 0.02615954869958971, 0.014576984768999475, 0.043421817145177295, 0.016509160732052157, 0.060345247254839966, 0.02589162066578865, 0.011232254960175072, 0.0681532650653805, 0.04417893330433539, 0.040682293075535975, 0.060281247831881046, 0.0034155926134969506, 0.04047573683783412, 0.023824538370328288, 0.049838933162391186, 0.012432381543996078, 0.037972410808184316, 0.05975859944841691, 0.07144141862435, 0.08007782591240746, 0.03683818524171199, 0.035492212644645145, 0.017866663335423385, 0.0540662775747478, 0.04445446941203304, 0.03076648086841617, 0.05407493907426085, 0.014526008129385965, 0.03652327035420707, 0.02220624592155218, 0.07883265308503594, 0.06284305679478816, 0.06844224634447268, 0.03444336035421916, 0.02542327204719186, 0.07696995910789285, 0.018312133449528898, 0.04021931506161179, 0.0353591960322644, 0.0789797662624291, 0.07513729709067515, 0.025673441123217344, 0.04996828907834632, 0.031274924121264897, 0.013444987341894634, 0.046180452153618844, 0.018555410306102464, 0.04978161391669086, 0.04579882709575551, 0.021039608433576565, 0.036844261522803984, 0.04650196579418012, 0.03668672265484929, 0.12717610863702639, 0.0762777312525681, 0.09143230199281659, 0.10644416324794292, 0.20790359111768858, 0.16642471828630992, 0.10060707932072026, 0.1495875096214669, 0.11096726411155292, 0.06208897368716342, 0.08943078653620821, 0.14786561844604357, 0.07329805328377656, 0.1160126333790166, 0.09934769118470804, 0.12956067068236216, 0.14080360239105566, 0.06984362471848726, 0.19099861037518295, 0.22626421946500028, 0.19499630800315312, 0.09390205410974366, 0.05333816200228674, 0.0892925893089601, 0.11750170561884131, 0.23374771433217184, 0.06614482855158192, 0.14509188942611217, 0.2728204477046217, 0.16916362488908426, 0.12633746649537766, 0.12138905988207885, 0.10204771773091384, 0.07650506762521607, 0.14227527699300221, 0.11909011538539614, 0.25808858392494066, 0.10023552711520876, 0.14400678979499, 0.12421696313789912, 0.12270625920167991, 0.16901130734809808, 0.05651062873325177, 0.0802003014832735, 0.08989023616803543, 0.1330408225102084, 0.1009257532922285, 0.1230741066059896, 0.17810998697366032, 0.08490820814456258, 0.14432021869080408, 0.13985008427074977, 0.10887061804533005, 0.15894344901399954, 0.13079857639968395, 0.12528687715530396, 0.05613548707749162, 0.10579948712672506, 0.13666295100535664, 0.12785628571041993, 0.08725707246256725, 0.11695281150085585, 0.16251623444259167, 0.09426135875816856, 0.06651610255773578, 0.21074802348656313, 0.08583843215767827, 0.13653820912752831, 0.08040394341307026, 0.17183770425617695, 0.094963981769979, 0.11446162446268968, 0.11447263030069214, 0.07724247912743262, 0.11066502425819635, 0.09031556905912501, 0.12881464857075894, 0.08526224057589259, 0.25657675362059046, 0.20425578685743467, 0.12294086946972779, 0.07836013486874954, 0.09238888030605656, 0.16436913715941565, 0.07615465178553547, 0.0630771853029728, 0.1799780481628009, 0.09142126222806317, 0.07349729152130229, 0.07040990968900067, 0.15049351671976702, 0.1159516873636416, 0.1462109022374664, 0.11189910303801298, 0.11675682344606944, 0.12361023069492408, 0.06730557126658303, 0.08819831588438579, 0.12044685972588402, 0.07350584784788744, 0.11006722133606672, 0.12930126674473286, 0.12521134263702802, 0.13990309142640658, 0.10840814214731966, 0.1607803383043834, 0.04821738374552556, 0.17935300884502275, 0.13286885459508213, 0.12733622933072702, 0.10335087816097907, 0.1519628707319498, 0.2519687408847468, 0.09711079193013054, 0.07869857456535101, 0.09319246932864189, 0.1921676312174116, 0.1593851074576378, 0.11718990520707198, 0.18473290944738047, 0.11461064432348524, 0.09602683902318988, 0.07092244790068694, 0.08504875310297523, 0.160372986591288, 0.0963322137083326, 0.1408536782754319, 0.11874345184436866, 0.08997167394097362, 0.09090938898069517, 0.14300509568836006, 0.10486469657293387, 0.16743433768195765, 0.1656537532274212, 0.11897175173674311, 0.23911061084696225, 0.09013999133769955, 0.1067961532888668, 0.13451521125222954, 0.11153472973299877, 0.24295168902192796, 0.2297141222017152, 0.11493001718606267, 0.10138187810246434, 0.18143015381480965, 0.11643899764333453, 0.14987063514334814, 0.17937101716441767, 0.14952645504048892, 0.12277849603976522, 0.08122136776468583, 0.12148036355418818, 0.11061044968664646, 0.12493055127561092, 0.1275735537388495, 0.1352739083979811, 0.11764692568353244, 0.08540703994887215, 0.12768168507942132, 0.07808402539896113, 0.10412934103182384, 0.09443234279751778, 0.15898682097239153, 0.15193779207766056, 0.11186213645019702, 0.09827557192849261, 0.10801549428807837, 0.07169854268431664, 0.12980530969798565, 0.11858787733529295, 0.11388856092733995, 0.1635385560137885, 0.10674932758722987, 0.10315309877374343, 0.11025133502802678, 0.11638342562530722], [0.05105697476704206, 0.027990851950432574, 0.04609138086172087, 0.015536234813875385, 0.02135244700392442, 0.01696836609127266, 0.060466392897069454, 0.05474533506536058, 0.02015142814655389, 0.04939129003988845, 0.016940088144370487, 0.024359329137951136, 0.05327245606375592, 0.023024643970919505, 0.013606603357142635, 0.010439780341195208, 0.009722081129439175, 0.0737696351217372, 0.06427463676248278, 0.05313893733546138, 0.03772345291716712, 0.038207207673362324, 0.06631438088204179, 0.05950083756553275, 0.03893327067739197, 0.01376957304975284, 0.04321956281949367, 0.048751574009656906, 0.03296077151649764, 0.08790448307991028, 0.01204722301502313, 0.04890681603657348, 0.009781899080345673, 0.038184721022844315, 0.003652779618278146, 0.02895488397085241, 0.036635262559034994, 0.07999377577964749, 0.03661417029798031, 0.05215260186897857, 0.01762375288775989, 0.03659070994971054, 0.0433533393910953, 0.022069987608119845, 0.026098606076889803, 0.02835685882850417, 0.09246029611676931, 0.013323697510973682, 0.07698200988982405, 0.04989752805392657, 0.02345449081622064, 0.038353503216058016, 0.025940249574237635, 0.019239879113488963, 0.0660179221470441, 0.018716207838484218, 0.10682062126163926, 0.0037353598745539784, 0.029815785453787873, 0.023756971549508826, 0.014657369116321206, 0.044789845523025305, 0.058062465462301455, 0.02696998922952584, 0.03738562050940735, 0.04111415347350495, 0.023501216433942318, 0.1068177849852613, 0.019617936773491756, 0.045550513813006024, 0.04728430649265647, 0.026081832691228816, 0.05393479105883411, 0.013135546535652663, 0.03309461933427623, 0.01569827406534127, 0.05691686425624149, 0.05187439572598253, 0.027816731382959654, 0.03189766999068005, 0.0034879590093623847, 0.0513611823719527, 0.016695764647530656, 0.05507067564342703, 0.0321130132568734, 0.06379663598324571, 0.020912729170439497, 0.03291297211710896, 0.009459918946959078, 0.01731559620904071, 0.00430721604165488, 0.060714960630450926, 0.015140231598966887, 0.03963890638468521, 0.04462313625429358, 0.01345430193136313, 0.011103492762361254, 0.033984568901360035, 0.020060794527775476, 0.017287967959418893, 0.020987603813409805, 0.014234633318015506, 0.08045965792345149, 0.02133906968603177, 0.03741899086162448, 0.029896510764956474, 0.044728037768176625, 0.043346180846648555, 0.02057872709286, 0.01032556763051876, 0.017858086652787666, 0.023216806784538285, 0.039682600647211075, 0.03885387868753501, 0.019675410385908823, 0.0073990172573498315, 0.02316551292980356, 0.056557966728827784, 0.008047644148713775, 0.023303230093525987, 0.08059098837631089, 0.056744278874248266, 0.04384807962924242, 0.026894736303282634, 0.026887036627158523, 0.019432501634582877, 0.02731930075346359, 0.0064482052195152, 0.03419361196990524, 0.01068084008459534, 0.03908007851402674, 0.027989476220682263, 0.030301874370447228, 0.03216679394245148, 0.04787313239648938, 0.05394003274185317, 0.0439240484099303, 0.04079193076384919, 0.021422965452075005, 0.02114468806290201, 0.028834057240081683, 0.038536049492124996, 0.024899616039225032, 0.03841707855463028, 0.015460588337321366, 0.024455820210278034, 0.07252674895737853, 0.047278128431311676, 0.02635258173436991, 0.03396816531728421, 0.02794371751536216, 0.06470251415989228, 0.05440567061305046, 0.041729622054845095, 0.1108228379328336, 0.03474361209997109, 0.0244293047580868, 0.044472280956272564, 0.03100962032164846, 0.011704083615248757, 0.042974367405154874, 0.01431818472753678, 0.03625563578680158, 0.04977604653686285, 0.037122504985226054, 0.023780382703989744, 0.08141711154686553, 0.052056545059063604, 0.008547382645442017, 0.012362444939623986, 0.007450305174903146, 0.04145252192392945, 0.01369947868598891, 0.02329755754077009, 0.046945955005607436, 0.021177826016875248, 0.014710298240450876, 0.005596190848986485, 0.03327063471078873, 0.023691523454285095, 0.042641617224684784, 0.03175989006246839, 0.034076781810394356, 0.03650513989850879, 0.03655992481591446, 0.026111934200993607, 0.050559958043907366, 0.032572466281375716, 0.015433640319055744, 0.005487246538645455, 0.03842136011059795, 0.02576111293663936, 0.02638615225441754, 0.02922606049105525, 0.01608698133246175, 0.049427737548415146, 0.004441741546283343, 0.026858711182805042, 0.03323646368724959, 0.0493764538717057, 0.05687531416437455, 0.03867131205541747, 0.02515375624144716, 0.015560933488554187, 0.0556413982329624, 0.045559925093714676, 0.04029932791101081, 0.027369400386565497, 0.01734972482414118, 0.011137762173478092, 0.019291137345135212, 0.01607466083286064, 0.07967630960047245, 0.0211618363391608, 0.02392146540140467, 0.03250915217878563, 0.033588792995682785, 0.01982119363466544, 0.03453439939767122, 0.0749353040009737, 0.1048149803121175, 0.009388685492532594, 0.006355617419883076, 0.04052761084000979, 0.031477022383894236, 0.01698571114268686, 0.04143548390961119, 0.05433460085519722, 0.01682511038546051, 0.04085634409316948, 0.05520957515441945, 0.043545307125896215, 0.02195394454923059, 0.03491829076249685, 0.04589229868724942, 0.030889054826859916, 0.044800098187157085, 0.04467820615640708, 0.07461002788373403, 0.06608882905649287, 0.04093235019328339, 0.026180505253640667, 0.017975479996364032, 0.02826596567008112, 0.04143348901665636, 0.019751871104485223, 0.04567214800044894, 0.0318961873916643, 0.018323254638484547, 0.026663540762716105, 0.034439312892832925, 0.025413460430822203, 0.062861607942198, 0.03804581133382661, 0.01976017637311348, 0.030129227920302322, 0.011672442679160407, 0.04216340949226703, 0.05971491536391633, 0.03606037037181003, 0.06492100243589707, 0.058181894410933764, 0.013035604264587164, 0.012603564903007021, 0.012261347462689238, 0.019836175687877194, 0.0519387208457504, 0.013128274336590298, 0.05085437438849892, 0.023675560917971388, 0.05896274572504418, 0.04256210309852447, 0.02828085781740291, 0.04803706984966993, 0.06762764469853469, 0.020304905982421975, 0.03429379427273359, 0.03551354578563145, 0.04116662119382194, 0.03032524311648948, 0.01592429238371551, 0.024327421028699194, 0.04022329466949616, 0.022860224757875715, 0.04451676910477025, 0.03532996474366103, 0.03633075300604105, 0.0266437648595976, 0.029529253686113015, 0.016441066350255693, 0.019471615785732865, 0.022137640942154185, 0.027644885604136755, 0.013089952375074583, 0.03027481439390353, 0.028829202322023254, 0.02370958266380642, 0.0620468638039061, 0.021198402591315762, 0.03862392995506525, 0.03846647929666298, 0.036176596635154316, 0.05084591644949146, 0.008429706861664141, 0.06174729059317282, 0.020676834774868827, 0.019304653762706687, 0.07848235938165869, 0.06712833113436188, 0.06712533879492964, 0.010728027106129696, 0.030226957319038253, 0.019220086246994988, 0.024195537569799593, 0.04681567628202694, 0.02132938020596547, 0.003846760057578129, 0.05047743461493935, 0.0569188659345465, 0.07437149568327836, 0.045757161652935405, 0.02739529497921467, 0.06892404013446399, 0.056650624078299315, 0.04164118519318955, 0.012607139086217752, 0.017132939671033194, 0.05232835600950888, 0.04457974393985101, 0.022963272174820304, 0.10552594251930714, 0.02089192359043019, 0.09759310140673604, 0.037577961438468525, 0.020804473997226784, 0.04000697431287595, 0.04333313261823995, 0.019403992985774363, 0.049902952941400666, 0.023111776349001696, 0.027958270395174623, 0.010429771949670144, 0.011666431707063956, 0.05560165982959526, 0.016931840551218817, 0.018624593736603856, 0.06932269981397049, 0.112066769041121, 0.018281797845182673, 0.0067614615129839096, 0.022906025871634483, 0.05506572912314108, 0.11763453563409192, 0.09237066164080586, 0.1161254873233182, 0.1281164496072701, 0.10738624126783439, 0.10592222732624837, 0.1476821561477014, 0.10893391179186956, 0.09325218041028295, 0.09864228617932115, 0.12871014060718672, 0.12090420589915343, 0.10250910797289439, 0.10282088124326297, 0.08947324247232505, 0.12355551363102027, 0.08392992349607603, 0.11382587107696704, 0.11061198996113879, 0.1686657973166023, 0.11260779215289013, 0.12342718908829348, 0.16871276551059314, 0.08572641959679977, 0.1671947469668729, 0.09460184084517614, 0.12053766128207956, 0.17940951724137577, 0.16071849662278379, 0.14939298720232078, 0.10234254119651658, 0.08111578771578414, 0.08612072308148656, 0.0993165396420019, 0.12548241737697804, 0.11826367330338274, 0.1667871374104704, 0.08453671022185258, 0.10054747680468218, 0.1309774789427008, 0.12314330360719136, 0.11082558599965912, 0.22828879154154233, 0.1328042716320072, 0.2445375339261123, 0.05837306486708777, 0.2519790546170303, 0.1558569289211716, 0.18219621985086373, 0.13563475332089833, 0.15446374725018228, 0.18793583900800773, 0.07952608873269387, 0.12289327702351979, 0.1579895509140832, 0.09708409836249692, 0.11005519091018609, 0.1137132342638714, 0.12221406346985272, 0.13465642796031066, 0.06828205101191998, 0.17138227155166014, 0.17977083713880607, 0.1736352385154792, 0.1720655970275402, 0.12287008469658238, 0.07282667500632149, 0.21920657317553247, 0.1461703394140516, 0.11013744292514664, 0.13040422541754587, 0.1269823190357004, 0.14383138849266938, 0.12961327071700776, 0.10112700677875962, 0.07720083064798798, 0.13961498545748846, 0.14119635203054973, 0.14293667221707956, 0.1700672706855195, 0.12950458297772066, 0.1336482742003032, 0.15801263467541762, 0.15335815586149693, 0.12892902243350232, 0.14094673256788934, 0.08729933162352868, 0.1426757483610085, 0.08589257246681622, 0.07926376709448439, 0.08767648174294404, 0.24007776752114296, 0.11596633014934403, 0.14682816554393086, 0.22548560053110123, 0.11994068617267267, 0.08734489525003092, 0.09228505766285316, 0.12233127360897404, 0.08540299588016101, 0.13777638625885757, 0.11082682093339306, 0.10399846519742693, 0.08108913486025163, 0.11545589539621558, 0.10476816139583077, 0.16533576457628182, 0.16860215073185308, 0.09594508912414312, 0.1681896150112152, 0.07972516412181513, 0.1302957683801651, 0.15953367948532104, 0.13039198464580945, 0.11757031907992703, 0.10588105382131678, 0.21141505055129528, 0.1561883254242795, 0.10363840058978115, 0.0724919672523226, 0.17246076225170068, 0.13447901819433483, 0.12474455125629902, 0.16245288641325065, 0.12390753759869508, 0.1688000793967928, 0.11021622084081173, 0.08427023594932896, 0.12133788477097239, 0.12084952954735075, 0.12225765255945069, 0.16902802645095757, 0.11470251796501023, 0.13613712707800524, 0.12108242990715162, 0.09325905397002186, 0.1252283060124942, 0.13090521496321472, 0.11073988024145365, 0.1613396547202553, 0.12845849911017077, 0.1258950616632189, 0.19534065095441683, 0.1387891811983926, 0.11639072666210787, 0.14413964695164136, 0.19961567941520894, 0.08966764954051801, 0.23945253821355955, 0.11404526180454663, 0.17136462964117527, 0.145885490413223, 0.11646176927856036, 0.10429476108402014, 0.22765240711825235, 0.05594962615785854, 0.1277440424476351, 0.10375661496073008, 0.12411797844937869, 0.17357275901096209, 0.13089927099645138, 0.0696409395230668, 0.14930188709071704, 0.11241621457572494, 0.17789029090532235, 0.0915074497461319, 0.1611339771854026, 0.15975462405809335, 0.09106461743691138, 0.1619604599795171, 0.14014751331082412, 0.21347658921565327, 0.06449298933148384, 0.11244376988283225, 0.0927113676443696, 0.14442769863775798], [0.004084932634473911, 0.016537279223224947, 0.01538854488171637, 0.06785211765340396, 0.07581130628074918, 0.03234483813866973, 0.02302882883564702, 0.004384930777762617, 0.044765248628599305, 0.07043464229043041, 0.009292785593840693, 0.052950671009187184, 0.02525513106957078, 0.04293468328458922, 0.05068969733214804, 0.026578225162146345, 0.05909236626965659, 0.012501535288590406, 0.039539243161146126, 0.05421972826921514, 0.035846981286470375, 0.04593605062525187, 0.02538795429947121, 0.012352694391406007, 0.02489748883194157, 0.041250949525939565, 0.01904247122417603, 0.03471953428483435, 0.010361356111908597, 0.06010418411876474, 0.0254048515177731, 0.07010244511600051, 0.03601646915610347, 0.06358500769627945, 0.06016674504748412, 0.014134746177920272, 0.024948752152600458, 0.03689146041870117, 0.01729003749122577, 0.05186078092083335, 0.020300503986488496, 0.03415436550442662, 0.045502941722848585, 0.056051922097269974, 0.007061661520440663, 0.006686391367111355, 0.01192258546195392, 0.044966183203671656, 0.017700318779264177, 0.00942635181958654, 0.02981399412133864, 0.048715296134884865, 0.03274815935375435, 0.0139140772599993, 0.08669811567025525, 0.006495402843159224, 0.028663212300411293, 0.011330973323700684, 0.036380618544561524, 0.03170607205746429, 0.04568019542577011, 0.01786092123282807, 0.018261243323130266, 0.013657826813869178, 0.023811571566121917, 0.031548750320715566, 0.015431022870221307, 0.013322708546184003, 0.022943090847028152, 0.07741942748959575, 0.018253979605755637, 0.07207361648657493, 0.03940309850232942, 0.021983998561544076, 0.025843621098569462, 0.046840181574225426, 0.030561224025275027, 0.03802308380337698, 0.0027480960873487803, 0.0467485725613577, 0.06596333400479384, 0.030116508781377758, 0.0207336536009929, 0.014928240295765656, 0.04787827908460583, 0.03416377339246018, 0.04482019978708454, 0.03178384234862668, 0.0827927463022726, 0.03787445070754204, 0.03577294633058565, 0.004909569813337709, 0.04322254837357572, 0.012225757452792354, 0.08101400067763669, 0.007913461304269731, 0.04869968304410577, 0.024836183193006685, 0.04202495442171182, 0.06349088131849255, 0.08128782348441226, 0.048102158321333785, 0.04575757895197187, 0.02856609019051705, 0.018576850316354206, 0.013416899384797683, 0.06234811978148563, 0.019271205378962413, 0.012977158650755882, 0.04740726382338575, 0.020891781098076274, 0.031286503321358135, 0.03793430767421212, 0.007093472938452448, 0.050383097891296656, 0.04159239513267364, 0.03174166800454259, 0.027609617050204958, 0.024716660945809314, 0.01721504919363984, 0.011740686338660973, 0.08046453659023557, 0.0206375153668757, 0.015847836754151752, 0.05986014899930783, 0.013642887169096087, 0.027904720411502888, 0.013348033169417508, 0.014977332304364868, 0.05359283994351115, 0.045201858771698813, 0.011361334373110106, 0.008231276080810597, 0.045059573370963335, 0.013532475950861616, 0.03102348279207945, 0.014853574302313583, 0.02735285091746066, 0.027517521188461354, 0.04657309322750994, 0.046735096855887344, 0.030190323213381425, 0.03350363006549222, 0.004973945823231978, 0.012386556681511658, 0.01873277427096452, 0.025097215614680733, 0.008968074357004037, 0.05815337558409997, 0.02649205630379064, 0.04359806661627122, 0.014305966008188469, 0.013986574485898018, 0.012422857456840575, 0.047985796350985765, 0.00857514829840511, 0.03658611626763429, 0.1006300545164517, 0.03543836071289011, 0.0487058916395264, 0.05177261547318526, 0.05176130768709949, 0.032791636485074244, 0.07542798827801432, 0.024620629580957547, 0.022803310936849033, 0.010695600765757263, 0.04941056043441806, 0.05200526477502925, 0.018978743215224574, 0.007540575777446585, 0.03615268166842205, 0.05728578713855573, 0.08678091729858092, 0.02883793506771326, 0.029842075293085406, 0.031060805610780205, 0.012004200502165725, 0.04820106497832707, 0.05571902942444597, 0.03518369973504117, 0.020172506836908202, 0.09489597899041005, 0.012954597361385822, 0.04170811588742903, 0.06767658742942981, 0.019012778531759977, 0.042170072706150155, 0.034214202115046125, 0.031238748026745658, 0.02215645502188376, 0.007778348866850138, 0.030185203666665723, 0.02192654530517757, 0.02198743025240089, 0.05653573113626667, 0.03287396313888686, 0.031085049666996514, 0.037810491996684244, 0.0014034130248806573, 0.06865903149758067, 0.03295397598828588, 0.014353524527645536, 0.0344344579747745, 0.043343093512313705, 0.025278608381216015, 0.030987557755517106, 0.04165319187034454, 0.025336494203656912, 0.021452817600220442, 0.011559734619887812, 0.07105427368410996, 0.04275946857939873, 0.013963102263265421, 0.021053922129794955, 0.04903138828064714, 0.03114411953304495, 0.04172691470012069, 0.042127677838185, 0.03413782621334706, 0.02584707653815193, 0.031573459173419645, 0.004795497474593243, 0.04502106311597994, 0.03702706903485315, 0.03759392397478223, 0.05672063532152346, 0.04002479264246566, 0.019982483104935715, 0.03654302250859993, 0.05231016109298382, 0.04685075654249106, 0.0625474869406649, 0.0015384327998617664, 0.03789134622950639, 0.06964275799691677, 0.030286773573607206, 0.036486561609698195, 0.0366826989421887, 0.03370476480839508, 0.05901420582085848, 0.06604813731142453, 0.015455769042351415, 0.011958799724067961, 0.01968234671013696, 0.04085400654003024, 0.009165712100054537, 0.07296830562076398, 0.05471256860931005, 0.03654025069304875, 0.0349414084505822, 0.0740445503698928, 0.01619648331377123, 0.06473666482738086, 0.0049696443352981335, 0.03893600517351713, 0.041549057101032565, 0.028161724031503712, 0.030887270279760872, 0.03444311947428754, 0.015458769863471389, 0.05190489926774587, 0.02950689595724855, 0.06321626462574516, 0.021708118097324456, 0.0104177830840594, 0.04887681121804884, 0.02131848462990352, 0.03880645248240658, 0.014548248810959714, 0.00504217591203217, 0.04937826895288058, 0.008522348944097757, 0.018443083922777857, 0.06830400840512343, 0.010483682405070534, 0.026235342757510285, 0.04177614241572363, 0.08055774016039711, 0.031809921842068434, 0.03717880303572331, 0.021709985764963285, 0.049038319515862634, 0.033995476351784806, 0.08922759243952376, 0.034686085901090076, 0.018242709139095883, 0.020340637636504004, 0.038635013824594874, 0.07489186418907982, 0.04265836686162012, 0.014575938128733208, 0.04917761257716587, 0.04101430026016065, 0.026322125690057874, 0.037251212900238376, 0.03855497044112001, 0.024984566927222267, 0.02053591831853347, 0.005131157722124564, 0.046696861407586505, 0.031442769936152866, 0.028117081516289284, 0.014189907682261296, 0.044442354169275076, 0.04667425601344023, 0.009181947746713246, 0.10877414393637862, 0.02846571450520839, 0.05184977508283087, 0.04832235311291047, 0.008463867707177997, 0.028431970958731005, 0.05865911487489939, 0.07979662742997919, 0.025184200411396365, 0.010160463945274907, 0.02015318555225219, 0.04676322552508541, 0.02570673853291997, 0.03244629269465804, 0.008032912305290145, 0.07962214893528394, 0.03195179672911763, 0.03869591573519366, 0.034365698628659756, 0.029583088654492582, 0.027058655096750175, 0.02383077410714967, 0.027901383715548685, 0.0841161949293954, 0.014926421821915677, 0.01792822003231517, 0.05883255521101611, 0.042968738957175186, 0.05038211062284453, 0.04935694259724446, 0.012513305326657636, 0.05506997675235782, 0.032193222881427834, 0.01294609871027725, 0.03999985648053033, 0.03160852925585849, 0.038294779402869086, 0.06027616560459137, 0.03243553791461246, 0.02199245141153889, 0.021449547061430554, 0.0402660457683461, 0.06682638983641352, 0.02919565194419452, 0.024526847559692602, 0.09598363669855253, 0.07902845115001712, 0.17887074686586857, 0.12864235495882376, 0.10083021556160279, 0.09131055245442049, 0.16262382295514854, 0.10610932657229048, 0.10462741287691252, 0.13534919864365033, 0.07982758898288012, 0.09138973749109677, 0.1072754364992891, 0.12002633086272649, 0.14674017312271254, 0.1273443717509508, 0.12270828123603549, 0.07009511693779912, 0.14288051665893622, 0.18141726164945535, 0.20111320620136602, 0.17918182803051813, 0.14241531305015087, 0.06484450439789466, 0.16342076233455113, 0.11510225651519639, 0.17454070278576442, 0.15154515100376947, 0.09949442438249077, 0.14373908058873244, 0.11344882273780448, 0.18733515909739903, 0.10273124676729951, 0.16073988404657158, 0.11388439472232546, 0.13918577134609222, 0.061630189019654474, 0.12914683217448847, 0.1372929843408721, 0.12624621710606984, 0.16450432847653115, 0.15461632263447556, 0.15193290662552628, 0.1428010602082525, 0.09338271697717053, 0.12241018723164286, 0.09641066592718874, 0.10689547724489655, 0.1657034084200859, 0.09594832573618207, 0.14847080382917607, 0.11145502900970833, 0.10184338369539805, 0.10049938224256039, 0.20861137099564075, 0.08942617249808141, 0.15961650146969728, 0.0586335069632956, 0.08950071635523013, 0.1505442847098623, 0.07014249903815133, 0.1372412664017507, 0.07235398715628044, 0.15557510618652615, 0.19135260209441185, 0.11145199595817498, 0.1131840923002788, 0.07966321387461253, 0.06442462692835502, 0.1376761259245021, 0.10590502646352563, 0.17589144887668745, 0.1410397325775453, 0.12142411300114223, 0.14931978684450897, 0.20363979919680528, 0.16883140057325363, 0.15128103803311074, 0.07786408505801644, 0.10376574804208108, 0.13722066607858452, 0.1393178549728223, 0.11850915370242936, 0.13711758303855145, 0.10643530158059937, 0.132823039910623, 0.1004461104582463, 0.11798840521701745, 0.1511610730418137, 0.09979234196777854, 0.09727756226701395, 0.11265146945204053, 0.08018455947084085, 0.10700174261416708, 0.13276780716010503, 0.14648201768951757, 0.11284926919532673, 0.1405642152364765, 0.13517843852085726, 0.12099943150367055, 0.12872323633304664, 0.14707467731620583, 0.12616190234465258, 0.06860514903174979, 0.13464067237717764, 0.14760826368417057, 0.14897676025118145, 0.11477817461958953, 0.14770351643008844, 0.10287652790014233, 0.06562638708523341, 0.11557272555572645, 0.07850777051810708, 0.12841298298111983, 0.14890012650617532, 0.0855246436383043, 0.12333830100085054, 0.18717304351074354, 0.05282270948269537, 0.11367226431944541, 0.13404856914920465, 0.08464621220316206, 0.13902069734675543, 0.06761107487337929, 0.14739923418632575, 0.14358370964016232, 0.1759137183959995, 0.10242855229548045, 0.0981795863647546, 0.28146270396453993, 0.09002403648836271, 0.11907503833728177, 0.1078658773164664, 0.12732734052198275, 0.17157684825360775, 0.26239760699016706, 0.10342723370662757, 0.13793759260858807, 0.1899747417441436, 0.07717413708035435, 0.07092778118593351, 0.12072682327457837, 0.1223339606076479, 0.07361422346106597, 0.06119811827582972, 0.08620125161749975, 0.17297792807221413, 0.11087207921913692, 0.19360867674861634, 0.15931322345776217, 0.14346738159656525, 0.10713350732943841, 0.13168384746781417, 0.21380961420280592, 0.20466912324939454, 0.17533243101622376, 0.16629245824047498, 0.20578418698694023, 0.1208551749587059, 0.09761875681579113, 0.10715342233223574, 0.14322580955922604, 0.11029275280556508, 0.11081802711955138, 0.13484341864074978, 0.11880240296678883, 0.10825290012040309, 0.13251402149243013, 0.1523648484476975, 0.09394784165280205, 0.1852279007434845, 0.10832685365208558, 0.22720082849264145, 0.22927155452115194, 0.08842253099594798, 0.10769817738660745], [0.04691172630659171, 0.03713830806581037, 0.01580081258102187, 0.05681872434381928, 0.04966875318703907, 0.050604011929993115, 0.06555609764265162, 0.03069528897425958, 0.006913036482209074, 0.04553000169939228, 0.02922094094433955, 0.014592245021568877, 0.04020482833896365, 0.021357575032327856, 0.026280361859660064, 0.029884592297353914, 0.08878872956016234, 0.03845503241089838, 0.00490395027113014, 0.013840401927674455, 0.05870164544986827, 0.0539907735905477, 0.02642581262625754, 0.028048272976385694, 0.05371865051399384, 0.049483842216432095, 0.045997047530753274, 0.0185580277549369, 0.03759237352226462, 0.02527533614608858, 0.02020616047749562, 0.05531040545819061, 0.019562332525051067, 0.019008503761142492, 0.05412729483629976, 0.02065450418740511, 0.03286547127312847, 0.031230673460023742, 0.008546280874205487, 0.039403692220470736, 0.013107935249406313, 0.03047117903562529, 0.04925723187625408, 0.03254918913756098, 0.07395167928189039, 0.02209264728506761, 0.04382684148315873, 0.03016977378034166, 0.08771270872758967, 0.013076226459816098, 0.036525597729321034, 0.020798996523288742, 0.029004033654928207, 0.024485338179926788, 0.0033886197862947093, 0.04673133437920894, 0.061993795580097606, 0.03528016705864242, 0.039811566405530484, 0.046935512351670435, 0.04975289831470166, 0.06650743088019745, 0.01260029775689223, 0.009845024889468082, 0.04788474891600864, 0.06488877202251128, 0.040674198152763505, 0.010675051332717496, 0.025324660552931682, 0.01611678089414324, 0.010635386720033628, 0.03984331166637795, 0.040282276325992177, 0.0739580982231668, 0.03577823211838092, 0.0148150352095919, 0.045205434651247094, 0.010155393592348056, 0.0726136150104659, 0.08785315190574952, 0.06693442618208272, 0.07670758997223207, 0.035950736076171906, 0.05465564291392054, 0.03848276752978563, 0.013728302853581096, 0.007903713300558073, 0.049831638910940716, 0.029075663204171827, 0.04379105554627521, 0.05228509600939495, 0.05970066612852471, 0.04016830958425999, 0.049923376845461984, 0.019536885765514204, 0.03341706256781306, 0.01171007423129465, 0.01858971534030778, 0.07092753012797662, 0.06346517162663595, 0.07280538257743631, 0.05291865094165717, 0.02588892518542707, 0.02312543016991445, 0.05250723819647517, 0.05811008504991021, 0.05467612449345844, 0.016283734435481683, 0.050001852813043764, 0.027234219247475266, 0.03564086609653064, 0.06481605342456273, 0.04273473937064409, 0.04094855360952871, 0.032134458356137784, 0.03135726434577789, 0.012583981534200055, 0.013990952733105846, 0.044481546351952214, 0.011770583439751394, 0.057215294135468345, 0.02576574563447918, 0.06734852253326348, 0.04574748913624457, 0.039580867891865115, 0.028885218780487776, 0.026866963864969354, 0.010399621246116502, 0.021694874790097986, 0.07742068277938025, 0.013363734469749033, 0.0400400359316596, 0.030562252005828277, 0.032828742172569036, 0.029283545977835144, 0.07072464137205056, 0.007459681680692094, 0.025447570386209657, 0.025025860872119665, 0.07397488517952816, 0.06382163321333272, 0.033997023411627324, 0.03887526611132281, 0.008070034107991626, 0.030903714575937817, 0.054493693568344624, 0.050997134763747454, 0.05506849415334208, 0.05252160617549505, 0.023882459815857664, 0.012132438531677638, 0.026390186145103404, 0.11641394613044602, 0.03011865295203669, 0.040479434853685756, 0.02907463861629367, 0.046850790469241996, 0.015617845613243324, 0.014241389830463698, 0.008283203517618989, 0.04272341122850776, 0.032669015029179196, 0.09108641198171036, 0.015361620612176401, 0.06803116947412491, 0.038276611627744775, 0.02071216100427721, 0.014782285716916834, 0.029476687578218322, 0.02221361141917961, 0.06977887212165765, 0.016061941693936075, 0.010274903965182602, 0.09781774399535996, 0.06110357120633125, 0.02798381893496428, 0.0060886724136902815, 0.022930176629285728, 0.010379383091016539, 0.039520820935389826, 0.019524924889472977, 0.05695838720670768, 0.012685501399183912, 0.03618580435535737, 0.016024617178897773, 0.06508758278297526, 0.019864579163757817, 0.012397433597860592, 0.005082359179920916, 0.01410495679426406, 0.03581742090838296, 0.006406977007697735, 0.029263468126633337, 0.021273365443838493, 0.02243913440699024, 0.05068411298894456, 0.02781390189193189, 0.09191756988210337, 0.016891187821914042, 0.03295124149216073, 0.04971215228683182, 0.05744716312204089, 0.04199521762451955, 0.018748831802180836, 0.04623510814937098, 0.007563977602070996, 0.022711569609652673, 0.02968183924843158, 0.04640817189855235, 0.0329037135067795, 0.005947807271565709, 0.004428372710078422, 0.025992798718756864, 0.031006651730941873, 0.038195068681878705, 0.060355343855917454, 0.006847050223898674, 0.014065812957207007, 0.05752066882061107, 0.009200760978274047, 0.02397372616854097, 0.015703325758555105, 0.04557379774217095, 0.029022374456482272, 0.042708571667649915, 0.06438188600753035, 0.03813880116545728, 0.01873834165079253, 0.022685025319723145, 0.040424656721630266, 0.05143105112282293, 0.039663557561912706, 0.10316795869065182, 0.023743241393406476, 0.01463191896410925, 0.006311878628496612, 0.022786240692117384, 0.034416486974805593, 0.04816281595932586, 0.03841558577758925, 0.015535008361829179, 0.04460243754354971, 0.00909204694575497, 0.019049327820539474, 0.02270851280939366, 0.04937376008768167, 0.0380174010725958, 0.018399979985718216, 0.030012815059827905, 0.026132671927501048, 0.02985001415280359, 0.006455531701379056, 0.07225158265126602, 0.04942530839304839, 0.004556539069328989, 0.06235558366669076, 0.017610139778948257, 0.09764120275420801, 0.00703725334356672, 0.08690833260438272, 0.031205384459878718, 0.014721555136410254, 0.021518923874412264, 0.04316796023132546, 0.02757942902722529, 0.04619248936484967, 0.03986375931916492, 0.04444609289722783, 0.02789902750269643, 0.06347029456602675, 0.01601654600485095, 0.02131757539297853, 0.02244348212012223, 0.03357611456885934, 0.07380208266632897, 0.10155622089015585, 0.059278033806809356, 0.03922107809090188, 0.04175114857831171, 0.02511769549788109, 0.04234939594087856, 0.02968458392258201, 0.02585696448971118, 0.02486762311309576, 0.01544278527476958, 0.041614871605166366, 0.04355116966845734, 0.06739564000495843, 0.0051686357557108355, 0.06903701621506896, 0.04669941269925662, 0.050027114671788046, 0.038134041242301464, 0.020368394807779362, 0.03007787639009101, 0.03194189690319555, 0.06601664650120906, 0.004123523889575154, 0.006183493441702532, 0.03205231151410511, 0.024791506751041328, 0.06840372591146401, 0.08352006798876183, 0.052645744157156775, 0.017850622767582536, 0.04306092133213367, 0.029286100662180355, 0.05271137545683554, 0.03481538074889353, 0.05818854405411652, 0.03768512925931385, 0.02589073857026441, 0.033815895273749313, 0.05254901899024844, 0.04412128496915102, 0.03763807624844568, 0.04674170578696898, 0.03390056287337627, 0.014668463163876107, 0.06355730311146804, 0.04993569225605045, 0.035686975943722894, 0.052208153530955315, 0.0636036606239421, 0.019585974381438324, 0.042050097536827834, 0.04844319341438157, 0.018856907163613608, 0.011117756416622018, 0.09128301071801356, 0.023803424056885496, 0.03088407437982304, 0.024824602296575904, 0.05904129972415311, 0.04207191243767738, 0.043756419726248295, 0.037728514788406234, 0.02329721996959831, 0.03650355551924024, 0.016156103694811463, 0.0712438156562192, 0.021309890983892337, 0.04685557074844837, 0.03416912364108222, 0.034388595792864046, 0.04843961753483329, 0.0564478608513517, 0.01930598878035588, 0.035525834054819176, 0.03240234398150018, 0.06361415756068059, 0.014074324330847179, 0.1275028639606067, 0.10124377587011882, 0.08559171682489769, 0.10360602089869124, 0.14939422213605472, 0.122091126495174, 0.09026777305241142, 0.07031861958759171, 0.1059240729414991, 0.09953103134674685, 0.10603138325469834, 0.11918939862932477, 0.1366976105741092, 0.11050368898681232, 0.09705059908862625, 0.13801152578422002, 0.2377368217068059, 0.10186287122113363, 0.08280757907778025, 0.1639075026448284, 0.12004869537694113, 0.18382680735417775, 0.1650035266897508, 0.08505634590983391, 0.14307684398123197, 0.1631145394806351, 0.1205011425273759, 0.12193152148808752, 0.1935376069907631, 0.12795026281050273, 0.15257036313414574, 0.13705793981041225, 0.12072797678411007, 0.1388791956539665, 0.15921794357044355, 0.16767236776649952, 0.25272172476564136, 0.0950130737785782, 0.05880391424787896, 0.10662917939147779, 0.10942656892750945, 0.14955229365399905, 0.18063287516789778, 0.11733075550624303, 0.15928859263658524, 0.15279366900878294, 0.12218256587428705, 0.13459533266723156, 0.16887397186032363, 0.15860719420015812, 0.11638379203421728, 0.14363253702010426, 0.1377375740557909, 0.07157337332942657, 0.18902975959437235, 0.14940395232822212, 0.13747293182781764, 0.10541234218648501, 0.13802565288330826, 0.09363213966467551, 0.11512608666505132, 0.193282830661961, 0.12998421224100248, 0.10794957461101667, 0.1344173936439412, 0.17329480392592295, 0.10823945155633347, 0.19515910212482723, 0.10484875778534583, 0.12360644446952002, 0.06794876139611006, 0.08873496923063483, 0.2528717081461634, 0.1991334581481559, 0.1402585759226765, 0.0678500888336982, 0.11082731626395669, 0.10728484099464757, 0.17141887173056602, 0.3104204615311963, 0.15861818646746023, 0.19325258157082967, 0.12259868425982338, 0.21039097835975035, 0.10411559391234602, 0.14836294390261173, 0.09940246253141335, 0.15634662764413015, 0.07950964782919202, 0.11820272728800774, 0.16473653673061303, 0.160701329686812, 0.11396330834499427, 0.16281264568013804, 0.08405895371522222, 0.07825868709811143, 0.08393888694367238, 0.13665248799536908, 0.20409892313182354, 0.18418716373188154, 0.1772674364703042, 0.1399052491677659, 0.12842227891087532, 0.07438700699380466, 0.15996130582477364, 0.12126895918377809, 0.10153504381222384, 0.13806723350925104, 0.11759733834436961, 0.10174629211957965, 0.14928231814077922, 0.1697135910923992, 0.06532913446426392, 0.21715765526252134, 0.13358470903975622, 0.15955585400973046, 0.10650031880608626, 0.08281090389937162, 0.17432799562811852, 0.11919123067387513, 0.19546163374824183, 0.1030268030507224, 0.16148572973906994, 0.1289054365562541, 0.13720902241766453, 0.12179880003843989, 0.1782612052879163, 0.12022124683218342, 0.1094815574054207, 0.17691163984792574, 0.15864093096128531, 0.1770920351679836, 0.1446276493370533, 0.20997392359588826, 0.11791154077010495, 0.11564076904739652, 0.10267908778041601, 0.09873056358524732, 0.10911662091634103, 0.21644399927130767, 0.16222643213612692, 0.12590483256748744, 0.1290127807962043, 0.1800435675042016, 0.15672911783414228, 0.12820744115327085, 0.17911795074386255, 0.1301949652177947, 0.17399461780275616, 0.14590359372752054, 0.13219249088849339, 0.1506394560315779, 0.1686050005789314, 0.160458346296634, 0.11672038611556802, 0.10250669917357819, 0.08656293792384011, 0.1096498408753957, 0.12606029851096018, 0.1223451971475567, 0.13398964516818523, 0.2317063281578677, 0.1391230204275676, 0.09930192399770021, 0.2708304944847311, 0.08921433386525937, 0.19706818754119532, 0.13824255338736943, 0.07656517225716795, 0.08659334307802574, 0.12069841979869775, 0.09698725105928523, 0.09982841967472009, 0.201115024675216, 0.13034608853714807, 0.06518753777657237], [0.02669050744069474, 0.02304847412077444, 0.08432648650237493, 0.01093509394143309, 0.09565710529152836, 0.010040975624828466, 0.02522677678747901, 0.03207412641495466, 0.0306757505583976, 0.012370040290988982, 0.026544132170134356, 0.04127362955893789, 0.022405363719112108, 0.019573151765923415, 0.010697550705767103, 0.028775445385170833, 0.02458869093762977, 0.010553731815889478, 0.05567487036543233, 0.016836908413097262, 0.035259882254259925, 0.012725925971088665, 0.04634827761245625, 0.07501392585358449, 0.06214212333517415, 0.05713164433836937, 0.03853051943172302, 0.02698550562906478, 0.07485328268791948, 0.034956651739776134, 0.021173027077955858, 0.05099132650398782, 0.014642247963430626, 0.05691072690699782, 0.10437159838953189, 0.026690558330821137, 0.04927894160417574, 0.018524323224223087, 0.009066368636142994, 0.052165948652795384, 0.03357242333835789, 0.027738548881773437, 0.02832701176937137, 0.02666418537098382, 0.007488007125045572, 0.0284285579275872, 0.044196965372455974, 0.1128243398187416, 0.03351814053686602, 0.04038339500714626, 0.04120514162683061, 0.03515738614701799, 0.03249556790771229, 0.03629659216052719, 0.01058102079800197, 0.03756034666938441, 0.06537719509963479, 0.01499224650407476, 0.006311524093949369, 0.02055306320211717, 0.021535602265170643, 0.01476812469107764, 0.04769260476210287, 0.0063813843631318635, 0.026414077363110015, 0.04506569036415645, 0.029911855834403207, 0.03449366694050176, 0.030402623250016143, 0.034013060586793084, 0.04497032565996051, 0.0579132895384516, 0.0413938116814409, 0.03739882140819516, 0.045355641948325295, 0.04015893562297736, 0.028802291623183658, 0.027315645146050622, 0.011355306437638189, 0.050072868288095505, 0.04699710297531315, 0.035517633959118805, 0.06454664109540836, 0.024501835062567676, 0.06715870236179658, 0.01438181774158563, 0.026876220778961266, 0.06773662420787982, 0.026973724564803497, 0.0838254155325038, 0.07571002814386572, 0.021689492311062555, 0.007610281679912337, 0.022884239808523228, 0.03895982853802187, 0.034067258571407626, 0.026742763118818402, 0.01994679046661726, 0.01690849555390222, 0.03577703111139791, 0.05193538923880883, 0.05385576547788722, 0.0025431210482825656, 0.044765659142285585, 0.05451422943068402, 0.07084683874355895, 0.03822264773771167, 0.03071574680507183, 0.00848863847620253, 0.03319663707433002, 0.04711713242743697, 0.05502571591309138, 0.016781828332958475, 0.02767887681589595, 0.008181899087503552, 0.05144473717414907, 0.03474636355947171, 0.02422396818708096, 0.012791359647443252, 0.06590119376778603, 0.03331288708639996, 0.010022442288962858, 0.007534827737669859, 0.0457549021313233, 0.016982883347996643, 0.019808859564363956, 0.05213790140779955, 0.04504700690241797, 0.12449905728655201, 0.027557351194056015, 0.031188237879957472, 0.04557946350957666, 0.03183161460661462, 0.050459840201905796, 0.02104462280736438, 0.013952595996670425, 0.0431197944230267, 0.033669348673096726, 0.022194802428462675, 0.007348343413988394, 0.05558987706899643, 0.023596718541479537, 0.06080954162670033, 0.042586988370333395, 0.03255631375525679, 0.01568262874414878, 0.009851806846979474, 0.05225412427846875, 0.040967868108834536, 0.031195925681718757, 0.030174408174519027, 0.043903726286121776, 0.04941870624731694, 0.03499152504705957, 0.022520646818780472, 0.08985263854265213, 0.03121658368036151, 0.004606328272659863, 0.023748021672612855, 0.04776877031794616, 0.057736524380743504, 0.03918695795748915, 0.026473503460043242, 0.024375761559765254, 0.02637364685402385, 0.03002936113625765, 0.007725893869064748, 0.04801983166752117, 0.027411717223003507, 0.09385049901902676, 0.024854802193918397, 0.0711906524375081, 0.02667529129290155, 0.006002545963773238, 0.08722628054342099, 0.015857972370992814, 0.036653827277145216, 0.0372207297145256, 0.06397315008299691, 0.01796094747260213, 0.06729225162416697, 0.030407430670623268, 0.01634849721033658, 0.02919460360759071, 0.03869800901572619, 0.026216686437172548, 0.06082680355757475, 0.0853961291057723, 0.02172629944314914, 0.01281224749982357, 0.10022040256964308, 0.03582021986533489, 0.05942292817469154, 0.03610611381009221, 0.06260850759489195, 0.012620809022337198, 0.03311121630083237, 0.003399100183742121, 0.016922317312232087, 0.02260024406548057, 0.030491674185863564, 0.00396685693911942, 0.029605843326342956, 0.04276216575609786, 0.02172152086028031, 0.008746408840774425, 0.01801984940123345, 0.029973643233201334, 0.027456724450790455, 0.01740182443921055, 0.03142423575211849, 0.024622468410858085, 0.006758478503408176, 0.004095481309507574, 0.015744502656161785, 0.028455329526747977, 0.028076552619625415, 0.031905744557401965, 0.02750076476617583, 0.032028349049921544, 0.017661046868722354, 0.04035557846405676, 0.06883097227130618, 0.04502429294266871, 0.05560282351715224, 0.010088274604640901, 0.022703944572380612, 0.030774853990546296, 0.0169133233305599, 0.043764070208583555, 0.022983640099742582, 0.06715150989059891, 0.06549427631710257, 0.038523330353200436, 0.00449789795259546, 0.005534070968029222, 0.0670663673164589, 0.010100708758857633, 0.049294167929994206, 0.0072060079712952885, 0.002387585342928235, 0.023495837347581983, 0.02221096513260688, 0.05878052514578615, 0.03982234154162662, 0.039269705303013325, 0.04335963958874345, 0.04829425158511315, 0.01835033157840371, 0.03568855693031635, 0.05297833827457257, 0.05352917978806155, 0.010009654448367655, 0.0375963463447988, 0.0242996299306729, 0.006979222484265587, 0.06458747533283063, 0.07574078613626105, 0.05837510047214372, 0.018323712649622133, 0.04544246728931155, 0.013918213779106736, 0.02449619474022516, 0.05853252738182034, 0.012743850321775036, 0.036204389429518154, 0.06936153237308774, 0.020888362977919833, 0.035418388034616194, 0.08502465832446303, 0.01203898644806551, 0.04647372855937906, 0.02142414271033236, 0.02826405220132853, 0.03406757748286639, 0.03170966150771294, 0.019083410634526184, 0.05427600935633693, 0.014809116687891739, 0.04841735140819635, 0.060522494172411304, 0.003903031814843416, 0.08675447478890419, 0.023948717064091136, 0.0410091535720442, 0.04571012560544269, 0.05345232891184943, 0.04413274881829109, 0.014370107923501303, 0.020627854724547694, 0.026184993762789027, 0.019672194129920433, 0.015598458171422993, 0.0341276651514428, 0.034436486794480255, 0.12968719032193932, 0.03510538661586387, 0.07427865852202688, 0.015257996440465962, 0.028556417673826218, 0.006539232812688819, 0.01712448342836329, 0.02054445768174316, 0.0041136062521088335, 0.1002136647169079, 0.042489262364272556, 0.05132550500067217, 0.06864926059331213, 0.012536026071757078, 0.015076963297490562, 0.03583454034690346, 0.03957477804007275, 0.007982280870367373, 0.007359531608277133, 0.014196978865324386, 0.02007197169587016, 0.042967388672488074, 0.010236132474217032, 0.03473069279321602, 0.05751659082514899, 0.04782573672543679, 0.020294488773548176, 0.024412801090095724, 0.05219332075544766, 0.043400490789541175, 0.06501243502965995, 0.038758313815508566, 0.03083038529647248, 0.04021523028079953, 0.019848368962162306, 0.06379472929984331, 0.014427103168730224, 0.02999985164829663, 0.05749926104077271, 0.027095475799537132, 0.017555407448006526, 0.02241931270275797, 0.020234730194455812, 0.011726052882815046, 0.03818132834775107, 0.03340676240622997, 0.009759792409438108, 0.020410092481012856, 0.048691577943308015, 0.036033812511180124, 0.06368604156055621, 0.06182866051260914, 0.04773139660911901, 0.054428259043821266, 0.01493403159214982, 0.10934309554951531, 0.02787005914641278, 0.09260261883693081, 0.08938989801598446, 0.11772045173815318, 0.1441617671932493, 0.18686998263001442, 0.11584537449691977, 0.06829898046063525, 0.07116100724254336, 0.10467437428555318, 0.11517943308821746, 0.14643046259880066, 0.1395979542285204, 0.1098401088799749, 0.07940908215407814, 0.18398620880075864, 0.11528125405311584, 0.12602391546326025, 0.08878698572516441, 0.11548091976770333, 0.03162401681765914, 0.17697284370660782, 0.05310790453638349, 0.07292560541204043, 0.08145572018942662, 0.11223125950034175, 0.10927903505840472, 0.12487936259380408, 0.1833469881010907, 0.09015556371637753, 0.10812930496675627, 0.06074877881578036, 0.08041138694222484, 0.15636741795710155, 0.10243181604892015, 0.14784482813307218, 0.14752880723348685, 0.142402000193085, 0.056566906427698474, 0.05175331115190472, 0.09972690405058009, 0.11448298474507672, 0.2019689745668854, 0.10609173215925694, 0.169052602989333, 0.07990555265652281, 0.13139810280076095, 0.16104137072605745, 0.18011052533984184, 0.17841003515890666, 0.0607960523505296, 0.10027641563543252, 0.09468081553599664, 0.19725102558732033, 0.16001159884035587, 0.041633914690464735, 0.23493984607713564, 0.1676626918571336, 0.09958313605082886, 0.10456682648509741, 0.11850236835224287, 0.1028285419036235, 0.14684696096394742, 0.13955094532242843, 0.10877969435283116, 0.15584460672523293, 0.13721382644559654, 0.09734071352119956, 0.12236294762364455, 0.09894381357090813, 0.14766093157231808, 0.13208594731986523, 0.15293218514748982, 0.11527536436915398, 0.13082457786159857, 0.1636789720505476, 0.12962522650403635, 0.10886820246066366, 0.11975725101573126, 0.086219198868743, 0.07901802206678049, 0.1520229617932013, 0.09942796866276435, 0.14825340120920114, 0.10542948198105608, 0.18127202801406384, 0.08862297024045672, 0.08253671468368598, 0.14566422014364175, 0.147848532934274, 0.12263442948460579, 0.18278013994651182, 0.15378992126456328, 0.13492352648505143, 0.0984628883057407, 0.09586019760796002, 0.12303538939782552, 0.0830394887764539, 0.09427987597882748, 0.15763477209423268, 0.17127009614237718, 0.150962018008743, 0.11131370373602424, 0.09037308847265584, 0.15372155207608426, 0.10195368634802954, 0.11175956909677812, 0.1440657680588109, 0.08537349996290036, 0.05909947053130184, 0.10839813375579459, 0.20839223132601806, 0.10642798697309834, 0.08444962025220905, 0.10725837812892028, 0.12493323827428476, 0.15083606833858149, 0.061494956990437846, 0.12775556397225174, 0.09660581259855203, 0.2273085798536028, 0.15669227338262967, 0.15093081896858557, 0.08089673625571386, 0.08751713457916464, 0.07374721632472106, 0.10233401201133217, 0.11280613472419125, 0.14427139131086214, 0.15873042973024504, 0.11822872874992234, 0.15938360110989638, 0.14870084077119827, 0.10696183118437018, 0.13276984276516096, 0.15875081292220525, 0.1384569433118616, 0.11112783942371607, 0.20801780213202747, 0.14221173897385597, 0.08332123687224728, 0.1861280452992235, 0.08107441743569714, 0.10677926455225263, 0.10907846010689225, 0.11609514323728425, 0.12976136777017797, 0.05549181518810136, 0.2603539137967995, 0.13240834644862584, 0.15174575309668267, 0.07366231802318778, 0.10231785609253816, 0.08669403767479317, 0.09172224679163524, 0.12674304044672421, 0.18818182152296814, 0.15116717985698155, 0.09598386740045887, 0.15138261472540243, 0.10652629312660013, 0.17464953980275563, 0.11108417569526605, 0.09435756145311253, 0.11290696502796241, 0.0794933969154954, 0.11901985986956529, 0.13542914363954747, 0.2276910836143153, 0.1066816301484193, 0.1231236532330513, 0.10368057832654033, 0.21431970968842506, 0.1872430004711662, 0.09614347919289555, 0.1692980019641774, 0.14401799919349806], [0.024571086346570934, 0.022124702975686108, 0.06343279193554606, 0.009722283841775996, 0.03428167224462543, 0.059002317887331755, 0.00925224821548909, 0.0413150914412524, 0.0049375627755320495, 0.01942151615263096, 0.0719940107581871, 0.04836957236485822, 0.03947638367701854, 0.02644419244357518, 0.025605389149859548, 0.0821569182776979, 0.04411159209640963, 0.012553008955105074, 0.015719256064455425, 0.02812835537562413, 0.06693480616169316, 0.005484609157844845, 0.014098557360869433, 0.01264041698803859, 0.07006749377718993, 0.05396856513938733, 0.02780252116333161, 0.05932797398418188, 0.02798623112695558, 0.03172266563134534, 0.05606787784823349, 0.09397484734654427, 0.03376052342355251, 0.017550957954621742, 0.026841072664995278, 0.04685060726478696, 0.05435860063880682, 0.027264566726184318, 0.06720065618199961, 0.02274508075788617, 0.019162765304957117, 0.026002917372222458, 0.0502500405668148, 0.018443385870861154, 0.0391481728958232, 0.01717795877318297, 0.038893647624977996, 0.018282159165080105, 0.009894559642166963, 0.0252139541719641, 0.011122650350444019, 0.022269049426540732, 0.0374397608185453, 0.04559862533850329, 0.01871883207266884, 0.06863503849932126, 0.048683347313531806, 0.03194918776197093, 0.051520465074905326, 0.02672136721334287, 0.04707919553454433, 0.0067441101003039095, 0.03620543437344687, 0.021220902812534144, 0.03953339418928538, 0.06939731830997126, 0.015985265540491258, 0.03871159328679953, 0.016260321584663222, 0.022937101079151034, 0.05458245273413403, 0.05669445065515382, 0.0103629990148225, 0.01587252694714282, 0.033494395203888416, 0.02968689433432051, 0.03288563733388271, 0.02038269323695983, 0.04445558220946363, 0.029642813306834017, 0.026516200276091695, 0.017972448641168218, 0.03292986424639821, 0.05630407588822501, 0.033393466512539556, 0.03933428826608828, 0.037679052978221855, 0.07168307887124163, 0.01637785233158086, 0.015679860321272696, 0.031154721642711332, 0.05721904643412147, 0.0363508613913187, 0.03232234131012644, 0.008023757171551031, 0.05978443127657686, 0.04115558482174363, 0.04049023713118263, 0.07898657196866614, 0.06884148277874504, 0.03526289834241782, 0.035080311354249716, 0.04851565416902304, 0.05936527983950717, 0.03297992656007409, 0.05355877070022481, 0.020531853893771768, 0.052542084362357855, 0.05229637665407998, 0.04003544564225844, 0.08789627959153481, 0.09034907511834588, 0.05411661808778133, 0.020235479975651418, 0.08841457856552941, 0.03864399084289159, 0.061745601040976386, 0.07222924527845212, 0.014083259788874005, 0.013213802827522159, 0.011031103253896748, 0.028469999453851154, 0.025481208759759153, 0.013964612003681915, 0.022878764030922736, 0.016507800269339765, 0.04852688053090658, 0.06215019111654588, 0.015991767602307454, 0.013879453314335218, 0.010091650316358676, 0.008899074979126453, 0.03443418995344213, 0.06409611419907638, 0.0611211181219135, 0.04558375524356961, 0.00690338941058144, 0.02574129292874464, 0.0074504001698057565, 0.05349036419231977, 0.05583385790565184, 0.015681219087647538, 0.02211756139461483, 0.017793919292411635, 0.03864415029862097, 0.029528622648545673, 0.045084563815700154, 0.05774668204997267, 0.014140150709343808, 0.10717043999050345, 0.004714214492456189, 0.025787762399496775, 0.010198718053288758, 0.015829170255788734, 0.01814994152768382, 0.03030232898890972, 0.00627913125624348, 0.046114905670817406, 0.03422955736251814, 0.06525406134980065, 0.07288913415478808, 0.014595585110198175, 0.03957239638215729, 0.04198302095755935, 0.03313495824113488, 0.040084941379193745, 0.015400653339124151, 0.0457359743969781, 0.0466216084813433, 0.03368174550788743, 0.008352195261977613, 0.010914499555448336, 0.04022871616429516, 0.032312858783240826, 0.024205761396193078, 0.02671529262858842, 0.07969658422682967, 0.014445372724107333, 0.06939997138189417, 0.047383202971624475, 0.011149662829536413, 0.04485647766185658, 0.004568211567987288, 0.004355408567269998, 0.015410149436710137, 0.01778697787917086, 0.08485750122261898, 0.023197789144303118, 0.02285069812621389, 0.08981528518987553, 0.003579605553698327, 0.023497484491339753, 0.04124448647988694, 0.013043173322720187, 0.025879005003454428, 0.012443301716952451, 0.060413976066878865, 0.014131353502827031, 0.02763017326859491, 0.03623764103810702, 0.06457457638212613, 0.0023723265746541855, 0.03359555120446852, 0.04522673386548247, 0.014356030018201895, 0.030740760998534303, 0.005245738962133015, 0.0630768799622144, 0.032400148920714855, 0.07856163941323757, 0.014755595541958298, 0.020468955393880606, 0.022556420881301165, 0.008428862933734698, 0.011337365971745124, 0.05368798412382603, 0.044868660758116415, 0.056399192927139144, 0.07541816309094429, 0.02000976021268538, 0.040682371107063124, 0.05071340534569962, 0.009913947083987296, 0.007786600700845676, 0.08448987773486547, 0.08305104422782149, 0.03005975271974291, 0.0204069830942899, 0.06758593515093837, 0.048570221955222745, 0.053682182649416585, 0.026719677661146437, 0.07644502406141587, 0.039990299314792664, 0.05988061361547027, 0.03741860070398875, 0.05193248510892902, 0.011384637810156813, 0.02881067492333906, 0.018137091770768166, 0.0235973139559584, 0.07320421867604766, 0.003484473459788465, 0.029664088772343736, 0.012412070446381611, 0.08032450053308691, 0.029022008047572205, 0.02008936763741076, 0.040986239444464445, 0.03957966688488211, 0.02489531921621944, 0.02018819117386426, 0.01048433973586985, 0.011123567220887967, 0.042174618890775104, 0.050409058641110144, 0.02097140548617712, 0.03455562736572964, 0.02684464684820601, 0.031043903303465674, 0.034835149866661856, 0.010151370727856244, 0.029286640097520182, 0.07647300006023475, 0.02308567819584693, 0.017835286179823533, 0.05467230773397854, 0.05230169976130128, 0.055210983114583154, 0.0156885930669627, 0.023081210042749132, 0.043485178745218685, 0.057293943129479885, 0.012704515646743988, 0.03102610193725143, 0.04242641645084534, 0.06832384876906872, 0.00754722542062934, 0.022602847943614637, 0.03671822364309004, 0.08621927350759506, 0.017235625768080354, 0.020281538932717273, 0.126201542360442, 0.024031552619167736, 0.022895764725814973, 0.03334036096930504, 0.08805414754897356, 0.062149309021021636, 0.07583935013306992, 0.044249137930039845, 0.07827262420739446, 0.03514239391578095, 0.030425737545426403, 0.040683867276779244, 0.04148356490103262, 0.02901828967567001, 0.021748782700992057, 0.053636968468448946, 0.022395426573764, 0.05559778539463878, 0.022198005113750696, 0.028117201956255094, 0.02266205182032926, 0.032536039128899574, 0.10104795066373688, 0.05587404753480639, 0.023692994178938012, 0.03271833095433457, 0.03518482271049704, 0.013225144540358866, 0.04239696463836091, 0.037839808102164946, 0.031988186562167745, 0.010388103962343718, 0.00574859235868124, 0.043876350790794404, 0.017127803160942028, 0.029675308348877088, 0.02037157374434173, 0.047504409682005644, 0.015117999399080873, 0.02036639821848699, 0.009513164438041193, 0.0458002350559192, 0.060833867107118876, 0.02726946066000632, 0.04133589532492416, 0.03183346700721553, 0.03588062983804515, 0.0427990950244878, 0.022183586244604418, 0.027192248463896767, 0.04632166886169996, 0.028010670261989747, 0.02689391018689743, 0.03189753767635141, 0.00868276140785643, 0.022881629145038978, 0.012236951584262508, 0.06728935427963734, 0.027978446633954133, 0.03297689011586564, 0.02133130724541843, 0.08016801678708621, 0.02620792485374425, 0.01654195772217853, 0.027415104809084108, 0.019725352259618894, 0.023155131344018236, 0.00847934848362846, 0.06082524971238204, 0.14578375087252685, 0.12248042917677335, 0.13193722601447785, 0.10665317238973719, 0.12158856274826185, 0.10668627132794686, 0.1283832360059023, 0.13885422556528024, 0.10125286823936872, 0.08228091376700572, 0.1057390228712133, 0.1131101930513978, 0.10400950496218034, 0.1688639024006469, 0.1491808635847909, 0.1353224507932152, 0.3163811202560152, 0.09886270149477891, 0.07229788588093859, 0.175085308562432, 0.15899573692253657, 0.0970631723425218, 0.10378237893538815, 0.09198157609041248, 0.12932854385248252, 0.1393855456262827, 0.10938644036650658, 0.21674007124134473, 0.0896211156089391, 0.11363377781318766, 0.11505550545241151, 0.15061394311487675, 0.1098139581403562, 0.20906925999692508, 0.1320394812417882, 0.2049209140241146, 0.1871988142707518, 0.13931087963283062, 0.11596763293657984, 0.13395734690129757, 0.099851048817592, 0.10380008191402469, 0.12425777023392064, 0.07779510518802063, 0.12922881277544157, 0.12945400497743062, 0.08910742388772112, 0.08481401391327381, 0.14575679946158612, 0.1022891133491482, 0.10636221657374076, 0.07200631259807519, 0.1289505727056946, 0.18662990336971624, 0.14021356190953935, 0.15127726537840708, 0.24138617302690232, 0.13251702061721257, 0.12573488668671676, 0.07308002641158444, 0.12846915210996354, 0.1043615017884544, 0.10601847751864366, 0.11779878182070595, 0.09829121894602265, 0.20031755603849888, 0.1252678781747818, 0.14856300316751003, 0.1420554452176605, 0.2068518211266824, 0.14452778255300863, 0.12252046274287359, 0.1594526216919933, 0.1349146105349064, 0.09640891530684062, 0.09542687157435076, 0.1039614782535604, 0.07444894367030688, 0.2092710563114711, 0.13923923990556172, 0.09463239527706589, 0.12546704177345547, 0.08995435094194752, 0.17074226375137055, 0.07975107058882713, 0.14084426020937307, 0.06274964287877083, 0.30504524282046724, 0.04698676549430404, 0.12161385853375707, 0.13802931697240897, 0.15181239880621433, 0.11805030118141856, 0.10692079338644232, 0.190241026026862, 0.08783939121557133, 0.27600291264908655, 0.08243357736085143, 0.15157313378793852, 0.1761358164783035, 0.17692393490246364, 0.15891201927193574, 0.10324007339243378, 0.14984457939863205, 0.1217952309442418, 0.13200465882463114, 0.04395790391468576, 0.22505606072289602, 0.10119891792003598, 0.15095386201781885, 0.13382914449487412, 0.17114057737801755, 0.1492924147418567, 0.1457624855850424, 0.14219690619834832, 0.2333681418427399, 0.1147394845528262, 0.11316102889499494, 0.1253802300031696, 0.09676531582538571, 0.10913921613246202, 0.18477364868990012, 0.11909341306558677, 0.0908603241134967, 0.16734060485448154, 0.17803291896624224, 0.08951507415622473, 0.13731274328061513, 0.067605897651187, 0.1660485520426716, 0.15942572456385407, 0.0998288132250309, 0.17174588489745343, 0.11814452255410807, 0.12249967242990221, 0.15804041389908108, 0.07759171431618077, 0.06880522865269866, 0.11236681044101715, 0.10598161271108048, 0.11186934927744524, 0.09937525327716555, 0.13597046530672482, 0.08635284991136619, 0.1441452923629965, 0.08450735001159565, 0.09920259325632028, 0.12391076742538384, 0.07147800523255553, 0.1454841640910932, 0.07316048709409577, 0.09120774761374507, 0.11105178921882596, 0.08852760892893587, 0.10852558298834733, 0.1276793373482568, 0.091777689888009, 0.10398541018366814, 0.09830392112157174, 0.12061206943222455, 0.13970133582396166, 0.08950521504240376, 0.12316174618899822, 0.12804103722529753, 0.13038434434149945, 0.1274951829441956, 0.1440080925822258, 0.11201830128473894, 0.12443037597196442, 0.09643047236438308, 0.09719676910234348, 0.1289783926414592, 0.13230911748749868, 0.11276587724153485, 0.0764814546065671, 0.11892809479364327], [0.010551207665620106, 0.056548518128693104, 0.029847160913050175, 0.07550986031336443, 0.005837834132502654, 0.06767379865050316, 0.01231137924228928, 0.10170707279550177, 0.04403377091512084, 0.041033119428902864, 0.11621157984648432, 0.015898085664957762, 0.03271942678838968, 0.02473862512436296, 0.06009544458772455, 0.09216404772762742, 0.013889047799498906, 0.032716922994170866, 0.03534155072910445, 0.0558278019806104, 0.05368434039077588, 0.019817466781075512, 0.032302419521978924, 0.06298533880284854, 0.051671473043305535, 0.03995174156235797, 0.02679809425691409, 0.003562615460915757, 0.02597223232234163, 0.038858903239348104, 0.1185807255761964, 0.020423194992222955, 0.02624014508910477, 0.022701216861605644, 0.03611512136246477, 0.04229166278881686, 0.03367045468517712, 0.03742815447705133, 0.037518019654921124, 0.01161445168379162, 0.02755815356171557, 0.01838334061072341, 0.02521434602593737, 0.0057141876646450585, 0.0207519519941083, 0.060949591254549365, 0.022740736437429274, 0.041139435688299794, 0.0799480832314917, 0.0674170884968979, 0.02783703145438007, 0.07376572676002979, 0.0076247785805857605, 0.03490091008799417, 0.029205962283802882, 0.016900604191635336, 0.020763124073190347, 0.003997125962216939, 0.02517167465495212, 0.06419387752456324, 0.03522485627659729, 0.021842834439926913, 0.060645878980202336, 0.017359626346400807, 0.055053973503943, 0.03186272543721965, 0.0138055260758847, 0.00886209397244134, 0.025623431396005408, 0.03730648636285748, 0.03308958799711295, 0.0225437017423766, 0.031345752999186516, 0.03510271318789039, 0.038812701789928336, 0.015034675298790847, 0.050667264964431524, 0.05225755427298801, 0.0865642474964261, 0.027878547619496073, 0.014170148742518254, 0.025833597440006476, 0.03208170225843787, 0.027634188499567763, 0.04459934003118958, 0.037400968971529176, 0.034613893167780976, 0.058907214419118, 0.020714203394683342, 0.018752606153222065, 0.00455563237691032, 0.06458214883293424, 0.0310999163692551, 0.03068400832957455, 0.054907487971442084, 0.021078451170719097, 0.017486587033740113, 0.011110962584747799, 0.029466346704534123, 0.029358758191977228, 0.014054331296522702, 0.02794887438150389, 0.0267787848466209, 0.027921059534751942, 0.011740062086443816, 0.021525424239890914, 0.033085611781903675, 0.023541361958320652, 0.010847266064956784, 0.05167853320017457, 0.01402104236850781, 0.026744152419269085, 0.08044330522950206, 0.0778788635507226, 0.0324391850403377, 0.06742354815027543, 0.006144385227733957, 0.024302154080942273, 0.027397233893030455, 0.02119453833438456, 0.0372290112344282, 0.0989091879289065, 0.042152522397892814, 0.028328082158363292, 0.030968026125005314, 0.03538839339411684, 0.05923555751464196, 0.045396181023014445, 0.04610548760475857, 0.027783768151753714, 0.01673297890062843, 0.016949920116790702, 0.0494705361447164, 0.01120441042751606, 0.031944712823522944, 0.05519784328394702, 0.0530998197916363, 0.030370219810200588, 0.03919869661331177, 0.05377559656543391, 0.028757392960999693, 0.06952978870166199, 0.019806364251832877, 0.04112952907702752, 0.005862893278910113, 0.020814969237627726, 0.031364348251372576, 0.029057983974260942, 0.047261901266340695, 0.028189869664077247, 0.010927900622066642, 0.08905019624424831, 0.03729995546330299, 0.028872642133917128, 0.018516430165618658, 0.027527892596221397, 0.036313514823892286, 0.054381826892495155, 0.06505544736449208, 0.05505171058965581, 0.007662070865210677, 0.07193302403071097, 0.0156831715721637, 0.0650393660845501, 0.027106057553152953, 0.0010658628452802077, 0.034076591820589135, 0.0327338761916118, 0.07089105208537408, 0.019318919961473772, 0.027378457132726908, 0.05643786942320211, 0.041823870568935356, 0.006010571760790688, 0.08844402698533875, 0.029249402095696757, 0.03324999028284635, 0.008841314685664006, 0.04645752175045865, 0.04673847256760512, 0.030104210334164754, 0.02110131610451, 0.023115135097344006, 0.11819429988307611, 0.06065075086163623, 0.013167935556599071, 0.022252610219376426, 0.03826737337346588, 0.013183701317757368, 0.01427382041168, 0.043622025687779696, 0.05524335602032287, 0.012557181945469762, 0.007070538454822132, 0.025032622473580495, 0.03427043570471661, 0.05629302255277123, 0.0383779610108052, 0.04292245947622827, 0.0025526633710666958, 0.015727373039616004, 0.06145716937524932, 0.02394640495601509, 0.029885355649249892, 0.0404256439900824, 0.04033589755584087, 0.05754897730158908, 0.024656756481687938, 0.018777710252574513, 0.02546507998236588, 0.015222246126670922, 0.046662025419729095, 0.02504381660505065, 0.03463849684755717, 0.04765254405460187, 0.055962711705693176, 0.012979209522849746, 0.033020075477127514, 0.0209830627177975, 0.03674236252637846, 0.0424451134832842, 0.032077610692275424, 0.06064342946878501, 0.014581268021304692, 0.03226633842236229, 0.020206713483535817, 0.05944248355392899, 0.009534552709997764, 0.052243084513715336, 0.03011532813044531, 0.032673204982919354, 0.04590914331908737, 0.06644037126430444, 0.011748979732926403, 0.05999437001134668, 0.02276563527993858, 0.02220115521257477, 0.03091308514454535, 0.0587401862389275, 0.04887349657448275, 0.08915831401411976, 0.017693365491660576, 0.0322576497814485, 0.08656540779130799, 0.01630524908458548, 0.06975124896104846, 0.030107433375503336, 0.09113116136619023, 0.04007795586117676, 0.06975935745452132, 0.020383191960198537, 0.04300707279305373, 0.07409176283649035, 0.038123418776584525, 0.028116392803245356, 0.029935462067701986, 0.03444591164588928, 0.07499299304825918, 0.05702092099402632, 0.020255040443901504, 0.03583544958382845, 0.03853675516854439, 0.02858094671475036, 0.0391852751906429, 0.02502178118032004, 0.014433462738192506, 0.021970539819449186, 0.06222308613359928, 0.0685159827449492, 0.02521645966252046, 0.05309569429872291, 0.08499420567282609, 0.01630186828385506, 0.03422411551166858, 0.03243259985798171, 0.025387905105682354, 0.07395366060414485, 0.11845664866268635, 0.022651695679607134, 0.010189799558637398, 0.0217624908047063, 0.04835895329181637, 0.030169895916645015, 0.08410131465643644, 0.008905509187440788, 0.02605303905771247, 0.04296959391129868, 0.036325263657740185, 0.014197932207025588, 0.021747488395443985, 0.037150267245514054, 0.09095584148807184, 0.03506852859365089, 0.024683765568105236, 0.024450799051140035, 0.030640867073088884, 0.034537751360663345, 0.012005825593535389, 0.06956347117998771, 0.0238509656129671, 0.04578584332817367, 0.050117488750921826, 0.03238927539704101, 0.036198594740458896, 0.023225754965096712, 0.04287049726450017, 0.024202348365049278, 0.01528899700913046, 0.04491298266553453, 0.03606246365234256, 0.050538051540830305, 0.022003253689035773, 0.030598305964044163, 0.07411321811378002, 0.034640807259295664, 0.047666586336812804, 0.04424939577334693, 0.03119094862735697, 0.038767480823610506, 0.038647169779453955, 0.00855309166945517, 0.04475349640207631, 0.012138920237443276, 0.01066063585624631, 0.059632127306291034, 0.012032698972948959, 0.041625572102410455, 0.04137903318873473, 0.028934975753405263, 0.0017030115746560373, 0.04481094117675509, 0.053949959709175994, 0.022313652925991585, 0.01736880013985293, 0.09110602842909948, 0.053525488557560105, 0.022981641814112663, 0.02335636786717389, 0.032552690378257206, 0.028475241136870215, 0.05074563915176051, 0.012474580484974598, 0.016489164305052588, 0.07203474321535655, 0.01859595955881689, 0.020269106474838088, 0.011719939282297023, 0.021817791408726146, 0.07579622244728462, 0.04943425487726927, 0.021371512141610895, 0.007641535851040057, 0.10610716883093119, 0.14602450866784367, 0.16601051336952619, 0.22169269834245953, 0.08462508940803153, 0.15695327866290296, 0.05240492529368826, 0.32395842937486513, 0.08651387984199183, 0.15995084281478608, 0.18629835758890423, 0.15152516136212008, 0.11228138288216931, 0.11573317194623606, 0.17265202770275728, 0.2182162513158151, 0.10156756599566766, 0.14547387750021049, 0.0776182586061103, 0.15247198912714208, 0.2324438685817378, 0.10259275776999337, 0.1987258078796523, 0.13302677683532238, 0.13870065951985971, 0.11561179560210023, 0.10933124832808971, 0.11061647507761206, 0.09033985382744245, 0.06843669592802014, 0.2308499626815319, 0.06353258408073868, 0.08988829555788211, 0.09510540882391588, 0.08296612557023764, 0.22566170750984124, 0.09801999492836849, 0.1391682651426111, 0.08703805492924792, 0.11973025889268943, 0.09301440816904817, 0.10514997305082423, 0.10980116775525467, 0.09354528039693832, 0.11541180419070379, 0.1277229128671544, 0.16398288788540022, 0.09339003158467156, 0.11756661427872521, 0.24953749563012803, 0.15753113265548432, 0.11542719336492674, 0.12514776390578064, 0.10182728205940553, 0.144710525604231, 0.1418533232063055, 0.1763377349291529, 0.117536297334092, 0.12870079039462975, 0.12325762318713324, 0.2028404442327363, 0.12467691488564014, 0.11268135213426181, 0.1499052404292992, 0.1974351799913815, 0.10140931805861847, 0.14354078551488264, 0.15575392730534077, 0.11666167926575456, 0.13204531664294855, 0.07721761760434934, 0.17813297574009213, 0.06033519136586359, 0.10553160828671285, 0.12696178656603607, 0.08967364779008286, 0.11520065766360078, 0.12476678006350994, 0.142500387770789, 0.15030218341520854, 0.10162836273333856, 0.15320541762879916, 0.10903122049889394, 0.12121766193636827, 0.13602442241140775, 0.10387323477438518, 0.13926140085927077, 0.10476584759141717, 0.09778981549399239, 0.10365789490086691, 0.07150706688740424, 0.1911416726985148, 0.13906561636498996, 0.1256228062723364, 0.12268158766840186, 0.17665136738547257, 0.05714845843613148, 0.13437430667025702, 0.14378214042101586, 0.08510927164128848, 0.18592379268790993, 0.148076344281435, 0.04718256016661014, 0.08589754612850291, 0.0937546898743936, 0.17970853405339376, 0.22368125378021173, 0.19994080625474453, 0.19850326196423598, 0.2206918727606535, 0.06701956197087254, 0.06872516152049814, 0.15832328157765524, 0.2125626839697361, 0.12036348134279251, 0.13113567259694847, 0.1300096573042018, 0.10279933097107069, 0.18317343241402081, 0.10813134057181222, 0.18472905536847456, 0.1759551226028374, 0.12432672296251569, 0.10556069029761211, 0.12547207650329384, 0.20200771891645022, 0.15778607183269092, 0.13044044561684132, 0.1579286591815097, 0.12664261726396425, 0.15001718513667583, 0.08503382533256497, 0.14069405969764504, 0.1472379057002919, 0.1313168007348265, 0.13525667360850743, 0.07949222304991313, 0.08691977949014731, 0.18924131324248655, 0.10543064227593796, 0.11546474349285875, 0.20343834214976855, 0.17504006384738854, 0.1873997284897736, 0.07437289346541677, 0.0820024972781539, 0.07311174113835607, 0.09516000375151634, 0.155149569734931, 0.08538863129381623, 0.08942084599818502, 0.13137690536677837, 0.1040684085871492, 0.10066421875464064, 0.08241961311016764, 0.12033701847706522, 0.1449672154017857, 0.0931120900703328, 0.1912211970027004, 0.1472428318645273, 0.06540999548243624, 0.09146519058517047, 0.09611068559544426, 0.11894709377416543, 0.08234871977141925, 0.14792651017861708, 0.0823616458635245, 0.1476350522467068, 0.13203220734638826, 0.08318046799727849, 0.07342495968831436, 0.08206170624388115, 0.11804323084652424, 0.13059485304568494, 0.2015656940639019, 0.050717588514089584], [0.02776916777448995, 0.02563006746848779, 0.034990341003452025, 0.031186795993042842, 0.0671044738431062, 0.024847770874787654, 0.009752843362678374, 0.06735810344772679, 0.04438276183126228, 0.06552134307899646, 0.04237446780981762, 0.011723238658825201, 0.04694089313436832, 0.038818683076117716, 0.04602282168343663, 0.037169649598321745, 0.028930456710181067, 0.046862501983663866, 0.01727468563642885, 0.05164942744054964, 0.0027413970383349806, 0.02423888917214104, 0.023667545723063604, 0.031224563252180815, 0.0057485965995251066, 0.04314596551869597, 0.06442756498498575, 0.04214252079171794, 0.026594850966440778, 0.038500914948859384, 0.06782343597816569, 0.010401407489553094, 0.01987862483864384, 0.02686697065031954, 0.05919604642050607, 0.04183184335540448, 0.020384784821154814, 0.03668117902374693, 0.04862801617543612, 0.10446837105389152, 0.041854106089366336, 0.027510886812316518, 0.029328498922820603, 0.024274189956486225, 0.004649656550360045, 0.032039785757660866, 0.037302713708153794, 0.041045051467205794, 0.060178110509046485, 0.017773773587707962, 0.02169330737420491, 0.0621410919619458, 0.029145294467785528, 0.023278480528720787, 0.035882302426866124, 0.03448548720085195, 0.02151993998060269, 0.06988277618906327, 0.008121233815992517, 0.05802050485674824, 0.036216779478958676, 0.09926137474498578, 0.05182459464828883, 0.06443760051791157, 0.07420472534639494, 0.0550057771615684, 0.04277667622747166, 0.0410514771938324, 0.06273115279951266, 0.0497738141566515, 0.05677559326535889, 0.03793741536459752, 0.029276662240070955, 0.02689240892816867, 0.014833744116393583, 0.02766478364355862, 0.04238469333254865, 0.024544087438178912, 0.06620171014219522, 0.04660682998863714, 0.03923992100836975, 0.04550525891993727, 0.01163180945773742, 0.0737241054219859, 0.036992412858775685, 0.059064838103950024, 0.005147872584140194, 0.05774801197860922, 0.024426817927243452, 0.01839824632874557, 0.02700194313989154, 0.10761899234993116, 0.026577251464394585, 0.012415190011129847, 0.05156456306576729, 0.05525566464556115, 0.026385159896952764, 0.012929259167451943, 0.022836270775379877, 0.03996108838223985, 0.022388666668640714, 0.010314549069984682, 0.01684203983417579, 0.036526215196188004, 0.011828660100166286, 0.017112705756777098, 0.03979721199721098, 0.00970862917269447, 0.04026573703491262, 0.060537890131984434, 0.04744352134210723, 0.025310513097792864, 0.03479794239891427, 0.036888868414929936, 0.01420750718430749, 0.026259330666757057, 0.03621201955580285, 0.043526464208428345, 0.011689140577800572, 0.0375834948915456, 0.061299030003803115, 0.08314553701451846, 0.0650046793743968, 0.025995163413296853, 0.011806394821698112, 0.05011169406186257, 0.014833925624511071, 0.02947636866675956, 0.018229348784578697, 0.01639426439734442, 0.042338797223887274, 0.025807253317907453, 0.02310440067334899, 0.0216639183262097, 0.11524284897106034, 0.06128121167421341, 0.058108809404075146, 0.024587842768856456, 0.023939037762050117, 0.05354630940460733, 0.008882921604838754, 0.06007300543465784, 0.055030604757900746, 0.037971379434955974, 0.022908583948654786, 0.02169155845019434, 0.02517741675754743, 0.11187010245131594, 0.027857049933767745, 0.05494975731042879, 0.056394202302076986, 0.02624300681054592, 0.038365587924740145, 0.007295541515174721, 0.018910279031842947, 0.0304686107805797, 0.06531688690717731, 0.02514038061989205, 0.040277071962399144, 0.013306919884468828, 0.02075061697645911, 0.04225801084456699, 0.04322691135374563, 0.027650865193988596, 0.031980685357536585, 0.03990289721904056, 0.05844072159379721, 0.05286058870011142, 0.03520508037347879, 0.015786804225561873, 0.11006822556789432, 0.033693216142377684, 0.05213948917974319, 0.02671196950333459, 0.07181120663881302, 0.065086008581732, 0.02952867353867207, 0.018575795194400207, 0.0236236207586314, 0.07523900270462036, 0.05189487052017024, 0.023033897492236326, 0.021714569269014255, 0.04908388992771506, 0.06976807662951094, 0.06608494105083601, 0.01014071433538837, 0.006600165681447834, 0.04565115751964705, 0.032320828177034855, 0.03636684428368296, 0.023550642621038214, 0.015941876618723785, 0.015017465954380376, 0.01419930624043835, 0.03658118671072381, 0.03656476955594761, 0.02627503196708858, 0.03899761276053531, 0.03002878777416689, 0.03704968799969979, 0.03425500921106764, 0.02253925733800445, 0.055275691606636555, 0.03065885164375816, 0.0088671100425667, 0.04110586177557707, 0.008721018060376602, 0.03772078627454383, 0.005971949547529221, 0.02506790459821267, 0.04034838599285909, 0.04444950592837163, 0.04043716212202396, 0.03470855898090771, 0.05517389439046383, 0.032838129704552035, 0.041452973149716854, 0.021803811891004443, 0.017646427831745574, 0.03510830092376896, 0.06280232433761869, 0.05233542973707829, 0.027774640159415345, 0.02720974448935262, 0.04297834701303925, 0.03472629249362009, 0.0563568455566253, 0.07652993593364954, 0.038331684922533374, 0.029195584090692655, 0.06415145551519734, 0.03214711303423558, 0.06843521672167949, 0.013993623616573001, 0.06126437043505056, 0.043089182315660376, 0.0568517961406282, 0.027224997956571833, 0.08995710579412323, 0.03680863504164985, 0.04170903190970421, 0.03402381197416356, 0.031767123245767186, 0.07148656834449087, 0.04267409869602748, 0.023222353808315735, 0.011889178638479539, 0.021557239050577794, 0.027222165072868978, 0.038661690428853035, 0.031016395493809665, 0.06769148127308913, 0.08715085459074803, 0.03783935009102736, 0.020175585689555322, 0.040922090743801424, 0.03124892265935029, 0.015697753289714456, 0.04540357705471771, 0.10701076034456491, 0.10446991811373404, 0.0394335782953671, 0.03125609477449741, 0.02977053395339421, 0.008327530514049743, 0.07334420723574502, 0.05538132593833974, 0.053171052397894006, 0.039030114587928565, 0.046600926733974896, 0.021888242003374865, 0.022741589695215225, 0.02142510962273393, 0.016664004119645272, 0.03990144854677575, 0.05006009825904455, 0.016930812570665563, 0.014273170714399644, 0.043138216648783, 0.05832627987755196, 0.024219513604683534, 0.013267066978317286, 0.07418915975306715, 0.01660803346229451, 0.03544784323977573, 0.033436244752790244, 0.033876905749951086, 0.02577415607603533, 0.01884483263295676, 0.056126177577035766, 0.04537373847727265, 0.031762722946171246, 0.004565087762395186, 0.01237872299472136, 0.010667942830228379, 0.031331720895000865, 0.004236368079935866, 0.07192053220101766, 0.09874939971736499, 0.03238818634833608, 0.008493773289956152, 0.01418630635764982, 0.054208837782165835, 0.008072249524827515, 0.05594779411330819, 0.05175667668559721, 0.01607316466314452, 0.012877268966154327, 0.023148295103705356, 0.052000725375754495, 0.09764251232679401, 0.011959608028908926, 0.028881768429917947, 0.01389639378924455, 0.02352443759861801, 0.07657988968172244, 0.01839952027824308, 0.02612020045385829, 0.03580900028880153, 0.011034505258846496, 0.05596827908552118, 0.04894381655114038, 0.012151423093330647, 0.03075759545234697, 0.04793758983058589, 0.05706906983894961, 0.007141289301216602, 0.028693512281669036, 0.05916774472487824, 0.016473366313480904, 0.006583033520395735, 0.035863313624369245, 0.044611227964716296, 0.03417773085779377, 0.012382436277610915, 0.05547000028725181, 0.05425819102674723, 0.027635798323899508, 0.030638543090650013, 0.024941620749554465, 0.013902042593274797, 0.009522643572251712, 0.021322985013414706, 0.0334782392850944, 0.047578919612403424, 0.054366339330694506, 0.04499560448208025, 0.047897773395691595, 0.02447730771798108, 0.07089485188147851, 0.006899714295286685, 0.13871727005711623, 0.05143993993156722, 0.15097763788487228, 0.2178919387183019, 0.1189125699124166, 0.10810105076857976, 0.106021510570177, 0.20812670700252056, 0.17544695415667125, 0.11258956670228924, 0.1628502229494708, 0.14013118775827543, 0.234075663877385, 0.1437871480094535, 0.0753510356215494, 0.1075447266921401, 0.10371766705065966, 0.1603452887918268, 0.10187676761831556, 0.1406047644891909, 0.14770335358168396, 0.09767506165163857, 0.10823420648063932, 0.07542439882776567, 0.09242364165506192, 0.10872579153094973, 0.16042226180434227, 0.20964575691946916, 0.1150963261191334, 0.15024605499846594, 0.14372379998011248, 0.069364015811256, 0.15579092103455747, 0.08614333186830793, 0.18785782105156354, 0.1407380151961531, 0.15347718447446823, 0.13447985957775796, 0.11791118793189526, 0.17796745390764304, 0.07829663756170444, 0.09059228242508002, 0.08425790018268994, 0.11958787510437624, 0.0978123564273119, 0.13711262973291533, 0.10154885199985333, 0.14767253452113696, 0.11488173263413565, 0.1733302641659975, 0.08483488565044743, 0.1877517524574484, 0.12830111969794544, 0.11472775946770396, 0.14834823326340743, 0.22970201713698252, 0.07927802311522619, 0.22600451697196278, 0.10284483352942125, 0.10790490665073905, 0.11840550069298063, 0.18981884153825895, 0.11174539450023856, 0.1718700025230646, 0.10727686820817844, 0.10573779472282954, 0.11480949579605035, 0.1246000232973269, 0.17308610012488707, 0.0986066698761923, 0.12177210647080626, 0.05526463487850768, 0.09110121761581727, 0.07159167341887951, 0.161967951006123, 0.10537845614765372, 0.14119795337319374, 0.1628936491906643, 0.16978675073810987, 0.14072415951107228, 0.08756791613996029, 0.16695432843906538, 0.08395932441843407, 0.19300107578081743, 0.22724250411348684, 0.22419764607080392, 0.08398099004157952, 0.19974614812859467, 0.10671635078532354, 0.12160097993910313, 0.12216428614088468, 0.17422381336135523, 0.11026661563664675, 0.08516937627324037, 0.150639021769166, 0.11174177790858916, 0.10750969392912728, 0.15103110644434178, 0.06399588100612164, 0.13488958616341862, 0.14992137599204267, 0.08756513414638382, 0.10757422939475093, 0.09713733622006007, 0.10838634081717048, 0.1136409906404359, 0.09226005364741598, 0.07022591134799377, 0.11881860638303415, 0.2443193984883172, 0.09491146994488579, 0.12938666716217995, 0.0989886172381895, 0.1207747007054942, 0.13215472362935543, 0.11786926803844315, 0.10721136922282831, 0.12672629420246395, 0.08109264967164823, 0.08672837154673678, 0.15408994230840886, 0.15629144917641366, 0.13401002836014542, 0.1697702216250556, 0.07737813184836081, 0.10923353928540434, 0.09861078179840531, 0.1578281545745475, 0.10120312483715159, 0.0891164755448699, 0.12188809524689402, 0.09398700669407845, 0.10723029356449842, 0.0638526219076344, 0.12599047725754126, 0.17666066331522806, 0.09542109724134207, 0.09143189487180539, 0.07473513617047242, 0.09392772308949913, 0.14440542911844595, 0.1469377489494426, 0.10840428806841373, 0.12402567054544177, 0.1001715480483004, 0.10779603570699692, 0.10738964072827782, 0.13549226096698216, 0.14947522564658097, 0.14958014073116438, 0.12309290202600615, 0.11317616701126099, 0.15017379101897987, 0.13120548027966702, 0.10442232566752604, 0.15083092504314013, 0.21843391177909716, 0.11998960854751722, 0.1590023594243186, 0.04394339005063687, 0.21187227458826133, 0.11193101453994002, 0.18316014669835567, 0.1161219725119216, 0.08538649390850749, 0.18084503949752875, 0.12086208244519574, 0.1345223087285246, 0.1745106843965394, 0.1319073840443577, 0.1246621228222336, 0.14303417769925936, 0.18338319472968578, 0.1548097322561911, 0.20167575244392666, 0.1768552671585764], [0.0471775084733963, 0.032429091831935306, 0.04371227763061013, 0.018485063188044087, 0.03335862034665687, 0.06772000009992293, 0.0468070588872901, 0.03479862432660801, 0.06907119402395827, 0.009602042347458857, 0.024333571948643242, 0.020980920243476118, 0.025853254599496722, 0.03026283485814929, 0.02265664389623063, 0.04344021222953286, 0.06050283022757087, 0.07195667097611086, 0.026737529917487075, 0.026083529028775435, 0.018143391968416314, 0.049016321410558054, 0.04978911851399711, 0.035374863405844996, 0.061037142628005574, 0.038667413871735334, 0.026920561346092393, 0.04530938621610403, 0.03256304142996669, 0.011489066045864351, 0.0530018698690193, 0.01704001599656684, 0.017926649223746996, 0.020591208744528036, 0.03224806886698518, 0.006460238613986543, 0.02349771519324609, 0.024658744589292576, 0.02847681873078857, 0.026694174922470535, 0.011291515664197505, 0.05004392198419996, 0.053860050426529985, 0.09251330327242613, 0.02325620761673365, 0.04992424876296094, 0.07300799991935492, 0.027274975453370383, 0.01915449396307979, 0.02424431236327759, 0.02888280658849648, 0.006930396376576806, 0.006938982389069029, 0.02130992491064327, 0.03858679034081953, 0.05435813584231904, 0.0491621385860656, 0.07144257891923189, 0.021319943480193615, 0.009591060258182032, 0.028081266741667475, 0.043454067914613655, 0.010338594654708036, 0.02507941933747913, 0.017792865866795182, 0.09091692071940218, 0.02897804237103888, 0.023483311591137732, 0.034683636389672756, 0.03309441238109555, 0.05852311610111168, 0.013897274188431246, 0.07267537526786327, 0.04642943718603679, 0.03634270540039454, 0.012782447089973305, 0.06288839650473424, 0.031502070504107645, 0.03462255805996912, 0.03086394563849483, 0.06546005101076194, 0.035594542510807514, 0.05274097993969917, 0.013706573617777653, 0.011650077316776981, 0.022843894116314392, 0.02825894283263811, 0.06890565183545862, 0.009732933448893684, 0.03544687293469906, 0.03270672122016549, 0.05446450299184237, 0.0011852774810644665, 0.028384261465232288, 0.027228792663663626, 0.0628062801967774, 0.01512523427871721, 0.021957501769065857, 0.03365633776411414, 0.055473375998969586, 0.0658966882952622, 0.04447778048259871, 0.018937308474310806, 0.0394392542407981, 0.0389436454778271, 0.08691491439406361, 0.06775960618896143, 0.022265914594754577, 0.046474895639611144, 0.06890551612845489, 0.03465661033987999, 0.020359153160825372, 0.035285083044852526, 0.05342274817771145, 0.03456985963774579, 0.02640551934018731, 0.03702563393328871, 0.053217481156545024, 0.012111798344579126, 0.03480652586690017, 0.025910304127527133, 0.0442563405792628, 0.008346303881678199, 0.05695456705455269, 0.011931872061852897, 0.055091180971690586, 0.043102026983563385, 0.021879254807052866, 0.016236600000411272, 0.0032231261554573265, 0.007867136870377829, 0.029631946568510363, 0.027837324920775633, 0.013964452547952533, 0.006581060255744627, 0.08403202266033206, 0.016619797563180327, 0.040490695142320225, 0.04261903218658907, 0.04590751822771771, 0.044669541264218945, 0.05575106306267636, 0.03469228092581034, 0.02212488278746605, 0.06698978785425425, 0.014866997421319996, 0.016037943606664027, 0.0565951097357486, 0.05882193613797426, 0.011185397028124757, 0.07502399531326123, 0.06500335623111043, 0.07272562757134438, 0.013732800692585962, 0.008057591472087162, 0.02524299038174961, 0.017319608047338467, 0.05095211396526013, 0.011096243463855768, 0.06914512041424002, 0.012201513396576047, 0.05579044523515871, 0.012950072380980211, 0.046119828442377706, 0.026765840094802634, 0.03391459837023701, 0.053275380549686294, 0.029787202166127305, 0.023168722400441766, 0.04325996618717909, 0.027375385065429976, 0.01991756765970162, 0.03837292967364192, 0.03669318909357701, 0.018243521684780717, 0.018782025735293115, 0.017064353351348212, 0.006882107159721532, 0.04144327009895018, 0.06186760163732937, 0.015247185681281345, 0.0481660559640399, 0.03700422276077526, 0.014738918847537466, 0.024248470086604357, 0.02590426686219871, 0.018288349100787724, 0.013609233528508671, 0.037162260351968665, 0.014196925430691667, 0.021769959778924073, 0.023100431243489896, 0.06335762382618018, 0.013060561630741825, 0.019169576100206802, 0.024036551725917628, 0.01811020651699177, 0.024110878451860378, 0.03471716959029436, 0.024802887479641607, 0.02998863885711346, 0.018876085955915705, 0.02329993580601045, 0.04821725482387202, 0.03438588843813964, 0.033821530507079194, 0.028895213601312468, 0.02574673986860684, 0.024574404382812123, 0.05129708116874099, 0.04045629341687475, 0.03211138816550374, 0.015540925187191792, 0.05563414469361305, 0.05392166819157345, 0.00935163239150175, 0.017328534175508788, 0.012704896474523204, 0.019486355262675455, 0.09860187263361045, 0.01523532488915537, 0.03635784690933568, 0.020076409314892123, 0.0247726434775229, 0.026261547779930488, 0.05495612196890371, 0.01537358996990536, 0.03789305953042848, 0.0852467224800161, 0.01287950643537832, 0.0624133948502796, 0.06076046997415168, 0.07687852651412998, 0.04939676581748894, 0.011586071108467877, 0.0038534016431575374, 0.01317224170946117, 0.019890210824087262, 0.02923654385709337, 0.025713383087090085, 0.057443342969885895, 0.07636440731585026, 0.04982236333723579, 0.03238460368343762, 0.03291933677558388, 0.04734314226412347, 0.0869437385616558, 0.019144946975367408, 0.022958537696727684, 0.04811602418443986, 0.02372317372022995, 0.03525089505793793, 0.07245776908738272, 0.0841279878680195, 0.06757604889571667, 0.02903393330052495, 0.004978394044363605, 0.015397659303354365, 0.03680259607998388, 0.026834168571180532, 0.0614321789305125, 0.015101534746853369, 0.018932297493198087, 0.0871772292469229, 0.02029830214035298, 0.02832014499498265, 0.009629708764675473, 0.004798382520675659, 0.08958252732242857, 0.011942908433931214, 0.0587249734838094, 0.059592188735093386, 0.021023690002039075, 0.03385859887514796, 0.05122327012941241, 0.04920057759487203, 0.03229101334831544, 0.06523868574627809, 0.05469174776226282, 0.03401694180709975, 0.044643122503267865, 0.02083948301151395, 0.024711414173777615, 0.015701537818780968, 0.04161016257213695, 0.02769894109639738, 0.027589471345501285, 0.031775465833821466, 0.017267905375255004, 0.027136028444926654, 0.02904582123405167, 0.036212117943380556, 0.04358230085511293, 0.05088634017322745, 0.03940889658406377, 0.017047001514583826, 0.030323702841997147, 0.02376194860387061, 0.049478118773549795, 0.04060109957520451, 0.040756619801478725, 0.016684752024177994, 0.06983113288879395, 0.0466748734803072, 0.049552889939929755, 0.04513938605253186, 0.022082528631602014, 0.0304406483524612, 0.06306453062487499, 0.03622699821633952, 0.03383660755519356, 0.06332835182547569, 0.03090373832466347, 0.056524925466094694, 0.02640518855436572, 0.02842349775268563, 0.05586366594902106, 0.00282049534975418, 0.049871648728315315, 0.04225866902353508, 0.002005544682365975, 0.012712399375491908, 0.02484640701940017, 0.07331373422805752, 0.03567581743534122, 0.02688826307920473, 0.0901349905346121, 0.039958516734519174, 0.02836013275996915, 0.008476402793478752, 0.007537835344140018, 0.029899696486869028, 0.037109972443431616, 0.026180922552677136, 0.025091544758262377, 0.08344714583030768, 0.01964678638614714, 0.0677935125838433, 0.03145537372412426, 0.01725169686999704, 0.05449326948395797, 0.031416222253548245, 0.03246543077485902, 0.021936105863590325, 0.019575652167467133, 0.03206519689410925, 0.003909109792272959, 0.04167819588578173, 0.031007374370736734, 0.006904605684602367, 0.053442476583378654, 0.054980019972260506, 0.09228237744952951, 0.04324042437864201, 0.0992585045418569, 0.10702028697622673, 0.07470718731305429, 0.1303706650755235, 0.126533196706857, 0.08975870215467044, 0.1146007241415126, 0.10094856563955545, 0.11483852352414813, 0.08704256718712193, 0.11216907855123281, 0.1178672324333872, 0.1486382662717785, 0.13068124412425927, 0.1681532726756164, 0.11116440567587103, 0.10130042675882578, 0.13378585396068438, 0.11104557383805513, 0.1233533780489649, 0.13530771301261016, 0.11609996083591666, 0.14689012936183385, 0.16023609893662588, 0.08869187547160046, 0.12610449828207493, 0.09194553909557206, 0.11005224606820516, 0.14962463905768736, 0.10963944571891002, 0.052326143985348086, 0.12469875014254025, 0.1344776746949979, 0.12588041887751647, 0.14030227357787745, 0.08417190265442644, 0.19087903893419675, 0.19332538837833063, 0.0781500061441745, 0.12443729702915464, 0.12795221699135645, 0.18240416369267873, 0.06195389772100108, 0.17069819968725952, 0.15302173819925102, 0.16324165623102868, 0.13952567667833396, 0.1013592489595924, 0.12161252860512052, 0.11254305991211108, 0.11473458552999155, 0.05570807786924498, 0.20091248197214945, 0.12412804790905543, 0.1583352509353842, 0.174070003043328, 0.16612408656094754, 0.15624055905001505, 0.12117424926587514, 0.10520994197577238, 0.1125229617048587, 0.12163853006703512, 0.13322066143155098, 0.2182240273271288, 0.10480603043522153, 0.1074740911966988, 0.10290783550590277, 0.10496864813779082, 0.23605701327323914, 0.09858820015298468, 0.1864970326423645, 0.12612686279628957, 0.08527261537632772, 0.07386727631092072, 0.18237308678882463, 0.1065448307033096, 0.1488543525338173, 0.1379792003759316, 0.17200200472559246, 0.11065368593803473, 0.12378579484564917, 0.09874348967735257, 0.12111084695373263, 0.10960815168384995, 0.08626894227096013, 0.1565595112208809, 0.10742873113070216, 0.12837683063532623, 0.07365024688520602, 0.13404125454170362, 0.12597495237631456, 0.10666318078126226, 0.09197941156370298, 0.19964117876120976, 0.0779010041483811, 0.0655342216736504, 0.157262012096388, 0.12809424794145993, 0.12569572164544038, 0.13180274037378176, 0.11829860428614275, 0.10037071843232427, 0.17634830650474342, 0.11756005963044507, 0.09973594892237868, 0.12367374157266957, 0.1482801626303366, 0.17036991087453707, 0.1782319468579122, 0.15375055266278131, 0.09075471692319427, 0.11295022842075143, 0.12236110200839383, 0.1230902150273323, 0.11929408301200185, 0.09790450148284435, 0.14647658940936836, 0.10427169089338609, 0.08500074675040585, 0.11932445423943655, 0.10762230360082217, 0.1312737680439438, 0.2322374310876642, 0.13170071584837778, 0.1338909997471741, 0.12387484578149659, 0.12480857782065868, 0.09403150502060141, 0.07928140900496926, 0.08118715602904558, 0.07879066533808197, 0.14017658175102302, 0.12896655899073395, 0.16990231882248605, 0.09791134790118251, 0.11577069493276732, 0.13879032113722392, 0.10173254500010184, 0.17028271912464074, 0.15978650163326943, 0.09976136684417725, 0.09863349915082965, 0.10311552150441067, 0.11233658170593636, 0.13473421521484852, 0.1723373503025089, 0.12363008462956973, 0.09945766814053059, 0.19294870644807816, 0.1394657620361873, 0.2271371547664915, 0.06461380927690438, 0.10532537435314485, 0.12903327255376748, 0.09720890809382711, 0.17256803863814899, 0.08366465701588563, 0.16284171412033693, 0.10274915330644165, 0.1545581721833774, 0.12543616843010696, 0.18266810024423258, 0.09587360545992851, 0.06247531117073127, 0.26701756194233894, 0.18038941680320672, 0.12373700817780835, 0.11589414759406022, 0.08158428221940994, 0.06269360267158065, 0.12454918745372977, 0.06765435862221889, 0.12535410640495165, 0.22017018789691584], [0.028629288942153965, 0.0340709871213351, 0.04641954753813999, 0.03233920969069004, 0.03371801659730928, 0.017374450640220727, 0.01693971495011023, 0.0934939831495285, 0.020862086709322672, 0.05352864035272172, 0.0547322698735765, 0.053015705198049545, 0.01948953589557537, 0.031027048493602445, 0.009711712266185453, 0.029209887608885765, 0.04185447928362659, 0.045692507443683486, 0.014752148584063565, 0.026137679515938674, 0.06125221108751638, 0.034010142886212895, 0.018423452208350812, 0.0419861082918942, 0.03965174765991313, 0.04126160591840744, 0.004159813638710017, 0.011632243720149356, 0.019952732737043073, 0.039707781081753116, 0.05862759013793298, 0.05425873724743724, 0.06776455949459757, 0.019155823891716342, 0.049640237752880366, 0.013397805409372916, 0.02144699576976044, 0.01978330423922411, 0.016651446132787635, 0.031010458312396492, 0.004811292921658605, 0.031700202729552984, 0.022336740080001097, 0.03668922305639301, 0.05512123328766652, 0.04209330664681537, 0.036205868635858805, 0.07507121456520897, 0.033857262161161215, 0.02163437830417284, 0.059127283681716235, 0.02819978814971234, 0.04369347881791847, 0.026765896073941673, 0.01163351088429668, 0.055117107794753144, 0.1016914936314736, 0.027157616036544954, 0.09606788360646792, 0.03641815170911806, 0.03216034107442413, 0.05026429319488151, 0.013123351565030004, 0.002458640681912324, 0.009814252478203602, 0.03203191814411964, 0.019537116467420543, 0.06198886941586222, 0.04473529809287616, 0.027119580756074617, 0.01550025210183646, 0.029143720266542265, 0.09366892983338662, 0.03353524640468614, 0.025553089366959672, 0.04092110347534929, 0.02546470339543053, 0.02746419851402087, 0.05845462477632931, 0.05356627529753106, 0.04970366042107344, 0.04645584916163768, 0.030931517548326935, 0.019934173107945492, 0.04737041597919805, 0.0543568534111338, 0.01782355091667601, 0.039285420174045224, 0.022451785692412938, 0.012281724717468023, 0.06743722741625138, 0.06283592539174215, 0.026081415392192345, 0.020119591283478906, 0.04176712468532579, 0.02706348117707031, 0.0910482918843627, 0.013295354255075966, 0.014498312026262283, 0.02854286054415362, 0.019274287624284625, 0.035909861126648526, 0.013913374976255, 0.04895878164097667, 0.052255257431949885, 0.0356444996515555, 0.03775649757257529, 0.08529540058225393, 0.0165796486461269, 0.08063194475003652, 0.0292658463918737, 0.0437649048066565, 0.09486265613564424, 0.06826444302818604, 0.03693700029647776, 0.03752871675949011, 0.05390679809663977, 0.03249031265399285, 0.04216972326061555, 0.04929406614974141, 0.0601750910282135, 0.01815530365066869, 0.023107130080461502, 0.040852853030498536, 0.056723749797259054, 0.13764378694551332, 0.018806731195322106, 0.023863374322120632, 0.020953565104199306, 0.05964052078447171, 0.04435672644259674, 0.04810993433264749, 0.06274021124201161, 0.03548437217250466, 0.028727629022406678, 0.08312628019068923, 0.03767186389969928, 0.05132150164406214, 0.02493819754038538, 0.064036864521248, 0.02557384066416749, 0.03591912312965308, 0.03265763599691646, 0.04048354338322367, 0.010320219078234263, 0.02396932247626994, 0.02112231676333717, 0.006668796529993415, 0.02652434608899057, 0.01721284395482923, 0.03389494799609695, 0.001535067690253657, 0.019704192145062343, 0.07306209273104157, 0.047546909722898684, 0.006343766805782382, 0.02504333314884986, 0.04603658237361482, 0.029486967383750846, 0.05590152141771146, 0.07844826299697161, 0.04957952243941171, 0.02994089374052627, 0.04485663711758597, 0.00627516267455316, 0.06176066451839038, 0.010743643589583891, 0.07579348795115948, 0.029475666383015256, 0.026571327853681784, 0.07188177428075246, 0.04203024699485727, 0.024781478003465703, 0.051712626192186556, 0.05591855264667954, 0.02392976897369538, 0.01742860282372151, 0.04039018375000783, 0.012518405365491552, 0.03729781468531915, 0.040506576254431687, 0.034989238384046724, 0.00834828011492001, 0.022454815351271203, 0.02557571342081896, 0.06343033563877855, 0.05184921868411558, 0.010206889311250831, 0.08939730083303792, 0.033894221963627, 0.043634429307920594, 0.023060394284714545, 0.04915773828646966, 0.05441626933004175, 0.039040146728179285, 0.05891168596489089, 0.05696396476456097, 0.015127225778996944, 0.01929509998964412, 0.014512680005282164, 0.029045302154762403, 0.0563441433810762, 0.056660018395632505, 0.06718177933778081, 0.02620648805584226, 0.014466683812705534, 0.02405622924145843, 0.020795861691502587, 0.04542097808527095, 0.021413491406877126, 0.05332687796492662, 0.038493844613965066, 0.03287808184645005, 0.03415893204510212, 0.042540613894483874, 0.04772275207298143, 0.01986143585028393, 0.03380654166851725, 0.03516186447814107, 0.0408440354679312, 0.043459455482661724, 0.01650195469015411, 0.035300119380865774, 0.013206671424476164, 0.005397988649617348, 0.04066896325509463, 0.012422485958917864, 0.02001147690628256, 0.05478880541133029, 0.009328652106757675, 0.04739274995933686, 0.013380818285181053, 0.006724444035041545, 0.03992340933265431, 0.030556084122508764, 0.002913386793807149, 0.03288511825459344, 0.03983125409909657, 0.009799304351742779, 0.007499917959129172, 0.053569505124219825, 0.04307444453505533, 0.050187937649233, 0.043155943376145194, 0.047163500117936304, 0.004383650891083691, 0.04513044296098607, 0.0430334406638784, 0.0521602659220142, 0.036164301580616405, 0.07287666946649551, 0.021289830096065998, 0.011917474396925951, 0.03303488450390952, 0.07231062876858882, 0.026477042020165494, 0.049445752653160265, 0.05195463927728789, 0.036118602247110436, 0.01558291632682085, 0.047811070191008706, 0.013476298340330166, 0.03696598391979933, 0.02125905853297029, 0.02204157056153885, 0.03601211974663394, 0.04498477167050753, 0.050203221650528054, 0.020516247588342855, 0.018723619137225405, 0.11305771515305553, 0.06105843505689076, 0.06968819270176546, 0.010317747514428837, 0.014844042581639119, 0.02443420547725899, 0.017074689136019776, 0.03296278337282794, 0.08243712609899895, 0.0008826281742325851, 0.06343912945262023, 0.057261617721191475, 0.0706312885241849, 0.07120197718696934, 0.0474725015727537, 0.022359929014263407, 0.027493148210591505, 0.038063273432531526, 0.03089701064995357, 0.02958791982382536, 0.11583303873028074, 0.03191989540521588, 0.07586320063897542, 0.024971009797549674, 0.04322106916723507, 0.09986135576452528, 0.04808132729626127, 0.036142191517033746, 0.03466874593868852, 0.04153775270762188, 0.006604227561703218, 0.0923914248123765, 0.01742107278135206, 0.02354037299353097, 0.013978336222602852, 0.02739195997959801, 0.0412570563411074, 0.006776638220929141, 0.06816914957016706, 0.006168156005774758, 0.022681517293676734, 0.015116515103727579, 0.04803620811019625, 0.011411486592675959, 0.027798025868833065, 0.04686225771105715, 0.03335542105404394, 0.027975167613476515, 0.033967975327478986, 0.02150375522407038, 0.05577362774472151, 0.05299567145162395, 0.06731737777590752, 0.01224530435034207, 0.037085406083081446, 0.07355905177869967, 0.03109911909060819, 0.023580591460423808, 0.016585760550307374, 0.044725567900708744, 0.008788475467424308, 0.04260226897895336, 0.040722475919340334, 0.014379464921408465, 0.020103749187131013, 0.019864896378879036, 0.10273641041879143, 0.025598478270694613, 0.04175614598872406, 0.09132376353123359, 0.05770099628716707, 0.06401118197079216, 0.02043405155252133, 0.039224620043699227, 0.02546526488315846, 0.019047850310536366, 0.04473187488370708, 0.022202003381348083, 0.02108503126406244, 0.011863111019400614, 0.022832109659378017, 0.03005652628572924, 0.07305728191775934, 0.07255302183330059, 0.15147987593497547, 0.17994238436222076, 0.13829490914940834, 0.10546078280146633, 0.10087565705180168, 0.23536154202052526, 0.11332021321036986, 0.09606480984283344, 0.1674091640327658, 0.15183377265930176, 0.16465162485837936, 0.12209994745041643, 0.10281924597386803, 0.13972287252545357, 0.14496849104762077, 0.13303325005940028, 0.06089531523840768, 0.11316946987062693, 0.20558005651193006, 0.1243143193423748, 0.15827583840915135, 0.10603307959224496, 0.10923194472811051, 0.1837936541331666, 0.09690985056970801, 0.1586745320154088, 0.19964571137513432, 0.09403147787920066, 0.24684569292834826, 0.13332013466528483, 0.17560392644788536, 0.07943508361599275, 0.15385641769639083, 0.0919536543743951, 0.08982821806733098, 0.17604451280619415, 0.15621206057923182, 0.162422990160329, 0.10049533817384924, 0.07426460606179067, 0.1191888829427106, 0.1392017033483301, 0.1067954476124474, 0.1483104931456702, 0.08236839050160986, 0.1737750574414219, 0.07907837097133909, 0.11071675576801811, 0.12623274140059948, 0.14649590051599912, 0.15703348150210722, 0.08205920244966235, 0.19853785367948668, 0.08964982442557812, 0.18450154257672174, 0.15296269208192825, 0.2869815821094172, 0.18375176138111524, 0.1576897470014436, 0.0791904174589685, 0.08150230840380703, 0.09503750782459974, 0.2595313936471939, 0.11789849932704653, 0.12590338050254754, 0.13857846893370152, 0.09745303142283644, 0.09780689422041178, 0.1551956965454987, 0.10760266679738249, 0.16517295688390732, 0.20568368237997803, 0.22104781866073608, 0.157912333628961, 0.1667344288102218, 0.15630592911371163, 0.13025976531207561, 0.18708366687808717, 0.17913358419069222, 0.08740613303546395, 0.09549437223800591, 0.13602326890187605, 0.12138686142861843, 0.14789859524794988, 0.07130703476390668, 0.11647261226815836, 0.07210936171135732, 0.17905575622405323, 0.1295703330210277, 0.13621750633631433, 0.10984544216522149, 0.11621094202356679, 0.18581524065562657, 0.131149080448917, 0.1633701707635607, 0.10796415632856743, 0.08628231619617768, 0.08665215170809201, 0.15371205258582318, 0.09349490595715386, 0.21259811706840992, 0.0982193553021976, 0.074136322231165, 0.11870861585651125, 0.13217905589512416, 0.18709958530962467, 0.09128471384091036, 0.20192743465304375, 0.08105630733604942, 0.08663123925881726, 0.11859915458730289, 0.1594657717006547, 0.12588115169533662, 0.08923496811517648, 0.12712794622140272, 0.13194994176072733, 0.112671716936997, 0.18437316375119345, 0.07581887194620711, 0.08698149225009338, 0.07426496568535056, 0.11363021550433976, 0.11765760582472597, 0.2937829728637423, 0.13185535397912773, 0.09665907081216574, 0.1421449032745191, 0.1564540397375822, 0.11802358047238418, 0.09832698452685561, 0.1584564372897148, 0.12083361111581326, 0.11021389346569777, 0.1689750464367015, 0.2351517118513584, 0.10453351041568176, 0.13300947419234685, 0.1655143957052912, 0.14811975695192814, 0.05583028541877866, 0.1485278686242444, 0.10539689872946058, 0.164181400090456, 0.11959951876529626, 0.14726489782333374, 0.09335912431457213, 0.1287811289408377, 0.12589483096131257, 0.062245878124875684, 0.1475395280867815, 0.10134229236947638, 0.10645255672612361, 0.08139634837529489, 0.11869087895112378, 0.13910455070436, 0.14861702812569483, 0.10469793980675084, 0.15420872664877347, 0.15561680894877228, 0.1590935681015253, 0.13134498707950115, 0.17481708366956028, 0.14217786650572503, 0.16979329181568964, 0.09583809772240263, 0.2169292468045439, 0.24574215071541922, 0.10085661057382822, 0.14634888911885874, 0.13869806751608849, 0.15744091463940485, 0.11677092340375696, 0.14831498504749366, 0.0722994872235826], [0.012773246155120432, 0.004088298592250794, 0.0012321452730767696, 0.011723065632395446, 0.0659050207052912, 0.026832419647169963, 0.003250077142313655, 0.0429089396659817, 0.031073952226766517, 0.012724443372072918, 0.055680471672011275, 0.024871219348694597, 0.009254897894736911, 0.021355332474091222, 0.03646005803186979, 0.07966066258294241, 0.023467311735398004, 0.009844197076745331, 0.006374561693519354, 0.021156565818403448, 0.043738428370228837, 0.0498313980310091, 0.08821469571973596, 0.023969327565282583, 0.0597615171489971, 0.024991742435044477, 0.030278495446379696, 0.004736390713203166, 0.09246624008353267, 0.06785951368510723, 0.025583842270342366, 0.025500239970694696, 0.047187296341040304, 0.014120462167608951, 0.056858673093042204, 0.03640168705689056, 0.08676698697464806, 0.005837770095760269, 0.035293072794697115, 0.04221789924693959, 0.017972394358366728, 0.026026318348678093, 0.04788204495395933, 0.012523050785862973, 0.021364004151629548, 0.023029644774006944, 0.03439136082306504, 0.028167196416429112, 0.03263505095882075, 0.0714273661641138, 0.057636664382049015, 0.022316685977524946, 0.059074120463005135, 0.031203216540494134, 0.04084365548832076, 0.04162615903520158, 0.01420027993819011, 0.026357499416917562, 0.05059476010501385, 0.04691112580310021, 0.03142584727278777, 0.04096084866406662, 0.026151413064716116, 0.03180611526061382, 0.039822982757219245, 0.0479017360402005, 0.0636050176939794, 0.023444358592054675, 0.02215434138530067, 0.005921566626057029, 0.05276634697137134, 0.019620398159271905, 0.012401179959332305, 0.02864555681922606, 0.03182227457208293, 0.04002209546576653, 0.03228856383689812, 0.026637931154774766, 0.007468735882347184, 0.011320295727013477, 0.021817319826888185, 0.024068251185651337, 0.024293618110407676, 0.027341258146667054, 0.02548654204500573, 0.033019780314394405, 0.048162802388625484, 0.002408516876000379, 0.010528544595997249, 0.059512250524546416, 0.014790211005934646, 0.037001111677714756, 0.040822790536497316, 0.019596013307039226, 0.055363880803010294, 0.07395539765379258, 0.018215991822736602, 0.06426717966262784, 0.05070720353562917, 0.019170278383951102, 0.040529113795076094, 0.03102983727252909, 0.06817326827773026, 0.03438235666336758, 0.02244807410586093, 0.06900783242391688, 0.040525415779224465, 0.07579310118619885, 0.008433792490645178, 0.017213239201477597, 0.045090551887239726, 0.04247963395235794, 0.04610582008691771, 0.07005187390106064, 0.012234653046886836, 0.027700450836813877, 0.021968863837953125, 0.04958599227081452, 0.015417799919045396, 0.05786300330821957, 0.0050920431468901885, 0.03822967057515468, 0.03401142192472305, 0.02764572189854724, 0.04441824921273759, 0.03510073525831103, 0.01927491357283933, 0.049884150736033916, 0.030240151432475874, 0.01808836786741657, 0.04622261971235275, 0.021581949599619423, 0.012596353772096336, 0.03638326143845916, 0.017833866345297014, 0.028465856997562305, 0.035390103302363835, 0.053347261156886816, 0.041739406529814005, 0.035271203611046076, 0.047959961130150726, 0.05092027031683496, 0.020855123243693794, 0.04345241568184324, 0.022789270350975648, 0.016263558196702173, 0.02282677298145635, 0.08642218940492187, 0.0570265528346811, 0.03237296002251761, 0.08283176206584487, 0.02496819557355983, 0.02833650617061981, 0.015476201428100467, 0.02991332147004349, 0.013113019173033535, 0.01153275861205267, 0.04384556904967342, 0.02959328025047268, 0.03933481413072773, 0.05384818624172892, 0.03469645730885012, 0.01637039183905082, 0.019292626729501144, 0.03336178231984377, 0.04525853340913143, 0.007918244127982428, 0.028865826249654804, 0.05693803794149842, 0.011860186533470238, 0.05555530570979629, 0.02183817799336144, 0.01433515319201563, 0.024735841434448957, 0.03931431558781436, 0.02793270828468459, 0.07718002676431622, 0.032553212850221565, 0.0417457338688629, 0.016696251496406536, 0.008236723020672798, 0.01689274505978184, 0.044212100096046925, 0.02413834724575281, 0.029870977492204735, 0.020614664003785168, 0.03432166849129966, 0.05253085121512413, 0.0317221329813557, 0.036309324870152135, 0.051440543827733824, 0.055994307688836537, 0.014912028397832598, 0.05134503663118396, 0.028258954707000936, 0.02779032110369631, 0.028582999283181768, 0.05179380612181766, 0.05170673650822469, 0.04243535614971604, 0.0681955377970423, 0.045631069490419965, 0.0582494018599391, 0.028397850825318267, 0.04053322232461401, 0.05624022913564529, 0.004994745466059872, 0.042996049991675785, 0.048184376409543414, 0.03390050519789968, 0.0465949522331357, 0.027674052431913357, 0.03401555759566171, 0.020667026551174264, 0.08622436930558511, 0.03718118808631386, 0.010943763074465096, 0.02561289713984089, 0.05814855798546757, 0.005151448039604085, 0.024229484676782573, 0.009756291168741882, 0.0180636267842991, 0.02936046470754913, 0.03567157659147467, 0.0221911247686616, 0.059059525174754005, 0.013083466428465076, 0.018865388851346712, 0.031153602059930563, 0.045173726709825654, 0.06605697862271752, 0.028877066182238714, 0.026535667445776717, 0.08531893217670065, 0.05060787618692432, 0.017661145256300057, 0.05633582454174757, 0.014537137800029345, 0.030136325396597385, 0.03667307731562427, 0.047829176897981336, 0.037703453097492456, 0.030396092350461652, 0.05022977272580777, 0.06979292458189384, 0.01926492553736482, 0.00971927453896829, 0.009190790754343783, 0.017096839911703552, 0.03859822365588375, 0.06079728049891336, 0.03282253018447331, 0.04857252218893596, 0.022889004820691686, 0.03772989221449409, 0.07124053833207913, 0.022011896528835808, 0.048314319258289676, 0.023107981641909907, 0.04574811338846173, 0.028982737833367925, 0.023837834264018705, 0.0054248213169298, 0.0023758140326078448, 0.04722036813784923, 0.03057175488876445, 0.01620428985916078, 0.01690903159656695, 0.02189029796448137, 0.049597211847347875, 0.05091252483959709, 0.05402938901845898, 0.06957718437271458, 0.01460255536117724, 0.04077707084694079, 0.021155870320009332, 0.030818480399570296, 0.009902286459691823, 0.007279118423217109, 0.07717518880963326, 0.058366557716258934, 0.08308345106031213, 0.007285314296106142, 0.031031177379190922, 0.014701351756229997, 0.014220478229357727, 0.051010885275900364, 0.0368435015635831, 0.021921865109886442, 0.026401845073061328, 0.02005374794160681, 0.03955144661345652, 0.057464784676475186, 0.01545974865023579, 0.06774805752294404, 0.03645366283931902, 0.057301915915949006, 0.028790057636797428, 0.09121787814157349, 0.031429507969213386, 0.05475467849256737, 0.022361852661041275, 0.0491741859753217, 0.06101382816476481, 0.0036856143519149293, 0.04654871007161481, 0.007927892047778835, 0.025871748071429983, 0.022644235187077096, 0.04739703490797963, 0.035260560789278576, 0.01612678080398057, 0.07338958765779223, 0.03945840249902435, 0.023070148225607615, 0.05983017132218395, 0.06903860398701259, 0.08532102206455809, 0.06587512445236955, 0.02947299295504178, 0.04125423024275473, 0.021639837118397866, 0.013689885048993995, 0.03381687236417617, 0.0689982854362045, 0.05963614423360143, 0.03212589863687754, 0.03160435965816889, 0.03198468532147152, 0.04186580064041274, 0.04346277012622782, 0.0347492303699255, 0.05344031544934426, 0.02123141840898565, 0.0638570866680571, 0.01495355474097388, 0.03677754456709538, 0.03593170656157391, 0.0775536959990859, 0.04001850601551788, 0.05013365484774113, 0.014995396602898836, 0.052419137209653854, 0.024146052010889565, 0.029058007722986594, 0.03657052692558084, 0.02535889434096004, 0.017115279100835323, 0.0478493734928114, 0.003615572998699333, 0.029070014400141578, 0.3005720685635294, 0.12024186072604996, 0.15548992290028504, 0.08297002714659486, 0.1338198214237179, 0.09154716440077339, 0.12102342450192996, 0.11763840328369822, 0.07930501523826804, 0.07376023062637874, 0.15815554772104534, 0.12048502053533282, 0.13054648706955568, 0.09501745711479868, 0.12942151672073773, 0.10476725894425597, 0.14536475549851144, 0.0983454610354134, 0.1369614385600601, 0.05786252833370652, 0.09349643944629601, 0.12573640660515853, 0.240797258913517, 0.07968063865389143, 0.1443512820239578, 0.13984120903270586, 0.18106548195438726, 0.10509485565125942, 0.1576237255441291, 0.15780432442469255, 0.07854796014726162, 0.1184724856700216, 0.16465588605829648, 0.08670881616749934, 0.14125518101666654, 0.11631835411701884, 0.15778364267732414, 0.05655116102259074, 0.1771884821355343, 0.15956980468971388, 0.08327931697879519, 0.08669731499893324, 0.11462403860475336, 0.0725592914968729, 0.113121443162007, 0.11221793985792569, 0.15987741175506795, 0.09268846708749022, 0.08411987937454667, 0.17877626764987195, 0.1331194918602705, 0.07291828401918922, 0.12353989375489098, 0.11544932717723505, 0.11527236524437155, 0.08982285764068365, 0.1080201490383063, 0.08698039980871336, 0.13450235979897635, 0.13863429879503592, 0.0700116367744548, 0.16248256553496632, 0.19993782070066246, 0.12188662961125374, 0.19367665238678455, 0.2263504612658705, 0.14942810817488603, 0.1429034240011658, 0.13894322221832617, 0.14815364299075945, 0.1173604889107602, 0.09710916344608579, 0.10665625293872186, 0.1388398270521845, 0.14020358744476522, 0.20891325122543744, 0.19215946165578707, 0.12939795798489026, 0.08315549790859222, 0.13035969994962215, 0.09024311508983374, 0.07651846190648419, 0.12896627400602612, 0.0919487824929612, 0.12529474816152028, 0.07612679113766976, 0.21028068927781923, 0.10375898983329535, 0.09835726754473788, 0.19906255123870714, 0.09149325479354177, 0.1015637797702636, 0.06197116643722568, 0.17137357273272105, 0.1470464909715312, 0.29768259504011696, 0.10964586466018643, 0.15841800506625855, 0.17016454546579293, 0.14053722311343464, 0.2052085178771189, 0.16913949618382113, 0.11619087095771517, 0.11438847838767938, 0.11764250163521085, 0.1517397684178182, 0.14820442455155508, 0.1469129824212619, 0.08508571969079119, 0.10317325804914747, 0.17183063392128262, 0.13912201619574002, 0.1304002899144377, 0.14065353758633137, 0.11638662831059524, 0.12421891731875283, 0.0704790795488017, 0.1089897280825036, 0.1356984813298498, 0.16425047495535441, 0.07872764300554991, 0.14589036229465688, 0.1642365785581725, 0.17735667739595684, 0.15370334019618376, 0.1367462615349463, 0.13734896347991057, 0.1167788351220744, 0.11554456635245255, 0.08032239028917891, 0.12449798520122256, 0.14362035053116934, 0.11542494062866483, 0.08886230311223439, 0.05593021327097501, 0.09024320329938616, 0.10694613666938883, 0.11954486955489431, 0.14693692113671983, 0.10622518642672471, 0.11442836267607552, 0.1620865182152816, 0.11923177992658955, 0.12698731305343763, 0.14743211599332945, 0.21189571118780545, 0.13887329239930424, 0.16662346119327204, 0.1619976165571383, 0.08425509783306293, 0.15192670481545584, 0.13644466628985746, 0.09835532014923436, 0.12651387202952588, 0.13067783787846565, 0.06435355038515159, 0.1377161323492016, 0.13114461568849428, 0.13077873603573867, 0.15443515378449643, 0.09205568568514925, 0.23987114003726415, 0.15565978735685349, 0.11304117246930089, 0.07592985991920743, 0.17436166453574384, 0.15345918972577366, 0.22130104792969568, 0.14403498971036502, 0.10773703708712544, 0.23253101961953299, 0.08586214017122984, 0.12269513122737408, 0.1069360604243619, 0.15403523881520542, 0.13362547542367662], [0.03622333751991391, 0.04699045672480549, 0.025614724095378603, 0.02536889594713492, 0.05213853244536689, 0.023101018176281025, 0.02428845445891576, 0.04956247763974326, 0.04674784652888775, 0.08092940771686179, 0.02251618036202022, 0.028944638092070818, 0.029548656394971267, 0.022327123542449305, 0.017065807112625668, 0.02452668810396322, 0.02195818878577224, 0.05811456338103328, 0.022375916995640312, 0.02948856194104467, 0.047742226028016636, 0.042977926321327686, 0.04207042644598654, 0.005887949456726866, 0.0378076014375048, 0.016794776477451836, 0.05633376518796597, 0.015298016435865845, 0.02468425750599376, 0.02816596657170781, 0.016611629697893347, 0.05205129998336945, 0.057243955454656055, 0.05835962987371853, 0.0386162217972534, 0.05052933236584067, 0.11085400983159031, 0.07282079889306001, 0.04723783362922924, 0.037935420471642695, 0.02558422733896545, 0.024273139923544865, 0.03610515368304082, 0.043052585529429574, 0.02795130353687065, 0.007705732897323157, 0.024418884156537906, 0.04412397875317505, 0.037821250169404914, 0.014250556838565638, 0.008365904213860631, 0.03249844828886645, 0.05895935983530112, 0.029009692636983733, 0.039948450667517524, 0.03358303223337446, 0.048351635291640244, 0.04198404215276241, 0.027772207611373494, 0.04670382996222802, 0.03477172380579369, 0.026953835007069365, 0.028127558096977215, 0.03247003124228545, 0.053514974657446146, 0.02056040664735649, 0.0628086957814438, 0.013926257811752813, 0.04530527090121593, 0.07160396847341742, 0.036688805757356543, 0.04353909853047558, 0.04778991346912725, 0.03166951598333461, 0.030029452738485167, 0.05876599771103688, 0.02507241515974913, 0.0417013067885169, 0.018294818932190537, 0.13570556523544447, 0.027726621932483146, 0.029342680304710354, 0.04153485536309225, 0.02388972183689475, 0.10807855054736137, 0.03199675306677818, 0.06624135694333486, 0.015400025694231902, 0.04149518481322697, 0.056218797607081275, 0.02510437076645238, 0.005457110678045345, 0.004103217456888939, 0.03282806024487529, 0.023131596356896416, 0.04991165854568992, 0.028722054857228483, 0.017306469913039888, 0.04933111755443471, 0.05325039349762457, 0.06048446228461606, 0.03364281116851738, 0.06539478272731815, 0.03265845702428903, 0.024762760614976287, 0.055759378509329896, 0.0225583360463913, 0.04164219281769224, 0.034237981374774656, 0.02261950258564736, 0.046867903122412305, 0.04663720800142203, 0.04719138112185257, 0.011251729763379055, 0.04607890938807811, 0.04862077281411205, 0.05973501357116869, 0.050142872745969465, 0.042918842884578874, 0.005706740318731005, 0.028324200938056623, 0.02236796965423439, 0.016478572373411486, 0.023290975751089196, 0.020564554192657982, 0.03998958346034799, 0.02060914072873337, 0.02956861210986972, 0.03225741568686707, 0.04827992431819439, 0.03313445612522108, 0.07077152135648898, 0.056610573548823595, 0.019664421511281813, 0.00859733554534614, 0.024805526980864148, 0.03906395991465875, 0.01772618114149996, 0.02363941026851535, 0.016944958329466835, 0.024401734183941568, 0.062180270573922565, 0.03358048094170434, 0.01716399791517428, 0.010816911800897546, 0.021371720791129128, 0.008514522890826421, 0.04215715000672, 0.04481442206140075, 0.013470516373802508, 0.01632375273454402, 0.043042502499052455, 0.09904789405741862, 0.022775088969085897, 0.07031754750226225, 0.01825854614643114, 0.02112402836792171, 0.03174076894564288, 0.04061533184722066, 0.036505842182253084, 0.02791482549426811, 0.03521257479275976, 0.03977801624153342, 0.07008149195462465, 0.0263950325814741, 0.038442099533442936, 0.011631763656623662, 0.07903470045753888, 0.026663235421957712, 0.022043097265330807, 0.03023164938869221, 0.022805339756554792, 0.03313928050920367, 0.022933365743873373, 0.014993298233353665, 0.028185654265273894, 0.03153401593278561, 0.01223122644504266, 0.026947646767699292, 0.02143901789427868, 0.0711899535464389, 0.012018614282299365, 0.015323834693325418, 0.04991926831592407, 0.012230650538445582, 0.039953994298619885, 0.04959519999101758, 0.07374399328338248, 0.017507680991132344, 0.025807981046714952, 0.004802762888305421, 0.05604539459039058, 0.07892023838524308, 0.003276194167223626, 0.015318886476701923, 0.017956764304212162, 0.028177179362890974, 0.08613268565386534, 0.03660556647394385, 0.015136587865916746, 0.06372644832091671, 0.03114667082471507, 0.05114316228511078, 0.04866408709702747, 0.04367090056517294, 0.03409183510978307, 0.06145507948739188, 0.05111240429271545, 0.0717604590047683, 0.04767890174740127, 0.02012714507457401, 0.03205106979502099, 0.045274767359452586, 0.006352424912620336, 0.015626844683928148, 0.0327433655038476, 0.049067377778036256, 0.0177595226559788, 0.04971692917336311, 0.054671266182724915, 0.0768141063994595, 0.06672104048941817, 0.006581835057919047, 0.023546834343246052, 0.044395528467638154, 0.010166247608140111, 0.013878778171991664, 0.00940997283240514, 0.06213990452566317, 0.024742033066494123, 0.04287346585520676, 0.02334720085907195, 0.05167170035253678, 0.06569818287555661, 0.04027863937829222, 0.04917759222111531, 0.0012648163101403043, 0.050176059893731556, 0.015378380427137017, 0.01930453671541597, 0.020081785008577362, 0.0441680869220623, 0.037339062829102786, 0.05011057787175689, 0.036184359075767655, 0.02855545754677483, 0.052855479331421, 0.052301601373723576, 0.07135365690503802, 0.006939943788373577, 0.016828377531575303, 0.027863857336342335, 0.04936194000765681, 0.009346137106019472, 0.033861306229872365, 0.10966763206358467, 0.07440612132527999, 0.012498257964450334, 0.05271397763863206, 0.028940261541200534, 0.0701792620654617, 0.015061725097309266, 0.023053915971623998, 0.028357233719101975, 0.031759204742099555, 0.028865008614957333, 0.03781893297231623, 0.014152381303054946, 0.014568129887006112, 0.034915739470826726, 0.07082769727068287, 0.03185139390240822, 0.014853620103427341, 0.053352051614118476, 0.020551283744030764, 0.03758860086756093, 0.028025901676820855, 0.03417351036997778, 0.05288115170385156, 0.0185101079155824, 0.056162977923772166, 0.014005909341254404, 0.030242288817784617, 0.015165113478100725, 0.05293220807132976, 0.006646631759524877, 0.0159519596491009, 0.13498477105583462, 0.007298498231518481, 0.0204426010937563, 0.0244504411239177, 0.028443884337320924, 0.0125066455054496, 0.05597990578306573, 0.05223229580691882, 0.07024925295263529, 0.035428661054798534, 0.050350677488105636, 0.059508525367294035, 0.04518249677494168, 0.02877392546672906, 0.08088076354137488, 0.024522535469649092, 0.023052818441231335, 0.07531309872865677, 0.08454165674213852, 0.016155934061056802, 0.04871541827118822, 0.033371743213917525, 0.02804543330733265, 0.047559883312455246, 0.06751713170004742, 0.05933629960886069, 0.06014670112303325, 0.03542567889339157, 0.03669596090912819, 0.017768676093380367, 0.024803628779149482, 0.044424372991280894, 0.07080149903361287, 0.03576417626546962, 0.0443506739102304, 0.07668162922241858, 0.012744078479175056, 0.024840164497228603, 0.024946843772860508, 0.025577321548813155, 0.011198630157325948, 0.08880940452218056, 0.027184284159115384, 0.04393871494435838, 0.043156581199062724, 0.01572597356114004, 0.050590020537908585, 0.028661322580384355, 0.021901261394045184, 0.06254716124385595, 0.031748039448367696, 0.060855661651917865, 0.043198182181056054, 0.028493439446070364, 0.019593770748802593, 0.01928874890186957, 0.07181729988328048, 0.025080006270270263, 0.009905620611139705, 0.03229027035247002, 0.014770396087052566, 0.018676016512992125, 0.05280261127544301, 0.0389483171914305, 0.04165259475952812, 0.1402706267046077, 0.09400639243956123, 0.09557906697903361, 0.11680607151772295, 0.12378776259720325, 0.1133876663765737, 0.10477772195424352, 0.22914599840130123, 0.16365314700773784, 0.1392842810600996, 0.15986304038337298, 0.1891157706933362, 0.1059476656040975, 0.11422675635133471, 0.06212492247245141, 0.14250620960124902, 0.17537447304597922, 0.16906301171651908, 0.07739774151039974, 0.11336410764072623, 0.1296267599931785, 0.14906301562275204, 0.17074702706720146, 0.11946588807872363, 0.150834412713136, 0.13038544356822968, 0.16746289043554238, 0.1347537434526852, 0.11757679230400495, 0.1237687636166811, 0.11474949972970144, 0.14983854043696607, 0.16962284381900514, 0.1151674637304885, 0.09010810697717325, 0.11639295225696904, 0.2535617511187281, 0.16158368305436202, 0.10289402731827327, 0.1392291568751846, 0.14844294318131038, 0.11267650739422866, 0.17147068466459, 0.1722617886428322, 0.1002674318317856, 0.13525433944804327, 0.15179205632635526, 0.11078483997178928, 0.12118307022111756, 0.09227668454072305, 0.04091596017990794, 0.11670142784714699, 0.1516387209828411, 0.10311567078211478, 0.12064463911311966, 0.14421987693224633, 0.18558357522955962, 0.1430025715380907, 0.12020999672157423, 0.12759551113205297, 0.07967877268259015, 0.12496435589023999, 0.09877515690667288, 0.1584365697843688, 0.11120397783815861, 0.08597351490919079, 0.1376461482473782, 0.10021303367934056, 0.12804411777428218, 0.16309266351163387, 0.14361135315682205, 0.1788157041051558, 0.16206304090363638, 0.10010508554322378, 0.10331165883690119, 0.16096997527139528, 0.1553465484508446, 0.07364718669227191, 0.10142024247241871, 0.31902119144797325, 0.09150829791490521, 0.09493823815137148, 0.10757657712591545, 0.07625869155994483, 0.2192556583987815, 0.11166458097951752, 0.25824787680591854, 0.08207636938563415, 0.11204534769058228, 0.14575256540306977, 0.11257775340761457, 0.08732344675809145, 0.1653317612196718, 0.12331063034279005, 0.14981570094823837, 0.17985017145318644, 0.10398484699960266, 0.2030331753194332, 0.10669778606721333, 0.13733787621770585, 0.16926654508071287, 0.148204275273851, 0.16108855605125427, 0.0844257426049028, 0.09029063289718968, 0.15154227401529038, 0.2608310053391116, 0.21705105741109165, 0.1489002350717783, 0.11094423463301999, 0.16423207308564866, 0.1368714648165873, 0.09686871099152736, 0.1552715567605836, 0.11503905776355948, 0.10534600860306195, 0.14194269983896188, 0.19998302470360482, 0.11395264177450112, 0.20338579639792442, 0.1443919941250767, 0.20593746804765292, 0.11909566580184869, 0.1621104705014399, 0.08522475151611225, 0.14831894769200257, 0.16273958102932998, 0.07269651841904436, 0.18920962565711566, 0.16630518755742482, 0.10662369682852711, 0.15334823567952427, 0.11992611124047212, 0.23152116952197893, 0.12194597428398472, 0.17167216885302747, 0.12398947748754706, 0.11636863356190068, 0.14421180236552442, 0.10651713968919856, 0.06293644356940474, 0.10283501512770142, 0.09951422403433494, 0.1901203960712467, 0.0588215154462627, 0.13763687945902348, 0.11486364289053849, 0.08631747109549386, 0.1931030595941203, 0.12275269813835621, 0.06080690212547779, 0.10850931850395032, 0.20132591335901193, 0.17539406913731778, 0.1436345183423587, 0.11945473296301705, 0.10207628405519895, 0.13231284943010124, 0.11164281357611928, 0.11350558219211442, 0.10296101229531424, 0.07953036350331136, 0.11756168811448983, 0.09487766533025674, 0.07592838071286678, 0.11802767882389681, 0.12328247113951615, 0.10091003163584641, 0.1656356906252248, 0.1058958594554237, 0.14271798038056918, 0.1377647833100387, 0.11930574024362223, 0.13147716570113385, 0.10909545740910939, 0.08110012712755374], [0.02004673528218908, 0.0894352648673313, 0.04456691962799855, 0.02770708012394607, 0.04766967027847256, 0.04695181076281837, 0.01974535038295601, 0.016657802309574823, 0.04832853117425527, 0.012663420173339546, 0.031017735600471497, 0.03779264652569379, 0.06616802766386952, 0.016397940360807946, 0.08666778515492167, 0.008019638463987835, 0.0314247819728085, 0.024197600316256285, 0.020020518385406052, 0.0119297872630081, 0.03671122116169759, 0.05570655455812812, 0.025050230457314422, 0.050088898677911074, 0.06122168379702738, 0.008025494221198772, 0.02666697584624801, 0.018603652449590818, 0.010404205598336245, 0.004446672375446984, 0.03963455018986549, 0.0234547113401017, 0.04789675559316363, 0.0644028934517077, 0.01600463262626103, 0.012038868552606021, 0.012678705022803374, 0.04006946399541838, 0.030505635043872253, 0.017027914324509244, 0.06878957484981843, 0.03338000098509448, 0.0673760235575693, 0.05437501100823283, 0.03911421221813985, 0.02773282883156623, 0.03583666076883674, 0.015633965908948864, 0.04013568222788828, 0.02588501512738211, 0.01040808342596782, 0.05517424722867353, 0.027835862677810446, 0.040857042984238694, 0.02397751239394503, 0.0263152606120067, 0.0375943378811436, 0.04942504037171602, 0.037366455287805626, 0.02690870564297906, 0.05495243413107736, 0.05829320129539285, 0.03988699235820344, 0.0429289734124073, 0.014740533760881849, 0.037178402700062306, 0.03196924525712218, 0.0829286432958075, 0.04160752307091441, 0.0483730464641537, 0.015462155753214444, 0.03374582974772368, 0.04836522974073887, 0.04108592302405408, 0.019189535207780342, 0.05129578855953046, 0.04978035184155617, 0.03571218351966568, 0.03257310071161815, 0.032198461171771796, 0.00905140778715057, 0.02882917518062251, 0.07803439734769718, 0.014827662746288946, 0.03081593250057527, 0.016165481048769186, 0.0573889176760401, 0.0179986892866769, 0.07108310463705234, 0.010877984193419772, 0.07189928048423358, 0.030075759360832826, 0.010344832087866962, 0.008569675065310938, 0.013961282941246671, 0.06181764110390629, 0.010191092167847922, 0.03599193332982915, 0.05677067388647369, 0.02784935704299382, 0.03676372280876551, 0.032072056883147786, 0.022270369177152003, 0.010919692892847317, 0.06199155641453607, 0.035775596009833474, 0.01921961466515703, 0.011993309166947646, 0.00679951163640778, 0.029186698674623455, 0.025468296238354275, 0.03913535876199603, 0.03013158243681703, 0.023312283447012305, 0.02732683079583304, 0.025298664180029715, 0.021925919356622865, 0.03279859486169048, 0.07430752340172019, 0.044459229335188866, 0.06925881574196474, 0.0655234261815037, 0.05132113862782717, 0.051467369709696086, 0.07122725940176419, 0.047159235525344095, 0.03350568263392363, 0.044105051018829854, 0.054962469664003165, 0.04180523121197309, 0.0193554522868778, 0.028915858029254844, 0.008917252932276045, 0.025577441988778964, 0.006906442818165357, 0.020218272327578495, 0.012035916077106126, 0.02509931568056345, 0.03554139964814697, 0.05024226116282599, 0.025554342960406626, 0.039559843484312296, 0.008004565656717335, 0.02398767854486193, 0.006987349213367062, 0.07031343558004924, 0.04405303452430027, 0.013833238294215074, 0.08606823161244392, 0.04917457274028233, 0.05397178818072591, 0.03726958084319319, 0.04472861113026738, 0.011619337984094662, 0.0739309907491718, 0.0340476421240185, 0.021935895517734543, 0.05574985187766807, 0.014715375378727913, 0.007353742008230516, 0.05366496482331838, 0.071351254891072, 0.03930861250098262, 0.020424942219895974, 0.026790956068517904, 0.0035168964074858066, 0.018229470920882056, 0.014293628545211894, 0.07112612375723464, 0.01696884276212326, 0.059795803523489406, 0.045583124206002266, 0.023342537627156292, 0.03377791088340538, 0.02057833523888673, 0.056669728231749365, 0.07622651542936053, 0.07512449992022344, 0.026668877440637777, 0.01222149286020015, 0.03367841050827077, 0.03421563721661057, 0.018543717451393604, 0.06298651945378099, 0.06674470779086862, 0.036213875349078856, 0.046278262976557016, 0.06244173725800855, 0.03687405260279775, 0.030348622040557008, 0.07659053589616503, 0.038589423056691885, 0.08929001087588923, 0.01237554320999022, 0.06850898026355676, 0.01289990998338908, 0.08571858251733439, 0.0560918199563665, 0.02678243536502123, 0.1069797920063138, 0.028313198492729237, 0.03304453666454979, 0.020316307067072818, 0.031782610807567835, 0.05079037157286491, 0.060512173654777665, 0.027011673332058957, 0.05685408280364104, 0.03129361436835357, 0.06742920034698077, 0.03973661203469549, 0.026296887580039244, 0.023625349326591407, 0.022513211771313633, 0.04892694477790168, 0.02568406698160938, 0.07418102411819355, 0.041582301924271245, 0.007658713813205915, 0.01846491578700287, 0.03303660798285689, 0.09712406407509531, 0.0358481755081032, 0.022041753765993884, 0.033012540345745425, 0.022979587549343705, 0.035946641117334366, 0.07200778501906566, 0.04505365654560072, 0.04788453857015286, 0.038166909478604794, 0.03778348969561713, 0.03202424730573382, 0.06724462525120803, 0.0025769746446582887, 0.014342360930251223, 0.023144841360460435, 0.06515085617346422, 0.059864925885839124, 0.026806930479194437, 0.029405264982155392, 0.051949747039803436, 0.010706858509885413, 0.015380750210689647, 0.07636218172098909, 0.010009417809279901, 0.027993252268061042, 0.010585530511369663, 0.016731175693816373, 0.06178030810718026, 0.052428202437503, 0.03469692889068808, 0.036172196335558376, 0.0038288399477356245, 0.03220430335828236, 0.03006958808483822, 0.08021541924348899, 0.02091902936808765, 0.02996012003027967, 0.058758242055773735, 0.06265283628766026, 0.023058859099234854, 0.041803609513278515, 0.05601306239675198, 0.030710081037666117, 0.039196671186281104, 0.038979770682219944, 0.047136379073240926, 0.016153842476861816, 0.03674006907801543, 0.02802372527574854, 0.03750306474311011, 0.018006517884454558, 0.009341322900062161, 0.0842896488362125, 0.027323536508317505, 0.03034289859767471, 0.05655695910432509, 0.026298991038597057, 0.003531373376193057, 0.03069193022591727, 0.07126662121819598, 0.024177956727466414, 0.01077275104554636, 0.03882052190601826, 0.03443395925153579, 0.0334945512669427, 0.024166530197752372, 0.06943668012640306, 0.0705273166032774, 0.015042661655960339, 0.013569118538206177, 0.05766215015734945, 0.014075695819753622, 0.0346931528433093, 0.010245916101017168, 0.05653166671150497, 0.03688459025163736, 0.04161837963121278, 0.020263092958235314, 0.011123996394287263, 0.08054596079247338, 0.04607659897633961, 0.02593686877350722, 0.04680021586162703, 0.03214980342558452, 0.008927906780237598, 0.031469880802822967, 0.040588706133088896, 0.027053382879655277, 0.027021483252091066, 0.01053565225031759, 0.031126827068094696, 0.07462313718029431, 0.04591812373005918, 0.03554478553789003, 0.015344358681301986, 0.09018079164837088, 0.01521378818766347, 0.0446428544819355, 0.01988998181851847, 0.0705158222200615, 0.06543613265135459, 0.0310811413052891, 0.03176716056519321, 0.04234627467979278, 0.06989207211881876, 0.06104843345071588, 0.013355339295230806, 0.016331209834398966, 0.0397061322416578, 0.018146599742716978, 0.037952431344560215, 0.07324832345225982, 0.02782766767112272, 0.005759212279891861, 0.02206798592981483, 0.026044039987027645, 0.027550743959311928, 0.004438501965653683, 0.01834204327315092, 0.019574761590255157, 0.021447628503665328, 0.007029495991966022, 0.03316980440701757, 0.04564771395442741, 0.02518925888996039, 0.0037378619724352446, 0.05307267499821527, 0.013823078080479587, 0.00951299480428653, 0.12968244057680878, 0.12782664730080537, 0.28256627331886974, 0.12352624163031578, 0.12704193512243883, 0.11912056803703308, 0.11041602904775313, 0.06964734489364283, 0.17077475200806344, 0.1391598241669791, 0.10235315348420825, 0.08903684267508132, 0.13863864141915525, 0.16400223970413208, 0.16249167147491658, 0.23039952399475233, 0.1793869084545544, 0.1271780085350786, 0.10852183747504439, 0.10709145851433277, 0.07875428907573223, 0.16564234026840755, 0.11169681817825351, 0.14991517418197223, 0.19550006597169808, 0.15770970950169222, 0.0852693651935884, 0.17220323107072286, 0.14784294180572033, 0.06181983955736671, 0.09140075011444942, 0.16972330771386623, 0.10533324535936117, 0.11930641877864089, 0.15424307409141744, 0.17136397824755736, 0.13517903563167366, 0.14753096497484616, 0.12086816211896283, 0.19319691455789975, 0.10445937367954425, 0.1483905195657696, 0.20239651948213577, 0.17354801962418215, 0.15304756324206079, 0.11446347007794039, 0.29890686220356394, 0.08689994591155223, 0.09795796325696365, 0.13431781184460434, 0.1303562665624278, 0.12554667464324407, 0.15702428056725434, 0.13623422543917382, 0.18141804875007697, 0.1208126579544374, 0.1828372318829809, 0.1039104727762086, 0.124772167631558, 0.14408939464816026, 0.11456575244665146, 0.13827301960970673, 0.15942843870392867, 0.11940980037408215, 0.11138368105249745, 0.06344026939145156, 0.13374588824808598, 0.08226574172398873, 0.14345197885164193, 0.23711427939789637, 0.21190166872526917, 0.1093177997640201, 0.07267267469848905, 0.20650021785071918, 0.15078612816120895, 0.11652511730790138, 0.14267334634704248, 0.15604189756725514, 0.11835079719977719, 0.09925725603742258, 0.10951053085071699, 0.1233347047652517, 0.08573950175195932, 0.16534202066915377, 0.153586442183171, 0.1552041918039322, 0.07857675038810287, 0.1367711094873292, 0.11292934989822762, 0.21521735723529542, 0.12449791734772069, 0.19401019306055137, 0.12497651523777417, 0.092636864499322, 0.16890443808266095, 0.11351727335048573, 0.1574262854244028, 0.1591821304921593, 0.07870988574411188, 0.15528491032975061, 0.13652173429727554, 0.15871561052543776, 0.17992592310266836, 0.14478399737605027, 0.07355339958199433, 0.11864830766405378, 0.13618375600448676, 0.08410358096339873, 0.09473809067692075, 0.09557663103831665, 0.12799542610134396, 0.1131533682346344, 0.12385625392198563, 0.1273988038301468, 0.17128119697528227, 0.09426497534981795, 0.09037394342677933, 0.26604275139314787, 0.12035459253404822, 0.17919265744941576, 0.1535758027540786, 0.19559826355959686, 0.10592028671609503, 0.16777405302439416, 0.09784340618976525, 0.16192210918026312, 0.11951424048415252, 0.12155022551970822, 0.08369667029806546, 0.16807822670255387, 0.13139317663652555, 0.1419754730803626, 0.09485116175242833, 0.12941451423934527, 0.10019716953060456, 0.17595607255186352, 0.0664636314447437, 0.07211134303361177, 0.13970569201878139, 0.15772927845163004, 0.13908906653523445, 0.11198085972240993, 0.13329365822885716, 0.15823144864823135, 0.0994676018932036, 0.1322287925119911, 0.14908255743128912, 0.1363681818225554, 0.09665123373270035, 0.17630470384444508, 0.11029539230678763, 0.16094766503998212, 0.14135442354849406, 0.07779873535037041, 0.12467515069459166, 0.1708324681967497, 0.1333964562841824, 0.09963631284024034, 0.09886415355971881, 0.08558563036578042, 0.09999742239181485, 0.12878918993685926, 0.13592337497643062, 0.14251722900995187, 0.05366680026054382, 0.09458699449896812, 0.11694986665887491, 0.08513990749738046, 0.08198860766632216, 0.10876186245254107, 0.11732578862990652, 0.13410631247929164, 0.11395232964839254, 0.23960108309984207, 0.09214841428079776, 0.09607118128665856, 0.1479504896061761], [0.07277864151235137, 0.044007233410541496, 0.04640018893405795, 0.003747235085549099, 0.04071455402299762, 0.07952946105173656, 0.016232447366097143, 0.027252768698547567, 0.023567716258444955, 0.030944297755403177, 0.049886522215924094, 0.02167689530844135, 0.01820820732973516, 0.06578998187822954, 0.02499489253386855, 0.05580846033990383, 0.029231193608471324, 0.07345065580947058, 0.03478939964302948, 0.11847823964697973, 0.08222905333553042, 0.04083978783871446, 0.03360048754672919, 0.03416795656085014, 0.058280980879707, 0.044422238998647244, 0.03224095442731466, 0.03704053456229823, 0.008144443106305386, 0.047894356971872706, 0.013241973056990122, 0.04863332910463214, 0.02928626351058483, 0.03674995194056204, 0.03229618039248245, 0.08068358805030584, 0.05281473330355116, 0.011813054642906147, 0.047491520909326415, 0.044124735319720845, 0.026812362152018716, 0.027201978656064187, 0.05803090001323393, 0.05968991134847913, 0.036019315610506704, 0.015671845126364912, 0.05977259084050145, 0.04137846321931907, 0.03965112340769597, 0.03236663607614381, 0.01147133338132075, 0.05315224340717707, 0.051267683639058044, 0.02294814762925463, 0.03767954491611038, 0.06790355060781751, 0.04750606870012624, 0.059444023828421316, 0.01617416290433279, 0.03731068988729801, 0.02439608537991132, 0.015265099005773664, 0.0441492100778435, 0.008840752349767302, 0.026079698698595166, 0.024575937871954272, 0.029471961581813436, 0.01338532884671752, 0.06808143534830638, 0.01752304980930473, 0.06183993097926889, 0.024277908328388418, 0.04789522210402148, 0.05611434731898563, 0.010840158410636442, 0.03724246997652309, 0.006129493504496557, 0.04531907230349524, 0.01310242893772998, 0.02237902638236327, 0.028799170362097875, 0.0037352848116175403, 0.0346419438054519, 0.0432374693586358, 0.015026573590668184, 0.03851553059316107, 0.055305625178984234, 0.02264042690928493, 0.03680672835824745, 0.03952960457120623, 0.049135628222887, 0.007042821147479117, 0.02016837795131973, 0.08637741966439144, 0.08269106782972813, 0.02005202615899699, 0.019647135831681744, 0.03455307607405952, 0.016581870848312974, 0.043726866133511066, 0.02395245579204389, 0.06315525075686829, 0.031199369246938398, 0.03234507901860135, 0.01651834131085447, 0.018522301189867512, 0.04625643789768219, 0.047952025663107634, 0.02275848012816693, 0.025260460962142264, 0.0034751255796956165, 0.05966542301965611, 0.02897243427910975, 0.019956856533618908, 0.05740384544645037, 0.06415652417178665, 0.0347908483152943, 0.013329298817552626, 0.01820385452759053, 0.029014238821608678, 0.09458843299320766, 0.04832586792430707, 0.04952260692204748, 0.022739191073924303, 0.04773525747337511, 0.04567908262833953, 0.08713452225284916, 0.03525228944740125, 0.010635951600436653, 0.012620556268042751, 0.02238562174274453, 0.010074971925600298, 0.04509612265974283, 0.045644630012767654, 0.027526806940191557, 0.03125740095440831, 0.020146405291078345, 0.0109262144625453, 0.09182339600686516, 0.009997874232275146, 0.017805561256994094, 0.05092975623639567, 0.017963395287681903, 0.015446624086637582, 0.06702928537768976, 0.013506321818567812, 0.03371927867244397, 0.06559385133108922, 0.03449428101469364, 0.028252525587699244, 0.03630927058735064, 0.04533677528213177, 0.03406542991953237, 0.011409559553222997, 0.0420913321099111, 0.01645883039704391, 0.09341175827596869, 0.04059687569471342, 0.0068936040874437565, 0.03561940403389079, 0.05301518611876028, 0.010886388697794505, 0.024942012603527734, 0.03836753871291876, 0.0713677229359746, 0.02132056773241077, 0.0071176372668040645, 0.046429491468838284, 0.009347800364983934, 0.046264546391155036, 0.07747033118669476, 0.12433208338916302, 0.031460109898554425, 0.012384873066496636, 0.06386623332010848, 0.02410470039051558, 0.056789381096937826, 0.008110165213500815, 0.02105847679610763, 0.02864550592909966, 0.03284885734319687, 0.10239977562533957, 0.03416514742587294, 0.05780683417937585, 0.08321443546031203, 0.06111613767487662, 0.04273276483373983, 0.033499012634690316, 0.02049787964538804, 0.003665842265555901, 0.02625580398099763, 0.041432131946619065, 0.023740274499037435, 0.07978972672883954, 0.06109679264149495, 0.04122609818088157, 0.026255812462685362, 0.023703070423964943, 0.06336968817881175, 0.024290785226704817, 0.06673495045730046, 0.03536659206396767, 0.03991862566077283, 0.10167163291147777, 0.052180951062057696, 0.029152249451726675, 0.022839330968313983, 0.0503990909616862, 0.09390033741614648, 0.025762868646000112, 0.03192502173728176, 0.025194429326802492, 0.04140293797744172, 0.004910755977367184, 0.014944216402779733, 0.021962505964828388, 0.014097530228484954, 0.011751271484951888, 0.04728690867445298, 0.03337238782218524, 0.013712487898633947, 0.007158699661626348, 0.03226966324395367, 0.03787077304774097, 0.0226948114910296, 0.010266939660401216, 0.0197219358358, 0.017425885290971825, 0.03564517140122397, 0.008119652829399067, 0.04480427457019687, 0.008630534567471062, 0.04102884805096047, 0.05294023174792528, 0.0732824130515967, 0.018128759360739162, 0.041341215039470365, 0.02507352626084217, 0.027097828619714295, 0.007939355048750128, 0.03389802175973143, 0.013330451478915555, 0.03895482773493443, 0.023056964290195277, 0.07352327941251652, 0.04510582231783441, 0.06274071335792542, 0.017342990364081094, 0.027828760112502744, 0.039989291690289974, 0.0699208691450102, 0.0374762117197471, 0.039441666432789395, 0.0520948517535414, 0.019014291664851562, 0.021578198997303843, 0.03399299969896674, 0.061023917980492115, 0.015584931575826235, 0.0579266431076186, 0.00940271420404315, 0.03224509349092841, 0.03530997849468674, 0.02345180551388434, 0.02144806446241481, 0.029373855596142154, 0.002829660873560767, 0.09466221689113549, 0.009752059654731835, 0.04591824925903763, 0.015393177579556192, 0.002087410356450294, 0.04745470020653946, 0.06257085568670716, 0.04282458758513842, 0.06668591273150273, 0.0834681261330843, 0.04705455114266702, 0.023811568173446825, 0.06357964726963214, 0.10288889759353229, 0.0038697835989296436, 0.02155646212798144, 0.06326868824128594, 0.03484760776960424, 0.03766683595521109, 0.02836261110912476, 0.05799008613186223, 0.020152875122481158, 0.02647464339887457, 0.03566072681652648, 0.03199324843340686, 0.07947542930820159, 0.02273539636683251, 0.017406575880678635, 0.12909864261746407, 0.07521020567842893, 0.02090479200705886, 0.05146233158718262, 0.031158891240400926, 0.02920757041179708, 0.031153364572674036, 0.05155792360060981, 0.019331135288146988, 0.041718470331813605, 0.024633023023073162, 0.025117369801072136, 0.07360739739877836, 0.02974363343257989, 0.041836362398628674, 0.022608154087460468, 0.048806250361459594, 0.0245280299069626, 0.023180544176804166, 0.014839160522179944, 0.03569727271263089, 0.04381803070594158, 0.0434852228499949, 0.045839362777769566, 0.07553454541734286, 0.041824036810014925, 0.033452410849609544, 0.04091624177194067, 0.08555497415363789, 0.036751980760267804, 0.022680792957544327, 0.0425536519448672, 0.05592326846505914, 0.0038237483905894415, 0.004101041479901011, 0.038046737534127066, 0.020829805405810475, 0.055813593457319906, 0.02754048620616751, 0.06498810276389122, 0.04172263314415302, 0.029534685358937298, 0.06189892959914037, 0.056638705610696755, 0.020149341651371548, 0.05320626497268677, 0.050194879062473774, 0.03117355777482901, 0.03924109148127692, 0.025183213142944232, 0.03128262549372656, 0.04086212521152837, 0.16613036979522022, 0.06038930453360081, 0.03513369170416679, 0.03189204493537545, 0.011170033298965012, 0.13960339607936995, 0.10153825328286205, 0.12208055491958346, 0.03492365458181926, 0.11568745225667953, 0.18780656451625483, 0.06086206023714372, 0.14496766323489801, 0.14925523102283478, 0.20175732592386858, 0.10977072188896791, 0.09529189060309104, 0.13886076664286, 0.18132191390863486, 0.0969010703265667, 0.17010862060955592, 0.09286809566297702, 0.16399024320500238, 0.06765666564128228, 0.1824275188680206, 0.1531267754201378, 0.13315150514245033, 0.13337903150490352, 0.16480152681469917, 0.37657838580863817, 0.17227451795978205, 0.11469738824026925, 0.16630008497408458, 0.16214423440396786, 0.13909796891467913, 0.10246025345155171, 0.1621881763317755, 0.1576705037483147, 0.15253255516290665, 0.14123660272785596, 0.13177551754883357, 0.1538123129201787, 0.18010177223810128, 0.16996578898813042, 0.1126584108652813, 0.060633543213563304, 0.09446422037269388, 0.20111285336315632, 0.12250774699662413, 0.16072349064052105, 0.11874718378697123, 0.12015218553798539, 0.09576145040669612, 0.18101679028144904, 0.09814000741711684, 0.10766339568155152, 0.08445905188896827, 0.12226218517337527, 0.0727233069815806, 0.15593490616551467, 0.17106829982783112, 0.15009077904479845, 0.13610645729516233, 0.11255818445767675, 0.0850297948345542, 0.10115982073226146, 0.13075800000556878, 0.10560900877629008, 0.0812692791223526, 0.10233796787049089, 0.13740775175392628, 0.1348880933863776, 0.18097823592168943, 0.17667716528688157, 0.10862250493041106, 0.23316059155123575, 0.0977812795234578, 0.16219266823359899, 0.1526199369026082, 0.22665546275675297, 0.14858576123203548, 0.11734001072389738, 0.16444887859480722, 0.17933824392301695, 0.06681158420230661, 0.09239612027470555, 0.14514195173978806, 0.10451952580894742, 0.10222011312310185, 0.12932847599898065, 0.15692411522780145, 0.12268435609127794, 0.16774164619190352, 0.15608262323907443, 0.09224238459553037, 0.11213306869779315, 0.3296802437731198, 0.11214136039572102, 0.1597062037991626, 0.09006875873144184, 0.12163938502115862, 0.15365890972316265, 0.15226104616054467, 0.09702809208205768, 0.21054739425224916, 0.12893915974668094, 0.12844880963010447, 0.11338442976453475, 0.14276322509561265, 0.1706216066543545, 0.07816633848207337, 0.1325697156467608, 0.1353565946753536, 0.09534094189958912, 0.09325841614710433, 0.15579896845987865, 0.19595613649913243, 0.1452692856213876, 0.12123458459973335, 0.09557515861732618, 0.1366216553641217, 0.21507285641772406, 0.08797051132257495, 0.09968640229531697, 0.1624216738023928, 0.15540978791458265, 0.092169672782932, 0.11310412694833108, 0.09367954890642848, 0.08275273987757308, 0.12550444262368338, 0.20997475140861102, 0.15869211964309216, 0.06798124286745276, 0.1280830656843526, 0.1164923304958003, 0.19286998281521456, 0.11609097703226975, 0.186200580692717, 0.08754513771938426, 0.10420047864317894, 0.16261741758457252, 0.10878357557313782, 0.15782484332365648, 0.09238071074443203, 0.13854272370891912, 0.09960909001529217, 0.1320458459002631, 0.16977696626314095, 0.1385398602911404, 0.16994680357830866, 0.12874703934150084, 0.139174738366689, 0.13815798078264507, 0.07512610126286745, 0.13489719932632788, 0.14907197228499822, 0.10562390940529959, 0.1157302406749555, 0.11203975656202861, 0.09539102456931557, 0.19416777603328228, 0.13431802897581033, 0.15092619135975838, 0.16826400959065982, 0.08863887510129384, 0.1311421865331275, 0.1271669077021735, 0.12345282414129802, 0.1628208559538637, 0.10967846826783248, 0.11524629592895508, 0.1253148192273719, 0.17891778291336127, 0.1227425608251776, 0.1235826143196651, 0.4097655607121331, 0.097294410291527, 0.08111486490815878, 0.13212026762110846, 0.10490127639578921], [0.020995758107996414, 0.06307664247495787, 0.032990260648408105, 0.04456691962799855, 0.046172204560467174, 0.03604479120778186, 0.03549367828028543, 0.03825037607124873, 0.029611597303301096, 0.019461634535608546, 0.07328213485223906, 0.008487010840326548, 0.05240356483097587, 0.04712517985275813, 0.044068427091198306, 0.019209540116467645, 0.027357488704313124, 0.022910750171701823, 0.014134169423154421, 0.044369808597756286, 0.009977440150188548, 0.027967389905825257, 0.07106145258460726, 0.01870287292903023, 0.06973019401941981, 0.0722078714253647, 0.05151392060465046, 0.07081466261297464, 0.025989701206396734, 0.0262683450044798, 0.033276283514818976, 0.04699282481202057, 0.08785007814211504, 0.061240479217043946, 0.027108150833685483, 0.027107857367289916, 0.026801855037254945, 0.01534097788057157, 0.022653729588325535, 0.0634598315560392, 0.011937662510068288, 0.043131217560065646, 0.03549441449078066, 0.01680081374278026, 0.07236130176378147, 0.01419287288029279, 0.04543780575373343, 0.00991203446340348, 0.03356251333441053, 0.042645657900720835, 0.07977772344435964, 0.02728441896449242, 0.03314339243141668, 0.029703504871577024, 0.01906204017411385, 0.06647900026291609, 0.026995113684928844, 0.04155278565096004, 0.07820158837629215, 0.029538977092930248, 0.08971435989120177, 0.020234426550034965, 0.031135824442441975, 0.020103772935856665, 0.05727896107626813, 0.03167738359687584, 0.026559253323024938, 0.09626369524214949, 0.034267161773251634, 0.07685304752417974, 0.0350762028247118, 0.10131632483431272, 0.039215921224760156, 0.1412666482584817, 0.01945422323686736, 0.009231541871226259, 0.009370538921627616, 0.05670995857300503, 0.010089978575706482, 0.06528253946453333, 0.021580743503623774, 0.028122511492776017, 0.039789924531110694, 0.009939789938341295, 0.043325431245778284, 0.061630677564867904, 0.008097401121631265, 0.01874007870044027, 0.010896863582144891, 0.04528438559334193, 0.037382034451833794, 0.04055382604045527, 0.05730298800127847, 0.03682785793872816, 0.06897119153290987, 0.02175044171911265, 0.04685155042846288, 0.005767590491034622, 0.02345101671692516, 0.021812687129048363, 0.11523024179041386, 0.011134214283499335, 0.030967513831066232, 0.023178237157740762, 0.024588685848617127, 0.010947886022872158, 0.05987883585372141, 0.015831550217366645, 0.020314668405002782, 0.01202152859020446, 0.06264457173113312, 0.010475839388423731, 0.02750232539671872, 0.030114625846701007, 0.10352179434682642, 0.03569431429994958, 0.010433126457168587, 0.01973660915557827, 0.0677757417517049, 0.015569340537435241, 0.040887967217713594, 0.05053806171885558, 0.013672752039773124, 0.0748821339969124, 0.01192831653835518, 0.03087040189919727, 0.02843312277192516, 0.05827688252819436, 0.09363370029521839, 0.012270370282099714, 0.02850472687610558, 0.03471035709870713, 0.038740447988467555, 0.016026795276307633, 0.014140760542691817, 0.02017445083973663, 0.03226252505555749, 0.021351517410948873, 0.022121466363647153, 0.01803159144973116, 0.04746685955407364, 0.043546555630330525, 0.03379061984430466, 0.03758908262742417, 0.03688573019046869, 0.05432262810479317, 0.03276843737278666, 0.0198699090563293, 0.07442839084459202, 0.07039025931486062, 0.07642468836690698, 0.009780471612300192, 0.03494151701618518, 0.03595468854265554, 0.1072854313201138, 0.05720458685287407, 0.019265894146103944, 0.05642027501016855, 0.02837125225258725, 0.008929745610138136, 0.019272881360458474, 0.03108119898076568, 0.06919305891330753, 0.007878071462203349, 0.05320020904764533, 0.06896825347627912, 0.029886312383626188, 0.028124124709782854, 0.008551428410490709, 0.030095847390059913, 0.034661797740097554, 0.0517993565382702, 0.06032836530357599, 0.05565516570849078, 0.040507994392620664, 0.04362100788525172, 0.09641290509275027, 0.01425235834904015, 0.02131767038788114, 0.03498695172103388, 0.050924344919621944, 0.011981313515986716, 0.031475658528506756, 0.06548962156687464, 0.021209282900339792, 0.03510357832003917, 0.07445256026195628, 0.02341667266695627, 0.0599556053057313, 0.06028801961136716, 0.0402950633184186, 0.02758575975894928, 0.02862066476206694, 0.04046262414859874, 0.040097986214927266, 0.027045508480763862, 0.016455303711284484, 0.056109064923865457, 0.015271670617429274, 0.04733810414161001, 0.04224556990500007, 0.030448119023016522, 0.023407612528119768, 0.06570449325123004, 0.010619159555062652, 0.025066143799839274, 0.05222775980031916, 0.011904716242237814, 0.06925290570195232, 0.017747195371027504, 0.04526659779782806, 0.03463935858703085, 0.04791140516421624, 0.025959285874185816, 0.012499157871518816, 0.029586009747747864, 0.04333142610266805, 0.06198036737207856, 0.05298042476975492, 0.03170668613165617, 0.05872570630162954, 0.034031995106488466, 0.027043486446408287, 0.02919547552508967, 0.02153601956420711, 0.05565273655312402, 0.021962544980591962, 0.041917477867433, 0.03808578383177519, 0.01623523953769888, 0.03824697321813021, 0.04634148547691958, 0.017891314512650882, 0.030247499966727834, 0.01334141321214182, 0.03644593093278153, 0.024750988032402735, 0.05104557877140386, 0.04021803602310164, 0.008034746894346816, 0.07973395115030663, 0.0259494793468288, 0.04182929884908455, 0.0566645374388567, 0.057004948279687336, 0.040755625747676404, 0.02628090638401253, 0.038897026729370864, 0.05455703141966036, 0.04924436345962541, 0.010243025541837727, 0.05467179883271456, 0.012335354429004448, 0.09947605643953596, 0.061693109571933746, 0.03917099202850035, 0.009297788093265678, 0.012626434925810566, 0.02424083317496947, 0.020585207102288092, 0.03641051479748317, 0.02515986475295254, 0.05523607533957277, 0.10550785956106015, 0.008276622576106871, 0.029555797976042544, 0.09529666070427213, 0.10859459678509406, 0.021130279371781007, 0.03536069220198052, 0.029599926500980343, 0.017261689994484186, 0.041655766910740306, 0.009733048799846853, 0.03404312986614449, 0.029943485744297504, 0.08673836636756148, 0.06259976127850157, 0.07377334670828921, 0.04331634905455368, 0.034542239869811704, 0.07266179099678993, 0.03944020079714911, 0.008327728137373924, 0.010884381930476852, 0.04088530736044049, 0.014825006281690938, 0.027173263054074984, 0.056352991477719376, 0.016132034361362457, 0.031388965501849136, 0.0316158540413848, 0.0242034408064293, 0.03665952357862677, 0.06399541960230895, 0.06340844609907695, 0.05705650337040424, 0.025028642865696123, 0.041196364776364396, 0.009028937251839255, 0.04531544892649565, 0.008349576964974403, 0.027950124582275748, 0.028846382828695432, 0.0368243736614074, 0.03930978975923998, 0.02408061070101602, 0.05219212992648993, 0.07441127819142171, 0.027981260857943977, 0.038041380500154834, 0.03746428307411926, 0.03405449193503175, 0.05602143212620701, 0.03643631948424237, 0.0395752055171345, 0.031955990075532875, 0.06153826788067818, 0.04353140055068901, 0.03969690077272909, 0.05837717678930078, 0.035066540486046245, 0.0364998133986124, 0.019103164485256587, 0.016153255544070686, 0.02399711696697133, 0.027318751140098487, 0.029835276372198547, 0.05654165813965457, 0.016594876668282917, 0.03013007269640054, 0.021587571262248924, 0.027200474004660333, 0.06452436479074614, 0.02121987652831844, 0.04008151477734957, 0.026595188537612557, 0.05056728622210877, 0.020241032088441507, 0.01698964155678238, 0.027939473278820515, 0.07517710674021925, 0.061092198959418705, 0.03911052777298859, 0.025868967774191072, 0.04730870321925197, 0.058855652543050904, 0.026631262851879, 0.019785093875335794, 0.0274414404494954, 0.014553135959431529, 0.012448852133404995, 0.1109462430966752, 0.07468697375484876, 0.07652463657515389, 0.12526985949703626, 0.11201251338102988, 0.0864546030227627, 0.16791627396430286, 0.20624879348490918, 0.09865006897598505, 0.12570467830768653, 0.2540240234562329, 0.09184794540383986, 0.19192652058388504, 0.12505644666297094, 0.1173068710735866, 0.12005603712584291, 0.12882052468402044, 0.09413146679954869, 0.09697980753013066, 0.09363557305186987, 0.07644108177295753, 0.11898862011730671, 0.15433299355208874, 0.11414932193500654, 0.13833517341741494, 0.12588409653731755, 0.1720582145665373, 0.13903584224837168, 0.09750400297343731, 0.20159362256526947, 0.17979169530527933, 0.08207828285438673, 0.19479030477149145, 0.09432907655302968, 0.09379376670611755, 0.1347737738064357, 0.20131412042038782, 0.10345305874943733, 0.1190430929086038, 0.17113708970802172, 0.15858454470123562, 0.21164438181689807, 0.1592151072940656, 0.08740392779665333, 0.13647494252238954, 0.08834466231720788, 0.11396727098950318, 0.16707091432596954, 0.13801732047327928, 0.1090493645252926, 0.158516989754779, 0.13038985404585088, 0.15758640611810343, 0.10435776306050164, 0.17623766458460263, 0.21722367671983583, 0.11464497819542885, 0.11574355353202138, 0.09422889764287642, 0.09476821763174874, 0.11045657151511737, 0.14926509692200593, 0.12892945669591427, 0.12701326023255075, 0.13093064645571367, 0.10884968524000474, 0.1327368931046554, 0.1881692007716213, 0.1501823134188141, 0.15375253398503574, 0.2157444025256804, 0.25377337262034416, 0.23541590624621936, 0.16079477752958024, 0.11818583176604339, 0.11169820917504174, 0.08756002477769341, 0.18914939888886043, 0.13042291227195943, 0.09683282327439104, 0.06179774645715952, 0.15715188586286136, 0.1284101331340415, 0.1149474283946412, 0.13947152958384582, 0.17518926012728894, 0.1394394484481641, 0.2550646790436336, 0.08372557588985988, 0.15068763201790197, 0.1615423331303256, 0.191047587032829, 0.14390247182122298, 0.1417399535753897, 0.13441557517009123, 0.09678776854915278, 0.14981861864881857, 0.08731321445001022, 0.1395673794405801, 0.1422536995794092, 0.19617835671773978, 0.154144998639822, 0.13650992778795107, 0.0920790069337402, 0.05616810764851315, 0.1634982374629804, 0.15733925652291092, 0.08196412612284933, 0.1009242944419384, 0.1273256577551365, 0.1457917033029454, 0.14847351796925068, 0.12768319142716272, 0.057169649084763866, 0.15972991181271418, 0.17268227679388864, 0.1396308767476252, 0.13671210408210754, 0.12967489526740142, 0.11825779719012124, 0.16273840037839754, 0.08784895855933428, 0.1133358059450984, 0.15155906097165175, 0.06506831917379584, 0.09377269140843834, 0.16277791825788362, 0.16853313014975616, 0.22807516157627106, 0.07236557653439896, 0.13797982462814876, 0.12419577927461692, 0.20479207379477365, 0.13025813682803086, 0.15988305716642312, 0.06199743252779756, 0.195620682356613, 0.16794143404279435, 0.09735261502542666, 0.1039597751306636, 0.155170237911599, 0.11540615877934865, 0.07314300803201539, 0.20696095669908182, 0.1661522321935211, 0.10033939725586347, 0.08007509141628232, 0.1625325871365411, 0.19233759066888265, 0.14937427320650645, 0.1367743664554187, 0.11692976845162255, 0.1211229113063642, 0.14402440456407412, 0.13403342424758843, 0.12611363136342593, 0.11564850434660912, 0.16415185667574406, 0.1004959624260664, 0.15028747277600424, 0.20566963670509203, 0.1102361154875585, 0.13211067313594477, 0.11648355025265898, 0.1535748392343521, 0.19425608058060917, 0.16249867395630904, 0.08920273091644049, 0.14017829165927, 0.16153845191001892, 0.13096445107034274, 0.11694665040288653, 0.09103427335087742, 0.15994735514479025, 0.1839243264070579, 0.0741704593279532], [0.031264820734837225, 0.016640788043982217, 0.061726351002497334, 0.03658387710207275, 0.035511554285351715, 0.05377224799511688, 0.032489213427262645, 0.0162841788759189, 0.06637141853570938, 0.04682028014212847, 0.0212287823004382, 0.02620992822838681, 0.037288817310971875, 0.051318960530417304, 0.028254472983202765, 0.022066717069329958, 0.01057855093053409, 0.05314405009682689, 0.012162357685156167, 0.03345655669857349, 0.03954014900539603, 0.027354436993066753, 0.024813900102994273, 0.012657773065646844, 0.005982080499442028, 0.0568080204539001, 0.04545380900214825, 0.07176945637911558, 0.019994014807577645, 0.02915475663862058, 0.015194629751411932, 0.017010649000959735, 0.03276497005884137, 0.04805690003558993, 0.05529658030718565, 0.014374621877712863, 0.02483391179703176, 0.06344470701047353, 0.034849008944417746, 0.04270096529009087, 0.1400566981839282, 0.09294806780027491, 0.04366769787988492, 0.029294243082404137, 0.07046431462679591, 0.03381143051332661, 0.056423145213297436, 0.02483006619981357, 0.013132864625991454, 0.01345109670156879, 0.04159632045775652, 0.022081582075251, 0.029600917162107568, 0.03000178886577487, 0.03944461127477033, 0.007478455896489322, 0.016566758177110126, 0.05360358454553144, 0.06585364203367915, 0.09596346385244812, 0.014298773536990796, 0.03352756199559995, 0.02323514419341726, 0.0282260389732463, 0.015020965498739054, 0.06940806630466666, 0.03217567935852068, 0.03039623484281557, 0.032368305272289684, 0.04789574457598584, 0.09459589687841279, 0.04688996908121875, 0.08246103767305613, 0.01771270204335451, 0.03075874556920358, 0.08381849447531359, 0.01960576046258211, 0.057558022173387666, 0.08373381330498628, 0.15597090923360415, 0.3285437247582844, 0.4861860285912241, 0.514522519494806, 0.32433422920959337, 0.13308547011443547, 0.16451511718332767, 0.17452840773122652, 0.09605271156345095, 0.025717052265203426, 0.05106923928750413, 0.05703750438988209, 0.1140521557203361, 0.05084224896771567, 0.04324084846302867, 0.026020678026335578, 0.020852448119382774, 0.02197879589428859, 0.0384926232509315, 0.039714793741170845, 0.03210801584646106, 0.1620344610086509, 0.041447080073079894, 0.053909549556140385, 0.057119383210582395, 0.09493447906736817, 0.032481111719139984, 0.029138091818562577, 0.0329973920514541, 0.011054499989508517, 0.05894016407962356, 0.04139929424439158, 0.04691584840683, 0.05772267548101289, 0.013348541222512722, 0.0516179230596338, 0.04320165628035154, 0.018097506037780216, 0.03778085697974477, 0.040651355271360705, 0.04601567670969026, 0.026597186823242476, 0.004256311072302716, 0.03647461600069489, 0.04573081074548619, 0.030893424592380012, 0.025136445116783892, 0.06169317742543561, 0.019774909064705883, 0.02704495717106121, 0.05308854593230145, 0.06284297537058592, 0.06016639220927443, 0.059809082453804355, 0.039600925387016365, 0.01795468629071755, 0.012453620538248547, 0.0367305458390287, 0.0332145707548729, 0.06057801190763712, 0.016636857629886696, 0.047555052143122466, 0.03321638244337269, 0.07830539744879518, 0.00412538307552625, 0.06468771531113557, 0.03027483814262918, 0.008593678241595626, 0.02676880868550922, 0.034392768783228736, 0.06017038878053427, 0.016435207200369666, 0.006551155097050858, 0.08783903159201145, 0.05248744532998119, 0.05718818666147334, 0.02518025303392538, 0.030066541462604488, 0.0018086615974815296, 0.024038131016173532, 0.022256197973287532, 0.02182636469868677, 0.08325288803981883, 0.06154060882649251, 0.07154910213180951, 0.04922218554254089, 0.07730676353509937, 0.0344428412749299, 0.024729982284562926, 0.02447650535032153, 0.015101558495579022, 0.04400068215493645, 0.03844127172072019, 0.015236656514129468, 0.05637785978615284, 0.03991122962906957, 0.021422448069123284, 0.04096288426912256, 0.02617550445055323, 0.019649583646761518, 0.010594842556331838, 0.048394929218505106, 0.06220429749893291, 0.04862790760983314, 0.05930189788341522, 0.045187565431530984, 0.021098291534664373, 0.010461182183852153, 0.0638975544965693, 0.05627140781975218, 0.09868164121040277, 0.011107506296996559, 0.010023740835354795, 0.007991714203464133, 0.057644861085074287, 0.02913499091352735, 0.02318199284906898, 0.016366003413817713, 0.03664288589996951, 0.07588000795138733, 0.06545155575232846, 0.02321547855223928, 0.009437418725740696, 0.016235393904415623, 0.037359045685401986, 0.037795659221176586, 0.03047767261575375, 0.024340060439759066, 0.011768605510172035, 0.03270531665267689, 0.027703709501240934, 0.05341728597081133, 0.02252882146941764, 0.05229344538279942, 0.09047779999673367, 0.04334040651363986, 0.04262432815240962, 0.11687758910868849, 0.05720957408526114, 0.020867908539782678, 0.08093879864151989, 0.02158619892517371, 0.06422589080674307, 0.061373472080699036, 0.00784182412150715, 0.01914733032962041, 0.02461475346769605, 0.04514406455148544, 0.05469102512246796, 0.010627676865884235, 0.03978497801082475, 0.015204449849469321, 0.01619287859648466, 0.05045108710016523, 0.0699464227738125, 0.040353363047220876, 0.06505575949060065, 0.03419542705108013, 0.04869701640148248, 0.012333977851085365, 0.09946002944239549, 0.011923918783265566, 0.010129640643884028, 0.039632107463798354, 0.1065151651522943, 0.04176033594246421, 0.020497581089979837, 0.09163935695375715, 0.007019154270113046, 0.02568063359441502, 0.05985498534781592, 0.011628995233747576, 0.04915607248299888, 0.0486004167635526, 0.034480693350945196, 0.03002046893483826, 0.254797879074301, 0.4627968179328101, 0.6819805651903152, 0.7397250352161271, 0.637982617531504, 0.21700742760939257, 0.3428751714527607, 0.29608144238591194, 0.18871729421828473, 0.04541014527369823, 0.05222458425643189, 0.03705707385337778, 0.007957739955080407, 0.11089001968502998, 0.06868096853473357, 0.05720709064709289, 0.003882925125903317, 0.023704707389697433, 0.04937792629269617, 0.01744557128820036, 0.07964191466037716, 0.206989889432277, 0.0034640359850267744, 0.03831900649570993, 0.04625259060412645, 0.10054393485188484, 0.0995216675634895, 0.03667891950213483, 0.044011983155672035, 0.011240797716059854, 0.049370889884552786, 0.021709473471024206, 0.04448226899174707, 0.146617860400251, 0.024727653213111416, 0.04504397385088461, 0.02869610089276518, 0.01610204141720065, 0.033873258624225855, 0.060585279017686844, 0.02920592835705195, 0.061182505185050626, 0.02761519800073334, 0.02234261788960014, 0.050219893255936246, 0.04843485761167748, 0.04145188070833683, 0.013623608292878737, 0.0059019853776719955, 0.003991182419537965, 0.013068130688874849, 0.03299453881170068, 0.01804073470910745, 0.013460880328368927, 0.03506271015586598, 0.02373415241683168, 0.05910741617637021, 0.06995278064693723, 0.03903739187600357, 0.05605330291603293, 0.008579731802456081, 0.08009340507643563, 0.04651611664199403, 0.023172130342572927, 0.03731256942929966, 0.0483751533153866, 0.007371068399931703, 0.04419568633394582, 0.04767278814688325, 0.051043264966990264, 0.034963477802063735, 0.03134839589308415, 0.013192975195124745, 0.06418474444321223, 0.01893103032905076, 0.0224766540008464, 0.0068006532715766555, 0.03666222754067608, 0.02503351305079247, 0.01081396865525416, 0.046110563046698055, 0.00978414757576372, 0.048904335991080315, 0.11483044895742621, 0.03592105016910604, 0.05301614285313657, 0.03212337448660817, 0.04610319076372044, 0.030592124510024275, 0.04604855173134378, 0.06894951233906405, 0.02761872807916786, 0.035125895336802514, 0.019932968708287393, 0.021477455206747566, 0.03417978681890028, 0.06374830393386738, 0.13385962428791182, 0.08388070935117346, 0.14480644331446715, 0.0777756448036858, 0.1874332752610956, 0.17298498483640806, 0.09362508290048156, 0.10531431423234087, 0.1392153011901038, 0.07975698741418974, 0.07606323954782315, 0.10594267158636025, 0.13255864195525646, 0.1933282653668097, 0.17288594586508615, 0.061891160373176844, 0.1216366301689829, 0.17056599392422608, 0.06827814943556275, 0.1269720188741173, 0.12114588650209562, 0.06435150120939527, 0.09480460746479885, 0.12885065163884843, 0.1376849061676434, 0.12044103789542403, 0.17996533241655144, 0.14036687011165278, 0.06211450017456498, 0.10005106737038919, 0.08646624668368272, 0.13464961546872342, 0.1388576046696731, 0.08838643971830606, 0.11101990485829966, 0.0787859291636518, 0.06952976156026125, 0.19334127966846737, 0.08522790670394897, 0.12175077332981996, 0.20168340631893703, 0.20765593940658228, 0.15264010296336242, 0.1386544784264905, 0.18555325828492641, 0.1082709627225995, 0.1614895566765751, 0.15111869174454892, 0.11050545996321098, 0.13206590339541435, 0.17174117586442403, 0.19615767497037137, 0.10973189611520086, 0.07095545862934419, 0.08602479858590023, 0.06959321136985507, 0.1715622597507068, 0.1589525413832494, 0.14845134344484123, 0.18674981407821178, 0.08191341241555554, 0.17791819226528915, 0.10395104917032377, 0.15750181994267873, 0.16613235111747468, 0.11700343021324702, 0.18711349527750695, 0.22711864433118276, 0.18151657203478472, 0.13546891936234065, 0.14241012904260839, 0.144044448488525, 0.1592539602092334, 0.09979141237480299, 0.11850342686687197, 0.11118897542889629, 0.22019072036658013, 0.11036731701876436, 0.18052634516996996, 0.4139112468276705, 0.754448159464768, 0.7732069385903222, 0.9087495197142873, 0.6537645821060453, 0.40398987063339775, 0.6217988516603197, 0.4391331805714539, 0.4239372531218188, 0.18562301168484346, 0.14728669236813272, 0.14290332900626318, 0.30829539841839243, 0.2701946800308568, 0.1351787777883666, 0.132535775325128, 0.11734157135444027, 0.11085776213024344, 0.1730209607630968, 0.13826737419835158, 0.15167073426502092, 0.14630278944969177, 0.16165210652564252, 0.1448681221476623, 0.10667900421789714, 0.1677032546805484, 0.2518413934324469, 0.08288429424698864, 0.13469243102840014, 0.08387896551617555, 0.1358672058475869, 0.14420968533626624, 0.12894935134266103, 0.2776552811264992, 0.08851904581700053, 0.2233124699975763, 0.11192450738911118, 0.10823396899338279, 0.12404483237436839, 0.13871927852077143, 0.11592609302273818, 0.13945327699184418, 0.0866541126742959, 0.17445121758750506, 0.15721409395337105, 0.11172725725919008, 0.1188431829214096, 0.18991418927907944, 0.10512013786605426, 0.11468765804810183, 0.19990249616759165, 0.16214088244097574, 0.17575876813914093, 0.13611649961343833, 0.11948042229882308, 0.08432675791638237, 0.15587151742407254, 0.11925495868282658, 0.134820212743112, 0.13805637694895267, 0.140812966174313, 0.15048171021044254, 0.11514463781246118, 0.1791476977190801, 0.0960301977715322, 0.16712241513388498, 0.10847884549626283, 0.10162026781056609, 0.11870928082082953, 0.23849637380668096, 0.11576986712004457, 0.20284885806696756, 0.09687503493790116, 0.20815068643007958, 0.12795531111104147, 0.14561928755470685, 0.06516179415796484, 0.1527291810406106, 0.07981234908636127, 0.05982540122100285, 0.11793796292373113, 0.09048958615000759, 0.22521496005356312, 0.21122587498809609, 0.12395479077739374, 0.09491015358694962, 0.14928974131388323, 0.16865492718560354, 0.08858367627752678, 0.2018915130091565, 0.19460024711276802, 0.08294517919421196, 0.10837340115436486, 0.06506327765860728, 0.14108037682516233, 0.11529320984014443, 0.20912734259452137], [0.021016109069543223, 0.048114446590521505, 0.035582084607865126, 0.027443270797708204, 0.0200866365339607, 0.037581384647637606, 0.028678733788962876, 0.024847323041675345, 0.037902141721653085, 0.00939897377975285, 0.11197423722062792, 0.028683524246194532, 0.11068072555852787, 0.041416247441832504, 0.016836263804829547, 0.01039832185155579, 0.02548569387623242, 0.031108869638826166, 0.026201468593041812, 0.053630006699157615, 0.035370802373758385, 0.034035754190491777, 0.022426359288926636, 0.02133941913156637, 0.0425606815676604, 0.07340336191867079, 0.02182520440380488, 0.020837788370304873, 0.028305390251002142, 0.03990379627794027, 0.020804272133058736, 0.007493449824063906, 0.06482254700469119, 0.02956957902227129, 0.037357956636697054, 0.03940330206283501, 0.0916112723893353, 0.08640823872493845, 0.02147095823394401, 0.0543738710694015, 0.025367053724559288, 0.025161735813266466, 0.03282508486881852, 0.023745210841298103, 0.04633280022868088, 0.05138183697792036, 0.05157290565382157, 0.01072271163242736, 0.03847747156396508, 0.008589145627671053, 0.10600405186414719, 0.08117162436246872, 0.010703824610183281, 0.07765162217297725, 0.04894090563591037, 0.02957335506965007, 0.09402998510215964, 0.010720858383657677, 0.06529549269803933, 0.04951459003080215, 0.022191133250349333, 0.08617974205740861, 0.03680634159328682, 0.08699504937976599, 0.02181215787173382, 0.05055757299331682, 0.061010537269924364, 0.02542869184565331, 0.07036788122994558, 0.015711030523691858, 0.039217997541917224, 0.11932127869554929, 0.12427120522728988, 0.169577829805868, 0.13671656884253025, 0.2328417615166732, 0.4160456194409302, 1.2572707810572215, 3.9244515640395026, 3.7473233086722235, 4.3074045692171365, 6.3454128333500455, 7.480685080800738, 7.529695068086896, 8.082356521061488, 6.8222090772220065, 6.2791313614164075, 4.018663491521563, 1.9828017864908491, 1.1192439475229807, 0.5761532581278256, 0.28313179154481205, 0.22520616623972142, 0.5723797348993165, 0.17348852567374706, 0.6120298472898347, 1.0391989627054758, 1.417528701680047, 2.65076316680227, 2.753693997859955, 2.002399180616651, 1.4018872209957667, 0.4513448567262718, 0.08687407337129116, 0.04728386205221925, 0.05410108981387956, 0.03382260937775884, 0.026962757742564594, 0.033240714709141424, 0.06490034104457923, 0.038411419572574754, 0.04623488084013973, 0.0306878488377801, 0.005881375300564936, 0.03567804303020239, 0.08041790766375405, 0.03614833225895252, 0.025217424878584485, 0.043886644167027304, 0.060845761825995784, 0.08241564368030854, 0.049145853745618036, 0.030556464102119207, 0.09215914870479278, 0.01617125029276524, 0.06510704995266028, 0.018191768122570853, 0.041315698730094094, 0.05624921293929219, 0.005852355205986116, 0.02462433947117201, 0.049568438569882085, 0.04444230667182377, 0.026086555294958607, 0.004638545963514064, 0.05368054738002164, 0.01819980706620429, 0.027933196829898015, 0.05260339000129274, 0.03721690956237061, 0.014789232219170247, 0.013623366564778345, 0.04368216424648251, 0.06307276804000139, 0.01713145198300481, 0.06510502791830472, 0.03425742140305894, 0.008422528809335614, 0.007220009541405099, 0.06865177117288113, 0.05111311675448503, 0.052732939299728186, 0.04139830358326435, 0.04923256712832621, 0.05246372374572924, 0.0325544986740819, 0.06272862864924328, 0.030367210507392883, 0.04901124596861856, 0.03536088897713593, 0.04647875311119216, 0.054120909821774275, 0.013863218515845281, 0.03977120714262128, 0.0339947774607156, 0.013114622212015092, 0.03187286614307335, 0.09309450244264943, 0.043564499488898685, 0.019328789253320013, 0.03414161243875112, 0.03217141137325338, 0.006129832772005881, 0.0276398440889482, 0.040094074460544755, 0.03796095713706953, 0.020078017442886318, 0.017007300430642705, 0.047404946626297066, 0.06358188643519368, 0.06390511337667704, 0.030516864798430885, 0.05453169492206403, 0.04327329940029553, 0.022755399579182267, 0.006324300484266132, 0.0927007757127285, 0.041366731348846636, 0.0970058904162475, 0.045700982346066406, 0.020408587829609002, 0.03845125975619469, 0.03407690055402262, 0.021452995715662837, 0.07790327724069357, 0.03570168658292719, 0.03943017204957349, 0.033382223187280555, 0.07764779523547206, 0.03488606374178614, 0.0320392157882452, 0.006985104110624109, 0.056362901481666734, 0.0065466033993288875, 0.013494273581142937, 0.050338124590260644, 0.003216094836326582, 0.0318286629792835, 0.05474993214011192, 0.011621650092170706, 0.004830676546719457, 0.03842542114268456, 0.01317001526643123, 0.05863563756325415, 0.03346961510500737, 0.032320319275770865, 0.06342130433768034, 0.07242814424846854, 0.0420683874482555, 0.06388257922870771, 0.02960495783814362, 0.03716282692870923, 0.07066119834780693, 0.06336648549352374, 0.08424631080457143, 0.010538385050105197, 0.026013823126309683, 0.039100665266492536, 0.014384928824646133, 0.12585363031498023, 0.07256588007190398, 0.045640239891197, 0.029372369604451314, 0.07488131296953984, 0.06580009883535759, 0.048664724919945, 0.06928536681724445, 0.10427269512521369, 0.023658665396007042, 0.026645255940301076, 0.06923984390284334, 0.026776778079303246, 0.05955085238175733, 0.05334655887314251, 0.08117221468793494, 0.04535039687263114, 0.05220273542883141, 0.13574213827294962, 0.04716351029596158, 0.20156249137861387, 0.13114511780440807, 0.5798146330884525, 0.8929891596947397, 2.734862642628806, 6.307886047022683, 6.673369109630585, 6.997575095721653, 9.287188053131104, 12.351037911006383, 11.667813726833888, 12.993028010640826, 10.183526515960693, 8.834182875497, 4.993811462606702, 2.8424292249338965, 1.5239041021892001, 0.6559450136763709, 0.4837366257395063, 0.2837054250495774, 0.510704538651875, 0.27965397387742996, 0.8600915021130017, 1.4564586984259742, 1.8875118025711604, 3.347735447543008, 3.7831538660185675, 5.262033207075937, 2.70903879404068, 1.063279573406492, 0.22724992728659085, 0.08404859248548746, 0.030194119616810764, 0.09960172112498965, 0.027184312996853675, 0.04360620225114482, 0.030689860694110394, 0.040829487677131376, 0.04344142680721624, 0.07049532367714814, 0.04574762823592339, 0.032376983735178194, 0.10929992036627871, 0.029549518134444952, 0.04363251244649291, 0.0505930264480412, 0.03952884800466044, 0.018204078444146683, 0.05642489922632064, 0.05436039197125605, 0.02765787106805614, 0.030667981332434074, 0.02985451283997723, 0.03297474255253162, 0.03551309455984405, 0.026185614622331092, 0.04302986478433013, 0.05960585443036897, 0.010433476750871964, 0.0522352711829756, 0.0382526016661099, 0.06869005411863327, 0.03823570953682065, 0.07879378659916775, 0.04759674812001841, 0.023568706919572184, 0.035052006265946796, 0.02107017982884177, 0.054994632223887105, 0.03589942865073681, 0.018461002336282815, 0.018911318886759024, 0.08373315512601819, 0.016132867263097848, 0.0025516718617706957, 0.027650108627442802, 0.04890146578795143, 0.046409946267626116, 0.012869103645373667, 0.020324256104816283, 0.055370839179626534, 0.03546212300924318, 0.013448071283554392, 0.039418575886104784, 0.055439459426062446, 0.031563810405454466, 0.01566491898016206, 0.01891853171400726, 0.08529355496700321, 0.04162453055115683, 0.049934246976460726, 0.02950068057647773, 0.03232683660462499, 0.024148949355419193, 0.07018065306224994, 0.030236334672995975, 0.06894402299076319, 0.06684412674180099, 0.04148023668676615, 0.0521461591789765, 0.026446453661524823, 0.050030721085412164, 0.032267156057059765, 0.13317412749997207, 0.15299366042017937, 0.10251449554094247, 0.20010319325540746, 0.1243977112961667, 0.13102284579404763, 0.17145384342542716, 0.12213797255286149, 0.15059685760310718, 0.13392903842031956, 0.19886188129229204, 0.12313688466591494, 0.21539501127387795, 0.1364567849252905, 0.04943792914439525, 0.06929393671452999, 0.09168806898274592, 0.10035984830132552, 0.1711795117173876, 0.11626522482505866, 0.06913967177804027, 0.19731809198856354, 0.2384857615189893, 0.13066871836781502, 0.11857638295207705, 0.24531399511865207, 0.0849725129082799, 0.08814684900322131, 0.06933607373918806, 0.10654566530138254, 0.06544170342385769, 0.22484669195754187, 0.18849587467099937, 0.12212056134428297, 0.10303526438240494, 0.15826038138142653, 0.14057261550000735, 0.11664428162787642, 0.11289695663643734, 0.16264568535344942, 0.10819806092019592, 0.1760434407208647, 0.12680181515003952, 0.14036898714091095, 0.09756982087024621, 0.14432822540402412, 0.17225413476782186, 0.22294914163649082, 0.11507119318204266, 0.18498358742466994, 0.1208666693419218, 0.1856525143874543, 0.14886660687625408, 0.14348012448421546, 0.1457224791603429, 0.10697787175221102, 0.20376103983393737, 0.09782490932515689, 0.20323939568230084, 0.1459636033645698, 0.12564498079674585, 0.23359944085989678, 0.09523212523864848, 0.16780191367225988, 0.12647605048758642, 0.11275499353983573, 0.13001100080353872, 0.157564231593694, 0.1762498239321368, 0.11126365499304873, 0.1496987622231245, 0.22972497876201356, 0.16531234154743807, 0.3139166539268834, 0.2895535555269037, 0.8714033322674888, 1.998674294778279, 3.361770808696747, 8.113910027912684, 8.957661049706594, 8.645489777837481, 11.415704420634679, 13.985831788608007, 14.416730403900146, 15.759758131844656, 13.191183686256409, 10.90280316557203, 6.686103854860578, 4.514803520270756, 2.5429935668195998, 1.3978609570435114, 0.8615341218454498, 0.6725405688796724, 0.874814680644444, 0.6809363269380161, 1.603548805628504, 2.3184597066470554, 2.94667934519904, 4.165060298783438, 5.525573602744511, 8.735393387930733, 4.435763852936881, 1.6868803969451358, 0.42380198038050104, 0.20726247051996843, 0.1844320334494114, 0.21452028463993753, 0.10227693364556346, 0.10133068263530731, 0.21957526196326527, 0.16249777829008444, 0.12066343453313623, 0.1298932885485036, 0.1249836262847696, 0.10702645485954625, 0.275787817048175, 0.23692103262458528, 0.1040073132940701, 0.12660806626081467, 0.1214629794870104, 0.1499597132205963, 0.13551833028239862, 0.17941556977374212, 0.17765171799276555, 0.1250590793788433, 0.15938807944101946, 0.0879705927467772, 0.16410843043455056, 0.13087200745940208, 0.16661131541643823, 0.1475974071238722, 0.10878476300942046, 0.11991439972605024, 0.13655228194381508, 0.11128636556012289, 0.1128697202407888, 0.11466295937342302, 0.2872983222561223, 0.09131013176270894, 0.11686348915100098, 0.16778807155787945, 0.08655140282852308, 0.1507695854774543, 0.1258693587567125, 0.08256454140480075, 0.20334184089941637, 0.2477761815701212, 0.05310578750712531, 0.13534124621323176, 0.14735826424189977, 0.1502871470791953, 0.16438057725983007, 0.11628567587052073, 0.1642266855176006, 0.12094537940408502, 0.09722310983176742, 0.21752984529095037, 0.10999173431524209, 0.17277520895004272, 0.13067578870270932, 0.20983953295009478, 0.139058668166399, 0.1250125047351633, 0.1611228356403964, 0.1238480843603611, 0.0951699103627886, 0.135832424142531, 0.1638156697154045, 0.09446168943707432, 0.15938318041818483, 0.07067955950541155, 0.13354027856673512, 0.1169373816145318, 0.10671084108097212, 0.19994700806481497, 0.15927473695150443], [0.060331846188221655, 0.018216376891359687, 0.041209402826747725, 0.04589231225794979, 0.06254848438714232, 0.05748957156070641, 0.05919903197458812, 0.012428773434034415, 0.0312141782737204, 0.00936103519052267, 0.039816414538238726, 0.04920180913593088, 0.06297013961843081, 0.07232820282557181, 0.009392967896669038, 0.076536029178117, 0.009984867564136428, 0.021904920394133245, 0.05255289003252983, 0.024471814977005124, 0.009802988796894039, 0.03643433476931282, 0.07318245127264943, 0.011099770149615194, 0.019861909128459435, 0.05058939289301634, 0.021287933590688875, 0.033285691402852535, 0.05928917535181556, 0.012462958028273923, 0.06888187596840517, 0.06265434263540165, 0.032633358013949225, 0.010194602738400655, 0.026047822819756608, 0.047019827113087685, 0.04156311295394387, 0.0380434568173119, 0.04178162497867431, 0.02924183303756373, 0.0363334875021662, 0.02930190713543977, 0.019260521845093796, 0.03214124370632427, 0.09130624375705208, 0.03995947686157056, 0.021791956187891107, 0.016057634692905203, 0.04576362130631294, 0.06866464298218489, 0.04829043482563325, 0.07838341540523938, 0.025691312039270997, 0.0717384201873626, 0.07573486252554826, 0.046624298872692246, 0.01211750736859228, 0.01886605890467763, 0.04701654978894761, 0.027612907945045402, 0.021481948804908564, 0.022272265682529126, 0.05520056081669671, 0.0632620250274028, 0.039257393285099945, 0.03586803622809904, 0.10162421688437462, 0.03322671653170671, 0.026036983222833703, 0.0570065224809306, 0.06640200689435005, 0.07729999175561325, 0.38503941893577576, 1.0830671744687217, 4.410834584917341, 7.550220915249415, 11.660956723349434, 22.412338665553502, 32.39508656093052, 42.147425242832725, 45.465603487832205, 36.097778115953716, 52.08610766274588, 46.62934684753418, 51.649976185389924, 45.24367107663836, 33.13933590480259, 30.343002114977153, 22.382951259613037, 11.672535027776446, 9.537078278405325, 9.521141716412135, 6.629103439194815, 8.129866565976824, 8.827677624566213, 11.293605463845388, 14.280808006014142, 16.764309576579503, 16.726763248443604, 18.6976249899183, 27.058691126959665, 26.41874466623579, 17.505473920277186, 9.415630715233938, 2.1807600898402075, 0.21938075311481953, 0.11937158528183188, 0.029199143006865467, 0.029543265434248105, 0.02817066542671195, 0.04660750852365579, 0.0320103984060032, 0.029537630200918232, 0.03520263086206146, 0.05805725431335824, 0.09993651030319077, 0.03098400223201939, 0.06595347489097289, 0.09984136612287589, 0.043962521345487664, 0.03164015577307769, 0.0064607992535457015, 0.023727994711537446, 0.034656376245298555, 0.04674120367105518, 0.0661718478160245, 0.1324789955147675, 0.039448343217372894, 0.05158449163926499, 0.025715138796450834, 0.03183579777500459, 0.050542689327682765, 0.034449138079902956, 0.05894242360123566, 0.04613148906667318, 0.010560144819984478, 0.026690719482888068, 0.023372769754912173, 0.039015376807323525, 0.07653287399028029, 0.02300641852031861, 0.0484138128480741, 0.03394428088462778, 0.016092328188408698, 0.009928619555596794, 0.003950394831398236, 0.013802775464552854, 0.027761196684358374, 0.03815965593925544, 0.02673361137775438, 0.04860420298895665, 0.07409793071980987, 0.02796018386392721, 0.04770680310736809, 0.044452552550605366, 0.02969584081854139, 0.022624983452260494, 0.04484541754105261, 0.017600808226104294, 0.013916195137426257, 0.04201722251517432, 0.010169895582034119, 0.04280089992763741, 0.037575997079589536, 0.03528521196650607, 0.045057473305080614, 0.06776132288255862, 0.011476938080574785, 0.04491429223812052, 0.034857785794883966, 0.02773249804574464, 0.027540014624329548, 0.05696659069508314, 0.06902712317449705, 0.04951045096718839, 0.020421539366777455, 0.049753417393990924, 0.03728643226038132, 0.052108609051044495, 0.01885772479831108, 0.11941521508353097, 0.047072600174163065, 0.0373118467895048, 0.03208463013704334, 0.035497919124151976, 0.02220534346997738, 0.043984465167990754, 0.01694103130804641, 0.04407188083444323, 0.061448205927652974, 0.04566863318905234, 0.0460819288689111, 0.01812009107587593, 0.020644757031862224, 0.005718797461928001, 0.07206656650773116, 0.006656030317701931, 0.12768441279019627, 0.026241488588441695, 0.019939757451148968, 0.035426696695919545, 0.031329420661287646, 0.03115179037143077, 0.054129988620323796, 0.05453738783087049, 0.02742162553061332, 0.06817207405609743, 0.016891087737998793, 0.009236746234819293, 0.041009041613766124, 0.017303233301000934, 0.057897561096719334, 0.04497382011530655, 0.043344107922166586, 0.049382452121270556, 0.08745514361986093, 0.0296329304442874, 0.03793866726170693, 0.019856195863602415, 0.029950186277606657, 0.11952979250677995, 0.045313508316342316, 0.07622231529759509, 0.02871787508151361, 0.0658283598188843, 0.06669273200844016, 0.06418949418834277, 0.04542484912755234, 0.05632390268146992, 0.03960074218256133, 0.06312530022114515, 0.07699936003025089, 0.017297847429290414, 0.03172047057056001, 0.036672398780605624, 0.019021156742902737, 0.0737240036417331, 0.013463147483499987, 0.034333128947764635, 0.024171994100990038, 0.0857484991263066, 0.04175905351127897, 0.058332474902272224, 0.04290046476359878, 0.035658562289816995, 0.040750594410513125, 0.14619773865810462, 0.26247476999248776, 0.8128314294985363, 2.097741710288184, 6.553033692496164, 11.319514427866254, 17.267548492976598, 29.383817195892334, 41.27105590275356, 52.896493434906006, 58.843119621276855, 51.50455386298043, 64.70755209241594, 58.68896688733782, 62.2387181690761, 56.45593745367867, 44.25044693265642, 38.34365824290684, 28.908228635787964, 14.793116058622088, 12.435809407915388, 10.992887428828649, 8.0168445621218, 10.13693710735866, 10.657669850758143, 13.957313776016235, 18.45350524357387, 21.907447814941406, 23.66600387437003, 26.33608021054949, 35.88463865007673, 34.708982603890554, 24.0129291670663, 13.34965819971902, 3.994922365461077, 0.515895385827337, 0.09158257714339665, 0.04334783307941897, 0.03569531513910208, 0.05158095307914274, 0.067084891322468, 0.01609291342486228, 0.030420048029295037, 0.08801608851977757, 0.0202350609802774, 0.04936777880149228, 0.04422911436163953, 0.07100117153355054, 0.046985761262476444, 0.03841086995920964, 0.07757736330053636, 0.013605132632489716, 0.022407628329736844, 0.06814018291022096, 0.01919428495291088, 0.01463092491030693, 0.017276777220623832, 0.027552565825836997, 0.07236383269940104, 0.1088983022740909, 0.028504051733762026, 0.05554833036980458, 0.08782330315027918, 0.0566370296292007, 0.0616720478449549, 0.028084790034751807, 0.030378084031066725, 0.007149590329000992, 0.020485090956624066, 0.014076947716863027, 0.01815438932473106, 0.03938753630167671, 0.01722254022024572, 0.028491946669029336, 0.010582713742873498, 0.008751273088689362, 0.04405082928548966, 0.01610023821038859, 0.02963700165439929, 0.04378096233787281, 0.017599546150969606, 0.07874136976897717, 0.039939626319600005, 0.032335196156054735, 0.03332343152058976, 0.0548164624986904, 0.051463610625692775, 0.03153440269774624, 0.01741475222765335, 0.02276510602262403, 0.048380411961781125, 0.0041049426321738535, 0.014413088027920042, 0.02282332771989916, 0.07041107676923275, 0.04281048423477581, 0.014616735046729445, 0.03712520216192518, 0.019824462477117777, 0.004958760633599013, 0.02143580842364047, 0.031044069544545243, 0.03474840594987784, 0.08205764181911945, 0.030802952125668526, 0.04343935388273426, 0.13624732116503374, 0.08877791371196508, 0.20158328169158526, 0.10445936010884387, 0.21420724929443427, 0.09004099307847874, 0.0993349618677582, 0.09466679700251136, 0.11524782941809722, 0.14005462186677115, 0.14958638325333595, 0.09915273450314999, 0.24115916235106333, 0.19357685345624173, 0.09506933111697435, 0.13646207749843597, 0.17946586278932436, 0.1278151393468891, 0.16046264820865222, 0.14870176357882364, 0.07973902659224612, 0.2841946216566222, 0.14652651601604053, 0.08420821106327431, 0.0896235244082553, 0.09063415482108082, 0.07523181701877288, 0.11279550208044903, 0.20238152385822364, 0.07945992478302547, 0.22896681087357657, 0.16349173709750175, 0.09437131535794054, 0.13744663181049482, 0.13499657756515912, 0.17613106673317297, 0.17918101378849574, 0.1486028331731047, 0.1289953560169254, 0.12044331777308669, 0.13540053660316126, 0.1339772144066436, 0.0759896659957511, 0.218500747478434, 0.1871696644063507, 0.22212698789579527, 0.17085264782820428, 0.13743209759039537, 0.10144521256110497, 0.16553129122725554, 0.17003520312053816, 0.2517199899469103, 0.08210384326853923, 0.16540486658258097, 0.12222128308245114, 0.1064361904614738, 0.08785041062427418, 0.1617124690009015, 0.15374805565391267, 0.1260152980685234, 0.1576086077839136, 0.13379314142678464, 0.1846349968441895, 0.118681935859578, 0.17188043839165143, 0.13768352195620537, 0.2782631670790059, 0.06703345836805445, 0.13047340884804726, 0.22490333606089863, 0.2594981725726809, 0.43157978302666117, 1.0735816891704286, 2.690882933991296, 8.420487131391253, 13.597377112933568, 21.43585968017578, 35.8572974886213, 48.1992541040693, 59.628134046282085, 68.03457192012242, 59.921021461486816, 72.96992601667131, 66.71268408639091, 69.33195345742362, 65.22889627729143, 53.23830311638968, 45.273030689784456, 36.062088693891255, 21.06039639881679, 16.86951051439558, 14.409418293407985, 11.875765493937902, 13.244825516428266, 14.317735075950623, 17.313729694911412, 22.950985601970128, 27.049297162464686, 29.63006135395595, 33.24140494210379, 42.7178966658456, 39.56883757455008, 27.64865745816912, 15.989590644836426, 4.968860047204154, 0.6414922177791595, 0.22266412978725775, 0.1812447780477149, 0.17196476672376904, 0.1486686917820147, 0.1360929680189916, 0.12740458494850568, 0.20129079238644668, 0.15245073741035803, 0.15981023678822176, 0.17035032835389885, 0.1388268263212272, 0.14672520464020117, 0.11346860203359808, 0.25122240664703505, 0.2118882065904992, 0.06513835755842072, 0.08272179189537253, 0.17802762639309677, 0.17587866527693613, 0.1044618571177125, 0.22929500469139644, 0.09384425649685518, 0.21747564391366073, 0.14944095962813922, 0.11348757387271949, 0.23166010635239737, 0.23603597868766102, 0.15134400608284132, 0.12239591085485049, 0.1402195737298046, 0.13784243485757283, 0.05774278725896563, 0.13983940412955626, 0.20900502987205982, 0.08588074560144118, 0.1305090726486274, 0.08210817910730839, 0.11012173483946494, 0.1300279234669038, 0.0924692867057664, 0.10972644747900111, 0.10762445455683128, 0.12945570131497725, 0.141833292852555, 0.0932287641667894, 0.21826533653906413, 0.11488912866583892, 0.1469647546431848, 0.17583308129438333, 0.12529572525194713, 0.14706738985010556, 0.17728249994771822, 0.09462620703769581, 0.0949780885130167, 0.22557713490511688, 0.10198180483920233, 0.13827046831803663, 0.1558412140501397, 0.10292556562594005, 0.1233171849910702, 0.07213188228862626, 0.12498570260192667, 0.18485761061310768, 0.0793974588492087, 0.09652769964720521, 0.12260373256036214, 0.146226969946708, 0.2006191105714866, 0.10197983030229807, 0.10075447748282126], [0.017947410698980093, 0.02875691798648664, 0.0917941036501101, 0.08866517511861664, 0.07477267272770405, 0.06243542688233512, 0.02984703877674682, 0.047848162307803116, 0.032716213925076384, 0.1046383169346622, 0.06125296426138707, 0.03965127607807517, 0.09564075259757893, 0.023783027294224927, 0.08250120016080992, 0.02260596920470042, 0.04983806463756731, 0.021276797134695307, 0.02933586442044803, 0.0927775383793882, 0.03998990576448185, 0.07288414692240101, 0.031312213013214726, 0.03649977607918637, 0.03155378844322903, 0.05100303801840969, 0.050738728272595575, 0.0442735109079097, 0.04330904123240283, 0.03886250626029713, 0.01568804175726005, 0.013783364274006869, 0.0247709115168878, 0.008250588883778878, 0.03073310373084886, 0.02416286101963903, 0.012234545329452624, 0.04099045653960534, 0.0048476751211897606, 0.02639436931349337, 0.07139123417437077, 0.06789014954119921, 0.022796311848131672, 0.016564771765843034, 0.00748996130589928, 0.07505291447575603, 0.07465772211019482, 0.012783776170441082, 0.01802733024981405, 0.01371797894327236, 0.039738274445491176, 0.06288452206977777, 0.01972772882852171, 0.02376000120836709, 0.0590371403044888, 0.026815430826640556, 0.04792069770129664, 0.044209382563297234, 0.04685652069747448, 0.0579589753012572, 0.0514712305739522, 0.034556536602654626, 0.012758626269974878, 0.07169663600091424, 0.0771592975194965, 0.030351875615971427, 0.13635405472346715, 0.20673332177102566, 0.3413202134626252, 1.2245935116495406, 3.467658532517297, 10.00849791935512, 14.059035403387886, 24.824942554746354, 32.46514524732317, 42.71893889563424, 54.81875426428658, 59.15757424490792, 56.65547929491316, 61.902772767203196, 66.01266697474888, 71.3320619038173, 62.702475684029714, 69.42601122174943, 72.55588981083461, 69.86446339743478, 68.6786629813058, 65.7050632749285, 57.97210386821202, 52.276547363826204, 38.44510889053345, 42.96902888161795, 32.820691517421174, 32.27353824887957, 43.22527149745396, 43.865249225071494, 56.95055539267403, 55.83104426520211, 61.88240759713309, 65.57840456281389, 63.025907380240305, 64.50374753134591, 50.435337271009175, 42.854338441576274, 32.18588324955532, 10.289166058812823, 0.5801611202103751, 0.06470791529864073, 0.06124269124120474, 0.03360471821257046, 0.07258204277604818, 0.07007927993046385, 0.01594453986867198, 0.04365436466676848, 0.018945376255682538, 0.04121382348239422, 0.03817939113027283, 0.08346560876816511, 0.022433110712362186, 0.028288545619164194, 0.02491162610905511, 0.047694175570671044, 0.007466083658593041, 0.016840355370991995, 0.03895205252670816, 0.014650062990507908, 0.026791434435706054, 0.09480309433170728, 0.015040310532120722, 0.009842639838877534, 0.08599625261766569, 0.0935952477157116, 0.025899651127734354, 0.016135252313688397, 0.012770490454775947, 0.08070423587092332, 0.059536067103700976, 0.03574296186811157, 0.01194418068709118, 0.07395797608686344, 0.03569559333845973, 0.040893839938299995, 0.018315750041178296, 0.05219905437635524, 0.029457162733056715, 0.03479861414858273, 0.03667027835867234, 0.005112358909432909, 0.05575196212157607, 0.026727109315938184, 0.06250270362943411, 0.09016433038881846, 0.046424385492822955, 0.03145031863823533, 0.055868687108159065, 0.02621938191753413, 0.04612337039517505, 0.05629885456125651, 0.03461485668750746, 0.05864162224211863, 0.02530206703314824, 0.06891814366515193, 0.05976671472723995, 0.03587179531210235, 0.043466712414686165, 0.006727175986660379, 0.08280159439891577, 0.024380731828776852, 0.07089873988713537, 0.03698029761601772, 0.03729204374498554, 0.06944273944411959, 0.07372994760849647, 0.015416213843439306, 0.012200513405592313, 0.04317056580579706, 0.04621627880260348, 0.04989453910716942, 0.014112731957409, 0.013782818053316857, 0.07026583634849105, 0.02873056029368724, 0.046541958648179255, 0.05997143552771636, 0.0328982886193054, 0.020443311859188334, 0.045443305280059576, 0.02057736663014761, 0.0435136365039008, 0.07147040564034667, 0.021942816574924758, 0.06790350989571639, 0.03369927206741912, 0.042151531736765585, 0.02214721167859222, 0.035690385582191606, 0.04954099522105285, 0.03860056460169809, 0.03878401332933988, 0.04726359421121223, 0.014291014489052551, 0.0470372417143413, 0.030408465436526706, 0.07847747392952442, 0.05035409391192453, 0.04136115379099335, 0.04068034907270755, 0.05902015657297202, 0.0029472155812462525, 0.053233460656234195, 0.01703594987546759, 0.026519302877464464, 0.05954088470233338, 0.013590592475208853, 0.01856819729852889, 0.0703586395829916, 0.0718496727890202, 0.006729932535173637, 0.033007078138845306, 0.021770585727478777, 0.0258335109267916, 0.037327242749077935, 0.07214524942849364, 0.018746141410831894, 0.07008321543357202, 0.025090662662738135, 0.09014336365674223, 0.010639124599817609, 0.08170482396547284, 0.023880451352202466, 0.05712360369839838, 0.030556260541613613, 0.036944131699523756, 0.026836009097418616, 0.03474552556872368, 0.03967411895947797, 0.0810869431921414, 0.03475859076050775, 0.09741852113178798, 0.05409748340025544, 0.03647655321817313, 0.09228846390864678, 0.13047046400606632, 0.38563522696495056, 0.7443896649139268, 1.4159913041761942, 4.7270049793379645, 13.915274568966456, 19.98121609006609, 32.777258328029085, 42.683565616607666, 54.86757230758667, 68.68039308275495, 74.29384967258999, 68.69542203630719, 72.02637454441616, 74.50453295026506, 82.52000958578927, 74.0013860974993, 79.464601789202, 84.48342459542411, 82.53014700753349, 78.36005360739571, 75.51510674612862, 66.4135432924543, 61.4815799168178, 46.47751481192452, 51.085532324654714, 39.337764808109824, 39.22853217806135, 50.9604925428118, 53.044559546879356, 67.97982706342424, 68.25883892604283, 76.07555539267403, 78.58636338370187, 76.46178490774972, 75.15700353894914, 62.73604243142264, 53.5753949710301, 41.55228771482195, 15.620031595230103, 1.6927996107510157, 0.04355578709925924, 0.05603277723171881, 0.10595044081232377, 0.05303337085726006, 0.08604875087205853, 0.03638588058363114, 0.012302388653292187, 0.018338401236438324, 0.0336436084471643, 0.03845036748264517, 0.004756996549466359, 0.007670406667914773, 0.05413036181458405, 0.043751632661691735, 0.02381990397615092, 0.02364897252326565, 0.017418406138728772, 0.0858209463102477, 0.04616484584818993, 0.04233126887785537, 0.030916053735251938, 0.005357240077241191, 0.041933949305010695, 0.07154568231531552, 0.06328600445496184, 0.017375902705160633, 0.03690366726368666, 0.015776439603152018, 0.04096826505182045, 0.04598404001444578, 0.03510151557358248, 0.05587511622746076, 0.030218597767608504, 0.016632886503690054, 0.05372456394668136, 0.04866921003641827, 0.04549122003040143, 0.013586070039309561, 0.018173457855092626, 0.07233597883688551, 0.0401040930300951, 0.02456502363617931, 0.056825502908655574, 0.053981389451239786, 0.09516445494123868, 0.024754112686163614, 0.010367094821828817, 0.017818002196561013, 0.01484760149781193, 0.05277565986450229, 0.018173144032646502, 0.031544631613152366, 0.004233885065851999, 0.03473878093063831, 0.0291669465202306, 0.09575168628777776, 0.06905012551162924, 0.031207881468747343, 0.016240494791418314, 0.05269037479800837, 0.034818688607109446, 0.01191323864207204, 0.039594221461032114, 0.029584347336952175, 0.02945427895922746, 0.06809625455311366, 0.024013990436547568, 0.043330242059060504, 0.018746662186458707, 0.1262823694518634, 0.19212879187294415, 0.17662324889429978, 0.288945452443191, 0.17178859189152718, 0.14208824560046196, 0.12451783913586821, 0.07133682245122534, 0.18933188409677573, 0.23112305945583753, 0.1759101085897003, 0.09851928135114056, 0.17964899939085754, 0.1169769809182201, 0.17485755149807247, 0.15682571407939705, 0.17076861805149487, 0.1460151991673878, 0.16503883765212127, 0.1718762857573373, 0.27022342277424677, 0.2117979342916182, 0.1453122640294688, 0.08997847286186048, 0.11809682154229709, 0.11218695116362401, 0.16205066442489624, 0.14225004906100885, 0.1475089125867401, 0.11964299928929124, 0.08824677685541765, 0.11960653481738907, 0.10954256448894739, 0.10323877060519797, 0.11802809951560837, 0.1472332373793636, 0.10736499633640051, 0.09180677868425846, 0.06466087925114802, 0.11995509825646877, 0.1423145370291812, 0.13806589000991412, 0.2679400438708918, 0.12678975079740795, 0.07035822567663022, 0.13734881420220646, 0.2339815374995981, 0.12992463686636516, 0.13403400778770447, 0.12469115055033139, 0.13902385931994232, 0.15035171647156986, 0.13977492973208427, 0.07836210940565382, 0.07452443747648171, 0.19804181743945393, 0.10496253453727279, 0.11241297796368599, 0.08695241023919412, 0.11108699161559343, 0.13729320147207805, 0.20081322586962155, 0.19616496243647166, 0.15419879289610045, 0.17463592839028153, 0.18918194142835482, 0.2548670625048024, 0.7316353778753961, 1.2643534924302782, 2.3470317849091122, 6.236257067748478, 17.09725856781006, 22.945100477763585, 36.04955414363316, 47.337576729910715, 61.464452607291086, 80.41109929765973, 84.47903333391461, 80.80137266431535, 84.11752550942558, 86.7274078641619, 93.33477646963937, 87.943849836077, 92.19015107836042, 96.05291175842285, 93.34868676321847, 89.67934308733258, 86.32819216591972, 77.07709653036935, 71.53029400961739, 56.63860559463501, 59.12599468231201, 49.78188003812517, 49.440049512045725, 61.14542606898716, 61.11601434435163, 78.68484020233154, 79.22138704572404, 86.97737625667027, 90.9850972039359, 87.57389995029995, 86.05308519090924, 73.39084093911308, 61.370235034397666, 45.09765468324934, 17.01639195850917, 2.089787542819977, 0.2117043507418462, 0.1310838596629245, 0.18706419292305196, 0.1739531864545175, 0.17701674492231437, 0.11218016581343752, 0.10247502515890769, 0.08284178402807031, 0.12427971405642373, 0.18901887589267322, 0.1333767380565405, 0.13475899531372956, 0.11989643211875643, 0.13910111731716565, 0.11332583826567445, 0.17666202038526535, 0.15063204642917427, 0.19366750573473318, 0.1014660368008273, 0.12211737222969532, 0.2551683320530823, 0.11971694603562355, 0.11518562132758753, 0.13915337808430195, 0.13941898383200169, 0.1309341069843088, 0.09159494683678661, 0.14674098736473493, 0.14041085275156157, 0.15985913202166557, 0.09879262918340308, 0.07856064196676016, 0.18628982161836966, 0.09248654185129063, 0.13988156829561504, 0.16975466960242816, 0.1283126412225621, 0.09440048557839223, 0.08341818595571177, 0.13534083909222058, 0.18855504292462552, 0.10675617400556803, 0.18195447139441967, 0.10417209552334887, 0.323363082749503, 0.125608855592353, 0.0708211629784533, 0.12715268560818263, 0.10889923186706645, 0.11307809155966554, 0.11019415488200528, 0.11375164613127708, 0.1537988507854087, 0.12712415999599866, 0.15956395571785315, 0.15149496655379022, 0.21075193184827054, 0.06023742804037673, 0.1568075836236988, 0.18719097040593624, 0.2476359690938677, 0.14593822615487234, 0.06967017759702035, 0.0872021789795586, 0.20202527940273285, 0.21342080006642, 0.09559351977493082, 0.1355495700346572, 0.12285937741398811], [0.064502746665052, 0.016747523298753158, 0.02919624905501093, 0.06504117098769971, 0.031487407362354655, 0.041362113918044736, 0.016558988951146603, 0.041530315963817496, 0.029017129380788122, 0.020095141970419457, 0.028848700025784116, 0.02301969745063356, 0.03272178130490439, 0.018385712090613585, 0.04653637430497578, 0.038981891104153225, 0.02209436397866479, 0.05500438277210508, 0.025506228042234267, 0.05298538486074124, 0.05891501757183245, 0.029707579474364008, 0.046557283361575434, 0.030453828895198445, 0.015271697758830019, 0.03101739633296217, 0.026055726056386317, 0.043336847597467046, 0.0783918903076223, 0.07181605816419635, 0.039395590512348075, 0.0664368225261569, 0.030812967302543775, 0.08594581032437937, 0.029675817250141075, 0.02053947214569364, 0.029468518016593795, 0.01921100914478302, 0.06279073495950017, 0.0452333936866905, 0.04168862157634326, 0.04139707882755569, 0.006420875525301588, 0.022105912644682185, 0.011311804709423865, 0.03652656464172261, 0.08823966580842223, 0.03600824870435255, 0.025492966075294783, 0.02750260698875146, 0.01917076692916453, 0.04866631608456373, 0.059608392151338715, 0.06741142951484237, 0.06548540107905865, 0.026794694796470658, 0.031109656739447798, 0.0323868224929486, 0.03636066961501326, 0.052613116800785065, 0.06685773815427508, 0.09339534451386758, 0.3031493345541613, 0.27056008470909937, 0.33908726328185623, 0.6505391523241997, 4.214944890567234, 6.324221696172442, 9.550181712423052, 13.553398489952087, 21.96017943109785, 33.58637605394636, 50.33945560455322, 58.57803889683315, 63.95174789428711, 66.28326456887382, 63.1959228515625, 63.628149441310335, 57.3275021144322, 58.3624849319458, 56.875268186841694, 53.92861359460013, 58.05347769601004, 50.92902762549264, 42.74931641987392, 59.76207447052002, 54.25781576974051, 59.81547137669155, 62.17990861620222, 64.43563434055874, 65.655182157244, 64.22186606270927, 65.64865779876709, 64.1327623639788, 60.345862116132466, 67.99443912506104, 71.47784205845424, 66.72660827636719, 64.39952455248151, 63.373442377362935, 63.05483967917306, 64.64768641335624, 66.31733158656529, 62.69476318359375, 62.8947879246303, 44.12040444782802, 19.083547047206334, 5.151717526572091, 0.3391267811613423, 0.29372755012341906, 0.05712807524417128, 0.04258754816172378, 0.03305165110422032, 0.025145790240328227, 0.009058640122280588, 0.08604234550148249, 0.09084897900798491, 0.019707320191498314, 0.011952948207700891, 0.0386413242002683, 0.0453007654286921, 0.008502786779510123, 0.0071167110665036094, 0.01575532868238432, 0.025689188224662627, 0.03645190543362072, 0.03261659141363842, 0.03266817025308098, 0.08004809929324047, 0.02756127482280135, 0.012188479587036585, 0.027871394164061973, 0.03151206871760743, 0.043574002371834855, 0.012758999464235135, 0.03199891759348767, 0.04391265580696719, 0.0051296170235478455, 0.038128579035401344, 0.021202879226101295, 0.015490528695019228, 0.05011851673147508, 0.0632807050964662, 0.02632576603043292, 0.03548478947154113, 0.0977318821741002, 0.017878692064966475, 0.009395533607208302, 0.021579181176743338, 0.05736524358923946, 0.01000059855037502, 0.02872636016192181, 0.032867839360343556, 0.01571863520491336, 0.03849778350974832, 0.04858435923233628, 0.04784850496798754, 0.02307991573720106, 0.026388964782069837, 0.04817884634914143, 0.06737156558249678, 0.03736213641241193, 0.020739282048972588, 0.03800373198464513, 0.037165045738220215, 0.1014347088390163, 0.009141708075601076, 0.06465704552829266, 0.01859855665160077, 0.06899902503937483, 0.0406781675826226, 0.04012464585580996, 0.06365470681339502, 0.03363279259896704, 0.04263541541461434, 0.014765341001163636, 0.055069050552057366, 0.1139970315354211, 0.03709415579214692, 0.07199907941477639, 0.016641642998105714, 0.009584763453208973, 0.005068308416022254, 0.05751811752894095, 0.039045703929982016, 0.03920829449115055, 0.062368204418037615, 0.041163062277649126, 0.0005040213779596213, 0.03230431602735605, 0.06652033661625215, 0.03945027364950095, 0.022600154159590602, 0.024761293282998458, 0.016522426091666733, 0.04828430426173976, 0.0074599726025813395, 0.04808400072423475, 0.04764429306877511, 0.06657932166542326, 0.012073294874945921, 0.0081595345732889, 0.012131208686956337, 0.02739024498233838, 0.10186755311276231, 0.07220509621713843, 0.05405040324798652, 0.027241216639855077, 0.04377280973962375, 0.028054137215284363, 0.01673203573695251, 0.03334335670141237, 0.016191947307171564, 0.005853780977694052, 0.09336416582976069, 0.04668890219181776, 0.06142250302114657, 0.028875067896608795, 0.008656636961469693, 0.04559815036399024, 0.011874185559073729, 0.01523421039538724, 0.08017715665378741, 0.039683421674583635, 0.009252755420415528, 0.05676276556083134, 0.007821608018795294, 0.05479292072621839, 0.07636133355221578, 0.02349869567634804, 0.03561567887663841, 0.03011677341003503, 0.011165433679707348, 0.010267536771217627, 0.05011033359915018, 0.034380867279001644, 0.038668798083173375, 0.05363386756341372, 0.31211747761283604, 0.32845369673201014, 0.5645289761679513, 1.0306735230343682, 5.783247547490256, 7.488524385860988, 13.305644835744586, 20.590930938720703, 30.37619365964617, 44.70699221747262, 63.72713347843715, 69.27003111158098, 76.03977911812919, 77.29292147500175, 72.96390192849296, 75.06743431091309, 69.07316780090332, 69.58964129856655, 65.00679016113281, 62.75483730861119, 68.87430340903146, 59.54215703691755, 52.58874034881592, 68.31425775800432, 63.73820195879255, 71.30469989776611, 69.68803473881313, 73.82793821607316, 75.0097017288208, 74.26297187805176, 75.49100344521659, 72.98799133300781, 69.76053919110979, 76.39271981375558, 80.08977290562221, 74.67247091020856, 72.86171477181571, 70.03656332833427, 71.07791764395577, 72.91487543923515, 75.15701743534633, 69.72693770272392, 70.49563080923897, 55.05995750427246, 28.30441801888602, 10.422468117305211, 0.6276835958872522, 0.2602185867726803, 0.051614370928811174, 0.05690665908956102, 0.008506255789792963, 0.03372087662241288, 0.05178252886980772, 0.021404882493828024, 0.02493834851442703, 0.008666119488355304, 0.01747817998485906, 0.043711259828082154, 0.009965556457505693, 0.0474820417751159, 0.0107680496460359, 0.0025073340511880815, 0.0060354481268275, 0.037987915333360434, 0.009141633436749024, 0.09098047230924879, 0.058518563131136556, 0.033131484141839404, 0.0158980653089072, 0.009507763299292751, 0.0064878388740388405, 0.05637243150600365, 0.04839843385187643, 0.02692770123082612, 0.023374274406316023, 0.03166146516533835, 0.0666238810600979, 0.05259519669094256, 0.08293308091482945, 0.01969869601141129, 0.040396409308803935, 0.0253988261268075, 0.005059563795969422, 0.07253936970872538, 0.03196130639740399, 0.01621715149043926, 0.03927081470776882, 0.06628466104822499, 0.05009733626086797, 0.041986345779150724, 0.021458931200738465, 0.05759905997131552, 0.05064078513532877, 0.024825245208506073, 0.05527341851432409, 0.013944421346033258, 0.10541329213551112, 0.04990811998556767, 0.037247341857956986, 0.008215975116140075, 0.02445556575964604, 0.02402049589103886, 0.032719691417046955, 0.05415626488892095, 0.03681066386135561, 0.037352477466421466, 0.010695191100239754, 0.04756930137851408, 0.03640380408614874, 0.048534005148602385, 0.05044334840827754, 0.04592184888731156, 0.03377954276012523, 0.035115235551659546, 0.12375854487930026, 0.23061548812048777, 0.1352323820548398, 0.1983214688620397, 0.171433243102261, 0.09758710994252137, 0.12044561122144971, 0.11914859153330326, 0.0845950303067054, 0.10933520418724843, 0.10926457547715732, 0.09950549128864493, 0.09116011445543595, 0.1290801050407546, 0.1447866843747241, 0.16807984161589826, 0.0921777066375528, 0.1505612073732274, 0.12375561360801969, 0.15629347121076925, 0.11546345427632332, 0.11144329035388571, 0.1587983646563121, 0.13426652816789492, 0.06501047406345606, 0.06941388134977647, 0.06270958895662002, 0.16676467790135316, 0.1887434178165027, 0.17181200134967053, 0.13386331551841327, 0.11132444494536944, 0.16140834960554326, 0.23578247800469398, 0.10881841834634542, 0.08649496228567191, 0.11503091534333569, 0.07477985841355153, 0.1831563604729516, 0.16250038386455604, 0.12406193145683833, 0.06162070988544396, 0.16977337002754211, 0.15314432233572006, 0.08160054670380694, 0.06800820106374365, 0.12600760348141193, 0.15172748693398067, 0.10893603560647794, 0.14957590667264803, 0.12909002522272722, 0.09644404985010624, 0.18254523112305573, 0.137893854241286, 0.0766848319077066, 0.2034483708973442, 0.11963284840541226, 0.1670634640114648, 0.19502032814281328, 0.09454105089285544, 0.21521984067346367, 0.2265845558473042, 0.4640384827341352, 0.5723083530153547, 0.8074530895267213, 1.3283675717456, 7.409254125186375, 10.05014021056039, 16.704466479165212, 26.2816549709865, 36.7815294946943, 52.683416502816335, 72.16456031799316, 79.08192975180489, 86.63385731833321, 89.72335297720772, 85.51955386570522, 88.24267101287842, 82.06554181235177, 81.51070731026786, 78.49521691458565, 74.87685911996024, 79.28400421142578, 72.32458427974156, 64.57148551940918, 80.4380305153983, 75.54734638759068, 79.97776099613735, 81.81022330692836, 84.92314829145158, 84.38329410552979, 83.80501638139997, 85.07766233171735, 82.67790739876884, 80.24082674298967, 87.06132439204625, 90.39747415270124, 85.99677698952812, 81.85507392883301, 82.59479304722377, 81.779602595738, 83.01326220376151, 85.98078223637172, 80.72297613961356, 81.59472492762974, 63.21210520608084, 33.41805246898106, 11.83445497921535, 0.9970656292779105, 0.5072523696081979, 0.14316757768392563, 0.24760597784604343, 0.06871359249843018, 0.12229065650275775, 0.1126426484967981, 0.09558548592031002, 0.2034891237105642, 0.0820577232433217, 0.0690685205959848, 0.27372395779405323, 0.15749793872237206, 0.1571350989065, 0.11196823897106306, 0.10758562878306423, 0.06820874887385539, 0.14451987083469117, 0.15427184397620813, 0.18278141559234687, 0.13040297691311153, 0.11892444427524294, 0.08383602103484528, 0.12753026320465974, 0.0749965010743056, 0.12066838783877236, 0.1614811292716435, 0.17012547541941914, 0.09693031518587045, 0.13203702494502068, 0.11760219665510313, 0.09786269015499524, 0.16741936919944628, 0.08311299447502409, 0.14337078535131045, 0.16466170788875648, 0.13495408770229134, 0.2359344427074705, 0.06046937845115151, 0.12202472505824906, 0.13874275583241666, 0.1957320435238736, 0.12197802827826568, 0.167000305971929, 0.18684760454509938, 0.20628386017467293, 0.12003359118742601, 0.17401542168642792, 0.12623346064771923, 0.08403020418648209, 0.1728604193776846, 0.11551490080143724, 0.17676970389272484, 0.09488244221678802, 0.18730136805347034, 0.13540079444646835, 0.14263035436826094, 0.2191117275506258, 0.10601906105875969, 0.16198050390396798, 0.08958399974341903, 0.1180346134517874, 0.11668546870350838, 0.1426652174975191, 0.15661158199821199, 0.17923631439251558, 0.1384314711072615, 0.11235763664756503], [0.022337103096236075, 0.02505897168469216, 0.05056992233065622, 0.03109169252482908, 0.04254241201228329, 0.025178543125678386, 0.0520411355287901, 0.04193398662443672, 0.041789618121193986, 0.02453913413254278, 0.01530661347455212, 0.0055077094584703445, 0.03961266743551407, 0.03138113520773394, 0.022733547358906696, 0.05761001152651651, 0.07169819663145713, 0.0257450537090855, 0.04013815209535616, 0.04434491654059716, 0.008311908093414136, 0.03369739591809256, 0.11184352423463549, 0.014652646512591412, 0.011287624265865555, 0.0368482716647642, 0.020268307499853627, 0.04095297087250011, 0.036737293869789155, 0.029373509543282644, 0.11284092999994755, 0.057766997388431, 0.11798851378262043, 0.038988045416772366, 0.031435451935976744, 0.050638417048113685, 0.04171146106507097, 0.04186624847352505, 0.007461283023336104, 0.0547293114608952, 0.017933979098285948, 0.011934308002569845, 0.019777918367513588, 0.02733893077155309, 0.04055789385789207, 0.06819844192692212, 0.07329745617296014, 0.06015359503882272, 0.028563739066677432, 0.007115266635082662, 0.03784123302570411, 0.02352798294409045, 0.054223989469132254, 0.02994375376562987, 0.12418100078191076, 0.18210449548704283, 0.37964609691074913, 0.4178829565644264, 0.7913688240306718, 2.1778008086340765, 2.647284290620259, 4.851965291159494, 5.3437283890587945, 8.011598672185626, 13.363670979227338, 17.49643431391035, 26.494707584381104, 28.971186263220652, 43.99386732918875, 56.0083657673427, 60.594162940979004, 62.3696847643171, 64.63615240369523, 60.93712602342878, 54.17993688583374, 56.34907068525042, 44.06180681501116, 36.3896233013698, 42.25029679707119, 40.84544052396502, 38.54742111478533, 45.233860220227925, 52.76399476187569, 36.973612444741384, 47.70823533194405, 48.402749470302034, 35.53754833766392, 35.75772632871355, 47.443932805742534, 49.18664870943342, 55.910566398075645, 58.64706230163574, 57.89428056989397, 55.57809509549822, 51.389290196555, 55.26208060128348, 56.05411965506417, 55.430032457624165, 48.20210633959089, 50.78303902489798, 45.80269186837332, 53.88291876656668, 54.17836659295218, 58.01576982225691, 58.164624554770334, 62.620702334812705, 61.0332612991333, 45.61513219560896, 14.43550443649292, 3.2456103903906683, 1.541673360126359, 0.282327374709504, 0.06574044882186822, 0.059520406515470574, 0.04895282071083784, 0.02213088782238109, 0.06689701176115445, 0.03016334805371506, 0.015183152331571494, 0.020473891736141274, 0.041756074742547104, 0.0403974813941334, 0.05086192648325648, 0.013789058030982102, 0.025131534219586422, 0.030660802431936775, 0.016359379215698158, 0.08014331811240741, 0.07184759647186313, 0.05223127121904066, 0.01888437256483095, 0.08865863404103688, 0.0330199838749, 0.0179906079346048, 0.07424769018377576, 0.062339936649160724, 0.029431500538651432, 0.009468793336834227, 0.08934432081878185, 0.049915332812815905, 0.015744300791993737, 0.019724863714405468, 0.05288472079804965, 0.01460131024941802, 0.04744331438892654, 0.03158169658854604, 0.03525044722482562, 0.007176740211434662, 0.031473595782050064, 0.042321810099695406, 0.04834280415837254, 0.020342705471973335, 0.02127456814715905, 0.0022424045060428655, 0.04939589389998998, 0.024312157383454696, 0.04303944569879344, 0.03984237189537712, 0.02396980593247073, 0.04730026224361999, 0.03488086616354329, 0.011319828386019384, 0.0467756834280278, 0.06729071813502482, 0.04206924918772919, 0.08568059134164027, 0.07206305848168475, 0.01442834997682699, 0.07481030427983829, 0.028051455305623155, 0.06873365677893162, 0.024006964206429462, 0.012623962513836367, 0.02125691605864891, 0.04281891503238252, 0.03148932083110724, 0.014156082711581672, 0.012664755190988737, 0.02871134757463421, 0.023369850357994437, 0.08671324700117111, 0.05231694305049522, 0.0501517411986632, 0.07712131312915257, 0.026194406739835228, 0.05141267978719302, 0.03942356651116695, 0.033880213608167, 0.0427058677056006, 0.014321085464741503, 0.06853033376059361, 0.018434968643954823, 0.0395414653633322, 0.03458976446251784, 0.014263374365067907, 0.02208317832888237, 0.02790734125301242, 0.033969322219491005, 0.07928625374500241, 0.08181231748312712, 0.0066739249824812365, 0.05927761311509779, 0.06427877582609653, 0.012887145043350756, 0.0686274321217622, 0.03841733639793737, 0.02906457594196711, 0.06584710095609937, 0.021343178215569684, 0.02556226824942444, 0.038309127025838406, 0.020273579716948525, 0.017535159963050058, 0.042539918396089754, 0.02546009444631636, 0.07409918600959436, 0.012583137606270611, 0.013763505250348576, 0.01205580648300903, 0.02386738107140575, 0.03681497255872403, 0.03296703778739486, 0.03971606260165572, 0.05531521966414792, 0.044569040049931834, 0.07651104551873036, 0.035474234859326055, 0.03736942387851221, 0.07255914900451899, 0.0014981044951127842, 0.13706237742943422, 0.2210599644375699, 0.5432565233537129, 0.6228633373975754, 1.162440572466169, 2.6170780829020908, 3.2624632460730414, 5.670855224132538, 6.21176814181464, 9.555763721466064, 15.568350894110543, 21.53844288417271, 31.369410855429514, 40.636855602264404, 58.17360162734985, 69.37958335876465, 71.8723121370588, 75.09214905330113, 75.0839432307652, 73.97323199680874, 65.72839532579694, 66.31429522378104, 53.627287592206685, 47.346251555851524, 54.37082821982247, 51.01826333999634, 50.59130695887974, 54.638549259730745, 61.886666842869346, 44.02136829921177, 53.05701766695295, 58.28283078329903, 44.79740565163748, 43.08602959769112, 56.447443280901226, 56.660607065473286, 64.11545440128872, 67.1052781513759, 66.18777547563825, 64.20728179386684, 59.21481350490025, 63.231719970703125, 65.63392066955566, 65.44438770839146, 57.636898449489046, 61.28002657209124, 52.45228815078735, 62.732755933489116, 61.44371918269566, 65.05667822701591, 65.34818989889962, 69.65979725973946, 70.46153599875313, 56.71550478254046, 23.798281942095073, 6.310984509331839, 3.259881556034088, 0.6698259945426668, 0.03912532662174531, 0.08776627906731196, 0.08848733787557908, 0.008563942292572131, 0.037083217807646306, 0.017008581165490404, 0.057772859930992126, 0.05108177522197366, 0.003182139671740255, 0.0321326941650893, 0.014292351203039289, 0.02682078616427524, 0.08530129705156599, 0.038418381341866085, 0.019373945758811066, 0.0528849989974073, 0.03711706652705159, 0.0372187212508704, 0.029755840277565376, 0.05862239934504032, 0.03152494052691119, 0.03602917811700276, 0.013187322150250631, 0.05225583079404064, 0.02067049216878201, 0.06071267396743808, 0.0996462262368628, 0.02279962140268513, 0.055434760571058304, 0.04306138952129653, 0.01600323654046016, 0.04561857087537646, 0.035283101722598076, 0.0022224002334821436, 0.040506725532135794, 0.07849312094705445, 0.041198854999882836, 0.026440613171351806, 0.04390163979093943, 0.03910005119230066, 0.01686184966404523, 0.05922923356826816, 0.03781306364440492, 0.0024971994945579873, 0.027489015932327936, 0.010747322097553738, 0.017409715801477432, 0.025786812450470667, 0.0672345490061811, 0.06110172559108053, 0.048896013759076595, 0.05526850592078907, 0.05462409782090357, 0.021832279827711836, 0.034653533183570416, 0.08147091258849416, 0.0734107850917748, 0.01721188043510275, 0.04779102626655783, 0.032277832805578194, 0.03082200199631708, 0.019598362734541297, 0.060387614981404374, 0.06717363691755704, 0.18766888976097107, 0.1349125477884497, 0.17841732262500695, 0.09448585206908838, 0.16222485793488367, 0.0828903332086546, 0.15543243741350515, 0.14387272484600544, 0.19704764150083065, 0.1615547231797661, 0.0762310480432851, 0.09511923058224575, 0.1320019718259573, 0.08275264488267046, 0.12514925668282167, 0.100434310734272, 0.16901020812136786, 0.12471907905169896, 0.09159817666347538, 0.130303150841168, 0.08768182859889098, 0.1497095102178199, 0.14933516244803155, 0.1398181388420718, 0.1452771701983043, 0.1459954266569444, 0.17447255072849138, 0.17245846880333765, 0.15383125761789934, 0.12937369357262338, 0.17542730378253119, 0.1143037700759513, 0.19915601265217575, 0.27384538842099054, 0.16367849707603455, 0.13141887954303197, 0.11198886643562998, 0.08199639724833624, 0.10444023220666818, 0.15021518165511744, 0.181033088692597, 0.07897849740194422, 0.12082168247018542, 0.1335868396397148, 0.09624483875398125, 0.18949086485164507, 0.1379890934165035, 0.14688309973904065, 0.1378052375678505, 0.10685420195971217, 0.15373616772038595, 0.18575751089623996, 0.23869499457733973, 0.17356498299964837, 0.326945069112948, 0.5020732475178582, 1.0136922342436654, 1.3488924418176924, 1.7787416619913918, 4.06177966935294, 4.8439861536026, 7.892905201230731, 8.774491769926888, 13.055990849222455, 20.84384536743164, 26.447362559182302, 37.468101842062815, 48.34730979374477, 66.65263775416783, 80.91777583530971, 84.83558014460972, 88.87700680324009, 88.6547269821167, 86.4774603162493, 78.01856354304722, 78.27899592263358, 66.27111216953823, 54.147672925676616, 59.48138114384243, 58.351013456072124, 58.7937457220895, 62.64121341705322, 70.02450820377895, 53.925876004355295, 61.74675096784319, 66.0237215587071, 53.93331752504621, 53.08472013473511, 66.731367792402, 66.26248945508684, 74.25644057137626, 76.07844584328788, 76.00688634599958, 74.2856924874442, 68.72491019112724, 72.22752489362443, 73.57264750344413, 73.74637331281389, 66.67373248508999, 70.07051917484829, 65.57306139809745, 72.22797652653286, 71.7940754209246, 76.62269823891776, 72.80171707698277, 79.46277441297258, 80.1085260936192, 65.18767956324986, 26.779854706355504, 7.444102815219334, 3.3803754789488654, 0.7716546133160591, 0.20099125988781452, 0.22057387552091054, 0.13477667793631554, 0.1006785019167832, 0.18755674149308885, 0.1078341965164457, 0.17771191761962005, 0.18287262426955359, 0.13079424734626496, 0.09911390194403273, 0.13110137943710598, 0.07917926234326192, 0.1333854640168803, 0.09572545412395682, 0.1161088225032602, 0.18301363741712912, 0.15253406151064805, 0.15110723807343415, 0.14905340756688798, 0.1440754168267761, 0.13731103337236814, 0.11668559083981173, 0.1518155743501016, 0.2327758621956621, 0.11555786563881806, 0.1554888915270567, 0.30119089250053677, 0.06408242136240005, 0.12720775551029614, 0.1541055350431374, 0.17461882930781158, 0.12462298492235796, 0.17303189874759742, 0.12981326212840422, 0.11559910699725151, 0.150802684415664, 0.12003193556198052, 0.1169660429337195, 0.10497839190065861, 0.08192521892488003, 0.1499454639852047, 0.17787760230047361, 0.20526547410658427, 0.08208753128669091, 0.12601714368377412, 0.10638668454651322, 0.07615716915045466, 0.08933175435023648, 0.17105615405099733, 0.14559131834123815, 0.15602566700960907, 0.2577381341585091, 0.09777589874075991, 0.1602248488260167, 0.12578036210366658, 0.22421531512268952, 0.16673455094652517, 0.10541563986667565, 0.07966513412871531, 0.06348394669060196, 0.15519211388060025, 0.06022612364696605, 0.10434420593082905, 0.22365960851311684], [0.029228075740060637, 0.00933155369213117, 0.05348342956442918, 0.03466133972895997, 0.04152750682884029, 0.055878264629947286, 0.039600810036063194, 0.030022087240857736, 0.01085868411298309, 0.013931043179971831, 0.032717255476330004, 0.005793284491768905, 0.06812889887286083, 0.025544409207733612, 0.04110210947692394, 0.04005380679986306, 0.05537137522229126, 0.040495553453053744, 0.022753095952793956, 0.10961157828569412, 0.03627668394308005, 0.01670673316610711, 0.006933158862271479, 0.030192698085946695, 0.0737897197582892, 0.048594187812081406, 0.01129797871025013, 0.019281451257744005, 0.07341340423694678, 0.017156654469934956, 0.029356234041707854, 0.015613969481949295, 0.03221053909510374, 0.015436291694641113, 0.015785694820806384, 0.021577315205442052, 0.0554293899663857, 0.01931947636018906, 0.08035207619624478, 0.057502490867461474, 0.011788614659703203, 0.01470418124725776, 0.052178443875163794, 0.019915637227573564, 0.02809161609703941, 0.027670218709057996, 0.032982983360333104, 0.05736509431153536, 0.030015105115515844, 0.0631986227152603, 0.05176287849566766, 0.026745446724817157, 0.17405016267938273, 0.4332118768777166, 1.2728800177574158, 2.42252830522401, 5.384572505950928, 11.100778188024249, 13.989307624953133, 15.527293988636561, 16.487392595836095, 23.344316176005773, 22.978417090007238, 35.56375694274902, 39.434049470084055, 45.73540898731777, 53.173987116132466, 61.17261437007359, 62.8063234601702, 59.00280312129429, 50.113003390175955, 49.04895625795637, 50.9810140473502, 36.74055249350411, 28.361593008041382, 34.57500396456037, 30.666857651301793, 31.461081913539342, 26.67426814351763, 36.42539957591465, 34.444155488695415, 27.89343207223075, 30.919184957231792, 39.80984279087612, 41.220542498997276, 19.950909784861974, 20.20040396281651, 23.53284512247358, 26.99496051243373, 28.86976167133876, 39.61498403549194, 35.112429755074636, 31.70941400527954, 28.860968726021902, 32.31549842017037, 32.52003254209246, 30.385768277304514, 28.159495966775076, 30.579699448176793, 31.907798971448624, 30.174268586294993, 33.09384952272688, 33.66587386812483, 38.245296069553916, 41.80138063430786, 46.12718663896833, 60.273135321480886, 63.71764918736049, 59.08604254041399, 39.198411737169536, 19.830176149095806, 13.677227548190526, 3.8711423788751875, 0.8212756078158105, 0.08229593653231859, 0.03228826528148992, 0.06957558981542077, 0.07801666044230972, 0.03535832411476544, 0.027104881991233145, 0.04193745054570692, 0.03956863051280379, 0.06555141575102295, 0.07877271808683872, 0.033170225098729134, 0.010545661490011429, 0.07434689200350217, 0.03466351782636983, 0.023490480313609754, 0.023103698389604688, 0.08731378441942589, 0.03286457221422877, 0.05460673750245145, 0.004006582195870578, 0.08116418083331414, 0.011612063240525978, 0.01881493129102247, 0.015946439766724194, 0.060982574841805866, 0.048332032414951494, 0.03844490527574505, 0.051921723543533256, 0.00476660460533042, 0.03478103330624955, 0.010362207673357, 0.09085346412445817, 0.027317185420542955, 0.011062751823504056, 0.029207991103508642, 0.019991841799180423, 0.08882638825369732, 0.029467344151011536, 0.06429803943527596, 0.036433673197669644, 0.02908633995269026, 0.10545574807162796, 0.0187612998831485, 0.03323205660230347, 0.03257161471992731, 0.026401415899662033, 0.007281263442044812, 0.03468465079952564, 0.020088617856215154, 0.03477175433986953, 0.007491638135564114, 0.02093693081821714, 0.06671055712338005, 0.03203933113919837, 0.006564612566892589, 0.04075826185622385, 0.03940356669149228, 0.07856370215969426, 0.10286515565322978, 0.016472699652825083, 0.025970211984323602, 0.01906616397068969, 0.0451842473952898, 0.027556933895019547, 0.022602909011766315, 0.04151767824909516, 0.019948690364669477, 0.03909234642716391, 0.060303042376680036, 0.04251438851601311, 0.02355629821041865, 0.027176024691600884, 0.0071669701553348985, 0.034036066316600354, 0.027084824496081898, 0.056070670019835234, 0.012186192075854965, 0.007480942727332669, 0.04503245232626796, 0.0432601120722081, 0.007677920595077532, 0.08159366635871784, 0.08381875910397087, 0.025550477007137876, 0.018673410938520516, 0.053269039639937024, 0.019429651787504554, 0.011935639627543944, 0.03214506046580417, 0.009603915104110326, 0.02467947722678738, 0.02007849920274956, 0.06317897234112024, 0.08247618936002254, 0.037952451700610776, 0.013136399793438613, 0.010469164300177778, 0.03787692736036011, 0.055182114842214754, 0.027309236382799487, 0.007838999719492026, 0.03863006391163383, 0.028688938955643346, 0.023825795356450335, 0.06513111080442156, 0.022028384929788963, 0.08194887265563011, 0.011439386256305235, 0.022499654641641036, 0.01942904619500041, 0.0933279659865158, 0.0054550619263734135, 0.11285751339580331, 0.02797993432198252, 0.31420983533774105, 0.4404153674840927, 1.6440835105521339, 3.055831853832517, 6.263388480458941, 12.204046164240156, 15.673291274479457, 17.848304986953735, 19.9750235080719, 27.38729575702122, 26.810506684439524, 40.71655144010271, 47.942570277622764, 54.91300310407366, 62.70747838701521, 70.96649633135114, 69.62976019723075, 67.09734330858502, 62.10030310494559, 58.48809446607317, 61.060018811907085, 50.838739258902415, 38.979564326150076, 46.043888160160606, 38.31001159123012, 35.317815031324116, 29.0152256829398, 41.60334655216762, 44.30327756064278, 45.09218297685896, 46.63100051879883, 50.78021110807146, 56.37148209980556, 36.34309121540615, 32.8339695249285, 31.464229447501047, 41.15752233777727, 40.48463446753365, 47.58031899588448, 44.61133289337158, 42.22731910433088, 37.89468649455479, 40.74083539417812, 44.34310463496617, 40.658551352364675, 38.50050687789917, 36.90982450757708, 45.213706970214844, 41.426372459956575, 45.61529895237514, 44.788428579057964, 49.06656994138445, 48.731308937072754, 55.85729455947876, 66.53802027021135, 69.22169249398368, 67.35313429151262, 54.36834076472691, 29.135968003954204, 20.114694459097727, 6.546172346387591, 1.96174071090562, 0.46310628418411526, 0.06132241232054574, 0.09011970992599215, 0.03162085484447224, 0.037684834096580744, 0.059533488670630116, 0.020048831955396702, 0.020826611202210188, 0.011924554061676775, 0.05853279201047761, 0.024276887133185352, 0.05824989040515252, 0.059231357382876534, 0.01697006412515683, 0.0013793725291699438, 0.026986214698159268, 0.1152182724326849, 0.045972481170403104, 0.039377612727028985, 0.03860877487542374, 0.083679333728339, 0.052208489405789545, 0.022886606199400764, 0.03829785995185375, 0.026145206165633032, 0.050650240520813634, 0.041974915856761594, 0.04113046545535326, 0.03237437816070659, 0.07360137879316296, 0.0527903637183564, 0.04790238743381841, 0.02630242103311632, 0.028656179284943, 0.04392283722492201, 0.024986736542944397, 0.05263014463707805, 0.06470776602093663, 0.04798550797360284, 0.03390444070100784, 0.005404033548464733, 0.05698457187307732, 0.06276328143264566, 0.027751598806519593, 0.02776858932338655, 0.04355080665222236, 0.04083743332219975, 0.03788901546171733, 0.01451678853482008, 0.022807042879451598, 0.03924610585506473, 0.031586202061069865, 0.017831864666992, 0.023181414397965585, 0.021375428985006044, 0.01664650809418942, 0.051588481425174644, 0.03651416441425681, 0.10146803847913231, 0.06467477564832994, 0.021274357801303267, 0.033776072053504844, 0.12563994606690748, 0.09736677605126585, 0.16239469525005135, 0.13827611372939178, 0.11839572978871209, 0.17838487508041517, 0.12745570577681065, 0.12730478601796286, 0.11548296894345965, 0.08173335636300699, 0.11840973475149699, 0.10083650558122567, 0.10584726956273828, 0.13401844219437667, 0.15188882899071487, 0.1116829149957214, 0.13616036011704377, 0.1595034168234893, 0.14978465118578502, 0.16675574838050775, 0.11331599272255387, 0.04265156794073326, 0.04798363860962646, 0.09360886591353587, 0.13072556603167737, 0.13416109739669732, 0.19232981465756893, 0.12128962736044611, 0.15193848418337957, 0.09039131392325674, 0.1295072699763945, 0.14231590766991886, 0.12621132683541092, 0.08123181720397302, 0.09045893672321524, 0.17510322188692434, 0.1600163485854864, 0.11398019029625825, 0.1589931584894657, 0.14404858755213873, 0.10309455477233444, 0.13564478206847394, 0.11829415309642043, 0.0928307965930019, 0.12015066561954361, 0.12188829880739961, 0.1522397944437606, 0.11015957673745495, 0.2713034605341298, 0.2212334115590368, 0.20364923083356448, 0.16881476289459638, 0.45205533717359814, 0.6335016808339528, 2.2794972487858365, 5.139617672988346, 8.69436948640006, 16.869758912495204, 21.50520965031215, 23.03773386137826, 27.907773154122488, 33.97438778196062, 33.082742827279226, 49.89581659861973, 56.064587116241455, 65.68754686628068, 71.75728470938546, 82.88211495535714, 81.93915407998222, 78.11858286176408, 73.95907851627895, 69.43229934147426, 70.9642312186105, 55.81419140951974, 46.22857127870832, 52.95324979509626, 48.09927647454398, 48.17769036974226, 40.12624291011265, 52.971346378326416, 49.117218835013254, 43.04916593006679, 48.53664820534842, 56.304779393332346, 54.58305747168404, 34.19716092518398, 33.746907234191895, 36.66307660511562, 43.33477510724749, 44.01529209954398, 54.510573863983154, 52.42962660108294, 47.08927937916347, 44.28835283006941, 49.62073394230434, 48.711826188223704, 44.83877175194876, 42.476696899959016, 43.116723264966694, 48.5976151738848, 46.84721803665161, 48.54522575650896, 49.742865903036936, 58.02458708626883, 58.17924356460571, 66.44886098589215, 76.27380834306989, 79.78167588370187, 76.91328580038888, 63.672166279384065, 36.31096274512154, 23.688295432499476, 8.033336980002266, 1.9535476991108485, 0.6773400913391794, 0.20685496952916893, 0.1138070553008999, 0.12759058496781758, 0.10329827134098325, 0.09851217708949532, 0.10978672174470765, 0.13286467481936726, 0.11868261439459664, 0.19027630984783173, 0.13882119448057242, 0.12307266811175005, 0.1834564357995987, 0.13968407389308723, 0.16779602398829802, 0.09685716232550995, 0.19498171950025217, 0.11278659291565418, 0.11422242729791574, 0.1414040108876569, 0.12801515789968626, 0.2283043707055705, 0.10799589141138963, 0.10909362536455904, 0.19574336148798466, 0.1160946139799697, 0.18814919755927154, 0.11540558880993299, 0.07363371098680155, 0.23648687877825328, 0.18953708665711538, 0.2466668039560318, 0.056303828222943206, 0.11515489726194314, 0.140644282368677, 0.05381828659613218, 0.22559388114937715, 0.16134425518768175, 0.10751890843468052, 0.13164681302649633, 0.07543678887720619, 0.20493330407355512, 0.22798695202384675, 0.16071621674512113, 0.155800800504429, 0.12062591154660497, 0.14097673738641398, 0.15471560587840422, 0.07993895015014069, 0.1281518827059439, 0.12352215684950352, 0.06652766479445354, 0.14167528918811254, 0.14395855952586445, 0.11330354160496167, 0.16336949222854205, 0.17448171095124312, 0.13682014042777674, 0.22374294618410723, 0.12975744583777019, 0.17555272419537815, 0.06613984131919486], [0.0433476668383394, 0.06945598444768361, 0.04147038435829537, 0.025478352127330642, 0.03029208311012813, 0.05146121878975204, 0.055094003677368164, 0.045297776481934955, 0.03980712539383343, 0.06704666265951735, 0.02388439024798572, 0.029711216422063962, 0.02425097896983581, 0.0197794688200312, 0.032801763620227575, 0.016043336263724735, 0.0062478588494871345, 0.0132598812924698, 0.0393189669453672, 0.009981173789128661, 0.032177060177283626, 0.06960912980139256, 0.05322419186787946, 0.01399353371068303, 0.06979474305574383, 0.015315855121506112, 0.0412059490835028, 0.0531275820519243, 0.04842566346217479, 0.03179283972297396, 0.04543428076431155, 0.018701047669830065, 0.0126044045900926, 0.046056802717170546, 0.03488298997815166, 0.08493946825287171, 0.0837347021858607, 0.04330800985917449, 0.03216479904949665, 0.01575011244442846, 0.011200802317554397, 0.03219835599884391, 0.05559980742899435, 0.02532808036942567, 0.042274183726736476, 0.00757447284247194, 0.0323832601841007, 0.041633127589843104, 0.10807603996779237, 0.045559273700096777, 0.05299681817580547, 0.5788216920835632, 3.027793049812317, 8.986488257135663, 17.24718679700579, 20.444405589784893, 23.86800537790571, 32.44816384996687, 42.856120654514854, 45.642577580043245, 49.09708990369524, 48.106874329703196, 55.75989818572998, 56.252657481602256, 60.40777056557791, 58.73408848898751, 55.104446819850374, 55.53487730026245, 42.96642678124564, 45.70429147992815, 36.45321321487427, 33.132721219744, 24.544926677431377, 13.490634543555123, 20.200424807412283, 26.64068923677717, 28.20775989123753, 38.576454162597656, 36.66081844057356, 33.26494543892996, 21.161416258130753, 13.958057233265468, 9.872321043695722, 11.83047800404685, 13.404084307806832, 17.173191956111364, 23.554625988006592, 17.415887321744645, 13.65206812109266, 12.532437137195043, 15.45308027948652, 15.82577644075666, 10.645301188741412, 13.523645435060773, 11.936915721212115, 17.12245099885123, 13.92873844078609, 29.317361150469097, 44.383449350084575, 13.858745762280055, 17.955378464290074, 18.52055709702628, 22.070120777402604, 26.376051459993633, 28.98809470449175, 44.14049168995449, 44.331723485674175, 48.09529863085066, 55.71609674181257, 56.15376724515642, 58.7262578691755, 47.78704874856131, 38.4357705116272, 21.176156861441477, 8.716169459479195, 4.262312063149043, 1.178967297077179, 0.36664580021585735, 0.14546288523290837, 0.14332847190754755, 0.02705885187190558, 0.04360498767346144, 0.07594672829977103, 0.04374133589278374, 0.027031098093305315, 0.059153346211782525, 0.016277729400566647, 0.026910003341202225, 0.08896238702748503, 0.027309380571490953, 0.023711779420929294, 0.04729092220908829, 0.08846471551805735, 0.01908394837352846, 0.029671057326985256, 0.05359081790915557, 0.07114453241229057, 0.06472531972186905, 0.022613446660605923, 0.05594133445993066, 0.06625154175396476, 0.058326585218310356, 0.023760735722524778, 0.021032254810311964, 0.020895594464881078, 0.023363621406523243, 0.04155559139326215, 0.02918413041957787, 0.026079198279018913, 0.02680632658302784, 0.04695868432255728, 0.00939697040511029, 0.05057749817413943, 0.01286397731330778, 0.0274123974543597, 0.05921523539083345, 0.0234746178612113, 0.03866298303806356, 0.021390714682638645, 0.00438049527916259, 0.03347937583125063, 0.025234680024108717, 0.017707875963034372, 0.015108969794320208, 0.028043502875204598, 0.05130734061822295, 0.037062790510909896, 0.0460587331492986, 0.02707757434940764, 0.04467088137088077, 0.05462115637159773, 0.01734554674476385, 0.030614383851311038, 0.04381944205878036, 0.04390731912904552, 0.030923222457723956, 0.025446094572544098, 0.07870894258043595, 0.04284266036536012, 0.03165949062843408, 0.023093532238687788, 0.04139472431104098, 0.0619778839339103, 0.03623449942097068, 0.06120106311781066, 0.02138257904776505, 0.01943671703338623, 0.01810533633189542, 0.009545103081368973, 0.015106929100251623, 0.025308382497834306, 0.03586860280483961, 0.020403593811871748, 0.03179635792704565, 0.0800368898947324, 0.010851947108416684, 0.013222661102190614, 0.035504280389951806, 0.039088013981069834, 0.043397478094058375, 0.008605566175122346, 0.033290590425687175, 0.01137729690942381, 0.035493929338242323, 0.01894933041850371, 0.06885391354028668, 0.04345231729426554, 0.032522268260696104, 0.02270260446571878, 0.01669429222654019, 0.010741080423550946, 0.02165004058874079, 0.007850813014166695, 0.010207585657813718, 0.028799102508596013, 0.012041810850080634, 0.0436967764981091, 0.0261759946921042, 0.04404044769970434, 0.025684061892596737, 0.027947390086150596, 0.07464526420725243, 0.0372957824729383, 0.09626044505941016, 0.09172641299664974, 0.09515949485025235, 0.10129130046282496, 1.2635670432022639, 4.289651487554822, 11.52378625529153, 20.725147553852626, 24.10982005936759, 26.86135012762887, 37.89646175929478, 50.10341140202114, 52.49295595714024, 56.285723958696636, 56.52538469859532, 63.56503200531006, 64.46221814836774, 68.86029584067208, 69.41995934077671, 63.86855016435896, 63.75556550707136, 52.1465048789978, 53.69072811944144, 49.58736869267055, 40.35546745572771, 36.817580223083496, 24.34859142984663, 26.832423039845057, 31.267248017447336, 41.10949638911656, 56.96808222361973, 48.821948187691824, 42.61964913776943, 29.494199752807617, 21.096961293901714, 19.79930009160723, 24.236433608191355, 22.569202933992656, 18.17068750517709, 31.153759615761892, 29.425329208374023, 24.03551081248692, 19.697656631469727, 26.020027501242502, 27.993263789585658, 19.419459445135935, 23.67411415917533, 20.22008647237505, 24.492898566382273, 25.23821098463876, 38.368230547223774, 55.36171082087925, 22.731410367148264, 30.589319229125977, 27.771032605852398, 31.454668726239884, 38.231302397591726, 38.26392766407558, 52.43984740121024, 52.1028493472508, 55.047381264822825, 61.464167731148855, 62.044460432870046, 66.64822564806256, 56.75894839423043, 47.16624457495553, 28.154647861208232, 14.35149724142892, 6.624806846891131, 2.1822982473032813, 0.4353528177099568, 0.27451434252517565, 0.09948473490242447, 0.04869712157441037, 0.03160661239443081, 0.020566715326692377, 0.03449280520102807, 0.06542204626436744, 0.03162168604987008, 0.0522615745929735, 0.04493120811613543, 0.08706147795809166, 0.02147188613058201, 0.03980966990015336, 0.02188710036820599, 0.08684298289673668, 0.022127283105094517, 0.04755820393828409, 0.013196828425861895, 0.03728633048012853, 0.014937205439699548, 0.007945290533825755, 0.042743780849767585, 0.03325429219486458, 0.09020945975290877, 0.011390456247941723, 0.015827740243236934, 0.03411899347390447, 0.048712581994810274, 0.05682909914425441, 0.038670294252889495, 0.022714429634756277, 0.03554551496303507, 0.03488677281088062, 0.03225882025435567, 0.04545110843277403, 0.060948824509978294, 0.043328036820249896, 0.06937549662377153, 0.04423220508864947, 0.04315462701820901, 0.053990553066666634, 0.05105144131396498, 0.02013662251244698, 0.04620141888569508, 0.021830522422013537, 0.04404270043596625, 0.002496198231321094, 0.06776850178305592, 0.01975958265497216, 0.05712179200989859, 0.03588450427300163, 0.013358544525025147, 0.041815304064324925, 0.020541512839762226, 0.06621725537947246, 0.036694491880812814, 0.031901215336152484, 0.04172808178035276, 0.09969804595623698, 0.15809857792087964, 0.0761761274188757, 0.14980983840567724, 0.08195783610322646, 0.10576098704976694, 0.1240354957325118, 0.06892196381730692, 0.1859639212489128, 0.095454569373812, 0.07738048636487552, 0.14704735949635506, 0.1726436817220279, 0.07694865989365748, 0.12874216746006692, 0.1481140979698726, 0.11711791264159338, 0.11407475093645708, 0.22120027190872601, 0.08084008536700692, 0.06800406878548008, 0.12032785825431347, 0.14456788397261075, 0.13363570773175784, 0.12526878741170677, 0.08126543861414705, 0.09918448315667254, 0.1357029460902725, 0.09190011117607355, 0.08408773717071329, 0.1446312591433525, 0.10645106394908257, 0.09166140255651303, 0.057862256919699054, 0.10433873015322856, 0.1557783952781132, 0.17822706140577793, 0.12083082912223679, 0.10747911914118699, 0.11263792589306831, 0.125947715980666, 0.11344347588185753, 0.11475762857922486, 0.09160420205444098, 0.1320859608905656, 0.139894446890269, 0.11102977754282099, 0.1882140790777547, 0.2066252582839557, 0.2843098369027887, 0.3205467824425016, 2.3017788188798085, 5.775120760713305, 15.474112476621356, 27.082196882792882, 32.745015212467735, 34.61018616812569, 46.47531918116978, 60.35704871586391, 62.37204715183803, 66.56966931479317, 65.98130280630929, 72.87000397273472, 74.59809044429234, 78.02978488377163, 77.99450887952531, 71.53748539515904, 73.49384798322404, 61.49592794690813, 63.862671988351, 53.45233889988491, 51.67461102349417, 40.00485093252999, 26.55273199081421, 33.077399662562776, 41.502993719918386, 42.949059758867534, 53.33492824009487, 50.64219903945923, 46.30061020169939, 31.321864332471574, 21.129659516470774, 20.006356409617833, 24.189425570624216, 21.445093836103165, 26.80223832811628, 35.02861016137259, 29.53951242991856, 20.945087569100515, 21.963158471243723, 28.29746287209647, 28.67469446999686, 21.944773537772043, 25.943282910755702, 23.50916566167559, 27.600068705422537, 26.69316029548645, 43.177075317927766, 59.290625299726216, 24.36675923211234, 30.475893361227854, 31.397985322134836, 34.88012368338448, 41.07345608302525, 43.8542537008013, 61.21486636570522, 63.09359673091343, 65.35561057499477, 72.33653518131801, 69.48071438925606, 77.50800296238491, 68.38812405722481, 54.55040441240583, 34.976846081869944, 18.67047142982483, 8.926461900983538, 3.5677888052804128, 0.585832587310246, 0.23352054080792836, 0.2619424728410584, 0.11823539196380548, 0.10598629460270916, 0.19564420038035937, 0.0935779247166855, 0.21738828931535992, 0.15985003965241568, 0.19723095452146872, 0.1559211861874376, 0.1763067937323025, 0.16446970961987972, 0.20612072678548948, 0.12991942571742193, 0.10867821944079228, 0.11368224556956973, 0.10776186468345778, 0.1616804828601224, 0.20159873871931008, 0.13485675863921642, 0.08890000251787049, 0.1017312625689166, 0.1744400489010981, 0.12513275471116814, 0.12540230953267642, 0.09544818435928651, 0.09797020402870008, 0.1271042110664504, 0.16112567191677435, 0.11250230031354086, 0.08221728753830705, 0.15508964152208396, 0.1582976465246507, 0.0933479420574648, 0.07394481929285185, 0.15022734100265162, 0.15931327774056367, 0.1455993793372597, 0.17401772870549134, 0.14336446140493664, 0.10890437516250781, 0.10831924048917634, 0.1143704429268837, 0.11034684561725173, 0.06846066857022898, 0.07610184819038425, 0.13891606724687985, 0.18944929779640265, 0.0727099534124136, 0.16620331230972493, 0.1205323687089341, 0.1597406869488103, 0.08448687861008303, 0.09026696559573923, 0.1742761419819934, 0.1047217088884541, 0.11338388693651982, 0.2073619980365038], [0.030304215316261564, 0.025268957916913286, 0.007631272160714226, 0.023053203509854417, 0.02213254684050168, 0.03557083110458084, 0.033603361142533164, 0.04986366576382092, 0.020437276290197457, 0.018882798363587687, 0.020968628581613302, 0.034239738780472956, 0.08811773985092129, 0.057561014512819905, 0.06585912459662982, 0.019058520273704613, 0.02600491396151483, 0.057593434916010926, 0.025819027596818547, 0.024397567978927066, 0.05654144440112369, 0.009725929271163685, 0.06332408384020839, 0.07552708153213773, 0.029361798028860773, 0.012509181530081799, 0.008300957386381924, 0.022503315338066647, 0.013282253440203411, 0.044493536065731726, 0.02427656652538904, 0.034983386019510884, 0.027456188408125724, 0.07572593979005303, 0.006739298862937305, 0.03523484770474689, 0.03997991094365716, 0.03592785248266799, 0.03707220179161855, 0.013592670488703464, 0.11359704192727804, 0.046735582008425675, 0.03512586819540177, 0.025762261357158422, 0.042777470113443475, 0.01937639357389084, 0.150283971535308, 0.035346107091754675, 0.17396500653454236, 1.6658305036170142, 5.974928370543888, 14.72667738369533, 23.566642897469656, 36.52211502620152, 35.09119258608137, 40.479107175554546, 47.8211852482387, 43.41912623814174, 51.74494416373116, 53.72152600969587, 53.310699871608186, 50.271686349596294, 52.70144360406058, 46.10235030310494, 43.313402448381694, 41.20281417029244, 36.84522015707833, 36.072841031210764, 29.707245418003627, 23.73016701425825, 23.008157117026194, 9.627036605562482, 11.923305937222072, 31.1398423739842, 57.77377101353237, 40.63451405933925, 15.903653587613787, 14.285192319325038, 11.60085219996316, 18.297017914908274, 21.00913953781128, 33.63136911392212, 28.24352921758379, 25.598683527537755, 38.199865273066926, 42.55704934256417, 49.720044544764924, 26.705382176807948, 29.58217089516776, 28.319017921175274, 16.64624057497297, 16.05242841584342, 15.940532888684954, 17.028763226100377, 19.8744900226593, 22.230017934526714, 15.905244725091116, 22.817788634981426, 18.36927570615496, 18.821174383163452, 17.162592479160853, 20.477089915956768, 23.113858325140818, 13.442347168922424, 19.686720166887554, 27.92197527204241, 23.266242742538452, 44.237019538879395, 41.68209743499756, 49.117288316999165, 51.18109784807478, 51.977420466286794, 55.477915968213765, 52.58264677865164, 40.70728254318237, 35.54584796088082, 23.411072731018066, 15.732119934899465, 4.233093151024409, 1.2178186923265457, 0.20019699393638543, 0.04038966806339366, 0.05419874118108835, 0.020535996350060617, 0.027338973179991757, 0.0771324411034584, 0.011562914404618953, 0.006440376621737544, 0.04502205377710717, 0.03387624417830791, 0.05106210109910794, 0.041987784273390255, 0.026010126806795597, 0.03984908939206174, 0.024819557388712252, 0.05743440666369029, 0.038796888531318734, 0.04362044809386134, 0.030612718047840253, 0.050104050364877493, 0.033431386442056725, 0.017578450497239828, 0.013408908786784326, 0.03779548619474683, 0.062210648586707454, 0.026785500646967973, 0.06988499499857426, 0.014379822848630803, 0.017697082167225223, 0.06258296753679003, 0.016927509801462293, 0.020957059559545348, 0.047914333042821715, 0.016329710272007754, 0.026465084536799362, 0.04343974404036999, 0.03471153096428939, 0.035817688929715326, 0.03225465065666607, 0.09827810286411218, 0.03370392342497196, 0.009244132936666054, 0.03063272126019001, 0.01928924592877073, 0.021022188743310313, 0.013434969620513064, 0.06688359712383576, 0.056559934480381865, 0.018198153137096336, 0.026727630091564994, 0.04900774472792234, 0.03588185120107872, 0.034757002988564115, 0.04436968646145292, 0.05278171578954373, 0.0193015613393592, 0.023141903303829685, 0.010424998455813952, 0.06505184434354305, 0.0318336332482951, 0.02635983018470662, 0.07875559864831821, 0.013824190029741397, 0.03785156372136303, 0.01717561443469354, 0.0080745158317898, 0.03755870461463928, 0.031189228541084697, 0.06321444615189518, 0.030442168270902972, 0.04739829019776412, 0.04550486197695136, 0.015401228397552456, 0.025010227425290004, 0.05676220576944096, 0.01720224693417549, 0.053427419891314845, 0.06408944419984307, 0.041841509086745124, 0.06896614323237113, 0.007443009227115128, 0.02428842901385256, 0.07329072510557515, 0.020985966847677315, 0.03197561330827219, 0.03432353785527604, 0.015378558542579412, 0.0397212941066495, 0.031336341718477864, 0.061911876047296185, 0.07849964845393385, 0.035219156582440646, 0.06070113887212106, 0.047411769295909574, 0.09251622097300631, 0.03225139029590147, 0.030093475910169736, 0.020154866622760892, 0.05451206151129944, 0.02178563393785485, 0.0016716524426426205, 0.01930553585823093, 0.0883601193449327, 0.051174761660929234, 0.46523406143699375, 2.9712292850017548, 7.971003821917942, 18.058208329336985, 27.900446278708323, 43.23640251159668, 44.046086515699116, 49.11903231484549, 56.230523994990754, 52.59304128374372, 60.176972252982004, 63.38619926997593, 60.56254863739014, 60.465259960719514, 61.34244918823242, 56.51192603792463, 50.05239077976772, 50.82811198915754, 45.572536264147075, 45.484443528311594, 37.98158066613333, 32.22633218765259, 33.85757119315011, 25.945014749254497, 21.21158398900713, 29.31033304759434, 54.30952773775373, 55.24868794849941, 23.093491418021067, 17.386889014925274, 21.534459829330444, 24.34735812459673, 18.008254255567277, 26.846343755722046, 23.023264237812587, 24.769565411976405, 27.787982736315044, 37.03829322542463, 50.91628115517752, 29.964530263628276, 30.47258949279785, 29.012423821857997, 22.921942131859915, 21.390258652823313, 23.44481144632612, 24.022180693490164, 24.727681670870098, 32.54338196345738, 23.872342790876115, 25.909671000071935, 26.858119215284074, 23.04422000476292, 23.627724511282786, 25.48208233288356, 30.644724164690288, 22.836595671517507, 25.632800919669016, 40.412348883492605, 34.37618473597935, 50.562034198216026, 50.67758968898228, 54.84291315078735, 57.01102556501116, 57.115912096840994, 62.12857532501221, 60.68803310394287, 48.726490361349924, 43.36684799194336, 29.90968813214983, 22.392675263541086, 7.452417203358241, 2.087639246668134, 0.5329645041908536, 0.03271102313218372, 0.0018095014966093004, 0.004269066682484533, 0.03168482712603041, 0.0713687271678022, 0.026341614912131002, 0.03194483835250139, 0.07483616324939898, 0.011207518966070243, 0.050718239907707484, 0.041502699588558505, 0.042758223467639515, 0.013881576280774814, 0.03653844239722405, 0.05265585093625954, 0.011363686345118498, 0.03274217128221478, 0.010053797392174602, 0.04303611748452697, 0.023973939907071844, 0.029774130188993046, 0.05831103998103312, 0.06793557067534753, 0.023545275409040705, 0.039509648856307776, 0.057441599134887965, 0.024144645747063414, 0.03925482503005436, 0.06537947497729744, 0.01711205266682165, 0.014587663213855453, 0.06303911948842661, 0.015255479075546776, 0.06001436643834625, 0.01514389059905495, 0.023791369882279208, 0.011923939987484897, 0.022321143952597464, 0.05318286229989358, 0.011927835626660712, 0.008070561668968626, 0.044951570952045064, 0.03729654582483428, 0.024941420581723963, 0.03991631185635924, 0.04970703613279121, 0.05837550759315491, 0.02699605854494231, 0.015449353493750095, 0.03836735550846372, 0.02987908598567758, 0.05935491182442222, 0.008163596453544284, 0.014356357411348393, 0.046131668878453116, 0.09508742086057152, 0.09197472288672413, 0.20680610143712588, 0.08023073377885989, 0.11244493017771415, 0.14595647874687398, 0.17343581707349845, 0.09754433509494577, 0.10250043629535607, 0.1484366599470377, 0.14979442209005356, 0.11139468010514975, 0.20308904589286872, 0.1468140927276441, 0.15198575093277863, 0.08630246868623154, 0.11289006272064787, 0.09631510105516229, 0.11728414015046187, 0.11566971535129206, 0.14216466221426213, 0.12748159867312225, 0.13834193162620068, 0.1607471579419715, 0.08973116720361368, 0.16592579148709774, 0.07044165155717305, 0.09061044680752925, 0.06829734519124031, 0.21979391308767454, 0.08767244445958308, 0.20359321098242486, 0.08122089279017278, 0.13528076160166944, 0.15381547489336558, 0.15458424149879388, 0.16601184329816274, 0.10786426240312201, 0.40688072836824823, 0.07359737543655293, 0.266883591988257, 0.21766399166413716, 0.09927163419446774, 0.22166668330984457, 0.14961511242602551, 0.096332519049091, 0.24323583234633717, 0.1420357541314193, 0.5952967394675527, 3.950254133769444, 11.300944498607091, 22.70986921446664, 35.86587503978184, 52.69126796722412, 53.337651933942524, 59.54406084333147, 64.82814502716064, 62.082362856183735, 67.18211133139474, 70.70861394064767, 67.72461972917829, 68.55627741132463, 70.81311484745571, 64.63032286507743, 59.14815943581717, 59.55540725163051, 53.183040618896484, 54.04158435549055, 45.14951603753226, 39.34826701028006, 35.33247225625174, 23.158316373825073, 21.14756155014038, 40.484835965292795, 70.87539849962506, 56.6659710747855, 27.16339005742754, 23.218956777027675, 22.909419740949357, 34.4761380468096, 34.546533720833914, 46.82716900961739, 43.89098882675171, 38.941328389304026, 52.04985196249825, 59.192259652274, 63.23925181797573, 38.59295266015189, 40.57695518221174, 41.46494538443429, 26.55802651814052, 25.912736892700195, 26.048615864345006, 27.103545222963604, 31.486095428466797, 34.25747128895351, 23.019814457212174, 30.981694425855363, 28.667563881192887, 29.34307643345424, 27.53204584121704, 32.7829350062779, 37.54743637357439, 24.02904725074768, 29.669395106179373, 42.310690539223806, 37.57137639181954, 60.82546847207205, 57.824763842991416, 66.85227339608329, 66.78924628666469, 68.74743625095913, 69.84905229296002, 68.85452188764299, 58.266978468213765, 50.22440038408552, 34.43940986905779, 26.078487907137188, 10.30180309500013, 2.872299096414021, 0.6857673334223884, 0.14508754680199282, 0.10127368569374084, 0.12798921072057315, 0.14190616751355783, 0.15193528149809155, 0.1367517305271966, 0.13777420137609753, 0.1765636463782617, 0.0929110808564084, 0.13354554399847984, 0.18221534096768924, 0.08925089333206415, 0.12104620970785618, 0.10130185846771513, 0.19784083536693028, 0.13813481559710844, 0.1409222645951169, 0.17631832882761955, 0.12437831876533371, 0.12177076297146933, 0.10910380338983876, 0.16180985234677792, 0.12490137426980905, 0.17673550572778496, 0.10141394566744566, 0.17045022227934428, 0.14371959306299686, 0.20804988326770918, 0.11576781794428825, 0.08349336763577801, 0.10821316510971103, 0.13205340478037084, 0.14053582533129624, 0.10247800392763955, 0.11279352075819458, 0.10475459748080798, 0.1492212364184005, 0.12099591669227396, 0.15851420776120254, 0.16818918074880326, 0.1569418657038893, 0.12283362022468022, 0.08266254221754414, 0.0996642956244094, 0.09845134642507349, 0.1593691347432988, 0.12040952672915799, 0.10465345505092825, 0.07397323633943285, 0.12834613371108258, 0.1322793840829815, 0.25271198100277353, 0.07379891390779189, 0.09087350804890905, 0.14484334204878124], [0.01243218985785331, 0.03768747020512819, 0.013404200601923679, 0.005393858491775713, 0.035165396252913136, 0.007484795958069819, 0.054158514232507775, 0.03172511514276266, 0.06474588611828429, 0.049983562901616096, 0.0028761381898740573, 0.02080124756321311, 0.03732080005907586, 0.03144595905074051, 0.05928239678697927, 0.058214844071439335, 0.05955193803778716, 0.04020712857267686, 0.08271725928144795, 0.030279927155269042, 0.04498744170580592, 0.06144913552062852, 0.04434669430234602, 0.015070776754458035, 0.030667228158563375, 0.011402972674529468, 0.029960401622312408, 0.038869474814938645, 0.0682736032509378, 0.07866183867944138, 0.07164662797003984, 0.012091703530001854, 0.11924393927412373, 0.04203268972092441, 0.04690935821937663, 0.03209093712004168, 0.04821941256523132, 0.08046689110675029, 0.022984545943992477, 0.03499480576387473, 0.02681158692575991, 0.029959468636661768, 0.032285598638866625, 0.04320944586236562, 0.05175379630444305, 0.04113140183367899, 0.2871480131787913, 1.0381343684026172, 4.439955787999289, 17.725113425936016, 37.49592590332031, 47.6593200138637, 53.85054016113281, 59.929345403398784, 52.17157745361328, 49.86444200788225, 50.8252979687282, 54.55786330359322, 52.50238118852888, 48.971859046391074, 47.99248961039952, 45.82956402642386, 50.25809914725167, 38.94278751100813, 35.20240197862898, 22.91490534373692, 23.190832206181117, 13.271017619541713, 16.20257203919547, 13.494431734085083, 11.680364779063634, 13.78650621005467, 24.73253846168518, 49.10515676225935, 60.98031602587019, 26.236670596258982, 41.81138604027884, 58.506500244140625, 40.87479666301182, 34.61169045312064, 32.15601989201137, 34.09145450592041, 46.12985822132656, 44.06678867340088, 42.19836596080235, 33.81806721006121, 37.8937589100429, 52.11903517586844, 52.70228433609009, 38.519016878945486, 40.50246007101876, 44.11530099596296, 39.19291223798479, 45.36461836951119, 35.30115672520229, 32.5567433493478, 36.03928470611572, 39.024831839970176, 33.673468249184744, 30.519792079925537, 31.390547275543213, 24.644357136317662, 27.004460436957224, 18.133521590914043, 20.94855993134635, 16.561199835368566, 14.571907997131348, 19.81398163522993, 22.47476475579398, 34.053263732365195, 37.32012953077044, 53.02057089124407, 51.29677840641567, 54.42519787379673, 48.315368924822124, 59.319085121154785, 53.17373350688389, 51.76625081471035, 30.12228911263602, 15.634824310030256, 8.897876143455505, 3.8268932104110718, 1.295777480517115, 0.4260906789984022, 0.044590067850159745, 0.03169084233897073, 0.046818030798541646, 0.043341397174767086, 0.031001057209713117, 0.048877734025674205, 0.02128061219783766, 0.06723242519157273, 0.04053409084943788, 0.028349535739315406, 0.04007514672619956, 0.02954261064795511, 0.02970531995275191, 0.01012450413379286, 0.05853955700461354, 0.048222011354352744, 0.04514248695756708, 0.04674752422475389, 0.018231021373399665, 0.029337017929979732, 0.021424938292641724, 0.019582252616861036, 0.033970105927437544, 0.05059932325301426, 0.06812485480414969, 0.03967468553621854, 0.018911335850134492, 0.07089589004005704, 0.04191674165693777, 0.041791412846318314, 0.07732169130550963, 0.03513325404907976, 0.010986026476270385, 0.032530074806085656, 0.03860139241442084, 0.04474929966298597, 0.007840816497004457, 0.03227889132020729, 0.0572825912386179, 0.05876799260399171, 0.026230353828785673, 0.041558261428560526, 0.0724296709522605, 0.01397285535598972, 0.07835926634392568, 0.011620623807955002, 0.03667237163920488, 0.0277790557260492, 0.03715566159891231, 0.02531804483649986, 0.10530510651213781, 0.08520717745912926, 0.03262977874172585, 0.027885936865849153, 0.04262502025812864, 0.01358540337865374, 0.04021276380600674, 0.05902907930846725, 0.028918809656585966, 0.0280163156733449, 0.02999761587541018, 0.026233254565990398, 0.08059008592473609, 0.05086899681815079, 0.06955710652151278, 0.029602779740733758, 0.08029181550123862, 0.10994385688432626, 0.026499968022108078, 0.04049707676417061, 0.04026266327127814, 0.05188678238274796, 0.01791849492916039, 0.028941605040537458, 0.032504164946398566, 0.02124617145662861, 0.06692979178790535, 0.018081859020250182, 0.015691291939999377, 0.024330488006983484, 0.007336023762556059, 0.06664530919598681, 0.05265676695853472, 0.028270829069827284, 0.11477968096733093, 0.04789520514064601, 0.04337761737406254, 0.04394675897700446, 0.04118238016963005, 0.022600379772484303, 0.030845218071980134, 0.08430677506008319, 0.02701040107889899, 0.042734610448990545, 0.03315738382350121, 0.06920625641942024, 0.030023390028093542, 0.0376685390781079, 0.3816610745021275, 2.181366971560887, 7.198108792304993, 23.9492541381291, 46.898766721997944, 55.76779481342861, 62.36582156590053, 69.17139448438371, 60.25741154806954, 60.20320865086147, 58.31716878073556, 65.20730822426933, 59.786886487688335, 56.46825660978045, 54.995433058057515, 54.00351864950997, 56.148031507219585, 47.795695781707764, 43.812418597085134, 34.24675369262695, 32.05594498770577, 26.295365503856114, 29.01797890663147, 26.355967691966466, 15.175178391592842, 7.446968947138105, 13.930240988731384, 38.50126770564488, 74.53431292942592, 34.982147557394846, 36.47137580599104, 42.8601610319955, 25.865176473345073, 27.615736893245153, 27.763888120651245, 26.90166183880397, 35.35227462223598, 34.749629565647666, 36.04934917177473, 35.06819404874529, 31.24407924924578, 32.74454620906285, 39.00930609021868, 34.73099102292742, 27.609492199761526, 31.996162687029155, 33.0088244165693, 35.24000562940325, 36.81843137741089, 32.0017386163984, 31.098608289446148, 38.411712374006, 32.63353484017508, 29.070010491779872, 26.350798232214792, 26.882229464394705, 28.55884541784014, 18.949780327933176, 24.517750535692485, 27.593768426350184, 22.2323351587568, 32.99891628537859, 31.801995277404785, 43.11360352379935, 45.66780996322632, 60.43143612997872, 58.64549200875418, 59.158137048993794, 56.62978833062308, 66.55653721945626, 61.785146713256836, 60.23441995893206, 38.451091289520264, 24.438450745173864, 13.525164484977722, 5.881671820368085, 1.9817973375320435, 0.3995520073388304, 0.023030867833378058, 0.049980753766638894, 0.03411968557962349, 0.030028031207621098, 0.028690872780446495, 0.0361582795823259, 0.017684956746441976, 0.04240725122924362, 0.033265264106116126, 0.01653817149677447, 0.017016520025208592, 0.10566822452736752, 0.03653323124828083, 0.019934478448703885, 0.024879421140732508, 0.10520821171147482, 0.024875407606097202, 0.019079464953392744, 0.014356250542082956, 0.018950967384236198, 0.02537153205568237, 0.008607141224534383, 0.05983509748641934, 0.02254965588716524, 0.04886335586862905, 0.13531356198447092, 0.069358994652118, 0.037361267887588055, 0.07483254665774958, 0.02223585040441581, 0.029654385721577064, 0.07620482945016452, 0.02147493784182838, 0.00956012584668185, 0.009841120768604534, 0.03444477849240814, 0.04937757006181138, 0.03629039374313184, 0.0815171276086143, 0.05068714264780283, 0.020052867542420114, 0.030173013785055706, 0.027437014704836265, 0.03997844530801688, 0.05268577772325703, 0.0598646341157811, 0.05354925424658826, 0.04915424043844853, 0.030706942813204866, 0.022275191864797046, 0.01488333654456905, 0.02158387324639729, 0.11370967195502349, 0.09794988869024174, 0.12459562639040606, 0.09369606444878237, 0.14328785480133124, 0.15475794646356786, 0.1817013235496623, 0.13780105779213564, 0.15244529555950845, 0.15587303734251431, 0.09487871027418546, 0.15943316130765847, 0.1673498736428363, 0.13525219527738436, 0.2056368091808898, 0.1531836230840002, 0.1636357900819608, 0.09886770908321653, 0.13769158295222692, 0.10010346384452921, 0.11713020769613129, 0.10779105525996004, 0.09884314611554146, 0.14636199841541903, 0.15533418554280484, 0.09165068170321838, 0.09676806389221124, 0.10803900552647454, 0.17704647832683154, 0.1421777307987213, 0.124869062432221, 0.06318873646003859, 0.2969056995851653, 0.12399472934859139, 0.13429527091128485, 0.0896420009168131, 0.11287476175597735, 0.11208165609943015, 0.08477615165923323, 0.12894760072231293, 0.12270898691245488, 0.13770671428314277, 0.07608843355306558, 0.16169623844325542, 0.10568703351808445, 0.14149558597377368, 0.6228224081652505, 3.2573417723178864, 10.74127231325422, 29.162475381578716, 55.933710847582134, 63.30226503099714, 71.41264016287667, 77.6706463950021, 69.14145469665527, 68.19288662501744, 66.47666767665318, 71.28598145076207, 68.57300172533307, 64.13046945844377, 63.98940713065011, 61.79098320007324, 66.47966235024589, 55.215829917362754, 51.945691517421174, 36.519453866141184, 34.615953172956196, 26.151299817221506, 25.89898293358939, 24.508113384246826, 20.271226951054164, 22.55078673362732, 36.889945711408345, 61.446741649082725, 71.54794938223702, 35.131867340632844, 58.19131258555821, 75.80972426278251, 57.47983094624111, 47.672691822052, 46.68885122026716, 43.990174361637656, 57.811763763427734, 55.73637853349958, 59.74708720615932, 45.05887678691319, 50.16042831965855, 65.77622672489711, 68.52862358093262, 50.3715215410505, 56.66938958849226, 57.166206632341655, 52.528892040252686, 59.36993898664202, 50.182297774723594, 43.442211627960205, 48.90089014598301, 53.73490129198347, 47.04628045218331, 45.56608486175537, 46.15863071169172, 39.97376469203404, 39.83407115936279, 30.345298494611466, 31.626264912741526, 27.724620376314434, 24.13106417655945, 34.2381865637643, 35.538462025778635, 49.00872271401541, 53.711013385227744, 70.17152513776506, 68.24574157169887, 71.37930965423584, 63.744531767708914, 77.16096823556083, 70.29407051631382, 66.92014339991978, 44.73584461212158, 28.919396127973283, 16.542939969471522, 7.292940412248884, 2.1407343404633656, 0.6225539797118732, 0.17583894383694443, 0.15637891234031745, 0.16812870970794133, 0.13682635580854757, 0.1290734146854707, 0.1179117171892098, 0.1402778870293072, 0.1687642391771078, 0.1959972692919629, 0.17803974502852984, 0.12830938425447258, 0.15150609452809605, 0.13678257672914437, 0.11055344595972981, 0.09216604262058224, 0.16615369782916137, 0.15225340585623467, 0.07420587885592665, 0.09228028077632189, 0.15485007794839994, 0.10790891679269926, 0.07865307879235063, 0.12318938970565796, 0.16553595954818384, 0.12853817269206047, 0.13478179409035615, 0.1156648298991578, 0.13839120683925493, 0.192160805155124, 0.08050693824355092, 0.14054588122027262, 0.1101119164377451, 0.1273195237985679, 0.07415849675557443, 0.13607482399259294, 0.1293096262961626, 0.11569796954946858, 0.10108740747507129, 0.1513584317373378, 0.24581165984272957, 0.10583616872983319, 0.16553013771772385, 0.10122974376593318, 0.11278746144047805, 0.21894315231059278, 0.12594122918588774, 0.1881589006100382, 0.10622289976371185, 0.09158242108034235, 0.13896181407783711, 0.15290163750095026, 0.17717539998037474], [0.04353839624673128, 0.05191523674875498, 0.02642097127889948, 0.021488722280732224, 0.05240990234805005, 0.03144725505262613, 0.03425676661676594, 0.04188144087259259, 0.002294621168402955, 0.002360916796273419, 0.05575138197413512, 0.012589113803447356, 0.029481501784175634, 0.009380086757508772, 0.05795705504715443, 0.04798812372609973, 0.021701607553820525, 0.05881712532469204, 0.05391395324841142, 0.012340143189898558, 0.017266224304746305, 0.06104005354323557, 0.0392601786713515, 0.08638569100626878, 0.05912793507533414, 0.05933416900890214, 0.03345575263457639, 0.059734402889651914, 0.04262203470404659, 0.1182899461793048, 0.03670081921986171, 0.03648404085210391, 0.016535350487434437, 0.02908450112278972, 0.05668324804199593, 0.011660080619289406, 0.04144201820184078, 0.02378395858353802, 0.028247053202773844, 0.023760566088770117, 0.033253399921315055, 0.14775964484683105, 0.04960983259869473, 0.04945682295198951, 0.0950926998630166, 0.6246177575417927, 6.810522207192012, 21.18813555581229, 35.74586227961949, 53.644230774470735, 59.75313213893345, 66.81280762808663, 60.876287596566335, 60.549451283046174, 55.91490207399641, 49.20096199853079, 53.123873233795166, 38.039080483572825, 32.28428363800049, 32.59676497323172, 20.184966802597046, 22.526726858956472, 22.03125602858407, 22.276711566107615, 14.047483154705592, 15.282448155539376, 22.110293524605886, 18.628016199384415, 10.92916897365025, 15.008944477353777, 34.21765463692801, 53.369217600141255, 47.09847184589931, 44.29218823569161, 22.40383059637887, 38.36751140866961, 36.889483656202046, 20.938049043927872, 27.584374461855205, 16.634866373879568, 14.987179245267596, 15.761017492839269, 8.804271749087743, 14.981810024806432, 14.897639547075544, 18.521312713623047, 27.05276778766087, 25.89547061920166, 28.117032051086426, 25.5453873702458, 30.410146032060894, 36.18493284497942, 47.680949756077354, 42.91358920506069, 40.63930484226772, 49.670086996895925, 53.77806002753121, 38.64141981942313, 38.92421497617449, 47.16907943998064, 38.476980277470176, 36.62903390611921, 36.496531758989605, 30.18843596322196, 19.456974506378174, 22.184538500649587, 22.353902578353882, 15.035017592566353, 20.661152907780238, 14.115069150924683, 25.353955813816615, 26.616037028176443, 36.202567373003276, 39.33306087766375, 42.887995515550884, 47.01943261282784, 53.748762948172434, 55.04027325766427, 55.95752927235195, 55.49261835643223, 45.831283705575125, 29.411755902426584, 17.846177101135254, 7.219129698617118, 1.5880694133894784, 0.4756181442311832, 0.020310003476749574, 0.05488383084801691, 0.026133357247869884, 0.057637960383934636, 0.030917902743177753, 0.10077473175312791, 0.047319692093878984, 0.05469788511150649, 0.04930307709478906, 0.034501700795122554, 0.12409440614283085, 0.057106904951589446, 0.027832190107022012, 0.025433019202734743, 0.016859403545303003, 0.05813921455826078, 0.02815140181753252, 0.013252650653677327, 0.05400523317179509, 0.045557193990264616, 0.03360276063904166, 0.05733991387699332, 0.009075742597425622, 0.03727432041029845, 0.08005354792944022, 0.049385217151471546, 0.026921314519963095, 0.04090701030301196, 0.027157444706452743, 0.05977518284427268, 0.03232895363388317, 0.044098560831376483, 0.007821870102946247, 0.05789059254207781, 0.034224213899246285, 0.02448755698943777, 0.03560123286609139, 0.06345446434404169, 0.006936680459018264, 0.02191335119173995, 0.029608601571193764, 0.024187590228393674, 0.04698795632326177, 0.059402511055980406, 0.08040903242571013, 0.04344650224915572, 0.01537553736540888, 0.0835259033899222, 0.02178943543029683, 0.03962550192539181, 0.018547919279496585, 0.020450025963197862, 0.01567226242540138, 0.08487474279744284, 0.03503213876060077, 0.02465138926969043, 0.015089863944532616, 0.03047441564766424, 0.011640436182330762, 0.020699206074433665, 0.014214402796434504, 0.023751636567924703, 0.057362766936421394, 0.031082423736474345, 0.012738716356190187, 0.010676047082857361, 0.02971529441752604, 0.057830813606934886, 0.03479305016142981, 0.03338588049103107, 0.019481732742860913, 0.012351406871208122, 0.02066476533322462, 0.04115673493860023, 0.05706398082630975, 0.0750789837911725, 0.052508798827018054, 0.013071100127750208, 0.05672867935416954, 0.05283589681078281, 0.02115340045254145, 0.021191719021382074, 0.02160008005531771, 0.07189115842006036, 0.032066849126879654, 0.02573946936588202, 0.08756773293550525, 0.050680452292518954, 0.02284374483861029, 0.020668821276298592, 0.034836103208363056, 0.04477672604843974, 0.038358755077102354, 0.041162441418107064, 0.12406240643135139, 0.9199599495955876, 9.292219417435781, 27.96596258027213, 43.96465015411377, 61.793831961495535, 67.40827519553048, 73.45692525591168, 69.79900441850934, 68.14631284986223, 63.91787542615618, 56.68751743861607, 59.71004635947091, 44.793969767434255, 39.4314751625061, 37.807163511003765, 27.998898778642925, 30.200921876089915, 30.559289114815847, 29.509833199637278, 21.88517710140773, 18.399689708437236, 24.04232178415571, 13.521944863455635, 10.17658873966762, 12.569339888436453, 25.504914113453456, 46.099626609257285, 53.61473914555141, 54.099007742745535, 31.14416762760707, 26.37837389537266, 32.67865991592407, 22.445452042988368, 19.840167658669607, 11.601010271481105, 9.409491981778826, 9.065976517541067, 5.695829655442919, 7.829692227499826, 9.280112181391035, 9.577877232006617, 14.45245282990592, 16.472394909177506, 13.906834244728088, 14.875922952379499, 19.3151878288814, 23.70719105856759, 28.618077073778423, 32.116439478737966, 31.273841857910156, 35.32580198560442, 37.9600099836077, 34.05365630558559, 39.104315757751465, 37.790536471775596, 35.43422862461635, 37.50881828580584, 37.446131638118196, 26.136988265173777, 19.14825735773359, 30.067704064505442, 22.370071036475046, 21.858591556549072, 28.193783589771815, 24.79503403391157, 38.022752216884065, 36.985396589551655, 42.747218063899446, 45.563927446092876, 50.396347454616, 55.43011236190796, 59.88105542319161, 62.6074868610927, 63.04328482491629, 64.64408724648612, 54.977614402770996, 39.158570766448975, 24.827746152877808, 11.56381048474993, 3.179648969854627, 0.7228286447269576, 0.02296178279045437, 0.07312364942793335, 0.038908558432012796, 0.029818469059786627, 0.04403811353924019, 0.04784698844222086, 0.015105010542486395, 0.06596984794097287, 0.11598883037056242, 0.022500699585569755, 0.09401623119733163, 0.029217504164470092, 0.048894812752093585, 0.030226648585604768, 0.04267260252631136, 0.10925614128687552, 0.06738761293568782, 0.02983450284227729, 0.035746317223778794, 0.016628895021442856, 0.035205351787486246, 0.02631616815259414, 0.004939258264909897, 0.054078070513371906, 0.06276271146323, 0.015358015894889832, 0.05659368820488453, 0.0359011894491102, 0.08590791414358787, 0.018162353629512445, 0.021098096455846514, 0.015914594421961477, 0.02507856777603073, 0.0307065764042948, 0.005302424201675291, 0.016225227753498724, 0.032817044228847535, 0.044128477440348694, 0.01947349532773452, 0.004519608104601502, 0.027203274657949805, 0.011085189280233212, 0.020373370165803602, 0.0755591762385198, 0.0943700804242066, 0.10471446213445493, 0.021919892269319723, 0.02491024529029216, 0.020943034240709882, 0.10708865616470575, 0.13632599051509584, 0.19680881074496678, 0.17640819400548935, 0.1414437187569482, 0.09648024969335113, 0.14102620258927345, 0.13476021667676313, 0.1256958573524441, 0.06300608840371881, 0.19684641515570028, 0.12482596188783646, 0.12345511758966105, 0.15646362065204553, 0.16348283471805708, 0.21910161737884792, 0.11689882725477219, 0.07011634829853262, 0.18865123204886913, 0.14053430541285447, 0.10849638562649488, 0.056352448649704456, 0.09678280845816646, 0.1028553576075605, 0.11073867923447064, 0.10616718525333063, 0.22135827557316848, 0.195979735947081, 0.11504019770239081, 0.1616627730961357, 0.1937416967536722, 0.11847932530300957, 0.18965778446623258, 0.0912835399753281, 0.1768401222569602, 0.16528008399265154, 0.10624445003590413, 0.12398755044809409, 0.09923835205180304, 0.12226689420640469, 0.08632758126727172, 0.14990412763186864, 0.2025492170027324, 0.12042480733777795, 0.12372566307229654, 0.36411456604089054, 2.106671231133597, 11.94618809223175, 33.88201495579311, 53.18096310751778, 72.60442992619106, 77.24452032361711, 82.16909081595284, 78.01130962371826, 77.16703401293073, 71.8135095323835, 63.82303251538958, 69.03730814797538, 51.15408672605242, 47.725088187626426, 44.886332171303884, 31.83577741895403, 34.88237142562866, 34.14683512278965, 33.86330345698765, 23.148493358067103, 24.08349507195609, 31.580149718693324, 26.99016104425703, 18.114942107881816, 24.924334798540386, 49.7227543422154, 67.2264894757952, 60.264943395342144, 53.819089140210835, 31.058287893022808, 50.25777953011649, 47.225002016339985, 27.617272445133754, 33.05168090547834, 20.643094539642334, 18.956641674041748, 20.419433764048986, 11.781202248164586, 18.95564808164324, 18.592531749180385, 24.72855714389256, 36.321923528398784, 32.94707924979073, 36.00685051509312, 33.412122181483674, 40.773123673030305, 46.519297804151265, 60.72276714869908, 55.39291865485055, 53.39687837873186, 65.49543612343925, 69.94888401031494, 49.12343052455357, 51.05953911372593, 61.364266531808035, 52.320206369672505, 52.64692108971732, 52.98897395815168, 45.12942879540579, 31.62890522820609, 33.59553377968924, 33.3836658341544, 24.289813143866404, 32.01270982197353, 25.559047528675624, 39.424110071999685, 39.5812783241272, 50.24702371869768, 55.121108600071494, 59.716244152614046, 63.3226649420602, 67.097989491054, 70.1348317010062, 70.95254434858049, 74.0660321371896, 61.732931000845774, 43.6358996118818, 27.941015073231288, 13.660793321473257, 3.8962492602212087, 1.0063639474766595, 0.23070285628948892, 0.22959798414792332, 0.07459316628852061, 0.10930673964321613, 0.10258640668221883, 0.19700281747749873, 0.1879029164889029, 0.23625218708600315, 0.18157408466296537, 0.14176885916718415, 0.21150970618639672, 0.11058471285338912, 0.16600360588303634, 0.10125560273549386, 0.15080017383609498, 0.20754703453608922, 0.3208004188324724, 0.14943451354546206, 0.16152412125042506, 0.09881747713578598, 0.14466362526374205, 0.1179852703852313, 0.07131079384790999, 0.14500646186726435, 0.21714728724743637, 0.09246292883264166, 0.12537975502865656, 0.13223244303039142, 0.2271190243107932, 0.10029554353760821, 0.08567755829010691, 0.15635999478399754, 0.15878137413944515, 0.08107698908341782, 0.07591172946350914, 0.11915988235601357, 0.11918031983077526, 0.11262135606791292, 0.09180860394345862, 0.07270818922136511, 0.07585260870733432, 0.09920874078358922, 0.10677910170384816, 0.31578455226761953, 0.17046247662178107, 0.13239765273673193, 0.08533955285591738, 0.17646858362214907, 0.09454310006861176, 0.2157992688672883], [0.015212003640564424, 0.009634358425890761, 0.03371978757370796, 0.04147088308153408, 0.07755383170608963, 0.013790736556984484, 0.085592673559274, 0.05414811568334699, 0.09475406339125973, 0.03574684648109334, 0.0844440698357565, 0.06747706420719624, 0.0356102641671896, 0.009567629595819329, 0.0313068525865674, 0.04677873344293662, 0.06217019432889564, 0.05212259705045393, 0.05866684338876179, 0.03366859210655093, 0.10911968110927514, 0.02371667674742639, 0.04442236792030079, 0.04560335812025836, 0.04263109653922064, 0.023806843873379484, 0.03656759565430028, 0.04104886822668569, 0.03696830450956311, 0.0358520397650344, 0.027151588949241807, 0.02263760250726981, 0.011271956892284964, 0.059384048118122985, 0.052001356413321834, 0.04301677245114531, 0.019855866774118373, 0.02761663479863533, 0.09831996847476278, 0.017071732419676015, 0.05410304060205817, 0.01697634227041687, 0.06019667522715671, 0.4251321532896587, 4.901657070432391, 17.174670185361588, 39.16473729269845, 59.82385785239083, 68.40108939579555, 62.613920892987935, 60.992857524326865, 56.2551657812936, 58.15225676127842, 48.38184928894043, 43.133496216365266, 38.780783312661306, 24.90586301258632, 31.39337866646903, 30.442580223083496, 30.899045603615896, 22.299982820238384, 24.265878336770193, 25.5659818308694, 26.113661425454275, 32.59904398236956, 42.88549763815743, 47.431189809526714, 71.02145658220563, 51.991476672036306, 44.62115069798061, 43.24277400970459, 18.750606741224015, 15.463761397770472, 12.049644163676671, 22.54224566050938, 19.359307152884348, 9.441478882517133, 5.594209211213248, 3.0569848205362047, 2.105744732277734, 2.388005094868796, 1.4940623492002487, 1.2775574581963676, 1.14246743278844, 1.7148574271372385, 1.9104026428290775, 1.2556678099291665, 0.7540260564003671, 1.578260402594294, 2.0872128009796143, 1.2312814784901482, 3.382017425128392, 5.627990918500083, 5.2767785872731885, 8.50629390989031, 12.172781876155309, 14.420537148203168, 17.572933980396815, 20.23644600595747, 26.709613629749843, 31.513096128191265, 31.44408314568656, 39.032096181597026, 38.6432854107448, 48.99753958838326, 39.7296918460301, 50.956862109048025, 43.427394594464985, 27.768498250416346, 24.624229942049297, 16.70107228415353, 14.464012895311628, 23.00119502203805, 28.26036470276969, 24.149779149464198, 34.120563983917236, 36.635422774723594, 46.05898312159947, 49.58837618146624, 50.31378548485892, 54.306956904275076, 56.81053876876831, 55.11734962463379, 42.37477724892752, 31.00532177516392, 13.625164696148463, 3.264543797288622, 0.2058103105851582, 0.024341989175549576, 0.08950973408562796, 0.013110090446259295, 0.07667421962001494, 0.10933204221406154, 0.0611359780388219, 0.054492238110729625, 0.04641219561121293, 0.06592310366353818, 0.015325765125453472, 0.03259045085204499, 0.03936879177178655, 0.04339089630437749, 0.04796580331666129, 0.05167561889226947, 0.02111225069633552, 0.06533852538892201, 0.028374037638838803, 0.05278511864266225, 0.0522391863300332, 0.03437532704057438, 0.010530554755989994, 0.03580862709454127, 0.035659980428005965, 0.06741634889372758, 0.06935619230249099, 0.03538533998653293, 0.025268591508003216, 0.03583672183698841, 0.026798411472035304, 0.0210095187981746, 0.016439524379425814, 0.019655787153169513, 0.05006301935229983, 0.09307125583291054, 0.06656605630580868, 0.029178790348981107, 0.04219445925472038, 0.03858069031100188, 0.02976011504818286, 0.04449420103005, 0.043479306024632285, 0.019366928010380695, 0.05398470409480589, 0.04830487405083009, 0.04428069320108209, 0.06121994674737964, 0.01674525699179087, 0.01476342074706086, 0.050654935983142683, 0.03456656874290534, 0.054966622298317294, 0.032765078624444346, 0.037721261249056885, 0.021865068336150477, 0.03114152413659862, 0.02855844988620707, 0.02893897911001529, 0.05351558533896293, 0.05285566592855113, 0.04933529733014958, 0.05383196246943303, 0.037771995312401226, 0.03624011429824999, 0.02504918720972325, 0.03006419033876487, 0.021305600946236933, 0.03088839664789183, 0.04388362129351922, 0.05261752388573118, 0.06614319328218699, 0.06077846472284623, 0.020625349233991334, 0.016231719637289643, 0.07727444491216115, 0.05824180905308042, 0.04720109435064452, 0.05213904134663088, 0.05864150010581527, 0.06005161122551986, 0.03209462835054312, 0.03129018098115921, 0.04998328809493354, 0.034630503705037494, 0.033718864766082594, 0.038665765031640015, 0.11579770062650953, 0.02205742962126221, 0.03666616304378424, 0.008464900776743889, 0.11775915537561689, 0.5018686013562339, 6.983180599553244, 22.686801195144653, 47.19999892371041, 68.45431954520089, 78.61164093017578, 72.25538716997418, 69.42548315865653, 64.76844610486711, 65.77310003553117, 56.66098574229649, 51.88030896868025, 45.98616252626692, 29.753999846322195, 35.84305020741054, 32.69080189296177, 31.434776033673966, 20.58688361304147, 23.2470292363848, 23.63419849531991, 22.090619700295584, 26.648610183170863, 38.64149972370693, 52.828981263296946, 65.90278816223145, 39.407892976488384, 38.662514550345286, 50.50160224097115, 33.47557313101632, 23.497741086142405, 15.099738325391497, 13.655082770756312, 12.54320250238691, 7.0161758576120645, 3.243376978806087, 2.1162056795188358, 1.590389677456447, 1.5459209893430983, 0.8200218922325543, 0.7584274145109313, 0.7001026613371713, 0.3948855863085815, 0.9105083367654255, 0.41483115032315254, 0.21322540912245, 1.004603447658675, 1.157604843378067, 0.9140332447631019, 1.9002634840352195, 3.0959702943052565, 3.7811193466186523, 7.599859714508057, 8.9147116286414, 9.908727867262703, 11.911196964127676, 12.50465737070356, 20.215587513787405, 23.30425807407924, 28.195690870285034, 35.49124206815447, 34.78138630730765, 42.24489804676601, 31.452017988477433, 46.220591272626606, 47.147995131356375, 33.77982085091727, 24.67518629346575, 23.332195043563843, 24.816563027245657, 34.482916014535085, 38.77338695526123, 34.67491906029837, 40.70580605098179, 47.91522216796875, 53.41310589654105, 56.76994044440133, 56.23352561678205, 61.11852959224156, 62.847964014325825, 64.54077448163713, 51.9848758833749, 39.58732673100063, 18.818334306989396, 5.37607616186142, 0.4134461246430874, 0.019282660746414746, 0.08678557204880885, 0.007413112126024706, 0.01887895615904459, 0.021438130709741796, 0.05482191792024033, 0.03232950324724827, 0.02544459161747779, 0.01349436433520168, 0.010239119724636632, 0.020993990524272834, 0.01385729490513248, 0.03461078208472047, 0.06970433504985911, 0.042640999757817814, 0.016206888648282205, 0.03610118764585682, 0.09815704543143511, 0.030678393452295234, 0.05540370402325477, 0.07728725565331322, 0.02224158402532339, 0.05440924988527383, 0.03825731748448951, 0.007390461778933448, 0.026824731845408678, 0.024600270137723004, 0.06157840322703123, 0.05061315179669431, 0.04235678179455655, 0.04118019189419491, 0.023400922172835896, 0.05942763042237077, 0.04853959288448095, 0.05326611176133156, 0.07471885133002486, 0.04820590971836022, 0.010047828828516816, 0.025462611811235547, 0.03797441587916442, 0.04069034389353224, 0.03737592424399086, 0.05148340349218675, 0.04490748653188348, 0.025320032944104502, 0.02531046560034156, 0.07625139052314417, 0.05556619958952069, 0.09617446110184703, 0.05793616295393024, 0.07710873308990683, 0.11918534098991326, 0.15640286462647573, 0.12161106296948024, 0.15925258956849575, 0.18052095760192188, 0.1503857925002064, 0.07332501148006745, 0.14923070876726083, 0.10884323915732758, 0.15562993181603296, 0.098963966060962, 0.11220053543469735, 0.12562623965953076, 0.11087870172091893, 0.12855596388024942, 0.1250338243054492, 0.12055956439248153, 0.14892007543572358, 0.13569403014012746, 0.15011572199208395, 0.23484794529420988, 0.04358180891722441, 0.1315330769866705, 0.12543486564287118, 0.18965127053005354, 0.194688117397683, 0.14777305269879953, 0.14934238206062997, 0.10804388419325862, 0.17381734374378408, 0.1714280183826174, 0.23038220778107643, 0.09879437980375119, 0.11560848435120923, 0.18444398923643998, 0.26879098106707844, 0.10046923493168183, 0.1926021243312529, 0.19287675459470066, 0.22264533436724118, 1.1591961979866028, 9.6033501965659, 29.219051088605607, 56.880052021571565, 79.72911970955985, 88.69831303187779, 79.30625234331403, 77.67484310695103, 73.07905442374093, 74.3113591330392, 63.15465750013079, 58.014008453914094, 53.362384046827046, 38.34888676234654, 45.57666349411011, 41.812060015542166, 44.29365430559431, 32.86904403141567, 34.19636188234602, 36.79840666907174, 37.62341145106724, 43.84433167321341, 54.701399190085276, 57.99162483215332, 79.3077392578125, 64.72185148511613, 60.70873178754534, 54.62296445029122, 28.585634197507584, 24.52415156364441, 19.234958716801234, 30.77648980276925, 23.928706577845983, 11.023018292018346, 7.574075818061829, 4.278564768178122, 3.1017503270081113, 3.6884820546422685, 2.000042655638286, 1.859178568635668, 2.519424191543034, 2.642513266631535, 2.9958595633506775, 1.852947554418019, 1.2041169532707758, 2.5087139776774814, 2.96418012040002, 2.053002042429788, 4.521791671003614, 7.403180531093052, 7.354426758629935, 12.075408952576772, 15.642542021615164, 18.734136036464147, 21.997037887573242, 26.53850555419922, 34.49020120075771, 40.22419513974871, 42.087872232709614, 51.222262450626914, 53.03145524433681, 63.169603075299946, 52.352192401885986, 66.72874137333461, 55.010448115212576, 40.29030377524239, 33.09604515348162, 26.732884883880615, 26.15287705830165, 36.5703980582101, 41.886259828295024, 35.99622671944754, 48.0220159803118, 52.290381227220806, 61.93792370387486, 65.2824182510376, 63.95549297332764, 68.0933814729963, 71.73262555258614, 71.47575065067836, 60.333160809108186, 44.62581293923514, 23.441523211342947, 7.363969240869794, 0.9491099225623267, 0.15774470833795412, 0.2383216917514801, 0.0969891238159367, 0.15146222045379026, 0.1973942100469555, 0.2130785605737141, 0.17853821042392934, 0.09450324292161635, 0.1466406320354768, 0.09152573626488447, 0.14801333551960333, 0.10780436811702591, 0.07222701968359095, 0.23065394748534473, 0.16318866264607224, 0.20306769918118203, 0.14829937874206475, 0.18692202626594476, 0.1059192960549678, 0.22259643913379737, 0.17378463835588523, 0.17393281683325768, 0.10616170269037996, 0.10839685810995953, 0.1676875805216176, 0.15860043599137238, 0.0722474775144032, 0.13892205192574433, 0.10387373689029898, 0.14545495994389057, 0.13133189135364123, 0.0836510116766606, 0.1465728056750127, 0.15239641389676503, 0.2101998757570982, 0.12063589958207947, 0.08277497547013418, 0.15133435731487616, 0.1272411122918129, 0.09763365744480065, 0.10650156731052057, 0.12217601122600691, 0.14404766474451336, 0.15251362403588636, 0.14646426721342973, 0.11642504696335111, 0.1931573695370129, 0.09053804712103945], [0.03609127764190946, 0.035833325769220076, 0.035118489127073965, 0.049125687684863806, 0.008437068966616477, 0.034358078680400334, 0.04074865719303489, 0.026865060574242046, 0.05271964679871287, 0.06245629861950874, 0.04069942608475685, 0.034465256679270945, 0.0800908605701157, 0.02951740307201232, 0.060670306240873675, 0.027015790343284607, 0.025581603104780828, 0.047625633355762274, 0.045243768487125635, 0.04010610827910049, 0.02936685990009989, 0.06415095339928355, 0.014237072651407548, 0.01724074361845851, 0.019898292176159363, 0.02295614925346204, 0.022488536845360483, 0.048977393856538196, 0.04904665531856673, 0.033188504832131524, 0.0205338962841779, 0.015429943999541658, 0.09239998113896165, 0.02179242776972907, 0.03769478481262922, 0.029444932139345577, 0.09418522034372602, 0.037619043341172595, 0.017586962719048773, 0.01004911889322102, 0.03841978590935469, 0.13025698331849916, 2.14109434400286, 11.286973408290319, 37.926196575164795, 54.31224448340279, 68.41315841674805, 68.65378843035016, 62.90802424294608, 62.0970652444022, 51.8833453314645, 46.858300413404194, 31.35331187929426, 31.519234861646378, 27.087772812162125, 24.35290105002267, 27.132328135626658, 18.128027302878245, 32.859153270721436, 28.77060045514788, 21.62690040043422, 29.706633976527623, 41.44206149237496, 42.22374425615583, 42.529409408569336, 32.113635880606516, 24.779318945748464, 24.41661603110177, 26.616448708942958, 20.508118833814347, 14.47088987486703, 13.679900867598397, 11.922471284866333, 9.264742766107831, 4.977693813187735, 0.8063258528709412, 0.23806479839341982, 0.28663262512002674, 0.2264939307102135, 0.09804016777447291, 0.10396656726620027, 0.1140466867280858, 0.02902440327618803, 0.007900987286120653, 0.03897328728011676, 0.07423045539430209, 0.10883751910712038, 0.06487965251186065, 0.08071554704968419, 0.09030733842934881, 0.020539029401593974, 0.05038666359281965, 0.11353182114128556, 0.18458323819296701, 0.05943462611841304, 0.5117863406028066, 0.7912946194410324, 0.8961153605154583, 5.091370684759958, 4.125092089176178, 7.421707034111023, 12.604665398597717, 16.862331288201467, 17.404650347573416, 23.642414740153722, 44.7160769871303, 54.747215611594065, 39.93895421709333, 31.2750369480678, 38.937406131199424, 34.15490892955235, 17.87543943950108, 14.618249007633754, 20.37151551246643, 23.461379425866262, 23.850845064435685, 21.19774317741394, 36.6989084652492, 32.976914814540315, 40.939988136291504, 43.08273267745972, 50.8749497958592, 50.563458578927175, 53.90908568246024, 56.13578530720302, 49.895271165030344, 26.561319964272634, 7.098084696701594, 1.55612105344023, 0.23612608813813754, 0.020606962631323507, 0.05772393077079739, 0.021018388947205882, 0.03025857705090727, 0.003941492027869182, 0.007064442241763962, 0.0032407436810899526, 0.08438452838787011, 0.013620545555438315, 0.08774260498051133, 0.062354715141866884, 0.02179973728821746, 0.018069468970809664, 0.005261289288422891, 0.01865899546204933, 0.011017902355108942, 0.03916083775194628, 0.1063619926571846, 0.052471971338880916, 0.004596625645977578, 0.03405379643663764, 0.051634611628417454, 0.03536398648949606, 0.038229154888540506, 0.024575846269726753, 0.03886768348248942, 0.09357518343521015, 0.032939808177096505, 0.03516719437071255, 0.02498868224211037, 0.06015820229159934, 0.0025596083890247557, 0.013457462208212485, 0.03908181895634957, 0.021415094445858682, 0.021376182158876742, 0.08337636784251247, 0.061466913138117106, 0.034115743291165145, 0.02067001549793141, 0.0943891065461295, 0.013236137655829745, 0.10928701463022403, 0.05632467621139117, 0.022645303879731467, 0.07463656538831336, 0.04932292763675962, 0.022554247872903943, 0.011477120436861046, 0.01801675697788596, 0.043022577318229845, 0.014048265193455985, 0.013209394894407263, 0.02315217802034957, 0.045237017063690085, 0.034707371544625075, 0.031687575192855935, 0.029311091106917177, 0.08186385221779346, 0.004594463239690023, 0.034329800733498166, 0.019814155530184507, 0.07186610690717186, 0.035319467806922536, 0.08118017390370369, 0.024338004478652562, 0.0175235179984676, 0.036430416229580126, 0.012926828315747636, 0.04302964426044907, 0.06078293626861913, 0.0147240674123168, 0.04186352415542517, 0.098053378851286, 0.03553597815334797, 0.03265056905469724, 0.03811738660026874, 0.03040207702932613, 0.06265619503600256, 0.02556360326707363, 0.06994259583630733, 0.06604173194084849, 0.06649421980338437, 0.021798281830602458, 0.032248971318559985, 0.08593008866799728, 0.02642312053857105, 0.32164902186819483, 2.845935025385448, 13.897258758544922, 44.150438036237446, 60.29631451198033, 79.72996044158936, 76.96880885532924, 69.75864928109306, 68.52653912135533, 60.44041320255825, 54.974046502794536, 41.921678270612446, 37.71833426611764, 35.180181639535085, 36.20796264920916, 34.11571414130074, 21.925686836242676, 41.9736681665693, 40.96631138665335, 32.682898317064556, 41.518891198294504, 51.533541747501914, 50.60124635696411, 56.360305922372, 40.24561643600464, 29.392179352896555, 37.62102127075195, 36.569748401641846, 29.548878601619176, 17.396520955221995, 11.9449782371521, 7.900662864957537, 4.964942565986088, 3.203403123787471, 0.8803916413869176, 0.18087215375687393, 0.2761308572122029, 0.09638696469898735, 0.14891957331980976, 0.07370417684848819, 0.1126300481015018, 0.02352235110343567, 0.054376476643873115, 0.022712292249447534, 0.012957436182270092, 0.13138929541621888, 0.21287965481834753, 0.1271150540560484, 0.15300113787608488, 0.1416898641203131, 0.1242570374161005, 0.18237558379769325, 0.1941828259399959, 0.08961728188608374, 0.029327369162014554, 0.35233335250190323, 0.5603750933493886, 2.613475659063884, 2.6373349045004164, 5.222219594887324, 8.777112977845327, 11.068866848945618, 16.047166892460414, 24.1703770841871, 32.5716472353254, 46.53851652145386, 35.26516853060041, 30.40047413962228, 39.4243289402553, 34.29232692718506, 21.270565509796143, 22.739807265145437, 33.633561270577566, 30.828153133392334, 34.527679783957346, 30.008366448538645, 46.45202187129429, 42.129179273332866, 48.68720872061593, 51.83334609440395, 58.092714173453196, 55.6517390523638, 60.72646359034947, 65.43142236982072, 59.83792795453753, 32.92440380368914, 9.71468552521297, 1.7432812047856194, 0.3663989763174738, 0.10442733325596366, 0.04365454447854843, 0.030988813045301607, 0.011379639551575695, 0.08495588880032301, 0.02290429560733693, 0.05705178076667445, 0.031159776728600264, 0.05411127462450947, 0.060400669995163164, 0.009548575484326907, 0.030342348984309604, 0.03142562674890671, 0.0408941893838346, 0.016507140394034128, 0.027618534696687545, 0.015935459373784915, 0.02495522876935346, 0.07083560220365014, 0.026552766528246657, 0.060581784562340806, 0.02415178223912205, 0.06008504264588867, 0.04635545651295355, 0.06871788762509823, 0.04256397246250084, 0.07015670756144182, 0.01555242296308279, 0.03413443014557872, 0.029463683454585925, 0.045089618901589086, 0.055293669391955645, 0.028243777574971318, 0.01876678074976163, 0.016501255799084902, 0.01307579389374171, 0.09457649756222963, 0.005042133503593504, 0.00969593717517065, 0.02747669712906437, 0.016257393706057752, 0.019402517172108804, 0.0468491314511214, 0.018209077550896575, 0.05028771283105016, 0.060816428757139614, 0.11239929191235985, 0.0980131213686296, 0.061674850194581916, 0.12557138688862324, 0.14956500940024853, 0.13302532477038248, 0.12740026946578706, 0.0864941616143499, 0.1128735336075936, 0.1390731209622962, 0.11685394894863878, 0.1353245135396719, 0.27486384234258104, 0.0950940569330539, 0.1189809391008956, 0.09766063599714211, 0.22269872150250844, 0.11287275329232216, 0.12166324231241431, 0.11543316447309085, 0.08218858550701823, 0.1222105622291565, 0.1606190912425518, 0.10693874063768558, 0.14761085568794183, 0.11290907527187041, 0.09486347037766661, 0.14205053262412548, 0.11156445635216576, 0.13829569625002996, 0.131601500457951, 0.13719249330461025, 0.14399581109838827, 0.14050789682992867, 0.13470689739499772, 0.09237841729606901, 0.12241176143288612, 0.1751204973884991, 0.11012926657817193, 0.13958713838032313, 0.08207569763596569, 0.7335667056696755, 4.774688294955662, 19.807330472128733, 54.93823896135603, 73.16069575718471, 90.76413059234619, 85.16161741529191, 79.34904629843575, 77.71225220816476, 69.75743334633964, 63.679823194231304, 46.673658984048025, 45.02862433024815, 38.38693509783064, 35.1043107850211, 40.90848500388009, 27.946832452501567, 44.62680305753435, 40.194512435368125, 34.674717562539236, 40.85699537822178, 54.35555607931954, 54.81449849264962, 56.3208019392831, 43.60551166534424, 34.70693288530622, 35.47231864929199, 38.06376395906721, 31.473387173243932, 21.365460532052175, 19.88621858188084, 15.765922921044485, 11.687906180109296, 6.208143353462219, 1.449104790176664, 0.554470915879522, 0.5241623307977403, 0.5157004020043782, 0.3323528303631714, 0.17562467604875565, 0.28214932712061064, 0.04810035341818418, 0.11825025188071386, 0.10625675866114241, 0.16676000958042486, 0.28959524471844944, 0.42146293446421623, 0.2434390942965235, 0.2206891586205789, 0.3524449036589691, 0.3039262571505138, 0.3788147015230996, 0.6878192776015827, 0.20025362446904182, 0.800822879586901, 1.3294862317187446, 1.4025961543832506, 6.5677061166082105, 5.119079232215881, 9.806735260146004, 16.430365255900792, 20.882541622434342, 23.223907368523733, 32.26968894686018, 55.202273981911794, 62.64156777518136, 49.37476423808506, 43.89530713217599, 54.82266610009329, 48.88790396281651, 26.06803607940674, 25.574078219277517, 31.28404528754098, 33.80764838627407, 37.54283666610718, 31.130514417375835, 52.62314782823835, 46.20284904752459, 57.22571447917393, 58.36618137359619, 64.94018472943986, 65.0009536743164, 68.08113874707902, 73.70867238725934, 67.29038511003766, 37.60694074630737, 13.293037329401288, 2.493120265858514, 0.42762088403105736, 0.16471574641764164, 0.17333219120545046, 0.1359050545309271, 0.11588399671018124, 0.15699815696903638, 0.10729669500142336, 0.1558054145425558, 0.18822310359350272, 0.17332497159285204, 0.1723681150802544, 0.14829405902751855, 0.0826202423444816, 0.13540873330618652, 0.08784295352441923, 0.13519500834601267, 0.11753761369202818, 0.08987285210085766, 0.1559005044400692, 0.1341730531837259, 0.08732877325798784, 0.07630183960178069, 0.16603703051805496, 0.1835083980113268, 0.08782463986426592, 0.13411765758480343, 0.13253911371741975, 0.17375631630420685, 0.1324202615235533, 0.11001186644924538, 0.0931025023705193, 0.09627404968653407, 0.1712926642170974, 0.11270661399300609, 0.12925186939537525, 0.08395924977958202, 0.13722673218165124, 0.20865696854889393, 0.13946013019553252, 0.07003592832812242, 0.07886223721184901, 0.18809529473739012, 0.08360962104052305, 0.25415899764214245, 0.11622069935713496, 0.19850441547376768, 0.12991753939007009], [0.04507014833922897, 0.018067260339323963, 0.029961283717836653, 0.0561511612364224, 0.04657445369022233, 0.010460376423517508, 0.028753521918718303, 0.009740340506791003, 0.011496758936638278, 0.11839134645249162, 0.01913708445083882, 0.07736796060843126, 0.03696408062907202, 0.02344593109696039, 0.018196231186656014, 0.04244759013610227, 0.07709242110805851, 0.006759643463218319, 0.025175562660608972, 0.031074220248098885, 0.030497842069183077, 0.06896231629486595, 0.04200676629053695, 0.045776523649692535, 0.006093126572003322, 0.04709163308143616, 0.019934717632297958, 0.025332290679216385, 0.03594492442373719, 0.046432653442025185, 0.012710326451009937, 0.04546173768384116, 0.014522778302697199, 0.008991358286168958, 0.04601162585562893, 0.05749363598546811, 0.009390163850704474, 0.03191715751641563, 0.048008747797991545, 0.07386451467339482, 0.676294604582446, 7.712012325014387, 27.072596209389822, 48.6600204195295, 68.70736598968506, 71.31806128365653, 61.84619358607701, 56.09315463474819, 51.54596512658255, 46.193937982831685, 37.41896070752825, 27.909152371542795, 25.004147018705094, 21.329607827322825, 28.041251523154124, 18.452949387686594, 16.80025087084089, 16.86298441886902, 14.48083187852587, 15.286849839346749, 19.127563885280065, 20.46955633163452, 17.359452315739222, 14.872330733707972, 17.0877742767334, 21.338048151561193, 25.375745364597865, 15.637905836105347, 9.02595055103302, 4.954925000667572, 4.4954923050744195, 3.9651415177753995, 0.6176931176866803, 0.05715770008308547, 0.039387848427785296, 0.019274316462022916, 0.024700102995016744, 0.01822116904492889, 0.09006924727665526, 0.045769134403339455, 0.08920556040746824, 0.07556716938103948, 0.1254823902355773, 0.14154742604919843, 0.021115826575883796, 0.0757898170767086, 0.059044054576328824, 0.0998643073918564, 0.04219709875594292, 0.07635829371533223, 0.09282416052051953, 0.05076468223705888, 0.01217376979600106, 0.07105470116117171, 0.037242721034479995, 0.027129782530079995, 0.0199592466732221, 0.05289327373195972, 0.036568983258413415, 0.2944728529879025, 0.22669854973043713, 0.7546923777886799, 0.730534305529935, 2.0566307391439165, 4.343837882791247, 8.532065646989004, 15.03024070603507, 32.276004859379356, 36.209470408303396, 32.963813986097065, 34.45776700973511, 42.30090747560774, 38.61949825286865, 30.34878649030413, 23.433075938905986, 22.231654235294886, 27.68016927582877, 15.847729274204799, 19.110929897853307, 22.760816880634852, 22.949710607528687, 31.133265904017858, 35.9575982093811, 46.05382061004639, 55.82916477748326, 54.03725562776838, 50.753655093056814, 29.06626888683864, 10.464411786624364, 1.9745288704122816, 0.07005861853914601, 0.04357907102842416, 0.0685866182403905, 0.11662707397980349, 0.05039374749841435, 0.06307189272982733, 0.03095589391887188, 0.023686056158372333, 0.04604792747912662, 0.04228117263742855, 0.019151245476678014, 0.05149742881102221, 0.08624283902879272, 0.012909436615050902, 0.050454130329723866, 0.021271869274122373, 0.02605589060112834, 0.016011441725173166, 0.11358600894787482, 0.02657595037349633, 0.0444153349048325, 0.003179163871599095, 0.02918902604973742, 0.030139277023928504, 0.060167579645557065, 0.03347573549087558, 0.06808005113686834, 0.05094689942364182, 0.027614994440227747, 0.007184110798074731, 0.05819919026855912, 0.06626136015568461, 0.03390905813180974, 0.040278849724148, 0.08148408295320612, 0.019828796619549394, 0.02165148756466806, 0.009189844197992767, 0.08242593705654144, 0.05048236417184983, 0.025700855634308288, 0.046711490622588565, 0.029464925173670053, 0.05429095748279776, 0.0337355770835919, 0.036314804040427716, 0.014613747796309846, 0.029036711901426315, 0.030166194508118287, 0.055687263807547946, 0.06221351200448615, 0.044503843012664995, 0.03250002249010971, 0.01760096598549613, 0.008805545712155955, 0.047072437325758595, 0.02475292355354343, 0.05238389070811016, 0.05109422294689076, 0.02877859378765736, 0.026418209641373584, 0.02632157438035522, 0.06629612829004015, 0.0199093438152756, 0.03878696156399591, 0.059811457326369624, 0.01801552713316466, 0.04583209906039493, 0.07487578290913786, 0.06768124896500792, 0.03701438043000443, 0.05956348670380456, 0.06280279252678156, 0.052810539957135916, 0.047741662843951156, 0.04493507915841682, 0.05255959056583898, 0.04214673110150865, 0.023876291932538152, 0.028447923317019428, 0.03856097886871014, 0.020160276243197064, 0.020522622424843054, 0.004290828572785748, 0.03833417853872691, 0.023913757243592824, 1.183722904750279, 10.083310042108808, 32.21992942265102, 55.08278233664376, 76.76088401249477, 80.87402302878243, 68.7134039742606, 65.04664502825055, 60.03912694113595, 55.39128930228097, 48.130008356911794, 37.63193689073835, 30.375606536865234, 27.937257834843226, 27.13885075705392, 17.40100254331316, 24.870434147971018, 23.034980637686594, 20.531740971973964, 22.435637712478638, 21.68728198323931, 22.08477279118129, 23.703242744718278, 20.31522294453212, 20.02001656804766, 21.05553960800171, 19.403350046702794, 12.500331248555865, 8.53857524054391, 3.9571836590766907, 3.6382402820246558, 2.414444293294634, 0.6434682746018682, 0.1332423338400466, 0.02101082667442305, 0.012780587904022207, 0.029102753714791367, 0.051048896807645044, 0.07549027779272624, 0.10269092143114124, 0.021907936482291137, 0.08658357217375721, 0.06778587906488351, 0.19407963433435985, 0.12809165593768868, 0.06895562593958207, 0.36016313093049185, 0.4324507234351975, 0.20833869491304668, 0.17165477121514933, 0.044440725685230324, 0.02471741072700492, 0.04764176891850574, 0.13302337058952876, 0.21269795671105385, 0.02494892687536776, 0.0595216482345547, 0.12564462795853615, 0.03725883624117289, 0.17223740209426197, 0.17860697316271917, 0.27621350277747425, 0.935661358492715, 1.6683002625192915, 3.786885917186737, 7.192671826907566, 14.277538010052272, 21.38459587097168, 27.122760466166906, 29.733683313642228, 30.52929721559797, 30.835990701402935, 29.50075885227748, 28.885723420551844, 27.456645727157593, 26.552334206444876, 30.76560197557722, 25.901253257478984, 24.54750793320792, 30.709137439727783, 30.481403282710485, 38.70321709769112, 44.262634072984966, 54.98679297310965, 62.23854446411133, 62.77316665649414, 58.143324851989746, 37.40680830819266, 15.280855281012398, 3.949206692831857, 0.1233664330627237, 0.012400485309106963, 0.032564659735986164, 0.024633443714784722, 0.03343900978299124, 0.034395180975220034, 0.01351504523440131, 0.01642393334103482, 0.025692602952143977, 0.04058800384934459, 0.04440025107136794, 0.0454095583409071, 0.07048754766583443, 0.012132133190919245, 0.031056503698761975, 0.052504761543657096, 0.019976774929091334, 0.014028784453070589, 0.037681505882314274, 0.04410614346020988, 0.024024967436811755, 0.06450464656310421, 0.017354376181694012, 0.013726050117319184, 0.006046044299312468, 0.04644146761191743, 0.06495634053966828, 0.0208104892101671, 0.023664729802736213, 0.036432862348322353, 0.04160468679453645, 0.007941864780150354, 0.009399994126787143, 0.0591397008725575, 0.053551544302276204, 0.0445573081794594, 0.08249011289860521, 0.015534794623298305, 0.03448941591860993, 0.0441569385917059, 0.05193727556616068, 0.0329831360307123, 0.008770935337192245, 0.03387921616168959, 0.03561863389664462, 0.07290862168052367, 0.08404598012566566, 0.07662446264709745, 0.09158200038863079, 0.10243478803230183, 0.11108338859464441, 0.12410192431083747, 0.2526901593165738, 0.10868782749665634, 0.166894970195634, 0.20986317311014446, 0.10367985907942057, 0.16744763696832315, 0.1366826963743993, 0.07056552491017751, 0.10343533541475024, 0.18521073380751268, 0.15074738381164415, 0.08282901399901935, 0.13630169896142824, 0.17617369230304444, 0.08801237693322556, 0.17629774207515375, 0.10418876034340688, 0.14882900246552058, 0.08470999449491501, 0.17888677386300905, 0.12091248402638094, 0.14024321388985428, 0.14859265514782496, 0.1376074853220156, 0.11279639774667365, 0.11087462372545685, 0.08363849270556654, 0.07724533575986113, 0.10523666268480675, 0.2659602958176817, 0.1486600472458771, 0.08377174341252872, 0.11622709115701062, 0.17323050594755582, 2.470353841781616, 16.732639687401907, 42.037817410060335, 67.21838092803955, 86.19364724840436, 88.76806599753243, 75.90924331120083, 72.61847223554338, 70.1910148348127, 62.50901699066162, 53.61440563201904, 42.82176876068115, 37.54446949277605, 34.11877134868077, 39.6280813898359, 26.5210725239345, 28.036283561161586, 27.199381726128713, 22.42354437283107, 24.40712305477687, 27.261005299431936, 28.987309558050974, 27.550019093922206, 25.14068259511675, 27.051088060651505, 32.47405283791678, 34.78801141466413, 22.307347910744802, 14.532125217573983, 7.25368743283408, 6.257370471954346, 5.327861309051514, 1.0408203899860382, 0.38681424941335407, 0.07387992420366832, 0.23734690834368977, 0.14353222240294727, 0.16211546451917716, 0.17352519370615482, 0.2768674748284476, 0.3059642235083239, 0.2587490427706923, 0.5898352382438523, 0.6116332028593335, 0.5263935710702623, 0.6401419873748506, 0.3485145574169499, 0.2357169043804918, 0.28418517644916264, 0.24612066469022206, 0.19710868251110825, 0.17066459863313607, 0.13495003006287984, 0.2472098491021565, 0.2885354273021221, 0.20713323674031667, 0.13988078119499342, 0.31928316024797304, 0.18439149776739733, 0.6742093850459371, 0.3961591422557831, 1.169788726738521, 1.2161418965884616, 3.3203445630414143, 6.127756169864109, 11.256348354475838, 19.118414844785416, 39.364220074244905, 44.19794634410313, 42.44224425724575, 46.47072294780186, 58.398073605128694, 52.76970965521676, 40.926244599478586, 36.670170715876985, 33.54161923272269, 39.76042372839791, 25.9210330418178, 29.58851112638201, 35.29841218675886, 34.90221895490374, 45.577639716012136, 52.39826938084194, 63.2464918409075, 70.27527563912528, 70.54754080091203, 66.9107563836234, 43.45040702819824, 19.581583499908447, 4.981082797050476, 0.22813625686935016, 0.17439252430839197, 0.1299782818449395, 0.15889608726969787, 0.07219048057283674, 0.19067340211144515, 0.11925829707511834, 0.06626568920910358, 0.11902740517897265, 0.14082200426076139, 0.09038368718964712, 0.13658844786030905, 0.16538464623902524, 0.10881212832672255, 0.14367923380008765, 0.12075602742178099, 0.13482737807290895, 0.1327611439462219, 0.22639422677457333, 0.10597145504185132, 0.08267884741404227, 0.16790879650839738, 0.13179383799433708, 0.1403642373957804, 0.11483916134706565, 0.16037533432245255, 0.23119777973209107, 0.13196603661136969, 0.12777032889425755, 0.13819656228380545, 0.11343163544578211, 0.1419533799801554, 0.14038154003875597, 0.11548476027590887, 0.13830240017601422, 0.20072059226887567, 0.16928029220019067, 0.07730239376957927, 0.2198977560869285, 0.17723485321870872, 0.09444013916488204, 0.09704762031989438, 0.07925229306731905, 0.09013575049383299, 0.16695275423782213, 0.22984174106802258], [0.033714986938451014, 0.019493001513183117, 0.027148350640865307, 0.037470277931009016, 0.061697859317064285, 0.02369624945068998, 0.04758216979514275, 0.013958511125695492, 0.11164920537599496, 0.011341559318160372, 0.04758310617346849, 0.03484093437769583, 0.035653792188635895, 0.031336043163069656, 0.0027117755920958836, 0.021561011705281477, 0.06851755016084228, 0.08412550442985126, 0.02704757122722055, 0.01271679628241275, 0.059449228192014356, 0.015427899912797978, 0.039262404266212664, 0.00796965163733278, 0.05433651093127472, 0.034972495532461574, 0.038213602865913084, 0.09039689148111002, 0.03456412601683821, 0.03485907840409449, 0.045584284500884156, 0.06499590591660567, 0.014753329234996011, 0.12206701136061124, 0.056416448072663376, 0.0379543957034392, 0.09222185891121626, 0.011939344428745764, 0.08098104423178093, 1.340718429003443, 15.249369519097463, 43.7235233443124, 65.94961902073452, 65.54621355874198, 60.820104462759836, 59.311066899980815, 53.44535248620169, 55.895363739558626, 39.09662757601057, 35.92778696332659, 23.347019025257655, 24.98941683769226, 31.864605494907924, 24.265529189790996, 50.17773628234863, 70.05869334084647, 30.598932061876567, 25.23595108304705, 29.346679074423655, 38.951677731105256, 42.683256421770366, 47.71775436401367, 34.21977036339896, 22.826697962624685, 20.70975729397365, 12.248093400682722, 5.516402414866856, 4.341887176036835, 2.0383142020021165, 0.8158711578164781, 0.27616410542811665, 0.04995606866266046, 0.045983670212860615, 0.030573973698275428, 0.09979953443897621, 0.0555114723475916, 0.028581109563154832, 0.12219306959637574, 0.09141375763075692, 0.12280482319848877, 0.11075152390237365, 0.0729194985968726, 0.060833473556808064, 0.03282218073893871, 0.08789381650941712, 0.04313739222873535, 0.11874795731689249, 0.1827273770634617, 0.2624524597610746, 0.038836436944880655, 0.057059122515576224, 0.11894239831183638, 0.07372487216655697, 0.011027484117741031, 0.053627855743148496, 0.05085818436262863, 0.04093104740604758, 0.06407025522951569, 0.08884194027632475, 0.04001973755657673, 0.06706845720431634, 0.04045089227812631, 0.03630679054185748, 0.09527348873338529, 0.10163626766630582, 0.7217189414160592, 0.46177619269915987, 2.6274269904409135, 5.760898232460022, 11.139688100133624, 20.154394728796824, 36.964121205466135, 49.453914642333984, 59.909716742379324, 52.063842160361155, 61.7096962247576, 47.59762348447527, 50.825867721012656, 37.98688561575753, 24.757553713662283, 21.740857805524552, 22.082610164369854, 25.070339032581874, 36.27081257956368, 49.224467754364014, 47.93687622887747, 57.55482632773263, 53.04363196236746, 51.438427856990266, 18.545476811272756, 6.572572895458766, 0.7886234713452203, 0.004437127508156533, 0.03672548736046467, 0.054397429805248976, 0.018212205597332547, 0.02054871209631009, 0.05204095571701016, 0.008669267042673059, 0.08228936152798788, 0.053821865868355544, 0.0828591613098979, 0.05375561370913472, 0.04470553754695824, 0.06583180677677904, 0.05274792813829013, 0.0130287832913122, 0.02288340521045029, 0.06823852299047367, 0.011867518104346735, 0.059072451266859255, 0.042322705765920024, 0.030673385863857608, 0.025256503406645994, 0.021489665444408144, 0.08792576872344528, 0.037989822016762834, 0.027935098424287777, 0.042852600903383324, 0.03757378505542874, 0.03491060635341065, 0.006881779766575034, 0.004609615774825215, 0.08485989645123482, 0.011458324168675711, 0.009748669524144913, 0.030688228817390542, 0.041533959696867635, 0.042765124168779166, 0.057010763324797153, 0.026191064954868386, 0.02686681119459016, 0.02379374305850693, 0.05468656375472035, 0.04450206525091614, 0.0329684219988329, 0.05364452734855669, 0.0638532190184508, 0.03133894729294947, 0.07226916349359921, 0.04403462586924434, 0.021105480613186955, 0.03466396565948214, 0.08097978215664625, 0.05173534354461091, 0.08480550508413996, 0.027347130867253457, 0.016309345739760568, 0.014848298692543591, 0.030219333978103738, 0.04152237371142421, 0.04366476660860436, 0.06384232174605131, 0.045614984817802906, 0.043982466882360835, 0.044114743891571245, 0.005935977437599961, 0.01202935803615089, 0.04074259787531836, 0.045352588540741375, 0.0547621932678989, 0.03812323896480458, 0.04529278924954789, 0.034445372210549455, 0.04370007757097483, 0.029509352254016057, 0.04176370147615671, 0.028959538721080338, 0.02266088474009718, 0.08227457624993154, 0.021977221693045328, 0.0033451159376584527, 0.04839734819584659, 0.03960922387029443, 0.01815719506703317, 2.0094511679240634, 18.397768531526836, 50.10993576049805, 73.31174959455217, 73.65027972630092, 69.76099082401821, 64.938399042402, 62.26576055799212, 62.333811214991975, 51.339520250047954, 44.83776078905378, 30.497137478419713, 29.315603256225586, 32.054214886256624, 22.345516102654592, 45.68399231774466, 67.65409551348004, 27.740384101867676, 22.77846356800624, 24.136131150381907, 32.170187268938335, 33.654708112989155, 31.730227334158762, 21.759873288018362, 15.367699078151158, 12.276039923940386, 7.76648359639304, 3.8014315366744995, 2.6279643901756833, 1.6293036064931323, 0.7532923700554031, 0.06630978719996554, 0.07269830296614341, 0.08467948756047658, 0.04781623723517571, 0.019171523495710323, 0.03769039469105857, 0.014356048677914908, 0.1887293585709163, 0.2563566097191402, 0.08950541860290936, 0.07659568597695657, 0.05977670954806464, 0.016602301537724476, 0.07431729430598871, 0.006142648602170604, 0.2451535351574421, 0.7731543385556766, 1.0542901243482317, 1.2499630131891795, 0.3994885507438864, 0.24817000329494476, 0.30889356774943216, 0.2174550843025957, 0.13055735720055445, 0.1354690007865429, 0.1874596838440214, 0.025308302769969617, 0.04699781543708273, 0.6405336377876145, 0.21373796090483665, 0.06266794726252556, 0.10085070053381578, 0.04729169234633446, 0.19917449594608375, 0.11591978264706475, 0.43415471485682894, 0.5954680017062596, 1.8053097277879715, 3.7714396374566213, 9.59290792260851, 16.844392776489258, 31.819317136492046, 44.03350680215018, 45.54812029429844, 40.41779974528721, 57.95356607437134, 46.533565929957796, 48.11292968477522, 40.80280985151018, 33.057513918195454, 34.01373543058123, 32.19578790664673, 34.125021253313335, 42.33187559672764, 56.338565008980886, 55.73627431052071, 66.75396333421979, 62.13113921029227, 61.411618505205425, 26.366973638534546, 9.752617478370667, 1.1133164827312743, 0.10030331276357174, 0.12324144691228867, 0.03294991834887436, 0.03898527020854609, 0.012628609630545335, 0.04087317515430706, 0.09559797096465315, 0.014322127015995128, 0.07333955248551709, 0.025184356474450657, 0.0037582515256612426, 0.07128691620060376, 0.07143470791301557, 0.03921492377828274, 0.03923609407086458, 0.012881542040434266, 0.01940709728348468, 0.03366110447262015, 0.06809850050402538, 0.056225647418094535, 0.026403219106474092, 0.009041440955895399, 0.006226032074274761, 0.08864033395158392, 0.05602453981659242, 0.030585471474166428, 0.049818142849419794, 0.050209080800414085, 0.029971929932279245, 0.016326989346582974, 0.00980143410353256, 0.009128707344643772, 0.01608244193318699, 0.031343317058469565, 0.01867330746193017, 0.03390309041632073, 0.008154404848547918, 0.025651025718876293, 0.02863568752737982, 0.031823075243404934, 0.012013653343144273, 0.0253790213859507, 0.05783757181572063, 0.044935143619243584, 0.16868851466902665, 0.131858638088618, 0.08502039033919573, 0.13500902189740113, 0.20189470212374414, 0.17652822685028824, 0.12400038833064692, 0.22418695235891, 0.16169302218726703, 0.1680206869329725, 0.22014084804270947, 0.17742606438696384, 0.08278542490942137, 0.10015240657542433, 0.1283595279923507, 0.14081587030419282, 0.1305312743144376, 0.1993108814848321, 0.1545655953564814, 0.15036657638847828, 0.19620207830199174, 0.1556634378752538, 0.13428699278405734, 0.09912583058966057, 0.12270283938518592, 0.12455667848033564, 0.12265437841415405, 0.13596591912209988, 0.10224098486027547, 0.17261867092124053, 0.08235545083880424, 0.17256269178220204, 0.075636793859303, 0.23256627629910195, 0.10659742395260505, 0.1346276445048196, 0.16978206884648117, 0.0905338062771729, 0.22517133025186403, 4.249262043407985, 26.062963894435338, 60.870645659310476, 85.20170157296317, 82.46103327614921, 79.77191366468156, 75.16943386622837, 71.04043906075614, 71.18666390010289, 53.60646036693028, 51.78025490897042, 35.351538113185335, 36.9297901562282, 43.840847151620046, 36.32543931688581, 62.99471691676548, 80.92025634220668, 42.81664793831961, 37.76231983729771, 43.10774966648647, 52.21661220278059, 56.32037462506975, 61.63495445251465, 43.25453730991909, 31.75829110826765, 25.84680543627058, 15.196384293692452, 7.649504593440464, 5.180424443313053, 3.0142738095351627, 1.1914964190551212, 0.3558768523590905, 0.22133303407047475, 0.19269717351666518, 0.1744812224060297, 0.2392328285745212, 0.1743685041687318, 0.08300981644008841, 0.1935944410839251, 0.19456855952739716, 0.2447660102375916, 0.19596646380211624, 0.3058616832963058, 0.2243125763322626, 0.2811855902629239, 0.23487704087580952, 0.32597180562359945, 0.4068400434085301, 0.8541189825960568, 0.7005049511790276, 0.259413762816361, 0.33527503641588347, 0.48408452421426773, 0.23146813522492135, 0.16104764038962976, 0.15840276516973972, 0.1503359880298376, 0.19542006669299944, 0.10831797841404166, 0.6839627559695924, 0.3217676026480538, 0.1430444914315428, 0.24234184888856752, 0.13035443451787743, 0.3739183928285326, 0.29693330238972393, 1.3464200773409434, 0.8976259423153741, 3.2687296526772633, 7.44172305720193, 14.981182949883596, 25.45701149531773, 44.33910594667707, 59.05103056771414, 72.23322936466762, 63.22435488019671, 71.64118031093052, 57.68922185897827, 62.485539027622764, 50.976799964904785, 38.076347146715435, 33.816479546683176, 35.53750317437308, 38.10067973818098, 51.58900921685355, 64.88578728267125, 63.834691592625205, 75.01260607583183, 72.87477738516671, 70.14952714102608, 33.78176982062203, 13.076788544654846, 1.2718107551336288, 0.18405028964791978, 0.22049414765621933, 0.10827288297670228, 0.09573272801935673, 0.07206841890833207, 0.18392591417900153, 0.19838715105184487, 0.15792661000575337, 0.14640367403626442, 0.15277680062821933, 0.11138010517294918, 0.1479222218372992, 0.10956788063049316, 0.1322942032877888, 0.08935124866132226, 0.12626210839620658, 0.18362946222935403, 0.09699272005153553, 0.23946765597377503, 0.11142077656196696, 0.07185507392776863, 0.07112515345215797, 0.07709143723228148, 0.18158213208828652, 0.14112096678997788, 0.20490492773907526, 0.1409678485776697, 0.14313443803361484, 0.10003957977252347, 0.1665737381471055, 0.07879587648702518, 0.1511259249278477, 0.0715290242806077, 0.14757844885545118, 0.15320978739431926, 0.12826419382223062, 0.11200347529458148, 0.13748822600713798, 0.08753871199275766, 0.1624306711767401, 0.11026049525077854, 0.14399902735437664, 0.1751853653362819, 0.17616173651601585], [0.05977869087031909, 0.009706870918827397, 0.028114124799945524, 0.03039223827155573, 0.016045463471008197, 0.03858058513807399, 0.007431486006160932, 0.02002147681611989, 0.015542528226173349, 0.005887589409082595, 0.026709915238565633, 0.05523393116891384, 0.02654701255128852, 0.02497370188523616, 0.009934549103491008, 0.0311735136700528, 0.038079941645264626, 0.019037799510572637, 0.02652067521453968, 0.01660069849874292, 0.055003982436444075, 0.0345161875177707, 0.021123085204245787, 0.07668848921145711, 0.03409396231706653, 0.009913873293304017, 0.007759082713164389, 0.031097378648285354, 0.042435047416282554, 0.04656095762870141, 0.05007031699642539, 0.07077389622905425, 0.03078598535752722, 0.02309767808765173, 0.0623328188168151, 0.13219604641199112, 0.07049296237528324, 0.1973686564181532, 4.518108257225581, 22.982450519289287, 49.6872490474156, 57.84635884421212, 59.01338522774832, 58.02162020547049, 49.22069835662842, 52.403119223458425, 37.52809258869716, 39.555448395865305, 24.526022366115026, 19.441516501562937, 26.363640240260533, 29.140027488980973, 51.26981592178345, 39.62822035380772, 29.393169471195765, 22.794274193899973, 34.48366641998291, 52.81509528841291, 46.67915153503418, 35.96869795663016, 26.086337634495326, 12.34384218284062, 10.273975559643336, 3.8535182731492177, 1.6755380055734088, 0.2985533997416496, 0.17115665865795954, 0.06804550691906895, 0.04082408993105803, 0.04110539697908929, 0.1445900449263198, 0.04252868185618094, 0.021867633198520968, 0.11812215803989343, 0.07756826414593629, 0.05560434004291892, 0.06745055384401764, 0.2550002453582627, 0.23488602467945643, 0.2243930505854743, 0.04659544077834912, 0.009020831302872725, 0.10105835260557276, 0.20887738386435167, 0.08349023280399186, 0.12387751920947007, 1.2613273348127092, 0.5724611591015543, 0.7593019647257668, 0.5843611434102058, 0.10754938822771822, 0.1559328841311591, 0.05548850393721035, 0.10703803745231458, 0.15325933402138098, 0.24297418924314634, 0.05392703879624605, 0.11685314827731677, 0.10898292237626654, 0.22547063204858983, 0.1688056569546461, 0.11837460020823137, 0.02363861638254353, 0.06413472962698766, 0.028746482117899826, 0.025780322263017297, 0.14839752204716206, 0.21658167402659143, 0.5317584489073072, 0.48096223175525665, 1.2756976208516528, 2.9622470012732913, 8.364130292619977, 24.45821837016514, 46.956648690359934, 55.062250409807476, 54.89447920663016, 55.86681011744908, 36.17775535583496, 14.579021215438843, 14.834412676947457, 16.463365725108556, 13.968023555619375, 28.444799423217773, 30.205399990081787, 43.29983956473214, 51.49180391856602, 57.485375608716694, 55.3493013381958, 48.382488523210796, 33.51336438315255, 9.545385718345642, 0.8113726334912437, 0.0961339118491326, 0.09693258827818291, 0.05578210264710443, 0.030093581083097627, 0.054533862841448615, 0.04836904650021877, 0.029686385433056524, 0.0394836338236928, 0.07392369649772133, 0.011440588111457015, 0.03888894537729876, 0.01576805460665907, 0.004182279933177466, 0.07034259901515075, 0.027713855296107273, 0.07533869306956019, 0.05252530758402177, 0.017673545483765856, 0.004120355555122452, 0.01790077837982348, 0.07114512952310698, 0.021739937997023975, 0.03959200943687132, 0.0022478185793651, 0.01711069220410926, 0.009848179229136025, 0.030874557926186492, 0.01907780932794724, 0.05883533720459257, 0.03497584071010351, 0.011665223066561987, 0.018308469360428195, 0.05797324489269938, 0.07951424151126828, 0.048372181332004924, 0.07851216742502791, 0.004214140120893717, 0.01917488733306527, 0.023916177917271852, 0.024168849091178606, 0.02913424452500684, 0.01090776000637561, 0.015110696665942669, 0.05412548993315015, 0.049018323088863065, 0.02743005972089512, 0.038552717704858096, 0.015610720995547516, 0.02336058665865234, 0.0018755874147505633, 0.03336447271119271, 0.05859338518764291, 0.028540845295148234, 0.04373310865568263, 0.03957259654998779, 0.03735071327537298, 0.03247419066194977, 0.03999753249809146, 0.04395755786182625, 0.05092889449692198, 0.0023329694231506437, 0.0483336371502706, 0.022132450149261525, 0.023513928787516694, 0.018880513396912386, 0.03225115620132003, 0.007311547308095864, 0.0857280684368951, 0.07400992472789117, 0.047120155300945044, 0.03059834328347019, 0.04504687798076442, 0.024668294969680052, 0.00921182194724679, 0.013789999498320478, 0.04107731580734253, 0.06910784170031548, 0.02751110733619758, 0.06824020575731993, 0.051049185185027976, 0.3699205459228584, 5.2354307259832105, 24.299792494092667, 55.82938711983817, 66.91603701455253, 69.00578417096818, 66.76549039568219, 59.66635608673096, 62.19134535108294, 47.772544384002686, 47.521908964429585, 31.392020293644496, 33.243843759809224, 32.1167174066816, 38.45320701599121, 59.747914041791645, 47.25163793563843, 39.35591002873012, 31.588341644832067, 42.340154375348774, 43.53155503954206, 40.182801246643066, 25.54177256992885, 17.91243859699794, 9.171086260250636, 6.670543364116123, 2.0018213944775716, 0.8591553409184728, 0.1453570066285985, 0.04906934892226543, 0.14815786347857543, 0.026609653207872595, 0.033721015722091706, 0.1593738030642271, 0.08462694180863244, 0.18164678290486336, 0.3335708278630461, 0.1662657239607402, 0.14940906848226274, 0.7196025092686925, 0.8835904183132308, 1.4750255878482545, 1.2410051567213876, 0.17048336192965508, 0.08737639284559659, 0.08743665354060275, 0.1568714337689536, 0.18643076691244329, 0.5334378502198628, 2.4946534293038503, 3.192758483546121, 2.5889124742576053, 1.5095749625137873, 0.3999222703278065, 0.4882685882704598, 0.3803481363824436, 0.43795643800071304, 1.0988218890769141, 0.7617668924587113, 0.5976506588714463, 0.4553653395601681, 0.21153616905212402, 0.5831344606620925, 0.7248054615088871, 0.19460482043879374, 0.39057200348802973, 0.2635133628334318, 0.07095663928027664, 0.09974024404904672, 0.2457773531121867, 0.22278466474797043, 0.3781121192233903, 0.44184246233531405, 1.2180401661566325, 3.265217121158327, 9.389839002064296, 25.790830748421804, 45.94631460734776, 60.58554022652762, 55.96534252166748, 61.649545669555664, 45.558612074170796, 25.459497213363647, 14.785099574497767, 24.27546337672642, 22.510686942509242, 38.217159339359824, 37.00908299854824, 49.85101808820452, 59.21916307721819, 63.359198570251465, 62.991228921072825, 56.825831753867014, 43.943645749773296, 14.651617731366839, 1.7249044137341636, 0.1403176627521004, 0.01628238075811948, 0.07499962233539138, 0.08052328415215015, 0.04710834879162056, 0.1131614970841578, 0.07874738837459258, 0.026719441870227456, 0.03464920073747635, 0.026323772833815644, 0.05310593339215432, 0.04690438795036503, 0.0029229515930637717, 0.01527330419048667, 0.02729300412881587, 0.07525421545973845, 0.05681324517354369, 0.032958552706986666, 0.12454286350735597, 0.042169998067298105, 0.011037229576946368, 0.05444073730281421, 0.033845177452479086, 0.02781003593866314, 0.04353726648592523, 0.010482768079132905, 0.042601709187562974, 0.024206667240442972, 0.03721373062580824, 0.022862228132518272, 0.048686634815697155, 0.04410997379039015, 0.09014004562050104, 0.05464243862245764, 0.0417542698393975, 0.09702725069863455, 0.10553882789931127, 0.03313455790547388, 0.024325222575238774, 0.045244199356862476, 0.05324817129543849, 0.07066266398344721, 0.06906882593674318, 0.14171328714915685, 0.14843440721077578, 0.0969138199995671, 0.07999964510755879, 0.19743386363344534, 0.1992231604776212, 0.08662742589201246, 0.11122276647282497, 0.09148364673767771, 0.17725708202591964, 0.09952155899788652, 0.12565271609595843, 0.08018993346818856, 0.13441429952425615, 0.09149833023548126, 0.1375228584344898, 0.11186710332653352, 0.11039292493036815, 0.10550116242042609, 0.09950116223522595, 0.17000713891216687, 0.12567774046744618, 0.13667122913258417, 0.18970574332135065, 0.13492641704423086, 0.16946219386798994, 0.16923470821763786, 0.13959061247961863, 0.15864519216120243, 0.0978363494255713, 0.11556184185402733, 0.1747905665210315, 0.13429026332284721, 0.12268968937652451, 0.14279791180576595, 0.21918462935302938, 0.13386468615915093, 0.7348332319940839, 8.483637571334839, 36.116969040461946, 68.75255012512207, 79.69468443734306, 77.03756128038678, 77.2140177318028, 65.74538367135185, 69.5367099217006, 53.948541028159006, 55.10587467466082, 36.71240186691284, 30.66895600727626, 39.27564096450806, 41.55252742767334, 60.59241894313267, 52.846567153930664, 40.81447240284511, 30.2239898954119, 48.702908175332205, 67.06590270996094, 58.36043521336147, 44.96796308244978, 31.056658540453228, 15.523757355553762, 12.383847304752894, 4.712153204849788, 2.2279967665672302, 0.7905619101864951, 0.4876621408121926, 0.20830394034939154, 0.1899501516350678, 0.1553147794412715, 0.430472088179418, 0.11140566558710166, 0.29588634999735014, 0.3281657536114965, 0.14387052639254502, 0.21591466053255967, 0.41239955223032404, 0.6605956384113857, 1.5499842741659708, 1.2931157776287623, 0.27762474705066, 0.23070825742823736, 0.5153069059763635, 0.43891995772719383, 0.6070906551820892, 0.4467340484261513, 3.13710732119424, 2.698984750679561, 1.5319890912090028, 0.9197001521076474, 0.36233246166791233, 0.2982188005532537, 0.2878871549453054, 0.1885711106338671, 0.5750986518604415, 0.6337684265204838, 0.40182319975325037, 0.45164110511541367, 0.21275157454822743, 0.5467358880809375, 0.6452585756778717, 0.2694388191614832, 0.36348542837159975, 0.3219525170113359, 0.11635705775448255, 0.2533466826592173, 0.3430045545101166, 0.5443722520555768, 0.8676109186240605, 0.8883012969579015, 1.96682961497988, 4.270240826266153, 11.31599863937923, 30.884277207510813, 55.08938659940447, 63.8598301751273, 63.682338442121235, 65.57073375156948, 47.3032352583749, 25.33296877997262, 22.392322642462595, 27.026434115001134, 24.58161837714059, 43.3419908114842, 47.25302062715803, 61.025124958583284, 68.6903429031372, 72.60325568062919, 70.90923622676304, 64.9910385949271, 50.01380395889282, 18.860522031784058, 2.3312693621431078, 0.19920721490468296, 0.1724230492753642, 0.2211114652454853, 0.15330627507397107, 0.20366561066891464, 0.19386124105325767, 0.1301191999976124, 0.16395558363624982, 0.1637285322483097, 0.07094439172319003, 0.1077920798478382, 0.10796427167952061, 0.09880141621189457, 0.12059009846832071, 0.1011495544974293, 0.18432557130498545, 0.1335916029555457, 0.09432944296193974, 0.193286942584174, 0.0740785381889769, 0.15295013918408326, 0.1814138146915606, 0.18437566076006207, 0.1386235643710409, 0.0856910679223282, 0.19920983404985496, 0.11334254379783358, 0.10765194201043674, 0.12481974650706563, 0.22895362015281404, 0.17115830071270466, 0.08601866462933165, 0.15380749532154628, 0.16422825971884386, 0.2198883787329708, 0.19075501630348818, 0.10424685651170355, 0.09724039890404258, 0.06446814816445112, 0.15759069445942128, 0.10218662063458137, 0.16684838198125362, 0.14346151905400412], [0.026594440452754498, 0.04309764025466783, 0.017049909037138735, 0.012710541037709584, 0.036264110689184496, 0.06985325991575207, 0.04021474512826119, 0.017072068294510245, 0.002908980132945414, 0.041649202084434886, 0.028384146114279116, 0.022237962344661355, 0.019381728555474962, 0.027165319105344157, 0.029006832611880133, 0.013177787885069847, 0.048772279505750964, 0.037929476504879336, 0.07285285288734095, 0.031991704766239436, 0.016145121605534638, 0.07461065892130136, 0.03497664138142552, 0.006804735507882599, 0.10283072000103337, 0.03408351966312953, 0.04240576523755278, 0.027842356257938912, 0.06061286825154509, 0.03985698414700372, 0.03502523805946112, 0.022658497993169085, 0.018696079097156013, 0.009538505176481391, 0.058986433382545195, 0.10942420762564455, 1.272864818572998, 7.582772357123239, 25.23505129132952, 48.47446182795933, 60.83828789847237, 60.603612491062705, 56.05021824155535, 50.53105912889753, 41.52859435762678, 34.14335060119629, 46.152568408421104, 20.290727070399694, 22.943834168570383, 18.51798105239868, 21.3124874659947, 19.587444305419922, 26.088123321533203, 25.083005598613195, 20.126937185014995, 37.641664368765696, 35.7739816393171, 29.818840435573033, 15.923532383782522, 13.603119799068995, 6.234804459980555, 2.9402368451867784, 0.3295167168336255, 0.19331529177725315, 0.11799105150359017, 0.15984131369207585, 0.014019463078251906, 0.12794647658509867, 0.14661306994301931, 0.20721003333372728, 0.04148035543039441, 0.13984270180974687, 0.16232300123998097, 0.3950819272015776, 0.16116054861673287, 0.293602889669793, 0.2401082744555814, 1.0813759395054408, 1.3237435455833162, 0.8223766801612717, 0.23278072050639562, 0.1044862029541816, 0.10031079700482742, 0.10540102422237396, 0.14238410043929303, 0.5720090376479285, 2.1059549152851105, 1.8188297280243464, 3.969224887234824, 1.5834441930055618, 0.5248173613633428, 0.45888780483177727, 0.40159578195640017, 0.46820962748357225, 0.5394198692270687, 0.583558083644935, 0.5304400282246726, 0.5134565681219101, 0.4790152705141476, 0.45311320040907177, 0.08364186502460923, 0.5123989220176424, 0.19646323285996914, 0.2028703133442572, 0.16655463060098036, 0.08168893946068627, 0.02782553367848907, 0.027404136290507655, 0.05326749936544469, 0.09720804635435343, 0.10037700845194714, 0.36345144733786583, 1.16143199801445, 2.6604187744004384, 7.6472915921892435, 15.158441918236868, 28.533639090401785, 26.022890159061976, 27.585713727133616, 35.99499341419765, 74.52573885236467, 22.84529655320304, 20.417389256613596, 15.97091736112322, 32.98006929670061, 38.18473904473441, 43.386910915374756, 48.879944801330566, 50.29601894106184, 53.50668770926339, 57.05517789295742, 44.19063336508614, 21.06809847695487, 5.138104268482753, 0.3194160988288266, 0.03065942500584892, 0.08067727767463241, 0.008660478317844016, 0.06903846828000886, 0.02177847539340811, 0.046829012887818475, 0.05773885175585747, 0.017244331372369612, 0.03692597410242472, 0.06440501048096589, 0.01179839574199702, 0.036549495732677836, 0.042288758658937046, 0.04834304503830416, 0.021896226664206812, 0.0244138918351382, 0.03751950903928705, 0.02313600174550499, 0.06359747916992221, 0.03134491161576339, 0.011453631250852985, 0.038574546176408014, 0.014540201385638543, 0.07642456623060362, 0.02449672399753971, 0.018462768223668848, 0.05886532845241683, 0.018369038788867847, 0.05126470487032618, 0.0019876667689199424, 0.021186102447765212, 0.030590190685221126, 0.01572474880543138, 0.03183774856318321, 0.0207083255850843, 0.0298440362592893, 0.011259289491655571, 0.08601966886115925, 0.031370427925139666, 0.024078361357429197, 0.03304848913103342, 0.03308681957423687, 0.008657175548640745, 0.05813493300229311, 0.016762547760403583, 0.01791454415901431, 0.041700082032808235, 0.009698744613810309, 0.04680504024560962, 0.01228072981549693, 0.060582829506269524, 0.0292906468468053, 0.006911588234028646, 0.012866846668267888, 0.012944254791364074, 0.0011618795792206324, 0.006518479819143457, 0.04078544057639582, 0.010833753040060401, 0.01761042476365609, 0.029535811727068255, 0.005366094959234553, 0.019007326502885138, 0.02708531473763287, 0.024728937340634208, 0.05243646699403014, 0.021775260833757262, 0.04537333474893655, 0.01351945910469762, 0.01605928353300052, 0.015818381548992226, 0.053276880112077506, 0.06494153490556137, 0.021348172233306935, 0.02250571226302002, 0.09160332674426691, 0.07032896046127592, 1.2527282876627786, 8.422009655407496, 30.38246440887451, 57.343198095049175, 70.16270092555455, 71.39136477879116, 63.815097672598704, 62.039596693856375, 48.635986600603374, 44.092191287449424, 51.386368479047505, 33.082374572753906, 28.342751230512345, 19.70602921077183, 27.056976658957346, 23.063900777271815, 33.986290046146934, 32.645843573978965, 25.093612023762294, 27.260805538722447, 30.17339311327253, 29.4291125025068, 14.453606230872017, 9.631490400859288, 3.6874120320592607, 1.3515031188726425, 0.3450748734176159, 0.16290878052158014, 0.14504923671483994, 0.15789437959236757, 0.23833276544298443, 0.4158205086631434, 0.4308532348700932, 0.6943915677922112, 0.4646803225789751, 0.889731268797602, 0.5695288564477647, 0.825591579079628, 0.8649533955114228, 1.3173413234097617, 1.4241709624017989, 3.1249729437487463, 2.1013143871511732, 2.69259067092623, 0.9980843003307069, 0.14626732920961721, 0.1675922463514975, 0.07518473347382885, 0.23173566801207407, 0.8386880106159619, 4.853456114019666, 5.761851004191807, 7.3340337957654675, 4.237909121172769, 2.300179213285446, 2.3910601309367587, 2.081418437617166, 3.1902143572057997, 2.7236588895320892, 3.027190510715757, 2.749882910932813, 1.8124760346753257, 2.0638764074870517, 1.7609487367527825, 1.2047694325447083, 2.3702465849263326, 0.7110538365585464, 1.0027947447129657, 1.0865901282855441, 0.28354466653295923, 0.1207041194928544, 0.08630759162562233, 0.08671583221959216, 0.18213350964444025, 0.1344101604606424, 0.190207587821143, 1.2356062978506088, 2.698009397302355, 9.16095231260572, 14.18595814704895, 28.26208438192095, 29.149610791887554, 30.342672075544083, 25.78573771885463, 67.46474320547921, 29.405999319893972, 23.77844830921718, 20.909302609307424, 38.5829507282802, 46.69505943570818, 49.74987316131592, 55.3051837512425, 59.91489315032959, 62.192936488560264, 64.29428018842424, 53.239800453186035, 27.60324924332755, 7.495016608919416, 0.297056252935103, 0.06144346296787262, 0.06612224012081112, 0.02099034679122269, 0.040949679977659664, 0.031194168276020458, 0.08122624643146992, 0.06605210674128362, 0.0863153404955353, 0.015439168683120182, 0.04048022534698248, 0.007637159300169775, 0.048272019385227134, 0.031908563870404444, 0.05409775820693799, 0.04013929542686258, 0.03928283156294908, 0.04658898791032178, 0.042637671543551345, 0.048934157605149915, 0.021588499158886925, 0.061392403207719326, 0.0484504096343049, 0.01227735834462302, 0.028111746534705162, 0.037400629704019854, 0.07736811667148556, 0.029696610955787555, 0.06356502483998026, 0.02302369232555585, 0.029842305994991745, 0.03715075918340257, 0.10137528274208307, 0.02119320840574801, 0.014010630248646651, 0.06395691274000065, 0.008787985225873334, 0.06205475516617298, 0.03126877659399595, 0.04932016260655863, 0.05369719184402909, 0.026903826976194978, 0.11121513295386519, 0.14919113660497324, 0.11828826341245856, 0.12333032142903123, 0.26471751821892603, 0.12069675060255186, 0.10924217025084154, 0.11158338747918606, 0.16226281518382685, 0.18306306190788746, 0.10663335238184247, 0.1388704561229263, 0.16081259585916996, 0.14206749599959168, 0.08334419171192817, 0.07227377753172602, 0.10830286065382616, 0.15441542198615416, 0.14427767454513482, 0.15805002195494516, 0.1337077138679368, 0.08226401824504137, 0.0564108637294599, 0.11234432379049913, 0.16295456806463854, 0.12050571585340158, 0.10397022456995078, 0.09363262820988894, 0.1570546246532883, 0.1537782640329429, 0.1140963826328516, 0.17466068134776183, 0.12413222768477031, 0.14117948364998611, 0.19873366531516823, 0.2800915203988552, 2.2613446457045416, 12.915537357330322, 39.209532329014365, 69.4986685344151, 82.68835054125104, 80.00879859924316, 74.9226963860648, 68.9398388181414, 59.16254220690046, 48.98737437384469, 59.771315574645996, 32.197618756975444, 35.0244516645159, 27.23562526702881, 33.29100118364607, 30.317283357892716, 34.4565406526838, 36.3873929296221, 29.711838177272252, 47.8064272744315, 44.64116498402187, 36.71170704705374, 20.059195722852433, 15.47303203174046, 7.750613042286464, 3.64313029391425, 0.6417311163885253, 0.4075301135224955, 0.20970199390181474, 0.30680229568055695, 0.16353550260620459, 0.38285589324576513, 0.46370876899787355, 0.6162814934338842, 0.28265399432608057, 0.5301496695194925, 0.4709986778242247, 0.6133821947234017, 0.5574424107159887, 1.2692556636674064, 1.1988760573523385, 2.5986425578594208, 3.5168246371405463, 1.5833724311419894, 1.150517572249685, 0.6317639797925949, 0.23010121285915375, 0.3002118750342301, 0.452229802097593, 1.1692960560321808, 7.098913703645978, 8.376346094267708, 7.999315994126456, 3.274409805025373, 1.617456493633134, 2.6887674246515547, 1.567511430808476, 3.142390557697841, 3.0234208958489552, 2.643155323607581, 1.5793853593724114, 1.5017693127904619, 2.1200297943183353, 1.37123133455004, 1.0162315836974551, 1.9673869907855988, 0.5816643195492881, 0.6901107175009591, 0.6098728658897536, 0.3157668017915317, 0.25369395688176155, 0.2684421869260924, 0.13966967537999153, 0.5119183020932334, 0.352341494922127, 0.808784863778523, 2.116692270551409, 4.113303601741791, 10.901571597371783, 20.766485861369542, 38.3725141116551, 36.76974187578474, 37.67110736029488, 45.36666808809553, 84.13404137747628, 31.64606727872576, 29.00979913984026, 28.01848575047084, 47.6344941002982, 54.772760663713726, 57.94114964348929, 64.94037233080182, 68.13992745535714, 71.10143034798759, 72.93344797406877, 61.869497844151084, 33.233459677015034, 8.445142814091273, 0.7868563490254539, 0.31397983910781996, 0.19170546744550976, 0.10932950449309178, 0.15831072867981025, 0.16451585000114782, 0.17189081997743674, 0.13538708803909166, 0.14462163751678808, 0.13701146016163485, 0.19145299813577107, 0.08998390114200966, 0.10386030868227993, 0.14775254737053597, 0.14227951105151856, 0.13970170223287173, 0.14044057258537837, 0.1184568250817912, 0.16349848173558712, 0.19321412220597267, 0.10047711950859853, 0.1354280172714165, 0.1378038940685136, 0.051901930677039285, 0.16064788826874324, 0.1631055963890893, 0.16818842078958238, 0.08828056789934635, 0.1364017285938774, 0.10291939095727035, 0.08780046366155148, 0.08351440222135612, 0.18004956575376646, 0.10355367192200252, 0.08015990829361336, 0.11280369199812412, 0.06271805707365274, 0.17169466907424585, 0.1436687165072986, 0.10484186386955635, 0.16918558228228772, 0.23535953355687006], [0.04597959221739854, 0.07126021584761993, 0.0592369960088815, 0.02409831707232765, 0.005663496009739382, 0.0160856514038252, 0.03674472722091845, 0.03868317284754344, 0.032852127881986756, 0.06568750951971326, 0.061810699690665515, 0.04996512710515942, 0.07617392896541528, 0.03447593682046447, 0.03236325697175094, 0.06926207271005426, 0.05607954186520406, 0.02019468305765518, 0.04809400572308472, 0.019446934074429528, 0.03552342525550297, 0.012726682537634457, 0.0416865452591862, 0.036121689581445286, 0.019939767629174248, 0.04822726321539708, 0.05986626259982586, 0.0163696997333318, 0.062089441876326285, 0.04201410464676363, 0.026338943180495074, 0.01664724260834711, 0.006504755176138133, 0.008200136412467276, 0.04601940865229283, 0.27937724015542437, 4.035321363380977, 28.226989030838013, 49.781692436763215, 44.49630893979754, 57.90613072259085, 52.05701208114624, 45.86484350476946, 42.239242213112966, 30.99770654950823, 28.967418602534703, 37.648473603384836, 19.378637041364396, 22.78663812364851, 44.4758951323373, 29.125076702662877, 25.78530866759164, 46.333155563899446, 38.926612104688374, 43.0659944670541, 36.03992394038609, 24.95282588686262, 8.373481699398585, 5.0687456130981445, 0.9685077731098447, 0.12275467946061067, 0.08466274131621633, 0.04694263357669115, 0.012010758543120963, 0.14189274609088898, 0.15885758719273976, 0.12633320529546055, 0.41716197239501135, 0.44900643506220406, 0.3929544213627066, 0.13236022474510328, 0.7496005424431392, 1.1644009415592467, 0.6243059028472219, 0.7643155242715562, 0.7977183376039777, 2.5131021993500844, 3.216287689549582, 2.4933493392808095, 2.4334295945508138, 0.4158342150705201, 0.20282170309552125, 0.16573776943343027, 0.022292993231011287, 0.17369334825447627, 1.6439167537859507, 3.3887530522687093, 5.460280512060438, 7.163297014577048, 4.444970216069903, 1.077854722738266, 2.682085863181523, 1.410034418106079, 2.8516992075102667, 4.349746457168034, 1.8980118334293365, 1.5195824312312263, 1.340004827295031, 1.451116293668747, 1.7351119688579013, 1.3735603924308504, 1.638511598110199, 0.9408233272177833, 1.0533033715827125, 0.9382230724607195, 0.19665156703974518, 0.2909008003771305, 0.11486879975668021, 0.2972856249128069, 0.0660487547782915, 0.024507965626461164, 0.0350906081231577, 0.046980560291558504, 0.29110449658972876, 1.2283907021795, 5.749336430004664, 13.02885205405099, 33.65844276973179, 52.57570552825928, 71.51921163286481, 36.22246353966849, 27.87191697529384, 26.623582771846227, 18.935413190296718, 19.911016702651978, 24.72609748159136, 33.707632541656494, 41.847054617745535, 34.36417130061558, 47.43010241644723, 57.012932845524375, 55.72830820083618, 48.32365117754255, 31.176348209381104, 9.704931122916085, 2.6354569367000034, 0.3661608105259282, 0.1158860730273383, 0.10751789063215256, 0.04638175992295146, 0.0525930152008576, 0.04657396175233381, 0.04352196212857962, 0.05552384204098156, 0.055415459642452855, 0.020452899559001838, 0.01211785342145179, 0.01760314577924354, 0.06829106195696763, 0.06081143473940236, 0.014669711668310421, 0.03607677734856095, 0.012006527029110916, 0.030608334711619785, 0.03456191738535251, 0.032128253153392246, 0.03369304650862302, 0.024554799809785824, 0.019785662148413912, 0.03597216760473592, 0.05986445091132607, 0.020990168675780296, 0.01879931820024337, 0.02146328569922064, 0.01486195420979389, 0.01736661695343043, 0.04883187523643885, 0.0360676137331341, 0.025657273330060498, 0.018598493887111545, 0.017960779535185014, 0.01579985415030803, 0.0025234060012735426, 0.037344073810215504, 0.02748598457713212, 0.04154549479218466, 0.01735701907559165, 0.01942298178827124, 0.04402259883603879, 0.04070531576871872, 0.04228917595797351, 0.044140131279293976, 0.01760727466483201, 0.03711495628314359, 0.025587051740980575, 0.05610091911096658, 0.04764893085562757, 0.044469736449952633, 0.049258229322731495, 0.042656897833304744, 0.04906327264117343, 0.028165082779846022, 0.036486375012568066, 0.02583173316504274, 0.021705302176997066, 0.026527550470616137, 0.035874017514288425, 0.022782729273395877, 0.09193198875124965, 0.027538219899205223, 0.05576432163694075, 0.012359405102740442, 0.02061322720588318, 0.02071567072666117, 0.054522507557911534, 0.013241928952213908, 0.01818664009416742, 0.011613803682848811, 0.02862932626157999, 0.053547167751405916, 0.041308292520365546, 0.3747405872813293, 4.696609650339399, 32.57530198778425, 56.84593636648995, 56.657303197043284, 69.4324174608503, 61.57301821027483, 52.51350178037371, 53.629729884011404, 42.04529367174421, 38.25209140777588, 44.87866483415876, 21.632002115249634, 29.62609393256051, 46.05005121231079, 31.969596249716624, 28.55596191542489, 39.53831761223929, 33.03774281910488, 30.806992394583567, 32.45407676696777, 20.011843749455043, 8.593150734901428, 3.4179313608578274, 0.9646666135106767, 0.13406137989035674, 0.08964553608426026, 0.26295601416911396, 0.10691501905343362, 0.40813376541648594, 0.6498429753950664, 0.5793858532394681, 1.1627138320888792, 0.8217488452792168, 1.5886298290320804, 2.8064531896795546, 3.053324422666005, 2.1391996570995877, 4.139097920485905, 5.364391897405897, 3.979344069957733, 5.5829479183469495, 4.580385395458766, 3.423225236790521, 2.6580062295709337, 0.45711867404835566, 0.1598998305520841, 0.23267894025359834, 0.11023915532444205, 0.22774865052529744, 1.556904679962567, 5.016514701502664, 6.732047080993652, 9.351605670792715, 9.563582181930542, 5.345285654067993, 4.873814335891178, 6.164752721786499, 4.14191107239042, 9.8062002488545, 5.714677946908133, 5.946408186640058, 4.244751359735217, 4.094319820404053, 2.9527579333101, 4.304095489638192, 5.8059824875422885, 2.3894505373069217, 3.0708154269627164, 2.329919240304402, 1.913539103099278, 1.2618450841733386, 0.96089135323252, 1.0940282834427697, 0.5719071488295282, 0.04740097041108778, 0.07438496460339852, 0.02434986357444099, 0.09810402470507792, 0.6491147716130529, 3.818227503980909, 10.36134307725089, 25.69363760948181, 40.88397175925118, 63.532333782741, 44.529691559927805, 25.74700845990862, 24.592952626092092, 27.053427866527013, 33.47747346333095, 31.45816019603184, 41.20998123713902, 49.747024399893625, 41.53097064154488, 55.616053104400635, 65.31987598964146, 64.23453957693917, 57.50403847013201, 40.28290741784232, 15.826632806232997, 4.578581903662, 1.1306566894054413, 0.08134178737444536, 0.08673157423202481, 0.04647080746612378, 0.033247622195631266, 0.029249612441552535, 0.069271341498409, 0.03286659424858434, 0.06137518198894603, 0.018684637300404053, 0.026022057148760984, 0.05778575888169663, 0.040243118070065975, 0.05713217359568391, 0.012815961630881896, 0.008707657705859413, 0.06848188636026212, 0.025002999331003854, 0.05346972994240267, 0.0845309223181435, 0.03267156292817422, 0.007212976525936807, 0.024987679706620317, 0.031608597109360356, 0.014597985427826643, 0.008977673083011593, 0.04792024986818433, 0.01722360891290009, 0.05380352845947657, 0.02680369047448039, 0.03309466004637735, 0.00425011307899175, 0.07376143841871194, 0.02122216488766883, 0.031481063059930287, 0.059937549488885064, 0.02082610738995884, 0.03633714819859181, 0.030465041686381613, 0.022565531910264065, 0.06977597477712802, 0.09090261720120907, 0.18223149010113307, 0.1394924284624202, 0.12000665334718567, 0.1269019262066909, 0.09196065685578755, 0.17243793633367333, 0.14037901588848659, 0.1955933238246611, 0.11364025103726558, 0.1793280794684376, 0.18888772864426884, 0.10079668236098119, 0.08819515391119889, 0.10773438401520252, 0.2116102379347597, 0.12828646334154264, 0.11627096523131643, 0.12744575845343725, 0.16246694565883704, 0.08640291222504207, 0.18188029394618102, 0.08250299827860934, 0.11347258503415755, 0.14785378479531833, 0.16284997867686407, 0.16649392885821207, 0.11626455986074039, 0.09537687711417675, 0.14574233309498855, 0.08395852374711207, 0.18296721205115318, 0.10912189991878611, 0.1916424044008766, 1.1834456282002586, 8.583193097795759, 42.01954364776611, 70.25898211342948, 69.3401940209525, 80.51809460776192, 70.88245092119489, 61.760473660060335, 58.62495313371931, 44.06789691107613, 43.16533981050764, 48.04561901092529, 29.288171768188477, 35.24400084359305, 57.64499657494681, 41.609582560403005, 38.48018339702061, 60.93875190189907, 51.88046530314854, 56.19338239942278, 47.58342136655535, 30.439099175589426, 11.259386454309736, 6.496913092476981, 1.5303892684834344, 0.3198566037629332, 0.19373331006084168, 0.3439992054232529, 0.15144007307078156, 0.4862795035753931, 0.30007690084832056, 0.5802786967584065, 0.7545655731643949, 0.8568377909915788, 0.920465213911874, 1.688590522323336, 2.3629249206611087, 2.2142588751656667, 4.296353459358215, 6.0434280548776895, 4.871960469654628, 7.922220519610813, 7.569398811885288, 4.755921644823892, 4.897969748292651, 2.7547792196273804, 1.7893500413213457, 0.6780394166707993, 0.5109135817204202, 1.337939366698265, 7.331376109804426, 11.59721655505044, 10.905727488654, 16.98791650363377, 18.08708677973066, 7.21596132005964, 7.442785263061523, 7.326912760734558, 8.954323308808462, 12.888196195874896, 10.384667311395917, 9.077938709940229, 5.343274584838322, 5.227438126291547, 6.835294272218432, 4.6280578545161655, 6.404195461954389, 4.8232674939291815, 3.5147475600242615, 2.519723181213651, 1.3456958362034388, 0.7798721609371049, 0.7590023779443332, 0.9170520199196679, 0.4463378925408636, 0.19548156910708972, 0.27395368260996683, 0.1500920139785324, 0.5983083492943219, 2.1927416069167, 7.514509780066354, 16.395460980279104, 42.39122710909162, 64.16632216317313, 83.09869030543736, 46.71550451006208, 37.94372688020979, 37.41437489645821, 32.31781217030117, 31.608335086277553, 35.367241042000906, 47.41241577693394, 55.12107733317784, 50.43111276626587, 65.42201450892857, 73.87483160836356, 72.48508766719273, 66.13428129468645, 46.09856006077358, 19.112104143415177, 6.1969941002982, 1.4385258321251189, 0.2296325894338744, 0.1746237011892455, 0.17946460071418965, 0.09380880304213081, 0.15127376413771085, 0.11292935668357781, 0.20079821667500905, 0.12009028957358428, 0.12547755906624453, 0.0970329978902425, 0.18035836704075336, 0.22420143229620798, 0.10954561111118112, 0.09349065832793713, 0.1160697660275868, 0.1267658799354519, 0.14108937419950962, 0.12329589256218501, 0.11258297134190798, 0.12299391733748571, 0.11242228067879166, 0.08387937263718673, 0.13426807522773743, 0.10279920204941716, 0.10163990461400577, 0.12052042649260589, 0.14521268223013195, 0.14185394745852264, 0.16163322968142374, 0.15725636668503284, 0.1439479472381728, 0.10342319642326661, 0.08071696518787316, 0.162989078355687, 0.0951231796560543, 0.07632469944655895, 0.129999913541334, 0.09325861292225973, 0.12653150036931038], [0.06233220813529832, 0.04491751188678401, 0.015180975930499179, 0.03147745325363108, 0.0453325446162905, 0.06685165848050799, 0.05972226389816829, 0.018468771562246338, 0.036704445989536386, 0.020648561916979294, 0.04494639712252787, 0.03919497145605939, 0.03304677922278643, 0.043643765949777195, 0.02723127949450697, 0.02076995013547795, 0.034378102248800654, 0.036641681500311406, 0.13265784377498285, 0.02769819979688951, 0.009182306522104357, 0.05728452506342104, 0.04280131044132369, 0.04914110739316259, 0.015810615715703795, 0.055527048118944676, 0.06261674501001835, 0.04140689044392534, 0.03135531695027437, 0.05390103054898126, 0.011987978426207389, 0.033280117237674336, 0.039869767746755054, 0.018755584921953932, 0.09519704497818436, 4.114380572523389, 19.995977537972585, 47.34451103210449, 57.570431981767925, 53.52152558735439, 55.26456805637905, 46.28566115243094, 39.95154435294015, 35.39877891540527, 24.166407925742014, 20.798711606434413, 22.934325558798655, 36.543286187308176, 33.00133078438895, 29.363288743155344, 32.419467789786204, 30.491849899291992, 45.20275660923549, 35.65086650848389, 24.402886390686035, 7.4364007370812555, 2.5329542883804868, 0.6612116396427155, 0.13370349338012083, 0.14607666086937698, 0.10740120975034577, 0.18647386745682784, 0.105396586603352, 0.08738518665943827, 0.4395731155361448, 0.9469743285860334, 1.1727209751095091, 2.1452265679836273, 0.5533229974763734, 2.870055913925171, 3.6481620924813405, 4.420687130519322, 1.042684787086078, 3.354173387799944, 3.6470191138131276, 2.159521835190909, 3.3202850690909793, 5.21594363451004, 3.1563486201422553, 4.694328469889505, 1.115602765764509, 0.1019134424360735, 0.47663980083806173, 0.18551190836089, 0.13696899744016783, 0.16401059925556183, 3.885993719100952, 4.960733694689615, 9.269569158554077, 7.131135540349143, 4.814111505235944, 2.883295489209039, 5.170996606349945, 4.973042862755912, 4.406312610421862, 4.189099328858512, 6.015096340860639, 3.100955843925476, 3.186342690672193, 2.479579963854381, 2.935336193868092, 5.153299978801182, 2.3798993698188236, 2.9321189607892717, 2.7988646711621965, 1.8371731894356864, 0.8646672708647591, 0.3947997923408236, 0.49997955986431664, 0.43187152594327927, 0.19504376474235738, 0.07696339088891234, 0.2223066639687334, 0.02198806807531842, 0.04816047501351152, 0.018178711412474513, 0.9976810876812253, 3.917182445526123, 13.664778981889997, 19.440350941249303, 42.37207439967564, 56.48322302954537, 39.44474622181484, 17.767193453652517, 11.622949208532061, 19.526176827294485, 17.244912999016897, 45.97353417532784, 35.591824190957205, 33.62625176565987, 45.40240614754813, 51.201574189322336, 56.38424594061715, 56.75969532557896, 47.06574930463518, 27.467913968222483, 14.259960804666791, 2.97789933851787, 0.21448183884578093, 0.03950499410607985, 0.009106253772707922, 0.018081723313246454, 0.046848466486803124, 0.059073462284037044, 0.04140846464516861, 0.08698363642075232, 0.027253990061581135, 0.08584384686712708, 0.04917096632665821, 0.02325890988244542, 0.0174329759819167, 0.04383689397946, 0.035721004474908113, 0.0640944450029305, 0.05972223675676754, 0.0737013609281608, 0.10480596258171967, 0.0075559649516695315, 0.027164097742310593, 0.030505475588142872, 0.031744297327739854, 0.027135368569621017, 0.03573363201160516, 0.03147881032366838, 0.04745338724127837, 0.02209473886926259, 0.006437718884886375, 0.0532569515385798, 0.026057966918285404, 0.027727473493931547, 0.02613567274862102, 0.01604456950112113, 0.03133187356538006, 0.02240444769683693, 0.012046215390520436, 0.1145491147679942, 0.07942624230469976, 0.027849246781053286, 0.01273741526529193, 0.01487116701900959, 0.03626793762668967, 0.0114154068287462, 0.09470512744571481, 0.03234752853001867, 0.13320430873760156, 0.05537330565441932, 0.03399827191606164, 0.04768875746854714, 0.033085055383188386, 0.049232414457947016, 0.030848597176373005, 0.0047064864026781705, 0.08474571257829666, 0.032650623337498734, 0.04943474342248269, 0.022978447610512376, 0.036320795504642386, 0.04088385868817568, 0.09919892916721956, 0.023353209286662083, 0.018825803118358766, 0.0066930516124037755, 0.0506240524617689, 0.0773993224969932, 0.01752399806199329, 0.044739406622414074, 0.016768208438796655, 0.021617509923609238, 0.08984914408730608, 0.057041595956044536, 0.08736035906310592, 4.486343264579773, 23.67850020953587, 53.387724127088276, 68.78573472159249, 65.5729432787214, 69.58288070133754, 56.479627336774556, 48.85693236759731, 41.794154507773264, 34.82898146765572, 27.630588667733328, 30.186424459729874, 34.01268972669329, 34.04018374851772, 34.24913692474365, 33.90152897153582, 30.63347155707223, 46.20669834954398, 34.03687988008772, 23.2102142061506, 6.733884010996137, 2.3859180297170366, 0.5312959594385964, 0.18458407957639011, 0.1419452918427331, 0.22465375731033937, 0.37419634791357176, 0.60110961326531, 1.6094052685158593, 1.3718445130756922, 1.6128688369478499, 2.9414364950997487, 3.9392573067120145, 3.4396974614688327, 5.780363176550184, 5.978996975081308, 6.369665086269379, 6.519040499414716, 6.862660186631339, 6.2737100294658115, 7.382095353943961, 5.4503845402172635, 3.744662582874298, 4.193609578268869, 2.6262457966804504, 0.9216543329613549, 0.1773017839129482, 0.4063826565231596, 0.08845907010670219, 0.08868838780160461, 1.827449185507638, 4.449929058551788, 8.563656500407628, 7.089486300945282, 8.167987857546125, 7.36608670439039, 7.320648091179984, 8.892646755490984, 7.198900886944362, 7.6551925625119885, 8.876640711511884, 8.748439499310084, 7.757485679217747, 5.885819460664477, 5.8035814506667, 6.805548165525709, 5.014890560082026, 4.75697169133595, 5.740717189652579, 6.873531511851719, 5.411487655980246, 3.920655242034367, 2.80818133694785, 1.653413964169366, 2.1158545783587863, 1.1538135153906686, 0.2665445687515395, 0.5292097085288593, 0.062055962958506176, 0.02546774492865162, 0.07484908934150424, 0.44326863437891006, 3.347916534968785, 12.894009232521057, 22.172333989824565, 35.99290548052107, 44.34854507446289, 34.48840856552124, 23.72711501802717, 15.296374082565308, 28.897457190922328, 28.47124253000532, 51.314635276794434, 41.20219578061785, 42.61235005514962, 53.99977009637015, 58.50292192186628, 63.722742216927664, 65.76813207353864, 58.38142572130476, 37.7426564352853, 19.777807576315745, 4.829966860158103, 0.5511040793997901, 0.07575288441564355, 0.00118910993166667, 0.026222642278298736, 0.038399429858795235, 0.024167103559843132, 0.02842232727977846, 0.045985824561544826, 0.011568963544310203, 0.015337186566154872, 0.03448252539549555, 0.013320267516454416, 0.019452905182593634, 0.026535857435581938, 0.05190986953675747, 0.07091550648744617, 0.027657704826976572, 0.02405762023824666, 0.032394927593746355, 0.025467563420534134, 0.05770962046725409, 0.03883341407137258, 0.04290274464126144, 0.041948201933077404, 0.021152530231380036, 0.04479187773540616, 0.022103722672909498, 0.01681307147789214, 0.03470511880836316, 0.04588224619094815, 0.01092945531542812, 0.031961116407598765, 0.021341492056048343, 0.054080543773514886, 0.022772971939827715, 0.03880321926304272, 0.059996269909398894, 0.05213209314803992, 0.18841018926884445, 0.14695035613008908, 0.1794540427092995, 0.0978079391643405, 0.15173743425735406, 0.21571846891726765, 0.0888024020407881, 0.06585739433233227, 0.21958909050694533, 0.11166900502783911, 0.15301405718283995, 0.11387072902704988, 0.0901364968823535, 0.20972632616758347, 0.13128021412662097, 0.08199574585471835, 0.17359401072774613, 0.13637032599321433, 0.2127100753464869, 0.12825117952057294, 0.12020242427076612, 0.11810780023889882, 0.15623548360807554, 0.10031235763537032, 0.10548565789524998, 0.21904820310217993, 0.1867247082825218, 0.15679208588387283, 0.08934574574232101, 0.13870721416813986, 0.13141266416226113, 0.07013720646500587, 0.18514376240117209, 0.13970877256776604, 0.32608018123677796, 7.710217084203448, 32.938977650233674, 68.50116430010114, 79.69451768057687, 76.39828532082694, 77.27110413142613, 63.48739283425467, 54.70796176365444, 47.6641594341823, 37.38573094776699, 31.5799377986363, 34.2237343106951, 49.586854525974815, 43.65601117270333, 40.709026541028706, 45.354477473667686, 43.22447592871529, 57.4773712839399, 44.158154010772705, 30.89407069342477, 9.748324360166277, 3.5136603840759824, 0.9485765397548676, 0.4843979531100818, 0.33738202335579054, 0.3249908339764391, 0.40378701580422266, 0.3679999661232744, 0.9758397511073521, 1.5278046471732003, 2.433624578373773, 3.581312822444098, 4.453031863485064, 4.6071164182254245, 6.859701991081238, 8.899019990648542, 12.026658654212952, 8.368334821292333, 10.43153725351606, 10.039553761482239, 12.178100722176687, 10.191545605659485, 16.245068958827428, 11.439874597958156, 10.741011755807058, 3.759972504207066, 0.37471360872898785, 1.1519749569041389, 0.788716023521764, 0.3051875994673797, 1.8011815207345145, 10.084292343684606, 14.158478890146528, 16.369318383080618, 17.750470876693726, 17.12192119870867, 13.699999400547572, 17.088361399514334, 14.150131498064313, 12.431179302079336, 14.921562194824219, 16.971949543271744, 10.367143954549517, 9.215806603431702, 8.98722129208701, 14.39504247052329, 13.974151866776602, 7.918202723775591, 8.731515424592153, 8.691061275345938, 7.77727849142892, 4.1881847722189764, 1.7070417893784386, 1.180562560047422, 1.7346439425434386, 0.9349679499864578, 0.1917807034083775, 0.6123070695570537, 0.22669191365795477, 0.1724121520029647, 0.12108118140271731, 1.6580956386668342, 5.170848522867475, 17.364720787320817, 26.95389665876116, 56.66131925582886, 71.70950194767543, 54.69597612108503, 25.10083293914795, 19.14084015573774, 28.494020462036133, 28.40980655806405, 58.543416023254395, 48.838912214551655, 51.13600056512015, 59.36051722935268, 68.13752337864467, 71.61650030953544, 77.6790884562901, 67.71396119253976, 43.83118568147932, 23.405793837138585, 6.207392079489572, 0.5922444175396646, 0.21771770449621336, 0.10063191370240279, 0.19490917053605827, 0.22367366775870323, 0.08945974641080413, 0.18891940265893936, 0.15652470237442426, 0.09872642452163355, 0.12625285317855223, 0.16602146492472716, 0.15076590781765326, 0.07087660607482706, 0.13215952765728745, 0.11567689425178937, 0.19815943469958647, 0.09370093633021627, 0.16255047331963265, 0.18197055267436163, 0.09380530180143458, 0.1189078473086868, 0.11516031197139195, 0.1578893991453307, 0.0830469187349081, 0.11663869049932275, 0.14368635841778346, 0.11448629599596773, 0.11986245108502251, 0.10889335575380496, 0.15815248074276106, 0.09098601594035115, 0.1156634728291205, 0.1532286913799388, 0.1362785744879927, 0.1374137635741915, 0.1031679247639009, 0.17736134571688517, 0.2415910634611334], [0.03452421119436622, 0.01524522471507745, 0.07638774892049176, 0.046347141066300016, 0.07276525401643344, 0.032784121709742715, 0.03956319544730442, 0.030868512179170336, 0.0400801984194134, 0.0522852724284998, 0.026938500115647912, 0.0076220440844606075, 0.043235359114727805, 0.030882293225399086, 0.03705774560304625, 0.059274064376950264, 0.0347753845022193, 0.050871531146445444, 0.05996494873293808, 0.03403321646952203, 0.016905798377203088, 0.0645804592807378, 0.06159265246242285, 0.021126773042072142, 0.0473888653463551, 0.02080754776086126, 0.03513662976079753, 0.013446517438361687, 0.020656626305675933, 0.01245797927757459, 0.057702217650200636, 0.09978008083999157, 0.031055543571710587, 0.08523214076246534, 2.1881948794637407, 13.528966886656624, 42.15554073878697, 60.55771269117083, 56.42068576812744, 54.40344306400844, 44.68098511014666, 35.03487743650164, 36.27398790631975, 29.089394228799, 17.471672671181814, 25.520446811403545, 42.260086808885845, 32.45340626580374, 17.71379828453064, 24.932092462267192, 37.004132407052175, 45.34950603757586, 23.966096571513585, 12.816515973636083, 3.3140583974974493, 1.5746533104351588, 0.5851411329848426, 0.0937535295795117, 0.0909284558147192, 0.017821949574032, 0.15099537479025976, 0.15943012147077493, 0.92569514470441, 1.2675817992006029, 1.2661273458174296, 2.362515845469066, 2.4123641763414656, 4.49640599318913, 1.5826847766126906, 5.64862185716629, 6.062869548797607, 4.271696908133371, 4.123360250677381, 5.47607376745769, 6.516546530382974, 3.238252682345254, 5.052322242941175, 2.8796978422573636, 2.8309425498758043, 1.700700363942555, 0.16082182393542357, 0.2611083633133343, 0.34937306706394466, 0.23778953030705452, 0.33408494027597563, 0.5237879965986524, 2.2457359518323625, 4.685314919267382, 3.824768364429474, 6.731123839105878, 3.969444189752851, 5.697077291352408, 7.369110039302281, 2.879658107246671, 12.262310283524648, 4.771994999476841, 5.468216223376138, 6.164335829871042, 5.123734959534236, 1.2101852276495524, 5.757257810660771, 6.018712878227234, 1.9148716373103005, 3.312149379934583, 3.279515645333699, 4.775394405637469, 4.080758239541735, 3.437279054096767, 2.3223663313048224, 1.6421932748385837, 0.2913829945027828, 0.3182368592492172, 0.17065979460520403, 0.06207308239702668, 0.03251008516443627, 0.10443143839282648, 0.06781034703765597, 0.5018581247755459, 0.9799092241695949, 10.548555340085711, 27.401843547821045, 36.99763584136963, 37.93051488058907, 29.735191072736466, 32.59661558696202, 14.854498182024274, 19.957517521721975, 73.90240206037248, 34.739210741860525, 19.197933503559657, 36.77151019232613, 41.96588618414742, 46.191245555877686, 52.0879419871739, 59.35448619297573, 56.77385228020804, 46.7723650932312, 24.717764854431152, 10.07976906640189, 1.2910719215869904, 0.15308134071528912, 0.033335438197744746, 0.049276393705180714, 0.01465174915002925, 0.0023198130532234374, 0.011767502042597957, 0.029190423831875836, 0.013226638165568667, 0.06967885605990887, 0.07394061237573624, 0.010706286844132202, 0.06918224306511027, 0.0816040343738028, 0.014825236983597279, 0.02099198884596782, 0.006383579423917192, 0.04190911492332816, 0.007251904079956668, 0.037521592141794305, 0.035719918818878274, 0.047401051835290024, 0.04039229738659092, 0.05675026016043765, 0.02550062843199287, 0.046398550271987915, 0.033473530252064974, 0.062107708039028306, 0.014732467675847667, 0.011197858323742236, 0.018761744323585714, 0.02519585085766656, 0.021698023192584515, 0.04540535820914166, 0.011038115065145706, 0.03916890214064291, 0.035066761009927304, 0.03922517644241452, 0.010824999938319837, 0.023494047711470296, 0.04307119095964091, 0.026768065689663802, 0.026880955257053887, 0.07606377559048788, 0.03703337601785149, 0.03284687941361751, 0.0688449161659394, 0.06436084463660206, 0.021916460578462908, 0.00449911634703832, 0.007846411018233215, 0.05468123046947377, 0.05621775944850274, 0.004971790626378996, 0.009970619176913584, 0.0578094736805984, 0.018053536968571798, 0.005121787153517029, 0.008652960149837392, 0.04723772506362625, 0.048593624628015926, 0.04912939927141581, 0.0629540311970881, 0.020701852361006395, 0.020037897363571183, 0.02764477364585868, 0.03424340286957366, 0.04247499955818057, 0.07260030893875019, 0.047928531388086934, 0.043135516079408784, 2.2618234200137, 16.49408371107919, 49.17465959276472, 70.05273873465401, 66.71681131635393, 63.46171924046108, 52.9117933682033, 44.520394870213096, 44.63523122242519, 34.13385936192104, 21.911130360194615, 31.481037139892578, 46.777635301862446, 38.69523014341082, 23.781521150044032, 34.13576316833496, 36.47241108758109, 39.501130853380474, 22.324126073292323, 13.284841929163251, 3.749811198030199, 1.6398439151900155, 0.23423780660544122, 0.14961504457252367, 0.16729455946811608, 0.28983075065272196, 0.7493990446840013, 1.8174546360969543, 2.5491273062569753, 2.1304646858147214, 3.3708306082657407, 5.590705147811344, 5.510274537972041, 6.462149083614349, 5.135840458529336, 7.762856636728559, 8.539746880531311, 9.505301560674395, 8.616634777614049, 11.232280663081578, 9.04816915307726, 7.694615772792271, 4.692688695022038, 1.4061652485813414, 1.5565649781908308, 2.5039789974689484, 0.5132690753255571, 0.3788044692150184, 0.577165523810046, 0.4682760696325983, 0.40495279324906214, 0.4504617569702012, 2.5332812879766737, 1.5838997342756815, 3.90475081545966, 4.613694190979004, 4.708699515887669, 6.398501847471509, 8.914721182414464, 6.088595688343048, 6.315582914011819, 5.8993619339806695, 9.423688888549805, 8.91514241695404, 5.818814073290143, 6.5528421827725, 6.540811376912253, 6.236379095486232, 5.11397100346429, 5.960860005446842, 8.193007452147347, 7.6741281407220026, 6.338201905999865, 6.959721744060516, 4.696594885417393, 2.5846814555781226, 1.297840986933027, 1.529971290911947, 0.8444831882204328, 0.4030067819569792, 0.26025156357458656, 0.14392311285649026, 0.03351006257746901, 0.28757931717804497, 0.6768132224678993, 7.688095756939479, 25.361195836748394, 36.79133340290615, 40.695630414145334, 25.53475488935198, 27.727526460375103, 21.943116392408097, 20.438296386173793, 74.70374475206647, 44.0056688444955, 27.77943992614746, 43.906538895198274, 50.766748973301475, 53.74744973863874, 60.87475899287632, 68.68830708095005, 64.4933113370623, 60.40526226588658, 33.847235747746055, 14.456723366464887, 2.5076637140342166, 0.026903414766171148, 0.03618541759039674, 0.06116518218602453, 0.06421195369746004, 0.06353023634957415, 0.02694331432160522, 0.04702583554067782, 0.010185672369386469, 0.04723606265283056, 0.02378623846120068, 0.037465416227600405, 0.02033906682793583, 0.0671239003006901, 0.0067019281227008575, 0.02899745186524732, 0.04223234186481152, 0.01310880801507405, 0.007917401896390532, 0.025426400093627826, 0.03125688187511904, 0.018457546896700348, 0.04812294863430517, 0.053988086591873846, 0.004682235137027289, 0.023185852016987543, 0.006014948735745358, 0.049381095051233254, 0.04180348737697516, 0.02868934946932963, 0.03541219640257103, 0.01604779084612216, 0.03652718210858958, 0.07108766439237765, 0.055793257762811015, 0.020293772919103503, 0.018561518817607845, 0.12119518885655062, 0.1200997212103435, 0.19876764634890215, 0.13323283434978553, 0.15860483289829322, 0.11026820340859038, 0.22393642365932465, 0.1264394638793809, 0.12790279250059808, 0.15614833257028035, 0.13756811672023364, 0.1224653385579586, 0.1647175241793905, 0.10202071203717164, 0.09586582266326461, 0.1474061416728156, 0.16347907563405378, 0.1078304306470922, 0.25169678404927254, 0.08830380093838487, 0.1417002592767988, 0.13316213100084237, 0.2402204227234636, 0.14252096095255443, 0.19967300205358438, 0.13014151022902556, 0.21474555826612882, 0.1287545846509082, 0.1761346086859703, 0.09127123135008983, 0.12490518763661385, 0.31969940076981274, 0.10148856416344643, 0.2156498283147812, 4.03075509411948, 21.952539886747086, 58.44073554447719, 80.01083442143032, 77.06201199122837, 73.30153574262346, 63.44114562443325, 52.6908232825143, 52.131482873644146, 41.19564362934658, 27.97660722051348, 35.79640695026943, 54.73062678745815, 45.24864598682949, 30.028971331460134, 38.39958776746477, 50.39177553994315, 55.98049306869507, 30.60956280572074, 16.65264333997454, 5.126304924488068, 2.3497133553028107, 0.761842236987182, 0.31454999851328985, 0.35123586282134056, 0.2445466262953622, 0.5831917833004678, 1.0081459432840347, 2.4909389657633643, 2.71679949760437, 3.997846688543047, 7.888467039380755, 8.666372588702611, 12.511631625039236, 9.448751040867396, 14.232558846473694, 14.85414034979684, 13.56674771649497, 13.178781151771545, 16.467631919043406, 15.75619718006679, 13.129342981747218, 18.738786118371145, 14.319686651229858, 12.00397539138794, 6.602833603109632, 0.8496267550757953, 0.5972201962556157, 1.1161810947316033, 1.0190626489264625, 1.1361061398472105, 2.77178623846599, 8.833969218390328, 14.360177278518677, 16.089392832347325, 15.247964245932442, 11.366169844354902, 15.035330261502947, 18.098957777023315, 13.67956735406603, 26.06609926904951, 13.172638944217137, 15.178145272391182, 14.336879968643188, 15.325254270008632, 8.891758254596166, 15.398344108036586, 14.631565230233328, 7.733132243156433, 12.50571870803833, 12.776846102305822, 14.369006701878138, 10.891718183244977, 10.415479966572352, 7.282057361943381, 4.708488898617881, 1.3654704093933105, 1.64825753229005, 0.4336704851261207, 0.36714916463409153, 0.18316694561924252, 0.29602938517928123, 0.35323300851242884, 0.928179777094296, 1.9526971961770738, 12.68147599697113, 32.848123005458284, 49.24479818344116, 52.44873414720808, 43.15793997900826, 46.52490847451346, 22.528316259384155, 27.477075168064662, 80.31119115012032, 43.42823532649449, 31.961939334869385, 51.92250190462385, 59.76342936924526, 62.5662145614624, 70.71738256726945, 78.07842922210693, 74.73906244550432, 67.7599652154105, 40.94333716801235, 18.55705598422459, 2.9796787287507738, 0.2507339157164097, 0.10029521105544907, 0.1839259277497019, 0.13715407465185436, 0.1572567873767444, 0.07051384089780705, 0.1017017395102552, 0.09832846373319626, 0.11028411505477768, 0.17159362163926872, 0.18620249416146958, 0.1252020059951714, 0.2771386174218995, 0.09315123475555863, 0.12391238233872823, 0.1770997704671962, 0.1118794119517718, 0.09006871123399053, 0.11935999590371336, 0.0911765553589378, 0.11734941521925585, 0.13204385100730828, 0.13022138737142086, 0.11144888826778956, 0.09732607752084732, 0.09620212497455732, 0.1550323867372104, 0.15147473263953412, 0.06529384385794401, 0.10992871876806021, 0.13831464094775064, 0.17531659400888852, 0.14039466290601663, 0.1184961801128728, 0.1410507791276489, 0.1545510339949812], [0.07925400297556605, 0.02044477410215352, 0.03584185495440449, 0.05587159802338906, 0.04892104830858963, 0.034921761469117234, 0.040687477083078454, 0.050416861793824604, 0.06115380993911198, 0.14699805714190006, 0.026264731805505495, 0.04985095341024654, 0.05691248431269612, 0.05481790777828012, 0.07295816830758538, 0.043954589271119664, 0.011108165324133421, 0.04567933029362133, 0.09093744640371629, 0.026701648985700946, 0.06884644286973135, 0.05789382236876658, 0.01876569339739425, 0.013014626506316875, 0.023787836411169598, 0.030949546223772422, 0.05322473469589438, 0.057389779415513785, 0.03996374823951295, 0.024810278422332237, 0.02090672243918691, 0.05467883184818285, 0.05578158696049026, 0.9521655014583043, 6.9262244786534986, 28.782403707504272, 57.403525829315186, 67.70349720546177, 56.57067653111049, 45.60452577045986, 42.142898491450715, 27.77223117010934, 27.020566361291067, 26.62742338861738, 29.212366921561106, 17.901967661721365, 22.949943372181483, 31.03266293661935, 33.183731419699534, 34.612392221178325, 33.48353229250227, 22.306960548673356, 10.985530155045645, 2.0488281292574744, 0.7956337694610868, 0.07619397967521634, 0.04850312841257878, 0.05333122058904596, 0.23138565250805446, 0.4717851813350405, 1.1378227791615894, 3.200566521712712, 2.866142123937607, 4.43649080821446, 3.3378529378346036, 1.9486650696822574, 3.3546193752970015, 3.5589878261089325, 3.7408510616847446, 7.465175833020892, 5.5654045854296, 5.771164195878165, 8.24734844480242, 7.42843462739672, 6.885088971682957, 6.358300873211451, 3.568623891898564, 1.4699625223875046, 2.033005561147417, 2.2420679543699538, 0.7842444777488708, 0.29888843319245745, 0.24168182430522783, 0.778675333729812, 0.32352541546736446, 2.545308619737625, 4.6808706777436395, 5.259380732263837, 7.448812825339181, 1.9378174117633273, 4.666028891290937, 3.43491775223187, 5.19206701857703, 3.36339299593653, 3.1578099131584167, 6.438270730631692, 6.1433049355234415, 11.322553396224976, 3.2208797974245886, 5.202104559966496, 2.7553122767380307, 1.8589060689721788, 4.680369973182678, 3.8317239454814365, 7.369546038763864, 3.875178413731711, 5.069644970553262, 5.756612062454224, 4.120087649141039, 2.6316365131310056, 2.3510754193578447, 1.4012338731970106, 1.1564969313996178, 0.5279149551476751, 0.22273495527250425, 0.073863720787423, 0.03984583242397223, 0.04035202633323414, 0.10087909722434622, 0.43825651332736015, 2.3646411257130757, 13.929395914077759, 28.85336218561445, 37.225870268685476, 31.413980075291224, 28.39837156023298, 50.978557859148296, 26.214490209306987, 12.59856401171003, 20.836049488612584, 25.194272313799175, 30.125638144356863, 41.762693064553396, 45.4643806048802, 52.846421241760254, 55.587009634290425, 55.821264675685335, 55.70404509135655, 43.03734704426357, 20.055575711386545, 3.3680313527584076, 0.11553805241627352, 0.046216414509607215, 0.013703037602161723, 0.029519689735025167, 0.05549965226756675, 0.058006248836006434, 0.05630816066903727, 0.07020997256040573, 0.0360914099562381, 0.017512183070981076, 0.027807973192206452, 0.03221104460369263, 0.034393532135124714, 0.04172545584983059, 0.051463851505624394, 0.04857107012399605, 0.03990258848560708, 0.045865737433944426, 0.13953225846801484, 0.03243004178096141, 0.007625545325156833, 0.031336470640131404, 0.027393571500267302, 0.06819270152066435, 0.0406193759159318, 0.048287754612309594, 0.028688894850867133, 0.0505174681810396, 0.033454303962311575, 0.03185521066188812, 0.04667731959904943, 0.04372469821412649, 0.013802124919103724, 0.03196984576061368, 0.10134455189108849, 0.01188205402078373, 0.030001856719276736, 0.11427114611225468, 0.02873057047171252, 0.027292605489492416, 0.047003718691744974, 0.04389546512226973, 0.028691113660378114, 0.024503717997244427, 0.06910790955381733, 0.005411859601736069, 0.08281996234187058, 0.012323483458853193, 0.025769333388390284, 0.04371880513748952, 0.01448268536478281, 0.01655050047806331, 0.06257060462875025, 0.029826211144349406, 0.0511425482109189, 0.04826155298256448, 0.0584010137245059, 0.018061560645167316, 0.0238580681782748, 0.060773572485361776, 0.0413166486791202, 0.01624250834408615, 0.003777776370822851, 0.04077898431569338, 0.033029344265482256, 0.03344979848978775, 0.09802933835557529, 0.07614863317992006, 1.0003588582788194, 9.204057199614388, 34.597634247371126, 65.25801617758614, 77.04161208016532, 66.63319669451032, 52.61207587378365, 49.40776470729283, 34.0587944984436, 35.357944352286204, 35.235225268772666, 29.05354152406965, 22.429000445774623, 31.115600109100342, 37.85714537756783, 31.358755792890275, 28.96888640948704, 34.54634959357125, 21.285780327660696, 10.459878087043762, 2.482091954776219, 0.4924669829862458, 0.03823605558968016, 0.1984953773873193, 0.26371724903583527, 0.9618443420955113, 1.4707058710711343, 3.1273839686598097, 4.427898057869502, 4.199432168688093, 5.923394450119563, 7.462338362421308, 6.805526452405112, 6.749760210514069, 6.843011549540928, 8.753160800252642, 7.047636432307107, 9.729028344154358, 9.44683507510594, 10.02170991897583, 9.430070808955602, 9.073932204927717, 7.14383293901171, 5.3268507804189404, 2.4444001487323215, 1.1915286630392075, 2.0632052549294064, 0.8228166965501649, 0.4536151534744671, 0.05595200103042381, 1.149848373872893, 0.5238519960216114, 1.6832107709986823, 3.868825588907514, 6.444353444235666, 6.4336219515119275, 1.1887366814272744, 3.619708784988948, 2.988249331712723, 7.51335985319955, 8.270811642919268, 6.6446213722229, 8.229537606239319, 8.429563215800695, 8.441427264894758, 6.263347225529807, 6.744445272854396, 4.9921252216611585, 4.696690857410431, 7.717632549149649, 6.486125145639692, 8.268906099455696, 7.889392886843, 8.270696997642517, 8.230371390070234, 7.2092046311923434, 3.2488630158560614, 2.0188429611069814, 3.1684999338218143, 2.704062581062317, 2.1938322569642748, 0.7294950612953731, 0.5478286551577705, 0.10944569004433495, 0.14780487599117414, 0.0838202450956617, 0.34973811890397755, 2.423227901969637, 15.126739025115967, 28.85489773750305, 34.572766644614084, 34.77291645322527, 25.150446551186697, 40.430733816964285, 34.493807315826416, 21.368418727602275, 27.97020271846226, 38.44839538846697, 41.60237727846418, 50.77022654669625, 53.31413228171212, 58.51963233947754, 64.41369887760708, 62.62694876534598, 67.616929599217, 53.14545086451939, 27.2926995073046, 4.602449834346771, 0.06711444830788033, 0.06480108494205133, 0.03761785929756505, 0.03233895184738295, 0.04243846384010144, 0.036979595332273414, 0.0461245985435588, 0.05574689346498676, 0.09832504391670227, 0.036374165676534176, 0.029177826829254627, 0.03176132177135774, 0.04649280896410346, 0.021493544968377267, 0.04395031789317727, 0.06650114764592477, 0.03494583249890378, 0.05888245467628751, 0.04638330019744379, 0.04077918448352388, 0.03100640745833516, 0.047966617558683665, 0.023156147450208664, 0.04157648687916143, 0.06254711374640465, 0.017667447150285755, 0.02441870264842042, 0.06151734186070306, 0.03743015954803143, 0.00934218633587339, 0.07970197858022791, 0.0030128784752118266, 0.01288390249413039, 0.03894651907363108, 0.015568314253219535, 0.20084329854164804, 0.1334983722439834, 0.27679191316877094, 0.23924078100493976, 0.15772722927587374, 0.09173780559961285, 0.09565624355205468, 0.1624769065529108, 0.1737647165677377, 0.2607273523296629, 0.07886313966342381, 0.14299738753054822, 0.06671075389853545, 0.20518320852092334, 0.12150694855621882, 0.1817855704575777, 0.053856684892837486, 0.1400190530610936, 0.16848874038883618, 0.23090861524854386, 0.1257896308920213, 0.15949019896132605, 0.07312004640698433, 0.12943848009620393, 0.21559209855539457, 0.10026013079498496, 0.18962008506059647, 0.16342752054333687, 0.15397467277944088, 0.20060111582279205, 0.16171307968241827, 0.23581534624099731, 0.16523182658212526, 1.8946512937545776, 13.622266428811209, 44.76943915230887, 76.95842824663434, 84.79672581808907, 74.14122554234096, 62.63122190747942, 57.308057580675396, 42.70400374276297, 39.49122967038836, 40.8454578944615, 41.54420348576137, 28.830539090292795, 34.84838431222098, 43.29611185618809, 48.25214031764439, 45.472207750592915, 42.84607008525303, 28.007177557264054, 13.728352393422808, 2.721277177333832, 0.982493845479829, 0.1473292772259031, 0.2699898438794272, 0.1749423955168043, 0.7596334155116762, 1.2998691009623664, 2.6325306594371796, 6.6289423278399875, 8.885262557438441, 10.350357106753759, 13.006768941879272, 10.453019346509661, 11.360279508999415, 13.707962036132812, 15.716766153063093, 16.636111838477, 16.383294684546335, 15.019001994814191, 20.07408571243286, 17.12856020246233, 16.35561827250889, 17.53044922011239, 10.578286681856428, 5.682448293481555, 7.639046686036246, 4.691546584878649, 2.3620694237095967, 1.0966007454054696, 0.6891337899225098, 1.5694714742047446, 1.707921822156225, 8.69243962424142, 5.267864917005811, 5.858362785407475, 10.420337625912257, 11.636146443230764, 11.172864879880633, 10.686734165464129, 16.34769558906555, 11.580407994134085, 12.263600042888097, 21.06558322906494, 19.280907154083252, 21.434181690216064, 12.430091040475027, 15.336187260491506, 11.065340638160706, 9.568504112107412, 12.750877210072108, 12.464984025274005, 19.205784967967443, 15.05478869165693, 15.181216376168386, 15.747308697019305, 13.55016497203282, 10.7686299766813, 6.175621007169996, 5.576106114046914, 3.706619458539145, 2.042125071798052, 0.8030025511980057, 0.3006738488163267, 0.18838067299553327, 0.24460788443684578, 0.44762214219995905, 0.7676988627229417, 3.614173024892807, 19.217702865600586, 39.697514738355366, 50.107858249119346, 44.75322205679757, 41.285046100616455, 60.86239814758301, 33.073157787323, 20.479850087847026, 32.11993442262922, 37.92641544342041, 43.8481844493321, 58.11982257025582, 59.92017378125872, 68.82463073730469, 73.5577644620623, 73.21728188650948, 78.21692766462053, 62.941757747105186, 34.30294377463204, 5.556172166551862, 0.22072604378419264, 0.1458999024970191, 0.15059341064521245, 0.12988373477544102, 0.09862091232623373, 0.16040183790028095, 0.11076833121478558, 0.15836269089153834, 0.2539501445634024, 0.08723474866045372, 0.116258032353861, 0.06978845303612095, 0.1341944813196148, 0.11495829852563993, 0.12266956402787141, 0.1408232527651957, 0.1331179855125291, 0.14596961518483503, 0.11027142644992896, 0.11899041144975595, 0.15276105861578668, 0.15283975510724954, 0.14537323718624456, 0.1291797954056944, 0.09327054156788758, 0.19828762353530952, 0.08354596767042365, 0.12786566306437763, 0.2166969028434583, 0.0692649157717824, 0.18864834148968967, 0.1199538768934352, 0.153699893238289, 0.15621168059962137, 0.23175208855952534], [0.0646756984559553, 0.01780986995436251, 0.049703657028398344, 0.026973117275961807, 0.05971123091876507, 0.0807870307138988, 0.05148002778046897, 0.061692397110164165, 0.08746145399553434, 0.2001343108713627, 0.1427837847066777, 0.08435556851327419, 0.013050476055858391, 0.1444878304111106, 0.12479713772024427, 0.1417466846427747, 0.08057844904916626, 0.0592465362112437, 0.049463917035609484, 0.06308939214795828, 0.06059977931103536, 0.07921867165714502, 0.039234272204339504, 0.005037536428842161, 0.09038072199161563, 0.07691021409950086, 0.07681181295109646, 0.07780984975397587, 0.08264823191400085, 0.03874377959540912, 0.03458348122824516, 0.06129383242556027, 0.38210651917116983, 3.4168285514627184, 27.865081684929983, 64.13829313005719, 66.46924700055803, 61.81572573525565, 50.52440275464739, 33.518707547869, 30.963653428213938, 27.860249212809972, 21.951846803937638, 19.917949267796107, 22.80208396911621, 42.162638323647634, 36.53520195824759, 27.966197081974574, 41.33420807974679, 44.43271555219378, 15.378387144633702, 5.235636132104056, 0.4089243401374136, 0.09088336716273002, 0.05537580266328795, 0.1949319557419845, 0.2664943571601595, 0.19295075562383446, 1.0816463764224733, 0.11132270111037151, 3.32383451291493, 4.414016859872, 3.618429013660976, 1.4540808945894241, 2.780686229467392, 5.664611399173737, 5.832450347287314, 5.11824848822185, 4.891071055616651, 6.102880750383649, 7.25228042261941, 7.798293318067278, 6.361722861017499, 11.438218321119036, 10.002838611602783, 6.952183382851737, 1.2439019041402, 0.31809121849281446, 0.6678467893174717, 1.1107283873217446, 1.1824620238372257, 1.5363494115216392, 0.15692335526858056, 0.11053766323519604, 0.6211915899600301, 10.370302779333931, 20.954681294304983, 24.610713958740234, 19.72198748588562, 12.731005362101964, 4.310700620923724, 2.57752611381667, 5.156886986323765, 2.3629414226327623, 2.0114494264125824, 2.1391521053654805, 7.143320509365626, 6.119811339037759, 1.6418533559356416, 5.062023665223803, 4.662900899137769, 4.2844429441860745, 6.393124376024518, 5.70886447599956, 6.160854782376971, 6.2332102826663425, 4.822061112948826, 7.290299228259495, 4.2888363770076205, 1.7030432096549442, 1.4009469343083245, 1.558859946472304, 4.263628312519618, 1.1319979088647025, 0.8406829035707882, 0.7443383133837155, 0.21899024264088698, 0.13362356195492403, 0.03732502054689186, 0.11028556033436741, 0.8831981707896505, 2.342897389616285, 10.380223069872175, 27.389123133250646, 34.78456163406372, 46.8248622076852, 42.81563697542463, 19.855755942208425, 16.057794162205287, 13.728121365819659, 12.323687195777893, 19.53957642827715, 29.671146052224294, 32.08595773151943, 34.69640983854021, 40.22422988074166, 44.800872802734375, 57.41846098218645, 55.63199574606759, 48.31610195977347, 17.369021722248622, 1.9939727527754647, 0.03387421535860215, 0.057415950511183055, 0.016328404092096856, 0.05376642616465688, 0.07370241265743971, 0.02607145449811859, 0.047293877229094505, 0.030213457864842246, 0.04736835662541645, 0.029842234748814787, 0.08284260505544287, 0.039610044897667, 0.0700468256005219, 0.04078665854675429, 0.034501568480793915, 0.03172300489885466, 0.12113114872149058, 0.18291094792740686, 0.07720123776899916, 0.056113526291613064, 0.034020283592066596, 0.004734486998391471, 0.09854107589593955, 0.04230723516749484, 0.017136997310444713, 0.07495031998093639, 0.03147343293364559, 0.04132731185693826, 0.03143802019102233, 0.1370031548930066, 0.018909495323896408, 0.09892450924962759, 0.0971989268437028, 0.1692751624754497, 0.07746775953897408, 0.042631235638899465, 0.04919118667021394, 0.04758912817175899, 0.04544329510203429, 0.010744568093546798, 0.03617363143712282, 0.008634370834832745, 0.0017000568727131135, 0.07499907272202627, 0.020371706058670367, 0.06946682065193142, 0.011034479813783296, 0.16301449627748557, 0.08650866869304862, 0.0891101515984961, 0.023859416766624366, 0.016587333055213094, 0.015645031118765473, 0.05477351462468505, 0.02958586047004376, 0.04625281112800751, 0.05869588468755994, 0.08733132454965796, 0.04585150516192828, 0.10655434376427106, 0.0016536306585684152, 0.048929611420524974, 0.00992679429639663, 0.0446611783201141, 0.028272963062460934, 0.02271451105895851, 0.5300980465752738, 4.810619601181575, 34.49305691037859, 72.98922116415841, 75.41348934173584, 71.88864040374756, 57.3834524835859, 41.42515652520316, 38.709060532706125, 33.67895385197231, 27.755348784582957, 25.456565073558263, 33.257521288735525, 40.709023066929404, 36.24087974003383, 34.24467618124825, 43.18307161331177, 34.57694598606655, 15.126650435583931, 4.976792284420558, 0.7816000910741943, 0.0897586682279195, 0.08583872392773628, 0.45882136268275125, 1.0683379705463136, 2.0122638855661665, 2.699217298201152, 3.7826262371880666, 5.282837416444506, 5.5034796340124945, 5.146370887756348, 7.30553662776947, 7.44451710156032, 7.924216389656067, 7.721835340772357, 7.734005110604422, 6.846047478062766, 6.835858813353947, 9.189542412757874, 9.651743531227112, 6.401741445064545, 6.137935280799866, 8.374552590506417, 10.711447170802526, 2.836421638727188, 1.421429572360856, 1.2225300052336283, 0.9808576532772609, 0.34641153312155176, 2.0602509677410126, 0.17529528800930294, 0.14347910668168748, 1.0073534143822533, 9.749384828976222, 22.85030620438712, 27.09925992148263, 22.073417697634014, 13.422230396951948, 2.6047964904989516, 2.6542407401970456, 2.1413325369358063, 3.2893102169036865, 3.780759343079158, 5.331364503928593, 5.418597834450858, 3.979918599128723, 3.726419218948909, 5.297383035932269, 4.759303680488041, 4.355193844863346, 8.924742221832275, 8.344154221670967, 6.457041723387582, 8.235501766204834, 9.008593950952802, 8.244681205068316, 5.838869179998126, 5.341959203992571, 4.502492180892399, 3.622628982578005, 7.925164818763733, 5.093331379549844, 4.720349907875061, 2.9018004962376187, 1.2893347633736474, 0.5922599967036928, 0.0817703500922237, 0.0722792058118752, 0.6388966856258256, 1.5781902692147662, 10.496674009731837, 26.78707562174116, 33.46856239863804, 35.10964352743966, 48.30552332741873, 25.529548951557704, 15.861976555415563, 22.00916596821376, 20.67858246394566, 28.0861143044063, 44.124052252088276, 43.43062203271048, 44.40965795516968, 50.94311509813581, 55.1071948323931, 64.17827306474958, 65.14681025913784, 58.24456010546003, 23.31275224685669, 3.0037359978471483, 0.05839436408132315, 0.015972598988030638, 0.0425946184966181, 0.013450127244660897, 0.038468833813177686, 0.0616382093035749, 0.07380476287965264, 0.09003777003714017, 0.03259463741311005, 0.02865167720509427, 0.024149275052228143, 0.02493182270388518, 0.01917166938073933, 0.0204344688515578, 0.04424103282924209, 0.04362151000116553, 0.08636778446712665, 0.12867363542318344, 0.07705328320818287, 0.08968139665999583, 0.040354034796889336, 0.03721974244607346, 0.1007442180333393, 0.020749013937477554, 0.11656851640769414, 0.04005202564543911, 0.023100320981549363, 0.07147888732807976, 0.02921809788261141, 0.054048401569681506, 0.06045317503490618, 0.09073397410767418, 0.07064500171691179, 0.0775199049551572, 0.1466380264610052, 0.09301149725381817, 0.20927796379796096, 0.12616654352418014, 0.13466862801994595, 0.15651309942560537, 0.16989347072584288, 0.277838295591729, 0.18998930310564383, 0.21531199929969652, 0.1471060799168689, 0.15299508534371853, 0.12040907889604568, 0.30342072142022, 0.14737776533833571, 0.3670224685754095, 0.1337320189923048, 0.09247027058154345, 0.21825914829969406, 0.12207258891846452, 0.07061540401939835, 0.16730120911129884, 0.16651812541697705, 0.17773382073002203, 0.20621243757861002, 0.19028538864638123, 0.13079170962529524, 0.24049873064671243, 0.20777727503861698, 0.10719370017094271, 0.08867302576878242, 0.21353935370487825, 0.9053165124995368, 6.6761240703719, 44.910935742514475, 83.3423080444336, 83.78902162824357, 79.77466515132359, 67.65449156079973, 47.57114042554583, 45.56477165222168, 42.14865159988403, 34.31974799292428, 29.842575481959752, 34.42224087033953, 56.00561080660139, 46.68807997022356, 41.14367110388619, 54.53981188365391, 55.24201420375279, 20.512379816600255, 6.674789147717612, 1.110631981066295, 0.28438805841973847, 0.17251208664051124, 0.6492284397993768, 1.0360043112720763, 1.787985697388649, 2.274243107863835, 4.589586113180433, 8.968924079622541, 12.45569862638201, 10.11431724684579, 11.75859715257372, 12.104190128190176, 15.844355923788887, 15.347257477896553, 14.607595682144165, 13.054015823772975, 15.635097026824951, 15.051750591823033, 18.542129516601562, 16.68169549533299, 23.380236625671387, 21.99791509764535, 18.478310312543595, 8.532268013272967, 1.3795846977404185, 2.24786622609411, 3.006043451172965, 4.058250418731144, 4.329216267381396, 1.2609791649239404, 0.15856429721627915, 1.3134162425994873, 6.534436838967459, 11.659812876156398, 14.212839858872549, 13.45094643320356, 13.787544097219195, 10.144166707992554, 9.866666947092328, 12.135516950062343, 8.85651351724352, 9.892870341028486, 10.192619102341787, 16.35378568513053, 17.816690683364868, 14.017224618366786, 16.021255322865077, 13.887169974190847, 14.407276511192322, 16.880129098892212, 15.11193415096828, 15.482835939952306, 13.48136304106031, 13.173579556601387, 17.438885859080724, 13.066656334059578, 6.063056715897151, 9.919177089418683, 7.793189866202218, 12.436728307179042, 6.020442545413971, 5.615387320518494, 2.9179989184652055, 0.9139361871140343, 0.4270261616579124, 0.29256581674729076, 0.33495704776474405, 1.2084470923457826, 3.2008594317095618, 13.646724956376211, 35.75322389602661, 46.92736203329903, 61.27372455596924, 53.95778560638428, 28.04924542563302, 26.320005553109304, 23.05135406766619, 20.630954299654277, 29.059687205723353, 43.752650192805696, 44.80690731321062, 50.360140391758506, 57.149603911808555, 61.78668226514544, 73.67940657479423, 75.57678590502057, 69.54440157754081, 30.09389877319336, 4.035344813551221, 0.169849121677024, 0.11678030075771467, 0.0899403120524117, 0.17419811045484884, 0.1869647196893181, 0.15612071619502135, 0.1180562044360808, 0.22866334287183626, 0.13058204230453285, 0.16483180304723127, 0.2805548512509891, 0.10848989204636642, 0.17075172252953053, 0.07980456628969737, 0.09866290685853787, 0.23675750568509102, 0.15865291388971464, 0.30877539409058435, 0.12471954045551163, 0.2191674081342561, 0.264248433389834, 0.13382436760834285, 0.27565745690039223, 0.09245810444865908, 0.16487193160823413, 0.16420174257031508, 0.2041020986757108, 0.13866435789636203, 0.1286566856184176, 0.17808637395501137, 0.26166845325912746, 0.22217299257005962, 0.2551772615739277, 0.27498578865613255], [0.2504230652536665, 0.08541103652013199, 0.02386786961661918, 0.054974313492753675, 0.11839553979890687, 0.023516944875674586, 0.09891317771481616, 0.076636235229671, 0.12723679680909428, 0.1859747235264097, 0.07144118113709347, 0.016940174657585363, 0.027690696895920804, 0.044196707529148886, 0.31148052322013037, 0.30975576862692833, 0.1706670413592032, 0.14737464407724993, 0.0864568150469235, 0.055381336116365025, 0.05284761171787977, 0.04212477370830519, 0.13409773579665593, 0.18074448060776505, 0.14929679807807716, 0.019924227480909655, 0.013644340082204767, 0.04360659919413073, 0.0961492263845035, 0.09174963246498789, 0.07988242139773709, 0.014466824608721902, 1.1079595301832472, 16.128382648740494, 55.26499537059239, 65.84119238172258, 63.99796731131417, 51.10442100252424, 47.526710169655935, 36.428498472486226, 22.805905478341238, 29.85148654665266, 23.75153272492545, 23.49122541291373, 22.386986425944738, 22.66345524787903, 35.09790107182094, 44.65077781677246, 24.175885268620082, 9.102705563817706, 2.360529963459287, 0.1369233184627124, 0.06796297670475074, 0.04724962317517825, 0.11928861401975155, 0.18626261236412184, 0.7700876859681947, 1.770197983298983, 3.059639032397951, 3.6385503453867774, 5.13852333171027, 3.638052897793906, 2.386752030679158, 7.346313868250165, 6.274979378495898, 5.151466957160404, 4.797729390008109, 4.054124057292938, 7.083420957837786, 5.0115936398506165, 7.138343862124851, 7.394525681223188, 5.625514754227229, 1.9730912446975708, 6.8917957203728815, 5.756304604666574, 3.8591953856604437, 1.8670825787952967, 1.0616429469415118, 3.6029136862073625, 3.420302216495786, 2.669441878795624, 0.9451447810445512, 0.9586015960999897, 8.42332547051566, 37.882301330566406, 57.13401910236904, 52.61844737189156, 51.27062191282, 37.00167621885027, 14.32498378413064, 5.783863765852792, 3.445841840335301, 4.562440804072788, 6.21177248443876, 5.555690135274615, 5.407587545258658, 2.186945072242192, 3.247164398431778, 4.440157285758427, 3.9397675650460378, 1.3329651079007556, 6.171235391071864, 8.05025063242231, 5.964577291693006, 6.961615128176553, 8.35738011768886, 5.608870778764997, 5.129359092031207, 4.530272381646292, 2.945531806775502, 2.9461747322763716, 4.255367338657379, 5.148017176559993, 0.7441860501255307, 3.6647869603974477, 1.5843798113720757, 0.46550493261643816, 0.12099546885916165, 0.06031866225280932, 0.024896895113800253, 0.2538028210401535, 1.128374314733914, 6.924114397593907, 19.46691737856184, 30.292321954454692, 22.66595138822283, 25.416178669248307, 35.528738021850586, 17.926447902406963, 22.36289702142988, 19.293875966753276, 14.33862396648952, 9.585605365889412, 24.377207585743495, 32.23685870851789, 35.32651417595999, 46.62204429081508, 53.09536477497646, 51.246358803340364, 33.14844846725464, 8.96927843775068, 1.0610766687563487, 0.0416197231305497, 0.10867652988859586, 0.09480712482971804, 0.015636423902053918, 0.010610270746318358, 0.06868273272578206, 0.04470623304535236, 0.09057601794068303, 0.125926138567073, 0.1542979675744261, 0.05708502898258822, 0.06665873740400587, 0.07204901959214892, 0.047521793749183416, 0.10362845326640777, 0.2677123546600342, 0.4232354036399296, 0.41229166516235893, 0.21021365001797676, 0.054086993248867135, 0.049704651082200665, 0.03848784636440022, 0.10321171741400446, 0.09332124848983117, 0.18264963052102498, 0.020184399859447564, 0.050518126360007694, 0.028737488136227642, 0.11822901373463017, 0.03969711111858487, 0.031192624608853033, 0.14093502105346747, 0.1455512304923364, 0.1479688100516796, 0.031053402793726752, 0.024592821519555788, 0.08591693187398569, 0.05823078964437757, 0.02543900897061186, 0.09744601537074361, 0.05853321270218917, 0.1369654554873705, 0.3198639047997338, 0.06081677480999913, 0.03992764678384576, 0.04673501543168511, 0.04893417117585029, 0.24904493348939077, 0.17078288085758686, 0.05958368669130972, 0.1456093266606331, 0.0802666214959962, 0.03659550719229238, 0.07993333188018628, 0.11991640818970543, 0.10864311203892742, 0.18782236081148895, 0.04636597041306751, 0.03665346086823514, 0.03517712473071047, 0.11484669308577265, 0.004566995293966362, 0.09047355236751692, 0.043563922734132836, 0.02434390434063971, 1.4329517483711243, 20.698499475206646, 64.02788625444684, 75.93706389835903, 72.44470473698208, 61.690602575029644, 56.94164432798113, 44.000662667410715, 30.729339327130997, 35.18536499568394, 28.117285660334996, 26.090027127947124, 26.20219710894993, 29.87870611463274, 40.427527223314556, 42.889378207070486, 24.66910661969866, 11.398707389831543, 2.6070283821650913, 0.20978811356638158, 0.03912078043712037, 0.12323059035199029, 0.7915308581931251, 0.6210869327187538, 2.07851647904941, 3.6798467465809415, 6.644001245498657, 4.585367688110896, 6.313234857150486, 7.301190529550825, 6.336046661649432, 6.409930331366403, 6.648233566965375, 8.454205870628357, 8.963428923061915, 8.526871868542262, 8.85191467830113, 9.46225312777928, 5.406808478491647, 5.672531042780195, 5.547356639589582, 6.8081472260611395, 9.038822957447596, 4.572186521121433, 4.593416741916111, 3.1268209474427358, 2.1397939452103207, 4.122044435569218, 3.840787870543344, 3.324930591242654, 1.0997521877288818, 1.5961841493844986, 11.400362798145839, 42.30326986312866, 62.956877027239116, 63.61123057774135, 63.098759242466514, 43.856272152491975, 16.464543444769724, 6.156314134597778, 3.493194682257516, 6.696475778307233, 6.83332358939307, 6.262793106692178, 5.061096949236734, 2.5553644001483917, 2.7516525302614485, 4.252022215298243, 6.069704839161464, 3.1443028322287967, 6.945397598402841, 9.019414901733398, 6.770011169569833, 8.801819903509957, 9.289385420935494, 10.108481628554207, 7.5165247576577325, 8.482853293418884, 6.155841222831181, 7.040032063211713, 7.850457787513733, 7.0483629533222745, 6.536503059523446, 6.394939592906407, 5.25018001454217, 2.0309797269957404, 1.5420102391924178, 0.3773196174630097, 0.12396905358348574, 0.15949695717011178, 1.0017123456512178, 7.1840391244207105, 18.721895047596522, 31.198005744389125, 29.84213774544852, 25.013087613242014, 28.08546117373875, 17.661485297339304, 23.34309503010341, 24.24399151120867, 19.86887240409851, 19.267512764249528, 33.423597131456646, 42.205032757350374, 44.32665824890137, 54.60797718593052, 62.535552161080496, 61.880469049726216, 41.52189629418509, 12.015730874879019, 1.2312808270965303, 0.021930077079949633, 0.07118750403502158, 0.07105727280889239, 0.11237573317651238, 0.05570127894835813, 0.07639072768922363, 0.03546072183442967, 0.1021033643877932, 0.05034294558156814, 0.041424535747085295, 0.03881671532456364, 0.02339035738259554, 0.014649223303422332, 0.08433437107929162, 0.11197638817663703, 0.12038440736276762, 0.2688368500343391, 0.20120237927351678, 0.15449504128524236, 0.07473170278327805, 0.07155358046293259, 0.058424742094108036, 0.029467615565018992, 0.1237443634974105, 0.14897004275449685, 0.05166392094854798, 0.034746472125074694, 0.01731231888490064, 0.03851879434660077, 0.046197595340865, 0.07705189221139465, 0.13727352395653725, 0.09412742273083755, 0.3600994029215404, 0.20301173361284391, 0.06611528513686997, 0.16014433386070387, 0.20393094500260694, 0.17732854533408368, 0.24138009335313523, 0.17061993745820864, 0.249686420496021, 0.7399453691073826, 0.20191155693360738, 0.13074320794216224, 0.08363581249224288, 0.16604822634586267, 0.45400039851665497, 0.4169897330658776, 0.227673970961145, 0.34719469824007576, 0.1754002302352871, 0.1527792297835861, 0.14266949226813658, 0.2897619200604302, 0.2588071253682886, 0.40527322462626864, 0.21260406103517326, 0.18993415177932807, 0.13402472542864935, 0.29662508464285303, 0.2049608254539115, 0.20143829232880048, 0.17001275718212128, 0.201267735766513, 3.0901107915810178, 28.506072112492152, 75.06608636038644, 83.50512518201555, 80.01225185394287, 67.56885501316616, 59.96781757899693, 48.00298139027187, 37.08376223700387, 42.306351389203755, 35.64664200374058, 36.30284030096871, 32.01033353805542, 33.34428691864014, 49.51245321546282, 56.66984122140067, 32.71369620731899, 12.18839795248849, 3.1694996058940887, 0.34019433387688225, 0.1404473850769656, 0.17376473013843807, 0.5531563492757934, 0.6502384256039346, 1.7051342917340142, 4.131913048880441, 9.309994646481105, 9.792445421218872, 13.919155137879507, 11.918286732264928, 8.77600474017007, 18.033788885389054, 15.128182513373238, 10.805122784205846, 13.990837097167969, 14.470327939305987, 17.667358262198313, 13.535107357161385, 16.2459739616939, 15.578104427882604, 13.248639208929879, 11.070303389004298, 16.303329604012625, 14.521025470324926, 9.859333992004395, 5.705624444144113, 2.1464153613362993, 6.864232650824955, 6.317784624440329, 4.222801131861551, 1.3782740937811988, 2.0770306502069746, 12.235020365033831, 34.70046411241804, 51.8412218775068, 48.757222243717735, 49.01049450465611, 31.563630376543315, 19.57091280392238, 10.292375258037023, 10.03759958062853, 11.528909683227539, 10.826610088348389, 10.937287075178963, 11.051788176809039, 9.854449408394949, 10.57022156034197, 11.198319605418614, 11.34678784438542, 8.308099150657654, 14.140437892505101, 15.988808972494942, 15.645554065704346, 19.794050727571758, 19.375904662268503, 15.445456368582589, 14.499106509344918, 13.285305721419197, 7.302032130105155, 10.04557090146201, 11.457946862493243, 12.208353178841726, 8.33305013179779, 9.548958829471044, 5.292573145457676, 1.4861265293189456, 0.709052212536335, 0.29871589530791554, 0.11756691283413342, 0.44386142971260206, 1.5408038582120622, 9.180199691227504, 25.024032763072423, 39.06903280530657, 32.81663376944405, 37.89671189444405, 48.39389399119786, 27.911632878439768, 29.984978812081472, 27.303853103092738, 22.859675850187028, 18.369640486580984, 36.35860306876046, 45.812735489436555, 49.611253125326975, 64.07408482687813, 70.08284527914864, 71.31647709437779, 50.58098540987287, 15.637633119310651, 1.5956099459103175, 0.12410505914262362, 0.16007977803902967, 0.21273070281105383, 0.16252567965005124, 0.16867380402982235, 0.1675132377339261, 0.16316275617906026, 0.2315387028668608, 0.1712602980967079, 0.3761127750788416, 0.13939556080315793, 0.23086451047233172, 0.15705880442900316, 0.21916869735079153, 0.24800194374152593, 0.41057084607226507, 0.6368689515760967, 0.5130873907889638, 0.2473921850323677, 0.1507790306849139, 0.16119493677147798, 0.18061906019491808, 0.2121636239545686, 0.39998795251761166, 0.28582695978028433, 0.18628534328724655, 0.19265914841422013, 0.0929840708683644, 0.17868229054978915, 0.17335055236305508, 0.24809832285557473, 0.24497673607298306, 0.3301629535853863], [0.3346247827368123, 0.0870882733059781, 0.015662460987057005, 0.03969580154599888, 0.0402202616179628, 0.050963408180645535, 0.1085188654916627, 0.0866962836257049, 0.11499350092240743, 0.14520722680858203, 0.06910129383738552, 0.0645815177953669, 0.10654548888227769, 0.026939100619139414, 0.32589168420859743, 0.29430088507277624, 0.16594438334660871, 0.21275719281818184, 0.07261364215186664, 0.050959571065115075, 0.05298185308596917, 0.0776908482824053, 0.04035369213670492, 0.26364782133272713, 0.03521072239215885, 0.08730689050363642, 0.04744086827018431, 0.06663168421281235, 0.07197208729173456, 0.06578224657901696, 0.04905649746901222, 1.111399757010596, 17.05694685663496, 52.837975706372944, 66.07463100978306, 68.14371422358921, 58.03862244742257, 44.47783020564488, 35.63833543232509, 24.609857593263897, 25.091013397489274, 24.96516936165946, 28.256293058395386, 35.40953820092337, 32.8670186315264, 39.626149790627615, 35.929343359810964, 27.42099973133632, 12.77891753401075, 2.0681727826595306, 0.08537983069462435, 0.031056693688567196, 0.11583151881183897, 0.12695270776748657, 0.6949042688523019, 1.2876416827951158, 1.9478386683123452, 2.928290069103241, 4.1911177805491855, 2.199561046702521, 3.6396852902003696, 4.129454689366477, 3.66479868548257, 3.3517871158463612, 3.873449180807386, 6.190994330814906, 5.501397345747266, 7.416600976671491, 4.7535827074732095, 4.422792868954795, 6.109229232583727, 5.888534903526306, 3.0562109649181366, 3.1974307128361295, 11.063275286129542, 13.216364826474871, 11.408215131078448, 10.229005081312996, 14.835275990622383, 10.863088999475751, 13.598260402679443, 17.557085139410837, 8.622580698558263, 7.863869547843933, 24.93330144882202, 51.54196643829346, 49.33003173555647, 57.834737982068745, 47.30655997140067, 67.8983872277396, 33.67584105900356, 20.85034019606454, 8.725480914115906, 9.91200133732387, 9.501910839762006, 12.523391451154437, 9.211987699781146, 3.7382754513195584, 1.583951194371496, 4.265472190720694, 2.6146357910973683, 1.945682555437088, 8.037736926759992, 7.942446725709098, 6.606938251427241, 9.914535692759923, 6.592113835471017, 8.24357991559165, 4.558442550046103, 10.142652869224548, 4.218583141054426, 3.9350888218198503, 7.12903197322573, 6.441210687160492, 6.347096902983529, 5.825746204171862, 3.5417452199118475, 3.207739233970642, 0.8011891256485666, 0.08931320320282664, 0.4448992625943252, 0.04879577038809657, 0.1580587886273861, 1.2020171859434672, 4.549948811531067, 10.75671294757298, 23.12607846941267, 46.37552220480782, 38.81095239094326, 42.876197474343435, 37.06025300707136, 33.64828797749111, 42.175030435834614, 30.5245099067688, 23.17203038079398, 16.748797723225184, 32.28587130137852, 36.632150173187256, 45.677349839891704, 53.05752141135079, 49.27133682795933, 24.601907117026194, 4.270035420145307, 0.241032819130591, 0.015215923876634665, 0.025196475109883716, 0.06294461313102927, 0.041763016155787876, 0.016957594347851615, 0.05607085661696536, 0.01945060834155551, 0.28107151495558874, 0.0766837258956262, 0.029341309663972685, 0.011122167742412006, 0.034136642169739516, 0.04538323796753373, 0.040603426950318475, 0.19417266148541654, 0.4090191721916199, 0.5403058188302177, 0.18471540324389935, 0.04644493831853781, 0.05350074917078018, 0.0723411560590778, 0.1832402138305562, 0.078187210219247, 0.12202948837407998, 0.10891529957630805, 0.05577287457085081, 0.02997113943898252, 0.046289462197039805, 0.04133372401286449, 0.10547116438725165, 0.0680154613884432, 0.15773814011897358, 0.24897656430091175, 0.1296830376876252, 0.027404153253883123, 0.03807440140683736, 0.029870875711951936, 0.035190061000841, 0.11068059663687434, 0.02722839402434017, 0.08478150530053036, 0.08053950792444603, 0.10759793740830251, 0.07758003672850983, 0.02757388709246048, 0.06258708624435322, 0.1926700999694211, 0.1654609271458217, 0.09486396570823022, 0.13051253317722253, 0.06341515002506119, 0.08301472903362342, 0.0422671405332429, 0.033928274243537865, 0.1196075254785163, 0.25796859179224285, 0.04329666814633778, 0.012042176410821932, 0.047063955638025484, 0.020259121832038676, 0.05574706309874143, 0.02801354555413127, 0.013465919299051166, 1.9138741365500858, 19.74775661740984, 63.34032726287842, 75.81901400429862, 76.72416278294155, 67.49102824074882, 52.452211720602854, 43.202602999550955, 31.87350266320365, 31.325838702065603, 30.007675102778844, 35.795142378125874, 36.621755668095176, 32.994778633117676, 32.98050355911255, 33.26674154826573, 29.686994893210276, 12.83313432761601, 2.2188349153314317, 0.12566406120147022, 0.04196966399571725, 0.16190487439078943, 0.5161904128534454, 1.5748076907226016, 3.113588971751077, 4.114830034119742, 6.763277062347957, 8.022521240370613, 7.331984945705958, 6.89142963715962, 7.322259204728263, 7.14527165038245, 6.040904121739524, 9.162695441927228, 7.90584795815604, 9.104334047862462, 8.479795217514038, 8.173011405127388, 6.300082351480212, 5.2769370930535455, 4.831034277166639, 3.6134519321577887, 2.515245718615396, 7.384458609989711, 8.041195392608643, 10.24764449255807, 12.059670414243426, 14.64881065913609, 13.928441405296326, 15.558295113699776, 17.061923503875732, 10.297512582370214, 8.934851850782122, 29.044990028653825, 61.68903228214809, 59.574473108564106, 66.62254510607038, 58.68230356488909, 79.17883627755302, 42.76164599827358, 21.78790405818394, 10.647315297807966, 10.254276548113141, 9.828919121197291, 12.170696548053197, 10.361685276031494, 6.039455422333308, 1.7003309151956012, 2.9055255992071967, 2.851774117776326, 3.97754796062197, 5.13859064238412, 8.091261506080627, 9.323521052088056, 9.182398796081543, 7.063742356640952, 9.378671509878975, 7.2698328750474115, 12.861997144562856, 11.047418628420148, 10.1040677853993, 12.30138521535056, 8.322042448180062, 11.030326928411212, 7.832253507205418, 7.289296082087925, 5.419746892792838, 2.8690019590514044, 1.4277644838605608, 0.770212644977229, 0.06569264602980443, 0.044745998590120246, 0.548018644962992, 3.574052389178957, 11.688178028379168, 24.801700830459595, 43.58132151194981, 41.22299173900059, 37.71013191768101, 29.980872426714214, 29.863440922328405, 35.9807322365897, 30.31882585797991, 33.926368781498496, 26.637590340205602, 41.27465506962368, 46.21650920595442, 54.29788255691528, 62.22491904667446, 57.64904737472534, 31.321843487875803, 4.620178597314017, 0.24356418901256152, 0.034513391953493865, 0.04327099238123212, 0.04777507051559431, 0.06675624967153583, 0.033641040192118714, 0.04909189664093511, 0.0542205017991364, 0.1958832482674292, 0.05980214782591377, 0.04405337379180959, 0.029780250574861254, 0.03160096359040056, 0.03313216267685805, 0.01427139125631324, 0.059735732818288464, 0.23717751886163438, 0.25875694091830936, 0.1440499039100749, 0.02838792046532035, 0.08161727259201662, 0.058413946601961336, 0.05919690815997975, 0.18215569773955004, 0.09833877746547971, 0.04072017568562712, 0.09314696677029133, 0.03872394940948912, 0.053243787959218025, 0.015502961152898414, 0.022675983840599656, 0.039824967472148795, 0.06982383185199328, 0.454618082514831, 0.3131186424621514, 0.15371951647102833, 0.20648189740521566, 0.14123660272785596, 0.12907321112496511, 0.24267316396747315, 0.14112765714526176, 0.2541983255318233, 0.2533608233290059, 0.21674212041710103, 0.2536278675709452, 0.16747285132961615, 0.14938823745719024, 0.5221996818270002, 0.5429629076804433, 0.3408699376242501, 0.4072549268603325, 0.2473518257694585, 0.18153918082160608, 0.23705245128699712, 0.2179277382258858, 0.3346510556127344, 0.6245280823537281, 0.20146166107484273, 0.3059776856430939, 0.1421594103532178, 0.15972003234284265, 0.08760331531188317, 0.1656448237065758, 0.1408715508878231, 2.952077226979392, 28.463182619639806, 72.04453018733433, 83.98425906045097, 85.08543041774205, 74.44327763148716, 56.56564603533064, 47.961274828229634, 35.72596958705357, 36.59704439980643, 37.37864031110491, 38.75680160522461, 47.041757174900596, 46.906979492732454, 50.93210915156773, 47.29935816356114, 34.53348500388009, 16.765058244977677, 2.7568890835557665, 0.2680839475776468, 0.13035864143499307, 0.16812075727752276, 0.40707017534545487, 0.8544836544564792, 3.9656009674072266, 5.005728491715022, 10.435977152415685, 11.494176506996155, 9.513230323791504, 10.983525599752154, 14.40971793447222, 14.401614597865514, 10.046233585902623, 12.965616498674665, 16.834456852504186, 14.425144672393799, 14.618523461478096, 13.942408152988978, 12.91828189577375, 14.47227430343628, 13.576275433812823, 7.52651800428118, 6.558134973049164, 18.64126467704773, 20.153750283377512, 14.892775808061872, 16.45038996423994, 21.408252750124248, 20.33200979232788, 22.789254120418004, 23.112989800316946, 12.327752760478429, 9.825645651136126, 32.069275106702534, 62.614914485386436, 57.686036109924316, 65.19243907928467, 58.95809146336147, 77.79920891353062, 42.72337532043457, 26.963855164391653, 13.560922520501272, 15.111169849123273, 13.678001403808594, 18.61186511175973, 14.118393863950457, 7.772711787905012, 5.837929001876286, 9.189739567892891, 7.552070004599435, 7.41512622152056, 19.034762007849558, 18.85893610545567, 17.667841162000382, 20.031903198787145, 13.15805901799883, 18.46222870690482, 15.598931653159005, 21.291729722704204, 11.93409822668348, 11.276313134602137, 16.142963443483623, 16.964164086750575, 15.314338650022234, 16.318622589111328, 10.750910333224706, 10.244458743504115, 2.8192624109131947, 0.89373543964965, 1.0309923802103316, 0.14047255872615746, 0.33447395797286716, 1.6902311657156264, 5.5258020247731885, 13.028039114815847, 30.777896812983922, 53.905038356781006, 50.08259459904262, 55.925178459712434, 48.854441438402446, 46.73053346361433, 56.844216687338694, 40.62392847878592, 34.31941100529262, 27.208673204694474, 45.11329507827759, 51.15769631522042, 63.259742055620464, 68.87338624681745, 68.76501519339425, 38.86534636361258, 6.770354236875262, 0.5167105506573404, 0.15674445272556373, 0.12734130477266653, 0.14972409872072084, 0.1464781364692109, 0.15842985228768416, 0.13748496903904847, 0.23173732363751956, 0.42591558982219013, 0.22124888215746197, 0.34310256210821016, 0.19197286452565873, 0.17366844601929188, 0.2109197335583823, 0.35213709303310936, 0.43235969117709566, 0.6837195690189088, 0.8382681331464222, 0.47471118718385696, 0.12584092813943112, 0.17930737057966845, 0.22193973937204906, 0.24353194502847536, 0.32959781533905436, 0.20863753530595983, 0.35747024257268223, 0.2579139290111405, 0.0825282669227038, 0.15922352112829685, 0.1408515748168741, 0.18380547421319143, 0.24305908754467964, 0.228038846382073], [0.16509576674018586, 0.10362179683787481, 0.041051548440009356, 0.05189370343993817, 0.04469917628115841, 0.030821696655558686, 0.031278269298906834, 0.07128214609942266, 0.082520741969347, 0.11259090341627598, 0.06632417214236089, 0.043188570732516904, 0.018261655533154095, 0.039641912294817824, 0.1409642252006701, 0.20309712045959064, 0.20050716586411, 0.08278091265154736, 0.102075049121465, 0.06676765584519931, 0.03131328849121928, 0.17487322565700325, 0.0094097802980936, 0.14181673659809999, 0.08127720441137042, 0.09029224102518388, 0.023316042531015616, 0.07065673358738422, 0.012929344832498049, 0.08378121576138906, 0.23490434512495995, 9.2153845003673, 44.89210959843227, 64.56435666765485, 65.54257270268032, 58.23423855645316, 58.29705374581473, 38.29895353317261, 36.689156668526785, 24.52932276044573, 35.39893177577427, 39.28331177575247, 23.249584436416626, 27.023213624954224, 39.124305725097656, 46.44803360530308, 32.93446479524885, 11.441972953932625, 0.8843929352504867, 0.014578660750495536, 0.052222894704235454, 0.011231227827790593, 0.3365609145590237, 0.8610634899565152, 3.320716291666031, 0.6992814168334007, 3.5661357854093825, 4.0777535779135565, 5.086383180958884, 3.9537573286465237, 3.782917627266475, 5.623166263103485, 6.865648780550275, 3.681450043405805, 5.3966793077332635, 6.9538448708398, 7.079266803605216, 5.797570824623108, 5.903140885489328, 7.740255883761814, 0.924111606819289, 3.211032680102757, 4.988453532968249, 17.801321268081665, 26.55766521181379, 25.899733339037212, 31.68370567049299, 30.42733587537493, 30.525802271706716, 29.683916841234478, 24.60817960330418, 34.59599794660296, 27.863157033920288, 24.1392491544996, 28.489415543419973, 34.746541091373985, 45.87040901184082, 55.99035603659493, 45.774353640420095, 40.98482138769967, 38.615916456495015, 41.37214871815273, 26.02899762562343, 20.3843766280583, 23.164814676557267, 28.46291858809335, 22.692556040627615, 25.93314548901149, 11.671767251832144, 5.996592419488089, 5.608387878962925, 6.268891888005393, 6.724336317607334, 6.190540960856846, 5.711159118584224, 5.817853919097355, 5.755245004381452, 8.542765872819082, 6.891070067882538, 8.045087252344404, 10.919779351779393, 9.151823248182025, 10.396150946617126, 8.422099981989179, 8.421463353293282, 5.264550626277924, 10.036586012159075, 2.811960505587714, 5.7702982766287665, 2.3900522078786577, 0.6382426864334515, 0.07530431848551546, 0.06799211299845151, 0.008174769380795104, 0.6487480370061738, 2.3292133467538014, 9.687820315361023, 22.81860157421657, 27.237787893840245, 35.72561870302473, 55.70820358821324, 73.82155282156808, 71.44578307015556, 55.76323332105364, 18.880175011498586, 18.53714939526149, 19.188930375235422, 35.91276148387364, 52.339181900024414, 47.02184016363961, 53.61540617261614, 40.39378677095686, 8.06457347529275, 0.6213800598468099, 0.06438174351517643, 0.04966018668242863, 0.027070978989026377, 0.05988740575100694, 0.061505786409335475, 0.07871716642486197, 0.02161290097449507, 0.14869800449482032, 0.051842087281069586, 0.03993183334491082, 0.03753280154030238, 0.05733894357191665, 0.05978097074798175, 0.022674195900825516, 0.2858753257564136, 0.25049113588673727, 0.2789234630763531, 0.1590867963220392, 0.03930774397615876, 0.020959129091352224, 0.04452041283782039, 0.1413400521767991, 0.07682672036545617, 0.052071123383939266, 0.14788555380489143, 0.0293756910333676, 0.06468294520995446, 0.005797435853829873, 0.06634340861013957, 0.029139954397188764, 0.05041850045589464, 0.19665516327534402, 0.12121440496827875, 0.061479466035962105, 0.057749599750552855, 0.03451219094651086, 0.06341901088931731, 0.08913830401641981, 0.08231193638805832, 0.01697425407889698, 0.0656697183315243, 0.052405335807374546, 0.03560601993064795, 0.03785711753049067, 0.028564682230353355, 0.03950599155255726, 0.06324473595512764, 0.12201836039977414, 0.1462715496974332, 0.08548623177089862, 0.07998745861862387, 0.010644685194295431, 0.020703989746315137, 0.09808687812515668, 0.10193424631974526, 0.13741465924041613, 0.030053320207766125, 0.017544840961428623, 0.053182197335575304, 0.06395671596484524, 0.09014577245605843, 0.09480412570493561, 0.3332085987286908, 12.371598499161856, 53.21417549678257, 74.88177844456264, 75.15850434984479, 65.3804156439645, 65.66603524344308, 42.66757433755057, 39.01273502622332, 26.523759739739553, 36.586674213409424, 38.91188539777483, 24.21561333111354, 34.32954147883824, 36.05770090648106, 44.41047784260341, 30.439168657575333, 10.17068885053907, 1.5320185124874115, 0.015862354010875736, 0.0643680981759514, 0.21583725325763226, 0.9022308066487312, 1.856246211699077, 5.277502502713885, 6.245143379483904, 7.43354937008449, 8.034473878996712, 8.806152973856245, 5.673694866044181, 7.105110194001879, 7.057776893888201, 8.81567461150033, 6.497610517910548, 7.419078877993992, 11.028520396777562, 8.16338380745479, 7.866447329521179, 5.900376370974949, 5.6200004901204785, 3.299607012953077, 2.0427905789443424, 4.307424111025674, 13.128348520823888, 23.44420174189976, 26.894058772495814, 31.330365453447612, 30.41369308744158, 31.522003718784877, 33.296153272901265, 28.757496152605327, 36.6040620803833, 30.227040154593332, 28.411745105470928, 35.695216860089985, 43.053918497903005, 52.894589628492085, 60.22939641135079, 54.643986225128174, 53.63974223818098, 48.810209206172395, 45.09282568522862, 30.499228886195592, 22.015280382973806, 25.82679636137826, 29.54498413630894, 22.656479256493704, 26.33969153676714, 12.666110055787222, 6.193750594343458, 4.680321770054953, 4.90787353685924, 4.932879669325692, 6.162129342556, 6.0609831128801614, 6.629063052790506, 8.65279928275517, 12.08021102632795, 10.406513316290718, 9.3784613268716, 12.97226071357727, 13.223887988499232, 9.313013638768878, 12.623081598963056, 9.820061036518641, 9.601303083556038, 8.189340540340968, 7.001220294407435, 9.93976547036852, 4.133584090641566, 2.507495654480798, 0.7946278548666409, 0.20208907526518616, 0.059887711091765335, 0.09444988971310002, 2.009118740047727, 9.596184866768972, 24.9456136567252, 32.132319586617605, 31.856312819889613, 43.39682599476406, 67.24638216836112, 69.99144172668457, 56.98474052974156, 23.585244962147303, 24.59197814123971, 26.57828746523176, 42.02386195319039, 58.791084562029155, 53.81784888676235, 61.97244930267334, 48.469191619328086, 10.540811572756086, 0.6387655926602227, 0.0603193747145789, 0.06220487425369876, 0.03404696698167494, 0.062102917581796646, 0.057527338819844384, 0.05590697005391121, 0.018796359787562063, 0.12409220768937043, 0.026445885388446704, 0.09120078584445374, 0.005498000470522259, 0.02059724261718137, 0.040596787485161, 0.08008788858673402, 0.13259559497237206, 0.17682059401912348, 0.10396026367587702, 0.0464921338217599, 0.026406014670750926, 0.08967992423900537, 0.05138149431773594, 0.09487112425267696, 0.09136493025081498, 0.09242303097354514, 0.10313179955950805, 0.04727742275489228, 0.036058674034263404, 0.007175900524349085, 0.059246773698500226, 0.055406272278300354, 0.06658031232655048, 0.12477634740727288, 0.36016682216099327, 0.19404600613883563, 0.1372812863971506, 0.17450581251510552, 0.20817987700658186, 0.15527207244719776, 0.2052408025733062, 0.15335339254566602, 0.2729129727397646, 0.23722754046320915, 0.12340281611042363, 0.08990740988935743, 0.10362193254487854, 0.15995723461466177, 0.32390403800777023, 0.3446118411208902, 0.321245727794511, 0.30341914721897667, 0.35281334817409515, 0.1002407246934516, 0.12101312434034688, 0.2625426506357533, 0.22284011462969439, 0.28877391879047665, 0.24213701273713792, 0.10100534544991595, 0.2214530940566744, 0.18359757108347757, 0.22590770359550202, 0.24379589515072958, 0.6353577183825629, 18.010163273130143, 63.724416732788086, 85.4117317199707, 81.23095199040004, 73.50150489807129, 71.59920624324253, 52.0054738180978, 46.479894569941926, 34.919478280203684, 45.67404249736241, 52.54987212589809, 33.70063917977469, 38.46682548522949, 52.37426682880947, 60.33418914249965, 40.44690922328404, 14.521301661218915, 1.2056013707603728, 0.17147326309766087, 0.3112393175917012, 0.20957757772079535, 0.4474724030920437, 1.5961067421095712, 7.630736640521458, 7.046823493071964, 11.366026537758962, 11.175753593444824, 15.218210322516304, 12.003515073231288, 11.723798836980547, 13.223200116838727, 16.57216235569545, 11.067503264972142, 11.578707422528948, 15.95215722492763, 17.18629625865391, 14.515651038714818, 16.709938185555593, 18.910771403993877, 6.605523858751569, 8.825971841812134, 10.635563288416181, 24.77318889754159, 35.67228780473982, 30.13366331372942, 37.23570891789028, 35.57149028778076, 32.4675041607448, 35.59959922518049, 35.72180414199829, 42.78879608426775, 30.718628679003032, 32.20083924702236, 42.61194011143276, 46.405229227883474, 55.192702838352744, 64.31008734021867, 59.597263199942454, 60.09220423017229, 52.80161925724575, 50.221711431230815, 34.01320389338902, 26.051009518759592, 28.176734447479248, 33.344002042497905, 27.560088770730154, 29.477062020983013, 16.727638721466064, 10.855947119849068, 10.526002355984279, 11.974291818482534, 14.085781625338964, 15.469971350261144, 13.868075455938067, 11.959565111568995, 14.422691958291189, 17.62564127785819, 16.818199804850988, 15.627851792744227, 20.09853294917515, 19.36355597632272, 21.412699597222463, 17.99047381537301, 15.928825174059186, 17.26486301422119, 20.300755058016094, 11.673036166599818, 15.27188515663147, 5.85291018656322, 1.8414747757571084, 0.5422024599143437, 0.31435536752854076, 0.18648807598011835, 1.0223466498511178, 2.919030725955963, 12.459815434047155, 29.31546081815447, 37.96751751218523, 44.72296960013253, 63.447829791477744, 78.9679445539202, 75.92746148790631, 64.78277329036167, 27.91482036454337, 29.26807757786342, 29.760770865849086, 49.952743189675466, 66.99803270612443, 62.36721120561872, 69.84718322753906, 55.55363743645804, 13.567054305757795, 1.2111552613122123, 0.2206533726836954, 0.17844412475824356, 0.15521023076559815, 0.19545568978147848, 0.16173829404371126, 0.14122911170125008, 0.13520780551646436, 0.2821481057575771, 0.225569752444114, 0.23946836165019444, 0.16003089637628623, 0.20456601306796074, 0.20491723636431353, 0.29513483175209587, 0.38484774636370794, 0.593465020614011, 0.5959942191839218, 0.35272793418594767, 0.1393766025347369, 0.17781102444444383, 0.13326786032744817, 0.31060423595564707, 0.1556337316121374, 0.24100787618330546, 0.2536049602287156, 0.2285694879080568, 0.10392047438238348, 0.08995055793119328, 0.15006286411413125, 0.13612643336611135, 0.20608726143836975, 0.5639366965208734], [0.05219387036881276, 0.02587955292048199, 0.0189387418795377, 0.02633457850398762, 0.08531792115952287, 0.038691922556608915, 0.017920807037236433, 0.08475170404251132, 0.0852733753355486, 0.07505535041647297, 0.00949204249107944, 0.04710821647729192, 0.0290904858016542, 0.01729248700264309, 0.06660777263875518, 0.06653246203703539, 0.06083272716828755, 0.03255873951794846, 0.016169939023841704, 0.044337530686919174, 0.032705625386110375, 0.07836515602788754, 0.03859951965776937, 0.05656646198726126, 0.04169365969885673, 0.10954700889331953, 0.024318203130470853, 0.043449901709599156, 0.025160621319498335, 0.017944170694266046, 2.5870093192373003, 26.89370267731803, 61.46612712315151, 69.16380705152238, 62.006009101867676, 55.794006892613, 52.730417592184885, 56.0126701763698, 41.8828239440918, 44.487227644239155, 40.86947086879185, 34.702010086604524, 25.557715211595806, 25.35422158241272, 44.110732555389404, 26.939666748046875, 8.720937660762242, 1.6880168616771698, 0.05230332145999585, 0.09071006253361702, 0.17299878623868736, 0.37071454046028, 1.4966836656842912, 2.12275088259152, 3.9400572180747986, 6.210111430713108, 4.131416252681187, 5.014260879584721, 5.5733398624828885, 7.4263666697910855, 6.953190003122602, 3.94861262185233, 4.5680645023073465, 5.323078342846461, 9.00401508808136, 5.556221238204411, 7.429187638419015, 7.9343642336981635, 5.008341882910047, 3.779065719672612, 5.363219823156085, 14.82471125466483, 24.470820665359497, 30.71864604949951, 41.41427217211042, 50.33938612256731, 47.107692105429514, 53.17117656980242, 46.35393762588501, 49.35478469303676, 41.928279059273855, 43.021032673971995, 45.441955293927876, 31.601505007062638, 37.12751851763044, 34.59041506903512, 51.00735466820853, 49.99796206610543, 41.42240503856114, 34.305879388536724, 33.97206013543265, 45.04993792942592, 36.67479474203927, 27.733468907220022, 41.90574952534267, 42.487473555973594, 42.00750241960798, 37.81853423799787, 35.85501847948347, 23.31198968206133, 18.36305706841605, 16.250584091459, 8.688790082931519, 12.307733263288226, 14.89289219038827, 10.915338584354945, 9.626393897192818, 7.438860399382455, 6.052009948662349, 12.907633781433105, 15.331639664513723, 13.53783278805869, 11.389360325677053, 5.721391209534236, 8.727642672402517, 6.375227119241442, 5.843654751777649, 3.343079068831035, 5.048162877559662, 3.7034059166908264, 1.580275488751275, 0.6082223430275917, 0.12925390500043119, 0.007083936128765345, 0.045105557689177136, 0.30276623368263245, 1.6335447217736925, 10.308019995689392, 27.04544264929635, 40.057115282331196, 65.01215417044503, 77.02820205688477, 74.74150821140834, 60.724747385297505, 44.90793064662388, 19.30152940750122, 19.564857448850358, 31.740093776157924, 45.08102069582258, 49.9654792376927, 54.559794902801514, 49.969644682747976, 21.898225818361553, 2.850582067455564, 0.05024287184434278, 0.04329435773459928, 0.03947623779198953, 0.06994046523634877, 0.034904027956404855, 0.07106416672468185, 0.07451357413083315, 0.08107090940965073, 0.016876987780311277, 0.02885297140372651, 0.026535755655329143, 0.0006251819161531914, 0.021008178691512773, 0.02959268992500646, 0.14456411131790706, 0.060742794136915884, 0.13824655674397945, 0.029001173629824604, 0.057668338396719525, 0.00975908334034362, 0.010822647118142672, 0.06425367003040654, 0.015935345719169294, 0.047508619991796355, 0.03207348519936204, 0.04787278973630496, 0.01874994290327387, 0.012484495577934598, 0.03242856596729585, 0.03513551017801676, 0.08972566428461246, 0.18927758772458347, 0.03917637620387333, 0.030796180346182415, 0.0473670266967799, 0.02335609306049134, 0.026309532080111758, 0.023841796908527613, 0.030010545360190526, 0.022039575668584024, 0.05660970163132463, 0.09721952038151876, 0.027118411979504993, 0.02420904211300824, 0.05203719663300684, 0.01708994260323899, 0.0952742351219058, 0.039760048634239605, 0.07366444862314633, 0.04263410923470344, 0.022584515623748302, 0.037371897138655186, 0.050028997606464794, 0.07082610271338906, 0.021699057958487953, 0.10687634255737066, 0.04399821228746857, 0.08667100141091005, 0.03869264519640377, 0.02686350333637425, 0.07973810378462076, 0.11537733461175646, 3.664838203362056, 34.37093537194388, 71.29896763392857, 77.29374831063407, 69.79193115234375, 65.07475743974958, 60.44933468954903, 63.46630505153111, 46.352329117911204, 44.15420743397304, 41.28965623038155, 39.9979305267334, 28.50570559501648, 24.810670954840525, 39.575900418417795, 26.541776418685913, 10.516786439078194, 1.9609898711953844, 0.05096278392842837, 0.08162527930523668, 0.4187883665519101, 1.2460423835686274, 2.5974294458116804, 3.901766998427255, 9.287969725472585, 9.396445870399475, 11.922857778412954, 10.203273296356201, 11.570792555809021, 10.422147631645203, 7.467061400413513, 9.142950398581368, 9.99301472731999, 9.821733815329415, 6.705384237425668, 9.180839794022695, 6.626051442963736, 6.553272971085139, 7.274188092776707, 5.2931676506996155, 7.381219012396676, 15.30497247832162, 24.03485768181937, 32.541877678462434, 41.604180335998535, 50.24777412414551, 47.58373750959124, 52.79117611476353, 48.371023995535715, 52.23997899464199, 48.52204656600952, 49.26552465983799, 49.434713295527864, 35.665624482291086, 41.29828936713082, 40.36246081760952, 56.63432897840227, 54.421306882585796, 49.58609369822911, 39.623638016836985, 40.68314102717808, 50.419429370335166, 40.998676095690044, 30.162168298448833, 45.57685456957136, 44.155864579336985, 43.2908034324646, 40.40801320757185, 38.63041387285505, 24.660254614693777, 20.886013984680176, 16.800909212657384, 11.986242720058986, 9.259496007646833, 10.353788648332868, 9.943972604615347, 10.80703353881836, 10.556096741131373, 11.377771598952156, 13.638373221669879, 12.636435168130056, 10.38885794367109, 14.23690755026681, 17.579361064093455, 19.260012183870586, 10.962639314787728, 8.938871383666992, 6.951327885900225, 9.052144391196114, 6.967082491942814, 5.1708328894206455, 2.1532927751541138, 0.4982258453965187, 0.14690211229026318, 0.148056476776089, 0.15812380585287297, 1.3632659848247255, 8.475348370415823, 21.933593886239187, 37.297839709690635, 62.46726526532854, 75.48609801701137, 76.84899411882672, 59.716535976954866, 44.59877402441842, 28.359440803527832, 25.59243709700448, 40.544698170253206, 49.9861536026001, 57.73487152372088, 61.05374458857945, 59.501676831926616, 28.020733492715017, 3.3284791665417806, 0.16680343582161836, 0.052454173365341764, 0.058360030209379535, 0.11398278230002948, 0.03328787289293749, 0.052581052628478835, 0.02501545044859605, 0.036074619607201645, 0.0377825533172914, 0.053896609893334765, 0.015367657877504826, 0.02660865236872009, 0.025924390514514277, 0.08519843114273888, 0.04373936474855457, 0.0369055535910385, 0.08937078368450914, 0.02746500597069306, 0.009477299621461757, 0.0468535487140928, 0.029791941733232567, 0.04401231903050627, 0.046117782659296475, 0.03522662725299597, 0.06159822323492595, 0.03212723195818918, 0.07425853317337376, 0.03168191621080041, 0.020971483517704264, 0.03075998728828771, 0.04143341098512922, 0.137133284338883, 0.1724968874560935, 0.06760232855698892, 0.13795883075467177, 0.13011162754680428, 0.21694462240806647, 0.08809493428894452, 0.09466224403253623, 0.20713353529572487, 0.19036027177103929, 0.16616806920085633, 0.126048939834748, 0.07846397108265332, 0.08445574742342744, 0.21252925933471747, 0.2909521519073418, 0.2751559109560081, 0.19819558704538004, 0.1308384606880801, 0.1727010586432048, 0.0910284583057676, 0.09055453552199261, 0.20694271767778055, 0.14825916875685963, 0.23806713255388395, 0.192905510908791, 0.21006078964897565, 0.13770851918629237, 0.09673155870820795, 0.18698297228131974, 0.25819647099290577, 5.235256152493613, 43.39843102863857, 82.26809569767543, 86.0763338633946, 75.6383330481393, 70.70161710466657, 64.73449025835309, 69.77760396684918, 53.06838491984776, 55.75440216064453, 52.514366831098286, 45.42845841816494, 38.18444374629429, 36.367656571524485, 56.3752167565482, 33.50227158410208, 11.767861706869942, 2.5280453860759735, 0.16617636089878424, 0.1656942753387349, 0.28107246490461485, 0.8079239928296634, 3.9734971608434404, 5.832777781145913, 12.596910340445381, 13.99688810961587, 15.783076286315918, 11.170863798686437, 14.709626504353114, 19.194429874420166, 18.332927942276, 13.749795402799334, 13.70017397403717, 12.857496448925563, 18.139278173446655, 14.483380130359105, 15.482620545795985, 13.388793059757777, 12.219798598970685, 11.75982437814985, 9.640660285949707, 20.055214405059814, 28.829368318830216, 36.1389114516122, 44.19894688470023, 55.42885821206229, 49.08158847263881, 56.92477410180228, 50.383045128413606, 53.72813374655587, 47.79570272990635, 55.64164331981114, 52.365835189819336, 39.186801297324045, 47.74248647689819, 45.242441245487754, 60.155217443193706, 57.83683633804321, 52.98652471814837, 46.325908592769075, 43.82306323732649, 55.804724488939556, 44.09316750935146, 33.77854585647583, 47.52894401550293, 45.282066822052, 44.818142550332205, 42.65576587404524, 41.26840169089181, 27.67125126293727, 23.639480863298687, 22.414635045187815, 15.052342925752912, 18.25359341076442, 21.43396282196045, 19.398906673703873, 15.867943320955549, 14.473954030445643, 14.819943053381783, 22.053511108670914, 23.65976960318429, 21.02700683048793, 21.66039592879159, 17.589891059058054, 23.106147561754497, 13.76535849911826, 17.838136298315867, 13.048145464488439, 13.708933915410723, 9.525367089680262, 6.241929837635585, 2.281389547245843, 0.33477422328931944, 0.20827094997678483, 0.2551557384431362, 0.5444244721106121, 2.207938402891159, 12.116053308759417, 33.44605370930263, 48.74417005266462, 70.17412376403809, 78.4068705695016, 77.90207699366978, 66.94845036097935, 54.783606801714214, 27.77238576752799, 29.783415045057023, 45.14680971418108, 57.11481428146362, 65.53131662096295, 69.52214649745396, 68.01831313541958, 37.70613670349121, 5.184400984219142, 0.32990429603627747, 0.13058209658733436, 0.08966113560433898, 0.23633789962955884, 0.10573271249553987, 0.1661821962999446, 0.16845100027109894, 0.2009789241211755, 0.1462831390755517, 0.16292343687798294, 0.11042681775454964, 0.18149350184415067, 0.11524869794292109, 0.12955536453851632, 0.2925794688718659, 0.280432117836816, 0.25159817934036255, 0.12078781000205449, 0.14320037806672709, 0.1479679008147546, 0.1066038700352822, 0.2287245195891176, 0.26017898746899193, 0.17182585703475134, 0.26519412121602465, 0.15042015351355076, 0.17436171881854534, 0.12029687634536199, 0.11646634260458605, 0.13808098062872887, 0.23290120118430682, 0.261963670275041], [0.009982883697375655, 0.016668300942650864, 0.05410767499623554, 0.056368930265307426, 0.07920618661280189, 0.019318385615146587, 0.09698506617652518, 0.059286949756954394, 0.09381560196301766, 0.05515346370105233, 0.022768491912367086, 0.020292846718803048, 0.01725390210880765, 0.054873836027192216, 0.10759964053119932, 0.08138440615896668, 0.05542674367981298, 0.03539827625666346, 0.05227773729711771, 0.0539559783147914, 0.04140842393306749, 0.09841652400791645, 0.04841525812766381, 0.02910335761095796, 0.08184448682836123, 0.03651806599061404, 0.12455666490963527, 0.049911661938365014, 0.06998121804956879, 0.421462744474411, 13.753761087145124, 54.71303742272513, 67.8422805241176, 68.68571540287563, 59.07921246119908, 47.30491672243391, 37.25733866010393, 18.33360539163862, 31.114738532475062, 47.50005340576172, 47.959680216653005, 24.626759086336406, 29.822971139635357, 45.8441343988691, 31.832984243120464, 13.13189731325422, 2.354268116610391, 0.06814717182091304, 0.0869017643854022, 0.08747370155262095, 0.5011468029447964, 0.4840511945741517, 2.271263416324343, 4.226866696562086, 7.632394654410226, 8.174929107938494, 8.238250647272382, 10.14219515664237, 7.035873566355024, 3.2156597461019243, 5.645355335303715, 5.317975759506226, 9.861507041113716, 6.511080469403948, 4.4471293687820435, 9.325182540076119, 4.489930706364768, 4.735674594129835, 6.7406832575798035, 12.295234322547913, 25.706073147909983, 31.340134620666504, 40.00826597213745, 62.67967864445278, 65.01484312329973, 66.20739718845913, 62.59297207423619, 61.360194887433735, 58.432307379586355, 57.455703326633994, 57.79338230405535, 59.34588432312012, 53.883231435503276, 33.52168485096523, 42.961451871054514, 38.96097789491926, 44.65684012004307, 50.5695104598999, 37.0942713873727, 39.04368577684675, 40.18612595966884, 42.896357672555105, 40.13439662115914, 43.9354955128261, 56.062426226479666, 52.624735491616384, 55.09133904320853, 50.67128767286028, 52.54670374734061, 49.38862936837332, 49.845226764678955, 42.22867052895682, 30.58831868852888, 20.92069070679801, 19.27302094868251, 16.392233542033605, 17.26185097013201, 17.273991210120066, 8.35740269933428, 12.379823429243904, 15.438607181821551, 13.900786706379481, 6.134127667972019, 11.322362320763723, 9.085706795964922, 8.84990838595799, 5.697112032345363, 8.069715142250061, 8.376275743756976, 5.128485790320805, 6.331008783408573, 2.5905565917491913, 1.0192560042653764, 0.19758163498980658, 0.09769975354096719, 0.03312363349167364, 0.10937451172087874, 1.32293701171875, 8.490625722067696, 22.47333516393389, 36.59385865075247, 51.61935200010027, 42.68790824072701, 42.16504240036011, 29.260455404009136, 20.767845971243723, 16.235815695353917, 19.997523512159074, 36.4390458379473, 47.38978896822248, 53.624140058244976, 56.081832545144216, 33.225312914167134, 6.973443133490426, 0.4217967465519905, 0.08586829448384897, 0.04668323303173695, 0.06306545343250036, 0.05037412087299994, 0.05458657144169722, 0.07536788364606244, 0.020400733786768148, 0.09573916053133351, 0.04047448494072471, 0.01603931255106415, 0.048956196422555616, 0.052389040788901706, 0.04111994816256421, 0.14908661507070065, 0.10574310086667538, 0.07125484863562243, 0.0600471261090466, 0.04905503183337195, 0.03274506862674441, 0.04150599387607404, 0.11096651093768221, 0.09627285546490125, 0.03189028413700206, 0.07190280886633055, 0.030470361400927817, 0.11342284163194043, 0.06161766326321023, 0.012756355722168726, 0.03150266422224896, 0.1287247019686869, 0.11916448282344, 0.005325463858233499, 0.07361764327755996, 0.03926338135663952, 0.03167723771184683, 0.035291295032948256, 0.03410777389737112, 0.011061108920590153, 0.10096916596272162, 0.09737491168613945, 0.05939260444470814, 0.01658622534679515, 0.01631330668793193, 0.05994755109505994, 0.04251881595700979, 0.014442853662850601, 0.04073919502219983, 0.045172325535012145, 0.029214454149561267, 0.053373893656368764, 0.031294920548264465, 0.03435163938307336, 0.12185760188315596, 0.04290227305942348, 0.04437330983845251, 0.06128846521356276, 0.023828831800658788, 0.06366265924381358, 0.04137149805735264, 0.014186333499050565, 0.7228262020008904, 19.096604449408396, 63.32668794904436, 76.74580642155239, 76.26201725006104, 66.22969395773751, 56.25020129340035, 44.27977180480957, 31.476830005645752, 42.30065734045846, 45.182870864868164, 46.571461405072895, 28.99731843812125, 29.272500106266566, 36.87541355405535, 28.189534766333445, 13.57953153337751, 2.198918555464063, 0.053725581749209335, 0.2932543398014137, 0.1527686853493963, 1.4221306890249252, 3.349545236144747, 5.994452374322074, 8.180359125137329, 11.141688312802996, 11.55813728060041, 9.563920038087026, 11.836774809019905, 7.8140431472233365, 12.154059955051967, 14.330656119755336, 11.391545534133911, 11.469790066991534, 7.330184493746076, 11.016394053186689, 15.785900729043142, 8.356082541601998, 5.1366399356297086, 4.361617020198277, 10.983773129326956, 22.627557379858835, 34.26497186933245, 45.11138432366507, 61.93260138375418, 65.54220444815499, 67.1585499899728, 63.885552406311035, 62.39211354936872, 61.78147806440081, 57.22316101619175, 61.7297556740897, 64.05545670645577, 58.74927725110735, 39.05170052392142, 46.48433446884155, 47.95690441131592, 51.571635246276855, 55.88494144167219, 41.398134980882915, 44.72589479173933, 45.64741005216326, 48.41597536631993, 46.707694734845845, 48.98354244232178, 59.74300166538784, 54.958951541355674, 55.48869957242693, 52.22433165141514, 53.26466110774449, 49.95412588119507, 50.46718781335013, 43.804633140563965, 33.36756338391985, 24.730820519583567, 22.01643030984061, 17.206840344837733, 14.204937151500157, 12.898678421974182, 8.70078180517469, 11.892573186329432, 11.447837233543396, 8.772813779967171, 10.617193988391332, 16.52876217024667, 14.041195034980774, 14.207393339702062, 9.435825654438563, 15.485177482877459, 11.77482727595738, 10.84989697592599, 7.3149184329169135, 4.4364829914910455, 2.489839847598757, 1.2620052184377397, 0.22340346154357704, 0.1922425821955715, 0.05416475675467934, 1.2192961616175515, 8.34696911062513, 24.07923582621983, 41.720510550907676, 63.32017053876604, 57.19348178591047, 47.82096637998308, 36.606733662741526, 25.846746376582555, 22.632221358163015, 27.133403369358607, 44.38094799859183, 52.86446918760027, 62.19716794150216, 62.435796873910085, 41.336900506700786, 9.097188694136483, 0.5657740065029689, 0.08550549538007804, 0.01682461335855935, 0.08555402420461178, 0.02175410241553826, 0.017676663352176547, 0.054457066248037984, 0.04388996559594359, 0.08784519947533097, 0.026968058797397783, 0.013431487887698625, 0.029708526030715023, 0.022882329732445732, 0.08504569291004113, 0.10347598644771747, 0.02571067912504077, 0.04695447062009147, 0.04281195326309119, 0.03637812492836799, 0.026100107335618565, 0.05939723883888551, 0.02010280093444245, 0.0881842498534492, 0.040820754931441376, 0.017735332882563983, 0.04605340325672712, 0.08180193589734179, 0.04813321826181241, 0.052810560313186476, 0.07880059909075499, 0.06120282730885914, 0.04257149402318256, 0.10855216120502778, 0.16034505808992044, 0.2206149540309395, 0.10181025083043746, 0.12454032578638621, 0.144499379077128, 0.28715124300548006, 0.243950221155371, 0.13564649197672093, 0.15888087451457977, 0.1802237049809524, 0.14519527102155344, 0.15154853010816233, 0.1855711308973176, 0.24819044076970645, 0.20840147297297204, 0.1188074376966272, 0.1243954992720059, 0.15810093922274454, 0.12347799779048987, 0.21084265198026383, 0.25149821756141527, 0.13671580888330936, 0.18692875733332975, 0.139643239655665, 0.3013739069657666, 0.20109903839017662, 0.1089259118639997, 0.14167406782507896, 0.999914716397013, 24.799057040895732, 73.23862675258091, 85.32643563406808, 83.90174225398472, 73.62113203321184, 60.647921153477256, 49.26796347754342, 29.478496823992046, 43.76411124638149, 57.3149710382734, 59.400392941066194, 35.45212023598807, 41.947779178619385, 58.47949259621756, 40.62222269603184, 16.231695413589478, 3.3559988098485127, 0.15659191805337155, 0.33295355098588125, 0.17893798968621663, 1.02026729285717, 2.977578852857862, 8.770913447652545, 10.082829747881208, 18.34185811451503, 18.95175187928336, 19.267432859965734, 19.750459466661724, 15.043529135840279, 9.726139630590167, 14.776525497436523, 17.523660830089025, 19.786416394369944, 14.024423820631844, 13.33511996269226, 17.91546627453395, 11.107694251196724, 12.32865081514631, 15.343880653381348, 19.054362876074656, 31.889452253069194, 37.223956039973665, 46.99423844473702, 67.57864502498082, 68.99274935041154, 70.15240369524274, 67.14398656572614, 65.13727733067104, 61.619036129542756, 58.536460876464844, 58.735679626464844, 64.91496276855469, 60.87378624507359, 42.05149841308594, 53.793877601623535, 52.34525115149361, 56.25577374867031, 58.14462416512625, 44.84989929199219, 47.52582080023629, 47.05908250808716, 52.80819920131138, 50.39786563600813, 52.061806338174, 60.99216965266636, 54.94782052721296, 55.429490498134065, 52.864292008536204, 54.1743609564645, 50.96667643955776, 53.68931416102818, 48.831022535051616, 36.48766238348824, 27.796607187816075, 26.09903720446995, 22.918876239231654, 25.966581957680837, 27.771987983158656, 15.736710957118444, 20.81919663293021, 25.777804613113403, 26.291814974376134, 12.713515877723694, 22.39167124884469, 16.85018583706447, 20.34282466343471, 17.07225373813084, 19.485901594161987, 20.43595658029829, 17.592474051884242, 15.346051965441022, 8.762896963528224, 3.2153831209455217, 0.7310569403426987, 0.27637198141642977, 0.22229382608618053, 0.1667147105825799, 1.9660913688795907, 10.45175564289093, 26.407846416745866, 44.11046157564436, 61.62019647870745, 50.40647792816162, 53.30261216844831, 38.69222157342093, 29.593979358673096, 25.341344833374023, 31.4633400780814, 51.36713933944702, 61.01276411328997, 68.77046952928815, 71.68756648472377, 51.18764999934605, 13.396333592278616, 0.8483244021024022, 0.3554311362760407, 0.17504458289061273, 0.17241945303976536, 0.13042017099048409, 0.20647986180015973, 0.15154599238719257, 0.09939974160598856, 0.18043904485447065, 0.10102192206042153, 0.10182596570146935, 0.14389542862772942, 0.12479739556355135, 0.18208918773702212, 0.18489699278559002, 0.3310350067913532, 0.2209451427417142, 0.13337124192288943, 0.10360256715544633, 0.11612269175904137, 0.13307635060378484, 0.2570569935653891, 0.23403280760560716, 0.20348582603037357, 0.15794224345258304, 0.12705394519226892, 0.22849756319608006, 0.1883492703948702, 0.13391344568559102, 0.11804760061204433, 0.2693932487496308, 0.1978437937796116], [0.021805840710710202, 0.04295137185337288, 0.0290088071487844, 0.03480758438152926, 0.06987514267010347, 0.055576028169265816, 0.08448275311716966, 0.03078660960974438, 0.031371842670653544, 0.0786835653707385, 0.058560652658343315, 0.08870043858353581, 0.06916269447122302, 0.04272021193589483, 0.11577825381287507, 0.06541531519698245, 0.07841800712049007, 0.009223273922024029, 0.05282103010852422, 0.03424676840326615, 0.02320299350789615, 0.09609985617654664, 0.05104350584692188, 0.0401506303543491, 0.03263264215950455, 0.03422670751543982, 0.04005691109757338, 0.11605395616165229, 0.09113839454948902, 5.446589955261775, 37.253753389631, 66.34286621638707, 63.296206201825825, 55.350840364183696, 46.653095790318076, 47.78019435065133, 29.99259751183646, 19.394591842378887, 39.40108026776995, 76.29534081050328, 57.95103693008423, 38.197867665972026, 49.12706790651594, 31.97719063077654, 13.791825924600873, 1.7726001058306013, 0.05307225091382861, 0.14727533369192056, 0.1494090820529631, 0.33192578756383484, 2.0125919708183835, 3.5869449887956892, 4.105073460510798, 5.331565133162907, 9.214494262422834, 8.48456689289638, 10.110451442854744, 12.692844986915588, 10.422756467546735, 16.109407118388585, 8.803698522703987, 10.574720518929617, 8.669144051415579, 7.9005933829716275, 6.636399916240147, 13.463137047631399, 7.620690413883754, 13.452740805489675, 23.30272773333958, 34.18941715785435, 52.12794624056135, 55.4685845375061, 60.95492730821882, 62.375111307416645, 63.52079977308001, 63.37872995649065, 57.45738131659371, 58.12453692299979, 57.81796850476946, 57.581305912562776, 62.08817155020577, 63.759866441999165, 57.530841146196636, 42.56279897689819, 35.20075178146362, 35.77272054127285, 37.59219319479806, 49.22870962960379, 39.99080514907837, 50.19731283187866, 43.81529515130179, 44.92696523666382, 47.95647014890398, 52.40772587912423, 55.62749678747994, 55.23668493543352, 57.64691775185721, 56.40776211874825, 59.21172155652727, 55.91334220341274, 59.56259863717215, 58.649362155369346, 53.34042426518032, 40.79778977802822, 36.47231381280081, 28.114678348813737, 27.24084857531956, 21.369273356028966, 16.973351342337473, 16.077910934175762, 11.444829532078334, 7.338603104863848, 17.445816687175206, 24.096385717391968, 23.694482803344727, 12.73950127192906, 6.723617613315582, 8.6062958581107, 8.724860787391663, 8.536009618214198, 6.144017994403839, 4.2194772873606, 2.370745552437646, 1.8613774563585008, 0.6713595922504152, 0.10673524120024272, 0.02870290320632713, 0.041660123105560026, 0.32620541165981976, 3.4226044586726596, 16.803360189710343, 25.241648605891637, 22.938838413783483, 22.68816304206848, 38.3831969669887, 32.81907606124878, 18.48100621359689, 16.70811254637582, 23.918082782200404, 44.345574719565256, 51.74743161882673, 51.1255852154323, 50.34201601573399, 23.699207578386577, 0.8592802999275071, 0.08148387939270053, 0.07403783287320818, 0.05055094709885972, 0.0974432605185679, 0.03791474211694939, 0.04345574728878481, 0.021670081120516573, 0.05882522024746452, 0.05024238669180444, 0.015336582669988275, 0.03975882387853094, 0.0713169617312295, 0.006074139465843993, 0.13202588340001448, 0.05271010998902576, 0.03491715421634061, 0.053400594009352584, 0.07062427247209208, 0.05952406381922109, 0.026353070279583335, 0.0846892109672938, 0.045117717036711316, 0.03177512317363705, 0.017144693593893732, 0.03876434599182435, 0.04164914780163339, 0.011471350344696214, 0.028568380246204988, 0.029756372927555015, 0.13423739187419415, 0.10245897780571665, 0.050067406081195386, 0.05075777814324413, 0.014125714028653289, 0.036412180600953956, 0.036735763773322105, 0.057364938248481066, 0.04316916123830846, 0.015931057377851436, 0.07737795542925596, 0.0062749497841910595, 0.03663299625207271, 0.06500024854072503, 0.0899894040610109, 0.05987632527415242, 0.03873895521142653, 0.10182474433843579, 0.09235642597611461, 0.03566101519390941, 0.06615940348378249, 0.035032305001680336, 0.04893856469009604, 0.05914288320179496, 0.07927789419357266, 0.03301649959757924, 0.029542227275669575, 0.022652499743604233, 0.033574720179396014, 0.08526812347450427, 0.14310158336801188, 7.2744143434933255, 46.444795744759695, 77.29604121616909, 72.22738592965263, 64.27526296888078, 55.08357443128313, 56.55236455372402, 40.1017609323774, 25.364612613405498, 37.88667869567871, 69.6761394228254, 56.309698717934744, 40.2799196924482, 42.08597190039498, 31.937446934836252, 13.374119332858495, 2.2803653393472945, 0.0650914775739823, 0.14985715943787778, 0.2302974180451461, 1.9312185772827692, 4.954353511333466, 7.384387390954154, 6.05832542691912, 7.550212230001177, 13.947066051619393, 14.574039357049124, 12.301432115691048, 14.703901188714163, 14.790691137313843, 15.426588535308838, 12.628769568034581, 9.515131524630956, 8.093393734523229, 5.857052615710667, 7.04292859349932, 10.343936971255712, 4.730237194469996, 10.106211304664612, 20.238685062953405, 33.92400639397757, 52.971943923405235, 59.64866597311837, 63.84473868778774, 64.87211322784424, 64.96115439278739, 64.55643572126115, 60.35068416595459, 60.28876182011196, 60.51053442273821, 58.791487557547434, 62.11434541429792, 65.06783703395298, 62.10204710279192, 46.65071950639997, 39.954931599753245, 39.67077112197876, 44.25788497924805, 56.32305662972586, 44.94760833467756, 52.94739246368408, 48.01922280447823, 49.63343177522932, 53.958143438611714, 56.63866465432303, 56.84985862459455, 53.630768639700754, 57.19152239390782, 58.772560664585654, 62.0208226612636, 58.89448070526123, 61.675608362470356, 58.2352807862418, 53.81554208483015, 43.348793097904746, 38.23330347878592, 29.457693917410715, 25.50459623336792, 19.70222680909293, 14.15323907988412, 12.992138641221182, 10.371537821633474, 8.83309461389269, 11.788433585848127, 14.1651109457016, 20.88345183644976, 14.067470516477313, 12.10525928224836, 12.307378036635262, 12.993182608059474, 11.721016083444868, 10.221641727856227, 6.897984828267779, 5.094978971140725, 5.032060861587524, 1.7598933705261774, 0.3660632371902466, 0.1270870848425797, 0.014422780900661434, 0.4520303670849119, 4.826505354472569, 19.61832731110709, 33.17286096300398, 27.306811298642838, 25.607839516230992, 34.9373004095895, 28.31179700578962, 22.12523909977504, 24.273161785943167, 32.17844867706299, 51.602016244615825, 59.351533208574565, 59.405583245413645, 57.79261105401175, 28.299495220184326, 1.7371436655521393, 0.0877345846965909, 0.03927370187427316, 0.0023818879812357147, 0.04257822169789246, 0.04031324805691838, 0.023017117321225147, 0.027521814618791853, 0.022060467761808207, 0.02100969012826681, 0.04346118913963437, 0.04284950339102319, 0.03304777666926384, 0.0672440892085433, 0.06521590054035187, 0.03199871403298207, 0.04136025133941855, 0.0806406299982752, 0.029674680703984838, 0.00924364269511508, 0.01539373567460903, 0.04018640950588243, 0.03837603057867714, 0.02922147698700428, 0.03579399448686412, 0.03329537749024374, 0.017745904458154525, 0.03771824516089899, 0.006455409989160086, 0.048889167340738435, 0.02854652124057923, 0.0382484354610954, 0.07314663819436516, 0.11616235891623156, 0.1659141749675785, 0.16599580273032188, 0.2149780107928174, 0.17398380195455893, 0.1632995895509209, 0.14419889662946972, 0.19613412980522427, 0.13357801868447236, 0.10189849430961267, 0.20171058843178408, 0.13705118160162652, 0.17967639863491058, 0.30122946043099674, 0.30144702589937616, 0.17292407953313418, 0.08591034329895463, 0.17884048420403684, 0.08897513670048543, 0.19296446203121118, 0.19856688140758447, 0.1257411834916898, 0.0867347362052117, 0.07078509884221212, 0.1633700214858566, 0.12985283429069178, 0.2045142679874386, 0.22501339444092341, 10.01588385445731, 56.15649093900408, 86.4036704472133, 80.36729090554374, 72.29864665440151, 61.67283603123256, 62.46079649244036, 40.79568099975586, 29.545178685869487, 49.21562964575631, 85.4178113937378, 66.39706911359514, 51.43881695611136, 62.62756020682198, 40.834299087524414, 16.656237295695714, 2.640932334320886, 0.1457163994865758, 0.3672341715012278, 0.3618814530117171, 1.206007297549929, 6.490393076624189, 10.542383602687291, 11.286483560289655, 14.563921911375862, 18.44735782487052, 20.736914328166417, 20.121840681348527, 21.16105842590332, 21.32383908544268, 28.496000698634557, 16.054167202540807, 18.830412013190134, 19.102121319089616, 20.95917330469404, 14.034021888460432, 24.423336676188878, 14.476050649370466, 19.178944076810563, 29.11814066341945, 41.44167934145246, 58.163415568215505, 63.08493232727051, 66.24295112064907, 67.35268265860421, 68.24550533294678, 67.68097114562988, 61.60104029519217, 61.44005053383963, 63.11888122558594, 59.779014178684776, 62.69607639312744, 64.28484453473772, 63.94196483067104, 50.16942971093314, 43.56574017660958, 45.48062549318586, 50.34790113994053, 62.052478654044016, 45.868036202022004, 55.387078693934846, 51.05827106748308, 53.95668431690761, 57.61022431509835, 56.46622426169259, 58.44486277444022, 54.34981686728341, 58.13838120869228, 58.22250999723162, 62.40517616271973, 59.63279628753662, 62.311062812805176, 60.293764523097444, 55.87242078781128, 43.29392317363194, 42.35068089621407, 34.635526248386924, 35.133969170706614, 29.541107041495188, 22.65381635938372, 22.51949725832258, 18.460858174732753, 13.88543118749346, 27.376402718680247, 36.175177574157715, 33.84390408652169, 22.61603205544608, 14.4643794127873, 15.393457787377493, 15.499692269733973, 17.83246656826564, 12.83149368422372, 9.149788294519697, 6.1942795259611945, 4.979840806552342, 1.8949576658861977, 0.3557245891009058, 0.24366412365010806, 0.1561316406088216, 0.5784747706992286, 5.857570256505694, 23.24700665473938, 36.247372831617085, 31.191439696720668, 31.215553419930593, 50.50474282673427, 43.82040902546474, 28.403947489602224, 26.46065272603716, 36.65741382326399, 59.85128239222935, 68.42781911577497, 66.31730379377092, 65.00053678240094, 35.95602791649954, 3.076147083725248, 0.1309461441955396, 0.2764839939773083, 0.10165880859962531, 0.23645354913813726, 0.1474816897617919, 0.0773072995777641, 0.05393953062593937, 0.11742366052099637, 0.11236123966851405, 0.14759979556713784, 0.08992542499410254, 0.18337100824075087, 0.1885378895593541, 0.2482115024966853, 0.13314903527498245, 0.16489269477980478, 0.18531834946147033, 0.20696970980082238, 0.12658139983458178, 0.13163677070822033, 0.2570717584873949, 0.27071356933031765, 0.0956563792590584, 0.13697712628969125, 0.13628997387630598, 0.11251479892858438, 0.10816626476922206, 0.1415056690041508, 0.1378850604274443, 0.14440351564969334, 0.1322247213018792], [0.04383350808971694, 0.04231952004400747, 0.0236729451654745, 0.040204801197562895, 0.05246411729604006, 0.10172855521419219, 0.044923774765006134, 0.0212418593665851, 0.046312230439590554, 0.06740934641233512, 0.05490127259067126, 0.07289398568017141, 0.0535580718091556, 0.04050523275509477, 0.07156409097037145, 0.13806728779205255, 0.057621471982981474, 0.04888950660824776, 0.030784563826663152, 0.050184063214276514, 0.04024509599964533, 0.046095489391258786, 0.04073752921872905, 0.08500535400318247, 0.06254409426557166, 0.08952966265912567, 0.10472998023033142, 0.05142455415001937, 0.41500007840139524, 16.878602232251847, 57.52835716520037, 74.5053458895002, 62.021795409066335, 51.68366800035749, 39.273632935115266, 29.35877241407122, 20.699562549591064, 28.53691864013672, 58.71039513179234, 67.92803519112724, 61.32003429957798, 32.29352126802717, 29.218269416264125, 14.314683079719543, 3.272941780941827, 0.49597256630659103, 0.12977503346545355, 0.024037606847871627, 0.6116658268230302, 1.1320198391165053, 2.000188567808696, 5.607567123004368, 5.421876949923379, 7.4029790333339145, 9.068257263728551, 8.100349749837603, 5.444888515131814, 8.68036104951586, 5.192026632172721, 13.519079600061689, 22.690370832170757, 6.667551730360303, 9.750785759517125, 4.725672662258148, 20.410079751695903, 30.76717574255807, 24.22393379892622, 31.441102368491038, 41.822958265032085, 52.27412939071655, 59.70407090868269, 58.69848591940743, 57.77639395850045, 60.981399944850374, 58.15943772452218, 58.0921687398638, 59.3635744367327, 56.80371216365269, 57.8632047516959, 58.59957831246512, 63.89637769971575, 61.81154291970389, 62.57852676936558, 52.23337820598057, 51.62068952832903, 37.4332913671221, 25.0564843245915, 44.745589460645405, 40.08364003045218, 47.45283692223685, 38.869365896497456, 45.58518198558262, 55.259349959237234, 61.11933558327811, 56.04784543173653, 58.97980458395821, 60.998311860220774, 57.614956038338796, 56.400108678000315, 55.591133390154155, 59.22886971064976, 62.18346609388079, 57.74796192986624, 58.44763510567801, 54.11290413992745, 47.00779785428728, 38.35051958901541, 29.99820123400007, 22.64815010343279, 19.572646379470825, 15.15421393939427, 11.695715955325536, 13.318047370229449, 16.17867371014186, 16.91393903323582, 15.884552989687238, 11.15888510431562, 19.47100986753191, 14.40879556110927, 12.279461043221609, 7.279991141387394, 4.013386768954141, 3.855280075754438, 3.9313532965523854, 1.3146579074008125, 0.4668092940534864, 0.06691611930727959, 0.11408958371196475, 0.03750011311577899, 0.7453751148922103, 4.674673753125327, 20.332652500697545, 43.263896533421104, 35.114896365574424, 34.21710920333862, 43.41978631700788, 24.688200269426616, 19.343746662139893, 21.39001199177333, 28.26285215786525, 43.42011635644095, 49.58465542112078, 50.85320193426949, 32.340515409197124, 8.666794691767011, 0.20122815003352507, 0.08389565747763429, 0.09389895320470844, 0.04254494294790285, 0.07266906489218984, 0.023856527903782468, 0.013541949147890722, 0.02377186030415552, 0.06419403358761754, 0.07718903092401368, 0.05944143182465008, 0.02684226519029055, 0.06601785429354225, 0.01994172011369041, 0.03576682594471744, 0.029797702495540892, 0.05927321620817695, 0.03600727839927588, 0.020646623003163507, 0.01388322003185749, 0.06358605942555837, 0.053622332468096695, 0.014460534589099032, 0.04684932144092662, 0.00867735518009535, 0.025288484458412443, 0.018542557156511714, 0.05209340986662677, 0.01975819335452148, 0.13866810340966496, 0.04367989454684513, 0.02438004650840802, 0.047907931064920764, 0.039555897803178856, 0.04103097186556884, 0.03706899232098034, 0.08089394069143704, 0.02332799492536911, 0.07160436880907842, 0.03839283449841397, 0.04045724675857595, 0.035612628861729584, 0.016034401653866683, 0.059188460398997576, 0.016152963774012666, 0.12146175812397685, 0.1140324239219938, 0.04734792932868004, 0.0234098805314196, 0.056963991905961714, 0.03788534119459135, 0.08656518387475184, 0.03930202053327646, 0.06914577859320811, 0.04690093081444502, 0.021982074914766208, 0.014888395023133074, 0.0829672519383686, 0.0207549392445279, 0.7857681417039463, 22.804069416863577, 67.53555924551827, 78.48798383985246, 69.85117844172886, 59.49418667384556, 50.57553802217756, 38.56734160014561, 29.44028867994036, 27.868448087147303, 53.54854713167463, 70.41577516283307, 59.98978083474295, 36.37006759643555, 29.87152167728969, 14.904978581837245, 2.6855471517358507, 0.38227297738194466, 0.14875425504786627, 0.07600231388849871, 1.7444245091506412, 4.5521639840943475, 6.770626953669956, 11.751250301088605, 11.248774818011693, 9.841377241270882, 12.008089593478612, 13.807658263615199, 13.142520240374974, 13.898026534489222, 12.088009510721479, 17.537326199667795, 16.603248596191406, 10.556689943586077, 5.820661859852927, 5.723472195012229, 10.296206321035113, 15.945717981883458, 18.31764885357448, 28.78389409610203, 43.68142073495047, 53.98711395263672, 61.92693860190255, 61.47242219107491, 61.00770582471575, 62.89964471544538, 60.32589994158064, 59.80946118491036, 59.862246649605886, 59.402658053806846, 59.28164822714669, 59.255432673863, 65.62247698647636, 61.44943060193743, 64.85147012983049, 55.38559177943638, 55.25017138889858, 40.41445071356637, 30.990956374577113, 51.79251153128487, 47.003194672720774, 51.22416625704084, 42.71076086589268, 49.94016695022583, 58.941005843026296, 64.14292757851737, 56.1229624067034, 60.114320346287315, 61.055259295872276, 60.34991986410958, 60.54114123753139, 57.51070874077933, 61.685037067958284, 62.299973487854004, 59.511716978890554, 59.57669653211321, 55.16100863048008, 46.98791905811855, 37.50480570111956, 27.439344712666102, 22.459426607404435, 18.903137070792063, 17.49687726157052, 11.555003643035889, 11.230852808271136, 9.23282708440508, 18.078028065817698, 13.565622976848058, 10.972026331084114, 15.441299608775548, 12.786102839878627, 9.808585218020848, 12.149672167641775, 8.277033754757472, 5.218052412782397, 6.6950275131634305, 3.8401017359324863, 1.660654638494764, 0.3978216073342732, 0.15080033668449946, 0.06189657508262566, 0.7408493406006268, 4.821787527629307, 19.314790044512065, 35.01942811693464, 36.873332568577354, 36.30317381450108, 37.2359972681318, 24.285553898130143, 23.641617434365408, 24.61435307775225, 34.34415354047503, 50.09893328802926, 55.82821634837559, 59.603301184517996, 38.605907576424734, 10.287186690739222, 0.291537239083222, 0.1509774343243667, 0.05423018788652761, 0.011863688622335238, 0.06428583937564067, 0.03086848503776959, 0.03419127780944109, 0.09390486324472086, 0.06132186270718064, 0.06289310553776366, 0.035676631677363596, 0.007318790669419936, 0.043693210796586106, 0.025045334827154875, 0.041839093502078734, 0.039931843522936106, 0.03179144533351064, 0.024901210596518855, 0.03251212416216731, 0.043003218714147806, 0.06341699564031192, 0.11237445074532713, 0.049710469519985576, 0.014312047378293105, 0.05624490763459887, 0.04709408259285348, 0.03802736196666956, 0.012648880864227456, 0.09451378057045595, 0.08454893742288862, 0.036013520921447446, 0.18042182363569736, 0.17066153165485176, 0.1327692727957453, 0.11406263230102402, 0.1755063802536045, 0.17248588161809103, 0.07965325298053877, 0.20321726186999253, 0.09886302719158785, 0.20793825068644115, 0.13200947642326355, 0.13312132390482084, 0.14183045657617704, 0.11872372004602637, 0.21121264355523245, 0.28882603027990883, 0.1901227438024112, 0.22095333944473947, 0.1422309550855841, 0.14945056768400328, 0.2189929432102612, 0.16250773918415817, 0.20858930503683432, 0.16092163643666677, 0.16286554427019187, 0.16201284288295678, 0.26181173271366526, 0.12492538083876882, 1.236714861222676, 30.196238790239605, 78.02407346452985, 89.23981394086564, 78.8107693535941, 66.03548485892159, 52.8964969090053, 39.174707957676475, 29.207221780504497, 41.587348324911936, 69.75789192744664, 74.15749127524239, 67.2647671018328, 42.62377984183175, 37.44698279244559, 17.370746612548828, 4.2023551889828274, 0.834221133163997, 0.42374541770134655, 0.13532407927725995, 1.4152356875794274, 5.506882948534829, 10.529439977237157, 16.570017099380493, 15.13353088923863, 17.964768954685756, 20.215229681559972, 19.769381148474558, 15.369260685784475, 17.644635915756226, 11.10749101638794, 21.689604418618337, 31.32460192271641, 14.842441320419312, 19.71665300641741, 10.77657003062112, 27.702101264681133, 38.45711885179792, 29.381135191236222, 34.83941766193935, 48.14478717531477, 58.15493876593453, 64.1199220929827, 64.05721460069928, 63.24369171687535, 66.78223555428642, 62.8005564553397, 63.620416096278596, 63.203711782182964, 59.35106767926897, 60.32594163077218, 61.19955253601074, 67.20913287571499, 61.23047201974051, 65.38913563319615, 58.007466724940706, 57.206509658268516, 48.93263993944441, 35.739601952689036, 60.29022789001465, 48.427481583186555, 51.74624000276838, 48.81834554672241, 55.518132141658235, 60.25133187430245, 65.41540677206856, 57.64596932274954, 61.42010225568499, 65.12882832118443, 61.89449051448277, 61.655326570783345, 58.45481954302107, 63.85236086164202, 66.2437710080828, 60.69745486123221, 59.9129615511213, 57.35875858579363, 50.6298451423645, 44.55246775490897, 38.016835825783865, 28.856148413249425, 24.31036765234811, 22.41479137965611, 17.130311148507253, 21.538039888654435, 24.239666257585796, 23.351776804242814, 25.069539989743912, 16.28943841797965, 32.435382638658794, 24.741635390690394, 22.306123290743145, 17.747488362448557, 12.689033899988447, 10.779465692383901, 10.556087187358312, 4.795099062579019, 0.6974654942750931, 0.3291173039802483, 0.35357697148408207, 0.1527345007551568, 0.9523278070347649, 6.430048840386527, 25.620389699935913, 53.775294644492014, 45.131138052259175, 48.209971700395855, 58.491679736546104, 33.84965024675642, 29.11274365016392, 31.534996850149973, 41.342618874141145, 58.42218385423933, 63.93866443634033, 69.38735839298793, 46.24123089654105, 15.975266933441162, 0.5931559886251176, 0.2034074959478208, 0.15208497989390576, 0.08224759091223989, 0.12227711294378553, 0.12651550051357063, 0.11096578490521226, 0.17468992620706558, 0.1579369915915387, 0.2039360882980483, 0.11570871754416398, 0.10640503213341747, 0.13135918203209127, 0.09424367613558259, 0.26219819911888664, 0.11776470579206944, 0.1513598838022777, 0.14302184193262032, 0.13199591929359095, 0.11226790039134876, 0.1362034199493272, 0.33810534168566975, 0.153122052816408, 0.17568170013172285, 0.16954363164092812, 0.18755950991596493, 0.05770361543233905, 0.11709539884967463, 0.15281714632042817, 0.2930098500634943, 0.13924770802259445], [0.020425620754914622, 0.03155349328049591, 0.056759471273315806, 0.08029393931584698, 0.02276919249977384, 0.1363079414835998, 0.0356690999386566, 0.027211023527862768, 0.027847903281716362, 0.03783712449616619, 0.010243931386087621, 0.03071684603180204, 0.046946229812289984, 0.009334969267781292, 0.023012114821800163, 0.046894389736865244, 0.10336368890213114, 0.005550405002265636, 0.020722194840865474, 0.05627292773819395, 0.04533089916887028, 0.026312646555847356, 0.026701806745092784, 0.018625631895182387, 0.04291502273242388, 0.05197308185909476, 0.021029946094911014, 0.15073989278503827, 1.8605964354106357, 37.46579156603132, 70.36856215340751, 60.96880980900356, 52.82913759776524, 41.62914521353585, 31.72889675412859, 20.613316297531128, 21.333887917654856, 53.58000857489449, 56.858589036124094, 66.39715944017682, 46.16223682676043, 30.5975250516619, 20.25265962736947, 4.588797492640359, 0.5520897465092796, 0.08892744925937482, 0.06553765506084476, 0.41636455804109573, 1.2702458905322211, 5.724628201552799, 7.141802327973502, 8.921042306082589, 6.255460585866656, 4.514259389468601, 15.73450664111546, 15.089576584952217, 12.824301430157252, 15.72865799495152, 26.089843000684464, 16.407761028834752, 17.12066878591265, 14.884127037865774, 11.398253151348658, 20.29653229032244, 26.291681221553258, 30.683349200657435, 40.43438856942313, 49.10839809690203, 61.40031378609793, 61.47441632407052, 59.25102056775774, 58.41375568934849, 60.27897875649588, 52.13995967592512, 51.059257711683, 54.299949645996094, 57.647643838609966, 57.32038368497576, 59.29405076163155, 60.56988593510219, 60.16336073194231, 61.63373156956264, 58.45711244855608, 62.35221004486084, 63.39200101579939, 43.01857648577009, 23.332353115081787, 40.18603910718645, 37.233148506709504, 41.14910806928362, 37.867911611284526, 45.77802576337542, 59.15829685756138, 59.420966557094026, 56.73920161383492, 60.41472571236746, 55.70076206752232, 53.07463135038103, 53.06909016200474, 53.68085125514439, 58.219001156943186, 58.55684689113072, 58.10046141488211, 57.63137810570853, 57.14321156910488, 54.15847042628697, 53.99268988200596, 43.057305744716096, 35.36535113198416, 31.05098533630371, 28.573721511023386, 24.29916889326913, 18.525780405317033, 17.992332458496094, 42.57874856676374, 16.74090804372515, 14.075495685849871, 11.500150220734731, 8.839540805135455, 7.7485615866524835, 10.068986330713544, 7.926532745361328, 5.398425476891654, 6.8555391516004285, 3.8196601356778825, 2.6286574729851315, 0.6437807264072555, 0.09265899831163031, 0.07119805525456156, 0.09543215057679585, 0.410641359431403, 4.324336894920894, 21.972663606916154, 32.1540709223066, 34.775355270930696, 31.508461679731095, 31.733524254390172, 20.528789724622452, 22.171237911496842, 36.1980927331107, 41.0963260786874, 47.16490357262747, 55.61668886457171, 50.803529262542725, 24.098949602672032, 3.153592790876116, 0.06884326054049389, 0.05367663223296404, 0.037333749899906774, 0.04105521931446024, 0.050317134109458754, 0.02346623795373099, 0.05555643547060234, 0.03749047452583909, 0.037724267159189494, 0.020924405061772892, 0.03975508515057819, 0.019382425750206624, 0.036836875669125996, 0.03776521335488983, 0.04220251685806683, 0.04128515108355454, 0.07180229068866797, 0.051029405889234374, 0.08143564912357501, 0.025523328821041753, 0.06222375109791756, 0.0311943989779268, 0.08854104392230511, 0.04633243042709572, 0.05995130339371307, 0.05448279290327004, 0.04666927556640335, 0.07797126644956213, 0.03427572149251189, 0.020232083907883083, 0.056747719046792815, 0.02640165338691856, 0.071652273381395, 0.01113031355531088, 0.08255789854696818, 0.06738715153187513, 0.04849573238087552, 0.013948990431215082, 0.022734222501250248, 0.052373956955437145, 0.026222893336255635, 0.06343120416360241, 0.04963876193921481, 0.013469320455832141, 0.04154234978237322, 0.056501319232795916, 0.09847074574125664, 0.06321062599974019, 0.07453822530806065, 0.05092197343973177, 0.0609181479417852, 0.027014450236622776, 0.03485001317624535, 0.037461355195513794, 0.03599304612725973, 0.06501139687108141, 0.05069244879164866, 0.18674173951148987, 3.4912224795137132, 47.43390308107649, 77.49174417768205, 71.07503414154053, 59.90659005301339, 53.377183709825786, 40.560348987579346, 31.872196401868546, 21.4516008240836, 41.4809262411935, 59.000961848667686, 68.45176260811942, 51.92974887575422, 26.38447788783482, 18.197220938546316, 4.094980333532606, 0.5852960561003003, 0.04710740902061973, 0.16410174007926667, 2.4363715052604675, 5.226342482226236, 7.730101960045951, 8.128834758486066, 12.786850639751979, 11.752668602125985, 11.324174063546316, 14.813517706734793, 11.493318404470172, 15.959147112710134, 12.59027567931584, 13.290971108845302, 9.469169190951757, 11.091238311358861, 12.958531073161534, 12.912939599582128, 16.70064323289054, 24.557306630270823, 28.406381096158707, 41.19054365158081, 50.27654661451067, 63.31388241904122, 63.27274213518415, 61.303039005824495, 61.35982663290841, 62.8004035949707, 56.23032944543021, 53.35678379876273, 54.90848330089024, 58.969389234270366, 58.4334260395595, 61.84906319209507, 61.30141312735421, 61.77477305276053, 61.9780912399292, 60.41910307747977, 63.929756845746724, 67.24719510759626, 45.74480642591204, 29.49069438661848, 47.59392009462629, 43.07791062763759, 47.06040613991873, 42.452472005571636, 52.65819454193115, 60.465989521571565, 61.392024585178916, 55.77240146909441, 60.08003098624093, 57.768907274518696, 56.40541362762451, 56.14295237404959, 56.80586610521589, 60.05504526410784, 59.726867948259624, 58.990664618355886, 59.15897083282471, 57.32051222664969, 56.95139265060425, 55.56325374330793, 44.733506543295725, 35.298047406332834, 29.429307052067347, 25.19579918043954, 24.637872729982647, 17.922018425805227, 14.727818625313894, 9.245188798223223, 11.144913145474025, 13.778557470866613, 11.458635602678571, 11.418878878865923, 15.073253529412405, 12.1472715650286, 12.507380196026393, 11.357032094682966, 7.2011134539331705, 6.545390674046107, 5.388284581048148, 2.189888285739081, 0.19101458308952196, 0.019621329448585, 0.040601106360554695, 0.4621553580675806, 4.302381455898285, 19.714943749564036, 31.632643359048025, 33.54756341661726, 35.81509760447911, 35.832829407283235, 27.24344199044364, 30.066276209694998, 41.06602498463222, 48.38228007725307, 52.941649777548655, 63.58766923631941, 60.547359875270296, 29.72357021059309, 4.076835112912314, 0.031609119581324716, 0.07893375480281455, 0.022006827872246504, 0.015174760549728359, 0.10154155096305267, 0.029949032768074955, 0.04203915615965213, 0.05032555812171527, 0.05190601545785155, 0.07186638510652951, 0.0363211890549532, 0.05515137720586998, 0.014490072914798344, 0.01378801987240357, 0.026529075478070548, 0.058874692235674174, 0.0363075335377029, 0.04226801584341696, 0.029857070916997533, 0.03178557600559933, 0.051416696714503426, 0.02352274295740894, 0.025797207606956363, 0.10793682493801628, 0.009931164061916726, 0.05560962583071419, 0.036725585748042376, 0.02928474698481815, 0.007000264279278261, 0.040996302118791, 0.07463644325201, 0.11778327051017966, 0.20321338064968586, 0.17198114655911922, 0.16984779174838746, 0.19896007888019085, 0.3017168385641915, 0.0627428778846349, 0.11005065829626151, 0.1274696293153933, 0.11886847870690481, 0.1892049844775881, 0.10011099558323622, 0.10363323015293904, 0.10354397565658603, 0.14140091676797184, 0.29128105140158106, 0.13416188449731895, 0.13666213676333427, 0.13939978129097394, 0.11768747493624687, 0.2249297175024237, 0.11003363385264363, 0.15705062129667827, 0.11694506263094288, 0.3152757052864347, 0.16405592539480754, 0.3104260798011507, 6.466238098485129, 59.47280706678118, 87.49766431535993, 79.14289324624198, 68.06692968096051, 59.22025394439697, 45.85572052001953, 30.795291628156388, 32.363541739327566, 67.33399200439453, 64.96362100328717, 74.19685282026018, 53.99329090118408, 40.34403419494629, 24.67482672418867, 5.898198110716684, 0.9777256441967828, 0.10841095128229686, 0.15983189562601702, 1.9390057708535875, 4.829602079732077, 15.57157485825675, 14.451141357421875, 16.56688346181597, 13.99673090662275, 11.663564034870692, 21.910364321299962, 23.571819305419922, 23.288714953831263, 26.879399810518535, 40.00255107879639, 24.285077946526663, 24.60292329107012, 22.580043860844203, 15.530959163393293, 25.86246841294425, 30.272307668413433, 33.495413712092805, 44.37209946768624, 54.743706771305625, 64.97212559836251, 66.03227479117257, 64.72041320800781, 64.27727099827358, 65.59497601645333, 56.567883355276926, 55.16263798304966, 58.64967482430594, 61.74049758911133, 60.38916328975132, 64.02901881081718, 63.41273444039481, 62.3571571622576, 62.51495770045689, 61.463181086948936, 65.87043734959194, 67.80832467760358, 50.81895773751395, 34.762706075395855, 52.02179513658796, 45.813489368983674, 49.872331687382285, 47.16085624694824, 54.65447800500052, 60.43950298854283, 59.94954381670271, 57.75226286479405, 62.348972184317454, 58.85980919429234, 57.53208487374442, 58.45718887874058, 57.71781022208077, 62.560523986816406, 62.584696769714355, 61.897137778145925, 60.174366678510395, 60.42964349474226, 57.954507555280415, 58.00209576742989, 48.630045890808105, 40.84678152629307, 34.86234324319022, 31.74921328680856, 28.70405408314296, 22.88273171016148, 25.450320380074636, 55.826993465423584, 27.095744132995605, 22.005511215754918, 20.581707205091202, 19.400822639465332, 18.136458941868373, 20.47638988494873, 15.439357587269374, 18.152087177549088, 17.86895850726536, 11.04514309338161, 7.8875385863440375, 2.3755185306072235, 0.19195571116038732, 0.20950452664068767, 0.30397551879286766, 0.8737786390951702, 5.702610228742872, 26.692656551088604, 40.371083532060894, 44.58330386025565, 43.02187688010079, 44.05597727639334, 28.901011194501603, 33.654054982321604, 48.96814523424421, 55.45976379939488, 61.87013013022286, 70.94407449449811, 70.84287398202079, 36.251882212502615, 6.242580796991076, 0.20840770192444324, 0.2023902362478631, 0.12783715102289403, 0.11621718454573836, 0.1850715662751879, 0.12438829323010785, 0.1331972519734076, 0.19232826759772642, 0.07828822372747318, 0.13901586617742265, 0.1119668615449752, 0.07353094007287707, 0.08514475902276379, 0.11890989648444311, 0.11135596968233585, 0.12838440308613436, 0.23905076405831746, 0.12476441876164504, 0.2025072563971792, 0.076017533428967, 0.16075942585510866, 0.0695010188168713, 0.1443170431469168, 0.1423877238162926, 0.2052269061761243, 0.18218121065625123, 0.0819993828024183, 0.14235025511256286, 0.09350681424673114, 0.10992668316300426], [0.02390380822388189, 0.12091348825820855, 0.07170851714909077, 0.02369698735752276, 0.03352723969146609, 0.0927807003525751, 0.04927305870556405, 0.013497461847561811, 0.014435866448496069, 0.09929272306284734, 0.031083193873720508, 0.06330196359860045, 0.018851768957184892, 0.030480227300098965, 0.045137136708945036, 0.03458744726542916, 0.02615487020063613, 0.025888691090845635, 0.030388967732765844, 0.03029092281524624, 0.06934028065630368, 0.03570370861728277, 0.055308017014924965, 0.02799184600423489, 0.020133034758535878, 0.09378392116299697, 0.03340068273246288, 0.06197075253086431, 19.687015465327672, 51.929922580718994, 68.43319702148438, 52.91426692690168, 47.32900612694876, 33.45427690233503, 27.500747680664062, 22.74305554798671, 54.5973916053772, 62.07402501787458, 70.67834063938686, 48.58663354601179, 23.07380369731358, 27.125954900469097, 5.065731831959315, 0.8172028777854783, 0.09001701365091971, 0.12903171192322457, 0.4509896572147097, 0.5535747611096927, 6.132869609764644, 4.610244410378592, 4.689491655145373, 12.752819231578282, 11.406496320452009, 10.759565183094569, 8.949900780405317, 12.046395012310573, 13.857637524604797, 13.269742625100271, 7.251024969986506, 26.39820752825056, 26.37370991706848, 32.76365722928728, 33.29660837990897, 37.631544317517964, 46.10250663757324, 52.24801458631243, 56.0853066444397, 60.87857355390276, 59.32224655151367, 56.23146200180054, 55.50304760251726, 55.07956532069615, 53.40457350867135, 52.24701751981463, 50.85789196831839, 55.05134521211897, 62.87264401572091, 59.68080833980015, 58.2568028313773, 61.316025188991, 58.54868275778634, 59.15230751037598, 59.48106152670724, 59.47448853084019, 65.85096849714006, 55.83423696245466, 25.060583761760167, 42.40152781350272, 40.21214696339199, 33.16209472928728, 42.296901839120046, 50.06240660803658, 57.441480364118306, 63.64374119894845, 60.39481217520577, 58.31041513170515, 55.84597594397408, 52.1486553464617, 47.27718298775809, 51.502399921417236, 54.48516430173601, 54.82993738991873, 56.111424922943115, 57.815741607121055, 55.83709962027413, 57.409542969294954, 58.62435558864048, 53.23956421443394, 46.12667942047119, 42.74946233204433, 39.456943784441265, 35.533771991729736, 28.693605729511805, 22.290755612509592, 25.55719930785043, 21.299669776644024, 20.16625009264265, 13.13076823098319, 9.971591694014412, 8.587257793971471, 13.91470742225647, 8.716302343777247, 2.8323476059096198, 2.879948194537844, 4.521593647343772, 4.8890456557273865, 1.685370032276426, 0.8936768685068402, 0.08632281795144081, 0.08226355684122869, 0.031881514071886025, 0.3848570015813623, 3.8484812634331838, 26.027943236487253, 41.24246406555176, 37.6699400629316, 34.43937512806484, 21.612402984074183, 12.658982941082545, 18.436897311891826, 32.38650900976998, 36.03532770701817, 51.17864165987287, 50.8741820199149, 42.15809767586844, 13.515819157872881, 0.2010140043816396, 0.16185687482357025, 0.0577157408531223, 0.03818646485784224, 0.015563946184036987, 0.006650690671189555, 0.03259666284014072, 0.03555349792752947, 0.04079701977648905, 0.03133462502488068, 0.033338298222848346, 0.07194792465972048, 0.012726661333415126, 0.07662064928029265, 0.02706172377137201, 0.022714307498452917, 0.05746007564344576, 0.10880289346511875, 0.008887519527758871, 0.01832213675204132, 0.038441203867218325, 0.03351884621328541, 0.029785631357559135, 0.09565301372536592, 0.039059936201998165, 0.07185622743730034, 0.03560739057138562, 0.0161364058232201, 0.055373573675751686, 0.050706908372896056, 0.0228267203949924, 0.0731327078704323, 0.014904106501489878, 0.040910026391169856, 0.0321752688448344, 0.02720053507281201, 0.0676139857886093, 0.03309872107846396, 0.02317357562216265, 0.05253279861062765, 0.055583844892680645, 0.025715159152501395, 0.03257525506030236, 0.04165681864001921, 0.03846238773050053, 0.018643948948010802, 0.02358299177805228, 0.06188599672168493, 0.01840939126642687, 0.03810603470940675, 0.1380710604467562, 0.02337002508076174, 0.009507561435124703, 0.026655111661446945, 0.041550627909600735, 0.013411628864040332, 0.0217183113896421, 0.42411285798464504, 25.775256361280167, 62.04759407043457, 75.11373015812465, 61.34209483010428, 53.91259452274868, 41.50975431714739, 36.33360692432949, 27.74035804612296, 42.23885311399187, 63.18461813245501, 69.64241981506348, 63.86110864366804, 26.992339304515294, 21.45004095349993, 4.96303528547287, 0.882256418466568, 0.031255280532475026, 1.0245584568807056, 1.7110226729086466, 5.420800847666604, 6.397914724690573, 10.255740012441363, 8.06965000288827, 11.241544348852974, 14.30735273020608, 15.482945374080114, 15.07669288771493, 13.99134692123958, 15.512624604361397, 12.362064702170235, 9.185910241944448, 15.342840160642352, 19.500597034181865, 27.377453633717128, 30.52021939413888, 35.09046997342791, 45.6707421030317, 50.75419705254691, 57.51123332977295, 59.84069333757673, 61.279046876089915, 57.99720770972115, 57.99518925803048, 56.005965164729524, 56.61601005281721, 54.21511908939907, 52.72385501861572, 57.4912086214338, 65.5466582434518, 60.83534186226981, 60.2443002973284, 61.601790700639995, 60.031115668160574, 60.18271146501814, 61.065063204084126, 60.94731903076172, 66.93674264635358, 54.51756722586495, 30.73884446280343, 47.671802452632356, 46.302336829049246, 39.35514572688511, 47.69216762270246, 54.87933908190046, 60.68184920719692, 63.180053165980745, 59.17568819863455, 59.890928813389365, 58.016075542994905, 55.37602758407593, 49.92045838492257, 54.35040051596505, 55.50691427503313, 57.859827927180696, 57.91305807658604, 59.09447765350342, 56.91290657860892, 58.819134439740864, 58.90415954589844, 55.236122131347656, 48.40466022491455, 42.569427558353965, 37.078915868486675, 32.6980801309858, 27.267147506986344, 23.34370299748012, 23.861873592649186, 18.718738828386577, 11.721050824437823, 10.579290696552821, 8.800660422870092, 12.938462938581194, 12.661011815071106, 14.37869770186288, 10.046118072101049, 12.844499843461172, 8.326067192213875, 10.06145622049059, 5.900245657988957, 1.343497057046209, 0.7756011358329228, 0.026323162152298858, 0.03365624276921153, 0.4499558684016977, 3.537607567650931, 22.968851157597133, 39.55605288914272, 30.92968021120344, 29.656961304800852, 23.589846406664165, 19.734390020370483, 28.95110944339207, 41.48913901192801, 44.45196206229073, 56.8668087550572, 59.0538306917463, 50.470022678375244, 16.565908976963588, 0.5760383957198688, 0.06760601978749037, 0.04676483365307961, 0.030081839034599916, 0.06079408459897552, 0.042580060527793, 0.015019046940973826, 0.041759216359683445, 0.10763586073049478, 0.03939198749139905, 0.061657079362443516, 0.03190143586003354, 0.02117742907388934, 0.09986770006694964, 0.04830931166985205, 0.029718419071286917, 0.03513350849971175, 0.025855466623657515, 0.05542350706777402, 0.04515495164585965, 0.09555972194565193, 0.01727812071996076, 0.03856879559212497, 0.030157722998410463, 0.04187952061848981, 0.052194029824542146, 0.054152091898556264, 0.03947513856525932, 0.04314843199348875, 0.06718253251165152, 0.09351006442947046, 0.28710341985736576, 0.267369558768613, 0.11979394618953977, 0.15067859393145355, 0.22556337421493872, 0.14727704360016755, 0.10165626409330539, 0.11676978346492563, 0.2653065137565136, 0.12174192523317677, 0.12993755617312022, 0.11469235351043088, 0.07044572955263512, 0.17599671679948056, 0.13116084624614033, 0.13328908490283148, 0.14294770519648278, 0.11040215979197196, 0.19864475008632454, 0.24540073903543608, 0.1517789334590946, 0.1005871778886233, 0.11995098633425576, 0.10536289055432592, 0.23440279918057577, 0.23824395877974375, 0.7481879410999162, 34.11458158493042, 74.38125106266567, 82.84649848937988, 71.53881250108991, 62.48774855477469, 49.28513247626168, 39.070238317762104, 33.80646024431501, 68.73570074353898, 70.50033473968506, 75.14947169167655, 57.070189476013184, 31.474516255514963, 32.77269683565412, 6.705648268972125, 1.273292024220739, 0.16694059489028795, 0.964417998279844, 1.544974188719477, 5.284076367105756, 13.81197656903948, 17.91625315802438, 13.913633057049342, 24.305514335632324, 23.478899308613368, 20.644199303218297, 19.572170427867345, 21.095146077019827, 23.81707160813468, 25.94459090914045, 18.709367445537023, 34.697862012045725, 30.73125355584281, 36.8772166115897, 35.69599158423287, 39.10048035212925, 49.01366983141218, 54.931203910282676, 59.0388434273856, 63.78185054234096, 63.05345698765346, 62.17235592433384, 60.00637313297817, 60.838211468287874, 57.59463255746024, 57.62699726649693, 55.792443547930034, 61.14165319715227, 68.5141157422747, 63.302105222429546, 61.66563074929373, 64.14345564161027, 61.824265071323936, 61.61521462031773, 62.98662921360561, 62.643992696489605, 67.91971124921525, 59.47357831682478, 36.06169959477016, 53.581985337393625, 49.89084168842861, 43.43710470199585, 51.03568594796317, 56.099324635096956, 59.15771320887974, 65.94597816467285, 61.25074686322893, 61.725635392325266, 60.62861210959298, 56.727705819266184, 50.75449235098702, 55.842703342437744, 57.51438781193325, 59.611757142203196, 61.75517218453543, 62.07656111036028, 58.774860518319265, 62.00367450714111, 62.26314803532192, 57.58795533861433, 51.31411416190011, 44.958141803741455, 42.732150895254954, 39.45393868855068, 34.52674177714756, 28.937999929700577, 33.535692419324604, 28.789525611060007, 26.1980334009443, 21.220496790749685, 22.09758700643267, 23.542992966515676, 26.268943241664342, 21.61457429613386, 12.938645328794207, 12.910162057195391, 11.14460916178567, 15.019919157028198, 5.5480970570019315, 2.307434218270438, 1.0596618418182646, 0.13698649007294858, 0.13161218059914453, 0.6177235160555158, 4.4621396490505765, 31.154190404074534, 52.80615643092564, 49.44789750235421, 45.35386255809239, 31.07468216759818, 21.589656318937028, 27.671136617660522, 44.330764634268625, 50.61020258494786, 65.29335471561977, 67.12280150822231, 58.82028784070696, 21.617633240563528, 1.579868910568101, 0.28096778052193777, 0.12146981911999838, 0.25514298198478563, 0.13022848484771593, 0.16310528426298074, 0.12124719178037983, 0.09730688176516976, 0.1507796956492322, 0.21453401818871498, 0.1255590511219842, 0.14392609841057233, 0.09455819747277669, 0.1384620051831007, 0.13368655714605535, 0.1313771903514862, 0.11613586890910353, 0.1631672480808837, 0.1144678805555616, 0.1190608162432909, 0.16394315287470818, 0.25304085335561205, 0.1063286562317184, 0.23715529005442346, 0.11392874377114431, 0.2261991072446108, 0.1173150542059115, 0.17682995780238084, 0.1369257883301803, 0.1035926401881235], [0.03477085188829473, 0.0533913964671748, 0.052974490981016836, 0.021779535604374747, 0.025251283776015043, 0.07623515318014792, 0.04076420243031212, 0.052415978629142046, 0.022303274732881358, 0.009676910205078977, 0.11457759966807705, 0.048998720212174315, 0.03749251352357013, 0.014222224608861973, 0.05919531360268593, 0.021000740251370838, 0.03495026672525065, 0.03442829687680517, 0.05890989463244166, 0.06988129698272262, 0.05979526748082467, 0.013989671150089374, 0.016269720991009047, 0.04366237816533872, 0.04755668741251741, 0.039012774625527005, 0.023983480109434043, 3.8029345188822066, 37.51987634386335, 60.0573798588344, 56.434033257620676, 55.13327489580427, 39.28873831885201, 32.63923931121826, 18.72317177908761, 45.7877254486084, 69.94721644265312, 63.56752640860421, 51.53510856628418, 19.758359568459646, 29.789616312299454, 7.359984448977879, 1.233848512172699, 0.038433064839669635, 0.03704016815338816, 0.21025371072547777, 0.7629692565117563, 5.538258842059544, 5.113485498087747, 5.447819786412375, 6.0195201720510205, 10.931306413241796, 12.179799556732178, 15.890427691595894, 10.727765883718218, 7.313405462673732, 20.44935097013201, 11.594648327146258, 6.225611993244716, 24.338007586342947, 37.12982531956264, 47.574190684727256, 54.08692829949515, 52.99612365450178, 57.56539453778948, 54.9376448903765, 55.38763802392142, 55.26535667691912, 59.10315595354353, 56.479179177965435, 54.55594907488142, 50.42169795717512, 50.212664876665386, 50.61338138580322, 52.62912327902657, 54.96586847305298, 61.346541677202495, 58.57232052939278, 60.80836200714111, 59.27059364318848, 58.17967087881905, 58.65010561261858, 60.776233536856516, 64.28248909541539, 64.38822678157261, 59.73430252075195, 34.02343511581421, 37.39636516571045, 39.012252126421245, 37.70592825753348, 46.266098499298096, 53.451050009046284, 58.69663769858224, 56.4841262953622, 58.976128986903596, 57.117878437042236, 53.509737968444824, 47.95126594815935, 44.79741607393537, 46.37383031845093, 51.133777141571045, 52.65184736251831, 49.17431913103376, 53.45144258226667, 52.029368673052105, 55.03678526197161, 55.701255389622276, 53.99140099116734, 53.763110978262766, 50.96099976130894, 48.37685006005423, 49.26428440638951, 41.91278805051531, 37.597345284053254, 27.492001635687693, 29.676235607692174, 26.665049621037074, 19.23591583115714, 15.557530811854772, 20.073238032204763, 9.406076073646545, 8.658734781401497, 9.152267064367022, 7.583814586911883, 8.265782884189061, 5.793475295816149, 4.857741849763053, 1.5308729282447269, 0.36549511338983265, 0.16966214456728526, 0.08061478459941489, 0.0516195786850793, 0.348342128098011, 4.858794501849583, 24.232657262257167, 47.507536615644185, 43.810268129621235, 39.99517904009138, 28.36037186213902, 17.74845242500305, 22.019624744142803, 32.16312442507063, 49.4754992212568, 51.736988476344514, 51.886600562504356, 21.46773280416216, 6.665612314428602, 0.3139369828360421, 0.056764180306345224, 0.042429642884859016, 0.01094070288153099, 0.005457213306466916, 0.05448591077168073, 0.026826129627547095, 0.003227370179956779, 0.05901031102985144, 0.03646735228332026, 0.07092780154198408, 0.012827718098248755, 0.02334701595827937, 0.059401913945163996, 0.036729643387453895, 0.033224555397672315, 0.056705215613224676, 0.003023870742513931, 0.02475149693366672, 0.013300631561183503, 0.0437629438404526, 0.03464638820982405, 0.036158296545701366, 0.07680474940155234, 0.029396382958761284, 0.02079825013476823, 0.029183190648577044, 0.03552214621699282, 0.007998960109294524, 0.06611690005021435, 0.03671647302274193, 0.024322359157460074, 0.025428902191509093, 0.030892579816281796, 0.07592698971607856, 0.10079947792525802, 0.0687767912500671, 0.02216999518818089, 0.0348261898117406, 0.015996568237564394, 0.06500147668910877, 0.04697548145694392, 0.03924629584486995, 0.022368600691801736, 0.015831385672624623, 0.08217555084930998, 0.02441845159046352, 0.06510639855904238, 0.061954060569405556, 0.027508518725101436, 0.07168882606284958, 0.014730842584478003, 0.07613660275403943, 0.03613717375057084, 0.030978197364934852, 0.06204805124018874, 4.898631998470851, 48.272554125104634, 68.55435970851353, 65.41521222250802, 63.01268495832171, 51.6433093888419, 41.402988297598704, 25.651062522615703, 33.70481504712786, 62.664746965680806, 63.567248480660574, 61.97590255737305, 26.110623325620377, 22.091880798339844, 8.150566986628942, 1.03039342377867, 0.09548441812928234, 0.1635799737913268, 0.62477338633367, 4.233864835330418, 10.015375767435346, 12.147069198744637, 10.642918825149536, 10.997487136295863, 10.130809664726257, 11.10480901173183, 14.249171989304678, 16.05925154685974, 11.431297915322439, 9.690444997378759, 12.61369458266667, 10.853435346058436, 20.407234464372905, 34.068733896527974, 43.11944695881435, 50.19418961661202, 51.88602038792202, 56.34789991378784, 54.4372147832598, 55.12608003616333, 57.69853591918945, 61.52675015585763, 58.63342298780169, 57.55380841663906, 52.31096526554653, 53.104904651641846, 52.98893574305943, 56.27233130591256, 56.9933945110866, 61.47864082881382, 58.663974217006135, 60.071026120867046, 60.73897034781319, 59.66789858681815, 59.39306953975132, 60.809973989214214, 64.14026641845703, 63.40443134307861, 59.74109091077532, 38.201518944331575, 42.35417584010533, 45.2853741645813, 41.810197898319785, 50.18480607441494, 56.844345229012625, 58.72074794769287, 56.43681601115635, 58.318669591631206, 57.56557171685355, 56.00072274889265, 49.83620800290789, 47.06433882032122, 49.044054303850444, 52.93637262071882, 55.12344319479806, 51.99391548974173, 53.76403161457607, 54.56135824748448, 56.556870460510254, 56.938184125082834, 57.17952285494123, 56.222790649959016, 52.38992806843349, 49.65909147262573, 46.440724100385395, 41.18108715329851, 35.45067848478045, 28.57053576196943, 27.279690742492676, 20.61795595714024, 16.199099676949636, 13.412510735648018, 15.82973517690386, 11.913237128938947, 10.413786343165807, 9.054512858390808, 10.62529558794839, 7.800861545971461, 12.120755502155848, 10.027465632983617, 4.4630589825766425, 1.1839063806193215, 0.2941459890987192, 0.12735915024365696, 0.09891310307596411, 0.30585066388760296, 4.822588741779327, 22.496759278433665, 45.49587331499372, 39.49595444543021, 29.22673579624721, 25.810462883540563, 22.173687151500157, 30.478460720607213, 39.82170336587088, 56.457004002162385, 57.683830056871685, 61.822729519435335, 29.125432797840663, 7.692130054746356, 0.3565871428166117, 0.037269285680460076, 0.026540678426889435, 0.03433614503592253, 0.008099499491176434, 0.028969916914190565, 0.0263288397940674, 0.03780547083754625, 0.04351602155449135, 0.02254159828381879, 0.037063533506755314, 0.018270752991416624, 0.0376534314959177, 0.026779130899480412, 0.013338361500895448, 0.03216172189318708, 0.03512162056618503, 0.010632355364837816, 0.0478216112325234, 0.019694735063239932, 0.0724385529756546, 0.04891506362972515, 0.059804224143070836, 0.05633252007620675, 0.02259930599081729, 0.01836888611848865, 0.017981250936697637, 0.02936289386291589, 0.04494396796716111, 0.13183285375790937, 0.18080326888178075, 0.10802303959748574, 0.10556463937142066, 0.10118467546999454, 0.1715577949902841, 0.29836126576576916, 0.17259979407702172, 0.1201056923185076, 0.09096274897456169, 0.19706235214003495, 0.11121594041053738, 0.11771882325410843, 0.11140426101961307, 0.16769754141569138, 0.0671727005392313, 0.22431545332074165, 0.20116575195321015, 0.14189836436084338, 0.14770152153713362, 0.14440772256680898, 0.21238257363438606, 0.09895466334585633, 0.11526970538709845, 0.12805177164929255, 0.14698093091802938, 0.306352861225605, 8.770733663014003, 61.44579669407436, 78.83027989523751, 72.89656693594796, 70.37998499189104, 55.63474375861031, 45.507150241306846, 28.04750837598528, 59.189237185886924, 77.83700711386544, 68.7783487864903, 62.963734899248394, 29.70413609913417, 38.422982352120535, 9.361502511160714, 2.16192004936082, 0.1948335681642805, 0.15631586286638463, 0.5821931426014219, 4.4034104347229, 10.959215589932032, 17.42000412940979, 13.797030993870326, 20.013216018676758, 20.905534948621476, 19.250946521759033, 26.564542191369192, 21.615967409951345, 17.802287067685807, 29.266274520329066, 18.533862897327968, 11.185155374663216, 28.562461955206736, 40.34372500010899, 51.38797351292202, 54.86499105181013, 54.46698086602347, 58.92149530138288, 55.339445318494526, 56.15271806716919, 58.741870471409385, 64.41012750353131, 60.80412360600063, 59.22493008204869, 55.81443807056972, 55.37101098469326, 55.35036441258022, 58.26559577669416, 59.37477493286133, 63.267134938921245, 60.015475273132324, 64.12839889526367, 62.688162394932334, 61.449256896972656, 62.19971098218645, 63.23605564662388, 65.37501689365932, 64.80404867444719, 61.104626246861045, 42.202041557856965, 45.84752859388079, 47.612221649714876, 46.392222200121196, 54.55462196895054, 57.33536747523716, 57.80438477652413, 58.192323548453196, 59.047250747680664, 60.694793701171875, 58.060384205409456, 51.10766233716692, 48.5921573638916, 50.97824171611241, 54.29866770335606, 56.42128331320626, 53.73465463093349, 57.00118344170706, 55.802504539489746, 58.58389622824532, 58.71540478297642, 59.84748867579869, 57.028239727020264, 55.4882618359157, 51.054748330797466, 51.2590913772583, 44.784186703818186, 41.56210551943098, 29.730386393410818, 37.293750694819856, 31.721809591565812, 24.903960943222046, 21.52285460063389, 26.833630289350236, 17.266768557684763, 18.21193896021162, 17.392063685825892, 15.468135288783483, 17.561297484806605, 15.528011390141078, 13.403104611805507, 3.310260989836284, 1.0563566706010272, 0.40931930180106846, 0.3342230085815702, 0.18798278006059782, 0.8480019079787391, 5.891288995742798, 29.885807173592703, 60.069483620779856, 60.25830091748919, 50.903489521571565, 38.42588669913155, 26.065303700310842, 33.91486256463187, 45.28701741354806, 64.49092115674699, 65.87631552559989, 70.38999734606061, 39.542670658656526, 11.51356371811458, 0.46540597506931847, 0.1809472811541387, 0.14206841880721705, 0.09741040585296494, 0.06439023198825972, 0.2089703567326069, 0.17624537274241447, 0.11396778667611734, 0.18554103108389036, 0.09079665717269693, 0.13432048527257784, 0.13707676237182959, 0.19191501262996877, 0.11136546238724675, 0.11994645372033119, 0.14222172700933047, 0.14521895189370426, 0.09483145709548678, 0.12599047725754126, 0.11360591037997178, 0.08890284557959863, 0.12045948047723089, 0.08320870862475463, 0.17122455287192548, 0.09592153717364583, 0.1474060873900141, 0.1432019251265696, 0.1656257025897503, 0.10995993137891803], [0.06270390283316374, 0.09673024235027176, 0.05994599724986723, 0.04740974386887891, 0.05447699821421078, 0.02219557765472148, 0.0387916332775993, 0.055448080213474374, 0.05754564569464751, 0.0826354076021484, 0.09477224134440933, 0.031677434487002235, 0.04293586054284658, 0.026035615974771123, 0.018392731535381505, 0.024887407497902, 0.009686616648520743, 0.031772246185157976, 0.06216908831681524, 0.027163358139140264, 0.03682614463780608, 0.02717846063231783, 0.042429642884859016, 0.04617496280531798, 0.057482311236006875, 0.035391063429415226, 0.07546064616846186, 18.72991326877049, 54.03773157937186, 57.59291982650757, 51.259883471897666, 47.455192361559185, 33.49969727652413, 20.00873269353594, 27.71001352582659, 48.314385754721506, 62.902785301208496, 66.8873062133789, 34.30299588612148, 32.918629850660054, 11.756389362471444, 1.6605874363865172, 0.05637485048334513, 0.05695462133735418, 0.08615416807255574, 1.7340207759823119, 5.901253581047058, 9.38981989451817, 6.9092565434319635, 8.134091939244952, 9.225816352026802, 5.646962974752698, 10.440315433910914, 13.635544436318533, 17.56054186820984, 17.865743228367396, 24.44039797782898, 35.60102360589163, 38.09610434940883, 44.089766366141184, 53.44297967638288, 55.77125154222761, 60.62146241324288, 55.10431480407715, 60.588819776262554, 55.95060191835676, 56.181535720825195, 55.858232566288535, 55.525104658944265, 52.07285744803292, 50.63617147718157, 45.39603117534092, 49.209994656699045, 52.86880138942173, 54.5908568246024, 56.50873681477138, 60.942246845790315, 56.895556926727295, 57.21110936573574, 57.277263164520264, 56.04262038639614, 55.74602263314383, 58.77620846884591, 60.10688577379499, 61.17620658874512, 59.99908447265625, 35.70649378640311, 37.35479061944144, 46.554250717163086, 39.403453077588765, 52.42602743421282, 53.53411224910191, 57.31166022164481, 54.37584481920515, 59.317368916102815, 55.12366206305367, 54.912235328129356, 43.602593421936035, 44.27814940043858, 46.891478061676025, 51.01758936473301, 47.383719716753276, 50.28122622626168, 50.11025537763323, 50.31853110449654, 49.945058482033865, 56.24381937299456, 53.67389958245413, 54.03112036841256, 54.456165994916645, 54.8574800491333, 51.70422077178955, 52.52550131934029, 47.46350588117327, 49.54864290782383, 43.01837846211025, 30.60440376826695, 24.59944919177464, 21.458738361086162, 18.665454830442155, 15.101593494415283, 10.52334293297359, 11.19648093836648, 15.085468462535314, 6.246243800435748, 10.420345442635671, 7.272369836057935, 2.3664218187332153, 0.7542773314884731, 0.1258903390594891, 0.1300614159554243, 0.09626077075621911, 0.0942515946392502, 0.6524367162159511, 5.9666548030717035, 23.275654077529907, 34.95588336672102, 52.76209095546177, 24.5047504561288, 13.528141788073949, 20.53073695727757, 31.020315987723215, 37.818593297685894, 40.04110663277762, 50.79247120448521, 45.8708085332598, 21.80394571168082, 2.166335629565375, 0.09107645108763661, 0.047629935267780504, 0.039825544226914644, 0.08406989848507301, 0.02969263813325337, 0.023168160912713835, 0.04117165592366031, 0.016663244160424386, 0.03994021325239113, 0.052634989377111197, 0.03018905096022146, 0.06626019986080271, 0.024314995356170193, 0.07398788591048547, 0.022870270468826805, 0.06627312595290796, 0.02283516476329948, 0.057145126829189916, 0.03372226422652602, 0.026124073192477226, 0.057125008265886984, 0.018418239363070046, 0.03701620229652949, 0.026388177681448202, 0.03657701372035912, 0.03757332704429116, 0.019827911131350056, 0.051875304962907515, 0.024545032298192382, 0.07429579831659794, 0.09784451898719583, 0.03960886424673455, 0.024460037305418934, 0.022196364755343114, 0.037201167549937963, 0.09575670744691576, 0.03308139468676277, 0.027568241681105325, 0.022878136386030486, 0.015412393691284316, 0.017868556448125412, 0.018886530306190252, 0.013433984048398477, 0.0598905405827931, 0.03635884774848819, 0.04579730039196355, 0.0396772639692894, 0.027963897146816765, 0.01783076374392424, 0.061011799345059056, 0.05803091358393431, 0.05208076536655426, 0.04071103921160102, 0.08040386198886804, 0.09053274097719363, 22.785885981151036, 62.46782806941441, 66.90395409720284, 60.05478123256138, 55.15460933957781, 42.82784496034895, 31.20337322780064, 31.71754687173026, 47.29209382193429, 63.19846589224679, 70.28883852277482, 36.89656387056623, 24.344855036054337, 12.854042325701032, 1.425264326589448, 0.11810613104275294, 0.09812005848756858, 1.0666416329996926, 2.2788756021431515, 7.7048782621111185, 12.380302854946681, 12.099197847502571, 13.599142823900495, 11.809515288897924, 11.346813900130135, 10.607654111725942, 16.720746108463832, 15.904998064041138, 15.498714310782296, 17.157296214784893, 26.029695919581822, 37.1914176259722, 42.765422344207764, 53.40805803026472, 55.377858434404644, 58.9389283316476, 55.148456709725515, 58.540852137974326, 55.722909450531006, 54.63422053200858, 56.79306404931204, 58.35585635049002, 55.39033392497471, 51.287426131112234, 47.10599327087402, 49.99616595676967, 55.32084846496582, 57.49825062070574, 57.48724120003836, 60.2620529447283, 57.85942840576172, 59.23615837097168, 60.026210239955354, 58.000796454293386, 57.866147313799175, 61.62289932795933, 60.89136518750872, 61.998025621686665, 60.87074293409075, 40.42497028623308, 42.6609457560948, 48.75424494062151, 44.762626443590435, 56.353545325142996, 55.72920799255371, 57.391665254320415, 53.687879358019146, 60.452357155936106, 57.055518354688374, 58.04353134972708, 45.82094131197248, 46.05159371239798, 48.52559362139021, 51.490796429770334, 50.13097490583147, 53.463407380240305, 52.33298063278198, 51.948126861027305, 52.2295115334647, 57.11186129706246, 55.34486838749477, 56.33518123626709, 55.52076203482491, 54.25938606262207, 52.39277335575649, 51.33991282326834, 49.39766550064087, 47.89434977940151, 40.93447126661028, 32.0758307320731, 24.468569449016027, 17.30512261390686, 11.950552429471697, 11.92094268117632, 12.956325888633728, 6.953148748193469, 11.36221979345594, 12.37246789251055, 15.171681710651942, 11.195415258407593, 7.079748400620051, 3.436565560953958, 0.8643660555992807, 0.2506093366869858, 0.05892867648175784, 0.041311434137501886, 0.3236506458904062, 6.776026572499957, 26.72588631084987, 41.55775942121233, 42.24756268092564, 31.099504607064382, 19.967378752572195, 22.446421316691808, 34.69617707388741, 44.81394236428397, 48.05179248537336, 58.235635144369944, 53.09514938082014, 25.13581017085484, 3.129231103828975, 0.04960992080824716, 0.04333068989217281, 0.04258326321308102, 0.056504331928278716, 0.03285753241341029, 0.04475196969828435, 0.04994476766192487, 0.017315653884517293, 0.0492064672788339, 0.041207770950027874, 0.036350233746426444, 0.008727465839391308, 0.03407687680529697, 0.054786902120602984, 0.047310226530368836, 0.08898331983281033, 0.04266115224787167, 0.05562655527942947, 0.04144789431510227, 0.036029568274638483, 0.027635060417066728, 0.027403523912653327, 0.022603429787393128, 0.03137664669858558, 0.01783385786360928, 0.032265283300408294, 0.030085866139935594, 0.04755444824695587, 0.17548679773296627, 0.1883441542408296, 0.20900797471404076, 0.12903985434344836, 0.1837792827614716, 0.1153570328439985, 0.15219510612743242, 0.1260895026581628, 0.07238984094666583, 0.13746255024203233, 0.2262396700680256, 0.109303496245827, 0.06979818322828837, 0.1193393955805472, 0.10944273163165365, 0.13408857557390416, 0.1630101536533662, 0.09409990813583136, 0.16141497210732528, 0.18817389623395034, 0.07497718996767487, 0.2203515331659998, 0.11556860006281308, 0.16558310416127953, 0.08579869714698621, 0.20685024692543916, 0.17177575400897435, 29.772683552333287, 74.06130041394914, 74.26335402897426, 67.27070086342948, 61.68981048039028, 46.593386445726665, 30.109403678349086, 39.99445990153721, 60.5944756099156, 71.54269654410226, 73.99533421652657, 45.91721555164882, 42.67766659600394, 14.402721098491124, 2.252939062459128, 0.2960214598902634, 0.3334649492587362, 0.8620426431298256, 3.511389408792768, 14.100484013557434, 17.08205590929304, 14.343174168041774, 21.909999540873937, 18.892756462097168, 19.44748674120222, 20.707579033715383, 20.926815543855938, 22.72657094682966, 25.898632049560547, 30.552535465785436, 43.82084328787667, 44.21230479649135, 47.00178418840681, 59.01443440573556, 56.90672615596226, 60.88905143737793, 53.977386474609375, 59.43699605124337, 55.701453413282124, 57.566454138074604, 58.771164076668875, 61.27273791176932, 57.72789205823626, 54.17009823662894, 49.17653908048357, 54.6312849181039, 57.29056896482195, 59.61976146697998, 60.52019936697823, 61.51125567299979, 59.412461962018696, 62.72022138323103, 61.42521612984793, 62.4140351159232, 59.28988879067557, 64.05491474696568, 61.566959381103516, 63.75447463989258, 60.697288104466026, 43.21213592801775, 45.61020939690726, 53.2552740914481, 48.91868100847517, 58.00865486689976, 56.59948376246861, 56.63534688949585, 56.65602125440325, 60.77783162253243, 59.51250212533133, 59.56919942583357, 47.113379205976216, 48.52195276532854, 50.646090030670166, 54.310910429273335, 52.311270986284526, 55.85416439601353, 54.22073323386056, 55.37367214475359, 55.49353551864624, 60.87743404933384, 57.88202394757952, 59.202598571777344, 59.18114253452846, 55.49827766418457, 52.49840334483555, 54.97987256731306, 50.74531378064837, 52.6059684072222, 45.476915155138286, 36.80188076836722, 28.50750344140189, 26.528814554214478, 22.669913598469325, 21.44522932597569, 16.88783117703029, 19.76858036858695, 33.12159367970058, 12.682293278830391, 19.31164424760001, 20.114668403353008, 9.058409060750689, 2.75255058492933, 0.5198728495410511, 0.24008615421397345, 0.19517466771815503, 0.14751747569867543, 1.0416442943470818, 7.771615709577288, 30.459957667759486, 48.46443557739258, 65.95151587894985, 34.81905596596854, 20.622550453458512, 29.81547055925642, 42.39764724458967, 51.39126695905413, 56.876074177878245, 65.49932016645158, 64.24552467891148, 31.762084824698313, 4.429218215601785, 0.14579610020986625, 0.10396096256694623, 0.20224521974367754, 0.1544057596474886, 0.11315931898674794, 0.12800272713814462, 0.11586320639720984, 0.09505656787327357, 0.1822929246617215, 0.18895961264414446, 0.11379379672663552, 0.11375444169555392, 0.07484437352312462, 0.13050715917987482, 0.24533964374235698, 0.17484836413392, 0.1299344077706337, 0.1662006795938526, 0.11227860767394304, 0.10641784965991974, 0.08383235694574458, 0.09512157831341028, 0.1253331803849765, 0.12122845064316477, 0.14396609126457147, 0.11990574161921229, 0.12446062506309577, 0.13836722741169588], [0.020138768379443457, 0.052079069029007635, 0.019632465904578567, 0.003068360163264775, 0.05955892016312905, 0.0555233738518187, 0.0229413351376674, 0.02660673381095486, 0.011695026869087346, 0.04312463916305985, 0.02433600788936019, 0.0863096679427794, 0.04252494991357837, 0.02905994833313993, 0.0016592856118222699, 0.02733242362072425, 0.11175665139619793, 0.09955495649150439, 0.020439937843808105, 0.03085797792300582, 0.010425434414563435, 0.003272896062948608, 0.03593920437352998, 0.03934993528361831, 0.09699924755841494, 0.008001467296188431, 0.875726251729897, 37.13563401358468, 65.85889639173234, 50.46558277947562, 57.15006249291556, 43.22628246034895, 24.287728684289114, 18.50795132773263, 24.087059497833252, 33.56696973528181, 58.41561780657087, 54.889796120779856, 27.683768442698888, 17.887765543801443, 1.6052135505846568, 0.12997041083872318, 0.08636969115052905, 0.145390281985913, 0.6194147510187966, 1.427937537431717, 3.661900418145316, 14.108007175581795, 13.244085533278328, 13.670308010918752, 8.960722599710737, 8.78288345677512, 14.049110770225525, 19.50067172731672, 31.57218360900879, 31.24686895098005, 29.471857820238384, 40.1169879095895, 48.934866837092805, 50.33691603796822, 57.798482281821116, 55.567509514944895, 57.44091061183384, 57.70448357718331, 54.964854036058696, 53.382106508527485, 52.70099891935076, 55.800812653132844, 54.1203282901219, 52.442890712193076, 45.257682119097026, 42.56946924754551, 49.151039191654746, 54.069741930280415, 54.90798997879028, 57.44264766148159, 58.578761509486604, 56.44905178887503, 55.686240332467214, 55.25596618652344, 53.00765071596418, 54.98507329395839, 56.760720184871126, 62.168242590767996, 59.77517877306257, 59.41216318947928, 39.168055057525635, 33.47275563648769, 47.20383432933262, 47.33227872848511, 52.78915071487427, 52.56451892852783, 54.88312585013253, 51.17191232953753, 59.20007637568882, 55.40977498463222, 53.570142132895334, 43.31904785973685, 42.63259015764509, 47.28400264467512, 49.32723161152431, 47.19302293232509, 48.06488636561802, 45.38123498644148, 46.90244231905256, 46.435387883867534, 49.575494221278596, 51.297125816345215, 53.912670952933176, 53.799151284354075, 54.69506243297032, 54.979156902858186, 50.72290236609322, 51.75000592640468, 51.786209515162874, 50.321800231933594, 44.30282940183367, 41.86784362792969, 33.823382581983296, 31.653696400778635, 21.47378294808524, 18.905487298965454, 8.523134606225149, 8.160265803337097, 7.414298517363412, 14.986295086996895, 11.819401706968035, 7.015878387859889, 3.744843670300075, 0.8989278610263551, 0.049661506433039904, 0.01588135808041053, 0.07809319919241325, 0.020109118095466068, 0.5233058567558015, 9.595168692725045, 32.444241591862266, 42.92184019088745, 36.76343985966274, 30.314403329576763, 50.22612006323678, 73.1247249330793, 58.61406530652727, 31.88562379564558, 37.54316323144095, 53.12732648849487, 35.259655135018484, 5.904763724122729, 0.22326947801879474, 0.07279977787818227, 0.04381914011069706, 0.020412626809307506, 0.05334474718464272, 0.06452883633651904, 0.07055116032383271, 0.007901766753223325, 0.01837360193686826, 0.005683913976619286, 0.06065626735133784, 0.038409529852547815, 0.009263048796648425, 0.04772274189495614, 0.05608723305964044, 0.04359035167310919, 0.020159112555640082, 0.004485908238815942, 0.03525618423840829, 0.027931619235979657, 0.03672467651111739, 0.027727906060005938, 0.042651961491044076, 0.03724095005808132, 0.07926276964800698, 0.042237702291458845, 0.04341404113386359, 0.04154046345502138, 0.024180435076622025, 0.05508095544895955, 0.02945003133001072, 0.05264479760080576, 0.042901893079813035, 0.07586522945868117, 0.0129244237572753, 0.014485643777464117, 0.041153878306171725, 0.06895848935736076, 0.06128087919205427, 0.05923416651785374, 0.003634313287745629, 0.007596176633212183, 0.03071102759401713, 0.028010576963424683, 0.08058619113372904, 0.06799391790160111, 0.027432853588834405, 0.05401177764204996, 0.02900803361886314, 0.010130633849517574, 0.06394399343324558, 0.06580136769584247, 0.06994551353688751, 0.049126881906496625, 1.3736604899168015, 45.343905789511545, 73.2317202431815, 59.26041453225272, 62.83432470049177, 55.097390924181255, 33.84727396283831, 27.2083466393607, 31.0509922845023, 36.00795875276838, 60.74479988643101, 57.31861189433506, 29.96602065222604, 18.763933386121476, 2.6293759601456776, 0.3982001484504768, 0.014125823442425047, 0.6070376208850315, 2.469291853053229, 8.402589440345764, 9.153581142425537, 13.65260660648346, 14.133329016821724, 11.929231882095337, 10.12548039640699, 8.57679033279419, 10.023713605744497, 13.5893588917596, 19.54977117265974, 25.058516672679357, 29.230383600507462, 40.02576501028878, 48.34807062149048, 54.18099301201956, 57.91988468170166, 56.36466939108712, 58.17340707778931, 56.46885415485927, 54.61905608858381, 54.46994774682181, 54.074174880981445, 57.515138217381065, 55.85894823074341, 54.73933288029262, 46.99073655264718, 44.78508302143642, 51.91774933678763, 57.04682615825108, 57.753805364881245, 57.65235819135393, 58.714841978890554, 58.751500674656455, 56.610517501831055, 57.24154247556414, 53.94290951320103, 56.839877537318635, 58.13619947433472, 63.471182686941965, 59.39145755767822, 59.95501899719238, 41.80991302217756, 38.24178722926548, 50.02693952832903, 51.664563928331646, 56.67278725760323, 55.35295956475394, 54.692265783037456, 51.717266014644075, 57.32497297014509, 56.91594294139317, 56.64087070737566, 45.70388501031058, 44.09732600620815, 48.698329312460764, 50.72132512501308, 48.79507950374058, 50.38301733561924, 47.241799286433626, 48.71073532104492, 48.061030115400044, 51.224013396671836, 55.413335936410085, 54.936331680842805, 56.23573166983468, 57.0633350781032, 53.50651053019932, 51.39462293897356, 52.06950841631208, 52.62211602074759, 50.92424726486206, 44.28424644470215, 39.78160531180245, 31.765788214547293, 25.532314334596904, 19.399221079690115, 12.395011322838918, 6.762290852410453, 7.57629576751164, 10.881688458578926, 11.5517657824925, 12.728527460779462, 10.319547057151794, 7.06788044316428, 3.4658220367772237, 0.7514432264225823, 0.1932795736938715, 0.2095976352159466, 0.07366222981363535, 0.6320257857441902, 10.819548113005501, 29.793781757354736, 47.2955436025347, 32.78367846352713, 13.599729946681432, 39.18451533998762, 69.43532875605992, 62.88030787876674, 37.57387774331229, 44.55842930930001, 60.51647513253348, 42.91156727927071, 7.323053904942103, 0.23169482020395143, 0.03581450320780277, 0.06875475921801158, 0.06840555795601436, 0.01590673189743289, 0.03385143693802612, 0.026286215920533453, 0.044184748349445205, 0.017896647797897458, 0.06262094514178378, 0.0159675218497536, 0.004454101061648024, 0.017882878626031534, 0.007477764638939074, 0.020373904512130787, 0.024291440012997816, 0.04396038735285401, 0.009950107063299842, 0.02879199824695076, 0.017828141206077168, 0.06486981375409023, 0.027802775613963604, 0.013678304152563214, 0.04563087610793965, 0.037419710108744245, 0.09916223399341106, 0.06099005908306156, 0.031750115765524764, 0.11132546953324761, 0.15796375301267418, 0.10542543791234493, 0.17454621249011584, 0.17770267597266606, 0.14822518772312573, 0.11491154746285506, 0.13754442227738245, 0.1059932495866503, 0.2204981917249305, 0.2192827590874263, 0.1669484387551035, 0.10597454916153635, 0.10772645194083452, 0.15138775802084378, 0.14408005800630364, 0.16179930791258812, 0.2970923509980951, 0.08347958658954927, 0.11666124500334263, 0.09085893990205866, 0.15332572188760552, 0.20538964601499693, 0.12138018464403492, 0.1795801959399666, 0.18526033471737588, 2.511242253439767, 56.591239724840435, 81.73544679369245, 68.21503053392682, 71.08269800458635, 57.67695134026663, 34.313108989170615, 26.491839715412684, 33.522553375789094, 45.54874563217163, 63.55450548444475, 65.008179800851, 37.256397179194856, 21.818846123559133, 2.639727473258972, 0.6475942560604641, 0.17217395907001837, 0.4902236376489912, 2.381754755973816, 8.546157462256295, 11.031812974384852, 30.415496144975933, 23.67722347804478, 24.82902635846819, 17.37940580504281, 18.009478875568934, 26.22678852081299, 27.415639196123394, 38.781245367867605, 36.23291015625, 34.89586135319301, 42.987142835344585, 52.692602021353586, 54.361691338675364, 59.81839656829834, 56.210877963474815, 58.748999323163716, 58.33080809456961, 54.789877550942556, 54.251242773873464, 53.29860653196062, 60.354109627859934, 58.05141060692923, 56.25034720557076, 49.98703949792044, 47.20411920547485, 55.17117384501866, 59.12013735089983, 59.76382541656494, 59.32115568433489, 59.87149470193045, 59.85538182939802, 59.5478823525565, 59.4278313773019, 56.07452998842512, 58.37900079999651, 60.406186376299175, 64.8903591973441, 62.162552016122, 60.115084648132324, 44.055501324789866, 42.14761631829398, 53.14455802100045, 55.675248282296316, 57.833862509046284, 54.831465993608745, 54.947983809879844, 51.44967699050903, 59.528740065438406, 59.76895318712507, 57.68595273154122, 47.09821823665074, 46.69241912024361, 51.71293033872332, 53.15462943485805, 52.420218740190776, 51.67962762287685, 49.576505184173584, 50.55772284099034, 50.78629078183855, 53.15129777363369, 56.16144153050014, 58.21327584130423, 58.321018082754954, 59.17955139705113, 55.364976474217, 50.93603835787092, 53.78846148082188, 54.65601008278983, 53.20109551293509, 46.65350225993565, 44.4670535496303, 36.77118362699236, 35.33734294346401, 26.238463231495448, 24.646584033966064, 13.167282751628331, 18.533343519483292, 20.182314327784947, 20.430377176829747, 17.231489079339163, 18.77070787974766, 12.655232650893074, 3.3326331036431447, 0.791674870465483, 0.3448660203388759, 0.30668276495167185, 0.15265139378607273, 0.8011145953621183, 12.274344563484192, 41.278452260153635, 55.09165171214512, 46.825292995997835, 38.598723139081685, 60.83653000422886, 78.58517524174282, 67.59867668151855, 43.521386350904194, 53.42216982160296, 68.04981626783098, 50.83778040749686, 10.462360330990382, 0.4116761253348419, 0.11956339356090341, 0.1297288252306836, 0.1472558190247842, 0.12376689086002962, 0.15671727061271667, 0.14965936647994177, 0.09186570266527788, 0.09358538860189063, 0.1273419561662844, 0.16704366435962065, 0.13327258293117794, 0.10681486728468112, 0.09830964795712914, 0.12939590880913393, 0.10965577127145869, 0.10403398650565318, 0.19840733068329947, 0.10701356269419193, 0.13580130652657577, 0.1143165265343019, 0.13011054189077445, 0.1273682290422065, 0.08105413602398974, 0.25774920785001343, 0.1532455054777009, 0.21378060004540853, 0.11608134183500494], [0.030586044836257185, 0.0064072967673252735, 0.015820780170283148, 0.01572995656169951, 0.03259758225509098, 0.062021798720317226, 0.03764789125749043, 0.014159328653477132, 0.041894156618842056, 0.006219319242518395, 0.0493569765239954, 0.0263657894185079, 0.03823712767500963, 0.0252793683404369, 0.026647320383095315, 0.04694635873394353, 0.011808557652070053, 0.011956961742336196, 0.038711698459727426, 0.010366444276379687, 0.010295316843049867, 0.0362432219886354, 0.09451582974621228, 0.07063020286815506, 0.030415142221110206, 0.04448958020657301, 5.143063979489463, 39.708044733319966, 55.73474570683071, 47.35325534003121, 51.921098368508474, 41.961824962071006, 27.471801485334122, 31.171220438820974, 39.49359900610787, 31.489239488329204, 45.18246439525059, 48.83744614464896, 17.36115288734436, 4.192242520196097, 0.27556805312633514, 0.05077990856287735, 0.0668719331068652, 0.49256892608744757, 2.9008040811334337, 7.266974994114467, 7.307183350835528, 8.216427224023, 12.24968888078417, 11.802092007228307, 9.026669689587184, 10.647308349609375, 16.092411824635096, 41.0914762360709, 41.94131735392979, 47.770425183432444, 48.87552922112601, 59.681378092084614, 61.66800703321184, 60.92005429949079, 56.93112128121512, 56.553511006491526, 56.36697966711861, 54.80930471420288, 56.06319052832467, 56.189157894679475, 55.91602073396955, 56.65133816855294, 52.278298309871126, 47.46189737319946, 41.93973663875035, 44.8504238809858, 49.257843426295686, 55.10341501235962, 52.73851919174194, 54.07695416041783, 55.51656184877668, 55.392651149204795, 53.853003297533306, 52.33900472096035, 49.872050285339355, 52.15118101664952, 57.189198221479145, 57.65935502733503, 59.29145213535854, 59.082804679870605, 47.408733231680735, 32.50542742865426, 47.240854331425254, 47.02470282145909, 52.366519587380544, 52.88736697605678, 54.732311725616455, 54.797336442129954, 55.341620104653494, 55.22147880281721, 53.339270864214214, 42.30562877655029, 41.619153703962056, 49.22588518687657, 50.67658914838518, 48.87897205352783, 49.45822599955967, 47.9172579901559, 43.36440222603934, 47.18464340482439, 46.68563767841884, 47.10265118735177, 50.24080855505807, 51.63780641555786, 55.200842653002056, 54.49085487638201, 50.767589705330984, 51.25921991893223, 52.136311871664866, 52.0677296774728, 54.793685163770405, 47.83370590209961, 41.070270333971294, 33.33608457020351, 34.238068444388254, 29.75106770651681, 6.366846723215921, 7.873702117374965, 15.134889262063162, 19.24266426903861, 10.72645354270935, 6.932740586144583, 3.9680714862687245, 3.873829160417829, 0.957624722804342, 0.20179664024284907, 0.15897073969244957, 0.06458947701113564, 0.09133867773094348, 1.9109962795461928, 19.023354802812847, 37.99012695040022, 57.80741419110979, 69.47259889330182, 80.94559642246791, 67.12361444745744, 33.57476214000157, 34.692098481314524, 39.69265794754028, 47.73670904976981, 43.92715072631836, 14.938710348946707, 0.7598236767309052, 0.014487511445102947, 0.011134298252207893, 0.028544275289667503, 0.06341793880398784, 0.029152134100773504, 0.04404050876785602, 0.029183319570230584, 0.007343184003340346, 0.045005996245890856, 0.09003887604922056, 0.026049883869875754, 0.041843961990837536, 0.025631777376734784, 0.01583228982053697, 0.059552413012300215, 0.014105100982955523, 0.018404239489297782, 0.021844900579058697, 0.022331026815144078, 0.01528787742634969, 0.11165723244526557, 0.03526217230994787, 0.009157119302212127, 0.07364311548216002, 0.07927910198590585, 0.018542470643296838, 0.05095718940719962, 0.029922559724322388, 0.02967729645648173, 0.010781178450477975, 0.06744929176888295, 0.01946079315218542, 0.058475978273366175, 0.048413748387247324, 0.06760182644107512, 0.020269525470212102, 0.011029529052653482, 0.07327808399817773, 0.005776748593364443, 0.04549067380971142, 0.014623852879075068, 0.007762231115650917, 0.055690395246659, 0.027731804243688072, 0.0219285876955837, 0.041042883547821214, 0.021732458844780922, 0.0181644112869565, 0.062230312531547885, 0.06827587634325027, 0.07179019919463567, 0.06210603205753224, 0.07171790128839867, 6.711810452597482, 50.4941919871739, 66.39216368538993, 53.66674641200474, 60.144197600228445, 44.907590184892925, 28.21302662576948, 23.251304115567887, 25.962946312768118, 31.507923194340297, 50.79006712777274, 53.52147347586495, 21.383560589381627, 5.811289174216134, 0.19387486603643211, 0.12413424971912589, 0.22343612621937478, 0.9800042190722057, 5.227849372795649, 10.528544528143746, 10.486868364470345, 13.215338230133057, 12.796962874276296, 12.990814140864781, 14.306686571666173, 9.686606986182076, 12.565539223807198, 26.292450734547206, 32.99911430903843, 42.10990497044155, 48.053467001233784, 57.8824199948992, 61.681660243443076, 61.19841997964041, 57.54804836000715, 57.574875354766846, 56.410312107631135, 56.954046862465994, 55.71441527775356, 55.537357807159424, 57.18013082231794, 58.73428998674665, 55.47399718420846, 51.472196102142334, 42.673813819885254, 46.80711998258318, 52.06942851202828, 56.445650645664756, 54.07014145169939, 55.57468352999006, 56.38545145307268, 58.3245130266462, 55.86790098462786, 54.04839359010969, 52.681804520743235, 54.390328339168, 56.9184581892831, 59.512731415884836, 60.53280339922224, 58.57176467350551, 46.995461327689036, 38.15474714551653, 50.01853220803397, 50.66972432817732, 55.274896553584504, 52.72641542979649, 54.2628219468253, 53.5731645992824, 56.13793230056763, 56.65637561253139, 54.99123287200928, 44.80318307876587, 42.50157492501395, 51.22199494498116, 53.00336020333426, 50.6419106892177, 52.15407146726336, 49.2921154158456, 46.222373485565186, 48.85879101072039, 47.712397302900044, 49.281818185533794, 53.003134386880056, 55.41243961879185, 56.110532079424175, 56.18866804667881, 51.46090875353132, 51.540385723114014, 52.06935208184378, 52.73472547531128, 54.09255634035383, 50.68572950363159, 43.58367000307356, 37.6457325390407, 30.841705594744, 22.55641998563494, 11.47730541229248, 12.119374547685895, 12.821443114961896, 15.736924614225115, 14.4658020564488, 11.245910423142568, 11.85335407938276, 4.46219219480242, 2.822617305176599, 1.2754687645605631, 0.2298621785427843, 0.03232028874169503, 0.23060123888509615, 1.6553871440035957, 18.677947691508702, 37.53693069730486, 42.44414111546108, 53.620450564793174, 84.16973427363804, 78.79010541098458, 44.766048431396484, 38.70956775120327, 45.37779910223824, 54.11576679774693, 52.4102133342198, 19.190571887152537, 1.1551432268960136, 0.047491296992770264, 0.034989248562072, 0.038336251463208876, 0.062266152751232894, 0.041886557026633194, 0.05908041048262801, 0.0779252957020487, 0.030952945684215853, 0.03179253438221557, 0.048556210207087655, 0.023800182355833904, 0.04644041248996343, 0.06565086184335606, 0.04330211678253753, 0.05487244503040399, 0.006074688231040324, 0.019239989375429492, 0.020760435378178954, 0.03888130168031369, 0.010749729200532394, 0.05167391237669757, 0.06275255379400083, 0.02459337791827108, 0.010501379446525658, 0.027343444725764648, 0.06589555514178105, 0.0387443902769259, 0.10774004978260823, 0.10028125359011547, 0.09618012008390256, 0.12763033354921, 0.12557639447706087, 0.1545899004808494, 0.17115603440574237, 0.13162797689437866, 0.08885202330670186, 0.20404184476605483, 0.12948372481124742, 0.10014782646404845, 0.09552019728081566, 0.08104485366493464, 0.1499829055475337, 0.0969534803714071, 0.10444796072053057, 0.131648292232837, 0.148743547765272, 0.11626122146844864, 0.11706334485539369, 0.13683424038546427, 0.22768809806023324, 0.15274618512817792, 0.13119019967104706, 0.25425662526062554, 10.965973581586566, 59.73988887241909, 73.26257024492536, 64.10671356746128, 66.03132288796562, 52.8479984828404, 39.24061509541103, 42.55330426352364, 55.96504027502877, 41.93633549554007, 57.41393770490374, 59.313220841544016, 23.817306109837123, 5.899420125143869, 0.6384297449673925, 0.22788661026528903, 0.26552652195096016, 1.3788377663918903, 5.390481948852539, 12.732695511409215, 19.7598933832986, 21.152093512671335, 24.44637516566685, 17.275167192731583, 19.933428117207118, 18.431105988366262, 22.89215346745082, 48.0403105872018, 45.68885605675833, 52.26910236903599, 50.93706669126238, 64.62450722285679, 64.36984879629952, 63.70302322932652, 58.87480340685163, 58.48045144762312, 56.91696432658604, 55.83481018883841, 55.294174330575125, 56.71976750237601, 58.862310545785085, 61.258501052856445, 58.45280456542969, 52.892348834446494, 46.389828545706614, 49.06582995823452, 54.65114981787545, 60.115077699933735, 56.0109817641122, 57.884678159441265, 58.00448247364589, 60.525063105991904, 58.889151436941965, 56.397527422223774, 53.950031416756765, 56.40764399937221, 59.271594183785574, 61.054397719247, 62.39992332458496, 60.501328059605186, 48.44086728777204, 42.023000376565115, 54.66185351780483, 53.36179344994681, 55.249480043138774, 52.77261400222778, 55.23571566173008, 55.62883084160941, 57.888496194567, 58.720921652657644, 56.95762865883963, 46.36042376926967, 45.46858079092843, 53.70224128450666, 54.55584485190255, 53.28570372717721, 54.00453656060355, 52.176409925733296, 48.22782857077462, 52.3992212840489, 50.19613858631679, 52.22602701187134, 55.128056798662456, 58.23723670414516, 58.583625248500276, 56.84639147349766, 52.809283120291575, 51.82228456224714, 53.22165175846645, 53.27916199820382, 57.339578083583284, 50.225998469761436, 45.25010858263288, 38.460078784397666, 37.96872649874006, 35.12501989092146, 12.209371958460126, 16.619959013802664, 27.05851568494524, 31.861162662506104, 19.140999964305333, 14.847433601106916, 14.715522050857544, 7.81050477709089, 2.2496684151036397, 0.8265365883708, 0.39354854662503513, 0.22174874533499989, 0.3005932388561112, 2.783014093126569, 22.844738960266113, 47.959471770695274, 72.29598549434117, 78.62568323952812, 85.47264657701764, 67.3563096182687, 42.24199717385428, 47.297562054225374, 55.056702273232595, 61.368657793317524, 59.58881419045584, 24.90354231425694, 1.667709231376648, 0.13511490050171102, 0.1673820497734206, 0.1748393124767712, 0.21760597692004272, 0.10425660705992154, 0.12788036013288157, 0.19710170717111655, 0.11689916652228151, 0.12994094884821347, 0.09739689622074366, 0.12299973916794572, 0.12856251852852957, 0.1648441795259714, 0.12620884339724267, 0.08813899835305554, 0.0862859734999282, 0.12076974739985806, 0.0731009863583105, 0.10852919279464654, 0.1037595665880612, 0.15477235854736396, 0.13962414568024023, 0.1261515071881669, 0.18106252354170593, 0.13973869596208843, 0.09091569257101842, 0.15367993073804037], [0.04327550124643104, 0.024292902255963002, 0.018520391113790016, 0.02469617427725877, 0.04324878393007176, 0.022236908919044902, 0.020172104804909656, 0.01719573639067156, 0.01705812948888966, 0.03475236180903656, 0.037144445415054045, 0.03244623841185655, 0.017183202152539576, 0.05363825089963419, 0.01474288318838392, 0.004271327476349792, 0.031365172671420236, 0.004266091730512146, 0.019560559852314845, 0.11312087997794151, 0.03271403922034161, 0.02517735229672066, 0.04049871203356555, 0.07788001027490411, 0.06839265221995966, 0.6371251663991383, 16.55470848083496, 58.49432700020926, 53.098901408059255, 55.39375243868147, 40.91689927237374, 46.914056232997346, 37.408204896109446, 63.12417575291225, 67.25886808122907, 46.939222608293804, 51.71161365509033, 27.60099455288478, 6.743720488888877, 0.9512912226574761, 0.050028434422399314, 0.1930619810840913, 0.21120386331209115, 1.2876893430948257, 6.259906998702458, 12.982445904186793, 8.143837656293597, 8.090661355427333, 10.785832847867693, 13.624635764530726, 21.572087798799785, 19.858922583716257, 28.650370563779557, 41.682514326913015, 49.8182121685573, 55.482717173440115, 59.51333590916225, 55.71852513722011, 52.91478456769671, 54.34801033564976, 55.77598326546805, 55.617512226104736, 53.68624653135027, 54.587407044001985, 54.625781944819856, 54.29611424037388, 55.08135795593262, 52.862773827144075, 49.588622842516216, 44.660849230630056, 41.55405603136335, 44.00225033078875, 52.26599999836513, 51.7956451688494, 52.64944328580584, 53.52884898866926, 53.87238529750279, 53.13639041355678, 53.17153787612915, 50.37817096710205, 47.31538070951189, 51.19671739850725, 55.33556474958147, 56.15439258302961, 58.54607718331473, 55.59101179667881, 54.85100780214582, 31.671240602220806, 42.30911677224295, 48.96470935004098, 51.851734501974924, 52.06197656903948, 53.49508074351719, 54.31915099280221, 53.954096112932476, 56.223999636513845, 52.95144673756191, 40.743649414607454, 43.02165453774588, 50.44754178183419, 49.26686566216605, 50.563253607068745, 49.11225782121931, 48.46883726119995, 44.07917383738926, 45.26345259802682, 43.07732350485665, 42.700911794389995, 46.14578696659633, 51.64384092603411, 52.45837824685233, 53.731031145368306, 52.80039290019444, 49.597429684230256, 48.66503701891218, 50.98604106903076, 50.551882880074636, 55.22816644396101, 53.6131341116769, 52.03540665762765, 43.70298446927752, 28.71613700049264, 20.53527934210641, 12.780083094324384, 7.127846871103559, 7.378015892846244, 12.46950990813119, 9.36632890360696, 7.296424065317426, 4.123823174408503, 2.023148672921317, 0.6089972300188882, 0.2123202569782734, 0.06788362881967, 0.06396472946341548, 0.08291003786559616, 5.575159421988896, 24.939210891723633, 35.86088275909424, 29.192436013902935, 25.769892351967947, 19.510897738592966, 23.70244196483067, 32.45690815789359, 38.9449588230678, 49.682684080941335, 53.97662912096296, 27.127615519932338, 3.466320352894919, 0.06967741756566934, 0.0383493437963937, 0.05363012883546097, 0.08208152625177588, 0.03236618145768132, 0.04097353387624025, 0.019493629158075367, 0.02385993075690099, 0.01649668756207185, 0.026718451209100227, 0.03344035667500325, 0.06388757324644498, 0.04640455191422786, 0.0375603025646082, 0.039956983245377026, 0.03586477926000953, 0.02813323573874576, 0.04651159081341965, 0.028485079894640615, 0.04077685710840991, 0.06464722034122262, 0.04932571302301117, 0.022895924181544354, 0.02986409714711564, 0.031241957497383867, 0.0408898230109896, 0.03646959484155689, 0.053094221877732446, 0.043420453289789815, 0.06332379885550056, 0.012436975226072329, 0.03166210298825588, 0.05332197894209197, 0.015125929777111326, 0.018726903246715665, 0.04137741827539035, 0.02623101879310395, 0.06755603211266653, 0.039080495813063214, 0.005842979124281555, 0.04441610843475376, 0.025294145136805515, 0.039499324945999045, 0.027905429480597377, 0.05131066883248942, 0.039728601928800344, 0.09714313090911933, 0.031662248873284886, 0.04706537038353937, 0.02907907623531563, 0.02375359244511596, 0.03848818902458463, 0.7689940503665379, 23.414492981774465, 65.93242917742047, 60.65602970123291, 61.373014313834055, 49.032867704119, 53.486232212611604, 43.37961878095354, 49.00285496030535, 54.71745300292969, 50.614746706826345, 56.452664852142334, 34.834147453308105, 9.430476410048348, 0.9751016135726656, 0.0516283623208957, 0.20074419171682426, 0.7088186336415154, 3.055447748729161, 8.467961566788809, 12.463511875697545, 11.170582396643502, 10.748569658824376, 11.797882267407008, 13.509503245353699, 14.970453194209508, 17.373107263020106, 25.164603505815776, 36.360315799713135, 44.53209216254098, 54.741229738507954, 59.81702082497733, 59.03564725603376, 56.10810715811593, 57.10911328451974, 57.50107853753226, 56.35133579799107, 54.87496171678816, 53.09820311410086, 54.61925411224365, 56.65934944152832, 56.59144122259957, 55.7282908303397, 52.0749488558088, 47.731348514556885, 44.78442989076887, 46.07975476128714, 53.90504877907889, 55.73671204703194, 52.85800388881138, 53.63085549218314, 54.49635784966605, 56.05235481262207, 55.04103408540998, 52.23430926459176, 50.064657824380056, 53.512704849243164, 55.50809894289289, 56.22783156803676, 59.718474524361746, 57.49276154381888, 54.80261359895979, 35.96699217387608, 45.90092550005232, 52.50215884617397, 53.780457156045095, 52.36210400717599, 54.632546016148154, 53.517043999263215, 55.22182968684605, 56.70398119517735, 53.83247137069702, 41.858227321079795, 43.94776603153774, 51.78918334415981, 52.585804734911235, 51.77767365319388, 51.455054896218435, 49.65034369059971, 46.78777272360665, 48.271042891911094, 45.99764442443848, 45.98311226708548, 48.65001848765782, 53.87575169972011, 54.5412849017552, 55.545480251312256, 52.6508537701198, 49.206947871616904, 49.0586906841823, 49.84859316689627, 50.52896772112165, 55.85833331516811, 53.77104582105364, 52.72327136993408, 45.0034510067531, 31.73600823538644, 20.539502109800065, 14.228689568383352, 7.21214849608285, 14.583584444863455, 14.981849976948329, 9.771555662155151, 9.142351116452899, 9.909624184880938, 6.002081062112536, 2.3582494344030107, 1.0452687570026942, 0.04835087872509446, 0.08516008712883506, 0.1516220018799816, 6.056059445653643, 24.942005804606847, 40.36089399882725, 39.18747527258736, 44.5765015738351, 31.958347116197857, 24.514029775347026, 38.65613957813808, 44.829343046460835, 56.712183543613975, 60.86633777618408, 34.64305114746094, 4.672575831413269, 0.18076588160225324, 0.02930237871727773, 0.03137413611901658, 0.01724920834281615, 0.010861033540485161, 0.030172562559268305, 0.06788364917572055, 0.023375780754057423, 0.03544610619012799, 0.026424233336001635, 0.03346084164721625, 0.017141758929938078, 0.08311718782143933, 0.08042613150818007, 0.027019259353567446, 0.052412643629525385, 0.016555818496271968, 0.015595643947433149, 0.023843467801011035, 0.04468741387661014, 0.02079135282630367, 0.032772189671439786, 0.032412213273346424, 0.04669818455087287, 0.021587856246956756, 0.06426570724163737, 0.017893294138567786, 0.12388962427420275, 0.11824311369231769, 0.11873324667768818, 0.08812605869024992, 0.1311347633600235, 0.20888122437255724, 0.12018608514751707, 0.15893973064209732, 0.19957722005035194, 0.1591451774750437, 0.22842585561530931, 0.07086386318717684, 0.09254085857953344, 0.1460233958704131, 0.11559563289795603, 0.08129143329071147, 0.1726199872791767, 0.10679130854883365, 0.09388819842466287, 0.23096721353275435, 0.09399664867669344, 0.1535902148378747, 0.1671780685761145, 0.15590359855975422, 0.2417199851146766, 1.5345893459660667, 34.56851782117571, 76.14835861751011, 69.74848406655448, 71.06487587520054, 52.94607925415039, 57.67904274804251, 48.834170069013325, 80.0836306980678, 79.12003367287772, 57.43016522271292, 63.779356139046804, 35.303519112723215, 9.32357142652784, 1.3176294565200806, 0.24862872010895185, 0.4494020752608776, 0.7225527795297759, 3.882848790713719, 13.569150924682617, 23.106805903570994, 20.385269471577235, 18.385240929467336, 21.647857904434204, 21.027788502829416, 32.93128252029419, 25.503741604941233, 32.82383905138288, 45.21591649736677, 55.04274334226336, 61.02047661372593, 63.21145207541329, 60.267896379743306, 57.018790176936555, 56.90233836855207, 59.05305249350411, 56.77506126676287, 55.669331891196116, 53.803077016557964, 55.06191689627511, 55.48343978609358, 58.60116250174386, 58.69010639190674, 53.87794733047485, 49.370272227696006, 46.81372424534389, 47.7764492716108, 57.413024016789024, 56.773900917598176, 54.128273555210654, 54.81850412913731, 56.457973275865825, 58.82683999197823, 59.25069400242397, 55.42138889857701, 51.86393206460135, 56.348803179604666, 57.46425655909947, 59.85520812443325, 62.07968085152762, 58.16687229701451, 55.87123611995152, 39.19893285206386, 50.59135212217058, 53.49258634022304, 54.30204800197056, 53.326298577444895, 54.623596736363, 54.76955754416329, 55.9224408694676, 59.33663627079555, 57.78323098591396, 44.56722572871617, 47.677110876355854, 54.665185179029194, 54.22294623511178, 54.96647644042969, 53.5613283429827, 52.9056442124503, 48.57646485737392, 50.65540061678205, 47.854977812085835, 48.45676129204886, 50.74581057684762, 56.09654188156128, 57.52659232275826, 57.919940267290386, 54.798941476004465, 49.43689850398472, 49.43524830681937, 49.828863756997244, 51.833023003169465, 57.19562530517578, 56.34741006578718, 56.00154263632638, 47.79601887294224, 31.343938759395055, 28.923716170447214, 20.865040847233363, 11.987872072628566, 17.02585366794041, 22.61649932180132, 20.552988563265117, 16.8640752860478, 17.353047813688004, 6.824756894792829, 2.065451911517552, 0.9661462541137422, 0.23915623554161616, 0.1765555582408394, 0.370803102850914, 7.572238888059344, 31.98594536100115, 46.15414217540196, 37.53476980754307, 33.85123791013445, 27.592667136873516, 34.46794959477016, 44.99732616969517, 52.95426423209054, 64.06615693228585, 68.74599797385079, 44.65355709620884, 6.925540515354701, 0.27435570103781565, 0.12151894505534853, 0.20927904945399078, 0.13273295760154724, 0.11960639911038534, 0.11435814787234579, 0.2665504312941006, 0.1752659481550966, 0.1048252261908991, 0.1502590285880225, 0.26949261341776165, 0.12166698782571725, 0.13193371120308126, 0.12778632874999726, 0.1218496494527374, 0.08148864949388163, 0.09254275169223547, 0.14146898740104266, 0.11173499934375286, 0.20478408065225395, 0.17166961756135735, 0.09460430392729384, 0.2086623968290431, 0.14209702584360326, 0.10067299221243177, 0.12763076781162194, 0.11620531018291201], [0.04903977158080254, 0.041957572501684935, 0.05091908288055232, 0.021672912307881882, 0.03325518107573901, 0.03294293961620756, 0.024524411618975655, 0.01135106389743409, 0.033852604018258195, 0.045026966370642185, 0.011858098341950347, 0.029094719860170568, 0.036532053990023475, 0.029532883848462785, 0.007887861874353672, 0.07489643072975533, 0.01549728011845478, 0.046372827009430954, 0.0613895058631897, 0.03615173511207104, 0.043020422969545634, 0.023458473816780106, 0.04028980806469917, 0.03492223644363029, 0.02764706709422171, 1.7963534998042243, 34.23199571881975, 57.436884130750386, 55.76524829864502, 44.379016399383545, 41.64166586739676, 28.214596918651036, 23.518259116581508, 51.685554436274934, 48.815903254917686, 55.88838079997471, 33.5139410836356, 10.867145878928048, 1.980162339551108, 0.08238496032676526, 0.08940013710941587, 0.13089518621563911, 0.2837892105536801, 1.4792675716536385, 6.747172006538936, 9.707529749189105, 7.734773755073547, 11.43615470613752, 12.26293214729854, 31.227823938642228, 37.516464778355186, 39.06048999513899, 41.85247768674578, 53.25931099482945, 56.01445238930838, 56.50084713527134, 56.63650376456124, 55.906699725559776, 54.569939272744314, 56.27279336111886, 57.864740303584504, 56.33551822389875, 56.24382979529244, 52.52505316053118, 53.8276423726763, 55.8192184312003, 55.208020142146516, 52.000832421439036, 47.58957052230835, 40.96771492276873, 41.498626777103965, 45.196548393794465, 49.42295694351196, 54.83496788569859, 54.82782861164638, 51.3472466468811, 55.30071953364781, 53.224517890385215, 51.54665299824306, 47.58688504355294, 47.32587596348354, 48.888268743242534, 53.51961135864258, 53.21752452850342, 58.850630623953684, 54.87908894675118, 58.51526887076241, 37.91901561192104, 37.2397631917681, 50.07701866967337, 48.13568156106131, 52.534085818699424, 51.43984528950283, 54.85591670445034, 52.608400276729036, 56.316834517887656, 49.43346956798008, 41.652407782418386, 42.65891340800694, 53.12908090863909, 52.447796140398296, 52.64746304920742, 51.74684797014509, 51.622690609523225, 47.64883518218994, 47.4900028364999, 43.64395604814802, 42.11525855745588, 41.52660369873047, 48.83214814322335, 49.266212531498496, 53.56445850644793, 52.71622589656285, 54.41814545222691, 49.0359388078962, 50.70653588431222, 49.130319663456504, 50.56235728945051, 50.850651945386616, 55.451658725738525, 53.610521589006694, 45.45756789616176, 27.80276676586696, 36.66041544505528, 22.10202690533229, 14.520332387515477, 16.17131904193333, 10.306270786694117, 11.60161302770887, 4.081618513379778, 5.5332517964499335, 4.191695783819471, 0.6586230556879724, 0.14854959531554154, 0.08650265687278338, 0.02575860235707036, 0.8165342765195029, 8.322000758988516, 26.634005069732666, 38.21795490809849, 25.88391923904419, 20.149696009499685, 25.31783560344151, 19.648572819573538, 29.99785382407052, 43.58549737930298, 48.41054882322039, 44.55810274396624, 11.248704467500959, 0.18185381750975335, 0.03572523174807429, 0.03522292923714433, 0.002950570936913469, 0.02788284613883921, 0.009643132731850659, 0.049884221982210875, 0.02651068039371499, 0.017961592080869844, 0.06537274390991245, 0.045784469294760904, 0.012705795533422912, 0.026745672337710857, 0.03356541407161525, 0.008259375064101602, 0.037313152969415696, 0.06920985265501908, 0.03740210212501032, 0.05762075273586171, 0.025523411941581538, 0.0994980206180896, 0.06550680207354681, 0.04713203984179667, 0.018059754045680165, 0.007464215142785439, 0.045449083005743365, 0.08202906870948416, 0.022796264350680367, 0.024422516015225222, 0.04118259730083602, 0.010751512899462665, 0.052458621162389, 0.032205551862716675, 0.033864427490958145, 0.024438661755993962, 0.019432734032826762, 0.03156350167202098, 0.09315657482615539, 0.04743271567193525, 0.024661455336692076, 0.050288496538996696, 0.05856462887355259, 0.038625904491969516, 0.008571354439482093, 0.040554596177701435, 0.08686829225293227, 0.050887734562690766, 0.07792491572243826, 0.08456796354481153, 0.044684726877936294, 0.10442990490368434, 0.010540368068697197, 3.5177813172340393, 43.43557609830584, 66.84937599727085, 62.8255421774728, 51.254001821790425, 46.52620778764997, 37.78221600396292, 32.25266238621303, 54.25024223327637, 54.918238571711946, 62.29016957964216, 43.76567806516375, 13.48145684174129, 1.9673431302819933, 0.08249059465846845, 0.10717642466936793, 0.6241599906768117, 2.18715786082404, 6.451210447720118, 10.431657978466578, 12.485485553741455, 9.058117236409869, 12.779742632593427, 16.285960844584874, 16.09177085331508, 24.984877926962717, 33.96475063051496, 39.96049015862601, 49.75123153414045, 55.81914547511509, 59.479776109967915, 58.91526971544538, 57.57878371647426, 55.72213820048741, 57.011449405125205, 58.23391546521868, 56.19553634098598, 54.823909827641074, 53.5498811858041, 53.66824722290039, 56.395126819610596, 57.034156118120464, 52.915125029427664, 48.591559818812776, 43.482549394880024, 42.94005141939436, 47.3406617300851, 53.04241950171334, 57.01077890396118, 56.05328587123326, 51.986262048993794, 56.156265122549875, 55.737941878182546, 54.68566499437605, 49.91686964035034, 49.47997733524868, 49.89271075384957, 54.78682729176113, 54.198505946568076, 58.87225341796875, 55.27115842274257, 57.92328235081264, 40.36741835730416, 41.831466334206716, 52.52929156167166, 50.04232284000942, 52.564331327165874, 52.45955944061279, 55.3024947983878, 54.787442207336426, 57.5546178817749, 52.25106831959316, 43.66566916874477, 43.7901565687997, 54.681409222739084, 53.91498122896467, 54.2884191104344, 53.54968663624355, 52.102439403533936, 49.40257092884609, 47.60161175046648, 45.03966849190848, 44.25320189339774, 44.81036751610892, 50.25872448512486, 50.82949468067714, 54.66734259469168, 54.58241476331438, 54.20707654953003, 49.17176914215088, 50.475355420793804, 49.83079535620553, 51.35219723837716, 51.59846224103655, 57.16339956011091, 53.660034452165874, 44.36258738381522, 28.888172660555156, 26.986513239996775, 13.929394177028112, 11.861549479620797, 12.955229810306005, 7.933378458023071, 13.583352174077715, 8.98591763632638, 9.035281113215856, 4.367124770368848, 2.675325483083725, 0.5088199483496803, 0.14876159679676804, 0.02879181843517082, 0.8470875141876084, 8.978913852146693, 27.47250325339181, 41.758833340236116, 26.79585119656154, 22.721945183617727, 33.384947776794434, 26.34531957762582, 36.772663593292236, 50.183003016880576, 54.46756451470511, 52.51193148749215, 15.955082416534424, 0.23955589266760008, 0.05343907033758504, 0.014215615677780338, 0.018297042830714157, 0.013660377257370522, 0.017248063314972178, 0.03593267686665058, 0.02186923284482743, 0.06474627288324492, 0.007464373750346047, 0.04415338985355837, 0.034212278468268256, 0.026195239641570618, 0.036723733347441466, 0.02474393805355898, 0.09422540997288056, 0.05088359549907701, 0.06237874885222741, 0.037509955266224485, 0.03010258185012, 0.06140490860811301, 0.06182651634195021, 0.01800700812600553, 0.032419141115886826, 0.012254188070073724, 0.03562405878411872, 0.06288826079773051, 0.08642700700355427, 0.08757706279201166, 0.13315454497933388, 0.06272281360413347, 0.20117069168814591, 0.08428469553057637, 0.11307663949472563, 0.11540181615522929, 0.14986617038292543, 0.14802025657679352, 0.14782449922391347, 0.10826801788061857, 0.0700399452554328, 0.12905037163623742, 0.10478950132216726, 0.154263579419681, 0.08689126744866371, 0.1604794758771147, 0.1953004952520132, 0.1656404539410557, 0.1062764497473836, 0.17077164431767805, 0.14158695749938488, 0.11253138232444014, 0.18059167452156544, 6.442727131502969, 53.61562851497105, 74.09656946999687, 72.19187368665422, 57.62213005338396, 53.183631215776714, 39.072218554360525, 34.3337972504752, 64.03930909293038, 58.267767088753835, 66.43002441951207, 42.760586397988455, 15.26687376839774, 2.8517563130174364, 0.2980764167649405, 0.3759065275745732, 0.5166374860065324, 3.72808461529868, 8.432689036641802, 18.6151533467429, 19.810623918260845, 12.54392077241625, 18.636109113693237, 21.015559673309326, 41.12223938533238, 43.77472114562988, 43.2602139881679, 44.995092323848176, 55.99119329452515, 59.94433266775948, 61.43658338274275, 60.14364174434117, 61.336327825273784, 58.21796587535313, 60.20541817801339, 58.7223390851702, 57.385140895843506, 55.79804727009365, 52.02280609948294, 55.124874523707796, 57.95499045508248, 59.47170925140381, 56.34590925489153, 51.40848112106323, 45.29994453702654, 46.299224036080496, 50.293253558022634, 54.75439657483782, 60.1064132962908, 58.03145885467529, 53.04951013837542, 56.07942846843174, 57.40465143748692, 56.204336234501426, 50.99221454347883, 51.28443145751953, 53.69535909380232, 55.73504447937012, 57.04082638876778, 61.35227394104004, 58.80186816624233, 59.21980231148856, 44.46407624653408, 45.72487204415457, 53.97077178955078, 51.42839118412563, 53.09629583358765, 52.570129598890034, 56.551072188786094, 56.913538864680696, 60.342832701546804, 54.79788187571934, 45.90896456582205, 46.915862764631, 58.32224791390555, 56.482868671417236, 56.7700377191816, 55.21152203423636, 55.69374091284615, 51.04327685492379, 51.064267362867085, 48.324776785714285, 46.85086236681257, 46.355629512241904, 51.94401352746146, 54.120568002973286, 57.96167114802769, 56.915605953761506, 57.477510247911724, 48.660934107644216, 50.81519876207624, 50.4699045589992, 52.945943764277864, 52.422018323625835, 60.423973764692036, 56.35927064078194, 49.29709380013602, 31.168906688690186, 38.13440976824079, 27.310094322477067, 20.228839465550013, 23.516737461090088, 22.826261963163102, 20.30930655343192, 11.106675471578326, 15.783842325210571, 12.201729808534894, 1.8608365825244357, 0.28529574828488485, 0.35595244116016794, 0.19606280220406397, 1.0150808968714304, 10.681360602378845, 33.746941975184846, 50.15790612357003, 35.573824882507324, 30.541088308606827, 35.9460711479187, 29.760663168770925, 41.14060000010899, 59.22488839285714, 63.073488644191194, 61.275718688964844, 22.201153380530222, 0.5124716066888401, 0.07680297842515366, 0.1251655143818685, 0.08612222942922797, 0.09998744792704072, 0.11027111432382039, 0.08279522295509066, 0.07173077988305263, 0.11565972731581756, 0.12043575889297894, 0.14924475444214685, 0.13325153477489948, 0.07298429869115353, 0.1590467356145382, 0.12057251084063735, 0.1263353901782206, 0.1222060431859323, 0.14582571147808007, 0.14225355030170508, 0.09681947649057422, 0.15740948489734105, 0.16584801780326025, 0.15667885195996079, 0.13412840557949884, 0.11217203696391412, 0.1242254583963326, 0.12413370689111096], [0.021823786265615906, 0.052759429306856225, 0.0067238537095753205, 0.013070201917019273, 0.07579773558037621, 0.03832371552873935, 0.02349069744481572, 0.03846591950527259, 0.032472175412944386, 0.07254943238305193, 0.051138080057821104, 0.04011241865477391, 0.023315896645986607, 0.03538548247888684, 0.012929567052716655, 0.025691995663302283, 0.016377767514703528, 0.038156992689307244, 0.01087381289939263, 0.025757725350558758, 0.10936134814151696, 0.041677144156502824, 0.027080793998071125, 0.03903379564040473, 0.18757439697427408, 8.459661075047084, 49.30215208871024, 56.05987971169608, 50.707383564540315, 37.936188084738596, 39.003497396196636, 28.599678243909562, 39.83290386199951, 56.429968561444966, 57.279295512608115, 42.89772646767752, 15.37897253036499, 5.334771292550223, 0.14317292453987257, 0.024714264020855938, 0.06269868489887033, 0.6996660104819706, 0.9425382294825145, 4.116561438356127, 7.741136567933219, 8.692323241915021, 10.253971695899963, 15.236157519476754, 21.860670804977417, 26.748295988355363, 33.98171465737479, 47.043782574789866, 51.817219325474326, 55.17128154209682, 57.54851041521345, 57.87505490439278, 53.04442753110613, 50.540348870413645, 49.08709839412144, 53.27768898010254, 55.54997226170131, 54.973240511757986, 53.40923922402518, 53.379841395786826, 53.80245515278408, 55.13271903991699, 53.75723627635411, 48.12205266952515, 45.46697923115322, 42.30851922716413, 42.79107509340559, 46.15352725982666, 51.90118483134678, 52.11034645353045, 53.69096435819353, 52.433802468436106, 52.85005862372262, 52.63327830178397, 54.07978555134365, 48.08072131020682, 43.042384488242014, 46.206587178366526, 52.37559740883963, 51.41232000078474, 57.61288547515869, 52.704476492745535, 60.00675528390067, 37.435257707323345, 35.100861004420686, 52.2109911101205, 47.59183216094971, 56.32898344312395, 51.865804604121614, 57.09755495616368, 53.36193241391863, 55.17333126068115, 43.16712897164481, 39.38327898297991, 41.69742863518851, 51.269923618861604, 52.46076842716762, 54.0745153427124, 52.72195816040039, 52.56805556161063, 49.39516067504883, 48.36733102798462, 46.39901406424386, 43.23282071522304, 39.28954083578927, 42.43457692010062, 46.40063646861485, 50.33994197845459, 50.82259859357561, 52.41187047958374, 48.623604910714285, 48.72561488832746, 49.67391545431954, 54.09002372196743, 50.81326021466936, 54.07256637300764, 51.1699355670384, 48.68693774087088, 47.523580006190706, 32.570580686841694, 18.208956445966447, 23.176305259977067, 13.831460186413356, 4.955300637653895, 6.777067933763776, 10.342349307877676, 6.915111703532083, 2.4455426931381226, 3.082771973950522, 0.5984038870249475, 0.08905967537845884, 0.0945021640509367, 0.06495926502559866, 2.1283252920423235, 13.818467055048261, 38.57383469172886, 52.719501972198486, 29.597390924181255, 10.407168184007917, 16.770345824105398, 29.528238977704728, 44.77541807719639, 48.90788698196411, 48.39628069741385, 29.522141933441162, 0.5401524699160031, 0.10665385092475585, 0.06915445027074643, 0.057622204800801616, 0.03815878062908139, 0.0279529608586537, 0.004523254382157964, 0.07663677127233573, 0.04024236489619527, 0.06715321301349572, 0.04271197112809334, 0.02397469647361764, 0.023456053143101077, 0.04835752158292702, 0.01392336979707969, 0.07139521038958005, 0.020353348293740834, 0.034001311752945185, 0.04161779948377183, 0.046540991735777686, 0.057081012055277824, 0.04896008103553738, 0.059590804523655345, 0.06319803238979407, 0.018253139918670058, 0.023107757725353752, 0.011440434592909046, 0.024189858231693506, 0.020349026025672044, 0.021187657989295464, 0.07167450897395611, 0.04304744562666331, 0.02870747653235282, 0.03253137420064636, 0.017421922646462917, 0.039109903520771434, 0.06288758226271186, 0.009141041414945253, 0.04421242579285588, 0.029148212168365717, 0.04463854578456708, 0.04292844754776784, 0.02628004634087639, 0.01912156805129988, 0.014032661432533391, 0.015282416915787118, 0.11705879867076874, 0.02632308072809662, 0.05283102492934891, 0.047545420338532755, 0.04670747708795326, 0.21802248885588987, 11.434739010674612, 60.03527069091797, 61.89622061593192, 57.318757806505474, 44.95974336351667, 46.73343781062535, 36.71251998628889, 38.82016222817557, 56.117650508880615, 60.79628603799002, 49.027660029275076, 20.975914989198955, 5.224667532103402, 0.4405912166195256, 0.03685797132285578, 0.3545147883040564, 1.6481944556747163, 4.687809322561536, 9.099812507629395, 9.62178897857666, 16.635390962873185, 12.64636674949101, 11.357765998159136, 23.61303080831255, 26.689244985580444, 32.87511328288487, 47.501877307891846, 51.97244208199637, 57.55003554480416, 57.44249480111258, 59.6401127406529, 54.52365384783064, 54.53241900035313, 50.093152386801584, 55.16926656450544, 56.193688120160786, 55.8136807169233, 54.01680360521589, 53.87020008904593, 53.86789676121303, 57.15390484673636, 55.93868923187256, 51.24417012078421, 46.70636762891497, 44.113984312329976, 45.01008653640747, 47.92422008514404, 52.81313589641026, 54.086702483040945, 53.784236976078574, 52.33470031193325, 54.76154974528721, 55.568006311144146, 55.675581795828684, 49.550855909075054, 45.06379263741629, 47.72671406609671, 52.55745955875942, 53.31636960165841, 57.91836302621024, 55.36865554537092, 58.891972405569895, 40.112277030944824, 37.223202160426546, 54.53623703547886, 49.407198429107666, 56.75868436268398, 53.927651269095286, 57.29508181980678, 53.99534061976841, 56.80282974243164, 46.627488204411094, 42.02415377753121, 42.09031799861363, 53.145249366760254, 54.27025999341692, 56.90063605989729, 54.526061398642405, 55.13384117398943, 51.54146269389561, 49.70058264051165, 47.47781222207205, 45.87956326348441, 41.48588030678885, 45.143373829977854, 49.69291182926723, 52.07560198647635, 53.67501824242728, 54.13083396639143, 49.68859699794224, 48.84163243430001, 49.660182339804514, 52.99635641915457, 51.12527254649571, 55.10284873417446, 53.0995580128261, 51.56523248127529, 46.59847252709525, 35.12562091009957, 19.90992409842355, 14.603953089032855, 6.721864061696189, 11.939445734024048, 12.131379297801427, 8.591193948473249, 8.237061636788503, 5.7407432453972955, 6.515759646892548, 1.4331117740699222, 0.23568550177982875, 0.16494543052145413, 0.043846142411764176, 2.2864764971392493, 14.576877696173531, 37.82305751528059, 44.51832430703299, 29.442942891802105, 16.28771526472909, 23.117203882762364, 35.75812585013253, 48.2816493170602, 55.744139671325684, 54.78674043927874, 37.16225256238665, 1.3731392664568765, 0.07611043165837016, 0.03900202323815652, 0.02399111362839384, 0.08324944786727428, 0.03905992263129779, 0.03280833183920809, 0.022543211500825625, 0.016614477848634124, 0.06307434902659484, 0.01874933561443218, 0.025315004999616315, 0.05867740139365196, 0.05022225116512605, 0.004598064140217113, 0.012612227250688841, 0.030650234249021326, 0.04416113193812115, 0.030129509512335062, 0.0264643618970045, 0.03141821375382798, 0.0386682857892343, 0.03449137688481382, 0.044146098994782994, 0.05998666185353484, 0.04823731231902327, 0.02160791543844555, 0.10835782877568688, 0.14066545266125882, 0.14673827322466032, 0.201738639069455, 0.1622238808444568, 0.18113854660519532, 0.14618922982897076, 0.19663695139544352, 0.1679547197584595, 0.21711577608117036, 0.19438352302781173, 0.13090389860527857, 0.16108548907297, 0.12116777604179722, 0.10332218291504042, 0.10361750849655696, 0.08897160153303828, 0.11554381996393204, 0.11023192214114325, 0.29034687152930666, 0.2161150454942669, 0.1522310142006193, 0.076062615295606, 0.08430078359586851, 0.4051649847200939, 15.998873438153948, 71.94610200609479, 69.3797709601266, 68.1193538393293, 51.088294233594624, 52.4745397567749, 38.58767550332205, 52.495516368321006, 68.33135727473667, 66.13297503335136, 52.4932199886867, 22.929079668862478, 6.436136330877032, 0.46489267689841135, 0.1682791273508753, 0.3554454397942339, 1.76819266804627, 5.274686310972486, 14.038747532027108, 19.18057516642979, 16.53967605318342, 16.38801772253854, 25.551253386906215, 28.067713737487793, 31.927476269858225, 36.31281096594674, 50.989344937460764, 53.4891608783177, 56.47314814158848, 58.017798696245464, 62.01932879856655, 57.44038602284023, 55.555040972573416, 53.046188899448936, 57.52307653427124, 56.84045076370239, 56.2934364591326, 54.68956988198416, 53.73127085821969, 54.57839175633022, 58.73051016671317, 58.87312889099121, 53.6265024457659, 49.07657882145473, 45.2469402040754, 46.38903297696795, 50.5137094770159, 56.92545849936349, 57.95228065763201, 54.504459449223106, 53.21611751828875, 55.461955956050325, 56.603461606161936, 58.20722048623221, 52.76641968318394, 47.972423212868826, 49.8435765675136, 54.546367509024485, 55.19232068743025, 59.80481284005301, 58.06102691377912, 60.202089990888325, 43.224281379154746, 40.9683506829398, 55.490565163748606, 51.402196475437705, 57.201486110687256, 55.609004156930105, 58.823713302612305, 57.4862128666469, 59.01892989022391, 47.69012485231672, 43.70994656426566, 46.1702515738351, 56.12064865657261, 56.58648368290493, 58.00394398825509, 56.16120876584734, 55.58755854197911, 54.38395684106009, 51.72968244552612, 50.09649099622454, 47.373453753335134, 43.66977902821132, 47.096036502293174, 52.035114833286826, 54.5629563331604, 56.232969760894775, 56.459901400974815, 51.00690998349871, 50.44497789655413, 50.30067770821707, 54.423408712659565, 51.71723127365112, 55.557049001966206, 54.53733137675694, 52.434608459472656, 49.46956198556082, 36.06974560873849, 22.779620443071636, 29.497256960187638, 24.030926738466533, 13.268042053495135, 15.979851007461548, 25.477991580963135, 15.245615754808698, 9.450034720557076, 9.302823237010411, 1.3721848662410463, 0.20910591445863247, 0.3274531832763127, 0.2195273573909487, 3.140727766922542, 17.15254190989903, 49.10352740968977, 66.67155075073242, 38.561199392591206, 16.864693675722393, 26.51151701382228, 42.019706930433, 57.36499111992972, 62.08722659519741, 63.89223657335554, 45.122828006744385, 2.598652111632483, 0.2590919743691172, 0.11937590076455049, 0.09526733442076615, 0.16811713390052319, 0.10717904381453991, 0.1070533384169851, 0.16818923503160477, 0.13614836361791405, 0.16651304997503757, 0.1932510616523879, 0.14819199379001344, 0.20520184109253542, 0.1418651704277311, 0.11782337192978178, 0.11775490774640016, 0.13148686875190052, 0.1773678460823638, 0.0774984225364668, 0.16575370143566812, 0.1047379190900496, 0.11718544044664927, 0.13809706190867083, 0.21048464333372457, 0.13569559077067034, 0.11225650100303547, 0.09886213152536324], [0.06523710475968462, 0.02334740272324, 0.06662150618753263, 0.03436886738719685, 0.03687475149386695, 0.04489175130480102, 0.03991568760414209, 0.03361409556652818, 0.005725709189261709, 0.037036147833402665, 0.05522291176021099, 0.03415573614516428, 0.034990439391029735, 0.04150274708600981, 0.09554404778672115, 0.03827740890639169, 0.049038475578916926, 0.028135274736476795, 0.022894986106881073, 0.03337966850293534, 0.021411679718377333, 0.043289404428963146, 0.09774366154202394, 0.03417684876226953, 0.13842277228832245, 20.901841981070383, 57.01152236121041, 53.032382828848704, 45.263178144182476, 25.18106378827776, 20.013917786734446, 21.348069190979004, 37.948733057294575, 51.15368373053414, 57.8508300100054, 29.693345546722412, 10.344459823199681, 1.0855446415288108, 0.05698834452778101, 0.11996275213147913, 0.11085380627108471, 1.7002606732504708, 1.9760181733540125, 6.980116443974631, 6.489984435694558, 16.761431285313197, 12.783278397151403, 13.803404229027883, 40.119385038103374, 32.59913778305054, 47.12780019215175, 58.048902307237896, 55.93271030698504, 56.227206230163574, 55.980704988752095, 53.81192902156285, 52.331653526851106, 50.87165287562779, 51.42828001294817, 56.88074336733137, 55.958752155303955, 53.6105181149074, 55.36868681226458, 53.53394896643502, 54.56534651347569, 53.73917096001761, 50.339566775730674, 43.95558622905186, 40.02624096189226, 40.9794156891959, 46.32239975248064, 49.04432528359549, 50.55390133176531, 52.35498210362026, 54.79728433064052, 50.147834709712434, 53.64348036902291, 52.72008909497942, 54.89863770348685, 44.849621364048545, 40.75257437569754, 42.25843661172049, 49.12859303610665, 49.91813768659319, 56.43609339850289, 51.20294298444475, 60.010722705296104, 35.03180980682373, 30.17809009552002, 52.63582134246826, 48.50499221256801, 54.57545961652483, 50.28571128845215, 55.479990005493164, 50.299840450286865, 47.28839043208531, 39.30018547603062, 41.20594085965838, 40.7631391116551, 51.292272499629426, 53.610153334481375, 53.428881781441824, 51.507809094020296, 54.49900163922991, 52.21811996187483, 51.28726632254464, 45.871965408325195, 43.510495049612864, 39.944015979766846, 39.362670625959126, 40.595927238464355, 47.779162543160574, 49.27016953059605, 51.322997433798655, 49.77862480708531, 49.51218223571777, 50.907648018428254, 50.713609150477815, 45.770354952131, 50.54503195626395, 52.1607208933149, 58.34647628239223, 50.20425060817173, 48.075906208583284, 31.342479637690953, 26.003624541418894, 9.53084487574441, 2.074902330126081, 16.609606197902135, 4.201385481016977, 7.567605308123997, 3.590700490134103, 5.795408632074084, 1.6947271930319923, 0.3768163616103785, 0.03787403001583048, 0.08791432183768068, 0.07380127520965678, 3.8820241263934543, 21.353163957595825, 43.480586528778076, 38.62514019012451, 31.46208245413644, 18.606551476887294, 23.597280979156494, 42.86711965288435, 46.67726509911673, 46.136723041534424, 35.13291999271938, 4.950816009725843, 0.01752967231108674, 0.0622741323230522, 0.030760516545602253, 0.09837150999477931, 0.05619570027504649, 0.06359559962792055, 0.03326452789562089, 0.03492864520688142, 0.019612856242539625, 0.03639531900574054, 0.060591046565345356, 0.027909236062051992, 0.023263807208942514, 0.04609485496101635, 0.009514597843268087, 0.04536057829058596, 0.067066516594163, 0.019132957261587893, 0.05997568994228329, 0.03850782922069941, 0.04025396445233907, 0.021747111808508635, 0.06638134550303221, 0.11455224959978036, 0.05004734180069395, 0.05248896524842296, 0.03159705862136824, 0.046851105988025665, 0.02111574006266892, 0.050861614357147894, 0.06365106308034488, 0.021888552433145896, 0.015840109936626892, 0.04187263348805053, 0.06565662939101458, 0.005209591705352068, 0.017512289940246513, 0.03798650398052164, 0.010515608325866716, 0.043469609759215794, 0.021498138650453517, 0.01455977712092655, 0.04767030470871499, 0.024750867592436925, 0.07642296488795962, 0.022589414646582942, 0.03361437037321074, 0.02855661784165672, 0.08632090448268823, 0.016862295800819993, 0.300964180380106, 26.752409321921213, 64.50652681078229, 59.96514252253941, 51.92103583472115, 32.8666364806039, 29.44132396153041, 26.51110359600612, 35.87894460133144, 56.45555182865688, 60.417539732796804, 35.152500016348704, 12.462025829723903, 1.3545305792774474, 0.04234961307208453, 0.1851125226489135, 0.6074510387011937, 3.5962458040033067, 6.5033922876630506, 9.132556762014117, 8.180697849818639, 13.971189328602382, 8.655596801212855, 17.48765526499067, 28.343876838684082, 32.923371996198384, 47.5095967565264, 56.740577357155935, 56.44891282490322, 54.88546391895839, 57.31107309886387, 57.14269740240914, 54.24101502554757, 51.34332438877651, 53.438640526362825, 57.30410405567714, 56.32731934956142, 54.1280129977635, 53.56372547149658, 54.930578572409495, 56.26067222867693, 54.93690838132586, 51.76737642288208, 47.54112768173218, 41.95846898215157, 42.457530294145855, 47.766617570604595, 50.40753752844674, 53.48267820903233, 54.84374693461827, 55.55177184513637, 50.55802508762905, 53.11753300258091, 53.84929643358503, 56.5231716973441, 46.94933223724365, 42.522033895765034, 44.52490772519793, 50.169068404606406, 51.38115733010428, 57.32059907913208, 53.08990349088396, 60.855943271092, 36.63674293245588, 33.74137299401419, 55.260961941310335, 50.06022834777832, 56.59951850346157, 53.539674282073975, 57.15578086035592, 50.929062366485596, 49.84097099304199, 41.77229200090681, 42.43811355318342, 40.70816496440342, 51.99566296168736, 54.85247734614781, 54.76005588259016, 53.20330504008702, 54.8997528893607, 53.55058642796108, 52.686605725969585, 47.427555901663645, 45.717826570783345, 43.40769992555891, 41.276583194732666, 42.33337640762329, 50.36665432793753, 52.165647166115896, 53.06879486356463, 49.818292072841096, 49.72457824434553, 51.27536405835833, 51.32941409519741, 46.39898974554879, 50.486906800951274, 53.30903925214495, 56.934824671064106, 51.38891151973179, 47.00136729649135, 32.30132062094552, 21.371246644428798, 14.809248038700648, 10.065820557730538, 13.328643373080663, 12.384445718356542, 7.690321786063058, 10.89329889842442, 9.142419729913984, 4.209717673914773, 0.8162234531981605, 0.24851331487298012, 0.0509597610549203, 0.10531193257442542, 4.007073027747018, 22.94289789881025, 42.306111676352366, 33.680440766470774, 27.4996429170881, 23.006593772343226, 29.45230906350272, 49.017592089516775, 53.449695110321045, 52.525796617780415, 43.09928328650338, 6.936665449823652, 0.024154299604041234, 0.024315600948674337, 0.021685672158907567, 0.030705830015774285, 0.06789982545056514, 0.12059054630143301, 0.02638194533730192, 0.003306015145166644, 0.03427794369469796, 0.024791522018079246, 0.07960471058530466, 0.0259050997639341, 0.02755373120973153, 0.03021714909534369, 0.02144134187671755, 0.045575283733861785, 0.02779864163936249, 0.02191609756222793, 0.004971704113164118, 0.02763936572176005, 0.01695978601596185, 0.040121969035161395, 0.09473517976169075, 0.05373530854870166, 0.014293631937886988, 0.016958970077601925, 0.17029174364038877, 0.12282752698021275, 0.12360272609761783, 0.1177773672555174, 0.11309996752866677, 0.15452913088457926, 0.0776043011407767, 0.15790850669145584, 0.09945521862911326, 0.16028069225805147, 0.10529232291238648, 0.18326146554734024, 0.12859997366155895, 0.15860000172896044, 0.11431229247578553, 0.10729632859251328, 0.13222724545214856, 0.17330693613205636, 0.19482196521546158, 0.23307881451078824, 0.17310077005199023, 0.11034751058157001, 0.27523440388696535, 0.07513102742710284, 0.732261638556208, 36.60132449013846, 74.54284531729562, 65.35198361533028, 60.250692640032085, 37.0496118409293, 31.72760091509138, 30.81766482761928, 50.19108724594116, 61.0676965713501, 66.33980900900704, 38.57481786182949, 13.977866547448293, 1.4955880216189792, 0.14866429487509386, 0.3023021157298769, 0.5455945378967694, 5.8627001983778815, 9.786386592047554, 17.491746016911097, 13.799765978540693, 25.746291058404104, 23.17376916749137, 20.944014072418213, 48.795975821358816, 35.89009646006993, 49.994355951036724, 61.93178844451904, 56.563644954136436, 55.71322018759591, 57.052523681095664, 59.999800137111116, 56.10441766466413, 55.00345127923148, 55.38146454947335, 60.79779379708426, 56.85061597824097, 54.72871255874634, 54.91692883627755, 54.441251686641145, 58.238876479012625, 58.71620382581438, 54.22837277821132, 48.04685926437378, 42.90663405827114, 45.79351677213396, 50.756142548152376, 53.27067824772426, 56.22750152860369, 57.18264259610857, 56.73328522273472, 52.22732979910714, 53.91053090776716, 56.736589091164724, 59.13026087624686, 49.16838536943708, 44.7346008845738, 46.836500440325054, 52.299754347120015, 54.45038856778826, 58.860809734889436, 56.08107171739851, 61.139853613717214, 38.62577942439488, 37.04019008363996, 56.471557004111155, 51.83137628010341, 57.64563233511788, 55.45566783632551, 57.747562408447266, 54.370275838034495, 51.98937831606184, 44.158206122262136, 44.508569036211284, 42.10508639471871, 54.74535002027239, 57.129891872406006, 57.89729608808245, 53.677905218941824, 56.472036429813926, 54.415491240365164, 55.551268100738525, 49.58489165987287, 48.17696080889021, 44.41500806808472, 43.557899134499685, 43.45312029974801, 53.635656697409495, 54.63279267719814, 56.121961866106304, 50.37034382138933, 49.92915405545916, 52.539439405713765, 51.787481035505024, 46.4766914503915, 52.88601207733154, 54.105010986328125, 60.87632233755929, 50.54026549203055, 54.27900777544294, 35.588068689618794, 29.92249366215297, 14.22418018749782, 7.9210063219070435, 31.038860729762487, 15.288835287094116, 16.395568677357264, 12.698072637830462, 15.190117018563406, 4.2259247813905985, 1.1963900136096137, 0.260285381759916, 0.31064646797520773, 0.19030148349702358, 5.761184411389487, 27.731551204408916, 56.95538786479405, 50.227714674813406, 42.72435849053519, 27.4071432862963, 34.82787322998047, 55.360220432281494, 59.591037614004954, 59.217092514038086, 50.20759963989258, 10.13778565611158, 0.12002297889973436, 0.13008236911680016, 0.0804912301578692, 0.12530887526060852, 0.10449847086731877, 0.1794700968478407, 0.0800633527604597, 0.12295996344515256, 0.17360009040151322, 0.08308150366480861, 0.1729580605668681, 0.10986415616103581, 0.07415644079446793, 0.11370792812002556, 0.09008079594267265, 0.09385926569146769, 0.18971106303589685, 0.07656768962208714, 0.12166587502828666, 0.13009093222873552, 0.10246046379740749, 0.10742814759058611, 0.24841207744819777, 0.23120611214212008, 0.10294886651848044, 0.11527917773595878], [0.042987144219556024, 0.029392542450555732, 0.02564435063063034, 0.07160998707903282, 0.040067564097366164, 0.03556233923882246, 0.061647722364536355, 0.008954599499702454, 0.03217723659638848, 0.01172043800553573, 0.022995426253016506, 0.027808018993320208, 0.029173009230622222, 0.06317771026598555, 0.04412871492760522, 0.03882879324789558, 0.0479277917849166, 0.06250684269304786, 0.04491027531081012, 0.03689027976776872, 0.040798112217869074, 0.0828657838116799, 0.008305656241386064, 0.017994243185967207, 1.6512907466718127, 38.54633024760655, 58.75891440255301, 54.01208577837263, 43.00145265034267, 45.133229460035054, 22.313002007348196, 38.16371726989746, 40.282202175685335, 41.79286561693464, 50.53032609394619, 18.16920406477792, 5.116809342588697, 0.11478297864752156, 0.13295215155397141, 0.049134104911770136, 1.504361316561699, 1.5685007891484668, 7.162757660661425, 5.414605225835528, 6.78586391891752, 20.89020722252982, 14.499612859317235, 22.484629460743495, 44.79873970576695, 52.112736633845735, 53.80549846376692, 55.84840781348092, 56.37207964488438, 53.865899154118125, 56.167128631046836, 54.34979602268764, 51.86317471095494, 46.67409324645996, 51.58396829877581, 53.27486106327602, 51.9167731148856, 51.75951106207711, 53.81932190486363, 52.123346533094136, 53.35240990774972, 47.80123349598476, 44.190258162362234, 41.47342218671526, 42.057164669036865, 44.9849305834089, 50.01232746669224, 48.785532678876606, 54.658667768750874, 52.00483110972813, 51.86807666506086, 50.63508408410208, 52.78319263458252, 50.09376035417829, 53.752535820007324, 44.25955254690987, 40.49140548706055, 42.41514975684029, 47.20412962777274, 49.94122655051095, 56.56430155890328, 49.83532905578613, 57.39274222510201, 35.30701058251517, 27.978078501565115, 52.03192561013358, 49.58224439620972, 56.14859431130545, 50.253172874450684, 53.19935498918806, 47.296637943812776, 47.87603432791573, 42.13976832798549, 38.94151251656668, 36.288634708949495, 46.20510721206665, 53.36274882725307, 51.26556709834507, 51.21325758525303, 53.02740791865757, 53.90625081743513, 50.38582093375069, 49.91804041181292, 45.350430147988455, 40.65919058663504, 39.015545572553364, 39.957863739558626, 44.920204639434814, 46.69622325897217, 52.01985311508179, 49.17859922136579, 48.06609187807356, 48.12065608160836, 46.30686705453055, 53.195630754743306, 52.29514421735491, 49.511428356170654, 50.530753408159526, 52.755361625126426, 50.65500109536307, 44.114342144557405, 27.91242844717843, 20.718659673418315, 33.637111800057546, 10.13428463254656, 7.863621149744306, 5.753696858882904, 4.6408412371362955, 6.055922218731471, 2.378264371837888, 0.6745123373610633, 0.015447204234078526, 0.03929539124614426, 0.08730321962918554, 0.6846923168216432, 6.5493468046188354, 33.784253801618306, 48.04841218675886, 37.58303199495588, 18.44799358504159, 22.62187201636178, 43.87109613418579, 43.217114312308176, 51.99416562489101, 46.96177646092006, 14.026158264705114, 0.24707327357360295, 0.014730184405509914, 0.041908334608056715, 0.05726775846311024, 0.0385664207195597, 0.05132555928347366, 0.03404568794316479, 0.02959425394822444, 0.02235184087684112, 0.019270282571337054, 0.08354398634816919, 0.05325909910191383, 0.07030566635408572, 0.03545016043686441, 0.019489247518192445, 0.021473826740735343, 0.0251033818016627, 0.05079239699989557, 0.04558403683560235, 0.008913111324155969, 0.01433595216700009, 0.016834994944344674, 0.054929883019732575, 0.06715347764215299, 0.04069523952369179, 0.015238822737176503, 0.01868533619147326, 0.041369893322033544, 0.06402071538780417, 0.025404598763478652, 0.012525960852924203, 0.03087657656786697, 0.06941599159368447, 0.047176748514175415, 0.11555802848722253, 0.054090769296245914, 0.044506163602428775, 0.08747760312897818, 0.025881486745285134, 0.045284195603536706, 0.02708745721195425, 0.03875757421233824, 0.05233100229608161, 0.039138395206204483, 0.04216445782887084, 0.04314493753814271, 0.06949086114764214, 0.04742217463042055, 0.014823623766590441, 0.03769986364724381, 3.177567115851811, 46.55881568363735, 65.67412294660295, 59.921285493033274, 51.295117786952424, 49.07843746457781, 30.1983962059021, 32.408458369118826, 36.114234924316406, 47.44439833504813, 55.45553929465157, 21.131040470940725, 4.601810600076403, 0.2321115764124053, 0.08936630535338606, 0.122706517044987, 1.6136639714241028, 5.210855381829398, 8.45656304700034, 12.354673555919103, 11.727115733282906, 17.78188715662275, 11.389395935194832, 18.4583637714386, 35.848865849631174, 47.44807045800345, 56.09265089035034, 56.26888499941145, 57.95495918818882, 54.70216696602957, 57.25322239739554, 55.237313747406006, 54.16561664853777, 50.49628339494978, 54.729549816676546, 55.06435571398054, 53.23603800364903, 51.520072664533345, 54.05137089320591, 53.648149558476035, 55.88379151480538, 50.333806719098774, 47.32855796813965, 43.357658999306814, 44.700610297066824, 46.678025926862446, 50.8874009677342, 51.458938939230784, 56.07458209991455, 53.98576600211007, 51.886190618787495, 51.027855328151155, 52.97390678950718, 51.58188383919852, 54.735553060259136, 45.97500719342913, 41.81050361905779, 43.96290963036673, 49.560496534620015, 50.79689373288836, 57.270790917532786, 52.908354009900776, 56.832092080797466, 36.228463309151785, 30.740015234266007, 53.3440512248448, 50.75640310559954, 56.759160314287456, 51.98545258385794, 53.94784273420061, 48.67542804990496, 49.061824321746826, 43.13481984819685, 41.35466357639858, 39.26230737141201, 48.29348904745919, 54.11141722542899, 53.48752805164882, 51.62238488878523, 53.75990091051374, 55.26581873212542, 52.39905105318342, 51.36974491391863, 47.78687504359654, 42.78175408499581, 40.771574224744526, 42.008381366729736, 46.0618770463126, 50.91972051348005, 52.733950751168386, 50.664930071149556, 48.55338988985334, 48.998554025377544, 46.55463981628418, 53.85441378184727, 51.63806349890572, 51.43369265965053, 51.49809898648943, 55.874800545828684, 53.2178441456386, 45.02494525909424, 28.948116506849015, 22.430197272981914, 22.87232330867222, 12.405883516584124, 9.451700551169258, 10.35333788394928, 13.576974596296038, 8.729278104645864, 5.175540728228433, 2.6315883100032806, 0.7711328470281192, 0.17365190333553723, 0.01095809882307159, 0.8010872368301664, 7.886321783065796, 33.30399431501116, 43.655656814575195, 36.755571024758474, 22.548778704234532, 27.514267138072423, 49.70938948222569, 48.986085483006065, 58.16936322620937, 53.09032733099801, 17.38204438345773, 0.3171096497348377, 0.05625317897647619, 0.0783694918666567, 0.07309253859732832, 0.052558922208845615, 0.04226000573752182, 0.023291253950446844, 0.020989300150956427, 0.02723654322991414, 0.03363186639866658, 0.07294508615242583, 0.031533632560500076, 0.08487585559487343, 0.02211021286036287, 0.03196298577157514, 0.04485434027654784, 0.02589612953098757, 0.03624779870733619, 0.012034607352688909, 0.016346673647473966, 0.05338822092328753, 0.0149370035755315, 0.0686728668266109, 0.04687652051714914, 0.10344590699034077, 0.018310313279341375, 0.1295909197734935, 0.11250535372112479, 0.14444654834057602, 0.09502925005342279, 0.12290768910731588, 0.1279976652669055, 0.15561290058706487, 0.10873641738934176, 0.23508423832910402, 0.17741788125463895, 0.10142971482127905, 0.25479217938014437, 0.13536789906876429, 0.12855896300503186, 0.1976285624716963, 0.11792961694300175, 0.163921643314617, 0.16481356402593, 0.19786178852830613, 0.16224179416894913, 0.14266983153564589, 0.11971017425613743, 0.1234009297830718, 0.11259208406720843, 4.459569684096745, 55.49578673498971, 73.42750658307756, 68.58340317862374, 58.041957582746235, 56.9218419619969, 31.58574996675764, 51.04790435518537, 53.697888238089426, 53.37977191380092, 59.79762145451137, 23.930624280657085, 6.232751701559339, 0.3719224956418787, 0.30356375660215107, 0.1787227312369006, 3.059975368635995, 7.670905913625445, 17.295643533979142, 18.085556438991002, 15.589572429656982, 28.234513929912023, 23.190625497273036, 29.093964406422206, 46.42685202189854, 53.049534457070486, 58.45090075901577, 57.97991711752755, 57.54928513935634, 54.24955783571516, 58.77882099151611, 59.08821732657296, 56.44822147914341, 51.83244282858712, 55.722186837877544, 58.212473324366975, 52.87459618704659, 52.9124812398638, 54.93434797014509, 56.13359662464687, 58.13316658564976, 51.879826068878174, 48.67861727305821, 45.36948905672346, 46.19879477364676, 49.46736288070679, 54.556442396981375, 53.48025328772408, 59.16459887368338, 54.67839370455061, 52.952968393053325, 52.302669116428916, 53.67202704293387, 52.41834272657122, 57.76337998253958, 48.94328457968575, 44.37039368493216, 46.27697243009295, 49.99924053464617, 53.325322355542866, 58.841653551374165, 55.40022815976824, 56.978417669023784, 38.28952482768467, 33.97402647563389, 53.79111221858433, 52.72865274974278, 59.32078742980957, 54.123180525643484, 56.705666133335654, 50.66928311756679, 51.70942497253418, 45.68870319638933, 42.79915237426758, 40.846340315682546, 50.408781255994526, 57.11209058761597, 55.361370359148296, 52.00948987688337, 54.45859786442348, 57.19055312020438, 55.910806110927034, 54.98635523659842, 50.730889320373535, 44.85063927514212, 42.11974014554705, 43.441763469151084, 48.327813148498535, 51.93388652801514, 56.204225063323975, 50.93417624064854, 49.13228252955845, 50.05020557131086, 49.11852509634835, 55.0920547076634, 53.444574287959504, 50.4556815964835, 52.99030801228115, 56.47122001647949, 55.940214361463276, 49.06737245832171, 32.318100520542686, 24.450676100594656, 45.65146085194179, 17.20773318835667, 17.840116534914287, 16.49238313947405, 13.492854493004934, 16.8600001675742, 8.829729080200195, 3.068818688392639, 0.80996692606381, 0.42417218908667564, 0.19112312155110495, 1.18388922725405, 8.879101242337908, 43.48909459795271, 60.072311537606375, 49.32819741112845, 26.76081143106733, 32.25108167103359, 53.995514324733186, 57.104551792144775, 64.38735825674874, 62.601650374276296, 23.07080728667123, 0.7835588316832269, 0.17379260435700417, 0.15934495175523417, 0.18169037199446134, 0.11781198611216885, 0.23049460032156535, 0.07114449848553964, 0.0920464236821447, 0.09632801357656717, 0.1659097509192569, 0.24520955500858171, 0.1677140433873449, 0.20876577842448438, 0.11074418893882207, 0.14428988817547048, 0.09849909493433577, 0.11792330656732831, 0.09540393030537025, 0.13140805012413434, 0.08060789068362542, 0.1310617122799158, 0.06785195480499949, 0.15320657113833086, 0.13661290226238115, 0.1268399352473872, 0.127257926389575], [0.06306690549744026, 0.03802012199802058, 0.026835573138669133, 0.009647230235194522, 0.025569258856454065, 0.004547118458763829, 0.04339474359793322, 0.07130430705313172, 0.020730357617139816, 0.017998528134609972, 0.038584069415394745, 0.03670099224629147, 0.007794660000529672, 0.05097764723801187, 0.00903542319844876, 0.03649043943732977, 0.012717977781513972, 0.04351704614236951, 0.04547059256583452, 0.03774217709100672, 0.06068747317684548, 0.04705562322799649, 0.01609038418558027, 0.09716477617621422, 7.002508316721235, 50.313698632376536, 57.829651900700156, 52.47180216653006, 43.52565949303763, 28.991551433290752, 20.055872746876307, 44.91251993179321, 47.795664514814106, 59.60535090310233, 27.73115168298994, 10.219605037144252, 1.0089891723224094, 0.01930201765415924, 0.013650049954386694, 0.30797474990998, 0.7032154000231198, 4.3705359016145975, 4.507261250700269, 7.483430487768991, 8.615483113697596, 16.76670323099409, 10.81008814062391, 33.983618463788716, 46.23739896501814, 49.53072002955845, 59.40578474317278, 55.308470249176025, 56.23742355619158, 50.12775788988386, 55.06850726263863, 51.04082761492048, 50.06912899017334, 47.31093038831438, 55.18262447629656, 55.36946848460606, 54.14772156306675, 54.11660058157784, 55.855727740696494, 51.772789069584434, 50.98174360820225, 44.667158194950645, 42.497225352696006, 43.224392550332205, 45.76339633124215, 47.103686468941824, 50.038741043635774, 52.43596683229719, 53.96146467753819, 51.08258976255144, 50.6149343081883, 50.32823773792812, 54.5244494165693, 51.894917556217735, 53.347257818494526, 41.332398074013845, 39.04501288277762, 41.104212284088135, 47.2250645501273, 51.03133290154593, 57.280153615134104, 50.74139847074236, 57.94089950834002, 38.25142438071114, 27.442792756216868, 52.85052415302822, 49.78150136130196, 52.960472447531565, 49.372158663613455, 54.58334582192557, 49.64042166301182, 52.456620352608816, 51.3661561693464, 48.280923230307444, 36.56031622205462, 39.87600701195853, 49.67027459825788, 52.0960887500218, 51.2139002936227, 50.68966218403408, 51.23706211362566, 53.29719257354736, 49.59487622124808, 46.97682278496878, 42.95461484364101, 38.08669301441738, 38.7349773134504, 44.614258084978374, 48.96301051548549, 50.83472320011684, 49.273862498147146, 48.004742758614675, 53.14155987330845, 51.88217108590262, 50.33921589170183, 50.68479149682181, 53.488024847848074, 49.74802841459002, 51.70631912776402, 52.17099380493164, 54.45500564575195, 41.005718094961985, 44.244360310690745, 27.53216396059309, 18.326976810182842, 14.218031900269644, 4.572077521256038, 15.041840723582677, 7.223654278687068, 5.850326759474618, 0.9579373917409352, 0.7370039469429425, 0.06220541029636349, 0.1056301315714206, 0.05320327602592962, 2.186555973121098, 14.485336916787283, 44.655172552381245, 39.97663082395281, 21.257112060274395, 19.057948146547588, 32.327782835279194, 38.3670563016619, 43.515803473336355, 45.85206576756069, 21.757771457944596, 1.4214182815381458, 0.06323037136878286, 0.0218560200716768, 0.08895286718117339, 0.04156106717086264, 0.016495741005720835, 0.0026268883167566465, 0.020139009259375076, 0.009983860787802508, 0.023224257099043046, 0.0835392637444394, 0.010939779225736856, 0.03724770826686706, 0.029438241784061705, 0.013551219632583005, 0.06559058079229933, 0.0588072594255209, 0.03206546491544161, 0.08464219527585165, 0.014578253629484346, 0.03849866560527256, 0.051302299103034396, 0.014167296350933611, 0.07238617007221494, 0.05350692044677479, 0.01845868174651904, 0.02695589605718851, 0.014878573228738137, 0.010587834985926747, 0.011866369683827673, 0.02231209399178624, 0.08531648945063353, 0.022205966025856987, 0.009523860694441413, 0.04387296150837626, 0.011114546097815037, 0.01632973232439586, 0.02161959811512913, 0.04400028521195054, 0.030049388097333055, 0.043681950507951636, 0.0335655429932688, 0.016786267648317983, 0.024446125641199093, 0.05719529092311859, 0.057256786551858695, 0.02868835541552731, 0.043352521756397824, 0.042536495186920674, 0.008184315520338714, 9.802550707544599, 59.71207523345947, 64.60012599400112, 59.476781436375205, 48.58745690754482, 40.41969312940325, 22.95493391581944, 36.43096855708531, 51.01550490515572, 60.80602741241455, 35.410691601889475, 10.515873619488307, 1.1220120447022575, 0.09612443950027227, 0.02577171165363065, 1.2356901104961122, 4.177755960396357, 7.268745481967926, 13.30020352772304, 7.749671561377389, 10.7969525711877, 12.790210093770709, 11.293491687093463, 25.5037659236363, 44.13229628971645, 53.2395989554269, 59.88241727011544, 57.151705741882324, 56.169247831617085, 51.42960711887905, 55.58869457244873, 54.69630963461739, 51.827235153743196, 49.430846623011995, 56.33399656840733, 55.95494106837681, 54.203633717128206, 53.50593382971627, 55.22365706307547, 53.322723729269846, 52.6395594733102, 47.80685111454555, 44.66176291874477, 45.306267397744314, 47.31576633453369, 49.559971945626394, 51.958101000104634, 52.43166937146868, 55.35184437888009, 52.12725142070225, 51.61101763589041, 51.172304902757915, 54.56160143443516, 53.07276228496006, 55.483676024845664, 43.52555874415806, 40.572987760816304, 41.57299682072231, 48.45699405670166, 52.39088691983904, 58.58718272617885, 52.588212285723, 58.524628094264436, 39.56178167888096, 29.362743309565953, 53.53921570096697, 50.76632513318743, 55.98243161610195, 52.319452490125386, 55.73022242954799, 52.377126012529644, 53.89541162763323, 52.83943830217634, 48.092397757938926, 38.8277496610369, 41.75288915634155, 51.093380314963206, 54.00272308077131, 51.417753492082866, 50.77812664849417, 52.137013639722554, 54.61464745657784, 51.62398297446114, 49.14284726551601, 45.439440046037944, 39.821467127118794, 41.23594318117414, 47.551991190229145, 50.190969126565115, 51.99268218449184, 50.669602734701975, 49.03386129651751, 54.123840604509624, 53.36377716064453, 52.98578126089913, 52.50353806359427, 52.24256025041853, 49.98506620952061, 53.629180976322715, 52.65759352275303, 54.043939794812886, 39.35464545658657, 35.423212255750386, 22.52291750907898, 11.834586126463753, 17.655991009303502, 11.71541496685573, 9.145022698811122, 7.35825434752873, 7.932139073099409, 3.900777748652867, 1.3715900353022983, 0.07005680006529603, 0.1296127007475921, 0.12354153580963612, 2.642554087298257, 17.714687653950282, 40.45218290601458, 37.23684842245919, 22.120886053357804, 25.14843852179391, 38.69108206885201, 42.77174520492554, 49.287418433598106, 52.40917805262974, 28.256185361317225, 1.8069041222333908, 0.03976253207240786, 0.02849897968449763, 0.06213704789323466, 0.05058627163193055, 0.01963652524032763, 0.05091772581051503, 0.052717974209891896, 0.06419414215322052, 0.031961177475750446, 0.016639519183497344, 0.04903888609260321, 0.04200464586860367, 0.04759571335411497, 0.04289105687556522, 0.024527227539303045, 0.01701856411195227, 0.02860746725595423, 0.035264631999390464, 0.03636668822062867, 0.04550236157540764, 0.027716160618833134, 0.0469400992483965, 0.04025875151689563, 0.01928073201062424, 0.037026088551751206, 0.14276294011090482, 0.13185645320585795, 0.059170445294252465, 0.04406027449294925, 0.08366870786994696, 0.1316294561007193, 0.1262311671993562, 0.09637616920684065, 0.17872240554009164, 0.11137752673987832, 0.1931267540369715, 0.14056840858289174, 0.19021383034331457, 0.10371879341879062, 0.11660058397267546, 0.12544114887714386, 0.11044603386627776, 0.13480559709881032, 0.0980582507327199, 0.12204862306160585, 0.1441587952098676, 0.15947524404951505, 0.10613036794321877, 0.12574232343052114, 14.568743961197988, 71.72387777056012, 71.03198310307094, 66.04394776480538, 55.72779056004116, 41.13593775885445, 29.56202459335327, 58.421982356480186, 56.73417806625366, 68.9957092830113, 34.820709637233186, 13.834376692771912, 1.2587936307702745, 0.18808935077062675, 0.10897250007838011, 1.3083251672131675, 3.90996196440288, 12.85928474153791, 14.35163881097521, 17.35033975328718, 22.623053210122244, 30.88481569290161, 15.808397259031024, 38.67269018718174, 51.46265969957624, 56.357498850141255, 63.6367860521589, 57.68402460643223, 56.55250351769583, 50.4008081981114, 56.34374836512974, 55.96344566345215, 54.27378273010254, 52.13652726582119, 58.66032641274588, 58.352041789463584, 56.19512987136841, 54.674283845084055, 58.26591191973005, 55.545289175851, 55.86508001599993, 48.10298681259155, 47.799659729003906, 48.15893718174526, 50.48614249910627, 51.87983996527535, 53.97433621542794, 55.53392539705549, 57.28737626756941, 52.93504898888724, 52.30353764125279, 51.89921849114554, 56.35614047731672, 56.95354311806815, 58.526788984026226, 46.46956607273647, 42.57621247427804, 43.58457326889038, 50.02841254643032, 54.54899392809187, 61.05890710013253, 55.081014020102366, 59.85857800074986, 41.29268911906651, 33.90855360031128, 54.77636677878243, 52.78268541608538, 56.352301597595215, 54.833543504987446, 57.508183070591514, 53.5262051991054, 56.82123899459839, 54.61088153294155, 51.08763068062918, 40.46994250161307, 43.15719652175903, 53.86837271281651, 55.32435730525425, 53.298616954258506, 50.327848638807026, 53.3305995123727, 57.091621194567, 54.668718338012695, 51.2916784286499, 46.81310238157, 41.03984417234148, 44.51060485839844, 49.936689376831055, 53.78376449857439, 53.29445845740182, 51.811921324048726, 49.37874902997698, 56.4213284764971, 55.39622252328055, 55.14274181638445, 52.9963355745588, 56.23407799857003, 49.94823728288923, 55.23741797038487, 54.07919495446341, 58.55077416556222, 42.088653905051096, 55.01315791266305, 36.493102822984966, 26.35149131502424, 29.097775493349346, 13.139554228101458, 28.335549422672816, 16.84035587310791, 15.541897365025111, 4.999644475323813, 1.3752339312008448, 0.16026919787483557, 0.33871124631592203, 0.25406576693058014, 3.177292444876262, 19.954152856554302, 57.391967500959126, 51.220549719674246, 29.533321584974015, 27.85478445461818, 44.635901723589214, 50.011455467769075, 56.82487637656075, 58.73876462663923, 36.00373077392578, 3.2223124291215623, 0.1904191550399576, 0.15907224853123936, 0.29394929536751335, 0.1256809974355357, 0.14697504123406752, 0.12690231975700172, 0.11374262161552906, 0.13419279855276856, 0.09864550243530955, 0.15210967856858457, 0.13900300115346909, 0.11024414255682911, 0.07442877082420246, 0.05194823390671185, 0.21954571854855331, 0.12498947525663034, 0.1080167360071625, 0.16435482007052216, 0.12571014729993685, 0.08691438513674907, 0.12986248305865697, 0.0959185923316649, 0.1538802342755454, 0.11241076593952519, 0.19557631973709377], [0.031530935383800945, 0.021548141592315266, 0.043882888475699086, 0.037616946667964966, 0.037377562906060896, 0.064964516886643, 0.04225893025951726, 0.01533214165829122, 0.02844410146852689, 0.00457450540436964, 0.014091792366733509, 0.08486261059130941, 0.03332217283813017, 0.022887110011652112, 0.05824480139251266, 0.026122400603656257, 0.042849421966820955, 0.015715257796858038, 0.06278635162327971, 0.038265934879226346, 0.043288769998720715, 0.07313258573412895, 0.14901425609631197, 1.4772546568087168, 23.65658038003104, 48.02337782723563, 52.187905720302034, 46.54660769871303, 35.025021416800364, 17.443473407200404, 37.92993818010603, 55.45531347819737, 52.48371137891497, 44.30668912615095, 14.12613068308149, 4.658257765429361, 0.007629132230899164, 0.07490295823663473, 0.05220877439049738, 0.7841375949127334, 3.2725563730512346, 5.951824307441711, 9.36379281112126, 7.9718011277062555, 12.312632611819676, 16.631234203066143, 21.763006925582886, 32.35564511162894, 49.65631914138794, 57.43745040893555, 55.00523696626936, 55.39051110403878, 53.53946236201695, 54.24490949085781, 54.38558619362967, 52.34325354439871, 49.64516380855015, 47.110255990709575, 51.73553282873971, 53.293225152151926, 55.76165607997349, 55.08241408211844, 51.32406050818307, 51.417461667742046, 45.87338631493704, 42.31727048328945, 41.53340251105172, 45.98095832552229, 47.48214094979422, 50.06214952468872, 52.04272658484322, 53.87656463895525, 51.99432890755789, 49.818292072841096, 49.159863403865266, 52.152396951402935, 52.12030669621059, 50.302404335566926, 44.59269782475063, 38.57300785609654, 41.040017877306255, 40.38596657344273, 44.43174975258963, 47.68026883261544, 53.53410530090332, 50.92926386424473, 55.23167528424944, 38.571729387555806, 27.23382568359375, 52.87932096208845, 49.15116078513009, 55.86363826479231, 50.42228855405535, 56.046063218797954, 51.540660176958355, 51.65947437286377, 50.509151458740234, 52.73321424211775, 42.90092263902937, 37.59686238425118, 43.65127944946289, 51.302177156720845, 51.62242310387747, 48.08890628814697, 49.50497347967965, 50.75372804914202, 50.560561180114746, 49.891849177224294, 43.48067685535976, 41.603134632110596, 38.23617308480399, 42.23178332192557, 46.930391447884695, 50.06845848900931, 48.12847975322178, 49.97917761121477, 50.836321285792756, 50.30548933574131, 50.62160805293492, 51.3908257484436, 52.02875375747681, 51.12772178649902, 51.12676293509347, 49.93557071685791, 50.892375877925325, 44.31693077087402, 38.83673368181501, 32.46195602416992, 19.15018027169364, 10.326721940721784, 11.290702853884016, 12.65505199772971, 4.347614662987845, 3.3831695233072554, 4.359607253755842, 1.7469787320920398, 0.18586337592984947, 0.0764155485002058, 0.09382554250104086, 0.13734364376536437, 6.245626713548388, 31.336497238704137, 44.73937777110508, 27.08804726600647, 12.744611671992711, 17.024806227002824, 31.822923251560756, 43.48797246388027, 43.88040672029768, 39.312136377607075, 6.996731758117676, 0.14485208157982143, 0.03297243553346821, 0.010327249549196234, 0.05327542465446251, 0.01376473339873233, 0.03342499803485615, 0.07398815053914275, 0.010065456320132529, 0.0224105375486293, 0.014848140933151757, 0.03778242778831294, 0.06146653315850666, 0.003967393405868539, 0.0906903443059751, 0.024243150372058153, 0.04959080647677183, 0.06319534539112023, 0.03540640849886196, 0.04236205740432654, 0.07447183744183608, 0.033199615843061886, 0.021802083323044435, 0.01062210270070604, 0.02697862358763814, 0.025865653130624975, 0.0517018612341157, 0.1264643254024642, 0.07968307459460837, 0.040475370428924046, 0.02300433881048645, 0.012037231586873531, 0.050592174886592796, 0.03999203297176531, 0.04421721964276262, 0.01101532731471317, 0.020503433454515677, 0.07087958484355893, 0.010177220367560429, 0.02949775948322245, 0.07577885195080723, 0.02515639234999461, 0.035000854903565984, 0.018363583367317915, 0.020398102767233337, 0.025783017743378878, 0.09589782237474408, 0.0367097623114075, 0.06156369258782693, 1.843935306583132, 32.462206159319194, 55.92104080745152, 59.56799738747733, 51.94357231685093, 43.72083439145769, 21.81148624420166, 25.560916594096593, 55.48488848549979, 56.17895793914795, 49.47458553314209, 17.16886670248849, 4.552662517343249, 0.09864969578172479, 0.019047278644783155, 0.11383031548133918, 2.0301253157002583, 6.225983721869333, 8.598606807844979, 11.309903332165309, 10.270099333354406, 6.772740943091256, 12.894580721855164, 21.1267569065094, 36.29711845942906, 52.13356038502285, 59.31681306021554, 56.823524951934814, 55.942819935934885, 53.30033663340977, 53.853517464229036, 55.442104952675955, 53.733094760349815, 50.37754562922886, 50.6316169330052, 53.71254893711635, 54.882469245365684, 56.5454615184239, 55.92491790226528, 53.92528888157436, 52.79543536049979, 47.90303502764021, 43.921880517687114, 43.38939489637102, 48.124015535627095, 49.973306383405415, 52.17054912022182, 53.52519423621041, 54.7474171093532, 52.96588509423392, 50.63023771558489, 50.303991998944966, 53.32009383610317, 53.37864630562918, 52.20905603681292, 46.86601638793945, 40.4937470299857, 41.87263788495745, 42.640729972294395, 46.455541133880615, 49.39146075929914, 54.630086353846956, 52.45352840423584, 56.40018858228411, 38.46287543433053, 29.04167400087629, 54.472459520612446, 48.82212536675589, 56.70138256890433, 51.43701042447771, 56.82498754773821, 52.487807341984336, 53.362210341862266, 51.59228529248919, 54.24482263837542, 43.627700737544465, 40.344489301954, 45.160438605717246, 54.84894071306501, 53.08746814727783, 47.88832916532244, 49.54391118458339, 52.43509830747332, 52.86709213256836, 51.651709760938374, 45.844686780657085, 42.7208183833531, 39.67082323346819, 43.30792031969343, 48.444608892713276, 51.31626115526472, 49.27403967721121, 50.775121552603586, 52.778978552137104, 52.68019253867013, 52.06337663105556, 53.5976813180106, 54.05014106205532, 52.71290118353707, 51.57126351765224, 53.38453490393502, 52.306125845227925, 47.709114279065815, 38.23010035923549, 29.389511244637625, 14.521147063800267, 12.461067846843175, 12.212060911314827, 14.879054852894374, 10.187077045440674, 6.238525220326014, 7.326163223811558, 3.5256818532943726, 0.6732369629400117, 0.08058748713561467, 0.11548466528100626, 0.22929484184299195, 7.009265874113355, 33.57618652071272, 47.63568571635655, 25.045825787952968, 16.61256786755153, 24.380726848329815, 39.204036303928916, 49.20623568126133, 51.00579827172415, 46.62609509059361, 9.528540679386683, 0.052034696231463125, 0.014045959022561354, 0.02099492690259857, 0.03277133471731629, 0.021857914880716374, 0.026213420987395302, 0.058768867914165766, 0.043298045572425635, 0.030840851699135134, 0.017025128938257694, 0.010592036814029728, 0.0960010275510805, 0.059771986944334846, 0.04876516506608043, 0.08073601845119681, 0.06595581583678722, 0.02174261142499745, 0.0525613411861871, 0.02552359684237412, 0.050900945639503856, 0.047024732921272516, 0.029939967540225813, 0.05072618894545095, 0.04307042421506984, 0.010980891662516763, 0.13061733969620296, 0.1954385499869074, 0.1547406166791916, 0.09471132247043507, 0.10275270204458918, 0.08009047380515508, 0.13095012041074888, 0.13453378954104014, 0.0762895852593439, 0.14170237630605698, 0.10341438903872456, 0.19062696317476885, 0.1336600671389273, 0.17602471315435, 0.06997718755155802, 0.07382229622453451, 0.14163567631372384, 0.1662225012800523, 0.11632021330296993, 0.14006862682955606, 0.13336141673581942, 0.13526633594717297, 0.17641075886785984, 1.9676492852824075, 43.35249648775373, 63.99855095999581, 68.79100840432304, 58.92192608969552, 49.479966912950786, 26.664118562425884, 52.677267347063335, 64.73078686850411, 60.42225061144148, 52.88219404220581, 19.361970049994333, 5.884223980563028, 0.19163077431065695, 0.2668866589665413, 0.16585477601204598, 2.7422212191990445, 10.50845468044281, 15.530368566513062, 17.36826436860221, 18.323940447398595, 24.933593273162842, 25.10645750590733, 26.07576768738883, 37.7222843170166, 55.83185373033796, 61.57702037266323, 58.06786741529192, 56.178697381700786, 53.95601381574358, 53.86229303904942, 57.081876346043174, 56.14319208690098, 53.950305870601106, 51.63809823989868, 55.3360823903765, 56.627839360918315, 58.12528385434832, 59.256898743765696, 56.16698619297573, 55.1776773588998, 49.32512283325195, 45.2853741645813, 45.200477600097656, 50.08439418247768, 52.239350182669504, 53.18231800624302, 54.60554184232439, 56.12337235042027, 53.79014294488089, 51.649006911686485, 50.24713488987514, 55.44764266695295, 56.59265715735299, 54.5967697416033, 48.563200746263774, 42.53014244352068, 44.22914375577654, 44.12903411047799, 47.89304004396711, 50.76195471627371, 57.12872804914202, 56.32236875806536, 57.438082695007324, 41.78253017153059, 33.199191161564414, 54.558672768729075, 50.556555543627056, 57.990523542676655, 53.34729255948748, 58.64938299996512, 55.54414619718279, 53.89735017504011, 53.76012325286865, 55.33022505896432, 48.0480751991272, 42.61068596158709, 47.36791951315743, 56.43397419793265, 54.62476750782558, 47.696378231048584, 49.57552201407296, 52.340887682778494, 54.16304928915841, 53.359107971191406, 48.569280420030864, 45.61152260644095, 41.7591564314706, 46.523310388837544, 52.27001953125, 52.742997305733816, 50.36431278501238, 50.11777680260794, 55.13231604439871, 55.293361391339985, 56.08461529867989, 55.29678337914603, 54.74522147859846, 54.224745818546836, 53.82492562702724, 51.09526327678135, 54.789592674800325, 48.081190313611714, 45.72906528200422, 42.685062953404014, 27.430570874895366, 15.574892623083931, 20.41866077695574, 19.35639238357544, 14.918289593287877, 12.92996268612998, 11.660184604781014, 4.277362295559474, 0.6548474154302052, 0.38131339315857204, 0.099703358885433, 0.4528906137815544, 8.489118831498281, 39.88673503058297, 56.21062088012695, 37.70234646115984, 20.6592994758061, 26.959708826882498, 44.21822118759155, 55.70303412846157, 58.65848514011928, 53.86182403564453, 12.534086465835571, 0.3038534096309117, 0.10437915726963963, 0.0999359403337751, 0.13694113679230213, 0.09782174735197, 0.16160572187176772, 0.11933951771685056, 0.1291001353945051, 0.058544992070112906, 0.1506437443728958, 0.11688242027802126, 0.1593395099043846, 0.23237883778555052, 0.2197482069688184, 0.194359190762043, 0.12438051721879415, 0.125002815255097, 0.18870305855359348, 0.09771205538085528, 0.17455560341477394, 0.07107657713017293, 0.11079498407031808, 0.11852614421929632, 0.08008775287973029, 0.11711317646716322], [0.03301892536027091, 0.009526267797420067, 0.01859653292090765, 0.004957672008978469, 0.026060104303594147, 0.04850007500499487, 0.015927089644329886, 0.055797410397125144, 0.015169993841222354, 0.00936729128339461, 0.038926549788032255, 0.029716587026736567, 0.035545491214309416, 0.04604086732225759, 0.06644042554710593, 0.019453693979552815, 0.032883761184556146, 0.03357691863285644, 0.06383994687348604, 0.032510074986410994, 0.05021060750420604, 0.10021865873464517, 0.20376374040331158, 4.288345226219722, 36.41880573545183, 50.593255928584504, 43.6624938419887, 41.32677698135376, 32.00325679779053, 24.958565098898752, 60.44501985822405, 59.18680531638009, 62.65484578268868, 28.407895803451538, 9.274772490773882, 0.8169818925006049, 0.0854005870808448, 0.06583044292139155, 0.08911880970533405, 1.944533062832696, 5.954111133302961, 5.460322201251984, 14.210103137152535, 3.6754233496529713, 4.98865372794015, 15.837211438587733, 29.640164034707205, 47.55182443346296, 53.35061379841396, 57.98048686981201, 56.53176661900112, 57.12580633163452, 55.72621331896101, 53.238914557865684, 52.475175516945974, 54.140366894858225, 46.69908939089094, 49.0155736378261, 52.885011536734446, 52.661446298871724, 51.57716253825596, 52.23026541301182, 50.39163657597133, 44.13838985988072, 42.51812553405762, 40.81756782531738, 44.94485684803554, 46.198231969560894, 49.646668093545095, 50.01336622238159, 51.94949565614973, 51.15341969898769, 50.23727192197527, 49.78853988647461, 50.88492393493652, 50.822754928043906, 49.41838155473982, 44.13496092387608, 38.09926230566842, 37.932720933641704, 39.49279301507132, 40.798713888440815, 44.58663552148001, 48.07737922668457, 52.16770383289882, 49.50620331083025, 56.162129402160645, 39.92304631641933, 24.81479471070426, 50.83827025549752, 46.51456955501011, 50.52091128485543, 49.330587591443745, 51.36894934517996, 48.42554998397827, 52.04438720430647, 50.297849791390554, 52.22202832358224, 48.93439088548933, 37.760318756103516, 38.20567396708897, 51.033285345349995, 51.705200467790874, 51.51785618918282, 48.11563948222569, 52.67604446411133, 50.589111328125, 51.95788560594831, 46.56118849345616, 43.64855922971453, 37.586603369031636, 39.991607666015625, 45.33498430252075, 51.44796078545706, 51.32399102619716, 51.23743731634957, 50.470057419368196, 49.89239461081368, 47.08746937343052, 48.3737268447876, 48.24364961896624, 53.81470135280064, 52.65029444013323, 51.392284870147705, 51.39006839479719, 51.21210071018764, 44.90437316894531, 32.332267897469656, 18.7892039843968, 27.159064803804668, 14.322373867034912, 5.241757495062692, 6.182335572583335, 5.816773908478873, 4.060621491500309, 2.910265790564673, 0.26070259937218254, 0.11901090320731912, 0.10957777367106505, 0.11980948464146682, 1.354965167386191, 14.467209935188293, 42.51335906982422, 46.818768637520925, 30.375113214765275, 15.72592908995492, 20.15006947517395, 33.85208906446184, 44.02852494376046, 38.740942341940745, 17.482263462884085, 0.29126468513693127, 0.03739725399230208, 0.03890866021226559, 0.057146280338721614, 0.02713522268459201, 0.024763700385977114, 0.07497801099504743, 0.02824677330707865, 0.03312836288075362, 0.04773369345015713, 0.031146100855299404, 0.022948707420645014, 0.019829685500423824, 0.03576120428208794, 0.045605797453650405, 0.020976061932742596, 0.010398543223605623, 0.020034455494689088, 0.02864130579733423, 0.019350168195420077, 0.03795270275856767, 0.07074756907033068, 0.019210583364058818, 0.06769595281886202, 0.015095792644258057, 0.024240931562547172, 0.03549824821363602, 0.12277602617229734, 0.03344809875956603, 0.03487708672348942, 0.03243656589516571, 0.04208688770553895, 0.03957857105082699, 0.009526344980778438, 0.024081233256895627, 0.08725236342953784, 0.010724947405313807, 0.020381120732054114, 0.034285105631819794, 0.028996895466532027, 0.021093056636995504, 0.027155838274796094, 0.06388608046940394, 0.013738253569629575, 0.05491427332162857, 0.029307708609849215, 0.0663786856457591, 0.14612597679453238, 5.609721064567566, 45.52252313068935, 58.9428471156529, 52.97026245934622, 47.10023321424212, 39.54134007862636, 25.035471235002788, 58.0694967678615, 62.25326074872698, 61.53325366973877, 32.89216068812779, 9.517108287130084, 1.045457009758268, 0.010573790159209498, 0.023067783531067625, 0.5273167586752346, 3.084804322038378, 7.985109533582415, 7.737383672169276, 16.157973289489746, 10.94687819480896, 8.472176517759051, 16.464626823152813, 31.07568618229457, 48.833329336983816, 54.3087842805045, 59.8909079687936, 56.92661884852818, 56.43943200792585, 56.26229810714722, 52.543333871024, 53.97064324787685, 56.18377651487078, 49.32598440987723, 49.78097677230835, 53.37521736962454, 55.93002135413033, 54.12208618436541, 53.92345455714634, 52.04125704084124, 47.126806599753245, 44.01362453188215, 43.71443510055542, 46.68831620897566, 48.39042336600167, 50.954093251909526, 51.60115466799055, 53.17656142371041, 51.61962297984532, 50.275139604296, 51.57327502114432, 52.4357271194458, 52.59705386843, 51.87347541536604, 47.307108879089355, 41.06085899897984, 40.28750365121024, 41.4045273235866, 42.259735924857004, 46.825063705444336, 49.687554768153596, 53.373271874019075, 51.19804103033883, 56.150793416159495, 39.22278601782662, 27.285322257450648, 50.76712417602539, 46.62937811442784, 52.29602663857596, 51.13485063825335, 51.2566317149571, 49.136677265167236, 52.218092169080464, 51.1047579901559, 54.85237659726824, 50.18769652502877, 39.92718396868025, 40.52661895751953, 51.94281496320452, 52.46820994785854, 51.67684139524187, 48.71858678545271, 52.712109088897705, 51.88917139598301, 52.495895045144216, 47.656776973179404, 45.566824844905305, 39.46277679715838, 41.22194603511265, 48.77436692374093, 53.3770204271589, 51.148278032030376, 51.03493206841605, 50.886400427137104, 50.45893682752337, 48.796361446380615, 50.068086760384695, 50.78457110268729, 54.94197709219796, 53.282865388052805, 51.367090702056885, 50.59067119870867, 51.800206661224365, 43.459842681884766, 34.35171318054199, 15.650018283299037, 15.0962781224932, 10.312538930347987, 7.232321287904467, 9.577005233083453, 7.751074228967939, 6.910788186958857, 5.178345194884709, 1.1565598994493484, 0.2859320512839726, 0.14421496433871134, 0.02348746422545186, 1.8739725862230574, 17.173037358692714, 40.23092099598476, 39.079482895987375, 29.459159987313406, 19.127463136400493, 25.051676171166555, 39.25925016403198, 49.555135999407085, 46.5201142174857, 20.87737216268267, 0.45195065279092106, 0.027781793614849448, 0.02975098875218204, 0.021422281828043715, 0.047460240444966724, 0.03479651069002492, 0.06280062121472188, 0.02758061815984547, 0.06110161702547755, 0.02222818974405527, 0.0386622095081423, 0.07552828253912074, 0.02567952758233462, 0.029421573571328605, 0.020669939162741815, 0.030630990995892456, 0.022212222118728926, 0.009032670890779367, 0.05329254409298301, 0.039274773959602625, 0.0235016269476286, 0.060738648287951946, 0.031560743427170176, 0.020507480915901915, 0.05906641909054347, 0.08503408317587205, 0.14008668943175248, 0.17558709877942288, 0.07042213689003672, 0.12555575344179357, 0.08772246606115784, 0.15232231787272862, 0.10299899668565818, 0.1366605218499899, 0.11812529287167958, 0.1858668771705457, 0.14213058618562563, 0.13376106029110296, 0.1520582591848714, 0.11199310727949653, 0.11429884391171591, 0.11751645697014672, 0.13012689458472387, 0.19493523985147476, 0.09998515447867767, 0.12243233461465154, 0.17726726005119936, 0.3090884972895895, 7.762605633054461, 53.566282408578054, 68.12659386226109, 58.84164660317557, 54.59835393088204, 42.776793071201865, 33.8023225920541, 72.33992590223039, 65.08821610042027, 68.8394581930978, 36.26802287782942, 12.764592954090663, 1.0722049687589918, 0.3171379310744149, 0.24730761242764338, 0.7496854407446725, 4.876190619809287, 13.666189466203962, 14.051545245306832, 24.716045175279888, 12.1022116286414, 11.218536257743835, 17.79945046561105, 35.03770535332816, 50.93964099884033, 57.91064705167498, 60.42960180555071, 59.329632486615864, 57.615411145346506, 56.22781419754028, 53.25899485179356, 54.609498841421946, 59.394229888916016, 51.496337618146626, 54.41783973148891, 57.410651206970215, 58.15676614216396, 54.90464094706944, 56.98215927396502, 55.31254536764962, 48.00850520815168, 47.08823367527553, 44.270218031747, 48.765980448041645, 50.25599731717791, 55.08498838969639, 54.00479016985212, 54.434306962149485, 53.538764068058555, 51.388202803475515, 50.97644560677664, 54.79229204995291, 54.05695724487305, 53.68148701531546, 48.72888401576451, 41.81721905299595, 42.07986790793282, 43.27149091448103, 45.54158551352364, 47.51566253389631, 52.306785924094065, 55.72956582478115, 54.4520457131522, 56.95087848390852, 40.81958627700806, 31.17357587814331, 49.350455965314595, 47.12698030471802, 52.367850167410715, 51.73318433761597, 52.076797076633994, 49.6469703401838, 52.42503036771502, 52.27461576461792, 56.46331296648298, 52.303013052259175, 41.69304084777832, 42.51038176672799, 55.073405742645264, 55.84511089324951, 52.99338606425694, 49.01366983141218, 53.62498426437378, 53.96252775192261, 55.28969274248396, 50.91239711216518, 48.7430305480957, 41.06563935961042, 43.78196464266096, 51.76193250928606, 56.188035760607036, 52.884556429726736, 53.439773082733154, 52.3519492149353, 53.609569685799734, 52.951495374952046, 52.36042601721627, 53.53118705749512, 59.832911355154856, 55.06644712175642, 52.57251283100673, 53.347719873700825, 54.63507168633597, 47.50754008974348, 36.85216488157, 22.43676332065037, 34.02311897277832, 22.047198670251028, 14.682247127805438, 16.840182168143137, 13.64454756464277, 11.726302794047765, 8.670260974339076, 1.8310659400054385, 0.3076820027615343, 0.4177731695984091, 0.3457300125488213, 2.3178823547703877, 19.460841178894043, 51.958924361637656, 58.25248452595302, 40.744681222098215, 24.803415298461914, 30.36317620958601, 46.75163861683437, 56.51459067208426, 53.564861501966206, 27.92487267085484, 0.8220497891306877, 0.22878835616367205, 0.10196785415921893, 0.11069478480411427, 0.06633350199886731, 0.14095203871173517, 0.12785214664680616, 0.12026778076376234, 0.09574362529175622, 0.09970954712480307, 0.13436302941824707, 0.15402970196945326, 0.1294053133044924, 0.12652418576180935, 0.0953142958294068, 0.09577206947973796, 0.07285093263323818, 0.08781844483954565, 0.10856687184423208, 0.11340404621192388, 0.10934025927313737, 0.20552748361868517, 0.1437484308012894, 0.128894444288952, 0.10737504544002668], [0.03532924549654126, 0.011628460039251616, 0.04329194214993289, 0.029102584081036702, 0.01815412299973624, 0.04869128956592508, 0.048101089628679414, 0.07746392581611872, 0.05216830995466028, 0.038675888774118254, 0.02433341079657631, 0.027640354686549733, 0.010596890883919383, 0.03787764321480479, 0.04309558768623641, 0.049579139067126174, 0.021578634956053326, 0.04196931455018265, 0.0202445757375764, 0.02081933900314782, 0.06640009342559747, 0.16872051438050611, 0.018812388481040086, 11.12463743346078, 47.54898262023926, 50.53274754115513, 49.716615608760286, 45.31954540525164, 26.78886651992798, 41.02517652511597, 54.78058433532715, 55.550444739205496, 47.58319902420044, 17.101641144071305, 4.0661757077489575, 0.05288556557414787, 0.071221831121615, 0.10423405934125185, 1.0369579515286853, 2.0367193732942854, 7.584591048104422, 6.57988326890128, 12.569685561316353, 13.523991976465497, 7.561420542853219, 21.666727474757604, 37.19013220923287, 51.18076433454241, 56.84286873681204, 58.533459254673545, 53.86824417114258, 54.77502230235508, 51.88585015705654, 51.99022947038923, 54.018589292253765, 53.579609053475515, 47.76196575164795, 43.287325859069824, 48.94260018212454, 49.97740929467337, 50.45179060527256, 45.64312301363264, 41.09759412493025, 41.7414003099714, 42.90767281396048, 45.33023868288313, 46.99485336031233, 47.8773683820452, 50.844596590314595, 52.25155816759382, 53.99497931344168, 50.723986285073416, 50.59276955468314, 49.40438788277762, 51.11802210126604, 49.07922608511788, 43.40349973951067, 37.76397350856236, 39.30880124228341, 38.25183432442801, 45.73861905506679, 47.85234791891915, 49.552255971091135, 47.38100297110421, 52.219961234501426, 49.706773485456196, 53.82845531191145, 42.822362831660676, 25.892809459141322, 50.086138180324006, 45.08789593832833, 46.56782749720982, 47.054295199257986, 49.851153578077046, 48.290091378348215, 46.51369060788836, 45.10620444161551, 51.11873776572091, 51.68779523032052, 41.83813313075474, 35.88612903867449, 44.486755166734966, 49.76531900678362, 50.87398052215576, 48.49818645204817, 49.94698313304356, 49.46570920944214, 49.93337856020246, 47.61715487071446, 44.52879524230957, 38.59665952410017, 38.22710221154349, 42.46506214141846, 47.61957631792341, 50.204611914498464, 52.275512082236155, 49.90871245520455, 46.251562867845806, 43.12701007298061, 47.38758986336844, 47.53463806424822, 50.433218070438926, 52.40625980922154, 52.030021803719656, 48.74560832977295, 51.55350739615304, 43.65391281672886, 43.63399233136858, 24.856266771044048, 22.621977976390294, 14.259880031858172, 11.665023156574794, 10.120226689747401, 5.035887147699084, 6.337464094161987, 3.9553193705422536, 1.357505385364805, 0.11682274990848132, 0.06164269442004817, 0.05851251059877021, 0.5677320414355823, 7.149433621338435, 33.71478223800659, 46.85258552006313, 31.631333623613628, 20.326525926589966, 17.818083797182354, 37.72880867549351, 43.546646526881624, 44.811479227883474, 27.45185147012983, 1.4343322685786655, 0.05869827991617577, 0.051331632171890566, 0.04029462905600667, 0.03618455585092306, 0.01075642294849136, 0.03813521171520863, 0.03445314143651298, 0.022047066695189903, 0.057337946125439236, 0.013869489027586366, 0.049562284257262945, 0.020776861014642885, 0.0650032205241067, 0.07475374838603394, 0.009444210013108594, 0.03576957740421806, 0.007334964399758194, 0.017482134147680232, 0.027143629733473063, 0.023750079330056906, 0.021507395564445426, 0.060037952315594466, 0.02742319125016885, 0.010365535887623472, 0.0188158456169601, 0.030233478040567467, 0.05811667362494128, 0.03955127697970186, 0.03475430920454008, 0.058402743988803456, 0.07518096760447536, 0.024449045038116828, 0.02683324915623026, 0.026106292182313542, 0.024738502988059605, 0.08942987729928323, 0.008242847647384872, 0.05016054179785507, 0.05223394125433905, 0.04342809698677488, 0.02188579418829509, 0.010549781893912171, 0.012146736960858107, 0.031381331982889345, 0.06222436856478453, 0.14829882234334946, 0.07145687565207481, 14.059500932693481, 54.76361683436802, 57.373829228537424, 56.29066065379551, 53.76625503812517, 33.06203372137887, 42.576674529484336, 60.7049936567034, 63.306788308279856, 56.433807441166465, 21.622696740286692, 4.380236889634814, 0.177718865818211, 0.07110956071742944, 0.0831790566444397, 2.8711719683238437, 4.153349544320788, 5.5017039350100925, 10.542830892971583, 14.3780289377485, 9.949308821133204, 12.697340471403939, 22.68105329786028, 38.03145483561924, 51.005996295383994, 59.12051255362374, 59.05934061322893, 56.51684883662632, 54.97340726852417, 53.07261984688895, 51.59537376676287, 54.430523668016704, 55.577671255384175, 50.296717235020225, 46.2507256099156, 51.27635070255825, 52.22401203427996, 52.23657785143171, 47.74366072246006, 44.18502269472395, 42.135755743299214, 44.13268191473824, 45.854820728302, 48.82476568222046, 50.11540399278913, 52.51603439876011, 54.170584610530305, 55.23266887664795, 50.790108816964285, 51.6792003086635, 49.75159978866577, 54.40012182508196, 51.4844457762582, 45.09387833731515, 39.3964284488133, 41.633300236293245, 39.755275113242014, 47.071050780160085, 48.60025201525007, 51.18564544405256, 48.96692929949079, 53.579042775290354, 50.7973175730024, 54.313731397901265, 43.27956819534302, 28.558973959514073, 50.83451475415911, 45.23790407180786, 48.322108677455354, 48.1441444669451, 49.90708310263497, 49.2054887499128, 47.54602268763951, 46.6061954498291, 52.607045378003804, 52.592725140707834, 43.227540084293906, 37.20767641067505, 46.39474092211042, 52.52305555343628, 53.22525092533657, 48.41066346849714, 50.153622559138704, 52.741812637874055, 52.53974512645176, 50.03028508595058, 47.15589870725359, 41.27556528363909, 40.12562799453735, 45.45281532832554, 49.4259272984096, 52.08190747669765, 53.339760712214876, 51.4197267804827, 48.30742713383266, 45.71451922825405, 47.696069036211284, 51.13256468091692, 52.7769045148577, 54.042223589760916, 52.808966977255686, 49.776821749550955, 51.144803932734895, 47.05581338065011, 42.831426756722585, 24.955862249646867, 16.74883941241673, 8.402046612330846, 10.02543762751988, 11.414012534277779, 7.174167037010193, 8.064553499221802, 6.805818276745932, 3.21524915099144, 0.5458956445966447, 0.22142045652227743, 0.09959664568305016, 0.4560588566320283, 8.455980266843524, 33.59713881356375, 51.54929331370762, 35.57612126214163, 22.857773780822754, 23.51034685543605, 41.032757009778706, 50.68744223458426, 50.77885620934622, 34.212495599474224, 2.014973900147847, 0.035889922375125546, 0.034735696988978555, 0.07491434405424766, 0.06395164730825595, 0.003231515392794141, 0.05658098942201052, 0.04602982077215399, 0.012596174808485168, 0.025855246099776456, 0.03137707756832242, 0.01440396173191922, 0.018918713222124746, 0.03834952021549855, 0.05819404697311776, 0.013669512035059077, 0.010170395153441598, 0.023009231047970907, 0.01855088278119053, 0.0340416676231793, 0.02289778845650809, 0.007521343550511769, 0.04543061328253575, 0.06980838160961866, 0.013973226005743657, 0.1413895988038608, 0.13515349557357176, 0.09524931253067084, 0.11026793877993311, 0.10870152711868286, 0.09342604143811123, 0.1419802363961935, 0.12152267699795109, 0.1479241217353514, 0.03863523434847593, 0.07032478068556104, 0.18836522953850882, 0.175057909318379, 0.10057585313916206, 0.16721384094229766, 0.13973923879010336, 0.11522618415100233, 0.21737792130027497, 0.11182510200887918, 0.08959850003676754, 0.13073141500353813, 0.23252244293689728, 0.2248607919152294, 18.108374323163712, 64.83321026393345, 64.23471328190395, 64.2008477619716, 57.2617860521589, 38.69173867361886, 51.37630748748779, 63.14106682368687, 60.02784306662423, 56.87632431302752, 23.359932252338954, 5.5458658167294095, 0.2285655252635479, 0.3630495917584215, 0.30899969062634874, 4.043488536562238, 7.481303470475333, 17.263636657169886, 19.09081138883318, 22.58544261114938, 22.70415084702628, 14.859820502144949, 25.609267371041433, 41.27937637056623, 55.845517362867085, 61.176686014447895, 61.42932251521519, 55.994896684374126, 56.90668099267142, 54.12065832955496, 51.55458089283535, 57.6705972126552, 59.00583948407854, 53.896151610783164, 48.30436297825405, 53.12650312696184, 53.719486713409424, 53.75477661405291, 50.1704545702253, 46.3134400503976, 45.919532775878906, 46.43067700522286, 50.07678937911987, 50.24645396641323, 52.53666707447597, 55.59342629568917, 56.168757983616416, 57.761872223445344, 52.86864505495344, 50.459628173283164, 51.231663363320486, 55.71716676439558, 54.31499597004482, 46.19487598964146, 42.54998302459717, 44.36942441122872, 43.1197179385594, 50.155769552503315, 51.603079319000244, 53.84208072934832, 51.11748708997454, 56.05446706499372, 52.98971046720232, 55.149193218776155, 45.357222012111116, 32.71767405101231, 50.955962317330496, 46.359120982033865, 48.29724454879761, 48.347219467163086, 51.91767985480172, 51.0486478124346, 48.16280732836042, 45.44407796859741, 54.19812379564558, 56.600963728768484, 46.35361453465053, 39.36435209001814, 48.21573870522635, 54.20235524858747, 55.39002473013741, 49.34691933223179, 50.47921167101179, 52.6812173979623, 53.49923229217529, 52.56563411440168, 48.13560165677752, 43.75845888682774, 41.24876955577305, 46.24062292916434, 52.19605595724923, 54.138744490487234, 56.976625033787315, 53.673489638737266, 51.393028327396934, 47.28830010550362, 50.70654630661011, 52.78660420009068, 56.04896061761038, 57.39390952246529, 54.98010533196585, 49.97620030811855, 53.61229337964739, 47.037101881844656, 47.46404784066336, 29.238606793539866, 30.500674111502512, 19.76292974608285, 19.009076254708425, 22.299852541514806, 13.621693202427455, 14.239502702440534, 7.92088212285723, 4.504977464675903, 1.1065952948161533, 0.30410995015076225, 0.21113188431731292, 1.1787412634917667, 9.888103008270264, 42.642171723502024, 55.875821931021555, 41.961936133248464, 30.305502687181743, 28.76352892603193, 49.208785670144216, 56.6575151171003, 57.60242496218, 40.222760336739675, 3.18124640413693, 0.13037329779139586, 0.12419290228613786, 0.13525253454489367, 0.12438504983271871, 0.11202533769288234, 0.09789139897163425, 0.12125244364142418, 0.09039727824607066, 0.11375480810446398, 0.09644399556730475, 0.09308948806886162, 0.11353408066289765, 0.1848021743020841, 0.249809913869415, 0.10929463457848344, 0.07956996959234987, 0.09473693038203887, 0.07533656246960163, 0.10352251359394618, 0.12205880108688559, 0.0975311172327825, 0.10221204534173012, 0.11011891891913754, 0.08274376964462654], [0.03386864797877414, 0.015179181205374854, 0.05445550222482, 0.06305492256901093, 0.02548492034631116, 0.06317694352141448, 0.06498810276389122, 0.08815708809665271, 0.026953690818377903, 0.007909675927034445, 0.037586656864732504, 0.047603282412247996, 0.07409191889954464, 0.013499046226830354, 0.029132293736828224, 0.030980344928268875, 0.019826435317684497, 0.03514835484591978, 0.06906457830752645, 0.061499048556600294, 0.023533116061506525, 0.030807776509651115, 0.5844416448048183, 22.76710500035967, 43.65344728742327, 43.73092664991106, 39.305754457201274, 24.357080391475133, 28.905612639018468, 38.22439936229161, 48.52535390853882, 35.75310925074986, 21.96382028715951, 12.332441926002502, 0.6324280213032449, 0.016574183046551685, 0.009387187626478928, 0.07104381745947258, 1.8792434462479182, 3.353084691933223, 1.9849222898483276, 5.897444665431976, 12.782747728484017, 10.164753351892744, 19.906314509255544, 32.462053298950195, 42.10385308946882, 53.83155073438372, 56.62357316698347, 56.249864305768696, 54.61412286758423, 52.577751772744314, 51.59236172267369, 51.662899834769114, 53.869328090122764, 49.86283002580915, 49.44225556509835, 43.29792881011963, 42.48760209764753, 44.16662386485508, 40.21955721718924, 40.34168570382254, 42.379950182778494, 45.347376414707725, 47.79741198675973, 51.5053459576198, 51.627391065870015, 51.32975108282906, 50.90955182484218, 51.64383397783552, 50.570712498256135, 49.74432155064174, 49.157247407095774, 52.7727564402989, 50.3221754346575, 45.6254745892116, 38.328809942517964, 36.689587456839426, 36.91753005981445, 45.42746482576643, 52.4361891746521, 48.709512438092915, 53.59424890790667, 53.07454449789864, 53.22318383625576, 52.33512762614659, 51.456677300589426, 42.96747943333217, 22.148624999182566, 50.27764095578875, 44.24314785003662, 50.01803541183472, 50.15061398914882, 53.34736898967198, 50.315032686506, 53.27307537623814, 48.44986867904663, 50.2033542905535, 52.31182336807251, 45.14286313738142, 35.732570375714985, 41.583599771772114, 49.086389677865164, 51.145241669246126, 50.87916387830462, 49.15584734507969, 50.35169833047049, 50.80251482554844, 48.16465902328491, 46.54495750154768, 42.33865703855242, 39.07859352656773, 37.337885652269634, 45.31064476285662, 48.32958146503994, 49.59157582691738, 47.85078457423619, 41.2260593686785, 39.0817688533238, 43.67235680988857, 45.37440838132586, 49.526804719652446, 50.54209634235927, 51.53629323414394, 51.22224508013044, 52.96139308384487, 47.55952303750174, 45.26109021050589, 31.898269517081125, 21.837812968662806, 12.824984959193639, 5.655492322785514, 6.51959114415305, 7.707257151603699, 5.312468443598066, 4.537184970719474, 1.3840446812765939, 0.5832663678697178, 0.13384184667042323, 0.05696139990219048, 0.059186981192656925, 1.6717589454991477, 17.505451338631765, 32.69638477052961, 32.1191075869969, 23.559934411730083, 21.162844112941197, 32.50544827325003, 42.35936267035348, 43.41588837759835, 32.75207805633545, 6.659148752689362, 0.12050891853868961, 0.03993248813120382, 0.05542765970208815, 0.02931729970233781, 0.061056799787495813, 0.03313787254903998, 0.06707944947161845, 0.0358146898049329, 0.08152650496257202, 0.0329562762219991, 0.05651268469435828, 0.043362703174352646, 0.026436698024294207, 0.007563951308839023, 0.03382953382762415, 0.06151158109839473, 0.027152594877406955, 0.038716482131608894, 0.030364197811910083, 0.016472475736268928, 0.13369525596499443, 0.010960763769357331, 0.04008691591609802, 0.039111850916274955, 0.008037908019364944, 0.041452002844640186, 0.012753755236709756, 0.015957856118412952, 0.05685894111437457, 0.024363446149176786, 0.05107793132109301, 0.050351013362939866, 0.04931985726580024, 0.03196306719577738, 0.036694814184946675, 0.051547250244766474, 0.05725239643028804, 0.02801302308216691, 0.04045744692640645, 0.032493946209017716, 0.063627307569342, 0.019876171934551427, 0.03161751984485558, 0.05009997236941542, 0.038101569948984046, 0.03144049005849021, 0.96247413115842, 28.03033069201878, 51.81438793454851, 52.29272277014596, 46.87943683351789, 32.32205751964024, 27.207729986735753, 37.116724491119385, 54.54506472178868, 45.46021515982491, 30.029249259403773, 13.132071018218994, 1.1956636011600494, 0.0704286711822663, 0.041495829421494684, 0.6469377598592213, 2.8929098418780734, 6.624081628663199, 9.79848427431924, 9.005115509033203, 17.03150429044451, 10.800173929759435, 18.916025979178293, 33.561084611075266, 43.0839729309082, 56.33779375893729, 57.690656661987305, 57.87897368839809, 55.97184256144932, 53.37283066340855, 51.50770139694214, 51.17160313470023, 56.36579499925886, 53.42414658410208, 51.14625610624041, 44.52798925127302, 44.82819659369332, 46.35749510356358, 42.638673305511475, 41.8434693472726, 44.23845086778913, 47.00919444220406, 48.86324828011649, 52.958912576947895, 52.12582703999111, 52.64492695672171, 53.255131653376985, 52.98461743763515, 52.37002147947039, 50.991109779902864, 49.64513601575579, 53.881018434252056, 53.08410521915981, 47.46727875300816, 40.34198447636196, 38.7764823777335, 38.45193549564907, 46.222508975437705, 55.13257312774658, 51.70640598024641, 53.96464000429426, 52.428400244031636, 54.04124389375959, 53.03772946766445, 50.97651161466326, 43.099655015128, 24.004622595650808, 49.30014753341675, 46.11074720110212, 51.131383487156455, 51.626164708818706, 54.53825201307024, 52.01670905521938, 54.86745071411133, 48.3400593485151, 50.495355810437886, 54.42165776661464, 46.85239791870117, 37.45087030955723, 42.219082014901296, 51.317011560712544, 52.7852840423584, 49.46364906855992, 49.5972455569676, 49.96102196829659, 51.67630638395037, 51.13854013170515, 48.31766530445644, 44.872543471200125, 40.1059159551348, 40.5181873185294, 47.002499852861675, 50.59419740949358, 51.876928670065745, 49.584248951503206, 43.612866333552766, 41.764777524130686, 46.26773132596697, 46.32706894193377, 50.248354298727854, 53.51996224267142, 52.16047770636422, 52.85203538622175, 52.51556192125593, 50.17513418197632, 46.64092254638672, 36.68188885280064, 23.351623943873815, 12.079744628497533, 8.092593823160444, 8.351317814418248, 9.250046457563128, 11.570697886603218, 7.199991319860731, 5.078423150948115, 1.657174133828708, 0.4438507360007082, 0.0327126414382032, 0.05969164161277669, 2.0260237072195326, 20.130393913814, 34.777679443359375, 27.424687487738474, 26.893014805657522, 24.639939819063457, 38.03578356334141, 47.38434158052717, 49.162416866847444, 38.73201390675136, 8.713731510298592, 0.09386322155062642, 0.01127407731421824, 0.04573048504867724, 0.009417460466335927, 0.01803238194302789, 0.00817950555522527, 0.033871596213430166, 0.11024142841675452, 0.05933306978217193, 0.04386557565469827, 0.015304247083674585, 0.030615062386329685, 0.05558146662744028, 0.011903401580639184, 0.007417334310178245, 0.027341809456369708, 0.02489674074708351, 0.0594781202131084, 0.059735074639320374, 0.03330548426934651, 0.0308083363010415, 0.042697942416582785, 0.0530047841769244, 0.06035768480173179, 0.10776116579238858, 0.14011913697634423, 0.15065818359809263, 0.18868989497423172, 0.10959968356681721, 0.13124072338853562, 0.2086379559976714, 0.15727662774068968, 0.12271122607801642, 0.10163066975240197, 0.17460113311452524, 0.1453173937542098, 0.25777738062398775, 0.09958948035325323, 0.11216734828693525, 0.09811895926083837, 0.14131113301430429, 0.12444348526852471, 0.18143995186047895, 0.18744721237037862, 0.1510878862547023, 0.20389042289129325, 1.6069851240941455, 35.68107032775879, 59.949113028390066, 60.49863910675049, 52.561350549970356, 36.08749825613839, 40.04123517445156, 47.51739263534546, 54.33682026181902, 45.73567649296352, 31.842468534197124, 15.873150995799474, 1.1577902734279633, 0.20328943085457596, 0.11034628921853644, 1.0166422873735428, 3.028420993259975, 10.689722759383065, 14.267203433173043, 16.52106182915824, 23.003717218126567, 20.218200036457606, 24.93490821974618, 38.5424462045942, 48.90340191977364, 57.11868442807879, 62.03087670462472, 59.441255296979634, 58.39282076699393, 53.62355293546404, 52.264464446476524, 51.592215810503276, 57.309138025556294, 54.90337984902518, 53.82867765426636, 46.0772499356951, 47.301018783024375, 48.211594104766846, 44.050929410117014, 43.2707405090332, 47.225026335035054, 49.24880034582955, 52.523385592869346, 54.262811524527415, 55.04589087622506, 55.4343055997576, 56.149831090654644, 54.74985940115792, 53.0031031199864, 51.00763954435076, 49.942984444754465, 55.44614880425589, 56.1593952860151, 49.9358104297093, 41.756637709481375, 40.373459815979004, 40.07654939379011, 48.21014193126133, 57.76323754446847, 53.05770901271275, 56.95051717758179, 54.88118382862636, 56.526729175022666, 55.21308190482003, 52.060333320072715, 44.24498912266323, 27.2601089818137, 50.86988455908639, 45.50831059047154, 52.36759655816214, 52.06367540359497, 56.8040109361921, 54.49133777618408, 56.901542799813406, 49.98807825360979, 51.57657541547503, 55.99924973079136, 48.12950461251395, 40.43788698741368, 44.98418712615967, 52.609748227255686, 54.97250747680664, 51.17093958173479, 50.66809150150844, 51.257312638419016, 52.538991246904644, 52.63012381962368, 50.973079204559326, 46.10672419411795, 42.59118931634085, 42.76356717518398, 49.414167472294395, 52.41560166222708, 53.99207149233137, 52.6907433782305, 44.7282259123666, 43.61191095624651, 48.50846978596279, 48.8462564604623, 54.039093426295686, 55.07040064675467, 56.41372019904, 54.28117561340332, 55.326115199497764, 49.75239883150373, 50.106538091387065, 35.33090543746948, 27.436343090874807, 18.820908614567347, 10.897938558033534, 13.420266662325178, 15.957654987062726, 13.266223362513951, 13.418198704719543, 6.668578326702118, 1.3218835996729987, 0.5234189821141106, 0.2065927700272628, 0.3048260488680431, 2.301169114453452, 23.37512275150844, 42.65029764175415, 43.746063300541465, 35.10623543603079, 30.67274624960763, 42.782528809138704, 55.04323666436331, 56.298251560756135, 47.822425501687185, 11.224706258092608, 0.33879733883908814, 0.10280069482645818, 0.12730121692376478, 0.07305247110447713, 0.11783718690276146, 0.1596440499914544, 0.18761775536196573, 0.2260244387601103, 0.1463319935968944, 0.0638212396630219, 0.11554527202887194, 0.15509797393211297, 0.17713352079902375, 0.09856920795781271, 0.1567278964711087, 0.1573317926377058, 0.13883454804973944, 0.15662022653434957, 0.10301502368279866, 0.09205162804573774, 0.15303902727152618, 0.18005541472562722, 0.21344643511942454, 0.11721711446131979], [0.020129667528505837, 0.04554292779149754, 0.025336441617192965, 0.03962697095370718, 0.017184533777513673, 0.02461946758973811, 0.06970215016709906, 0.034407676197588444, 0.07198264529662472, 0.02800793746220214, 0.026605637976899743, 0.05309396064175027, 0.03511092685429113, 0.0072597437039283765, 0.02504221356606909, 0.04333315297429051, 0.05493216968274542, 0.0435849742830864, 0.06648823512451989, 0.06956636173916714, 0.030699417859848057, 0.022750444577208588, 1.0076261311769485, 29.28673349108015, 44.52720063073294, 46.545075620923726, 38.77757324491228, 29.663589886256627, 36.47404391424996, 40.806593145642964, 34.67097248349871, 39.687762941632954, 29.721649033682688, 6.142937983785357, 0.20723171931292328, 0.059726321537579806, 0.028626004832663705, 0.4525049073355538, 2.734229488032205, 4.152375493730817, 4.950875069413867, 8.523890222821917, 16.409800325121196, 10.589704309191022, 32.548179694584434, 42.31979962757656, 48.93946654456002, 52.28148405892508, 56.624031748090474, 56.26839862551008, 52.21219662257603, 51.87020281382969, 52.11470297404698, 49.750804219927105, 53.00469773156302, 51.41820165089199, 47.618259634290425, 45.52928720201765, 40.75925159454346, 40.05796296255929, 40.780533926827566, 43.22175223486764, 47.93629258019583, 49.95961148398263, 52.45607839311872, 48.80774259567261, 49.875232560294016, 50.55327251979283, 52.54411901746477, 51.025395665849956, 49.9250476700919, 48.773626940590994, 50.13704415730068, 50.82466915675572, 49.139154297964915, 40.94327116012573, 37.89695855549404, 36.25318499973842, 39.843169825417654, 50.23058775493077, 51.572674001966206, 52.832545689174104, 52.698087624141145, 47.994341305324006, 51.93387263161795, 48.86054195676531, 51.430607659476145, 41.55413940974644, 20.831854513713292, 50.01394639696394, 43.86933823994228, 53.793884549822124, 47.97211054393223, 50.75040681021554, 47.1322991507394, 50.41103594643729, 51.775088923318044, 53.311231408800396, 49.6220714705331, 47.314449650900706, 36.431402819497244, 40.87247943878174, 48.82636376789638, 50.70168604169573, 50.44680527278355, 51.30960825511387, 49.54524176461356, 49.29874052320208, 51.62890229906355, 49.37514986310686, 45.39380080359322, 40.8426126071385, 35.209235531943186, 36.1228472164699, 39.597464152744834, 41.68016236168997, 39.4400839805603, 38.24468462807791, 38.236367634364534, 43.58691133771624, 44.28075844900948, 46.86756583622524, 48.806238310677664, 48.64483513150896, 48.729533672332764, 51.615377630506245, 52.13588803155081, 50.7005534853254, 44.80595888410296, 34.006134101322715, 24.32463230405535, 15.792921883719307, 7.888262936047145, 4.294616409710475, 9.881707191467285, 9.466519321714129, 3.5161969108240942, 0.6627892607024738, 0.44515737731541904, 0.08573605479406458, 0.037851126066276004, 0.5743981323071888, 8.574246423585073, 38.94205447605678, 60.38147858210972, 50.13630417415074, 36.58667768750872, 34.806670801980154, 45.283730915614534, 45.744615350450786, 38.28577627454485, 12.296313898903982, 0.06771600352866308, 0.025595903230298842, 0.06607644579240254, 0.010160204405630273, 0.03390243563002773, 0.03970260385956083, 0.04797773874763932, 0.014351753551246864, 0.04782972311867135, 0.009427473098704857, 0.0482295634491103, 0.013712877208100898, 0.012050063532244946, 0.040440103571329794, 0.06897834329200642, 0.020011967147833536, 0.04853388301229902, 0.022305897270728434, 0.024328158935531974, 0.05993168694632394, 0.027614758649308766, 0.03157840908638068, 0.030431973282247782, 0.04220834547387702, 0.058464348183146546, 0.11295519529708795, 0.03513385455257126, 0.052411897241004875, 0.04938942067591207, 0.011333568720147014, 0.09391265961208514, 0.03048401352550302, 0.07212329882064036, 0.05863468761422804, 0.051852909914617024, 0.021246470012036816, 0.036913763864764144, 0.02369864298296826, 0.01506315341352352, 0.03717398204441581, 0.03423422568344644, 0.04744496322902186, 0.006672858410248799, 0.008649611579520362, 0.022740470112434456, 0.03262418761317219, 1.917031658547265, 34.638135296957834, 52.87875815800258, 54.41686003548758, 44.05815206255232, 32.84008741378784, 43.082593713487896, 40.63142558506557, 40.81175218309675, 43.477626596178325, 27.092141492026194, 7.2977311951773505, 0.3845373030219759, 0.05555089183949998, 0.32664518377610613, 1.2417764067649841, 6.903662809303828, 9.280076571873256, 5.665039581911905, 8.09475644997188, 12.217764513833181, 10.21887287071773, 26.73378641264779, 42.61692544392177, 50.83238860539028, 55.130585942949565, 58.37214987618582, 57.28885970796858, 53.951153550829204, 53.55235821860177, 51.67100838252476, 49.74018737248012, 53.56070647920881, 53.14273064477103, 50.95002508163452, 46.307627882276265, 41.9967222894941, 40.82364749908447, 42.47037056514195, 44.95462948935372, 49.32005064828055, 52.68030023574829, 53.09854704993111, 51.84165613991873, 52.640275137765066, 52.32287447793143, 53.0581328528268, 52.67955330439976, 51.19611985342843, 49.23548412322998, 50.303964206150596, 52.76083680561611, 50.33200018746512, 41.82654006140572, 38.962166036878315, 39.101366247449604, 40.45861693790981, 52.26576028551374, 52.89063957759312, 52.36960111345564, 52.8974210194179, 50.10760811397007, 53.42573077338082, 50.21359593527657, 52.018623283931184, 42.290839535849436, 22.746710300445557, 49.903417927878245, 44.840310777936665, 54.71849175861904, 51.202018874032156, 52.48944364275251, 48.46535273960659, 51.88242816925049, 53.27252646854946, 54.848951135362896, 52.23676545279366, 49.52140596934727, 38.21829884392874, 43.1941887310573, 50.99205820901053, 52.02916022709438, 50.814462253025596, 50.3413976260594, 49.186283929007395, 51.359802041734966, 51.85974924904959, 50.099780968257356, 47.66412469318935, 42.45502894265311, 37.77879054205758, 38.14466183526175, 41.63561051232474, 44.145695890699116, 41.30273274012974, 39.731932640075684, 40.283772468566895, 44.26369367327009, 46.939969539642334, 50.06820835386004, 51.0694819859096, 52.00195802961077, 51.96761308397566, 53.761394773210796, 52.920735699789866, 51.99925170625959, 46.23901094709124, 35.639613900865825, 22.347051654543193, 9.789171082632881, 7.743604915482657, 10.037225246429443, 10.074984363147191, 10.695723397391182, 6.283282910074506, 2.6397346385887692, 0.6936851856963975, 0.0607844086896096, 0.06708823650010995, 0.735440982239587, 10.064067874635969, 35.728477886744905, 52.54241323471069, 42.448886735098704, 35.75537436349051, 37.76351840155465, 50.050660678318565, 52.39313466208321, 44.16667250224522, 15.416392053876605, 0.23245885063494953, 0.06972238408135516, 0.04230775424678411, 0.019171660899051597, 0.018974334433940903, 0.052940048543470244, 0.06413985256637846, 0.01160766463726759, 0.05212805586467896, 0.010733963439374097, 0.06888360623270273, 0.023283698463014195, 0.03065934018897159, 0.08898300092135157, 0.06558237730392388, 0.013688453340104647, 0.03698482005191701, 0.017589439371866838, 0.04977197193407586, 0.11298371412392173, 0.012205544742755592, 0.025846535406474556, 0.07209408110273735, 0.058071727465306006, 0.14038760614182266, 0.17734960706106254, 0.09222702256270818, 0.1499270349740982, 0.08474731392094068, 0.05847673144723688, 0.3498616394187723, 0.12531004234084062, 0.23650853761604854, 0.19923949960087026, 0.13249335331576212, 0.16559332289866038, 0.0844911126685994, 0.07886975537985563, 0.08470250346830913, 0.10862613509276084, 0.13028955299939426, 0.19154340614165577, 0.17315115806247505, 0.12156372836657933, 0.10737859417817422, 0.11606572195887566, 2.7111047974654605, 44.88046441759382, 62.720561844961985, 63.442799295697895, 50.83622748511178, 42.38271903991699, 48.47098772866385, 49.48049150194441, 40.92222506659371, 50.779630933489116, 38.901751450129915, 8.331300922802516, 0.499079062470368, 0.2280511414366109, 0.4718199766107968, 1.0058685626302446, 8.103262782096863, 12.523323706218175, 11.230405517986842, 16.4402334349496, 25.703201804842266, 17.69633572442191, 39.30749150684902, 55.50825527736119, 54.565850257873535, 56.21806240081787, 61.1399439402989, 59.282620974949424, 55.085756165640696, 53.32008688790457, 51.027031966618125, 49.13527372905186, 55.5399112701416, 56.49549354825701, 53.31844711303711, 49.149375098092214, 45.47548730032784, 43.811939171382356, 45.74388231549944, 46.874882289341514, 52.076678957257954, 54.43505736759731, 55.815855503082275, 53.175494875226704, 52.32415642057146, 53.417212281908306, 53.710499218532014, 54.78717122759138, 51.396151542663574, 48.61673314230782, 51.635218211582725, 55.524538380759104, 52.64417307717459, 44.6673457963126, 41.675857952662874, 41.247616154806956, 42.04330996104649, 55.09922177450997, 55.510047912597656, 54.79766648156302, 54.67898777553013, 51.794116565159385, 54.70334121159145, 51.74569804327828, 51.289069380079, 43.34285586220877, 26.07051658630371, 49.06189727783203, 45.6899608203343, 56.62861408506121, 52.85281705856323, 55.249695437295095, 51.372656209128245, 54.45776408059256, 55.38332666669573, 55.176266874585835, 53.37318502153669, 51.67609098979405, 40.40876013892037, 45.00518110820225, 52.83614485604422, 54.18997008459908, 52.131920610155376, 52.183104515075684, 50.68575382232666, 51.47918946402413, 53.84581191199166, 52.378310680389404, 49.57773848942348, 45.04613379069737, 39.805208342415945, 39.752290861947195, 44.08551754270281, 46.48182616915022, 42.836915833609446, 42.217998095921104, 41.20050389426095, 47.53486735480172, 49.752124377659385, 51.967293466840474, 53.525962012154714, 53.90287051882063, 53.6796110016959, 54.680870737348286, 55.11690146582467, 52.995296818869456, 49.77759994779314, 37.994351455143516, 29.822814805167063, 22.314702578953334, 17.717569419315883, 17.187691109521047, 22.367418561662944, 20.005279438836233, 10.482195700917925, 3.321590027638844, 1.0122795786176408, 0.12533664091357163, 0.2673870378306934, 1.15859973856381, 10.978389143943787, 49.7068429674421, 71.7361969266619, 57.580055236816406, 46.85395778928484, 46.026892866407124, 57.44434649603707, 57.10452747344971, 51.99404403141567, 20.62867181641715, 0.6407063656619617, 0.13724179565906525, 0.14290881156921387, 0.09016706488494362, 0.0870018754420536, 0.12408288461821419, 0.12401192342596394, 0.09155095062617745, 0.202872633934021, 0.06619214279843227, 0.12705758213996887, 0.0485989613059376, 0.07591061666607857, 0.15630671621433326, 0.2057516308767455, 0.12347208096512727, 0.14220327085682324, 0.08737044887883322, 0.07723332569003105, 0.22327759329761776, 0.07921474293938705, 0.09973937552422285, 0.16027241413082394, 0.15159800888172217], [0.054273698944598436, 0.052381122285234075, 0.043277428285884004, 0.04063233932746308, 0.05305896519816347, 0.008704668759102268, 0.021036000323614905, 0.035980333773685355, 0.06534869662885155, 0.01078417503075408, 0.017421763190733533, 0.031465779058635235, 0.03677053190767765, 0.03490551734077079, 0.023317562449457388, 0.006902574320390288, 0.055479136761277914, 0.03853219202054398, 0.02470674246017422, 0.0053447537606449, 0.05383619313527431, 0.0998284061040197, 3.6756187677383423, 33.53467798233032, 45.56657123565674, 45.196513652801514, 37.86177287782942, 20.84759565762111, 20.539033106395177, 35.539549418858115, 29.282439504350933, 29.161568641662598, 17.94223247255598, 1.1339624034506934, 0.15506118376340183, 0.093313601400171, 0.17905224141265663, 1.0086755262953895, 4.715980359486171, 5.530273624828883, 8.580070751053945, 4.4297124062265665, 19.56198263168335, 19.11027503013611, 31.389557157244, 46.939559595925466, 50.97912066323416, 53.43164369038173, 53.461906569344656, 54.32224294117519, 52.46374920436314, 52.24635396684919, 50.08703449794224, 50.98090982437134, 50.71939352580479, 51.73559536252703, 50.81302397591727, 49.778246130262104, 46.4891356740679, 44.91513940266201, 45.24068682534354, 48.76555660792759, 51.24134220395769, 52.00598103659493, 50.412408215659006, 47.37084470476423, 47.55257831301008, 47.68209273474557, 49.03713737215315, 48.73710720879691, 49.546405587877544, 47.821025439671104, 49.59980596814837, 49.936654635838096, 45.7909494127546, 36.62647002083914, 36.81838968821934, 38.24282945905413, 41.18915401186262, 50.837186336517334, 54.44965205873762, 47.513150760105674, 47.81008202689034, 46.490518365587505, 49.606938294001985, 46.72903265271868, 51.317793233054026, 39.67299801962716, 14.794644662312098, 50.085717814309255, 46.86534241267613, 50.29016160964966, 49.25590140478951, 46.08477830886841, 43.60944781984602, 47.966722215924946, 50.421840395246235, 51.34452295303345, 51.289201395852224, 47.86419807161604, 35.96326099123274, 39.78250857761928, 46.669729777744834, 51.273046834128245, 47.67715603964669, 48.8673095021929, 46.84887865611485, 49.61520665032523, 50.50044536590576, 48.82294872828892, 47.499671254839214, 42.64322090148926, 38.702171393803184, 35.535950251988, 33.67354467936924, 34.47578021458217, 34.725276129586355, 37.84315517970494, 39.878800187792095, 41.971945013318745, 43.210749762398855, 46.89273221152169, 45.9977833884103, 46.70497798919678, 49.90269184112549, 51.1999865259443, 54.48661300114223, 53.181254931858604, 45.83352449962071, 40.90142910821097, 25.80540806906564, 14.727735246930804, 7.546165772846766, 7.652762430054801, 11.773032035146441, 3.030477660042899, 4.211989734854017, 3.324928419930594, 0.6420193580644471, 0.07412194407411984, 0.01721772431795086, 0.014071330295077391, 3.3193826717989783, 28.990955625261577, 58.77971730913435, 39.58417919703892, 23.263748339244298, 31.005113329206193, 41.65958527156285, 43.43230349676949, 38.84909105300903, 21.561583859579905, 1.7215389886072703, 0.037739910784044435, 0.06940425293786184, 0.059103562097464285, 0.07801671472511121, 0.08198201909129109, 0.014879312831908464, 0.08054661218609128, 0.0035605565312185456, 0.03854902308168156, 0.033599188152168474, 0.043024256692401, 0.03994335147685238, 0.02490742936996477, 0.06250646271343742, 0.03593465479622994, 0.00736338399084551, 0.031215650694710866, 0.06744014511683158, 0.03126234747469425, 0.0059247570128978366, 0.05702501256018877, 0.12317889955426965, 0.03684254143653171, 0.05563232621976307, 0.05645805923268199, 0.02710303128696978, 0.011255646606774201, 0.026598944228940775, 0.0166267389764211, 0.03816959308460355, 0.04245184455066919, 0.01607919344678521, 0.020302307193300555, 0.056350867663111, 0.07116864754685334, 0.018352168711966703, 0.026505050249397755, 0.015191130207053252, 0.034788697359285185, 0.08999997563660145, 0.022794072682570134, 0.06475506669708661, 0.10673568224800484, 0.09412332437932491, 0.1224278834249292, 4.393841462475913, 41.702757903507774, 52.2162960597447, 51.43505450657436, 45.063691888536724, 26.321435144969396, 26.137245348521642, 42.071314675467356, 31.081317697252544, 33.11290495736258, 20.630766698292323, 1.3982356169394083, 0.139325848115342, 0.06110017853123801, 0.36822073427694185, 2.7600049163614, 6.414992528302329, 9.446207131658282, 11.807834693363734, 8.681811485971723, 12.095471876008169, 19.648652723857335, 32.6029314994812, 48.1417612348284, 53.71461602619716, 56.97326557976859, 55.216740131378174, 55.28054196493966, 53.18836988721575, 52.07999324798584, 50.70943675722395, 52.24772276197161, 51.78928061894008, 54.69422517504011, 51.51237753459385, 50.41882835115705, 48.85500771658761, 45.55511365618025, 45.867462975638254, 49.91718578338623, 52.46327325275966, 53.389735630580354, 51.02068131310599, 47.800496986934114, 48.672819001334055, 48.15101970945086, 48.65512193952288, 48.050618239811485, 50.063198702675955, 48.22572674070086, 49.24033743994576, 52.89522191456386, 48.73187868935721, 38.69234664099557, 37.49286869594029, 39.363566943577354, 44.28270394461495, 52.689221722739084, 54.17306859152657, 50.128643785204204, 50.45654664720808, 47.787302357809885, 50.67253140040806, 46.938117844717844, 51.88407836641584, 40.693545954568044, 15.65691089630127, 49.74392897742135, 46.81266117095947, 52.43397617340088, 50.559609276907786, 47.96349477767944, 45.674761635916575, 49.810395445142476, 52.30489253997803, 52.54286139351981, 53.30659001214163, 49.946920599256245, 38.114586557660786, 41.06763696670532, 48.83509070532662, 53.31319080080305, 48.58894034794399, 49.6164608001709, 48.01891360964094, 50.58029406411307, 52.356427328927175, 50.519803047180176, 48.140993458884104, 45.13212817055838, 40.052988052368164, 37.52289533615112, 35.44069044930594, 37.48965515409197, 37.160543305533274, 39.2471672466823, 41.379388741084504, 44.31477335521153, 44.42527750560215, 48.879729407174246, 48.33146442685808, 49.29361970084054, 52.135881083352224, 53.00950241088867, 54.41589423588344, 55.2475380216326, 47.71733052389962, 42.599818978990825, 30.40237099783761, 16.27876251084464, 7.2321910091808865, 12.104098064558846, 11.97019932951246, 6.042591665472303, 9.504419139453343, 5.306015304156712, 1.606200737612588, 0.571828655898571, 0.04150681151077151, 0.0650114036564316, 3.4821759249482835, 30.25973837716239, 61.06359713418143, 46.13844966888428, 30.88894292286464, 38.044447966984336, 47.41757134028843, 47.80415868759155, 46.07511336462838, 26.561611788613455, 2.4697489142417908, 0.04781446286610194, 0.017722243942054253, 0.0955003569168704, 0.016685208338978033, 0.09907907274152551, 0.04143420487110104, 0.00826877192594111, 0.024348389457112977, 0.025423122769487754, 0.006894816120620817, 0.04299645711268697, 0.009861639667568462, 0.03598575187580926, 0.048505679704248905, 0.02291086552265499, 0.04571410182065197, 0.022525366029835174, 0.04081571680892791, 0.01222099837780531, 0.0567507894177522, 0.023908612251813923, 0.031235446953879933, 0.018147946634728993, 0.14301360451749393, 0.13873442342238768, 0.1491831298917532, 0.10577037797442504, 0.10665473980563027, 0.07186405773141555, 0.1135104608588985, 0.11498252222580568, 0.20425274702055113, 0.10630033418004002, 0.11821129039994308, 0.17230564914643764, 0.17027480740632328, 0.12025995046964713, 0.07251361930476767, 0.08915125046457563, 0.2348327732511929, 0.25060309416481424, 0.18032648946557725, 0.2252605983189174, 0.16849665210715362, 0.1678996905684471, 6.869936687605722, 53.8474760055542, 61.15436840057373, 60.6519650050572, 49.763411726270405, 31.94835560662406, 29.20647484915597, 43.54378386906215, 39.27851057052612, 40.23205702645438, 22.881673846926006, 1.8952900937625339, 0.27754462563565796, 0.357887650174754, 0.6552493795752525, 3.830718193735395, 10.566354887826101, 15.1126480783735, 20.90403934887477, 13.685549753052847, 27.840801204953873, 24.215186016900198, 37.659455231257844, 52.676377977643696, 55.1380934715271, 58.8022711617606, 57.64174829210554, 56.72898081370762, 53.58712353025164, 53.81172752380371, 50.78149652481079, 53.5968336377825, 50.70780393055507, 56.20542362758091, 54.74846976143973, 53.71445621762957, 52.227110930851524, 49.82332951681954, 48.93328612191336, 52.668623788016184, 54.834940092904226, 55.41314486094883, 53.66561385563442, 48.33132546288626, 47.31410918916975, 47.849231651851106, 49.69919300079346, 49.27481092725481, 49.99425867625645, 48.85971859523228, 50.561836174556184, 53.9430102620806, 50.84410326821463, 39.69521835872105, 39.727833202907014, 41.43635354723249, 45.78322301592146, 54.305626324244905, 57.80646923610142, 51.63537107195173, 50.6426020349775, 48.51290968486241, 49.98651838302612, 46.66997296469552, 52.08958871023995, 41.801109654562815, 19.34665274620056, 49.87980100086757, 49.13685097013201, 55.276671818324495, 52.48413174492972, 50.44168445042202, 48.26518208639962, 51.831900869097026, 54.06190088817051, 55.39300203323364, 55.74469552721296, 52.61889205660139, 40.075600964682444, 43.50215026310512, 51.37283686229161, 55.516356876918245, 48.95037521634783, 50.29071399143764, 47.42678812571934, 50.70913451058524, 52.96889019012451, 51.00255346298218, 52.129599911826, 47.042538847242085, 42.81591490336827, 38.95910882949829, 37.92970194135393, 38.677640778677805, 39.23649133954729, 41.80247497558594, 43.68535341535296, 46.853815351213726, 46.415939876011436, 51.937701089041575, 51.10920831135341, 51.84484536307198, 55.29996565410069, 54.951433590480256, 58.31099183218819, 56.31545182636806, 51.208765574863975, 45.93494735445295, 31.642895426068986, 19.43165179661342, 14.603583097457886, 15.271357093538557, 17.83579649244036, 12.15954121521541, 12.91482777254922, 7.926128012793405, 1.8889752668993813, 0.7310304503355707, 0.15142101980745792, 0.29457957297563553, 4.4075906447001865, 35.0990822655814, 64.75999014718192, 52.00144386291504, 34.09484870093209, 44.12088734763009, 53.08423376083374, 55.18377440316336, 52.74583217075893, 34.01628541946411, 3.5591932322297777, 0.2179257297622306, 0.11318025179207325, 0.19330225033419474, 0.11991049136434283, 0.22310561181179114, 0.07670543223087277, 0.15670127075697693, 0.10562086956841604, 0.14018051725413117, 0.13128148977245602, 0.15242997423878737, 0.143556663234319, 0.0817452035844326, 0.19387405179440975, 0.16240509040653706, 0.0788689139964325, 0.11292314130280699, 0.15296501267169202, 0.1792913842946291, 0.17620593628713063, 0.10739034640469722, 0.16747490050537245, 0.12546614610723086], [0.030171422620436976, 0.032004929413752894, 0.07124574948102236, 0.026220306421497037, 0.02889246553448694, 0.017285011243075132, 0.07832113946122782, 0.05563594959676266, 0.05166979366913438, 0.02002966503745743, 0.07325287642223494, 0.05707735475152731, 0.052872832864522934, 0.009247905591369739, 0.029532493690827062, 0.054270458939884386, 0.016370164529819573, 0.0837107566850526, 0.030930818657257726, 0.016876472093697106, 0.04283521344353046, 0.027861512997852902, 10.984494873455592, 39.8679575238909, 49.536160469055176, 37.346626486097065, 38.39499153409685, 40.78956658499581, 27.73779242379325, 22.129550457000732, 26.321539367948258, 36.95268794468471, 7.471118279865809, 0.4885528130190713, 0.1313492211380175, 0.11639870623392717, 0.31467940871204647, 1.7335728343044008, 8.27025578703199, 8.19147971698216, 5.576984626906259, 5.643560094492776, 12.701658776828221, 25.644013575145177, 37.05121687480381, 50.75413799285889, 53.16215780803135, 56.54422126497541, 54.340176241738455, 53.42700229372297, 49.33074392591204, 51.66358075823103, 50.636011668613975, 52.459055696214946, 50.80389404296875, 51.24891921452114, 51.012472016470774, 48.62458460671561, 48.025708947862896, 47.74872595923287, 46.32998023714338, 48.880260944366455, 49.630023683820454, 49.02044085093907, 46.17737347739083, 47.947649410792756, 47.84174149377005, 50.88804020200457, 49.33335297448294, 50.6937928880964, 50.663658550807405, 48.81385701043265, 48.67422948564802, 48.78442791530064, 41.74761199951172, 36.75944464547293, 37.3475992338998, 36.20526327405657, 40.76524094172886, 47.154967648642405, 50.994490078517366, 50.354616573878694, 51.57078409194946, 51.24467733928135, 52.870587076459614, 49.64486503601074, 49.03691850389753, 41.646369797842844, 18.033345937728882, 49.75730078560965, 48.154448645455496, 50.26758691242763, 45.23376989364624, 46.31710869925362, 39.67180640356881, 39.054236616407124, 41.1622679574149, 46.815725326538086, 47.530173846653526, 42.40611709867205, 37.17917490005493, 37.778557777404785, 44.28632743018014, 52.38324042728969, 49.70850011280605, 46.861705030713765, 45.79929767336164, 49.379026957920615, 49.31639242172241, 49.09642635072981, 46.360243116106304, 43.509834970746724, 38.47536482129778, 39.728865010397776, 39.166932923453196, 43.0412415095738, 41.600459575653076, 41.78823811667306, 44.45822238922119, 46.931499685559956, 46.3981385912214, 49.48508078711373, 47.9476945740836, 49.92132690974644, 47.965238775525776, 50.02953815460205, 51.39547756740025, 52.699657917022705, 44.982443128313335, 42.182197502681184, 30.249687807900564, 15.704686709812709, 5.803668303149087, 7.895823444638934, 7.0474688070161005, 5.04976704290935, 5.269653209618159, 2.6038009439195906, 1.7506705054215022, 0.4584168472460338, 0.031081473787448237, 0.03969249029510787, 0.5291789844632149, 13.9741918189185, 31.60010494504656, 26.794666528701782, 21.808239698410034, 31.505501747131348, 37.129432746342246, 36.879182951790945, 45.782267638615195, 32.16330507823399, 5.031361264841897, 0.07421758358499833, 0.05028751266321965, 0.0403602298216096, 0.05341288906389049, 0.007336156925053469, 0.0382758957733001, 0.04310999298468232, 0.03338332919936095, 0.07005323775644813, 0.021362631814554334, 0.09261289185711316, 0.057380598836711476, 0.03544570246179189, 0.05717627837189606, 0.034987274025167735, 0.01155794837645122, 0.019984057306178978, 0.012395497228551124, 0.03748082575787391, 0.03893626640949931, 0.058526529132255485, 0.014777249290740915, 0.027735179955405847, 0.008608577174267598, 0.050846408387379985, 0.06505612589951072, 0.09270088427833148, 0.09278577579451458, 0.012683639668726494, 0.04099163719053779, 0.023770114772820046, 0.05299587161945445, 0.03416999216590609, 0.03532273495303733, 0.0439650624591325, 0.020278831577992866, 0.014338625594973564, 0.019322809663468173, 0.0063144867474745426, 0.03214587131515145, 0.07290120529276983, 0.050331614046756706, 0.0544444081772651, 0.03755209229088255, 0.030958662341747965, 12.815639632088796, 47.94221939359392, 56.16214329855782, 44.78219257082258, 42.29393148422241, 37.2470692225865, 27.952106135232107, 29.733103139059885, 24.99675760950361, 33.814471517290386, 8.529475705964224, 0.7984697744250298, 0.051710064722491164, 0.3176410240786416, 0.3949532498206411, 3.828944666045053, 8.369930301393781, 12.30586506639208, 9.552853294781276, 5.73695387159075, 14.30910541330065, 25.61821665082659, 38.228874002184185, 51.63126816068377, 56.26079034805298, 56.924607345036094, 56.17350707735334, 53.932271821158274, 51.55479628699166, 49.690598079136436, 51.54169545854841, 53.22758204596383, 51.27612836020333, 51.796941007886616, 53.1252316066197, 50.584897245679585, 50.72494166237967, 48.838832310267854, 47.700092043195454, 50.57216119766235, 51.34481825147356, 49.980244159698486, 47.40101725714547, 47.58532517296927, 48.04997900554112, 50.68106031417847, 50.261524609157014, 50.128438813345774, 49.29582575389317, 48.94011272702898, 51.03011349269322, 52.02616555350167, 43.00254004342215, 38.209571906498496, 39.52103396824428, 37.78989723750523, 42.570250919886995, 47.69556876591274, 53.75662136077881, 51.88888304574149, 53.29471206665039, 52.887085574013845, 53.16267544882638, 49.29244545527867, 48.68709060123989, 42.30102906908308, 18.72640269143241, 48.89501544407436, 48.861070019858225, 52.46194962092808, 47.54663412911551, 47.15252535683768, 40.88593462535313, 40.3169709614345, 43.9866099357605, 50.32343305860247, 49.3821189062936, 45.51409496579851, 38.29430171421596, 40.883193561008994, 46.4678498676845, 53.333837372916086, 51.31380844116211, 47.70187773023333, 47.3584942817688, 48.746136392865864, 49.98214101791382, 51.51005336216518, 49.09864977427891, 45.51117672239031, 40.0046911239624, 40.181727749960764, 40.18663317816598, 44.08028554916382, 42.31234768458775, 43.66049970899309, 44.70737784249442, 46.95071840286255, 48.5905453818185, 51.9020915712629, 49.1981132371085, 51.79745170048305, 49.24797003609793, 53.75833061763218, 52.531188419886995, 54.62301656178066, 49.132310322352815, 45.69960839407784, 30.27981867109026, 16.82467552593776, 4.914691456726619, 10.503911427089147, 8.922226105417524, 7.173223384789058, 6.8587813547679355, 5.827422891344343, 3.8956907987594604, 0.5370360399995531, 0.08373875303992204, 0.0474080916361085, 0.6600504219532013, 16.04743092400687, 37.19371747970581, 31.898884432656423, 27.42598853792463, 36.80792222704206, 42.69263996396746, 42.34062337875366, 50.98150389535086, 36.77933733803885, 6.615368587630136, 0.034308660974992175, 0.04837483101125274, 0.026315889953236495, 0.017762291078854884, 0.02547130554116198, 0.04549308939437781, 0.039993502000080686, 0.025841507461986372, 0.05964646475123508, 0.03553674150524395, 0.06400636437215976, 0.08751214056142739, 0.0497362131385931, 0.09376088489911386, 0.007917133026889392, 0.02402867393435112, 0.034562090411782265, 0.015934482283358063, 0.039452794407095225, 0.01165251325749393, 0.046719005397920094, 0.0234691200312227, 0.01927147000761969, 0.09647477391575064, 0.1928735383387123, 0.16233355924487114, 0.11556234396994114, 0.17114641277917794, 0.09962069974946124, 0.08528438795890127, 0.13299259224108287, 0.1250643040984869, 0.11365272251090833, 0.2191557101905346, 0.10871368646621704, 0.07685549025024686, 0.12909010664692946, 0.11668066467557635, 0.10808047080146414, 0.09676930561129536, 0.18552303633519582, 0.06538729848606245, 0.0910630432356681, 0.12333085068634578, 0.12264236834432397, 17.424266849245342, 55.46249444144112, 61.92115075247628, 51.357220785958425, 49.182062898363384, 50.10423476355416, 39.14434780393328, 30.900782653263636, 38.18289777210781, 46.12960808617728, 10.522729754447937, 1.1910368608576911, 0.2543355795953955, 0.4359811411372253, 0.9661047820534024, 6.166298261710575, 16.03591775894165, 15.090663978031703, 12.987646630832128, 11.767811332430158, 17.353610617773874, 31.333856923239573, 42.58254228319441, 56.498568126133506, 57.31581177030291, 60.575847489493235, 57.187575817108154, 55.731945582798545, 52.368802070617676, 51.38111564091274, 50.929809297834126, 51.82030432564871, 52.516892501286094, 53.56257554462978, 54.014003481183735, 52.587614740644185, 52.17604514530727, 51.26831858498709, 49.80250576564244, 54.212346758161274, 54.01923200062343, 51.93956668036324, 48.21694769178118, 48.08484854016985, 48.42690140860421, 51.73089838027954, 51.05858026232038, 51.88308824811663, 51.06658111299787, 50.3722893169948, 52.3942220551627, 53.238264901297434, 45.90686968394688, 41.0000900541033, 40.993034158434185, 39.44172722952706, 43.983493668692454, 50.54482698440552, 54.90972008023943, 54.63063873563494, 55.803223678043906, 54.98195702689034, 56.29807438169207, 50.88806799479893, 48.791257994515554, 43.40564325877598, 22.4283264705113, 49.4419116292681, 51.44992365155901, 53.62916707992554, 49.21283994402204, 49.88125664847237, 42.53556203842163, 42.30374928883144, 45.00828347887312, 52.43879474912371, 51.74285275595528, 47.628178187779014, 41.291143144880024, 41.20579147338867, 47.54749917984009, 54.96117149080549, 53.28616230828421, 46.52669416155134, 46.30553994859968, 49.57910033634731, 51.77054132734026, 52.707075119018555, 50.116786684308735, 47.351139613560264, 43.117126260484966, 43.727542877197266, 42.33500576019287, 46.46074880872454, 44.48069633756365, 46.58150502613613, 48.53901406696865, 50.17205613000052, 50.35336937223162, 54.20875801358904, 52.40155587877546, 55.55716364724295, 53.11404848098755, 56.335639817374094, 55.14321429388863, 56.380368845803396, 49.972389221191406, 45.834928035736084, 32.71396023886544, 20.83670609337943, 10.36105125291007, 14.913003751209803, 16.993073804037913, 17.41413811274937, 17.422713926860265, 9.152348705700465, 3.6982564330101013, 0.8762153397713388, 0.190155883452722, 0.1846509695585285, 0.8328041891966547, 17.494144882474625, 41.97543995720999, 38.72914777483259, 34.16790900911604, 40.81958975110735, 48.489671434674946, 47.904911041259766, 59.4722512108939, 44.93311786651611, 9.225939682551793, 0.17863055903996738, 0.14485206800912107, 0.14837635175458022, 0.14474639296531677, 0.1473358997276851, 0.10073771088251046, 0.11844315938651562, 0.12527220722820076, 0.16501077344374998, 0.044273368415555785, 0.12834751792252064, 0.2167797383985349, 0.1596489625849894, 0.2159260870622737, 0.1047233577285494, 0.08831099340958254, 0.12925648343350205, 0.14086674685989106, 0.1509305882666792, 0.05907186772674322, 0.11633195195879255, 0.14529576205781528, 0.08726410887071065], [0.04529729472207172, 0.03646093673471894, 0.008794142082998795, 0.11973955482244492, 0.022089872076841335, 0.031548187136650085, 0.03514781201790486, 0.04031614540144801, 0.035582759750208685, 0.045088926795870066, 0.0780384074896574, 0.03950467858729618, 0.03397125604429415, 0.040250900866729875, 0.044626338939581595, 0.04138973029330373, 0.015296606779364603, 0.04006082624463098, 0.05390050468434181, 0.047157837743205686, 0.038572619136955054, 0.5913101562431881, 14.401956796646118, 41.908170972551616, 45.469094957624165, 37.47820799691336, 45.624553952898296, 52.36799260548183, 17.37045999935695, 21.93702629634312, 41.14563396998814, 24.599706275122507, 3.8713621156556264, 0.07054349966347218, 0.04938616370782256, 0.23719165953142302, 0.04315380599083645, 2.6619102486542294, 4.534451723098755, 9.753142935889107, 9.757175496646337, 10.078740733010427, 20.42298776762826, 32.02622406823294, 42.51273373195103, 54.729789529527935, 52.40128837312971, 54.04494728360857, 55.77790444237845, 50.08915022441319, 49.90053789956229, 49.93700899396624, 51.66793727874756, 48.53994165148054, 45.7483743258885, 47.445110525403706, 48.05231360026768, 49.705842426845, 51.02381147657122, 48.93628774370466, 48.92491006851196, 48.31624092374529, 48.50978994369507, 48.426915305001394, 49.864476748875205, 49.29939365386963, 51.091354915073936, 49.94422122410366, 50.74211760929653, 49.369500977652415, 50.426255975450786, 48.370499406542095, 50.1922093800136, 45.962090492248535, 36.95991407121931, 35.89250748498099, 36.71099485669817, 36.37957273210798, 38.112053939274375, 39.884400435856406, 46.61521768569946, 46.21937186377389, 47.824346678597585, 45.890110628945486, 51.99299832752773, 47.84816510336739, 53.9348634992327, 37.09677621296474, 18.915857485362462, 49.02491201673235, 46.978882925851, 52.377692290714805, 47.59069960457938, 49.34853131430489, 44.56204584666661, 42.68409020560128, 35.10706574576241, 36.9975072996957, 37.500952925000874, 36.65897716794695, 36.50143371309553, 37.40192025048392, 41.90390477861677, 49.728733267102925, 49.79770803451538, 48.319683756147114, 46.53674473081316, 46.484911169324604, 48.9008206639971, 49.23379223687308, 46.0893988609314, 47.15441526685442, 43.34590264729091, 47.56355994088309, 44.97213200160435, 49.60607671737671, 48.66118771689278, 49.28830085481916, 46.85262026105608, 49.87801531382969, 48.21283088411604, 49.7311303956168, 51.277823720659526, 52.87510687964303, 51.953779220581055, 54.55369438443865, 53.046095098767964, 52.32349981580462, 49.16531079156058, 46.94369377408709, 34.442098821912495, 23.16946475846427, 7.817427788461957, 12.745616555213928, 8.224353381565638, 3.7752146806035722, 8.360737834657941, 6.912665069103241, 3.2929591068199704, 0.7270003323044095, 0.1308195431317602, 0.04068300214463046, 0.029821668352399553, 3.9992289458002364, 28.348999398095266, 42.57723385947091, 23.254496812820435, 23.82586281640189, 26.94784825188773, 36.34492206573486, 46.31445448739188, 35.12777485166277, 14.616360834666661, 0.2288302896278245, 0.01666096258642418, 0.022390067843454223, 0.030242129362055233, 0.041599658850048266, 0.05641119281894394, 0.03627440745809248, 0.021658547721537094, 0.04712570232472249, 0.04435564757191709, 0.017579549723970037, 0.031730903046471734, 0.004586851349033947, 0.058812626637518406, 0.06461714766919613, 0.009264323594314712, 0.030215795417981486, 0.027993581357545087, 0.013071047541286265, 0.030405286499964337, 0.03813802085018583, 0.03653479866417391, 0.05483982785205756, 0.0059979968105575866, 0.020082656926076328, 0.03798248705321124, 0.040372837002256086, 0.010259234047095691, 0.023648321129647747, 0.044048467983624766, 0.03904921195602842, 0.05020996968128851, 0.058332997374236584, 0.09103268557893378, 0.01048878753291709, 0.047170258326722045, 0.054824109588350566, 0.03810295755309718, 0.03454522881656885, 0.028488218119101863, 0.06496898843241589, 0.05812396787639175, 0.022719883359968662, 0.0463158198898392, 0.6087443807295391, 18.438735110419138, 48.63971430914742, 52.25285400663103, 41.61023221697126, 50.24325432096209, 57.04345628193447, 21.535510744367325, 25.559771878378733, 39.7263115474156, 28.199816363198416, 4.221634703023093, 0.045906347754810534, 0.03194834298587271, 0.3108101577631065, 1.059405301298414, 4.2571256671633035, 11.760724169867379, 12.138730491910662, 6.02258345910481, 5.9610767023903986, 16.68029022216797, 28.878935030528478, 43.755196707589285, 55.2136447089059, 55.7131472315107, 54.218092918395996, 56.02891159057617, 51.269333021981375, 51.773014886038645, 50.92261791229248, 51.33961752482823, 49.19662632261004, 49.130545479910715, 48.88355439049857, 48.56076887675694, 51.10403190340315, 51.47456891196114, 50.62649958474295, 50.42765256336757, 50.406095777239116, 50.009860856192454, 48.651998724256245, 49.47824028560093, 49.074171270642964, 51.4280298777989, 52.50960731506348, 53.03483554295131, 50.48538514545986, 50.42560631888253, 50.79428121021816, 51.53562273297991, 48.26549128123692, 39.834561007363455, 37.411102294921875, 38.72842863627842, 38.17746428080967, 40.635945388248985, 41.35886376244681, 47.97526502609253, 48.41027089527675, 49.684851918901714, 49.29823677880423, 53.721091747283936, 48.380223410470144, 53.817004680633545, 37.885421071733745, 19.645414863313945, 48.49069629396711, 48.474698066711426, 54.51645203999111, 49.734177180698936, 50.26364033562796, 46.338884353637695, 43.772938932691304, 37.43686621529715, 38.73777743748256, 38.97404745646885, 39.70568929399763, 37.95089742115566, 39.29672874723162, 43.70520789282662, 52.13687467575073, 52.25297212600708, 49.06210919788906, 46.558707986559185, 47.05003942762102, 50.20718969617571, 51.62883281707764, 47.904772077287944, 47.64075790132795, 44.513005461011616, 48.51054034914289, 46.72416891370501, 49.62704985482352, 50.20139837265015, 51.988912786756245, 47.87680210386004, 51.51705714634487, 48.7370412009103, 51.7749673298427, 52.65803473336356, 52.75107111249651, 52.25551516669137, 54.0733654158456, 53.111581870487754, 54.51973506382534, 50.686031750270296, 49.604496002197266, 35.564983299800325, 25.251803398132324, 8.80315569468907, 9.477568694523402, 11.120508466448102, 7.800110271998814, 9.011666791779653, 8.174156989370074, 4.142509485994067, 2.6951482594013214, 0.5273189842700958, 0.03324004974482315, 0.06234733946621418, 4.843217074871063, 30.116185120173864, 43.22116163798741, 30.016544478280203, 31.419423988887242, 32.14376674379621, 40.18633440562657, 52.213151999882285, 40.598696095602854, 18.19409077508109, 0.35427078711135046, 0.002976200052736593, 0.04460766565586839, 0.020571736485830376, 0.01646066244159426, 0.018499402329325676, 0.05699468204485519, 0.04421111622026988, 0.08666885724025113, 0.0704015569229211, 0.005282688162489129, 0.04344613244757056, 0.06692462813641344, 0.029661306778767278, 0.02634568781858044, 0.039912294929048846, 0.018766684058521475, 0.03744520606206996, 0.027820845001510212, 0.01261529338080436, 0.015970843278669884, 0.004369632781682802, 0.03296699707529374, 0.07043753963496004, 0.15698476268776826, 0.099546318740717, 0.21620117872953415, 0.125667399593762, 0.13262189498969487, 0.10956887129162039, 0.1352808837379728, 0.08937646980796542, 0.1275624121938433, 0.16713913423674448, 0.06735336048794643, 0.15690483126257146, 0.105698405764997, 0.14177483027534826, 0.12971301536474908, 0.11330468832914319, 0.13649453861372812, 0.18132624296205385, 0.0772528335718172, 0.1673689540475607, 1.4009285867214203, 23.425660473959788, 57.148283754076274, 58.593512535095215, 48.09946755000523, 55.95527458190918, 60.03871004922049, 26.05533650943211, 29.156836918422155, 52.26078537532261, 32.06932374409267, 5.0926786831447055, 0.1861453615128994, 0.18400015948074205, 0.7503816719566072, 0.9496411340577262, 6.196598921503339, 13.454303281647817, 16.626462527683803, 17.536732128688268, 17.815109968185425, 21.594087532588414, 36.49472870145525, 47.81640141350882, 57.147085189819336, 57.64490277426583, 57.003914083753315, 57.13194506508963, 52.705376284463064, 51.34130941118513, 51.07534973961966, 53.85385792595999, 50.659656388419016, 50.90901681355068, 49.58968939099993, 48.887771947043284, 53.15216629845755, 54.78159529822213, 52.26836238588606, 53.6611704826355, 51.80550118855068, 52.27336508887154, 49.05065509251186, 49.30668578829084, 49.06063617978777, 52.01267215183803, 53.857248646872385, 54.73413562774658, 53.183367184230256, 53.82612419128418, 51.39296579360962, 54.4445138658796, 49.81340748923165, 42.988042627062114, 38.92534405844552, 39.949341773986816, 39.488304478781565, 41.79729509353638, 43.30042321341378, 50.020727838788716, 50.6283095904759, 52.9732779775347, 51.10953140258789, 55.766360010419575, 50.99644252232143, 54.516729967934744, 38.87889535086495, 23.592552730015345, 47.61799907684326, 49.49084084374564, 56.44566106796265, 52.21216535568237, 52.82425996235439, 48.397183963230674, 46.21810729163033, 38.978251116616384, 40.15216316495623, 41.39746447971889, 41.17302029473441, 40.76472677503313, 42.0880355153765, 45.96457099914551, 55.15033967154366, 54.497281960078645, 49.622290338788716, 46.96878719329834, 46.84285109383719, 51.55181898389544, 52.71674353735787, 50.65257617405483, 50.24787834712437, 47.37600026811872, 50.70297840663365, 48.966074671064106, 53.21194165093558, 53.13172122410366, 54.29959528786795, 50.82187250682286, 54.60793202263968, 51.94150522777012, 53.33462946755545, 54.49743134634835, 56.741108894348145, 55.03745228903634, 57.58619744437081, 56.18678161076137, 55.8732476234436, 54.02725369589669, 50.50255067007882, 38.06172466278076, 29.579429830823624, 12.700139726911273, 23.6068469115666, 18.59929234640939, 9.128148130008153, 13.952278069087438, 17.413729906082153, 7.694387350763593, 3.4484035543033054, 0.5900123087423188, 0.09183077168251787, 0.46204087563923424, 5.868854999542236, 38.376634393419536, 53.4046881539481, 33.087544032505576, 32.15953915459769, 38.65315532684326, 48.26418849400112, 58.63396494729178, 47.997332504817415, 23.0452743938991, 0.7915518656373024, 0.13576933395649704, 0.1391329134681395, 0.1266147294746978, 0.12061805411108903, 0.13441158538418158, 0.16241886466741562, 0.18089584819972515, 0.1423655900039843, 0.12284651239003454, 0.07552275247871876, 0.09596410167536565, 0.13741289504936763, 0.195131512890969, 0.11178726011088916, 0.10418821751539196, 0.13557136457945618, 0.07852871689413275, 0.11927574899579797, 0.1471543644687959, 0.08600662063275065, 0.12471564566450459, 0.12157740763255528], [0.033859301158892255, 0.030744129924901893, 0.02629544908579971, 0.053058914308037074, 0.05887452260191951, 0.024538492916950157, 0.052418204224003215, 0.025522657071373293, 0.008998376882768102, 0.02673143836935716, 0.034727574924805334, 0.019937782914244702, 0.03056486097297498, 0.015065251783068691, 0.009223410477196532, 0.015220081599961435, 0.009608770870337529, 0.08902347553521395, 0.035316455111439736, 0.019753384237576808, 0.011607604417284685, 0.9795025374208177, 20.987150226320537, 46.22488178525652, 47.06070143835885, 39.748611790793284, 30.22725554874965, 23.605573654174805, 18.108841589518956, 32.244988100869314, 35.54395110266549, 15.698016439165388, 0.7700523478644234, 0.04586342362953084, 0.06364344313208546, 0.613747626543045, 0.6812478016529764, 5.266038843563624, 8.079847352845327, 14.113886220114571, 6.935418248176575, 4.914504289627075, 24.25852540561131, 29.39659145900181, 50.343402181352886, 51.11580562591553, 58.448378562927246, 53.429764202662874, 52.81337560926165, 49.54456778935024, 54.554719243730815, 47.761635712214876, 54.02034023829869, 49.07306998116629, 49.90020438602993, 48.08897229603359, 48.02407264709473, 45.94665854317801, 50.94464717592512, 47.68341636657715, 51.06843280792236, 47.32596281596592, 49.235348633357454, 47.19384281975882, 48.02003921781267, 48.29369054521833, 50.31551558630807, 46.117445264543804, 48.78677293232509, 48.023436886923655, 51.05044044767107, 48.19051674434117, 46.97770520618984, 36.64485842841012, 35.11426060540335, 36.15233884538923, 38.087040424346924, 36.301429816654746, 38.94960716792515, 38.185301848820274, 39.13608292170933, 38.235537324632915, 44.914038113185335, 44.042973722730366, 51.077093737465994, 47.52491058622088, 54.199353626796174, 33.32846934454781, 21.348423549107142, 52.76585340499878, 46.33818258558001, 52.997885022844585, 47.49985190800258, 51.59658622741699, 47.047555446624756, 49.568358421325684, 42.90831899642944, 40.42920173917498, 35.621545110430034, 36.898262705121724, 37.06758335658482, 38.07258817127773, 39.203608989715576, 47.91523259026663, 50.09531675066267, 47.48760570798601, 45.038765226091655, 49.30105079923357, 47.959381444113596, 50.46320996965681, 47.36379228319441, 46.20434291022164, 44.63702733176095, 46.362018380846294, 48.65407623563494, 49.85036148343767, 50.254715374537874, 50.161418437957764, 50.58512653623308, 53.270309993198936, 53.49939904894148, 52.15407494136265, 47.40397718974522, 48.20808179037911, 45.53472416741507, 47.79921504429409, 48.55758660180228, 54.65244565691267, 54.68971926825387, 52.97113445826939, 40.40696750368391, 24.255195481436594, 11.304096375192914, 11.481519494737897, 6.378220055784498, 7.1155533364840915, 5.4189013838768005, 4.0729740858078, 5.931880371911185, 0.6558956706098148, 0.19764385665101664, 0.06995791037167821, 0.07585492929709808, 1.7465058203254427, 17.863898481641495, 35.25061552865164, 23.44109068598066, 18.87340920312064, 25.982578447886876, 42.15777805873326, 45.01208414350237, 36.914240087781636, 19.129033429282053, 1.9916314269815172, 0.16249866038560867, 0.034351703843900135, 0.03857549273275903, 0.025797026098838875, 0.05605760482805116, 0.007783565104805997, 0.019643936539068818, 0.057078861099268706, 0.01662802480028144, 0.015641541752432073, 0.019846036498035704, 0.017037047405860255, 0.023477016482502222, 0.01411863521207124, 0.040409745914595466, 0.009811031981371343, 0.020558542372392755, 0.013095590152910777, 0.03339063023616161, 0.02078014682047069, 0.0717464472566332, 0.012336375624207514, 0.013387034514120646, 0.009156004808443998, 0.018846759672409723, 0.03036015374319894, 0.08786047329860074, 0.009359086098681604, 0.01600799137460334, 0.02270145434886217, 0.02176085044629872, 0.006999952153169683, 0.047291834838688374, 0.014708459410550339, 0.03689953837809818, 0.06172333152166434, 0.03509913730834212, 0.02095503922152732, 0.019718950281717947, 0.039379726363612075, 0.01708192062298102, 0.016804650858310715, 0.04490167148677366, 1.4536315415586745, 25.34333722931998, 52.837656089237754, 52.247788769858225, 45.822640146527974, 35.535168579646516, 30.882908412388392, 21.00089376313346, 29.928931168147496, 39.488148144313264, 16.712997129985265, 1.4233645371028354, 0.03934594549770866, 0.149613565366183, 0.43969498042549404, 2.4706938692501614, 5.597467482089996, 12.806344679423741, 14.595505816595894, 6.3539886474609375, 7.480892658233643, 17.771951232637676, 30.79652840750558, 50.087062290736604, 52.72053377968924, 57.511966364724294, 54.88168062482561, 53.89271572657994, 50.03095211301531, 54.47377273014614, 48.66283791405814, 51.743464197431294, 48.57869175502232, 50.01217460632324, 49.180110454559326, 48.24648795809065, 46.25057622364589, 51.091087409428184, 50.74989264351981, 51.88402278082711, 49.18884434018816, 48.40767921720232, 47.198536327907014, 48.27335316794259, 50.11926024300711, 52.41909660611834, 48.34234183175223, 51.157727582114084, 50.18411125455584, 53.118203503744944, 51.679346220833914, 48.594036851610454, 39.8159294128418, 37.53951890127999, 38.47605616705758, 38.89975036893572, 37.551622663225444, 40.2734682900565, 39.27672140938895, 41.06776550837925, 41.80550439017159, 46.04583018166678, 46.951117924281526, 52.944078172956196, 50.29182570321219, 55.32618120738438, 34.372870445251465, 22.400445086615427, 53.71921225956508, 46.22237001146589, 54.17144618715559, 48.91099977493286, 52.6299466405596, 48.3083165032523, 49.90787519727434, 44.97106545312064, 41.94798762457711, 37.324510369982036, 37.56305939810616, 38.764104161943706, 39.19322838102068, 40.487938335963655, 49.2240161214556, 52.84238086427961, 48.28069741385323, 45.95318637575422, 48.705121176583425, 48.193362031664165, 50.455111844199045, 48.99661200387137, 47.744834968021934, 47.82110186985561, 49.15148040226528, 49.046645981924875, 51.506891931806294, 52.548607553754536, 52.09959064211164, 51.740632806505474, 53.49982288905552, 55.81313180923462, 54.373440742492676, 48.57613481794085, 49.07407052176339, 48.05155624662127, 52.530160086495535, 50.4321619442531, 54.46101583753313, 55.882433141980854, 53.58536216190883, 40.92565747669765, 23.653655188424246, 11.681641510554723, 7.958876609802246, 9.674584865570068, 10.678002016884939, 9.2276063816888, 8.973691412380763, 5.22355625459126, 1.8485269801957267, 1.2986317787851607, 0.09305599558034114, 0.12837502573217663, 2.132189358983721, 19.815437282834733, 38.60372584206717, 23.992534467152186, 22.269209248679026, 33.36760854721069, 47.73183488845825, 51.34203897203718, 44.28683812277657, 24.220928703035625, 2.751113827739443, 0.08737209771892854, 0.046201652980276516, 0.02206726498635752, 0.02936061398525323, 0.022113157702343803, 0.016730780447168008, 0.03813655860722065, 0.05493002551208649, 0.022686672463480915, 0.04422211188024708, 0.03382457034396274, 0.0695587010788066, 0.04870960322607841, 0.030930028163961003, 0.01351331836277885, 0.01882030868104526, 0.03623301682195493, 0.030450113915971348, 0.021429932310378978, 0.006463658430480531, 0.03046385764277407, 0.0361289600841701, 0.1082798990287951, 0.12543584273329803, 0.09861506335437298, 0.11740086174436978, 0.21825461568576948, 0.19359837658703327, 0.14527669522379125, 0.1406863515398332, 0.07103192274059568, 0.10231349311236825, 0.21600763340081486, 0.08957475809646503, 0.145278432273439, 0.10599803325853177, 0.1655935128884656, 0.10360089117395026, 0.1659615502825805, 0.13232490021203244, 0.15939044074288436, 0.13919558296246187, 0.14150033571890422, 2.4696429542132785, 30.263038771493093, 61.219466073172434, 59.87941564832415, 51.813703536987305, 42.55054235458374, 34.48393045152937, 25.91958781651088, 42.76456076758248, 45.62222283227103, 20.74009312902178, 1.6197464678968703, 0.19138768235487597, 0.40256291148918016, 1.1848808654717036, 3.2515953949519565, 13.082334075655256, 17.064303261893137, 23.066546303885325, 15.075589861188616, 8.479855145726885, 25.155998161860875, 33.14008631025042, 53.0539048739842, 53.472856930324006, 60.45321873256138, 55.20413957323347, 56.142396518162315, 50.44709709712437, 54.177428586142405, 48.29206466674805, 52.70349679674421, 50.371142864227295, 52.44749736785889, 49.38198341642107, 48.40751246043614, 47.14015408924648, 52.01050083977835, 50.19931391307286, 54.54912941796439, 49.76055254255022, 50.21797330038888, 49.22432879039219, 48.46385192871094, 50.63787031173706, 55.415403025490896, 50.41687590735299, 53.64083310535976, 52.699796880994526, 55.037580830710276, 54.43405335290091, 49.86781188419887, 41.803037779671804, 40.018868923187256, 39.93427807944161, 41.00848695210048, 39.85393605913435, 42.58514438356672, 42.48717825753348, 42.587958403996055, 42.92503636223929, 47.37717798777989, 47.699782848358154, 53.31737014225551, 51.04561144965035, 54.875739915030344, 35.49847861698696, 24.95437707219805, 52.475151198250906, 49.5954008102417, 55.09039061410086, 50.852013792310444, 54.90894883019583, 51.63687188284737, 52.239169529506135, 46.98578248705183, 45.214273248400005, 39.80709477833339, 39.28222785677229, 39.84387159347534, 42.41241216659546, 42.72546672821045, 52.46411745888846, 55.83470596585955, 48.353170599256245, 45.674195357731406, 49.84210007531302, 49.35735552651541, 53.213053362710134, 52.33969259262085, 49.43127046312605, 48.69251019614083, 50.57003157479422, 53.16022968292236, 54.616280283246724, 54.18760074887957, 53.500948497227256, 54.03098835263933, 56.61741358893258, 57.33553423200335, 54.794334820338655, 50.061364378247944, 49.67284543173653, 48.493211541857036, 51.80907603672573, 51.36866446903774, 59.211158752441406, 59.67495100838797, 57.75795691353934, 46.992348534720286, 30.669345106397355, 15.978794881275721, 18.90415324483599, 13.386498417173113, 17.56811019352504, 15.800472838538033, 8.303000041416713, 16.619074855531963, 2.7330291867256165, 1.0887919472796577, 0.38798702933958595, 0.38050930202007294, 2.4305150423731123, 23.789205857685634, 46.03123549052647, 33.560122285570415, 28.4097683429718, 39.204147475106375, 53.46342127663748, 58.623612131391255, 52.55509369713919, 29.851604666028702, 4.157244878155844, 0.32753949293068474, 0.2744261329727513, 0.11610538911606584, 0.12678109269057, 0.0967853936765875, 0.11272489372640848, 0.07731006800064019, 0.11366456294698374, 0.13592220789619855, 0.10710438460643802, 0.13876935440514768, 0.13473298028111458, 0.15084760343389852, 0.08866086642124824, 0.17171860778970377, 0.10152419403727565, 0.1416724393410342, 0.12342366070619651, 0.09692690215472664, 0.08139540521161896, 0.20427752711943217, 0.10107151618493454], [0.031734587491622994, 0.03062282143426793, 0.043433297957692824, 0.005245791548596961, 0.056096508633345366, 0.002027654745948634, 0.028211989905685186, 0.04577897994646004, 0.011085983166205031, 0.012937248917296529, 0.02947651455178857, 0.0580468320154718, 0.03112536482512951, 0.052515221160969565, 0.036186337005347013, 0.02002415363676846, 0.036876220522182326, 0.05616900670741286, 0.012724044732749462, 0.05618567831282105, 0.015344482513942888, 1.9884756420339857, 27.20644109589713, 47.33613845280239, 46.612219538007466, 34.12887750353132, 22.764520270483835, 14.44626806463514, 15.357865640095302, 35.86569786071777, 29.64703232901437, 8.878368207386561, 0.3879447430372238, 0.023707445278497677, 0.18572511763444968, 0.12823329333748135, 1.5590589472225733, 2.97820788196155, 15.108649390084402, 14.795207466397967, 1.5817767339093345, 9.878164478710719, 18.69021647317069, 33.18033375058855, 49.00011042186192, 51.24519845417568, 49.7954637663705, 51.58037608010428, 49.81695454461234, 50.26748616354806, 52.75882530212402, 53.530266421181814, 49.94825117928641, 48.554977553231375, 50.03525652204241, 47.06637116840908, 47.81068304606846, 48.62333393096924, 48.138307980128694, 50.27963161468506, 48.72058439254761, 46.64612327303205, 45.933981554848806, 45.93831375667027, 46.95676680973598, 49.33053895405361, 48.38637951442173, 46.594373089926584, 39.3163400377546, 37.92324011666434, 40.28220912388393, 39.15700394766671, 35.60415376935686, 35.468573570251465, 34.725130217415945, 35.37849712371826, 40.723926952907014, 42.43481663295201, 45.64705569403512, 42.540686334882466, 41.80900280816214, 40.73361274174282, 42.6494916507176, 42.4286778994969, 50.07987437929426, 47.26620135988508, 54.56097262246268, 29.277596609933035, 22.27479212624686, 55.52212388174874, 42.8060519354684, 51.24591064453125, 45.63959680284773, 50.15112120764596, 46.99589211600167, 50.885552746909006, 49.18285846710205, 50.189718450818745, 40.85071420669556, 36.14607157026018, 35.74773134504046, 37.34088727406093, 36.35420485905239, 44.032071999141145, 48.77286263874599, 49.95226723807198, 44.555247034345356, 46.758732727595735, 47.923956053597585, 49.54830592019217, 50.65770394461495, 51.343584946223665, 49.07051304408482, 50.419995648520334, 48.57667677743094, 48.72618464061192, 46.24448265348162, 49.08549336024693, 49.94231046949114, 48.05905335290091, 49.64890193939209, 51.353764057159424, 46.491727352142334, 46.67619160243443, 46.390078680855886, 46.36228936059134, 50.698792116982595, 49.255415030888145, 40.186066899980815, 39.80652502604893, 38.77635383605957, 33.62371219907488, 14.42426746232169, 7.46031209400722, 11.646402852875845, 6.621591567993164, 6.923778278487069, 9.814995799745832, 2.7022454099995747, 3.1213244880948747, 1.1074514431612832, 0.05431869260168501, 0.05230762676468917, 0.3103687571627753, 8.821211457252502, 34.489516803196494, 41.52162184034075, 23.0536139692579, 17.32411551475525, 30.309414522988455, 45.118676458086284, 47.740360328129356, 34.478021008627756, 4.673302786690848, 0.060855702364018986, 0.013645317172631621, 0.033023725995527844, 0.04435847027759467, 0.00461328198434785, 0.020517066919377873, 0.04899221984669566, 0.002056825390484716, 0.030525064894131253, 0.041823721291231256, 0.0508371158502996, 0.05373683185981853, 0.03678076760843396, 0.013011204145316566, 0.018865768830957155, 0.06748251284339599, 0.019179279150973474, 0.017385115514376333, 0.05615240974085672, 0.03313518215769103, 0.02236972705993269, 0.02901136183312961, 0.044120151815669875, 0.013677747753847922, 0.01887194180328931, 0.04017619416117668, 0.08794478806001799, 0.032175282415534766, 0.04768951403509293, 0.028413184020402174, 0.07401343953928777, 0.028798186486320834, 0.02179965586401522, 0.046061647457203696, 0.02936297867979322, 0.008514939341694117, 0.008958497683384588, 0.05911551109914269, 0.030854592033262764, 0.05322325888222881, 0.02518239720458431, 0.1496962516435555, 0.024555166218695895, 3.2164331674575806, 32.001874106270925, 53.682828017643516, 50.58567891802107, 39.74478333336966, 28.16242810658046, 22.21139849935259, 22.867582900183542, 34.30523668016706, 33.31002535138811, 9.858305658612933, 0.5273025365812438, 0.018933016740317856, 0.08561076330287115, 0.36147167214325493, 4.763821312359401, 6.609643271991184, 10.3585490328925, 11.987237180982317, 5.9613025188446045, 10.82743431840624, 21.613787412643433, 36.36797271456037, 50.86124447413853, 52.53388432094029, 50.785005365099224, 53.08832972390311, 50.72056777136666, 51.01920829500471, 52.43507398877825, 52.709885665348594, 51.714007309504915, 49.06650045939854, 49.635092394692556, 47.216966424669536, 47.798784255981445, 48.12858050210135, 47.539376735687256, 48.8239666393825, 49.2321628843035, 46.93886477606637, 47.419958046504426, 46.5797575541905, 46.71460124424526, 50.12573248999459, 50.46692030770438, 47.3995338167463, 43.21214287621634, 40.67911802019392, 42.87919214793614, 42.99002286366054, 37.86938115528652, 36.93996926716396, 37.223570414951865, 37.57286678041731, 43.55425827843802, 43.94784246172224, 45.24097170148577, 43.760393960135325, 43.671356269291465, 42.620667048863, 43.671648093632285, 44.35298844746181, 52.59425374439785, 48.48520721708025, 55.534144265311106, 29.525299889700754, 24.841277769633702, 55.083095005580354, 42.66019535064697, 50.99402454921177, 47.506841795785085, 50.183173247746055, 49.85032674244472, 53.222016538892476, 51.569265910557334, 51.75128786904471, 42.16756807054792, 37.81683887754168, 36.70650632040841, 39.41288525717599, 38.01559557233538, 47.26018074580601, 52.15523181642805, 52.04637091500418, 44.46385390417916, 46.078507559640066, 48.86488110678536, 50.167029108319966, 52.33645820617676, 52.97478573662894, 50.64956065586635, 50.68223455974034, 50.1316488810948, 49.95345190593174, 48.45090396063668, 50.31855194909232, 52.500748361860005, 49.7787846156529, 51.2221234866551, 51.1334262575422, 47.06022548675537, 47.459865025111604, 46.54146950585501, 48.31350333350045, 51.97206687927246, 51.397489070892334, 44.73006023679461, 41.57963235037667, 39.69965478352138, 33.68489803586687, 15.165456124714442, 7.900156514985221, 6.19057092496327, 7.440277831895011, 10.206923706190926, 8.961869052478246, 6.889266141823359, 6.348204272133963, 1.9541910588741302, 0.129821295983025, 0.018123136001772115, 0.417771893952574, 9.979117461613246, 38.43278973443167, 40.779641083308626, 25.482025010245188, 22.865345580237253, 36.99123307636806, 48.98017604010445, 53.869929109300884, 41.15855067116873, 6.622127447809492, 0.1340853457472154, 0.022731023208637322, 0.02067171692449067, 0.02482624095864594, 0.037919932909842045, 0.02629750165423112, 0.04528104720105018, 0.049264644871332815, 0.029709679540246725, 0.05233120246391211, 0.05586232244968414, 0.09512542560696602, 0.024755249232319847, 0.015449560446930783, 0.06924796596701656, 0.024421693291515112, 0.07857850779380117, 0.0677185548203332, 0.066168590847935, 0.029541077158812965, 0.030165577041251317, 0.039074365249169726, 0.12079265474208764, 0.19259322195180825, 0.11478939758879797, 0.10548643821052142, 0.19502099310713156, 0.06178652348795107, 0.08056617435067892, 0.1558379027992487, 0.12631341921431677, 0.09361677084650312, 0.1008745985371726, 0.13365242683461734, 0.12185172576989446, 0.14796007052063942, 0.2175858515713896, 0.2314946252320494, 0.11924757622182369, 0.204542481473514, 0.1320794333836862, 0.2351196307156767, 0.08429481248770442, 4.2845892906188965, 40.06285796846662, 62.061462674822124, 57.73045941761562, 45.9245285306658, 34.473747866494314, 24.268890380859375, 23.17000845500401, 46.07068041392735, 38.90723705291748, 11.488619685173035, 0.6464616996901376, 0.14376554345445974, 0.41785456665924614, 0.36916243231722284, 6.86571695974895, 10.87106726850782, 23.911902359553746, 23.866197109222412, 6.331899455615452, 13.476033772741046, 21.999622617449077, 36.85077176775251, 51.92189046314785, 52.54782935551235, 51.10949318749564, 53.575304644448416, 51.039493560791016, 50.111648491450715, 51.98054368155343, 54.13787249156407, 52.66617802211216, 48.68645831516811, 50.96691962650844, 47.308171953473774, 48.049152169908794, 48.217090129852295, 48.22273554120745, 50.512900011880056, 49.67122997556414, 47.11301442555019, 47.39545522417341, 48.14803198405674, 46.866575717926025, 52.19532987049648, 52.42129571097237, 49.90211861474173, 43.89824622017996, 42.31973361968994, 44.27674239022391, 44.29331731796265, 38.55553661073957, 39.94349833897182, 37.71011107308524, 40.75327614375523, 45.86406530652727, 46.516629695892334, 48.33394840785435, 46.03818021501814, 46.83275188718523, 45.10773999350411, 45.642758233206614, 46.1760185786656, 55.49445962905884, 52.50470188685826, 55.04648494720459, 31.41021067755563, 27.013604266302927, 54.13854994092669, 43.029512950352256, 50.6282296861921, 47.692150252205984, 51.99251195362636, 50.39793511799404, 54.04403012139456, 54.09020784923008, 54.665056637355256, 44.646132946014404, 39.69289418629238, 39.170601572309224, 41.445935113089426, 39.92147254943848, 48.99571221215384, 53.91983454568045, 53.7065179007394, 44.34647103718349, 46.57911137172154, 49.4472200529916, 51.31686912264143, 54.60892908913748, 56.103886127471924, 52.009184156145366, 53.120923723493306, 50.81056431361607, 51.35720688956124, 49.53388493401663, 51.31964145387922, 53.441291264125276, 50.788694858551025, 51.88986621584211, 52.43024846485683, 47.30552121571132, 47.90916681289673, 47.33010394232613, 48.42048822130476, 53.40916974203927, 53.85768290928432, 45.035120895930696, 43.62401124409267, 41.65398154939924, 38.76259292875017, 20.078833069120133, 16.587031500680105, 25.138203825269425, 15.836097989763532, 14.31207663672311, 20.029483488627843, 7.9008608886173795, 7.305880563599723, 2.6390302649566104, 0.24285134726337024, 0.12594121561518737, 0.6096494378788131, 11.87146542753492, 45.35944196156093, 53.813881465366904, 34.21175561632429, 25.31102636882237, 41.194559710366384, 55.77926281520298, 61.61938353947231, 48.584469182150706, 8.860658117703029, 0.25103977216141565, 0.12968671534742626, 0.10392651334404945, 0.14404837042093277, 0.1145018208771944, 0.2106605874640601, 0.12699488550424576, 0.13029637906168187, 0.10572898733828749, 0.12243067898920604, 0.1750642332647528, 0.19196548206465586, 0.0787159518471786, 0.1534758409751313, 0.14216561216328824, 0.1619746142200061, 0.13094572350382805, 0.14245709723659924, 0.16620485936956747, 0.08252002950757742, 0.15510953616883072, 0.12915097123810224], [0.01819763405780707, 0.03818716035623636, 0.009594496189882713, 0.03842714122895684, 0.0467011327855289, 0.025153707047658305, 0.10721376445144415, 0.03699331531035049, 0.005077693827583322, 0.04394441803119012, 0.026652808035058633, 0.046701275277882814, 0.07807189997817789, 0.020725192269310355, 0.05872610663729055, 0.03433849276708705, 0.018053765974140594, 0.11385128221341542, 0.08825375219540936, 0.06308772973716259, 0.03295454256502645, 5.4862276911735535, 31.482899257114955, 49.84038387026106, 47.925363063812256, 38.560400349753245, 23.117158719471522, 14.795679943902151, 18.91227568898882, 43.71517855780465, 25.62464026042393, 4.351794872965131, 0.046826705868755064, 0.07371040579995938, 0.008117243181914091, 1.167503529361316, 2.3033784244741713, 5.314329258033207, 11.682634234428406, 10.365528498377119, 5.573745897838047, 9.120788250650678, 22.848586525235856, 34.64526414871216, 50.35992152350289, 52.7858954838344, 53.000862325940815, 51.97264705385481, 50.608736515045166, 50.13670369556972, 53.33726978302002, 50.9946950503758, 48.61429779870169, 48.25870289121355, 49.12582070486886, 49.11452988215855, 48.80740213394165, 48.223426886967246, 47.243355682918, 47.68667507171631, 50.282431738717214, 45.90994773592268, 47.097308022635325, 45.309835297720774, 46.937079089028494, 48.00260966164725, 46.20754950387137, 41.85743522644043, 37.61920084272112, 36.23005444662911, 36.56082344055176, 33.827238832201274, 34.616415228162495, 33.65089702606201, 37.343947955540244, 40.358618463788716, 45.576764242989675, 46.30493198122297, 48.65646989004952, 47.374878134046284, 49.61485924039568, 47.185623100825715, 49.83455433164324, 46.44577891486031, 51.28070027487618, 46.85425656182425, 55.28162240982056, 23.397129433495657, 22.700987679617747, 54.0570718901498, 43.99872759410313, 48.382488523210796, 43.267971651894705, 48.331447056361604, 43.581095695495605, 47.163618155888145, 46.047859055655344, 49.75225986753191, 45.7904908316476, 41.25387300763811, 35.546831130981445, 37.770230361393516, 35.98126029968262, 40.90662636075701, 48.62393147604806, 50.417706217084614, 46.293436186654226, 46.728462900434224, 46.26128339767456, 46.98461866378784, 49.32514715194702, 47.95708506447928, 49.1563788822719, 46.217631340026855, 45.49205527986799, 44.63084690911429, 44.9409693309239, 46.65717090879168, 46.37977450234549, 46.95946618488857, 45.63704333986555, 46.99732344491141, 48.87084266117641, 46.91595656531197, 46.72987338474819, 45.4327906199864, 45.02336801801409, 44.16371604374477, 40.274194376809255, 32.01548910140991, 23.701384101595195, 18.757556676864624, 18.14256467138018, 8.534866639545985, 4.88536137342453, 6.875863066741398, 6.541446702820914, 5.948965557983943, 3.183737333331789, 2.299913444689342, 2.2524969833237782, 0.14327971238110745, 0.028514894723360027, 0.1796529484646661, 3.0634062588214874, 25.195432662963867, 34.092420305524556, 26.858794927597046, 20.354523692812236, 32.18277393068586, 39.93439619881766, 44.51118155888149, 37.53005198069981, 10.62184580734798, 0.4475480190345219, 0.010630151822364755, 0.009986580865058516, 0.053213233527328284, 0.012656890121953828, 0.021312654317755784, 0.03395085249628339, 0.027050731504069905, 0.028400692190708857, 0.024144801810117703, 0.033844787294843366, 0.01783506395960493, 0.01937591690304024, 0.009059822469550585, 0.03514048723237855, 0.026112027499558668, 0.007411986606062523, 0.03198888545323696, 0.0350556669623724, 0.03670593198122723, 0.05202364628868444, 0.041205446967589, 0.0316843826855932, 0.05794860728617225, 0.027135629805603197, 0.02028350668427135, 0.021681531398956264, 0.03392845405531781, 0.02738730183669499, 0.05399402377328702, 0.01818979867467923, 0.02477178004171167, 0.047862136736512184, 0.03210577328822442, 0.011733123217709363, 0.04547053489035793, 0.05510856843154345, 0.07701101726187126, 0.0009155204773248572, 0.12025928550532886, 0.07926240323909692, 0.04325824949358191, 0.043325940147042274, 6.553947380610874, 36.47797312055315, 55.97332600184849, 53.49443456104824, 42.05114752905709, 26.602378606796265, 19.083095414297922, 19.595865522112163, 36.8077380997794, 27.555697509220668, 5.186876714229584, 0.15184011017637594, 0.10852934885770082, 0.5022444554737636, 2.198004650218146, 5.938696988991328, 6.362559250422886, 12.532714196613856, 9.154662455831255, 10.941234520503453, 12.14734365258898, 26.952164820262364, 36.943196705409456, 50.29986824308123, 53.90658780506679, 53.23102140426636, 52.287671429770334, 52.87176479612078, 50.21881055831909, 52.80907814843314, 51.85074438367571, 49.15428400039673, 48.67321852275303, 49.73606709071568, 50.09040437425886, 50.26154545375279, 48.4618056842259, 47.18332324709211, 48.64073569434029, 49.57629326411656, 46.03830528259277, 47.406047752925325, 46.05825703484671, 48.49976716722761, 49.71397181919643, 49.75561932155064, 44.411481857299805, 38.9379689352853, 38.18868909563337, 39.11806624276297, 35.97829341888428, 36.62071343830654, 35.544875213078086, 38.55856602532523, 41.05288246699742, 48.35244798660278, 47.85561357225691, 49.36195175988333, 48.40653623853411, 51.09124026979719, 48.80315678460257, 50.27497284752982, 48.68409940174648, 53.6528708594186, 46.78849186216082, 54.716448988233296, 24.696150745664323, 24.020827531814575, 52.86378826413836, 43.09545135498047, 48.517537185123985, 43.45146662848336, 50.367290088108604, 43.96057503564017, 48.83880451747349, 47.62730966295515, 52.13715260369437, 48.2605858530317, 42.46212305341448, 37.580916268484934, 39.60846662521362, 38.21317107336861, 42.824402127947124, 49.67196648461478, 52.86741174970354, 46.965608392442974, 47.00138119288853, 47.27493177141462, 48.47729321888515, 51.07217788696289, 50.350468499319895, 50.51664509092058, 47.601323400224956, 46.15276295798165, 45.47587292534964, 46.971757548195974, 47.439715249197825, 46.6129595211574, 47.32517766952515, 47.73745598111834, 47.0379912512643, 50.19102471215384, 47.32607051304409, 47.084030015128, 46.61560331072126, 48.038170542035786, 49.264155864715576, 45.35759721483503, 35.07298135757446, 24.482208762850078, 21.193145206996373, 16.749819108418055, 9.64870195729392, 5.182658289160047, 7.256501887525831, 11.170315759522573, 12.524155752999441, 6.40094370501382, 6.640902783189501, 2.6664899800504958, 0.4556815911616598, 0.06657272630504199, 0.2735479458102158, 4.245795326573508, 29.871563366481237, 38.348473344530376, 29.40254953929356, 21.873154980795725, 36.56314761298043, 47.61947556904384, 49.20505101340157, 44.36925070626395, 14.043447988373892, 0.5681341684290341, 0.05586526050631489, 0.04010965023189783, 0.03702178324705788, 0.049479292639132054, 0.011663481776070381, 0.010068111936561763, 0.02200990672489362, 0.02253865683451295, 0.03182090053867016, 0.00376332357492564, 0.009341359371319413, 0.06694463813411337, 0.07941360119730234, 0.0022305812453851104, 0.012984022032469511, 0.06090636857386146, 0.031189445672290664, 0.04297543270513415, 0.021671312661575418, 0.03355211817792483, 0.017166118337107555, 0.0788973378283637, 0.1583871045815093, 0.11987615749239922, 0.11828073167375155, 0.1162508534533637, 0.10814879927784204, 0.19022894810353005, 0.1099242540076375, 0.1978984565607139, 0.15227289338197025, 0.14323343629283564, 0.16290572711399623, 0.1519132698220866, 0.09708890239042894, 0.18003539794257709, 0.1068605055500354, 0.09650648864252226, 0.24420209335429327, 0.15590273003493035, 0.15877608156629971, 0.12856649474373885, 8.570622938019888, 44.57325676509312, 63.47775568280901, 60.21792493547712, 48.80629389626639, 33.66759007317679, 22.30343607493809, 26.59779453277588, 53.553813866206575, 32.567071846553254, 6.294787389891488, 0.3400061625455107, 0.2694660962692329, 0.48673347064426964, 3.1533700142587935, 5.151921629905701, 12.498676708766393, 24.78524054799761, 19.94553014210292, 10.152832848685128, 11.973043748310634, 26.017163106373378, 37.95271437508719, 51.963930538722444, 54.07926096235003, 52.50210326058524, 52.50566073826381, 51.681458473205566, 51.02760171890259, 53.07809155327933, 51.58400651386806, 49.36923347200666, 50.37379707608904, 50.539754799434114, 52.74979611805507, 50.56521994726998, 48.37261860711234, 47.249351978302, 49.39871120452881, 50.31359093529837, 46.49966219493321, 47.357365199497764, 47.07600137165615, 49.77857616969517, 50.98893846784319, 51.40831783839634, 46.63254301888602, 40.991696630205425, 41.2745577948434, 40.9906405040196, 38.01328877040318, 38.862306526729036, 36.76774079459054, 40.268569810049875, 43.95057657786778, 50.44098615646362, 50.43260662896292, 52.14538621902466, 51.113068035670686, 53.64480400085449, 51.15592452457973, 53.29297501700265, 51.3063599722726, 54.98789773668562, 49.1957300049918, 54.73495551518032, 26.35859063693455, 27.28053321157183, 53.1385999407087, 45.26128823416573, 48.530530316489084, 44.05240937641689, 50.8116204398019, 44.959031173161094, 49.29690619877407, 48.42024850845337, 53.53427900586809, 51.6483815738133, 44.92586742128645, 38.99468013218471, 41.42271423339844, 40.24644674573626, 45.15830203465053, 53.00430515834263, 55.185389859335764, 48.264449051448274, 47.18945155824934, 47.17159816196987, 49.00209413255964, 51.41765621730259, 49.96602814538138, 51.95336927686419, 47.27515411376953, 45.877204350062776, 46.96785613468715, 45.20579297201974, 47.226113728114534, 46.58327334267752, 47.04073231560843, 46.49955102375576, 47.58493954794747, 49.422015462602886, 47.828633717128206, 47.869853905269075, 46.611472606658936, 49.61852788925171, 49.65095165797642, 48.71753413336617, 39.58520058223179, 30.078581469399587, 24.277589525495255, 22.200797285352433, 13.267329863139562, 14.639569555010114, 14.63064980506897, 12.380384496280126, 16.018425668988908, 10.72734464917864, 6.961516984871455, 4.743954241275787, 0.9782341654811586, 0.1662942495729242, 0.5314640732748168, 4.837229464735303, 34.6665221623012, 46.673134395054404, 38.16507911682129, 30.59009395326887, 43.914456367492676, 52.91671964100429, 56.508472783224924, 50.8910105569022, 18.703202656337194, 1.0327878381524767, 0.10934089031070471, 0.11033326813152858, 0.2197396167154823, 0.11786670317607266, 0.07156092221183435, 0.0645037983943309, 0.16784168939505303, 0.10284244508615561, 0.06784765289298125, 0.11516593024134636, 0.09967886377125978, 0.12864166285310472, 0.1667720332209553, 0.08365764774914299, 0.1694900273744549, 0.13975323018218788, 0.1452083938888141, 0.20193831835474285, 0.08115969571684088, 0.15442250589174883, 0.12079897868846144], [0.036226933755512745, 0.051615290343761444, 0.044271254778972695, 0.059728621771293025, 0.035320363473147154, 0.05017243651673198, 0.003482499559010778, 0.029595454955207448, 0.036579276634646316, 0.015363064195428575, 0.04520578409678169, 0.04054124939388462, 0.03411092908520784, 0.027534338678898554, 0.11712946130761079, 0.02195323208746101, 0.04865162919408508, 0.05680265324190259, 0.09992274961301259, 0.03345304527985198, 0.17154818693442003, 8.6330611876079, 37.17641299111502, 49.76542670386178, 47.47574513299124, 35.38019248417446, 19.969272136688232, 14.09330826146262, 26.524473667144775, 40.61011545998709, 20.600608042308263, 1.8248418739863803, 0.047477509161191325, 0.09084986788885933, 0.159745952380555, 3.6420018630368367, 8.574311562946864, 4.734476029872894, 6.386042424610682, 5.65910712310246, 13.21457132271358, 12.729773793901716, 30.99835273197719, 42.53582606996809, 48.03989022118704, 53.78269100189209, 49.09343862533569, 52.20150681904384, 48.3541259765625, 49.34325763157436, 49.37268672670637, 46.53599085126604, 48.107534408569336, 48.759376185280935, 48.71685320990426, 46.83963060379028, 49.06609051568167, 49.519189493996755, 50.392751761845176, 48.50483240400042, 47.02524825504848, 48.177704266139436, 45.345455237797324, 46.283152852739605, 47.528801577431814, 47.61413587842669, 46.23678404944283, 42.026001998356406, 36.43118742534092, 34.31006220408848, 36.74997425079346, 35.57013191495623, 35.03211900166103, 37.04222937992641, 40.99175916399275, 46.41231986454555, 49.053455216544016, 49.27844483511788, 50.77030297688076, 49.26443379265921, 51.931458132607595, 48.025733266557964, 50.26640919276646, 47.87335927145821, 53.44326802662441, 45.96569660731724, 54.10291610445295, 24.700354405811854, 23.36138095174517, 52.547492367880686, 43.27347115107945, 51.46185023444039, 46.05950771059309, 50.48613902500698, 47.8759891646249, 50.3014281136649, 43.95872334071568, 49.42509004047939, 46.58431557246617, 41.131970337459016, 35.86031995500837, 37.93793903078352, 34.54540811266218, 37.10967206954956, 43.26670707975115, 50.43678249631609, 48.021123136792866, 49.661064761025564, 45.280628544943674, 46.10296869277954, 45.36521244049072, 46.394761766706196, 43.85150221415928, 44.1689132962908, 43.45787286758423, 47.98313733509609, 43.34471797943115, 42.96104192733765, 46.33484745025635, 44.77427509852818, 42.90231575284685, 46.71797806876046, 46.263208048684255, 47.06456116267613, 47.08245277404785, 51.50708300726754, 52.158803190503804, 49.67323453085763, 43.63945361546108, 42.92854520252773, 36.075842653002056, 23.235946859632218, 14.262208546910967, 11.25850316456386, 5.920612130846296, 6.779168461050306, 15.772073813847133, 8.754232559885297, 5.213575601577759, 10.462257845061165, 2.9111121680055345, 0.27257823784436497, 0.06199193639414651, 0.030782141456646577, 1.0751919341938836, 17.548186234065465, 37.68825898851667, 23.44072937965393, 16.455158165522985, 32.28029537200928, 44.96679925918579, 44.36351496832711, 45.815035343170166, 17.703904049737112, 1.83469072835786, 0.014918248867616057, 0.01599437996212925, 0.027542362355494072, 0.0653475159779191, 0.03191978683961289, 0.02389077695884875, 0.0081674666476569, 0.06627877136426312, 0.040057369108710966, 0.06382738719029085, 0.020507416455075145, 0.08018048826072897, 0.05102043565628784, 0.026197495770507624, 0.011514010689487415, 0.05765362097216504, 0.003098578084193702, 0.0945899732677, 0.05004289061097162, 0.027486566420910612, 0.08695695642381907, 0.04846271486686809, 0.020433802190901976, 0.05494467169046402, 0.006394130219372788, 0.03408161637240222, 0.04559530390958701, 0.02756299151639853, 0.010962935081417007, 0.014472037454002669, 0.03238171312425818, 0.032212289715451856, 0.041195479288165054, 0.06913923751562834, 0.0165652654000691, 0.06564887373575143, 0.023867586328248893, 0.040414797607809305, 0.023999378184920976, 0.04970783680411322, 0.046762879472225904, 0.1524706727692059, 10.434503265789576, 42.68381575175694, 55.631155014038086, 53.057354654584614, 42.48960665294102, 28.400850330080303, 17.593047278267996, 22.915641852787562, 41.37926367350987, 22.382682016917638, 2.5656331862722124, 0.033760560742978535, 0.12304963863321713, 0.11649678168552262, 4.63818268265043, 9.159214394433157, 10.35305300780705, 10.385513254574366, 11.714940752301898, 15.424029861177717, 12.597912618092128, 30.317345891680034, 41.954894133976524, 49.59385136195591, 54.80496556418282, 49.52296583993094, 52.149739265441895, 48.76549754823957, 49.85014261518206, 49.798903124673025, 47.11459166663033, 48.91786459514073, 49.570939677102224, 52.02381011417934, 48.57628420421055, 51.540524687085835, 50.329123633248464, 51.363599232264924, 48.04322188241141, 46.943735463278635, 48.91008956091744, 45.35090957369123, 47.57520512172154, 49.2955756187439, 48.68462746483939, 47.80875144686018, 43.90768534796578, 39.24465894699097, 37.034051350184846, 38.525405747549875, 36.846648011888774, 36.684834889003206, 37.70196431023734, 42.81521660940987, 49.29452991485596, 52.62843540736607, 50.554349490574424, 52.07136011123657, 50.620305265699116, 53.461493151528494, 50.26977906908308, 51.57376486914498, 48.53767653873989, 53.49426433018276, 47.33842788423811, 53.50366176877703, 26.091626950672694, 25.0821144921439, 50.82092407771519, 43.8389607157026, 51.9302248273577, 47.72223942620413, 52.3014566557748, 49.19733851296561, 51.4634622165135, 46.056408814021516, 50.391455922807964, 48.52525315965925, 43.58602196829659, 37.80816057750157, 38.79163987295968, 36.04594802856445, 38.19913223811558, 46.225562708718435, 52.86718593324934, 49.382605280194966, 50.562722069876536, 46.69221414838518, 46.101856981004985, 45.63871785572597, 46.38295677730015, 43.843574319567, 45.099339621407644, 43.656539235796245, 46.63660771506173, 45.428816250392366, 45.56057146617344, 45.66787944521223, 46.09367200306484, 43.18011168071202, 45.320247173309326, 47.013116700308665, 47.42593002319336, 47.8469352722168, 51.23767702920096, 51.60985728672573, 51.36852203096662, 45.45183910642351, 46.75095074517386, 40.10557549340384, 24.377490724836075, 15.420157977512904, 11.417737637247358, 7.418299811226981, 9.01487946510315, 8.918737241200038, 10.722459197044373, 14.103089588029043, 7.3926566158022196, 5.039296541895185, 0.5606910192540714, 0.15225953981280327, 0.041798917443624566, 1.2225473757301057, 18.94051664216178, 39.40675694601876, 30.29494489942278, 22.356930255889893, 35.26492881774902, 49.528069291796, 47.91450650351388, 51.36117083685738, 21.895172085080826, 2.1982070165021077, 0.053427199367433786, 0.018405706821275607, 0.03805357377443995, 0.02890540858996766, 0.010924546962736972, 0.06593516123081956, 0.06093720120510884, 0.010998946631194224, 0.053330477593200545, 0.04606991879908102, 0.008001512249133416, 0.05930748901196888, 0.05566331830673984, 0.05325056991672941, 0.013679407620137292, 0.03701886893915279, 0.06161615013011864, 0.06181252494986568, 0.016731024719774723, 0.0647647086797016, 0.04109202305387173, 0.2098362895527056, 0.13091877209288733, 0.1403199697711638, 0.14764418532805784, 0.10417641100606748, 0.14314367968056882, 0.08683699143252202, 0.1529767106154135, 0.11072251653032643, 0.17032094778759138, 0.11772856701697622, 0.13137846599732125, 0.14420384993510588, 0.10353917841400419, 0.25425760235105244, 0.16840002872049809, 0.17621813634676592, 0.09458683165056364, 0.18469823630792753, 0.13670833142740385, 0.35075296301926884, 13.345363344464984, 49.1197167124067, 63.733463287353516, 59.11925492967878, 48.38395806721279, 30.18258558000837, 21.842794827052526, 37.03694180079869, 49.73884984425136, 25.787292378289358, 3.1633139720984866, 0.1739603110722133, 0.2825832095529352, 0.36004908276455744, 7.034566002232688, 16.498129299708776, 12.59474858215877, 11.022910594940186, 13.162295682089669, 20.594424145562307, 15.64452052116394, 33.200469630105154, 42.65684631892613, 48.23967177527291, 52.92432444436209, 49.04989079066685, 52.24068423679897, 49.823659556252615, 51.012437275477815, 50.894074712480815, 48.01062788282122, 49.758127621241975, 52.72872223172869, 53.53469589778355, 50.773902143750874, 53.76963186264038, 52.876486097063335, 54.011342321123394, 49.79198966707502, 46.649041516440256, 49.42803955078125, 46.5703010559082, 49.55983298165457, 50.646937710898264, 50.324485710689, 50.56307642800467, 45.606870787484304, 39.90712104524885, 38.2300899369376, 40.47871807643345, 38.4683575630188, 40.0169859613691, 41.211221490587505, 45.2701541355678, 50.63723455156599, 54.60505894252232, 52.90820114953177, 53.34028877530779, 50.71716662815639, 54.91237776620047, 51.399771554129465, 52.12248495646885, 50.98873002188546, 53.612828390938894, 48.676171507154194, 53.576402459825786, 28.108616045543126, 28.368980680193218, 51.11050762448992, 45.879820346832275, 54.30289568219866, 50.18734564099993, 52.46806403568813, 51.99368619918823, 52.65611703055245, 47.491715567452566, 52.33646515437535, 51.45513480050223, 44.61007874352591, 39.622453348977224, 40.67046751294817, 37.7256646156311, 41.03934737614223, 47.2927747453962, 55.66098363058907, 51.79298748288836, 51.45406130381993, 47.81454971858433, 47.044081347329275, 46.04111582892281, 45.87859746388027, 43.701834542410715, 43.85238463538033, 44.79580756596157, 46.72838299615042, 47.5116742679051, 47.14719608851841, 45.570392744881765, 45.570767947605674, 43.14035408837454, 47.37071616309029, 47.616526058741975, 49.20263304029192, 49.45999779020037, 52.48333617619106, 52.61838831220354, 51.27610404150826, 46.5660765511649, 48.90452057974679, 44.123406069619314, 31.70826060431344, 17.8786130292075, 15.33849058832441, 9.732822060585022, 11.77398567540305, 26.37537053653172, 15.177596364702497, 14.472585235323224, 18.57512477466038, 5.807088553905487, 1.020962438413075, 0.31710829266480034, 0.10477526565747601, 1.6737543812819888, 23.962042297635758, 48.722015721457346, 31.85136570249285, 26.944363730294363, 41.201883111681255, 56.56858859743391, 55.489912033081055, 58.1519649369376, 27.519097873142787, 3.3926774816853658, 0.10134969518652984, 0.13761212650154317, 0.1147460120597056, 0.2657389576945986, 0.09610911817955119, 0.13885685828115257, 0.08856801568929638, 0.147991310272898, 0.11522758193314075, 0.1680642081690686, 0.13947204527045998, 0.16948960668274335, 0.18627274967730045, 0.1381438672542572, 0.08688267040997744, 0.10260777374995605, 0.19064161953117165, 0.1537705830165318, 0.10408369598111936, 0.2152356912514993, 0.19752585941127368], [0.04774392575823835, 0.010908843117899128, 0.04385958079780851, 0.0583044242646013, 0.06709926947951317, 0.04498069028237036, 0.04889370674001319, 0.03942693543753453, 0.029314605918313776, 0.05246818511347685, 0.05479922770921673, 0.036372669506818056, 0.032264835467295985, 0.01563818470042731, 0.029147635413599864, 0.03530908961381231, 0.013237580390913146, 0.030215367940919738, 0.027079876279458404, 0.07247865439525672, 0.2722164158310209, 8.777733973094396, 35.48434945515224, 44.77501508167812, 37.52135978426252, 21.022483553205216, 13.10041241986411, 18.97252699307033, 37.79351724897112, 36.159829003470286, 11.893688372203282, 0.6272650754877499, 0.02360254546095218, 0.11341283324041537, 0.6135245242289135, 1.6008111068180628, 7.69932404586247, 6.719260658536639, 8.314933572496686, 9.23023019518171, 17.534828322274343, 19.112290007727488, 32.080593722207205, 42.27085999080113, 51.617691380637034, 50.4642139843532, 52.969876834324424, 52.41395146506173, 49.713228361947195, 46.767136573791504, 47.20427206584385, 45.68329054968697, 47.97764131001064, 49.76336656297956, 47.65503992353167, 45.64764281681606, 45.090515409197124, 45.09810284205845, 47.1471266065325, 47.30639321463448, 51.043290751320974, 46.07931702477591, 47.186137267521445, 46.05374417986189, 49.03765153884888, 45.829584871019634, 44.561778341020855, 39.56722559247698, 35.54813044411795, 34.145772048405235, 35.76006439753941, 32.77453463418143, 36.7510929107666, 37.951324735369, 46.98689072472708, 49.62773772648403, 53.01088162830898, 48.2246150289263, 49.637552056993755, 47.644773960113525, 48.62759665080479, 48.33319105420794, 49.556893893650596, 47.85773624692644, 48.5064582824707, 44.89411415372576, 44.224988733019146, 19.224744864872523, 28.72187273842948, 52.7375533921378, 45.3749920300075, 49.27593306132725, 44.34514740535191, 48.00603859765189, 46.663361753736226, 49.84296860013689, 45.53401892525809, 47.946808678763254, 43.97500991821289, 39.469078813280376, 34.874328885759624, 36.412416866847444, 34.51728875296456, 37.44623933519636, 37.79092557089669, 47.35917867933001, 47.731640338897705, 49.045075689043315, 48.787116868155344, 49.013767106192454, 43.740824358803884, 44.846029145377024, 43.505356856754844, 47.50716141292027, 47.40839624404907, 48.74607385907854, 39.4355502809797, 43.24400036675589, 45.559508391789024, 45.496415274483816, 46.10732173919678, 47.683986118861604, 49.243335587637766, 47.74581118992397, 50.42748580660139, 51.577575956072124, 52.09625203268868, 55.85317080361502, 47.97070353371756, 42.47299351011004, 37.32945053918021, 35.62805904660906, 22.074578046798706, 11.507734179496765, 4.60033106803894, 10.124691775866918, 11.199152520724706, 15.991247790200369, 7.674632753644671, 5.351634570530482, 3.189755993230002, 0.15170315466821194, 0.06483189721724816, 0.10930916201323271, 0.4074376699115549, 10.98988493851253, 32.68659128461565, 38.8419691494533, 23.050014802387782, 30.16267899104527, 35.407808099474224, 36.24995061329433, 41.90982811791556, 29.666101660047257, 6.507876481328692, 0.07718158739485911, 0.02504137727165861, 0.025005062077460543, 0.04536657314747572, 0.016545866083885943, 0.024909480242058635, 0.024248124033744847, 0.010167388395140213, 0.06298774760216475, 0.03746914817020297, 0.05455128422805241, 0.10956835560500622, 0.043665628348078044, 0.022925964623157467, 0.01733180132162358, 0.013346030642943723, 0.03108687831887177, 0.033012163758810074, 0.06908962982041494, 0.017277404865516082, 0.057534992694854736, 0.03623168010796819, 0.01371139460908515, 0.030641918802367787, 0.04327568445088608, 0.03367728414013982, 0.014117800613998302, 0.03439754566976002, 0.024349675280973315, 0.03638179241014378, 0.060098823692117415, 0.050434225504951816, 0.030066887515464, 0.030355756836278096, 0.015532066912523337, 0.0244618371195559, 0.012378787455548133, 0.026694878902552382, 0.0375535239997719, 0.03611238008098943, 0.048938252563987455, 0.29873823268072947, 11.855576634407043, 42.05516011374337, 51.37948281424386, 43.111807414463584, 26.804685831069946, 16.174803563526698, 16.693274668284825, 34.708458014896934, 38.7482761655535, 14.041900277137756, 1.0720782727003098, 0.04361510802326458, 0.11891385912895203, 1.0153796694108417, 3.277304381132126, 9.124575887407575, 7.878857680729457, 8.663757460457937, 9.99537364074162, 11.182838150433131, 18.06296784537179, 34.162993158612935, 42.59471205302647, 53.04304483958653, 50.53465134756905, 52.11662762505667, 52.14908266067505, 50.36257920946394, 48.22306905473982, 48.866274220602854, 47.5851514680045, 48.879600865500315, 52.075699261256624, 48.915161745888845, 47.84627171925136, 47.81817667824881, 46.98235355104719, 49.52204520361764, 49.55880117416382, 50.732063565935405, 45.99651881626674, 46.30145788192749, 46.42272479193551, 51.478928906576975, 47.64111920765468, 46.223408767155235, 41.015021732875276, 36.25621094022478, 36.81112534659249, 37.95638997214181, 34.80942923682076, 38.77639899935041, 39.64677551814488, 48.554515498025076, 51.3621609551566, 52.29045418330601, 49.70613772528512, 50.305388586861746, 48.65391295296805, 48.91483865465437, 48.38905457087925, 48.956031050000874, 48.29181800569807, 50.01119143622262, 44.83698953901018, 47.57527460370745, 21.595195770263672, 29.209990637642996, 54.5445852960859, 47.80152184622628, 51.255019732883994, 47.59061970029558, 50.78119427817208, 48.864533696855815, 52.087618895939414, 47.37982872554234, 49.71855068206787, 44.93807193211147, 42.60340077536446, 36.35961750575474, 38.16907433101109, 36.34522778647286, 37.918331214359824, 39.58520405633109, 49.59493180683681, 48.36613246372768, 50.63861724308559, 48.40592132295881, 49.02347026552473, 44.68096773965018, 44.96947431564331, 44.2034284727914, 47.92011717387608, 48.98012392861502, 48.054530075618196, 42.90472330365862, 42.82960980279105, 44.83542619432722, 44.58886589322771, 48.37055846623012, 49.345182282584055, 50.58147178377424, 50.186880111694336, 52.99563033240182, 52.87429394040789, 53.38751220703125, 55.03637531825474, 47.42391504560198, 44.345505237579346, 42.093316146305625, 38.43084076472691, 23.535872800009592, 9.56758781841823, 6.659426246370588, 8.643731883593968, 8.688944680350167, 15.111225434712, 10.841086660112653, 12.838911754744393, 8.516340136528015, 1.361540551696505, 0.14705460625035421, 0.08091403211333922, 0.48677749399627956, 11.742933307375226, 35.90897471564156, 29.937717165265763, 23.035041434424265, 35.44281312397548, 41.18703828539167, 43.35759646551949, 47.73851210730416, 34.20340388161795, 7.9436982699802945, 0.06608321078653846, 0.015373379624049579, 0.02419391756744257, 0.03377276419528893, 0.022829799247639518, 0.03698057242270027, 0.025459049502387643, 0.04501617427117058, 0.05268209667078086, 0.029640665743499994, 0.048247249464371374, 0.009966129819596452, 0.00786180019245616, 0.029928042287273065, 0.027170879699821984, 0.05436579989535468, 0.04840642020904592, 0.012913368725483971, 0.02588119836790221, 0.020466733191694533, 0.045084082055836916, 0.10922886417912585, 0.11660025827586651, 0.07852104944842202, 0.1762014308146068, 0.14595111832022667, 0.167547110202057, 0.14258999510535172, 0.0799308145152671, 0.2809973917901516, 0.10219009473387684, 0.15978359750338963, 0.14001732958214624, 0.08076158565069948, 0.048115230298468044, 0.19349282367953233, 0.1023264667019248, 0.07946069152759654, 0.12678076699376106, 0.09225076450301067, 0.172246535175613, 0.5290566310286522, 15.8316650390625, 47.96632964270455, 57.438409260341096, 49.99349090031215, 31.321923392159597, 22.048393760408672, 26.86629377092634, 46.91319465637207, 45.877013274601524, 16.509098768234253, 1.3273624713931764, 0.10671896993049554, 0.2653810983257634, 1.5031900022711073, 5.977793199675424, 14.171872411455427, 14.107697112219673, 16.70360142844064, 19.221147435052053, 25.474950007029943, 22.414666312081472, 36.00336251940046, 43.89080122538975, 53.353403500148225, 50.899751390729634, 55.27753339494978, 52.823269844055176, 51.11848068237305, 49.63456085750035, 48.09483657564436, 49.16199997493199, 49.52088138035366, 54.40645510809762, 51.088054520743235, 51.08234657560076, 49.61441108158657, 49.066764490945, 51.01008531025478, 51.3244982446943, 53.69876718521118, 47.90383754457746, 46.546378408159526, 48.39776413781302, 53.37645762307303, 49.53123419625418, 48.435729094914024, 43.2956463268825, 37.88770355497088, 38.87504257474627, 39.56341450554984, 36.43667997632708, 40.48377289090838, 41.88972697939192, 51.70142412185669, 55.04138496943882, 54.21371555328369, 49.674169063568115, 52.6013582774571, 48.75190339769636, 48.8979788507734, 48.52233144215175, 49.158696106501985, 49.34039844785418, 49.50686338969639, 44.76273761476789, 48.16219588688442, 23.613675253731863, 31.15184886114938, 53.352736473083496, 50.092235224587576, 52.75610160827637, 48.781398500714985, 51.9378331048148, 49.99261542728969, 53.63708802631923, 50.35748617989676, 52.743897097451345, 46.9448367527553, 43.51828745433262, 38.65541001728603, 39.240747111184255, 37.82541642870222, 40.49960783549717, 40.78554705211094, 51.78551469530378, 51.56648315702166, 52.07631417683193, 51.35880497523716, 49.702927657536094, 44.75867639269148, 44.58196633202689, 44.90803139550345, 48.812498637608115, 48.85376398903983, 50.66452707563128, 43.94444479261126, 44.14199250085013, 45.418842111315044, 44.79045050484793, 48.78921869822911, 50.156669344220845, 54.451138973236084, 52.0490459714617, 55.21488496235439, 55.133636202131, 55.48412070955549, 59.800803729466026, 51.045350892203196, 45.37594740731375, 44.721705027988975, 43.05498852048601, 26.61504864692688, 13.714139853205, 8.516671913010732, 17.737373522349767, 17.392595223018102, 28.083904777254375, 15.288473980767385, 11.601106677736555, 8.483271053859166, 2.1626268114362444, 0.4123509148401873, 0.2309752745287759, 0.8594344088009426, 14.57044974395207, 42.60935885565621, 50.369280747004915, 31.119994844709122, 40.62612410954067, 46.40045928955078, 48.28994199207851, 56.85750164304461, 40.65672050203596, 10.327526194708687, 0.23739104026130267, 0.14286955153303488, 0.11598802969924041, 0.1378633744482483, 0.11701090766915254, 0.06385334115475416, 0.09461862780153751, 0.1446233202836343, 0.22631183905260904, 0.2048859151878527, 0.06628778230931077, 0.12614639103412628, 0.18886117078363895, 0.11421554695282664, 0.08160009208534445, 0.17053399421274662, 0.1298506629786321, 0.15143212064036302, 0.09482420355613742, 0.11002984084188938, 0.12226031241672379], [0.06647506475980793, 0.026696186778800826, 0.05931010815714087, 0.0413844750395843, 0.03704763882394348, 0.024047861208340952, 0.06073916397456612, 0.03429642698860594, 0.04972686631871121, 0.03502567232187305, 0.09461184245135103, 0.040672118442931345, 0.017124144160853963, 0.014129174557248396, 0.04441789637452789, 0.043980187004698176, 0.08099098476980414, 0.0202192986117942, 0.018867712833785584, 0.08416245744696685, 0.20839645181383404, 11.475100227764674, 39.49716690608433, 45.70858199255807, 35.07528121130807, 27.782231364931377, 15.076289892196655, 25.092905044555664, 34.451881885528564, 31.333936827523367, 7.769871711730957, 0.13136287326259272, 0.06191049862120833, 0.0831346736688699, 0.37802133123789516, 3.4627057697091783, 8.058446032660347, 8.16084771496909, 11.502912998199463, 11.293330141476222, 16.953524657658168, 17.727835382734025, 35.63439580372402, 48.924371583121165, 48.46000957489014, 54.13592004776001, 49.99146550042288, 46.26338522774832, 48.781398500714985, 47.19292565754482, 46.690473624638145, 47.83484888076782, 46.4700003351484, 47.07704707554409, 46.447533335004536, 43.28274352209908, 42.233555112566265, 45.65707152230399, 48.1830404826573, 44.30707822527204, 49.86362212044852, 48.91299738202776, 47.39814070292881, 44.391328607286724, 49.53854717527117, 46.37570980616978, 41.5535557610648, 37.20828785215105, 34.52961138316563, 32.61512558800833, 33.32481459208897, 34.06153208868844, 35.310918944222585, 41.32023177828108, 47.68333298819405, 49.45745127541678, 50.24276794706072, 42.64293255124773, 47.44700390951974, 44.02747923987252, 48.39894880567278, 46.36745187214443, 47.8055795942034, 44.024456773485454, 46.628801413944785, 39.316277503967285, 42.20720754350935, 17.911352940968104, 34.91233205795288, 49.78308902468, 43.530405112675254, 47.896455083574565, 40.531072752816335, 42.29348332541329, 42.38235773359026, 43.601707526615684, 43.58172798156738, 46.104017870766775, 40.9509037562779, 38.65751184735979, 35.575085980551584, 35.9885767527989, 33.784337180001394, 35.52166822978428, 34.94580500466483, 38.82618979045323, 45.27605663027082, 47.988647256578716, 48.41864000047956, 49.51934930256435, 47.35674333572388, 45.261250019073486, 47.827997956957134, 48.484488078526084, 47.42509971346174, 48.29261357443673, 48.254356792994905, 49.212951115199495, 46.96524361201695, 49.63572120666504, 48.200866086142405, 49.71045255661011, 44.655009269714355, 45.48260572978428, 47.80892515182495, 46.684849057878765, 49.49013212748936, 48.245362349918906, 49.35936008180891, 51.542657784053254, 45.87853493009295, 39.91414567402431, 31.644132205418178, 18.25146552494594, 11.137082525662013, 7.165446179253714, 1.8102451200996126, 11.006904550961085, 18.773212705339702, 9.84628961767469, 8.141588176999774, 1.7287806400230952, 0.033841153739818504, 0.10100700786071164, 0.15413008444011211, 4.302170404366084, 28.45697614124843, 43.669643538338796, 27.4877667086465, 19.173910106931412, 28.122568028313772, 41.55473348072597, 46.633776324135916, 33.293648447309224, 9.966327565056936, 0.3526889591344765, 0.0402661000511476, 0.021322718688419888, 0.030015132256916592, 0.03982580207022173, 0.042722027017069716, 0.05301796132698655, 0.03562796036047595, 0.032066499681345055, 0.053673178489719114, 0.047923744323530366, 0.05643666163086891, 0.013543088238553276, 0.020124361384660006, 0.04377012952630009, 0.08936996265713658, 0.038290474098175764, 0.05910057654338224, 0.013062910210075123, 0.00829725937053029, 0.042038630295012674, 0.02324917120859027, 0.02112801306481872, 0.07662998592214924, 0.019593489156769853, 0.019602880081427947, 0.026345048299325362, 0.013354565765309547, 0.06092848203011921, 0.0151093005801418, 0.02683985130196171, 0.041639712772199085, 0.05026236615542855, 0.020293956123558537, 0.05821359556700502, 0.03489028422960213, 0.012572637276857026, 0.03171192781467523, 0.008163849207838731, 0.0313465129584074, 0.06392551692468779, 0.16811432476554597, 14.501166650227137, 47.49310520717076, 49.67500979559762, 40.18468420846121, 28.9801025390625, 17.766265869140625, 27.587014777319773, 36.35633448192051, 37.0660617010934, 8.773333157811846, 0.3459135969834668, 0.05061881756410003, 0.2376346071915967, 1.2999931914465768, 6.407407266753061, 11.265632016318184, 11.482942138399396, 13.580232432910375, 8.8903295312609, 7.340675405093601, 19.707938228334697, 35.42079080854143, 49.607855456215994, 51.231319427490234, 52.07144348961966, 51.33127621241978, 48.11142539978027, 49.30148506164551, 48.97287695748465, 45.540181977408274, 48.61645521436419, 47.22325454439436, 49.13890763691494, 47.830742495400564, 47.464728764125276, 44.946847506931846, 46.220949104854036, 50.60009295599801, 47.35622916902815, 51.06812013898577, 49.484347752162385, 47.848099095480784, 46.4824515070234, 49.28698764528547, 48.87510190691267, 44.490882396698, 40.22830152511597, 36.48559529440743, 35.10662800925118, 35.671718052455354, 36.02542999812535, 37.05638633455549, 44.163848059517996, 49.17523281914847, 49.04507916314261, 51.381685393197195, 44.65939705712454, 47.64872401101248, 44.33719171796526, 48.57634673799787, 45.839055265699116, 47.79347235815865, 44.68991354533604, 46.35587617329189, 40.69488000869751, 44.68606424331665, 20.307241201400757, 35.65064069202968, 50.13861097608294, 46.34392874581473, 49.315315450940815, 42.57502433231899, 44.32967029299055, 45.34595898219517, 44.877337728227886, 46.71754380634853, 47.116575377328054, 42.57437120165144, 40.410872391292024, 37.220749446323936, 37.743330410548616, 35.56525775364467, 36.82799209867205, 35.846256801060264, 41.081592423575266, 47.632631983075825, 50.92004360471453, 49.93790183748518, 51.133322034563335, 47.217411109379356, 46.46355240685599, 48.54506594794137, 50.68271745954241, 49.84701245171683, 49.625760963984895, 50.87236854008266, 50.79799154826573, 47.450835841042654, 49.63638823372977, 50.41406536102295, 49.6642609323774, 47.55868925367083, 47.92904560906546, 50.44234105518886, 48.476754733494346, 51.04363816125052, 49.534760407039094, 51.23663132531302, 53.09850188664028, 49.10947854178292, 43.08699887139456, 34.43570647920881, 16.515187127249582, 9.742171730313983, 5.023739090987614, 5.317267043249948, 11.221248660768781, 11.55452595438276, 10.743100558008466, 8.989971041679382, 2.464884740965707, 0.3678590751120022, 0.07345887286854641, 0.1654485370963812, 5.651300387723105, 32.110759326389854, 46.036575181143625, 29.836377688816615, 25.449142660413468, 32.06590175628662, 46.68173279081072, 50.23275211879185, 40.796389716012136, 11.769507561411176, 0.4572610578366688, 0.026960387959011962, 0.027466877031006982, 0.030642332708729163, 0.0320449392311275, 0.011235349079860108, 0.005098160140083304, 0.07088136939065796, 0.010100530643415238, 0.03319449968902128, 0.010958751064858266, 0.03530276566743851, 0.03857329088662352, 0.024975942747135247, 0.07867852385554995, 0.03774698790428894, 0.05111920999895249, 0.05423495798770871, 0.02726005107563521, 0.06038028001785278, 0.00903825947482671, 0.17543931385236128, 0.11482846763517175, 0.20210445086870873, 0.1113021754260574, 0.16997159724789007, 0.14757152779826097, 0.2781005086643355, 0.09654837460922343, 0.1523883936128446, 0.10261661506124906, 0.20799501692610128, 0.1298016727502857, 0.15112293937376567, 0.1444563599569457, 0.14890433342329093, 0.131485321692058, 0.11250133679381438, 0.0639522240630218, 0.08436114607112748, 0.3181024007499218, 0.6390066082988466, 18.97441690308707, 56.92522573471069, 57.54679421016148, 48.46382761001587, 38.07980734961373, 22.066931554249354, 32.8514928817749, 43.86315434319632, 41.05452571596418, 10.898371083395821, 0.349858789571694, 0.14354894150580677, 0.41180960674371037, 1.0379853078297205, 8.556272302355085, 15.530537060328893, 16.58763599395752, 20.10971781185695, 19.659330368041992, 23.300905568259104, 22.331524167742046, 37.92798573630196, 49.933715547834126, 50.689022949763704, 53.15942021778652, 52.101348536355154, 53.78102690832955, 51.72515222004482, 49.64016110556466, 46.8657488822937, 49.33195638656616, 46.897085257938926, 49.54458515984671, 49.79029083251953, 49.55613306590489, 46.861986432756694, 48.377378123147146, 53.26861115864345, 48.98992436272757, 52.46916879926409, 50.90213462284633, 49.733885356358115, 47.91274513517107, 52.77988529205322, 51.43515525545393, 46.07129185540335, 41.87649066107613, 38.35126999446324, 37.488922119140625, 37.96734728131975, 38.245546204703196, 38.839050906045095, 44.71483325958252, 52.88031802858625, 49.816190242767334, 50.71944216319493, 44.86982672555106, 47.59219694137573, 43.83800533839634, 48.93350846426827, 46.7617621421814, 47.781118461063926, 44.637663091932026, 47.16728333064488, 41.157560552869526, 44.633132866450715, 23.145158222743444, 37.97182886941092, 51.72087560381208, 47.928705147334504, 51.30255583354405, 44.52183314732143, 47.05309316090175, 46.76348182133266, 46.79973752158028, 48.14488097599575, 49.470482621874126, 44.8542662348066, 44.26321424756731, 39.71507283619472, 40.698204721723286, 38.269771099090576, 39.90960155214582, 38.07085459572928, 42.86090448924473, 49.83885874067034, 52.3747010912214, 50.24710709708077, 53.677898270743235, 49.515322821480886, 47.33530466897147, 50.24410547528948, 52.75389208112444, 52.35819911956787, 52.36988598959786, 52.22948374067034, 52.69753176825387, 49.11404698235648, 53.26653364726475, 51.68862901415144, 53.26661007744925, 48.07487440109253, 51.580629689352854, 52.69736501148769, 51.1458809035165, 54.032548223223, 52.24472461427961, 53.70587171827044, 58.815465790884836, 51.55249643325806, 47.08559683391026, 37.205004828316824, 19.53444344656808, 14.600890670503889, 14.356095211846487, 10.785772919654846, 19.876510211399623, 30.436010701315745, 16.266724756785802, 16.36736593927656, 3.163644011531557, 0.6886633208819798, 0.2145189954234021, 0.4641755468079022, 6.519125180585044, 39.67147289003645, 56.1819143976484, 36.904943398066926, 28.4669919695173, 38.52172667639596, 52.833355154309956, 57.81304223196847, 46.99891458238874, 16.068232093538555, 0.6153203621506691, 0.1335320547223091, 0.14811996051243373, 0.07619480748793908, 0.1259789014501231, 0.11390576857541289, 0.10931488206343991, 0.15977705642580986, 0.12141160081539835, 0.1477076012109007, 0.10854927743119852, 0.09670905170163938, 0.11157320266855614, 0.07433547225913831, 0.2068698023046766, 0.1468012955571924, 0.13544445138956818, 0.13968047765748842, 0.05565858891765986, 0.10193444988025085, 0.09021051148218767], [0.029393553467733518, 0.047996116868619404, 0.005588242659411792, 0.01824324518176062, 0.07792937369751078, 0.0646169101819396, 0.016200618984709893, 0.07012351362832955, 0.056196687543498616, 0.023542259320882813, 0.020309876251433576, 0.07610510515847377, 0.0619738670065999, 0.045920905723635635, 0.019454557415364043, 0.028990825970790217, 0.053136382651116164, 0.02665251287232552, 0.018715861785624708, 0.04164835391566157, 0.3370923160442284, 17.377854619707378, 40.86381156103951, 46.96480587550572, 37.566443170819966, 23.634500741958618, 19.166944537843975, 20.705604008265905, 38.35262489318848, 24.37674900463649, 3.615622158561434, 0.11002025992742606, 0.019631719516058053, 0.324640547058412, 1.9331425768988473, 3.5810461853231703, 9.543947441237313, 4.541337822164808, 6.98651008946555, 6.037995432104383, 6.863186946937016, 23.2801547731672, 38.1101153918675, 45.98641613551548, 58.94559860229492, 54.89258582251412, 45.719223158700125, 45.15896211351667, 48.477974142347065, 52.012154511043, 49.939364433288574, 48.09935637882778, 48.04258612224034, 46.553614956992014, 45.65620299748012, 44.31643744877407, 40.131888321467805, 37.82993275778634, 41.45222323281424, 44.43317065920149, 47.47127744129726, 47.40090261186872, 47.066822801317485, 45.331746441977366, 48.33659219741821, 42.200738770621165, 41.99970306668963, 34.61270489011492, 34.820727007729666, 32.04082918167114, 34.91089030674526, 32.623470374516074, 37.02500479561942, 42.746498925345286, 52.244272981371196, 45.96907690593174, 42.08531876972744, 46.330754961286274, 46.72017022541591, 44.3783597946167, 47.512039048331125, 43.63203293936593, 50.56818682806832, 45.69999054500035, 48.583360944475444, 43.49929455348423, 49.294255461011616, 18.209258692605154, 28.60492239679609, 55.344409806387766, 44.23815209524972, 47.16287122453962, 36.43314681734358, 38.07296684810093, 34.50484800338745, 38.16665288380214, 40.28912605558123, 39.25851018088204, 37.93553842817034, 36.30484138216291, 34.34919098445347, 36.613678387233186, 35.50582981109619, 35.95842504501343, 35.55850757871355, 37.630696637289866, 38.12538405827114, 41.31433275767735, 45.15746477672032, 47.19494063513619, 50.74724537985665, 50.04390008108956, 48.64601979936872, 46.92366559164864, 46.8152563231332, 46.563602992466514, 45.52323184694563, 45.90715108598982, 48.41351917811802, 48.59508950369698, 48.90142515727452, 44.57374313899449, 42.71622562408447, 41.8769075529916, 42.60082994188581, 41.261995451790945, 42.232603209359304, 45.165958949497764, 46.10482733590262, 45.16838387080601, 47.10329736982073, 41.40927989142281, 35.646655900137766, 22.01189661026001, 12.852769936834063, 7.510429450443812, 5.556793596063342, 10.457662480218069, 7.829970155443464, 16.332181998661586, 8.789056062698364, 0.8353357219270298, 0.33927277475595474, 0.21465903148055077, 0.05943214946559497, 2.4275344823087965, 19.79258986881801, 28.60941093308585, 30.486687387738908, 26.448166813169205, 32.86322838919503, 38.95766360419137, 45.24370581763131, 32.39085163388933, 13.08075944014958, 1.987116617815835, 0.08131168077566794, 0.021834344270506074, 0.027331941860861013, 0.044416274675833325, 0.004682082042563707, 0.037806885583060126, 0.052540903711425405, 0.02988888063867177, 0.020466566950614964, 0.035546071361750364, 0.10804531590214797, 0.04314799773107682, 0.05975028060908828, 0.02626103548599141, 0.007369919131243867, 0.01019504208982523, 0.03284187861053007, 0.016269502163465534, 0.05498260519068156, 0.06908200308680534, 0.006281525212606149, 0.027511446603706906, 0.02569997693145914, 0.06272128690034151, 0.059078551296676905, 0.02013071925778474, 0.03737083183867591, 0.06018807140312024, 0.03373634382816298, 0.02563582144544593, 0.03646606306678482, 0.08064938988536596, 0.01476906446207847, 0.02797559000152562, 0.10612118057906628, 0.024590675652559315, 0.03171309150223221, 0.0010711585990585653, 0.035627037552850585, 0.035711840859481266, 0.8069624272840363, 20.862496069499425, 47.59631722314017, 53.765056473868235, 41.96596956253052, 28.775290489196777, 19.76526607785906, 22.54640415736607, 37.37372446060181, 25.154738800866262, 4.805180898734501, 0.057361199520528316, 0.03895841718518308, 0.41126387459891184, 2.4516742612634386, 5.792086958885193, 9.840172597340175, 8.282352600778852, 11.12409199987139, 7.168611083711896, 8.952252745628357, 24.062085935047694, 39.195913859776084, 47.35316848754883, 54.76312698636736, 54.03322219848633, 48.90859569822039, 49.013725417000906, 49.48780448096139, 51.430291516440256, 50.048517159053254, 49.19867951529366, 48.45707048688616, 48.55428620747158, 48.243114607674734, 46.735685552869526, 43.736665861947195, 40.4003632409232, 44.84514325005667, 47.22841010774885, 48.522727489471436, 48.438991274152485, 48.75857366834368, 47.55138669695173, 50.196447781154085, 43.63183144160679, 43.08137083053589, 36.34061418260847, 37.20211785180228, 33.59755570547921, 36.09270593098232, 34.49669081824166, 37.88949966430664, 44.312918186187744, 54.175490038735525, 46.783259868621826, 43.5421267236982, 46.91635261263166, 47.53660787854876, 44.96500314985003, 47.31891386849539, 44.21055037634713, 51.600765568869456, 45.55037151064192, 49.84103005273001, 44.47054501942226, 49.09762838908604, 19.785009384155273, 30.213855947766984, 56.497109004429404, 45.953050885881694, 48.64492545809065, 39.02202129364014, 39.36220857075283, 36.27718407767159, 40.26728091921125, 42.64562497820173, 41.010571411677766, 40.45205089024135, 39.38222633089338, 35.89790970938546, 37.87240014757429, 37.95394768033709, 37.44352606364659, 37.4769538470677, 38.23935535975865, 40.50100094931466, 43.92442355837141, 47.24185139792306, 48.07969992501395, 51.89773505074637, 50.55809456961495, 50.4467705317906, 49.18181276321411, 48.064306191035676, 48.808451311928884, 48.05125747408186, 48.06208276748657, 50.393516063690186, 50.261833803994314, 51.371370792388916, 47.74078416824341, 45.237640040261404, 44.97591182163784, 46.88680192402431, 44.64841195515224, 46.11365849631173, 46.92851196016584, 47.94756603240967, 47.504937989371165, 49.45564821788243, 44.692790099552695, 39.790724822453086, 23.675161600112915, 12.367732695170812, 5.416137737887246, 8.34566284929003, 12.217648131506783, 7.8248336996350965, 16.20171914781843, 9.253997376986913, 5.873641874108996, 1.3633344897202082, 0.7842207561646188, 0.059553634375333786, 3.153653370482581, 23.361014434269496, 34.68753351484026, 30.869762420654297, 26.915391479219707, 39.19677891050066, 43.410190854753765, 51.83354411806379, 38.19445610046387, 16.050934553146362, 2.048743013824735, 0.08821953367441893, 0.01837540853635541, 0.04710312067930188, 0.018623575934075882, 0.05367957028959479, 0.0006634573344074722, 0.04278907645493746, 0.006657310204380857, 0.01102841371071658, 0.049389067837702375, 0.01059247022827289, 0.03895433918972101, 0.057636067271232605, 0.03941405684288059, 0.044947608307536156, 0.017533589154481888, 0.03906947301168527, 0.0411445518423404, 0.018302522000989745, 0.02754067280329764, 0.11659424645560128, 0.11967950447329453, 0.06619632257414715, 0.19251911235707148, 0.10060471801885537, 0.12988506470407757, 0.14678494286324295, 0.13522115908563137, 0.0993514774101121, 0.09784766738968236, 0.11433281137474946, 0.16497686026351793, 0.16839245626968996, 0.12779124134353229, 0.18624996447137424, 0.08184965047985315, 0.12804231287113257, 0.15013599661844118, 0.0957269672570484, 0.10545360390096903, 1.4473262684685844, 27.048303570066178, 54.822443757738384, 59.73414271218436, 50.685774666922434, 32.83962883268084, 27.4431505884443, 28.128951685769216, 49.98570891789028, 31.00065953390939, 5.045425721577235, 0.3734042261328016, 0.2415796640728201, 0.5767356583050319, 4.086175663130624, 8.61557344027928, 20.09651623453413, 15.772179773875646, 16.401749100003922, 13.119095257350377, 10.229170101029531, 28.229521649224417, 42.01808452606201, 47.47975076947893, 57.69845601490566, 55.1078896522522, 50.147115571158274, 49.63870198386056, 49.04904658453805, 51.43303952898298, 50.57388087681362, 49.43797894886562, 48.772702830178396, 50.949806213378906, 50.73284871237618, 49.063839299338206, 46.12946217400687, 42.07676206316267, 44.88258709226336, 50.41647638593401, 51.831404072897776, 52.78806332179478, 51.049019541059224, 49.841436522347585, 50.412706988198416, 44.95211771556309, 45.24508850915091, 37.97159610475813, 39.21315581457955, 35.26170137950352, 38.148233209337505, 36.36838265827724, 39.956175327301025, 47.616380146571565, 56.22471530096871, 47.81682872772217, 44.62352698189871, 46.642256600516184, 47.6178879056658, 45.57885912486485, 48.82901797975813, 43.955520221165244, 52.77745689664568, 46.45519024985177, 50.012897218976704, 45.85813501902989, 48.30480071476528, 22.58529496192932, 33.17395183018276, 58.63630649021694, 48.784407070704866, 51.52868495668684, 41.37319094794137, 41.77295902797154, 37.98936264855521, 41.06586517606463, 45.037514550345286, 42.39480195726667, 41.846738474709646, 41.066490513937815, 37.718059812273296, 40.17130545207432, 39.067622320992605, 40.04114832196917, 39.10835613523211, 40.917024339948384, 41.470896516527446, 45.52653571537563, 48.56677212033953, 50.47486557279314, 56.000854764665874, 52.340262344905305, 51.79791028159005, 51.37082188470023, 50.53736809321812, 50.72277382441929, 49.87331485748291, 49.91217960630144, 53.051754406520296, 52.26312344414847, 52.80547203336443, 49.64034175872803, 47.972294671194895, 46.872210706983296, 47.025463649204795, 46.51085574286324, 45.66306781768799, 49.87891510554722, 50.9299760546003, 50.02208273751395, 53.236465317862375, 48.44127375738961, 43.67253398895264, 26.258748497281754, 15.755311284746442, 13.098335777010236, 14.354926177433558, 20.236882005419048, 14.202130947794233, 26.285424368722097, 16.496039628982544, 4.745384267398289, 1.2190684995480945, 0.6990176024181503, 0.22852918292794908, 3.613058490412576, 28.031680379595073, 39.4374714578901, 41.173517090933665, 36.823684215545654, 44.35440240587507, 49.96277986254011, 59.37172467367989, 46.010213715689524, 20.408073459352764, 2.4040406686919074, 0.2749331614800862, 0.12873393004494055, 0.14389324374496937, 0.12635977672679083, 0.10902000431503568, 0.21104661960686955, 0.09847010791833911, 0.05907347585473742, 0.10971774187471185, 0.11517500903989587, 0.21136390258158955, 0.11129965127578803, 0.24539913769279206, 0.09595361152397734, 0.06380688864737749, 0.13938783907464572, 0.12794035619923047, 0.1291900005723749, 0.2451608633356435, 0.11537308698253972], [0.021103779186627696, 0.049397939683071206, 0.06204765090452773, 0.018776371842250228, 0.01854515933830823, 0.06589857462261405, 0.03688013566923993, 0.07338048850319215, 0.03056970571300813, 0.03621682358373489, 0.04358029239145773, 0.01577565759154303, 0.05692904056715114, 0.015342602971941233, 0.07887892238795757, 0.02287114068998822, 0.08838378664638315, 0.059969929179974964, 0.025905204936861992, 0.04804678647113698, 0.7555417950664247, 14.442207711083547, 44.13496787207467, 41.88156632014683, 35.81361763817923, 25.473780972617014, 18.547670704977854, 26.13454076222011, 34.409984248025076, 22.226851293018886, 1.8292452948434013, 0.06972649600356817, 0.03926638048142195, 0.11247791376497064, 1.869440189429692, 4.64320536170687, 7.526956609317234, 11.446436303002493, 12.923988103866577, 5.917407274246216, 10.62711775302887, 28.249475138528005, 44.275991984776084, 62.6503780909947, 53.91624232700893, 44.597863810403005, 40.52955109732491, 47.59214135578701, 45.197423866816926, 47.73181751796177, 46.23128455025809, 46.574136461530415, 45.72483382906233, 46.752336910792756, 47.354752676827566, 45.135564054761616, 42.30423566273281, 36.05269472939627, 34.43031815120152, 38.6774913924081, 45.02183594022478, 47.9879663331168, 47.69896643502371, 48.34407540730068, 48.38284982953753, 43.91139568601336, 39.98652853284563, 36.150059836251394, 36.701670374189106, 33.984952517918174, 35.3854592187064, 32.92022793633597, 36.63848345620291, 46.82021733692714, 50.434128284454346, 35.865312235695974, 43.48237221581595, 46.715042454855784, 46.915504932403564, 46.11901903152466, 47.29626621518816, 49.38671861376081, 47.64083085741316, 44.93813793999808, 48.75727782930647, 46.01127331597464, 48.06598418099539, 24.58588978222438, 29.124953372137888, 48.980898652757915, 43.99191835948399, 48.466078826359336, 40.62086432320731, 38.577055181775776, 34.37975263595581, 36.74503060749599, 35.20928764343262, 37.15950107574463, 34.56049265180315, 35.27212367738996, 34.45566170556204, 37.080048424857004, 35.80892413003104, 35.692395891462056, 36.6865302494594, 37.392168453761506, 35.287437507084434, 35.44194459915161, 39.207704952784944, 45.46866069521223, 48.33374343599592, 49.491782324654714, 47.04154178074428, 46.139811515808105, 44.85222693852016, 42.55474254063198, 45.18091147286551, 44.95500469207764, 46.08412170410156, 43.874545914786204, 42.25628614425659, 39.802012171064106, 38.29095615659441, 35.8949601990836, 35.745525291987825, 35.290637152535574, 39.58940076828003, 37.40295900617327, 44.41366706575666, 44.2550813811166, 50.06470993586949, 44.90548488071987, 40.6572242464338, 27.700272151402064, 16.032839706965856, 5.385083632809775, 5.140311190060206, 9.80308050768716, 7.7024924244199475, 9.778931174959455, 8.226541195596967, 5.903374518666949, 0.9982479086944035, 0.037013922418866835, 0.008646015343921525, 0.8943507894873619, 14.208195856639318, 38.83292954308646, 38.88951219831194, 28.17109772137233, 19.271037237984793, 35.85566813605172, 45.553644112178254, 43.80403559548514, 22.70591221536909, 3.1084785716874257, 0.06023313969905887, 0.05971946833389146, 0.11863158856119428, 0.030585871809827428, 0.015517961865823184, 0.03862641000055841, 0.03876895324460097, 0.07743508129247598, 0.077679557459695, 0.026145374103050147, 0.04079109277310116, 0.03907933212550623, 0.04301319317892194, 0.021299521272469844, 0.0736880616417953, 0.062041069114846845, 0.05727844538965395, 0.028421553749857203, 0.04272994552073734, 0.09910485028688397, 0.03761620706479464, 0.013920399510035557, 0.057481693769139905, 0.01855624999318804, 0.05381383879908493, 0.054438250471970866, 0.0477766311461372, 0.03716740704008511, 0.017982896384117857, 0.026949899503961205, 0.0419579931933965, 0.013226454112944859, 0.039074901291834455, 0.024594575532578995, 0.05703550949692726, 0.012356612082969929, 0.042360856397343535, 0.06604333328349249, 0.022110226431063244, 0.029172697104513645, 0.9955854458468301, 18.14420792034694, 49.992240224565776, 47.539091859545024, 40.63159234183175, 29.52493510927473, 21.649930204663956, 24.826750823429652, 39.663284437997, 24.031809159687587, 2.1316317660467963, 0.028745063979710852, 0.07760567178151437, 0.7898886948823929, 4.762905018670218, 8.063220313617162, 9.435852578708104, 10.902513946805682, 10.63118244920458, 8.020658254623413, 13.713284356253487, 29.79613024847848, 45.79364531380789, 57.73552812848772, 56.15629638944353, 49.33666031701224, 43.79383911405291, 48.455281325748985, 47.87049313953945, 48.30622162137713, 47.9652214050293, 46.99014595576695, 46.24983971459525, 47.47678736277989, 50.91034391948155, 46.84855209078108, 44.086181095668245, 38.104963302612305, 37.65308025905064, 40.7477696963719, 48.56828335353306, 50.85116958618164, 48.81765420096261, 48.87497683933803, 50.69515126092093, 46.14083290100098, 41.74153927394322, 37.201343127659385, 38.94351707186018, 35.404535497937886, 37.90097114018032, 34.04781634466988, 38.85467045647757, 48.635121549878804, 51.6069529397147, 39.73060553414481, 44.893877914973665, 47.133108615875244, 47.90632847377232, 47.43303803035191, 48.92032078334263, 50.93534353801182, 49.22252573285784, 46.86412647792271, 52.30788026537214, 46.64545624596732, 48.56712300436837, 24.509673254830496, 29.883615016937256, 51.23493249075753, 46.04012223652431, 50.21530866622925, 42.101765155792236, 40.0642545563834, 36.80994415283203, 37.005622795649934, 36.99150058201381, 38.30548136574881, 36.45417554037911, 36.749612944466726, 35.356502601078574, 38.4417633329119, 39.0431855065482, 36.270190715789795, 37.143909318106516, 38.272967270442415, 36.32020732334682, 38.210412638528005, 40.75778552464077, 47.52260031018938, 50.93429436002459, 51.22993326187134, 49.97875377110073, 46.55945144380842, 47.08926548276629, 45.98812191826956, 46.66090209143502, 46.906020641326904, 47.77129718235561, 46.436787945883616, 45.053943565913606, 42.187971455710276, 38.96139478683472, 37.83258349554879, 38.04379483631679, 38.28694009780884, 40.59601756504604, 39.83518287113735, 46.238785130637034, 46.35381255831037, 51.71251344680786, 48.437504359654014, 42.845062596457346, 30.02851275035313, 16.666112422943115, 6.85117655141013, 8.956439903804235, 11.987802590642657, 8.806119969912938, 9.619790502956935, 7.575197083609445, 5.954201025622232, 2.8135631510189603, 0.19860080815851688, 0.020398862726454223, 0.972875041621072, 16.890848432268413, 42.287132671901155, 46.20905031476702, 31.798507281712123, 25.675812005996704, 40.694181714739116, 51.08868680681501, 48.42162077767508, 28.7218953200749, 3.937815989766802, 0.055080833312656195, 0.1133597989433578, 0.025074908775942664, 0.02195848394850535, 0.052772168801831346, 0.05618492853162544, 0.03730244229414633, 0.060018987261823246, 0.012484098634948688, 0.09256912634841033, 0.015664913891149417, 0.07643608775522027, 0.0504189720377326, 0.022915764545489634, 0.03575195245710867, 0.04978403289403234, 0.05143549552719508, 0.015016784026686634, 0.07776874410254614, 0.08404015829520566, 0.1670954501522439, 0.11050639634153672, 0.2073337845504284, 0.04680810043854373, 0.15824347228876182, 0.2228814238416297, 0.09841562834169183, 0.11727446424109594, 0.09050973185471126, 0.20279628517372267, 0.18246563896536827, 0.14170439834041254, 0.12916220777801105, 0.11187681994800057, 0.22246671680893215, 0.06484022284192698, 0.15374654930617127, 0.11973287803786141, 0.0943560211786202, 0.12040035293570586, 1.9550250598362513, 24.585585798536027, 57.121446337018696, 54.50985472542899, 46.234522410801475, 35.684898785182405, 26.03878763743809, 35.20548350470406, 44.654484680720735, 28.553483145577566, 2.868883405412946, 0.20031600897865637, 0.13717209654194967, 0.8375317326613835, 5.496162746633802, 14.5873156275068, 18.27079020227705, 17.318829672677175, 23.098931857517787, 11.050646935190473, 14.9856002671378, 31.68978534426008, 47.41489628383091, 59.31904343196324, 55.76905243737357, 50.46622896194458, 45.53375489371163, 49.497459002903526, 46.04077189309256, 47.99708236966814, 47.58836848395211, 47.998774256025044, 47.28527763911656, 47.46953691755022, 52.51465170724051, 48.77373811176845, 46.51860645839146, 41.59513030733381, 38.79497848238264, 42.39440243584769, 49.66779409136091, 53.33047444479806, 51.89802687508719, 52.495835985456196, 52.17964431217739, 49.15021235602242, 44.50529990877424, 39.999306270054404, 40.423007420131135, 37.841466767447336, 40.30641317367554, 34.909743853977744, 40.811995370047434, 51.438789163317, 52.538598673684255, 42.81622062410627, 45.132593699863975, 47.92985160010201, 49.25048875808716, 48.108131953648154, 50.5567535672869, 53.0379934992109, 50.768697943006245, 49.37606702532087, 55.15211146218436, 49.13346719741821, 48.94959354400635, 27.97566052845546, 33.711471421378, 53.96711356299264, 47.301199436187744, 54.0865044593811, 43.89365693501064, 41.84958723613194, 37.68352379117693, 39.24613543919155, 38.96767248426165, 39.62528126580374, 38.44708912713187, 37.47107219696045, 37.387940474918906, 40.79305110658918, 40.13806874411446, 38.665686403002056, 39.19462149483817, 40.149168491363525, 38.495007378714426, 38.75176763534546, 43.38806431634085, 49.84443467003958, 53.8822135244097, 52.33214684895107, 52.83938271658761, 49.0205728667123, 48.30944211142403, 47.06989043099539, 49.467960425785606, 48.196012769426616, 49.59648820332119, 48.03376885822841, 47.09041888373238, 44.04570436477661, 41.396043573107036, 39.38028430938721, 39.67029169627598, 39.05838121686663, 43.05075011934553, 41.744787556784495, 49.791392121996196, 49.208354881831575, 54.51359633037022, 50.475313731602256, 47.37289094924927, 30.594405310494558, 19.24365438733782, 8.3860570703234, 11.590970993041992, 18.08737686702183, 16.366955995559692, 18.387888193130493, 14.452903594289507, 12.031891516276769, 3.2289255942617143, 0.5221231430768967, 0.08105182221957616, 1.4121877082756586, 19.69117569923401, 50.23815434319632, 48.81835944311959, 36.60425662994385, 28.745567832674297, 46.44690452303205, 56.36023644038609, 56.16666310174124, 34.777738503047395, 5.069367911134448, 0.15807871041553362, 0.21531513413148268, 0.2047186563057559, 0.07656216634703533, 0.15401500490094933, 0.14675227818744524, 0.16697764290230616, 0.15303680167666503, 0.18972186531339372, 0.2765842814530645, 0.09923768030213458, 0.20095027637268814, 0.11245210907821145, 0.07292009570768901, 0.17584201081522874, 0.16114734432526998, 0.15677134985370295, 0.10523019624607903, 0.17235093457358225, 0.21311315228896482], [0.03190692860100951, 0.03241366873096142, 0.032237972265907695, 0.0481333268274154, 0.03330582692953093, 0.03541418451017567, 0.04185620954792414, 0.055914447509816716, 0.025470869582412497, 0.023186082718893886, 0.05824583276574101, 0.08138336800038815, 0.017790068606180803, 0.03499510771195803, 0.019978647685742805, 0.05928161647170782, 0.07630045539034264, 0.02803442407665508, 0.012796930419946355, 0.024035718824182237, 0.4899074946131025, 19.546698331832886, 41.443617888859336, 46.10286099570138, 30.722085407802037, 16.48327578817095, 12.766311764717102, 27.1398651940482, 34.79224981580462, 11.719635128974915, 0.7620713646922792, 0.06539256391780716, 0.014478259620123675, 0.987269646355084, 1.8377047266278947, 5.152185661452157, 7.696182591574533, 7.268823214939662, 7.243719807692936, 9.02943594115121, 19.037777526038035, 35.26509557451521, 52.22452967507498, 42.723396165030344, 36.62263808931623, 40.68476343154907, 48.79843895775931, 44.68368101119995, 47.96084751401629, 47.31847613198416, 43.980637959071565, 43.4203074319022, 47.272951534816194, 44.80626113074166, 46.80782175064087, 46.07070473262242, 45.86679942267281, 40.18386779512678, 35.9546799659729, 32.94820485796247, 35.78409126826695, 39.48012644904, 44.30591440200806, 45.46980367388044, 43.64363643101284, 38.835569858551025, 36.88735750743321, 34.822439738682334, 35.882272788456504, 34.055226598467144, 35.03945977347237, 34.08606617791312, 37.593648842402864, 45.93302270344326, 45.31627975191389, 41.366913250514436, 48.249093532562256, 48.53943790708269, 49.68560927254813, 45.53891045706612, 48.01624550138201, 43.87833963121687, 47.234020778111045, 41.810910088675364, 45.85445247377668, 42.82876212256295, 53.14178221566336, 22.82940776007516, 27.098756177084788, 50.75495440619332, 44.75582068307059, 48.31356239318848, 45.07086590358189, 47.95534801483154, 40.100187165396555, 39.92226811817714, 36.246737071446006, 36.45150743212019, 33.957958766392295, 35.18726880209786, 34.824003083365305, 35.586269106183735, 37.49048893792288, 38.52334908076695, 38.62327807290213, 36.656785011291504, 35.0183059828622, 35.81107807159424, 36.800842012677876, 35.20410081318447, 39.39186348233904, 41.66305242265974, 42.80671201433454, 41.34915018081665, 38.50410951886858, 38.31253031321934, 35.8080278124128, 36.55807195390974, 36.88212898799351, 35.99546589170183, 37.25503880637032, 35.59771626336234, 36.869243553706575, 36.54066324234009, 40.4627719606672, 41.197047165461946, 44.42567702702114, 45.19033670425415, 47.47737101146153, 47.357514585767476, 50.23451001303536, 41.17894015993391, 38.59142058236258, 28.80015982900347, 20.827883618218557, 8.377227646963936, 11.147279007094246, 13.306837320327759, 5.991761250155313, 11.036167757851736, 8.113216076578412, 10.638273085866656, 17.03074172564915, 8.950256007058279, 0.1770900809871299, 0.31121084626231876, 7.375736015183585, 30.989226273127965, 23.3924081325531, 26.027178934642247, 28.063649041312082, 30.16367605754307, 40.716374261038645, 50.389517375401084, 26.91396188735962, 8.725366268839155, 0.21418340557387897, 0.03634988430089184, 0.029169161937066486, 0.02625213480288429, 0.07880677375942469, 0.018539634366918887, 0.041876901473317824, 0.03996839959706579, 0.0927224684772747, 0.04452991572075656, 0.01942246440531952, 0.02819306217133999, 0.05331848787942103, 0.02539373711416764, 0.07213792125029223, 0.026378303300589323, 0.04315911552735737, 0.013491512791785811, 0.0478694581293634, 0.027999138559347818, 0.01846785214729607, 0.058088527992367744, 0.07314021925308875, 0.036099026511822424, 0.02828465761350734, 0.004342374757730535, 0.013569568915824805, 0.019989416036488752, 0.02021289324121816, 0.03636291556592498, 0.06659850385040045, 0.031413603108376265, 0.028991843773318187, 0.021841299254447222, 0.06182804304574217, 0.035660879486905675, 0.06468407836343561, 0.03910695528611541, 0.1063040593372924, 0.04018019073243652, 0.9336937155042375, 24.021642208099365, 47.95008128029959, 50.909996509552, 36.93974345070975, 21.02262772832598, 13.979037318910871, 27.826864855630056, 33.08805819920131, 15.186022792543683, 0.9423903631312507, 0.06290325642164264, 0.07791345526597329, 1.5397023516041892, 4.072371763842447, 8.21470580782209, 7.877093706812177, 8.670379093715123, 6.632657442774091, 8.498538851737976, 24.018934147698538, 35.10388347080776, 53.198073046548025, 47.74145814350673, 42.572703633989605, 44.92688185828072, 51.69060230255127, 46.23575224195208, 47.61148861476353, 48.460092953273225, 45.69019358498709, 45.41095590591431, 47.43951027733939, 45.268743651253835, 48.88020535877773, 48.310380118233816, 47.48444775172642, 42.00459112439837, 38.03015899658203, 35.403034687042236, 38.65079641342163, 42.733839307512554, 46.811462606702534, 47.665979862213135, 46.943127495901926, 41.68366772787911, 38.81180354527065, 36.29569060461861, 38.57263265337263, 36.45888989312308, 35.97331156049456, 35.39305707386562, 38.79736171449934, 47.95359012058803, 47.75295393807547, 42.910799503326416, 49.0152713911874, 49.891616412571494, 50.81994090761457, 48.120663029806956, 50.31734643663679, 46.85603877476284, 48.65397548675537, 43.38066101074219, 47.655164991106304, 45.62394251142229, 53.20844323294503, 22.92457549912589, 28.594204800469534, 52.98213345663888, 48.25368629183088, 51.04666410173689, 46.6528491292681, 49.10870034354073, 40.87841320037842, 39.7352226121085, 37.10274818965367, 38.2523068019322, 35.323224203927175, 36.323056084769114, 35.47576495579311, 39.01791838237217, 38.10861458097185, 40.06821155548096, 40.411379609789165, 37.54655047825405, 36.57626928601946, 38.71412576947893, 37.372195856911794, 39.032506125313894, 41.985785824911936, 44.77728019441877, 45.38523020063128, 43.58542442321777, 41.161357743399485, 40.18804366247994, 38.845071520124165, 39.38325119018555, 39.437023299080984, 38.356369972229004, 37.41148097174508, 37.77764408929007, 37.055590765816824, 38.01851034164429, 41.84782239368984, 43.28929219927107, 46.304066930498394, 48.01174654279436, 48.900052888052805, 50.799877984183176, 52.467973709106445, 45.441792011260986, 40.210687841687886, 31.840960775102886, 19.704936606543406, 9.877204758780342, 11.556850126811437, 10.157586285046168, 11.810230953352791, 14.587742941720144, 10.891949210848127, 6.749164402484894, 11.777413742882864, 6.455657729080745, 0.16369837815208094, 0.20687343925237656, 9.639951569693428, 34.62158121381487, 31.03865228380476, 30.318099771227153, 30.86934552873884, 35.779550620487754, 45.48166772297451, 55.64925159726824, 33.429979051862446, 9.77684497833252, 0.23073184330548557, 0.08539329282939434, 0.023782506518598114, 0.07140343423400607, 0.04784855925078903, 0.05512915857668434, 0.06981993027563606, 0.047640788435403786, 0.034536933725965877, 0.0894648829208953, 0.041846146873597584, 0.051593271882406304, 0.0071845391233052525, 0.04065684461966157, 0.048160709108092954, 0.035774995506341965, 0.0442844522850854, 0.03646635822951794, 0.03597837280748146, 0.06792457840804543, 0.1582905219069549, 0.1829354159001793, 0.14066751540771552, 0.1254364534148148, 0.13436209303992136, 0.0887912604957819, 0.09711130083139453, 0.23239037288086756, 0.08637410841350045, 0.11641267048461096, 0.21667103708854743, 0.13365235898111547, 0.1200858655252627, 0.10865820944309235, 0.12777996409152234, 0.1060429997742176, 0.1424804659826415, 0.10816737756665264, 0.15657617604093893, 0.10567820577749185, 1.9588511288166046, 31.350741045815603, 55.52895048686436, 58.1791740826198, 42.50166177749634, 24.90219783782959, 19.76166864803859, 36.86580419540405, 44.01705346788679, 17.80352210998535, 1.34610957971641, 0.19394018181732722, 0.27045597029583796, 2.052847010748727, 7.333991238049098, 13.065563729831151, 16.9846282686506, 16.81457805633545, 14.113485830170767, 14.048829368182592, 24.013802903039114, 38.03567239216396, 51.8565218108041, 49.86083589281355, 45.585449491228374, 48.3116203716823, 51.56959594999041, 48.42050906590053, 47.596313749040874, 48.66781977244786, 45.75217151641846, 46.814019543784006, 49.045298031398225, 47.54942730494908, 48.760911737169536, 51.27603108542306, 50.578987802777974, 44.54892417362758, 40.68275540215628, 37.64086185182844, 40.34695591245379, 44.015934807913645, 48.371989795139854, 49.01800203323364, 48.558475971221924, 42.49074615750994, 40.5983521597726, 37.80546120234898, 39.49891437802996, 38.2333972794669, 38.95335572106497, 37.98006248474121, 40.55788932527815, 49.402977398463655, 49.370091574532644, 44.184376512254985, 49.29141364778791, 52.02111073902675, 53.28688492093767, 49.721795490809846, 52.5943649155753, 49.74874060494559, 51.06620243617466, 45.04256936482021, 49.08576781409127, 47.271985735212056, 54.15996081488473, 24.447410447256907, 33.253731046404155, 55.08546086720058, 49.79307011195591, 52.29440770830427, 48.3884778703962, 51.18626383372715, 44.34071792875017, 42.47926773343767, 39.375559534345356, 39.74842766353062, 36.84836074284145, 38.42195749282837, 37.8691588129316, 40.07633399963379, 40.85701969691685, 42.85476228169033, 43.44402858189174, 39.17949526650565, 38.5016359601702, 39.45921584538051, 41.30411890574864, 39.07489708491734, 43.22057798930577, 45.912421294621055, 47.96745525087629, 44.9408894266401, 41.466616426195415, 42.095699378422324, 40.441795349121094, 39.48971496309553, 40.52904387882778, 39.197022097451345, 39.55395800726754, 39.06368269239153, 40.108691760471885, 39.54183340072632, 44.686873708452495, 46.79777812957764, 49.31306423459734, 51.21099942071097, 51.58284616470337, 53.179233006068635, 54.43889624731881, 46.91319465637207, 44.52265650885445, 32.13473408562796, 22.71756260735648, 11.771312355995178, 17.067009585244314, 20.678860391889298, 13.279441441808428, 20.251365525381907, 16.485606908798218, 20.76342691693987, 23.28487433706011, 11.252168144498553, 0.4820720979145595, 0.7408665482486997, 10.996365002223424, 39.68310070037842, 31.75309385572161, 36.00054849897112, 38.9733178956168, 39.69516972133091, 52.53354385920933, 61.481816155569895, 41.076290948050364, 12.876980934824262, 0.33256027208907263, 0.13937517761119775, 0.10211066542459385, 0.1849770870591913, 0.15601873238171848, 0.1670033593795129, 0.1619095698531185, 0.09380809058036123, 0.1825502115700926, 0.12034043829355921, 0.13005309711609567, 0.13279513855065617, 0.12258952403707163, 0.11195058348987784, 0.11439105682075024, 0.09155859093048743, 0.11622346778001104, 0.12891516674842152, 0.09487092069217137, 0.12226286370839391], [0.029416742401995828, 0.020939575408452323, 0.0513577184506825, 0.0541380190822695, 0.041188317351043224, 0.03795395465567708, 0.046963651198893785, 0.0691648589979325, 0.025061051394524317, 0.07740126989249672, 0.015094287992854203, 0.011106236588342913, 0.02472464899931635, 0.04626741659428392, 0.011792814791468638, 0.06347722919391734, 0.027371902484446764, 0.055124988978994746, 0.027266241011342833, 0.004393714837663407, 1.1145274234669549, 19.96829765183585, 44.837333474840435, 44.465650013514924, 34.009497029440745, 23.351610047476633, 22.411789757864817, 33.54006978443691, 34.23032815115792, 9.964343854359218, 0.3243044008101736, 0.09180270068879638, 0.05922187824866601, 1.3651986696890421, 5.224727026053837, 7.012834208352225, 6.3117800780705045, 9.639517307281494, 6.167777793748038, 14.281472427504402, 26.717711755207606, 38.66285153797695, 32.425898347582134, 30.13926703589303, 39.18920884813581, 45.99064758845738, 49.91924245016915, 44.469707761492046, 48.06502185549055, 44.822651931217735, 46.62138768604824, 46.768210070473806, 45.82783045087542, 45.10293878827776, 45.067895548684255, 46.70792055130005, 45.85223947252546, 44.10088348388672, 40.08206973757063, 35.056329999651226, 33.869720118386404, 32.81998974936349, 34.68671015330723, 33.39700290134975, 35.53423057283674, 35.0213041305542, 34.897455964769634, 35.30027777808053, 36.90270955221993, 34.43709264482771, 36.65564898082188, 33.75580440248762, 36.22187989098685, 44.01929773603167, 49.28141171591622, 49.228299685886924, 48.90957539422171, 47.62687540054321, 46.17069625854492, 43.2692049571446, 44.076919146946494, 40.65858956745693, 39.87497867856707, 37.74632855824062, 43.25466932569231, 39.89411749158587, 52.90353543417794, 26.75506179673331, 24.14692865099226, 51.08829075949532, 43.254585947309224, 49.60294655391148, 45.97163731711251, 50.57165745326451, 46.00052097865513, 48.27520833696638, 40.389718600681846, 39.30096020017351, 33.50023923601423, 37.31689167022705, 33.38580240522112, 38.44296537126814, 39.85549245561872, 42.982716832842144, 42.13728434698922, 41.718460832323345, 36.35847452708653, 38.5683525630406, 36.83283846718924, 36.324445724487305, 34.03519146783011, 36.264034611838206, 37.30866847719465, 37.31965357916695, 36.3419690813337, 36.589307580675396, 35.719587666647776, 34.2494843346732, 32.28539187567574, 34.24504096167428, 33.59908430916922, 38.67820010866438, 41.304389885493684, 45.023930822099956, 45.94591508592878, 48.27725805555071, 46.96829039709908, 46.07941082545689, 47.521822111947195, 46.8167918750218, 44.331278800964355, 44.981723989759175, 42.37593412399292, 34.454404081617085, 22.21837101663862, 8.674379519053868, 12.810627375330244, 6.126075140067509, 11.333878091403417, 7.636155366897583, 8.496642862047468, 4.468245378562382, 1.92764698607581, 7.488150920186724, 0.8697591604931014, 0.04489446205220052, 4.905596699033465, 34.96845613207136, 36.83460330963135, 21.63711425236293, 18.99951379639762, 27.03316170828683, 42.615831102643696, 44.81938975197928, 32.927214350019185, 9.853563513074603, 0.658538700214454, 0.033106731184359105, 0.037609031556972435, 0.03278360263045345, 0.07053166601274695, 0.03423838171043566, 0.047939286168132506, 0.03789435553231409, 0.047251428078327856, 0.0611928596294352, 0.028386536253882304, 0.060337858008486886, 0.018753875013706938, 0.03171987685241869, 0.03519389133102127, 0.020554963100169386, 0.019134192195321833, 0.06229181494563818, 0.0718299884881292, 0.027523117406027656, 0.06223752535879612, 0.04746807413175702, 0.04880136490932532, 0.04239791798006211, 0.05338585622874754, 0.01962058136372694, 0.05929965193250349, 0.08263040001371078, 0.03683869753565107, 0.03466963142688785, 0.03664996302021401, 0.05912796900208507, 0.021586114108296375, 0.08107373211532831, 0.016786372821245874, 0.027610120862456303, 0.025928112279091562, 0.010001121022339379, 0.03486261357154165, 0.057494151672082286, 1.9953180977276392, 24.322730234691075, 50.56913525717599, 50.55956411361694, 38.981131144932334, 23.84534556525094, 22.70541020802089, 33.69260358810425, 36.453612736293245, 10.782448206629072, 0.4527920904968466, 0.11087315130446639, 0.0057443366718611544, 1.2329566457441874, 8.25927676473345, 8.363489321299962, 13.785997254507881, 9.744176285607473, 5.618143584047045, 13.319835662841797, 26.40855860710144, 38.89464691707066, 36.42115075247628, 32.80724327904837, 43.85150568825858, 47.606742995125906, 48.366125515529085, 46.73840577261788, 48.146454742976594, 44.139254910605295, 47.03143909999302, 47.0980931690761, 46.87779705865042, 45.1228141103472, 46.770103454589844, 47.44192130225045, 47.74189240591866, 45.32637548446655, 41.144456250326975, 36.35737323760986, 36.606723240443635, 35.51138489586966, 36.0134790965489, 35.290776116507395, 37.9650092124939, 36.731801237378804, 36.158738136291504, 35.656463282448904, 39.2410945211138, 36.72784423828125, 38.243392263139995, 35.32153926576887, 39.12903050013951, 46.26649802071707, 50.253363949911936, 50.084387234279085, 50.05723714828491, 49.42452028819493, 47.42611762455532, 45.50536455426897, 46.821426323481965, 43.01760026386806, 42.343541622161865, 40.67520271028791, 45.86906106131417, 42.862665857587544, 54.52802079064505, 27.406524896621704, 26.026049852371216, 52.02403940473284, 44.122131075177876, 51.33661937713623, 47.20048877171108, 53.16392959867205, 47.644937242780415, 49.298111711229595, 43.259724140167236, 41.18097250802176, 34.891744545527864, 37.881425857543945, 36.154134954724995, 40.542870794023784, 41.02135501589094, 45.43107788903372, 44.063071387154714, 43.696286405835835, 36.78504875728062, 40.444154262542725, 38.32941096169608, 35.94620663779122, 34.8758088520595, 37.8529486656189, 38.45191812515259, 38.8623343195234, 37.8710035596575, 39.20434202466692, 37.02260071890694, 36.17883232661656, 35.29183224269322, 35.7782096181597, 34.32351391656058, 39.156111104147776, 42.01051098959786, 45.87732941763741, 46.52186516353062, 50.03458949497768, 49.29451254435948, 49.166731698172434, 49.44048030035836, 49.658261162894114, 46.32941395895821, 47.21147387368338, 44.6677314213344, 36.00630508150373, 22.04396254675729, 14.73347967011588, 11.349517617906843, 9.018455181803022, 13.582124948501587, 10.950026597295489, 10.216622522899083, 6.8487095066479275, 4.57151471717017, 9.186055285590035, 1.0028317655835832, 0.11933464583541666, 6.06074036019189, 37.267107827322825, 35.128473145621165, 26.918405260358536, 26.81979295185634, 31.683667455400737, 48.181442396981375, 49.99394948141915, 38.962902545928955, 12.172075765473501, 0.837274540747915, 0.05766039953700133, 0.012509787970754718, 0.0573021669739059, 0.023635695289288248, 0.011706903776420014, 0.03972192175154175, 0.063879424040871, 0.021640790460099067, 0.03586890475292291, 0.011566980525718203, 0.03220738729994212, 0.014755743123324854, 0.01412542480310159, 0.03332202695310116, 0.011801714626406985, 0.03490482862772686, 0.09268960024097136, 0.05542913551575371, 0.009987372206524014, 0.21207694789128645, 0.17250254643814905, 0.11062064806797675, 0.14566693428371633, 0.14507669024169445, 0.11803516985050269, 0.18495586248380796, 0.1541872170886823, 0.15628044333841118, 0.18022895684199675, 0.15278079041412898, 0.15081876569560596, 0.061488558405211995, 0.1746295637318066, 0.09179529108639274, 0.17866050957569055, 0.13443986672375882, 0.14367015500153812, 0.14614163738276276, 0.1295569794518607, 3.0748419080461775, 30.357565539223806, 58.024917125701904, 55.64323445728847, 44.955032484872, 33.31655318396432, 31.865029335021973, 42.59793601717268, 44.529733249119346, 13.364352771214076, 0.5184793014611516, 0.28422504716685837, 0.29140421907816616, 2.689761451312474, 11.615468604224068, 14.924570764814105, 15.827546494347708, 17.01992859159197, 11.534422210284642, 21.59169908932277, 30.640444074358257, 42.6999112537929, 39.71115057809012, 40.82048954282488, 46.810774735042024, 50.02800955091204, 49.4795708656311, 48.10573482513428, 48.70807763508388, 45.01756974628994, 47.9177235194615, 48.17769731794085, 47.53121607644217, 46.697369711739675, 47.58469983509609, 50.88481971195766, 50.743965830121724, 47.78163957595825, 43.68833419254848, 39.25812455586025, 37.91705274581909, 36.878429072243826, 36.67616353716169, 35.92453520638602, 39.392964771815706, 39.44029937471662, 38.1095734323774, 38.66063158852713, 41.58759846006121, 37.800038133348735, 40.5647610936846, 36.994724546160015, 40.08371993473598, 48.928213936941965, 52.5350272996085, 53.104397433144705, 52.1476582799639, 53.092331886291504, 48.600752285548616, 47.089529514312744, 49.229793548583984, 44.587882723127095, 43.36075789587838, 43.11589642933437, 47.35658005305699, 44.92410257884434, 55.70356566565377, 30.919966629573278, 27.398034197943552, 51.27990123203823, 45.168276173727854, 52.8222519329616, 48.23274094717843, 55.797762393951416, 49.78074400765555, 51.66415398461478, 44.499241079602925, 43.53394521985735, 36.90185144969395, 40.19771555491856, 37.71030909674508, 43.139353547777446, 43.47577837535313, 47.17748328617641, 45.94112777709961, 46.51705353600638, 39.28747722080776, 40.783688408987864, 39.773239680698936, 40.27429512568882, 37.55889742715018, 40.728276525224956, 41.040170737675254, 40.89550576891218, 38.71532085963658, 41.50906297138759, 40.0403597014291, 37.437599250248496, 36.78740767070225, 37.54980223519461, 36.430520398276194, 41.63444668906075, 44.818587235042024, 49.85939761570522, 48.5679463659014, 52.251801354544504, 53.27772372109549, 50.46274791445051, 51.9739602633885, 51.40994719096592, 47.90164538792202, 48.733306544167654, 48.81125838415963, 38.64416435786656, 25.369594471795217, 13.471195220947266, 19.353696482522146, 12.498051370893206, 18.41000257219587, 14.839059284755162, 17.28573019163949, 10.719477551324026, 4.514615918908801, 9.961829474994115, 1.848523723227637, 0.22671005768435343, 7.486765623092651, 44.02572134562901, 46.576047216142925, 32.10144526617867, 29.334036827087402, 37.464526993887766, 54.522073132651194, 55.65943765640259, 46.501934255872456, 15.407003300530569, 1.1986036662544524, 0.09433151249374662, 0.10982292158795254, 0.15571910488818372, 0.14471475966274738, 0.10350308035101209, 0.24953896126576833, 0.17215725353785924, 0.14464103004762105, 0.18546023113386972, 0.12154413227524076, 0.174589408029403, 0.17818333660917623, 0.09871471300721169, 0.13659080916217395, 0.13770053961447307, 0.09140949643083982, 0.256610137543508, 0.27473402502281324, 0.16244364476629666], [0.019853281555697322, 0.022809158212372234, 0.01922498187715454, 0.009307442798412271, 0.04810818710497447, 0.056410422681697776, 0.05215868493542075, 0.06977397988417319, 0.020349044685385058, 0.05348807413663183, 0.018607358947130184, 0.03859843060906444, 0.04689929893772517, 0.04043218506766217, 0.01354470569640398, 0.029545379070831195, 0.07444194118891444, 0.05658579005726746, 0.02295311789826623, 0.04851032766912665, 0.7617247147219521, 23.700284549168178, 46.554386207035606, 41.80708857945034, 33.96206515175955, 19.75793399129595, 16.727129765919276, 33.782992703574045, 25.090796266283306, 5.9291675346238275, 0.03619369571762426, 0.029282755484538417, 0.18205437889056547, 1.5270760634115763, 4.68240362405777, 9.418201548712593, 7.787803275244577, 4.7583187733377725, 4.99387833901814, 11.077545148985726, 31.197029522487096, 23.4480163029262, 26.418315614972794, 36.8836020060948, 48.71314287185669, 49.98828322546822, 52.4448744228908, 43.01225362505232, 45.83380242756435, 44.99481092180525, 44.90682935714722, 47.11641556876046, 46.51251983642578, 45.538834026881624, 44.13743795667376, 44.806035314287456, 45.34794964109148, 44.80531964983259, 43.929506165640696, 39.13001367024013, 34.012213775089805, 33.02861288615635, 34.15789318084717, 34.10964836393084, 34.505494185856406, 34.660428592136924, 35.19522448948452, 33.56881448200771, 35.35919502803257, 35.26168400900704, 35.29054682595389, 34.84366301127842, 34.42868879863194, 39.385134152003694, 46.95807654517037, 46.03630072729928, 47.82715375082833, 43.51560892377581, 44.12511880057198, 38.1078850201198, 38.285418442317415, 34.42305728367397, 35.900953020368306, 35.353330748421804, 43.32413741520473, 41.64590426853725, 51.52014214651925, 27.473550694329397, 28.137030703680857, 50.48373147419521, 41.512922695704866, 48.46175009863717, 46.712443828582764, 47.642244815826416, 45.39700392314366, 48.2434481212071, 44.38439777919224, 41.881896359579905, 34.99004418509347, 35.892556122371126, 37.28454433168684, 41.09267480032784, 43.16154261997768, 44.983335971832275, 43.69964933395386, 43.76569543566023, 40.91762883322579, 38.78798164640154, 34.076178891318186, 33.768988609313965, 35.84687866483416, 36.16811473029, 34.29235471997942, 36.209119524274556, 34.32361466544015, 35.52114711488996, 32.748600482940674, 32.619492530822754, 34.28013631275722, 35.153761114392964, 41.78416299819946, 45.9904773575919, 47.842387676239014, 48.660367829459055, 46.22818217958723, 45.580415521349224, 45.23409993307931, 47.99902786527361, 44.63836485998971, 47.85582896641323, 47.690427098955425, 47.70660597937447, 46.237704685756135, 38.3629082271031, 23.86412307194301, 18.987526416778564, 12.426990406853811, 8.543530174664088, 15.662111622946602, 17.840212072644913, 7.881334713527134, 9.536760398319789, 3.0956762986523763, 0.051221326126583984, 0.32140903760279926, 0.058655070806188245, 2.292940927403314, 22.629824229649135, 44.776262283325195, 30.19037103652954, 23.977062565939768, 30.2481244632176, 38.4357670375279, 44.60056318555559, 37.16906874520438, 15.303424767085485, 0.9785395605223519, 0.06662886829248496, 0.03708516859582492, 0.01740909494193537, 0.02276635113438325, 0.0017384229390050418, 0.012296537136925119, 0.056972059687333446, 0.05278992945594447, 0.031216967052647045, 0.058830784234617434, 0.06973799038678408, 0.027448093485353247, 0.06118730242763247, 0.02979854048628892, 0.15652958782655851, 0.04101097883124437, 0.035302877625716586, 0.05450077747393932, 0.04889167452763234, 0.03137888925682221, 0.020550289690228443, 0.014640078347708498, 0.03769713932914393, 0.014080634706520608, 0.04637337662279606, 0.013532427605241537, 0.021308220091408918, 0.01050416483277721, 0.014278179999174816, 0.0043218622200324065, 0.029501382860222032, 0.1050577669271401, 0.032913671008178165, 0.03574668363268886, 0.035961545139018974, 0.06066399586520024, 0.018894380956356014, 0.03540910906823618, 0.06805295723357371, 1.7668950919594084, 27.593577350888932, 53.45703935623169, 46.019656317574636, 38.64262185777937, 22.901476212910243, 17.922287668500626, 31.86801358631679, 30.04187066214425, 6.972530748162951, 0.09671219331877572, 0.015106749288471681, 0.2808457799255848, 2.675688309328897, 6.393538662365504, 8.313346777643476, 9.293434483664376, 8.205365691866193, 4.890102216175624, 13.03484226976122, 28.84138696534293, 25.57847121783665, 29.259725843157085, 42.051616532461985, 48.42056117738996, 49.942168031420024, 51.82935435431344, 44.83422415597098, 47.030497619083945, 45.23352323259626, 45.183892250061035, 47.39534752709525, 48.051709106990266, 45.98111118589129, 45.766627243586946, 46.826178891318186, 48.56008447919573, 47.81413630076817, 45.62226799556187, 39.62569120952061, 34.15349497113909, 34.66853713989258, 35.878263677869526, 36.36836181368147, 36.14261484146118, 36.13815757206508, 36.19141204016549, 35.563902854919434, 36.68707915714809, 37.11766249792916, 36.74113266808646, 37.076351983206614, 36.17064387457711, 42.34721027101789, 48.581193106515066, 48.07039628710066, 49.395852020808626, 46.400445393153596, 46.279602323259624, 40.26735734939575, 39.823732239859446, 36.234004497528076, 37.83386543818882, 37.202684129987446, 44.966740199497764, 43.24685607637678, 52.63482775006975, 29.430787018367223, 29.802866527012416, 49.30945117133004, 42.88912807192121, 49.04134798049927, 47.73631647654942, 48.82655136925833, 46.76641048703875, 50.30571515219552, 46.065111432756694, 43.109281744275776, 37.226693630218506, 39.14186034883772, 38.23945958273751, 43.216777324676514, 44.452521392277305, 46.533736160823274, 44.98842552730015, 45.40952110290527, 42.02916342871529, 39.55664348602295, 34.698032242911204, 35.79445103236607, 36.57935776029314, 37.52175235748291, 35.81850569588797, 39.20694065093994, 35.808458600725444, 36.77525874546596, 34.93181133270264, 35.937712465013774, 36.1542044367109, 36.653783389500205, 41.88016625813076, 48.22198860985892, 49.98992300033569, 53.005604471479145, 48.855959619794575, 48.9282660484314, 47.25625501360212, 50.34607376371111, 46.38302973338536, 49.073483398982454, 48.01646089553833, 51.301857539585654, 46.69793946402413, 43.09022283554077, 24.46104976109096, 18.651160648890905, 10.013776813234601, 9.7489401442664, 11.450418489319937, 13.529418519565038, 8.715313094002859, 8.459569011415754, 7.177803984710148, 0.3380630282419068, 0.46248903444835116, 0.006435597190699939, 3.523446921791349, 25.03225248200553, 41.339516503470286, 32.97540358134678, 24.88195252418518, 32.9846898487636, 43.21610682351248, 49.86461918694632, 43.15096746172224, 17.805960927690776, 1.2187704869679041, 0.01525047148710915, 0.03142444609797426, 0.06012807533677135, 0.031069969226207052, 0.10457201727799006, 0.03349681757390499, 0.022679753102628247, 0.04556361971689122, 0.02368693146854639, 0.03061043138482741, 0.030479409665401493, 0.018064990639686584, 0.025131719120379006, 0.028494664201779023, 0.1318038667419127, 0.01176294737628528, 0.0680312237569264, 0.026245955045201948, 0.10926813778600522, 0.10811752559883253, 0.07099315124963011, 0.1264359897800854, 0.08870170744402067, 0.09154721189822469, 0.08711722639522382, 0.09020982616181884, 0.22365301315273556, 0.1149256881326437, 0.11289744518165078, 0.08513784475092377, 0.12944175063499383, 0.19422204526407377, 0.11279234010726213, 0.13641797272222383, 0.09477882991944041, 0.12482897458331925, 0.15907475911080837, 0.10338462170745645, 0.15283873730472156, 2.9558071068355014, 34.008666719709126, 60.71423476082938, 53.14671891076224, 45.684707982199534, 28.813762664794922, 24.955273389816284, 44.21172114780971, 34.23052617481777, 8.869943516595022, 0.18043329087751253, 0.15865352457123144, 0.45507897064089775, 6.044839407716479, 12.68496572971344, 17.687422922679357, 14.00568974018097, 9.673627751214163, 10.712033425058637, 14.2832042660032, 34.41783223833357, 30.310352529798234, 37.67729473114014, 45.11307273592268, 50.7219991002764, 51.08497646876744, 52.26120226723807, 44.28963129861014, 49.59903819220406, 45.965220655713765, 45.946818351745605, 49.50249644688198, 49.12689767565046, 47.009642601013184, 45.78052364076887, 47.2319050516401, 51.868448393685476, 50.49819414956229, 48.857408319200786, 41.334552015577046, 36.858199392046245, 36.17979465212141, 37.72079045431954, 37.89871992383684, 37.590932096753804, 38.549929414476665, 38.52110481262207, 37.357448305402485, 38.47922454561506, 38.59229605538504, 39.71345043182373, 39.54846545628139, 37.903204986027305, 44.050918987819124, 50.60037783214024, 50.227360316685264, 51.516744477408274, 48.15306942803519, 48.87763799939837, 41.744256019592285, 41.78097724914551, 38.36454452787127, 40.664415631975444, 39.025582245418, 46.350536482674734, 46.02710826056344, 55.137575830732075, 33.742568084171836, 31.849069322858536, 48.423726081848145, 43.79006971631731, 50.02500098092215, 49.988106046404155, 49.77474423817226, 49.8355062348502, 51.02571528298514, 49.04628814969744, 45.841976983206614, 39.32298946380615, 40.003965037209646, 40.462539196014404, 44.471952029636924, 47.67065947396414, 48.957462378910606, 47.9040390423366, 47.77315582547869, 44.39623403549194, 42.53885548455374, 37.28510366167341, 36.510320459093364, 39.029591356004985, 39.126053197043284, 37.359616143362864, 40.16535431998116, 38.04923527581351, 38.56590332303728, 35.95648649760655, 37.2675837789263, 37.180522850581575, 38.90120601654053, 45.780200549534385, 52.02555758612496, 52.752050808497835, 53.982298851013184, 51.01115533283779, 49.92114973068237, 50.16060202462332, 52.618218081338064, 47.095960072108674, 51.20718138558524, 49.92985929761614, 51.146235261644634, 49.06557287488665, 44.411996023995535, 29.708239010402135, 23.66098380088806, 16.070217541285924, 13.658106105668203, 27.792533806392125, 27.994302545275005, 13.135384440422058, 15.11350096975054, 7.031480133533478, 0.38592349578227314, 0.5128365499632699, 0.17881068294601782, 4.232136905193329, 30.122045925685338, 55.70181124550955, 39.05553592954363, 32.23388140542166, 39.540200574057444, 48.97185557229178, 56.578858034951345, 50.31689827782767, 23.867525952202932, 1.8998003431728907, 0.09061287596289601, 0.1680580335003989, 0.15383948146232537, 0.08623952777790171, 0.1672247246439968, 0.11485114427549498, 0.10749043710529804, 0.16055157700819628, 0.11398268730512687, 0.20342801484678472, 0.1379629833889859, 0.07410465500184468, 0.11964552343956061, 0.11986087688377925, 0.2937752918473312, 0.12843054346740246, 0.15217977123601095, 0.13295829908124038, 0.1666689230395215], [0.02540720603428781, 0.0058441809794333366, 0.0664894904143044, 0.005470050764935357, 0.01693529259812619, 0.06786746611552578, 0.017007989143686633, 0.025887788639270833, 0.04134386471871819, 0.025372719491965005, 0.0478852204978466, 0.01197926264389285, 0.045464010776153634, 0.00979252069789384, 0.0605710908504469, 0.09448104804115635, 0.02499612746760249, 0.04135295369529298, 0.013794933296074825, 0.039020954365176816, 0.5643508742962564, 24.219077008111135, 48.86662857873099, 44.56829922539847, 27.01065128190177, 20.493091617311748, 21.783881051199778, 33.45406150817871, 26.308367320469447, 3.595475856746946, 0.12766675730901106, 0.05769706078405891, 0.07916397494929177, 2.0689006064619337, 9.523886254855565, 6.648703004632678, 15.657775947025844, 10.992615580558777, 4.139652907848358, 22.765788316726685, 19.495111431394303, 21.288325105394634, 36.90718766621181, 44.10951314653669, 48.918198108673096, 44.74122599193028, 45.303213664463584, 45.945258481161936, 40.05397122246878, 43.77459955215454, 48.40590047836304, 46.088770048958914, 45.5377014705113, 46.91969469615391, 45.082566670009065, 45.61657394681658, 45.32608713422503, 46.41398743220738, 45.49913896833147, 43.30098254340035, 41.22304732458932, 36.762533119746614, 35.80534928185599, 34.8679712840489, 33.21074601582119, 32.539862700871055, 35.312127930777415, 34.18362583432879, 35.25550011226109, 36.69486461366926, 34.71634422029768, 34.03041458129883, 34.423832007816856, 33.78620277132307, 37.65189906529018, 39.22607251576015, 40.07487487792969, 36.00437348229544, 36.51591375895909, 32.93836273465838, 34.537195341927664, 33.53363575254168, 35.156554290226524, 35.511176449911936, 44.72130898066929, 43.342300006321494, 53.10547092982701, 31.102065018245153, 29.408948830195836, 53.14258125850132, 44.665838037218364, 49.3430735043117, 44.2892804145813, 48.80869449887957, 45.83852025440761, 48.21661070414952, 47.22465808050973, 43.739153317042756, 37.32175540924072, 36.91659205300467, 37.113087109157014, 40.258421966007774, 41.6414087840489, 46.147392000470845, 45.116807392665315, 46.21473741531372, 42.39816835948399, 38.23607233592442, 34.66378457205636, 35.34282854625157, 32.908957958221436, 36.40694516045706, 37.34442738124302, 39.533005714416504, 35.55167749949864, 35.12292153494698, 30.929603781018937, 35.40493154525757, 32.79487895965576, 39.77641153335571, 45.42811795643398, 49.21116542816162, 46.16328253064837, 46.52804211207798, 44.28485441207886, 46.60639694758824, 46.18161187853132, 48.36802932194301, 47.15209109442574, 49.77526535306658, 43.443688120160786, 49.94729927607945, 49.25832980019705, 48.33633858816964, 25.76604652404785, 23.974066155297415, 12.956985967499868, 15.19314295904977, 9.562341928482056, 9.240984269550868, 7.897961752755301, 7.954044137682233, 10.094720721244812, 0.2575080022215843, 0.05730725598654576, 0.038885433958577256, 1.518039496881621, 17.849611248288834, 38.18987723759243, 27.31302125113351, 23.410112142562866, 22.827912160328456, 40.6632205418178, 40.40034934452602, 41.98094987869263, 20.46290169443403, 1.9233432284423282, 0.044336597701268535, 0.05580844337652836, 0.018294735811650753, 0.03405008824276073, 0.0332595033438078, 0.037876479527247806, 0.038375626850341044, 0.04002206493169069, 0.0508214009792677, 0.03315359420542206, 0.07929162095699992, 0.06749383080750704, 0.01129790407139808, 0.039662468513207774, 0.0151953489985317, 0.03281061171687075, 0.010261862522124179, 0.023916125330807905, 0.07308817561715841, 0.03939862695655652, 0.01240008497344596, 0.00527779889359538, 0.0434479203873447, 0.012822325441188045, 0.03306958817743829, 0.015695580281317234, 0.04502694262191653, 0.06426605329449687, 0.007382292217308921, 0.06131465666528259, 0.031083712953009775, 0.061179675694022856, 0.036091566019292386, 0.10200540428715092, 0.07329273356923036, 0.02667748465734933, 0.05402620668922152, 0.04615776872794543, 0.00407112147825371, 1.1400475054979324, 29.4762282371521, 54.081300258636475, 50.584348337990896, 32.74880198069981, 23.986418315342494, 25.919224773134502, 33.8693379674639, 28.51025492804391, 4.606625267437526, 0.07859851779150111, 0.1710725338863475, 0.0970022263271468, 3.6503477352006093, 10.36704581124442, 9.727878417287554, 11.221890500613622, 9.954772710800171, 8.442919390542166, 18.514043160847255, 20.11512872150966, 23.633149317332677, 41.49473925999233, 45.0434969493321, 48.714879921504426, 45.741005761282786, 45.749510356358115, 45.18897833142962, 43.11205407551357, 44.17217200142996, 47.907551356724326, 46.95578363963536, 46.38433599472046, 46.10719667162214, 45.89950111934117, 46.34923716953823, 47.44616665158953, 49.413715839385986, 48.0852723802839, 45.94203451701573, 42.47928510393415, 39.08827236720494, 35.82992158617292, 36.04618426731655, 34.94609335490635, 35.13317707606724, 35.81846053259713, 35.822024958474294, 37.25812380654471, 38.522240843091694, 37.092318943568635, 35.90181112289429, 36.03303827558245, 36.48248597553798, 39.90367126464844, 41.18785122462681, 41.10931921005249, 38.54563890184675, 37.90811736243111, 34.94424513408116, 35.21481146131243, 34.542934553963796, 37.65614094052996, 38.028369835444856, 46.46985442297799, 43.99032722200666, 53.75337307793753, 33.58671998977661, 30.25132758276803, 52.93038327353341, 48.13909312656948, 51.03508145468575, 46.696657521384104, 49.63610683168684, 48.267033781324116, 49.78734132221767, 48.25052833557129, 45.57570464270455, 39.12922157560076, 36.4664113180978, 38.49342318943569, 42.599304812295095, 43.65668167386736, 48.43916845321655, 46.72941827774048, 47.977533612932476, 44.156670570373535, 39.853512219020296, 36.81056601660592, 36.86314650944301, 34.5923501423427, 37.596223149980815, 39.19867924281529, 40.22139154161726, 37.97713729313442, 36.30737052645002, 33.52756997517177, 35.614857469286235, 36.03977108001709, 41.474318504333496, 47.136210986546104, 51.081144537244526, 48.96811049325125, 49.154117243630544, 46.27205310549055, 46.23844814300537, 46.94090754645211, 49.755925042288645, 48.875233922685894, 49.84990985052926, 48.45374924795968, 50.76211452484131, 52.79664782115391, 48.11388158798218, 31.186461312430247, 20.810337679726736, 11.140545334134783, 6.8919607400894165, 14.902027334485735, 14.563313943999153, 7.560869898114886, 13.101577111652919, 8.756307465689522, 1.0728721043893268, 0.14705174283257552, 0.09514620234923703, 1.671109831758908, 21.360056570598058, 43.635788440704346, 31.376508440290177, 28.50710391998291, 28.908763647079468, 45.5118020602635, 46.511477606637136, 48.79622595650809, 25.845744098935807, 2.458299368619919, 0.06182017203952585, 0.07339352316090039, 0.016767687663169842, 0.011876726672718567, 0.056284781744969745, 0.05366978920730097, 0.03340660973585077, 0.03564878120752318, 0.01532992284878024, 0.06580718952630248, 0.013723385171033442, 0.025047222850844264, 0.05505835344748838, 0.01151229314772146, 0.015059163627613868, 0.04528608871623874, 0.04820082749107054, 0.005517400210789804, 0.08865551956530128, 0.12459131090768746, 0.10068578259753329, 0.14671181035893305, 0.0802207864554865, 0.07996656652539968, 0.15512481677745069, 0.07347626372107438, 0.11816687349762235, 0.09439987489687544, 0.09280672217054026, 0.195909765415958, 0.06935848575085402, 0.11587953194975853, 0.10887855690504823, 0.12950233024145874, 0.22232491656073503, 0.14197719655930996, 0.15681854874960013, 0.10267495550215244, 0.1012854582763144, 2.3879566746098653, 36.66445582253592, 60.96203531537737, 57.77153716768537, 37.571331228528706, 29.65870530264718, 31.0322390965053, 43.04982253483364, 34.1883019719805, 5.555572015898568, 0.30133580043911934, 0.30124645094786373, 0.32378564721771647, 5.106506032603128, 15.381527730396815, 15.896066154752459, 27.303193024226598, 18.195400510515483, 8.747733388628278, 25.951917784554617, 23.96852149282183, 29.121774571282522, 45.550086634499685, 46.82950013024466, 49.971419947487966, 45.71783004488264, 48.36852264404297, 48.41179602486746, 43.89131191798619, 45.379800183432444, 48.14537082399641, 48.297515528542654, 46.92667416163853, 48.664276191166465, 48.26620347159249, 48.06258303778512, 48.21851451056344, 50.80606882912772, 50.24802425929478, 47.824370997292654, 45.44141680853707, 40.330446992601665, 38.83710541043963, 38.17264223098755, 36.33038296018328, 36.61371660232544, 38.65848112106323, 37.89914376395089, 39.69291155678885, 40.911715916224885, 39.30072396142142, 37.62845931734358, 38.08971200670515, 37.71150418690273, 40.219817774636404, 42.62815720694405, 42.90254156930106, 39.82916573115757, 38.84282030378069, 35.84214346749442, 37.6675637790135, 37.10546840940203, 39.22886221749442, 41.12755128315517, 48.20359672818865, 48.41566617148263, 55.36322900227138, 35.268298694065635, 32.81048461369106, 53.41030577250889, 50.25484044211251, 53.34499617985317, 49.31677804674421, 51.36777857371739, 50.580874238695415, 50.92507757459368, 50.09921816417149, 50.27807869229998, 41.45148324966431, 39.671889781951904, 40.589048521859304, 44.13101782117571, 45.030052185058594, 51.1353439603533, 48.38307564599173, 48.658745425088064, 46.00239699227469, 41.92682688576834, 38.59280674798148, 39.46547964641026, 35.66429737636021, 39.73195695877075, 40.698281151907786, 43.67934669767107, 39.49232401166643, 38.56139394215175, 34.843065466199604, 37.953329290662495, 37.61989566258022, 43.243513992854524, 49.70514760698591, 52.37966210501534, 49.51621219090053, 49.404624121529714, 47.21437474659511, 48.09868240356445, 49.177570887974326, 51.55683558327811, 49.16152402332851, 52.09196499415806, 49.32135343551636, 54.45333807809012, 54.54780926023211, 52.42998095921108, 32.58669703347342, 31.252344131469727, 16.70429277420044, 21.768654073987687, 21.0894798210689, 12.963497298104421, 17.060855218342372, 14.51309323310852, 15.605473382132393, 1.8269441383225578, 0.44520137352602823, 0.1240752036018031, 2.385768643447331, 23.924303156988962, 49.906228474208284, 38.05843816484724, 31.45614869253976, 34.55866527557373, 51.89598410470145, 52.32378469194685, 56.573379380362375, 30.497707230704172, 3.698379329272679, 0.1758417258305209, 0.14692561674330915, 0.10904471656041485, 0.14007720351219177, 0.18953501033995832, 0.0961039884548102, 0.14520163568002836, 0.10049201335225787, 0.10631095325308186, 0.09753155828054462, 0.0808315561818225, 0.13350451977125236, 0.10132092530173914, 0.1769638599029609, 0.14971677054251942, 0.1195536090859345, 0.10788184324545519, 0.11830655671656132, 0.19838183133729867], [0.04186935616391046, 0.054875685035118034, 0.005055190213689846, 0.05630151441852961, 0.027313772389399152, 0.04369931421907885, 0.04680391727015376, 0.030738257204315493, 0.041593636851757765, 0.07253345966871295, 0.026478144639570798, 0.05490529291065676, 0.012750242121650704, 0.01121193538087287, 0.07117836416832038, 0.013799263197662575, 0.033252314265285215, 0.0351844393382115, 0.03436605485954455, 0.02298163842143757, 1.355727732181549, 31.136510712759836, 45.21618052891323, 38.505561692374094, 26.993160928998673, 11.80216930593763, 13.207540614264351, 29.7837416103908, 21.992255789893015, 1.435284823179245, 0.15120285722826207, 0.03622101353747504, 1.9819052517414093, 1.8879784175327845, 5.303701988288334, 6.518419938428061, 3.6199389440672736, 6.761928243296487, 8.579490576471601, 14.930943999971662, 17.009085927690776, 30.106461116245814, 40.08307722636631, 49.06040688923427, 46.86099631445748, 48.596698011670796, 47.78357812336513, 47.401983056749614, 41.538742201668875, 44.44949197769165, 44.59167643955776, 46.24857861655099, 45.74348974227905, 44.05398314339774, 44.951162338256836, 44.61836099624634, 46.50528328759329, 46.62577199935913, 46.2560270854405, 46.42827640260969, 43.89801345552717, 42.29671423775809, 41.49608373641968, 39.273598194122314, 36.2250725882394, 35.28925098691668, 32.64175803320748, 33.60004316057478, 34.17345714569092, 34.11496026175362, 34.71565982273647, 33.213351590292795, 33.61295291355678, 33.4274012701852, 33.11858510971069, 31.39660610471453, 32.265707629067556, 32.9860760143825, 34.01612213679722, 33.54236963817051, 36.00073610033308, 32.353473799569265, 34.3205817767552, 37.37082706178938, 44.29759046009609, 43.58591774531773, 52.43960768835885, 31.635731833321707, 30.217260565076554, 52.19439533778599, 43.30026340484619, 44.96413809912545, 40.367998531886506, 44.147391251155305, 42.18090861184256, 44.02195542199271, 40.393269130161826, 38.739090647016255, 35.4541734286717, 37.03840092250279, 34.592412676130024, 36.27037831715175, 40.700716495513916, 46.15443747384207, 48.55686051504952, 46.8085686819894, 43.53489364896502, 38.30885124206543, 35.83058513913836, 37.942351136888774, 40.22777346202305, 44.86258322851998, 46.77988304410662, 47.82134158270699, 44.23656790597098, 41.17388187135969, 38.32868487494332, 33.9788624218532, 34.983637945992605, 44.0363312448774, 45.47312143870762, 47.084710938589915, 45.14168541772025, 46.04329408918108, 44.655447006225586, 49.065843854631694, 48.338624545506065, 48.7103705406189, 44.184769085475374, 43.8652457509722, 44.74819156101772, 49.52016918999808, 48.74953753607613, 47.28771645682198, 34.9761894771031, 25.81165623664856, 12.973350712231227, 6.981910381998334, 7.3707020453044345, 17.549106870378765, 5.799841582775116, 3.9232143504279, 7.88089610849108, 0.9876006628785814, 0.6122901876057897, 0.006376956498050796, 0.7372297091143472, 11.098948206220355, 37.31543254852295, 29.081990923200333, 16.589640549251012, 23.281021560941422, 34.678507804870605, 43.49895061765398, 45.01055553981236, 22.180569342204503, 1.6748810751097543, 0.06889700051397085, 0.017422555380367806, 0.009897311101667583, 0.04714394473869886, 0.06764764791088444, 0.0010776898166763463, 0.010183017601126006, 0.06558190911476101, 0.013758002331347337, 0.04876635928771325, 0.044726222687001736, 0.01855548664129206, 0.016878075132678663, 0.09039425876523767, 0.15396423691085406, 0.035324909657772095, 0.027845285832881927, 0.04097655335707324, 0.03841148064072643, 0.025827658562255756, 0.0528960421548358, 0.005057683405798993, 0.0746773589136345, 0.045106904581189156, 0.03685647854581475, 0.019279268071321503, 0.053681975696235895, 0.052862244325556924, 0.039984823537192175, 0.02742294019221195, 0.020466134384540573, 0.014927885761218411, 0.07277765763657433, 0.01597987797244319, 0.033319923494543345, 0.09344915912619658, 0.05974329848374639, 0.013273798893871052, 0.04233332823163696, 2.2240147973809923, 38.04414224624634, 50.28661455426897, 45.38564361844744, 30.966283321380615, 17.01539489201137, 15.700939893722534, 31.870560101100377, 25.375498703547887, 2.1963064670562744, 0.12009940908423491, 0.07658731285482645, 3.6589904257229398, 5.345304327351706, 12.118936811174665, 8.232183132852827, 9.775003705705915, 9.09166053363255, 10.024857452937535, 17.965866770063126, 17.636136531829834, 33.74364505495344, 43.91140610831124, 49.44124460220337, 49.26156071254185, 48.71877786091396, 49.3036459514073, 48.7557874407087, 43.14194522585188, 46.453317710331504, 45.05075434276036, 45.71922663279942, 45.57516615731375, 45.43339163916451, 46.198628016880576, 45.97288799285889, 46.45580516542707, 45.99039397920881, 49.772593770708355, 47.62607288360596, 45.22139515195574, 42.93491322653634, 41.91044650759016, 41.16870893750872, 38.86158391407558, 36.38694477081299, 35.03265053885323, 36.54831320898873, 36.1150027002607, 35.163735253470286, 36.60585124152047, 35.02674457005092, 35.23810877118792, 34.147703647613525, 35.34866155896868, 34.21907206944057, 34.54465075901577, 34.70640482221331, 34.840362616947715, 35.62025274549212, 37.76165281023298, 34.430623871939524, 36.8475512777056, 38.85450717381069, 46.268634591783794, 44.417123794555664, 53.889533451625276, 33.154302324567524, 32.245179176330566, 54.22836235591343, 44.68079056058611, 47.91133465085711, 43.070305824279785, 46.58407933371407, 45.04133605957031, 46.48510224478585, 43.34193869999477, 40.586151123046875, 38.19037055969238, 38.17399712971279, 37.2711968421936, 38.41333130427769, 42.77936390468052, 47.88979523522513, 49.41991710662842, 48.66691650663103, 44.96160200663975, 41.43366806847708, 37.63424021857125, 37.94589819226946, 40.83020659855434, 46.536543233054026, 47.81985119410923, 49.16356679371425, 46.455992766789024, 42.04655476978847, 38.621224880218506, 34.48185641424996, 36.66673830577305, 46.520103795187815, 48.596944672720774, 48.58244725636074, 46.53726584570748, 47.81424399784633, 46.02535036631993, 48.19557850701468, 49.9082156590053, 49.37599059513637, 47.78748648507254, 45.637338638305664, 47.74294853210449, 49.33877951758248, 49.01939167295183, 48.052848611559185, 37.94143050057547, 26.492214918136597, 12.700916188103811, 9.508762632097516, 13.201563426426478, 13.550426398004804, 11.224106975964137, 9.757297090121678, 6.7316740495818, 2.2665981352329254, 0.3240354566701821, 0.031120316524590765, 0.7197287710649627, 13.587085093770709, 40.09465292521885, 31.789026464734757, 20.51762396948678, 29.154870578220912, 39.525331429072786, 48.81424610955374, 50.059203488486155, 25.94381618499756, 2.3924258862222945, 0.0579030504450202, 0.06074991875461169, 0.06500457080879382, 0.04693121722500239, 0.06190010346472263, 0.04809193619127784, 0.061842448344188075, 0.04408856601055179, 0.027876888601375476, 0.03074969391205481, 0.039084892719984055, 0.0469283979119999, 0.02030930628201791, 0.05221401946619153, 0.043400080275854895, 0.02253620053774544, 0.04300706600770354, 0.03896996924387557, 0.014319789462855883, 0.09246674898479666, 0.1936507730611733, 0.13470644956188543, 0.11979121847876481, 0.13135593863470213, 0.11879085430077144, 0.12032378704420157, 0.11762787242020879, 0.19366384164563247, 0.16418123724205153, 0.13044594175049237, 0.12743746675550938, 0.08339284267276525, 0.12406068295240402, 0.19746891675250872, 0.09773221465625934, 0.19128812769693987, 0.18255591126424925, 0.10126483081174747, 0.12384626588651113, 3.906127861567906, 45.33578681945801, 55.75118514469692, 51.67173446927752, 37.24848665509905, 18.868208476475306, 19.04555777141026, 39.92248003823416, 29.76608623777117, 2.8090372681617737, 0.2775274451289858, 0.26919375945414814, 4.5628750664847235, 7.383378165108817, 11.828810436385018, 12.513036898204259, 9.822691798210144, 13.201600772993904, 12.277684041431971, 19.465550320489065, 22.419505732400076, 37.95248508453369, 45.902415888650076, 52.45506048202515, 51.198683738708496, 50.8520450592041, 50.73515204020909, 51.577370984213694, 45.79556649071829, 47.89943586077009, 46.10598768506731, 47.12579911095755, 46.742706707545686, 45.543954849243164, 45.78604398454939, 46.15851606641497, 47.8357104573931, 47.456873825618196, 51.0123747416905, 51.667496068137034, 48.295733315604075, 47.50136661529541, 45.58063786370413, 43.92096682957241, 40.36057438169207, 39.807216371808735, 36.18047210148403, 38.56956154959542, 38.46286153793335, 38.28720760345459, 37.67606142589024, 37.192331314086914, 35.06054755619594, 36.94675418308803, 36.41229179927281, 35.57428346361433, 35.18928377968924, 35.69595684323992, 37.12851211002895, 36.86035680770874, 39.5158679825919, 36.041758264814106, 38.34455108642578, 41.63906724112374, 48.29898854664394, 47.87674304417202, 55.13458810533796, 34.87340824944632, 34.99979598181588, 55.0994302204677, 47.339428424835205, 48.56537553242275, 43.968780858176096, 47.675919260297505, 46.61588471276419, 47.58012097222464, 44.127599307468955, 42.271801471710205, 38.72169583184378, 40.202033860342844, 39.033235686165945, 39.122485297066824, 44.49517638342721, 51.450983251844136, 52.0549693107605, 50.748450892312185, 48.64014162336077, 42.202274322509766, 38.61869921003069, 41.58128602164132, 43.9598593711853, 49.59331635066441, 51.16921990258353, 52.29396997179304, 49.06559024538313, 44.01231132234846, 42.380440030779155, 36.98272500719343, 39.091503279549734, 49.04053851536342, 49.45151056562151, 50.30869940349034, 46.02304009028843, 47.7293370110648, 46.23621777125767, 51.10734966823033, 52.05871091570173, 51.88783386775425, 49.9242833682469, 47.64742469787598, 48.94573729378836, 53.43312018258231, 50.8914726121085, 51.0644063268389, 39.38452271052769, 32.99296167918614, 17.268854754311697, 12.462325470788137, 13.295958178383962, 25.565578835351126, 10.520040801593236, 5.887735860688346, 13.431545325687953, 2.3569073464189256, 1.1327440802540099, 0.08533759188971349, 1.2335962057113647, 15.82929744039263, 48.41721561976841, 38.78834990092686, 23.656594276428223, 33.302934714726035, 45.423730169023784, 54.490844454084126, 57.720231669289724, 32.048180375780376, 3.895230914865221, 0.16303789216492856, 0.0674040334831391, 0.08924716138946158, 0.32890570962003296, 0.20075647320066178, 0.09323904397232191, 0.20391326238002094, 0.15234910643526486, 0.061996577573674064, 0.16033843558813843, 0.06233793497085571, 0.07018986756780318, 0.08559534698724747, 0.1822629062724965, 0.43076323398521965, 0.08538943875048842, 0.07997373185519661, 0.16644645854830742, 0.09399111183094126], [0.020186175924858878, 0.013794929903399731, 0.05525894196970122, 0.05039627504135881, 0.02861970124234046, 0.025959353727687682, 0.031598208738224845, 0.04018092015758157, 0.03710595551612122, 0.022886456921696663, 0.007647695252671838, 0.048731146712920496, 0.0431827455093818, 0.008643644712200122, 0.04164068307727575, 0.013107964935313379, 0.006634775208242769, 0.08102830419582979, 0.08857148300324168, 0.03392426410157766, 2.884322954075677, 28.55255729811532, 42.30114024026053, 39.44482612609863, 31.700395243508474, 16.7671149117606, 28.368160792759486, 30.191910062517437, 17.821297339030675, 1.3474167095763343, 0.35819871776870316, 0.3741844871214458, 6.96063369512558, 25.522559063775198, 12.689401285988943, 12.038138815334865, 10.527272139276777, 11.290079253060476, 13.593565157481603, 13.594603044646126, 22.364262342453003, 39.77706118992397, 46.791114807128906, 50.296178749629426, 46.47923101697649, 47.427013942173545, 43.63894292286464, 48.218848024095806, 45.41983917781285, 47.221878801073345, 47.890298979622976, 45.788270882197786, 46.13275562013899, 47.44715676988874, 45.29397256033761, 46.49386044910976, 44.305799756731304, 46.05866697856358, 46.2368083681379, 47.79022060121809, 46.31960310254778, 46.598121643066406, 45.67584555489676, 46.28963204792568, 47.300077302115305, 43.43722629547119, 38.63335296085903, 32.955955573490684, 33.433519159044536, 31.923408099583217, 32.98569733755929, 33.14690596716744, 32.673507826668875, 33.73472356796265, 34.27054779870169, 33.39931665148054, 34.135200364249094, 32.64137935638428, 33.731395380837576, 32.41496188299996, 35.3113671030317, 33.38908542905535, 34.33229991367885, 36.23842007773263, 43.530082021440776, 42.475248200552805, 49.015587534223286, 36.300297260284424, 33.632084778376985, 50.465416022709434, 43.09174796513149, 43.902811186654226, 37.405244963509695, 37.25823497772217, 33.25160142353603, 34.191376549857004, 33.37546695981707, 35.08016926901681, 34.73299557822091, 35.324158736637656, 33.88869564873831, 34.89823416301182, 41.38417257581438, 47.67413704735892, 48.29739740916661, 47.455466815403526, 44.4657438141959, 43.91504349027361, 40.95550346374512, 42.19877937861851, 45.73685768672398, 46.41273675646101, 48.82736778259277, 48.062409332820344, 49.07846873147147, 45.3274142401559, 45.637922286987305, 41.77365037373134, 43.347549370356965, 43.64682218006679, 45.994632380349294, 47.61524064200265, 46.21549129486084, 43.72787291663033, 46.5975866317749, 46.088214193071636, 47.258916173662456, 44.27566541944231, 44.05042566571917, 43.84646129608154, 47.35063934326172, 47.31743390219552, 51.91194759096418, 46.614071232931956, 40.132506711142405, 27.72685422216143, 17.227931601660593, 8.90400184903826, 22.26042672566005, 16.659164224352153, 8.324794803346906, 11.48280838557652, 11.557828085763113, 1.8482594745499747, 0.055717132919068844, 0.19386471515255316, 0.08872843493840524, 9.919592244284493, 33.214876719883506, 32.736726011548726, 24.304294926779612, 26.24904533794948, 38.84089912687029, 45.39639595576695, 45.218869481767925, 26.70996277672904, 3.7712390082223073, 0.07439058965870313, 0.04835194741774883, 0.03407365715663348, 0.015042527645294155, 0.03140945386673723, 0.05382776912301779, 0.037424012020762475, 0.03958924440667033, 0.0208784139582089, 0.05199790606275201, 0.01272611172005002, 0.04075369531554835, 0.05033968861347862, 0.010846679980334426, 0.05421742803550192, 0.024546928803569505, 0.03480536896469338, 0.02264390609759305, 0.0632364713986005, 0.02878065314143896, 0.04271281590419156, 0.04540153466431158, 0.05460890542183604, 0.05243048231516566, 0.06749948300421238, 0.017125360434874892, 0.022724137774535587, 0.05425911383437259, 0.033126897245113335, 0.04549024972532477, 0.023181032722017596, 0.04510911660534995, 0.04774754234988775, 0.021702462507944022, 0.026109744229220917, 0.06964725668409041, 0.04971628456509539, 0.09030881763568946, 0.030144515314272473, 4.719991207122803, 33.487704685756135, 48.34669140407017, 43.97918231146676, 33.135597773960654, 16.13104554585048, 26.327382802963257, 34.100709506443565, 22.464417151042394, 1.2488227486610413, 0.22493148169347219, 0.25023796090057915, 8.210698434284755, 24.977274860654557, 11.014472876276288, 10.19734822000776, 8.931481974465505, 7.711609329496111, 12.75807728086199, 14.406547818865095, 22.699703999928065, 42.970241342272075, 47.642706871032715, 51.54865060533796, 48.681205477033345, 49.53444078990391, 46.06233215332031, 52.01171677453177, 47.01310280391148, 49.66182211467198, 50.18861716134207, 46.207855224609375, 47.740266527448384, 47.61693252835955, 45.552178042275564, 46.883331298828125, 44.21060248783657, 46.00637831006731, 47.40565517970494, 50.000282764434814, 48.16690329142979, 48.91271250588553, 47.520210129874094, 46.994061265672954, 47.954722676958355, 45.64312996183123, 38.71541118621826, 34.08454104832241, 34.05189841134207, 33.95304638998849, 35.57206698826381, 34.54870155879429, 34.62697301592146, 34.67909492765154, 34.8018730708531, 34.5021208354405, 33.99171658924648, 34.89214406694685, 35.12484966005598, 35.400331837790354, 37.059863907950266, 36.21079751423427, 35.76849603652954, 38.62915277481079, 45.16244663511004, 44.93129743848528, 50.80746194294521, 37.76831613268171, 34.76009702682495, 50.78505400248936, 43.955513272966655, 45.72871092387608, 39.74350486482893, 38.87526144300188, 35.22691522325788, 36.44678613117763, 36.21280901772635, 37.9247339793614, 37.362687247140066, 37.34671333857945, 35.97523621150425, 36.59942763192313, 42.44451284408569, 48.95558636529105, 49.00315720694405, 49.41111373901367, 45.162067958286826, 44.69095924922398, 42.18145057133266, 44.87176527295794, 47.619562421526226, 49.213440963200156, 50.270056997026714, 50.00755058016096, 51.40937743868147, 47.559338910239084, 46.77383116313389, 41.41885450908116, 44.04675006866455, 45.849283014025005, 48.28650263377598, 48.59287997654506, 46.502361570085796, 45.41769218444824, 46.36871991838728, 46.89984369277954, 49.05075584139143, 45.72665425709316, 46.216533524649485, 46.85284955160958, 48.83265536172049, 50.01201827185494, 54.30910389763968, 47.27798203059605, 42.1670434815543, 28.72469197000776, 19.530625411442347, 8.924010055405752, 9.200193132672991, 9.498980437006269, 9.196304747036525, 15.056292976651873, 8.879430413246155, 2.755923718214035, 0.11403118898825985, 0.1195405540721757, 0.19279908947646618, 10.915367245674133, 38.99117129189627, 33.2751419203622, 22.811703750065394, 28.399881056376866, 42.4167617389134, 50.11986821038382, 52.25682142802647, 32.26445695332119, 5.063699918133872, 0.05264792903991682, 0.05206243474302547, 0.016775422962382436, 0.04397325237680759, 0.06077223577137504, 0.018499658476295214, 0.06413092304553304, 0.04130839430061834, 0.011203949023703379, 0.008659310389443167, 0.029451720882207155, 0.020998845442331264, 0.036369432894779105, 0.034496445541403124, 0.03472102027652519, 0.02375141265136855, 0.03361571387254766, 0.06263708748987742, 0.0879057247989944, 0.10977298141058002, 0.1158862765878439, 0.11227194446005992, 0.15246728009411267, 0.2244306957083089, 0.14229700368429932, 0.12113927757101399, 0.12633999064564705, 0.1851224156894854, 0.17480325512588024, 0.15784882275121553, 0.13224213251045772, 0.09551685210317373, 0.12252693596695151, 0.10710962968213217, 0.09822154697030783, 0.15444914517658098, 0.1887852834271533, 0.15432721243372985, 0.12734705874962465, 7.165048394884382, 39.27286515917097, 56.770298276628765, 52.32316977637154, 42.25656407220023, 23.664629868098668, 37.5197616985866, 38.524950640542166, 25.69337705203465, 1.7054863699844904, 0.692859978548118, 0.4615724150623594, 10.753653134618487, 34.31431450162615, 22.850992338997976, 20.783953632627213, 19.098518678120204, 17.613386392593384, 19.43337494986398, 19.64411207607814, 27.593711103711808, 47.12408638000488, 50.187633991241455, 53.93893166950771, 50.22299337387085, 52.55554533004761, 48.572146551949636, 54.04937328611101, 49.71716799054827, 52.908027444567, 51.03670038495745, 48.876477650233674, 48.777451923915315, 49.41984762464251, 45.89320952551705, 48.97085503169468, 44.28947149004255, 47.46926246370588, 48.773981298719136, 51.2807662827628, 49.70873287745884, 50.9156106540135, 50.13013417380196, 50.24103437151228, 50.83130121231079, 48.74221413476126, 41.8915057182312, 36.43714203153338, 36.764068671635215, 35.37612778799874, 37.050181593213765, 37.16684532165527, 36.37314217431204, 37.11862482343401, 36.79218108313424, 36.50037063871111, 36.816260065351216, 36.714281354631694, 36.81347731181553, 36.24241876602173, 38.792154039655415, 37.44213989802769, 37.45901707240513, 41.088641371045796, 46.63840729849679, 48.91059330531529, 51.96707807268415, 39.23235368728638, 37.92120429447719, 52.11559581756592, 47.170514242989675, 48.65091827937535, 40.90537221091134, 41.33310679027012, 36.76975229808262, 37.92047473362514, 36.33884239196777, 39.12629290989467, 38.55107239314488, 39.03283963884626, 37.840820584978374, 37.804582255227224, 45.24208688735962, 50.954048088618684, 49.37568140029907, 50.74197169712612, 47.902190821511404, 47.99201365879604, 45.69715567997524, 46.16460963657924, 49.85236256463187, 50.64391524451119, 52.47414023535592, 52.011532647269114, 53.00262369428362, 49.78914090565273, 49.24993985039847, 44.36270202909197, 47.70544215611049, 47.01832784925188, 51.25438049861363, 50.02806861060006, 47.18414660862514, 46.175097942352295, 49.110169887542725, 49.40540926797049, 50.78214965547834, 48.151283740997314, 47.02798931939261, 50.21792466299874, 51.40699768066406, 52.12173802512032, 55.38397979736328, 48.81937735421317, 45.28044441768101, 33.461388383592876, 22.298261404037476, 11.057515229497637, 28.263170037950786, 23.403688532965525, 12.427530629294258, 21.257320506232126, 16.54970751489912, 4.970777315752847, 0.23248303362301417, 0.39444209582039286, 0.3595355674624443, 13.68063303402492, 43.801805223737446, 42.24213266372681, 34.76815346309117, 36.93696417127337, 49.84974309376308, 56.43660756519863, 57.35097312927246, 38.68229259763445, 6.97404111283166, 0.17091507304991993, 0.09886743766920907, 0.07820367826414959, 0.1034019650625331, 0.13150125369429588, 0.12505906580814294, 0.134608957650406, 0.10235596261918545, 0.1008392943601523, 0.14698828623763152, 0.13251129378165516, 0.12299193601523127, 0.0918220728635788, 0.10291211706187044, 0.16681910998054914, 0.09470683056861162, 0.10631742647715978, 0.1881387752613851, 0.23815322507705006], [0.028828981798142195, 0.02255945054015943, 0.043482559600046704, 0.04463965179664748, 0.013644022018914776, 0.04170450947380491, 0.033442941893424304, 0.03906761382573417, 0.03843723443735923, 0.06905126545046057, 0.06662447817091431, 0.03573326560269509, 0.035168799106031656, 0.0129563522225778, 0.03869112188528691, 0.08556841593235731, 0.05579315937523331, 0.02542432038379567, 0.021376512944698334, 0.16057263873517513, 3.1466009489127567, 26.252931118011475, 41.816458225250244, 38.65438863209316, 26.47402800832476, 18.57134321757725, 18.88643533842904, 33.72861957550049, 15.440316438674927, 0.7251077081475938, 0.12909740768373013, 0.3082726267831666, 5.164477893284388, 10.041930913925171, 12.922720057623726, 5.006676920822688, 7.590729781559535, 8.641134125845772, 8.54601502418518, 16.421485458101543, 28.827165739876882, 42.308501856667654, 47.737643582480295, 46.11980070386614, 43.76457330158779, 43.14988006864275, 45.528957162584575, 44.074706145695274, 45.26082270486014, 47.20319856916155, 45.339625699179514, 47.069216455732075, 45.77699742998396, 48.730502946036204, 46.87815836497715, 47.37838350023542, 46.852297169821604, 46.548931871141704, 45.1847642489842, 43.8809243610927, 44.411179610661094, 45.93408577782767, 44.96265813282558, 47.10310282026018, 45.31255899156843, 46.12622083936419, 45.40792996542794, 38.08877747399466, 32.7352043560573, 32.61217260360718, 32.760582651410786, 33.80290624073574, 35.462622438158306, 34.360711097717285, 33.88788618360247, 32.650724683489116, 33.47494084494454, 33.35647405896868, 33.73684276853289, 32.343242577144075, 34.66150208881923, 34.357007707868306, 34.80167852129255, 36.18562766483852, 42.13954945972988, 42.45179108210972, 49.6017792565482, 38.51282255990164, 34.5200263432094, 50.70574031557356, 42.100948742457796, 43.67396184376308, 35.085776465279714, 35.4411038671221, 32.62250804901123, 34.82172754832676, 32.69702400479998, 34.35532624380929, 34.529691287449424, 35.55286911555699, 33.772445338112966, 34.43069682802473, 38.88247019904, 47.45811755316598, 48.16157054901123, 47.162666252681184, 47.57621261051723, 45.69805894579206, 46.45714269365583, 45.279179845537456, 47.28112956455776, 47.54929181507656, 45.77513878686087, 46.1816257749285, 46.57684278488159, 48.91198294503348, 47.41687652042934, 46.14120462962559, 48.33123861040388, 47.17509657996041, 50.225432191576274, 44.634300163814, 44.21148143495832, 44.319435596466064, 46.30687747682844, 48.05746916362217, 46.74795607158116, 43.88894953046526, 43.35775279998779, 42.35963365009853, 48.256142480032786, 48.33121429170881, 45.41421808515276, 45.39019816262381, 44.66844708578927, 30.193727016448975, 24.79898234776088, 15.306355169841222, 15.347226211002894, 5.176473958151681, 19.786791597093853, 14.102730018751961, 9.272297195025853, 10.504152008465358, 0.2319304347038269, 0.26399677832211765, 0.06069921861801829, 6.004565043108804, 26.931243794304983, 53.23228597640991, 53.798241070338655, 35.17178474153791, 33.602228369031636, 40.86798742839268, 44.93146766935076, 32.10878256389073, 4.4987536157880506, 0.05183878620820386, 0.029898397092308317, 0.03141307045838662, 0.014350601738052709, 0.07608753110149077, 0.04161979776940175, 0.05208796123042703, 0.03712937854496496, 0.037958449950175624, 0.0502660031031285, 0.028777223146919693, 0.04602220421656966, 0.0412761367458318, 0.04001283007008689, 0.03825995359303696, 0.0028270491498655504, 0.029990691425544874, 0.018397069070488214, 0.04499592339353902, 0.014501438376360705, 0.016293271245168786, 0.0329268549435905, 0.049165629648736546, 0.052430251613259315, 0.049758974595793655, 0.030366206275565282, 0.02139295045552509, 0.05095712494637285, 0.024568662280216813, 0.06581148465297051, 0.029397356656513045, 0.022454136816252555, 0.05698024281965835, 0.039481774637741704, 0.04187388877783503, 0.018075758990432535, 0.03324260103649326, 0.062401188005294116, 0.0526817777593221, 4.772689385073526, 33.147166524614605, 49.65939024516514, 43.93186855316162, 30.647569452013286, 22.131548064095632, 21.223871878215245, 32.96715954371861, 17.277897834777832, 0.8566952443548611, 0.10099689090358359, 0.12726230972579547, 3.060562491416931, 13.78979183946337, 9.03718318258013, 8.365816099303109, 9.45688738141741, 8.809136356626238, 9.624384999275208, 17.18470685822623, 31.794279302869523, 43.63198430197579, 48.931250299726216, 48.181956563677105, 47.11071457181658, 45.63894019808088, 45.81006738117763, 46.623246329171316, 47.429706369127544, 49.040771280016216, 47.90409810202462, 48.35834353310721, 47.79956245422363, 49.545422417776926, 48.08155509403774, 47.658493178231375, 45.55529430934361, 46.78602525166103, 44.83217443738665, 44.369024889809744, 45.46705566133772, 46.218583243233816, 47.202010427202495, 48.451810700552805, 47.964147908346995, 48.63685165132795, 46.860350131988525, 39.82805401938302, 33.92005286897932, 33.55306986400059, 33.53109966005598, 36.08048057556152, 37.54844386237008, 35.04552902494158, 36.26101214545113, 34.67802143096924, 34.610318183898926, 33.80085999625069, 35.10350479398455, 33.95568323135376, 36.817535059792654, 35.880438464028494, 36.718252250126426, 38.269493171146934, 44.96824448449271, 44.964495931352886, 51.994752747671946, 41.16622148241316, 36.37606736591884, 52.25942700249808, 43.62005424499512, 45.319573198046, 37.170757157461985, 35.629785673958914, 34.66955157688686, 35.31322922025408, 34.48262766429356, 36.1608156476702, 35.31255871909005, 36.99765321186611, 36.26696327754429, 36.014580386025564, 40.57267509187971, 48.54520838601248, 49.17342281341553, 49.61508853094918, 48.88137265614101, 47.760002885546, 48.78869063513619, 48.36541332517351, 48.78847871507917, 50.03471803665161, 47.01315491540091, 46.83547905513218, 47.67882708140782, 50.65471274512154, 48.86004168646676, 48.76541069575718, 49.58405787604195, 49.829259804316926, 51.284803186144146, 46.62228747776577, 45.34223127365112, 45.70829711641584, 47.12588248934065, 49.97916024071829, 48.1438387462071, 46.38420397894723, 45.16116469247, 43.333375045231406, 50.81686980383736, 50.158854552677695, 47.92420618874686, 46.81861925125122, 44.52088124411446, 32.45883280890328, 25.482219559805735, 14.89348452431815, 6.667768427303859, 7.849670035498483, 10.01532713004521, 11.701195478439331, 15.050515549523489, 7.805134688104902, 0.11186888108828238, 0.12584031745791435, 0.02916587104222604, 6.661541538579123, 28.680857522147043, 43.64675269808088, 42.749180930001394, 35.84235538755144, 38.9683256149292, 46.12820107596261, 50.87846558434622, 39.560114111219136, 6.486594149044581, 0.10555910931101867, 0.06415224940116916, 0.03590503674266594, 0.02893132184232984, 0.024981276032381823, 0.024918464045705538, 0.042780503164976835, 0.033490951638668776, 0.019106273871979544, 0.07020563672163657, 0.007729344219634575, 0.0220143341658903, 0.014455370937607117, 0.0045636755613876236, 0.04072583466768265, 0.045597020603184185, 0.05877573468855449, 0.010471897948134159, 0.037720548787287304, 0.1453526775751795, 0.10021685383149556, 0.1472569861050163, 0.13020290407751287, 0.07081331911363772, 0.1744436179952962, 0.09899497511131422, 0.1112547797550048, 0.19141867783452782, 0.0945480465888977, 0.13984016408877714, 0.08876696894211428, 0.14178508972483023, 0.23697973947439874, 0.1113669890910387, 0.2738778223948819, 0.1510594149253198, 0.06822345951305968, 0.11898399250847952, 0.2031012052404029, 6.8767728464944025, 41.28868695667812, 57.57646301814488, 50.4964188848223, 36.727969305855886, 26.29781995500837, 26.440245866775513, 43.87758922576904, 21.028795991625103, 1.199087217450142, 0.4489477824951921, 0.6523617516670908, 8.821433799607412, 11.778112036841256, 23.503129414149694, 12.854899559702192, 14.043634721211024, 13.001131347247533, 13.194944398743765, 19.614563124520437, 33.813234737941194, 46.128353936331614, 51.86938292639596, 50.155408246176584, 49.68628672191075, 48.03306014197213, 48.587873799460276, 49.6575802394322, 48.354987553187776, 50.60307025909424, 49.90928568158831, 50.728162152426584, 48.84580135345459, 51.636514050619944, 49.68012366976057, 49.66218342099871, 46.41997677939278, 48.46551602227347, 44.271044867379324, 44.974897384643555, 45.15767322267805, 47.42149359839303, 47.131910051618306, 50.52256495612008, 48.624935490744456, 50.469466822487966, 48.487996918814524, 41.83888006210327, 36.17706748417446, 35.10270922524588, 35.95196322032383, 36.68762806483677, 38.63796656472342, 37.51538780757359, 38.18903997966221, 36.86564091273716, 36.65708378383091, 36.99925824574062, 36.9465457371303, 36.81962299346924, 38.49665757587978, 37.794712339128765, 39.173679624285015, 40.94662366594587, 45.697510038103374, 47.14789090837751, 53.22604649407523, 42.620295320238384, 40.11993047169277, 54.055206298828125, 45.424320765904014, 47.49564824785505, 38.671835558755056, 37.62757689612252, 36.671192101069856, 37.7205160004752, 36.48310089111328, 37.537740162440706, 37.209542001996724, 38.09158802032471, 37.659618513924734, 38.11969348362514, 43.64675964627947, 50.97611209324428, 51.90434626170567, 49.707697595868794, 51.8447585105896, 50.187230995723176, 51.26620980671474, 50.3265632220677, 50.42012071609497, 50.198139667510986, 46.89930520738874, 47.68920074190412, 49.26972484588623, 50.88452788761684, 51.71879114423479, 51.5920421055385, 53.077917848314556, 53.35566166469029, 54.150587694985525, 46.38680260522025, 46.50553342274257, 47.088928495134624, 48.28721482413155, 51.48257671083723, 50.58587694168091, 47.1938601902553, 48.104411193302695, 45.6470730645316, 53.62337228230068, 51.08263145174299, 48.13544879640852, 48.039858954293386, 47.035437788282124, 36.29881729398455, 30.80897957938058, 20.16372094835554, 22.522535358156475, 13.293384739330836, 32.00919055938721, 26.41692076410566, 14.498999680791583, 16.421909298215592, 0.4252265782228538, 0.5258043312600681, 0.1345075573772192, 8.351237041609627, 35.0570387159075, 66.30515834263393, 62.74124663216727, 45.49237142290388, 43.5167692729405, 53.767269475119456, 56.97391523633684, 46.61535317557198, 7.881518840789795, 0.2397593988903931, 0.19761079842490809, 0.12653360382786819, 0.15647609212568828, 0.11948112797524248, 0.17797164725405829, 0.13448473145919188, 0.11148067084806305, 0.09963328657405716, 0.14248418435454369, 0.11505580400781971, 0.1605015146945204, 0.103858564847282, 0.12886978632637433, 0.19584868369357927, 0.0944955822612558, 0.1594190749206713, 0.0923672214682613, 0.13892940724534647], [0.059048431127199104, 0.03681417188740202, 0.02338124974630773, 0.03209910328899111, 0.0303259352222085, 0.04400048537978104, 0.06491362676024437, 0.05005231885505574, 0.03011773692976151, 0.01186041469087026, 0.0324812033213675, 0.06092047531689916, 0.048986109638852735, 0.018383634077118974, 0.007537253500361527, 0.030473665866468633, 0.06642743838684899, 0.030916891725999967, 0.037954036079879315, 0.06045860331505537, 5.407551501478467, 34.61161749703543, 42.184111731392996, 40.18072720936367, 21.287305457251414, 12.393328990255084, 32.88978440420968, 38.84516184670584, 14.200491172926766, 0.3719171759273325, 0.15556480602494308, 0.8462887427636555, 6.31429272038596, 12.590399878365652, 5.07181715113776, 6.978902680533273, 7.879476070404053, 7.897319912910461, 12.948666368212018, 21.13784796851022, 34.774240085056846, 44.80559062957764, 47.87536382675171, 43.99195657457624, 43.62143693651472, 38.76185989379883, 39.56956366130284, 40.683359895433696, 40.9622814314706, 41.531554290226524, 42.028256688799175, 44.05898584638323, 45.09884282520839, 44.87198761531285, 45.90548351832798, 45.105641637529644, 46.96894005366734, 47.61255168914795, 48.9951285634722, 46.68675633839199, 46.99158770697457, 47.037650789533345, 46.11824083328247, 45.17275081362043, 45.944303103855674, 46.00201484135219, 47.228232928684776, 40.44683279309954, 36.00297689437866, 32.17934499468122, 32.18162052971976, 32.68361050742013, 33.08189167295183, 33.51414605549404, 33.50458880833217, 32.88533408301217, 33.02849129268101, 33.193378993443076, 32.50958592551095, 33.18646900994437, 34.01713309969221, 32.479031222207205, 35.22812768391201, 36.923429080418174, 41.446094921657014, 42.37669147763933, 49.68635272979736, 40.02839142935616, 31.055348805018834, 51.1750876562936, 41.89998252051217, 43.36118173599243, 39.831740038735525, 42.2160074370248, 41.66133969170706, 42.89372430528913, 41.1960118838719, 36.93363945824759, 33.110764912196565, 34.52431685583932, 34.17438473020281, 32.68977008547102, 37.869704246520996, 47.80983883993966, 46.976704665592735, 48.291745049612864, 47.95717191696167, 48.50745187486921, 48.154094287327354, 47.896201474326, 46.00845234734671, 43.827829701559885, 44.01238775253296, 46.47514200210571, 45.89392171587263, 46.22488873345511, 48.84006214141846, 48.563930307115825, 45.41805001667568, 48.17874302182879, 43.71404252733503, 45.95824466432844, 49.105264459337505, 50.47482735770089, 48.917836802346365, 45.79921082087925, 43.832887990134104, 40.562405654362266, 39.910442284175325, 45.814621925354004, 46.460564681461875, 50.15033606120518, 46.486050673893516, 37.72984395708357, 45.83385106495449, 32.489905153002056, 23.725763593401226, 15.05125379562378, 4.315348531518664, 3.8570188624518256, 2.8101359520639693, 8.068080578531537, 3.738129104886736, 14.476867062704903, 1.8897280607904707, 0.11637632814901215, 0.18604062284742082, 3.6361467029367174, 29.936344896044048, 69.33015387398856, 60.80910546439034, 31.131983961377824, 40.03771938596453, 40.64045476913452, 51.763006005968364, 35.59034422465733, 6.069860305104937, 0.18882328138819762, 0.040048073178955486, 0.03591955399938992, 0.0286804267338344, 0.02800026492747877, 0.04213438515684434, 0.013425914570689201, 0.011430329510143824, 0.011661866862725998, 0.05576254387519189, 0.073630671149918, 0.020186572867844785, 0.052911502575235705, 0.03183540083201868, 0.02091667315523539, 0.04773802250357611, 0.026497189421206713, 0.02130370444085981, 0.024673367018944452, 0.024648298542680483, 0.028901853066469942, 0.03246697783470154, 0.02976428803854755, 0.04932676814496517, 0.025464274222031236, 0.09451340059084551, 0.05592578582997833, 0.03273741814440914, 0.03343493178752916, 0.04774297920188733, 0.07660181993352515, 0.038989019114524126, 0.02835012606478163, 0.022853829565324953, 0.07525355049542018, 0.03713128862104245, 0.00931689394305327, 0.03475765098950692, 0.017855313140898943, 7.013249363218035, 39.87739665167672, 49.63855259759085, 45.826003074645996, 24.964111498423986, 14.61538461276463, 29.896212100982666, 40.58822863442557, 15.430814777101789, 0.49525245066199985, 0.014419598571423973, 0.5717878895146506, 8.939426371029445, 7.141309874398368, 4.333706106458392, 7.711084740502494, 7.495212027004786, 8.030917269842965, 9.062131558145795, 22.779936586107524, 36.73663023539952, 47.040735789707725, 49.57154764447893, 46.69496216092791, 46.00284515108381, 41.81330721718924, 41.861871651240754, 42.848422050476074, 42.80372428894043, 44.31127493722098, 44.02739238739014, 47.47459520612444, 47.13912575585501, 46.83527060917446, 47.357660497937886, 47.160230909075054, 48.171110425676616, 48.997807094029014, 48.55354969842093, 47.735927377428325, 46.980348995753694, 46.78540686198643, 45.442775181361604, 46.635850361415315, 46.41461624417986, 47.44518000738961, 50.210236481257844, 42.37517329624721, 36.676927839006694, 34.02515132086617, 33.59368903296334, 34.663989543914795, 35.567564555576865, 35.22929845537458, 35.77008369990757, 34.464468547276084, 34.84234980174473, 34.492744241442, 34.63936512810843, 34.61086709158761, 34.3955910546439, 34.798294748578755, 36.79060731615339, 38.085445812770296, 44.81557866505214, 44.83515868868147, 50.91397435324532, 41.02757017953055, 32.90930536815098, 52.21979795183454, 45.93042060307094, 45.538406712668284, 40.559824398585725, 42.980788707733154, 43.73631150381905, 44.73989193780081, 41.62873526981899, 38.96959366117205, 35.06531402042934, 36.74826499394008, 35.18390934807913, 35.362891469682964, 38.58619206292288, 49.64840166909354, 48.87154790333339, 48.45932865142822, 47.54694332395281, 49.99324771336147, 48.75192771639143, 50.14142152241298, 47.282873562404085, 44.37889133180891, 44.28686244147164, 46.784732886723106, 45.76445593152727, 48.76461860111782, 49.028921127319336, 49.795877184186665, 48.519889150347026, 49.05261101041521, 45.297151361192974, 46.85285302570888, 48.5202191897801, 50.92789854322161, 50.48480497087751, 49.15122331891741, 45.22261456080845, 44.05099194390433, 42.30335324151175, 47.16529614584786, 49.1591477394104, 49.79737799508231, 46.786226749420166, 39.80308566774641, 46.98504945210048, 35.40976749147688, 27.36173333440508, 19.605665956224712, 9.811418345996312, 8.87970313004085, 11.4095196553639, 6.186207456248147, 7.031298611845289, 16.041446787970408, 1.509998368365424, 0.02433463555228497, 0.1266512753708022, 4.353937523705619, 30.871666227068218, 67.20866734640938, 68.24607508523124, 40.55273723602295, 45.65878077915737, 46.59945222309658, 56.577888761247905, 42.44953639166695, 7.826442207608904, 0.1550177303808076, 0.027540226666522876, 0.028041550390688435, 0.046272967010736465, 0.04446856936972056, 0.045809914357960224, 0.0705677844317896, 0.014727890957146883, 0.02434591280429491, 0.02961317150454436, 0.030611995408045392, 0.027509343145149093, 0.09632602546896253, 0.0416566727549902, 0.045159450333033285, 0.07300076673605613, 0.020214525117938007, 0.07750454292233501, 0.027419070846268108, 0.15195915236004762, 0.16470488985734327, 0.13464930334261485, 0.1503929714007037, 0.13126565276512078, 0.09007128966706139, 0.1680863012692758, 0.13244949281215668, 0.0936671317155872, 0.18080336387668336, 0.15919496837471211, 0.1463216391525098, 0.15482593567243644, 0.15389932825097016, 0.08235440589487553, 0.2361486969249589, 0.25287208812577383, 0.08191372454166412, 0.1569092824522938, 0.1667444168456963, 9.820351992334638, 47.193724700382774, 56.804848194122314, 52.681724616459434, 29.26869944163731, 20.184688874653407, 43.6774012020656, 48.1437657901219, 17.68783286639622, 0.7724312916398048, 0.32059799826570917, 2.006602623632976, 12.845843451363699, 20.190096310206822, 13.695859142712184, 17.59997636931283, 16.661978244781494, 12.630408474377223, 16.154999460492814, 26.236375297818864, 39.43227073124477, 48.93134757450649, 50.58853810174124, 48.74932909011841, 48.21213606425694, 43.03168078831264, 44.70190266200474, 44.17259236744472, 44.934997354234966, 46.7359356880188, 45.85196154458182, 48.70456879479544, 49.00300782067435, 49.551269326891216, 49.447963510240825, 50.787194047655376, 50.00130067552839, 51.61952917916434, 50.43973895481655, 49.443752901894705, 48.319965158190044, 48.217090129852295, 45.53749997275216, 45.79713678359985, 46.104240213121685, 48.22601161684309, 51.7018757547651, 45.61839784894671, 38.88711854389736, 35.71860102244786, 34.748000213078086, 35.63804360798427, 35.85703693117414, 37.01046221596854, 36.884446212223594, 36.370408058166504, 36.28008842468262, 37.75567735944475, 36.46497304098946, 37.67615522657122, 36.04267542702811, 36.11049331937517, 39.11342484610421, 41.48685652869088, 45.95453085218157, 47.309335776737754, 53.83700507027762, 43.05809089115688, 36.307165554591585, 53.9820556640625, 46.49810579844883, 48.1293934413365, 43.413355759211946, 46.07385574068342, 46.35241249629429, 46.49392645699637, 44.17226232801165, 41.36382130214146, 36.73269408089774, 38.79530504771641, 36.76049729755947, 36.35476418903896, 40.58400065558297, 53.07309579849243, 49.63134731565203, 49.85847003119332, 49.319626808166504, 52.2624876839774, 51.20591681344168, 51.92257833480835, 48.70530182974679, 44.291660172598704, 43.520451818193706, 47.652121680123464, 45.589239733559744, 49.03747435978481, 50.03640644890921, 51.26472636631557, 49.398596559252056, 49.947785649980815, 46.37664086478097, 48.147184303828645, 49.0071246283395, 52.9226256098066, 52.31334849766323, 51.18710456575666, 48.03151069368635, 44.279389653887065, 45.330263001578196, 50.125367709568565, 51.30930600847517, 53.56029653549194, 48.161726883479524, 42.80215399605887, 50.7145471572876, 40.74987847464425, 35.00205414635794, 23.432440178734915, 10.24492427280971, 10.939579112189156, 10.50375509262085, 16.2889016696385, 8.295345732143947, 20.25722806794303, 2.702986913067954, 0.15211877093783446, 0.32919737111244884, 5.2557368363652905, 37.2029516356332, 75.57476397923061, 64.54262270246232, 41.70495006016323, 51.53573390415737, 53.677821840558735, 63.63026169368199, 50.11394487108503, 10.688511167253766, 0.29440320815358845, 0.13363245076366834, 0.13010851985641889, 0.14998696318694524, 0.11679558136633464, 0.15308619902602263, 0.13690327453826154, 0.14372411210622105, 0.14834802970290184, 0.17724918387830257, 0.16174377660666192, 0.10427703774933304, 0.16456258749323233, 0.11282169353216887, 0.11795351494635854, 0.19613859456564697, 0.19429433638496058, 0.14542967772909574, 0.22375697828829288], [0.013499676416228925, 0.05377584762339081, 0.048939022701233625, 0.041725428708429844, 0.07774593854056937, 0.07948184146412782, 0.032316203960882764, 0.02063508960418403, 0.030685589316168, 0.05587618492011513, 0.038638325075485876, 0.10498481084193502, 0.029980571075741733, 0.009505514803874706, 0.05023124175412314, 0.0480225797343467, 0.020049619056018333, 0.08504612717245306, 0.013826508923167629, 0.07018466998956033, 8.376751695360456, 34.88953501837594, 42.474414416721885, 39.271385192871094, 26.880308287484304, 21.17492355619158, 29.06858437401908, 32.15025636128017, 9.981003029005867, 0.18746345649872506, 0.794580303132534, 7.662475143160139, 19.503855739321025, 32.10091025488717, 10.421203545161656, 3.311235691819872, 7.342787657465253, 6.382473656109401, 8.601593664714269, 26.10979996408735, 38.50674636023385, 45.956094196864534, 44.99582883289882, 44.60589940207345, 41.11602769579206, 38.225007329668315, 36.969686712537495, 37.69317136492048, 35.90523658479963, 35.91722917556763, 36.892964703696116, 39.64763362067086, 41.532593045915874, 40.95473221370152, 42.199640955243794, 42.72680425643921, 43.214977741241455, 43.21553707122803, 46.4412556375776, 45.83780458995274, 46.206482955387656, 47.31595393589565, 46.71862077713013, 45.69769763946533, 47.27332673754011, 45.82293891906738, 46.1687125478472, 42.648595333099365, 32.68318319320679, 32.43379150118147, 33.450281688145225, 32.71225445611136, 35.519552503313335, 35.296477113451274, 35.85086693082537, 33.75883034297398, 32.127278668539866, 31.956676074436732, 32.51179197856358, 32.693435260227744, 33.553691727774485, 32.09486879621233, 35.90061255863735, 34.62515606198992, 43.55548463548933, 41.39085674285889, 48.075152329036165, 40.14420747756958, 30.74368040902274, 49.32668270383562, 43.27194602148873, 45.6669032233102, 42.55009419577462, 47.08378335407802, 44.99080181121826, 48.84589515413557, 46.12749930790493, 42.77010543005807, 35.393866539001465, 35.92713730675833, 33.57555423464094, 33.550801277160645, 34.15606233051845, 43.61863333838326, 46.86151742935181, 45.25046294076102, 45.45800563267299, 45.42765242712838, 44.68801668712071, 46.282037666865754, 44.821408203669954, 47.02337918962751, 47.668356146131245, 48.73155559812273, 47.647146769932334, 46.65790741784232, 44.184779507773264, 46.99974489212036, 46.39017595563616, 44.96131018229893, 45.854626178741455, 48.34279693875994, 47.753867626190186, 49.437364033290315, 46.04479142597744, 44.211206981113975, 40.07631662913731, 41.86028746196202, 37.382416657039094, 40.80922303880964, 45.81515346254621, 48.71790933609009, 47.46435703550066, 45.66936635971069, 42.903851304735454, 37.87781279427664, 26.78748209135873, 21.37238962309701, 8.533643756593976, 10.974201117243085, 8.7176832982472, 5.519063574927194, 8.17424123627799, 19.12114896093096, 7.4180062498365125, 0.022565891533823948, 0.18876393671546662, 1.90888945545469, 24.083121606281825, 40.7667487008231, 19.00500634738377, 12.825512153761727, 30.948235375540598, 37.65565456662859, 48.070806230817524, 34.282960755484446, 6.007438123226166, 0.21308658085763454, 0.08120949340185948, 0.04319946800491639, 0.0366383736420955, 0.026301801869911805, 0.03522353991866112, 0.015177886899826782, 0.06650256578411375, 0.04382783214428595, 0.039953617711684535, 0.0400713096106691, 0.07139888126403093, 0.02426031052267977, 0.05003892796646271, 0.014664056078929986, 0.03925523215106555, 0.04801951954141259, 0.010776449061397995, 0.019042449171787927, 0.027111499404002513, 0.04500896483659744, 0.012989072877514576, 0.02280414553492197, 0.025264611900118843, 0.03067310427182487, 0.033643866290471384, 0.008275665841730577, 0.019276535271533897, 0.01845889039603727, 0.0734374447326575, 0.08494960556605033, 0.02137045023430671, 0.08483401034027338, 0.03089728206396103, 0.07103435189596244, 0.023308573556797843, 0.0437696206250361, 0.028970534381057535, 0.10690359930906977, 10.381055116653442, 41.71473659787859, 47.550712721688406, 45.913390568324495, 30.73509243556431, 25.07439156941005, 33.12936871392386, 35.546702589307515, 11.686718906675067, 0.14870069149349416, 0.9639082827738353, 10.254903623035975, 25.118827036448888, 32.25116852351597, 10.212800145149231, 4.345739083630698, 13.086483018738882, 6.813522526196071, 10.117113896778651, 28.35852885246277, 39.60310609000069, 49.25146150588989, 48.099540506090435, 46.47213690621512, 42.51634679521833, 40.36044584001814, 38.18810197285244, 39.75872836794172, 38.689730644226074, 38.76793261936733, 40.75308854239327, 42.86665759767805, 43.1250194140843, 43.14266436440604, 44.229241030556814, 45.4298689024789, 44.8631842476981, 46.97558947971889, 49.386815888541086, 48.407905033656526, 47.6435614994594, 49.73132494517735, 48.390284402029856, 47.56078066144671, 47.297152110508506, 47.09012705939156, 47.61933313097273, 44.48162392207554, 35.69485207966396, 33.981634753090994, 34.822217396327424, 33.47895690373012, 36.46728679112026, 37.77733489445278, 37.83662734712873, 36.12941326413836, 35.16330099105835, 33.61679874147688, 34.5781306539263, 33.969141892024446, 36.248536654881065, 33.92141124180385, 36.96575403213501, 36.26437854766846, 43.772483825683594, 44.679258482796804, 48.81606306348528, 42.21834550585066, 32.72845418112618, 50.91858100891113, 45.56731121880667, 46.579528263636995, 44.98046636581421, 48.47906500952584, 47.51117747170584, 50.38722446986607, 47.05725165775844, 45.69670752116612, 37.49098226002285, 36.68321248463222, 34.807271821158274, 34.603036471775596, 36.14391415459769, 45.31806196485247, 47.896462031773154, 46.95815644945417, 46.77232687813895, 47.42460639136178, 45.12276547295706, 46.217193603515625, 44.21286065237862, 47.456314495631624, 48.63199486051287, 50.03623274394444, 48.749454157693044, 46.821957860674175, 45.69694723401751, 48.882849148341585, 45.768531050000874, 45.96590505327497, 45.92625863211495, 48.54264450073242, 49.67959213256836, 51.38407557351248, 48.141789027622764, 45.15944848741804, 42.39213384900774, 42.51966108594622, 39.211522987910676, 43.56577491760254, 48.860177176339285, 50.87676674979073, 49.76357153483799, 46.42744609287807, 45.378462655203684, 40.29905503136771, 30.67911774771554, 19.137284415108816, 11.729395610945565, 16.21729006086077, 10.200016328266688, 9.796952196529933, 7.961842622075762, 19.427573204040527, 5.817412274224417, 0.01572503718281431, 0.14413044601678848, 2.32759159377643, 27.393309422901698, 55.9922320502145, 29.972027369907924, 18.345868962151663, 35.13562979016985, 43.116612093789236, 54.14090885434832, 40.43326990944998, 8.695850321224757, 0.2969596024070467, 0.0656697658289756, 0.04884674193869744, 0.03951629510681544, 0.008416331240109034, 0.06890961447996752, 0.018007946200668812, 0.05871291591652802, 0.009323169543806995, 0.04678266555336969, 0.005673234259510147, 0.023861525314194814, 0.04566485374899847, 0.027915471798873374, 0.004246260272338986, 0.025577233339260732, 0.01751616776787809, 0.04269446153193712, 0.032799409103712866, 0.09801354884569134, 0.11589276338262217, 0.09502989466169051, 0.17969041716839584, 0.22005793106343063, 0.1747280191630125, 0.1535769019808088, 0.11367318712707077, 0.14786287716456822, 0.20476581448955194, 0.115506486967206, 0.21155894068734987, 0.1482959860669715, 0.17488594140325273, 0.14002752117812634, 0.11239393148571253, 0.06962739596409456, 0.23575121111103467, 0.12533525670213358, 0.20613750017115048, 14.158989582742963, 49.07128082002912, 54.92712184361049, 50.661240577697754, 35.386070660182405, 30.290907996041433, 37.916993686131065, 41.892245701381135, 14.074066093989781, 0.4470421304660184, 1.1032080480030604, 9.528109891074044, 23.543041603905813, 38.20233883176531, 19.569981745311193, 9.759368521826607, 15.024395533970424, 11.467071584292821, 12.028761352811541, 30.7521641595023, 42.359175068991526, 49.9027613231114, 50.416497230529785, 47.645288126809255, 45.76295164653233, 42.852785519191194, 40.17542225973946, 42.45825638089861, 40.908995696476524, 40.58900335856846, 40.67496647153582, 44.45471702303205, 45.154067107609336, 43.86635051454817, 47.20342785971505, 47.62439489364624, 48.56799152919224, 49.30767590659005, 51.50277859824044, 51.37748868124825, 48.96991702488491, 51.74890463692801, 50.65845087596348, 50.70743220193045, 49.89511830466134, 48.13168634687151, 49.59081499917166, 46.27027784075056, 36.770756312779014, 35.58310420172555, 35.98967456817627, 35.62309455871582, 38.69872856140137, 39.50188473292759, 39.75453860419137, 37.057306970868794, 35.40692915235247, 35.510009152548655, 37.83979572568621, 36.63989741461617, 38.7487347466605, 35.58164855412075, 39.48796054295131, 38.49513939448765, 46.09671878814697, 46.21434136799404, 50.10991491590227, 43.648983069828574, 35.3557139805385, 50.81211723600115, 47.9454676764352, 48.95464835848127, 46.863084248134065, 51.14512702396938, 50.24942432131086, 52.73383957999093, 49.95682178224836, 47.57309981754848, 39.046878474099294, 39.33640990938459, 36.73154067993164, 37.59175893238613, 36.859005383082796, 47.167939935411724, 49.182354722704204, 46.98335061754499, 49.07113490785871, 47.34828390393938, 44.72266040529524, 46.721827370779856, 45.30141755512783, 48.07437413079398, 50.28346354620797, 53.154733657836914, 50.955079896109446, 47.82895680836269, 46.19313199179513, 49.26068523951939, 46.59670421055385, 46.391433579581125, 46.42210292816162, 46.946744033268516, 49.71131065913609, 53.4720196723938, 49.99644388471331, 47.55150134222848, 44.007391997746055, 45.88814776284354, 41.91152695247105, 46.88786152430943, 50.729857512882774, 54.46602201461792, 51.19288199288504, 50.35894530160086, 46.44712339128767, 44.688152176993235, 32.560116699763704, 24.931394168308803, 10.56707489490509, 16.493284668241227, 16.215877839497157, 15.055577312197004, 15.419296400887625, 22.574186529432023, 9.800917012350899, 0.09184969602418797, 0.2966060313795294, 3.278198093175888, 29.361760139465332, 50.638259410858154, 29.196118559156144, 23.67569661140442, 41.17303419113159, 50.11531366620745, 60.13556793757847, 48.112745557512554, 11.286097935267858, 0.5104764423200062, 0.14770937897264957, 0.16726836801639625, 0.17380715214780398, 0.16605716943740845, 0.1695548953222377, 0.12359891273081303, 0.10245962241398436, 0.09847003327948706, 0.14165538097066538, 0.13774240522512368, 0.12907274972115243, 0.10702641414744513, 0.1082279910998685, 0.12774310606930936, 0.08482687893722739, 0.14857684528189047, 0.1461312286555767, 0.08496059104800224], [0.047460450790822506, 0.007692237683971013, 0.023727818292432597, 0.019092450417312126, 0.01834369041690869, 0.04079514362716249, 0.042154585144349506, 0.06688378711364099, 0.03695298318884202, 0.004786038272348898, 0.034621279021458964, 0.052914043688880544, 0.024585337278300097, 0.08868857100605965, 0.10688188618847302, 0.04956919852910297, 0.03809386518384729, 0.020620801353028843, 0.019733811894963895, 0.039220823640269895, 6.19150676046099, 35.15574482509068, 42.82884202684675, 36.03221838814871, 20.976284980773926, 20.909278290612356, 39.4215600831168, 36.6550931249346, 8.989474245480128, 0.0663987227848598, 0.34705961548856323, 1.1335421460015433, 2.1269287041255405, 4.300386020115443, 4.835242714200701, 5.55451979807445, 5.9146753294127326, 4.352834497179304, 13.559791701180593, 30.696356228419713, 40.078613008771626, 47.8708370753697, 46.433921813964844, 44.277374676295686, 42.93296078273228, 41.599608421325684, 37.69024964741298, 38.17887476512364, 36.74034057344709, 35.023350375039236, 34.06203930718558, 35.65022727421352, 35.92335748672485, 37.335297448294504, 35.76457725252424, 35.58142968586513, 36.66065515790667, 37.5448968069894, 39.86239896501814, 40.695467131478445, 40.593415464673726, 43.03959478650774, 41.50416449138096, 42.91453416006905, 43.20613268443516, 45.381919384002686, 42.46027830668858, 37.82907465526036, 31.894701617104666, 34.83628055027553, 33.24743250438145, 37.8249682698931, 40.79667806625366, 40.68038259233747, 38.710474491119385, 36.936679295131135, 34.55566365378243, 33.1776065826416, 32.83526536396572, 31.249217442103795, 32.288918086460654, 33.1233446257455, 32.936372075762065, 36.96949911117554, 42.824565410614014, 42.140643801007954, 47.42123998914446, 38.75401537758963, 27.2576128414699, 49.15264769962856, 45.01993213381086, 48.62250362123762, 46.722942556653706, 47.87602390561785, 42.82177570887974, 42.86824526105608, 46.12457759039742, 44.14568894250052, 37.234385286058696, 35.27995082310268, 34.07074540002005, 35.052049909319194, 33.6559032031468, 37.27591119493757, 47.013992173331125, 47.701043946402415, 49.72345263617379, 47.43484803608486, 46.236085755484446, 47.81981645311628, 47.1737243107387, 44.98966925484793, 46.15567077909197, 42.86421877997262, 44.401483399527415, 46.50144440787179, 46.80017178399222, 46.628735406058176, 46.29985979625157, 48.599227155957905, 46.02957834516253, 44.378193037850515, 46.8578314099993, 47.69260883331299, 46.16377932684762, 41.56828941617693, 38.43420021874564, 35.26999405452183, 36.66317735399519, 38.38336719785418, 38.60319777897426, 43.90839753832136, 47.31648547308785, 51.339436871664866, 48.801120962415425, 44.1237986428397, 33.19703722000122, 20.632434265954153, 18.382168088640483, 20.5080406665802, 15.731220143181936, 5.246105764593397, 3.806652673653194, 7.5182817833764215, 10.952791111809866, 0.045134907721408775, 0.037899315623300414, 1.6797719555241721, 15.84713694027492, 26.002636160169327, 23.22639134952, 29.381614616939, 35.17037078312465, 41.87280811582293, 48.88151509421212, 35.451946531023296, 4.866331994533539, 0.10978215520403214, 0.024592970797259892, 0.03184858476743102, 0.030980114226362536, 0.020941266656986306, 0.02801798147681568, 0.06333575464252915, 0.06734939105808735, 0.011934436924223388, 0.02490380090395255, 0.0330449336075357, 0.005246150748072458, 0.07954865680741412, 0.03594504316736545, 0.024431703379377723, 0.03128830483183265, 0.09763129614293575, 0.10060171210872275, 0.010225991768363332, 0.05028085623468671, 0.042782260570675135, 0.040645255241543055, 0.017017120528700094, 0.017313609797773615, 0.027236816340259144, 0.03568911332903164, 0.06993617010968071, 0.029491116625389883, 0.008101679284923842, 0.0055835175111756796, 0.047691749807979376, 0.007987050123379698, 0.019695043796673417, 0.15583741425403527, 0.029711263919515268, 0.05941692992512669, 0.010634895630313881, 0.03729074095774974, 0.034661933447101285, 8.862711310386658, 41.9558356148856, 49.74718073436192, 42.203080313546316, 24.32389579500471, 23.317695890154155, 36.123298849378315, 39.364272185734336, 9.777063846588135, 0.21029463995780262, 0.15196235504533562, 1.4082857519388199, 3.189736451421465, 7.837795564106532, 5.377473618303027, 5.9251545156751355, 6.540709325245448, 6.630576891558511, 13.85471407004765, 31.03449031284877, 41.645390101841514, 49.664410318647114, 48.35452549798148, 46.13453088487898, 45.35435240609305, 42.77644566127232, 39.94213996614729, 39.734034470149446, 38.61639240809849, 38.07907084056309, 35.43756723403931, 37.02684954234532, 38.05730560847691, 39.81539787564959, 38.09768853868757, 38.67153331211635, 39.0755432673863, 39.71490607942854, 42.39466299329485, 43.33989245550973, 43.64753784452166, 44.255713667188374, 44.93175254549299, 44.63945920126778, 45.74795743397304, 46.581741264888215, 45.8726532799857, 39.5705155645098, 33.28114863804409, 36.491935525621685, 34.8988664490836, 39.54124975204468, 42.02267033713204, 41.364022799900596, 39.83640922818865, 37.29491799218314, 36.940872532980784, 35.55632584435599, 34.45785733631679, 32.360592229025706, 34.14907591683524, 35.16557305199759, 34.96615627833775, 38.718586512974326, 45.47673102787563, 43.36664302008492, 50.04714141573225, 40.391459124428884, 30.954610347747803, 49.178925786699565, 47.966694423130576, 49.660078116825645, 48.68675013950893, 48.632067816598074, 45.014008794512065, 43.878447328295024, 47.40854563031878, 45.82480451038906, 39.80996091025216, 36.0958708354405, 35.013661112104145, 37.14326660973685, 35.481386048453196, 40.18240172522408, 48.89119740894863, 48.68285914829799, 50.03876536233084, 47.64610801424299, 48.436621938432964, 48.79164014543806, 49.8289019720895, 46.48699562890189, 47.75294004167829, 45.12661130087716, 46.10432011740548, 47.361217975616455, 48.02599034990583, 47.2283684185573, 47.54198578425816, 47.64273118972778, 46.37484128134591, 43.95781660079956, 47.08860540390015, 48.54632357188633, 47.34333678654262, 44.17689677647182, 40.24644674573626, 38.77262960161482, 38.55413654872349, 39.65963315963745, 42.062358447483604, 46.16553027289254, 49.72906330653599, 53.64836147853306, 50.51972314289638, 44.75110633032662, 36.1621983391898, 20.576018367494854, 12.62189953667777, 13.960978950772967, 10.693654571260724, 9.427557298115321, 8.72545051574707, 11.685506446020943, 10.361475093024117, 0.08323530041213546, 0.11132768834275858, 1.873713765825544, 20.6400842326028, 32.224494389125276, 24.62927086012704, 31.884327956608363, 38.45844595772879, 48.09537853513445, 53.34705632073538, 42.5190600667681, 7.391459788594927, 0.1788513543350356, 0.06814324310315506, 0.036865051835775375, 0.018626471582267965, 0.029156140850058625, 0.018966833229309747, 0.07202893495559692, 0.04913279873185924, 0.00904220515596015, 0.018077404437852756, 0.022931942516671758, 0.0712722327028002, 0.03199348592066339, 0.05183927814609238, 0.0019457095560418175, 0.04752768004047019, 0.022860022893707668, 0.0691200824720519, 0.013434815253796322, 0.08198827518416302, 0.13644230498799256, 0.08942922590566532, 0.11378779169172049, 0.12894443874912603, 0.17247824131378106, 0.11542243004909583, 0.12479143802608762, 0.10166065421487604, 0.130981088749, 0.09903084925775017, 0.12113703840545245, 0.06757787415491683, 0.1668415016361645, 0.2241859074149813, 0.12436606442289692, 0.16150719858705997, 0.06988144626042672, 0.11335430959505693, 0.1929237906421934, 12.170455966676984, 49.47437361308506, 56.42163419723511, 48.71658223015921, 29.447702407836914, 30.49520935331072, 47.912335191454204, 44.96337032318115, 11.737359115055629, 0.25023052415677477, 0.6521339267492294, 2.158192123685564, 3.6674120766775946, 6.124862679413386, 6.446287649018424, 10.558843885149274, 12.934790815625872, 9.17564080442701, 16.515923636300222, 33.69733531134469, 42.366661752973286, 51.26019614083426, 50.321980885096956, 48.288489818573, 47.279924052102224, 45.478930132729666, 42.605308055877686, 41.920132296425955, 40.88425316129412, 39.450554915836875, 37.59323195048741, 39.37145662307739, 40.43343666621617, 41.55125938143049, 39.45629412787301, 40.32590981892177, 41.05495650427682, 42.68120322908674, 44.17602130344936, 44.56386974879673, 44.970009326934814, 46.12392793382917, 46.816708496638704, 47.836634567805696, 46.69527135576521, 48.49880484172276, 46.18393952505929, 41.515316350119456, 35.00444780077253, 38.015369755881174, 36.21395547049386, 42.1913343838283, 44.30112361907959, 43.23441185270037, 42.81309393474034, 40.00319726126534, 37.938946519579204, 37.82963745934622, 36.58399568285261, 33.29407923562186, 35.8980347769601, 37.55248771395002, 36.28029687064034, 41.44865533283779, 47.60418258394514, 46.82270131792341, 49.363952841077534, 42.409209047045024, 34.03160967145647, 49.481905460357666, 50.01141030447823, 50.303554262433735, 49.93363216945103, 50.08186503819057, 46.245010716574534, 45.01605156489781, 49.12145028795515, 47.12319701058524, 41.71725531986782, 39.253719397953574, 36.598645959581646, 37.897441455296104, 37.821706090654644, 40.0149883542742, 48.94485834666661, 50.14677510942732, 52.67062834330967, 49.48176997048514, 49.2700583594186, 51.756849902016775, 51.32855599267142, 49.77983379364014, 50.03528431483677, 47.326796599796836, 47.14177996771676, 50.08687468937465, 50.803136689322336, 49.23330238887242, 50.140480041503906, 49.98738343375069, 45.740797315325054, 43.81345040457589, 49.43845837456839, 51.551610537937705, 51.16206325803484, 46.33306523731777, 43.03420645850045, 39.65085063661848, 40.54089403152466, 41.910408292497905, 42.6089871270316, 50.05218928200858, 51.82083933694022, 57.00140230996268, 51.876018456050325, 44.88606466565813, 37.59583405085972, 23.527713877814158, 25.206999676568167, 27.21022960117885, 24.77392019544329, 10.151847941534859, 9.048402786254883, 11.191299319267273, 14.684295109340123, 0.3133973032236099, 0.2908221445977688, 2.6235987501485005, 20.91655305453709, 37.25134583881923, 34.051054205213276, 40.205771991184776, 45.387801034109934, 53.9759065083095, 59.76946040562221, 50.625738756997244, 10.513495598520551, 0.28042041989309446, 0.11659350006708077, 0.1647489946335554, 0.0983794963519488, 0.11968421350632395, 0.2123008780181408, 0.25075763730066164, 0.20127403257148607, 0.059759155847132206, 0.12105793479297842, 0.11137338089091436, 0.15002641321292945, 0.23193160178405897, 0.2213149850389787, 0.18571757232504232, 0.13373851935778344, 0.15273254657430307, 0.25325714317815645, 0.09201470217002289], [0.001984242075455508, 0.007863918069883116, 0.03682717601103442, 0.053667438083461354, 0.020634821582851664, 0.016751638613641262, 0.003756527622629489, 0.05792757948594434, 0.04567585280165076, 0.005515890470373311, 0.027502059071723903, 0.07502543380750076, 0.021920106007850597, 0.03777252456971577, 0.048997390283537764, 0.066757274259414, 0.01734099886380136, 0.024732292696301426, 0.025488748980153884, 0.27135953466807095, 8.620235681533813, 40.140281745365684, 39.993004253932405, 44.43833664485386, 22.969033547810145, 28.64378019741603, 57.556796142033164, 34.142360482897075, 5.759222413812365, 0.33973659415330204, 3.024703707013811, 13.849191989217486, 31.799942084721156, 18.664308377674647, 3.091919711657933, 2.4319211840629578, 10.673000182424273, 6.675074892384665, 14.661069018500191, 33.47037935256958, 41.36342525482178, 45.81180443082537, 46.9147823197501, 46.05056190490723, 43.96962506430489, 42.840626171657014, 42.94156960078648, 40.335779735020225, 39.05845069885254, 37.147869791303364, 34.93106092725481, 32.8258957181658, 34.07477535520281, 32.273708479745046, 32.3927241734096, 31.95406355176653, 32.39828968048096, 32.361558028629844, 33.13358974456787, 33.478289876665386, 32.822397300175254, 33.47371448789324, 33.64739860807146, 34.607632705143516, 36.57834332329886, 36.11624642780849, 36.65376949310303, 32.376402854919434, 32.27518844604492, 31.937898567744664, 38.67147772652762, 42.94517918995449, 44.63352196557181, 42.84004947117397, 38.02773754937308, 35.79677520479475, 35.13301726749965, 33.80550486700875, 32.09870072773525, 32.69743047441755, 32.995087827954976, 33.24436834880284, 38.50456462587629, 41.49257142203194, 42.41584805079869, 42.755382197243826, 49.8611033984593, 39.44663960593087, 27.235307386943273, 46.16208744049072, 42.99521664210728, 45.4542362349374, 44.0748416355678, 45.338277748652864, 45.6403854233878, 45.163509709494456, 42.93164757319859, 44.56326872961861, 36.45603765760149, 35.31340639931815, 33.105414799281526, 34.25817305701119, 35.16042791094099, 33.63324860164097, 37.39940847669329, 44.51692424501692, 45.16206448418753, 46.381862436022075, 46.18764986310686, 44.392058168138774, 44.53527791159493, 42.80926200321743, 40.34329768589565, 39.44021252223423, 43.54694529942104, 42.433367933545796, 42.10399900163923, 45.72089072636196, 44.957856927599224, 46.93245158876692, 45.8029454776219, 43.79709434509277, 45.59481913702828, 47.860327925000874, 43.77741009848458, 40.0785539490836, 39.29579768862043, 35.10445669719151, 35.58754062652588, 38.35731145313808, 40.92621333258492, 41.29859161376953, 44.78570488521031, 44.18873650687081, 52.22865343093872, 43.066790035792756, 33.96369797842843, 20.045375755855016, 12.428272349493843, 13.009784460067749, 5.957743304116385, 8.566796217645917, 8.493407607078552, 2.4156248356614793, 8.286452906472341, 0.5828419849276543, 0.16106383023517473, 0.7029215129358428, 13.37175520828792, 40.73799010685512, 32.6907046181815, 17.084625005722046, 27.347833463123866, 40.63288123267037, 46.69108854021345, 33.39291041237967, 3.8458926251956393, 0.16034927857773645, 0.08842006791383028, 0.034783737268298864, 0.03329989992614303, 0.050633908182914765, 0.05956781575722354, 0.040399642528167794, 0.04204288131690451, 0.045263768306800296, 0.05866763048938342, 0.0861785885478769, 0.06476591647203479, 0.04344595263579062, 0.05689786866839443, 0.05869589825826032, 0.020342008277241672, 0.08647592259304863, 0.028970181542847837, 0.07823764572718314, 0.03853041425879512, 0.015150701394304633, 0.06255301700106689, 0.04719199858871954, 0.05280981392466596, 0.023115465883165598, 0.034107739970620186, 0.07314900628158025, 0.022272114708487476, 0.032396291449133835, 0.027559386799111962, 0.010070011834613979, 0.0411201008329434, 0.02499864822519677, 0.05107871163636446, 0.03939253031941397, 0.01633408003752785, 0.019667819275387695, 0.03015854741845812, 0.2825980287577425, 11.584325909614563, 46.23000955581665, 45.00474337169102, 47.62451301302229, 27.18643375805446, 29.383386407579692, 54.31573595319475, 38.82084662573678, 7.034618547984532, 0.2259403004177979, 2.650643527507782, 14.889796767915998, 18.639993156705582, 17.013593571526663, 3.793156232152666, 5.741439368043627, 9.315309149878365, 4.999773016997746, 17.93555872780936, 32.95180402483259, 44.4635968208313, 46.46732527869088, 49.75757871355329, 47.38605778557913, 45.588777678353445, 43.12389380591256, 44.84587628500802, 42.01363073076521, 41.70190327508109, 38.65476730891636, 36.832630021231516, 34.482683249882285, 34.88977820532662, 34.34289591653006, 33.94851269040789, 33.748571327754426, 34.4291022164481, 33.76890870503017, 35.70764371326992, 35.608760425022666, 35.04095016207014, 35.976764815194265, 35.74170725686209, 36.61715248652867, 39.506765842437744, 39.1528628213065, 39.010716574532644, 34.43737057277134, 33.07158749444144, 33.53694656917027, 39.69693456377302, 44.39628962108067, 45.879973207201274, 44.873332091740195, 41.22328008924212, 37.86894341877529, 37.07665075574602, 36.66308355331421, 34.578321729387554, 34.45743349620274, 34.555350984845845, 33.792098317827495, 40.16869987760271, 43.24189853668213, 44.45999070576259, 45.63809946605137, 50.35121890476772, 40.18913105555943, 29.63496330806187, 45.69063479559762, 43.121173586164204, 48.093391350337434, 45.2108964238848, 45.71844496045794, 47.233722005571636, 45.46970639910017, 45.50134154728481, 45.46932077407837, 38.136452538626536, 37.067055293491904, 34.601570401872905, 36.084889207567485, 36.05845478602818, 35.44743020193917, 39.9832489831107, 46.132265772138325, 46.3070581299918, 48.61916501181466, 47.33339391435896, 46.916779926845, 46.33936725343977, 45.30985961641584, 42.72053350721087, 42.441160338265554, 45.41876915522984, 46.43522112710135, 44.74622522081648, 47.944185733795166, 46.39008215495518, 48.618108885628835, 46.560330390930176, 45.11316653660366, 46.38681302751814, 49.91807862690517, 45.840312889644075, 42.54547711781093, 40.97846378598894, 37.71966484614781, 36.177022320883616, 40.1581038747515, 41.90550633839199, 44.5004118510655, 46.32923330579485, 46.73874276024954, 52.10618448257446, 45.89368895121983, 34.772569043295725, 25.592600379671367, 14.161414504051208, 13.981591650417872, 9.53797459602356, 13.053809983389717, 6.391370390142713, 5.676198388848986, 12.180624655314855, 0.46878491661378313, 0.0046714451579776195, 1.0041416095835822, 14.76794273512704, 38.336261885506765, 37.416084153311594, 24.546260731560842, 34.111892632075715, 45.13970865522112, 52.227541719164165, 40.44365051814488, 5.980989371027265, 0.15815026871860027, 0.15401647053658962, 0.006970686089646603, 0.11399538948067597, 0.07626767536359173, 0.07715175221008913, 0.04563543925594006, 0.03746213211811014, 0.02027586637996137, 0.03796616489333766, 0.041524867327617745, 0.004366885138941663, 0.04564758503277387, 0.04041772209373968, 0.05088166845962405, 0.00782445871404239, 0.06784724577197007, 0.027102164458483458, 0.05212212886129107, 0.15686840750277042, 0.06910775349076305, 0.18870996604008333, 0.13714274311704294, 0.15241051385445253, 0.16363714715199812, 0.1366458112107856, 0.11661454822335925, 0.14778320358267852, 0.15937510585146292, 0.12473986936467034, 0.17458906876189367, 0.09589107773665871, 0.12542342554245675, 0.12910586223006248, 0.15555211742009434, 0.1314196259315525, 0.1647333883281265, 0.09894146583974361, 0.5881031826138496, 16.61228472845895, 54.615432603018625, 50.20739466803414, 54.10407297951834, 30.905257293156215, 37.29665156773159, 64.01203046526227, 42.13056891305106, 7.954212631498065, 0.5280969110982758, 3.950328392641885, 19.42157690865653, 37.201652322496685, 27.57005943570818, 8.783809304237366, 8.462506362370082, 17.25464047704424, 10.148891483034406, 18.49345564842224, 36.098789078848704, 46.41378246034895, 48.155348437173025, 51.32766662325178, 49.219100270952495, 48.46960503714425, 46.97229950768607, 47.34053666251046, 45.00509772981916, 43.85008825574602, 41.96238429205758, 39.119699069431846, 36.59436239515032, 36.68304572786604, 35.18806437083653, 36.00403649466378, 35.7421658379691, 36.65730612618582, 35.67610583986555, 36.44830431256975, 36.659282888684956, 36.018954277038574, 38.24703311920166, 37.31886148452759, 38.461065428597585, 40.7787378174918, 39.689211641039165, 40.95649358204433, 34.703434467315674, 35.19926486696516, 35.34950576509748, 42.581510475703645, 46.72441904885428, 47.70200974600655, 47.12912034988403, 42.28198058264596, 40.14837292262486, 38.64070415496826, 37.914388111659456, 35.67212799617222, 36.35105732509068, 35.57421398162842, 36.843038422720774, 42.799148900168284, 45.52685185841152, 44.47353969301496, 47.75932196208409, 52.11455011367798, 41.28927755355835, 32.233360290527344, 45.426759583609446, 44.22962318147932, 48.24758924756731, 45.80037464414324, 47.21678229740688, 48.95429400035313, 47.21763345173427, 47.845552580697195, 47.26620830808367, 40.40086351122175, 39.486383301871165, 36.31255388259888, 37.27730778285435, 39.10268987928118, 36.103204659053254, 40.6164105279105, 46.97225087029593, 48.20141499383109, 51.514798981802805, 49.69378382819039, 48.685030460357666, 47.976435797555105, 47.10361351285662, 44.39530645098005, 42.790797165461946, 47.691267830984934, 47.64650058746338, 47.051797321864534, 50.111665861947195, 48.19100659234183, 49.64925282342093, 47.046353408268516, 44.866748673575266, 46.43133360998971, 52.46086917604719, 48.255190576825825, 45.10374477931431, 43.75707966940743, 39.7555113519941, 38.93410226276943, 42.75616386958531, 44.04216078349522, 45.85051284517561, 48.40255144664219, 49.20481130055019, 55.35856328691755, 46.95200381960188, 35.83922174998692, 24.645078011921473, 18.094246898378643, 17.183935608182633, 12.193179181643895, 17.978965861456736, 18.304657459259033, 4.494522162846156, 11.325039114270892, 1.0229840385062354, 0.15837795792945794, 1.468991837331227, 19.596621138708933, 51.25283452442714, 42.90640476771763, 25.436385767800466, 36.9348658152989, 52.27332339968, 57.543087346213206, 48.777236529758994, 9.232844454901558, 0.22349557945770876, 0.20841910131275654, 0.2605858642075743, 0.1293355191924742, 0.15417349711060524, 0.1832277016448123, 0.11678771036011831, 0.1575652901083231, 0.11235684954694339, 0.10525663875575576, 0.1405942336257015, 0.12275288812816143, 0.1897481381893158, 0.16978495940566063, 0.20425745605358056, 0.13727608881890774, 0.19865148115370954, 0.07389080790536744, 0.154688600184662], [0.026083252525755336, 0.07330555788108281, 0.007120883208699524, 0.025823258262659823, 0.046566182348345, 0.05455039195450289, 0.0186113436440272, 0.0119744306263913, 0.07317772188356944, 0.03693779418244958, 0.04389843710565141, 0.028123422426038554, 0.04581764287182263, 0.047047514734523635, 0.0715304288480963, 0.004811339570941138, 0.006757635847731892, 0.034252681835953674, 0.023325660764904957, 0.14151145012250968, 8.803452730178833, 41.79685735702515, 40.91422769001552, 28.15740282194955, 17.514082738331386, 46.211242471422466, 51.694191047123496, 32.303575311388286, 4.5865280372755866, 0.298709435654538, 0.9249703607388905, 3.7374924761908392, 25.45572781562805, 47.94295242854527, 11.527323756899152, 3.757368666785104, 5.700818462031228, 6.245647123881748, 19.731701067515782, 28.08429213932582, 42.491823128291536, 43.508111817496165, 49.078131743839805, 46.93898636954171, 48.25085142680577, 44.97028725487845, 45.227092674800325, 45.33616897038051, 45.207894802093506, 40.64904621669224, 36.11597892216274, 31.512040002005442, 32.84333917072841, 31.42047664097377, 33.27530867712838, 31.010859489440918, 31.720725672585623, 31.26683807373047, 31.42289808818272, 30.361532960619243, 31.318268639700754, 31.48721408843994, 30.833433764321462, 30.969858169555664, 32.596202169145855, 30.630195481436594, 31.734580380576, 31.01429189954485, 29.41732140949794, 36.38415159497942, 44.62791476930891, 44.52794408798218, 44.47153513772147, 40.55211189814976, 40.349648339407786, 37.15762506212507, 37.527467250823975, 33.13237380981445, 32.127956117902485, 32.47770759037563, 34.509103775024414, 39.45086063657488, 44.81217752184187, 43.60832221167428, 47.33403662272862, 45.0466479573931, 44.41848564147949, 37.994445255824495, 27.483229534966604, 43.82242052895682, 41.21715872628348, 42.86775541305542, 44.61395583833967, 46.678039823259624, 45.8302275793893, 45.42563744953701, 42.297475065503804, 38.68175063814436, 36.970944336482454, 35.95619814736502, 33.88166754586356, 33.369821548461914, 32.18517105919974, 32.64624309539795, 32.414399078914094, 33.30238580703735, 35.875533035823274, 35.999662603650776, 36.26696675164359, 37.91521494729178, 38.55960825511387, 36.47320665631975, 35.014414991651265, 35.45618840626308, 36.96396139689854, 40.09376702989851, 40.3195834841047, 41.835548400878906, 42.927707944597515, 43.23588834490095, 46.7075001852853, 47.32807854243687, 45.1162098475865, 46.81197329929897, 47.83382402147566, 44.3350829396929, 38.45618779318673, 32.21365172522408, 42.46321044649397, 47.21446507317679, 48.0376945904323, 46.664466517312185, 45.98806633268084, 47.19120250429426, 50.12255021503994, 44.93805456161499, 37.55818176269531, 25.145318780626567, 12.934842927115303, 13.110459515026637, 11.890789236341204, 12.417462689535958, 10.690272535596575, 2.7429813955511366, 3.801489293575287, 1.2602499297686984, 0.15553599542805127, 0.852257353918893, 12.875918728964669, 38.13979809624808, 26.18350992883955, 28.20458456448146, 32.682839257376536, 44.748924595969065, 47.87575987407139, 33.984344550541465, 3.600854196718761, 0.009024257056548126, 0.032191655465534756, 0.03668387280777097, 0.012630516313947737, 0.01786684993255351, 0.048656053242406676, 0.016731740574219396, 0.05631730392841356, 0.05322041242782559, 0.04886642963226352, 0.028660318348556757, 0.005732564089287604, 0.03336216229945421, 0.04332610299544675, 0.04506532734792147, 0.02855112849335585, 0.035672665640179596, 0.026672777320657457, 0.02653838158585131, 0.0453738640062511, 0.037086814043245146, 0.02565231323907418, 0.02772603160701692, 0.03764217459995832, 0.04891439188005669, 0.03199388625632439, 0.04798825264775327, 0.05535696992384536, 0.03622837224975228, 0.06205668220562594, 0.06408635686550822, 0.06803165123398815, 0.02795342226246638, 0.08641666612987008, 0.035130801144987345, 0.03148190783602851, 0.04709310889510172, 0.0038410188031515902, 0.23645767463105066, 12.39346969127655, 49.4279214314052, 45.77945014408657, 34.05905852999006, 21.64459572519575, 42.54363237108503, 56.85065419333321, 37.008297852107454, 5.769254309790475, 0.26624150787081036, 1.6919137154306685, 5.57160758972168, 39.17104973111834, 52.5421005657741, 15.957415274211339, 6.009771849427905, 5.448381287711007, 6.989994176796504, 18.185195343835012, 28.63333531788417, 46.05092321123396, 46.325738361903596, 50.16781078066145, 47.922927720206125, 48.72390563147408, 46.44059903281075, 46.496504238673616, 47.224109172821045, 47.93343339647566, 42.32335710525513, 37.554891790662495, 32.96702752794538, 35.33459840502058, 33.264441694532124, 33.72935261045183, 32.10451289585659, 32.72810329709734, 32.56184332711356, 32.89878232138497, 32.096748283931184, 33.94606345040457, 33.29297794614519, 32.11137771606445, 32.58161095210484, 34.10448932647705, 33.03539432798113, 33.727493967328755, 32.78072200502668, 30.824672085898264, 37.58193417957851, 46.69503164291382, 47.829158306121826, 45.349436555589946, 43.01351819719587, 41.41469253812517, 38.64241688592093, 39.33483961650303, 34.592343194144114, 35.37387657165527, 33.680878502982004, 36.50048875808716, 39.76271663393293, 45.28855643953596, 44.69210570199149, 48.47628920418875, 47.08290788105556, 44.48795025689261, 38.3609036718096, 28.943958009992325, 44.15255723680769, 42.290325369153706, 44.31293903078352, 46.62328107016427, 48.345649174281526, 46.95449822289603, 46.803006649017334, 42.94678769792829, 40.99396521704537, 38.987436635153635, 36.69935662405831, 35.206876618521555, 34.44699035372053, 34.70757211957659, 34.844771248953684, 33.7996266910008, 34.807306562151226, 37.36636979239327, 38.45911645889282, 38.74015024730137, 39.84700175694057, 40.67743655613491, 38.82780524662563, 36.55035597937447, 37.16197463444301, 39.23886414936611, 42.581236021859304, 41.636131627219065, 44.25361878531319, 44.84198876789638, 45.08611372538975, 47.795386586870464, 47.511531829833984, 44.751488481249126, 47.956428459712434, 47.98027120317732, 46.27938345500401, 39.38538081305367, 34.17933532169887, 43.6359030859811, 48.38519137246268, 49.12147808074951, 48.37047161374773, 47.04263959612165, 50.978728090013774, 51.2557875088283, 46.21818024771554, 36.35516023635864, 26.06037221636091, 14.219318185533796, 13.430868744850159, 8.530907903398786, 10.76749655178615, 7.936177713530404, 6.262545577117375, 6.771464645862579, 1.6357550088848387, 0.054424774766500504, 0.7945268345730645, 14.503978065082006, 41.252031735011506, 28.752000127519878, 25.529917206083024, 34.39066825594221, 49.22114651543753, 52.548381737300325, 39.822408608027864, 5.563354866845267, 0.05698115884193352, 0.03858666481184108, 0.01889125969527023, 0.04402682610920497, 0.038019999861717224, 0.061425868554839065, 0.06344538554549217, 0.05977263833795275, 0.00668880610360897, 0.028365184453182986, 0.038118044779236825, 0.0770318347162434, 0.12326130084693432, 0.049245096277445555, 0.026473176066896746, 0.02026863319666258, 0.026352597001407827, 0.020899211056530476, 0.02450787741690874, 0.12508417160383292, 0.12196362976516996, 0.11918352251606328, 0.11451707434441362, 0.10693895776889153, 0.1197227950074843, 0.10379353405109473, 0.1092209592461586, 0.17094483359583787, 0.12387943267822266, 0.10792336958859648, 0.19312602121915134, 0.17830069602600165, 0.10868807855461325, 0.2414267494210175, 0.09602396203471081, 0.08972172878150429, 0.1114569017663598, 0.17609846991087708, 0.43682146604572025, 16.394578559058054, 56.49372175761631, 52.80043111528669, 39.98504856654576, 26.227875913892472, 53.30597162246704, 58.04233625956944, 39.44461420604161, 6.7519936220986505, 0.6615985674517495, 1.754633475627218, 5.272381246089935, 30.994281087602886, 55.384685039520264, 18.845513922827585, 12.102967245238167, 10.865025809832982, 9.626975808824811, 22.285134519849503, 31.93122829709734, 47.83944164003645, 45.861803667885916, 51.53720344815935, 49.64832523890904, 51.07919904163906, 48.96694319588797, 49.356612069266184, 49.709017753601074, 50.07338128771101, 44.988026005881174, 40.00770664215088, 34.970450265066965, 36.739260128566194, 35.319732734135215, 35.847219126565115, 34.07193354197911, 35.563569341387065, 35.95363426208496, 35.26320913859776, 33.688340868268696, 35.88570172446114, 35.6791387285505, 34.746259689331055, 34.4148062978472, 35.5743008341108, 34.835022926330566, 34.71721274512154, 34.04192427226475, 32.02037715911865, 39.62980106898716, 48.95563152858189, 49.01144640786307, 48.15484469277518, 44.79600558962141, 44.13662849153791, 41.35524722508022, 41.236485140664236, 36.13931097303118, 36.26458351952689, 35.965453147888184, 38.95523520878383, 43.26031126294817, 48.57671846662249, 46.589175837380544, 52.176847662244526, 48.76691150665283, 43.736099583762034, 39.518626417432515, 33.928845814296174, 43.77336972100394, 41.860450744628906, 43.62143693651472, 47.073941230773926, 49.66093969345093, 48.49680723462786, 48.49807875497, 46.07192414147513, 41.655888829912456, 40.95016377312796, 38.83243274688721, 37.29546342577253, 36.47194555827549, 36.39475107192993, 35.95656640189034, 33.96684898648943, 35.54732097898211, 39.56276484898159, 39.66365964072091, 39.239180292402, 40.576510497501914, 41.88663503101894, 39.927593912397114, 38.491977964128765, 38.68922342572893, 41.09150750296456, 44.69866132736206, 43.62872212273734, 46.52308457238333, 46.716063840048655, 47.767218589782715, 50.508859634399414, 48.51263175691877, 45.41484342302595, 48.48433869225638, 50.502717426845, 49.51670551300049, 42.51878908702305, 35.987141949789866, 47.885230268750874, 51.895966734204976, 53.901307174137656, 51.889268670763286, 51.21326800755092, 52.890618732997346, 53.68897369929722, 48.039521966661724, 39.9173001561846, 28.992550236838206, 15.690307412828718, 20.710915906088694, 25.34010979107448, 21.798175232751028, 14.813281467982701, 9.43190426485879, 6.607753796236856, 2.2514586618968417, 0.2128579688391515, 1.3087547613041741, 17.469235590526036, 48.777615206582205, 34.64004952566964, 37.42424133845738, 42.99866642270769, 54.69293281010219, 57.91169275556292, 48.51186050687517, 8.370085767337255, 0.22651607809322222, 0.19798795532967361, 0.09310830384492874, 0.12109410070947238, 0.09723800367542676, 0.15539567438619478, 0.13767926075628825, 0.17045394065124647, 0.09660602972975799, 0.14422601088881493, 0.1096736913813012, 0.14119754625218256, 0.1524031992469515, 0.0994807044044137, 0.1526993933532919, 0.1218167133629322, 0.09210198212947164, 0.11420671242688384, 0.07064024518643107], [0.03919895784929395, 0.021504197968170047, 0.060918331146240234, 0.006078191592158484, 0.018899532733485103, 0.018802011984267404, 0.043618361598679, 0.04802482229258333, 0.022746444613273655, 0.042021687275597026, 0.06387520355305501, 0.04984466678329876, 0.06736523485077278, 0.024936586019716094, 0.020281491435265968, 0.06291638607425348, 0.049663979693182876, 0.02131223532238177, 0.08371339618627514, 0.10644062808049576, 11.061208197048732, 40.039689200265066, 40.02804054532732, 25.719173976353236, 28.428728239876882, 36.719624519348145, 33.150734424591064, 25.00035330227443, 6.632705645901816, 0.15138439248715127, 0.045963188633322716, 1.4160940072366168, 3.1206648434911455, 13.500210898263113, 7.009181192943028, 4.633305915764399, 5.809546044894627, 4.681321007864816, 18.645178249904088, 32.54818664278303, 44.54714543478829, 46.726670265197754, 46.49914802823748, 46.8523770741054, 46.893628529139924, 45.315126350947786, 46.38314437866211, 45.59768526894705, 45.38001905168806, 44.98456232888358, 36.574969972882954, 29.80423879623413, 31.530598640441895, 34.25658539363316, 35.92337485722133, 37.67703764779227, 36.170956543513704, 34.82133844920567, 33.81683043071202, 31.974199431283132, 33.22324235098702, 32.64150094985962, 32.437303815569194, 33.50108691624233, 32.434937953948975, 30.749134744916642, 30.673218727111816, 30.045841557638987, 32.43562582560948, 40.172434534345356, 46.857768876211985, 45.83104746682303, 45.17112146105085, 41.87569161823818, 38.75608594076974, 36.11795221056257, 33.280589308057515, 34.149100235530305, 33.19534533364432, 32.24557869774954, 39.408236912318635, 42.593687193734304, 44.48539331981114, 46.17952047075544, 44.93700190952846, 42.67397710255214, 43.41015263966152, 40.482244287218364, 27.079097986221313, 43.268993037087576, 40.91389070238386, 43.928484780447825, 44.802467414310996, 42.58968850544521, 44.50139849526541, 40.62667301722935, 39.96417965207781, 38.129625933510916, 36.375580992017476, 34.193759781973704, 31.72347715922764, 33.51784597124372, 33.60974979400635, 33.651147161211284, 34.29381731578282, 34.02869142804827, 31.224488803318568, 31.870876244136266, 30.791765417371476, 32.45361123766218, 31.9846773147583, 34.00508144923619, 33.5124819619315, 35.17707926886422, 36.13292210442679, 35.73562410899571, 37.00455972126552, 36.503434794289724, 38.86745861598423, 42.50164788109915, 43.74745988845825, 47.873626777103965, 45.83331605366298, 46.97102451324463, 46.937551566532676, 44.17932169778006, 36.50325414112636, 38.164467675345286, 45.848598616463796, 48.51490381785801, 48.45325592585972, 50.81690107073103, 48.31388201032366, 49.969335487910676, 49.74833760942732, 46.749616691044395, 37.36239194869995, 31.00788218634469, 18.55175277165004, 20.64616390636989, 9.364999192101614, 10.504459466253008, 6.107144338744027, 4.428060472011566, 4.948051929473877, 0.7963127930249486, 0.01575165780793343, 0.4269985045705523, 9.759285143443517, 32.928791591099326, 38.48318154471261, 31.961376530783518, 30.193424769810267, 41.77315705163138, 44.72270556858608, 30.195147923060826, 3.3944757623331885, 0.03594127390533686, 0.09490302218390362, 0.020839695053707277, 0.04373968705268843, 0.041242494979607205, 0.014774714962446263, 0.015337817603722215, 0.011880417055051242, 0.0324095635940986, 0.050282247231474946, 0.03084060064117823, 0.03191607864573598, 0.04178792856899755, 0.04278381780854293, 0.060944034052746635, 0.04696913715451956, 0.025922989339700768, 0.04587933188304305, 0.03642250790393778, 0.04162565352661269, 0.035303339029529264, 0.02202660038268992, 0.016995115638045327, 0.06801001953759364, 0.057135769831282754, 0.03880030156246253, 0.016172188367428522, 0.030293864264552082, 0.010685817138957126, 0.03419986806277718, 0.022732848467837487, 0.04358735254832676, 0.04461823383878384, 0.032010059138493877, 0.09186989601169314, 0.05134657012032611, 0.012774153695707875, 0.05353903550920742, 0.06272334286144801, 14.503297141620092, 46.80092913763863, 45.03548220225743, 32.20319468634469, 27.8031975541796, 44.46724115099226, 42.57188374655587, 28.47988956315177, 6.955827713012695, 0.0760932375809976, 0.054819207172840834, 1.5169347333056586, 3.986145922115871, 21.01753990990775, 6.569966018199921, 5.224887703146253, 6.3212209429059705, 8.308230297906057, 21.65666127204895, 34.71915129252842, 45.99688012259347, 48.09621579306466, 48.176460538591655, 49.28397560119629, 48.8864483152117, 48.293287549700054, 48.42456681387765, 47.55142143794468, 46.812174797058105, 47.08369302749634, 38.90059110096523, 31.774664538247244, 32.81419842583792, 35.46021488734654, 36.98276669638497, 38.1530761037554, 37.10675382614136, 36.02718094417027, 34.42401613507952, 32.91308518818447, 35.75763252803257, 34.70100259780884, 33.43710790361677, 34.03045974458967, 34.476311751774375, 32.73127862385341, 32.08508573259626, 32.577733857291086, 35.05244943073818, 42.19330072402954, 47.86438567297799, 48.21790654318673, 46.52923372813633, 44.24845974785941, 41.79258074079241, 38.350797516959055, 34.61700929914202, 35.98604760851179, 35.30625670296805, 34.029184750148225, 40.155995096479145, 45.23112262998308, 47.23412847518921, 47.042445046561106, 48.0174822807312, 44.970436641148154, 42.6997514452253, 41.974686077662874, 28.215694734028407, 44.91133178983416, 40.09925610678536, 45.22158970151629, 46.26369094848633, 45.05814722606114, 44.87084116254534, 42.47570330756051, 40.889061314719065, 40.24324362618582, 36.67726135253906, 36.42357219968523, 33.84288270132882, 36.65694481985909, 35.78400788988386, 35.01728112357003, 35.348623343876426, 34.95863832746233, 32.813354219709126, 33.35182918821062, 32.672145979745046, 34.31591606140137, 33.64316020693098, 35.1988479750497, 35.577580383845735, 37.82392604010445, 38.13528176716396, 38.301927362169536, 38.47233888081142, 38.369550704956055, 40.839934076581685, 45.69222593307495, 45.880883421216694, 49.42952299118042, 46.74483980451311, 47.74366072246006, 49.71264123916626, 47.168971742902485, 39.31369972229004, 38.59406089782715, 48.293864250183105, 50.84987027304513, 50.24569313866751, 52.04946286337716, 50.63032109396798, 51.82528270993914, 50.356006213596885, 45.87407766069685, 38.9256706237793, 30.234578950064524, 16.810294491904124, 12.199681827000209, 9.2454754114151, 10.822654826300484, 11.254758954048157, 4.433313310146332, 3.0100738406181335, 0.8084935279829162, 0.04313301907054015, 0.5264287463256291, 10.613916175706045, 37.36612660544259, 37.43876307351248, 36.933431012289866, 38.99836267743792, 47.13611371176583, 51.841485909053254, 35.757549149649485, 5.343547735895429, 0.03455525756414447, 0.048810667624430995, 0.016829156150509204, 0.0641113608809454, 0.055302802473306656, 0.06046618255121367, 0.04416112515277096, 0.024601464359355823, 0.007408397155813873, 0.058520374819636345, 0.00868688605260104, 0.016683330493313924, 0.028367287911740795, 0.08801530820450612, 0.01883249177730509, 0.01140579198753195, 0.044711349199392965, 0.030065903639686958, 0.024992319189810326, 0.10416281316429377, 0.11140972322651319, 0.1777786040412528, 0.09379944604422365, 0.17233393048601492, 0.1378484195364373, 0.08546818952475276, 0.1035110599228314, 0.08901019660489899, 0.08813598565757275, 0.2065780729587589, 0.14528714466307843, 0.18922534052814755, 0.09195567640875067, 0.15767168439924717, 0.21757369222385542, 0.15891541194702896, 0.11906734375017029, 0.1471177100070885, 0.3163528931992394, 19.618855374200002, 52.387520517621724, 51.68386254991804, 37.00255169187273, 38.96968051365444, 43.67130763190133, 40.63785266876221, 32.903930936540874, 9.257907475743975, 0.4281105691833155, 0.19979213923215866, 3.761530203478677, 4.380667243685041, 16.820859227861675, 10.832588144711085, 13.465588893209185, 12.82508657659803, 8.423606872558594, 20.933982610702515, 36.64681434631348, 49.023438998631065, 48.24023110525948, 49.262252058301655, 49.371943269457134, 48.454520498003276, 50.155168533325195, 47.55705990110125, 49.34217718669346, 49.681287493024556, 50.69017635072981, 40.01119463784354, 33.717175892421174, 33.98223229816982, 37.921513489314485, 39.94872338431222, 41.87040751320975, 40.927081857408794, 39.138257707868306, 37.39453084128243, 34.5552328654698, 38.176988329206196, 36.84211778640747, 35.571288790021626, 37.354564802987234, 36.05933025905064, 34.58902195521763, 33.632015296391074, 33.927011489868164, 36.8251885005406, 44.28306177684239, 48.347511291503906, 48.3579683303833, 48.31459420067923, 44.91348573139736, 42.704674243927, 40.3281923021589, 36.03887823649815, 37.731924942561555, 36.622690200805664, 35.41114670889718, 41.39667238507952, 47.74580076762608, 48.23589890343802, 49.4445276260376, 49.66375371388027, 44.4413799558367, 42.601688044411794, 42.680220058986116, 32.32843944004604, 44.80950593948364, 41.38439144407, 46.598121643066406, 48.415555000305176, 46.903164931706016, 47.96309525626046, 43.50272001538958, 44.051436628614155, 41.528615202222554, 39.13036108016968, 37.64917189734322, 35.03280339922224, 38.145283699035645, 37.001328808920725, 36.41162824630737, 36.857469831194194, 37.603039332798545, 33.517769541059224, 35.048930168151855, 33.45464515686035, 35.18910312652588, 34.87539196014404, 37.05074092320034, 37.00304848807198, 39.475905418395996, 40.925435134342735, 39.05490711757115, 41.26954814365932, 40.18451745169503, 42.74157265254429, 46.92895317077637, 47.81212132317679, 52.77000147955758, 47.09864207676479, 49.511417933872764, 51.043360233306885, 50.11620650972639, 40.54472943714687, 41.421939509255544, 50.54330880301339, 53.25279011045183, 51.37081841060093, 53.81824493408203, 52.648282936641145, 54.44555956976754, 51.60412849698748, 48.352646010262625, 41.231458118983674, 33.234686034066335, 20.223796810422623, 26.667851482118877, 15.992204904556274, 19.345695631844656, 18.810837200709752, 12.69755412851061, 9.35907324722835, 1.7129539464201247, 0.24494821046079907, 0.6677015828234809, 13.220026527132307, 44.06862299782889, 49.39343057359968, 42.818853991372244, 42.86289167404175, 54.547388894217356, 57.49037831170218, 43.74755021503994, 8.152089510645185, 0.10789031136248793, 0.21966436718191418, 0.10954890879137175, 0.17934827267059258, 0.12461051344871521, 0.16918575870139257, 0.10087331610598735, 0.07968423488949027, 0.10707180135484252, 0.1281638384929725, 0.07951173093169928, 0.24464466103485652, 0.10334867292216846, 0.11232801180865083, 0.11600411097918238, 0.1144313346594572, 0.16566418909600802, 0.18474194753382886, 0.15310556441545486], [0.02469662211037108, 0.026846168462985327, 0.10152613464742899, 0.04724479879119566, 0.00614637418350737, 0.016446547216868827, 0.03604688788098948, 0.04512195788057787, 0.04270680747660143, 0.034526691239859374, 0.032467737793922424, 0.0388405285110431, 0.0450702331561063, 0.030531870600368296, 0.03348701613556061, 0.00214680061825285, 0.027595483165766512, 0.02939161964293037, 0.013147448039879757, 0.43781204574874466, 17.14370380129133, 36.301815441676546, 37.2084059715271, 26.51933547428676, 26.913411242621287, 19.220761810030254, 29.822505610329763, 27.8589186327798, 5.504705122538975, 0.13462989724108151, 0.13388553075492382, 0.24916812830737659, 4.91043438230242, 0.6960915965693337, 2.236286836011069, 4.658472291060856, 1.2442658160414015, 7.405636719294956, 20.351560286113195, 31.19529594693865, 46.53722415651594, 48.775624547685894, 48.48318876538958, 46.411361013139995, 45.04464340209961, 46.2029185295105, 44.49365472793579, 45.19199732371739, 45.17318160193307, 44.79054083142962, 34.79400076184954, 31.274241379329137, 34.13260868617466, 39.393256596156526, 44.99662440163748, 45.74755096435547, 46.61567626680647, 44.76614570617676, 41.32332025255476, 41.15664339065552, 40.51664481844221, 39.56372022628784, 42.35147646495274, 41.641481740134104, 40.36087662833077, 37.71268538066319, 34.77348967960903, 33.377968311309814, 35.151513372148784, 42.322856834956575, 45.011580399104524, 43.227943079812185, 45.600930077689036, 41.966310024261475, 36.67128937585013, 33.51902369090489, 34.260208879198345, 33.57843426295689, 34.17696598597935, 33.51305866241455, 40.63464954921177, 46.81022930145264, 47.66794620241438, 44.87680271693638, 44.13435990469796, 44.293942655835835, 42.72162784848894, 40.161557129451204, 26.296251399176462, 43.58457326889038, 42.023653507232666, 42.9591520173209, 44.54346636363438, 43.58796051570347, 42.55225508553641, 42.91923809051514, 40.234422888074604, 38.382206848689485, 36.13815062386649, 34.25868374960763, 33.575925963265554, 33.79887975965227, 37.80546120234898, 39.445378507886616, 38.23004477364676, 37.273461954934255, 36.890595367976594, 36.62314183371407, 35.14518356323242, 31.50400788443429, 32.22111756461007, 34.123384952545166, 34.17737592969622, 33.65323509488787, 35.223177092415945, 36.18292481558663, 33.46057544435774, 33.51115138190133, 33.92089360100882, 38.54480859211513, 43.12450524738857, 46.797569683619905, 47.64801182065691, 45.73738922391619, 49.926902839115684, 45.073384625571116, 37.74284751074654, 35.45221403666905, 44.16624518803188, 48.80292749404907, 48.606574875967844, 48.68386663709368, 49.898220675332205, 47.93213755743844, 45.66508974347796, 46.89320468902588, 41.179725306374685, 30.62364333016532, 22.392692634037562, 10.043824298041207, 5.88080416406904, 7.057565408093589, 6.127498652253832, 4.41837077481406, 1.2263169905969074, 0.7400314073477472, 0.03363983579246061, 0.09957908519676753, 8.87874254158565, 29.347474643162318, 33.967102595738, 18.483290433883667, 20.95067392076765, 45.09965229034424, 47.797926153455464, 30.057914052690776, 7.40211398260934, 0.13673003097730024, 0.08409105520695448, 0.049969829352838654, 0.059742748870381286, 0.028752371801861694, 0.07184201891400985, 0.0591095807030797, 0.042864587224487743, 0.05236053214009319, 0.022296184041936482, 0.07913387513586453, 0.046062451521200795, 0.06854569579341582, 0.06312313569443566, 0.053233348697956116, 0.04796377449695553, 0.043829009402543306, 0.02164290748935725, 0.024939054190846424, 0.0031330415139174356, 0.008780657895840704, 0.021434597238632183, 0.07215532567352057, 0.024183144127683978, 0.0021575475527372745, 0.013608258982588137, 0.04174425805519734, 0.034651100635528564, 0.10373482720128127, 0.024251106195151806, 0.048107321972825696, 0.047260520447577746, 0.04429812137303608, 0.011204355296545794, 0.021261506348050067, 0.022577681079772965, 0.028096828942320178, 0.06468958806778703, 0.6736716596143586, 19.997851814542496, 42.87089947291783, 42.24004125595093, 31.771423203604563, 32.68489939825875, 25.206655740737915, 34.32590062277657, 32.42874016080584, 5.890401363372803, 0.24120291428906576, 0.12842568515666894, 1.4576769130570548, 5.121617496013641, 2.45000821352005, 5.078000179358891, 6.625305814402444, 5.17442467382976, 11.22620359488896, 22.498880216053553, 34.64913429532732, 46.71000153677804, 49.03691850389753, 48.978310448782786, 47.28179311752319, 47.34992715290615, 47.032651560647146, 46.83260597501482, 47.32778671809605, 47.7204224722726, 48.06309373038155, 36.756102561950684, 32.18660238810948, 35.295424461364746, 40.36421871185303, 45.325812680380686, 46.23078427995954, 47.24971328462873, 45.95987401689802, 43.04566751207624, 40.178743498665945, 40.29750905718122, 41.23441457748413, 43.39752776282174, 42.5520327431815, 41.14360509599958, 38.072487422398154, 35.98501927512032, 34.257954188755576, 35.57871641431536, 43.740671498434885, 47.19006299972534, 44.20824704851423, 47.307178361075266, 43.05545404979161, 39.530983788626536, 35.31199591500418, 35.02058151790074, 35.71784366880144, 34.6611407824925, 34.27773918424334, 42.77905123574393, 48.03337281090872, 48.71888555799212, 46.66300739560808, 45.3301796231951, 43.21366800580706, 43.39518969399588, 41.30817665372576, 28.19428907121931, 44.06864384242466, 41.5706969669887, 44.230029651096885, 45.27919026783535, 44.34828104291643, 44.18610313960484, 45.669394152505056, 41.86984123502459, 40.54715435845511, 37.82945333208357, 36.1475167955671, 35.79658760343279, 35.006070205143516, 39.83347708838326, 40.26444605418614, 39.81730168206351, 38.911322593688965, 37.59470844268799, 37.93182461602347, 35.85716894694737, 33.623330048152376, 33.67982932499477, 35.72750513894217, 36.249481609889436, 37.05909265790667, 37.199637344905305, 36.944200720105854, 36.956085613795686, 35.79304749625069, 35.272252219063894, 40.115441935403005, 45.81843301228115, 48.30741671153477, 48.18473931721279, 45.55289718082973, 51.346551827022004, 46.65350920813424, 40.47747434888567, 37.22994538715908, 46.20724030903408, 51.05740254265921, 49.89809908185686, 50.04821491241455, 51.899961948394775, 48.76641123635428, 46.528928007398335, 46.26418079648699, 40.60901417051043, 34.37308931350708, 21.51368818964277, 12.046706812722341, 11.179762704031807, 8.12381034237998, 10.573184967041016, 6.417094358376094, 3.0932661422661374, 1.388358209814344, 0.18413450941443443, 0.2766371529017176, 10.514597756522042, 34.07273258481707, 38.21716628755842, 19.873673609324864, 24.9015724999564, 50.76812124252319, 53.82320942197527, 37.41204724993025, 8.99145187650408, 0.0841207614700709, 0.011528410050751907, 0.018636035533355813, 0.01048990966020418, 0.022437846886792352, 0.032924398646823, 0.03788844209962657, 0.0938273338334901, 0.047131680218236785, 0.030086860193737915, 0.009592063641840858, 0.058607308726225577, 0.04769916619573321, 0.06099381138171468, 0.016516695863434246, 0.04668301250785589, 0.021995560798261846, 0.010421501455961593, 0.03334663063287735, 0.08027401074234929, 0.09200072434863873, 0.1783787411238466, 0.10381598677486181, 0.10303179028310946, 0.054617709413702996, 0.08902119565755129, 0.11777318747980253, 0.11299025520150151, 0.21066161883728846, 0.1340393546436514, 0.16896247996815614, 0.10520562649305377, 0.19181758857199124, 0.08085180366677897, 0.07817226209278617, 0.08581779112241097, 0.09695877294455256, 0.1558283490261861, 1.1009365298918314, 24.321312802178518, 51.45518691199166, 48.88776152474539, 37.84360681261335, 37.14202288218907, 28.616393872669764, 39.63283395767212, 35.734637464795796, 7.211133190563746, 0.33332175122840063, 0.49182861724070137, 1.3729159470115389, 11.01142088004521, 3.686716777937753, 4.626359888485499, 12.577188747269766, 4.431858965328761, 12.402157545089722, 24.206035239355906, 35.23038584845406, 49.84853410720825, 51.23284108298165, 51.10524436405727, 48.05539860044207, 47.885136468069895, 47.24184792382376, 45.67729772840227, 49.31222002846854, 50.01207038334438, 50.73596150534493, 37.81481695175171, 34.92688853400094, 37.237154143197195, 43.33468130656651, 48.16262320109776, 48.999481609889436, 49.065774372645784, 49.338122912815635, 45.81581006731306, 43.45960296903338, 45.54572663988386, 45.16580956322806, 46.47508989061628, 46.53991658346993, 43.959362574986045, 40.41003860746111, 38.834086418151855, 37.33733674458095, 37.64859519686018, 44.99491514478411, 48.564256872449604, 45.76939262662615, 48.61105298995972, 44.79112100601196, 41.03235748835972, 36.22011504854475, 37.74988603591919, 36.95962572097778, 37.58059317725045, 36.088936533246724, 44.6433675629752, 50.93797690527779, 51.53400032860892, 48.85698447908674, 46.034362179892405, 44.08816133226667, 43.187021664210725, 41.294092655181885, 32.576274735586985, 43.5674181665693, 42.54278121675764, 45.47831174305507, 46.460814816611155, 46.977871962956016, 45.90017856870379, 49.685883726392476, 44.354996476854595, 41.982909270695274, 39.98344700677054, 36.947296142578125, 37.2489070211138, 36.78948170798165, 41.402078083583284, 42.44887283870152, 42.67702388763428, 40.17086771556309, 39.85243872233799, 39.779260294778005, 38.21850381578718, 35.797560351235525, 35.12977245875767, 37.05394751685006, 38.477167878832134, 37.78673928124564, 39.74942125592913, 38.586793082101, 38.40370110103062, 37.3575872693743, 36.23507799421038, 43.128840923309326, 46.78405543736049, 50.76647104535784, 48.744378498622346, 46.365801674979075, 54.24177237919399, 48.84762178148542, 42.73325218473162, 38.193518093654085, 47.89706999914986, 54.02307088034493, 51.63026762008667, 52.501543930598665, 53.49505989892142, 50.57300887789045, 46.72873388017927, 47.436060496738975, 43.47331523895264, 35.423785482134136, 26.180421454565867, 16.571757623127528, 13.258174742971148, 15.801454271589007, 14.447521345955984, 12.312742914472308, 5.585518751825605, 2.2618822625705173, 0.3054830607559, 0.24696473511201994, 13.080136707850865, 39.343993868146626, 46.54687867845808, 26.33162294115339, 31.640157835824148, 57.61099903924124, 59.16750322069441, 44.02605485916138, 11.646666015897479, 0.22290856524237565, 0.16793281664805754, 0.15700184819953783, 0.12804590910673141, 0.14690713344940118, 0.09921469153570277, 0.21809412858315877, 0.20568275957235269, 0.1883923573685544, 0.1254434966083084, 0.16446171647736005, 0.1195300639207874, 0.09983882161655597, 0.17647526040673256, 0.13757251362715447, 0.12079288544399397, 0.12757202024970735, 0.06108649247991187, 0.1380547620356083], [0.019068917126527855, 0.03831673679607255, 0.030040282157382796, 0.020817018413384045, 0.025463388733831898, 0.08110839168408088, 0.059911751587476046, 0.005746390512545726, 0.09668164567223617, 0.05380448858652796, 0.030849034831460034, 0.027333902827064906, 0.03909251266824348, 0.07357883107449327, 0.008017280554798032, 0.02381066232919693, 0.029184042210025445, 0.055858678716634, 0.014479937297957284, 0.49593114852905273, 18.09834807259696, 40.461691515786306, 41.94542373929705, 34.34608861378261, 20.79404936517988, 16.649127551487513, 29.655498708997452, 29.0862831728799, 4.840377867221832, 0.1930228838963168, 0.01228143718825387, 1.947358591215951, 4.462034557546888, 3.629952383892877, 3.03951444370406, 3.3765713402203152, 7.216515004634857, 8.520757453782217, 22.76976616042001, 36.281724725450786, 48.25887312207903, 48.15739120755877, 48.04180097579956, 45.13661323274885, 46.44971854346139, 45.19136503764561, 46.12049204962594, 43.50214678900582, 43.82105868203299, 38.28400100980486, 33.739292008536204, 33.5673623085022, 33.80460854939052, 41.01918717793056, 46.60353776386806, 44.5658986227853, 42.568802220480784, 42.66230065482003, 45.63229424612862, 43.74816165651594, 44.255550384521484, 43.52923434121268, 44.122506277901785, 45.05117123467581, 45.50075095040457, 43.44515419006348, 39.40763589314052, 38.043204239436555, 38.6147700037275, 45.04148891993931, 43.17239570617676, 44.30155093329293, 44.53133480889456, 40.79662248066494, 36.09997722080776, 32.20809664045061, 31.936700003487722, 33.03064523424421, 33.52727467673165, 35.18400314876011, 40.54159927368164, 44.54285492215838, 45.468323707580566, 46.60717167173113, 45.3706876209804, 45.97946793692452, 42.68537562234061, 41.58523954663958, 26.439867189952306, 43.301243100847515, 42.15138224193028, 42.84590332848685, 42.24181304659162, 45.1392639705113, 44.10196392876761, 43.217763968876426, 39.89367628097534, 37.26231704439436, 33.32254947934832, 32.62062856129238, 32.8929180417742, 36.668885299137656, 38.51467078072684, 43.46690899985177, 44.93667187009539, 45.27589334760393, 44.8063896724156, 47.159039293016704, 45.426398277282715, 41.091913972582134, 31.337834766932897, 32.5551244190761, 32.852840832301546, 33.335410594940186, 34.81402199608939, 33.445101806095664, 34.07446616036551, 34.71924161911011, 33.632077830178396, 34.73449986321585, 42.252617495400564, 46.06207854407174, 47.21633761269705, 44.97644683292934, 47.12343324933733, 45.44144112723214, 39.409095014844624, 36.823718956538606, 38.50699302128383, 44.99012783595494, 43.81363800593785, 45.330638204302105, 47.50428485870361, 49.888239588056294, 48.286884784698486, 48.67813784735543, 40.63376712799072, 40.25199488231114, 24.77117565699986, 12.348954319953918, 12.391026530947004, 10.087034276553563, 9.717570764677864, 3.1140195429325104, 1.496545135974884, 0.22808438965252467, 0.14796681515872478, 0.1495868039450475, 5.795157194137573, 31.83236585344587, 33.32944209235055, 24.144964047840663, 37.77784211294991, 45.44183717455183, 46.522900445120676, 26.678115708487375, 7.961754032543727, 0.41754005210740225, 0.03871056191357119, 0.03017951754320945, 0.06653003288166863, 0.04569538782483765, 0.05345710240570562, 0.022068496527416364, 0.020379765358354365, 0.08984007885945694, 0.05887260913316693, 0.023519357067665884, 0.0038135843600944747, 0.0159658662243081, 0.02187703430120434, 0.0458279973162072, 0.024938531718882065, 0.028524387428270917, 0.03764322632923722, 0.02456658087404711, 0.01465779320070786, 0.022652072266542485, 0.04379830908562456, 0.05128393455275467, 0.02010218007490039, 0.11506663342671734, 0.0017761118485525782, 0.03185681878988232, 0.05029516653823001, 0.03716982941010168, 0.008804301448565508, 0.0636386051774025, 0.030750318164271966, 0.029600618606699363, 0.08385718454207693, 0.03318593318441084, 0.02386985093887363, 0.01569749035739473, 0.020023503939488103, 0.6866720648748534, 22.23685496194022, 45.75969988959176, 46.69246775763375, 38.148677894047324, 26.665216377803258, 22.41954915864127, 34.03740446908133, 30.995844432285853, 5.44197895697185, 0.1585342109735523, 0.05334543250501156, 0.9987512188298362, 5.594129306929452, 6.289896292345865, 6.216044758047376, 6.633822134562901, 6.515135177544185, 17.88605281284877, 24.299280064446585, 37.539386885506765, 49.02725008555821, 49.77206918171474, 47.88019282477242, 46.575036253247944, 45.98219510487148, 46.27076768875122, 46.785170623234336, 46.08008132662092, 44.9077604157584, 41.77024923052107, 35.96399055208479, 36.3252968788147, 36.53286041532244, 43.58496931621006, 47.51450565883091, 46.45915419714791, 43.90194613592965, 44.885870116097585, 46.78458002635411, 46.540906701769146, 45.81817592893328, 47.06163249697004, 46.35097074508667, 45.92980221339634, 47.44990825653076, 45.23531239373343, 41.133342606680735, 39.061980383736746, 39.500213691166465, 45.50860588891165, 44.52306645257132, 43.70296709878104, 46.37824589865548, 42.990488392966135, 37.502821990421836, 33.6537492615836, 34.14437893458775, 34.60485689980643, 34.05490698133196, 35.66968223026821, 42.62913690294538, 47.44439833504813, 47.915166582380024, 48.51619618279593, 46.519888401031494, 46.60753992625645, 43.64135047367641, 41.73038741520473, 28.31420976775033, 42.744647230420796, 41.370248385838096, 42.98526682172503, 43.87249967030117, 45.40378189086914, 44.90084000996181, 45.571122305733816, 42.04970577784947, 39.47954627445766, 35.8493070602417, 35.08499131883894, 35.06473731994629, 38.66545016424996, 41.138591970716206, 45.99315588814871, 47.61807550702776, 48.28369208744594, 46.8037987436567, 48.631699562072754, 46.95005137579781, 42.53290087836129, 32.94980294363839, 34.768761430467876, 33.936676434108186, 35.29681062698364, 36.674989291599815, 35.57024308613369, 35.92107847758702, 36.20012160709926, 35.406025886535645, 36.908424445560996, 43.05575629643032, 47.06123297555106, 48.585608686719624, 45.541853019169395, 49.57284695761544, 47.556347710745676, 40.971237659454346, 37.60218470437186, 42.06365081242153, 46.50793055125645, 46.765097277505056, 47.48521900177002, 49.23622063228062, 50.54792240687779, 49.229863030569895, 47.39340203148978, 42.06193460736956, 38.78559841428484, 24.393469844545635, 14.105610047067914, 12.187647547040667, 5.219402534621103, 7.050165576594217, 7.790522626468113, 3.7869836262294223, 0.6035448483058384, 0.0903519724628755, 0.1572503141526665, 7.639915210860116, 34.35195984159197, 41.46853412900652, 32.09337145941598, 39.09000941685268, 50.999774183545796, 51.87078298841204, 33.812129974365234, 10.111525808061872, 0.4575495166437966, 0.09916517205004181, 0.035831120530409474, 0.02662608054067407, 0.02095133950933814, 0.12932812316077097, 0.01706895890778729, 0.023265751211770942, 0.006743164816206055, 0.012558902031742036, 0.01798768514501197, 0.028443146430488144, 0.028299598954617977, 0.014163778146861919, 0.06580429896712303, 0.006814265532219517, 0.012811379823168474, 0.035084592910217385, 0.022223467140325477, 0.13176623518977845, 0.08590622459139143, 0.10756335926375218, 0.10891821727688823, 0.18478280891265186, 0.19291277123349054, 0.08496341375367981, 0.0800797665225608, 0.128689119592309, 0.12075149480785642, 0.08623214531689882, 0.17156135051378182, 0.13568047301045486, 0.16634011854018482, 0.12242488430014678, 0.15125202387571335, 0.09990368277898856, 0.09052202012389898, 0.11975816025265626, 1.1341509819030762, 25.887388127190725, 54.653084891183035, 52.973812988826204, 44.140206813812256, 30.29233237675258, 25.484432561056956, 38.56998538970947, 37.65867008481707, 6.409393148762839, 0.42761355585285593, 0.10844746325165033, 3.408548035791942, 7.722231388092041, 10.374196376119341, 9.067566786493574, 6.930220127105713, 12.97416799409049, 11.872816852160863, 25.748837573187693, 39.89113324029105, 52.651183809552876, 50.24040903363909, 50.105509757995605, 47.223838193076, 48.15292698996407, 47.0705817767552, 48.65377746309553, 47.40711430140904, 48.51694311414446, 42.31940705435616, 38.63601759501866, 38.126759801592144, 37.214721884046284, 45.5912720816476, 49.75079379762922, 45.97352722712925, 43.93186160496303, 44.836947849818635, 48.649757930210654, 48.011482511247905, 48.48623207637242, 47.99377850123814, 46.53923566000802, 46.94075468608311, 50.22908346993582, 47.14399644306728, 43.71159676143101, 42.606926986149375, 42.9654609816415, 47.93826239449637, 45.69916370936802, 44.577943325042725, 48.00011873245239, 43.99922786440168, 39.74449150902884, 33.78311429704939, 35.363801683698384, 35.82361262185233, 37.00881896700178, 38.13019568579537, 45.30391543252127, 48.505867685590474, 49.22058023725237, 50.166160583496094, 47.99775287083217, 48.43107032775879, 44.50945840563093, 41.50792694091797, 31.468259402683803, 42.763494219098774, 41.85885613305228, 43.60968058449881, 44.699891158512656, 47.32119982583182, 48.899830545697895, 47.46079955782209, 43.28389344896589, 42.065533774239675, 37.305635588509695, 37.24282039914812, 37.441021238054546, 39.80370058332171, 41.75926412854876, 47.86267989022391, 49.20396362032209, 49.943172046116416, 48.00655276434762, 51.443333285195486, 49.55330514907837, 45.93279341288975, 35.09068536758423, 36.78307894298008, 35.432394300188335, 36.97572122301374, 38.21955646787371, 36.59023516518729, 38.43494367599487, 38.18156371797834, 36.85092462812151, 38.01548787525722, 45.11033167157854, 49.58969633919852, 49.392457825796946, 44.95898253577096, 51.19955573763166, 50.649432114192415, 44.03440311976841, 40.85255200522286, 42.6048390524728, 49.04779243469238, 49.37256860733032, 49.47189310618809, 52.03723750795637, 54.11910540716988, 49.853081703186035, 49.61485229219709, 44.210772718702046, 48.55256652832031, 27.48989459446498, 17.117934669767106, 17.580273015158518, 13.84757045337132, 14.268441949571882, 12.870906472206116, 5.810177896703992, 0.6526915196861539, 0.1717518288642168, 0.35737223497458864, 8.446454286575317, 40.75411687578474, 47.07108552115304, 35.4630879674639, 48.50666672842843, 56.42846080235073, 60.190236364092144, 41.2654104913984, 12.183496866907392, 0.6327424272894859, 0.23102193059665815, 0.1032700307135071, 0.14727583580783435, 0.13085770394120896, 0.15884860338909285, 0.20111003065747873, 0.14922868673290524, 0.2068544402718544, 0.11094144585409335, 0.1898419524409941, 0.09657908510416746, 0.09763220537986074, 0.09919034569923367, 0.11288183887622186, 0.12480222673288413, 0.04723856983972447, 0.1770162699478013, 0.09665548136191708], [0.0349836777895689, 0.04387604205736092, 0.034212556667625904, 0.03375738859176636, 0.01109349200435515, 0.01410949110452618, 0.03469841488237892, 0.04678062655563865, 0.02609460611295487, 0.035113271192780564, 0.06048189742224557, 0.03876471579340952, 0.037726275622844696, 0.023594686329098682, 0.03423817814993007, 0.024895392158733945, 0.019880397511380057, 0.05711623480809586, 0.04239805029439075, 0.33940986597112244, 13.263556122779846, 34.58895942143032, 40.3480224609375, 33.004596437726704, 19.843838044575282, 19.32904601097107, 31.522806235722133, 27.04665858404977, 5.52155841248376, 0.09596169966139964, 0.15236891965780938, 1.472557457430022, 5.8295790042196, 3.4006151471819197, 6.669947556086949, 7.460410237312317, 7.456747668130057, 19.101813861301967, 22.42423745564052, 38.871978419167654, 45.46420342581612, 48.66997023991176, 46.2674012865339, 43.680541787828716, 46.86242764336722, 44.99861853463309, 44.14180837358747, 43.37568262645176, 42.320859227861675, 34.61674526759556, 30.44582850592477, 31.45091322490147, 30.786641120910645, 38.87277398790632, 44.22048282623291, 47.11417130061558, 43.861382552555625, 45.157273701259065, 43.76113394328526, 45.53858389173235, 45.87867736816406, 46.34045812061855, 45.49640137808663, 45.40022441319057, 45.048926966530935, 44.70886475699288, 44.28803668703352, 44.65516907828194, 43.349348953792024, 46.18335240227835, 41.655312129429404, 46.004081930433, 43.011246136256624, 40.45392690386091, 36.31884200232369, 32.210087299346924, 33.09688935961042, 33.98191268103463, 34.04493284225464, 33.39836822237287, 37.343736035483225, 40.66438089098249, 43.36391237803868, 43.95207738876343, 42.879216466631206, 43.97178942816598, 45.74819367272513, 44.423564774649485, 24.444005829947336, 40.0505770274571, 42.28122670309884, 40.95160552433559, 44.02488061359951, 41.97294902801514, 44.514871052333284, 44.550167901175364, 41.79846933909825, 36.752270630427766, 33.4364686693464, 32.909239360264365, 34.04159075873238, 35.79210254124233, 41.179895537240164, 44.562806674412315, 45.92839520318167, 45.365514687129426, 47.342635018484934, 46.652727535792756, 49.13883120673043, 46.259278842381065, 36.23688799994332, 31.813838481903076, 33.608950751168386, 31.964162758418492, 32.49883358819144, 31.297976425715856, 34.265621525900706, 33.06680713381086, 32.77307898657662, 32.25495876584734, 38.70819895608084, 44.71099090576172, 48.17591510500227, 46.81833437510899, 47.5312751361302, 45.60957016263689, 43.02811288833618, 37.71251514979771, 36.25661046164376, 38.393389974321636, 40.47358683177403, 44.65014900479998, 45.15325764247349, 47.22547449384417, 48.51011650902884, 46.890637329646516, 45.86124086380005, 39.358442647116526, 27.146870715277537, 18.102485724857875, 18.595536845070974, 4.681434784616743, 9.351528372083392, 3.6036352132047926, 4.016282430716923, 2.5928942263126373, 0.10538436618766614, 0.10291156066315514, 6.009106125150408, 29.05810127939497, 29.510719094957622, 19.485665355409893, 30.95304352896554, 41.002448967524934, 46.098837988717214, 30.799415384020122, 3.746566389288221, 0.09400093023266111, 0.011666416440026035, 0.04297576857996838, 0.14466091112366744, 0.043977635713028054, 0.02130960769552205, 0.0520118669207607, 0.046229025082928796, 0.0920337757893971, 0.020305248642606393, 0.007258636843679207, 0.08833865728229284, 0.0644499294992004, 0.02203142985568515, 0.03505824539544327, 0.0666479215558086, 0.0416659110092691, 0.03170161408239177, 0.056045174066509516, 0.027266393681722026, 0.04991198084982378, 0.022258564364165068, 0.03182971131588731, 0.019627802672662904, 0.014651910302096179, 0.030336958023586443, 0.005467537640860038, 0.051876149739005735, 0.01011506571168346, 0.025901182920538952, 0.0234069696161896, 0.07191901906792607, 0.025411792931013873, 0.0658015034028462, 0.03353389272732394, 0.017728287992732863, 0.016057980745764713, 0.009951273295363145, 0.5792644226125309, 16.030209813799175, 41.274318081992014, 46.9758882522583, 38.5435266494751, 25.463647024972097, 19.152872698647634, 34.21322863442557, 32.452732290540425, 6.574375952993121, 0.07620557583868504, 0.08588386007717677, 1.3828085533210208, 3.6851356284958974, 4.769447181906019, 6.33888543503625, 7.1348797508648465, 6.828112006187439, 18.89518485750471, 23.634273188454763, 40.947071824754985, 47.56886836460659, 49.327096121651785, 47.75652183805193, 45.21997424534389, 47.83852447782244, 47.19410685130528, 45.20547335488455, 45.888773100716726, 44.913027150290354, 37.07894018718174, 32.338055746895925, 32.8550260407584, 32.18937471934727, 40.66916125161307, 45.934964724949424, 48.54088660648891, 44.18813896179199, 44.81709337234497, 44.24287339619228, 45.976341247558594, 47.06501626968384, 46.66855900628226, 46.025968755994526, 45.229375158037456, 44.57079710279192, 46.64522000721523, 46.59382765633719, 46.26607418060303, 46.062422479902, 47.495665618351524, 43.71600191933768, 46.197401659829275, 44.96305765424456, 42.1873391696385, 36.3870073046003, 34.117527621132986, 34.37913772038051, 35.11855459213257, 35.05808789389474, 35.31246839250837, 39.43563365936279, 42.73019845145089, 44.17252288545881, 45.363402434757774, 46.26330879756382, 47.074111461639404, 47.12890842982701, 43.97661147798811, 26.919277259281703, 40.99114424841744, 42.63262837273734, 41.52145160947527, 45.08996302740914, 44.544011797223774, 46.96776928220476, 45.74599804197039, 43.45224135262625, 38.494493212018696, 35.257178102220806, 34.37733466284615, 35.951191970280235, 38.71806539808001, 42.98646886008126, 46.54153551374163, 48.019465991428916, 46.723616531917024, 48.44825322287423, 48.39709711074829, 49.73002910614014, 48.82469967433384, 38.4545966557094, 33.3929659979684, 35.17786094120571, 34.5096492086138, 35.454183850969585, 33.855048997061594, 34.75154379435948, 33.94735581534249, 34.815776416233604, 34.32239178248814, 39.49125746318272, 47.242091110774446, 47.67912585394723, 47.842655181884766, 49.39049843379429, 48.622791971479145, 43.05129207883562, 39.71190793173653, 38.62971905299595, 41.208511693137034, 41.62984003339495, 47.28036873681204, 47.82962383542742, 50.34198822293963, 51.00988381249564, 48.223409516470774, 45.88446174349104, 37.87411982672555, 26.576586893626622, 18.091627427509852, 13.311542987823486, 6.4772449135780334, 11.805467963218689, 8.673319050243922, 5.58904105424881, 1.7182851689202445, 0.08338575198182038, 0.22983150875994138, 7.08392470223563, 33.54990495954241, 35.38387155532837, 20.995203188487462, 38.06029680797032, 45.28655883244106, 52.97302784238543, 37.23547962733677, 6.087103562695639, 0.09986201394349337, 0.10505829618445464, 0.02944497624412179, 0.08485766407102346, 0.09423434627907616, 0.04212782033053892, 0.06154455111495086, 0.01578150486706623, 0.06377630028873682, 0.052902746080820046, 0.07746661960014276, 0.06351015849837235, 0.08294571523687669, 0.03143683954008988, 0.02926739345171622, 0.059088803960808685, 0.06292357854545116, 0.05122497325230922, 0.026457686808758547, 0.1953332820641143, 0.17231243449662412, 0.11967140276517187, 0.12457433396152087, 0.07693787797221116, 0.10384986602834292, 0.20918828860989638, 0.1329558699258736, 0.17073520698717662, 0.10352226253598928, 0.10649082610117537, 0.06572209444961377, 0.14477242156863213, 0.1598531880549022, 0.21164356757487568, 0.1751794892230204, 0.11122472743902888, 0.15867647262556211, 0.08476080998246159, 0.9382340375866208, 19.838993413107737, 49.720398902893066, 52.505747590746196, 44.19456257138933, 30.84531170981271, 28.216439928327286, 42.65724584034511, 35.88533694403512, 7.606964247567313, 0.36330995921577725, 0.5038822218775749, 2.758740995611463, 10.808154804365975, 7.787778956549508, 15.806630679539271, 15.895180259432111, 14.93757084437779, 22.462692260742188, 26.153351272855485, 43.35334416798183, 49.41791255133492, 50.40942049026489, 48.61829648699079, 45.95633738381522, 48.513378688267295, 47.50600453785488, 46.84450476510184, 47.662318161555696, 47.093722752162385, 38.40075159072876, 34.04476955958775, 35.72560828072684, 33.378235816955566, 42.17907428741455, 48.03406763076782, 50.24468217577253, 44.6663487298148, 45.67387921469552, 43.99104636056082, 47.445433616638184, 48.3779548236302, 48.498193400246755, 46.83999538421631, 46.930169105529785, 45.72986085074288, 47.615351813180105, 47.889354024614605, 50.44035039629255, 48.482851777757915, 49.484372070857454, 43.28275394439697, 47.44739300864083, 46.912829875946045, 44.69038254874093, 38.73774964468819, 35.771080766405376, 35.623236996786936, 37.44314043862479, 36.804482868739534, 36.83522169930594, 41.57934400013515, 44.95727327891758, 44.784725189208984, 48.04181487219674, 48.37292085375105, 48.05526311056954, 49.02039916174752, 45.14818198340279, 30.38082115990775, 40.811001777648926, 41.62353801727295, 41.58128602164132, 46.75149270466396, 46.19135325295584, 48.834375040871755, 47.42882742200579, 46.59328917094639, 39.54640531539917, 36.31477383204869, 35.636296136038645, 37.13098914282662, 38.889953408922466, 45.5648307119097, 47.83718000139509, 49.77843720572335, 48.383225032261436, 50.30432898657662, 49.276099818093435, 52.93156794139317, 49.906461238861084, 40.97174140385219, 34.61606434413365, 37.28662531716483, 35.33978870936802, 36.47492980957031, 34.6018830708095, 37.857989583696636, 36.07417161124093, 35.23737226213728, 35.378955704825266, 42.39504861831665, 48.444925035749165, 51.251615115574424, 49.86001600537981, 51.864758900233674, 49.90831988198416, 45.841573987688335, 41.847106729234966, 40.36906508037022, 42.0589850970677, 43.47263431549072, 50.61722721372332, 50.08524186270577, 50.813374859946116, 53.16699028015137, 48.0785882132394, 47.85352563858032, 40.47547674179077, 29.827522209712438, 21.352587257112774, 23.151666947773524, 10.980864439691816, 24.43806685720171, 13.354472432817731, 8.857986535344805, 4.632375725678035, 0.23289992553847177, 0.276351869638477, 8.825794662748065, 36.89930146081107, 40.91926165989467, 28.38929373877389, 43.33247525351388, 51.53026567186628, 58.3733241217477, 43.50004843303135, 9.207516533987862, 0.18606209169541085, 0.17015288823417254, 0.1332166445042406, 0.28980352782777374, 0.1561922337859869, 0.1352053763610976, 0.17062193235116346, 0.14015291444957256, 0.1558857938008649, 0.1283895056694746, 0.13134297861584596, 0.1380637322685548, 0.23640100338629313, 0.1885686136249985, 0.1665487816291196, 0.1543097605130502, 0.19565524693046296, 0.16651918393160614, 0.1458973783467497], [0.03432331393871989, 0.07152149932725088, 0.06101678657744612, 0.036428455263376236, 0.04956128002543535, 0.027814729704654644, 0.06552729383111, 0.005600031781276422, 0.021170558906825523, 0.053413991683295796, 0.03716341046882527, 0.006368170317728072, 0.05242229579016566, 0.03807384500812207, 0.004076717271735626, 0.020623289880209734, 0.03762396611273289, 0.06686457778726305, 0.042874826317919154, 0.3366497483636652, 12.77240446635655, 33.69282593045916, 43.03661400931222, 33.921609265463694, 21.690321820122854, 25.015192917415074, 28.733417170388357, 27.82720010621207, 6.8417404634611945, 0.18570041895977088, 0.08769354011331286, 0.24721454456448555, 3.8322372436523438, 4.5626870308603555, 3.7507578900882175, 6.639259534222739, 4.628618487289973, 32.679219245910645, 28.82837646348136, 44.91064044407436, 46.189383438655305, 48.69447306224278, 43.366319928850444, 45.773377418518066, 43.53865957260132, 45.97554915291922, 44.55596964699881, 43.07932111195156, 36.9227933202471, 31.751169204711914, 30.454114232744487, 29.958853585379465, 29.506536279405864, 36.61126388822283, 41.27113580703735, 45.406366620744976, 44.60953330993652, 43.284213066101074, 44.71374934060233, 45.494073731558665, 42.131889070783345, 45.35681206839425, 44.59456689017159, 45.90657091140747, 44.3076479775565, 44.13341147559029, 43.1762067931039, 45.81241239820208, 43.64062786102295, 43.75225067138672, 44.04342882973807, 45.88263784136091, 41.185711179460796, 37.42282043184553, 31.403696741376603, 32.63936785289219, 30.69162450517927, 32.87494305201939, 32.438214029584614, 32.408072744097026, 33.17866618292672, 36.90313686643328, 35.740571226392476, 39.50523376464844, 39.183532169886995, 42.99890613555908, 42.24055889674595, 46.149379185267854, 26.95980610166277, 39.75555998938424, 45.4154930795942, 44.34154823848179, 43.59022910254342, 43.279429231371196, 46.23806251798357, 44.57577201298305, 40.47408710207258, 35.919310161045615, 32.914589473179404, 33.64859022412981, 33.90172004699707, 36.86921576091221, 38.31669923237392, 42.635157517024446, 44.64299930844988, 45.148220198495046, 47.560068471091135, 46.128541537693565, 47.554520334516255, 43.98246533530099, 35.610243865421836, 33.71052646636963, 33.82375431060791, 33.455419881003245, 33.88852194377354, 34.58328621728079, 34.60948787416731, 34.491903509412495, 31.3026282446725, 32.998037338256836, 34.025102683476035, 39.14754744938442, 46.48173931666783, 48.609413215092246, 45.6569047655378, 47.282651220049175, 44.75828729357038, 41.42533023016793, 37.769372258867534, 38.597357818058555, 38.67516027178083, 42.09469536372593, 43.604059491838726, 47.56782266071865, 46.10284015110561, 49.41334411076137, 44.35829339708601, 38.93789945329939, 29.205557686941965, 22.82497133527483, 12.542894176074437, 4.9752866966383795, 2.1299865628991808, 7.3409238031932285, 3.4291127494403293, 3.132449422563825, 0.04914816076468144, 0.07146446167358331, 5.50897696188518, 29.089877128601074, 41.773445401872905, 40.973836285727366, 30.668090956551687, 35.63604252679007, 44.737508705684114, 36.39499773297991, 8.416326028960091, 0.031114762715463127, 0.012949041855920638, 0.04904807345675571, 0.018296615353652408, 0.032630681193300655, 0.04618197885741081, 0.02289849074025239, 0.03157498248453651, 0.0558905596844852, 0.03154604975134134, 0.04353945815403547, 0.03576406430719154, 0.015555096391056265, 0.009576543001458049, 0.019413831743544767, 0.046445318298148255, 0.06789202229785067, 0.03359113394149712, 0.008484574051440825, 0.013043063060779656, 0.028196646532576, 0.020433127048558423, 0.029135320003011396, 0.0662935905690704, 0.02976760607478874, 0.07875285736684288, 0.02442897397226521, 0.03856682784057089, 0.010269363726755338, 0.027651869425816194, 0.02419032302818128, 0.04477730280320559, 0.014988351713067718, 0.005216726501073156, 0.0028231925264533076, 0.03330427647701331, 0.031848292997373004, 0.03102162021345326, 0.3395143603639943, 15.868268149239675, 41.13291529246739, 48.59189680644444, 38.58803333554949, 24.471579756055558, 33.77664205006191, 34.53375250952584, 31.35736267907279, 7.103659757546016, 0.19053164257534913, 0.07590590763304915, 1.1611745889697755, 4.999768674373627, 7.703089100973947, 8.99539237362998, 9.415219902992249, 6.449824716363635, 21.021340574537003, 28.68180247715541, 46.15385382516043, 49.414768491472515, 48.70991890771048, 44.40290430613926, 46.179583004542756, 45.339900153023855, 46.5161190032959, 46.36746576854161, 44.22491577693394, 39.63094752175467, 33.683897495269775, 32.450244835444856, 30.994454792567662, 32.23173788615635, 36.0156260899135, 43.69329868044172, 46.181452069963726, 44.5379182270595, 42.517395973205566, 45.462508065359934, 46.105331080300466, 45.135571002960205, 46.832102230616975, 46.24817909513201, 47.470304693494526, 45.51990365982056, 45.78247261047363, 43.734831537519185, 45.6529859815325, 44.861867564065115, 44.40134790965489, 45.01150744301932, 47.40284810747419, 43.78360094342913, 39.87961312702724, 32.99151297977993, 32.97741508483887, 32.665395804813926, 33.05086101804461, 33.146127768925254, 34.24953644616263, 35.48446410042899, 38.57763883045742, 38.56686912264143, 41.54689938681466, 41.64412552969796, 44.354266916002544, 44.384564535958425, 48.75623559951782, 29.439687660762242, 38.93684332711356, 43.900139604296, 44.68608161381313, 43.609256744384766, 45.74949298586164, 48.26579352787563, 46.429662568228586, 42.98923076902117, 36.38250487191336, 34.674186025347026, 35.94011306762695, 35.40953125272478, 37.64261279787336, 39.77910396030971, 44.204717363630024, 46.1896196774074, 47.0915653364999, 50.07040745871407, 46.71263837814331, 48.47148105076381, 46.204940455300466, 36.62958628790719, 34.96432542800903, 35.36982577187674, 34.95351750510079, 35.428305285317556, 35.28472076143537, 35.757625579833984, 35.7354781968253, 33.65765414919172, 34.348107065473286, 36.03406660897391, 42.5210611479623, 48.34454788480486, 50.301546233040945, 47.851323059626985, 48.68191071919033, 46.775113105773926, 42.097922801971436, 40.34390565327236, 40.67948974881853, 41.1816395350865, 44.10398585455758, 46.877842221941265, 50.19738578796387, 48.47933598927089, 50.19580159868513, 45.14219958441598, 41.085073471069336, 29.99181236539568, 21.0632712159838, 11.425824471882411, 8.46272349357605, 6.251850128173828, 5.9161713634218485, 4.236337959766388, 4.1953210064343045, 0.16342963757259504, 0.09530999391738858, 6.1138628125190735, 31.095815113612584, 41.67842183794294, 37.0722073827471, 34.39546946116856, 41.82775599615914, 50.28365114756993, 40.4340237889971, 10.471517188208443, 0.07210187068475143, 0.028285461677504436, 0.02716590094912265, 0.01710365749230342, 0.014361232685457383, 0.05125261337629386, 0.01813813841103443, 0.06364077648946218, 0.022338112417076315, 0.07997909906719412, 0.027059688166316067, 0.04212534028504576, 0.016464173860315765, 0.03734395845926233, 0.06187271100601979, 0.03585867244484169, 0.08828928707433598, 0.010637971090285905, 0.008059883224112647, 0.07733729082558836, 0.16780301289899008, 0.118574198069317, 0.07206141642693963, 0.18780233045773848, 0.13370813455964836, 0.12527458210076603, 0.12697697217975343, 0.11484667951507227, 0.09691902436316013, 0.1866609395614692, 0.09987521823495626, 0.1483541229473693, 0.22490249467747553, 0.21601200316633495, 0.0943257517314383, 0.16706498392990657, 0.08639679862452404, 0.07132280391774007, 0.807719889496054, 19.43756471361433, 47.88836390631539, 54.544342109135215, 43.46914631979806, 31.31272050312587, 34.254282065800254, 37.82364811216082, 36.648912702287944, 9.359439764704023, 0.3827182320611817, 0.27768877361501965, 1.2644167861768176, 8.618241548538208, 14.155915873391287, 10.996066229684011, 10.739684649876185, 11.641541719436646, 36.70621797016689, 31.692377022334508, 49.21880497251238, 49.20015948159354, 52.08190747669765, 45.252286842891145, 47.529360907418386, 44.82363510131836, 48.0134870665414, 48.7719281060355, 47.72978169577462, 40.547734533037456, 33.86207709993635, 35.08966398239136, 33.76124831608364, 32.744219643729075, 39.66977752958025, 45.77342258180891, 48.08740547725132, 46.07767030170986, 43.07419681549072, 46.390221118927, 48.82616227013724, 47.16162402289254, 50.1895169530596, 50.28245953151158, 50.75065347126552, 46.906809261866975, 46.521271092551096, 43.509484086717876, 46.699815477643696, 45.518222195761545, 43.30120488575527, 46.30414683478219, 48.31107841219221, 46.23194810322353, 41.10049499784197, 34.00863197871617, 35.30334888185774, 33.39978912898472, 35.4158228465489, 34.773743288857595, 34.507672446114675, 37.720144271850586, 39.99200371333531, 39.60583325794765, 42.841887269701274, 43.8115222794669, 45.938449246542795, 46.65813670839582, 48.097431727818076, 32.031956332070486, 39.45455707822527, 45.08826766695295, 46.56786571230207, 46.69259977340698, 48.13132504054478, 48.45209557669503, 50.2400164604187, 44.835850034441265, 39.57273898805891, 36.83416557312012, 37.191104957035606, 37.90774910790579, 40.85038416726248, 41.70121192932129, 46.9031788281032, 50.22770772661482, 49.34689848763602, 50.08821221760341, 46.82081140790667, 51.12009266444615, 47.81147166660854, 38.794099535260884, 37.26824038369315, 36.429439953395296, 37.17774357114519, 38.42288160324097, 37.172643593379426, 38.72608709335327, 39.10934625353132, 34.928576946258545, 36.04782056808472, 37.82038593292236, 43.92900242124285, 49.670569896698, 52.86148493630545, 48.44911132540022, 49.810746329171316, 48.2161625453404, 44.88114186695644, 41.07310519899641, 43.96113436562674, 42.13501228604998, 46.43104525974819, 49.3371536391122, 52.55567387172154, 49.70049578802926, 53.697200366428916, 45.49130834851946, 43.6924683707101, 32.36959709439959, 25.133263656071254, 15.215926102229528, 9.438246233122689, 8.8959584406444, 14.65624349457877, 7.157313747065408, 5.158460319042206, 0.4741836669189589, 0.20517032992626938, 8.207214781216212, 37.56901053019932, 55.3094916343689, 53.55189616339547, 42.60711458751133, 47.790310927799766, 57.7469231741769, 49.107512201581685, 13.550644397735596, 0.36030024928706034, 0.08991068042814732, 0.13936854153871536, 0.08463401892887694, 0.09919958056083747, 0.09997631995273487, 0.1485973641808544, 0.19159701040812901, 0.06803352399063961, 0.14995372854173183, 0.10190121523503747, 0.12446840107440948, 0.08691796780164752, 0.11855650187603065, 0.11267471606177942, 0.15495567156800202, 0.12743796887142317, 0.10488537153495209, 0.062180345212774615], [0.07457352269973073, 0.016005226344402348, 0.02706588658371142, 0.01162735911618386, 0.01768841557869954, 0.016102770842345696, 0.04640516938109483, 0.05170283493186746, 0.0069120157110903946, 0.04000516262437616, 0.04267642607114144, 0.030320625685687577, 0.0029831849346269985, 0.013137486297637224, 0.08481866866350174, 0.04041579505428672, 0.03896464952932937, 0.04160655615851283, 0.04618190082588366, 0.7143439171569688, 9.402256301471166, 30.247679778507777, 48.458619935171946, 36.82439293180193, 25.64752241543361, 18.413058042526245, 30.610886437552317, 35.04286091668265, 6.9149158511843, 0.40102233844144003, 0.055747500753828456, 1.8833780586719513, 2.192507105214255, 3.992799690791539, 6.607554035527365, 7.097189247608185, 4.508658707141876, 14.583318676267352, 27.551803043910436, 42.474706241062705, 48.2675826890128, 47.29429987498692, 44.82044587816511, 44.67231723240444, 47.37060151781355, 46.00073984691075, 42.013345854622976, 40.16749783924648, 33.85974945340838, 31.396244798387798, 30.535404682159424, 30.443146501268657, 31.256457465035574, 33.963704926627024, 41.026468890053884, 45.27673060553414, 45.428962162562776, 45.083244119371685, 44.563605717250276, 40.067349978855674, 39.17766094207764, 39.02094432285854, 40.610066822596956, 41.83321033205305, 44.396348680768696, 46.82762064252581, 45.71931348528181, 44.40513815198626, 43.69311802727835, 45.25469786780221, 45.82233442578997, 43.552847794124055, 40.483644349234446, 34.289981910160606, 31.478695596967423, 31.609554495130265, 32.87208734239851, 32.362513405936106, 32.03720917020525, 32.43152986254011, 32.093044894082205, 32.654591356004985, 32.40614809308733, 33.88133750643049, 35.47455596923828, 42.87534284591675, 41.477233273642405, 47.70246485301426, 27.45256539753505, 40.11162737437657, 48.96913882664272, 43.8552542413984, 45.56585209710257, 46.08911051068987, 44.802186012268066, 43.3187768799918, 42.10834162575858, 33.6004079410008, 33.597614765167236, 32.306337220328196, 33.8862429346357, 33.919285093035015, 34.02491855621338, 37.65181221280779, 42.09190913609096, 44.302773816244944, 48.394356046404155, 44.369771821158274, 45.84190402712141, 44.72372695377895, 38.254738671439036, 35.40710980551583, 36.17989887510027, 38.40388175419399, 40.31346559524536, 43.766841888427734, 44.349715845925466, 44.86729063306536, 40.22962168284825, 35.00105013166155, 31.38828911100115, 33.983326639447895, 38.840020179748535, 45.992669514247346, 47.34339584623064, 48.12126404898507, 46.32163197653634, 44.2105781691415, 41.4597932951791, 41.60473966598511, 40.99642835344587, 41.31234209878104, 41.95570012501308, 46.59570366995675, 47.84813731057303, 49.40988738196236, 46.02966867174421, 44.10408312933785, 30.748360020773752, 22.398721933364868, 12.659919210842677, 8.685837967055184, 6.904968636376517, 5.7602724603244235, 3.372009196451732, 6.108904838562012, 0.22473571076989174, 0.13017310281949385, 4.6916108557156155, 26.69640336717878, 34.14337491989136, 19.616274118423462, 33.61812237330845, 40.19975485120501, 45.14479126249041, 40.44083649771554, 6.955686577728816, 0.11836083951805319, 0.04761710077790277, 0.04639038749571357, 0.0687756852379867, 0.013453437647383128, 0.030765313788184097, 0.07420010452291795, 0.06973574443587235, 0.03862368907513363, 0.03921809592949493, 0.028684280812740326, 0.011549715202168694, 0.051840906630137136, 0.047871955138232024, 0.048219873969044, 0.017387144334082092, 0.054865150778953514, 0.043256312276103666, 0.054413928384227414, 0.05281715906624283, 0.038061024088944705, 0.07991753558495215, 0.0016312109073624015, 0.024314975000119636, 0.02786344682265605, 0.007408364077231714, 0.035907611783061705, 0.029220883268862963, 0.014974697892154967, 0.011528754407273871, 0.024412022471161823, 0.045288314311099906, 0.04625230222674353, 0.030195697210729122, 0.018292574677616358, 0.049537066503294876, 0.015540095678131496, 0.028813022654503584, 0.6859723052808216, 12.589608652251107, 35.845951080322266, 53.090042454855784, 42.94216019766671, 30.500809601375035, 20.271734169551305, 33.59989724840437, 37.48424250738961, 8.67431264264243, 0.5708751784903663, 0.030375084906284298, 2.9109167499201636, 4.730866874967303, 8.159841963223048, 11.458408917699542, 9.179252130644661, 6.890876821109226, 16.338200875691005, 30.460510049547466, 45.241089820861816, 48.47237042018345, 48.78216975075858, 46.40749086652483, 45.438224111284526, 47.49452263968331, 47.83838551385062, 44.205085618155344, 42.52508068084717, 35.21528046471732, 32.29676955086844, 31.69973169054304, 31.508187225886754, 31.41136407852173, 35.60319839205061, 41.7776004246303, 45.82263319832938, 46.05928884233747, 44.7782564163208, 46.00111157553536, 42.687439237322124, 41.87012611116682, 41.61238268443516, 42.04379286084856, 43.94627911703927, 46.039319719587056, 46.83964797428676, 47.228799206869944, 45.79699781962803, 44.21686976296561, 45.221082483019146, 47.80713251658848, 44.663635458265034, 41.40132767813546, 35.55445677893502, 33.2805233001709, 33.348650387355256, 34.463134493146626, 34.58870928628104, 32.93441615785871, 34.42492982319423, 34.45983757291521, 34.16383041654314, 34.37141479764666, 36.65697261265346, 39.08533327920096, 44.15860216958182, 43.98985474450247, 49.20737171173096, 30.170092718941824, 39.8574275289263, 48.390822887420654, 44.927587100437705, 46.4856025150844, 47.38252810069493, 46.91297231401716, 44.5152462550572, 43.89170796530587, 35.240738664354595, 35.571354797908235, 33.81546858378819, 35.17894833428519, 35.50342920848301, 35.34909234728132, 41.01457357406616, 43.47182832445417, 46.03314277103969, 50.253377846309114, 44.24156713485718, 47.54292031696865, 47.504104205540244, 39.725484711783274, 37.191268239702495, 37.81941318511963, 39.70259734562465, 40.78481749125889, 44.11364732469831, 46.021619183676584, 45.942152636391775, 42.21254028592791, 35.231025082724436, 33.455315658024375, 36.61403621946062, 41.60881131035941, 47.84091813223702, 48.94829075677054, 48.77644443511963, 48.21373067583357, 45.28495379856655, 44.13619770322527, 42.27406658445086, 42.04052025931222, 41.94965171813965, 44.67745542526245, 48.237378869737896, 49.07805183955601, 50.36612279074532, 46.45864003045218, 44.349191256931846, 31.922087941850933, 19.412486927849905, 13.584270204816546, 8.957075663975306, 7.307651485715594, 6.829649729388101, 2.6895540910107747, 5.8749611633164545, 0.27763964767966953, 0.1458440183528832, 5.726902433804103, 32.55564553397042, 44.99960517883301, 29.25135326385498, 36.38990122931344, 45.40612690789359, 50.921301228659495, 47.86575099400112, 9.32118124621255, 0.18876418098807335, 0.03279135150036641, 0.04883021282564316, 0.06830968095787934, 0.04156075504475406, 0.01425015989557973, 0.04137291280286653, 0.04293461882376245, 0.05788646026381424, 0.03028345893004111, 0.010435305402747222, 0.04679083850766931, 0.01836054353043437, 0.07074687017926148, 0.06923137578581061, 0.0173496383109263, 0.006460853536347193, 0.057223205853785784, 0.05237240989559463, 0.12222483860594885, 0.1615151645881789, 0.16265914748821939, 0.04942961030506662, 0.0996322687715292, 0.07386606173323733, 0.18058924536619866, 0.19509914677057946, 0.06813673595232622, 0.11877025397760527, 0.12970181953694138, 0.09571289444076163, 0.15633127918200834, 0.13855326814310892, 0.1954861017210143, 0.17897579765745572, 0.1210856054510389, 0.140773706138134, 0.10635496981974159, 1.0279594915253776, 16.290397269385203, 43.4080125944955, 61.83559758322579, 48.1916493007115, 37.350628648485454, 25.928123678479874, 40.17180224827358, 43.90225533076695, 10.37033838885171, 0.7969195661800248, 0.23115647052015575, 3.1895197544779097, 7.738662140710013, 12.650346330233983, 14.700465304510933, 16.36910125187465, 9.366088322230748, 16.354645524706157, 29.52856206893921, 45.72013684681484, 50.215788091932026, 48.733118942805696, 46.35700872966221, 45.3124999318804, 48.44207280022757, 50.00956555775234, 46.88608973366873, 43.62403208868844, 37.83098888397217, 34.670291560036794, 33.81334590911865, 33.54793167114258, 34.20985528400966, 38.46419906616211, 43.64813191550118, 48.68835169928414, 46.90443297794887, 45.83277062007359, 48.78022078105381, 44.79529687336513, 42.71047946384975, 43.19887181690761, 44.772093364170615, 45.85410506384713, 48.88736547742571, 49.10753999437605, 48.98362929480416, 48.24478564943586, 45.79621614728655, 46.77402571269444, 48.14959532873971, 47.90821490968977, 43.8835403578622, 37.105162688664024, 35.330658776419504, 34.9452109336853, 37.74908699308123, 35.812078612191335, 35.169950417109895, 35.85784639630999, 35.1834716115679, 36.972327028002056, 34.74509934016636, 37.39610113416399, 40.49532774516514, 46.47356823512486, 46.879266602652415, 52.07408727918352, 32.899953092847554, 40.289449146815706, 50.060238770076204, 49.023362568446565, 48.391559396471294, 49.475686822618755, 47.77270071847098, 46.49977336611067, 45.73313692637852, 37.09610571180071, 37.71270275115967, 35.41972426005772, 37.54025193623134, 37.04971258980887, 36.66469553538731, 43.04202318191528, 44.52845478057861, 49.49760838917324, 52.21971804755074, 44.820348603384836, 47.26588521684919, 49.366318702697754, 43.05500936508179, 40.408961636679514, 38.83933230808803, 41.87845352717808, 43.25718109948294, 48.67154400689261, 49.14368452344622, 48.7117532321385, 45.08332749775478, 39.198651450020925, 35.82514817374093, 38.57443223680769, 42.586183139256065, 50.4282431602478, 51.20743499483381, 50.798821857997346, 50.288073675973074, 47.77538619722639, 45.701369762420654, 45.210594177246094, 45.858715193612234, 45.62390429633004, 46.73765884126936, 50.900248186928884, 52.69637141908918, 51.95515843800136, 47.50755746023995, 45.849995204380576, 34.35014288766043, 24.95867279597691, 15.802484342030116, 16.997767312186106, 14.668227400098528, 10.143697704587664, 9.060615982328143, 10.361224957874843, 0.5195007409368242, 0.293307401239872, 6.932627243655069, 36.09635720934187, 47.37902968270438, 32.10915776661464, 44.7380576133728, 54.12669978822981, 59.61625262669155, 54.845553466251914, 12.612800002098083, 0.43213270764265743, 0.16886591086430208, 0.1632559597492218, 0.11583769348050867, 0.0929026941635779, 0.084986416090812, 0.12376600876450539, 0.2174413236124175, 0.12143173973475184, 0.12092908099293709, 0.1035338519141078, 0.17614139403615678, 0.12513474960412296, 0.16660549358597823, 0.16484591657561914, 0.14197221611227306, 0.13432765060237475, 0.13250015223664896, 0.14137073553034238], [0.042566747670727115, 0.014051086202796017, 0.05731102864124945, 0.051821073051542044, 0.012185597509544874, 0.03384322666430047, 0.050399464155946455, 0.04850451601669192, 0.012063725834845431, 0.00930304334698511, 0.030023549483822923, 0.04902183450758457, 0.023602674382605722, 0.039916746118771176, 0.024915782136044333, 0.06688050300415073, 0.013422274230314153, 0.04289951481457267, 0.05700789312166827, 0.49337111732789446, 8.769692301750183, 28.164484773363384, 44.45900058746338, 36.20106308800833, 39.223192487444194, 39.26580578940255, 29.365824835641043, 30.786887781960623, 8.073949200766426, 0.5403442510536739, 0.7667291547570909, 4.579637595585414, 7.146339067390986, 6.487169546740396, 10.738645894186837, 8.555370773587908, 5.143380556787763, 22.14673682621547, 34.95023448126656, 42.80911609104702, 48.45954404558454, 47.41489628383091, 45.91068771907261, 47.647799900599885, 45.13415357044765, 41.68045418603079, 41.79595409120832, 34.11866365160261, 31.45579433441162, 31.618562834603445, 33.47167866570609, 35.739643641880576, 36.8543118749346, 38.394282817840576, 43.124175207955496, 46.108905928475515, 43.58103663580758, 43.687976360321045, 40.53549528121948, 38.002685819353374, 37.72405958175659, 36.768838609967915, 37.932415212903706, 40.519205229622976, 39.43435519082205, 43.205646310533794, 44.73833554131644, 46.13422516414097, 44.12108884538923, 44.39815868650164, 43.06233276639666, 40.720018591199604, 36.86106899806431, 32.94160406930106, 31.353982380458287, 32.41525718144008, 32.305823053632466, 33.65983935764858, 32.385709966932026, 32.225196157182964, 33.042276518685476, 33.25245952606201, 32.19007996150425, 32.331315994262695, 34.33352279663086, 39.08733436039516, 39.29503338677542, 48.57410594395229, 32.005115440913606, 41.22921732493809, 47.28135885511126, 41.47142457962036, 44.16873959132603, 40.151982511792866, 43.06371545791626, 39.10863406317574, 34.62891503742763, 32.65860741479056, 34.02921601704189, 32.912678718566895, 33.55127028056553, 33.31504889896938, 33.01044682094029, 33.65340185165405, 37.56012031010219, 41.61372021266392, 46.34116336277553, 46.22584063666207, 43.632769448416575, 46.15867587498256, 42.05460773195539, 40.71906668799264, 42.86910683768136, 45.15295886993408, 46.36862959180559, 45.00810282570975, 45.2908285004752, 46.81092759541103, 47.32314879553658, 42.90719338825771, 35.98955297470093, 31.39901712962559, 33.16520404815674, 37.001995835985454, 43.842629364558626, 45.62689202172415, 46.367524828229634, 44.5740384374346, 42.99213859013149, 39.68133238383702, 39.506578241075786, 39.261841842106406, 41.58705302647182, 45.381644930158345, 48.924652985164094, 51.01382344109671, 47.6883669580732, 45.07306848253523, 33.45823390143258, 18.54153197152274, 11.903117946216039, 7.598357166562762, 6.366956157343728, 2.832491998161588, 3.4813588602202277, 5.358411235468728, 0.06658206973224878, 0.06757812521287374, 3.93477224452155, 25.347584315708705, 28.116163526262554, 27.536956480571202, 33.1111991746085, 40.351402759552, 47.23469475337437, 37.40386574608939, 7.777981996536255, 0.13182057227407182, 0.036423047339277606, 0.05706873057144029, 0.012752371873440487, 0.01612169179134071, 0.04186292365193367, 0.08038125998739686, 0.04689417939100947, 0.017319653848452226, 0.013574400933326354, 0.1019507482913988, 0.033599062623190026, 0.03856448350208146, 0.10568260268441268, 0.043836490251123905, 0.05322847342384713, 0.012934504243146096, 0.011981821569081928, 0.051262377495212216, 0.04007463103958538, 0.06663721427321434, 0.04777186783030629, 0.02516328796212162, 0.015079126127862504, 0.016534627847639576, 0.093447245657444, 0.031233984710914747, 0.03139518766797014, 0.03135346115699836, 0.049626392245824845, 0.03013046963938645, 0.019403473906485096, 0.0289675895390766, 0.04466556504900966, 0.015102817178038614, 0.051807512529194355, 0.10175318603536912, 0.07388308617685523, 0.7756123723728316, 11.002647042274475, 34.170375619615825, 51.991132736206055, 40.55796922956194, 43.80651610238211, 38.08852733884539, 36.69934620176043, 36.81965773446219, 8.905890890530177, 0.4629270423735891, 0.8758590274623462, 2.102999976703099, 2.7097874624388556, 8.041151097842626, 10.201905369758606, 7.320383191108704, 6.773736272539411, 15.035187823431832, 33.63357169287545, 44.40341847283499, 50.98191383906773, 47.31523132324219, 46.17801965985979, 47.57306507655552, 46.66251754760742, 44.451124804360525, 44.2876649584089, 36.47513825552804, 32.3088698387146, 32.95122037615095, 33.7066285269601, 36.37149545124599, 38.36494057519095, 40.11155441829136, 44.00342457635062, 47.18322597231184, 42.55909906114851, 45.66187967572893, 42.763261454445974, 40.972248622349326, 40.0256746837071, 39.311990465436665, 39.967594691685264, 40.76334408351353, 41.84678363800049, 45.72299950463431, 47.000880922589985, 46.81128542763846, 47.04453298023769, 46.85753263745989, 45.10393238067627, 43.15303455080305, 38.609680448259624, 34.5121887751988, 32.70517771584647, 33.39852803094046, 33.97013201032366, 35.218719823019846, 33.706430503300254, 33.84879214423043, 34.98726143155779, 34.012359687260215, 34.10720607212612, 34.280508041381836, 35.39646863937378, 41.05745438167027, 41.23354605266026, 50.09340252195086, 33.510487828935894, 41.77622468130929, 48.86959893362862, 42.96634687696184, 46.310716356549946, 43.550353390829905, 45.82004846845354, 42.45614412852696, 37.32345771789551, 33.38292237690517, 35.440033844539094, 34.44788319723946, 35.054787499564036, 35.12319598879133, 34.01884583064488, 35.06517505645752, 40.84397097996303, 43.43628828866141, 48.95281750815255, 45.57160867963518, 43.60114124843052, 46.52368211746216, 43.48389387130737, 43.67372213091169, 43.695094789777485, 44.99447046007429, 47.40831633976528, 48.71286146981375, 48.42069666726248, 48.816195079258506, 49.05613374710083, 45.260100092206685, 36.70534597124372, 33.32170874731881, 34.85027422223772, 40.40258319037301, 45.99033144542149, 48.62937191554478, 47.84770999635969, 44.91461133956909, 44.89486108507429, 42.03027861458914, 42.309582301548545, 40.74244737625122, 42.906793866838726, 48.91412993839809, 51.76519816262381, 52.55199480056763, 48.69841616494315, 45.88350984028408, 36.18521772112165, 19.193471023014613, 11.287404196602957, 9.080711041178022, 10.802055154527936, 5.05500077349799, 3.8958223802702765, 5.886250683239528, 0.01767816291456776, 0.11169030424207449, 4.5259623272078375, 29.78261947631836, 36.304275103977744, 30.315640108925955, 39.12125546591622, 47.841651167188374, 53.258185386657715, 44.37177290235247, 9.892555935042244, 0.1260610856115818, 0.039520196683172665, 0.03983812765883548, 0.012359081102269036, 0.02257283803607736, 0.03414701357749956, 0.060544743335672786, 0.05521792113514883, 0.032731179014912674, 0.06537089150931154, 0.048853059099721055, 0.010260506300255656, 0.01824163196475378, 0.07063830457627773, 0.0072868528742609275, 0.10760225289102111, 0.026897850779018233, 0.03130054560356906, 0.02236887889115938, 0.14250448612230165, 0.09764353012932198, 0.11062786768057517, 0.10941367676215512, 0.1035100081935525, 0.101976953313819, 0.1576498355716467, 0.19828819350472518, 0.19452860738549912, 0.05398151158754315, 0.16172681323119573, 0.1236806083470583, 0.0934135631791183, 0.14247184858790465, 0.10151378531008959, 0.08221869889114584, 0.0991275269272072, 0.09788598426218544, 0.12076188996434212, 0.993154336299215, 15.733360188347952, 42.66660853794643, 56.54701096670968, 46.18249429975237, 45.110324723379954, 45.94066572189331, 39.83816712243216, 39.31503030232021, 11.459563187190465, 0.8762188138706344, 1.263653352856636, 6.74046265227454, 13.608919807842799, 14.262723582131521, 17.91158049447196, 16.221846342086792, 10.526999422482081, 24.469747168677195, 37.337416648864746, 44.76294258662632, 51.60296467372349, 48.35294130870274, 46.81480816432408, 49.850938183920725, 49.269307953970774, 48.100527150290354, 46.63034738813128, 37.79605334145682, 33.79472126279558, 34.812587193080354, 36.65144532067435, 39.70208665302822, 42.00844737461635, 42.17302935464041, 47.11678729738508, 48.650650773729595, 43.51432350703648, 46.51392337254116, 44.23441049030849, 43.059629917144775, 43.110848563058035, 41.35504225322178, 42.10822350638253, 44.11287954875401, 43.977962902614046, 46.7426997593471, 49.06525673185076, 49.69622264589582, 48.45407928739275, 48.24930892671858, 47.363986832754954, 44.85097973687308, 41.84434134619576, 36.11398826326643, 34.93881164278303, 35.51326090948922, 36.50804492405483, 36.55831861495972, 35.97636181967599, 35.445821693965364, 37.577932017190115, 34.80053901672363, 35.28212908336094, 35.673878942217144, 37.3612003326416, 43.83304779870169, 43.71333033697945, 51.53156498500279, 37.21205030168806, 42.256091594696045, 50.08028432301113, 44.338619572775706, 48.16623626436506, 45.85756179264614, 46.75020728792463, 44.92575625010899, 38.75586707251412, 35.048568861825125, 37.96309845788138, 36.60926628112793, 36.659880433763774, 37.04071467263358, 35.99574729374477, 37.484332833971294, 41.73713411603655, 45.80118063517979, 51.452619552612305, 48.2207796233041, 43.84350483758109, 49.73942307063511, 46.986206327165874, 46.04935639245169, 47.10002129418509, 48.32536390849522, 49.96534027372088, 47.789675167628694, 49.31759098597935, 49.44291911806379, 51.20601061412266, 46.94856793539864, 38.432834897722515, 35.51161418642317, 36.95592927932739, 40.641059262411936, 48.09592396872384, 50.17994928359985, 49.85832411902291, 49.02573537826538, 47.830485412052695, 43.49491718837193, 44.480616433279856, 43.01986885070801, 45.778949873788015, 51.27981090545654, 53.32942526681082, 54.51003885269165, 50.27379512786865, 48.58747427804129, 37.96595764160156, 21.964270183018275, 14.070317540849958, 14.94518780708313, 14.618292433874947, 9.846358231135778, 7.905933942113604, 8.766565612384252, 0.18228980340063572, 0.22236067535621779, 5.1766237786837985, 34.79438986097063, 40.498398848942344, 38.80175297600882, 45.64404017584664, 53.36122717176165, 59.79088865007673, 51.66780178887503, 12.90779185295105, 0.31819614714809824, 0.0683392718700426, 0.15603998409850256, 0.1619254204311541, 0.18499010136084898, 0.1325493731669017, 0.21593340166977473, 0.12021575069853238, 0.1142224408686161, 0.10485855583101511, 0.20112256998462336, 0.13292973275695527, 0.10691471371267523, 0.18976020254194736, 0.13087489801858151, 0.29235715365835596, 0.07973762202475752, 0.13006917839603765, 0.09319081370319639], [0.05193969454350216, 0.04753708453582866, 0.010383367787913551, 0.03266461472958326, 0.04781427626897182, 0.06052041785525424, 0.02271254500374198, 0.06834360770881176, 0.031204020604491234, 0.030252093648804084, 0.039613213656204085, 0.02789940917864442, 0.046191909217408726, 0.02597495833677905, 0.03947074844368866, 0.03569996649665492, 0.029832606336900165, 0.08455032163432666, 0.06363627101693835, 0.37852656841278076, 7.704825282096863, 26.57143133027213, 41.72649989809309, 37.26310566493443, 25.142596823828562, 17.7535628250667, 29.406930378505162, 34.277495997292654, 10.984513981001717, 0.37123136701328413, 0.8097807360546929, 3.3089766587529863, 0.6079908268792289, 4.467626988887787, 11.27902466910226, 4.926234585898263, 4.63801201752254, 15.320835215704781, 30.26365716116769, 44.226996762411936, 44.8515807560512, 47.375607694898335, 49.29636771338326, 46.5207326071603, 42.10289076396397, 40.76527220862252, 34.131503922598704, 32.08727094105312, 32.051762172154014, 35.30477326256888, 40.500441619328086, 43.36337389264788, 42.04067311968122, 42.85701697213309, 45.24468551363264, 44.89109863553728, 46.03466442653111, 43.37041589191982, 40.284415176936555, 37.983553954533164, 35.24713448115757, 32.30035482134138, 33.19426836286272, 35.77859871728079, 38.10060330799648, 39.257280349731445, 41.213288579668315, 42.52493824277605, 43.48708656855992, 41.80140495300293, 38.20599011012486, 36.279331071036204, 31.75762060710362, 32.634740352630615, 32.01667724336897, 32.19909177507673, 32.42749643325806, 30.634353978293284, 32.14155374254499, 32.57858501161848, 32.23048721040998, 32.96088532039097, 33.72804287501744, 34.691806656973704, 35.25330795560564, 41.32853487559727, 41.18221623556954, 45.463717051914756, 28.682505982262747, 43.214960370744976, 45.68406179973057, 40.502988134111675, 38.25443295070103, 36.55652250562395, 35.915314946855815, 33.34640959330967, 32.795361859457834, 32.96505423954555, 33.42927033560616, 31.98535476412092, 34.284141949244905, 32.60634306498936, 33.00926910127912, 32.32052891595023, 35.083084038325715, 41.58073711395264, 44.756873335157124, 46.56966182163784, 44.307661873953684, 44.88866676603045, 46.580334254673545, 44.13032994951521, 46.23221213476998, 44.58639233452933, 47.818815912519185, 45.401839869362966, 46.56544426509312, 45.152437755039756, 48.30951854160854, 45.869846207754954, 43.47312068939209, 37.93751171657017, 32.782987117767334, 31.7150559425354, 35.782375063214985, 39.10142878123692, 41.33323185784476, 41.33329439163208, 41.8846686908177, 38.76832866668701, 37.178309849330354, 37.686949253082275, 41.12298631668091, 45.759286471775596, 47.59413896288191, 48.73378944396973, 49.87962729590279, 43.14652756282261, 35.52055304391043, 16.286329099110194, 14.625339644295828, 5.427574472767966, 8.48311037676675, 5.847419806889125, 3.482098626238959, 6.584177255630493, 0.08311462295906884, 0.2962544416742665, 4.459466329642704, 26.80144623347691, 37.49497052601406, 28.095503057752335, 28.40303032738822, 39.895204884665354, 46.56028175354004, 32.2648286819458, 4.924284747668675, 0.2468391518507685, 0.11363440206540482, 0.041340109027389965, 0.023780721971499066, 0.05463225720450282, 0.06597745431853191, 0.03234652090551598, 0.00802655443216541, 0.025835185211950114, 0.016392657965687767, 0.043035523766385655, 0.005542802441466067, 0.04307349119335413, 0.04218061714033995, 0.01984648942016065, 0.036669087529714615, 0.055863296147435904, 0.04056046550561275, 0.08691473118960857, 0.03027509937861136, 0.06066947842815092, 0.03782894475651639, 0.023932316872690405, 0.014713818140860115, 0.037216102105698416, 0.025600108451076915, 0.11853568442165852, 0.004931246038592819, 0.034992532671562264, 0.04063933502350535, 0.021101694387782897, 0.04776084163625326, 0.030617311729916503, 0.0702527609786817, 0.049212041444012096, 0.01944050325879029, 0.014073383711677576, 0.07370737274842602, 0.4983781629375049, 10.456119980130877, 32.490669454847065, 47.663989203316824, 41.53686271395002, 30.699281420026505, 23.61711287498474, 32.432631152016775, 37.219137464250835, 12.24659172126225, 0.3941230757960251, 1.4050894720213754, 1.9158406938825334, 2.4530111380985806, 7.8608957188470026, 10.352590084075928, 7.368778262819562, 7.810319781303406, 17.423175982066564, 31.685331548963273, 45.44389384133475, 46.03771815981184, 48.60349334989275, 48.959529467991416, 48.319947787693565, 44.96419715881348, 43.33292688642229, 36.93463652474539, 33.98863158907209, 32.99040126800537, 35.503748825618196, 41.62829058510916, 44.923445974077495, 44.054153374263215, 43.848778520311626, 47.021193981170654, 45.56212786265782, 46.929575034550254, 45.08208377020699, 41.30213519505092, 40.8029522895813, 38.276142597198486, 35.887824399130686, 35.90261363983154, 38.319138050079346, 39.496235847473145, 42.990703787122456, 43.54877962384905, 43.96974318368094, 44.70162125996181, 43.622479166303364, 41.898248944963726, 38.033772059849326, 34.01216513769967, 34.18606465203421, 33.08864879608154, 33.84787845611572, 33.91782249723162, 33.253800528390066, 34.47836494445801, 34.831805910382954, 34.28802599225725, 33.76890523093087, 34.877716132572715, 36.67088638033186, 38.47878680910383, 42.74486609867641, 42.824978828430176, 49.748386246817454, 30.759459768022808, 44.100622926439556, 48.332048075539724, 43.09413119724819, 40.1071457862854, 38.73123223440987, 38.09354393822806, 34.90703753062657, 33.826783725193565, 33.76723766326904, 35.14191096169608, 34.250047138759065, 35.23249462672642, 33.75277498790196, 34.41655029569353, 34.213148730141775, 37.249167578560964, 43.62366730826241, 46.45873383113316, 49.617648942129954, 44.14067234311785, 46.85585812159947, 47.874613421303884, 46.46127339771816, 48.3990148135594, 46.80696712221418, 49.240434714726035, 45.759321212768555, 47.011185101100374, 45.84595135280064, 48.10258034297398, 48.21249737058367, 44.374718938555034, 38.43890414919172, 33.32490144457136, 33.271455901009695, 38.242989267621724, 42.3066987991333, 44.282426016671316, 45.20556715556553, 44.18919856207711, 42.229869093213765, 38.41141012736729, 39.078881876809255, 42.847803660801475, 48.69136026927403, 50.27394104003906, 50.18294048309326, 50.165399755750386, 45.0494168145316, 34.82602848325457, 20.116454090390885, 10.049434099878583, 9.285949536732264, 11.029991677829198, 4.262765433107104, 5.451243077005659, 7.779331684112549, 0.08068092819303274, 0.25363305157848764, 5.028286686965397, 30.201529843466624, 38.54188687460763, 30.557409627096995, 34.16877058574131, 45.04098170144217, 54.128085953848704, 38.76719958441598, 8.110230088233948, 0.21155534445175103, 0.0551241577735969, 0.06808314525655337, 0.06054795959166118, 0.018846104886116724, 0.06632374466529914, 0.018562341541317955, 0.014363726301650916, 0.017769658272819858, 0.04177772679499217, 0.011688010816994523, 0.03933604567178658, 0.03395831298881343, 0.04345753862123404, 0.02438097440504602, 0.07966774648853711, 0.006896211358252913, 0.022577129770070314, 0.01399641833268106, 0.09682700822928123, 0.1343912836164236, 0.11877813855452196, 0.1402830710368497, 0.12961588986217976, 0.1855218963963645, 0.09293896186032466, 0.19115855464977877, 0.07910545808928353, 0.11466150730848312, 0.13278456697506563, 0.1035320470109582, 0.1310857052781752, 0.0850816552660295, 0.10737621930560895, 0.07217537638332162, 0.08801412755357367, 0.17720716898994787, 0.2718092133956296, 0.6611817298190934, 13.519229854856219, 40.556565693446565, 54.56009714944022, 47.29357378823416, 35.31633506502424, 26.981977803366526, 39.32683529172625, 42.83311864307949, 14.33061443056379, 0.8710971772670746, 1.4238643731389726, 5.606699900967734, 2.787224701472691, 14.03065982886723, 21.04040469442095, 9.32113434587206, 12.1302467414311, 17.280157736369542, 31.190873418535503, 44.9336702483041, 46.50094761167254, 48.48819146837507, 51.17898212160383, 50.865020820072715, 46.29283169337681, 46.030888080596924, 38.09563534600394, 36.79809400013515, 36.19329500198364, 38.4474504334586, 44.285410267966135, 47.04405008043562, 46.7468513080052, 46.919184003557476, 49.40541621616909, 46.09668057305472, 47.79356268474034, 48.699531350817, 44.4426132610866, 42.962101527622764, 39.27155889783587, 36.86735364368984, 37.84123747689383, 40.59047985076904, 42.458270277295796, 44.37929432732718, 45.087541580200195, 46.02576378413609, 46.407734053475515, 45.568266596112935, 43.021067414964946, 38.9460323197501, 35.30423477717808, 36.51416628701346, 34.467438902173726, 35.86393301827567, 35.72751208714077, 32.635254519326345, 35.78588390350342, 36.900604248046875, 36.18204934256417, 35.86589935847691, 36.99484961373465, 38.98140907287598, 40.21846635001046, 44.97271565028599, 46.96275615692139, 50.75626761572701, 34.36075278690883, 46.666749000549316, 50.78033964974539, 45.77282503673008, 41.03525141307286, 40.482838358197895, 40.471696921757285, 36.506214073726106, 35.532966000693186, 35.55306713921683, 37.111405645098, 36.30816262108939, 36.6750796181815, 35.783351285117014, 36.32471323013306, 35.5327228137425, 38.880545548030305, 44.87608357838222, 49.199711322784424, 51.64619289125715, 44.43596036093575, 47.118256841387065, 49.85911621366228, 48.40369095121111, 50.12227576119559, 48.53307335717337, 48.26653698512486, 46.59985521861485, 47.91699743270874, 46.09629842213222, 48.225511346544536, 48.854476179395405, 46.04022993360247, 42.38425806590489, 36.5485702923366, 35.07824114390782, 39.478132316044395, 43.581318037850515, 45.645332540784565, 46.8484582901001, 46.32317795072283, 44.24398858206612, 41.407396929604666, 42.162527152470176, 45.64669438770839, 51.09629855837141, 53.34390878677368, 52.686890602111816, 51.39326804024832, 45.93255370003836, 37.78482852663313, 19.966694355010986, 17.89781437601362, 10.829987781388418, 14.694983175822667, 10.655389973095485, 8.916855147906713, 8.025640981537954, 0.23394937493971416, 0.4016128810388701, 6.411265254020691, 35.41454437800816, 48.224114758627756, 36.57318081174578, 39.4358560017177, 52.075313636234824, 61.765816824776785, 46.48058591570173, 10.708850281579153, 0.38257394837481634, 0.20845522651714937, 0.11212348778332983, 0.13322007789143495, 0.13710162389491284, 0.22332665137946606, 0.17328466661274433, 0.10389768239110708, 0.09974006762994186, 0.23990460538438388, 0.14760341894413742, 0.11674792106662478, 0.18685918035251753, 0.11228221069489207, 0.0794694989121386, 0.1139631454965898, 0.15485203212925366, 0.09807159751653671, 0.15266617227877888], [0.03842985536903143, 0.030077116430870125, 0.029398656051073755, 0.05025609309918114, 0.07975167448499373, 0.10046309418976307, 0.044609429846916876, 0.027253638919708983, 0.03411333788452404, 0.018944986098046814, 0.03119690277214561, 0.10298389928149325, 0.04492574590923531, 0.015031845807763082, 0.03574421037254589, 0.08017323472137962, 0.022277431030358587, 0.03667684657765286, 0.021123387152329087, 0.0804895202496222, 5.748761032308851, 25.42893556186131, 43.32226834978376, 41.28166232790266, 36.303410053253174, 29.18378550665719, 31.751613889421733, 36.460508823394775, 12.450814042772565, 0.791327243404729, 0.2863187076789992, 2.362542769738606, 1.8604837443147386, 7.688926066671099, 5.330139883926936, 6.1524552788053235, 5.804420011384146, 16.932975360325404, 36.45064238139561, 44.617002623421804, 48.14295979908535, 49.207670484270366, 46.764975684029714, 43.40702595029558, 40.15394190379551, 36.15587895257132, 33.20803969247, 31.852185589926584, 33.03957714353289, 41.01323257173811, 44.095519474574495, 42.04065922328404, 42.024904182979036, 46.037766797201975, 45.29710619790213, 42.427878856658936, 43.43484306335449, 42.871858324323384, 38.40805414744786, 36.542188371930806, 32.708992276872905, 32.36737367085048, 31.283510276249476, 31.516330514635357, 30.991491385868617, 33.40115792410714, 35.608468600681846, 38.549199853624614, 36.56598595210484, 37.11239576339722, 32.004333768572124, 33.34205307279314, 31.278285230909074, 30.384983130863734, 32.9413435118539, 32.63174220493862, 31.956749030521937, 33.13250582558768, 32.43458706992013, 37.647879532405305, 37.33300454275948, 41.08804382596697, 38.67432301385062, 41.02495765686035, 38.11980465480259, 43.74925947189331, 40.76878799710955, 49.52119057519095, 30.90756756918771, 41.372888701302664, 45.72066838400704, 40.424747943878174, 34.99841676439558, 33.13966594423567, 31.65824399675642, 32.24754156385149, 31.480088710784912, 33.43236575807844, 32.83882631574358, 34.38022858755929, 33.73815597806658, 34.87516614368984, 33.52172654015677, 32.78841366086687, 34.3959766796657, 38.3377731187003, 43.651213441576274, 45.443727084568565, 46.94288430895124, 42.8289601462228, 43.55036728722708, 47.2260616166251, 45.28040272848946, 47.14832864488874, 46.823861667088096, 46.302979537418906, 45.56386143820626, 47.19579873766218, 45.73773315974644, 46.87957927158901, 47.14855793544224, 44.112730162484304, 41.32670055116926, 36.835544790540425, 31.639122554234095, 30.140211990901403, 32.908725193568635, 34.35305765696934, 37.276720660073416, 34.73486464364188, 35.13841949190412, 36.74735477992466, 40.41329036440168, 45.1717745917184, 46.76347834723336, 49.77965314047677, 49.38342864172799, 44.07101665224348, 36.900242941720144, 19.36569254738944, 6.196238049439021, 9.507591860634939, 11.497285825865609, 2.238851372684751, 4.665047023977552, 10.042834179741995, 0.04341402756316321, 0.13669542569134915, 4.826174012252262, 26.361731222697667, 39.69045189448765, 39.0450302532741, 34.9015554019383, 44.65906006949288, 40.80152790887015, 29.724317141941615, 5.147140400750296, 0.08477187010326556, 0.05473346748788442, 0.02804994217253157, 0.007544214421484087, 0.03408700394045029, 0.03965642615886671, 0.04141257656738162, 0.025643575404371535, 0.01967174290413303, 0.007432603044435382, 0.012782190094834991, 0.04773671293099012, 0.02751558905999575, 0.011158232726821942, 0.07393092289566994, 0.013788140312369381, 0.023240116158766404, 0.021315941819921136, 0.06490290590694972, 0.04406246955373457, 0.04725047812930175, 0.04609577776864171, 0.06796439484293972, 0.010361911662455116, 0.028777966142765114, 0.006068962243651705, 0.012719870894216001, 0.005232734414416232, 0.04657433833926916, 0.05645450370918427, 0.051403899544051716, 0.036408455443701575, 0.07061059999146632, 0.05296849273145199, 0.08172128522502524, 0.03224009608051606, 0.027218580711632967, 0.029167662374675274, 0.06883966430489506, 7.404195836612156, 31.077690737588064, 51.56962374278477, 45.51500170571463, 37.047916480473106, 31.486335141318186, 37.01691014426095, 39.72748579297747, 14.984943662370954, 0.8237930813005993, 0.5190428655062402, 1.4305798070771354, 1.9387892910412379, 5.203400833266122, 7.487194674355643, 10.003721032823835, 7.743493744305201, 18.67854002543858, 34.14813791002546, 46.10192993709019, 46.70516906465803, 48.44607496261597, 49.29506492614746, 45.50838007245745, 42.779700892312185, 38.89637354442051, 34.00529336929321, 33.981738976069856, 33.82778773988996, 43.21481793267386, 45.732848576136995, 44.312001023973735, 44.518894059317454, 47.7926663671221, 45.688157762799946, 41.701962334769114, 43.432574476514546, 44.536792618887766, 39.963721070970806, 38.536227566855295, 34.48752614430019, 34.33881732395717, 32.77198117119925, 33.3076525415693, 33.32137870788574, 36.164630208696636, 37.41794974463326, 41.7534623827253, 39.29990407398769, 38.88020508629935, 35.13786711011614, 34.659504481724326, 32.46403700964791, 32.700710024152485, 32.651058197021484, 34.00818034580776, 33.99351964678083, 34.48325300216675, 33.816656725747244, 37.408135414123535, 38.01293093817574, 41.8380879674639, 41.15174143654959, 42.97388914653233, 39.480946336473735, 46.004811491285054, 42.32877670015608, 49.61209385735648, 32.69503682000296, 43.183634417397634, 48.11041096278599, 41.16014180864607, 37.71655205317906, 35.43667786461966, 33.8662668636867, 33.63749395098005, 33.55682536533901, 34.79937866755894, 34.484305654253276, 35.167591503688264, 35.44016586031233, 35.443514892033164, 34.97745752334595, 35.25489909308297, 36.240528856004985, 41.49647978373936, 45.66341870171683, 48.135327202933176, 47.49747214998518, 41.93600198200771, 44.0302619934082, 47.31832674571446, 46.17853035245623, 46.16140651702881, 47.07727289199829, 48.30034691946847, 48.187789576394216, 48.70017753328596, 46.45504781178066, 46.92345714569092, 50.49284403664725, 45.36006382533482, 41.83300188609532, 37.29558154514858, 32.94154500961304, 32.93847043173653, 35.77368981497628, 36.52034670966012, 39.51452350616455, 35.812808173043386, 37.90287494659424, 39.20029469898769, 42.88288164138794, 46.218437331063406, 49.37406594412667, 51.03820814405169, 51.299408299582346, 43.888668128422324, 38.817851952144075, 18.882942131587438, 10.746768338339669, 6.434113536562238, 8.76801518031529, 6.213621139526367, 7.162088896547045, 12.300870180130005, 0.0938709093523877, 0.2772333680519036, 5.524326401097434, 30.139287880488805, 38.81382199696132, 39.57140145983015, 39.666240896497456, 48.9433262688773, 48.83938816615513, 34.75018194743565, 6.838837853499821, 0.0790555721947125, 0.020170086163229177, 0.08330564413751874, 0.03072528022208384, 0.03344220229025398, 0.05054268593500767, 0.018410722891400968, 0.0304220734563257, 0.03765708201431802, 0.03390896992225732, 0.0298708926753274, 0.05271490044625742, 0.023074470493676405, 0.018031228433496187, 0.0273694987741432, 0.00444442727270403, 0.026883545564487576, 0.01597115540477846, 0.033224643607224734, 0.18533360292868956, 0.14979708194732666, 0.11730674893728324, 0.0824089872517756, 0.21417290185179028, 0.15955878528101103, 0.12976565611149582, 0.07587362293686185, 0.08490501224462475, 0.11084448998527867, 0.1080644302336233, 0.16200229844876698, 0.07595245513532843, 0.11012936835842473, 0.13802992765392574, 0.1000286146466221, 0.10134841275534459, 0.10661947634071112, 0.11770571395754814, 0.3230056847844805, 9.420702031680516, 36.30797501972744, 58.71320915222168, 51.68374443054199, 45.47550119672503, 39.27740928104946, 40.61526754924229, 46.63803209577288, 17.5347831589835, 1.4901226120335715, 0.7348470741084644, 3.4410011172294617, 4.887149231774466, 12.863622154508318, 11.310370598520551, 16.52859193938119, 11.261149559702192, 19.755899906158447, 39.96331460135323, 45.33712434768677, 48.519024099622456, 47.604759284428184, 51.15357255935669, 47.62677812576294, 45.99956560134888, 39.85784442084176, 36.90151098796299, 35.5571665763855, 36.1948687689645, 45.673500537872314, 48.07074022293091, 46.01801306860787, 44.071218150002615, 48.44356318882534, 46.12916687556675, 42.58513396126883, 46.964830194200786, 47.572561332157676, 43.06225633621216, 41.17907912390572, 36.65830666678292, 35.38120692116873, 33.963868209293906, 34.81737102781023, 34.61029386520386, 37.035791873931885, 38.793772969927105, 42.81231573649815, 41.18503720419747, 41.805535657065256, 35.841834272657124, 37.409479890550884, 34.25571339470999, 34.22912958690098, 35.48512765339443, 35.602038042885916, 35.36669560841152, 36.65783766337803, 36.07193429129464, 39.96524272646223, 41.06375987189156, 45.25484377997262, 42.690201146262034, 44.88534900120327, 42.12575728552682, 47.760030678340364, 45.751302991594585, 50.88118927819388, 34.861210686819895, 45.392355578286306, 49.373555251530235, 44.6545923777989, 38.55046442576817, 37.74965327126639, 34.95447288240705, 36.99487393242972, 34.4038142476763, 38.414321422576904, 35.41977289744786, 37.15662104742867, 36.98653609412057, 37.20666197368077, 37.610706669943674, 36.345318113054546, 38.461082799094065, 41.88965054920742, 48.486291136060444, 48.69419166019985, 48.31368398666382, 42.908492701394216, 44.05214881896973, 48.50096920558384, 46.46455989565168, 47.78224059513637, 48.85573032924107, 50.33535616738455, 49.76183795928955, 50.63710948399135, 46.91595309121268, 47.260879039764404, 51.93684993471418, 46.1451928956168, 46.06050477709089, 39.51581934520176, 34.79497698375157, 33.4051844051906, 37.010288511003765, 37.20401471001761, 41.626279081617085, 38.15392030988421, 39.67579814365932, 41.683080605098176, 44.2835168838501, 49.835707732609336, 53.6315781048366, 55.281921182359966, 53.17379951477051, 46.33371489388602, 42.57637575694493, 20.957300765173777, 9.207820517676216, 13.237685373851232, 20.39794819695609, 7.246311920029776, 9.012596981866018, 13.285013028553553, 0.15019296641860688, 0.43085670896938866, 6.713955274650028, 36.5218996320452, 50.85902452468872, 49.71827275412423, 46.158057485307964, 56.652887616838726, 55.38667917251587, 41.85140766416277, 9.656070521899633, 0.23411675595811435, 0.17517852570329392, 0.11343059728720359, 0.1082499281370214, 0.19098216268633092, 0.2048215629266841, 0.10331558755465917, 0.1198168263903686, 0.13696531978036675, 0.16277292424014636, 0.10964380191372973, 0.20083863022071974, 0.08202579138534409, 0.05604501800345523, 0.16499879051532063, 0.09625614993274212, 0.14810097510261194, 0.09571866198842015, 0.13194266786532743], [0.015531741215714386, 0.042095393141997714, 0.02491598400021238, 0.06669253523328475, 0.03414002127413239, 0.022975385721240724, 0.017519343311765363, 0.02772686111607722, 0.053112304835979424, 0.039703234897128174, 0.06376207819474594, 0.05492196451606495, 0.04707808612978884, 0.021666038748142973, 0.028729864795293127, 0.042791970406791995, 0.008350725385493465, 0.08556378832353012, 0.029293679898338656, 0.018657850434205363, 4.072762165750776, 17.676288434437343, 42.93174832207816, 42.51973751613072, 33.85223497663225, 16.17865286554609, 25.571149553571427, 33.19849286760603, 14.878874199731008, 0.7771297938057354, 0.11586497058825833, 1.6642051679747445, 3.763481778757913, 3.2871723430497304, 8.52532502583095, 6.193380602768489, 8.303157244409833, 19.161441564559937, 29.014371054513113, 42.284784180777415, 45.55889695031302, 48.1420704296657, 44.65872655596052, 42.32339532034737, 38.772268295288086, 33.51526471546718, 30.927220548902238, 31.407528672899517, 38.341740540095735, 43.936579431806294, 45.693282059260774, 41.25639520372663, 44.1483223097665, 43.1373906816755, 42.66896745136806, 43.668476240975515, 43.803312982831685, 41.5225806917463, 38.46527256284441, 38.69530309949602, 35.120302064078196, 31.100512095860072, 31.753066062927246, 32.29067598070417, 32.31595352717808, 30.355831963675364, 32.97712673459734, 31.791204724993023, 30.5016816002982, 30.35811444691249, 31.388653891427175, 29.568812983376638, 32.94681521824428, 35.46874032701765, 31.56238317489624, 32.55374520165579, 33.64677674429757, 33.91758973257882, 38.368042945861816, 42.55577087402344, 43.182863167354036, 43.266797406332834, 43.18862322398594, 43.336522579193115, 44.191717284066335, 45.633214882441926, 45.740884167807444, 43.70412744794573, 24.656266348702566, 42.20241328648159, 45.34396137510027, 40.21369293757847, 35.74330881663731, 32.89360591343471, 34.58367531640189, 33.00242859976632, 32.97471570968628, 33.6490592275347, 31.585645743778773, 33.87245423453194, 31.995724950517925, 33.16918536594936, 33.30202450071062, 33.24875266211373, 34.90712785720825, 36.83903278623308, 43.01082577024187, 46.743168762751985, 47.147352422986714, 46.67296069008963, 45.665107113974436, 44.79319851739066, 45.10745511736189, 46.59632553373064, 47.60202864238194, 45.311138084956575, 42.287441866738455, 43.70697620936802, 46.372576168605256, 45.15657888139997, 44.842624528067454, 48.40990611485073, 47.20183672223772, 46.965163707733154, 41.00054516111101, 33.298407963344026, 31.949894632611954, 33.93912220001221, 34.77510166168213, 36.01729713167463, 35.372452190944124, 35.74993044989449, 39.806254046303884, 45.430539403642925, 46.70282404763358, 48.18020214353289, 51.23240334647042, 45.11939559664045, 36.544279779706685, 18.92522018296378, 10.714776226452418, 6.878567653042929, 7.165351944310324, 3.175016475575311, 5.298598536423274, 8.493085384368896, 0.04861440137028694, 0.20908207073807716, 4.975183776446751, 27.31058243342808, 42.79443802152361, 26.220090457371303, 28.376505579267228, 40.255979674203054, 47.9651415007455, 33.250454970768516, 5.874382725783756, 0.125286551458495, 0.09270300130758967, 0.03786357379119311, 0.015750144674841846, 0.09340193308889866, 0.041844040022364686, 0.06335968657263688, 0.013964363490231335, 0.02230396174958774, 0.0075276267847844535, 0.015963111372132386, 0.026909616576241593, 0.02193774113298527, 0.07504101975687913, 0.029878102109900544, 0.036451593307512145, 0.00643431645585224, 0.05588038165920547, 0.018768916438732828, 0.046630714421293566, 0.05466362587841494, 0.044205382599362304, 0.013716758428407567, 0.027246709380831038, 0.055210291008864126, 0.029174865023898225, 0.027668809052556753, 0.052018798155976195, 0.021720684565869824, 0.07901152848665204, 0.029261683579534292, 0.03935054935781019, 0.018827319644125443, 0.038754778648061414, 0.03582590938146625, 0.019913599926180074, 0.016685544213812267, 0.024047111427145343, 0.0633206165262631, 5.1016514131001065, 23.8266601221902, 47.378470352717805, 46.51236697605678, 41.337980951581685, 23.63323269571577, 29.360974993024552, 41.64134277616228, 16.747112785066875, 1.3622789063623972, 0.18002588488161564, 1.6639180119548524, 3.471747113125665, 5.738367830004011, 8.600942271096365, 10.66657223020281, 8.587880526270185, 20.98311505998884, 32.59269332885742, 43.05733701160976, 46.90859147480556, 48.911670276096885, 46.103187561035156, 44.66373273304531, 41.385468414851594, 34.91567414147513, 33.40571941648211, 33.12361560549055, 39.95620659419468, 44.800570556095664, 46.919472353799, 42.590352058410645, 44.502850668770925, 43.0288667678833, 42.83791984830584, 43.913716384342735, 44.593430859701975, 44.61566162109375, 41.43651335580008, 39.48317323412214, 36.28626537322998, 33.796197754996165, 32.95926986421858, 32.3465290750776, 33.37795441491263, 32.18378489358084, 34.50937475476946, 33.99261638096401, 32.77026496614729, 31.45178869792393, 32.38421957833426, 31.925593308040074, 33.43859134401594, 36.10544545309884, 33.345280511038645, 33.53278112411499, 34.66396522521973, 34.38872276033674, 38.81102534702846, 43.86339405604771, 45.08668695177351, 46.568928786686485, 43.43607636860439, 44.653654370989116, 46.0106132371085, 46.38365854535784, 47.98821299416678, 46.1804723739624, 26.93686314991542, 44.12178019114903, 47.33770874568394, 42.09517131532942, 37.84367976869856, 34.61827039718628, 35.205014501299175, 33.59073257446289, 34.70881584712437, 35.16809524808611, 34.053315843854634, 34.100066798073904, 33.05613470077515, 34.791607107434956, 34.271916593824116, 34.03760249274117, 36.97449834006173, 39.290037631988525, 44.36183697836739, 48.04725531169346, 49.18794802256993, 48.79195628847395, 46.068095684051514, 45.869752407073975, 46.78498649597168, 47.81187466212681, 48.265084811619346, 46.89632443019322, 44.36734342575073, 46.328000000544954, 48.97321741921561, 46.86507143293108, 45.76203448431832, 49.45956352778843, 48.930579798562185, 46.96696676526751, 41.77495663506644, 33.358819075993125, 33.187323638371055, 35.71397352218628, 36.704341956547324, 37.38497706821987, 37.377288886478965, 37.981479917253765, 42.57512508119856, 47.350309303828645, 48.692600522722515, 49.98038312367031, 51.34652056012835, 45.336436476026265, 39.01616048812866, 20.064158473696025, 9.353751795632498, 5.5639680453709195, 7.921596918787275, 7.180409124919346, 6.467994689941406, 12.535939029284886, 0.04721690760925412, 0.4176995892609869, 6.013688896383558, 31.398954595838273, 44.85874087469918, 33.69943714141846, 34.56839622770037, 47.33209807532174, 53.77701779774257, 38.585663999829976, 7.027264748300825, 0.08787295155759368, 0.044255780787872415, 0.04305295533101473, 0.03947988152503967, 0.06819891011608498, 0.027873124428359524, 0.018650222004258206, 0.0014280805293570406, 0.008795513571905238, 0.03587748482823372, 0.014981213524671537, 0.04641193776790585, 0.030647231731563807, 0.04507120346118297, 0.022800203246463622, 0.03805885277688503, 0.03893262606912425, 0.020448830045227493, 0.014451637298667004, 0.06003087519534996, 0.13843205464737757, 0.11992381779210907, 0.12897390073963574, 0.11960901825555734, 0.15406441582100733, 0.10159033084554331, 0.12410187002803598, 0.09924091012882334, 0.1409565984670605, 0.14339313629482472, 0.15005491168371268, 0.11590622551739216, 0.11431584799928324, 0.11540987715125084, 0.11165698138730866, 0.14767290093004704, 0.12850155894245419, 0.21322350922439778, 0.14108512657029287, 6.472684723990304, 28.28543380328587, 54.194295338221956, 53.72577483313424, 45.22097826004028, 25.130767515727452, 34.73621954236712, 42.68928050994873, 20.59111680303301, 1.6270473961319243, 0.3595087246171066, 1.8448025286197662, 8.8037462915693, 9.343029856681824, 16.059324502944946, 14.667348452976771, 16.91789776938302, 21.472078902380808, 30.550847053527832, 44.85706288473946, 45.69122886657715, 52.987302916390554, 47.89630569730486, 46.840943813323975, 44.0153546333313, 36.94347810745239, 34.92406409127371, 34.036945887974326, 42.697045121874126, 47.81253474099295, 48.81334631783621, 44.14936453955514, 45.88880089351109, 44.94289745603289, 43.74761274882725, 44.97258016041347, 46.52457843508039, 45.8234600339617, 41.947761808122905, 43.24834993907383, 38.39973367963518, 34.957999093191965, 34.92590536390032, 34.721322604588096, 34.71779291970389, 34.31926509312221, 36.268509251730784, 35.215871061597554, 34.45393507821219, 33.70234496252877, 33.9123021534511, 32.392018931252615, 36.40298816135952, 38.671456881931846, 34.53403391156878, 35.42697817938668, 35.93551683425903, 37.18393094199044, 42.392814772469656, 46.45782361711775, 47.31825378962925, 48.63080324445452, 46.83962018149239, 46.95203856059483, 47.77571276256016, 50.48335974557059, 48.54339490618025, 48.77875123705183, 31.831452165331157, 46.502618653433665, 49.088210105895996, 43.88955749784197, 39.35406528200422, 37.12698003223964, 38.90985999788557, 36.908733640398296, 36.177828311920166, 37.880995069231304, 34.50776277269636, 36.46450056348528, 35.60569279534476, 36.631385871342246, 35.38352067129952, 35.64262247085571, 38.20812668119158, 41.97410937717983, 46.160569259098594, 50.438158239637104, 51.93641219820295, 49.974445887974326, 47.95036268234253, 47.266573088509695, 48.78281593322754, 50.19965090070452, 51.37767628261021, 48.69188833236694, 46.402991907937185, 48.5645625931876, 50.69252136775425, 48.0559092930385, 45.936493328639436, 51.20153597423008, 52.06544024603707, 51.22297464098249, 44.464604309626985, 36.88447747911726, 35.285954066685264, 37.6043073790414, 38.4964873450143, 39.544324329921174, 39.710271630968364, 39.75664043426514, 44.41773176193237, 51.80318396432059, 51.22057751246861, 53.15319115774972, 53.54658773967198, 47.084109919411794, 40.7629063470023, 21.92441357885088, 14.504976000104632, 11.66396963596344, 16.618817772184098, 10.949658342770167, 8.82676567350115, 11.059235777173724, 0.1277313945548875, 0.5404251324278968, 7.058049176420484, 35.99246079581124, 54.17687620435442, 38.51267317363194, 40.53104496002197, 53.49644259044102, 60.47077683040074, 45.37958131517683, 9.631142990929739, 0.2641536013356277, 0.1773202536361558, 0.11389016226998397, 0.10441669382687126, 0.20021474441247328, 0.08925919181534223, 0.1686466219169753, 0.13974217006138392, 0.12150160170027188, 0.07404597529343196, 0.10371174343994685, 0.1119354928710631, 0.11393510842961924, 0.16527487284370831, 0.12416977781270232, 0.1626793678317751, 0.10030973170484815, 0.11214026116899081, 0.1334617313529764], [0.030305884512407438, 0.019956993936960186, 0.026757504292098538, 0.007161953237040767, 0.03718953067436814, 0.008331365933242654, 0.013265876997528332, 0.06948728526809386, 0.02895568124949932, 0.027634843285860758, 0.020963013704333986, 0.016605353248970847, 0.07118785687323127, 0.06045948541057961, 0.023638070161853517, 0.015264417078079922, 0.08088692463934422, 0.04899526646892939, 0.07143858234797205, 0.05237156851217151, 2.0105680908475603, 19.83459346635001, 42.33571100234985, 45.86668130329677, 31.880867753710064, 22.795239993504115, 33.29341915675572, 36.53240530831473, 17.319757257189067, 2.7134823841708045, 0.047412932983466556, 0.9641928332192558, 2.8495648077556064, 3.805389404296875, 7.47192861352648, 11.693885973521642, 4.3418771880013605, 14.356566820825849, 25.249588659831456, 41.39397300992693, 46.97844171524048, 47.84604242869786, 42.806145736149375, 40.865024021693635, 35.01512370790754, 31.481123992374965, 32.315776348114014, 35.78265993935721, 43.24924278259277, 45.61055680683681, 43.61980758394514, 44.35111938204084, 43.199181011744905, 44.90096855163574, 44.3633690561567, 44.53315871102469, 44.200465066092356, 44.66760982785906, 40.29565041405814, 37.70147793633597, 36.18296997887747, 33.748595646449495, 30.381971086774552, 31.003306797572545, 31.607126099722727, 31.059482983180455, 31.12999677658081, 29.94521427154541, 31.611461775643484, 30.721126556396484, 31.723668234688894, 30.856352397373744, 40.37892804827009, 42.435646942683626, 30.56192943028041, 32.49426514761788, 31.06325932911464, 34.984374455043245, 40.54771716254098, 46.015522139413015, 47.01335293906075, 47.36360815593174, 46.04972464697701, 46.5287230355399, 43.06622723170689, 44.72115612030029, 39.05508082253592, 38.64294842311314, 27.833985022136144, 36.16408477510725, 47.47641563415527, 37.84307527542114, 37.33788217817034, 34.92641258239746, 37.624248708997456, 38.30716977800642, 39.728118079049246, 36.49725089754377, 32.64475965499878, 32.51086786815098, 33.52835512161255, 32.70859622955322, 33.651654379708425, 33.94649076461792, 32.440871715545654, 33.55049555642264, 37.19448178155081, 43.167976651872905, 45.23453419549124, 45.49393824168614, 46.953681809561594, 46.698689869471956, 45.169964585985454, 41.04049730300903, 40.509873798915315, 40.007522514888215, 39.75216579437256, 38.522240843091694, 40.73588827678135, 45.43610838481358, 47.025352478027344, 44.38069438934326, 45.97255447932652, 46.38773018973214, 45.7392235483442, 40.50785534722464, 32.30287701742989, 33.71150963647025, 35.3233562197004, 34.264798164367676, 35.645162037440706, 34.74778829302107, 39.799361433301655, 42.09890944617135, 45.757837772369385, 48.40222488130842, 51.825560637882774, 44.430151666913716, 35.353091035570415, 17.989148446491786, 7.903041754450117, 2.2320160823208943, 4.988651556628091, 7.199396814618792, 1.4324475697108676, 4.412215539387294, 0.1877881083637476, 0.04917590606159397, 6.194654294422694, 26.315369367599487, 38.291404315403526, 30.772056852068218, 32.56159666606358, 44.79958391189575, 51.16754886082241, 28.978045872279576, 4.06655308178493, 0.007430910099563854, 0.020279359138969864, 0.08126516720013958, 0.014734286149697644, 0.006131340816084827, 0.09575540465967995, 0.014304228958540728, 0.019627190294808576, 0.02894781363595809, 0.021911113722515956, 0.033327652008405755, 0.05967710739267724, 0.09786845770265375, 0.027591347494827848, 0.026609773647838404, 0.0312379744968244, 0.0529787793223347, 0.025102419978273765, 0.07048627201999937, 0.00670541833720303, 0.0660647207072803, 0.026061559761209146, 0.05008461372926831, 0.025045875958832245, 0.014930618561006017, 0.036095569375902414, 0.04593947383442095, 0.013259720988571644, 0.043928435138825855, 0.052922990173101425, 0.03401593078992196, 0.058136887183146815, 0.021392271920506443, 0.03302364117865052, 0.05021449890253799, 0.03718977833964995, 0.04717810219153762, 0.03064796794205904, 0.067835127136537, 2.636882620198386, 22.793803453445435, 47.52682134083339, 50.07889815739223, 34.40436315536499, 23.112354040145874, 34.32008498055594, 40.6807404245649, 19.44711674962725, 2.8098719205175127, 0.06006381128515516, 1.6063580491713114, 4.80734395980835, 4.038780263492039, 7.713391542434692, 11.72914113317217, 7.40365127154759, 16.306560516357422, 28.464898824691772, 41.36850438799177, 48.54736580167498, 49.899686745234895, 45.98365075247628, 43.20811639513288, 38.473749365125386, 33.65680646896362, 34.365505354745046, 36.96102925709316, 44.62764378956386, 47.05392347063337, 44.08207123620169, 44.42668104171753, 45.53275782721383, 45.198393140520366, 46.18030909129551, 45.16542393820626, 45.465019839150564, 45.89681216648647, 42.1615127154759, 38.63749408721924, 38.33445535387312, 34.69056640352522, 31.787529127938406, 32.159219537462505, 32.97856501170567, 33.02881438391549, 31.81238283429827, 31.852154323032924, 32.60407100405012, 31.369143349783762, 33.33233254296439, 31.758426598140172, 42.60912956510271, 43.45676462990897, 32.0194148336138, 33.3246408871242, 32.85245173318045, 35.891545159476145, 42.77957929883684, 47.4189783505031, 48.67106458118984, 47.65146507535662, 46.998615809849326, 47.452885559626985, 44.761889934539795, 45.87690210342407, 40.7690555027553, 40.56070334570748, 30.577608040400914, 38.67027916227068, 49.525765963963096, 39.05046374457223, 38.54531233651297, 35.54906497682844, 38.41817767279488, 39.62491995947701, 39.691431590488975, 39.00539772851126, 33.08464315959385, 32.70974963051932, 35.28725685392107, 34.473706177302766, 35.46910163334438, 35.68568393162319, 34.015274456569124, 35.86757040023804, 39.279747349875315, 45.60609606334141, 48.086463996342246, 47.101518630981445, 48.55916731698172, 48.59648609161377, 47.920690400259836, 44.54744073322841, 42.808487279074534, 42.44810158865792, 42.20088120869228, 40.91339043208531, 43.28808321271624, 47.88242667061942, 47.40089566367013, 45.216201373508994, 46.668093476976665, 49.866186005728586, 48.23255334581648, 41.69114398956299, 33.72639615195138, 35.37301499502999, 36.711734839848106, 36.70132643835885, 37.497273853846956, 37.274601459503174, 41.98448303767613, 45.612394605364116, 48.42744336809431, 50.5316983631679, 53.273766721997944, 45.76872559956142, 37.985158988407676, 21.68702142579215, 11.42222877911159, 6.0870905348232816, 6.393068356173379, 7.808119807924543, 2.964787870645523, 5.274165630340576, 0.2576766588858196, 0.16422165078776224, 7.29212052481515, 29.674818175179617, 45.138030665261404, 30.690266132354736, 36.51998540333339, 50.76969500950405, 57.119549478803364, 35.576913356781006, 5.416704016072409, 0.08298013731837273, 0.042427620850503445, 0.011110535955854824, 0.029163374033357416, 0.020880771867398704, 0.10986938088067941, 0.045038548963410516, 0.020235179723905664, 0.026638519783903445, 0.036525492556393147, 0.0349628433718213, 0.03937270352616906, 0.02985634488452758, 0.03127086987452848, 0.030140288041106293, 0.025560873859961118, 0.020990095733265792, 0.03176458213212235, 0.03121957601979375, 0.12263395451009274, 0.13920832585011209, 0.16051817951457842, 0.13241310976445675, 0.12192086848829474, 0.1121123055262225, 0.1360081240002598, 0.21004184495125497, 0.1164228485098907, 0.1025953022763133, 0.18150562047958374, 0.17936951081667626, 0.19612609595060349, 0.17246890467192444, 0.1061106768569776, 0.08547914107995373, 0.14250878803431988, 0.20541684169854435, 0.12114345734672886, 0.09299646091780492, 3.4688345151288167, 27.701670476368495, 54.54414061137608, 56.072581018720356, 42.97286081314087, 33.52569048745291, 42.36206899370466, 45.90536887305123, 23.626859460558208, 3.9836771403040205, 0.11068305971899203, 2.0968247652053833, 6.175105103424617, 9.626947147505623, 14.754857540130615, 17.85129792349679, 9.244559117725917, 18.721316610063823, 28.95917977605547, 43.57285860606602, 48.28324045453753, 51.47378029142107, 48.94608122961861, 45.58849280221121, 39.903462818690706, 35.47821766989571, 36.62317310060774, 40.27671309879848, 47.37259565080915, 49.54271262032645, 45.69703756059919, 47.26151827403477, 47.14214127404349, 47.143433638981406, 46.950190339769634, 47.101834774017334, 45.72816549028669, 48.098032746996196, 44.13445717947823, 42.668025970458984, 40.331409318106516, 37.57280077253069, 32.95992646898542, 34.559836047036306, 34.174603598458425, 34.82475348881313, 33.525787762233186, 33.15964201518467, 34.247448512486045, 33.64849294934954, 35.209895610809326, 34.25786733627319, 43.487402711595806, 44.61064154761178, 34.194016865321565, 34.93828705378941, 34.455953529902864, 37.51091316768101, 43.796399525233674, 49.82994767597744, 51.93213905606951, 51.441026483263286, 48.53199986049107, 49.18356370925903, 45.51760728018624, 44.985246726444785, 41.10992022923061, 41.137570585523335, 33.36323118209839, 39.52138485227312, 52.19717461722237, 41.00105585370745, 40.74467427389962, 38.31812361308506, 41.55876691000802, 42.14241559164864, 42.39020919799805, 40.928610461098806, 35.33827747617449, 36.03913531984602, 35.80968495777675, 35.97448928015572, 37.23088339396885, 37.9474059513637, 34.93510477883475, 37.73597921643938, 41.13491637366158, 47.75775514330183, 49.491629464285715, 49.84253781182425, 49.67743819100516, 49.71483339582171, 49.38543667112078, 45.80688510622297, 44.72469622748238, 44.579134941101074, 44.074706145695274, 42.26402643748692, 44.846011774880544, 51.26444149017334, 50.02186734335763, 46.18171262741089, 47.907655579703196, 50.29172495433262, 49.20939016342163, 45.34700468608311, 35.769545214516775, 38.09479113987514, 40.00414221627371, 38.27159847532, 41.26166888645717, 39.171174798692974, 43.83817209516253, 47.599502972194124, 50.78568976266043, 53.31535169056484, 56.441078730991904, 47.858347688402446, 40.60956655229841, 22.12444874218532, 12.421405792236328, 6.575205394199916, 8.104859130723135, 16.037627015795024, 4.956820556095668, 6.253855986254556, 0.7886246112840516, 0.19764521372105393, 8.995915225573949, 34.49447781699044, 49.80580963407244, 42.265489033290315, 44.38825055531093, 56.182341711861746, 65.36574104854039, 41.54551322119576, 7.250932472092765, 0.1988134474626609, 0.27881744876503944, 0.135695468634367, 0.1304438111505338, 0.10404093470424414, 0.16695721899824484, 0.05533923641113298, 0.11015349706368786, 0.14489108377269336, 0.0945177771417158, 0.10646244298134531, 0.13675859730158532, 0.2110335917345115, 0.09804403542407922, 0.09881814888545445, 0.11017468092697007, 0.0791661191199507, 0.15332189495010035, 0.13827333173581532], [0.06801550210054431, 0.03513075704021113, 0.04919354118672865, 0.050111426040530205, 0.007929618919401296, 0.03391008950503809, 0.0819645400292107, 0.03366671595722437, 0.02365958989996995, 0.05296125276280301, 0.03699232464922326, 0.04209512172799025, 0.03616322610261185, 0.03884729689785412, 0.01968381573845233, 0.06954969691910914, 0.047802272984491925, 0.04897079849615693, 0.0200273715890944, 0.030682101646172147, 0.7508335762790271, 17.825771978923253, 44.465264388493125, 43.9304233278547, 41.475371156420024, 20.539953742708477, 29.24599620274135, 40.74893699373518, 20.029817002160208, 3.671267024108342, 0.06870295985468797, 1.525703794189862, 2.819186632122312, 4.635047742298671, 3.981240928173065, 11.457365819386073, 7.6783483028411865, 11.122407061713082, 24.781019517353602, 34.89728225980486, 48.98672471727644, 48.04274940490723, 44.38772944041661, 38.93247985839844, 34.15722962788173, 30.966074875422887, 34.07062380654471, 40.10808031899588, 44.61893422263009, 45.561971528189524, 46.15194307054792, 44.43656832831246, 42.65842008590698, 41.88235494068691, 42.17318916320801, 44.52273988723755, 44.621067319597515, 44.142169679914204, 42.793232509068076, 41.505144187382285, 38.399261202131, 35.92387165342058, 32.51325110026768, 31.064221654619487, 31.354920387268066, 30.97549315861293, 30.76994112559727, 31.309871741703578, 31.76051105771746, 30.552254063742502, 31.175917421068462, 32.37515217917306, 31.83032308306013, 31.852623326437815, 31.44168254307338, 31.755087988717214, 32.767774036952424, 35.48838983263288, 43.336890833718435, 47.95236723763602, 45.97584097726004, 48.138922895704, 46.177939755576, 46.52117729187012, 43.75286211286272, 44.28229400089809, 42.254615102495464, 39.75703648158482, 26.96125132696969, 36.339495522635325, 49.15581260408674, 41.557418959481375, 41.615745612553184, 41.947838238307405, 43.464661257607595, 41.08800561087472, 45.69709662028721, 41.228466919490266, 36.54378298350743, 31.528406483786448, 33.031642300742014, 30.62090573992048, 34.52022089276995, 33.26523378917149, 32.08145529883248, 33.549161502293174, 32.06119435174124, 37.43473311832973, 40.90810980115618, 42.79373625346592, 43.511078698294504, 43.07997076851981, 43.03019734791347, 40.55882038388933, 40.75550651550293, 36.16458504540579, 38.827131271362305, 41.585375036512104, 40.42666564668928, 40.998436382838655, 45.93604169573103, 45.52224520274571, 43.23202862058367, 45.69978209904262, 46.67265149525234, 46.31350605828421, 35.601079191480366, 33.27910934175764, 33.991678374154226, 34.63859735216413, 34.8574343408857, 35.27152960641043, 38.27470779418945, 41.47317205156599, 47.430435929979595, 47.2849371773856, 48.31997210638863, 46.424583435058594, 29.123817341668264, 18.57116256441389, 6.321464564119067, 5.108649551868439, 4.679823236806052, 6.62468785899026, 1.16359039076737, 2.0432443831648146, 0.23775432791028703, 0.2768757529556751, 4.729020391191755, 31.836076191493444, 46.61239324297224, 35.76609195981707, 32.574711390904014, 39.14918027605329, 48.029506138392854, 33.29242556435721, 5.081642772470202, 0.09742903163922684, 0.03493840254044958, 0.034135373309254646, 0.09006167482584715, 0.055158583247768025, 0.006159947852471045, 0.008706689097120293, 0.049378499654786925, 0.024145694083667228, 0.022780132180612003, 0.009121513177108551, 0.01949639249193881, 0.025769543734246066, 0.043368480900036435, 0.02429932967892715, 0.021782042791268656, 0.01878879581844168, 0.033675350315336666, 0.0360310644443546, 0.026800189233784164, 0.04524121380278042, 0.04746166876118098, 0.04689934643517647, 0.022577455466879264, 0.025610054078112756, 0.019826075694124614, 0.028384587162041237, 0.01196811770621155, 0.10012736863323621, 0.033723200604851754, 0.05549564551828163, 0.037035886597420485, 0.03193014128399747, 0.03977414859192712, 0.02533687248692981, 0.05869619681366852, 0.0674662347882986, 0.026119494777438895, 0.07624147034117154, 1.3307669801371438, 22.111594574792043, 49.360016686575754, 48.27763325827462, 45.495411259787424, 25.066708598818096, 33.271035534994944, 42.32161658150809, 24.653061492102488, 4.1640258857182095, 0.06661983020603657, 1.2260415596621377, 4.4646027854510715, 2.710795602628163, 6.582170529024942, 9.841169663837977, 8.845161029270717, 12.988372717584882, 27.463012014116558, 39.599343640463694, 47.65328550338745, 49.640289647238596, 46.35182189941406, 41.62834964479719, 36.92997775759016, 33.51212412970406, 34.37119245529175, 42.66522932052612, 46.26069280079433, 46.70848682948521, 45.75568035670689, 46.3294243812561, 44.413264070238384, 44.24044847488403, 41.66816629682268, 45.79626825877598, 44.32311119352068, 46.2971465247018, 44.62588936941964, 42.54131514685494, 40.56907592500959, 36.92852210998535, 33.64800657544817, 33.43973779678345, 32.12596198490688, 32.35943187986101, 32.52365950175694, 33.062221322740825, 32.96085057939802, 33.18380784988403, 32.239499023982454, 34.19247089113508, 34.503305503300254, 34.347599846976145, 32.917712688446045, 33.68240015847342, 33.51442745753697, 36.89050504139492, 44.47764260428292, 49.50580726351057, 47.79525804519653, 48.737739494868684, 46.66221182686942, 47.52135310854231, 43.85508748463222, 45.73385953903198, 41.909963607788086, 40.148577894483296, 29.07054897717067, 37.30008397783552, 49.52788863863264, 44.01219667707171, 43.13451760155814, 43.82482460566929, 45.92118992124285, 42.869989258902415, 46.57048865727016, 43.23047569819859, 37.86634479250227, 33.483073711395264, 34.60568026133946, 32.92810371943882, 36.23492513384138, 34.93777288709368, 33.878724983760286, 34.50131137030465, 34.62030274527413, 39.28809213638306, 43.44186074393136, 46.03507784434727, 46.20474590573992, 44.21023423331124, 45.1032201903207, 43.592911107199534, 43.30164609636579, 40.08950778416225, 39.94248390197754, 42.67807306562151, 42.133209228515625, 45.72126940318516, 47.7223471232823, 45.83454588481358, 43.49946478434971, 45.49030433382307, 47.98861598968506, 48.51700217383248, 36.962929589407786, 35.64975132261004, 36.25182662691389, 37.44523532049996, 37.20732205254691, 38.13964523587908, 38.99170282908848, 45.484724930354524, 50.38711329868862, 50.1165817124503, 51.36570801053728, 49.115724972316194, 31.697532585689, 20.402716398239136, 8.763693400791713, 6.511742285319737, 9.435662371771675, 6.217213358197894, 1.542795711330005, 1.1662964969873428, 0.14936558795826776, 0.3008072216595922, 6.4313759463174005, 32.03548601695469, 51.351311343056814, 46.94034126826695, 35.61802584784371, 45.46187577928816, 54.24370050430298, 38.35362195968628, 6.727794783455985, 0.1678351890295744, 0.034169476479291916, 0.024259615024285655, 0.015421699799065079, 0.011309056642598339, 0.051388330558048825, 0.04621193278580904, 0.06619666862700667, 0.04839278844052127, 0.021366428217983673, 0.012031196866051426, 0.06022982166281768, 0.025438237137028148, 0.023832840246281455, 0.010869718788723861, 0.012270462732496006, 0.059647916816174984, 0.034833277110010386, 0.02030394585537059, 0.11676696075924806, 0.17297240479716233, 0.16574992878096445, 0.1354851634906871, 0.11764676283512797, 0.14645892035748276, 0.15022146488939012, 0.09059667254665069, 0.06100934983364173, 0.20264973518039497, 0.17933885460453375, 0.13186098581978253, 0.12910291738808155, 0.08443480104740177, 0.12206180021166801, 0.1175838897803, 0.2311873845756054, 0.10414538838501487, 0.12367963125663144, 0.1614854447543621, 1.7980750245707375, 25.194994926452637, 55.948823179517476, 54.87034463882446, 53.163161822727744, 29.108592101505824, 36.628255707877024, 48.46693345478603, 26.834130559648784, 5.51198900597436, 0.14728119623448166, 2.0224380024841855, 5.718026978628976, 9.86220794064658, 13.608798214367457, 19.155269827161515, 14.89360785484314, 15.448701177324567, 26.39555331638881, 38.490213121686665, 50.52779694965908, 51.98803383963448, 48.47377395629883, 43.61961998258318, 37.67310496738979, 34.01213387080601, 37.52869708197457, 45.06492171968733, 49.01102604184832, 49.42325919015067, 48.61288384028843, 48.19553334372384, 46.44289888654436, 45.47927406855992, 45.54798827852522, 47.143708092825754, 46.62811354228428, 48.56481967653547, 46.12078734806606, 45.223913873944966, 42.19127185004098, 40.302584716251914, 36.561525208609446, 34.477169854300364, 34.11734001977103, 34.133470262799946, 33.81376280103411, 35.027526242392405, 34.56111798967634, 34.837277616773335, 34.527523449489046, 34.624242373875205, 34.26221343449184, 35.48795904432024, 35.29986783436367, 34.63886138371059, 35.21480451311384, 37.84896387372698, 47.51879269736153, 51.64260414668492, 49.04436697278704, 50.02884333474295, 48.06252745219639, 49.96781383241926, 45.5921961920602, 46.32030487060547, 42.89401265553066, 39.34932313646589, 30.449483258383616, 40.825374126434326, 51.21184015274048, 46.94994020462036, 45.11046716145107, 45.547043323516846, 47.35850122996739, 46.08059549331665, 48.28246920449393, 46.15313121250698, 40.278807980673655, 34.7532183102199, 36.888305936540874, 34.08970703397478, 37.59812695639474, 36.36904273714338, 35.2854711668832, 36.74714285986764, 35.21457174846104, 40.07078586305891, 44.202445302690776, 47.45323644365583, 47.83785745075771, 46.857383251190186, 46.41221564156668, 45.79401009423392, 44.81464760644095, 40.8569015775408, 43.07020854949951, 46.106470584869385, 44.90454339981079, 46.420880045209614, 50.360123021262034, 46.626230580466135, 43.546434606824604, 47.13423074994768, 48.72555235454014, 49.954772063664024, 40.123967375074116, 37.541186468941824, 37.551462854657856, 39.67323773247855, 39.09896217073713, 40.11545583180019, 41.93938228062221, 46.76638616834368, 54.19826970781599, 52.4090564591544, 54.23569965362549, 50.3905074937003, 33.478390625544954, 21.88768540109907, 9.01881127698081, 8.491401314735413, 12.632272328649249, 15.095810856137957, 6.376152966703687, 4.303847091538565, 0.4896152360098702, 0.5791785472205707, 7.298724787575858, 39.320866789136616, 57.76908792768206, 46.11770234789167, 43.972432136535645, 51.0085323878697, 61.788301195417134, 46.69416659218924, 9.15006274836404, 0.4308146397982325, 0.13693972543946334, 0.11072289650993687, 0.1277050402547632, 0.13684212496238096, 0.05671511543914676, 0.07207609313939299, 0.2412471276308809, 0.09750576037913561, 0.10275753321392195, 0.09407168107905559, 0.08921164008123533, 0.14363024357174123, 0.1829854782138552, 0.08496375980653934, 0.1096826276874968, 0.17913310921617917, 0.1284660715609789, 0.17186148012323038], [0.057982622246657095, 0.027384375654427067, 0.006040480312159551, 0.06283926378403391, 0.04244456386991909, 0.03501926016594682, 0.045143677786524804, 0.04029610826234732, 0.021765835982348238, 0.040570236409881284, 0.03722501127049327, 0.028047811572573016, 0.04046827634530408, 0.013303089554288557, 0.05707920715212822, 0.04904051796932306, 0.026708714231582623, 0.051228006303842576, 0.04503643193415233, 0.026172968425921032, 0.32092369507466045, 10.396561758858816, 34.12108857291085, 49.20667689187186, 32.10595464706421, 31.061973912375315, 29.339776039123535, 35.576927253178184, 29.152240685054235, 5.280845889023372, 0.16480422738407338, 0.6606592035719326, 4.136679513113839, 1.650815229330744, 5.942082498754774, 6.5945218205451965, 4.215021755014147, 4.343908667564392, 19.125439473560878, 35.064285687037874, 49.550994873046875, 46.639727456229075, 43.29542745862688, 37.282654421670095, 34.213423183986116, 32.829824924468994, 38.49044936043875, 46.62804406029837, 43.82979604176113, 45.33415399278913, 44.93212080001831, 42.793197768075125, 39.80533340999058, 38.4456821169172, 40.79612915856497, 40.68875864573887, 44.38014895575387, 46.352082456861226, 43.030860900878906, 42.51300818579537, 40.44395623888288, 38.11560794285366, 31.936283111572266, 32.16442721230643, 30.592407703399658, 31.457336834498815, 30.58525800704956, 32.91684763772147, 33.69214153289795, 33.77363348007202, 31.435394423348562, 32.851520674569265, 32.76841674532209, 32.10967540740967, 30.947453703199113, 32.90757179260254, 30.858370849064418, 33.17149911608015, 39.52695730754307, 43.53115899222237, 44.13865736552647, 46.40718861988613, 43.3330727985927, 44.48272868565151, 46.0586530821664, 48.75660385404314, 42.9282603263855, 43.67043910707746, 27.50530743598938, 33.290511335645405, 47.87076759338379, 41.935790061950684, 45.90959685189383, 42.331020968300955, 43.36293615613665, 45.15953881399972, 44.17415223802839, 43.06478200639997, 40.68622950145176, 32.5158497265407, 32.984863553728374, 32.265346322740825, 32.27825607572283, 30.721126556396484, 33.26370518548148, 31.77793366568429, 33.23169483457293, 32.40965345927647, 33.29592398234776, 35.33829484667097, 37.17508588518415, 37.539171491350444, 36.1153153691973, 35.91722570146833, 33.28006819316319, 33.46379940850394, 34.064102922167095, 36.11170925412859, 40.431032589503694, 41.62770346232823, 45.75300530024937, 45.92442430768694, 44.12353808539254, 48.495011125292095, 46.8232432774135, 42.15952205657959, 34.886008807591026, 34.8084773336138, 33.71240247998919, 33.43825783048357, 35.35252128328596, 35.979491983141216, 36.76160553523472, 39.75404528209141, 44.50518873759678, 46.00978640147618, 47.34939214161464, 47.99789878300258, 32.04528297696795, 17.848803520202637, 9.651595013482229, 6.812430356230054, 8.566419277872358, 5.301584090505328, 2.2464629071099416, 0.4135929324797222, 0.03360896923446229, 0.23414672006453785, 6.4201658964157104, 30.523606640951975, 42.95828696659633, 26.37978959083557, 30.414589405059814, 43.056440693991526, 46.72350188664028, 30.083142961774552, 3.218147852591106, 0.09227019096059458, 0.06063426924603326, 0.010916917684621044, 0.030931961988764148, 0.08997804538479873, 0.016050028315346156, 0.031049782809402262, 0.025693980378231833, 0.03761390343840633, 0.028891142391200577, 0.0482925179281405, 0.021372153357203518, 0.025355910483215536, 0.02642983464258058, 0.018777242063411644, 0.042671622043209415, 0.034320837285901816, 0.043404344868447096, 0.0030315390363934314, 0.05988013185560703, 0.04292321265009897, 0.014199223119898565, 0.039846388822687526, 0.038443076623869796, 0.07661466460142817, 0.030382969483200992, 0.04594130248629621, 0.026017602566363554, 0.06038135210318225, 0.033116722612508705, 0.04785430304972189, 0.0344930460809597, 0.037195142158972364, 0.024321436349834715, 0.040287731747542105, 0.05505219913486924, 0.05122788077486413, 0.06790970492043666, 0.026602698223931447, 0.6252872816153935, 14.253601465906415, 40.67425080708095, 52.706595693315776, 37.81793321881975, 28.997653688703263, 29.063562563487462, 40.41109125954764, 28.82240448679243, 6.747167229652405, 0.053805204440972636, 1.1857650237424033, 1.6380132819925035, 2.2090164593287875, 4.695700304848807, 8.392557110105242, 10.436449629919869, 12.00193088395255, 25.65698412486485, 40.22063071387154, 50.69152430125645, 48.639467648097444, 45.23766783305577, 40.42287540435791, 34.55605622700283, 34.70859350476946, 39.93154048919678, 47.655588831220356, 45.63606364386422, 45.44991445541382, 46.689952509743826, 42.26287998471941, 42.15497446060181, 39.58587455749512, 42.321203163691926, 42.36139154434204, 46.576964378356934, 46.076965059552876, 44.97603341511318, 45.40973997116089, 42.950372968401226, 40.085231167929514, 34.289742197309224, 32.37754235948835, 31.686078480311803, 32.51402235031128, 33.51820380347115, 34.19494792393276, 34.67143106460571, 35.08256639753069, 33.69861030578613, 33.86900097983224, 33.79302937643868, 32.43821055548531, 33.24963855743408, 33.87797805241176, 33.1314879144941, 35.14251545497349, 41.22508314677647, 45.40580381665911, 45.66686153411865, 48.023290974753245, 45.748061656951904, 46.39953865323748, 48.13414600917271, 49.01048060825893, 43.09926591600691, 44.069932733263286, 29.087561641420635, 35.25058773585728, 49.94316509791783, 44.13561405454363, 47.67875412532261, 44.875270639147075, 46.51939507893154, 46.20318603515625, 45.997488089970176, 43.671151297433035, 40.482751505715505, 33.56665359224592, 35.20168284007481, 34.29209416253226, 34.64477777481079, 32.682391098567415, 35.55378975187029, 33.43571131569998, 35.081326144082205, 33.910231590270996, 36.492922169821604, 37.75904376166207, 41.34501600265503, 40.279766832079204, 40.03532920564924, 38.0364089012146, 36.61699267796108, 36.744450432913645, 35.96449777058193, 38.98384441648211, 43.17999356133597, 43.43689625603812, 46.900472504752024, 47.90085676738194, 44.167259625026155, 49.10996144158499, 50.13150644302368, 45.129328046526226, 36.67114346367972, 36.74366181237357, 36.73648084912981, 36.53049455370222, 37.332997594560894, 38.691950593675884, 39.6537549836295, 42.1961738041469, 47.088636670793804, 48.515602111816406, 50.115886892591206, 50.357791900634766, 32.331743308476035, 18.255987065179006, 8.767764176641192, 7.218738428183964, 11.04337911946433, 6.140533472810473, 3.1283944972923825, 1.4268828225987298, 0.0655807556052293, 0.2887592895754746, 7.312573415892465, 35.086651938302175, 49.33519424710955, 31.20477328981672, 38.06882919584002, 46.553451674325125, 54.23985815048218, 36.5955296925136, 4.857983299664088, 0.04749435040035418, 0.05529556929000786, 0.0490824650041759, 0.03472704906016588, 0.003562455581101988, 0.015533719145293747, 0.04696802096441388, 0.0303566083977265, 0.03274294141946094, 0.03264434010322605, 0.014380067121237516, 0.04070982124124255, 0.02121764245176954, 0.06261046177574567, 0.035481681781155724, 0.04568286546106849, 0.0451173743765269, 0.0009672103208556239, 0.033559171549443684, 0.10525189579597541, 0.15599145527396882, 0.17341050771730288, 0.15744601722274507, 0.14823711636875356, 0.16325663828424045, 0.16323132892804487, 0.12906033253031118, 0.07188848499208689, 0.15789052551346167, 0.12761673570743629, 0.15216461276369436, 0.08589167680059161, 0.12478742109877722, 0.16112195354487213, 0.10767586715519428, 0.13439489342272282, 0.2196861481560128, 0.13465120324066707, 0.1779702359012195, 0.8443241938948631, 16.983099664960587, 45.468622480119976, 59.91936084202358, 41.8310216494969, 42.08484281812395, 39.13148321424212, 45.29968050548008, 36.412468978336875, 7.498261417661395, 0.29947010055184364, 1.1798690429755618, 7.957586850438799, 5.259863197803497, 12.201538733073644, 15.767338616507393, 10.929728303636823, 8.005467755453926, 22.34770999635969, 40.696589265550884, 54.09624930790493, 50.75083065032959, 46.92739677429199, 41.59548119136265, 38.223770550319124, 36.528622014181956, 42.18672425406319, 50.09525769097464, 46.778757435934885, 46.223950726645334, 48.04052945545742, 45.932282720293315, 43.84794126238142, 42.275661196027485, 44.74133368900844, 44.40286956514631, 49.44863748550415, 49.197918687547954, 45.81005348478045, 47.01987729753767, 45.59685843331473, 43.622479166303364, 35.37410238810948, 33.94961397988455, 33.93233380998884, 35.6758348601205, 35.510231494903564, 36.134471552712576, 37.682804652622764, 36.9420884677342, 35.34125477927071, 35.78445257459368, 36.67518731525966, 34.89236640930176, 33.97497143064226, 36.60451718739101, 34.06697252818516, 35.52953359058925, 44.503493377140586, 46.78810971123831, 46.868882519858225, 50.691503456660676, 47.50527845110212, 46.802673135484966, 50.89054502759661, 51.24387829644339, 44.40884849003383, 44.192505904606406, 32.297822202954976, 37.2027918270656, 50.67823587145124, 45.601614475250244, 50.542645250047954, 47.174665791647776, 47.74278177533831, 49.34433460235596, 47.13588094711304, 46.20292895180838, 43.631647314344136, 34.859675134931294, 36.91694988523211, 35.956844329833984, 35.76310076032366, 34.120991298130576, 36.48893390383039, 34.83761807850429, 36.97340399878365, 35.377333300454275, 36.7975172996521, 38.849966526031494, 41.50046457563128, 41.94214071546282, 39.577734742845806, 39.18015534537179, 37.93821695872715, 38.03060368129185, 37.79017169134957, 40.33770438602993, 44.720033986227854, 46.711853231702534, 49.341520581926616, 47.65504339763096, 44.956314427512034, 49.21023089545113, 50.7173125403268, 47.50268677302769, 37.9793016569955, 39.39566762106759, 38.6761017526899, 38.09110164642334, 39.82954788208008, 40.208447047642295, 42.21052878243582, 44.17896386555263, 49.40906054633004, 52.72800656727382, 52.41516392571585, 53.09742838995797, 35.00811644962856, 21.101654802049907, 12.179493835994176, 13.078966804913112, 16.326559168951853, 9.863161580903189, 7.761030997548785, 1.719417182462556, 0.15708411378519876, 0.4300988939191614, 9.33163481099265, 39.31415482929775, 51.353319372449604, 37.03195994240897, 42.96481479917254, 56.096976143973215, 60.510263442993164, 44.278677463531494, 6.884477095944541, 0.2725955811994416, 0.17853052940751823, 0.10024578656469073, 0.09207774485860552, 0.1571006021861519, 0.09105111459004027, 0.09683455353868858, 0.10107317859573023, 0.0835154200238841, 0.21220502816140652, 0.12289504121456828, 0.13496293579893454, 0.10040377665843282, 0.11816045455634594, 0.10146799098168101, 0.1484984066337347, 0.1666102704725095, 0.1280682057674442, 0.2410698128598077], [0.026986774489549652, 0.07942861039191484, 0.04238442870389138, 0.025488998341773237, 0.0300338530380811, 0.047817950536097796, 0.02692496164568833, 0.0238465229049325, 0.05702166059719665, 0.04938071846429791, 0.03745764360896178, 0.05112243643296616, 0.012742891891061195, 0.044469739842627726, 0.009637360095179506, 0.03409230669162103, 0.0065155977416517475, 0.019824398016291003, 0.0399107614399067, 0.05338294531351753, 0.1638253049126693, 9.182370134762355, 32.67604391915457, 46.94880764825003, 42.704007216862266, 37.544146401541575, 28.80735989979335, 37.08527347019741, 33.32285867418562, 7.860256484576634, 0.1193328680736678, 0.4829491451382637, 1.3577163283314024, 0.47584477492741173, 2.3804354667663574, 5.905885858195169, 8.827282445771353, 12.834032382283892, 23.625002554484777, 36.61817387172154, 46.090024198804585, 47.8048917225429, 42.55778585161482, 38.0437079838344, 34.67456817626953, 33.942756107875276, 41.117184570857454, 45.866049017224995, 45.037754263196675, 45.467875548771445, 42.81733928407942, 40.090445790972026, 38.68695831298828, 35.75899090085711, 37.2054078238351, 38.657018525259836, 41.17576483317784, 44.833501543317524, 43.64211130142212, 45.18886716025216, 41.90502691268921, 36.661749499184744, 32.863113743918284, 31.46258967263358, 31.015914303915842, 35.134278365543906, 33.96508066994803, 35.42275020054409, 38.40166180474417, 38.506881850106375, 37.618620668138774, 33.47391945975167, 32.18301364353725, 32.093062264578684, 31.99245582308088, 32.27355214527675, 32.76791647502354, 32.89535338538033, 35.98397357123238, 39.62889780317034, 40.26173625673567, 41.75858667918614, 40.97554554258074, 42.989835262298584, 44.66832896641323, 47.06801789147513, 44.58586079733712, 47.52668932506016, 33.35682841709682, 30.07729605266026, 45.386387075696675, 42.462067467825754, 46.719708170209614, 43.776756967817036, 46.253490992954795, 44.03546966825213, 45.3927446774074, 43.292877469744, 41.77854190553938, 35.01811490740095, 32.111697333199636, 32.20756162915911, 32.85098218917847, 32.52268327985491, 33.619025639125276, 32.2214788709368, 34.08325563158308, 32.68998895372663, 32.959825720105854, 32.579668930598665, 33.07482188088553, 30.764396463121685, 34.21598012106759, 32.70663683755057, 32.515210492270334, 32.61282573427473, 33.22020598820278, 34.372648102896555, 38.230065618242534, 41.7262601852417, 45.80669750486101, 47.06498500279018, 41.773952620370046, 45.547797203063965, 45.395364148276194, 41.375970227377756, 37.48573637008667, 34.87842832292829, 35.89244842529297, 35.20335040773664, 33.31526429312569, 35.791171482631135, 38.70110484531948, 39.5560633114406, 44.12752635138375, 47.17835875919887, 49.635630880083355, 47.202180658067974, 28.58756058556693, 15.972234044756208, 5.789173926625933, 3.1167842745780945, 9.30064410822732, 4.0724199669701715, 0.42915068194270134, 1.3302341401576996, 0.05830781015434435, 0.21769619493612222, 7.670550686972482, 28.176232440131052, 41.30200317927769, 36.8486282484872, 32.246009486062185, 45.72755752290998, 47.30841514042446, 29.71171658379691, 4.3695705362728665, 0.04615532600187829, 0.03526043865297522, 0.06041632379804339, 0.0257710076735488, 0.04069142954956208, 0.03598365859527673, 0.04526184466002243, 0.004745053484969373, 0.05276148866063782, 0.02358198245721204, 0.02699243347160518, 0.06807164408798728, 0.0307929233780929, 0.04317338511879955, 0.025654423482982174, 0.005092682666145265, 0.02484691083165152, 0.05586776090785861, 0.03899042707468782, 0.04500814041654978, 0.04747085951800857, 0.037148170572306426, 0.014158040285110474, 0.0398097513243556, 0.06570127699524164, 0.015232329157048037, 0.024017992096820047, 0.016870156629011035, 0.016734356326716285, 0.012389927304216793, 0.02517037356405386, 0.00781000591814518, 0.0234352085473282, 0.02928508285965238, 0.027982190450919524, 0.04069884254464081, 0.043044225977999825, 0.013317977460766477, 0.02122728104170944, 0.34868750242250307, 11.274107950074331, 37.676433154514854, 53.82375485556466, 44.557543413979666, 41.30989285877773, 30.717975548335485, 41.55263859885079, 39.31432853426252, 8.163374253681727, 0.32293565997055595, 0.5337947053568703, 1.8093422885451997, 2.060795532805579, 5.99835205078125, 6.137441958699908, 9.089684639658246, 12.691096646445137, 23.06151580810547, 35.14311647415161, 47.78537770680019, 49.90071855272566, 45.43596942084176, 39.08413124084473, 36.409151213509695, 35.84451627731323, 41.94375964573452, 48.68752833775112, 45.98792042051043, 47.2714854649135, 45.14067098072597, 42.32366630009243, 39.31935208184378, 38.199719360896516, 40.05322776521955, 40.94206912176949, 43.66938992909023, 47.54400076184954, 45.58205877031599, 47.17900494166783, 44.5705052784511, 39.217783314841135, 33.84025280816214, 33.301923751831055, 32.36273227419172, 35.967332635607036, 35.026171343667166, 37.58991765975952, 39.05456665584019, 40.27064037322998, 37.56390707833426, 33.39412982123238, 33.96713733673096, 33.17642886298043, 33.53248235157558, 34.6162554195949, 33.13770655223301, 34.21990237917219, 37.68386425290789, 41.64143310274397, 42.87075356074742, 44.32465021950858, 42.79094655173165, 45.759321212768555, 45.130081926073345, 48.41941819872175, 45.585974080221995, 48.51141929626465, 35.429420471191406, 31.68114525931222, 45.96461616243635, 44.73266928536551, 49.05656453541347, 45.89007936205183, 47.132775102342876, 46.32659993852888, 46.95837879180908, 45.25944348743984, 42.95541736057827, 35.629118646894185, 33.55794402531215, 33.304598808288574, 34.949456283024375, 33.2832087789263, 34.54118708201817, 34.31809432165963, 34.69169201169695, 34.07571683611189, 34.41410800388881, 33.93965373720442, 33.73385156903948, 34.07235043389456, 35.367154189518516, 34.98513528278896, 34.739485195704866, 34.363215923309326, 34.753061975751606, 36.206083161490305, 40.733755179813926, 44.03050170625959, 46.25524888719831, 49.43689502988543, 42.18484476634434, 47.385752064841135, 47.69418954849243, 43.06687688827515, 38.736165455409456, 37.0573764528547, 38.582342760903494, 37.70128686087472, 35.88196359361921, 37.74759660448347, 40.2793082509722, 41.10772112437657, 46.80420521327427, 48.59891448702131, 53.89219113758632, 49.10754346847534, 31.50732217516218, 16.008184024265834, 7.727146370070321, 7.295667580195835, 7.16368350812367, 3.122520229646138, 2.3346516149384633, 0.7346824343715395, 0.02316703793725797, 0.3364283830991813, 9.103429913520813, 35.16276250566755, 42.518997532980784, 36.75618941443307, 39.01658085414341, 52.01710857663836, 53.58442415509905, 34.38489082881382, 4.9909092869077405, 0.014672023776386465, 0.018449801419462477, 0.01579383384835507, 0.013461102548587536, 0.03320952923968434, 0.0780284194541829, 0.01957893797329494, 0.04734729150576251, 0.015545062554468001, 0.04390928348792451, 0.021015296523858393, 0.011216828466526099, 0.0382367884075003, 0.02051694139039942, 0.022585538515288914, 0.013609178397538406, 0.023985405452549458, 0.011358914547599852, 0.054444852617702315, 0.15755085088312626, 0.10659725431885038, 0.09141972873892103, 0.11459343667541232, 0.08435523603111506, 0.15891413630119391, 0.08713014570197888, 0.12145897613040038, 0.13678368952657494, 0.14849753810891084, 0.0917266301278557, 0.08471074766878571, 0.08783852947609765, 0.08546633712415184, 0.06439291898693357, 0.08575896892164435, 0.09769646943147693, 0.11419247676219259, 0.12893362290092877, 0.20839508117309638, 0.6351265822138105, 14.337767601013184, 44.86206906182425, 58.90813391549246, 52.857611315590994, 47.49038846152169, 37.31321259907314, 44.52743339538574, 41.40818207604544, 10.039184638432094, 0.4721779174038342, 0.8892447320478303, 3.489157561744962, 5.632613207612719, 11.566494226455688, 12.409868308476039, 15.497084958212715, 16.23074872153146, 28.27265954017639, 41.37036997931344, 49.26561151232038, 52.208489758627756, 48.23707662309919, 41.494322368076865, 37.98402643203735, 38.60071379797799, 44.59915964944022, 51.14980663572039, 47.539338520595, 47.4264372416905, 47.55090379714966, 45.56311798095703, 42.19233839852469, 39.684042181287495, 42.17709405081612, 42.627326897212434, 43.78059237343924, 49.9440336227417, 46.708354813711985, 48.73135757446289, 46.905985900333945, 40.745511531829834, 36.326564925057546, 34.93891586576189, 34.75802993774414, 37.82203613008772, 37.93897083827427, 40.36972515923636, 42.85721846989223, 42.17998450142996, 40.84213318143572, 35.954742499760215, 36.52031544276646, 35.72821385519845, 35.497120244162424, 35.68687554768154, 35.130581923893516, 36.061769076756065, 39.18712786265782, 42.65313598087856, 44.23267691476004, 46.71510846274239, 45.36017152241298, 47.717688356127056, 48.195463861737935, 50.318242754255024, 47.03859921864101, 50.20974315915789, 36.64884669440133, 36.028153691973, 48.03988674708775, 46.38593060629708, 51.3040531703404, 47.809828417641775, 48.97313404083252, 48.68449197496687, 48.976045336042134, 46.89889178957258, 44.0877548626491, 38.28208678109305, 34.83216721670968, 35.7231798853193, 36.51678575788225, 35.00806433813912, 36.47596856525966, 36.0895688193185, 36.91873904636928, 35.536961214882986, 36.70439059393746, 36.15959276471819, 36.46814489364624, 35.18891205106463, 37.26091003417969, 36.236849784851074, 36.39520617893764, 35.0376740864345, 37.04773930140904, 37.96334859303066, 42.08152852739607, 45.981865065438406, 48.667791979653494, 50.53793784550258, 42.49707249232701, 49.10445499420166, 49.252406460898264, 45.62282732554844, 42.32315560749599, 38.085685525621685, 39.91335705348423, 40.855574471609934, 38.34425926208496, 40.09027903420584, 42.31219482421875, 43.955214500427246, 48.49765491485596, 53.08722496032715, 56.17846461704799, 51.381838253566194, 30.70625741141183, 18.409102780478342, 8.197165949004036, 7.181268530232566, 18.809826237814768, 9.697674598012652, 4.205139245305743, 1.878250070980617, 0.22950133361986705, 0.6384991183876991, 10.935298153332301, 40.40052999768938, 54.030870233263286, 48.10162149156843, 44.970499174935476, 58.464401108878, 60.4141629082816, 40.98188577379499, 7.096165256840842, 0.0778468841952937, 0.16933241726032325, 0.16082696723086493, 0.12627305995140756, 0.0915490642988256, 0.12143141403794289, 0.14061142770307405, 0.12282872120184557, 0.14745499619415828, 0.0842332218640617, 0.13502215833536216, 0.12621363385447434, 0.17408754995891026, 0.07855214670832668, 0.11519068319882665, 0.127250503216471, 0.09721242969057389, 0.09236515872180462, 0.2447446770966053], [0.034214202115046125, 0.01976716358746801, 0.019581769160660248, 0.03647930467767375, 0.05075079941057733, 0.023760693314086114, 0.04261059799630727, 0.022215231421536634, 0.048574201563107114, 0.013912240974605083, 0.013410758642878915, 0.018021060586241738, 0.04395903028281672, 0.0055000678819072035, 0.0650041229756815, 0.04184691361816866, 0.02452822498578046, 0.037114569518182955, 0.01884862225103591, 0.06434627648975168, 0.18038328284663813, 3.873404017516545, 28.635346821376256, 48.69440705435616, 39.911574840545654, 23.112138645989553, 20.538577999387467, 22.571334293910436, 30.86861596788679, 13.874261958258492, 0.48002873041800087, 0.2538302338549069, 0.7554811611771584, 1.445229975240571, 4.478905652250562, 5.527630703789847, 12.544347218104772, 15.720101288386754, 19.59167923246111, 32.476265839168, 45.74799564906529, 46.31107766287667, 43.84899391446795, 38.31520536967686, 34.31316457475935, 35.62523807798113, 42.885476793561665, 46.845446246010916, 43.10181243079049, 45.312329701014924, 41.60214103971209, 38.236430168151855, 35.77461045128958, 32.73425940104893, 34.711126123155864, 36.70963300977434, 40.2620906148638, 41.08504567827497, 43.26221506936209, 43.332235540662495, 38.47540651048933, 34.51457895551409, 31.085163525172643, 30.81438180378505, 30.72387456893921, 33.31182146072388, 34.04844863074166, 40.093343189784456, 43.06964227131435, 43.88181373051235, 42.70830815179007, 41.62948220116751, 37.381732259477886, 32.824912548065186, 31.726051466805593, 32.533303601401194, 32.38581766401018, 33.95985909870693, 31.45241403579712, 33.35463278634207, 34.822002002171104, 37.512570313044954, 39.71221365247454, 42.86683825084141, 41.76941197259085, 45.09494488579886, 43.65778643744332, 48.25195619038173, 35.39431469781058, 30.60700239453997, 43.11674063546317, 42.20330613000052, 45.33750997270857, 44.951572281973704, 48.98622097287859, 44.02776064191546, 46.137195519038606, 44.71018491472517, 39.69903986794608, 37.79080397742135, 33.42430584771292, 32.814090728759766, 33.08559158870152, 32.0139604977199, 32.79649788992745, 33.83819266727993, 35.59157058170864, 33.78813089643206, 33.730683190482004, 32.73095900671822, 31.84278120313372, 32.58380658285958, 35.56043570382254, 34.41990974971226, 31.198391369410924, 32.32245356695992, 32.50314841951643, 34.44128588267735, 39.249262128557476, 40.90007420948574, 47.57068531853812, 46.99175793784005, 39.44111578805106, 45.25864791870117, 48.26365000861031, 43.735731329236714, 39.257777145930696, 38.26084613800049, 43.346316065107075, 37.59518092019217, 36.781991549900596, 33.57936879566738, 38.506583077566965, 40.65114804676601, 44.25780854906355, 46.669816630227224, 50.4859618459429, 42.507029260907856, 27.845220259257726, 10.996324181556702, 4.803886362484523, 5.7451223475592474, 7.635579534939357, 3.038474602358682, 2.8956945495946065, 1.2292046185050691, 0.07548318710178137, 0.33491530429039684, 8.132158602987017, 31.079167229788645, 43.84439073290144, 27.889695678438457, 26.826774154390606, 40.98429332460676, 46.99982132230486, 30.11535828454154, 4.339498732771192, 0.0635713759277548, 0.04113826860806771, 0.05628086659791214, 0.039055335734571726, 0.01769745027247284, 0.009813266906089016, 0.0528331894560584, 0.02736768199663077, 0.05780829302966595, 0.05478548398241401, 0.067939954011568, 0.02287861644955618, 0.008661044046415814, 0.054817785641976764, 0.02780575947170811, 0.014818456722423434, 0.02431096994717206, 0.06753696527864252, 0.05346398614346981, 0.02602845403764929, 0.015749591668801646, 0.03991983684578112, 0.014103437723991061, 0.010009980145176607, 0.04380516907466309, 0.03352380291159664, 0.021820402072210397, 0.04083685317475881, 0.04578726825171283, 0.036041093191930225, 0.06038101962102311, 0.043250344560614655, 0.0288761705160141, 0.08408324526888983, 0.008651715886246945, 0.02289553063123354, 0.03146035417116114, 0.021343171430219497, 0.008695642547016698, 0.1775446180254221, 6.017907755715506, 35.64922325951712, 53.79767826625279, 45.88480915342058, 29.40483202253069, 28.063225201198033, 27.82747803415571, 35.37997709001814, 13.658745339938573, 0.520563923886844, 0.4380493701568672, 0.4398358714367662, 0.12233469342546803, 4.6231003148215155, 5.833667150565556, 7.926075901303973, 12.331544739859444, 18.63579297065735, 33.44960771288191, 49.75928797040667, 48.92621980394636, 45.78146512167794, 40.92188113076346, 35.49046039581299, 37.996623516082764, 45.01042352403913, 48.47597653525216, 43.33135311944144, 46.48516130447388, 44.552596296582905, 41.12626934051514, 37.07442733219692, 34.19387442725045, 36.943599700927734, 40.167244229997905, 42.40994208199637, 44.220048563820974, 46.56328337533133, 45.17290019989014, 41.53166198730469, 35.75651386805943, 32.783098288944785, 31.845143590654644, 32.707355976104736, 35.747314453125, 36.89426749093192, 40.13176672799246, 44.396202768598286, 45.140448638371055, 44.78528799329485, 43.26511594227382, 37.044452803475515, 34.798336437770296, 32.838107177189414, 33.8178448677063, 33.71210370744978, 35.02205106190273, 33.85411099025181, 35.710266658238, 37.1778894833156, 41.12656116485596, 41.72390127182007, 43.85805436543056, 44.23749549048287, 46.04477752958025, 45.18157849993025, 49.58013909203665, 36.50302832467215, 34.111138752528596, 45.50424936839512, 42.57842200142996, 45.82354688644409, 45.17724977220808, 49.20242806843349, 45.00549030303955, 47.58085400717599, 45.63566412244524, 41.8186434337071, 38.02494089944022, 34.35965149743216, 34.421782289232524, 33.89837448937552, 33.265522139413015, 35.15571355819702, 35.32298796517508, 37.565428733825684, 35.02204063960484, 34.9489039012364, 34.39501782826015, 33.84257698059082, 33.530700138636995, 36.982652051108225, 35.7243332862854, 32.8269032069615, 33.92057398387364, 34.72991405214582, 36.20166410718645, 41.75947257450649, 44.802064418792725, 48.18043143408639, 47.827827726091655, 39.46845694950649, 46.64572375161307, 51.23984834126064, 45.373994963509695, 41.53000136784145, 40.404118742261616, 44.64986760275704, 38.64722503934588, 38.47256122316633, 35.771980558122905, 40.71181624276297, 41.67882483346121, 47.13542931420462, 48.686819621494834, 53.852350166865754, 45.40897914341518, 32.69566215787615, 15.8326256275177, 9.958609853472028, 6.299466133117676, 7.465201020240784, 6.569993376731873, 1.81623446728502, 0.8813369220920971, 0.010210062310631787, 0.30200630160314695, 9.230865955352783, 34.81943811689104, 46.94234234946114, 34.847411564418245, 34.08301591873169, 47.053642068590435, 51.660523550851, 36.10691499710083, 5.396898610251291, 0.06238431962473052, 0.023331019495214735, 0.028633309262139455, 0.02542241370039327, 0.05854576560003417, 0.03616001663197364, 0.060415489199970446, 0.027553610769765716, 0.0304078174355839, 0.025297797351543392, 0.03240276128053665, 0.02686229215136596, 0.039751631407333274, 0.06254513920950037, 0.03526514768600464, 0.03971289384311863, 0.034284952961440594, 0.017979956631149565, 0.016443118918687105, 0.12111548813326017, 0.12154776922294072, 0.17494829877146653, 0.11605479754507542, 0.1231503603713853, 0.08382385490196091, 0.1332452515406268, 0.09647978828953845, 0.12640210374125413, 0.152150919927018, 0.12216900874461446, 0.16481384901063784, 0.11761952643947941, 0.07297984750143119, 0.13216811791062355, 0.10254918903644596, 0.10427951440215111, 0.1539430394768715, 0.08128268697432109, 0.17474312335252762, 0.4766022914222309, 8.5188102211271, 42.66836643218994, 58.04563317980085, 51.733448369162424, 34.3578588621957, 30.92473656790597, 31.762588569096156, 39.74065957750593, 17.657611676624843, 0.9209312860454831, 0.5734698421188763, 1.0407834776810236, 4.426673003605433, 10.066454580851964, 10.06292142186846, 21.10978593145098, 22.831999438149587, 22.869726419448853, 35.3105993270874, 51.75614465985979, 50.78222608566284, 49.154110295431956, 42.57453795841762, 37.82399204799107, 39.17823069436209, 46.58120277949742, 50.47864886692592, 43.55579383032662, 47.91963079997471, 47.568375042506624, 43.58627210344587, 39.151608671460835, 36.456906182425364, 38.271185057503835, 41.51165812356131, 43.95754909515381, 45.96175003051758, 48.699211733681814, 46.95938975470406, 43.303918157305034, 38.025899750845774, 34.5743682043893, 34.31747940608433, 32.93577800478254, 36.21781866891043, 38.716665336063926, 43.514688287462505, 47.85649946757725, 46.97632598876953, 45.59212671007429, 45.86597258704049, 41.14902121680123, 37.276960372924805, 35.12048271724156, 35.03445359638759, 35.71254219327654, 37.80350875854492, 35.43032373700823, 36.982787540980745, 38.317842211042134, 41.83668095724923, 44.2685226712908, 47.096029554094585, 45.88771002633231, 49.434199128832134, 46.078017711639404, 51.309938294546946, 39.41951036453247, 36.86987931387765, 45.844697202954976, 44.22044113704136, 47.09148890631539, 47.790088585444856, 53.364447661808555, 46.75654057094029, 49.54887219837734, 48.33689791815621, 43.410114424569265, 42.19220985685076, 36.9022787639073, 36.65007305145264, 35.948919909340994, 35.09355844770159, 36.79301486696516, 36.40088980538504, 39.69952276774815, 37.954270771571565, 36.44772066388811, 36.33507299423218, 35.12465163639614, 35.82789618628365, 38.478557518550325, 37.41647672653198, 34.620177677699495, 35.76210021972656, 36.27298041752407, 37.73962354660034, 43.568953718457905, 47.0978638785226, 50.558931827545166, 48.40095683506557, 38.67062657220023, 47.18092264447893, 52.79278114863804, 49.19000121525356, 44.331115518297466, 43.37615857805525, 46.868410042354036, 41.19617516653878, 40.402263573237825, 37.75229358673096, 43.26354564939226, 44.98688302721296, 48.49415649686541, 51.02057014192854, 55.58009270259312, 47.150430474962505, 32.093680654253276, 13.836178881781441, 8.088617716516767, 13.28981510230473, 14.109380313328334, 12.565183997154236, 7.383465886116028, 1.6684988290071487, 0.1375247719032424, 0.4455957109374659, 11.348191380500793, 41.0455972807748, 54.056509086063926, 37.83227777481079, 41.39339630944388, 53.34809160232544, 60.805221421378, 40.61707755497524, 7.333548290388925, 0.18710212303059442, 0.10376375314912625, 0.12174177595547267, 0.0771001089098198, 0.14478554443589278, 0.11512553026633603, 0.1573953985103539, 0.11694739679140703, 0.10469964971499783, 0.12717201028551373, 0.12468908780387469, 0.07169120093541485, 0.09211067416306053, 0.12643567765397684, 0.12039043275373322, 0.12284185763980661, 0.11739022231527738, 0.1323143286364419, 0.11035323741712741], [0.03637464404372232, 0.05989514783556972, 0.06796782823013407, 0.034561435625489266, 0.027948228076898625, 0.027383870145838176, 0.052053813955613544, 0.022571275709196925, 0.06120215555919068, 0.00416379451884755, 0.03897166558142219, 0.032535462374133725, 0.003892975077698273, 0.05044271397803511, 0.0401025866823537, 0.038269968769912205, 0.040068164600857666, 0.014182294519352061, 0.04747878819970148, 0.03527745631124292, 0.056036702556801696, 4.09764974457877, 26.481485162462505, 47.376097542899, 38.27480159487043, 26.715436220169067, 20.316020250320435, 35.30556535720825, 38.79148701259068, 16.763948270252772, 1.9961651265621185, 0.10692400285708052, 0.25547877539481434, 0.850610902266843, 4.815400830336979, 3.8344163724354337, 4.2393074461391995, 6.18482346194131, 12.349171451159886, 25.091810703277588, 41.92144203186035, 47.50384712219238, 43.125144481658936, 40.496592317308696, 35.23276213237217, 38.22853006635393, 42.87431451252529, 47.49395636149815, 42.93058449881417, 45.81565373284476, 43.30084705352783, 38.28331313814436, 34.19902651650565, 31.431812626974924, 33.26374340057373, 34.60035099302019, 36.9645346232823, 41.23585980279105, 39.54383795601981, 38.90940836497715, 35.69846861703055, 30.587370259421213, 30.418991088867188, 29.728138651166642, 31.625201838357107, 30.289483615330287, 32.23347840990339, 38.687277930123464, 40.04833970751081, 43.2440698487418, 43.75453315462385, 45.337586402893066, 41.68976477214268, 37.112625053950715, 30.61357191630772, 33.16841064180647, 31.684084347316197, 33.09026772635323, 33.8367509160723, 34.32027605601719, 30.755735533578054, 33.041606017521445, 34.066402775900706, 36.2940126146589, 39.585607051849365, 43.71578652518136, 40.405247824532644, 48.644939354487825, 39.05105781555176, 31.607424872262136, 45.18748794283186, 43.85098457336426, 47.57819284711565, 43.74225916181292, 46.03007166726248, 42.299000195094514, 45.322157927921836, 41.83599655968802, 40.85818352018084, 39.83103479657854, 32.962021350860596, 31.744307858603342, 33.61572871889387, 32.83361864089966, 32.56660284314837, 33.576433181762695, 35.437452588762554, 32.85289294379098, 32.0051258632115, 32.0325608253479, 32.028054918561665, 31.525540351867676, 31.658924920218332, 33.13514961515154, 34.893641403743196, 32.58243778773716, 35.26352875573294, 38.19375433240618, 42.51423454284668, 43.931521143232075, 44.682037762233186, 43.54593086242676, 46.3607850755964, 43.45923471450806, 46.73680421284267, 46.04680987766811, 46.61218479701451, 44.40194545473371, 45.589712211063926, 42.85611718041556, 40.61809894016811, 36.8719151360648, 38.785198892865864, 41.77189595358712, 46.45771939413888, 47.04754849842617, 49.60794925689697, 40.24992779323033, 29.270884650094168, 12.849347949028015, 12.345346467835562, 7.046057454177311, 2.7539829994950975, 2.5019581573350087, 1.0711058505943842, 0.16458911821246147, 0.0725653168878385, 0.46121805693422047, 8.985708321843829, 33.46756533214024, 37.496040548597065, 25.18646080153329, 22.635328939982823, 44.50641509464809, 45.27496228899275, 24.244787079947336, 4.260801698480334, 0.020239669929391572, 0.014573363088337439, 0.023824965847390037, 0.017432879290676544, 0.027567142454375113, 0.026509732141026428, 0.02453007738638137, 0.06443523243069649, 0.02375908688242946, 0.0072363978584430045, 0.09733297143663679, 0.02215085201896727, 0.02358881530484983, 0.02430473590668823, 0.04374897280441863, 0.04337263692702566, 0.01642259323437299, 0.023569088595520173, 0.023398693185299635, 0.05462801296796117, 0.047473729721137455, 0.1259484895105873, 0.07561434113553592, 0.07712771171437842, 0.059526336911533556, 0.04913555019135986, 0.06359279049294335, 0.03817468209724341, 0.040078766710524044, 0.08969540162278072, 0.038360814430883954, 0.027686018396967223, 0.05419782515881317, 0.07883837313524314, 0.0450098401467715, 0.04945300279983452, 0.06336217679615531, 0.09566992960338082, 0.017038804811558554, 0.09002531213419777, 4.755233338900974, 32.63273579733712, 53.32301207951137, 43.42282962799072, 31.781897612980433, 22.763825450624736, 32.39757054192679, 42.421413557870046, 18.454498835972377, 2.194701216050557, 0.025478165530200516, 0.2116899929408516, 1.4638445249625613, 2.6691168333802904, 5.5867103678839545, 7.147193695817675, 6.6462759120123724, 11.623240164348058, 27.65326237678528, 43.77858781814575, 49.52700621741158, 45.59445783070156, 42.06499528884888, 37.1009555544172, 39.17593084062849, 44.283162525721956, 47.85859782355172, 45.32050078255789, 47.52556371688843, 44.605503354753765, 39.87557622364589, 36.613636698041645, 33.21455710274832, 36.274571555001394, 35.797344957079204, 40.43894311359951, 43.51790877750942, 42.758588790893555, 41.37595285688128, 38.06660577229091, 33.28662034443447, 32.65455314091274, 31.811955520084926, 32.242844581604004, 32.213304315294536, 33.72220638820103, 40.190954957689556, 43.056954860687256, 44.22768810817173, 46.502747195107595, 47.380193505968364, 45.0167498588562, 37.26373447690691, 33.261964661734446, 35.73225770677839, 33.1912111554827, 34.88029044015067, 35.24147169930594, 35.578414167676655, 32.484707900456016, 34.627278736659456, 34.46250568117414, 38.54737595149449, 41.34452615465437, 45.33826732635498, 41.749897956848145, 50.173862661634175, 41.523014954158235, 33.17174925122942, 46.54576696668352, 44.50421251569475, 48.71971239362444, 45.79082434517996, 46.63340112141201, 44.40275839396885, 47.01318965639387, 44.158737659454346, 42.34969425201416, 41.41679089409964, 35.4137418610709, 32.55960600716727, 35.27333961214338, 33.99056666237967, 33.680510248456685, 35.057761328560964, 36.06982551302229, 35.260402066367014, 34.3493195261274, 33.76221064158848, 33.11244985035488, 32.955931254795615, 33.410333020346506, 34.859709875924246, 35.970824105399, 33.97531189237322, 35.20800570079258, 40.46493632452828, 44.041882855551584, 45.36398260934012, 46.753247124808176, 44.84125573294503, 45.80366114207676, 43.45849820545742, 48.29776218959263, 47.53908143724714, 45.56236410140991, 46.84840965270996, 46.76148074013846, 45.3714553969247, 42.56304216384888, 38.859082562582834, 40.2871492930821, 44.62516328266689, 47.536118030548096, 51.98622383390154, 52.15947021756853, 44.97707911900112, 31.17460421153477, 16.70785893712725, 6.8173540234565735, 7.3573067869458875, 7.738570945603507, 4.842706382274628, 3.409210503101349, 0.375585743359157, 0.045722193350749354, 0.5030855132000787, 10.170469982283455, 36.470875535692485, 43.4211551121303, 27.877333096095494, 28.040902376174927, 49.441077845437185, 52.71190759113857, 29.863503456115723, 5.239620055471148, 0.12914755142160825, 0.027075884797211205, 0.025440140427755456, 0.057764832861721516, 0.027685334772935936, 0.05371868783341987, 0.04090334621391126, 0.037475383907024346, 0.06747751204030854, 0.0662064938140767, 0.03218765889427491, 0.0742571557472859, 0.014413564698770642, 0.025681157762716924, 0.03259011158453567, 0.009907270299403794, 0.06282762012311391, 0.012906918401962944, 0.02574189512857369, 0.16463633067905903, 0.17109708328332218, 0.29828081865395817, 0.15767575560935906, 0.17039942714784825, 0.15700847070131982, 0.18680594249495439, 0.13856696097978524, 0.16040495916136674, 0.1796125756310565, 0.14701955313129084, 0.17529759502836637, 0.1640503614076546, 0.08983701188117266, 0.09555404260754585, 0.14064128324389458, 0.07429205958864518, 0.12289405055344105, 0.1609503384679556, 0.09745786259216921, 0.2970499289887292, 6.657103376729148, 38.69065475463867, 60.22997311183384, 50.28544725690569, 37.334894452776226, 28.838539940970286, 42.989133494240896, 48.2543637411935, 22.572849001203263, 3.312198668718338, 0.30219897840704235, 0.8802503432546342, 3.1560227062020982, 10.761213643210274, 11.816089153289795, 9.898536596979413, 11.369691712515694, 14.736020973750524, 29.621459484100342, 45.511121136801584, 52.534961291721885, 49.10418054035732, 44.75090830666678, 39.803363595690044, 41.14398724692208, 47.313650608062744, 50.97404153006417, 46.81910562515259, 48.14449535097395, 48.781335966927664, 42.86402423041207, 39.350115231105256, 33.56312043326241, 38.14349453789847, 36.547906739371165, 41.331942967006135, 45.37785816192627, 44.659542969294954, 43.84484583990914, 39.95579317637852, 34.21973214830671, 34.11350114004952, 33.15920427867344, 34.70953845977783, 34.198373385838096, 35.999488898685996, 42.09862457002912, 44.82455921173096, 46.419490405491416, 48.347528662000386, 50.48264408111572, 46.23867743355887, 40.70119244711739, 34.342162881578716, 36.68517187663487, 35.47921821049282, 37.391963481903076, 36.65670510700771, 38.150119645254954, 33.954623631068635, 35.66673966816494, 36.6048263822283, 38.758934702192036, 43.6163786479405, 47.12509734289986, 44.42867170061384, 52.582994188581196, 44.4237037386213, 35.97452054704939, 45.32899842943464, 47.751484394073486, 51.674958433423726, 48.15949303763253, 48.257796151297434, 46.42179373332432, 48.404114791325156, 43.853194100516184, 43.1600661277771, 44.03850950513567, 36.910918848855154, 34.865428243364605, 36.58341203417097, 35.83868326459612, 34.993421009608674, 36.70073584147862, 37.65697125026158, 36.27651357650757, 35.31880514962332, 36.378718103681294, 34.95550468989781, 35.48836203983852, 34.4985077721732, 36.22250522886004, 38.83839430127825, 34.8569028036935, 36.984934534345356, 42.11298997061593, 46.882910932813374, 48.41486712864467, 48.482261180877686, 45.12211581638881, 47.978589739118306, 43.1876539502825, 49.946156297411235, 48.48135444096157, 50.08793428965977, 49.8777026448931, 49.43621410642351, 46.95582185472761, 44.911724363054546, 42.41496562957764, 44.34088815961565, 46.22047315325056, 51.86862209865025, 54.16581119809832, 55.98429025922503, 45.26935509272984, 33.29629223687308, 15.758024556296212, 15.351459400994436, 11.670031070709229, 10.30348195348467, 7.461666992732456, 4.446563959121704, 1.859739852803094, 0.17100876516529492, 0.8947328861270631, 12.606873188699995, 43.47035878045218, 48.510575090135845, 35.44383798326765, 36.07115609305245, 57.57651512963431, 59.490253993443076, 37.648539611271445, 6.923655816486903, 0.2301118794296469, 0.15224899537861347, 0.10653631508882556, 0.11015008403254406, 0.0795851144939661, 0.12082504800387792, 0.13583793384688242, 0.20033267379871436, 0.1335732825100422, 0.17228912003338337, 0.22414417751133442, 0.19998864297355923, 0.056071999948471785, 0.09894830547273159, 0.1418350570436035, 0.14614123026175158, 0.1310568946812834, 0.09532169864646026, 0.1226141412875482], [0.049774465550269396, 0.09900780620851687, 0.09524377568491868, 0.03340650117024779, 0.08207566370921475, 0.03909517252551658, 0.011520154824081277, 0.037378814803170304, 0.02197057374620012, 0.058735178650489876, 0.0296521601267159, 0.016580680019355247, 0.02156849594653717, 0.028071265135492598, 0.08185311779379845, 0.02384760686462479, 0.03633510920086077, 0.01198655180633068, 0.04381333863628762, 0.03290268213355115, 0.03704490772049342, 2.676144067730222, 26.642002446310862, 47.95174189976284, 39.892717429569785, 28.393309797559464, 30.71121495110648, 23.128294944763184, 32.02489696230207, 24.846909284591675, 3.1164709542478835, 0.10478939275656428, 0.029256859195551703, 0.4189690468566758, 1.3392270633152552, 3.9329974140439714, 6.295581655842917, 6.181315924440112, 5.950543667588915, 22.244094984872, 40.00207165309361, 48.15042911257063, 43.4040139062064, 41.00114965438843, 35.302549839019775, 39.752033778599326, 44.49317530223301, 45.244285992213655, 39.72454670497349, 45.98533916473389, 41.30574825831822, 38.32029145104544, 33.96024472372872, 32.48707376207624, 31.43885462624686, 33.96607773644583, 34.82533366339547, 38.08899286815098, 36.21485873631069, 35.27805049078805, 32.18425737108503, 32.57100452695574, 30.930590425218853, 29.525991235460552, 31.638247081211635, 31.356820719582693, 31.597488948277064, 32.637846197400776, 39.65005159378052, 43.791563579014365, 45.197844232831685, 45.954888684409006, 45.579380239759175, 42.39555583681379, 35.406679017203196, 32.19992208480835, 32.25667149680001, 31.549921580723353, 32.417126246861045, 34.6266325541905, 32.143836225782124, 32.76062086650303, 33.38943631308419, 34.08527060917446, 35.062274183545796, 41.116225719451904, 43.228141103472026, 47.19483641215733, 40.94388607570103, 31.119206224169048, 46.13732753481184, 44.116075720105854, 45.839336667742046, 41.81528745378767, 43.027008124760215, 40.47182546343122, 42.08966834204537, 41.20870624269758, 40.767130851745605, 40.587318420410156, 36.72199732916695, 31.488294533320836, 34.31652055467878, 32.45049844469343, 34.1731653213501, 32.37729917253767, 32.725765228271484, 34.57781451089041, 36.805059569222585, 34.960451807294575, 32.81332990101406, 32.26629475184849, 31.41321577344622, 31.13602433885847, 32.10664251872471, 32.0447792325701, 36.52144105093819, 38.63079602377755, 43.05210501807076, 46.371367182050435, 45.14381851468767, 40.53591217313494, 45.343398571014404, 43.464532715933665, 45.45421886444092, 46.85704626355852, 47.07151978356497, 43.914918422698975, 46.336355209350586, 46.8984887940543, 43.660114083971294, 37.82197707039969, 37.544368743896484, 38.70132718767439, 45.01825066975185, 47.9725969178336, 51.15522275652204, 44.3991105897086, 30.969941547938756, 15.489759819848196, 8.019539594650269, 3.180110590798514, 7.021761775016785, 7.131225432668414, 1.9561263493129184, 0.49328236494745525, 0.10576210663254772, 0.5447411036917141, 9.488344482013158, 33.666909149714876, 41.13871703829084, 36.65413774762835, 41.39618601117815, 44.58785145623343, 41.717800753457205, 21.845544576644897, 5.032870760985783, 0.059964466973074844, 0.025624211711276854, 0.03776108107662626, 0.010892526895206953, 0.025518282216840556, 0.012905963363924196, 0.08290822617709637, 0.06887781154364347, 0.049629907057221444, 0.04111751561452236, 0.0399549883524222, 0.039239378180354834, 0.046655650583228896, 0.01152831335951175, 0.0018412893779376255, 0.024326013068535497, 0.05379659722426108, 0.012443037088295179, 0.026143677765503526, 0.015409416618889995, 0.08011933189949819, 0.049493104219436646, 0.05469091994954007, 0.03787759232467838, 0.02183604908974043, 0.04980652293722544, 0.043051876460335085, 0.013663250005005725, 0.01968725930367197, 0.002918952689339806, 0.03806738196206944, 0.033589746337383986, 0.06201781571975776, 0.019940648028360944, 0.033084061329386065, 0.027123657055199146, 0.04794925384755645, 0.015155490155198743, 0.010048653248564472, 0.025440245600683347, 3.8939268248421803, 31.587528705596924, 53.441392013004844, 43.75573171888079, 32.2875006539481, 30.28667654309954, 33.00755984442574, 40.817678996494834, 26.63542250224522, 3.769934049674443, 0.11352472366499049, 0.07451155888182776, 0.5135020028267587, 2.9228222710745673, 5.3762624604361395, 10.401399442127772, 8.50556434903826, 6.499070508139474, 24.15877706663949, 45.23333215713501, 48.4488160269601, 46.70485986982073, 42.321699959891184, 38.48362275532314, 40.41499614715576, 45.22401114872524, 48.00225877761841, 43.94488600322178, 48.15171800340925, 44.39512232371739, 40.566161155700684, 36.268391132354736, 34.03744963237217, 34.01400293622698, 36.126915386744905, 37.045585359845845, 40.66756664003645, 38.46008573259626, 37.12535762786865, 33.47250550133841, 33.24467059544155, 32.38963917323521, 30.790799617767334, 33.17595638547625, 33.50662463051932, 32.992343289511545, 33.93719754900251, 41.808561597551616, 45.01342861992972, 47.40280989238194, 46.73187099184309, 46.69372190747942, 43.35857963562012, 36.53816883904593, 34.07057169505528, 33.75436265127999, 32.82447828565325, 34.407934529440745, 35.54422208241054, 33.15564680099487, 34.751217229025706, 35.07140759059361, 35.35570008414132, 37.12780686787197, 43.76905836377825, 43.926025118146626, 49.20062153679984, 42.255421093532014, 32.17741686957223, 47.65479326248169, 46.50978224618094, 46.63695165089199, 43.217406136649, 45.361988476344514, 41.94928693771362, 44.60297073636736, 42.68657766069685, 42.458405767168315, 42.57980121885027, 38.10639810562134, 33.152620860508506, 35.44659641810826, 34.63581459862845, 35.61567040852138, 34.28328732081822, 34.31290054321289, 35.43613590512957, 38.219834395817344, 35.43366929462978, 34.6188644681658, 32.975191661289756, 33.39155203955514, 33.74947806767055, 33.400289399283274, 34.25844056265694, 37.68035888671875, 41.35234982626778, 45.27065787996565, 49.11478696550642, 47.67892435618809, 40.715394565037315, 45.60976818629673, 43.05957433155605, 47.37133455276489, 48.828663621629985, 48.15043953486851, 44.99729837690081, 46.7240230015346, 48.39268847874233, 44.736695766448975, 40.72912767955235, 38.50154563358852, 42.47748899459839, 46.54687173025948, 51.9446701322283, 52.45598111833845, 47.169305256434846, 30.064747606004985, 19.458133118493215, 9.539742044040135, 6.51086550951004, 10.436739717211042, 3.760046328817095, 2.9601988026074, 0.39996461091297014, 0.06418946026159184, 0.592912801674434, 11.486458795411245, 38.19651624134609, 47.185383387974326, 38.589384760175435, 44.08931473323277, 50.46450580869402, 50.83231912340437, 27.855258669172013, 5.922270144735064, 0.03577438821750028, 0.09548122901469469, 0.0368488246708044, 0.03516365920326539, 0.04287217324599624, 0.04269098064729145, 0.09617545176297426, 0.009454690834640391, 0.0610857732327921, 0.03795565438589879, 0.01912234497389623, 0.04787436393754823, 0.03265336461897407, 0.006129110556295407, 0.06613430447344269, 0.007305804357331778, 0.0423785966954061, 0.07421212137809821, 0.023959934944286942, 0.14750235793845995, 0.21588936474706444, 0.17196632735431194, 0.11430423147976398, 0.16248141202543462, 0.09170269819774798, 0.10208035526531083, 0.11257504605289016, 0.09330237164561238, 0.13859632797539234, 0.07344536323632513, 0.09396313583212239, 0.14577811903187207, 0.16380254684814385, 0.14971169510057994, 0.06488151169781174, 0.14386287251753466, 0.12306363002530166, 0.07253924078707184, 0.13662664938185895, 0.1751486158796719, 4.443085517202105, 36.00370298113142, 59.33587891714913, 50.86110551016671, 36.97162525994437, 40.08867400033133, 32.45102998188564, 40.19678449630737, 31.80864817755563, 4.88629503761019, 0.2035274337977171, 0.3591345804078238, 1.0706763650689806, 6.6636698586600165, 11.964834451675415, 13.14885699748993, 11.021647759846278, 7.4023458787373135, 25.944625650133403, 44.38712842123849, 51.7708956854684, 48.10184383392334, 45.98523841585432, 40.469296319144114, 43.241457326071604, 47.98716729027884, 51.034483909606934, 44.49992547716413, 49.49481521333967, 45.75199086325509, 42.78511701311384, 37.23624392918178, 35.381404944828574, 36.22424922670637, 38.19303171975272, 39.476829528808594, 42.96447433744158, 39.411262852805, 38.75464071546282, 35.36567769731794, 36.3066201210022, 34.72209732873099, 31.89379140308925, 35.01422391619001, 34.55626467296055, 34.67132684162685, 36.83903626033238, 44.06701796395438, 47.11970901489258, 49.98355497632708, 49.469325746808735, 48.251938819885254, 46.422731740134104, 38.89109986168997, 36.25178146362305, 36.54159082685198, 35.17829172951834, 35.05832413264683, 37.40127059391567, 35.47853033883231, 35.83284330368042, 36.88454696110317, 36.592052119118826, 38.75335529872349, 44.08965866906302, 46.832404477255686, 52.154008933476035, 44.192832469940186, 35.61025081362043, 47.52562277657645, 49.05807229450771, 48.59305715560913, 45.84554835728237, 46.83633368355887, 44.993136405944824, 46.05894490650722, 44.70701306206839, 43.769475255693706, 45.05990859440395, 40.23940474646432, 34.87216452189854, 38.3596008845738, 35.93053844996861, 37.14442001070295, 35.444390365055625, 34.87890427453177, 37.213874203818186, 39.93799189158848, 38.59044088636126, 35.93636451448713, 33.720924445560996, 34.925901889801025, 34.91520166397095, 35.889985288892476, 35.952539920806885, 39.86145053591047, 43.67764786311558, 47.194165910993306, 50.36991998127529, 48.14671182632446, 41.02011128834316, 45.919848918914795, 43.68796246392386, 48.07639953068325, 49.97564097813198, 51.121273858206614, 47.26852553231375, 47.79878078188215, 50.6663544518607, 47.9609135219029, 41.68950768879482, 41.039409909929546, 43.25193520954677, 50.53259120668684, 54.18560314178467, 54.52535615648542, 49.75754744665963, 34.981167861393516, 18.483545780181885, 11.587880781718663, 9.407388414655413, 14.46345443384988, 17.519262620380946, 6.519893825054169, 1.5274034972701753, 0.21100836380251817, 0.8463728811059679, 13.414936525481087, 43.749176093510215, 55.99821444920131, 48.951056139809744, 52.613375186920166, 55.75766086578369, 58.8035774230957, 35.54904065813337, 6.857209324836731, 0.09992282425186463, 0.25391122379473274, 0.15751993682767662, 0.09988184752208845, 0.09810892372791256, 0.05326535180211067, 0.2261265039976154, 0.09860655452523913, 0.1785091148423297, 0.1590995934924909, 0.14916175603866577, 0.1682373567351273, 0.15215336265308516, 0.18473539288554872, 0.11937070318630763, 0.1179194524884224, 0.09873767463224274, 0.16548521869948932, 0.14727419375308923], [0.07256313200507845, 0.01933540327341429, 0.03893960140911596, 0.06320865146283593, 0.041688088926353624, 0.019996584758960774, 0.024531863629817963, 0.049770139889525514, 0.04154438878010426, 0.02807083765843085, 0.051579056573765616, 0.01601851375640503, 0.0655762908448066, 0.021093297516927123, 0.03979658095964363, 0.033286515822900195, 0.04430319681497557, 0.019825091818347573, 0.05069026051621352, 0.02388927400378244, 0.03329585925010698, 0.7347070787634168, 17.30682839666094, 44.49673277991158, 44.596620082855225, 35.72945063454764, 20.585129192897252, 21.320222548076085, 33.37316710608346, 27.014010735920497, 5.8017145565577914, 0.12846639725778783, 0.13367518489914282, 0.589249309684549, 1.5172230835471834, 4.0859428984778265, 8.442466020584106, 4.566854212965284, 2.0868619169507707, 11.840872509138924, 33.691689899989534, 49.04749018805367, 45.301500933510916, 44.158376353127615, 39.02051700864519, 40.53645413262503, 45.017739977155415, 46.56080286843436, 46.65611130850655, 45.298113686697825, 43.85775211879185, 40.31682504926409, 34.412666252681184, 32.11545283453805, 31.096614156450542, 32.361637932913645, 33.414627007075715, 34.788372720990864, 34.347975049700054, 32.345841203417095, 35.67246150970459, 32.47689117704119, 29.717205660683767, 32.539796692984446, 31.51910284587315, 34.53366218294416, 37.76175703321184, 39.161718300410676, 41.43598181860787, 42.57906123570034, 44.782359327588765, 45.0458801814488, 44.35431555339268, 45.32089682987758, 43.035182680402485, 36.30645336423601, 31.57159996032715, 33.076312269483296, 30.99567767551967, 33.1210378238133, 31.62535469872611, 34.35319662094116, 33.54497521264212, 34.71879693440029, 35.28543642589024, 39.75985050201416, 42.54470239366804, 45.785404750279014, 42.53027793339321, 34.13620785304478, 48.07108415876116, 43.898538044520784, 43.61256061281477, 41.07047183173043, 40.70132098879133, 38.3486123085022, 40.89681550434658, 39.286195278167725, 39.37185614449637, 39.80407926014492, 35.807096753801616, 31.674749442509242, 33.57954944883074, 33.65867900848389, 33.52541255950928, 33.86646836144583, 37.305086680821006, 40.735916069575715, 43.599918365478516, 41.93533842904227, 36.78236675262451, 33.12557847159249, 32.97538273675101, 33.28927455629621, 35.40985434395926, 33.0006012235369, 37.98846285683768, 42.78005872453962, 44.537838322775706, 44.26915495736258, 43.107822622571675, 47.182989733559744, 45.84409270967756, 49.022487095424104, 46.60080712182181, 45.01125383377075, 45.853973048073904, 48.8970547403608, 45.605234486716135, 49.01231493268694, 44.04611778259277, 40.769805908203125, 38.6159234046936, 38.498530115400044, 40.32625722885132, 45.193376541137695, 45.39740344456264, 45.15119055339268, 28.62764126913888, 18.234735999788555, 3.902876538889749, 8.928894639015198, 5.433146493775504, 0.8161873008523668, 2.679238621677671, 0.22493480651506356, 0.04456030730424183, 0.9702100817646299, 11.975878613335745, 35.20217963627407, 34.885675294058665, 27.082271575927734, 29.48523657662528, 45.89267798832485, 47.278054986681255, 22.47256565093994, 2.5428626367024014, 0.040672718946422846, 0.03257421011637364, 0.05181167873420885, 0.03305980030979429, 0.03811236883380583, 0.03249171382880636, 0.027110272951956307, 0.035936724328036816, 0.06353666207620076, 0.05151518267978515, 0.054187168766345294, 0.027844946565372602, 0.03564792286072459, 0.019229953842503682, 0.014180520998447068, 0.027000774363321916, 0.08260023234678165, 0.05169716577178665, 0.040371466361518414, 0.043515013929988654, 0.03431365838540452, 0.029613029012190442, 0.08125239717108862, 0.0013849824234577163, 0.027950884541496634, 0.08170619460621051, 0.05171095360336559, 0.02544988419062325, 0.04016217562769141, 0.0177202117296734, 0.02769493095443717, 0.032057858537882566, 0.006505041009014738, 0.055300268145012, 0.029661802109330893, 0.01193317654542625, 0.015111443054463183, 0.02863806239994509, 0.018046885629051497, 0.041441746787833314, 1.1046379655599594, 22.218148674283707, 49.67305040359497, 50.27593864713396, 39.02424471718924, 26.96447876521519, 22.945067473820277, 35.27512877328055, 30.116796561649867, 6.604371326310294, 0.2193008895431246, 0.11604972210313592, 0.5039128916604179, 2.414871173245566, 3.1923583107335225, 5.994408513818469, 7.899616292544773, 4.4549543431827, 15.503503356661115, 36.612358229500906, 50.1420190674918, 46.531867095402305, 45.655869483947754, 41.16375487191336, 42.93428441456386, 47.229306425367085, 48.72026130131313, 46.71431636810303, 47.74388653891427, 45.52574709483555, 42.56525863919939, 36.192961488451274, 33.61281394958496, 33.034515380859375, 33.55789538792202, 35.77555888039725, 36.457833766937256, 36.22882808957781, 33.71171808242798, 35.547894205365864, 33.66537012372698, 30.931452001844132, 34.06043774741036, 31.675555433545792, 36.414331095559255, 37.53737538201468, 40.77156032834734, 42.20390714917864, 44.945912974221365, 45.51852791649954, 46.697084835597444, 46.086008140019004, 46.22152233123779, 43.106168951307026, 37.571286065237864, 33.319315092904226, 34.28892578397478, 32.47277784347534, 33.84903533118111, 34.310169901166645, 35.55666978018624, 34.651065894535606, 34.72223629270281, 37.022878646850586, 41.375018324170796, 44.46957574571882, 47.38560267857143, 44.619354588644846, 35.20581007003784, 48.83355515343802, 45.97510099411011, 45.07101876395089, 43.48878540311541, 42.72631788253784, 40.13436535426548, 42.82812636239188, 41.40662567956107, 41.627300466809956, 42.40690571921212, 37.505299023219514, 32.52298552649361, 36.517268657684326, 34.79609216962542, 34.599058628082275, 35.496606077466694, 38.68391500200544, 42.514755657741, 45.362110069819856, 43.397604193006245, 38.97082001822335, 33.59094796861921, 35.06793349129813, 34.12022352218628, 36.185269832611084, 33.30792352131435, 39.201531478336875, 44.28435066768101, 45.8167793410165, 46.44921132496425, 45.12552390779768, 47.3660226549421, 46.76080329077584, 49.16908713749477, 47.88368082046509, 46.97699301583426, 47.1863283429827, 49.50306619916643, 47.1187675339835, 49.57252039228167, 46.91264574868338, 42.923865590776714, 41.43685729163033, 41.33619179044451, 44.32226698739188, 48.868977069854736, 49.35735552651541, 47.692459447043284, 30.454155921936035, 19.54794900757926, 7.9629517282758435, 6.030756711959839, 12.74272002492632, 5.690346658229828, 4.079838906015668, 0.18540579905467375, 0.11210349814168044, 0.9705064658607755, 13.701655677386693, 39.11094433920724, 42.72401108060564, 33.70965794154576, 37.314303466251914, 50.26585333687918, 53.983688490731375, 27.71416507448469, 3.3335446204457964, 0.040504930807011466, 0.07092317393315689, 0.03352124822725143, 0.10868848567562443, 0.04338010759758098, 0.04865081495206271, 0.05734090453812054, 0.03159475838765502, 0.0409838001110724, 0.04082836130900042, 0.03404114854389003, 0.03218816440286381, 0.03357833677104541, 0.05013392626174858, 0.034546341613999436, 0.060281112124877315, 0.02490574829945607, 0.05094697745516896, 0.011440833232232502, 0.19929995707103185, 0.1366380623408726, 0.15855417347380094, 0.24629892941032136, 0.11766919520284448, 0.11660344739045415, 0.14699622509734972, 0.09705573559871741, 0.11604447024209158, 0.17055949355874742, 0.1527383548340627, 0.06906161989484515, 0.19073609874716826, 0.09275863439376865, 0.152169403220926, 0.12607959604689054, 0.12696507067552634, 0.1185160611889192, 0.08988770523241588, 0.13434618817908422, 0.14224835272346223, 1.5914638255323683, 27.73712192262922, 55.769660404750276, 56.4858911378043, 46.14866699491228, 30.840128353663854, 29.215250423976354, 43.088697705950054, 34.551011834825786, 8.412425483976092, 0.2767756011869226, 0.3944482297769615, 1.3425268062523432, 4.7087333883558, 11.453456589153834, 16.081567423684255, 7.918188827378409, 3.736241800444467, 14.723385674612862, 37.60090276173183, 53.114840575626914, 48.999266215733115, 48.054915700639995, 43.388675757816856, 45.319277899605886, 49.75329862322126, 49.63885831832886, 46.01784978594099, 49.320186138153076, 47.82042442049299, 44.26925570624215, 38.28309774398804, 36.729400634765625, 34.71914781842913, 34.934587138039724, 36.17092875071934, 37.17435285023281, 38.56117507389614, 35.174855845315115, 38.423496518816265, 36.10129043034145, 32.1516147341047, 35.57037162780762, 33.94455221721104, 38.54205015727452, 40.42009612492153, 42.98632294791085, 45.157204219273154, 47.18561615262713, 48.40100547245571, 47.97140530177525, 47.34354523250035, 47.124114172799246, 48.03197969709124, 40.99783188956124, 35.604310103825156, 36.258983271462576, 34.111764090401785, 36.433650561741416, 35.46333810261318, 38.664220333099365, 36.17815835135323, 36.93175302233015, 40.00632047653198, 43.42104394095284, 48.1310783794948, 49.423359939030235, 46.97225087029593, 37.857913153512136, 47.981685161590576, 48.37960502079555, 45.34645925249372, 45.59080307824271, 45.10272339412144, 42.30667795453753, 44.6635798726763, 43.74454164505005, 43.07273769378662, 44.61272948128836, 40.01988683428083, 34.31042351041521, 37.474112033843994, 37.332990646362305, 36.898898465292795, 37.24897302900042, 41.71093940734863, 44.87495797021048, 46.95051690510341, 44.86870459147862, 40.32612868717739, 35.93473168781826, 36.22921371459961, 37.9551670891898, 39.99949734551566, 35.488355091639924, 40.464700085776194, 47.86528199059622, 47.78363718305315, 48.07876886640276, 48.43867860521589, 48.934224128723145, 47.31841707229614, 52.297767162323, 49.564655031476704, 48.49319069726126, 49.004404408591135, 50.894984926496235, 48.734334877559114, 51.348268032073975, 48.58433716637747, 47.23695986611502, 43.10708611352103, 43.7890795980181, 47.20962217875889, 49.18986572538103, 50.62234108788626, 49.74707303728376, 32.33451911381313, 22.384158509118215, 8.266393457140241, 13.254386237689427, 12.106443950108119, 6.95543600831713, 8.388284836496625, 0.9410361157996314, 0.20789973703878267, 1.5483768518481935, 15.319572380610875, 45.514532702309744, 44.38208750316075, 36.07585654939924, 40.82036794934954, 58.18389885766165, 65.75651468549455, 34.59316308157784, 4.651118491377149, 0.14237647370568343, 0.11946041908647333, 0.12560914057706082, 0.1776189583220652, 0.11885181388684682, 0.13877744254256996, 0.15848006387906416, 0.12355729139276914, 0.16234023602945463, 0.1497786800776209, 0.22042936113263878, 0.08318579449717488, 0.16898248318050588, 0.19165533727833203, 0.1272567728800433, 0.11434398006115641, 0.1720551068761519, 0.22780963725277356, 0.07910903396883182], [0.043583993799984455, 0.03146102252815451, 0.08580239516283784, 0.06072686892002821, 0.026941202381359677, 0.020742172608152032, 0.06866074140582766, 0.008615380335998322, 0.056373008260769505, 0.03627705035199012, 0.0173726813601596, 0.036435824153678756, 0.017402251916272298, 0.001187984729767777, 0.01826011186598667, 0.05413928794275437, 0.09395042687122311, 0.04749992456553238, 0.046705631472702534, 0.08407829874860388, 0.04405999968626669, 0.355700216123036, 15.15940945489066, 43.385528223855154, 48.80288233075823, 37.27494886943272, 28.534712587084087, 26.888368197849818, 35.36131075450352, 35.022089276994976, 8.611446210316249, 0.7723480218223163, 0.04060900450817176, 0.2785496988466808, 1.1091343185731342, 0.15335027128458023, 7.304398860250201, 14.151103377342224, 5.214299517018454, 9.212110161781311, 26.55224735396249, 40.111394609723774, 49.536108357565745, 44.1426352092198, 41.167051792144775, 43.09623997552054, 45.61493764604841, 46.51268311909267, 41.673992361341206, 45.962656770433696, 44.13095528738839, 40.42240987505232, 34.90393515995571, 32.62001711981637, 30.07270676749093, 30.33894784109933, 31.170657634735107, 32.61429875237601, 32.5831812449864, 31.878029414585658, 33.111504895346506, 30.77439144679478, 32.39616700581142, 33.07119492122105, 34.160575185503276, 43.36774778366089, 43.08700581959316, 43.6000052179609, 41.99402986254011, 43.38033791950771, 41.72593361990792, 44.84437200001308, 44.90706212180001, 45.35011053085327, 43.64805548531668, 40.66694130216326, 32.95446171079363, 31.261130128587993, 32.55714634486607, 33.626460211617605, 30.511652265276226, 32.5472868510655, 33.02956131526402, 33.87329496656145, 34.44429097856794, 39.81095797674996, 42.153094972882954, 45.99690096718924, 42.898862498147146, 31.801620074680873, 45.700153827667236, 46.74185902731759, 43.809837341308594, 41.022619588034495, 40.00444793701172, 37.61444827488491, 37.517142227717805, 37.27113430840628, 37.19512101582119, 34.88491446631295, 34.77549076080322, 35.019911016736714, 32.46935238157, 32.95529202052525, 32.860508169446675, 33.93871920449393, 42.34734228679112, 45.94202062061855, 47.147772789001465, 45.86264092581612, 41.46118640899658, 35.42864574704851, 32.68445471354893, 32.60435240609305, 31.997910158974783, 33.3039665222168, 35.34491647992815, 43.03026335580008, 44.02063873835972, 46.506356784275596, 44.82865170070103, 48.870776653289795, 44.828811509268625, 45.65720353807722, 45.82019438062395, 46.447067805698936, 45.13915279933384, 47.02906281607491, 46.48896891730172, 48.25811924253191, 47.57845687866211, 43.895279339381624, 41.3070718901498, 38.73799630573818, 37.82290465491158, 44.51874119894845, 45.818815163203645, 47.61234671728951, 29.098956687109812, 23.813785110201152, 11.228486946650914, 3.698493540287018, 17.393660034452164, 2.7433199031012396, 0.9555481885160718, 0.22809304775936262, 0.06928145845553704, 0.8952318536383765, 13.834631170545306, 35.35571050643921, 33.9948537009103, 29.622574669974192, 31.737255437033518, 45.92881209509713, 50.37485320227486, 23.74147173336574, 1.503031387925148, 0.08103831258735486, 0.07810886656599385, 0.0464148724318615, 0.04445066622325352, 0.07306636750165905, 0.026200859607862573, 0.029671454269971167, 0.03542996044935925, 0.034264356030949523, 0.023227308810289417, 0.053829954005777836, 0.03786924295127392, 0.013444679456629922, 0.02590870957023331, 0.06343067490628787, 0.02688046671184046, 0.0412421489267477, 0.022455872169562748, 0.07595753736261811, 0.02220034266688994, 0.042363210913858244, 0.048196980197514804, 0.02316732801097844, 0.011382961828660752, 0.03689299390784331, 0.03409623201670391, 0.03370138570400221, 0.039773934853396246, 0.03315814717539719, 0.12614801951817103, 0.011973212656032826, 0.04861740728041955, 0.05754857696592808, 0.01207767821116639, 0.019044403352641633, 0.007700406397426767, 0.04174211388453841, 0.061754652698125155, 0.04597156514812793, 0.042922493402979205, 0.5796101497752326, 17.780269963400706, 47.0146244594029, 53.75080224445888, 41.64590426853725, 30.348845549992152, 27.10905167034694, 37.62755952562605, 40.153028215680806, 9.812550033841815, 0.8135936143142837, 0.06918994443757193, 0.46696123161486214, 1.833501500742776, 2.0381185667855397, 8.14956818308149, 7.50909800188882, 5.271036335400172, 13.623862777437482, 30.830963679722377, 44.249154567718506, 50.11077649252755, 45.232289927346365, 42.323141711098806, 45.05021933146885, 47.03316920144217, 47.846702507564, 42.31650965554373, 47.5327273096357, 47.43732854298183, 42.34094646998814, 36.31533316203526, 33.49807139805385, 33.001011167253765, 32.483078547886436, 33.88675710133144, 34.44980090005057, 34.05921833855765, 33.40712642669678, 35.214036737169536, 33.359215123312815, 32.55913005556379, 35.44477946417672, 34.7549101965768, 43.24881199428013, 45.471228054591585, 44.71917240960257, 44.44164398738316, 45.82566608701433, 45.31332676751273, 47.30190467834473, 45.723287854875835, 47.48605973379952, 46.00332457678658, 40.634052004132954, 34.91709852218628, 33.14882019587925, 33.44332306725638, 33.19494233812605, 32.220797947474885, 33.77271631785801, 34.6263997895377, 34.56820167813982, 35.99958964756557, 41.72765677315848, 42.82314797810146, 47.088553292410715, 43.50373445238386, 34.8988664490836, 48.06115518297468, 47.10682705470494, 46.727698598589214, 43.660760266440256, 42.21001808983939, 40.010267053331646, 39.08370392663138, 38.94705023084368, 38.865669454847065, 37.51656552723476, 35.61993660245623, 35.89462668555123, 34.06605536597115, 35.25091430119106, 34.449463912418906, 35.62197242464338, 42.447146211351665, 47.46831056049892, 49.00461285454886, 46.0863937650408, 42.72043623243059, 37.71103865759713, 33.947678906576975, 34.620031765529085, 34.457360540117534, 34.924262114933555, 37.041854177202495, 45.770570346287315, 46.812087944575715, 47.824138232639854, 47.142721448625835, 47.970981461661204, 46.71576854160854, 47.85045453480312, 47.49227489743914, 47.88621343885149, 47.51407834461757, 49.7896272795541, 47.85833726610456, 50.02168321609497, 47.7824455669948, 46.200608253479004, 43.0511531148638, 40.855598790305, 41.48758956364223, 46.71032462801252, 49.12501123973301, 49.392558574676514, 30.74991294315883, 21.0125059400286, 8.610058307647705, 8.223418848855154, 16.07481724875314, 7.976786460195269, 1.6281497712646211, 0.15986456030181476, 0.020265176060742567, 1.4349665088312966, 15.368465117045812, 40.03840030942644, 34.62333563395909, 28.090846027646744, 34.634192194257466, 52.13223327909197, 56.020347935812815, 27.124327284949167, 2.557932410921369, 0.040620183372603993, 0.05402557225897908, 0.022113851504400373, 0.02827915978351874, 0.040608420968055725, 0.03926110487165196, 0.008274989003049476, 0.042432058469525406, 0.004700753629939365, 0.03612420355368938, 0.02727317394289587, 0.007490582165441343, 0.03626115906185337, 0.02347582734988204, 0.02118059104707624, 0.05121565018115299, 0.012784398726320692, 0.049745017130460055, 0.10746817437133618, 0.1321729626506567, 0.15814968517848424, 0.14290160552731582, 0.20243862936539309, 0.11782761955899851, 0.21138176162328037, 0.10107307003012725, 0.09151645390582935, 0.19671092528317655, 0.12899192262973103, 0.2681897447577545, 0.14018184718276772, 0.1513021404721907, 0.08966718135135514, 0.08654389144586665, 0.08379135307456766, 0.21460689284971782, 0.16091871873608657, 0.11829469592443534, 0.10425206087529659, 0.20520384955619062, 0.6771081952112061, 21.381394488470896, 53.969771248953684, 60.915294783455984, 48.35480342592512, 38.39197949000767, 34.66093928473336, 45.769472530909944, 44.664563042776926, 11.831964918545314, 1.3919574852500642, 0.25091790727206637, 1.850061446428299, 5.064165447439466, 6.464550120489938, 17.19908962930952, 20.823848451886857, 10.368085435458593, 11.408887369292122, 31.30860369546073, 44.07160030092512, 53.89483492715018, 46.411208152770996, 45.70977013451712, 46.98025866917202, 49.71386064801897, 48.636938503810335, 43.958660806928364, 49.85611459187099, 49.13978658403669, 43.77826125281197, 37.5519631249564, 35.02043907982962, 33.95932756151472, 33.532235690525596, 34.82183871950422, 36.90495729446411, 35.80645751953125, 34.8905668258667, 37.16387496675764, 33.88190031051636, 34.90222937720162, 37.278051240103586, 36.921191760471885, 45.51672485896519, 47.002294881003245, 47.14409719194685, 46.98659195218767, 48.062788009643555, 46.662785053253174, 48.45553840909685, 47.69479751586914, 48.78344474520002, 47.5318865776062, 43.95042371749878, 37.05121687480381, 35.51013422012329, 36.110673972538535, 36.51301636014666, 33.84646449770246, 35.682077816554475, 36.45221962247576, 35.336446625845774, 38.08919784000942, 42.41055004937308, 44.301332065037315, 50.140504360198975, 47.15935543605259, 39.40710435594831, 49.91980872835432, 48.364951269967214, 49.21096740450178, 44.20041642870222, 43.688876152038574, 40.90684870311192, 40.6262526512146, 41.013281209128245, 40.63783877236502, 37.31610999788557, 37.19920655659267, 38.04456956045968, 36.81904976708548, 36.37480974197388, 36.12779433386666, 37.233509813036235, 46.58802591051374, 48.17891672679356, 50.10735103062221, 49.034340722220286, 44.929372787475586, 39.49178900037493, 36.18729870659964, 35.91120508738926, 35.63406923839024, 37.48170641490391, 39.73770659310477, 48.03496742248535, 49.109485489981516, 50.50875193732125, 48.34255027770996, 50.91149732044765, 48.33522687639509, 50.08917801720755, 50.04174961362566, 49.949130126408164, 48.361529282161165, 51.15951674325125, 50.35060051509312, 52.14134236744472, 51.53118978227888, 47.776779311043875, 45.90632425035749, 43.22251306261335, 43.213793073381694, 50.78821195874895, 50.552567277635845, 53.15787771769932, 32.45467778614589, 28.289034707205637, 16.11286732128688, 11.99943126950945, 30.807544776371547, 9.032111866133553, 3.841514391558511, 0.7927282825112343, 0.19079775043896266, 1.7675559307847704, 18.269747972488403, 45.71088184629168, 44.43484170096261, 39.95078352519444, 43.93473815917969, 57.08852924619402, 63.71327877044678, 33.641287667410715, 3.8186213799885342, 0.17006032248692854, 0.16106551300202096, 0.1018951694880213, 0.13694836997560092, 0.17421758440988405, 0.2361518181860447, 0.1405148178871189, 0.13650401096258843, 0.12860960885882378, 0.1248735814754452, 0.2225541528314352, 0.11512295183326517, 0.09260161460510322, 0.10711988234626395, 0.11597194841929845, 0.15085079254848616, 0.11050529711480651, 0.09987296549869434, 0.207698754966259], [0.037679480455283604, 0.12113262792783124, 0.024313723103010228, 0.02424637002072164, 0.008738902547130627, 0.044925328610198836, 0.05504611946110215, 0.017487620103306005, 0.021758095594123006, 0.033283516698117764, 0.039522127115300724, 0.04903432633727789, 0.012040612387603946, 0.044515927721347125, 0.01137061758033399, 0.00982414127793163, 0.06174029489713056, 0.051509761184986146, 0.043160302963640006, 0.012698247679509223, 0.09075633183653865, 0.2053316177002021, 7.912451352391924, 35.838617256709504, 47.56537342071533, 45.204333850315635, 31.916185447147914, 20.005390610013688, 27.854006256375992, 30.595659460340226, 14.933695486613683, 1.2918438230242049, 0.03899031511640974, 0.34439310857227867, 1.2697197816201617, 1.5065763805593764, 0.9272493698767253, 3.5993331926209584, 3.635355693953378, 5.155555537768772, 14.558404173169817, 39.231109959738596, 46.070961815970286, 45.57979365757534, 43.13910688672747, 44.07518557139805, 45.188026428222656, 43.78562634331839, 44.86605732781546, 45.42190279279436, 44.11512034279959, 38.64633914402553, 34.97663763591221, 31.60673005240304, 30.485082353864396, 31.109516961233957, 32.217917919158936, 31.72134406226022, 31.219555582318986, 31.05924674442836, 31.74916464941842, 29.64949893951416, 31.86801358631679, 31.959184374128068, 41.000024046216694, 43.77630533490862, 46.062943594796316, 43.68170213699341, 42.83073193686349, 39.81519290379116, 41.716164452689036, 42.487303325108115, 45.25699424743652, 44.54941749572754, 44.736035687582834, 42.47407048089163, 37.8265837260655, 32.68922117778233, 32.39245319366455, 32.14049414225987, 33.16615942546299, 32.64053862435477, 32.53133031300136, 34.978451115744456, 37.31261157989502, 38.58227327891758, 42.7571678842817, 41.529567105429514, 45.562975542885916, 24.552500213895524, 36.724359716687886, 50.79326329912458, 46.791712352207725, 45.87790959221976, 45.13193709509713, 42.18435491834368, 35.64158024106707, 35.75625678471157, 33.6475236756461, 35.50770582471575, 33.539816175188335, 34.17505523136684, 32.32028225490025, 34.81345919200352, 32.572543552943635, 38.46284416743687, 45.50003181185041, 46.96613645553589, 48.786720820835654, 47.59866918836321, 43.52923781531197, 39.400545256478445, 32.56605046136038, 32.0453177179609, 32.196847506931846, 32.60350472586495, 34.689201082502095, 37.86895384107317, 44.02298028128487, 45.35498816626412, 45.215225151606965, 44.52065890175955, 43.1361643246242, 41.85137292316982, 42.063518796648296, 40.722752707345144, 42.45760325023106, 44.0313389641898, 46.661371094839915, 47.00099209376744, 45.41089684622628, 48.55530064446585, 46.22787993294852, 41.76127215794155, 39.17449256352016, 44.21943712234497, 46.51048401423863, 45.72189474105835, 29.88006101335798, 21.663473980767385, 7.007222235202789, 5.037652858666011, 13.60119080543518, 7.456455843789237, 2.538023216383798, 0.20032499278230326, 0.0538427240348288, 1.3594702056476047, 15.900641543524605, 35.19246258054461, 37.976386887686594, 28.987187964575632, 44.11220209939139, 43.587404659816194, 44.58136878694807, 17.523487125124248, 1.118782326579094, 0.011025628324465027, 0.029075123768832003, 0.015433609784979905, 0.06306796401206936, 0.01712027990392276, 0.05969649313816002, 0.02264900698459574, 0.025465174977268492, 0.03051401155867747, 0.08638731270496335, 0.04564072165106024, 0.04403833067044616, 0.003927713526146752, 0.019659476687333415, 0.0315085199794599, 0.056863368555371246, 0.03863807062485388, 0.0414113789530737, 0.03643467742949724, 0.046405288124723096, 0.12130435157035079, 0.04528108112780111, 0.06277206167578697, 0.025096498063898513, 0.007361120228389544, 0.026436731951045137, 0.05922383242951972, 0.017125211157170788, 0.01886012002692691, 0.04242916451767087, 0.0354309375397861, 0.05360909424988287, 0.044276832336825986, 0.029509240295737982, 0.025447288794176917, 0.06440663217966046, 0.038045536527144055, 0.06082862203142472, 0.011080460739322007, 0.0507720511273614, 0.1734767055937222, 10.172962648527962, 42.44503048488072, 52.60999141420637, 48.55381025586809, 37.448462758745464, 24.215896470206125, 34.68787745067051, 37.98488106046404, 16.09941734586443, 1.5404030340058463, 0.11162015050649643, 0.0791140551279698, 2.376623728445598, 2.1336612914289748, 6.533028960227966, 6.607058976377759, 7.219240001269749, 10.258688654218401, 20.69435313769749, 39.45915331159319, 49.603679588862825, 46.55483089174543, 47.37287705285208, 45.71665927342006, 47.21011202675955, 45.50489902496338, 43.623521396092, 46.222971030644004, 46.40887008394514, 42.29035316194807, 37.55968257359096, 32.69517230987549, 31.674884932381765, 32.95297132219587, 33.00943585804531, 33.73435878753662, 33.00602081843785, 33.61574261529105, 33.612525599343435, 31.289221695491246, 33.37064143589565, 34.11216708592006, 42.28537130355835, 47.17743812288557, 46.80176639556885, 45.80505425589425, 44.78347103936331, 42.44090672901699, 43.40221084867205, 45.303859846932546, 47.8697635786874, 46.776381152016775, 46.99851853506905, 44.56125375202724, 38.29317263194493, 33.60856165204729, 34.23413923808506, 33.627419063023154, 34.182076386043, 33.38734490530831, 33.15121732439314, 37.395076274871826, 37.36430965151106, 39.71284941264561, 43.864297321864534, 43.90474625996181, 46.101658957345144, 29.89383234296526, 39.36427913393293, 51.74448210852486, 49.07699918746948, 46.33868980407715, 47.4829226221357, 43.11674063546317, 37.52090120315552, 35.64173657553536, 35.68360989434378, 36.55167613710676, 35.740175179072786, 35.75695855276925, 33.05480759484427, 36.35136999402727, 34.00359106063843, 39.83245570319039, 47.248935086386545, 47.682933466775076, 52.004629611968994, 47.73211629050118, 45.94630071095058, 40.5436281476702, 34.24069486345564, 33.52281045913696, 33.60218667984009, 34.22170196260725, 36.07063497815813, 41.41861479622977, 45.66273430415562, 46.47364466530936, 48.17026621954781, 47.68172448022025, 45.185761315482004, 44.08743177141462, 43.466360092163086, 44.98367990766253, 45.36135271617344, 46.25554418563843, 48.84004824502127, 47.686713286808555, 47.62683023725237, 50.09325313568115, 47.884733472551616, 42.80218873705183, 42.99526527949742, 46.394261496407644, 51.524137360709055, 47.204299858638215, 30.751326901572092, 15.528593301773071, 7.086697033473423, 7.5286502327237805, 8.49077250276293, 9.44272347858974, 3.2676743950162614, 0.48434421313660486, 0.039154110077236376, 2.1691644149167195, 17.38872160230364, 41.17397914613996, 42.93910299028669, 37.151865005493164, 44.643610749925884, 49.350198881966726, 51.77810444150652, 22.09372901916504, 1.8052033334970474, 0.04456047693799649, 0.07036841727261033, 0.04606135229447058, 0.02429492598665612, 0.022669508920184205, 0.026116619485297372, 0.02712667653603213, 0.017319356989381567, 0.034529422343309434, 0.02125965734012425, 0.0626264548461352, 0.053229962808213065, 0.06063764835042613, 0.04325643441240702, 0.04114149504208139, 0.009404750657267869, 0.05970629796917949, 0.012901773410184043, 0.014094704130132283, 0.11442104806857449, 0.22667872293719224, 0.09482714161276817, 0.2553533006991659, 0.12135264969297818, 0.10336788903389658, 0.12568272091448307, 0.0807851647425975, 0.15908572423670972, 0.19897067759718212, 0.1971002279647759, 0.1602454220077821, 0.09472312897975955, 0.13603783026337624, 0.15506845765880176, 0.14878630904214724, 0.17561706288584641, 0.12793902627059392, 0.20427732355892658, 0.16555453783699445, 0.14431280908840044, 0.32099792680570055, 10.865004965237208, 47.001530579158235, 58.54855074201311, 55.70021315983364, 42.20498064586094, 30.193994522094727, 37.468463148389546, 40.19821235111782, 20.16597737584795, 2.215340622833797, 0.2584947007043021, 0.7875109996114458, 4.723483111177172, 5.275472325938089, 9.253369433539254, 11.416238563401357, 6.5037892035075595, 7.804734298161097, 17.9316086769104, 41.59443201337542, 49.17158154078892, 51.051378454480854, 48.043854168483186, 47.29518577030727, 50.43059859957014, 45.876655442374094, 45.88460765566145, 48.40255144664219, 49.03378486633301, 43.1193323135376, 39.79808643886021, 34.74549191338675, 33.61001035145351, 34.19347490583147, 34.51237290246146, 35.52886656352452, 34.61558491843087, 34.90642261505127, 35.40087379728045, 32.26100369862148, 35.9105658531189, 36.17237050192696, 46.37333699635097, 49.2492276600429, 49.33578831808907, 48.805091857910156, 46.16812195096697, 44.88205208097185, 47.243505069187705, 47.462592193058555, 49.752496106284006, 48.53952475956508, 49.044568470546174, 46.59275763375418, 41.37995849336897, 35.712090560368125, 35.36268997192383, 35.37179211207798, 36.52605812890189, 34.81036376953125, 35.3767010143825, 38.960328238351, 40.130279813494, 42.72187450953892, 47.124336515154155, 46.17377083642142, 47.91636167253767, 33.6327657018389, 40.55950130735125, 52.030921595437185, 51.511529854365754, 48.93513434273856, 50.07564640045166, 46.76762294769287, 39.49291113444737, 37.31856966018677, 37.15359858104161, 38.28672122955322, 37.83120775222778, 38.546816621507915, 35.58390324456351, 38.13607733590262, 36.642954621996196, 42.813854762486045, 49.15768166950771, 50.499420506613596, 52.56190987995693, 51.496122223990305, 47.75027888161795, 42.567318780081614, 35.78723185403006, 35.78804131916591, 35.73294905253819, 36.55178730828421, 38.5174674306597, 42.65092297962734, 47.07955190113613, 49.345686026981895, 49.15595851625715, 48.09172378267561, 47.6407196862357, 45.78269842692784, 46.280116489955354, 46.42850569316319, 47.97471611840384, 47.61790180206299, 50.42612048557827, 48.95074347087315, 47.84600073950631, 53.57356412070138, 51.872262954711914, 46.431059156145366, 44.97444575173514, 48.77396740232195, 53.12925113950457, 50.87119776862008, 32.63775587081909, 26.008373635155813, 11.532068508011953, 11.844045230320521, 25.866361141204834, 16.084652423858643, 4.2851764133998325, 0.6336030811071396, 0.4286606168108327, 2.5656470826693942, 21.339437791279384, 47.2938551902771, 48.33142621176583, 41.62992341177804, 56.47164733069283, 57.063647747039795, 58.846239362444194, 25.945424692971365, 2.4310602588312964, 0.21698993497661181, 0.17244800579335007, 0.09309986286929675, 0.19965939064111027, 0.15412479186696665, 0.11124380105840308, 0.21532893553376198, 0.07121152417468173, 0.13072141339736326, 0.17285144914473805, 0.11790010066969053, 0.17131785143698963, 0.12738284468650818, 0.11995492183736392, 0.23030746036342212, 0.12466174284262316, 0.20084876753389835, 0.12480996203209672, 0.06402214709669352], [0.041384970370147905, 0.029910827853849957, 0.026400847626583915, 0.05435385089367628, 0.02942592298079814, 0.0775447596928903, 0.031132228206843138, 0.027962823365149752, 0.007687421781676156, 0.02911018706592066, 0.03703129630801933, 0.03168813498424632, 0.0031957137647883166, 0.030260649975389242, 0.003782994729200644, 0.02625636037971292, 0.04199977059449468, 0.06665119887994868, 0.0373346387807812, 0.027032887729417, 0.017594726855999658, 0.08826116858316319, 3.8908539840153287, 24.635461705071585, 46.510543073926655, 42.04289306913103, 28.02115559577942, 28.004756110055105, 33.958198479243684, 40.36773797443935, 19.604311057499476, 2.841578504868916, 0.11755701979356152, 0.16640913912228175, 1.4280875750950404, 1.200488907950265, 9.687689168112618, 4.579727487904685, 6.0337322780064175, 10.643895047051565, 14.291614191872732, 25.708244459969656, 39.8206159727914, 45.82867465700422, 45.05537836892264, 44.502273968287874, 45.79969719478062, 47.221312522888184, 47.044526032039094, 43.12980672291347, 41.11436707632882, 37.99341344833374, 32.03991896765572, 31.23083598273141, 30.764566693987163, 30.759431975228445, 30.865458011627197, 30.136981078556605, 29.987904003688268, 30.505496161324636, 33.02879353931972, 31.603700637817383, 31.925728797912598, 37.71292509351458, 44.27210099356515, 45.20492444719587, 46.92442294529506, 45.518944808415, 42.39255421502249, 37.878764697483604, 36.076742444719585, 38.580772468021934, 40.37986952917916, 43.36079263687134, 43.32486697605678, 42.59516716003418, 37.509391512189595, 33.964417116982595, 32.419426100594656, 31.95576238632202, 31.80205086299351, 33.285675389426096, 34.35669503893171, 36.656965664454866, 37.6654098374503, 40.30822317940848, 42.67392846516201, 47.22382082257952, 44.263773577553884, 35.13227728434971, 38.01230560030256, 38.509497846875874, 46.477681568690706, 46.063089506966726, 44.601636682237896, 43.897030285426546, 37.45513302939278, 32.35742037636893, 35.5777645111084, 32.859736919403076, 33.52935218811035, 32.44680895124163, 34.157486711229595, 32.467188017708914, 35.65409394672939, 40.959849561963765, 44.29914338248116, 48.137109415871755, 47.52045679092407, 46.84527601514544, 45.2755320412772, 41.238045011247905, 34.05115842819214, 31.936255318777903, 32.028781005314414, 32.670301233019146, 31.909417901720317, 32.74511596134731, 37.68945755277361, 41.18769489015852, 41.899013246808735, 41.81274093900408, 40.39648267201015, 38.09852579661778, 38.53726632254464, 38.10991389410836, 39.102394580841064, 41.15637935910906, 44.45063148226057, 47.75939144407, 46.39649881635393, 47.996939931597026, 48.248568943568635, 44.6313784463065, 42.8162727355957, 43.8124463898795, 47.85129874093192, 42.770362513405935, 31.556571006774902, 14.823420626776558, 6.608430811337062, 6.211878444467272, 7.7086051021303446, 8.424564855439321, 2.3229734301567078, 0.38589700577514513, 0.03577248153409787, 1.5854949972459247, 17.713225058146886, 37.820368562425884, 30.477227415357316, 23.104669332504272, 39.89655630929129, 48.28550904137747, 40.95025062561035, 16.17186794962202, 0.887860574892589, 0.05378311134076544, 0.03481392189860344, 0.01070399594027549, 0.07379947030650717, 0.07582632904606205, 0.06783037739140646, 0.031060177965887954, 0.05102363494890077, 0.03172333398833871, 0.06517359388193913, 0.03476502327248454, 0.007006904168520123, 0.01620587593476687, 0.11798065634710447, 0.02775454704117562, 0.026855345649112548, 0.045783590591911755, 0.019168213941156864, 0.020927958888933063, 0.06416810676455498, 0.02323186517293964, 0.05937730348003762, 0.015520214602085096, 0.03531449753791094, 0.02026201578389321, 0.023408818624115417, 0.0059984900206992665, 0.02891943051612803, 0.022556169823344265, 0.04494403921333807, 0.03245336302955236, 0.020987418912617222, 0.014841453970542975, 0.035574223779674084, 0.02280666120350361, 0.041755772794463804, 0.04840284093682255, 0.030576521597270454, 0.04423072588230882, 0.01606985510859106, 0.1145130709878036, 5.0873598371233255, 30.926001140049525, 51.39148235321045, 49.01549373354231, 32.340122835976736, 30.223656381879533, 33.67710910524641, 41.09148318426949, 21.332750150135585, 2.821172079869679, 0.05732010065444878, 0.1679732030523675, 1.1706923182521547, 3.474705308675766, 5.734853344304221, 5.12922968183245, 9.743877513068062, 8.194966844149999, 15.213014807019915, 30.643751416887554, 43.78928109577724, 49.36522436141968, 47.12416975838797, 46.196998664310996, 46.89101253237043, 47.38719381604876, 48.02488906042916, 47.011692319597515, 43.70288372039795, 38.88291835784912, 34.12536171504429, 31.706464494977677, 32.47475460597447, 32.293437889644075, 33.07103163855416, 32.05616733006069, 31.154068810599192, 33.11120612280709, 34.06480469022478, 33.517811230250764, 33.082096644810264, 38.305297238486155, 46.25442899976458, 46.358426162174766, 48.65827294758388, 47.46399572917393, 44.80803986958095, 39.85339757374355, 38.316667965480256, 41.566027777535574, 44.06474242891584, 45.71165657043457, 46.038392135075156, 44.26566348757063, 40.218334334237234, 35.57888664518084, 35.37051016943795, 33.277021408081055, 33.40949576241629, 32.752005100250244, 35.466909476688926, 38.917249407087056, 39.7629702431815, 41.78394412994385, 44.1100446837289, 49.048626218523296, 46.45379713603428, 36.79466506413051, 37.93046276909964, 38.11404807226998, 48.45567389896938, 47.9558413369315, 45.946596009390696, 46.47404418672834, 39.32616826466152, 33.925211906433105, 36.30418477739607, 34.51759099960327, 35.23546150752476, 34.28995759146554, 35.18006352015904, 33.78273909432547, 36.14692619868687, 43.009481293814524, 47.76875761577061, 47.94045802525112, 49.03608124596732, 49.47134072440011, 47.27584893362862, 41.24257871082851, 36.70519311087472, 33.7133126940046, 33.59812545776367, 33.535167830330984, 34.00742646626064, 34.899078369140625, 41.08355181557791, 44.05862801415579, 44.96062578473772, 44.27689872469221, 42.473379135131836, 41.02529811859131, 40.47058173588344, 40.73327922821045, 41.81046540396554, 43.521052837371826, 47.00644642966134, 48.32566615513393, 47.99837473460606, 49.41971908296858, 51.362220014844624, 45.611640725817, 44.744012219565256, 46.184134074619834, 50.87724617549351, 44.94783762523106, 31.937394823346818, 13.270475660051618, 7.8929243087768555, 10.415750077792577, 7.758452347346714, 4.944391097341265, 3.341870950801032, 0.39613124089581625, 0.03170894904594336, 2.163249760866165, 20.324901785169327, 42.251193114689414, 31.651135989597865, 27.7313323361533, 47.49577331542969, 53.17084305627005, 48.390711716243196, 18.21167492866516, 1.0856136892523085, 0.05767333919980696, 0.01784288916470749, 0.004321258747950196, 0.00843195874975728, 0.025417850552392856, 0.0240830805684839, 0.00870523788034916, 0.03146562299558094, 0.05406658970085638, 0.05742052383720875, 0.031940950346844535, 0.005558991014757859, 0.03794352896511555, 0.047900619850094826, 0.027621947727831345, 0.03900440150339689, 0.01482578320428729, 0.02823409148758011, 0.04118636656286461, 0.09559503969337259, 0.0938643818455083, 0.12841307797602244, 0.13241059918488773, 0.10061959829181433, 0.19619589006262167, 0.1526968963444233, 0.056696082531873665, 0.06162198553127902, 0.09313998464494944, 0.13446521679205553, 0.12859170910503182, 0.11246291814105851, 0.11555269520197596, 0.15520723164081573, 0.08979769756219216, 0.09533976803400687, 0.16157171369663306, 0.16110357881656714, 0.18433663142578943, 0.12675157641725882, 0.31296247084225925, 5.971955410071781, 36.133578709193635, 57.75077942439488, 53.26408093316214, 38.604045459202354, 37.75762632914952, 44.42809500013079, 51.25156647818429, 24.51851483753749, 4.072307058743068, 0.36566949688962525, 0.5703787079879216, 3.1010904652731757, 6.122789076396397, 19.931701489857264, 13.015090278216771, 16.863330091748917, 14.91256080354963, 17.212748050689697, 28.579900196620397, 45.621541908809114, 49.44994027273995, 50.523138182503835, 48.924441065107075, 47.874238218579976, 50.032782963344026, 50.77140426635742, 48.16371406827654, 46.79177836009434, 40.947242055620464, 36.10214853286743, 32.48572928564889, 34.64234243120466, 33.85677215031215, 34.68079028810774, 32.40695408412388, 33.19210747310093, 34.740642070770264, 36.28162397657122, 35.4195887701852, 35.464696475437705, 41.39156198501587, 50.29103708267212, 47.96036808831351, 52.123638357434956, 48.838154860905235, 47.24332441602434, 40.75788974761963, 39.302763257707866, 42.73761565344674, 45.14228643689837, 46.91634566443307, 47.75200203486851, 46.36546816144671, 42.31932715007237, 36.41384472165789, 36.139898095812114, 34.5712171963283, 35.081267084394185, 35.73049981253487, 37.4012462752206, 40.56511197771345, 42.707359722682405, 43.38683795928955, 48.15101970945086, 51.866697447640554, 48.5088449886867, 39.445256914411274, 39.42633696964809, 41.280759062085835, 48.09174462727138, 50.67651966639927, 47.231012208121165, 49.22014250074114, 40.822431564331055, 35.96888555799212, 38.09613561630249, 36.25517218453543, 37.81662000928606, 36.2090083530971, 37.67694384711129, 36.34586354664394, 38.22019222804478, 45.29978820255825, 49.218200479234966, 49.8859987940107, 49.21077980313982, 50.77973863056728, 49.349538803100586, 44.24276222501482, 38.148827280317036, 35.46365771974836, 35.72243990216936, 34.774267877851216, 34.97622421809605, 35.84104912621634, 41.45566953931536, 46.32177788870675, 46.176546641758506, 46.08825240816389, 44.8600367137364, 42.46169573920113, 43.82235452107021, 42.079374585832866, 41.917860235486714, 45.78382403509957, 48.83849879673549, 52.209080355507986, 48.426897934504915, 50.53142390932356, 53.37258052825928, 48.72816835130964, 48.5690268107823, 50.2112717628479, 51.41628394808088, 47.23652907780239, 33.28468874522618, 17.22014614513942, 10.057845762797765, 14.626531260354177, 17.122002840042114, 12.999274441174098, 5.645821298871722, 0.8371341111404556, 0.3091486697750432, 2.5376412825925008, 24.372665200914653, 48.01522411618914, 40.42904193060738, 33.90783446175711, 52.684667178562705, 61.47487490517752, 56.05973032542637, 23.131393841334752, 1.8734512541975294, 0.15676824216331753, 0.08223612367042474, 0.1469210705586842, 0.10077821942312376, 0.24879227418984684, 0.1362820350165878, 0.08907380247754709, 0.14304632347609314, 0.11776813917926379, 0.15571297093161515, 0.1464121150118964, 0.06824497585850102, 0.08619642044816699, 0.15668052115610667, 0.0919257394437279, 0.15720276241855963, 0.07483313698321581, 0.1663628358926092, 0.11687515995332173], [0.026176271195124303, 0.07947189414075442, 0.02719365303138537, 0.010941199908432151, 0.01082756819336542, 0.03004540509677359, 0.019088070473766754, 0.021808967060808624, 0.016611836651074033, 0.0424102707100766, 0.027743039087259343, 0.028092216600530913, 0.08163804254893746, 0.039920864826334376, 0.013764345785602927, 0.015475835019190396, 0.06855455067540918, 0.042052774357476404, 0.04281577002257109, 0.03385915866653834, 0.034694089221635034, 0.03048162508223738, 2.5393626987934113, 18.383465664727346, 41.136900084359304, 42.82969318117414, 30.541397503444127, 30.808812822614396, 34.333672182900564, 32.48758792877197, 24.497345413480485, 4.848553725651332, 0.49877529591321945, 0.0724683270922729, 1.331954362136977, 1.6893593839236667, 2.0850542996610915, 1.7202252362455641, 4.940030234200614, 7.291542955807277, 5.766287428992135, 17.34922456741333, 32.010243211473735, 44.83028105327061, 47.28388105119978, 47.39373901912144, 45.471221106392996, 47.088886805943076, 41.28061662401472, 42.00762748718262, 37.88252714702061, 32.792026724134175, 31.509792259761266, 30.700427872794016, 30.00860963548933, 30.12747594288417, 33.72251558303833, 33.87042883464268, 31.863882882254465, 31.575900895254954, 32.47086361476353, 32.58223281587873, 32.0377893447876, 37.45107528141567, 44.62947463989258, 44.88664831433977, 46.83940478733608, 45.52185957772391, 43.42782538277762, 40.10575614656721, 34.36092301777431, 34.842731952667236, 38.45024013519287, 41.4465708732605, 42.354498931339805, 41.6895945412772, 37.973840372903005, 34.087462765829905, 32.12013939448765, 32.86983960015433, 32.03200844355992, 36.22492320196969, 38.09492315564837, 41.08623382023403, 38.78535175323486, 41.654797962733674, 43.473211015973774, 44.34011343547276, 43.14220578329903, 33.37078039986746, 47.35292182649885, 45.61707421711513, 45.51490095683506, 44.71043504987444, 44.77001237869263, 43.129587854657856, 38.79641328539167, 36.17090443202427, 37.38245487213135, 32.657360213143484, 33.63027824674334, 32.009735992976594, 33.95160811288016, 33.348907470703125, 37.811485290527344, 44.08571209226336, 46.316709177834646, 45.83325004577637, 45.301070145198274, 47.72256251743862, 43.114604064396445, 39.34191983086722, 35.0589633669172, 32.82279682159424, 32.37001051221575, 32.621827125549316, 32.030351298195974, 32.153303146362305, 32.11530344826834, 33.76661579949515, 35.87053380693708, 36.5784649167742, 35.26974391937256, 34.486289364951, 34.87287671225411, 34.01784529004778, 37.25698430197579, 39.40339054380144, 43.59435633250645, 45.79288796016148, 49.063349451337544, 45.16896404538836, 48.58048786435808, 47.35045174189976, 46.58861998149327, 46.725468226841514, 48.56173815046038, 38.49239485604422, 26.716483661106654, 9.22452746118818, 8.831130010741097, 8.092686755316597, 2.907155603170395, 3.3268259295395444, 3.3410332586084093, 0.3720041641167232, 0.05289726012519427, 2.7829949855804443, 18.022800309317454, 37.62330027988979, 36.86862168993269, 42.614212172372, 37.796188831329346, 46.689976828438894, 40.55347721917288, 15.179090227399554, 0.9481233869280133, 0.013839116103814116, 0.016026608679177504, 0.04083464454327311, 0.018357719128419245, 0.019535618601366878, 0.04494434116142137, 0.06310150399804115, 0.020966056933892623, 0.01567452194701348, 0.05123089686302202, 0.09398139520947422, 0.03816893490563546, 0.025769866038379923, 0.051054084207862616, 0.024895332786919813, 0.027398779256535426, 0.030223805523876632, 0.04648754692503384, 0.019332566997036338, 0.019239266735634634, 0.04193689075431653, 0.01671522842454059, 0.025073855350326215, 0.03366722485848835, 0.015431938892496484, 0.01481405133381486, 0.021822312148287892, 0.06779647099652461, 0.062269409719322405, 0.041128701264304776, 0.026902081444859505, 0.026852063235959837, 0.0437533052505127, 0.03671740261571748, 0.030466534463422637, 0.01207498527531113, 0.016920157874535238, 0.02024088959608759, 0.02255813078954816, 0.029395874057497298, 0.05479985535410898, 3.6583199245589118, 23.999559095927648, 47.80889735903059, 47.84489597593035, 36.384592805589946, 33.95955685206822, 39.50243016651699, 39.497986793518066, 27.165431090763636, 5.5422809805188855, 0.25811971511159626, 0.08167015761137009, 0.5608810633420944, 3.318793377705983, 4.838246941566467, 6.198893129825592, 5.29749550989696, 5.6235540594373425, 8.104078326906476, 19.149351699011667, 36.634241580963135, 46.68419592721121, 49.07297618048531, 48.82354279926845, 45.985964502607075, 48.71138150351388, 44.257634844098774, 44.59235388892037, 40.18820694514683, 34.9375262260437, 32.633548736572266, 33.12732941763741, 32.304176330566406, 31.282290867396764, 33.75239978517805, 35.217979839869905, 33.82265649523054, 33.909571511404856, 33.528539248875205, 34.16526174545288, 33.443312644958496, 39.86975710732596, 46.439376149858745, 47.57949216025216, 48.21361950465611, 46.821082387651714, 45.59801878247942, 40.19726044791085, 35.43246725627354, 36.477031639644075, 41.349942275456016, 43.44526188714163, 43.555602754865376, 43.173257282802034, 40.06108965192522, 35.91305330821446, 34.24473524093628, 33.62530681065151, 33.18503073283604, 37.109960419791086, 40.77393313816616, 42.456269196101594, 40.48610748563494, 42.91998502186367, 44.1033535684858, 46.27248041970389, 46.772976534707205, 35.62261860711234, 46.53357287815639, 46.618382590157644, 45.89283432279314, 47.07269402912685, 46.26064763750349, 44.90778126035418, 40.262556144169395, 37.16912085669381, 38.32257393428257, 33.10875688280378, 34.49301522118704, 33.594380378723145, 35.45052215031215, 35.169377190726145, 39.045388085501536, 44.51052148001534, 47.617057595934185, 46.98140859603882, 46.7159491947719, 49.17686217171805, 45.129501751491, 42.702172892434255, 37.2585129056658, 33.994054658072336, 34.75371510641915, 33.62734610693795, 34.41375017166138, 33.26496628352574, 34.1960631098066, 36.149288586207796, 39.12750537054879, 38.95290061405727, 37.22780186789376, 36.305296489170615, 36.67430141993931, 35.491839613233296, 38.98794732775007, 42.19473205293928, 45.76618603297642, 49.466272013528005, 49.93704720905849, 46.83101831163679, 51.555932317461284, 49.61947979245867, 48.421120507376536, 48.92031383514404, 49.33278669629778, 43.685607024601524, 28.43612286022731, 11.3561418567385, 5.723191661494119, 8.357182962553841, 7.606807044574192, 5.797992493425097, 1.6056242542607444, 0.8634487305368695, 0.06311956660023757, 2.9518594443798065, 21.825577190944127, 42.845198086329866, 38.97597210747855, 38.948728220803396, 43.40888111931937, 52.86402102879116, 46.59772212164742, 16.782975912094116, 1.1413912219660622, 0.08069496708256857, 0.0355907359293529, 0.035529284405389, 0.0649656228987234, 0.03931872606543558, 0.037391276098787785, 0.06578241621277162, 0.011761907521369202, 0.053387203120759556, 0.03512979691315975, 0.10999821432467018, 0.0344163818018777, 0.012478096992708743, 0.02338542782568506, 0.0793438410120351, 0.05243420747241803, 0.02693290898709425, 0.04455032266144242, 0.04578811642048614, 0.275231554039887, 0.1396664319826024, 0.16370141798896448, 0.11172317247837782, 0.1262394453265837, 0.09274624434432813, 0.07446072303823062, 0.1011910197724189, 0.12852218640702112, 0.08259652754557983, 0.06295830596770559, 0.1255594582429954, 0.1437848409903901, 0.20257998178047792, 0.15741413964756898, 0.18136733504278318, 0.156287567956107, 0.11470361719174044, 0.11871549620160035, 0.1534298634422677, 0.07554738329989569, 0.18248276518923895, 4.354377431528909, 27.499325037002563, 56.526197637830464, 55.328123228890554, 43.008032594408306, 40.43869992664882, 45.5656019619533, 43.49597331455776, 32.779214245932444, 7.283056165490832, 1.0169468138899123, 0.22390650026500225, 3.94121105330331, 4.8501066480364114, 7.6632125207356045, 9.180639164788381, 13.607515403202601, 10.902189987046377, 8.472547377858843, 20.848267895834788, 35.50721250261579, 49.50254161017281, 50.52594872883388, 48.67241253171648, 48.15314933231899, 51.87608098983765, 45.310495376586914, 47.93976320539202, 42.74018996102469, 36.09701728820801, 33.86396353585379, 33.94579594475882, 33.935140882219585, 33.03607872554234, 36.11628116880144, 38.33712693623134, 35.87888901574271, 35.63136986323765, 36.6521748815264, 36.138630049569265, 35.827152729034424, 41.49657358442034, 48.042120592934744, 48.99441637311663, 49.83856691632952, 49.14153058188302, 47.981546197618755, 43.233706610543386, 37.60108341489519, 37.67989335741316, 42.96401228223528, 46.34578391483852, 45.49832950319563, 44.172001770564485, 42.29654400689261, 37.00943040847778, 34.66001517432076, 35.06736026491438, 35.89677367891584, 39.986702237810405, 41.8874305997576, 44.4843476159232, 42.57851927621024, 44.85176488331386, 46.00945288794381, 47.61982297897339, 47.302213873182026, 38.93464422225952, 50.06157282420567, 47.74129138674055, 48.588909081050325, 49.159964152744834, 47.98082358496529, 46.80504594530378, 43.53250694274902, 39.3027354649135, 40.543815749032156, 34.43974685668945, 37.10515921456473, 35.372514724731445, 37.36520249502999, 35.79720251900809, 42.571949754442485, 48.31822810854231, 50.87921251569475, 48.59464481898716, 46.599792684827534, 50.561391489846365, 46.85742841448103, 44.32415689740862, 38.17080443246024, 35.79124443871634, 35.31401089259556, 35.95769548416138, 35.89483165740967, 34.110169478825156, 34.84915208816528, 37.602372305733816, 40.065894331250874, 41.15876259122576, 39.61084290913173, 38.912865093776155, 38.590284551892964, 36.78099448340279, 42.63841274806431, 44.123440810612266, 48.653857367379324, 52.53278997966221, 53.147462368011475, 46.43357787813459, 54.0243285042899, 51.74167851039341, 50.684652532849995, 50.435594354357036, 51.86205952508109, 43.15564707347325, 30.36172751017979, 11.479792867388044, 12.583379592214312, 16.685051475252422, 11.65840152331761, 11.514293278966631, 7.383444172995431, 1.4841832050255366, 0.1357753864888634, 4.247483304568699, 24.258516720363072, 49.83813612801688, 49.67596517290388, 51.89238493783133, 48.34073679787772, 60.25063010624477, 53.3423558643886, 19.938519409724645, 1.6336112724883216, 0.1079991687355297, 0.12440725149852888, 0.1453729114894356, 0.13710756786167622, 0.09380801594150917, 0.08050752856901713, 0.24568034974592073, 0.13187288732400962, 0.15729140623339585, 0.11766002140939236, 0.2696128226816654, 0.12604712136089802, 0.08208666276186705, 0.11371906287968159, 0.06606782161231552, 0.11392018065920897, 0.08728781009891204, 0.15163201705685683, 0.1365516712622983], [0.0071279306430369616, 0.060188471738781245, 0.053763369364397864, 0.02102154752771769, 0.008751064439171126, 0.03104264462100608, 0.02124804930229272, 0.05378916387313178, 0.053333246016076634, 0.056086798797228506, 0.022741007851436734, 0.06539824325591326, 0.03930043276133282, 0.03645053479288306, 0.06366244211260762, 0.045893516657607894, 0.013919234974309802, 0.02786276998397495, 0.050498465807842355, 0.012419608970438796, 0.010563435714824923, 0.005018783417264265, 1.4082611075469424, 14.217859063829694, 33.72380794797625, 45.18274232319423, 33.85947152546474, 30.45877299989973, 30.87773895263672, 37.116922514779226, 29.802439212799072, 9.52653351851872, 0.6091034614614078, 0.14192925127489225, 0.5345991221921784, 4.0652711391448975, 3.7953127792903354, 4.033995994499751, 4.215412591184888, 2.6228670179843903, 4.865817827837808, 11.619747826031276, 23.24982762336731, 36.45097936902727, 46.60046666009085, 46.078274794987266, 46.609825883592876, 45.42013447625296, 41.72399854660034, 39.08492680958339, 33.73186785834176, 32.01198720932007, 30.74361092703683, 32.998568875449045, 35.19198662894112, 39.670972619737896, 40.04402487618582, 39.32903439658028, 38.51274960381644, 34.91639675412859, 33.87054000582014, 33.73047127042498, 33.07187237058367, 38.77024636949812, 42.336346762520925, 45.54026535579136, 46.7834335735866, 44.70658574785505, 42.721836294446675, 39.36096484320504, 33.78725889750889, 33.83322817938668, 34.431843280792236, 37.483957631247385, 40.88281488418579, 39.61099576950073, 37.506337778908865, 32.85674224581037, 31.630506787981304, 32.438359941755024, 32.41776895523071, 37.7532593863351, 42.46416582380022, 42.789560386112754, 41.744606903621126, 42.68772063936506, 43.43601036071777, 45.188495431627544, 46.02069159916469, 35.91607230050223, 48.27130344935826, 44.854537214551655, 45.324798243386404, 43.240779876708984, 44.11928578785488, 41.15308938707624, 40.15009260177612, 33.23244524002075, 34.10334982190813, 32.90796089172363, 32.94604744229998, 31.70789929798671, 34.14287117549351, 34.45176029205322, 40.59211267743792, 44.31209829875401, 46.7878873688834, 47.32096358707973, 45.65736334664481, 46.99920293263027, 44.81836836678641, 39.846702984401155, 35.357833181108745, 34.24181352342878, 32.968160084315706, 32.5340644291469, 32.86052901404244, 32.06669037682669, 34.26959242139544, 33.54128919328962, 33.78389596939087, 33.74792167118618, 32.86667469569615, 33.27957834516253, 33.3868168422154, 32.7887749671936, 34.753162724631174, 36.19677257537842, 39.47222287314278, 43.75185809816633, 46.947876589638845, 46.2893819127764, 48.23685428074428, 51.21467849186489, 51.017043931143625, 47.23532009124756, 49.53470829554966, 36.32573808942522, 22.508618116378784, 10.60247596672603, 6.29903838464192, 8.15178552695683, 5.664728215762547, 1.601111507841519, 1.4997833222150803, 0.47056685813835686, 0.096354205028287, 3.41251654284341, 20.84512731007167, 39.5676702771868, 32.02667222704206, 29.083321503230504, 44.03839485985892, 51.517831870487754, 28.717686448778423, 7.918686492102487, 0.5792798389281545, 0.06968981440046004, 0.02367599348404578, 0.03804582829720207, 0.0035091579276403146, 0.03071607250188078, 0.04452439923105495, 0.021869526311222996, 0.06830783534262862, 0.02860749779003007, 0.0327612347235637, 0.05568906531802245, 0.047321914296065054, 0.023720118616308485, 0.05816032378269093, 0.024954400956630707, 0.03660934930667281, 0.04244291502982378, 0.06578389541911227, 0.02693127202136176, 0.03437420067244342, 0.07658882598791804, 0.04007456318608352, 0.023442314505310993, 0.01896970173610108, 0.019355158820482235, 0.03743613404887063, 0.012815487504537617, 0.07062242685684136, 0.05928690225950309, 0.037439499582563124, 0.008251249607253288, 0.022045312682166696, 0.053667360051934204, 0.0893162837518113, 0.030946526742939438, 0.025054968328082135, 0.025482623505273035, 0.016735626883538704, 0.06381655777139322, 0.035199217830917666, 0.02355799963697791, 1.9656788195882524, 17.97591733932495, 41.01619945253645, 51.57130520684378, 38.56735897064209, 35.716488770076204, 35.61232485089983, 40.90974610192435, 34.475953919546946, 9.507252267428807, 0.8374612193022455, 0.13485616152840002, 0.5348378036703382, 2.453128823212215, 5.243393361568451, 7.255629454340253, 5.739154713494437, 4.781810198511396, 6.596509439604623, 13.759679215294973, 27.700418063572474, 40.1285914012364, 47.7228821345738, 46.09678827013288, 48.68553420475551, 46.79093762806484, 44.3240978377206, 41.26460797446114, 36.26190151487078, 34.16707175118582, 32.70214830126081, 33.686100074223106, 35.90847791944231, 40.83681780951363, 42.13387278148106, 39.38634313855852, 39.83596454347883, 37.290346077510286, 35.40676586968558, 35.01958097730364, 34.371703147888184, 40.879722935812815, 44.723997933524, 46.87790128162929, 47.16959708077567, 45.82862254551479, 44.41647413798741, 39.97165938786098, 34.22222307750157, 35.17434515271868, 37.18181521551949, 39.752349921635215, 42.11421285356794, 41.619435106004985, 39.77683537346976, 33.04258918762207, 32.52278402873448, 34.08207443782261, 32.83357695170811, 38.68849733897618, 43.42997932434082, 44.59550837108067, 43.68420001438686, 44.07852070672171, 45.810428687504356, 45.596691676548545, 46.466415064675466, 37.75988449369158, 48.63179683685303, 48.209836210523335, 46.83346060344151, 45.604581356048584, 45.726341588156565, 43.07225826808384, 40.525000027247835, 34.57756437574114, 35.873149803706575, 34.27142674582345, 33.88569055284773, 33.18116406032017, 35.27800532749721, 36.52973025185721, 41.83886269160679, 46.94946425301688, 46.85823787961687, 48.009450163160054, 46.426563671657014, 48.256271021706716, 45.907970973423545, 42.57994713102068, 36.778527872903005, 35.39072595323835, 34.77063396998814, 33.82032190050398, 33.976875237056184, 33.866343293871196, 35.16873100825718, 35.08114896501814, 34.83672523498535, 35.182255676814485, 35.33410160882132, 34.02893461499895, 35.55718394688198, 34.696197918483186, 36.66703360421317, 38.45814023699079, 41.98316287994385, 46.52185126713344, 49.27919176646641, 47.715708119528635, 49.63160787309919, 52.95895079204014, 52.652166979653494, 49.308804988861084, 49.770870617457796, 37.9674654006958, 23.322847979409353, 10.705641950879778, 6.621241552489145, 6.965682864189148, 7.067272910049983, 5.4996168698583325, 1.1393816726548331, 0.23192753057394708, 0.18434856007141726, 3.836823488984789, 22.58410508292062, 42.56729098728725, 35.011937958853586, 35.544875213078086, 47.670558725084575, 56.30124970844814, 36.74315806797573, 10.7565826688494, 0.8130184880324772, 0.09266755463821547, 0.009973541118337639, 0.04401326558685728, 0.0542403319850564, 0.03691642711471234, 0.059590187056788375, 0.02869559877685138, 0.042336666623928716, 0.04152555264798658, 0.012684797419102063, 0.018930231354066303, 0.028395046779353703, 0.04565323722947921, 0.045835881893123896, 0.03397929668426514, 0.010420968805971955, 0.036687930447182486, 0.04990995203011802, 0.0461294161421912, 0.07301492776189532, 0.17295991975281919, 0.1285563302891595, 0.06616106589457818, 0.12980129277067526, 0.13426561893096992, 0.1547574714890548, 0.1290832670139415, 0.22402987150209291, 0.16218373871275357, 0.1330219049538885, 0.10701931667115007, 0.10415008384734392, 0.11965006962418556, 0.17054613998958043, 0.14421244018844195, 0.07987185660749674, 0.15538439713418484, 0.15392607610140527, 0.13081404699810914, 0.09932225290685892, 0.11341845151036978, 2.5430052919047217, 20.963217156273977, 46.66681153433663, 56.839783736637656, 44.36458499091012, 40.853403159550254, 39.64796713420323, 47.931758880615234, 38.617538860866, 12.655362061091832, 0.9676181865589959, 0.45733363394226345, 0.6899690936718668, 9.287444267954145, 12.996019210134234, 9.225646989686147, 7.72446436541421, 7.371640920639038, 7.625872032982962, 13.927155988556997, 27.344807522637502, 39.86445563180106, 48.16895648411342, 48.381150994982036, 51.562133584703716, 49.00615882873535, 46.30840955461775, 43.06472642081124, 38.43766736984253, 35.896124022347585, 33.27244601930891, 35.68773365020752, 39.52146475655692, 44.13980381829398, 46.05918114525931, 41.635273524693076, 42.30305446897234, 39.365568024771555, 38.1977356501988, 36.83267518452236, 36.23203468322754, 43.12875754492623, 46.928925377982004, 48.86245618547712, 48.937354292188374, 47.575083528246196, 47.220179966517854, 42.26613868985857, 36.18058327266148, 36.99098988941738, 38.356943198612754, 40.437320709228516, 44.26595531191145, 44.04904644829886, 42.1940268107823, 34.80204677581787, 35.20350674220494, 34.94674301147461, 34.41953107288906, 40.894015380314414, 45.60645042146955, 46.32373380661011, 46.51325287137713, 46.24551098687308, 47.69761153629848, 48.91194472994123, 48.68821620941162, 42.27811043603079, 48.86217825753348, 49.314335754939485, 48.026188373565674, 47.539074489048545, 48.17787797110421, 44.15505164010184, 43.16234513691494, 36.45688533782959, 37.77302006312779, 36.196974073137554, 36.058246340070454, 34.93091154098511, 37.70465326309204, 38.721289362226216, 44.09422363553728, 48.84012814930507, 49.58175802230835, 49.431378160204204, 47.18708222252982, 51.07843126569475, 49.2777430670602, 44.617516790117534, 39.7429906981332, 38.52539185115269, 35.62877123696463, 36.13800818579537, 35.90105724334717, 34.9177690233503, 37.58028050831386, 37.65137447629656, 37.761294978005544, 36.92300871440342, 36.646154267447336, 36.82109601157052, 37.59507669721331, 35.94166946411133, 39.63273320879255, 41.381320340292795, 42.99740879876273, 48.48411634990147, 51.13907166889736, 49.31461715698242, 50.79579244341169, 52.5802982875279, 55.343826157706125, 51.85864795957293, 52.846747807094026, 40.50851195199149, 26.414864097322734, 13.06562192099435, 11.05832382610866, 14.991937024252755, 15.679204191480364, 8.481609565871102, 2.632659201111112, 1.044249217425074, 0.423019032393183, 5.110875580992017, 26.565462827682495, 51.23868104389736, 40.83336108071463, 41.39385836465018, 56.47511795588902, 63.891555649893625, 41.6918283871242, 13.05319767338889, 1.144605415207999, 0.2087882243629013, 0.13647449468927725, 0.14584485973630631, 0.1367901898920536, 0.1692817442651306, 0.22691668516823224, 0.12036228712115969, 0.19569392342652592, 0.10123760120144912, 0.07735209645969526, 0.1987665742635727, 0.06517666086022343, 0.16764875474785054, 0.17694841644593648, 0.12349443190864154, 0.1070536912551948, 0.06322107543902737, 0.10272594740880386, 0.06403306472514357], [0.049034282232501676, 0.00669311692139932, 0.01444571538429175, 0.1468702754271882, 0.06879358499177865, 0.021628341038844416, 0.04905385457511459, 0.029971634769546132, 0.013422562607697077, 0.013718559090713305, 0.03614612362746682, 0.08307102708412067, 0.057543331890233924, 0.014283684614513601, 0.035850055050104856, 0.052674965267734866, 0.04312136862426996, 0.019384844727548103, 0.04878421154405389, 0.02578999986872077, 0.037857751960733106, 0.014502751341621791, 0.3955557346343994, 10.008402381624494, 29.830819129943848, 41.088280064719065, 33.559222493852886, 29.379634380340576, 27.624217169625418, 31.848565578460693, 30.53049577985491, 14.678929362978254, 1.9637663279260908, 0.09292615111917257, 0.5511435429964746, 1.4854082592896052, 3.233565471002034, 9.685489194733755, 4.1251307385308404, 4.056312739849091, 2.655164633478437, 4.622393769877298, 14.053223235266548, 29.065825939178467, 41.83061170578003, 47.89759806224278, 47.0599718775068, 42.15249742780413, 38.82624190194266, 33.98687022072928, 32.85882323128836, 32.39724397659302, 35.810098375592915, 39.31023257119315, 41.08050850459507, 42.46965142658779, 44.22862958908081, 42.97523362295968, 41.07419259207589, 39.95391716275896, 38.58299241747175, 34.687630789620535, 35.25059815815517, 40.5935891696385, 42.992836884089876, 45.2821432522365, 43.7245968409947, 44.963405064174104, 40.70969009399414, 40.86654915128435, 33.50254256384713, 32.24761799403599, 32.676526818956646, 34.84668547766549, 36.17359685897827, 36.95527614865984, 35.82792397907802, 33.787074770246235, 31.874694279262, 31.15860251017979, 33.21156937735421, 42.56864241191319, 44.38546085357666, 44.844837529318674, 44.055730615343364, 44.25009604862758, 44.5290766443525, 45.857798031398225, 44.9528021131243, 36.12488998685564, 47.909128597804475, 43.28337580817086, 42.621618952069966, 40.62308774675642, 41.76472193854195, 38.138748918260845, 33.4393903868539, 33.64013079234532, 33.07852527073452, 31.010036127907888, 33.30223642076765, 31.132039546966553, 33.17840909957886, 33.38284247262137, 40.38836717605591, 46.348462445395334, 46.51144633974348, 43.97439847673689, 48.140538351876394, 46.67207479476929, 43.17016186032976, 41.2652576310294, 34.481818199157715, 34.00127731050764, 35.70402717590332, 37.54763092313494, 37.23602853502546, 36.13246004922049, 32.61719962528774, 32.15262222290039, 31.689229488372803, 32.005577496119905, 31.47570092337472, 34.02243457521711, 33.12510599408831, 33.41241747992379, 32.28272724151611, 34.58717026029314, 36.115502970559255, 42.30290855680193, 44.73939166750227, 50.38190562384469, 50.004260608128135, 48.89269127164568, 49.95322956357683, 51.22822053091866, 42.74943106515067, 32.967552116939, 15.520505598613195, 6.602519197123391, 2.8448547976357594, 4.994250067642756, 4.644678379808154, 5.661132088729313, 0.9248565839869636, 0.2825339750519821, 0.16441092134586402, 4.393506211893899, 24.751477513994487, 43.99259580884661, 36.97841017586844, 37.1210150037493, 47.32376023701259, 49.16608204160418, 26.337685244424, 7.260137966700962, 0.3631608172186783, 0.048184976913034916, 0.050385082606226206, 0.05013416374900511, 0.07352571535323348, 0.0671451927295753, 0.04901575483381748, 0.012203945944617902, 0.013520584624659802, 0.07236368342169694, 0.05725319031625986, 0.023682341179145232, 0.02948759842131819, 0.01823264137575669, 0.03645601735583373, 0.04817154870501586, 0.00889103433915547, 0.03992644916953785, 0.04968331115586417, 0.052657153723495345, 0.009830831633215504, 0.023794543729828935, 0.011024776763016624, 0.040841538459062576, 0.041290162064667256, 0.028547854561890875, 0.04299020780516522, 0.02616513643546828, 0.059034290457410474, 0.0057670527520323435, 0.07525912126792328, 0.06953960710338183, 0.04969312616490892, 0.028190173308498094, 0.01871810943287398, 0.003858816352606352, 0.043760989659598896, 0.03814550169876643, 0.09890952719641583, 0.0407052750566176, 0.014077119046955236, 0.04068336855354054, 0.6757869518228939, 13.052022559302193, 35.6316408429827, 48.3839441708156, 38.59689228875296, 34.74316774095808, 34.6404698916844, 39.53740739822388, 33.818355560302734, 16.536651849746704, 1.6894833658422743, 0.14542731642723083, 0.415696092482124, 1.6507067722933633, 3.6718940990311757, 7.845788598060608, 5.864037292344229, 5.959791285651071, 4.790187554700034, 8.240395903587341, 20.513046843664988, 30.136129924229213, 44.88089868000576, 48.76167951311384, 49.47623225620815, 43.414359773908345, 41.515024525778635, 35.790091037750244, 34.83185454777309, 32.78227145331246, 37.34856850760323, 39.995304107666016, 43.16230692182268, 44.30571985244751, 45.74367386954171, 44.20000301088606, 42.80092763900757, 42.814302921295166, 39.348888874053955, 34.934475966862266, 36.09932409014021, 40.95691742215838, 45.08765622547695, 46.804472718920024, 45.53947673525129, 45.81395142418997, 43.86706270490374, 41.537352561950684, 34.894172940935405, 34.35527065822056, 35.389124393463135, 37.29738807678223, 38.1344062941415, 38.57679115022932, 38.13747392381941, 35.66719477517264, 33.62170764378139, 33.1065925189427, 33.755866936274934, 45.1132047516959, 47.390417780194966, 46.909546852111816, 45.164107254573274, 45.39442614146641, 46.70361614227295, 47.999357904706685, 45.55958482197353, 37.73679562977382, 50.42804166248867, 45.35845879146031, 44.47493280683245, 42.898362227848594, 44.034232888902935, 41.46353490012032, 36.37813445499965, 34.09801707948957, 34.43856218882969, 32.86249188014439, 34.97040510177612, 34.16682161603655, 34.54867376599993, 35.784799984523225, 42.81890262876238, 48.4658773286002, 47.17728526251656, 45.91745179040091, 48.155424867357524, 48.36874846049717, 45.67248957497733, 43.13079684121268, 36.19726937157767, 35.41945328031267, 38.10632862363543, 38.71643257141113, 37.223744119916645, 36.485709939684185, 33.568425382886616, 35.05421427318028, 34.84758526938302, 34.36720766339983, 33.20111928667341, 35.90337446757725, 34.50247866766793, 35.714105537959504, 35.43263748713902, 35.41027818407331, 38.7137644631522, 46.004033293042866, 47.61102655955723, 51.82804461887905, 50.98594379425049, 49.35362434387207, 53.54439558301653, 52.35979373114449, 46.8307785987854, 34.63473415374756, 18.320320435932704, 5.046366333961487, 6.070047472204481, 7.184479466506413, 6.497938386031559, 2.741408279963902, 0.7857697159051895, 0.26545226307851927, 0.3067550967846598, 5.734695707048688, 25.51310430254255, 49.33159508023943, 37.359008175986155, 38.99979748044695, 51.812067236219136, 55.41814408983503, 30.923148904527935, 9.190277184758868, 0.4570034316607884, 0.03194720983239157, 0.07539493005190577, 0.05057162545355303, 0.017793783585407903, 0.017069089525778378, 0.08437482533710343, 0.035107846305306466, 0.008053136889689734, 0.04400564903127296, 0.02695802835348461, 0.029672322794795036, 0.05589656811207533, 0.032170420712126155, 0.028754705962325846, 0.07687568345240184, 0.06694730477673666, 0.04287307569757104, 0.027918531991807476, 0.02760034317283758, 0.07522876361118895, 0.17752100500677312, 0.08051315362432174, 0.22587507963180542, 0.20108903678400175, 0.06878468939768416, 0.16477194268788609, 0.12513214402965137, 0.1487763345773731, 0.13810562502060617, 0.1629443493272577, 0.24529629892536572, 0.11964386781411511, 0.16815446689724922, 0.13390750171882765, 0.08532161917537451, 0.1642644392060382, 0.11044578959367105, 0.16935391324971402, 0.061283165855067115, 0.14450528233179025, 0.1777716829840626, 0.8113911439265523, 15.007561785834175, 41.354830333164756, 53.90010860988072, 43.598441873277935, 39.4149523462568, 39.042719977242605, 42.64540958404541, 40.91650669915335, 18.84422676903861, 2.6874776652881076, 0.1924496168004615, 1.3875877197299684, 4.300146741526468, 7.041352220943995, 20.838140896388463, 11.856308800833565, 9.329373172351293, 4.773196169308253, 6.229757462229047, 16.011025837489537, 32.48802219118391, 44.28526088169643, 50.62406424113682, 50.51414721352713, 46.22565998349871, 42.247097151620046, 37.60079506465367, 37.58781582968575, 35.70603173119681, 40.91785464968, 43.469573634011404, 44.31012501035418, 47.11291020257132, 47.512191908700125, 47.288345268794465, 44.67332124710083, 44.728875568934846, 42.293007373809814, 38.735960483551025, 38.629684312003, 44.58012853349958, 46.097868715013774, 49.58993605204991, 45.80400160380772, 49.583057335444856, 44.25980963025774, 44.260414123535156, 37.39016389846802, 35.92782170431954, 36.5062175478254, 39.36741624559675, 39.496218476976665, 41.498498235430034, 38.79717411313738, 37.68270737784249, 35.52981151853289, 34.46414198194231, 36.75936474118914, 47.3101487159729, 48.5447359085083, 49.10099131720406, 47.193623951503206, 46.69914845057896, 47.59946128300258, 48.42741904939924, 47.06676026753017, 40.593241759708945, 51.380844661167686, 48.06161028998238, 47.278200898851665, 45.15440756934029, 45.75646202904837, 42.268080711364746, 38.12228863579886, 36.47818851470947, 35.98189953395298, 33.947807448250906, 36.57601567677089, 35.419265678950715, 36.74465887887137, 37.13076680047171, 43.938914026532856, 51.72660091945103, 47.92765596934727, 45.52567413875035, 49.214142731257844, 49.52617590767996, 48.4360591343471, 45.41491985321045, 38.13789776393345, 38.049645219530376, 39.0832279750279, 41.32939992632185, 40.724666936056956, 39.2745292527335, 36.224311760493684, 36.60619865145002, 35.81516013826643, 35.54381908689226, 33.805716787065776, 37.36478212901524, 36.817448207310264, 37.99368095397949, 37.13229193006243, 38.48921952928816, 40.647514138902935, 47.398408208574565, 49.68319477353777, 55.20147841317313, 52.62443324497768, 49.68268060684204, 53.53610985619681, 53.98811796733311, 46.464570317949565, 36.536313670022146, 17.043029614857264, 9.445246543203082, 5.320809321744101, 7.980816415378025, 15.057482855660574, 11.191803063665118, 2.7631489762238095, 0.3807852215000561, 0.7462766979421888, 6.203636143888746, 32.70614004135132, 55.31318807601929, 46.71260711124965, 47.34824568884713, 58.56412860325405, 61.732896259852815, 37.077293464115684, 11.73490640095302, 0.7582567493830408, 0.15434965837214673, 0.17731701023876667, 0.15512755805892603, 0.13437593515430177, 0.12431077738957745, 0.21340869500168733, 0.10173918107258421, 0.18533118734402315, 0.1452539778713669, 0.09497325055833374, 0.11905458729181971, 0.19305514145110333, 0.13560529133038862, 0.23269335233739444, 0.15993918558316572, 0.12544988840818405, 0.12319160172981874, 0.10733108315616846, 0.07534713404519217], [0.049116541032812426, 0.05136955549408283, 0.05310309033042618, 0.04267720977908798, 0.06280921825340816, 0.03499665477180055, 0.028747852758637497, 0.018814254452341368, 0.04624546259375555, 0.04406261543876358, 0.02649873648104923, 0.04198749928868242, 0.042999510520270894, 0.03511692171118089, 0.02959820980738316, 0.03625960182398558, 0.017471092686589276, 0.02730499893160803, 0.0678720258708511, 0.02008596308795469, 0.024733493703284433, 0.05764001634504114, 0.03510086078728948, 4.815025627613068, 27.36985056740897, 46.53514664513724, 40.165392535073416, 28.91614784513201, 21.699738366263254, 34.370879786355154, 36.62278052738735, 19.79018579210554, 3.487123476607459, 0.23968714848160744, 0.26809949960027424, 1.260340256350381, 2.0879137005124773, 4.195965451853616, 5.927438735961914, 4.4990189501217435, 4.184601673058101, 4.479092385087695, 12.435593145234243, 18.81704715320042, 36.08683122907366, 43.478998865400044, 46.52627379553658, 40.57533972603934, 40.79623685564314, 33.37287180764334, 35.00159556525094, 37.62122276851109, 42.07892295292446, 42.206731591905864, 44.473900999341694, 43.2298503603254, 44.77881574630737, 41.65321724755423, 43.54700435910906, 41.46482031685965, 42.90341704232352, 40.668911116463796, 41.92572907039097, 41.76062250137329, 42.51671852384295, 45.298353399549214, 47.21887717928205, 44.090426445007324, 43.60326392310006, 37.898910999298096, 34.31498500279018, 31.474811553955078, 33.34098999840872, 34.48193631853376, 33.43461697442191, 35.47859982081822, 35.54364538192749, 31.89508376802717, 33.61764989580427, 32.10901532854353, 34.67462028775896, 43.78879819597517, 45.461392879486084, 45.54804039001465, 46.27473858424595, 45.30139671053205, 46.97890377044678, 45.402385302952354, 43.78733560017177, 37.929462228502544, 46.526318958827424, 43.28674915858677, 40.44410562515259, 36.78907176426479, 34.8203934941973, 33.14414405822754, 34.21479892730713, 34.394805908203125, 33.4161764553615, 33.455496311187744, 33.26327787126814, 33.3437762260437, 32.18072073800223, 35.29296132496425, 42.71925503867013, 45.4541528565543, 48.465915543692454, 45.074472018650596, 45.288764885493684, 46.20308181217739, 43.73233713422503, 43.01339660372053, 37.515016078948975, 37.16322531018938, 41.205228669302805, 41.87552833557129, 43.25282110486712, 42.790609564099995, 41.62798833847046, 35.91944912501744, 35.83582755497524, 34.521916253226145, 34.01410368510655, 32.48647969109671, 34.04707636151995, 33.646860122680664, 33.99687215260097, 33.30030482155936, 35.68940469196865, 36.75483104160854, 43.86542987823486, 44.883782182421, 50.000008310590474, 51.21109322139195, 49.73077603748867, 43.00162982940674, 37.6228278023856, 22.51367293085371, 13.304913537842886, 2.8832909294537137, 6.492193962846484, 7.164011376244681, 4.7941931911877225, 3.3086160038198744, 0.31591998785734177, 0.1677764007555587, 0.12358851757432733, 5.821294145924704, 24.0761855670384, 39.17756366729736, 32.4652737889971, 29.87640973499843, 43.10192707606724, 43.18445430483137, 27.249624150139944, 6.441217201096671, 0.20035292128367083, 0.0723543603505407, 0.039763848430344036, 0.03485941427892872, 0.035597555206290314, 0.08016891245331083, 0.03067360638773867, 0.01697561963062201, 0.07036598811724357, 0.01721274047823889, 0.05630360769906214, 0.02692134166136384, 0.021890038424836736, 0.01697542455180415, 0.04418408338512693, 0.03754006525767701, 0.037013155674295764, 0.02041920690265085, 0.03874104849195906, 0.09448110910930804, 0.021459071996754835, 0.048587416032595296, 0.00893917809506612, 0.025354290480858514, 0.045024442220372815, 0.02355327533691057, 0.05612733447924256, 0.01728729620975043, 0.059492403375250955, 0.027093219670600126, 0.028865744825452566, 0.035695942783994336, 0.03644118797300117, 0.048370084658797295, 0.05557603834729109, 0.04276689175250275, 0.020819578186741898, 0.035624642324234755, 0.010734792948434395, 0.017662161362490485, 0.024719736405781338, 0.012580637204726892, 0.0351999540414129, 7.483559897967747, 32.90370512008667, 51.51892968586513, 44.392794677189414, 33.49038669041225, 25.761665684836252, 35.69094371795654, 41.45821605409895, 20.662509543555124, 4.145973597254072, 0.10071472890142884, 0.1939590179494449, 1.0612708926200867, 2.813123026064464, 5.574433769498553, 7.118913224765232, 7.941405364445277, 6.276313432625361, 6.16279593535832, 16.718491418021067, 23.544271435056412, 39.426323073250906, 47.34648779460362, 47.112691334315706, 42.631540979657856, 41.61803504398891, 36.48174946648734, 36.910105909620015, 40.32285261154175, 43.83828674043928, 43.879159518650596, 45.513410568237305, 46.13964128494263, 46.64810698372977, 43.05973066602434, 45.00060224533081, 43.70505503245762, 44.55781439372471, 41.65795591899327, 43.460005964551655, 43.60433741978237, 43.83172416687012, 46.10666166033064, 47.67861516135079, 45.86968639918736, 45.74150603158133, 39.41478558949062, 35.5885967527117, 32.97879082815987, 35.07150486537388, 35.5279598236084, 35.528077942984446, 36.26224545070103, 36.55592496054513, 34.064325264522004, 34.84761306217739, 33.11554527282715, 36.128916467939106, 46.06440271650042, 47.22688845225743, 48.24067578996931, 46.873530864715576, 46.84548793520246, 48.238431521824424, 47.69904286520821, 44.07723181588309, 40.473267214638845, 47.567836557115825, 45.56681442260742, 43.54370049067906, 38.63351624352591, 37.20834343773978, 33.98313556398664, 35.53068004335676, 34.88079765864781, 33.356435843876426, 35.77124057497297, 33.888174533843994, 34.14204086576189, 35.30053833552769, 36.743258816855295, 43.70915446962629, 47.1060106413705, 47.28972448621477, 46.017940112522666, 45.46750034604754, 48.882661546979634, 46.283017362867085, 44.98974221093314, 38.44456345694405, 38.77693053654262, 41.31816121510097, 44.27118730545044, 46.29061869212559, 43.802051884787424, 42.755614961896626, 37.79286411830357, 36.81049306052071, 36.08056047984532, 35.08333764757429, 33.68174007960728, 34.47780214037214, 35.25463506153652, 37.17906372887747, 36.35435771942139, 36.92176151275635, 41.16279602050781, 45.00803334372384, 46.9167834009443, 51.49288783754621, 53.00725466864449, 50.136328492845806, 47.35761533464704, 38.735901423863, 27.9609112398965, 15.811890465872628, 5.3358044028282166, 8.642379590443202, 9.689123971121651, 6.575925401278904, 5.307048414434705, 1.4999258688517978, 0.022863622521981597, 0.263199581099408, 6.696984299591609, 28.18182921409607, 44.316246373312815, 39.2165013722011, 36.481989179338726, 49.57546642848423, 49.58107015064785, 32.256744452885215, 7.671896900449481, 0.1729162899511201, 0.07269079836883716, 0.012525011752066868, 0.03364665846207312, 0.025315184811396257, 0.0343898239412478, 0.029514088428446224, 0.026937394103567516, 0.02746218835402812, 0.007453433221339115, 0.01589749364315399, 0.006906637048814446, 0.007845600168885929, 0.02391399133817426, 0.0730286884520735, 0.06126344084207501, 0.027605232017646943, 0.027336252254566977, 0.05089655212525811, 0.08248706627637148, 0.1064682783825057, 0.15711774198072298, 0.0992687911327396, 0.17547178853835377, 0.09907500153141362, 0.26623542819704327, 0.2769524816955839, 0.13488394075206347, 0.12998018174299172, 0.1922492996922561, 0.0832076704661761, 0.12296000415725367, 0.09303679982466356, 0.09065174923411437, 0.15950220903115614, 0.12091014986591679, 0.11532238684594631, 0.18783020467630454, 0.17475696546690805, 0.0717671357893518, 0.2058920469135046, 0.1514647038919585, 0.2717806063592434, 8.392717787197657, 37.83877086639404, 58.71592589787075, 49.964034012385774, 40.86399221420288, 32.470054149627686, 42.72917359215872, 45.26236867904663, 26.249884332929337, 5.244487268584115, 0.47680932602712084, 0.7225460484623909, 4.435507203851428, 9.447450859206063, 10.054865854127065, 12.549704279218401, 12.42301082611084, 10.140634417533875, 7.644371611731393, 17.752506698880875, 20.053631952830724, 40.96001631872994, 46.65215083530971, 50.85236815043858, 45.356440339769634, 44.736980642591206, 38.189616680145264, 39.46696656090872, 41.84850679125105, 47.121831689562114, 46.877241202763145, 48.346986702510286, 46.949366978236604, 48.37859753199986, 44.32519565309797, 47.754819529397146, 45.60032558441162, 48.04433012008667, 44.660640784672324, 46.09106295449393, 45.586033139910015, 48.29770312990461, 47.75175537381853, 49.48889534814017, 46.45489842551095, 47.17137581961495, 40.706059660230366, 36.34410565240042, 33.95479038783482, 36.03250673839024, 36.84079415457589, 37.09331601006644, 38.66262572152274, 37.81337867464338, 34.538001332964214, 37.17111151559012, 34.433858258383616, 38.710293837956016, 48.17816284724644, 50.42708281108311, 48.270900453839985, 49.50591148648943, 48.17283705302647, 49.378815037863596, 48.53531762531826, 44.31603792735508, 41.71694612503052, 49.78382900782994, 46.95011738368443, 45.72791188103812, 39.936376435416086, 37.49875034604754, 34.96645505087716, 38.73692280905587, 37.95633438655308, 35.8935740334647, 37.19981104987008, 36.093334742954795, 36.99605860028948, 36.72056252615792, 38.05121203831264, 45.66794197899954, 49.12357643672398, 49.38429716655186, 47.7692995752607, 46.2270496232169, 50.703610692705425, 48.47726195199149, 47.52861050197056, 41.962287017277305, 40.81931529726301, 43.54264783859253, 47.174797807421, 47.71951225825718, 47.291253089904785, 45.51434857504708, 39.38483190536499, 39.98075805391584, 37.73336321966988, 37.760902404785156, 35.690481662750244, 37.24921274185181, 37.55697972433907, 38.62109981264387, 38.016380718776155, 39.95100586754935, 41.82506356920515, 47.383813517434255, 48.66157334191458, 53.778529030936106, 54.015820435115266, 51.3984375, 46.77921254294259, 41.154298373631065, 26.575770480292185, 15.992215326854161, 6.187592753342219, 12.845629794257027, 19.54362201690674, 11.308750799724034, 10.35706124986921, 2.7402162296431403, 0.554704657622746, 0.392074958554336, 8.3949533700943, 32.16102606909615, 51.02481549126761, 44.95075239453997, 41.31819248199463, 55.940759795052664, 58.49400738307408, 37.055840900966096, 9.396478874342781, 0.34509772647704395, 0.17304248389388832, 0.11794617319745676, 0.180401616862842, 0.11225390899926424, 0.2015750307057585, 0.15005739512188093, 0.13730202242732048, 0.16923953938697064, 0.09232695041490452, 0.12748998536595277, 0.12459924976740565, 0.10871583063687597, 0.09089592006057501, 0.16612241736480168, 0.15675370794321808, 0.15239701100758143, 0.08565637442682471, 0.12716708412127836, 0.155325785279274], [0.03029614074953965, 0.09385997136788708, 0.07551013851272208, 0.07418911225561585, 0.03472648248342531, 0.038493359461426735, 0.031225055190069333, 0.0027584087594212697, 0.016254647335569774, 0.03483689370165978, 0.040532557360295735, 0.052177565172314644, 0.02424374409019947, 0.021062848257965276, 0.03666576949347343, 0.04206408553623727, 0.030512532352336814, 0.08767881590340819, 0.06741045920976571, 0.056148423347622156, 0.010576915661139148, 0.04350420147446649, 0.051570429001003504, 2.0581819244793484, 21.588898965290614, 44.6538975579398, 43.228860242026194, 31.019999844687327, 30.24646384375436, 29.212120260511124, 30.40791913441249, 24.64825333867754, 5.8623093622071405, 0.19495212180273874, 0.0592685750286494, 0.539016873708793, 0.8598907100302833, 3.0187176167964935, 3.1988785437175205, 5.768886055265154, 5.702951558998652, 3.9041280831609453, 9.172176258904592, 15.209837743214198, 27.156754527773174, 44.21837057386126, 43.875397069113596, 42.532838344573975, 39.298028060368125, 40.07822738374983, 41.33891895839146, 41.525460720062256, 43.82579040527344, 46.71882922308785, 45.18464960370745, 41.56599651064192, 39.63656514031546, 43.683963775634766, 46.01609883989607, 43.177207333701, 42.816213675907676, 42.10249819074358, 41.25623539515904, 39.92366123199463, 46.65936653954642, 44.76178223746163, 45.51112461090088, 42.60032272338867, 41.664858954293386, 37.96064574377877, 33.16549587249756, 32.7764766556876, 33.56409318106515, 31.79258394241333, 34.95121765136719, 37.0533048084804, 34.85737875529698, 33.19731862204415, 33.636027881077354, 30.760515894208634, 35.1499673979623, 44.64299930844988, 44.601765223911826, 46.6747533253261, 45.75212982722691, 45.279367446899414, 46.01812423978533, 45.61493764604841, 41.85576071058001, 33.940654277801514, 46.91376093455723, 43.311929430280415, 42.72455998829433, 37.179581369672505, 34.41776623044695, 33.13058812277657, 32.99497318267822, 33.320093291146414, 33.0196601322719, 32.50653914042881, 34.90545334134783, 33.75224692480904, 33.53685276848929, 32.707877090999055, 39.914979457855225, 45.19815342766898, 45.667865548815044, 46.85831778390067, 46.87092529024397, 47.94865689958845, 44.720659324101035, 44.38948386056082, 43.490334851401194, 41.39290298734392, 44.60972091129848, 46.2612521307809, 46.116691384996685, 44.74397053037371, 43.19776010513306, 42.81020695822579, 43.09875174931118, 40.1655592918396, 39.49331412996565, 39.94386311939785, 38.94580997739519, 38.855490343911306, 35.04639407566616, 34.521176270076204, 33.135601248059956, 36.468509674072266, 41.831997871398926, 45.30922038214547, 47.01942913872855, 51.381668022700715, 46.86749982833862, 39.47300454548427, 28.046342815671647, 18.706645488739014, 9.910761083875384, 1.204476305416652, 8.678356494222369, 6.660761603287288, 3.3916287379605428, 1.6510400686945235, 0.781043529510498, 0.13615645175533636, 0.2903190515935421, 7.925712857927595, 28.631374188831874, 40.92786700384957, 31.46576499938965, 32.59253352028983, 44.548865113939556, 41.03211777550833, 19.8086610521589, 3.413745722600392, 0.0708871776504176, 0.026658326221097792, 0.0816320917968239, 0.058697065338492393, 0.03304023814520665, 0.01512461681185024, 0.012088112383415657, 0.03603157334561859, 0.026294697608266557, 0.07188497018069029, 0.013108670611732771, 0.03626741515472531, 0.029619726152824502, 0.015326631953939795, 0.04925408008109246, 0.09461755571620804, 0.05067285948566028, 0.018275241500564983, 0.03102600694234882, 0.050997063517570496, 0.018380648523036922, 0.03833901649340987, 0.020956562532644187, 0.03396403643169573, 0.03165159248081701, 0.04225385481757777, 0.026652132892715077, 0.019393363734707236, 0.03573062949414764, 0.027373434277251363, 0.030358610076031516, 0.031711524086339135, 0.01472552795894444, 0.04016039786594255, 0.048569244864795885, 0.030901461839675903, 0.0674960564023682, 0.11556461027690343, 0.0010264446256249876, 0.09000815876892634, 0.04962843802890607, 0.04962430235796741, 0.0356757258331137, 3.0590914274965013, 26.31763448034014, 51.40227290562221, 47.994341305324006, 34.217984676361084, 33.19314275469099, 34.82856804983956, 39.46501064300537, 29.74890681675502, 6.171719593661172, 0.20295540163559572, 0.1020141506035413, 0.8841537109443119, 2.563411065510341, 5.464839398860931, 6.668615673269544, 9.237473692212786, 5.583337017468043, 5.70361294065203, 11.39162630694253, 16.51919276373727, 33.21194805417742, 44.325206075395855, 46.96610171454293, 42.85272993360247, 42.32141160964966, 41.029428822653635, 42.736559527260916, 42.89165721620832, 46.34934834071568, 46.790531158447266, 47.81939261300223, 42.136012826647075, 42.035819802965435, 45.33629751205444, 48.49023076466152, 44.836972168513704, 45.2311087335859, 43.35630757468087, 43.10013444083077, 42.48497567858015, 48.28861141204834, 46.59659998757498, 47.121147292000906, 44.344330992017476, 43.54599339621407, 37.87618691580636, 35.52558353969029, 33.81638922010149, 35.37040594645909, 34.44669852937971, 35.91434219905308, 39.93219361986433, 35.73864310128348, 35.028144632067, 34.72134344918387, 33.09119183676583, 37.45334734235491, 46.764642170497346, 46.56232104982649, 48.02502455030169, 47.97163806642805, 46.41629423413958, 46.49760552815029, 45.118832792554585, 42.81824949809483, 36.672057151794434, 49.67807742527553, 44.33959232057844, 43.19135039193289, 38.34026404789516, 35.54770312990461, 34.68038729258946, 33.54185199737549, 34.486654145377024, 34.51354367392403, 35.501469816480366, 36.371804646083284, 34.87755632400513, 34.59731115613665, 35.150630950927734, 42.40449122020176, 46.46159648895264, 46.53784602028983, 48.86027445111956, 46.244555609566824, 49.725755964006694, 47.34582771573748, 46.06112316676548, 44.87929712023054, 42.87562077386038, 45.774575982775005, 47.37546525682722, 47.52984728131975, 46.4360271181379, 44.324031829833984, 44.821383884974885, 43.967853273664204, 41.82949651990618, 41.37860706874302, 41.22046259471348, 40.48227902821132, 39.863510676792686, 37.238071305411204, 35.73812198638916, 35.840177127293174, 38.32001004900251, 44.54982743944441, 48.17618261064802, 49.113112449645996, 53.40819352013724, 48.03937258039202, 41.01404898507254, 32.158319745744976, 20.967521565301077, 11.569182310785566, 4.777504486697061, 7.681741629328046, 4.135224734033857, 7.457928861890521, 4.847749037402017, 0.9141073950699398, 0.09614484304828302, 0.3359343824642045, 9.078025562422615, 32.87161486489432, 45.12662172317505, 36.7188150542123, 35.25436755589077, 52.12835618427822, 47.17648274557931, 25.347101415906632, 5.360529567514147, 0.06522124739629881, 0.03473003461424794, 0.06784540015671935, 0.030702963205320493, 0.025035937117146592, 0.08325569038944584, 0.06318210038755621, 0.048766630701720715, 0.04997855870585356, 0.04235749425632613, 0.04338489805481263, 0.032580432282494645, 0.002793145087447816, 0.039569478681577105, 0.0612700701292072, 0.008653219689482024, 0.09399780218622514, 0.01552257760028754, 0.042764879896172454, 0.06318103508757693, 0.099356349291546, 0.1672821015651737, 0.16926528300557817, 0.21614327255104268, 0.13175630143710546, 0.13278942528579915, 0.1265218516013452, 0.23189957493117877, 0.10006042436829635, 0.14011317943888052, 0.17242617053644999, 0.18102065793105535, 0.18713467914078916, 0.09630447519677025, 0.13937752534236225, 0.12892748894436018, 0.17778663789587362, 0.22606154105493, 0.2671987036509173, 0.18697002583316394, 0.11986665800213814, 0.12818255248878682, 0.21054071746766567, 3.707034613404955, 30.11105040141514, 57.114136832101, 55.573134081704275, 40.85739489964077, 38.687948431287495, 39.08583007540022, 41.28799213681902, 32.992874826703755, 7.798248154776437, 0.5684578567743301, 0.39477832349283354, 1.430655477302415, 4.709181981427329, 10.402387823377337, 10.295622672353472, 13.967353922980172, 12.38580322265625, 8.931810276848928, 14.129291244915553, 18.819364377430507, 33.06572321483067, 47.27950716018677, 50.08833728517805, 47.067552362169536, 44.137761047908235, 43.721918310437886, 45.96563407352993, 44.57320812770298, 48.498071806771414, 48.908505371638704, 48.08698163713728, 43.656153610774446, 41.738989285060335, 46.41853502818516, 48.52900518689837, 46.24382952281407, 48.58273213250296, 45.45828703471592, 45.85667242322649, 43.876216956547324, 51.98619951520647, 46.67686905179705, 48.44482776096889, 46.983764035361155, 45.30921343394688, 41.02166421072823, 37.89879287992205, 37.03328357424055, 37.06449488231114, 34.12943683351789, 37.17610032217843, 40.34242916107178, 37.727141107831685, 36.098670959472656, 37.56016199929373, 34.41239179883684, 39.27206264223371, 48.23421049118042, 47.70397956030709, 50.05038969857352, 49.06389141082764, 47.35904318945748, 47.949827671051025, 46.528104645865305, 42.89654874801636, 38.99759142739432, 50.9787871497018, 46.65426308768136, 45.94929191044399, 40.95754623413086, 38.457070214407786, 35.76978145326887, 36.428342138017925, 36.60447202410017, 35.791334765298025, 36.71000126429966, 38.24319771357945, 37.511500290461946, 36.802033628736226, 36.73491055624825, 44.108262470790315, 49.09088863645281, 48.63635832922799, 51.30848959514073, 46.9645904813494, 51.102597100394114, 48.776218618665425, 48.48452281951904, 49.39003637858799, 45.134549617767334, 47.493282386234824, 50.44439077377319, 51.260210037231445, 47.90228114809309, 47.11378220149449, 46.78684513909476, 48.597076688494, 44.83279630116054, 43.11214440209525, 43.43130643027169, 43.21249028614589, 42.77271795272827, 39.23999670573643, 38.7876272882734, 37.39092820031302, 39.329604148864746, 46.56219598225185, 49.73839473724365, 50.25176239013672, 53.69058220727103, 47.984214305877686, 41.8284056527274, 31.73190532411848, 22.362759794507706, 11.957562293325152, 3.0218968519142697, 18.255834204810007, 12.423956649644033, 9.350070118904114, 5.256558895111084, 1.983509634222303, 0.5462959259748459, 0.8057525722043855, 10.37302473613194, 38.10444566181728, 53.52161938803536, 43.6678717476981, 44.714152336120605, 57.28299542835781, 54.2263126373291, 29.88886090687343, 6.10561443226678, 0.18277442668165478, 0.1284179227160556, 0.18516571979437554, 0.14326696949345724, 0.08852440624364785, 0.1538127064704895, 0.10949003909315382, 0.15272554409291061, 0.1310284369226013, 0.17834484151431493, 0.11145593824663333, 0.17808710677283152, 0.054514687441821606, 0.13387875897543772, 0.09698084568870918, 0.14687260958765233, 0.2212864729974951, 0.07988736791802303, 0.14856465879295552, 0.15420190058648586], [0.01564494799822569, 0.02770410305155175, 0.022979039632316147, 0.034333671775779555, 0.02142062789893576, 0.029137053659984043, 0.00691775738960132, 0.015205196237989833, 0.03030388622677752, 0.0348019932529756, 0.025205121342358843, 0.08756406206105437, 0.016054175860647644, 0.0817360705030816, 0.012911709707363375, 0.06203241100800889, 0.046625866288585324, 0.043166813507143936, 0.02557338434936745, 0.018865278589406183, 0.02570676906699581, 0.044259899495435615, 0.06484698105071272, 1.1229114021573747, 13.136093156678335, 40.46644408362252, 44.54180574417114, 35.68308530535017, 22.21284372465951, 22.97185799053737, 34.998600891658235, 27.86010503768921, 9.669096657208033, 0.9457102992704937, 0.056140114686318805, 0.5952120040144239, 1.6855670788458414, 4.814648687839508, 6.119889506271907, 7.501548784119742, 4.9149563567979, 2.9164053925446103, 6.027527970927102, 10.77623130593981, 23.525945561272756, 38.56590332303728, 47.43577562059675, 43.210947786058696, 43.04653256280081, 42.85379648208618, 42.11130155835833, 44.09003039768764, 46.37649495261056, 45.3742207799639, 43.68292849404471, 44.91880457741873, 44.62272793906075, 42.40102406910488, 43.8794652393886, 43.85929461887905, 46.1219094821385, 45.7512126650129, 43.41919919422695, 43.36455161230904, 45.3273343358721, 45.94481727055141, 46.60305833816528, 44.068251269204275, 41.31686190196446, 39.88237156186785, 34.307039737701416, 32.983442647116526, 32.87917797906058, 31.875639234270366, 33.43613862991333, 37.97474363871983, 34.873189381190706, 31.59404264177595, 34.14438588278634, 31.925867761884415, 34.78702824456351, 43.242409229278564, 46.3823835509164, 45.12881735392979, 44.96590641566685, 44.583036354609895, 44.045509815216064, 43.04471560886928, 42.79844018391201, 34.02401876449585, 46.890300342014854, 45.63327741622925, 42.84803989955357, 38.086175373622346, 33.75545004435948, 34.39251300266811, 32.46779945918492, 31.912732192448207, 33.95346328190395, 33.38563564845494, 33.4988044330052, 32.07485451017107, 33.3682165145874, 34.75168623243059, 38.18264763695853, 44.62383270263672, 46.661009788513184, 46.24077926363264, 47.82204335076468, 45.62076718466622, 46.411663259778706, 44.909084047589985, 42.80033009392874, 45.1238181250436, 41.33072008405413, 47.56986195700509, 47.72434820447649, 47.384866169520784, 46.326884814671104, 45.30902583258492, 46.00501993724278, 44.71846716744559, 45.54513256890433, 43.8486465045384, 42.67632211957659, 43.36221701758248, 42.885587964739116, 41.6510910987854, 37.95643860953194, 38.57468932015555, 40.0293641771589, 43.68938684463501, 46.704290117536274, 48.95458582469395, 41.528907026563374, 31.296944618225098, 22.810341903141566, 13.944383178438459, 6.971604032175882, 6.72662444625582, 7.348610247884478, 3.04383014355387, 6.719500371388026, 5.786954845700945, 1.098414116672107, 0.03321253175714186, 0.6114254082952226, 8.15172473021916, 27.045253310884746, 30.722432817731583, 24.856403997966222, 37.464009353092735, 46.61205278124128, 44.16459151676723, 16.952009950365337, 1.8561782496316093, 0.05846293683030775, 0.02041436725163034, 0.0029247376244581702, 0.06142689314271722, 0.03955253905483654, 0.042143250216862986, 0.05168377827586872, 0.049690391668783765, 0.037133297084697654, 0.040775913944733996, 0.02097391606574612, 0.09813825001141854, 0.009988109265188021, 0.031569659377315214, 0.04004374073286142, 0.047815653695059676, 0.02278311094934387, 0.04309287354616182, 0.053967452341956754, 0.05265295019905482, 0.027829270710104277, 0.02380478791227298, 0.054109330621681044, 0.01335395169111767, 0.012374011417185622, 0.02148647972249559, 0.026155204379132817, 0.042259418804730685, 0.03732369740360549, 0.020491923804261854, 0.05970726827425616, 0.029746160975524356, 0.015872735596661056, 0.018445109349808524, 0.025604186446538994, 0.04000894545710512, 0.023123253768842136, 0.02738264878280461, 0.056626943206148486, 0.050257029477506876, 0.017547285383833305, 0.0335081558940666, 0.06413572707346507, 1.3313874325581958, 17.08290532657078, 45.64365107672555, 50.67607150759016, 40.53341082164219, 25.870794091905864, 26.906956366130284, 36.94997467313494, 30.807739325932094, 10.90266420160021, 0.9752828095640454, 0.13659653599773133, 0.5562330984643528, 1.6581687033176422, 7.642766577856881, 7.61784599508558, 5.932571717670985, 7.88165693623679, 8.159418991633824, 6.976865555558886, 13.680686014039175, 27.152521337781632, 41.11935935701643, 48.09512145178658, 44.799441473824636, 44.02788918358939, 45.35347693307059, 44.17810923712594, 45.37816388266427, 48.877669266292024, 45.417171069553916, 46.06275599343436, 45.39588873726981, 44.94437394823347, 43.204885482788086, 44.852119241442, 45.425925799778526, 46.95579753603254, 47.61383015768868, 45.232359409332275, 45.23352323259626, 46.648388385772705, 45.80582550593785, 47.66324574606759, 45.212678636823384, 42.39134175436837, 41.266084466661724, 35.75074338912964, 34.90104470934187, 34.51050383704049, 34.305556297302246, 35.318113803863525, 41.14838545663016, 35.196697507585796, 33.37793009621756, 35.72993006025042, 33.87005363191877, 36.8500074659075, 45.39322410311018, 48.2402971131461, 46.01117951529366, 47.33163602011544, 44.968765599387034, 44.09148604529244, 43.21188579286848, 43.2528350012643, 37.8833018711635, 49.28208221708025, 47.631113801683696, 43.83674424035208, 38.60010930470058, 35.81942285810198, 35.98968499047415, 34.356260776519775, 33.295079776218955, 34.702593735286165, 34.813129152570454, 35.273350034441265, 34.178136757441926, 35.52898815699986, 36.07485948290144, 40.61788354601179, 46.10065146854946, 48.15242324556623, 49.32364634105137, 48.982913630349294, 46.13991921288626, 49.57643222808838, 46.41299383980887, 45.66032327924456, 46.268978527614046, 43.75589500154768, 49.059559209006174, 49.5484379359654, 48.83152627944946, 49.63645771571568, 46.13354771477835, 47.848512513296946, 46.47191456386021, 47.09010968889509, 44.47716665267944, 45.54606362751552, 44.53754997253418, 44.58788619722639, 42.34276342391968, 39.203786168779644, 39.726196902138845, 42.98883472170149, 45.75600344794137, 48.140100615365164, 50.41792161124093, 44.548118182591026, 33.269458293914795, 25.117623261043004, 15.988543203898839, 9.003198674746923, 7.603233064923968, 6.558166239942823, 5.8410192131996155, 8.199008090155465, 4.478486589023045, 1.3086470642260142, 0.10520809636052166, 0.7101027475936073, 9.7801262651171, 30.14471094948905, 34.88859701156616, 30.91260153906686, 43.62479639053345, 51.097160134996685, 50.3088071005685, 20.513831990105764, 2.577900665146964, 0.02090527885593474, 0.046713492300893576, 0.06627574509807996, 0.0934172747656703, 0.05375919298135808, 0.06271222167249237, 0.08594756094472748, 0.021658768245418156, 0.024014519693862115, 0.030546886580330983, 0.038687990446175845, 0.04890565913436668, 0.03406789300165006, 0.04624867545706885, 0.03138566442898341, 0.05023531635691013, 0.08233204816601106, 0.06473858508148364, 0.02816747800846185, 0.09596598121736731, 0.11031917495919125, 0.10498083462672574, 0.08388551337910549, 0.050277436418192725, 0.04016273881175688, 0.0718576523608395, 0.11268059217504092, 0.07731181862098829, 0.09136841792081084, 0.1509775836020708, 0.1273506549852235, 0.13382596895098686, 0.11522076944155352, 0.13261266691344126, 0.07263988110103778, 0.11620851286820003, 0.21688329641308102, 0.13473866640457086, 0.12605413741299085, 0.12971331392015728, 0.10648245976439544, 0.15084297582507133, 0.17925494696412766, 1.7958281508513858, 18.268306221280778, 52.0714921270098, 57.531244141714915, 47.33196953364781, 33.15273550578526, 32.74452883856637, 43.722964014325825, 36.183289596012656, 13.036781685692922, 1.6301773424659456, 0.25766186682241304, 1.6272107873644148, 4.200928202697209, 10.126018013272967, 12.26697860445295, 14.167033859661647, 11.452641912869044, 6.80760874067034, 8.59408266203744, 13.989976389067513, 27.85475492477417, 42.82667766298567, 51.65577098301479, 47.15785462515694, 48.02618489946638, 48.3778714452471, 46.12612703868321, 47.64159515925816, 50.12815741130284, 46.84051302501133, 48.77720178876604, 46.519363812037874, 45.17758675983974, 44.68530688967024, 44.680203437805176, 45.920654909951345, 49.34684985024588, 50.919439111437114, 47.73124776567732, 47.16473681586129, 47.74677698952811, 45.651710987091064, 49.17903000967843, 46.137838227408274, 44.48006752559117, 43.314878940582275, 36.79443229947771, 35.17887190410069, 36.09991468702044, 35.149637358529226, 37.28728539603097, 41.106786591666086, 37.443911688668386, 34.34971557344709, 38.125672408512656, 35.22979525157383, 38.86807353155953, 47.80553790501186, 49.53478472573416, 48.464477266584126, 49.94560391562325, 46.00986977985927, 44.736525535583496, 42.97958319527762, 43.658846037728445, 39.80571903501238, 50.2493930544172, 49.22062540054321, 45.31394168308803, 40.622517994471956, 36.69979783466884, 37.56728390284947, 36.29725742340088, 34.70379229954311, 37.30403402873448, 36.41554703031267, 36.9964268548148, 34.7134051322937, 36.808551039014546, 37.329509598868235, 41.35027231488909, 47.368180070604595, 50.94194780077253, 50.04892015457153, 51.60160282679966, 47.83520671299526, 49.71250574929373, 49.53210966927664, 46.284698826926096, 50.17716653006417, 45.58544601712908, 50.43537548610142, 50.977623326437815, 50.48638221195766, 50.16335351126534, 48.35413639886038, 50.26050669806344, 49.76107365744454, 50.080013343266074, 47.93309988294329, 47.610470703669954, 48.03909117834908, 47.441556521824424, 45.998182909829275, 42.122189385550364, 42.299080099378315, 46.44231871196202, 47.92061397007534, 50.43369402204241, 52.343778133392334, 45.619537353515625, 33.20042446681431, 25.584741967064993, 16.362338917596, 9.885450533458165, 12.12276440007346, 15.025672265461512, 9.128228034291949, 18.98805969102042, 11.84459240095956, 2.9714381652218953, 0.1831851303577423, 1.1427119225263596, 11.531247752053396, 35.71873998641968, 42.791321754455566, 38.06680032185146, 49.79360859734671, 58.98741980961391, 57.75702585492815, 25.057872227260045, 3.837205639907292, 0.10745288697736603, 0.15789549238979816, 0.13173039497009345, 0.23472754604050092, 0.09158898251397268, 0.18087948193507536, 0.19692275034529821, 0.20406821263687952, 0.12305471407515661, 0.12952375837734767, 0.09373632871678897, 0.17328138250325406, 0.09659751411527395, 0.1725214368530682, 0.12333998376769678, 0.17537133821419307, 0.14582796421434197, 0.23752956997070993, 0.1328662625913109, 0.1787723321467638], [0.10264827550521918, 0.023665734034563814, 0.028120631950774362, 0.07009890316320316, 0.022630817157083323, 0.022638744142438685, 0.03754367506397622, 0.022620947865237082, 0.05311269499361515, 0.026651959866285324, 0.048878110612609556, 0.036969193390437534, 0.0204936829062977, 0.09366540145128965, 0.06248266649033342, 0.05189855157264641, 0.02435644536412188, 0.059479626560849805, 0.04591767250427178, 0.027197797184011767, 0.05843709143144744, 0.03396729000711015, 0.0084823281005291, 0.14825102633663587, 7.158961338656289, 33.66741636821202, 45.888130392347065, 39.998708724975586, 33.093356200626914, 24.553700515202113, 32.63099874768938, 34.30220379148211, 15.294638769967214, 1.378606630223138, 0.010842895451267915, 0.29704881619129864, 1.6466986387968063, 7.593912056514195, 6.241837339741843, 4.507278186934335, 5.095361990588052, 8.47748407295772, 5.139573378222329, 9.313165630613055, 19.81860739844186, 35.23602431161063, 44.73992320469448, 45.57746253694807, 45.419547353472026, 45.71324075971331, 46.060602051871165, 45.39107363564627, 45.173789569309776, 45.09177998134068, 45.57273428780692, 46.130625997270855, 45.07907172611782, 47.07560185023716, 46.60418394633702, 44.76990468161446, 43.82764557429722, 45.029211453029085, 45.72082471847534, 43.871929918016704, 44.831194741385325, 43.71983732495989, 44.80673360824585, 44.79724931716919, 42.42371688570295, 43.06066172463553, 40.386338302067344, 35.26941040584019, 31.55862419945853, 34.021142210279194, 32.46502365384783, 34.49787548610142, 35.12182024547032, 33.39072172982352, 32.745915004185264, 32.6412855557033, 33.806797231946675, 40.075052056993755, 45.57569422040667, 45.105995995657786, 44.84440674100603, 45.74255173546927, 45.20149898529053, 42.197299412318635, 45.03561074393136, 32.25480243137905, 45.08654451370239, 45.73097256251744, 42.10545812334333, 40.68645184380667, 34.52372973305838, 35.50299147197178, 33.2123475755964, 33.33139453615461, 32.85680825369698, 34.96022251674107, 34.23223195757185, 34.520731585366384, 32.963897364480154, 33.053775787353516, 36.31709453037807, 41.660509381975444, 44.41344124930245, 44.196528911590576, 46.917116914476665, 48.94784607206072, 44.015625613076345, 47.465020588466096, 47.74025610515049, 47.43188115528652, 45.94633892604283, 45.46103504725865, 44.074938910348074, 45.204507555280415, 45.30521127155849, 45.482042925698416, 46.117455686841694, 48.27205385480608, 47.62056296212332, 47.92920541763306, 48.294256823403494, 46.76534741265433, 44.263662406376426, 44.664938245500835, 42.43707479749407, 42.34534815379551, 44.15647949491228, 44.652417591639924, 48.42031799043928, 47.00459473473685, 35.60847207478115, 25.268496445247106, 14.331542883600507, 8.009860754013062, 3.92341193982533, 8.67544867311205, 4.027979288782392, 2.836194736616952, 6.717421557222094, 3.2184726808752333, 0.402510365737336, 0.12428526447287627, 0.6026118897965976, 11.331105760165624, 30.579251289367676, 36.05944490432739, 29.384084701538086, 35.06076989855085, 47.36555017743792, 42.87656920296805, 12.568483522960118, 1.5617588652031762, 0.07835194495107446, 0.01965381940161543, 0.036575907708278725, 0.03072130400687456, 0.05075646178530795, 0.050688289371984344, 0.004468295590153762, 0.01889725964117263, 0.059396886000675816, 0.020081299856039028, 0.029328733017402034, 0.03721564748723592, 0.024378077060516392, 0.058946216611989906, 0.04280010264899049, 0.013323415918940944, 0.018394471977704337, 0.030163212346711328, 0.0342513145878911, 0.010159905850222068, 0.0470433688855597, 0.005992597792231078, 0.062174265539007526, 0.04324649726705892, 0.009295907703095248, 0.036278115651969395, 0.03443730103650263, 0.019364195210593085, 0.01288352336268872, 0.054972406809351275, 0.03906484879553318, 0.02291196644572275, 0.038465838081070354, 0.02811779228172132, 0.032001319607453685, 0.11145437083074025, 0.057652134980474196, 0.06355881624455963, 0.06208709414516177, 0.03811865546075361, 0.04223985324746796, 0.018108116629134332, 0.007485700105982167, 0.2574341504701546, 9.761357443673269, 39.55888080596924, 49.77268409729004, 44.329055377415244, 34.97213520322527, 27.7711854662214, 39.088494709559846, 38.04456608636038, 18.379986354282924, 1.875530285494668, 0.10954671033791133, 0.2836960612663201, 1.9701630132538932, 5.491464461599078, 8.576827679361616, 9.725978084972926, 9.497913888522557, 11.923592550413948, 7.085365150656019, 10.66522775377546, 22.319208485739573, 37.961628913879395, 47.70429570334298, 46.440491335732595, 46.94489581244332, 47.162145137786865, 46.86430365698678, 47.39582347869873, 46.61627728598458, 46.64924648829869, 47.06442219870431, 48.88612174987793, 46.805091108594624, 46.32597460065569, 46.34861530576433, 45.44851786749703, 44.351609230041504, 46.283298764910015, 44.911595821380615, 45.956969669886995, 45.1912955556597, 43.811133180345806, 46.32163545063564, 46.17248541968209, 44.15206044060843, 45.29266629900251, 41.023561068943565, 36.437861170087544, 33.315997328077046, 35.6034311567034, 33.70521804264614, 36.81885869162423, 37.23905100141253, 34.231130668095176, 34.211741719927105, 34.04923030308315, 36.10458040237427, 43.43209505081177, 47.13020426886422, 46.449958256312776, 46.58815097808838, 46.30363266808646, 45.17845181056431, 44.07858324050903, 44.01953744888306, 34.91134193965367, 46.57726315089634, 46.1446578843253, 43.014591693878174, 43.29340900693621, 36.1266895702907, 36.30466420309884, 33.50429350989205, 34.831052030835835, 33.5771940095084, 36.05752372741699, 35.198274748665945, 35.443747656685964, 34.6589868409293, 34.57909992762974, 38.58399643216814, 43.442083086286274, 45.678954873766216, 45.62772233145577, 47.49049963269915, 50.60792704990932, 46.54280008588518, 48.84816026687622, 48.32421398162842, 47.92897960117885, 46.64557783944266, 45.47881548745291, 45.90847471782139, 46.178158623831614, 46.46527556010655, 46.528584071568076, 48.13898890359061, 50.949000222342356, 49.35366950716291, 49.54829202379499, 49.29282065800258, 49.02036094665527, 45.89372021811349, 46.87378099986485, 45.09697028568813, 44.99828502110073, 45.08603729520525, 45.89629799979073, 49.1619165965489, 49.92027078356062, 38.02666057859148, 27.29767962864467, 18.033886160169327, 10.647727847099304, 5.1982526523726325, 7.789459552083697, 6.120763676507132, 4.750102528503962, 6.196376579148429, 2.5159857017653326, 0.7838804029992649, 0.06560842626328979, 1.0107391412769045, 11.94141902242388, 34.28709493364607, 39.50829097202846, 31.560840674809047, 37.87468263081142, 52.73534039088658, 48.72378751209804, 16.94803384372166, 2.033696038382394, 0.07175813162965433, 0.10664160336766924, 0.02298957558481821, 0.04856278521141835, 0.03868486579241497, 0.005427719085543815, 0.02636256637716932, 0.002877144330081397, 0.028155269467138817, 0.04964098414140088, 0.05961316903787, 0.02309119638188609, 0.03588099963963032, 0.037350696311997514, 0.039607486820646694, 0.05576547175379736, 0.04456716390060527, 0.030552470923534462, 0.02530499660809125, 0.034699123951473405, 0.1606228638972555, 0.15915181354752608, 0.1968616007694176, 0.2698918362813336, 0.06320702297879116, 0.08924726995506457, 0.05508798507175275, 0.14004396886697837, 0.1523035495941128, 0.11785298319799559, 0.09037595867578473, 0.17238244573984826, 0.06803724236254181, 0.21245383338204452, 0.1055131589195558, 0.16346378145473345, 0.18362632739756787, 0.15193325946373598, 0.1576695537992886, 0.16447405224399908, 0.15323881512241705, 0.10177245642989874, 0.06616343398179327, 0.3866118831293923, 11.166022641318184, 43.94827325003487, 56.965365477970664, 50.15350096566336, 43.958848408290315, 35.3473414012364, 43.29682057244437, 43.51351056780134, 21.2812431539808, 2.3867948055267334, 0.27317746569003376, 0.9814875509057726, 3.8092087422098433, 14.497352957725525, 14.647422756467547, 12.50267105443137, 10.358386618750435, 13.78230254990714, 9.982470835958209, 10.783759679113116, 24.719105856759207, 40.127986907958984, 47.43101263046265, 48.668118544987266, 49.67165034157889, 50.38524770736694, 49.350799901144846, 47.70486198152815, 47.21873126711164, 47.51271302359444, 49.20105579921177, 49.5062450000218, 50.10444320951189, 49.41509853090559, 48.78951399666922, 45.94597067151751, 45.398949418749126, 46.1453527041844, 46.59330654144287, 45.206658022744314, 46.423280647822786, 43.90137638364519, 47.12036214556013, 48.51967723029, 46.173895903996055, 46.9032552582877, 43.85528203419277, 39.55243287767683, 34.438666411808555, 37.91978338786534, 35.853357860020225, 38.34794875553676, 38.62945849554879, 35.816897187914165, 36.58872045789446, 34.94620452608381, 38.46202775410244, 44.05286795752389, 50.40278148651123, 48.013865743364605, 47.29701314653669, 47.2735595021929, 46.69016095570156, 44.09178134373256, 45.869450160435264, 37.309338978358674, 48.186983585357666, 48.621058395930696, 45.51339667184012, 45.468563420431956, 37.39091430391584, 37.688269410814556, 37.27090154375349, 35.771699156079976, 36.340249402182444, 38.56439903804234, 37.77890171323504, 38.33628273010254, 36.59106894901821, 36.099442209516255, 40.69297967638288, 45.458606651851106, 47.63530009133475, 48.23826823915754, 50.32420430864607, 52.292653288160054, 46.78464950834002, 50.0706193787711, 50.63878747395107, 51.051566055842805, 48.368560859135215, 45.50248452595302, 46.245448453085764, 45.83673109327044, 46.25722564969744, 47.31211505617414, 49.6415160042899, 52.62465558733259, 51.77039541516985, 50.99240561894008, 52.342579569135395, 50.95905079160418, 48.655024664742605, 49.10966614314488, 48.0911088671003, 47.89073671613421, 48.176297255924766, 49.52316733769008, 51.75796856198992, 49.96188701902117, 38.67215517589024, 27.923102617263794, 16.927503653935023, 10.66686579159328, 7.16854681287493, 13.146663103784833, 13.097127658980233, 11.843572752816335, 14.825013501303536, 10.005954878670828, 1.8766155072620936, 0.3413968879197325, 1.4889930955001285, 15.172539813177925, 40.869790485927034, 47.34174564906529, 39.835082122257774, 45.55538463592529, 60.856221199035645, 55.75052506583077, 19.321180650166102, 2.7060764729976654, 0.10624093522450753, 0.20059500900762423, 0.2458653183920043, 0.1313044513974871, 0.11301325753863369, 0.11127392801323108, 0.12332506956798689, 0.18657571556312696, 0.18980494514107704, 0.05733243642108781, 0.14564830171210424, 0.07880969146000487, 0.1008967323494809, 0.1754268016666174, 0.126106574599232, 0.13916703020887716, 0.052119258658162186, 0.1377067007124424, 0.10581055403287921, 0.07743930178029196], [0.041612629046929736, 0.012716511297704918, 0.06799298830862556, 0.014228079517904137, 0.003137921664996871, 0.061397621142012734, 0.026438947367881025, 0.03643476903172476, 0.05143413506448269, 0.0491691682088588, 0.03705296193116477, 0.05828777980059385, 0.05168784609330552, 0.04901311872527003, 0.047329344254519255, 0.02328840071069343, 0.03266227378376892, 0.07818613813391753, 0.037816198476191075, 0.06321371333407504, 0.003259083634475246, 0.05028629130018609, 0.026775929910529937, 0.10463172157428094, 1.3708094486168452, 23.01786027635847, 44.877577441079275, 41.744033677237375, 30.463337966373988, 24.105133499417985, 23.10250496864319, 30.807822704315186, 20.02266730581011, 3.0099242372172217, 0.348807901676212, 0.2013120712446315, 0.8671903897609029, 6.372550759996686, 4.740368102278028, 7.482386520930699, 13.085433840751648, 14.608089004244123, 3.6991306032453264, 11.28285573210035, 19.09586272920881, 30.68927948815482, 45.911917550223215, 50.243577412196565, 47.193255696977886, 46.222894600459504, 45.115049498421804, 47.040607248033794, 46.16357435498919, 44.93696369443621, 43.308531761169434, 42.450439657483784, 43.525082792554585, 43.946682112557546, 45.1121312550136, 47.55016033990042, 47.537479877471924, 46.87949936730521, 46.50952863693237, 46.45366164616176, 46.02016006197248, 44.168426922389436, 44.38109391076224, 43.93160799571446, 43.45657702854702, 42.90048490251814, 41.94273131234305, 43.637296199798584, 37.040815421513145, 31.20270620073591, 31.92746237346104, 32.971873896462576, 32.77180399213518, 32.53649629865374, 32.218869822365896, 31.14216307231358, 32.0208774294172, 38.38936696733747, 41.513693945748464, 43.47769955226353, 45.24908372334072, 45.51843064171927, 44.88760369164603, 45.235555580684114, 44.64100864955357, 33.777580056871685, 44.29935877663748, 47.70603622709002, 44.586510453905376, 42.86502824510847, 35.96358755656651, 34.4802895954677, 32.76534564154488, 34.01031344277518, 33.98004361561367, 40.90420838764736, 36.21027987343924, 33.888980524880544, 35.293982710157124, 33.70443984440395, 35.74791199820382, 36.63582229614258, 40.99716138839722, 44.80733115332467, 44.62489925112043, 46.455402169908794, 47.55582659585135, 44.69741759981428, 46.83578824996948, 47.76095478875296, 47.19970709936959, 47.15901844842093, 46.77321972165789, 46.50937925066267, 45.27665070125035, 46.50142356327602, 46.221206188201904, 48.36426339830671, 48.72756038393293, 47.473646777016775, 46.48366049357823, 46.997097628457205, 48.162414755140034, 48.344825812748496, 45.88348552158901, 46.20057698658535, 44.88402189527239, 47.30160590580532, 49.528767585754395, 45.32746287754604, 30.753762245178223, 20.365255185535975, 10.241971288408552, 5.610916154725211, 2.5034233587128774, 6.018547424248286, 3.9634895835603987, 3.7916250228881836, 3.9789488911628723, 1.8643651817526137, 0.7549134716391563, 0.09108686660017286, 1.042591420667512, 12.425234249659947, 30.628812789916992, 37.66048356464931, 29.70474406651088, 32.32226596559797, 43.94880826132638, 38.94523327691214, 9.236983844212123, 0.5505938210657665, 0.16696116807205336, 0.023653381304549317, 0.019026038802361915, 0.03550265869125724, 0.01530578057281673, 0.06252367714686052, 0.03892283820148025, 0.07083657929407698, 0.029418842467878546, 0.02261229315107422, 0.030412526468613317, 0.027396891232846037, 0.05892198612647397, 0.0306598864096616, 0.04852833938119667, 0.032879567838140895, 0.06775548069604806, 0.02567606366106442, 0.0427526560878115, 0.049890844483992884, 0.025460588080542426, 0.008577183055292283, 0.028719157512698854, 0.022158324385860136, 0.0070549223954523245, 0.037303741688707044, 0.025572490379480377, 0.014984312733369214, 0.06387755128421954, 0.029302361753902266, 0.041491025393562656, 0.06550064097557749, 0.01931477241617228, 0.04559759057259985, 0.005494756649048733, 0.037496096188468594, 0.028524716517754962, 0.012315718473733535, 0.024781766380848627, 0.04438129958829709, 0.026517255398045694, 0.0913490050339273, 0.03825274755113891, 0.10592440542365823, 2.6919301577976773, 28.172671488353185, 50.174067633492605, 45.22425086157662, 35.57973085130964, 26.99977387700762, 28.761550426483154, 38.64514752796718, 22.95242040497916, 2.8268261764730727, 0.4901456875460488, 0.12614860305828707, 1.3566664989505495, 3.643148967197963, 6.710190653800964, 6.8558774420193265, 6.87830752985818, 9.649488840784345, 8.17011226926531, 14.606214727674212, 22.354366370609828, 34.37119940349034, 46.03204148156302, 50.39894955498831, 47.48735557283674, 47.58991098403931, 46.18569047110421, 47.36961487361363, 47.78760460444859, 46.95870188304356, 44.79145104544503, 44.83387327194214, 44.7731078011649, 46.35930163519723, 46.53965255192348, 48.313388688223704, 47.74327162333897, 47.345105103084016, 46.68422024590628, 47.27123532976423, 46.5247243472508, 45.365643228803364, 45.262389523642405, 47.75604241234915, 44.52184009552002, 43.206212588718955, 44.57292325156075, 43.88685812268938, 37.36936446598598, 32.7617186818804, 34.30554934910366, 34.50781488418579, 34.88140562602452, 33.870647702898296, 34.82383285249983, 33.44726616995675, 33.50354657854353, 41.303173950740266, 43.765615531376426, 45.33046449933733, 47.11685677937099, 46.854277406420024, 45.76860748018537, 45.853913988385884, 44.97490085874285, 36.83516958781651, 44.52209717886788, 50.38287489754813, 46.2443436895098, 44.44967957905361, 37.04197577067784, 35.0589598928179, 35.21724680491856, 36.54519346782139, 35.681400367191856, 41.998914446149556, 37.67403602600098, 35.66962317058018, 36.459598609379356, 35.2933087348938, 37.338913985661094, 38.55103417805263, 43.773060526166645, 47.04278898239136, 47.00985104697091, 48.63981853212629, 48.09571899686541, 46.37610585348946, 48.02381208964756, 47.74051318849836, 49.287908281598774, 47.41797086170742, 48.77771942956107, 46.66024201256888, 46.25830609457833, 46.87227324077061, 48.125564983912874, 49.845588071005686, 49.675249508449006, 48.78613369805472, 48.64217397144863, 47.29440757206508, 50.23627485547747, 50.110971042088096, 47.95251314980643, 48.10666935784476, 46.294728551592144, 48.53844084058489, 51.44266973223005, 47.80509669440133, 32.94649560110909, 21.76695350238255, 12.802795018468585, 7.55259198801858, 5.858586864812033, 6.596749586718423, 5.781423211097717, 6.3315828783171515, 4.783448670591627, 2.342433814491544, 0.28811147862247055, 0.06953943746962718, 1.3131745755672455, 14.184352244649615, 35.23692757742745, 41.84749582835606, 35.59193536213466, 37.03906100136893, 51.36597204208374, 46.0059266771589, 12.477908543178014, 0.9548465290239879, 0.12939987145364285, 0.04216022716302957, 0.0444990729114839, 0.019663471562255706, 0.013930681011905628, 0.005624256329610944, 0.04174102144315839, 0.052875733601727655, 0.03800825781321951, 0.017338320346815244, 0.021564533302028264, 0.02064598348390843, 0.07857507440660681, 0.017106466627280627, 0.02780875690015299, 0.004653088665301246, 0.034608583631260056, 0.013669490830839744, 0.03070462561611618, 0.04178651721615877, 0.07311132723199469, 0.10341256377952439, 0.1462755123419421, 0.07195361756852695, 0.08292342536151409, 0.21828419981258257, 0.10221482054995638, 0.08578481432050467, 0.16947547958365508, 0.1630538377378668, 0.16438440419733524, 0.1801885568669864, 0.15459384955465794, 0.1265189881835665, 0.0857218937682254, 0.1418820930910962, 0.10610712811883007, 0.12331763282418251, 0.09226250994418349, 0.19438767566212586, 0.14579751156270504, 0.12907589812363895, 0.10987641728882279, 0.2614952911223684, 3.3142129949160983, 31.480891227722168, 55.39621557508196, 53.81656347002302, 40.97894321169172, 33.73120430537632, 32.31538030079433, 40.416646344321116, 26.40283850261143, 4.681096059935434, 0.6787007983241762, 0.3893191021467958, 3.544704718249185, 14.168189866202217, 13.791596634047371, 17.212188720703125, 19.99968613897051, 22.842239345823014, 7.078182016100202, 14.224427717072622, 23.478046417236328, 37.21045569011143, 48.62745073863438, 52.44749389375959, 50.85069016047886, 48.375790459769114, 47.82995040076119, 49.43590491158621, 50.01593705586025, 49.70663799558367, 47.46051468167986, 47.441473143441335, 48.25347089767456, 49.63794463021414, 48.543384483882356, 51.25129549843924, 49.592704909188406, 50.31550516401018, 48.42955214636666, 50.8163035256522, 48.2191606930324, 46.07486322947911, 45.84028162275042, 47.55980096544538, 47.09043278012957, 45.31184680121285, 46.27363729476929, 47.567475250789094, 40.38643557684762, 33.69722761426653, 35.85295833860125, 38.00439855030605, 36.16705860410418, 36.25301129477364, 35.54112318583897, 33.69055734361921, 35.196652344294954, 42.41317646844046, 46.03001608167376, 47.126942089625764, 48.800116947719026, 49.85015998567854, 47.20011356898716, 47.96166740145002, 45.73763935906546, 39.49126788548061, 47.07177339281355, 51.147864614214214, 48.989260809762136, 46.844133036477224, 38.99686534064156, 38.560879775456016, 36.35663325445992, 37.677524021693635, 36.92642722811018, 43.934109347207205, 40.04825980322701, 36.43198994227818, 38.898836680821006, 37.233065128326416, 39.54778453281948, 40.177756854466026, 45.24264621734619, 47.39352362496512, 48.43533304759434, 49.651761123112266, 50.15970570700509, 46.63347060339791, 48.98138850075858, 49.404099532536094, 49.891241209847585, 48.36477061680385, 50.9315185546875, 47.56569651194981, 47.47086749758039, 49.06623295375279, 49.306122984204976, 50.145649501255576, 51.2951386315482, 50.35385227203369, 49.5353718485151, 48.784518241882324, 51.71744319370815, 52.922354630061555, 50.840153217315674, 50.68466990334647, 49.26305457523891, 51.42008808680943, 54.45746183395386, 48.22152655465262, 34.98992606571743, 22.10964560508728, 13.96303301198142, 8.198233366012573, 6.769538692065647, 11.855982235499791, 13.179922393390111, 12.280320014272418, 11.986317413193838, 6.285608385290418, 1.2088828746761595, 0.3761160863297326, 1.7406096224273955, 16.415855680193218, 40.87136425290789, 50.77828993116106, 42.32198483603341, 44.05072443825858, 57.82347495215279, 52.70702648162842, 15.438954591751099, 1.1969942897558212, 0.2565453238785267, 0.14551824011972972, 0.1801307185419968, 0.11123210990003177, 0.09314555541745254, 0.10422622904713665, 0.13416223733552865, 0.20440621807106904, 0.10396782934133496, 0.10434084718248673, 0.11879075930586883, 0.08918958769312926, 0.14573185651430062, 0.08223251386412553, 0.14210470686001436, 0.18294753453561238, 0.12703681896839822, 0.06383316830864974, 0.1374708012278591, 0.10784246107297284], [0.07733961141535214, 0.054344449790992906, 0.039607113626386435, 0.012582173238375356, 0.007808485151534634, 0.03295189627845373, 0.02960640311773334, 0.0069900268821844035, 0.009798062632658651, 0.05000175103279097, 0.024699202239779488, 0.024538408100072826, 0.03933480056002736, 0.03587540511840156, 0.05844256042369774, 0.014827164023050239, 0.04310581320896745, 0.055316010157444646, 0.010388460193228508, 0.014184821214127754, 0.050351600295731, 0.011870348443543273, 0.11003482807427645, 0.05001896207353898, 0.8833164530141013, 16.42241304261344, 39.559075355529785, 45.017885889325825, 35.31577920913696, 22.249422516141617, 33.74480887821743, 36.9603031703404, 23.569036551884242, 5.128111890384129, 0.3022557039346014, 0.14993741655988352, 1.1122654591287886, 1.0883360803127289, 5.2496532542364935, 5.738534152507782, 5.5910933784076144, 7.723749569484165, 8.341241189411708, 11.600074870245797, 21.71571227482387, 38.15253414426531, 45.213484627859934, 43.29759529658726, 44.00180912017822, 46.98491743632725, 47.43958670752389, 45.04917710168021, 40.56823866707938, 42.21486793245588, 39.7214651788984, 40.99331208637783, 40.017917019980295, 42.70010927745274, 43.22206142970494, 45.8187005179269, 45.57116052082607, 44.77071762084961, 43.33587639672415, 42.84189074380057, 45.57384252548218, 46.536835057394846, 42.39159536361694, 42.862783976963584, 43.11280448096139, 45.04370539528983, 45.81581354141235, 44.604620933532715, 42.16338178089687, 34.964599881853374, 32.128751686641145, 31.891220569610596, 31.19307599748884, 32.18934345245361, 32.274719442640034, 32.80347735541207, 33.059768608638215, 35.9262409891401, 39.83495705468314, 42.32179723467146, 43.01197917120797, 44.419020652770996, 46.18007632664272, 45.115872859954834, 44.55041456222534, 32.12544434411185, 44.563716888427734, 48.32638529368809, 44.43406350272042, 43.21370274680001, 38.210850375039236, 34.67076056344168, 32.98960222516741, 33.67701530456543, 33.93232338769095, 36.74076788766043, 33.91341039112636, 33.04890162604195, 34.80825499125889, 33.065410545894075, 33.61811542510986, 34.30323559897286, 37.27485506875174, 41.678373200552805, 44.783019406454905, 45.117092268807546, 47.97165196282523, 42.8516286441258, 44.73784221921648, 47.455063819885254, 44.07682534626552, 45.43198115485055, 46.14679445539202, 46.00916453770229, 45.231174741472515, 45.498249598911826, 45.01612799508231, 45.690857137952534, 47.59797784260341, 47.917654037475586, 46.92396436418806, 45.620968682425364, 47.25809628622872, 49.39232581002371, 47.0115498815264, 50.89996678488595, 49.14086702891758, 50.395718642643516, 49.08278703689575, 40.48260906764439, 27.900404589516775, 15.93839110646929, 8.490385140691485, 3.783786152090345, 4.104541054793766, 4.03719390290124, 3.603558131626674, 3.023616748196738, 3.2803014431680952, 1.323150125997407, 0.2270422141466822, 0.12347498509500708, 1.8129175709826606, 12.755251969609942, 34.36328887939453, 37.81444174902779, 27.629638501576014, 33.35700559616089, 44.659115655081614, 31.57818337849208, 7.662081701414926, 0.23321240448525973, 0.00824123018953417, 0.06315919304532663, 0.021477624840502228, 0.0728201949968934, 0.03179576760157943, 0.0542480604989188, 0.03490194146122251, 0.002956422241238345, 0.09267214153494154, 0.0517707393238587, 0.04786292722980891, 0.018077416312215582, 0.048759967487837584, 0.013744402793236077, 0.034304376026349406, 0.0673248688025134, 0.032791958789208105, 0.03849379372383867, 0.039667394677443166, 0.06499616375991277, 0.04449193811576281, 0.06493663588272673, 0.04436338287112968, 0.08605846749352557, 0.039880936433162005, 0.06319895519741944, 0.004870613421579557, 0.051456465651946406, 0.046787951341164966, 0.06742816218840224, 0.016453505593485067, 0.009913724015599914, 0.07082202471792698, 0.0411640291900507, 0.08054437980587993, 0.03339934262580105, 0.008193792958211685, 0.02483521797694266, 0.14636551322681562, 0.038784691864358525, 0.02682322889034237, 0.03591212404093572, 0.07768590176211936, 0.03593178120042596, 1.0708429047039576, 20.20374778338841, 45.48678159713745, 50.436792918613975, 38.28199645451137, 25.726450477327617, 31.632869175502233, 39.75269733156477, 26.532936573028564, 5.8160751802580695, 0.3192337357572147, 0.13545069391173975, 0.8003399255020278, 2.4529779170240675, 4.071470669337681, 5.428400874137878, 6.463160915034158, 6.945446670055389, 8.818259341376168, 14.145824483462743, 21.777356692722865, 39.426819869450156, 47.586874621255056, 46.75419555391584, 46.36061484473092, 47.32722043991089, 48.875595229012625, 46.44086306435721, 42.73658732005528, 43.5056278364999, 42.14651850291661, 43.498533725738525, 42.50077935627529, 45.47647047042847, 45.45267983845302, 48.19245876584734, 47.90941347394671, 46.740663937159944, 46.39919819150652, 44.92401572636196, 47.07140861238752, 46.80010230200631, 43.76458024978638, 42.689120701381135, 44.64993361064366, 46.791396209171836, 47.765408584049766, 45.68663610730852, 43.75137867246355, 36.60718876974923, 33.4269357408796, 33.8569666998727, 32.98872675214495, 34.6317012650626, 33.76192576544625, 34.524667739868164, 33.51257576261248, 39.057623863220215, 41.751235485076904, 43.58438219342913, 43.49365609032767, 46.755817958286826, 46.612216063908164, 46.20965828214373, 44.553186893463135, 34.163437843322754, 46.338575158800396, 49.95399733952114, 46.48045737402779, 44.57599435533796, 39.46779339654105, 36.7095878464835, 34.727360589163645, 35.264063767024446, 34.97342756816319, 38.51860693522862, 36.257593631744385, 34.748490061078755, 36.965663705553325, 35.81747041429792, 34.47827114377703, 36.61655146735055, 39.6147860118321, 43.716272899082725, 45.24670049122402, 46.460943358285085, 49.5007837159293, 44.51912334987095, 45.32152911594936, 48.70559712818691, 46.97636420386178, 47.867265701293945, 47.80966166087559, 48.730520316532676, 48.578549316951204, 48.496546677180696, 46.81622907093593, 49.106876441410606, 48.492798124040874, 48.97263029643467, 48.78462246486119, 47.07798160825457, 47.12213741030012, 50.81145715713501, 50.51839256286621, 51.894035134996685, 50.60116645268032, 51.25249753679548, 50.98642321995327, 43.397586822509766, 29.239343302590505, 18.12883676801409, 10.304609298706055, 5.497106398854937, 5.0441524641854425, 6.082304963043757, 5.361127981117793, 6.8947791031428745, 4.636900305747986, 1.1236436771495002, 0.23988473787903786, 0.16152764963252203, 1.822032413312367, 15.081591367721558, 38.30352544784546, 42.72092955453055, 31.55182191303798, 37.637068135397776, 49.98370436259678, 38.47989852087838, 9.81037437915802, 0.4917965361050197, 0.0784655859959977, 0.05131732865369745, 0.027088283328339458, 0.045017049581344636, 0.04747830643983824, 0.02195825833561165, 0.09203408113015549, 0.0031649290550766246, 0.038672804832458496, 0.019038773208324398, 0.039355631585099866, 0.04907402063586882, 0.025792520626315048, 0.023409542960247824, 0.05256693570741585, 0.04948600674314158, 0.030046446648027216, 0.007972837359245335, 0.06588298867323569, 0.031801090708800724, 0.11083773177649293, 0.12412318959832191, 0.16943972078817232, 0.18368998755301746, 0.07680806743779353, 0.11908468710524694, 0.1898900605738163, 0.16489316975431784, 0.08138145453163556, 0.23424282776457922, 0.17691263050905295, 0.09389186929911375, 0.1219471413642168, 0.23280107655695506, 0.2074853421321937, 0.11768169381788798, 0.07582378453974213, 0.14710422073091778, 0.27710995610271183, 0.10592677351087332, 0.08059161262852804, 0.08377429470419884, 0.16252080776861735, 0.07849845423230103, 1.6598957649299075, 23.07956722804478, 50.99049139022827, 57.514120306287495, 46.013548851013184, 31.685216903686523, 42.29627997534615, 46.26220055988857, 31.237325600215367, 7.305097154208592, 0.5060533710888454, 0.4656903626663344, 2.8760270220892767, 5.279919607298715, 11.444533365113394, 15.61639768736703, 13.710082973752703, 15.075188602719988, 14.567314369337899, 15.275915111814227, 24.681913886751445, 41.19841248648507, 49.43694019317627, 46.21270159312657, 47.41441338402884, 48.568304198128835, 51.0564158984593, 48.88244267872402, 44.14130462918963, 47.85366460255214, 45.288698877607075, 44.89167186192104, 44.961313656398225, 47.08028493608747, 47.72679397038051, 50.285475049700054, 50.3374718938555, 48.103844915117534, 48.557343414851594, 46.34333120073591, 50.00555992126465, 48.68249784197126, 44.78681312288557, 42.789640290396555, 45.118506227220806, 47.938474314553396, 50.25932550430298, 49.2269413130624, 46.29777186257498, 38.95877184186663, 36.12844399043492, 35.494952406202046, 34.0664826801845, 36.22018453053066, 34.09594651630947, 35.896328994206016, 35.90349953515189, 40.622167110443115, 44.75033508028303, 47.186790398189, 45.320674487522666, 50.38391712733677, 47.281091349465505, 48.37998022351946, 45.24124615533011, 37.86707782745361, 48.53210060937064, 50.73657642092024, 49.64338506971087, 46.40434333256313, 41.88378974369594, 37.59860290799822, 36.139898095812114, 36.31181737354824, 37.261917522975374, 40.466913087027415, 38.39277853284563, 35.811547074999126, 37.896920340401785, 37.86196395329067, 36.292119230542866, 37.64903988157, 41.181347710745676, 44.45364352634975, 48.97056320735386, 49.260706084115164, 51.902696064540315, 45.39375911440168, 47.06735781260899, 51.3748379434858, 48.6107576915196, 49.491566930498394, 49.743393966129844, 50.44660724912371, 50.5253199168614, 50.50213377816336, 49.490788732256206, 51.821197169167654, 50.50908892495291, 51.942648206438335, 49.44601106643677, 48.31150572640555, 48.91006176812308, 53.316651003701345, 51.59505762372698, 54.4269939831325, 52.0399820463998, 52.68818991524832, 51.94660520553589, 44.04564183098929, 30.789482934134348, 17.98434897831508, 12.157933575766426, 5.865437354360308, 8.135722160339355, 11.245658550943647, 11.004045367240906, 11.495131015777588, 10.5382068668093, 5.367451276097979, 0.8956634019102369, 0.3444135460470404, 2.501235978943961, 17.247006143842423, 45.04733235495431, 49.76082352229527, 38.50878913061959, 45.72398614883423, 57.04908084869385, 45.42066253934588, 11.781554000718252, 0.749221322791917, 0.1731389444321394, 0.15723789696182522, 0.0636036131264908, 0.2338408636195319, 0.11117749461638075, 0.12765685069773877, 0.22540944176060812, 0.09366073313036136, 0.15673386757927282, 0.1340183336287737, 0.14396664766328676, 0.09324964268931321, 0.11878967364983899, 0.07527085313839571, 0.13272185676864215, 0.16734346827226027, 0.06270414032042027, 0.2119628454425505, 0.11494484996157033, 0.16024665694151605], [0.009918245603330433, 0.06290848792663642, 0.04136525892785617, 0.04633472726813384, 0.033727655187249184, 0.05810488747166736, 0.04774423449167183, 0.030248334564800774, 0.04793961525761655, 0.04502442525699735, 0.06830507370510272, 0.051566727592476776, 0.03031780637268509, 0.06203598688755717, 0.08828243387064763, 0.03750257280522159, 0.007782974779339773, 0.052142376346247535, 0.04039743389668209, 0.025330005712541084, 0.04470897771950279, 0.027917710964434912, 0.027928996698132584, 0.005107763955103499, 0.2941728319440569, 10.484854255403791, 33.79795912333897, 46.810931069510325, 29.047612973621913, 24.898918288094656, 26.31848737171718, 37.08885874067034, 29.220826353345597, 6.8220314638955255, 1.3140771899904524, 0.025512645287173133, 0.8189202227762767, 1.7161646655627658, 3.4310159044606343, 1.373497098684311, 3.2059055609362463, 3.3700011670589447, 7.516949466296604, 15.712704930986677, 17.60332887513297, 30.081996509007045, 39.027809143066406, 45.77024725505284, 48.428502968379426, 46.29381486347744, 43.36992951801845, 42.24834087916783, 41.32075636727469, 38.28484174183437, 36.561146531786235, 35.269809927259175, 34.88079418454851, 36.773872579847065, 40.156405040196006, 42.1937905720302, 43.015415055411204, 42.54975373404366, 42.09122821262905, 41.529344763074604, 44.23811388015747, 45.192490645817344, 46.76470123018537, 44.825313091278076, 41.18105936050415, 44.406774452754426, 46.43942478724888, 46.09255681719099, 45.56042902810233, 38.08785336358206, 32.36309010641915, 34.47784730366298, 32.51526607785906, 32.179987703050884, 31.610534191131592, 31.867940630231583, 33.088909353528706, 34.215754304613384, 38.1943553515843, 40.47962481634957, 41.99759776251656, 43.34023986543928, 44.427250794001985, 45.25704983302525, 46.66433102743966, 34.80602461951119, 42.75187335695539, 47.82422161102295, 43.56827279499599, 43.40751232419695, 37.26364415032523, 34.950804233551025, 35.02455588749477, 33.92168569564819, 35.51372296469552, 35.54982233047485, 34.503666809626985, 34.91197769982474, 34.15891804013933, 33.01321567807879, 34.57074819292341, 35.12470374788557, 37.1161721093314, 41.268811634608674, 42.68060915810721, 45.97766487939017, 46.67767851693289, 46.27052102770124, 48.15084253038679, 45.88374260493687, 44.183792863573345, 44.16026626314436, 44.335968835013254, 44.63562379564558, 43.80665854045323, 44.544199398585725, 43.10575900759016, 42.35346712384905, 42.715676716395784, 43.56780726569039, 44.53001812526158, 46.03271893092564, 45.11306231362479, 42.728138310568674, 46.88650662558419, 48.663324287959504, 46.868076528821675, 48.14770541872297, 42.66574001312256, 36.03542498179844, 24.232031924383982, 14.42860313824245, 6.008628870759692, 4.9262193867138455, 4.380213439464569, 4.430285198347909, 3.5879290274211337, 5.342371753283909, 2.631664740187781, 0.8738344418151038, 0.17746544655944618, 0.03223410800897649, 1.981826433113643, 15.799793652125768, 33.862372398376465, 32.964779785701204, 27.73795918055943, 37.71485321862357, 44.92442567007882, 31.36493968963623, 5.9435993773596625, 0.12874884424465044, 0.06825406822775092, 0.14389199524053506, 0.02632257521950773, 0.0743186581613762, 0.018291665440691367, 0.05715603767228978, 0.04494780169001647, 0.05203549351011004, 0.03583796016339745, 0.06077502455030169, 0.02474688459187746, 0.03492391921047654, 0.05199051003104874, 0.06198860478720494, 0.04328045115939208, 0.041061353271028826, 0.03849546631265964, 0.04558371453146849, 0.04454030069921698, 0.036073720548301935, 0.01772868663205632, 0.060242930959377966, 0.02814474029998694, 0.05389506961884243, 0.010795319120266607, 0.025427945457132797, 0.07567887660115957, 0.040406190391097746, 0.09327411744743586, 0.10466332095009939, 0.08038142962115151, 0.05187327614320176, 0.019084221483873468, 0.05547886873994555, 0.058551485650241375, 0.036079518630036285, 0.029666653634714227, 0.03563120036518999, 0.04827010591647454, 0.05931061027305467, 0.01398192482468273, 0.017948508229372755, 0.05007786909118295, 0.014368350517803004, 0.6192862093448639, 13.19211300781795, 40.269931656973704, 51.91589764186314, 35.636046000889365, 26.334099973951066, 32.167168276650564, 41.33752931867327, 29.310899325779506, 8.826233267784119, 1.138273326413972, 0.07577311154454947, 0.5287657837782587, 1.5935245092426027, 3.0093662100178853, 4.288798596177783, 5.736282936164311, 6.599079404558454, 8.491485561643328, 13.783131122589111, 18.71124345915658, 32.80014222008841, 44.36778811046055, 47.44566290719168, 49.61151020867484, 49.95950378690447, 46.68980312347412, 43.35533830097744, 43.14191048485892, 39.99724612917219, 38.52121598379952, 37.5592691557748, 38.89662715366909, 40.178305762154714, 42.649554184504915, 44.2266389301845, 45.94073520387922, 43.94228042875017, 44.72380338396345, 43.3058671270098, 45.94324697766985, 47.31987271990095, 47.41866568156651, 45.1922926221575, 41.670730182102744, 45.68494074685233, 47.31441143580845, 48.39569704873221, 47.49508196966988, 39.13244553974697, 34.583373069763184, 36.00882032939366, 33.6309244292123, 33.28780501229422, 33.84206976209368, 32.61166538511004, 34.87582622255598, 37.42498132160732, 40.463140215192524, 40.95606279373169, 43.13083505630493, 44.62915849685669, 46.18091705867222, 46.91189881733486, 47.05311400549752, 37.02069691249302, 44.95277432032994, 49.90648903165545, 44.93338189806257, 45.099690505436485, 39.07920844214303, 35.07103933606829, 35.896586077553884, 34.79437943867275, 36.46861042295183, 36.355479853493826, 35.856651306152344, 35.63128648485456, 36.79027727672032, 34.68898221424648, 36.63363013948713, 35.73165321350098, 39.12575789860317, 42.4269825390407, 45.03734431947981, 46.78717517852783, 48.17718662534441, 45.425797258104595, 49.08976650238037, 47.68902356284005, 46.13998522077288, 45.63039738791329, 46.68363312312535, 47.13802099227905, 47.13914312635149, 45.61324575969151, 45.65835346494402, 44.7436648096357, 44.65785108293806, 46.212305545806885, 47.45152718680245, 48.20492730821882, 47.49235132762364, 45.79596948623657, 48.5331324168614, 49.65292147227696, 49.14301402228219, 50.000550270080566, 43.48776401792254, 38.021491118839805, 26.51374912261963, 16.29501782144819, 8.266116397721426, 5.035228371620178, 6.905137130192347, 7.350221361432757, 7.230034896305629, 8.26493433543614, 3.4164891753877913, 1.79107742863042, 0.2522845853652273, 0.05315572768449783, 2.68607434630394, 16.557456493377686, 37.34556688581194, 39.86038746152605, 34.015343938555034, 44.426771368299214, 50.508303778512136, 37.13867037636893, 7.811688576425825, 0.2032197317374604, 0.09126763511449099, 0.011709018261171877, 0.028764409013092518, 0.023557578945266347, 0.0866490915151579, 0.015980332590905682, 0.03608510636591485, 0.0375193869029837, 0.02538821383911584, 0.006336236339328545, 0.03401751516919051, 0.018726670848471776, 0.03758355935237237, 0.03358494909480214, 0.058577656745910645, 0.01656284642272762, 0.07647668450538601, 0.026912814172516977, 0.028034307029364363, 0.040193167714668174, 0.09182687010616064, 0.12157332285174302, 0.1353118656469243, 0.1558101371462856, 0.12419268515493188, 0.11770910663264138, 0.11666097358933517, 0.11218607585344996, 0.1044324358393039, 0.18830150152955735, 0.15761517600289413, 0.13642937211053713, 0.14999711407082422, 0.07948136648961476, 0.18228361516126565, 0.1597730123570987, 0.10513687053961412, 0.13370303197630815, 0.1550679284014872, 0.12438281066715717, 0.07281610343073096, 0.1296593975275755, 0.16740362718701363, 0.12541444173880986, 0.7202723590391023, 15.089456728526525, 45.88201250348772, 57.73975263323103, 40.71831280844552, 35.269962787628174, 36.685828481401714, 46.37964596067156, 36.873839787074495, 10.209100229399544, 2.1740922076361517, 0.16169919685593673, 1.772080619420324, 6.35694944858551, 10.576862301145281, 7.670572400093079, 10.022621870040894, 8.280620762280055, 11.534153836114065, 19.569726399012975, 20.899919067110332, 36.84659937449864, 44.50888865334647, 47.37453767231533, 50.990227358681814, 52.00794390269688, 48.091626507895334, 45.69991758891514, 45.00036948067801, 42.55137961251395, 39.124312673296245, 39.38783352715628, 39.76134089061192, 40.66477346420288, 44.70691926138741, 45.89955670492989, 47.51579107557024, 46.55202381951468, 45.96582514899117, 46.88040263312203, 47.48421846117292, 48.84515864508492, 49.008913789476665, 46.33923871176583, 39.89565304347447, 45.75031634739467, 48.71008913857596, 50.31232636315482, 48.128517968314036, 41.985080582754954, 36.710953167506624, 37.34389584405081, 35.5770696912493, 35.34797021320888, 35.01982763835362, 35.0278319631304, 35.15608876092093, 39.19530936649868, 42.03709132330758, 43.76406955718994, 45.30256053379604, 47.44679198946272, 47.61288867677961, 48.30165318080357, 47.529367855616975, 40.14881065913609, 45.86460379191807, 49.72529738289969, 46.38194581440517, 47.66366958618164, 39.79539748600551, 37.1214006287711, 38.34672587258475, 36.16709681919643, 38.73900032043457, 39.8455947467259, 37.76337596348354, 38.50223003114973, 38.35343435832432, 36.960758277348106, 38.66736786706107, 37.81527553285871, 40.931730202266145, 45.92042561939785, 46.47178602218628, 48.69455991472517, 50.25126559393746, 45.78344188417707, 50.52472931998116, 49.04995679855347, 47.86197117396763, 48.60764837265015, 49.677042143685476, 49.23980590275356, 48.31250626700265, 47.94286905016218, 47.57410383224487, 46.522487027304514, 46.172791140420095, 48.27382911954607, 48.04536887577602, 50.793676716940745, 48.287499700273784, 47.05110945020403, 50.050688471112935, 48.321862016405376, 48.0190213067191, 49.553197452000205, 45.67952810014997, 39.46311378479004, 29.72208677019392, 18.171198197773524, 9.77312421798706, 8.750100118773323, 9.789836372647967, 13.067818420273916, 10.509320599692208, 13.679853098733084, 8.34657393183027, 4.415089922291892, 1.1267723206962859, 0.27902850029723986, 3.0802990666457584, 20.883118322917394, 45.76469217027937, 43.19725636073521, 38.975079263959614, 50.73093795776367, 58.16923468453543, 43.230996813092915, 9.831332751682826, 0.5258702848638807, 0.14465366436966828, 0.23983485198446683, 0.21386959669845446, 0.23179136216640472, 0.22891537791916303, 0.11643696203827858, 0.14246894445802483, 0.09801344706543855, 0.07690694356071097, 0.1607516769851957, 0.1088808299973607, 0.13521212099918298, 0.14578767280493463, 0.14685868604906968, 0.13744891168815748, 0.15956710412033967, 0.0868197362869978, 0.16370641200670175, 0.0808555016826306, 0.09046007666204657], [0.025798593514731953, 0.03695002477616072, 0.021415946007307087, 0.04044950467401317, 0.03495959658175707, 0.08287598219301019, 0.056120416814727445, 0.011054598377086222, 0.04066184203007391, 0.02688843271295939, 0.023765234409698417, 0.02876646158152393, 0.03727994207292795, 0.020655433780380657, 0.021961065774251307, 0.002121530913947416, 0.052950881355042966, 0.02841960296167859, 0.03408185385965875, 0.021492133615538478, 0.007659939417083348, 0.025865676879350628, 0.024744933803698847, 0.08022255064653498, 0.05288704138781343, 5.955743091447013, 26.620595046452113, 43.31737681797573, 35.52329758235386, 29.441813809531077, 21.82180953025818, 33.06056765147618, 28.567878076008387, 12.001701593399048, 1.4048153438738413, 0.08424483838358096, 0.2027699037321976, 1.0991347751447131, 0.9188364041703088, 3.127091710056577, 3.9718921269689287, 6.341991714068821, 6.652706904070718, 8.271729673658099, 14.681957040514265, 30.052855764116558, 47.15270948410034, 51.12558174133301, 46.78530611310686, 43.63341563088553, 43.260262625558035, 39.55649757385254, 35.72698402404785, 34.148492268153596, 35.78959076745169, 34.251461097172324, 31.92273759841919, 32.695384229932515, 35.22181177139282, 36.67083774294172, 37.98476294108799, 35.294858183179585, 38.46045746122088, 39.014103821345735, 42.24048941476004, 44.362285137176514, 46.13050787789481, 45.52239111491612, 43.884221281324116, 41.14142336164202, 44.75648076193673, 45.23113305228097, 44.30454213278634, 38.21133327484131, 32.04203469412667, 32.53730923788888, 30.654222352164133, 33.03483847209385, 34.47162519182478, 33.89027288981846, 31.579256875174387, 31.15871020725795, 36.547750404902864, 39.37698738915579, 41.27120876312256, 40.14773368835449, 43.984042576381135, 42.01268924985613, 44.52032191412789, 35.436855043683735, 41.70094094957624, 47.268185070582796, 42.65501894269671, 43.26679045813424, 36.05584921155657, 38.08540064947945, 34.86219733101981, 34.21635184969221, 33.4449246270316, 33.08324657167707, 32.24826765060425, 33.47670221328735, 34.400628498622346, 32.76772539956229, 32.798293999263215, 38.38841853822981, 41.92178249359131, 44.86289937155587, 44.24718475341797, 45.362648555210654, 46.03318793433053, 46.166659355163574, 46.45555503027779, 45.00857182911464, 42.2354484966823, 38.246661390577046, 37.28343261991228, 39.306928702763145, 38.335619177137104, 37.76554380144392, 36.430641991751536, 35.49049513680594, 36.850806508745464, 40.76545980998448, 42.20574842180525, 44.06097303118025, 45.67259727205549, 47.11950404303414, 48.64255264827183, 50.68520144053868, 48.165124552590505, 47.52423661095755, 43.825231075286865, 38.20867211478097, 27.420563731874736, 16.147212266921997, 6.198004628930773, 2.416882025344031, 2.707609636443002, 5.605542157377515, 4.229568243026733, 5.8974737610135755, 3.2260253727436066, 0.7199097499251366, 0.15624195683215344, 0.02583543287723192, 2.6119127486433302, 18.533788204193115, 36.146356446402415, 31.911509309496196, 31.027993747166224, 35.900574343545095, 47.94213254111153, 23.003420182636805, 2.6306804844311307, 0.11724777067346231, 0.0978535231468933, 0.03630998644179531, 0.03165965008416346, 0.046066580406789265, 0.02492379054560193, 0.07362128022525992, 0.06546669386859451, 0.01676980299609048, 0.05550163698249629, 0.024697371891566684, 0.03713360581813114, 0.07072435638734273, 0.0039313470811716145, 0.0463802841092859, 0.03073897984411035, 0.045889370808643956, 0.05180669828717198, 0.0215444605398391, 0.01203495595005474, 0.03503513110003301, 0.054564410487988164, 0.041163174235927205, 0.020385242832292403, 0.011105284942979259, 0.012942799333749073, 0.07331331353634596, 0.03468543790014727, 0.02716518339834043, 0.0320566880649754, 0.03800195422289627, 0.03156218192140971, 0.06162628744329725, 0.04080288910440036, 0.01572718983516097, 0.01373194997930633, 0.023921043013355563, 0.059241175784596374, 0.020989907439798117, 0.03728712436610034, 0.024409834195726683, 0.03213218187115022, 0.05559072184509464, 0.016041614481114914, 0.02103087229521147, 0.0786508871242404, 7.507208091872079, 32.047023500714985, 50.143780435834614, 39.809571811131065, 34.00546360015869, 24.336039509092057, 35.67272901535034, 34.08029569898333, 12.93935751914978, 1.94405255147389, 0.15904079164777482, 0.2655022032558918, 0.9558922329119274, 2.6103672087192535, 3.632459815059389, 4.861320606299809, 5.791842034884861, 6.907383135386875, 9.104700565338135, 17.075696570532664, 32.21433959688459, 47.587489536830354, 51.96591772351946, 48.091894013541086, 44.73403460638863, 44.03622007369995, 41.52112851824079, 37.18862097603934, 36.72608286993844, 37.10334573473249, 36.054199014391216, 34.04681232997349, 34.36720071520124, 36.204547609601704, 40.2743889263698, 39.944974831172395, 38.592188358306885, 40.2215131350926, 40.67985800334385, 43.59624971662249, 44.72907011849539, 47.16121407917568, 46.21222216742379, 43.88045883178711, 41.4082168170384, 46.22196701594761, 47.30359656470162, 45.50179318019322, 39.696545464651926, 33.91986526761736, 34.093601499285015, 33.18411009652274, 34.5141099521092, 36.07337604250227, 35.90106071744646, 33.66408123288836, 33.86417893001011, 38.01664475032261, 40.56163093021938, 42.92379263469151, 42.71185173307146, 45.072036675044465, 44.85130282810756, 45.78784009388515, 36.90460293633597, 42.92591878346035, 48.39482157570975, 45.27577175412859, 45.164468560900005, 37.06799677440098, 37.304245948791504, 36.706349985940115, 34.927256788526265, 35.61987059456961, 35.637393951416016, 33.49914836883545, 35.38064064298357, 36.617013522556846, 34.808446066720144, 35.230278151375906, 40.21464136668614, 44.316590309143066, 45.580384254455566, 45.85709973743984, 47.70000866481236, 47.09836067472185, 46.54723998478481, 48.32871988841465, 47.55958904538836, 44.90611021859305, 40.700139795030864, 40.86146306991577, 42.86749832970755, 41.72398812430245, 39.491399901253835, 38.66676337378365, 39.288623673575266, 39.630360398973735, 43.6186055455889, 44.54610320499965, 46.0345185143607, 47.49135773522513, 49.48558105741228, 49.41876023156302, 50.709169251578196, 48.61773368290493, 48.071379457201274, 44.99982057298933, 39.38270228249686, 29.397734437670024, 17.471987077168055, 7.639198677880423, 4.857219432081495, 5.544168719223567, 5.576978547232492, 6.80222692659923, 8.08865853718349, 5.7377455319677075, 1.0453320507492339, 0.20370957973812306, 0.09406207302319151, 3.2658580924783434, 20.217863048825944, 43.79021562848772, 36.85098716190883, 32.595027923583984, 40.91338695798601, 53.30675676890782, 29.144413539341517, 3.5867330687386647, 0.21541875999953064, 0.03827477619051933, 0.02525460350859378, 0.01719255236509655, 0.025263225992343256, 0.02236675168387592, 0.06517702726913349, 0.07149967085570097, 0.018531834606879523, 0.05125385509537799, 0.00816012405058635, 0.026725519847657, 0.04952336688126836, 0.02677709699076201, 0.0141371922966625, 0.04432544597823705, 0.019126696079703312, 0.03638373641297221, 0.013240652458210076, 0.014926060502018248, 0.027168353853215064, 0.09837368809218917, 0.09798583069017955, 0.0771107008414609, 0.1973113337797778, 0.15301506141466753, 0.1510933009641511, 0.16873464147959435, 0.12281444482505322, 0.12715326914829866, 0.1727470633174692, 0.16938231672559464, 0.1740554009697267, 0.10400987137109041, 0.0808714133288179, 0.1269952112010547, 0.08414048648306302, 0.1977709462600095, 0.11562653338270527, 0.06936951873025723, 0.13108528458646365, 0.08454821139041867, 0.1893365252763033, 0.08345208556524344, 0.27183475345373154, 0.17139219173363276, 9.182913831302098, 36.68649203436715, 56.323563848223, 48.44719014848982, 40.1300505229405, 30.001602377210343, 41.25752428599766, 37.480459213256836, 16.226310559681483, 2.685197353363037, 0.4822398860539709, 0.5420498166765485, 3.059499199901308, 6.638066615377154, 9.616622124399457, 11.917215841157095, 11.956681609153748, 10.345702682222639, 11.903517467635018, 20.057317972183228, 34.771770000457764, 50.704083170209614, 53.682091508592876, 49.709764684949604, 46.23478644234793, 47.6470946584429, 43.67951692853655, 38.98702321733747, 36.9871266910008, 39.39121035167149, 37.97884654998779, 35.20128331865583, 36.39653328486851, 38.79200117928641, 41.835666520254954, 41.056321825299946, 38.18306105477469, 41.881896359579905, 42.28784138815743, 46.702702454158235, 47.25267669132778, 48.94952753611973, 47.013168811798096, 44.48656061717442, 41.07036413465227, 47.09446620941162, 49.30032123838152, 47.57669203622, 41.34705529894148, 34.98451689311436, 37.22616556712559, 33.801061494009836, 36.08412143162319, 38.43322399684361, 37.955462387629915, 34.756713254111155, 35.013376235961914, 40.86350236620222, 43.91929578781128, 44.14788109915597, 44.07093327386038, 46.7570721081325, 46.61559288842337, 46.353041308266775, 40.1783196585519, 45.56905174255371, 50.34656708581107, 47.985704694475444, 47.22689887455532, 38.450184549604145, 39.391582080296104, 37.97121047973633, 36.355274881635395, 37.861189229147776, 35.67210367747715, 34.89524643761771, 37.08011443274361, 37.3607417515346, 36.528868675231934, 35.952977657318115, 42.08651385988508, 45.92339250019619, 47.32633107049124, 48.26967757088797, 49.21116195406233, 47.88826663153512, 47.4127562386649, 49.57430955341884, 48.98170811789376, 47.12489584514073, 42.32531302315848, 42.327831745147705, 43.868886607033865, 43.23403317587716, 41.472234044756206, 39.590109484536306, 39.83376891272408, 40.7831186567034, 44.60129622050694, 46.125164713178364, 47.09828424453735, 50.483811378479004, 50.360852582114084, 50.740456989833284, 52.92706550870623, 50.12639604296003, 50.501418113708496, 46.12944827760969, 42.14661577769688, 31.571158749716624, 18.97105744906834, 8.867959805897303, 7.374385459082467, 8.987862263407026, 12.0710836989539, 12.145702140671865, 11.442524467195783, 8.249233143670217, 2.3607247301510403, 0.6471693845731872, 0.2691851013473102, 3.793439371245248, 23.769783905574254, 46.64638383047921, 42.82835565294538, 43.63604204995291, 47.01264769690377, 61.81894275120327, 33.48476559775216, 4.790225335529872, 0.47660945675202776, 0.1714308818003961, 0.08128114669982876, 0.06833703270448105, 0.10071512923708983, 0.06440049143774168, 0.16459017672709056, 0.1362461405141013, 0.07529167059276785, 0.13795994355210237, 0.15501483982162817, 0.1783551009637969, 0.14092288884733403, 0.12496909206467015, 0.16892598835485323, 0.11245581387941327, 0.10360635338085038, 0.10719686214412961, 0.09727060728307281, 0.1243031235145671, 0.09216304349579982], [0.0027842388912436684, 0.02556817659309932, 0.0818883337612663, 0.04498508379661611, 0.02186483593790659, 0.02908643494759287, 0.042595649869846444, 0.007484052962224398, 0.046908167390418906, 0.05494540111560907, 0.03056932912607278, 0.011116558802314103, 0.07721974141895771, 0.0254737296075161, 0.05080273448090468, 0.0682162738272122, 0.04226989199274352, 0.049644766974129846, 0.0301335569737213, 0.04632917345900621, 0.007966568543841797, 0.010729429977280753, 0.02148497337475419, 0.04638752068525978, 0.04483162292412349, 3.4032606737954274, 21.645858560289653, 38.00154284068516, 37.2632863180978, 29.575326919555664, 28.597687585013254, 33.73856592178345, 30.851572036743164, 20.321731669562205, 4.4097172277314325, 0.14383669463651522, 0.02154631124410246, 0.7115522612418447, 1.167611986398697, 1.7353813201189041, 3.9963471804346358, 3.970500750201089, 7.566206983157566, 8.682119812284197, 19.26704897199358, 38.41089596067156, 47.407611097608296, 49.697150230407715, 45.689408438546316, 42.70281212670462, 39.52448374884469, 36.074505124773296, 36.82097789219448, 36.93465042114258, 39.95624828338623, 39.66354499544416, 37.72010605675833, 33.461037499564036, 31.81491892678397, 34.67429372242519, 34.29492902755737, 35.28801073346819, 36.291233335222515, 39.742181232997346, 41.51993342808315, 44.66603258677891, 46.37921517235892, 44.98971094403948, 44.36179528917585, 44.587924412318635, 47.12670585087368, 45.744691780635286, 42.83500507899693, 36.56769173485892, 31.091924122401647, 32.921409130096436, 32.115647384098594, 31.59373344693865, 33.458900928497314, 34.62115042550223, 33.30921588625227, 33.09387731552124, 34.42436701910836, 36.63434927804129, 40.68880033493042, 40.52028220040457, 43.5126177242824, 43.52682679040091, 45.66209159578596, 35.683217321123394, 43.56667818341936, 48.123473576136995, 43.19444581440517, 44.54281670706612, 39.33662182944161, 35.258147375924246, 32.423139912741526, 33.221995149339946, 32.02998651776995, 32.921760014125276, 33.5129405430385, 35.499385356903076, 32.62926517214094, 34.07221494402204, 35.48728854315621, 39.424752780369346, 45.30609021868025, 45.16290174211775, 47.44210890361241, 46.887034688677105, 44.97748906271798, 46.33722373417446, 47.06247322899954, 46.293589047023225, 43.22381932394845, 37.41216884340559, 34.22015598842076, 33.780814443315776, 33.906618527003694, 32.6788718359811, 35.962479318891255, 35.86276919501168, 35.278245040348594, 34.9486711365836, 38.24287462234497, 40.65010234287807, 42.81060995374407, 44.985271045139854, 45.60385874339512, 46.8506886618478, 48.04210669653756, 50.21775095803397, 48.033108779362266, 41.12097133908953, 26.96855562073844, 15.944852931158882, 7.814271569252014, 3.298045188188553, 5.278367987700871, 3.711850583553314, 6.212998407227652, 8.881388936723981, 3.2474729418754578, 0.6508256026676723, 0.2638771933104311, 0.048357348556497266, 3.6994093997137885, 16.845388105937413, 34.92088181631905, 28.887347561972483, 29.414806161608013, 46.95120130266462, 44.012881074632915, 17.274864946092876, 1.2558471603052956, 0.11528601736894675, 0.023149167021204318, 0.024684084479564, 0.05339630227535963, 0.019580154247315865, 0.028320485958829522, 0.004402351740282029, 0.03979502032910075, 0.06217386520334652, 0.023711535148322582, 0.041381625192505975, 0.04786006720470531, 0.011101715000612395, 0.021546243390600597, 0.05250523991084524, 0.09699474208589111, 0.08891070301511458, 0.030275886479232992, 0.028016714312668358, 0.026805047544517686, 0.017142674952213253, 0.01791087837357606, 0.03389070036688021, 0.0018258681853434869, 0.04215490405580827, 0.014697407771434103, 0.008500201561089073, 0.025904193919684206, 0.03340741379984787, 0.018642038871933306, 0.07105008033769471, 0.07492900719600064, 0.06011101696640253, 0.04284361031438623, 0.06587664437081132, 0.028346183776323284, 0.06756206428898232, 0.03259706996115191, 0.013936672476120293, 0.044341221917420626, 0.054005107642816644, 0.026041432716218487, 0.017345146409102848, 0.029589684014873843, 0.10162928554096393, 0.03641111869364977, 4.526632394109454, 26.281166860035487, 44.51434646333967, 43.16253968647548, 33.83817877088274, 28.569893053599767, 36.38449553080967, 34.163986751011436, 21.39016832624163, 4.487755485943385, 0.2188440861978701, 0.04325401882774063, 1.0785543194838931, 2.0610332914761136, 3.68533148084368, 5.451378566878183, 8.401573266301837, 4.492486340659005, 6.521629137652261, 19.8926682472229, 39.86600855418614, 48.682893889290945, 52.2293586730957, 47.64970370701381, 46.44359370640346, 40.374762603214805, 38.30028411320278, 38.2033428464617, 38.73784344536917, 41.24185609817505, 41.56187275477818, 38.66024596350533, 34.848064695085796, 34.53699731826782, 35.79823432649885, 35.971140248434885, 36.69062621252877, 37.54269422803606, 40.40099205289568, 43.46276787349156, 44.99982752118792, 47.56372322354998, 46.484883376530235, 44.222612449101035, 43.71259730202811, 48.0585218157087, 48.145339557102744, 43.93071515219552, 37.24837895802089, 33.31123086384365, 33.1705367905753, 33.34434945242745, 33.11433628627232, 34.58663524900164, 35.47951003483364, 34.754698276519775, 34.19023357118879, 36.07664516993931, 39.718289852142334, 42.06154203414917, 43.135167258126394, 45.487591062273296, 46.01401785441807, 45.53459562574114, 37.60121890476772, 44.9101436478751, 49.24932493482317, 45.19240379333496, 45.995594705854145, 39.19588259288243, 36.188664027622764, 32.99868699482509, 35.2289753641401, 34.39871426991054, 34.90602656773159, 35.00354453495571, 36.38628816604614, 34.57920067650931, 34.45529692513602, 36.19084923607962, 40.78979240145002, 46.34676708493914, 47.63670015335083, 48.56739745821272, 49.047931398664204, 45.13866989953177, 46.96275268282209, 47.78668744223458, 47.44628824506487, 45.694466727120535, 38.62958356312343, 34.76787553514753, 35.93085806710379, 35.76045002256121, 34.38724626813616, 37.20480680465698, 37.87820536749703, 36.4123751776559, 38.28301089150565, 40.254993030003135, 42.72177028656006, 45.00449671064104, 47.36525140489851, 47.72271190370832, 48.685398714882986, 50.70072371619088, 51.94570541381836, 48.785324232918875, 41.847930090767996, 28.039839301790508, 17.311765091759817, 5.49594691821507, 5.892363360949925, 6.277310064860752, 5.028974558625903, 6.136473119258881, 7.978592123304095, 6.304957815579005, 1.372039714029857, 0.3475664540060929, 0.1648118405469826, 3.5540298521518707, 21.133416754858835, 37.5491213117327, 32.26141364233834, 34.4157304082598, 52.36527238573347, 50.46847670418875, 21.080997807638987, 1.689123579433986, 0.1347182017884084, 0.018496947728895714, 0.03605667914130858, 0.02944646562848772, 0.036745789128222635, 0.04091059296791043, 0.07757316995412111, 0.005663480318617076, 0.03678524933223214, 0.04328152663739664, 0.02025965108935322, 0.06952330190688372, 0.01946376683190465, 0.010350267153366335, 0.025298274022393992, 0.04433492511244757, 0.08543268178722688, 0.009188890008122792, 0.06303115348730769, 0.0071559999404209, 0.045048645564488, 0.04849630235029118, 0.09447556547820568, 0.12631523768816674, 0.10839470715395041, 0.09394163305738143, 0.09846187050321273, 0.11168782080390624, 0.08441578849617924, 0.0879545725349869, 0.19711230588810785, 0.14795834704169206, 0.22007755429616996, 0.14989027194678783, 0.13776456617883273, 0.1402789048318352, 0.14008985140493938, 0.10690577062112944, 0.12202442650284086, 0.12872909887560777, 0.07598839034991604, 0.08067895365612847, 0.14339412695595197, 0.09936169614749295, 0.14184155740908214, 0.15289557139788354, 4.8821912578174045, 29.17763982500349, 50.118996211460654, 48.53363616125924, 40.54825217383248, 38.961144651685444, 43.18236289705549, 41.02164684023176, 26.47681771005903, 6.567158511706761, 0.47190503776073456, 0.597899925495897, 2.801200568675995, 5.032485135963984, 7.805771316800799, 10.550708413124084, 9.987629873411995, 14.994382790156774, 12.308679086821419, 23.219078370503016, 44.167415959494456, 50.40246534347534, 54.300376960209434, 51.45605543681553, 46.84660312107631, 42.15068047387259, 39.42762238638741, 39.78175469807216, 41.622197014944895, 44.60259553364345, 44.84587281090872, 42.14777612686157, 37.32977710451399, 35.986214365277974, 37.18738072259085, 38.56103263582502, 39.387572969709126, 39.308561529432026, 43.482479912894114, 45.13405976976667, 47.092701366969514, 49.095241682870046, 47.92322996684483, 44.97128084727696, 44.07155861173357, 49.705460275922505, 49.047698634011404, 46.32509217943464, 39.029480184827534, 34.06227554593767, 34.876232692173545, 35.18791845866612, 35.46330336162022, 36.324007987976074, 37.826139041355674, 35.01124661309378, 36.58867876870291, 37.392665249960764, 40.66850464684622, 43.68630184446062, 45.496311051504954, 47.251360007694785, 47.592283793858115, 47.18702663694109, 39.658966132572715, 47.109047004154746, 50.81527171816145, 47.87731279645647, 49.11439439228603, 41.63150760105678, 38.88771608897618, 34.44431529726301, 36.798917361668174, 35.137227875845774, 35.86857788903372, 36.639661175864084, 38.74741111482893, 36.28438588551113, 36.757037094661165, 37.94409166063581, 41.83619805744716, 48.10439382280622, 50.487636361803325, 51.517362867082866, 49.53796352658953, 45.305746282849995, 47.66181789125715, 49.689861570085796, 49.33014290673392, 47.94327899387905, 40.27162701742989, 35.80374077388218, 37.89057316098894, 37.79818296432495, 37.14651836667742, 40.241068840026855, 39.48644583565848, 38.377165930611746, 39.33338049479893, 42.412700516836985, 44.38787187848772, 45.75841447285244, 49.6834032194955, 50.9606488772801, 52.056345054081504, 52.21978405543736, 53.69162443705967, 50.10698972429548, 44.307849475315635, 29.95984717777797, 22.100654636110576, 10.932430284363882, 6.8519686460494995, 11.473880818911962, 10.589257887431554, 13.020591514451162, 18.09405061176845, 8.747546655791146, 3.1767930431025366, 0.8089844073568071, 0.3033499095056738, 4.966413847037724, 24.290886640548706, 45.168929304395405, 40.47390644890921, 44.33898087910244, 60.7647134235927, 55.901863779340474, 25.91712815420968, 3.138918629714421, 0.19141983134405954, 0.10215945887778487, 0.1706256778644664, 0.1785017323813268, 0.13221619890204497, 0.05947759095579386, 0.18947524497551577, 0.16425579466990062, 0.08483636485678808, 0.1408894235002143, 0.23722797472562107, 0.20061651856771537, 0.12048147858253547, 0.0654526414083583, 0.09678432837660823, 0.19563491802130425, 0.19258452313286917, 0.14625469488756998, 0.20349109146211827, 0.08808460698596068, 0.08878163208386727], [0.054871345803673775, 0.03216295682692102, 0.06710751367998974, 0.04849422264045902, 0.02474916786221521, 0.04663814777242286, 0.05809996809278216, 0.05870511954916375, 0.006607307262519109, 0.003708017457808767, 0.022755129861512353, 0.02999963451709066, 0.06294789724051952, 0.03659383460347142, 0.04266372389559235, 0.009521573183259793, 0.038546939979174306, 0.017421405263511196, 0.042917628306895494, 0.03156907244452408, 0.0314661997503468, 0.01332824963278004, 0.026137226593813727, 0.05603200709447265, 0.07160512198294912, 1.3692641258239746, 13.070361460958209, 34.975327900477815, 46.58641740253994, 36.96326657703945, 32.47653681891305, 30.449205330439977, 39.44559390204293, 25.997817584446498, 6.578389406204224, 0.6474462811435971, 0.13178763618426664, 0.3431216153715338, 0.9559587836265564, 1.7211854990039552, 2.1160612872668674, 6.711211170469012, 1.9298493478979384, 5.072164995329721, 21.29660562106541, 36.011992182050435, 47.636533396584646, 46.70126417704991, 44.960601466042654, 40.734321457999094, 40.96014486040388, 40.98214980534145, 43.915269306727815, 43.062311921800884, 45.23400960649763, 42.643543992723735, 45.21990128925869, 41.28549773352486, 33.7530529158456, 33.15856157030378, 33.50482504708426, 34.60765354973929, 37.21895333698818, 41.27681595938546, 42.99079758780343, 42.79049491882324, 44.62259939738682, 43.67099496296474, 43.2461508342198, 45.93649680273873, 45.226509026118684, 44.19672346115112, 41.057391847882954, 34.72394207545689, 32.46063586643764, 32.09810318265642, 32.57320710590908, 32.285968576158794, 31.713721888405935, 33.07199396405901, 33.45780658721924, 32.88825580051967, 33.44487598964146, 35.12202174322945, 40.12238318579537, 40.83065823146275, 44.29345628193447, 43.672686849321636, 45.60123927252633, 30.257709503173828, 39.62455517905099, 46.01659563609532, 42.5362777028765, 43.80944129398891, 43.05206332887922, 43.09128243582589, 39.89041757583618, 35.09448255811419, 31.602109500340053, 33.17551864896502, 32.114896978650776, 32.069834436689106, 31.970600264413015, 33.89695358276367, 36.7205034664699, 44.62221377236502, 43.91437646320888, 46.74077163423811, 47.20811441966465, 48.460711342947825, 46.22234221867153, 46.92501354217529, 46.97693395614624, 46.104684897831504, 44.069682598114014, 38.1790588923863, 33.202991826193674, 32.88166543415615, 35.44180563517979, 41.49389852796282, 42.17482198987688, 42.951005254473, 41.877522468566895, 41.29240771702358, 38.34517295019967, 38.47013630185808, 37.71193150111607, 42.67255967003958, 42.796373094831196, 44.17528479439871, 46.10836396898542, 47.32436473029, 47.57500014986311, 41.122614588056294, 27.79422742979867, 16.828990357262747, 4.237944730690547, 5.302464774676731, 3.3956658584730963, 1.8276085598128182, 2.3035019721303667, 6.36095986195973, 6.11906875031335, 0.36499633586832453, 0.17932109055774553, 0.30722114177686827, 3.949125051498413, 21.138617481504166, 41.3512659072876, 39.473098346165244, 29.791308198656353, 49.63246944972447, 37.01255014964512, 15.499770436968122, 0.95796485883849, 0.10341252985277347, 0.06920198164880276, 0.010491686573784267, 0.01624791117917214, 0.023961317459387437, 0.038247750140726566, 0.04000680467912129, 0.03880414207066808, 0.03197424266753452, 0.028625272014843564, 0.02724612075170236, 0.04279453866183758, 0.013303936874893094, 0.039851718715259006, 0.007121225020715168, 0.018746502730729322, 0.03345399522887809, 0.026746255877826895, 0.0042517343536019325, 0.024233379467789615, 0.02038981785465564, 0.04514180163719824, 0.060862229870898385, 0.019647743120523434, 0.04331620656219976, 0.039387882354536226, 0.03466934983485511, 0.019701778256733502, 0.10181712439017636, 0.0743654974337135, 0.030780370480247905, 0.05344731453806162, 0.05424968219761338, 0.029075710701623132, 0.04716913535126618, 0.038603899601314745, 0.014152842706867626, 0.04155194426753691, 0.045252619976443906, 0.042544016747602394, 0.07646351414067404, 0.07138436739998204, 0.04711709510801094, 0.04414562062759485, 0.04551589834902968, 0.07117409618305308, 2.0293581911495755, 17.02332626070295, 40.79322828565325, 50.235757214682444, 40.943823541913716, 33.52667018345424, 33.75797571454729, 41.507589953286306, 29.005371400288173, 7.328001890863691, 0.657557158597878, 0.12596033673201287, 0.89390936174563, 2.246087921517236, 3.4863166170460835, 6.28173519883837, 9.410807796886989, 4.089693622929709, 5.644542396068573, 23.151006868907384, 37.85288960593087, 49.70311178479876, 48.470657689230784, 45.99581357410976, 41.352120535714285, 41.33605630057198, 42.89779942376273, 44.737081391470774, 45.90104014532906, 46.74757392065865, 45.607079233442036, 47.31634303501674, 40.33786072049822, 35.69976098196847, 35.37888969693865, 35.416118144989014, 36.6993670463562, 38.71805844988142, 42.899178641183035, 46.46978146689278, 45.04166609900338, 45.884767464229036, 44.643013204847065, 42.531723158700125, 46.428564752851216, 47.52227374485561, 45.811818327222554, 44.05801657267979, 37.13775321415493, 34.06130279813494, 34.70686687741961, 34.7494523865836, 33.21769421441214, 33.46224996021816, 34.45627662113735, 35.72696317945208, 35.34553139550345, 35.88943638120379, 36.5531074660165, 42.15815673555647, 42.167158126831055, 46.607783113207134, 44.654425621032715, 47.48301989691598, 33.04774822507586, 43.286262784685405, 47.15186875207083, 43.39889308384487, 44.60991893495832, 44.59163127626692, 43.19492871420724, 40.2013703073774, 36.47007301875523, 33.36902250562395, 34.62979398454939, 33.28454283305577, 34.233472211020334, 33.44240590504238, 34.737487588609966, 37.32164076396397, 46.39355625425066, 45.55701051439558, 48.359232902526855, 48.67597695759365, 48.53084993362427, 46.40089702606201, 47.673765318734304, 49.27546058382307, 48.08449418204171, 45.374912125723704, 39.5743579183306, 34.61882277897426, 34.21942295346941, 37.645169734954834, 41.94476366043091, 43.822479588644846, 44.426684515816824, 43.71079077039446, 41.835204465048655, 39.40916102273123, 40.864072118486675, 40.680288791656494, 45.17783342088972, 44.85912649972098, 46.173708302634104, 48.39810807364327, 48.84138229915074, 49.50662020274571, 43.328872612544465, 30.008963993617467, 16.566042729786464, 6.069641002586909, 4.617123995508466, 5.791309629167829, 6.824148058891296, 3.9552051595279147, 6.764084356171744, 5.437727962221418, 1.2604463249444962, 0.20109901124877588, 0.3805798968034131, 4.534125592027392, 24.428009339741298, 43.492151805332725, 40.13088083267212, 34.736045837402344, 56.7638955116272, 44.54708637510027, 19.486850023269653, 1.4557623586484363, 0.16946390377623693, 0.0033773226023186, 0.015257324690797498, 0.021141919640025923, 0.04117185269881572, 0.018878291194726313, 0.03448045586368867, 0.02411429487567927, 0.017625695194250772, 0.04222492886973279, 0.028732884276126112, 0.05940196822796549, 0.012290083420728999, 0.04671023194012897, 0.04258342606148549, 0.025044641025098305, 0.0403541535405176, 0.050054534271891625, 0.043555369800222773, 0.034389623773417304, 0.026514393676604544, 0.1333086131406682, 0.10751660820096731, 0.11574420492563929, 0.1421960648149252, 0.07117076457611152, 0.07338606606104545, 0.12243194106434073, 0.15432524468217576, 0.1674074541245188, 0.11446725630334445, 0.11564676729696137, 0.11904818192124367, 0.11171367977346693, 0.16468004190496036, 0.11051536657448326, 0.0781368018527116, 0.08435693236866168, 0.15718437411955424, 0.1157892325094768, 0.21436328520732267, 0.13860917942864553, 0.1154934319534472, 0.17423936538398266, 0.09777643478342465, 0.21242160296865872, 2.1094748292650496, 18.419514656066895, 46.08700868061611, 57.15307106290545, 47.14801597595215, 41.914705753326416, 40.246780259268625, 49.608876841408865, 34.932787554604666, 9.482177087238856, 1.1545858510902949, 0.370288501892771, 1.8379351028374262, 4.16307007414954, 7.206266845975604, 10.046233585902623, 13.47468842778887, 5.194824584892817, 6.880118838378361, 24.644544737679617, 39.58407844815935, 51.66935818535941, 50.77225194658552, 47.88784973961966, 43.597180775233674, 43.70439147949219, 45.80834770202637, 48.49636949811663, 47.67177813393729, 49.24983562741961, 46.544043813432964, 48.84738901683262, 44.955379894801546, 37.319629260471885, 36.81462376458304, 37.06011404309954, 38.11589976719448, 40.32190418243408, 44.741257258823936, 47.90392787115914, 47.77840518951416, 47.9771340915135, 44.04780966894967, 42.771074703761506, 48.51378863198416, 49.04756661823818, 48.840155942099436, 44.59368446895054, 39.910477025168284, 37.10716724395752, 35.634451389312744, 35.57183769771031, 35.74241597311837, 34.18990353175572, 36.48143332345145, 37.12006310054234, 37.15456090654646, 37.377153396606445, 38.55399758475167, 43.98895147868565, 43.76547656740461, 47.40113190242222, 46.8439176423209, 49.67367574146816, 37.22859743663243, 43.95990106037685, 48.46612746374947, 45.11046021325247, 46.1927741595677, 47.951335430145264, 46.42498295647757, 44.83060067040579, 38.42209645680019, 35.21902901785714, 36.67534017562866, 34.810784135546, 36.34648193631853, 34.52476154054914, 36.900388853890554, 39.978777817317415, 49.309524127415244, 47.62302957262312, 50.10443278721401, 50.46019097736904, 48.62199987683977, 47.12182126726423, 48.58597346714565, 51.007337297712056, 49.715587275368826, 48.6515679359436, 40.91664218902588, 37.7200539452689, 35.30784784044538, 39.27275398799351, 45.85160371235439, 47.615515095846995, 46.71962479182652, 46.76196711403983, 45.50974539348057, 43.331172466278076, 41.25788559232439, 41.86961889266968, 46.359464917864116, 46.13572250093733, 47.35710116795131, 51.155677863529746, 51.44147464207241, 51.68184062412807, 45.57769182750157, 33.52884496961321, 19.609836612428936, 7.702631388391767, 11.966637509209768, 11.69251023020063, 11.869982855660574, 9.060437066214424, 13.577781455857412, 12.321289198739187, 2.574718390192304, 0.5521085283585957, 0.7885257080197334, 5.565459302493504, 29.234100886753627, 51.731773853302, 51.237534591129844, 42.34555312565395, 64.36069107055664, 52.20790263584682, 23.297137907573156, 2.158634202820914, 0.3714943400451115, 0.16591587130512508, 0.12989076439823422, 0.09171605176691498, 0.07002645597926208, 0.1534172019788197, 0.1554898821881839, 0.184196676792843, 0.07909507650349822, 0.13366131564336164, 0.1477407001491104, 0.1432027800806931, 0.14532255062035151, 0.20000294649175235, 0.156134748299207, 0.10199080221354961, 0.20120566338300705, 0.09500723837741784, 0.16119223620210374, 0.13437710223453386, 0.08752974175981112], [0.04731310012617281, 0.021291940339973996, 0.048076418095401356, 0.05809264669993094, 0.029437749846173183, 0.10727671893047434, 0.0481015985299434, 0.048860770650207996, 0.07365061329411608, 0.09177496217723403, 0.044304044983748875, 0.012285241225202168, 0.06728607695549726, 0.028112121425302963, 0.022706282125519853, 0.03674306820279785, 0.034761627204716206, 0.047152087158922634, 0.0475955471130354, 0.02465030361366059, 0.019752583566254804, 0.004291291672935975, 0.02437233835059617, 0.021084585127287676, 0.0365535262306886, 0.31140523297446115, 8.474946243422371, 27.543393986565725, 42.36316680908203, 36.889070238385884, 36.725693770817344, 29.91969701222011, 31.467679228101456, 31.41350759778704, 11.221544827733721, 1.238115357501166, 0.0959862151316234, 0.8550517782568932, 0.973589186157499, 2.6880793358598436, 5.790315168244498, 10.526989000184194, 2.8421649762562344, 7.381919911929539, 22.80575782912118, 33.456298828125, 47.07361119134085, 48.74457304818289, 45.077449321746826, 42.31058979034424, 43.35066563742501, 45.74919768742153, 43.672909191676546, 45.14425277709961, 46.331988266536165, 46.56196321759905, 45.992634773254395, 45.22506727491106, 35.87564768110003, 31.931777204786027, 32.84884214401245, 36.546621322631836, 41.22689315250942, 44.23989609309605, 44.557626792362754, 46.22140768596104, 46.38166093826294, 42.6869980267116, 46.33260318211147, 47.12667110988072, 44.58194201333182, 43.16873747961861, 36.20244925362723, 32.40522050857544, 32.70792920248849, 31.7077533858163, 32.47658198220389, 33.344731603349956, 32.54033865247454, 32.19215052468436, 33.88715314865112, 32.2273223059518, 32.50322137560163, 32.24006877626692, 38.79786545889718, 41.21406330381121, 44.548729624067036, 44.71420097351074, 47.89010443006243, 33.97031613758632, 38.38468040738787, 47.846855367933, 44.617568901606965, 46.75998340334211, 43.636028153555735, 44.01480572564261, 42.01954712186541, 42.3365204674857, 34.08895662852696, 33.478366306849885, 34.26574659347534, 31.954998084477015, 34.02262912477766, 34.06451633998326, 37.95506634031023, 43.81497553416661, 45.47669281278338, 45.95082746233259, 46.96637269428798, 45.39580535888672, 43.61859859739031, 49.22369997841971, 47.284145082746235, 46.7222512108939, 44.668506145477295, 37.17078147615705, 32.1374751499721, 36.46228061403547, 42.7584741456168, 46.22193227495466, 46.86791672025408, 47.25698110035488, 44.430947235652376, 45.00624418258667, 43.91590159279959, 42.9682228905814, 40.420870849064414, 40.87255239486694, 40.82126079286848, 42.69273376464844, 44.6021716935294, 47.513154234204976, 46.31709132875715, 41.10321521759033, 26.12593194416591, 14.074955463409424, 3.851956231253488, 4.3707782200404575, 4.523675935609, 4.951469574655805, 3.1495752121720995, 4.508127169949668, 4.324231803417206, 1.2805787303618021, 0.19094560321952614, 0.130253957052316, 5.790000762258257, 23.780002968651907, 34.95285395213536, 38.40115111214774, 42.20534195218767, 43.370454107012065, 38.52858107430594, 11.454576986176626, 0.5514999638710703, 0.04534014081582427, 0.06239858243082251, 0.0347665974737278, 0.009389572677069476, 0.023972302941339355, 0.056233314863805256, 0.06016565939145429, 0.014750986592844129, 0.06848399660417012, 0.04755995116595711, 0.01858711994386145, 0.019706611122403826, 0.013844481619474078, 0.04260727656739099, 0.02538602047466806, 0.05358234979212284, 0.025707101549154947, 0.021447645467040793, 0.05846639057355268, 0.020518400240689516, 0.054848876116531234, 0.05072120510573898, 0.07461538152503115, 0.03369383021656956, 0.06051790049033506, 0.04809077250372086, 0.05712297944618123, 0.024687853741592596, 0.026781868788280656, 0.061835004815033505, 0.02203141967765987, 0.019753586101744856, 0.02221240701952151, 0.08239334701959576, 0.009907194812382971, 0.05679101975900786, 0.010028046140048121, 0.03047056156875832, 0.03366793053490775, 0.02838602565628077, 0.01617140805215708, 0.027714964700862765, 0.012871563334816268, 0.0945847010506051, 0.04142740595021418, 0.04344760486856103, 0.6354124354464668, 11.3564293384552, 33.3836658341544, 50.00529588971819, 40.962000029427664, 40.98686415808541, 33.7246139390128, 36.06745270320347, 34.07784993307931, 12.732118810926165, 1.2196945973805018, 0.12429070632372584, 0.4192090854048729, 2.1286442577838898, 4.777357706001826, 5.306866892746516, 7.941020607948303, 2.454231632607324, 7.15740624495915, 24.090391159057617, 35.68800115585327, 48.68330730710711, 50.75375584193638, 46.78106076376778, 44.02117722375052, 46.1112231527056, 48.50018753324236, 45.88966941833496, 47.66262040819441, 47.71654190335955, 49.767577171325684, 47.91323150907244, 46.2358078275408, 36.898384298597065, 32.43600797653198, 34.57269368852888, 37.75999913896833, 42.8088972227914, 44.940872056143625, 46.29788998195103, 47.25760643822806, 47.298513957432334, 43.20821366991316, 47.168294293539866, 48.43722990580967, 46.46906232833862, 44.436273029872346, 38.30647495814732, 33.99799428667341, 33.83007369722639, 33.044864722660606, 34.32994100025722, 34.65543283735003, 34.02844476699829, 34.97578648158482, 35.06869431904384, 34.33200461523873, 34.670652866363525, 34.56656190327236, 40.76611988885062, 42.546825068337576, 46.15556308201381, 46.60898167746407, 48.88596888950893, 38.08246503557478, 40.40533815111433, 48.74586541312081, 47.232624190194265, 47.91400970731463, 46.16797603879656, 46.35373960222517, 44.38837562288557, 43.81329754420689, 34.18116617202759, 36.19933646065848, 35.14878967830113, 32.73546838760376, 35.38678632463728, 35.00167546953474, 37.68586880820138, 45.22041198185512, 48.16459648949759, 48.396509987967356, 46.99351235798427, 46.15712990079607, 45.03367567062378, 49.474957261766704, 47.96659367425101, 48.29864461081368, 46.1035349709647, 39.2905205317906, 34.53328698022025, 36.194945199149, 44.5454500743321, 47.64954389844622, 47.97879818507603, 48.47401714324951, 45.63076564243862, 47.75611189433506, 45.94852760859898, 44.08415569577898, 42.85295922415597, 42.41055352347237, 42.14669220788138, 45.127278327941895, 47.26208107812064, 48.46786451339722, 48.44874654497419, 41.511380195617676, 28.800048657826014, 14.967387301581246, 4.97062315259661, 3.1345123861517226, 5.212882953030722, 5.8532050507409235, 5.184482191290174, 3.9154562524386813, 3.5105195811816623, 1.4126429238489695, 0.052997574742351256, 0.27345639786549975, 6.141758961336953, 26.363516909735544, 41.53973231996809, 45.34851591927664, 46.19098499843052, 51.09155988693237, 43.44624505724226, 14.94062978880746, 0.7663955869419234, 0.029179781010108333, 0.045302828175148795, 0.026893123086275797, 0.011596428097358771, 0.02994068678734558, 0.0772165319483195, 0.03852232951404793, 0.0226847471203655, 0.043808989226818085, 0.027779790240206888, 0.03586418214919312, 0.019757893102775727, 0.06648097479982035, 0.09514601914478199, 0.034998184868267605, 0.02765556744166783, 0.016768323789749826, 0.013179734432404595, 0.10686699234481369, 0.016525828944785253, 0.03980879119730421, 0.16657958711896623, 0.16149662701146944, 0.10346500096576554, 0.12139644234308175, 0.13610377029648849, 0.16636044744934353, 0.16148772463202477, 0.2150780539959669, 0.12790598161518574, 0.16579612344503403, 0.1376537342688867, 0.10976935803358044, 0.14174170419573784, 0.07102604662733418, 0.16551827692559787, 0.1280381330954177, 0.11427889498216764, 0.08945466418351446, 0.11590530270976679, 0.0959105109795928, 0.13412126739110264, 0.1447885978434767, 0.1601763471428837, 0.13549067319503852, 0.12413008351411138, 0.7534072324633598, 11.774267945970808, 38.062026909419465, 54.50541830062866, 49.04884508677891, 46.87679304395403, 41.00213977268764, 41.98028285162789, 39.96075766427176, 15.863942895616804, 2.398205484662737, 0.4452718054609639, 2.8442068781171526, 3.783130415848323, 9.010048730032784, 13.646428789411273, 19.69531856264387, 7.276078002793448, 10.156091553824288, 26.939312389918737, 35.78963245664324, 51.49824142456055, 52.16152688435146, 49.305813789367676, 45.70059156417847, 47.82699394226074, 50.407012939453125, 46.35572678702218, 49.609161717551096, 50.37318563461304, 52.0279859815325, 50.07147748129708, 49.837319714682444, 38.83929409299578, 34.65940373284476, 35.9582895551409, 39.84165164402553, 46.66258702959333, 47.8343312399728, 48.404448304857524, 49.41221850258963, 47.434295654296875, 43.86512068339756, 48.13562944957188, 50.693466322762625, 48.57937267848423, 45.836446217128206, 40.45469120570591, 36.00264685494559, 35.546452454158235, 35.53003733498709, 35.81538595472063, 36.67327308654785, 36.10500771658761, 36.20935576302664, 37.149189949035645, 36.47882774897984, 37.10294621331351, 36.341482707432334, 42.08007982798985, 46.3417261668614, 48.670237745557515, 49.74068416867937, 49.79532480239868, 40.961041178022114, 42.02119731903076, 49.42739336831229, 48.66743762152535, 49.414049352918354, 47.17063931056431, 48.45910630907331, 46.28062718255179, 47.16043240683419, 37.22384834289551, 37.00181518282209, 37.61254446847098, 34.943842138562886, 38.28086042404175, 37.78465829576765, 41.002862385341096, 46.36293206896101, 49.799066407339915, 50.00892979758126, 48.245688915252686, 46.02000720160348, 45.07755701882498, 50.18484428950718, 50.349850109645296, 49.86066913604736, 47.98773356846401, 40.65642867769514, 36.402755396706716, 39.51692410877773, 46.598368304116384, 47.91620881216866, 50.33112471444266, 51.122757298605784, 47.70970140184675, 49.4342998777117, 48.654065813337056, 47.38682556152344, 44.761229855673655, 44.177035740443635, 45.12194905962263, 46.998119013650076, 48.31437880652291, 50.01072243281773, 49.8143698147365, 44.44670227595738, 29.69626031603132, 17.172299112592423, 6.128589953695025, 8.168731314795357, 9.942857418741498, 10.037335549082075, 11.394674829074315, 11.078888756888253, 9.003778849329267, 4.091212238584246, 0.6863880029746464, 0.542253702878952, 7.703017013413565, 30.84063904626029, 47.12800516401018, 50.978154863630024, 52.12609107153756, 57.537101473127095, 50.260763781411306, 18.411359207970754, 1.1346812163080489, 0.0824420726192849, 0.11003706723983799, 0.10760646659348692, 0.05761440164808716, 0.10361117776483297, 0.14343067285205635, 0.12027592318398611, 0.13397627802831785, 0.1142146105745009, 0.1587538527590888, 0.2006296142935753, 0.06839008735758917, 0.17791277755584034, 0.20511725491711072, 0.2158361268895013, 0.1307315235691411, 0.11719830547060285, 0.16397735103964806, 0.18574797069387777, 0.12064664757677487, 0.11840015383703367], [0.023021671987537826, 0.012854336178861558, 0.07201887906662055, 0.03886811774490135, 0.04177886334114841, 0.029712997576487914, 0.0340067773525204, 0.004227539915258863, 0.09792757845882859, 0.038659329126988135, 0.0681356502962964, 0.056838225440255234, 0.025896326306142976, 0.011911409142028009, 0.010033889174727457, 0.053167232245739014, 0.022167644064341272, 0.023052618273400834, 0.024016813142225146, 0.03359951384897743, 0.021625067107379436, 0.007605862720603389, 0.12243052971150194, 0.045746922559503994, 0.033304395220641575, 0.027864956563072543, 4.077473044395447, 19.673039163861954, 39.35504150390625, 41.675989968436106, 33.95694432939802, 28.30065209524972, 34.98797014781407, 29.353832244873047, 14.028643114226204, 2.4537839080606187, 0.11604043974408082, 0.2688694197152342, 1.7959840510572707, 3.11947192464556, 3.7153199059622626, 6.361973430429186, 1.2967564165592194, 5.138502487114497, 17.450345175606863, 33.283778531210764, 46.058208397456575, 48.65067161832537, 47.54286820547921, 47.78219543184553, 46.23091976983206, 48.6661765234811, 47.177615301949636, 46.742449624197825, 44.82635532106672, 42.91219956534249, 45.32092809677124, 43.74571589061192, 37.20766598837716, 32.72362518310547, 33.67967993872506, 38.45745236533028, 44.43380641937256, 43.46408803122384, 47.436154297419954, 44.576887198856895, 43.40941613061087, 44.39146409715925, 45.89787524087088, 43.2672073500497, 42.70089789799282, 36.86344180788313, 32.55576712744576, 32.107264382498606, 33.443687847682405, 32.13143369129726, 32.27171434674944, 32.408381938934326, 36.042578152247835, 36.2764892578125, 35.948304993765696, 33.47109849112374, 33.71995864595686, 32.93550355093819, 34.23646341051374, 39.262321267809185, 44.06820958001273, 42.349096706935335, 47.3586436680385, 36.354003361293245, 39.821811062949045, 44.63109704426357, 42.560328892299104, 43.818043163844514, 45.9518175806318, 48.13255139759609, 45.698104109082905, 44.973320143563406, 41.23565830503191, 33.12370940617153, 33.20254366738455, 32.93972110748291, 33.14467906951904, 34.16650547300066, 35.713806765420095, 44.74406085695539, 46.09801810128348, 46.45812586375645, 46.22761590140206, 45.62429339545113, 46.727920940944124, 46.854062012263704, 44.85523203441075, 44.63124990463257, 41.037711075374055, 35.11785977227347, 32.621740273066926, 36.322955335889546, 44.44539948872158, 49.01563269751412, 46.571836607796804, 45.4773667880467, 47.837603841509136, 46.79781287057059, 45.979367188044954, 46.37339605603899, 45.10271297182356, 44.34147528239659, 45.15903506960188, 43.51123850686209, 45.85910776683262, 48.35031141553606, 48.61242525918143, 38.877536978040425, 29.06451620374407, 13.483991197177343, 5.504018987928118, 1.0399084389209747, 3.199931412935257, 4.090759302888598, 1.3047913568360465, 2.415786381278719, 1.8138784851346696, 0.7964585423469543, 0.04623697412067226, 0.618309770311628, 6.823556159223829, 26.850448404039653, 37.66774443217686, 31.570429188864573, 36.15929399217878, 44.823579515729634, 33.18419000080654, 7.539536322866168, 0.07385917460279805, 0.04342110129073262, 0.03899454917492611, 0.04529672475265605, 0.05942214785942009, 0.07934028548853737, 0.006752286871363009, 0.031865429399268966, 0.0019013755622186831, 0.03771494408803327, 0.03062010050884315, 0.027399968389155607, 0.033455104633633576, 0.030202255251684358, 0.03172095911577344, 0.010326412406616976, 0.09504743479192257, 0.0660002055977072, 0.06559558838073697, 0.022305951553529928, 0.039499844025288305, 0.043432293725865226, 0.03969484481162258, 0.05098251572677067, 0.06308033370545932, 0.01721236389130354, 0.07625811480517898, 0.03755877925349133, 0.035872823292655606, 0.01850955999855484, 0.021441416515569602, 0.029004997174654688, 0.05476584717897432, 0.019224376284650395, 0.027070127427577972, 0.01275742017397923, 0.010144728718192449, 0.12986716495028564, 0.013468513847328722, 0.04612020842198815, 0.01023863033125443, 0.041957908376519165, 0.014200737949327698, 0.04189270794657724, 0.03415666234546474, 0.017918572960687534, 0.02980068465694785, 0.09817329634513174, 5.607606640883854, 24.315389462879725, 46.591593810490195, 46.75098896026611, 38.814464705330984, 31.63353967666626, 39.52726650238037, 35.36910663332258, 15.737400565828596, 2.8324500918388367, 0.160769698875291, 0.3559672332235745, 1.7057513786213738, 3.139492941754205, 5.418507073606763, 5.717564054897853, 1.7541110579456602, 6.506923275334494, 19.52349829673767, 35.454322814941406, 48.58376741409302, 50.031032017299104, 47.08450596673148, 48.11346469606672, 47.83116980961391, 50.0920649937221, 48.552962575639995, 47.91880743844168, 46.271962778908865, 46.323980467660085, 46.04277992248535, 45.694383348737446, 39.206047807421, 33.78192962918963, 34.47786814825875, 39.501572063991, 46.307019914899556, 46.040431431361604, 49.46774503162929, 46.12977484294346, 42.67152786254883, 46.29196664265224, 47.49375833783831, 44.783071517944336, 45.131857190813335, 38.896265847342356, 33.532725538526265, 33.89864894321987, 34.261153834206716, 33.02499982288906, 34.30333634785244, 34.32072421482631, 37.71449886049543, 36.75966351372855, 37.84280776977539, 34.079830169677734, 35.36820684160505, 34.976460456848145, 36.14363275255476, 40.856293610164094, 45.672180380140034, 44.667853014809744, 48.80277115958077, 37.93781396320888, 40.555116994040354, 44.063637665339876, 43.88666704722813, 47.10929366520473, 48.53913566044399, 49.266393184661865, 47.21188381740025, 45.86851562772478, 42.46260595321655, 33.904843262263704, 35.14659404754639, 33.88844551358904, 34.496617862156455, 34.159571170806885, 37.718942233494346, 46.97871616908482, 47.616852624075754, 47.269883905138286, 47.732213565281455, 46.714733260018484, 46.57157605034964, 49.61378921781267, 47.508745602199006, 46.47379057747977, 42.60113218852452, 37.43860673904419, 34.65348734174456, 39.454199245997835, 46.84311165128435, 49.994769368852886, 47.45888532911028, 46.71060255595616, 49.54777090890067, 49.647043296269004, 47.638718605041504, 49.05703353881836, 46.39688791547503, 45.50093855176653, 47.38225017275129, 45.86740044185093, 47.501748766217915, 49.207336970738, 50.006689003535676, 42.86743927001953, 28.12530561855861, 14.663634640829903, 5.997812696865626, 3.7476533481052945, 6.6933668937001904, 6.917841911315918, 5.220183338437762, 3.8386048333985463, 2.5188005907194952, 1.339736127427646, 0.04814052947663835, 0.5629606917500496, 8.203397614615303, 29.182791914258683, 40.8466842515128, 37.447187764304026, 42.193835735321045, 51.32764230455671, 39.57610886437552, 10.260490843227931, 0.2819049188068935, 0.030515643435397317, 0.010804715133937342, 0.05292045245213168, 0.019877345800133686, 0.07467528938182763, 0.036320323922804425, 0.07165082131645509, 0.002723784389672801, 0.019428243827340857, 0.029474146464573484, 0.05108304408245853, 0.030860379936971834, 0.024873253257412995, 0.06100432188915355, 0.01797269461011248, 0.07787098575915609, 0.02257972855919174, 0.086420011307512, 0.014259739113705499, 0.03023030928203038, 0.0178829210344702, 0.14220119453966618, 0.21585390450698988, 0.1899922750890255, 0.09926783439836331, 0.1417234923158373, 0.09690389981759445, 0.10661186996315207, 0.10730867792985269, 0.08348387493086712, 0.1427553269479956, 0.15210806365524018, 0.20892334782651492, 0.10105913292084422, 0.06147809539522443, 0.10817153020096676, 0.32014717959931915, 0.10657406199191298, 0.1754085762160165, 0.0872128251940012, 0.12466562406292983, 0.16934453589575632, 0.14055463432201318, 0.2704968995281628, 0.08509715300585542, 0.18937368185392447, 0.1942836291023663, 5.908930906227656, 27.72819869858878, 53.30435964039394, 54.66096067428589, 46.05407074519566, 38.73214939662388, 43.94067192077637, 40.295528820582796, 19.515038864953176, 3.841981657913753, 0.44421717205217903, 1.0406895684344428, 3.979878212724413, 8.933380569730486, 11.444040043013436, 13.597260730607168, 4.982953599521092, 7.240373381546565, 20.15419496808733, 36.76191125597273, 49.43096821648734, 52.43583134242466, 48.58087348937988, 51.40431915010725, 50.89664207186018, 51.29966538293021, 50.76754454204014, 50.462365763528005, 47.830513204847065, 47.95906182697841, 49.11201810836792, 47.77715451376778, 40.225341592516216, 36.09647185461861, 36.45454379490444, 42.16421903882708, 48.51480654307774, 47.4381171635219, 50.91788966315133, 47.060871669224326, 43.08700234549386, 47.96025344303676, 49.39866256713867, 47.17192472730364, 47.672702244349885, 39.91788380486624, 34.676225321633474, 34.93204409735543, 36.546551840645925, 35.064879758017405, 36.69876255307879, 36.60222775595528, 39.744710377284456, 39.255359172821045, 40.40345866339547, 35.23081316266741, 37.73624324798584, 36.7919031551906, 38.06266266959054, 43.206806659698486, 47.43721737180437, 47.107306480407715, 50.591994830540244, 41.68765251977103, 41.414598737444194, 43.95978988919939, 43.821319239480154, 46.93350076675415, 50.4366956438337, 50.950876235961914, 48.26771123068673, 47.460820402417866, 45.542617321014404, 36.11968578611101, 37.627298968178884, 35.158690861293245, 36.325182233537944, 36.38685097013201, 38.52772644587925, 49.318563733782085, 49.10429865973336, 48.25023651123047, 46.986192430768696, 47.45830168042864, 47.69338008335659, 51.39938940320696, 48.317265783037456, 48.980513027736116, 43.044521059308735, 38.89075245176043, 36.001434394291465, 40.654375485011506, 48.50848020826067, 53.73521048682076, 48.45894650050572, 46.97073268890381, 51.92552784511021, 50.84732723236084, 49.57036992481777, 51.66704790932791, 49.77475118637085, 47.018366064344136, 49.36060380935669, 47.45991366250174, 49.81400156021118, 52.2784720148359, 51.53376061575753, 44.1168851852417, 31.792788914271764, 16.15210553577968, 7.207967417580741, 4.462509206363133, 11.064269747052874, 10.629242164748055, 9.374233348029, 10.7549489736557, 6.002461041722979, 2.5276182889938354, 0.21123734222991125, 1.2326815405062266, 9.03988082068307, 34.85879966190883, 50.040356499808176, 42.17653472082955, 48.852829456329346, 57.99152060917446, 46.93066937582833, 12.753573979650225, 0.48249631800821846, 0.0789318752608129, 0.13775919218148502, 0.07952931177403245, 0.18011664572571004, 0.11703684127756528, 0.06124050635844469, 0.1197449831025941, 0.08426054646926266, 0.07490509562194347, 0.10619588728461947, 0.1407361424395016, 0.19862926591719898, 0.1316013511802469, 0.16817508079111576, 0.06678723158048731, 0.2414126901754311, 0.20017962343990803, 0.13831512949296407, 0.14613884181848594, 0.12828015296586923, 0.20969435359750474], [0.02692423900589347, 0.03237721782975963, 0.02465527897168483, 0.06578620243817568, 0.07139095597501312, 0.03323567319395287, 0.05191742502419012, 0.022658959396981766, 0.01971001736819744, 0.03334827947297266, 0.026998289228816117, 0.06675268057733774, 0.09701736444341284, 0.02251978507930679, 0.04090350566964064, 0.042991429168198786, 0.041298206097313335, 0.07971326261758804, 0.01679215393960476, 0.024596012330480983, 0.012006728045110191, 0.048372700411294184, 0.07713582699320146, 0.027699000468211513, 0.017897819967142174, 0.01919301609242601, 1.5544099509716034, 14.227295586041041, 35.136894362313406, 41.51248843329293, 37.57507978166853, 27.51565330369132, 28.609112160546438, 33.29787990025112, 20.916452305657522, 4.221735451902662, 0.568578798856054, 0.12762457957225187, 1.998011827468872, 2.1416124190602983, 4.130815667765481, 4.124983089310782, 1.8027430198022296, 5.1497954811368665, 15.020761626107351, 31.108054365430558, 43.23928253991263, 50.156342778887065, 48.33292007446289, 49.95888539722988, 48.21563448224749, 47.0537462915693, 45.63122769764492, 44.80691426140921, 48.453815255846294, 47.76065254211426, 46.89707483564104, 42.733908789498464, 34.94810485839844, 34.37680312565395, 35.652363845280235, 42.996644496917725, 45.135810715811594, 48.46045773369925, 46.076662812914165, 41.22332525253296, 46.1884697505406, 45.11537953785488, 43.221057415008545, 42.84612567084176, 37.607215200151714, 33.16987323760986, 33.59656558718, 32.47226367677961, 32.27123839514596, 33.225226061684744, 34.09178107125418, 36.08455221993582, 39.5952650478908, 40.79854713167463, 41.800380093710764, 39.800817080906455, 36.60381194523403, 35.491110052381245, 35.15448720114571, 35.957497460501536, 42.73140048980713, 42.756077017102925, 49.52213205610003, 36.5697831426348, 37.869044167654856, 44.964374337877544, 44.021566322871614, 44.98161629268101, 45.387262548719136, 45.72089420046125, 46.01227733067104, 46.121527331215994, 43.683011872427805, 39.518522194453645, 31.913465227399552, 33.07380396979195, 32.08876827784947, 33.140805448804585, 37.08663879122053, 44.04955019269671, 45.14546176365444, 47.346699714660645, 44.726603507995605, 46.16200406210763, 46.89952060154506, 45.89428302219936, 43.274850368499756, 42.79581029074532, 38.656038829258506, 32.31228835242135, 32.99481337411063, 33.62290620803833, 44.76207753590175, 47.489596366882324, 45.687264919281006, 44.55959660666329, 46.71555314745222, 48.88024704796927, 47.7012072290693, 46.185627937316895, 47.68018198013306, 48.57189294270107, 45.83452156611851, 47.3797800881522, 49.859460149492534, 50.538695199149, 48.02267953327724, 37.920478207724436, 24.52396396228245, 12.321365628923688, 3.702033647469112, 4.0506556034088135, 4.339361505849021, 5.381987341812678, 4.3599815879549295, 1.1961610487529208, 1.4091569909027644, 0.7513842753001622, 0.18601475709250995, 0.8738543093204498, 8.79535460472107, 32.95007739748274, 42.81138815198626, 29.871563366481237, 32.82882785797119, 46.649451460157124, 26.446162257875713, 5.324732882635934, 0.21970403433910438, 0.0820172554148095, 0.06307238806039095, 0.02034998276004834, 0.054938809147902896, 0.03172344255394169, 0.05480101904166596, 0.03421148458229644, 0.09736904914357833, 0.04766405540119324, 0.04007442747907979, 0.053891090010958057, 0.017127005882295113, 0.03771425198231425, 0.019660606448139464, 0.07137965836695262, 0.0710721802232521, 0.013642958415273045, 0.12630372973425047, 0.02134528337046504, 0.047979567399514575, 0.06360558766339507, 0.07324310551796641, 0.03912171342277101, 0.11299577169120312, 0.02831197712969567, 0.06637352199426719, 0.03637808760894196, 0.03634607771943722, 0.010321035016594189, 0.02298863242114229, 0.05836490209081343, 0.04075872665271163, 0.03828798387465732, 0.03710906999185681, 0.02183608471282891, 0.010669108214122909, 0.044154723174870014, 0.023625753054927503, 0.03439005803582924, 0.03918046098468559, 0.04141453753358551, 0.025490075516115342, 0.064460575713643, 0.011930453075495149, 0.09719906933605671, 0.03618233025606189, 0.025354088616690466, 2.407532572746277, 18.772028037479945, 40.90298897879464, 47.86689397266933, 41.255606583186555, 31.30436529432024, 34.40541580745152, 36.51421839850289, 24.461550031389507, 5.149130625384195, 0.3343755161123616, 0.04863155473555837, 1.4014498101813453, 2.217395769698279, 4.3284797583307535, 3.954483849661691, 2.542831586939948, 5.7005466137613565, 17.157004390444072, 32.870180061885286, 45.81797790527344, 51.18155990328108, 49.39888143539429, 49.90843105316162, 50.387220995766775, 47.817151818956646, 46.582265853881836, 44.94091721943447, 48.943194253104075, 49.08961016791207, 48.78276382173811, 45.61199508394514, 36.65487425667899, 35.46661417824881, 37.63235378265381, 44.5835713659014, 47.1194623538426, 49.21991321018764, 46.73684590203421, 42.0987982749939, 46.1583388873509, 47.487067222595215, 45.02332285472325, 45.71815313611712, 41.447828497205464, 34.34571688515799, 34.3095827783857, 33.66532843453543, 33.347774914332796, 34.14747783115932, 35.40360443932669, 37.36553948266165, 40.600471360342844, 42.94027028764997, 43.635204792022705, 41.24211318152291, 38.185593673161094, 35.63097381591797, 36.25761795043945, 37.71986286980765, 44.490364755902974, 44.53781400408064, 51.227418013981406, 39.61445597239903, 38.93937941959926, 44.3499937738691, 43.74017122813633, 44.46514279501778, 45.47370508738926, 47.62879310335432, 47.0691956111363, 46.74314096995762, 45.76130839756557, 39.87570823941912, 32.689561639513286, 34.75948905944824, 34.64175878252302, 34.65610333851406, 39.13415479660034, 47.52142606462751, 46.47596536363874, 48.36792857306344, 45.376541478293284, 47.181412492479595, 48.124307359967915, 47.96881709780012, 46.46949659075056, 45.15068333489554, 40.8437625340053, 33.91981315612793, 34.654651165008545, 35.2584878376552, 47.54314613342285, 48.780582087380544, 46.461860520499094, 46.01585565294538, 47.67227840423584, 48.78822857992989, 48.915675912584575, 47.649276392800466, 50.40494237627302, 50.06364686148507, 46.71469851902553, 49.15570490700858, 50.34486477715628, 52.161495617457796, 49.49658005578177, 40.401666028159006, 26.677547693252563, 14.28586368901389, 3.399323650768825, 2.978501660483224, 7.676566089902606, 6.192539436476571, 4.965535334178379, 3.0809463347707475, 2.5959242922919135, 0.5108021391289574, 0.08926474223179476, 1.0063853349004472, 9.451124719211034, 35.058046204703196, 45.97077226638794, 34.16795417240688, 40.11813088825771, 55.65530347824097, 31.635863849094935, 6.309807658195496, 0.20115797594189644, 0.09384351010833468, 0.03178084322384425, 0.06808674149215221, 0.02562236100701349, 0.02999728000057595, 0.0208762562168496, 0.006988124015541481, 0.017390552276213254, 0.019731462467461824, 0.07698516507766076, 0.046983606913792234, 0.025229711451434662, 0.02936599137527602, 0.024401143858475343, 0.0405644552915224, 0.07252586007650409, 0.021093607946698154, 0.01829053567988532, 0.01961491389998368, 0.05348457968128579, 0.03962901673678841, 0.09949620214423963, 0.11150400566735438, 0.16225426564259188, 0.11662312490599495, 0.1470538191497326, 0.1717748176306486, 0.11655375148568835, 0.07880426996520587, 0.0926572476912822, 0.1305289672953742, 0.1035474565412317, 0.2175970066870962, 0.19825547454612596, 0.11331876793078013, 0.11507184457566057, 0.17544745627258504, 0.10349575217281069, 0.14952250596668037, 0.15740949846804142, 0.1410470607557467, 0.14165045480643, 0.1497862118163279, 0.13421554304659367, 0.14011056029370852, 0.12202297443790094, 0.08711723996592419, 2.8098780001912798, 21.32627269199916, 49.05425773348127, 55.55969973972866, 48.16146632603237, 36.96934625080654, 38.2816664150783, 43.36803960800171, 28.293700422559464, 6.536371478012629, 1.10111294899668, 0.33008915611675804, 5.432089064802442, 6.382112784045083, 10.730402725083486, 9.552233168057032, 4.15078261920384, 7.114636608532496, 17.359714610236033, 35.71644360678536, 46.277549130576, 52.809866768973215, 50.13106870651245, 51.87937443596976, 50.36370134353638, 49.174499784197124, 45.998175961630686, 46.34736810411726, 50.51673541750227, 52.182048388889854, 52.53253984451294, 48.16948454720633, 37.685670784541536, 38.53811400277274, 40.52089711597988, 47.464669704437256, 49.75531012671334, 51.285855838230674, 49.256547587258474, 43.55187504632132, 47.18353169304984, 49.928174359457834, 48.175293241228374, 47.23123107637678, 41.15512520926339, 36.274418694632395, 36.27231339045933, 36.45601333890642, 35.129185335976736, 36.38428361075265, 37.4089344569615, 39.95732178006853, 43.07847343172346, 44.76114647729056, 44.62313788277762, 44.31751094545637, 40.16468729291643, 38.270740372794016, 38.1694530078343, 40.547835281917024, 45.825881481170654, 47.18211078643799, 52.44177900041853, 42.17305019923619, 40.57953643798828, 44.02943515777588, 44.07360485621861, 44.54759359359741, 44.01296445301601, 47.74095092500959, 47.76958097730364, 49.379207611083984, 47.48491675513131, 43.66123274394444, 34.24844557898385, 37.144843850817, 36.09490156173706, 36.59088829585484, 41.78848477772304, 47.84788370132446, 48.03852142606463, 49.1379314150129, 45.21749721254621, 46.987133911677766, 48.48942824772426, 48.89534200940813, 47.295762470790315, 46.82279164450509, 42.75473254067557, 34.872459820338655, 36.62294033595494, 37.23757103511265, 48.20785249982561, 50.498732634953086, 47.774559361594065, 45.07764039720808, 47.900624002729145, 49.378109795706614, 50.32929386411394, 48.86778545379639, 51.389693192073274, 53.38165487561907, 48.816657134464805, 51.43204246248518, 53.05129582541329, 54.232326303209575, 51.10423340116228, 41.8948860168457, 27.114028317587717, 15.408292191369192, 5.990679068224771, 7.032760339123862, 10.657398002488272, 11.83056833062853, 12.255426355770656, 9.414492079189845, 6.229067853518894, 3.073888267789568, 0.4429742858878204, 1.477173666868891, 11.321314011301313, 38.983260767800466, 53.46449129922049, 40.609570026397705, 45.46520744051252, 62.68312495095389, 37.15263625553676, 7.52174893447331, 0.44855024239846636, 0.20281521630074295, 0.11969113456351416, 0.16559880546161107, 0.10658703558146954, 0.1215936653316021, 0.08563457309667553, 0.09766869020781346, 0.1327918137290648, 0.22303661837109498, 0.21048400551080704, 0.16192390051271233, 0.11221946656171765, 0.14457123593560287, 0.11367409636399575, 0.15920946188271046, 0.2866486114050661, 0.09477021252470356, 0.2400059513747692, 0.05603921652904578, 0.15275938941964082, 0.13322668682251657], [0.013264938074696277, 0.03423738765663334, 0.03363944563482489, 0.03781414930043476, 0.014660520911482828, 0.028706903170262064, 0.05256973805704287, 0.05077173900125282, 0.03750005204762731, 0.042063179691987376, 0.03723625120307718, 0.04107926659552114, 0.030757758300751448, 0.0180675928214831, 0.016485513786652257, 0.0171735754369625, 0.016511866390439014, 0.03695348191208073, 0.04508472327142954, 0.04658483188333256, 0.020405904223610247, 0.0610425505521042, 0.06175494446818318, 0.03992956703794854, 0.03741440735757351, 0.04708811827003956, 0.5217849069408008, 7.840309074946812, 30.34746285847255, 46.0681860106332, 39.21441343852452, 35.12895951952253, 37.9763035093035, 31.91023084095546, 21.007350376674108, 8.277676463127136, 0.4285867107766015, 0.08058387732931546, 0.7532153427600861, 1.0647867896727152, 3.776446683066232, 2.6448875963687897, 3.0966164767742157, 2.886660371507917, 12.347551652363368, 29.4016740662711, 44.92711462293352, 47.740756375449045, 49.0093480518886, 48.328601769038606, 45.4528500693185, 45.445717743464876, 50.178986958095, 47.96818481172834, 46.20662539345877, 45.20649821417672, 42.779186725616455, 36.12437582015991, 32.857447487967356, 33.74612903594971, 38.996114935193745, 44.33362034388951, 44.49008682795933, 47.96604129246303, 42.77829735619681, 44.65092025484358, 44.36635330745152, 43.30772229603359, 41.53358663831438, 37.085322107587544, 33.85388517379761, 33.16949108668736, 33.57733992167881, 32.5083943094526, 32.94396645682198, 31.710477079663956, 33.46580048969814, 37.83569976261684, 43.00738641193935, 43.670835154397146, 44.12274251665388, 41.891585622514995, 40.91407830374581, 41.17830787386213, 39.15972416741507, 40.61276619774954, 43.658985001700266, 41.98668909072876, 47.38626970563616, 34.30635534014021, 41.42830058506557, 45.94716576167515, 41.37472997392927, 46.918232100350515, 46.73915270396641, 45.59470796585083, 45.0989852632795, 47.95025845936367, 46.463086877550396, 38.60814837047032, 31.40258502960205, 31.81644753047398, 31.540795121874126, 32.91788291931152, 37.0241744858878, 45.423782280513215, 45.21729918888637, 46.7214104788644, 44.16987909589495, 44.9576484816415, 48.47489956447056, 44.74415118353707, 43.77604825156075, 39.82020255497524, 37.005101680755615, 34.10374934332711, 30.755065032414027, 31.66575152533395, 38.85087326594761, 45.192490645817344, 46.85532658440726, 47.471339975084575, 47.27531392233712, 45.80203873770577, 46.09018748147147, 47.93427412850516, 46.72940438134329, 46.44114446640015, 48.51043265206473, 49.169528348105295, 50.569340229034424, 49.20154912131173, 43.67393752506801, 35.91611746379307, 20.299000637871877, 9.743097577776227, 3.4881392163889746, 2.8257259726524353, 6.925949590546744, 5.0271784492901395, 1.7805151896817344, 1.8109886859144484, 1.4875519956861223, 0.21453840152493545, 0.16414456920964376, 1.2234386993306023, 13.100447160857064, 28.660601786204747, 40.46476261956351, 37.550208704812185, 32.14243963786534, 44.131844656808035, 23.073060240064347, 3.4521564500672475, 0.2674294598400593, 0.061969320821974955, 0.017262494058481286, 0.039567846804857254, 0.04097231590588178, 0.07857782247343234, 0.045384276126112254, 0.027966648606317382, 0.027647733754877533, 0.07276560006929295, 0.04449850972741842, 0.04898600446592484, 0.02273299265652895, 0.008256269070053739, 0.012603625122989928, 0.04389877298048564, 0.04172231762536934, 0.022974707186222076, 0.029588001248027598, 0.05589586922100612, 0.05453761514010174, 0.024776282121560404, 0.029905219761920825, 0.01289210089349321, 0.04749802127480507, 0.023637284757569432, 0.010877795051783323, 0.03997078804033143, 0.044641195463814905, 0.04074415511318615, 0.0858252075101648, 0.008239341317676008, 0.02521337741719825, 0.056417567655444145, 0.0401483199426106, 0.02106088220274874, 0.007797872015674199, 0.006954380469064095, 0.02707395775775824, 0.04337026205446039, 0.019960276350112896, 0.07563602711473193, 0.03561449483303087, 0.033777751427675994, 0.13237912873072283, 0.024563983781263232, 0.02340497981224741, 0.03319936817778008, 0.7083494131054197, 10.674864036696297, 35.420234952654155, 52.62441240038191, 44.801908084324424, 36.31867871965681, 38.176550592694966, 40.40414653505598, 24.646000385284424, 8.32130593912942, 0.7199168066893304, 0.1574800389685801, 0.9920645547764642, 2.603416621685028, 4.111459289278303, 4.485403954982758, 2.955381529671805, 4.685484281608036, 14.990484850747244, 30.229934079306467, 46.27738584790911, 49.978114536830354, 49.5195438521249, 47.85945592607771, 45.981392587934224, 45.28457859584263, 50.137982164110454, 48.18222406932286, 48.21826090131487, 46.37825632095337, 44.812594413757324, 38.50174365724836, 34.5319390296936, 34.57485805238996, 39.594653606414795, 45.867824281964985, 47.83638443265642, 48.76322896139962, 43.62410504477364, 44.68131167548043, 46.840172563280376, 46.58948155811855, 43.814100061144146, 40.11982972281319, 36.584506375449045, 34.125406878335134, 35.49920817783901, 33.66471699305943, 34.31542273930141, 33.53125252042498, 35.026386737823486, 39.41726262228829, 45.06350776127407, 44.284277711595806, 45.08349772862026, 43.580939361027305, 42.5109897341047, 41.737610067640034, 39.58628102711269, 41.343306745801655, 43.16354717527117, 44.83020462308611, 48.38210637228829, 36.687912940979004, 42.37975215911865, 46.01219047818865, 42.61165176119123, 47.3787830216544, 46.765559332711355, 46.92441599709647, 46.35911055973598, 49.494648456573486, 47.680557182856965, 40.68492324011666, 32.91071237836565, 33.65931476865496, 33.39444943836757, 34.29509231022426, 37.80230672018868, 46.902873107365195, 46.90580177307129, 48.35569279534476, 42.85015910012381, 45.99572672162737, 49.12506682532174, 47.101612431662424, 45.68947097233364, 41.927893434252056, 38.4667421068464, 34.94585016795567, 33.21894489015852, 33.19097491673061, 42.56666217531477, 46.69184589385986, 49.430092743464876, 48.73542921883719, 49.12205825533186, 47.497889041900635, 48.494128704071045, 49.45831980024065, 47.246506690979004, 48.80042266845703, 49.61396639687674, 50.18149178368704, 51.50454691478184, 50.34764405659267, 46.69386434555054, 37.38089500154768, 21.90835976600647, 11.061523471559797, 5.097327896526881, 4.165953142302377, 6.304480561188289, 6.895222919327872, 6.471835740974971, 3.6110921502113342, 1.6666145644017627, 0.44875621848872727, 0.14005156845918723, 1.4030021897384097, 13.933451925005231, 34.51922730037144, 46.86545010975429, 38.54105656487601, 38.281364168439595, 49.87530551637922, 28.79609339577811, 4.124373819146838, 0.2027825109128441, 0.045576257431613545, 0.05368388916498848, 0.0407160196586379, 0.017534196443323578, 0.04102131970492857, 0.007557950514767851, 0.040674700268677304, 0.017080794254850065, 0.046976316055016856, 0.04025929434491055, 0.05237540223502687, 0.026402991797242845, 0.020935085202966417, 0.01729974054199244, 0.05133996118924447, 0.028637580640081848, 0.03885459454197969, 0.009504008456133306, 0.09001547337642737, 0.02933274655203734, 0.04739795432292989, 0.08508159419787781, 0.08506279877786126, 0.19327979082507746, 0.11730098138962473, 0.11674010434320994, 0.12506570188062532, 0.12583047870014394, 0.18349309026130609, 0.15790754317172936, 0.09439403271036488, 0.12740358071667807, 0.21337921944047722, 0.1278574120785509, 0.09645960187273366, 0.17085860536566802, 0.1235435985560928, 0.08485815940158707, 0.16197470921490872, 0.11688833710338388, 0.21198667559240544, 0.22779948636889458, 0.19241997839084693, 0.23765290049569948, 0.17627836311502115, 0.10182661030973707, 0.17148737662604877, 0.8076607212424278, 11.337954078401838, 40.69295883178711, 60.92569623674665, 49.950262682778494, 44.872380188533235, 47.67891393389021, 43.16626392092024, 29.10154836518424, 11.481996314866201, 0.85697974051748, 0.5190859660506248, 2.1502889820507596, 4.772014107022967, 9.636294211660113, 7.8574007749557495, 6.05629003899438, 3.855154573917389, 15.942994288035802, 31.598864691598074, 47.35761880874634, 51.780859402247835, 49.482065268925254, 48.67813784735543, 46.15555960791451, 45.39378343309675, 52.350569997514995, 50.928906032017295, 50.15246915817261, 48.432188987731934, 46.899503231048584, 40.44741644178118, 35.17858007975987, 36.590533937726704, 42.738855906895225, 47.91786595753261, 48.62033230917794, 50.38355234691075, 44.235063620976035, 45.17608594894409, 47.993886198316304, 47.754089968545095, 45.222572871616904, 39.873123509543284, 38.50654486247471, 36.78641755240304, 35.91312973839896, 34.7856525012425, 36.640911851610454, 35.32924829210554, 36.28745698928833, 40.48927933829171, 46.17987135478428, 46.5619284766061, 45.779790605817524, 45.20862088884626, 44.70911489214216, 44.7584227834429, 41.74305050713675, 43.77242824009487, 45.46882397787911, 46.67666060583932, 50.54727969850813, 40.71221923828125, 44.63761445454189, 45.792061124529155, 43.304571287972585, 47.24209805897304, 48.56347867420742, 47.34685952322823, 45.736784730638774, 51.016964026859824, 50.474017892565044, 42.4159175327846, 34.83870547158377, 35.213084833962576, 36.36705207824707, 35.219539710453574, 40.52238055637905, 48.570267064230784, 49.57373980113438, 48.63091788973127, 43.55661719185965, 45.46733358928135, 49.24603843688965, 47.76765980039324, 47.20789902550833, 44.430433068956646, 40.9881009374346, 36.51458665302822, 34.22804914202009, 35.05829633985247, 43.4944794518607, 48.496042932782856, 50.570208753858296, 50.39149413790022, 50.08986241476876, 47.47856957571847, 47.489818709237234, 50.481153692517964, 48.400487831660676, 49.78758798326765, 48.829573835645405, 51.02596194403512, 53.00072683606829, 52.39330836704799, 47.133897236415315, 38.29999228886196, 23.296877350125992, 11.675347311156136, 4.917692644255502, 6.940690193857465, 12.819563627243042, 12.344867042132787, 12.73624517236437, 6.772546827793121, 4.408591619559696, 1.4120964046035493, 0.3986803341124739, 2.071315105472292, 15.787903547286987, 37.161366667066304, 48.15587650026594, 48.80963945388794, 45.20062698636736, 57.238554750170024, 33.13134200232369, 5.590286953108651, 0.3536221076335226, 0.1788665670901537, 0.13786284519093378, 0.10682730483157293, 0.11039260601890938, 0.1708659471145698, 0.11473168140011174, 0.10376016369887761, 0.0732456228828856, 0.19476123633129255, 0.19585150639925683, 0.11353719513863325, 0.08865251365516867, 0.08503195936126368, 0.0844674182257482, 0.12136828313980784, 0.13823610730469227, 0.1073477276201759, 0.14972172384815557, 0.144541950364198, 0.1704653264688594, 0.1545578736279692], [0.048653542662837675, 0.011190977130484368, 0.03069944160857371, 0.028376415904079164, 0.026457783499998704, 0.053442724248660464, 0.043469294240432124, 0.05178413360512682, 0.08586894587746688, 0.05778940261474677, 0.03231640073603817, 0.0402885900943407, 0.0293828699338649, 0.025936068102185215, 0.024249214778787324, 0.01392198134479778, 0.01874918124771544, 0.10879143979400396, 0.0375357022775071, 0.02949819035295929, 0.10194601890231882, 0.04007998468088252, 0.007535207717280302, 0.10048364023012774, 0.047167245631239245, 0.06244276184588671, 0.09880039840936661, 3.6170328600066046, 22.3061580317361, 40.37213271004813, 40.336387702396934, 40.71660702569144, 28.157213483537944, 32.883541447775706, 38.19217014312744, 12.39536394391741, 1.4993614362818855, 0.16293623404843466, 0.567336374095508, 0.921132349542209, 2.187612750700542, 2.8104827105998993, 1.7479297667741776, 4.265508668763297, 14.811730282647268, 25.02078969138009, 39.133143833705354, 48.89231954302107, 48.51492118835449, 45.18006031853812, 45.47326387677874, 46.282673427036826, 48.22355195454189, 44.44932174682617, 44.691838196345735, 41.77792351586478, 37.50481612341744, 33.244615009852815, 33.816281523023335, 32.47947938101632, 41.02944619315011, 44.49903610774449, 48.56182152884347, 45.114896638052805, 43.68271309988839, 46.550561223711284, 44.87174442836216, 43.30665227345058, 40.55754886354719, 34.39151593617031, 33.67504549026489, 32.19477694375174, 32.626267024448936, 32.54374326978411, 32.32252304894583, 34.42284536361694, 33.85559443065098, 39.60058389391218, 45.429941858564106, 46.496229784829275, 47.05316959108625, 43.85976709638323, 45.469977378845215, 42.405960764203755, 46.84961516516549, 44.14561251231602, 46.85452406747, 41.9120272227696, 51.08497299466814, 36.29169539042881, 37.50777953011649, 46.35836015428816, 43.202971254076274, 46.22936684744698, 46.748675210135325, 46.402759143284385, 45.61467361450195, 44.442231110164094, 43.38236679349627, 38.59991128104073, 31.720319202968053, 32.84431191853115, 32.63327775682722, 33.03817708151681, 38.620203495025635, 44.62141820362636, 45.4956579208374, 47.23776585715157, 43.85870054789952, 45.54518468039376, 45.016982623508994, 46.71591097967965, 43.45483997889927, 42.558015142168315, 37.27424015317644, 33.91772174835205, 31.969769954681396, 31.653838838849747, 32.40039151055472, 41.1950113432748, 42.67852469852993, 44.478386061532156, 47.1442083631243, 46.16317135947091, 47.1515873500279, 45.34258215767996, 46.95145838601248, 45.50723014559065, 44.49054888316563, 44.75030728748867, 47.2501996585301, 47.72215952192034, 41.88583598818098, 32.288525513240266, 18.740236554827007, 6.819944398743766, 2.2134066351822446, 1.8012327636991228, 6.476408524172647, 5.209469650472913, 3.3203221985272, 2.194451080901282, 1.6190369916813714, 0.2540655769407749, 0.06740076294434921, 2.2642068692616055, 10.64598732335227, 28.273910215922765, 34.94840710503714, 34.197129658290315, 41.22312722887312, 43.581265926361084, 18.51711252757481, 1.062130515064512, 0.04649237130901643, 0.07665401963250977, 0.03731341759807297, 0.010160352835165603, 0.012953634689828115, 0.07096665445715189, 0.030140372857983624, 0.020198274204241376, 0.00914376149220126, 0.018923011741467884, 0.07581162519220795, 0.022588179712849002, 0.06314739332135234, 0.0010846894354991882, 0.026441890513524413, 0.05552664099793349, 0.023067864955269864, 0.02256719092838466, 0.08048665004649333, 0.01048358147298651, 0.03292382528473224, 0.02060103223526052, 0.010857742645644715, 0.04586941170107041, 0.003058161145807909, 0.016196115208523612, 0.042147212861371894, 0.014811764670802014, 0.036525041330605745, 0.0819673016667366, 0.07253831797944647, 0.00841558994060116, 0.024389552784019282, 0.030624304033283676, 0.007709126420585173, 0.014667204481416514, 0.031639124399849346, 0.04623350002137678, 0.020363353292590806, 0.03499384902949844, 0.10349894128739834, 0.03102381866691368, 0.038575974492622275, 0.049497962530170164, 0.0817651796553816, 0.015224826256079333, 0.02228630457206496, 0.05018420231395534, 0.2230128017919404, 5.440358289650508, 30.040185723985942, 48.73005131312779, 45.51834378923689, 44.281626973833355, 35.60325745173863, 34.90980986186436, 37.32632384981428, 13.34051263332367, 1.269999338047845, 0.10178339441439935, 0.3827161421733243, 2.524736523628235, 6.578134059906006, 3.2822232714721133, 2.4413270907742635, 4.01507214137486, 14.07389325754983, 27.703155653817312, 41.46515383039202, 48.73324053628104, 48.97266503742763, 47.823968001774375, 46.50078780310494, 48.15679713657924, 51.98459448133196, 46.930836132594514, 47.32825572150094, 43.95994274956839, 40.19349799837385, 34.25934730257307, 36.23546361923218, 34.28297117778233, 42.38256617954799, 47.143374579293386, 48.40535157067435, 45.540876797267366, 44.36540140424456, 46.90722267968314, 46.817222663334434, 45.12199074881417, 41.08792570659092, 36.15165444782802, 36.415376799447195, 34.46562194824219, 33.97918898718697, 33.33158908571516, 33.97859491620745, 35.676109313964844, 35.31215919767107, 42.204143387930735, 47.73040703364781, 47.96599612917219, 47.30659818649292, 45.847660609654014, 47.545317445482524, 44.52812474114554, 47.833778858184814, 44.51758084978376, 48.04655006953648, 43.84487363270351, 52.40831995010376, 38.92765780857631, 38.19770785740444, 46.38361685616629, 44.74915041242327, 48.512822832380024, 48.1326174054827, 48.2396057673863, 48.222843238285606, 46.6161105292184, 45.99422243663243, 40.21673624856131, 33.423708302634104, 35.44093016215733, 33.662469250815256, 33.82616880961827, 40.82028457096645, 46.22770275388445, 47.48803997039795, 47.91762971878052, 45.35601997375488, 46.7294773374285, 46.878967830113, 48.21130575452532, 45.90829406465803, 42.849870749882285, 38.98508814402989, 35.60937534059797, 33.91332006454468, 32.500271865299766, 35.63675471714565, 43.83928033283779, 45.24385172980172, 46.69658803939819, 48.164610385894775, 47.235650130680625, 48.97900179454258, 47.36567871911185, 49.37316962650844, 46.17673771721976, 47.51988703863961, 46.92650045667376, 49.14864901133946, 49.35480553763253, 44.84057133538382, 33.53248929977417, 19.751291513442993, 8.237763404846191, 3.974989286490849, 2.9709140104906897, 6.279992938041687, 8.248702475002833, 5.536512672901154, 5.068928003311157, 2.4959746726921628, 0.30929197637098177, 0.10713405694280352, 2.7778161891869138, 14.720269407544817, 32.955427510397776, 39.335228715624126, 40.066915716443745, 43.66036421912057, 50.64455795288086, 22.49028182029724, 1.5156036104474748, 0.03876541807715382, 0.0947382195985743, 0.00955218868330121, 0.016234523683254207, 0.02889944426715374, 0.0558146485792739, 0.02391079713457397, 0.06211798105921064, 0.017209078085475733, 0.03261566521333797, 0.024393069291753427, 0.049892361009759564, 0.046621465988989384, 0.029932646147374595, 0.019961991347372532, 0.03953613547076072, 0.05914175683366401, 0.08511189757181065, 0.026998501271009445, 0.014126448542810977, 0.02258816614214863, 0.0245830268665616, 0.15027467560555252, 0.12993280642798968, 0.06308883574924298, 0.08840440732559987, 0.09215954225510359, 0.12873540925128119, 0.07975693313138825, 0.16729576726044926, 0.1431015290852104, 0.09279564847903592, 0.06824457552284002, 0.11402069883687155, 0.19183765963784286, 0.11117702642721788, 0.16308574245444366, 0.12091552386326448, 0.09951598822538342, 0.18115420719342573, 0.1800752415188721, 0.09823834071201937, 0.16613130617354596, 0.17669733134763582, 0.12483677773603372, 0.2002081083399909, 0.20807150139340333, 0.17060868734759943, 0.3840258776077202, 6.411690831184387, 33.3203364780971, 54.88496017456055, 51.89902394158499, 51.428394658224924, 39.27427911758423, 43.43515225819179, 46.40244994844709, 17.003845248903545, 2.1942415492875234, 0.5123799773199218, 1.4028521520750863, 5.8207300390516, 8.217644895826067, 5.224946328571864, 4.791699656418391, 7.0057010139737805, 17.634844166891916, 30.46365758350917, 45.00842591694423, 50.06014149529593, 50.24022143227713, 47.991211141858784, 46.568741185324534, 50.30256414413452, 52.316836493355886, 48.562849862234934, 49.529952253614155, 46.51665054048811, 41.50831951413836, 37.02737760543823, 39.20215334211077, 35.165131841387065, 45.312329701014924, 49.52360507420131, 51.245184557778494, 46.41429315294538, 45.00294378825596, 48.10101352419172, 49.04140356608799, 47.895451068878174, 42.6074481010437, 37.771362917763845, 37.458978857312886, 35.95017753328596, 34.71729612350464, 36.410342829568044, 35.232077734810964, 37.551924909864155, 37.28122656685965, 44.04731634684971, 49.85209853308541, 49.934681347438264, 50.24437298093523, 47.54748180934361, 49.38442918232509, 47.04242420196533, 49.76995692934309, 47.9690637588501, 50.6109425680978, 45.4091910634722, 53.33187450681414, 41.28161369051252, 39.80494431086949, 46.305689334869385, 47.02291366032192, 50.60631506783621, 51.0863869530814, 49.138786043439595, 50.769142627716064, 47.49594007219587, 48.31933287211827, 41.78089039666312, 35.002297333308626, 35.97364854812622, 36.69809900011335, 35.770729882376536, 42.158101149967735, 47.76464428220476, 48.91451208932059, 48.34788302012852, 45.05351972579956, 45.86484350476946, 49.51143183026995, 52.892866475241526, 48.95221996307373, 44.99433844430106, 40.62337957109724, 36.22619472231184, 35.86509336744036, 35.46917806352888, 37.67349059241158, 43.967457226344514, 48.35410860606602, 48.56215156827654, 50.598717212677, 49.35981518881661, 50.84668104989188, 47.63539041791643, 49.66550465992519, 45.94595330102103, 49.35472215924944, 50.54969767161778, 47.95116172518049, 48.95396396092006, 43.68797983442034, 36.482812540871755, 21.012846401759557, 9.517926437514168, 4.256759149687631, 3.8307837673595975, 12.83568171092442, 13.030736752918788, 9.687556283814565, 7.965385334832328, 4.7895009858267645, 0.7934353702834674, 0.3193313090928963, 3.1348852004323686, 15.143359116145543, 37.851746627262656, 45.03578444889614, 44.49680921009609, 53.94065482275826, 55.106781414576936, 26.79554373877389, 2.5561747338090623, 0.15992465136306627, 0.15419449098408222, 0.14915312507322856, 0.1273636014333793, 0.15006575467331068, 0.1657842355115073, 0.15631029887923173, 0.12807189699794563, 0.12559491848306997, 0.17042232091937745, 0.12287843067731176, 0.11093884027962174, 0.11932967895908014, 0.1262232826224395, 0.08635928242334298, 0.11154409351625613, 0.13879281814609254, 0.2528290961469923, 0.09353561805827276, 0.11155899414526564, 0.11054119161729302, 0.11336333411080496], [0.01082130107429943, 0.06910106313547917, 0.03230611075248037, 0.04392436392871397, 0.09570348316005298, 0.01566646434366703, 0.012413004280201026, 0.07303565022136484, 0.05156815930136612, 0.008590990394753004, 0.06913391780108213, 0.03755233995616436, 0.02819517920059817, 0.03767592832446098, 0.027642878836819103, 0.06991016186241593, 0.023564286263925687, 0.02555574583155768, 0.027846888871863484, 0.028352453439895595, 0.02187277140494968, 0.03572505872164454, 0.029343138315847943, 0.029384047192122256, 0.05574877639966352, 0.043873755394348075, 0.04128614513735686, 1.8516126317637307, 20.016238485063823, 41.119501795087544, 43.701181411743164, 34.37127235957554, 35.900567395346506, 61.89547021048409, 42.86568832397461, 18.87744610650199, 2.294883600303105, 0.125239759683609, 0.20097101240285806, 1.450433524591582, 5.415416428021022, 4.193793271269117, 0.06404552941343614, 2.9608310886791775, 8.670222759246826, 24.276536873408727, 38.37874664579119, 47.217171396527974, 40.831023011888774, 47.162093026297434, 50.31826359885079, 47.786906310490195, 44.985708781651084, 42.45223924091884, 39.82636908122471, 36.00889675957816, 32.14513553891863, 33.96671002251761, 33.04336391176496, 34.167519909994944, 43.088638646262034, 45.00757128851754, 45.3503919328962, 47.267326968056814, 43.88233137130737, 46.494763714926584, 44.9724029813494, 42.696239130837576, 37.368999685559956, 35.320094040461946, 32.422184535435264, 32.9511786869594, 32.16176952634539, 37.63962507247925, 34.65652370452881, 36.18987648827689, 33.773574420383994, 39.636155196598594, 44.403748512268066, 43.986064502171104, 44.849399021693635, 47.26063585281372, 45.92194727488926, 44.51804290499006, 44.79901415961129, 48.48978955405099, 45.0657103402274, 44.76361656188965, 36.011742046901155, 27.907505648476736, 42.69138234002249, 46.7144136428833, 45.512416975838796, 45.26884092603411, 42.57036209106445, 43.414794036320274, 42.841390473502024, 41.198926653180806, 37.878010817936485, 33.05589498792376, 32.37924814224243, 30.998026166643413, 32.70240885870797, 32.42563779013497, 37.15323032651629, 46.13183845792498, 47.006324836185996, 45.222051756722585, 42.66182470321655, 45.16733816691807, 46.39305945805141, 46.218788215092246, 42.880269118717735, 43.55783660071236, 41.57605750220162, 36.792778628213064, 32.603268487112864, 34.93756096703665, 31.11790691103254, 34.79995884214129, 37.60314008167812, 41.84472349711827, 41.573799337659565, 47.109595911843435, 41.63492611476353, 48.240818228040425, 45.2085896219526, 50.258533409663606, 35.931170736040386, 46.718172618321006, 46.217999594552175, 45.85960456303188, 39.84226655960083, 28.801648480551584, 17.103084632328578, 6.620525888034275, 3.588877022266388, 3.4424997568130493, 2.743606299161911, 6.14094124521528, 3.556036795888628, 4.650846208844866, 0.6475453472563198, 0.06462123245000839, 0.11962416315717356, 3.0385273652417317, 15.495955875941686, 29.447764941624232, 33.279988288879395, 29.298510687691824, 43.98341376440865, 36.021740504673545, 13.622014556612287, 0.7950559290392059, 0.05410268437117338, 0.03145933636863317, 0.04886978498793074, 0.04446933611429163, 0.056005605296897035, 0.003094656575870301, 0.017217105154746344, 0.05619138818500297, 0.040702835723225556, 0.05451069087056177, 0.0650968990687813, 0.046102386699723344, 0.0073483883669333795, 0.031129096767732074, 0.01547062217390963, 0.050919089665902514, 0.02957230673304626, 0.057678061803536754, 0.06773893122694322, 0.012227872785712992, 0.035265425885362287, 0.029694253046597754, 0.040794990956783295, 0.04335484913151179, 0.02784627310133406, 0.013312430436989027, 0.039236796354608874, 0.055480466689914465, 0.01974832745535033, 0.018912446951227527, 0.02599125505158944, 0.0333342066566859, 0.015600697336984532, 0.023609200193147575, 0.012842077595580901, 0.03634918540982263, 0.010500517707051975, 0.057586473146719594, 0.033977627488119264, 0.042266302542494874, 0.02493342913554183, 0.01750764367170632, 0.015914506212409054, 0.07125182915478945, 0.054215141372489076, 0.04269082797691226, 0.046467000884669166, 0.03395124604659421, 0.02544429136573204, 2.674623280763626, 23.090408154896327, 48.80093336105347, 48.578313078199116, 39.574330125536235, 34.72599179404122, 55.68222427368164, 44.93326377868652, 20.501778602600098, 2.9707715724195753, 0.14369268236415728, 0.04714778185422931, 1.996154704264232, 6.0185695716312955, 5.343119987419673, 2.1566663427012305, 3.1909830016749243, 12.347786154065814, 28.65806916781834, 40.61545862470354, 49.10256855828421, 44.94854634148734, 46.94025788988386, 52.40826783861433, 50.192685331617085, 46.453175272260395, 44.932930265154155, 43.151985372815815, 38.90041739600045, 35.005701950618196, 35.17869125093733, 35.43341221128191, 35.67380946023123, 44.20956373214722, 46.80603953770229, 47.27147504261562, 47.28684793199812, 44.33252600261143, 48.570739541734966, 47.577390330178396, 44.229432106018066, 39.6369959286281, 36.24422877175467, 34.70831905092512, 34.322895526885986, 34.04236200877598, 37.939960956573486, 35.14094516209194, 38.188699517931255, 35.986377647944856, 40.70990548815046, 46.54753875732422, 44.783078466142925, 46.74329035622733, 49.26176221030099, 48.75780241830008, 44.898158005305696, 46.820158277239116, 49.91594205583845, 47.00837108067104, 45.71007585525513, 38.41626344408308, 32.63023097174508, 43.29209579740252, 47.332695620400564, 48.483668191092356, 45.986690589359824, 44.53382226399013, 44.94363396508353, 43.70749037606375, 43.136358874184744, 40.36451053619385, 35.661104679107666, 33.76093912124634, 32.94972651345389, 34.95982646942139, 34.17334597451346, 37.90640115737915, 48.09789030892508, 48.21045807429722, 47.57810946873256, 44.338223525456016, 45.15137120655605, 47.68188428878784, 48.45993661880493, 44.99272298812866, 45.581721782684326, 42.23286029270717, 37.551025118146626, 34.91152606691633, 35.57452665056501, 33.191381386348176, 36.644017696380615, 39.63570008959089, 44.03153698784964, 44.9351293700082, 47.781288691929404, 45.32422501700265, 48.58775915418352, 48.3342923436846, 49.88356345040457, 40.36835289001465, 48.3611228125436, 48.329022135053364, 46.975745814187185, 42.721655641283306, 32.88773468562535, 17.20789647102356, 6.276015528610774, 4.2619828922407965, 3.656262823513576, 6.214518325669425, 10.047925472259521, 6.765638147081647, 4.568618621144976, 2.164156500782285, 0.47061109862157274, 0.08929383781339441, 3.4773308592183247, 16.155299970081874, 34.858372347695486, 35.73119463239397, 34.98612192698887, 49.59327813557216, 42.13417155402047, 15.614193371364049, 1.0096452342612403, 0.04475156257727316, 0.06757178091044937, 0.024804154643788934, 0.019879568002319763, 0.04038371052592993, 0.011368323283802186, 0.018800585364390696, 0.036838110602859936, 0.04678249591961503, 0.01000464177091739, 0.018493332833583866, 0.02991946560463735, 0.04066645946087582, 0.03327299601265362, 0.030893967420394932, 0.013296017523056694, 0.03905114238815648, 0.03137488250753709, 0.1399428535784994, 0.059772305855793614, 0.021568858962772147, 0.062217067527983866, 0.09356429294816085, 0.1619599171515022, 0.09836313008729901, 0.1595106635774885, 0.1566506927566869, 0.12900294203843388, 0.13527153352541582, 0.16213902325502463, 0.10342805473400013, 0.11617734096944332, 0.13313275043453487, 0.13021471058683737, 0.12685829640499183, 0.12425084917673043, 0.08109026122838259, 0.21165968956691877, 0.11668366380035877, 0.1043379023405058, 0.10743466152676515, 0.07712233771703073, 0.09844201656856708, 0.16451769561639853, 0.0882421899586916, 0.14704330185694353, 0.15363049267658166, 0.1503802692251546, 0.19261484007750238, 3.1457827985286713, 27.951494693756104, 58.34726142883301, 56.76008789879935, 46.80199916022164, 45.545566831316265, 68.43942955562046, 50.70031724657331, 24.29388826234, 3.754642801625388, 0.4979872724839619, 0.8236872841204915, 4.441231216703143, 11.265946422304426, 11.115231309618268, 4.414721667766571, 5.094985485076904, 14.927209343229022, 36.77811792918614, 46.01000874383109, 51.48575551169259, 46.04115056991577, 47.85330677032471, 52.802140372140066, 52.39343343462263, 49.03967693873814, 46.48166983468192, 44.54242065974644, 38.954446588243755, 36.262335777282715, 38.0600049836295, 35.85967377253941, 38.33879450389317, 45.35972683770316, 47.821695940835134, 48.704777240753174, 49.39419140134539, 44.777815205710276, 50.18788065229143, 49.515030997140066, 47.349736077444895, 41.214369024549214, 38.12226431710379, 36.072000299181255, 36.1693480355399, 36.61832673209054, 40.57178919655936, 38.36238016401018, 40.083087648664204, 38.01408781324114, 43.249347005571636, 48.363304546901155, 45.40556410380772, 47.348808492933, 51.85494456972395, 50.66893570763724, 47.95573363985334, 47.98696231842041, 53.371274266924175, 47.697708811078755, 46.43037823268345, 40.98731231689453, 36.01269047600882, 44.48794330869402, 49.55419799259731, 49.858688899448936, 49.02333130155291, 46.581689153398784, 45.853726387023926, 45.765710081372944, 43.96975360597883, 41.79443938391549, 36.347777775355745, 35.829727036612375, 33.127975600106375, 35.91122245788574, 36.618625504629954, 39.65933091299874, 50.1609320640564, 50.41691064834595, 49.77744361332485, 46.53409399305071, 44.25462974820818, 49.42363091877529, 50.5453758920942, 46.98905856268746, 48.39561019624983, 44.85228599820818, 39.8548949105399, 37.06435591833932, 37.58396305356707, 34.064797742026194, 38.27008376802717, 41.0623459134783, 44.75154059273856, 45.869022846221924, 49.152540002550396, 46.296573298318044, 50.89130585534232, 50.22409813744681, 53.279175894601, 41.0640412739345, 50.411376408168245, 50.0953688621521, 48.41199057442801, 43.932111740112305, 33.242256096431184, 20.573921748570033, 9.53039584841047, 6.178585716656276, 8.782593369483948, 8.95510584967477, 15.45291004862104, 12.376539536884852, 11.209231751305715, 3.444304985659463, 0.7118379516260964, 0.3545240435217108, 4.215127280780247, 20.210463217326573, 40.64508574349539, 43.808166299547466, 40.04543188640049, 56.26767601285662, 47.56248991830008, 18.819680520466395, 1.3148502856492996, 0.13046256585844926, 0.19674415992838995, 0.10419800877571106, 0.16305423128817761, 0.0877827742536153, 0.07647998218557664, 0.1430535295179912, 0.11678476551813738, 0.1263301790292774, 0.11263940509940897, 0.13705499496843132, 0.0708826043243919, 0.07829420162098748, 0.12245285351361547, 0.15391825937799045, 0.07480945611106497, 0.09592699938054595, 0.18454263465745108, 0.1511723231524229, 0.1781609042414597, 0.1630403891737972, 0.17460059028651032], [0.04918777024639504, 0.023743217644680823, 0.02339908673561045, 0.05649689179179924, 0.03109057294204831, 0.007016018590158117, 0.03491711689691458, 0.029319620292101587, 0.03122169304905193, 0.04183852013998798, 0.03437223970623953, 0.034466047172567675, 0.03594429338616984, 0.007252646227633315, 0.0365257164729493, 0.022843856796888367, 0.05723633550639663, 0.05198397573881915, 0.0263833600828158, 0.03388856637424656, 0.021039961271786263, 0.017723148089966605, 0.13174928538501263, 0.041565518360584974, 0.08452447623546634, 0.05545287745605622, 0.05885306732462985, 0.8054071164556912, 13.923750502722603, 36.306446416037424, 40.70535094397408, 39.45359822681972, 60.73147324153355, 67.19614669254848, 51.91230542319161, 20.72175509589059, 4.4661717755453925, 0.41579122309173855, 0.10456494015774556, 1.3945870527199336, 5.43229968207223, 6.892720265047891, 4.528476706572941, 2.517620265483856, 17.268290213176183, 26.199529000691005, 28.331300599234446, 33.250746795109336, 49.01526096888951, 49.742195401872905, 49.496892724718364, 45.825110231127056, 44.15172345297677, 40.24857289450509, 37.82342576980591, 35.67510877336775, 37.94858019692557, 33.841937746320454, 34.06349148069109, 34.67961604254586, 41.47648286819458, 46.66881261553083, 48.629229477473665, 46.19459458759853, 44.39956569671631, 43.92998906544277, 43.64775323867798, 42.09826673780169, 36.08528872898647, 32.16098437990461, 34.23502165930611, 35.24706847327096, 32.80732318333217, 32.54827002116612, 33.16018050057547, 31.239722728729248, 32.47210386821202, 38.204461506434846, 45.01858418328421, 45.62701708929879, 45.11071034840175, 44.536594595227925, 44.52136761801583, 44.730025495801655, 47.709190709250315, 44.89349923815046, 44.76036480494908, 41.947160788944785, 34.10818576812744, 31.220608234405518, 41.73316669464111, 47.235952377319336, 43.573410987854004, 43.786300318581716, 40.1767007282802, 37.70703649520874, 35.06831216812134, 34.08536788395473, 31.899669579097203, 32.33360889979771, 33.38400629588536, 36.536560331072124, 33.52291120801653, 32.77960681915283, 34.90719039099557, 42.01925529752459, 45.89653423854283, 45.55828203473772, 46.881521293095176, 44.06499603816441, 46.14737810407366, 47.66642107282366, 45.3759890965053, 43.06640093667166, 46.01936101913452, 39.47641263689314, 33.534097807747976, 32.285815715789795, 32.56977469580514, 32.56280565261841, 32.83434125355312, 33.21241358348301, 36.19856868471418, 38.98799596514021, 41.79038511003767, 42.93259947640555, 45.98212909698486, 46.30284057344709, 48.594947065625874, 41.536452770233154, 49.38780600684029, 42.619173186165945, 36.771857602255686, 22.728210721697124, 11.420709729194641, 1.6002304979733057, 2.0404457790510993, 2.035185775586537, 5.541308666978564, 8.823898673057556, 4.846363306045532, 3.8648959483419145, 2.0756527355739047, 0.18985495317195142, 0.5045285129121372, 4.623565409864698, 18.782419068472727, 28.95160797664097, 26.256403480257305, 37.408948353358674, 43.45518044063023, 31.25161804471697, 7.788195848464966, 0.2509746870824269, 0.05085719709417649, 0.005758520598257226, 0.029049030704689876, 0.03673837274046881, 0.021591126785746644, 0.019920558302796314, 0.022463098567511355, 0.031766970575387986, 0.09548831970563956, 0.012279552557239575, 0.030122439177440744, 0.04118637674088989, 0.039385578728147914, 0.006680826107705278, 0.029629205287035023, 0.04697306247960244, 0.036755668598094156, 0.014003693076249744, 0.03310672439900892, 0.03973604206527982, 0.008424419377531325, 0.05802944116294384, 0.01667018048465252, 0.017418504526306475, 0.04926407829459224, 0.06896156990634543, 0.030003685371151993, 0.03645775440548148, 0.036959035721208365, 0.03400483674236706, 0.0751741211861372, 0.027845574210264852, 0.018411844170519283, 0.025368878983759453, 0.027699777390807867, 0.02420494206515806, 0.016651244268619587, 0.008039556011291487, 0.028653807805052826, 0.043029108217784336, 0.07246859850628035, 0.028751143653477942, 0.0474682844776128, 0.09685993074838604, 0.09802091773599386, 0.034753769769200256, 0.025706976020176495, 0.056082161010376046, 0.05541251480047192, 1.0838075918810708, 19.845156465257915, 44.73681388582502, 47.056292806352886, 42.35233804157802, 59.42062609536307, 67.23627253941127, 54.69486788340977, 25.836317130497523, 4.674549988337925, 0.4382403370525156, 0.09232366630541426, 1.1689117337976183, 5.228797367640904, 11.764279910496303, 5.2727464607783725, 2.282899694783347, 19.215462071555002, 27.884557485580444, 32.919925689697266, 39.17088644845145, 48.30950117111206, 51.20900876181466, 51.43268864495413, 47.96496432168143, 46.03825664520264, 42.17357131413051, 39.27600574493408, 37.201336179460796, 39.74118416649954, 35.92744997569493, 35.37100349153791, 37.052307741982595, 43.57359858921596, 48.105981486184255, 49.08988809585571, 47.918845653533936, 44.72017642429897, 45.56722436632429, 45.517569065093994, 43.62420926775251, 37.86180067062378, 34.88972609383719, 35.15502221243722, 36.46152326038906, 34.455432415008545, 34.977610383714946, 34.77692208971296, 32.57943269184658, 34.37028224127633, 40.162304060799734, 46.63351229258946, 46.88930674961635, 46.19068622589111, 45.1388053894043, 47.051147665296284, 46.326276847294395, 47.22321285520281, 45.949476037706646, 45.95055300848824, 42.803908416203086, 35.99850572858538, 34.29406745093209, 43.482875960213796, 48.18817172731672, 46.535504477364675, 44.6424434525626, 40.90915550504412, 40.41175481251308, 37.678503717694966, 36.69665724890572, 33.39398043496268, 34.196521690913606, 35.1289039339338, 37.44492959976196, 35.19936908994402, 34.33780288696289, 37.001002243586946, 45.41615315846035, 47.745505469185964, 46.06499331338065, 48.08950730732509, 44.83316455568586, 46.80612291608538, 48.462778432028635, 47.10728563581194, 45.748131138937815, 46.08578927176339, 41.9609877041408, 35.27648714610508, 34.30404506410871, 34.66861704417637, 35.21225452423096, 33.66162504468645, 36.86692632947649, 38.35264573778425, 43.88664272853306, 44.202608585357666, 45.64610031672886, 48.01115942001343, 48.95922027315412, 48.52041373934065, 44.42401988165719, 50.935579776763916, 44.888708455221995, 39.824989863804404, 26.004378420966013, 13.77737193448203, 3.1008179656096866, 2.8394990393093655, 4.134654113224574, 6.925094527857644, 6.845852059977395, 6.94320240191051, 3.9319204432623724, 1.397611256156649, 0.10295988592718329, 0.630968953881945, 4.14666450875146, 20.679193905421666, 32.10489852087838, 30.98217385155814, 38.182345390319824, 50.32775831222534, 35.615465436662944, 9.80087445463453, 0.3682008124887943, 0.07439889492733137, 0.008995756041258574, 0.04157254459070308, 0.03191978005426271, 0.009723841927812567, 0.021492030138948133, 0.04545912532401936, 0.026632801430033784, 0.09312747924455575, 0.05537194858438202, 0.03551487910694309, 0.027103472334731902, 0.015204868844843336, 0.07073464297822543, 0.08883277326822281, 0.040751232233430655, 0.04484609607607126, 0.0602412074804306, 0.02422463654407433, 0.023757024135972773, 0.03417212276586464, 0.015646615498034016, 0.08582056633063725, 0.06956856019262757, 0.10083369644624846, 0.15876460075378418, 0.10097183260534491, 0.16075226052531175, 0.09487021501575198, 0.09478328110916273, 0.13273088128439017, 0.13471801179860318, 0.14537714554795197, 0.09947748136307512, 0.16724081949463912, 0.11623842269182205, 0.17066750276301587, 0.07307741405176264, 0.09376202483794518, 0.17890263801174505, 0.2110676406217473, 0.09285744266318423, 0.07089434976556472, 0.116941792092153, 0.23177855142525264, 0.07238781212696008, 0.14866566551583155, 0.12868160142430238, 0.14072307385504246, 1.4691888839006424, 21.392377853393555, 51.32798276628767, 54.77272244862148, 50.103605951581685, 68.25214086260114, 70.78975500379289, 58.75534997667585, 28.651124443326676, 7.089309990406036, 0.7528364488056728, 0.8219153306313923, 3.685526898929051, 10.446851083210536, 14.556305817195348, 10.242408156394958, 5.088180158819471, 21.72805401257106, 30.245504992348806, 32.97976705006191, 39.785742964063374, 49.45867763246809, 52.3438024520874, 54.54976865223476, 49.88980640683855, 49.02669422967093, 43.61738613673619, 40.68124416896275, 40.021853174482075, 41.74012878962925, 36.58678885868618, 38.25498185838972, 38.409245763506206, 45.86183840887887, 51.52926860536848, 51.93689162390572, 47.73693139212472, 44.467529501233784, 46.88111482347761, 47.57905094964163, 45.243987219674246, 39.64470148086548, 35.187977518354145, 37.342030252729145, 38.896109512874055, 36.812560149601524, 35.80867746898106, 35.369909150259836, 34.66570922306606, 35.94700915472848, 40.26087815420968, 47.39276279721941, 48.33595296314785, 46.630149364471436, 44.59249980109078, 46.62470892497471, 46.6715258870806, 49.44149473735264, 46.86692312785557, 46.08141885484968, 43.88085835320609, 38.74933923993792, 37.97168295724051, 45.82389429637364, 50.24873992374965, 47.74670055934361, 46.49499647957938, 43.27762269973755, 40.91377258300781, 38.89387566702706, 36.36012472425188, 34.39741495677403, 37.32540321350098, 37.347661767687114, 39.6957221031189, 36.3216803414481, 35.71998718806675, 37.39673689433506, 46.010686193193706, 49.061247621263774, 48.19416107450213, 50.17842762810843, 45.99421548843384, 46.60376705442156, 49.11517953872681, 48.509890692574636, 45.241405963897705, 48.70098352432251, 43.53816277640206, 37.294716494424, 36.779281752450125, 35.26324387959072, 35.00297825677054, 35.955121176583425, 36.78023018155779, 40.108761242457796, 43.53381667818342, 46.49189758300781, 46.31157098497663, 49.953222615378245, 50.82070173536028, 50.10221283776419, 44.11279617037092, 53.972265652247835, 47.82915483202253, 41.2415086882455, 26.82946310724531, 14.44723994391305, 2.8002586535045078, 5.203026933329446, 5.764491753918784, 13.98740121296474, 15.675660610198975, 11.69140112400055, 9.55693622997829, 4.5097695503916055, 0.8896011529224259, 0.9687487887484687, 6.075108366353171, 25.2822573525565, 38.936440331595286, 36.28952407836914, 47.197858878544395, 54.817514010838096, 41.789686816079275, 12.194071156638008, 0.5140491191829953, 0.12953913398087025, 0.07509608287364244, 0.1122726501364793, 0.09574230893382005, 0.08012769145092793, 0.09593272621610335, 0.09885136317461729, 0.11193073634058237, 0.22502749439861092, 0.10138614608773164, 0.08380615870867457, 0.12478252207594258, 0.0830034992790648, 0.1643408015370369, 0.1337490773626736, 0.14609973106001103, 0.2075460303042616, 0.23310250895363943, 0.14511148551745073, 0.1376999696450574, 0.1267115157097578, 0.14777787029743195], [0.035484898037144115, 0.08219237173242228, 0.029022513556161096, 0.031276959726320844, 0.029606437044484273, 0.007115263242407569, 0.005843777675181627, 0.07346009423157998, 0.046447883160518746, 0.026068477425724268, 0.04076442973954337, 0.01400757853740028, 0.01551813489225294, 0.046279677722070894, 0.027754245093092322, 0.010987285158729978, 0.03542795877105423, 0.04441817796656063, 0.02161312149837613, 0.008704488947322326, 0.044970111921429634, 0.04126100541491594, 0.03180054109543562, 0.03513394954747387, 0.04562444020328777, 0.055346744401114326, 0.06085144116410187, 0.3158546042229448, 6.057929379599435, 27.23278866495405, 42.50287423815046, 42.86175216947283, 53.73959827423096, 57.686282770974294, 27.869403464453562, 23.395778008869716, 7.812539730753217, 0.6825373438852174, 0.12465338329119341, 0.6260953353984016, 3.5389346735818044, 5.148292933191572, 2.146572998591832, 1.666365623474121, 6.2450847540582926, 9.850919723510742, 23.59902150290353, 39.990697452000205, 50.711180755070274, 49.318264961242676, 50.23183148247855, 46.35915224892752, 43.927508558545796, 41.15431921822684, 39.37958948952811, 37.22532830919538, 38.596836703164236, 34.88051625660488, 35.50245646068028, 33.98193005153111, 38.65153987067086, 44.91936043330601, 47.427538531167166, 45.71509940283639, 44.25958033970424, 44.774872643607004, 44.75027254649571, 41.077833448137554, 41.78424637658255, 39.3906649180821, 39.66753326143537, 37.15509244373867, 33.861840861184255, 32.942632402692524, 33.337793827056885, 31.81455762045724, 32.428396224975586, 33.61011457443237, 45.11442068644932, 45.911264419555664, 45.63526807512556, 42.780635425022666, 45.5155679838998, 43.834336689540315, 46.75835057667324, 45.62237916673933, 47.23019232068743, 40.63262414932251, 49.4737309047154, 37.70730400085449, 38.293787547520225, 48.44726310457502, 41.865474292210166, 43.126037325177876, 36.88723938805716, 35.38541405541556, 33.52323429925101, 33.49813393184117, 32.11443839754377, 34.13568326405117, 31.625413758414133, 39.401795932224815, 35.056038175310405, 32.189232281276155, 33.811605385371614, 35.42395223890032, 43.8119079044887, 46.149997574942454, 45.89195537567139, 46.29574646268572, 47.037727219717844, 45.73139292853219, 45.37402275630406, 45.92790535518101, 45.218963282448904, 44.861370767865864, 40.1312768799918, 33.32400860105242, 33.09310606547764, 33.63388436181204, 33.89964253561837, 33.642454964774, 34.79974692208426, 34.7821957724435, 35.73259122031075, 38.902585233960835, 42.947079522269114, 45.86956133161272, 46.59923335484096, 45.84301226479666, 42.29667949676514, 41.24635853086199, 31.24523959841047, 18.130884749548777, 6.498824715614319, 2.0279262108462195, 2.316252133675984, 3.220644644328526, 3.6246500398431505, 4.519299004759107, 6.360177321093423, 1.6829630242926734, 1.339208715728351, 0.1760604583791324, 0.6473517205033983, 5.446797966957092, 22.697829723358154, 35.633475167410715, 28.983864988599503, 34.09332357134138, 41.37956592014858, 23.21457072666713, 4.11930684532438, 0.17205155135265418, 0.05028167047670909, 0.030735156299280267, 0.011610936024226248, 0.11213649529963732, 0.05703255786959614, 0.0480324659895684, 0.05968670866319111, 0.02281333289907447, 0.10491899294512612, 0.026382915642378584, 0.028862911941749708, 0.0060466948447615975, 0.05366422522014805, 0.02924728167376348, 0.030377958502088274, 0.01869920714359198, 0.03856921289116144, 0.05328263748171074, 0.02942680846899748, 0.034712928746427806, 0.029584849452865974, 0.05846442960734878, 0.07684299163520336, 0.04436590023604887, 0.017539801142577614, 0.05305198985817177, 0.0275079097399222, 0.049928129983267615, 0.03919257962011865, 0.04518162825011781, 0.017638053013277904, 0.011097363046636539, 0.01929665044216173, 0.03902855735006077, 0.004808334933061684, 0.0797168927799378, 0.02724344902006643, 0.05083960946649313, 0.011102931274633323, 0.06934755455170359, 0.02028754905664495, 0.014238295710778661, 0.0429392125058387, 0.05680996445672853, 0.060961302768971236, 0.02086502137327833, 0.029059524248753275, 0.04549332009628415, 0.036996677451367886, 0.49117407522031237, 8.17900162083762, 35.470331464494976, 50.94521345411028, 47.31323371614729, 61.48714542388916, 63.55586733136858, 41.52470684051514, 26.136679070336477, 8.321695038250514, 0.681765225316797, 0.07994099932589702, 0.4737242172871317, 5.016750505992344, 5.695647265229907, 2.8475941249302457, 1.6995555396590913, 7.877577475139073, 14.416046006338936, 28.25913313456944, 40.41180344990322, 52.27451154163906, 50.49314628328596, 51.748935903821675, 47.49262925556728, 46.47662196840559, 42.91920334952218, 41.09911925452096, 39.53498247691563, 40.22210373197283, 35.12530824116298, 38.19231605529785, 35.74953440257481, 39.3805969783238, 47.040006228855674, 49.29552003315517, 47.738585063389365, 43.611587865012034, 45.852326325007844, 46.26619577407837, 43.50730235236031, 42.140445777348106, 39.97911480494908, 40.337290968213765, 38.17440707342965, 34.952416215624126, 34.251103264944895, 34.63663101196289, 33.95459236417498, 32.950633253370015, 35.978307315281455, 46.63751098087856, 47.30439908163888, 45.91379356384277, 43.64257683072771, 44.78321395601545, 44.77243035180228, 47.67062473297119, 45.97421162469046, 48.66023233958653, 43.63094554628645, 50.379709993089946, 39.80659450803484, 41.300603117261616, 50.09932586124965, 43.01843057359968, 44.792569705418174, 39.00420611245291, 37.221315724509104, 34.606903144291465, 34.79332678658621, 34.789289883204866, 35.34127909796578, 33.92110899516514, 40.66260215214321, 37.858288356236045, 33.424128668648855, 35.75324821472168, 38.28638424192156, 46.082158837999614, 47.235386099134175, 46.62472629547119, 48.05631576265608, 48.293794768197195, 46.2467998777117, 47.07065125874111, 48.41366856438773, 47.34795733860561, 45.52325963973999, 40.74685948235648, 35.18850558144705, 34.93327740260533, 35.36061246054513, 35.75582252229963, 33.67200565338135, 35.292002473558696, 35.92944063459124, 37.99067933218819, 41.43900081089565, 45.27065787996565, 47.04410219192505, 48.3811787877764, 46.91708217348371, 45.506292138780864, 43.114270550864084, 34.5073458807809, 19.850416251591273, 8.63446819782257, 2.1884046282087053, 3.2149423445974077, 4.3962320770536145, 7.256718584469386, 7.235687255859375, 8.14340339388166, 2.7343630237238745, 1.0304116627999713, 0.13499508478811809, 0.5910590982862881, 6.527014425822666, 23.90148527281625, 38.94321482522147, 32.55544751031058, 41.02392584936959, 46.720281396593364, 28.999107599258423, 5.9593261906078885, 0.08946083885218416, 0.027492685110441277, 0.039475786566202126, 0.030384197631584745, 0.014490415574982762, 0.0253197818861476, 0.10047183372080326, 0.05148842465132475, 0.008290958324713367, 0.039649284577795436, 0.05399935366585851, 0.01325576937025679, 0.043801352315183194, 0.04638224846816488, 0.03133812626557691, 0.021821838870112385, 0.024717593931459954, 0.05551627976819873, 0.014992551844833153, 0.021016584044056277, 0.03407493619514363, 0.028667819553187916, 0.024845382431522012, 0.14714847478483403, 0.21319406080458844, 0.1687247755804232, 0.11243038238691432, 0.0772947466799191, 0.19697184913924762, 0.11379517415272337, 0.1615873607141631, 0.1197087357618979, 0.15309390718383448, 0.08882664609700441, 0.11944257361548287, 0.07557924051902123, 0.12859546818903514, 0.05833298380353621, 0.1425182061003787, 0.1165952371167285, 0.16709946707955428, 0.13600002229213715, 0.21159178178225244, 0.09241940081119537, 0.13927432016602584, 0.1284540614911488, 0.20663880184292793, 0.09928771547440972, 0.13192327533449444, 0.14601625768201693, 0.6486295919333185, 11.079469799995422, 41.56810181481497, 58.1835549218314, 54.71046311514718, 61.827405657087056, 62.209438460213796, 38.98224285670689, 31.75770745958601, 10.791729262896947, 0.9876551628112793, 0.4262365640274116, 1.9040954155581338, 9.158371925354004, 12.746906314577375, 7.133363740784781, 2.545242177588599, 7.799523149217878, 12.240450382232666, 29.511987141200475, 41.58033064433506, 54.04301221030099, 52.55420085362026, 53.484766142708914, 51.49531275885445, 48.41977603094918, 45.00489970615932, 43.44609914507185, 40.69761412484305, 42.119934695107595, 38.89672442844936, 39.912811619894846, 36.99790334701538, 42.517267431531636, 48.867062841142925, 51.18028490883963, 48.2988669531686, 45.1090532030378, 48.02085910524641, 48.95791401181902, 45.05706678118025, 44.10944019045149, 42.07972894396101, 43.28226409639631, 41.23721122741699, 37.70611933299473, 36.75107901436942, 37.47604710715157, 35.682755265917095, 34.68822486060006, 36.43666607992989, 48.45015008108956, 48.736249106270925, 46.97688184465681, 44.79225008828299, 46.377592767987935, 43.98249660219465, 48.03825044631958, 48.15066882542202, 49.6752564566476, 45.010586806706016, 50.81956570489066, 42.472288267953054, 43.23330014092581, 51.63177537918091, 45.56170402254377, 46.67354086467198, 40.83823871612549, 38.20692464283535, 36.10637651171003, 35.82644401277815, 36.342941829136436, 37.5345961025783, 34.64810248783657, 41.709421225956504, 38.016088894435335, 35.14037888390677, 38.11616379874093, 38.566024916512625, 47.58986234664917, 48.79267195292881, 47.68816546031407, 50.04791613987514, 49.350893701825825, 47.010208879198345, 47.94912242889404, 49.849204608372276, 48.574074677058626, 47.321936334882466, 43.222162178584504, 35.82789618628365, 35.46854230335781, 37.92910439627511, 36.83824069159371, 35.09641415732247, 37.72807216644287, 38.14346674510411, 40.246488434927805, 42.73952293395996, 47.59947517939976, 49.861322266714915, 50.240645272391184, 49.543806961604524, 46.312078203473774, 46.7742133140564, 36.543147223336355, 20.233473914010183, 8.703264049121312, 3.251758460487638, 4.76937335729599, 7.674527662140982, 10.120783414159503, 12.651493651526314, 16.44208860397339, 5.326802143028804, 2.5900463334151675, 0.32125270313450266, 1.1505097555262702, 8.143321752548218, 29.358935696738108, 46.62284680775234, 40.94754082815987, 46.91882617133004, 54.077742780957905, 32.273107460566926, 7.522674781935556, 0.23346937926752226, 0.21974838338792324, 0.12701433231788023, 0.10917319038084575, 0.2565555290452072, 0.11621765952025141, 0.15527455588536604, 0.15975888525801046, 0.049069077508257966, 0.18213849009147712, 0.08764056009905678, 0.08460659254342318, 0.09312657679298095, 0.17207521865410463, 0.11864186158137661, 0.18522251317543642, 0.08160322691713061, 0.17687508038112096, 0.1604491996445826, 0.1337846733097519, 0.10234994401357003, 0.15421195647546224, 0.09562486809279237], [0.036732564480709176, 0.07135499361902475, 0.0606907776423863, 0.016304115931104337, 0.03693179254020963, 0.04586286044546536, 0.03311531125966992, 0.031018756795674562, 0.036481340282729695, 0.015432970265724828, 0.0917795015765088, 0.03658208916229861, 0.03434299145426069, 0.0518219992518425, 0.09584444881017719, 0.04014529028375234, 0.0494003518750625, 0.028426323851038302, 0.04539899355066674, 0.021435855921091776, 0.002647346783695476, 0.038511561163301976, 0.0789011511951685, 0.005627576062189681, 0.03651869363550629, 0.0477382769542081, 0.0018469861035035656, 0.02628114726394415, 5.662909959043775, 23.924768686294556, 38.39161818368094, 42.37411369596209, 37.99272905077253, 32.603011403764995, 23.89517457144601, 24.384577887398855, 10.126787526266915, 1.3740334127630507, 0.07240043287830693, 0.27634291297623087, 3.4118983703000203, 4.158910274505615, 1.5779888800212314, 1.3667514835085188, 1.346970722079277, 6.500576964446476, 21.57760293143136, 33.86521768569946, 48.06508091517857, 51.34438746316092, 49.91656044551304, 46.19137062345232, 44.956057344164165, 41.198857171194895, 39.60006625311715, 35.94233996527535, 35.16367619378226, 36.383554049900596, 37.76194116047451, 37.867918559483115, 40.04951395307268, 43.342807224818635, 45.24960483823504, 46.89153364726475, 43.54561471939087, 44.90352201461792, 46.01012338910784, 44.659098284585134, 44.412451131003245, 45.73357118879046, 45.17058644975935, 45.3529314994812, 42.077488149915425, 33.666558265686035, 31.64831849506923, 31.023282868521555, 31.61116647720337, 32.4672019141061, 42.498587199619834, 44.85647576195853, 47.06113917487008, 46.43498141424996, 46.92104959487915, 43.96300343104771, 46.23378242765154, 45.07319007601057, 47.650263037000386, 46.31089006151472, 45.21479436329433, 34.91552822930472, 37.80094139916556, 48.65763371331351, 42.90321901866368, 44.22923060825893, 36.50809703554426, 34.500074590955464, 33.5832702091762, 33.92804677145821, 31.963190010615758, 35.0364407811846, 34.55595547812325, 33.977896622249055, 32.54377801077706, 34.06850808007376, 33.77776765823364, 33.96031073161534, 35.882043497903005, 40.72735588891165, 42.914443833487375, 44.6923315184457, 46.418246677943635, 48.28440080370222, 45.349547726767405, 45.942906515938894, 46.48333740234375, 45.688730989183696, 41.9612169946943, 34.98168897628784, 32.06294182368687, 33.70984901700701, 34.538765634809224, 34.682812213897705, 34.86725909369332, 34.70611994607108, 35.91990770612444, 37.1863454410008, 41.23173257282802, 42.856690406799316, 44.98253345489502, 46.37180144446236, 45.809202330453054, 36.91139827455793, 26.26792185647147, 12.223652243614197, 4.7611536383628845, 0.8410735768931252, 1.6449517096791948, 3.9676541600908553, 6.5184507710593085, 4.818272173404694, 3.9098651238850186, 2.278835867132459, 0.7215989221419606, 0.1287093535065651, 1.3842368423938751, 8.093101041657583, 23.185450826372417, 28.692005906786235, 35.61854001453945, 35.32514190673828, 32.964918749673025, 13.189522198268346, 1.0986127917255675, 0.042636772484651635, 0.08836095394300562, 0.05553214730960982, 0.005339458642993122, 0.02636710916911917, 0.02868061333096453, 0.07329423991697175, 0.0716608025665794, 0.013997855130583048, 0.03827883043725576, 0.01405094116593578, 0.038834360627723594, 0.07002057308065039, 0.01987665199807712, 0.037419764391545735, 0.0259479475540242, 0.045377171864467006, 0.012156278011389077, 0.032849579982991726, 0.026662967400625348, 0.003180339009434517, 0.03849465885598745, 0.016987285343930125, 0.03148642009390252, 0.052059947912182124, 0.04660935074623142, 0.032972303219139576, 0.028514053339936903, 0.044841461681893895, 0.04560768038832715, 0.019825247881401862, 0.044746592308261564, 0.02096031652763486, 0.02180236321873963, 0.01743036531843245, 0.04577836926494326, 0.022907561057114174, 0.03626850081075515, 0.037735608872026205, 0.0381119345713939, 0.020741117486198033, 0.04694265393274171, 0.025278840779459903, 0.019504141361851777, 0.04369025916925498, 0.03752365828092609, 0.03403501458732145, 0.013667484063522091, 0.028133756514372568, 0.04488476239410894, 0.05336454344381179, 7.51764862877982, 28.12347824232919, 46.81789663859776, 48.31149877820696, 45.86368662970406, 43.35283694948469, 24.452376672199794, 28.3849823815482, 11.869037900652204, 1.2686141495193755, 0.09502178616821766, 0.6409868448972702, 3.356311913047518, 1.824376561811992, 2.748068996838161, 2.4243268030030385, 2.687074669769832, 7.6427935021264215, 23.116225923810685, 36.213920729500906, 46.89610208783831, 53.296216351645334, 50.70782477515084, 48.55085727146694, 45.48531205313546, 43.10917752129691, 40.49686329705374, 37.95581327165876, 36.464219161442344, 36.96788018090384, 37.687539849962505, 39.39418765476772, 40.49679381506783, 45.68496853964669, 47.9550735609872, 48.49728318623134, 43.88614593233381, 45.71888617106846, 48.396721908024375, 44.93301364353725, 46.012034143720356, 46.83540262494768, 46.74055276598249, 45.21429409299578, 42.40731913702828, 35.32776485170637, 34.08653865541731, 34.025849614824565, 33.20194264820644, 33.936624322618755, 43.735731329236714, 46.97975492477417, 49.17869649614607, 46.92490931919643, 46.57269123622349, 46.89598396846226, 48.60028328214373, 47.363507407052175, 49.3408396584647, 47.23092188153948, 46.81043774741036, 36.96164069856916, 40.31349686213902, 50.44655166353498, 44.076245171683176, 45.433436802455354, 38.21743031910488, 35.816914558410645, 34.95623425074986, 35.313885825020925, 34.3168158531189, 35.152611187526155, 35.07892206736973, 35.95961666107178, 34.814292975834434, 35.86998837334769, 35.80319881439209, 35.59345701762608, 38.80698149544852, 43.875265053340364, 44.32941320964268, 47.02028029305594, 47.45439331872122, 48.84765999657767, 45.184329986572266, 47.124815940856934, 47.8878219468253, 47.273236410958425, 43.1565294946943, 35.50888007027762, 34.07973984309605, 35.263858795166016, 35.048878056662424, 37.233620984213694, 37.035645961761475, 36.77523790087019, 37.41175889968872, 40.72628239222935, 42.28429433277675, 44.17510414123535, 46.87903036390032, 48.44971581867763, 46.98252725601196, 41.57814196177891, 27.2562701020922, 15.32705385344369, 5.469172469207218, 2.543466695717403, 4.921254898820605, 7.269407732146127, 8.284967729023524, 7.123121227536883, 5.334210225514003, 2.059686643736703, 0.7341924778052739, 0.14137492887675762, 1.3848339532102858, 8.03502539225987, 26.95388102531433, 33.553820269448416, 38.48679460797991, 40.87358767645699, 40.177843706948416, 17.386829955237253, 1.5660942154271262, 0.013793386236232306, 0.05020338449893253, 0.03924404989395823, 0.03413162440327661, 0.017104982331927334, 0.028705817514232228, 0.024612432877932276, 0.015564570436254144, 0.07039665790008647, 0.004648396171562905, 0.03376313239069922, 0.08601853570767812, 0.08542283624410629, 0.05417989826362048, 0.06463088800332376, 0.0707336048196469, 0.050464589947036335, 0.02615103987045586, 0.029789482043789964, 0.03117518625887377, 0.028642211641584123, 0.10405418649315834, 0.026447697076946497, 0.10810430773666926, 0.20982438804847853, 0.10050568583288363, 0.14184986267771038, 0.10648851229676179, 0.15484098557915005, 0.17560573135103497, 0.11920226365327835, 0.14571315608918667, 0.06904915520655257, 0.21131787076592445, 0.06990336294152907, 0.1508432472390788, 0.14370938789631638, 0.1310517242444413, 0.12253123787896973, 0.18681544198521546, 0.12898053681211813, 0.10669834246592862, 0.10671510228088923, 0.074376795041774, 0.09240194889051573, 0.20973530997123035, 0.0761583023039358, 0.13007437597428048, 0.1667024019573416, 0.10386947569038187, 0.13133726535098894, 8.329992055892944, 33.596371037619456, 53.624723706926616, 54.91635908399309, 49.495402336120605, 42.22643320901053, 32.721092564719065, 34.4661534854344, 13.765204770224434, 1.9985696375370026, 0.44904440588184763, 1.8230841968740736, 5.395070799759456, 9.257428050041199, 5.970180579594203, 1.9290726695741927, 2.671683758497238, 8.497034566743032, 24.861097506114415, 36.38520424706595, 49.2764333316258, 54.18956708908081, 53.55843441826956, 50.649508544376914, 49.09542233603341, 45.00035211018154, 43.027445861271445, 40.18706396647862, 39.182427406311035, 38.45250177383423, 41.44171755654471, 42.40163203648159, 44.23133591243199, 47.92320564814976, 49.5648843220302, 49.16908366339547, 44.643972056252615, 46.46558128084455, 49.87318284170968, 47.98213332039969, 48.367987632751465, 50.38686663763863, 48.85964216504778, 49.379780837467735, 46.92847374507359, 38.73334796088082, 34.45126696995327, 36.13453756059919, 34.614021573747905, 36.059472697121755, 45.62390429633004, 47.8075806753976, 50.66392953055245, 47.388795375823975, 48.09273474557059, 47.425874437604634, 50.54070322854178, 49.81119448798043, 51.30294145856585, 48.850091866084504, 47.0298444884164, 40.3155882699149, 41.58781385421753, 51.3662360736302, 47.477513449532644, 46.642676966530935, 39.91933250427246, 36.9630720274789, 36.802752767290386, 36.87344026565552, 36.07361922945295, 37.838868141174316, 36.22537136077881, 37.53117758887154, 35.141077177865164, 37.65882641928536, 37.861745085035054, 35.585633346012656, 39.39095674242292, 44.25998680932181, 45.70938450949532, 48.44307334082467, 49.40851163864136, 50.7450566973005, 46.39155517305647, 47.90169402531215, 49.37972525187901, 49.50330591201782, 45.7076335634504, 37.946176120213096, 35.89214270455496, 36.91515377589634, 38.412323815482004, 38.394675391060964, 38.493829659053254, 39.19833878108433, 40.04823548453194, 42.783498082842144, 45.603751046316965, 46.30041912623814, 48.86650003705706, 49.11735779898507, 49.42841822760445, 42.26915420804705, 30.190298080444336, 15.613191093717303, 6.8096667102405, 1.9966905840805598, 5.850658535957336, 11.735444886343819, 12.296163644109454, 14.365748865263802, 10.241123608180455, 5.614877496446882, 2.1825935457433974, 0.4761950618454388, 1.8683352087225233, 11.071483714239937, 30.146472317831858, 38.93751730237688, 46.24742521558489, 47.576292514801025, 44.13793822697231, 19.81245650563921, 2.6406420298985074, 0.1704110029552664, 0.13736399981592382, 0.1682133094540664, 0.2822443763060229, 0.12937690982861177, 0.1106345783919096, 0.16808650482978138, 0.1630598088460309, 0.2078963986464909, 0.08589129003563098, 0.2539238988288811, 0.17650568591696875, 0.2141520029732159, 0.17803422175347805, 0.15155646896788053, 0.08988304369683776, 0.13115878349968366, 0.10757868058447327, 0.11789279963288989, 0.11208971031010151, 0.15492467608835014, 0.16269937104412488, 0.11057095216321093], [0.004760020695227597, 0.044211424953703365, 0.09345747796552521, 0.06140552607497998, 0.01047825497309012, 0.06896945448326212, 0.0372483393044344, 0.02279795559921435, 0.03092504771692412, 0.0236847414967737, 0.03179410179810865, 0.03767162641244275, 0.07054355394627367, 0.025169250588597994, 0.01889967522583902, 0.08577165752649307, 0.03774884369756494, 0.05524863502276795, 0.02058251671093915, 0.07765392919204064, 0.04014232847839594, 0.027454195211508443, 0.0824984453086342, 0.02422239737851279, 0.015722202602773905, 0.0470508938389165, 0.05575803840266807, 0.03468738868832588, 2.4927617822374617, 17.913202898842947, 39.619281496320454, 43.451661178043906, 32.64746945244925, 26.162112951278687, 27.096022060939244, 23.401173285075597, 13.065538542611257, 2.6003618027482713, 0.035419388873768706, 0.3569545830999102, 2.363363742828369, 0.9214877933263779, 2.127618747098105, 2.339250236749649, 1.5351457446813583, 3.6294366972787038, 12.932482276644025, 27.762739930834087, 42.32458346230643, 50.9476592200143, 51.41032934188843, 46.282562255859375, 45.96717657361712, 42.66200883047921, 40.74179424558367, 36.289159297943115, 40.085206849234446, 43.49902704783848, 43.89531755447388, 43.64999750682286, 42.82390185764858, 44.29993200302124, 45.52287401471819, 48.21600273677281, 44.95931952340262, 44.462589332035606, 46.06583751950945, 47.31918484824044, 47.24155957358224, 45.58955587659563, 45.82596138545445, 45.77585792541504, 45.861494473048616, 43.26524100984846, 34.89621918542044, 32.01761525017874, 32.79637977055141, 30.786502156938823, 34.36595698765346, 41.97600276129586, 45.1587884085519, 44.39241252626692, 45.380366461617605, 44.61836447034563, 44.31873382840838, 41.23080151421683, 44.347006048474995, 43.151297501155305, 52.79204116548811, 37.42724643434797, 37.263171672821045, 50.164367948259624, 40.46191733224051, 43.90739352362496, 38.6470513343811, 37.46976246152605, 34.88237489972796, 35.42138487952096, 35.47128684180123, 40.31342043195452, 32.938446113041465, 33.369161469595774, 32.1602200780596, 34.59823874064854, 32.98664576666695, 33.032225949423655, 33.51877008165632, 33.82504667554583, 36.46166222436087, 42.34189142499651, 43.89841992514474, 46.733024392809185, 45.815275056021555, 44.85127503531319, 46.67096308299473, 45.54407296861921, 42.416456018175396, 35.229103905814036, 32.815633228846956, 33.02445438929966, 36.34472404207502, 40.27583415167672, 40.308313505990164, 40.38113757542202, 37.448094504220144, 40.02541760035923, 38.33706440244402, 44.980900628226145, 43.6511925969805, 48.63860259737287, 42.76779515402657, 36.87484380177089, 19.14474504334586, 9.796192237309047, 2.2655546026570454, 1.764714008995465, 3.985675181661333, 4.074617334774562, 7.899080412728446, 5.16531992810113, 2.811711456094469, 2.254416423184531, 0.3389626842524324, 0.1781649211687701, 1.8691902714116233, 11.559862170900617, 20.765099695750646, 28.261690071650914, 31.719047682625906, 38.940049920763286, 25.836223329816544, 8.535855889320374, 0.7646706423589161, 0.03913348600534456, 0.0461191770487598, 0.030751047589417015, 0.028766587110502378, 0.06705163632120405, 0.026217044364394884, 0.015732026093506386, 0.009231058415025473, 0.024279216204636862, 0.07258120139262506, 0.017022677730502825, 0.02351614929336522, 0.04518782327483807, 0.039864176618201394, 0.03181640524417162, 0.05316058938790645, 0.0379434543262635, 0.023446365359372327, 0.06071184615471533, 0.0070951968414842016, 0.011753684525111956, 0.03598572473440852, 0.033928932422505956, 0.032834333301122696, 0.03413421979972294, 0.025238445893462216, 0.10040149678077016, 0.05838663556746074, 0.02490509012048798, 0.03080519807658025, 0.045975232629903724, 0.01745595796299832, 0.04588129284924694, 0.04956643010622688, 0.030736567652119056, 0.019310312744762217, 0.037241615022399595, 0.04579600099740284, 0.044454455841332674, 0.044527510314115455, 0.05324458184518984, 0.02911190375951784, 0.04705929070977228, 0.03073580769289817, 0.03086008477423872, 0.02515509125909635, 0.029043412434735467, 0.025056686718016863, 0.029219115685139383, 0.04537237122921007, 0.032637598857815774, 3.012616447040013, 21.604905877794536, 45.423542567661826, 49.324841431209016, 38.108958516802105, 30.00314835139683, 29.046919890812465, 27.843415464673722, 15.77448831285749, 2.7682469998087202, 0.13299059734812804, 0.11469574618552413, 2.942291774920055, 4.807488134929112, 6.018787137099674, 3.3357745579310825, 2.247146870408739, 5.588644572666713, 14.761008432933263, 31.266171046665736, 44.3748266356332, 52.196716036115376, 51.72594778878348, 49.02666991097586, 46.30438307353428, 44.85453026635306, 42.425759656088694, 39.286702496664866, 42.01055267878941, 43.934623513902935, 45.95663963045393, 45.736621447971885, 45.4749071257455, 46.15292624064854, 47.65323339189802, 49.26619168690273, 44.776484625680105, 45.402378354753765, 47.837551730019705, 48.40370832170759, 47.76567261559622, 46.62627574375698, 48.792553833552766, 49.1456995010376, 48.042405469076975, 43.80412244796753, 35.937618664332796, 33.95408514567784, 34.650826181684224, 32.13056864057268, 36.415289946964805, 44.49041339329311, 47.81834690911429, 45.89502647944859, 46.88613142286028, 46.909991536821636, 45.9904009274074, 44.14372607639858, 46.01856892449515, 45.16168928146362, 52.13333109446934, 38.79598944527762, 38.91770798819405, 50.966551371983115, 43.04284306934902, 45.83161721910749, 40.88862010410854, 38.34099013464791, 36.30042927605765, 37.249751227242605, 36.10100555419922, 41.3494176864624, 35.035888399396626, 35.125051157815115, 34.98471144267491, 34.93086290359497, 34.679827962602886, 35.10440805980137, 35.68680606569563, 36.13113294328962, 38.83739376068115, 44.06007323946272, 44.97565473828997, 48.11557347433907, 46.12218393598284, 46.24837017059326, 49.29836532047817, 47.849026679992676, 43.70179285321917, 36.634439604622976, 34.23814140047346, 35.450539520808626, 38.45234891346523, 42.7276554107666, 41.890112604413716, 39.846105439322336, 39.3443204334804, 40.94023132324219, 41.12358386175973, 47.90632847377232, 46.642009939466206, 49.85571159635271, 45.58444895063128, 38.034261907849995, 23.417722157069615, 10.97039350441524, 3.5434920404638564, 4.387212012495313, 4.50840596641813, 7.69611484663827, 10.603523407663618, 6.161609530448914, 6.023680405957358, 3.028311993394579, 0.32393682481987135, 0.3149841252182211, 2.202099527631487, 14.360398752348763, 23.738308565957205, 32.43423271179199, 38.351919651031494, 43.32721894127982, 31.39312505722046, 10.918034485408239, 1.0946020526545388, 0.03656574325369937, 0.04117817325251443, 0.04541714436241558, 0.028696494443075996, 0.043160489560770135, 0.03352626599371433, 0.0592909666842648, 0.018602841600243534, 0.010196624772756227, 0.02076433356186109, 0.027620531285979917, 0.08426989668181964, 0.056909895701599975, 0.054203134695334096, 0.08900877168135983, 0.0343120604354356, 0.05909363513014146, 0.016578576560797434, 0.07389231425310884, 0.04511877555134041, 0.058183319334472926, 0.005222506771263267, 0.07857805996068887, 0.076714246400765, 0.3023364767432213, 0.10001227552337305, 0.22624617043350423, 0.1187373585999012, 0.11651371791958809, 0.07722567860037088, 0.11537867811109338, 0.1016375297414405, 0.19584246831280844, 0.11478368432394095, 0.10623480126793895, 0.11295267793216876, 0.21703561395406723, 0.16146681218275002, 0.15657604033393518, 0.11888462784034864, 0.11789571733347007, 0.09729814223412957, 0.11964833257453782, 0.17577730571585043, 0.05628241705042975, 0.2654517745333058, 0.10230682311313492, 0.13419800970171178, 0.18260173951940878, 0.11290408125413315, 0.08849471355123179, 3.6520313705716814, 23.672971180507115, 51.35629667554583, 55.46280363627842, 45.029433795383994, 35.89070790154593, 36.10027946744646, 32.212585176740376, 18.796360628945486, 3.2524765133857727, 0.3606549873948097, 0.6945401398198945, 7.88212159701756, 5.865966285978045, 6.087503084114619, 6.6108400991984775, 2.3061566182545254, 4.755377948284149, 14.687706674848284, 32.58595357622419, 46.69997181211199, 52.960712160382954, 55.498350620269775, 50.54739086968558, 48.87723500388009, 47.54097482136318, 45.26468937737601, 41.024617195129395, 43.83824157714844, 48.95137923104422, 48.92646993909563, 48.52724381855556, 46.131227016448975, 48.384632042476106, 49.431225299835205, 50.9558059828622, 46.48855897358486, 45.160671370370046, 48.44154473713466, 51.15814447402954, 51.14653056008475, 48.380206039973665, 49.99597488130842, 48.90673705509731, 48.90225894110543, 46.04238387516567, 38.832276412418906, 36.331776074000764, 35.86137955529349, 33.160423687526155, 36.10709912436349, 45.14759833472115, 49.09492553983416, 48.10751703807286, 48.45984976632254, 50.31901053019932, 47.11679424558367, 46.71340962818691, 47.882614271981375, 46.262777260371614, 54.885995456150596, 40.866893087114605, 42.19375583103725, 51.705210890088765, 46.339304719652446, 46.73266656058175, 43.36937018803188, 39.87062215805054, 38.97034754071917, 39.33381475721087, 37.831989424569265, 43.264782428741455, 34.90053749084473, 36.39768321173531, 36.01230137688773, 36.72707993643624, 36.60645226069859, 36.67498581750052, 38.519923618861604, 37.25587259020124, 38.97757714135306, 45.60915674482073, 46.933580671037944, 48.38106066840035, 47.17334563391549, 45.02549764088222, 50.65474053791591, 49.6907822063991, 46.59439740862165, 38.48580796377999, 35.87930243355887, 37.09009204592024, 39.811965465545654, 45.394440037863596, 44.442745276859824, 43.22604969569615, 41.974738189152305, 44.16546351569039, 42.58813558306013, 49.647988251277376, 48.72756385803223, 52.8489990234375, 47.52439989362444, 41.83093479701451, 23.2071761063167, 12.551291942596436, 3.7486009086881364, 4.479646938187735, 9.384814585958209, 10.989399433135986, 17.54204055241176, 11.742382662636892, 8.912050468581063, 5.358723470142909, 0.723587518291814, 0.6844116747379303, 3.1459958042417253, 15.17285943031311, 29.131826877593994, 39.382931573050364, 43.29054287501744, 50.50365890775408, 35.28250776018415, 12.395435162952968, 1.3378762900829315, 0.15301895620567457, 0.09282378732625927, 0.134511370744024, 0.14333662789847168, 0.17560721055737563, 0.16927745592381271, 0.11119511617081505, 0.06280552023755652, 0.13004780454295023, 0.13705603991236004, 0.12153897540909903, 0.22397463875157492, 0.17693034027303967, 0.24413467411484036, 0.12364275966371809, 0.1327618903347424, 0.1325772880975689, 0.09873314201831818, 0.08895353893084185, 0.1471175743000848, 0.16948491122041429, 0.14599229182515824, 0.10751067101955414], [0.008465862600132823, 0.06309437938034534, 0.04896079010463186, 0.04374820266717246, 0.06663950772157737, 0.033496332421366654, 0.07460817548313312, 0.0269077573902905, 0.030013422348669598, 0.03931268710376961, 0.01853980908968619, 0.012333926112790192, 0.06522341870835849, 0.051003679234002314, 0.022649146084274565, 0.0034346072851414128, 0.02667302668227681, 0.019466136615457277, 0.026937497580157857, 0.01385779193203364, 0.06807534210383892, 0.05580507105748568, 0.04181454749777913, 0.015785397961735725, 0.04932880035734602, 0.015668759488367608, 0.06015976970749242, 0.014269023169098156, 0.3461535541074616, 9.53854261125837, 29.695648874555314, 41.29391895021711, 38.40236357280186, 27.674463067735942, 21.924467427389963, 18.630698204040527, 15.187280416488647, 3.758031351225717, 0.2770443281957081, 0.08460405482245342, 2.3034164224352156, 2.638452695948737, 4.387721836566925, 2.863308995962143, 0.7925678768328258, 1.6978915546621596, 8.906676036970955, 21.670816489628383, 36.21898944037301, 49.02809429168701, 49.75622034072876, 48.7215119770595, 45.60358428955078, 42.69735779081072, 39.706206934792654, 41.855277810777935, 44.8602660042899, 46.147374629974365, 46.295586654118125, 46.19043261664254, 45.76957675388881, 46.19918734686715, 46.48361185618809, 44.441984449114116, 44.345581667763845, 42.532803603581016, 43.89636673246111, 45.33231619426182, 44.68696403503418, 45.78136437279837, 45.540070806230815, 46.19887467793056, 46.7273268699646, 46.15352031162807, 44.30283635003226, 34.17409985406058, 32.192595209394185, 31.889823981693812, 30.984039442879812, 33.9370516368321, 40.97908912386213, 42.37692076819283, 42.07639033453805, 40.263751234327046, 38.688823904309956, 37.59885304314749, 42.84760216304234, 42.67069060461861, 47.55051122392927, 36.349632944379536, 35.698475565229145, 51.339221477508545, 43.94727618353707, 44.908191204071045, 39.64953395298549, 38.88536064965384, 35.91556855610439, 34.73858887808663, 32.612488746643066, 34.60138974870954, 32.01373815536499, 34.131983348301475, 32.10923072269985, 32.952088900974815, 32.64575672149658, 34.09972633634295, 32.71150752476284, 33.52468647275652, 33.80624485015869, 39.04390117100307, 42.30414186205183, 45.75012527193342, 47.316162381853374, 46.780101912362234, 45.356158937726704, 45.103706564222065, 43.5233770098005, 35.545201778411865, 31.185328756059917, 35.48675353186471, 40.778578008924214, 45.0594847542899, 43.695848669324604, 42.804860319410054, 40.67913539069039, 41.31129986899239, 40.82277202606201, 42.82777200426374, 45.160403864724294, 46.36938694545201, 42.34464291163853, 33.8261444909232, 18.558982372283936, 5.6549369011606485, 1.3274273936237608, 6.157123599733625, 4.264613653932299, 7.13142215354102, 7.224734289305551, 3.8582295860563005, 6.3758785128593445, 1.1183118032557624, 0.6347126215696335, 0.4860992303916386, 4.31464980329786, 13.61962958744594, 32.93562167031424, 29.37906810215541, 34.696128436497276, 40.617588247571675, 19.806804146085465, 3.360613065106528, 0.07503825133400303, 0.04085890895553997, 0.03865551915285843, 0.031834827469927926, 0.03395509334014995, 0.012143205186086041, 0.0474532752830003, 0.05617617542988487, 0.07061249310416834, 0.015701242656047856, 0.022028354395713125, 0.013677685837527471, 0.011484140729797738, 0.03041271985109363, 0.018111863838774816, 0.09432987722435168, 0.009869757490897817, 0.036074748528855186, 0.030383057692753415, 0.03344091985906873, 0.03794508281030825, 0.03250658731641514, 0.05247442763564842, 0.06199546477624348, 0.07499297947755881, 0.031070087969835316, 0.095087074807712, 0.06410703861287662, 0.05341186108333724, 0.013105790230578609, 0.06353365616606814, 0.0297874566167593, 0.018882839075688804, 0.01772908527137978, 0.02219343857307519, 0.02730248835203903, 0.02687072125263512, 0.03178576938807964, 0.042043159516262155, 0.029673788430435315, 0.08605736826679536, 0.04871421047885503, 0.013502905394748917, 0.04497992693047438, 0.03984130998807294, 0.015684489626437426, 0.037068924467478476, 0.040829148409622054, 0.009108861043517078, 0.03186693574701037, 0.016731328364195566, 0.024352582803528224, 0.6295467444828579, 13.26854406084333, 34.84851632799421, 47.700710432870046, 42.21263408660889, 29.090420825140818, 24.02206083706447, 23.836326803479874, 18.195384877068655, 4.373096312795367, 0.489583317722593, 0.0964328200955476, 0.6693624194179262, 3.9549194148608615, 9.436737605503627, 6.981763601303101, 2.763191533940179, 2.7249944635799954, 9.577766929353986, 25.66515694345747, 38.85313490458897, 51.01877055849348, 51.969582898276194, 50.388867718832834, 48.60242680140904, 43.3883387701852, 42.147810867854524, 42.65717288425991, 46.992372853415354, 48.335282461983816, 48.3964752469744, 47.168662548065186, 47.68529238019671, 46.12318100248064, 47.840390069144114, 45.12396056311471, 44.83018377849034, 44.00087111336844, 44.97995219911848, 46.35764796393258, 45.23769562585013, 46.545322281973704, 46.579358032771516, 48.226814133780344, 48.181873185294016, 48.70412063598633, 46.07260506493704, 34.44994681222098, 34.40997729982649, 34.37554202760969, 34.1463418006897, 36.352519920894075, 42.98776817321777, 44.06851530075073, 44.84625496183123, 41.44382980891636, 41.085459096091135, 40.23707709993635, 44.77149929319109, 45.464557783944265, 49.874947684151785, 39.03764084407261, 37.309179169791086, 51.372492926461355, 43.40082468305315, 45.86046961375645, 41.137431621551514, 41.135399273463655, 37.334626947130474, 36.56699344090053, 34.502044405256, 36.42626462663923, 34.30785615103585, 35.88585805892944, 34.181454522269114, 35.17919152123587, 35.703860419137136, 35.34127214976719, 35.02557727268764, 35.099745818546836, 35.40227733339582, 41.30887494768415, 44.246187686920166, 46.85822398321969, 49.36530079160418, 46.71073109763009, 46.17719629832676, 46.73395892551967, 44.31582948139736, 36.618882587977815, 34.11047519956316, 36.63312292098999, 42.581812722342356, 46.40249858583723, 45.63811336244856, 44.86670698438372, 41.981721128736226, 42.882732255118235, 42.33417197636196, 44.220006874629426, 47.203236784253804, 48.168991225106375, 44.439754077366416, 35.00307205745152, 21.220133747373307, 6.821750930377415, 3.7892600297927856, 7.2344222494534085, 4.306603355067117, 8.776535408837454, 8.896487372262136, 5.373280814715794, 5.083940889154162, 1.255804494023323, 0.07908908503928355, 0.6859655199306351, 4.003734418324061, 15.3079080922263, 32.72725909096854, 32.142832211085725, 37.53091703142439, 45.44674955095564, 24.443637575422013, 5.333623102733067, 0.1724652677242245, 0.0406637080013752, 0.028838335403374264, 0.027369266375899315, 0.029044002760201693, 0.03789442338581596, 0.057378223964146206, 0.017751110518085103, 0.02559982516270663, 0.033589403677199564, 0.03169274902237313, 0.002716036155886416, 0.06255254881190402, 0.03181930598137634, 0.04349231014826468, 0.038896283733525445, 0.0327068162150681, 0.03088588946099792, 0.04941959173551627, 0.06632033841950552, 0.07154784005667482, 0.015982402122712562, 0.012688011978752911, 0.07843117069985185, 0.19961436305727276, 0.15587086603045464, 0.1596807451652629, 0.15678198928279535, 0.14033465326896735, 0.09401972565267767, 0.14512398413249425, 0.08948673853384596, 0.09891585792813982, 0.07887405050652367, 0.14073774378214562, 0.0972917979317052, 0.1077968499490193, 0.09982082686786141, 0.10322563416723694, 0.10072327165731362, 0.15753388750766004, 0.09075274238629, 0.07732296695134469, 0.15957131103745528, 0.11706364341080189, 0.12052053505820887, 0.15957756713032722, 0.10298132763377257, 0.12876279492463383, 0.05791130821619715, 0.1904632733868701, 0.09321919682302646, 0.7697696430342538, 13.947707891464233, 39.45041595186506, 54.66951043265206, 49.60367611476353, 37.932515961783274, 32.53207377025059, 27.337673459734233, 21.925071920667374, 5.817456568990435, 0.856298491358757, 0.38622601383498734, 4.587761342525482, 7.660441058022635, 12.04769171987261, 8.231464862823486, 2.996016549212592, 3.3638329037598202, 10.381769912583486, 25.407946790967667, 40.61171007156372, 52.94262947354998, 53.032494000026155, 52.33213642665318, 50.21426296234131, 45.912852082933696, 44.34280238832746, 46.12832266943795, 49.11107315335955, 51.37540422167097, 51.30650241034371, 49.58558995383126, 50.17448452540806, 48.83509070532662, 48.59028829847063, 45.75573941639492, 46.41027362006051, 43.380188533238, 44.702076366969514, 46.9860326222011, 44.34902102606637, 46.87410061700003, 48.13634511402675, 49.61341748918806, 50.831975187574116, 49.73779719216483, 48.696161474500386, 37.8079833984375, 34.761799335479736, 35.42854847226824, 34.632535048893516, 36.59757593699864, 43.71002994264875, 46.245010716574534, 45.16014330727713, 43.49887418746948, 41.76598998478481, 41.235112871442524, 45.938661166599815, 46.886152267456055, 51.05045781816755, 41.21736369814192, 40.34702886853899, 52.251783984048025, 47.72082894189017, 47.73308209010533, 42.4283652305603, 43.10465424401419, 39.60716731207711, 38.586845193590435, 36.228223596300396, 38.204958302634104, 36.113213539123535, 36.636524064200266, 35.560637201581685, 35.948287623269216, 36.28677953992571, 36.85014295578003, 35.83012308393206, 36.73541777474539, 37.32775517872402, 42.11284058434622, 44.6050934110369, 49.525783334459575, 50.38127333777291, 46.5006696837289, 46.208070618765696, 49.86385488510132, 46.68134716578892, 38.92121682848249, 34.96381820951189, 38.86285890851702, 44.0258012499128, 48.88658727918352, 47.61217301232474, 46.522830963134766, 44.65756968089512, 44.641158035823274, 44.03045654296875, 46.46945142745972, 49.25965690612793, 50.20917688097273, 45.90476090567452, 36.1409854888916, 22.205148594720022, 7.856806703976222, 3.4685251031603133, 9.62749605519431, 8.561689291681562, 14.462008340018135, 15.440337283270699, 9.895177142960684, 12.603047336850848, 2.9554657765797208, 0.9994361592190606, 1.3213530395712172, 5.664755140032087, 19.272164583206177, 44.10878358568464, 39.58171258653913, 44.5200127192906, 51.4619197164263, 28.723156418119157, 6.000682737146105, 0.2842113407594817, 0.16034594018544468, 0.12271581297474247, 0.18447493043329033, 0.13001043083412306, 0.12942902131804399, 0.18953395182532923, 0.13553758710622787, 0.20988632472498076, 0.15371579809912614, 0.08409077700759683, 0.07804323865899018, 0.17156425464366162, 0.0854234876377242, 0.1616261186344283, 0.1661684898925679, 0.1281782505767686, 0.09899685465331588, 0.11453273493264403, 0.11986207110541207, 0.17039166470723494, 0.08693330947841917, 0.11665536889008113, 0.12231108040681907], [0.04224966486383762, 0.06802240958703415, 0.028894891297178607, 0.05601917260459491, 0.03487126150035432, 0.03430131922609039, 0.0439366963026779, 0.025612490018829703, 0.05231304147413798, 0.008307774966981794, 0.03236681588792375, 0.07224838675132819, 0.027840095039989268, 0.07684456583644662, 0.020120989065617323, 0.01740796009211668, 0.06827765410499913, 0.05108701351231762, 0.007930213485711386, 0.05245255845199738, 0.09357642515429429, 0.023110863719401614, 0.04565702345488327, 0.042412618441241126, 0.02905243695048349, 0.032363253579075844, 0.029248299476291453, 0.03292034440008657, 0.06483469956687518, 2.7632540677274977, 14.589158637183052, 37.15815659931728, 38.55560956682478, 32.79813071659633, 23.36707673754011, 16.55290194920131, 15.769443920680455, 7.062717931611197, 1.4348075687885284, 0.0933444747435195, 0.6182484850287437, 3.9194688371249606, 9.65929274899619, 4.823313091482435, 2.085499418633325, 2.931718570845468, 5.851041121142251, 17.718472685132706, 31.830041681017192, 44.1691495350429, 51.49647658211844, 50.71885504041399, 45.3469352040972, 45.36564670290266, 44.7980066708156, 45.19610023498535, 47.10317925044468, 49.315975529806956, 47.18973643439156, 48.010447229657856, 47.51193829945156, 49.13541269302368, 46.18550981794085, 44.94386672973633, 45.931761605399, 46.266911438533235, 47.14399296896798, 43.52119180134365, 43.94065455027989, 43.66589845929827, 44.48660578046526, 44.31689255578177, 47.30781759534563, 46.86065237862723, 45.36744976043701, 42.8577743257795, 35.91886895043509, 32.254969188145225, 31.90629816055298, 32.558112144470215, 33.79842465264456, 33.08343069893973, 34.49078137534005, 33.527236461639404, 34.11015905652727, 35.72080707550049, 43.88292891638619, 43.59812920434134, 49.98055682863508, 37.927113737378804, 33.13052558898926, 50.411008153642925, 42.9987359046936, 46.0063088280814, 41.28412546430315, 38.376266138894216, 35.87860066550118, 34.537323883601594, 32.59466661725725, 32.713015283857075, 35.48537431444441, 33.887702056339805, 31.933295386178152, 33.82616880961827, 33.04121691840035, 37.192407744271414, 34.606336866106304, 35.01588453565325, 34.80612884249006, 39.53601081030709, 42.76825720923287, 44.78510386603219, 48.19292082105364, 48.09363453728812, 46.53519180842808, 44.748195035117014, 45.52641064780099, 37.366005011967246, 33.302524771009175, 33.71963555472237, 43.26416056496756, 46.92567014694214, 46.594216755458284, 46.379479203905376, 44.93974297387259, 43.74723754610334, 42.70900991984776, 44.058468205588206, 45.3437876701355, 46.10944093976702, 37.66759852000645, 28.172337974820817, 16.839454344340734, 4.616333203656333, 2.7768401844160895, 5.283236503601074, 2.8534138926437924, 5.253842149462018, 8.49432042666844, 5.227084636688232, 3.6978378040449957, 1.379581332206726, 0.2209150700696877, 0.8369189883981432, 6.060445061751774, 21.55166530609131, 29.630721432822092, 32.16003942489624, 35.38709551947457, 34.34912150246756, 13.355038711002894, 1.2910857094185693, 0.0757739529279726, 0.03952707363558667, 0.046104781928339174, 0.027281060216150115, 0.030287536925503185, 0.02492329860771341, 0.009893940478962446, 0.029079992257590805, 0.018696986637743454, 0.007105512270105204, 0.03848300162436707, 0.03686718922108412, 0.05596712896866458, 0.0773189907361354, 0.021073234932763234, 0.05020878903035607, 0.059538292698562145, 0.04299629765695759, 0.033797663037798235, 0.07249560420002256, 0.01663382288201579, 0.01482901642365115, 0.05829018181455987, 0.012662387951942427, 0.03785343987068959, 0.020844326055209552, 0.041575567464211156, 0.013716012039887053, 0.059543510632855554, 0.035484765722815476, 0.03987390002501862, 0.033132138928132396, 0.026115085996155227, 0.04952795038531933, 0.02922686455505235, 0.02342047755207334, 0.04935367884380477, 0.006147690541443548, 0.007760312557885689, 0.022971126217661158, 0.01651682478508779, 0.013157222336823387, 0.08446241063731057, 0.032748481657888205, 0.015205606751676117, 0.04112909820729068, 0.049029098224959204, 0.035314171841101985, 0.014835957836891924, 0.029911299435687915, 0.009819212569189923, 0.032957165102873526, 0.11685894296637603, 3.972477512700217, 19.890359708241053, 42.00434446334839, 42.399349553244456, 37.42252860750471, 25.698058400835308, 18.709143366132462, 20.117880208151682, 7.985053079468863, 1.165674633213452, 0.05320827343634196, 0.37928416633180206, 2.738475488764899, 8.732342260224478, 7.674363510949271, 6.486870339938572, 4.847474583557673, 7.452423283032008, 19.451810257775442, 33.62174238477434, 46.26458031790597, 53.175571305411204, 50.66196666445051, 48.43015316554478, 47.002593653542654, 46.406052589416504, 47.209146227155415, 48.78813477924892, 50.631717681884766, 49.00833708899361, 48.872979232243125, 48.91903189250401, 49.13699688230242, 47.79271500451224, 46.020048890795024, 46.443732670375276, 46.18993582044329, 46.21657868794033, 43.843470096588135, 43.8541772706168, 44.347006048474995, 45.329755783081055, 44.74910872323172, 49.15472173690796, 48.21461657115391, 46.916585377284456, 43.49725178309849, 37.543166705540244, 34.61978510447911, 34.02454335348946, 33.620251996176584, 34.87598950522286, 35.759699617113384, 36.454043524605886, 35.548321519579204, 37.150433676583425, 36.66458089011056, 43.34286281040737, 45.49415710994175, 50.46364770616804, 40.00807837077549, 35.96384463991438, 51.5304011617388, 45.61270032610212, 48.07539899008614, 42.582754203251426, 41.12262848445347, 37.3821039881025, 35.673865045819966, 35.36489602497646, 34.21142210279192, 35.93440859658377, 36.002473149980815, 33.15212059020996, 34.77448327200753, 34.036970206669395, 38.48979275567191, 36.972198486328125, 36.62053625924246, 36.39089829581124, 39.46494810921805, 44.91838421140398, 47.954284940447124, 48.53091246741158, 47.73196690423148, 48.22985397066389, 46.69702925000872, 47.116207122802734, 39.52080815179007, 34.62569802148001, 36.71802643367222, 44.75179072788784, 47.9167994090489, 48.28358786446707, 47.02160392488752, 46.72364779881069, 46.033830642700195, 44.18806600570679, 46.85589286259243, 47.887596130371094, 46.856636319841655, 41.673537254333496, 31.333207266671316, 19.50885844230652, 5.7187283124242505, 4.196384080818721, 6.004607600825174, 6.168609406266894, 9.440633807863508, 8.931892786707197, 5.2980144534792215, 3.570173991577966, 0.8389931342431477, 0.25374197001968113, 0.9654018197740827, 7.137840117727007, 23.70580836704799, 39.7704256602696, 37.4479729107448, 39.67131655556815, 40.50775459834507, 16.152871574674332, 1.9635622245924813, 0.07341740080820662, 0.020649320179862634, 0.01785229705274105, 0.03767913779509919, 0.04182863049209118, 0.016601519526115487, 0.028108725357534628, 0.04650513116004212, 0.0276349722075143, 0.12250264441328389, 0.024160396241183792, 0.06585712291832481, 0.0073655162871416125, 0.020120810950174928, 0.0293632908059018, 0.030996887612023523, 0.06975963565387897, 0.03267278429120779, 0.01120266574434936, 0.03429428281794701, 0.015800744727520005, 0.013281509596189218, 0.03869836863928607, 0.032813580307577334, 0.12196801310139042, 0.0948681929813964, 0.13907936348446778, 0.09019549550222498, 0.1400070022791624, 0.13577404298952647, 0.09925901344312088, 0.11759159793811184, 0.1152716867093529, 0.1165250087422984, 0.07782367151230574, 0.11424457468092442, 0.15854958657707485, 0.10444817785173655, 0.09892936077501092, 0.11267964222601481, 0.15287674883646624, 0.12837457789906434, 0.2067773315523352, 0.18436584914369242, 0.22622000612318516, 0.15685485037309782, 0.16074392811528274, 0.09737958000706774, 0.07683273897107158, 0.13710996987564222, 0.11116754729300737, 0.13300361164978572, 0.2057828027755022, 3.827352660042899, 19.986592258725846, 48.00062247685024, 50.636689117976594, 44.554215226854595, 31.93732534136091, 25.797756365367345, 21.55522452081953, 10.391665015901838, 1.7489832873855318, 0.47403569200209206, 2.099225802080972, 8.422913789749146, 18.155048847198486, 13.01807974066053, 6.429724446364811, 5.966754683426448, 8.26398069517953, 21.783446788787842, 34.57039730889456, 46.82936116627285, 53.72960329055786, 53.91270916802542, 50.087552138737266, 49.58378342219761, 49.6814785684858, 49.50127356392996, 51.97955008915493, 53.46311208180019, 49.657788685389924, 49.1898136138916, 49.92054871150425, 50.56154782431466, 48.23590932573591, 47.390862464904785, 48.14698280606951, 47.17051771708897, 48.646002428872244, 44.82990237644741, 43.94471229825701, 44.85387366158621, 44.3025792666844, 46.28209325245449, 50.04921892711094, 50.1180408341544, 48.65735578536987, 46.4718450818743, 39.58730241230556, 36.38820934295654, 35.059807573046, 35.468934876578196, 37.08317858832223, 36.150858879089355, 36.78619521004813, 36.5742369379316, 37.368329184395925, 39.770067828042166, 46.416412353515625, 47.71424552372524, 51.89665807996477, 42.49942445755005, 39.02386256626674, 53.038677896772114, 46.96979815619332, 50.11008167266846, 44.85028144291469, 42.20510918753487, 39.92256689071655, 37.74233681815011, 38.21586002622332, 35.28212213516235, 38.27297421864101, 37.41713680539812, 34.84861707687378, 36.80673408508301, 35.71839257649013, 41.08783885410854, 38.76763037272862, 38.47632367270333, 37.16388886315482, 41.694896016802105, 46.477837903159006, 48.35604020527431, 50.24456058229719, 48.316775935036794, 49.43772186551775, 48.422756808144705, 48.764201709202354, 40.72574043273926, 36.502663544246126, 37.641688687460764, 46.61959852491106, 49.77136741365705, 50.231810637882774, 49.10056747709002, 49.13559682028634, 48.21678440911429, 47.29955618722098, 47.63069690976824, 49.60927288872855, 49.19017839431763, 42.020040443965364, 34.59163795198713, 24.26149923460824, 9.078127179827009, 5.030593054635184, 10.423559853008815, 11.555846112115042, 15.679292781012398, 18.956822327205114, 10.95683148929051, 8.620605673108782, 2.778742470911571, 0.6238774486950466, 1.5034339491810118, 8.36018979549408, 28.332467896597727, 41.57629026685442, 44.3906546320234, 46.68066276822771, 44.667307581220356, 19.277370521000453, 2.3364394732884, 0.20651114226451942, 0.10483110908951078, 0.204158430652959, 0.10486281024558203, 0.07747599016875029, 0.07620263778205429, 0.11818710741187845, 0.08970799523272685, 0.0761330472305417, 0.1632403534437929, 0.10575771651097707, 0.15715077306543077, 0.10420178143041474, 0.15501965742026055, 0.08106234629771539, 0.09900665269898516, 0.14360808261803218, 0.09916504991373845, 0.08212044702044555, 0.10788662013198648, 0.1675633950425046, 0.10251862103385584, 0.135155178340418, 0.09033570119312831], [0.01847253573526229, 0.004593515411085848, 0.059918950844023905, 0.0016639693058095872, 0.008125064146172787, 0.05109835861782942, 0.029400959677462066, 0.027984358370304108, 0.02510479654717658, 0.06915953928338629, 0.03684238198080233, 0.07369700473334108, 0.030287533532828093, 0.03593332486759339, 0.06639236491173506, 0.054906795865723064, 0.08664361573755741, 0.06681387765066964, 0.0012370634857299073, 0.054373647152845345, 0.004079432684063379, 0.06484299126480307, 0.06224020557211978, 0.10108708856361252, 0.002472227709534179, 0.0424500837522958, 0.025539810436644723, 0.034126257191279104, 0.008989335403644612, 0.1882518870489938, 6.846352330275944, 30.34909221104213, 48.292954036167686, 38.83076865332467, 20.350245339529856, 25.525753498077393, 22.872611658913748, 13.955936295645577, 2.7233809615884508, 0.07498096940772873, 0.18128626367875508, 2.755789096866335, 7.253459445067814, 9.108668855258397, 3.644880371434348, 1.4937847469534193, 2.8589164316654205, 14.28498647894178, 28.908735854285105, 43.06953110013689, 47.10943957737514, 50.22644315447126, 48.97724390029907, 47.00849962234497, 46.321614606039866, 47.90187815257481, 49.068494592394146, 47.34377799715315, 46.78990929467337, 47.55259568350655, 48.46888937268938, 48.00569813592093, 48.451894078935894, 47.47636352266584, 46.689771856580464, 45.98414407457624, 47.07677609579903, 46.47969307218279, 48.78597388948713, 48.20221056256975, 46.117584228515625, 45.75888695035662, 44.605152470724924, 45.158423628125874, 46.78026519502912, 45.500573771340505, 39.986024788447786, 33.33261741910662, 32.539821011679514, 30.335407733917236, 32.8797025680542, 35.47683497837612, 35.65237774167742, 33.62849950790405, 35.990192208971294, 36.45957081658499, 45.17993177686419, 42.24916424070086, 47.00328499930245, 36.187180587223594, 32.22243077414376, 51.288308552333284, 44.83076047897339, 45.924872466496055, 40.90426744733538, 39.920242718287874, 36.821686608450754, 33.061345849718364, 30.51789174761091, 32.983397483825684, 35.163863795144216, 32.347342014312744, 32.93850517272949, 36.06171696526663, 42.775344371795654, 43.782371112278526, 43.196026529584614, 43.66029126303536, 43.38651139395577, 44.05827365602766, 43.479471342904226, 45.557802609034944, 45.60746833256313, 46.67682041440691, 46.951673780168804, 43.757638999394004, 44.8619578906468, 37.7820805140904, 33.481187275477815, 35.01019048690796, 40.965449810028076, 44.42565965652466, 46.60126570292881, 48.531020164489746, 45.838912827628, 47.558091708592, 46.23566191537039, 44.754111426217214, 47.155172620500835, 40.11420168195452, 30.924865109579905, 17.405475446156093, 8.545532124383108, 3.018247093473162, 6.067871817520686, 7.031281675611224, 4.875296907765525, 7.314361708504813, 5.08002210514886, 3.0796971789428165, 2.291943426643099, 0.4852362424135208, 0.40983547696045464, 2.9398407978670935, 10.406213675226484, 16.012504066739762, 15.8107978616442, 27.638721534184047, 34.92171560014997, 26.09868632044111, 8.490289602960859, 0.4041056829903807, 0.08907695766538382, 0.04160315330539431, 0.011554543826995152, 0.020858867060659186, 0.03427864937111735, 0.05247626985822405, 0.05295676764632974, 0.07115021175039665, 0.026664003862866333, 0.009421885362826288, 0.027982867289600626, 0.0185114649856197, 0.08930409726287637, 0.041194156144878695, 0.009573442096422826, 0.032090055024517436, 0.030574787940297807, 0.006782719166949391, 0.06269103780921016, 0.027008643673200692, 0.036357287117945294, 0.016002610591905456, 0.011071159720553883, 0.017321195819282105, 0.06851133478007146, 0.02019404523473765, 0.07573938156877245, 0.056571645994803736, 0.0375036211418254, 0.03475820060287203, 0.05727900178836925, 0.06735496861594063, 0.025811132841876576, 0.023840180298845683, 0.0334346094833953, 0.05893612001091242, 0.015501524354996426, 0.054129815593894036, 0.029527767694422176, 0.013980578780839486, 0.020664943448667015, 0.0644084167267595, 0.025937784795782397, 0.027922504814341664, 0.013567942128117596, 0.04412460300539221, 0.025660352182707617, 0.04402348771691322, 0.027641070540994406, 0.03155219049326011, 0.03412965665172253, 0.04665896861947008, 0.02888755633362702, 0.46358657841171536, 10.003361463546753, 37.651586396353586, 52.74798958642142, 43.05812563214983, 22.07379116330828, 23.855535098484584, 23.760362148284912, 13.714228442737035, 2.837565051657813, 0.07051041429596287, 0.28906039627535, 2.8705333854470934, 7.492698516164507, 8.606896008763995, 6.189748431955065, 4.461647195475442, 4.588419684341975, 15.32064414024353, 30.58123847416469, 44.51475988115583, 50.43536506380354, 53.3564190183367, 50.46663195746285, 48.279637813568115, 48.71487644740513, 48.73414032799857, 51.44360426494053, 47.92214952196394, 48.29552139554705, 47.899053709847585, 48.754634039742605, 49.92493997301374, 49.6436699458531, 49.837955474853516, 48.572747571127756, 47.67556142807007, 48.77843509401594, 49.56808049338204, 48.86007642745972, 48.89000579289028, 46.70925113133022, 45.0032182421003, 45.520570686885286, 47.61081116540091, 49.497021266392295, 47.530809606824604, 39.68707159587315, 34.05465337208339, 34.023250988551546, 32.709360531398225, 35.243542262486045, 35.836758613586426, 36.30796112333025, 34.942494188036235, 37.58509908403669, 38.11244303839547, 47.24690273829869, 45.284547328948975, 49.9706243787493, 39.57609844207764, 33.65684468405587, 52.63986866814749, 47.48173795427595, 47.251412119184224, 42.960704939705984, 40.90324606214251, 39.05428525379726, 34.47991786684309, 32.853886536189485, 34.071787629808696, 36.66434465135847, 34.77613694327218, 35.00028582981655, 38.549644538334434, 44.210255077907014, 46.26912791388375, 44.50657837731497, 43.29811641148159, 44.205728326525005, 44.55857869556972, 45.75726107188633, 47.635810783931184, 47.10459668295724, 46.36165360042027, 48.52355432510376, 46.85105344227382, 46.4952883039202, 38.54899835586548, 36.131657532283235, 36.348576818193706, 42.872869287218364, 48.10163191386631, 48.90995407104492, 50.7961676461356, 48.917322635650635, 48.74420131955828, 48.25363418034145, 47.35740341459002, 47.90902437482561, 44.04746573311942, 33.73816292626517, 23.32662432534354, 11.60069933959416, 3.0075948536396027, 1.3295044707400459, 5.638135288442884, 4.591803022793361, 5.080874128001077, 6.011647863047464, 1.5223808182137353, 0.5835238311971936, 0.29005729992474827, 0.33755217279706684, 2.766352095774242, 11.298798373767308, 21.73461311204093, 19.53286967958723, 32.31197568348476, 40.08527980531965, 31.336754322052002, 11.075861079352242, 0.61131651699543, 0.03537016115816576, 0.015488903603649564, 0.024419325204300027, 0.043624495555247576, 0.03430419621456947, 0.022091685461678674, 0.04029944326196398, 0.0505866007214146, 0.10163619302745376, 0.024619012971275618, 0.024675494226227914, 0.052450879077826223, 0.012879250288408781, 0.06356784076030765, 0.010524053542342569, 0.03318537000034537, 0.007265424738372011, 0.017724873265251517, 0.005223923213114696, 0.014986936967553837, 0.021489858826888458, 0.06431486710373845, 0.04843519348651171, 0.04144325652824981, 0.17369884438812733, 0.08516274020075798, 0.12121606059372425, 0.1485805500830923, 0.10598779416510037, 0.09393422345497779, 0.17419565415808133, 0.2582789265683719, 0.0876470333231347, 0.11903500477118151, 0.14723151390041622, 0.21171709362949642, 0.16837007818477495, 0.09363648907414504, 0.1162355864154441, 0.10743201524019241, 0.15509154142013618, 0.20429791031139238, 0.10636139554636818, 0.1501794092889343, 0.1224310996809176, 0.16502720756190165, 0.19464496257049696, 0.1440974013613803, 0.0733149488057409, 0.13853392989507743, 0.12397256839488234, 0.1448928208223411, 0.16863712242671422, 0.6131951361894608, 12.256200211388723, 41.32652684620449, 60.09704712459019, 50.011174065726145, 29.694634437561035, 34.362041677747456, 30.844033241271973, 17.958089998790197, 4.096667008740561, 0.14165452601654188, 0.8432915721620832, 5.166111154215677, 13.283215182168142, 18.23031520843506, 12.284918853214808, 3.48262625506946, 3.6421592831611633, 15.657657827649798, 30.05941833768572, 47.838736397879465, 50.61643859318325, 56.07283810206822, 52.565199851989746, 52.15474544252668, 49.41766241618565, 52.18249307359968, 52.77497638974871, 50.17148290361677, 48.42476831163679, 49.48090491976057, 50.95744923182896, 52.00102002280099, 51.73629713058472, 51.95217418670654, 51.04567745753697, 48.683501856667654, 50.37007631574358, 50.33049937656948, 50.64146947860718, 51.9753394808088, 47.46499626977103, 46.404054982321604, 44.63610322134835, 47.821748052324565, 49.738575390407014, 49.239406381334575, 43.35092966897147, 37.26893867765154, 35.62086418696812, 32.85616554532732, 36.613824299403596, 40.031413895743235, 38.191659450531006, 37.347818102155415, 39.41490718296596, 39.95739473615374, 49.69479826518467, 47.00446966716221, 50.00428145272391, 41.977423667907715, 37.78364385877337, 52.743400301252095, 49.737831933157786, 49.01883234296526, 45.18828698566982, 42.79927396774292, 39.907697745731895, 36.73298590523856, 33.32238967078072, 34.945016384124756, 37.171014240809846, 35.62082249777657, 35.906654017312185, 38.86935894829886, 45.44271264757429, 48.45487833023071, 46.30810035978045, 46.77845866339547, 46.6460086277553, 46.546413149152485, 46.94663633619036, 49.47261919294085, 47.24423115594046, 46.96823481151036, 48.288024289267405, 47.797728129795615, 49.137868881225586, 40.38904809951782, 38.124942847660606, 38.006152970450266, 44.54030840737479, 48.78950704847063, 49.528329849243164, 51.899447781699045, 49.52457087380545, 51.81760147639683, 50.72036279950823, 48.87393460954939, 50.226272923605784, 44.34721449443272, 35.27971111025129, 23.45209836959839, 12.31264477116721, 4.85556662934167, 10.53675295625414, 17.101104395730154, 10.849112698010035, 17.441649505070277, 11.445917793682643, 10.818969675472804, 7.453127656664167, 1.6161290620054518, 1.00129035115242, 4.128135400159018, 14.130905832563128, 24.433873619352067, 23.822668382099696, 39.180207456861226, 45.84643772670201, 34.72687074116298, 11.913440363747732, 0.6928862514240401, 0.172805200197867, 0.09639374326382365, 0.13584716192313603, 0.19204932185156004, 0.12491201369890145, 0.11783230145062719, 0.13969836384058, 0.14145665163440363, 0.22433974487440927, 0.13985059995736393, 0.12574974660362515, 0.09916993536587272, 0.21377492749265262, 0.18412309645542077, 0.14003946339445456, 0.093134983841862, 0.07241075339594058, 0.10354488489351102, 0.13386168703436852, 0.07688766638083117, 0.12054583084370409, 0.11798563679414135, 0.2025000232138804, 0.15130778588354588], [0.02280463577647294, 0.07059538045099803, 0.015724165265315344, 0.011750747316649981, 0.069868357319917, 0.013083177202913378, 0.022461054480767677, 0.056011311776403866, 0.0036782679380849004, 0.04322563570791057, 0.021548543624313812, 0.013318030895399196, 0.0381835742986628, 0.048492767182844024, 0.04344797467014619, 0.08824607117899827, 0.03341017204469868, 0.015805770975670645, 0.007036549363484872, 0.034866274267967255, 0.0509586075453886, 0.024650081393441985, 0.025940873826454793, 0.005872419062403164, 0.08767817129514047, 0.05437549616077116, 0.0568250890022942, 0.07853630970099143, 0.03628539972539459, 0.04853323840403131, 2.270501720053809, 15.552251917975289, 38.93427249363491, 42.16845743996756, 27.81624800818307, 22.502727781023296, 24.06503197125026, 20.427634375435964, 3.9580400245530263, 0.5927046814135143, 0.015729932812973857, 1.7019705814974648, 5.356435775756836, 6.786361583641597, 7.092562181609018, 2.1368822157382965, 2.7205680268151418, 9.493546945708138, 22.688595567430767, 28.602603435516357, 44.84231880732945, 48.704957893916536, 49.81049966812134, 47.839618819100515, 49.290541648864746, 49.97496352876936, 47.29536989756993, 48.0278559412275, 49.42819588524954, 48.23671531677246, 45.467208521706716, 45.146486622946604, 45.11968742098127, 44.13285561970302, 45.12369653156826, 45.53022868292672, 44.81063502175467, 44.08639301572527, 46.85481936591012, 47.246284348624094, 47.64401313236782, 46.96836335318429, 45.314945697784424, 44.40253605161394, 46.9312356540135, 44.23054729189192, 44.278455121176584, 34.37815455027989, 32.72183949606759, 34.437860420772004, 34.38622835704258, 37.370344161987305, 37.901287283216206, 36.6776122365679, 38.88858808789934, 38.67436817714146, 46.32900748934065, 44.04798337391445, 51.2309581211635, 36.671741008758545, 31.285740647997173, 48.687986918858115, 41.848975794655935, 47.166046551295686, 41.66694688796997, 39.05506345203945, 35.07055991036551, 34.26505524771554, 33.81170960835048, 35.15874644688198, 33.04205765042986, 33.92144250869751, 36.440939222063335, 42.14880446025303, 44.55504901068551, 44.775737694331575, 46.49283558981759, 43.74006700515747, 42.89461714880807, 44.58489499773298, 45.853861876896445, 47.2491261618478, 45.05020196097237, 45.322053704942974, 45.018903800419395, 44.813768659319194, 45.378077030181885, 39.02791684014456, 31.352082048143657, 33.04731396266392, 40.71312945229666, 43.81593785967146, 46.57365008762905, 47.85475894383022, 44.37260321208409, 47.81724909373692, 47.46662214824131, 47.33506495612008, 44.67722266060965, 37.37777526038033, 25.020543030330114, 11.94066514287676, 4.501855117934091, 2.629689931869507, 0.6159502054963792, 2.1839751516069685, 3.7493647762707303, 4.703246917043414, 6.1743451442037305, 1.980398144040789, 0.760456559913499, 0.49680477593626293, 0.6536021679639816, 5.482384034565516, 11.998407278742109, 22.852032831736974, 26.89357587269374, 34.45102378300258, 32.99666506903512, 15.038559436798096, 2.254435096468244, 0.030595880201352493, 0.04067291572157826, 0.018473422919799174, 0.004716738642725561, 0.04156358453578182, 0.03768413181283644, 0.06124215519854, 0.03691939231274383, 0.006057387708486723, 0.04702699583555971, 0.044496772677770684, 0.026581375260970423, 0.04065510078466364, 0.0129177342501602, 0.04569605618183102, 0.027354832239715115, 0.028543396586818353, 0.03196796282593693, 0.021121872322899953, 0.043367473275533745, 0.04216073267161846, 0.004226394463330507, 0.07365988208247082, 0.07220036004270826, 0.055746001191437244, 0.02460789347865752, 0.03058682515152863, 0.03336988063529134, 0.012490599848596113, 0.07600907888263464, 0.02434676097306822, 0.043796507575150044, 0.01887567713856697, 0.055913589163018126, 0.04912109061011246, 0.030731502388204848, 0.043785023369959424, 0.04060498418818627, 0.03692537359893322, 0.035223899542221, 0.014206100920481341, 0.036607334057667425, 0.015642003156244755, 0.04471721852730427, 0.042123379318841865, 0.05098233252231564, 0.016373782817806517, 0.017551984238837446, 0.016229799383186867, 0.0404431637642639, 0.01808321609028748, 0.02496323548257351, 0.0246616198814341, 0.08399812305080039, 0.048327469266951084, 3.2413967422076633, 21.879095690590994, 46.02431855882917, 45.26240342003958, 30.503036499023438, 25.085915156773158, 26.54570041384016, 20.813177755900792, 4.2048057317733765, 0.5264430227024215, 0.10131699658398118, 1.1766653805971146, 3.717283206326621, 5.806476243904658, 7.805262361254011, 4.122686275414058, 4.359540377344404, 11.821360230445862, 26.79227982248579, 34.1089118548802, 48.26096452985491, 52.62646906716483, 50.781809193747385, 50.53229243414742, 50.0816079548427, 51.79522827693394, 48.06325353894915, 47.5772374698094, 50.66008022853306, 49.700040681021555, 48.7827707699367, 47.174797807421, 47.36083582469395, 45.762409687042236, 46.44817951747349, 47.60354682377407, 47.5370317186628, 46.33263097490583, 49.427726881844656, 48.98361192430769, 49.18080527441842, 47.89826856340681, 46.719888823372976, 45.14345373426165, 47.91489560263497, 46.03722136361258, 44.73763377325875, 35.120437553950715, 34.10662242344448, 34.339161259787424, 35.10235486711775, 38.109114851270405, 39.22774355752127, 37.364719595227925, 39.29101732798985, 40.44482476370675, 46.25559977122715, 46.35828719820295, 52.46401671000889, 39.303697790418354, 34.65077059609549, 49.59819746017456, 45.349033560071675, 47.706574712480815, 43.77399853297642, 39.43173571995327, 36.94310985292707, 35.823654311043875, 34.68498352595738, 35.782458441598074, 34.42463452475411, 35.89112826756069, 37.39341218130929, 42.50855786459786, 46.6554651260376, 47.23402772630964, 48.30744103022984, 45.67095749718802, 44.96915122440883, 47.435323987688335, 48.23951891490391, 48.8149721963065, 46.69510112489973, 44.84616463524954, 47.30931493214199, 47.58405365262713, 47.36032165799822, 40.32471472876412, 33.83147028514317, 35.186636516026084, 44.088178702763145, 46.26403488431658, 47.45025566646031, 48.37309455871582, 46.45579821722848, 48.64541530609131, 49.259882722582134, 48.03159407206944, 47.46647276197161, 39.77243716376168, 27.563785212380544, 12.897065571376256, 5.397233426570892, 4.77987425667899, 3.9203781826155524, 3.2732857167720795, 2.418297503675733, 4.6542490891047885, 1.5276230169194085, 0.3064368910023144, 0.24609792019639695, 0.04159646973546062, 0.9043123892375401, 6.412048663411822, 15.67938310759408, 24.601422480174474, 25.7131290435791, 36.422536918095176, 39.57675157274519, 19.211082969393047, 3.576670774391719, 0.011779666479144777, 0.0363737008800464, 0.02234003267117909, 0.035444735549390316, 0.02188196894712746, 0.04621162065970046, 0.01730555049808962, 0.03725526036162462, 0.042322464885988405, 0.025374125755791153, 0.017409965163096786, 0.07150925855551447, 0.038777960796973536, 0.042385860412780724, 0.011634676268191209, 0.014720812140564834, 0.048961122586791, 0.0796920448275549, 0.012085366012927676, 0.02708729266721223, 0.04996883190636124, 0.016675900534859726, 0.08869762944855861, 0.018476722296327353, 0.04249782208353281, 0.08520557611648526, 0.1784851761268718, 0.09192492520170552, 0.06676282467586653, 0.17717739487332956, 0.14655787790460245, 0.1059897347752537, 0.11555687497769083, 0.13102025379027638, 0.17192097407366547, 0.09795902177159276, 0.12170106385435377, 0.0862746758918677, 0.08805440539228064, 0.10592711277838264, 0.12342006447059767, 0.15310538799635, 0.08045830763876438, 0.09891289273010832, 0.1126915505155921, 0.11092991754412651, 0.12489692308008671, 0.13107901492289134, 0.11145552434027195, 0.21899979641394957, 0.09602283566657986, 0.09477513868893896, 0.17505465235028947, 0.1883653381041118, 0.23527137828724726, 4.175586385386331, 24.837749821799143, 50.576278005327495, 51.507805619921, 37.139097690582275, 32.19028493336269, 32.6611921446664, 24.982418264661515, 5.510998453412737, 0.8791557305625507, 0.37355464377573555, 3.6106904574802945, 12.518936787332807, 16.183150087084087, 12.905465943472725, 7.278784326144627, 5.505277480397906, 14.236947502408709, 29.66919708251953, 36.99918876375471, 51.98107521874564, 53.21236549104963, 51.91667584010533, 53.005319595336914, 52.0817164012364, 53.918208667210166, 48.50202880586897, 49.64583430971418, 53.11126225335257, 51.62461873463222, 49.8490343775068, 49.089033467429026, 49.14334058761597, 48.607106413160054, 50.14308214187622, 50.48530871527535, 49.015816824776785, 47.32233933040074, 50.45589699063982, 51.60916246686663, 49.90113197054182, 50.448292187282014, 47.050838470458984, 45.505444458552766, 49.42134843553816, 47.56913239615304, 47.02090563092913, 37.929378850119456, 35.020932401929585, 36.560323170253206, 36.60939482280186, 40.47873197283064, 39.834484577178955, 39.32109955378941, 41.21638052804129, 42.71926893506731, 48.142244134630474, 49.748017992292134, 54.399927275521414, 41.13996076583862, 38.01182617459978, 49.76070540291922, 46.70256349018642, 49.3656655720302, 46.8123311315264, 41.427814211164204, 39.1924467086792, 35.33505351202828, 37.984731674194336, 37.984894956861226, 35.57356085096087, 37.91534348896572, 39.000829287937705, 44.492244243621826, 47.82159171785627, 48.863359451293945, 50.93893575668335, 47.788108348846436, 47.17153910228184, 48.5992306300572, 50.681546688079834, 49.680384227207725, 46.78768239702497, 44.0968222618103, 46.68427930559431, 48.05049664633614, 49.34284768785749, 43.30496733529227, 35.70633397783552, 36.23012045451573, 44.95746782847813, 47.3329770224435, 49.26976306097848, 49.207121576581685, 47.41539308003017, 51.00199065889631, 49.66310405731201, 47.390400409698486, 47.60696881158011, 38.860496520996094, 27.367102554866246, 13.87371391909463, 6.428480718817029, 4.34720732484545, 4.406415964875903, 7.389510818890162, 6.521831503936222, 11.166275382041931, 16.36176221711295, 6.658072216170175, 1.7664475845439094, 1.2699910870620181, 1.4789202702896935, 7.787215283938816, 17.585831574031285, 33.64582484109061, 35.5895208631243, 44.445646149771555, 44.167763369424, 21.184963703155518, 3.986693961279733, 0.22198396628456457, 0.15700287957276615, 0.08835984114557505, 0.18116304171936853, 0.1265411219958748, 0.08815649777118649, 0.15891471984130995, 0.10379027708300523, 0.18330437610191957, 0.10760735547436134, 0.13088225333818368, 0.10594807951045887, 0.176977579881038, 0.1451769234346492, 0.143910804231252, 0.190778914306845, 0.13020313477941922, 0.20595212440405572, 0.12470401557428495, 0.143378154241613, 0.1064524074484195, 0.09297813368695122, 0.1835812455309289, 0.13241677385355743, 0.12964562326669693], [0.021552304404654672, 0.02428211354916649, 0.06189077360821622, 0.03171639257509794, 0.08361129702201911, 0.0074255802069923705, 0.07880022589649473, 0.035736532748809884, 0.05613101213904364, 0.021797265724412034, 0.0385846461701606, 0.0260323403469686, 0.015507349578131522, 0.024002558817820888, 0.04149380399446402, 0.04754696739837527, 0.012986370611802807, 0.020559231085436683, 0.06678750977984496, 0.02282322254697127, 0.03165054075153811, 0.03280579072556325, 0.0391142393595406, 0.010019964787976017, 0.050185264221259525, 0.06022179459354707, 0.06663145351090602, 0.059231540587331565, 0.06815931081239666, 0.049780321307480335, 0.45999186273132053, 9.090832829475403, 32.364365100860596, 40.37911912373134, 28.80608490535191, 21.770563091550553, 19.467327322278702, 18.31591006687709, 6.461072112832751, 0.7665387306894574, 0.11933033035269805, 0.6484765144331115, 2.399843739611762, 6.136708923748561, 3.66902015038899, 3.641867675951549, 1.5172309002705981, 5.347315830843789, 12.966529318264552, 23.940146786826, 35.627524035317556, 48.77172313417707, 52.99420247759138, 49.441772665296284, 50.17109033039638, 46.51916926247733, 48.97264071873256, 50.29506703785488, 46.41178485325405, 46.60840150288173, 44.973198550088064, 43.3593613079616, 40.44266734804426, 40.02219363621303, 40.59383235658918, 41.33881820951189, 41.975287096840994, 43.85854768753052, 44.21711989811489, 45.7356903893607, 47.430119786943706, 46.827353136880056, 45.834448610033306, 44.739937101091655, 45.81838437489101, 46.07837554386684, 44.364779540470664, 37.29185731070382, 34.32115152903965, 39.62447527476719, 37.41447564533779, 34.877733503069194, 34.542736530303955, 35.19050318854195, 38.298394203186035, 40.57211576189314, 46.22160223552159, 44.357372760772705, 46.85789394378662, 36.96893630708967, 30.851756164005824, 48.224052224840435, 44.616005556924, 44.19929429462978, 42.62582608631679, 37.48316553660801, 35.08411931991577, 33.691759381975444, 35.4067519732884, 34.531407492501394, 32.78781958988735, 35.354661328451975, 39.27689511435372, 45.819860867091585, 46.33739396503994, 46.25324085780552, 44.42453752245222, 45.55776786804199, 45.77183491843087, 45.34183522633144, 46.935126645224436, 48.240894658224924, 45.82671873910086, 43.95849405016218, 45.60224676132202, 44.17339835848127, 43.75731938225882, 39.65093054090227, 33.936916146959575, 32.05384315763201, 36.90869542530605, 41.727670669555664, 44.54260131290981, 46.23553684779576, 46.09710093906948, 45.02819006783621, 44.767841066632954, 44.519752161843435, 40.52482632228306, 28.56839919090271, 14.942434583391462, 3.6525438002177646, 2.310680329799652, 0.915441232068198, 2.807844566447394, 0.5718492290803364, 1.3863712421485355, 3.1129879525729587, 0.844899483025074, 0.21565398094909533, 0.031429938838950226, 0.24388041347265244, 2.008938955409186, 8.991288593837194, 18.200887850352697, 22.61288104738508, 34.30632407324654, 34.24893542698452, 28.178474971226283, 10.414861576897756, 0.574988240642207, 0.09103364231331007, 0.031271036115608046, 0.05674477081213679, 0.04657191936192768, 0.01259805604682437, 0.06511330604553223, 0.03243724782285946, 0.046673367132565806, 0.05875417763101203, 0.027096890545051013, 0.05853393194930894, 0.0310943422040769, 0.051201852171548774, 0.12067586529467787, 0.031566273487572155, 0.04526871143441115, 0.03794090642726847, 0.05528171021225197, 0.01916755915486387, 0.07123730850539037, 0.008470189957214254, 0.11433962386633668, 0.024198701239324043, 0.0013627657026518136, 0.06341548929257051, 0.04141285815941436, 0.021988144410508018, 0.06498913413711957, 0.05178252886980772, 0.02662169381177851, 0.03258987748995423, 0.05260030945230808, 0.026127216505951116, 0.031016602446990352, 0.02144903816016657, 0.012341548605555934, 0.01905876793898642, 0.03517002386174031, 0.02693150102693055, 0.06149391883185931, 0.022536354904462184, 0.05056390033236571, 0.04862826723339302, 0.049159526226243803, 0.049912883301398585, 0.05143590604088136, 0.05262982572561928, 0.06923805935574429, 0.03950448181214077, 0.021840976950313364, 0.034293543214776685, 0.0385909701165344, 0.05253169259854725, 0.032347803336701224, 0.031085555175585405, 0.7823880059378487, 12.076302664620535, 40.09405190604073, 45.95743519919259, 31.521725790841238, 22.197298867361887, 19.882178204400198, 22.310514552252634, 8.623903461865016, 1.134385266474315, 0.1297827416232654, 0.4693575458867209, 2.1660375084195818, 4.248485582215445, 3.375503271818161, 6.548407060759408, 1.628837751490729, 7.583946602685111, 18.644297565732682, 27.360209941864014, 38.8734792300633, 52.20288603646414, 54.641748905181885, 50.48478760038103, 51.14722885404314, 47.8559262411935, 49.57747793197632, 52.65424449103219, 48.420748778751914, 47.8609219959804, 47.60963691983904, 46.09912633895874, 43.701653889247346, 44.02724300112043, 41.885804721287315, 43.90219974517822, 45.30903278078352, 46.21821846280779, 45.94895839691162, 47.06303603308541, 49.64517423084804, 49.29108708245413, 47.30619171687535, 45.04009233202253, 46.08290924344744, 48.85513278416225, 45.79193953105381, 38.93341786520821, 34.98344687053135, 40.223403045109336, 37.80504778453282, 36.35723774773734, 35.80291393824986, 37.43338516780308, 39.45673533848354, 42.61217287608555, 47.31292104721069, 46.20054571969168, 48.04256527764456, 40.03133051736014, 33.871262618473594, 50.328171730041504, 46.08428498676845, 45.869596072605674, 44.78252608435494, 38.56438166754586, 37.06772926875523, 35.60217700685774, 36.66268055779593, 37.17084053584507, 33.786602292742046, 36.65861586162022, 40.307114941733225, 46.68868098940168, 48.23259850910732, 47.0038616997855, 46.17786679949079, 46.80247858592442, 45.29868343898228, 46.00755255562918, 48.93521077292306, 47.135696819850374, 45.57366534641811, 46.51744958332607, 46.2839275768825, 45.76753398350307, 44.85544742856707, 41.2018483706883, 35.0031623840332, 34.774128913879395, 40.374481201171875, 44.43456724711827, 47.09959397997175, 47.50814458302089, 46.220108372824534, 47.299458912440706, 46.72705241612026, 47.534144742148264, 42.96595777784075, 31.665595190865652, 18.66843387058803, 5.807902795927865, 2.2720657161303928, 2.049793928861618, 1.9812336649213518, 1.0368020513228007, 0.48805373694215504, 0.9545258262327739, 0.04333779076114297, 0.11262953920023781, 0.04463070870510169, 0.15348407839025768, 2.0384483890874043, 9.793544105121068, 20.737650837217057, 28.72898943083627, 39.36041940961565, 39.56119108200073, 33.19982344763619, 11.390153288841248, 0.9530748469488961, 0.05830204939203603, 0.019043202345658625, 0.06416120606341533, 0.03171583617638264, 0.004063036733506513, 0.04714545447911535, 0.04941994796640106, 0.018280506932309697, 0.0390384334272572, 0.021870143778089966, 0.034566935151815414, 0.09246153783585344, 0.024955003156459758, 0.059065604848521094, 0.027378119561555128, 0.058733936931405745, 0.04248064496953573, 0.04256959751780544, 0.019656431761437228, 0.06165900640189648, 0.02060907117889396, 0.020365433002422963, 0.04203142086043954, 0.004941332885729415, 0.027142058924904892, 0.0983128777838179, 0.08160951693675347, 0.10620635707995721, 0.10573257678853613, 0.16895363187151297, 0.13315495210034506, 0.194829293393663, 0.07762756810656615, 0.1272155993751117, 0.11487615507628236, 0.15173337661794253, 0.11596547519522053, 0.18831167955483707, 0.12143505098564283, 0.13325199617871217, 0.09553206485829183, 0.09778193770242588, 0.10448723432740994, 0.1915000206125634, 0.1326976330684764, 0.1556341658745493, 0.15118996506290777, 0.17340820069823945, 0.12662322473313126, 0.14818225002714566, 0.14361306306506905, 0.13331986325127737, 0.15572073337222847, 0.11217257979192904, 0.17163444230599062, 1.3073415628501346, 14.036053368023463, 46.024130957467214, 51.61252539498465, 39.174211161477224, 30.271637167249406, 28.5583781514849, 26.857235057013376, 9.703454630715505, 1.3329451318298067, 0.5422882267407009, 2.001003678355898, 6.838875200067248, 13.486871225493294, 9.889426640101842, 11.140283908162798, 4.576612957886287, 7.672591720308576, 18.71810827936445, 27.256678308759415, 39.094067164829795, 51.515174184526714, 55.41766813823155, 50.46552719388689, 50.42333425794329, 49.02290398733956, 50.58686705998012, 54.72847284589495, 50.098384380340576, 50.58929198128836, 49.01627887998308, 47.62208114351545, 43.96297911235264, 44.74677412850516, 43.89913558959961, 45.21839005606515, 45.4423200743539, 47.10730995450701, 46.99473524093628, 49.70362595149449, 52.550250802721294, 50.69889981406075, 48.174299648829866, 45.38753700256348, 46.91858645847866, 50.40075956072126, 48.13601507459368, 41.37729038511004, 37.27826663425991, 42.935538564409526, 39.36777407782418, 38.03331000464303, 37.05486815316336, 39.727114064352854, 40.7097178867885, 44.85850811004639, 50.327674933842246, 48.25725071770804, 48.53006131308419, 41.92404065813337, 36.20737900052752, 49.75371898923601, 48.66433872495379, 47.8543107850211, 47.0558967590332, 39.74212564740862, 38.094568797520225, 36.19177334649222, 38.07668760844639, 37.82281085423061, 35.01288986206055, 38.380594866616384, 42.7812260219029, 49.64887067249843, 48.67473670414516, 48.26452200753348, 47.53979710170201, 47.301484312329976, 47.97632810047695, 47.091520173209055, 48.86792441776821, 47.92815276554653, 44.95750604357038, 46.39153780255999, 47.64406871795654, 45.42974383490426, 46.821582657950266, 43.03673907688686, 36.718210560934885, 34.988602433885845, 41.68163537979126, 45.42246559688023, 48.01339673995972, 49.93122114453997, 46.9247008732387, 47.64586135319301, 45.98997361319405, 46.820245129721506, 43.39798981802804, 31.725735323769705, 17.718903473445348, 5.611973149435861, 3.7883750029972623, 6.26705539226532, 10.32762781211308, 3.403156016554151, 2.4075412579945157, 6.601218146937234, 2.9920334943703244, 0.6108144010816301, 0.0981233154556581, 0.40463849582842415, 3.6839922155652727, 12.89848734651293, 25.78490219797407, 33.77855627877371, 45.57573938369751, 44.46398939405169, 36.32859032494681, 14.393520815031868, 1.3934466796261924, 0.1405622474849224, 0.0764097198843956, 0.14788944859589848, 0.1599882843771151, 0.05884461956364768, 0.12131104192563466, 0.12766732727842672, 0.11541522400719778, 0.17265259767217295, 0.0918500352916973, 0.13750858205769742, 0.18054174791489327, 0.1789133995771408, 0.24990252032876015, 0.10951006266155414, 0.10001777844237429, 0.1500643976032734, 0.17976565313126358, 0.10329448511557919, 0.09581153307642255, 0.11655600422195025, 0.1771793897662844, 0.11313252363886152, 0.08281274272927217, 0.13600277714431286], [0.026985302068559185, 0.028694903278457265, 0.04847263844151582, 0.040412158106586764, 0.019525983404102068, 0.08678245078772306, 0.042179405955331664, 0.019685968390798995, 0.03128306654148868, 0.05731729830482176, 0.013793153837988419, 0.019995692485411252, 0.014709724878360118, 0.06689584468092237, 0.0017835044875807527, 0.025875744642689824, 0.04189996827127678, 0.053815260329949, 0.005205456882582179, 0.031151661449777227, 0.07129267696291208, 0.06337796630603926, 0.07375335706663982, 0.016829312213563492, 0.023280378730435456, 0.029397105598556142, 0.031337664861764224, 0.037610738072544336, 0.054628243669867516, 0.0059644776047207415, 0.08191310707479715, 4.014502389090402, 19.886093514306204, 39.263283593314036, 40.37332085200718, 30.12302909578596, 24.875139815466746, 14.587862798145839, 11.73377731868199, 1.7208706587553024, 0.4614554356251444, 0.1823206360318831, 0.16795338982982294, 2.1379733000482832, 1.8958492066179002, 3.892606232847486, 0.8436567868505205, 2.4923149262155806, 5.33471006155014, 16.092604637145996, 29.160832132611954, 40.581846714019775, 49.08399254935128, 50.522460733141216, 47.78680903570992, 48.028238092150005, 51.40282528741019, 46.595008850097656, 46.89804063524519, 42.998034136635916, 40.5104991367885, 37.69137525558472, 37.87724304199219, 37.35978637422834, 37.78142738342285, 38.170693261282786, 37.87843465805054, 39.657708508627756, 42.91936315808977, 41.86090932573591, 44.801539829799104, 46.871918882642476, 47.996894768306184, 44.40624291556222, 45.197389125823975, 46.53190531049456, 46.50821195329939, 39.946930749075754, 35.3870712007795, 35.39318561553955, 34.110951151166645, 33.80977800914219, 36.34878873825073, 34.72280951908657, 40.052696228027344, 43.280329023088726, 46.44716855457851, 44.75918013708932, 53.417007310049875, 40.573425497327534, 29.47675977434431, 48.3717222894941, 43.18178967067173, 46.43496404375349, 39.98780352728707, 41.08561890465872, 34.736553055899485, 33.75256654194423, 31.668961593082972, 32.87105900900704, 31.51933213642665, 35.33385147367205, 41.80318021774292, 44.50821120398385, 46.14316749572754, 47.700383867536274, 46.18460655212402, 45.42684991019112, 47.01058408192226, 45.02637311390468, 44.81201423917498, 45.8680396761213, 48.98649195262364, 45.62806279318673, 45.24648857116699, 44.40204272951399, 43.38554212025234, 37.25721011843, 33.105956758771626, 36.2837918145316, 36.002928256988525, 43.01498426709856, 43.47957903998238, 46.269930430821006, 47.58385910306658, 45.4651449067252, 44.84871462413243, 46.45423139844622, 31.358463968549454, 21.316256863730295, 7.784325701849801, 3.0767995629991804, 2.4929643656526292, 17.453027180262975, 32.94584594454084, 9.64386601107461, 1.7204152260507857, 1.0165877874408449, 0.06037704340581383, 0.04917661852336355, 0.06387888121285609, 0.6474977412394115, 2.8164520817143575, 11.824641517230443, 21.749346767153057, 24.76258942059108, 36.05840962273734, 35.373174803597585, 17.35605812072754, 3.826016434601375, 0.15036133809813432, 0.05640502832829952, 0.06651974629078593, 0.03973433215703283, 0.05249904827880008, 0.05205952722047057, 0.08433908011232104, 0.037955308333039284, 0.036675764314298115, 0.043441331812313626, 0.05614770410050239, 0.010232316562905908, 0.026644633384421468, 0.031831512826361825, 0.04177155551899757, 0.020584844086053114, 0.058238117822578976, 0.031409128169928274, 0.053694040048867464, 0.03622657073927777, 0.06028350056814296, 0.04829500815165894, 0.06818599080932991, 0.011926558284488107, 0.018430493705506836, 0.05083170114085078, 0.03290444632459964, 0.03264380745323641, 0.028648396488279104, 0.06596650276333094, 0.0389005754675184, 0.02167594705575279, 0.02297497520755444, 0.04020011930593422, 0.07708905557436602, 0.07333198682005916, 0.06780183820852212, 0.023763208982667754, 0.007533158541523984, 0.04153854998626879, 0.03544538015765803, 0.0534221205328192, 0.06525813255991254, 0.03854004945605993, 0.03176590527540871, 0.04748216051874416, 0.0509573997530554, 0.05374991740765316, 0.007877043481650097, 0.02605765139950173, 0.03988827478938869, 0.02465591000925217, 0.06586372506405626, 0.08231182782245533, 0.03076735617859023, 0.016926442805145468, 0.09697669305439506, 5.683679861681802, 25.706710645130702, 44.739329133714946, 42.551636695861816, 30.60020010811942, 25.214694806507655, 22.5588709626879, 10.888176339013235, 1.9253599430833543, 0.31510368308850695, 0.1945660218064274, 1.7585032965455736, 4.448964561734881, 3.1979943854468207, 5.106848665646144, 4.237392348902566, 2.0005120933055878, 7.286911112921579, 21.691549914223806, 30.986057894570486, 42.643116678510395, 48.644887242998394, 51.64081151144845, 46.750346251896445, 49.89008780888149, 52.63966022218977, 49.7030805179051, 47.92979254041399, 46.64094686508179, 42.81235047749111, 40.34820311410086, 38.630723067692344, 39.706043652125764, 40.02085263388497, 39.91004623685564, 40.342161655426025, 41.56159482683454, 44.68762411390032, 44.7699567931039, 47.84901973179409, 48.11625439780099, 47.93780033929007, 45.44911541257586, 46.487534114292686, 48.08253479003906, 48.53088467461722, 41.96572984967913, 36.01270089830671, 35.85472665514265, 34.71388455799648, 35.43202951976231, 38.24412529809134, 37.04442501068115, 42.34727280480521, 46.04890128544399, 47.20211117608206, 46.59340729032244, 51.18613876615252, 42.63148886816842, 33.69490344183785, 49.554305689675466, 44.706658703940256, 47.253041471753804, 42.71185173307146, 41.54178898675101, 35.61078235081264, 34.99587024961199, 33.20441620690482, 33.79067393711635, 33.240678855351035, 37.43107141767229, 44.50958694730486, 45.97884259905134, 47.122210366385325, 48.82435573850359, 47.44142798015049, 45.531135422842844, 46.83761215209961, 46.379503522600444, 45.90806824820382, 47.659993989127024, 48.3420604297093, 46.322264262608115, 47.473080498831614, 46.02235916682652, 44.63138192040579, 39.125796113695415, 34.79209348133632, 37.995869636535645, 37.77875927516392, 45.26596089771816, 44.51572915485927, 48.64029448372977, 47.44640289034162, 46.24782821110317, 46.02415180206299, 48.45076152256557, 34.29710381371634, 24.457785844802856, 8.952613183430262, 4.00160870381764, 2.324172862938472, 15.605285780770437, 27.586337327957153, 10.96015099116734, 1.6172871312924793, 0.08590068774563925, 0.08288356821451869, 0.007029415415932557, 0.01718027257759656, 1.0903243507657732, 4.665518632956913, 15.63623479434422, 26.538416964667185, 27.88864302635193, 39.374982833862305, 38.812005043029785, 23.346143552235194, 6.174567052296229, 0.2567129491695336, 0.020384447249983038, 0.03471650801865118, 0.028048529123355235, 0.04796631221792527, 0.032702836607183726, 0.017270353190334778, 0.02684888769207256, 0.009651889226266315, 0.017484247784263322, 0.012911862377742571, 0.01760665719796504, 0.03447932271020753, 0.019693566286670308, 0.03392201815066593, 0.018601506582594345, 0.04243977680536253, 0.042145977927637954, 0.07013998845858233, 0.04086630837991834, 0.05304923500599606, 0.010510104558696704, 0.031698350328952074, 0.029128894276384796, 0.029518522654793093, 0.052585408823298554, 0.23584506607481412, 0.14643598587385245, 0.15093171463481017, 0.16494587835456642, 0.09577504824846983, 0.16387398301490716, 0.17423897183367185, 0.13916483175541672, 0.14391877023237093, 0.15571643146021025, 0.1825755073555878, 0.172623054257461, 0.09558242572737591, 0.16756685557109968, 0.08643679147852318, 0.13189145204211983, 0.2442561047417777, 0.07450693127300058, 0.10365472614232983, 0.12537147690142902, 0.1600416036588805, 0.1684553021831172, 0.10117016839129583, 0.18460865611476557, 0.14072071255317756, 0.08762208359049899, 0.11322641931474209, 0.11804249802870409, 0.1455897441399949, 0.13893269135483674, 0.22237558955592768, 6.366667372839792, 27.817314556666783, 51.64410148348127, 49.482051372528076, 39.67654160090855, 33.288572788238525, 22.265787260872976, 14.745503527777535, 2.758178625788007, 0.7969310198511396, 0.4222882773194994, 2.559475996664592, 6.7342987315995355, 11.452662757464818, 9.832165666988917, 4.861670187541416, 4.321560655321393, 7.958707247461591, 22.33178298813956, 34.175743103027344, 44.316819599696565, 49.023140226091655, 50.15872253690447, 47.780691146850586, 50.889134543282644, 54.39083555766514, 52.0845616885594, 49.87269646780831, 47.34006765910557, 43.33878769193377, 41.636628423418315, 39.99562719890049, 41.94116449356079, 41.89586223874773, 42.336638586861746, 42.14785255704607, 42.60699994223458, 46.489781856536865, 45.48618752615792, 48.17151689529419, 49.29176453181675, 48.60163470676967, 45.79167202540806, 47.8511563028608, 48.24339253561837, 51.02562148230416, 43.55386570521763, 38.91517536980765, 37.851506914411274, 35.650289808000835, 36.86094045639038, 38.66871234348842, 37.97057819366455, 43.9378787449428, 48.495337690625874, 48.29111623764038, 49.21293027060372, 52.26541287558419, 44.6407585144043, 37.20808982849121, 48.41116721289498, 47.18341704777309, 47.69946323122297, 43.704853534698486, 44.101102352142334, 38.64814567565918, 35.65867975779942, 34.42832401820591, 34.86125932421003, 35.76715850830078, 39.048122201647075, 46.453071049281526, 47.47599526814052, 49.77149942943028, 50.55988720485142, 46.89957618713379, 45.35564824513027, 48.00944321496146, 46.665810993739534, 46.73299312591553, 46.689017977033345, 51.78792919431414, 47.715089729854036, 48.1642039162772, 47.31603384017944, 46.31469767434256, 39.908607959747314, 36.36474527631487, 40.7420026915414, 39.72074951444353, 47.91824810845511, 46.72541958945138, 49.6270637512207, 48.09115055629185, 45.7734295300075, 45.427951199667795, 49.217891284397666, 34.40166030611311, 25.021232639040264, 9.933180315153939, 4.775818245751517, 5.474293725831168, 27.342092514038086, 41.1026211466108, 14.501844099589757, 4.536539656775338, 2.135990023612976, 0.32207997302923885, 0.17588289933545248, 0.1450577862560749, 1.781667179294995, 8.989127704075404, 14.72580191067287, 34.528416293007986, 34.51342555454799, 46.29416922160557, 44.697865758623394, 25.468654939106532, 6.197843517575945, 0.47947862850768225, 0.16985298932663032, 0.13230187073349953, 0.12104183994233608, 0.17242995676185402, 0.09097302199474402, 0.24136709262217793, 0.11295242687421185, 0.11759492275970322, 0.1176441844020571, 0.13676174570407185, 0.08458591079605476, 0.1034411301038095, 0.13952702017767088, 0.11407160253397056, 0.07329915929585695, 0.11041896031903368, 0.1698777015720095, 0.13655031419226102, 0.129972405731678, 0.18343643258724893, 0.1290079496268715, 0.21399333434445517, 0.05422343985576715, 0.1392823811620474, 0.16351818639252866], [0.019613889312105517, 0.03133195159690721, 0.08329538468803678, 0.03002522207264389, 0.009045425652792411, 0.03926967137626239, 0.037044609165085216, 0.0208958353448127, 0.03434151903327022, 0.04333327850326896, 0.019036561184163605, 0.06572164661650147, 0.049176628701388836, 0.06485653482377529, 0.08280723302492074, 0.032788905381624184, 0.02777098455200238, 0.06295480472700936, 0.059861913190356324, 0.021939047312896167, 0.015683258085378578, 0.03948966260733349, 0.010644718272877591, 0.05454627324693969, 0.030407586733677557, 0.0779104900679418, 0.02182612381875515, 0.04167644865810871, 0.08563879358449153, 0.026505911988871436, 0.02852762404030987, 0.6520422430975097, 8.951764634677343, 29.808411189488, 39.43907649176461, 29.716715812683105, 18.78472760745457, 18.717274495533534, 28.692419324602398, 5.358271402972085, 1.191010370850563, 0.2111576415066208, 1.1009347928421838, 2.1359539798327853, 2.7475926109722684, 2.744265292372022, 3.01432027561324, 4.839356047766549, 1.9642759348664964, 6.692479695592608, 17.04434629849025, 32.94990021841866, 44.56738553728376, 48.776194299970356, 46.231437410627095, 52.48114054543631, 48.30062484741211, 44.972882407052175, 42.32754339490618, 41.58811610085623, 39.611899035317556, 40.161334787096294, 44.942893981933594, 44.370338099343435, 45.30513136727469, 43.287232058388845, 42.09376083101545, 41.28209311621529, 42.27553960255214, 43.62780148642403, 45.30584008353097, 44.49771247591291, 47.8732133592878, 46.01178748267037, 47.85811144965035, 46.44035931995937, 45.16740417480469, 43.733546120779856, 38.72179658072335, 34.01617077418736, 35.06584555762154, 34.735924243927, 37.04894133976528, 36.822690623147146, 42.67917782919747, 42.83743347440447, 47.09416743687221, 46.45381450653076, 52.99186788286482, 42.35701070513044, 28.270434379577637, 48.99790089470999, 44.29070826939174, 46.5331038747515, 42.56701305934361, 43.88282469340733, 37.652416706085205, 34.60465540204729, 32.9552503313337, 35.88517018726894, 36.13600015640259, 37.65382024220058, 43.73015539986746, 44.31645481927054, 47.29743003845215, 44.91362816946847, 45.92958334514073, 45.52918297903878, 45.94245835712978, 45.55347735541207, 45.52169976915632, 44.07900708062308, 45.40987893513271, 46.650035108838765, 45.217702184404644, 43.771257468632285, 41.529028620038716, 34.083165305001394, 35.63901635578701, 36.224509784153526, 36.20188644954136, 40.74280868257795, 42.76583228792463, 45.38044984000069, 45.96357045854841, 47.72286476407732, 43.152009691510884, 37.42815317426409, 23.762875659125193, 11.624062657356262, 3.530294154371534, 1.7316435149737766, 0.7097836190036365, 4.902984610625675, 12.444597142083303, 3.7256766302245, 0.38451545419437544, 0.027899527922272682, 0.2073289126689945, 0.05991551067147936, 0.1951832715421915, 0.8620679389153207, 5.240911986146655, 11.623237558773585, 21.67623782157898, 27.565744604383195, 38.52934537615095, 22.386672019958496, 10.56736237662179, 0.5745274339403424, 0.07508297357708216, 0.05931058991700411, 0.01581584382802248, 0.04155597476554768, 0.06207982703511204, 0.054254126601985524, 0.030285087414085865, 0.06456219990338598, 0.02275772356162114, 0.017506040632724762, 0.03139387131003397, 0.039781358026500256, 0.06358351491923843, 0.02542470205974366, 0.04802853048646024, 0.08176336796688181, 0.053030575292983224, 0.04526028063680444, 0.056928192398377826, 0.03180406947753259, 0.026530071228210415, 0.038994165802640576, 0.08523307714079108, 0.020775946688705256, 0.018283675690846782, 0.02605686938789274, 0.02546590779508863, 0.08410379130925451, 0.09758394118398428, 0.016799110619883453, 0.023700619216210077, 0.0319155663517969, 0.04784337185057146, 0.023316330908398544, 0.0882996686601213, 0.021745786968884722, 0.06458625396979706, 0.039101655927619765, 0.02797648906042533, 0.03893047511311514, 0.05753199357007231, 0.038290212862193584, 0.043130016553082635, 0.010622639591539544, 0.046448704187891314, 0.02376645746906953, 0.027571062690445354, 0.02875783061608672, 0.030225359369069338, 0.04363372702417629, 0.023444708037589277, 0.04655361248712454, 0.027202887892989174, 0.04474103510645883, 0.04699368994416935, 0.018931559586365308, 0.07230364664324693, 1.2325575585876192, 12.336760231426783, 37.05020938600813, 44.67929669788906, 33.22514615740095, 22.05885601043701, 19.30050802230835, 24.02521358217512, 5.753969141415187, 0.9633275653634752, 0.13331796335322516, 0.36910706385970116, 0.6789830146091325, 2.5305237216608862, 4.458755007811955, 5.886201611586979, 2.250990527016776, 1.1769134529999323, 8.757445233208792, 21.183518477848597, 36.65945659364973, 47.518625940595356, 50.77152238573347, 48.970771653311594, 53.4079190662929, 50.522168908800396, 48.13604286738804, 45.214488642556326, 43.753397124154226, 41.87894684927804, 41.42788716724941, 45.06773921421596, 45.42944506236485, 46.73757546288626, 44.787136214120046, 42.35974134717669, 41.92541987555367, 44.10270391191755, 45.20796080998012, 46.51715081078665, 45.73564175197056, 48.130953311920166, 46.36121933800833, 48.87771095548357, 46.69762332098824, 47.8267194884164, 44.271096978868755, 38.95818819318499, 34.68372242791312, 35.73339373724801, 37.12592390605381, 38.50421026774815, 38.67000470842634, 43.170008999960764, 45.03664949962071, 48.12935522624424, 48.440790857587544, 51.68024253845215, 44.16596378598894, 32.607169900621685, 48.35646751948765, 46.780171394348145, 47.49071850095476, 44.809644903455464, 45.75689629146031, 39.06418991088867, 35.212945869990754, 34.48214823859078, 37.64733757291521, 35.883002349308555, 39.40425212042672, 46.515986987522666, 45.15967777797154, 47.44899109431675, 46.05063486099243, 46.80988189152309, 45.50640330995832, 47.45329550334385, 47.58659669331142, 46.4543251991272, 46.750398363385884, 47.50738722937447, 47.40666961669922, 47.84984309332711, 45.34079647064209, 43.263014112200054, 34.794219630105154, 37.31130531855992, 38.37148577826363, 38.4599016053336, 43.30273001534598, 45.23247752870832, 47.14441333498274, 47.02414696557181, 47.459336962018696, 45.68774087088448, 40.19550602776663, 26.556421484266007, 14.482644489833287, 4.699683793953486, 2.629282376595906, 1.1549846125500542, 5.963146831308093, 18.568854025432042, 5.733621776103973, 0.6814211809209415, 0.04538232873060873, 0.1981899416340249, 0.18319385631808213, 0.32608653232455254, 2.06865741951125, 5.171651039804731, 14.262204204286848, 25.099719490323746, 31.969394751957484, 42.262824399130686, 28.544535602842057, 12.873283624649048, 0.9564944463116782, 0.025429648580029607, 0.02650440564113004, 0.01768814755736717, 0.0521673973250602, 0.03473192433427487, 0.036449798582387824, 0.027586294105276465, 0.08148463256657124, 0.02094957871096475, 0.01378706144168973, 0.06611921385462795, 0.02347152374152626, 0.05036185295986278, 0.03727107022755912, 0.026321316537048136, 0.05258411621408803, 0.05232054267876914, 0.006086101190053991, 0.0624925663162555, 0.06380021186279398, 0.020910064224153757, 0.02774055564909109, 0.05450971717281001, 0.03890773740464023, 0.02253114545185651, 0.04083055636978575, 0.0732609306329063, 0.16020028585834162, 0.20967976509460381, 0.09791287460497447, 0.062220975889691284, 0.09082783585680382, 0.10290546741868768, 0.0828595073627574, 0.2374419846705028, 0.1316095343125718, 0.10288089088031224, 0.2320705928972789, 0.13766449583428247, 0.12005899553852421, 0.16790724944855484, 0.15037812505449566, 0.1595413876431329, 0.22546376527420112, 0.1273570874972003, 0.08828448983175413, 0.07261246828628437, 0.11787753259497029, 0.10081139978553567, 0.1404577802334513, 0.17028016783297062, 0.13187823417995656, 0.14602441367294106, 0.10647714004984923, 0.16150083392858505, 0.08114466616617781, 0.1897377430328301, 1.3005771658250262, 13.511675425938197, 41.471289089747835, 52.09315313611712, 38.916047368730815, 27.36373441559928, 25.79361697605678, 34.174912793295725, 7.31546299798148, 1.5542075846876418, 0.5548203342727253, 2.8701432006699696, 5.461401343345642, 12.29534809929984, 10.454659121377126, 6.8113225528172086, 10.363576054573059, 3.9945046050207953, 8.749873433794294, 20.342152425221034, 39.35272775377546, 50.82996368408203, 52.0887827192034, 47.9498415674482, 56.20618792942592, 52.840254715510774, 48.919775349753245, 45.5430064201355, 46.01062365940639, 42.49308770043509, 44.23088080542428, 48.829254218510215, 47.554707935878206, 47.528596605573384, 47.0085517338344, 45.687469891139436, 45.48742083140782, 46.564058099474224, 47.05935001373291, 49.016629764011924, 48.04117563792637, 49.0520829473223, 46.974175521305625, 49.89362096786499, 48.470848764692036, 49.092299120766775, 47.409014633723665, 42.27913529532296, 37.50171375274658, 38.44246162687029, 38.89186763763428, 40.14535740443638, 40.901133809770855, 45.51689856392996, 46.83749750682286, 50.33573137010847, 50.61382259641375, 50.547286646706716, 46.876966748918804, 36.06765072686331, 48.544371128082275, 48.73220872879028, 49.56572157996041, 46.40223108019148, 48.25314085824149, 41.00813259397234, 37.632478850228445, 36.847679819379536, 40.18461125237601, 37.85079819815499, 40.27069248471941, 47.20081186294556, 47.30218260628836, 48.08153077534267, 45.87155546460833, 45.52456242697579, 46.37037706375122, 48.85800239018032, 49.261616298130576, 49.1942708832877, 46.90721573148455, 48.921234471457346, 49.96122694015503, 49.11362314224243, 47.24207721437727, 45.05183826174055, 36.75429950441633, 38.95079530988421, 39.409960065569194, 39.343931334359304, 44.44862692696707, 46.742192540849956, 49.34154837472098, 47.4503425189427, 47.48442690713065, 44.66253069468907, 41.152814933231895, 26.688138484954834, 14.120407973017011, 5.531224659511021, 4.578183685030256, 3.741363491330828, 7.902037739753723, 15.334365095411028, 6.248122419629778, 1.5869013560669762, 0.22963942906686238, 0.5922795927950314, 0.38971723935433794, 1.8668928061212813, 7.568553737231663, 12.431838512420654, 18.724111522947037, 33.74601786477225, 38.03439392362322, 47.6776111466544, 31.010258470262798, 14.163416453770228, 1.306578129529953, 0.15755151584744453, 0.13953406337116445, 0.0883123776210206, 0.13697008309619768, 0.07877959164657763, 0.1397452370396682, 0.16293167429310934, 0.15200400352478027, 0.12023694813251495, 0.19134425611368247, 0.12519418927175657, 0.10618208588234015, 0.18821996876171657, 0.16124805249273777, 0.07416613705988441, 0.22006981899695738, 0.132479850468891, 0.1201250169958387, 0.13244339956768922, 0.15315888369722025, 0.13521213456988335, 0.10917569417506456, 0.16757786140910216, 0.09770640318414994, 0.23423970650349343, 0.063380212256951], [0.05371353096727814, 0.03158250404521823, 0.054156488805477104, 0.034614025482109616, 0.01082016367997442, 0.014471129913415228, 0.03337290690147451, 0.05789581047637122, 0.04629576578736305, 0.04822221830753343, 0.0163965086519186, 0.027171585376241376, 0.05171030560242278, 0.041804111629192314, 0.05442656270627465, 0.02150706308228629, 0.01770127042462783, 0.08173923247626849, 0.045024496503174305, 0.05289499721090708, 0.0530539847511266, 0.07380094272749764, 0.02906858269125223, 0.024650195048057606, 0.02344997855834663, 0.020692173058965375, 0.043818566748606305, 0.07665952255151101, 0.017021905896919112, 0.09453420447451727, 0.03480997282479491, 0.21535519483898366, 3.059039750269481, 17.731069769178117, 36.13473905835833, 37.20830522264753, 22.682524578911917, 43.07474224908011, 28.704041923795426, 10.261225615228925, 1.9481891180787767, 0.2963161883609635, 0.13563384408397333, 1.3428731305258614, 2.8014839248997823, 5.385538305555071, 7.369839600154331, 1.06299860562597, 0.5443107496414865, 2.426722628729684, 7.591554880142212, 17.442493711199077, 32.256678444998606, 43.396746090480256, 49.382869311741416, 49.867155279432026, 48.18613937922886, 46.08627217156546, 44.59872191292899, 43.84208393096924, 45.47534138815743, 45.60442154748099, 46.970711844308035, 46.654603549412315, 46.79628774097988, 44.35326637540545, 45.706747668130056, 42.915110860552105, 41.00204249790737, 43.51362173897879, 43.89393138885498, 45.46682637078421, 47.207652364458355, 48.22501107624599, 44.287578105926514, 46.54837254115513, 48.099387645721436, 46.057624748774934, 36.443829672677175, 32.77818938664028, 34.22546441214425, 34.97492837905884, 36.64844369888306, 39.132852009364534, 44.06532260349819, 45.83470221928188, 47.31136812482561, 47.33271646499634, 33.74239437920706, 33.24348940168108, 31.488426549094065, 46.03917728151594, 44.08635480063302, 47.083133697509766, 45.436268193381174, 45.10256705965315, 44.06789343697684, 38.62809317452567, 29.28545502253941, 32.85315350123814, 33.90722302028111, 39.59207582473755, 44.810742718832834, 47.94573518208095, 45.92951386315482, 44.76614570617676, 47.45427867344448, 46.636076177869526, 46.57619660241263, 44.1462447983878, 43.23988355909075, 42.65216670717512, 43.96755450112479, 43.68866075788225, 41.845255034310476, 41.024301052093506, 36.47927590778896, 36.19525439398629, 35.67478915623256, 39.37121343612671, 40.633614267621724, 43.37243781770979, 43.533955642155235, 45.021589279174805, 46.7443881716047, 45.997067723955425, 41.34936557497297, 27.54083357538496, 14.105027266911097, 5.871477510247912, 1.5790498916591917, 0.2537459869469915, 0.6929643100925854, 0.6918952646000045, 0.14783061960978167, 0.6290954915540559, 0.2716167265815394, 0.027771183023495332, 0.11972909181245736, 0.24268760319267, 0.4038717783987522, 2.4088214635849, 9.548249244689941, 17.314895255225046, 26.466737610953196, 34.39560147694179, 31.016626494271414, 16.24145415851048, 3.1993660032749176, 0.49228627554007937, 0.02484012208878994, 0.022495888772287538, 0.02758511684701911, 0.01372418923503054, 0.0442397741467825, 0.01829010311381093, 0.03457635661054935, 0.07077941950410604, 0.019825183420575092, 0.05597207209627543, 0.07339654942708355, 0.0678345775231719, 0.04565545943166528, 0.028101280132042508, 0.028822671422468762, 0.0654766886894192, 0.041898309253156185, 0.026061339237328087, 0.05896873040390866, 0.025391224838261093, 0.056767769756593874, 0.012651313412269312, 0.02232413289935461, 0.05345531107325639, 0.05560033668630889, 0.08961924285228763, 0.012104058804522668, 0.043669859013919315, 0.02738680989880647, 0.019255912895979624, 0.027008731882753115, 0.0412907931022346, 0.03627558810902493, 0.012648700204278742, 0.035613507564578734, 0.030235730776829377, 0.04548073327168822, 0.022517790186351964, 0.01836555451154709, 0.052826421069247384, 0.02866283232080085, 0.05826208367943764, 0.06595513051641838, 0.006917313797332878, 0.0454888790845871, 0.015628452811922346, 0.013362886300975723, 0.0368771399371326, 0.05991164980722325, 0.04387429143701281, 0.029314388787107806, 0.010896229151902454, 0.010251404601149261, 0.0076173952714140925, 0.011307183037778097, 0.10681960345911128, 0.027148494829556773, 0.1542038954794407, 4.735298522881099, 22.592875446592057, 42.25024468558175, 38.82338271822248, 22.208065101078578, 34.70455660138811, 32.808216026851106, 12.61150242601122, 2.12283056974411, 0.29390095653278486, 0.11258074574704681, 2.3082441176686967, 2.937119709593909, 6.3527266808918545, 6.284018984862736, 1.790336902652468, 0.9428913933890206, 3.958062171936035, 11.649589470454625, 22.21941498347691, 36.80316965920584, 47.9327073097229, 49.202063288007466, 50.92900678089687, 49.27894857951573, 47.08544397354126, 45.85177394321987, 45.003298146384104, 47.167634214673726, 48.554129873003276, 47.329499449048726, 48.94366325650896, 48.58772441319057, 46.5812201499939, 47.12735898154122, 44.16701643807547, 42.887474400656565, 44.88427203042166, 46.402324880872456, 46.67140776770455, 48.663522311619346, 48.46827793121338, 45.71793079376221, 46.50130544389997, 49.99246604101998, 47.98122310638428, 37.3631979397365, 34.599847248622346, 36.3415070261274, 37.567606994083945, 38.24508762359619, 40.97379807063511, 45.01257746560233, 47.8490058353969, 49.48658854620797, 48.29011917114258, 36.099716663360596, 35.256997449057444, 35.237316676548545, 47.02618278775896, 45.656727586473735, 47.86455242974417, 47.11112451553345, 46.87572302137102, 44.71845327104841, 39.32620995385306, 31.49610778263637, 35.00237028939383, 35.43512494223458, 41.71962465558733, 47.35133763722011, 47.9980377469744, 45.43227645329067, 45.16012593678066, 47.737480299813406, 46.42032766342163, 49.18176065172468, 45.22214208330427, 45.269782406943186, 44.413778236934114, 45.42688117708479, 45.42719037192208, 44.1771364893232, 42.69488075801304, 37.827632904052734, 37.10674340384347, 37.65948649815151, 39.785982676914756, 41.55508089065552, 44.83352238791329, 45.681862694876536, 47.79357310703823, 47.45693288530622, 46.25977911267962, 42.93610831669399, 30.42782919747489, 17.76683735847473, 7.779018146651132, 3.52597867165293, 1.200589656829834, 1.7483990958758762, 2.606409558228084, 0.8083367049694061, 0.1972325558641127, 0.09070196082549435, 0.08734036942145654, 0.16932313490126813, 0.22157035847859724, 0.7913778349757195, 1.7621862760611942, 12.551173823220388, 17.10369607380458, 27.900336844580515, 36.55501127243042, 36.002834456307546, 19.808219841548375, 5.326530729021345, 0.5110250243118831, 0.017859464078875523, 0.04492935571553452, 0.016071278335792676, 0.02819121994876436, 0.03312854269253356, 0.024857590972845043, 0.05069896951317787, 0.030251279406781708, 0.0627486047201923, 0.028329345929835523, 0.02944516623392701, 0.005785945287373449, 0.015275746916553803, 0.047520216155265055, 0.025453977453123246, 0.008585906471125782, 0.004350582486949861, 0.051279697101563215, 0.04786370075973017, 0.01308171750445451, 0.050760692451149225, 0.053569803679628034, 0.06152937228658369, 0.030558652377554348, 0.040238575278116126, 0.12516237955008233, 0.15225848129817418, 0.08689623432500021, 0.12220558178211961, 0.10752420779317617, 0.15955151138561113, 0.1270501318254641, 0.17122417289231504, 0.10993745151375021, 0.066791004235191, 0.1927097535559109, 0.2058209500142506, 0.06302508738424097, 0.08708571522895779, 0.11459924493517194, 0.18297985994390079, 0.10457568136709076, 0.14913071984691278, 0.11804956836359841, 0.13643778594476835, 0.12338863472853388, 0.16370239507939133, 0.14399254055959837, 0.09251630239720855, 0.08523548594010727, 0.12645862570830754, 0.11501260846853256, 0.12956448404916696, 0.09655610312308584, 0.09635759091803006, 0.2480120403426034, 0.12014070472546987, 0.3706430500107152, 4.958646629537855, 25.95337516920907, 47.524934904915945, 47.09764501026699, 32.023062637874055, 50.56176321847098, 34.9812581879752, 13.967769946370806, 2.9628065483910695, 0.9317000167710441, 0.924338617495128, 4.801397604601724, 8.347342576299395, 16.091098615101405, 15.459767920630318, 2.608599760702678, 2.4517461316926137, 4.181222677230835, 8.963611313274928, 22.589458669934952, 39.19503491265433, 49.93098837988717, 51.58867917742048, 51.54347767148699, 51.54647929327828, 50.3006568636213, 48.123199122292654, 46.00969607489449, 49.269137723105295, 50.72538982118879, 49.31983525412423, 50.48795597893851, 50.874651023319785, 48.322709696633474, 48.819040366581504, 46.160280908857075, 44.907093388693674, 46.910283361162456, 48.28400823048183, 48.188835280282156, 50.28743096760341, 49.99335888453892, 45.283817768096924, 48.03394603729248, 52.00102697099958, 50.57589585440499, 38.8452730178833, 36.19351387023926, 37.73701797212873, 39.653848784310476, 39.853897844042095, 44.23502540588379, 46.41072872706822, 49.83133036749703, 51.81404052461897, 47.98418303898403, 38.17456340789795, 38.38479505266462, 38.09111554282052, 46.545742647988455, 46.324067320142476, 49.31088597433907, 48.88779626573835, 48.83456611633301, 47.06292833600725, 41.42476395198277, 32.707835401807515, 35.70110198429653, 37.3296902520316, 43.10588754926409, 49.61261149815151, 50.08484581538609, 46.86852468763079, 46.16434907913208, 47.914454392024446, 47.49062817437308, 49.2395453453064, 46.333833013262065, 46.224815777369905, 46.86617967060634, 46.83075428009033, 47.44923080716814, 45.813336508614675, 44.16093676430838, 38.41848339353289, 38.475076471056255, 39.3268735068185, 43.39145851135254, 44.63213579995291, 47.70568881716047, 48.48433869225638, 48.62676286697388, 48.44117300851004, 46.40155363082886, 43.513951778411865, 30.537902559552872, 18.237348522458756, 7.915185468537467, 2.785702177456447, 1.6869376110179084, 2.446667432785034, 3.4939780916486467, 1.5645142602069038, 1.7901403989110674, 0.9645868177924837, 0.3819004887981074, 0.5445934001888547, 0.48715177391256603, 2.5332139773028235, 6.087096180234637, 17.06442138126918, 25.400003262928553, 36.04750442504883, 44.234017917088096, 41.26181479862758, 23.49718870435442, 5.163717065538679, 0.8100237058741706, 0.13778878987899848, 0.12044475626732622, 0.15493413486651011, 0.10432742575981788, 0.1463107554508107, 0.16112029791942664, 0.13511727537427629, 0.25109921182904926, 0.12881820409425668, 0.1355812983321292, 0.13515208422073297, 0.13487365416118077, 0.16316085628100804, 0.1285097420747791, 0.1162521562405995, 0.17339532210358552, 0.14426600374281406, 0.153617261243718, 0.15754897812647478, 0.16191023481743677, 0.12863935583404132, 0.1479251395378794, 0.14262295833655766, 0.17587002074079855, 0.08448445624006645, 0.22390358256442205], [0.01382444956938603, 0.01524128412295665, 0.02828145492821932, 0.029710758410926377, 0.02439703363259988, 0.05497119901701808, 0.011072868780632104, 0.016253010369837284, 0.009426998124191803, 0.023359227892277495, 0.044820043724030256, 0.03273128418784056, 0.11967684461602143, 0.029745960807693855, 0.003204343670014558, 0.04377189032467348, 0.011104120407253504, 0.04840254916676453, 0.02990807978702443, 0.03397600578942469, 0.03738020919263363, 0.017773208707304936, 0.053149162858192406, 0.05622776444735272, 0.08353070741785423, 0.008115911556939994, 0.065182394481131, 0.10410234212343182, 0.027296437516010234, 0.05609000826786671, 0.07501985624964748, 0.05576004347364817, 0.5408286164913858, 7.396731734275818, 26.581285612923757, 38.915171895708355, 31.907673903873988, 31.210964134761266, 22.071413142340525, 14.699304955346243, 5.920290342399052, 0.9248018669230598, 0.1374875203307186, 0.9843020055975232, 1.0123877099582126, 2.8007131091185977, 8.061311296054296, 0.4783651796834809, 0.3645735814103058, 0.994042728628431, 4.326968959399632, 12.318971105984279, 25.007739237376622, 40.2140577180045, 49.38791370391846, 51.11203622817993, 48.971508162362234, 47.09176683425903, 46.23989336831229, 46.27918543134417, 47.660344873155864, 48.355612891060964, 48.7660117149353, 47.679320403507774, 48.57629810060774, 46.671241010938374, 46.252917766571045, 46.14947993414742, 43.58093588692801, 44.58881030763899, 46.01942007882254, 46.0569611958095, 48.08421972819737, 47.04842397144863, 47.34133570534842, 49.000899042402, 47.45791605540684, 44.35445104326521, 38.34498534883772, 34.454178265162874, 35.499117851257324, 34.66878032684326, 37.50885302679879, 41.062415395464214, 45.85399041857038, 45.446388244628906, 47.793201378413606, 44.62843588420323, 46.82993786675589, 38.60414968218122, 29.50944757461548, 46.583919525146484, 45.14265469142369, 48.074936934879844, 46.77168416976929, 47.51363365990775, 44.2796745300293, 43.448548385075156, 32.6314503805978, 32.00615419660296, 33.372597353799, 43.84040246691023, 45.458460739680696, 46.98657805579049, 49.67532941273281, 45.89783007758004, 44.877869265420095, 45.99496936798096, 44.88325064522879, 43.87038046973092, 39.979010581970215, 39.62118877683367, 37.68500375747681, 37.948191097804475, 35.80863577978951, 35.48843847002302, 34.921673910958425, 37.7283570425851, 39.66316631862095, 40.06667947769165, 44.05710983276367, 43.44171830586025, 45.95300572259085, 46.00228929519653, 47.49543980189732, 41.43309831619263, 32.4555150440761, 20.49216055870056, 9.175453203065054, 2.0727088706833974, 0.43258317347083775, 1.6419296775545393, 1.3126784307616097, 1.1955492815801074, 0.6854013044919286, 0.04287128097244671, 0.05582701827266386, 0.05785892531275749, 0.04250683302858046, 0.04832400534568088, 0.6963959059544972, 3.9722143496785844, 8.919390371867589, 16.00530399594988, 29.546662126268657, 29.176993642534526, 26.606691701071604, 8.674773829323904, 1.7458186000585556, 0.050177990325859616, 0.05181146499567798, 0.037498433741607835, 0.06399078520813159, 0.051279642818761725, 0.027691068393843513, 0.047862286014216285, 0.052898335603198836, 0.03762836641232882, 0.04297467953126345, 0.03291064813467009, 0.02240698711414422, 0.010182993852400353, 0.03881235234439373, 0.04880461509206465, 0.04747721739113331, 0.020751522820709006, 0.033644497328038724, 0.04407928365149668, 0.025318714889830778, 0.03303035528266004, 0.013256232470407017, 0.06223187316209078, 0.030979299984340156, 0.02878370654902288, 0.03535852088992085, 0.026170637658131973, 0.036183141105409176, 0.006967487221118063, 0.06326190289109945, 0.042490314093551466, 0.056118676372404606, 0.030952260363847017, 0.021567483233021836, 0.018267121132729307, 0.00890140574691551, 0.010848099814860948, 0.024333086796104908, 0.08975106863571064, 0.02834122538167451, 0.04074092867917248, 0.019026752960469042, 0.023668214080056975, 0.03885350888594985, 0.01616638689301908, 0.005747507126735789, 0.02373992674984038, 0.025793173716270497, 0.08639754501304456, 0.04342457199735301, 0.045271791983395815, 0.015277539945340582, 0.03226838420544352, 0.02735339035280049, 0.03835172884698425, 0.04839547883187022, 0.013537218910641968, 0.04573605242850525, 0.012009942604761039, 0.9791224492447717, 10.456720999308995, 32.87263625008719, 43.92214454923357, 30.77182756151472, 34.466535636356895, 28.9793347631182, 18.814043794359478, 6.787574478558131, 0.5669307187199593, 0.12352457243416991, 0.78950035572052, 1.7165259718894958, 3.346932713474546, 7.924732293401446, 2.303813121148518, 0.3223647406058652, 1.4698174787419183, 6.129164048603602, 14.02791963304792, 26.72738712174552, 42.505490234919954, 52.36426142283848, 52.290919712611604, 51.831487451280864, 49.1868953704834, 49.58788980756487, 47.6037517956325, 49.47010394505092, 50.685218811035156, 50.782604762486045, 49.5250746182033, 50.25190830230713, 48.11605984824044, 47.36244085856846, 48.281326225825715, 44.99329621451241, 45.97530944006783, 47.71913010733468, 47.31108324868338, 48.002161502838135, 47.837072304316926, 48.07608338764736, 49.76819208690098, 49.23042583465576, 46.744290896824424, 38.61779594421387, 35.92240558351789, 37.205786500658306, 35.93873037610735, 38.476980277470176, 42.3648031098502, 47.72350399834769, 47.578727858407156, 49.33962719781058, 45.73806667327881, 45.48306778499058, 40.36183895383562, 31.470302173069545, 46.5719165120806, 46.55388593673706, 48.35415724345616, 48.705576283591135, 49.975071225847515, 45.310571806771414, 44.68210029602051, 33.73219442367554, 34.02210453578404, 35.786669049944194, 44.74622869491577, 47.40144109725952, 49.21832207271031, 50.85220486777169, 45.71035030909947, 45.81748458317348, 46.97407129832676, 46.80682815824236, 47.00263186863491, 42.95675836290632, 41.418739863804404, 39.88574143818447, 38.38774456296648, 39.02326154708862, 37.133087498801096, 36.51003558295113, 39.090749400002615, 39.92696510042463, 41.80745335987636, 44.659115655081614, 46.42820692062378, 48.10267414365496, 48.66678449085781, 46.47296721594674, 43.284779344286235, 34.03795337677002, 22.867734023502894, 9.657680766923086, 3.190684446266719, 3.8599718468529836, 3.1245719024113248, 1.7465121171304157, 2.616007626056671, 0.921213122350829, 0.2473688434277262, 0.040973628871142864, 0.08587962601866041, 0.20412111122693333, 0.07345258963427373, 0.8309003284999302, 4.25789908851896, 13.096999985831124, 19.212363174983434, 34.02654096058437, 34.56750338418143, 31.47458921160017, 12.008741855621338, 2.0578655643122534, 0.030283750700099126, 0.01725933208529438, 0.034089388991040845, 0.07586142287722655, 0.0715901670711381, 0.04114412097260356, 0.017670196913448826, 0.0253682547315423, 0.05218885260234986, 0.012080520424725754, 0.020885192523045198, 0.046241184430462975, 0.016876913141459227, 0.017090127504031574, 0.03684131668082305, 0.09916977930281844, 0.025935666070186665, 0.0156981078242617, 0.048088852249618085, 0.05154389828177435, 0.01693745542849813, 0.013463949851159538, 0.031566707749984095, 0.01929887434068535, 0.012463655223005583, 0.027478361236197606, 0.027562843935031976, 0.09989817985998732, 0.11241655384323426, 0.09272444301417895, 0.13670925423502922, 0.15300126001238823, 0.14809262912188256, 0.11031722756368773, 0.06530250196478196, 0.13164204971066543, 0.08250130872641291, 0.12959876363830908, 0.17144133123968328, 0.15358912918184484, 0.09806791985673563, 0.05193308221974543, 0.1525976402418954, 0.0866728402408106, 0.0864633357684527, 0.10463542637548276, 0.08223236458642141, 0.11371014014418636, 0.133582008470382, 0.08492053034050123, 0.1985720382737262, 0.19923464129013674, 0.12226902480636324, 0.13684392986553057, 0.22442715375551156, 0.16685980851096766, 0.12887397967278957, 0.18762664417071, 0.10611883284790175, 1.4471768821988786, 12.27331188746861, 38.71483448573521, 50.15228155681065, 41.74473891939436, 39.73553875514439, 32.50744588034493, 20.441621099199565, 8.11384836265019, 1.2651643689189638, 0.2929785560284342, 3.829697677067348, 5.8453622715813776, 8.857082401003156, 15.722746815000262, 3.9717509916850497, 0.7616607695817947, 2.9298351747649054, 7.510676980018616, 14.345411487988063, 27.406392880848475, 42.7213568687439, 52.806382247379844, 55.19487762451172, 52.63629729407174, 51.29947778156826, 51.51506301334926, 49.072354316711426, 51.11030960083008, 52.14774513244629, 51.432157107761924, 49.91815505708967, 51.5224107333592, 49.61419916152954, 48.838901792253765, 51.61494336809431, 47.07072768892561, 48.07886266708374, 50.26089232308524, 49.932982512882774, 50.30038240977696, 48.73715932028634, 50.646149090358186, 51.16687488555908, 52.37832457678658, 49.17544821330479, 41.15049770900181, 38.0963579586574, 38.279946735927034, 38.022394384656636, 41.07146889822823, 44.4327711377825, 49.083544390542166, 49.65881701878139, 49.63112497329712, 46.45656599317278, 45.33620718547276, 43.0863596371242, 34.96249805177961, 45.479263646262034, 46.63136182512556, 47.75382941109793, 49.542684827532085, 51.9226929800851, 47.94049971444266, 46.26203727722168, 36.68230921881539, 35.68571172441755, 37.43674462182181, 47.06554433277675, 49.07715204783848, 49.943404810769216, 49.14423343113491, 44.949995040893555, 46.2053017616272, 47.31656190327236, 49.27047177723476, 48.406060286930625, 44.60280050550188, 43.694194998059956, 40.42203119822911, 39.461112703595845, 39.69044842038836, 38.57800013678414, 38.73745782034737, 41.06897102083479, 43.21056910923549, 42.95383317129952, 46.617208344595774, 47.742007051195415, 50.0984399659293, 48.85689762660435, 47.36408410753523, 42.899744919368196, 35.10162878036499, 22.704055309295654, 11.873466508729116, 3.387300010238375, 3.1003645956516266, 4.701043903827667, 2.584512744631086, 2.9156539014407565, 1.8343734996659415, 0.6273995339870453, 0.1364891103335789, 0.2497050937797342, 0.5837854743003845, 0.3768967001565865, 1.6217474405254637, 6.016775633607592, 20.52026949610029, 23.998317105429514, 38.87608827863421, 39.25178779874529, 36.133012431008474, 12.337826779910497, 2.4841038925307135, 0.13521639576980046, 0.18441190810075828, 0.12586181344730513, 0.1595920877797263, 0.17934791983238288, 0.10979448418532099, 0.09251297757561718, 0.15519053967935698, 0.102565928495356, 0.10427401148314987, 0.16273207643202373, 0.12030334956943989, 0.09123632072338037, 0.13717852905392647, 0.08309941698930093, 0.126103154782738, 0.08939076654080834, 0.1080495228192636, 0.1092810503074101, 0.18864614303622926, 0.08830941242298909, 0.05950013188911336, 0.15262859500944614, 0.09712912594633442, 0.08678892401180097, 0.143552442746503, 0.09824045774127756], [0.015492693221728717, 0.04740428505465388, 0.032991889132452865, 0.015728034611259187, 0.0586681936734489, 0.026743979392839328, 0.05366750254428812, 0.0527304728249354, 0.018167581741831133, 0.05301659407892397, 0.014522187977230974, 0.018829538453636423, 0.03605505744261401, 0.08429094483809811, 0.05703194718807936, 0.03051336695040975, 0.0261428363820804, 0.08232214834008898, 0.007831931080935257, 0.018220862007832954, 0.0567857271858624, 0.06099682407719748, 0.04007597114624722, 0.01473417249508202, 0.025078016466328075, 0.10225875569241387, 0.010476087053705539, 0.02733711738671575, 0.05117705510929227, 0.05698681782398905, 0.08123777474143676, 0.024872377947238938, 0.06141749543270894, 2.8919820402349745, 20.218147924968175, 36.40076126371111, 41.2312844140189, 23.91134650366647, 18.134348426546367, 17.81980173928397, 10.771239025252205, 2.250223836728505, 0.13815810291894845, 0.7961299142667225, 0.2493058166333607, 2.9076033277170996, 2.4242486357688904, 1.4514881308589662, 1.6427669354847498, 0.6759458375828606, 1.7679781424147742, 3.273548662662506, 11.765615701675415, 29.59583452769688, 43.323331424168174, 50.82154941558838, 51.56894281932286, 50.803779397692, 51.75940683909825, 49.075345516204834, 50.23150839124407, 47.64996426446097, 46.72098316465105, 43.12346649169922, 46.87023741858346, 46.738315446036204, 44.93565048490252, 45.63955511365618, 45.38606398446219, 44.566058431352886, 45.485284260341096, 46.912531103406636, 47.79734250477382, 47.286003725869314, 47.48410381589617, 46.53005708966936, 45.32204328264509, 38.68196950639997, 35.665047781808035, 35.83839838845389, 36.70118400028774, 35.54654972893851, 41.18331057684762, 45.05939095360892, 48.49474014554705, 45.5653726713998, 45.366817474365234, 44.82072728020804, 46.09890399660383, 39.22857386725289, 31.12167978286743, 47.710424014500205, 38.1361711365836, 45.01662131718227, 44.38282401221139, 47.037626470838276, 46.597030775887625, 44.40111167090279, 33.27562134606497, 31.206645829336985, 33.622214862278526, 42.742270946502686, 44.73041459492275, 45.53055872235979, 40.452902044568745, 44.4514548437936, 44.97314991269793, 46.14076689311436, 47.463099411555696, 42.969049726213726, 43.294117723192485, 41.23303883416312, 37.87836865016392, 33.66633939743042, 36.103076117379324, 35.20524031775338, 34.99538387571062, 37.08023950031826, 40.60181931086949, 42.512299469539094, 43.57862908499581, 44.144038745335166, 46.353777817317415, 48.83229752949306, 45.22131177357265, 36.25829887390137, 23.719734294073923, 11.69182322706495, 3.0559981763362885, 1.8121936555419649, 6.4087695479393005, 2.697720612798418, 2.119791818516595, 1.682384152497564, 0.393764890730381, 0.05567078558462007, 0.08478865705962692, 0.07568741935704436, 0.07111398476575102, 0.05401748412155679, 2.4234278798103333, 7.642341000693185, 16.451077835900442, 21.084041118621826, 27.725311722074235, 27.273359196526663, 16.3480794770377, 1.9032538150038039, 0.5733683332800865, 0.0397038218299193, 0.05384669346468789, 0.029326476888465028, 0.027089977969548533, 0.01274576039785253, 0.05280794795336468, 0.05795542656310967, 0.02688619015472276, 0.021943574837808098, 0.05978745075740984, 0.03965436341241002, 0.028941191134176085, 0.0050294682233860445, 0.05662802546950323, 0.06150419185204165, 0.05093084867777569, 0.06028409767895937, 0.028210953443444202, 0.028821168467402458, 0.05416524190721767, 0.018924336581091796, 0.029744739444660287, 0.04067618965304323, 0.05893000641039439, 0.008985530518527542, 0.034438865059720616, 0.068662573450378, 0.012966408959722944, 0.03357791607933385, 0.01521492303748216, 0.043998758508158584, 0.08998858303363834, 0.030511538298534494, 0.03376222654644932, 0.03548622118043048, 0.015596766922889011, 0.04526333404438836, 0.01610224667404379, 0.02721365794007267, 0.09261477139911481, 0.0429402167376663, 0.012358020043133624, 0.014731656826500381, 0.05231501261836716, 0.05291899360184159, 0.01441972070772733, 0.03346844123942511, 0.03107212357489126, 0.02170027932152152, 0.024264134067509855, 0.04935800111187356, 0.039219853335193226, 0.05346620834565588, 0.05576920369639993, 0.06285152491182089, 0.0801912701821753, 0.007225587099258388, 0.016627960339454666, 0.03964109805279544, 0.1306098893816982, 3.8762323686054776, 24.129545995167323, 42.09522342681885, 42.18737391063145, 29.95230838230678, 20.05474192755563, 19.4591440813882, 12.719313280923025, 2.5136363421167647, 0.11418320797383785, 0.39104296107377323, 0.30430900518383297, 0.556749165058136, 1.9258730241230555, 3.6151720455714633, 1.6701946237257548, 1.5405405866248267, 2.5826074182987213, 3.649894799504961, 15.019912208829608, 33.583402224949424, 45.51289987564087, 53.714275564466206, 53.23270981652396, 54.40131344114031, 53.513854776109966, 49.554931027548655, 51.9013237953186, 48.433870451790945, 46.86073228291103, 45.63946826117379, 50.010625158037456, 48.89250714438302, 46.64786727087838, 45.55894211360386, 46.02273784364973, 46.43423100880214, 47.47541161945888, 48.196252482278005, 49.11123296192714, 49.199902398245676, 48.872148922511506, 48.10943126678467, 47.328450271061485, 41.33533716201782, 36.91629328046526, 37.56891672951834, 37.4838673046657, 37.17657627378191, 42.00244413103376, 45.93481533867972, 49.86337545939854, 47.00710998262678, 46.196818011147634, 45.39988047736031, 47.13823638643537, 41.49222748620169, 32.99148866108486, 47.76385218756539, 40.213953495025635, 44.63178491592407, 45.696387904030935, 49.23899643761771, 47.74728768212454, 45.15679774965559, 34.82049771717617, 33.299325125558035, 34.62950563430786, 44.14602940423148, 48.20800188609532, 47.548628262111116, 44.260719844273154, 44.74812207903181, 46.17871100561959, 46.52912255695888, 48.378698280879426, 45.04821130207607, 44.292097909109934, 41.79836859021868, 39.017824581691194, 35.601857389722554, 36.89427791322981, 35.61186279569353, 35.98762832369123, 38.33926003319876, 41.51421506064278, 43.81904023034232, 46.52412332807268, 45.1835344178336, 48.20383991513933, 49.28948204857962, 47.33183056967599, 38.40777274540493, 26.24671595437186, 14.701670816966466, 4.198802488190787, 3.33078162584986, 6.082308002880641, 3.1439365318843295, 2.310521824019296, 1.3659518978425433, 0.26078641201768604, 0.06660576417509999, 0.1240528119461877, 0.05025939077937177, 0.03687755384349397, 0.2573822018291269, 2.303018638065883, 8.838034783090864, 17.188191379819596, 24.956553595406668, 31.604683807918004, 31.67805678503854, 20.894728762762888, 3.5955010439668382, 0.9188404210976192, 0.02269476738625339, 0.014133505307004919, 0.00728652039210179, 0.00459086276324732, 0.07155013350503785, 0.018948222710085765, 0.054701501703155894, 0.00405745069396549, 0.01649823292557682, 0.05107068456709385, 0.03048072602333767, 0.06546879732715231, 0.044277711039675136, 0.06686022159244333, 0.026952418565217937, 0.04660746781155467, 0.04968669365293213, 0.019919973066342727, 0.02690144531827952, 0.035679644372846396, 0.016642638748245578, 0.013820043332608683, 0.022437896080581204, 0.011931977234780788, 0.020735460200480053, 0.05952376526381288, 0.10949864970254046, 0.04424789281828063, 0.13633340011749948, 0.08188954833894968, 0.13198939178671154, 0.15559785068035126, 0.07794048131576606, 0.1056880173938615, 0.09287464352590696, 0.1066146112446274, 0.08576199518782751, 0.060744463333061764, 0.0741669445165566, 0.12351598218083382, 0.18015377516193049, 0.11513171850570611, 0.14356114156544209, 0.10305770353547164, 0.15355945006012917, 0.16583861330790178, 0.09238879209650414, 0.17135911993682384, 0.11060372540461165, 0.24674537831119128, 0.07516219932585955, 0.13526173547974654, 0.11762648820877075, 0.14250087631600244, 0.11304927417742354, 0.16889647208154202, 0.12250364864511148, 0.240301249814885, 0.10388586909643241, 0.20231379249266215, 5.365011155605316, 28.64892360142299, 47.982814243861604, 51.33888796397618, 36.33288778577532, 26.553581408091954, 26.169351237160818, 15.018949883324758, 2.735306893076215, 0.6831518251981054, 2.1280786309923445, 2.2035334621156966, 9.564554929733276, 8.681318163871765, 7.8380847828728815, 3.092519428048815, 4.2329107608113965, 4.955278924533299, 4.176187404564448, 14.551620125770569, 33.38338095801217, 46.092098236083984, 52.87066698074341, 54.655537605285645, 54.80147409439087, 55.536662987300325, 51.86591577529907, 53.20128658839634, 49.20750720160348, 47.2881646156311, 46.179753235408235, 51.114131110055105, 49.663715498788015, 48.39540522439139, 48.329536301749094, 48.72766808101109, 49.581146580832346, 48.95766387666975, 48.386011259896414, 49.53974226542881, 50.78515475136893, 50.78773948124477, 50.403153215135845, 48.581870555877686, 43.04561192648751, 37.98056970323835, 38.19524819510323, 38.65612915584019, 38.53784302302769, 43.88148716517857, 49.97925404139927, 51.480044092450825, 48.17301770618984, 46.250002997262136, 45.86508321762085, 46.176838466099326, 42.52894040516445, 37.37883833476475, 46.77016598837716, 40.61784185682024, 46.19875308445522, 46.624736717769075, 50.79333278111049, 50.088007245744976, 47.04240335736956, 36.085069860730854, 34.48192589623587, 36.989099979400635, 46.162507806505474, 49.3698171206883, 49.29389762878418, 44.221695286887034, 44.33599315370832, 46.33053609303066, 47.38353558949062, 50.194304261888774, 46.629409381321494, 47.111774172101704, 45.398820877075195, 41.86330298015049, 37.530177048274446, 40.175870418548584, 38.04143244879586, 37.664138317108154, 40.469734055655344, 43.54509013039725, 47.2433626311166, 47.01990509033203, 47.82276596341814, 50.25574023383004, 50.97068555014474, 47.819604533059255, 38.62241997037615, 27.116527932030813, 15.266015665871755, 4.464709614004407, 4.763377496174403, 14.659969466073171, 6.89524723802294, 4.922399180276053, 4.312960956777845, 1.925828946488244, 0.13200406171381474, 0.41393621691635674, 0.1937518883496523, 0.17686697867299828, 0.36334100897823063, 2.985302426985332, 12.150489449501038, 23.87446893964495, 31.428835323878697, 36.584881578172954, 38.2736690385001, 23.19534853526524, 4.795498583997999, 0.7340571507811546, 0.15500306045370443, 0.09635906333902053, 0.07881075675998415, 0.16202059175286973, 0.1436294157590185, 0.20719834896070616, 0.1335242379988943, 0.08248855226806232, 0.14672263977783068, 0.19199590757489204, 0.2807019576430321, 0.09403290280273982, 0.1675371221665825, 0.14093660882541112, 0.08716251182236842, 0.11194197288049118, 0.17132511176168919, 0.12653330527245998, 0.07796617743692227, 0.14235298282333783, 0.0908347297725933, 0.1401902474462986, 0.11498288863471576, 0.09239280223846436, 0.22061423478381975, 0.08162462791161877, 0.2222622742078134], [0.06210369789706809, 0.052116262926054854, 0.07730468043259212, 0.07083121886742966, 0.02839609850863261, 0.020858899291072572, 0.044286070591104884, 0.026260345076609935, 0.012946068176201411, 0.044453339651227, 0.011904455006255634, 0.011260838247835636, 0.025668572634458542, 0.019274157006293535, 0.058787670119532516, 0.012366304955711322, 0.04376999042662127, 0.02872553913454924, 0.03006511993174042, 0.038496969267725945, 0.013966827420517802, 0.03059224664632763, 0.04448475921526551, 0.051763584172087054, 0.025524412780734043, 0.004915816152268755, 0.03612048518178718, 0.02252664676468287, 0.049781423926885636, 0.07359343993344478, 0.04695699137768575, 0.0205433347062873, 0.0416652596156512, 0.76971492597035, 8.080499614988055, 25.700234924043926, 37.346018518720356, 28.81101812635149, 28.235486677714757, 20.71680624144418, 15.866447721208845, 5.325747753892626, 0.5094374694994518, 0.058768494719905515, 0.29553006482975824, 0.4566262204732214, 0.8926109714167458, 0.9108442387410572, 0.09572552876280886, 0.15298482589423656, 1.4332190368856703, 0.7395828685590199, 4.854211730616433, 16.825719492776052, 32.47697802952358, 43.060682569231304, 51.934126240866526, 52.397518975394114, 51.32405008588518, 49.81266403198242, 52.41705730983189, 48.749794619424, 47.30712277548653, 45.61942965643746, 49.4140111378261, 47.57809904643467, 48.052824292864116, 47.192029339926584, 46.28017207554409, 46.589898450034006, 48.82164246695382, 47.21509388514927, 46.21857282093593, 45.82204260144915, 45.08437320164272, 43.25622572217669, 39.04936940329415, 36.26182508468628, 36.40897056034633, 37.368707861219136, 37.91350221633911, 34.74841710499355, 38.39258745738438, 45.33332020895821, 47.86889157976423, 46.32418196541922, 47.20478275844029, 45.6095632144383, 46.394115584237234, 41.2080739566258, 30.057872363499232, 48.06403521129063, 41.73910393033709, 45.87091623033796, 48.599518980298726, 45.70801224027361, 44.47621474947248, 41.17514991760254, 32.50300598144531, 32.629303387233186, 32.295598779405864, 43.02980824879238, 44.88798236846924, 44.92218835013253, 43.91727386202131, 45.46385254178728, 45.913004943302695, 43.301312582833425, 43.99995742525373, 46.10522338322231, 43.386181354522705, 44.26566001347133, 42.66285303660801, 40.73264694213867, 38.41224043709891, 35.621176855904714, 37.17333493913923, 40.04026242664882, 41.5069055557251, 43.474642344883506, 44.59928124291556, 46.50070095062256, 46.98319428307669, 45.06748560496739, 37.173776149749756, 23.74933535712106, 12.361363802637372, 3.610085529940469, 0.9707059008734567, 3.8969267095838274, 5.717389915670667, 1.8892694796834673, 1.200576520391873, 1.5742378298725401, 0.27121248255882946, 0.06815393681504897, 0.10207415345524039, 0.06633783105228629, 0.16298816911876202, 0.259945137160165, 4.312526260103498, 9.935061539922442, 19.895544801439556, 27.590344701494487, 30.05962678364345, 27.412694896970475, 10.564916610717773, 1.2407644667795725, 0.04987300240567752, 0.008394456119276583, 0.0302358698765082, 0.031185255718550513, 0.014509976043232849, 0.00399881212173828, 0.022279408959937946, 0.07942229323089123, 0.03344157125268664, 0.030058460110532384, 0.02494017716630229, 0.07932425170604672, 0.020782421609120708, 0.0579666563176683, 0.0506908711977303, 0.012117483619866627, 0.026117939235908643, 0.02061420938532267, 0.05454761674627662, 0.03511603622298155, 0.0993552975622671, 0.024141154684392468, 0.06801798553871256, 0.024834992364048958, 0.07404739343162094, 0.04605875011267407, 0.01730521971226803, 0.04823793996391552, 0.059568894627903185, 0.016499381346095885, 0.00472124623567132, 0.03724796950284924, 0.04514476344255464, 0.007859616157864886, 0.023621091519349387, 0.0282349498343787, 0.0661546333826014, 0.08685464691370726, 0.03307670261710882, 0.040118752779173, 0.006159250657739384, 0.006185517596480037, 0.04320096417463251, 0.03050422708370856, 0.0314263358180012, 0.01414580290604915, 0.012473301446464444, 0.023332308711750165, 0.0376494111759322, 0.06806211745632545, 0.015701824499826347, 0.02126307546028069, 0.005498620057811162, 0.02844024060427078, 0.06875809082495314, 0.005830963965438838, 0.05106939535055842, 0.053201691646661074, 0.024137979140505195, 0.03164704629619207, 0.005939904883104775, 1.0549582370689936, 11.169488055365425, 32.15951483590262, 45.98352915900094, 31.691070760999406, 23.89054533413478, 22.638691868100846, 18.502396242959158, 5.652500254767282, 0.7528204896620342, 0.05000849227820124, 0.21266849472054414, 0.14312633632549218, 0.37812585277216776, 0.8510802313685417, 0.5844091836895261, 0.6516106405428478, 1.7953427540404456, 1.0586818201201302, 5.996786100523813, 19.680485895701818, 34.83055176053728, 45.6686680657523, 54.384568282536094, 53.404340744018555, 53.22297191619873, 50.820097242082866, 52.61120387486049, 49.56633302143642, 46.858644349234446, 47.59502485820225, 49.57362168175833, 48.82559599195208, 47.45924663543701, 49.3389184815543, 47.25757169723511, 47.38859040396554, 50.14119570595877, 48.60473012924194, 48.59691340582711, 47.13331706183297, 47.06455768857683, 45.636456217084614, 41.864230564662385, 38.78495570591518, 38.247613293784006, 38.92506960460118, 38.61658000946045, 36.671028818402974, 40.16515629632132, 46.35390635899135, 49.84987163543701, 47.47264623641968, 48.32182032721383, 46.928925377982004, 45.27382278442383, 41.90319258826119, 33.469833918980186, 47.54378884179251, 41.927490438733784, 46.50126722880772, 49.300171852111816, 47.58517231260027, 45.7861134665353, 44.18662772859846, 34.522208077566965, 33.10522024972098, 34.33029883248465, 44.1134249823434, 46.52363000597273, 46.82995523725237, 43.738680839538574, 46.631400040217805, 46.152759483882356, 44.735778604234966, 47.11412961142403, 45.73834112712315, 45.09220034735543, 45.78168051583426, 46.05932705742972, 41.7287928036281, 39.903855391911094, 38.13884619304112, 37.384372574942454, 41.30413280214582, 43.66480759211949, 45.31685297829764, 45.42959444863455, 47.864997114454, 47.418429442814414, 46.33113711220877, 40.056760924203054, 28.204560245786393, 15.966699804578509, 3.2287668713501523, 2.4306003749370575, 4.21600318806512, 7.2672633443559915, 0.9536944308451244, 0.7804610207676888, 1.1938808453934533, 0.26384883054665154, 0.1694043826844011, 0.06831268008266177, 0.16898848143007072, 0.1897613831928798, 0.5085711159876415, 4.5797509380749295, 10.361270121165685, 23.45870089530945, 30.56675148010254, 33.433724130902974, 32.84036534173148, 12.744431018829346, 1.673132300376892, 0.12692283865596565, 0.015118611776935202, 0.12259569870574133, 0.010587914713791438, 0.03722005117950695, 0.027250539711011306, 0.03923792950809002, 0.011382308738705302, 0.01435709192550608, 0.04394011611917189, 0.005008564255799034, 0.07340805059564964, 0.04304973568235125, 0.03004621255344578, 0.019792277864845734, 0.01159958158885794, 0.007952117444282132, 0.006039412043589566, 0.05177302937954664, 0.017106215569323728, 0.030970373856169835, 0.043079693003424575, 0.024142096151730845, 0.06725356834275381, 0.0452928333543241, 0.06382172142288514, 0.07580378811274256, 0.021473289001733065, 0.1777512455093009, 0.15283709524997643, 0.18996141531637736, 0.16740404787872518, 0.12946874275803566, 0.09494531527161598, 0.12810684155140603, 0.1311620676091739, 0.1500523875334433, 0.21425093337893486, 0.17484491717602524, 0.11017283531171934, 0.13618896715342999, 0.09386184412453856, 0.1121292756870389, 0.17929042077490262, 0.1664139295795134, 0.08984579890966415, 0.09893189849598066, 0.10411332082003355, 0.08473774657717772, 0.18582825495728425, 0.1396488036428179, 0.12227274317826543, 0.11242435699594872, 0.07817970562194075, 0.20617161691188812, 0.11538136510976724, 0.13167677713291986, 0.14371763888214314, 0.15078428254595824, 0.08075024054518767, 0.13665702060929366, 1.2739366867712565, 12.172601222991943, 39.362351008823936, 52.2480354309082, 38.198166438511436, 36.54677765710013, 31.21306596483503, 23.004210540226527, 7.243666393416269, 1.0375333492244994, 0.4818773312228066, 0.6563514290111405, 1.6318595664841788, 4.778314386095319, 2.5743212572165897, 0.9850607705967767, 1.3786823004484177, 2.735107349497931, 1.2301247119903564, 6.001391887664795, 19.055113281522477, 34.72959096091134, 46.189313956669395, 55.171354498182026, 54.20773662839617, 53.280575956617085, 49.63378960745675, 53.69303492137364, 49.32568563733782, 47.16012668609619, 47.5539436340332, 51.04683780670166, 48.780377115522114, 51.34187568937029, 51.60291256223406, 49.12056786673409, 49.71036223002842, 51.996858051845, 50.58789886747088, 49.831007276262554, 49.05918400628226, 48.83175209590367, 47.154220717293875, 43.78314583642142, 41.92554841722761, 39.55057423455374, 41.14103078842163, 40.90665762765067, 38.015136991228374, 42.055552686963765, 49.835735525403706, 51.48768016270229, 48.18605252674648, 49.97712789263044, 46.6423191343035, 45.989813804626465, 43.28067295891898, 36.8227288382394, 46.76649733952114, 44.2111097063337, 47.73628520965576, 52.35543026242937, 48.64863232203892, 47.294126170022146, 45.43983609335763, 36.28007452828543, 35.34104980741228, 35.63941240310669, 45.82993575504848, 48.89439010620117, 46.02960613795689, 45.60077721732003, 46.4473283631461, 46.108614104134695, 44.89682742527553, 46.756022930145264, 48.880629198891775, 46.12489720753261, 47.1605018888201, 46.97284146717617, 44.54737819944109, 41.94080318723406, 39.1166661807469, 40.503022875104634, 44.23391369410923, 44.75421217509678, 47.078193528311594, 46.7300192969186, 49.94899811063494, 48.93334518160139, 47.36823913029262, 41.941320828029085, 29.177024909428187, 15.111489466258458, 5.533699955259051, 4.057122639247349, 6.669009115014758, 9.603122643062047, 8.086626189095632, 2.1641347876616885, 4.65553320305688, 0.9309131332806179, 0.2328008051429476, 0.3406572847494057, 0.17644232431692736, 0.34389215973871096, 0.67873222806624, 6.2435513734817505, 14.251716767038618, 28.665463788168772, 36.209015301295686, 41.122579847063335, 37.45760311399187, 15.25665991646903, 2.0219553198133196, 0.2688430925565106, 0.10815142520836421, 0.21246323787740298, 0.07948065402784518, 0.14444544911384583, 0.13435230856495245, 0.13124281327639306, 0.12501859797963075, 0.1789304579475096, 0.15152346502457345, 0.10908553722713675, 0.28363542737705366, 0.11267495354903595, 0.1482931226491928, 0.1275637149810791, 0.05144844876070108, 0.14139041304588318, 0.11156837149922337, 0.13529883777456625, 0.09881462050335747, 0.18830701123390878, 0.09179231910301106, 0.1282669622451067, 0.12871419824659824, 0.15430733135768346, 0.18659132186855587, 0.14501533710530826, 0.08441589027643204], [0.012300971363271986, 0.018103466967919042, 0.05997275188565254, 0.1129062661368932, 0.010059482667462101, 0.01525484973431698, 0.0358144896371024, 0.02266214002988168, 0.026221196998709013, 0.029716468283108304, 0.0455468599019306, 0.09359892537551266, 0.055366649225886376, 0.0462278172905956, 0.007322508193153355, 0.04092320014855691, 0.06560529821685382, 0.08174742239394359, 0.03310473968407937, 0.05151517250175987, 0.018721244264660136, 0.07666866241821221, 0.057552478542285304, 0.024814631224476864, 0.04712182788976601, 0.03892927071345704, 0.0633582684344479, 0.033240005640046935, 0.01763038896024227, 0.05672015356166022, 0.03422764389376555, 0.07835292204150132, 0.02207431666153882, 0.04756945404889328, 1.8762170714991433, 15.637746027537755, 35.98882341384888, 32.53716679981777, 31.82459429332188, 12.652263164520264, 11.305321863719396, 10.589393377304077, 1.447449381862368, 0.3065873629280499, 0.15575730640973362, 0.047727515388812335, 0.30095763930252617, 0.8533754167812211, 0.29145681911281174, 0.031102925672062805, 4.617435795920236, 0.32009745655315264, 0.8147715511066573, 7.734990017754691, 17.10374297414507, 31.54565191268921, 41.71079002107893, 47.963633741651265, 49.84398651123047, 51.524179049900596, 49.913836751665386, 52.285795416150776, 47.91242551803589, 48.21332768031529, 47.868234974997385, 50.168304102761404, 48.90549332754952, 47.87818479537964, 46.74843897138323, 45.182922976357595, 43.48441498620169, 43.96451119014195, 44.673710346221924, 41.90319258826119, 40.638478006635395, 37.27084248406546, 35.63335357393537, 35.31311457497733, 37.29691559927804, 38.27527059827532, 38.21344552721296, 39.57164464678083, 38.82462297167097, 44.640789781297954, 46.71505635125296, 48.52095569883074, 47.45208304268973, 47.34892313820975, 47.14193977628435, 41.177487986428396, 32.82075752530779, 48.299196992601665, 44.05763094765799, 48.600915568215505, 45.42432771410261, 44.17270006452288, 42.01045887810843, 37.67603363309588, 32.21565975461687, 33.87181500026158, 34.68178040640694, 41.86896923610142, 46.01047427313668, 47.718588147844585, 48.848712648664204, 45.06682552610125, 45.89288296018328, 46.78249556677682, 48.3662679536002, 46.69095652444022, 45.319138935634065, 45.066214084625244, 44.768862451825825, 42.61552538190569, 41.668795108795166, 41.124063287462505, 38.3402327810015, 39.83680527550833, 42.93020234789167, 44.41237122671944, 45.86443703515189, 47.25439984457833, 45.913029261997764, 38.052834442683626, 24.447135993412562, 12.227248804909841, 4.615690061024257, 1.0940033133540834, 2.9948976721082414, 3.305664539337158, 3.864914187363216, 0.14735092249299797, 1.1627904794045856, 0.754410975745746, 0.051454219701034684, 0.1240144068641322, 0.04208252811804414, 0.36171887602124897, 0.17315556854009628, 1.9368993810244968, 12.35341853754861, 27.382046392985753, 24.903040306908743, 31.76026439666748, 31.553010054997035, 20.103455747876847, 4.553143245833261, 0.274897714810712, 0.005238484574614891, 0.015186653572267719, 0.05560661652790649, 0.020358228656862463, 0.007800361391023866, 0.09784893625016723, 0.016923241816194992, 0.051394260954111814, 0.03472781580473695, 0.050272201520523856, 0.07513532255377088, 0.0751078011734145, 0.002573544862181214, 0.015481393917330673, 0.07387001759239606, 0.03546342579647899, 0.04778194746800831, 0.03502275462129286, 0.031239653870995556, 0.051145676257354875, 0.029012254106679132, 0.06993099288748843, 0.050168908134635, 0.030429988567318236, 0.05379390683291214, 0.04261749530477183, 0.03207084909081459, 0.022475992429203222, 0.03744452752705131, 0.06394467196826424, 0.031568970664271286, 0.053936304191925695, 0.009021856738919658, 0.04888464490483914, 0.03294414062319057, 0.0595759174653462, 0.05127611782933984, 0.04923702510339873, 0.05744721740484238, 0.04416914204401629, 0.048316694130854945, 0.0240835317942713, 0.055685628538153, 0.037640759854444435, 0.07241394251052823, 0.03346628010539072, 0.042921730051083226, 0.026278215992663587, 0.04204433338184442, 0.003454550277508263, 0.01317000254389963, 0.04474155079307301, 0.07280726211943797, 0.03701110649853945, 0.04395520334531154, 0.05544705901827131, 0.02683454515811588, 0.06142280836190496, 0.01723717961327306, 0.037614683753677776, 0.007033728354144841, 0.08748408992375646, 2.98365700670651, 19.826398066111974, 41.63392557416643, 37.24023566927229, 34.06565237045288, 13.74907192162105, 14.805225031716482, 12.730864661080496, 1.5748396090098788, 0.29061681990112576, 0.03544848784804344, 0.06362286316496985, 0.26736991160682266, 0.28295838513544624, 0.08019625741456236, 0.20597459748387337, 2.9560459511620656, 0.5452548904078347, 1.3275874193225587, 8.868247287614004, 19.137407745633805, 34.28782102039882, 45.9691116469247, 50.924549511500764, 51.47878646850586, 51.28272220066616, 51.34027412959507, 52.92510264260428, 48.394366468702046, 47.60348776408604, 47.31332056862967, 51.42699112210955, 48.78632129941668, 48.390951429094585, 49.67036839893886, 47.96408537455967, 46.2362733568464, 46.46866280691964, 46.36251170294625, 43.6666453906468, 44.327134200504844, 38.268673283713206, 36.75899648666382, 35.587297439575195, 38.72363090515137, 38.75760064806257, 39.70280579158238, 40.75310591288975, 39.4130276952471, 46.38500302178519, 47.94181292397635, 48.661309310368125, 49.35578523363386, 46.79225778579712, 47.46098368508475, 42.139056137629915, 36.62201969964163, 47.863715171813965, 46.36888667515346, 49.045760086604524, 47.41238798413958, 46.1845440183367, 43.20833873748779, 39.72895186288016, 33.72120932170323, 33.89475795200893, 36.33640357426235, 42.94919177464077, 48.68028136662075, 48.07142809459141, 48.56398589270455, 45.86003187724522, 45.81574753352574, 46.216731548309326, 49.16866329738072, 48.34423521586827, 45.63099145889282, 46.67879717690604, 45.134087562561035, 44.326383795057026, 42.308390685490195, 41.467498847416465, 41.0524343081883, 41.16325807571411, 43.97334582465035, 44.75620283399309, 48.1172445161002, 47.78116709845406, 46.41549171720232, 39.15762233734131, 28.25210850579398, 15.246274096625191, 5.792088261672428, 1.6731650871889931, 2.2211766753877913, 4.156342480863843, 4.396176925727299, 0.2847566657832691, 0.44598337156432016, 0.7950871959328651, 0.1902104648096221, 0.32915945457560675, 0.30828128489000456, 0.2586987768965108, 0.30745515493409975, 1.6994539222546985, 11.563516054834638, 25.107442413057598, 26.269009249550955, 36.35728638512747, 36.34254230771746, 24.18408761705671, 6.26664935691016, 0.46618433615991045, 0.08504702962402787, 0.0350609900695937, 0.008344573617380644, 0.04548137787995594, 0.013565205087486123, 0.07648741214403085, 0.0393742404079863, 0.018372719841344014, 0.038830954381929975, 0.04067055781238845, 0.05408597544633916, 0.03166985525084393, 0.01831484928594104, 0.047385241969355514, 0.03615504975563713, 0.011466566672814744, 0.02919670706614852, 0.00787158975643771, 0.035262392833828926, 0.03835016482376626, 0.018189096390934925, 0.025672681163996458, 0.07000213049884353, 0.027791070884891918, 0.029681469446846416, 0.022761102666014006, 0.042692934828145165, 0.021261864275272404, 0.13955378159880638, 0.1581000978393214, 0.31318687594362665, 0.132168389324631, 0.07567187411976711, 0.1505382593188967, 0.15833401600165026, 0.11933455084051404, 0.11596449810479369, 0.09363015155707087, 0.10629090932863099, 0.18353450803884439, 0.12670133768447808, 0.10056344951902117, 0.18065025923507555, 0.09759471632008042, 0.18857116491666862, 0.18492315709590912, 0.241916081735066, 0.13413235465330736, 0.13611754455736705, 0.22445049536015305, 0.16155460104346275, 0.1184813201959644, 0.13628768042794295, 0.15389904326626233, 0.15273097237305983, 0.11932815904063837, 0.17177819673504147, 0.19425850973597594, 0.11111044857118811, 0.2055040198777403, 0.07393190677144698, 0.18968264598931583, 3.5029649351324355, 24.52289915084839, 50.794687679835725, 45.635931628090994, 41.48644658497402, 21.972232818603516, 21.1589982850211, 14.026149579456874, 2.3442566309656416, 0.5677273188318525, 0.2434120343199798, 0.3534885176590511, 0.7218434661626816, 3.495458275079727, 2.006835605416979, 0.5223796835967472, 7.2522717373711725, 0.9249162950686046, 1.4814104395253318, 9.219683698245458, 19.09847698892866, 34.44938053403582, 45.38502870287214, 51.54313720975603, 49.894878591809956, 51.66595009395054, 50.8018547466823, 53.64547102791922, 47.11765929630825, 48.343154770987375, 47.9214894430978, 53.21516561508179, 50.64925493512835, 51.59077753339495, 50.96501929419381, 49.29563120433262, 47.49515145165579, 48.216645445142476, 48.45036547524588, 44.67458234514509, 45.50655617032732, 40.02964210510254, 38.145043986184255, 38.06421559197562, 40.89761802128383, 41.30279527391706, 41.1604197365897, 42.742201464516775, 42.1754994392395, 49.33082730429513, 49.94205338614327, 51.389592443193706, 51.003717286246165, 48.57053804397583, 46.74560758045742, 43.172958510262625, 40.396708488464355, 47.7178064755031, 46.10717235292707, 50.87441825866699, 49.04152168546404, 46.542327608381, 43.95733370099749, 40.583535126277376, 35.51648139953613, 36.406920841761995, 37.998975481305806, 44.39950316292899, 50.11495583398001, 49.82178006853376, 49.010407652173726, 45.96382059369768, 47.29062080383301, 47.63112422398159, 49.792472566877095, 48.2336859021868, 47.439791679382324, 48.66916077477591, 47.68700163705008, 46.198593275887625, 44.325112274714876, 43.808930601392476, 43.6547292300633, 43.776447772979736, 47.3385842187064, 48.811633586883545, 49.580809593200684, 48.95203930991036, 48.444306646074565, 40.15500150408064, 28.370776789528982, 13.827061108180455, 6.333392884050097, 3.6047860085964203, 5.7261611478669305, 8.194063578333173, 10.269237756729126, 3.6871597255979265, 3.4928281647818427, 2.590552031993866, 0.41589001779045376, 0.30951138745461193, 0.1460163119648184, 0.9192092184509549, 0.684446849993297, 2.6729359541620528, 13.590540085520063, 31.9107380594526, 34.15174749919346, 41.62067188535418, 40.93091031483242, 27.76114879335676, 7.000594522271838, 0.663686175431524, 0.2918401099741459, 0.10653076467237302, 0.10775626676955394, 0.11116365928735052, 0.09643043165228196, 0.17318076933068888, 0.15618471561798028, 0.07734092098793813, 0.18088731222919055, 0.1562118705894266, 0.21831134121332849, 0.13671656884253025, 0.08454575509365116, 0.15869989565440587, 0.1638594487948077, 0.08662968541362456, 0.20559635492307798, 0.09958747867494822, 0.08801538284335818, 0.0861874230738197, 0.06830077857843467, 0.12403004031096186, 0.2144740628344672, 0.11467802285083703, 0.14173813510153974, 0.15422400725739344, 0.14725847888205731, 0.10352095974875347], [0.053484158989574225, 0.04397349325673921, 0.015808707335963845, 0.05563861284671085, 0.012750628886611333, 0.03614133656291025, 0.04282980891210692, 0.01562185914787863, 0.00410295240414728, 0.06824126427194901, 0.03105978441557714, 0.05039135566247361, 0.007822245841712823, 0.08529926823186022, 0.010742729263646262, 0.028057977723489915, 0.055412721753652604, 0.04824758194653051, 0.026102787548942224, 0.06484566469277654, 0.018371646059677005, 0.03583967685699463, 0.043784782490027804, 0.02477876216705356, 0.05255393836913364, 0.03547356650233269, 0.04349478001573256, 0.03057156489895923, 0.023712230646716695, 0.018806089979729483, 0.06854127853044442, 0.08119269287479774, 0.038033845368772745, 0.03362689273697989, 0.2569497036082404, 7.248031599181039, 25.673585108348302, 38.15760980333601, 28.95099479811532, 22.66238522529602, 17.267946277345928, 11.504298295293536, 5.878388796533857, 0.19819216722888605, 0.1228025976036276, 0.23167970244373592, 0.04919606872967311, 0.2591950302677495, 0.2481121921113559, 0.09035447625709431, 2.323618092707225, 4.494802696364267, 0.2554465856935297, 1.7532716287033898, 6.3672149777412415, 16.793221030916484, 27.1219197341374, 37.568798610142295, 43.1190231187003, 48.29381561279297, 50.05499635423933, 51.49525022506714, 48.51609543391636, 50.07092162540981, 47.64666734422956, 48.24423674174717, 50.90203734806606, 49.33818197250366, 46.76048714773995, 46.604979515075684, 42.98748677117484, 42.274347986493794, 39.62833152498518, 38.18888364519392, 37.79658835274832, 37.00561237335205, 36.590679849897114, 38.155573981148855, 38.270181042807444, 36.97728109359741, 37.62258808953421, 36.474950654166086, 38.63263382230486, 40.05698674065726, 46.118004594530376, 47.41171053477696, 47.709989752088276, 49.175830364227295, 51.193083490644185, 45.08004447392055, 32.64519739151001, 47.412283761160715, 45.46742391586304, 47.884740420750205, 45.236948694501606, 44.415925230298726, 37.644117082868306, 33.560115337371826, 31.7841523034232, 33.35604674475533, 33.83496870313372, 41.3544134412493, 46.76617077418736, 44.99387986319405, 44.61920520237514, 45.22075244358608, 47.04509925842285, 45.75215067182268, 46.318543502262656, 46.88170542035784, 46.635343142918174, 45.95775481632778, 45.9212246622358, 45.84433242252895, 44.373298031943186, 43.522550174168174, 41.48041902269636, 40.238452843257356, 42.20491116387503, 45.63725525992257, 45.65223210198538, 43.20929758889334, 38.67720651626587, 28.12336359705244, 16.233894518443517, 4.962832484926496, 1.3230658790894916, 0.7422971171992165, 2.1704628595284055, 1.9847616127559116, 5.155474330697741, 0.24101254450423376, 0.4221682851868016, 0.37412206189973013, 0.047648886750851355, 0.4984847200768334, 1.354313230940274, 0.6887649382863725, 0.849752528326852, 5.44690957239696, 13.4397919688906, 33.064218929835725, 34.112552710941856, 28.15827308382307, 31.772072860172816, 13.127194251332964, 1.6736862020833152, 0.024792141181283762, 0.11305994753326688, 0.044446411808686595, 0.02385745749675802, 0.04762147393609796, 0.041491157707891295, 0.02943820446463568, 0.05951725811298404, 0.010379953908600976, 0.04179052396544388, 0.029018459309424673, 0.023322836362889836, 0.051237882381039004, 0.011542202971343483, 0.033367783962083716, 0.010031864595865565, 0.03755287939150419, 0.02677709699076201, 0.02190915445264961, 0.045493102965078185, 0.02327073335514537, 0.029105589991169314, 0.08139364102057048, 0.06191697184528623, 0.03284495237416454, 0.08481091979358878, 0.06870375374065978, 0.04209992236324719, 0.041180571873805354, 0.03719883678214891, 0.023664573739681925, 0.030141149780579975, 0.048748266151441, 0.03963061807943242, 0.029846794504140104, 0.015936511103063822, 0.08920068852603436, 0.05322740473119276, 0.01814999750682286, 0.01710120289187346, 0.037287317748580656, 0.05379043273361666, 0.010290538260181035, 0.0014447664476132818, 0.021740957495889494, 0.060968949858631404, 0.025225708094824637, 0.02741212264767715, 0.08252317791006394, 0.01595723525887089, 0.04439806958128299, 0.025974045707178966, 0.031390217398958545, 0.019176809283505594, 0.038099303642021756, 0.032937616508986266, 0.06715730457965817, 0.0050723537569865584, 0.035580493443246396, 0.02844928208339427, 0.011112907435745, 0.019739123127822365, 0.0387323937777962, 0.48712213550295147, 9.442224076816014, 33.23733329772949, 43.91218083245413, 32.18237440926688, 18.672206742422922, 18.640090431485856, 13.896516169820513, 6.207814182553973, 0.8963944826807294, 0.029558278021535704, 0.34636607127530233, 0.1640966646373272, 0.13859921853457177, 0.2428655150745596, 0.145290075934359, 3.3616049204553877, 2.417953133583069, 0.19657645321318082, 2.102530321904591, 8.768589275223867, 19.967145987919398, 27.80199898992266, 39.76774365561349, 45.19350855691092, 49.8666341645377, 50.99176638466971, 51.106369972229004, 49.2224770954677, 49.52534212384905, 47.78999825886318, 48.92662279946463, 51.65324183872768, 51.04950244086129, 48.3899439402989, 47.149787766592844, 44.402306761060444, 43.69762045996529, 42.071227822984966, 39.930018833705354, 39.27659286771502, 38.12135757718767, 37.881707259586875, 38.06629657745361, 40.01719093322754, 39.62945018495832, 39.41384758268084, 38.85625811985561, 39.442488057272776, 43.38679279599871, 47.55290487834385, 49.137660435267854, 50.06487669263567, 50.6529027393886, 50.71857016427176, 45.75271347590855, 36.505880560193745, 47.63446978160313, 46.871255329677034, 49.58438791547503, 46.68484558377947, 46.333343165261404, 40.36931521551949, 35.10126747403826, 32.572543552943635, 35.20933280672346, 35.09277677536011, 42.884427615574424, 48.764573437826975, 47.39007731846401, 45.426346165793284, 46.34094796861921, 48.40129382269723, 48.29358632223946, 48.34712219238281, 47.168721607753206, 47.90436213357108, 47.988466603415354, 46.09103863579886, 46.176442418779644, 44.495357036590576, 45.17952878134591, 42.73568058013916, 42.13775682449341, 43.28486272266933, 47.377792903355186, 46.24330840791975, 45.90996510641915, 40.483884062085835, 30.914349011012487, 16.600146225520543, 7.72865412916456, 2.4609768135207037, 1.8848819094044822, 3.463615332330976, 2.4719371625355313, 5.02236465045384, 0.352291609027556, 0.4601049880896296, 0.48330871441534584, 0.27552155990685734, 0.6732163354754448, 2.199168690613338, 0.17779480745749815, 0.7796441188880375, 6.532326323645456, 18.1854750088283, 36.30706480571202, 37.01580190658569, 33.194758210863384, 35.42442124230521, 16.066463776997157, 2.467368939093181, 0.1556899007409811, 0.039031838066875935, 0.10338245039539677, 0.049949042432542355, 0.044028033901538165, 0.026225987455940673, 0.023853659396991134, 0.05914020977382149, 0.033997047160352976, 0.04889948107302189, 0.010279512914296771, 0.027646200265735388, 0.02860848166580711, 0.028744273486414125, 0.0332600529571729, 0.024544869449787905, 0.026947870684255446, 0.019503349172217504, 0.008553559858618038, 0.042299903596618345, 0.02058335130901209, 0.05717231572738715, 0.053215167352131436, 0.07162655011883803, 0.04330219142138958, 0.03292890072667173, 0.02108548757886248, 0.030139388982206583, 0.03624174617496984, 0.19167018362454005, 0.12810719438961574, 0.10613407274442059, 0.1244011175419603, 0.1145935452410153, 0.07762336118945054, 0.07675057516566344, 0.14053011206643923, 0.14360835403203964, 0.15195018212710107, 0.052182318310120275, 0.09917007785822664, 0.16720549496156828, 0.18318517106984342, 0.2051887453666755, 0.061703749001026154, 0.17079190537333488, 0.13777335999267443, 0.09509645894701992, 0.19688955641218595, 0.11152129473962955, 0.17005243791001184, 0.18309694794671877, 0.12359727067606789, 0.12052312706198011, 0.13102984827544006, 0.1403490924941642, 0.16552728787064552, 0.12683811677353724, 0.11872663774660655, 0.16194101316588266, 0.15337100731475012, 0.1016760841012001, 0.14565318716423853, 0.7674628953848566, 11.743790541376386, 38.60484797613961, 52.610741819654194, 39.23088761738369, 32.05714702606201, 26.011767830167496, 18.63694637162345, 6.851660319737025, 1.3018524859632765, 0.3058950129364218, 0.928427415234702, 0.3455347301704543, 0.6468720233866146, 1.7233947004590715, 0.5690869401608194, 5.1813346573284695, 5.6462816170283725, 0.5388229212590626, 2.2715956270694733, 7.570499232837132, 18.780956472669327, 28.53407335281372, 39.56216035570417, 46.410853794642854, 49.14205517087664, 51.429311820438926, 51.02886281694685, 50.99615069798061, 49.559662750789094, 48.840016978127615, 47.250185762132915, 53.4101494380406, 52.73758118493216, 50.251647744859966, 50.672413281032014, 47.05069950648716, 46.22714689799717, 44.1984292439052, 41.61037812914167, 40.79544823510306, 40.68638236182076, 39.96920319965908, 40.624077865055625, 41.24838393075125, 41.186781202043804, 42.017959458487375, 41.13832793916975, 41.67550706863403, 43.86534997395107, 49.857994079589844, 50.6465277671814, 51.07381418773106, 52.418975012642996, 52.436630385262625, 45.677506174360005, 39.915715966905864, 47.65874678747994, 48.12469645908901, 51.147600582667756, 48.4091591835022, 48.052539416721885, 41.421623366219656, 37.002298082624165, 34.78185878481184, 36.0167794908796, 36.270190715789795, 43.452210085732595, 50.52388858795166, 47.32386793409075, 47.2483549118042, 47.58750690732683, 48.50349834987095, 49.5598156111581, 50.112041064671104, 48.62424067088536, 48.45345394951956, 48.86633675439017, 47.861186027526855, 49.311917781829834, 47.30049071993147, 46.31330803462437, 45.49525839941842, 44.30751248768398, 45.792540550231934, 48.29104675565447, 48.36310652324131, 47.440212045397075, 41.214351654052734, 30.783535276140483, 19.12137304033552, 6.80188342503139, 2.987323049988065, 2.65391634617533, 6.368427872657776, 8.72420070852552, 11.07278389590127, 1.518763195191111, 0.5949629002383777, 1.576763065797942, 0.51589185744524, 1.690794621195112, 3.995802181107657, 1.631985176886831, 1.5541635070528304, 7.1184989384242465, 17.46644762584141, 38.83577135631016, 43.396419525146484, 39.179536955697195, 40.909495966775076, 18.3929933820452, 2.8006093204021454, 0.2526440460767065, 0.11952587057437215, 0.153028794963445, 0.20569814874657563, 0.15387096548719065, 0.14040313102304935, 0.11270157247781754, 0.20101986692420074, 0.1454931886068412, 0.07633351361645119, 0.10550940662090268, 0.15310773572751454, 0.11152649231787239, 0.1575055518852813, 0.09134190755763225, 0.11168944928795099, 0.1571998990007809, 0.12353016356272356, 0.09982147147612912, 0.10707185563764401, 0.11328898024346147, 0.15263136343232223, 0.10587698939655509, 0.2250035149710519, 0.20693715369062765, 0.1304563776190792, 0.13094933331012726, 0.07032679593456642, 0.07717457134276628], [0.01523043604434601, 0.00820336030197463, 0.005663311957115573, 0.03109731079478349, 0.011070739877011095, 0.04581979043515665, 0.020853747513943484, 0.01465275847086949, 0.009845276795593756, 0.016135525424033403, 0.06401986721903086, 0.059453340114227364, 0.015726127927856784, 0.021252132386767437, 0.05094239395111799, 0.01044419505966029, 0.09406947584024497, 0.036682203611625094, 0.04849562381527253, 0.02138918628250914, 0.08485081086733512, 0.050540429806070666, 0.0382062645096864, 0.04371467625190105, 0.009139959151590509, 0.033613145617502074, 0.040913839757974656, 0.013279135571792722, 0.016846850647458007, 0.04364238852368934, 0.08888668966080461, 0.06671574113092252, 0.06098914984613657, 0.04193492639543755, 0.03407777925687177, 2.2676206060818265, 14.99633002281189, 32.172709465026855, 36.75190585000174, 25.475990499768937, 17.92035606929234, 11.627395187105451, 7.874835542270115, 2.6044416981084004, 0.1204518401729209, 0.1343777807695525, 0.04076366978032248, 0.07353777292051486, 0.07664610791419234, 0.1779404617846012, 0.772112705877849, 4.267337347779955, 0.35716691027794567, 0.3350057122962815, 1.4274673398051942, 5.707635947636195, 12.7662170955113, 24.160225766045706, 32.03735508237566, 39.145727021353586, 45.673903533390586, 51.492255551474436, 49.52354948861258, 50.394568715776714, 49.787351744515554, 48.945337772369385, 47.50057452065604, 49.91197810854231, 46.693673270089285, 47.517448220934185, 45.14835568836757, 43.97477715356009, 42.19657332556588, 41.21484497615269, 39.080226353236604, 38.82729107992989, 39.76785830089024, 40.42050954273769, 40.911563055855886, 40.14900868279593, 38.10247584751674, 35.88030992235456, 36.17417008536202, 36.71360043116978, 40.535067967006135, 45.124294076647075, 45.60439722878592, 47.392001969473704, 48.83746004104614, 46.21650573185512, 31.651066507611954, 47.91824810845511, 48.372222559792654, 45.51070771898542, 45.847869055611746, 41.567195074898855, 35.12968908037458, 34.07756853103638, 33.02154656818935, 32.515339033944265, 32.85778794969831, 36.77563394818987, 46.16761473246983, 44.93903773171561, 45.49926403590611, 46.35975326810564, 47.006581919533865, 44.50084611347744, 43.73925059182303, 46.11363417761666, 45.41314806256975, 44.22105605261666, 44.97588750294277, 47.372279507773264, 45.351020744868684, 44.698459829602925, 42.62321703774588, 42.49327877589634, 42.199307441711426, 44.96227250780378, 45.820583479745046, 41.094248567308696, 31.555306434631348, 18.676752601351055, 3.6660115803991045, 2.0149556611265456, 1.5698706699269158, 2.3033775559493472, 2.503338026148932, 2.4142054489680698, 1.5049317202397754, 0.20626317842730454, 0.09713889685060297, 0.26576770043798853, 0.16928008863968508, 0.07237677914755684, 1.449853567140443, 0.15811659981097492, 1.365835732647351, 3.9385142837251936, 9.255261949130468, 24.532670055116924, 32.93271384920393, 32.164725984845845, 23.993526322501047, 7.5981113740376065, 0.24425510050995008, 0.06192600314638444, 0.05609871047948088, 0.04829167993739247, 0.05641576614496963, 0.03458223950916103, 0.08484468369611672, 0.050649925002029965, 0.027370647194662263, 0.014858900802209973, 0.030776289092110734, 0.014847671047651341, 0.0429441318847239, 0.014883743665580238, 0.08827853907964059, 0.05204374110326171, 0.04451075728450503, 0.021042285254225135, 0.018238912735666548, 0.019177762625206794, 0.07189959261034216, 0.0931925168260932, 0.023781848339630023, 0.008244805220913674, 0.048487009813210795, 0.06852536009890692, 0.00917067558371595, 0.022924716118723154, 0.028630578158689395, 0.016048946051991413, 0.06672110155756984, 0.07164406989301954, 0.03705339280090161, 0.04405519565833466, 0.040692959646029134, 0.04750097629481128, 0.014075844249288951, 0.020714563018243228, 0.039830331291471205, 0.05275658963780318, 0.01833464384877256, 0.026091971700744968, 0.020701560590948378, 0.00686047546332702, 0.02051439688407949, 0.06714946750019278, 0.08206752807434116, 0.019346270011737943, 0.06055150832980871, 0.02501363876009626, 0.11789639586848871, 0.06300971178071839, 0.08872775640338659, 0.08805234943117414, 0.025162382117871727, 0.02709222731313535, 0.061313082464039326, 0.03824524634650775, 0.035072318211730034, 0.0443098566361836, 0.0876405533137066, 0.06067174473511321, 0.04058178846857377, 0.06156992153929813, 0.12110904205058302, 3.1570360575403487, 19.46277972630092, 39.416949953351704, 40.638182708195274, 28.881896700177872, 21.168640647615703, 18.14008069038391, 11.088252323014395, 3.062841934817178, 0.31861499324440956, 0.11390023172966071, 0.04174223941351686, 0.049037294927984476, 0.082975781123553, 0.10479121123041425, 0.555075463439737, 6.234332851001194, 1.18705586876188, 0.33361349414501873, 2.931310147047043, 7.732241136687143, 16.836049727031163, 27.277981485639298, 35.30534648895264, 41.10784271785191, 47.24750375747681, 49.98935672215053, 50.29126289912632, 51.24098784582955, 49.37156459263393, 49.01962791170393, 48.07475628171648, 50.02037000656128, 49.66782188415527, 48.94674130848476, 46.713010106767925, 44.76470742906843, 44.343712602342876, 41.92490918295724, 39.653855732509065, 39.4542235646929, 40.2985234941755, 40.80693013327462, 42.18354892730713, 41.270374979291645, 40.55983134678432, 36.64784267970494, 38.66325453349522, 38.66005836214338, 42.651107106889995, 47.18434810638428, 48.03975820541382, 49.23967388698033, 51.199197905404226, 46.98361117499215, 35.40485511507307, 48.7293495450701, 50.41740049634661, 47.62257446561541, 47.5398075239999, 44.47912604468209, 36.48233311516898, 36.364526408059255, 34.40044437135969, 34.098722321646555, 34.471604347229004, 39.36858354296003, 47.752443245479036, 47.21831784929548, 47.62272385188511, 47.017834527151926, 48.71280588422503, 47.45954193387713, 46.22131041118077, 47.39912039893014, 45.71949066434588, 45.71083320890154, 47.20474106924874, 47.58136469977242, 46.39541489737374, 45.90181139537266, 44.23090859821865, 43.45170981543404, 43.210159165518625, 45.07677187238421, 47.680112498147146, 43.40384020124163, 33.453550815582275, 20.49871792112078, 7.745286379541669, 4.04612581218992, 0.8293880639331681, 1.7918698489665985, 1.836147461618696, 3.6973410078457425, 3.77259738104684, 0.40877544241292135, 0.3939024433493614, 0.5547510151352201, 0.43974823185375755, 0.9930382796696254, 1.760844839470727, 0.4046692470354693, 2.1223943531513214, 6.8210287519863675, 12.76631784439087, 30.72905445098877, 37.46659408296858, 36.02507216589791, 29.099529913493566, 10.317524262837, 0.7534884395343917, 0.07149572178189244, 0.04716230928897858, 0.05490723691348519, 0.05400366914857711, 0.0524939185540591, 0.04936875928459423, 0.06148644137595381, 0.03898238643471684, 0.02153772607977901, 0.041795232998473306, 0.035774289829922576, 0.029510906099208763, 0.035247142759284804, 0.08144091455531971, 0.02277340111322701, 0.009256182022259703, 0.09289913185472999, 0.0062712377735546655, 0.061492894243981154, 0.0885240330493876, 0.01607896444121642, 0.02872861289818372, 0.01778209751604923, 0.0387312877657158, 0.031488866212644746, 0.01965092375342335, 0.02663080484074141, 0.009879933819839997, 0.02147401842687811, 0.2364122670676027, 0.13263826125434466, 0.14904899708926678, 0.13729154584663256, 0.12617721009467328, 0.17340879780905588, 0.10837832731860024, 0.06257925595023803, 0.1507394720933267, 0.13504627346992493, 0.22178008008216107, 0.1612990918968405, 0.13337764729346546, 0.08006034006497689, 0.12896536476910114, 0.12299702502787113, 0.23236499567117008, 0.21990786625870637, 0.1028266352202211, 0.12642195767589978, 0.18974155639963491, 0.12755124350743635, 0.16409868667168276, 0.21599901600607804, 0.08339741599879094, 0.10746854078024626, 0.1231734034206186, 0.13028116630656378, 0.08211539193455662, 0.1643821650317737, 0.18657562056822435, 0.06740670012576239, 0.13405097116317066, 0.1326039545238018, 0.19744079826133593, 4.133572365556445, 23.48065025465829, 46.342160429273335, 47.95528548104422, 35.60483469281878, 27.79534261567252, 22.01484612056187, 12.498704501560756, 3.606325251715524, 1.6014758540051324, 0.42291505368692534, 0.2503821903041431, 0.2595301994255611, 0.15552380893911633, 0.5933076004896845, 2.020135108913694, 7.530117171151297, 3.100354390484946, 0.5298523626157216, 2.670308883701052, 6.643989086151123, 15.196000405720302, 26.805964299610682, 34.616825171879356, 41.60087646756853, 48.03740276609148, 52.32584483282906, 51.02225855418614, 52.2280524117606, 49.460355622427805, 49.983812059674946, 48.07622235161917, 52.13760423660278, 51.04079287392752, 51.083670207432334, 48.71012735366821, 47.40758677891323, 46.693958146231516, 44.095974581582205, 41.85738658905029, 42.43713733128139, 42.30795642307827, 43.52336311340332, 44.60600015095302, 43.31133188520159, 42.756591183798655, 38.96164492198399, 39.804753235408235, 39.90264293125698, 43.22129017966134, 48.05658674240112, 49.68303149087088, 50.4369284084865, 52.80373845781599, 47.69331407546997, 38.418754373277935, 48.895376750401084, 51.53152329581124, 49.15233155659267, 51.13731377465384, 45.29502868652344, 38.649153164454866, 37.398411410195486, 36.41125999178205, 35.35935831069946, 35.92563649586269, 40.85474763597761, 48.92484058652605, 48.98597431182861, 48.94161353792463, 47.90129797799246, 51.03029414585659, 48.80115222930908, 47.95877347673689, 49.99307748249599, 46.985605307987754, 45.822230202811106, 46.226907185145784, 49.116325991494314, 48.29545191356114, 48.62035315377371, 44.35267577852522, 44.98063312258039, 44.66866595404488, 48.13928072793143, 48.70261982509068, 45.604480607169016, 35.45731054033552, 21.372657128742762, 5.019764721393585, 3.5941376771245683, 4.992838714803968, 5.030375489166804, 4.991350931780679, 6.085228417600904, 3.977052901472364, 0.5660619224820818, 0.6532965557915824, 0.5758571454456874, 0.6752372298921857, 2.4493709334305356, 3.6117233506270816, 0.5732369146176747, 2.329331248998642, 7.107822597026825, 16.389028685433523, 36.351432527814595, 43.02306154796055, 41.040215900966096, 32.589893204825266, 11.548720734460012, 0.8833509768758501, 0.25682756730488365, 0.20648804493248463, 0.10513344393776995, 0.20488470739551953, 0.20472432885851177, 0.13704960740038327, 0.12379559289131846, 0.09882880867059742, 0.06949384670172419, 0.1196381545492581, 0.10306718945503235, 0.14438835717737675, 0.17314572978232587, 0.23546948337129184, 0.10054331738501787, 0.08014757931232452, 0.1736451858388526, 0.0515403088315257, 0.13198157506329672, 0.18867380012358936, 0.15532767160662583, 0.0649509597569704, 0.08170401650880064, 0.12839595175215177, 0.16470760399741785, 0.13450202053146704, 0.1894482664231743, 0.2017425610018628, 0.11580923572182655], [0.03520698705688119, 0.018452027014323642, 0.020915872483913387, 0.0563332969988031, 0.03583789570257068, 0.03145226603373885, 0.035677398421934674, 0.038099697192332575, 0.017344023433646986, 0.0645305598154664, 0.03953507695613163, 0.026072797997455512, 0.015482664474153092, 0.02647676721348294, 0.014251869803826724, 0.088914611376822, 0.15007667908711092, 0.026889206242880652, 0.015648790202768784, 0.04682359817836966, 0.017618875917313353, 0.07043475085603339, 0.02708013242642794, 0.029807405546307564, 0.034660403350634236, 0.018848264323813573, 0.04173339810222387, 0.03828509670815297, 0.048155508137175014, 0.0363525645142155, 0.11126875757638897, 0.05824754945933819, 0.02721183268087251, 0.009632519595990223, 0.011587379832885094, 0.417060843535832, 4.8128573553902765, 24.142417533057078, 38.09074034009661, 26.537586654935563, 18.16038680076599, 13.046781011990138, 11.35175233227866, 5.108045927115849, 0.9288550551448549, 0.015956122461440306, 0.01591678100105907, 0.02097028081438371, 0.0610204099544457, 0.03660575985642416, 0.02934834946479116, 1.2424675353935786, 1.5549717779670442, 0.285428524017334, 1.8798902801104953, 1.6903782721076692, 3.261413199560983, 8.810064809662954, 16.2638429914202, 27.638811860765728, 37.11930227279663, 46.74068130765642, 48.228349685668945, 51.21440403802054, 48.678064891270225, 48.7846884727478, 47.47113152912685, 49.87567377090454, 48.80785376685006, 49.35286004202706, 47.69917140688215, 49.01932219096592, 45.26232351575579, 46.088839530944824, 42.109060764312744, 40.9067097391401, 41.295412812914165, 40.66019460133144, 42.455445834568565, 40.57971709115164, 40.04641158240182, 38.07231371743338, 35.45090082713536, 35.91627379826137, 36.23050260543823, 39.242591857910156, 43.295917306627544, 46.31649030957903, 47.822227478027344, 46.255585874829976, 32.96114935193743, 45.69122886657715, 47.98768840517317, 44.83042696544102, 45.60343142918178, 40.933359554835725, 36.512526512145996, 33.72706317901611, 33.66871568134853, 35.57382140840803, 34.58932072775704, 35.12343570164272, 38.33001545497349, 44.23330225263323, 46.58632360185896, 46.610958439963206, 43.77944244657244, 44.49680921009609, 43.47930458613804, 43.532652854919434, 43.69338205882481, 44.91909987585885, 45.64542981556484, 45.80133696964809, 46.40112631661551, 45.78255598885672, 43.57730197906494, 46.03342764718192, 43.94870056424822, 45.536964961460654, 42.90413270677839, 30.105696814400808, 19.823709113257273, 7.338656953402928, 2.0013152616364613, 1.8245361532483781, 0.24673302897385188, 1.3999113270214625, 1.5065929910966327, 1.7146916474614824, 4.609217379774366, 0.24055589043668338, 0.2602139727345535, 0.7706761115363666, 0.16496784931847028, 0.45289769768714905, 0.7353585809469223, 0.8486099296382495, 2.725169905594417, 9.441400715282985, 17.435066086905344, 23.945371832166398, 29.169770990099224, 30.840725898742676, 14.618271589279175, 3.441440156527928, 0.019346370095653192, 0.04317730026585715, 0.03676951749782477, 0.02186870019483779, 0.04391372789229665, 0.040928299339222055, 0.05716028530150652, 0.03195436837683831, 0.02522267334695373, 0.0373258517522897, 0.044071697629988194, 0.07751194573938847, 0.03952457323404295, 0.07130169469330992, 0.07979712954589299, 0.08235133213124105, 0.01714444762494947, 0.026476589098040546, 0.027137027587741613, 0.021777840963165675, 0.02371080911585263, 0.02260332291812769, 0.051866755421672545, 0.049995572971446176, 0.038515975033598285, 0.08752811327576637, 0.013462461314962378, 0.026959855309022323, 0.05053104566676276, 0.07333580697221415, 0.05144619263176407, 0.05667888166915093, 0.05001277383416891, 0.04518357225294624, 0.04933417774736881, 0.08023581600614957, 0.07710881451410906, 0.030467596370726824, 0.027022708007799726, 0.140862960634487, 0.03528437397575804, 0.04318857751786709, 0.03867513220757246, 0.051428699998983314, 0.009917746880091727, 0.040985564302120886, 0.05243923880958131, 0.04075710495401706, 0.02661960053124598, 0.01944956509396434, 0.012884383405824857, 0.030764306163681403, 0.010800464960214282, 0.008388747943432202, 0.018056575109117796, 0.04558458644896746, 0.010560897145686405, 0.05573091735797269, 0.007098242191464773, 0.029121002914117913, 0.03806784675855722, 0.05129375295447452, 0.03504161789481129, 0.05531132487314088, 0.06567794896130051, 0.5937912602509771, 6.623200510229383, 31.007065773010254, 44.03308296203613, 27.367517709732056, 19.613790137427195, 15.965702738080706, 16.463110378810338, 7.006067965711866, 0.6274658132876668, 0.03462605930066534, 0.15185951627790928, 0.08447087196899311, 0.03966251601065908, 0.03821520420855709, 0.332170413008758, 2.953386528151376, 3.117348381451198, 0.6033651179500988, 4.2141879711832315, 4.535213853631701, 5.441188599382128, 11.832841260092598, 20.365712029593332, 29.853039469037736, 39.57216228757586, 49.20189305714199, 49.59111724581037, 50.670106479099815, 48.47857863562447, 50.26317828042166, 47.72770071029663, 49.94852563313076, 48.422607421875, 50.50194617680141, 49.305820737566265, 50.158719062805176, 47.15951871871948, 47.87700707571847, 43.91464049475533, 42.10653509412493, 43.16830669130598, 42.36931249073574, 44.8113819531032, 42.46657337461199, 42.20276764460972, 40.28814288548061, 36.94811603001186, 37.37866462979998, 38.07508257457188, 41.55318055834089, 45.25705330712454, 48.09874146325247, 49.857083865574424, 47.923956053597585, 37.60211522238595, 44.6140079498291, 49.25721114022391, 47.16606739589146, 46.76035165786743, 43.28409842082432, 38.82330976213728, 35.654938152858186, 35.55265372140067, 37.18122114453997, 36.632629598890034, 36.50739874158587, 40.41800124304635, 47.10275888442993, 48.04316282272339, 47.241104466574534, 46.281506129673545, 47.04295573915754, 44.59542499269758, 44.51644481931414, 45.95849827357701, 45.839336667742046, 47.42802143096924, 47.33004488263811, 45.79977362496512, 46.44641120093209, 45.69540473393032, 47.115314279283794, 45.967954771859304, 49.001152651650564, 44.6237701688494, 34.71131025041853, 22.189006192343577, 10.620310255459376, 3.895306042262486, 3.6585214223180498, 1.775807785136359, 1.9267682560852595, 2.07307973078319, 3.085711930479322, 5.647257838930402, 1.7751022172825677, 0.8072165250778198, 1.1645084215062005, 0.500154187636716, 0.09856035986116954, 0.17535347917250224, 0.6449404241783279, 3.7636754597936357, 10.937461648668561, 19.045693261282786, 29.061716079711914, 36.0074063709804, 35.76738779885428, 18.78189969062805, 4.318151261125292, 0.10861717164516449, 0.06753241909401757, 0.008253697422333062, 0.013166333365786289, 0.041999387222209146, 0.02857492471645985, 0.05978285028998341, 0.052595644524054866, 0.009866413161424654, 0.015374836778002126, 0.016453637907813703, 0.029589779009776454, 0.007471768085711769, 0.043446889014116356, 0.02607556981300669, 0.009043633472174406, 0.041532704407083135, 0.043152275894369395, 0.02649281287033643, 0.04327483628211277, 0.028765053621360233, 0.08643745644284145, 0.0722939164510795, 0.01326445461849549, 0.04902855200426919, 0.045905207815979204, 0.031091801090432063, 0.07894730514713696, 0.025171744204791527, 0.06761170591094665, 0.16507600780044282, 0.1323241809649127, 0.12724143798862184, 0.1419507744056838, 0.1770669836550951, 0.1401576641947031, 0.10883886939180748, 0.0751176399311849, 0.11673527317387716, 0.2427893563040665, 0.09140383744878428, 0.11469893530011177, 0.08124084850507123, 0.09529382442789418, 0.05646997430760946, 0.20321814396551677, 0.3246786264436585, 0.22279645768659456, 0.11504653521946498, 0.1776967320059027, 0.26870901403682573, 0.17085327208042145, 0.07147763203829527, 0.1473554279655218, 0.1573148156915392, 0.16964875028601714, 0.10992422008088656, 0.20945165519203457, 0.11208864501012222, 0.18446331391377108, 0.20161342221711362, 0.15417705263410295, 0.12577832649861062, 0.16621843006994041, 0.18661289928214891, 0.6359679656369346, 8.857358591897146, 39.33251544407436, 51.79923391342163, 35.541376795087544, 27.19236057145255, 20.717315196990967, 18.537739992141724, 7.149968198367527, 2.8727976296629225, 0.19074824452400208, 0.3625406633530344, 0.13716772677642958, 0.15798461117914744, 0.14903440858636582, 0.5800383325134004, 2.5963744052818845, 3.4252699613571167, 1.3977540199245726, 3.515597628695624, 3.164948101554598, 4.655904063156672, 10.212411046028137, 18.70611916269575, 30.018034866877965, 40.63687644686018, 50.26645088195801, 51.388511998312815, 54.851952757154194, 49.20016990389143, 50.970265184129985, 48.69669648579189, 49.822183064052034, 51.67235285895211, 53.09507989883423, 52.08299139567784, 52.595896993364605, 48.76360763822283, 50.10595096860613, 45.01975842884609, 44.47586733954293, 45.07637929916382, 45.22521666118077, 47.16974646704537, 43.9409567969186, 43.703839097704204, 42.5547251701355, 37.91385310036795, 38.7973895072937, 40.06058938162667, 42.860411167144775, 46.65489189965384, 49.63768754686628, 51.80123846871512, 49.88365030288696, 39.829134464263916, 46.45555503027779, 50.74945143290928, 49.35631329672677, 47.51895598002842, 45.023750168936594, 40.49398326873779, 36.944259779793875, 36.52479008265904, 39.53456558500017, 38.32200070789882, 38.66480050768171, 41.83318253925869, 47.32883242198399, 50.6753454208374, 51.0612587928772, 48.128747258867534, 47.509645393916536, 46.994328771318706, 46.28171110153198, 48.31587961741856, 48.70751135689871, 48.94244384765625, 48.32700368336269, 47.31701701028006, 47.33871276038033, 48.24178402764456, 51.938712051936555, 47.8344076701573, 50.847983837127686, 46.296420437949045, 34.95977088383266, 23.308459997177124, 8.537673711776733, 3.150993730340685, 4.11663613149098, 3.432162791490555, 4.076085575989314, 2.7169256508350372, 3.905517722879137, 11.807604534285408, 1.3815422441278185, 0.7062163704207965, 3.5069110776696886, 1.0805511666195733, 1.9229074461119515, 1.3826262716736113, 1.6242014574153083, 4.045751043728419, 14.207761594227382, 24.2455062185015, 34.340627329690115, 41.92387042726789, 39.486887046269004, 22.175799403871807, 4.8572680694716315, 0.21061076942299092, 0.12498843031270163, 0.09582180609660489, 0.19880453151251587, 0.14416837612433092, 0.1292523443698883, 0.20361522265842982, 0.14108910278550216, 0.1447058165712016, 0.18733229567962034, 0.15071520768105984, 0.11071740037628583, 0.08914605288633279, 0.252174581268004, 0.2203697586166007, 0.10951875469514302, 0.16097752058080264, 0.11062196442591292, 0.12020907391394887, 0.06850876991770097, 0.13053880605314458, 0.22401594796351024, 0.17740752681025437, 0.10384211715842996, 0.09801667010677712, 0.18953691023801053, 0.08640610133962971, 0.16426020514752182, 0.14303804534886563, 0.1419454954032387], [0.07682934629597835, 0.020541633279728036, 0.030121071929378167, 0.022475946628089463, 0.03986816640411105, 0.01689277559385768, 0.010930112646227437, 0.04135734381686364, 0.08675655110606126, 0.017533017488728677, 0.014533582276531627, 0.044855134162519655, 0.058425244210021834, 0.012010600783729126, 0.016081356277157153, 0.026391368492373397, 0.06818867780800376, 0.0301747236933027, 0.05493114848754235, 0.028727520456803695, 0.0247223402839154, 0.04036227560469082, 0.03119341510214976, 0.0034689299188487765, 0.05468961716230426, 0.048820621733154566, 0.047000655106135776, 0.024828744752864753, 0.011843557336500712, 0.03747463412582874, 0.03311186769445028, 0.015478272656244891, 0.10277677646705083, 0.04667986410536936, 0.034917496876525025, 0.05610928884042161, 1.185318710548537, 16.397621870040894, 33.31032759802682, 40.18655674798148, 25.15294963972909, 23.32424283027649, 15.292837449482509, 6.8236443144934515, 3.956520540373666, 0.10620828411941018, 0.025924721300335865, 0.03985544387251139, 0.03441215113603643, 0.055523455276020935, 0.08003083057701588, 0.33257813113076345, 0.438072250357696, 1.629232170326369, 3.5079997735364095, 2.866801117147718, 0.9718449711799622, 1.698729246854782, 5.37746102469308, 13.690718344279698, 22.09414417403085, 34.137027740478516, 45.28110102244786, 46.88869530814034, 51.09016677311489, 49.2125620160784, 49.883619035993306, 49.43875714710781, 49.51713630131313, 50.83941323416573, 48.164617334093364, 48.288409914289204, 47.83335154397147, 48.4834041595459, 44.363084180014475, 44.64281518118722, 43.24988201686314, 42.40909787586757, 41.549949645996094, 41.04722663334438, 39.470795018332346, 36.870806898389546, 37.346623011997764, 38.00230366843087, 36.39836066109793, 38.44621018001011, 41.148072787693565, 46.15374265398298, 46.94273839678083, 49.274845668247764, 34.0658677646092, 40.67268746239798, 48.10739197049822, 45.420617376055034, 44.49030917031424, 41.196248122623985, 35.15604012353079, 41.22479827063424, 36.50854172025408, 33.855726446424214, 33.52667713165283, 33.933820724487305, 33.556863580431255, 33.94441325323922, 40.01496056147984, 41.63268532071795, 41.98663003104073, 40.86799437659127, 41.16035025460379, 40.75331783294678, 42.9810596874782, 42.28795950753348, 45.169057846069336, 46.093265533447266, 47.59061622619629, 46.355049337659565, 45.16711235046387, 45.307149818965364, 45.065613065447124, 39.70275715419224, 30.486006464276993, 16.651408297674998, 8.657781141144888, 3.59702313372067, 3.331028721162251, 3.223317095211574, 1.2413477897644043, 0.4541776047221252, 0.5350288791315896, 3.3305451699665616, 4.5959437148911615, 2.4567705477987016, 0.2588724818612848, 0.6260371442352022, 0.28717200617705074, 0.3117897994816303, 1.8047270561967577, 2.9464361582483565, 7.770178300993783, 11.215180277824402, 19.59519154684884, 23.86450695991516, 30.750187397003174, 23.37668088504246, 9.53132951259613, 1.246679772223745, 0.006608346269266414, 0.06545483307646853, 0.053667346481233835, 0.036258628126233816, 0.025701746211520264, 0.05016572580539754, 0.0453613586058574, 0.040935596983347616, 0.02173233331580247, 0.03671265287058694, 0.04583612955840571, 0.06027122586965561, 0.013479791947507432, 0.02532582084781357, 0.03099824468206082, 0.06798531407756464, 0.11215004564395972, 0.01674094490174736, 0.017774479264127355, 0.03401644986921123, 0.0245083235536835, 0.04928342332797391, 0.014765907577904207, 0.06844638540808644, 0.04637766496411391, 0.04946785253871765, 0.0455763795679169, 0.03371278169964041, 0.04481169095795069, 0.09551974266235318, 0.024243735608511736, 0.009002435370348394, 0.07152654084243945, 0.03819216794467398, 0.007017487194389105, 0.019413831743544767, 0.030980219399290423, 0.04334774486986654, 0.027615711991009966, 0.026324483599247675, 0.027651779519926225, 0.028861341133181537, 0.022830574473898326, 0.0679578266239592, 0.02189334967572774, 0.03358054200985602, 0.055952740633594136, 0.01853594313641744, 0.01405481729722981, 0.019336604280397296, 0.01735698345250317, 0.030135076892163073, 0.058059812390378544, 0.022033289041636244, 0.016670065133699348, 0.08377845412386314, 0.05184379718931658, 0.03255749779886433, 0.011691534958247627, 0.03319359723744648, 0.03417431443397488, 0.05410273526129978, 0.07322636605905634, 0.01361385265564812, 0.015588154617164816, 0.022905342247603194, 1.854990541934967, 19.580699341637747, 41.0767946924482, 43.64398036684309, 25.155909572328838, 19.102586848395212, 14.304035833903722, 10.190511192594256, 4.3430323260171075, 0.41827726683446337, 0.19041843579283782, 0.09955750099782433, 0.1456405528421913, 0.10986062777893883, 0.28757375319089207, 1.0833043903112411, 3.3752242582184926, 2.800276458263397, 4.34253248998097, 5.267246527331216, 3.5099628567695618, 3.686876586505345, 8.684106997081212, 17.046679156167166, 26.37410249028887, 36.84123536518642, 46.80354166030884, 48.67913491385323, 50.59113672801426, 49.40860891342163, 51.383599621909006, 49.07464722224644, 50.660889693668906, 51.13201577322823, 49.760959012167795, 49.90367153712681, 49.502663203648154, 49.927694933755056, 47.25392041887556, 45.84319986615862, 44.522058963775635, 44.32466064180647, 43.689279147556846, 42.898355279650005, 41.81893873214722, 38.588981764657156, 39.778565474918906, 40.11318724496024, 37.40780537469046, 40.68490586962019, 42.179025650024414, 49.1848977633885, 48.70208828789847, 50.996206283569336, 36.24519109725952, 43.611563546316965, 49.98245021275112, 46.67478806631905, 47.29184716088431, 41.56449569974627, 37.32655661446707, 41.79699979509626, 38.39015211377825, 35.157276902879985, 34.797085762023926, 35.302171162196565, 35.2692471231733, 36.80833217075893, 43.353990350450786, 44.02183035441807, 44.38971315111433, 43.865353448050364, 42.76811477116176, 43.40910346167428, 44.20656211035592, 45.9288329396929, 46.18795558384487, 47.47802414212908, 47.92308752877371, 46.05588075092861, 47.688043866838726, 46.89875977379935, 45.88001837049212, 42.6295051574707, 33.553330421447754, 20.99324553353446, 12.345980490956988, 5.473307081631251, 3.299272630895887, 3.062565961054393, 1.8919853568077087, 1.8080279933554786, 1.6646476813725062, 3.002301846231733, 3.9526212981769016, 5.156265122549875, 3.324413384710039, 0.4873057742203985, 0.7514877926026071, 0.1418311351111957, 0.7087107194321496, 2.7104709914752414, 8.1363023349217, 15.370893512453351, 22.50795108931405, 28.545843601226807, 35.42643274579729, 28.018860953194753, 12.418765476771764, 1.7936105898448398, 0.014759390249050089, 0.09838863621865, 0.0656970361513751, 0.011039765601578568, 0.052150478054370196, 0.0331583439505526, 0.0956229410533394, 0.02632570665861879, 0.039105642320854325, 0.05428007717377373, 0.029407097026705742, 0.04906283159341131, 0.07724940696997301, 0.01772804880913879, 0.04216768087020942, 0.04089252358036382, 0.09511606182370867, 0.017818602700052515, 0.0112470249711935, 0.004991585189210517, 0.01838371210864612, 0.022321696958637664, 0.032641961837985685, 0.04237917684284704, 0.010082890429267926, 0.004277027170506439, 0.03340014668979815, 0.04594835925049015, 0.011263148659574134, 0.06347015885902302, 0.3073238448372909, 0.14342665592474596, 0.1608404972191368, 0.07070450245269708, 0.10885094052978925, 0.1238469308508294, 0.09284072356032473, 0.15972124013517583, 0.15659460505204542, 0.13637464147593292, 0.12152461760810443, 0.0665439021374498, 0.11175244447908231, 0.1300704133297716, 0.08658674771764449, 0.13278616831770965, 0.1022276177204081, 0.0800019996240735, 0.0804784329874175, 0.13189964874514512, 0.12879516104502337, 0.12758233398199081, 0.10129799081810884, 0.07900605270905153, 0.2150169587028878, 0.1362118473542588, 0.11472224976335253, 0.09279889866177525, 0.08693539258092642, 0.15684217533894948, 0.19657281626548084, 0.2011928797832557, 0.2622153524841581, 0.1268911917826959, 0.20853485938693794, 0.16968962523554051, 2.509624625955309, 25.837046691349574, 49.27314335959298, 52.09091234207153, 35.00211320604597, 31.439042227608816, 23.601481165204728, 12.942773427282061, 6.59842757667814, 0.5967461445501873, 0.23448962452156202, 0.1484834381512233, 0.2390689216554165, 0.17186244364295686, 0.30730131747467176, 1.5462332240172794, 2.6718928558485846, 3.9751252106257846, 8.823640721184866, 4.749896253858294, 2.617489763668605, 2.7703800967761447, 6.953891771180289, 14.950579609189715, 25.72936872073582, 38.33788081577846, 48.16024691717965, 49.23863165719168, 53.59957470212664, 50.3036584854126, 52.01978710719517, 48.429437501089915, 51.63419335229056, 51.332078729357036, 50.86123057774135, 51.28755119868687, 51.479158197130474, 53.4506504876273, 50.28377968924386, 47.439027377537315, 47.14194672448294, 46.27759081976754, 45.34298167909895, 45.31476157052176, 44.49084070750645, 40.077119146074565, 40.70686565126692, 41.275947434561594, 39.48326356070382, 41.99147639955793, 44.752919810158865, 50.20287486485073, 50.08004461015974, 53.82987969262259, 40.16276611600603, 45.67179128101894, 52.694828919001985, 49.97103779656546, 48.93476608821324, 43.79874801635742, 39.15066371645246, 44.09560980115618, 39.084833008902415, 37.37631613867623, 36.576710496629985, 37.78061791828701, 36.03320155824934, 38.0442464692252, 45.344239303043906, 44.60205357415335, 45.047356673649375, 45.38804422106062, 44.03227697099958, 44.77665138244629, 46.2399628502982, 46.143813678196494, 48.32809107644217, 49.697021688733784, 48.67842272349766, 45.79988827024187, 49.05230181557791, 47.981862340654644, 47.97018241882324, 44.05372953414917, 34.37119940349034, 20.454417943954468, 10.964876634734017, 4.851796797343662, 6.1683240958622525, 7.622898203986032, 2.7648929740701402, 1.7310270794800349, 1.1828905322722025, 7.01884309734617, 13.382339920316424, 8.531979663031441, 6.581740609237126, 4.131005874701908, 2.9046106083052496, 1.381939485669136, 2.766811328274863, 3.8418109927858626, 11.523637737546649, 16.160549334117345, 28.656083720070974, 34.29180233819144, 41.15762308665684, 32.436859130859375, 13.965784498623439, 2.0585011073521207, 0.12432946424399104, 0.14962710892515524, 0.11225008206175906, 0.11441479197570256, 0.18535805733076163, 0.1303380411118269, 0.20842591380434378, 0.06893199256488255, 0.10351783170231751, 0.1229841328625168, 0.2485395334661007, 0.14441395151828015, 0.19224727765790053, 0.12844420916267804, 0.18939576138343128, 0.19180157514555113, 0.21598600170442037, 0.10443913976528815, 0.07819506086941276, 0.13872712238558702, 0.17243641641523155, 0.13693779840001039, 0.08633658542696919, 0.08426618509526763, 0.11799026440296854, 0.08647934240954262, 0.14280492785785878, 0.20758641670857156, 0.1318890635988542, 0.1700349859893322], [0.025915335464690412, 0.018872588107894574, 0.03752137501058834, 0.00414510299950572, 0.046852547874940295, 0.027225123485550284, 0.04772174784115382, 0.04662851257515805, 0.024762144844446863, 0.02635910245589912, 0.026466667219730358, 0.03986140140997512, 0.048991680411355834, 0.03147703256191952, 0.01756246590853802, 0.02288207528181374, 0.06534700707665511, 0.05316431115248373, 0.059185990531529696, 0.012953621119127741, 0.09566112221883875, 0.026234216389379332, 0.07486980501562357, 0.03569498604961804, 0.03407379286363721, 0.05410847906023264, 0.022940459827493345, 0.0031208620223748896, 0.06486118278865304, 0.04020090640655585, 0.01978188270836004, 0.06565793217825037, 0.04453514383307525, 0.009964354602353913, 0.02592746427814875, 0.025366716153387512, 0.22758859768509865, 7.375358206885202, 23.926455361502512, 35.71297298158918, 33.37638759613037, 20.121375152042933, 18.637300729751587, 11.866260358265468, 5.6051278710365295, 1.4162017043147768, 0.0541646753304771, 0.11390739705945764, 0.07738966015832764, 0.053177898816232166, 0.0977453850209713, 0.8620213642716408, 2.356042729956763, 0.20362812839448452, 3.353056464876447, 7.636763334274292, 2.2033128568104337, 1.4777856511729104, 0.8160255923867226, 4.092260113784245, 10.421290397644043, 21.255147457122803, 33.57893105915615, 45.23285967963082, 46.713472161974224, 48.84363351549421, 47.82586138589041, 49.20582921164376, 47.21898487636021, 50.49159683500017, 49.37226983479091, 50.3101098878043, 49.80677195957729, 47.50857537133353, 46.935373306274414, 46.8469956942967, 47.402490275246755, 45.17390421458653, 44.265635694776265, 43.871982029506135, 41.77484893798828, 41.34331021990095, 37.863624572753906, 36.266021796635215, 39.47078112193516, 39.75293704441616, 39.06876877376011, 47.38839585440499, 46.75283718109131, 49.911092213221956, 32.80606208528791, 40.63010195323399, 47.426287855420796, 45.204333850315635, 46.632292883736746, 40.436007499694824, 38.880125182015554, 37.67218085697719, 33.64753409794399, 38.068568638392854, 40.05565963472639, 37.79297181538173, 36.92599296569824, 35.148101806640625, 33.77629116603306, 35.00503839765276, 36.47617353711809, 37.43556342806135, 37.246089526585166, 39.15462418964931, 41.11749029159546, 42.70665795462472, 43.420807702200754, 45.88127599443708, 45.60608911514282, 46.39035313470023, 45.13030774252755, 45.36790139334542, 37.67566885266985, 28.8000590801239, 16.418240649359568, 8.628855790410723, 2.915141906057085, 2.152714554752622, 1.3460980717624937, 1.4999690779617854, 2.6308465898036957, 1.5608406173331397, 1.7758627193314689, 3.474437151636396, 3.8971347212791443, 3.4642196084771837, 1.4332729939903532, 0.035615305682378154, 0.35585986184222357, 0.018212955378528153, 1.2054840113435472, 3.9332692623138428, 10.929425188473292, 14.193430066108704, 23.073623044150217, 24.293151753289358, 27.602537052971975, 16.269236530576432, 4.633224708693368, 0.4400816639619214, 0.03679451812058687, 0.03920945478603244, 0.029695952776819468, 0.04050264414399862, 0.04041601557816778, 0.019790640899113247, 0.031972492047186406, 0.042445713986775706, 0.02997482388413378, 0.05086204183420964, 0.07694144706640925, 0.04880495775224907, 0.0681538689615471, 0.039705704764596055, 0.0394647060893476, 0.032069118826517036, 0.03786525655803936, 0.010256352817772754, 0.04037234167169247, 0.046386855720941506, 0.026286582329443524, 0.04571547246138964, 0.04688751956980143, 0.030220110900700092, 0.013235031643749347, 0.04158432735130191, 0.04212249043796744, 0.0369196094439498, 0.04072821293292301, 0.07801676222256251, 0.05375567477728639, 0.025522054871544242, 0.0641295863315463, 0.010098557802848518, 0.03479306712480528, 0.007225738921468812, 0.1289210021495819, 0.02565022504755429, 0.04068185542044895, 0.05487342212083084, 0.020448667196823016, 0.006485183257609606, 0.0740413341139044, 0.03644088602491787, 0.009807932772673666, 0.0321346992360694, 0.010304360866679676, 0.013679421190837664, 0.02003724766629083, 0.01784215634688735, 0.02572500808829708, 0.03239451368738498, 0.04442877329087683, 0.05674127296411565, 0.0174310184083879, 0.10969448847962276, 0.008645142578253788, 0.004891102210552032, 0.06284064121012177, 0.02073371975815722, 0.013504532182456126, 0.04120930443917002, 0.00934880374864276, 0.04478961821379406, 0.02766596938350371, 0.013514476961323192, 0.42433083057403564, 8.858228853770665, 28.892617770603724, 41.37735986709595, 35.24048505510603, 22.309020689555577, 20.48530616079058, 18.425387620925903, 8.719733885356359, 1.1727057759250914, 0.060420143950198374, 0.22271172223346575, 0.025595107647989477, 0.3040046686572688, 0.44925575596945627, 2.596865338938577, 4.0349244475364685, 1.3021500642810548, 3.6006713722433363, 8.41269212109702, 6.52616023165839, 3.861867836543492, 3.5859887429646085, 7.881209645952497, 14.795655625207083, 24.294881854738506, 36.351998805999756, 45.366028853825156, 48.251716477530344, 50.38880171094622, 49.46815497534615, 49.7208366394043, 49.119192123413086, 50.415802410670686, 49.25316034044538, 50.61436455590384, 50.96409865788051, 48.983281884874614, 48.267117159707205, 48.96789509909493, 48.62210062571934, 46.443732670375276, 46.07908773422241, 44.7953211920602, 43.672273431505474, 42.51296649660383, 39.648901666913716, 37.170611245291575, 40.556558745247976, 41.60354110172817, 41.09089953558785, 48.77291127613613, 48.758879389081685, 49.77239574704851, 35.40900666373116, 44.21289191927229, 49.15793527875628, 47.83677005767822, 47.66884599413191, 42.01153237479073, 39.08462456294468, 39.81920548847744, 35.41355078560965, 38.736106395721436, 40.462514877319336, 39.804016726357595, 38.107596669878276, 37.35071897506714, 35.368286745888845, 38.33739791597639, 37.9424067224775, 38.65361043385097, 39.018022605351035, 40.90583774021694, 41.66987207957676, 44.93078327178955, 45.28735440117972, 46.48285102844238, 46.73946189880371, 47.295852797372, 45.590785707746235, 46.35490689958845, 39.95533112117222, 32.7882399559021, 19.13401528767177, 11.502643755504064, 4.687193972723825, 3.181181699037552, 2.832500249147415, 4.236280637128012, 4.864585825375148, 2.879165653671537, 4.192167827061244, 6.038261200700488, 3.827679659639086, 4.272242775985172, 2.3554254259381975, 0.3465223786021982, 0.10252102983317204, 0.13376731638397488, 1.2979830993073327, 7.533708521297999, 14.402535234178815, 15.210315431867327, 27.406045470918926, 28.9526241506849, 32.45603615897042, 19.78782340458461, 6.196869032723563, 0.9146257958241871, 0.07653365430555173, 0.04756072469587837, 0.02934259209515793, 0.0289075968654028, 0.03585290150450809, 0.024963344048176492, 0.018460705477212156, 0.019698158272409012, 0.024386467146021978, 0.02374196914024651, 0.0343303842736142, 0.03921690849321229, 0.02159883494355849, 0.018175717376704727, 0.03330326885251062, 0.0747806251581226, 0.01276193158368447, 0.01498131700126188, 0.051980311649718454, 0.01651283330284059, 0.04831872973591089, 0.017082059722659842, 0.03297273748155151, 0.006084147009200284, 0.009072614550989653, 0.01709929620847106, 0.05693582591733762, 0.08262273256800004, 0.08591295565877642, 0.03425687178969383, 0.1466698633240802, 0.09949163560356412, 0.19267860879855497, 0.07855312379875354, 0.13353403604456357, 0.08905332429068429, 0.20550138716186794, 0.0876658083871007, 0.10102671930300337, 0.11657716094383172, 0.10959539522549935, 0.1638299732335976, 0.14322309541915143, 0.07769078042890344, 0.1388381171439375, 0.11971871022667203, 0.132089869252273, 0.12478815391659737, 0.14833452685603074, 0.12534964164452894, 0.164473685835089, 0.09202200999217373, 0.1682102560464825, 0.16382108442485332, 0.09088952826069933, 0.1831005306116172, 0.134674341284803, 0.13660140787916525, 0.11083723644592933, 0.11962181542600904, 0.06549674618457045, 0.14032269748193876, 0.08883480208792857, 0.08038400126887218, 0.08378658975873675, 0.12436223748539176, 0.5399054288864136, 10.516387786184039, 35.97545855385916, 49.45614848818098, 43.4831087248666, 29.000872441700526, 28.709874936512538, 17.0747446673257, 7.555899330547877, 2.092164043869291, 0.376068290323019, 0.5981668883136341, 0.2218931782990694, 0.2634001831923212, 0.5548271196229118, 1.8369986159460885, 5.263706420149122, 1.30080070240157, 8.576050349644252, 15.61440008027213, 5.194785501275744, 3.2508426010608673, 1.9643556220190865, 5.7678664071219305, 12.970439417021614, 23.819593804223196, 36.726148877825054, 46.77341774531773, 48.80878482546125, 51.72909184864589, 50.03707695007324, 48.88777542114258, 50.72491386958531, 51.27408211571829, 50.75848061697823, 52.79161385127476, 53.47061613627842, 51.661451135362896, 50.7064768246242, 51.38950559071132, 51.076836654118125, 47.674143995557515, 47.94038854326521, 48.11534765788487, 46.57438659667969, 45.66540241241455, 42.16275644302368, 38.40941252027239, 42.999979632241384, 43.31181478500366, 42.31140272957938, 50.58757925033569, 51.64862823486328, 52.86787380490984, 38.459359645843506, 45.633756841932026, 50.34255102702549, 49.02942834581648, 50.09695305143084, 44.554131848471506, 41.7125027520316, 40.84918212890625, 36.44280481338501, 41.58131381443569, 42.44500616618565, 41.466616426195415, 41.078861781529014, 39.059305327279226, 37.71625328063965, 39.113542965480256, 40.09211335863386, 40.866875716618125, 41.19177000863211, 42.68244348253523, 45.00956194741385, 46.315739904131206, 46.550637653895784, 48.85081100463867, 48.08926064627511, 46.498279503413606, 45.36129018238613, 46.66820117405483, 40.873341015407014, 32.19894586290632, 20.508798020226614, 11.148160559790474, 3.886823160307748, 3.4326719641685486, 4.481386593409947, 5.661512068339756, 8.767567890030996, 2.5425790633474077, 3.519499259335654, 11.333931939942495, 10.743475760732379, 10.802727392741613, 6.39836722612381, 2.3768990508147647, 0.9037746095231601, 0.26353355603558676, 2.06185730440276, 7.468868800571986, 16.538606030600413, 21.12359721320016, 32.92263548714774, 34.388194697243826, 37.46745565959385, 23.16791183607919, 7.0254369378089905, 0.99240642786026, 0.24842298829129764, 0.186664752928274, 0.11838222694184099, 0.1187038253992796, 0.1527824324688741, 0.18897808236735208, 0.10879787230598074, 0.07895319483109883, 0.13724022145782197, 0.12300585955381393, 0.12505430249231203, 0.09987836663744279, 0.16501370471503052, 0.13452655635774136, 0.18813188134559564, 0.18497011171919958, 0.10493765944348914, 0.12923709090266908, 0.1287638670099633, 0.13052832947245666, 0.06898248235562018, 0.15556547098926135, 0.12516577222517558, 0.07346295086400849, 0.1232677333589111, 0.1868648121931723, 0.12766606520329202, 0.1524208682988371, 0.1537101391170706, 0.19945588441831724], [0.021129046134384613, 0.014294456357934644, 0.016300400951877236, 0.07647815692637648, 0.022930946766531894, 0.031409060316426415, 0.013150444620155861, 0.018250435956620743, 0.042452801285045486, 0.09966627694666386, 0.0500325599153127, 0.009755760215089788, 0.06276615842112473, 0.03210180385836533, 0.06554158377860274, 0.019687603660193936, 0.03669944518644895, 0.05509141845894711, 0.04189066555617111, 0.0451709888210254, 0.01474940899892577, 0.07316640391945839, 0.013441909337416291, 0.02152371602798147, 0.03504906142396586, 0.031883875373750925, 0.008885991127629365, 0.03989739430003932, 0.03607397839160902, 0.04273062066308089, 0.011531117405476314, 0.018985457319234098, 0.05536758221153702, 0.01345518063421228, 0.014088616822846234, 0.05378165927582553, 0.016963575634041002, 1.5343381251607622, 14.674409559794835, 36.7370297568185, 36.92608329227993, 27.065314497266495, 12.309755189078194, 14.401231578418187, 13.188945497785296, 3.786818172250475, 0.533099505518164, 0.170105567201972, 0.10998429078608751, 0.24726589609469685, 0.4218282848596573, 3.128295051200049, 3.6141975607190813, 2.1793730556964874, 1.711174556187221, 5.368842652865818, 10.179328066962105, 4.642985190664019, 5.4725775207792005, 1.6467504245894296, 3.403417876788548, 8.597029566764832, 19.22891899517604, 30.751069818224224, 40.47499731608799, 41.6082797731672, 49.26781409127371, 49.92357465199062, 49.86727339880807, 46.31905766895839, 50.237813881465364, 48.702762263161794, 49.754424231392996, 50.20064101900373, 48.48919200897217, 48.81023699896676, 47.96837241309029, 46.93134682519095, 47.85981723240444, 47.742615018572124, 46.7994978087289, 46.78229406901768, 46.06576108932495, 40.48099708557129, 36.51317269461495, 38.83673715591431, 40.78628008706229, 48.81731721333095, 48.465943336486816, 49.1722867829459, 33.80367054258074, 40.32624680655343, 47.69283464976719, 45.4767518724714, 46.097107887268066, 41.94381175722395, 36.794307231903076, 36.41318811689104, 38.68145881380354, 43.02161979675293, 45.39911617551531, 44.54605804170881, 43.93370287758963, 40.31300006593977, 38.52846990312849, 37.42696850640433, 36.9424706186567, 38.81593772343227, 39.48390974317278, 39.87750434875488, 42.94902849197388, 42.60588823046003, 44.84028993334089, 45.6516831942967, 48.87302092143467, 45.74616479873657, 42.20930937358311, 34.49622181483677, 26.79598147528512, 15.662934984479632, 5.838090547493525, 3.483121314219066, 1.8374506831169128, 1.8138871703829085, 1.473331747310502, 2.6976661128657202, 2.0680123226983205, 3.9590679236820767, 5.685155051095145, 1.8805425422532218, 1.2256169595888682, 2.5656071305274963, 1.9362577583108629, 0.10119581701500074, 0.2756497487425804, 0.8648706142391477, 5.695993372372218, 8.431420121874128, 13.362207514899117, 18.03105650629316, 19.732967376708984, 24.08433406693595, 20.764978102275304, 8.519131575311933, 2.013703465461731, 0.016164934828079174, 0.01667129497842065, 0.02561727538704872, 0.02772077465695994, 0.015894172214237706, 0.02240758592129818, 0.021106858039274812, 0.06733647175133228, 0.029377767350524664, 0.03764110251462885, 0.0806613660284451, 0.06222102338714259, 0.07012766626264368, 0.02650585092071976, 0.050667882431298494, 0.05190545566646116, 0.03532063488715461, 0.04639518813097051, 0.05717106043760266, 0.031222171416240077, 0.022439500815900307, 0.06732994424445288, 0.0347619325454746, 0.03632790655163782, 0.025958439401750053, 0.022386064486844198, 0.023388803537402834, 0.004138294324677969, 0.028803835290351083, 0.02632342847729368, 0.01574637202013816, 0.028766302125794545, 0.046689546800085475, 0.05368728184008172, 0.051794342164482386, 0.00420720167624365, 0.032783371928547106, 0.03150550049862691, 0.07733030191489629, 0.015055993172739233, 0.046295809892139266, 0.026922834438404868, 0.0071976356973339406, 0.01859699941373297, 0.008056154674185174, 0.023656901204958558, 0.07749249214040381, 0.024678836011194756, 0.007103261230180838, 0.028707072804016725, 0.017180671216920018, 0.03382783070472734, 0.014936238527297974, 0.034466047172567675, 0.08207258316023008, 0.05664754013663956, 0.031371360910790305, 0.032695128449371884, 0.019164483694891845, 0.0392930604783552, 0.0687640415770667, 0.056721819365131, 0.026226759289524386, 0.03663317606385265, 0.01862262428871223, 0.020782796499718512, 0.06837125801082168, 0.04411189065181783, 2.084701895713806, 18.03671407699585, 42.2582802772522, 42.59736279078892, 28.086772646222794, 16.25486765589033, 15.045528479984828, 13.703849571091787, 6.424949296883174, 0.720294397856508, 0.1548794178026063, 0.2708567945020539, 0.3907355032861233, 0.6147131004503795, 5.272315238203321, 5.039855437619345, 5.370084643363953, 7.990193009376526, 6.490931562014988, 11.182502899851118, 8.10499722617013, 4.704987440790449, 2.708992762225015, 4.43320517880576, 9.783489193235125, 21.943880694253103, 35.70232139314924, 42.503930364336284, 43.59675693511963, 50.0990548815046, 50.20983348573957, 49.76254667554583, 48.975770882197786, 49.5026284626552, 49.438041482652935, 51.21361889157976, 52.478854588099885, 49.621713638305664, 49.882965905325754, 48.99071993146624, 49.00969546181815, 49.722472940172466, 48.645557744162424, 48.103709425245015, 48.208557741982595, 46.94275229317801, 41.40084130423409, 38.03451899119786, 39.75179059164864, 41.84821844100952, 49.8424266406468, 50.707463468824116, 52.07699510029384, 36.728893416268484, 43.82986899784633, 49.28407982417515, 47.38242040361677, 47.04087127958025, 42.516141823359895, 38.18331118992397, 36.86475849151611, 40.01519332613264, 44.76112215859549, 46.05714879717146, 45.02511548995972, 45.718563079833984, 41.15086248942784, 39.9102338382176, 37.95279427937099, 38.136518546513145, 39.57454899379185, 40.579703194754465, 41.25766672406878, 43.39928913116455, 43.62538351331438, 45.20837770189558, 46.90811204910278, 48.63217898777553, 45.03844560895647, 43.780939783368794, 37.97531339100429, 29.48289850779942, 18.187898193086895, 8.435593383652822, 4.587020056588309, 2.3709346737180437, 5.230462329728263, 6.412115105560847, 3.487016430922917, 5.220209828444889, 6.910973182746342, 8.301559158733912, 6.251372005258288, 3.6059520031724657, 3.277471572160721, 1.4550595049347197, 0.11656889638730458, 0.21507547556289605, 0.7749331316777638, 6.467839223997934, 9.433563147272382, 16.36842553956168, 20.487487895148142, 24.79358012335641, 30.95277602331979, 26.93146092551095, 12.491693769182477, 2.9019933087485175, 0.06482049104358469, 0.046605211682617664, 0.020409685360001664, 0.04410425713285804, 0.0774754812674863, 0.019109239070011035, 0.03949595941230655, 0.026816402828054767, 0.01601709901089115, 0.018817809975839088, 0.053467232933534045, 0.046333804460508485, 0.014926939204867398, 0.015632045654846088, 0.06041652735854898, 0.045564247361783466, 0.07550346851348877, 0.0874952653955136, 0.017963739644203867, 0.0382840280154986, 0.009376465925015509, 0.033220233129603524, 0.05310459667816758, 0.028063182087082948, 0.050090622156858444, 0.058263651095330715, 0.05282648553007415, 0.03769009613565036, 0.05475884809025696, 0.022362839929493408, 0.04289012049723949, 0.10538953662450824, 0.10708334323550973, 0.09379631121243749, 0.17377987504005432, 0.08017653918692044, 0.0831480340233871, 0.08028020576706954, 0.13962194722677979, 0.11885538298104491, 0.16669690582369054, 0.12848576264722006, 0.07818309829703399, 0.12129122870309011, 0.11517794031117644, 0.09896217472851276, 0.10856334346213511, 0.15890147483774594, 0.12102626077830791, 0.15702238066920213, 0.11039760003664664, 0.1323638345514025, 0.1440007644040244, 0.09152819934700217, 0.20464772225490638, 0.10753416190189974, 0.09449682398033993, 0.14612113205449923, 0.09887045036469187, 0.10723872096943003, 0.23567738650100573, 0.07569640316069126, 0.13422341405281, 0.15067214784877642, 0.06922501112733569, 0.07220767465020929, 0.103662773567651, 0.09826661526624646, 2.6487177908420563, 20.87405092375619, 49.60127551215035, 49.99095480782645, 36.8937463760376, 21.927227599280222, 22.791442802974156, 17.343605211802892, 6.459160055433001, 0.7598707399197987, 0.6660787441900798, 0.7592805773019791, 1.0835938262087959, 0.8658370652369091, 7.125669913632529, 7.422237702778407, 7.6621763706207275, 10.080911176545278, 14.466777409826006, 18.378447328295024, 9.9272152866636, 8.941261563982282, 3.169623587812696, 4.381646071161542, 9.832773634365626, 21.170593091419764, 35.86517327172415, 44.29761825289045, 44.86644295283726, 51.437569754464285, 51.17889526912144, 50.95674398967198, 50.42262206758772, 49.81390428543091, 48.513465540749685, 51.49654606410435, 53.60540771484375, 52.57133511134556, 52.926443644932334, 51.14056553159441, 52.05091156278338, 52.81290660585676, 51.92358929770333, 50.81980889184134, 50.427517073495046, 49.96484695162092, 43.475191252572195, 40.94638395309448, 41.71522644587925, 45.21234164919172, 53.04784951891218, 53.246943201337544, 51.68160785947527, 40.0163745198931, 45.0333525793893, 51.667833055768696, 49.50374712262835, 49.6604984828404, 45.518555709293906, 39.03943347930908, 39.43142652511597, 43.399525369916645, 46.686676434108186, 48.43204654966082, 48.397795404706685, 47.63471296855381, 43.76789454051426, 41.77262898853847, 40.28950820650373, 40.566154207502095, 41.97744798660278, 43.34138284410749, 43.639644690922324, 46.36105605534145, 47.17652790887015, 48.95633329663958, 48.01196541104998, 50.797963755471365, 45.071463448660715, 44.464159624917166, 37.30183144978115, 30.19099290030343, 18.256563765662058, 8.78268369606563, 4.219899824687412, 2.9591385509286607, 6.579210162162781, 7.8618841000965665, 6.555797338485718, 6.984657526016235, 11.387251547404698, 15.263255493981497, 10.188332063811165, 6.3533976163182935, 7.808303066662379, 4.818833240440913, 0.8350522028548377, 0.7847174437982696, 1.381852416055543, 7.588609712464469, 12.011594091142927, 20.011042969567434, 26.951065267835343, 29.831381934029714, 36.10033505303519, 29.298225811549596, 13.192866887365069, 2.936993339232036, 0.1655361766793898, 0.16381704035614217, 0.09783563696380172, 0.12064681042517934, 0.14099190942943096, 0.07461963593959808, 0.15026824309357575, 0.18776954364563736, 0.1553562379309109, 0.09084944719714777, 0.10088149923831224, 0.17036355978676251, 0.22214632614382676, 0.0982191449563418, 0.20720784845096724, 0.22132234035858087, 0.14322198262172087, 0.3220203162303993, 0.1446291963968958, 0.17446406904075826, 0.11309047482375588, 0.13264079897531442, 0.13818597713751452, 0.17964328612600053, 0.11070952258471932, 0.12122930559728827, 0.11846709810197353, 0.09288044500031642, 0.08772938711834805, 0.09241264938775982, 0.09296707356614725], [0.001738685235198188, 0.0016430771065643057, 0.029183299214180027, 0.009359201449634773, 0.0382074214118932, 0.05303019192069769, 0.03584528834159885, 0.021774870676121542, 0.04191620222159794, 0.0325685579196683, 0.032865013261990886, 0.042259554511734417, 0.07697835937142372, 0.029121840904865946, 0.02640494258542146, 0.012354881818672376, 0.009501203561999967, 0.03611935881365623, 0.07418237440288067, 0.07807046826928854, 0.015274963208607264, 0.045493472766663344, 0.021182363719812462, 0.025645692433629717, 0.048161923685776334, 0.06608909368515015, 0.028993099063102688, 0.037362730130553246, 0.04726454755291343, 0.06276008553270783, 0.022467534490195767, 0.050388244579413106, 0.005595122580416501, 0.03738923031570656, 0.02511568194521325, 0.038159055435763936, 0.049085335207304785, 0.15040173807314464, 6.069110333919525, 20.37656511579241, 37.065787247249055, 32.33814607347761, 21.596033028193883, 26.213456664766582, 24.321137360164098, 7.482478584562029, 1.786408673439707, 0.7223362997174263, 0.02979652184460844, 0.5998529121279716, 1.1754317496504103, 6.8722521747861585, 4.459590094430106, 2.9248517964567458, 5.274195160184588, 4.951624172074454, 9.124274509293691, 6.1602476835250854, 3.949124182973589, 2.410449296236038, 0.7522305441754205, 1.2093945443630219, 6.6674032126154215, 16.455609798431396, 24.886048487254552, 30.906264781951904, 37.67845855440412, 47.13046135221209, 48.03333806991577, 49.28955153056553, 47.331573486328125, 53.508966718401226, 49.07796846117292, 51.28881924492972, 50.165250369480674, 50.68871028082711, 50.04961150033133, 48.752705914633616, 48.36298492976597, 48.93292134148734, 47.804433141435894, 48.638689449855256, 49.34578677586147, 45.2557053565979, 38.76931183678763, 38.76486151559012, 40.70792872565133, 50.102018288203645, 48.146062169756206, 50.18071705954415, 33.43176473890032, 41.574886730739046, 48.936506611960276, 45.256316798073904, 46.71754380634853, 41.86492191042219, 36.670455592019216, 38.270233154296875, 41.19306237357003, 47.29491826466152, 48.83752952303205, 48.44179834638323, 45.12458937508719, 46.266998291015625, 42.776244163513184, 42.629178592136924, 39.93280158724104, 40.88850198473249, 40.370982783181326, 42.29762445177351, 43.219643456595286, 44.33353001730782, 42.960406167166575, 46.444434438432964, 46.2174437386649, 40.317429542541504, 31.99222653252738, 24.89105987548828, 15.98643616267613, 7.412836790084839, 2.2121540052550177, 1.4422261821372169, 1.122589505144528, 4.608903842312949, 3.4578298713479723, 5.309825956821442, 4.7435091223035535, 3.896115073135921, 7.019705542496272, 5.265282792704446, 3.2692158094474246, 2.536792950970786, 0.6925532807196889, 0.10650168266147375, 0.4533590200756277, 2.5809550498213087, 6.909912279673985, 9.55957133429391, 14.772848163332258, 19.892953123365128, 23.645084585462296, 19.201737642288208, 14.515147294316973, 2.9631222571645464, 0.37061883988124983, 0.032811548095196486, 0.11005211036120142, 0.013860600218842072, 0.028179980016180446, 0.02740444502394114, 0.05101335175069315, 0.005360687883304698, 0.04242130708215492, 0.01003416907042265, 0.02331648357877774, 0.009113479322487754, 0.009951059556832271, 0.030061466020665, 0.035313534018184455, 0.019069804311064736, 0.062391369603574276, 0.014690574923796313, 0.050512402917125394, 0.03088292426296643, 0.0600857279662575, 0.012312259641475976, 0.03232772548549941, 0.027348326785223823, 0.003992477149170424, 0.04135284512969, 0.03147617760779602, 0.017206496259729778, 0.009191830609259861, 0.015358009109539645, 0.02534436181719814, 0.03251058728035007, 0.026250340077759962, 0.046807985087590556, 0.022012586938217282, 0.013549784531018563, 0.04069985016914351, 0.08064623469752924, 0.029939702911568538, 0.0375522212125361, 0.06389095913618803, 0.09407459877963577, 0.022110949070858102, 0.04421572008037141, 0.005317435940794114, 0.03283937820898635, 0.055074960592069795, 0.06986517499067954, 0.05331997387111187, 0.04763580459569182, 0.02873013960197568, 0.07582132145762444, 0.022452766175514886, 0.02019546167658908, 0.008466583543590136, 0.018392288791281835, 0.06245228847754853, 0.005920731603899705, 0.006120720046705433, 0.029417217376508882, 0.03162455964567406, 0.037848354250724824, 0.025205458913530623, 0.03897402349061199, 0.04590931973819222, 0.043612560124269555, 0.06237855886242219, 0.006441952943402741, 0.014216450275853276, 0.27276345076305525, 6.800814705235617, 26.117995364325388, 43.1974196434021, 37.176948002406526, 21.259549140930176, 20.266012328011648, 25.531305108751567, 10.273291162082128, 2.525797860963004, 0.4174879677593708, 0.2922322489321232, 0.5610755586198398, 1.349101104906627, 1.963877933365958, 4.785219592707498, 5.58938672712871, 7.647969910076686, 4.623033004147666, 10.419813905443464, 9.755123172487531, 6.841239758900233, 3.001400968858174, 1.8351556062698364, 2.633201377732413, 8.899830324309212, 20.186945302145823, 28.14116140774318, 33.8395162991115, 40.736774172101704, 48.29468413761684, 49.3163229397365, 50.503749234335764, 50.08121190752302, 52.84339182717459, 48.41483586175101, 51.030009269714355, 52.63784326825823, 52.02463347571236, 51.51222120012556, 50.289678709847585, 49.79908377783639, 50.57829645701817, 49.41466426849365, 51.28846836090088, 50.9859298978533, 47.89731318610055, 39.78738621303013, 39.12431614739554, 43.020869391305105, 51.40343672888619, 48.86710105623518, 52.31477982657296, 36.61540501458304, 44.39315250941685, 50.85378210885184, 48.26350062234061, 47.35161903926304, 43.85653618403843, 39.274042878832134, 39.902983392987935, 42.54208639689854, 48.50681264059884, 48.96564040865217, 48.956913471221924, 46.68903882162911, 46.58170304979597, 43.828187533787315, 43.474958487919395, 41.41141993658883, 42.01844235828945, 40.88013635362898, 43.19421304975237, 44.84962831224714, 45.491627965654644, 44.94529111044747, 47.95862061636788, 46.79045820236206, 42.62446076529366, 35.407380785260884, 26.68120939391, 17.033222232546123, 10.847907185554504, 3.823096888405936, 1.9726808667182922, 2.0565417153494696, 5.75171879359654, 6.7859733530453274, 6.197940792356219, 7.391044633729117, 7.788544126919337, 7.9874632358551025, 4.210149765014648, 3.415113866329193, 0.9773954961981092, 0.26151914841362406, 0.1629162444067853, 0.5827816224523953, 2.7253240687506537, 9.561073013714381, 13.267317703792028, 17.898491825376237, 24.975470066070557, 28.63211417198181, 24.32043038095747, 19.304600511278423, 4.368365892342158, 0.7534196632249015, 0.05357665688331638, 0.10554583038070373, 0.042154676746577024, 0.03962508801903043, 0.05763764147247587, 0.08395585710448877, 0.017635335480528216, 0.03426940433148827, 0.010018646733702292, 0.01743847720458039, 0.007078357298658895, 0.036812760534563234, 0.0033245868606692447, 0.02552397342930947, 0.09105367266706058, 0.03132896604282515, 0.028993251733481884, 0.04796813747712544, 0.04982683149033359, 0.039939158130437136, 0.021898116384233748, 0.03376127999009831, 0.05927943837429796, 0.0414324644287782, 0.010540853221235531, 0.06129375778670822, 0.019023467154641236, 0.06279828705425773, 0.014971439227727907, 0.014184515025200588, 0.04725236784932869, 0.11080590848411832, 0.10742669552564621, 0.1441003190619605, 0.10503865259566478, 0.13790106028318405, 0.22393354667084558, 0.14006338853921207, 0.07854458782821894, 0.1491648501583508, 0.1582364019538675, 0.10713242845875875, 0.20478931894259794, 0.14965058623680047, 0.0814692366069981, 0.0923034663179091, 0.12149696052074432, 0.1284356324800423, 0.2087615036538669, 0.11138693123523678, 0.17427658981510571, 0.1142603438347578, 0.09271168655582837, 0.07881586612867457, 0.11461818963289261, 0.11338174955121108, 0.1534996304128851, 0.10876072251370975, 0.11113245346184288, 0.13543609183813843, 0.1035278740205935, 0.11375797686300107, 0.15841511450707912, 0.15079431129353388, 0.09846689166235072, 0.20520275032946042, 0.11439928066517625, 0.14669612262930187, 0.3142958735781056, 7.988697409629822, 31.455815179007395, 50.65592173167637, 44.86253111703055, 31.479150703975133, 33.03517893382481, 30.30313335146223, 11.250876648085457, 2.896225218261991, 1.2059627856527055, 0.8577198865158218, 2.7287213035992215, 3.9155947821480885, 12.865857737404959, 11.566592369760786, 11.081617661884852, 16.780035087040492, 12.95282312801906, 19.321288347244263, 15.305773258209229, 11.645410997526985, 6.392624539988382, 1.7611952892371585, 1.6388364263943263, 7.648339901651655, 19.870892592838832, 26.619698728833878, 33.44297913142613, 42.30607346126011, 49.36478315080915, 50.20346893583025, 50.88574034827096, 51.42477117265974, 55.69380692073277, 48.646002428872244, 53.05749361855643, 53.01914998463222, 53.9000426019941, 54.39550127301897, 52.49758345740182, 52.899099009377615, 52.338942187173025, 50.66496133804321, 53.10605110440935, 52.7759039742606, 48.72916194370815, 42.885039057050435, 40.93316500527518, 44.64938817705427, 53.986888136182515, 51.644000734601704, 54.157688753945486, 40.24197210584368, 46.62798500061035, 52.830530711582725, 50.71971661703927, 48.982072898319785, 45.110196181706016, 40.45753301892962, 40.95431184768677, 44.340033531188965, 51.00702462877546, 49.829148633139475, 51.48944500514439, 48.58711644581386, 48.72799464634487, 45.42712088993618, 46.36070169721331, 43.28991753714425, 45.447433948516846, 43.51740503311157, 45.502151012420654, 46.93422337940761, 48.61221333912441, 45.85014111655099, 49.719238553728374, 48.37484897886004, 42.94426897593907, 34.49618707384382, 27.718139444078716, 18.22737090928214, 9.31725117138454, 3.119921386241913, 2.9841105937957764, 2.993557755436216, 10.440584676606314, 11.328243102346148, 12.057317580495562, 10.63147861616952, 12.664365189416067, 14.286557640348162, 13.723453913416181, 7.812809841973441, 4.18870849268777, 2.342597314289638, 0.5623898538095611, 0.8569536847727639, 3.922078319958278, 10.524279202733721, 16.409312214170182, 23.379670347486222, 30.40533787863595, 33.04354803902762, 30.571198327200754, 22.59402711050851, 5.07910190309797, 0.7448499830705779, 0.10940333588847093, 0.1738404275051185, 0.11585401903305735, 0.1672991192234414, 0.1743091187838997, 0.16716561067317212, 0.08310496740575347, 0.13973503187298775, 0.12185051797756127, 0.11607150307723454, 0.08126153025243964, 0.08802046507064785, 0.15761269256472588, 0.107238137429314, 0.13144169189035892, 0.21216418035328388, 0.07731671764382295, 0.09438295901886054, 0.1079809907823801, 0.15918348756219658, 0.12774766582463468, 0.09279769086944205, 0.15742038216974052, 0.14144560508430004, 0.0959321426759873, 0.11904031091502734, 0.09951170666941575, 0.15218183398246765, 0.07984164144311633, 0.11825584300926753, 0.14683986348765238], [0.011764979588666132, 0.014867589443123766, 0.02898174038689051, 0.03928503340908459, 0.025892124478039995, 0.02085448881345136, 0.10061817336827517, 0.05014595329495413, 0.08544134667941503, 0.028063263511285186, 0.04176024773291179, 0.04125696134620479, 0.016261285104389702, 0.046636753382959535, 0.0231855483725667, 0.019837641323517476, 0.06956027528004986, 0.03344308438577822, 0.07150323316454887, 0.02864299195685557, 0.06958207661019904, 0.07499521185777017, 0.07224841389272894, 0.07445307594857045, 0.024791857892913476, 0.05063337553292513, 0.015881415755887116, 0.020832275273278356, 0.03184403179745589, 0.045024455791073184, 0.01558586286513933, 0.042706230721835575, 0.04231300610782845, 0.12395663639264447, 0.04800791319991861, 0.05000900457214032, 0.05042073962145618, 0.03826056766722884, 0.91811346582004, 9.878395506313868, 27.708842754364014, 33.088600158691406, 34.75880118778774, 15.21221923828125, 15.91076854297093, 19.89648280824934, 6.290892056056431, 1.725889755146844, 0.12234037954892431, 0.13979428155081614, 0.503814694072519, 1.5985453426837921, 1.2143393818821226, 4.453698890549796, 7.679160373551505, 2.396181604691914, 9.587827052388873, 8.825855459485735, 3.889556407928467, 2.5911487085478644, 1.7083795347384043, 0.5862729293959481, 0.8359404323356492, 4.556910906519208, 12.97933224269322, 16.841465847832815, 23.23991080692836, 30.516595908573695, 39.54072168895176, 45.60803461074829, 47.464086055755615, 46.92705978666033, 52.16932276317051, 50.53343193871634, 48.96540069580078, 50.74023812157767, 52.487901142665315, 51.84066949571882, 50.87201765605381, 49.79813534872872, 51.583718163626536, 51.23169463021414, 49.03910371235439, 50.623056752341135, 42.043247427259175, 39.19865492412022, 41.890258516584126, 48.713191509246826, 48.119016306740896, 51.513881819588796, 35.808983189719065, 41.12505340576172, 49.998354639325825, 46.748744692121235, 46.555098397391184, 40.73990780966622, 37.431992053985596, 41.06044905526297, 46.531276498522075, 45.59367615836007, 47.958881173815044, 48.56050137111119, 47.735104015895296, 44.99374089922224, 46.89617504392351, 44.865984371730256, 43.88344308308193, 42.32649074281965, 43.88156706946236, 43.458418301173616, 44.635012354169575, 46.18109423773629, 45.946363244737896, 43.12662097385952, 38.53827033724104, 29.836283888135636, 19.613145692007883, 13.534568003245763, 7.191486290522984, 4.196854821273258, 1.6606239144291197, 0.5629052690097264, 1.6767903098038264, 4.818188795021602, 7.612713881901332, 2.2061403393745422, 6.15101135628564, 7.6322852202824185, 6.132081857749394, 1.6148618842874254, 2.8719803478036607, 0.975299420101302, 0.581500982599599, 0.21634483816368238, 2.5689800466809953, 6.8762630224227905, 14.478149005344935, 12.301481621606008, 15.399865763528005, 21.703500815800258, 21.18316238267081, 21.14737742287772, 12.2321811573846, 1.746790153639657, 0.024953932767467837, 0.01975123497790524, 0.06506454651909215, 0.042000038615827046, 0.007229051020528589, 0.013480163445430142, 0.017587459745949933, 0.00353536252597613, 0.002392364986008033, 0.013997627821351801, 0.021180256868579557, 0.05287532987339156, 0.007009794303615178, 0.035857345908880234, 0.04003626327695591, 0.026741453546232412, 0.03778176282399467, 0.004774894606920758, 0.02803738757834903, 0.07896256539970636, 0.010257355353262807, 0.03610403749293514, 0.015797655696847608, 0.03344156446733645, 0.00023895085126111683, 0.04552460056064384, 0.02118896077653127, 0.03555907548538276, 0.043531295377761126, 0.049043764759387286, 0.010215303145482071, 0.017748674577368156, 0.03814284523416843, 0.032251400473926745, 0.03858348587527871, 0.02132220469814326, 0.04382172193644302, 0.04617381947381156, 0.0356852660354759, 0.039756625425070524, 0.03102557946528707, 0.05371604833219733, 0.03379577671044639, 0.04622351537857737, 0.05262038730350988, 0.05622236330860427, 0.03996496281719633, 0.020455778243818452, 0.03055355997223939, 0.03433620271139911, 0.053669385478964875, 0.05085778063429253, 0.012925516198655325, 0.15007340854832105, 0.034216580380286486, 0.03678775651912604, 0.028292280954441855, 0.038972893729805946, 0.05970190106225865, 0.02390450202593846, 0.016276335011103323, 0.00491970034116613, 0.004532557521348021, 0.0458231797175748, 0.0680078753669347, 0.055374303100896735, 0.02615140119035329, 0.08396517339029483, 0.051415777299553156, 0.05839257274887391, 1.5571283251047134, 12.901685254914419, 33.73066234588623, 37.72425760541643, 37.46470764705113, 20.38835620880127, 20.404163360595703, 18.38740529332842, 6.732583395072392, 2.1318638793059757, 0.06000963704926627, 0.14412280571247849, 0.4105503543147019, 1.197155943938664, 2.423429616859981, 3.404085555246898, 6.120500513485499, 6.252437685217176, 9.739993470055715, 7.9692129237311224, 7.377378395625523, 4.6933848176683695, 4.590874135494232, 1.8088287732430866, 1.2720277777739932, 6.53594286101205, 15.231477907725743, 20.089540243148804, 26.89489081927708, 34.21046672548567, 40.50455495289394, 47.03682395390102, 49.1925824710301, 48.744583470480784, 51.98744324275425, 48.572170870644705, 48.46176399503435, 51.91438640866961, 53.01612751824515, 53.44230570111956, 51.863046169281006, 51.404888902391704, 51.532412665230886, 51.85903011049543, 50.977081366947715, 51.53218684877668, 43.220904554639546, 40.2083671433585, 42.77855096544538, 50.95312745230538, 50.66880021776472, 52.75504200799124, 37.66652502332415, 45.651040485927034, 51.252320357731406, 47.7975891658238, 48.309351784842356, 43.94088384083339, 38.31429515566145, 42.350660051618306, 47.29930257797241, 48.84227166857038, 49.76964773450579, 50.85161427089146, 48.7260491507394, 48.16346393312727, 47.57068879263741, 45.5138760975429, 44.43234729766846, 43.10325418199812, 45.210476057870046, 44.705720697130474, 46.50966412680489, 46.548650469098774, 46.04490607125418, 46.04390205655779, 42.559505530766074, 34.018894468035015, 22.98031394822257, 15.580510241644722, 9.089145285742623, 6.504344190870013, 3.6650887727737427, 2.7972344500677924, 3.1399817040988376, 5.58724581343787, 7.167432929788317, 6.133005968161991, 7.364479064941406, 7.535723498889378, 5.777855745383671, 4.30779801096235, 1.958955351795469, 0.39749154075980186, 0.05797090394688504, 0.09827699006668159, 2.7313961429255347, 9.052369339125496, 15.663775716509138, 14.864190919058663, 20.49634858540126, 27.56689974239894, 28.33188772201538, 24.088603734970093, 15.457761628287178, 2.2012286143643514, 0.021438266416745524, 0.01764068233647517, 0.09287840260991029, 0.04130608049620475, 0.019719065632671118, 0.0327822727018169, 0.023641871654295495, 0.011947645456530154, 0.03355705112751041, 0.05607328577233212, 0.004933165444526821, 0.06017286543335233, 0.06625376734882593, 0.043277940579823086, 0.04345483805185982, 0.06960926550839629, 0.03216816458318915, 0.033932131715118885, 0.02644143589506192, 0.04609826459948506, 0.04079310462943145, 0.06390675543142216, 0.048039841665221114, 0.01635418163745531, 0.058635162588741095, 0.03726727043145469, 0.04774889602724995, 0.05574671704588192, 0.06756962316909007, 0.036907012441328595, 0.04429703910968133, 0.02717886266431638, 0.1779562309384346, 0.07905402513486998, 0.07891388729746852, 0.1572609535817589, 0.21849313431552478, 0.08983349028442587, 0.19799811978425297, 0.11926979145833425, 0.2092654380415167, 0.13659494822578772, 0.061777064709791114, 0.19707965478301048, 0.1274860498628446, 0.16882120897727354, 0.0933251975636397, 0.07865717714386326, 0.14340863403465065, 0.04930183198302984, 0.16869688779115677, 0.11148709657468966, 0.10575370636901685, 0.3259086747254644, 0.11930747729326997, 0.14520734894488538, 0.11364315516714539, 0.1403795587165015, 0.12243061113570418, 0.13948400105748857, 0.10713333769568376, 0.1460256621773754, 0.092926639664386, 0.10092548187822104, 0.21055322965340956, 0.19902291122291768, 0.09888450282492808, 0.17636014015546866, 0.254358812634434, 0.11855815750147615, 1.4936866036483218, 15.635934284755162, 42.17654166902815, 46.80067900248936, 46.23177439825875, 25.161106824874878, 24.931838853018625, 26.04933500289917, 9.115498065948486, 2.4597092015402655, 0.3320358730852604, 0.576981993658202, 1.6021100942577635, 6.124225182192666, 6.6784921033041815, 11.295288664954048, 16.048971687044414, 10.669208203043256, 17.19060935292925, 19.246581315994263, 13.113495877810887, 5.811471998691559, 3.9549202833856856, 1.8017093666962214, 1.3600049998079027, 6.027344277926853, 14.588969298771449, 18.764525720051356, 27.28738934653146, 34.33382156917027, 40.35806955610003, 47.102178709847585, 49.94068111692156, 49.652473313467844, 52.293476649693076, 49.28870732443673, 49.189963000161306, 51.931604044778005, 54.65339061192104, 54.26267603465489, 54.98275259562901, 52.99310466221401, 54.715504033224924, 52.88721064158848, 53.14496796471732, 53.279512882232666, 45.698291710444856, 42.947242804935996, 45.23628166743687, 53.951205662318635, 52.28038624354771, 54.36669751576015, 42.229327133723665, 47.569191455841064, 53.40874242782593, 50.95108815601894, 50.39124400275094, 46.16632236753191, 39.59055069514683, 45.00687994275774, 49.7641065461295, 50.772033078329905, 49.86224637712751, 51.02547904423305, 50.604404313223704, 49.20976536614554, 50.509887967790874, 48.86755268914359, 46.51067508969988, 45.277901376996724, 47.60418953214373, 47.172956534794395, 48.16372101647513, 49.74001714161464, 47.6640100479126, 46.34069088527134, 41.21792302812849, 31.741851670401438, 20.907167775290354, 15.877215691975184, 8.622764825820923, 5.493339606693812, 3.3594533673354556, 2.6603712226663316, 5.023135466235025, 9.66194782938276, 15.610081774847847, 8.930632557187762, 13.864013365336827, 16.305551290512085, 14.397133009774343, 8.672933425222125, 6.512616889817374, 2.614867687225342, 1.0887730568647385, 0.39716592537505285, 4.29297229221889, 10.881887350763593, 20.43097472190857, 20.533922706331524, 24.641355514526367, 32.645690713609966, 33.80970852715628, 28.49304597718375, 17.22903983933585, 3.0604849755764008, 0.18675567662077291, 0.11255116162023374, 0.18017848740730966, 0.17297469824552536, 0.12335420586168766, 0.09661035878317696, 0.07993318260248218, 0.09326372907630034, 0.08354665977614266, 0.1686135229787656, 0.0754921573347279, 0.15634702119444097, 0.17596509706761154, 0.12281787821224757, 0.09891395124473742, 0.09958406564380441, 0.0623654495658619, 0.08176371401974133, 0.17644227003412588, 0.1761215672429119, 0.14722968185586588, 0.15239429686750683, 0.07809693792036601, 0.07459466585091182, 0.24120310427887098, 0.18246680604560034, 0.0685382251228605, 0.08913732014064278, 0.1159121287720544, 0.15010353550314903, 0.10843631492129394, 0.1004899845325521], [0.07345241321516888, 0.03090607248512762, 0.03349287189277155, 0.028285880672878454, 0.03962634330881493, 0.01870548868152712, 0.054823587116386206, 0.01773262213516448, 0.03336165339819022, 0.027478205173143318, 0.009259151461135064, 0.03990194048466427, 0.057315642679376264, 0.0354555887170136, 0.02327309126433517, 0.034329831267574, 0.05556364829785057, 0.023649662932647125, 0.02602960754718099, 0.105577314405569, 0.04702926892787218, 0.0477762817006026, 0.039104308999542675, 0.017991266113572886, 0.057251419339861186, 0.04451191757938691, 0.033421486616134644, 0.025254449141877036, 0.05644413230142423, 0.02452103081824524, 0.012716451077722013, 0.07550678654972996, 0.04615103087521025, 0.0199871582112142, 0.04116609872185758, 0.04010367912373372, 0.01119539184894945, 0.012336651279058839, 0.08513567343886409, 2.994506184543882, 14.323173778397695, 29.008188894816808, 32.388649054935996, 20.464682170322963, 18.966443845203944, 17.203526054109844, 13.663892218044825, 4.376104882785252, 1.028289096696036, 0.1984388825616666, 0.2366403905408723, 0.4268672487565449, 2.9992298739297047, 0.6275022913302694, 2.7713647867952074, 3.2130248589175086, 9.230012195450918, 5.05802150283541, 6.075862680162702, 4.7836349691663465, 4.248551155839648, 2.3246116851057326, 0.46777102244751795, 0.37608620364751133, 1.8724033789975303, 5.2977447765214105, 10.100446905408587, 18.74632317679269, 25.726306302206858, 35.622788837977815, 43.53437948226929, 45.115376063755576, 42.91553817476545, 53.249736377171104, 51.26167263303484, 50.67533152444022, 49.29262958254133, 49.5216178894043, 48.84168801988874, 50.569621631077354, 50.37548896244594, 52.08754941395351, 49.75513989584786, 48.75802823475429, 41.08243662970406, 42.405272892543245, 44.400649615696494, 49.60134499413626, 48.19272974559239, 53.01185785021101, 33.09749732698713, 40.16006326675415, 49.72417177472796, 46.334517410823274, 46.90522507258824, 42.59569869722639, 40.26281670161656, 43.20808512823922, 46.43385233197893, 48.58579976218087, 49.87775823048183, 47.94185808726719, 47.238995688302175, 48.38907541547503, 47.309481688908164, 46.1285206930978, 44.20428310121809, 42.76319892065865, 43.88821996961321, 44.162236077444895, 44.37519836425781, 46.752319540296284, 45.39233125959124, 38.18416234425136, 23.61170891353062, 18.568711587360927, 10.109800917761666, 6.098558970860072, 2.5549511994634355, 3.700349577835628, 1.8499433270522525, 2.786757652248655, 0.7963144215089935, 3.3691524011748175, 4.045739318643298, 4.439047311033521, 7.401743991034372, 4.446015051433018, 4.919052754129682, 3.2857418826648166, 2.0396786545004164, 0.21503236144781113, 0.21052137921963418, 1.097373081105096, 4.909519391400473, 7.960126417023795, 9.322174838611058, 13.332203456333705, 14.37755732876914, 20.524756295340403, 23.45500271660941, 15.6784086227417, 4.250010711806161, 0.6894158433590616, 0.0341414190562708, 0.049408843740820885, 0.014457352259861571, 0.034068025315978696, 0.014495816713731204, 0.017444260019276823, 0.016916885639407804, 0.044043507892638445, 0.05777857319584914, 0.015422088260363256, 0.04427932934569461, 0.04127584497577377, 0.03921180930254715, 0.020960348758048246, 0.03888458239712885, 0.10143692764852728, 0.030471033150596277, 0.05360703489610127, 0.0393577723630837, 0.049927861961935244, 0.025245041253843477, 0.021108047171894993, 0.056990692258945534, 0.06574536820075341, 0.024120934340836744, 0.035691895322608094, 0.0440851461940578, 0.046705502551048994, 0.023785965350855674, 0.025422381469979882, 0.011399190689969276, 0.06426360378307955, 0.008258100266435316, 0.016544303757005503, 0.0455770852443363, 0.014694669882633855, 0.007313333551532456, 0.011605290612871093, 0.06377834267914295, 0.01535637044746961, 0.014796265234638537, 0.030088994186371565, 0.024454966952492083, 0.035190661504332504, 0.042518558113702705, 0.07370991725474596, 0.11827013295676027, 0.05704349585409675, 0.03903164807707071, 0.08306618234408752, 0.009940064745023847, 0.07044219438518796, 0.05216993843870504, 0.02777587848582438, 0.03565772769174405, 0.05738552500094686, 0.011523081854517971, 0.004664235299320093, 0.023361348314210773, 0.02546370934162821, 0.02276879216411284, 0.04099134881315487, 0.0043861835230407965, 0.030960511349673783, 0.006508761077254478, 0.0598696552749191, 0.021548385864921978, 0.026886943328593458, 0.03644020748989923, 0.030283350364438126, 0.04163360934970634, 3.906708036150251, 18.120273113250732, 35.748672825949534, 38.20891530173165, 21.197953360421316, 20.831837143216813, 25.154481717518397, 16.67957976886204, 5.156323313713074, 1.623562440276146, 0.13136712089180946, 0.08547159577054636, 0.27993830719164436, 0.545229648905141, 2.821458258799144, 4.068311410290854, 3.9466975246156966, 7.059339370046343, 6.421711436339787, 7.324504341397967, 7.676342010498047, 7.939372147832598, 3.4412097803183963, 1.9023555432047163, 1.2453342101403644, 4.127654671669006, 6.4393377133778165, 14.670275381633214, 20.85406616755894, 29.926916190556117, 38.54143524169922, 45.82916797910418, 45.19069801058088, 46.85431909561157, 52.22180250712803, 52.88465370450701, 50.87846558434622, 50.422629015786306, 50.036288329533164, 49.27895900181362, 50.915742669786724, 50.859635966164724, 52.20700979232788, 51.940487316676546, 49.73795005253383, 43.27330092021397, 42.80611446925572, 46.066209248134065, 50.79141160420009, 50.647649901253835, 53.154553004673545, 36.864220006125315, 43.345252990722656, 51.15961749213082, 47.704782077244346, 47.8483110155378, 44.12311771937779, 42.04924372264317, 44.55779702322823, 49.393065793173655, 50.26027045931135, 50.49238198144095, 48.144585677555625, 48.493562425885884, 49.291295528411865, 49.17140088762556, 47.1337582724435, 45.03306075504848, 43.93089233125959, 45.60019704273769, 45.050031730106895, 45.461743763514924, 45.99985047749111, 47.273166928972515, 39.6839588029044, 27.96723931176322, 22.543169770921978, 13.029306292533875, 7.05734567131315, 4.136573553085327, 8.688438330377851, 5.772462206227439, 3.661652888570513, 4.382423835141318, 6.867708921432495, 5.810503159250532, 7.320109605789185, 9.372136729104177, 5.700530546052115, 4.959169915744236, 1.9999568888119288, 1.019939858998571, 0.22754487288849695, 0.1681536255138261, 1.7333281274352754, 7.356240238462176, 10.104230199541364, 15.141675915036883, 18.245566504342214, 20.26107736996242, 26.2107538155147, 26.671025071825298, 20.490077836172922, 6.957944308008466, 0.9155836701393127, 0.010196768113278916, 0.0442046294254916, 0.01476025877387396, 0.015686099450769167, 0.019928760094834224, 0.07128658371844462, 0.026790832235877002, 0.0360688690229186, 0.026732179668865035, 0.042389697528311183, 0.011459943322863961, 0.07730609178543091, 0.026215444718088423, 0.01817687427891152, 0.06770663296005555, 0.055512659783874235, 0.016515949474913732, 0.030124824228031293, 0.028858684668583528, 0.04476762689383967, 0.06710568842078958, 0.041645846728767665, 0.011747876265352326, 0.02784466666967741, 0.009905065908761961, 0.01567445239717407, 0.026052664167114666, 0.016348495513999035, 0.03586817193510277, 0.013986637250387242, 0.004020335676614195, 0.022842788104233996, 0.16787837099816116, 0.08443309113915477, 0.19868957410965646, 0.08068952523171902, 0.1304471766842263, 0.09434603992849588, 0.16314995900860854, 0.07347039439316307, 0.09107947735381977, 0.06039006449282169, 0.1434628761240414, 0.11642267209078584, 0.13724140210875443, 0.1627141631075314, 0.22066242434084415, 0.13606908358633518, 0.10999822789537055, 0.13075460733047553, 0.14379936163978918, 0.19690103722470148, 0.1317560707351991, 0.1485806450779949, 0.11314554472586938, 0.08876576114978109, 0.15666943389390195, 0.12576406369251864, 0.15484893800956862, 0.13311825692653656, 0.1793480555393866, 0.08590097273034708, 0.09110769762524537, 0.14565371642155306, 0.14640454256108829, 0.13369003124535084, 0.15961772283273085, 0.1863894441298076, 0.08658032199101788, 0.14384148509374686, 0.2329537197947502, 4.9234974299158365, 22.877548354012625, 46.704727854047505, 45.61010864802769, 27.593627725328716, 27.661124263490947, 25.06448517526899, 19.346049989972794, 6.8113225528172086, 1.9210468488080161, 0.3193397500685283, 1.2949734436614173, 1.8585130614893777, 5.123139585767474, 6.461424733911242, 10.18562834603446, 8.970742770603724, 18.860608884266444, 13.075008068765912, 12.223777311188833, 12.259595274925232, 10.741205436842781, 6.373516125338418, 1.7961058616638184, 0.8828472324780056, 2.6312094160488675, 6.868718581540244, 12.816066077777318, 21.633344854627335, 29.409855570111954, 37.33822611400059, 46.967574732644216, 48.0476861000061, 47.115599155426025, 54.74263674872262, 53.82161481039864, 51.8259254183088, 49.91702250071934, 49.444482462746755, 49.051610469818115, 51.620856285095215, 51.2412553514753, 53.28095810753958, 53.16999190194266, 52.54869788033621, 43.8687059538705, 45.328932421548025, 48.58838101795742, 52.54247576849801, 52.58784403119768, 55.99817623410906, 38.66781602587019, 46.83664982659476, 53.01500538417271, 49.58022247041975, 50.13377155576433, 47.61449718475342, 42.813486507960725, 47.096783433641704, 51.131265367780415, 51.83367613383702, 49.77895484651838, 49.24096277781895, 46.95236165182931, 50.81577893665859, 50.048242705208914, 49.706318378448486, 46.24454171316964, 45.115924971444265, 47.0347638130188, 47.76992491313389, 46.79194859095982, 49.796457358769004, 47.54567180361067, 40.821847915649414, 25.93270775250026, 22.78845160348075, 12.193239978381566, 7.803976075989859, 3.5510935868535722, 7.114105071340289, 4.3392512031963895, 4.898602034364428, 4.863478021962302, 9.587919984545026, 9.580397691045489, 12.57438862323761, 17.01003783089774, 11.228154301643372, 11.341304847172328, 7.219271268163409, 4.0230478048324585, 0.7417864788855825, 0.623162924179009, 1.8651785552501678, 7.2515721406255444, 12.006146703447614, 18.439429930278234, 22.50569292477199, 23.964729513440812, 30.231396675109863, 33.5235469681876, 22.438305820737565, 6.740779229572841, 0.9830341764858791, 0.15100874193012714, 0.1005724740347692, 0.12984618464750902, 0.1543033415717738, 0.051883464346506765, 0.10225282529635088, 0.1419990046748093, 0.1082274347011532, 0.17323296224432333, 0.11818398615079266, 0.07779884391597339, 0.12914903062794889, 0.08609959350100585, 0.0960182962673051, 0.08471289183944464, 0.16193363070487976, 0.15236616480563367, 0.20143679955175944, 0.09047781356743403, 0.13843711651861668, 0.14286814018019608, 0.11090319683509213, 0.10213418344834022, 0.11401672262166228, 0.09602030473096029, 0.14913470963282244, 0.1572457408266408, 0.13069470625902924, 0.1659027755792652, 0.08969312853046826, 0.16897024240876946, 0.10885303720299687], [0.057479413891477246, 0.045482063200324774, 0.007314794098160097, 0.024645314684935977, 0.02876383565100176, 0.041470109551612816, 0.07830927866910185, 0.026909618272579143, 0.06643708036946398, 0.02542220674721258, 0.028276096197909543, 0.05182401789352298, 0.03242674070809569, 0.06344062222966126, 0.05735937426132815, 0.015891050953151922, 0.08246650666530643, 0.01287087716627866, 0.0291799472511879, 0.05019229384405272, 0.06464829921190228, 0.05463298662964787, 0.03396641469693609, 0.05125817057809659, 0.012143164473984922, 0.007960856975322323, 0.04037570720538497, 0.04049427780721869, 0.04508916428312659, 0.060097629470484595, 0.03819257506568517, 0.07344418258539268, 0.022061602611626898, 0.04054694908804127, 0.026769422759701098, 0.03405137067394597, 0.02644470813018935, 0.04244048926713211, 0.022901827436206595, 0.5019920947296279, 6.93590201650347, 25.888029098510742, 34.63951104027884, 32.80954313278198, 18.444717509405955, 13.923918996538434, 20.77267149516514, 10.153702242033821, 3.4819828953061784, 1.1361807244164603, 0.06527057010680437, 0.25676343217492104, 0.2284274569579533, 1.1452328158276421, 2.8804052557264055, 4.767678431102207, 3.649219955716814, 3.678491847855704, 5.891253386225019, 5.681879843984332, 8.591854895864214, 2.402327286345618, 1.7911204206092017, 2.079125532082149, 1.3732445750917708, 0.5435277745127678, 4.13349506684712, 6.697534075805119, 12.69099850314004, 22.330226591655187, 31.373433862413677, 38.32925115312849, 43.44765901565552, 41.11358540398734, 47.01840080533709, 50.32629224232265, 49.14614071164812, 49.32091917310442, 50.78484903063093, 49.575570651463096, 50.78393881661551, 51.37887832096645, 50.83408396584647, 49.57294075829642, 43.34684412819998, 44.957387924194336, 45.12458937508719, 48.87911449159895, 48.11253363745553, 52.37145628247942, 37.30075795309884, 40.46997029440743, 49.06341198512486, 47.33546447753906, 46.78526789801461, 44.037175451006206, 44.71249866485596, 43.03875058037894, 47.64641720908028, 48.07843882696969, 49.21989583969116, 46.64372614451817, 49.85697269439697, 47.770494665418354, 48.14497825077602, 48.59933137893677, 46.231479099818635, 45.53499514716012, 44.91632407052176, 45.78791652406965, 47.94207348142351, 47.12055322102138, 40.44378253391811, 23.762505667550222, 15.503930670874459, 10.329785227775574, 6.493609224046979, 2.4293362370559146, 1.3390110177653176, 7.032769458634513, 5.897969254425593, 5.512272145066943, 3.756485377039228, 4.151057073048182, 4.971327091966357, 5.381436262811933, 5.44856367792402, 4.165267441953931, 2.437417426279613, 1.9673665804522378, 0.40574847055333, 0.21552820769803865, 0.7735042997768947, 1.7597806794302804, 12.21133656161172, 28.118485961641582, 25.402898924691335, 24.614099468503678, 18.870520489556448, 21.917380264827184, 21.23206901550293, 10.472419585500445, 1.893239289522171, 0.02425118422667895, 0.04264207862849746, 0.06060162492628608, 0.022970907390117645, 0.06687676427619797, 0.05110982585964458, 0.04931823895978076, 0.01943690193417881, 0.01387107595136123, 0.007762622969624187, 0.021921130595728755, 0.02084054491881813, 0.026006433879956603, 0.06859222972499472, 0.03692927856796554, 0.01866137542362724, 0.06836369234536376, 0.030699417859848057, 0.038550770309354575, 0.049603030285132785, 0.024370246766401187, 0.02549942403233477, 0.03659031300672463, 0.0455560472660831, 0.06903712478067194, 0.013612795837356575, 0.10499708554042236, 0.02169728358941419, 0.0319161702479635, 0.06559703366032668, 0.024615082557180097, 0.04265296911554677, 0.0326882413189326, 0.024416314205154777, 0.018514776236510704, 0.029521508208875145, 0.05030236918745296, 0.04087379940652421, 0.03047563022534762, 0.07100739369967154, 0.017333616402798464, 0.019172313989007046, 0.031593774511877976, 0.018674844343747412, 0.03509975477520909, 0.05011452016021524, 0.030025937927088568, 0.018742511248482124, 0.048949102338935645, 0.07279436316873346, 0.04169585136696696, 0.033003468332546096, 0.054637274970965724, 0.009881675958500376, 0.04095397171165262, 0.013897364094321216, 0.01689925729962332, 0.030884702024715285, 0.015582412514569504, 0.04478544522342937, 0.04759084147268108, 0.009300898328157408, 0.06999168105955635, 0.0231545478039022, 0.03497490093910268, 0.010675045395536082, 0.016809385336403335, 0.023949972353875637, 0.028395370779825107, 0.01980569419850196, 0.06302936894020864, 0.0493744454080505, 0.6037479202662195, 9.873006309781756, 31.909251144954137, 39.34062051773071, 35.28388350350516, 20.597125257764542, 17.85145946911403, 25.273214272090367, 11.10222862448011, 3.7333913019725253, 0.9243173386369432, 0.07795648117150579, 0.2354977647108691, 0.3486132435500622, 0.7185753158160618, 1.9772176061357771, 1.9540282104696547, 4.738591534750802, 7.220601413931165, 6.842015785830362, 6.068769437926156, 6.721075441156115, 5.192570328712463, 3.895033759730203, 2.991642875330789, 1.858624232666833, 1.8357281812599726, 6.158111112458365, 9.622236268860952, 15.410680634634835, 26.640640599387034, 33.11848783493042, 41.64847162791661, 44.18929236275809, 46.14502613885062, 48.556968212127686, 51.54640286309378, 48.206636565072195, 49.351630210876465, 50.8502767426627, 50.12465899331229, 50.72856167384556, 53.11966609954834, 51.54610061645508, 50.53999103818621, 45.919848918914795, 45.28011785234724, 46.87056050981794, 51.71851669039045, 49.92391511372158, 52.20025266919817, 39.43099921090262, 45.38159629276821, 50.15426179340908, 48.72940860475813, 49.15971401759556, 45.22707183020455, 45.00613995960781, 44.92132677350725, 49.36594349997384, 49.63997003010341, 48.701108591897146, 48.03615209034511, 49.366464614868164, 48.482646805899485, 48.72426693780081, 49.449137755802695, 47.19251571382795, 46.511724267687114, 45.460475717272075, 48.126836504255024, 47.74491139820644, 48.25819219861712, 41.723939486912315, 28.401449612208776, 18.890484401157924, 14.429205894470215, 9.575335928371974, 3.569343898977552, 1.6704790656055724, 6.693850662027087, 12.230451924460274, 3.8875740000179837, 6.2582420366150995, 10.334870440619332, 6.205657635416303, 4.721233631883349, 6.058403594153268, 4.72414926971708, 1.7096369415521622, 0.8754014234457697, 0.33979448676109314, 0.05042756907641888, 1.323846465774945, 3.055804495300565, 8.530041115624563, 21.25871535709926, 21.82949423789978, 22.69924541882106, 22.52794279370989, 26.714232444763184, 26.821474415915354, 12.461768746376038, 2.5937089025974274, 0.051549160320843966, 0.074277498227145, 0.05618075893393584, 0.012585636311476784, 0.06110571537699018, 0.011895068322441407, 0.08758250464286123, 0.07364502216556243, 0.018502153788826296, 0.058635746128857136, 0.046366299502551556, 0.02907340707523482, 0.02072519057297281, 0.0428385552284973, 0.06037553705807243, 0.0037635326485282606, 0.07812959581081357, 0.00497547210293955, 0.08292131511760609, 0.009322390924873096, 0.012603438525859798, 0.03861326677724719, 0.03810861314247761, 0.02679942418555064, 0.027559190023956553, 0.047741958006684265, 0.04065078190926995, 0.0642676410664405, 0.0515680235943624, 0.05544592925746526, 0.06570872052439622, 0.025722695980221033, 0.048145333504570384, 0.16027430045817578, 0.12090605151440416, 0.08376895463360207, 0.15708711290998117, 0.12237123932157244, 0.12268242905182497, 0.1549944837710687, 0.1265437411410468, 0.10406312279935394, 0.10907330324075051, 0.13176528524075234, 0.10287545581481286, 0.19942817304815563, 0.07597950154117175, 0.1325712219945022, 0.22820595598646573, 0.12321894669107028, 0.16004654339381627, 0.153618971151965, 0.1380691741194044, 0.17024928091892175, 0.13564594914870604, 0.10699574436460223, 0.1344401924205678, 0.08267652003892831, 0.18218938021787576, 0.08789541106671095, 0.14584073424339294, 0.14543091266282968, 0.2833458014896938, 0.09835599868425302, 0.11844751558133534, 0.13823807505624636, 0.11359151186687605, 0.09646216673510415, 0.09777350351214409, 0.07457684752132211, 0.08634153873260532, 0.1274978020893676, 0.9985349561486925, 11.07808710847582, 39.19001136507307, 47.42693056379046, 44.02752092906407, 26.426422425678798, 21.66051057406834, 30.28035715648106, 14.458122559956141, 5.630180035318647, 1.7837263430867876, 0.2999396467847483, 0.9777492029326302, 1.679718541247504, 3.4113121160439084, 7.215729858194079, 12.824560250554766, 13.122277532305036, 10.289181692259652, 14.205611995288304, 12.532853160585676, 15.020645243780953, 7.54582096849169, 4.517402146543775, 3.931408013616289, 3.0880471765995026, 1.2875750235148837, 5.531186010156359, 7.778011526380267, 14.461571472031729, 24.882993016924175, 33.64443520137242, 39.80016395023891, 46.62163782119751, 47.081049237932476, 52.23413208552769, 51.804587500435964, 49.91049119404384, 50.18461847305298, 51.364123821258545, 52.05218308312552, 53.18749441419329, 55.337958403996055, 53.93101419721331, 51.67281491415841, 46.343195710863384, 47.826472827366416, 49.59865951538086, 53.61676801953997, 51.543637480054585, 52.63895845413208, 44.643166065216064, 46.61447422845023, 52.66671650750296, 51.4922069140843, 50.70741135733468, 48.02654620579311, 47.68339204788208, 46.1233686038426, 50.86270012174334, 51.76971796580723, 49.58919606889997, 49.91091503415789, 50.94053731645857, 48.75057281766619, 50.00910350254604, 52.06744827542986, 48.404656750815256, 48.62275723048619, 47.50635889598301, 50.54638685498919, 49.76463808332171, 50.214071886880056, 42.13366780962263, 26.60723713466099, 18.60874363354274, 15.26361506325858, 9.110311235700335, 3.5751180691378455, 2.7518370917865207, 13.111370597566877, 12.404347964695521, 8.28118096079145, 11.065040997096471, 13.588406988552638, 11.776764954839434, 12.628754803112574, 12.257516026496887, 12.406581810542516, 7.558347702026367, 5.556579070431845, 1.1459667193038123, 0.6976081494774137, 1.5250438238893236, 3.3756057577473775, 15.181263276508876, 32.99916294642857, 34.12953410829817, 33.080845969063894, 31.073848383767263, 32.993851048605784, 30.052511828286306, 14.03386468546731, 2.830650508403778, 0.08345258768115725, 0.4266154036990234, 0.1905219123831817, 0.12287396591688905, 0.11993371083268098, 0.15149757212826184, 0.18526080969188893, 0.19311920872756413, 0.11980742189501013, 0.1246362706380231, 0.16176310128399304, 0.20377531621072972, 0.10712064909083502, 0.14928580581077508, 0.26257389038801193, 0.14367456547915936, 0.14358780799167498, 0.32121771786894115, 0.23941394314169884, 0.10181810148060322, 0.09794009742992264, 0.1253140999802521, 0.13025694260639803, 0.15760157816112041, 0.09021423663944006, 0.10736236362052815, 0.27513585346085684, 0.1087186262011528, 0.10632264441145317, 0.10412014009697096, 0.13500508639429296, 0.12358477206102439, 0.14045851305127144], [0.023319503059610724, 0.028063745271148424, 0.04702214431017637, 0.07718062387513262, 0.030999995302408934, 0.015069492626935244, 0.013022147218829818, 0.05233677323641522, 0.02166212529742292, 0.026446748824257935, 0.030853007653994218, 0.06493315499808107, 0.02291066705116204, 0.06441619273807321, 0.02560598456433841, 0.0383538628396179, 0.05604745055149708, 0.021617942489683628, 0.06026064072336469, 0.0740083030291966, 0.039491969626396894, 0.054171379256461344, 0.08236592063414198, 0.06571407416569335, 0.015116450642900807, 0.050289728080055544, 0.04997339166168656, 0.028323805691408258, 0.06190905334161861, 0.06611669648970876, 0.10708949754812888, 0.022564183321914504, 0.06010769893016134, 0.09249563422054052, 0.022469166366915618, 0.030340852814593484, 0.043102739445332966, 0.05022273292498929, 0.059729049248354774, 0.110135454817542, 2.1725905282156805, 15.902981349400111, 32.48923812593733, 39.25865261895316, 27.892428057534353, 17.752907957349503, 16.683611461094447, 22.71000644138881, 13.954036831855774, 5.644846814019339, 1.2005113810300827, 0.08140036530260529, 0.2199463934770652, 0.6881657647235053, 1.4990459446396147, 1.035738651241575, 2.6626754190240587, 7.036879752363477, 4.0667919261114935, 5.318096918719156, 5.4154398781912665, 3.9048819627080644, 3.0514277815818787, 2.52404648065567, 1.6666925145047051, 0.7513382434844971, 1.2229670903512408, 1.916980198451451, 4.53430711371558, 9.664055739130292, 17.890986033848353, 26.147803136280604, 34.8061740057809, 41.63592318126133, 42.49130548749651, 46.518825326647075, 50.83231912340437, 51.33328424181257, 49.49862282616751, 52.03406565529959, 53.51951060976301, 50.08278914860317, 48.950510706220356, 47.248024872371126, 44.67755964824131, 45.812992572784424, 47.4629430770874, 51.680666378566194, 49.75834648949759, 51.300057956150596, 33.9189897945949, 40.55375167301723, 49.53156770978655, 47.36142989567348, 47.06904969896589, 45.141647202628, 46.479557582310264, 45.50441265106201, 48.166538511003765, 48.80408089501517, 49.05612679890224, 47.454799788338796, 48.92742184230259, 47.4959192276001, 47.87412357330322, 46.89446578707014, 47.69584321975708, 45.1331148147583, 47.10519770213536, 47.09553623199463, 46.80368062428066, 40.072925908224924, 26.50481721333095, 13.309605308941432, 5.302565957818713, 4.193767649786813, 2.6945044653756276, 0.649468369781971, 0.9082372529166085, 5.992025715964181, 14.402265991483416, 1.920011784349169, 4.236123434134892, 7.9698834248951504, 3.9789549708366394, 4.49123045376369, 5.433152139186859, 2.060294176851, 2.2410891268934523, 0.2600293297852789, 0.4728284967797143, 0.6014518120459148, 2.2199034179959978, 15.614372287477766, 39.0149758202689, 32.533209800720215, 36.33412456512451, 34.8707401411874, 30.042228494371685, 26.332328183310374, 15.253871951784406, 5.826231709548405, 0.23309520791683877, 0.1475642267614603, 0.007708988169075123, 0.017253478024420992, 0.10153537629438297, 0.04155581191714321, 0.015175479796848126, 0.021197254170796702, 0.04621861296306763, 0.05094007336135421, 0.01750008139892348, 0.042168481541531425, 0.020179309150470153, 0.042355577394898446, 0.03865975660404988, 0.07178194142345871, 0.03035203507170081, 0.04329947728131499, 0.02663563940274928, 0.020709219554971372, 0.0315993859964822, 0.02257060056685337, 0.026565458525770476, 0.05151796128068652, 0.032765244865523915, 0.03273290927921023, 0.04538342456466385, 0.026175898000864044, 0.05657530669122934, 0.054835281667432616, 0.04610133836311953, 0.04159637134788292, 0.01770197270837213, 0.021961913943024616, 0.01764689602090844, 0.023624426518966044, 0.026453291598175253, 0.03043133206665516, 0.025084099532770257, 0.028367121670661227, 0.01221469309114452, 0.06895479134150914, 0.038945148432893414, 0.0559251955045121, 0.02959241172564881, 0.03030715337289231, 0.018231989982138787, 0.07887226595942463, 0.023675716981025677, 0.029289439054472104, 0.022995626420847008, 0.011257793321939451, 0.026093720624755536, 0.02995070196422083, 0.09500095514314515, 0.010261459641956856, 0.047903242387941906, 0.016873330476560762, 0.033506907389632294, 0.06348848608987671, 0.03768096644697445, 0.059832994027861526, 0.0438850394317082, 0.042561061547270844, 0.06396970312510218, 0.03901455917262605, 0.023686030713309134, 0.06012299310948167, 0.04660180204414895, 0.045692110500697575, 0.06358283638421978, 0.08834975132984774, 0.007408394611307553, 0.06647640825914485, 2.711334305150168, 20.61044669151306, 38.50713893345424, 43.18933194024222, 27.340239082063945, 17.140415566308157, 21.13238321031843, 26.024873869759695, 15.302238362176077, 5.041823080607823, 1.2073146445410592, 0.09769171290099621, 0.06187307062957968, 0.26436031024370876, 0.6866662566150937, 2.1409636310168674, 2.4451861636979237, 5.190631781305585, 7.41059512751443, 4.116716470037188, 7.336658477783203, 6.18220442533493, 4.885769145829337, 4.31740346125194, 4.352762409618922, 2.0670925549098422, 2.819455223424094, 4.178570202418736, 6.615111070019858, 12.828225425311498, 19.55724569729396, 28.28525836127145, 37.00809288024902, 42.663360255105154, 45.99634511130196, 48.45166826248169, 49.87560428891863, 51.93818746294294, 49.98079654148647, 52.501613412584575, 53.38817228589739, 52.68110275268555, 50.29513651984078, 48.7763089452471, 45.38514682224819, 47.44056987762451, 49.855732440948486, 52.901774065835134, 51.3475593158177, 50.692719391414094, 36.9307906968253, 45.219529560634065, 52.12217228753226, 49.02067014149257, 49.280397278921946, 47.22402926853725, 48.087613923209055, 47.818892342703684, 49.81625625065395, 50.90540375028338, 50.73700026103428, 47.97803735733032, 50.181321552821565, 48.19918462208339, 49.45222275597708, 49.46485110691616, 49.227556228637695, 47.59966625486101, 46.621554442814414, 47.9699079649789, 48.044309275490896, 42.47531073434012, 29.629272733415874, 17.597712993621826, 9.020170518330165, 6.6572362610272, 5.817784871373858, 2.0100647807121277, 2.0354493728705814, 5.805254229477473, 18.36726941381182, 6.8141244138990125, 5.245186431067331, 7.928153412682669, 6.172532098633902, 5.4377870219094415, 4.61476160798754, 3.3086950395788466, 1.0686048247984477, 0.23616525317941392, 0.2823130169085094, 0.6775884894388062, 2.818726748228073, 8.97413088594164, 35.516123567308696, 37.95093216214861, 40.17342812674386, 39.45940344674246, 32.87241390773228, 30.124022688184464, 19.423272269112722, 7.521250401224409, 0.5535898517285074, 0.09680042322725058, 0.017284880625084043, 0.03587830924828138, 0.027360939054882953, 0.01757648783469839, 0.005547134887560138, 0.08654653773243938, 0.07866340609533445, 0.06307029817253351, 0.03966480606634702, 0.033917543212217946, 0.04104183181854231, 0.03750577209783452, 0.05448722034426672, 0.08323897128658635, 0.015194516096796309, 0.04175832408613392, 0.04184957008276667, 0.034022733103483915, 0.012544208355913205, 0.005928700149524957, 0.01131136026898665, 0.050962247885763645, 0.059234071522951126, 0.013158028097158032, 0.059813364009772024, 0.04798870048086558, 0.044945043445165665, 0.026169460399874618, 0.019368344452232122, 0.0658413130523903, 0.03885050636849233, 0.01372036399386291, 0.07926829970840897, 0.15565970593265124, 0.16232803596981935, 0.10747631679155997, 0.06747418043336698, 0.1460885623736041, 0.16642481328121253, 0.11663755056049142, 0.1218365401561771, 0.1966800790812288, 0.1278647402567523, 0.141671231548701, 0.08192048275044986, 0.1525332744100264, 0.1402425624962364, 0.13994767117713178, 0.15865397240434373, 0.11415920140487806, 0.12127730516450745, 0.19330238604119845, 0.14978900738060474, 0.10681431088596582, 0.13894681845392498, 0.15788715997976915, 0.08097256254404783, 0.14367076568305492, 0.1286351896290268, 0.13816054564501556, 0.14410529950899736, 0.13165509115372384, 0.13330121710896492, 0.06838885242385523, 0.20274258591234684, 0.17533480588878902, 0.0996526519634894, 0.16131148194628103, 0.1580855364778212, 0.186425080788987, 0.1679961918187993, 0.21609061823359557, 3.2158933792795454, 23.790036167417252, 45.08253192901611, 51.20131015777588, 37.275938987731934, 25.5071861743927, 26.414096321378434, 32.00122792380196, 19.05692502430507, 7.227387632642474, 1.6753333594117845, 0.3098508449537413, 0.610985880451543, 2.137072856937136, 4.157237495694842, 5.082113512924739, 10.070536647524152, 16.85851846422468, 12.125155448913574, 14.846726621900286, 15.441532373428345, 10.846816318375723, 7.459590349878583, 8.179814560072762, 4.65862124306815, 2.1051812767982483, 2.650861744369779, 3.1723805027348653, 6.1099496739251276, 11.481881669589452, 20.387082951409475, 29.824336460658483, 37.61264521735055, 44.148353576660156, 46.08345120293753, 49.584558146340505, 50.978266034807476, 52.33609342575073, 51.689646925245015, 53.36189072472708, 56.04991946901594, 53.736516748155864, 52.46897772380284, 50.34382254736764, 49.08675793239048, 50.47978489739554, 51.21516833986555, 54.2299986566816, 53.64644030162266, 52.11512334006173, 40.57556554249355, 47.823849882398335, 52.99530724116734, 50.76825673239571, 49.303729329790386, 49.09258052280971, 51.08108895165579, 49.04542657307216, 51.47351973397391, 52.57405533109392, 51.03047827311924, 47.69788599014282, 49.03625842503139, 48.66464444569179, 49.456711292266846, 49.61209733145577, 50.404921531677246, 48.83620589120047, 48.628294944763184, 49.204745292663574, 49.463072368076865, 43.51832914352417, 28.31873651913234, 16.65938135555812, 7.538937909262521, 5.746086844376155, 5.041556009224482, 2.3497748034340993, 3.2880410850048065, 14.019996081079755, 25.16937518119812, 7.462002243314471, 12.00653406551906, 15.200146743229457, 9.58413234778813, 11.385867987360273, 13.497363005365644, 6.699703650815146, 4.083389869758061, 1.3300519670758928, 0.91619630583695, 0.9639192478997367, 3.632416388818196, 17.87474983079093, 41.984806128910606, 38.71494913101196, 43.1821996143886, 43.18063279560634, 39.05492448806763, 37.14122036525181, 21.000643627984182, 8.093082802636282, 0.8226763212255069, 0.2598076659653868, 0.05620667218629803, 0.1450401579162904, 0.22065842098423413, 0.14398336676614626, 0.06078436119215829, 0.18392329503382954, 0.2854401133954525, 0.11959285555141312, 0.13894407717244966, 0.10183767721589122, 0.13117474264332227, 0.09068492959652628, 0.08704508455204112, 0.19641361837940557, 0.11755921824702195, 0.13753883114882878, 0.11086633202752896, 0.10296155512332916, 0.130175328414355, 0.0970446483365127, 0.11777800507843494, 0.14044414167957647, 0.12143249969397273, 0.17475148290395737, 0.1150348779878446, 0.17331311080072606, 0.11378603428602219, 0.11730328840868813, 0.10293735177921397, 0.18672597035765648, 0.09134702371167285, 0.09829220960714988], [0.02819735899434558, 0.025326000659593513, 0.0204619546088257, 0.03375600438032832, 0.01065450020334018, 0.008757911705678063, 0.013369517284445465, 0.032889840858323235, 0.04562780912965536, 0.06815452714051519, 0.007516364799812436, 0.008709415111557713, 0.011649437797521906, 0.012541372079535254, 0.029768284609807388, 0.04284023120999336, 0.04986674292013049, 0.04844097799754568, 0.008788916515186429, 0.02383239410950669, 0.02373643229449434, 0.050632581646953306, 0.011063381164733852, 0.024449175656107918, 0.03278624891702618, 0.002307116178729172, 0.061212584642427306, 0.05327920748719147, 0.08736050834081002, 0.013673561192782862, 0.05212487692811659, 0.016727443751213805, 0.015980137512087822, 0.015905076271987388, 0.02761977811210922, 0.035873305052518845, 0.045180104939000945, 0.023195721308833787, 0.057902555114456584, 0.05606919759884477, 0.3871293067932129, 4.480645741735186, 23.477026769093104, 37.9354133605957, 40.442834104810444, 27.61371844155448, 18.651150226593018, 18.160001175744192, 13.962023786136083, 13.531497767993383, 5.421582520008087, 1.0072160788944788, 0.3304728812405041, 0.18297093042305537, 0.33398402854800224, 1.1293456511838096, 1.180897484932627, 4.90133832182203, 6.115342778818948, 2.2841325657708302, 4.252656238419669, 4.8041395374706815, 5.6650126576423645, 3.6127288852419173, 3.758302765233176, 2.3172274870531897, 2.6168520493166785, 2.390471488237381, 1.0437906363180705, 3.8114308629717146, 6.0975028446742465, 13.151778714997427, 19.356142248426163, 28.34073277882167, 37.78590202331543, 42.582643032073975, 43.63818209511893, 49.59388957704817, 50.790761947631836, 52.57909972327096, 52.29439728600638, 51.23479005268642, 49.29653099605015, 49.390005111694336, 48.12094095775059, 51.08104726246425, 48.533340862819124, 49.692974363054546, 51.52111142022269, 50.52756765910557, 39.684872491019114, 40.64636421203613, 49.45394243512835, 50.0842274257115, 48.70138304574149, 48.009193079812185, 47.33106974193028, 47.29763848440987, 49.467692920139854, 48.455430712018696, 47.723792348589214, 49.45703785760062, 48.64343506949288, 48.015557629721506, 48.10163191386631, 46.917537280491416, 49.406170095716206, 47.31415435246059, 49.355128628867014, 46.81907088415963, 39.19881125858852, 24.285951682499476, 13.464900153023855, 5.12847797359739, 2.890803886311395, 2.4574445230620245, 3.612384080886841, 1.5163566214697701, 1.250728726387024, 2.61602651647159, 15.368454694747925, 5.7797117829322815, 4.400216434683118, 7.732416578701564, 5.693406471184321, 1.3823241336005074, 2.875503953014101, 2.5107228755950928, 0.03141806108344879, 0.38918483363730566, 0.6703250706195831, 1.119363152555057, 15.250507286616735, 17.85149942125593, 9.272364071437291, 16.914937836783274, 20.89651792390006, 25.229775871549332, 25.918316296168737, 18.5723819732666, 8.93700839791979, 1.416347942181996, 0.09645918796637229, 0.019805550009810498, 0.061338690375643115, 0.04166567012933748, 0.07599350650395666, 0.017497445290376033, 0.033462517628712315, 0.047464189518775256, 0.06338650906192404, 0.04016315611079335, 0.04477617982774973, 0.04469141044786998, 0.04759015615231224, 0.01703270138906581, 0.04699131167892899, 0.026107657734038572, 0.032430191058665514, 0.06054313520767859, 0.03275114151516131, 0.05661514348217419, 0.04439021893111723, 0.027654880424961448, 0.020068370371258686, 0.045088234690151045, 0.06678558274039201, 0.04009643236973456, 0.05321025475859642, 0.02907496431310262, 0.007876175804995, 0.023789030632802417, 0.016935614902260046, 0.018747284742338315, 0.03352796572393604, 0.013903149453523968, 0.049789990431496074, 0.0673812414918627, 0.019970866585416452, 0.010637515623654639, 0.03546719166583248, 0.025567978121606365, 0.037391048789556534, 0.03148082896534886, 0.02021965823535408, 0.049084622745535204, 0.014453192840197256, 0.057123278001589436, 0.04812763052593384, 0.03299736151737826, 0.03736471823815789, 0.012889583528574024, 0.029375056603125164, 0.02508132262820644, 0.0656924628253494, 0.04790257063827344, 0.06114973872900009, 0.03773595831756081, 0.054171291046908925, 0.03503717349043914, 0.025936112206961428, 0.051489218537296565, 0.06058958771505526, 0.06084574146994522, 0.020733882606561695, 0.0453662813774177, 0.05654140029634748, 0.04552714506696377, 0.033693982886948755, 0.030209013460470096, 0.014886893764404314, 0.05166697435613189, 0.039437272918543646, 0.04067478847822972, 0.05071631965360471, 0.010683654308585184, 0.47974369142736706, 6.075454907757895, 29.6712190083095, 45.25484377997262, 45.25011900493077, 26.856974499566213, 17.691376447677612, 25.07877935682024, 22.851086139678955, 16.199983835220337, 4.449006250926426, 0.6665364024894578, 0.06245205777564219, 0.2611054591834545, 0.2035331470625741, 1.020622845206942, 1.4398447956357683, 3.0793393467153822, 4.731195177350726, 5.104291728564671, 7.513699446405683, 7.770595192909241, 4.7182932410921365, 5.7727132099015375, 4.759970707552774, 3.8705126983778815, 3.259155252150127, 3.513474085501262, 3.0383319471563612, 6.982389373438699, 9.30331916468484, 16.43922942025321, 24.08951916013445, 31.434046472821915, 39.35055991581508, 44.824076311928884, 46.790694441114155, 50.11905527114868, 51.36860540934971, 52.88829803466797, 54.57435485294887, 52.96618039267403, 51.56449597222464, 51.26463603973389, 48.423277923039024, 51.68468243735177, 50.92949662889753, 52.05597332545689, 52.62533303669521, 51.32289668491909, 39.817402430943076, 44.51869256155831, 50.4208676474435, 51.79286936351231, 50.82455103737967, 49.8276686668396, 49.3355381829398, 48.863804136003765, 50.61489609309605, 49.568504333496094, 48.9260322025844, 49.86891317367554, 48.190669604710166, 47.67656544276646, 48.27427380425589, 46.64237471989223, 50.12090349197388, 47.29207297733852, 48.585876192365376, 48.090504373822895, 41.51279067993164, 28.919620207377843, 16.71751172201974, 8.717220374516078, 5.1506874561309814, 4.3658415249415805, 5.326344430446625, 2.331619594778333, 2.069860543523516, 5.4652193784713745, 16.55659317970276, 9.660299369267054, 4.69356677361897, 8.514567477362496, 4.643441166196551, 4.333692210061209, 4.265850867543902, 1.7563061458723885, 0.5418047841106142, 0.24776000529527664, 0.6280134724719184, 1.748660521847861, 10.502619062151227, 23.318272590637207, 21.584309680121287, 21.782300336020334, 26.682303735188075, 31.019676753452845, 30.49874598639352, 23.84864248548235, 11.605952177728925, 2.171439298561641, 0.0799461765480893, 0.020133662403428128, 0.06509839184582233, 0.06042669859847852, 0.04785277295325484, 0.0055905399245343036, 0.01413287766211267, 0.041505410335958004, 0.08832339702972344, 0.0280929511146886, 0.0356154346040317, 0.011444318357722034, 0.024133604285972457, 0.04243209918162652, 0.034322740576629124, 0.09734197559633426, 0.033435257484338114, 0.011973486614546605, 0.012990988890773483, 0.025464837406096712, 0.0053731351841374165, 0.03213860759777682, 0.11968808115593024, 0.02898263944579022, 0.029044107933129584, 0.07556887928928648, 0.04047730764640229, 0.03318721561559609, 0.0127189557201096, 0.01708251264478479, 0.02451641678011843, 0.038651400445295234, 0.08472682216337749, 0.04254984536341258, 0.2022906273071255, 0.12346534989774227, 0.06965530410941158, 0.07464180367865733, 0.06370846714292254, 0.07268945486950022, 0.03942766486267958, 0.1103871234559587, 0.08419051486998796, 0.09842227798487459, 0.07041369591440473, 0.1334008260497025, 0.11794082634150982, 0.14270031132868358, 0.14037927373179368, 0.12420449166425637, 0.13524566777050495, 0.10981899965554476, 0.09903254559529678, 0.16579355858266354, 0.16996426906968864, 0.08173896784761123, 0.20090695869709763, 0.07847295488630023, 0.08924880344420671, 0.125458546515022, 0.17714877426624298, 0.14130996593407222, 0.16996543614992074, 0.0967394093583737, 0.14012124043490204, 0.10760741654251303, 0.15111643900828703, 0.10013559247766222, 0.13068849087825843, 0.17275972478091717, 0.1214733746434961, 0.10257652042699711, 0.23144433221646718, 0.1550793277898005, 0.5990490381206784, 7.395752038274493, 34.97143343516758, 51.76585476739066, 52.63519253049578, 37.121233872004915, 26.5359434059688, 27.69325794492449, 20.95663547515869, 18.9595217023577, 7.069931464535849, 1.851268695933478, 0.7385309221489089, 0.5809425211378506, 1.1519460784537452, 3.2764992586203983, 6.408701368740626, 11.065287658146449, 11.861605065209524, 8.516577243804932, 12.346849884305682, 11.840448669024877, 13.304744175502233, 9.41984566620418, 9.145502993038722, 7.190813618046897, 5.876693436077662, 4.4780410357884, 2.1715391789163863, 5.772652413163867, 7.66365373134613, 14.98245620727539, 23.20177388191223, 31.78788001196725, 39.370841707502095, 45.22125966208321, 46.017151491982595, 51.396658761160715, 52.60682998384748, 54.83218513216291, 55.86334644045149, 54.512314387730186, 54.15885605130877, 53.62286158970424, 50.541231291634695, 54.469284193856375, 52.54182611192976, 54.11149018151419, 53.47598361968994, 52.676829610552105, 44.48538984571184, 47.68151256016323, 52.5888306753976, 52.81468187059675, 53.815205097198486, 51.46725245884487, 50.52643510273525, 51.04405157906668, 51.59948362622942, 50.47032145091465, 49.91807515280587, 50.316689831869944, 48.36932863507952, 49.057287148066926, 49.750349112919395, 48.33842999594552, 50.088941778455464, 48.87569945199149, 51.70143801825387, 50.728506088256836, 41.808492115565706, 27.46305196625846, 15.131255354200091, 8.70935501371111, 5.7651327252388, 4.195125588348933, 6.082351863384247, 3.385856956243515, 3.9656808716910223, 7.783197488103594, 24.25975523676191, 11.837538242340088, 9.631180337497167, 17.085059268133982, 13.284293021474566, 7.157647694860186, 8.018510392733983, 7.1347963724817545, 1.7117652616330554, 0.8047146850398609, 1.1847764253616333, 2.362664146082742, 16.979067972728185, 23.367856672831945, 19.108871494020732, 27.108296053750173, 30.26984453201294, 37.1069518498012, 33.27908502306257, 25.317786966051372, 12.522401332855225, 2.0512443653174808, 0.16894550302198955, 0.10806147860629217, 0.11697787658444472, 0.13683836587837764, 0.15974151476153306, 0.16977194510400295, 0.10276632024241344, 0.10164844736989055, 0.21522062777408532, 0.10707493618662868, 0.10414302708314997, 0.1686750389635563, 0.10732995000268732, 0.0861779303689088, 0.1480305024555751, 0.23470558864729746, 0.29826434382370537, 0.10933482420763799, 0.0813531664067081, 0.1683066487312317, 0.15046457041587147, 0.0879408661276102, 0.24155594248856815, 0.11122594201671225, 0.11936676768319947, 0.12493304828447954, 0.1448756403156689, 0.1326028010142701, 0.08463410035307918, 0.07103234343230724, 0.08590424326913697, 0.08769491075405053, 0.14662335653390202, 0.061687586296881945], [0.003802665459391262, 0.05550535874707358, 0.032175882919026275, 0.014939836459234357, 0.03776030076135482, 0.0282785762434027, 0.028907576509352242, 0.05090244520189507, 0.11324993055313826, 0.061133284254797866, 0.0703817301296762, 0.008688170180123831, 0.03206290005307112, 0.017314839642494917, 0.06288872898689338, 0.04117856001747506, 0.025211124680936337, 0.055065342358180454, 0.0172931604486491, 0.045802901698542495, 0.06385826053363935, 0.02991179476625153, 0.04148853177736912, 0.0406288652281676, 0.015482703489916665, 0.016150902723893523, 0.014649267408198543, 0.027044421128396477, 0.05023347752700959, 0.07687839759247643, 0.03407633397728205, 0.022850386000105312, 0.048639666621706316, 0.026324468332209756, 0.03005651610770396, 0.11632599442132882, 0.04092148006228464, 0.04304082991023149, 0.028774230807487453, 0.07898815974060978, 0.04830693340461169, 0.8714765597667012, 7.598447493144444, 27.211139815194265, 39.02637086595808, 36.25641243798392, 25.262008564812795, 16.598575932638987, 15.294449431555611, 19.90565616743905, 18.143127475466045, 5.392531667436872, 1.1200799026659556, 0.23127505130001477, 0.14910132570990495, 0.7342766161475862, 0.562390288071973, 1.1537889795643943, 4.867724239826202, 2.16904108439173, 5.119861773082188, 5.265404386179788, 3.398519831044333, 3.7557962025914873, 4.933370385851179, 2.0535466074943542, 2.1741879624979834, 2.670921627964292, 2.9899696622576033, 2.434490714754377, 2.162556678056717, 4.332953529698508, 10.511355553354536, 13.184483885765076, 21.69871003287179, 35.19952195031302, 43.56213753564017, 45.55953271048409, 47.79934358596802, 53.57876137324742, 51.17116887228829, 51.46760334287371, 52.233774253300254, 50.24300071171352, 51.97032982962472, 52.159584862845286, 52.702402455466135, 52.723976612091064, 50.375575814928325, 47.58902856281826, 41.38077143260411, 45.0061434337071, 48.125113351004465, 50.20544222423008, 50.38518517357962, 49.34111411230904, 49.30635922295706, 49.60185916083199, 47.981435026441304, 50.55638183866228, 50.16483695166451, 52.21928378513881, 50.026275975363596, 49.19487190246582, 49.062362807137625, 47.70961454936436, 47.13332748413086, 48.71668645313808, 45.62392166682652, 37.489898341042654, 24.56144254548209, 12.748612097331456, 5.178932751928057, 1.8264770890985216, 1.3603830252374922, 3.1200764179229736, 3.802464646952493, 1.533538973757199, 1.6352183691092899, 5.311741054058075, 18.254312549318584, 7.931965368134635, 1.5939332587378365, 4.050804121153695, 3.696107268333435, 5.2158302920205255, 2.8572052206311906, 0.9211282240492957, 0.5264668528522763, 0.12388636730611324, 2.5930594631603787, 10.0095123563494, 11.566192848341805, 5.291163963930948, 14.425051740237645, 23.29360474858965, 27.99886577469962, 27.34153492110116, 22.942873580115183, 10.23649958201817, 2.4589082045214514, 0.376868228827204, 0.010547849765446569, 0.06118653568306139, 0.0520429404319397, 0.019579558832837, 0.039005687327257225, 0.035166529406394274, 0.01480206162003534, 0.012546652778317886, 0.014798728316756231, 0.05550345545634627, 0.019439655090016977, 0.023304914556709782, 0.04807224849771176, 0.03031154688713806, 0.035660319695515294, 0.05813474979783807, 0.02672201521428568, 0.013429568481764622, 0.01984586856061859, 0.0324219672142395, 0.027120288128831556, 0.05368920887953468, 0.029036013010357107, 0.02882754330390266, 0.10615159930395228, 0.03957568388432264, 0.03496527931253825, 0.0361014522745141, 0.002936990270557414, 0.0370631908465709, 0.07040395215153694, 0.021385542549458996, 0.09305577166378498, 0.03140743861773184, 0.04869812580623797, 0.008984818904926735, 0.024162582820281386, 0.060644040150301795, 0.044989287321056635, 0.03802910240899239, 0.032556337503982444, 0.02865670175690736, 0.04424753658739584, 0.04352810626317348, 0.024416012257071476, 0.07062178903392383, 0.038641934881785085, 0.03065052262640425, 0.07057917024940252, 0.020732194750702808, 0.005229492289280253, 0.030944548813360076, 0.016268693010455797, 0.05184530692973307, 0.052088911179453135, 0.013140036741138568, 0.03621151065453887, 0.07568482056792293, 0.012014770381418722, 0.04931995226070285, 0.04238122941127845, 0.02747031211453889, 0.03712165681645274, 0.03304294889260616, 0.013176960072347095, 0.008694680723627763, 0.03607241436839104, 0.045889832212456634, 0.07306053888584886, 0.062419338817042966, 0.05073144080649529, 0.04375972758446421, 0.05435106550742473, 0.04988051039565887, 0.016073885606601834, 1.403422121490751, 11.188210844993591, 32.83681828635079, 44.62495483670916, 37.31762817927769, 26.777054582323345, 16.75763062068394, 15.399011135101318, 26.69260617664882, 19.576243809291295, 5.947461272989001, 1.1317587388413293, 0.10174304193684033, 0.09331820186759744, 0.3160673656633922, 0.9388094352824348, 2.441212445497513, 3.20049986243248, 3.738371857575008, 4.742510753018515, 5.695568663733346, 7.14750679901668, 7.8240459476198465, 8.84824081829616, 4.118977674416133, 4.933108525616782, 4.572125290121351, 3.289198611463819, 3.9955615997314453, 4.128339937755039, 7.1926983169146945, 15.672170877456665, 16.67441725730896, 24.83227637835911, 36.626438753945486, 45.947186606270925, 47.13996648788452, 51.194858755384175, 54.07378578186035, 53.58101953778948, 53.7009801864624, 52.88429934637887, 50.47108575275966, 53.70172711781093, 53.887108530317036, 54.30411856515067, 53.750427041734966, 51.022282872881206, 48.498509543282644, 45.81928416660854, 47.68033831460135, 50.40988949366978, 51.97752816336495, 52.29603706087385, 51.18731995991298, 51.69197457177298, 51.21279205594744, 49.514676639011924, 51.219399792807444, 50.15698201315743, 51.28692586081368, 50.28416531426566, 49.08558716092791, 50.43743215288435, 48.67665788105556, 49.949029377528596, 48.57564149584089, 47.240350587027415, 40.235433850969585, 28.26763251849583, 15.130096742085048, 8.536184191703796, 4.784699780600412, 3.6224711281912665, 3.594573676586151, 4.511324209826333, 3.717855998447963, 3.343243871416364, 6.475911727973393, 14.718523672648839, 11.988202980586461, 4.607000035899026, 5.059726417064667, 5.053590723446437, 3.2834183616297583, 1.3665913492441177, 1.03084896504879, 0.3719192658151899, 0.18838797403233393, 1.783950856753758, 7.293849757739475, 15.797368730817523, 11.464102097920009, 11.915117485182625, 25.771629401615687, 30.950729778834752, 31.404818875449045, 26.8702038696834, 13.07665913445609, 3.897549876144954, 0.5274230444005558, 0.02131195373034903, 0.03609384250427995, 0.048554357806486745, 0.07345379742660693, 0.05734715384564229, 0.01179645343550614, 0.028151138885212795, 0.004124847456945905, 0.04345937066578439, 0.0024588830461392975, 0.02664055538895939, 0.022426969970443418, 0.0979769215253847, 0.022725199681839774, 0.020793291740119457, 0.03291850217751094, 0.032681360973843505, 0.03976145998707839, 0.008435087644362023, 0.019188049216089503, 0.030015105115515844, 0.01172044563905469, 0.03508391098252364, 0.07561096881649323, 0.05130860947870782, 0.04213033091010792, 0.04640181402542761, 0.034027075727603266, 0.03716348171500223, 0.033222048210778406, 0.08292620735509054, 0.03271667193621397, 0.025628031863431846, 0.024157802541075007, 0.07703190256974526, 0.13716520262616022, 0.1384707447141409, 0.17002870275505952, 0.1451098977455071, 0.10445080378225871, 0.10841903941971914, 0.1270439571567944, 0.21071629518909113, 0.17289144199873718, 0.17092535964080266, 0.14434075116046838, 0.09969284837799412, 0.2043226496981723, 0.20563638848917826, 0.1078317402196782, 0.09424740807818514, 0.07944995031825133, 0.10411266264106546, 0.16641994139977864, 0.08635270741901227, 0.12516810638563974, 0.1257046918783869, 0.17769555135497025, 0.07069425657391548, 0.10805926658213139, 0.10984695529831306, 0.1067731509517346, 0.12185405993035861, 0.13165176633213246, 0.06057276004659278, 0.08217807499957935, 0.16159095694976194, 0.13336997984775475, 0.1501836840595518, 0.23962149343320302, 0.2268652929259198, 0.13752341483320507, 0.12963035622877733, 0.1804197473185403, 0.1026028815124716, 1.7222875484398432, 13.805098720959254, 38.90620524542672, 50.96720102855137, 45.70942619868687, 36.3628762108939, 26.378915854862758, 23.103863341467722, 27.217757974352153, 22.053033420017787, 6.944742730685642, 1.6937142759561539, 0.5679946616292, 0.6278476385133607, 1.207636432988303, 2.5837797096797397, 6.286155555929456, 9.853797146252223, 9.471599323408944, 12.584404451506478, 12.957089321953909, 11.90614822932652, 10.71817215851375, 11.860580205917358, 7.835922156061445, 6.886635380131858, 7.275944249970572, 5.435113268239157, 4.335299849510193, 4.171918170792716, 6.070675415652139, 13.438708049910408, 15.45477737699236, 24.18018967764718, 36.37903424671718, 45.83520596367972, 49.6236070224217, 51.389401367732454, 56.94538940702166, 54.7079131262643, 56.25228575297764, 55.922367913382395, 53.46248326982771, 56.21835422515869, 56.243628297533306, 55.90432691574097, 55.49319853101458, 52.495380878448486, 49.37728296007429, 47.71320676803589, 49.50735671179635, 50.260471957070486, 52.52946179253714, 53.89905595779419, 52.98968962260655, 52.07142611912319, 52.55051483426775, 49.261657987322124, 51.115923745291575, 50.17924404144287, 53.14903613499233, 50.17493615831648, 50.24011026109968, 50.759984901973176, 49.2424635887146, 49.88911158697945, 51.52849735532488, 48.475667340414866, 41.78009830202375, 27.74757375035967, 14.76880431175232, 7.439577800886972, 4.600471334797995, 3.602937353508813, 5.862261159079416, 7.9081895010811945, 4.179214647838047, 5.633644146578653, 12.314271518162318, 29.658410004207067, 15.190087488719396, 9.115596209253583, 11.358151623180934, 11.281617215701512, 12.087268659046718, 6.932270714214869, 3.479554499898638, 1.1116123284612383, 0.2768128934715475, 3.329303179468427, 11.747042298316956, 16.16113645689828, 12.724769353866577, 21.584096023014613, 32.705021381378174, 37.203274726867676, 37.82215772356306, 30.11637966973441, 14.623937845230103, 3.768334661211286, 0.6128430579389844, 0.18596101711903298, 0.23471066408923694, 0.1652623335165637, 0.1306426761937993, 0.10069419643176453, 0.1346218226743596, 0.11189832272274153, 0.1443849237901824, 0.10371654746787888, 0.1574707973216261, 0.1303024994475501, 0.09163786417671613, 0.2371709777840546, 0.12564130313694477, 0.09933495508240801, 0.1337713333112853, 0.19620965075279984, 0.15996638126671314, 0.11387560090848378, 0.06652281326907021, 0.11733741872012615, 0.12362466992012092, 0.1091730614591922, 0.12202956979828221, 0.1637603962527854, 0.16341458766588143, 0.1242872593658311, 0.12727183635745729, 0.08241359450455223, 0.09996316315872328, 0.1818739292877061, 0.08966372760811023, 0.1907648550612586, 0.08303188239889485], [0.02845940412953496, 0.02375125658831426, 0.05818000129823174, 0.026610557355784943, 0.011031356856359966, 0.03429600968956947, 0.025959145078169446, 0.009223659838815885, 0.017772849083745053, 0.01938701095059514, 0.008808007097936102, 0.022165423558492745, 0.044297052680381706, 0.04436491975294692, 0.014439045385058438, 0.03807789246950831, 0.040797216551644463, 0.009594391865123595, 0.04824048447023545, 0.01236425238727991, 0.051676931857530556, 0.007553251659763711, 0.0453186855385346, 0.035707688225167136, 0.04749266763350793, 0.04925060598179698, 0.016746498710875, 0.06448921667678015, 0.026658701111695597, 0.015326994970174772, 0.024704343838883296, 0.042510663358760734, 0.034860530469034395, 0.01287685421162418, 0.03076438419520855, 0.037115224304475954, 0.05180361095283713, 0.06805079270686422, 0.04121461397569094, 0.049268834825072966, 0.03822498529085091, 0.13969954449151242, 0.3462052584758827, 11.37538923536028, 32.83197886603219, 38.075464725494385, 29.09911128452846, 24.827042647770472, 21.674757855279104, 12.905530214309692, 14.847881759916033, 14.131396549088613, 6.397349749292646, 1.590845218726567, 0.10953990463167429, 0.291886141789811, 0.6673628581421716, 1.7818510894264494, 1.8127022853919437, 4.841174738747733, 3.8697718467031206, 4.354231519358499, 3.4135733204228536, 4.712075906140464, 4.288165441581181, 3.4992146449429646, 4.460528535502298, 2.836989002568381, 2.6699912207467213, 4.208207743508475, 2.3175295165606906, 4.41825395822525, 5.640654010432107, 7.502405149596078, 11.54046366895948, 17.333625861576625, 29.150086743491038, 43.78803389413016, 44.45547090257917, 45.58824961526053, 52.02010325023106, 52.75222103936331, 53.5949958392552, 54.811159883226665, 54.75922557285854, 55.10787922995431, 52.298423767089844, 52.02252122334072, 49.572200775146484, 44.8349780355181, 41.687676838466096, 42.75684131894793, 52.07483421053205, 49.0995773587908, 53.036791460854666, 53.5628638948713, 52.913412298474995, 49.91181829997471, 51.2273520060948, 49.54309824534825, 51.21873276574271, 52.05697386605399, 49.19674096788679, 49.441387040274485, 48.66180263246809, 48.75599936076573, 46.73760672977993, 47.040284156799316, 36.36796576636178, 24.941423892974854, 13.147179007530212, 4.616582904543195, 1.7380495369434357, 1.8879247861249107, 2.677383018391473, 2.8637462982109616, 4.632726175444467, 3.5523407885006497, 2.0957573481968472, 3.17022590977805, 9.668242028781346, 11.21778324672154, 3.378863594361714, 4.239326553685324, 2.032038675887244, 2.4662986993789673, 1.2868089846202304, 0.7591607751590865, 0.501146422965186, 1.653701771582876, 8.114722967147827, 6.5490875499589105, 9.507812465940203, 19.480146748679026, 24.7845961025783, 24.77454900741577, 28.7373046875, 18.63807371684483, 11.830694266727992, 3.1081719824246, 0.43923553079366684, 0.04356267762237361, 0.036576901762081046, 0.012444530713504978, 0.060576396994292736, 0.016740848210507205, 0.07947956158646516, 0.023001772251778414, 0.09328048210591078, 0.04318386848483767, 0.05008423714233296, 0.047253015850271494, 0.03381196316331625, 0.027457503069724356, 0.029662287261869227, 0.026633347650723796, 0.07405069789716176, 0.03919619621176805, 0.007888721069321036, 0.01869151764549315, 0.045624297710933855, 0.02858895342797041, 0.037573713809251785, 0.03180506692401, 0.06380060541310481, 0.08627053004290376, 0.023533149988257458, 0.05366887997037598, 0.03190509655645915, 0.05767903210861342, 0.040653092321008444, 0.04758630207340632, 0.03628680768555828, 0.02454105269030801, 0.04838770960590669, 0.021362153447366188, 0.036315139915261946, 0.02924884230430637, 0.04989201495690005, 0.04380747948640159, 0.015387888399085827, 0.007375791003661496, 0.01739264216407069, 0.03352220156895263, 0.059050962062818665, 0.022279425923313414, 0.04491979854979685, 0.014108860066958835, 0.11224829751466002, 0.022593911637419035, 0.026160900680614368, 0.04053540042202387, 0.04431905417836138, 0.07142581231892109, 0.04567105895174401, 0.026891662539648156, 0.029646002421421663, 0.04209968148331557, 0.034250961749681404, 0.02269721350499562, 0.008318269359213966, 0.03244420959215079, 0.0589484286361507, 0.010831082156593246, 0.05195744501959, 0.006291011980335627, 0.07508853756423507, 0.06158113772315638, 0.0656839268548148, 0.06447546277195215, 0.04926775934706841, 0.03410978575370141, 0.056956677298460684, 0.022269368337999498, 0.03468940393733127, 0.018943013257480094, 0.020854152938617126, 0.1329912758831467, 0.89582907302039, 15.845366886683873, 38.411868708474294, 43.856074128832134, 34.05688721793038, 23.40165271077837, 15.300075735364642, 19.296658720288956, 24.159067153930664, 15.4567836693355, 6.452532342502049, 1.137265294790268, 0.15180504348661217, 0.07178950030356646, 0.26985638961195946, 0.5725651106664112, 1.1423771062067576, 3.3319393694400787, 5.2227120484624585, 7.6538784844534735, 5.795611866882869, 9.246959720339094, 7.420325211116245, 6.144995953355517, 8.132995860917227, 5.440608424799783, 4.577748988355909, 3.37864950299263, 3.2609224830354964, 4.920837138380323, 6.864653016839709, 9.639228957039968, 14.869806800569807, 20.68895959854126, 34.25986494336809, 44.09066268375942, 46.19610234669277, 48.73466491699219, 54.79851763589041, 53.191392353602815, 55.129856382097515, 56.86846937452044, 55.62887600490025, 55.296918869018555, 53.827937671116416, 52.74497406823294, 50.48587499346052, 46.54028831209455, 44.43384116036551, 45.961704867226736, 52.437797682625906, 51.258014406476704, 53.52605928693499, 52.00864219665527, 53.448229040418354, 50.24889625821795, 50.91878598076956, 50.168804373059956, 51.07087509972708, 52.01805353164673, 49.89765439714704, 50.886820793151855, 49.290343625204905, 49.5230770111084, 48.42622743334089, 48.780043601989746, 39.81813199179513, 29.98368297304426, 16.660993337631226, 7.551325678825378, 3.6990363683019365, 2.755578262465341, 3.2313201172011237, 4.0848941547530035, 4.147526953901563, 4.930928094046457, 4.408245512417384, 6.438862630299159, 9.057240894862584, 11.828569855008807, 4.692317834922245, 4.53492854322706, 3.605914439473833, 2.3333612041813985, 0.5120481465544019, 0.1798123363405466, 0.13247542642056942, 1.180215475814683, 6.744553404194968, 10.839511156082153, 10.682714632579259, 16.167719875063213, 23.811599901744298, 27.50343315941947, 31.85449239185878, 24.631872960499354, 15.836672953196935, 4.8752530472619195, 0.7223717463868005, 0.06070032463009868, 0.031774040910282304, 0.016663149165521775, 0.03170901011409504, 0.013003487505816987, 0.056310674641281366, 0.027470451214217713, 0.10190122202038765, 0.09346072814826455, 0.03833111156044262, 0.02335201167235417, 0.017860168058957373, 0.032392668072134256, 0.06995698077870266, 0.00472236709070525, 0.026296059767316495, 0.04911726027993219, 0.03697257928018059, 0.02437183623468237, 0.0009532116133154237, 0.039250305986830165, 0.02805742641378726, 0.0028120866045355797, 0.02293509940084602, 0.011745279172568448, 0.046329570401992114, 0.007051774841134569, 0.06423961078482014, 0.11112254006522042, 0.041609986153032096, 0.08675478691501276, 0.03705404419451952, 0.03492721689066716, 0.04880499507167509, 0.029662568853901963, 0.05751996314419167, 0.08273114889327969, 0.13775065621095045, 0.20406529493629932, 0.16215563379228115, 0.13196970070047037, 0.10496354555445057, 0.20415321950401577, 0.13673772556441172, 0.09691652056894132, 0.12597535949732575, 0.09901548722492796, 0.1847990123288972, 0.14005061851016112, 0.1496099555598838, 0.11918232829443046, 0.12888172854270252, 0.1527885664254427, 0.13345481029578618, 0.0996778459687318, 0.14226087847990648, 0.14970064855047635, 0.10552647177662168, 0.06343349082661526, 0.10054670327476092, 0.10776595624962024, 0.14786343356328352, 0.1081616235896945, 0.14165643948529447, 0.11706457978912763, 0.10305638039218527, 0.11882357325937067, 0.1303518967969077, 0.12947064265608788, 0.2231076338461467, 0.13259498429085526, 0.13008554466068745, 0.19319574747766766, 0.12887749448418617, 0.22379826035882744, 0.17840608608509811, 0.23068301592554363, 1.6251895129680634, 18.712169306618826, 44.1504727772304, 52.090297426496235, 42.43148497172764, 33.87090131214687, 30.478860242026194, 18.88635196004595, 21.461561066763743, 18.87965910775321, 8.621384739875793, 2.1632139342171803, 0.4487314112484455, 0.6738292425870895, 1.7439433463982172, 4.294789680412837, 6.059881823403495, 11.309620193072728, 11.009432826723371, 10.956749847957067, 10.323880127498082, 13.606674671173096, 12.269336649349757, 8.57454432759966, 10.324549760137286, 9.097516127995082, 6.905322125979832, 8.67831654208047, 5.303291176046644, 7.0414981331144055, 9.054835081100464, 8.88614411013467, 13.588769163404192, 20.649073464529856, 31.594973700387136, 45.58234364645821, 47.263220582689556, 50.88083144596645, 56.376602922167095, 54.71373224258423, 55.951935972486226, 58.00626816068377, 57.24457883834839, 57.873119831085205, 56.19633885792324, 54.05786745888846, 52.78684391294207, 48.38576112474714, 48.79107386725289, 47.56780529022217, 53.399299825940815, 52.58185120991298, 55.38610247203282, 54.22245291301182, 54.392555236816406, 51.89388574872698, 50.83453559875488, 50.5964104107448, 51.5019656590053, 52.59631041118077, 49.49192476272583, 51.177595955984934, 48.40076575960432, 49.98181445258004, 48.17048508780343, 49.63542243412563, 38.45674017497471, 28.278784377234324, 15.507543734141759, 6.7387299452509195, 4.103384179728372, 4.666672902447837, 5.551716634205409, 6.211108062948499, 9.103468128613063, 7.227186134883335, 6.998468807765415, 10.023493000439235, 18.042750324521744, 18.285782677786692, 7.874878968511309, 12.956356287002563, 8.059292844363622, 6.458890812737601, 3.470810626234327, 1.1375058761664798, 0.9655284072671617, 2.368274165051324, 10.474740283829824, 10.504642724990845, 16.43211099079677, 28.56908358846392, 34.70567526136126, 34.75493451527187, 38.88251883643014, 27.924099683761597, 16.513670682907104, 4.4899415629250665, 0.7068917570369584, 0.0972101158861603, 0.15208816900849342, 0.08039647274251495, 0.1357070987245866, 0.14038509556225368, 0.17007568451975072, 0.09177881625613996, 0.19268609982516083, 0.16284958512655326, 0.10053147694894246, 0.14437775846038545, 0.1140298590596233, 0.06490235629358462, 0.19168292651219027, 0.1051311097773058, 0.1349239336060626, 0.15856098596538815, 0.2098721976258925, 0.17621843490217412, 0.09068383036979608, 0.22413535655609199, 0.11519654574138777, 0.11209596640297345, 0.10509233828634024, 0.13840302691927978, 0.17546927795878478, 0.1550007127225399, 0.2724660352936813, 0.17185869812965393, 0.09759886216904436, 0.1531993650964328, 0.11736453297947134, 0.07244839851877519, 0.07477428085569825, 0.10504866098718983], [0.04159418307244778, 0.024119592537837367, 0.011909399830204035, 0.031403041710811, 0.04782922100275755, 0.054021219456834454, 0.03151403307648642, 0.045280266885778735, 0.021924448631969944, 0.025366909535867826, 0.05434685180495892, 0.024718090958361114, 0.06372143394712891, 0.029666168482175896, 0.029922074571784054, 0.025153649372181723, 0.023891306216163293, 0.038639766962400506, 0.04461507525827203, 0.05121714295819402, 0.05303174915856548, 0.013822356288853501, 0.02833871480210551, 0.02483250044419297, 0.06501484382897615, 0.037929734348186424, 0.012986255260849637, 0.07625231333076954, 0.04886353228773389, 0.05475789474855576, 0.06066189240664244, 0.027413710419620787, 0.017901540035381913, 0.06425715091505221, 0.04066258502591934, 0.01954297561730657, 0.06085900004420962, 0.02214365785143205, 0.043466980436018536, 0.020267881719129424, 0.027374835452064872, 0.027954964233296256, 0.12408942569579397, 2.0487692867006575, 14.384522029331752, 34.28492709568569, 38.2761287008013, 28.246999842779978, 25.188298600060598, 19.962252719061716, 26.12862263407026, 31.507791178567068, 13.368537323815481, 7.450740950448172, 1.7464998492172785, 0.3616758297596659, 0.24643813765474729, 0.3573886826634407, 0.9027832970023155, 0.8709816091826984, 2.259537462677274, 6.0723225729806085, 5.659494919436319, 7.967050296919687, 7.349769728524344, 4.222457196031298, 5.660384288855961, 4.092730854238782, 3.011778537716184, 2.5433257775647298, 1.3300737887620926, 1.7524168917110987, 2.9157553017139435, 2.62520769238472, 5.160106173583439, 8.195259537015643, 17.56328466960362, 27.342314856392996, 42.05899551936558, 46.27427305494036, 46.24281855991909, 48.543815272195, 50.042079653058735, 50.03304699489048, 51.22600752966744, 49.060896737234934, 51.76398570196969, 50.318541526794434, 48.16285943984985, 49.53395094190325, 42.35375199999128, 42.493761675698416, 52.092722347804475, 45.14322444370815, 55.69553354808262, 53.39943878991263, 50.857673100062776, 53.29176255634853, 49.425003187997, 53.28216361999512, 51.326322146824424, 51.71667194366455, 49.886936800820486, 48.69611978530884, 49.193999903542654, 48.59079899106707, 41.89029325757708, 35.483314173562185, 22.522511039461406, 13.607906239373342, 4.385078481265476, 1.8175616817814964, 1.1588710440056664, 1.8934837792600905, 2.5733454695769717, 2.843382865190506, 2.9606085291930606, 4.063848495483398, 3.4570325655596594, 4.6634871533938815, 6.613599402563913, 11.31781906741006, 2.731095850467682, 1.9431594908237457, 2.3325424024036954, 1.1162096474851881, 0.35545971617102623, 0.31503395682999064, 1.9342948922089167, 7.319642339433942, 9.881276403154645, 15.137154374803815, 20.26964102472578, 20.19941210746765, 24.915620020457677, 27.988625867026194, 21.72427245548793, 10.219204647200447, 2.9041672263826643, 0.20799200423061848, 0.011143799438806517, 0.04123407436002578, 0.01854639087936708, 0.02303618924426181, 0.04163477642993842, 0.013802572752216032, 0.04688200308009982, 0.00889299445719059, 0.03514873482553022, 0.01762774945901973, 0.02400323735283954, 0.030903507622757127, 0.033900963209037266, 0.021722681155162196, 0.10244769376835652, 0.015104503337559956, 0.032542773588959656, 0.025010000116058757, 0.031173123512417078, 0.023676984145173004, 0.02245814526187522, 0.08958735170641116, 0.03445509561736669, 0.04306619354922857, 0.06774032222373144, 0.013444855027565998, 0.04644395105008568, 0.05961280941431012, 0.05586914851197174, 0.02294854966125318, 0.035343209747225046, 0.039904617305312834, 0.06621627150369541, 0.02082398527168802, 0.01806032910410847, 0.0035666718280741145, 0.02321642341225275, 0.008130221012314516, 0.024571227142587304, 0.03211574096764837, 0.034885863573955636, 0.025431879263903414, 0.03322886748771582, 0.02720873516851238, 0.021033499922071184, 0.03462194059310215, 0.03406798799655267, 0.02770208101719618, 0.060049399201359065, 0.021202450052702, 0.0076855600512187395, 0.05029886455408164, 0.0176084349597139, 0.02617720587711249, 0.04110266248296414, 0.04711941909044981, 0.057662835477718284, 0.03653371300814407, 0.049075638941888294, 0.03927473324750151, 0.03763904655352235, 0.04082848683797887, 0.02522821188904345, 0.030687947225357805, 0.04908901286710586, 0.014723882511524218, 0.017619873363790766, 0.04881396530462163, 0.0037468093048248973, 0.027331090299412608, 0.0199758385507656, 0.013549075461924076, 0.06365590782037803, 0.07199769520333835, 0.05003067698063595, 0.029384328784154992, 0.06382521587823119, 0.026302690750786235, 0.15682316278772696, 3.7275322335106984, 18.910422257014684, 41.07653066090175, 41.944510051182334, 31.433438505445206, 22.60264461381095, 15.466516358511788, 25.31386297089713, 34.48519154957363, 16.754338911601476, 7.095950296946934, 1.6132046303578784, 0.23606241441198758, 0.10975198753710304, 0.2807091772556305, 0.3996889628469944, 1.927005580493382, 3.9249809299196516, 5.842342410768781, 5.102116508143289, 7.646793058940342, 8.560723492077418, 7.471290247780936, 8.542449729783193, 4.4887716599873135, 4.364902649606977, 3.8542191726820807, 2.941929817199707, 2.1278717049530576, 4.4875288009643555, 5.805726272719247, 9.246125936508179, 11.010147622653417, 20.981770583561488, 33.215272767203196, 42.49545703615461, 49.03036982672555, 49.007465090070454, 50.5805025100708, 53.33980587550572, 52.424693380083355, 52.91981853757586, 51.21708951677595, 53.24431678227016, 51.51592458997454, 49.877539362226216, 51.04589979989188, 44.978086607796804, 43.12435933521816, 54.55062675476074, 47.465552125658306, 55.07125874928066, 56.589586053575786, 52.64162656239101, 53.370853900909424, 49.37218645640782, 52.60956409999302, 53.06110668182373, 53.129188605717246, 49.96437447411673, 50.244633538382395, 50.407666070120676, 51.37532431738717, 44.205874238695415, 39.91859252112252, 26.233653341020855, 17.066332135881694, 6.71410379239491, 2.9362220891884396, 2.797231627362115, 1.6068477886063712, 3.2221117998872484, 5.197500944137573, 4.806496713842664, 7.312701957566397, 5.5360740678650995, 6.65544102021626, 7.289252655846732, 10.632935132299151, 6.244802917752947, 2.55227375456265, 2.4688788694994788, 1.0192903109959193, 0.2809055181486266, 0.1392445731908083, 1.3598132729530334, 5.937414177826472, 12.535196440560476, 14.766891820090157, 20.463610410690308, 21.835384573255265, 28.089220149176462, 32.91776132583618, 26.824778284345353, 14.08374754020146, 4.624300181865692, 0.5691110960074833, 0.04123967566660472, 0.08878828172705003, 0.013394107393521284, 0.029181172006896565, 0.017538556030818393, 0.01659420831128955, 0.07510341105184384, 0.013168691274976092, 0.026193368581256697, 0.008169418284004288, 0.059985976533166, 0.03161983025659408, 0.036260175186076334, 0.049296858321343145, 0.06238108301269157, 0.019960001543430344, 0.03756256887157049, 0.012476349765035723, 0.045527189171739986, 0.015615692960896661, 0.02503370643327279, 0.06210869870015553, 0.04636825029073017, 0.06670363606618983, 0.04768171088237848, 0.07486312823104006, 0.025940073155132786, 0.033554516799215756, 0.052085918840020895, 0.017444355014179434, 0.03015478154910462, 0.10285307772989784, 0.04084781151530998, 0.016418942715972662, 0.05963558104953595, 0.07587135662989956, 0.16153751553169318, 0.08740649265902382, 0.09724091459065676, 0.10476947775376694, 0.11389806041760103, 0.15704560013754026, 0.11357101332396269, 0.14731987273054464, 0.16590676536517485, 0.11410262515502316, 0.0901436282853995, 0.10147584841719695, 0.17217405406492098, 0.13970565130668028, 0.14881093986332417, 0.17249605964337075, 0.07691951002925634, 0.09456251974084548, 0.13397893788559095, 0.12315322378916399, 0.18797207277800354, 0.13050690133656773, 0.13633734919130802, 0.15180888399481773, 0.1345794956598963, 0.15143828173833235, 0.06273038605494158, 0.16504935494491033, 0.09148528200707265, 0.16673883928784303, 0.08742609553571258, 0.11253123983208622, 0.13513251527079514, 0.14824601874819823, 0.12553142117602484, 0.13212577732545988, 0.145202314215047, 0.09873843459146363, 0.1898982437061412, 0.21315945551863738, 0.1993588131985494, 0.1294653500829424, 0.2920658178627491, 5.181124908583505, 23.22718518120902, 47.49493258340018, 52.294678688049316, 41.2884646143232, 34.12677567345755, 28.187802927834646, 32.56437941959926, 37.92210061209542, 17.355893101011002, 9.907779438155037, 2.207998548235212, 0.8683140437517847, 0.5278224029711315, 1.576895950095994, 2.9783516228199005, 4.800542541912623, 9.382160374096461, 15.239424909864153, 13.100387232644216, 16.645469324929373, 16.375233037131174, 10.041060652051653, 11.17018895489829, 10.79262297494071, 8.124153409685407, 6.00281366280147, 4.282351536410196, 4.524002935205187, 6.053250202110835, 5.1098198890686035, 8.009433439799718, 10.704062104225159, 20.734178474971227, 31.633636951446533, 44.32073490960257, 49.58214364733015, 50.40106528145926, 52.524028301239014, 55.08481815883091, 54.75734608513968, 55.99965272630964, 52.0306784084865, 55.87038843972342, 53.18860960006714, 50.372556822640554, 51.639456612723215, 49.159366607666016, 46.48725618634905, 54.84743642807007, 50.41334622246878, 53.00711917877197, 56.34069463184902, 52.32129028865269, 56.409085750579834, 50.23070240020752, 53.90564979825701, 52.29237536021641, 53.018962383270264, 49.79690899167742, 48.188567774636404, 49.99286903653826, 50.1823742049081, 44.573340143476216, 38.12167024612427, 25.625135319573538, 15.374694177082606, 5.868724720818656, 2.996164849826268, 3.0631131316934312, 4.0285338418824335, 6.680878375257764, 8.083564639091492, 7.114877624171121, 11.646530526024954, 7.017280186925616, 12.229411431721278, 15.820490598678589, 18.622992651803152, 9.35455778666905, 6.795809830938067, 6.631523149354117, 3.632922521659306, 0.8442908099719456, 0.5585819152849061, 2.49611211674554, 9.292217680386134, 14.737617322376796, 23.061317784445627, 31.123062474387034, 27.696362052645, 33.55645016261509, 40.53540842873709, 31.041202272687638, 16.343174048832484, 4.4641494154930115, 0.6228836934481348, 0.12431368151945726, 0.1446899524224656, 0.09035204710172755, 0.1702982032937663, 0.11750265556786742, 0.07291406353137322, 0.12786581234208175, 0.14202283482466424, 0.14712450892797538, 0.11071220279804297, 0.15588971573327268, 0.08445289757634912, 0.08495333750865289, 0.06736228322344166, 0.2040126949016537, 0.06679955377642598, 0.08181966601737908, 0.1657239816018513, 0.16016962964619907, 0.07944923107113157, 0.06952187698334455, 0.14226841021861347, 0.13983985196266854, 0.2006137501448393, 0.1634905564465693, 0.16758639737963676, 0.10754353247050728, 0.11846293189695903, 0.13377141473548754, 0.10413615352341107, 0.07130279392004013, 0.14434604373361382, 0.1516739505210093, 0.10261601795043264, 0.1162749957293272, 0.137843859781112], [0.03680412617645093, 0.021089864129732763, 0.01729974732734263, 0.022297337551468184, 0.04754452467230814, 0.08424488588103227, 0.09119953734001943, 0.02207805878216667, 0.06840000075421163, 0.020492936517777186, 0.02609537455386349, 0.013155336857640317, 0.04026779638869422, 0.008015314499581499, 0.011225095567559558, 0.01604995028381901, 0.027876052306964993, 0.06455774871366364, 0.012653966484192227, 0.03446734995980348, 0.04773706237652472, 0.03511103881256921, 0.056395864712872674, 0.02568843505079193, 0.05893325659313372, 0.057505469636193345, 0.025195542124233077, 0.030267068916665654, 0.024462167905377488, 0.06226959292377744, 0.018111748487821648, 0.014528483085866486, 0.05661441744970424, 0.05628673931849854, 0.014604188934234636, 0.049622633161821535, 0.026513099371056472, 0.007661466120875308, 0.07748719278190817, 0.050845007212566476, 0.03040549684582012, 0.03930738435259887, 0.04619187868333288, 0.5491484329104424, 4.562656198229108, 16.581135954175675, 32.92733941759382, 34.252062116350444, 29.04596103940691, 22.521946498325892, 30.59318937574114, 19.548560449055262, 12.500586594854083, 16.305005856922694, 6.176753563540323, 2.843047831739698, 0.33077005243727137, 0.29037355152623995, 0.04693730029144457, 1.8483982213905878, 2.2688684591225217, 4.79099007163729, 3.645900453839983, 8.256660767963954, 5.219536287443979, 7.240079385893686, 9.779568672180176, 3.408066873039518, 3.7838916778564453, 2.8323128649166653, 1.841771159853254, 1.2730742416211536, 1.4189822865383965, 2.9633608843599046, 2.9432977437973022, 1.947444575173514, 6.077046479497637, 16.66390984398978, 25.25410325186593, 37.38604014260428, 47.262275627681184, 49.305737359183176, 51.057270526885986, 49.33817502430507, 49.111705439431326, 53.1645827293396, 48.395995821271626, 51.367149761744905, 49.889594486781526, 48.97196674346924, 43.870310987745015, 40.57749714170183, 45.523923192705425, 52.51311615535191, 53.14355748040335, 45.84099381310599, 52.656909125191824, 50.116109234946116, 53.24118314470564, 49.882573332105366, 50.3538487979344, 49.15282487869263, 50.18828364780971, 49.76084089279175, 48.24319451195853, 41.495840549468994, 31.649367673056467, 21.605060475213186, 12.119632499558584, 5.782019453389304, 1.8587768759046281, 0.8489711273993764, 3.275794016463416, 0.2728397995233536, 1.8401263909680503, 5.234814941883087, 3.024500472205026, 4.603785191263471, 4.601341596671513, 5.952100498335702, 5.726096877029963, 9.41385110786983, 4.576655949865069, 1.964419024331229, 0.865383043885231, 1.1499584593943186, 0.23551071115902492, 1.7292664710964476, 3.7613334826060703, 9.480480858257838, 13.761851395879473, 18.260824748447963, 11.236403550420489, 19.222394636699132, 21.167179788861954, 22.461446796144756, 11.03169572353363, 4.660783435617175, 0.36145780288747376, 0.0706008223018476, 0.024786577194130847, 0.061372142152062485, 0.06238379715276616, 0.06795757556600229, 0.01602198785570051, 0.04939544267420258, 0.008180170519543546, 0.04990882905466216, 0.0389388278791947, 0.0017258471406031667, 0.035505572999162335, 0.0687861278919237, 0.06848525189395462, 0.049269398009138446, 0.043546036551041264, 0.06143413989671639, 0.025990905606054833, 0.02242331436303045, 0.02058737671801022, 0.009420725067944398, 0.0558681680288698, 0.06044974843306201, 0.009747686496536647, 0.027769695335466946, 0.0512988317890891, 0.09913136065006256, 0.024228697576160942, 0.021328995137342384, 0.0364617068719651, 0.04541190267939653, 0.009243547700212469, 0.0006201101849520845, 0.032742575010550876, 0.03245709836483002, 0.022471978894567916, 0.017949943330937197, 0.07279591022857598, 0.07231336326471396, 0.016828190934445177, 0.07033595615731818, 0.03283466239060674, 0.05026160619620766, 0.01613413103457008, 0.05019816656463912, 0.025721740942182283, 0.017177449871918986, 0.05472884327173233, 0.025729471152382236, 0.02108659528728042, 0.009935990990405636, 0.01463808854376631, 0.018834664785702313, 0.04964807822502085, 0.03212771371805242, 0.07303084619343281, 0.09943264376904283, 0.013587766376856183, 0.05178827266874058, 0.027530971448868513, 0.0028984719579706764, 0.07526567591620342, 0.02862726690779839, 0.027036960635866438, 0.04720670583524874, 0.025190453111593212, 0.028643287119588683, 0.021554105915129185, 0.019790148961224725, 0.029373227951249907, 0.05241486583171146, 0.008597807975352874, 0.056922445206769874, 0.04125244230298059, 0.04065987088584474, 0.01498999716048794, 0.010734640278055199, 0.024932619982532093, 0.05852382856288126, 0.09176386812967913, 0.616600187761443, 6.46651646069118, 21.224010842187063, 40.09088700158255, 39.063668795994346, 32.01262296949114, 18.670382840292795, 27.104269572666713, 25.526726245880127, 22.311466455459595, 19.808749641690934, 6.337358568395887, 3.406042124543871, 0.19731520142938408, 0.1298072910202401, 0.11820966191589832, 0.8088614568114281, 1.200930118560791, 3.9492036529949734, 2.9742230900696347, 3.8028003317969183, 6.460287834916796, 8.739223582404, 8.665588310786656, 3.6815633858953203, 6.420228430203029, 5.687824462141309, 5.137532779148646, 3.7469494087355475, 3.400212151663644, 4.601898321083613, 4.847154097897666, 5.1111591543470105, 9.011576465197972, 19.605881350381033, 30.307983194078716, 40.66166067123413, 48.62683234895979, 50.09984697614397, 51.40521199362618, 51.805865968976704, 51.6755907194955, 52.41079003470284, 49.05866289138794, 52.72178098133632, 50.884093625204905, 51.80519546781267, 44.039068835122244, 40.38978113446917, 51.171123708997456, 53.28131941386631, 54.50332689285278, 50.05465589250837, 52.74906655720302, 51.30100291115897, 52.31635011945452, 51.66448402404785, 49.542222772325786, 52.00487974711827, 49.88444587162563, 50.57017053876604, 47.72110686983381, 44.32740865434919, 34.14614030293056, 26.267734255109513, 13.996479034423828, 8.843996337481908, 2.908911326101848, 2.2992283957345143, 3.4611411222389767, 2.756510406732559, 4.488174983433314, 8.077252200671605, 5.34284987619945, 8.814411776406423, 8.70710813999176, 7.395348174231393, 6.356418779918125, 8.522609148706708, 4.5720254097666055, 1.0761972516775131, 0.2702777327171394, 0.27455842015998705, 0.17847592090921743, 0.8279396902237619, 5.696412001337324, 11.79488411971501, 17.937210662024363, 19.54436547415597, 14.61385600907462, 20.02722532408578, 26.26040390559605, 27.39494572366987, 15.081721646445137, 6.072582261902945, 0.7816292409385953, 0.07533696959061281, 0.027104956630085195, 0.028790064422147613, 0.056364787809018574, 0.014673053453277265, 0.014074057157683586, 0.023823781803782498, 0.007055509752327842, 0.06563180179468223, 0.06177406558500869, 0.0367261760735086, 0.03298572464180844, 0.03265016871903624, 0.036110690528792996, 0.035508399097515006, 0.016899845928751996, 0.04415743052959442, 0.04518701921084097, 0.055762852608625374, 0.03225055230515344, 0.028537211740123372, 0.01776425713407142, 0.037927641067653894, 0.02755109510118408, 0.02404426666907966, 0.014921833228852068, 0.0240406076689916, 0.02379788042578314, 0.01783775265461632, 0.03581620293802448, 0.03492964604603393, 0.012301280944874244, 0.020629776674988012, 0.010359958329770182, 0.016642526789967502, 0.018878857771466886, 0.038826068929795704, 0.1317695735820702, 0.16362122872046062, 0.06950904588614192, 0.11089677789381572, 0.10150030960461923, 0.1328113012548004, 0.11909430873181139, 0.15856018529406615, 0.17363512994987623, 0.11305099087102072, 0.15642178218279565, 0.12442801467009953, 0.14853122058723653, 0.05661622913820403, 0.16764157584735326, 0.07872213330119848, 0.10354633695845093, 0.13453266317290918, 0.11951223202049732, 0.18225445172616414, 0.11811823610748563, 0.1282443263168846, 0.0771814923999565, 0.12229839180197034, 0.1397762189486197, 0.13386539183557034, 0.12828545910971506, 0.1654644419572183, 0.10627005116215774, 0.11218075613890376, 0.15572521170335157, 0.08758991424526487, 0.12843811591821058, 0.10230686382523604, 0.06193191997174706, 0.16837208664843015, 0.14648688957095146, 0.13861990028194018, 0.18179582990705967, 0.16443175237093652, 0.11976067083222525, 0.13441458450896399, 0.14545714482665062, 0.9673089917216982, 8.030427421842303, 26.335852657045635, 46.435200282505576, 47.7084333556039, 40.004368032727925, 30.608027253832134, 37.82988064629691, 27.421272448131017, 17.601904494421824, 21.06174087524414, 8.468548689569745, 3.4972407051495145, 0.733216255903244, 0.44554976054600304, 0.7439181645001683, 4.3037654502051215, 5.743924651827131, 10.695354274341039, 7.938060675348554, 16.700542484010967, 9.614381330353872, 14.13137309891837, 19.187611954552786, 7.651627268110003, 9.532783423151288, 7.296186089515686, 6.6920719231878, 4.434570499828883, 3.211766149316515, 6.049829517092023, 4.722875578062875, 3.1743451058864594, 8.660326787403651, 19.928720712661743, 28.37963226863316, 41.233174324035645, 49.01752608163016, 51.22263070515224, 53.47880111421858, 50.93515593664986, 50.80415112631661, 54.786997522626606, 50.0943717956543, 52.625096797943115, 54.100345270974294, 55.17113562992641, 48.383544649396626, 41.93792315891811, 51.52891424724034, 54.7280524798802, 55.646555696214946, 50.41720942088536, 54.02562434332711, 51.97827162061419, 52.782021863119944, 50.41194616045271, 49.93959024974278, 50.36379861831665, 50.125385080065044, 51.034244196755544, 48.17590815680367, 43.09892545427595, 33.168504442487446, 24.466217483792985, 14.445840750421796, 8.836142267499651, 3.8189331804003035, 2.4309529960155487, 7.195237014974866, 4.578019533838544, 6.808119867529188, 10.176675592150007, 9.090465443474905, 13.008574604988098, 11.71529597895486, 11.345427734511238, 13.81911758014134, 16.050618410110474, 9.923175777707781, 6.233935500894274, 3.809992151600974, 2.1515168590205054, 0.4835461473890713, 2.178791795458112, 5.859172250543322, 14.27646017074585, 22.055017130715505, 27.034214360373362, 18.644049167633057, 27.43847792489188, 33.7300682749067, 33.97109086172921, 17.520207575389318, 6.18382465839386, 1.1711520935807909, 0.170656700485519, 0.09824323973485402, 0.20493805381868566, 0.19929014545466217, 0.2102417413677488, 0.12978770849960192, 0.13909894600510597, 0.08782391383179597, 0.19104897124426706, 0.21635486691125802, 0.10838185570069722, 0.10550157632678747, 0.16567898115941457, 0.1382550112903118, 0.14177212970597403, 0.21875494026712008, 0.15037557376282557, 0.12156798956649643, 0.1192251302834068, 0.08185666653194598, 0.09670829852776867, 0.16919884085655212, 0.14180229737290315, 0.08235715396170105, 0.08992583211511374, 0.09883392482463803, 0.12508681789040565, 0.13227209661688122, 0.1336750899042402, 0.14798000587948731, 0.17981583758124284, 0.1303031915532691, 0.09910263147737298, 0.19470822917563574, 0.16698433325759002, 0.05651328180517469, 0.2008144608033555], [0.07874166153903518, 0.02536582387983799, 0.04833242596526231, 0.02846633197207536, 0.016156558313273957, 0.04649348410644701, 0.04698374601347106, 0.04472404458959188, 0.032899269102407355, 0.06901632768235036, 0.02129537711984345, 0.069921771596585, 0.018509392061137726, 0.03134088451042771, 0.040171576730374775, 0.06529270391911268, 0.011037804635374673, 0.05435020376795104, 0.058429023650075705, 0.05214954846139465, 0.007811480883641967, 0.038510831738156934, 0.028358105636600937, 0.035778591741940806, 0.034835088798510175, 0.07167026134473936, 0.02435276091897062, 0.031849348119327, 0.02361930357957525, 0.04782380290063364, 0.05329636763781309, 0.024116014961951544, 0.021961562801152468, 0.010838421360988702, 0.046149962182555876, 0.03497987460078938, 0.01853227904731674, 0.07947210448661021, 0.06099588769887175, 0.006471997201775334, 0.03989407965647323, 0.031625071939613135, 0.06869826439235892, 0.05674428565959845, 0.9219937090362821, 7.801208087376185, 20.20619354929243, 31.085507461002894, 31.46834625516619, 27.16355334009443, 30.648747171674454, 23.386116538728984, 18.47355600765773, 12.352270347731453, 11.54534912109375, 6.566388130187988, 3.513002476521901, 0.887259664280074, 0.23200284796101706, 0.27331819385290146, 0.7795487982886178, 2.2847724514348164, 3.197360796587808, 1.927005580493382, 9.293248619352068, 7.459058812686375, 6.991316505840846, 2.3418833868844167, 3.6976606249809265, 5.4522488287517, 3.81966187272753, 2.5884649668421065, 5.227797695568629, 3.2059978416987827, 4.8534634964806695, 2.927032445158277, 3.5361354180744717, 5.718101671763828, 15.59888127871922, 24.366714068821498, 34.03093222209385, 43.13969053540911, 50.05024031230381, 52.386568614414756, 51.178513118198936, 52.328113419669016, 56.32795858383179, 54.979695388248985, 50.86150850568499, 51.23465803691319, 40.560331617082866, 40.26763180324009, 41.063301290784565, 50.503182956150596, 50.066287176949636, 48.504109791346956, 51.70941802433559, 49.82423973083496, 49.0047413962228, 51.55143683297293, 55.00601169041225, 53.31316648210798, 52.507394313812256, 49.68797860826765, 41.40661873136248, 28.312868765422277, 16.80708963530404, 8.878853712763105, 2.738382556608745, 3.4714533346039906, 1.2831333875656128, 2.639314489705222, 2.7017859603677477, 2.2455561671938216, 2.900128803082875, 4.148730729307447, 4.132260458809989, 8.02064870085035, 7.466123393603733, 6.146072489874704, 3.7690620507512773, 6.992251038551331, 3.704643998827253, 0.6473633913057191, 0.5995528368013245, 0.07861189850206886, 2.006829308612006, 2.4554623322827474, 5.925255264554705, 12.337866732052394, 17.93817298752921, 13.994192208562579, 20.973649876458303, 26.218014683042252, 26.379511662891932, 16.040253434862407, 5.665618887969425, 0.7159441198621477, 0.018486318477828587, 0.003352288476889953, 0.06749276550752775, 0.014117790435973023, 0.03746058166559253, 0.03187236063448446, 0.06715720958475556, 0.029429200304938213, 0.015526733627276761, 0.05219920365405934, 0.07190204212175948, 0.03334006580657192, 0.046712053806654046, 0.025054337290514792, 0.05547757952341011, 0.007851287140510976, 0.027094252740166018, 0.056136301319514, 0.05539333600816982, 0.054110748759870014, 0.02970134713021772, 0.03516825627801674, 0.025014374970591495, 0.010074799747339316, 0.02683768847158977, 0.02871242305263877, 0.03493079277021544, 0.032575998056147776, 0.028535746104483093, 0.02601807245186397, 0.017126539389469793, 0.07594663330486842, 0.006274697878065386, 0.03048014926857182, 0.09431725647300482, 0.014344572954412018, 0.03307574588273253, 0.00788065413611808, 0.05211890581995249, 0.03938663045742682, 0.020677864451759627, 0.04102592695770519, 0.05861150885799101, 0.036614950613251755, 0.03923075400026781, 0.06507905359779086, 0.034352026148033996, 0.06004409984286342, 0.05111520664234247, 0.03931287370089974, 0.07660916168242693, 0.09135654355798449, 0.04614720733038016, 0.0338626938339855, 0.01902914310007223, 0.036043960002384016, 0.070979648402759, 0.06070117958422218, 0.018014141225389073, 0.024571848002129366, 0.06408954598009586, 0.0775492312386632, 0.03057764796540141, 0.030684714005993943, 0.05180051683315209, 0.011068052030168474, 0.036546778199928145, 0.01539028193136411, 0.038998240405427556, 0.024800633047042147, 0.025206420736919557, 0.03187814853819353, 0.052642358267413716, 0.023744120096255626, 0.040820602261062176, 0.04661187828917589, 0.03431594504841736, 0.03872635481613023, 0.010354440143731023, 0.05174583708867431, 0.09373141612325396, 0.06443016377410718, 1.345542541572026, 9.544901081493922, 25.243378707340785, 36.843441418239046, 36.35081761223929, 25.905243260519846, 28.547683136803762, 18.704347372055054, 13.09864410332271, 21.618159566606792, 15.40789440699986, 7.146864090647016, 4.212295455592019, 1.3358857397522246, 0.177757325183068, 0.23244224009769304, 0.08450216600405318, 1.4857694570507323, 1.9211517231804984, 3.5103235117026736, 3.8097728490829468, 8.961325355938502, 7.31649306842259, 4.309761311326708, 6.089010408946446, 4.907793632575443, 5.402865810053689, 4.755740557398115, 5.088637871401651, 4.448728322982788, 3.288166803973062, 4.279139297349112, 4.287746378353663, 8.547679117747716, 17.760809796197073, 27.78239812169756, 36.95735713413784, 45.9714149747576, 50.58489377158028, 53.01598160607474, 53.21625995635986, 54.17714023590088, 54.27196230207171, 53.872152532849995, 52.29427916663033, 52.920357022966655, 37.99849258150373, 40.79894665309361, 46.11374882289341, 55.358935015542166, 53.07461397988455, 49.82980523790632, 54.162594182150706, 50.58915996551514, 51.01969466890608, 51.52363361631121, 55.448896816798616, 52.62927961349487, 53.17255578722273, 51.38988079343523, 43.63418688092913, 32.44670125416347, 21.120533057621547, 12.733218363353185, 5.394957891532353, 4.512381204536982, 2.9420047274657657, 3.5482189868177687, 4.620992839336395, 4.131295093468257, 3.8580671719142368, 12.065570303371974, 7.845155443464007, 7.111190302031381, 6.915400922298431, 6.792103835514613, 5.3245900103024075, 6.825298854282924, 3.2435257136821747, 0.49137806998831884, 0.42475306934544016, 0.1631166972219944, 0.6329450107046536, 4.549285692828042, 8.433937106813703, 15.998731000082833, 20.27906104496547, 13.810335057122366, 19.399559804371425, 29.181006227220806, 29.560398714882986, 20.807640041623795, 8.104449187006269, 1.1615969091653824, 0.06855673555816923, 0.04443154510642801, 0.05730749347380229, 0.03134379203298262, 0.042488309022571356, 0.027485933687005724, 0.03425079890127693, 0.07455092069825955, 0.06575167179107666, 0.11740072603736605, 0.023994538533900465, 0.01854464704436915, 0.059408332886440415, 0.06907088868319988, 0.11663258368415491, 0.031649590802512, 0.05691948340141347, 0.02607891329431108, 0.03535435129223125, 0.022205214548323835, 0.028485663434756652, 0.02608375803434423, 0.017936625384858677, 0.034786953524287255, 0.011839243550119656, 0.019733749130474668, 0.03904529002362064, 0.08460792925740991, 0.06489702300833804, 0.013416777248494327, 0.019643168098160198, 0.06625114141830377, 0.03848818563190954, 0.016412946162745357, 0.12076606974005699, 0.02761851603697453, 0.015806145866268446, 0.046213361102023294, 0.14024596874203, 0.06257318306182112, 0.09188563123877559, 0.18598838922168526, 0.19845352534736904, 0.15376678322042736, 0.20350429575358117, 0.1248771505696433, 0.1272117452962058, 0.21144528607172625, 0.11082947400531598, 0.2638850100338459, 0.12744190437453135, 0.13320371162678513, 0.11438226300690855, 0.20137176875557217, 0.08711255807429552, 0.20449214774583066, 0.20295062474906445, 0.2199495690209525, 0.04501529556832143, 0.11147498472460679, 0.1243783323360341, 0.16836203075945377, 0.16422128437885217, 0.19270618446171284, 0.17712022151265824, 0.06499550558094468, 0.15364597684570722, 0.13288060682160513, 0.11687111588461058, 0.09826176374086312, 0.2023387761520488, 0.06927900894411973, 0.09727208648941346, 0.09558374208531209, 0.11440616101026535, 0.11216091577495847, 0.133386617526412, 0.17500806413590908, 0.18629235933933938, 0.12272654739873749, 0.2801367108310972, 0.20659838829721722, 2.0620366547788893, 12.27039885520935, 29.982230799538748, 43.50309521811349, 43.627210889543804, 35.94906234741211, 38.92180395126343, 31.45561020714896, 24.384338174547466, 19.264254059110367, 16.84940937587193, 9.442264897482735, 4.7089487825121195, 1.6270402308021272, 0.484439913715635, 0.8626560387866837, 2.084775503192629, 4.354832972799029, 9.137756620134626, 7.032571869237082, 17.88248143877302, 13.78110659122467, 14.160504290035792, 9.673170038631984, 10.092599783624921, 11.111743313925606, 8.997248411178589, 6.618794049535479, 11.400559084756033, 8.045465060642787, 8.547469803265162, 4.513957142829895, 5.372854803289686, 6.977734080382755, 17.770929847444805, 26.876181057521276, 37.66227272578648, 45.84561089106968, 51.40395784378052, 53.904506819588796, 52.80223764692034, 53.61230032784598, 56.19631801332746, 55.64729915346418, 54.90713882446289, 55.89691318784441, 40.03083372116089, 41.73626906531197, 49.94763626371111, 56.211461612156455, 54.90337984902518, 51.98206533704485, 57.77619246074131, 55.18553924560547, 55.1307943889073, 51.53734936032976, 53.65897485188076, 52.813709122794016, 53.43866484505789, 51.72315461294991, 44.81390414919172, 31.820550441741943, 19.334476028169902, 11.378041710172381, 4.051278335707528, 7.3311112097331455, 3.2619351829801286, 5.488127589225769, 6.1969159330640515, 7.683116504124232, 9.66138676234654, 10.510439259665352, 11.307103208133153, 16.097056695393153, 16.040595633643015, 14.529140097754341, 10.794782996177673, 13.748570782797676, 8.741774439811707, 2.9799940032618384, 1.5593115793807166, 0.36723593569227625, 2.3322279964174544, 3.9248211213520596, 10.362030080386571, 20.09101152420044, 27.601609468460083, 21.63409004892622, 29.704382760184153, 37.25246449879238, 37.45356273651123, 23.52156819616045, 8.248785853385925, 1.1642529666423798, 0.2302170523575374, 0.11216935675059046, 0.14834055224699633, 0.08013210192854915, 0.10653615902577128, 0.1169855711715562, 0.12990732065268926, 0.11647079379430839, 0.14494685935122625, 0.21907959213214262, 0.08628123054014784, 0.15970906721694128, 0.1481134601469551, 0.10455837872411523, 0.18619037552603654, 0.09670297202787229, 0.12536565507096903, 0.17870479077100754, 0.08567482379398175, 0.18554325667875154, 0.09742263983935118, 0.15069363026746682, 0.1432755190346922, 0.15427423241947377, 0.12229680403002671, 0.12182767848883357, 0.16281761255647453, 0.13063262030482292, 0.15474145806261472, 0.17382543188120636, 0.1420773890401636, 0.19324595906904765, 0.10211625655314752, 0.14259304851293564, 0.21626226045191288, 0.12228753524167196, 0.08154528002653803, 0.14907541924289294], [0.0563513697790248, 0.023397614314619983, 0.006002995917307479, 0.06144016528768199, 0.012719561312613743, 0.05949722097388335, 0.03882756849218692, 0.028067936921226125, 0.019864355247201662, 0.022883503598027995, 0.03294056474364229, 0.010632387595251203, 0.025837744985307966, 0.024423808624435748, 0.06433719090585198, 0.02066893153823912, 0.028490894939750433, 0.06793978437781334, 0.04662001731672457, 0.033414548595568964, 0.03868784795382193, 0.018973540547969084, 0.026920783566311002, 0.02178704189801855, 0.04944649225633059, 0.012303156246032034, 0.052028301038912365, 0.06809725878494126, 0.017565609222011905, 0.034580699234668694, 0.05668099191305893, 0.04428366179178868, 0.06784774110253368, 0.03260891718257751, 0.06960464468491928, 0.06616304721683264, 0.03346182891566839, 0.034179783426225185, 0.03297586552798748, 0.01746956428645977, 0.11415259247379643, 0.050438283144363334, 0.056139629533780475, 0.02875751509730305, 0.11487937133227076, 1.18678260913917, 7.5043202468327115, 19.668835503714426, 36.32298312868391, 34.97507776532854, 26.470164809908184, 26.885234560285294, 34.49529423032488, 24.97170761653355, 17.041468007223948, 15.06604824747358, 6.780080412115369, 3.1362064438206807, 1.8111856239182609, 0.41697445245725767, 0.28837160180721966, 1.9207780403750283, 0.9184388369321823, 1.8782680928707123, 2.221423987831388, 9.36088412148612, 4.307623437472752, 3.82667521068028, 7.094913278307233, 3.0352423872266496, 4.585959153515952, 4.710557724748339, 2.5502420578684126, 3.444626122713089, 2.610816236053194, 4.768134406634739, 0.784994937479496, 3.3695273867675235, 6.346535835947309, 14.86061085973467, 21.39335581234523, 31.004859719957622, 37.15795857565743, 43.6450469153268, 49.13632638113839, 55.59426702771868, 53.14950166429792, 55.003433908735005, 51.664897441864014, 44.308158670152935, 40.292294434138704, 29.046694074358257, 36.840217454092844, 43.76497629710606, 46.47255032403128, 54.42700787952968, 49.051884923662456, 48.35236113412039, 50.549385002681184, 42.452489376068115, 47.162110396793906, 55.20156526565552, 47.46214403424944, 37.17048270361764, 22.1509040083204, 13.816209759031024, 4.805908722536905, 2.972783293042864, 1.094466779913221, 2.731662562915257, 2.241972416639328, 3.069513508251735, 3.15126753279141, 2.1938018585954393, 2.2671772241592407, 17.381038631711686, 5.16544108731406, 5.431021213531494, 5.8366318600518365, 5.3842576657022745, 4.3041645373616895, 5.753139700208392, 2.5364153598036085, 0.3136347090559346, 0.21652811047221932, 1.528441058737891, 3.5454781396048407, 5.327304584639413, 12.993253827095032, 12.366471597126552, 14.942222663334437, 24.052299397332327, 29.32609851019723, 23.81679889133998, 19.68650303568159, 6.161464486803327, 0.9431868003947395, 0.07814487641943352, 0.05939776809620006, 0.07375864963978529, 0.07747290283441544, 0.10693082891936813, 0.013343949236774018, 0.03588275704532862, 0.08911042301250355, 0.020179612794891, 0.01804097558903907, 0.018696369170876484, 0.03618922756452646, 0.02816407515534333, 0.02910169180748718, 0.018285940301471522, 0.0283731606323272, 0.05182469982121672, 0.018071134774280444, 0.040226127553199015, 0.05597237404435873, 0.07289761584252119, 0.039763794147542546, 0.022788383166438768, 0.023523448633828332, 0.02974011862118329, 0.03243747513209071, 0.040450678539595435, 0.047141705573137314, 0.06022526869284255, 0.05286562342994979, 0.033794741944542954, 0.026761103920372467, 0.018133953546306918, 0.028418602122526084, 0.017630716353388767, 0.021016561991668174, 0.06533372814634017, 0.03489854200077908, 0.015305809410555022, 0.037141860196633, 0.05615677272102662, 0.11164718334163938, 0.012888042405912918, 0.07326491363346577, 0.10070442873984575, 0.04932146200111934, 0.03200242901220918, 0.01996691751160792, 0.008373079721682837, 0.05479465099051595, 0.016701237032456056, 0.06023353324936969, 0.06359464289354426, 0.0748233525082469, 0.08911442636911358, 0.037241635378450155, 0.05805942562541791, 0.049144744340862544, 0.047956578633082766, 0.029870081825980117, 0.005309759589311267, 0.02056012335898621, 0.04766003508120775, 0.05376176802175386, 0.028262503445148468, 0.017961295221799185, 0.012110220750660768, 0.0507930857129395, 0.011186270641961267, 0.05109790739204202, 0.023168245729591166, 0.07347939176751034, 0.018358894690339054, 0.047360380446272235, 0.05072603966774685, 0.04306990513578057, 0.008468374876039369, 0.061176459438034465, 0.04423173011413642, 0.03919837430917791, 0.052679379138031175, 0.06995655330164091, 0.02506467986053654, 0.12523597345820495, 2.3211710240159715, 10.604012387139456, 25.95733216830662, 41.48421621322632, 38.32081951413836, 31.211478301456996, 32.505854742867605, 24.96725903238569, 18.800923858370098, 19.553815024239675, 17.772887502397808, 7.559028625488281, 3.101738601922989, 0.9931286062513078, 0.25451357290148735, 0.16144576402647154, 0.49752185174397057, 0.12981951822127613, 1.5104426188128335, 1.9914572877543313, 7.306384307997567, 6.26047067131315, 2.977585801056453, 6.085959281240191, 5.090223797730037, 3.661734095641545, 6.010765876088824, 4.808481727327619, 6.7571830579212735, 4.278466624873025, 5.570862829685211, 2.6976506965500966, 4.971015725816999, 9.164568849972316, 17.138305050986155, 24.726571696145193, 31.887739522116526, 40.245157854897634, 48.2364547593253, 53.042054721287315, 55.895474910736084, 56.21478632518223, 56.11523600987026, 56.029008865356445, 47.57219655173165, 38.094283921378, 31.979556492396764, 42.02220480782645, 46.56902606146676, 49.78476701463972, 56.88503735406058, 51.33485800879342, 51.1311993598938, 52.36090196881975, 47.363448347364155, 51.025496414729524, 55.79944038391113, 49.76130294799805, 40.62000969478062, 27.12410146849496, 16.30417033604213, 7.762670772416251, 4.955374028001513, 2.0191176320825304, 5.130173334053584, 3.6958419339997426, 4.644731794084821, 5.308197038514273, 4.94217939887728, 3.514344564505986, 12.209696786744253, 11.318688460758754, 7.889430233410426, 7.59413092476981, 4.568491816520691, 4.675975237573896, 2.358433995928083, 0.5630851622138704, 0.21740435702460154, 0.22526756008820875, 1.0226214293922697, 4.959279349872044, 8.193334886005946, 13.711101753371102, 17.226415157318115, 15.723690032958984, 25.12141350337437, 30.913605553763254, 29.974153518676758, 24.825972625187465, 8.588189721107483, 1.3985947519540787, 0.14880164393356868, 0.11897926990474973, 0.040692701802722046, 0.03685456507706216, 0.06642781836645943, 0.02583289854893727, 0.036074453366122076, 0.058914786869926114, 0.027983515290543437, 0.02002165323522474, 0.07481557649693318, 0.016344324219971895, 0.013820669281163385, 0.02732951270549425, 0.05436622737241643, 0.04223723749497107, 0.06525387814534561, 0.030604063333677392, 0.06859363429248333, 0.04880491704014795, 0.04787493729963899, 0.06924787775746413, 0.051342291957033534, 0.04694562591612339, 0.03186469318877373, 0.044092711859515736, 0.01660778749335025, 0.018237657445882047, 0.028591905055301528, 0.030168484563806226, 0.06159393489360809, 0.030211412081761018, 0.05311365851334163, 0.033066622979406796, 0.04691288999414869, 0.022169927334679023, 0.022357309869091426, 0.010095729159989526, 0.0796601197549275, 0.1141468384968383, 0.14231412990817002, 0.11479812354913779, 0.12094822925116334, 0.2015688560370888, 0.17249239555427007, 0.14527414393212112, 0.12414711474307946, 0.06943115006600108, 0.0826948947672333, 0.1924177799373865, 0.22848776515041078, 0.09910193937165396, 0.13381953643901007, 0.22127335013023444, 0.11118936219385692, 0.13180298464638845, 0.17959364450403623, 0.12287013897938387, 0.14939878189138003, 0.12677641079894134, 0.10762583198291914, 0.12695677897759847, 0.1424384918063879, 0.14599446313721792, 0.13872685097157955, 0.097493512822049, 0.21833838761917182, 0.13344585363354, 0.12256190766181264, 0.12677559655691895, 0.1201484671660832, 0.1991445454103606, 0.14623999781906605, 0.11238081540380206, 0.1581279042043856, 0.1329153206731592, 0.1193117249224867, 0.11476836300321988, 0.11422747559845448, 0.20771738753787108, 0.08159842288919858, 0.1794291811862162, 0.15239709243178368, 0.19976334220596723, 2.172817213194711, 11.529903275626046, 30.513535227094376, 51.95894520623343, 45.45529930932181, 36.03928123201643, 36.26745659964425, 42.88851663044521, 32.736114570072715, 25.253715889794485, 21.168869938169205, 10.426322630473546, 4.315083631447383, 2.308743302311216, 0.6036632390958923, 0.7398138418793678, 3.8479623198509216, 3.080290815659932, 3.8719097205570767, 7.772184593336923, 15.337140900748116, 11.229393686567034, 8.03364964893886, 16.638944966452463, 7.045518100261688, 10.158507789884295, 12.421526517186846, 9.190280658858162, 9.625329954283577, 6.818596013954707, 10.44079485961369, 2.20914934362684, 5.111658556120736, 7.70941196169172, 17.144535848072596, 23.959216117858887, 33.43255683353969, 40.63007068634033, 49.21462563105992, 54.18189975193569, 58.882272720336914, 56.913358211517334, 60.7787835257394, 58.47814464569092, 51.34517955780029, 38.5025565964835, 35.01349435533796, 45.62027038846697, 52.86455604008266, 52.29752050127302, 54.98079667772566, 51.21943800789969, 54.383018834250315, 58.28872285570417, 55.53804220472063, 55.81773151670183, 61.51857212611607, 53.5254339490618, 43.72964470727103, 26.330502544130596, 16.70136410849435, 6.588095605373383, 4.874050574643271, 2.1941023681844984, 5.831425053732736, 5.792404404708317, 8.728809969765798, 8.307843804359436, 7.333110553877694, 7.439633386475699, 30.727814197540283, 15.212719508579799, 11.54808063166482, 14.95783179146903, 12.473247170448303, 10.636177335466657, 9.51571604183742, 4.691700313772474, 0.7585253406848226, 0.546923326594489, 1.7906001742397035, 5.8149552174976895, 9.049836720739092, 20.998791933059692, 21.998257296425955, 23.38314618383135, 34.77303804670061, 39.82504197529384, 38.67071689878191, 29.26941510609218, 9.746932983398438, 1.5007514016968864, 0.2041507496365479, 0.197915270658476, 0.102472453511187, 0.28924170083233286, 0.2573956639638969, 0.09631599672138691, 0.18376924044319562, 0.2151855339429208, 0.08979812503925391, 0.11843446056757655, 0.10386851217065539, 0.10851239905293499, 0.09423278564853327, 0.14765715891761438, 0.18402635093246186, 0.17906224301883153, 0.11707057803869247, 0.21549584157764912, 0.15239802881010941, 0.12953556488667214, 0.14926217922142573, 0.21195622294076852, 0.1199505113597427, 0.24024444286312374, 0.1334190515003034, 0.07125775955085244, 0.08888031143162932, 0.14664779736527375, 0.15989027677902154, 0.11266396128173385, 0.11137832741120032, 0.1010383561785732, 0.11628787432398115, 0.14373927057853766, 0.15270103540803703, 0.11926695518195629, 0.12540168528045925, 0.09521702104913336, 0.14603119902312756], [0.02609896400411214, 0.009892892142358636, 0.027890528851587857, 0.023441917562325085, 0.04687135347298213, 0.04584372236526438, 0.0419571891293994, 0.013203333032184413, 0.03253912307055933, 0.014688094878303153, 0.04335728846490383, 0.02345750181536589, 0.02324564113015575, 0.07302534327443157, 0.01764622257490243, 0.06321663103465523, 0.051074094205562554, 0.06176394862788064, 0.03255798973675285, 0.026043810981458852, 0.06417071233902659, 0.10731285770556756, 0.04940337474857058, 0.018048632856724516, 0.07036020699888468, 0.019940985599532723, 0.017090568551793694, 0.01953278571766402, 0.009206156179841076, 0.06257177170898233, 0.0537700291856059, 0.08538253126399857, 0.026356573216617107, 0.06014496407338551, 0.06635195136602436, 0.0384765080442386, 0.039676073140331676, 0.03221270701448832, 0.07029862316059214, 0.032655261124351194, 0.03550244156005127, 0.03187900349231703, 0.04879390102412019, 0.09621788055769034, 0.023736096419660107, 0.04413971058758242, 1.1645310031516212, 7.622590746198382, 20.84249915395464, 33.80316679818289, 30.828222615378245, 22.298900638307842, 17.574921165193828, 31.96582337788173, 41.00987311771938, 24.60805627277919, 21.29243322781154, 9.775473577635628, 3.478306212595531, 1.849512755870819, 0.20920526555606297, 0.05928918892251594, 0.4936651129807745, 2.1779295674392154, 0.8990543399538312, 6.506337889603206, 6.705706460135324, 1.9885323132787431, 3.9765291810035706, 4.337556711265019, 2.969370859009879, 2.882367253303528, 3.321121024233954, 5.012959395136152, 3.42995109302657, 3.8922431894711087, 1.9745890157563346, 2.0535783086504256, 3.1345067407403673, 5.262755385466984, 10.321826934814453, 18.273871728352137, 26.616719688688004, 31.92151471546718, 41.64695692062378, 58.04618556158883, 60.84142848423549, 55.878858293805806, 53.15715510504586, 44.70465414864676, 35.086266313280376, 29.502415997641428, 41.361681256975444, 44.61537674495152, 44.1313339642116, 56.251010758536204, 49.35978044782366, 43.66058656147548, 40.537760393960134, 44.747816358293804, 54.75835009983608, 52.401034763881135, 43.387501512254985, 27.13282319477626, 12.469715748514448, 3.901744851044246, 2.5090943915503363, 1.056705491883414, 1.3591255098581314, 3.3554596730640958, 4.318314543792179, 3.075198871748788, 5.041968558515821, 3.8681355459349493, 1.79779166834695, 9.209464635167803, 7.682570202010019, 5.566853719098227, 4.603560243334089, 3.4141682599272047, 2.9683651072638373, 2.680212672267641, 0.87449397785323, 0.29488333953278406, 0.8642128152506692, 5.619015148707798, 5.059875803334372, 13.917816741125923, 18.10831700052534, 16.795004980904714, 18.653773171561106, 23.811019727161952, 28.960201161248342, 23.385025671550206, 8.560923252786909, 1.8526561643396104, 0.06810751144907304, 0.07309608055012566, 0.08302745156522308, 0.08459438569843769, 0.019039212559748973, 0.0565175938952182, 0.04875242557110531, 0.0325999333789306, 0.059241046862942834, 0.027990008870671903, 0.07411005614059311, 0.020290692370118837, 0.07822820730507374, 0.043933035606252294, 0.017829177668318152, 0.04597608079867704, 0.06776907175247159, 0.08866039823208537, 0.07498994642602545, 0.022635465121961067, 0.11542211792298726, 0.025582106917032173, 0.03432620789057442, 0.04582214495167136, 0.00959012218351875, 0.13614620587655477, 0.02677732260365571, 0.04742536713768329, 0.01941978419199586, 0.05531150468492082, 0.045889309740492275, 0.029811639604823928, 0.006867701437191239, 0.03240827437756317, 0.028213916945138147, 0.03089067991822958, 0.015264847947816764, 0.00789653864090464, 0.0574456499889493, 0.03111317494351949, 0.040400334633886814, 0.012840321886220148, 0.03503745508247188, 0.10370461882225104, 0.030525943596980402, 0.05244266541142549, 0.04465065424197486, 0.021613498085311482, 0.007029141457418778, 0.025640834122896194, 0.002050250386154013, 0.006424740630401564, 0.024484517152554224, 0.0161205416744841, 0.04724730258541448, 0.06505628196256501, 0.09320615537996803, 0.05259459279477596, 0.03457140330491321, 0.053029228400971205, 0.046244434613202295, 0.06816477301929678, 0.049192879615085464, 0.029620974657258818, 0.059462792107037137, 0.033016818509038, 0.033199843152293136, 0.036884800597493134, 0.02503373018199844, 0.04388663398900202, 0.04201131586783698, 0.04578152106010488, 0.03906265712742295, 0.07147225804094758, 0.06305013889712946, 0.05762520392558404, 0.028879033933792795, 0.012189807819335588, 0.026773527896563922, 0.017454728118277023, 0.16581589595547744, 0.06805373076349497, 0.042621915960418325, 0.09789808254156794, 0.05850741480078016, 0.08770789791430746, 2.020622785602297, 10.262796776635305, 26.73067535672869, 37.78337287902832, 32.36208956582205, 25.688146795545304, 24.898312057767594, 32.83186422075544, 33.96151624407087, 24.567886999675206, 17.980695962905884, 9.170235105923243, 7.489248735564096, 2.087034753390721, 0.22107156738638878, 0.22838536064539636, 0.02213342554335083, 0.466517795409475, 0.9821798737559999, 5.375943711825779, 6.096383316176278, 2.525789175714765, 5.033912556512015, 4.61308057819094, 4.942609318665095, 5.259795452867236, 6.138059479849679, 8.111933265413557, 5.861805183546884, 5.184840892042432, 4.178481178624289, 3.721041747501918, 5.649624569075448, 7.219600439071655, 12.376193864004952, 21.388481651033672, 30.296094826289586, 38.369807788303916, 48.16197007043021, 60.434062549046104, 59.358710697719026, 56.21474116189139, 55.432672773088726, 44.18454326902117, 35.69399050303868, 31.567038467952184, 44.91872814723423, 48.996917724609375, 46.25844505855015, 58.431209564208984, 51.575029441288535, 50.493295669555664, 45.134368964603965, 50.137881415230886, 55.60719762529646, 53.81257520403181, 46.11595835004534, 30.622000081198557, 16.880473034722463, 6.904772784028735, 3.376132300921849, 2.5450654327869415, 2.0414728096553256, 4.38551013810294, 6.354165392262595, 4.1004937291145325, 5.396309316158295, 4.7568166596548895, 4.3734919258526395, 8.139146753719874, 10.990077751023428, 6.685422497136252, 5.562441612992968, 3.1187221705913544, 2.2596290920461928, 1.2817486332995551, 0.12143655733338424, 0.3426005547600133, 0.6649458621229444, 4.897026964596339, 8.343311752591815, 12.617585573877607, 14.450816529137747, 14.568991490772792, 18.094008922576904, 27.12878108024597, 34.01078244618007, 28.622675044195994, 10.775746669088091, 2.443200715950557, 0.16177277719335897, 0.03859083780220576, 0.043697753588535955, 0.06084105957831655, 0.06086195845689092, 0.027641677829836096, 0.03252233950687306, 0.09084530134818383, 0.03862988409985389, 0.06993488767849547, 0.05221102712675929, 0.023130103579855392, 0.034721274727157185, 0.03892210199098502, 0.039684001822024584, 0.0403215702889221, 0.07220382057130337, 0.12156808456139905, 0.02020871007282819, 0.05581289795892579, 0.06627238634973764, 0.00780478204667036, 0.013895649945230355, 0.029686500784009695, 0.006489209090692124, 0.05557063042319246, 0.02773956668430141, 0.02382011092933161, 0.03517972691250699, 0.08530739029603344, 0.02352847488197897, 0.035065641427146535, 0.02158195129595697, 0.10698111514960017, 0.05664984376302787, 0.03226043516770005, 0.040262585239751, 0.024336133418338637, 0.008789853741680937, 0.03458419708268983, 0.10675017575600318, 0.12163280323147774, 0.13432945550552436, 0.18345066825194017, 0.11174527914928538, 0.1388128213584423, 0.09310390015265771, 0.1164932804448264, 0.09506064586873565, 0.10635656437703542, 0.13513047966573918, 0.07003418449312449, 0.08192186017653771, 0.20401729536908014, 0.09679920864956719, 0.1483114023825952, 0.2615626017962183, 0.07433508549417768, 0.1788179161293166, 0.09477048393871103, 0.17044129275849887, 0.218925076137696, 0.12947497170950684, 0.17843792294817312, 0.17159240027623518, 0.0984175078836935, 0.10323591397276946, 0.17951730931443827, 0.1500390339642763, 0.11035937815904617, 0.12240812448518616, 0.20549376042825834, 0.1886198158775057, 0.13738245596843107, 0.1306819769420794, 0.14599451742001943, 0.08969424132789884, 0.19228786762271607, 0.16944744251668453, 0.13666388738368238, 0.4151202605238983, 0.20202019039009297, 0.12326495136533465, 0.217062239668199, 0.11618966316538197, 0.2798208120678152, 1.9921694781099046, 12.622273870876857, 31.336681365966797, 46.735244342258994, 42.6338095664978, 32.49765586853027, 27.057723590305873, 40.891857964651926, 51.8383001599993, 34.042966502053396, 28.333458014896937, 13.069306203297206, 5.728234316621508, 2.736871757677623, 0.6835252908723695, 0.5582876482180187, 0.7005931064486504, 4.591356601033892, 3.854634327547891, 12.987287061555044, 13.60951214177268, 8.740375246320452, 8.334834081786019, 9.34953771318708, 8.363746404647827, 8.110312598092214, 8.890498893601553, 13.840798565319606, 10.661380188805715, 7.7526688405445645, 4.35267208303724, 3.813436721052442, 5.102198583739145, 6.352567740849086, 11.83841632093702, 21.547869852610997, 29.951245307922363, 37.975177901131765, 51.21296576091221, 63.97704628535679, 62.285146032060894, 58.561877386910574, 60.046637943812776, 48.822670800345286, 37.75938074929373, 36.38665989467076, 48.90310314723423, 52.61031450544085, 50.210469245910645, 58.628197942461284, 55.15257699148995, 56.561056750161306, 50.39847012928554, 52.944651399339946, 58.84314046587263, 57.05827678952898, 50.99710260118757, 32.25416667120797, 15.559220961162023, 5.868577940123422, 4.141633578709193, 2.6829172585691725, 3.9866018976484026, 7.428399886403765, 10.848364898136683, 8.584929278918676, 12.05269181728363, 9.721696257591248, 6.907511677060809, 20.080564907618932, 18.083362545285905, 12.429279838289533, 11.382792540958949, 7.951497622898646, 6.947871157101222, 4.8773422837257385, 2.170138031244278, 0.6252093857952526, 1.3210240857941764, 7.2980212824685236, 9.406320997646876, 20.19631494794573, 26.73145181792123, 24.47183162825448, 26.646197421210154, 33.03155197416033, 40.646315574645996, 33.29795980453491, 12.767256719725472, 2.6330263699804033, 0.26539203631026403, 0.15881882927247457, 0.13016608676740102, 0.21366471983492374, 0.16536586438970907, 0.16107565031519958, 0.11913173672344003, 0.1282272543758154, 0.16356602311134338, 0.13309202476271562, 0.1582616027444601, 0.056615269011152644, 0.17196646306131566, 0.09113335303430047, 0.1592276601919106, 0.06933027226477861, 0.20379141106137208, 0.18861704745462962, 0.14505826123058796, 0.11796639354101249, 0.1763598687414612, 0.11334525115255799, 0.14662255586258002, 0.11284323701901094, 0.09906909827675138, 0.218198636546731, 0.13016201555728912, 0.13653773415301526, 0.16618590110114642, 0.19072499791426317, 0.13043258818132536, 0.16379869276923792, 0.07889489510229655, 0.2052259562270982, 0.16945878762219632, 0.12072039076260158, 0.13757168581443174, 0.1296278049371072, 0.1220638629581247, 0.19014822957771166], [0.01838658400811255, 0.0060072778973595375, 0.023169012474162236, 0.06635255526219096, 0.027561537755121077, 0.02977258652182562, 0.011956653008902711, 0.09432411646204335, 0.06564063632062503, 0.02857466348047767, 0.054112848825752735, 0.026633463001676967, 0.016779992895733033, 0.04650036105886102, 0.0021206191325161073, 0.10738909111491271, 0.04572165391540953, 0.062528460818742, 0.05409753089770675, 0.012718140629918447, 0.001823598485706108, 0.00689967824811382, 0.1252043265849352, 0.05464285592149411, 0.05044059016342674, 0.036568067236138244, 0.07669914221124989, 0.042639781787459335, 0.025133671604895165, 0.05340608675032854, 0.06009617740554469, 0.03543719702533313, 0.025307598789887767, 0.030534883295851092, 0.05808270616190774, 0.05331086114581142, 0.004359579437212753, 0.058981161165450297, 0.045016316763524494, 0.047681853374732394, 0.05553199463923063, 0.01835380737403674, 0.09137928126645939, 0.10393113416752645, 0.013884775573387742, 0.013735126371362379, 0.03134302868108664, 1.4601186620337623, 7.424657412937709, 24.439984560012817, 37.49681179864066, 38.87644611086164, 24.692697490964616, 13.869895883968898, 23.39968463352748, 40.317849908556255, 18.863299574170792, 10.645330718585424, 8.06605691569192, 6.932986378669739, 2.9997053912707736, 0.7660436172570501, 0.02967085037380457, 0.4310275912284851, 0.4779786318540573, 4.911939101559775, 5.519649829183306, 0.32618095725774765, 3.7464773654937744, 4.530231126717158, 2.760491290262767, 4.868610569408961, 4.638845367091043, 7.704058374677386, 3.8484847375324795, 4.7997230887413025, 4.5605708701269965, 3.4771936322961534, 2.020597381251199, 1.6969159841537476, 2.58039767401559, 4.390878924301692, 8.623563000134059, 18.62824375288827, 29.35559708731515, 45.72103316443307, 53.0435277393886, 52.18377501623971, 48.11950268064226, 35.01888963154384, 32.29721770967756, 39.83865349633353, 55.3823504447937, 43.678492069244385, 43.41208076477051, 48.02204377310616, 39.83653776986258, 34.92432812282017, 45.79608760561262, 47.68566410882132, 52.13622849328177, 46.00961964470999, 26.060613666261943, 16.47681048938206, 5.105761272566659, 0.9898114928177425, 0.5687825764928545, 1.972067036799022, 1.5943950968129295, 5.998200058937073, 3.7212797233036587, 3.0392708224909644, 3.053054962839399, 1.9944343737193515, 3.964862287044525, 3.974193283489772, 12.878483482769557, 8.892446994781494, 4.68523371219635, 1.5097055669341768, 2.047870363507952, 0.5577714730586324, 0.40644470176526476, 1.3225407472678592, 7.870269707271031, 9.989121999059405, 8.057542766843524, 16.808614764894756, 23.255490405218943, 28.209861721311295, 26.844469479152135, 29.12037624631609, 23.85249352455139, 10.22998651436397, 1.6689861799989427, 0.06934690315808568, 0.0646590336358973, 0.06969080506158726, 0.031446434025253565, 0.02415699338806527, 0.024181559748415436, 0.03730672045743891, 0.0480371885932982, 0.023130300355010798, 0.04894710744598082, 0.08901282253542117, 0.05168172570743731, 0.029661744433854307, 0.03214906721508928, 0.04044831384505544, 0.050366338076336045, 0.04302335084815111, 0.06878996161477906, 0.050127846587981494, 0.01382824088380273, 0.011451658410286265, 0.013815043377690017, 0.006405376089138112, 0.033362973148801496, 0.061349696213645596, 0.09109609467642647, 0.08144556252019745, 0.03695980246577944, 0.017944974758263146, 0.024216472071462443, 0.052198969559477906, 0.09309714872922216, 0.034619223060352464, 0.053464576468936036, 0.01784385268443397, 0.04285165434703231, 0.06978930799024445, 0.05982456662292991, 0.02638999785163573, 0.024181797235671963, 0.022423563724649802, 0.031939963078392405, 0.05136463611519762, 0.017286459915339947, 0.04613929221938763, 0.04635683393904141, 0.03921744114320193, 0.02268975810147822, 0.05180486963529672, 0.023119297909683416, 0.04913842039448874, 0.04837544847811971, 0.00883619174627321, 0.012866410709518408, 0.0060150874113397935, 0.005069521297368088, 0.09566342923790216, 0.045243151020258665, 0.06729276731078114, 0.04539746345419969, 0.010638969384932091, 0.023799320616360222, 0.04400282971827047, 0.14279355561094625, 0.02926027901204569, 0.0700913103563445, 0.10971911930079971, 0.03272374566378338, 0.07715331962598221, 0.07101196024034705, 0.02846924288730536, 0.0257053933372455, 0.033726067415305545, 0.01621249334753624, 0.06890578075711216, 0.03533809020050934, 0.026478176869984184, 0.021391747752204537, 0.04031100210600665, 0.06495837614472423, 0.0766142981925181, 0.03199784550815821, 0.042345253484589715, 0.02874219716925706, 0.07063120031463248, 0.015198565254520093, 0.020632446710286394, 0.06360965887350695, 2.1684576528412953, 10.223404833248683, 30.76019627707345, 41.41209043775286, 41.733416829790386, 23.506624358040945, 18.791389192853654, 32.21564238412039, 44.507214137486045, 29.226113932473318, 15.745873894010272, 11.776679839406695, 7.038642423493521, 2.4497910823140825, 0.5885388020958219, 0.01600334849873824, 0.1398783248982259, 0.27660634741187096, 2.483106608901705, 3.0957429579326083, 0.8836283077086721, 3.1279218026569913, 4.239885883671897, 2.4276536873408725, 4.74543160200119, 4.109618016651698, 7.602763192994254, 9.663664034434728, 5.453845611640385, 7.266518584319523, 4.112499347754887, 4.714578560420445, 2.3852310265813554, 4.483193559306009, 6.975987476961953, 11.657833508082799, 22.614138671330043, 37.714603083474294, 54.716146741594585, 59.77310126168387, 56.81427342551095, 54.05561971664429, 39.31647900172642, 33.71765531812395, 41.39195455823626, 56.74109499795096, 48.9300274167742, 48.16799415860857, 53.83455583027431, 44.35663972582136, 39.936324323926655, 49.18719066892351, 54.045214789254324, 57.95543513979231, 51.32169812066214, 32.37788282121931, 19.196295465741837, 5.854369742529733, 1.892022269112723, 1.5810218772717883, 2.5312597964491164, 2.7925654777458737, 6.459956926958902, 5.525473722389766, 5.878929018974304, 6.2556368964059015, 5.367915936878749, 5.876349934509822, 5.840348277773176, 7.548014862196786, 5.097932389804295, 2.9858552430357252, 1.5881735278027398, 0.16443906697843755, 0.2818898824708802, 0.4380239929471697, 1.1673950723239352, 5.66719308921269, 12.269073486328125, 13.029515607016426, 16.371020691735403, 21.04541608265468, 23.81316498347691, 26.598037719726562, 32.79731430326189, 28.717669078281947, 13.79497606413705, 2.421511262655258, 0.12330612487026624, 0.05178309544654829, 0.014913013969947184, 0.07134507343705211, 0.03299732419795223, 0.0870521209601845, 0.08181248711688177, 0.03199982004506247, 0.048160017002373934, 0.062265894907925806, 0.07226222208035843, 0.041830737343324084, 0.016431722923048904, 0.0814321885949799, 0.0157652285083064, 0.02346854327645685, 0.02780938284870769, 0.06671558506786823, 0.06332007369824819, 0.03282080331285085, 0.015123895868392927, 0.018138918726305877, 0.023704692122659514, 0.026980255464357988, 0.08224107019071068, 0.06916266054447208, 0.06710783937679869, 0.027288530886705433, 0.043835217997963936, 0.007654907231751297, 0.021049360678132092, 0.036645871454051564, 0.03317308173115764, 0.027225946209260395, 0.02075726831597941, 0.05574477643572858, 0.06608217941331011, 0.029980340373835394, 0.053681035925235064, 0.022251244667651396, 0.04354884568601847, 0.15045300817915372, 0.09163662924298219, 0.09891419551734414, 0.11439651224230017, 0.0971968098144446, 0.06881419210029499, 0.11424370615610055, 0.1871313950312989, 0.14564429835549422, 0.12390208217714514, 0.16458180360496044, 0.10161194897123746, 0.07201143553746597, 0.2349685345377241, 0.109121458871024, 0.18309755862823554, 0.13307100374783787, 0.11792383582464286, 0.09706192383808748, 0.10578446436141219, 0.08561456309897558, 0.23324372566172055, 0.2638120539486408, 0.13924031199089118, 0.19439148902893066, 0.2578021878642695, 0.14478349526013645, 0.15508668310940266, 0.1379266953361886, 0.17360266883458408, 0.1691325344145298, 0.07189074451369898, 0.11674672684499196, 0.16687297209032945, 0.24839253563966068, 0.2785961649247578, 0.08707901130297355, 0.18909150628106935, 0.16410655767789908, 0.22100280464759894, 0.1522014843566077, 0.1290408314338752, 0.1568922105112246, 0.23916584359748022, 0.10932727889823061, 0.09285752408738647, 0.17675409758729593, 2.18265586239951, 11.15183355127062, 33.26319101878575, 48.084129401615684, 49.44050114495413, 31.637322970799037, 21.274605887276785, 31.69963788986206, 47.95677586964199, 25.39124158450535, 17.504454272133962, 12.197354180472237, 8.364980578422546, 3.8326389363833835, 1.0042338903461183, 0.31200283233608517, 0.9097856698291642, 1.7827354648283549, 8.063399229730878, 12.076174991471426, 3.7890741654804776, 9.824196083205086, 10.945521559034075, 8.681055000850133, 12.268634012767247, 12.642444491386414, 14.568569387708392, 13.074815256255013, 11.355003220694405, 9.797260522842407, 8.01996864591326, 5.025146535464695, 2.8943190234048024, 3.7052541375160217, 6.064912753445761, 11.431750416755676, 22.35243477140154, 37.381096499306814, 55.10591288975307, 65.97718947274345, 62.15566635131836, 58.19045795713152, 41.694965498788015, 39.88039479936872, 47.37842171532767, 58.626912525721956, 52.65026664733887, 52.072193895067485, 55.61985376902989, 52.64399937220982, 48.18140418188912, 53.443907260894775, 53.43843902860369, 60.64441926138741, 57.54114532470703, 39.069765840257915, 20.385078396115983, 6.4628048198563715, 1.7632977707045419, 1.525141750063215, 4.467994809150696, 5.016370960644313, 11.87884702001299, 10.437306863921028, 7.393211603164673, 8.568826828684125, 8.714200513703481, 11.226319977215358, 10.884304455348424, 23.332214151109966, 16.539161886487687, 9.88533067703247, 4.046256959438324, 3.663564077445439, 1.583356037735939, 0.881705719445433, 1.8138928157942635, 9.207521745136805, 13.234277282442365, 15.299613680158343, 26.33221353803362, 32.300976685115266, 35.75564186913626, 35.01316779000418, 39.65752785546439, 33.2932767186846, 15.288357598440987, 2.956679540021079, 0.1744234247931412, 0.16947756947151252, 0.16779690608382225, 0.17667422044490064, 0.08211295599383966, 0.15300476125308446, 0.18007920416338102, 0.10295681894889899, 0.09501016964869839, 0.16933243083102362, 0.18631989429039614, 0.24505843168922833, 0.11326455298279013, 0.11465732753276825, 0.12107326968439988, 0.15998280181416444, 0.10768201468246323, 0.12522871313350542, 0.15746044287724154, 0.11780940767909799, 0.04612227456111993, 0.11769606518958296, 0.05138484967340316, 0.09692808959100928, 0.2753733407173838, 0.16047378975365842, 0.12233624048531055, 0.21807727377329553, 0.11410770059696265, 0.16410601484988416, 0.11223763094416686, 0.15596398817641394, 0.12425664386578969, 0.160929941705295, 0.06466355946447168, 0.1310205523456846, 0.18157259188592434, 0.09772617569459335, 0.21236685876335415, 0.18476716189512185, 0.19817882723041944], [0.05455451066206608, 0.025496341787012558, 0.03820530777531011, 0.04204146657139063, 0.04367669864690729, 0.012881610742104905, 0.03179184227649655, 0.03868589038029313, 0.048143464140594006, 0.04306365582825882, 0.010815603076480329, 0.054664647073618004, 0.011416440746480865, 0.03921686099576099, 0.05871645786932536, 0.022927230090967247, 0.04525122558698058, 0.05518385867721268, 0.014042716473340988, 0.02274479916585343, 0.01689633620636804, 0.10521834902465343, 0.03692409456042307, 0.008485655466626798, 0.02518378141602235, 0.0026479973291446057, 0.015408565057441592, 0.0442054843796151, 0.06459747693900551, 0.042126788957310576, 0.03626819207732167, 0.047311142552644014, 0.05481446760573557, 0.05785689649305173, 0.04559488321787544, 0.033709365275821516, 0.025131936251584972, 0.008337980801505702, 0.016962734250617877, 0.05487994284236005, 0.010153276563089873, 0.059861071806933196, 0.009224644562761699, 0.049939240994197984, 0.09271539814238038, 0.030720845995736972, 0.020806686021387577, 0.03147484089380928, 0.9747418271643775, 7.089457205363682, 18.91037014552525, 32.311652592250276, 38.667093413216726, 31.382775715419225, 17.20706616129194, 15.38308412688119, 10.701099566050939, 16.7038984639304, 17.254298278263636, 13.247304286275591, 6.807559669017792, 4.375793950898307, 1.1985481892313277, 0.4619291073509625, 0.10701456014066935, 2.194492987224034, 1.6654267481395175, 0.7106519266963005, 2.189547606876918, 1.416280088680131, 1.6798548996448517, 2.991733853306089, 3.328670024871826, 5.622385893549238, 5.822492710181645, 3.399570746081216, 8.460651193346296, 2.1769149133137295, 3.5429841705730984, 0.9057284646800586, 0.9828627513987678, 1.4836085672889436, 2.140346109867096, 4.509129447596414, 10.880936316081456, 18.715521812438965, 34.29781600407192, 39.8468975339617, 33.811223234449116, 27.4685914175851, 28.602457523345947, 36.89996501377651, 48.78683546611241, 46.726791858673096, 41.957315581185476, 38.54086896351406, 44.811104025159565, 49.813567297799246, 47.31459903717041, 33.209655148642405, 35.27198471341814, 27.7874789919172, 14.421844278063093, 9.014546820095607, 1.8926204655851637, 1.3839151625122343, 1.174197033047676, 2.1530628332069943, 2.159309263740267, 4.667121061256953, 5.567076061453138, 3.9732235755239214, 4.264453845364707, 3.9112200226102556, 2.5160682116236006, 5.601750612258911, 4.720910106386457, 3.2657306364604404, 3.2097062255655016, 2.569983409983771, 0.14972365088760853, 0.6183960799660001, 1.3087511786392756, 9.479486397334508, 11.711921760014125, 9.567168320928301, 14.74243242400033, 10.633841003690447, 13.958360348428998, 23.74528455734253, 31.208841460091726, 23.50241027559553, 12.999420353344508, 2.1497546221528734, 0.2818102224596909, 0.018658354246456708, 0.028016337725733007, 0.0407406165530639, 0.05380412896296807, 0.09589756453143698, 0.08138804989201681, 0.04168353934905358, 0.07824636490217277, 0.013869934316192354, 0.07781603799334594, 0.026084801281935403, 0.042976294444607835, 0.023512176470831037, 0.09937523970646517, 0.01375032979662397, 0.03347693649785859, 0.062095711539898596, 0.037487282018576346, 0.021017430516492044, 0.04513111471065453, 0.0407387098696615, 0.018386344824518477, 0.06351959013513156, 0.028664857747831514, 0.03672284107389195, 0.03702065348625183, 0.0070097336595478866, 0.016533260599577, 0.056549773418477604, 0.04704569286799856, 0.03219365035848958, 0.050615580952061076, 0.07436721412731068, 0.02156588019404028, 0.10387584713420697, 0.040472490047769885, 0.010826657260102885, 0.02670023593652461, 0.04912157915532589, 0.024691080175606266, 0.05494579805859497, 0.017082846823281476, 0.04338974279484578, 0.005311753210012934, 0.01811255424815629, 0.04638666233846119, 0.0022963876919155674, 0.05582108787660088, 0.02556024451873132, 0.06483123225292989, 0.0513991871183472, 0.01133990623722119, 0.021319283604887978, 0.09025955599333559, 0.013137737355594124, 0.010090097319334745, 0.018225640590701784, 0.01173616390276168, 0.05075709282287529, 0.014177745790220797, 0.056430303757744174, 0.04756503678592188, 0.03296638300110187, 0.013240908605179616, 0.030427118364189352, 0.02675319559473012, 0.020061639303873693, 0.014978597772174647, 0.035881813881652694, 0.039957488753965924, 0.011829873829680895, 0.019863113528117537, 0.03019794655431594, 0.014163086889311671, 0.025217275600880384, 0.014853481003748519, 0.0199592466732221, 0.01727759146264621, 0.07191593173359122, 0.04270679051322596, 0.04240570756207619, 0.054275229041065486, 0.042257491765277724, 0.009291384419027184, 0.034362838603556156, 0.014029452810063958, 0.03287974086457065, 0.03906852984800935, 0.00996619597676077, 1.5632793264729636, 9.999268974576678, 25.29831463950021, 38.23018026351929, 42.144889150347026, 26.34758816446577, 16.763197864804948, 20.141434601375035, 12.613780566624232, 19.00087911742074, 16.33736882890974, 16.61525160925729, 9.814326167106628, 5.649210716996874, 1.0588694214820862, 0.32066058633582933, 0.03705532323302967, 0.6233621963432857, 0.6145145882453237, 0.7066398848380361, 1.0016258188656397, 1.6957394587142127, 1.4243446673665727, 2.7892637806279317, 4.140196604388101, 7.856259533337184, 8.282364760126386, 5.525210125105722, 9.08394890172141, 5.423748186656407, 5.9504641975675305, 3.0604788959026337, 2.72194442152977, 3.16040506533214, 3.3028796144894192, 7.042480434690203, 15.557645457131521, 27.171213729040964, 41.11093119212559, 47.63429955073765, 43.94637986591884, 32.18682473046439, 31.380312579018728, 38.35899291719709, 52.421264444078716, 51.197464329855784, 47.35202898297991, 44.92733696528843, 51.70886564254761, 52.86644942419869, 54.388059752328054, 38.68627391542707, 44.83480085645403, 34.931074823652, 22.445646592548915, 11.642946124076843, 2.9546178792204176, 1.9268568456172943, 2.252762100526265, 2.3460269016878943, 4.278283366135188, 5.834902627127511, 4.913718708923884, 6.7756761227335245, 7.217156410217285, 4.502034902572632, 5.375478182520185, 3.3253733217716217, 3.7922264763287137, 3.9074940511158536, 1.3115521711962563, 0.1249823234975338, 0.16737237386405468, 0.5971658591713224, 2.0449794786317006, 8.22754955291748, 14.527701820646014, 16.205672672816686, 14.064634782927376, 14.811864035470144, 17.82214675630842, 27.29466758455549, 35.822514806474956, 28.00995683670044, 16.221945353916713, 3.207004461969648, 0.32460493754063335, 0.027176034869626164, 0.03209641968299236, 0.04236393016097801, 0.0146759219600686, 0.02929047721305064, 0.030096210406294892, 0.04270308231934905, 0.035287457917417796, 0.026999318905706917, 0.009824244754521974, 0.026227171499548212, 0.003057590116181278, 0.03389026949714337, 0.1364168734954936, 0.03593422731916819, 0.03601835548345532, 0.06349297120634999, 0.029153905077172176, 0.017129044880026152, 0.03131675919783967, 0.01643255752112184, 0.039012177514710596, 0.043434142733791044, 0.047766694000789096, 0.06968067453375884, 0.028294128266030123, 0.03118873660319618, 0.010544808232225478, 0.04270004926781569, 0.03834882132442934, 0.022362858589206423, 0.05368255584367684, 0.04959865712693759, 0.05354597692244819, 0.051484675745346715, 0.013089648730653738, 0.041196096755032025, 0.033661060367843935, 0.020198484550097158, 0.03890774418999042, 0.06781822482922248, 0.06641025788017682, 0.11033738683909178, 0.13260476876582417, 0.11694122212273733, 0.15396263556821005, 0.12487432786396571, 0.12310407071241311, 0.10416870284825563, 0.20863742674035685, 0.11649204551109246, 0.08248425714139428, 0.22131275944411755, 0.14485734701156616, 0.10983956605195999, 0.14886260351964406, 0.0732969744130969, 0.11538943967648915, 0.19850167419229234, 0.11323863973042794, 0.16073859483003616, 0.09845834890646593, 0.16355634720197745, 0.09179425292781421, 0.13886120090527193, 0.07945401474301304, 0.06979493304554905, 0.09051160461136273, 0.13046533428132534, 0.16550663326467785, 0.07673971860536508, 0.12075039558112621, 0.10645680435534034, 0.10026564049933638, 0.18662611714431218, 0.14023781275110586, 0.14611951714115484, 0.1165533715060779, 0.15379415532307966, 0.14276553211467607, 0.10269924027046987, 0.10579597910067864, 0.15847538198743547, 0.0753333122868623, 0.16544135819588388, 0.15080340366278375, 0.12942040392330714, 0.12153620698622294, 0.1357542569083827, 1.6886486049209322, 10.885776604924883, 28.57673008101327, 44.185283252171104, 51.66317081451416, 39.35168204988752, 25.11094777924674, 21.8187575340271, 17.43023361478533, 26.641651562282018, 23.05714018004281, 18.731045825140818, 10.376814109938485, 5.97294248853411, 1.3611859764371599, 0.7155111602374485, 0.3483193021799837, 3.216855921915599, 3.8336134212357655, 3.4428934156894684, 5.4736010772841315, 6.370105862617493, 6.5732290659632, 8.961324487413679, 8.948665738105774, 12.990997399602618, 12.180463109697614, 9.043654561042786, 15.928786958966937, 7.628289137567792, 10.06289449759892, 3.9969959684780667, 2.8083624243736267, 2.9079583372388567, 3.390487713473184, 7.049568900040217, 13.562221833637782, 23.565915073667252, 42.03418002809797, 51.73662369591849, 51.511960642678396, 37.85426187515259, 37.876683712005615, 45.58836773463658, 56.075280393872944, 54.490920884268625, 50.347261905670166, 52.2492652620588, 56.954022543770925, 55.91350201198033, 55.02911792482649, 45.55795199530465, 46.041240896497456, 38.880983284541536, 26.537306989942277, 12.39259856087821, 3.31086266040802, 2.5251254056181227, 3.0341354523386275, 5.7150114604405, 5.530981906822749, 8.945432220186506, 9.046675290380206, 12.902745723724365, 13.5059666122709, 9.581675291061401, 9.929294535091945, 12.209823591368538, 12.129163690975734, 8.21368442262922, 7.520195143563407, 4.315098396369389, 0.8797149519835199, 1.1301571790661131, 2.4520275337355475, 11.50062096118927, 15.680816173553467, 16.567215238298687, 21.269702196121216, 18.784559113638743, 22.83051426070077, 34.92734364100865, 41.60144969395229, 34.21256855555943, 18.322462218148367, 3.7466224091393605, 0.39268143315400394, 0.14350624808243342, 0.14451798450733933, 0.15215683675238065, 0.15704284528536455, 0.22012074983545712, 0.16180698892899922, 0.11215575890881674, 0.11471954919397831, 0.08394363668880292, 0.15942231831806047, 0.14405446366540023, 0.1521403347807271, 0.09234989168388502, 0.11584633801664625, 0.13155538721808366, 0.12853526856218064, 0.2396549859217235, 0.13228608800896577, 0.17688152646379812, 0.0972944577889783, 0.11830935228083815, 0.12849262942160877, 0.1789921232100044, 0.14101195335388184, 0.12439821341208049, 0.1430788795862879, 0.051735017847801955, 0.10796298246298518, 0.15613363550177642, 0.07768062275967427, 0.10735446547291108, 0.18665959606213228, 0.19159530049988202, 0.15883671545556613, 0.16991674447698252, 0.156729253541146, 0.16771168208548, 0.12733712499695166, 0.10343332016574484, 0.09787245427391358, 0.1390497793576547], [0.03708261051880462, 0.048986540508589575, 0.01983827575375991, 0.06317007674702577, 0.024124554325161234, 0.05966115503438881, 0.024076237542820827, 0.04960633135799851, 0.04440277861431241, 0.023315314802208116, 0.05722359261874642, 0.052458631340414286, 0.03865183470770717, 0.074046959169209, 0.06256105085568768, 0.024961942873362983, 0.03980806855750935, 0.026917660608887672, 0.07146691118500062, 0.011581004148216119, 0.07441336807927915, 0.05855720570044858, 0.015708601368325095, 0.01964604339030172, 0.04185133766649025, 0.02139331347176007, 0.020842858723231723, 0.039380248835576434, 0.026870002005515353, 0.024852188137759055, 0.047705554602933783, 0.05742239659386022, 0.02873887913301587, 0.042099355786506615, 0.017171921507854546, 0.01604459833885942, 0.040765305049717426, 0.011636903559389924, 0.05294646069939647, 0.03146490714113627, 0.067922379954585, 0.0488109661798392, 0.04583918635866471, 0.016821678694603697, 0.049331599314297946, 0.03520219320697444, 0.026003516179376414, 0.0562359034749014, 0.019095363028879677, 0.6988606708390372, 4.19775287594114, 23.30969156537737, 31.607456139155797, 38.93706566946847, 37.62405068533761, 27.208341428211757, 23.919489792415074, 19.20368140084403, 21.00473611695426, 14.152912514550344, 15.352536371776036, 10.691967027527944, 4.2692194410732816, 2.562483698129654, 0.29240321261542185, 0.9387639462947845, 0.1909964390631233, 0.2754168483827795, 0.3297562396952084, 1.251862802675792, 0.23342451453208923, 2.5196219980716705, 2.2069528443472723, 6.06119590146201, 9.127053788730077, 2.941287543092455, 6.999654344149998, 4.36397419657026, 5.073574176856449, 1.7655459472111292, 2.0289102494716644, 0.7526118808559009, 0.31013658962079454, 1.2757179226194109, 2.308839274304254, 5.680053336279733, 10.18222199167524, 6.02189211334501, 16.316254990441458, 25.74170698438372, 22.561064856392996, 25.95581919806344, 36.414692401885986, 37.81518520627703, 30.969066074916295, 34.94704873221261, 40.982212339128765, 36.023859705243794, 31.063981941768102, 29.83025632585798, 17.478655610765728, 8.045697825295584, 1.833708861044475, 0.8066594749689102, 0.5266278013586998, 1.790042472737176, 1.959870776959828, 1.5829168898718697, 3.4376373205866133, 5.544345464025225, 2.5833406703812734, 5.363601974078587, 5.616251936980656, 4.287263478551592, 3.9784981267792836, 2.173151812383107, 2.69943334375109, 2.4147476255893707, 0.5564196684530803, 0.27410784576620373, 0.5200669105563844, 2.7978241784232, 7.123079104082925, 22.08995267323085, 12.668901494571141, 18.2743980543954, 21.90147410120283, 13.339276722499303, 21.68238697733198, 28.891215971538, 24.795272009713308, 12.958185400281634, 2.5222818553447723, 0.07338186592928, 0.041668991558253765, 0.11511186457106046, 0.08360118006489106, 0.03003103711775371, 0.021667945431545377, 0.0424010833459241, 0.024531554896384478, 0.04220248632399099, 0.0747243474636759, 0.05900729833436864, 0.016232040245085955, 0.03567916261298316, 0.04533782022606049, 0.004414207019310976, 0.039399254601448774, 0.04210238205268979, 0.0412879839672574, 0.05862814653664827, 0.04601850959339312, 0.02803765899235649, 0.044577718512820344, 0.07114224574927773, 0.05049054391149964, 0.01624349900521338, 0.014377049336742078, 0.020211851689964533, 0.01950082671828568, 0.05943902302533388, 0.012878810088815433, 0.03874584234186581, 0.029587349854409695, 0.022724054653995802, 0.034976068019334755, 0.012311438614103411, 0.031726112589240074, 0.0741787985233324, 0.023008403235248158, 0.07676780316978693, 0.019336283672600985, 0.06707155810935156, 0.015204012194382293, 0.016240342121039118, 0.09924623662871973, 0.031124598080558435, 0.04004815121048263, 0.04276499185445053, 0.031480252210583, 0.02279963666972305, 0.0739145769870707, 0.038329835914607556, 0.042904176350150786, 0.019930602317409854, 0.04303874002237405, 0.04976890156311648, 0.003488554635883442, 0.05671985500625201, 0.04993386699685028, 0.01761076063849032, 0.025082971468301754, 0.02464181344423975, 0.06886666999863726, 0.020927348207416277, 0.0663753743948681, 0.01809327197926385, 0.037965842589203797, 0.01933693845889398, 0.06825745411749397, 0.042010236997157335, 0.031792320643684695, 0.022943883036662425, 0.06732226322804179, 0.02301761265178876, 0.019159596546420028, 0.05614702895815883, 0.03454019408673048, 0.032603275163897445, 0.05505922197231224, 0.03343240763725979, 0.03597436605819634, 0.08600610494613647, 0.03696352762303182, 0.01840423440028514, 0.03639557684904762, 0.007946233697501677, 0.019451546416218792, 0.014269850981820906, 0.04310748240511332, 0.023162403543080603, 0.06480389407702855, 0.046965649484523704, 0.04337049275636673, 1.1382944967065538, 6.870738336018153, 28.022573028291973, 39.252701486860005, 41.98138066700527, 35.91410943440029, 20.342937571661814, 19.247739928109304, 18.98338876451765, 19.191120794841222, 19.419266632625035, 17.76771456854684, 12.711744955607823, 4.780126997402736, 2.424944107021604, 0.39814505140696255, 0.15701569031391824, 0.24031967882599148, 0.39543818522776875, 0.28871629759669304, 0.8333450087479183, 0.36485161791954723, 1.718588175518172, 2.497301127229418, 5.384082657950265, 5.33925461769104, 4.878273776599339, 6.4768123882157465, 3.5752869972160886, 5.569949575832911, 2.896334000996181, 2.0718140729836056, 2.9905192213399068, 1.201351244534765, 1.8670563059193748, 2.3460264674254825, 7.915161149842398, 21.415339912687028, 12.953221780913216, 22.31114857537406, 30.790327140263148, 25.172378540039062, 31.43085377556937, 38.834093366350444, 41.688798972538535, 36.14948313576834, 41.25621107646397, 42.84829003470284, 38.47494445528303, 35.894185474940706, 40.256657123565674, 22.97904416493007, 11.133612768990652, 2.5824365360396246, 2.2753483057022095, 1.7253346592187881, 2.4248600772448947, 2.5500948429107666, 2.381434270313808, 5.788409624780927, 6.390838418688093, 5.474708880696978, 5.8370183535984586, 6.365407577582768, 3.4901322637285506, 3.098398255450385, 3.5685322625296454, 1.2561396360397339, 0.7458644743476595, 0.1408344485930034, 0.49143354701144354, 0.5497586258820125, 2.6852203692708696, 7.124922548021589, 22.583632605416433, 16.305057968412125, 17.862692969185964, 16.601954494203838, 13.160481333732605, 22.989362239837646, 31.806699207850865, 28.671585151127406, 15.574154376983643, 3.580881165606635, 0.15998882720513002, 0.032132158122424564, 0.037423228312815936, 0.06810738931276969, 0.04327645458813224, 0.04600275061758501, 0.03081111829461796, 0.0258433751296252, 0.05936065223067999, 0.046537059625344615, 0.00883338091495846, 0.004517827798346323, 0.020727880964321748, 0.025770529306360652, 0.04264884362263339, 0.006220127123274973, 0.029103866512221948, 0.06535418597715241, 0.1001678771738495, 0.029659169393458536, 0.03410589435536947, 0.0839340625596898, 0.03718080471402832, 0.04033099853300622, 0.027869986203898276, 0.048852499308330674, 0.0703017579923783, 0.011754622599775237, 0.026107472833245993, 0.044358673838100264, 0.016732678648882678, 0.0424086659747575, 0.06291793991944619, 0.07155374331133706, 0.030756760854274035, 0.03179976078016417, 0.03482089723859515, 0.02637415236261274, 0.0258022084100438, 0.03272214432113937, 0.014951698947697878, 0.012705427428175296, 0.02949782394404922, 0.175712451338768, 0.1605154110917023, 0.08429239011768784, 0.18928745362375463, 0.06168549640902451, 0.1195925162839038, 0.2094762995839119, 0.07571656922144548, 0.115753582279597, 0.16538410341101034, 0.13738356876586164, 0.13612020441464015, 0.0676019350066781, 0.12251606583595276, 0.1914617240961109, 0.13570257968136243, 0.18994289131036826, 0.09594506198274237, 0.1319283100643328, 0.14033630889441284, 0.19796132961554186, 0.10694228259048291, 0.079079022364957, 0.09096672518977097, 0.11592514307371207, 0.08949467060821396, 0.11093787675989525, 0.14090063289872237, 0.18275225215724536, 0.06847252257700477, 0.12921847190175736, 0.11490765267184802, 0.16041202949626104, 0.10971774187471185, 0.10767225734889507, 0.11598264213119235, 0.11138436637286629, 0.22477467225066253, 0.1147273387759924, 0.07985205017030239, 0.14023840986192226, 0.1761895835931812, 0.18919381579118116, 0.10527204828602926, 0.15296174213290215, 0.11962249396102768, 0.14857198697115692, 0.1693438302193369, 0.19029294752648898, 1.3559399779353822, 7.536868214607239, 33.18031290599278, 44.17202608925955, 52.74689177104405, 46.61038868767874, 37.428365094321116, 32.31622103282383, 29.23770352772304, 30.921203408922466, 23.43831835474287, 22.114617041179113, 14.664827993937902, 6.270331902163369, 3.3734214178153445, 0.8358213901519775, 1.491274275950023, 1.181558432323592, 1.0329980211598533, 1.9862993359565735, 3.4946359992027283, 3.2719234355858395, 7.428577933992658, 8.234699249267578, 13.529421993664332, 20.374600512640818, 10.002538970538549, 15.622843878609793, 8.341730168887548, 11.83809322970254, 5.509030810424259, 4.165432895932879, 3.129519236939294, 1.0579665899276733, 2.5302816203662326, 3.7717944298471724, 8.223118339266096, 22.049644436155045, 11.547633341380529, 22.051866122654506, 32.522592953273225, 31.064301558903285, 36.00209447315761, 41.99663891111101, 45.95360674176897, 40.03693423952375, 45.405776023864746, 46.1616427557809, 43.46829169137137, 45.74876689910889, 51.894174098968506, 31.475013051714214, 10.539550474711827, 4.5745758329119, 1.2839906215667725, 1.09565546470029, 5.148099686418261, 6.026208247457232, 6.322666602475302, 7.997017008917672, 13.06332380431039, 11.453889983040945, 13.215862819126674, 11.038867133004324, 10.30223388331277, 9.767244304929461, 8.139217972755432, 6.156619421073368, 4.794140645435878, 1.447650011096682, 1.1531842691557748, 1.047669033919062, 4.196700223854609, 9.007290295192174, 27.498517308916362, 18.98985927445548, 26.488666125706263, 29.507575035095215, 21.52543064526149, 30.112707546779088, 38.63688611984253, 33.83685861315046, 18.855342149734497, 4.796905159950256, 0.25330371782183647, 0.14084355453295366, 0.25038837854351315, 0.3120570879961763, 0.2316174672118255, 0.07609302723514182, 0.12770029050963266, 0.08252055197954178, 0.13606005907058716, 0.15020287302987917, 0.12307744499828134, 0.11617598389940602, 0.09725058371467249, 0.12299866708261625, 0.1396878601184913, 0.1276428321642535, 0.09802018491817371, 0.20506316210542405, 0.22389709576964378, 0.19167722681803362, 0.11264888423361949, 0.1250434187906129, 0.09852831943758897, 0.10517307038285903, 0.13391238717096193, 0.10619755648076534, 0.11533267343682901, 0.09189969048436199, 0.13898841265056813, 0.09573175092892987, 0.1131471460685134, 0.14734664772238049, 0.17109800609094755, 0.14824455311255796, 0.12516748213342258, 0.08667970701519932, 0.26335312000342775, 0.22669291788978235, 0.2966169965054308, 0.13272812643221446, 0.09943377013717379, 0.09267900152398006, 0.10249306740505354], [0.03380461123638919, 0.07502201399100678, 0.016407680731000643, 0.007769989315420389, 0.016939180603783046, 0.03575918564040746, 0.02554422600327858, 0.05487027032566922, 0.0208690773163523, 0.08595611727131264, 0.05540772095056517, 0.07735082081386022, 0.0479296509708677, 0.07127235483910356, 0.048590160706745725, 0.03496830557872142, 0.029160948270665746, 0.007732073626747089, 0.029104931812201227, 0.05314355476626328, 0.028565666106130396, 0.07601698381560189, 0.03829842992126942, 0.013371499454868692, 0.07063839278583016, 0.027419247265372957, 0.044038530838276656, 0.08772290710891996, 0.05968679008739335, 0.040659043073121987, 0.043858393361525874, 0.03694460667403681, 0.022656903435875262, 0.030266702507755587, 0.04239455583904471, 0.027258023952267, 0.038763792985784154, 0.004840722257670547, 0.057266442105174065, 0.027908644040248225, 0.027991805292133774, 0.02514903194137982, 0.04341800377837249, 0.03383924027106591, 0.049055103079548905, 0.07222173389579568, 0.04253585736400314, 0.0647629444886531, 0.049930521819208346, 0.03621821118784802, 0.4601864122918674, 4.287567462239947, 18.21461054256984, 32.175478322165354, 33.74204349517822, 34.35963065283639, 23.134511845452444, 19.73087075778416, 19.044930696487427, 15.567253078733172, 17.526030165808542, 19.018491063799175, 13.486963289124624, 7.797824314662388, 3.787949425833566, 1.0325505137443542, 0.34980654237525804, 0.1878538312656539, 0.24110175828848565, 0.28445154215608326, 0.3899653117571558, 0.4936757524098669, 2.5649691990443637, 5.245360570294516, 3.9049362455095564, 4.444221981934138, 5.38229957648686, 3.891686030796596, 4.500612258911133, 2.5513453015259335, 1.789074284689767, 3.8022192886897495, 1.0149384588003159, 0.2727581853313105, 0.2115332649222442, 0.5468726807406971, 3.0029842896120886, 2.9279899937765936, 5.156134843826294, 9.086211408887591, 11.482355884143285, 14.057634472846985, 22.39970162936619, 20.569136176790508, 17.972854920795985, 24.51753340448652, 19.296120234898158, 17.58862474986485, 27.104307787758962, 17.49743832860674, 8.436091916901724, 4.61037642615182, 0.11906097909169537, 0.8105354298438344, 1.3703006016356605, 0.732197530567646, 1.4942858857767922, 1.2134180941752024, 5.27357416493552, 2.6662949962275366, 3.9711326020104543, 3.252333858183452, 5.252566286495753, 2.5289944665772572, 2.2783733776637485, 1.4093365584100996, 0.624261988060815, 0.9709062044109616, 0.48891238229615347, 0.9602568958486829, 2.697341284581593, 6.388682305812836, 21.216831615992955, 38.405573640550884, 16.3873576436724, 15.164351361138479, 18.23438685280936, 27.338482924870082, 29.25334392275129, 25.91057252883911, 14.123697076525007, 2.8989619399820055, 0.280546953103372, 0.05195929063484073, 0.01335843256674707, 0.03222638288778918, 0.025623273636613573, 0.047420077957212925, 0.01702826885905649, 0.0675927951399769, 0.010282769034217511, 0.007143370707386306, 0.08502825456006186, 0.055442190529512506, 0.017419013427570462, 0.02303195179307035, 0.037651928540851386, 0.0034412340277672876, 0.0172757899521717, 0.035314358438232114, 0.02516119977060173, 0.034521419022764475, 0.013060787243635526, 0.04525219928473234, 0.07540373065109764, 0.043977900341685326, 0.03519854268857411, 0.06965963316283055, 0.031439190663929494, 0.016674183841262544, 0.012173773188676153, 0.017255284623908143, 0.03644279270832028, 0.05811022075691393, 0.032045007084629366, 0.03660939001877393, 0.01994596265389451, 0.012916521368814366, 0.011643779663635152, 0.06626665272883006, 0.05443879669266088, 0.044244747808469195, 0.018249908395643746, 0.03375152265653014, 0.014630068259845887, 0.00533406895452312, 0.029743562186402932, 0.04801503103226423, 0.028969604788081985, 0.02836740665536906, 0.0069209515932016075, 0.03777606991518821, 0.006852214299474976, 0.026779823005199432, 0.06356014617319618, 0.02779482996889523, 0.03977343273748245, 0.04209684181426253, 0.016674002333145057, 0.09578991495072842, 0.018784831477595226, 0.03222544311678835, 0.01900414247731013, 0.0531016755849123, 0.09100935075964246, 0.04385110928810068, 0.03686906537041068, 0.002821677060897595, 0.04855505330488086, 0.029053403862885067, 0.01756858459806868, 0.05136278032192162, 0.03477345407009125, 0.04660116422123142, 0.0028037963909030494, 0.030846151057630777, 0.012654187008073288, 0.10036667436361313, 0.02800594426558486, 0.02810577373020351, 0.016989748426047818, 0.0812460392979639, 0.005346931009885988, 0.017032372299581766, 0.04874980981860842, 0.018548119447327087, 0.04955123092180916, 0.03970827980499182, 0.0299730563004102, 0.02154485069747482, 0.05555982475302049, 0.0319226434720414, 0.044955333428723473, 0.033344991970807314, 0.0248174488411418, 0.027791023387440612, 0.7150977424212864, 7.004855070795331, 22.778974260602677, 38.18339456830706, 38.23790666035244, 39.13133730207171, 24.75644200188773, 21.654265880584717, 21.658285413469585, 19.66849330493382, 25.66492244175502, 21.285452025277273, 16.289233446121216, 9.536268813269478, 3.3469563807759966, 1.2889610805681773, 0.2959634044340679, 0.19307186055396283, 0.15418424510530063, 0.2838189032460962, 0.2998570826436792, 0.8613041256155286, 1.8265726268291473, 2.5393466310841695, 2.4258197971752713, 3.9313593762261525, 3.2529188096523285, 3.1213557549885342, 4.9324619088854105, 4.589730288301196, 3.8595988154411316, 4.363142584051404, 3.4777942172118594, 1.8553598821163177, 0.4157479596989495, 1.1446413504225867, 3.3529761263302396, 3.635748918567385, 8.063181230000087, 11.456809963498797, 15.126476730619158, 18.218478952135357, 28.78404869352068, 25.898328065872192, 21.62168230329241, 28.319877760750906, 29.392669200897217, 25.291369915008545, 33.90338066646031, 25.3375563280923, 13.671778423445565, 6.605332349027906, 0.45055444485374857, 2.3022751808166504, 4.687476677553994, 4.4031407577650885, 4.7691028118133545, 5.406313853604453, 7.136015347072056, 5.202702973570142, 5.556864380836487, 4.250362030097416, 4.517619277749743, 1.4443008708102363, 3.2210962772369385, 0.7510090182934488, 0.9796893788235528, 0.3140593905534063, 0.21191020469580377, 0.9628307691642216, 3.544657817908696, 7.87320966379983, 18.815621035439626, 41.204843044281006, 21.55346836362566, 17.0724013873509, 20.30287425858634, 26.998504093715123, 32.73870972224644, 30.973794324057444, 17.18827302115304, 4.190248387200492, 0.5237786599567958, 0.034070566429623535, 0.06069360034806388, 0.03368605420525585, 0.03375141069825206, 0.01912623637222818, 0.020951521017455628, 0.03483273767467056, 0.028019491217232177, 0.05232487512486322, 0.03854829365653651, 0.03363534049796207, 0.04306403920054436, 0.011643523516665612, 0.05785847747964518, 0.026665583153122237, 0.06382303099547114, 0.0077805591946733844, 0.049992312610681565, 0.0170418446484421, 0.01374227728229016, 0.007941021700389683, 0.01899292290077678, 0.02234360685438982, 0.03586285561323166, 0.05114297229530556, 0.030483996562127556, 0.04592141801757472, 0.010264379038874592, 0.008646042485322272, 0.05312513932585716, 0.0422075006977788, 0.0019688813148864676, 0.03129771950521639, 0.04360390541010669, 0.01752878343021231, 0.011160339578054845, 0.06459096978817667, 0.019560388522222638, 0.03016669662403209, 0.059792037654135904, 0.035399256739765406, 0.01893820583687297, 0.028661424360637153, 0.12503628060221672, 0.14056383525686605, 0.10956884415021964, 0.09830237406172923, 0.17809469279433998, 0.1430754190576928, 0.0924343489376562, 0.11749967001378536, 0.11719040732298579, 0.13516063376196794, 0.20918330816285952, 0.1593564325677497, 0.16519167087972164, 0.18550048183117593, 0.1494408239211355, 0.09333722798952035, 0.10173532020832811, 0.20742089487612247, 0.14840014119233402, 0.16518052933471544, 0.21914665853338583, 0.21169485125158513, 0.12255922066313879, 0.12670759377735002, 0.11722493118473462, 0.0768907672858664, 0.1084671136257904, 0.2241086901298591, 0.12384511237697941, 0.17266173075352395, 0.10954273412270205, 0.21171300884868416, 0.18890353851020336, 0.13845701116536344, 0.06808520800301007, 0.2177775784262589, 0.1104366768683706, 0.10576819309166499, 0.1330623049288988, 0.18439483615968907, 0.0769447311758995, 0.10514440906367131, 0.08716329892299005, 0.1329243587596076, 0.20071558468043804, 0.17496363366288797, 0.14772353321313858, 0.14851956335561617, 0.11753004124122006, 0.13650173108492578, 0.9305097034999302, 7.5425553151539395, 25.64335870742798, 43.79228966576712, 47.62928989955357, 44.34798921857561, 32.79548692703247, 30.320319720676967, 28.161319868905203, 24.02994704246521, 26.922697510038102, 25.72321261678423, 19.267808062689646, 10.05694510255541, 5.034859682832446, 1.8028275924069541, 1.0269172617367335, 0.632564976811409, 0.9080734817045075, 1.556831181049347, 1.579280810696738, 2.351834510053907, 5.776113050324576, 12.246233020509992, 10.630060315132141, 12.281325766018458, 12.609899997711182, 11.101202896663121, 11.662160498755318, 9.578224641936165, 5.101322676454272, 7.245961036000933, 3.745109873158591, 1.2347335389682224, 0.6681915393897465, 1.2857076951435633, 6.785745799541473, 5.648354351520538, 6.058144773755755, 11.572639039584569, 15.57118923323495, 21.67530676296779, 31.163942200796946, 27.194521461214336, 20.42314236504691, 28.41807665143694, 32.88633462360927, 29.492111819131033, 38.25933837890625, 26.069526468004497, 14.922392504555837, 7.0488601837839395, 0.25541749011193005, 1.8373660019465854, 4.572901317051478, 5.30022007226944, 6.961676359176636, 8.107315318925039, 11.869165573801313, 10.580626487731934, 10.45730117389134, 10.000795841217041, 13.454764468329293, 8.249293940407888, 8.059457864080157, 3.864569817270551, 2.1847978617463792, 1.771386559520449, 1.0244620506252562, 1.499664225748607, 3.6196616675172533, 8.56977265221732, 24.426409517015728, 45.34507656097412, 23.54090850693839, 22.956782136644634, 26.176862239837646, 35.285596234457834, 39.2361786706107, 35.29554258074079, 20.092366422925675, 4.79681613615581, 0.7538717846785272, 0.19859942394707883, 0.12067138696355478, 0.08855266044182436, 0.10812741185405425, 0.14096389950386115, 0.15471616227711948, 0.2110353966376611, 0.104964834770986, 0.25609656795859337, 0.153345969372562, 0.08120122884533235, 0.07265470709119524, 0.06520323907690388, 0.08617190497794322, 0.07951308800173656, 0.18463035566466196, 0.279406335737024, 0.1502807552793196, 0.1133316872375352, 0.08259987272322178, 0.19291733098881586, 0.17604992751564297, 0.17955567368439265, 0.1056743042011346, 0.11705571812178407, 0.10014944816274302, 0.19031444351587976, 0.1478506363928318, 0.11913700215518475, 0.1211527804178851, 0.15783466851072653, 0.17468296443777426, 0.11970992998353072, 0.11750053853860923, 0.07229535494531904, 0.0988527609567557, 0.13855796360543796, 0.20327953781400407, 0.08868248454694237, 0.2079755701124668, 0.2007603951330696, 0.08839939295181207, 0.13175271877220698], [0.02948173927143216, 0.018406972289085388, 0.08407842767025743, 0.057881805513586314, 0.031244206840970686, 0.10779010531093393, 0.06291635214750256, 0.027249650830136876, 0.09854901475565774, 0.0503074717707932, 0.022688278895137564, 0.007857108970970979, 0.029919743803994994, 0.02666485881698983, 0.01750613732396492, 0.02038645910631333, 0.012564328615553677, 0.014207910912643586, 0.06343467826289789, 0.06752872786351613, 0.057258543957556994, 0.0361553686670959, 0.07494301215878554, 0.0535457190791411, 0.017126680185486163, 0.01732046978681215, 0.14753267488309316, 0.013791408306652946, 0.028368266698505198, 0.05158206248389823, 0.026601760149268166, 0.020847281075215766, 0.031021908590836183, 0.010288170172965952, 0.023919414529310803, 0.0598008246826274, 0.015691946726292372, 0.060530711231487136, 0.018382322808195437, 0.05174720433673688, 0.024954546841659715, 0.05769515410065651, 0.023532654657693844, 0.04350722774064966, 0.08774901713643755, 0.04902196003656302, 0.016185660680223788, 0.04248237184115818, 0.03621413319238594, 0.03515264657991273, 0.049648319104952474, 0.5155971018331391, 4.121631017753056, 16.457103661128453, 32.63811370304653, 38.53121096747262, 39.987164293016704, 26.09331362588065, 17.726082699639456, 19.73673677444458, 9.057907921927315, 13.081763454845973, 16.130413259778702, 11.790536284446716, 8.258278829710823, 5.588645875453949, 2.2425104677677155, 1.0610561498573847, 0.14865056132631643, 0.2775808594056538, 0.23980059953672545, 0.769744510097163, 1.2763676877532686, 1.8894931248256137, 0.8829276795898164, 1.7002763066973006, 1.4553136570113046, 1.0940159069640296, 2.9427814057895114, 2.44471737742424, 2.2233388679368153, 3.440624611718314, 2.8154426387378146, 2.0106853416987827, 0.2924093194305897, 0.3599598418389048, 14.186042393956866, 2.237523832491466, 0.20479693210550717, 2.073060840368271, 2.969231677906854, 4.59053931917463, 5.226018522466932, 8.404719063213893, 7.8391313552856445, 7.211891412734985, 4.640059130532401, 25.947444881711686, 3.8691782099860053, 1.2716996925217765, 3.6259189546108246, 1.5455689110926218, 0.41614701971411705, 3.3516253530979156, 5.3370203375816345, 2.943030889545168, 2.7375904619693756, 2.832199739558356, 6.015678252492632, 4.663253954478672, 3.8882306047848294, 3.7003634742328098, 3.4824492931365967, 1.2055759664092744, 1.575680992433003, 1.0786071909325463, 0.851662414414542, 0.25229283635105404, 0.9729309529066086, 2.5492467284202576, 7.490218877792358, 9.914297716958181, 35.35677705492292, 44.30768966674805, 15.398868697030203, 16.31889009475708, 19.664760385240825, 26.25849836213248, 26.98282027244568, 15.235113552638463, 2.750680216721126, 0.4594048485159874, 0.005911428464709648, 0.027118145654510175, 0.03783999130661998, 0.026770160666533878, 0.016021438242335404, 0.02806802513077855, 0.015947929151090126, 0.042468173495892964, 0.031548336414354186, 0.015445974389357226, 0.026066024521631852, 0.011283317264834685, 0.049189517474068065, 0.011829079095540302, 0.06021283793130091, 0.037183790268110375, 0.018193026805030446, 0.034658269358000586, 0.01382148521952331, 0.02989744714328221, 0.01599384900847716, 0.026476689181955795, 0.035600018288408, 0.07416542459811483, 0.017059031940464462, 0.02895012404769659, 0.018648831007469977, 0.02252268242383642, 0.02168250340037048, 0.03854228862162147, 0.054664833670748134, 0.016775964094059806, 0.04299810256010719, 0.018957883352413774, 0.07016343862882682, 0.01154067287487643, 0.022244308343423263, 0.07037221028336457, 0.09063315058925323, 0.024712945966582214, 0.026399476985846246, 0.01261289051866957, 0.0869370074942708, 0.06204812587904079, 0.030103599652647972, 0.035265049298426936, 0.050085034420979876, 0.01813483564183116, 0.029590080957859755, 0.05354976314785225, 0.07352285872080497, 0.06908652891537972, 0.029003433151436702, 0.0330768111827118, 0.09800788986363582, 0.01105099281163088, 0.056653697841933796, 0.026846941992906586, 0.02354786910914949, 0.006209154787939042, 0.013973929137656731, 0.022133876769138233, 0.014685153428997313, 0.03968308240707431, 0.02504212535651667, 0.021266261182193245, 0.0682253594111119, 0.01502782039876495, 0.014501333203432816, 0.06133408312286649, 0.09489586363945689, 0.03937753130282674, 0.04683432581701449, 0.08732576056250504, 0.04297016727338944, 0.04073833667540124, 0.018042224093473384, 0.02107636976454939, 0.04764418789584722, 0.05381263779210193, 0.023299696622416377, 0.08349910804203578, 0.031126576010137796, 0.05114590356658612, 0.07025319524109364, 0.007238590374722013, 0.021057168919859186, 0.0158448512000697, 0.053851650162999115, 0.013244410694044615, 0.0077182416903919405, 0.01308375904669187, 0.02369813238536673, 0.05504069118095296, 0.05475763011989849, 0.7039046830364636, 5.619225765977587, 20.317098958151682, 36.83574628829956, 42.87178536823818, 40.31376436778477, 28.245149884905132, 17.505797011511667, 17.22559526988438, 12.382938827787127, 20.490235907690867, 25.25354392187936, 14.405211159161158, 10.279667002814156, 4.328682558877127, 1.5949131718703677, 0.9300927030188697, 0.11536354678017752, 0.1444579070167882, 0.1542163398116827, 0.23622518139226095, 0.4156648527298655, 1.5078034975699015, 1.6600161641836166, 2.8378208322184424, 1.929223358631134, 2.370302821908678, 4.408962479659489, 3.911483185631888, 3.696709156036377, 3.449658138411386, 4.066748934132712, 4.118983319827488, 2.5449229947158267, 1.5592605535473143, 12.450605596814837, 2.1870614545685902, 0.9219002340521131, 3.513475171157292, 3.62700417637825, 5.354741718087878, 7.922828486987522, 11.476927603994097, 11.462527462414332, 10.13605294908796, 11.139992083821978, 30.14686141695295, 6.664494088717869, 2.2126688233443668, 5.847364221300397, 2.452197330338614, 1.7197024928671973, 4.226042032241821, 4.911031927381243, 4.738381786005838, 3.1269488377230505, 5.014622620173863, 4.5077285170555115, 4.4322880165917535, 2.939833415406091, 2.508508571556636, 2.451112759964807, 0.6663156886185918, 1.117184892296791, 0.03496860074145453, 0.3589801729789802, 0.359288824988263, 1.433521609221186, 3.5088009876864295, 9.862875836236135, 13.62205364022936, 33.91681500843593, 49.61085360390799, 15.291296686444964, 15.193575484412056, 22.153697184153966, 31.106873171670095, 30.05325528553554, 18.952854905809673, 4.461207287652152, 0.6229397132992744, 0.037290662926222594, 0.09544521916125502, 0.03841655608266592, 0.04031244399292128, 0.04630947219473975, 0.04919236732114639, 0.09145235948796783, 0.03569577654291477, 0.05361321635012116, 0.027633565943688154, 0.034020297162766965, 0.11824704919542585, 0.0209564064695899, 0.011638073184128319, 0.045840818235384564, 0.06785333223108735, 0.01422560795409871, 0.03932170483416744, 0.022523376225892986, 0.09306548149990183, 0.06392544907118593, 0.014986875899402159, 0.01279999315738678, 0.014080532078099037, 0.010994693064796073, 0.047649860448603115, 0.018803718499839306, 0.02376737179500716, 0.033332289795258215, 0.06689638750893728, 0.027349848400003145, 0.02442959143913218, 0.017841033371431485, 0.055908642642732174, 0.06629160246146576, 0.01976550287300987, 0.00690041997170608, 0.011137306706846824, 0.025741527023326074, 0.09693004377186298, 0.062601559396301, 0.02909652137064508, 0.050947201371725113, 0.039251690198268206, 0.08650723019880907, 0.08756833683167185, 0.16339708146240028, 0.14403131205056394, 0.14835984978292668, 0.17414864525198936, 0.18717224283942155, 0.09447081573307514, 0.15714054075734957, 0.13972739156867775, 0.20935102844876902, 0.09905775995658976, 0.10495293326675892, 0.25781331583857536, 0.08219084502863032, 0.12236507822360311, 0.07524039370140859, 0.06099491060844489, 0.17385010341448442, 0.1367940575416599, 0.10005226837737219, 0.13290921385799134, 0.13476396219006606, 0.12987073404448374, 0.16870564089289733, 0.16936163497822626, 0.28636112968836513, 0.08099124261311122, 0.13881416485777923, 0.18182009431932653, 0.13681206586105482, 0.1466983753655638, 0.13852722596909317, 0.08550517646861927, 0.09249662488166775, 0.2723329338644232, 0.13836939872375556, 0.19542181731334754, 0.19171621544020517, 0.16104177784706863, 0.1329612439232213, 0.15563755854964256, 0.0822048635621156, 0.07537158844726426, 0.17584697769156524, 0.12230168948216097, 0.11516101764781134, 0.1498991743262325, 0.07243556742157255, 0.15353224080588135, 0.16962930347238267, 0.8083231342690331, 6.219328216144016, 21.96312199320112, 42.065756116594585, 50.96834748131888, 50.14917571204049, 35.93618733542306, 25.53905061313084, 27.14231617110116, 15.726514475686209, 21.259757586887904, 24.96645998954773, 16.868522133146012, 12.05116581916809, 6.972056099346705, 3.419042855501175, 1.6114896195275443, 0.6412105986050197, 0.539725372833865, 0.5659083564366613, 2.027951180934906, 3.4388313250882283, 5.322527263845716, 4.8423433388982495, 7.127072146960667, 5.764006682804652, 5.207407338278634, 8.12477787903377, 8.94443428516388, 7.923599737031119, 8.004396864346095, 6.552119135856628, 7.1447509697505405, 1.5047292453902108, 1.6860281569617135, 16.764604875019618, 3.0716483422688077, 0.7810952067375183, 3.2536861513342177, 4.1459197487149915, 6.390136216367994, 8.650093827928815, 12.09487693650382, 10.122016719409398, 9.286649567740303, 15.667751823152814, 46.5172689301627, 6.809295415878296, 2.2290748230048587, 6.073509846414838, 1.8345026927334922, 1.7262004699025835, 6.7674364277294705, 10.98068378652845, 8.618872966085162, 9.511514987264361, 7.83896894114358, 13.624978831836156, 9.24704396724701, 9.847381353378296, 10.379544751984731, 7.039153984614781, 3.705252400466374, 3.413877304111208, 2.8503545139517104, 1.6626677704708916, 0.7465495233024869, 1.64296778185027, 4.493782613958631, 10.522759284291949, 14.113227009773254, 41.639543192727224, 51.49739721843174, 20.966399431228638, 21.777205569403513, 28.803781577519008, 37.967048508780344, 35.52115058898926, 21.117844104766846, 5.049617656639644, 0.9509224253041404, 0.14342406392097473, 0.1346345112792083, 0.15548179405076162, 0.12030121896948133, 0.15417428421122686, 0.134356149073158, 0.21113649835543974, 0.1537548274333988, 0.1261142420449427, 0.08382133753704173, 0.13845665832715376, 0.2064619484756674, 0.15455999065722736, 0.11150309643042938, 0.2036203523831708, 0.17365157763872827, 0.10124881059995719, 0.12598855021808827, 0.09068936721554824, 0.14910433840538773, 0.10607035152081933, 0.10677005004669939, 0.10894525011203118, 0.20659344856228146, 0.06374489090272359, 0.19743363293153898, 0.06656522170773574, 0.07741868788642542, 0.14323677468512738, 0.14571006196950162, 0.22976954494203838, 0.1325006950646639, 0.062137448228895664, 0.14454790790166172, 0.17666379814701422, 0.0912790277174541, 0.06902864987828902, 0.1536167184157031, 0.16556281596422195, 0.21386633973036492, 0.15419070475867816, 0.10545584306653057, 0.2790638655424118, 0.09039545977222067], [0.016028730797448328, 0.019889208288597207, 0.03215804084071091, 0.009931115716296648, 0.02992344181984663, 0.027384226376722966, 0.04525764452825699, 0.1283196165625538, 0.010198939425338591, 0.031149378179439476, 0.018293051348466958, 0.021385715575888753, 0.032256024690078836, 0.005573367051381085, 0.006652549433056265, 0.015302398075748767, 0.040339347906410694, 0.02147276483343116, 0.04039785458839365, 0.06313223484903574, 0.019378614079739367, 0.06575000259493079, 0.02359444205649197, 0.01748482114635408, 0.031744351610541344, 0.041635896012719185, 0.022908711173970784, 0.016381312860175967, 0.042985804112894196, 0.009892532518798751, 0.03213242953643203, 0.0176595676623817, 0.03268420064289655, 0.02451221495201545, 0.039536454382219484, 0.05702346550034625, 0.045506049413233995, 0.029781404084392955, 0.014096359755577785, 0.03867021282868726, 0.029163329928581203, 0.0648763073342187, 0.010549903182046754, 0.04575769091024995, 0.0218827781001372, 0.03461805258744529, 0.008001963474920817, 0.06814880709030799, 0.028512346824365, 0.009732138714753091, 0.03717590229851859, 0.007293025846593082, 0.19463964285595076, 3.3790739945002963, 12.66174224444798, 26.1076112815312, 39.99526936667306, 39.876135553632466, 35.02548694610596, 27.751374414988927, 21.439715930393763, 15.903851611273629, 18.26158036504473, 22.89780408995492, 16.98793387413025, 11.649969015802656, 7.0994943124907355, 3.362566811697824, 2.166236183473042, 0.7046307155064174, 0.2642540788011891, 0.30312013040695873, 0.4155541972390243, 1.3182087625776018, 1.0564940060888017, 2.557595206158502, 0.7594588963048798, 1.5683241529124123, 3.4430860110691617, 3.2200138781751906, 4.043664847101484, 2.1925969975335255, 4.909014778477805, 3.680943693433489, 2.1444355590002875, 1.3463321392025267, 3.2857247292995453, 0.6429074246968541, 1.0031423717737198, 0.1635130973798888, 0.04479007961760674, 0.3682760755930628, 0.6613439268299511, 0.9822157004049846, 1.0356567927769251, 1.2506388340677534, 0.17420522150184425, 7.866539393152509, 6.39154713494437, 0.19838554970920086, 0.294886867914881, 0.7511772406952721, 2.063254326581955, 4.306053578853607, 6.080551411424365, 5.680524945259094, 2.8738168435437337, 4.665668019226619, 3.083239891699382, 3.7979596086910794, 2.582509274993624, 1.05436101768698, 1.6992196376834596, 0.21865773334034852, 1.3461506175143378, 0.11663708915667874, 1.104454163994108, 1.9029077078614915, 5.8899653639112195, 9.484165140560695, 15.081483670643397, 20.57414582797459, 45.95073018755232, 47.36569608960833, 22.087600708007812, 24.789788143975393, 30.34908526284354, 28.18871487889971, 14.89062534059797, 4.028024452073233, 0.38704951107501984, 0.06353301155780043, 0.011957820089134787, 0.04500538217169898, 0.011886420393628734, 0.06027832334595067, 0.11124584344880921, 0.04137835465371609, 0.05506746278011373, 0.017937799250440936, 0.015699792287445495, 0.016437753403027142, 0.0354796868882009, 0.0431297315683748, 0.11107419444514172, 0.040980831520365815, 0.021446213758151447, 0.026920997304841876, 0.006166952030201043, 0.020326312065922787, 0.07397869854633297, 0.021168228139036467, 0.034013040230742524, 0.022372437807332193, 0.028126589488238096, 0.0344441474548408, 0.0388669370939689, 0.02313199669255742, 0.031107821302222352, 0.07478617557457515, 0.016303259280643294, 0.04670678158955915, 0.0035642265575006604, 0.03787730394729546, 0.026477662879707556, 0.017480454773509076, 0.0502124361560813, 0.06270575523376465, 0.03495917249737041, 0.024290703802502582, 0.0506619554279106, 0.026161127989845614, 0.02015884453430772, 0.014235447560037886, 0.05602613098121115, 0.03404671253104295, 0.045661040382193666, 0.03210629915286388, 0.004380553378723562, 0.01910001947544515, 0.03973994703431215, 0.0157317173600729, 0.032460518181324005, 0.06304329926414148, 0.0565100655491863, 0.03461761153968317, 0.03993456105568579, 0.03621706446366651, 0.04551168464656387, 0.024110091351238743, 0.026529859186017087, 0.013900682130562407, 0.03936568068872605, 0.014548416748376829, 0.021319610998034477, 0.06720961284424577, 0.05742770952305623, 0.09138232110334293, 0.05645543669483491, 0.016018074404980456, 0.03333933638142688, 0.048640806560537646, 0.034394397267273495, 0.013233885767736604, 0.056087898023958714, 0.05940804790173258, 0.025743985016431128, 0.04812749481893011, 0.027890971595687524, 0.028990334032901695, 0.06094993052205869, 0.04754551872611046, 0.02472132757040007, 0.045006016601941416, 0.03996160746152912, 0.028435360241149153, 0.05518035404384136, 0.033803084532597234, 0.03297538037544914, 0.023032068840361068, 0.0076029679205800805, 0.016121333864118372, 0.029548975306430032, 0.05491684836202434, 0.020714870055339167, 0.09472940542868205, 0.008769715670496225, 0.024477009162572876, 0.2904211032603468, 4.506385343415396, 16.826534169060842, 32.503290857587544, 45.50224133900234, 40.990727356501985, 33.86217784881592, 26.26868268421718, 16.858719961983816, 16.008328199386597, 21.011838912963867, 24.88153042112078, 20.940784897123063, 14.427086693899971, 9.400463666234698, 4.107762847627912, 1.6913717559405734, 0.7415032855101994, 0.2711813242307731, 0.210794991680554, 0.21997540763446263, 0.4609753042459488, 0.6617337859102658, 0.39851205742784906, 0.7724406282816614, 1.8465515204838343, 1.5061120454754149, 3.0382435747555325, 4.510990262031555, 4.4579572677612305, 4.934727021626063, 7.695959380694798, 5.138040431908198, 2.6039399078914096, 1.9025084035737174, 2.1598336356026784, 1.2438998413937432, 0.9961835337536675, 0.20678588109357016, 0.25659648541893276, 1.0477438356195177, 1.7850744021790368, 2.228705048561096, 2.132162651845387, 0.6034185322267669, 13.457251054900032, 4.922924203532083, 0.14482181891798973, 1.0063957571983337, 3.083924723523004, 4.182361747537341, 4.342703589371272, 5.098020979336329, 5.318911595003946, 4.212112196854182, 3.5473437309265137, 3.4727309346199036, 2.947720055069242, 1.6473974755832126, 1.7364476514714104, 0.8367422435964856, 0.4667225501367024, 0.22061903881175177, 0.12997288070619106, 0.9653018308537347, 2.4329071768692563, 7.374578271593366, 9.619228567395892, 14.206748025757925, 17.813194002423966, 46.92523241043091, 51.58375290461949, 19.560123988560267, 24.92421841621399, 32.171524797167095, 31.235637187957764, 18.664874655859812, 6.126998816217695, 0.5578441577298301, 0.06796223710158042, 0.02090198965743184, 0.04981882816978863, 0.011448508311462189, 0.06388932386679308, 0.06873671697186572, 0.11859201639890671, 0.014639355707913637, 0.03372981632128358, 0.013782997865096798, 0.08770462059016738, 0.026629332419750944, 0.021613034985161254, 0.10091286112687417, 0.002541342014280547, 0.01890395169279405, 0.02047256689651736, 0.016556473282564963, 0.024355062849021385, 0.08636114839464426, 0.009304309662963663, 0.02098841975176973, 0.043455791393561025, 0.008375540259294212, 0.024947013406615173, 0.036810592615178654, 0.057832401378878524, 0.033430226147174835, 0.05641973896750382, 0.0434727208422763, 0.05982270065162863, 0.043262408913246224, 0.015535142372495361, 0.026316980698278973, 0.023111045227519104, 0.014369509116347347, 0.03140935887183462, 0.03307409704263721, 0.008810903594296957, 0.03215402391340051, 0.010883428588775652, 0.05503335961007646, 0.010473627364262938, 0.01611881480286164, 0.0195920608405556, 0.13582029193639755, 0.11408040991851262, 0.09505956021270581, 0.0921575270060982, 0.11292772819953305, 0.1852149542953287, 0.146200154242771, 0.27904093105878147, 0.15531076251396111, 0.12368074405406203, 0.10876889207533427, 0.09420826339295932, 0.13545787281223706, 0.10156034638306924, 0.14967565132038935, 0.07555387009467397, 0.08716806902417115, 0.09405447343098265, 0.12269158927457673, 0.14792645589581557, 0.1360804694039481, 0.21802509443036147, 0.13649741560220718, 0.1755843303565468, 0.17631165204303606, 0.18295563624373504, 0.10344187649233, 0.14657982172710554, 0.12273525978837695, 0.16703772039285728, 0.1520418929202216, 0.17385516528572353, 0.15557573043874331, 0.09994536518518414, 0.15054946871740477, 0.1921993459441832, 0.12109617702662945, 0.11937166670603411, 0.12367318517395429, 0.081074593854802, 0.15530532066311153, 0.08481735909091574, 0.13616588339209557, 0.12047135484005723, 0.14550409944994108, 0.1597556554313217, 0.08879704839949097, 0.1456695127167872, 0.13848451897501945, 0.11995009066803114, 0.10516125030283417, 0.0879221453464457, 0.34082710849387304, 5.169134923389979, 18.309344019208634, 36.3519675391061, 51.04126535143171, 50.77797031402588, 44.57959352220808, 37.12955433981759, 29.26453399658203, 25.289179495402745, 26.851676498140606, 31.396081515720912, 25.607512950897217, 18.06644194466727, 10.271607092448644, 4.9458914739745, 3.0511194552694048, 1.200870298913547, 0.683718917625291, 0.8170480632356235, 0.8181861021689006, 2.490670374461583, 2.9126807238374437, 5.967569359711238, 2.9182325516428267, 5.4230168887547086, 6.841500750609806, 8.549945967538015, 9.852477857044764, 8.571118865694318, 13.86122453212738, 8.349718860217504, 6.520660732473646, 4.340378548417773, 6.471540008272443, 3.185274622270039, 2.2996418135506764, 0.5007763228246144, 0.10865649274949517, 0.5365244245954922, 1.230007244007928, 1.401124439069203, 1.5680819430521555, 1.907273782151086, 0.9373405426740646, 15.289832353591919, 7.200802956308637, 0.2053549321634429, 1.105141275695392, 1.386408045887947, 6.65364100251879, 8.467831288065229, 13.565332021032061, 14.125874468258449, 8.854799049241201, 12.039099403790065, 7.557335002081735, 11.815918053899493, 7.713925685201373, 3.6575339095933095, 4.762589744159153, 1.3043308215481895, 2.3862532802990506, 0.5707927229149001, 1.443046829530171, 3.010058641433716, 7.97030292238508, 13.086083497319903, 20.38794800213405, 27.050018038068497, 53.051139490945, 53.63340548106602, 28.08001204899379, 34.224852970668245, 39.77194731576102, 36.692870480673655, 20.62138315609523, 6.304980831486838, 0.7846551814249584, 0.1534981240651437, 0.10083856832768236, 0.09482256828674249, 0.07585293440414326, 0.18760018130498274, 0.12901677058211394, 0.16431098670831748, 0.20379332453012466, 0.21784967955734047, 0.12669970920043333, 0.14675024258238928, 0.08133114794535296, 0.1819116286933422, 0.19523216677563532, 0.13687107126627648, 0.11495337236140456, 0.0993448074108788, 0.0887816727959684, 0.15687014455241816, 0.1269409962530647, 0.1091114097673978, 0.13954429567924567, 0.14485723844596318, 0.15025115758180618, 0.12984401333544934, 0.11075780035129615, 0.08671705358262573, 0.15222099902374403, 0.15622750403625624, 0.16664475362215722, 0.20904450703944477, 0.09796026349067688, 0.11653716808983258, 0.20633552383099282, 0.08955586768154587, 0.14303250850311347, 0.20240798672395094, 0.13797601126134396, 0.12164053853069033, 0.12917393286313328, 0.08875135585133519, 0.14501469928239072, 0.10623117789093937, 0.10394774470478296, 0.1679577731660434], [0.010934523123848652, 0.043234588977481635, 0.02839366256791566, 0.03120237515707101, 0.08226263403360333, 0.06425683200359344, 0.051585489085742404, 0.03989607115675296, 0.024732228235474656, 0.0672882686236075, 0.015137627720832825, 0.0601967295099582, 0.02193522885707872, 0.036510351047452004, 0.05429690484223621, 0.02105870919435152, 0.03848852150674377, 0.038944904160286696, 0.01892095069134874, 0.014809340604447892, 0.044779484293290546, 0.02697134460322559, 0.035188588579850535, 0.05146779040140765, 0.027703032662559832, 0.026733971001314263, 0.05647951111729656, 0.01654579653404653, 0.06527707725763321, 0.026772613570626293, 0.03781588974275759, 0.0471338820643723, 0.09521166062248604, 0.08701747496213232, 0.03584860637784004, 0.031333437588598044, 0.019583434964131032, 0.035587397537061145, 0.01933001061635358, 0.017771622631698847, 0.07879400373037372, 0.025505205150693655, 0.051076289266347885, 0.0672208968816059, 0.022114845558202693, 0.042154323908367326, 0.07384705596736499, 0.05890270894659417, 0.03750585352203675, 0.13894474213676794, 0.031037080633853163, 0.02286506101622113, 0.02767956892161497, 0.08970956943397011, 1.321367478796414, 9.318335958889552, 21.698020424161637, 35.472999572753906, 39.67656591960362, 37.958807945251465, 26.31007136617388, 18.601369857788086, 20.53679231234959, 18.865258966173442, 19.363778318677628, 10.540746433394295, 12.35973618711744, 8.777871200016566, 7.246496915817261, 5.29754501581192, 2.17676357286317, 1.1514219237225396, 0.47044542751141954, 0.37093690995659145, 0.48906887961285456, 0.17053355995033467, 0.8768451831170491, 0.8535321312291282, 2.3161685381616866, 1.1010491124221256, 2.711242458650044, 2.2922272171292986, 2.2779979578086307, 6.014653393200465, 7.690112471580505, 1.9008087004934038, 2.38926271881376, 1.6040135749748774, 1.37172617656844, 2.1865538018090382, 0.8709088159458978, 0.7780760516013417, 0.30179234594106674, 0.8718442714640072, 1.7599249631166458, 0.6558830227170671, 0.36104123666882515, 16.033320869718278, 14.539001328604561, 1.7789497822523117, 1.118293998496873, 6.692428886890411, 1.6826286422354835, 2.1029400484902516, 2.6534990199974606, 2.5867604868752614, 1.9717035591602325, 2.8712542610509053, 2.308675991637366, 0.8830723432557923, 0.31348307004996706, 1.2309132239648273, 0.2688349229948861, 0.3846028223633766, 0.7544309518166951, 1.6967201318059648, 4.14657461643219, 6.86720300572259, 10.481471351214818, 9.25934054170336, 15.686536278043475, 19.81331808226449, 43.40524026325771, 36.71303415298462, 25.440375770841325, 31.271899836403982, 29.518862383706228, 15.8702483858381, 4.680970123835972, 0.3465177374226706, 0.16433453187346458, 0.019326891051605344, 0.04027172510645219, 0.027118768210389783, 0.05649657627301557, 0.008606035212453986, 0.046656111987041574, 0.013749879419005342, 0.03137137108881559, 0.02073825746109443, 0.011552077352202364, 0.030039685046566383, 0.03587737626263073, 0.10055529352809701, 0.033764268936855454, 0.08223683613219432, 0.020830870705789754, 0.023585989206497158, 0.010017989402902978, 0.02125578120883022, 0.046673550337020836, 0.027301933649661284, 0.03473568341827818, 0.024517588949363147, 0.018989365680941513, 0.04279104759916663, 0.02714322430879942, 0.015052900749391742, 0.048072804896427054, 0.04711089329794049, 0.057295924451734336, 0.02135845543151455, 0.03130359901115298, 0.03584202119548406, 0.0687634851783514, 0.03725322475656867, 0.052910640835762024, 0.06563079756285463, 0.023073819100058506, 0.0649332907050848, 0.035505233731653006, 0.027437947690486908, 0.014257398167891162, 0.06319694673376423, 0.05950049151267324, 0.06500039781842913, 0.023581526142411997, 0.037436622594084056, 0.03179702628403902, 0.06085593306592532, 0.03301819593512586, 0.029304756982518092, 0.03272217485521521, 0.04469040621604238, 0.031971664234463654, 0.010333900040547763, 0.060535535615469725, 0.008839464829569417, 0.034200173403535566, 0.0676861751292433, 0.037471662142447064, 0.02963654025058661, 0.050868874681847434, 0.05140810985384243, 0.05204464016216142, 0.0363978974388114, 0.04976244869508913, 0.05172690596165402, 0.03273865986349327, 0.017689964334879602, 0.036075125115790536, 0.06542363403631107, 0.008697218444597508, 0.074386036688728, 0.021486856309430938, 0.015561398285041963, 0.035948605476213355, 0.027942245094371692, 0.03925275210557239, 0.07120253358568464, 0.05571832714070167, 0.0073296582559123635, 0.01595576962323061, 0.03302077776087182, 0.015305551567247935, 0.03495658727894936, 0.04501201145883117, 0.056525118848575015, 0.026620326563715935, 0.021569542586803436, 0.006800418752910835, 0.060022630994873385, 0.09093389088021857, 0.03584501692759139, 0.019056328605594378, 0.08332401208047356, 0.04688544664531946, 0.07894442815865789, 0.04963934547933085, 0.09776777667658669, 1.9819693054471696, 12.482955540929522, 27.33863057409014, 42.01504468917847, 43.5755684035165, 39.47493961879185, 27.539259808404104, 19.334309271403722, 18.708257470812114, 23.825037717819214, 25.415171180452617, 17.7583292893001, 17.10978443281991, 9.254665272576467, 7.537172198295593, 5.04587778874806, 2.5513372676713124, 0.7676651531032154, 0.21025242150894233, 0.4108432371701513, 0.025210999151957885, 0.30240460165909355, 0.5248649130974496, 0.36357819767934935, 0.6551318573100227, 1.3137196834598268, 1.92740575330598, 2.687954919678824, 5.348084909575326, 6.505547097751072, 4.915344153131757, 4.14643087557384, 4.219783876623426, 2.2975048082215443, 2.38360840507916, 2.8683896490505765, 1.6779136380978992, 1.0463246660573142, 1.3968594393559863, 2.059621504374913, 2.9913662501743863, 0.28675514140299385, 0.8171253619449479, 24.248282023838588, 18.098594733646937, 2.654712132045201, 2.326653152704239, 9.339098913328987, 4.4874158927372525, 3.264984573636736, 2.763416264738355, 3.3910159936973026, 2.634312220982143, 2.1757871338299344, 1.9716123640537262, 0.8987950852939061, 0.7115261512143272, 0.42031078200255123, 0.3446788803807327, 0.03901297479335751, 0.5716294380170959, 2.1844406809125627, 5.477068228381021, 8.419758439064026, 13.995784214564733, 17.449473176683696, 16.535154512950353, 18.76774447304862, 48.28037084851946, 40.26861844744001, 26.69421468462263, 32.986287934439524, 33.71459811074393, 19.811145033155167, 6.561395849500384, 0.6593204811215401, 0.10422197463256971, 0.02429795394917684, 0.07360961620828935, 0.018372027735624994, 0.06967448629438877, 0.03425753675401211, 0.08962970586227519, 0.015395998588896223, 0.019382759928703308, 0.02791574321288083, 0.06887682088251625, 0.04632365696930459, 0.046276973760021586, 0.042295486333646944, 0.0354739634453186, 0.03304003458470106, 0.046923129087580104, 0.031472255675388236, 0.08797621780208179, 0.07165101130626031, 0.060695317041661055, 0.040319426118263176, 0.06764960887708835, 0.03719583087201629, 0.026181877590715885, 0.04830112175217696, 0.016459064491625344, 0.04018222973016756, 0.03173967989693795, 0.025202144269964526, 0.07843708073986427, 0.04035372606345585, 0.022034727535875778, 0.009841387093599354, 0.013904360638532256, 0.02908328315243125, 0.03747381649113127, 0.03095198216448937, 0.007963865429961255, 0.017905485716515353, 0.07900337249572788, 0.019699674798175693, 0.06104362942278385, 0.015780341179509248, 0.03294995566830039, 0.06187732504414661, 0.07333411063466753, 0.1033047717064619, 0.10438838534589324, 0.23845680164439337, 0.24818552817617143, 0.17157728251601967, 0.13133201348994458, 0.15511790929096086, 0.11607519430773598, 0.14263139931218966, 0.13696470909884997, 0.14841802737542562, 0.08132620142506701, 0.1397645752876997, 0.17291812199567044, 0.15930455178022385, 0.12512624077498913, 0.1428672852260726, 0.1253960941519056, 0.17097219212778977, 0.1683317409562213, 0.0728638180132423, 0.1253686813371522, 0.0848286295575755, 0.22628019217933926, 0.31549842762095587, 0.1546188196433442, 0.2037780439215047, 0.13698555369462284, 0.11138660553842783, 0.19528507893638952, 0.176463087488498, 0.1579446726079498, 0.2240667295243059, 0.1334012738828148, 0.1746117996850184, 0.1153054234704801, 0.0802175769848483, 0.14825745884861263, 0.07724944768207413, 0.1215647461691073, 0.10121020195739609, 0.17355319006102427, 0.11377549663718257, 0.09756645533655371, 0.16914872426007474, 0.11983042423214231, 0.1227208748459816, 0.15759981397007192, 0.28711566062910215, 0.1344534917069333, 0.16129917332104274, 0.15420461472656044, 0.1832625512033701, 2.3245576194354465, 13.499384062630789, 31.09786135809762, 46.61855629512242, 52.55092477798462, 48.35149955749512, 36.36770520891462, 27.792142970221384, 28.696275574820383, 28.593551669801982, 28.42896795272827, 20.785767112459453, 19.415023020335607, 13.936251180512564, 10.057675531932286, 6.867583853857858, 3.1347599157265256, 1.7075525905404771, 0.753492456461702, 0.9758026216711316, 1.1661249633346285, 1.3040144613810947, 3.0446330947535376, 2.7133829380784715, 5.1648682951927185, 6.428026914596558, 8.182034509522573, 5.670223372323172, 6.86850449017116, 13.073195457458496, 16.831965923309326, 8.37481575352805, 8.096067922455923, 5.321871093341282, 4.625625116484506, 5.7042339359010965, 3.7047621182032993, 1.431450937475477, 1.1935434234993798, 2.3163481056690216, 3.8186192086764743, 2.319732095514025, 1.336423248052597, 25.15868190356663, 24.23283965247018, 3.290409117937088, 3.6301734234605516, 12.69865368093763, 6.93774893454143, 7.882891978536334, 7.419427156448364, 8.911760381289891, 6.081200633730207, 8.202283297266279, 6.548479148319789, 3.850732914039067, 1.848870916025979, 2.5563354109014784, 0.7536006420850754, 0.8510201403072902, 1.211370329771723, 2.77896220769201, 6.154553200517382, 9.739897932325091, 14.033379180090767, 15.864616870880127, 22.199001176016672, 23.67948685373579, 51.45042739595686, 44.854467732565745, 33.2560830116272, 40.20671347209385, 39.91572986330305, 22.590059689113072, 7.954420208930969, 0.8326827042869159, 0.22181579816554273, 0.1444109116813966, 0.14683102896170958, 0.1349177182252918, 0.16316821160061018, 0.1385503640132291, 0.1461371047688382, 0.1596034328852381, 0.15556080266833305, 0.08697470689990691, 0.12248983367213181, 0.09450706307377134, 0.1491983833589724, 0.225148042930024, 0.06969481520354748, 0.14853734097310475, 0.22053585041846546, 0.17488267086446285, 0.20068769689117158, 0.208849197519677, 0.21236058909978184, 0.12102726501013551, 0.13664883747696877, 0.13219927623867989, 0.08463162370026112, 0.11083191673138312, 0.08611059933900833, 0.17856204057378428, 0.16015008783766202, 0.12310559063085488, 0.18516761969242776, 0.1027731734461018, 0.10291689394840173, 0.102982725415911, 0.16545875583376202, 0.09289662806051117, 0.17897027438240393, 0.16104711113231523, 0.13417297175952367, 0.12901354075542518, 0.11918088980019093, 0.10301813137318407, 0.1411648951470852, 0.08270618558994361, 0.14040604872362955, 0.19988490853990826], [0.03623493368338261, 0.04429240471550396, 0.026220282672771385, 0.09184433559754066, 0.0528032185642847, 0.026408840769103596, 0.022469542953850966, 0.038049543276429176, 0.08621400807585035, 0.07073409336486033, 0.06522780204457895, 0.01984697118002389, 0.08686565953705992, 0.035983132730637274, 0.06821703378643308, 0.03223680857835071, 0.039190479554235935, 0.019938152715829865, 0.021307197199868302, 0.05234914971515536, 0.08564604712384087, 0.04672724959839668, 0.0384265067987144, 0.04443409300542303, 0.01778826200669365, 0.08473262363778693, 0.0434545971719282, 0.0071043396767761025, 0.0700342252052256, 0.05161661348704781, 0.02680273543644164, 0.017599220454160656, 0.017593133995043378, 0.03185488157240408, 0.08102618716657162, 0.061383792598332675, 0.0044556014722080105, 0.03079788007640413, 0.03374280348154051, 0.017568129979606186, 0.05974343419075012, 0.04812016664072871, 0.018890335191307322, 0.06793060379901103, 0.024859329718830328, 0.021652607147448828, 0.046026845396097214, 0.055791775163795264, 0.0140854209229084, 0.050691044224160056, 0.02751727861219219, 0.030915205566478626, 0.04208295898778098, 0.03363918439884271, 0.03065904841891357, 0.29354277146714075, 5.827276544911521, 18.372662952968053, 33.80430630275181, 35.69100625174386, 32.53266784123012, 31.397700445992605, 28.200747421809606, 22.16898148400443, 21.26924361501421, 21.133854491370066, 26.00643161364964, 25.104265349251882, 18.569283076695033, 11.076413461140223, 7.442793948309762, 4.320300425801959, 2.3382221204893927, 1.4074841035263879, 0.40513271359460695, 0.3114950710109302, 0.41844535352928297, 0.3060465162353856, 0.32062937372497147, 0.7693784268839019, 1.388178859438215, 2.5757217534950803, 4.876148496355329, 8.165786147117615, 3.1801826783588956, 3.5285755608763014, 2.1597791356699805, 1.7749446885926383, 1.5794256372111184, 2.032020002603531, 0.2616853894931929, 1.1076830135924476, 2.265485772064754, 2.0624416044780185, 1.681435723389898, 0.8186684048601559, 0.5747883713671139, 4.039062968322209, 17.116551978247507, 1.6537647396326065, 1.535174406000546, 12.00833625452859, 3.5957003704139163, 3.0934196540287564, 1.7574393536363329, 2.2616319102900366, 2.71102945293699, 0.5851391245211873, 1.3671961682183402, 0.5528740244252341, 0.6208029251013483, 0.8054657961641039, 0.7729374244809151, 1.5889153565679277, 4.305344428334918, 5.143552090440478, 8.808240907532827, 13.32322725227901, 15.831388848168508, 9.72723310334342, 9.916255371911184, 16.151422875268118, 33.936606952122276, 33.38416263035366, 30.071727071489605, 31.48971196583339, 17.33077883720398, 5.859886612210955, 0.3258967325091362, 0.07162775791117124, 0.07028049270489387, 0.033216657250055244, 0.01299627891941262, 0.03078447561711073, 0.016383799691019312, 0.027327125958566154, 0.029710768588951657, 0.03770641490284886, 0.02796397008933127, 0.0557097742067916, 0.023441929436687912, 0.012552416933301305, 0.04033418086224368, 0.03991407947614789, 0.058951699174940586, 0.0520861156151763, 0.010482309219826545, 0.035319691723478694, 0.042042226530611515, 0.021981930726074746, 0.00459084495170308, 0.04410746321082115, 0.03524093755653926, 0.07830966543406248, 0.018452851434371302, 0.07393722648599318, 0.04408561099054558, 0.030709388931947093, 0.012354163419721382, 0.028624698652752807, 0.04591762500682047, 0.005185296759009361, 0.04956156161746808, 0.020181188692471812, 0.016550978845251457, 0.011704053081172918, 0.025522716443187425, 0.021383432305551002, 0.07243244616048676, 0.02436910173855722, 0.03568075377760189, 0.04865093030301588, 0.04445407925439732, 0.04344034454386149, 0.010420588826361512, 0.07137902732938528, 0.020663162294243063, 0.024410561924534183, 0.012528946407006254, 0.0289657812432519, 0.014038178770403777, 0.04148951904582126, 0.05674353927107794, 0.022319071028115492, 0.03952112966882331, 0.051117537410131524, 0.029586766314293658, 0.04036692696224366, 0.01944871013984084, 0.045217407401651144, 0.03481480060145259, 0.07603933475911617, 0.025881250954366157, 0.0259885137701141, 0.07140574125306946, 0.017908476359610046, 0.037101853771933486, 0.008863960791911398, 0.04557950082900269, 0.017818110762163997, 0.040358655620366335, 0.021429682948759625, 0.017815140475119864, 0.01578953872168703, 0.07247927186212369, 0.07927916983940772, 0.014386525078277503, 0.007800850784406066, 0.04507581749930978, 0.059552528363253386, 0.07869163315211024, 0.03077980051083224, 0.05584982044196554, 0.06490724174571888, 0.01917690088573311, 0.019124475573854785, 0.03325346438214183, 0.05771356275571244, 0.031060239034039632, 0.063135518958526, 0.01056713712335165, 0.06769652957362787, 0.02260801668411919, 0.03451862006581255, 0.03099274176305958, 0.018801270684759532, 0.05435714857386691, 0.021270293376541564, 0.02081244339102081, 0.0453498133325151, 0.08457121372755085, 1.2501282500369209, 8.574760590280805, 23.648383242743357, 40.18391990661621, 42.13886506216866, 34.99682910101754, 30.479634966169083, 25.980431454522268, 19.10922932624817, 22.678345237459453, 23.20243396077837, 27.71216573034014, 31.183247770581925, 20.864392927714757, 13.07621966089521, 8.446561983653478, 5.781827943665641, 2.6968247294425964, 0.9865020875419889, 0.4677205394421305, 0.12270408788962023, 0.19198696448334626, 0.18892978424472467, 0.2717043933059488, 0.36717087775468826, 0.7001813713993345, 0.7087518657956804, 2.3651848222528185, 1.6568835037095206, 1.5211377420595713, 2.433435457093375, 2.423876690013068, 1.9740008073193687, 2.5490725891930714, 2.853942607130323, 2.250788594995226, 1.2051600515842438, 2.415054431983403, 2.1031678191253116, 3.556284325463431, 2.2126584010464803, 1.0459224304982593, 4.104545397417886, 21.74644763129098, 3.3150958503995622, 1.8463539310864039, 7.454626730510166, 5.438644690173013, 2.132251024246216, 2.121970078774861, 1.2756539774792535, 0.9940543451479503, 1.4532117183719362, 0.4374311976134777, 0.26839156821370125, 0.0486960019916296, 0.11482405715755054, 0.3461182160036904, 2.092422430004392, 4.4202693700790405, 8.603624275752477, 10.776436277798243, 14.608554533549718, 15.907369136810303, 10.437860114233834, 12.044353110449654, 15.579653876168386, 37.02525840486799, 36.99562086377825, 30.981750011444092, 35.61840105056763, 21.00763872691563, 7.4047673259462625, 0.6476337739399501, 0.03606865867706282, 0.06444168529872384, 0.03164664256785597, 0.020881574235058258, 0.040935244145137925, 0.09316982661506959, 0.05199871691209929, 0.03063071279653481, 0.025490757443809083, 0.08747279231569596, 0.038668913434126546, 0.0644317108339497, 0.018644488383350626, 0.03493711332391415, 0.06798847605075155, 0.017783259507268667, 0.03691581982587065, 0.05271466635167599, 0.028339568059891462, 0.01149585987773857, 0.0015246606594051368, 0.04381670756265521, 0.04082386940717697, 0.0412831120858235, 0.0574422844552568, 0.03125638315188033, 0.030499304312148263, 0.03535390006644385, 0.02524376900068351, 0.00992295887720372, 0.05285733173202191, 0.05290548736229539, 0.07514906967324869, 0.030684201712054864, 0.03369811177253723, 0.0068690059207645905, 0.029252404613154273, 0.011079655827156134, 0.07828197441995144, 0.027211769916383282, 0.08457632988159146, 0.06205492479992764, 0.040011727450681586, 0.007128085009753704, 0.02743165088551385, 0.0591936715479408, 0.007224489568865725, 0.08374265461627926, 0.1703321843275002, 0.08140347977834088, 0.13983260520866939, 0.1548397642161165, 0.10306167975068092, 0.1116843738460115, 0.09472804157329456, 0.1750090547970363, 0.20262762850948743, 0.13508834264108113, 0.08682071337742464, 0.1647399701178074, 0.09577660209366254, 0.14982441333787783, 0.07783577657703843, 0.08949618374130555, 0.10060810390859842, 0.14234418900949614, 0.12567680408912046, 0.11292618792504072, 0.1261974847210305, 0.11683252081274986, 0.09390396757849626, 0.11087729036808014, 0.14025192627949373, 0.1262814195028373, 0.06718297355941363, 0.1890960388949939, 0.215554127735751, 0.09534756440137114, 0.05929375546319144, 0.14152154672358716, 0.1281608800802912, 0.18338816160602228, 0.13172998784908227, 0.10348125866481236, 0.1928673636700426, 0.10277765177722488, 0.12101876975170203, 0.1278818936220237, 0.1368988776313407, 0.06810762001467602, 0.19051987677812576, 0.16546627400176867, 0.19522098451852798, 0.11131293020610299, 0.16416415173028195, 0.09355173326496567, 0.11603870269443307, 0.10980720671692065, 0.07073988805391959, 0.06756450701504946, 0.13105806176151547, 0.20152754682515348, 1.290646670120103, 9.429440259933472, 27.62337122644697, 45.125041007995605, 47.27920491354806, 42.93650088991438, 41.03659241540091, 36.98916251318795, 30.455955505371094, 31.37070322036743, 30.642205442701066, 36.33575391769409, 34.47275079999651, 25.587854760033743, 15.682657446180071, 9.567950861794607, 6.246219047478267, 3.2069944739341736, 1.9945943994181496, 0.8646942494171006, 0.5963979746614183, 0.8539327383041382, 0.8444159861121858, 0.9809424430131912, 2.475597560405731, 3.761515438556671, 5.20350809608187, 8.709383675030299, 17.526834419795446, 7.719809940883091, 9.431436998503548, 3.284123169524329, 7.338010770933969, 5.172875225543976, 6.186012038162776, 4.611297930989947, 2.9367701283523013, 6.671143080507006, 5.758483733449664, 6.719694052423749, 2.5095755543027605, 2.083920657634735, 5.44056065593447, 21.518181937081472, 4.215699204376765, 6.182051130703517, 24.613081557410105, 10.685109155518667, 6.685739942959376, 5.920010677405766, 7.007746824196406, 5.134127293314252, 4.104218397821699, 4.23430517741612, 1.1790172372545515, 2.0300454114164626, 1.1660524415118354, 1.4293424848999297, 2.539453459637506, 5.3384160569735934, 7.656719429152353, 12.945517097200666, 18.303550958633423, 22.848725489207677, 15.699023927961077, 15.749198607036046, 23.069236993789673, 43.11120292118618, 41.531377111162456, 38.78091880253383, 40.26935495649065, 24.850697789873394, 8.513026714324951, 0.8893745765089989, 0.14155878472541059, 0.16562798246741295, 0.12267985061875411, 0.08679959058229413, 0.14577653125992843, 0.17334232851862907, 0.12936747819185257, 0.17872883805206843, 0.1019578186262931, 0.18345646294099943, 0.17755715735256672, 0.20423513225146703, 0.10774507772709642, 0.1337513029575348, 0.1061278437929494, 0.14588239629353794, 0.11120988787817103, 0.1140412584479366, 0.16570247204176017, 0.15825454598026617, 0.10691554831074816, 0.1003573037950056, 0.16327776786472115, 0.10639764288706438, 0.16533999863479817, 0.20614870956965856, 0.201260204027806, 0.11786169558763504, 0.08848613686859608, 0.09573503503842012, 0.18453513006014483, 0.15591377658503397, 0.1518406258629901, 0.13001433919583047, 0.08841611205467156, 0.091490533868117, 0.12392463668116502, 0.17946039379707404, 0.1708780521793025, 0.1960090079477855, 0.19795998611620494, 0.15745824442378112, 0.2142718051161085, 0.09521081245371274, 0.08854943740048579, 0.12254269155008451, 0.10120568969952208], [0.04143298690074256, 0.01927263878418931, 0.01800208365810769, 0.03997523923005376, 0.00590799847019038, 0.04741966065817645, 0.02427389988276575, 0.03193337789603642, 0.017570774569841366, 0.04369372987587537, 0.03003668592178396, 0.02084401392910097, 0.015752526332757304, 0.024036887600751858, 0.05390927814213293, 0.029034985029803853, 0.03463776402973703, 0.010380782569492502, 0.07651802085872207, 0.033328791947237084, 0.07361986887242113, 0.02987965934776834, 0.011664308740624359, 0.07256450264581613, 0.05668260343372822, 0.09505307341792754, 0.02643900504335761, 0.009835994436538644, 0.04811035502435906, 0.012583616821627532, 0.02258726877958647, 0.015441207680851221, 0.035489535823996575, 0.04406903438004, 0.024497904648472155, 0.04136567961956773, 0.11072246903287512, 0.044439324510416815, 0.034189042036554644, 0.030639723741582463, 0.014995844436011143, 0.012649677294705595, 0.04431113228201866, 0.04434014983209116, 0.0259911736273872, 0.011716728115321269, 0.05529232928529382, 0.06456715999437229, 0.03688793542927929, 0.0686551977747253, 0.016643771901726723, 0.020263674802013805, 0.005866513687318989, 0.035694253231797896, 0.03811456389459116, 0.0563181385264865, 0.5311991732035364, 4.25278217451913, 13.826982940946307, 26.27599045208522, 38.885871342250276, 40.85331283296858, 35.73884112494332, 35.29519517081124, 21.303166457584926, 24.402078662599834, 16.50601897920881, 15.968217985970632, 24.745540278298513, 23.786662817001343, 17.128852026803152, 10.913799558367048, 8.181971107210432, 6.397591199193682, 3.8665396315710883, 1.8196289879935128, 0.8748731975044522, 0.37927431400333134, 0.3059946490185601, 0.17133161212716783, 0.437786804246051, 0.5372887807232993, 1.794831627181598, 1.0380213516099113, 0.39110044656055315, 1.3886477542775018, 1.7083145039422172, 0.7242974830525262, 0.6475621206419808, 2.3945411784308295, 1.4761061412947518, 0.39257330181343214, 1.6423605744327818, 2.2245011712823595, 3.109398122344698, 1.2049411833286285, 0.5006494096347264, 0.662083204303469, 0.10977473203092813, 1.871282764843532, 1.9605408438614436, 4.177773765155247, 6.424227552754538, 1.3226815568549293, 1.5755926200321742, 0.7168873378208706, 0.7543788403272629, 0.890018316251891, 0.28891890815326143, 0.4464713739497321, 0.6912788833890642, 1.6960132611649377, 3.9355152675083707, 6.231099767344339, 8.534446273531232, 9.842607940946307, 10.947080561092921, 15.14399140221732, 19.02219271659851, 21.31612137385777, 19.12003551210676, 26.92503384181431, 31.252528258732386, 30.43868923187256, 28.922508920942033, 19.08873040335519, 7.055238195828029, 0.8068721007023538, 0.025183699991820113, 0.006958509354652571, 0.0717176366597414, 0.02674234242710684, 0.022524146363139153, 0.044605633443487544, 0.014408031245693564, 0.07996875819350992, 0.010609226650558412, 0.01794722070917487, 0.01564298872835934, 0.014644341243963157, 0.020240680946569358, 0.05674198203321014, 0.021290054012622153, 0.022279785546873297, 0.07731960141765219, 0.06397030023591858, 0.020958450556333576, 0.018321488751098514, 0.046297078752624135, 0.01755160086655191, 0.03868807865572827, 0.10454927956951515, 0.026106773942176784, 0.07030427535729748, 0.059273582617087026, 0.07354665494390897, 0.074063223653606, 0.12531099228986672, 0.011768915939943066, 0.02805532295522945, 0.08696314466318913, 0.054664273879357746, 0.05359643278643489, 0.014380513258012277, 0.01591308637788253, 0.0376367090003831, 0.009497759996780326, 0.04597539887098329, 0.06397228155817304, 0.1070045449637941, 0.04284395297457065, 0.006425067599463675, 0.06710524058767728, 0.020228631860975708, 0.0316298115067184, 0.017879204358905554, 0.02072961801396949, 0.01921211854953851, 0.04753498446994594, 0.022691583360678384, 0.05567258030974439, 0.049528496606009345, 0.024554869359625236, 0.034901195072702, 0.02521542998562966, 0.021619411517999003, 0.06772301958075591, 0.0347377325940345, 0.043622076577906094, 0.04925485021833863, 0.05942352528550795, 0.02757193291160677, 0.03589374591995563, 0.017923561889412146, 0.06048239953815937, 0.00414792146433943, 0.017576628630714755, 0.01577652950904199, 0.03777230404583471, 0.04920514413554754, 0.019713535572269132, 0.040147353030209026, 0.0064885407336987555, 0.017832794259967547, 0.02958931421328868, 0.06161934603005648, 0.06916258590562002, 0.060655507392116954, 0.015177781726898891, 0.014784865846325244, 0.026958343872268285, 0.019478904948170696, 0.02851092190082584, 0.04549899264904005, 0.011411327136946576, 0.04066279876445021, 0.018007647645260607, 0.019584658023502146, 0.01676334334271295, 0.051959212603313584, 0.019288860860147646, 0.02112010813185147, 0.02053770625830761, 0.04343660920858383, 0.02613505528175405, 0.06063922255166939, 0.01896373402061207, 0.016025489096396735, 0.03785158747008868, 0.010897939060149449, 0.017687548750213215, 0.029058475912149464, 0.8801614823085921, 6.319625028542109, 18.903602600097656, 32.1625268799918, 44.0753036907741, 44.783696855817524, 39.15833452769688, 34.30851970400129, 23.60806805746896, 25.028731482369558, 24.038635764803203, 24.053317308425903, 32.09733888081142, 23.32480910846165, 18.603089536939347, 11.530036159924098, 9.570847392082214, 8.196409463882446, 4.5896534238542825, 2.7818706801959445, 0.7346617526241711, 0.3143422582319805, 0.23204668132322176, 0.13817528342562063, 0.24000717273780278, 0.3842197486332485, 0.36369205585547854, 0.7393420700516019, 0.404299011187894, 0.6959725001028606, 1.407109117933682, 0.8147840361510004, 1.8150557705334254, 2.042777333940778, 1.791204884648323, 1.0596945200647627, 1.7013850872005736, 1.2567941780601228, 1.6222787605864661, 1.348935759493283, 1.6840085110494067, 0.9148379330124173, 1.411344587802887, 1.6274969662938799, 1.0476718566247394, 2.434097707271576, 1.6669694653579166, 1.2222404607704707, 0.8521018879754203, 0.49437475204467773, 0.44710987540228025, 0.07313179184815713, 0.11477850031639848, 0.43862677631633623, 0.7548811733722687, 2.1740492156573703, 4.367933366979871, 7.545101829937526, 11.49745692525591, 12.140417167118617, 15.354316847664968, 17.96613253865923, 20.28156934465681, 17.13265095438276, 17.155701603208268, 26.078614711761475, 35.024611473083496, 34.1338141986302, 33.17204802376883, 23.007127046585083, 8.661421128681727, 1.2264247962406702, 0.07268272380211524, 0.015689636314553872, 0.03836909595078655, 0.03297792488176908, 0.03602415695786476, 0.037426125657345564, 0.028022544624816095, 0.11425720900297165, 0.033434002194553614, 0.047147805602954965, 0.04890104848891497, 0.010310194571502507, 0.029563638448183025, 0.05642446157123361, 0.007236452141244496, 0.01578261936083436, 0.04614824888163379, 0.02295838333001094, 0.061831897124648094, 0.018649730066369687, 0.07627303579023906, 0.05030820119593825, 0.04618887955855046, 0.03722259568582688, 0.010949867345126612, 0.038831480246569426, 0.0068238137921850595, 0.05494669372481959, 0.04156079914953027, 0.060412646138242314, 0.037843865741576464, 0.011315320368989237, 0.031601411423512867, 0.036641759531838555, 0.02738075058108994, 0.035975919903389046, 0.024879548366048505, 0.06134878019137042, 0.054067821241915226, 0.013630419936297196, 0.02162764045143766, 0.04931126022711396, 0.019484316264944415, 0.02057895779476634, 0.03963458750929151, 0.04614715304757867, 0.08662525457995278, 0.03148596886811512, 0.14816850290766784, 0.05883317267788308, 0.08103129653526203, 0.14256872981786728, 0.11996961890586785, 0.2263341357133218, 0.17050917340176447, 0.14071771342839512, 0.11625784236405577, 0.13645782986921923, 0.21693794562348298, 0.13342667823391302, 0.15356536688549177, 0.23591481947473117, 0.14305677291538033, 0.12426253354975156, 0.18977656880659716, 0.06674922004874263, 0.18708773808819906, 0.16340545458453043, 0.13693900619234356, 0.13368982768484525, 0.12009718348937375, 0.16435403296990053, 0.22007243814212935, 0.1176855478967939, 0.11220637762120791, 0.08699039462953806, 0.09486028126307897, 0.09044563065149955, 0.15919741110077926, 0.11889738429869924, 0.16514607332646847, 0.13671014990125382, 0.0996486893189805, 0.07747589517384768, 0.15628921001085214, 0.12264166266790458, 0.09705004947526114, 0.13771476170846395, 0.11943367123603821, 0.11759474634059838, 0.14649642977331365, 0.1382041618760143, 0.11234001509313073, 0.07559637352824211, 0.11063866995807205, 0.14998407262776578, 0.09832387683647019, 0.21295413082199438, 0.08079072872975043, 0.0868864498500313, 0.1983487866818905, 0.13794777063386782, 0.13369754941335746, 0.1609322080122573, 0.900849309350763, 7.096349384103503, 21.171237536839076, 35.69338600976126, 51.13645567212786, 52.92514085769653, 47.429167883736746, 45.8412161554609, 30.243792261396134, 34.28685174669538, 26.145716939653667, 24.30371301514762, 36.817972796303884, 31.028685092926025, 23.85004949569702, 15.344360079084124, 10.540584019252233, 9.028173106057302, 5.602962204388209, 2.7815362981387546, 1.5410407483577728, 0.7896328600389617, 0.8330911823681423, 0.6713701231139046, 1.4612429674182619, 1.7319608522312981, 3.140674135514668, 2.24185277734484, 3.1809100678988864, 4.603869438171387, 6.725631288119724, 3.0956074680600847, 4.325174152851105, 6.517308226653507, 3.429403705256326, 5.845399618148804, 4.386502427714212, 6.915657137121473, 7.171645275184086, 4.729744740894862, 3.286902883223125, 2.8621718798364912, 1.1420251365218843, 5.666563842977796, 7.756052613258362, 10.639687044279915, 13.144015840121678, 3.0261851932321275, 4.36801370552608, 1.909977717058999, 2.3796653023787906, 1.9102445713111331, 0.93466602904456, 1.1586618380887168, 1.1064663188798087, 2.519377508333751, 5.2508440017700195, 9.271197642598834, 12.721566234316144, 15.120258092880249, 18.499325139181956, 23.711702176502772, 26.891347237995692, 28.624042102268763, 26.246983460017614, 35.30443974903652, 40.74609170641218, 39.68344463620867, 38.04438543319702, 26.242701632635935, 10.450428536960057, 1.473391892654555, 0.11774318266127791, 0.1057490584041391, 0.15856595284172467, 0.17110339365899563, 0.13464916763561113, 0.1925562553639923, 0.08307113564972367, 0.24175763023751123, 0.13106039592197963, 0.08544336871377059, 0.13046663706856115, 0.06224300113639661, 0.06800056754478387, 0.12235631155116217, 0.07432870726500239, 0.12073145088340555, 0.11830635315605573, 0.11473761179617473, 0.12546135564999922, 0.07109111135027238, 0.2195368433105094, 0.1873355119356087, 0.13269941083022527, 0.14981656947306224, 0.16362472996115685, 0.11278037753488336, 0.144845079098429, 0.20262420869299344, 0.12905029021203518, 0.22616473266056605, 0.07329788365002189, 0.10882898313658577, 0.2578123116067478, 0.17050427437892982, 0.18103551784796373, 0.20822380536368915, 0.0691168187186122, 0.12992013139384134, 0.1010117983179433, 0.12509008842919553, 0.11728770924465996, 0.23712692729064397, 0.2034484658922468, 0.08106558969510452, 0.20281807971852167, 0.09323240789983954, 0.10906796995550394, 0.12265497552497046], [0.02400063008203038, 0.06411975435912609, 0.05226445836680276, 0.06660231043185506, 0.030465404702616588, 0.02220474635916097, 0.02296717375117753, 0.044913742624755414, 0.01847919386013278, 0.001623717972376783, 0.057480004216943464, 0.05201526638120413, 0.0543463598670704, 0.028077592474541495, 0.04774395968498928, 0.13483134071741784, 0.03167598242206233, 0.056083416300160546, 0.047512117839817486, 0.07747835147061519, 0.028524614737502167, 0.06144895910152367, 0.05391450286177652, 0.06281208167118685, 0.01436331748430218, 0.0656882423375334, 0.024990643208314265, 0.05174978616248284, 0.02634716872125864, 0.04419728089123964, 0.030050036098275865, 0.08014897030911275, 0.043784260018063445, 0.0550282197073102, 0.06753508573664085, 0.060609977692365646, 0.00651128649977701, 0.01548126499567713, 0.058769899287394116, 0.018925356079957316, 0.05760706668453557, 0.0189157242753676, 0.02091237124321716, 0.019510417810774276, 0.061039592139422894, 0.04530760506168008, 0.02200571846749101, 0.045191365227635415, 0.02714820984484894, 0.01838566628949983, 0.011201010118903858, 0.01693287362078471, 0.036730864750487466, 0.04223176511004567, 0.02742339650701199, 0.0766688184812665, 0.07404447573104075, 0.20750712310629232, 2.2049671794687, 10.010018706321716, 23.35729888507298, 35.56020641326904, 40.48562805993216, 34.44302988052368, 31.140714372907365, 24.378392253603252, 18.686193466186523, 24.067178964614868, 20.552637679236277, 35.65350334984915, 31.168020793369838, 21.14277250426156, 18.878667252404348, 14.99225664138794, 9.505665472575597, 7.232392072677612, 5.947421755109515, 3.507583750145776, 2.194839311497552, 1.2617346729551042, 0.7174140981265477, 0.7136348209210804, 0.2796517754239695, 0.15706101645316395, 0.038849179832530875, 0.513486695076738, 0.9875087078128542, 0.34962559065648485, 1.6753039381333759, 1.4389934241771698, 2.419803091457912, 0.5389156362840107, 0.6606872134975025, 0.4139530988676207, 1.2877866178750992, 2.170076583112989, 0.5921052364366395, 1.0186808237007685, 1.1373358624322074, 0.5062686566795621, 0.4909413648503167, 1.8102395832538605, 1.1420316504580634, 1.132883478488241, 0.976681894489697, 0.49841436956609997, 0.4442145936191082, 1.2877168101923806, 1.2856493954147612, 2.6960817064557756, 4.680148933615003, 7.388967990875244, 12.14242172241211, 16.133032730647496, 14.122311779430934, 15.233044726508004, 13.204061303819929, 13.455671208245413, 15.200362137385778, 24.28215101787022, 27.958687816347393, 30.989264488220215, 30.191718987056188, 26.749617883137294, 17.087185416902813, 6.53039733001164, 0.7960687375494412, 0.028793362102338245, 0.055438336450606585, 0.010135919637312847, 0.06952289478587252, 0.046217123578701697, 0.008164872099379343, 0.020728915730225186, 0.009875593740226967, 0.04683521809056401, 0.040463027876934836, 0.023485798421981077, 0.08488653573606696, 0.04818002021472369, 0.057084302950118265, 0.016763373876788785, 0.01694865125630583, 0.05098259375829782, 0.0535614848402994, 0.0546966264290469, 0.04891024263841765, 0.06922228341656071, 0.04700374583314572, 0.02318182660798941, 0.0029244140480711523, 0.08032206459236996, 0.04086169773446662, 0.02872697084343859, 0.035470384173095226, 0.03508317816470351, 0.04325391026213765, 0.01155357267374971, 0.038158098701387644, 0.02012301279631044, 0.014566167224464672, 0.01908847759477794, 0.04610662075823971, 0.04985499408628259, 0.04095938642110143, 0.06040558258869818, 0.10259017933692251, 0.07204881603164331, 0.036619032001388926, 0.015997932092951875, 0.031074383096503358, 0.028993424759911637, 0.048041938338428736, 0.06669436727783509, 0.008782984422785895, 0.01549864567017981, 0.03751976688259414, 0.04725740257916706, 0.027661399450153112, 0.007374539954720863, 0.022072057139926722, 0.039840102195739746, 0.017709587567618916, 0.03094455220603517, 0.056832105054387023, 0.014042771604311253, 0.01031513515460704, 0.06819040128695113, 0.0359661015016692, 0.025461734804723943, 0.1655395422130823, 0.06701857130974531, 0.03037018927612475, 0.06009739876857825, 0.049949195102921555, 0.03690686994897468, 0.012296316613044058, 0.04423728731593915, 0.061404019727238586, 0.01832675079016813, 0.05690507131761738, 0.019238874881661365, 0.021267165330105593, 0.04187027218618563, 0.006006766875673617, 0.021843901436243738, 0.039061076140829494, 0.03544601458790047, 0.044722595917327065, 0.049077121540904045, 0.03895575054255979, 0.07726842630654573, 0.05206458909170968, 0.02255166943983308, 0.06455498029078756, 0.07301701764975276, 0.07640526869467326, 0.029434055222996643, 0.048377643538905044, 0.01603464423013585, 0.10160721958215747, 0.058411218891186376, 0.05975983438215085, 0.03361186657899192, 0.041625124269298146, 0.06297169346362352, 0.06209446303546429, 0.03358260475631271, 0.004769321289911334, 0.07767452272985663, 0.11213671921619348, 0.02114849125168153, 0.01791062731561916, 0.556261705500739, 3.990693083831242, 13.923667124339513, 29.482134205954416, 39.97560943875994, 43.95165702274868, 39.36425828933716, 32.41190814971924, 26.034476280212402, 17.585168021065847, 21.553928681782313, 31.637448038373673, 42.419037273951936, 32.90677274976458, 24.768966129847936, 25.2833343233381, 18.078043699264526, 12.395512461662292, 8.104646342141287, 5.859156617096492, 4.195968057428088, 2.141405927283423, 0.9281222373247147, 0.7116346625345094, 0.12062337382563523, 0.1916431507893971, 0.10604528643723045, 0.17069518699177674, 0.08307646214962006, 0.49657781954322544, 0.10662307257630996, 0.627077474125794, 0.32677752524614334, 0.5175970973713058, 0.4207891220492976, 0.7260430551001004, 0.6282433058534349, 0.9245379439422062, 0.4934840255549976, 0.23451025198612893, 0.5145886902298246, 0.572649628988334, 0.6233799468193735, 0.13257586317402975, 0.2342603611094611, 0.3648918957582542, 0.4180554673075676, 0.06700688693672419, 0.2121486554720572, 0.3950875183301312, 0.9928810766765049, 1.178325348666736, 2.335924438067845, 5.5224573356764655, 8.056939142090933, 15.651194265910558, 18.689318418502808, 15.286483321871076, 15.220002957752772, 14.926189695085798, 14.930865832737513, 16.526773248400005, 24.484265429633005, 29.33697244099208, 34.31190695081438, 35.714699608939036, 30.371694701058523, 20.3768812588283, 8.599713308470589, 0.9667657294443676, 0.045646631691072664, 0.03251437350575413, 0.03508877607860735, 0.05485834846539157, 0.09096253184335572, 0.03533101647293993, 0.026553816561188017, 0.011708600962135409, 0.00631482304639316, 0.00894135788881353, 0.021511241161663617, 0.011732360713982155, 0.05091751207198415, 0.048636426616992266, 0.05602166282811335, 0.01959602178872696, 0.0515304191836289, 0.02763783392895545, 0.018386751945529665, 0.015118771232664585, 0.03456576807158334, 0.04181806230917573, 0.011608682439795561, 0.009733135313061731, 0.01579665994670774, 0.0233384664170444, 0.009773950042602206, 0.032604024945093055, 0.07009384129196405, 0.0805112605116197, 0.078572170276727, 0.037697519308754375, 0.012407149371158863, 0.031762685626745224, 0.014281816946874772, 0.04419848868357284, 0.04064260556229523, 0.05178651526304228, 0.029337231668510606, 0.03093827236443758, 0.056092355999031236, 0.01312387064431927, 0.020430202562628046, 0.025384215571518456, 0.0156373619767172, 0.04392414001215782, 0.06418796069920063, 0.029805224056222608, 0.04137860231899789, 0.10658799231584583, 0.16879874946815626, 0.19119740756494658, 0.20512839646211692, 0.10376783114458833, 0.1409172434359789, 0.11192678048142365, 0.11671632847615651, 0.1305033051009689, 0.04880888307733195, 0.1019397017412952, 0.17251284659973212, 0.10773246376109974, 0.09741195291280746, 0.19248262074376854, 0.25523138152701513, 0.17984428176922457, 0.15328378842345305, 0.19211195063378128, 0.24590869035039628, 0.11908615274088723, 0.1905584039964846, 0.23198110769901956, 0.1729911866464785, 0.18557252867945603, 0.1695666882608618, 0.1274912202996867, 0.11961209880454199, 0.09940913253064666, 0.13501789713544504, 0.10327880417129823, 0.1999659120504345, 0.17095493019691535, 0.14973146761102335, 0.10906079105500664, 0.16848538842584404, 0.10302881829972778, 0.12600509290184292, 0.23765987583569118, 0.14534464372055872, 0.17673028100814137, 0.11769810079463891, 0.12808967461543425, 0.07789579299943787, 0.2387675435415336, 0.08603634046656744, 0.09267397357949189, 0.061836945425186834, 0.1843439188918897, 0.17767455748149327, 0.0815862567563142, 0.10482363841895546, 0.148700867912599, 0.09574773721396923, 0.2132889200001955, 0.18372228581990513, 0.1388174896793706, 0.5475071924073356, 3.8979428836277554, 15.180113349642072, 32.55955042157854, 46.464278493608745, 51.75122880935669, 48.108517578669954, 41.56914751870291, 35.56949268068586, 25.94727291379656, 33.54061869212559, 31.2435233933585, 47.58450528553554, 40.66839000156948, 31.035188606807164, 25.85857742173331, 20.861856835229055, 13.777443153517586, 10.090801068714686, 9.14892063822065, 4.956094903605325, 3.579678475856781, 1.9006174079009464, 1.2183872503893716, 0.9422647527285984, 1.2073045479399818, 0.7512068791048867, 0.6278537724699292, 1.9206490644386836, 2.521920766149248, 1.9166110754013062, 5.234051074300494, 3.915199169090816, 5.090250287737165, 1.0262711878333772, 2.6089921167918613, 1.5355903208255768, 4.750493364674704, 4.725187156881605, 4.305187225341797, 1.5109612366982867, 4.631243169307709, 3.4572666329996924, 2.241390287876129, 4.16800286088671, 2.9016200602054596, 2.391113110951015, 2.3362360213484084, 1.1930367478302546, 0.9697055774075645, 2.2756032177380154, 1.9137718677520752, 3.6031679468495503, 6.313724270888737, 9.669896568570818, 17.19238461766924, 23.56078209195818, 20.53621734891619, 23.318505355290004, 19.542861189161027, 20.298088686806814, 22.84088271004813, 32.60065943854195, 36.905721596309114, 41.91949306215559, 39.93680722372872, 35.216531140463694, 23.08775568008423, 9.62505202633994, 1.4953068367072513, 0.16714150910930975, 0.10117168152438742, 0.15765402891806193, 0.16212585967566284, 0.2171476265149457, 0.09587395151278802, 0.15651084668934345, 0.05267292966267892, 0.07675495171653372, 0.07430924009531736, 0.25385308691433495, 0.09866072876112801, 0.12403223876442228, 0.13427617693586008, 0.10533396460648094, 0.10165118186601571, 0.1279213029359068, 0.1273333794836487, 0.1567979348557336, 0.16269202929522308, 0.11302285880914756, 0.08179006153451544, 0.10171270463615656, 0.08381223838244166, 0.12086890850748334, 0.09813079969691378, 0.13754890060850553, 0.1239059633974518, 0.1629452449934823, 0.15093976206013135, 0.14009971730411053, 0.12955254183283874, 0.1407740589763437, 0.10298430640250444, 0.13451977100755486, 0.14238457541380609, 0.1696493202554328, 0.1494690374072109, 0.20576536442552293, 0.15146743160273346, 0.15143731821860584, 0.13265916013291904, 0.07933356799185276, 0.14481374435126781, 0.07756906481725828, 0.10160677174904517, 0.15017457811960153, 0.0650272678051676, 0.11368812168283121], [0.06262445995318038, 0.05113706225529313, 0.06073666696569749, 0.02626787681531693, 0.006246359711180308, 0.02749567066452333, 0.0668951797166041, 0.07453821173736028, 0.035831639609698734, 0.01938145883780505, 0.009966393600084951, 0.002624912719641413, 0.03399658914921539, 0.031368103942700794, 0.040275368839502335, 0.00859094544180802, 0.08004524944616215, 0.0033938557441745487, 0.019880770705640316, 0.06752884999981948, 0.027005590265616775, 0.0987220818975142, 0.02054317355422037, 0.03181763678523047, 0.05379497213289142, 0.05002846834915025, 0.055621015041002204, 0.03578443732112646, 0.0041128730102043065, 0.0608446490285652, 0.01672015119610088, 0.007575686571986547, 0.08556601391839129, 0.05636803459908281, 0.05473882791453174, 0.03171277937612363, 0.057347113133541176, 0.046312366146594286, 0.01726771877812488, 0.009974034752563705, 0.041241728235036135, 0.0308967426286212, 0.027342145331203938, 0.03561047112037029, 0.027451068861410022, 0.019484385814783827, 0.03212739480659366, 0.03466144150921276, 0.01707759835491223, 0.022967881123934473, 0.043270792213401625, 0.025952634534665515, 0.056944952213338444, 0.06884403407041516, 0.014259394757183535, 0.012569180140937013, 0.0373630558273622, 0.012934006368076163, 0.10881622667823519, 1.5205957825694765, 7.259242951869965, 18.297238520213536, 28.4357077053615, 38.31224543707711, 37.671684060777935, 38.612324237823486, 34.179415225982666, 24.455897671835764, 20.435796771730693, 17.505972453526088, 43.60112040383475, 22.756809507097515, 18.411753518240793, 24.70188648360116, 16.45418541772025, 18.116088560649327, 12.40681196962084, 8.90292227268219, 10.664005739348275, 8.262335709163121, 5.813289386885507, 3.670803666114807, 2.009935370513371, 1.4166305384465625, 0.8791209352867944, 0.3603585490158626, 0.5636749991348812, 0.22363446200532572, 0.33679172503096716, 0.36061975785664147, 0.344232295772859, 0.3003428322928292, 0.8452822853411947, 0.4131830973284585, 0.457426728946822, 0.3032927225743021, 0.5555244907736778, 0.9208370511020932, 0.13411137435053075, 0.5027515111224992, 0.24126824364066124, 0.45227862947753494, 0.06900252628007106, 1.0081990318638938, 1.3903388806751795, 1.5208443978003092, 3.1792483627796173, 4.7595681462969095, 6.0100919008255005, 9.017899325915746, 9.886144484792437, 13.878181610788618, 14.064838017736163, 15.014648948396955, 19.028067418507167, 19.965598276683263, 19.200467858995708, 23.19605725152152, 30.24010624204363, 32.419853414808, 33.29998173032488, 25.467454637799943, 18.78824165889195, 13.879588621003286, 3.8008157525743758, 0.4511885493993759, 0.024124394869431853, 0.04617139371111989, 0.1078243577586753, 0.024222687452233264, 0.03232245666107961, 0.012659763717757804, 0.042907321359962225, 0.017818148081590022, 0.03125323135671871, 0.037324118095317056, 0.04422281077131629, 0.06259503867477179, 0.023698905915287987, 0.07390439896179096, 0.021317326031359177, 0.003950521208545459, 0.03164408449083567, 0.012150553720338004, 0.020812960773972527, 0.06364024044679743, 0.026340907539374063, 0.059410890963460715, 0.042172529002917666, 0.030500128732195923, 0.023353594355285168, 0.0642964652340327, 0.026040450536778996, 0.03934435433308993, 0.0061512316460721195, 0.02667390538512596, 0.033750084162290604, 0.024404522962868214, 0.02782347093203238, 0.025365851021238735, 0.07689627699021782, 0.0471553203782865, 0.021632522510896837, 0.01827932967405234, 0.011642582049327237, 0.025931404870269553, 0.029990538755165677, 0.01653097732923925, 0.044774619197206836, 0.027090222242155244, 0.027806936729965464, 0.021424385286601524, 0.026786925570507134, 0.007338039011561445, 0.007510234235918948, 0.029859062417277267, 0.023121099420157925, 0.029600350585367, 0.03463335015944072, 0.03745594048606498, 0.010607988324149378, 0.0706827011225479, 0.07350486397211041, 0.046313394127147536, 0.021416208939626813, 0.054188766716314216, 0.003555945461682443, 0.018450659766261066, 0.028686832104410444, 0.044665629509836435, 0.07487467011170727, 0.01681776694022119, 0.06504290803734745, 0.024685529759153724, 0.03976439465103405, 0.028048301814123988, 0.043589004781097174, 0.07881685000445161, 0.019871985373486365, 0.04059447028807231, 0.07291983786438193, 0.01695161306166223, 0.06167375775320189, 0.0628861098417214, 0.05203405162319541, 0.00289797832374461, 0.05185237726462739, 0.038500613000776084, 0.05763333277510745, 0.04380969829591257, 0.006447233218100986, 0.024312544148415327, 0.0216563356973763, 0.010017428763343819, 0.05569482268765569, 0.06857331216867481, 0.07036770481084074, 0.007318934009942625, 0.06432602900479521, 0.020194040145725012, 0.04761597780244691, 0.017668782167934945, 0.05817122105509043, 0.06913046405783721, 0.0450400112063757, 0.04370859318545886, 0.030293033059154238, 0.04154086039800729, 0.021388847014999816, 0.022782079576115524, 0.054431451551084004, 0.04167638758995703, 0.03157673989023481, 0.01567057965855513, 0.18800601309963635, 2.2657695625509535, 10.507040722029549, 24.37108622278486, 36.05993822642735, 43.004568917410715, 42.00000878742763, 39.66879088538033, 31.37836708341326, 26.2764664036887, 20.798270395823888, 27.6026325907026, 45.10263654163906, 29.82453795841762, 25.619715724672588, 28.66939299447196, 19.24061107635498, 19.593628202165874, 17.388580901282175, 12.319196053913661, 11.457709755216326, 8.56257518700191, 6.007194936275482, 3.420019728796823, 2.0105733019965033, 1.3011297647442137, 0.7311110060129846, 0.38392952563507216, 0.24427447947008268, 0.06271112923111234, 0.2032371565167393, 0.17585676216653415, 0.11068126160119261, 0.12167754583060741, 0.15337088517844677, 0.05127606354653835, 0.21064097780202115, 0.024211050576663444, 0.30636575339095934, 0.2686051167547703, 0.276641278394631, 0.19692660442420415, 0.2099361020539488, 0.16521518890346798, 0.21260708730135644, 0.7074667204703603, 1.1448223292827606, 1.6127109825611115, 3.288155947412763, 5.650277699742999, 9.322428447859627, 10.718351074627467, 12.852556279727391, 18.231492928096227, 20.476615701402935, 19.87341478892735, 22.412435940333776, 19.113644906452723, 19.23124143055507, 23.522507940019878, 30.22536563873291, 35.712580408368794, 37.126854964665, 29.482095990862163, 24.40846926825387, 17.565700905663626, 5.5859643050602505, 0.6579419693776539, 0.023823995542313372, 0.05014304916507431, 0.031682079059204886, 0.023555290585915958, 0.0519901775488896, 0.04470180221168058, 0.06746894214302301, 0.02543021515677018, 0.04028611004884754, 0.016169962772567357, 0.02078448944459004, 0.024646931294617907, 0.0493646575404065, 0.020136612334421704, 0.022908957142915045, 0.06935786828398705, 0.03686156416577952, 0.012199978211096354, 0.03964792750775814, 0.08441164264721529, 0.06180622135954244, 0.05657432960080249, 0.04789459445912923, 0.049723188658910136, 0.07957900767879826, 0.024326170827927332, 0.035279094973312955, 0.027906189439818263, 0.010296186216042509, 0.025617850445477024, 0.012700370645948818, 0.030491602939686606, 0.016617237789822475, 0.01957906180593584, 0.028913652790444236, 0.03571514532502208, 0.032070689635085206, 0.03549793948020254, 0.01838014131811048, 0.03360151552728244, 0.022662771067449024, 0.02882469006414924, 0.01904128209155585, 0.02404374080444021, 0.028132718355794038, 0.04073936804862959, 0.035067381869469366, 0.06855116478566613, 0.010550300125032663, 0.012895437589447414, 0.1314017940312624, 0.22247445210814476, 0.11630092933773994, 0.07919465830283505, 0.1037257823294827, 0.11284900456666946, 0.14721706110451901, 0.1849866272615535, 0.09784529930246727, 0.20257809545312608, 0.04623468406498432, 0.06637986629669156, 0.10608424113265105, 0.1258615827453988, 0.17816751317254134, 0.09230968169867992, 0.21878662785249098, 0.12026847286948136, 0.13826413080096245, 0.11347244254180364, 0.07263010341141905, 0.136160550106849, 0.14914491479950293, 0.17751535959541798, 0.2089659869670868, 0.06933044868388347, 0.16400316251175745, 0.23893856150763376, 0.10112478118389845, 0.25366051867604256, 0.16668128594756126, 0.09569392938699041, 0.19770417841417448, 0.20871353122804845, 0.11772121169737407, 0.054409324524125884, 0.11486958685730185, 0.14913100483162062, 0.17207582933562143, 0.18483817737017358, 0.14277520802404198, 0.07867101247289351, 0.13178619769002708, 0.08789429826928036, 0.1365047980632101, 0.10496581864676305, 0.17515256495348044, 0.098009097655969, 0.14012308605015278, 0.1433617744062628, 0.10332491062581539, 0.11541548185050488, 0.12152095351900373, 0.09909917094877788, 0.16196210203426226, 0.18874184361525945, 0.09846231833632503, 0.085840169207326, 0.3286106011697224, 2.3002919043813432, 10.794268829481942, 26.699882677623204, 39.92462355749947, 50.903593744550435, 49.071075848170686, 50.66629886627197, 45.10276855741228, 34.66822099685669, 28.865469421659196, 29.884636402130127, 52.70860719680786, 33.75198636736189, 27.031627893447876, 33.73181574685233, 25.490218673433574, 24.006790433611187, 19.464852026530675, 12.934313126972743, 13.773694600377764, 11.075777700969152, 7.477850215775626, 5.363497751099723, 2.701236835547856, 2.1721388953072682, 1.3812687673739024, 0.8840469909565789, 1.1302668303251266, 0.9000334388443402, 0.7655449754425457, 1.0255572604281562, 1.0219967429127013, 1.4671892140592848, 1.8665903423513686, 1.2807323506900241, 0.7065015722598348, 0.6555650340659278, 1.649706231696265, 1.6123873484986169, 1.3650359298501695, 1.087133064866066, 0.702907073710646, 0.7744501233100891, 0.451313101287399, 1.5924777196986335, 2.167473179953439, 2.3090826783861433, 4.608851296561105, 6.614877436842237, 8.909097484179906, 12.162296175956726, 14.88973423412868, 19.6706211907523, 22.20344454901559, 22.857541016169957, 28.26268540109907, 29.439531326293945, 27.21321211542402, 33.04959644590105, 38.461381571633474, 43.43663569859096, 43.08021395547049, 34.1219744682312, 27.939526421683176, 18.520407710756572, 6.194659939834049, 0.8103747527514185, 0.15939894957201822, 0.11258495266416244, 0.20511421508022717, 0.1426617841103247, 0.1503095251641103, 0.17004358981336865, 0.13389117616627896, 0.0807013792384948, 0.08727154561451503, 0.10763336372162614, 0.12249519409877913, 0.10841381470007555, 0.1299370133451053, 0.13531856957290853, 0.07344790095729486, 0.1678183749318123, 0.14344474566834314, 0.15779577488345758, 0.1063049617888672, 0.1360421728874956, 0.18948234245181084, 0.11554434922124658, 0.109938862866589, 0.14887848123908043, 0.1386176339749779, 0.11096961184271745, 0.13178030800606522, 0.12801447936466762, 0.08525679193969284, 0.1001431310017194, 0.10508323913174016, 0.11405473415340696, 0.06254178046115808, 0.10760202218911477, 0.16280196553894452, 0.11739950467433248, 0.16323089466563293, 0.10708545347941772, 0.06849229508744818, 0.12004184217325278, 0.10533477884850331, 0.10512012429535389, 0.10213209356048278, 0.0993806951280151, 0.08409499071006264, 0.09348101634532213, 0.19380937383643218, 0.10578510218432971, 0.07883928237216813, 0.055115872861019204], [0.043632875462727885, 0.02580267490286912, 0.028422848055405275, 0.018635161919519305, 0.026883070589974523, 0.04102579803605165, 0.030082802554326396, 0.03398647219208734, 0.02028714193563376, 0.05326132808945008, 0.01104600218656872, 0.02666244492866099, 0.025042296686608876, 0.018656520505568812, 0.01572024163657001, 0.08749970301453557, 0.01542776420579425, 0.09004400577396154, 0.04384694986843637, 0.02001418935001961, 0.04893108384151544, 0.04060631750949791, 0.024190224640603577, 0.05355977153937731, 0.010696531206901585, 0.017112310510128736, 0.0017051871275595787, 0.052013651467859745, 0.024229815462604165, 0.0242320580208408, 0.013725603132375648, 0.035323023330420256, 0.030906316757734333, 0.03528618227158274, 0.037807764285909276, 0.033472261391580105, 0.03146417432331613, 0.030755434318312576, 0.0813395074967827, 0.016781031054311564, 0.06956846519772496, 0.03460858702393515, 0.033424950537404845, 0.048820679408631155, 0.02823375561274588, 0.005919737974181771, 0.030548213116292442, 0.013432976423895784, 0.03125109397140997, 0.022139944568542496, 0.025452136926885163, 0.11831070935087544, 0.054157241979347806, 0.015971776264320527, 0.034429921968174834, 0.047999109208051643, 0.010118336250473346, 0.07965538358049733, 0.011918943425241326, 0.10903282862688814, 0.7690714576414653, 3.3906894283635274, 12.850008027894155, 25.02113015311105, 35.16170290538243, 40.74391344615391, 39.41836738586426, 31.780765056610107, 33.023349625723704, 22.99310037067958, 48.79950203214373, 27.717281341552734, 24.037775925227574, 27.426454067230225, 22.05664300918579, 19.582622255597794, 15.471446105412074, 18.65357862200056, 14.85995078086853, 15.366788864135742, 16.797726937702723, 13.297326104981558, 10.070493221282959, 6.994447103568485, 5.578903632504599, 4.275709927082062, 3.826966166496277, 3.1071979318346297, 1.9252528973988123, 1.913519561290741, 1.7833612369639533, 1.3293988364083427, 1.3949825572116035, 1.7754724259887422, 1.198778782572065, 1.4037596519504274, 1.3042060796703612, 1.3640767527478082, 1.4043328783341815, 1.639119022658893, 1.6165269549403871, 2.449914412839072, 3.387451784951346, 4.905256237302508, 6.804876361574445, 9.694856234959193, 9.476100887571063, 12.271553993225098, 12.839066352163043, 12.201889617102486, 17.088953733444214, 13.481996195656912, 18.335794074194773, 16.434824262346538, 15.51209306716919, 22.189167737960815, 28.598047154290335, 30.47351360321045, 32.83889927182879, 28.200391326631816, 20.59393777166094, 13.826144814491272, 5.342253633907863, 2.1642487815448215, 0.4111240692436695, 0.0319486483266311, 0.013156403005788369, 0.017717297421768308, 0.05959174768733127, 0.022822175906705003, 0.029026479593345096, 0.022105413921443478, 0.026063987220238363, 0.05337896231295807, 0.03094520020697798, 0.0601097277498671, 0.04192988148757389, 0.022181062094335045, 0.0468577149191073, 0.014427590017606105, 0.07629951901201691, 0.0353375609431948, 0.004966172780508974, 0.03392774159354823, 0.01300389801950327, 0.02267075572828097, 0.06765119664903198, 0.028620081221950904, 0.008820275011073266, 0.06803889120263712, 0.05715958641043731, 0.06653223133512906, 0.0715460894363267, 0.015087207479934608, 0.029021692528788532, 0.02280858315394393, 0.05154571336294923, 0.03849338999550257, 0.0511621816216835, 0.048463118595204184, 0.09814974439463445, 0.012084054744004138, 0.0032422773822742912, 0.011593478166365197, 0.050684910267591476, 0.03655810973473957, 0.10940532399607555, 0.052199027234954495, 0.043092530885977406, 0.042350342497229576, 0.017063045475099767, 0.01464840566872486, 0.02653220352450652, 0.04354195516290409, 0.06485217184360538, 0.040231335309467146, 0.02764475328980812, 0.09370340619768415, 0.025101486992623125, 0.03864661677341376, 0.06036658039582627, 0.05211410518469555, 0.034639708032565455, 0.03466623875179461, 0.028436678295422877, 0.03470902717007058, 0.016174827868651067, 0.05460995715111494, 0.04511602409183979, 0.01771301756213818, 0.03243002821026104, 0.02272043127699622, 0.017415040605036274, 0.03165868317176189, 0.06556651315518788, 0.059523514205855985, 0.0057318444180834505, 0.023773931532299945, 0.04553404916077852, 0.07300753851554223, 0.01977680217740791, 0.031347917525896, 0.03830863848062498, 0.0723511033824512, 0.01609381757277463, 0.02584287810272404, 0.02895658030839903, 0.011117135557079954, 0.06987039292497293, 0.018131527783615247, 0.007682701722452683, 0.02505957388452121, 0.02308843474436019, 0.06559514733297483, 0.03839409996622375, 0.014726688253826328, 0.009743780679335552, 0.03368516193170633, 0.014643961264352714, 0.07898129296622106, 0.013062341936997004, 0.04071832328502621, 0.05110733224345105, 0.026277418714016676, 0.07647416035511664, 0.05257435209516968, 0.03102198662236333, 0.0940216119800295, 0.03707871572779758, 0.05029690358787775, 0.02771380610231842, 0.043471899814903736, 0.05257344625091978, 0.08986061132912125, 0.04237338893913797, 0.09018296296043055, 1.3392588730369295, 5.693954510348184, 16.416640826633998, 30.21026372909546, 40.447465079171316, 46.66830539703369, 42.60728481837681, 33.45927960532052, 30.45580264500209, 25.98664835521153, 52.70036315917969, 30.35810055051531, 20.845907245363506, 31.899360384259904, 24.664585079465592, 26.10682613509042, 25.451004777635845, 20.05885352407183, 20.44560067994254, 20.355902910232544, 16.806566783360072, 13.688977820532662, 10.481612920761108, 7.03321110350745, 6.0124838181904385, 4.907340696879795, 3.675776404993875, 2.9778092290673936, 1.9636929375784737, 1.750691675714084, 1.3955882447106498, 1.1058936353240694, 1.3026361124856132, 1.1767662380422865, 1.6969231494835444, 1.395433864423207, 1.5060527686561858, 1.2451373807021549, 0.8121773760233606, 1.0564703387873513, 1.1113921574183871, 1.8839836376053947, 2.959891127688544, 4.676050364971161, 7.95665579182761, 10.08860717500959, 11.663226178714208, 14.782351561955043, 17.02325677871704, 17.905603306634085, 18.961816344942363, 17.290592193603516, 17.08191520827157, 16.615484373910085, 19.26994637080601, 26.806561844689504, 30.409649235861643, 34.467230456215994, 37.067357540130615, 33.11155700683594, 26.706169060298375, 17.46034015927996, 8.297334653990609, 3.5088887086936404, 0.479513695197446, 0.027860283153131604, 0.04376000239114676, 0.03192371216469577, 0.010436179864752506, 0.02618557051755488, 0.014211538530487035, 0.01789188787474164, 0.02494064874814025, 0.035279424062797, 0.03749983152374625, 0.012629312762458409, 0.032269381651920934, 0.07979473431727716, 0.048630363906600645, 0.0201751955319196, 0.04805118337805782, 0.04743672242122037, 0.041564809291490486, 0.023172386489542465, 0.02502851394404258, 0.0306760016163545, 0.012751985108479857, 0.0481352335108178, 0.043773746117949486, 0.03863382638831224, 0.011507338993916554, 0.09137233306786843, 0.005435735128620374, 0.055768671046410284, 0.016730500551472818, 0.004973512833073203, 0.033525129447558095, 0.04490205825173429, 0.030917237778859477, 0.03901371778920293, 0.012370036050145115, 0.01649281651979046, 0.04625218687579036, 0.03482972497918776, 0.05214902598943029, 0.033675784577748606, 0.06897324070866619, 0.006163557234685868, 0.045485883352479765, 0.07920476847461291, 0.017073995333963206, 0.02999331396339195, 0.030070680526218245, 0.04343102825805545, 0.016913945886439512, 0.031543620595974584, 0.10735742388559238, 0.18027523293026856, 0.12991873361170292, 0.09655851870775223, 0.14743792425308908, 0.15832348513816083, 0.12223722865538937, 0.11816567927598953, 0.12594211128141197, 0.1447001983012472, 0.1402676004384245, 0.1468727181532553, 0.11122159260724272, 0.11758532827453953, 0.09883902740797826, 0.12475818981017385, 0.11511305879269328, 0.12222212446587426, 0.18335677257605962, 0.14700879156589508, 0.10137985606810876, 0.1594076348202569, 0.1214274378227336, 0.118863973234381, 0.11430149019828864, 0.07862196117639542, 0.08358469844928809, 0.14658267157418386, 0.10748339391180448, 0.09750122776521103, 0.09643210084842783, 0.09630912994699818, 0.13760325126349926, 0.1493273592953171, 0.15898660384118557, 0.10056436554129634, 0.10693871349628482, 0.16753556153603963, 0.2146017359835761, 0.09345947285848004, 0.12533144333532878, 0.22785423057419912, 0.11826836876571178, 0.1990212555974722, 0.09618870355188847, 0.2517650718135493, 0.18270210841936724, 0.1280680564897401, 0.12198233019028391, 0.12435551998870713, 0.15493010436849936, 0.19303494824894837, 0.18633380425827845, 0.15749097695308073, 0.13333788514137268, 0.14466099254786968, 0.07776712240385157, 0.21995961133922848, 0.1731982891048704, 0.1681436374783516, 1.2970512807369232, 6.199756443500519, 18.432940312794276, 32.162116936274934, 47.106635979243684, 54.12921503611973, 51.04753262656075, 42.58529724393572, 42.89121947969709, 33.346840381622314, 57.69173015866961, 35.82285526820591, 34.241771834237234, 41.11450604030064, 33.71218013763428, 30.634826455797466, 27.62071875163487, 26.771685361862183, 23.491581508091517, 23.14609796660287, 22.096715007509502, 16.857799325670513, 13.615332995142255, 9.6409729548863, 7.919222371918814, 6.127313656466348, 5.856348242078509, 4.175772683961051, 3.6956365278788974, 2.8351581522396634, 3.041920474597386, 2.6420082194464545, 2.3589145072868893, 2.3152153321674893, 2.169516601732799, 2.0775641415800368, 1.8637980350426264, 2.2243934742041995, 1.81602743268013, 2.119168217693056, 2.605795294046402, 3.5908826632159094, 4.590030797890254, 6.354304356234414, 8.868989876338414, 13.006709013666425, 14.482920680727277, 17.05897225652422, 18.142014026641846, 19.779728753226145, 25.670237813677105, 20.66915202140808, 26.187025717326573, 24.09499260357448, 25.40952055794852, 32.73003837040493, 38.065518379211426, 39.65872989382063, 42.445235456739155, 37.117829254695344, 29.758863585335867, 19.228547266551427, 9.031634177480425, 3.67205434186118, 0.6646654371704374, 0.12474402199898448, 0.09359811113349029, 0.24236111928309712, 0.15942921223384993, 0.08681539366287844, 0.1423462110438517, 0.13294231279620103, 0.11555540934205055, 0.15329015308192798, 0.10161050369164773, 0.17498409827905043, 0.10716250791613545, 0.10514619361077036, 0.07561719098261424, 0.13002181665173598, 0.186906243541411, 0.1344846093228885, 0.0962607232587678, 0.09357035226587739, 0.08386792575142213, 0.13153640180826187, 0.1467255303370101, 0.09504541275756699, 0.11954774654337338, 0.14051059739930288, 0.07028387859463692, 0.2744941221816199, 0.15632469739232743, 0.17172491816537722, 0.10077294720602886, 0.09857909421303443, 0.09886371251195669, 0.11083786748349667, 0.12968831669007028, 0.0766148003084319, 0.2275149223527738, 0.10990826772259814, 0.128496130662305, 0.09033488016575575, 0.14501739985176496, 0.10611090755888394, 0.18060737582189695, 0.12277389557233878, 0.1028953165348087, 0.13358062425894396, 0.10631089897028037, 0.10152842131044183, 0.08638503282730069, 0.17574641880180153, 0.24825224173920496, 0.15614236146211624], [0.043029763004077334, 0.036559500731527805, 0.024143193682123507, 0.041743352210947444, 0.02795625344983169, 0.039735539949366024, 0.03149679150166256, 0.044387318193912506, 0.040703096959207735, 0.042392398097685406, 0.03217483458242246, 0.028490538708865643, 0.06821970721440655, 0.04151298278676612, 0.045375570521823, 0.039376340473869016, 0.04405840512897287, 0.047710962527032406, 0.013216047930265111, 0.04970459679939917, 0.06684342785073177, 0.030632799291717153, 0.01041205455216446, 0.021564333134197762, 0.030321121016251187, 0.027678437464471375, 0.02694668324797281, 0.032669072704655785, 0.020061568057696735, 0.048585634878171344, 0.036184094447110376, 0.005766611280185836, 0.07556497771292925, 0.0725603432261518, 0.043227515249912224, 0.07325058975922209, 0.04216658164347921, 0.08473859474595104, 0.024386950602222766, 0.053197895243231735, 0.03594249866104551, 0.030493529979139566, 0.006243794424725431, 0.013170056826701122, 0.04320167663640209, 0.0158306935669056, 0.02851297107658216, 0.0035748524158926947, 0.038362032401242425, 0.03967632759096367, 0.05825445016047784, 0.020825936059866632, 0.05054655358461397, 0.020749906211027076, 0.05498624213838151, 0.030565020428704362, 0.010062476703231888, 0.015103285367201482, 0.10713766674910273, 0.024105300894007087, 0.08418705434139286, 0.30718664505652016, 3.186457118817738, 9.576600500515529, 18.047344820840017, 32.545508112226216, 43.23628091812134, 37.73067774091448, 39.35565641948155, 32.467729977199006, 43.41030202593122, 33.86246967315674, 23.11432385444641, 23.457142761775426, 14.667853934424263, 16.769048248018535, 19.612914664404734, 24.135549238749913, 23.03800310407366, 18.02507758140564, 23.225898027420044, 15.961382695606776, 14.485452430588857, 17.412472282137188, 13.723706654139928, 11.322786160877772, 10.059442111424037, 9.203767112323217, 8.555231809616089, 7.160397010190146, 7.447662898472377, 8.192759922572545, 6.7172452466828485, 6.4412888543946405, 6.054823969091688, 6.254430949687958, 6.347314468451908, 6.638372336115156, 6.523949835981641, 7.939421653747559, 6.991817210401807, 10.068380968911306, 12.64559723649706, 14.244372521127973, 15.25607453073774, 20.33955553599766, 23.26828898702349, 22.341427087783813, 22.286696127482823, 16.880754436765397, 16.342576503753662, 17.594065189361572, 17.938961608069285, 24.25873211451939, 25.966205017907278, 30.5800016948155, 34.964815276009695, 26.688807249069214, 21.16455510684422, 14.345797981534686, 7.024774253368378, 3.109639355114528, 0.591584175825119, 0.0461868032413934, 0.06046398409775325, 0.027603198108928542, 0.007554024341516197, 0.009809013339690864, 0.054252236881958585, 0.03891816988055195, 0.04125146860522883, 0.0600957702845335, 0.027177658264658282, 0.029241836430238824, 0.034030960340585024, 0.12693163246980735, 0.015467595907726457, 0.03251543202038322, 0.030398436688951085, 0.022508923429995775, 0.045902890618890524, 0.020630860634680306, 0.013965022517368197, 0.05319001066631504, 0.04189453320577741, 0.054160997670676024, 0.022789400968966738, 0.022495076226602708, 0.04170322025726948, 0.012558779047269906, 0.025625190498041253, 0.0034432422793802936, 0.03206925453352077, 0.012596246902830899, 0.014644683904147573, 0.0427723369960274, 0.027222117575417672, 0.05558036061535988, 0.023758951175425733, 0.05015810246446303, 0.07990019901522569, 0.02673745358229748, 0.02885404009638088, 0.017270653442080532, 0.022614459374121258, 0.15896187802510603, 0.060372517577239444, 0.019198310361909013, 0.029356305287884812, 0.015481604263186455, 0.03068982676735946, 0.03892594249919057, 0.022122012584337165, 0.06016390198575599, 0.05492745725704091, 0.004395779704542032, 0.036231537615614276, 0.031683144359184165, 0.012070290661150855, 0.04400740643697126, 0.047773557382502725, 0.038911174184509685, 0.010774027539550193, 0.042367546752627404, 0.04873513649883015, 0.038066486295844824, 0.018882226697834473, 0.01688858903279262, 0.05699099759970393, 0.0622834689649088, 0.028423881124971167, 0.017960141712267483, 0.021802509103768637, 0.04009294130706361, 0.04733902355656028, 0.016939640311258178, 0.03485521753983838, 0.053678125010005066, 0.04764815732570631, 0.05188665006841932, 0.027635869570076466, 0.04106893929253731, 0.03168590599671006, 0.11578144292746272, 0.022627146282632436, 0.08661169066493, 0.03392303256051881, 0.03319893052269306, 0.03219030857352274, 0.03754103895542877, 0.03544435556977987, 0.01257509526996208, 0.05937143415212631, 0.06055644806474447, 0.021336859358208518, 0.045642933675221035, 0.038528697565197945, 0.038928218984178135, 0.02437174123977976, 0.025983234767669013, 0.022702307606648122, 0.014394837132255946, 0.044701008325708766, 0.014064895238594284, 0.010627915201309537, 0.034222381854695935, 0.05327677493914962, 0.024941213628543273, 0.017435961535998752, 0.021910598035901785, 0.07176646403968334, 0.01508125163880842, 0.014299949098910605, 0.040484537437025986, 0.07221097911575011, 0.01355237144577716, 0.0568510938568839, 0.511112853884697, 4.739361916269575, 13.148374966212682, 25.031199829918997, 38.19467149462019, 47.58625275748116, 42.232544149671284, 43.76500756399972, 34.97442463466099, 47.903854915073936, 33.31850562776838, 22.361064434051514, 27.824957575116837, 19.272015196936472, 20.200492552348546, 22.99945797239031, 27.17399821962629, 23.20063611439296, 23.044398920876638, 26.249133927481516, 26.73325834955488, 22.192697422845022, 19.625673294067383, 16.109460966927664, 15.336305379867554, 13.59946938923427, 11.735639435904366, 9.155451944896154, 8.852030192102704, 8.342847960335867, 9.58709922858647, 7.870108161653791, 8.25091895035335, 6.250584253243037, 8.77365277494703, 6.758734677519117, 8.658348287854876, 6.846189916133881, 8.396331718989781, 7.642056993075779, 12.399738703455244, 14.926358188901629, 19.3307135786329, 17.496668815612793, 25.882670300347463, 27.775609731674194, 24.851474251065934, 18.718242032187327, 19.58040578024728, 19.087658643722534, 15.313616037368774, 21.483319350651332, 25.196884836469376, 27.351168598447526, 33.669900349208284, 37.73099735804966, 31.771475315093994, 25.80947276524135, 19.432496002742223, 10.239346606390816, 4.837192118167877, 0.8930955539856638, 0.0849869657041771, 0.028626842823411738, 0.09344717780394213, 0.011813338779445206, 0.06581312670771565, 0.01026551388869328, 0.021171558049640486, 0.02886001459722008, 0.08066111497048821, 0.020155300885172825, 0.03593737572165472, 0.11888412572443485, 0.06102771099124636, 0.027213094756007195, 0.02594877197407186, 0.03010357590392232, 0.02567016040640218, 0.055882753139095645, 0.03305145093638982, 0.043013746184962134, 0.012737058186238366, 0.036439749478761635, 0.028194554948381016, 0.052034957467445304, 0.02251445349039776, 0.05646074962403093, 0.008911375122677003, 0.019356872121404325, 0.013256303716583975, 0.041151055600494146, 0.06837618417505707, 0.03978395342294659, 0.033917631421770365, 0.06695048710597412, 0.03530215159324663, 0.037665024266711304, 0.05420209653675556, 0.07667038589715958, 0.0325308551213571, 0.028113096819392273, 0.015929891993956904, 0.015176925076437848, 0.0547948749070721, 0.025384515823264207, 0.04236662733767714, 0.017884295067882965, 0.043148913753351996, 0.02944522730207869, 0.03414002127413239, 0.04489055369049311, 0.05748081845896585, 0.03156244315739189, 0.02413785700420184, 0.11465757180537496, 0.1642474215477705, 0.10572412224220377, 0.1586901790329388, 0.18639880791306496, 0.15273767629904406, 0.12914931561265672, 0.1386785257075514, 0.2397988624870777, 0.17815486527979374, 0.1455383790390832, 0.08331998158246279, 0.11378834809043578, 0.21091338247060776, 0.1380698119423219, 0.13395324854978494, 0.17967023753694125, 0.15149544152830327, 0.15692521445453167, 0.20022708017911228, 0.16389140779418604, 0.22382950011108602, 0.0921084824949503, 0.15003660480890954, 0.13557987340859004, 0.10001081667308297, 0.11266566440463066, 0.21233829243906907, 0.10942373943648168, 0.26107777495469364, 0.17824179918638297, 0.06809269902961594, 0.16635712262775215, 0.20388074698192732, 0.13556949182280473, 0.11424728882099901, 0.14596787813518727, 0.2411659477012498, 0.14731719930257114, 0.1721464241189616, 0.17095037044159003, 0.11257470678538084, 0.15399264038673469, 0.07912563772073813, 0.15672096184321813, 0.10500094640467848, 0.21509425741221222, 0.16352575884333678, 0.1565543543547392, 0.08350222251777138, 0.15574943540351732, 0.16187332251242229, 0.18717681616544724, 0.08856472479445593, 0.22415709681808949, 0.15081921352871827, 0.08662657772323915, 0.09486374179167406, 0.18463872878679208, 0.15839261428586074, 0.17392905774925435, 0.44456211211425917, 4.530532070568629, 14.296939117567879, 26.916171414511545, 43.15661287307739, 53.61329739434378, 50.27211018971035, 51.17189843314034, 43.16105624607631, 51.90548229217529, 42.95674794060843, 33.259004729134695, 36.11375549861363, 25.497981548309326, 26.51103585106986, 29.69735813140869, 34.91602155140468, 33.54099389484951, 30.50930724825178, 35.065376554216655, 24.268075704574585, 23.73133431162153, 24.861802748271398, 19.976480892726354, 16.977405616215297, 15.10611503464835, 12.256911533219473, 11.559737971850804, 10.343029362814766, 9.997086371694293, 10.840185131345477, 8.92877391406468, 9.121468305587769, 8.143853289740425, 9.253286923680987, 9.43160809789385, 9.893597296306066, 9.362699338368007, 10.612625547817775, 9.475420832633972, 14.210533056940351, 17.91794330733163, 20.167757851736887, 21.05771960530962, 28.76387459891183, 33.96052612577166, 31.380840642111643, 29.14776951926095, 26.337792941502162, 25.066797188350133, 25.89539245196751, 26.66957810946873, 32.655046463012695, 35.001939501081196, 40.738438265664236, 45.976924896240234, 36.064711638859336, 28.571129832948955, 20.922853333609446, 10.35439487865993, 4.904591815812247, 1.0197300016880035, 0.15273456860865864, 0.10130669642239809, 0.27944240665861536, 0.08960567893726484, 0.15495514231068747, 0.19124386007232325, 0.07903858846319572, 0.1669675191598279, 0.19559928136212484, 0.13172261895877974, 0.1590602384614093, 0.20681300892361573, 0.3086254107100623, 0.09137818203972918, 0.13582060406250612, 0.10284815835101263, 0.13441206035869463, 0.12986559074904236, 0.1319915223866701, 0.08761383260467223, 0.1433254184999636, 0.22687473813337938, 0.14965290682656424, 0.1319699449730771, 0.07420104090124369, 0.11313678483877863, 0.06900141348264047, 0.11145211130912815, 0.1185256556740829, 0.13038810342550278, 0.1755954311894519, 0.17231788991817407, 0.1120496563879507, 0.15229077956506185, 0.13104886082666262, 0.11540926646973405, 0.1973491417510169, 0.27031684347561424, 0.13364238451634133, 0.14271337991314276, 0.09382128130112376, 0.09322055389306375, 0.20355551157678875, 0.10586596998785223, 0.08467673270830087, 0.11127086103494678, 0.12476819141634873, 0.08083471815500941, 0.11359719120498214, 0.12735723677490438, 0.22641926471676144, 0.15743256865867547, 0.20624985199953827], [0.0169229619204998, 0.046769335732928345, 0.025789557124621103, 0.02299845591187477, 0.018005461066163013, 0.00911192293278873, 0.021298829166750823, 0.012028559909335204, 0.01285353974838342, 0.034868353977799416, 0.0014967335363118245, 0.023226670987371887, 0.020735127718320916, 0.034268963283726146, 0.03400089445390871, 0.034798705750810247, 0.04852522490546107, 0.07873403480542557, 0.057170694028692584, 0.043160676157900264, 0.030990126010562693, 0.023167536660496677, 0.020017731302816952, 0.021005038770713975, 0.027814371777432303, 0.07162319815584592, 0.09995322940605027, 0.025773078901693225, 0.028638445772230625, 0.04675969035763826, 0.09230269278798785, 0.06300777117056505, 0.01661925303882786, 0.026430282475692884, 0.06441498494574002, 0.044504144960748296, 0.013970030105805822, 0.026735207631385753, 0.030638505771223987, 0.04004353038700564, 0.06259770531739507, 0.009026479258734201, 0.07116222860557692, 0.04815122997388244, 0.012971003489967967, 0.013098900555633008, 0.006577760031047676, 0.025318329821207693, 0.03436890809929796, 0.009305028061914657, 0.036998319506113014, 0.02989770837926439, 0.02241775207221508, 0.009495809208601713, 0.04305079758965543, 0.11466419430715696, 0.0909141997939774, 0.13745846546122006, 0.045922123693994114, 0.02236977795005909, 0.023094207381031344, 0.11609588962580476, 0.19077320104198797, 1.4638327998774392, 5.751112563269479, 15.616757256644112, 25.257957765034266, 32.223327091761995, 39.71770967755999, 39.67424522127424, 48.41821616036551, 42.546540192195344, 28.54673818179539, 22.267331498009817, 20.625268936157227, 22.620782886232647, 22.50287195614406, 20.526267528533936, 22.490531955446514, 17.56486538478306, 22.282369136810303, 16.525717122214182, 23.29179126875741, 20.559356587273733, 19.670664616993495, 15.241019521440778, 19.32884451321193, 15.715994903019496, 15.599668162209646, 13.172409653663635, 11.89564950125558, 14.172997151102338, 15.664034536906652, 15.951629161834717, 18.269037519182476, 12.944256867681231, 16.196476731981548, 13.688691207340785, 20.63421474184309, 20.317310878208705, 15.54767826625279, 16.637128012520925, 20.185145718710764, 18.928100211279734, 23.42570390020098, 20.280426365988596, 26.076591048921856, 33.231951917920796, 29.008072512490408, 19.689970186778478, 19.735465254102433, 26.18640559060233, 26.035650525774273, 31.924797739301408, 36.70583929334368, 27.461533784866333, 20.105635745184763, 11.318954229354858, 7.491445234843662, 3.36665387238775, 0.9834452058587755, 0.13092635811439582, 0.09052744161869798, 0.01673739785993738, 0.021942948889253393, 0.048417643178254366, 0.09915748424828053, 0.047268228605389595, 0.0335537941594209, 0.01344241145333009, 0.00980528224525707, 0.01998089363665453, 0.015331693825178912, 0.0261037544613438, 0.023839922455538596, 0.07210738717445306, 0.0658736927434802, 0.035081525931933095, 0.03756920155137777, 0.033837415011865754, 0.035067178308963776, 0.04335502894329173, 0.044918387196958065, 0.038842065392860343, 0.056103226130029986, 0.06693460938653775, 0.019507576445383683, 0.027029644332027862, 0.029340305432145084, 0.06055195616292102, 0.04549260424183948, 0.013611582956010742, 0.05433323021445956, 0.018439872755802104, 0.04346404916473797, 0.004648198972323111, 0.10935830151928322, 0.052181653345802, 0.031113592242555957, 0.04714834503829479, 0.050738246512732336, 0.04854661911459906, 0.054876322858035564, 0.053920568964843235, 0.029054693079420497, 0.023244938846411448, 0.017896172823384404, 0.012896753099214817, 0.03075794150520648, 0.10882258455135993, 0.04193877029631819, 0.024395150697923133, 0.05484410262267504, 0.04654323768668941, 0.03367750805669597, 0.03507300353209887, 0.02227084245532751, 0.018798743141815066, 0.04676301178655454, 0.03887283695595605, 0.06518632319888898, 0.03090237107660089, 0.004512693408677089, 0.02329027177100735, 0.03783951293943184, 0.05077231236334358, 0.0958199944081051, 0.05042841724519219, 0.06697262770363263, 0.043521375195788484, 0.054190483409911394, 0.012730196500862283, 0.014141727455093392, 0.028546697659684078, 0.03789587205808077, 0.06851959255124841, 0.017303545427109514, 0.006582305367503847, 0.004609627649188042, 0.04853762174025178, 0.0728398250149829, 0.01577531493135861, 0.03875764885119029, 0.07305950072727033, 0.015919193193050366, 0.022574286708342176, 0.05776154196688107, 0.025128355283024054, 0.013881283662548023, 0.04713205001982195, 0.03849393282351749, 0.02350850559638015, 0.04063417476468852, 0.007179834331119699, 0.048220528755337, 0.04937974476654615, 0.04562297796032258, 0.040881514349686246, 0.04869467206299305, 0.020124425845486776, 0.035769814891474586, 0.06677980162203312, 0.02146989632663982, 0.02212454012728163, 0.04058143563036408, 0.01589421631901392, 0.025297590398362706, 0.011273599795198866, 0.05721133827630963, 0.030463738899145807, 0.02843258503292288, 0.10470589902251959, 0.05805356308285679, 0.05164650295461927, 0.046801864701722345, 0.016550900813724314, 0.03510865376197866, 0.04711049296227949, 0.3281529428703444, 2.3468622054372514, 7.536090884889875, 19.596047912325176, 30.857255663190568, 38.13032422746931, 46.19129071916853, 43.09263386045183, 52.26708739144461, 45.01441873822893, 31.37107147489275, 25.579450913837977, 21.618590354919434, 23.062089034489222, 19.250474044254847, 22.427044527871267, 27.3840457371303, 24.02581286430359, 28.383691753659928, 18.996647664478846, 25.339418445314678, 29.400746481759207, 25.10623516355242, 21.57107857295445, 26.440202440534318, 19.328062840870448, 21.187555381229945, 17.50516472543989, 21.046988112585886, 20.12441498892648, 19.75653566632952, 20.435206174850464, 21.245003087180002, 20.014470168522426, 18.69970597539629, 17.175170455660137, 22.71694074358259, 21.35222942488534, 21.361055374145508, 22.69342109135219, 26.536693811416626, 24.176798956734793, 27.034601722444805, 25.469528675079346, 34.79448366165161, 35.33775636128017, 28.281202350343975, 19.303949117660522, 21.559009552001953, 26.18132472038269, 27.43545719555446, 34.11614145551409, 39.3655298096793, 32.355995995657786, 24.942902122225078, 16.08230219568525, 10.623847757066999, 5.629916438034602, 1.6225978348936354, 0.29858083969780375, 0.07597989509148256, 0.007380385533906519, 0.018423822009935975, 0.01590606354043952, 0.07867663074284792, 0.05246893489467246, 0.03874455312533038, 0.04690020478197506, 0.026306967217741267, 0.008122663828544319, 0.04024789156392217, 0.0753744315089924, 0.024752060117732202, 0.0026058164117525196, 0.010832161027272897, 0.024619214835443666, 0.018801725303222026, 0.043871713003941944, 0.03940753272867628, 0.040974246338009834, 0.07210402164076056, 0.0932789146900177, 0.010372169415599533, 0.028030279924028685, 0.023363865679129958, 0.03699633479118347, 0.04569205282522099, 0.04264972571815763, 0.026193394026319896, 0.01939243414173169, 0.002766746258462912, 0.03330143002261009, 0.01267104351427406, 0.0404337762322809, 0.056665253293301375, 0.01516654179431498, 0.05426928846697722, 0.042076068464666605, 0.03524589425485049, 0.03960424681593265, 0.07976496020065886, 0.044417119451931546, 0.02962482873616474, 0.044714402606976886, 0.01459984461377774, 0.04969101931367602, 0.019185421589229788, 0.05836695805191994, 0.05599602098975863, 0.030619109847715924, 0.13340751640498638, 0.04921537983630385, 0.0485466971461262, 0.0266322670837066, 0.16663426347076893, 0.10156320301549775, 0.18550941135202134, 0.12881375290453434, 0.11808253159480435, 0.11131896238241877, 0.08115488490355866, 0.18838052371782915, 0.10933548238660608, 0.07583766736622367, 0.14265856785433634, 0.16611757262476853, 0.11321816832891532, 0.14297974562006338, 0.15319754662258284, 0.13053601048886776, 0.15613970160484314, 0.13054184589002812, 0.14200630571160996, 0.1364124630178724, 0.10093971754291228, 0.1498577565486942, 0.08117570914328098, 0.24081574220742497, 0.2208804376423359, 0.1298685355910233, 0.1179157341165202, 0.10098663823945181, 0.09034307686878101, 0.1294597860957895, 0.16512782073446683, 0.11086145336074488, 0.11460908369294234, 0.13946022519043513, 0.08657531440258026, 0.11270900243627173, 0.14507637811558588, 0.06645244240228619, 0.1981237708990063, 0.16240887663194112, 0.21990971187395708, 0.1381690680448498, 0.18210168635206564, 0.09086387963699442, 0.11407540233007499, 0.14758323931268283, 0.1574701052159071, 0.11819833038108689, 0.08684816690427916, 0.07128644122609071, 0.08824076503515244, 0.08627196175179311, 0.0951144333396639, 0.10539202006267649, 0.13379920752985136, 0.1999363550650222, 0.16570484691432544, 0.19659762350576265, 0.1026984192430973, 0.09112029802054167, 0.13076489392135823, 0.3879678946520601, 0.42048440554312294, 2.144012587411063, 8.094084211758204, 21.747574976512364, 33.68592636925833, 43.148486954825266, 52.35766410827637, 52.03349937711443, 58.85243020738874, 53.22915233884539, 40.197104113442556, 34.420507294791086, 32.04276425497872, 35.207088538578574, 32.674973896571565, 31.043780054364884, 33.545468534742085, 28.150386878422328, 34.13425540924072, 23.901196922574723, 35.46581860951015, 32.65494918823242, 30.42824956348964, 25.521999733788626, 29.821459906441824, 22.62134047916957, 22.796737330300466, 20.32758378982544, 19.41839984485081, 20.69540752683367, 22.66195269993373, 23.117617300578527, 24.892103842326573, 18.44043915612357, 22.050622395106725, 19.426477125712804, 27.010569640568324, 27.7095045702798, 23.490428107125418, 24.089800562177384, 31.455693585532053, 28.26721736363002, 33.302437918526785, 30.525941235678538, 38.13844319752285, 46.07551983424595, 39.75031409944807, 27.192080906459264, 30.505124432700022, 36.82829087121146, 35.94396931784493, 43.21005146844046, 48.369179248809814, 38.598875999450684, 28.386682953153336, 17.13209162439619, 10.05441074711936, 5.350826842444284, 2.075731771332877, 0.3598174037677901, 0.13689578351165566, 0.19740375024931772, 0.13860346616378852, 0.19411776800240788, 0.1715923324227333, 0.17156804086906569, 0.1180757326739175, 0.12569893790142878, 0.09178725044642176, 0.10312146547117404, 0.10626084344195467, 0.11810929301593985, 0.12339521651821476, 0.15701617885913166, 0.1046781265842063, 0.07589276440973793, 0.15498790198138782, 0.1229020029838596, 0.14418506808578968, 0.16521467321685382, 0.1775362313325916, 0.22677504776843957, 0.1437769971255745, 0.13920443105910504, 0.1257914900779724, 0.16959634024117673, 0.10300275576966149, 0.13529684288161142, 0.0798459704965353, 0.12217496628207819, 0.13447581550904683, 0.12315729499927588, 0.15215714887848922, 0.23299155490739004, 0.24871853100402014, 0.12340786441096238, 0.11116993573627301, 0.12884615973702498, 0.17433646374515124, 0.09615227979208742, 0.11644682793744973, 0.18203675055078097, 0.09876632238073008, 0.10595971638602869, 0.07893143421305077, 0.09662232814090592, 0.13454311261219637, 0.26679239688175066, 0.13715864797788008, 0.09205104450562171, 0.22749221857104981, 0.17908938441957745, 0.12445084058812686, 0.12231664439397198], [0.020464834989979863, 0.03905158682859369, 0.03170208227155464, 0.04486971588007041, 0.04199043734531317, 0.047098791625882895, 0.02046480615224157, 0.054746010207704136, 0.008611511838223253, 0.031077908085925237, 0.04398311149062855, 0.017536135357139365, 0.03904814665604915, 0.07394494142915521, 0.04891949107072183, 0.024152969675404683, 0.016306139661797454, 0.07564474628972155, 0.0129405898540946, 0.034111421023096354, 0.0397703929005989, 0.020892273035964797, 0.022264136833005717, 0.017496490252337286, 0.049130135481911044, 0.02503660717047751, 0.015893766789564064, 0.031816659694803615, 0.023667167439790707, 0.03320608228178961, 0.08115390102778162, 0.014026643675086754, 0.02026577147522143, 0.02829730211357985, 0.03497415794325726, 0.005796737386845052, 0.033185923006385565, 0.02432178070635668, 0.08694421353616885, 0.01639376737044326, 0.06830049359372684, 0.021239430211218338, 0.035689391528389285, 0.034372657005275996, 0.07012722521488156, 0.014131116015570504, 0.040506559291056225, 0.01673232581067298, 0.04020760015451482, 0.03779015290950026, 0.01059941079334489, 0.061169199113334925, 0.0532143327540585, 0.03411345323547721, 0.02182435623503157, 0.07645250830267157, 0.014868605549314191, 0.025278974790126085, 0.020057800492005687, 0.02324581246024796, 0.03892299426453454, 0.03135322366974183, 0.019015782745555043, 0.0671611043757626, 0.3069478007299559, 1.8364379831722804, 6.580108651093074, 13.579027788979666, 26.334680148533412, 36.40122331891741, 45.67673145021711, 47.98425946916853, 42.38215970993042, 40.98108325685774, 37.28039625712803, 36.61354289736067, 33.13809217725481, 35.47697741644723, 22.940248898097447, 19.325196708951676, 27.0898277418954, 27.05934946877616, 27.79503515788487, 21.64402597291129, 20.98524294580732, 27.370755570275442, 20.071500982557023, 21.764512947627477, 22.24462652206421, 17.24255061149597, 16.743541410991124, 24.061514445713588, 22.581756591796875, 20.07351769719805, 16.66425551686968, 16.52062930379595, 18.75287880216326, 17.672807386943273, 36.416877610342844, 45.77727535792759, 17.031440019607544, 19.78226137161255, 23.011223009654454, 29.94830969401768, 21.351711784090313, 23.65123721531459, 21.69790404183524, 30.305704184940883, 27.048560653414043, 30.520528588976177, 35.667021070207866, 34.107984270368306, 33.700798988342285, 27.914394787379674, 18.655711718967982, 10.341983658926827, 4.735718888895852, 2.0508470152105605, 0.46328129193612505, 0.12157607770391873, 0.06692049585814987, 0.010483539912716618, 0.033978638505297046, 0.01314741835397269, 0.027463075538565005, 0.018077519788805927, 0.04113026189484766, 0.04926280604143228, 0.01897921140438744, 0.04624747105741075, 0.0419952956560467, 0.026828723327655877, 0.00656733349231737, 0.022669754889128462, 0.033719220996967385, 0.034466009853141646, 0.02468761625433607, 0.05345489038154483, 0.05143549891987017, 0.04054674892021077, 0.01444227181907211, 0.05829343878264938, 0.0534495808450239, 0.024658685217478445, 0.055565263211194954, 0.015112572815269232, 0.013046227578472878, 0.08595092647841998, 0.011327349098532327, 0.0940284448276673, 0.02947158838755318, 0.022597959098805274, 0.03613706857764295, 0.030645705027771846, 0.025726714603868977, 0.018334703220586692, 0.024718443796570812, 0.030879321242017404, 0.057198588603309224, 0.04141435432913048, 0.027213371259027293, 0.06371578175042357, 0.020976923672216277, 0.022765024598421793, 0.039749405812472105, 0.06468645323600088, 0.07313909967030797, 0.0501797545169081, 0.17890433434929165, 0.02741097761983318, 0.07617211049156529, 0.07249986539993968, 0.024066493779953037, 0.0221270167800997, 0.020422321378386447, 0.041115395192589076, 0.04323645494878292, 0.06669784816248076, 0.029000478131430488, 0.05289235092433436, 0.018075864163360426, 0.021574850426986814, 0.06757222874356167, 0.09369266498833895, 0.011325453441323978, 0.039160824181245904, 0.046764545275696685, 0.018270130435537015, 0.08640346183840718, 0.019053056370466948, 0.038509915715881755, 0.021588790928944945, 0.00588880737944107, 0.05250886328784483, 0.0028049155495994326, 0.02884470684719937, 0.06024599793766226, 0.036161383880036216, 0.03280831826850772, 0.015866698331332633, 0.05979211229298796, 0.021196288954732672, 0.04636390088126063, 0.046953866723924875, 0.019367482712758437, 0.05190511979162693, 0.060433483948665004, 0.03252742173416274, 0.06522318122110196, 0.04631035429026399, 0.06057845974074943, 0.032812029855059724, 0.02920474431344441, 0.07204789322401796, 0.1129125968686172, 0.014868359580369932, 0.037164798072938404, 0.003937148555581058, 0.060340918201420984, 0.024781206589458243, 0.03940289154914873, 0.012574834882148674, 0.011875211843289435, 0.007205801866283374, 0.050963947615985355, 0.05548380508220621, 0.04063727906239884, 0.042076570580580404, 0.00883633763130222, 0.018026957055553794, 0.03585236546184335, 0.052048090512731245, 0.01440745109825262, 0.06851505993732385, 0.028345272843060747, 0.035246036747204404, 0.03937982475118978, 0.03889410224344049, 0.034408860241195986, 0.05125816040007131, 0.655797690153122, 3.1980371602943967, 8.982703225953237, 18.858493157795497, 33.194237095969065, 43.21399457114083, 51.686044284275596, 51.585879053388325, 44.57372924259731, 41.34103468486241, 39.35189744404384, 38.97259875706264, 35.05669130597796, 35.1601881980896, 26.291550942829677, 19.22298697062901, 29.939360414232524, 21.188029595783778, 26.853031396865845, 23.848211697169713, 25.683227470942906, 24.831597191946848, 24.39682756151472, 22.075408356530325, 26.558462517602102, 21.009424413953507, 19.519444022859844, 25.79321919168745, 28.75548117501395, 25.491434608186992, 23.52750369480678, 19.508947031838552, 25.18084144592285, 18.90546124322074, 41.380514349256245, 50.151454721178325, 24.66763186454773, 24.54161412375314, 25.70669674873352, 26.430820635386876, 23.03099410874503, 23.486893211092266, 22.63778339113508, 37.08867808750698, 30.149960313524517, 30.178399290357316, 36.868291650499614, 39.4968820299421, 36.53259290967669, 34.30954456329346, 25.069175209317887, 14.063232983861651, 7.128381882395063, 3.348263076373509, 0.9009668316159929, 0.2855455848787512, 0.10029888871525015, 0.10290409677795001, 0.03758430574089289, 0.02379326299498124, 0.031118620187044144, 0.02061190745527191, 0.052483862665082724, 0.07624222351504223, 0.050702284156743965, 0.017884147486516407, 0.05700015103710549, 0.019712207339970127, 0.0015230032316009912, 0.0332909771906478, 0.03419047713811908, 0.014480972063860722, 0.03918019974870341, 0.07336872949131898, 0.06408805998840503, 0.013739598765304046, 0.01895045000128448, 0.05445899668016604, 0.01636490927610014, 0.017151858923690658, 0.04719084168651274, 0.02161529111409826, 0.006826575853795345, 0.10166576358356647, 0.05824493031416621, 0.04881501364122544, 0.04690416403380888, 0.028960699015962224, 0.04279363960293787, 0.03199671914002725, 0.03488495772970574, 0.016716585494577885, 0.03199506012190666, 0.04816614417359233, 0.058910634235611985, 0.01709350321574935, 0.033271418418735266, 0.028902714805943624, 0.035399009074483595, 0.05546517590326922, 0.04507686583591359, 0.013044264915931438, 0.05980510623859508, 0.08657120248036725, 0.06853048303829772, 0.058052891333188326, 0.0496749108923333, 0.01368956359302891, 0.033694505358913114, 0.028332909935020974, 0.012981583547246243, 0.07791287851120744, 0.13997710602624075, 0.13578272823776516, 0.1373329364827701, 0.14732618310621806, 0.12589105830660888, 0.1478051474051816, 0.13513288167970522, 0.20735262068254606, 0.08860305523765938, 0.11076227868241922, 0.09038615027176482, 0.06662241542445761, 0.1352830957621336, 0.13861950673162937, 0.17541925635721, 0.11827496412609305, 0.11131092174244778, 0.14530831495566027, 0.1396508121064731, 0.08440630257661853, 0.10999715581004109, 0.09308279771357775, 0.09810238265033279, 0.09966538806578942, 0.16881051526537963, 0.10751147847622633, 0.17989055785749639, 0.11734573755945478, 0.24800791484969004, 0.08853236545941659, 0.1861553495483739, 0.11161799276513712, 0.13557143243295805, 0.12164855881461076, 0.12917918472417764, 0.07941951123731476, 0.08357127702661923, 0.11810554750263691, 0.30971141957810944, 0.10502578078636102, 0.14123363074447426, 0.08492859133652278, 0.11215609817632607, 0.11601415329745837, 0.1846341554607664, 0.1865426573370184, 0.11878573814673082, 0.14364603986697538, 0.15163068712822028, 0.10416437379483666, 0.131765855210168, 0.15969905204006604, 0.14420104080012866, 0.156207446541105, 0.09994280710816383, 0.1418112947472504, 0.08904761781117745, 0.14701586190078939, 0.12838139039065155, 0.13924515673092433, 0.11640418879687786, 0.08311285198267017, 0.1289373277021306, 0.10756418029112474, 0.6365347866501126, 3.2452621119362965, 10.121890783309937, 22.234442199979508, 37.81041874204363, 48.27551753180367, 58.78902094704764, 60.48830018724714, 54.84401444026402, 52.12573323931013, 50.98644059044974, 50.255507469177246, 44.47958809988839, 46.810750416346956, 33.34396035330636, 28.732150861195155, 39.89642776761736, 36.724366664886475, 38.85954461778913, 32.609254360198975, 31.599132197243826, 37.783831460135325, 30.77312340055193, 32.27014057976859, 35.02751929419381, 27.07284460748945, 26.078336783817836, 34.85619756153652, 32.822991371154785, 31.330139636993408, 26.331226893833705, 24.013448544910975, 29.105474097388132, 27.767633199691772, 47.4492620740618, 57.13748277936663, 26.90980339050293, 28.902800355638774, 34.12954453059605, 40.453044482639854, 29.383038997650146, 34.15789318084717, 31.16524498803275, 43.758660384586875, 38.49595580782209, 39.59261083602905, 45.24766976492745, 46.63023969105312, 42.812082971845356, 36.8842134475708, 26.268279688698904, 16.073443242481776, 6.942376000540597, 3.4758610980851308, 0.6923820727637836, 0.28222035616636276, 0.19827572203108243, 0.13468635135463305, 0.14762308288897785, 0.08085203436868531, 0.12078192031809262, 0.09109682070889644, 0.1331877117710454, 0.16124376415141992, 0.15978756014789852, 0.20077468508056232, 0.10661054003451552, 0.14066428558102675, 0.10732503062380211, 0.08052565223936524, 0.1549871555928673, 0.12734160332807473, 0.08934032424752202, 0.14380986536187784, 0.11179906662021365, 0.14861233266336576, 0.05200675415939518, 0.18748812803200313, 0.146555896582348, 0.05733821075409651, 0.10537015087902546, 0.16952631542725222, 0.0709529887618763, 0.19933731720915862, 0.14300706343991415, 0.16042216680943966, 0.1239914180977004, 0.08038574510387012, 0.116624509117433, 0.11160669515707664, 0.15245691207902773, 0.17533043612326893, 0.10614766380084412, 0.11955658106931619, 0.1432725606220109, 0.1197986009397677, 0.13809954534683908, 0.13489314168691635, 0.06330388385270323, 0.18522285244294576, 0.07420010452291795, 0.13103343094033854, 0.2544065814997469, 0.16023198701441288, 0.26043577226144926, 0.09346853808632918, 0.26052083341138704, 0.11219593496727091, 0.09450282222990479, 0.12136797101369926, 0.07128777794007744, 0.20541367972535746], [0.03159973204934171, 0.06579601405454533, 0.012060411191279334, 0.0257526838353702, 0.03721554909965821, 0.026075069393430437, 0.0146308400934296, 0.030295543638723235, 0.018608939933723638, 0.015552960702085068, 0.0399157825990447, 0.01593133557720908, 0.027433484626401747, 0.019385884582464184, 0.09608090469347579, 0.05859865740473781, 0.02731150608243687, 0.019677926054490463, 0.02735854891527976, 0.059113835117646625, 0.009985445167071052, 0.03627048891835979, 0.038582108449190855, 0.04373752252597894, 0.044361259056521316, 0.044593830326838155, 0.013211751955428293, 0.01398237859497645, 0.024394129502720067, 0.04112585820257664, 0.013972432119771838, 0.061658212515924654, 0.014467153698205948, 0.04017575311341456, 0.02730316179804504, 0.03965619545696037, 0.01838221084991736, 0.03636786887156112, 0.051314458450568576, 0.014309857406520417, 0.0536082766151854, 0.0151159519196621, 0.0032475540522552493, 0.046073277547423325, 0.021663302555680275, 0.013573947163032634, 0.015049828682094812, 0.050183187904102464, 0.044486896600574255, 0.018854688354102627, 0.020614092338031957, 0.041574668405311446, 0.0350086275222046, 0.0032944461230986883, 0.09777072151856762, 0.047695505499307594, 0.04530679760500789, 0.03414073034322687, 0.0065577135620904815, 0.03279904269480279, 0.026416235104469315, 0.019429049587675502, 0.030208915072892393, 0.027965464562709843, 0.03978927992284298, 0.051851026979940276, 0.5971418118902615, 2.9691404828003476, 8.04435248034341, 16.361242839268275, 25.894645520618983, 31.275749138423375, 40.131367206573486, 42.60810817990984, 49.971169812338694, 41.368233408246724, 48.52715696607317, 44.336990220206125, 39.243036542619976, 38.13831465584891, 40.203124727521626, 30.92283970969064, 28.64383578300476, 29.082843814577373, 19.46991900035313, 28.00104750905718, 25.146875177110942, 22.03861243384225, 21.226652894701274, 17.698904820850917, 25.656464747020177, 26.001679045813425, 20.10262370109558, 18.87337272507804, 18.60310343333653, 33.15630340576172, 17.684923308236257, 20.43579156058175, 60.16560500008719, 66.74748761313302, 16.18420100212097, 23.393705708639963, 28.725954805101665, 34.087890080043245, 26.3835346698761, 32.92805508204869, 37.85838563101632, 34.64797394616263, 34.951231547764365, 37.87288652147566, 29.646160330091202, 28.174589191164287, 18.566554171698435, 10.125225918633596, 5.134358320917402, 1.1472813401903426, 0.32287508036409107, 0.09602907140340124, 0.04026113317481109, 0.047044410436813316, 0.05756737917129483, 0.01848222012631595, 0.0550264114114855, 0.06321952837918486, 0.029996255412697792, 0.03470179737944688, 0.03453097618850214, 0.03596434070329581, 0.0447220768380378, 0.012298987496511211, 0.049672824397150955, 0.05215270025655627, 0.04536942977990423, 0.04073433331879122, 0.03631086175196937, 0.044518455264291594, 0.050853271769093614, 0.028326930345169136, 0.07026966328599624, 0.04246931343472429, 0.05376524551372443, 0.04392437071406415, 0.005120001334164823, 0.04321496235206723, 0.020795100035944154, 0.01378531675852303, 0.005702721270998674, 0.04751707114545362, 0.016215908075017587, 0.03829245881310531, 0.02330550318583846, 0.056224707647093704, 0.01583352475427091, 0.039472851902246475, 0.058890203546200476, 0.032252116328371425, 0.026552501899589385, 0.09011289743440491, 0.0080588772959475, 0.019698911446279714, 0.026303265809214542, 0.02737526292912662, 0.01348895556293428, 0.01339905645831355, 0.04614726500585675, 0.04070857273680823, 0.07158341564770256, 0.07824812909322125, 0.027056300580235462, 0.07694035462502923, 0.05822793979729925, 0.01885345172403114, 0.02183709742634424, 0.022491995677618042, 0.03988416625985077, 0.006803903454315982, 0.0395775634263243, 0.04603512691599982, 0.03167792981756585, 0.0081334788285728, 0.023641461140609214, 0.027398490879152502, 0.056592093647590706, 0.02755759546666273, 0.03182352986186743, 0.016438398011294857, 0.05686212683628712, 0.08706523025674479, 0.05563780878271375, 0.015552641790626305, 0.03476380190945097, 0.027957997284829617, 0.019376822747290134, 0.011953077129354435, 0.053835395856627395, 0.02217552185590778, 0.04196680057793856, 0.0472454332214381, 0.03046395263767668, 0.03298001137695142, 0.03067769795390112, 0.01319971728870379, 0.006569630333355495, 0.029298538209072182, 0.01774536332647715, 0.023339898125933747, 0.039400190979774506, 0.05424552956329925, 0.04215442568862012, 0.01401672773395798, 0.06316925571965319, 0.08795148520065205, 0.06888663249888591, 0.0515253505270396, 0.03598345842744623, 0.020455223541440706, 0.03182023896702698, 0.014029738642940564, 0.04730441148525902, 0.03770643186622432, 0.007708971205699656, 0.02149310731329024, 0.031258408578911, 0.02528697980700859, 0.03759258726079549, 0.029486349916883876, 0.0570096844541175, 0.095697844534048, 0.028133206901007464, 0.04513402562588453, 0.02049500265690897, 0.058630636760166714, 0.059087474032172134, 0.04970836606142776, 0.062210594303905964, 0.06628060340881348, 0.05624623077788523, 0.02388477192393371, 0.018154913493032967, 0.07850170441504035, 0.05490542522498539, 0.028243833554110358, 1.3014119267463684, 4.285522954804557, 10.765733446393694, 21.33748013632638, 33.143084457942415, 38.61418635504586, 46.6472349848066, 48.13044261932373, 52.153505189078196, 47.85937254769461, 50.58848251615252, 47.97617524010794, 40.54081760134016, 35.398824078696116, 42.782813685280935, 30.84467942374093, 30.464883940560476, 28.710767780031475, 18.365617479596818, 28.39495130947658, 21.63822075298854, 22.723531109946116, 27.327344962528773, 21.444781167166575, 25.670720713479177, 29.35935606275286, 22.581932033811295, 20.889095510755265, 19.576382773263113, 22.275163854871476, 18.929045166288102, 21.448774644306727, 63.55148996625628, 69.68920203617641, 15.731055123465401, 18.860725266592844, 28.59125702721732, 31.4635728427342, 24.51220761026655, 35.31357315608433, 38.34630550657, 38.69162402834211, 38.669261251177105, 41.195872919900076, 34.64632027489798, 32.31308044706072, 24.199125255857194, 13.668541431427002, 6.993833490780421, 2.5694731516497473, 0.66267086991242, 0.03139947261661291, 0.015653830021619797, 0.036942218230771165, 0.04219314968213439, 0.01802747104583042, 0.0442851070713784, 0.07477187205638204, 0.016606252307870557, 0.03088488183649523, 0.025982720777392387, 0.04327701098684754, 0.03077868092805147, 0.026107109817011014, 0.009196428532179977, 0.04057507436456425, 0.027037785055914094, 0.013773137903107064, 0.029966569505631924, 0.06872106995433569, 0.02608302012751145, 0.021046656716082777, 0.03150930368740644, 0.02704760176129639, 0.03579880190747125, 0.03743587281288845, 0.07712433939533574, 0.02013410345119025, 0.019346575352496335, 0.015141469925375921, 0.06983940423067127, 0.012397944195462125, 0.03574197459965944, 0.018520759219037633, 0.010082647004829986, 0.02705159833255623, 0.03584233332159264, 0.028543379623442888, 0.03250705211290291, 0.03377191263384052, 0.03212323199425425, 0.06904335373214313, 0.013048142743563014, 0.0504739944423948, 0.05351754630516682, 0.03896099901092904, 0.01197564520407468, 0.010131040122359991, 0.027713560133374164, 0.03350865461730531, 0.01858644649785544, 0.04932583176663943, 0.041307339178664346, 0.03863489508096661, 0.06662335180278335, 0.052847523508327346, 0.03432750389246004, 0.06255284736731223, 0.038419198976563554, 0.022648874670267105, 0.1919247835342373, 0.21321595034429006, 0.05527734383940697, 0.09494745944227491, 0.11299780051090888, 0.11616020117487226, 0.11977281660905906, 0.07439936990184443, 0.108668421395123, 0.09350340121558734, 0.12553619806255611, 0.1501143920634474, 0.11280973095979009, 0.20495759562722274, 0.29640499502420425, 0.15088493643062456, 0.0954715870320797, 0.0925490620679089, 0.1350411166037832, 0.1117033049730318, 0.18339648044535092, 0.17413193971983024, 0.14884246460029057, 0.14240567785288605, 0.12559418566524982, 0.18442998427365506, 0.12855641171336174, 0.11872576922178268, 0.09122089762240648, 0.11298470478504896, 0.14855937979051045, 0.1891423421246665, 0.17125689185091428, 0.11975754957113947, 0.13705187370734556, 0.15587542578577995, 0.07653913008315222, 0.18323460913130216, 0.1679594423621893, 0.11435214962278094, 0.10345867023404155, 0.0907027954235673, 0.17207846205149377, 0.0916170874344451, 0.12727562258286135, 0.12617412954568863, 0.13710545083241804, 0.140739467261093, 0.10267752714987312, 0.0985907039472035, 0.14009678603282996, 0.11800170450338296, 0.12947683089545794, 0.1176897683846099, 0.12658089771866798, 0.11731775477528572, 0.0949435510805675, 0.20243538596800395, 0.208320876583457, 0.115986523351499, 0.10293706679450614, 0.07979742131595101, 0.06290770761136498, 0.22868437745741435, 0.16999139689973422, 0.1491284535399505, 1.2706496460097176, 4.037724137306213, 12.015054294041224, 23.522888353892736, 36.07605457305908, 43.3716596194676, 52.631183419908794, 56.084531920296804, 61.369651385716026, 53.94238492420742, 59.53834247589111, 56.556321552821565, 52.25558464867728, 48.71950394766671, 53.03117036819458, 40.435409954616, 40.96084662846157, 40.833691120147705, 28.460585730416433, 40.29392031260899, 35.62204885482788, 33.800853048052105, 35.089670930589946, 29.06365462711879, 38.597941466740195, 38.84131601878575, 30.830178533281597, 30.798897743225098, 29.05859807559422, 46.38057701928275, 26.428998470306396, 29.55148070199149, 67.41447993687221, 76.15322235652378, 23.404312133789062, 31.730779715946742, 39.080924647195, 43.71907302311489, 34.58476965767996, 45.23777205603463, 48.42394495010376, 46.90478386197771, 46.62767233167376, 48.91644368852888, 40.5079665184021, 37.82193190710885, 27.61055874824524, 15.179232665470668, 7.576670970235552, 2.353657977921622, 0.5876509525946209, 0.20082295606178896, 0.09783967424716268, 0.15052980477256434, 0.16856607981026173, 0.15460664672510965, 0.1323449034243822, 0.18178782319383963, 0.10210002599550144, 0.16058660298585892, 0.0984122831640499, 0.12394895537623338, 0.1858830398746899, 0.05461251522813525, 0.0852326632344297, 0.1672379289354597, 0.13377031550875731, 0.11393509485891887, 0.10996267944574356, 0.12859394827059337, 0.09241881048572914, 0.11197249338562999, 0.19643078531537736, 0.14284948046718324, 0.128066197303789, 0.12279891994382654, 0.22496829900358403, 0.09421258566102811, 0.08368085364678077, 0.07557275372424296, 0.1331547756812402, 0.11345510597207717, 0.1035336008561509, 0.12970374657639436, 0.1464857632028205, 0.28596652086291996, 0.11659788340330124, 0.18581282507096017, 0.1376363094896078, 0.1598711149500949, 0.10975519022239105, 0.1516786731247391, 0.1447162660104888, 0.15304759038346155, 0.1383344948823963, 0.19034632109105587, 0.09330028175775494, 0.11104094622922794, 0.13094542494841985, 0.12124155993972506, 0.07808129090283598, 0.10818947745221001, 0.07854650129697152, 0.1885885489838464, 0.17184060838605675, 0.13475092074700765, 0.11176191004259245, 0.07834703235753945, 0.14515920009996208, 0.0999802758118936], [0.08346218216632094, 0.044167181077812395, 0.023405677006979073, 0.039055580007178445, 0.01582421355747751, 0.02331481098995677, 0.03457873148311462, 0.03327247014801417, 0.010551328953754689, 0.02420903363132051, 0.07599842588284186, 0.0662849053208317, 0.03200443069051419, 0.00793902765560363, 0.04776737253580775, 0.05353565979748964, 0.048872027546167374, 0.030506283044815063, 0.013180224673955568, 0.03136673330196312, 0.10977437240736825, 0.09672310416187559, 0.0330389082165701, 0.036901770758309534, 0.040084401943853924, 0.06149868893304041, 0.052050414495170116, 0.027540559148682014, 0.05017070625243442, 0.006511914992838034, 0.03323252818414143, 0.01723969867452979, 0.02528492214956454, 0.03266753243016345, 0.08226198942533561, 0.05359099432826042, 0.10024107074631111, 0.04437630217788475, 0.03675311391374894, 0.039260497582810264, 0.02723899613400655, 0.028167140437290072, 0.006667688397491085, 0.01791064767166972, 0.05942828860133886, 0.04296781614954982, 0.03385525709018111, 0.020257990374895077, 0.01250929942554129, 0.02814456557721964, 0.04386530424069081, 0.023096621269360185, 0.02995930578825729, 0.036598764160381894, 0.07272880311523165, 0.021946584140615802, 0.009294690580905547, 0.04733819913651262, 0.08566138880061251, 0.04397667558597667, 0.013667522231116891, 0.027137261682323048, 0.06826467373009239, 0.07177936299038784, 0.009047678389054323, 0.035826404712029865, 0.045097886850791316, 0.06088633143476077, 0.8730523352112088, 3.008727192878723, 5.216629334858485, 13.217697143554688, 22.017885957445415, 30.4365040234157, 36.07812166213989, 34.90986197335379, 45.909892150333945, 45.53621803011213, 48.97217518942696, 48.04931197847639, 45.29813800539289, 41.60196386064802, 44.937748840876985, 34.75428138460432, 42.88362509863717, 30.57867111478533, 35.77985634122576, 30.028262615203857, 25.55474659374782, 27.188097851616995, 25.077931676592144, 23.396276542118617, 24.742041860307964, 29.107601983206614, 28.99352819578988, 30.293030670710973, 26.900437218802317, 23.434675761631556, 58.05642720631191, 71.6322101865496, 27.11784635271345, 34.971992765154155, 30.782413142068044, 28.552048342568533, 37.20026615687779, 37.029111180986675, 35.95156022480556, 40.56367022650582, 30.566424914768763, 26.505857706069946, 16.225065095084055, 11.370638404573713, 3.8658851981163025, 1.3318870514631271, 0.24317335284182004, 0.005000282311812043, 0.05223957309499383, 0.029734792121286904, 0.06477683410048485, 0.021196161729416678, 0.07092661410570145, 0.041920870542526245, 0.06729265874517815, 0.010459021049817758, 0.034192299004644156, 0.06210801337978669, 0.0641949021124414, 0.010905994967158352, 0.08773836413664476, 0.034079679154923985, 0.028836581390351057, 0.00647438013194395, 0.05592247797176242, 0.012113156262785196, 0.013232756006930555, 0.03622456906097276, 0.021403632293056165, 0.02074343977229936, 0.054658078854637485, 0.06474396586418152, 0.02114590603326048, 0.052286052743771246, 0.035104066865252595, 0.014914443982498986, 0.02831142581999302, 0.031180081889033318, 0.033363872207701206, 0.027331970698599304, 0.021352117914440374, 0.015527678487290229, 0.02827174509210246, 0.032282531660582335, 0.034042112063616514, 0.033272483718714545, 0.012953693213473474, 0.037616047609065256, 0.08292479600225176, 0.03236511955037713, 0.0359887951053679, 0.06514683924615383, 0.023542791970872452, 0.0485899232194892, 0.02541598118841648, 0.03766300901770592, 0.04613862046971917, 0.06531480380467006, 0.07017840032598802, 0.03874056673209582, 0.04985535710251757, 0.026508836474801813, 0.04890020710549184, 0.005276632661532078, 0.040019557744796784, 0.03487882377313716, 0.02670017656471048, 0.030240952103797878, 0.06185325062168496, 0.038168724559779675, 0.029559652054948465, 0.005746192889221544, 0.03831237381590264, 0.04345983885494726, 0.037188597688717503, 0.04897569412631648, 0.027134505133809786, 0.05770035846424954, 0.038713357477848015, 0.036041388354663334, 0.06200495748115437, 0.04846289807132312, 0.008928974624723196, 0.013613438749286746, 0.026100999609168087, 0.040510243736207485, 0.05022032751834818, 0.02668042610665517, 0.1524895089013236, 0.07814432002071824, 0.01002534048166126, 0.036982496069478135, 0.047553220098572116, 0.07944015227258205, 0.07239904866686889, 0.013698615250177681, 0.017435885200809156, 0.009981647915472942, 0.02898898035553949, 0.055645635684153864, 0.020300383546522686, 0.06891553809068032, 0.09503474618707385, 0.030180905147322586, 0.039955921338072846, 0.034669655175613504, 0.09242717003715889, 0.024331013871622936, 0.05190978811255523, 0.035629656698022566, 0.08570123916225773, 0.037636383303574154, 0.0017717581982391753, 0.007608451331699533, 0.015874270782140747, 0.03817501797207764, 0.08352415276957409, 0.018632659821638038, 0.009731650169539665, 0.05509861771549497, 0.06241847707756928, 0.02679630631713995, 0.024468390071498494, 0.03323638565572245, 0.022046372893133333, 0.030558017947311913, 0.035230698463107855, 0.05212782516277262, 0.03670720762706228, 0.014718639132167612, 0.06919250929994242, 0.020571841658758264, 0.022159016491579156, 0.009405232417131109, 0.05693060798304422, 0.22165324831647532, 1.443119677049773, 4.801659899098532, 8.523313522338867, 17.30568889209202, 27.841101714542933, 36.42810937336513, 45.02845062528338, 41.47087219783238, 53.47458355767386, 51.885134492601665, 54.595050062452046, 50.19035768508911, 50.37790693555559, 42.91283185141427, 48.75638498578753, 38.515181473323274, 38.926431451525005, 33.344592639378135, 36.563394274030415, 33.138634136744905, 27.785530022212438, 28.810140916279384, 28.22845857484, 26.457906450544083, 25.381442887442454, 30.599717208317347, 27.838164363588604, 32.48134497233799, 25.192505734307424, 25.00448748043605, 60.08771569388253, 74.99766050066266, 22.99395673615592, 30.806794370923722, 32.13795804977417, 31.65511383329119, 38.476834365299766, 42.91114343915667, 41.33838047300066, 44.931926250457764, 37.30745949063982, 32.44176803316389, 20.433078289031982, 14.947423389979772, 5.8751053384372165, 2.2609099490301947, 0.5358702625547136, 0.12666381469794682, 0.0822866406025631, 0.0075283740214737395, 0.021868913933368664, 0.04216288362762757, 0.03627152029158814, 0.039359858858266046, 0.0637250505387783, 0.04224019930032747, 0.01975158611977739, 0.06693351694515773, 0.045049374989633045, 0.02580530252972884, 0.01774367716695581, 0.05880172257976873, 0.027616356599277685, 0.03612138424068689, 0.05450959164383156, 0.043286764927740605, 0.03046277877209442, 0.014238076883235147, 0.03150557853015406, 0.018110769701057246, 0.014190555683204105, 0.09244287133749042, 0.04476792544924787, 0.049594630021601915, 0.03512298781424761, 0.0393721335567534, 0.01617986259848944, 0.03113560052588582, 0.03397170387740646, 0.05303183397544282, 0.03499339780371104, 0.030169926450720856, 0.03889549324022872, 0.06064174670193877, 0.03677320533565112, 0.048908546300871034, 0.03576512621449573, 0.03420529295025127, 0.026658290598009313, 0.0518293749274952, 0.03751909174025059, 0.034236186649650335, 0.05335909480761204, 0.024125449991385852, 0.027717253060213158, 0.020308422490156124, 0.040873226044433456, 0.032935730181634426, 0.01348063163459301, 0.024656005004154782, 0.044724522956780026, 0.02630492822001023, 0.058284733178360124, 0.009367128434990133, 0.036317609782729826, 0.0711205190579806, 0.03562635901783194, 0.03006731838520084, 0.20238517437662396, 0.10677093892757382, 0.13491991667875222, 0.13436434577618325, 0.08776545125458922, 0.14710993399577482, 0.12378411207880292, 0.164365839479225, 0.10187817218580417, 0.1111077412164637, 0.16303254530898162, 0.1423940206212657, 0.11136268039367028, 0.10300006877098765, 0.10830706757094179, 0.11283356110964503, 0.07592160893338067, 0.1446967649140528, 0.09488977718033961, 0.20281375066510268, 0.23650701769760676, 0.2187425230762788, 0.20415218813078745, 0.06414931134453841, 0.20567578423236096, 0.19828094675072602, 0.1616716483341796, 0.2367621197232178, 0.08372452416058097, 0.09422816482505628, 0.14638596427227768, 0.12664850694792612, 0.1033802315858858, 0.17485284246504307, 0.21474804170429707, 0.09191495073693139, 0.1936634752367224, 0.13527230705533708, 0.10506793138171945, 0.11360674497804471, 0.0867281137034297, 0.1950756830296346, 0.16477667886231626, 0.08522875487272229, 0.11889555225414888, 0.1349101322037833, 0.1033444320783019, 0.1301934045872518, 0.13901372200676373, 0.08245225064456463, 0.09624812964882169, 0.12520290166139603, 0.10545583628118038, 0.1774876889373575, 0.16177735051938466, 0.08805856481194496, 0.10080435659204211, 0.11305468210152217, 0.20003315487078258, 0.13321824584688458, 0.08259871242833988, 0.1041117941162416, 0.185023213869759, 0.14122795819171838, 0.11566913181117602, 0.13088970365268843, 0.12168487400880881, 0.17856153845787048, 1.3031698209898812, 4.77926151241575, 9.852114813668386, 19.3721022605896, 29.91837338038853, 40.75926896503994, 49.45729146684919, 50.23277643748692, 59.59962558746338, 58.72258227212088, 64.64891624450684, 60.132330077035085, 60.67943123408726, 55.26470702035086, 57.540547779628206, 47.52465350287301, 53.433168819972444, 42.785721506391255, 47.18284034729004, 40.876387800489155, 36.787779399326865, 39.31460298810686, 37.14463540485927, 34.93911041532244, 35.649115562438965, 41.200552531651084, 39.29369933264596, 42.3094676562718, 35.7447054045541, 34.362614904131206, 63.97348880767822, 79.72304698399135, 34.93773814610073, 44.407674244471956, 42.403636591775076, 40.861706256866455, 47.22504717963082, 48.90826218468802, 48.91976145335606, 51.53365986687796, 41.84465748923165, 36.002129214150564, 22.50766795022147, 16.26861466680254, 5.996126890182495, 2.2953007093497684, 0.4061057599527495, 0.1559755504131317, 0.12988952946450028, 0.1804877229567085, 0.1206848898104259, 0.11849525730524745, 0.15481712828789437, 0.15577352339667933, 0.14497196514691624, 0.09982492521937404, 0.11743899541241781, 0.22650784067809582, 0.16078533232212067, 0.11272817783589874, 0.10294589453509875, 0.15986173759613717, 0.12136126708771501, 0.11841757861631257, 0.13425701510693344, 0.07618296705186367, 0.1171124843614442, 0.1233926380851439, 0.09125022390591246, 0.11539024034781115, 0.12464745289513043, 0.28451122609632357, 0.12948426763926232, 0.12329467119915144, 0.07705287608717169, 0.07667151226529054, 0.11510942184499331, 0.12988141418567725, 0.1386713603777545, 0.1545523503529174, 0.12523437211556093, 0.10776411063436951, 0.12106884563607828, 0.15569964450384888, 0.2165139698024307, 0.13049504054444178, 0.13863915710576943, 0.10483354503022772, 0.12495351290064198, 0.13641605925347122, 0.12421457469463348, 0.15695413361702645, 0.20579612920326845, 0.12919982575944491, 0.09352389297315053, 0.11762002855539322, 0.14421714922147139, 0.21333960656608852, 0.1002251183880227, 0.1069503707279052, 0.1303836250943797, 0.07811278849840164, 0.16968419695539133, 0.11160518880933523, 0.08429880905896425, 0.2297845541366509, 0.10246485391897814, 0.10609042258667094], [0.058568523664559634, 0.05340124540297048, 0.037563461145120006, 0.0598545917975051, 0.05217531582872782, 0.02657956357247063, 0.012951857776248028, 0.08344775651182447, 0.019330034365079234, 0.04078216664493084, 0.02877896698191762, 0.056934400993798456, 0.038324974211198945, 0.02913975083668317, 0.03983091822426234, 0.039285979965435605, 0.04721309763512441, 0.014467476002339805, 0.002698994324808674, 0.05178857800949897, 0.023027641399364387, 0.03468712066699352, 0.02734484420424061, 0.04486621463937419, 0.0779083323265825, 0.038579207711986134, 0.11367227789014578, 0.018723615744550313, 0.1151400509157351, 0.027370029727795293, 0.05746333261153527, 0.03431238952491965, 0.13613754776971682, 0.029475109984299967, 0.08324395851897341, 0.05424159066751599, 0.03881748206913471, 0.029843198268541267, 0.042718878614583185, 0.038027691056153605, 0.02159178496471473, 0.08232683023171765, 0.01759976158583803, 0.06107607018202543, 0.05543613799714616, 0.015932278740885, 0.044225474021264484, 0.0236664176585951, 0.037452113548559804, 0.05133629370746868, 0.06929616230939116, 0.05326124666524785, 0.024344326728688817, 0.06361779450838055, 0.013028550893068314, 0.03921338011111532, 0.022365443807627474, 0.007054751489444503, 0.028586646408907006, 0.024123908020555973, 0.02684240598630692, 0.05368868980024542, 0.040078641181545596, 0.033088044329945526, 0.08779275550373963, 0.03596382501668163, 0.01359542110003531, 0.04458616627380252, 0.052768328293625794, 0.08233105071953364, 0.49830569539751324, 1.7080649116209574, 4.85578202349799, 9.449402434485298, 14.29102533204215, 13.701156275612966, 22.833032982689993, 29.895027433122905, 36.03769704273769, 40.39326565606253, 43.095277650015696, 48.305749143872944, 46.45895964758736, 50.60050984791347, 52.25338901792254, 44.64037983758109, 45.25682749067034, 43.23355375017439, 46.30067620958601, 45.48438446862357, 41.473099095480784, 43.5211501121521, 42.61155448641096, 42.38129465920584, 39.36435209001814, 38.915936197553364, 45.62581157684326, 39.219864300319124, 56.194216183253694, 55.461903844560894, 36.23803792681013, 40.39168494088309, 38.635965483529226, 40.127542223249165, 35.57414102554321, 35.54642813546317, 23.785101209368023, 20.76953785760062, 10.769802485193525, 4.073037053857531, 2.5957861968449185, 0.44347542471119333, 0.03813453996554017, 0.0319829380937985, 0.03955515480733343, 0.07985374650784902, 0.013845049892552197, 0.07258752533899886, 0.008320146356709301, 0.03254348605072924, 0.039385897639606676, 0.02117570729127952, 0.018446966839422072, 0.027331102173775434, 0.0275438296874719, 0.03875563699486, 0.018265565591199056, 0.0220171721386058, 0.01262250535988382, 0.055145019332745245, 0.03086553341043847, 0.04950477841443249, 0.047268639119075875, 0.053863419352897575, 0.04675345462081688, 0.06684209113674504, 0.041189776201333315, 0.01840058557822236, 0.03407900740525552, 0.011003442773861545, 0.04697847040370107, 0.02916146056460483, 0.03183185887922134, 0.01729814937737371, 0.041300543650452576, 0.03631244952391301, 0.05107024012665663, 0.047064915765076876, 0.06646742445549794, 0.02569868941126125, 0.03529807020510946, 0.054191209442381344, 0.012769668579234608, 0.028129970288968513, 0.046378587771739276, 0.025306360463478735, 0.08089769299009017, 0.033873183985373805, 0.016439819542158927, 0.04812840066318001, 0.017260614516479627, 0.02531980224219816, 0.009948960339118327, 0.0344764762558043, 0.02939685114792415, 0.037899861843990426, 0.02293348279116409, 0.01976065643663917, 0.05063478349308882, 0.0627028171771339, 0.01945787205893014, 0.025346427956329923, 0.027587293248091425, 0.039300422583307536, 0.061192866414785385, 0.018544490981314863, 0.07561843270169837, 0.031076228711754084, 0.006445846462156624, 0.05549974386979427, 0.019006469852424095, 0.012573582985039269, 0.04625445657542773, 0.011889791864502643, 0.036600148371819935, 0.012122855920876776, 0.011989883413272244, 0.042539134688143215, 0.030705650203994343, 0.013441665912978351, 0.028225441862429892, 0.05328082240053585, 0.016250520146318843, 0.01682666931966586, 0.006349369808698871, 0.019018429032127773, 0.03074302730549659, 0.017127034720033407, 0.03834526580093162, 0.013027634870793139, 0.06528622390968458, 0.032179550400802066, 0.08912446190203939, 0.05172616635848369, 0.08162662958992378, 0.07413968776485749, 0.06649407731103045, 0.005368720041587949, 0.03904971067926713, 0.025321988821295754, 0.046129456854292324, 0.08414136857858726, 0.025822634010442665, 0.004204541394886161, 0.004563576325641147, 0.034354811534285545, 0.10256991828126566, 0.047090316723499975, 0.03245794653360333, 0.04770288796031049, 0.05266170669347048, 0.025891668163239956, 0.04556398612580129, 0.04427905793168715, 0.1007024949150426, 0.030424947052129676, 0.09212205319532327, 0.05504030102331724, 0.03830992091181023, 0.08665523904242686, 0.020118478486048322, 0.041568887286952565, 0.047899758110621145, 0.01763860771565565, 0.07056145370006561, 0.08519700621919972, 0.0752120241522789, 0.10827570568237986, 0.02724966948984989, 0.02856964910668986, 0.04800536869359868, 0.02048336578133915, 0.05514397778149162, 0.015783810189792087, 0.057725898522351465, 0.12916789390146732, 0.8245897899780954, 2.7873280559267317, 7.482090353965759, 13.302905508450099, 19.631280490330287, 19.550434725625173, 28.579455511910574, 37.54001569747925, 43.54240117754255, 46.68348026275635, 51.408446380070274, 53.54770292554583, 52.38613782610212, 55.60093035016741, 58.30309867858887, 48.34696585791451, 47.961333887917654, 47.63493531090872, 49.324514865875244, 48.00153963906424, 45.05880730492728, 45.33386564254761, 44.94667032786778, 45.77083090373448, 42.58556822368077, 40.10979304994856, 45.48921346664429, 40.406852858407156, 57.233360971723286, 60.811134338378906, 37.815317222050254, 43.962270396096365, 42.97231190545218, 44.73159578868321, 40.19624948501587, 40.01396002088274, 28.891064848218644, 25.08456199509757, 14.795907497406006, 7.621795177459717, 4.46931757245745, 1.19258066373212, 0.20009693716253552, 0.030371359749031917, 0.03567337810194918, 0.05440544330381921, 0.03821439335920981, 0.07757737687123673, 0.025350061511354785, 0.05056436512885349, 0.06874801457992621, 0.07647737661110503, 0.04612207439328943, 0.021029194617377858, 0.057962211913296154, 0.05677835490288479, 0.014103591242539031, 0.040816727826105695, 0.023152120344872986, 0.048240165558776686, 0.04687323301498379, 0.04917882036949907, 0.011902723045620536, 0.03970769965755088, 0.10752781759947538, 0.044556728032018454, 0.018175288203305433, 0.030380065353321176, 0.06306944321841002, 0.01319653750397265, 0.04142554337158799, 0.03169766840125833, 0.05698872450739145, 0.024498457654512355, 0.030593420511909893, 0.020462706086358855, 0.03831585470054831, 0.028529900525297438, 0.017491676046379974, 0.01947553432546556, 0.04535073274746537, 0.07655670414013521, 0.023563755310273597, 0.017605064337008765, 0.011603740160353482, 0.041693554525928836, 0.05453305538477642, 0.03108854072966746, 0.03970807285181113, 0.02217624449570264, 0.0336149912327528, 0.05003553189869438, 0.04188503032284124, 0.03550637027780924, 0.08157609908708505, 0.05668139224871993, 0.011060287893217589, 0.030517020861485174, 0.040117701049894094, 0.07208310240613562, 0.016843714119334306, 0.041720007213630846, 0.04291409992479852, 0.048657831004155536, 0.05599999041961772, 0.052356654312461615, 0.1432516753141369, 0.13410749313022408, 0.1670316950018917, 0.14714728056320123, 0.1355103099984782, 0.0987147062218615, 0.147389164726649, 0.1314238328486681, 0.10861866442220551, 0.30749551419700893, 0.15434117668441363, 0.10659959526466471, 0.1261473409831524, 0.09807274424071823, 0.12867226478244576, 0.08618804054068667, 0.13493697504912103, 0.10000238926815135, 0.04921099650008338, 0.1499442154807704, 0.20613055197255953, 0.07934831934315817, 0.2734362318047455, 0.1233502703585795, 0.17359521852007934, 0.21465536739145005, 0.2027164487434285, 0.09185017778405122, 0.1520389345075403, 0.17647630535066128, 0.1522425085838352, 0.12181279143052441, 0.24964725545474462, 0.12258653848298959, 0.133912645014269, 0.19474759777741774, 0.13426590391567775, 0.16992851027420589, 0.10771838415946279, 0.1478954197040626, 0.15290653652378491, 0.2073525663997446, 0.11144944466650486, 0.08899268361606769, 0.1632280855306557, 0.14131004735827446, 0.14677973171429975, 0.20954536087810993, 0.1831416498337473, 0.14239920462880815, 0.1693531261490924, 0.1249221781534808, 0.09418496250041894, 0.1821300219744444, 0.08622092234769038, 0.09335397423378058, 0.07589597388037614, 0.07647515101624386, 0.15126802373145307, 0.19588194548019341, 0.09594523840184722, 0.09712473582476377, 0.1559465498264347, 0.18318960868886539, 0.15606734263045446, 0.09699888114950486, 0.16104093646364553, 0.16402985607939108, 0.17648625267403467, 0.27613348992807524, 0.908734917640686, 2.7345777664865767, 7.305480173655918, 13.413895164217267, 22.230481726782664, 24.778304508754186, 31.51950236729213, 41.923391001565115, 48.0356240272522, 51.882751260484966, 56.837091309683665, 63.33528981889997, 61.827697481427876, 64.4162210736956, 67.12952041625977, 59.13267190115792, 58.389027050563264, 57.539887700762065, 58.77231747763497, 58.396232332502095, 55.83141251972744, 55.84065362385341, 56.98561947686331, 55.27887092317854, 51.88710083280291, 51.51048067637852, 57.19805022648403, 50.52838407244001, 64.61170864105225, 64.85172721317836, 49.50836420059204, 53.18681001663208, 52.593882015773225, 53.64786120823452, 48.215280124119346, 46.63481160572597, 34.968449183872764, 29.014193875449045, 17.542860439845494, 9.449266944612775, 4.476752579212189, 1.7571353699479784, 0.3059874294059617, 0.1134536267657365, 0.09884246758052281, 0.21693064458668232, 0.09567456399755818, 0.10471596169684615, 0.11089812817850284, 0.12321013930652823, 0.19708394312432834, 0.16304196337504046, 0.11052960902452469, 0.11148585485560553, 0.15235275695366518, 0.0976947730939303, 0.08469109050929546, 0.14290494391960756, 0.10082542510437113, 0.13520494209868567, 0.06280244647392205, 0.14024871002350534, 0.13934148156217166, 0.23182328045368195, 0.18934925459325314, 0.11899085928286825, 0.14965863366212162, 0.12298496067523956, 0.1819140985608101, 0.12733755925936358, 0.16468757364366735, 0.10386074294469186, 0.13571134635380336, 0.1304109836263316, 0.23813832444804056, 0.13824918945985182, 0.15953929775527545, 0.09591590533299105, 0.16554543189704418, 0.13828059206051485, 0.12376980856060982, 0.1618545406631061, 0.06048338341393641, 0.11565451616687433, 0.10908111317881516, 0.12933076944734367, 0.23628160836441175, 0.07182733541620628, 0.08232742734253407, 0.20012364430086954, 0.07737913608018841, 0.15919640686895165, 0.13884108912731918, 0.0927533825327243, 0.11174967605620623, 0.09899148744131837, 0.10659447911062411, 0.1521892842969724, 0.15711082092353276, 0.1377986150660685, 0.06580469930278403, 0.11182631658656256, 0.10904190064008747, 0.11724640003272466, 0.18457861058413982, 0.12175593019596168], [0.020194621989503503, 0.015847178575183665, 0.04140759272766965, 0.03298346172752125, 0.041249585670552084, 0.09151359727340085, 0.06833876296877861, 0.036252975929528475, 0.08454536832869053, 0.010446890540021871, 0.0487496198288032, 0.020596216332965663, 0.041648092679679394, 0.02686275864419128, 0.015347951524225729, 0.03395930704261575, 0.03285094044570412, 0.05282668909057975, 0.03247496758454612, 0.006693717848975211, 0.008387674161765193, 0.015207228450370687, 0.042341938841023614, 0.012535240667472993, 0.016967974237299392, 0.028750726354441473, 0.0534911512929414, 0.04474645320858274, 0.007405406512719179, 0.04941649083048105, 0.019186356271217977, 0.03882720208327685, 0.03580124802621348, 0.03334478162495153, 0.040136693245066066, 0.05493022907259209, 0.046498522228960476, 0.04758499250082033, 0.038340047866638215, 0.03481687691860965, 0.045501072358872206, 0.08986323725964342, 0.038870502795491896, 0.03654212684237531, 0.024955089669674635, 0.045741202509296794, 0.02496064856781491, 0.013562630047090352, 0.010457872629298695, 0.017584803281351924, 0.018953861336090734, 0.045753456851733584, 0.05176855783377375, 0.044638298119285276, 0.025204829572300826, 0.05298912698136909, 0.008046265874457146, 0.07197250798344612, 0.03937204195452588, 0.02442951680028013, 0.02109174197539687, 0.006900573490254048, 0.025690937148673192, 0.04224915596257363, 0.006887801764865539, 0.03262432332017592, 0.059083769230970314, 0.046197442670485804, 0.04454180026160819, 0.03323958155566028, 0.007895901666155883, 0.05405886797234416, 0.2094402015209198, 0.5644442949976239, 1.8131861622844423, 3.3685950253690993, 6.227808058261871, 6.485897592135838, 12.45232788154057, 14.955657005310059, 19.24140317099435, 28.96559817450387, 30.991293362208776, 31.62540681021554, 35.33729083197457, 38.54576744352068, 45.3072054045541, 42.124906131199424, 41.61477633884975, 43.08212471008301, 45.602344036102295, 45.966214248112266, 44.92527335030692, 45.451661927359446, 42.414534841264995, 45.226502077920095, 43.089333466121126, 43.85507011413574, 40.97282532283238, 45.23373515265328, 43.54254361561367, 39.72437994820731, 32.58653027670724, 27.715612036841257, 25.04832019124712, 14.459972517830984, 8.173544679369245, 4.17354622057506, 1.9596805700234003, 0.7353176517145974, 0.07474177902830498, 0.038799341435411146, 0.028818939479866197, 0.06942197627254895, 0.021247374159949164, 0.012869833918687488, 0.03945505732138242, 0.03082617837935686, 0.059162737136440616, 0.031359500118664334, 0.06305564860148088, 0.006524843205365219, 0.022734370082616806, 0.009715363632754555, 0.008403844499428357, 0.026133460724460225, 0.040040158067962954, 0.05296821113941925, 0.031386773833738904, 0.0532350145014269, 0.05291596055030823, 0.032283054132546694, 0.020904603713591183, 0.027909911204395548, 0.03581898832427604, 0.03428502081494246, 0.01886259837608252, 0.018350119536210383, 0.032837607232587676, 0.03839680053559797, 0.07532155327498913, 0.05839692215834345, 0.05972590084586825, 0.01826045791884618, 0.020491727029106448, 0.046483723380203755, 0.04330829484388232, 0.03781234100461006, 0.04802451016647475, 0.050987129764897485, 0.06075921468436718, 0.011901952060205596, 0.03607812084789787, 0.08120264019817114, 0.013265045792130488, 0.022861654770427516, 0.007030529061531914, 0.058718038855918815, 0.022431701055860946, 0.10520849669618265, 0.043336247093975544, 0.047907018435320685, 0.10238745342940092, 0.025150339817628264, 0.010796051089917975, 0.011902724741958082, 0.036077927465417554, 0.05846328966851745, 0.04413121872182403, 0.007033133787834751, 0.014820655175883855, 0.04485730208190424, 0.04015131228204284, 0.04614330914669803, 0.02398592622817627, 0.021782685703198825, 0.019161954455609833, 0.04122830341969218, 0.026133481080510786, 0.03453500329383782, 0.014391815955085414, 0.02978823353935565, 0.09173613640346698, 0.04100368797246899, 0.024916408084599034, 0.044587913501475535, 0.012631902221723326, 0.036117621764008484, 0.039490548095532825, 0.0207544625736773, 0.018547632598451207, 0.019038306715499078, 0.035812769550830126, 0.04502261356849756, 0.013831595391301172, 0.01625476947187313, 0.014195053522208971, 0.02238114001894636, 0.024232405770037855, 0.026767648390627334, 0.036508033850363324, 0.09096215186374527, 0.08160248052861009, 0.017658733064308763, 0.0031383692860669854, 0.02155620089199926, 0.016059312370738814, 0.04718370349811656, 0.029804925500814403, 0.09835563906069313, 0.031829229556024075, 0.05300149667475905, 0.048568532403026304, 0.0461646592510598, 0.01409334790826376, 0.044935411640575955, 0.024294624038572823, 0.03298667798350964, 0.0058997937095617604, 0.011433805305776852, 0.040572913230529854, 0.052462709335876365, 0.046114495157131126, 0.11332575005612203, 0.04201993326257382, 0.05443369750199573, 0.06349871161260776, 0.1081991805029767, 0.01893305405974388, 0.06933293212205172, 0.06318799685686827, 0.0206765972876123, 0.01764280445474599, 0.01912242639809847, 0.021096568055717007, 0.01690808673655348, 0.04360424128494092, 0.034178076910653284, 0.04691066439928753, 0.044510014288659604, 0.06301294160740716, 0.03889980533027223, 0.06182532212031739, 0.04153351864910551, 0.03052292750882251, 0.023901879488091384, 0.05966845607118947, 0.04553619672411254, 0.3682700773434979, 0.9047533827168601, 3.0206396622317175, 4.872056441647666, 8.671979784965515, 10.545824698039464, 17.615198135375977, 21.210251671927317, 25.619196346827916, 36.05194432394845, 37.801691804613384, 37.835831778390066, 42.6581768989563, 46.049995626722065, 51.30462639672415, 48.205305985042024, 48.150915486471995, 48.78389637810843, 51.42997537340437, 53.23708023343767, 51.89344801221575, 49.96323149544852, 49.25701311656407, 51.828753335135325, 50.77820307867867, 47.75849512645176, 47.57710197993687, 50.19789300646101, 48.26339987346104, 46.04674734388079, 39.64641768591744, 33.42410434995379, 29.32641465323312, 19.165732077189855, 10.379399708339147, 6.3831029023442944, 2.5992173041616167, 1.0013904486383711, 0.1027483187083687, 0.03145554335787892, 0.012060511275194585, 0.05875903594174555, 0.03929001046344638, 0.015351975236886313, 0.008797157322987914, 0.036900369583496025, 0.05581591065440859, 0.0779042679018208, 0.08627925600324358, 0.035881742635475736, 0.038428345628614934, 0.012912244901859334, 0.05797244422137737, 0.04898467792996338, 0.085388841639672, 0.04332672385498881, 0.05204052145459822, 0.07756756525486708, 0.0222544066408383, 0.05009892064013651, 0.00810500665102154, 0.04372345988771745, 0.03702757115076695, 0.04777727575440492, 0.08283934130200318, 0.020269578056676046, 0.03182222368195653, 0.043880883404718976, 0.021470059175044298, 0.027194492718470947, 0.02435806706281645, 0.07463994449270622, 0.017114753236195872, 0.045687004524682245, 0.02106597800073879, 0.02476043493619987, 0.06975148644830499, 0.05595144123903342, 0.049235427153429816, 0.004159699135925621, 0.05128734419122338, 0.03165295972887959, 0.06941374564277274, 0.05938083864748478, 0.041208748040454726, 0.03932269888796976, 0.015207058816616024, 0.028836377829845463, 0.038569633582873006, 0.025210225622036626, 0.025732268412996615, 0.03584634346355285, 0.0029854467887032244, 0.03578553654785667, 0.06118411331304482, 0.008689618852388645, 0.04613990629357951, 0.012156703792113279, 0.04093563091009855, 0.0071049232168921405, 0.016376524099281857, 0.015649970853701234, 0.05329975352755614, 0.061034428487930975, 0.08806638153535978, 0.13530394035790647, 0.10740146759365286, 0.21150562140558446, 0.06225575080939701, 0.24419091109718594, 0.22052435603524956, 0.11375691834837198, 0.17396511510014534, 0.1473783760198525, 0.0713028549881918, 0.13343502421464237, 0.08863766052361045, 0.18222572255347455, 0.061915743696902475, 0.15323549030082567, 0.07797534444502421, 0.14007039102060453, 0.16626621250595364, 0.09149243376616921, 0.1406559667416981, 0.07785710971802473, 0.1737467082483428, 0.07342023708458457, 0.11170055012085608, 0.1990138731364693, 0.2035945409110614, 0.10063116052853209, 0.06787560853574957, 0.13861022437257425, 0.12727843171783856, 0.09275404749704258, 0.12818842860204832, 0.2322464148913111, 0.211658169648477, 0.15294194248105797, 0.09002485751573529, 0.17089227427329334, 0.07525350978331906, 0.1198945865035057, 0.103560457272189, 0.2974058613181114, 0.15180295359875473, 0.1152708317552294, 0.15112915475453648, 0.14481397505317414, 0.13182144079889568, 0.19337873480149678, 0.10834585941795792, 0.118097472935915, 0.18178087499524864, 0.15935013576277665, 0.09651933331042528, 0.12674042130155222, 0.15521214423435076, 0.0915750725460904, 0.10652704630047083, 0.1687092235577958, 0.0761547332097377, 0.11815327565584864, 0.09777541019554649, 0.13721066447240965, 0.13977055996656418, 0.0960803415094103, 0.16548903206629412, 0.12420150611017432, 0.17334861175290175, 0.1244709523660796, 0.12928458835397447, 0.12485294044017792, 0.12145152581589562, 0.15478480287960597, 0.5129209597195897, 1.0039974344628197, 2.9412234893866946, 4.417855305331094, 8.289984328406197, 10.396236062049866, 17.124775171279907, 22.019395453589304, 27.3481148651668, 37.418210302080425, 40.71554742540632, 42.30597966057913, 47.159021922520225, 52.11756910596575, 56.041699750082834, 54.86721794945853, 55.117749146052766, 58.77535384041922, 57.32842969894409, 60.83649526323591, 57.98299864360264, 58.49445901598249, 56.2549330166408, 58.27224520274571, 58.54415948050362, 56.83909239087786, 55.99746404375349, 59.77321243286133, 57.136801855904714, 55.025067125047954, 47.27174602236067, 39.20708656311035, 33.54727159227644, 21.827338559286936, 11.934093884059362, 6.1889606799398145, 2.815646742071424, 0.8858960260237966, 0.2149348831070321, 0.15453077293932438, 0.07669515242534024, 0.13622719581638063, 0.1392615501369749, 0.061056894782398424, 0.14578936914248125, 0.1279565460447754, 0.17777272792799131, 0.10614066131945167, 0.15830224699207715, 0.14123000736747468, 0.26520828902721405, 0.09211000919874225, 0.10575779114982911, 0.17002486224685395, 0.143422326871327, 0.14834135291831835, 0.11758287197777204, 0.13992499453680857, 0.17309270905596869, 0.08659750249769006, 0.09031538585466997, 0.14809998444148473, 0.1520786423768316, 0.14751305165035383, 0.12686912582388946, 0.09662719323698964, 0.14726766624620982, 0.11724659002252988, 0.14980632359428064, 0.1437605358660221, 0.08484011715544121, 0.2504854904753821, 0.15168176724442414, 0.08456893384988819, 0.1473514653210129, 0.17116527605269635, 0.13147568649479321, 0.17924485036305018, 0.13277844658919744, 0.09293162011142288, 0.14934330486825534, 0.1794546398201159, 0.16926531014697893, 0.145623223057815, 0.13572856757257665, 0.11609921444739614, 0.0816880709358624, 0.1742683116878782, 0.09707299074424164, 0.11696712858974934, 0.24082217471940176, 0.1877176628581115, 0.08261917704450232, 0.13976490098450864, 0.11624588657702718, 0.11593435757926532, 0.10508583792086158, 0.1556460673787764, 0.10453930510474102, 0.1353681976241725, 0.11381970319364752, 0.12694115910146916, 0.10888923704624176, 0.0683515669245805], [0.0043299821637836945, 0.03243038783382092, 0.03886830094935639, 0.07856233151895659, 0.05359444467883025, 0.004617063120739269, 0.007345855734976274, 0.010565941205381282, 0.04291409653212343, 0.09044862977628197, 0.048115742592407126, 0.04884161560663155, 0.07985984653766666, 0.03078119150762047, 0.08861120444323335, 0.05977763914104019, 0.041182722829814465, 0.03970092109271458, 0.019075222413188646, 0.06656351858483893, 0.01621007776286985, 0.016818099422380328, 0.058086248114705086, 0.017683424953637377, 0.05004398983770183, 0.029838414596659795, 0.034060541074723005, 0.0334821510394769, 0.028903780105922903, 0.06902550826115267, 0.04812493334923472, 0.023047853261232376, 0.0234280805369573, 0.027477119517113482, 0.019175567564421465, 0.022798489945541536, 0.043195271265826056, 0.027040310902521014, 0.020650300662964582, 0.010854645133284586, 0.015645121024655442, 0.08789137378334999, 0.027202053294916238, 0.013489794401851083, 0.04360835659982903, 0.0378711123152503, 0.005740511854777911, 0.01823448868734496, 0.044006632907049995, 0.03277893770220024, 0.04382774054205843, 0.05538495270801442, 0.05226031591051391, 0.03946363400401814, 0.05511081438245518, 0.01111541038179504, 0.05162895943171211, 0.026080616417207887, 0.010323740674981048, 0.0207281303259411, 0.026733745388420563, 0.0621083119351949, 0.00198268165695481, 0.034500856019024334, 0.07238116248377732, 0.049751022165375094, 0.04385310418105551, 0.0156730563113732, 0.06494043567883116, 0.005090109322087041, 0.008395036266717528, 0.017621686748628105, 0.017911378793152313, 0.015261609639440264, 0.018469689280859063, 0.046343246275292974, 0.18264326586255006, 0.620708527309554, 0.6518455765077046, 1.524446495941707, 2.594379403761455, 4.9631907514163425, 6.963635316916874, 9.080206428255353, 12.388842191014971, 14.668647766113281, 16.359952211380005, 17.55809610230582, 21.890539373670304, 21.683543852397374, 22.339650085994176, 20.276024682181223, 21.73797082901001, 20.843765463147843, 25.510825293404714, 24.377532414027623, 24.784868819372996, 28.224920204707555, 26.222308669771465, 22.670959302357264, 20.227432455335343, 17.235317536762782, 11.071098957742963, 7.51973569393158, 4.177766816956656, 0.7996277351464544, 0.2609421765165669, 0.10744438493358237, 0.04220624201531921, 0.015079877605395657, 0.03254693979397416, 0.04435319806049977, 0.0075115005518975, 0.029237096863133565, 0.04968240870428937, 0.029686225977327143, 0.041932802580829175, 0.05261512526444026, 0.06458783495639052, 0.03155483677983284, 0.004277975423195, 0.03350861729787929, 0.017305411398410797, 0.03142850713006087, 0.026168488398460404, 0.05936684047005006, 0.04342242443401899, 0.03706990495058043, 0.012508000030980577, 0.03704720116885645, 0.03089174521820886, 0.04832811726789389, 0.023436363753197447, 0.02426344874714102, 0.04839856955888016, 0.038474353695554395, 0.021769422039921795, 0.023535723332315683, 0.052961992365973334, 0.02111310395412147, 0.029145280897085155, 0.04024986610082643, 0.010471059957386127, 0.05009349235998733, 0.03225399926304817, 0.030895192176103592, 0.07613028559301581, 0.09388005600443908, 0.041354127560875246, 0.050396417533712726, 0.03622565471700259, 0.021560394238414507, 0.04053451493382454, 0.020666096958198717, 0.03212051785417965, 0.03641307626717857, 0.026051167997398546, 0.04035067944122212, 0.04984890762716532, 0.03982350183650851, 0.029440525054399456, 0.03624916256272367, 0.0341147628080632, 0.032207831740379333, 0.04257091726841671, 0.03569153230637312, 0.01740271332008498, 0.02403603434296591, 0.0613128449767828, 0.05730722884514502, 0.01486570990112211, 0.013639148441143334, 0.05208518262952566, 0.02759351202153734, 0.018293528019317558, 0.029070021185491766, 0.018520616726683717, 0.023197795929653302, 0.04364627992202129, 0.09963446722498961, 0.0251568978585835, 0.01151265955663153, 0.01108344629340406, 0.014772117869662387, 0.012797532619775405, 0.053215744106897285, 0.029929935399975096, 0.02334011186446462, 0.042067403572478464, 0.041517176133181365, 0.04979851622400539, 0.05192628329885857, 0.0073571423168427175, 0.01498632289336196, 0.024593812180683017, 0.019332378703568662, 0.02488650843900229, 0.06215204351714679, 0.03561421663367322, 0.0037310617792952272, 0.023258414551881806, 0.04449025195624147, 0.02718436049430498, 0.004451384801151497, 0.005909619320716176, 0.04084562663254993, 0.07556045188435487, 0.034899464808404446, 0.0914155218218054, 0.03764728057597365, 0.03346275172329374, 0.027839620065476214, 0.044881627562322786, 0.02487754838408104, 0.0630642252841166, 0.034730719934616766, 0.018100763005869727, 0.013170418146598552, 0.013438400463201106, 0.04647293806608234, 0.04008241383624928, 0.042857913832579336, 0.025316402781754732, 0.01837484195961484, 0.044892029504158666, 0.043368277339530845, 0.03176928437980158, 0.015141975433964814, 0.085044851526618, 0.052130308600940874, 0.02297903623964105, 0.040237598187689266, 0.0065444681344420785, 0.018838400120979974, 0.06059914148811783, 0.032736980489322116, 0.02235518944715815, 0.01879350994048374, 0.012818781792053154, 0.04950074452374663, 0.04612035430701716, 0.024028037807771137, 0.05527775774576834, 0.008543849174332405, 0.019665590287851434, 0.03705118756209101, 0.10516778459506375, 0.03819056660202997, 0.03704905356945736, 0.04705899554703917, 0.032832684461027384, 0.09087266666548592, 0.38682442743863377, 1.0025769621133804, 1.3453299701213837, 2.6313405632972717, 4.8797971691404065, 7.896524344171796, 10.074371184621539, 13.176814811570303, 16.552992275782994, 20.236131599971227, 21.543148551668438, 23.108172961643763, 26.79595194544111, 29.625048228672572, 29.91965879712786, 26.603554589407786, 27.537743364061626, 28.996818167822703, 30.98949030467442, 30.251431805746897, 30.880990709577286, 33.33853728430611, 30.913629872458323, 27.836458580834524, 25.061328956059047, 21.222775799887522, 15.665528399603707, 9.974086965833392, 5.703111801828657, 1.314333513379097, 0.5360275198306356, 0.20551309867628983, 0.08672667520919017, 0.04769984473075185, 0.023703903325700333, 0.05056061961555055, 0.01139131374657154, 0.03495140327140689, 0.04342624458617397, 0.04931689206776874, 0.03439418013606753, 0.04547043311010514, 0.011977383101891195, 0.00926932948641479, 0.03430887132084795, 0.08317330266748156, 0.04577893584168383, 0.1166899741760322, 0.04078680103910821, 0.058407419095081944, 0.03853541166920747, 0.06942142665918384, 0.029999118830476488, 0.015123624454385467, 0.03344633456851755, 0.04862038265647633, 0.030360713534589325, 0.040437844049717696, 0.028075573832861016, 0.027534954449427978, 0.03616567561402917, 0.024536727029564123, 0.022309481631964445, 0.016416679801685468, 0.04520231339016131, 0.018226956948637962, 0.042086504333253415, 0.06463996001652308, 0.035328970689858706, 0.14276946761778422, 0.03878642212865608, 0.03837470065004059, 0.03330374043434858, 0.0404642492399684, 0.02450802330193775, 0.04716263498578753, 0.01299444941936859, 0.039700822705136876, 0.052381030683006556, 0.04623477566721184, 0.017718540837189982, 0.02486354681397123, 0.05894390280757632, 0.008450530253217688, 0.014658553159928747, 0.0291785426836993, 0.05515796917357615, 0.018028868827968836, 0.023185673901545148, 0.0037421354707995696, 0.016545340219246488, 0.022240006431405033, 0.030229929302419935, 0.03384644631296396, 0.06067105941474438, 0.028167908878198693, 0.02441756270958909, 0.06299821739750248, 0.0449490434091006, 0.030377768512283052, 0.10311586077192, 0.07950349351657288, 0.1062730842136911, 0.20776819624006748, 0.07821689612631287, 0.1311229704213994, 0.09013898710587195, 0.05367721577308007, 0.17022432440093585, 0.19509165574397358, 0.10577839147299528, 0.13467169499823026, 0.14575337964509213, 0.14573854686958448, 0.20280049209083828, 0.2032151719821351, 0.13396836631000042, 0.12890726860080445, 0.1087009571492672, 0.11820309369691781, 0.09410914299743516, 0.13119733785944326, 0.11742779958461012, 0.12735144208584512, 0.12467429574046816, 0.11485145640160356, 0.1658772219504629, 0.08568741740392787, 0.10286742874554225, 0.17283595140491212, 0.14202545396983624, 0.0861240682591285, 0.1595254149287939, 0.13161074210490498, 0.07951120845973492, 0.09685757623187133, 0.19410041107663087, 0.11287311970123223, 0.17483491556985037, 0.08960512932389975, 0.11135527079126664, 0.17519517695265158, 0.13247485645115376, 0.22434190261576856, 0.2580516444785254, 0.084184367342719, 0.12920955595161232, 0.16503966546484403, 0.17757238367838518, 0.0942298136651516, 0.09053370449692011, 0.18552672756569727, 0.14981490027691635, 0.17098303511738777, 0.12241805823785917, 0.10344349819102458, 0.13472274797303335, 0.08794656582176685, 0.1155175878001111, 0.12430270282285553, 0.1366211668189083, 0.11164354639393942, 0.07082677446305752, 0.11495870564665113, 0.14755039821778024, 0.13070473500660487, 0.17869731331510202, 0.1427392185266529, 0.10137659910001925, 0.13158775333847317, 0.14353908917733602, 0.12394804613930838, 0.13118943971182617, 0.11821496805974416, 0.11216966209134885, 0.1452874160770859, 0.45299459248781204, 1.0170231355088097, 1.206807317478316, 2.288163172347205, 4.6123644794736585, 7.218061413083758, 9.495743444987706, 13.452808550425939, 16.018335342407227, 20.14374140330723, 22.397971527917043, 24.211706706455775, 27.893348693847656, 30.008109365190776, 30.35322638920375, 28.257508993148804, 29.19252634048462, 29.23899241856166, 33.88590594700405, 33.47154317583357, 34.18938589096069, 37.239304610661094, 35.478050913129536, 32.674768924713135, 29.91912031173706, 24.66564815385001, 18.684492894581386, 12.326522929327828, 6.855576063905444, 1.8178894413369042, 0.6688926560538155, 0.2947395715330328, 0.12680475999202045, 0.14611049262540682, 0.10840164856719119, 0.13811603374779224, 0.13534733945769922, 0.08751817273774318, 0.1063126428052783, 0.1119729887161936, 0.06708538665303163, 0.12227137253752776, 0.18795401017580712, 0.18286501110664435, 0.09604847750493459, 0.17594369607312338, 0.08582406757133347, 0.256745057446616, 0.124894168227911, 0.32106852158904076, 0.12198036243872983, 0.18514107540249825, 0.10240917333534785, 0.10067218475575958, 0.05846250256789582, 0.11874284116285187, 0.06815337363098349, 0.1252651640347072, 0.13292441304240907, 0.1797599262957062, 0.15664031117090157, 0.07605600636452436, 0.1660578479724271, 0.069114810254957, 0.1608970191861902, 0.18319741184157984, 0.094347790548844, 0.18770673844431127, 0.18928824072437628, 0.18658387155405112, 0.09933454117604665, 0.13274901174008846, 0.0853487334347197, 0.15110383182764053, 0.2756916550653321, 0.08258159298981939, 0.14472586049565248, 0.1020895087027124, 0.1454789936542511, 0.11022345402411052, 0.12125173796500478, 0.09404567283179079, 0.09932147259158747, 0.09459354236189808, 0.2207796751920666, 0.1938332582690886, 0.10437586637479918, 0.1575700127120529, 0.10921610772077527, 0.1528562299375023, 0.10565218395952668, 0.08960498004619565, 0.1450173727103642, 0.14825395760791643, 0.16304501678262437, 0.11392564965145928, 0.15702402272394725, 0.1352944408676454, 0.12474592189703669, 0.20715376920998096], [0.03890822934252875, 0.01780285220593214, 0.05655426871297615, 0.06078957234110151, 0.051404099711882215, 0.03518506019775357, 0.05564098432660103, 0.039644005575350354, 0.026575638247387748, 0.04275615054315754, 0.0504421134745436, 0.02863987748111997, 0.013524836494720407, 0.03263142079647098, 0.010870822256297936, 0.061558413585381846, 0.025174405758402178, 0.030523416054035937, 0.017633686640432904, 0.028610296746981994, 0.03593762677961162, 0.05468353409586208, 0.05629165530470865, 0.040535834684435806, 0.0323132251921509, 0.04895331943407655, 0.05062312626146844, 0.029535272291728427, 0.03933132646073188, 0.04239715802084122, 0.014091898387830173, 0.038754666689783335, 0.046131539956799576, 0.013217933409448181, 0.0908355779413666, 0.034033786438937695, 0.04359996312164834, 0.013508549957935299, 0.03294667834416032, 0.012816102426898266, 0.04104552983439394, 0.021626620952572142, 0.07362567034683057, 0.0315554101419236, 0.01700705785437354, 0.03331943494932992, 0.008603876622925912, 0.025450640757169043, 0.025183148682117462, 0.012709930356192802, 0.05959986975150449, 0.03159896530477064, 0.03484353995216744, 0.030966146583003656, 0.007733328068362815, 0.01575451104768685, 0.023198482946359684, 0.017036991426721215, 0.029931265328611647, 0.04431715088763407, 0.039393083325454166, 0.014951078088155814, 0.05938590730407408, 0.041375226607280116, 0.03150323419166463, 0.03292157254847033, 0.00930252596403339, 0.03396066411265305, 0.018303670421508805, 0.10472055537892239, 0.032689849446926794, 0.04405982665983694, 0.011367810141694332, 0.08040454730923687, 0.029107503459921906, 0.057385382508592944, 0.009629970000657653, 0.026914266237456883, 0.0697031340428761, 0.08361989406070539, 0.04038228899506586, 0.037943016671176465, 0.1736296745283263, 0.3023494503327778, 0.904637271804469, 1.1191559008189609, 1.3940138263361794, 1.6409900422607149, 2.327118464878627, 2.1241700521537235, 2.3984584425176894, 1.8911991247109003, 2.2538038960524966, 3.0071356211389815, 2.7017201696123396, 3.530807886804853, 4.854475327900477, 5.193223459380014, 6.0110815848623, 3.31996089220047, 2.218352232660566, 1.3415643721818924, 1.0385649395840508, 0.29579854756593704, 0.010767773991184575, 0.038080294483474324, 0.037938962424440045, 0.013505094518352832, 0.04839796905538865, 0.049889100648994954, 0.029223115649074316, 0.034759662845837216, 0.036799220368266106, 0.013538422462131296, 0.0032248057416706744, 0.06811803552721228, 0.03306848895070808, 0.04952732613310218, 0.03915806254372001, 0.02094671529318605, 0.05125327494793704, 0.010815011054676558, 0.028224654761808257, 0.03077542395996196, 0.010296746007432895, 0.02346012944222561, 0.049772952417177815, 0.024365873608206, 0.03753029774608357, 0.018163710699549744, 0.07070540490427188, 0.018518177393291677, 0.031816768260406594, 0.042069144014801295, 0.026822926942259073, 0.014100802463612385, 0.046717770464186154, 0.018418536222140704, 0.023487136832305362, 0.022681907451312457, 0.010960304910050971, 0.034590300505182574, 0.043867974275989194, 0.04931674957541483, 0.042335336695292165, 0.04323757453156369, 0.0353099479606109, 0.02976693432512028, 0.03711287996598652, 0.08598306868225336, 0.03700594963239772, 0.055654032555009635, 0.034995993200157366, 0.050641562057925124, 0.030350111424922943, 0.006803383526857942, 0.05540540375347648, 0.035632855990635495, 0.04171393093253885, 0.10927170688020331, 0.033444539843393226, 0.03315032705930727, 0.04821735321144972, 0.03451520364199366, 0.029186596894370656, 0.04170907262180533, 0.01584032197882022, 0.029195638373494148, 0.06502267412309136, 0.03294791667056935, 0.046657139967594824, 0.030158499921006814, 0.036726651048021655, 0.02313811198941299, 0.04045557416975498, 0.07735562484179224, 0.01844132990975465, 0.02065187825688294, 0.042673433731709204, 0.03754072004397001, 0.015323593813393797, 0.022650070588237474, 0.03371955008645143, 0.004089840563080672, 0.05847647360392979, 0.01665740706292646, 0.023849873171587075, 0.031205092689820697, 0.032548649702221155, 0.0042435236557919, 0.014841986620532615, 0.028179820560451065, 0.10818603049431529, 0.08192016383899109, 0.006952745623753539, 0.0068942363972642594, 0.024659284024632404, 0.0968174815976194, 0.06384053041360208, 0.035864680872431824, 0.0075257786250274095, 0.0506674787029624, 0.03835304859759552, 0.01665677093634648, 0.024001993937417865, 0.012041691258283598, 0.007241430043775056, 0.0593482486105391, 0.02555006479711405, 0.031123458141727105, 0.035230047069489956, 0.0680815778406603, 0.042790772792484076, 0.053795959401343546, 0.03309614943074329, 0.05181137678612556, 0.01038045178367091, 0.033661148577396355, 0.036028523330709765, 0.061501423429165564, 0.019271364834691797, 0.029320224188268185, 0.04825117478945425, 0.012190045306592115, 0.04349388434950795, 0.004728358130835528, 0.05022987111338547, 0.06436581151293856, 0.010093874214882297, 0.03919821146077343, 0.04688603697078569, 0.03799838852137327, 0.052133680919983556, 0.005823175655677915, 0.06262974574097566, 0.05100251215377024, 0.04568767288167562, 0.010901014520121472, 0.018084294960967133, 0.09057131569300379, 0.004072131223178336, 0.04945069578077112, 0.017277182645297477, 0.04918231482484511, 0.015287670473169004, 0.020344505286110297, 0.0516883583872446, 0.06890324303614241, 0.04407195886597037, 0.014015171344258955, 0.03432612307369709, 0.07226140783833605, 0.0630714584674154, 0.05022248525970748, 0.024869679074202265, 0.04297041493867125, 0.07127308087157351, 0.27373777276703287, 0.4210253336599895, 0.6290666673864637, 1.5109829498188836, 2.012627580336162, 2.5054468044212888, 3.213464115347181, 4.267781163964953, 4.153413380895342, 4.4573870812143594, 4.294545190674918, 4.356886165482657, 4.971683187144143, 5.24569799218859, 6.172668022768838, 7.246228975909097, 7.31658513205392, 8.066226278032575, 4.976235994270869, 3.394312696797507, 2.0417353212833405, 1.4460425887789046, 0.671044263456549, 0.17984985932707787, 0.04867062478193215, 0.03190977844808783, 0.013443498805697476, 0.0033301315519825687, 0.024031567886205654, 0.058266039538596354, 0.014489043237907546, 0.025100545525284748, 0.10186336655169725, 0.015124284329691103, 0.025875067804008722, 0.05243965610861778, 0.044850011223128865, 0.042775135952979326, 0.06831038663429873, 0.03162105840497783, 0.033651835684265406, 0.03287716921684997, 0.08166371831404311, 0.015493812804509486, 0.0713242899094309, 0.019492411187716892, 0.01976603382666196, 0.06729432115597384, 0.0025070433413410293, 0.0779389546119741, 0.03086302283086947, 0.046628129202872515, 0.008746150149298566, 0.024237723788246512, 0.04442463083458798, 0.045140444567160945, 0.022531740866335373, 0.029156917772654976, 0.024465085605957677, 0.04705585392990282, 0.023601580244888152, 0.016906334419867823, 0.03898884608809437, 0.024535397100927572, 0.02541885817689555, 0.04964539801169719, 0.023319949196385484, 0.03912205947563052, 0.0373304691830916, 0.014113932964392006, 0.025811465324035714, 0.039974720150764496, 0.007486384578182229, 0.011414253319214498, 0.009233133884013763, 0.023496376782921807, 0.0657362419047526, 0.033421791956893036, 0.03515521822763341, 0.03183123462700418, 0.017693854036874006, 0.03795984773231404, 0.009662426875105925, 0.05639888080103057, 0.05198222851114614, 0.011219741078093648, 0.03326335742271372, 0.035238199667739015, 0.05398450053430029, 0.14123855690870965, 0.0337520451284945, 0.056001618903662474, 0.06315989872174603, 0.02970345737412572, 0.040523787295179706, 0.06701045603092227, 0.11362299589174134, 0.09017974670444216, 0.13068522033946856, 0.14160461298057012, 0.1076690818050078, 0.21951396310968058, 0.09427667329353945, 0.12173469204987798, 0.11636401952377387, 0.14343626398061002, 0.12247972350035395, 0.15434064742709908, 0.1403932651238782, 0.17493607157043048, 0.10649605760616915, 0.18256845059139387, 0.17699818020420416, 0.12033026026827948, 0.1052946774289012, 0.10442067004208054, 0.2174581784222807, 0.16142486514789717, 0.10884603472160441, 0.12102657290441649, 0.08457999397069216, 0.08997902926057577, 0.11849711649119854, 0.1374197346823556, 0.11321433460605995, 0.07201239905719246, 0.21683087279754026, 0.12959248040403637, 0.08051187797848668, 0.21577587297984532, 0.16336282901465893, 0.1616274757044656, 0.16255942998187883, 0.10808853179748569, 0.11715717267777238, 0.13222238714141504, 0.10471754946878978, 0.13967970412756714, 0.17702833430043288, 0.10421981689121042, 0.1448194711868252, 0.12557437244270528, 0.09960163291543722, 0.0734436668987785, 0.12774651231510298, 0.09205805377236434, 0.12530686679695333, 0.16998516794826302, 0.12807268409856729, 0.18207968824676105, 0.09169726991759879, 0.12510143353470735, 0.09420039238674299, 0.17386142137859548, 0.22495770028659276, 0.19081028976610728, 0.10173583589494228, 0.19021103477903775, 0.1674610176788909, 0.11712145459439073, 0.12186117097735405, 0.08976521609084946, 0.10799635960055248, 0.15709847158619336, 0.16017667283969267, 0.2059801479003259, 0.14818234502204827, 0.1546704697289637, 0.11990029976836272, 0.1313921452632972, 0.12445481680333614, 0.14263530767389707, 0.1634586245885917, 0.12687090358563832, 0.17528345435857773, 0.1638031303882599, 0.2699787701879229, 0.335907403911863, 0.6356220756258283, 1.4790829015629632, 1.8622223138809204, 2.1975729933806827, 2.871818367924009, 3.6303197698933736, 3.839674855981554, 3.9783074855804443, 4.06458934715816, 3.4144220863069807, 4.69689278943198, 4.625312881810324, 6.2577387264796664, 7.385630249977112, 7.802694133349827, 8.156456453459603, 6.052012988499232, 3.7970754504203796, 2.1433216759136746, 1.7023084376539503, 0.809216249201979, 0.1985247986657279, 0.1301872842013836, 0.138929135831339, 0.10645765930946384, 0.17727475107780524, 0.12042330099003655, 0.15800324375075953, 0.13795501738786697, 0.11961657713566508, 0.22364759844328674, 0.10249750502407551, 0.16513972223869391, 0.15200500775660786, 0.16496900282800198, 0.1920140516012907, 0.14405625499784946, 0.2904854826629162, 0.13194296642073564, 0.1361684753958668, 0.2239796191986118, 0.08335809489446026, 0.19379424250551633, 0.13552298503262655, 0.08408414093511445, 0.08557875002069132, 0.11262772072638784, 0.25526365265250206, 0.1469869834503957, 0.16947397323591368, 0.13368916272052697, 0.1588629340486867, 0.13395676336118154, 0.11036730344806399, 0.12342512634183679, 0.07996275994394507, 0.12187054833131176, 0.10200760952596154, 0.13836990083966935, 0.09079924239111797, 0.1990768276154995, 0.10517821367830038, 0.10731285770556756, 0.06814671720245055, 0.13475413700299604, 0.13742022322756903, 0.13953694035964354, 0.08590755452002798, 0.12279320667896952, 0.1388695061739002, 0.09466113123510565, 0.10927731836480753, 0.1458377351186105, 0.11487144604325294, 0.2627641244658402, 0.09327018872967788, 0.16662336619836943, 0.1558973288961819, 0.11170441777046237, 0.11561666748353414, 0.1596484604690756, 0.13003090902098588, 0.14141250614609036, 0.14746915043464728, 0.20193075947463512, 0.16101275011897087, 0.09060280650321927, 0.18831785422350678, 0.13604245787220343, 0.11774536754403796, 0.18509865339313233, 0.09508017410657235, 0.1210204932306494], [0.003873259818647057, 0.08034452410148722, 0.02505044249950775, 0.009807188080490699, 0.06428979523479939, 0.015600836436663355, 0.029307518620043993, 0.010710095121924366, 0.021805335202121308, 0.04533198143222502, 0.08951166791043111, 0.021951086220464537, 0.031245631764509847, 0.041285934791501076, 0.006774398631283215, 0.053551130395914824, 0.022342731544215764, 0.038128653674253395, 0.06215532762663705, 0.05822766838329179, 0.03768402663990855, 0.02929546105276261, 0.06254715445850577, 0.045283710450998375, 0.035713988422815285, 0.05187175961743508, 0.015503704148743833, 0.04471290304458567, 0.059937101655772755, 0.028782990694578205, 0.027047978348231742, 0.04702003067359328, 0.006138335239873933, 0.034305668635559936, 0.03859867827434625, 0.03838362338553582, 0.03172357826094542, 0.0648219906059759, 0.05066786886059812, 0.04184658792135971, 0.07138561590441636, 0.025457914652568952, 0.04671367550534861, 0.01711001366909061, 0.005146137654914388, 0.04150743576298867, 0.07029771392366715, 0.054153106308409145, 0.04415496405480163, 0.007311244511843792, 0.040030824818781445, 0.05484404494719846, 0.04450812456863267, 0.0660014133900404, 0.045374908950179815, 0.010073874395207634, 0.055202341971120665, 0.03135667062763657, 0.03200800996273756, 0.07264545865889106, 0.03835792047902942, 0.027934172223987322, 0.029727341806782142, 0.034906046598085334, 0.013292889476620724, 0.0380596704115825, 0.03670210504372205, 0.04985724342986941, 0.03352328383230737, 0.006474561640061438, 0.021441068766372542, 0.024475251756874577, 0.021128374384716153, 0.04328733489715627, 0.05807450267353228, 0.09735699157629694, 0.0368789957304086, 0.01645201620911913, 0.04078332693981273, 0.02250766644387373, 0.02825693945799555, 0.07045326129134212, 0.03155677399731108, 0.05459814724911537, 0.017450853683320538, 0.07421379735959427, 0.026757000479847193, 0.0662197456029909, 0.0475493151295398, 0.05545046526406493, 0.011583038056934518, 0.050046435956444056, 0.04915228286491973, 0.05865364588264908, 0.012811500263134283, 0.1395188913281475, 0.08368653298488685, 0.07612313383391925, 0.04566864675975271, 0.05216362127768142, 0.02045718959665724, 0.016291488394407288, 0.03629005786829761, 0.04893529075863106, 0.009932331990317574, 0.01240366933468197, 0.053582220870469294, 0.0378679469493883, 0.013848393373856587, 0.01980555509882314, 0.030874829340193952, 0.051895175860928636, 0.06856561079621315, 0.0343180824337261, 0.028142814956871525, 0.040551210287958384, 0.031357800388442617, 0.047295336079384596, 0.038740950104381354, 0.017518252566722885, 0.07044221474123852, 0.02615567935364587, 0.0024813779663028462, 0.05265133189303534, 0.009836841757143182, 0.09082861617207527, 0.07295075191983155, 0.05152019026822277, 0.03954037970730236, 0.059481567171003134, 0.04270650552851813, 0.028658035078219006, 0.020912137148635726, 0.03238801332190633, 0.034000212526214976, 0.04585201067051717, 0.018460625749347464, 0.0516417701728642, 0.017084482092676417, 0.010388543313768293, 0.014533053019217082, 0.007987533579580486, 0.019062281054045473, 0.03273107723465987, 0.06264480243303946, 0.03965632437861391, 0.045217783988586495, 0.0901416198217443, 0.03461143687101347, 0.02284802809091551, 0.0033615750767889297, 0.06086360729698624, 0.046425902018589635, 0.060448133519717624, 0.03451677105788674, 0.06843723197068487, 0.058424029632338455, 0.013007704600957888, 0.0356226643946554, 0.040807903478188176, 0.05842544098517724, 0.05607034432302628, 0.002771474587331925, 0.0737503104444061, 0.0436304089879351, 0.01655859370449824, 0.031533686843301566, 0.01603457298395889, 0.03363723361066409, 0.017882291693240404, 0.04929286175008331, 0.11317459281001772, 0.03761581012180873, 0.02926065559898104, 0.06645122103925262, 0.024281531705388, 0.011739686347677239, 0.06795733129339558, 0.01605542266874441, 0.034577639041734595, 0.04397639060126884, 0.0057823541407872525, 0.07188219497246401, 0.038971112575381994, 0.07541433615343911, 0.020906505307980945, 0.0533057008869946, 0.013281976937183311, 0.018841718157221164, 0.014737802657431789, 0.0370834722582783, 0.031639802934868, 0.014291523390316536, 0.02618629315734974, 0.08032811033938612, 0.04821663735700505, 0.05929644924721547, 0.04675734601914883, 0.015157074534467288, 0.011676317962285663, 0.03731011313253215, 0.04841144476085901, 0.03938233533075877, 0.01963919018661337, 0.021513320871495774, 0.06395675667694636, 0.028871844855270216, 0.01393942563195846, 0.027212014188989997, 0.030065795074083974, 0.019063120741131048, 0.01559779659977981, 0.01345964115379112, 0.02289283854354705, 0.03988261241465807, 0.03979334095492959, 0.025357942695596387, 0.03855993053210633, 0.024020148141841804, 0.06378482947392122, 0.0892796360754541, 0.09738204987453562, 0.037824171262660196, 0.026027894246258905, 0.046213866610612185, 0.030824281873979738, 0.02693931944668293, 0.05842814833990165, 0.06606891405369554, 0.022606501854690056, 0.1151473790939365, 0.035660468973219395, 0.030274217283087115, 0.02617546882746475, 0.05804455213780914, 0.0210577660306756, 0.014407831077863063, 0.03201676645715322, 0.019676197486530458, 0.016732315632647703, 0.012949325144290924, 0.007925601143922125, 0.010384859716785806, 0.029875225121421472, 0.030006413081926957, 0.04023347948012607, 0.03337289333077414, 0.012297277588264217, 0.0009958952827478892, 0.03237611860302942, 0.047416692067469866, 0.046494427270122936, 0.03142433753237128, 0.039331010941948207, 0.024592092094410743, 0.05318071812923465, 0.031490043470902104, 0.03207025537267327, 0.026289544134799923, 0.02619174518622458, 0.03479968623391219, 0.06094945554754563, 0.044612198269792964, 0.04863355302118829, 0.03944264691589134, 0.050121841553066454, 0.01493263550634895, 0.06699959268527371, 0.06428990380040236, 0.11818121772791658, 0.07661149584289108, 0.15886085773152964, 0.10510566471410648, 0.07818737985300166, 0.11070545137460742, 0.15051429346203804, 0.01840408512258104, 0.10007981011377913, 0.06532133809689965, 0.05346002010628581, 0.03130267959620271, 0.024631002685055137, 0.03734426719269582, 0.02761905886498945, 0.00664257030335388, 0.031405223200895956, 0.07550238964280911, 0.016613298894039223, 0.05593070520886353, 0.003391084776792143, 0.048444842254476886, 0.011804803657079381, 0.03575907028945429, 0.06787721666374377, 0.022739516770733253, 0.0794378723949194, 0.1026533916592598, 0.05076605287779655, 0.024829516586448466, 0.02653262760889317, 0.020705636890072907, 0.026108080122087683, 0.012064142285713127, 0.025752112169616988, 0.05588388968525188, 0.06065220292657614, 0.007418425055220723, 0.029093976864325147, 0.005206992916230644, 0.003972375549242965, 0.05043159278907946, 0.03702817165425845, 0.02717857259059591, 0.04340899283332484, 0.022871189883777072, 0.0500050453203065, 0.038637426016586165, 0.05278822633304766, 0.030908348970115185, 0.05597503050895674, 0.04424327199480363, 0.022424084500276616, 0.042430314634527476, 0.024457555563588227, 0.0513444666617683, 0.0599868314872895, 0.02553246190239276, 0.027210200804152658, 0.04098072634743793, 0.003108849620080686, 0.03572710111205067, 0.02802316378802061, 0.02379825192370585, 0.03905515931546688, 0.014404701335089547, 0.022701739333570004, 0.030649280907320123, 0.0305292073504201, 0.03257699550262519, 0.0274373505796705, 0.046627362458301444, 0.01766415455910776, 0.030867653832371746, 0.009106866150562252, 0.020432263612747192, 0.034037922109876356, 0.011239170928352644, 0.02313543007975178, 0.033398945682815144, 0.01991100622607129, 0.03448657624955688, 0.020697282427655797, 0.054726492147892714, 0.10858232887195689, 0.07360634566949946, 0.10232874657958746, 0.13720028288662434, 0.08652296542589154, 0.12649673223495483, 0.10753224164779697, 0.12926450371742249, 0.12636251800826617, 0.2171713345284973, 0.1508823987096548, 0.036101764400622675, 0.06239832458751542, 0.0781309325248003, 0.2080433964729309, 0.1312026304325887, 0.14979910398168222, 0.19545889246676648, 0.23900725639292172, 0.12884633615612984, 0.1719547108347927, 0.09560063760727644, 0.11893910063164574, 0.12285344701792512, 0.20254528149962425, 0.14095355863017694, 0.13466018704431398, 0.13264287529247148, 0.12026913783379964, 0.10058359522372484, 0.07096697336861066, 0.12615773613963807, 0.12267781501369816, 0.12545604950615338, 0.10376715939491987, 0.1720090207776853, 0.06159931567630597, 0.11438945547810622, 0.08074500225484371, 0.1673220129949706, 0.07037866315139191, 0.11423325671681336, 0.16976197063922882, 0.15978700374918325, 0.12212479540279933, 0.149632048660091, 0.12773040389376028, 0.1271747922790902, 0.174253750326378, 0.1004846173205546, 0.1825552870120321, 0.2261546632008893, 0.13125483691692352, 0.18825678607182844, 0.09852841443249158, 0.13021106006843702, 0.10811737632112843, 0.13246115004377707, 0.16407142313463347, 0.12070553084569317, 0.1100685919768044, 0.08094229309686593, 0.09745185077190399, 0.1451659718794482, 0.19361540781600134, 0.1268229175891195, 0.07423760036804847, 0.07534091187907116, 0.1248277939323868, 0.10612943835024323, 0.10238961117076022, 0.18298003636300564, 0.1384202345673527, 0.16349455980317934, 0.14702764126871312, 0.20863716889704975, 0.08617133500852756, 0.12689421804887907, 0.15858605104897702, 0.19344386059258664, 0.12012015868510519, 0.11037912352808885, 0.22159916907548904, 0.15174561738967896, 0.143932381644845, 0.1033420232789857, 0.12979537594531262, 0.16926958491759642, 0.1745755523443222, 0.14220659567841462, 0.10446744824626616, 0.19279367476701736, 0.16328136410032, 0.17948256832148346, 0.27885628810950686, 0.21968784449355944, 0.15795619413256645, 0.2822554228561265, 0.22448739409446716, 0.12535946683159896, 0.16920345489467892, 0.20969123233641895, 0.13503510478351796, 0.1070614265544074, 0.07319833577743598, 0.08983482021306242, 0.08887634200177022, 0.07497161919517176, 0.09595448004880122, 0.1557439256991659, 0.09785431024751493, 0.11307964540485825, 0.1493609467787402, 0.14963959396949836, 0.1066944341042212, 0.1364966963550874, 0.12596729850130423, 0.09363146112965685, 0.14808451384305954, 0.22938299711261476, 0.19113031402230263, 0.14290246048143931, 0.10965301641928298, 0.09914001197155033, 0.1530798343675477, 0.15173767852996076, 0.1035563385646258, 0.19537087290414742, 0.12445678455489022, 0.20978370308876038, 0.14482536087078707, 0.18189623951911926, 0.1504440243755068, 0.22322522396487848, 0.25199341241802486, 0.1323038927678551, 0.15687089094093867, 0.13471767253109387, 0.17602700660271303, 0.1402795969375542, 0.08078553115150758, 0.09423870925924607, 0.08316616447908537, 0.10755337801362787, 0.17906522857291357, 0.11114877901439156, 0.1888903613601412, 0.1728290846305234, 0.12035938299127988, 0.11244552728853055, 0.2134486742849861, 0.1196274608373642, 0.11666676827839442, 0.11014697634215866, 0.15025005835507596, 0.24774021921413286, 0.2037395438445466, 0.10602942228849445, 0.1274169071444443, 0.14937428677720682, 0.05396966775879264, 0.1541458943060466, 0.1829936070633786, 0.17679043992289475, 0.07319125187184129, 0.1851983708994729, 0.10644842444786004, 0.15837745581354412, 0.14957407462809766, 0.13081583833055838, 0.19451313678707394, 0.10814512161804096, 0.11266000542257514, 0.1412022010024105, 0.11109796352684498], [0.021211700181343725, 0.030376933914210116, 0.033334254154137204, 0.04910522306870137, 0.002044355825221698, 0.06514411153537886, 0.05187254332538162, 0.014983595182586993, 0.04173351006050195, 0.03418592416814395, 0.08873376822365181, 0.058705221329416545, 0.06902588824076311, 0.033478374992098124, 0.019533708525289382, 0.012984362148147608, 0.02881543823916997, 0.036017989074545245, 0.011432218382001987, 0.020841121673583984, 0.028403470791610222, 0.010331822027053152, 0.046317774070692916, 0.025991814842979823, 0.043566290821347914, 0.02266823497068669, 0.03727406595966645, 0.04348755022510886, 0.003709569606663925, 0.021837764087000062, 0.008219217665360441, 0.07754537037440709, 0.0199311315747244, 0.05079942662268877, 0.030290525872260332, 0.10577364172786474, 0.03185829799622297, 0.006566142663359642, 0.02993468175243054, 0.01673034448841853, 0.056978566838162284, 0.023556371152933155, 0.06509119937462465, 0.050887602248362133, 0.024803501553833485, 0.041425601047064574, 0.010860986043033856, 0.04047209649745907, 0.07122515594320637, 0.06426128319331578, 0.05023043769012604, 0.023922607036573545, 0.0646897577015417, 0.0071172640725438085, 0.03264249109530023, 0.01032717660668173, 0.02384430748809661, 0.0014723875938216224, 0.03098676386954529, 0.019956379862768308, 0.09766529074737004, 0.03748266798044954, 0.07680694106966257, 0.020250747013571005, 0.01810419639306409, 0.03330195249457445, 0.07643279686037983, 0.07674767103578363, 0.022536298925323144, 0.042918903952730555, 0.04007553688383528, 0.00539220795534285, 0.0620334084544863, 0.041503222060522864, 0.025624895335308144, 0.025819465251905576, 0.043852561353040595, 0.03287576125668628, 0.0047173913085966235, 0.01877724884876183, 0.05782208764659507, 0.03349461912044457, 0.009131441840768924, 0.010435262146139783, 0.046122722394232235, 0.01164025891505714, 0.029349859205207655, 0.08665085570620638, 0.02853525077391948, 0.03486860503575631, 0.041490553811724694, 0.04170248065409916, 0.01944885093585721, 0.0372892549660589, 0.02706930640020541, 0.03812255025176065, 0.026232788073165075, 0.03308440738224557, 0.012975318972686571, 0.021689970678250705, 0.04140969618622746, 0.023799899067463617, 0.06381495642874922, 0.022257003733622174, 0.0057272286836190945, 0.027579274660508548, 0.09353810149644103, 0.007955989334732294, 0.013389857219798225, 0.04272672247939876, 0.012732353394052811, 0.03375543101823755, 0.005483072276027607, 0.04974656419030257, 0.027123938647231886, 0.009416863355519516, 0.021745334046759775, 0.02279509896678584, 0.03407929578263845, 0.021274985446195518, 0.04240192812202232, 0.0337624843897564, 0.027178017888218164, 0.040345074741968086, 0.07072990680379526, 0.03850908451048391, 0.022484273949105824, 0.00812338137932654, 0.009697838769560414, 0.027224114164710045, 0.019725162269813672, 0.09867237920739821, 0.030618387207921063, 0.031175556060458933, 0.04630305325346334, 0.021536993261958872, 0.004403938664056892, 0.02530709158496133, 0.04863559541159442, 0.06091357461575951, 0.0073213478982714665, 0.07148543519100972, 0.046106186495827775, 0.034574795980006456, 0.029668862266199927, 0.021248505617092763, 0.055166481395385096, 0.045964474457183054, 0.01896705205685326, 0.0446671019308269, 0.014999898682747568, 0.013313851119684321, 0.006725956319964358, 0.053422629434083185, 0.04514395598588245, 0.05060744531718748, 0.03728650350655828, 0.013351585300240134, 0.05261911165767482, 0.12562219559081964, 0.015841980996940817, 0.04482380280803357, 0.020698312104546597, 0.04180847800203732, 0.06231120069112096, 0.022636747553146312, 0.024196480733475516, 0.030066968939666237, 0.027164983230509927, 0.027714162333203212, 0.03307979673679386, 0.09048322149153266, 0.0361525052493172, 0.06288148223289422, 0.01471891563518771, 0.016712183498644402, 0.023457510297053626, 0.0301516806440694, 0.07687241291361195, 0.017269079240837266, 0.04059583753613489, 0.025203930513401116, 0.04056051639573915, 0.029696088483823196, 0.01034198563346373, 0.03815613094983356, 0.02422819546024714, 0.03912020368235452, 0.02702702009784324, 0.04868023283779621, 0.03836602557982717, 0.06081712764820882, 0.022285790581788336, 0.01741294902084129, 0.045719333325645754, 0.03977154301745551, 0.05534502092216696, 0.01377300389244088, 0.06600984758032219, 0.04929378455770867, 0.0045029297138431245, 0.017920301528647542, 0.04047210667548435, 0.05864947289228439, 0.09013223568243639, 0.05187956277014954, 0.07016388646193913, 0.005830946577978986, 0.01686084712855518, 0.03187014861032367, 0.028879556405757154, 0.015191985161176749, 0.009497536080224174, 0.030051444058439562, 0.06535991959805999, 0.011070368379088385, 0.10089806906346764, 0.01297040977182665, 0.03330935870430299, 0.010633007606624492, 0.01942738887321736, 0.021736017760953734, 0.03930168126576713, 0.08646383109901633, 0.016764523993645395, 0.029526763462594578, 0.027502177815352167, 0.04238264076411724, 0.04361279761152608, 0.023528659782771553, 0.009203166384915156, 0.03425632896167891, 0.031248003244400024, 0.020363419449755123, 0.02541929922465767, 0.011373870307579637, 0.07901338767260313, 0.019886745206479515, 0.027925073069387248, 0.03697820772816028, 0.10532314875828368, 0.03095110346164022, 0.041796708812138865, 0.05196508871657508, 0.08121319141771112, 0.028057870854224478, 0.02630644304943936, 0.05325457666601453, 0.04118798826155918, 0.06349348010761396, 0.028089088554094945, 0.01702416711486876, 0.03730821662715503, 0.022465900917138373, 0.0753579091812883, 0.0462124552577734, 0.010792166476936212, 0.02952259047222989, 0.0068899145532798555, 0.031605017837136984, 0.03893424776781883, 0.044088932419461865, 0.037151407184345384, 0.006035814959821957, 0.021195666398853064, 0.019215877633541822, 0.04781126018081393, 0.0392346759326756, 0.04447662018771682, 0.046768436674028635, 0.035208418765770536, 0.012082442375166076, 0.0401622299104929, 0.03988399323342102, 0.021388309275997535, 0.03310834609770349, 0.07630494050681591, 0.019770500283422213, 0.03965520479583314, 0.025561733903097253, 0.009799661430796342, 0.027880613758627857, 0.01031192229129374, 0.08823648347918477, 0.013243311467314405, 0.04315221482621772, 0.0741911478606718, 0.05184362755556192, 0.05112511325361473, 0.0365795819754047, 0.031219976355454752, 0.0633845277396696, 0.0117240300002907, 0.015046498771490795, 0.015504460715289627, 0.016896000331533805, 0.06690290144511632, 0.0711511956261737, 0.025466779712587595, 0.030948921971555268, 0.046041030170662064, 0.04915605551962342, 0.014887967546071326, 0.05728212983480521, 0.03582251670637301, 0.017030167060771158, 0.03799127408170274, 0.04502493755093642, 0.05182590761354991, 0.045063485125345845, 0.057348605910582204, 0.040304420316325765, 0.022426489906917726, 0.009248564618506601, 0.04525640620184796, 0.014132657986400383, 0.018882051975067173, 0.0431838515214622, 0.02338047112737383, 0.045677030059908114, 0.02328689436295203, 0.012604782873365496, 0.07616780857954707, 0.027327899488487413, 0.04081586608663201, 0.05047539222453322, 0.017244992944012796, 0.016165849154016802, 0.021439823654613326, 0.09387337921985558, 0.05753888748586178, 0.033044604518051655, 0.027166818667735373, 0.037374475571726046, 0.027004762452894022, 0.02117035534631993, 0.011922971378745777, 0.042813150877399106, 0.03564068289207561, 0.11871952669961111, 0.02583951596170664, 0.01863938749634794, 0.038977789359965494, 0.011148052157035895, 0.029006296569215398, 0.034554830087082725, 0.02574900278289403, 0.1013267674882497, 0.0037122387937935336, 0.03540607601670282, 0.06050162922058787, 0.016429914627224207, 0.13478570245206356, 0.17185544116156443, 0.1363911298768861, 0.08294540311076812, 0.06104120705276728, 0.12018703509654317, 0.08697745496673243, 0.11875129570918423, 0.111515744323177, 0.13100766018033028, 0.17250830041510717, 0.11433328634926251, 0.13125817530921527, 0.15098823660186358, 0.09803083113261632, 0.17179986914353712, 0.10652397932218653, 0.151957456022501, 0.14343318343162537, 0.07827755715698004, 0.16418097939874443, 0.13740195706486702, 0.1878922770598105, 0.21428507726107324, 0.1305738998843091, 0.10593007797641413, 0.13679940439760685, 0.1974695274340255, 0.14401930198073387, 0.10558249841311149, 0.1822042129933834, 0.20821577150906834, 0.10340393281408719, 0.13813088009400026, 0.1912837986435209, 0.19331765307911805, 0.09291694339896951, 0.14826151648802416, 0.15589221274214132, 0.06471071086291756, 0.19594126301152365, 0.07343478487538439, 0.12704829978091375, 0.13822953908571176, 0.15081933566502162, 0.14997238825474465, 0.07851518012051072, 0.16194106744868414, 0.1492002425449235, 0.1703965501593692, 0.08986766809331519, 0.06547414418309927, 0.09649605277393546, 0.09587392437138728, 0.19180287793278694, 0.12460663222840854, 0.09421115395213876, 0.07359236106276512, 0.1633329734738384, 0.12562784100217478, 0.23770463200552122, 0.16845729707607202, 0.17546999720590456, 0.20163157981421265, 0.1701500519577946, 0.10074595508298703, 0.11554723978042603, 0.1587252185813018, 0.1472979560494423, 0.09694272559136152, 0.13147575434829506, 0.13004557894808905, 0.11955658106931619, 0.15426239876874856, 0.11434324724333626, 0.06542249409747974, 0.16200014070740767, 0.09998482878186873, 0.2366604208946228, 0.14349995127746037, 0.09620481197323118, 0.1449769998767546, 0.11968228646687099, 0.17072018422186375, 0.0956293735653162, 0.08654887189290353, 0.14132433730576718, 0.15406888058143003, 0.15275541320443153, 0.06748274354530232, 0.19834470190107822, 0.13196280678468092, 0.15184488706290722, 0.0894107154703566, 0.09795486913727862, 0.06950246409646102, 0.26640356917466435, 0.07402091699519328, 0.15374903274433954, 0.16905348508485726, 0.17640121866549763, 0.17277838449393, 0.11395965782659394, 0.08873137978038617, 0.0689296041216169, 0.10335060674697161, 0.17605581719960484, 0.11916959897748061, 0.14863243087061814, 0.14690262797687734, 0.19595471157559327, 0.15601664249386105, 0.06871123798191547, 0.15298353667770112, 0.1573651765606233, 0.14788642232971533, 0.06873954646289349, 0.08931143901177815, 0.10308667019541774, 0.06862602076892342, 0.12355305733425276, 0.13379628982927116, 0.13659481251878397, 0.1313306564199073, 0.18927978617804392, 0.11876801481204373, 0.14475321902760438, 0.12637025330747875, 0.10217081755399704, 0.11222311029476778, 0.08703938485788447, 0.1410798339971474, 0.11584883502551488, 0.3049734266740935, 0.09986478915171963, 0.17264431954494544, 0.12234614709658281, 0.0976684662912573, 0.2213423028588295, 0.1356947086751461, 0.12250249513557979, 0.10713605862110853, 0.16640661497201237, 0.1041134904537882, 0.1516263716455017, 0.12341555899807385, 0.2105059629040105, 0.17507690829890116, 0.127796398209674, 0.11786027066409588, 0.11816939764789172, 0.11732878775468894, 0.09954803543431417, 0.22131179592439107, 0.16585445031523705, 0.1495197918266058, 0.11135973555168935, 0.20670258413468087, 0.0796633360109159, 0.17510608530470304, 0.11262021612908159, 0.11541008071175643, 0.1301702665431159, 0.20688888270940098, 0.14733395911753178, 0.2191469163766929, 0.09284503904304334, 0.11492814442941121, 0.1961027000631605, 0.16402303001710347, 0.13251320725040777, 0.2028431040900094, 0.10544087458401918, 0.1822238905089242, 0.1593809276819229, 0.12199773293520723], [0.012896100009259368, 0.06701135169714689, 0.03987026307731867, 0.06171447663967099, 0.04534341474728925, 0.008693059024933194, 0.0389390789371516, 0.03358616027981043, 0.02235984759006117, 0.11037735255169016, 0.04012616916692682, 0.016131905439708914, 0.06198545638471842, 0.014738618595791715, 0.03406004913683448, 0.01745887566357851, 0.04764597583562136, 0.027275818533131053, 0.041827049505497725, 0.04437910792018686, 0.022158644993656447, 0.023347475665754507, 0.05524086579680443, 0.10454467910208873, 0.02833523561379739, 0.02546923770569265, 0.03697917464056185, 0.032003117725253105, 0.08642685094049998, 0.01804012233125312, 0.029800124865557467, 0.02424690606338637, 0.03688068528260503, 0.010436525917612016, 0.04495033262563603, 0.014589088137394615, 0.06706071511975356, 0.0966629588178226, 0.01000884868803301, 0.00809282440293048, 0.10862977204046079, 0.02850523577736957, 0.007674019018720303, 0.02404282478216503, 0.0690716350717204, 0.020683185862643377, 0.05623950988852552, 0.018998074677905867, 0.06415632061128106, 0.015641251678711603, 0.018739301777843918, 0.06571332777717284, 0.0849452018737793, 0.06321585750473396, 0.046166803421718736, 0.027896086053390588, 0.08698985858687333, 0.04033561257113304, 0.046055466003183804, 0.03466698853299022, 0.022437896080581204, 0.03151270654052496, 0.04215510083096368, 0.028546734979110103, 0.05980533015515123, 0.023871314878176366, 0.03215877026585596, 0.04067747547690358, 0.043621051990027936, 0.036378728824534586, 0.04341561194243176, 0.0034486612296729746, 0.042642679131988964, 0.013984494776065861, 0.028411480897505368, 0.04207403625228575, 0.03090944141149521, 0.03272893984935113, 0.031234422366001775, 0.035393102427146265, 0.007348174628402505, 0.03304725758997457, 0.032520680488752465, 0.08546253732804741, 0.03210157315645899, 0.07287061014877898, 0.0325207110228283, 0.03785070876723953, 0.02788925150941525, 0.03827452852523752, 0.048062813468277454, 0.043346839025616646, 0.033761330880224705, 0.023937105633584515, 0.08723610573049102, 0.028442659581612264, 0.04080721815781934, 0.010395163271043981, 0.02307010242449386, 0.0374590413911002, 0.012217774488297957, 0.016584542579948902, 0.016369521617889404, 0.017730798572301865, 0.03413768372099314, 0.052952906782073636, 0.02499683653669698, 0.03221390462879624, 0.031656315084546804, 0.03476832773802536, 0.017136885352166634, 0.01030064928012767, 0.04157698220972504, 0.0393073707818985, 0.0007345165431615897, 0.03782583706613098, 0.023266612951244627, 0.02089540277873831, 0.03266062155099852, 0.027327773959508965, 0.04148341901600361, 0.01500173581631056, 0.01641214549142335, 0.051807787335876904, 0.03767150766881449, 0.03013899203922067, 0.005582522609204586, 0.025472842422979217, 0.04900527146777936, 0.019748100146119083, 0.009844412511613752, 0.056291648519358466, 0.040762061652328284, 0.019602001378578798, 0.015266752934881618, 0.06261559828583683, 0.002808327308490074, 0.0681634566613606, 0.03923760720395616, 0.008809426932462623, 0.06891593842634133, 0.0429869067322995, 0.041517271128083975, 0.017815420370815054, 0.06879676732101611, 0.03371714467981032, 0.04838689197120922, 0.03896305836471064, 0.0405459312855133, 0.03785332791241152, 0.048595066514930556, 0.040891522741211314, 0.05786367505788803, 0.008259669378665941, 0.023776199535599778, 0.053425553920013566, 0.05615078464948705, 0.038251862062939575, 0.005498902922097061, 0.030619116633066108, 0.016297620654638325, 0.031571420175688605, 0.005876898241695017, 0.041673259543521066, 0.015490150411746331, 0.044141271218125305, 0.03794579187940274, 0.05249320609228952, 0.09981744097811834, 0.04514459041612489, 0.027443241959969913, 0.04140872588115079, 0.04310304478609136, 0.047893898960735114, 0.05410526958959443, 0.025194176572508047, 0.03577237975384508, 0.05097733850457838, 0.03709667315706611, 0.023019558350954736, 0.017484992476446286, 0.056394219265452454, 0.041486944005425484, 0.04990929724382503, 0.03280231662626777, 0.09826665597834758, 0.011092263007802623, 0.019599097248698984, 0.05532638495787978, 0.011602926766499877, 0.027462968669299568, 0.0032083784088691963, 0.014568896631577184, 0.013788389673988734, 0.022111702244728804, 0.021629616684679474, 0.029147832188755274, 0.025314828580511466, 0.030136576454554285, 0.03492281319839614, 0.049034838631216965, 0.006699267417258982, 0.04700514700795923, 0.014755164672221457, 0.07200878246554307, 0.007203108930428113, 0.03163099215765085, 0.03876925180000918, 0.025356195467923368, 0.023312929751617566, 0.014914857888860362, 0.036458477045276334, 0.02067138783500663, 0.07883474975824356, 0.04201877296769193, 0.02796839244131531, 0.05618579027109912, 0.025052495067939162, 0.03943513214055981, 0.05601279437541962, 0.05799111071974039, 0.003965518528795136, 0.12457803876272269, 0.09421435663742678, 0.016448409795495014, 0.01922543140660439, 0.03783554690224784, 0.0451360985503665, 0.08500000036188535, 0.020026023000744835, 0.05468263503696237, 0.03944816001291786, 0.02460424804926983, 0.033586431693817885, 0.01810199285059103, 0.0025007066724356264, 0.05162785341963172, 0.031507179872798066, 0.042153906609330855, 0.016112370416522026, 0.021619645612580434, 0.031466807039188485, 0.05318101329196777, 0.0035424076278494404, 0.01127394924073347, 0.010406051213586969, 0.039268338054950745, 0.05190824105271271, 0.02116958860174886, 0.006921693740878254, 0.03378068609163165, 0.015078459467206682, 0.05144006206787058, 0.011227502670538212, 0.06231121426182134, 0.005178544487405036, 0.06495319213718176, 0.0391674025782517, 0.08857636167002575, 0.14620159273701056, 0.07644217421433755, 0.03465111081355384, 0.0683709458847131, 0.018427679481516992, 0.07151659351906606, 0.07662896133427109, 0.06182448752224445, 0.005379980754306806, 0.014805003069341183, 0.05352420951904995, 0.019400958237903457, 0.03492410580760666, 0.12028893748564379, 0.024480629146897366, 0.042044998346162696, 0.05343388293736747, 0.05112667049148253, 0.036118622603160996, 0.059243028185197284, 0.012564907066657074, 0.04910000174173287, 0.03410594863817096, 0.04679317606080856, 0.03324475199250238, 0.013122410945860403, 0.05271897165636931, 0.04748897301033139, 0.0138964684280966, 0.07400581959102835, 0.019109491824305484, 0.05354718132210629, 0.08864646112280232, 0.014980436602075185, 0.026070382412789122, 0.02805858331599406, 0.05386736842670611, 0.025770361368943537, 0.05277502204158476, 0.0432749210989901, 0.04091464042929666, 0.029989392030984163, 0.038628147050206146, 0.02917606263820614, 0.017024988142241324, 0.05407089839822479, 0.0781250564115388, 0.03529678438124912, 0.05716339299189193, 0.0396971959354622, 0.01634172543085047, 0.04150686240089791, 0.02976663576971207, 0.005349146850806261, 0.03745697185929332, 0.010307675510245775, 0.032685137021222284, 0.045856495786990435, 0.01727527256921998, 0.005605268799367228, 0.021629594632291367, 0.015452642692252994, 0.04189504549971648, 0.02376344477358673, 0.03479568626997726, 0.021943340743226663, 0.03686120454221964, 0.021630028894703304, 0.011611003877728112, 0.05616957667682852, 0.05523149862087198, 0.06961464629109416, 0.012021621888769525, 0.016864658799022436, 0.03628805958266769, 0.019070986658334732, 0.05804939687784229, 0.014371758459934166, 0.02284946319247995, 0.013486873308595802, 0.028357598431674496, 0.05298756974350129, 0.014624455078904117, 0.045030705098594935, 0.025387228267001252, 0.07634918777538197, 0.038227037859282324, 0.03664709620976022, 0.025168687404532517, 0.07187558604138237, 0.04188675719446369, 0.031687090040317605, 0.042493788192846944, 0.10835537926426955, 0.15170923434197903, 0.08394506161234208, 0.13962227292358875, 0.14074577763676643, 0.21890275233558246, 0.11155190345432077, 0.20718240338776792, 0.08644686772355012, 0.13676425628364086, 0.14292270796639578, 0.1245302427560091, 0.07469333162797348, 0.1565878875553608, 0.20792656631342002, 0.09132876433432102, 0.09162092794265066, 0.0826031229059611, 0.16639898823840277, 0.19863070441143854, 0.11042095521198851, 0.10252833765532289, 0.1117971327954105, 0.13169925021273748, 0.09789893749569144, 0.09998066257685423, 0.1704656793070691, 0.09961073885538749, 0.1302020898354905, 0.08884075284004211, 0.1257372751299824, 0.14795209094882011, 0.1316812147519418, 0.10052577725478581, 0.1403293064130204, 0.07597808340298277, 0.09935317374765873, 0.17539584689906665, 0.14662619281027997, 0.07133693101682834, 0.11779164363230978, 0.1388297440218074, 0.1285307766603572, 0.15571838564106397, 0.12868660901273998, 0.10185615372444902, 0.20870810294789927, 0.09923120707805667, 0.14549232008201735, 0.08244786052299397, 0.13715127908757754, 0.21072074637881347, 0.16558581830135413, 0.1457142417452165, 0.10185045403029237, 0.11806615175945417, 0.10885771230927535, 0.13396584215973104, 0.1592610441148281, 0.0966420192271471, 0.15064394793340138, 0.1524365967405694, 0.08306012981172119, 0.05919963587075472, 0.08946010603436402, 0.0877853866134371, 0.1758545230009726, 0.11106485780328512, 0.10331053925412041, 0.138736364032541, 0.10605322529694863, 0.0644499837820019, 0.08802499089922224, 0.09187554820839848, 0.10067571992320673, 0.18049810454249382, 0.12313049286603928, 0.09228372094886643, 0.16763811531875814, 0.12942686357668468, 0.1163619974894183, 0.09573318942316941, 0.14193215540477208, 0.2898137058530535, 0.2588517186897141, 0.2058501270200525, 0.1343918400151389, 0.08106584075306143, 0.14369656358446392, 0.16863294265099935, 0.09713957538562161, 0.11593514467988696, 0.1368337111281497, 0.12815522109823568, 0.18962560833564826, 0.18561264366975852, 0.19633481332233974, 0.1959624740162066, 0.1403897910245827, 0.1193410512059927, 0.14564456976950169, 0.11035747147564377, 0.12475785054266453, 0.05186312525932278, 0.15703726772751125, 0.05542695402566876, 0.17561904420810087, 0.1224396356514522, 0.09017335490456649, 0.09837966598570347, 0.11407281032630376, 0.11496021199439253, 0.17902679634945734, 0.18915908836892673, 0.09349008157317128, 0.1301248182675668, 0.10451430787465402, 0.11602822611374514, 0.11329157224723271, 0.16558926525924886, 0.11434620565601758, 0.12456978777689592, 0.1487897831414427, 0.11002481968275138, 0.09337720048746892, 0.07882216293364763, 0.14034214429557323, 0.08283223704035793, 0.2160616990711008, 0.08183573372662067, 0.08098787707941872, 0.22166301922074386, 0.08925470669886895, 0.09182058008653776, 0.14562966914049216, 0.1473790816962719, 0.07428719449256148, 0.13957237345831736, 0.1303131388766425, 0.087551495592509, 0.114243977570108, 0.12863582745194435, 0.11315015876399619, 0.15487109896327766, 0.14519181049295835, 0.11449314919965607, 0.10603907105645963, 0.1656266525387764, 0.10383701457508973, 0.2269085698894092, 0.09683616845203297, 0.16888617191995892, 0.17886055526988848, 0.14311986310141428, 0.11024079059383698, 0.1311665323695966, 0.13572741406304495, 0.10352294785635811, 0.11285189512584891, 0.11100245293762002, 0.06794186748032059, 0.13977758958935738, 0.05179061022187982, 0.14992334374359675, 0.2205654074038778, 0.09554750831531626, 0.08687007680003132, 0.08975573017128877, 0.14668111343468937, 0.0902034207912428, 0.1643417921981641, 0.11951129564217158, 0.08490292235676732, 0.16699029079505376, 0.15883558908743517, 0.13466488250664302], [0.05057809867763093, 0.04128384151096855, 0.05503130704164505, 0.03545775663639818, 0.11954104261738913, 0.02871299980740462, 0.03739381042708244, 0.04041763049151216, 0.006107464865116137, 0.019932424183934927, 0.03298531073544707, 0.0452297295975898, 0.03596676307331238, 0.03840806082423244, 0.0890030177044017, 0.017658931535801718, 0.04763056630534785, 0.024985281085329394, 0.018645864113100936, 0.030651679528611045, 0.08151780614363295, 0.04881911877808826, 0.036893075332045555, 0.059634631100509844, 0.028517978665019785, 0.010585001254055117, 0.045936881830649715, 0.0598133775804724, 0.029361757316759655, 0.015920134660388743, 0.029148022178560495, 0.07904140438352313, 0.03822890043790851, 0.011148365131313247, 0.03655142616480589, 0.03319442844284432, 0.0072817299348701325, 0.04142344669838037, 0.024823000953931893, 0.05444344126486352, 0.05163975492385881, 0.025776578446051905, 0.07581634779593774, 0.01580800165954445, 0.019763411288814883, 0.03645962716213294, 0.09676644897886685, 0.026894785497071486, 0.053623835423163006, 0.039592206212026734, 0.03734114593161004, 0.04080725547724536, 0.02749166391523821, 0.023750783310138752, 0.03263059976909842, 0.057651911063918045, 0.022738320852762887, 0.021166799822822213, 0.1173758509435824, 0.029136208883885826, 0.062335336181734285, 0.05761596906398024, 0.016525596546541368, 0.026595093542709947, 0.036080020745950084, 0.033236660462405, 0.03748564674918141, 0.026073339129132882, 0.010096305914755379, 0.04946366258497749, 0.027813031670770476, 0.03232148296332785, 0.012939899444713123, 0.01739649285030152, 0.018449662319783653, 0.02501806620109294, 0.02513929157118712, 0.028604522413973297, 0.030594282251383578, 0.01571209921634623, 0.029692434572747776, 0.028210139201421822, 0.026753855470035757, 0.009503567408371185, 0.025688144977071455, 0.016152968863025308, 0.042137163757745705, 0.05925733170339039, 0.018764488997736146, 0.010275835254495698, 0.01400122744962573, 0.03610633433397327, 0.04158851391236697, 0.03398037894761988, 0.025713790208101273, 0.06842235169772591, 0.021728898232270564, 0.0645561677270702, 0.02672814917085426, 0.07802120662693467, 0.07821370022637503, 0.0498559440353087, 0.041096650662698915, 0.028004968871495554, 0.0015570868937564747, 0.05105216395375984, 0.10023307081844125, 0.00759156683592924, 0.05030980932393244, 0.00475943969961788, 0.025624783377030065, 0.03062189184129238, 0.05324282443949154, 0.03605966469539063, 0.060598809005958695, 0.025518248290089623, 0.005869615864607373, 0.021055587933265736, 0.027775719030094997, 0.09613266334469829, 0.08275988485131945, 0.025206873659044504, 0.045476604386099746, 0.022363545605912805, 0.03676767188257404, 0.06132992370320218, 0.008853646211459168, 0.04151826857456139, 0.0014027219793726026, 0.04240231827965804, 0.03736995652850185, 0.045941970843289576, 0.025516987911292484, 0.06353346617626292, 0.03242758209151881, 0.06023814050214631, 0.021927944783653532, 0.02463641400182886, 0.044147076085209846, 0.11523193812796048, 0.016747121266754608, 0.023415958508849144, 0.029825949908367226, 0.04124587408400007, 0.052149260084011724, 0.04242858776290502, 0.016985488922468255, 0.04722311281199966, 0.048785979127777476, 0.05758213052260024, 0.023829491675964425, 0.019418228650465608, 0.041227475606969426, 0.02199195947365037, 0.006157172220160386, 0.0505793709307909, 0.054713138578725715, 0.024455397822228924, 0.037201282900891135, 0.03919417417741247, 0.03251171364848103, 0.012300597320842956, 0.05083730584010482, 0.03851331517632518, 0.008675291585469884, 0.02921192321394171, 0.040839363754327805, 0.02439085387491754, 0.026568294802148427, 0.013765405996569564, 0.03267212271956461, 0.022088396263175776, 0.006459980770679457, 0.019930704097662653, 0.02432479170550193, 0.05265338785414185, 0.06400310061872005, 0.04032269665705306, 0.042453116803829155, 0.005439232128472733, 0.04596332773300154, 0.08435529031391654, 0.03796469586502228, 0.04432390570374472, 0.01881023752503097, 0.04102656817329781, 0.03979708646823253, 0.08097093406000308, 0.03514857536980084, 0.050982447873268805, 0.04867410905925291, 0.051297637567456277, 0.07876824654106583, 0.008844907528587749, 0.014555699125464474, 0.009438266894514007, 0.037265319643276076, 0.0044741941798877504, 0.029184215236455202, 0.018961985096601502, 0.029735925274768045, 0.023971334332600236, 0.029635424060480933, 0.02582399108047996, 0.03118604960452233, 0.08142584429255553, 0.019022663090644137, 0.04504732920655182, 0.021044946807835783, 0.01061783471543874, 0.028305252847660865, 0.020411076356789896, 0.028815502699996744, 0.015994178097961203, 0.024350743973627687, 0.026648819945486527, 0.08315125027937548, 0.06289168739957468, 0.0073847298543634156, 0.050559170943285735, 0.040725227378840954, 0.04562359881986465, 0.0292470204377813, 0.036385632918349335, 0.02588561223819852, 0.015278355883700507, 0.04143912085731115, 0.008431695817437555, 0.02243819972500205, 0.03759193925985268, 0.016980554276545132, 0.05569751647167972, 0.03780113160610199, 0.040034454981131215, 0.03781792874048863, 0.05237000448895352, 0.04177011023940785, 0.017526685060667138, 0.01033609764583941, 0.04637024857636009, 0.032034374440887144, 0.039319055154919624, 0.013207043770567646, 0.07502936252525874, 0.015902999954830323, 0.06550214732331888, 0.023515180684626102, 0.016946016844095926, 0.07004466107381241, 0.018747929350606034, 0.04550979831921203, 0.053516450471111705, 0.06084931056414332, 0.0028246267798489755, 0.041291173081845045, 0.04275393173364656, 0.02825605057712112, 0.03228049944820149, 0.013494174345396459, 0.038420946204236577, 0.02742405977499272, 0.04888022085651755, 0.024168065383232067, 0.010617213007727904, 0.014801035335819637, 0.02706168475560844, 0.04608199672241296, 0.017899037937500646, 0.08177641619529043, 0.042900254417743, 0.015252027028639401, 0.025999616299356734, 0.04442874614947608, 0.01222097293274211, 0.03293384046160749, 0.03505559232352035, 0.015116336988285184, 0.02175285730377904, 0.03394287970981427, 0.016913526891065494, 0.04018839082813688, 0.03545132412442139, 0.016367567437035695, 0.034245221343423636, 0.04852063800873501, 0.031751354091933796, 0.011050429627565401, 0.033256117454064746, 0.05844994288470064, 0.022916724672541022, 0.05181180426318731, 0.02810325806162187, 0.03146375023892947, 0.038286565736468346, 0.06158397399953433, 0.014978187258488365, 0.018754063307174614, 0.05057742353528738, 0.04368272403787289, 0.026319596450775862, 0.03527474895651851, 0.01106595026794821, 0.025092535419389606, 0.019397616452936615, 0.025716891113136495, 0.030683760664292743, 0.017572460729362707, 0.048927870978202136, 0.07393334526568651, 0.023766756024477736, 0.04610608471557498, 0.03153850783460906, 0.08470892919493572, 0.024850887046860795, 0.06452023929783277, 0.04254377247499568, 0.009732992820707815, 0.025800690187939575, 0.014530069161472576, 0.08848389091768435, 0.04300520003640226, 0.024828105233609676, 0.028277124178462794, 0.018383257490183626, 0.05177734825494034, 0.04470310499891639, 0.060962463063853126, 0.02682178361075265, 0.036490164630647214, 0.031572787423751185, 0.006731695453968963, 0.05832297541201115, 0.035184941454125304, 0.05061377604891147, 0.043383873466934474, 0.05857629967587335, 0.03904133416446192, 0.04809449426829815, 0.031954456586390734, 0.016166849993169308, 0.0277796341771526, 0.08052102463053805, 0.044366979106728516, 0.057978747811700614, 0.031528295882578404, 0.01878117417384471, 0.009855891627791737, 0.017202019624944245, 0.022810662863776088, 0.022028915883441056, 0.03898520574771932, 0.017566930668960725, 0.0884414417669177, 0.13456607423722744, 0.1403054084096636, 0.18158316346151487, 0.21937605765249046, 0.12888468695538385, 0.22573045667793068, 0.13076740450092725, 0.0788042563945055, 0.23086945020726748, 0.08573498949408531, 0.20060111582279205, 0.14853417899991783, 0.11171669925429992, 0.12623236142098904, 0.09743259394807474, 0.16463683279497282, 0.10456544227365937, 0.06588326687259333, 0.07177896944007703, 0.15123831746833666, 0.1303020380437374, 0.11156918574124575, 0.10536409834665911, 0.07251507136970758, 0.13514410464891366, 0.09487706143409014, 0.1682251159633909, 0.1208852476307324, 0.1194397509098053, 0.10179055974419628, 0.1695387733301946, 0.12986534647643566, 0.0830795494839549, 0.20786894511963638, 0.17523183141435894, 0.09525096815611635, 0.12987294606864452, 0.11737532168626785, 0.11394022458365985, 0.18787782426391328, 0.3067596565399851, 0.20150987777326787, 0.11864597350358963, 0.11580899144921984, 0.15793995000422, 0.1346033936632531, 0.07765889606837716, 0.1460527628660202, 0.17846947482654027, 0.1336175501346588, 0.10649929421820811, 0.12692013808659144, 0.10473073340420212, 0.07882725873163768, 0.10398741186197315, 0.11720258024122034, 0.06222081304128681, 0.18453225307166576, 0.139917734212109, 0.12116731463798455, 0.09247055556625128, 0.06761526143444435, 0.11307945541505303, 0.16717535443603992, 0.07730206807277032, 0.09987616139863219, 0.21827354681278976, 0.1685255712696484, 0.14756722588624271, 0.14229363815060683, 0.1302250786019223, 0.12419586069881916, 0.10172193271241017, 0.11107119532035929, 0.12065393504287515, 0.09562311747244426, 0.16853363226566995, 0.11138718229319368, 0.17900135128625802, 0.09827728862208979, 0.12829514858978136, 0.09016359078564815, 0.13329563955111162, 0.07903023569711617, 0.1241765631628888, 0.116657038086227, 0.08805024597261633, 0.06592147517949343, 0.09568354780120508, 0.1277523748576641, 0.2041947187057563, 0.25090178528002327, 0.11175550467201642, 0.13956469244190625, 0.15859514341822692, 0.15300063576017106, 0.1623889955558947, 0.2033258681850774, 0.14104476730738366, 0.146944059325116, 0.16499824768730573, 0.11310253239103726, 0.0964187133525099, 0.10713668965867587, 0.08504262593175684, 0.15292438199477537, 0.07972287745880229, 0.10987105007682528, 0.07390449395669357, 0.0989554775878787, 0.17382871599069663, 0.14193561593336718, 0.12473199835845403, 0.1832773025546755, 0.08555744402110577, 0.07301977250192847, 0.15039476273315294, 0.1974063151116882, 0.21475402638316154, 0.08440896243389164, 0.08277089747467212, 0.1591671755803483, 0.11995800238634859, 0.15299553317683084, 0.17777171012546333, 0.12530802030648502, 0.10283889634800808, 0.13280234459255422, 0.1106098797172308, 0.10310633414025817, 0.1445882807352713, 0.12654501678688185, 0.09805881391678538, 0.11453734897077084, 0.15675323296870503, 0.12231500233922686, 0.0955724919747029, 0.0986193177689399, 0.178197192294257, 0.12292201976690974, 0.08642216226352112, 0.08153050153383187, 0.12073557637631893, 0.20028177010161535, 0.13948432675429753, 0.18083589284547738, 0.11792797488825661, 0.18930330420179026, 0.11894716162766729, 0.12439958405281816, 0.13419350422918797, 0.10083975576396499, 0.10706060552703482, 0.08007446716406516, 0.19705024707530225, 0.277716186429773, 0.12437932299716131, 0.10917077479617936, 0.11172906216233969, 0.1858477153416191, 0.09664833638817072, 0.09563503933272191, 0.1615844972963844, 0.08573522698134184, 0.13527449193809712, 0.15394301233547075, 0.13666223175823689, 0.11196346208453178, 0.11621930157499653, 0.12581460098070757, 0.1112078929852162, 0.08261896669864655, 0.08504990661250693, 0.07527588786823408, 0.16214527934789658], [0.06171041900025947, 0.012509425802688514, 0.032972208224236965, 0.036465041871581755, 0.02095554642645376, 0.027028156643999473, 0.04780974365504725, 0.031348066803600104, 0.03351286153442093, 0.00914313893632165, 0.05826198868453503, 0.039129940659872124, 0.041372794059238265, 0.03291728759982756, 0.02854414636801396, 0.04336198053455778, 0.01601522964691477, 0.06540909981621162, 0.042089537384786775, 0.008225020836107433, 0.04966689400108797, 0.031063275478248085, 0.03154814303187387, 0.016354064590164592, 0.018982388644612262, 0.03736903711355158, 0.007413359791306513, 0.07290771244359867, 0.01055336625514818, 0.015430373172940952, 0.05512191182268517, 0.00677806102404637, 0.010755877575970121, 0.028865802500929152, 0.035307267747287235, 0.04966215443398271, 0.02667058225987213, 0.04503861342423728, 0.031066630833915303, 0.03404264132093106, 0.06068998375641448, 0.05518764150994165, 0.034681780596396754, 0.0536403034680656, 0.01638782679635499, 0.01747288232270096, 0.014935911134151476, 0.026882135907986333, 0.006241104881545263, 0.03272873628884554, 0.0362328336174999, 0.026242854140166725, 0.0632967728057078, 0.015063628388036574, 0.016583962432507957, 0.04598429446507778, 0.02280251874721476, 0.01254315153762166, 0.03156620902674539, 0.022918029156114374, 0.033936582904841216, 0.046044619620910714, 0.02519739791750908, 0.040343354655695815, 0.02206281040396009, 0.015576607647484966, 0.019796120069388832, 0.022986059077084064, 0.06360193714499474, 0.016535623597779443, 0.021531458112544248, 0.03203531760456307, 0.02801228008632149, 0.044466462518487654, 0.05213286328528609, 0.023624937116567577, 0.010617803333194127, 0.05009652541152068, 0.00672486557492188, 0.11007788112120968, 0.03136467055550643, 0.0012682549983894984, 0.04630149940827063, 0.05872697516211441, 0.020313275711877004, 0.01305608669229384, 0.030088166373648813, 0.004571806107248578, 0.04118185769766569, 0.044247828357453854, 0.012763728853315115, 0.04715543912191476, 0.014104061976208218, 0.019488228019326925, 0.01917527579436345, 0.010638588557152875, 0.022930027351581624, 0.04784628276580146, 0.04132571051429425, 0.08499090799263545, 0.031339876885925017, 0.06971707793750934, 0.035075425902115445, 0.058207563390689235, 0.04929299406441195, 0.041492843867412636, 0.026358839523579394, 0.03339721881119268, 0.02824408800474235, 0.06795288010367326, 0.028697244224271605, 0.022056381284658397, 0.0319278139088835, 0.024716594788644995, 0.05635264542485986, 0.016694339723991494, 0.00960835357130106, 0.003399689873081765, 0.03845519865197795, 0.07020653238786118, 0.036059854685195854, 0.016641853343961493, 0.06357084667044026, 0.04604066715442708, 0.043629788128393035, 0.04054912718545113, 0.03331979118021471, 0.059280992219490666, 0.02196764586759465, 0.019150039380682365, 0.055748694975461276, 0.06517089331256491, 0.03609706215294344, 0.029592028353363276, 0.023241240830559815, 0.048540831210889986, 0.028697736162160124, 0.03333793520661337, 0.03132902032562664, 0.03983305560957108, 0.016650311282968948, 0.029230593104979823, 0.06326425740761416, 0.009953865299134381, 0.09093855241579668, 0.10913572167711598, 0.04798999309007611, 0.08377854233341557, 0.011335790074164314, 0.050122296171528954, 0.054862857330590487, 0.041977555357984135, 0.03282640801210489, 0.020589539548382163, 0.015675616084731052, 0.02652803053414183, 0.053927527341459475, 0.021767323670376624, 0.0925576455358948, 0.06742326995091778, 0.031366662055786164, 0.036437561203326495, 0.039357070079339404, 0.06602411717176437, 0.0689179604606969, 0.034869602482233725, 0.08539460918733052, 0.015600325839061822, 0.020192403179992522, 0.03671684960967728, 0.009676455586616482, 0.037720121310225556, 0.07105649249362093, 0.011292219644279351, 0.019104460487142205, 0.05032319342717528, 0.04548170696943998, 0.08826587761619262, 0.02615273111898984, 0.013806557449113046, 0.027395442560581223, 0.028358504275924394, 0.031506097609443326, 0.014507163515580552, 0.037409362449709854, 0.02174636541998812, 0.010034605877340903, 0.1009280060284904, 0.022228534100577235, 0.025359898572787642, 0.0406611465316798, 0.037393430447471995, 0.04065817115562303, 0.0556665515261037, 0.04158167767205408, 0.0207785352998014, 0.02256877700399075, 0.058455683290958405, 0.022369910264387727, 0.01910246559418738, 0.02080477594531008, 0.027534114762342403, 0.013547337564107562, 0.04880105617589184, 0.08298659018640007, 0.05475310089864901, 0.05542294727638364, 0.024809811929506913, 0.009187445576701845, 0.03834997483396104, 0.06168354901352099, 0.031188858739499534, 0.051117299922875, 0.04147149037037577, 0.05844099300780466, 0.02168510727850454, 0.01278248949841197, 0.037087241520306895, 0.044555666124714274, 0.05620984433751021, 0.05072712871645178, 0.016949100785755684, 0.03619896454204406, 0.01739210951408105, 0.017343809695116112, 0.013334891642443836, 0.016219260038009713, 0.04655239451676607, 0.01007702449403171, 0.01776672530520175, 0.038767874373921325, 0.050463633212660036, 0.006029310777583825, 0.028563637286424637, 0.06726652836161, 0.017896637619872178, 0.02692198457329401, 0.018632310376103436, 0.013775403361900576, 0.06805922689714602, 0.017971466461728727, 0.004951639832662684, 0.03350830517177071, 0.04783487659213798, 0.03811719321778842, 0.03592008664937956, 0.046493453572371175, 0.03127296315506101, 0.06967064578618322, 0.0639427313581109, 0.0233987610388015, 0.029691881566707577, 0.026914703892543912, 0.02831202801982207, 0.023158556249524866, 0.03960200086502092, 0.05193497533244746, 0.05056759834821735, 0.02614170153226171, 0.012216995869364058, 0.018134696542152336, 0.04301069277737822, 0.05895300196217639, 0.031517429144254754, 0.06843419213380132, 0.018295378723580922, 0.010358435018653316, 0.02929699793457985, 0.023091455921530724, 0.027039291403655494, 0.054523067349301915, 0.006913832488602826, 0.0095091822856505, 0.022188481874763966, 0.023914990480989218, 0.0435588201507926, 0.041721337142267396, 0.009036246770327645, 0.023886851633765867, 0.09516524882721049, 0.04387388092332652, 0.03557644258918507, 0.03555930279461401, 0.04021919631798353, 0.026791359796854, 0.04415529992963586, 0.033321063433374674, 0.033766474175666056, 0.04523636906274727, 0.006130388746636787, 0.022881320411605493, 0.04903515075732555, 0.009610004955902696, 0.0036819913989997333, 0.032766445872506926, 0.05074735584535769, 0.034267090527074676, 0.02390526537783444, 0.036457747620131285, 0.01771236107950764, 0.0417164652608335, 0.004570586016468171, 0.029628285872084752, 0.01622942109991397, 0.032077875320932696, 0.03874526219442487, 0.050015793315001895, 0.032037763723305294, 0.04076430081788983, 0.03973190300166607, 0.023413502212081636, 0.041971825129751644, 0.0638137554217662, 0.07560543875609126, 0.031886457199496884, 0.042307859419712, 0.06025529386741774, 0.05245394266343542, 0.04595065609152828, 0.014495777697967631, 0.008992981681201075, 0.03474146792931216, 0.0579034032832299, 0.043428683919566016, 0.025599275549341525, 0.02296323485539428, 0.04923651280945965, 0.06977120467594691, 0.015255229713927423, 0.03782775732023375, 0.015825881057285836, 0.02674025932459959, 0.04588413251829999, 0.0273412343979414, 0.04340107093698212, 0.022576500428840518, 0.01405763067305088, 0.008153089338780513, 0.022917145364252583, 0.0576891829924924, 0.09137808704482657, 0.022712039495153085, 0.04961854838100927, 0.004180931344827903, 0.03561998757400683, 0.06384122930467129, 0.04281321533822587, 0.03700173592993191, 0.0609615741829787, 0.0332875166620527, 0.019349716969632676, 0.024048276811039875, 0.16385886525469168, 0.1705628183803388, 0.1470211816153356, 0.07092716371906654, 0.08508890202002865, 0.12699253777308123, 0.13117312772997788, 0.15459139325789042, 0.0998258548123496, 0.12870606939707482, 0.2354657921407904, 0.14475330045180662, 0.086221709448312, 0.17257947873856339, 0.13698876995061124, 0.20006857439875603, 0.09834187837051493, 0.22072338392691954, 0.12278287937598568, 0.12836039651717457, 0.08629700647933142, 0.22478654661348887, 0.0604754038421171, 0.11537543471370425, 0.1853894056486232, 0.10466051181512219, 0.12649903925401823, 0.13501261813299997, 0.14643635228276253, 0.15856950836522238, 0.151979142001697, 0.06540237553417683, 0.1102562476215618, 0.14685879461467266, 0.10003189197076218, 0.14129533671907016, 0.1384938284754753, 0.10401917408619608, 0.16852516414863722, 0.10554571502975055, 0.11784919697259154, 0.2073355351707765, 0.14188863416867598, 0.14339262060821056, 0.13098005737577165, 0.14143979682454041, 0.10730183829686471, 0.13888785376080445, 0.08263958059251308, 0.12642286691282476, 0.0861345584105168, 0.12767960876226425, 0.10385743169380085, 0.12834964852247918, 0.06788795108773879, 0.091435810018863, 0.09397114933069263, 0.09303359713937555, 0.1510535388120583, 0.10863049807293074, 0.09075283738119261, 0.12435721632625375, 0.11263029237410851, 0.12889531281377586, 0.11243809054472617, 0.11871959455311298, 0.15915618331304618, 0.04768804839945265, 0.27654278225132395, 0.14668438397347927, 0.1143208420170205, 0.10938433012259857, 0.14593842971537793, 0.07453537546098232, 0.08457825692104441, 0.12786488953445638, 0.09587985476745026, 0.10628178303263017, 0.06910727173089981, 0.1768218968063593, 0.13134757908327238, 0.15886217408946582, 0.15398084744811058, 0.20743624333824429, 0.07704505257840667, 0.1435216643980571, 0.19934563604848726, 0.06580161875379936, 0.14277467876672745, 0.09123860060104302, 0.09282181957470519, 0.13937914025570664, 0.08589673188648053, 0.05955246050975152, 0.14293717433299336, 0.12564673141709395, 0.06801579387060233, 0.23186187552554266, 0.122553697388087, 0.14885209979755537, 0.2174233967172248, 0.15180148796311446, 0.09711542632430792, 0.1666560580155679, 0.12683460196214064, 0.11397211572953633, 0.16853850414710386, 0.1866244479481663, 0.10859108875904765, 0.20381073573870317, 0.06125402956136635, 0.08858017503683056, 0.08818163749362741, 0.1115607244095632, 0.16455266731125967, 0.16920938529074192, 0.10970047315848724, 0.12306291077818189, 0.08988554749105658, 0.2491788220192705, 0.09304706605949573, 0.10461164372307913, 0.20761866069265775, 0.2116978775177683, 0.13865245639213494, 0.09262877636189971, 0.09320667785193239, 0.08884077998144285, 0.07637269222842795, 0.19738123645739897, 0.17123010328837804, 0.1428207784358944, 0.13379985892346927, 0.1490618349718196, 0.11057026005749192, 0.10950745708708252, 0.1796216680003064, 0.1369110912616764, 0.10334732942283154, 0.1843750500785453, 0.12522390910557338, 0.150195517710277, 0.1543637311884335, 0.10929498741669313, 0.16335037111171655, 0.25764237929667744, 0.12494224921933242, 0.14926299346344812, 0.08491107834769146, 0.11908843261854989, 0.2148966680147818, 0.16264246909746102, 0.10916394873389176, 0.08218378826443638, 0.11705642379820347, 0.14021748384194715, 0.1977821827999183, 0.08015729593379156, 0.16167444389845642, 0.18495651387742587, 0.0765536982300026, 0.24383538588881493, 0.1294364852032491, 0.14707949491483824, 0.19499976853174822, 0.1644972174295357, 0.17514883301087789, 0.09519941985074963, 0.1630131799195494, 0.10177083473120417, 0.11142455600202084, 0.12318774765091282, 0.13759041338094644, 0.08842456660100392, 0.10916369767593485, 0.12239777004080159], [0.01772443561016449, 0.037674808741680214, 0.01959857647307217, 0.03160178801044822, 0.03332683098103319, 0.07602282600211245, 0.03880624892190099, 0.021348784611161267, 0.01997758917111371, 0.027509195563782538, 0.032259427543197355, 0.03758000722154975, 0.0224085545300373, 0.03939673723652959, 0.03120768130091684, 0.07104439421423844, 0.05491537254835878, 0.038156918050455194, 0.024083190830424428, 0.04793471284210682, 0.03385674986722214, 0.04164963295417173, 0.018416563381573985, 0.02148994873277843, 0.0425671547917383, 0.01095038472807833, 0.023300695765231336, 0.00791534932795912, 0.039726189736809046, 0.009401733720941203, 0.06108119312141623, 0.04398664665807571, 0.06288899361555066, 0.06976986117660999, 0.05629352806136012, 0.016740593759875213, 0.01825109074291374, 0.027019546034612825, 0.022923537164128253, 0.02360862004570663, 0.02070467167400888, 0.08062353091580526, 0.062424814594643455, 0.02074362467309194, 0.04111473701362099, 0.01942387066914567, 0.029860504304191897, 0.023638370413599268, 0.04931489038946373, 0.020993641078738228, 0.02006323555750506, 0.04508794631276812, 0.03105335190360035, 0.00615891393473638, 0.0512232769147626, 0.009804011688434651, 0.034118983295879195, 0.09502446638154131, 0.030365717730351856, 0.017654934964541878, 0.057686950612281046, 0.07675586773880891, 0.01236426002079887, 0.021465244969086986, 0.01681216054462961, 0.048924183140375783, 0.05545256193727255, 0.013608781454552497, 0.062108040521187444, 0.04687981141198959, 0.029096484051219056, 0.03345044309805546, 0.005684543741933469, 0.02568034521703209, 0.06950599926390819, 0.023846365145540664, 0.03293625943894897, 0.01122505824813353, 0.05007979613063591, 0.04190778160201652, 0.027643324973593866, 0.012297991746371346, 0.003227406015087451, 0.05006690396528159, 0.018595245400709764, 0.07176524267664977, 0.06163306600813355, 0.011913613532669842, 0.009352347397777652, 0.03606789193249174, 0.04135032437209572, 0.0458075666267957, 0.01804287209441619, 0.023311450545276915, 0.04816500084208591, 0.01746633615610855, 0.006913082283322832, 0.03473968677488821, 0.059933600415076525, 0.07356659030275685, 0.05903886378343616, 0.08011393076074974, 0.007675024098716676, 0.015563893597573042, 0.02356879343278706, 0.06285168097487517, 0.06301966588944197, 0.011310367911521877, 0.06820374128541776, 0.0233315894646304, 0.00902539529904191, 0.020231590273657014, 0.00872364907991141, 0.0014178711218327017, 0.02374179272114166, 0.045144037410084686, 0.037165944797119925, 0.04468990410012858, 0.02867021817447884, 0.026492906168901494, 0.02235564067294555, 0.03780661416905267, 0.011037114225993199, 0.0480704707359629, 0.007424659943873329, 0.0679650530219078, 0.016663817522515143, 0.01883184038368719, 0.07919623250407831, 0.009366928267159631, 0.03145011507772973, 0.011231640037814421, 0.06761064061096736, 0.052670904235648255, 0.043660993953900676, 0.021305852004193833, 0.05159270191299064, 0.02106053614988923, 0.0020552172624905196, 0.019981312632028545, 0.0084699405955949, 0.07526387101305382, 0.06466141529381275, 0.013366280672406512, 0.03223309699179871, 0.05596549030659454, 0.05603024968877435, 0.03168434875884226, 0.047473356526877196, 0.022903869826612726, 0.06812639507864203, 0.012731735927185841, 0.021125180181115866, 0.03285703029749649, 0.0114736675417849, 0.024783018277958035, 0.013755050704016216, 0.02447733485938183, 0.026120344642549753, 0.04908892126487834, 0.04977770894765854, 0.008596264308185449, 0.06277565112603561, 0.00799931718834809, 0.02625410764345101, 0.04333515465259552, 0.008346521861052938, 0.02969783910417131, 0.016129593331632868, 0.036542269334729226, 0.0059259860094503635, 0.06736608980489628, 0.021302109883565987, 0.04972357881654586, 0.027895706073780144, 0.0030303312440602376, 0.04185893725869911, 0.032503486411379914, 0.05265405960381031, 0.01914535748905369, 0.03514374080779297, 0.018369888653978705, 0.01784033278402473, 0.03875716030597687, 0.03555144535909806, 0.027830973833001087, 0.01925348204427532, 0.048530201959822855, 0.04502708511427045, 0.04065553843975067, 0.01970672477701945, 0.04792208191273468, 0.04888654141021626, 0.022155728989413807, 0.06641234776803426, 0.07376730096127306, 0.030211649569017545, 0.03893658871363316, 0.04930440363075052, 0.013425037564177598, 0.047157569721873314, 0.02941290189379028, 0.09624917459275041, 0.010116763745567628, 0.02641744289680251, 0.03958044041480337, 0.014486880407535603, 0.01417891965580306, 0.07635793409177236, 0.0515783135779202, 0.022175333562440107, 0.04871601198932954, 0.055021400430372784, 0.025815629832712666, 0.014440159878826566, 0.02261371468193829, 0.016597205739734427, 0.014293460607794779, 0.03437708783894777, 0.016428287839516997, 0.017819929236013974, 0.013672166803319539, 0.08005135626132999, 0.04227276898122259, 0.04428984663848366, 0.028422055865771005, 0.018453205968918543, 0.02270878931241376, 0.00997875226728086, 0.021828072910596217, 0.03339311367432986, 0.0351485957258514, 0.058080372001443586, 0.07274595648050308, 0.05523501343226858, 0.030127484085304395, 0.02725637341583414, 0.03893655817955732, 0.024626308919063637, 0.047731898725032806, 0.042727448511868715, 0.010572748607955873, 0.039727964105882814, 0.042800798147384606, 0.01691132165225489, 0.040966107310461145, 0.03296864930806415, 0.004109393821896187, 0.02823592522846801, 0.043449338525533676, 0.028668623617185012, 0.023470835028482333, 0.05153230890365584, 0.012843797681853175, 0.007770465986270989, 0.04286843451804348, 0.09408265299030713, 0.020772301259317567, 0.0669848888314196, 0.031382882435406954, 0.05104765508856092, 0.040108123528105874, 0.07091283984482288, 0.0025060681592939155, 0.024299443333542774, 0.02545283072894173, 0.012882942367079002, 0.043790597535137615, 0.01907309011689254, 0.022020529190610563, 0.04018038411491683, 0.034110823912279944, 0.023138988995924592, 0.007887424219266644, 0.009546016559137829, 0.03582685933049236, 0.0574199470824429, 0.0358923549231674, 0.01420453520092581, 0.02626170214664723, 0.05957951370094504, 0.03487964480050972, 0.032418818811752965, 0.01615601378892149, 0.024950942124373147, 0.034479268427406035, 0.03104612889832684, 0.0036851529481022483, 0.02485203886005495, 0.02288071990811399, 0.06490804241704089, 0.0743656942088689, 0.03811940524194922, 0.04862390425322311, 0.043461328239313195, 0.05340918765536376, 0.02734171785414219, 0.036952789806361706, 0.03237885988450476, 0.05434594935338412, 0.028484930616936514, 0.08959752973169088, 0.007764136102715773, 0.061879618492509635, 0.0324340146034956, 0.035446380996810536, 0.027818904391356876, 0.0334485160586025, 0.04429852170869708, 0.11375346460512706, 0.09817347954958677, 0.015492708488766636, 0.026156771795025895, 0.025602629208671193, 0.03903726973970022, 0.023350311942132454, 0.07132317711200033, 0.04213244454669101, 0.026779168218906437, 0.04284005818356361, 0.05143306637182832, 0.09386762524289743, 0.009210264709378992, 0.04416751695264663, 0.04527101166812437, 0.011879843692960483, 0.08340102580509015, 0.06238366144576243, 0.04291634587571025, 0.031997092334287505, 0.010916727694815822, 0.006287368247285485, 0.03291794577879565, 0.043758048210293055, 0.04010749927588871, 0.037657034516866715, 0.013827891438268125, 0.027031052292191556, 0.051925462271486006, 0.014321677486545272, 0.056260459657226286, 0.05412318291408675, 0.025891167743663703, 0.006487556009752942, 0.018012928344043236, 0.02543124313732343, 0.015104372719568866, 0.041880250043634853, 0.038372882176190615, 0.03771195853395121, 0.046357749961316586, 0.022916169970163276, 0.10335585860801594, 0.13803621088819845, 0.23927204789859907, 0.11924870258995465, 0.11928541133446352, 0.14389038032719068, 0.1027522881382278, 0.0857075834646821, 0.12406936820064272, 0.07656979308064495, 0.1187909764370748, 0.1057808884818639, 0.10883283043014151, 0.0995290025270411, 0.13084884227386542, 0.12684066806520733, 0.14501668060464518, 0.15344356984964438, 0.11774149989443165, 0.11653680168092251, 0.07371774076351098, 0.10114047569887978, 0.09111901558935642, 0.06707519505705152, 0.09272261096962861, 0.13039814574377878, 0.20207854440169676, 0.23224451499325888, 0.116083418152162, 0.12678520461278303, 0.08781250087278229, 0.09285693376192025, 0.12905902974307537, 0.12030795003686633, 0.14500414127750055, 0.15120021094168934, 0.12659547265086854, 0.11935935808079583, 0.1092893352199878, 0.1315308513918093, 0.1871129253080913, 0.1439428717962333, 0.09339738011892353, 0.15708642080426216, 0.23149188395057405, 0.11753095047814505, 0.14688907084720476, 0.09995390115571873, 0.10179600159504584, 0.09231018381459372, 0.14538247883319855, 0.1454098645065512, 0.10251634794154338, 0.10652975365519524, 0.14877754236970628, 0.14018304140440055, 0.10621857749564306, 0.23959280497261456, 0.12244427683097975, 0.12490083144179412, 0.18456704834742205, 0.2757275088557175, 0.13604880895997795, 0.10285241276557956, 0.10928783565759659, 0.12191915858004775, 0.14228651353291102, 0.1717644224741629, 0.12161024872745786, 0.11471175961196423, 0.14456749042229994, 0.10618042347154447, 0.040315514363880665, 0.11393749687288489, 0.1436528523585626, 0.16853307586695465, 0.13272311884377683, 0.12579818043325627, 0.12623264640569687, 0.11579221806355885, 0.1373595350555011, 0.18846105225384235, 0.14372092299163342, 0.10194475682718412, 0.08769506681710482, 0.17452159523963928, 0.17328621367258684, 0.0764538992994598, 0.11378786633057253, 0.10167943606419222, 0.1103063981447901, 0.08185204570846898, 0.07526775901871068, 0.06394811892615897, 0.13974884684596742, 0.10617517839585032, 0.0973849268630147, 0.10139601877225296, 0.09633895834641797, 0.15051242070538656, 0.17774659075907298, 0.1563481611332723, 0.06070788351020642, 0.19333747987236294, 0.09435358523790326, 0.1669001949152776, 0.15428070564355167, 0.09867597544299704, 0.13104666237320217, 0.09273844119161367, 0.12461181623595101, 0.09329516560371433, 0.0946629089968545, 0.07777246247444834, 0.10890404946569886, 0.08236448213990245, 0.19537843178425515, 0.1192072576710156, 0.06991014829171555, 0.12769467223967823, 0.11008626102869, 0.11824768701834337, 0.1448756403156689, 0.1160308588296175, 0.11721624593649592, 0.21841207652219705, 0.13798373298985617, 0.060293888939278464, 0.11748250307781355, 0.08546362298407725, 0.08514316446546998, 0.17049472060586723, 0.14745134567575796, 0.14236503360526903, 0.21632208009915693, 0.13867620511778764, 0.1656827266727175, 0.14608647248574666, 0.12463598565331527, 0.16972672753036022, 0.14797601609357766, 0.12968552112579346, 0.09664224314370326, 0.12623115362865583, 0.1057566919230989, 0.18640302840088094, 0.20129315368831158, 0.1473889068833419, 0.09006818197667599, 0.12296491675078869, 0.15036337370319025, 0.0781190310205732, 0.11485738679766655, 0.10263216029852629, 0.1378260821636234, 0.09417014329561166, 0.1501218152365514, 0.10913454102618353, 0.09710152314177581, 0.10631798287587506, 0.14281985562826904, 0.0837790851614305, 0.17380655503698758, 0.09234873817435332, 0.14112079037087305, 0.16327391378581524, 0.11748369729944638, 0.10153857219432082, 0.09869664361966507, 0.12207549304834434, 0.08036766214562313, 0.1806988694838115, 0.17393394320138864, 0.07563820521214179, 0.07793819465275321, 0.10149099331881319], [0.02461978480485933, 0.03371536013271127, 0.008940442714707127, 0.04061230897371258, 0.059712818690708706, 0.047895099967718124, 0.005218549215767, 0.025214544497430325, 0.02417894060324345, 0.041706687571214776, 0.03305378509685397, 0.033420367033353875, 0.061615586946053166, 0.002750086527417547, 0.02239767591735082, 0.010539844748564065, 0.04128485592082143, 0.039527518076023886, 0.05440376053697296, 0.03161872085183859, 0.03016200116170304, 0.08051257008420569, 0.04388021504772561, 0.02945063861885241, 0.012467570370063186, 0.020134870195761323, 0.05432571543912802, 0.02784845119874392, 0.03740619369117277, 0.01207236697830792, 0.0352534192082073, 0.041143941160823615, 0.01310192173280354, 0.008706935914233327, 0.06610951080386128, 0.06520008388906717, 0.02437583450227976, 0.037536988101367436, 0.08030590188822576, 0.06111486202904156, 0.03944687758173261, 0.05394999702860202, 0.017860322425674115, 0.04748092897768531, 0.02337038640065917, 0.013073205282645566, 0.019304043081189905, 0.05795173533260822, 0.06452564722193138, 0.03661133741427745, 0.009607065202934402, 0.03563666596476521, 0.045274689327925444, 0.036962913548839946, 0.025439729914069176, 0.009217966081840652, 0.02256586099974811, 0.078088313740279, 0.040262140799313784, 0.03364867031840341, 0.01206579536665231, 0.057300585987312455, 0.02630350329647107, 0.07386038239513125, 0.06389184801706246, 0.01604225908938263, 0.03265145793557167, 0.06198371933507068, 0.006283005691199962, 0.01531407396708216, 0.031095906227294887, 0.041582915998463116, 0.018394114050482, 0.018853967410645316, 0.050025316553988626, 0.012730327118853373, 0.03927689438153591, 0.08417016560477869, 0.01403124668701951, 0.023680609218510132, 0.01867392492879714, 0.024337069796664373, 0.04525722722922053, 0.061157358677259514, 0.022269066389916197, 0.034570358360984495, 0.05815355878855501, 0.030323176977357695, 0.08667420409619808, 0.05959820055535861, 0.031623952356832366, 0.05256306127245937, 0.029686887548970323, 0.035103038884699345, 0.020692746421056132, 0.05924853788954871, 0.035549267261688194, 0.004549237608443946, 0.019638460761468326, 0.018661563717094914, 0.027114998948361193, 0.05460866793457951, 0.014797479812321919, 0.03825333448393004, 0.03171536459454468, 0.07628073037735053, 0.01011744058424873, 0.08196973760745355, 0.050884667584406476, 0.023090200631746223, 0.04720644799194165, 0.08154756668955088, 0.015387421906260508, 0.015200541487761905, 0.02742162553061332, 0.04007299237751535, 0.045309077482670546, 0.08358863395239625, 0.022677958377503922, 0.08731039174433265, 0.024747123775471534, 0.017157059894608598, 0.06583837499575955, 0.06008215208670922, 0.05090083368122578, 0.01814575327028121, 0.012608467318516756, 0.009343886914263879, 0.059749574932668886, 0.04258694426555719, 0.039467182742165666, 0.041932809366179366, 0.040332012942859104, 0.03486918857587235, 0.023151038081518242, 0.04723183198698929, 0.01299682429193386, 0.0547399033925363, 0.025071661985878433, 0.029593097046017647, 0.027915705893454806, 0.06287775029029165, 0.11959592252969742, 0.009528524774525846, 0.009315924486145377, 0.010147324962807553, 0.03667690764580454, 0.04268778135467853, 0.03768996721399682, 0.04241874561245952, 0.01231678038103772, 0.0969298402113574, 0.10480588115751743, 0.044872440198170285, 0.003761764640720295, 0.03616073587909341, 0.05596052682293313, 0.05483445046203477, 0.029726849868893623, 0.022650572704151273, 0.02023997187747487, 0.042173312710864205, 0.020877129830686108, 0.01703378195608301, 0.013618412410973437, 0.03703781024419835, 0.009934706862882843, 0.017000761049400483, 0.07798918655940465, 0.044922465192420144, 0.07452945185026952, 0.0932028509144272, 0.034496370902551074, 0.08555798684912068, 0.03403941149424229, 0.05386636419487851, 0.022257595755425946, 0.05523785649399672, 0.015113300544076731, 0.01995541125402919, 0.006314614396874926, 0.06588205229490995, 0.044702860726309676, 0.05668099869840911, 0.010856281250848301, 0.011359998507292142, 0.05805479801659073, 0.05038358982918518, 0.02808721410110593, 0.027164218182276403, 0.028121997502499392, 0.05241285397538117, 0.04852377623319626, 0.01829780957528523, 0.02551871817559004, 0.04118989833763667, 0.00462186333191182, 0.05940061794327838, 0.047502689595733366, 0.043589289765805006, 0.03323084541729518, 0.0520897288141506, 0.024845480819099715, 0.04281416867992707, 0.039432387466409376, 0.059951072691806724, 0.04539820645004511, 0.06158058810979128, 0.01690790013942335, 0.07915239914187364, 0.04118997976183891, 0.04803414875641465, 0.03554541318278227, 0.04820849832945636, 0.030627784917929342, 0.05244419550789254, 0.04999939312360116, 0.012172935197928121, 0.04487423492329461, 0.022987904692334787, 0.06174463752124991, 0.03281411974291716, 0.018783762784940854, 0.03659197881019541, 0.0259257340138512, 0.05073995981365442, 0.02393652548614357, 0.02264729198733611, 0.06814313453755208, 0.05896075761743954, 0.030501085466572216, 0.04049519043681877, 0.02164241555146873, 0.04172286045338426, 0.01999360090121627, 0.03344948636367917, 0.011850544550855244, 0.04922871983477047, 0.04346316367653864, 0.04830089444294572, 0.04360727094379919, 0.02280639318217124, 0.04067502935816135, 0.03982292508174266, 0.06067908648401499, 0.04051431494631937, 0.013582148955070546, 0.055977639476103444, 0.019923277531883547, 0.0548046661673912, 0.04586075698690755, 0.00972426007501781, 0.018505899302129234, 0.02742411914680685, 0.010490750195458531, 0.09101649573338882, 0.00895534928089806, 0.06899247717644487, 0.024670900544151664, 0.041903357553694925, 0.033641508381281576, 0.02269149854380105, 0.04106264927291444, 0.04867334570735693, 0.030317589241479124, 0.038365136698952744, 0.027914074016734958, 0.09900910221040249, 0.046244505859379254, 0.02553194621577859, 0.015817728459036777, 0.03708371313820992, 0.0975860853546432, 0.0359303562768868, 0.022258274290444593, 0.03522175197888698, 0.04976877603413803, 0.05198149908600109, 0.059965491560953, 0.0281056787353009, 0.019304601176242744, 0.02183881920895406, 0.006976339982689491, 0.03993980613137994, 0.040265207777598074, 0.029295647649892738, 0.04823349895221846, 0.03120257532490151, 0.019405763962173035, 0.033459107990243604, 0.031434702154781134, 0.013045711891858705, 0.02768905314483813, 0.06968407399420228, 0.014523007308265992, 0.030211123704378093, 0.0184868646985186, 0.02056875093174832, 0.04546259942331484, 0.009236543522482472, 0.034874599892646074, 0.032707175838627985, 0.043953825919223685, 0.07667641807347536, 0.034909490163304975, 0.04457072960212827, 0.036318749721561155, 0.02602158217424793, 0.05376640580860632, 0.029877603386661837, 0.01606502054658319, 0.0653133788811309, 0.031195932467068945, 0.0669531130364963, 0.05156073612826211, 0.03693685780412384, 0.05297554610297084, 0.06673584612352507, 0.04130519161533032, 0.005399309672481779, 0.001962173148058355, 0.030166126654616425, 0.0379715151419597, 0.0262817749088364, 0.03220136869432671, 0.059559429064393044, 0.027730537079540745, 0.05301232609365668, 0.07762489467859268, 0.04209053483126419, 0.06956712848373822, 0.0272361598576286, 0.0668376467323729, 0.0372659608588687, 0.026672217529267073, 0.047265704455120225, 0.04966940458065697, 0.0504829816387168, 0.021259864293304936, 0.03070103277319244, 0.02811723418666848, 0.033152304988886626, 0.011742809305100568, 0.0396263602721904, 0.03308090953422444, 0.059719624396945746, 0.0370717743145568, 0.0972520357796124, 0.03475225663610867, 0.03241236594372562, 0.07033875172159501, 0.06379120091774634, 0.08252356467502457, 0.1862864696553775, 0.11607275158166885, 0.09370753847594772, 0.07750944194516965, 0.20437546686402389, 0.09876449033617973, 0.0924739075292434, 0.05091165970744831, 0.05922390706837177, 0.16539413215858595, 0.10455873834767512, 0.1832734891878707, 0.052551471894340854, 0.20718328548329218, 0.07239482817905289, 0.10289451586348669, 0.16010849364101887, 0.1563503188746316, 0.10760499417249646, 0.09281545491623026, 0.1308788742337908, 0.15673962155623095, 0.20931255551321165, 0.12013651137905461, 0.08592043311468192, 0.12997795614813054, 0.12304035627416202, 0.1464922364268984, 0.10109280861381974, 0.14361427085740225, 0.19336196141583578, 0.0697317546499627, 0.14275213783340795, 0.13232129040573323, 0.1759164868188756, 0.15736033182059014, 0.16967709947909626, 0.10365236484046493, 0.19985954490091118, 0.13123625862811292, 0.1428696465279375, 0.09921919022287641, 0.17010623216629028, 0.0815036247617432, 0.07327965819942099, 0.17029365710914135, 0.13403676263988018, 0.11836368936513152, 0.13625950765396866, 0.06498129705765418, 0.12324984717581954, 0.14098554477095604, 0.18419826456478663, 0.1304516550153494, 0.06133615944002356, 0.13306526334158011, 0.15838979158018315, 0.1191283440483468, 0.11232611191059862, 0.0853204113830413, 0.139314896560141, 0.08474651324961867, 0.15628835505672864, 0.17766819282301835, 0.13047435879707336, 0.23076766995447023, 0.15593744388648442, 0.1105913014284202, 0.05712006174560104, 0.21366035006940365, 0.08330108438219343, 0.06819900511098759, 0.22340312227606773, 0.09223420824855566, 0.15448544680007867, 0.13985935305910452, 0.22733337352318422, 0.07369741185435227, 0.14752207616610186, 0.0757645620033145, 0.09911124208675963, 0.13149634110076086, 0.09998093399086169, 0.12506688253155776, 0.17705550284257957, 0.11512314182307039, 0.16140634114188807, 0.1578230248498065, 0.115266814827919, 0.18366390466690063, 0.12569257324295385, 0.11207995297653334, 0.1129261472129396, 0.11308164029781308, 0.25334106438926285, 0.17387619987130165, 0.15030287552092755, 0.08729357764657054, 0.15567455227885926, 0.1335533471511943, 0.15427230538002082, 0.12960690605853284, 0.1070212572813034, 0.13889177569321223, 0.1178310393754925, 0.09705417496817452, 0.19373036521886075, 0.09793443166251693, 0.08364562410861254, 0.11719523849231855, 0.20163106412759849, 0.17892382187502726, 0.10432773110057626, 0.12329476619405405, 0.1329543228660311, 0.15071204570787294, 0.15097375666456564, 0.041874553742153306, 0.1571505559342248, 0.1420695044632469, 0.0946879672950932, 0.18657473847270012, 0.12211533662463937, 0.18313018259193214, 0.13218605837651662, 0.07266949915460177, 0.2524608416216714, 0.10047329257109336, 0.12506534904241562, 0.15674332635743277, 0.12905586776988848, 0.14403307624161243, 0.08153331066880908, 0.10208515929324286, 0.08554972907794373, 0.11399908071117741, 0.20658382693571703, 0.10508458263107709, 0.10840417271746056, 0.2002490647137165, 0.18833218488310063, 0.1292833262788398, 0.07703800259956292, 0.08080262344862733, 0.13254779896565846, 0.09981974121183157, 0.1303851721542222, 0.11499223884727273, 0.14588226058653422, 0.15038967372051307, 0.1897335632571152, 0.21046347304114274, 0.1141486433999879, 0.13977868881608757, 0.18807484369192803, 0.13066497285451206, 0.08350165254835572, 0.11822188911693436, 0.1471663202558245, 0.11765973642468452, 0.15465018153190613, 0.19686780257948808, 0.06393874835755144, 0.10232886871589081, 0.10067747054355485, 0.06719862057694367, 0.08011199015059642, 0.1581628080457449, 0.12109305576554366, 0.26690359520060675, 0.2052232963698251, 0.11289032056395497, 0.23222671023436955, 0.23291792028716632, 0.18030260503292084], [0.03647266521251627, 0.05133700616923826, 0.04880074065710817, 0.01988792585741196, 0.008346430258825421, 0.060583793025996, 0.0504173639097384, 0.052267644088715315, 0.014901763859337993, 0.04823555152064987, 0.013179479133603829, 0.061731399303036075, 0.004360412338948143, 0.013745767496792334, 0.018233939073979855, 0.06610016737665449, 0.017557851870411208, 0.012127623477551554, 0.01376298108204667, 0.056449747178703547, 0.07278476189821959, 0.007698419986159674, 0.0806227098884327, 0.04081866504358394, 0.023233259562402964, 0.022576296868334924, 0.01398413600067475, 0.016438961195360337, 0.0794349071968879, 0.06738035261098828, 0.02484101096966437, 0.02929848731894578, 0.027652951689170938, 0.03159766251753483, 0.006753379312743033, 0.02628373078602765, 0.0082530383951962, 0.0404048095723348, 0.012812773364463022, 0.026051003452656523, 0.06177640653082302, 0.059324255612279685, 0.02603187215780573, 0.031030010298958847, 0.013128207331257207, 0.025584095024636815, 0.03067185576739056, 0.04799343665529575, 0.026953795991305794, 0.02700019082320588, 0.031747293059847186, 0.01700756505929998, 0.016065022242920737, 0.04972866443651063, 0.037998782071684084, 0.0815598006759371, 0.027901334521759833, 0.021645972771303992, 0.017614909880129353, 0.005557470672231699, 0.0334257783501276, 0.013954876722501857, 0.03376653863649283, 0.08475157512085778, 0.06018504513693707, 0.0388956018058317, 0.029753295771245445, 0.03270330818902169, 0.01600904480021979, 0.028118392785212824, 0.03714398401124137, 0.044370164828641076, 0.03003147816551583, 0.05337254337168165, 0.004807702199156795, 0.03699675887557013, 0.07086810403104339, 0.02360423670948616, 0.032115252422434945, 0.04385997774079442, 0.02038919529877603, 0.03244898308600698, 0.06322290748357773, 0.030571245987500464, 0.128242304282529, 0.03414626718897905, 0.009242601992030228, 0.07185794413089752, 0.04972368738214884, 0.05595747341534921, 0.052122172966067276, 0.05111796488719327, 0.06312012978430305, 0.009786301076279154, 0.09132429957389832, 0.02674249849016113, 0.05585499766415783, 0.03333428468821304, 0.024271099229476283, 0.003089655136656282, 0.011694795319012232, 0.02608374446364386, 0.029878268350980113, 0.04233716195449233, 0.05237462531243052, 0.03166217762710793, 0.007773242890834808, 0.003593158018442669, 0.0549787171850247, 0.07900994750005857, 0.05181475589051843, 0.05133567624060171, 0.017219354498333166, 0.019869398458727767, 0.027003496985084245, 0.019562627687784176, 0.06240125585879598, 0.05332380759396723, 0.01127221219108573, 0.02161810194541301, 0.009876803228897708, 0.023081724033025757, 0.04566931172407099, 0.031828747796160836, 0.04215993878564664, 0.013455827786986316, 0.024055179208517075, 0.025946846630956446, 0.04689525826168912, 0.02600239829293319, 0.04253202024847269, 0.028471278492361307, 0.09350754027920109, 0.06668646913021803, 0.03869443652885301, 0.02987319290904062, 0.03043677391750472, 0.017718478072700754, 0.06323375725852591, 0.07339021191000938, 0.05827047037226813, 0.022691357747784684, 0.023885871150663922, 0.04204785158591611, 0.042254740305777104, 0.01225811509149415, 0.04266875523275562, 0.058200140217585225, 0.020164562888177376, 0.009067329611363155, 0.014532233688182064, 0.04282093706673809, 0.034075431525707245, 0.025742124134142483, 0.07109592894890479, 0.037475736745234044, 0.049422763886728456, 0.043338584647114785, 0.09362078777381352, 0.03548655026991453, 0.07465145244662251, 0.030925733037292957, 0.032610199613762755, 0.005987546099017241, 0.01574116596020758, 0.06066217739135027, 0.047818975123975954, 0.025913477975076864, 0.0314007821891989, 0.040754563840372224, 0.04402539440031562, 0.03332725167274475, 0.019589297506692152, 0.034950680631612024, 0.03915652905457786, 0.08375264943710395, 0.01667416687788708, 0.06502960196563176, 0.03579753304698637, 0.046457477645682435, 0.05325965889330421, 0.03663236860718046, 0.038558166341057847, 0.01825363694557122, 0.06239044001059873, 0.04466226397614394, 0.034375876653939486, 0.05713280463325126, 0.04326274139540536, 0.03682334568085415, 0.06679157420460667, 0.03672492756907429, 0.013030375304099704, 0.01054345625120082, 0.04677022461380277, 0.08179750506367002, 0.018334504749093736, 0.039861051964440515, 0.015660011475639682, 0.011208071123941668, 0.027924231685964123, 0.020042742103604332, 0.029380953072437217, 0.021270491848034517, 0.06296680122613907, 0.04299265731658254, 0.022667027178353498, 0.017678697260894945, 0.06153169287634747, 0.01270363015854465, 0.013791182693759245, 0.039146194966243844, 0.031311066289033206, 0.022409672416480522, 0.03649416798725724, 0.02198622585274279, 0.020450964037861143, 0.0049241591644074234, 0.0419230520326112, 0.04483967374211975, 0.08109420351684093, 0.07966755649873189, 0.04841830474989755, 0.053323665101613314, 0.01363052086838122, 0.027576409546392303, 0.009375822164916565, 0.042913194080548625, 0.023472857062837908, 0.03420886204444936, 0.05245089604120169, 0.021598590670951774, 0.054162368311413696, 0.012939639905068492, 0.023297985017831837, 0.01206211855502001, 0.023465170957414166, 0.02640475768462888, 0.019041797778170024, 0.03501499557335462, 0.008988341349842293, 0.03741923852690628, 0.04574590475697603, 0.029105613739894967, 0.0392511405849031, 0.03488493398098009, 0.03799480585647481, 0.006010566247693662, 0.010896959425216275, 0.02460649230384401, 0.07268325984477997, 0.016747260366433432, 0.017225547826715877, 0.05015592436705317, 0.033839304731892686, 0.022283510704125677, 0.01978084963879415, 0.016300165160958256, 0.09897850028106145, 0.042242299366210184, 0.0665690079331398, 0.026725063532856957, 0.03348158446273633, 0.03198651058067169, 0.008857934552777027, 0.04448044373254691, 0.011970545165240765, 0.035448474277343066, 0.02214041445404291, 0.005980247182638517, 0.07691558131149837, 0.049876659709428034, 0.07129760312714747, 0.056695577023284774, 0.08852288632520608, 0.015113534638658166, 0.024620198711220707, 0.01774380948128445, 0.0787466284153717, 0.07157715955483061, 0.04263264699173825, 0.03611687198281288, 0.031050936318933964, 0.0625075212280665, 0.0333176368315305, 0.09180707723966666, 0.06533799613160746, 0.013649768362353955, 0.045426372438669205, 0.06664515991828271, 0.012891435929174935, 0.05338058061897755, 0.048993122298270464, 0.028128754014947584, 0.024653182298477207, 0.026294161565601826, 0.008637168095447123, 0.013557998197419303, 0.04395435517653823, 0.04049490545211094, 0.03193306916260293, 0.03073280517544065, 0.020034346929086105, 0.028328680965517248, 0.012780182479348565, 0.03988999826833606, 0.03881932768438544, 0.04335123932521258, 0.024423623723643165, 0.023724936214940887, 0.027863770823127458, 0.08154045564255544, 0.028891790392143384, 0.024401786770405512, 0.04679116081180317, 0.05833869706839323, 0.02272106909991375, 0.06559157145342656, 0.013567708881704934, 0.023742639193577424, 0.017336408574400202, 0.0590684614809496, 0.021670301644397632, 0.060487237492842336, 0.007248217090299087, 0.033925655098365884, 0.020939609335203255, 0.03695739705913833, 0.009128949072744166, 0.06008903243179832, 0.0701594827696681, 0.017614669000197734, 0.08053772337734699, 0.024026277009397745, 0.058762353977986743, 0.0459795616833227, 0.08381025027483702, 0.025863147640068616, 0.017869046689676385, 0.02612554052445505, 0.020444668929225633, 0.027452295313456228, 0.040737614035606384, 0.03312683617696166, 0.06282657517918519, 0.02772644381704075, 0.024024760483631065, 0.02921290708971875, 0.03016537008807063, 0.03728882070364697, 0.02578393885466669, 0.017771821103191802, 0.15340032002755574, 0.1346873284450599, 0.18692167342773505, 0.16905744772936615, 0.13550019982670033, 0.15397171436675958, 0.07533866592815944, 0.12669574655592442, 0.0993876229705555, 0.105272584328694, 0.1000602954466428, 0.12809557787009648, 0.10729780779885394, 0.1280598190746137, 0.16342331362622126, 0.16696127663765634, 0.12269582333309309, 0.07851330736385924, 0.10857841372489929, 0.1554080101528338, 0.11746674749468054, 0.14437792130878993, 0.17651842880461896, 0.0861925460132105, 0.11516213044524193, 0.10925636520343167, 0.134650728266154, 0.1081300920673779, 0.15123895529125417, 0.10660684880401407, 0.09485570793705327, 0.10715292021632195, 0.1427168675831386, 0.15542976398553165, 0.11688446945377759, 0.10075590240636043, 0.07253788371703454, 0.14153472387364932, 0.08369891624897718, 0.11026356901441302, 0.19196742267480918, 0.1275448924196618, 0.1666654082281249, 0.09395717150930848, 0.19486754919801438, 0.17082203232816287, 0.2141418113772358, 0.0865687665396503, 0.10561696120670863, 0.14427132345736027, 0.08430929242500237, 0.19270769080945424, 0.1023624154872128, 0.09242230494107519, 0.15769974860761846, 0.12865520641207695, 0.14356538919465883, 0.06562869410429682, 0.1410012325005872, 0.10245316954595701, 0.08101464528590441, 0.20257449921752724, 0.11800065955945424, 0.12963763012417726, 0.11566491132336003, 0.1378493830561638, 0.08613829713846956, 0.13707665380622658, 0.1292586818869625, 0.12823619746736117, 0.17610904148646764, 0.177559423659529, 0.11144874577543565, 0.1537789697093623, 0.22097277268767357, 0.1178716564817088, 0.17475453631154128, 0.12196091562509537, 0.1141571793705225, 0.19998208832527908, 0.11140575379665409, 0.08151699190161057, 0.12151796796492167, 0.09311367105692625, 0.19528725024844917, 0.12771614108766827, 0.15976176224648952, 0.2395795871104513, 0.10608324368617364, 0.16952769963869027, 0.10805266443639994, 0.14135268649884633, 0.09915517722921711, 0.11292470871870007, 0.19851646625569888, 0.12240059274647917, 0.21713978265013012, 0.13604574198169367, 0.09124354712132897, 0.12467340007424355, 0.0942081209006054, 0.10722424781748227, 0.145795326679945, 0.19866974731641157, 0.07578875856207949, 0.08513950716171946, 0.09365449739353997, 0.1921793291611331, 0.12254201301506587, 0.24911216273903847, 0.15229924768209457, 0.09668659219252211, 0.1352735012769699, 0.1876082830131054, 0.06913156328456742, 0.2064311701272215, 0.1517195887863636, 0.13275625849408762, 0.08769163342991046, 0.12622972870511667, 0.11610243070338454, 0.10978149023971387, 0.15335313470235892, 0.12257386344884123, 0.08249577866601092, 0.13556265218981675, 0.08178537964288678, 0.1429151762276888, 0.15367406819547924, 0.12183955285165991, 0.09266438587967839, 0.15482898908002035, 0.15727071091532707, 0.11441097860889775, 0.09692604720060315, 0.15062247908541135, 0.11745256611279078, 0.12604197806545667, 0.13287346863320895, 0.18439756387046405, 0.11694427553032126, 0.18056149328393595, 0.12251841356711728, 0.14079516141542367, 0.14233972424907343, 0.10049467999488115, 0.09044881298073701, 0.13732486191604817, 0.15505796750741346, 0.07568010474954333, 0.07365661832903113, 0.1942616852798632, 0.11985376583678381, 0.0939041439976011, 0.17664566769131593, 0.1718276347965002, 0.18909674457141332, 0.0699724310210773, 0.13985316481973442, 0.09437398200056382, 0.19890339406473295, 0.13134022376367024, 0.10659955455256359, 0.09356856093342815, 0.07270270665841443, 0.14164054819515773, 0.12487943044730596, 0.07945088669657707, 0.14462504376258167, 0.10302805834050689, 0.07641013379075698, 0.14125497745616095, 0.0990676326411111, 0.11191338620015553, 0.13707311185342924, 0.17156285686152323], [0.015779761032068303, 0.019121907318809202, 0.02994721768690007, 0.04481969427849565, 0.016928922850638628, 0.012576816204403127, 0.010581483898152198, 0.049229883522327454, 0.03676424188805478, 0.03152133072061198, 0.05187066378337996, 0.008380001627041824, 0.025914906291291118, 0.05040076355050717, 0.022753582801669836, 0.015137799050925034, 0.06122786525104727, 0.03429506313321846, 0.051832713319786956, 0.017257961444556713, 0.0627988570236734, 0.025909968252692903, 0.03273345889257533, 0.013352905899020178, 0.03227051480540207, 0.05771160178950854, 0.01480809210001358, 0.021386426341320788, 0.05106988389577184, 0.029174902343324254, 0.05240784299426845, 0.028463115716086965, 0.038681910772408755, 0.020402039966679046, 0.03550155267917684, 0.055032979630466015, 0.04469992606235402, 0.019175789784640074, 0.032440009460385354, 0.06770270424229757, 0.0495150175078639, 0.019494187253128206, 0.06619271276784794, 0.04042174919907536, 0.039921305874096494, 0.001744908355509064, 0.06502371906702008, 0.02066664826790137, 0.024282668251544237, 0.044477509068591256, 0.02572344915409173, 0.05187393771484494, 0.04117308084719947, 0.04011581811521735, 0.021793057110958865, 0.032419938394533734, 0.03331885140921388, 0.02332962510575141, 0.05090385655473385, 0.03801796764933637, 0.029046079077358757, 0.05196421340640102, 0.029639590265495435, 0.06296285215233054, 0.03923239266233785, 0.0724145056945937, 0.03308753203600645, 0.005431540085867579, 0.031189214970384325, 0.044711590079324584, 0.028857351347271885, 0.0251168625961457, 0.09875683646116938, 0.04950003206197705, 0.037141907694084306, 0.009952507380928313, 0.07260528938578707, 0.07769291781421218, 0.040174684420760186, 0.014742357323744466, 0.02270668585385595, 0.007987455548053342, 0.033362708520144224, 0.04007178119250706, 0.03838304663076997, 0.020574852657903517, 0.005710620690868902, 0.051782030146569014, 0.008792579756118357, 0.008463564910925925, 0.02748595573939383, 0.024595206570146338, 0.023064886186537997, 0.10601877607405186, 0.03525135646175061, 0.01746818855670946, 0.026917869258405905, 0.010770853692000466, 0.02287485058020268, 0.05053347142945443, 0.07501401406313692, 0.031579518491136174, 0.01926155491465969, 0.014542276006458061, 0.007764334574208728, 0.02663838068422462, 0.05692348336534841, 0.09786894624786717, 0.036020425015262196, 0.039339255142424784, 0.009805150779097207, 0.017758250402818834, 0.05983771663159132, 0.026188393223232458, 0.05712898448109627, 0.014978336536192467, 0.06014575117400714, 0.025637614474232708, 0.059507894329726696, 0.030400876022343124, 0.023327036494655267, 0.018494459201714823, 0.007706117117777467, 0.010294660360419323, 0.03694038279354572, 0.06376148108392954, 0.04184161425967302, 0.03906544929902468, 0.053107185289263725, 0.1999292847301279, 0.02361121035314032, 0.0484377074587558, 0.047758269988532574, 0.07159991761935608, 0.03006455335499985, 0.08015011024794408, 0.0431026749845062, 0.018041102814355066, 0.01554105750152043, 0.0537591353058815, 0.08119570557028055, 0.04825334270883884, 0.012284317569408034, 0.03454729834837573, 0.05559208909315722, 0.13061263066317352, 0.039740649318056445, 0.014587478313062872, 0.02042840444482863, 0.07367677081908498, 0.025362144523699368, 0.012009062205574341, 0.058481270846511633, 0.01644384495115706, 0.040336450561881065, 0.03215222579560109, 0.060903912277093956, 0.021049604950738803, 0.028241925174370408, 0.08229876602334635, 0.019021765728081976, 0.052700237304504426, 0.029776993606771742, 0.014120921875084085, 0.05590556548642261, 0.061275681613811424, 0.024065564186977487, 0.02898520091548562, 0.0320037216214197, 0.057922124064394405, 0.01808455110793667, 0.004290092362290514, 0.031622228877885, 0.08511436065392834, 0.04396794962563685, 0.012987827765755355, 0.019558707451713935, 0.05207868904939719, 0.06531502093587603, 0.07494939038796083, 0.05097175755405, 0.018247525041390742, 0.07371703508709158, 0.05113267552639757, 0.020013502333313227, 0.02474298980087042, 0.011556726165248879, 0.022208493568801453, 0.008765956586492913, 0.06546110274004084, 0.06609982810914516, 0.046576268771397214, 0.031451095560831685, 0.08016738574951887, 0.03836477029004267, 0.03497556929609605, 0.039022786409727166, 0.037376141375196834, 0.05145765308822904, 0.03633521098111357, 0.02964007541803377, 0.03458071280536907, 0.03095547661983541, 0.03229772066697478, 0.03452425869181752, 0.02571969007008842, 0.019489805613245283, 0.025869437659691488, 0.02039967187946396, 0.01870711546923433, 0.029724407142826488, 0.03989301774916904, 0.028835142896111523, 0.028366108957145895, 0.03508663869329861, 0.01871913402075214, 0.06403703415500266, 0.04344145055594189, 0.021057949235130633, 0.0031286354891822805, 0.018301066543374742, 0.0061433525822524515, 0.03811220259272626, 0.02719578193500638, 0.04216488530593259, 0.04841465423149722, 0.011088708332473678, 0.04026648003075804, 0.04544596853000777, 0.014612458579774414, 0.031604810883956294, 0.05000340326556137, 0.06319727243057319, 0.03068356049646224, 0.028255804608176862, 0.029453810770064592, 0.05560828233137727, 0.040385647743408165, 0.054477137313889604, 0.017893075311024274, 0.03904574803475823, 0.0640761720548783, 0.007420354639180005, 0.019518616210137094, 0.03494289444227304, 0.00223581020587257, 0.04011327700157251, 0.01855236029119364, 0.051932532606380324, 0.018470033637381027, 0.0365714497332062, 0.03041499972875629, 0.0016937769250944257, 0.06182966474443674, 0.07302549933748585, 0.019869842899164984, 0.003115688616942082, 0.02338637438203607, 0.028026846536834325, 0.004547794449276158, 0.015659271872469356, 0.029416403134486506, 0.005136354028114251, 0.04363092467454927, 0.03621882186936481, 0.036152159196457694, 0.02593009190500847, 0.023480427817308476, 0.007272548507899046, 0.05783229281327554, 0.03291817648070199, 0.05776029346244676, 0.01559974908429597, 0.042795430935387097, 0.0479533996965204, 0.015251523216388055, 0.03692087491175958, 0.03959774984312909, 0.03943028400785156, 0.017018545452239256, 0.05023594060912728, 0.03592208832768457, 0.056889892489250214, 0.07735175040683576, 0.052388888118522506, 0.018033219933775917, 0.012935740873217583, 0.03515193072546806, 0.03349710934396301, 0.046390672480421405, 0.06650054374975817, 0.02939781466765063, 0.0450784162884312, 0.054499854666313956, 0.025835130929148624, 0.07208087002592427, 0.025390710847984468, 0.02088000681916518, 0.018493373545684984, 0.035942539373146634, 0.04853692284918257, 0.08977494628301688, 0.017248377137418305, 0.03872223610856703, 0.04768958528126989, 0.06550236445452486, 0.03975927849699344, 0.036858127385910065, 0.03388080054095813, 0.0786312028233494, 0.0726305783859321, 0.0419215456848698, 0.03886242483609489, 0.028429801343008876, 0.04342953208833933, 0.012778289366646536, 0.06208711450121232, 0.023974355509770767, 0.04258531578151243, 0.031021094348813807, 0.05175252065860799, 0.052621625629918914, 0.03154743057010429, 0.04592542476685984, 0.03705782702724848, 0.035615627986512015, 0.015700660812269365, 0.03405338931562645, 0.03193267221961703, 0.07175276441765682, 0.06396529943283115, 0.032083765004894564, 0.0682814878278545, 0.029931095694856982, 0.06729556966040816, 0.09144390494163547, 0.03006778657436371, 0.04145665420219302, 0.034461389029664655, 0.027227637457794378, 0.02054076305856662, 0.020777775340580514, 0.021215896920434067, 0.020366857925962125, 0.055177982563951185, 0.07889659143984318, 0.05140675278380513, 0.04041522169219596, 0.03152828570455313, 0.031578775495290756, 0.052925775559352975, 0.020218016180608953, 0.08038485622299568, 0.12715663468199118, 0.11431018901722771, 0.1396613565406629, 0.10955085618687527, 0.09708322983767305, 0.16543339219476494, 0.11961484008601733, 0.06711585287536893, 0.16767034573214395, 0.08940501577619996, 0.13371144581053937, 0.19520589389971324, 0.13374352694622108, 0.13805122008281095, 0.07295631590698447, 0.15990019696099417, 0.11937640288046428, 0.09871552724923406, 0.12720842047461442, 0.14884614226009163, 0.16058612801134586, 0.10440923672701631, 0.13252905782844338, 0.1765169088861772, 0.11223632815693106, 0.08576293156615325, 0.0898024473073227, 0.11798712957118239, 0.12118895990507943, 0.12954857918832982, 0.1388941098536764, 0.11378061279122319, 0.12947791655148777, 0.20231634378433228, 0.24496680232031004, 0.15224543985511574, 0.08183911283101354, 0.08670600024717194, 0.13440706634095737, 0.09805617441556283, 0.09462739447397844, 0.10360841612730708, 0.12103136336164814, 0.11784828773566655, 0.13435248498405727, 0.196776363200375, 0.14082367345690727, 0.10983174254319497, 0.1013972129938858, 0.09868563099631242, 0.11232884640672378, 0.1463586464524269, 0.1086037162957447, 0.12271193175443582, 0.12295586509363991, 0.13160080835223198, 0.08181078399398498, 0.22606487944722176, 0.16323435519422802, 0.14516500835972174, 0.12089469283819199, 0.1118039113602468, 0.07931599393486977, 0.07465907918023211, 0.15813527309468814, 0.1641613290246044, 0.0637431809944766, 0.09882812335022859, 0.10901282541453838, 0.13505494514746325, 0.09067248526428427, 0.17936755663582257, 0.09630752181900398, 0.13469745218753815, 0.13161843669201645, 0.19729964940675668, 0.14362306467124394, 0.11596692726016045, 0.10408669510590178, 0.08302004874816962, 0.07862508922283139, 0.047445048045899184, 0.10975008085370064, 0.12923485173710755, 0.11636076255568437, 0.14131850190460682, 0.12031455896794796, 0.11541226559451648, 0.11270328917141471, 0.16847147845796176, 0.12087056413292885, 0.1572559867054224, 0.17720741326255457, 0.11378238376762186, 0.11881328666848795, 0.05495548753866127, 0.09983956121972629, 0.1411200575530529, 0.08466698216008288, 0.10645535907575063, 0.15706610546580382, 0.13567672749715193, 0.11972974320607525, 0.09755166327314717, 0.09512306430510112, 0.1556367307369198, 0.2144270132162741, 0.12386678478547505, 0.11538420138614518, 0.11610233570848193, 0.12095038699252264, 0.10570285695471934, 0.15906428253012045, 0.23022660613059998, 0.10778434454862561, 0.20917474505092415, 0.12959875006760868, 0.159664921728628, 0.2076143180685384, 0.21038606576621532, 0.19145833142101765, 0.13266129073287758, 0.12277234851249627, 0.22691387603325502, 0.10937755834311247, 0.11530007661453315, 0.12200272695294448, 0.12267128750681877, 0.25698075337069376, 0.13795532951397554, 0.16060070294354642, 0.17442669533193111, 0.22765354705708368, 0.2741006804364068, 0.19379903296274797, 0.106911212471979, 0.13118250508393559, 0.1422459642801966, 0.12933880330196448, 0.2362595966884068, 0.057004737933831554, 0.1135253750586084, 0.15412528041218007, 0.14166171848773956, 0.24790594460708754, 0.1131734528711864, 0.17777742339032038, 0.11508266042385783, 0.08204827803586211, 0.16696169732936791, 0.11787112722439425, 0.12894290525998386, 0.16130169747131212, 0.11863139857138906, 0.16641292534768581, 0.14947542920708656, 0.131365139569555, 0.12625658512115479, 0.1293442180114133, 0.12088839603321892, 0.16868552911494458, 0.08069725374558143, 0.11545373765485627, 0.15938123980803148, 0.08887813333421946, 0.10923472672168698, 0.2104071003517934, 0.11506649771971361, 0.15563405730894633, 0.11701527743467263, 0.1453762770231281, 0.10835628850119454, 0.18587268543030533, 0.17420568290565694, 0.12448521517217159], [0.00513613604873951, 0.05828762373753956, 0.029783222558242933, 0.013196131231130233, 0.013769550997364734, 0.0047039902419783175, 0.006549669953528792, 0.014032204269564577, 0.05194040700527174, 0.026035017167617167, 0.045615453006965775, 0.05841700000954526, 0.007115061378239521, 0.06437780801206827, 0.025116638679589545, 0.03253651749608772, 0.02579024414132748, 0.03349426967490997, 0.016515686542594006, 0.010815022929039384, 0.06320802721061877, 0.045823440953556976, 0.020490183361939023, 0.024087631842121482, 0.01384246552229992, 0.018041153704481463, 0.04627931809851101, 0.01588913069904915, 0.056557647817369015, 0.07080141082406044, 0.0352277671918273, 0.043778495863080025, 0.08595988314066615, 0.041665490317557535, 0.01679966871493629, 0.03575783535572035, 0.03341166142906461, 0.08098269307187625, 0.04020166636577674, 0.019293345976620913, 0.01945793143074427, 0.007224144364174987, 0.02060098304147167, 0.031245994780744826, 0.014036013395525515, 0.05290410993620753, 0.051273074599781206, 0.022726728081969277, 0.014455230141590749, 0.03757759163688336, 0.04183422501331993, 0.008753339227821146, 0.03595517708786896, 0.022870957485533187, 0.02106504501508815, 0.029921111052057574, 0.03396220099447029, 0.05743443380509104, 0.04223448942814555, 0.08659152460417577, 0.005113065858105463, 0.040112092957964966, 0.03784976899623871, 0.022451505796717744, 0.07636384413178478, 0.03169183639277305, 0.08596847339400224, 0.016766817442008426, 0.09489130388413157, 0.027947186525645, 0.03248268931305834, 0.026417034079453776, 0.05656793101557663, 0.015012370156390327, 0.030812244662748914, 0.018771123373880982, 0.036941393810723505, 0.01804002733635051, 0.0287903222654547, 0.013318644121422299, 0.11127244202154023, 0.02688761507826192, 0.011388032181587602, 0.01469898536535246, 0.02014527722660984, 0.07640604222459452, 0.03983835157539163, 0.018044827971607447, 0.02016463074167924, 0.08644529352230684, 0.020527557070766176, 0.01792530911708517, 0.04361079932589616, 0.05624240044770496, 0.055239827638225894, 0.02377732590373073, 0.030530835834464858, 0.04525795665436557, 0.0674743704231722, 0.023231627685683112, 0.0280682269949466, 0.04607420714039888, 0.011502981950928057, 0.05339201732671686, 0.05995567994458335, 0.008729996775010867, 0.021222303987347653, 0.009526121064222284, 0.03567121696791478, 0.013864560318844659, 0.06669081175433737, 0.01596819529575961, 0.01269545465973871, 0.0387636199593544, 0.007054674730170518, 0.03081118954079492, 0.025407530034759214, 0.009104341152124107, 0.03058765296425138, 0.013607017263504011, 0.02650050406477281, 0.02208967869436102, 0.03306025153558169, 0.03882336836042149, 0.06945631692984275, 0.007945297319175941, 0.04810396661715848, 0.061243919389588494, 0.017436256698731865, 0.021620877153639282, 0.011454382728386139, 0.02007851786246257, 0.09390520929758038, 0.03914070222526789, 0.13324192671903543, 0.04882958857342601, 0.024212346578549062, 0.029224615211465528, 0.07061414194426366, 0.009111478492351515, 0.043389396741986275, 0.03190745446564896, 0.03651559612314616, 0.021936485843200768, 0.03738753058548484, 0.04683352853836758, 0.05904588662087917, 0.04113471308457, 0.09207610280386039, 0.03888986139957394, 0.017471937462687492, 0.05108293551685555, 0.015413258823433092, 0.01723500490853829, 0.05481793152700577, 0.0312770309724978, 0.007709535237933908, 0.05569237656891346, 0.0903059338618602, 0.08756293569292341, 0.039538812291409285, 0.03561086806335619, 0.03175832264657531, 0.03354243887588382, 0.05262917772467647, 0.04702773204605494, 0.09040263867271797, 0.03013460191765002, 0.019126573943399956, 0.06634598704321043, 0.021899561663823466, 0.03686282624091421, 0.03878860022606594, 0.030489323062023947, 0.007693403067865542, 0.035601986039962084, 0.030549386981874704, 0.05933903410498585, 0.00945578666869551, 0.03393107659316488, 0.04182921063953212, 0.059865183729146204, 0.025962083134800196, 0.060740459976451736, 0.0746943290744509, 0.049365593918732235, 0.0072400568585310665, 0.04252863435872963, 0.0052390452141740495, 0.05404189781152776, 0.020140030454578142, 0.01858775776677898, 0.023417570029518435, 0.03143860373113837, 0.06789104520742383, 0.03877530772505062, 0.021777374470340352, 0.03335684937025819, 0.02132710880999054, 0.01501891971565783, 0.08771031349897385, 0.02865431670631681, 0.035145820517625125, 0.011664993212824422, 0.07987113736037697, 0.06679807457008533, 0.019324273602770906, 0.016896912961133888, 0.09659027414662497, 0.04331906997997846, 0.04220317164435983, 0.05319572053849697, 0.027193032171843306, 0.018742898013442755, 0.013862599352640765, 0.04515154540006604, 0.035243288680378876, 0.0427110890325691, 0.022427090410409228, 0.05032978878755655, 0.03170540030779583, 0.03296233893239072, 0.02191866751361106, 0.02678061180215861, 0.021304640819185545, 0.026961821364238858, 0.008154034198793982, 0.030072237764086043, 0.051131678079920154, 0.0810658543237618, 0.0072924999819536295, 0.02196998511707144, 0.01687192082005952, 0.038248024947409115, 0.0446224746826504, 0.045998374066714726, 0.06339055991598538, 0.01276006646055196, 0.03962813124858907, 0.015505892424178975, 0.026474395733592764, 0.02413832688970225, 0.02923555319596614, 0.017098716061030115, 0.046423747669905424, 0.01341676028511886, 0.07430262437888555, 0.03179306363953011, 0.07065328662948948, 0.027688142211575593, 0.012141949048132768, 0.031445331405848265, 0.010882676263073725, 0.01406620565934905, 0.026139928859525492, 0.05502318837014692, 0.006068456310978425, 0.04549238371795841, 0.01655960132900093, 0.024015478124575954, 0.03827879651050482, 0.027610112380768572, 0.015999294252001812, 0.019031463689836006, 0.029766082763671875, 0.015362918310399567, 0.06411644310823508, 0.01463674334809184, 0.024906718604532734, 0.05017929311309542, 0.02714279174272503, 0.016212344069832137, 0.05528839717486075, 0.012871590476217014, 0.053230763479535065, 0.03751378898907985, 0.09016105985002858, 0.04472209719408836, 0.028525021858513355, 0.011220001465907055, 0.03659571075279798, 0.027623057132586837, 0.057442705146968365, 0.03427563328295946, 0.015420961892232299, 0.024489757139235735, 0.05074585289029138, 0.032685455932681046, 0.014710026826443416, 0.00955786632506975, 0.01412420513640557, 0.02803118746461613, 0.02271224814467132, 0.03435047569551638, 0.034428066174898825, 0.03717611603704946, 0.04758402219574366, 0.03104572177731565, 0.02525107343015926, 0.06377371507031576, 0.026988991602723087, 0.03772554959037474, 0.0808949652793152, 0.03077422295297895, 0.06753837663148131, 0.0877686675105776, 0.08019975865525858, 0.005681349114248795, 0.029944951379937784, 0.039056306039648395, 0.08905120726142611, 0.09535453295601265, 0.05534978763067296, 0.025290513278118203, 0.06370340527168342, 0.016409400817272917, 0.03189979041261332, 0.029074550406741242, 0.014531187047915799, 0.032321876513638666, 0.03175360682819571, 0.060724969021975994, 0.04176859710631626, 0.021817682843123163, 0.028346105744796138, 0.0529223998476352, 0.025220077950507402, 0.01754330238327384, 0.04414283863401838, 0.014509675791487098, 0.0070357296083654675, 0.09680108819156885, 0.04260348694931183, 0.050785794854164124, 0.08627198210784368, 0.030283614993095398, 0.04105626425838896, 0.029035351438713924, 0.02672234600010727, 0.01426764065399766, 0.05026466978181686, 0.02095328181582902, 0.037460344178336005, 0.023205066432378123, 0.019396054126056175, 0.02081626863218844, 0.01869142604326563, 0.019088750705122948, 0.017595356197229454, 0.025423304277605245, 0.036977953277528286, 0.02148415065104408, 0.07447246169405324, 0.12294476426073483, 0.07235572420592819, 0.11431621440819331, 0.07813030827258315, 0.15744974916534765, 0.09769079009337084, 0.16783996591610567, 0.12368656588452202, 0.13839238749018737, 0.07141664531081915, 0.07822116411158017, 0.0798720737387027, 0.16124434769153595, 0.18175673271928514, 0.16262638781751904, 0.10012873248862368, 0.07567994868648903, 0.10673159068184239, 0.11723152654511587, 0.12050385666745049, 0.10110485939575092, 0.06911272715244975, 0.11595917839024748, 0.18566771357187203, 0.10179661906191281, 0.11082617632512536, 0.1890827938914299, 0.2151679191738367, 0.11067096143960953, 0.22621771267482213, 0.162908156269363, 0.2208921898688589, 0.20179839086319717, 0.09475746963705335, 0.1385149173438549, 0.12319111318460532, 0.14662398078611918, 0.08802224283239671, 0.10649517551064491, 0.098520970903337, 0.13306390627154283, 0.11299759695040328, 0.11500199618084089, 0.1350096868617194, 0.17515005437391146, 0.12867165410092898, 0.13963021178330692, 0.12165130009608609, 0.1232467530561345, 0.09747126365878753, 0.09812915085681848, 0.11067261706505503, 0.21146847839866365, 0.1043720937200955, 0.11075867566147021, 0.15290982063327516, 0.15027346781321935, 0.14748128264078073, 0.21639215919588292, 0.13668836892715522, 0.16152258776128292, 0.11633036418684892, 0.09356653211372239, 0.1026635289724384, 0.05087447598842638, 0.1742832665996892, 0.07764341868460178, 0.20486713333853654, 0.12272269331983157, 0.12417205769036498, 0.12934083890702042, 0.150027743141566, 0.07814778733466353, 0.06271923093923501, 0.1439998144549983, 0.11829373240470886, 0.10350324319941656, 0.15872600568192347, 0.11399419525904314, 0.21784361345427378, 0.1357678954622575, 0.07523590858493533, 0.12354799546301365, 0.05721258678074394, 0.1405696842287268, 0.12318667556558337, 0.09515233630580561, 0.09112526489687817, 0.11788924410939217, 0.09871861458356891, 0.07196527480014733, 0.10904751212469169, 0.20992149998034748, 0.20873551576265267, 0.07345564304185764, 0.1687340715101787, 0.06188046666128295, 0.12436972851199762, 0.11377451954675571, 0.1540663835725614, 0.10853417324168341, 0.14607704084898743, 0.10431444538491112, 0.11581459614847388, 0.08156616533441202, 0.12161863542028836, 0.09882110729813576, 0.1240452259246792, 0.10287445158298526, 0.1179332538907017, 0.098190734695111, 0.08729650891785111, 0.07712642249784299, 0.13621498218604497, 0.11544191757483141, 0.0930140417601381, 0.08193107468209096, 0.12617260962724686, 0.08287665394267865, 0.07337162005049841, 0.11017377847539526, 0.14209583162197045, 0.18916929353560719, 0.12866482803864138, 0.09148285285170589, 0.10897540420825992, 0.09816459752619267, 0.13170083798468113, 0.21736227428274496, 0.1259990403694766, 0.13129560330084392, 0.14818607696465083, 0.1574826988258532, 0.19179529191127845, 0.21564577067536966, 0.20894290320575237, 0.12512862921825477, 0.1598249338567257, 0.11605110631457397, 0.11431959351258618, 0.11289168441934244, 0.1160732808389834, 0.16692516500396387, 0.1345133792076792, 0.16079587675631046, 0.13031152396329812, 0.1404417532363108, 0.1516469448272671, 0.1340089834162167, 0.06430422088929585, 0.19099232714091027, 0.1087056729676468, 0.115271035315735, 0.16736815337623867, 0.2742699070700577, 0.09104462100991181, 0.15760569008333342, 0.17183363304606505, 0.15387416817247868, 0.10873327577220541, 0.11430386507085391, 0.12999489238219603, 0.08461274685604231, 0.14763132030410425, 0.10542055924556085, 0.15162538098437445, 0.1563629260552781, 0.08217555084930998, 0.09970148612878152, 0.1041314173489809, 0.15643082026924404, 0.13445236533880234, 0.1054489966481924, 0.07835743429937533, 0.13562878221273422], [0.02008202758484653, 0.007711855827697686, 0.0278823983057269, 0.03859444760850497, 0.030376360552119355, 0.051493988638477664, 0.0693465978173273, 0.0560036680794188, 0.005789155182096043, 0.0373461840541235, 0.029310097053114856, 0.03784603705363614, 0.0363230957383556, 0.019925642226423537, 0.03131994152707713, 0.019225551846570203, 0.048543528387589116, 0.07247573669467654, 0.04223410266318491, 0.05397803070289748, 0.03969224262982607, 0.051425314109240255, 0.006554133441698338, 0.02231292350084654, 0.012132174751189138, 0.022968712329332317, 0.004724628732739282, 0.033522187998252254, 0.09680040287120001, 0.034207579613264115, 0.02560210334403174, 0.04503267624282411, 0.036452621288065395, 0.03382288757711649, 0.025009915299181427, 0.07158604157822472, 0.03159545388604913, 0.0845273600092956, 0.0510003747684615, 0.025835434573569467, 0.04442769442019718, 0.01618028668287609, 0.005939197934432221, 0.11018223302172762, 0.003851353739654379, 0.01665459114259907, 0.022104141668283513, 0.006837831901585949, 0.019982742644580345, 0.016304005669163804, 0.011199771792494824, 0.08113019301423005, 0.038458241881536584, 0.02801829529926181, 0.037137660064867566, 0.0354312394878694, 0.03011552829827581, 0.0538381541014782, 0.060334058212382455, 0.0244512672403029, 0.096266952210239, 0.02113205034817968, 0.033111039881727526, 0.04532670921513012, 0.03033339910741363, 0.03862554147573454, 0.022024025342294147, 0.05910121436629977, 0.0059052537960399476, 0.030729463390473808, 0.05900000408291817, 0.024014407735584036, 0.02110773165311132, 0.046294178015419414, 0.050579974826957495, 0.05806827372206109, 0.014454188590337123, 0.02538955394577767, 0.013984348042868078, 0.021028302343828336, 0.04227566971842732, 0.018126630457118154, 0.06140052527189255, 0.0472543186375073, 0.030251316726207733, 0.04150032810866833, 0.04083884467503854, 0.053575435520282814, 0.04542684741318226, 0.018100859697109888, 0.047065774111875465, 0.04892663943714329, 0.02694305308562304, 0.024614948546513915, 0.03321771915735943, 0.03302199573123029, 0.03587339665474636, 0.04477818489872983, 0.03136860605861459, 0.09239344006138188, 0.01880263793282211, 0.060139813992593966, 0.023435513888086592, 0.03818823583424091, 0.015006112367180842, 0.040074732819838185, 0.05012238098840628, 0.022403239904503738, 0.025652230118534396, 0.023164586729503105, 0.06339643602924687, 0.05688857273863895, 0.03075540378423674, 0.026838097288938503, 0.018836663071332232, 0.04171359505770462, 0.03994994005188346, 0.03709946532866784, 0.042005185303943496, 0.01586299861914345, 0.030836159629481177, 0.03039208220850144, 0.050647774046020846, 0.06878204311111144, 0.07976425452423946, 0.014790063424568092, 0.03877802186512521, 0.020300795756546513, 0.02450609626248479, 0.0068963377354001355, 0.02858719602227211, 0.02995524475617068, 0.010853786786485995, 0.029123472781585794, 0.04968778609431215, 0.06306364174400057, 0.04988963669165969, 0.017364737411428775, 0.024030940241313407, 0.04508722706564835, 0.035918220678078275, 0.04410554974206856, 0.037485168381993256, 0.0384964366177363, 0.0075624924585489285, 0.043190928641706705, 0.011321488252308751, 0.027993420205478157, 0.04682623089424201, 0.007485120806709996, 0.002448322284700615, 0.013377383201649147, 0.05248816796977605, 0.03536987956613302, 0.05952105790908847, 0.051062352157064846, 0.037772331187235456, 0.015890046721324325, 0.04201042698696256, 0.058140646267150126, 0.05389064896319594, 0.022887179561491524, 0.029012036975473166, 0.02595449541695416, 0.0261974330060184, 0.008184189143191491, 0.0606407221140606, 0.020292410760053566, 0.035423483832606247, 0.06381708024335758, 0.06113198146756206, 0.0371456226733114, 0.0500648378261498, 0.0483218883164227, 0.0138417479715177, 0.07112847827374935, 0.048316117376089096, 0.018879700851227556, 0.03567695737417255, 0.059777951267148764, 0.07635173906705209, 0.054798311686941555, 0.06862787316952433, 0.008727689755947461, 0.03163280723882573, 0.04604688932054809, 0.01829682569950819, 0.046680210158228874, 0.05553425755351782, 0.03226049623585173, 0.061835622281900475, 0.0015473506583865465, 0.07079845919672932, 0.0050357556985025954, 0.052223529134477885, 0.08278434603874173, 0.0547366396390966, 0.05923817665981395, 0.024360911820882132, 0.029261178070945398, 0.036595490228916915, 0.026977576947371875, 0.015504986579929079, 0.0420106034060674, 0.0030460724083241075, 0.05635916953906417, 0.04885397172932114, 0.08257652433323008, 0.0393137456183987, 0.052509270408856015, 0.023709596234506795, 0.02987938454108579, 0.03797252955181258, 0.06239047393734966, 0.027352828865072558, 0.019243271788582206, 0.07459976843425206, 0.03639478296307581, 0.0467596157187862, 0.02871556466977511, 0.04230267201949443, 0.060621967406145165, 0.03574797624189939, 0.034807720088532994, 0.019393399357795715, 0.028194755116211515, 0.06965252211583511, 0.07120522736970868, 0.05627384715314422, 0.040821653990341086, 0.011095359671993979, 0.0585065394906061, 0.022402904029669504, 0.04544485912525228, 0.028067514533177018, 0.050448814007852755, 0.05135511626888599, 0.053471100583140335, 0.015909351042604873, 0.018413845848824297, 0.02007331349886954, 0.04861113761684724, 0.06523536092468671, 0.015124194423801132, 0.007265436612734837, 0.016247015512947525, 0.04433147476187774, 0.004133550092644457, 0.04723907195563827, 0.026731126243248582, 0.034369233796106916, 0.08081326287771974, 0.06665019464812108, 0.027288021985441446, 0.05414857030180948, 0.057021837016301494, 0.027700942774702395, 0.03206658449822238, 0.023655678145587444, 0.02720532383370612, 0.028809613016034876, 0.033392526741538725, 0.01186658935953996, 0.03722373562465821, 0.044753303019596, 0.030439701796110188, 0.020956085861793587, 0.06794233566948346, 0.01872651987443013, 0.04936167198632445, 0.021636866831353734, 0.05937077597315822, 0.058137389299060614, 0.052203776980085034, 0.031851750133293014, 0.049735666917903085, 0.029738296754658222, 0.04396552047027009, 0.01110341473083411, 0.06405470999223845, 0.03054264573646443, 0.060798508647297106, 0.012970280002004333, 0.03772905422374606, 0.05492133008582251, 0.0682677746351276, 0.07477056248379604, 0.031743601829345734, 0.10774701833724976, 0.011773991381882556, 0.046236634853162935, 0.1234557961246797, 0.06633941882422992, 0.060840299619095664, 0.036196701627756865, 0.014338476317269462, 0.0331758128346077, 0.03657412316117968, 0.03765017792050328, 0.03202810138463974, 0.02028705711875643, 0.05482799080865724, 0.04271529594968472, 0.04449290502816439, 0.03769698665876474, 0.006675433026560183, 0.038154807806547196, 0.013006737688556314, 0.0271522471282099, 0.036236083800239224, 0.05743936675467661, 0.023815770001549805, 0.03161892101966909, 0.012024805066175759, 0.06190234263028417, 0.05485164453940732, 0.0163445973303169, 0.023154946443225657, 0.08216978330165148, 0.028571932377027612, 0.016086837143770287, 0.044947197793849876, 0.01335823324708534, 0.02335573682960655, 0.04259437761668648, 0.02704427863604256, 0.03412793317277517, 0.01793271871948881, 0.0440304766276053, 0.018576332933402488, 0.019033451797440648, 0.06074864989412682, 0.005698917658134762, 0.009191468441193658, 0.024475173725347434, 0.03420064498537353, 0.04208268078842333, 0.018791133371580924, 0.007586032534683389, 0.018358733538272123, 0.030827155469783714, 0.0031513475405517966, 0.028043704739372646, 0.05926486344209739, 0.031025969622922794, 0.005550554704054126, 0.024500808778351972, 0.05527172896212765, 0.014707165105002267, 0.06817216905100004, 0.03951868015740599, 0.012447069282643497, 0.1022056264004537, 0.09478523529001645, 0.09059833495744637, 0.15340266775872025, 0.23798956243055208, 0.15030313336423465, 0.2165391705930233, 0.09850244011197772, 0.1724641142146928, 0.11005029867270164, 0.13902772696954863, 0.12187134900263377, 0.1113388773852161, 0.06409890297800303, 0.12236387043126992, 0.0700693190363901, 0.1088824381253549, 0.18866743546511444, 0.08829903083720378, 0.14210210128554276, 0.12756416281419142, 0.1007762923836708, 0.1600927109164851, 0.11646242067217827, 0.07124300819954701, 0.20724382437765598, 0.08816995990595647, 0.1498597650123494, 0.1320972517132759, 0.1968445831111499, 0.10142582003027201, 0.2115213634180171, 0.13693862621273312, 0.10793271301580326, 0.10081724197204624, 0.18620994447597436, 0.08387213266853775, 0.15150415391794272, 0.22775150037237576, 0.08841790338712079, 0.1386174304144723, 0.13758494438869612, 0.07704737316817045, 0.12690803302185877, 0.1749063924487148, 0.14765992734049047, 0.12594422831067018, 0.08473421140973057, 0.11529297913823809, 0.09299361785607678, 0.1477474719285965, 0.1853710173496178, 0.10919651841478688, 0.09288629397217717, 0.10329090245068073, 0.13966066443494388, 0.19293950551322528, 0.10532126243093184, 0.09467801318636962, 0.14853816878582748, 0.18028272395687445, 0.15178498599146092, 0.11564053834549018, 0.08132196736655065, 0.1475107582019908, 0.21240808655108723, 0.1415627880820206, 0.16767778247594833, 0.1118004440463015, 0.08515341034425156, 0.1468722296080419, 0.07304210308939219, 0.13218193288360322, 0.15722986310720444, 0.13917746607746395, 0.12434467699910913, 0.14292519140456403, 0.10607900962765728, 0.14272932548608097, 0.09258254098572902, 0.10980302694120578, 0.09012059202151639, 0.12240365972476346, 0.1040767952799797, 0.21961520053446293, 0.11329782834010464, 0.15593707747757435, 0.10420563550932066, 0.15536366110401495, 0.09537682283137526, 0.1605890185705253, 0.15270680295569555, 0.17916462038244518, 0.12909428642264434, 0.12297285561050687, 0.1590947623231581, 0.1052684656211308, 0.07838914224079677, 0.12673016185207026, 0.13692899101546832, 0.12976215487079962, 0.1704626258994852, 0.07997732130544526, 0.21692388637789659, 0.09453885243939501, 0.10900118853896856, 0.07745552555258785, 0.14622071385383606, 0.14626663710389817, 0.13408709636756352, 0.29020570910402704, 0.1511832204248224, 0.22379774467221328, 0.09547973623765366, 0.10852123357887779, 0.22969965583511762, 0.196664513487901, 0.11664960134242262, 0.11456280760467052, 0.10420550658766713, 0.12236209266952106, 0.07472537205155406, 0.18424872042877333, 0.19963485481483595, 0.17729643705700124, 0.10287897062620946, 0.12621404097548553, 0.12950861347573145, 0.15640769579580852, 0.08017224406025239, 0.1752485233758177, 0.13718425588948385, 0.09143261411892516, 0.14017286337912083, 0.1895562620567424, 0.08214878264282431, 0.12198230304888316, 0.19237826205790043, 0.12509890938443796, 0.1531652347849948, 0.19157395378819533, 0.10468639792608363, 0.1434516938669341, 0.11923950165510178, 0.08071570989808866, 0.13574064549590859, 0.15772112246070588, 0.07640800319079842, 0.1486723151590143, 0.06929745152592659, 0.09078441640096051, 0.11629669527922358, 0.14172628788011415, 0.08200036667819534, 0.17578144477946417, 0.14152932273490088, 0.1747636015393904, 0.047465668725115914, 0.09123641571828298, 0.11937571077474526, 0.1571944842913321, 0.09808478145194904, 0.12428378526653562, 0.1513161047228745, 0.10538093958582197, 0.1103061470868332, 0.18768369539507798, 0.12894905278725283, 0.1227864891822849, 0.09709901256220681, 0.11206355957048279, 0.10002881820712771, 0.16190131886729173, 0.19958690953041824, 0.1523205265402794, 0.08912342374346086], [0.0184293571593506, 0.04531568302107709, 0.032496548390814235, 0.020922795237441148, 0.05486562914614167, 0.034872689816568575, 0.045185601072652, 0.010725721783403839, 0.05033103050664067, 0.028188953641802073, 0.05638176475518516, 0.03440664821703519, 0.09869155460702521, 0.021339035759280835, 0.030708228637065207, 0.0665193052430238, 0.013399857977804328, 0.07104347819196326, 0.062260113789566925, 0.05730394473565476, 0.021700603321992924, 0.02998946327716112, 0.07339920928435666, 0.029622908482061963, 0.05922418526772942, 0.051719587961477895, 0.003252442472980225, 0.07968992779829673, 0.02494099140832467, 0.02712128557530897, 0.02682722546160221, 0.05111346620001963, 0.005411769695846098, 0.026139939037550772, 0.04752421611919999, 0.04842182295396924, 0.04691522754728794, 0.0843067139919315, 0.023600972956046462, 0.05188257885830743, 0.022005888101245676, 0.05553930924673166, 0.06447084873382534, 0.04712086097736444, 0.015213338658213615, 0.05842503386416605, 0.023273727390915155, 0.015437602963564652, 0.018106181107993637, 0.02347113867290318, 0.02545645410594131, 0.027087737107649446, 0.011071333595152413, 0.0650729060705219, 0.02111551784245031, 0.07309983963412897, 0.030945088248699903, 0.029784576235605136, 0.046088697255722115, 0.019638253808287636, 0.032579611255122085, 0.028262031863310506, 0.04356879122289164, 0.02929821590493832, 0.03763472767812865, 0.04989910904052002, 0.010938326312628175, 0.015016181826857584, 0.04125861018630011, 0.02033411691497479, 0.07844240045441048, 0.003947080187832138, 0.02016494795680046, 0.07175391114183835, 0.026444816695792333, 0.06139492057263851, 0.027381149220413396, 0.027663100876712372, 0.056734324765524695, 0.06516780597823006, 0.0731685073780162, 0.05842673020171268, 0.043498345717255554, 0.07966809254139662, 0.043864381433065446, 0.009482718571754438, 0.04723575391939708, 0.047803412923323255, 0.012389293722143131, 0.04140376239748938, 0.03402624452220542, 0.004887895284420145, 0.01926953618281654, 0.05580993615356939, 0.04527020421145218, 0.061472076789609024, 0.056656971773398776, 0.027421360901956047, 0.007221745742884065, 0.051460825239441225, 0.029562512080052068, 0.01897426658043904, 0.009155140524463994, 0.03700388688594103, 0.08112452724682433, 0.039828896189906766, 0.0170579344100718, 0.029009651924882616, 0.039294678784374676, 0.026456770786483372, 0.056660354270466735, 0.015422247716092637, 0.024273511421467577, 0.04331114129828555, 0.05050874900604997, 0.037660423799284866, 0.04761015257931181, 0.015880174036802988, 0.05809249742222684, 0.03192536439746618, 0.08224158587732486, 0.05663512633847339, 0.039261793584695885, 0.0410433924490852, 0.015784280075292503, 0.033020285822983296, 0.008991621218488684, 0.02439157821104995, 0.022275181686771766, 0.03013304467978222, 0.04216845100745559, 0.02560302784799465, 0.017423378104077916, 0.023291243772421564, 0.06368040971990142, 0.019229271914809942, 0.032002646143415144, 0.04375861817970872, 0.04159495999504413, 0.010030359944461711, 0.04631836100348404, 0.013228248838069183, 0.031098657686795508, 0.040836914242910485, 0.016251909446769526, 0.023219517531937788, 0.02115621298019375, 0.047219567466527224, 0.05084455937945417, 0.0729362719825336, 0.06222150514700583, 0.01993133343889245, 0.01603631003360663, 0.027741541221205677, 0.033247170969843864, 0.03960540032546435, 0.03463497864348548, 0.013802676228806376, 0.03033401318160551, 0.011748771931576942, 0.042829988723886867, 0.011142822348379662, 0.026210698365632976, 0.04741256996723158, 0.02380604829107012, 0.02252851612865925, 0.04031995198290263, 0.009233669078509723, 0.05469608360103198, 0.045701579456882815, 0.0395594397559762, 0.03099526252065386, 0.022205816748152887, 0.022843512440366403, 0.013201295730790921, 0.02905967691913247, 0.052439211668180566, 0.06714133186531918, 0.04357498964028699, 0.04212830548307725, 0.05430850100570491, 0.02285683717179511, 0.022536273480259945, 0.02813024679198861, 0.011493611382320523, 0.06074805278331041, 0.06838363448956183, 0.009863171460373061, 0.09727826115808316, 0.01912452307130609, 0.08277705857264143, 0.036449276110423465, 0.07457310200801917, 0.07569039812577621, 0.016612959626529897, 0.022528122578348433, 0.04843224185918059, 0.05820882546582392, 0.059521193616092205, 0.03364490444904991, 0.016885968191283088, 0.07330007531813212, 0.019237879131521498, 0.022162030883399502, 0.026132592199636356, 0.06371929656182017, 0.10498434265277215, 0.014854249444657137, 0.08644904582095997, 0.018222390407962457, 0.020841988502070308, 0.051508828199335506, 0.0483260545214372, 0.03081996299858604, 0.03400296737839069, 0.04907101133306112, 0.005549849027634731, 0.017370532100488032, 0.009563690700036074, 0.04721895678501044, 0.035528673723872216, 0.06182755450052874, 0.046121847084058185, 0.02716540392222149, 0.04402493978185313, 0.043782987764903476, 0.08003319866423096, 0.03836349803688271, 0.002756708181030782, 0.02781162710328187, 0.012531067677108305, 0.016166354662605693, 0.041274979843625, 0.0264397141124521, 0.015234985621646047, 0.13487647686685833, 0.041891367839915414, 0.042766338746462546, 0.04158280064750995, 0.07509530934372119, 0.016365089087880084, 0.00549088221409225, 0.03738262816997511, 0.021199466194957495, 0.05084767046251467, 0.045110965613275766, 0.022396181443972246, 0.06241925060749054, 0.0657881973311305, 0.044302124729646106, 0.05255178402044943, 0.03588858226846371, 0.038820793320025714, 0.031247100792825222, 0.07160613978547709, 0.028502189155135835, 0.17751389395977768, 0.006317486720425742, 0.040125446527131965, 0.05225150852597185, 0.04482555342838168, 0.07686507116471018, 0.009702429907130343, 0.11318329841430698, 0.025331691872062426, 0.005944233936523753, 0.0632465137168765, 0.03286635336865272, 0.02832863516440349, 0.08358462381043605, 0.005304285932132708, 0.04278519184195569, 0.09246231815112488, 0.020611999057499424, 0.04340332028056894, 0.04282912698441318, 0.0348931612180812, 0.06255733248378549, 0.033838914574256966, 0.035468284107212505, 0.10152177166725908, 0.0330081366534744, 0.04855683445930481, 0.039106588877205334, 0.04748257103243044, 0.05209315202331968, 0.027061465928064923, 0.04566100984811783, 0.018363272937546884, 0.030307336577347348, 0.013161039944472057, 0.03125495822834117, 0.06208792195788451, 0.04400089250079223, 0.024232882440888455, 0.04215220009375896, 0.06219698289143188, 0.016219911431627612, 0.019644230005464385, 0.013960629003122449, 0.0364388639905623, 0.036617233883589506, 0.006358078381578837, 0.00967129532779966, 0.03148429288661905, 0.043296681717038155, 0.018413286057433913, 0.025999799503811767, 0.035355609974690845, 0.029357262022261108, 0.06627991130309445, 0.012133944031250263, 0.11289006272064787, 0.01535139508944537, 0.06854771782777139, 0.05281262645231826, 0.03798652094389711, 0.016680227891941155, 0.030211103348327533, 0.026942464456494366, 0.03348979812913707, 0.029794452312801565, 0.013513063063978084, 0.06741164664604835, 0.06557027902454138, 0.04197981148692114, 0.05768837553582021, 0.04532706544601491, 0.007923492596351674, 0.054332195448556116, 0.07473477654691253, 0.02562859674383487, 0.09084901293473584, 0.0448164067763303, 0.058062987934265814, 0.028259283796484982, 0.027819581230037978, 0.047902451894645176, 0.02481725036964885, 0.015046485200790423, 0.023203951938609992, 0.020795756518574696, 0.019685948034748435, 0.015080537480701293, 0.05265774065628648, 0.001314648239973134, 0.03390872225697551, 0.020218285898278867, 0.014979101584425994, 0.028704287417765175, 0.0505235444621316, 0.03609566776348012, 0.21261950449219771, 0.26806098595261574, 0.0872276376134583, 0.10312341965202775, 0.12769165954419545, 0.1347325731601034, 0.08982485931898866, 0.10039032130901303, 0.09191980226231472, 0.11837377239550863, 0.1468817155276026, 0.12995483167469501, 0.16432657944304602, 0.12954043676810606, 0.18114754397954258, 0.16026832935001167, 0.10322568166468825, 0.3330247157386371, 0.14063276084406034, 0.14973152189382485, 0.15835119650832244, 0.09220192355236836, 0.16037639283708163, 0.08524022889988762, 0.13918801051165375, 0.15811472705432347, 0.13904619669275625, 0.14957710089428083, 0.15284093575818197, 0.08014410521302905, 0.1412760798952409, 0.1300979754222291, 0.1782142235232251, 0.14558112674525805, 0.14935289935341903, 0.20285596911396298, 0.12866433949342795, 0.18744319544306823, 0.09282544295170478, 0.18868510451700005, 0.07245590311608144, 0.17459816113114357, 0.11368348728865385, 0.16071219981781074, 0.08276602559323822, 0.16794014482625894, 0.15550645201333932, 0.10684530636561768, 0.1337684698935066, 0.10284299469952073, 0.1126965173919286, 0.14870814180799893, 0.15347029055867875, 0.16434620267578534, 0.1433667548532997, 0.13922792194145067, 0.09389775898307562, 0.12926512796963963, 0.0654370826003807, 0.1744244968784707, 0.07835664041340351, 0.09631915190922362, 0.1404153039412839, 0.10313487332314253, 0.08498126601002046, 0.15491878640438828, 0.1480750414941992, 0.10516221382256065, 0.09179033778075661, 0.08948217199317046, 0.17279963621071406, 0.22240559437445231, 0.1759239099919796, 0.14507527888885566, 0.14918610187513487, 0.1205773555806705, 0.09735683551324265, 0.17092697455414704, 0.12868591690702097, 0.1309521695865052, 0.2125068133963006, 0.1401139801102025, 0.13712306560150214, 0.17955586367419787, 0.17924632956939085, 0.1958942405347313, 0.12037820555269718, 0.271247142127582, 0.09975624390478645, 0.12432038544544152, 0.1438990927168301, 0.1022201334791524, 0.1158543447298663, 0.16524121750678333, 0.14130601686026367, 0.183888418333871, 0.2260429627661194, 0.08829604528312172, 0.1318759135901928, 0.15494782770318644, 0.13435552482094082, 0.2048503735235759, 0.09579026100358792, 0.1316166046474661, 0.18659825649644646, 0.12308849154838494, 0.12591069511004857, 0.12049492714660508, 0.1463262124785355, 0.19056679068931512, 0.10377918303545032, 0.11717666020350796, 0.09795581230095454, 0.11713942220168454, 0.15844229661992618, 0.09008986795587198, 0.19265244448823587, 0.13472688703664712, 0.10523195365177733, 0.14807794562407903, 0.2101150724504675, 0.09752275768135275, 0.17225148848124913, 0.09357231323208128, 0.10717765281775168, 0.137806092521974, 0.11089265918625252, 0.09184293103005205, 0.10521823367370026, 0.15560489387384482, 0.08531874897224562, 0.1263283605554274, 0.11193019351256744, 0.06153978779911995, 0.1580311722521271, 0.10369294801993029, 0.20493714458176068, 0.14979542632188114, 0.1871329149497407, 0.11291751624750239, 0.21194734770272458, 0.08071797620505095, 0.06737043921436582, 0.07124598696827888, 0.10005185447101082, 0.08576443112854447, 0.09463255134012018, 0.1341509193714176, 0.10790682690484182, 0.12598872663719313, 0.2328589420233454, 0.1211748735180923, 0.1041101859882474, 0.11522892543247767, 0.12010585516691208, 0.08001310724232878, 0.22403189353644848, 0.1381096826600177, 0.0828899871557951, 0.07709091476031713, 0.1630428997533662, 0.11007790147726025, 0.1096571758389473, 0.1163434192006077, 0.15061063186398574, 0.1371800082602671, 0.12969067799193518, 0.07676065819604055, 0.1252063757606915, 0.11536991143865244, 0.11805548518896103, 0.1279213029359068, 0.11099053107734237, 0.060412666494292874, 0.10423248514000859, 0.1521611250936985], [0.038448538830769916, 0.014056450022118432, 0.01539229039501931, 0.017813705373555422, 0.006981386586890689, 0.04721898053373609, 0.05272784010906305, 0.045189852094543834, 0.02288584115116724, 0.018471701137189354, 0.03459507060636367, 0.03210226526217801, 0.04570659722334572, 0.03864323088367071, 0.049297642029289684, 0.03613836797220366, 0.043245011275368075, 0.04560416218425546, 0.03213118103199771, 0.024083092442846725, 0.03560551442205906, 0.031758980825543404, 0.030226027726062706, 0.05511802720970341, 0.029295634079192365, 0.0202626485177981, 0.04333831323310733, 0.02553863317838737, 0.02602003511440541, 0.05003370663949421, 0.023869623629642383, 0.04723899392411113, 0.027831314796847955, 0.02508035401946732, 0.03915631192337189, 0.0837290771305561, 0.09204001831156866, 0.007034922151693276, 0.0018107048360564346, 0.015260498538347227, 0.015489476965740323, 0.0537210796693606, 0.07125381726239409, 0.06006074430687087, 0.016052842539336, 0.039133343512990644, 0.103559656600867, 0.029235736400421177, 0.01128427145470466, 0.03568922867998481, 0.03932649189872401, 0.017646717905466045, 0.05896389923457589, 0.04081619517611606, 0.035205182153731585, 0.061950389694954665, 0.059840926102229526, 0.014415213538865958, 0.016816036675923636, 0.06865470244416169, 0.024638407198446136, 0.016224403333451067, 0.04081469561372485, 0.04982169498024242, 0.05794981507850545, 0.05296965981168406, 0.05251632038769977, 0.03400495209332023, 0.05526462130780731, 0.04601346129285438, 0.06664367392659187, 0.029685781536889926, 0.0864202623654689, 0.01619505669389452, 0.02880997263959476, 0.07363246248236724, 0.013507843433347131, 0.06628604525966303, 0.025564290283780013, 0.022139344065050994, 0.022762946584927182, 0.07422852835484914, 0.11375923215278558, 0.04144956011857305, 0.03539576228441937, 0.016030167595350316, 0.011225874186493456, 0.020486536236213784, 0.028371969803369472, 0.0378852156656129, 0.0442412296043975, 0.034376232884824276, 0.05718687030353716, 0.06803183443844318, 0.021589103055053523, 0.05088656748245869, 0.053584039344319274, 0.03982057395790305, 0.01046040017224316, 0.048577292290117056, 0.135084882112486, 0.026603305512773137, 0.024941744582195367, 0.01428191363811493, 0.02104501466133765, 0.0535981359093317, 0.016191675893164108, 0.07386453502944537, 0.024910447154460207, 0.029275115180228437, 0.020410648879728148, 0.05224469942705972, 0.05680398317053914, 0.014413030352443457, 0.006931370074328567, 0.016330792535362498, 0.008938774366730025, 0.03093360743618437, 0.04462710568415267, 0.059363915984119685, 0.034148896512176306, 0.03850756798471723, 0.013174484267697802, 0.010595892589273197, 0.04229026161400335, 0.057096428370901516, 0.046113049877541404, 0.06123017905546086, 0.015269263514450617, 0.006043110907609973, 0.044177433741944175, 0.03149043023586273, 0.026825844642839262, 0.0293957722772445, 0.05162122073982443, 0.027007171252210225, 0.02254071958096964, 0.04045901434229953, 0.023134760026420866, 0.003429251523422343, 0.03212953558457749, 0.04417086552296366, 0.05882483348250389, 0.021920065295749476, 0.034079920034855604, 0.044366534666291306, 0.0494359953195921, 0.015129812693755542, 0.033318539283105304, 0.016779304182689105, 0.08248756839228527, 0.06921334032501493, 0.05174823570996523, 0.01951864844055048, 0.006188839873565095, 0.039595927976604016, 0.028281643221686994, 0.016377341733979325, 0.052688020281493664, 0.05146253854036331, 0.036795905724700005, 0.014004968722084803, 0.06382453734321253, 0.02221148760457124, 0.05766331723758152, 0.017461739081357206, 0.010857503462050642, 0.06028706966234105, 0.05492391869691866, 0.03152550710365176, 0.06498483222510133, 0.04691867111250758, 0.047694406272577386, 0.03335019972707544, 0.027368050101878386, 0.009347913171430784, 0.09483842565012829, 0.01176430020547871, 0.03793231617393238, 0.036086456650601964, 0.022101802418806722, 0.02778159683969404, 0.032438774526651414, 0.05846997323845114, 0.01216410321649164, 0.023346666512744765, 0.023199565209714428, 0.030538147049290792, 0.032724967026816945, 0.021506252232939005, 0.05538957353149142, 0.018688491379309977, 0.03338483215442725, 0.04199973327506866, 0.016245773793863397, 0.016968316897483807, 0.018111037722389613, 0.0323797453727041, 0.009245199084814106, 0.01852388896181115, 0.05876412495438542, 0.02933901621560965, 0.026810706526573216, 0.03238375212198921, 0.06615607866219111, 0.03682936428646956, 0.016589389016319598, 0.04630565882793494, 0.027268373307638934, 0.021747062614719783, 0.031756358287696324, 0.08397128699081284, 0.07841102499514818, 0.046893606028918705, 0.0035964149865321815, 0.05303573215912495, 0.029292431393904344, 0.04979296920022794, 0.02359039968411837, 0.024221683220405663, 0.014716274437627621, 0.07461160208497729, 0.028267663703965287, 0.021919527556747198, 0.015879980654322674, 0.03625062819836395, 0.012960090102361781, 0.012538954798531319, 0.05392438911699823, 0.04193994076922536, 0.04279552593028971, 0.030986197292804718, 0.06478255415069205, 0.018377157460365976, 0.012382577921796058, 0.09626619225101811, 0.04347380989098123, 0.015492889996884125, 0.008895544900691934, 0.05351513072050043, 0.021677019141082252, 0.04642002251265304, 0.030655343617711748, 0.044197450524994304, 0.04199372484747853, 0.04791378342945661, 0.07699910218694381, 0.048700331045048575, 0.02399495244026184, 0.04156981687992811, 0.039226360486022065, 0.03443116368725896, 0.01926252182706126, 0.056440556421875954, 0.01937726209871471, 0.020552595012954304, 0.047146363716040335, 0.04560917655804327, 0.04888519451820424, 0.017938881513795683, 0.07984936995697872, 0.04542266424479229, 0.05879961233586073, 0.05983132483171565, 0.042854751859392436, 0.023605459768857275, 0.04133579693734646, 0.03488801113728966, 0.03909615979396871, 0.009169673048225897, 0.06920390190290553, 0.03189891170976417, 0.029708695664469684, 0.04731108148449233, 0.03807992807456425, 0.09769194360290255, 0.08408956921526364, 0.023591166428689445, 0.05284788313188723, 0.021582097180985978, 0.007491737371310592, 0.07284901237913541, 0.06526938267052174, 0.027238366792776754, 0.018834498544622744, 0.03531710650505764, 0.02893303514325193, 0.07170924318156072, 0.022405077038066726, 0.010741964215412736, 0.0984058031546218, 0.0400523309861975, 0.01304183915323977, 0.016809521043407064, 0.07028260973415204, 0.018276584999901906, 0.024140243751129935, 0.06316869932093791, 0.014477492875552602, 0.02475509656194065, 0.043137460082237206, 0.014793043889637505, 0.04197171995682376, 0.016275269711124044, 0.03177215797560556, 0.036792540191007514, 0.03980219244424786, 0.029212367654378926, 0.016053724634860243, 0.044333605361836295, 0.024229820551616803, 0.023803790465795567, 0.04703408991917968, 0.04794488747471145, 0.0896516903968794, 0.014184276689775288, 0.02794062509201467, 0.02096406034460025, 0.019970120196895938, 0.0168300619947591, 0.020000594900920987, 0.011722242908685334, 0.07333908429635422, 0.11906651593744755, 0.024746075438867723, 0.03221022696899516, 0.058401020509856086, 0.04372706290866647, 0.10017481858709029, 0.018185176154864684, 0.05934148361640317, 0.04283921680014048, 0.04362798661791852, 0.020986402806426798, 0.03583722395290222, 0.06649502047470637, 0.00906252219075603, 0.02777292685849326, 0.026849327043497136, 0.05380254119102444, 0.014881630028997148, 0.04055899308462228, 0.016787746854658638, 0.029485868157020638, 0.040800694043615034, 0.016770349216780493, 0.11384332978299685, 0.057437351505671225, 0.011669589439406991, 0.01680069669548954, 0.007584169107888426, 0.032200876756438186, 0.15538746411246912, 0.0887629452294537, 0.11498558920408998, 0.13101576188845293, 0.10997683368623257, 0.17124569602310658, 0.1643130223133734, 0.14132730928914888, 0.2146669024867671, 0.19966447965375014, 0.11335807546441044, 0.11755176793251719, 0.09047661256045103, 0.16013267662908348, 0.11339521168598107, 0.15532966649958066, 0.1154461923454489, 0.10614504465567214, 0.16244179915104592, 0.1002825970894524, 0.092463159534548, 0.09293590845274073, 0.18706575355359487, 0.10151734083358731, 0.1303771382996014, 0.1348929245557104, 0.12256090342998505, 0.09731015230395965, 0.14604360264326843, 0.09260485800249235, 0.06827724698398795, 0.21499042798365864, 0.13372583075293473, 0.11448132911963121, 0.21682938002049923, 0.23751616211874144, 0.2173084393143654, 0.16425423403935774, 0.0930856272046055, 0.10212818519877535, 0.12466529836612088, 0.11660766787827015, 0.1282217718128647, 0.14402140543929168, 0.09468029984938246, 0.2006710727832147, 0.14983659982681274, 0.13083888137979166, 0.09660022825534854, 0.18589182011783123, 0.1382240429520607, 0.08549325460834162, 0.1370628931160484, 0.09945668426475354, 0.1314761343279055, 0.13518853512193474, 0.15416766170944485, 0.09514399032507624, 0.08009164767073733, 0.15159221419266292, 0.1616941892674991, 0.0947812930015581, 0.11584997496434621, 0.17158694485468523, 0.1456997889493193, 0.149480029674513, 0.15952317576323236, 0.1983259879052639, 0.1586754819644349, 0.13429147111518042, 0.16951008486960614, 0.07460949184106928, 0.12935464030929975, 0.11829675867089204, 0.08078377374580928, 0.2200924956372806, 0.08879883294659001, 0.1293941717594862, 0.09485556544469935, 0.08553021441080741, 0.13677591351526125, 0.16772837404693874, 0.12247202891324248, 0.11092404143086501, 0.14089806803635188, 0.1181440611502954, 0.1250249897795064, 0.12572839989193849, 0.1489909009209701, 0.11820139735937119, 0.15777228400111198, 0.10086471906730107, 0.10097111335822515, 0.21950464003852435, 0.16851350691701683, 0.20611425356141158, 0.122689743659326, 0.1404513477214745, 0.07814665418118238, 0.2044428861034768, 0.20933656208217144, 0.09013960457273892, 0.09420472822551217, 0.10410830644624573, 0.12065994686314038, 0.09969786953713212, 0.12609966711274215, 0.19194294113133634, 0.14953978146825517, 0.12422354492758002, 0.13963475796793187, 0.22238384054175445, 0.08671484834381513, 0.08296924004597322, 0.23215847675289425, 0.06046551080154521, 0.08055710912282978, 0.12289901742977755, 0.13713902474514075, 0.08191618083843163, 0.1112970049892153, 0.1403414114777531, 0.09954038834465401, 0.09294481761753559, 0.09194812431399312, 0.16406855971685477, 0.07945742777415685, 0.10779257517840181, 0.19985077822847025, 0.12586053780147008, 0.13169224773134502, 0.10212834804717984, 0.06378282779561621, 0.10671787070376532, 0.12852040864527225, 0.11267234797456435, 0.14230317835296902, 0.17174973897635937, 0.17788279987871647, 0.11227874338094677, 0.06473447994462081, 0.2262621431478432, 0.11349573664899383, 0.12526895026011126, 0.13584341640983308, 0.13683072557406767, 0.10647236316331796, 0.11941448226571083, 0.22048360322202953, 0.1128305144874113, 0.21679577896637575, 0.14979455779705728, 0.10632170803312745, 0.08789890552205698, 0.17646235467067786, 0.13058057666889258, 0.12819743954709598, 0.07264796245310988, 0.13151504152587482, 0.09752311051956244, 0.07727905216493777, 0.1690916187529053, 0.12389292195439339, 0.13795452884265355, 0.1718633800212826, 0.1173664600189243, 0.10108590112732989, 0.20831703607525143, 0.166177880817226, 0.10355701709964446, 0.2203870748302766, 0.1495315847652299, 0.2161987902862685, 0.11299059446901083, 0.09102000375943524, 0.10557229324643101], [0.05159329902380705, 0.01194716030399182, 0.02231484036227422, 0.057772669941186905, 0.04909172361450536, 0.043857423056449206, 0.06927427955503974, 0.07152715830930642, 0.0805717044110809, 0.06306250859051943, 0.03003308629351003, 0.07796830125153065, 0.03167660667427948, 0.061366157473198006, 0.0034019988005249096, 0.06159961423171418, 0.06228636630943843, 0.04381637508049607, 0.03906145951311503, 0.022356789093464613, 0.019618491475869502, 0.03556284474741135, 0.02486140773232494, 0.07231797730284077, 0.027126708766445518, 0.06471392711890595, 0.015557932667434216, 0.030741724518260787, 0.02793620104369308, 0.05198517335312707, 0.10504587899361338, 0.02257715691147106, 0.07426940330437251, 0.07863591185637883, 0.06384545657783747, 0.041285300361258645, 0.025465736464996423, 0.06717429509652512, 0.022708429688853875, 0.02755450304331524, 0.05912793507533414, 0.01255418366885611, 0.0481968818099371, 0.022126943837585192, 0.028140499456120387, 0.028572519309818745, 0.021306779900831834, 0.031562985985406806, 0.015406537934073379, 0.02060775482095778, 0.012456846124093448, 0.05809609365782567, 0.02699424516010497, 0.060402936302125454, 0.019727613477568542, 0.01842430037712412, 0.0351346382605178, 0.06246678877089705, 0.015024934928598148, 0.025252917349072437, 0.05957831947931221, 0.032106421289167235, 0.02758461982011795, 0.047725388181528876, 0.048304460144468715, 0.008115371273431395, 0.021983221638947725, 0.03717589212049331, 0.007828378950112631, 0.018320599870224084, 0.04069348890334368, 0.006653902262249696, 0.01599230194863464, 0.03494270445246782, 0.011639983260205813, 0.055602494427668195, 0.03649647839899574, 0.021852042160129974, 0.021541357938466326, 0.05779912602156401, 0.04458685837952154, 0.07886292253221784, 0.04125776880287698, 0.03147145839674132, 0.02704226508337472, 0.025794897195217863, 0.017468711028673818, 0.00907323880320681, 0.0378354654780456, 0.025625573870326792, 0.04318724080388035, 0.02448698871635965, 0.06488269913409438, 0.046905690737600834, 0.03875271590160472, 0.028628739328788858, 0.010919797217606433, 0.08523543844265596, 0.017960978006677966, 0.042926422120737176, 0.02027170017494687, 0.0689588693369712, 0.008379499511128026, 0.05887351158474173, 0.007002597591573638, 0.052957262976893356, 0.03818396445629852, 0.013625150263708617, 0.034478671316589625, 0.04111091346879091, 0.019610148887815218, 0.016195175437522785, 0.015360066766983696, 0.032419565200273476, 0.045173743673201115, 0.02977863566151687, 0.0315130390226841, 0.028142930307824696, 0.05345017456316522, 0.01917339625236179, 0.01200775517749467, 0.013081403682008386, 0.05170838534832001, 0.03619784495926329, 0.08025277938161578, 0.027398212679794857, 0.01823460403829813, 0.024687088693359067, 0.06963875464030675, 0.019955814982365285, 0.07861320128930466, 0.014998521256659712, 0.07642406411468983, 0.045947097175355466, 0.02702842466533184, 0.010360036361297327, 0.05640062463602849, 0.03637305287910359, 0.015717196710673825, 0.06537484736847025, 0.01075680716894567, 0.03361530675153647, 0.011062086011017007, 0.028517442622355053, 0.03798510619838323, 0.007563020019525928, 0.018226744906444634, 0.06686162615993194, 0.008545509040621775, 0.04469689640349575, 0.05158822358186756, 0.020365785840632658, 0.04130141217527645, 0.04022884169327361, 0.008312220219522715, 0.030749887294535126, 0.028881412199033157, 0.07670893347156899, 0.039016632097108025, 0.01987241454688566, 0.06530340441635676, 0.010364990515102233, 0.05998755073440926, 0.0418375566202615, 0.05207382395331349, 0.023273001358445202, 0.029657537516738688, 0.029499252260263478, 0.0027551310111968113, 0.04882906610146165, 0.01713081924909992, 0.04801900385479842, 0.03701351529785565, 0.06282883470079728, 0.06655946094542742, 0.019863686890208294, 0.051718159645263634, 0.01576876706842865, 0.04836761818400451, 0.0435263861769012, 0.05719240036393915, 0.03809633844399026, 0.07507524506321975, 0.05637931863644293, 0.0296934761240014, 0.07825278384344918, 0.03079364601788776, 0.025481741409748793, 0.019125932727807333, 0.028357079352385232, 0.0164562248225723, 0.0216514417635543, 0.004068403945504022, 0.04041309787758759, 0.03879970784432121, 0.056789245389934094, 0.03941225193973098, 0.04533186947394695, 0.005784583128323513, 0.015775528669889485, 0.024672366179791943, 0.005693019492485161, 0.034108174233032126, 0.06118554502193417, 0.035608347305761914, 0.004510391478626323, 0.01272669865284115, 0.0351314762873309, 0.043380867556801865, 0.00988693121221981, 0.05108622980437108, 0.02603936318441161, 0.04120145378900426, 0.06165541695164783, 0.023993159411475062, 0.05078457688380565, 0.015237570840067096, 0.023580623690837195, 0.023614575886832814, 0.015414410636627247, 0.037004310970327685, 0.05358145073322313, 0.010706144351778286, 0.062314233742654324, 0.02998678645651255, 0.029040297958999872, 0.009659943436937673, 0.03592569813398378, 0.02637779270298779, 0.04139742148774011, 0.030989070888608694, 0.04494579661903637, 0.008667455354173268, 0.07111118920147419, 0.03246793796175292, 0.031238398581211056, 0.02644605332586382, 0.02406048365602536, 0.04500918196780341, 0.028053623225007738, 0.04065207112580538, 0.04865867238757866, 0.03326214963038053, 0.008452983157310103, 0.03680246037298015, 0.01300192263443023, 0.04231991359431829, 0.013479207559222621, 0.012611699689711844, 0.02418769370498402, 0.03679475221516831, 0.047030246018299034, 0.012590529397130013, 0.030000662497643913, 0.012040564890152641, 0.049289713347596784, 0.031122857638235604, 0.015027196146547794, 0.034504075667687824, 0.013767417004731084, 0.039329718332737684, 0.03351951457027878, 0.03848090155848435, 0.06119816577328103, 0.01396430835926107, 0.03131756665451186, 0.021538889767335992, 0.05263086049152272, 0.031077758808221136, 0.015384027534829718, 0.027892793462212597, 0.013682086985292179, 0.02676945329377694, 0.023226457248841013, 0.04628169975642647, 0.018856081047228405, 0.04032022339691009, 0.015726931991853883, 0.05351054043109928, 0.027889801122780358, 0.021355039007695656, 0.0218767272641084, 0.011813811209451939, 0.009074410972451525, 0.014946733767698919, 0.026257537637970278, 0.04854701945026006, 0.038677870096372705, 0.0452100995795003, 0.05946716187255723, 0.028637031026716744, 0.04338089130552752, 0.018091338154460703, 0.057441076662923606, 0.06305125847991024, 0.04371010971122554, 0.05009642702394298, 0.023335416402135576, 0.011395725920530302, 0.016615556719313775, 0.042052513121494224, 0.009905820778970207, 0.051722502269382985, 0.020038192526304295, 0.007493555845160569, 0.05635849100404552, 0.00392967534051942, 0.003583218328588243, 0.039399553156856976, 0.07567138557455369, 0.01096872637780117, 0.023026998487434218, 0.01809946191497147, 0.028912424642060484, 0.02263493925732161, 0.028385550681767718, 0.004895351112021932, 0.018669063225388527, 0.009800535892801625, 0.03442102976675544, 0.05023700251643147, 0.01281993106074099, 0.011201110202819109, 0.028929089462118487, 0.029845091381243298, 0.03612080070057085, 0.028623887803405523, 0.0460267029037433, 0.029507917152451615, 0.04060259913759572, 0.03867912199348211, 0.01760272678386952, 0.08774695438998086, 0.008205903111957014, 0.042846877460501025, 0.024519227611433183, 0.04868853471374937, 0.02443919949499624, 0.030330301595053503, 0.05532159110797303, 0.047835198896271844, 0.043086295149156024, 0.052639230220977745, 0.027400631657136337, 0.06060896667518786, 0.036514619032719305, 0.0752011743773307, 0.021729374903121164, 0.032797627949288914, 0.02261947374790907, 0.0112797956680879, 0.09803032223135233, 0.134239169635943, 0.07513575003083263, 0.07288783136755228, 0.1249526986586196, 0.10164281552923576, 0.10693217241870505, 0.15018681889133795, 0.14526039681264333, 0.13330998378140585, 0.12482940884573118, 0.09002733416855335, 0.11859323776194028, 0.11234413380069391, 0.13404155309711183, 0.1267539920019252, 0.10776359494775534, 0.09924613484846694, 0.09779451095632144, 0.10148911377681152, 0.16136596830827848, 0.0948385749278324, 0.11857312598398753, 0.08773179591766425, 0.1430194942014558, 0.1282580734363624, 0.09551279446376221, 0.09611399006098509, 0.2317898151065622, 0.11026685312390327, 0.16942864709666797, 0.20635273147906574, 0.159736018627882, 0.13225411543888704, 0.14695165891732487, 0.16238773348076002, 0.15351899580231734, 0.11782894948763506, 0.15389856829174928, 0.08339062386325427, 0.12867674311356886, 0.1246518362313509, 0.16369524332029478, 0.15254081971943378, 0.08124821739537375, 0.12407977692782879, 0.14232790416904859, 0.05902113366339888, 0.17867230251431465, 0.07957604926611696, 0.21286446920463017, 0.06646376036639724, 0.12941652270300047, 0.13724315272910254, 0.14177853507655008, 0.07455792317965201, 0.14416283927857876, 0.11704720929265022, 0.11100682270314012, 0.12032666403268065, 0.1022887130134872, 0.15785940789750644, 0.08096948199506317, 0.11244619225284883, 0.12182933411427907, 0.17258597910404205, 0.10131893719413451, 0.08524537898067917, 0.10210573247500829, 0.11359290286366429, 0.11195194734526531, 0.10031708023910012, 0.14037342475993292, 0.10018408737544503, 0.08083120334361281, 0.1489144300243684, 0.12094622078750815, 0.10994996369949409, 0.1164719880159412, 0.13733945041894913, 0.14506178961268493, 0.14799087601048605, 0.17994987538882665, 0.10423642064311675, 0.07478544275675501, 0.12465735950640269, 0.1082273939890521, 0.13233783308948788, 0.18744814874870436, 0.15389171508806093, 0.07425601580845458, 0.18965604741658482, 0.09914006625435182, 0.1532199111367975, 0.14987049943634442, 0.12640895694494247, 0.11685393537793841, 0.18650072387286595, 0.10658886762601988, 0.13851617941898958, 0.1516689836446728, 0.2732845385159765, 0.1468783499939101, 0.09679399071527378, 0.11855929744030748, 0.12109393786106791, 0.08349883662802832, 0.1640696046607835, 0.0781829422339797, 0.056167561427823136, 0.11021979672036, 0.1714876616107566, 0.11919865384697914, 0.14964095103953565, 0.11851686186024121, 0.11585392403815474, 0.1761939940708024, 0.10638555817838226, 0.1333859661327941, 0.21140937799853937, 0.0733662528385009, 0.10480588794286762, 0.07658039858298642, 0.06694469241691486, 0.12988397904804774, 0.07310821954160929, 0.13150130797709736, 0.127101686916181, 0.11690508334764413, 0.1203156446239778, 0.1221204392079796, 0.15582897327840328, 0.09056290864412274, 0.11981677210756711, 0.12149136939219066, 0.10055574814655951, 0.07331184790070568, 0.06925240358603851, 0.13369003124535084, 0.11793652442949158, 0.2175197351191725, 0.08315196274114506, 0.14015283302537032, 0.06814434911523547, 0.13051899283060006, 0.11086825228163175, 0.11221322403954608, 0.16527784482709, 0.09456828728850399, 0.09711187758616038, 0.1272298621812037, 0.15098378541214125, 0.12066504944648061, 0.14511362968810967, 0.12476652222020285, 0.19544952868350915, 0.10438862283314977, 0.15030036494135857, 0.17260657942720822, 0.19063598769051687, 0.159812028120671, 0.11472436679261071, 0.1416132575167077, 0.09092999608921153, 0.19928279013506003, 0.10615644404398543, 0.13827975067709172, 0.07816739021135227, 0.15421481989324093, 0.18635208399168082, 0.12308234402111598, 0.18795048179371016, 0.07708657213619777, 0.09164246464414255, 0.1302761315767254, 0.1196160614490509, 0.14696657311703476], [0.018199006394882287, 0.01862304498042379, 0.024732211272099187, 0.076968181346144, 0.0533478209482772, 0.0536514484057469, 0.04211807996034622, 0.009477062982374003, 0.053298097902110646, 0.019324500912002156, 0.08601119395877634, 0.045008801988192966, 0.031066423880734613, 0.03561375183718545, 0.033378833904862404, 0.020817761409229467, 0.02175680807392512, 0.048311438877135515, 0.11855225424681391, 0.012356355087831616, 0.016245806024276783, 0.06166091987064906, 0.022802014934963415, 0.05773278565279075, 0.0312621744482645, 0.016156655004514114, 0.019865339122978703, 0.027850517337875705, 0.014143685876790966, 0.026905689554821168, 0.009459434642589517, 0.023323899966531565, 0.07758032849856786, 0.006919279004380639, 0.004526077087835542, 0.05408990416409714, 0.027655954206628457, 0.020584504818543792, 0.007417827944404313, 0.045306977416787825, 0.02236132340372673, 0.0442605576744037, 0.04212583561560937, 0.02484788283306573, 0.11518286647541182, 0.05132233963481017, 0.0391782489605248, 0.015044095061187233, 0.044321205134370496, 0.02931014115789107, 0.025054462819493244, 0.016397363606042097, 0.015878815270428146, 0.027741118833156567, 0.018787647397922616, 0.017412650465433086, 0.03087662745799337, 0.03861327695527247, 0.016438146953337958, 0.06679759959557227, 0.03174784267321229, 0.06005929224193096, 0.014782455350671495, 0.010835724184289575, 0.05065060014437352, 0.029432206215070825, 0.010459769134675818, 0.04821182315104774, 0.02470405206882528, 0.016209950537553856, 0.017068219304616963, 0.03097909303115947, 0.033639754368258376, 0.060631772237164636, 0.03559771466201969, 0.02345932537822851, 0.013916897421170558, 0.027690795283498507, 0.07270416550870452, 0.04539567890710064, 0.025825702685064504, 0.02403514546209148, 0.022208474909088442, 0.03299544804862567, 0.06099472740398986, 0.03069414564275316, 0.07606257458350488, 0.0683542742793049, 0.03360808374626296, 0.028195431954892616, 0.07708907593041658, 0.030335997896535054, 0.024938777687826326, 0.016814048568318998, 0.047822439045246155, 0.04898093241666045, 0.04352085611649922, 0.006394680256822279, 0.030366094317287207, 0.022020378216568912, 0.022063743389610733, 0.024775864822523933, 0.061290439750467024, 0.019117091416514347, 0.05691117813278522, 0.0285771095992199, 0.03375894243695906, 0.025863861798175743, 0.04843271004834345, 0.03038762423342892, 0.01667499977962247, 0.020806180512798682, 0.05062000160770757, 0.026731750495465736, 0.029002055725348846, 0.021906647265755703, 0.017577178244079863, 0.03291637836290257, 0.00984184256023062, 0.024033596705911413, 0.02483649192644017, 0.019904500771579996, 0.014405312016606331, 0.026985939891476716, 0.053977420021380694, 0.08326272679758923, 0.03148523944297007, 0.029577986071152345, 0.06838951060282332, 0.02360708825290203, 0.04358987669859614, 0.04645585933966296, 0.04793288419023156, 0.028837209035243307, 0.00357873024352427, 0.11367448312895638, 0.011020852286102516, 0.029865671348358904, 0.07483647537550756, 0.01605353125237993, 0.03817234454410417, 0.08118374299790178, 0.0205093977773296, 0.02272610552608967, 0.05496203540159123, 0.011437779824648584, 0.02766206780714648, 0.05374786823189684, 0.0847886638449771, 0.053496301373732943, 0.04758589495239513, 0.04094736956592117, 0.01322002160096807, 0.011795964890292712, 0.05511116722066488, 0.01411707203702203, 0.03444814741877573, 0.06263099424540997, 0.015429782847474729, 0.05724662209727934, 0.03002337645739317, 0.04238589094685657, 0.026931621466896365, 0.023000939350043024, 0.04637040803208947, 0.04372705951599138, 0.0010117413018763597, 0.0336623326210039, 0.019364627776667476, 0.07569229123847825, 0.05279210755335433, 0.027026210944833498, 0.04779005256880607, 0.02227486956066319, 0.05466276413894125, 0.04000345950147935, 0.0833668140694499, 0.05833835101553372, 0.04265483169417296, 0.055109043406056504, 0.06064988233681236, 0.021143524375345026, 0.05568940797820687, 0.025370119006506035, 0.02686707243057234, 0.012394947615186018, 0.06126139845166888, 0.034809572489133904, 0.07295033122811999, 0.04225110675075224, 0.04536999296396971, 0.015436220448464155, 0.057235799463731904, 0.04625400195696524, 0.06903539451637439, 0.06690560879984073, 0.03852995624765754, 0.03802644933706947, 0.044042177964001894, 0.03198954702488013, 0.026235514087602496, 0.02050577100765492, 0.05530357261055282, 0.023115942554016198, 0.03280902733760221, 0.020841367642528245, 0.01682989575367953, 0.07546150112258536, 0.06182895228266716, 0.04912094133240836, 0.04178017969908459, 0.009009402228652366, 0.016268862644210458, 0.017027081422773854, 0.024650653059195195, 0.028246966689558964, 0.044103483602936776, 0.030359312359775816, 0.04360782055716429, 0.04423070552625826, 0.06788856855460576, 0.05532007118953126, 0.04254977750991072, 0.02431560603768698, 0.054328361725700755, 0.029312017307217633, 0.024270169636500732, 0.04604423285595008, 0.020519197519336427, 0.03197182369019304, 0.023810046558667506, 0.04330422702644553, 0.05275648446487529, 0.027953461278229952, 0.040387856374893866, 0.02096755988895893, 0.042372133649353466, 0.06126547644713095, 0.0013425075095645817, 0.017186065570318272, 0.04986790321501238, 0.05030176868396146, 0.02299358063776578, 0.03138555586338043, 0.07110884825565986, 0.03023982234299183, 0.006471868704206177, 0.1180928046149867, 0.04501158058909433, 0.06686051336250134, 0.04514644620940089, 0.03958324615710548, 0.02332481598880674, 0.013576281323496784, 0.04223868277456079, 0.01392786593974701, 0.024341022263148, 0.015745130301054035, 0.02079874716166939, 0.057946368120610714, 0.0408605510102851, 0.016298894604135836, 0.0644633916339704, 0.09169161772089345, 0.06980659027716943, 0.0313801479392818, 0.02428799814411572, 0.0015368565842176654, 0.023019213994432772, 0.04515360136117254, 0.021149880552132214, 0.079230532449271, 0.029985911146338497, 0.02985956792586616, 0.014717020826148135, 0.04504259303212166, 0.07652049072618995, 0.029117413463869264, 0.014488938064979655, 0.020484609196760824, 0.04900189236338649, 0.017403271415137818, 0.008776702884850758, 0.030098510640008107, 0.05350300869239228, 0.03798852601487722, 0.018102978422705616, 0.08170732775969164, 0.03434380230360797, 0.04120808646881154, 0.07272743925984416, 0.06948729883879423, 0.020500892340870838, 0.0025114567875529504, 0.04824817566467183, 0.006141730459473495, 0.01983991780850504, 0.061642836912402084, 0.008177877919349288, 0.08809588423797063, 0.02888540198494281, 0.060800605320504734, 0.06878661643713713, 0.038671003321983984, 0.011340054666756519, 0.004783668488796268, 0.03895058010571769, 0.08198948297649622, 0.05094704870134592, 0.06996884157082864, 0.0630010197471295, 0.015996586897277405, 0.019303459541073868, 0.07280166420553412, 0.06731189521295683, 0.03030435780861548, 0.020134340938446776, 0.05577354632051928, 0.04906691298154848, 0.01642066958759512, 0.03677449794486165, 0.02215234309967075, 0.012730073516390153, 0.010289209179713257, 0.05364530087847795, 0.05675472831353545, 0.018464591786531464, 0.06570352973150355, 0.0531473613477179, 0.048762288077601364, 0.03473466222307511, 0.03721598336207015, 0.012683149427175522, 0.03055342087256057, 0.011780981988912182, 0.040963620479617796, 0.019614686590752432, 0.020763146125578454, 0.00790566239239914, 0.035589229581611495, 0.0074547419457563335, 0.03088203877476709, 0.031997414638421366, 0.030651258836899484, 0.04490277410617896, 0.03524370597941535, 0.04702816291579178, 0.042841764699135504, 0.04268425975793174, 0.018468722368457487, 0.036687662425850115, 0.007268154145484524, 0.15445517056754657, 0.15866090703223432, 0.07046608560319458, 0.13951241810406956, 0.11484591955585138, 0.20203286542424134, 0.13066307295645985, 0.126053051756961, 0.1909844289932932, 0.09626113716512918, 0.18134620546230248, 0.10618403327784368, 0.10661338309624366, 0.10536878702363797, 0.24061603578073637, 0.1177061346492597, 0.20728776630546364, 0.08812533944313015, 0.2131900167358773, 0.1467992735228368, 0.09775609230356556, 0.20164098430957111, 0.08339324979377644, 0.08994097023137979, 0.14198200058724197, 0.09237314507897411, 0.12463557853230409, 0.1324040445366076, 0.11379782722464629, 0.1032989498760019, 0.09007731505802699, 0.19189076178840228, 0.24614411486046656, 0.08393615923289742, 0.08055828977376223, 0.21686952215220245, 0.05606213065662554, 0.05312935981367316, 0.10896850350712027, 0.12379270233213902, 0.10941150545009545, 0.12326534491564546, 0.15010216486241135, 0.1866659607206072, 0.19869304820895195, 0.1502433679997921, 0.09607826519225325, 0.08666409392442022, 0.1510906953896795, 0.12181421635406357, 0.0945879105212433, 0.17836575396358967, 0.11333800439855882, 0.2324268509234701, 0.08812694078577415, 0.154179237516863, 0.09181089060647146, 0.09014000490839992, 0.13475012007568563, 0.12817871198058128, 0.10011925335441317, 0.10796617836292301, 0.09015036613813468, 0.1321705470659903, 0.1344991706843887, 0.07845619507133961, 0.11572022549808025, 0.10517197115612881, 0.10515650734305382, 0.11408685600118977, 0.0847351545734065, 0.16447021173579351, 0.14116630649992398, 0.1508085469582251, 0.13009246571787766, 0.14182839382972035, 0.09440599528274365, 0.10730151260005576, 0.1549930317061288, 0.16894770147544996, 0.07488661232803549, 0.0789095786001001, 0.09633365220257215, 0.14573073014616966, 0.13783702014812402, 0.1800857859530619, 0.1116460230467575, 0.12184128990130765, 0.20471881915416035, 0.07012302508311612, 0.12405259481498174, 0.09661890832441193, 0.12639791039483889, 0.1957690372530903, 0.10408769933772938, 0.07463815994560719, 0.18436788474874838, 0.12909784194614204, 0.10010717543108122, 0.14306047771658215, 0.16155294541801724, 0.09548667086554424, 0.14157907292246819, 0.05625290416979364, 0.10789091525865452, 0.07282189133444003, 0.1333698984235525, 0.1433946562132665, 0.11347588271434818, 0.2365901789494923, 0.07134420491222825, 0.13178796188107558, 0.17372895777225494, 0.14086731682930673, 0.14295626830841812, 0.15154506957956723, 0.09071638647999082, 0.09401199713881526, 0.08712635269122464, 0.08879714339439358, 0.1427057803209339, 0.12685130749429974, 0.09162363529737506, 0.11623135235692773, 0.12060490410242762, 0.14959527206208023, 0.1774677535785096, 0.06716073796685253, 0.11748881345348698, 0.08936002211911337, 0.16958202315228327, 0.16559268507574285, 0.11024638850774084, 0.08331690103347812, 0.11807016868676458, 0.25394031937633244, 0.10235096181609801, 0.15630359495324747, 0.17451824327664717, 0.1429107521793672, 0.15870940871536732, 0.16795558828328336, 0.18422493099101953, 0.1022785757003086, 0.1296300305319684, 0.10832943208515644, 0.07847745357347385, 0.1091515247577003, 0.1835131070443562, 0.14761882168906076, 0.19158844729619368, 0.09204689187130757, 0.09629332008106367, 0.10381133880998407, 0.10568672817732606, 0.08165585409317698, 0.19332564622163773, 0.18539199765239442, 0.08001331758818456, 0.12289415911904403, 0.06813159944223506, 0.10287877385105405, 0.1024546351815973, 0.07386467752179929, 0.17348791499223026, 0.08516253664025239, 0.07668259274214506, 0.1662506197712251, 0.15711067164582865, 0.21236624808183738, 0.15470644565565245, 0.1223254246371133, 0.0949892843408244, 0.1332260218581983, 0.16676196376127855, 0.09874711305435215], [0.04514229018241167, 0.024172969495079348, 0.027647849105830704, 0.008821034122125378, 0.041401625012180636, 0.04103975210871015, 0.0213668404280075, 0.033220328124506135, 0.03082270428006138, 0.03349348935963852, 0.051620494707354476, 0.022046718945992843, 0.08037893939763308, 0.0196998461282679, 0.08460115069257361, 0.013054573559202254, 0.032990277611783574, 0.04190699450139489, 0.01709762870866273, 0.06451323003109012, 0.03218610165640712, 0.03705354547128081, 0.05472908415166395, 0.03607456532440015, 0.04774944224793996, 0.05410850280895829, 0.06301796276654516, 0.04510829218530229, 0.027047974955556647, 0.032299145590513945, 0.02591971540823579, 0.03237077174708247, 0.027946245058306625, 0.025107018749362657, 0.005546132776154471, 0.0016310053324559703, 0.018362443428486586, 0.05888284144124814, 0.04229195455887488, 0.02292455157398113, 0.04042414782036628, 0.050757228529879024, 0.08890555971967322, 0.03504143129768116, 0.0655159962230495, 0.04697180040446775, 0.0654074577614665, 0.017873545376850025, 0.024514240379046117, 0.04246163581098829, 0.03697679976799658, 0.10755953232624701, 0.009712589272697057, 0.023920428939163685, 0.04436863812484911, 0.06511589804930346, 0.05496846791356802, 0.08109501775886331, 0.011289697190347527, 0.02970635811133044, 0.0677072097148214, 0.10566614142486028, 0.03279067296534777, 0.03247837043766465, 0.005725631581818951, 0.01904333465998726, 0.0848839980150972, 0.011942873659011508, 0.025189382722601295, 0.02172695592577968, 0.022962714079767466, 0.009728023399864989, 0.012594447936862707, 0.025903065855215703, 0.02419506768429918, 0.025893150762255703, 0.022870504563408237, 0.052918701831783564, 0.011907309942346598, 0.050746623027537546, 0.021231291183669652, 0.024044414250446216, 0.11044562674526658, 0.03662114224529692, 0.04962938119258199, 0.022926176665350795, 0.007822149150472666, 0.010637129706862782, 0.08320351783186197, 0.02348808169231883, 0.028624729186828648, 0.028752782315547978, 0.061677055433392525, 0.02368282972435866, 0.04484988230147532, 0.003648607900166618, 0.022582510552768196, 0.043401596801621575, 0.03642163598643882, 0.02914207481912204, 0.001046824742973383, 0.027490425588829175, 0.07126055511512927, 0.024249397983242358, 0.04285049744482551, 0.04975679649838379, 0.012196767892289375, 0.011367559083737433, 0.030092145981533185, 0.03274389136848705, 0.0855122943009649, 0.01032046165450343, 0.03982544583933694, 0.01522422575258783, 0.01870942079196019, 0.055580214730330875, 0.02310694517966892, 0.04194009343960455, 0.027084408893382976, 0.028449297350432192, 0.06491001016859498, 0.01760671996245427, 0.031732792766498666, 0.02180680083776159, 0.0322592545167676, 0.019696019190762724, 0.017637781599270444, 0.023307986624006714, 0.05294015032372304, 0.027491122783560838, 0.013717107025773397, 0.03611132835171052, 0.09577417972364596, 0.035091625925685675, 0.02870830095240048, 0.03795273329264351, 0.0036806419624813964, 0.029389750278953995, 0.023719529987179806, 0.03979123749637178, 0.032688841822424104, 0.03211385464029653, 0.0341449338676674, 0.030357646556305032, 0.011312569757657391, 0.020616909954696894, 0.016132753608482223, 0.0159184485008674, 0.01999251694152398, 0.03169591099556003, 0.07936704012432269, 0.023308163043111563, 0.04290219842057143, 0.04813657361747963, 0.030532559313412224, 0.014581324000443732, 0.03545191105721252, 0.043744843918830156, 0.05480559576036675, 0.02083764078893832, 0.009595865134282835, 0.03441498062706419, 0.04846617539546319, 0.0638375516448702, 0.06527810184551136, 0.06977727077901363, 0.03502047135095511, 0.1017971211778266, 0.02426520106382668, 0.05210788641124964, 0.025605933674212013, 0.02163417644000479, 0.046075048523822, 0.03661664355812328, 0.03149890174557056, 0.057915331928857734, 0.05229949791516576, 0.04865752227072205, 0.011530947771721652, 0.02300766872109047, 0.027195230625303726, 0.008317308383993804, 0.03753776841663888, 0.015359530724318964, 0.04508175128804786, 0.045278584118932486, 0.026022739076454724, 0.02993296505883336, 0.010277506995147892, 0.07011997846088239, 0.13052827518965515, 0.023316595537055815, 0.05975764271404062, 0.017357287096924016, 0.02661883209033736, 0.04367913458762424, 0.015715576708316803, 0.01604023196601442, 0.011748989062782909, 0.0766044051519462, 0.04154904692300728, 0.022099848237953017, 0.016814450600317547, 0.06495359925819294, 0.015381686589015382, 0.009273542340711823, 0.06319725207452263, 0.02056957026278334, 0.03725473449698516, 0.011431404988148382, 0.06030463693397386, 0.04602315077292068, 0.050093614496290684, 0.02363246546259948, 0.05868468885975225, 0.007054893981798419, 0.02845304286373513, 0.022996354149654508, 0.011026552828427936, 0.01251451566349715, 0.05444848956540227, 0.047564029161419184, 0.07544369636369602, 0.04799940437078476, 0.03709334833547473, 0.023973731257553612, 0.09836583744202342, 0.030176474313650812, 0.010588618693873286, 0.0031373572086782326, 0.045222683011421135, 0.04357842981283154, 0.04505878287766661, 0.04901577179719295, 0.006542195890298379, 0.016950266169650213, 0.05079758779278823, 0.08350777971957411, 0.06259142886847258, 0.05374484196571367, 0.023290902808574692, 0.02398739186381655, 0.038169610047979016, 0.03663803776726127, 0.03445546541895185, 0.002602497103258169, 0.01755001479094582, 0.025920733210763762, 0.036795535923114846, 0.015187001321464777, 0.06619525048881769, 0.020241607146869813, 0.033164596650749445, 0.0359256913486336, 0.009038066940515168, 0.03354802321908729, 0.024135738278606107, 0.01682423846796155, 0.05935115274041891, 0.02326164098589548, 0.03023117102150406, 0.09226021649582045, 0.03996101713606289, 0.03662807008783732, 0.014607059137363518, 0.045576087797858884, 0.029943706268178563, 0.049358462515686236, 0.042286940185087066, 0.041023524943739176, 0.023907060102958764, 0.08229327667504549, 0.0295482390959348, 0.053512799952711375, 0.05374093360400625, 0.04847742550607238, 0.017199945004124726, 0.004280742997902313, 0.00781037487156157, 0.05191865995792406, 0.035544093432171006, 0.03410151441182409, 0.02591644147677081, 0.05332973459735513, 0.035845617431082895, 0.08655232563614845, 0.06883657697056021, 0.032741319720766375, 0.006609250841263149, 0.008556120480144662, 0.020084544949765717, 0.039806331507861614, 0.04892576412696924, 0.0179526031882103, 0.05559210944920778, 0.014033403580210038, 0.04943877731316856, 0.035600622184574604, 0.010861309195336486, 0.028909598543707813, 0.021809538726561835, 0.023604022970955287, 0.023779157948281084, 0.04994755304817643, 0.013676424610561557, 0.023291102976405194, 0.01099902211821505, 0.04052580932953528, 0.03340421450723495, 0.022065678910751427, 0.04176054968099509, 0.035607261649732075, 0.06867217472089188, 0.03849789207535131, 0.0053312437043392235, 0.0401859243533441, 0.028016103631151573, 0.031485439610800574, 0.014503538442243422, 0.023748608605403985, 0.06397353684795754, 0.08655048002089773, 0.03956804358001266, 0.048204135349286456, 0.0030028319160919636, 0.03273430706134864, 0.02081578517598765, 0.05177072236048324, 0.041688760676022084, 0.011915973138197191, 0.026052677737815038, 0.02546704943025751, 0.08128978445061616, 0.03345040577862944, 0.04936892891834889, 0.00950784217898867, 0.03651745530909725, 0.012127966985904744, 0.03868828560890896, 0.05601750001577394, 0.04259434708261064, 0.047340495977550745, 0.011760357917020363, 0.03746239674676742, 0.04436597826757601, 0.024023998828072633, 0.025510794582909772, 0.024718089262023568, 0.08754120221627609, 0.04572102966319237, 0.02750693604217044, 0.0764013806890164, 0.08815193123051099, 0.07277176116726228, 0.13675538104559692, 0.13277350685426167, 0.13013590552977153, 0.10923225006886891, 0.100214723231537, 0.11710761248001031, 0.12338438709931714, 0.09606299136898347, 0.15762124210596085, 0.10161447990685701, 0.1665145291813782, 0.21171689006899083, 0.16937291223023618, 0.14469679205545358, 0.12833235945020402, 0.20288551252867493, 0.09592333529144526, 0.15421711334160396, 0.07166194250541073, 0.22334337048232555, 0.14469691419175693, 0.17505049971597536, 0.20824830047786236, 0.104908109243427, 0.1151075219469411, 0.21657516009041242, 0.1593821897570576, 0.12572023033031396, 0.17934585708592618, 0.11875858317528452, 0.08526026603898831, 0.09466982326869454, 0.24866118122424397, 0.1676960214972496, 0.14110396270241055, 0.20929123594292573, 0.10407809128186532, 0.1204391922801733, 0.08728819007852248, 0.12420697510242462, 0.11667086662990706, 0.09920677981738533, 0.11101790996534483, 0.09595913479902915, 0.15645846378590378, 0.13559860097510473, 0.07187641385410513, 0.134559763861554, 0.20410736410745553, 0.1705235040613583, 0.1141103875956365, 0.06867524848452636, 0.08589857071638107, 0.12447557997490678, 0.13768548970775946, 0.12736597630594457, 0.13419422347630772, 0.13359826616942883, 0.14810789615980216, 0.21626056411436625, 0.11715188010462693, 0.09472484567335673, 0.0872806515544653, 0.10440305527299643, 0.19644962144749506, 0.12795376405119896, 0.08676434747342553, 0.1320909820497036, 0.13335551348115715, 0.12320374750665256, 0.13863442093133926, 0.1563760353518384, 0.1610593247626509, 0.08406881282904319, 0.1270546508686883, 0.15615651570260525, 0.10345144383609295, 0.12588698709649698, 0.09207296797207423, 0.07338034601083823, 0.19900339655578136, 0.13797996033515247, 0.12840976672513144, 0.17009671910532884, 0.07400215550192765, 0.07372249050864152, 0.16019545468900884, 0.07307584663586957, 0.11732316948473454, 0.13123803638986178, 0.15734773821064404, 0.1241537236741611, 0.1547324335468667, 0.12470750324428082, 0.13927889349205153, 0.10027336901319878, 0.14535651808338507, 0.16222199451710495, 0.08029402074004922, 0.09375460166484118, 0.1660703330167702, 0.19474329586539949, 0.06368971922035728, 0.09507370088249445, 0.14149000841592038, 0.10450624687863247, 0.19511697867086955, 0.21888557182891027, 0.14424844325653144, 0.26320443941014154, 0.12860209069081716, 0.05904747439282281, 0.0966149117531521, 0.13440394507987158, 0.13259935405637535, 0.13285605742463044, 0.08795680491519825, 0.08639234064945153, 0.17220715300313064, 0.08848201816103288, 0.1365657305078847, 0.10122256486543588, 0.21443548133330687, 0.1422941674079214, 0.08448190494839634, 0.12020946746425969, 0.12930256953196867, 0.21136323761727127, 0.12224686385265418, 0.06442532581942421, 0.09086476173251867, 0.06342030010585274, 0.10497525706887245, 0.1449193244001695, 0.12781504435198648, 0.12674556459699357, 0.06921519272561584, 0.24381994243179048, 0.11384605749377183, 0.0962466707985316, 0.12295068108609744, 0.14559876865574292, 0.09403082648558275, 0.1699196078947612, 0.10128431833748307, 0.10371004710240023, 0.13325414034937108, 0.1279896314122847, 0.12352077263806548, 0.23553399848086493, 0.09314692605819021, 0.1128234373671668, 0.19081461881952627, 0.23863590774791582, 0.13863522160266126, 0.13242988315011772, 0.09623726630317313, 0.1268010280494179, 0.16140849888324738, 0.21449250541627407, 0.08567179074244839, 0.11328418978622981, 0.15021993140024797, 0.11712194313960415, 0.10713780245610646, 0.13487817320440496, 0.08599697865013566, 0.14070160500705242, 0.06768047543508665, 0.17093644690300736, 0.12838467450014182, 0.10357538504259926, 0.0848127654088395, 0.12153980322182178], [0.017879027939800705, 0.0808848279661366, 0.006565847924710917, 0.054149106344474215, 0.08914899772831372, 0.07184825465083122, 0.07616200710513762, 0.02164789811441941, 0.026726600414674197, 0.011604505208587008, 0.04486962767051799, 0.03680990729480982, 0.020325124629640152, 0.03696522396057844, 0.07609458786568471, 0.020701334978054677, 0.04546773932608111, 0.0795197512156197, 0.012847197142296603, 0.02150761948100158, 0.03291882787431989, 0.03516950478245105, 0.04043403746826308, 0.04500726849905082, 0.03222291557384389, 0.05709941392498357, 0.009764662594534457, 0.04640200062255774, 0.05432354412706835, 0.017081918926643472, 0.0021491398677296403, 0.004516117466014943, 0.04738641922761287, 0.020263164204412272, 0.04453015660068818, 0.023474836688754813, 0.03859591663682035, 0.04531898070126772, 0.10944885880287204, 0.0631678511521646, 0.013343317351037902, 0.03962938653837357, 0.03846251665215407, 0.07334151345172099, 0.04857816081494093, 0.04439263451578362, 0.025388458111722554, 0.06507191540939467, 0.06839896259563309, 0.02110067319257983, 0.042041683702596595, 0.050375969880925756, 0.01139805923282568, 0.0057052326987364465, 0.04328206946541156, 0.03142513481101819, 0.025995456879692416, 0.05222903883882931, 0.04531997475507004, 0.009863371628203561, 0.051877781615725586, 0.013330948505816715, 0.022440396482124925, 0.02529660821892321, 0.06786876211741141, 0.036457934217261415, 0.01880125711405916, 0.05524074366050107, 0.06048654538712331, 0.02401534072123468, 0.0287618577214224, 0.05025795907048242, 0.022014693789450184, 0.026334972054298435, 0.049073155503720045, 0.048748432392520566, 0.04701039208365338, 0.06424122569816453, 0.007129631221427449, 0.07111127062567643, 0.02812719508074224, 0.04321960692426988, 0.017027678533590267, 0.03728306333401373, 0.01023025720912431, 0.061124768640313826, 0.019903106382116675, 0.03981438232585788, 0.007603412361017295, 0.0836552321644766, 0.024762786060039486, 0.013288607920653053, 0.06125206859516246, 0.05773236496107919, 0.03607421927154064, 0.047658057151628394, 0.032202016695269516, 0.11293625738471746, 0.07502453135592596, 0.052724803664854596, 0.03948067541101149, 0.021492294767605405, 0.01582872581535152, 0.043878990292016945, 0.0346181475823479, 0.009970004254552935, 0.01869153800154371, 0.012522826021138047, 0.017175270078171576, 0.060507362841495445, 0.027807664458772967, 0.07297392389071838, 0.02063117954613907, 0.0370801576147122, 0.08163396455347538, 0.02914627155821238, 0.056979448933686526, 0.036767787233527215, 0.02014270388255162, 0.0410465035321457, 0.029512195315744196, 0.007819712361586946, 0.018495193715872507, 0.07483956949519259, 0.04161459679848381, 0.04842287468324814, 0.03608312165098531, 0.02038661347303007, 0.041809112432279756, 0.0036345181205043836, 0.04587980346488101, 0.030108719199363674, 0.022136779202680503, 0.004092899907846004, 0.04582350880705884, 0.009734424529597163, 0.08776821289211512, 0.03187634702771902, 0.04365665472245642, 0.039622587617486715, 0.027759139026914324, 0.048972131817468574, 0.053945600121681175, 0.016402111654835086, 0.06035510636866093, 0.03735360722722752, 0.009405221390937055, 0.05159591816897903, 0.05613757357267397, 0.0382324186419802, 0.05412638220669968, 0.017378286059413637, 0.05029106818671737, 0.04491064511239529, 0.06305807097149746, 0.06797744985669851, 0.013941080409235187, 0.03346487893057721, 0.03732522071472236, 0.02779443302590932, 0.025333033675061803, 0.01694955370788063, 0.1154700903488057, 0.06256860295044524, 0.010502600809559226, 0.025569925517109886, 0.022852864349260926, 0.07362271871949945, 0.021419311540999582, 0.01374738834731813, 0.02613231908929135, 0.0683275196435196, 0.023252209349136268, 0.04514299246615597, 0.025169878233490244, 0.05133580516225525, 0.04099334370610969, 0.027328706945159605, 0.021597683130364333, 0.05356281476893595, 0.09394145663827658, 0.019291987210246067, 0.03335171964551721, 0.03322113218850323, 0.01144729373377881, 0.06222504709980317, 0.047819989533828836, 0.04437360500118562, 0.038751874518181594, 0.02106625450375889, 0.05726261516766889, 0.03007908078974911, 0.013360781146080365, 0.0616292729973793, 0.019550397094073038, 0.04195747411410723, 0.019382047466933727, 0.03307894517534545, 0.041053231206855605, 0.026018096200589622, 0.023724099920530404, 0.044390436062323194, 0.10390463737504822, 0.04372613670836602, 0.05415002915209957, 0.046323721430131366, 0.01476175494359008, 0.034384466907275577, 0.028483899243708168, 0.022139020064579587, 0.020184062288275788, 0.023272777441889048, 0.026743243182344095, 0.0379908432119659, 0.049445545699979575, 0.06787636849497046, 0.04504933088485684, 0.02921740916956748, 0.05168034149599927, 0.011577541075114692, 0.04637226043269038, 0.04374344952936683, 0.005271915146814925, 0.013419158906409783, 0.07197061487074409, 0.06468680607421057, 0.010221761102522058, 0.04510648388947759, 0.04743090398343546, 0.004080610366405121, 0.04627708571829966, 0.05314908482666526, 0.014841828861140778, 0.03584989220170038, 0.036716306781662364, 0.038492460402527025, 0.03800448515851583, 0.019901058902697902, 0.02753705281897315, 0.040265808281089575, 0.02391128398344985, 0.05422916669132454, 0.035057244556290765, 0.038491469741399796, 0.017875884626326815, 0.01830156526661345, 0.017647917216111506, 0.08933589341385023, 0.006643065633917493, 0.023392803501337767, 0.05744927336594888, 0.046658710776163, 0.008594254996361477, 0.03288532860044922, 0.022331579821184278, 0.04249058550755892, 0.01854386503276016, 0.02625495920489941, 0.08389803235019956, 0.03694082384130784, 0.03121289923521025, 0.009275280238528336, 0.06136267658855234, 0.002463977995960574, 0.031814641053123136, 0.03168541745149663, 0.008970116747410169, 0.014733512619776385, 0.029822173860988448, 0.11138927218105112, 0.024012389093903557, 0.06226301791944674, 0.041780413793666024, 0.074070755392313, 0.0602794157873307, 0.11547318446849074, 0.020904832719159976, 0.02678093240995492, 0.10019209408866507, 0.02883755848077791, 0.02426359972118267, 0.05875531078449317, 0.02102745756773012, 0.037828754766711166, 0.037026180153978724, 0.023275432210149508, 0.012601453810930252, 0.029678616207093, 0.02633710265425699, 0.08076248810227428, 0.027356443760384406, 0.07396955189428159, 0.05244593934289046, 0.04972388754997935, 0.009946721173556787, 0.03283170737060053, 0.04913922106581075, 0.026781848432230096, 0.03192148317715951, 0.032561110997838635, 0.008003010115187083, 0.022473380069381425, 0.02024664018037064, 0.055595865140536, 0.017345358451296176, 0.07197545961077724, 0.06466695892491511, 0.03427390980401209, 0.024835048343187997, 0.04500787239521742, 0.07183818519115448, 0.04955578389178429, 0.05079252592154911, 0.027078816068491766, 0.01920563854011042, 0.03388766392267176, 0.009839880745857954, 0.10047148088259356, 0.04555608797818422, 0.048568834351109605, 0.06306371638285262, 0.020175468642264605, 0.06681687677545206, 0.04741107040484037, 0.030074629600026777, 0.03589032271078654, 0.04870452778413892, 0.024145283569980944, 0.02236431065414633, 0.07292186668408768, 0.042857689916023185, 0.02530324598774314, 0.012671126634813845, 0.032225999515503645, 0.025690348519544517, 0.0342140121252409, 0.04055916950372713, 0.05677589521344219, 0.08135170077106782, 0.03110419792522277, 0.02462514183883156, 0.05244937951543501, 0.016066153700064336, 0.040151169789688926, 0.03717046044766903, 0.039483294556183476, 0.02282725983033223, 0.04448454886940973, 0.05231752659061125, 0.035407134531331916, 0.0334001195483974, 0.0807183019018599, 0.14595930145255157, 0.1407080918018307, 0.1629388803350074, 0.2003731687686273, 0.15479405809726032, 0.14786578129444802, 0.1740359134439911, 0.1328633041786296, 0.122599579926048, 0.09697460316653762, 0.18606886347489698, 0.1677011919340917, 0.133531905444605, 0.11679596134594508, 0.1659098459141595, 0.10671694789613996, 0.1033382099121809, 0.11963667534291744, 0.10802253748157195, 0.10744496168834822, 0.14970100138868603, 0.13311611275587762, 0.13497814855405263, 0.07525526040366717, 0.11424901229994637, 0.18752290973705904, 0.21187215245195798, 0.07963548893375055, 0.13681425074381487, 0.08906803492988859, 0.1361994030220168, 0.11305342002638749, 0.11344132492584841, 0.11445316991635732, 0.1755513128425394, 0.0782576489395329, 0.15428248340530054, 0.11267635811652456, 0.17096578675721372, 0.20482731690364225, 0.08078623682792697, 0.08652638524238553, 0.09042344934173993, 0.18372869119048119, 0.09178811218589544, 0.11616187037101813, 0.0813630051644785, 0.21406844817101955, 0.17133310490420886, 0.17571849030043396, 0.12385142275265285, 0.17664724189255918, 0.14909615527306283, 0.09719709479915244, 0.10601749364286661, 0.17212619020470551, 0.11861268457557474, 0.21337256979729446, 0.13612432990755352, 0.0904706482376371, 0.14438970067671367, 0.061661917317126475, 0.15453051509601728, 0.1960523934768779, 0.11336205846496991, 0.15372554186199391, 0.17675307978476795, 0.10516437156391995, 0.12375224807432719, 0.15318574011325836, 0.15773402819676058, 0.17068618961742946, 0.15198049907173428, 0.10203229462993996, 0.15265062025615148, 0.15402088101421083, 0.12139063408332211, 0.14318364539316722, 0.11842682026326656, 0.18403382838836738, 0.09029869389321123, 0.141624548339418, 0.10531336428331477, 0.13860672313187802, 0.05693561557148184, 0.14789962662117823, 0.11590602195688657, 0.1456137914210558, 0.0832087764782565, 0.177532825086798, 0.1369339171797037, 0.15095747182411806, 0.1606234067252704, 0.20376612884657724, 0.11014076774673802, 0.26190759614109993, 0.09387434952493225, 0.19108686063970837, 0.1611611321568489, 0.23739364583577427, 0.17342681969915116, 0.1779886106295245, 0.21274770689862116, 0.12360862935228006, 0.11497725679406098, 0.2410086632839271, 0.08303903415799141, 0.1115423021838069, 0.11574385208742959, 0.10347811704767601, 0.13343073587332452, 0.13840251123266561, 0.08300792332738638, 0.1916350626519748, 0.17613794707826205, 0.107182212573077, 0.12840621120163373, 0.10511004126497678, 0.10441452251481158, 0.13018211376454147, 0.11450259440711566, 0.12500234028058393, 0.15259640530816146, 0.12061235441693238, 0.1464393785489457, 0.1169827077537775, 0.1853124869189092, 0.1229984499514103, 0.13579750673047133, 0.11000553571752139, 0.19950290689510958, 0.12463306795273509, 0.05841636897197791, 0.08289401086845569, 0.17661022102194174, 0.12099826442343847, 0.12619840752865585, 0.06575066077389888, 0.07466196973941155, 0.22715067118406296, 0.0747026614844799, 0.18287258355745248, 0.11191289086959191, 0.18503884731658868, 0.1341805849224329, 0.10788684404854264, 0.13584017301244394, 0.14488668686577252, 0.15589503544781888, 0.1300522828740733, 0.13410591892898083, 0.16207230969199113, 0.1144962433193411, 0.1267329438456467, 0.15341793479663984, 0.09916887006589345, 0.07360030670783349, 0.08614004097346749, 0.10661452303507499, 0.11347208970359393, 0.11358856702489512, 0.1291244812309742, 0.13381855934858322, 0.14367900309818132, 0.13453661224671773, 0.07352378831378051, 0.07787632582975285, 0.13681619135396822, 0.10874430875160865, 0.09263559563883714, 0.13383037942860807, 0.2322570543204035, 0.16642375476658344, 0.12316834154937949, 0.09933887022946562, 0.1969441920518875], [0.07511386049113103, 0.025278221616255384, 0.04225516439016376, 0.037111146309013875, 0.025989998065467392, 0.045773734870765886, 0.04684308231143015, 0.022858475833865147, 0.058034706594688554, 0.01872142916545272, 0.05542173948405044, 0.021897583734244108, 0.010481825763625758, 0.04341825483632939, 0.053613097606492896, 0.00451956399982529, 0.02724885694416506, 0.026897879616756524, 0.01394444763926523, 0.0491206190282745, 0.053465397496308596, 0.03676954124655042, 0.05151894176378846, 0.03493108793294855, 0.0574508204257914, 0.05866849222885711, 0.016357031484533633, 0.03831042981307421, 0.04566527444071003, 0.03452551058892693, 0.061960058818970404, 0.05625244955133114, 0.06016182566859892, 0.009296306342418705, 0.03393246080460293, 0.03171566654262798, 0.04551103664562106, 0.011899248946325054, 0.007732579135335982, 0.013864236318373253, 0.05174650883834277, 0.019804498280531595, 0.03646232094615698, 0.012596615008078516, 0.031539505281086476, 0.05319805130628603, 0.09761378993945462, 0.02992597614814128, 0.03700703868110265, 0.06641063107443707, 0.028018166377608265, 0.05165757325344852, 0.060521618862237246, 0.016826268984004855, 0.017981795461050103, 0.022404941331062998, 0.056005008186080625, 0.06968515286488192, 0.06536706457180635, 0.034044361407203336, 0.04322914034128189, 0.0311967568871166, 0.018717118771746755, 0.058921762209917815, 0.01313180526319359, 0.05907861236482859, 0.0278679166720914, 0.036373412502663474, 0.01900022054490234, 0.06516811131898846, 0.008497888604844255, 0.06021753339362996, 0.03987506031990051, 0.014746063821283835, 0.014736805210954376, 0.04083359959934439, 0.04932697170547076, 0.01622073245900018, 0.05317074366446052, 0.038137895321207385, 0.06339602890823569, 0.048836543557367156, 0.03159919261400189, 0.051633400443409166, 0.011835060381729687, 0.023451009931574975, 0.017492500466427634, 0.016150856922779764, 0.0335448035704238, 0.009719725764755691, 0.04746499019009726, 0.014605741083089794, 0.05860104584800346, 0.02431076129765383, 0.021046868758276105, 0.010573856316373816, 0.0389697046152183, 0.045302244635032754, 0.004735606157087854, 0.09306022285350732, 0.03746041542451296, 0.013527770310507288, 0.042550937804792605, 0.08696153653519494, 0.037499858665147, 0.041797156645251174, 0.03544812483180847, 0.07766578319881644, 0.04785079163100038, 0.05999312150691237, 0.03400143388924854, 0.036564104591629336, 0.021788741628240262, 0.09353146542395864, 0.00842064926733396, 0.04240398408312883, 0.04327931122056075, 0.050848769689244885, 0.03668345890140959, 0.009380716946907341, 0.05876884077276502, 0.039239788694041114, 0.041338521255446334, 0.027522298074992638, 0.016213684176493968, 0.0060892385663464665, 0.07911878451704979, 0.07064971074994121, 0.05165185320324131, 0.014585663231887987, 0.017494692134537866, 0.06263729783573321, 0.01648659265733191, 0.02086885509613369, 0.0241261030813413, 0.007611351220735482, 0.05585387468870197, 0.05904058047703334, 0.02339729879583631, 0.057166432828775475, 0.03665362032396453, 0.0694761708644884, 0.032264794755194864, 0.0356258738652936, 0.03328903318781938, 0.023997118663308874, 0.028865273243614605, 0.03435657233265894, 0.031430291677159924, 0.026563969141404544, 0.0594040716865233, 0.07543233090213367, 0.03353625063651374, 0.06913954964173691, 0.05471849561269794, 0.05406586366838642, 0.019414749462157488, 0.01013974318214293, 0.05679438529270036, 0.04998994113079139, 0.09586010261305741, 0.004128274906958852, 0.05197524977847934, 0.03968570494492139, 0.030534109765929834, 0.03986748108374221, 0.046700898690947464, 0.04983001042689596, 0.01850972623963441, 0.030897896138152907, 0.021946148181866323, 0.14810231860194886, 0.008525231869758239, 0.03894780489749142, 0.09480868546026093, 0.03635923790612391, 0.058710072854799886, 0.015118761054639305, 0.046882403415760825, 0.004686561645939946, 0.042866890850876055, 0.03640309162437916, 0.07338710421962397, 0.04873755547617163, 0.036960626885827096, 0.005918450029899499, 0.06768755255533115, 0.017306668384532844, 0.07179689633526973, 0.03911519609391689, 0.0411926972945886, 0.034488340440605364, 0.018206097085827162, 0.08518625143915415, 0.046459811806146584, 0.02366870771428304, 0.024362116220540235, 0.03646949306130409, 0.03085126381899629, 0.010640362926226641, 0.02486214055014508, 0.03496402741542884, 0.0337617346085608, 0.007768762015205408, 0.044283166461225064, 0.03880090206595404, 0.04111402115917631, 0.01649111000421856, 0.014252558516870652, 0.008193997366886054, 0.03227204829454422, 0.07683049302015986, 0.04844494742740478, 0.07877763068037373, 0.0406099883839488, 0.04375161909099136, 0.022169817072738494, 0.02677744473995907, 0.031986486831946034, 0.004928888129403016, 0.026740120224920765, 0.0727763684200389, 0.0327279016907726, 0.02834229577066643, 0.04088866950145789, 0.03656688658520579, 0.058560693370444436, 0.04977606010756322, 0.024844842996182184, 0.04054725442879966, 0.03923403810975807, 0.02476964096006538, 0.03778784249776176, 0.06131483308438744, 0.07853865064680576, 0.06846736571086304, 0.020473228468160545, 0.023025286882849674, 0.024215778269405876, 0.026069953239389827, 0.026134771993383765, 0.040119648445397615, 0.024336398046995913, 0.06609077645199639, 0.0222266698256135, 0.049097569193691015, 0.02655938733369112, 0.018100820681346313, 0.02682810416445136, 0.03841524311740484, 0.031074243996824538, 0.038188103519912274, 0.03469885593014104, 0.07418894262186118, 0.03621949701170836, 0.030227313549923043, 0.048578059034688134, 0.048410681408963034, 0.018596965486982038, 0.02517861097918025, 0.04727549910811441, 0.020047921022134166, 0.010536322303648506, 0.04844842152670026, 0.031328331612582715, 0.04516434935586793, 0.06499068119696208, 0.01647269626014999, 0.02603205366592322, 0.03656353122953858, 0.005817655349216823, 0.01726106065325439, 0.04351876283596669, 0.029744936219815696, 0.05332009940009032, 0.02641323089067425, 0.05969516999487366, 0.02380925097635814, 0.02418111021896558, 0.027798146308798875, 0.00429730603770752, 0.059371250947671275, 0.01568717323243618, 0.025347327015229633, 0.033210879524371455, 0.029627715902669088, 0.0029635156887317343, 0.05518722760358027, 0.035454272359077416, 0.052284105348267725, 0.02279988772767995, 0.014597926056012511, 0.06278681981244258, 0.03227870133040207, 0.04479237985131996, 0.06212791481188365, 0.023516741315168992, 0.013207082786331219, 0.08642705450100557, 0.03809594489367945, 0.027277514870677675, 0.03404264132093106, 0.08013747592589684, 0.0578182064262884, 0.05751900640981538, 0.02658021666242608, 0.07581463110234056, 0.06752101970570427, 0.07220680612538542, 0.017031878665355698, 0.04374907797734652, 0.06694008516413824, 0.042778952712459226, 0.04835903471601861, 0.06537715438753366, 0.0028514240361151417, 0.014376172330230474, 0.047759040125778744, 0.007802195980080536, 0.03399013628118804, 0.04752854856529406, 0.023900810795437013, 0.022600929385849407, 0.03891653121848192, 0.0499512273153024, 0.043157127419752736, 0.034409531990864446, 0.042841018310614994, 0.009267067420296371, 0.03989807962040816, 0.06933211109467916, 0.05312915964584265, 0.044312631844409874, 0.012840326127064015, 0.01390772617222475, 0.06804666721395083, 0.014665569212021572, 0.029129739052483013, 0.044313364662230015, 0.03578936687803694, 0.02456598206689315, 0.02706527929486973, 0.061388135222452025, 0.05849634110927582, 0.02562993176148406, 0.023541662210066403, 0.03803720411711505, 0.022321720707363317, 0.010641729326120444, 0.029162912629544735, 0.05432436176176582, 0.07866946541305099, 0.14076549586440834, 0.14443163414086613, 0.1398468137319599, 0.13594309320407255, 0.1914485605167491, 0.09521104315561907, 0.14906562119722366, 0.16153172084263392, 0.08040353629205908, 0.0675328058589782, 0.14204663783311844, 0.14848381813083375, 0.16474390562091554, 0.1785050436322178, 0.13029678618269308, 0.10190236195921898, 0.0853796067780682, 0.21176406182348728, 0.1298592532319682, 0.13816377547170433, 0.12150992053960051, 0.17586098265435013, 0.12562405477677072, 0.14938065143568174, 0.13384409940668515, 0.2078295222350529, 0.08209074754267931, 0.11817956210247108, 0.22686749137938023, 0.08335440366395883, 0.16958214528858662, 0.08524336373167378, 0.11655365649078574, 0.08706146438739129, 0.11602503699915749, 0.11026734845446688, 0.18663561663457326, 0.18439556897750922, 0.1337566633841821, 0.17077277068580898, 0.09604643511452846, 0.09231084877891199, 0.1172205749899149, 0.05139042044590626, 0.2369817207966532, 0.10954156704246998, 0.12599259428679943, 0.1467239289943661, 0.15506239155573504, 0.16830046049186162, 0.1605118148561035, 0.1347735838166305, 0.10513214115053415, 0.11750517971813679, 0.13305911581431115, 0.1857638619840145, 0.12489876869533743, 0.18718528428247996, 0.14831475434558733, 0.22305024335426943, 0.1530279400093215, 0.12419501931539603, 0.1061087226761239, 0.09304359874555043, 0.05747874892715897, 0.1367220106933798, 0.0962195633245366, 0.10752462169953755, 0.09890042804181576, 0.2259570195206574, 0.06956030242145061, 0.1334346713764327, 0.19311527322445596, 0.13453494305057184, 0.13762808564518178, 0.09016641349132572, 0.12318146441664014, 0.12048478983342648, 0.11331019124814443, 0.17164924794009753, 0.12097334861755371, 0.08765438864273684, 0.15356224562440599, 0.17117624117859773, 0.15951257704624108, 0.07683068979531527, 0.07764335083109991, 0.10621037400726761, 0.13027394669396536, 0.17021825829786913, 0.15429160291595118, 0.09262797569057771, 0.11986967069762093, 0.07144823790128742, 0.09116001267518316, 0.08743560859667403, 0.1707183928894145, 0.14137596024998597, 0.18429039604961872, 0.2316562794148922, 0.1485674814986331, 0.09402202588639089, 0.07142531020300728, 0.17203300020524434, 0.0998814200450267, 0.16080557980707713, 0.26437184533902575, 0.20115450184260095, 0.1475503303642784, 0.07738763812397208, 0.09122316392936877, 0.11171379512442009, 0.09561424901975052, 0.1633884369262627, 0.04893186076411179, 0.10414655546524695, 0.19177532941102982, 0.11402688707624163, 0.13714846995260033, 0.09355196396687201, 0.18929558247327805, 0.08338379101561648, 0.11236332277102129, 0.08876017002122742, 0.11812017671763897, 0.13045962101646832, 0.10160341300070286, 0.1478346772491932, 0.15388718247413635, 0.09437187854200602, 0.15544368752411433, 0.15734951597239288, 0.16994604361908777, 0.1330951867359025, 0.10400689260235854, 0.09240550441401345, 0.13586105832031795, 0.1448706327272313, 0.1122204436521445, 0.18078048367585453, 0.1073356361261436, 0.13992468241069997, 0.17733389219003065, 0.1236608222659145, 0.09546664051179375, 0.2188957091420889, 0.0846183786966971, 0.15855246356555394, 0.09896465138133083, 0.15659613854118756, 0.1491438698555742, 0.1421585011162928, 0.12052293707217489, 0.14207643909113749, 0.14302323971475872, 0.10381950158625841, 0.15394838633281843, 0.10108769924512931, 0.15079834179154464, 0.19941196963191032, 0.12413233625037329, 0.2314798060272421, 0.116944302671722, 0.07627077626862697, 0.10373441329491989, 0.13117889527763638, 0.2279449099940913, 0.149166967187609, 0.07291350034730774, 0.12078747073454515, 0.059214353295309205, 0.144785734425698, 0.1120146100542375, 0.10518516187689134, 0.18242635178778852, 0.11509275702493531], [0.008900661054732544, 0.07755461880671126, 0.020648093727816428, 0.03534224283482347, 0.02976955347029226, 0.07483373409403221, 0.03378286758171661, 0.05598685737433178, 0.047740030967231305, 0.020685472525656223, 0.01730990669290934, 0.004607389331795275, 0.03301505771066461, 0.09580075794032641, 0.018469136274818863, 0.024996466735111814, 0.033992351698023934, 0.019824559168357934, 0.03170704236254096, 0.06012672505208424, 0.04028261898617659, 0.009700166992843151, 0.034389196296355555, 0.05644114335466709, 0.0397527204560382, 0.011463792312757244, 0.021103173594123552, 0.026990955961602073, 0.023209417538185204, 0.027561245985063057, 0.02977703431887286, 0.04700071278161236, 0.024487331376544068, 0.01128609841024237, 0.04722689225205353, 0.02125238174838679, 0.03679900662973523, 0.024203500178243433, 0.006089721598462867, 0.015235002585021513, 0.00672774892466675, 0.093522854814572, 0.04448156670800277, 0.04053185507655144, 0.03708429667832596, 0.022543096149872457, 0.026941865649340407, 0.015493208908342888, 0.02327576808498374, 0.02510051159853382, 0.05118714153234448, 0.043753763261650286, 0.04000859601157052, 0.08000989777169057, 0.054948966817132065, 0.028591372405311892, 0.04756029721881662, 0.028955202882311175, 0.026133713478754674, 0.0034149787513472673, 0.03354629974013992, 0.01914997661619314, 0.016914870390402417, 0.025148428045213223, 0.008224263421392866, 0.04588464820491416, 0.012013077436547195, 0.04746024723031691, 0.023231983916567903, 0.036119755756642134, 0.04891846648284367, 0.03744954868618931, 0.026124617716829692, 0.02675862896389195, 0.032556958363524506, 0.03736412112734147, 0.0500703136037503, 0.05968980278287615, 0.030665362187262093, 0.0633782445053969, 0.057915983322475634, 0.014486264637006181, 0.03356191961626921, 0.040951498451509645, 0.03369558422959276, 0.04146462020331195, 0.04146925459748932, 0.008170355510498797, 0.03888162398444755, 0.021731758257374167, 0.029014903785926954, 0.09340139026088373, 0.05086701210322125, 0.04798040199758751, 0.02363990051006632, 0.03471163274454219, 0.038890631536820104, 0.052355795965663025, 0.10248076556516544, 0.041826055451695404, 0.008989933362629796, 0.011178732117904084, 0.031242293372218097, 0.053753252407269816, 0.03696693726150053, 0.015902865944164138, 0.05328835753191795, 0.017632063245400786, 0.05060837830283812, 0.015583667804354003, 0.0191260005813092, 0.013637723517604172, 0.0706403266106333, 0.02845867470438991, 0.03477111312427691, 0.05862379712717874, 0.013530518377332814, 0.03572803409770131, 0.025201094237023165, 0.0223694217191743, 0.0456346691186939, 0.01002483582124114, 0.01904896310796695, 0.04989873584625976, 0.015129670201401626, 0.025887220366192714, 0.050241521559655666, 0.02925460985196488, 0.0481600339657494, 0.014093764359131455, 0.05265525721811822, 0.05115543019824794, 0.05953914086733546, 0.03916284282292638, 0.05418405768328479, 0.04829495047618236, 0.050913926014410596, 0.026807105201961737, 0.06708555628678628, 0.002022124685546649, 0.00962480210832187, 0.07377128396183252, 0.03396439266258052, 0.012313386857775705, 0.05861667250948293, 0.0036782454616124077, 0.07889636073793684, 0.030348211526870728, 0.009494827877330993, 0.009997128691923405, 0.04556740254962018, 0.058202345456395826, 0.03238107530134065, 0.008838970347174575, 0.021824315522930453, 0.0087346481325637, 0.05298009228759578, 0.024916268984920213, 0.026802508127210394, 0.051488936945263825, 0.023786328367090652, 0.0356463588375066, 0.01916725211776793, 0.021233284380286932, 0.010663042959224964, 0.02512134940895651, 0.007567272737755307, 0.004802820987866393, 0.016988545722727264, 0.015871000243350863, 0.07916947786829301, 0.027357678694118346, 0.05880144438041108, 0.011377782910130918, 0.023945329478010535, 0.0204258599385087, 0.03348158107006124, 0.04127508501655289, 0.011612811325384038, 0.016668336565739343, 0.0514440179270293, 0.02276226126455835, 0.049882912409624884, 0.011849980518620993, 0.03847389229174171, 0.016781156583290015, 0.05686673748173884, 0.043198524841240475, 0.02910741525036948, 0.040844656327473264, 0.03551747450338943, 0.048273851429777484, 0.0702567779059921, 0.04411279310339263, 0.004658569107829992, 0.045109242134328396, 0.005233422279291387, 0.01055960453647588, 0.07733352495623486, 0.0395629545673728, 0.031134667540235177, 0.017453686567023396, 0.09659210619117532, 0.05330429292683091, 0.061614236661366055, 0.04161843391401427, 0.037740192376077175, 0.048821442760527134, 0.02488460684461253, 0.04534676331760628, 0.0036018441148501423, 0.009730383005392338, 0.05012358199538929, 0.03436578683821218, 0.03527343259858234, 0.06987791787832975, 0.009789057624792414, 0.04012902579935534, 0.005406200195596154, 0.053594407359404225, 0.03926794450463993, 0.07287914611931358, 0.05117937909173114, 0.014974323001557162, 0.047726321167179515, 0.01590806182606944, 0.029671057326985256, 0.030648140968488793, 0.025720755370067697, 0.04099052439310721, 0.02242780796119145, 0.027739868632384708, 0.03451228594141347, 0.032817363140306303, 0.008249073206180972, 0.021538311316232597, 0.06403432680027825, 0.04144734809441226, 0.018014614503564577, 0.02565279839161251, 0.027404984459280968, 0.024351661692240407, 0.001752908283378929, 0.04806323076731392, 0.02868421295923846, 0.02474108481380556, 0.009675444569438696, 0.043353631161153316, 0.01455145319258528, 0.04206068607579384, 0.04716640424781612, 0.03064224449917674, 0.07934323711586849, 0.04062783046226416, 0.10690834226885013, 0.04549186124599405, 0.01868925812388105, 0.02780911313103778, 0.06812055289213147, 0.04798295668193272, 0.048283018437879424, 0.03655243378930858, 0.043662286563111205, 0.03393290185236505, 0.03252583735489419, 0.033932152071169445, 0.0748895707407168, 0.07540356780269317, 0.02185376563907734, 0.03208638754274164, 0.007395058005516018, 0.05163638599749122, 0.01012324629950204, 0.029777712853891507, 0.060390905876244814, 0.016148672040019716, 0.03882808417880109, 0.03557349435452904, 0.03861633036285639, 0.026240263832733035, 0.032761842012405396, 0.06424257598285164, 0.04857528382646186, 0.012264824106491037, 0.030205770063080957, 0.030446571963174, 0.05280169864584293, 0.044262535603983064, 0.0531045356100159, 0.034725932870060205, 0.05034646378563983, 0.04091854200565389, 0.019595931882836988, 0.03705263284168073, 0.02297388106983687, 0.05090350032384906, 0.036191507442189116, 0.003127938082408426, 0.028427536732384136, 0.05032185332051345, 0.014259498233773878, 0.01090778545143881, 0.05329608943845544, 0.02722113369964063, 0.06351357831486634, 0.029597307355808358, 0.10765947374914374, 0.03698474541306496, 0.03637318858610732, 0.09582469665578433, 0.04324021742546132, 0.02568237403673785, 0.04708058653133256, 0.029087693630052463, 0.06028748356870242, 0.018392103890489255, 0.03607745588357959, 0.08695903952632632, 0.05292630820934262, 0.022127479880249927, 0.059626889015947065, 0.0400493182907147, 0.06904108063983065, 0.028143391711637378, 0.01077824378652232, 0.030793846185718263, 0.09716597718319722, 0.012956163080941354, 0.018114404952419654, 0.03693570090191705, 0.06609669327735901, 0.0005201073758403904, 0.0543632791377604, 0.03896478862900819, 0.0065214780957571095, 0.047747983397649865, 0.03558858158066869, 0.03427246791709747, 0.04383904154279402, 0.03158224280923605, 0.023333374011729444, 0.038758130611053536, 0.019491093133443167, 0.0334236138234181, 0.03955190123191901, 0.02968566957861185, 0.03598714965794768, 0.013597028379860734, 0.03410833029608641, 0.009963441124585058, 0.03791383966537459, 0.03306950336056096, 0.093345838598907, 0.21145443272377762, 0.053556874194847684, 0.1117685189736741, 0.1788924599864653, 0.17337024344929627, 0.09786520073456423, 0.1467854721205575, 0.1469067127576896, 0.12352337821253709, 0.10102587113423006, 0.112901855659272, 0.07371820895267384, 0.14144248382321425, 0.1070165957457253, 0.13724691181310586, 0.19742686115205288, 0.14453407935798168, 0.08019816409796476, 0.14797121206564562, 0.07788390506591115, 0.10271487371729952, 0.1812165238495384, 0.19169030897319317, 0.12056151857333523, 0.060524522992117066, 0.20441550043012413, 0.09880548742200647, 0.13389213968600544, 0.07322073421840157, 0.1302179946963276, 0.1342600006610155, 0.11747031658887863, 0.12943822225289686, 0.12273639972720828, 0.1522173485053437, 0.12398987103785787, 0.17175690430615628, 0.17910476002310002, 0.15814747315432343, 0.06225713502083506, 0.13662550944302762, 0.12671079646263803, 0.12918022966810636, 0.10002898784088236, 0.1056982564872929, 0.1528667743716921, 0.06654318289033004, 0.09914003911295108, 0.139573744099055, 0.1600991298577615, 0.19555348024836608, 0.10408572480082512, 0.11643086879381112, 0.11646996598158564, 0.11724112103027956, 0.15005751725818428, 0.12928936524050577, 0.1204388394419636, 0.1441165767610073, 0.16503266298345157, 0.07431306703282253, 0.12506745250097343, 0.1328694381351982, 0.0835397115775517, 0.15726106214736188, 0.0765225263312459, 0.11877414876861231, 0.09303599915334157, 0.08024655721549477, 0.19347876443394593, 0.14822106223021234, 0.13582069905740873, 0.07761123576866728, 0.07820118804063116, 0.14389074673610075, 0.1572389690471547, 0.17071509520922387, 0.20502566626029356, 0.21270749691341603, 0.14265574514865875, 0.08459456211754254, 0.17778878206653254, 0.1150011412267174, 0.11079004433538232, 0.07141896590058293, 0.127929350361228, 0.11956013659281389, 0.14656159627650464, 0.1476354729384184, 0.11938303895294666, 0.23396449269992964, 0.18597324432006904, 0.08975522805537496, 0.09728872416807072, 0.25282904186419075, 0.1535367462784052, 0.08916105529559509, 0.22112287820449897, 0.07496684230864048, 0.11986222038311617, 0.12459093092807702, 0.14857575962586062, 0.19011384142296656, 0.08091359785092728, 0.13106476568749972, 0.11450191587209702, 0.10073009771960122, 0.1603619943239859, 0.08960622176527977, 0.06702619804335491, 0.07768564391881227, 0.16640874557197094, 0.1083137918529766, 0.1152459838028465, 0.18299610407224723, 0.09740664676896163, 0.09680701180228166, 0.11843405344656535, 0.14323325987373078, 0.1795437993215663, 0.13343183510005474, 0.14174601967845643, 0.09794374794832297, 0.24094876221248082, 0.06773709918239287, 0.13030842984361307, 0.12021756917238235, 0.09682763926684856, 0.15614301285573415, 0.1881222461483308, 0.17518783520374978, 0.17117833106645516, 0.2362595966884068, 0.09391671046614647, 0.11564085047159876, 0.1403692178428173, 0.06157477306468146, 0.15747748767691, 0.09781304174768073, 0.13688765466213226, 0.23719670783196176, 0.11759969964623451, 0.1294553620474679, 0.10734472171004329, 0.09367992888603892, 0.2251316359532731, 0.1629824965660061, 0.09756511862256698, 0.19790957096431935, 0.18672854879072734, 0.18977924223457063, 0.13649095594882965, 0.13271626564008848, 0.15999528685850756, 0.09828781270022903, 0.1319845606173788, 0.18377274168389185, 0.10913083622498171, 0.0849549388512969, 0.13316526583262853, 0.1594252088772399, 0.08574516751936503, 0.0962762413546443, 0.1314822682844741, 0.09198040222483021, 0.17224369889923505, 0.13014636853975908, 0.12327462727470057, 0.12291049824229308, 0.11588877359671251, 0.09713023874376502, 0.15227969230285712, 0.07121552753129176, 0.18191848189703055, 0.1376557970153434], [0.0544399909142937, 0.04962234139176352, 0.015862907016915933, 0.05144247765253697, 0.038579753932676146, 0.10614619816520385, 0.08084349839815072, 0.05796207620629242, 0.03296309889161161, 0.04435285200764026, 0.019313260979418243, 0.06923678370990924, 0.016185153475297347, 0.11923494189977646, 0.034417145153773684, 0.04949307029268571, 0.027408806307773505, 0.04913124827934163, 0.0157966803027583, 0.009877761659611548, 0.032092484179884195, 0.022512845362403562, 0.031763995199331214, 0.04367802518286875, 0.040366251819900105, 0.04099391706820045, 0.05227327932204519, 0.1178161251757826, 0.0304451673956854, 0.023076039605907032, 0.04174702987074852, 0.0254509885063661, 0.06068498295332704, 0.10763446294835635, 0.027537761888067638, 0.01441897771188191, 0.017626290608729635, 0.02372919232584536, 0.059805493003555706, 0.06951843002544981, 0.07138946998332228, 0.03750596548031483, 0.03406649861218674, 0.045420255445476086, 0.005964296944772026, 0.015228887288165944, 0.042054501229098866, 0.014690578316471406, 0.0022666659497190267, 0.00618466264235654, 0.02172190592890339, 0.07628007219838244, 0.017907894515831555, 0.04351141769438982, 0.023391916316800883, 0.046760524955711195, 0.022028936239491616, 0.036547717970928977, 0.058126899147672315, 0.011155641571219479, 0.0517626070816602, 0.02180275846538799, 0.041675166226923466, 0.13094184228352138, 0.06937148648181132, 0.03278033548433866, 0.08092212025076151, 0.02970064484647342, 0.031199491383241754, 0.06912029281790767, 0.0450749998646123, 0.04468122224456497, 0.0923003518421735, 0.04179351969755121, 0.04307790845632553, 0.004599823242252958, 0.03300177878034966, 0.0523843724679734, 0.059936015999742916, 0.038633517654878755, 0.033633908789072714, 0.029627369849809577, 0.029913535208574364, 0.015873018885031343, 0.025421551960919584, 0.03534557444176503, 0.01664847754208105, 0.03671889200008341, 0.026543787813612392, 0.06633107284350054, 0.05766467430761882, 0.03527806020740952, 0.06995535229465791, 0.02806966718552368, 0.016288071970588396, 0.02315230863834066, 0.013150535374214607, 0.047311291830348115, 0.06677809849913631, 0.01630224147811532, 0.03900995191984943, 0.036405999146934064, 0.09072275113846574, 0.036057819080139906, 0.05156411862533007, 0.02590662646772606, 0.08361804166010448, 0.07806459215602704, 0.06835507495062691, 0.012868255476600357, 0.012124938175215252, 0.06477587058075837, 0.055893602914043834, 0.020421895597662245, 0.03533471788146666, 0.042036238459071944, 0.011807471996040216, 0.02576963703281113, 0.03149476607463189, 0.019078350459624614, 0.016342636364113008, 0.023536707208092724, 0.07744121524904456, 0.04265860095620155, 0.017606580862775445, 0.005947119406690555, 0.08007266904626574, 0.029364386639956917, 0.023558980120079856, 0.044441492429801395, 0.020812029484659433, 0.01208833884447813, 0.020995815783472996, 0.022330446667703133, 0.04647596772494061, 0.04064887861854263, 0.02880840522370168, 0.04894402011164597, 0.04758505356897201, 0.03851140510024769, 0.033786019376878224, 0.014932440427531089, 0.028930154762097766, 0.03483442044151681, 0.04452162741550377, 0.041830282724861584, 0.08471756016037293, 0.012461757869459689, 0.025293151083003198, 0.061237520804362636, 0.05070005177653261, 0.0199955669564328, 0.03262124616386635, 0.04134657546611769, 0.03476794097306473, 0.031663724686950445, 0.06649162101426295, 0.021590768858524303, 0.0547803644356983, 0.01882493798620999, 0.02733318697262023, 0.04547900640006576, 0.019020524008997848, 0.029386069226477827, 0.022679318840216314, 0.033170991843300204, 0.01497097103856504, 0.008943497818628592, 0.037077270448207855, 0.014539589007784213, 0.04370888834819198, 0.061653802038303444, 0.08859487210533448, 0.09739708621054888, 0.008445338612156255, 0.024329612696809427, 0.020891499506043534, 0.020705316282276596, 0.054727805113153796, 0.030932168941944838, 0.06440874242356845, 0.06543732687298741, 0.01805768451387329, 0.034859929965542893, 0.010375372100887554, 0.021915933017485907, 0.026624021186892475, 0.06940468041492359, 0.019506633281707764, 0.052099218126386404, 0.020246216095983982, 0.033778368894542964, 0.006493725589410002, 0.028378312409456288, 0.03320731043017336, 0.04068629303947091, 0.015372923309249538, 0.017919144626440744, 0.01624702738731035, 0.0678355817549995, 0.04856708712343659, 0.032731535245797465, 0.06537657763276782, 0.09987365081906319, 0.014858790540269442, 0.017424182168075016, 0.026603980655116693, 0.01785216304207487, 0.029414089330072914, 0.04115745757839509, 0.022555191036579863, 0.05567892461216875, 0.03999429249337741, 0.02559007122181356, 0.05125999922997185, 0.019282837165519595, 0.09153294230678252, 0.02103415470836418, 0.020419953291171362, 0.012918473853330528, 0.029931119443582635, 0.019257660123652647, 0.05414351860859564, 0.01162945239671639, 0.05366505642554589, 0.012019883990953011, 0.03432718837367637, 0.05175088538921305, 0.02477210234584553, 0.057654211297631264, 0.049329163373581, 0.018907520786992142, 0.034998178082917414, 0.05321874323167971, 0.018681022405092205, 0.04288183558466179, 0.02905190090781876, 0.11205305584839412, 0.021737473218568733, 0.14658588783017226, 0.03259278840518423, 0.01603616414857762, 0.04081919090822339, 0.023040670968059982, 0.02994749927893281, 0.03411261524472918, 0.030280744789966514, 0.0042745488213508254, 0.04734214821032115, 0.04305689422679799, 0.03697366154353533, 0.03597289024453078, 0.00731627075999443, 0.014029464684426785, 0.02080854690367622, 0.01910396515657859, 0.06552740239671298, 0.016552103517044867, 0.0540872612701995, 0.03833461619381394, 0.03948597816218223, 0.09582983995122568, 0.03989636631948607, 0.016148538029353534, 0.026083069321300303, 0.05097491613456181, 0.062018019280263355, 0.011714684028577591, 0.0732489273484264, 0.03860526345670223, 0.014959561472226466, 0.01538280617179615, 0.003775167403676148, 0.05494377263156431, 0.06962078703301293, 0.02198155244280185, 0.03827187545331461, 0.012684867817110248, 0.0080308639777026, 0.054086637017982345, 0.0900115514440196, 0.04693885752931237, 0.07861862956945385, 0.02455689987566854, 0.051215019143585644, 0.034823075336005004, 0.06187343703848975, 0.03330425612096276, 0.015949854494205544, 0.05983986080225025, 0.06567093969455787, 0.028629994618573358, 0.006727095410626913, 0.039265773192580254, 0.03820452067468848, 0.035444922146520445, 0.05739737222237246, 0.01829481214684035, 0.029031666993562664, 0.11694371913160596, 0.031027486148689474, 0.012411991566685694, 0.017352218440334712, 0.012104505789466202, 0.03426272415422967, 0.031826440777097426, 0.03556573869926589, 0.020234733587130904, 0.025668077303894928, 0.015129453070195658, 0.03765377076342702, 0.0497618651549731, 0.041795229605798206, 0.04386210494807788, 0.09150204182203327, 0.033124895566808324, 0.042494385303663354, 0.07314918270068509, 0.009784564026631415, 0.02096667609709714, 0.009168876617747759, 0.02589453836636884, 0.08852114249020815, 0.04486291017383337, 0.07192041685006448, 0.03604007538940225, 0.03294666477345994, 0.03136094200557896, 0.038278016195233376, 0.043321224328662665, 0.010634158571649874, 0.01835167677407818, 0.029062923709196702, 0.004506733750791422, 0.015550886081265551, 0.03948902817709105, 0.05963335545467479, 0.010719536936708858, 0.026482482174677507, 0.020730160841984407, 0.02376369752788118, 0.02864709709371839, 0.03379010415769049, 0.027267766018797244, 0.02275269222445786, 0.020152077843834246, 0.05277824169024825, 0.019520614495767013, 0.08841377110885722, 0.0724946271095957, 0.0625215804736529, 0.027701901205416237, 0.14526321951832089, 0.12490222922393254, 0.10800756221371037, 0.15915887031172002, 0.13276133393602713, 0.17385987431875297, 0.22188028613371508, 0.13869167571621283, 0.14879318938723632, 0.18148789714489663, 0.1058428455144167, 0.16855667531490326, 0.1445562538823911, 0.1619347706437111, 0.11453824463699545, 0.1523315052368811, 0.10066240028079067, 0.12178265090499606, 0.11796709921743188, 0.09609162554677043, 0.08594477216580085, 0.12559698122952664, 0.12713675360594476, 0.11638744255261761, 0.18196981985654148, 0.09121688748044626, 0.09005455020815134, 0.19746662330414566, 0.11532956574644361, 0.07042966184339353, 0.13605202521596635, 0.09681653843394347, 0.12490901457411901, 0.1614274707223688, 0.12785932554730348, 0.10719152885888304, 0.11250555728163038, 0.10109502742333071, 0.19980870905731404, 0.0918586662571345, 0.1909171183194433, 0.16688700419451508, 0.10847499141735689, 0.15946001772369656, 0.1768164142434086, 0.06618212083620684, 0.13910820122276032, 0.12277926956968647, 0.16626420404229844, 0.06965795039598431, 0.0856348852227841, 0.22290563397109509, 0.10232738950955016, 0.1971891839057207, 0.09358930374894824, 0.2102124829377447, 0.13322284631431103, 0.22383576977465833, 0.15173185669950076, 0.12111571883516652, 0.10242313080068145, 0.18412381570254052, 0.10102739105267183, 0.24406090378761292, 0.16439402582389967, 0.10098918953112193, 0.1247717197984457, 0.12519520707428455, 0.07919295517993824, 0.1515910742538316, 0.13621609498347553, 0.07384145126811095, 0.16256807451801641, 0.13859780718173298, 0.14075606422764914, 0.1328296081296035, 0.19307670529399598, 0.15083662473729678, 0.10517481421785695, 0.145844520468797, 0.18097340475235665, 0.09003252496144601, 0.2482288729931627, 0.15491941065660544, 0.08499070443212986, 0.161832596840603, 0.12126709999782698, 0.18425805707062992, 0.10237261386854307, 0.14804038192544663, 0.19348801965160028, 0.19183175638318062, 0.19893510879150458, 0.09265637238110815, 0.07679586737815823, 0.13787872291037015, 0.06758395382868392, 0.20579075520592077, 0.28091545190129963, 0.08590534249586718, 0.0870349540242127, 0.1475324034690857, 0.14818386494049005, 0.1511818633547851, 0.18269802363855497, 0.21912855521908828, 0.12910578080586024, 0.12348023695605141, 0.3050209784082004, 0.10493208188563585, 0.18879795846130165, 0.14598089243684495, 0.15484897872166975, 0.10406395739742688, 0.1601850866739239, 0.07643312934253897, 0.13333989360502788, 0.15933102821665152, 0.10926385623003755, 0.14187095154608997, 0.1436287100825991, 0.12348417245915957, 0.26725363784602707, 0.2500236252588885, 0.09564663549619061, 0.1337680220603943, 0.16396729515067168, 0.08838638543550457, 0.12568056317312376, 0.08577557945890085, 0.07541073313249008, 0.12737786423947128, 0.12089002451726369, 0.12056823607001986, 0.10953546701265232, 0.1191984231450728, 0.09098158510667936, 0.13522132193403585, 0.20876158507806913, 0.11053435198430504, 0.0895008792036346, 0.10280311719647475, 0.1315937108759369, 0.08050194422581367, 0.09995864411549908, 0.10280361252703837, 0.14960580292556966, 0.053340075471039326, 0.14732657665652887, 0.10056329345596687, 0.15004595502146653, 0.12789346942944185, 0.20722675243658678, 0.14619530950273785, 0.12256135126309735, 0.08049798836665494, 0.152735491416284, 0.07820690809083836, 0.11479735001921654, 0.15425056511802332, 0.15461830395673, 0.11661338114312716, 0.12424493235136781, 0.1549481533999954, 0.08691272951130356, 0.14273138823253767, 0.10224459466657468, 0.0960892371035048, 0.11538851686886378, 0.18841336481273174, 0.1617134189499276, 0.16583075587238583, 0.16155067911105497, 0.1862383886639561, 0.1965235953352281, 0.0785499278988157], [0.018505614317421402, 0.017103766057906405, 0.04705577589837568, 0.021132890035265257, 0.043286015146545, 0.015040441150111812, 0.03437937789463571, 0.03806563473439642, 0.024119606108537743, 0.03564717647220407, 0.061763575433620384, 0.03599193672250424, 0.04640131190951381, 0.018179590115323663, 0.0676268372418625, 0.05382010167730706, 0.0217291068817888, 0.03763379129980292, 0.03702519288552659, 0.041579302799488814, 0.0452471000940672, 0.029549521527120044, 0.03251999516838363, 0.0829304007015058, 0.029122892634144852, 0.028841561837387935, 0.09545685603682484, 0.030175473474498306, 0.031248749632920538, 0.036010545545390675, 0.002784071165868746, 0.0413016394845077, 0.016029636641698222, 0.022355708526447415, 0.11142649661217417, 0.012753503330584084, 0.026934537471139004, 0.05523200752213597, 0.04029960271769336, 0.01798984967172146, 0.016599254915490746, 0.05416905866669757, 0.06762582622468472, 0.018250595412350128, 0.02529102048304464, 0.0737999656370708, 0.03925520161698971, 0.03792937133195145, 0.07245701591351203, 0.04317887107442532, 0.04715022797297154, 0.025255902903154492, 0.0692602949483054, 0.029686158123825277, 0.024962553554879766, 0.04441265129883375, 0.05451155261003545, 0.040568533286984475, 0.02437697274477354, 0.027804502485586063, 0.01624332937145872, 0.0036767853390691535, 0.029427392009113516, 0.030030551965215375, 0.02767295659785824, 0.020020325002925735, 0.029439877053456645, 0.0683269225327032, 0.027874576493299434, 0.09714830134596143, 0.043949927735541544, 0.03635957717363324, 0.009832034336536058, 0.03266249430764999, 0.03791596347998295, 0.010241497989876993, 0.049065674655139446, 0.02846106654033065, 0.012784398726320692, 0.018164521548897028, 0.07105434832296201, 0.01947756314517132, 0.02158508443140558, 0.024164007743820548, 0.03404497548139521, 0.04951037632833634, 0.01899268541352025, 0.029162556398659945, 0.03586739840518151, 0.015818200040874735, 0.04499365030122655, 0.016865812308554138, 0.06258332716034991, 0.023527884556512748, 0.03160116375823106, 0.03362911833184106, 0.01665519843144076, 0.03929358973566975, 0.042452665578041754, 0.008181557275487908, 0.00645430016032021, 0.0784609651725207, 0.03284354441400085, 0.055813668096171956, 0.02494214491785637, 0.02795049947287355, 0.02196565775999001, 0.037940702866762877, 0.0438335284457675, 0.05999313507761274, 0.07156912570020982, 0.008396701222019536, 0.01437845899324332, 0.07006038273019449, 0.0016979801314716625, 0.016135131873722588, 0.06129867716559342, 0.03537052756707583, 0.02975954847144229, 0.014789632554831249, 0.0157641733863524, 0.07855945453047752, 0.04343196124370609, 0.010591091954016259, 0.05960119968014104, 0.054915399689759524, 0.04208461122055139, 0.04872663784772158, 0.03664191898756793, 0.05633708322420716, 0.01351457619706967, 0.01527965527826122, 0.051656680979899, 0.035317069185631614, 0.0415318698090102, 0.030246553410376822, 0.021486099742885147, 0.015119129159886922, 0.062498713843524456, 0.04640800905014787, 0.04473934216158731, 0.03702130487986973, 0.05396394431591034, 0.08242655452340841, 0.034674839183155975, 0.06137681047299078, 0.004497982345388404, 0.05922395456582308, 0.08642474748194218, 0.026970594822029983, 0.022082252128581916, 0.009538752841763198, 0.0210361021038677, 0.02336490383770849, 0.036560471036604474, 0.019551716844684312, 0.01630197006410786, 0.017818110762163997, 0.061640054918825626, 0.05868388818843024, 0.011222474726050027, 0.024392663867079785, 0.022712161631456444, 0.02259812703622239, 0.018097444969628538, 0.03292647835665515, 0.05394812427195055, 0.06867141476167099, 0.026498655056846992, 0.03262513077684811, 0.049525561942053695, 0.03856867006314652, 0.009672847476654818, 0.054564318885760646, 0.05386666275028672, 0.048582893596696, 0.004779705844287361, 0.015449116006493568, 0.09091406408697367, 0.07035863279764142, 0.019447707604350786, 0.03490790239136134, 0.05069738174123423, 0.0023569997408360776, 0.016958815710885183, 0.015462138789838977, 0.07387718970754317, 0.004840194272609162, 0.009625579030918223, 0.020400509870211993, 0.0548074278049171, 0.06758405560893671, 0.015992620860093405, 0.037075662320213656, 0.011272720244180943, 0.014540089427360466, 0.023666638182476163, 0.029073084771100963, 0.006955644664620715, 0.006448516497455005, 0.004253140193343694, 0.035087812558880875, 0.048892288601824214, 0.03291747758963278, 0.03882055922544428, 0.04880968374865396, 0.005403781642339059, 0.006440329124286238, 0.015697168053260872, 0.036468678819281716, 0.04187589045614004, 0.03959348525053688, 0.025338641766990935, 0.02750557897213314, 0.022721021602462445, 0.026470845299107686, 0.03650207631289959, 0.02538037675965045, 0.06933751223342759, 0.029967543203383684, 0.05046654073521495, 0.02763903493593846, 0.06419529566275221, 0.042111087656979046, 0.08852724252002579, 0.019631709338032773, 0.061461769842675755, 0.049961951561272144, 0.030162632199270383, 0.022816618704902272, 0.03156170355422156, 0.01603018625506333, 0.04205950881753649, 0.04238019125269992, 0.056935819131987433, 0.021119702707177827, 0.034495319173272164, 0.027473382485498275, 0.03288255678489804, 0.029123428676809584, 0.06473960288401161, 0.03391627095905798, 0.0704283726268581, 0.027280905849433372, 0.006688376506125289, 0.06362719221838883, 0.08494386515979256, 0.028361810437802757, 0.019555196032992432, 0.03632031374477914, 0.0388282300638301, 0.030505428090691566, 0.037286832596042326, 0.04285182737346206, 0.013633530171188925, 0.03600787890276738, 0.021393115000267113, 0.01989760685579053, 0.03006819708804999, 0.04422408641715135, 0.02241148240864277, 0.06636407000145741, 0.021351527588974153, 0.012955174116151673, 0.027301774193931903, 0.02379700172293399, 0.026642472250387073, 0.002657266329541536, 0.016708767074825506, 0.00980184122454375, 0.030046697705984116, 0.04038804636469909, 0.029187648623649563, 0.0038200656417757273, 0.04200987737359745, 0.03081946766802243, 0.03486998246184417, 0.038720770472926755, 0.03454107278957963, 0.006161929174725498, 0.016493618887450014, 0.02932942851579615, 0.028039306136114255, 0.039197322579899004, 0.028381806864802326, 0.06754841216440712, 0.02919492930439966, 0.036653542292437384, 0.04110008744256837, 0.027300393375168954, 0.008586473896035125, 0.05574918012799961, 0.03913312638178468, 0.06360262925071375, 0.03662152901025755, 0.03323653493342655, 0.05032570739941938, 0.01502063640925501, 0.05793674649404628, 0.08959770615079574, 0.03962109823312078, 0.027241966421050683, 0.04888574413156935, 0.06397169801805701, 0.05227242776059678, 0.11184413491615228, 0.025639120821974108, 0.03713257783757789, 0.030901315954646895, 0.039802816696465015, 0.04044526722282171, 0.022489374836108515, 0.028968244325369596, 0.04122600318597896, 0.03280183486640453, 0.036622309325529, 0.022280409799090455, 0.06798273564449378, 0.03625420747058732, 0.023488095263019204, 0.05020699091255665, 0.017686206947213838, 0.03745479715455856, 0.017639484722167253, 0.037982120644301176, 0.00432336305467678, 0.05288739761869822, 0.024646200173135315, 0.045557702891528606, 0.055976608102875094, 0.014680680186886872, 0.02967286223013486, 0.0179426372051239, 0.06914199915315423, 0.05122468826760139, 0.010593640701180058, 0.03456543219674911, 0.06107786829982485, 0.03642362070136836, 0.012056457876626934, 0.03576133320374148, 0.0412806523963809, 0.03322091505729726, 0.05564932691465531, 0.03124693115907056, 0.015387545738901411, 0.03192088945901819, 0.026128356444782445, 0.009984941354819706, 0.03130313082199011, 0.013437984860502183, 0.06110376798148666, 0.07493985018559865, 0.17985212563404016, 0.19655007177165576, 0.14162491474832806, 0.21671100280114583, 0.16682571891163075, 0.14442274533212185, 0.08947893538113151, 0.1243060412151473, 0.09946242467101131, 0.141725555062294, 0.17169859100665363, 0.09135534255100147, 0.095494630081313, 0.2782342614872115, 0.29140522330999374, 0.10302252149475472, 0.10260386538824864, 0.12931502743491105, 0.08122195809015206, 0.13980721442827157, 0.1306506964777197, 0.10126618788178478, 0.1570922697761229, 0.09522284287959337, 0.127085822767445, 0.23165942781737872, 0.09931125385420662, 0.12994732707738876, 0.1362878568470478, 0.0776706143681492, 0.1364504202668156, 0.11092723733080284, 0.13166699265795095, 0.1665489851896252, 0.11748440297586576, 0.12501859797963075, 0.19115806610456534, 0.13111329451203346, 0.11221282370388508, 0.11092231116656746, 0.14815535289900644, 0.17843765153416566, 0.09914149117789098, 0.1039545029135687, 0.129712648955839, 0.14236943051218987, 0.10648784054709332, 0.3085766647543226, 0.12180080850209508, 0.13416594213673047, 0.1908477313284363, 0.13161260129085608, 0.08686292504093476, 0.11507951202137129, 0.11979163917047636, 0.08679410123399325, 0.15808472223579884, 0.11524602451494761, 0.07797201962343284, 0.18170249062989438, 0.16793128315891537, 0.06907772153083767, 0.16800242077027047, 0.10882305952587298, 0.18849966089640344, 0.0840431506346379, 0.1339534249688898, 0.07973891124129295, 0.2202356665262154, 0.2045769239110606, 0.11918299325874873, 0.0676735272364957, 0.1251557163361992, 0.22538196109235287, 0.13959629860307488, 0.20683118009141513, 0.09556595768247332, 0.11083393876573869, 0.0979592999709504, 0.1722226371722562, 0.07896458064871174, 0.1208124001111303, 0.12400015762874059, 0.07011260278522968, 0.19822541544479982, 0.08345535610403333, 0.11974958357002054, 0.10863873548805714, 0.06984994187951088, 0.13656847178936005, 0.123405340260693, 0.1375930868089199, 0.10064209172768251, 0.10406490734645299, 0.09331632911094598, 0.18038345926574298, 0.12398258357175759, 0.15374825921441826, 0.09031044611973421, 0.12203721010259219, 0.2499394326337746, 0.10943013123635735, 0.13942093801285538, 0.07471691071987152, 0.07238047716340848, 0.11947898380458355, 0.09741465348218169, 0.15476148841636522, 0.13733129442802497, 0.11909825780561992, 0.09251432786030428, 0.09632530622184277, 0.1467533909848758, 0.086566608798291, 0.12783508827643736, 0.14756284255002225, 0.26089625326650484, 0.1766065705035414, 0.0890879092205848, 0.1499921064823866, 0.18987340932445868, 0.10487370751798153, 0.19648683230791772, 0.17685861912156853, 0.1310742651777608, 0.10564209414379937, 0.1682088989764452, 0.14794541416423662, 0.14494554299329007, 0.05912736510591848, 0.0937765794140952, 0.1439725916300501, 0.11636779217847756, 0.1811281107366085, 0.1088633102231792, 0.1389643789402076, 0.08782350671078477, 0.11461649329534598, 0.16708368435502052, 0.09847574654434409, 0.11886721663177013, 0.16705916209944657, 0.15421357138880662, 0.0984008362782853, 0.14182482473552227, 0.11410531215369701, 0.09500672947615385, 0.16816548630595207, 0.16292525535183294, 0.1498463028775794, 0.11620225677532808, 0.11133068068219082, 0.10692529207361595, 0.0722311587472047, 0.09174702689051628, 0.0691064235621265, 0.1541766319423914, 0.15855626336165837, 0.10488633505467858, 0.06475463922002486, 0.191842504377876, 0.1303636354527303, 0.08175717972751174, 0.10695325450173446, 0.15763789335531847, 0.08815519498395068, 0.15379236399063043, 0.12692735769918986, 0.11478806766016142, 0.11110479637448277, 0.09420226514339447, 0.09646967811776058, 0.11952135153114796, 0.11604257034403936, 0.09702800387250525], [0.036464841703751256, 0.0187094394516732, 0.03290626819112471, 0.04723981495148369, 0.024118269394551004, 0.053373503498733044, 0.006530470381091748, 0.033331713040492365, 0.03044752191220011, 0.04787481855601072, 0.02872865361028484, 0.030369480207030262, 0.08980992476322822, 0.043334187740193944, 0.03372783160635403, 0.02535120993187385, 0.009081949496508708, 0.06268176223550524, 0.03643220416935427, 0.01806002206701253, 0.022392013542620198, 0.019609645075563873, 0.016388720766242062, 0.047079935137714655, 0.06314472667872906, 0.04645459047917809, 0.0690293555547084, 0.011083216439666492, 0.037310421865965636, 0.05021063803828188, 0.020886895645942007, 0.023172718971701603, 0.010462832720285016, 0.03128849482163787, 0.07789655974400894, 0.05490485864824482, 0.02220479046393718, 0.034489575374339304, 0.011251520265692046, 0.010998401258672987, 0.07530955677585942, 0.08690947254321404, 0.04309970300112452, 0.035589847048478465, 0.06643645611724683, 0.021806185067232167, 0.030214760652078048, 0.006948770256713033, 0.022642572776281407, 0.025525593431666493, 0.020207797443228107, 0.024041552529005066, 0.026486875688923255, 0.00862586370203644, 0.033331882674247026, 0.010216778110978859, 0.054043984306710105, 0.013758626583564495, 0.02370234778417008, 0.07559442613273859, 0.06211114821157285, 0.031501432681190114, 0.022324192271168743, 0.03225365999553885, 0.011061395601635533, 0.017000582933958088, 0.04926034635198968, 0.054242079212729416, 0.042270814800368886, 0.07314321837787117, 0.049205154313572814, 0.07896654161491565, 0.06019852084240743, 0.02239372345086719, 0.054412075983626504, 0.03164704629619207, 0.02846784849784204, 0.021086770010047724, 0.028457622975111008, 0.10362477560660668, 0.10612376579748732, 0.032374629218663485, 0.00820885134661304, 0.021424655004271438, 0.040017162516180954, 0.04790917617667999, 0.013394168461672962, 0.004005434199435902, 0.023006379504555037, 0.024601728988013098, 0.026188644281189357, 0.04921645192163331, 0.014589630965409535, 0.0335255297832191, 0.05587502123255815, 0.05749187179441963, 0.03301484736480883, 0.038676540167736154, 0.07521042959498507, 0.09026731843394892, 0.03765116518895541, 0.007407963741570711, 0.005850514255663646, 0.025609024401221956, 0.019548290242840136, 0.05647779781637447, 0.0511921491207821, 0.031334357003548315, 0.05447330359103424, 0.039909879344382455, 0.012166290643758007, 0.012073545084734048, 0.04338886409199663, 0.0816708972145404, 0.05590989453984158, 0.013371343391814401, 0.01816296940004187, 0.025875332432665994, 0.04140995063685945, 0.025254674754770737, 0.017885272158309817, 0.05184216870527182, 0.036785510568214316, 0.027218017527567487, 0.05813405769211905, 0.012307617613779647, 0.040459845547697375, 0.007687859436763185, 0.03894788292901857, 0.030387512275150845, 0.014611111687762397, 0.0855903597548604, 0.03361407181780253, 0.01999888668901154, 0.025903069247890795, 0.014470220676490238, 0.05352148859362517, 0.019869712281173894, 0.041690077033958266, 0.03080278927726405, 0.06711533040340457, 0.02254209022170731, 0.03506165842658707, 0.05605621383126293, 0.026066494407132268, 0.05537831324285694, 0.026592633853267347, 0.040773610318345685, 0.017793220401342427, 0.01660300212513123, 0.042480298916676214, 0.007585702597030571, 0.06600087734737567, 0.05745534625436578, 0.01208548475655594, 0.05209503835067153, 0.04029495475281562, 0.06721257125692708, 0.0781836479103991, 0.01650707932588245, 0.022996516998058984, 0.003206984655532454, 0.02107447325917227, 0.09996200964919158, 0.044598692030246766, 0.084729278460145, 0.07431261241436005, 0.03925093363172241, 0.14059284941426345, 0.03544570246179189, 0.07395727719579424, 0.016392276289739778, 0.09959816560149193, 0.011241348177593733, 0.06166486215910741, 0.025258221796580722, 0.01423947127269847, 0.0813427712502224, 0.008783471271661776, 0.04380106054512518, 0.02506829645218594, 0.06130293836551053, 0.038270664268306324, 0.043449338525533676, 0.021481090458109975, 0.01623138545879296, 0.06095724512955972, 0.05929489540202277, 0.05749215677912746, 0.007358320423268846, 0.02615634092528905, 0.013046513411349483, 0.017243306784491454, 0.03429143975621887, 0.023131552252120206, 0.0734332717422928, 0.0437561143854899, 0.010783660192308682, 0.02706282469443977, 0.014921426107840878, 0.07688075210899115, 0.02298752640906189, 0.015743569670511142, 0.01839762377286596, 0.0647225920110941, 0.008116093913226255, 0.020649094566968933, 0.034194392285176685, 0.033632266734327586, 0.028891539334186485, 0.02639840659685433, 0.030337969040764228, 0.0662115081878645, 0.006690893446960087, 0.014248468647045749, 0.010584599222056568, 0.03545515784727676, 0.03790913741769535, 0.007269063382409513, 0.04830146101968629, 0.047011074011347125, 0.0072704492901851025, 0.05367301903398974, 0.01352051761932671, 0.02446964366494545, 0.03126565194023507, 0.04273072922868388, 0.02313319600320288, 0.02983360717605267, 0.051009504457137415, 0.014752650699977363, 0.030627883305507045, 0.05666645769295948, 0.04001628042065671, 0.024884101336023638, 0.023247971897944808, 0.04898089509723442, 0.019387499495808567, 0.006266018142923713, 0.04123601157750402, 0.0042526372292611215, 0.040880856170718155, 0.06892785350126879, 0.05726790774081435, 0.007592379381614072, 0.008155257258165096, 0.04214190332485097, 0.048062345279114585, 0.021722336798640232, 0.021512959551598345, 0.04495105526543089, 0.023389188606025915, 0.09245353790798358, 0.005391141383110413, 0.027049488088648235, 0.06427090481988021, 0.008318330427365643, 0.020132400328293443, 0.014141061642606343, 0.06640105015997376, 0.08441386824207646, 0.02083277569285461, 0.014885982831141778, 0.02918691241315433, 0.02317808788003666, 0.04706038993650249, 0.019790043788296834, 0.0074895457032003575, 0.020146883658266494, 0.027488961649526442, 0.06821857406092541, 0.02893698082438537, 0.027293029573879073, 0.033408764084534984, 0.03906912695882576, 0.012926997101333524, 0.022286487776519995, 0.03182377752714923, 0.02960518854004996, 0.0328401042414563, 0.05475510936230421, 0.03610125889203378, 0.07735305319407157, 0.01649363076181284, 0.0644037484058312, 0.04459988625187959, 0.08651881957692759, 0.008222439858530248, 0.03639702552131244, 0.008601488179660268, 0.010668013228236564, 0.05013210778789861, 0.00994739801223789, 0.013714057010864573, 0.044445814697870185, 0.029311905348939554, 0.05379967438057065, 0.02047188327248607, 0.02560912278879966, 0.018835719907656312, 0.04436886204140527, 0.09206760076007672, 0.031463251515690766, 0.016225780759538923, 0.039380638993212154, 0.06974909121968917, 0.022169796716687933, 0.03389535511710814, 0.024907839883651053, 0.03613376411210213, 0.02468728377217693, 0.007852969907357224, 0.03375709682170834, 0.021815961060513343, 0.039816641847469976, 0.043559318874031305, 0.05150971708020993, 0.032251305479024134, 0.030792604466634135, 0.0519846576665129, 0.021136732239808356, 0.03957763806517635, 0.04236865955005799, 0.05825337128979819, 0.032710056219782145, 0.02502256997727922, 0.0387908801037286, 0.053987095930746624, 0.028200470077406083, 0.016115813981741667, 0.022521951302353824, 0.06727135953094278, 0.02716664394496807, 0.050805418086903434, 0.03285125596448779, 0.013888013881764241, 0.06431621060307537, 0.02294171511727784, 0.0465065934030073, 0.04070815883044686, 0.019112200875367438, 0.05993284724120583, 0.027351524381499206, 0.006499619514215738, 0.028533659609300748, 0.03938562961827431, 0.04670998427484717, 0.04034020286053419, 0.035154763609170914, 0.008001749736389943, 0.08015741807009492, 0.020779980579391122, 0.19568549602159432, 0.13236711866089276, 0.12946351803839207, 0.1488193672682558, 0.15602435065167292, 0.10126149920480591, 0.0903281762397715, 0.1609240655920335, 0.10395117809197732, 0.11082882261169807, 0.15457076579332352, 0.20701576875788824, 0.13911262527108192, 0.1705235040613583, 0.094048773736826, 0.10226085915097169, 0.09823635260441474, 0.16493375971913338, 0.16436962570462907, 0.09362324407058102, 0.12515720911324024, 0.14397960768214293, 0.052976194103913646, 0.1031715345702001, 0.10334455421460526, 0.16530639758067472, 0.16231863147446088, 0.13101421482861042, 0.08391554533903088, 0.12157697337014334, 0.0733988903728979, 0.13939831565533364, 0.11048147375030176, 0.11175275660519089, 0.07699199113994837, 0.18941902156387055, 0.11957220094544546, 0.1254618034831115, 0.1562818411205496, 0.12758667660611017, 0.08731284804110016, 0.2073105379406895, 0.11581850451018129, 0.1133240130064743, 0.150173031059759, 0.07259129799370255, 0.12375224807432719, 0.1077475950920156, 0.1484908748950277, 0.1362998126340764, 0.22973192696060452, 0.08996040347431387, 0.1284238395414182, 0.11470209727329866, 0.10737661964126996, 0.06801638419606856, 0.12594923589910778, 0.11929719070238726, 0.09362857057047741, 0.11976866397474493, 0.18013352767697402, 0.19879119151404925, 0.1307403173829828, 0.14771596076233046, 0.11378165094980172, 0.16549539672476904, 0.11676351380135332, 0.08202123163001877, 0.17197976234768117, 0.16383688072008745, 0.13105652827237332, 0.15972042589315347, 0.16735451482236385, 0.1541496669607503, 0.13743080837385996, 0.12066993489861488, 0.15684613798345837, 0.1093571547951017, 0.07015640900603362, 0.25133113509842325, 0.16916598619094916, 0.06799598743340798, 0.09972524842513458, 0.08396270352282695, 0.21405493175344809, 0.10051635918872696, 0.10596181984458651, 0.06034274346062115, 0.06615312703486, 0.10169016370283705, 0.06667494760560137, 0.1347320574734892, 0.12893990613520145, 0.14936015967811855, 0.16085248014756612, 0.17229006998240948, 0.09160741831042937, 0.12536755496902124, 0.10817183554172516, 0.1334109633628811, 0.12126469798386097, 0.10273069036858422, 0.11023847678942339, 0.10071979077266795, 0.14155695268086024, 0.12297719823462622, 0.15312590689531394, 0.11243383613015924, 0.1651466568665845, 0.15003029443323612, 0.11245943047106266, 0.10824334634734051, 0.21930022457880632, 0.19459517167082854, 0.11669016416583743, 0.1433231114809002, 0.22300388584179537, 0.13080666453710624, 0.186216444841453, 0.08802588656544685, 0.11944511133645262, 0.10814326243208987, 0.10775801738990204, 0.12370975821145944, 0.10752133759004728, 0.18012652519558156, 0.10012616762625319, 0.08322225218372685, 0.13430155414555753, 0.1185302697122097, 0.08374671225569078, 0.19727286084422044, 0.10761574895254203, 0.14977668518466608, 0.12129695553864751, 0.09454625525644847, 0.13256476234112466, 0.09931969482983861, 0.10184409615716764, 0.13829052581318788, 0.19439078335251125, 0.13173848310751574, 0.09836595957832676, 0.09880957898816892, 0.07269079836883716, 0.08865005057305098, 0.08738133936588253, 0.1622642943901675, 0.12392151542007923, 0.07952365957732711, 0.08647364271538598, 0.09251128802342073, 0.24548194610646792, 0.1670513725174325, 0.12307125675891127, 0.1386728531547955, 0.10081859904208354, 0.0891068335622549, 0.14620579965412617, 0.10459700772272688, 0.1804624678833144, 0.06959559302777052, 0.06633031966962985, 0.19553353131881782, 0.12152145563491754, 0.17860333621501923, 0.17215779636587414, 0.06917994283139706, 0.19554069664861473, 0.11049748717674188, 0.11591632211846964, 0.07931262161582708, 0.17633249663880893, 0.11430363436894757, 0.1505331295941557, 0.08104183418410164], [0.054692256663526805, 0.04294090545071023, 0.04609818317528282, 0.029069854944412197, 0.04817353002727032, 0.024384153341608386, 0.014715154854846852, 0.027625616905944686, 0.05172941654122301, 0.02815968164109758, 0.020543746916311126, 0.043438990866499286, 0.01385247306565621, 0.08327298624707119, 0.03071733796969056, 0.031415852451963086, 0.017717409380046383, 0.023655727339376296, 0.08936775063297578, 0.011543404826495265, 0.05374262315620269, 0.033923768771014044, 0.02244780778086611, 0.030276157893240452, 0.030765541097415344, 0.04990051021533353, 0.03444633912295103, 0.07963979084576879, 0.010091527331886547, 0.0670367017654436, 0.037202310881444385, 0.025723186221772006, 0.006610111308483673, 0.04368674435785838, 0.011895306657866707, 0.027595352547775422, 0.05525062991572278, 0.04982917582882302, 0.04245374105604632, 0.09131118349198784, 0.01216417531083737, 0.059549067834658284, 0.05888486347560372, 0.012863896737274314, 0.045222292853785415, 0.04258332767390779, 0.03421301467876349, 0.02208499680273235, 0.008928335953636892, 0.03059860791212746, 0.10776447025792939, 0.033984361948179345, 0.01222445975456919, 0.013547008474623519, 0.043484340754470656, 0.03784019825980067, 0.028972176435802664, 0.01974036993591913, 0.018085546858076538, 0.05256728854562555, 0.088451131246984, 0.03175207333905356, 0.025588196768824543, 0.00786315302164959, 0.04834150815648692, 0.06813398110015051, 0.015580081746780446, 0.032382707178060494, 0.0940691162166851, 0.012387964641675353, 0.040341593857322416, 0.03228637895413807, 0.036780998310340304, 0.04143186731796179, 0.09175795130431652, 0.041056708698826175, 0.022907535612050976, 0.03436905737700207, 0.05521174646647913, 0.0207691732128816, 0.054584858140775135, 0.025199579407594035, 0.05455202043854764, 0.04047661893335836, 0.0433338586507099, 0.04705963676263179, 0.028812320370759283, 0.039526693655976226, 0.003726147913507053, 0.06984361793313708, 0.03126510911222015, 0.02210690500214696, 0.03269202075898647, 0.04176401699494038, 0.03299926820078066, 0.043628909425543885, 0.02551781402767769, 0.02831632484282766, 0.03913610854319163, 0.07505148955221687, 0.06763881338494164, 0.00573150854324922, 0.03428786048399551, 0.017452292177560072, 0.02931698757622923, 0.05118975049949118, 0.01613937271758914, 0.06290933609540973, 0.019561949152765528, 0.025029295955651572, 0.04431248256670577, 0.08851114088403327, 0.05442690536645906, 0.05582045344635844, 0.044569806794502904, 0.03417036196749125, 0.05884650589099952, 0.03605588186266167, 0.023291162348219326, 0.029053977224975824, 0.07879874669015408, 0.08119178363787276, 0.05027555348351598, 0.010013521249805177, 0.02663905413023063, 0.00843581198049443, 0.0299842521282179, 0.021974638170961822, 0.051836414728313684, 0.08647570546184268, 0.038955658940332274, 0.010831457895359822, 0.047666755970567465, 0.02398484057214643, 0.04259193489061935, 0.02674102098015802, 0.05049884918012789, 0.03971304312082274, 0.013286172828104879, 0.047759922221302986, 0.09202531445771456, 0.02403666029152061, 0.07266791816800833, 0.024881534777315598, 0.04830889776349068, 0.040919990677918704, 0.026169796274708848, 0.027494958202753748, 0.011134111655077763, 0.026975643122568727, 0.00970392013966505, 0.03163865960336157, 0.04211510119161435, 0.02804319923078375, 0.02961037933294262, 0.06108571216464043, 0.03186469318877373, 0.02252921332339091, 0.02438980384197618, 0.04316220286169222, 0.03370824569304075, 0.021995537049536194, 0.04102120774665049, 0.08353766240179539, 0.049762638684894354, 0.04061635982777391, 0.06402188925338642, 0.039896335785410235, 0.01733364863321185, 0.05254504616771426, 0.03829131208892379, 0.015183267682524664, 0.024841119535267353, 0.008869128684247178, 0.024994017223694494, 0.009726656999971186, 0.022721182754529372, 0.044734643306583166, 0.05710859450378588, 0.0405934219514685, 0.029906064538019042, 0.044564137634422095, 0.03009229865191238, 0.03857879719829985, 0.04491571376898459, 0.023839109909853766, 0.040407296403178146, 0.048178666537361484, 0.038771161876086674, 0.05876880684601409, 0.03295755186783416, 0.0241920448107911, 0.029287620580622127, 0.014892084557296974, 0.013338979815931191, 0.01695245105241026, 0.03238242219335266, 0.04351424379274249, 0.018161595366629105, 0.027520672983622978, 0.06623417125748736, 0.05847914024655308, 0.01168803880656404, 0.03556611867887633, 0.01645880495198071, 0.027875543405701007, 0.027847496160705174, 0.027229428790243607, 0.055166722275316715, 0.02508635226903217, 0.06711103527673654, 0.022584442681233798, 0.02984432124399713, 0.019630966342187355, 0.02556126062492175, 0.01513880497909018, 0.027022643546972955, 0.038248231900589805, 0.0371922617778182, 0.024866532368053283, 0.023284219238641005, 0.05485836203609194, 0.010412526134002422, 0.014311881137213536, 0.027777386529903327, 0.03485416241788438, 0.05632008931466511, 0.06471250219536678, 0.019543642277962396, 0.0438597877509892, 0.03441560487928135, 0.045033381919243505, 0.022926790739542673, 0.012418433408518987, 0.01246743296672191, 0.04850351857021451, 0.030356676251228367, 0.016478587640449405, 0.015594180008130414, 0.005559901948020394, 0.009651967257793461, 0.04929684814331787, 0.006277379787726594, 0.025067237937556844, 0.05313508664923055, 0.004741670987901411, 0.011498047305004937, 0.06629344807671649, 0.01390787969077272, 0.05262494366616011, 0.03622726284499679, 0.038314925107572756, 0.012050117815046437, 0.05463760406044977, 0.005514197525501783, 0.032115381344088485, 0.028456549193443995, 0.05446338680173669, 0.029643179715744088, 0.02729889381277774, 0.07445875528667655, 0.034237889772547145, 0.05649856098794511, 0.0297155658315335, 0.016411880862766078, 0.021827346878126264, 0.02122902657304491, 0.06323820166289806, 0.03212359840316432, 0.05738973191806248, 0.04261996177956462, 0.015962273381384354, 0.050391369233173985, 0.010299831645430198, 0.017400065337174704, 0.08033742662519217, 0.028269069967791438, 0.04618282702618411, 0.019097971996026378, 0.03228543918313725, 0.01403928902332804, 0.018270194896363785, 0.04683385084250143, 0.011136235469686133, 0.027078573492222598, 0.03672228467517665, 0.04210339306986757, 0.005643828248139471, 0.0314860265435917, 0.08610407861747912, 0.03013139244701181, 0.03475853647770626, 0.07727814292801277, 0.028566911217889616, 0.024130588197814565, 0.05644440710810678, 0.054704120848327875, 0.047924568743578026, 0.015749316862119094, 0.07863942666777543, 0.04020376982433455, 0.043949015105941465, 0.029308380359517675, 0.038269517544124804, 0.0402582663643573, 0.020026811797704016, 0.05091182594852788, 0.03332066649038877, 0.10014252710555281, 0.026440187390627604, 0.036435484886169434, 0.03152806178799697, 0.02458565279708377, 0.035559038165956736, 0.013726094222095395, 0.023440302648980702, 0.0353759660252503, 0.009768523458790566, 0.028809372136103253, 0.053471775725483894, 0.020371989347040653, 0.045638553731675656, 0.025614240639177815, 0.007781005331448146, 0.034636359462248426, 0.04327611871329801, 0.046721420982586484, 0.010741572361439466, 0.01993118755386344, 0.04185044878561582, 0.02103614281596882, 0.06522770704967634, 0.026709726945097958, 0.03856097547603505, 0.030392245056905916, 0.03378811265741076, 0.036178052092769315, 0.018303348117374947, 0.08219855318644217, 0.01605612155981362, 0.06825013950999294, 0.024907958627279316, 0.02649395280916776, 0.045157167062695534, 0.0290557956988258, 0.06616505568048783, 0.0490396935492754, 0.0356154854941581, 0.04607669736391731, 0.013466926923553859, 0.011747989071799176, 0.029331681252058064, 0.2134233242166894, 0.16030028834939003, 0.24170416167804173, 0.13336115889251232, 0.13636705545442446, 0.08296431388173785, 0.11827060793127332, 0.12828635477593966, 0.15444241410919599, 0.061849667956786494, 0.1271727702447346, 0.2543730347284249, 0.10061030236205884, 0.10440030042082071, 0.11715265363454819, 0.10180319406624351, 0.08427326221551214, 0.19003971825752938, 0.20116564338760717, 0.03526550052421434, 0.1377158337937934, 0.08860011718102864, 0.13909821318728582, 0.09833218889044863, 0.13277037202247552, 0.1314856202474662, 0.15493737826389925, 0.19596108980476856, 0.08849334291049413, 0.07125932696674551, 0.11231999831008059, 0.11784694423632962, 0.14392665480928762, 0.09990850037762097, 0.1558876936989171, 0.0846748531662992, 0.12789492149438175, 0.14441437220999173, 0.074243951455823, 0.1259406863578728, 0.11009174359164067, 0.11953150241502694, 0.1248786026345832, 0.07819255028984376, 0.07940591339554105, 0.11336113565734454, 0.08548576358173575, 0.07880331323082958, 0.13088134410125868, 0.1279710666941745, 0.21115070687873022, 0.13057794395302022, 0.15772356518677302, 0.12789155596068927, 0.17081201715128763, 0.11565446188407284, 0.09910476207733154, 0.12655429914593697, 0.11351235397160053, 0.1991263742425612, 0.17485896285091126, 0.0817810438041176, 0.11294691716986043, 0.09150155327681984, 0.07290106280041592, 0.13031161895820073, 0.17095037044159003, 0.06971581586237464, 0.14467465824314527, 0.12042539087789399, 0.08220408324684415, 0.2110847532749176, 0.12271782143839768, 0.13460563282881463, 0.14316480926104955, 0.17472173592873982, 0.1016069006706987, 0.11799031868577003, 0.12575250145580086, 0.1271535134209054, 0.1402442181216819, 0.15023355638342245, 0.11815358778195721, 0.16811618395149708, 0.15981187884296688, 0.16404101119509765, 0.09796345260526453, 0.08236971364489623, 0.11362858023494482, 0.09115166669445378, 0.1081070015206933, 0.17777602560818195, 0.13363094441592693, 0.08811705453055245, 0.10844179748424462, 0.13680217282048293, 0.15665076061018876, 0.10148632499788489, 0.11581918304519993, 0.22127655281552247, 0.1912590999688421, 0.13939284666308335, 0.08482303164367165, 0.17993379410888466, 0.11228837179286139, 0.120625694415399, 0.10818423237651587, 0.11806030278759343, 0.10855463785784585, 0.11305392892765147, 0.11740489224238054, 0.2312114861394678, 0.11760079887296472, 0.24498525847281727, 0.13838119166237967, 0.09440520139677183, 0.19664698014301912, 0.1503292026796511, 0.11398051599306719, 0.11715905900512423, 0.13991952554455825, 0.15726106214736188, 0.23755057741488728, 0.17876256124249526, 0.1779852043837309, 0.13429881286408218, 0.06985124466674668, 0.08610384791557278, 0.10188039778066532, 0.11131449762199606, 0.11111084212149892, 0.1463748091565711, 0.22001981096608297, 0.08210026738899094, 0.12050005687134606, 0.12467228727681295, 0.1289641298353672, 0.09297037803168808, 0.18370977363416127, 0.10207251140049525, 0.19491614587605, 0.11100682270314012, 0.07971943728625774, 0.15108859193112167, 0.13608216574149473, 0.19271230484758103, 0.13608942606619426, 0.06689820598278727, 0.23325767634170397, 0.11026426112013203, 0.21271957483674797, 0.1695731207728386, 0.10910456334905964, 0.12942693143018655, 0.09781764221510716, 0.17733553424477577, 0.10369790132556643, 0.08219233780567135, 0.10515883471816778, 0.10440063968833004, 0.12194229662418365, 0.16014581306704453, 0.1601083850754159, 0.18644443260771887, 0.11442267655261926, 0.1133303369528481, 0.15262316672929696, 0.09162263785089765, 0.15198357962071896, 0.1000198886862823, 0.08507162651845387, 0.09140144222016845, 0.16244706458279065, 0.06264443602412939, 0.07539730492447104, 0.17351010308734008], [0.026947595877572894, 0.0260849030621882, 0.026717675982841423, 0.04410674057102629, 0.023486183490604162, 0.025126830275569643, 0.046513059841735024, 0.0665167471660035, 0.02729217122708048, 0.014703911529587848, 0.08675365376153163, 0.04745882569945284, 0.011779428143719477, 0.016140565242884413, 0.07347020440335784, 0.07034679236156599, 0.0455370211441602, 0.05555561105055468, 0.027263213048822114, 0.03500362332644207, 0.025308126350864768, 0.0517485003386225, 0.012558475402849061, 0.027900265829105462, 0.020029639592394233, 0.0469884448684752, 0.007960978263456906, 0.0637085349964244, 0.04215218313038349, 0.04277072208268302, 0.047234661478017054, 0.04727152967825532, 0.05879695247858763, 0.04423221526667476, 0.02768005577049085, 0.00333491077097798, 0.039992246710296185, 0.029339090854461704, 0.023169037919225435, 0.041233365290931294, 0.028120034839957952, 0.06164673848875931, 0.026490911275946667, 0.04836422211623617, 0.01673490763641894, 0.018049803329631686, 0.05436912810962115, 0.02989462443760463, 0.052964516516242705, 0.027268332595537816, 0.0322575988913221, 0.01554236707410642, 0.0330514102242887, 0.02100449424636151, 0.03694369065176163, 0.0320967962699277, 0.055537338102502484, 0.13937642611563206, 0.07779160394732441, 0.12967360605086597, 0.04014442175892847, 0.018698698242327998, 0.033288174841020785, 0.04106259838278804, 0.03322187179167356, 0.023310258019981638, 0.030973576541457857, 0.024864924240059087, 0.043278853209423165, 0.031061979476362467, 0.022795368684455752, 0.07724255376628467, 0.031645801184432845, 0.04405850012387548, 0.046133813049112044, 0.019108289120984927, 0.038203431625983546, 0.047229558894676824, 0.042413195196006975, 0.039546574732022624, 0.10461654274591378, 0.04165421985089779, 0.012715720804408193, 0.039320419010307105, 0.0036129347697299507, 0.009134880316975926, 0.03745262923517397, 0.0675886357203126, 0.02713294280692935, 0.02613521134480834, 0.08701915772897856, 0.08602734309222017, 0.0252527850347438, 0.04011656789641295, 0.04263423815635698, 0.03333830840087362, 0.021933434131954397, 0.039912722406110594, 0.013971208212231951, 0.018395418534055352, 0.007848591660149395, 0.010615295298131449, 0.03378821104498846, 0.0377071986107954, 0.06694803080920662, 0.037710357191307206, 0.022237701108679175, 0.003845749040400343, 0.029894963705113957, 0.03117002939273204, 0.02824369106175644, 0.02156403288245201, 0.02714051865041256, 0.022382271476089954, 0.025057292310521007, 0.038902739994227886, 0.062117485728647025, 0.014982249986912523, 0.032369804834680896, 0.021997282580871667, 0.019071758491918445, 0.07590761754129614, 0.08166943157890014, 0.04663987125137022, 0.023210657560931783, 0.04355966492689081, 0.023700765101239085, 0.019408710500491515, 0.0712815693446568, 0.01584073418884405, 0.01847495980161641, 0.08145641229514565, 0.04114758489387376, 0.003384534369355866, 0.025866284168192318, 0.004902494389430753, 0.025897479815674678, 0.02436503392112042, 0.027173685442124094, 0.023805586887257438, 0.06273926807833569, 0.02876207824530346, 0.024425184354186058, 0.013399952972706939, 0.031120652399424995, 0.03386800676318152, 0.018853375388841544, 0.026966978230380585, 0.04043760316978608, 0.06934263517281838, 0.006436151044908911, 0.05382176748077784, 0.05600837032709803, 0.0365000135664429, 0.0651347002546702, 0.04816702287644148, 0.004871714344647313, 0.033229919216994724, 0.03908014636752861, 0.05239967003996883, 0.04742073274350592, 0.04290510594312634, 0.04415637540764042, 0.023918344140318886, 0.009249536619920815, 0.049575458014650006, 0.011882649435262595, 0.05961063131690025, 0.02312317573731499, 0.02055820480122098, 0.06966551606144224, 0.01789039509770061, 0.034143637865781784, 0.0055996149063243395, 0.022886173633326377, 0.037867831598435125, 0.04702615784481168, 0.08954672781484467, 0.031350051518529654, 0.05691908306575247, 0.05404728877225092, 0.04730179912543722, 0.06353106416229691, 0.02407270746438631, 0.04957592959648796, 0.01550345478712448, 0.05173375916534236, 0.06114375405013561, 0.03847869631967374, 0.017518037131854465, 0.06463255041411944, 0.02560557913966477, 0.03661755618772336, 0.043793460952916315, 0.006876487193429577, 0.016072021331638098, 0.03373821319213935, 0.013440154476224311, 0.032069868607712645, 0.0485506631833102, 0.008105620725213416, 0.056343783757516315, 0.011210657190531492, 0.04883814490001116, 0.016187338358057395, 0.037038709303098064, 0.07039867314909186, 0.036627520474472215, 0.018444135652056763, 0.013736764185263641, 0.034311300476214716, 0.012767984964219587, 0.046208068528877835, 0.02084394607559911, 0.01800530669944627, 0.0642863754183054, 0.04488543075110231, 0.025550704316369126, 0.021964658617175052, 0.06557836716196366, 0.08131334997181382, 0.011230984403352653, 0.07813247958464281, 0.02083546099519091, 0.05408180245597448, 0.0467879343777895, 0.009759764419868588, 0.0447994366155139, 0.02529255736486188, 0.052239098120480776, 0.0029573003079609145, 0.07921694817819766, 0.038295956661126444, 0.033003821170755794, 0.023443145710708838, 0.0157620156449931, 0.04492488756243672, 0.013384892887968038, 0.026118068157562187, 0.052103387724075995, 0.044255163321005445, 0.06047066766768694, 0.042279133639697514, 0.020634936933804835, 0.05235654913953372, 0.04217957898176142, 0.020023629468466555, 0.08012114358799798, 0.01476541903269078, 0.10315977555832692, 0.02636414736376277, 0.06989032149847065, 0.035353682935237885, 0.050187937649233, 0.05428225866385868, 0.06455974360661847, 0.026080029484416758, 0.02638392157054373, 0.02079153263808361, 0.031041423257972513, 0.05982894995915038, 0.04449645037363682, 0.011737712658941746, 0.02635963849856385, 0.05756012563194547, 0.010507137664327664, 0.05215348396450281, 0.06739731598645449, 0.10015972118292536, 0.04331492752368961, 0.03394443016233189, 0.01734339918142983, 0.04793012933805585, 0.05071759869211486, 0.005333567262693707, 0.009502535186974066, 0.03330055471243603, 0.04329421863492046, 0.04397272311949304, 0.08920384371387106, 0.05710840451398066, 0.052620414444910626, 0.05577072700751679, 0.026608252033059086, 0.02562387753278017, 0.04491235502064228, 0.015271899622998067, 0.017506625869178345, 0.06923155220491545, 0.06056670072887625, 0.03693747527099081, 0.06331830950719969, 0.05081119581258722, 0.02149583163139011, 0.03133639260860426, 0.03748479179505791, 0.03385592883984957, 0.04093439597636461, 0.04532388990212764, 0.05417278043127485, 0.05432855171550598, 0.02946355114025729, 0.0166043982109321, 0.014648314066497343, 0.027478702200044478, 0.05587619170546532, 0.028523199991988282, 0.056855660397559404, 0.033892023510166576, 0.04087463400459715, 0.06734269391745329, 0.08884004037827253, 0.007910468116668718, 0.054249621129461696, 0.017054231305207525, 0.016648046672344208, 0.030889848712831736, 0.059916392767003605, 0.054037080212895355, 0.04336166162309902, 0.009119517435984952, 0.0182709158398211, 0.04063422226213983, 0.06335362046957016, 0.013747730159333773, 0.012329985520669391, 0.027051065682566593, 0.044643268388296874, 0.03705661923491529, 0.041077142780912776, 0.02775622302267168, 0.01985531037540308, 0.021852973449443067, 0.0429138081547405, 0.013051307261256235, 0.07338022387453488, 0.047861502306269746, 0.06276786154402153, 0.07080565845327717, 0.03862570093146392, 0.0025517829718799995, 0.04661820562822478, 0.03846656072086521, 0.016696885926648974, 0.041328791063278913, 0.03245351230725646, 0.10133436708045857, 0.03835578987907086, 0.08839392395956175, 0.022639236080327203, 0.019671854862411107, 0.010839772493844586, 0.11156702121453625, 0.2258560127977814, 0.1702605988830328, 0.16612643429211207, 0.15698757182274545, 0.11638118645974568, 0.09580883250704833, 0.143461586907506, 0.07205617813659565, 0.11326599147702966, 0.1591270063072443, 0.07796796198402133, 0.08508999446140868, 0.10512766281941108, 0.19222686732453959, 0.2002883247498955, 0.1451503520033189, 0.1032261566392013, 0.11286647005804948, 0.06838461836533886, 0.0838388776672738, 0.10651810320892505, 0.1206479910761118, 0.09027731325477362, 0.12574724959475653, 0.15958047126020702, 0.0821476834160941, 0.1525399647653103, 0.18426558880933694, 0.10857979115098715, 0.13462072344762938, 0.0639252115839294, 0.12847757951489516, 0.06352466557707105, 0.14599962000335964, 0.08920705996985946, 0.08629360023353781, 0.10064367271427598, 0.11683215440383979, 0.10979831112282616, 0.07621781661042146, 0.1363101399370602, 0.07945266445832593, 0.11846556461283139, 0.1923119013330766, 0.12582614964672498, 0.14138916454144887, 0.0672601026349834, 0.23440418339201383, 0.12710151049707616, 0.08107776939868927, 0.13552478993577616, 0.10461798124015331, 0.13140468459044183, 0.097825350372919, 0.20336363544421537, 0.21185413056186267, 0.2514292241207191, 0.16367703144039425, 0.16784950611846788, 0.1276874119149787, 0.06418070715985127, 0.11138017302645103, 0.12905398144253663, 0.09829969384840556, 0.14549100372408116, 0.09028264654002019, 0.12294807551162583, 0.12969823687204293, 0.14906939385192736, 0.1508353626621621, 0.32711738986628397, 0.13367720693349838, 0.30072026061160223, 0.12758352820362362, 0.103139656995024, 0.11583841272762843, 0.08442766964435577, 0.09560449847153255, 0.2507805446428912, 0.15735897475055285, 0.1214934592800481, 0.07819039254848446, 0.13983050175011158, 0.16212687747819082, 0.17461720082376683, 0.11495763356132166, 0.15274450236133166, 0.1036355100306017, 0.08424982561596803, 0.18065506326300756, 0.1964503406946148, 0.1323945450463465, 0.10661064181476831, 0.08885925649000065, 0.1075547147276146, 0.1267228201031685, 0.08066631254873105, 0.10971282249582665, 0.06295338658882038, 0.12941573560237885, 0.10838898031839303, 0.1178442979497569, 0.17568596133163997, 0.19623683286564692, 0.12327578078423228, 0.08149728045931884, 0.0800232377701572, 0.1680508545999016, 0.1079376188239881, 0.06757172662764788, 0.06404223173324551, 0.14914348987596376, 0.11907516047358513, 0.09426173195242882, 0.09089092604283776, 0.20036423924778188, 0.10562283053461995, 0.08598926370697361, 0.07331130507269076, 0.14871536142059735, 0.13083076610096864, 0.18961120982255253, 0.1716096486364092, 0.10083505351628576, 0.10704959290368216, 0.07337844611278602, 0.07218963240406343, 0.17651898520333426, 0.14297378808259964, 0.1006792008078524, 0.17848726601472922, 0.11589660389082772, 0.19596064197165625, 0.163052426385028, 0.12524049250142916, 0.15358435229531356, 0.13273392112127372, 0.13988326463316167, 0.1122292781780873, 0.1040616368076631, 0.161053760775498, 0.15433535485395364, 0.1525651112731014, 0.11156901610749108, 0.10520175205809729, 0.17936180265886442, 0.14297735717679771, 0.10621377346771103, 0.09899112781775848, 0.1331693913255419, 0.1567424035498074, 0.12793057172426156, 0.13909457623958588, 0.14340359930481228, 0.1676026415079832, 0.06448310986161232, 0.1998599927340235, 0.12853331438132695, 0.12285567261278629, 0.1403746461229665, 0.13875653009329522, 0.145164764087115, 0.16337847603218897, 0.09714794850775174, 0.16272512823343277, 0.0785006255443607, 0.14841983227857522, 0.1231217940471002, 0.08292880614421197, 0.1108803234196135, 0.0946517674518483, 0.1861053008053984, 0.16393567541880266, 0.08116326481103897, 0.12037304868655545], [0.008502516213671436, 0.02663258938784046, 0.027073274133726954, 0.04891501613227384, 0.031077945405351262, 0.027529234399220774, 0.018295120880273835, 0.0472792208726917, 0.017314949904435446, 0.02967729645648173, 0.028177630588678376, 0.02942657098174095, 0.07019183531935726, 0.01688635495624372, 0.022077341231384447, 0.031755354055868726, 0.08990198160920825, 0.019365847443363497, 0.058955403976142406, 0.024351578571700623, 0.021918742152463113, 0.05499354317518217, 0.0333360624499619, 0.0585793327274067, 0.022829125801633512, 0.03448181293372597, 0.030631723813712597, 0.04101724849481668, 0.06616599205881357, 0.04561218246817589, 0.06052964593150786, 0.05082570628396102, 0.01858181380001562, 0.07954898250422307, 0.01455939544497856, 0.020477031656940068, 0.057825310687933645, 0.019521968173129216, 0.0565206574808274, 0.01799532205664686, 0.035136894389454804, 0.08474237418600492, 0.05627584204609905, 0.017837342140930038, 0.0218693736408438, 0.05674269788765481, 0.04734922533056565, 0.012754853615271193, 0.03460207308775612, 0.03857551648148468, 0.04336775826024158, 0.049567335950476785, 0.0071718573038067135, 0.05592812677579267, 0.043330913808728964, 0.08283539222819464, 0.06757601496896573, 0.06320808827877045, 0.03514400543645024, 0.07562869893653051, 0.080057069526187, 0.01166228755443756, 0.05052854526521904, 0.01871073036454618, 0.03233030731124537, 0.017987525689282587, 0.019600768141182404, 0.03882852183388812, 0.07506309250103575, 0.03974522264408214, 0.018870759456019317, 0.10831481644085475, 0.03746428307411926, 0.01927719684317708, 0.02244093591746475, 0.02518746586117361, 0.02277562840442572, 0.047234834504446814, 0.0573717507400683, 0.0417738964648119, 0.06068152242473193, 0.017168062339935983, 0.022376505624768988, 0.055988601209329705, 0.016675308513055955, 0.05629566544666886, 0.023660661985299418, 0.05946442737643208, 0.0668153500716601, 0.02187407758486058, 0.016847422313211218, 0.026448009203055074, 0.045120258150356155, 0.01830767547445638, 0.043892499924238236, 0.04615619791937726, 0.01335602461559964, 0.033402256933706145, 0.0038830862779702458, 0.050872487880821736, 0.033789388303245814, 0.02108105844152825, 0.012664869693773133, 0.07528073260826723, 0.031079170161059926, 0.08032403912927423, 0.007214838256394225, 0.029235546410615956, 0.11213688206459795, 0.0778764547514064, 0.034167993880276165, 0.014424080295222146, 0.015438257749857647, 0.03273385583556124, 0.011049400798843374, 0.0036341784289106727, 0.03697265391903264, 0.002074305300733873, 0.03385773374299918, 0.07168383883046252, 0.020321514823340943, 0.027888623864523003, 0.027542389496894817, 0.024972017422052364, 0.016060389545080916, 0.023973509037335004, 0.01822983054444194, 0.029575957251446586, 0.02354348746926657, 0.04644784923376782, 0.023707423226109574, 0.05886028015187808, 0.010992375867707389, 0.02766869030892849, 0.058951027425272126, 0.05135300602497799, 0.04540280352479645, 0.06467973573931626, 0.017444799454616647, 0.05974621618432658, 0.014987786832664694, 0.03217025107837149, 0.05444293575627463, 0.026327616734696285, 0.036708839503782134, 0.023492422620100633, 0.05155440200386303, 0.020249649483178343, 0.09441124035843781, 0.013064049300737679, 0.06363262049853802, 0.037217387929558754, 0.012816783506423235, 0.030810059779988866, 0.04071910360029765, 0.011429976671934128, 0.05144951745335545, 0.02181444623108421, 0.042722678410687616, 0.022360426041164568, 0.06592823338827916, 0.09861288525696311, 0.017815172705533247, 0.0211051328639899, 0.05177125840314797, 0.046043690027935166, 0.022917903627135923, 0.03873817828883018, 0.023881581113008515, 0.049720623796539645, 0.014594071977106588, 0.05097841737525804, 0.05444438782121454, 0.0493138013407588, 0.03595216778506126, 0.015503753342532685, 0.0165942320600152, 0.037719778650041134, 0.0330334392243198, 0.04353659473625677, 0.06960051919200591, 0.03528913389891386, 0.05543089292145201, 0.017113816857870136, 0.056132331889654906, 0.04175299419356244, 0.035566030469323905, 0.05663824420688408, 0.08158369189394371, 0.02553185461355107, 0.01570272016605096, 0.032257761739726575, 0.04364420699753931, 0.02023998205550015, 0.014143900463490613, 0.01459341888715114, 0.04436495367969785, 0.04284364763381226, 0.01585147200551416, 0.05111741866650326, 0.038851497029619556, 0.023080677392759492, 0.07737019298864262, 0.09645614134413855, 0.04651353142357298, 0.05533459862428052, 0.030721063126942942, 0.05452102156622069, 0.0344785322169108, 0.031207453991685594, 0.03430060337164572, 0.009088393882848322, 0.049128849658050706, 0.014062257433709289, 0.041016264619039636, 0.048362936292375834, 0.020394518405997326, 0.10677085071802139, 0.10819646636290209, 0.029638375687812055, 0.044319403623895984, 0.05243305396288633, 0.03183213368590389, 0.01586485101974436, 0.012054932021003748, 0.02522758933316384, 0.026209714489855936, 0.06647190957197122, 0.014151117531582713, 0.016090728542102233, 0.01177011355425098, 0.033940867853483984, 0.05474786939365523, 0.04282778348507626, 0.04039134743756481, 0.03264146990009716, 0.05781817249953747, 0.02120406666238393, 0.03542818608028548, 0.006282202899456024, 0.017325789501358355, 0.06695504007594925, 0.013781765475869179, 0.02319437780949686, 0.031161283076341664, 0.027011486734928827, 0.005876473733223975, 0.04325548107070582, 0.031366366893053055, 0.04354341062051909, 0.01857560350825744, 0.035955190658569336, 0.06802133750170469, 0.02062754429477666, 0.0486721548783992, 0.04791774607396551, 0.025439595903402994, 0.06810963526368141, 0.015466345706954598, 0.036467552451150756, 0.013308973301069012, 0.061317479370960166, 0.01954129115412278, 0.021035742480307817, 0.022428532297323858, 0.029548371410263435, 0.07470725516655616, 0.035043422797960896, 0.05488671801452126, 0.02342937484250537, 0.03609868045896292, 0.027878045503582274, 0.07049708786819663, 0.04056124921355929, 0.004933050941742424, 0.019529666152915785, 0.032532894119088135, 0.03779388824477792, 0.03771862853318453, 0.11990559234150819, 0.009535740994449173, 0.00970598288612174, 0.02236182551964053, 0.07213273045739957, 0.013980440529329436, 0.03688733492578779, 0.03832706070638128, 0.0073135888503332224, 0.039908247467662604, 0.025716122672227875, 0.021867307501712015, 0.03109330404549837, 0.05095965248931732, 0.020064847078174353, 0.09466576562928301, 0.010843021828415138, 0.022810391449768628, 0.014566906827634998, 0.028995219485035965, 0.059888348914682865, 0.10004275531641074, 0.03680958499067596, 0.024652123783848116, 0.022086816972919872, 0.041125440903540166, 0.01481251954101026, 0.016599085281736085, 0.042782114685646126, 0.024364555553932275, 0.016646650586543337, 0.0170013547675418, 0.06437970791012049, 0.03801285828064595, 0.04615646594070962, 0.06880480796098709, 0.0049370000155509585, 0.04138184571638703, 0.028787502952452217, 0.06563066864120108, 0.013915239251218736, 0.053636646164315085, 0.10100830386259727, 0.03903685922601393, 0.02733509535236018, 0.02883932606450149, 0.024689835063847046, 0.035484392528555224, 0.062064451431589465, 0.008470205224252172, 0.09386003922138896, 0.02939676633104682, 0.03649100262139525, 0.0242284923193178, 0.04213760480550783, 0.01819217185090695, 0.06200183622006859, 0.0987295593534197, 0.067443144241614, 0.018690130041380013, 0.03450009605980345, 0.042537804759506664, 0.06473397104335682, 0.038092246877827814, 0.05051105941778847, 0.021449087353955423, 0.0500655435025692, 0.03053260681086353, 0.04682563717610069, 0.055922209950430055, 0.02469555172137916, 0.05333103399191584, 0.03765035433960812, 0.09747260715812445, 0.11030538712761231, 0.08565759578985827, 0.10280116980097123, 0.1512847292636122, 0.15732593009514467, 0.20136754826775619, 0.10194611389722143, 0.15168146868901594, 0.14029157986598356, 0.1401367788868291, 0.12659108931464808, 0.15984853330467427, 0.18465696780809335, 0.11493411553757531, 0.1973911159272705, 0.14419490684356007, 0.0783531323873571, 0.17068162986210414, 0.13034585783524172, 0.18388098159006663, 0.1347056081784623, 0.11185397367392268, 0.21855228899845056, 0.08587803146136658, 0.1205974809293236, 0.22157419898680278, 0.25108238416058676, 0.1685229656951768, 0.1266135216823646, 0.12988784669765405, 0.09275543170848063, 0.1465166772582701, 0.17631285983536923, 0.11845298457358565, 0.13920478389731475, 0.11137956234493426, 0.09615684633276292, 0.1990782796804394, 0.09132536487387759, 0.15850370403911385, 0.11011013189064604, 0.17826790921390057, 0.07127073992575918, 0.11601958157760756, 0.10069789444761616, 0.14692685167704309, 0.17103927209973335, 0.11192171182483435, 0.20365954456584795, 0.1147172421749149, 0.12545334893677915, 0.13611735456756183, 0.12525499958012784, 0.059976857022515366, 0.09429086824612957, 0.18896685939814362, 0.12894967703947, 0.10521639484379973, 0.1497056968510151, 0.1279194030378546, 0.1160175052604505, 0.08160837021257196, 0.06673416335667882, 0.08297636466366903, 0.13383313428078378, 0.10981712689889328, 0.06750801218939678, 0.16238942981830665, 0.186081999912858, 0.09382238052785397, 0.15287604316004685, 0.1292024449046169, 0.0771816959604621, 0.0398761731173311, 0.0856676720348852, 0.139901978628976, 0.12749462654548033, 0.1580799724906683, 0.15800282305904798, 0.11582887252526623, 0.13737162654953344, 0.09103723854890891, 0.10426225925662688, 0.08950465864368848, 0.15547160245478153, 0.09060322040958063, 0.1348733827471733, 0.09819815786821501, 0.1116383895277977, 0.09781164396554232, 0.09307234148894038, 0.1401123380554574, 0.11280323737966162, 0.17426334481154168, 0.10712986359638826, 0.11786685245377676, 0.1304429154843092, 0.09133784991822072, 0.15112175872283323, 0.14351236846830162, 0.07595514891935246, 0.09496656020304986, 0.17558138551456587, 0.07478671840259007, 0.23451573454907962, 0.12403725992356028, 0.1643498939062868, 0.14754982824836457, 0.14739159388201578, 0.09888140191989285, 0.11356772921447243, 0.10049193192805563, 0.09655822015234403, 0.06238563598266669, 0.08173999922083956, 0.15229916625789233, 0.1391984870923417, 0.11190628193851028, 0.1551796288362571, 0.07769840716251306, 0.0754197644335883, 0.14049716240593366, 0.1423617766371795, 0.21232181760881627, 0.08320818615279027, 0.14209485453154358, 0.13179549361978257, 0.1095682131126523, 0.12256661669484206, 0.09601733274757862, 0.12772463634610176, 0.08992799664182322, 0.07692393407757793, 0.12429526607905116, 0.12106064893305302, 0.1279056016355753, 0.11790048064930098, 0.10252866335213184, 0.11667789625270025, 0.10859454928764276, 0.0957685343122908, 0.20029162243008614, 0.07741390421454396, 0.1279244784797941, 0.18282789524112428, 0.07873290843729462, 0.07576794789305755, 0.16559947042592935, 0.10550256020256452, 0.09314755031040736, 0.15939977738474095, 0.08432558405080012, 0.17924103699624538, 0.08175320351230246, 0.10598196554929018, 0.13846086524426937, 0.10804359242320061, 0.12209785756255899, 0.11403755364673478, 0.1486846509256533, 0.17196583880909852, 0.07249884081206151, 0.1058899290593607, 0.16068128576236113, 0.23280246076839312, 0.07508385567260639, 0.13871083754513944, 0.06804445518979005, 0.16553228188838276, 0.08302344820861306, 0.15946780730571064, 0.12119465959923607, 0.12735684322459356, 0.12386747689119407, 0.11972233360367161], [0.016414679819718003, 0.017819807099710618, 0.04219417766268764, 0.04741646475823862, 0.015216789008783442, 0.0074611693687204805, 0.03491443668359092, 0.008119293205839182, 0.007237091660499573, 0.018444320552849343, 0.09530578700027295, 0.03070815060553806, 0.03818848689219781, 0.022336682404524515, 0.01616995768355472, 0.036522289871105125, 0.04437864312369909, 0.0290739702593003, 0.018403520242178013, 0.051598812120833566, 0.01912826858460903, 0.023800787948338047, 0.04679442456524287, 0.06025958899408579, 0.04454579344019294, 0.04556794198496001, 0.024571527394333055, 0.013847838671478842, 0.03923046223020979, 0.03295573339398418, 0.01024983124807477, 0.09456998362605061, 0.025226137268223932, 0.03417262827445354, 0.03140441235154867, 0.012818751257977315, 0.015122991720480579, 0.002192065689346886, 0.04779427984197225, 0.026728198364643112, 0.05976491660944053, 0.00913755883396204, 0.023611982186724032, 0.01793591631576419, 0.03278036941108959, 0.057802057292844565, 0.016000586861212338, 0.07138400777642216, 0.026901835475915244, 0.012842718811173524, 0.033650597357856374, 0.0415503938150193, 0.016058211447671056, 0.017704732649560486, 0.04989315828840647, 0.08335785740720374, 0.005449651881852853, 0.03681056547377791, 0.0014417941461683118, 0.0028955082442345364, 0.012066859818462814, 0.015752383840403388, 0.010228523552151663, 0.024021091305517724, 0.04097730313826885, 0.08076670859009027, 0.009162004754346396, 0.016851084705974375, 0.0657718310664807, 0.030911795928009918, 0.030630051224891628, 0.020086653497336165, 0.07680615396904093, 0.01006426040216216, 0.04336750380960958, 0.05260320340416261, 0.021400388895667026, 0.031048500378217016, 0.018904891463794878, 0.04053821973502636, 0.03573869049016919, 0.005227709438518754, 0.05479255770998342, 0.056180256818022044, 0.014689338293724825, 0.08265559401895319, 0.015068167787311333, 0.07222131320408412, 0.01205708212884409, 0.009873391894091452, 0.05344527554033058, 0.037544601264276674, 0.03736637725627848, 0.061117359037910185, 0.02849070494994521, 0.015059560570599777, 0.007474511911693428, 0.020818232991067425, 0.012732405980516757, 0.027848274779639075, 0.01405479439667293, 0.008443781374288457, 0.06193060361381088, 0.11591739420379911, 0.031055404472031763, 0.013439102746945406, 0.019327975011297634, 0.026521501330924884, 0.019142534783376113, 0.018527607333713343, 0.016745709913915822, 0.030671329902751104, 0.04542830287079726, 0.07411650222327028, 0.0414750391085233, 0.010690912936947175, 0.029143272433429956, 0.012050782779364713, 0.02691879715504391, 0.05197005559291158, 0.006201993274901594, 0.051472553717238564, 0.026566958088161688, 0.050796892294394116, 0.02504084801434406, 0.02083367475175432, 0.03129919531888195, 0.03394832834601402, 0.013150075666739472, 0.02755418752453157, 0.007787660911812314, 0.07275316930775132, 0.03248996999380844, 0.036307279087070904, 0.04746249318122864, 0.03534542516406093, 0.03945306582110269, 0.052711073508752246, 0.006848059120654527, 0.02728230193523424, 0.03665050584822893, 0.05718003745589938, 0.07979598282171146, 0.03938998581309404, 0.10122648001249347, 0.041543085992868455, 0.037771941029599736, 0.027359196916222572, 0.037036229257604907, 0.022835122354860817, 0.048128010505544286, 0.036599215386169295, 0.0414007904141077, 0.048612199524151425, 0.059053336935383935, 0.033209064443196566, 0.02107219847052225, 0.03937960761998381, 0.03847941217411842, 0.04028381660048451, 0.0287030694474067, 0.03593929936843259, 0.03003641790045159, 0.011068419287247317, 0.036126513965427876, 0.04274498185675059, 0.0656514996662736, 0.04562022989349706, 0.034420917808477364, 0.029354873578995466, 0.0853238786969866, 0.0544155399048967, 0.05185164783948234, 0.012551484795819436, 0.03756663329633219, 0.02888698297153626, 0.0366018752434424, 0.02664402948825487, 0.02756390075332352, 0.06499394495040178, 0.015814875219283358, 0.044742049516311715, 0.030270811037293503, 0.019996119962473, 0.0366703529975244, 0.03187848102035267, 0.0888355891885502, 0.02473889314569533, 0.04307457684938397, 0.005962374994331705, 0.018287414418799535, 0.01924614199171109, 0.040078844742051194, 0.025291293593389646, 0.03213897400668689, 0.023206510015630295, 0.054809144498514276, 0.04078147793188691, 0.055488419120333025, 0.019550951796450784, 0.032450808345207145, 0.008309301670773752, 0.02027960341157658, 0.05196665952514325, 0.04666766743840916, 0.0525835292812969, 0.01808688017938818, 0.06345220482242958, 0.03113998725478138, 0.04388987060104098, 0.0396277173422277, 0.04305029547374163, 0.05102839147938149, 0.030734328486557518, 0.04992645060909646, 0.012147785297461917, 0.04667277341442449, 0.006230613881988185, 0.01790269524125116, 0.02337819803506136, 0.019650959376511828, 0.02269421438021319, 0.024252013735739247, 0.023081038712656925, 0.022376855070303594, 0.016866638424939344, 0.032486278763306994, 0.02548641651602728, 0.03304040438628622, 0.030205295088567903, 0.05352957673104746, 0.10303918631481272, 0.03399943221094353, 0.022419490818200365, 0.029852009045758417, 0.004494729194058371, 0.018319183428372656, 0.018849950483334914, 0.04539055936038494, 0.03623884543776512, 0.036472115599151166, 0.012932081873129522, 0.002323913313115814, 0.027338201346408044, 0.06288092583417892, 0.04489329157929335, 0.0416336297057569, 0.018134577798524072, 0.04542131396010518, 0.00845271598414651, 0.048562741106642146, 0.03607212259833302, 0.04077501827850938, 0.01940019997502012, 0.011067353987268038, 0.005466882430482656, 0.03993761107059462, 0.045717874475355656, 0.03280725296852844, 0.019528958780158843, 0.007331004299755607, 0.04356169713927167, 0.0522223179494696, 0.02150642017035612, 0.020651630591601133, 0.053077886147158485, 0.03146507677489093, 0.062337901044104777, 0.04360359328399811, 0.026730043979893838, 0.029233056187097515, 0.02767140105632799, 0.05011897134993758, 0.018390746820451956, 0.018708587890224795, 0.01551104080863297, 0.017043452776436294, 0.029991885647177696, 0.057812852784991264, 0.054516146292111704, 0.016979678966371075, 0.06784618725734097, 0.03394305273624403, 0.01601154180908842, 0.029057118842112165, 0.03791680825608117, 0.009345207513043923, 0.004063730959647468, 0.016972215081165944, 0.031233153505516902, 0.052651409924562485, 0.01657486836692052, 0.04009396928761687, 0.013873184498931681, 0.04241086103554283, 0.03563449804538062, 0.009207293574166085, 0.016622359032875726, 0.044435673992016485, 0.044511289934494665, 0.026338761672377586, 0.04292110919154116, 0.043792972407702885, 0.06827985934380974, 0.0604459350662572, 0.020226706517860293, 0.05192012898623943, 0.07761492021381855, 0.0396489520956363, 0.037938697795782766, 0.03428163153252431, 0.04652509026761566, 0.10420127252915076, 0.04914076812565327, 0.04380570851000292, 0.02147937546085034, 0.05998248207781996, 0.021644795513046638, 0.0074096151261723465, 0.008660234045237303, 0.016166644736326168, 0.005819009450663413, 0.034684850967356136, 0.04130381079656737, 0.04582614491560629, 0.012206234303968293, 0.04272897521566067, 0.021889839953343784, 0.012828363554685243, 0.023365614603140523, 0.018252558074891567, 0.07492121761398655, 0.03985084340508495, 0.023758508431326066, 0.06270069336252553, 0.058223352900573185, 0.023652063250275593, 0.024175995761262517, 0.03808860653745277, 0.048803834776793203, 0.008418803652083235, 0.07259264827838965, 0.031043384224176407, 0.024700296377497058, 0.028422176305736815, 0.002680019517096558, 0.13431608836565698, 0.06969507304685456, 0.021232108818367124, 0.029450750577130487, 0.035084630229643414, 0.060830650851130486, 0.08633201888629369, 0.194358281525118, 0.18258644534008844, 0.15806402691773005, 0.07839632114129406, 0.10109595023095608, 0.10527280145989996, 0.18296360224485397, 0.1371320222637483, 0.10754263001893248, 0.18486576660403184, 0.1041792608531458, 0.12947398104837962, 0.11108258113797222, 0.15640476452452795, 0.0716448434229408, 0.22558875142463616, 0.16284657243107045, 0.11683314506496702, 0.08287862847958292, 0.18205694375293596, 0.10511240256684166, 0.1981056947261095, 0.1726845431008509, 0.11316678965730326, 0.10886600400720324, 0.10939873542104449, 0.21643067284354142, 0.11000675029520478, 0.15637602178113802, 0.09715454386813299, 0.25396732507007463, 0.1316731944680214, 0.09008135234138795, 0.19896744777049336, 0.12353337981871196, 0.13142946468932287, 0.12180527326251779, 0.17125368916562625, 0.12072686398667948, 0.08841722485210214, 0.10164160773690258, 0.13724267775458948, 0.14812396386904375, 0.09751395708216087, 0.09575288729476077, 0.05913283409816878, 0.14219295712453978, 0.1317211804645402, 0.10597709366785628, 0.149321388187153, 0.16463335869567736, 0.0463788252589958, 0.13857318993125642, 0.138829146910991, 0.16846652515232563, 0.07285416924527713, 0.10505278648010322, 0.09444912296852895, 0.15406881272792816, 0.1313139780291489, 0.10957548022270203, 0.11211653958473887, 0.09125165561480181, 0.13685802982321807, 0.26365444383450914, 0.12536671358559812, 0.14287743610995157, 0.12862354596810682, 0.15397997892328671, 0.13220397170100892, 0.16320326471967356, 0.16246389225125313, 0.14376333143029893, 0.12327787067208971, 0.11421778611838818, 0.14695145535681928, 0.09762366940932614, 0.16072221499468597, 0.14960340091160365, 0.20052145581160272, 0.11760910414159298, 0.07039306166448764, 0.1474801834140505, 0.08911815152636596, 0.12162008748522826, 0.18049532254891737, 0.13064852516566003, 0.10196102131158113, 0.149462347051927, 0.11304364912211895, 0.1208105952079807, 0.1315335248197828, 0.09160211216658354, 0.16524735146335193, 0.09781553875654936, 0.11715562561792986, 0.06888967912111964, 0.08183561159031731, 0.06943424418568611, 0.10162878342505012, 0.18709231141422475, 0.17498101773006575, 0.3016701282135078, 0.1038429449711527, 0.16282317654362746, 0.18317807359354837, 0.09465622542692081, 0.06652102193662099, 0.12994683853217534, 0.1360888018139771, 0.11726265773177147, 0.164483836718968, 0.17529006328965935, 0.1843332251799958, 0.09250119820769344, 0.15803098226232187, 0.16527168372912066, 0.08255254490567104, 0.11894452891179494, 0.09559721779078245, 0.10665376271520342, 0.13627367546515806, 0.15057906641491822, 0.07360785880259105, 0.08206638813550983, 0.13458440825343132, 0.26392591212477, 0.15206256109688962, 0.19256610769246305, 0.14857957299266542, 0.13383586199155875, 0.09114942074354206, 0.16419222950935364, 0.1886624821594783, 0.12195161969533988, 0.17755679094365664, 0.15920566208660603, 0.15066746595714772, 0.0899515010948692, 0.13433431381625788, 0.2528720609843731, 0.09017195712242808, 0.0902077905567629, 0.20611631630786828, 0.12862347811460495, 0.10993038796420608, 0.11896926829857485, 0.11346615252218076, 0.10670237296393939, 0.144558615184256, 0.10320114583841392, 0.06341297871300153, 0.1318257969937154, 0.081977540760168, 0.10077314398118428, 0.08135564305952617, 0.11280468944460154, 0.11744730068104607, 0.21191162961934293, 0.11453767466757979, 0.1099822416103312, 0.09689902115081038, 0.07474692232374634, 0.12115653950188841, 0.13387079297431878, 0.19862397334405354, 0.14192836917936802, 0.19352447055280209, 0.11917619433786188, 0.29379838917936596, 0.20623172154384, 0.09285801941795008, 0.10132883702005659, 0.08846680540591478, 0.1772902895297323], [0.053834571436579735, 0.016818070584642034, 0.02192648423702589, 0.05745379240917308, 0.04347488876166088, 0.059379596928400655, 0.0482451290424381, 0.023390599958864704, 0.06948261016181537, 0.027170696495366947, 0.04670810473284551, 0.05907796775656087, 0.0020900352267614964, 0.015729138927002038, 0.010732793814635702, 0.0921036581109677, 0.029713370770748173, 0.06990079807915858, 0.02099925765235509, 0.03025699945698891, 0.0415585294498929, 0.04094968337033476, 0.035941399434315305, 0.023511799883895686, 0.059046171605587006, 0.02627471135929227, 0.05893971624651125, 0.053454001500670395, 0.023574223409273794, 0.11101760462458644, 0.06455192688320364, 0.04014300362073949, 0.026338636143399135, 0.03919860840375934, 0.04932837288028427, 0.03988384734839201, 0.03368207799004657, 0.02781948453879782, 0.06355063311223473, 0.0612533035288964, 0.06188408325293234, 0.03136685543826648, 0.029790119866707494, 0.023724200004445653, 0.026949097136301652, 0.05746450647711754, 0.0332878695002624, 0.03852718782478145, 0.017902847911630358, 0.07198980384107147, 0.01953680094863687, 0.026463851299402968, 0.017239469668960998, 0.02995983843824693, 0.06246676841484649, 0.062828169736479, 0.016425658516319733, 0.040642537708793364, 0.033350678094263585, 0.02918200321229441, 0.05737534019031695, 0.029484958920095648, 0.07766260765492916, 0.031272304976092916, 0.04232734694544758, 0.051770115071641545, 0.03195009360622082, 0.0788849274228726, 0.06327105632850102, 0.06436315165566546, 0.017833277716168335, 0.02516072309975113, 0.009551101330933827, 0.0349583243285971, 0.03368249189640794, 0.03707437649635332, 0.042069897188672, 0.04120966067005481, 0.028507010146443332, 0.04067503275083644, 0.05905856165502753, 0.037680756101118665, 0.01773885956832341, 0.008911317447200418, 0.014087512507103384, 0.05745170930666583, 0.022965058418256894, 0.035440915397235324, 0.027201200037130287, 0.0069711377395183915, 0.03950558103887098, 0.07118927501142025, 0.05180877460432904, 0.03172595313351069, 0.00440256208613781, 0.016116721522329108, 0.0027861209777516444, 0.05562420415558985, 0.05033853171127183, 0.03230460440473897, 0.01092859696862953, 0.036063132009335926, 0.041153745991843085, 0.04367938903825624, 0.058675515066300116, 0.025998154056391547, 0.026112644966425638, 0.04705753330407398, 0.01780668762512505, 0.04579726307253752, 0.042112492224467654, 0.04760278368900929, 0.03108104631038649, 0.033668958515461, 0.033742884905742745, 0.021421528654173017, 0.0519292315335146, 0.05506500309067113, 0.050223221470202715, 0.01602381481123822, 0.027626173304659978, 0.01998042205481657, 0.03737407523606505, 0.06601439376494714, 0.011219842858346445, 0.04308569464566452, 0.010694535465777984, 0.04074622803766813, 0.06891456778560366, 0.031179264254335846, 0.03726956048714263, 0.049203865097037384, 0.040935841255954335, 0.025996673153713346, 0.03658227236675365, 0.06160853018185922, 0.04050663053723318, 0.030047399989728416, 0.06177411986781018, 0.02861903967069728, 0.04164320383487003, 0.040075760800391436, 0.039946601659591706, 0.0185964073919292, 0.019101040670648217, 0.05949097845171179, 0.02651897378798042, 0.02486376733785229, 0.020148956582748463, 0.0427569749632052, 0.017791895561718514, 0.0773310958008681, 0.010279269489858831, 0.03432745300233364, 0.008735405547278268, 0.08135655229645115, 0.008991745051129587, 0.04045140117939029, 0.039065266094569645, 0.031608407119555135, 0.017278573642085706, 0.06994596815535001, 0.04224714749891843, 0.01169193020489599, 0.06092427511300359, 0.02295655128546059, 0.0158899076216455, 0.0458729841879436, 0.09141103670533214, 0.021790315829483525, 0.0310852566201772, 0.05550367258755224, 0.02988715037437422, 0.022387240048764006, 0.022671700588294437, 0.05316359529803906, 0.04722736383389149, 0.02241189292232905, 0.015185318554618528, 0.013280320463569036, 0.04434743729819145, 0.026770630552034293, 0.058855428626494746, 0.10177601873874664, 0.03385526726820639, 0.018560585831957202, 0.03423801530152559, 0.02885626569124205, 0.021327381920335547, 0.03929331832166229, 0.0150008859511997, 0.03787988916571651, 0.052845219881939035, 0.049913073291203806, 0.006862315565480718, 0.009774303728980678, 0.04768841480836272, 0.02457613295077213, 0.00854885930727635, 0.040386791074914594, 0.01793022849597037, 0.03362333042813199, 0.05094633963225143, 0.02009997483608978, 0.024236979096063545, 0.05028904275968671, 0.014213195852270084, 0.06183051969856024, 0.027602182002738118, 0.06451431568711996, 0.05294857094330447, 0.017295436933636665, 0.03494234482890793, 0.034229336838637076, 0.06430044144924198, 0.01614623609930277, 0.051581763928490024, 0.0222350276807057, 0.034831889505897246, 0.05740515501903636, 0.04295355334345784, 0.07087072317621537, 0.05024431033858231, 0.07326462864875793, 0.005444397052217807, 0.015770332787984183, 0.04519758400108133, 0.051640901648040326, 0.011047267654378499, 0.048883593175560236, 0.020783602260053158, 0.08210672025701829, 0.042622384149581194, 0.05072749173268676, 0.04618180922365614, 0.05216647791010993, 0.012585145221757037, 0.016001784475520253, 0.04388233546965888, 0.03841582326484578, 0.01676409990925874, 0.1335799050118242, 0.031714068592659066, 0.005381689814385027, 0.08098511544189282, 0.03762403396623475, 0.023067668180114458, 0.019599553563499024, 0.012414642942271062, 0.0283862122534109, 0.03118369508800762, 0.06177462198372398, 0.017412280663847923, 0.02010514696926943, 0.03777428536808916, 0.015302835730835795, 0.03188155817666224, 0.00522822851780802, 0.005817589192052505, 0.04333427594974637, 0.036348347419074604, 0.01874322201391416, 0.06939996459654399, 0.041856759161289246, 0.028078225208446383, 0.044472382736525366, 0.018935776681506207, 0.038344617799988816, 0.04740089577223573, 0.041596066007124524, 0.027733113816274062, 0.021402081840538552, 0.025407977867871523, 0.008921297849155962, 0.03238988268588271, 0.02163189316966704, 0.005823560724300998, 0.03986283990421465, 0.053635333199054, 0.026749679086995975, 0.037309970640178235, 0.030759824439883232, 0.040171932961259565, 0.010514180857821234, 0.07191658312720911, 0.024325582198798656, 0.045874982473573515, 0.03637198757912431, 0.053746517947209735, 0.038372661652309556, 0.07738201306866747, 0.033466120649661334, 0.015099107287824154, 0.015378365160099097, 0.010416804297295, 0.01918277869533215, 0.027006457094103098, 0.033305555515523465, 0.015902133126344, 0.019877837738022208, 0.01699295111133584, 0.044542214167969565, 0.03465458152017423, 0.02325607360606747, 0.033445805311203, 0.018539055915815488, 0.018633485938023244, 0.013040513465447085, 0.0542084510172052, 0.02494807361758181, 0.018895510717162063, 0.04299899483365672, 0.037703147756734064, 0.03903323245633926, 0.035438991750457456, 0.024347361476559724, 0.024493709605719362, 0.006930491371479417, 0.007529278169386089, 0.020209049340337515, 0.007793157893632139, 0.042383746776197634, 0.015029270767367311, 0.03419359161385468, 0.04184808409107583, 0.007812282403132745, 0.053532820128436596, 0.05524855359856572, 0.08253574437860932, 0.021872187864833643, 0.024718893326020668, 0.005427001110677208, 0.05320565089849489, 0.002315302915771359, 0.04634053213521838, 0.01348183348974479, 0.0330781716454242, 0.02736023168212601, 0.03490666067227721, 0.07268035571490016, 0.07227266473429543, 0.05365584870534284, 0.003177057020366192, 0.03320622816681862, 0.058655125088989735, 0.06764515090201582, 0.09523730924619095, 0.044964873631085665, 0.0324972167478076, 0.030198156900171722, 0.0409323909053845, 0.04837418640298503, 0.1599527427128383, 0.11104595381766558, 0.07122572591262204, 0.10535262431949377, 0.1336710186941283, 0.10141271073371172, 0.10217907532517399, 0.1948351559362241, 0.11686294632298605, 0.10139013587364129, 0.16322877763637475, 0.20655303501657077, 0.11503903062215873, 0.1145716014185122, 0.12760815902480058, 0.13794488007468836, 0.15950238545026096, 0.1194876419114215, 0.11535876989364624, 0.1468938205923353, 0.18554701576275484, 0.09254277883363621, 0.12226397650582449, 0.10313893774790422, 0.18749164284339973, 0.09867913741618395, 0.1269170032548053, 0.1503414163099868, 0.09952670229332787, 0.18163815193942615, 0.10944995124425207, 0.15249837056866714, 0.055472293735614846, 0.14490979776850768, 0.12529767943280085, 0.05793154213045325, 0.13162823473768576, 0.04536903962226851, 0.19232655768947943, 0.10518659358578068, 0.0841963163443974, 0.12111464674983706, 0.14839203948421137, 0.18495796594236577, 0.15465540625154972, 0.1618654922183071, 0.13552651341472352, 0.14703988204044954, 0.08524230521704469, 0.1544867902994156, 0.14221135899424553, 0.14843767774956568, 0.062108359432646205, 0.09225394683224813, 0.13290686612682684, 0.18306254622127327, 0.1168352078114237, 0.17485546161021503, 0.08995230855154139, 0.12455601351601736, 0.1358945100967373, 0.071910320248987, 0.14728408679366112, 0.10654830480260508, 0.11421972672854151, 0.2710919475981167, 0.16760745910661562, 0.1319533751479217, 0.15025935428483145, 0.10700729303061962, 0.09584829610373292, 0.22577677347830363, 0.08430660542632852, 0.1378264350018331, 0.1717811958598239, 0.1865469863904374, 0.07922669194106545, 0.09344392083585262, 0.13745059445500374, 0.09252713860145637, 0.160354720428586, 0.15618634410202503, 0.10221294100795474, 0.07889393158257008, 0.0626235982137067, 0.0848494130851967, 0.07310701174927609, 0.13088263331779412, 0.1377656925469637, 0.09620842177953039, 0.05451403604820371, 0.16293437486248358, 0.12207740651709692, 0.09466137550771236, 0.1338401096207755, 0.04864427726715803, 0.10333447796957833, 0.12308465104017939, 0.0901640114773597, 0.13474420325032302, 0.09063032788357564, 0.09383481128939561, 0.21858403086662292, 0.0763344703508275, 0.1148890879537378, 0.08556046350193874, 0.09926278609782457, 0.09423991026622908, 0.12116498047752039, 0.1312212087213993, 0.20391189173928329, 0.102421950149749, 0.14286784162478788, 0.09929810384554522, 0.2050589280469077, 0.10115762906415121, 0.12010791791336876, 0.12561887076922826, 0.09793735614844731, 0.15504366398922034, 0.11594951605158192, 0.10625384774591241, 0.09529505936162812, 0.12346643555377211, 0.061458024329372814, 0.12645200320652553, 0.16240772312240942, 0.11433389703077929, 0.16818728085075105, 0.08767533501876251, 0.08955373708158731, 0.13972104048090322, 0.1199690896485533, 0.10573567769357137, 0.1710085208926882, 0.14355112638856682, 0.14497415002967629, 0.12828258212123597, 0.12954408728650638, 0.05834331789187022, 0.08010399700807673, 0.10946515721401998, 0.11816562499318804, 0.0774503822571465, 0.10260196549019643, 0.1532263843608754, 0.10748215897807054, 0.07654227170028857, 0.0949520327683006, 0.09533011926604168, 0.08862446980284792, 0.15466029170368398, 0.22870269790291786, 0.08903501741588116, 0.1657299798514162, 0.15538982541433402, 0.18736478393631323, 0.07948336816791977, 0.15218158970986093, 0.12409554608166218, 0.13463277422956058, 0.11155626643449068, 0.09989528251545769, 0.15709792875817843, 0.25121111582432476, 0.14038559767816747, 0.1192760882633073, 0.10234843088047844, 0.14954563044011593, 0.14860888570547104, 0.15604891361934797, 0.15712277671056135, 0.16558154353073665, 0.08892017536397491, 0.18270930089056492, 0.07436787909162895], [0.02872487756290606, 0.0510172431490251, 0.019618109799921513, 0.03404010020728622, 0.02707158458153052, 0.03332982671314052, 0.03142406272568873, 0.03827559043254171, 0.04035494403381433, 0.0550659191129463, 0.0494791705028287, 0.0014162624637330218, 0.03026653965935111, 0.042049093305000236, 0.076576490221279, 0.03509600926190615, 0.03094602462702564, 0.01839448554840471, 0.02588985817107771, 0.05676647714738335, 0.02658133115619421, 0.014738420124298759, 0.03293237143329211, 0.01977940266286688, 0.09642792107271296, 0.09262153639325074, 0.017881241660299044, 0.035211580738957436, 0.02503082435578108, 0.005877022922504693, 0.03794219225112881, 0.03378861477332456, 0.029387012390153747, 0.040954880948577604, 0.019392440927081873, 0.037504377708371194, 0.0618249149993062, 0.07827457160289798, 0.0673707445551242, 0.04067938216030598, 0.028762342873960733, 0.09115620609372854, 0.0506498571485281, 0.056605857730443986, 0.02714780781285039, 0.01893503368566079, 0.020378720414425646, 0.01962359745188483, 0.010635452029029173, 0.046846522483974695, 0.028715283077742373, 0.044781462222869904, 0.013879303188462342, 0.0343632185831666, 0.014346053857090217, 0.024358321513448442, 0.010058933054096997, 0.055472141065235646, 0.053850347375763316, 0.05086570592331035, 0.02476693699801607, 0.10045746913445847, 0.0634926115827901, 0.019172000166560923, 0.011259236905191625, 0.022727426973038485, 0.026166288248662437, 0.03234448190778494, 0.03897590981796384, 0.0585495653961386, 0.049896289727517536, 0.07352961014424052, 0.06431656344128506, 0.06243242775755269, 0.04131132217922381, 0.0315097718765693, 0.03086502450917448, 0.05588364880532026, 0.050082055652248006, 0.04242375998624733, 0.025034742895513773, 0.020663598252992545, 0.024960424651258757, 0.0298680835403502, 0.060612311852829795, 0.056638444374714575, 0.07298232415424925, 0.057679975272289345, 0.05397456678162728, 0.01703608558247132, 0.009336713102779217, 0.006344972053609256, 0.01895513867826334, 0.024355600588023663, 0.06339520788086311, 0.03588515905929463, 0.011643306385459644, 0.033578499619449885, 0.03108869679272175, 0.007416510738299361, 0.025719898719606653, 0.015052843073915158, 0.018520321563950608, 0.01870958533670221, 0.061332461424171925, 0.007912556308188608, 0.039563602568315606, 0.06598651276103087, 0.009577718563377857, 0.017119545389765074, 0.03150577191263437, 0.00909232599328139, 0.027184964390471578, 0.07649287435093097, 0.0033804353817166494, 0.05038679590714829, 0.04546364097456847, 0.02976179781502911, 0.010943937797232397, 0.01948164962232113, 0.02120906237645873, 0.03608547616750002, 0.03241478152839201, 0.043235474465680976, 0.025283853456910168, 0.056590105539986064, 0.08965518485222544, 0.038537582981267145, 0.043936014374984164, 0.040292016696184874, 0.04140022383736713, 0.007878070614034576, 0.04377895387421761, 0.018766699325559393, 0.00800895068927535, 0.02282630479229348, 0.06459595702056374, 0.023699197685346007, 0.06551252890910421, 0.028509429123784815, 0.011523833332051123, 0.04950411684278931, 0.022652593042169298, 0.017582993289189677, 0.07315392566046544, 0.01971995790622064, 0.035849542756165774, 0.054657352822167535, 0.07864654450012104, 0.031364436460925, 0.039578452307198725, 0.07088548809822116, 0.03826275594266398, 0.020831345680302808, 0.05220594150679452, 0.0484461416490376, 0.04363026988825627, 0.04568525729700923, 0.07260546580489192, 0.03116219231326665, 0.0475872180956815, 0.015332791355571576, 0.0175331311433443, 0.026902722660452127, 0.0865559625838484, 0.02210103058522301, 0.017434005658807497, 0.029476226174405644, 0.013963951280207505, 0.014719416054763963, 0.043410672207496, 0.031679588835686445, 0.06123393813946417, 0.014827610159825002, 0.030217759776860476, 0.015430101758933492, 0.049619976697223525, 0.08053155549402748, 0.03979622133608375, 0.0458775507286191, 0.030444892589002848, 0.060443851963749955, 0.04169406003451773, 0.015309524389782121, 0.029194600214915614, 0.03503584695447769, 0.06112096205885921, 0.0365369631908834, 0.010889445498053516, 0.028647972403892448, 0.019686950570238487, 0.026222089272258536, 0.05662122654861637, 0.014199784607626498, 0.004770869622007012, 0.02509233694789665, 0.011955450305582156, 0.04122886321108256, 0.025070796853729656, 0.023245432480637516, 0.04858577397785016, 0.06462380409772907, 0.04270832400236811, 0.044109634522880824, 0.05674540863505431, 0.010235938243567944, 0.017822022516546503, 0.018376063322648406, 0.036023491993546486, 0.022897203220054507, 0.019463032317746962, 0.014232134612809335, 0.06885930789368493, 0.055953134183904955, 0.09795824824167149, 0.04976426038358893, 0.026470697717741132, 0.05978257887597595, 0.020105778006836772, 0.06103861504899604, 0.04097803256341389, 0.05019652790256909, 0.034943837605948956, 0.061183699406683445, 0.022045419551432133, 0.035977466963231564, 0.0070879483911474896, 0.06326182146689721, 0.009985764078529817, 0.019268976391426156, 0.018346197603802596, 0.007675583890107061, 0.06687522400170565, 0.04130950031269874, 0.09002503393484013, 0.06277540006807872, 0.03548454519893442, 0.012269104814289935, 0.016609188668163757, 0.0703563800613795, 0.04268156258123262, 0.03885986675907459, 0.01861788472160697, 0.07031623792967626, 0.031083787591861825, 0.05102345174444573, 0.02731865953787097, 0.05609475462032216, 0.038633795854236395, 0.0411271338484117, 0.027536179205136638, 0.03492483523275171, 0.030119043109672408, 0.017130225530958602, 0.026672482157924345, 0.006004906417469361, 0.047525142319500446, 0.01177522716378527, 0.059144423476287296, 0.055355070025793145, 0.03754167338567121, 0.01716352972601141, 0.03732762951403856, 0.02361079305410385, 0.028963399585336447, 0.016806861186133962, 0.05333517984087978, 0.0580398023926786, 0.02742413611018232, 0.022622086107730865, 0.05234880366229585, 0.08298192186547176, 0.02022132064614977, 0.02792926811214004, 0.027382292551919818, 0.05219998396933079, 0.061042625190956254, 0.062035871536604, 0.0375342977100185, 0.020145251781546643, 0.05943190519298826, 0.0339164609488632, 0.033827559290719886, 0.025627801161525503, 0.025553754331277947, 0.03662410744332841, 0.06781044881790876, 0.038874017606888495, 0.0483935280436916, 0.04089834201814873, 0.058117861061223915, 0.059613216535321305, 0.010030205577744969, 0.01142193518379437, 0.03207500172512872, 0.04691011478592243, 0.13418739741402014, 0.016683944567505802, 0.03608697912256632, 0.034012575434254746, 0.03509994137233921, 0.04250255147261279, 0.03126508875616959, 0.025300810047026192, 0.028615097382238934, 0.07790225943816559, 0.014754196063482335, 0.05483454206426229, 0.02315519580484501, 0.036140800520245514, 0.03173922188580036, 0.052547977438994815, 0.0885699630847999, 0.007466691795603505, 0.026813637797853777, 0.06080732960253954, 0.013266931271313556, 0.046901785768568516, 0.010345791366749575, 0.008680321226295615, 0.023856495673369085, 0.008607606021022158, 0.037138647333319695, 0.04356303046058331, 0.011252817963915212, 0.014362732247848595, 0.045964162331074476, 0.04379706736654043, 0.034979905134865215, 0.01909285075297313, 0.015600495472816485, 0.04788106107818229, 0.04674485418945551, 0.03435284039005637, 0.04997254688558834, 0.02857220379103507, 0.03725503305239337, 0.05010122426652482, 0.025977911660447717, 0.038171140144446065, 0.043494118444089375, 0.041077471870396814, 0.02916711276131017, 0.0010215802716889552, 0.024965262605941722, 0.06737525681299822, 0.009204989947777773, 0.05597945116460323, 0.05287815257906914, 0.033214770922703404, 0.03702439899955477, 0.028138984626691257, 0.13420505289520535, 0.19437584201140062, 0.15731073091072695, 0.13076344185641833, 0.10781061063919749, 0.17069562125418866, 0.11277708664004292, 0.18207340501248837, 0.13196402814771446, 0.12505006843379565, 0.07960245784904275, 0.11817581658916813, 0.1386015119829348, 0.1379099219505276, 0.11747887970081397, 0.11530881614557334, 0.10815063132239239, 0.09965985800538744, 0.09209698811173439, 0.16324261975075516, 0.15528504603675433, 0.14547372822250637, 0.10892600007355213, 0.06990338329757963, 0.16897385221506867, 0.13090570350842817, 0.1395227996898549, 0.09780285693705082, 0.14073055131094797, 0.12497864583773272, 0.10742055478372745, 0.16803583183458873, 0.10425887336688382, 0.14481464001749242, 0.10362291642065559, 0.12158071888344628, 0.21551667260272162, 0.1522125851895128, 0.31120625936559265, 0.1590460163674184, 0.10652281224195446, 0.16115317972643034, 0.11797749437391758, 0.1204198133200407, 0.16426956893077918, 0.11999819880085331, 0.13810130953788757, 0.1513794527522155, 0.0925634198689035, 0.1558341844273465, 0.06889367569237947, 0.11542747834963457, 0.10237311598445688, 0.0813097944483161, 0.13444842983569416, 0.07777434201644999, 0.11773947786007609, 0.16315487160214356, 0.194903592978205, 0.1506235918828419, 0.11651090878461089, 0.1699048022606543, 0.11475832068494388, 0.14167919754981995, 0.08622200800372021, 0.12996118276246957, 0.13770637501563343, 0.14280278368719987, 0.13298085358526024, 0.1554713581821748, 0.09831866568752698, 0.16906404308974743, 0.130741416609713, 0.16565143263765744, 0.1835752065692629, 0.07597262119608265, 0.16184900381735393, 0.06661174206861428, 0.11176790150680713, 0.09389271746788706, 0.1420570601310049, 0.06142784309174333, 0.133382397038596, 0.10986784739153725, 0.10732787368553025, 0.12877384147473744, 0.196296326816082, 0.11380141667489495, 0.13636595622769423, 0.12406567697014127, 0.13270121573337487, 0.15595693141222, 0.09743260751877512, 0.11390774989766733, 0.1618450004607439, 0.29565225541591644, 0.12493044271000794, 0.17894918551402433, 0.12167176471224853, 0.09427491588784115, 0.09354673246187822, 0.1434170478688819, 0.18197418962206158, 0.08892748318612576, 0.14587174329374517, 0.08621147035488061, 0.13778938698981488, 0.1428690901292222, 0.12255323598427431, 0.07931221449481589, 0.14903067664376327, 0.06828827317804098, 0.0857077327423862, 0.14056071399578027, 0.15213790562536034, 0.1457798560815198, 0.14587576022105558, 0.09841291420161724, 0.0780496576002666, 0.1465930395892688, 0.22586551228804247, 0.17700250925762312, 0.13596005657953875, 0.13296241100345338, 0.12742833367415837, 0.16939060842352255, 0.12864977813192777, 0.15683161733405931, 0.14697601832449436, 0.13080610813839094, 0.12190534360706806, 0.127520885850702, 0.08058171280260597, 0.09773269641612257, 0.18264998335923466, 0.1411428970417806, 0.25487097086650984, 0.1068526820412704, 0.14658231873597416, 0.13069250780556882, 0.06544949979122196, 0.13973617181181908, 0.10480832388358456, 0.11020123200224978, 0.13834761774965695, 0.08505063264497689, 0.1610540050481047, 0.12626231195671217, 0.11059778143784829, 0.05900466561849628, 0.12158883416226932, 0.13533566865537847, 0.1186815830213683, 0.14245257819337503, 0.1444605261619602, 0.1295828316360712, 0.09648812069956746, 0.18510417666818413, 0.16163574026099273, 0.10447025738124337, 0.06877782940864563, 0.12259223817714623, 0.11273822693952493, 0.10226321366748639, 0.14457085595599242, 0.09455198887735605, 0.17047637301896298, 0.1595703882298299, 0.07903850025364331, 0.3143710823995726, 0.07744257910443203, 0.11690013004200799, 0.23850210064223834, 0.12982075315501007, 0.10318070157830204, 0.1438215768762997], [0.01446015969850123, 0.022320363637326018, 0.047469356562942266, 0.02686203770073397, 0.013449844804459384, 0.09356985014996358, 0.04365321794258697, 0.05473333178088069, 0.0349673115249191, 0.01337313642060118, 0.02671216458215245, 0.018874845933169127, 0.008217029389925301, 0.029350507206150463, 0.012402784694651408, 0.07056476495095662, 0.07519960696143763, 0.05918238751058068, 0.17654903073396, 0.03092839628724115, 0.060041976028255055, 0.03580646596050688, 0.021971062291413546, 0.07226488872298173, 0.03668947072167482, 0.05650980431320412, 0.04143676973347153, 0.04734974440985492, 0.02288447051042957, 0.04219181636082275, 0.0468913498999817, 0.026729489277516092, 0.02381336289857115, 0.03383743536791631, 0.04796207137405872, 0.046314028557389975, 0.07565183698066644, 0.010965806132714664, 0.04867263663826244, 0.054894283679979186, 0.06944819486566953, 0.02601381973363459, 0.0477374253927597, 0.07670811244419642, 0.01961217601118343, 0.061134722749037404, 0.008149900224192866, 0.1133780786767602, 0.0011271211988059804, 0.040674649378550906, 0.04916542948090604, 0.028338828456721137, 0.01870639113310192, 0.022532811255327294, 0.03386842406221798, 0.02200877696408757, 0.03757288599652903, 0.01815410773269832, 0.031667181822870455, 0.014540462621620722, 0.048370105014847856, 0.015166584202753646, 0.04000646201893687, 0.05103895287694676, 0.0092565603055326, 0.02098494056346161, 0.022551530340154256, 0.005700775147748313, 0.0037837691072906765, 0.04307943855279258, 0.03723126057801502, 0.009818622243723698, 0.0100610017377351, 0.04672181114022221, 0.07305365175540958, 0.06433759124151298, 0.06510460044124297, 0.05677713014717613, 0.005403884694845016, 0.007322400475719145, 0.04198246116616896, 0.029494957133595432, 0.053219954416687996, 0.018158954169069017, 0.03501507360488176, 0.01272288104519248, 0.03534536070323416, 0.02702758158557117, 0.09351775901658194, 0.038442096140767844, 0.02494805835054389, 0.05429797014221549, 0.03933282941579819, 0.062402083671518734, 0.0365892748481461, 0.014935444641326154, 0.061040942424110005, 0.03239570112366762, 0.03480651568887489, 0.004952501996220755, 0.046619613588388474, 0.020232959218057137, 0.03981168854183384, 0.061738713910537105, 0.020140496947403465, 0.024833229869338017, 0.019637933200491325, 0.022770379936056476, 0.02054067315267665, 0.04901088634505868, 0.017374808567443063, 0.02167614552724574, 0.03174670273438096, 0.013920317237664546, 0.0033590914265784833, 0.018871483792151724, 0.06765567498015505, 0.08532723065997873, 0.028716209278042828, 0.010477884323336184, 0.017428543451907377, 0.055644773944680176, 0.06094245985150337, 0.05227253632619977, 0.027793096311922585, 0.04414492852187582, 0.024077655681009804, 0.011730864544266036, 0.05511035637131759, 0.024415175962660993, 0.048578113317489624, 0.05231961647846869, 0.0070911447151697105, 0.027560173899733593, 0.04355036221178515, 0.036707814915903976, 0.015452715634767498, 0.05262960180906313, 0.028494765982031822, 0.007694304671271571, 0.010410494769790342, 0.03432163117187364, 0.03178858191573194, 0.041201691276260784, 0.030705517889665704, 0.01918389318910028, 0.07365661154368094, 0.025123371443312083, 0.004144452878140977, 0.0016473957699158096, 0.03675006389884012, 0.06695220379957131, 0.04340896908459919, 0.030927928098078285, 0.01388121665721493, 0.023259505296924284, 0.005655601254797408, 0.018617742229253054, 0.010905988181808164, 0.08987306244671345, 0.04321007689993296, 0.03297022011663232, 0.025126833668244735, 0.039602567441761494, 0.03808776854670473, 0.10245950027768101, 0.07686423656663724, 0.05603632936254144, 0.013119481370917388, 0.02878871074478541, 0.00568289532592254, 0.05875748209655285, 0.040602395577090125, 0.0263984456126179, 0.017134174604767134, 0.037762974189328294, 0.01872952578456274, 0.056208453340721984, 0.026170030369290283, 0.046334421927375455, 0.07169692777097225, 0.05285600858873554, 0.03125322796404362, 0.012409017038797694, 0.03663357300683856, 0.03604190404127751, 0.015337607257866433, 0.04213157941454223, 0.010431188391521573, 0.10902754283909287, 0.01461267571098038, 0.02382472836013351, 0.016131725627928972, 0.03551420396459954, 0.015392789118258017, 0.036768906816307984, 0.06497360925589289, 0.07848394715360232, 0.014231518842279911, 0.08328055191252913, 0.0076947592897340655, 0.06377338937350682, 0.030277671026332036, 0.02250472329823034, 0.056221905297466686, 0.030242061508553367, 0.038330171789441786, 0.008478857393908714, 0.0018486762918265803, 0.03562881192192435, 0.03531149162777832, 0.04879427761105554, 0.010423710087447293, 0.02235452109016478, 0.028512170405260155, 0.07099201131079878, 0.038405241511229954, 0.08557734545320272, 0.020788789660270725, 0.1209248062223196, 0.02368115204652505, 0.06425627560487815, 0.02245181622648878, 0.02559373700725181, 0.029964615324778215, 0.048313155570732694, 0.01204982858949474, 0.033509360293724706, 0.036299520039132664, 0.054189479178083796, 0.03368604063455548, 0.04608880242865, 0.044138540114675245, 0.028624885249882936, 0.04433381910036717, 0.06337004780237164, 0.002753945271251723, 0.06683949234762362, 0.021815762589020387, 0.0710449099008526, 0.011568385093206806, 0.019268708370093788, 0.05600927956402302, 0.03532473663134234, 0.021919308729203682, 0.02838833267534418, 0.033212504615741115, 0.028379235217081647, 0.018776483800528303, 0.018742365363453115, 0.021755639297355498, 0.06868183705955744, 0.023094684051881944, 0.013994526068147804, 0.03403677538569484, 0.014766426657193472, 0.04561123251914978, 0.0521251754835248, 0.05281639910702195, 0.04219147709331342, 0.026416762665446316, 0.026119857793673873, 0.0388297364115715, 0.03875092796183058, 0.03187136318800705, 0.0014216972111691056, 0.04572953170697604, 0.00889251269732735, 0.009813447566037732, 0.04421602202845471, 0.0351477916618543, 0.018374482336054956, 0.05110030262065785, 0.054951246694794724, 0.048072224748986106, 0.019255687283085923, 0.009965459766265537, 0.005972416464438928, 0.03305751703945654, 0.010275786060706844, 0.023066339947815453, 0.02612907229922712, 0.009485682921617158, 0.043570094010127444, 0.03936899872496724, 0.03298241678359253, 0.05018427695280739, 0.05489285536376493, 0.04251683124208024, 0.029791113920509815, 0.02441079093010298, 0.07275745764906917, 0.045215853556458435, 0.018261960873912488, 0.02799630058663232, 0.03675069832908256, 0.021472863221008862, 0.036915823218545744, 0.010522023026299263, 0.016766118550939218, 0.022930522682145238, 0.03736086415925196, 0.04958152751039181, 0.028534897935709784, 0.09303903220487492, 0.02855738458622779, 0.043721512492213926, 0.04438313502552254, 0.05443204866190042, 0.01888649637943932, 0.036840224239443026, 0.0361188193783164, 0.03880566877446004, 0.03037588218493121, 0.0561092413429703, 0.040517317463776896, 0.03489624855241605, 0.05948755184986761, 0.020970691328069994, 0.03443289395155651, 0.07056776407573905, 0.0307830337301961, 0.04323473146983555, 0.06063278325434242, 0.05820280686020851, 0.050533393397927284, 0.03875128419271537, 0.018628787083019103, 0.03678884896050606, 0.11140550273869719, 0.005357987313930477, 0.044813699421605895, 0.037718394438603094, 0.03419673662366612, 0.03386851227177041, 0.05024558598441737, 0.044182746671140194, 0.04386739073587315, 0.03990197101874011, 0.08389479573816061, 0.04502290873123067, 0.0710836678211178, 0.05613794337425913, 0.01812167206246938, 0.038288268859365156, 0.01963776526307421, 0.05190420037667666, 0.03536477359011769, 0.016196520633197257, 0.03623872669413686, 0.033530235423573425, 0.05803484230169228, 0.05445245220991118, 0.07402418753398315, 0.1671936884522438, 0.12094694003462791, 0.10520595218986273, 0.14173377890672, 0.10005371365696192, 0.08279016108385154, 0.0981301958007472, 0.07141542394778558, 0.10562602643455778, 0.11929544008203916, 0.11132184615624802, 0.19112313512180532, 0.16032536700367928, 0.09395567194691726, 0.14658826270273753, 0.09269937114523989, 0.23160427649106297, 0.10990652388760022, 0.14769673107990197, 0.17549802070217474, 0.18361952847668103, 0.16182769781776837, 0.15060037241450377, 0.14346607880932943, 0.1239518052233117, 0.09462120623460837, 0.1609579109187637, 0.15284231996962003, 0.08036289882979222, 0.103286546255861, 0.14852822146245412, 0.11184758865939719, 0.219469478353858, 0.1209044773131609, 0.1887361846332039, 0.07983578568590538, 0.1624854832355465, 0.24652344307729177, 0.1796154933316367, 0.23910613251583918, 0.0858537263369986, 0.23036318165915354, 0.21061617056173937, 0.1374895287943738, 0.12242313367979867, 0.21445502314184392, 0.10115626520876374, 0.10674657273505415, 0.13329838083258697, 0.273170816046851, 0.13050677920026438, 0.17748340059603962, 0.07581748094941888, 0.2105421559619052, 0.10095828904637269, 0.1137075617111155, 0.08659859493907009, 0.1688803636601993, 0.09074423355715615, 0.1124097074248961, 0.08470791139240776, 0.11269354540854692, 0.1282892996179206, 0.11095180708382811, 0.14544997949685368, 0.11358680961919682, 0.103596806393138, 0.13566968430365833, 0.12044893604304109, 0.09328510971473795, 0.08697028285158531, 0.11279924080840179, 0.10775571037083864, 0.15329801051744393, 0.11325121976967369, 0.17763866297900677, 0.10424346383661032, 0.13183045174394334, 0.11159431867833648, 0.10820689544613872, 0.17319799054946217, 0.12244298761444432, 0.09234553548906531, 0.06827584920184952, 0.11599168021764074, 0.12585889574672493, 0.14966782102627413, 0.16748098017913954, 0.21117126648979528, 0.10015105629073721, 0.15612995784197534, 0.09871622614030327, 0.089434308132955, 0.15575027678694042, 0.2420990690588951, 0.12167716585099697, 0.22541735347892555, 0.10378058081758873, 0.09816193766891956, 0.15321104946945394, 0.07285648304969072, 0.09233547281473875, 0.07491489366761275, 0.06836487978164639, 0.10444037469902209, 0.11370363299335752, 0.12900685040014132, 0.15960972969021114, 0.06594672346753733, 0.10263555975896971, 0.16098645010164805, 0.1244111598602363, 0.061664746808154244, 0.1440577477748905, 0.3028165266982147, 0.2250964335565056, 0.11337071657180786, 0.11322688750390496, 0.10099719624434199, 0.13175684426512035, 0.26166278070637156, 0.20691660765026296, 0.10693253882761512, 0.1363288810742753, 0.1871201042085886, 0.13581525720655918, 0.3008734466774123, 0.11212177108973265, 0.15766029858163425, 0.15014910591500147, 0.124778898698943, 0.09380488110972302, 0.17980739660561085, 0.11931173849318709, 0.13816596035446438, 0.10215169643717152, 0.1330175351883684, 0.07294077745505742, 0.05569623404049447, 0.10437855337347303, 0.16245904751121998, 0.12335785638008799, 0.178953175299934, 0.10962330337081637, 0.17823482384639128, 0.09999953263572284, 0.07896733550088746, 0.3114967809191772, 0.1450892567102398, 0.14448738257799829, 0.15557602899415152, 0.13925323129764625, 0.05850490422121116, 0.09764232912233897, 0.16898930924279348, 0.08541623409837484, 0.10824819787272386, 0.23380153572985105, 0.11559648785207953, 0.12007681386811392, 0.10569924036306994, 0.16199031552033766, 0.10864771250635386, 0.2246140901531492, 0.16178587291921886, 0.10099164582788944, 0.1327999018664871, 0.09954406600445509, 0.14389019033738545, 0.12430692331067153, 0.10382503164666039, 0.0650574965402484, 0.11128976502056633, 0.13720039145222732], [0.05083179613575339, 0.01886965174760137, 0.08189091219433717, 0.05759191499756915, 0.00520330253389797, 0.04211098587672625, 0.029480270243116787, 0.0183152699776526, 0.056908755762768645, 0.026541416333722215, 0.0178662528217371, 0.01138014336382704, 0.019447403959929943, 0.02166724145146353, 0.012074804615362414, 0.056311210683946095, 0.045914303577904186, 0.013376985410494464, 0.06556023670626537, 0.030467165500989983, 0.012768625331643437, 0.010703577793070247, 0.05747494234570435, 0.06236105944429125, 0.0214420204117362, 0.03920573641413024, 0.020140466413327625, 0.044626338939581595, 0.042764503309237104, 0.027821318279685717, 0.035749848998550854, 0.0259178273845464, 0.0029684592404269745, 0.05563152554844107, 0.03242077977795686, 0.018816848152450154, 0.040636332506047826, 0.020107316584991555, 0.01342380347861243, 0.03236214417432036, 0.046796293929219246, 0.009262193842524928, 0.028594422420220714, 0.07952743223203079, 0.048119515247110806, 0.026886210510773317, 0.00967182288877666, 0.039456645093326054, 0.022911925733621632, 0.02247333257193012, 0.007314487061064158, 0.030691896299166337, 0.047057879356933494, 0.020277784937726598, 0.031030427597995316, 0.011979946267924138, 0.03533263477895941, 0.035655247646250894, 0.005280081315764359, 0.04951502090053899, 0.05255819956905075, 0.023531019388298904, 0.002929924176506964, 0.047823450062423944, 0.0076898000469165185, 0.015346221259928175, 0.013999120598392827, 0.047103714397443194, 0.015009800205007195, 0.04494415456429124, 0.02745517060559775, 0.07949219590851239, 0.017553953686729074, 0.0372879012886967, 0.036942856053688695, 0.040082271343895366, 0.03943012115944709, 0.051956780055271726, 0.02917926193081907, 0.02181978290900588, 0.022530685744381378, 0.06812646971749407, 0.012685201147438159, 0.025535031853775893, 0.05276699157963906, 0.02682426874525845, 0.01730087708814868, 0.05452565256772297, 0.025375257212934748, 0.0014498767704935744, 0.03367268367271338, 0.023169492537687932, 0.03410900543842997, 0.05731009226292372, 0.09057406375982932, 0.04026445121105228, 0.03721012081950903, 0.051223066568906815, 0.011310544330626726, 0.02113672036544553, 0.0899070706218481, 0.036135104218763966, 0.05443782638758421, 0.04574219656309911, 0.03917096149442451, 0.030128708841013055, 0.02295070231359984, 0.06349340546876192, 0.04574930082474436, 0.03630293307027646, 0.06654527277818748, 0.021857909791703736, 0.019843948306515813, 0.00844501206717853, 0.0367756785957941, 0.02298381312617234, 0.04564025006922228, 0.04278808918648532, 0.05667443726477878, 0.04518493950100882, 0.07719654909202031, 0.05199714610353112, 0.017440048013148562, 0.0152101834703769, 0.014751342823728919, 0.028818433971277306, 0.025235026076968228, 0.010017602637942349, 0.0417824324353465, 0.057188207017523904, 0.06996482464351825, 0.023514442777793323, 0.0789145997592381, 0.034113711078784296, 0.053705374976353984, 0.018580098802755986, 0.021889268287590573, 0.02365043985524348, 0.019737175732318844, 0.04044693302629249, 0.013936547795310616, 0.018979925562494566, 0.028837344742247036, 0.04807566152885556, 0.06302418493266616, 0.02382969862914511, 0.01435662034366812, 0.019454681248004948, 0.04834947415760585, 0.02098840448473181, 0.03151669293375952, 0.03405581507831812, 0.038640343717166355, 0.03878161131537386, 0.015991341821583252, 0.04974341578781605, 0.03773219244820731, 0.04884914055998836, 0.013813844067044556, 0.03228060801380447, 0.08330450419868742, 0.009276966398049678, 0.012521437568856137, 0.02539960983475404, 0.0306031065993011, 0.09011223247008664, 0.09376102060611759, 0.027157799240999987, 0.03255752154758998, 0.04177948080801538, 0.020483279268124273, 0.042845737521669695, 0.0486573458516172, 0.034543403557368686, 0.0232962954656354, 0.0749931898234146, 0.008706500803652619, 0.018140031523736458, 0.028602503772292818, 0.03568574779533914, 0.03039172597761665, 0.018634966840701442, 0.01588992458502097, 0.07506961322256497, 0.039898503704794815, 0.05010623185496245, 0.07759635549570833, 0.037445097496466975, 0.016831644677690098, 0.044475680416716, 0.040299931807177405, 0.061870098646197996, 0.0050971241019267055, 0.082869753241539, 0.04665060567536524, 0.015356289023267371, 0.032443944963493516, 0.05486458759488804, 0.012458419477167939, 0.09089967914457832, 0.07754183520695992, 0.024821723611759286, 0.03485844058117696, 0.034372880921832154, 0.04695379887042301, 0.02078886260278523, 0.021271465545786277, 0.04368236441431301, 0.01918029356082635, 0.06309639462935072, 0.050084447488188744, 0.03554035470421825, 0.0603869500170861, 0.01728881273551711, 0.038865600379982164, 0.046147583917315514, 0.04041589344186442, 0.014663952602339643, 0.0360820733143815, 0.008798079282444502, 0.023224543780088425, 0.03320315779585924, 0.005311741335650108, 0.04320908623880573, 0.028807825076260736, 0.01428621555013316, 0.027006452005090456, 0.027484133872868757, 0.031037901661225727, 0.05341167448620711, 0.011227346607483923, 0.032551007611410956, 0.021338394543688213, 0.10734655375459365, 0.028252907263647233, 0.027795786703271524, 0.008317165891639888, 0.030525991094431708, 0.019709408383018205, 0.024058461621669785, 0.020653561023729186, 0.07067824993282557, 0.02210210606322757, 0.0317882494335728, 0.0196078995442284, 0.13020261909280503, 0.005380063450762204, 0.011486595330227698, 0.02243640160720263, 0.03204517671838403, 0.010164647113664873, 0.034560892797474346, 0.0488390778856618, 0.052130176286612234, 0.04334787718419518, 0.05991303401866129, 0.03411629968988044, 0.026760386369590248, 0.03587376306365643, 0.028716979415288994, 0.03481334175116249, 0.024898681357236843, 0.02559362504897373, 0.03770520032516547, 0.056438653131148646, 0.05548765576843705, 0.05945479217916727, 0.020662074941875677, 0.01166825696626412, 0.0569646025874785, 0.05363410505067025, 0.031275935138442686, 0.014781922700681856, 0.058450445000614436, 0.035881868164454184, 0.040031201405716796, 0.05251758585550955, 0.0081950541851776, 0.005892659337925059, 0.019252489686810544, 0.06582205622856106, 0.04287562359656606, 0.044843107129314115, 0.038211289061499495, 0.02968837014798607, 0.0028345444173152956, 0.05600152051608477, 0.048936586760516675, 0.06052224989980459, 0.037400297221860716, 0.005443225307057479, 0.005137035531723606, 0.047526692772018056, 0.06929559912532568, 0.07205066843224422, 0.031051743775606155, 0.01792324467429093, 0.015110362487445985, 0.029965565273804323, 0.039151155057230165, 0.023443479889205525, 0.050106265781713386, 0.020087810399542962, 0.04863599235458033, 0.08098101709038019, 0.02566165496994342, 0.02018552283490343, 0.021916925374950682, 0.051665542647242546, 0.008452159585431218, 0.021619238491569246, 0.04825465228142483, 0.0167375878497426, 0.018978607508220842, 0.0360141451736646, 0.059309626397277625, 0.020215508993715048, 0.048287473020276854, 0.04774930314826114, 0.01587932926070477, 0.06843362216438566, 0.00478583386367453, 0.032215390620487075, 0.025092671126393334, 0.048637135686086755, 0.0299836991221777, 0.01239292897350554, 0.015590169866170202, 0.04591060895472765, 0.021903492077918987, 0.01247894431331328, 0.0353902695434434, 0.03937149912651096, 0.008472885437575834, 0.038154882445399246, 0.017423484973343353, 0.02924782789445349, 0.04477121973676341, 0.026361545181966255, 0.011306193224819643, 0.036069150614951334, 0.059993521842573366, 0.04081314176853214, 0.04622343395437513, 0.013662368757650256, 0.028543888524706875, 0.018161044056926454, 0.05501668800466827, 0.012950127511950476, 0.04659366301660027, 0.045133635468248806, 0.12158612002219472, 0.08354787435382605, 0.13385547165359768, 0.11881923063525132, 0.06520340192530837, 0.06941513663956098, 0.09846829622983932, 0.0862761822396091, 0.10540573325540338, 0.10824697650969028, 0.13861886890871183, 0.1650246698409319, 0.1379210634955338, 0.13986388567302907, 0.1338671560266188, 0.145645818273936, 0.16360064196799481, 0.22738828057689325, 0.15828266447143896, 0.21732395062489168, 0.12242336438170501, 0.1016798499705536, 0.13469469733536243, 0.20569992650832447, 0.20800628060741083, 0.2156685423105955, 0.11795955390802451, 0.09600530910704817, 0.18927032739988395, 0.10908752533474139, 0.15202530952436583, 0.14303877816668578, 0.11679273151925632, 0.09011775574513844, 0.14702055736311845, 0.20265421351151808, 0.13730036680187496, 0.0947013683617115, 0.12346346357039042, 0.10671438303376947, 0.14534910848098143, 0.12162495936666216, 0.08363220947129385, 0.11130667411323104, 0.15333409500973566, 0.13179605001849787, 0.14107777125069074, 0.0983517374843359, 0.1938083560339042, 0.09760482649185828, 0.11545118636318616, 0.07976099755614996, 0.09107151813805103, 0.18883491147841724, 0.2039191520639828, 0.081052799310003, 0.08380996529012918, 0.1129556227741497, 0.1646504442074469, 0.08203205426356622, 0.15272401060376847, 0.08918286341109447, 0.15423029049166612, 0.1185630022415093, 0.13421732080834253, 0.08283906988799572, 0.191084336489439, 0.0554083044906812, 0.1181985746536936, 0.11313065766756024, 0.2884848357311317, 0.0882403307727405, 0.14369755424559116, 0.1493268028966018, 0.08869189582765102, 0.07382845732250384, 0.08085754407303673, 0.13038712633507593, 0.14094908029905387, 0.1493629959544965, 0.10586816165596247, 0.06803083699196577, 0.1457595678844622, 0.1440703413848366, 0.12276624169732843, 0.12005060884569373, 0.16072112933865615, 0.18423011499856198, 0.17983742856553622, 0.20144813108657086, 0.17612744335617336, 0.1802526648555483, 0.12537979574075767, 0.09874076875192778, 0.09845574333199433, 0.17616070514278753, 0.13405546306499413, 0.10823941762958254, 0.14130833745002747, 0.1528631645653929, 0.07357157074979373, 0.21218046519373143, 0.08038748215351786, 0.10931769798376731, 0.15563953987189702, 0.18624537757464818, 0.1418197900056839, 0.12349074067814009, 0.134216682985425, 0.17475655834589685, 0.09523366551314082, 0.13298617329980644, 0.14618572858827455, 0.13107414304145745, 0.1220769179718835, 0.06651169208011457, 0.05238390427881053, 0.17378889955580235, 0.11492294685116836, 0.18900572588401182, 0.12708973112915242, 0.14911747484334878, 0.13113333843648434, 0.11017121361302477, 0.09942049799220902, 0.09150116651185922, 0.12970586360565253, 0.0932573712031756, 0.09267900830933026, 0.1986154509442193, 0.10737841775906937, 0.14834983460605145, 0.12325739248522691, 0.3058475697679179, 0.07848681057138102, 0.20214440301060677, 0.08782454486936331, 0.06838914419391326, 0.08966718135135514, 0.12179531236844403, 0.1348241889583213, 0.08355162665247917, 0.09218523159090962, 0.09275421713079725, 0.09469099356127636, 0.22960903069802693, 0.1992653382143804, 0.1492435737912144, 0.19179575331509113, 0.11999707243272237, 0.10121798475405999, 0.12346758906330381, 0.1718683468976191, 0.17399744050843374, 0.13096890226006508, 0.11696218885481358, 0.11200495450092213, 0.09698666751916919, 0.11831928603351116, 0.1254920390035425, 0.1844130887516907, 0.14824183897248336, 0.12104198922004018, 0.12372159186218466, 0.1117069690621325, 0.11363273965460913, 0.2806783989071846, 0.20767838534499916, 0.21701164809720858, 0.1763939583407981, 0.08602467644959688, 0.07706238236278296, 0.16644944410238946, 0.16496470091598375, 0.1304505015058177, 0.14190044067800045, 0.28960487991571426], [0.017518965028492466, 0.07933195986385856, 0.010651783518759268, 0.03353293599294765, 0.06061744836292096, 0.027521392230742743, 0.02535594780264156, 0.03465775027871132, 0.01869417750276625, 0.021916214609518647, 0.03414810262620449, 0.04828734409862331, 0.013472903968899377, 0.020662051193150024, 0.034320464091641564, 0.033342732449195216, 0.03775421090956245, 0.08289931022695132, 0.05069439957982727, 0.011074464186094701, 0.04981381040332573, 0.048821028854165754, 0.09547586858804737, 0.011288087366015782, 0.07430286865149226, 0.11454520640628678, 0.04290915001183748, 0.013079943135380745, 0.045229607461286445, 0.057904726426516256, 0.02501356242490666, 0.018787145282008817, 0.03719067739854966, 0.005654645368589887, 0.041259349789470434, 0.0338488347562296, 0.0320644674689642, 0.010469384824058839, 0.016556100088304708, 0.05682190328038164, 0.015272888587787747, 0.03447677141853741, 0.03988794569990464, 0.02356308016793004, 0.07093832562012331, 0.06438774176474128, 0.07390631921589375, 0.023988770986241952, 0.06920266696917159, 0.031896204355039766, 0.02034175891562232, 0.017527311009221842, 0.03616317181981035, 0.09516324714890548, 0.012810732670394438, 0.025064552635220543, 0.01770389126613736, 0.08397505286016635, 0.019828433603314415, 0.037051584505076916, 0.061371205773736746, 0.01647842988105757, 0.04815323843753763, 0.010218212364374526, 0.08384487591683865, 0.01734908191221101, 0.010035510873422027, 0.05877800099551678, 0.008788594211052572, 0.029088582510926893, 0.057751906769616265, 0.02023975983528154, 0.022897215094417334, 0.04749972439770188, 0.050010066479444504, 0.044059260083096366, 0.029553246684372425, 0.04354652509625469, 0.031685064613286934, 0.015524845603587372, 0.01949162069442017, 0.01617918236713324, 0.061706836335361004, 0.006634892679617873, 0.01381642504462174, 0.06451799334692103, 0.009703645332982498, 0.07122909144631454, 0.07391230389475822, 0.027442020596936345, 0.016882911391024078, 0.00821026524395815, 0.05431110318750143, 0.008528760251855212, 0.02833639081966664, 0.04953894604529653, 0.04489325765254242, 0.01745769670898361, 0.03019682357886008, 0.018403404891224842, 0.008630126598291099, 0.0918394840721573, 0.026411319118259207, 0.029610861092805862, 0.05626218992152384, 0.021410902795780982, 0.051582985291523595, 0.028022873714300137, 0.04542293565879975, 0.021964631475774304, 0.027658330775531273, 0.0660995091976864, 0.046015551180711815, 0.05646149940522654, 0.026313655876687596, 0.07188986241817474, 0.025125720870814154, 0.049614609485226016, 0.012076053119796728, 0.020808791176282933, 0.03409484101991568, 0.007685420951539916, 0.01813059310162706, 0.02283258972290371, 0.013615062992487634, 0.016990964700068747, 0.035993107195411406, 0.04036214329036219, 0.01702322225485529, 0.10558459508631911, 0.042047257867774794, 0.04858000982286675, 0.01445883825155241, 0.08749899733811617, 0.06320336567504065, 0.018279943748244216, 0.05098906019702554, 0.008930843988699573, 0.028413424900333797, 0.024784419452771544, 0.01341155931420092, 0.04808098802875195, 0.028324893043775643, 0.0196466065743672, 0.03529495233669877, 0.028047915049163357, 0.01638808972867472, 0.02759933385199734, 0.07123376655259303, 0.03685246501117945, 0.0043395372090994245, 0.014331928454339504, 0.041412926012916226, 0.056117573752999306, 0.03483995050191879, 0.04196557582222989, 0.01924271199719182, 0.013331542223958033, 0.023174289780269777, 0.09552201575466565, 0.0376520710332053, 0.010474628203415444, 0.02660366683267057, 0.02574974068972681, 0.02875534039256828, 0.016946619043924978, 0.02633418156100171, 0.011923573578574827, 0.0476937447009342, 0.08389082630830151, 0.04861563291134579, 0.012392142721052681, 0.05209279579243489, 0.046511953829654624, 0.020116375027490512, 0.033633352390357425, 0.009782260400243104, 0.050222234201750586, 0.018195852903383117, 0.025870126372735416, 0.021543530946863548, 0.020034648877169405, 0.009571262302675417, 0.016574822565806762, 0.03576965204307011, 0.04942838894203305, 0.011603375447780957, 0.028343632484653165, 0.019634730515203307, 0.02707485342398286, 0.03640175151771732, 0.03894220359091248, 0.028413143308301057, 0.041964778543582985, 0.03853108600846358, 0.03229197686804192, 0.010652568923043353, 0.0358333664813212, 0.015060208571542586, 0.0088879062927195, 0.05433799692296556, 0.01916154903093619, 0.025471493834629655, 0.011518345680087805, 0.04941821091675332, 0.016289050757352794, 0.05239568703940936, 0.021541754881452237, 0.047692350311470885, 0.016782169296805347, 0.011297402803653052, 0.01869148202240467, 0.01991560330082263, 0.04151421093514987, 0.008437241993046232, 0.027207227124433433, 0.04253933824864881, 0.05645560972126467, 0.04343284673190542, 0.02871997854007142, 0.08671014609613589, 0.06296480633318424, 0.0365469003362315, 0.040246222367776294, 0.1278137687061514, 0.08317987088646207, 0.006683923620065408, 0.0558909091300198, 0.047014741493122916, 0.03152744432113, 0.014474257959851196, 0.010469353441814227, 0.023972514983532683, 0.08480089783136334, 0.013900520978495479, 0.09806521928736142, 0.061007321013935974, 0.023550204965951185, 0.029690582172146866, 0.04168962920084596, 0.03630461583712271, 0.07952200395188161, 0.03620364982634783, 0.058904120299432955, 0.027785440740574683, 0.02890841110742518, 0.012167973410604256, 0.030290132321949517, 0.03486549734537091, 0.017544152248384695, 0.04236931433635099, 0.013049577845127454, 0.011077262294877852, 0.017479655798524618, 0.04412957327440381, 0.058034441966031275, 0.08771909374211516, 0.08341921054358993, 0.06555690509932381, 0.03051678676690374, 0.042846239637583494, 0.009651453267516834, 0.043237923977098296, 0.0201475571042725, 0.030627065670809576, 0.04712170575346265, 0.013707770383916795, 0.032111937778868845, 0.04320480468283806, 0.017464534645634036, 0.02455036897611405, 0.03150024524490748, 0.02180252776348165, 0.05186790553852916, 0.04826107122270124, 0.05201190424018672, 0.02285731044997062, 0.028153406888512627, 0.03842568577134183, 0.033551239475075684, 0.04782933974638581, 0.04170407181871789, 0.029142359803829874, 0.037313526163675954, 0.01359789351200951, 0.01726969501136669, 0.02314154876928244, 0.03457856863471014, 0.03127884605367269, 0.049327463643359284, 0.025436639187059233, 0.037517928052693605, 0.00913680311558502, 0.028493554797023535, 0.016552059412268654, 0.01981816058313208, 0.0034298418488885674, 0.01997534152386444, 0.051577431482395956, 0.014507199138669031, 0.014400550397112966, 0.043175495362707546, 0.045039200357028415, 0.03263410779514483, 0.03591029538906046, 0.05586815445816942, 0.048965790907719305, 0.09104707730667931, 0.09003238925444228, 0.07611498462834529, 0.03225254380543317, 0.03543542265625937, 0.02526829295259501, 0.021066675195470452, 0.026026560924947262, 0.011267101974226534, 0.023243705609015057, 0.011730325957094985, 0.02557861415802368, 0.03750167374632188, 0.01201953539358718, 0.025140409457630346, 0.06015389359423092, 0.05537223696176495, 0.0459153044170567, 0.010968546566021229, 0.030145577221576656, 0.021434140923832144, 0.04649170634469815, 0.03574504836329392, 0.0347384348777788, 0.05403277151552694, 0.06055487386350121, 0.0721823177965624, 0.06775723810174636, 0.032719036630753956, 0.05381147749722004, 0.03292658692225814, 0.013834391803746777, 0.03931197124932494, 0.03356335471783366, 0.06668414854045425, 0.0426756966459964, 0.05254927344088044, 0.013925466470287313, 0.0665096157629575, 0.06287507686231818, 0.058805250961865695, 0.038071873863892894, 0.04229429550468922, 0.06520361905651433, 0.036424153351358006, 0.16097560711205006, 0.15560629165598325, 0.14387725745993002, 0.09150344638952188, 0.10775699958737407, 0.11842882872692176, 0.12247320956417493, 0.10135958822710173, 0.12201895751059055, 0.10299586185387202, 0.1374826891613858, 0.19174517531480106, 0.09200066328048706, 0.06187606296901192, 0.13675410539976188, 0.0795400326273271, 0.0796297417421426, 0.2195553673165185, 0.09717943931796721, 0.1368478246565376, 0.0876724308888827, 0.14566219810928616, 0.212417938879558, 0.08722465884472642, 0.19566192371504648, 0.160786472260952, 0.15830821810024126, 0.10963823114122663, 0.1057798842500363, 0.17014877631195954, 0.18333146321986402, 0.1303247418254614, 0.09772935802383081, 0.07162100648773567, 0.18070443347096443, 0.08926358872226306, 0.13573841990104743, 0.1929942768599306, 0.07161799379225288, 0.21913268071200165, 0.13147375945534023, 0.14396885968744755, 0.19544804947716848, 0.1052572697933231, 0.23954351618885994, 0.2535085268318653, 0.16487508001072065, 0.11509270274213382, 0.24110867934567587, 0.14699245244264603, 0.15042939516050474, 0.22134669976575033, 0.0752124719853912, 0.1875543123377221, 0.08895948289760522, 0.0481565191543528, 0.11447910352477006, 0.24561597034335136, 0.18688220983105047, 0.1723069247922727, 0.1303603377725397, 0.15024756134620734, 0.15786928736737796, 0.15206329391470977, 0.22681867757013865, 0.2173430174589157, 0.1773335122104202, 0.13166193078671182, 0.11324054641383034, 0.11193630032773529, 0.14648371402706417, 0.10643261458192553, 0.1878023575991392, 0.14912461303174496, 0.15876892980720314, 0.2197424258504595, 0.08069942505764109, 0.13390022782342775, 0.16842415742576122, 0.25121076298611505, 0.12544352374970913, 0.15008775277861527, 0.21406468908701623, 0.10576729742544037, 0.14212894413088048, 0.1043925719069583, 0.07418975007853337, 0.1743338174585785, 0.10627807823142835, 0.19524538463779859, 0.12655519481216157, 0.13835063044513973, 0.09329630554254566, 0.08694462065718003, 0.08298860543540545, 0.15513103215822152, 0.12100731608058725, 0.08496729497398649, 0.09936160793794052, 0.1198254573558058, 0.15481172714914593, 0.15641619105424198, 0.17140215262770653, 0.15473374990480288, 0.13583927734621934, 0.08458078107131378, 0.0865956229556884, 0.10281184315681458, 0.14152658145342553, 0.10350109224340745, 0.10082753534827914, 0.08228063556764807, 0.13732653111219406, 0.12608901411294937, 0.13008644032691205, 0.12640977118696484, 0.12387758706297193, 0.0943123438794698, 0.131078784220985, 0.10677942061530692, 0.17854081599840096, 0.21544069025133336, 0.3063540283058371, 0.09215520641633443, 0.18721333492015088, 0.0846788158108081, 0.14676873944699764, 0.13118934471692356, 0.11944868043065071, 0.20786401895540102, 0.17984000699860708, 0.13763554953038692, 0.12961552345326968, 0.19998738089842455, 0.1639833085771118, 0.13740083069673606, 0.1449783162346908, 0.11808724062783377, 0.11888016307992594, 0.12748918469463075, 0.16162126032369478, 0.14613114723137446, 0.18653675408235618, 0.08342429277087961, 0.07968922212187733, 0.146660323121718, 0.15447820004607948, 0.16101743201059954, 0.13215050314153942, 0.05990860318498952, 0.08549657264458281, 0.11336812456803662, 0.1404796697731529, 0.10858159605413675, 0.13133118567722185, 0.14072597798492226, 0.14622086313154015, 0.13253523249711308, 0.15167789959481784, 0.17784828958766802, 0.16824582485216005, 0.09750208950468472, 0.15793279824512346, 0.1716804876923561, 0.12686726663793835, 0.1821864489465952, 0.14499017702681677, 0.1123097592166492, 0.13669271155127458, 0.14897443966141768, 0.17644251430673258, 0.13635856019599096, 0.10530682999108519, 0.1483127458819321, 0.1531178458992924, 0.09394383151084185], [0.048302723094820976, 0.038954142414565594, 0.02597915507586939, 0.02343480651532965, 0.048047753383538554, 0.1007768012849348, 0.09165231018726315, 0.014633847699899758, 0.02924584996487413, 0.033438979248915396, 0.029993524309247732, 0.059480244027716775, 0.014769909238176686, 0.030630488879978657, 0.03717625513672829, 0.05796035951269524, 0.061327806673943996, 0.06774620512234313, 0.06236158191625561, 0.029315274275307144, 0.02762878396814423, 0.058280132710933685, 0.07232065073081426, 0.01965380074190242, 0.026283137067886334, 0.051581095571496656, 0.04819050018808671, 0.05099410849756428, 0.052826960504587205, 0.009342261822894216, 0.047815290678824694, 0.03602954791858792, 0.061551356821187904, 0.0202041367468025, 0.045948966539331844, 0.05810522673917668, 0.05323865823447704, 0.04746206909684198, 0.021024327824956605, 0.042319285949426036, 0.06262934540531465, 0.02220164884680084, 0.019127327117270658, 0.08300538560641663, 0.05557796199406896, 0.017621308465355208, 0.021365079629634107, 0.019132584067327634, 0.051527833965207846, 0.013353600549245519, 0.06175790288086448, 0.01039250850278352, 0.06898979696312121, 0.01960057475870209, 0.03351673257670232, 0.04698129650205374, 0.05037795120318021, 0.01615535221727831, 0.08915873470583133, 0.01448442241443055, 0.01859965078931834, 0.06960822056446757, 0.033479426721377034, 0.058367419455732615, 0.06589332954691988, 0.039669314931545935, 0.03864340391010046, 0.011043085334157305, 0.04513373046315142, 0.0466171403282455, 0.04508379367845399, 0.03551351525155561, 0.030925068072974682, 0.07029846031218767, 0.027439504928354706, 0.04983981865059052, 0.037251901613282304, 0.03636274253949523, 0.03769765501575811, 0.05285290768370032, 0.04726383848381894, 0.07631822622248105, 0.03895315175343837, 0.046408185469252725, 0.027067667738135372, 0.014313399359317762, 0.009071409303162779, 0.032024684960820844, 0.03162448500682201, 0.010545119510165282, 0.050976782105863094, 0.0351881068199873, 0.058535621501505375, 0.04546093361984406, 0.006447477490707699, 0.08185831537204129, 0.02995788086471813, 0.02997635058792574, 0.01484361510457737, 0.022032924329063723, 0.10206540713885001, 0.009634097189908581, 0.029244238444204842, 0.028898579135004963, 0.021513149541403567, 0.012836649315431714, 0.025261422785531198, 0.027959196595475078, 0.07345694582909346, 0.02636914816685021, 0.018817952468193004, 0.04429197384576712, 0.032798279342906814, 0.030632436275482178, 0.03958987544423767, 0.04130981583148241, 0.030460074810045104, 0.017338188032486608, 0.028437904747469083, 0.009129720906327878, 0.03777468909642526, 0.028502229867236953, 0.008519119965577764, 0.08952329800065074, 0.029212734063288996, 0.06661317377750363, 0.06893972786409513, 0.02132186203795884, 0.04810816335624882, 0.06966221159590141, 0.03659095422231725, 0.029589236181761538, 0.023147390955793004, 0.04311297853876438, 0.043112561239727905, 0.009084711134034609, 0.03739215140896184, 0.04868094529956579, 0.04721286014786788, 0.023788233354155506, 0.023914914145799618, 0.0565425436278539, 0.013488322829029389, 0.03624213972528066, 0.043508377857506275, 0.05929267659251179, 0.017522401808361922, 0.03129570086353591, 0.03780863281073315, 0.045065914280712605, 0.02944362595943468, 0.03498059045523405, 0.04744303958224399, 0.06043916328677109, 0.004736107000748494, 0.010842175355979373, 0.03341807358499084, 0.04423965879582933, 0.05038742694471564, 0.029644991404243877, 0.031497412361204624, 0.025045850513769046, 0.04417196814236896, 0.013647441835408764, 0.03146555514207908, 0.080896668402212, 0.02989829531205552, 0.037765484768897295, 0.025569676155490533, 0.035379090679011176, 0.019218225364706347, 0.01196601933666638, 0.07063470155532871, 0.028356724817837988, 0.00879180961887219, 0.005689182801039091, 0.014790976054168173, 0.029600571109248058, 0.011147779046690889, 0.04057028730000768, 0.014185341989754565, 0.03574102125795824, 0.019937584442751746, 0.026222906906956008, 0.04936474574995892, 0.06231605900185449, 0.03465015407917755, 0.01842860228914235, 0.04535651047314916, 0.036780771001109054, 0.047242861573717425, 0.03196026145347527, 0.015099166659638286, 0.05107036904831018, 0.011171509960799344, 0.03580413519271782, 0.024937559717467854, 0.06079610663333109, 0.06420919884528432, 0.046748304540025334, 0.04514601533966405, 0.025060793551217233, 0.03450680337846279, 0.023008348952446665, 0.04769452840888074, 0.00714992535566645, 0.07441380912704126, 0.03398065375430243, 0.023127752456015775, 0.028806084633937905, 0.01062910009308585, 0.08307226201785461, 0.019721638976729343, 0.03419470441128526, 0.03555315526734505, 0.019256550718897154, 0.027596202412886277, 0.06591446591275078, 0.06949019618332386, 0.0410989644671125, 0.03133449610322714, 0.014948299487254449, 0.01612188687015857, 0.09666380698659591, 0.0656318628628339, 0.024053323415241072, 0.0406411670680557, 0.014816112383934004, 0.013264982179472489, 0.01650891306677035, 0.032558373109038384, 0.043173320657972775, 0.06512740600321974, 0.013437606577229286, 0.05706384511930602, 0.05347072399620499, 0.013799148694878178, 0.07513830810785294, 0.019543063826858997, 0.06404947170189448, 0.021168104306395565, 0.04232976253011397, 0.007028309827936547, 0.022458060444997888, 0.04374329346631255, 0.021354764201013104, 0.04283188522926398, 0.04742023741294231, 0.012200521039111274, 0.013980795063876679, 0.04478891932272485, 0.045759499206074646, 0.04606424963900021, 0.0030687691926557037, 0.03255463098841054, 0.027955883648246527, 0.030315478997571126, 0.02600180118211678, 0.041263129229524305, 0.04933799111417361, 0.05920794113938298, 0.0077201577036508495, 0.04621100997818368, 0.019914119005469338, 0.024575132111619626, 0.057911667839757035, 0.03880075618092503, 0.032563855671989064, 0.03945598691435797, 0.0510633292474917, 0.03397204314491578, 0.018427121386464154, 0.005976001673843712, 0.0164742212676044, 0.03417750354856253, 0.03456928627565503, 0.022543474433145354, 0.01979395723901689, 0.041732295482818565, 0.007688571050363992, 0.048997142618255954, 0.02324720176069864, 0.030080739807869707, 0.052072504202702215, 0.09137352050415107, 0.014077270020996886, 0.03658017908622112, 0.06314268428832293, 0.08430493623018265, 0.05045965360477567, 0.018279738491401076, 0.03580634382420352, 0.040756640157529285, 0.030616819792027985, 0.04654646072802799, 0.06598340507064547, 0.045737236472112794, 0.010852411056735685, 0.047898071951099803, 0.013270640313359243, 0.040201825821506124, 0.008697033543804926, 0.017859942446063672, 0.09151034709066153, 0.03131277958995529, 0.027588392474821637, 0.056827446911484, 0.03517971334180661, 0.08235966454127006, 0.034121086754437, 0.009864912750864667, 0.05329674422474844, 0.013294217708919729, 0.013586102269722946, 0.03014224561463509, 0.022254203080332706, 0.05302610374721033, 0.04058362051312413, 0.05344643922788756, 0.010856244779591049, 0.03920504430841122, 0.021760263513507586, 0.017941609224570648, 0.026251342613250017, 0.0027227551368663883, 0.054732615926436017, 0.03578288008325866, 0.04060133706246104, 0.02151980766627405, 0.0411212577351502, 0.05367305974609085, 0.01678094284475914, 0.021709821220221262, 0.022106268875566975, 0.02076390608479934, 0.03394916294408696, 0.013996816972004516, 0.033545241225510836, 0.015296983366299952, 0.03242532256990671, 0.01405933209961014, 0.06254771764257125, 0.009287617701504911, 0.020521443470248153, 0.028391238501561538, 0.033868841361254454, 0.05123729205557278, 0.08544537717742579, 0.01599538928296949, 0.0118243980520804, 0.009482755891180463, 0.004169343663046935, 0.061659488161759715, 0.12179607232766491, 0.11161044745572976, 0.1375653347266572, 0.09920024552515574, 0.19651448939527782, 0.18181567027100495, 0.092661970295012, 0.12344116690967764, 0.15026160702109337, 0.1741052054400955, 0.1976147067866155, 0.10753800919545548, 0.17654770080532345, 0.2012019721525056, 0.11371126651231732, 0.17314149572380952, 0.14340711411620888, 0.1219178286514112, 0.1806512363255024, 0.10278248973190784, 0.19537326134741306, 0.17408947699836322, 0.10972291909690414, 0.10212551177080188, 0.08752198610454798, 0.07901299412229232, 0.12526861099260195, 0.09994218964129686, 0.14616322836705617, 0.12792314855115755, 0.15417500345834664, 0.14694504998624325, 0.09492606523313693, 0.12281722681862967, 0.19945509731769562, 0.10753628571650811, 0.1274103932082653, 0.10455201406564031, 0.2096407629017319, 0.12444562943918364, 0.12587887181767396, 0.21009080803820065, 0.19965150606419357, 0.20196081857596124, 0.10791406008814063, 0.11472968650715691, 0.12433145913694586, 0.1533392925879785, 0.09831228745835167, 0.12021625281444617, 0.09934220183640718, 0.1300204595816987, 0.11424319046948637, 0.12166700139641762, 0.14206263768885816, 0.1477970185556582, 0.11480566885854517, 0.16102013257997377, 0.1324860251375607, 0.15889038757554122, 0.1745989482317652, 0.13745720338608536, 0.3209735538278307, 0.21380329025643213, 0.15195099636912346, 0.15167153493634292, 0.10174042957701854, 0.1662944938455309, 0.13357314680303845, 0.18450861291161605, 0.09657065769923584, 0.11587974908096449, 0.16450580768287182, 0.19047313928604126, 0.12121730909815856, 0.10827343937541757, 0.12167019051100526, 0.13571365337286675, 0.1323234617177929, 0.10423708560743503, 0.16378973610699177, 0.14605626410671643, 0.14692552174840653, 0.1456195046859128, 0.05382056308111974, 0.10171096080115863, 0.0895050454086491, 0.12083320399480206, 0.15141142532229424, 0.14426695369184017, 0.19547212389963015, 0.11009265282856566, 0.1397455898778779, 0.1016923010881458, 0.1911797656544617, 0.08019013702869415, 0.11316790245473385, 0.08272372572017567, 0.11245088092982769, 0.1543593749936138, 0.1293662161167179, 0.08483094336198908, 0.10999892678643976, 0.1632668977337224, 0.11682654970458575, 0.06875988894275256, 0.11786351406148501, 0.19719343153493746, 0.17479617122028554, 0.09935742137687546, 0.1620257214776107, 0.1044889645917075, 0.13185102492570877, 0.07233378716877528, 0.15208902396261692, 0.18132150678762368, 0.11959597681249891, 0.10893345717340708, 0.08965053010199751, 0.13167778136474745, 0.13077589975936071, 0.14591200756175177, 0.15950579169605458, 0.16699490483318055, 0.2275476005992719, 0.13806656854493277, 0.18172702645616873, 0.21782755931573256, 0.16550885885953903, 0.1310442875006369, 0.09315155366701738, 0.12182360727872167, 0.16775056214204856, 0.12491090090147086, 0.08220668882131577, 0.10085053768541132, 0.20792241367910588, 0.13214823683457716, 0.11418677706803594, 0.11735385283827782, 0.138043362647295, 0.1005715105150427, 0.1078725541010499, 0.15637171986911977, 0.1795885283499956, 0.13916458748281002, 0.1619589129196746, 0.11028573675347225, 0.1695221492222377, 0.13329601953072207, 0.11247524033699717, 0.1032700374988573, 0.1555145808628627, 0.08423309294240815, 0.1338045543857983, 0.08995804217244897, 0.18733342204775127, 0.05175268689968756, 0.10545684729835816, 0.10341065709612199, 0.09539154704127993, 0.09149265768272535, 0.18351208924182824, 0.11433513196451323, 0.18762407930833952, 0.08204087521880865, 0.2394088948411601, 0.09506085621459143, 0.09599159591432128, 0.09758941696158477, 0.15978564667914594, 0.10173052296574626, 0.13775988428720407, 0.09491055392261062, 0.10919301717409066], [0.061848901212215424, 0.01048534396769745, 0.030289742164313793, 0.02027889434248209, 0.11260347667017154, 0.02571170710559402, 0.05870571665998016, 0.014832263213715382, 0.019704305799677968, 0.051168648060411215, 0.04300282855651208, 0.05140439487461533, 0.046870803859617026, 0.04655032837763429, 0.044398391885416846, 0.03614199134920325, 0.02090802013741008, 0.006778617846846048, 0.004970964085909405, 0.01556202253725912, 0.037756955583712885, 0.03993377395506416, 0.06672091156776462, 0.02488235241201307, 0.05204720502453191, 0.02271267562173307, 0.05390615348837205, 0.02446658516834889, 0.0650676813508783, 0.02872437544699226, 0.023062195795189058, 0.03129650492753301, 0.052037875168025494, 0.07755807254995618, 0.04137974904317941, 0.09827880175518137, 0.05289081743519221, 0.040653655505073924, 0.028024605674935237, 0.045510968792119195, 0.017125423199364116, 0.03171562243785177, 0.020538221944921782, 0.06192531104066542, 0.0008489753818139434, 0.017119206122255752, 0.03067810507491231, 0.05175857997632452, 0.012989993140633618, 0.018922399363613555, 0.043418916407972574, 0.002772046889211716, 0.05624166762988482, 0.05195974186062813, 0.021143911140305654, 0.015653578963662897, 0.02840090762557728, 0.01502559650024133, 0.028659490535834005, 0.03492314907323037, 0.053583910422665734, 0.0637856505012938, 0.01698491895305259, 0.035102010904146094, 0.05595506461603301, 0.03296052045854075, 0.0314206632652453, 0.02524221345915326, 0.016728826266314303, 0.013282823409619076, 0.04566832445561886, 0.006289163396494197, 0.025122638625491942, 0.025540407547461133, 0.03255912967558418, 0.029565395853881325, 0.01615623092012746, 0.02853706246241927, 0.013593482186219521, 0.04586834300841604, 0.03291297550978405, 0.041402347651975493, 0.06424221635929175, 0.05172957938962749, 0.01680714956351689, 0.029749580792018344, 0.028354319411196878, 0.005033860041294247, 0.02672349611696388, 0.010708397936208971, 0.03673482060964618, 0.03667267019461308, 0.008416729031263717, 0.05409115266853145, 0.014388511489544595, 0.042430969420820475, 0.01923963484088225, 0.01511387390616749, 0.0437076194877071, 0.05819161103240081, 0.019306655441011702, 0.011211985422830497, 0.01853111875243485, 0.04062300607828157, 0.03179667344582932, 0.023554717223825197, 0.03515468218496867, 0.0192520842621369, 0.06782617047429085, 0.015288632296557938, 0.0634891442688448, 0.014316805605111378, 0.039796024560928345, 0.028388699084254246, 0.017328654615474597, 0.04448017231853945, 0.013165463992793645, 0.018682158951248442, 0.053510055278560946, 0.02258384387407984, 0.033026887968714745, 0.08402622118592262, 0.07766172555940491, 0.01490081221397434, 0.03286431776359677, 0.09559280052781105, 0.03131473037813391, 0.10976739028202635, 0.07223547422992331, 0.04448198061436415, 0.027202509609716277, 0.035599254936512024, 0.008200041417564665, 0.052929405721702745, 0.048651951498218944, 0.012651331223813551, 0.01435413012014968, 0.034761284544531784, 0.0722060597368649, 0.099193086980709, 0.03474272661177175, 0.0253199820539781, 0.028889184817671776, 0.08106695355049201, 0.00627156431853239, 0.04975544282102159, 0.016113449287201678, 0.031633380600916486, 0.04220235740233745, 0.060595273838511536, 0.0546289052415107, 0.030664490269763128, 0.08345346977668149, 0.050562967346715074, 0.012572227611339517, 0.037329712616545815, 0.023613953330953206, 0.06080909379358802, 0.010247106081806123, 0.02855500632098743, 0.07934030584458794, 0.10763657319226436, 0.04378834479887571, 0.03671954678637641, 0.033361005397247415, 0.02793371251651219, 0.09805982493396316, 0.0236429488286376, 0.03454999552507486, 0.04549668562997665, 0.06060089889381613, 0.043132788368633816, 0.012209772015921772, 0.031009728887251446, 0.03367662935384682, 0.02792216554683234, 0.02884852360667927, 0.0359379897958466, 0.0054806176755976465, 0.04845012125692197, 0.05673753762883799, 0.047799507954290936, 0.0429236978026373, 0.03644203953444958, 0.030694372951984406, 0.03566775643931968, 0.01615596459513264, 0.048563541777964146, 0.06767035169260842, 0.02984790730157069, 0.028994897180902104, 0.03273305516423924, 0.023521801490070562, 0.018639399370710765, 0.07360467647335359, 0.027362499685425843, 0.030548006163111756, 0.0371801126083093, 0.018636722550062195, 0.027440056238057356, 0.02589184288600726, 0.02627086576207408, 0.0866253970723067, 0.018632064407159175, 0.031886881283883534, 0.07332471971000944, 0.056851453480443785, 0.02801763542395617, 0.003397684378017272, 0.04719527591285961, 0.046541979004229815, 0.0587000237511737, 0.040929534272955995, 0.0475968532929463, 0.0361861436228667, 0.03740887051182134, 0.02198831574060023, 0.047555371054581234, 0.021189657971262932, 0.03233656679679241, 0.03199442908433931, 0.015120303025469184, 0.07164352027965443, 0.02468536182173661, 0.007402942582432712, 0.05539988047842469, 0.03240454922031079, 0.009553466025473816, 0.03355975169688463, 0.02502254962122866, 0.010336565835002278, 0.04276277983028974, 0.03616870527288743, 0.04499170969107321, 0.02656584359439356, 0.03471258608624339, 0.0583025650786502, 0.050030028979693136, 0.060258720469261916, 0.020974153553002646, 0.057540373477552614, 0.013030103041923471, 0.027519936773127744, 0.026286604381831627, 0.025824267583500062, 0.008934536915538567, 0.026855328685737083, 0.05565647528107677, 0.044728448281862905, 0.02038512408866414, 0.027012496055769067, 0.026743494240300994, 0.03341997687571815, 0.0038201279821805656, 0.037405905313789845, 0.010050119732373526, 0.024930580984801054, 0.035196425659315925, 0.03091193502768874, 0.036382016326699934, 0.008533495578116604, 0.04243206864755068, 0.012587551476566919, 0.03972161301810827, 0.025176751793229153, 0.0708593170025519, 0.020187270062576448, 0.03282983800662415, 0.028495390234248977, 0.018609866134024093, 0.05105319871966328, 0.032230583019554615, 0.1274273701544319, 0.032322585582733154, 0.03564534442765372, 0.052301692975951095, 0.02091730080012764, 0.019732054489265596, 0.024590901265453016, 0.020979647990316153, 0.06506554396556956, 0.017638892700363482, 0.04382938938215375, 0.028582113794982433, 0.014497604653505343, 0.031541900509702306, 0.054775193998856206, 0.03421157618452396, 0.02844925663833107, 0.025811339795057262, 0.030329663772135973, 0.02054162649437785, 0.03178671594443066, 0.054639388607548814, 0.0048219959634090105, 0.010717366472817957, 0.07597841588514191, 0.030744370804833512, 0.026494156369673352, 0.029736593631761413, 0.048130612687340806, 0.07274196669459343, 0.013504883324328278, 0.10931003053805657, 0.04697988175653985, 0.08401411612118993, 0.009722883497098727, 0.021975776413455606, 0.02360030629539064, 0.05359887211982693, 0.019592690181785395, 0.04158465304811086, 0.012884984757485134, 0.0294998934758561, 0.04393894564626472, 0.0015076344134286046, 0.007620018657429942, 0.06494996231049299, 0.025904882632728134, 0.03947144394208278, 0.09584571088531188, 0.03962205157482198, 0.024896140243592005, 0.08970461612833397, 0.05638561544141599, 0.04064636125362345, 0.02817275531456939, 0.08388253461037364, 0.01880798818144415, 0.02391561134053128, 0.06591281707265548, 0.0029288156199202475, 0.04411518833200846, 0.026061866798305085, 0.026912980413596545, 0.037195552672658644, 0.0625924738124013, 0.07202205461050783, 0.018346374022907445, 0.017174847690122466, 0.036807434034666846, 0.05719767936638423, 0.08383747988513537, 0.04168637901810663, 0.03068010675321732, 0.059280781873634884, 0.07345426561576979, 0.051149638901863775, 0.03725451058042901, 0.02794880313532693, 0.05831966416112014, 0.06573319528251886, 0.1309572993112462, 0.09966657550207206, 0.14693469554185867, 0.07654082642069884, 0.27450842569981304, 0.1455791997058051, 0.1525163110345602, 0.15455426382166998, 0.06433406964476619, 0.13203865342906543, 0.07720155668045793, 0.11405435417379652, 0.1506475984518017, 0.1259829590895346, 0.12596215520586285, 0.1341276727616787, 0.09802719418491636, 0.06855033697294337, 0.09567991763885532, 0.1695353128015995, 0.15247124273862156, 0.12594103919608252, 0.11987565537648541, 0.12573914788663387, 0.14965872865702423, 0.13453639511551174, 0.1752673052251339, 0.11511951844607081, 0.14783641429884092, 0.12556110029774054, 0.1604954893035548, 0.1257905401289463, 0.10397618210741452, 0.13313855869429453, 0.1564026339245694, 0.1831154990941286, 0.1581607995820897, 0.0879529169095414, 0.1598327098680394, 0.09623462001660041, 0.23059258077825817, 0.08481695875525475, 0.06747897089059864, 0.13841249926814012, 0.06933712546846696, 0.09324836704347815, 0.10854955563055617, 0.10144803526678256, 0.11051012149878911, 0.14214562252163887, 0.14697536693087646, 0.19990731376622403, 0.12256797376487936, 0.13322889884667738, 0.22261832867349896, 0.08025490319622414, 0.08782563052539315, 0.13223000030432427, 0.15143982879817486, 0.11430910336119787, 0.2348739467561245, 0.14508130427982124, 0.1321177299001387, 0.10782165718930108, 0.15564773657492229, 0.07455039144094501, 0.13058231371854032, 0.10972640676689999, 0.1160537526011467, 0.1030154579452106, 0.11778871236102921, 0.06743751240095922, 0.12266964545207364, 0.10876659862697124, 0.1627020716134991, 0.1456084174237081, 0.08473209438047238, 0.13019835789288792, 0.13889679685235023, 0.16649489237793855, 0.11519702071590082, 0.1362633210207735, 0.17361393251589366, 0.14831281373543398, 0.13059566728770733, 0.13552759907075337, 0.14975198650998728, 0.11391300175871168, 0.13432344368525914, 0.11353617055075509, 0.07380737523947443, 0.15226129043315137, 0.09334516006388835, 0.11635675919907433, 0.12883087912840502, 0.11790622105555874, 0.24061218170183046, 0.1561901303274291, 0.10385959622051034, 0.13584435278815882, 0.0805613092545952, 0.1660848536661693, 0.09751261358282395, 0.14166326554758207, 0.14716208619730814, 0.07847131283155509, 0.11282847888235535, 0.08827129232564143, 0.1602373474410602, 0.1445206172232117, 0.3002788871526718, 0.18859407225889818, 0.13368530864162104, 0.12131834296243531, 0.10467168728687934, 0.10870545583644084, 0.15682831965386868, 0.10545048942523343, 0.11128627735057048, 0.10474950168281794, 0.1356112760092531, 0.2383880524763039, 0.19301930123141833, 0.1638595980725118, 0.12926520939384187, 0.2195211420101779, 0.11478497354047638, 0.23656325467995235, 0.15624954285366194, 0.1258622341390167, 0.09033690220011131, 0.1591621951333114, 0.09224143464650426, 0.20816011806683882, 0.11569338265274252, 0.13332290308816092, 0.1396890679108245, 0.0812281599002225, 0.19836588576436043, 0.14261576586535998, 0.14588557183742523, 0.11980420563902174, 0.06945301924965211, 0.13719391822814941, 0.11701459889965397, 0.13321401178836823, 0.09994090721011162, 0.19000765069254807, 0.11237614029752356, 0.12155865292463984, 0.13962417282164097, 0.109603205163564, 0.32619927770325113, 0.08945256751030684, 0.12312784657946654, 0.16560108533927373, 0.17893287353217602, 0.16541659166770323, 0.10717151886118309, 0.146491639316082, 0.13037019010101045, 0.1582109568906682, 0.12499244724001203, 0.08616195765456983, 0.1043180755472609, 0.17381084337830544, 0.19785118981131486, 0.10103616451046296, 0.13868894800543785, 0.1601169617580516, 0.22174581406371935, 0.1667159997991153, 0.1584581471979618, 0.15101271814533643, 0.20892302212970598, 0.26265319756099154], [0.03973665274679661, 0.04139919585681387, 0.05432526421334062, 0.010015712917915412, 0.007614293518210096, 0.05275712228779282, 0.05154872605843203, 0.008318882585237069, 0.05139022706342595, 0.011936883042965616, 0.002342483968407448, 0.05192336220560329, 0.008003206890342491, 0.02842276493486549, 0.08374129076089178, 0.08154074062726327, 0.03952166231881295, 0.05611392662727407, 0.05219920365405934, 0.03278016585058399, 0.03890600374766758, 0.020348795323765705, 0.03976258974788444, 0.035904320888221264, 0.03595106177298086, 0.06550549928631101, 0.04415976469005857, 0.01864713297358581, 0.008872286416590214, 0.049908133556268046, 0.014289570905800377, 0.12637418881058693, 0.027265616759125675, 0.02417136645609779, 0.034296684831913025, 0.034323829625334056, 0.017192671108724814, 0.03432644877050604, 0.010925228890430714, 0.023277257469349673, 0.02426699409261346, 0.03429095460368054, 0.06515610124915838, 0.04772498106051769, 0.01667124917730689, 0.054864553668137105, 0.01076379353513143, 0.013098047297847058, 0.025150760509339825, 0.046967708838305304, 0.01639018640188234, 0.0411359683743545, 0.009910556953400373, 0.06782098646674838, 0.03214974235743284, 0.03359986329451203, 0.015904545318335295, 0.06428022789103643, 0.03786009629922254, 0.057945228181779385, 0.0471136515427913, 0.020496615873915807, 0.041732315838869126, 0.027326564470838224, 0.04882113063441856, 0.03811554437769311, 0.050161769946238825, 0.01312255343821432, 0.032803765298532586, 0.06737396759646279, 0.012903831915796866, 0.04821455764717289, 0.056628775250698836, 0.008378393499047627, 0.08643202137734209, 0.06563463807106018, 0.022025743732228875, 0.024453102677528347, 0.02653438501459147, 0.03836061765572854, 0.051611327699252536, 0.07101939019880124, 0.01174601707940123, 0.046295691148511, 0.016172483530161635, 0.025932429458147714, 0.022365723703322665, 0.006586872332263738, 0.02992605757234352, 0.029625344422778914, 0.03697609409157719, 0.020546866481059363, 0.019352398879293884, 0.041338595894298384, 0.09036882727273873, 0.03378098464703985, 0.026187202394274727, 0.047191133456570764, 0.029463222050773244, 0.0321888734719583, 0.03863250324502587, 0.03956310045240181, 0.010332413200688149, 0.06958842769797359, 0.03493585464145456, 0.10921600594052247, 0.014039868322600211, 0.013368502874592585, 0.027399837771164517, 0.05639580364472099, 0.009645111509598792, 0.03738647885620594, 0.07248345842318875, 0.049694880177932124, 0.034389976611627, 0.029489257439438785, 0.007625650498084724, 0.022274409853188053, 0.036434887775353024, 0.00916741183027625, 0.060129133851400444, 0.03184911063207047, 0.030322990380227566, 0.058529969304800034, 0.049093094255243025, 0.008138399903795548, 0.051653060995574505, 0.004587622758533273, 0.023062226329264895, 0.03623171742739422, 0.058472782373428345, 0.0331059339057122, 0.02910285210236907, 0.02548586859899972, 0.018435967786769782, 0.022367479412683418, 0.026952776492440274, 0.025223165284842253, 0.05055063497275114, 0.016788586541744213, 0.037442963503833325, 0.04027093122048037, 0.04780299223161169, 0.013234375161118805, 0.04744328724752579, 0.029566871667546884, 0.05149458235661898, 0.09388352331838437, 0.0829546447577221, 0.08789233051772628, 0.038824392948299646, 0.019631807725610476, 0.022651419176587036, 0.00872018770314753, 0.027788662085575715, 0.011692754624943649, 0.018307612709967152, 0.04641960860629167, 0.017973478318059018, 0.05799243386302676, 0.00999166987769838, 0.031940804461815527, 0.02998289166550551, 0.05252819475052612, 0.029944347483771186, 0.03034608092691217, 0.09664299631757395, 0.02252352041458445, 0.03691320407337376, 0.037004592562360425, 0.022784965046282326, 0.056502384532775195, 0.024361933016085198, 0.04922724062842982, 0.02258290071040392, 0.03837809332513383, 0.05192640543516193, 0.03408468335068651, 0.04522070847451687, 0.03658951912075281, 0.07292579540184566, 0.024444486979129057, 0.011427928344346583, 0.01725784270092845, 0.06531791149505548, 0.05274792474561504, 0.08424966276756354, 0.024041912152564952, 0.008258985754634653, 0.015718480838196616, 0.03686086866738541, 0.013980488026780742, 0.01740884897299111, 0.023051904115293707, 0.025442740913214426, 0.06272521561809949, 0.07760411793632166, 0.006917318886345518, 0.08276233436273676, 0.03739725399230208, 0.03135200230670827, 0.00565974201474871, 0.05776625778526068, 0.004308972599184406, 0.03617085962157164, 0.04722722812688776, 0.02219553354994527, 0.1141577357692378, 0.024472915900072882, 0.08140225841530732, 0.008997697499580681, 0.06409194799406187, 0.04637763782271317, 0.05927882090743099, 0.053682091047189066, 0.05335878607417856, 0.008442851781312908, 0.053519799041428735, 0.01575228206015059, 0.027488311952246085, 0.023443618988884345, 0.016106892942583988, 0.04573533318138548, 0.013775807938405445, 0.05096265161409974, 0.04616669824879084, 0.0349595796183816, 0.03218614236850824, 0.03884553949215582, 0.09638425734426294, 0.016694400792143176, 0.01213222140047167, 0.034160380717366934, 0.05904955749533006, 0.03322320172031011, 0.03588114891733442, 0.015815969357000928, 0.008252453158742614, 0.026036068896896074, 0.032937918457069566, 0.03326425648161343, 0.02691706519440881, 0.06263310448931796, 0.029193110830549682, 0.04722473451069423, 0.043622171572808704, 0.03936243050598672, 0.019853405388338224, 0.0887352813567434, 0.015055519894563725, 0.03636270182739411, 0.07522726404879775, 0.0659943362697959, 0.056501580468778095, 0.06149931318525757, 0.032834798097610474, 0.027252780572910393, 0.04870802563216005, 0.02274902304634452, 0.022106731975717202, 0.028281171639849032, 0.018550920100616555, 0.036399288435599635, 0.03329019687537636, 0.029778723871069293, 0.0139787636996646, 0.04029387927481106, 0.04180764001128929, 0.05380511283874512, 0.06933317639465843, 0.013833415561488696, 0.011252080905251205, 0.05936553089746407, 0.05481412833822625, 0.005977609377753521, 0.01538830400178475, 0.06366492555077587, 0.04026615433394909, 0.04706456631954227, 0.048242533645991764, 0.11926482458199773, 0.08681265916675329, 0.038133406812059026, 0.062335865439048836, 0.04968320259026118, 0.07811279528375183, 0.009736613653201078, 0.048073870196406326, 0.07571358366736344, 0.046435367582099776, 0.00573832357934277, 0.02121436512762947, 0.011139397442873036, 0.03962622795786176, 0.04013394517824054, 0.0360101791364806, 0.04980191568444882, 0.08306190757347004, 0.03449138367016401, 0.02324544096232525, 0.011652575173814381, 0.0077178667997941375, 0.027515171760959283, 0.026363297498651912, 0.05316718474828771, 0.05243396659248641, 0.09282327842499528, 0.017784791300073266, 0.012658555077255836, 0.017255566215940883, 0.015298584708943963, 0.02157917948040579, 0.02383934230809765, 0.044715820745165856, 0.04901291177208934, 0.010443280733722662, 0.04446015553548932, 0.03207402124202677, 0.04467186185398272, 0.06775880551763944, 0.06201352059308972, 0.028420929497640048, 0.002843050065816247, 0.04190142372889178, 0.014911463517429573, 0.09155770883496318, 0.015514765965885349, 0.017152776642303382, 0.06655754747667483, 0.01064254017546773, 0.03923961566761136, 0.009161058197995382, 0.04507986496069601, 0.05886416137218475, 0.017493633619908775, 0.034604668484202454, 0.04558423700343285, 0.012334337474645247, 0.03005988842674664, 0.030485139893633977, 0.024125326158744947, 0.08189653724964176, 0.06753222910421235, 0.04019643146810787, 0.01735802839643189, 0.07114118044929844, 0.027421596692875028, 0.08233289633478437, 0.07978649011680058, 0.017004806814449172, 0.02836340499509658, 0.03455987499494638, 0.13790547076080525, 0.11181204699512039, 0.09543807418750865, 0.15705355256795883, 0.1891369138445173, 0.09751408600381442, 0.131169748625585, 0.06401316329304661, 0.19219843670725822, 0.1296007449605635, 0.15002378049705709, 0.16925723558025701, 0.19287961801247938, 0.12834355527801172, 0.1255505151514496, 0.14743673003145627, 0.089490741890456, 0.1547804602554866, 0.10768316140664475, 0.14984846061893872, 0.1612147499940225, 0.11001799362046377, 0.17926691632185662, 0.15108104662171432, 0.0990516667121223, 0.14668323046394757, 0.2624975959105151, 0.1480016918586833, 0.08086935058236122, 0.14221114186303957, 0.11435064327503953, 0.2657633035310677, 0.10373148880898952, 0.15828548717711652, 0.2361680758850915, 0.16624935769609042, 0.1346544466380562, 0.12234968904938016, 0.10732605521168027, 0.17177302629819938, 0.08485535705196005, 0.07919843095753874, 0.24932242717061723, 0.09504313287990433, 0.0652028319558927, 0.16678020278257982, 0.08879613237721579, 0.10247966633843524, 0.10933901076870305, 0.1489880375031914, 0.1262649582432849, 0.2321995688336236, 0.15568375321371214, 0.18214847812695162, 0.08251576152231012, 0.10433493035712413, 0.14822558127343655, 0.1312603059091738, 0.10060205137623207, 0.1203383891178029, 0.10494936417256083, 0.11193454292203699, 0.10056465731135436, 0.10614232373024736, 0.16283429094723292, 0.10483552635248218, 0.10514373052865267, 0.158391677907535, 0.11764209451419966, 0.19297260445143494, 0.08375762988414083, 0.10764324997684785, 0.3378153629601002, 0.13485789857804775, 0.3054942158716065, 0.1546759522919144, 0.10829934584242956, 0.09224554656871728, 0.17564705413367065, 0.10252584743180446, 0.12854350597730704, 0.10676979898874249, 0.10757632606795856, 0.1276317991848503, 0.16197027159588678, 0.05482401120077286, 0.10897393857261964, 0.11224744934588671, 0.11108728338565145, 0.1269188081579549, 0.17619669464017662, 0.11867835319467954, 0.12731903525335447, 0.11275928188115358, 0.1784443011773484, 0.1433334116424833, 0.07973729632794857, 0.12094974916960512, 0.08109357926462378, 0.11846180552882807, 0.11262431448059422, 0.15651198662817478, 0.10802360956690141, 0.17670137541634695, 0.20871544469680103, 0.21469010838440486, 0.18781454408807413, 0.10484928704266037, 0.15748397447168827, 0.1744046565145254, 0.09364402759820223, 0.1748812459409237, 0.11069844889321498, 0.10259606223553419, 0.08803518928055253, 0.09818657527544669, 0.11604132183960505, 0.11519194527396134, 0.10336293572826044, 0.17188734587814125, 0.13109559831874712, 0.2529946586915425, 0.11798896161573273, 0.1085522494145802, 0.14363670322511876, 0.10770418242152248, 0.09837691791887794, 0.11517814387168203, 0.15580040695411818, 0.1666184128927333, 0.1626210952443736, 0.11190008691379003, 0.07878656698656933, 0.09882400464266539, 0.1931107406105314, 0.10142876487225294, 0.18637287430465221, 0.2140208828662123, 0.17859558734510625, 0.06212660523929766, 0.11919754104954855, 0.11321810047541346, 0.159561512991786, 0.12830517733735697, 0.10392856930515595, 0.09199969297541039, 0.0796196519264153, 0.1867739563541753, 0.1719449670719249, 0.1487449048353093, 0.1454647851309606, 0.07273217543427433, 0.14332178155226366, 0.09757570376885788, 0.08676734659820795, 0.15365322359970637, 0.08826428305889879, 0.17749242511178764, 0.09586980566382408, 0.13546448174331868, 0.11210187644298587, 0.10410683402525527, 0.13446851447224617, 0.1316926684230566, 0.135327974068267, 0.15985759853252343, 0.12049922905862331, 0.11479819140263967, 0.15159506403974124, 0.11651062379990305, 0.08344659621694259, 0.19586804908301148, 0.1943656097033194, 0.1034646209861551, 0.13220325245388917, 0.20233235721077236], [0.03830451638038669, 0.1030889975705317, 0.03578823711723089, 0.030553424265235662, 0.05652334787217634, 0.06290180435670273, 0.01986219241682972, 0.012049269646273127, 0.032283807306417396, 0.04820761962660721, 0.012230261228978634, 0.04194145729499204, 0.04827633826062083, 0.05805726109870842, 0.09789738365049873, 0.047913454339972565, 0.052095292801303525, 0.054575745415474684, 0.0010164002929481544, 0.05427244704748903, 0.09007240246449198, 0.04295153470177736, 0.018288028492991413, 0.02512657073592501, 0.028852496429213455, 0.02875164576939174, 0.03694608248770237, 0.030590034622166837, 0.02101117611995765, 0.06236473031874214, 0.04457466171256133, 0.004332059753193919, 0.04812024806493095, 0.07391364060874496, 0.0030536382858242306, 0.007361294102988073, 0.033910846071583886, 0.07405086074556623, 0.0205283221189997, 0.06809219691370215, 0.05680607984374676, 0.04573330096900463, 0.028761274181306362, 0.029041292012802193, 0.04516423061223967, 0.014233584981411695, 0.0030219952293139484, 0.04069311910175851, 0.02205537535649325, 0.015892012776540856, 0.040223213245293925, 0.03828446567058563, 0.02929595299065113, 0.058338778492595465, 0.04625037518729057, 0.013388127803669443, 0.048064608193401775, 0.05215758570869054, 0.02783568116969296, 0.019137630671528832, 0.06213356022323881, 0.03879564341955951, 0.01727933529764414, 0.021709142685202614, 0.020545411023444364, 0.027125930147511617, 0.07316773384809494, 0.004266107421634453, 0.018851239699870348, 0.018316895069022263, 0.014097758385884975, 0.03141875318916781, 0.008322443197747427, 0.028257148107513785, 0.041316350123711994, 0.030176487884351184, 0.08722465884472642, 0.037282435689121485, 0.027259157105748142, 0.07122911858771529, 0.009322894737124443, 0.034337264618703296, 0.014420482363285763, 0.04872741816299302, 0.005636545871051827, 0.012260655356970216, 0.04595582992104547, 0.007135735492088965, 0.01657924152511571, 0.04905108615223851, 0.01777101195018206, 0.023925438223938857, 0.04239169242126601, 0.03253288733373795, 0.03456901486164757, 0.059994532859751155, 0.04560485428997448, 0.06853058481855051, 0.01438590930774808, 0.019064016407355666, 0.022749357224841203, 0.02189856082467096, 0.024218726504061903, 0.03216988466946142, 0.02578020521572658, 0.00892841228882649, 0.030870842946959392, 0.037106362637132406, 0.1110758568559374, 0.021555466377841573, 0.032440467471522946, 0.056335461525512595, 0.0725651133273329, 0.03191146121493407, 0.05142218606280429, 0.09793950031910624, 0.027671916742942164, 0.042221858498773406, 0.0836032224552972, 0.027223576425707767, 0.05759828644139426, 0.0781568322064621, 0.016643381744091, 0.03026045998558402, 0.008616674641546394, 0.05025509904537882, 0.010529866042946066, 0.022728943498805165, 0.028994781829948937, 0.02320827929569142, 0.05795193210776363, 0.028274067378203784, 0.03591353539377451, 0.038613724788384776, 0.04514394920053227, 0.009257886841494058, 0.0409530794381031, 0.03335495625755616, 0.048659601980554204, 0.0405706299601921, 0.07231204690677778, 0.022193927118288617, 0.0218732124527118, 0.015086215122469833, 0.06791910941579513, 0.015947423642501235, 0.023770808574876616, 0.027035997116139958, 0.0404459762919162, 0.021676908879141723, 0.07926995533385447, 0.040489270218781064, 0.012315877929462917, 0.031176692606615167, 0.01915965591823416, 0.030661667564085553, 0.041767901607922146, 0.021932134737393687, 0.04923095900033202, 0.02855986123904586, 0.04447137850469776, 0.035876578983983824, 0.04951754165813327, 0.06289488329951252, 0.05929891911468335, 0.051349603171859465, 0.047152355180255005, 0.035568520692842345, 0.09015415914888893, 0.015296167427940028, 0.04248453636786767, 0.05170412414840289, 0.05272309036393251, 0.019239984286416854, 0.07408342364111117, 0.04817209153303078, 0.03085334352882845, 0.026536586860726987, 0.08737150060811213, 0.07228657470217772, 0.06397678703069687, 0.009459477051028183, 0.02931918263701456, 0.05201440803440554, 0.025457772160215036, 0.02803397285086768, 0.01927486777172557, 0.061367405977632315, 0.01826953502105815, 0.027828663421262587, 0.06177427593086447, 0.02644981919521732, 0.04712355136871338, 0.028806138916739395, 0.032534095126071146, 0.04240752603592617, 0.03214092479486551, 0.052719880893294296, 0.02714199446407812, 0.03536943173302071, 0.03521856964964952, 0.038699196452008824, 0.05213548582313316, 0.035660095778959136, 0.011116089764982462, 0.06248880723225219, 0.061203750116484504, 0.049689027813396285, 0.047517563083342144, 0.06756613549909421, 0.039317874503987174, 0.035998762784791846, 0.05952075935368027, 0.1084533529356122, 0.04316390259191394, 0.0315018906923277, 0.024957133756418313, 0.029565219434776475, 0.04834882276398795, 0.021232488797977567, 0.023584345455414484, 0.02694814040192536, 0.049515981027590375, 0.027020865785224096, 0.0590359325121556, 0.04298345298905458, 0.017342340666800737, 0.0272316917045308, 0.05198295793629118, 0.023005828194852387, 0.02031412218431277, 0.017075011440153633, 0.10689422195511204, 0.03624194973547544, 0.034359958222401996, 0.009508910023474267, 0.0018200433862927768, 0.09436550031283072, 0.013574247414778386, 0.0053202692485813585, 0.035219404247722456, 0.007498588030492621, 0.007064590247214905, 0.015777711856311986, 0.012358837677831096, 0.0159493981794055, 0.022848984825291803, 0.07434210154627051, 0.020697114490238682, 0.02495029242709279, 0.023383923174281205, 0.034073263606322665, 0.011658976303546556, 0.011986268517960395, 0.022671054283689176, 0.06961293638284717, 0.035509199768837006, 0.011887120132866715, 0.08679032179393939, 0.05083659677101033, 0.045241502180163345, 0.03981470802266683, 0.030942608203206743, 0.014253423649019428, 0.057834816963544915, 0.05518913767965777, 0.02253332863827901, 0.01744396485654371, 0.05498990962015731, 0.053725958336144686, 0.08643394841679505, 0.056731420635644875, 0.05693394637533596, 0.08433059163923774, 0.051915304602256844, 0.015008137794211507, 0.042140251092080555, 0.05313031994072454, 0.026019324348973374, 0.057561143434473445, 0.0018545871800077812, 0.02382007530624313, 0.05674012963260923, 0.0280714907483863, 0.04841144136818392, 0.016559277328529527, 0.06859050624604736, 0.10223011472927672, 0.03792080143466592, 0.038474967769746266, 0.03956279171896832, 0.062358983127134185, 0.056572860572487116, 0.02997167208897216, 0.03116426184507353, 0.04722378795434322, 0.03940025204792619, 0.0385879099236003, 0.013111060751335961, 0.01175527399339314, 0.0295110893036638, 0.06977729113506419, 0.0242173728266997, 0.017859710047819784, 0.004123445009879235, 0.036370474446032725, 0.02954027648749096, 0.03154551370867661, 0.02111441352670746, 0.04896113955016647, 0.07454353145190648, 0.04927704170612352, 0.04743432719260454, 0.008246332772874405, 0.021087750493149673, 0.03199170815891453, 0.07780818055783, 0.06928970265601363, 0.04504927660205534, 0.05381138589499252, 0.016774556133896112, 0.009508681017905474, 0.0446991830665086, 0.02691004066062825, 0.025226573226973414, 0.014855852483638694, 0.04797643256772842, 0.013989547317448472, 0.03523948209892426, 0.031465049633490186, 0.013751524866425564, 0.017487087453316365, 0.015533954936212726, 0.01782101658838136, 0.035839649715593884, 0.10396661476365157, 0.045895915278898816, 0.008510205711770271, 0.0528225975244173, 0.05309461882071836, 0.04137410023914916, 0.026728474867663214, 0.043817745721233745, 0.02880909393674561, 0.016493296583316157, 0.011723141119416271, 0.03401391893359167, 0.007771071578775133, 0.03685914518843804, 0.03322477592155337, 0.08111905825457402, 0.08475126299474921, 0.09767966211906501, 0.21498771384358406, 0.16265424846538476, 0.1624500501368727, 0.14013258554041386, 0.13786417511957033, 0.1353256670492036, 0.10210695383804184, 0.13775332963892392, 0.10663033290100948, 0.10662544066352503, 0.13300567439624242, 0.11104610309536968, 0.14396966035876954, 0.16364052625639097, 0.1147419408495937, 0.15527712074773653, 0.2174676779125418, 0.10267757464732442, 0.15323402466518538, 0.17047593875655107, 0.23059149512222835, 0.11804252517010484, 0.12856479840619223, 0.21017874617661747, 0.120623984507152, 0.1489097617034401, 0.20278800704649516, 0.09209390756274972, 0.1424613312951156, 0.11383310426026583, 0.17860538539077553, 0.1579512001148292, 0.1553327063364642, 0.09826603172613041, 0.0822685237175652, 0.13190122294638837, 0.19224138797393867, 0.10203437094709703, 0.09264472193483796, 0.10361412260681391, 0.1740151909845216, 0.13028409757784434, 0.14309688790568284, 0.15173880489809172, 0.10758756260786738, 0.15958235758755887, 0.11777860218925135, 0.17733686417341232, 0.1786477802587407, 0.1051103805324861, 0.12270824052393436, 0.2192486830587898, 0.12348949217370578, 0.09622733255050012, 0.1101859649643302, 0.17578430819724286, 0.18632491544953414, 0.10323477403393813, 0.1342578022075551, 0.12796330425356114, 0.16902413165995053, 0.2264329982655389, 0.09115787528987442, 0.1931961410279785, 0.12426076935870306, 0.10923613128917557, 0.09485180636069604, 0.10811469610780478, 0.10317924272801195, 0.09376132594687597, 0.17044692459915364, 0.1273747565490859, 0.10376787864203964, 0.1408217599881547, 0.09029834105500154, 0.21423947970782006, 0.12730583096189158, 0.11754488758742809, 0.17858425581029483, 0.14497011953166553, 0.11024941477392401, 0.15295285332415784, 0.1527385719652687, 0.12424497306346893, 0.08467057161033154, 0.09856399002351932, 0.052779575011559894, 0.23444342985749245, 0.1728029338909047, 0.11678419554872171, 0.07765579516334192, 0.17697876053197042, 0.07774373330175877, 0.1468294004776648, 0.18707479164004326, 0.16520627295332296, 0.17656317140374864, 0.15304461840007985, 0.11036385649016925, 0.12538990591253552, 0.12049275583454541, 0.09386969477470432, 0.11618993457938943, 0.13171364872583322, 0.07740452007523604, 0.13363413353051457, 0.17448895770524228, 0.15656234749725886, 0.09966483845242433, 0.16667190859360353, 0.206025487610272, 0.1377241662038224, 0.15465122647583485, 0.09601543963487659, 0.1160717202084405, 0.18533468858471938, 0.1216878459921905, 0.1488674482596772, 0.17325333186558314, 0.1101462028122374, 0.21071415101843222, 0.09554128614919526, 0.08550917303987912, 0.10024530480482749, 0.14576135921691144, 0.07639277686497994, 0.16056837753525802, 0.2269165494612285, 0.14467605602528366, 0.16848435705261572, 0.13702923777912343, 0.1113216561664428, 0.1991594596100705, 0.2033663767256907, 0.17542989578630241, 0.19533329563481466, 0.0706675358648811, 0.13584478705057076, 0.1687289417854377, 0.25136492614235195, 0.1280499803168433, 0.10365307730223451, 0.11563722709459917, 0.2660861504929406, 0.09493116103112698, 0.11074469784008605, 0.0927916926198772, 0.11836894122617585, 0.14227400134716714, 0.15592252968677453, 0.09736484901181289, 0.12894348880009993, 0.10198827127793006, 0.09666800033301115, 0.08136417903006077, 0.16112196711557253, 0.09602014188255582, 0.18073397688567638, 0.18968048824795655, 0.14362843866859162, 0.19425055730555738, 0.12915372609027795, 0.16628910627748283, 0.11725793512804167, 0.12435699919504778, 0.13251134806445666, 0.16419015319219657, 0.1176683809608221, 0.08621596904205424, 0.12829134879367693, 0.10158632748893329, 0.10976948016988379, 0.1315648459962436, 0.13393483310937881, 0.12421327190739767], [0.03953111770429781, 0.04276554825316582, 0.03324396828455584, 0.014786046497257692, 0.1014616127525057, 0.0215141113647925, 0.04947129949661238, 0.06293764457638774, 0.0472393569403461, 0.014654938264616897, 0.013307513602610146, 0.008386809877785189, 0.057887383071439605, 0.04595320059784821, 0.06354519126138516, 0.04109746490472129, 0.06442932239068405, 0.0274573045982314, 0.04070750743682895, 0.008492503581302506, 0.04129172269521015, 0.006784782337490469, 0.020956747433436767, 0.028108898383964385, 0.07673863973468542, 0.04558691382408142, 0.029688387111361538, 0.03185057287503566, 0.10892718750983477, 0.03423621039837599, 0.06551366884793554, 0.060193900018930435, 0.02790105462606464, 0.017748374325622405, 0.06268134154379368, 0.007327038262571607, 0.024396584103150026, 0.023193115734362175, 0.03533167125923293, 0.006371962480313543, 0.022154539856793623, 0.011287975407737707, 0.05505526611315353, 0.05282244824671319, 0.02254920805405293, 0.03789150568523577, 0.015082725756136435, 0.013821072161330708, 0.04758195944928697, 0.015225637105426617, 0.07290548684873752, 0.027372960999075855, 0.009801335715954857, 0.011558459822221525, 0.04305903500478182, 0.027370121330022812, 0.04419177457956331, 0.04681676533073187, 0.033258675531085045, 0.0845641637487071, 0.027828037472707883, 0.009381643147207797, 0.016383000716034855, 0.04107665762837444, 0.07575005492461578, 0.009788483414532883, 0.025212943154786314, 0.014398915127718022, 0.017774353735148907, 0.04590826800891331, 0.027059752627142837, 0.02840558103551822, 0.023611091609512056, 0.017558353986325007, 0.04479076833065067, 0.015873889106192758, 0.02613966423086822, 0.005205310573468783, 0.03357810606913907, 0.07069221418350935, 0.01755892565207822, 0.02754112911809768, 0.02022667937645955, 0.006511109656587775, 0.007133656630425581, 0.04242576505722744, 0.04239245916583708, 0.008500586629712155, 0.021563547729913677, 0.06211022540394749, 0.09037522585796458, 0.0316275010949799, 0.041361886608813486, 0.05587566923350096, 0.020726937800645828, 0.020719762292823622, 0.041863008468811, 0.031940071643995385, 0.02934695846800293, 0.023064614772530537, 0.06748076900839806, 0.024217808785449182, 0.031113836515162672, 0.044168850273958275, 0.012303554037186717, 0.05266872953091349, 0.006821933826099017, 0.010466998077130743, 0.019500616372429898, 0.035592710466257164, 0.059225929102727344, 0.05215484103454011, 0.09251875190862588, 0.013916077241966767, 0.04914724474240627, 0.029745102460895265, 0.08706680445798806, 0.026856049629194394, 0.014728092821314931, 0.03075832487749202, 0.04228129477373191, 0.07304094279451029, 0.05703644587525299, 0.04910241054104907, 0.02787352815669562, 0.034705838055482933, 0.04461334838664957, 0.029458343383989165, 0.028301958560145328, 0.03373460338584014, 0.07082996357764516, 0.020283018139057925, 0.04378130499805723, 0.04040026678038495, 0.027497475567672933, 0.012031248604346598, 0.07108197826892138, 0.024241167353466153, 0.03727793700194784, 0.007318069725962622, 0.06830383877136878, 0.04192177638677614, 0.02312695517736886, 0.04918525627415095, 0.050849197166306634, 0.012651088647544384, 0.02071557573175856, 0.027291516440787485, 0.022764787111165266, 0.024405474608231868, 0.022072260700432316, 0.029960832492049252, 0.018016010589365448, 0.07099643535912037, 0.05785794143698045, 0.0050170238911440325, 0.007950399902516177, 0.012567884987220168, 0.0402862796826022, 0.031044198466198783, 0.054032238865537305, 0.024421450715245943, 0.051604220044932196, 0.0636076300538012, 0.037306812059666426, 0.06698309749897037, 0.03591622578512345, 0.049257007959697924, 0.023930729100746766, 0.03712043884609427, 0.024592348241380284, 0.07205641562385218, 0.06234066268163068, 0.02157930500938424, 0.03126363669122968, 0.0357425479617502, 0.03835212239729507, 0.03630073122414095, 0.01993055990897119, 0.023483888345903585, 0.07335512486419507, 0.08244425071669476, 0.025742972302915793, 0.045464475572641404, 0.011497278015927544, 0.06346077471971512, 0.02947345096617937, 0.04394854013142841, 0.062349985752786906, 0.041954135721815486, 0.06605550620172705, 0.02401955781637558, 0.040899794083088636, 0.05280386656522751, 0.11901246383786201, 0.05541991761752537, 0.028206146022837077, 0.0033848838148904698, 0.035324183625302145, 0.03574901779315301, 0.03840022713744214, 0.04520540411717125, 0.07097151955323559, 0.018724523285137754, 0.11383007799408265, 0.03543769235589674, 0.025084136852196286, 0.05026139585035188, 0.03139645992113011, 0.020803274686581323, 0.03103893981980426, 0.023123603214376738, 0.02250065717713109, 0.010102659547036248, 0.022513637552037835, 0.01977253588847816, 0.053292815506990464, 0.03712456433900765, 0.054573282333356996, 0.016724960313045552, 0.008585786031159972, 0.03539831018341439, 0.01544221700169146, 0.03935122789282884, 0.060076099554342885, 0.04427035911274808, 0.020603128908468143, 0.07142143576805081, 0.012350470492882388, 0.026384824022118534, 0.021794090180524757, 0.0485529735950487, 0.03825872205197811, 0.02902342957843627, 0.03790348522099001, 0.02956742128091199, 0.10015776700207166, 0.02507349572676633, 0.016239936696365476, 0.0232095956536276, 0.015301081717812588, 0.04281839256041816, 0.016994538883279477, 0.022975075291469693, 0.032163927131997685, 0.08554534574172326, 0.036791980399617126, 0.006444635277148336, 0.04366751467542989, 0.02770291391893157, 0.02201459540187248, 0.05769432628793376, 0.047413621696510484, 0.028619548571961265, 0.014365266576143247, 0.08370421560747282, 0.03574265652735319, 0.049511791073850224, 0.0328580277439739, 0.02221537391389055, 0.016010527399235537, 0.0354814409012241, 0.037017365984086475, 0.031200692390224764, 0.024524196184107235, 0.09499332162418536, 0.05928327888250351, 0.01612440762775285, 0.00869942962058953, 0.04588034629289593, 0.021578504338062236, 0.004343510455717998, 0.025606583371492367, 0.05854567060513156, 0.029560788601104702, 0.017326985419328724, 0.008346023985983005, 0.016223002158637558, 0.03449604520574212, 0.012934124263535653, 0.06991612618522984, 0.05580096592062286, 0.05427478799330337, 0.039229912616844685, 0.02060510514170996, 0.03556862586577024, 0.00854122409197901, 0.015928421269303987, 0.07262417980070625, 0.022672955878078938, 0.036149892889495404, 0.023034494603052735, 0.05752668064087629, 0.04428226400965026, 0.02446911101495581, 0.02419851633853146, 0.011471835497234548, 0.091042517551354, 0.02703839404109333, 0.16037618927657604, 0.046441834020827494, 0.04839529223474009, 0.04376761894673109, 0.056174519804439375, 0.04273569271234529, 0.01977846967721624, 0.012708547841092306, 0.0189001620747149, 0.04803791462576815, 0.014530467800796032, 0.0033045851326148424, 0.030493852283273424, 0.025884519796818495, 0.013617392063939145, 0.014620991157633918, 0.05155212212620037, 0.09245180085833583, 0.014701497641259005, 0.08429078198969364, 0.045612942427396774, 0.03788763803562947, 0.04944146091916731, 0.06281979661434889, 0.0004471813476162164, 0.07446127943694592, 0.0052188409858250195, 0.007394009668912206, 0.032404206560126374, 0.01774646424954491, 0.04239137011713215, 0.05515278855870877, 0.050752271831567795, 0.028377420135906765, 0.003752192632029099, 0.014201536924312157, 0.03579427268622177, 0.026809810860348598, 0.02501299584816609, 0.05353698294077601, 0.060692046502871175, 0.04372660489752889, 0.044364923145622015, 0.024371337511443665, 0.010131353096637343, 0.050385839172772, 0.011907996110884207, 0.04218888169686709, 0.03456963572118964, 0.060069361701607704, 0.02765411707306547, 0.02285440462375326, 0.07650527118572167, 0.11181001139006444, 0.14294115054820264, 0.11185620605413403, 0.15708574226924352, 0.22937824736748422, 0.15049150825611182, 0.1120836917044861, 0.0773312450785722, 0.10074402804353408, 0.19007232865052565, 0.16502910745995386, 0.10844373130904776, 0.10823049489408731, 0.18009747032608303, 0.17126263225717203, 0.11381236144474574, 0.11690658969538552, 0.1940705148237092, 0.1855771698589836, 0.10133941538099732, 0.25780788755842615, 0.06799705273338727, 0.11260549191917692, 0.07464275362768344, 0.13044911729437964, 0.1729885403599058, 0.1422017237969807, 0.11584559162812573, 0.1645053191376584, 0.1153058713035924, 0.11233511607029609, 0.14585574343800545, 0.08967866894922086, 0.10414709829326187, 0.14901179979954446, 0.10979704904769148, 0.13690471303250107, 0.07085517793893814, 0.10840538729514394, 0.0771620591570224, 0.13562826652612003, 0.08165008654551846, 0.12394827684121472, 0.13658585585653782, 0.07603585387447051, 0.13574402460030147, 0.08617150464228221, 0.12728605845144816, 0.15891743398138455, 0.0924649169402463, 0.1302866352988141, 0.1307629533112049, 0.09553781883524996, 0.12494850531220436, 0.11355086761925902, 0.17889611050486565, 0.14784201899809496, 0.12794779294303485, 0.09823146036693028, 0.2201969628887517, 0.09826061023133141, 0.10459325542407376, 0.10075932222285441, 0.17745111589985235, 0.13103391948555196, 0.13645113951393537, 0.17332440162343637, 0.0786405937480075, 0.07446795622152941, 0.12871019488998822, 0.11526312359741755, 0.1191058981099299, 0.12951959217233316, 0.07624237957809653, 0.15952549635299615, 0.08583301744822945, 0.08639909885823727, 0.2169292468045439, 0.11366735851126057, 0.13374476187995502, 0.12041469716600009, 0.09408395577754293, 0.13753246649035386, 0.1599753922117608, 0.10289090605718748, 0.10720004447336708, 0.15214056548263344, 0.08657150782112565, 0.09225877800158092, 0.15558464638888836, 0.17360082321933337, 0.11935378052294254, 0.08114644392792668, 0.17387212866118976, 0.14592551040862287, 0.06771103665232658, 0.07267454745514051, 0.06940384581685066, 0.109970991499722, 0.17074577856276715, 0.22970695687191828, 0.11991560751838343, 0.08148586071495499, 0.10959804151207209, 0.13675903156399727, 0.16690886659281595, 0.16013404726982117, 0.12972216201680048, 0.1488273332693747, 0.07200613617897034, 0.2155806448842798, 0.08020956348627806, 0.18265967283930096, 0.08826502266206912, 0.1163452241037573, 0.20325606050235884, 0.2176325890634741, 0.14915020737264836, 0.13739165690328392, 0.08480325913322823, 0.09441859567803995, 0.14909654882337364, 0.09579060027109725, 0.36900799774697846, 0.12012056580611638, 0.11329708195158414, 0.1347542998514005, 0.20750411041080952, 0.1136418930920107, 0.10249536085341658, 0.17594528384506702, 0.07344853199486222, 0.15831142078552926, 0.153482816315123, 0.08953173219093255, 0.1633384424660887, 0.14240628853440285, 0.14499791232602938, 0.11038873836930309, 0.09624711184629373, 0.22062861972621509, 0.12263888067432813, 0.12920327271733964, 0.16032251715660095, 0.17170434498361178, 0.13308165674763067, 0.14951228722929955, 0.13706140033900738, 0.13701684772968292, 0.11019140002982956, 0.10229007686887469, 0.21295102313160896, 0.06968870160302945, 0.12051354614751679, 0.08003002312034369, 0.12320758801485811, 0.07883804743843419, 0.07885114994964429, 0.14267847607178347, 0.12338068229811532, 0.16539027807968004, 0.12321160494216851, 0.13420624711683818, 0.1712513550051621, 0.20979669024901731, 0.11247804268662419, 0.16307133037064755, 0.12355510651000909, 0.05787628223853452, 0.08414016757160425, 0.10915345858250346, 0.160379826224276, 0.2264198482568775, 0.18617455208940165, 0.12271004542708397, 0.196043301107628], [0.004810363752767444, 0.03857657499611378, 0.014667911854173456, 0.03564885923905032, 0.03194679592603019, 0.056143202020653656, 0.03119827341288328, 0.03177761000448039, 0.0530683391594461, 0.03303204483485647, 0.05592936849487679, 0.03456580539100936, 0.062465112789400985, 0.009423444297031632, 0.043941178026476076, 0.024570630031770894, 0.08178390722189631, 0.05284163382436548, 0.03558210835659078, 0.027977330443848456, 0.03570584600259151, 0.05620507423632911, 0.034090922480182986, 0.0032269711165489362, 0.03579782820971949, 0.0075370940446321455, 0.04214232062388744, 0.08818106073886156, 0.025268883278061236, 0.0969200896631394, 0.07079619288976703, 0.042026040077741654, 0.034786980665688, 0.013253358026434268, 0.017105443735740015, 0.04752417879977396, 0.022986556103985225, 0.030949169636837075, 0.019562916065167104, 0.03505970085305827, 0.023503686301410198, 0.029493203120572225, 0.011299435016033905, 0.01551466079295746, 0.062348018001232824, 0.041821587298597605, 0.02948510819779975, 0.011248901120520063, 0.026902497047558427, 0.01046918804890343, 0.03952553675376943, 0.07265714303191219, 0.03534460752936346, 0.023417624312319925, 0.04886686050200036, 0.033882724187735996, 0.027089063643610904, 0.1094019381063325, 0.022308085546163575, 0.04583224155274885, 0.03360741538926959, 0.044387090884681256, 0.06977159144090754, 0.05496693103175078, 0.06495250681681292, 0.010784521931782365, 0.04208449247692313, 0.061799870271767886, 0.05025566562211939, 0.052567376755177975, 0.017263822290780287, 0.021257138278867518, 0.047353534027934074, 0.032651912554034164, 0.008735796553082764, 0.034937398308621984, 0.023679686410884773, 0.008546013701041895, 0.017519774181502204, 0.03038249790136303, 0.02056907323588218, 0.071428465390844, 0.025196431005107503, 0.03969859032492552, 0.029535940648721795, 0.06584359971540314, 0.04699098937479513, 0.007406363247095474, 0.038804481338177405, 0.035312662100685496, 0.03295389795675874, 0.011122294967728001, 0.0029740601229215308, 0.011916463379748166, 0.037833406124264, 0.027662581797423105, 0.0625018554606608, 0.0270254577709628, 0.042656375361340385, 0.013991567655466497, 0.0916176438331604, 0.06650586346430437, 0.021975133501525437, 0.021931169521329657, 0.06866425621722426, 0.006151813065766224, 0.009426780144817062, 0.04304686547922237, 0.057119905682546754, 0.05379766930959054, 0.050699631084821055, 0.027710365929773877, 0.03974794696218201, 0.06821479462087154, 0.0844355338652219, 0.04941665028621044, 0.0477745751850307, 0.03754231120858874, 0.054702736636889834, 0.03529648243316582, 0.05353723060605781, 0.010059307096526027, 0.03588388341345957, 0.026627644563892057, 0.03398492852491992, 0.07584798788385731, 0.038381211193544526, 0.0075230755111468685, 0.01589740882627666, 0.020967035720657026, 0.07121877771403108, 0.060668229923716614, 0.021729877019034963, 0.03526859464389937, 0.02336924646182784, 0.019232343982106874, 0.024144740741966025, 0.04571537407381194, 0.12086984488580908, 0.010509415845652776, 0.013728804969494897, 0.02527597057633102, 0.07198221781956297, 0.03814853475029979, 0.037069901557905335, 0.05881702354443925, 0.022171236907265017, 0.036061632446944714, 0.031655887607485056, 0.0933007024494665, 0.010352184014794017, 0.04242468957922288, 0.012547946235697185, 0.05592079859759126, 0.029395243019929955, 0.0420895272067615, 0.010589695020046617, 0.03162295491035495, 0.009480258034143065, 0.023849917276363288, 0.019424238774393286, 0.0767868971452117, 0.023918432349871312, 0.040478817386818786, 0.050084749436272044, 0.0072181444182725886, 0.01871987192758492, 0.0937763758535896, 0.030533258204481432, 0.011160252216671194, 0.027024792806644524, 0.06210543494671583, 0.04161661883283939, 0.028883386735937426, 0.03526119521952101, 0.033612870810819526, 0.01746948964760772, 0.0708025846896427, 0.036299971264920065, 0.05265598664326327, 0.030275632028601, 0.00577995424724317, 0.07690117601305246, 0.03758444484057171, 0.024386728382004157, 0.035255526059440205, 0.02527189427720649, 0.029194732529244254, 0.01650182407216302, 0.02251081823903535, 0.016464204394391606, 0.027109601202287843, 0.046893646741019826, 0.005220857507083565, 0.04805846066613283, 0.026544710621237755, 0.03240692409287606, 0.018349113608045236, 0.027996814576908946, 0.027930360553520064, 0.01331216496016298, 0.022890641786424176, 0.027041299867310693, 0.038892338052392006, 0.017722057344924127, 0.052350421968315325, 0.03154901494937284, 0.02595536394177803, 0.08818330668977328, 0.03461367603657501, 0.029349937236734798, 0.04486616374924779, 0.027998271730861495, 0.03962697095370718, 0.010245638749828296, 0.02074103436565825, 0.016929837176576257, 0.016443069724898254, 0.020256341534799764, 0.009941052861644753, 0.08022498658725194, 0.006962639512494206, 0.04161135679376977, 0.03164038986765912, 0.02199348108842969, 0.08891973431621279, 0.03284534592447536, 0.059499283720340045, 0.04761023400351405, 0.06060290735747133, 0.0036662044336221045, 0.03194693163303392, 0.05299101670139602, 0.006474880975604589, 0.07456602488777467, 0.06736009155533143, 0.048001962447805066, 0.03935066131608827, 0.08550352762852396, 0.06391396147332021, 0.020162715576589108, 0.013961215087744807, 0.038168127448963265, 0.11446940047400338, 0.05821209600461381, 0.016639763456104056, 0.024694259112168635, 0.02299329565305795, 0.042273698574198146, 0.02877068206933992, 0.03166343291689243, 0.025831422735271708, 0.05238022661900946, 0.0076320974289306575, 0.02212522884032556, 0.041899713820644786, 0.0317685176352305, 0.03137828875333071, 0.08626592279012714, 0.04391040985605546, 0.08135421135063682, 0.0653466135263443, 0.06569544837943145, 0.018804069641711454, 0.06972574282969747, 0.020980402860524397, 0.042683842458895276, 0.0211503131182066, 0.03168888815811702, 0.047800607181021144, 0.028794515611869947, 0.03625800387401666, 0.04013452193300639, 0.04547253656866295, 0.02149744824107204, 0.023033410643360445, 0.03496930981054902, 0.027519909631726996, 0.07129810524306127, 0.02406982029788196, 0.039407295241419754, 0.03140538604930043, 0.029510346307818378, 0.040457806549966335, 0.04136934370866843, 0.051204847903656106, 0.028988128794091086, 0.041056447462843995, 0.05976356632475342, 0.027785169326567223, 0.03263288303943617, 0.03620404676933374, 0.0596564934988107, 0.030406680889427662, 0.0025308465618374093, 0.014693875996662038, 0.039587079879960844, 0.03180320434538381, 0.03547474715326514, 0.00897410314064473, 0.07311999212418284, 0.019423222668202858, 0.025983343333271996, 0.029090655435408865, 0.015210088475474288, 0.0437494376009064, 0.0271289275759565, 0.018257955820964913, 0.07439690003437655, 0.018783898491944586, 0.06571832858026028, 0.04708746348374656, 0.06371135770210198, 0.0734934713691473, 0.03645344910078815, 0.026364347531593273, 0.03332569443487695, 0.0016123301403630258, 0.025167075883863226, 0.014368847544704164, 0.03259525827265211, 0.04182199441960879, 0.048909689632377455, 0.02272737947558718, 0.042774365815733156, 0.03608158137649298, 0.05727891357881682, 0.026032252137416174, 0.03636306145095399, 0.06570750594671283, 0.009987139808280128, 0.05973482358136347, 0.032791789155453444, 0.05839381446795804, 0.0185418362130544, 0.0519434875542564, 0.04477297714246171, 0.08378958209816899, 0.05822450641010489, 0.05745266604104212, 0.065056390528168, 0.008483930291341884, 0.01908684571805809, 0.0635672640055418, 0.011738222408374506, 0.05330334637047989, 0.02483536725464676, 0.011420252416948122, 0.06611263885029725, 0.06561531339372907, 0.06831306006227221, 0.015295926548008407, 0.08754327174808298, 0.16637458811913217, 0.14723064537559236, 0.09291302146656172, 0.09957673068025283, 0.07319210682596479, 0.13887304812669754, 0.1250793540052005, 0.11162173149308988, 0.149692085438541, 0.12952994661671774, 0.11756254306861333, 0.14856992422470025, 0.06811087019741535, 0.13905250706842967, 0.2567358836531639, 0.16425774885075434, 0.09509633681071655, 0.17656754116926873, 0.14559840224683285, 0.08526916163308279, 0.15835290641656943, 0.10020182428083249, 0.13012008209313664, 0.15206546522676945, 0.0782465481066278, 0.07569055418883051, 0.10897678163434778, 0.11640929138021809, 0.22069424763321877, 0.13650831287460669, 0.1353328459497009, 0.12856669830424444, 0.13192379102110863, 0.0617029211883034, 0.11425624548324517, 0.05457223738942828, 0.2047598569520882, 0.07206033077090979, 0.10065956400441271, 0.10850669935877834, 0.09571214805224112, 0.09612080255257231, 0.1335433591157198, 0.1688655037432909, 0.12006852217018604, 0.1232467530561345, 0.08365810236760549, 0.12481685594788619, 0.3231898120471409, 0.23792279458471707, 0.11610855108925275, 0.11274530405976943, 0.10513366106897593, 0.09206973814538547, 0.1256122211260455, 0.11391772436244146, 0.2916855668382985, 0.09741983748972416, 0.17065758258104324, 0.1547056721257312, 0.0817548455670476, 0.18637440779379436, 0.12803782096930913, 0.16012906682278427, 0.1474311796150037, 0.17082576427076543, 0.1830151573355709, 0.24658795818686485, 0.07403966491775853, 0.074932040247534, 0.17023138116512979, 0.16509310688291276, 0.12170669569500855, 0.1005050480099661, 0.11963552183338574, 0.11129515258861439, 0.06431625131517649, 0.09091536687420947, 0.09657598419913224, 0.15036283087517532, 0.11491576795067106, 0.2286670883851392, 0.1779686209878751, 0.1303494812122413, 0.18803874562893594, 0.11165426724723407, 0.1359591744840145, 0.1470292154699564, 0.12447741201945714, 0.16413990088871547, 0.09862617775797844, 0.10488345128084932, 0.1027518810172166, 0.23685773887804576, 0.1193685590156487, 0.13496579921671323, 0.06514105134244476, 0.07597329973110131, 0.11007906855749232, 0.18794741481542587, 0.13906231868479932, 0.05938317959329911, 0.10328407638839313, 0.19892950409225055, 0.17673968550349983, 0.12749457226267882, 0.09999027063271829, 0.13814454578927585, 0.09230859604265008, 0.10955145329769168, 0.10314315145037004, 0.11652557871171407, 0.10484077821352653, 0.1484406225915466, 0.11380250233092479, 0.1379202628242118, 0.2785265472318445, 0.1022151191053646, 0.12656275369226933, 0.11559259306107249, 0.04971967384751354, 0.1258436558502061, 0.0777842825544732, 0.08834830605025802, 0.12391399725207261, 0.09129046781786851, 0.061180408511843, 0.09994710223483187, 0.15835986818586076, 0.14122544761214936, 0.12130946772439138, 0.10623976135892527, 0.11587612570396491, 0.11586677549140793, 0.1264253096388919, 0.09469188922750098, 0.10683609186006443, 0.1942455768585205, 0.09724915200578314, 0.18542105252189295, 0.17737039737403393, 0.10910364054143429, 0.14329727286739008, 0.17374368198215961, 0.13476149232259818, 0.15099358345781053, 0.0665757864979761, 0.07330945945744004, 0.1462240115340267, 0.14481316081115178, 0.14431002709482396, 0.07926181291363069, 0.15736863708921842, 0.06014113713588033, 0.1108708307147026, 0.11738674821598188, 0.16938030826193945, 0.0734857360699347, 0.1483665265675102, 0.12408531377358095, 0.11713111693305628, 0.09731311071664095, 0.12415054813027382, 0.14312780196113245, 0.09566228251372065, 0.09903237596154213, 0.13233760238758155, 0.16364332182066782, 0.10082257525729281, 0.05886711978486606, 0.10308899078518152, 0.15443300961383752, 0.13504494354128838, 0.20324242194848402, 0.1161370359893356], [0.08835986828697578, 0.01154340906733913, 0.024384054954030683, 0.034394824744335244, 0.1010371008887887, 0.04527357992316995, 0.02941254905558058, 0.004094534329072173, 0.03390022021319185, 0.011064361647835799, 0.029094204173556397, 0.05599676737827914, 0.0349806650940861, 0.031690998402025015, 0.06632860976138286, 0.023057052499747703, 0.02686782899711813, 0.028092206422505633, 0.023588720309947218, 0.007801992419574941, 0.03281802810462458, 0.02652683631250901, 0.1265134241964136, 0.026462765643373132, 0.03260464919731021, 0.036041313715811284, 0.024899166509775177, 0.0671574877841132, 0.02076993147576494, 0.031225452133055245, 0.013361264602281153, 0.03816021912332092, 0.06678404246589967, 0.02019539212674967, 0.032949029467999935, 0.04552984902901309, 0.03869621429060187, 0.043999935766415935, 0.05380046148119228, 0.011824644869193435, 0.06255274558705942, 0.040135716154639206, 0.018952249815421443, 0.011436002911068499, 0.0612938663523112, 0.005151976872834244, 0.007677306520885655, 0.06856415873127324, 0.06348643012877021, 0.021524128238005296, 0.04177254618012479, 0.05651036749726959, 0.033895144771252356, 0.0709927509139691, 0.052751459913062196, 0.020457442350951687, 0.01641780447347888, 0.040962497504161935, 0.015667030920407603, 0.020331519822190915, 0.052580804963197024, 0.0077337623307747495, 0.013745072846566992, 0.010290588302138661, 0.035314735025167465, 0.029429407258118902, 0.07856788872075932, 0.04680281804342355, 0.044936459977179766, 0.041788054097976, 0.009762701628330563, 0.030515137926808426, 0.017293954334620918, 0.04248943878337741, 0.017775629380983964, 0.07035291953278439, 0.036930191197565625, 0.0853142367143716, 0.02478823621225144, 0.023705981339194944, 0.05812327577067273, 0.05034172421853457, 0.01879420374254031, 0.010725639511032828, 0.054000171300555976, 0.04235044088480728, 0.025809711311012506, 0.03978600259870291, 0.017802914970421364, 0.02648822936628546, 0.04218895633571914, 0.02095184671426458, 0.07311211433261633, 0.007814240824830319, 0.059771165916962285, 0.014581242576241493, 0.04151005830083575, 0.07600992705140795, 0.020561363381732787, 0.030152023304253817, 0.06735712635729994, 0.015115887458835329, 0.04295049315052373, 0.05111757812223264, 0.022477415656404834, 0.01241696862104748, 0.03880014210673315, 0.08179624977388553, 0.04127183144113847, 0.04719741329816835, 0.02135577521819089, 0.022286307964740053, 0.03587467230058142, 0.058281795121729374, 0.03937590281878199, 0.020875404655401195, 0.06597100145050458, 0.019513008118207966, 0.04145550408533641, 0.13495619116084917, 0.04223426551158939, 0.005427342498608465, 0.0038546946764524493, 0.03719669600416507, 0.02862280554005078, 0.006107779959815421, 0.05299356799306614, 0.05170215978952391, 0.03247060799705131, 0.053934808022209575, 0.017212083995608345, 0.020377692433872392, 0.012319776113145053, 0.04091457596846989, 0.047231092383818965, 0.043958202470093966, 0.016773621451907923, 0.019355923868715763, 0.011833023080336196, 0.03741779663999166, 0.03390375538063901, 0.035210196527519395, 0.05433480102302773, 0.023179495840200355, 0.04566447716206312, 0.044234043918550014, 0.04232075158506632, 0.021502058886523758, 0.026515129887099777, 0.0525477840565145, 0.05246726569852658, 0.02713129057415894, 0.02508914952964655, 0.014703436555074794, 0.08302259325448956, 0.035330256513719044, 0.038692458599273644, 0.0364707449584135, 0.042406240212065835, 0.05912743974477053, 0.012978795616488372, 0.01182554816893701, 0.05050706623920372, 0.02310142190461712, 0.02863154507109097, 0.03243996196293405, 0.07015505872134652, 0.026447764930448363, 0.009804242390340992, 0.011177696503831871, 0.023627013433724642, 0.057556203699537685, 0.046286171302199364, 0.023363029384719472, 0.03093747508579067, 0.0776434118992516, 0.056521939912012646, 0.06049126120550292, 0.033116688685757775, 0.02245558548851737, 0.013967710364210819, 0.013140850983160948, 0.07421282026916742, 0.04406585205080254, 0.04005738946476153, 0.04029045267296689, 0.01210286034204598, 0.05378202229206051, 0.013597374432720244, 0.02393922096650515, 0.034122983259814124, 0.030887297421161617, 0.019227746907355528, 0.03709448488163097, 0.0537607943240021, 0.03147705291797008, 0.059408923211906633, 0.015750984361927425, 0.041024322222386084, 0.07579182554036379, 0.04335125968126314, 0.03960019935454641, 0.007328125614938992, 0.05875097494572401, 0.10500472584473235, 0.032755606275584014, 0.026934727460944226, 0.038159594871103764, 0.01817133743315935, 0.009230141544581523, 0.0259757861495018, 0.03210286237299442, 0.03806977719068527, 0.02303144458814391, 0.029575641732662916, 0.03025274843509708, 0.08828629473490374, 0.026066998219383613, 0.04020543562780533, 0.026979758437456827, 0.06071508276675429, 0.020218321521367346, 0.0702623486784952, 0.05126685582633529, 0.03241856096844588, 0.04231508242498551, 0.010257739573717117, 0.011798520422806697, 0.02501742328916277, 0.0631369167406644, 0.13311856905264513, 0.04006862261199525, 0.01167134938961161, 0.031158741962696825, 0.00794644998053887, 0.016138733198334063, 0.02886702725663781, 0.05054411764389702, 0.03470161756766694, 0.02050722816160747, 0.02249920680852873, 0.049972970969974995, 0.07037502620369196, 0.010389986048851694, 0.06694647017866373, 0.05207304024536695, 0.03367842747164624, 0.021454542775505354, 0.05927011530314173, 0.08097588736563921, 0.04131041294229882, 0.015984709141775966, 0.031014845041292052, 0.02920984011143446, 0.07051564580095665, 0.03578046110591718, 0.009166877483949065, 0.02150826748194439, 0.03205339377745986, 0.02252860094553658, 0.04089869146368333, 0.01788545197008976, 0.0329663660377264, 0.025525271127532636, 0.04303355262215648, 0.008545703271270862, 0.019623188634536097, 0.03268623624795249, 0.03701284694086228, 0.025379691439281617, 0.035060759367687364, 0.03308515716344118, 0.02607251301274768, 0.058249585064394135, 0.03472010086157492, 0.0309509643619614, 0.009393235918001404, 0.021446239203214645, 0.025964200164058378, 0.03251076369945492, 0.015949130158073137, 0.03099731169641018, 0.033355488907545805, 0.028262493267123188, 0.010161804051936736, 0.02858884825504252, 0.038656601416213174, 0.02052305668725499, 0.03963421092235616, 0.05978313527469124, 0.055224506317504814, 0.034976953507534096, 0.029300773981958628, 0.02151780259529395, 0.037451943914805136, 0.0604368494823575, 0.02431966706977359, 0.004139861740571047, 0.03857212041371635, 0.07749604087855134, 0.05011360753061516, 0.048936420519437106, 0.04441119584121874, 0.026450345059856772, 0.03477276874972241, 0.015385513526520558, 0.014329294042129601, 0.03262863201754434, 0.015192256575184209, 0.0761696474094476, 0.02341647758813841, 0.0269401625264436, 0.036997963275228224, 0.021586246422625015, 0.020191141104857837, 0.015880034937124168, 0.04025597291599427, 0.03091956515397344, 0.0075234190195000595, 0.010875348933041096, 0.05233376393360751, 0.024797542320032204, 0.02166041199650083, 0.04543811448716691, 0.029850329671587263, 0.022333712117480378, 0.05102732278672712, 0.06731754062431199, 0.036592535208910704, 0.06518168201936142, 0.03613424587196537, 0.07986847071775369, 0.032981524510043006, 0.029407555037843328, 0.03570486551948956, 0.0612786060997418, 0.032662840360509496, 0.044692546994026215, 0.052288220663155825, 0.0035627359008815673, 0.04527146289391177, 0.1016783911202635, 0.07459529688847916, 0.017502028794427003, 0.03386022396651762, 0.031434295033769946, 0.033602913309420855, 0.0031885808774469687, 0.022670854115858674, 0.03723020884873612, 0.02151640142048044, 0.036791172942944934, 0.14795903914741107, 0.20553945297641413, 0.12410520842032773, 0.10960591251828841, 0.12640584925455706, 0.19866744029734815, 0.23813376469271524, 0.14967641127961023, 0.10097717267594167, 0.10394373456282274, 0.1452228466847113, 0.20152936529900345, 0.12987635231443814, 0.0993094557364072, 0.18362422393901007, 0.10642603957759482, 0.1540846633059638, 0.1002376645005175, 0.15293613422129834, 0.07633101660758257, 0.09338040995810713, 0.11434601566621236, 0.15700023328619345, 0.19848682784608432, 0.16665755079260894, 0.1090899273487074, 0.08222822552280766, 0.18482604516404016, 0.12604569643735886, 0.17016278127474443, 0.10863275759454284, 0.14209925143846444, 0.20694592036306858, 0.08686778335166828, 0.12369073208953653, 0.16145210154354572, 0.08635486516037158, 0.08973814254360539, 0.08033824765256473, 0.08168017278824534, 0.21066714211234025, 0.07619249368352549, 0.08698316823158946, 0.10826389917305537, 0.12233960601900305, 0.10576574358024768, 0.13828425614961556, 0.18714808699275765, 0.1361707959856306, 0.09255560993083886, 0.1129334278936897, 0.18778307363390923, 0.08299357231174197, 0.17367774194904737, 0.27376890395368847, 0.0934190321713686, 0.11467719503811427, 0.20985764983509267, 0.1288587533469711, 0.17064285837113857, 0.14486512302287988, 0.14994517900049686, 0.13739485958857195, 0.1720578210162265, 0.09407988456743104, 0.12971718156976358, 0.24819684614028248, 0.23627050753150666, 0.20717624228979858, 0.14900371166212217, 0.10516762853200946, 0.1159107717020171, 0.09611251085464444, 0.1826458578663213, 0.19670186005532742, 0.10583191431526627, 0.12454952672123909, 0.1556131855717727, 0.2365811408630439, 0.11463385022112302, 0.18719749791281565, 0.1313974242657423, 0.12066276956881795, 0.1216253393462726, 0.1744792546544756, 0.058058882797403, 0.10518453762467418, 0.1451481535498585, 0.11036154268575565, 0.11463456946824278, 0.14672194767211164, 0.10257160104811192, 0.12116559115903718, 0.13583127063299927, 0.09761560162795441, 0.1356751804373094, 0.12096482621771948, 0.2368608329977308, 0.15193449439746992, 0.10165266107235636, 0.09331594234598534, 0.1221775718565498, 0.11827101505228452, 0.14279742326055253, 0.12788847541170462, 0.07538323889353446, 0.07872633343296391, 0.1758005523255893, 0.18163281865417957, 0.14444954746535846, 0.14082788037402288, 0.16411773993500642, 0.11217842876378979, 0.1602175613599164, 0.08369209697203976, 0.11933495796152524, 0.09616169107279607, 0.09887729678303003, 0.167584768895592, 0.12585795936839922, 0.09736533077167613, 0.09481365912194763, 0.10366341817591872, 0.11188876216432878, 0.13187197808708462, 0.13885824249259063, 0.08137946642403092, 0.17024626822343894, 0.18969490033175263, 0.1268810001867158, 0.07968742400407791, 0.14984708997820104, 0.11620252818933555, 0.14522670076361724, 0.08114145669553961, 0.11379403421389205, 0.13378083280154637, 0.05785156320780516, 0.09186317172965833, 0.12340888221349035, 0.15480659742440495, 0.12243119467582021, 0.2028075624257326, 0.06686474063566752, 0.18634586861091001, 0.13052435325724737, 0.13954341358372144, 0.06690047907509974, 0.0782533266714641, 0.1213832109102181, 0.1314987295440265, 0.15242743651781762, 0.1717878726444074, 0.12529594238315309, 0.148846264396395, 0.13195584501538957, 0.11928907542356423, 0.09498458887849535, 0.15376372981284345, 0.1251698705766882, 0.1362613532692194, 0.12253267637320928, 0.186006098985672, 0.08330109116754361, 0.13512704627854483, 0.19756799643593176, 0.18068608588406018, 0.10366169469697134, 0.10509007197937795, 0.12767191417515278, 0.07759781434599843, 0.11033092040036406, 0.12266048522932188, 0.13114009664527007, 0.1261388050126178, 0.1736536268144846], [0.056280025214489014, 0.059821207874587605, 0.0196434700462435, 0.032216194684484174, 0.0374042191542685, 0.009994806405822081, 0.012367824025984322, 0.022608089626633694, 0.014036002369331462, 0.054281888862273524, 0.0671504106638687, 0.059942672428275855, 0.011079678727713014, 0.06787602244211094, 0.032676197322351594, 0.012306399643421173, 0.10797259730419942, 0.019402389946792806, 0.0246060953608581, 0.04889794419120465, 0.0031119112973101437, 0.030693965830973217, 0.08676460531673261, 0.027049055522573844, 0.04515377438760229, 0.01734317696121122, 0.00889102925014283, 0.03615171814869557, 0.01404552984916206, 0.00804572643911732, 0.0938709636351892, 0.07252923918089696, 0.08594859231795583, 0.04614378412121108, 0.03053622000983783, 0.015198217505323035, 0.0045733357796312445, 0.02429781315316047, 0.027803226839751005, 0.03925111344350236, 0.07229821836309773, 0.018909807450004985, 0.04253475135192275, 0.019597699466560568, 0.057106769244585714, 0.02902188930394394, 0.040560787809746604, 0.04168411610381944, 0.021507575376225368, 0.05199066270142794, 0.02273567795886525, 0.04229519795626402, 0.03827550561566438, 0.057979982745434554, 0.07208729575255088, 0.061014676333538125, 0.04094620927103928, 0.02990609167941979, 0.030692802143416235, 0.03513316583952733, 0.052041712283555946, 0.059106635861098766, 0.024564837039049183, 0.02972381003201008, 0.00679243790883837, 0.0842355220977749, 0.08458646719477006, 0.052151858873133145, 0.026419241014601927, 0.04110242160303252, 0.03611577954143286, 0.07157764131469385, 0.02016700561424451, 0.05111681816301175, 0.02206084774141865, 0.06393367970096213, 0.05431677574025733, 0.06000628508627415, 0.037958880819912465, 0.0147312463128141, 0.017918352436806475, 0.03664291982672044, 0.05919025173144681, 0.016658363797302757, 0.06890991982072592, 0.03033069514536432, 0.02166686825720327, 0.048124733181404214, 0.05945739096828869, 0.04950902604364923, 0.016067042580938766, 0.05721186753362417, 0.014093799134051161, 0.041793655404554944, 0.03890050761401653, 0.0373663670782532, 0.04338998028210231, 0.056930865826351304, 0.014083962072618306, 0.02908462325909308, 0.040241560832198174, 0.11676746287516185, 0.05150679259427956, 0.03238555702513882, 0.030135972558387687, 0.02925117646477052, 0.028564309036093097, 0.04125090542116335, 0.035661476597722085, 0.028425981190853884, 0.025327123635049378, 0.028550986001001935, 0.026959173381328583, 0.019090750687090412, 0.05950577051511832, 0.04104692761653236, 0.06014955097011157, 0.02697171949382339, 0.05558673884453518, 0.10223322241966214, 0.08683577685483865, 0.020693835469761064, 0.07686113566160202, 0.026072635149051036, 0.05403130927256175, 0.02443034291666533, 0.09872737447065966, 0.033722606886710436, 0.05521995334752968, 0.03309060240696583, 0.033911287119346004, 0.009353990300691553, 0.02575791534036398, 0.06526805274188519, 0.03920539375394583, 0.047186807795826874, 0.04019603452512196, 0.015942544975717152, 0.02437374122174723, 0.016780113335698843, 0.04795714860249843, 0.009791715785727968, 0.021310679780851518, 0.009006433637945779, 0.02003927987867168, 0.06294622804437365, 0.04327633923717907, 0.0616818866027253, 0.024182428273239305, 0.058572791649826934, 0.03526639619043895, 0.02100820922558861, 0.016681518804814135, 0.06061001840446677, 0.04288605607247778, 0.02206244908406266, 0.029895777947136333, 0.008594298252968915, 0.03033253736793995, 0.020821707090362906, 0.017455708601378968, 0.041452766196536164, 0.025970100026045526, 0.03255345033747809, 0.0019783101950971676, 0.029869840946048498, 0.021479813115937368, 0.0013402611345684687, 0.05064269521140626, 0.039241345931908915, 0.009188229284648384, 0.014252153092197009, 0.06813446286001376, 0.05230364376412971, 0.011763858309547816, 0.0701274016339864, 0.08960772132767097, 0.014825377779613649, 0.020727310994906083, 0.03564195514523557, 0.038491357783121724, 0.019222739318917905, 0.024395344080403447, 0.030167008750140667, 0.036161380487361124, 0.07402465572314602, 0.12305685824581555, 0.010062469069712927, 0.00854128600829946, 0.0513955230292465, 0.037615447105573754, 0.0036758663482032716, 0.019680828488032733, 0.017238667301301445, 0.0856019084208778, 0.061031252944043705, 0.0012594399803284822, 0.03319384151005319, 0.055137799720146825, 0.05030341413138168, 0.01510047453588673, 0.055826831675533733, 0.029987973892795186, 0.014570531900972128, 0.04182899011565106, 0.12550110423139163, 0.04180804713230048, 0.05390383968395846, 0.03456912681992565, 0.023561984333874922, 0.03568011934735945, 0.01429869550546365, 0.04274218289979866, 0.05999178479292563, 0.050884609908929894, 0.04159104824066162, 0.022560447986636843, 0.04831293843952673, 0.061306459962257316, 0.03528601603050317, 0.042967347960386953, 0.06728542556187936, 0.04024784406647086, 0.04915953301159399, 0.06705950732742037, 0.04467753779941371, 0.007107402414216527, 0.09187757702810423, 0.041667515744588206, 0.03760524533156838, 0.023584408219903708, 0.03223503760195204, 0.04916677298024297, 0.0725148067410503, 0.006676227760700775, 0.06857295254511492, 0.03594712966254779, 0.034612990716206174, 0.05015526279540999, 0.016489517143262283, 0.02168263741103666, 0.04390629114849227, 0.06472739603902612, 0.0793691910803318, 0.044710507815969844, 0.02423757959955505, 0.006694450666795352, 0.039457377911146195, 0.04575640508638961, 0.07481771388224193, 0.034402590577623675, 0.06700861720102173, 0.01740028246838067, 0.046460938174277544, 0.03401694519977484, 0.014724735769310167, 0.0060448649206331796, 0.04756819536643369, 0.02100526777628277, 0.0579964779317379, 0.038651624361851385, 0.015168563828670552, 0.05689360746847732, 0.042727669035749774, 0.037191610384200297, 0.03460077369319541, 0.04318019421771169, 0.04089167541159051, 0.020365185337141156, 0.042918615575347624, 0.0498688497713634, 0.014426092151552439, 0.04028143833524414, 0.042579358244048696, 0.032397981001330275, 0.020634231257385442, 0.05011663040412324, 0.03151359881407448, 0.039343319567186494, 0.013235461665317416, 0.010272877689983164, 0.02265740215911397, 0.0072092581540346146, 0.08923268145216362, 0.010014852026610501, 0.008129391503254218, 0.03993884939700365, 0.02808326672363494, 0.06611911207437515, 0.0486190900472658, 0.047049628371106725, 0.03349810339776533, 0.036023824475705624, 0.06080130421157394, 0.05551301262208393, 0.028488550601261, 0.019523516929309283, 0.02094498842156359, 0.03556104323693684, 0.01960155524180404, 0.022879237309098244, 0.003951115350771163, 0.04262716103611248, 0.011338797680634474, 0.025466557492368987, 0.033587758229779344, 0.0125768806652299, 0.014579503830256206, 0.0161762663628906, 0.03900595874126468, 0.027823548963559524, 0.0219721377694181, 0.02066823773618255, 0.01840653802667345, 0.026220779699672545, 0.020835332073537365, 0.026075069393430437, 0.04059898933129651, 0.036296225751617124, 0.021931707260331938, 0.017832249735615084, 0.08154769561120442, 0.03257672408861773, 0.019638040069756762, 0.018931501910888722, 0.07028345111757517, 0.05404085286759904, 0.015009287911068116, 0.08333505863057715, 0.006958809182313936, 0.032267566570746045, 0.03353789608393397, 0.01461407688579389, 0.022302255234015838, 0.009897724159860184, 0.03808776515402964, 0.05157914139064295, 0.018468461132475307, 0.04534974208633814, 0.06924175737159592, 0.05428322896893535, 0.020792638650164008, 0.019283712475693653, 0.04115304710077388, 0.01633113349920937, 0.011763159418478608, 0.042755231128207276, 0.04675430618226528, 0.02759501836927874, 0.010356333256433052, 0.017929877354098216, 0.03954835927912167, 0.16430506988295487, 0.11456549460334436, 0.12461040488311223, 0.14167904827211583, 0.11894619810794081, 0.11247240406061922, 0.09804987761058978, 0.12694046699575015, 0.13777089012520655, 0.1440724448433944, 0.22179252441440309, 0.19302432239055634, 0.11267059735421624, 0.1325829742210252, 0.12833059525915555, 0.13261091629309313, 0.17526973438050064, 0.09324177846844707, 0.1970432988767113, 0.1932498945721558, 0.061002706975809166, 0.1359820682555437, 0.17562885582447052, 0.14750469209892408, 0.15561516689402716, 0.12083829300744192, 0.10451559709118945, 0.12036036008170672, 0.08215104894978659, 0.1661938942436661, 0.16124132142535277, 0.19706731901637145, 0.11805475237114088, 0.10475391216043915, 0.1502925075058426, 0.1537283645676715, 0.14051822413291248, 0.2007348822163684, 0.13228498878223555, 0.1258629398154361, 0.16498790681362152, 0.08842744358948298, 0.20585983007081918, 0.1236320116690227, 0.11708718857594899, 0.10230870944048677, 0.09110431852085249, 0.1708031961960452, 0.21725176806960786, 0.11879728681274823, 0.09136201933558498, 0.21484538433807238, 0.1311146922941719, 0.1528864518872329, 0.10732311036969934, 0.1043206879070827, 0.1453757749072143, 0.2594900572938578, 0.13540671127183096, 0.124086697985019, 0.10915031018001692, 0.11527586648506777, 0.08220869728497096, 0.16692312939890794, 0.11320872312145573, 0.1208097402538572, 0.17142348576869282, 0.1516638539199318, 0.10436761538897242, 0.08420655543782882, 0.13702284597924777, 0.15935746394097805, 0.12797485291957855, 0.14467834947364672, 0.08768372171159301, 0.1863031480461359, 0.09341459455234663, 0.16251031761722906, 0.11009010153689555, 0.10045276688677923, 0.0703369468184454, 0.2099763663219554, 0.10932571148233754, 0.1910616055663143, 0.14484830892511777, 0.07172917175505843, 0.12573694943317346, 0.16465623889650616, 0.14690158303294862, 0.11153877380170993, 0.1191038896462747, 0.1519743651151657, 0.08135516129966293, 0.11358500471604721, 0.11994376672165734, 0.10116410228822913, 0.12579913038228238, 0.18727343955210277, 0.08738129865378141, 0.14729919098317623, 0.16239810149584497, 0.13988633161144598, 0.13951635360717773, 0.1154961460935218, 0.12259519658982754, 0.12509215117565223, 0.1072246820798942, 0.12155534167374883, 0.10602911016238586, 0.10146053388182606, 0.19447519310883113, 0.2035797352769545, 0.23150985155786785, 0.15447442739137582, 0.12001501289861542, 0.1372922243816512, 0.12863365613988467, 0.18476841039955616, 0.10944347802017416, 0.25196184696895735, 0.19794402697256633, 0.10449705951447998, 0.1067767743287342, 0.04702086527166622, 0.10396465379744768, 0.17410620967192308, 0.2383384108543396, 0.10423675312527589, 0.18932535658989633, 0.10512415479336466, 0.08139531700206654, 0.11740603218121187, 0.1284857897886208, 0.15136238081114634, 0.13425911856549128, 0.09024678596428462, 0.18173088053507463, 0.19686354137957096, 0.18556012505931513, 0.11491226670997483, 0.16048490415726388, 0.1023607055789658, 0.13189983873495034, 0.11446739201034818, 0.1067241607233882, 0.19152580494327204, 0.09876795086477484, 0.1680967371378626, 0.08781449576573712, 0.11500884938452925, 0.1655075696430036, 0.1115207111995135, 0.12492728073682104, 0.186442871977176, 0.08524564360933644, 0.3107063147638525, 0.09227476428662028, 0.12673419235008104, 0.05051123922956841, 0.15159354412129947, 0.0870143740570971, 0.12464714076902185, 0.18405007251671382, 0.12299888421382223, 0.08603119717112609, 0.07149447327745811, 0.10921427567622491, 0.08764777292630502, 0.11507022966231618, 0.10581399420542376, 0.11804561928978988, 0.13025858466114315, 0.1123163817184312, 0.14871865910078796, 0.054007913385118754, 0.17819935003561632], [0.06093005623136248, 0.04796858870291284, 0.04363343525411827, 0.05431947630963155, 0.07235781409378562, 0.006660002292067344, 0.03980024165606924, 0.0319927768515689, 0.01903712436822908, 0.10201298352330923, 0.028410664959145442, 0.023393633010398065, 0.03290794077994568, 0.09076908829488925, 0.013655697910248168, 0.022124112650219883, 0.041822900263858695, 0.03302678279578686, 0.04107011315811958, 0.027833884748231088, 0.042391773845468245, 0.03875840881041118, 0.022430216760507653, 0.025707469654402564, 0.023741684155538678, 0.019792707038245032, 0.04246305055650217, 0.03551751860816564, 0.03743884140359504, 0.02269504388927349, 0.02674073938812528, 0.04219322432098644, 0.03356028434687427, 0.026555056583934596, 0.027435133466497064, 0.0359535011063729, 0.030547256381916146, 0.04838189116812178, 0.10475923187498536, 0.020563402379463826, 0.02914608156840716, 0.013586388102599552, 0.01808150448570294, 0.044202369903879504, 0.09212631439524037, 0.011696218546213848, 0.05402576903413449, 0.04738981190270611, 0.0476114655445729, 0.0564832057404731, 0.03786080876099212, 0.02425768968117024, 0.05294403154402971, 0.019308348385883228, 0.08265716822019645, 0.06034604114081178, 0.041829275100358894, 0.05655128315889409, 0.04057321517861315, 0.03631344357771533, 0.007557925069704652, 0.03984749483476792, 0.05818143979247127, 0.006137830579453813, 0.031475672099207125, 0.10209191071667842, 0.03475229734820979, 0.008598199829326143, 0.040452191672687016, 0.003563643865553396, 0.05157523981428572, 0.06561840072806392, 0.023387222550809383, 0.011697701993398368, 0.005705292918719351, 0.037345179822295904, 0.042320056086672206, 0.012185187844027365, 0.041699596880269904, 0.03041335767401116, 0.06522079277783632, 0.07254596506910664, 0.05480760083134685, 0.051042857845979075, 0.047867527697235346, 0.008453235911604549, 0.02708892963294472, 0.08939561128084149, 0.06409514389399971, 0.03736356133595109, 0.03235466332573976, 0.015126696521682399, 0.04451512026467493, 0.045275364470268996, 0.04761984205937811, 0.07536250964871474, 0.019662279036960432, 0.012286562672150987, 0.065128579868802, 0.027677233064813272, 0.015403323374422533, 0.032265266337032826, 0.03335056613598551, 0.009189332752222461, 0.07497189060917922, 0.037633760765727074, 0.017671218108651892, 0.04856715836961355, 0.03275751635166151, 0.008630738127976656, 0.022491006712828363, 0.0274051931087992, 0.014077627948219222, 0.0769699794639434, 0.02949916065803596, 0.04832373053899833, 0.06688059799905334, 0.0026169310274001744, 0.007944920732240592, 0.017598112745742713, 0.08357330584632498, 0.03843988072393196, 0.035128989456487555, 0.03822152476225581, 0.08298635269914355, 0.047775633699659786, 0.019054364246715392, 0.0494263567296522, 0.08356544841080904, 0.05017100141516753, 0.03904145969344037, 0.04383381003780024, 0.03244477616889136, 0.0326293037672128, 0.03830861812457442, 0.04726116505584546, 0.08412870032978909, 0.043784680709775, 0.018267473970939006, 0.03259032193039145, 0.03393221653199621, 0.052167838372822316, 0.036267642463956556, 0.054044136977089305, 0.04640087764710188, 0.0938347095091428, 0.09511503723583051, 0.008794386355605508, 0.03537858517042228, 0.040935071118708165, 0.0257016529129552, 0.02080884376274688, 0.047422381583601236, 0.02203203714452684, 0.01920269539446703, 0.02231573433216129, 0.02134560397826135, 0.05028958898037672, 0.06781433003821544, 0.03996437249173011, 0.020038419835535542, 0.04160645777093513, 0.028962300358606235, 0.0384265576888408, 0.07661870188478913, 0.07327653015298502, 0.0438169654059623, 0.04441295324691704, 0.02493437229921775, 0.08260846297655787, 0.04605523530127747, 0.0030457100282157107, 0.010838649518388723, 0.06416723823973111, 0.011738913665924753, 0.08648527280560561, 0.039974832109042575, 0.024426690701927458, 0.038720091937908103, 0.04217043232971004, 0.018730323063209653, 0.011789127801811057, 0.03269437527550118, 0.016616118207041706, 0.06667719355651311, 0.10230170017374413, 0.04363629527922187, 0.0053427478414960206, 0.03353960259950586, 0.027594436525500247, 0.028370707728234783, 0.017468466756067107, 0.05528442435232656, 0.04186559707990714, 0.052258290483483245, 0.03505560589422073, 0.11563223307686192, 0.013392243118557547, 0.024616666936448643, 0.013093276348497187, 0.05129592765920928, 0.021123473665543964, 0.045528403749423366, 0.04775437519752553, 0.04320996833432998, 0.0163040090618389, 0.0350835310029132, 0.00681634312162974, 0.05906233430973121, 0.046090566619698486, 0.03871338801192386, 0.04940335099984493, 0.03517718919153724, 0.03147070861554571, 0.08010363738451685, 0.042859406609620364, 0.018608624414939965, 0.04330099041440657, 0.014941597257607749, 0.06672597343900374, 0.06084676605782338, 0.06036377804619925, 0.05895245913416147, 0.0016129652067320421, 0.018242266394996216, 0.08555156790784427, 0.037805219779589345, 0.04979626348774348, 0.03606182922210012, 0.03499317727982998, 0.0391497810238174, 0.05735998494284494, 0.07051420730671712, 0.014912186157224434, 0.010722994072628873, 0.0143603200558573, 0.05150525910513742, 0.037092632481030056, 0.09236341488680669, 0.03209359019196459, 0.01484423766045698, 0.07887043391487428, 0.014801355943615948, 0.05149381221937282, 0.020733651904655353, 0.03825207919414554, 0.028614870073007684, 0.04207272328702467, 0.012440562979983432, 0.0453431365479316, 0.044233368776206455, 0.01961105812474021, 0.0046305417948003325, 0.014086581217790288, 0.030757476708718708, 0.05210525030270219, 0.015423630231193133, 0.02450708013826183, 0.036560752628637214, 0.024402041221037507, 0.02659328524688525, 0.01586612157656678, 0.03694599427814994, 0.031081324509744133, 0.06089669266449554, 0.039589960261115005, 0.041416922584176064, 0.06670652662536927, 0.02081891491876117, 0.03256906682093229, 0.011321394105574914, 0.05748868267983198, 0.019318115897476673, 0.035733133288366456, 0.04924581891724041, 0.06714596625949655, 0.016214674837621193, 0.06328457274607249, 0.05069483044956412, 0.06656284683517047, 0.06100969588650124, 0.0019859320517363293, 0.028842447325587273, 0.026197219267487526, 0.0199056797261749, 0.01825274806469679, 0.08852752750473362, 0.02873428545093962, 0.0747551733095731, 0.016746575046064596, 0.031072788539209535, 0.028615063455488, 0.021029170868652206, 0.017501896480098367, 0.02633624939647104, 0.028627864018614804, 0.0032784960972743905, 0.03746266816077488, 0.031983399497611184, 0.03162608974214111, 0.041979146522602866, 0.050455344907407246, 0.015721013470153724, 0.034344355309648175, 0.02490358886175922, 0.07182166286345039, 0.03599792479404381, 0.045442277299506326, 0.022462094335683754, 0.035023046391350884, 0.026283057340021645, 0.06789383398635046, 0.00666870577593467, 0.047262352492128096, 0.038487395138612816, 0.01673996102597032, 0.03120310797489115, 0.03565917297133377, 0.05098554538562894, 0.04090202985597508, 0.036843664411987574, 0.07704891344266278, 0.07795806894344942, 0.037610751643244705, 0.07637336397809641, 0.028150143135072928, 0.026874302221196036, 0.03331972671938794, 0.05041504331997462, 0.024496898720307008, 0.03126821680260556, 0.019054723870275275, 0.013331084212820445, 0.024495478885780488, 0.017589863456253494, 0.02726556247632418, 0.008519705202031349, 0.05455289914139679, 0.013552008429542184, 0.02042784634977579, 0.0681112976744771, 0.022723774758300612, 0.04422628487061177, 0.01610251299903861, 0.02794297451951674, 0.02905004850721785, 0.032866455148905516, 0.001924345244853092, 0.02701606006095452, 0.033062433025666645, 0.028413302764030438, 0.020564518569569503, 0.11981218521084104, 0.13245295334075177, 0.10618762272809233, 0.2473025641271046, 0.08358055938567434, 0.16412687301635742, 0.17139434947499207, 0.1271771942930562, 0.1376061961054802, 0.24632395378180913, 0.17020286912364618, 0.14132382161915302, 0.1393295664872442, 0.13273687953395502, 0.18395477905869484, 0.0984108785965613, 0.1683387705790145, 0.14624624034123762, 0.11642909103206225, 0.15256433774318012, 0.16494728970740521, 0.11495462086583887, 0.15053215250372887, 0.069917150773108, 0.15276740970356123, 0.12034144252538681, 0.1311817044126136, 0.1236441574458565, 0.09277807442205292, 0.1076565289071628, 0.05260551381590111, 0.13711166621318885, 0.21813652345112391, 0.14272766986063548, 0.1220032154981579, 0.10152456723153591, 0.1308018740798746, 0.12057932333222457, 0.22742935908692224, 0.11655305937996932, 0.10416170715221337, 0.10424435950283494, 0.06092219201049634, 0.1647927194301571, 0.14310070127248764, 0.1293613849473851, 0.12831325190407888, 0.15371518741760934, 0.09547497970717293, 0.15157362233315194, 0.16124229851577962, 0.14376230005707058, 0.18745675257274083, 0.19188260579747812, 0.17762456302131924, 0.15882569604686328, 0.14720389752515725, 0.06326629979802029, 0.1925804383520569, 0.15953955559858254, 0.08375172662947859, 0.14546420159084456, 0.16541032200413092, 0.13010849271501812, 0.12119923292526177, 0.2679414280823299, 0.08779242980693068, 0.10433001097823892, 0.10866699647158384, 0.10144488686429602, 0.1607251191245658, 0.09981448256543704, 0.06985109538904258, 0.0967265646904707, 0.09907259273209743, 0.14069747951413902, 0.19226303324103355, 0.07504187471100263, 0.13574931717344693, 0.07760140379624707, 0.10266811586916447, 0.15585897809692792, 0.16308781877160072, 0.15971782031868184, 0.11334173634116139, 0.12467483856848308, 0.0974634401500225, 0.15367572382092476, 0.14940715501351015, 0.13805382565728255, 0.17801805904933385, 0.11691517994872161, 0.06713099777698517, 0.16767536689128193, 0.09977899518396173, 0.1266075912863016, 0.09228401950427464, 0.0859381700200694, 0.16417575467910084, 0.08428998810372182, 0.049878176235194714, 0.14795612144683087, 0.14374414245997155, 0.13738146530730383, 0.18336057237216405, 0.09073125318224941, 0.07199652133775608, 0.07279814260878734, 0.05924812398318734, 0.07307037764361926, 0.16582850313612393, 0.09305758335228477, 0.20107125916651317, 0.19386224528508528, 0.12473545888704912, 0.1033652156059231, 0.22185862729591982, 0.13150828331708908, 0.10943726263940334, 0.10423057167125599, 0.13403301712657723, 0.17212887720337935, 0.0784829564924751, 0.16240601321416243, 0.12078810855746269, 0.15778307270790848, 0.21006841638258525, 0.15565632682825836, 0.18107221302177223, 0.19845999857144697, 0.16345420054027013, 0.18913069846374647, 0.12646454253367015, 0.11043440377605812, 0.10277780784027916, 0.16108922101557255, 0.15055366206382, 0.14381825205470833, 0.07403879639293466, 0.15592964073376997, 0.11680190531270844, 0.08902196240212236, 0.09371948069227592, 0.12434235640934535, 0.16500666152153695, 0.1619287316820451, 0.18273458310535975, 0.1543916461191007, 0.14913390896150044, 0.15545800461300782, 0.14874466056270258, 0.07752468862703868, 0.10198868518429142, 0.07398055094693388, 0.17387438139745168, 0.14528994022735528, 0.2385520136782101, 0.20570771609033855, 0.12159821151622704, 0.08744794436331306, 0.0734676598970379, 0.10666114517620631, 0.11239888479134866, 0.13483428555939878, 0.12803152416433605, 0.1458715668746403, 0.16174722356455667, 0.12361868524125644, 0.11704437301627227, 0.16695018937545164, 0.1536535085844142, 0.046528828995568414, 0.13203664496541023, 0.13396432224128926, 0.09789288496332509, 0.26114674125398907], [0.02616260041083608, 0.025152441579848528, 0.050573820514338355, 0.01313059323001653, 0.009075089507470173, 0.09049842067595039, 0.052564384415745735, 0.036219113639422824, 0.028398373297282627, 0.006566146056034735, 0.06663943986807551, 0.031374668769006214, 0.02880856128675597, 0.0627996101975441, 0.044875995721668005, 0.05028108015124287, 0.022295359621888826, 0.011217800467940313, 0.007731463793399078, 0.03136201409090843, 0.016214091297505156, 0.04296161773215447, 0.03718708116295082, 0.056750748705651076, 0.03020751050540379, 0.050313076470047235, 0.01984981763442712, 0.00910120886484427, 0.006331090075296483, 0.053255719997520955, 0.007834441660504256, 0.029623563268354962, 0.027017435790704827, 0.06523730832019023, 0.03158739289002759, 0.04935174162632652, 0.030182265610034977, 0.032408939341881444, 0.0303625828985657, 0.06458184349217586, 0.025682119586105858, 0.008391300931439867, 0.05675208881231291, 0.032667837770921845, 0.019726180072341646, 0.04190393091578569, 0.046089369005390575, 0.0678440091599311, 0.009660013834945858, 0.041666016182196994, 0.02631842597786869, 0.030959038928683316, 0.013469278895562249, 0.02650316392204591, 0.025226637687800185, 0.03676405189824956, 0.0320063814786928, 0.03740780860451715, 0.042927880971027274, 0.03911527751811913, 0.061598426795431545, 0.034095146360674074, 0.02439696917177311, 0.08674139263374464, 0.02889508128698383, 0.013089601233202432, 0.046936713358653445, 0.019896714582241008, 0.0064012955491697145, 0.05197102929066334, 0.02943650134173887, 0.027497604489326477, 0.015624081350064703, 0.024756250071472356, 0.046192452045423646, 0.018677931678082262, 0.01572714912305985, 0.07778441826147692, 0.03341941708432777, 0.021210053037585955, 0.03945291315072349, 0.10718588344752789, 0.03080897412395903, 0.016509483036186014, 0.028049375595790998, 0.0218001936030175, 0.06567429844290018, 0.0550470456614026, 0.03338835035849895, 0.06129554233380726, 0.03151944439326014, 0.021298181165808013, 0.0068578304490074515, 0.0370540034824184, 0.042484678860221586, 0.07318283125225987, 0.03750371274405292, 0.03676437420238342, 0.03990826103836298, 0.01220508842795555, 0.0874968735235078, 0.032972208224236965, 0.056156131505434, 0.05711864360741206, 0.027537442976608872, 0.013473121948274118, 0.07003676971154553, 0.03525929871414389, 0.012595715949178805, 0.018406074926523224, 0.03334773325228265, 0.022716358370546783, 0.030426371975668838, 0.04450582433491945, 0.011161863737340485, 0.0198843431925135, 0.016361207867573415, 0.05565466019990189, 0.009936566048833941, 0.010571879234963229, 0.03476657033232706, 0.011391027065526162, 0.0624623443665249, 0.02954736039308565, 0.03720233802284513, 0.07753919570573739, 0.03754938154348305, 0.06221428553440741, 0.029976930735366683, 0.012817000637629201, 0.030524254044783965, 0.03771474392020276, 0.011719452433421143, 0.026267713966912458, 0.07752559786396367, 0.008977179448785526, 0.03055552433111838, 0.042021215693759065, 0.020474290375464728, 0.04348978599799531, 0.026161265393186892, 0.06346851001892771, 0.02788813871198467, 0.03802694806030818, 0.0640546353533864, 0.04183940562818732, 0.014951556455343962, 0.042466551797198396, 0.06817083912236349, 0.01557015986847026, 0.046358964538999965, 0.05232281916375671, 0.026531406245859604, 0.0432013204055173, 0.06227154710463115, 0.031837310908096175, 0.0031541956912925734, 0.025036339149145142, 0.052968485946101804, 0.017397303699648807, 0.0208815284339445, 0.043105005752295256, 0.013946714794396289, 0.00530471934637587, 0.06522845343819686, 0.022841534510787045, 0.02878040208348206, 0.00940885579413069, 0.013967225211672485, 0.039436034592134614, 0.032239899305360656, 0.018686779774725437, 0.06519743081714426, 0.057254296328340254, 0.02415479493460485, 0.0327145956190569, 0.03023981216496655, 0.02670680415550513, 0.04386156890541315, 0.01287743859990899, 0.03799355735204049, 0.059315461798438, 0.02116603307825114, 0.061468745182667456, 0.02305046731739172, 0.06645104462014777, 0.024512688230190958, 0.05573480875630464, 0.030637121559785943, 0.020170016613389765, 0.02126956564773406, 0.027609717134120207, 0.05804400930979422, 0.05241591416831527, 0.02174302193868373, 0.06489272109631981, 0.017590065320421542, 0.04259019105562142, 0.04815928418455379, 0.012981407976310168, 0.04136829537206462, 0.07328851308141436, 0.015740831781710898, 0.04452688266922321, 0.04882892021643264, 0.042744493311537166, 0.004158131720032543, 0.0021667211341472076, 0.011134889425842889, 0.020008934096300175, 0.05751583765127829, 0.016587026018117155, 0.008272412266316158, 0.049877022725663016, 0.03444171151412385, 0.02807599791724767, 0.020384028254609023, 0.013731823602159108, 0.062351654948932786, 0.02185960952192545, 0.013887940939249737, 0.05944135718579803, 0.04258736834994384, 0.022991660383663008, 0.022495137294754386, 0.033212745495672734, 0.06755245623311826, 0.025506034659753953, 0.0066072334718358305, 0.02750411333649286, 0.06720198611063616, 0.047090900263616016, 0.03178201030407633, 0.04984206799417734, 0.024765037099963853, 0.028874134910958152, 0.027811143647081087, 0.02822519250081054, 0.036106904303388934, 0.05036161207993116, 0.052241547631898096, 0.019919387829889144, 0.011806543251233441, 0.012885969481430948, 0.05842016876808234, 0.05134959638650928, 0.022549959531586086, 0.027486298399578248, 0.029491462678249394, 0.0069812381573553595, 0.04201237438246608, 0.020752211533752934, 0.056205549210842164, 0.08889698303703751, 0.014321007433214357, 0.04168359702453017, 0.036685104348829815, 0.029619027261755297, 0.046628858628017564, 0.020727864000946283, 0.07683351250099284, 0.05510686191597155, 0.019468292660479034, 0.08133293927780219, 0.02808102246906076, 0.04728511734200375, 0.02080977165938488, 0.028602147541408027, 0.026322225773973123, 0.05146392275180135, 0.03173949329980782, 0.014105984774817313, 0.012587198638357222, 0.010770600089537246, 0.014380425048459853, 0.001965592964552343, 0.032028986872839074, 0.03682395296969584, 0.014802830060943961, 0.09411197248846292, 0.006299519961300705, 0.03286352387762495, 0.047803528274276426, 0.04442981144945536, 0.02152016050448375, 0.04079658890675221, 0.029281880174364363, 0.013093752171179014, 0.04783118196896144, 0.034947634009378295, 0.02362164791806468, 0.027236241281830838, 0.030423722296421016, 0.046070906067533154, 0.01874462827774031, 0.05179270689508744, 0.05767809573028769, 0.024414661972384368, 0.0047360972468076, 0.018634344284821833, 0.03494840753929956, 0.04472984606400132, 0.024138766241126826, 0.040587919032467265, 0.024895037624186704, 0.020862448029220104, 0.03163228815953646, 0.006340565392747521, 0.04905978836385267, 0.006661544262897223, 0.09785802861941711, 0.06657073819743735, 0.032600133546761105, 0.02603275764600507, 0.039910683408379555, 0.02990660397335887, 0.04363208496943116, 0.04926519109202283, 0.01575298434389489, 0.04773525068802493, 0.0395146564447454, 0.021678542452199117, 0.04272031032347253, 0.024422648329553858, 0.039185539819300175, 0.005814274548486407, 0.017052428098395467, 0.05724415222981146, 0.01780127121933869, 0.022785774199292064, 0.07937147774334465, 0.015907105091693144, 0.02218988135323993, 0.03730161787409868, 0.04400665665577565, 0.009258488193154335, 0.019316160020285418, 0.03763241048103996, 0.048329267384750504, 0.053236283361911774, 0.026816470681556633, 0.05072418387447085, 0.05295554628329618, 0.04445325483434966, 0.04361065683354225, 0.034125246174101315, 0.028317457996308804, 0.06079624912568501, 0.03856604413262435, 0.07514830292867762, 0.02051467338709959, 0.025893836082624536, 0.18310788593121938, 0.15055860179875577, 0.12296976149082184, 0.13543176278471947, 0.1369184194398778, 0.12859169553433145, 0.12262948974967003, 0.0989681254806263, 0.08245480872158494, 0.10984850914350577, 0.16346136587006704, 0.1275298289422478, 0.1657682763678687, 0.2565010019711086, 0.17798633075186185, 0.1115507295887385, 0.1304757565792118, 0.07836812122591905, 0.08721112207110439, 0.1342647232647453, 0.10575872752815485, 0.14644834878189222, 0.08058114961854049, 0.10187165146427495, 0.12720889544912747, 0.1965104860386678, 0.0878746546804905, 0.12171498739293643, 0.1770701049161809, 0.09854071627237967, 0.11537248987172331, 0.13736021359051975, 0.20900349638291768, 0.1649345061076539, 0.17138421216181346, 0.13995204094265187, 0.11562797187694482, 0.13223462791315146, 0.13198248430022172, 0.09806075452693871, 0.1293175108730793, 0.12059007132691996, 0.22002753269459518, 0.13088282330759934, 0.0682616610346096, 0.10550583752670459, 0.09897728570337806, 0.14512086287140846, 0.08400351061884846, 0.09156258071639709, 0.19414153029876097, 0.13348453012960299, 0.09465723644409861, 0.12216719027076449, 0.12035767308303288, 0.09219083629016366, 0.2027336699622018, 0.13554116977112635, 0.09832239084477935, 0.08522085672510521, 0.19765609742275306, 0.08881766229335751, 0.12715212920946733, 0.1773775898452316, 0.10958862344601325, 0.1669987589120865, 0.1202387258942638, 0.2219549792685679, 0.18390593810805253, 0.14951143227517605, 0.07394777092018298, 0.07608619438750402, 0.07626611473304884, 0.07250690859343324, 0.13645601139536925, 0.06327172807816948, 0.13218554268990243, 0.1511071023664304, 0.07773191322173391, 0.11006458183484417, 0.0934398699817913, 0.1949719214545829, 0.14542042251144136, 0.09366468898952007, 0.15425120294094086, 0.17025013587304524, 0.1625316236168146, 0.18369164317846298, 0.16052146362406866, 0.11739607128713812, 0.13606848647551878, 0.11177841879959617, 0.11918606023703303, 0.1047414339014462, 0.15031552341367516, 0.21719310193189553, 0.07973307584013258, 0.10909221401172024, 0.12126275737370763, 0.11488672665187291, 0.11032123770564795, 0.11746674749468054, 0.1344425401517323, 0.2686732959534441, 0.11242258601955005, 0.09115782779242311, 0.08073305325316531, 0.1423329117574862, 0.130025019337024, 0.07585548569581338, 0.15347782229738577, 0.11396231768386704, 0.1764074204755681, 0.13916734233498573, 0.10052406056118862, 0.19330902211368084, 0.1373515147715807, 0.18738565567348683, 0.1587709654122591, 0.11600288961614881, 0.258725999721459, 0.08967749508363859, 0.117602264508605, 0.09167431507791791, 0.17006657857980045, 0.10216894479734556, 0.1017499358526298, 0.11843855891908918, 0.15322094251002583, 0.11008047312498093, 0.11326928915722029, 0.11018936442477362, 0.14743628219834395, 0.11506896758718149, 0.16710549247051987, 0.17714076755302294, 0.0929445665595787, 0.08720227397446122, 0.15525305989597524, 0.16288353901888641, 0.10761166417172977, 0.094490459321865, 0.12167462813002722, 0.09655380967472281, 0.1358560507318803, 0.11686496835734163, 0.1517831946590117, 0.12982299232057162, 0.15204240860683577, 0.1076387105775731, 0.1566475307835, 0.16220674104988575, 0.0801428227818438, 0.15636390314570495, 0.1776065139898232, 0.10789989227695124, 0.08428401021020752, 0.11513315699994564, 0.15015423563974245, 0.13640645119760716, 0.08637784714145319, 0.10783957729914359, 0.10393306120697941, 0.12143154974494662, 0.1307835400636707, 0.15796406513878278, 0.11716162386749472, 0.11475768286202635, 0.124391536627497, 0.18837304626192364, 0.10209771897643805, 0.0968205892880048, 0.2091908806136676, 0.20666746316211565, 0.1206409071705171, 0.17731182623122418], [0.021566585870459676, 0.012222162913531065, 0.012580268251310502, 0.028030106897598932, 0.066130131483078, 0.040529249502079825, 0.055634334683418274, 0.032795141118445566, 0.015108267510575908, 0.03277180969182934, 0.03435306091393743, 0.034776046073862484, 0.028848204695220505, 0.023045198492971913, 0.014381235897807139, 0.058513901595558436, 0.05262008196275149, 0.031595813509609015, 0.03736432468784707, 0.026476368574159484, 0.0246627479459026, 0.015769372660932795, 0.01888792639199112, 0.022141145575525503, 0.007918191541518484, 0.07965252016271863, 0.028005900160808648, 0.029632129772965397, 0.04848851616095219, 0.026398638995098214, 0.016812213131093552, 0.057679934560188224, 0.04169040273076721, 0.007295407504508538, 0.03249052639252373, 0.051553760788270404, 0.029743555401052748, 0.017132790393329093, 0.0353601493739656, 0.029073597065040042, 0.02181670066368367, 0.022571279101872017, 0.01746456009069724, 0.04005387465336493, 0.04112564107137067, 0.03358730700399194, 0.03287548305732863, 0.021724246874717728, 0.032811829687229226, 0.010476431410227503, 0.01999711910528796, 0.013420130059655224, 0.04708922767479505, 0.034487207287124226, 0.02852180560252496, 0.0184890987750675, 0.0745842842651265, 0.029237344528415372, 0.020680200308561325, 0.02243002507436488, 0.04182369075715542, 0.02646780546222414, 0.04958578531763383, 0.02840753860904702, 0.03675272036343813, 0.04890672443434596, 0.0876495846148048, 0.034615240059792995, 0.03638507651963404, 0.017254375386983156, 0.04179514139624579, 0.03622461995109916, 0.044489736269627295, 0.05316017208886998, 0.013367988036147185, 0.015228933089279702, 0.05732214304485491, 0.03780937919925366, 0.04692053369113377, 0.05021591704072697, 0.01869899170872356, 0.015607886415507113, 0.049497182214898724, 0.026971607535545315, 0.019888577251029865, 0.010238293608251427, 0.03988221886434725, 0.043499360127108436, 0.041723450778850486, 0.01719619949082179, 0.026374908929158534, 0.02996915133137788, 0.045985939912498, 0.039305867826832194, 0.010192019216317152, 0.02212234167382121, 0.03320499662575977, 0.08995298708656005, 0.016320302383974195, 0.018474693476621593, 0.01381767015638096, 0.019396376430190036, 0.042539959108190875, 0.036867104404206784, 0.02724581880361906, 0.053051752370915244, 0.012055941341843988, 0.030755922863526002, 0.029985765261309485, 0.08382788539997169, 0.03876952999936683, 0.037633835404579125, 0.01565273418756468, 0.0626001548288124, 0.016336426072354828, 0.021611482836306095, 0.03783908885504518, 0.07568741257169417, 0.038885355927050114, 0.08306475063519818, 0.036497540306299925, 0.09454386681318283, 0.008676838645312403, 0.017408655590510795, 0.02701019073304321, 0.024352055242551223, 0.01726539309934846, 0.024689826582159315, 0.07349604301686798, 0.001896696215096329, 0.006327356012271983, 0.017506921031911458, 0.00570783657687051, 0.015281404202271785, 0.03226886935798185, 0.017958399573607103, 0.020760187712897147, 0.166354897032891, 0.03204716143331357, 0.044249572192451785, 0.05119171825104526, 0.03414059802889824, 0.06853553133883647, 0.03302157503951873, 0.02657296142673918, 0.01055567157787404, 0.0420388677822692, 0.01866993005387485, 0.006005111250228116, 0.008034572171579515, 0.049179431051015854, 0.05654832474621279, 0.06087008052106414, 0.01521228692893471, 0.053948989404099326, 0.033632694211389334, 0.0244778759910592, 0.036219510582408736, 0.02006677072495222, 0.06334971210786275, 0.043726560792752674, 0.022611848710637008, 0.008019803856898631, 0.05541802789749844, 0.05591644240277154, 0.04884050620187606, 0.0021399414773830877, 0.02537881104009492, 0.03771719682429518, 0.017649423563852906, 0.05030493404982345, 0.023411062878689597, 0.02498381375335157, 0.03299713760082211, 0.059519225864538124, 0.06931867610130991, 0.029141983216894523, 0.0676630302997572, 0.03737951708691461, 0.07861962023058108, 0.02048596796313567, 0.018674394814297557, 0.051681518754256625, 0.04471502685919404, 0.034016877346272976, 0.027469457160415392, 0.058350259305111, 0.02369852763201509, 0.04195164889097214, 0.04345899407884904, 0.016668100774820362, 0.004207987504612122, 0.058663559279271534, 0.021828781979690706, 0.06373573067997183, 0.015824364531519156, 0.038890353337462456, 0.008448777936532028, 0.029052626940288713, 0.036973424056278806, 0.025760644747476493, 0.037600838246622255, 0.13096799302314008, 0.00985216222969549, 0.03165607759729028, 0.036929648369550705, 0.007385749353228935, 0.02433598753330963, 0.009929983410984278, 0.015574985948790396, 0.012759521088030721, 0.03136597673541733, 0.04561815357633999, 0.03803368591304336, 0.02965752055336322, 0.06499938680125134, 0.052518155824925215, 0.017196967931730405, 0.01975536047081862, 0.030646654976797954, 0.019990057252081375, 0.027832083237756575, 0.02001228097027966, 0.014370671107566782, 0.008971515377717358, 0.0862544962604131, 0.017418621573597193, 0.029146685464573757, 0.01939740780341838, 0.024478274630382657, 0.06466865526246172, 0.051774644292891026, 0.06555092720580952, 0.019017092318141034, 0.014075635599770715, 0.009393843206843095, 0.04779273278212973, 0.046058936709804196, 0.03442968448091831, 0.012329122933026935, 0.02270057564601302, 0.043022014134164364, 0.060177493042179515, 0.046101996542087624, 0.05332239284845335, 0.053067952394485474, 0.013511946025703634, 0.07925417939467089, 0.007346979558600911, 0.05002803069406322, 0.02640319875042353, 0.03527816538033741, 0.0497960022517613, 0.025805682509339282, 0.01820334732266409, 0.019619867205619812, 0.014604093939332026, 0.05557966850964086, 0.03197128764752831, 0.023523733618536165, 0.03427325841039419, 0.024246068072638342, 0.02102014804924173, 0.0695341516818319, 0.031116058717348745, 0.014108977114249553, 0.03211814298161438, 0.02727944530280573, 0.012998413760215044, 0.03544072201475501, 0.029098916599260907, 0.009123660740442574, 0.04520162806979247, 0.0628426836005279, 0.050068942963012626, 0.008879983548208006, 0.06471902970224619, 0.031873609138918776, 0.010082288229438876, 0.01604035579865532, 0.04223467263260058, 0.04164993490225502, 0.03909316745453647, 0.05032862170732447, 0.008936129776494843, 0.05291944482762899, 0.031150253489613533, 0.05037847028246947, 0.028387747438890592, 0.02009544731117785, 0.007426152720914355, 0.03648998142619218, 0.022561637119257023, 0.05111095901312573, 0.035276913483228, 0.1200045363179275, 0.010733350213350994, 0.12453455823872771, 0.005977977483001138, 0.050340261975569386, 0.01770922285504639, 0.032130607669906955, 0.027232828250687038, 0.05560381757095456, 0.005581789367300059, 0.014104082332258778, 0.05027809798983591, 0.034071424776422124, 0.0592455794768674, 0.023075712212760533, 0.00404865645603942, 0.0483109944366983, 0.0587190023756453, 0.09248526620545558, 0.07129568965839488, 0.01521129796414503, 0.03272598822202001, 0.014015558109219586, 0.0009529467726159574, 0.13669025525450706, 0.04151202605238982, 0.04662155419854181, 0.03500508896208235, 0.04722421543140497, 0.03622055891901255, 0.01723602949641645, 0.040168099238404205, 0.05416110623627901, 0.015356714803991573, 0.02141424118807273, 0.026736469706520438, 0.019008315467674817, 0.03451748351965632, 0.02313537070793765, 0.033191347893859656, 0.030754640432340757, 0.034479495736637285, 0.04466440475412777, 0.026810577604919672, 0.021285066780235087, 0.05070718317957861, 0.0879712373550449, 0.021191588403390985, 0.02942883050335305, 0.08374180644750595, 0.10570878056543213, 0.004259516302097056, 0.04845699142398579, 0.03979642489658935, 0.03360773090805326, 0.025620668062141964, 0.02322454208375088, 0.16425674461892673, 0.13672509124236448, 0.12900241278111935, 0.09232134571565048, 0.131948001150574, 0.15168507849531515, 0.22643408392156872, 0.20542072291885102, 0.14333327593547956, 0.13009679477129663, 0.17065824754536152, 0.08046507941825048, 0.10818912461400032, 0.13539058927978787, 0.07787828001060657, 0.10246165801904031, 0.1488740300493581, 0.15664421953260899, 0.21099350388560975, 0.12147908790835313, 0.13645822341953004, 0.06268758406596524, 0.1179960590920278, 0.0909525030957801, 0.08869655057787895, 0.11046061558382851, 0.19962968437799386, 0.16763218492269516, 0.09701597344662462, 0.10715061998260872, 0.09174153075686522, 0.20936367634151662, 0.06693610894892897, 0.09094847938311951, 0.08553036368851151, 0.1764881390013865, 0.21434174850583076, 0.12433920800685883, 0.08614346757531166, 0.12433034633951527, 0.11152398852365357, 0.07067750354430505, 0.11268329952976533, 0.10499999645565238, 0.15210197041077272, 0.13691998007042067, 0.04482344996982387, 0.11781001836061478, 0.2789464789841856, 0.13699364183204515, 0.10970545360552413, 0.10668941973043339, 0.14263640690062726, 0.10658025701663323, 0.0612665078203593, 0.16945379360445909, 0.19926577247679234, 0.12847311475447246, 0.0956377059753452, 0.11788583786359855, 0.1872295926191977, 0.13994342354791506, 0.24687880543725832, 0.10427574174744741, 0.08317560290119477, 0.13357826295707906, 0.2151707825916154, 0.13849471057099955, 0.12317923882177897, 0.14815158024430275, 0.10953227789806468, 0.13244793218161377, 0.08432339916804008, 0.12082639150321484, 0.11254501409296479, 0.12859540033553327, 0.10049584707511322, 0.11262418555894069, 0.0743455213627645, 0.18753615474062307, 0.12710874368037495, 0.1095311651006341, 0.08700302216623511, 0.2207236417702266, 0.1387712543031999, 0.15931171711002076, 0.21706435669745716, 0.12965249004108564, 0.14652525394090585, 0.12404013691203934, 0.15984883186008247, 0.133428496707763, 0.07253050125603165, 0.1251724354390587, 0.09883933274873666, 0.07447279417621237, 0.13095715003354208, 0.11984144364084516, 0.11070304257529122, 0.06889156544847147, 0.126296944384064, 0.06594818910317761, 0.11197697171675307, 0.09303339357886996, 0.1156794862555606, 0.15000027604401112, 0.10550309624522924, 0.15123364914740833, 0.148026349821261, 0.12311006896197796, 0.09530202791626964, 0.11063581332564354, 0.0500241257250309, 0.14161221257277898, 0.14735200814902782, 0.10530888595219169, 0.08843308221548796, 0.14464842607932432, 0.08018106501549482, 0.30416672996112276, 0.07440599918897663, 0.23085294823561395, 0.10520662393953119, 0.08683246560394764, 0.07296892987298113, 0.07579879409500531, 0.06796467982764755, 0.15513431626771176, 0.21996624741171086, 0.10169419420084783, 0.1329062690160104, 0.06869471565421138, 0.10326157616717474, 0.1352705428642886, 0.09549136632787329, 0.09955519397876092, 0.09436654525675944, 0.2658125380320208, 0.2666698805987835, 0.15476640100990022, 0.11126716980444533, 0.16030585233654293, 0.12558403478137084, 0.23623739502259664, 0.1308667827397585, 0.18065255268343858, 0.08569693046488933, 0.11231724345790488, 0.12381475472024508, 0.07925827096083335, 0.17865946463176183, 0.18369044895683015, 0.15676893426903657, 0.08462855672197682, 0.1162892042526177, 0.13516690342554025, 0.05655265719230686, 0.08551257928567273, 0.1547542688037668, 0.19226425460406713, 0.1223578043282032, 0.10646190693868057, 0.16681284031697682, 0.1242054280425821, 0.15571185813418456, 0.11197450863463537, 0.1272250445825713, 0.062363888935319016, 0.2224711679986545, 0.23180094308086804, 0.09852723378155913, 0.10672732269657509, 0.1463711993502719, 0.16553278400429658, 0.1325642873666116, 0.17575434409081936], [0.03708028653636575, 0.04505414169813905, 0.0403452681244484, 0.020912174468061755, 0.0020215701952110976, 0.05212079214730433, 0.016274245123245885, 0.031628196593374014, 0.02373717020132712, 0.02886578214487859, 0.0156436384256397, 0.019108601247093508, 0.13953828385898046, 0.08459817870919194, 0.011773439224011131, 0.03734635368787816, 0.04335766165916409, 0.022422708770526305, 0.02446428663097322, 0.09545000961848668, 0.02805381660748805, 0.021196528138326745, 0.07621462071048361, 0.01738890682879303, 0.034323229121842554, 0.05191697379840272, 0.047589643858373165, 0.04017371411568352, 0.004366059870725232, 0.02444162016867527, 0.037336555642208884, 0.046994857024401426, 0.0750037749697055, 0.03128701900797231, 0.013512381136284342, 0.027979963159720813, 0.0452803347392806, 0.03837248184052961, 0.0383630502037704, 0.07145810380045857, 0.02329518606087991, 0.009883552955995713, 0.003934292771321322, 0.02276666326049183, 0.015286842660446252, 0.027114864937695007, 0.02339264065293329, 0.024351843200357895, 0.040586416077400954, 0.02054263581521809, 0.021412756892719438, 0.013652051632691706, 0.043792358333511014, 0.02468868494699044, 0.052249574701168706, 0.06927529057221753, 0.02038125813539539, 0.03313380812427827, 0.019651732906433086, 0.03248078262965594, 0.05125302728265524, 0.018710369044648748, 0.026094348269647787, 0.035851320517914634, 0.06594731379300356, 0.0365180863466646, 0.06674919290734188, 0.05418916026662503, 0.07182641260858093, 0.018058458043794547, 0.03974953812680074, 0.05731787505958762, 0.062144240364432335, 0.024242517638153264, 0.0465921430981585, 0.05824254187090056, 0.11218051186629704, 0.0236221907460796, 0.08649590544934783, 0.03187614346721342, 0.01914070952417595, 0.0924880142722811, 0.047087758646479676, 0.047944653380130015, 0.031195851042866707, 0.0357149349791663, 0.03644566969679935, 0.02133554808928498, 0.006252448714803904, 0.025318127957039645, 0.018716776111562337, 0.02721220417879522, 0.06202632454889161, 0.02526400121860206, 0.029831371403166225, 0.03012755193880626, 0.056146645585873296, 0.06346004190189497, 0.0377473610985492, 0.00575579543198858, 0.01702055730856955, 0.03404826298356056, 0.01599155386377658, 0.03509950032457709, 0.018643453617447188, 0.03234593058004975, 0.024452666718778864, 0.022395126322018247, 0.06433729947145496, 0.04250180169141718, 0.05364563336063709, 0.06797437609306403, 0.032100080379417965, 0.052918630585606606, 0.07127059064805508, 0.026965056279940263, 0.087208706486438, 0.029663020079689364, 0.017963373235293796, 0.033133071913783035, 0.04184572957456112, 0.03597681556961366, 0.0249367827948715, 0.02515997501489307, 0.012591226591861673, 0.081389766585614, 0.01272608118597418, 0.02590698778762349, 0.04200431677911963, 0.03398492852491992, 0.031146426552108357, 0.03812223473297698, 0.022421083679156642, 0.01449026120826602, 0.014121865038760006, 0.06365185018096652, 0.04221363126167229, 0.03670280393479126, 0.0738668827606099, 0.01945439456695957, 0.015137383448226112, 0.05811611722622599, 0.06797558388539723, 0.03209001770509141, 0.05128742900810071, 0.015911176301805035, 0.04610482942579048, 0.0321566396658974, 0.1196377474282469, 0.015293862105214169, 0.018336606511314, 0.04056750191375613, 0.0659697325900197, 0.04137250907453043, 0.026500863688332692, 0.0518488081704293, 0.03832513027425323, 0.04860050497310502, 0.022116965980135968, 0.055004155462873836, 0.05745722579636744, 0.03381403269512313, 0.035287814148302586, 0.06877208221703768, 0.03640704409086278, 0.0665219651002969, 0.0626910242385098, 0.01737366523593664, 0.025461894260453324, 0.04582687094807625, 0.03469639963337353, 0.012130685366823204, 0.05414842441678047, 0.04579700862190553, 0.014927602472848125, 0.031110939170633043, 0.027773194879825627, 0.05340692134840148, 0.024421043594234755, 0.024666130442970564, 0.013803850094388639, 0.023000805339376842, 0.03720948978194168, 0.02416835884962763, 0.021390962347920452, 0.03678311873227358, 0.045514110409255536, 0.04794876190966793, 0.05618478264659643, 0.03591142175719142, 0.03926013795925038, 0.023116419224866798, 0.03109303263149091, 0.035688380511211495, 0.070118872448802, 0.07261930791927235, 0.03515772880720241, 0.009906545115102614, 0.031510579333241494, 0.03845505615962403, 0.041141437366604805, 0.05939310656062194, 0.049573415624243874, 0.01845620509370097, 0.08693290235740797, 0.008381613147711115, 0.07066984288394451, 0.047767701625291786, 0.06421646595533405, 0.04470643999853304, 0.03497797131006207, 0.07725638230996472, 0.026772270910441875, 0.008495966654403933, 0.038017492674823315, 0.03773763429905687, 0.009724125216182853, 0.05064157562862549, 0.016630340301032578, 0.014374894988057869, 0.02248220780997404, 0.02398349198379687, 0.0497195924233113, 0.024644037342763374, 0.025747557503304312, 0.03200038322912795, 0.015507527693573917, 0.01526150616284992, 0.018505236034148505, 0.025963358780635253, 0.05650807744158166, 0.052769047540745566, 0.05569194909185171, 0.037564560371850214, 0.03949619011421289, 0.059827905015221665, 0.03068342139678342, 0.04465832508036068, 0.04707100222419415, 0.06072533543088606, 0.01839543380109327, 0.038124460327838144, 0.026171423062416058, 0.02996591471933893, 0.05139086149366839, 0.03491724581856813, 0.07458093230213438, 0.054583942118499956, 0.021378750413922325, 0.02380803639867476, 0.01820966278735016, 0.028322959218972495, 0.0500728716807706, 0.032381217793694565, 0.04496647158105459, 0.019736909407324026, 0.019257096939587166, 0.023853320129481808, 0.07200320490768977, 0.007796673553197512, 0.013316318442645882, 0.037677950358816555, 0.01469114319687443, 0.012765918825087803, 0.023688505669789653, 0.07737832183816604, 0.03377724252641201, 0.008430811177406992, 0.01578268382166113, 0.06613840282495533, 0.021556144912860224, 0.026251357880287936, 0.025501605522419726, 0.041898590845188925, 0.03741592727601528, 0.02338719880208373, 0.08904691892010824, 0.016804335339527045, 0.02502753006826554, 0.014995941127251302, 0.04962621243404491, 0.021076052549428174, 0.08444378485104867, 0.04485828935035637, 0.01837767823599279, 0.03073086795796241, 0.03428170277870127, 0.049039873361055336, 0.05824637559375592, 0.0573252643059407, 0.029495839229119674, 0.05973755807748862, 0.05311339727735945, 0.03521908872893878, 0.03470884057294045, 0.032815344498625824, 0.029859079380652735, 0.022991896174581986, 0.021275462117046118, 0.00313001121893259, 0.04487636213057807, 0.025343437313235233, 0.022276913647406867, 0.058342917556209226, 0.05247878722314324, 0.03179850549037967, 0.046567834581115415, 0.0661297786448683, 0.014712924170973045, 0.054742508967007907, 0.0227878895322127, 0.00928568048402667, 0.028429555374064615, 0.010325891630990165, 0.0229374199906098, 0.006924985059803086, 0.016235029191843102, 0.04691861343703099, 0.1038048927273069, 0.04784649311165724, 0.0751497210668666, 0.015301702577354652, 0.034436279841299565, 0.0477798474021256, 0.052974246708410125, 0.022440981718578508, 0.03085947409272194, 0.022970993903332522, 0.03450742084532976, 0.016824374174965278, 0.027671704700748836, 0.04264553237174239, 0.08979899356407778, 0.03590421571529337, 0.023495106226099387, 0.03398137978677239, 0.031306744020964415, 0.051743682739990096, 0.03207898472568818, 0.07945575857801096, 0.008595875846887273, 0.06795600136475903, 0.018741783519674624, 0.04283286910504103, 0.003259090207783239, 0.027755361283198, 0.027708879938083034, 0.06662257148751191, 0.058417407130556445, 0.08271021608795438, 0.006817747265033956, 0.04616306130109089, 0.1369247840983527, 0.1669392106788499, 0.1310900750436953, 0.1337337696126529, 0.11702859029173851, 0.12014413811266422, 0.08925976178475789, 0.12848410702177457, 0.0808567094749638, 0.10246369362409626, 0.15525091572531632, 0.12143484742513724, 0.2579472315098558, 0.14446180180779525, 0.09961110526429755, 0.08016739932021924, 0.07487278378435544, 0.11026040704122611, 0.2169827153640134, 0.15944342075714044, 0.13988046906888485, 0.10773308122796671, 0.15141916062150682, 0.16502447985112667, 0.10980335263801472, 0.135064906041537, 0.1372512680079256, 0.13649125450423785, 0.17192014626094274, 0.10708917863667011, 0.10968644783965179, 0.07742314586149794, 0.18920298958463327, 0.12476812356284686, 0.11630107861544405, 0.1923916291977678, 0.11795386778456823, 0.09960203325109822, 0.12302637845277786, 0.15179506902183804, 0.08651056859110083, 0.06231557045664106, 0.09053622864718948, 0.15144456497260503, 0.09516222934637751, 0.17035495596272604, 0.09337764153523104, 0.08670061267912388, 0.15458661637135915, 0.07223121303000621, 0.07684588897973299, 0.07804347614624671, 0.06801211621080126, 0.0755184641374009, 0.13349476243768418, 0.11968597769737244, 0.12492071251784052, 0.12399466149508953, 0.1964793141399111, 0.10341262484767608, 0.10992185199367148, 0.1581522636115551, 0.134978854230472, 0.0905157301042761, 0.19813153333961964, 0.08973054295139653, 0.14407319123191492, 0.06732499772416693, 0.07855290666754756, 0.07417585368135146, 0.21703857236674853, 0.11407624371349812, 0.27108320806707653, 0.06975366454571486, 0.13637123523013933, 0.14402057762656892, 0.16577929577657155, 0.14520633114235743, 0.19123478127377375, 0.0940994331613183, 0.09726581682584115, 0.2534054166504315, 0.1721388923802546, 0.09735284572733299, 0.05274961429781147, 0.12383344157465867, 0.09113032676811729, 0.06854415551892348, 0.07300407798694712, 0.18279115935521467, 0.14487952153597558, 0.05660217667796782, 0.11671866263662066, 0.1548410127205508, 0.12492357593561922, 0.11794503325862543, 0.16298664920032024, 0.12321862099426133, 0.11048862550939832, 0.08883038482495717, 0.2050783477191414, 0.16528427733906678, 0.108642514928111, 0.17184021483574594, 0.17527917958796024, 0.13105431624821254, 0.14826462417840958, 0.11465423341308321, 0.1941506905215127, 0.1378000264189073, 0.17956241832247802, 0.10753487436366932, 0.12611101221825394, 0.2436455317905971, 0.12809381367904799, 0.11737519954996449, 0.14139723910817079, 0.06791100770767246, 0.10079660772212914, 0.1465168401066746, 0.16297724470496178, 0.0775972240205322, 0.14447892803166593, 0.13006299015666756, 0.1984323686254876, 0.1399379681263651, 0.05880949180573225, 0.13362178419317516, 0.12871016774858746, 0.1034317391791514, 0.09604558694575514, 0.13553295949740068, 0.1694754117301532, 0.14480186998844147, 0.09471061679401568, 0.22979535641414778, 0.08728846149252993, 0.13155158742197923, 0.13055001545165265, 0.14503228691007408, 0.0927586140377181, 0.141804875805974, 0.19209382017808302, 0.07288196203964097, 0.2133576013147831, 0.05730937301580395, 0.1808554617954152, 0.12612060670341763, 0.16693163822804177, 0.10189169538872582, 0.10567864003990378, 0.21657673429165566, 0.18612123280763626, 0.11069591117224523, 0.13662089540490083, 0.18880635872483253, 0.29690716522080557, 0.14099075591989926, 0.17320675722190312, 0.15296463269208158, 0.18480315139251097, 0.15557221562734672, 0.1640533333910363, 0.1797414972845997, 0.08484218668724809, 0.2517130146069186, 0.13068144768476486, 0.09368813915976457, 0.08384634155247893, 0.10465775696294648, 0.04708512932328241, 0.14787770994007587, 0.16893019527196884, 0.24098605449710572, 0.0783279790942158, 0.1247546478573765], [0.024959542555734515, 0.0141607629068728, 0.00481942473977272, 0.04813981701486877, 0.03767872049606272, 0.0132893246232665, 0.048868098828409395, 0.03587205654808453, 0.08587976172566414, 0.03304702688806823, 0.09768824558705091, 0.0225776386713343, 0.013387016702576407, 0.02890464523807168, 0.018535427449803268, 0.05384767394778984, 0.02641330722586385, 0.041321625733481984, 0.01755186210253409, 0.026815318868362477, 0.04228902668026941, 0.0534867849200964, 0.026916661466072713, 0.04343595102961574, 0.011170613446405955, 0.03000715947044747, 0.09651794231363706, 0.05046238470822573, 0.038146726454475095, 0.021138588033084358, 0.08047126765762057, 0.012260298277916653, 0.04276534129998513, 0.037272332302693806, 0.028151145670562983, 0.09302716462739877, 0.02932960832757609, 0.034207525330462625, 0.07001673257244484, 0.025055962381884456, 0.05272351444831916, 0.025114021230755106, 0.03661639250016638, 0.03742206123258386, 0.03057657927274704, 0.007704050978645682, 0.06131359136530331, 0.03235098905861378, 0.06139986709292446, 0.012163011623280389, 0.0164963109751365, 0.037951963155397346, 0.02524860356269138, 0.026555197379950966, 0.08063860117856946, 0.01705544757922845, 0.00580934711199786, 0.020120544625180106, 0.021456395176106265, 0.04787527317447322, 0.042571069938795905, 0.0334902866743505, 0.04295394350109356, 0.023022962900410806, 0.003514329424693382, 0.046481982937880924, 0.012989092385396361, 0.024563410419172475, 0.03930226141320808, 0.03852668570886765, 0.024758512985759547, 0.013808685504565281, 0.018807216347860437, 0.019592395019052283, 0.034397555847785304, 0.03260964321504746, 0.05983356399727719, 0.02565884244229112, 0.05349798074790409, 0.027343088494879857, 0.0471124946405845, 0.0064163412150394705, 0.02450535157030182, 0.02338686801626214, 0.04865258592846138, 0.02617160457053355, 0.048795325947659354, 0.010395866402957057, 0.04214352841622063, 0.032582081122589965, 0.02607776826646711, 0.05286068030233894, 0.02085082302801311, 0.028464662775929486, 0.025238756323233247, 0.03405904151233179, 0.01155556587036699, 0.06379138412220137, 0.023022235171603303, 0.016559273935854435, 0.04027038839246545, 0.06104963445769889, 0.019482709833287766, 0.017061963211745024, 0.1301122653697218, 0.03130292726148452, 0.03590347271944795, 0.03919292228030307, 0.011188335084755505, 0.012010187725536525, 0.05501243019742625, 0.03598495798983744, 0.04901866914172258, 0.007796008588879236, 0.07318254626755204, 0.009622141402879996, 0.02164019165294511, 0.009175652638077736, 0.03722522500902414, 0.09609748130398137, 0.049199753174824376, 0.031537523958832026, 0.02406474994495511, 0.04316526644730142, 0.05996528121509722, 0.005192363701228584, 0.01046702521853149, 0.03694258124700614, 0.05603133873747928, 0.06960999832621642, 0.050154112678553374, 0.022868918487802148, 0.023598672722333243, 0.05413857548098479, 0.04702961837340679, 0.01154145403831665, 0.03584374128175633, 0.0024250131225146887, 0.04839331091248563, 0.02564180612431041, 0.02391440185186054, 0.03032636269927025, 0.04617904419345515, 0.04498596928481545, 0.031035051814147403, 0.0075424621047984275, 0.07285452208348683, 0.010358209405759615, 0.028168494114652276, 0.026934466224962046, 0.04185515781864524, 0.055422116070985794, 0.05597250296601227, 0.04963261780462094, 0.04849520990891116, 0.04094040779662984, 0.013126767140680125, 0.015332284150645137, 0.042658583992826085, 0.049833484526191435, 0.06283425619559628, 0.031952865421772, 0.028376977391807095, 0.06564132842634406, 0.012989419778542859, 0.030177570147705928, 0.030683709774166346, 0.018693588873637573, 0.035139557639403005, 0.01058634984240468, 0.02422836679033935, 0.021776200604758093, 0.018056213789220368, 0.01582962317791368, 0.02153838086607201, 0.057985356742782254, 0.03500021708064845, 0.029113284578280788, 0.016633688871349608, 0.019612271006086042, 0.05342082453093358, 0.018657100653009753, 0.04233029518010361, 0.014015988978956426, 0.038793539961001704, 0.024311797759894813, 0.04367614903354219, 0.010815351170354655, 0.01594562382836427, 0.039951429436249394, 0.015983192616009285, 0.00740935982737158, 0.017826170061847994, 0.013266631867736578, 0.01164271605999342, 0.03287764758403812, 0.05701122472860983, 0.02275225456937083, 0.05659971698852522, 0.02499178484348314, 0.05118951301223465, 0.014230533270165324, 0.028180141168247377, 0.017388925488506044, 0.004838299463569585, 0.04451212113989251, 0.011470781223449324, 0.016034274428550686, 0.009161818157216268, 0.038800556013094525, 0.030191246021006788, 0.02309637699675347, 0.032797180116176605, 0.021517124060275297, 0.02826897836556392, 0.0463097503940974, 0.05929895982678447, 0.05332750900249396, 0.017067393188231757, 0.05068368551188281, 0.04965197301602789, 0.05082183184900454, 0.018076194949182015, 0.031070613834474767, 0.03109219464074288, 0.013619868716757213, 0.06999282099838768, 0.03393771605832236, 0.05591568922890084, 0.011590161826461554, 0.029783724674156735, 0.043313088693789074, 0.031314676095332415, 0.02132314955815673, 0.02316795565587069, 0.06150307226926088, 0.0417215882002243, 0.04459306358226708, 0.02033380648520376, 0.04036897274532488, 0.018577710359490344, 0.00914460202745561, 0.014631586481950112, 0.015816814133099148, 0.025275549884619455, 0.03621278630037393, 0.05100587768746274, 0.016065660065838268, 0.006252800280760441, 0.05230697537107127, 0.028630574766014303, 0.0076254265815285695, 0.049718248923974376, 0.010884073197043367, 0.025340036156454256, 0.06132335548422166, 0.03464570628213031, 0.02566135471819767, 0.03688631373058472, 0.04103765543550253, 0.042618265442017994, 0.039617030415683985, 0.04168604653594749, 0.05885126920683043, 0.03768673738730805, 0.03779699593516333, 0.06321334013981478, 0.039681050194693465, 0.018098842751766955, 0.03920014528557658, 0.01150389712503446, 0.014872137324086257, 0.03419095889798232, 0.09839400343064751, 0.04682269572679486, 0.015674820502421687, 0.021043862848143493, 0.05415767963443484, 0.03819492618952479, 0.041881451050617864, 0.03448683748553906, 0.03686300266001906, 0.04075795312279037, 0.03132244871397104, 0.05404714288722191, 0.029966644144483974, 0.07918118938271489, 0.05206738126331142, 0.016657829450975572, 0.012429554597474635, 0.032388325448014905, 0.040319405762212615, 0.048917991508330615, 0.006736254785209894, 0.021595072466880083, 0.032593734961535246, 0.049020887951233556, 0.05338770184399826, 0.02097680832126311, 0.0249672812476222, 0.03569297080061265, 0.026577509307701672, 0.027706800228250877, 0.03931156073563865, 0.04062547594574945, 0.007690726247216974, 0.040605632189129076, 0.02635309742098408, 0.03472386673092842, 0.03357907637421574, 0.06778209962482963, 0.017610657161899974, 0.05738270229526928, 0.03858662070706487, 0.02070120266372604, 0.06204893333571298, 0.040645014361611435, 0.04401753357212458, 0.05494319587679846, 0.030426086990961006, 0.0649708883304681, 0.017452052993966, 0.013963605227347995, 0.009518385765009692, 0.06276917790195771, 0.04303805470200522, 0.057518456796450276, 0.025377040063696246, 0.03186690182025943, 0.026983476809359024, 0.011819188599474728, 0.007120596527654145, 0.06261711141892842, 0.03759530479354518, 0.059496087820402214, 0.04943906908322658, 0.03544577370796885, 0.027221629030204246, 0.03637080353551677, 0.01820033971619393, 0.011379658211288708, 0.03420380695856043, 0.044106978058282814, 0.011086056956888309, 0.04696861807523029, 0.0350094315862017, 0.009716385676126395, 0.032799086799579005, 0.02987920812198094, 0.03934245104236262, 0.015611095886145319, 0.07652034823383604, 0.10650591671999012, 0.17234249359795026, 0.11015684902667999, 0.19183014146983624, 0.09636502766183444, 0.07033586794776575, 0.11441343490566526, 0.11999021922903401, 0.16319045397852147, 0.15922854228743485, 0.11938033838357244, 0.1367881814283984, 0.10934602003544569, 0.09996103255876473, 0.08322443028113671, 0.07378051882343632, 0.08363353261458022, 0.08854026360703365, 0.1223962636930602, 0.18920251461012022, 0.08050953024732214, 0.09261539565133196, 0.09362578179155077, 0.09063802247068711, 0.24863935953804425, 0.07211184514952557, 0.14179690980485507, 0.13998741975852422, 0.07640697181757007, 0.2421179594738143, 0.18211512134543487, 0.06287165704582419, 0.1788263028221471, 0.11804202305419104, 0.10917584345276866, 0.1735234430858067, 0.11724751283015523, 0.10570193414709397, 0.1298319896949189, 0.22378003490822657, 0.1945935838988849, 0.20550910889038018, 0.1278321027223553, 0.09428320080041885, 0.09270427016807453, 0.2086151029382433, 0.09076457603701524, 0.09445198638630764, 0.16048684476741723, 0.06323024244712931, 0.14692506034459385, 0.09584327494459492, 0.12152723675327641, 0.06420214208109037, 0.15253522859088012, 0.06331235196973596, 0.06381708024335758, 0.07914304892931666, 0.10617652868053742, 0.16707604405071053, 0.15358047107500689, 0.18476014584302902, 0.09779555590025016, 0.11270869709551334, 0.11300504047955785, 0.08932951518467494, 0.12514088356069156, 0.08138796846781458, 0.19543446520609514, 0.08665252490235226, 0.2084769939205476, 0.1309142666203635, 0.11674581760806696, 0.1245427413710526, 0.1018000320930566, 0.1196139037076916, 0.09589915230338063, 0.0696898822539619, 0.09416686597147159, 0.17908231408468314, 0.14075822196900845, 0.08196488608207021, 0.08448811354381697, 0.18196593863623484, 0.20935488252767495, 0.11927281772451741, 0.10033428110182285, 0.10879551778946604, 0.12207148969173431, 0.12031918657677514, 0.14935950828450067, 0.13840385473200253, 0.12789406654025826, 0.1270493311541421, 0.12912853887038572, 0.10574156737753324, 0.05545617513624685, 0.23921152257493564, 0.1872967133032424, 0.10673902742564678, 0.1270419486931392, 0.10564847915832486, 0.13445626012980938, 0.07157115451991558, 0.20377670042216778, 0.1411862147173711, 0.09859263098665647, 0.07970272496874843, 0.09091979092253105, 0.07923486150268998, 0.13366446404584817, 0.11202448952410902, 0.12736175581812859, 0.08455864047365529, 0.130794030215059, 0.14498445019125938, 0.12315920846802847, 0.06656652449497155, 0.11345926539174148, 0.2297453890953745, 0.12385204700487, 0.1431627193731921, 0.11394831272108213, 0.1308468473809106, 0.13104548172226974, 0.13556320858853205, 0.13786099957568304, 0.1555620783141681, 0.16962099820375443, 0.25251634578619686, 0.14569811975317343, 0.08423561030732733, 0.12395176451121058, 0.14109639025160245, 0.09507667965122632, 0.0852669021114707, 0.12677821570209094, 0.14245056972971984, 0.14831976193402494, 0.20353188498743943, 0.1571448426693678, 0.12058339454233646, 0.13260134894933018, 0.19727592782250472, 0.09123790170997381, 0.1268857635025467, 0.15864596569112369, 0.17549835996968405, 0.09324006856020008, 0.12510175923151629, 0.15104687559817517, 0.12745740211435727, 0.18450129830411502, 0.22010651417076588, 0.11459370808941977, 0.1164404089961733, 0.1468494851142168, 0.10707492261592831, 0.15047759828822954, 0.24881374303783688, 0.1709125353289502, 0.20578809534864767, 0.0948059441787856, 0.18049895949661732, 0.12178385869732924, 0.09086719767323562, 0.13581708925110952, 0.10416804466928754, 0.10452717289860759, 0.07344826058085475, 0.11049798929265567, 0.11244596833629267, 0.134573117430721, 0.0684795861265489, 0.17780152495418275, 0.15616657159158162], [0.023038235027343035, 0.02132997053143169, 0.0716415253866996, 0.056127728029553375, 0.012857865409127303, 0.02843856462277472, 0.020618083820279156, 0.00411248200439981, 0.03439402407301324, 0.06230755017272063, 0.024308740959635804, 0.0342637148153569, 0.010239650678288723, 0.025073120836168528, 0.022909065708518028, 0.04351446431662355, 0.0023010687353754683, 0.019438752638442174, 0.04841349393661533, 0.05976422450372151, 0.019783621454345326, 0.03976751930479493, 0.0419163718553526, 0.037708684602486234, 0.012124580247992916, 0.045643099916300604, 0.02423993411606976, 0.007990727783180773, 0.09603741738413062, 0.04789169032924941, 0.03700023976021579, 0.04822744641985212, 0.033477743954530785, 0.002278765077270301, 0.03741909603455237, 0.014409281446465423, 0.045293064056230445, 0.0730339606691684, 0.07814913761935063, 0.053617433445262055, 0.013279335739623224, 0.05286872772766011, 0.014678685293932046, 0.04129453861553754, 0.11380809345947844, 0.01375381407394473, 0.012852127547375858, 0.013875676418787666, 0.0387331469516669, 0.03411214705556631, 0.06201150534408433, 0.030438785773835013, 0.02662193469171013, 0.03501616604626179, 0.027347498972501074, 0.023225651488506367, 0.05679559987038374, 0.03564943599381617, 0.020876773599801317, 0.03521971298115594, 0.07186922816825764, 0.038845417355852466, 0.016661374796448008, 0.02300195036722081, 0.014626270160079002, 0.04980663489550352, 0.03434145457244345, 0.044392872003040144, 0.09242708182760648, 0.046997398138046265, 0.005288920506635415, 0.0534163495924856, 0.014819406671449542, 0.01758052172538425, 0.04529891981344138, 0.012864453135989606, 0.012769945930423481, 0.02650403244686978, 0.02438596842278327, 0.031168434835438217, 0.08022404342357602, 0.06344106327742338, 0.057584417185613086, 0.020521182234265974, 0.043542687980724235, 0.05642465834638902, 0.03177624275641782, 0.05951545999518462, 0.056111232843250036, 0.0472170161748571, 0.044122957557971985, 0.036593719252518246, 0.05192085841138448, 0.015860813736383404, 0.019591691038970436, 0.016412995356534208, 0.02872068082381572, 0.06741299693073545, 0.04210732178762555, 0.012956051122663277, 0.04900159380797829, 0.035527510036315234, 0.06935163254716567, 0.026971741546211497, 0.005395198598437543, 0.033700157555618455, 0.025389241819669093, 0.04661466367542744, 0.031062311958521605, 0.021290230431727, 0.019023757228361707, 0.02178430061654321, 0.04328943496303899, 0.031520109357578416, 0.07597412754382406, 0.029735491012356112, 0.09141990515802588, 0.01628162249523614, 0.05206430410700185, 0.009441312668578965, 0.10641113894858531, 0.031988152635416815, 0.10024606476404838, 0.025306516526533023, 0.030156047016914402, 0.009253461945003696, 0.0199085906414049, 0.03173921510045018, 0.03537523999278035, 0.04559047952560442, 0.010325177472883036, 0.0361530107579061, 0.02538987116089889, 0.06750647191490446, 0.09043118464095251, 0.02723649742880038, 0.014266880694776773, 0.05326626443171075, 0.027019878516771963, 0.006095160904806107, 0.02635272083404873, 0.05828132014721632, 0.10097002091684512, 0.026298549990834932, 0.027057325168113624, 0.06701934483966657, 0.05514325853437185, 0.02770898850368602, 0.03551804447280509, 0.04272763850167394, 0.021705000228913765, 0.03239227452182344, 0.040937225467392375, 0.014790160115808249, 0.014792570611461997, 0.04302214305581791, 0.04714024672284722, 0.012675204630275922, 0.029738035518676043, 0.00349060635614608, 0.047190668660082986, 0.03144429324726973, 0.06715367441730839, 0.017911073452393924, 0.015544843726924487, 0.13138329716665403, 0.04259213845112494, 0.028719093051872084, 0.011220044722514493, 0.023482834920287132, 0.02453101546104465, 0.01227626675141177, 0.033795678322868686, 0.024450237563412105, 0.03527041990309954, 0.07322682067751884, 0.043941466403859, 0.04597152443602681, 0.014493803161063364, 0.0647770105195897, 0.0044394981398779365, 0.039827712146299224, 0.034523871926856894, 0.025192213909966604, 0.05389384147045868, 0.002087405479479847, 0.03225096621151481, 0.04395188530907035, 0.01157658179623208, 0.02571533217893115, 0.032272390954728634, 0.04564404647265162, 0.02803970647177526, 0.011482290873703147, 0.03609631237174783, 0.03779458035049694, 0.006951934350321868, 0.030973722426486865, 0.014627060653375728, 0.025208208676693693, 0.024865110837189213, 0.02793540885405881, 0.017581983968349438, 0.04117042438260146, 0.04231155065021344, 0.03820794727653265, 0.02524806073467646, 0.04470732548673238, 0.012529730114952793, 0.01079422328621149, 0.032513125001319816, 0.04588359647563525, 0.03853085530655725, 0.07049588686121361, 0.03088486148044467, 0.021207177745444433, 0.02736217907762953, 0.060710414445825985, 0.06663001501666647, 0.06899312178471259, 0.1203194579907826, 0.0751309460029006, 0.021449497867641703, 0.06851746873664004, 0.004662957957147488, 0.011075990041717887, 0.030450290335076194, 0.030106405394950082, 0.05492414261347481, 0.03041516596983586, 0.060247701060559065, 0.017593602184206247, 0.01711852419456201, 0.008713568594040615, 0.006950034452269652, 0.04700962194640722, 0.048352992361677546, 0.016495683330244253, 0.058153389154800346, 0.057473293505609035, 0.02420718971240733, 0.04963373399472662, 0.04455533703523023, 0.023430962614449005, 0.0702518585271069, 0.053622990647064786, 0.03424328751862049, 0.03101821057498455, 0.11401292282555785, 0.06856612648282732, 0.021756151591294577, 0.028695110231637955, 0.007102077186573297, 0.0035517834975118084, 0.017896895463179265, 0.06721550931355783, 0.05115908410932336, 0.0770205913909844, 0.06896000249045235, 0.04114630585536361, 0.012318692153452762, 0.025286238507500718, 0.05055126261764339, 0.01418453877392624, 0.02398677439694958, 0.08201846999249288, 0.06882373230265719, 0.04498424241319299, 0.03090336513040321, 0.015014794222744448, 0.015064980369061232, 0.03750018096928086, 0.01892648414442582, 0.040896421764045954, 0.03736682848206588, 0.06849189475178719, 0.014677077165937849, 0.05486418047387685, 0.041350792561258586, 0.039614183961280754, 0.05606553350974407, 0.06952555464314562, 0.05008120069812451, 0.03819289058446884, 0.04500188771635294, 0.04801466801602926, 0.028191311550991874, 0.01256783155258745, 0.036410586043660126, 0.01221625881070005, 0.022532740009150336, 0.015432013531348534, 0.05697844470185893, 0.08839313685894012, 0.011140445779476846, 0.0659024151308196, 0.00977779648798917, 0.006748475200895752, 0.04996341719691243, 0.039957699099821706, 0.07625869155994483, 0.013101019281228738, 0.030283109484506503, 0.04023797477462462, 0.02485458167003734, 0.008818417521459716, 0.008875837699244065, 0.021713229162352424, 0.032780267630836794, 0.05621299613267183, 0.06615179032087326, 0.024904526936422502, 0.019790545904210637, 0.04136752523481846, 0.019084146845021417, 0.024242887439738427, 0.016597964002617767, 0.035455191774027686, 0.06126327799367053, 0.021055170634229268, 0.039425069466233253, 0.01913214471590306, 0.04086086652906878, 0.03053255592073713, 0.01650869593556438, 0.0660204327266131, 0.011937314760871232, 0.032728000078350306, 0.06696282965796334, 0.030649175734392235, 0.016618287822763835, 0.022417920009632195, 0.046992658570941, 0.03069415921345353, 0.043093026216541014, 0.011211295861617794, 0.03158012917265296, 0.05363607619489942, 0.012643492448010614, 0.03470131901225873, 0.016889672992484908, 0.06569026437188898, 0.050164480693638325, 0.04989233726103391, 0.03787140408530831, 0.022298733637269055, 0.028306406357192566, 0.02527963466543172, 0.06590645241418056, 0.008641297829204371, 0.038297096599957774, 0.02143535719785307, 0.13359462922172888, 0.1131599907364164, 0.20642950093107565, 0.12086738858904157, 0.073739318177104, 0.17290711615766796, 0.137058876188738, 0.1117946697132928, 0.12349220631378037, 0.12771164918584482, 0.09046198334544897, 0.10410078827823911, 0.07456417927252394, 0.15136045377169335, 0.10420964565128088, 0.16829853345240864, 0.07862132335347788, 0.083710553124547, 0.15934554886605057, 0.16870508449418203, 0.08456813996391636, 0.18805771746805736, 0.12725825208638394, 0.2180816706802164, 0.09575757597173963, 0.21276378817856312, 0.06258655020168849, 0.131236625037023, 0.1101599024342639, 0.13822753062205656, 0.10521843723420586, 0.1285597908177546, 0.15042683029813425, 0.1301386739526476, 0.12388881003218037, 0.11529500117259366, 0.12940624968281814, 0.20194400447819913, 0.1543306458209242, 0.1232071944645473, 0.11186784971505404, 0.1203490285468953, 0.17249040066131524, 0.11595045242990766, 0.25615090504288673, 0.17951555869409017, 0.10913527384400368, 0.1526258130158697, 0.12943341822496482, 0.08040234207042626, 0.2354932049555438, 0.1333435576941286, 0.12689241314572947, 0.19838907809129783, 0.1861686488347394, 0.08124514363173928, 0.18898602122707026, 0.12392671299832207, 0.10776926750051123, 0.09790173984531846, 0.16510954100106442, 0.09266596008092165, 0.13309023343026638, 0.09771574661135674, 0.05953743774443865, 0.13007960069392407, 0.11355110510651555, 0.12067321900810514, 0.1964200780327831, 0.16964079785559857, 0.16149159228163107, 0.12110495726977076, 0.19477490202656814, 0.21621763998908655, 0.15848714778465883, 0.10741855989077262, 0.10335621144622564, 0.10237412700163466, 0.08999499518956457, 0.14584395049938134, 0.14793142277215207, 0.1450730940060956, 0.1495718490332365, 0.056812244334391186, 0.09682510154587881, 0.09716343946222748, 0.06520308979919978, 0.1372076789183276, 0.10000308815922056, 0.1157332533704383, 0.3082737667219979, 0.11581165130649294, 0.08134103420057467, 0.14444312852408203, 0.0681315315887332, 0.13014053313859872, 0.18513149448803493, 0.17880221482898506, 0.09660980238446168, 0.1250637884118727, 0.2542255754981722, 0.17683957942894526, 0.14161362392561777, 0.13557904559586728, 0.14657258854380675, 0.104601268922644, 0.17013045586645603, 0.13867049185293062, 0.16990427300333977, 0.10318144796682255, 0.10477895688797746, 0.07067846027868134, 0.13695092126727104, 0.05832983540104968, 0.15801353034164223, 0.09300335483359438, 0.12223105398671967, 0.12309018788593155, 0.09184126861925636, 0.11694498120674066, 0.201664339484913, 0.13566927718264715, 0.12350276431867055, 0.0926246712250369, 0.1891417857259512, 0.08423246190484081, 0.1111489554334964, 0.12237646404121603, 0.11475552512066704, 0.11002266194139208, 0.09599960262754134, 0.09109253915292875, 0.1277711431362799, 0.1539389682667596, 0.12438864606831755, 0.08783580176532269, 0.24326158953564508, 0.15898338758519717, 0.1162874943443707, 0.13276145607233047, 0.11333915790809052, 0.14075208801243985, 0.16011382692626544, 0.08906604682228395, 0.08997042543653931, 0.1029437639351402, 0.12013469290520463, 0.16260122773902758, 0.08432679184313331, 0.17579842172563076, 0.05434022930317691, 0.18850240217787878, 0.18835186239864143, 0.08550448436290026, 0.09107307876859393, 0.1057594535606248, 0.15583296306431293, 0.10788996530962841, 0.07799517802361931, 0.1487271815006222, 0.09593669564596244, 0.15266835716153893, 0.14646778202482633, 0.09906985823597227, 0.0933833344440375, 0.17843907645770482, 0.15445457345673017, 0.13534184332404817, 0.19884421224040644, 0.10109945825700249, 0.17169118140425, 0.07793320063501596, 0.12003705171602112, 0.0948636739381722, 0.11761065120143549, 0.1583983682628189]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.03903216037100979, 0.060342702748520036, 0.008469534322752484, 0.056774595818881474, 0.023606794786506465, 0.010246139169404549, 0.03326033115653055, 0.01641264251832451, 0.0715888642839023, 0.03476151524643813, 0.02706690608257694, 0.05050538686503257, 0.04129806699763451, 0.059101546848458905, 0.04812676539378507, 0.016388076157974343, 0.025059692628149475, 0.042443987115153244, 0.025377688064639057, 0.04085153667256236, 0.03445587593263813, 0.010513079086584705, 0.01582524153803076, 0.02843859006783792, 0.027180061974961842, 0.05504369369841047, 0.026347234878422957, 0.06757069525441953, 0.04107623354398778, 0.034998724303607426, 0.03547105931543878, 0.09312973198081766, 0.06622174728129591, 0.023677650805828825, 0.02902325994468161, 0.018383265971871357, 0.03594952828383871, 0.03344051952340773, 0.06547421882195131, 0.02349665158960436, 0.03330700418778828, 0.0626538133780871, 0.022405407823888317, 0.042900172993540764, 0.0533011343463191, 0.03028097888454795, 0.019081296997943094, 0.027019881909447055, 0.049176835654569526, 0.03892041243878858, 0.025382865286831344, 0.08317098886306797, 0.022866538526224237, 0.022616593366754905, 0.03318828430825046, 0.011504930194600351, 0.05667135671579412, 0.031706061879439015, 0.027574530004390647, 0.027240137769175426, 0.05014199743579541, 0.020153743647305027, 0.0479465702415577, 0.03157098591327667, 0.03351707523688674, 0.06529001692043883, 0.03377006023323961, 0.028005991763036166, 0.03906877412061606, 0.029972998624933616, 0.02806461718864739, 0.026859930849501064, 0.08044899813830853, 0.039348914088415246, 0.013011288114025124, 0.017133506247773767, 0.04106596391648054, 0.03570664328123842, 0.041635356577379365, 0.04847796154873712, 0.045194004728857956, 0.04055873863399029, 0.016503517017034546, 0.03203542617016605, 0.013283970981969364, 0.054049840063921044, 0.039205485356173346, 0.05445924773812294, 0.005080564030712205, 0.04302484362519213, 0.01430208987689444, 0.031760446461183686, 0.030477655652378286, 0.0351561749620097, 0.029738415498286486, 0.037709994175072224, 0.13371863828173705, 0.08809543640485831, 0.0054594707076570815, 0.049329282117209265, 0.07674056677413837, 0.02236315205560199, 0.05970038114381688, 0.02426848347697939, 0.023705838846841028, 0.028715038805135658, 0.0416515023181481, 0.021356952476448247, 0.09012681418763739, 0.02902421328638281, 0.027737717676375593, 0.07182877391044583, 0.06102853201861892, 0.022641660146681324, 0.04735547124541231, 0.14374845794269017, 0.058257774982069216, 0.008746390181061412, 0.04289417135130082, 0.02987365092017821, 0.009956023040493684, 0.05346572658579264, 0.026163687763203467, 0.028218088239165287, 0.05364998955545681, 0.02078200431008424, 0.04945687044944082, 0.046843564071293385, 0.07528707012534142, 0.029599970605756556, 0.031780999286898544, 0.03952185570129326, 0.02580194378138653, 0.0653486694874508, 0.016318755324131677, 0.01994761997567756, 0.04441843920254281, 0.0254874105698296, 0.023868137637951543, 0.03566968347877264, 0.03953832035352077, 0.033517397541020594, 0.08950343728065491, 0.08900148421525955, 0.029096277098038366, 0.018703130772337317, 0.05620103356029306, 0.03114327136427164, 0.008904482903225082, 0.033792367071977684, 0.042125248682818243, 0.06365370258156743, 0.038956747989037206, 0.018819055087598305, 0.06862217347536768, 0.005979219626169652, 0.021007011611280695, 0.021614232599469166, 0.009725284662895968, 0.028455107306529368, 0.016400079442454234, 0.00861690703979028, 0.03087653246309076, 0.08590331367616143, 0.01801507081836462, 0.01687781898570912, 0.025045867477144514, 0.07562605943530798, 0.005954044704724635, 0.030773116940898553, 0.004953003263965781, 0.037580709505294047, 0.0462272642845554, 0.023795519123918245, 0.033839620250676355, 0.023939460150099227, 0.07591488465134587, 0.03968476517392056, 0.021304135310596654, 0.025908217632344792, 0.0449636522680521, 0.020240567291953733, 0.020396021361063634, 0.08420475053467921, 0.07224605937621423, 0.014212551244002367, 0.0582514578210456, 0.06707759707101754, 0.036416143245462856, 0.013329637236893177, 0.009015378425829113, 0.023571541499612585, 0.034108750987797976, 0.025030646240338683, 0.029656102415174246, 0.021187909047252367, 0.033681603015533516, 0.021148172340222766, 0.044594447793705125, 0.09048384574374982, 0.020893910001697283, 0.07427502835967711, 0.032076277370963774, 0.02230532730131277, 0.03091427936617817, 0.011373793972390038, 0.0013066902964575483, 0.02193781068282468, 0.06141747507665839, 0.0305045561731926, 0.03569062985479832, 0.021235306414642503, 0.03195467711027179, 0.02240120429944779, 0.01879855993736003, 0.023674342947612916, 0.016567085570256625, 0.03207104925864509, 0.03075081010216049, 0.06612710521689483, 0.04478176077827811, 0.022161493144397224, 0.011496445962360926, 0.06380501589072601, 0.052629187902701755, 0.051994866225868464, 0.03872875343742115, 0.036411987218473635, 0.024118067530382956, 0.04145455074363521, 0.025275806031588997, 0.015622600447386503, 0.010627476698053735, 0.04189847210156066, 0.027939693802701573, 0.011163219111040235, 0.06548454612493515, 0.12231231534055301, 0.019738961975755434, 0.02412780111522547, 0.01575582062027284, 0.03928226498620851, 0.05521523074379989, 0.05158024740272334, 0.03385569474526814, 0.01849993328297777, 0.00657378975301981, 0.019306467147544026, 0.01412412540854088, 0.05016579365889941, 0.04367141964446221, 0.03514429381383317, 0.06503882325653519, 0.006020100936958832, 0.0057138606955829474, 0.00947843786395554, 0.006317205128393003, 0.06103719012545688, 0.04912812362558075, 0.02391558250279299, 0.025335135437282066, 0.042381263338029385, 0.05247096710705331, 0.07814075092652015, 0.03378283026229058, 0.04311044081779463, 0.0923072796847139, 0.01650995122534888, 0.052973778519247255, 0.02560299731391881, 0.024380099094871963, 0.0634416536028896, 0.11235868159149374, 0.02355131267436913, 0.03235671589417117, 0.05256933093603168, 0.04833909596449562, 0.06276298966258764, 0.05046442709863186, 0.037419974737401517, 0.048346529315624914, 0.006043965437649084, 0.012311699001916816, 0.02987292149503316, 0.20255988357322557, 0.01164926222658583, 0.03604203635560615, 0.06938416830130986, 0.031030834719006504, 0.030614251536982398, 0.01744809204579464, 0.13895791928683007, 0.026104714588395188, 0.018083138058760335, 0.0503910571070654, 0.027218346617051532, 0.010798471763597002, 0.06910871701048953, 0.028592498773442845, 0.005979369327958141, 0.013630514931199806, 0.07175030133553914, 0.019185267222513045, 0.03619493743670838, 0.06159700865724257, 0.055595064469213994, 0.02593605622782239, 0.026253848103806376, 0.009215504696060504, 0.03815300629607268, 0.055092381978673596, 0.0198793729235019, 0.03375714092648455, 0.02629065014688032, 0.05393016684268202, 0.07353079758052315, 0.026575460131945353, 0.015717915957793593, 0.08321061530815703, 0.03607581043615937, 0.03562713933310338, 0.014360006233411176, 0.010479581509051579, 0.008926283385205482, 0.031166779209992716, 0.0618555915674993, 0.020022323288555657, 0.03605254686304501, 0.038696933537721634, 0.04547129484957882, 0.012090197182260454, 0.02396499681552606, 0.03944258584773966, 0.01791924810303109, 0.04028083443907755, 0.018758093805185387, 0.02620718694691147, 0.022094508167356253, 0.024193544373182312, 0.017018693033605814, 0.06808690434055668, 0.049755269794591835, 0.03194924204477242, 0.06644652557692357, 0.04207475549940552, 0.03083974907972983, 0.018200628093576858, 0.05950997064688376, 0.003488850434743134, 0.03662156293700848, 0.020284834916570356, 0.013598417680311416, 0.1772726611899478, 0.11019866713987929, 0.08041862691087381, 0.15038557536900043, 0.17894511430391244, 0.1421580532831805, 0.1880077501492841, 0.146128365237798, 0.22154533410710947, 0.14536797175449984, 0.12184795311519078, 0.16693797574511596, 0.099290782452694, 0.09415349204625402, 0.16631054798407213, 0.10899662878364325, 0.2028546120439257, 0.0742825600983841, 0.11891054787806102, 0.08700714765914849, 0.07918680086731911, 0.13797550914543016, 0.0915577495470643, 0.1743669163967882, 0.05757761826472623, 0.12574205201651367, 0.10763638320245913, 0.12687384842761926, 0.21904296481183597, 0.10407514643988439, 0.1064303143482123, 0.17192942861999783, 0.15844285301864147, 0.1467214591268982, 0.2219594983117921, 0.06453465138162885, 0.1454968255545412, 0.08424668399883167, 0.1399937979876995, 0.12726133263536862, 0.1950937592025314, 0.10113771406135388, 0.1326131418879543, 0.15161392731325968, 0.14369053819349834, 0.15115911886096, 0.11066786731992449, 0.1334058064967394, 0.08580692099141222, 0.10624726595623152, 0.09730630501040391, 0.1822497426931347, 0.1413656058056014, 0.056963510146098476, 0.12313551402517728, 0.0980230076238513, 0.08344233501702547, 0.08927868612642799, 0.13184702156909875, 0.1330670818154301, 0.1481181691799845, 0.25297964949692997, 0.1027424018830061, 0.15944924258760043, 0.08690372535160609, 0.19281154737940856, 0.11337693195257868, 0.12813500075467996, 0.09233789518475533, 0.12704334647527762, 0.09450549565787826, 0.15225318872502872, 0.21772136858531407, 0.15984017375324452, 0.18088501878082752, 0.08809786556022507, 0.09725401031651668, 0.13216891858194554, 0.09872556956751005, 0.07521873486361333, 0.0824340387646641, 0.19425936469009944, 0.2080453099416835, 0.09566421633852379, 0.15098212978669576, 0.1369769905826875, 0.09723108261823654, 0.167908674372094, 0.09580669512173959, 0.20833573650036538, 0.109849499804633, 0.1267584160502468, 0.07741862681827374, 0.15867364991988453, 0.11927238346210547, 0.11757699586451054, 0.21574461965688638, 0.15049922998462403, 0.06830145711345331, 0.1306590831705502, 0.14479565460767063, 0.11563664355448314, 0.16235253108399256, 0.11591018816190106, 0.12617651798895427, 0.07629352076245205, 0.1135896323248744, 0.07269912399351597, 0.3075687416962215, 0.1051152999113713, 0.11592659513865199, 0.12683378772011825, 0.1598760818264314, 0.0636630460087742, 0.08298703801951238, 0.2731223686465195, 0.18756025630448545, 0.10723213917974915, 0.09419243995632444, 0.21414813532360963, 0.11921067748750959, 0.14935203082859516, 0.11526948825589248, 0.09299477136560849, 0.13083448447287083, 0.14708286044853075, 0.10200902087880032, 0.1356036357049431, 0.2327543662062713, 0.11558621483189718, 0.13722116819449834, 0.07292869274637528, 0.07368789879339081, 0.12173286000532763, 0.12047989081059184, 0.11476957079555307, 0.11855686828494072, 0.07334702315607242, 0.11853750289550849, 0.13331280648708344, 0.08110119242753301, 0.19111259068761552, 0.17387731266873224, 0.11933733283409051, 0.08283309877983161, 0.13068270975989954, 0.17105951958468982, 0.12309131425406251, 0.07232695432113749, 0.10863214012767587, 0.10578052207295384, 0.1159952628825392, 0.11682131141424179, 0.15378346161118575, 0.14162291985537323, 0.08808175713888236, 0.16889238730072975, 0.11021580693445035, 0.07564526876168591, 0.10861730056681804, 0.08099875399576766, 0.08909156652433531, 0.12906671075948647, 0.1408604093428169, 0.13344548722462996, 0.15048009529709816, 0.12240785307117871, 0.19279763741152628, 0.09318799099751882, 0.15731423215142318, 0.09214062469878367, 0.1542818048702819, 0.14725429910634244, 0.19143824678446564, 0.1523719323532922, 0.09898250363767147], [0.04658561219860401, 0.006179183472080955, 0.028726882633886168, 0.05675109475851059, 0.05139572998242719, 0.02851132902183703, 0.0365952459563102, 0.04298802970775536, 0.0053962435423662615, 0.05947482931826796, 0.021343191786270057, 0.06338669226637908, 0.028055567227836167, 0.008780263497361114, 0.04040479600163443, 0.059340119761015685, 0.0030779487112470505, 0.06056516045438392, 0.018630773494286195, 0.030753398713256632, 0.008648918625632567, 0.019117642726216997, 0.07892152760177851, 0.02449430332386068, 0.004763195390946099, 0.03762505855411291, 0.015136391090761338, 0.025377243624201844, 0.014542756069983755, 0.03971775893920234, 0.03500035957300237, 0.04365222388878465, 0.021855309306244766, 0.02693552982860378, 0.04529971709208829, 0.006436391076671758, 0.03685744885089142, 0.052324739417859485, 0.008280668341155564, 0.04669913449989898, 0.04439802208383169, 0.015215347121868814, 0.01494379062205553, 0.04989143480945911, 0.0710754846887929, 0.01240001033459391, 0.024234373521591936, 0.07418246939778328, 0.08695692249706813, 0.014865562319755554, 0.03168504764991147, 0.02252843979346965, 0.012964285145114576, 0.035040460992604494, 0.044292224903724024, 0.05659645662776061, 0.02339391629876835, 0.04322194108473403, 0.03912071936896869, 0.016186159403462495, 0.03231427013607962, 0.027029820751132708, 0.03795981380556311, 0.009524284778828067, 0.015482993563637137, 0.018568400859034488, 0.02959188586100936, 0.04745040847254651, 0.021016667164596062, 0.015091986062803438, 0.05548532160797289, 0.012559577174085592, 0.07236094892557178, 0.04654415710163968, 0.019433064818648354, 0.05310977050768478, 0.0331054317897984, 0.045953865562166483, 0.04675824847072363, 0.024030522942276936, 0.030449978208967617, 0.023425661559615816, 0.0363175249658525, 0.012389558350800403, 0.030362922166075026, 0.06022488871323211, 0.013183696228744728, 0.018832215274284993, 0.04464215898354139, 0.040972960514149497, 0.03836733854508825, 0.07218922528305224, 0.06492659356445074, 0.01692097381289516, 0.058916415353970866, 0.06026486121118069, 0.012690242662626718, 0.04952332277649215, 0.02382378010744495, 0.03332463252757277, 0.031577123262520344, 0.044752692338079214, 0.010099247364061219, 0.031909469714654345, 0.03387597276430045, 0.06564517571989979, 0.03098312352917024, 0.039288412513477464, 0.033386094229561944, 0.05224574776366353, 0.040743697102048566, 0.05380472268110939, 0.0713747525587678, 0.05820757017603942, 0.0191683208104223, 0.02446431546871151, 0.020383463374205997, 0.022981350044054643, 0.0299907796350973, 0.007719451179062682, 0.025310407924864973, 0.013931744615547359, 0.043928004269089015, 0.04738051936562572, 0.052635230257042816, 0.01821178151294589, 0.017108887300959656, 0.030807549200419868, 0.04022797656112483, 0.02440389192530087, 0.06003474284495626, 0.016269700634958487, 0.043869975954294205, 0.017153797837506448, 0.1004711619711348, 0.03623570042795368, 0.014602211004655277, 0.0524713776207396, 0.02755528505492423, 0.03780169818284256, 0.022374147715579187, 0.07984131574630737, 0.025288964521938136, 0.04949014919943043, 0.04708444739558867, 0.10306256863155536, 0.08318694122135639, 0.041652601544878314, 0.03566676577819245, 0.023466638289391994, 0.01986745954491198, 0.024853423071492995, 0.04448076942935586, 0.027288819264088358, 0.0397183323012931, 0.04107164664726172, 0.020137784503666416, 0.03465940590415682, 0.04662185275395002, 0.019208138941654136, 0.0231881098422621, 0.02320506134336548, 0.09485011002314941, 0.01701576685133789, 0.049170474388769696, 0.014883058345211404, 0.024833306204527617, 0.017094909479575496, 0.03778801891686661, 0.047359522099473646, 0.028331846331379244, 0.06675815635493823, 0.01342151511926204, 0.037720375760857544, 0.05079609162307211, 0.03228671143629721, 0.05728315442268338, 0.006606815748714975, 0.029873393076871122, 0.0576842636136072, 0.03164323292938726, 0.051451732870191336, 0.011586889591334122, 0.010587506744611477, 0.005250191848192896, 0.04518417954178793, 0.01581344859940665, 0.014049151529824095, 0.05822589062154293, 0.015769650860290443, 0.04120665815259729, 0.026180598552205732, 0.03586974274367094, 0.03509674886507647, 0.014048059088444071, 0.031331327344690046, 0.03739173750260046, 0.08585172465869359, 0.038538953622004817, 0.04943292834130781, 0.0346799994419728, 0.024774843627320867, 0.032904955225863626, 0.07092575236622777, 0.03915571481255548, 0.018313760237236108, 0.0661675323333059, 0.03650394228420087, 0.02097656235231885, 0.03752326133794018, 0.057508312697921476, 0.04032113263383508, 0.02895979656438742, 0.02573714029443051, 0.0674662347882986, 0.05657312859381948, 0.00886616263804691, 0.01416947614468102, 0.04318738668890936, 0.05111346620001963, 0.05795401521027088, 0.025557806881676828, 0.04973072039761713, 0.008606961412754442, 0.01993858188922916, 0.031499654919441254, 0.015193182775484664, 0.048615677016122, 0.07769329779382263, 0.043504975004387755, 0.06626358575054578, 0.030215639354927198, 0.01554603285954467, 0.05561133913163628, 0.05191108750711594, 0.07378035597503185, 0.04410276096314192, 0.04329178608687861, 0.03857322981847184, 0.01890460817542459, 0.05605324863323143, 0.02224128207724009, 0.06334688940218516, 0.051507949496486356, 0.07602337561547756, 0.06843330325292689, 0.04699532860623939, 0.03740224801003933, 0.06150265157754932, 0.02961954634104456, 0.018116708578807966, 0.025735667873440043, 0.020534696955499903, 0.025532475473093133, 0.0448316670288997, 0.0504638537365411, 0.02323133421928755, 0.019721335332308496, 0.04235006769054702, 0.07379731256514788, 0.017420350141557198, 0.02540813393092581, 0.04289230537999954, 0.05815438660127776, 0.04831035661378077, 0.0536398522422782, 0.007940230358924185, 0.06276199900146041, 0.002804956897827131, 0.04330779951331871, 0.01599918059738619, 0.08327179202543837, 0.017022357122706513, 0.004555886403457927, 0.030158343857952526, 0.029712576884776354, 0.027257046861840144, 0.06404239458164998, 0.01143184264323541, 0.053237165457436016, 0.024343495523290973, 0.021237861098987714, 0.021023683216688887, 0.00979763430742813, 0.03372147712590439, 0.03629696196211236, 0.020158905602459396, 0.03675627588693585, 0.0843422624415585, 0.03760479071310588, 0.023019322560035756, 0.041580357921442816, 0.04074881325608917, 0.022319557876991372, 0.03851158830470272, 0.07324847272996392, 0.05373266226212893, 0.06825558814619269, 0.027880126909751977, 0.01161349325307778, 0.011147671329256679, 0.03379907099796193, 0.027980142971500754, 0.039948827254452875, 0.05112933713410582, 0.03131077791165028, 0.028922066624675478, 0.03784855781123042, 0.03799412053610597, 0.05514050368219614, 0.02434468804858625, 0.03490608391751136, 0.03934509732893535, 0.0333453515943672, 0.020813719036855867, 0.07455784175544977, 0.022860106014247452, 0.05870427816574063, 0.013723703234323432, 0.04038775798731616, 0.0674532340573413, 0.01762799033895135, 0.011082443757914007, 0.027841402916237712, 0.007622400315345398, 0.028927596685077463, 0.008913380193657108, 0.05068116814696363, 0.03312717544447098, 0.024944977801559225, 0.05461897148883768, 0.008914258896506258, 0.034993150138429234, 0.05640795959958008, 0.035890237893909216, 0.007845302461646497, 0.01227439908377294, 0.037833545223942826, 0.022446391339014684, 0.02720785646566323, 0.029322324254150902, 0.027090614096128514, 0.04578590778900044, 0.03183999451409493, 0.054517303194318495, 0.006367524861291583, 0.0492246927294348, 0.014841574410508786, 0.027324391462441002, 0.010487951238506606, 0.05347563319706491, 0.05661205954051443, 0.19891847111284733, 0.10458081787718193, 0.12285519763827324, 0.09127578432006495, 0.16356789586799486, 0.09114391103919063, 0.10817539106522288, 0.09525640322161572, 0.19010032500539506, 0.17651290552956717, 0.07955416651176554, 0.1262096847806658, 0.2253705888454403, 0.12588052744311945, 0.13948647092495645, 0.08862131461501122, 0.10040871639336858, 0.11131128815135785, 0.09197530642684017, 0.08548021995063339, 0.16201148581291946, 0.13941584900021553, 0.18899661994406156, 0.11316689143755607, 0.12239653510706765, 0.13684724111642155, 0.05350730042638523, 0.17357970720955304, 0.08640889011855636, 0.1433016290622098, 0.1033352447141494, 0.1334368155470916, 0.07942966212119375, 0.1163144050432103, 0.08201552515051194, 0.09219921619764396, 0.13350255201969827, 0.08761531859636307, 0.2136993794036763, 0.13698130606540612, 0.07545391510107688, 0.08384141538824354, 0.08744628195251737, 0.13636088078575476, 0.1318538747727871, 0.06291711889207363, 0.10640857408621482, 0.10495833440550736, 0.1690850369632244, 0.12656035167830332, 0.1977317269359316, 0.11775931822402136, 0.14944606221147946, 0.123501325824431, 0.1754535630877529, 0.10624145091112171, 0.1194955264883382, 0.20928814182324068, 0.1272314228117466, 0.09062509637858186, 0.12629782647958823, 0.19448041782847472, 0.14255804967667374, 0.15659417078963347, 0.07966125290840864, 0.08481105550059251, 0.1802952361426183, 0.1380726346479995, 0.11978809721767902, 0.17800820672086307, 0.11059890780597925, 0.0892151277512312, 0.20522582052009447, 0.1997872944921255, 0.11206790219460215, 0.1369115798068898, 0.09973522288990871, 0.08197928459516593, 0.19405850475387915, 0.10577126006994929, 0.12122941416289125, 0.10357183630445174, 0.11474253796041012, 0.1292915636939662, 0.09873971023729869, 0.1592939802046333, 0.14169390818902425, 0.10214335724179234, 0.12113489423479352, 0.11920957826077938, 0.09745219003941331, 0.18922950673316205, 0.16857711278966495, 0.1156422346830368, 0.1809618289449385, 0.22278801671096257, 0.09123988981757845, 0.12812651906694683, 0.10773530682282788, 0.10277912419821535, 0.1092497291309493, 0.13880964581455502, 0.09016124305448361, 0.1311874176774706, 0.11827866892729487, 0.11873179461274828, 0.10137036336319787, 0.0777123374864459, 0.0964297599026135, 0.09204444235989026, 0.10745801670210701, 0.2623726369014808, 0.16198088388357842, 0.11330225238842623, 0.13114730268716812, 0.11260070146194526, 0.1512404480682952, 0.09617302939295769, 0.08369080097015415, 0.13664095290005207, 0.0789928212761879, 0.14424088437642368, 0.09726779814809561, 0.09512870293110609, 0.1391431593469211, 0.12914700859359332, 0.1361150611191988, 0.16228820596422466, 0.1382195239088365, 0.1163975934364966, 0.18267792543130262, 0.1073478836832302, 0.14301777072250843, 0.13321455461638315, 0.19958927083228314, 0.07276105388466801, 0.19462684568549904, 0.125826041081122, 0.07636891278837409, 0.17391556847308362, 0.12382960106645312, 0.12995164256010736, 0.08897468208202294, 0.1029985827792968, 0.0978333435154387, 0.15443438025457518, 0.15029408170708589, 0.15751680199589047, 0.3179066298263413, 0.19549211354127952, 0.06328445060976914, 0.13393415457436017, 0.08748112472572497, 0.10494171708290066, 0.11433794109949044, 0.07381931067045246, 0.09563683066517115, 0.12926816780652317, 0.09634374201829944, 0.05318542376958898, 0.1350689229688474, 0.09087283629924059, 0.2122135777026415, 0.1166043294859784, 0.16433098992066725, 0.07256900811833994, 0.14084610582462379, 0.0863935077296836, 0.10458353880260672, 0.1437293096844639, 0.16880803182721138, 0.09783134862248387, 0.1714024647538151, 0.0950129245008741, 0.15550812120948518, 0.152230457801904], [0.06852392160466739, 0.1663746695433344, 0.02711000493062394, 0.027759288304618428, 0.0639609025259103, 0.013063458975271454, 0.02937874783362661, 0.03589198172890714, 0.011009789620792227, 0.026995624282530377, 0.02023662330715784, 0.012781919528996306, 0.02755379058154566, 0.016680942050048282, 0.006140674065266336, 0.057566978835633824, 0.03238062746822834, 0.04166564977328692, 0.01970842111456607, 0.04507927463522979, 0.03292832736458097, 0.0039291257271543145, 0.03958527158413615, 0.040166134879525216, 0.037435991556516716, 0.047235635175768814, 0.02981288471658315, 0.014010404635752951, 0.029054893247251, 0.07741693726607732, 0.057230710451092036, 0.06610237940081529, 0.022031974380037615, 0.041772067812936645, 0.01644228262427662, 0.020326344296336174, 0.02212551382503339, 0.04440922469698957, 0.05169867551220315, 0.04233816618631993, 0.028898161835968494, 0.05392957990989089, 0.03782761482787984, 0.0327062157115766, 0.04304101650736161, 0.02982449105807713, 0.021902910234140496, 0.016298606226752912, 0.014263762826366084, 0.011452506579059576, 0.05733729473182133, 0.02379526976229889, 0.005444658712284374, 0.03181969953168716, 0.04861545988491603, 0.02380438588027443, 0.020449074317834208, 0.01850428099610976, 0.04786043700629047, 0.018009330412106853, 0.043905911168881824, 0.0029700001510458863, 0.028182782365807464, 0.020253568022911037, 0.019898281998134086, 0.014112188281225306, 0.03268400047506605, 0.006654662645554968, 0.03509441131193723, 0.06715262947337967, 0.015592483670583792, 0.0148011031893215, 0.028063115929918628, 0.020927032688632607, 0.04367929743602872, 0.05190512318430202, 0.012631456933117338, 0.03498702635988593, 0.02472675415421171, 0.05970543622970581, 0.02722885033914021, 0.013402311730065515, 0.023857978272384832, 0.09544249145048005, 0.0194715224871678, 0.015386967287798013, 0.016408410156145692, 0.023899105976202657, 0.06105902538235698, 0.006274711448765759, 0.015251010922448975, 0.019325956369617155, 0.04139035115284579, 0.06223445838051183, 0.05640500797224896, 0.02680913741434259, 0.016282389239807214, 0.05488407512062362, 0.02081344592651086, 0.08852002290742737, 0.03893663960375956, 0.07010769019169466, 0.02324121877817171, 0.028866185873214687, 0.049737817873912196, 0.0323581577810858, 0.0675644798736487, 0.03371706325560808, 0.015923391628478254, 0.03596949417676244, 0.06930254053856645, 0.07348526109542165, 0.05767343419470957, 0.039884169652525864, 0.035187390965542624, 0.03714167020682778, 0.053728801397872825, 0.08030905707606248, 0.05518003513238259, 0.04626981521557484, 0.016320092038118413, 0.0065119056629815274, 0.01723477759930704, 0.0908244838938117, 0.038524955444570096, 0.029825709028435603, 0.04991116321512631, 0.062024587499243874, 0.06326319889298507, 0.06236696269895349, 0.007190457645005414, 0.03342508624440857, 0.024548548805926527, 0.027852676775572554, 0.02306325430981815, 0.020022553990461996, 0.025369431989799653, 0.04971237959606307, 0.058336064352520874, 0.03543971778292741, 0.029225168217505728, 0.030360934058470384, 0.054947752239448686, 0.03307382223595466, 0.011338343062171978, 0.019858621626294086, 0.016170076427182982, 0.03869552897023303, 0.019019999840695943, 0.04949763683336122, 0.02541276323609054, 0.006667472114453891, 0.025339703674295118, 0.021092663086684685, 0.04740675152944667, 0.016742664988019636, 0.04812783408643944, 0.031071584139551436, 0.044032135645725896, 0.014279555728925126, 0.03639817903084414, 0.009297198615968227, 0.054829120569463284, 0.029907889797219207, 0.06127255356737545, 0.019856153455163752, 0.08129169113401856, 0.04177085662792836, 0.03232058390442814, 0.023461527224364023, 0.023436353575172167, 0.07636814604380301, 0.0024988907430919683, 0.03562575512166534, 0.0318465389843498, 0.0458201161319656, 0.09712362981268338, 0.09478965933833804, 0.04557237960398197, 0.026637576620227525, 0.017195693982232894, 0.013046126646388854, 0.05234634397285325, 0.035584605365459404, 0.030780814920685122, 0.042827773307050974, 0.03403997467830777, 0.07518311177513429, 0.06916228735021182, 0.0321269198320806, 0.019484141542177116, 0.059968212486377785, 0.04301553073206118, 0.014103650614353163, 0.09238762501627207, 0.03774904725807054, 0.03603514922516687, 0.030716462659516504, 0.08667576472674098, 0.029513328469225338, 0.03530879784375429, 0.047399986535310745, 0.00546027986066682, 0.051653770064668994, 0.011421024250531835, 0.015634300087445548, 0.03019358018147094, 0.03184747536267553, 0.06486838883055107, 0.015999560576996634, 0.07172199285456113, 0.04615393500509007, 0.005232140696274915, 0.08936326551650252, 0.0517311332348202, 0.018614112066903284, 0.029738754765795808, 0.02022150215426726, 0.03687066671305469, 0.02576638345739671, 0.025019643795011298, 0.07650075214249746, 0.050245467240789106, 0.029002031976623193, 0.059531514133725844, 0.0357102191607867, 0.02713387748891754, 0.011443310733219343, 0.10084382697407689, 0.0622133355853813, 0.08551570054675851, 0.022991049702146223, 0.04695655372259872, 0.011331441512863551, 0.03025190026632377, 0.04166392968701465, 0.029851422112967287, 0.07170618298862662, 0.029889165623379604, 0.04310178949630686, 0.05178624384903482, 0.06253035393144403, 0.027921926363238266, 0.013874025882354804, 0.02756502542511693, 0.021628709144092033, 0.012873940751887858, 0.038739457327340326, 0.021951905551499555, 0.06915252323129348, 0.023256713125322546, 0.027821465861052275, 0.04988739752609815, 0.03088107525504061, 0.038230403392974815, 0.009198734703074609, 0.031251748757702966, 0.010669364361092448, 0.00472767705131056, 0.04172342363744974, 0.05474489062492337, 0.008775070159962135, 0.024125377048871348, 0.011758587788790464, 0.020112139272636602, 0.032305917370000055, 0.04967607118721519, 0.0206590775134308, 0.024283940504704202, 0.030622465203383138, 0.05049078818410635, 0.019177852531096766, 0.04319112541686211, 0.06518745635237012, 0.017290448004912053, 0.059599781541952064, 0.047823585769427676, 0.07281828152814082, 0.04332385365185993, 0.03098109470946448, 0.03570234136922019, 0.016636883074949895, 0.0421113624636616, 0.02008343384867268, 0.02002582622558943, 0.02024188025721482, 0.07911579896296773, 0.08990181876080376, 0.05837911739945412, 0.016669708902814558, 0.015684148662590554, 0.035200822566236765, 0.042229508981108665, 0.03404358109193189, 0.015082876730178083, 0.013032971548714807, 0.028586520879928554, 0.011372622651314097, 0.06463123405618326, 0.018477051385811398, 0.0491571174269276, 0.05147856553750379, 0.02130229987337121, 0.011167170729355087, 0.06560956620212112, 0.04854100084464465, 0.06517102223421846, 0.017436684175793613, 0.03791064715811184, 0.014745185118434685, 0.08009813446551561, 0.039498575164803436, 0.035151700023561716, 0.028813460309590613, 0.0621557008208973, 0.029016345672841583, 0.043925351197166104, 0.033587778585829904, 0.02672556904144585, 0.08038818782993726, 0.022689035461683358, 0.019021012554211274, 0.026005068328231573, 0.04313717849020447, 0.047581206275416274, 0.03757347632199526, 0.02416561926448984, 0.022715851165620343, 0.04881597037560173, 0.01355736970435828, 0.056579496644969494, 0.013763222810147064, 0.03788133444530623, 0.03513803772096123, 0.037876923967685015, 0.06599524550672088, 0.02391136540765209, 0.005464642416752342, 0.035853508793349774, 0.058926498384347985, 0.034449209326079915, 0.1128161499010665, 0.03884228252406631, 0.04958702025136777, 0.02312613245365875, 0.02451768733694085, 0.013197531557774969, 0.00872749213262328, 0.06737319406654153, 0.023304347979969213, 0.07534357852169446, 0.04100328763680799, 0.1875026893935033, 0.3023763746023178, 0.10142785563532795, 0.08613167463668756, 0.20395070394235, 0.15553102855171475, 0.21207252384296485, 0.0842021449602076, 0.08412775038076298, 0.09813090147716658, 0.10119329286473137, 0.13479510694742203, 0.13618507236242294, 0.10109306645712682, 0.10139110617871795, 0.14233403812561715, 0.12221810753856387, 0.19550488357033047, 0.14107927759843214, 0.16978107818535396, 0.1398579552769661, 0.09763225966266223, 0.28355063764112337, 0.13064340901161942, 0.15736666933766433, 0.13470334187150002, 0.09825560264289379, 0.15301845408976078, 0.09323101011770112, 0.10662321506866387, 0.10065467176692826, 0.14597497561148234, 0.17797569132276944, 0.13477362452873162, 0.17991508011307034, 0.08243333308824471, 0.14341345163328306, 0.1326395369001797, 0.13239225159798348, 0.10691009967454843, 0.13707370896424564, 0.11828097594635827, 0.08810606226325035, 0.09969680423715285, 0.13275433145463467, 0.16199210685278687, 0.17919630796781608, 0.18502877785691194, 0.09725185257515737, 0.20152738397674902, 0.15578412211367063, 0.06922727064894778, 0.21556038382862294, 0.08544054600809302, 0.14942991307803563, 0.14927337504923344, 0.12378860398062638, 0.14237491307514055, 0.1033361471657242, 0.11045727040618658, 0.08540446151580129, 0.22542713795389446, 0.09167861020458595, 0.09291078908635036, 0.19994675022150787, 0.1610080546566418, 0.10869527102581092, 0.11858228620673929, 0.18523434682616166, 0.1627097526299102, 0.10699300986847707, 0.07258624290781361, 0.07433182174073798, 0.15880432219377585, 0.07877498439380101, 0.11138513990278755, 0.13518021628260612, 0.11339219899049827, 0.21861790333475384, 0.17769895760076387, 0.14622000817741665, 0.09056299006832497, 0.18609980467174733, 0.16365060928676808, 0.09206868641610656, 0.0713411650753447, 0.09213097593081848, 0.08449673093855381, 0.16633143329194613, 0.1777432659374816, 0.21010862636779035, 0.11300523046936307, 0.11484981434685843, 0.19761786875980242, 0.13465074183685438, 0.12800998746284417, 0.2126335094549826, 0.1684805572565113, 0.1591947376728058, 0.22049028000661305, 0.12543527276388236, 0.13478381612471171, 0.13012789881655148, 0.12639982386359147, 0.1433847224605935, 0.1153459862938949, 0.1691525647682803, 0.1286803800612688, 0.20916304710720265, 0.10813179519027472, 0.2661048780594553, 0.21351917407342366, 0.13387065726731504, 0.12181478632347924, 0.07008324936032295, 0.09698301700076886, 0.11638529838195869, 0.16621925788266317, 0.2276415369872536, 0.11839306993143899, 0.07663154655269214, 0.1335958777261632, 0.13634318459246839, 0.12720075302890368, 0.1523878372141293, 0.17542073556355067, 0.19503892000232423, 0.12976549326309136, 0.11959418548004967, 0.15788178598242147, 0.130903477913567, 0.10315881203860044, 0.12706204690039158, 0.07892725443733589, 0.19186520815959998, 0.14060674581144536, 0.12574302910694055, 0.18075157808406012, 0.16407298376517637, 0.14991156437567302, 0.18506345099636487, 0.1181879895074027, 0.12171270751527377, 0.1190929923738752, 0.1514425157968487, 0.08777494395950011, 0.1509362743901355, 0.17671392831419194, 0.10100555579577174, 0.10988448507019452, 0.08027084876916238, 0.06956506573728152, 0.11332393836762224, 0.25622861087322235, 0.1966023732508932, 0.1506783360881465, 0.10919096121298415, 0.08748914500964539, 0.11678287919078555, 0.18435644464833395, 0.14270278119615146, 0.11877359236989703, 0.0800906570096101, 0.11639485215502125, 0.12225928104349545, 0.21818776641573223, 0.169359042974455, 0.18076368314879282, 0.1147590127906629, 0.09287211259028741, 0.1355274362223489, 0.1397718627538, 0.13816076277622155, 0.09751702406044517, 0.2237206766647952, 0.13589453723813805], [0.058382367582193444, 0.09370121452957392, 0.04311455952535782, 0.0492108845418053, 0.047241643603358946, 0.038482173811644316, 0.047734141283269436, 0.06560702169580118, 0.0906811501564724, 0.02233544407811548, 0.05593446768554194, 0.06422137854886906, 0.13436328726155417, 0.015499291974785072, 0.054246866277285984, 0.04385562154597469, 0.03858898200892976, 0.02967895208192723, 0.03732296458578535, 0.03808519350630896, 0.0181677988730371, 0.020382886619440148, 0.036879776045680046, 0.04607533011585474, 0.011525791753748698, 0.029202657818262066, 0.03833642788231373, 0.024235834068219577, 0.01145284075755626, 0.046091838872858455, 0.04360547961134996, 0.02903690528390663, 0.07250074749546391, 0.06931429276508944, 0.05675831097843392, 0.03671451884188822, 0.04280895074563367, 0.057186727811183245, 0.007609799071880323, 0.03468544129282236, 0.0652766769219722, 0.06204051950148173, 0.02515133556776813, 0.015739613811352422, 0.04080450062506965, 0.06861458745385919, 0.03580369075228061, 0.04393069126776286, 0.046159577023770125, 0.005321737004643572, 0.01379893919719117, 0.0403432121633419, 0.0357699573838285, 0.020678637981680886, 0.022558317386678288, 0.01101695919143302, 0.021855171902903488, 0.001130829710746184, 0.038997843462441645, 0.031544407696596215, 0.02222450360256646, 0.056346704850771596, 0.02928573086059519, 0.09114174651248114, 0.040412080075059614, 0.05193424590730241, 0.036602791265717576, 0.05346041365659662, 0.04314966692722269, 0.012565134375888323, 0.0223202974801617, 0.009234981195602034, 0.014745185118434685, 0.010727587754705122, 0.014730973202469093, 0.03897546537752662, 0.01826648839882442, 0.0575577032619289, 0.027794935141823122, 0.009275474469177425, 0.030630946891116242, 0.016162761819681952, 0.02436122394699071, 0.007089388157640184, 0.024442977238712565, 0.024022716396887387, 0.06206700950860977, 0.05015541207311409, 0.03294148076591747, 0.06805320150618042, 0.03928588836320809, 0.02359007059463433, 0.008856339995483202, 0.027293916758415953, 0.022717542414154326, 0.021837733552924225, 0.011988561118154653, 0.029987722834838287, 0.06489954037325722, 0.015374283771961927, 0.02688115542488439, 0.037977421789297035, 0.0055682352062181705, 0.021524878019200902, 0.02372886493269886, 0.03848161741292902, 0.035290952372763834, 0.04677120509690472, 0.05856247113219329, 0.056814201907919984, 0.03269196647618498, 0.05383272582132902, 0.033936990025852404, 0.019833588773118596, 0.008857122855260968, 0.005952780085083629, 0.03252741155613746, 0.022948668404881443, 0.054392018488475254, 0.045087712218186686, 0.03970754698717168, 0.0416959802886205, 0.032368715785975964, 0.03245663017566715, 0.0321794316571738, 0.03595012200198003, 0.05298290142257299, 0.04099884323243584, 0.02667370012828282, 0.007623593688809446, 0.042261871708823104, 0.005930633974328105, 0.031239538520042385, 0.02040071682339268, 0.03634863240378244, 0.01533635366441948, 0.027545268181711435, 0.02225192659534514, 0.0190620673155146, 0.025265987629869154, 0.02619580112929855, 0.03009771675403629, 0.03218165725203497, 0.06320228001901082, 0.019974958151578903, 0.05071548505553177, 0.03555464465171099, 0.01040895958431065, 0.09934899397194386, 0.022822791677234427, 0.007956309094359832, 0.043147638107516935, 0.05738445970096758, 0.11561807883637291, 0.036116916087589095, 0.030920854370508875, 0.03003446032692279, 0.07215238761688982, 0.026655413609530245, 0.03851659928581544, 0.05133915033989719, 0.037648457834231, 0.037761559443814416, 0.03404802210362894, 0.016998810261221867, 0.009660856066537755, 0.035637062907751114, 0.029277761466801167, 0.05959616495030267, 0.04204582615888544, 0.03592705859669617, 0.013786543210569237, 0.07952403277158737, 0.027188155201396773, 0.013214332084836704, 0.040187481591211896, 0.023571219195478728, 0.08007701167038508, 0.011900085240735539, 0.02707349126493292, 0.08168618460851056, 0.03420347447640129, 0.10469768874879394, 0.05347509715440018, 0.01504257005373282, 0.010769741742738655, 0.0344752209660198, 0.05251792851569397, 0.039903518078582625, 0.03606004128232598, 0.04025045642629266, 0.01487746721665774, 0.020245294984696165, 0.021270985482260585, 0.04604114891429033, 0.020759546497304524, 0.05881102529487439, 0.018266172880040746, 0.02035650348157755, 0.052091381046921015, 0.02496559508810086, 0.050128318169819455, 0.023417076395292367, 0.028362950376634086, 0.0044735775611895534, 0.0396892638610942, 0.08934829703399114, 0.019048203148746064, 0.06246362001235996, 0.05090983784092324, 0.029117508458771875, 0.018408806029973284, 0.05667069175147584, 0.022237249882891774, 0.019578939669632485, 0.04395967489108443, 0.03582605187382017, 0.07779391096638781, 0.02433094092910843, 0.02515469940512308, 0.018704014564199106, 0.018161218779693757, 0.07489495152341467, 0.008645608222910335, 0.0411487180473549, 0.035921457290117226, 0.050034317321011, 0.019662482597466027, 0.0554766838571855, 0.01178337212851537, 0.036470449795680385, 0.035253856863294325, 0.023359450112496103, 0.011840060336648353, 0.020906769936638217, 0.003037721974708672, 0.0067417555837892, 0.047370185277291706, 0.06899433636239596, 0.031781898345798254, 0.03312774541388665, 0.033524902138326845, 0.06111511308699846, 0.027764199201815894, 0.03905322549066373, 0.012189076697852994, 0.030176952680838958, 0.04822205545912896, 0.033915507607162, 0.015353927721402474, 0.05982894995915038, 0.04696559180904712, 0.022058394837326238, 0.06097329926810094, 0.0323078003046768, 0.01791892240622214, 0.027371200200702463, 0.007898261271683233, 0.03113266925460526, 0.03231686892520104, 0.024058520993483917, 0.02663113732290055, 0.09065377126846995, 0.05466339856918369, 0.019803361734375358, 0.10881151085985558, 0.02217670250684023, 0.010078857386750835, 0.053716207787926705, 0.03970478195697069, 0.009131109358609786, 0.03589082143402525, 0.008434348041191697, 0.045620969496667385, 0.07789767254143953, 0.02884647443092295, 0.04417433622958405, 0.10638676597071545, 0.04281598715377705, 0.0756708291758384, 0.06102477293461561, 0.031307863603745184, 0.025228510444451655, 0.030797293143612996, 0.032076976262032986, 0.061939560276057036, 0.04467734780960849, 0.03020507117201175, 0.0259638880379498, 0.04170708451420069, 0.050860308177236996, 0.011048128545683409, 0.04519244749099016, 0.023113275911392908, 0.036338315278823884, 0.03869079279580286, 0.010533128100048219, 0.048395322768815925, 0.041191648957984786, 0.06688314250537328, 0.042847511890743456, 0.024411265904616033, 0.05200577028361814, 0.06414844960506473, 0.029647281459931816, 0.10063816979527473, 0.028893120320779935, 0.03992441017180681, 0.002293936060076313, 0.040602772164025476, 0.023928043798410466, 0.030500237297798907, 0.04110068794605987, 0.023426007612475326, 0.016057127487978766, 0.03991398108857019, 0.02609300646664841, 0.04684987783964191, 0.004126599773631564, 0.06288266288382666, 0.05989352613687515, 0.11843619761722428, 0.012944601692392357, 0.03403577454654234, 0.11285404608185802, 0.036405683628150394, 0.006262313765806279, 0.011400760650368673, 0.0637407654098102, 0.05010340914928487, 0.04087989265099168, 0.027644483572138206, 0.0323849124168711, 0.0331953444651195, 0.04475135562409248, 0.01110639434773475, 0.08032130463314907, 0.044994990407888374, 0.07267682054745299, 0.03538423736712762, 0.01371229366798486, 0.018935025203973055, 0.05717040225863457, 0.002290557379767831, 0.042084485691572936, 0.044802788578506024, 0.014717762125656009, 0.024054195332740034, 0.0641229095469628, 0.06461161760879414, 0.024686040356755257, 0.022796091324250613, 0.13656806466834887, 0.1731114773345845, 0.14136667789093085, 0.07395490910857916, 0.1626468931457826, 0.14336532992976053, 0.14804408672664846, 0.13602496523942265, 0.11561596180711474, 0.07671582060200827, 0.11034714417265994, 0.11676117964088917, 0.2331447952560016, 0.06755849519478423, 0.11276600616318838, 0.11412773095071316, 0.16104873961636, 0.13007348030805588, 0.09827458805271558, 0.1637676837188857, 0.10414651475314583, 0.08525483775883913, 0.13250217427100452, 0.19620511813887528, 0.15553333557077817, 0.1964777670800686, 0.1486873107829264, 0.17679075204900332, 0.08493669304464545, 0.09582128362464053, 0.18849463973726543, 0.1359597308827298, 0.1265287319464343, 0.20215337324355329, 0.13230942961360725, 0.12744385855538504, 0.16546909670744622, 0.12131630735737936, 0.10650519747287035, 0.12360245468361036, 0.12472351667072092, 0.20115530251392297, 0.10216403220381055, 0.05259484724540796, 0.12181478632347924, 0.10633902424680335, 0.12961503490805626, 0.15678243711590767, 0.09937870702041046, 0.09211618386741195, 0.16559826263359614, 0.13472050880747183, 0.12172004926417555, 0.10475015986178603, 0.09882355680955307, 0.09916688195828881, 0.12795417117221014, 0.11863420770636626, 0.09701873508415051, 0.12256758021456854, 0.1079932926222682, 0.19570886476763658, 0.18830882970775875, 0.16183381820363657, 0.1072577674474035, 0.10312798619270325, 0.14522386448723928, 0.1556622843657221, 0.0859661256628377, 0.12599192932248116, 0.12357451261154243, 0.15944536136729376, 0.0990977528105889, 0.08584787057978766, 0.16736832979534352, 0.209835393886481, 0.09845107501106602, 0.17384430872542517, 0.08340202325156756, 0.11809911499066011, 0.07914244503315006, 0.09244604009602751, 0.09299331930066858, 0.0822740944900683, 0.17499004224581377, 0.09239168944103376, 0.15679851839584963, 0.1562747165028538, 0.11794278052236352, 0.1506603006273508, 0.11343301287186996, 0.13265559103872093, 0.1705146831061159, 0.3133640007248947, 0.13602983712085656, 0.11134442780166864, 0.09320447261312179, 0.17097065863864763, 0.11900448426604271, 0.15714978240430355, 0.1063278012775949, 0.15749886152999742, 0.18040832078882627, 0.22659674233623914, 0.15748197957873344, 0.09710193704813719, 0.16381223632821015, 0.14478616868810995, 0.14611611089536122, 0.1268108668071883, 0.1292066111096314, 0.11533818314118044, 0.0665418461763433, 0.07212601974606514, 0.11506534421018191, 0.09467846101948194, 0.09257247152605227, 0.09162892108517033, 0.15648620229746613, 0.13997059209006174, 0.10580698493868113, 0.08946815345968519, 0.13125656039587089, 0.17694847072873796, 0.1908116332654442, 0.09456598705479077, 0.1782662807298558, 0.14236065026904854, 0.15242879358785494, 0.17501555516251496, 0.18251618982425757, 0.13699224404990673, 0.07006121054291725, 0.17218344498957905, 0.17749241154108727, 0.12689146319670336, 0.11304685859275715, 0.10906765782939536, 0.19393631416772092, 0.2397055503513132, 0.11998498093869005, 0.1464188867913825, 0.16047041064926557, 0.1710583796458585, 0.12381544682596411, 0.17636164650321007, 0.07187717381332602, 0.13116076482193811, 0.2597164980002812, 0.11142741263444934, 0.1220174783042499, 0.25873539064611706, 0.11184097972831555, 0.16800235291676863, 0.09371471059109483, 0.14142405481210776, 0.09429931600711175, 0.1295609420963696, 0.10586248910320656, 0.14429774561098643, 0.11301813620541777, 0.19976900118802274, 0.12772201720092977, 0.07513709353016955, 0.11223864196134464, 0.08527034906936543, 0.14612333050795964, 0.11561592109501362, 0.10880559403449297, 0.12241581907229764, 0.11177005924816642, 0.08922409119882754, 0.12485097268862383, 0.12837261014751025, 0.07827938920153038, 0.125910274418337], [0.03872232431811946, 0.006374138881385858, 0.04208733893132635, 0.0038183845712670256, 0.015748416106881838, 0.06364291387477092, 0.06127536270235266, 0.04794798159439649, 0.020297442097216845, 0.04761208301143987, 0.06054833957127162, 0.0502736841195396, 0.046768813260963986, 0.02849129188273634, 0.06830705502735716, 0.018166770892483846, 0.0694786271612559, 0.04184415876599295, 0.02417474556049066, 0.01255046105611005, 0.038817638132189, 0.06277914558138166, 0.07841405804668154, 0.022032722464895675, 0.017586306236418228, 0.016573692805000713, 0.01963833353615233, 0.02091708536525922, 0.03245140206334846, 0.0918432092294097, 0.026840502695579613, 0.01652719619284783, 0.03007221401536039, 0.02077095945631819, 0.10256947723350354, 0.012752353213727474, 0.03944465198687144, 0.05220494406031711, 0.04942683170416525, 0.06962142485593047, 0.030917088501155376, 0.034854769706726074, 0.06753361331565039, 0.04584813623556069, 0.052516551089606116, 0.04136425808870366, 0.02843731442200286, 0.01823040560287024, 0.019337559318436042, 0.017027513988848244, 0.011868276367230075, 0.013148883141444197, 0.015918572333508303, 0.024617900173845034, 0.026622423236923556, 0.04869179168183889, 0.09265964970524822, 0.03808553616649338, 0.03465721084337149, 0.04631521260099752, 0.07355170324444771, 0.03774530513744269, 0.01695146717663322, 0.05997590028813907, 0.017440173542127013, 0.028425341671598808, 0.009100556623057594, 0.028872998364801918, 0.01728836150972971, 0.05117038171738386, 0.06191253422626427, 0.055370333671037636, 0.014804987802303262, 0.022085471777245402, 0.0485261137863355, 0.006113496193263147, 0.05860484564410789, 0.014493494427629879, 0.04379023112622755, 0.046200960874557495, 0.010791586329495268, 0.008311857203287738, 0.030772753924663578, 0.10075905759419714, 0.010288253293505736, 0.01827632206758218, 0.07328542574707951, 0.07675800512411765, 0.06759065775466816, 0.017556635596390282, 0.03393033020464437, 0.042513693017618995, 0.04033578559756279, 0.06730139827621834, 0.04984401538968086, 0.014018096678358103, 0.023161760631150434, 0.01977333825613771, 0.07684348696576697, 0.06863562882478748, 0.04639367839055402, 0.04271787777543068, 0.040468842922044654, 0.043101562187075615, 0.03255071584135294, 0.02735914263342108, 0.00921271082812122, 0.054549428434776406, 0.021994814409741333, 0.010303694206023855, 0.04250243612165962, 0.0454078009352088, 0.02182127398970936, 0.023083915701135993, 0.04639880132994481, 0.04451123904436827, 0.09378747668649469, 0.03949476519067373, 0.05390774465299078, 0.03736030436786158, 0.048646865878254175, 0.04742605924340231, 0.03506113934729781, 0.050508250282811265, 0.02872636016192181, 0.03952994383871555, 0.06952839770487376, 0.04132607692320432, 0.028334777602659802, 0.05845277916107859, 0.029224893410823176, 0.046589832686419995, 0.04822969576343894, 0.048372798798871894, 0.03741941155333604, 0.035906210608248196, 0.04324608336069754, 0.03733059471207006, 0.049476212090147395, 0.01171138380388064, 0.031078267709485123, 0.043797844289136786, 0.02979959560824292, 0.037584505908723385, 0.04201852869508522, 0.04724435095808335, 0.021421543921210935, 0.09264709002205304, 0.06752053794584104, 0.05073013462658439, 0.027139214166839207, 0.025215871033391783, 0.05571702774614096, 0.03265155293047428, 0.025326204220099107, 0.0663619190454483, 0.016720841605482355, 0.05440004895042096, 0.04961506071101342, 0.04103682083742959, 0.015426300266491515, 0.051123121753335, 0.036114727812153954, 0.059243611725313325, 0.03058143419080547, 0.03276127204298973, 0.03335596388205886, 0.03690531949645706, 0.0019340760731470904, 0.03837736729266388, 0.017361967292215143, 0.03500229339780552, 0.01098788226954639, 0.07590864891452448, 0.02648244146257639, 0.03830846545419522, 0.024307979304077368, 0.01618756227461355, 0.10941407031246594, 0.09700641288821187, 0.030849981387811046, 0.012415634451567062, 0.02264869655482471, 0.04816145210393837, 0.04696051297443254, 0.03751396880085979, 0.027716828975826502, 0.016228579716490846, 0.024483531580439637, 0.05831889063119888, 0.0764332175520914, 0.03176514531618782, 0.02006542044026511, 0.014223928579927554, 0.07222427840211562, 0.06578487250953913, 0.008646411438738661, 0.0258501028043351, 0.06101652194878884, 0.032924782019108534, 0.03174167139721768, 0.04877567896619439, 0.014963607237275158, 0.027059516836223856, 0.021020908008462617, 0.020902554537834864, 0.040500869774924855, 0.022725805274343917, 0.013560551185426968, 0.021727091632783413, 0.03292810684069991, 0.030804529719586884, 0.02549816026086254, 0.005520584660449198, 0.014540357448692833, 0.02744592895864376, 0.024091786172773157, 0.03787840995937586, 0.04652819795800107, 0.03622789727523923, 0.044052674900740385, 0.014307504586343254, 0.028278946044987867, 0.04489207021625979, 0.023087318554254513, 0.03574566583016089, 0.027167749957048466, 0.04711164986448629, 0.006896369117644748, 0.0537982935618077, 0.03802675807050296, 0.0360049069193857, 0.06220084375568798, 0.036648867186158895, 0.01679499021598271, 0.03354914958721825, 0.06820511192615543, 0.003754409321118146, 0.055981734434940984, 0.007361171966684716, 0.027468011880825673, 0.0329545697064272, 0.015683865374220268, 0.0362659664824605, 0.012055254325137606, 0.03465574520773121, 0.022646097765703286, 0.039612596189337115, 0.03326182393357158, 0.04745105308081422, 0.03331099397369793, 0.05394581386021205, 0.06813392003199883, 0.07607143625084843, 0.038460094282137494, 0.08454407232680491, 0.08747147595775978, 0.02741072147286364, 0.02462698915041983, 0.04440857669604676, 0.019922605782215084, 0.036435016697006564, 0.060481246028627665, 0.00803089705628476, 0.0112973663323958, 0.038283108600548336, 0.015193418566403645, 0.03894172522372433, 0.023549791059589813, 0.004681501046953989, 0.043702506726341586, 0.029029315869723047, 0.06787676204528127, 0.054091634428394694, 0.07267033375267472, 0.04916759740029063, 0.02045868576637336, 0.013135588095922555, 0.0046639965398104066, 0.04260111886209675, 0.012174204906581767, 0.04244570041607533, 0.004216399642505816, 0.05873122279133115, 0.04034332072894488, 0.03283686423674226, 0.058155913305069716, 0.03337471180462411, 0.017567368324047754, 0.031717698755008836, 0.04173748966838632, 0.02199993226011949, 0.034760036040097475, 0.01950962222846491, 0.03027631395629474, 0.028523294986890893, 0.0424806076501097, 0.0153867230151913, 0.04927525715902448, 0.0897606834769249, 0.010217254781829459, 0.03845283056476286, 0.054144390526094606, 0.019391216171373214, 0.01924202498048544, 0.04218233044126204, 0.033531602671636004, 0.04622351877125246, 0.05157044257170387, 0.04233155046988811, 0.06302632910332509, 0.02245803499993469, 0.039086894398289065, 0.008388697901474578, 0.031557031840618165, 0.028180675514574562, 0.05020454140113933, 0.011745718523993023, 0.03688597785575049, 0.007765633120600666, 0.05808380538863795, 0.028250686757798706, 0.06814611330628395, 0.03863836918026209, 0.04126003510983927, 0.04585247207432985, 0.019031177008790628, 0.013017239714307445, 0.006066610271643315, 0.05013455729931593, 0.01434828114828893, 0.024831932171114852, 0.03857891594192811, 0.04462320750047054, 0.009956006077118218, 0.047140826870288165, 0.010280847931945962, 0.08026364951261453, 0.05010481710944857, 0.044592429152024646, 0.02434782966572259, 0.022030617310000316, 0.04227965271898678, 0.05417804925569466, 0.00412131822668016, 0.043776958981262784, 0.05945439862885645, 0.05649867633889828, 0.012913991281363581, 0.0015316965374430375, 0.038921274178262265, 0.034222548095775504, 0.10262200262929712, 0.08486175563718591, 0.20460033336920397, 0.21905804185995034, 0.07942117364811045, 0.11785857432654925, 0.11626745041991983, 0.09807207249104977, 0.0908873365925891, 0.15057652869394847, 0.10599551589361259, 0.18122115145836556, 0.1743373322699751, 0.11165290339184658, 0.22850689983793668, 0.10612520429172687, 0.09269572741218976, 0.08706445672682353, 0.1603734887072018, 0.1767561196216515, 0.13490382182810987, 0.127592091315559, 0.18073477755699838, 0.10450381093791553, 0.10445331436182771, 0.0840558053127357, 0.11635871337992804, 0.15137008896895818, 0.11789453668253762, 0.20244892952697618, 0.09825678329382624, 0.08963151755077498, 0.0995498335521136, 0.18018725407975061, 0.19668286107480526, 0.07555508467235736, 0.12537140904792718, 0.1564437395759991, 0.07650031109473535, 0.17047342817698205, 0.09974882751703262, 0.10278312755482537, 0.12578139347689493, 0.1322464615638767, 0.14242307549076422, 0.12610528538269655, 0.08365719991603068, 0.11231816626553025, 0.12686643882521562, 0.07786966940121991, 0.09470771944948606, 0.09632385415690285, 0.09746641213340418, 0.09913653787225485, 0.10853928261037384, 0.09731364675930568, 0.20925057812460832, 0.109361931681633, 0.14945415034890175, 0.1272896004042455, 0.16294699561383041, 0.11091036216488906, 0.1766456812620163, 0.14320130087435246, 0.17480507359973022, 0.09311102477035352, 0.274360043661935, 0.10208870803139039, 0.11195218483252184, 0.11691636059965406, 0.16431081028921263, 0.13011261820793152, 0.08941087831876107, 0.068270190219794, 0.15852866055709974, 0.11958973429032735, 0.17103912282202924, 0.13272059469350747, 0.15372817457786628, 0.17165999593479292, 0.11893065965601377, 0.1014755702178393, 0.1564713559512581, 0.1964300660682576, 0.12953401782682963, 0.13871528873486177, 0.23963072150945663, 0.12050414165215832, 0.1281870308199099, 0.09922526311129332, 0.12321053285683904, 0.11048368577446256, 0.10227107110300235, 0.09248272169913564, 0.12211224250495434, 0.07975569141230412, 0.1951053078685488, 0.1948548877345664, 0.18919840268790722, 0.13497217744588852, 0.11963169489588056, 0.11457299920065062, 0.13022027457399027, 0.10740245825478009, 0.12249645617391382, 0.08881896508059331, 0.0801602407757725, 0.13789259216615132, 0.16436303034424782, 0.1310314360473837, 0.16462482272514276, 0.11962786795837538, 0.08975338244012424, 0.1460465881973505, 0.123988201841712, 0.15052247659436294, 0.13523477049810545, 0.17007007982049668, 0.16009116385664257, 0.2040574646421841, 0.10857164873076336, 0.09813613976751055, 0.18950302419917925, 0.18096332172197954, 0.07526963856071234, 0.09888209402561188, 0.17050777561962605, 0.10502605220036847, 0.046034139647547684, 0.15738479979336262, 0.07796796198402133, 0.11333013339234249, 0.15652953354375704, 0.11273283937147685, 0.1300433533532279, 0.1055144142093403, 0.15070364544434206, 0.12146620931369917, 0.11220314100916896, 0.08536463151020662, 0.15514747984707355, 0.12800031155347824, 0.12222506930785519, 0.20012664342565195, 0.23459591024688312, 0.1404834831399577, 0.14302066128168786, 0.23622965972338403, 0.09628218532140766, 0.14625677120472702, 0.11874088698199817, 0.1084150971312608, 0.10332323464431933, 0.11475374735891819, 0.1128214221181614, 0.12226260586508683, 0.09967647532799415, 0.18188866706831114, 0.11137869382011038, 0.08005710345293794, 0.12880114572388784, 0.14650732704571315, 0.1483337397554091, 0.1821009942463466, 0.07575407185192619, 0.14234109488981112, 0.17506582103669643, 0.11856346364532198, 0.08490814029106072, 0.10846847748117787, 0.14300479713295186, 0.1399580663336175, 0.10339216701686382, 0.1626890165997403, 0.10533710622361728, 0.12633126468530723], [0.009841661052113133, 0.026146173078034605, 0.032904504000076225, 0.01247904185272221, 0.0839678468182683, 0.04697456882734384, 0.025091064694736685, 0.03708790987730026, 0.04192939294236047, 0.06431040234331574, 0.052354394790849516, 0.02117098808022482, 0.030370436941406558, 0.052575047593563795, 0.012646768923981913, 0.04986350970076663, 0.03292110435930746, 0.03838634770363569, 0.050716652135763846, 0.05145559712712254, 0.07720346336386033, 0.013785573753661342, 0.03921587711998394, 0.03704886697232723, 0.05477167918745961, 0.06245916882263763, 0.017377363251788274, 0.04353684240153857, 0.050407528544643095, 0.013579639223670321, 0.03985680094254868, 0.01820434137646641, 0.03724869553531919, 0.023810720004673516, 0.030872542677181106, 0.038575190784675736, 0.01057435928045639, 0.010490446551037686, 0.03718351885410292, 0.06830298381724528, 0.010776625480502844, 0.009085108925189291, 0.04630818637087941, 0.014147049714145916, 0.0740880241085376, 0.008551803301088512, 0.022819493997043798, 0.01857296231069735, 0.034086189698427916, 0.03127275959455541, 0.025624742664928948, 0.05956559694771256, 0.0441600496747664, 0.03479142507006015, 0.04425744998401829, 0.019755899906158447, 0.03190174459346703, 0.08730571663805417, 0.0849211003099169, 0.03769667113998106, 0.05284498918003269, 0.04004982040662851, 0.061319182493856976, 0.04682904342189431, 0.06587697006762028, 0.035501023421862295, 0.03794302684920175, 0.024115277055118765, 0.017989352644820298, 0.023185385524162223, 0.04330920408080731, 0.03758914030290075, 0.032964367752096484, 0.019768983757655536, 0.058337971035923274, 0.02139933038103793, 0.04611718215580497, 0.008106692810542881, 0.041974919249436686, 0.03470478971887912, 0.04247966109375868, 0.029034567730767385, 0.02225358222079064, 0.011721586426054793, 0.005235957031670425, 0.010677729001534837, 0.03756911673450044, 0.05302734885896955, 0.05298640266326921, 0.009760523530920702, 0.03529238408165319, 0.01227577990253589, 0.032578264363110065, 0.023774767826710428, 0.014882332312741449, 0.02800380688027612, 0.03436600736209324, 0.04531629370259387, 0.0987438764423132, 0.030980012446109737, 0.03706269890868238, 0.011994648425440704, 0.044662783055433204, 0.02192828235482531, 0.014805574735094394, 0.05694054173571723, 0.015832595161295364, 0.03749339222641928, 0.021975416789895723, 0.002477440342772752, 0.033246760456157584, 0.03906090311439974, 0.07719295964177166, 0.03439636501882758, 0.0461139557217913, 0.022735820451219167, 0.031773725391498635, 0.017879867626886283, 0.028526338216449534, 0.03365215798839927, 0.016884801111051014, 0.0398764716727393, 0.08539402564721447, 0.06940954551100731, 0.01532967179082334, 0.03920814521344645, 0.05031984146418316, 0.02324886926050697, 0.0023354113010490046, 0.030525332915463617, 0.030573525865163122, 0.023246954095416834, 0.022319033708689467, 0.003098951914580539, 0.033915388863533735, 0.014805018336379101, 0.008865656281289245, 0.02852072673184531, 0.09212769860667841, 0.04092378029599786, 0.06511474453977176, 0.0396783699813698, 0.018713821091556122, 0.03369634758148875, 0.11512779657329832, 0.04237837277884994, 0.048852723224886825, 0.039848858690155406, 0.03249541523733309, 0.03960654365697077, 0.0703653706503766, 0.02377674575628979, 0.006539807447032737, 0.02773087634705007, 0.06550226945962224, 0.030584860792649642, 0.026793889036136012, 0.057284084015658925, 0.022266788208591085, 0.023369229498452375, 0.0392493831792048, 0.027808953675308397, 0.04638122727296182, 0.025388765148818493, 0.038459985716534514, 0.01576920472351568, 0.03762071592999356, 0.04835004412702151, 0.02401685555066381, 0.04472179524600506, 0.04008031716304166, 0.03477530647069216, 0.05710638247962509, 0.06274443851517779, 0.011025278878930424, 0.02483111453641738, 0.11099573544093541, 0.011339944404815989, 0.02415723935700953, 0.04139813734218478, 0.04866323892825416, 0.04916553126115884, 0.03077722547043647, 0.06482553934412343, 0.019974237208121588, 0.018981011218524406, 0.026984604873827527, 0.02636378604386534, 0.024366955871560743, 0.017153453480984484, 0.06282985928867545, 0.02265661845116743, 0.040776249819568226, 0.027388697922495858, 0.030047260890049592, 0.04678443313709327, 0.02904307995257633, 0.03935982832419021, 0.01314593745129449, 0.044877305294253995, 0.047379352285393646, 0.01344385588475104, 0.022036664753354022, 0.04237056962613549, 0.037665227827216895, 0.02249832810567958, 0.027963169418009262, 0.06413964900587286, 0.013447296057295586, 0.03852135581629617, 0.010927437521916415, 0.014017605588638356, 0.06214143122945513, 0.031245940497943332, 0.031506338489374945, 0.038611217601490874, 0.051259028924895186, 0.007599630376457104, 0.028387338621541858, 0.06802479124494962, 0.042274221046162505, 0.011852952502002674, 0.02235748289552118, 0.017963831246431385, 0.035794133586542945, 0.11430991760322026, 0.035768881905823946, 0.014089368300379386, 0.025436245636748414, 0.02135898808150419, 0.017640336283615658, 0.03637999429234436, 0.062442571856081486, 0.0658057238906622, 0.010254625946150293, 0.03279474078278456, 0.012873814374740635, 0.0674424385651946, 0.03370073091770921, 0.07297866685049874, 0.0224291633348912, 0.07308440296245472, 0.024427213173891817, 0.027576414635404944, 0.023802058505160466, 0.03079541020893625, 0.04022965932797108, 0.03122363026653017, 0.027512666270402924, 0.014876549498045018, 0.023091284591438513, 0.022064404961253916, 0.021560551997806345, 0.02692068857140839, 0.04820272060377257, 0.02384413276532931, 0.04057521346424307, 0.04817942649658237, 0.03531684526907546, 0.04104079705263887, 0.013769472117668815, 0.05440117531855192, 0.009997603666436459, 0.0414651019631752, 0.04414895223453641, 0.06885959966374294, 0.011244743397193295, 0.030958078801631927, 0.023105849345613803, 0.007046197283281279, 0.02145558432675898, 0.01731841721838074, 0.025968286641208187, 0.014763217186555266, 0.0032161546322251005, 0.047057916676359515, 0.05553837286840592, 0.0454724619298109, 0.06033591739833355, 0.002048192304625575, 0.008743032280887877, 0.03399039412449513, 0.021589552584503378, 0.014773766709757703, 0.04862963787413069, 0.03134798537939787, 0.02158846692847354, 0.1022859513759613, 0.05528043456641691, 0.038307199986385446, 0.010461044780510877, 0.0721269900511418, 0.048838243287588866, 0.038427392286913734, 0.012734443281910248, 0.0039792414754629135, 0.051159233387027464, 0.03907446702942252, 0.04051339553136911, 0.0036276275973900086, 0.009626589199927236, 0.055002632151756964, 0.008265298674814403, 0.07010419573634863, 0.04698598857170769, 0.019971674042088643, 0.039122273214161396, 0.013390847032756677, 0.015018541432384933, 0.01921486492002649, 0.013754546043596097, 0.04307734527226005, 0.01958571993080633, 0.03311505002368774, 0.0673105584989701, 0.020220676037882055, 0.033499870981488905, 0.05826439069850104, 0.018915247604517, 0.008827021345496178, 0.09164070723844425, 0.03930919264842357, 0.041250145461942465, 0.041876365430653095, 0.013887171650172343, 0.04109583302800145, 0.012198185182309576, 0.019250745851812617, 0.06019715698701995, 0.03435952735266515, 0.02232922530466957, 0.043752660642244985, 0.04165119697738971, 0.05582804964589221, 0.04628186599750604, 0.023318095099447027, 0.02082399375337575, 0.04658445190372212, 0.07214421805526529, 0.0037543384990255746, 0.0666621368644493, 0.0048457209403360525, 0.007713636133952865, 0.0351079820123102, 0.008781688420900276, 0.023860928203378404, 0.009033702264007713, 0.04400589669655476, 0.03199876153043338, 0.02245229289733938, 0.003978680411819369, 0.04375800410551684, 0.19429120155317442, 0.07357222214341164, 0.1462826912424394, 0.09398807199405772, 0.17247275875083037, 0.13721918687224388, 0.1106906525258507, 0.18144280170755728, 0.09555535218013184, 0.1412533082600151, 0.1103303979283997, 0.12078437661486012, 0.1132121022258486, 0.08643753108169351, 0.19055640910352978, 0.10620377864688635, 0.1696381244276251, 0.14362352607505663, 0.11223035026341677, 0.1415327696927956, 0.19601145067385264, 0.14774356356688909, 0.08734750760985271, 0.1235865226813725, 0.21331341511436872, 0.15598973179502146, 0.09316836776477949, 0.21752352134457656, 0.11399112828075886, 0.07863938595567431, 0.16384201044482843, 0.1166727529572589, 0.06139027939311095, 0.10669897350349597, 0.2212827546255929, 0.08036740430231605, 0.19697117060422897, 0.1500366726624114, 0.13966991965259823, 0.10451540031603404, 0.17315084593636648, 0.11538117511996202, 0.08943799257810627, 0.10415432469121047, 0.1900308701608862, 0.2036733188267265, 0.11407545661287648, 0.118095763027668, 0.19523302172975882, 0.16342969185539655, 0.1750534852700574, 0.09966551020209279, 0.10150933412036725, 0.12110589364809649, 0.11579117311963014, 0.11951580111469541, 0.15513424841420992, 0.2528506192777838, 0.17775875010660716, 0.14860931996788296, 0.09271195796983582, 0.09703046695462295, 0.2523385967527117, 0.12099306684519563, 0.14891733415424824, 0.11693929508328438, 0.22575432753988675, 0.09438633812325341, 0.14407942018338613, 0.1441868051354374, 0.10166472542498793, 0.14524647327406065, 0.15060817556721823, 0.09749533129589898, 0.11290663254580327, 0.14057431183755398, 0.11140605235206229, 0.08537346603614943, 0.06968989582466227, 0.17817784047552518, 0.09389522804745606, 0.11227080452122859, 0.10611583372311932, 0.09939587395638227, 0.07794614708317177, 0.14352143369615078, 0.07130271249583789, 0.1037596140855125, 0.09861571474799088, 0.19986713092241967, 0.055588262155652046, 0.06796593511743204, 0.08737630463604416, 0.19100231517638477, 0.07261067016848496, 0.11657615671200411, 0.0804478581994772, 0.14717009291052818, 0.22392262225704535, 0.10980209056288004, 0.1531829038368804, 0.1755871530622244, 0.13709915402744496, 0.07803637866995164, 0.20163981722933905, 0.1296721811273268, 0.07404596850808177, 0.1000618017943842, 0.1589917607073273, 0.07143551536968776, 0.09727109582828623, 0.15094588244599955, 0.15883425915879862, 0.121023207370724, 0.16290437004395894, 0.12729118817618915, 0.12097744696906634, 0.09687063803098031, 0.13295486569404602, 0.0983885887211987, 0.0896042947258268, 0.09817448378141437, 0.16015329052295002, 0.12366312928497791, 0.1023118035601718, 0.15079802966543607, 0.12769948983831064, 0.11932909541896411, 0.16105180659464427, 0.08472981450280972, 0.10347460223627941, 0.08811588745032038, 0.17814932843404158, 0.040103797867361984, 0.10483814549765416, 0.20878551022282668, 0.10154045852167265, 0.1096661121451429, 0.162715275904962, 0.1707913896867207, 0.08524573181888886, 0.18039394941713127, 0.10614136699587107, 0.09653251046048743, 0.21809602848121099, 0.10092376518462386, 0.20169760127152714, 0.15259067847260407, 0.09287877580417053, 0.21259840205311775, 0.23523498166884693, 0.09811573621949979, 0.11753356962331704, 0.09487563651055098, 0.11752773422215666, 0.14119732912097657, 0.09314180311879941, 0.14161548311156885, 0.10953010658600501, 0.11649230335439954, 0.18647309392690659, 0.0897221766146166, 0.09941299339490277, 0.10509317288441317, 0.11248839713100876, 0.047749628845070086, 0.160039948033435, 0.13686970062553883, 0.11758488044142723, 0.10876334165888173, 0.2043320813349315, 0.09414251334965229, 0.12785161738949163, 0.22403033290590557, 0.05757584050297737, 0.09296165207134825], [0.018268245804522718, 0.022979119360180836, 0.06532065956188099, 0.028355223559109227, 0.035027497581073215, 0.014843362350282925, 0.04271518399140664, 0.059273562261036465, 0.0066334851435385644, 0.012609824388554054, 0.10156019710536514, 0.011253967232603048, 0.04273578092189772, 0.023178567943562354, 0.06070042641035148, 0.0464072931957032, 0.021480398352390954, 0.049399456208837886, 0.05020197653876884, 0.04578855746824827, 0.02906579730500068, 0.11498630845120975, 0.03973430162295699, 0.019204715732485056, 0.06473859865218401, 0.03279900876805186, 0.027932850777038505, 0.0584732573479414, 0.05295328676168408, 0.04131445361833487, 0.020803328969382813, 0.017830919806978533, 0.03062708263418504, 0.04020342716415014, 0.010114426192428385, 0.03940528677776456, 0.03260974160262516, 0.014313869244818176, 0.029368400174592222, 0.03813436693911042, 0.018593869670959454, 0.042635781823524406, 0.0378132739902607, 0.035738870301949124, 0.0481858861499599, 0.03316585872588413, 0.05576520373246499, 0.03981440268190844, 0.02515344920435122, 0.0459281558703099, 0.02073483425192535, 0.03998505423909851, 0.04170757305941411, 0.0806931486087186, 0.01990649905720992, 0.017469811951741576, 0.011766281527733164, 0.04818956720243607, 0.06245731642203672, 0.03784893100549068, 0.030467514946524586, 0.03701253142207861, 0.03029659197532705, 0.004962575696741364, 0.030680269601621797, 0.0655508322109069, 0.09173990227282047, 0.009411429138188916, 0.018247358800311173, 0.028391145202996473, 0.029866892711392472, 0.01967844513377973, 0.04813536582514644, 0.03099181895543422, 0.04318315263039299, 0.025546056351491382, 0.13425238749810628, 0.036807579919695854, 0.020836171760622944, 0.03243379407961454, 0.02337666624225676, 0.0349922612575548, 0.04536767576688102, 0.07279311466429915, 0.035152015542345386, 0.04305786453187466, 0.07784600888511964, 0.024228538120431558, 0.024045644095167518, 0.04146180089030947, 0.07650745606848172, 0.024899373462955867, 0.061004254035651684, 0.006568270294727492, 0.046193476633301804, 0.028623032849282026, 0.025594505448160425, 0.04791600223896759, 0.017446558556652496, 0.045055922852563005, 0.10016588228089468, 0.03698162754465427, 0.03731981957597392, 0.045000008174351284, 0.011293328200866069, 0.04050610127991863, 0.02909251462135996, 0.028051190676965883, 0.035713995208165476, 0.02580960444174707, 0.058475998629416735, 0.028702048252203634, 0.04814556759915181, 0.035180184923644574, 0.07516884218369212, 0.016494417862434472, 0.041362765311662636, 0.03004161547869444, 0.03936489358810442, 0.04594640167696135, 0.0583629614806601, 0.032918644669864855, 0.027675570654017583, 0.0683039812637227, 0.05158104807404535, 0.03804548902969275, 0.05065291394878711, 0.0404937180158283, 0.032716885674744844, 0.05936046902622495, 0.04233347411666598, 0.01919654956353562, 0.05793790000357798, 0.045701650703059774, 0.01890146655828825, 0.042681111355445216, 0.0072802956814744645, 0.033038209325500896, 0.02339371613093785, 0.06288934645376035, 0.03375306632369757, 0.05023516707920602, 0.005927048764923322, 0.03039706265553832, 0.03263563449893679, 0.03121649207813399, 0.06074552184769085, 0.024514767940023115, 0.07276305556297302, 0.019272962784660713, 0.06965822180999176, 0.04451374623126217, 0.04054764458643539, 0.04491588340273925, 0.06119987568152802, 0.02302164484613708, 0.023696071335247586, 0.03565323918259569, 0.012583981534200055, 0.03932484984397888, 0.028694411340568746, 0.04614639987370797, 0.1502261467810188, 0.016338604169764688, 0.011103331610294325, 0.008849795525228339, 0.025496294289561253, 0.03843256950910602, 0.08023906618888889, 0.010242223174178174, 0.026414246996864676, 0.03127164001177464, 0.02764575582529817, 0.05331554303744009, 0.03500579803117684, 0.013672749495266803, 0.011770666560291179, 0.07530842362237827, 0.048934028683496375, 0.033029880308146985, 0.042152393476239274, 0.012348404353750604, 0.043466790446213315, 0.056450116980288706, 0.02797955264603453, 0.029779141170105765, 0.07273200580051967, 0.052655715229255814, 0.08780714723148517, 0.012054656366152423, 0.013281272957101464, 0.033194828778505325, 0.034377749410590956, 0.033080183501754484, 0.033200365624257495, 0.08091553846108061, 0.04104663584647434, 0.09610890783369541, 0.012171126902103424, 0.037852079407977204, 0.0017866914817464671, 0.053928541751312356, 0.04718610551208258, 0.07810818124562502, 0.026212720399988548, 0.04647942486086062, 0.03026681107335857, 0.03239115493904267, 0.01388223106706781, 0.04345888212057097, 0.021935237338766456, 0.012419994039061879, 0.016808832330363135, 0.028900740269039358, 0.010834397648328116, 0.03937317510800702, 0.016554317237543206, 0.043630687187292745, 0.04772285385323422, 0.058373668763254366, 0.07001837462718997, 0.02540924503201885, 0.04179140606096812, 0.015306906940947686, 0.039118154506598196, 0.055525107508791346, 0.02466736707304205, 0.04264526774308511, 0.008708829026935356, 0.05687392316758633, 0.09159956087491342, 0.050851568646196804, 0.020589900868279592, 0.023582219944468567, 0.05001378824402179, 0.027622500733871545, 0.05666699373562421, 0.023661876562982798, 0.05447913220684443, 0.04261416369783027, 0.03744875480021749, 0.027403735954846655, 0.04527095738532288, 0.03839514830282756, 0.009024128983063357, 0.02332133680049862, 0.02713715311672006, 0.026739363658374975, 0.022363072327737297, 0.014071868882248444, 0.027349680462586026, 0.03157838873033013, 0.061746795262609205, 0.027447321651769534, 0.025785799736955335, 0.09570335423839943, 0.0853085166641644, 0.0261300103738904, 0.09990208822169475, 0.06970582782690014, 0.0463775699692113, 0.025244155765644143, 0.02766093465366534, 0.028440132038667798, 0.009301884748440768, 0.019909834056826572, 0.014283301242228066, 0.030426626426300833, 0.044837214052677155, 0.016272989833461385, 0.019836939039773176, 0.013643230677449276, 0.013019577267446687, 0.01402614580001682, 0.050639763940125704, 0.016292987956798503, 0.036248317786625454, 0.03133989724197558, 0.017792428211708154, 0.026493091069694077, 0.01536124911425369, 0.04810642630660108, 0.04680686550480979, 0.036854273307004144, 0.04266358479591353, 0.016961153264024427, 0.05821101034858397, 0.021429104497656226, 0.04509039243151035, 0.03916491235473326, 0.027401166003463522, 0.0817451018041798, 0.006576270646681743, 0.06469862615423543, 0.009715814010373183, 0.00684633945846664, 0.03739226675991501, 0.13495863388691628, 0.05599832122347184, 0.03901872198496546, 0.04225505921723587, 0.013230832360152687, 0.03860385888921363, 0.06013308971055916, 0.013982333642031466, 0.04660531685554555, 0.06243117246776819, 0.01227119130947228, 0.03624127798580697, 0.04451479796054108, 0.03002567669110639, 0.014255584783053823, 0.028042329009622335, 0.10844610618161303, 0.022397217906213233, 0.06899689443941627, 0.02761327944296811, 0.04944158305547067, 0.010481912276840635, 0.048826681050871096, 0.050011247130376954, 0.06538224340017353, 0.0243944144874279, 0.004130849947354623, 0.05990911887160369, 0.022513584965573888, 0.03618872544861265, 0.009751328533249242, 0.03441743353115661, 0.05353472002648881, 0.026071827692378844, 0.022101785455431257, 0.022846559062600136, 0.03846115618944168, 0.015560341466750418, 0.061450166893856864, 0.018337162910029292, 0.008930879611788052, 0.10654755162873439, 0.0069746550954213095, 0.0486812947451004, 0.06581071112304926, 0.020567867139886533, 0.04576753306069544, 0.07747015476758991, 0.008606887622071164, 0.022130650335124562, 0.037775940993534665, 0.025035212781014185, 0.0028307634929660708, 0.04068294446915388, 0.014027957488516611, 0.09214041435292789, 0.13765916254903587, 0.18053690317486012, 0.13457589942429746, 0.1881743169256619, 0.18835070888910974, 0.18718951834099634, 0.3035351224243641, 0.06396585583154644, 0.1598541922867298, 0.1671953983604908, 0.0673249095146145, 0.19916024671069213, 0.06701500900089741, 0.15800407156348228, 0.13103398733905383, 0.11763176721121583, 0.1290907851819481, 0.14357849849121912, 0.11665459536015987, 0.10793161378907305, 0.20127723525677407, 0.13889584690332413, 0.13706518656441144, 0.14091728414808, 0.11487421446612903, 0.10557575377502612, 0.11702157423964568, 0.20189223225627626, 0.1222385178719248, 0.08521850899394069, 0.1243721033845629, 0.1106029518746904, 0.06747829235557999, 0.10231757789318051, 0.07116355853421347, 0.07966953103563615, 0.12038129967238222, 0.12614915945700236, 0.10763556217508656, 0.08903943467885256, 0.12135818653873034, 0.09344692674598523, 0.09540610840278012, 0.161776780549969, 0.10419790021010808, 0.12739652395248413, 0.09817138966172934, 0.05829442944377661, 0.1636690247271742, 0.08533490489103965, 0.13317870082599775, 0.17902404149728163, 0.12710441462695599, 0.1388812041176217, 0.08434530227844204, 0.08831068806882415, 0.10938777029514313, 0.11375273178730692, 0.09527824526386601, 0.16062635156725133, 0.14230553965483392, 0.15701809232788427, 0.09325536273952041, 0.13120341753321035, 0.10413502036992993, 0.12459008954465389, 0.1138510922236102, 0.10926617003445115, 0.08987487413521324, 0.11395574946488653, 0.13426720670291356, 0.14887400290795735, 0.07876656377421958, 0.10264261652316366, 0.08274741337767669, 0.22191603135849747, 0.1460083866758006, 0.1572609128696578, 0.13562640734016895, 0.10693502905113356, 0.15715474928064005, 0.17732760895575794, 0.22110416420868464, 0.12820271854954107, 0.14417608428214276, 0.1714216401534421, 0.11455351167491504, 0.1030944733481322, 0.11437813751399517, 0.13354848884046078, 0.10915510063724858, 0.12405688315629959, 0.06949625550104038, 0.1629689530070339, 0.139262391520398, 0.1124205504144941, 0.18390683377427713, 0.10084242240658828, 0.07617819695068256, 0.172354272965874, 0.10806271354002611, 0.09459052966641528, 0.10408816074154206, 0.09093493582414729, 0.20414415427616664, 0.1779256018676928, 0.07799699649746929, 0.18288922123610973, 0.12510584401232855, 0.15087398487542356, 0.1596674865909985, 0.22389385237225465, 0.10989724831389529, 0.1369596200862101, 0.20040979608893394, 0.1363283653876611, 0.12157613198672022, 0.15401501847164972, 0.14557712338864803, 0.14271667759333337, 0.1735498516687325, 0.09110353820558105, 0.1712576246687344, 0.16138179174491338, 0.09859806605215583, 0.12159601306276661, 0.11537536686020237, 0.09301571774163417, 0.185677973021354, 0.11141241022518703, 0.09058336647493498, 0.1295211799442768, 0.08089282110865627, 0.13311153942985193, 0.1277797876724175, 0.09265188047928469, 0.18734972045889922, 0.06840290488409144, 0.18610291236213275, 0.10548540683729307, 0.10303396159516913, 0.08786741471184151, 0.15086189338139125, 0.15786745532282762, 0.1341209416942937, 0.17862249804394587, 0.07828458677977324, 0.17112412968916552, 0.11067191138863564, 0.13637468218803406, 0.10489502708826746, 0.12824052652078016, 0.12012303567358426, 0.12126874205257211, 0.06541268926646028, 0.0837069908156991, 0.15355377750737326, 0.1157109159976244, 0.15188646768885, 0.15772705285676888, 0.13884416967630386, 0.2566555993897574, 0.07095708711338894, 0.07302520756742784, 0.11625962012580462, 0.11816647994731154, 0.24128756831799233, 0.18504613478268894, 0.14056082256138325, 0.10039623813437563, 0.12016469772372927, 0.17378210063491548, 0.09345796651073865, 0.10737670785082237, 0.0447174051244344], [0.014113232376985252, 0.03356424020603299, 0.016733316471800208, 0.017988524832097546, 0.01908225373231939, 0.03355340400178518, 0.05019114711987121, 0.0166551780753902, 0.04237767728045583, 0.022685563058725426, 0.010033891719233776, 0.032444501362208805, 0.025390412292576263, 0.04192203423008323, 0.04292996746620961, 0.029614694815661226, 0.010864891012066176, 0.04304088080035789, 0.008126607813340212, 0.0038527506736240214, 0.06808609688388449, 0.005732014475922499, 0.07385430272136416, 0.036313212875808985, 0.10647897209439959, 0.04443242380927716, 0.05671501026621886, 0.036335736845753024, 0.02959441001127873, 0.004270239699898022, 0.04436185956001282, 0.04047414906589048, 0.047764970521841726, 0.03696819594396012, 0.014854573445128543, 0.029556215275079012, 0.03462435617776854, 0.013658148269834263, 0.03592138604394027, 0.03411274416638272, 0.03444152491699372, 0.049518749450466464, 0.04740005099613752, 0.06363599960293088, 0.015039184163989765, 0.06352278603506939, 0.03142105003020593, 0.07947359047830105, 0.012701405411852258, 0.024840982131926075, 0.02047072467394173, 0.04483022514198508, 0.05539704080937164, 0.027527471904509833, 0.03521140431985259, 0.05335518305322953, 0.07040193011718136, 0.0557097775994667, 0.023818813231108443, 0.0026433192542754114, 0.03215407141085182, 0.05788677917527301, 0.019423823171694363, 0.01952863477968744, 0.0379022333238806, 0.05310452203931553, 0.005484110858690525, 0.021969605137460997, 0.03726502787321806, 0.02294882107526064, 0.057934432689632685, 0.01372708912406649, 0.033422667267067094, 0.014342654396646788, 0.023663016501814127, 0.04251187454376902, 0.015959482906120162, 0.025794661404298883, 0.0159998031532658, 0.08460788854530879, 0.06802566655512367, 0.019473508898434893, 0.01512269486140992, 0.09834879942770515, 0.02846731924052749, 0.06491078369851623, 0.023118861950933933, 0.026915697946346233, 0.02876300783827901, 0.07237449926989419, 0.02691102962541793, 0.012932593318899828, 0.018263653818784014, 0.0315536527362253, 0.012048751415152634, 0.03356913922886763, 0.026150797294186692, 0.09490985503154141, 0.0031598432230696616, 0.042788190966738124, 0.05830614774354866, 0.022503065976447294, 0.0599644398316741, 0.033828621198024066, 0.08259779640606471, 0.028737332073173354, 0.07038025092333555, 0.0264623788784125, 0.04259036747472627, 0.001444079854991287, 0.024172633620245115, 0.07481223131929125, 0.02867974141346557, 0.03439267039565103, 0.037230985771332464, 0.09435313061944076, 0.038205745430397134, 0.04189470962488225, 0.008273149324980165, 0.03593058019344296, 0.04902789043262601, 0.018584059750927345, 0.030685938761702607, 0.03265227217759405, 0.025335593448419656, 0.11008126022560255, 0.02475503210111388, 0.02637419307471386, 0.0615629529846566, 0.018749227048829198, 0.0568793582330857, 0.02726725202852062, 0.029104867351374457, 0.056638013504977734, 0.051915436916585476, 0.011474737082608044, 0.05617588705250195, 0.06979650046144213, 0.023038228241992847, 0.009852107946893998, 0.010916122950480452, 0.030769907470260347, 0.07013810891658068, 0.03851581218519381, 0.0535510930764888, 0.02595625282265246, 0.049617232023073096, 0.027542447172371403, 0.04223242328901376, 0.03411158726417592, 0.0056771650976900545, 0.016377828582855206, 0.040373749631856165, 0.03338466591334768, 0.006937453988939524, 0.011506925087555178, 0.026106361732152954, 0.06043162476271391, 0.007838015843714987, 0.005543661212349045, 0.06004129070788622, 0.052805976809135506, 0.03924686920696071, 0.020954107932214226, 0.04325412739334362, 0.03562937510598983, 0.0661447878394808, 0.02419876739648836, 0.05321713171101042, 0.04548409541270562, 0.006955522104232971, 0.06694776618054935, 0.05707044726503747, 0.04711966336305652, 0.008620732280957912, 0.009020585333928466, 0.017958318149404864, 0.029692119053964103, 0.06500252841838769, 0.0217322943000389, 0.03632760460355452, 0.02343382772856525, 0.02678005370710577, 0.031100370987717594, 0.028434094773339372, 0.0345927466239248, 0.026281947935266153, 0.007110719178204558, 0.036530595139733384, 0.036614777586821995, 0.02765755894194756, 0.040110610358949216, 0.014505889566083039, 0.02618047471956483, 0.0077084987756929225, 0.05313525628298521, 0.03843064586232815, 0.0232272172080619, 0.0454767774125295, 0.0770201367725219, 0.08640466284539018, 0.07918891789657728, 0.018658747796767523, 0.017421127064153552, 0.04896525486505457, 0.05942889249750546, 0.04653866436066372, 0.03620413497888616, 0.009773983121184366, 0.031020130829087326, 0.01174115707233016, 0.06675366445311479, 0.04561929012249623, 0.07321045441286904, 0.03796993076269116, 0.028181952856747166, 0.011797364368768675, 0.07229439142559256, 0.04830437532759138, 0.03255539773298161, 0.03003773765106286, 0.03141824428790382, 0.059561993926763535, 0.024084853241220117, 0.013909491211442011, 0.03524112415366939, 0.051782684932862005, 0.014793654571154287, 0.04090833683897342, 0.056812766806355545, 0.028006459952199032, 0.023618377379274795, 0.028712680895945857, 0.019673267911587442, 0.05186128982209733, 0.024717673659324646, 0.031783625217420716, 0.047500406325395615, 0.04727134308112519, 0.042083322004015954, 0.01930737977714411, 0.03267782919907144, 0.0858754123161946, 0.03499751311859914, 0.04064919413732631, 0.06614832300692797, 0.05498470864923937, 0.025479320736069764, 0.03581038110756448, 0.008376109380541103, 0.03232511312567762, 0.0262896052029516, 0.04817277346072452, 0.05037497243444834, 0.04765757539176515, 0.049185290200901885, 0.017699423113039563, 0.022782295010983944, 0.0595045287960342, 0.03563078645882862, 0.043633269013038704, 0.08882173350346939, 0.03205055410840681, 0.009511753933371177, 0.041732824740133116, 0.054746081453881094, 0.07761535447623048, 0.02176723376448665, 0.02175605998906706, 0.04356182606092521, 0.036680086582366905, 0.004470373179563987, 0.028205223215211715, 0.09312476510448114, 0.010604095229479884, 0.012103328531208848, 0.07919312481369291, 0.022150528018495867, 0.010487546662001737, 0.04898673389106989, 0.08958639497203486, 0.04287132168454783, 0.03990028825189386, 0.032019806294036765, 0.0827494150559817, 0.017947782196902802, 0.05393006845510431, 0.03709614389975156, 0.014085217362402805, 0.045608304640544314, 0.028692172175007205, 0.04864437226206064, 0.052751157964978895, 0.01931886058965964, 0.034243351979447265, 0.005253909371926316, 0.05836731767547982, 0.03207887276741011, 0.03232847187401993, 0.027031545926417624, 0.03154138821576323, 0.010116675536015203, 0.05790303687431982, 0.03227972252560513, 0.045230594729738574, 0.014991240575909615, 0.014923261545066322, 0.017147377199892486, 0.03788868637223329, 0.043966616304325204, 0.03716257926342743, 0.0302140821170594, 0.008284591121732124, 0.0601856354624033, 0.016666677547618747, 0.042598102773938856, 0.059932908309357505, 0.014947692198412759, 0.09454960043409041, 0.017790658931647028, 0.0451667242284332, 0.048974211527300734, 0.070927944034338, 0.025318385800346732, 0.013851147377863526, 0.021801657542320232, 0.04662178490044815, 0.027288033859804273, 0.06857719338898148, 0.04871722995968802, 0.02111248139824186, 0.03775327453123672, 0.012596019593599652, 0.009923272699649845, 0.026616801574294056, 0.049090369937143156, 0.026036613421248536, 0.018308449004377638, 0.03558635937848261, 0.021096953124340092, 0.07826124517513172, 0.03521370455356581, 0.02403242284032915, 0.014463850929002677, 0.06772246318204062, 0.10441052594355174, 0.009764265651548547, 0.051962839372988255, 0.1097204831561872, 0.06338633942816939, 0.024576684260474782, 0.01690124031821532, 0.06895563272493226, 0.1510991227946111, 0.1033134094572493, 0.10136794099318129, 0.08729508399431195, 0.18259783115770134, 0.17059939141784394, 0.08728956071926014, 0.14125296899250575, 0.10435570709939514, 0.10011438825832945, 0.055683216346161704, 0.09890611416527204, 0.11757877362625939, 0.11063649864601237, 0.07844855476702962, 0.07012119303856577, 0.1184878477028438, 0.13219312871141092, 0.08598000170396906, 0.10261345987341233, 0.08945100009441376, 0.170716845829572, 0.16412580093102797, 0.14562585577368736, 0.15354921775204794, 0.10858013041849647, 0.19503840431571007, 0.1793701079274927, 0.10271601365613085, 0.11803781613707542, 0.11177232555512871, 0.1280824685735362, 0.13587361121816294, 0.153996399470738, 0.18531296189342225, 0.22079133242368698, 0.16346623775150093, 0.13591794669628143, 0.10888144746422768, 0.12700648845306464, 0.13440902052181108, 0.13172105832823686, 0.09148451526250158, 0.08211998561663286, 0.20110677368938923, 0.08389964726354394, 0.11454125733247825, 0.18851038174969809, 0.10394298817430224, 0.2261781540832349, 0.09328202916575329, 0.19720120754625114, 0.13505839210535797, 0.12691021790461882, 0.10780178968395505, 0.13088522532156535, 0.09518257861158677, 0.1812091413885355, 0.09178273140319756, 0.10867485390709979, 0.15557453621711048, 0.0923078835808805, 0.09905611790184464, 0.1348448164228882, 0.1264515146613121, 0.18102452558066162, 0.15323877441031591, 0.14737160424036638, 0.13961349268044743, 0.2231118000511612, 0.1379538503076349, 0.06478425727358886, 0.06103463204843657, 0.1940774901637009, 0.10750159222100462, 0.10814835144472973, 0.16923044701772078, 0.0684333507503782, 0.16826485097408295, 0.1788168711853879, 0.09736442832010132, 0.15823709405958652, 0.14517099303858622, 0.18046535844249384, 0.20163152553141117, 0.12325082426624638, 0.12856763468257018, 0.08464531653693744, 0.2071012370288372, 0.13969000428915024, 0.08731813382889543, 0.10471149015107326, 0.08287358696439437, 0.16119895369878837, 0.1514835943068777, 0.09913423763854162, 0.1435592280966895, 0.11570547414677483, 0.19849486170070513, 0.12056145071983337, 0.09611050917633943, 0.08890024000512702, 0.11817114826823984, 0.16320264046745642, 0.13349814154207706, 0.1288030863340412, 0.20698843736733707, 0.21989835319774492, 0.07704047925238099, 0.14459814663444245, 0.12162915271307741, 0.05644056999257632, 0.10947173900370087, 0.08375150271292243, 0.18038215647850717, 0.11556824722460338, 0.1306362843939236, 0.15107846818864346, 0.07640015254063265, 0.18678842272077287, 0.12176903949252196, 0.146515835874847, 0.10718204972467252, 0.14035297371447086, 0.12005412365709033, 0.1038015271936144, 0.11462228798440524, 0.1296089416635888, 0.11298032823417868, 0.10529362569962229, 0.18047465437224933, 0.10050742966788155, 0.15110453750405992, 0.0950177488848567, 0.11400655816708292, 0.10365200521690504, 0.16134972417993204, 0.08923007587769202, 0.14444462130112307, 0.13851353313241685, 0.0984839703887701, 0.12814783863723278, 0.15036367225859845, 0.17640655195074423, 0.1817191554499524, 0.098919684865645, 0.07736980622368199, 0.10808667939688478, 0.11248476696865899, 0.1900286309953247, 0.09359682191695486, 0.11820629638220582, 0.10158553360296146, 0.16144114998834475, 0.16410074941813946, 0.13072790019214153, 0.1104618301615119, 0.0745008990966848, 0.14167870900460652, 0.10982506575861148, 0.19924728918288434, 0.0839391787137304, 0.07922840184931244, 0.15212867754910672, 0.12927020341157913, 0.19496605891202176, 0.09566325281879731, 0.1543614241693701, 0.24775764399341174, 0.065103982974376, 0.13092223262148245, 0.15563602506050042, 0.14421846557940754, 0.09513985804681267, 0.08533801258142505], [0.07209924475422927, 0.02235607323901994, 0.03797445659126554, 0.009742023273637252, 0.02320424370866801, 0.02384267052236412, 0.021438602291579758, 0.04568282135629228, 0.07566274103841611, 0.023290241236931512, 0.020456217595243027, 0.013588669676599758, 0.01715725497342646, 0.031712904905102084, 0.005203981068916619, 0.039834673915590556, 0.021679984339113747, 0.01905181974039546, 0.03375383985361882, 0.00979156481168632, 0.04502304783090949, 0.031127546315214465, 0.031008551628994088, 0.10131929681769439, 0.051987687325371165, 0.026486619541953717, 0.08688851938183818, 0.011937991599552333, 0.015744533190237622, 0.03182798444426485, 0.011014439282007515, 0.047102910333446095, 0.04038941361276167, 0.04724765881629927, 0.00547055881803057, 0.04749643689553652, 0.10010097362101078, 0.011195308728409665, 0.04014331913952317, 0.04384578278820429, 0.06594386683510882, 0.0675441984619413, 0.0351788685657084, 0.05455098567264421, 0.018825246719643474, 0.04441406265167253, 0.027197164450106875, 0.02269767321247075, 0.026704420801252127, 0.02184491414975907, 0.0573819898334997, 0.03732273727655411, 0.037391706968524625, 0.04066900396719575, 0.014360513438337615, 0.038483944788042984, 0.019030856400994316, 0.04664001035104905, 0.05149046704173088, 0.02845796393895788, 0.01351745573005506, 0.03623287432960101, 0.024091882864013314, 0.012848400693785931, 0.038759457147014995, 0.046928520048303266, 0.018401347233780792, 0.015671889231141125, 0.004786905524919608, 0.08246639131435327, 0.04757750825956464, 0.03550274011545947, 0.025001798324020844, 0.012576325962852155, 0.016288121164377247, 0.06851972147290196, 0.03825593666572656, 0.031754265007163794, 0.05003576260060072, 0.05562140180596283, 0.037988271564245224, 0.02027395460754633, 0.022184585387419378, 0.024542489488209997, 0.03444001856925232, 0.036651130100446086, 0.034551179568682394, 0.029978392978331873, 0.014173324286405529, 0.024836420680263212, 0.07765401740159307, 0.05940304031329496, 0.020331250104521, 0.004082492452913097, 0.030139592542712177, 0.03611587453633547, 0.03788733948022127, 0.01598456664942205, 0.05250558257102966, 0.05904484846230064, 0.058801586872764995, 0.012887749787686127, 0.03834017339561667, 0.045207490612353594, 0.025524071816887175, 0.024315081869385073, 0.011245834990404546, 0.02186289193507816, 0.027866669863994633, 0.029171421458678584, 0.014965359553960817, 0.07403181426759277, 0.0401722688360938, 0.0186624000115054, 0.05236274755692907, 0.07577140163630247, 0.01393243672126638, 0.03565446054562926, 0.023487431995038475, 0.04229609022981354, 0.04475036157029016, 0.02161976944522134, 0.02563949062355927, 0.06262340822390147, 0.08191692722695214, 0.08720339355724198, 0.023042998343173946, 0.024834252760878632, 0.06298031085836035, 0.021944027759933045, 0.051726339384913445, 0.032634708298636336, 0.040093850543988604, 0.009456064019884382, 0.043113117638443194, 0.04940339849729623, 0.05636502190360001, 0.04977829248777457, 0.0728244629821607, 0.013575510338081844, 0.025016524230263064, 0.02117215346411935, 0.011681683477945626, 0.062460790521332195, 0.036606194118836095, 0.018944753699802926, 0.028713244080011333, 0.08308398710297686, 0.023326252786708728, 0.007426240082298006, 0.056408641527273824, 0.05323356922183718, 0.0676095617402877, 0.005707644466643355, 0.03603556652420333, 0.03865817901013153, 0.03543963296605008, 0.040211389772593975, 0.03891720636082547, 0.04006708912285311, 0.06123446061142853, 0.040616298759622235, 0.017927261601601328, 0.033938431912767034, 0.026396898552775383, 0.03444556559302977, 0.017147278812314783, 0.013334167306311429, 0.02477890974842012, 0.023181168429021324, 0.027803998673334718, 0.04923131183854171, 0.028480425144412687, 0.012907892947883477, 0.06991157321525471, 0.021501448205006973, 0.037583684881350825, 0.030568362213671207, 0.05838142441851752, 0.021439828743625964, 0.05204546118953398, 0.06179511374128716, 0.020341811502086263, 0.023947483826694742, 0.05759298029754843, 0.04951996063547475, 0.02183571151856865, 0.026319835634369935, 0.051250808473144255, 0.04509299122063177, 0.010985233438467341, 0.04793485872713583, 0.04944752023688384, 0.024368982994928956, 0.016147701734943048, 0.07810739414500338, 0.03546486768339362, 0.08275903668254614, 0.06341485146965299, 0.01926312572322786, 0.014998436439782381, 0.07757707153047834, 0.021047706749024134, 0.026361875967787843, 0.048711706684636216, 0.059255899994501045, 0.05640279255541308, 0.034283663744905164, 0.02761610723765833, 0.023607858390148197, 0.04701375422467079, 0.016318276956943528, 0.05181429109403065, 0.07045142246144158, 0.02825448994657823, 0.02669222922330456, 0.031127580241965394, 0.02653732816023486, 0.03775227029940911, 0.038512158274118385, 0.03584124427288771, 0.06032542724694524, 0.05830517065312181, 0.022854204455922757, 0.057995514412011416, 0.04396071644233806, 0.04815455140279872, 0.06502499471285514, 0.02156803454272449, 0.0376348532071071, 0.032120548388255496, 0.03157249904636826, 0.04998465873567121, 0.04863187703969223, 0.037503244554890056, 0.08081999394510474, 0.03285611427522131, 0.061620370617934635, 0.03893771847443921, 0.01235275630772646, 0.027015420541699444, 0.011165253867927407, 0.026233356346243193, 0.06423321898494448, 0.010538785385766199, 0.04327748596136059, 0.0817348084279469, 0.030569739639759064, 0.021268195006996393, 0.05161509696128113, 0.04035347839817405, 0.03553010882543666, 0.053738473914563656, 0.016416055549468313, 0.017756002755569558, 0.006492020770175648, 0.06325064599514008, 0.01915431924031249, 0.032850346727562804, 0.07252615184656211, 0.009040978703913944, 0.06469022589070456, 0.0665307521287884, 0.02241150615736842, 0.021201449213549495, 0.1401305499353579, 0.030729154657040323, 0.08863505494913884, 0.05501656247568982, 0.020633783424273133, 0.02770593000708946, 0.028884950759155408, 0.038445451496435065, 0.010417972225695848, 0.06801768019795418, 0.029547133083854402, 0.024772226178486432, 0.016599295627591864, 0.04438446495415909, 0.015047474165580102, 0.037546121182718446, 0.05128983102206673, 0.03608444140159658, 0.07303831686398812, 0.0885445587337017, 0.026851761287876537, 0.012111878920612591, 0.04442174706075873, 0.07442463176058871, 0.023921372102839605, 0.03216593559565289, 0.05236108175345829, 0.006092738110705146, 0.047882173875612874, 0.02174824326565223, 0.036753890836345296, 0.05715752366398062, 0.021455526651282395, 0.0239153501045491, 0.02245006221346557, 0.021439628575795462, 0.03513696563563176, 0.035100979530917745, 0.0816901268969689, 0.054069537935512405, 0.02450387066762362, 0.026592398062348366, 0.04342114878818393, 0.05076760672298925, 0.019584988809323738, 0.014831043547019362, 0.018099287192204168, 0.017075508467054794, 0.05349754648549216, 0.01702740542324526, 0.06747183270220246, 0.061024420096405914, 0.012307388608210852, 0.036910639211003266, 0.07046185154467821, 0.052682035602629185, 0.007644919196276793, 0.05432395803342972, 0.08745259911354099, 0.00853213426723544, 0.06492273270019464, 0.02763544039667717, 0.03411326663834708, 0.0597330051075135, 0.013071153562382927, 0.034413626949701986, 0.014536952899236764, 0.006031152151990682, 0.05412859083818538, 0.022936336030917506, 0.05950865428894758, 0.02341694916997637, 0.04082541985969458, 0.048234306408890655, 0.04054885916411877, 0.05422575705285583, 0.01336907284400825, 0.025336531523082937, 0.025836464250460267, 0.011480381645794426, 0.0424507860360401, 0.009009780511925263, 0.030120240723980323, 0.025162914767861366, 0.06931296283645288, 0.05521483040813889, 0.04465008766523429, 0.1986412624163287, 0.10263986167098794, 0.12388164470238344, 0.0897489787478532, 0.21792454911129816, 0.17149193638137408, 0.18242823811514036, 0.08842580832008805, 0.12968005213354314, 0.13819394313863345, 0.09358229448220559, 0.11872091091104917, 0.0916147261325802, 0.14104697933154448, 0.12178562288837773, 0.1222543413085597, 0.21099566162696906, 0.11223170054810387, 0.08354198466986418, 0.14417072385549545, 0.12014856216098581, 0.1809415000357798, 0.1826213898935488, 0.14196369371243886, 0.10260507318058185, 0.12737216454531464, 0.1782501180257116, 0.13645605210747036, 0.09388116880186967, 0.11327482600297246, 0.06726134435406753, 0.08536065529499735, 0.09717154117035014, 0.1021155169499772, 0.0853668028222663, 0.09242366879646267, 0.23365548785243714, 0.1642517370304891, 0.18845977660800728, 0.13106951543263026, 0.11741173187536852, 0.0919078193338854, 0.1283876057714224, 0.11032966511057955, 0.1850322519562074, 0.10297369411481277, 0.13784784956702165, 0.13717938400804996, 0.16094933423612798, 0.0609047943726182, 0.2378087192773819, 0.10345702139394623, 0.09745120616363627, 0.1528596497539963, 0.07284046283790044, 0.12563297072691576, 0.13159008749893733, 0.2027894455407347, 0.14103758840688638, 0.15124811551400594, 0.09971877520105668, 0.12205494700797967, 0.10188539179840259, 0.09620783823941435, 0.13436016600046838, 0.1554020797567708, 0.13083867781928607, 0.10855801017688853, 0.08435296972415277, 0.15825586233820232, 0.16334925831428596, 0.10135605305965457, 0.12373664176889829, 0.16713852355522768, 0.21335610853774206, 0.14888435735234193, 0.11244938136743647, 0.06720571805323873, 0.15975375553326948, 0.11214277853391, 0.21885597413139685, 0.10024799858885151, 0.10541279680494751, 0.13479129358061723, 0.1540838083518403, 0.10553143865295819, 0.20405346128557408, 0.1904428494828088, 0.09679690841585398, 0.1583865617534944, 0.15574535062270506, 0.23033422178455762, 0.1912717478615897, 0.1912193785288504, 0.0761334000687514, 0.11827223641531807, 0.1217925168041672, 0.10032312598611627, 0.2901385341371809, 0.12704967042165144, 0.1747523242873805, 0.1259769472692694, 0.1279460694640875, 0.08606614172458649, 0.0809874360316566, 0.19789458891110762, 0.12473134696483612, 0.15995325839945249, 0.24937581430588449, 0.11814009850578648, 0.10646443787430014, 0.2145477110253913, 0.21783319115638733, 0.1653280971305711, 0.15348033287695476, 0.1534956813390766, 0.1167020792407649, 0.09455341380089521, 0.09507544471749238, 0.09009155072271824, 0.11819135504109518, 0.11325258362506117, 0.08398637760962759, 0.1783681966896568, 0.11157985909708909, 0.17907333028103622, 0.10421121985252414, 0.2020739982170718, 0.24179595389536448, 0.1387381146528891, 0.08988250765417304, 0.1302754801831075, 0.1663056353905371, 0.08230330542262111, 0.0876452759174364, 0.22006249081875595, 0.13214297140283243, 0.1753948155258383, 0.09738588359739099, 0.1329285656767232, 0.12264268047043256, 0.08322229968117816, 0.1087377066058772, 0.1221091483852693, 0.1472994623971837, 0.05480234218495233, 0.13349325608994278, 0.23213011398911476, 0.09632992704531976, 0.13417559090469564, 0.12947362821016992, 0.11005458701401949, 0.24003119287746294, 0.16011256485113076, 0.19357297223593506, 0.12545963217105183, 0.15433407920811856, 0.155286416677492, 0.0975594324991107, 0.14663095612611088, 0.12121475780648844, 0.12077453785708972, 0.08616586601627724, 0.20342327867235455, 0.09425899067095347, 0.13563369480626924, 0.09686390017824513, 0.1139140467026404, 0.10663567975695644, 0.07299990499658243, 0.10569151863455772, 0.12474729253777436, 0.14454950924430574, 0.10200378258845635, 0.1240661655153547, 0.09921697819871561], [0.026917745425765003, 0.05187622777053288, 0.03773114750427859, 0.05014472853924547, 0.05280542041042021, 0.03221936005034617, 0.007788479394678558, 0.04096601910090872, 0.031726638453879526, 0.08092737211180584, 0.016224153971831714, 0.026135033229365945, 0.034427560666309934, 0.03869552557755794, 0.03279365512675472, 0.0425291025478925, 0.06300417493496623, 0.011075244501366146, 0.03696212644821831, 0.03615779442978757, 0.01699076622857579, 0.03535973886027932, 0.03800459372411881, 0.009821524677265967, 0.013832303612226886, 0.05347188768376197, 0.04396269776459251, 0.03318770416080952, 0.047410724351980855, 0.007538365449623338, 0.01435893923709435, 0.03479318247575845, 0.07453572829919201, 0.08101398710693632, 0.052643104655934234, 0.017340055700125437, 0.06800559548927204, 0.07222889922559261, 0.04076353746599384, 0.03450606038261737, 0.06405683380684682, 0.05053920505036201, 0.011625231908900397, 0.059971428742366176, 0.009765495496269847, 0.07102682694260563, 0.029886027398918356, 0.006919360428582877, 0.018572955525347164, 0.037629292612629275, 0.01700896962678858, 0.026157117847885405, 0.017080473647053753, 0.004216791496479085, 0.019278304551595023, 0.039537316121693165, 0.07050872474376645, 0.0259789481226887, 0.019330746826848814, 0.014036489218207342, 0.019224340661561916, 0.02899930426584823, 0.04202062197561775, 0.009645161551556416, 0.10627592049006905, 0.011036921691681658, 0.046930497977882624, 0.057756208681634495, 0.022009156943698014, 0.025228842926610793, 0.052581015309052806, 0.03939288315762367, 0.042380496593458314, 0.0675138815173081, 0.03203824209049344, 0.03584351057984999, 0.03696172271988221, 0.035464881254093986, 0.016444408135222535, 0.04458910772310836, 0.0245210511742958, 0.0337203677211489, 0.0447541545810444, 0.06306484953633376, 0.03384694503620267, 0.05913586036435195, 0.025474352163395712, 0.031090155643011843, 0.022618148908285157, 0.05541812289240105, 0.0711917584495885, 0.03551740664988756, 0.06266954860516957, 0.02087408660112747, 0.022809302401063696, 0.007571025884577206, 0.072360338244055, 0.013134947728498705, 0.02932556765154004, 0.07460624165832996, 0.03085596945935062, 0.047583095995443206, 0.03836268040218523, 0.07575631780283791, 0.056583469467503686, 0.013030192099644669, 0.076847089986716, 0.024356564107750143, 0.02546743449888059, 0.05528941158471363, 0.014176080834918788, 0.02496169351174363, 0.04534105683809944, 0.024245757642867308, 0.019230505152206336, 0.031202558361526047, 0.04644490439178688, 0.021952467039227486, 0.03440464314605508, 0.04374749020540288, 0.08128901092069489, 0.044079860406262536, 0.021740092363740717, 0.03479598143271037, 0.02560537727549672, 0.01723193284124136, 0.023435507102736404, 0.017286892481414334, 0.04781697005299585, 0.02484092615278704, 0.05514025940958943, 0.013488205781738673, 0.04372838265927775, 0.03517598139920405, 0.05640713178685733, 0.0027665378209868713, 0.02381161058188549, 0.00976154302978622, 0.03141902460317526, 0.03281034030286329, 0.05981111127351012, 0.019566649704107215, 0.005190138954536191, 0.05343134182372263, 0.009666462462129337, 0.0686373794451356, 0.013189899735152721, 0.06832477157669407, 0.03989158943295479, 0.018337179873404757, 0.05291794865791287, 0.03015302075073123, 0.030674105110977377, 0.02396099006624094, 0.050411979734365425, 0.023621708986216357, 0.031998476545725546, 0.053334555588662624, 0.02879420348576137, 0.02543012016186757, 0.018122408272964612, 0.029258453752845526, 0.017100409005901644, 0.08154924945639712, 0.04512494682733502, 0.062372357052351744, 0.011531943521861519, 0.05275421476523791, 0.037016826548746655, 0.019350246226947223, 0.03779155069163867, 0.023114512541464398, 0.026093966593699794, 0.037393243850341866, 0.08162781702620642, 0.03447027105305876, 0.02031980830776904, 0.060270879816796095, 0.0787181570859892, 0.05943024956754275, 0.02823710418306291, 0.03709079025845442, 0.036954116342323165, 0.04384757751332862, 0.012242351026673402, 0.048999147689236064, 0.005403896145123456, 0.07503630393849951, 0.0069429492744218025, 0.022257656823577623, 0.03824778746015259, 0.07838264187531811, 0.040813464072666, 0.01632947617742632, 0.018273713100435476, 0.016256633746836866, 0.010213714525369661, 0.04254065799926009, 0.02334001856589956, 0.02005674028103905, 0.04945872624271682, 0.014728571188503077, 0.058496802513088496, 0.03683342192588108, 0.05552222712763718, 0.0267470056590225, 0.03196301969832607, 0.01339278425023492, 0.03619041160813399, 0.026668426214850376, 0.06612211119915758, 0.05455783887633255, 0.022932456506948386, 0.03898455435410142, 0.04059891469244446, 0.02700142575693982, 0.09256148604410035, 0.032716118930173774, 0.02728687526125993, 0.04471772742856826, 0.0600361813391958, 0.1163411121815443, 0.07159123915646758, 0.02050249368351485, 0.0323733671435288, 0.10778135899454355, 0.006833893429887081, 0.019458523452548043, 0.022607903029503565, 0.08064670288669211, 0.020374223423589553, 0.0595440398901701, 0.08144597642655883, 0.014830188592895865, 0.040415333650474033, 0.013849672412366738, 0.014845282604385699, 0.012909507013059087, 0.07879206312022038, 0.007837402617691882, 0.044447385506438356, 0.0316030025881316, 0.05133848198290382, 0.04180672398901411, 0.034866518540573974, 0.0031838881716664347, 0.03137350847412433, 0.031875587068498135, 0.011974329694307275, 0.022489770082756877, 0.038182125626397986, 0.04289408653442349, 0.07968219928443432, 0.022364790717672025, 0.0187223926851792, 0.05002759303897619, 0.015837940320904766, 0.08024703219000782, 0.04810919812215226, 0.02231701337067144, 0.01856536611116358, 0.04077866879690971, 0.020988682684089457, 0.04371849979673113, 0.031498552300035954, 0.03972705826163292, 0.04506794649309345, 0.03982229404417532, 0.08793230301567487, 0.0418310800035085, 0.049859716690012386, 0.0456947601799454, 0.011908303147980144, 0.050909308583608696, 0.021377846266009977, 0.030583544434713464, 0.10077598025756222, 0.026759212504007986, 0.037014804514391084, 0.010925387497991323, 0.0490839204617909, 0.01555320158201669, 0.04686396422662905, 0.06940786952951125, 0.027109007484146526, 0.0713053655677608, 0.028980196719723086, 0.03966248547658324, 0.04194586777261325, 0.04066416261983769, 0.02851378871127963, 0.10448584333062172, 0.021802146087533662, 0.04903222627139517, 0.01986235356889665, 0.03155427698844245, 0.02880920928769878, 0.018164979560034614, 0.046055001206696033, 0.03971062075080616, 0.02623014517926744, 0.0030140135370727095, 0.004433496497637991, 0.024470162744234716, 0.049573598828698905, 0.029298887654606785, 0.03508588891210301, 0.006408980806424681, 0.0729676406564457, 0.06661706178316049, 0.03739750844293407, 0.05251982841374619, 0.039978574229670424, 0.01241067860142461, 0.03223323269880243, 0.02646570878901652, 0.02267612294027848, 0.024570959121254937, 0.030025812398110117, 0.026996307906561663, 0.0150802830300693, 0.0759488046169281, 0.03671617786000882, 0.04258024373224803, 0.03271281107195786, 0.06430217849888972, 0.05377520980047328, 0.004192405371993248, 0.07118164149246045, 0.031435173736619096, 0.0918660012206861, 0.021117941908804432, 0.009370990147415017, 0.03532709114785705, 0.015207886629338776, 0.04561729183686631, 0.0387666326548372, 0.02002752765214869, 0.05329981120303273, 0.025593787897378206, 0.010447764153858381, 0.08626204835517065, 0.05218879831954837, 0.0491977311404688, 0.04695171576791576, 0.05026954844860094, 0.02434105279722384, 0.026673330326697657, 0.01093020340028618, 0.005514070724270174, 0.08982058454837118, 0.0526598882196205, 0.11119119423840727, 0.15259522465722902, 0.1431041753717831, 0.13155179098248482, 0.1664316936263016, 0.09536553200866495, 0.20632572578532354, 0.0933892580547503, 0.10483528886522565, 0.14651943211044582, 0.1602785209459918, 0.11725181474217347, 0.12857447431555816, 0.1386958012091262, 0.0835024125075766, 0.22934079223445483, 0.09688163029828242, 0.13207750634423324, 0.12010605872741767, 0.10151337140372821, 0.11019186821899243, 0.13137077141020978, 0.11821241676807404, 0.06421217082866601, 0.11851364560425282, 0.14367803957845482, 0.2256460062095097, 0.18514161823051317, 0.1523285468241998, 0.12324811012617179, 0.08040870672890119, 0.08560775739273854, 0.11830704526177474, 0.16367853778813565, 0.14826769115669386, 0.16850668085472925, 0.11714974950466837, 0.12803042493760586, 0.1400415397116116, 0.10598321405372449, 0.16191095406455652, 0.08033336220043046, 0.08777138165065221, 0.11922137119940349, 0.19118526178811276, 0.18775270240647451, 0.12495484282927853, 0.18153763376176357, 0.14486266672611237, 0.2618250862828323, 0.06608180621904985, 0.11577805025236947, 0.10416042472102813, 0.1393940273140158, 0.14750941470265388, 0.14942117354699544, 0.17774234312985623, 0.15213610072221073, 0.17465883573251112, 0.08991960316364254, 0.07951720670929976, 0.20010817370244435, 0.16668405437043735, 0.19337839553398745, 0.25527830900890486, 0.10617427594427552, 0.0842617814029966, 0.12522245704063348, 0.15640708511429174, 0.08607770396130425, 0.16226873200918945, 0.12425082203532968, 0.10094104068619864, 0.20412492459373816, 0.17028626107743808, 0.12235932424664497, 0.1205449216067791, 0.142995487632496, 0.1123049823301179, 0.11820827770446028, 0.10216443932482175, 0.14669487412486756, 0.11944524704345635, 0.13750027678906918, 0.07300844096711703, 0.10211347455957107, 0.15708616296095507, 0.12486917099782399, 0.12390970891075474, 0.1043796661709036, 0.14838540341172898, 0.1720494750354971, 0.13730736928326742, 0.07914661802351475, 0.11959615323160376, 0.1073196701971548, 0.16605355963110924, 0.10921356999980551, 0.1356908953083413, 0.07898770512214728, 0.20381412841379642, 0.1566585094801017, 0.10459369647183589, 0.12178106313305241, 0.1540024791445051, 0.07935195629085813, 0.11244176141917706, 0.179298766755632, 0.05461775351847921, 0.12934226383055958, 0.12118844421846525, 0.1301815573658262, 0.16437126775937422, 0.13618462452931063, 0.14008834505719797, 0.1260416116565466, 0.0890662232413888, 0.12769777993006365, 0.14294431252138956, 0.161480165751917, 0.10961244681051799, 0.10762946214526892, 0.07464990538677999, 0.0850756298750639, 0.08681344626737492, 0.10473190048443419, 0.1024381196392434, 0.04650677660746234, 0.1447276518281017, 0.04348253585132105, 0.07707608198480946, 0.14637098221906594, 0.13544320288513387, 0.20339967922440597, 0.19785395823419094, 0.10851554745542151, 0.13113479050142424, 0.13269083414758953, 0.0679997940148626, 0.0714846480903881, 0.20036395426307405, 0.08293600540075984, 0.09869907277503184, 0.1180319535945143, 0.08470766711980104, 0.17049026941614492, 0.08437674559120621, 0.20109194091388158, 0.12599746616823332, 0.12774976928319248, 0.11747372283467225, 0.1108933784333723, 0.23429930901953153, 0.07057294808328152, 0.29632395080157686, 0.19496405044836657, 0.04548421076365879, 0.141627058918987, 0.10524873382278851, 0.12818621657788754, 0.081200998143426, 0.08902893774211407, 0.2169472686946392, 0.1424997906599726, 0.09182311780750751, 0.2270696269614356, 0.10594697349837848, 0.11589718743094377, 0.1534796000591346, 0.08747278553034578, 0.20276797669274466, 0.08839403931051493, 0.09680216027689831, 0.10589247356568064, 0.1906050600643669, 0.13298947097999708], [0.07585370793406453, 0.03956159410466041, 0.016490119343091334, 0.05224281309970787, 0.02473601615721626, 0.03818426301170673, 0.058922291467232366, 0.047691003419458866, 0.04706868163443037, 0.04600551225511091, 0.04091856575437954, 0.017087208107113838, 0.016662451970790113, 0.02921281548749123, 0.0743165004200169, 0.020210981468803117, 0.07785335063402142, 0.03615328556458865, 0.06878816349697964, 0.048059502217386446, 0.03324229230305978, 0.07414147909730673, 0.018389257436086024, 0.03931047168693372, 0.03689178950818522, 0.0038554813529896948, 0.04922096078683223, 0.010579746000335684, 0.032337886547403674, 0.05339386633464268, 0.07003280706703663, 0.02317671215028635, 0.015128706681675144, 0.041055494121142795, 0.024304839383278574, 0.028388244465791752, 0.06109549663960934, 0.007694867855337049, 0.007856861305689173, 0.04787958865719182, 0.020679146882944872, 0.012248498553942357, 0.027772709727287292, 0.028474467606948953, 0.02789837950175362, 0.02970857352816633, 0.05771204962262085, 0.015275952173396945, 0.02942083396815828, 0.029404644122613326, 0.03131081523107631, 0.06282770833266632, 0.04278675925784877, 0.00836914761124977, 0.04598545136728457, 0.058750174274402, 0.03444627466212426, 0.008876224464204694, 0.0017183530393854848, 0.026013755272807818, 0.04352865248386349, 0.026997955050319433, 0.06820031468357358, 0.005116684994261179, 0.045332327485084534, 0.0750310927895563, 0.07134578589882169, 0.03162628312462142, 0.007648666405917278, 0.06670098977961711, 0.006702913694815444, 0.06145845180643456, 0.0100851380765172, 0.09498656341539961, 0.026372764758499603, 0.011600057411539768, 0.06876068961407457, 0.023750849467303072, 0.012476842551093017, 0.016160095177058662, 0.05917819416416543, 0.021811301221272776, 0.028750604218138114, 0.05165971742410745, 0.03179590330858316, 0.0023135164602925734, 0.015223626945433872, 0.04317314763154302, 0.027774494274386337, 0.04326204928968634, 0.06946051706160818, 0.06239952559449843, 0.040803801734000444, 0.021777354114289795, 0.006101140494657946, 0.033550231850572994, 0.025573024725807563, 0.012768316598209952, 0.00935471209231764, 0.029510142747312784, 0.007309821284642177, 0.02665154087091131, 0.03546359543023365, 0.021226466799687062, 0.030782945520643677, 0.04685953678563237, 0.014046099818577724, 0.026310548186302185, 0.03281478809991053, 0.01790549759087818, 0.062159337768597264, 0.02851349694122161, 0.047012885699846914, 0.020543441575552737, 0.0678014446582113, 0.04624811566567846, 0.013439224883248764, 0.05028927006891795, 0.08410487017993416, 0.061600055279476304, 0.03940670152327844, 0.05254090031875031, 0.038545535411685705, 0.03600795693429453, 0.015580926522878664, 0.004897700963608388, 0.020002337039581368, 0.01381249463052622, 0.07285209292812006, 0.062032607783164294, 0.03245486259194357, 0.02692814906393843, 0.045708351236368926, 0.022429504298738072, 0.0943222369200417, 0.0170013547675418, 0.027942172151857188, 0.017085577926731536, 0.04135720132450972, 0.032018249056168964, 0.010056927134948117, 0.009393871196412613, 0.044842550730598826, 0.055316661551062546, 0.0238409996298807, 0.025166187002988796, 0.017320183105766773, 0.04509802595047014, 0.02209753273720188, 0.047364085247474055, 0.025742468490664448, 0.00867047144233116, 0.027794733277655075, 0.03845640644431114, 0.029985083333615745, 0.019102406222373247, 0.044355026712375026, 0.02647818874434701, 0.029144463262387683, 0.018186280470607535, 0.026217979046383073, 0.07657002378255129, 0.03321334599916424, 0.04719819700611489, 0.022598700398313146, 0.0031437757258702603, 0.043887376984847445, 0.043856561316975524, 0.0374155676524554, 0.019514166716752306, 0.07366835698485374, 0.02896214768822704, 0.026086843672341535, 0.015687510803607956, 0.027156840810286145, 0.06993193605116435, 0.025338253305692757, 0.045567857168082676, 0.04090236233813422, 0.07631316435124193, 0.039682787244341204, 0.014391736227220722, 0.015739050627286946, 0.008935412225712622, 0.018081292443509613, 0.024254721090463654, 0.033742772947464666, 0.02078234527393111, 0.0445109710230359, 0.060420184662299495, 0.035061227556850226, 0.039497733781380315, 0.05030839118574347, 0.02626088451194976, 0.01989542366936803, 0.03149723933477487, 0.03735413648454206, 0.03681390047339456, 0.03764481070850577, 0.009797936255511428, 0.011314349215743797, 0.03899254071127091, 0.07396532462111541, 0.036024638717728, 0.05106401117518544, 0.03262547682970762, 0.09625296760350466, 0.04297813666718347, 0.036501299390303235, 0.03208446050328868, 0.0070157140975684994, 0.04649139761126467, 0.022770001652783582, 0.03485844736652715, 0.029780447350016663, 0.050623265361147265, 0.02716898319444486, 0.04220046428963542, 0.03677157685160637, 0.01971800033269184, 0.02779798854940704, 0.06810999488724129, 0.05000115052929946, 0.032482065060841184, 0.05493773027722325, 0.03329824430069753, 0.05054517276585102, 0.010630740451493433, 0.014563510759866663, 0.00559749363622229, 0.013370867569132574, 0.029289961526436464, 0.010802084962571306, 0.03650843757869942, 0.016157438712460653, 0.018957832462287376, 0.032588873258126635, 0.027420799414228116, 0.004594281731572534, 0.014535424499107259, 0.029945066730890955, 0.010649367085924106, 0.06045464745589665, 0.04612445605120488, 0.03533324885315128, 0.03295613033697009, 0.027019590139389038, 0.05487747297489217, 0.01585635236863579, 0.0267353840504906, 0.010113217551926417, 0.03979285580239125, 0.03540956707937377, 0.035015056641506295, 0.018411515081035237, 0.0184191146732441, 0.039023071394435, 0.01626132072747818, 0.0979293290791767, 0.040621292777359486, 0.026746132045185993, 0.019797293934971094, 0.028941211490226642, 0.045696921313979795, 0.014490303616704685, 0.052263827329235416, 0.059679292275437286, 0.02771107160619327, 0.05855392837630851, 0.03672164006690894, 0.08262467996350356, 0.023647997129176344, 0.019537844196228043, 0.05078438689400043, 0.055005034165722985, 0.046209239001785, 0.059369812453431745, 0.04734632120068584, 0.03327733185142279, 0.03528690830405269, 0.020996007469615767, 0.035284221305378845, 0.02648480615711638, 0.14269486947783402, 0.020172684952350597, 0.021264011838606427, 0.04147767860974584, 0.024430069806320325, 0.06754027652953352, 0.06869097014090844, 0.06719389118786369, 0.020139341741534214, 0.028591284195759466, 0.06452937237918377, 0.04354950047231146, 0.016462974549670304, 0.033040716512394805, 0.020828087015875747, 0.07647828584803001, 0.01250199499606554, 0.05574262208704438, 0.010820128905054714, 0.015411397941144449, 0.04840622343389051, 0.04044216971046158, 0.04323295710076179, 0.020141479126842957, 0.01749005095501031, 0.018298969870167117, 0.01150697682585035, 0.05658510812957372, 0.041000882230166874, 0.01335567601823381, 0.051222635699169974, 0.06647589257253067, 0.03093358708013381, 0.0072093031069796, 0.007684116467966565, 0.02445687024321939, 0.042363227877233706, 0.01971801051071712, 0.03762992365019662, 0.027896951185539365, 0.01229677886502551, 0.015654289729094932, 0.003751314353264336, 0.014274660098765577, 0.040271738677152565, 0.019455495490027324, 0.08532203986708607, 0.07172769933406796, 0.0298072868026793, 0.031504143428589614, 0.03567854853879128, 0.10155464668891259, 0.04960161214694381, 0.0944676266184875, 0.06639001039522034, 0.04105065955913492, 0.03378115088811942, 0.04280779045075178, 0.03600843530148268, 0.02369752509652504, 0.03189649273242269, 0.05648252720545445, 0.05285376263782382, 0.03577993863395282, 0.025104136671870947, 0.04540282388084701, 0.01597541830103312, 0.014438953782830919, 0.06144779880664178, 0.14618606785578386, 0.11468510675643172, 0.13101245063756192, 0.17206080657030853, 0.17442330265683786, 0.1491173119949443, 0.1517912285136325, 0.1386321410536766, 0.13467316063387053, 0.10226380399295262, 0.09519073460251093, 0.06337240910423653, 0.11974909502480711, 0.15772271023264953, 0.16092303421880516, 0.12223345600068569, 0.14372884828065122, 0.15107373201421329, 0.08040592473532472, 0.09423581870006663, 0.1620535007012742, 0.15823081082531384, 0.11256534978747368, 0.08077291040016071, 0.12881379361663545, 0.18753212424261229, 0.15246493236294814, 0.09675595882747855, 0.10247062146663666, 0.10344007837453059, 0.10546414833515882, 0.13997284482632363, 0.1332192500787122, 0.19444309840244905, 0.08996071560042244, 0.1488017796405724, 0.13259944905127796, 0.07250371269349541, 0.06513170791523797, 0.18231982178986073, 0.10439558460244111, 0.15013394744268485, 0.12383178594921317, 0.1569909237857376, 0.13462696596980095, 0.1327944871570383, 0.10159702120082718, 0.11625530464308602, 0.13863267031099114, 0.1088918765474643, 0.11339069942810706, 0.09187186376324721, 0.13474955010626996, 0.12809635140001774, 0.09669324862105505, 0.11275056949151413, 0.06424632828150477, 0.14957659877836704, 0.11036035524947302, 0.13741782121360302, 0.12908399983176164, 0.16679057079766477, 0.19474425938512596, 0.0971950524087463, 0.1311228618557964, 0.15779373927840165, 0.11718427336641721, 0.0767996943156634, 0.09972497701112713, 0.13032459254775727, 0.11929202026554517, 0.16533865513546125, 0.09213945083320141, 0.13183495721646718, 0.11115862455751215, 0.06413895011480365, 0.12122615719480173, 0.07433725002088717, 0.0939340606065733, 0.0986352836979287, 0.09705361856945924, 0.1776870968086379, 0.1469798588326999, 0.12931661520685467, 0.08152790274471045, 0.08284492564520665, 0.10504137352108955, 0.10738070442208222, 0.1028586688584515, 0.12630960584751197, 0.16438509630305426, 0.1553285401314497, 0.16820736548730306, 0.1077357003731387, 0.0961595740435379, 0.08090531293834959, 0.18894393848521368, 0.12148834312600748, 0.09153368190995284, 0.11090608060892139, 0.162884651816317, 0.12903384252318315, 0.10510493868163653, 0.11057259421795607, 0.07150415597217423, 0.10129128689212458, 0.15354465799672262, 0.16977375000715256, 0.10413541392024074, 0.07702379407627241, 0.12631183144237312, 0.08122458402067423, 0.1319299385483776, 0.1359926126897335, 0.15250298460679396, 0.08816836534866265, 0.09228370059281588, 0.1519918441772461, 0.13124184975666658, 0.13967730211360113, 0.0854274977796844, 0.10525439280484404, 0.12376176113528864, 0.11867285706102848, 0.136547803612692, 0.09118095226585865, 0.08925495097147566, 0.07628615187214953, 0.14575213114065783, 0.1338425116347415, 0.12019904516637325, 0.1142140541757856, 0.11794067706380572, 0.05531388973551137, 0.1890802290290594, 0.10424735184226717, 0.0811483913234302, 0.11127860311950956, 0.08786023581134421, 0.07012550852128438, 0.19504650602383272, 0.16597859508224896, 0.12931210973433085, 0.0802450847945043, 0.10841151446636234, 0.2428675235382148, 0.12168456188270024, 0.08818106752421175, 0.10813748809908118, 0.10248115911547627, 0.06737710242824894, 0.1132795282506517, 0.0902899204354201, 0.14174975162105902, 0.14286860158400877, 0.14708385110965796, 0.07000227299119745, 0.12314459282372679, 0.16867258266678878, 0.1581986075533288, 0.13373345748654433, 0.0935563880151936, 0.13821041796888622, 0.12417809665203094, 0.09646054503640958, 0.15358143459473336, 0.1314733794757298, 0.13077588618866035, 0.15787951967545918, 0.09145476150193385, 0.14402649445193155, 0.11857984348067216, 0.22069431548672064, 0.16639381780156068, 0.13916190048413618, 0.2785270357770579], [0.012084381288981863, 0.015607538666310055, 0.018091046384402683, 0.0367217079204108, 0.0018095358474446194, 0.04409821817119207, 0.024033369396680167, 0.05488648731261492, 0.03849345106365425, 0.06626167228179318, 0.0017885945604315826, 0.04467396191986544, 0.029160456332777227, 0.018521113753584877, 0.015058532590046525, 0.03440783226064273, 0.05365611333400011, 0.03050143491210682, 0.009028441073106868, 0.023057583453399793, 0.02289945086730378, 0.017953844907294427, 0.008389347598754933, 0.0034463887734870824, 0.013662148233769196, 0.018928117717483213, 0.007036057425596352, 0.07913745101541281, 0.05580078950151801, 0.07849162817001343, 0.0067830792145936614, 0.020537456896688257, 0.08152653210397277, 0.06471225792276007, 0.0238162755101387, 0.01547032022582633, 0.028270990221894214, 0.05225643129753215, 0.04035550382520471, 0.010861963133460708, 0.062241311584200175, 0.024398270262671367, 0.0182263360890959, 0.02490998405430998, 0.08377960763339486, 0.022442510118708014, 0.029576489901436225, 0.051311313440757136, 0.03027001375864659, 0.06331643675054822, 0.013132130111833768, 0.057064510083624294, 0.03769702058551567, 0.06009900011122227, 0.05521411116101912, 0.019948474929801056, 0.01668104891931372, 0.0033322350105403787, 0.034244624232607226, 0.0764380351507238, 0.02948235334562404, 0.011679595286425735, 0.018656396672927907, 0.035804817120411565, 0.07845958774643284, 0.01674229688277202, 0.036884278125528774, 0.007165984583220312, 0.022245202313310335, 0.017279467611972774, 0.03583249117114714, 0.034244939751390896, 0.01212208069461797, 0.03910183234672461, 0.04696692173768367, 0.0231266583182982, 0.01668781560978719, 0.008596348276894008, 0.030213797132351568, 0.048226408261273584, 0.024004748789593577, 0.0489547477502908, 0.02194008038246206, 0.008857077902315982, 0.0063424805578376564, 0.05360758111679128, 0.04914037796801754, 0.022819594080959047, 0.010613333483758782, 0.016592411889827678, 0.01172691207778241, 0.029596516862511635, 0.03634957217478326, 0.014585471545745219, 0.04021218705124088, 0.013008763115586979, 0.030567195133439133, 0.04518277497429933, 0.0435162454710475, 0.017594377410465052, 0.07141007030648844, 0.02027092664502561, 0.032142108838473044, 0.05892877826201064, 0.047677473431187015, 0.032516829802521637, 0.015525020326354673, 0.0315476273452597, 0.0334360683336854, 0.06381636099623782, 0.040208753664046526, 0.025300813439701284, 0.03595117373125894, 0.023757376974182468, 0.03734636725857854, 0.020827566240248934, 0.03408187421570931, 0.06103630802993264, 0.056691946860935004, 0.02127035953370588, 0.04254695141155805, 0.04416193939479334, 0.020518432471102903, 0.008653614087961614, 0.02702810745021062, 0.0140529521740973, 0.006676304095890373, 0.07125509969357934, 0.03895674120368702, 0.03191661808107581, 0.06121001299470663, 0.018387776533407823, 0.07795196891363178, 0.018718540302610824, 0.018747108323233466, 0.06167679759008544, 0.028183935875339166, 0.020217200242249028, 0.06742519699037075, 0.020002416767446057, 0.057423156553081105, 0.07615827516253505, 0.013064634537191262, 0.03444688534364104, 0.04212907901299851, 0.04210221581161022, 0.006907084881926754, 0.02882126346230507, 0.024373887106776237, 0.04649826777832849, 0.05873523971864155, 0.03387818818113633, 0.05299887413691197, 0.01909096272928374, 0.019169275848461047, 0.009833639071855162, 0.02363224493871842, 0.03346869569005711, 0.046390631768320284, 0.05985578601913793, 0.012533798780558365, 0.07118986533688647, 0.0162892000350569, 0.024569272961733595, 0.007140106953946608, 0.06970825019691672, 0.022337785023929815, 0.02023979545837002, 0.016250406491703222, 0.01200966355723462, 0.009063113364391029, 0.0308872567090605, 0.03120704008532422, 0.014771315502002835, 0.016135016522769417, 0.02224988250860146, 0.004690805458397205, 0.01951931679754385, 0.028820642602763007, 0.03686801364113178, 0.021058566701997603, 0.02211447066760489, 0.02448270546405443, 0.025786439256210412, 0.027363558200054934, 0.03387386591306754, 0.01848923448207123, 0.04848498099350503, 0.027043515284146582, 0.02174753589289529, 0.015824566395687203, 0.034290791755276065, 0.06356034973370177, 0.047253504395484924, 0.04509369350437607, 0.04017386678606272, 0.021063888112881353, 0.00988567337792899, 0.060713277863604684, 0.03572507907769509, 0.02823479377132441, 0.053317344547914605, 0.039871660859457085, 0.043891210707702806, 0.04063437493251903, 0.05899295410407441, 0.023793459770136645, 0.028692718395697217, 0.054166802537760565, 0.04000651290906327, 0.01828681900432067, 0.024960446703646864, 0.013406909652985632, 0.05206469087196248, 0.005404182402084449, 0.06335616497589008, 0.055378903568323166, 0.05199206048356635, 0.048626713388200314, 0.08475575489657265, 0.04405451033796583, 0.012147401925176382, 0.05855229310691357, 0.04232094157487154, 0.030923422625554458, 0.045103556010872126, 0.057088903417544704, 0.010865567002578505, 0.054234842636755536, 0.05550152163154312, 0.009523337374308279, 0.01271998624516917, 0.07470629164682967, 0.07341938891581126, 0.02951952688662069, 0.03998400929516979, 0.011619689974135585, 0.021445918595418334, 0.03835664822586945, 0.04549782217613288, 0.06345928872802428, 0.07599606458097696, 0.0784935484241162, 0.042359882699591775, 0.03368649525301797, 0.04191650077700615, 0.03372872048722846, 0.007504218174809856, 0.05744520215583699, 0.018269443418830633, 0.09153486256088529, 0.023028973024338484, 0.02775078117182212, 0.04391394841617771, 0.11429155644561563, 0.008471088167945189, 0.04570836141439421, 0.0170065252043839, 0.06173211855015584, 0.043532119797808785, 0.020373957098594735, 0.015135593812114425, 0.041258735715278556, 0.07242940632360322, 0.05417339789814182, 0.025077186957267777, 0.028579141811600754, 0.046954860777727196, 0.04529220570943185, 0.04853015106969646, 0.03454067923926881, 0.02493346475863031, 0.04725225589105061, 0.04307543858885765, 0.023244528332725167, 0.043537839848015986, 0.07034960149654321, 0.015860876500872628, 0.03473962570673653, 0.048375265273664675, 0.04490641783922911, 0.06996174409453358, 0.02114497813662248, 0.02197561695772622, 0.017589206973622953, 0.06257037392684392, 0.010312305663579276, 0.02545717335306108, 0.019860803116379038, 0.023342269605823925, 0.028004811112103716, 0.017006408157093183, 0.041327505239418576, 0.016805470189345733, 0.04932276478835514, 0.014757420801158463, 0.0684398307598063, 0.02957899369565504, 0.003780626641985561, 0.029288882655756812, 0.022960882035217116, 0.04541350741471563, 0.03491593624598213, 0.019982671398403387, 0.03654244914650917, 0.05530713152672563, 0.06401519889810256, 0.029515394608357122, 0.05389884227354612, 0.07585888515625681, 0.0726294248764004, 0.03773915761017373, 0.017200272397271225, 0.012273518684586244, 0.04701830719464591, 0.01579649031295308, 0.04389362968504429, 0.04193747429443257, 0.08930549504501478, 0.012657494866289198, 0.08001763307090316, 0.038720858682479174, 0.04918120542008962, 0.008652444463223219, 0.027874856388994625, 0.06374028364994697, 0.012243432441859372, 0.08204021703984056, 0.08631196817649261, 0.054001840496701856, 0.09945712531251566, 0.03137290797063282, 0.04524841305932828, 0.024765206733718514, 0.040520571039191315, 0.0825521649260606, 0.03455145437536495, 0.0543597643263638, 0.010370847120481943, 0.04502536163532308, 0.06697790670607771, 0.024108557862096598, 0.016566591936030557, 0.029215444810688496, 0.04633264755830169, 0.059604124166071415, 0.062471192463168075, 0.04459286341443658, 0.05065085120233042, 0.06765019920255456, 0.0911747504557882, 0.01970126257011933, 0.11125154992831604, 0.06443637236952782, 0.09464422892779112, 0.08738069475761481, 0.08706262468227319, 0.11031025222369603, 0.06974415148475341, 0.09103145064519984, 0.11183617570038352, 0.15224191147301877, 0.04763211336519037, 0.15376170777848788, 0.11393533913152558, 0.11707854403981141, 0.14781630252088818, 0.1261609931077276, 0.1844276094010898, 0.11468604313475744, 0.14482627010771207, 0.14144860420908245, 0.09794340868081365, 0.09670906527233974, 0.11278501192906074, 0.18917352759412356, 0.10153248573520354, 0.21875579522124358, 0.15043502700115952, 0.19246185757219791, 0.20094720939440386, 0.18709555481161388, 0.13418290551219667, 0.09317062050104141, 0.19294287104691776, 0.12328035411025796, 0.08986451290547848, 0.11955378550503935, 0.15658349064843996, 0.17474158986338548, 0.14169852222715104, 0.17934919547821793, 0.20802556457264082, 0.12244122342339583, 0.08876434301159211, 0.11586039726223264, 0.2109437808394432, 0.1491746346333197, 0.10739910629178796, 0.14388974250427314, 0.14625310711562634, 0.13327588061136858, 0.122252278562103, 0.21903152471142157, 0.10499309575451271, 0.16566870813923223, 0.111919479444623, 0.0764536957389542, 0.18792401892798288, 0.1401965713926724, 0.14573314573083604, 0.13614393956959248, 0.19156012524451527, 0.0729836540828858, 0.12539114084626946, 0.15127377770841122, 0.17870724706777505, 0.1427827804748501, 0.15988563559949398, 0.10621682008994476, 0.11434300297072955, 0.0734223337577922, 0.32723922761423246, 0.13640590836959227, 0.14576150849461555, 0.09099948486047131, 0.13399189790444715, 0.09397896605410747, 0.1591246992881809, 0.18726635564650806, 0.1727750189602375, 0.18116594584924833, 0.09505793172866106, 0.08939603875790324, 0.21559737755783967, 0.1288333489958729, 0.09807501054768052, 0.13947056606411934, 0.15725389681756496, 0.10046447161585093, 0.09037887637636491, 0.10222971439361572, 0.0953427671587893, 0.14508647471666336, 0.11107352948082344, 0.08766774899725403, 0.08629286063036748, 0.15536341683140822, 0.11289844262812819, 0.1117061616054603, 0.12483069806226663, 0.1805712641882045, 0.14618799489523682, 0.09016512427479029, 0.12361525185406208, 0.15190035051533154, 0.10792026189821106, 0.17926578995372566, 0.09823528730443545, 0.14420701190829277, 0.08377815556845494, 0.13848331118268625, 0.08522861916571856, 0.15552817870463642, 0.16875674815050193, 0.10528837383857795, 0.16711009293794632, 0.15583145671657153, 0.18406470173171588, 0.11755184935671942, 0.16637108687843594, 0.11685183191938059, 0.13643679528364114, 0.14505098733518804, 0.10957195184060506, 0.09240684112800018, 0.1051058139918106, 0.1799016044076, 0.14418082045657293, 0.2688161682869707, 0.13345096978758061, 0.13567290055964673, 0.09553291302706514, 0.14901931796755108, 0.13463350704738072, 0.11772098099546772, 0.12496499371315752, 0.1415281013718673, 0.19377091447157518, 0.09072102765951838, 0.1012524204062564, 0.07488492277583905, 0.12753312662243843, 0.1390722660081727, 0.1780916800988572, 0.09800013420837266, 0.20245643412428244, 0.21563180642468588, 0.0857660189004881, 0.07508670551968472, 0.09644930171115057, 0.20307346672884055, 0.13741319360477583, 0.1964828289513077, 0.16198300091283663, 0.12157210148870945, 0.17020033140267643, 0.07769242926899876, 0.09491005859204701, 0.18129631956773146, 0.1148313039115497, 0.12296764446156365, 0.10306785441935062, 0.1813216017825263, 0.08550226555338927, 0.15003859970186437, 0.12212627460913998, 0.16987508242683752, 0.09524847114724772, 0.1544628787253584, 0.13599472971899168, 0.23683374587978634, 0.10209853321846042, 0.1448106366608824, 0.1925408797604697, 0.09247368361268725, 0.1350278037467173, 0.09919786386724029], [0.01248472967251603, 0.03721504359106932, 0.03311877518094011, 0.09665174263396434, 0.04052165669522115, 0.04200438802529659, 0.018061331639598523, 0.012066234718076885, 0.04131399899987238, 0.02282788577888693, 0.0431925876598273, 0.017772872832470706, 0.024011771627036587, 0.0506313806399703, 0.028123532687979083, 0.04071434028446674, 0.042150615714490414, 0.08706776119236435, 0.03173049931813564, 0.028635409328022172, 0.03147766359948686, 0.017383188474923372, 0.041802059060760906, 0.03847797028720379, 0.028314397803374698, 0.01607782789506018, 0.01058006745630077, 0.009222179784306457, 0.05346800985613039, 0.02111830492503941, 0.015098264208063483, 0.03039805670934064, 0.03720587658296738, 0.005271266297703343, 0.014065146296551185, 0.015395601645910313, 0.0025333482356342885, 0.0561265609493213, 0.04027787602639624, 0.0663984649415527, 0.020210925489664078, 0.03929949638300708, 0.0333015250175127, 0.0387525768019259, 0.026583641567932706, 0.04828190564044884, 0.009882715813416456, 0.033767339307814837, 0.02215579175390303, 0.11408414186111518, 0.05428376501160009, 0.03629949629040701, 0.04428250828225698, 0.03549254173412919, 0.022605353434170996, 0.027795952944351093, 0.025025294295379093, 0.03309099595727665, 0.07693049551120826, 0.0157828500627407, 0.010285886054459428, 0.029101990362895385, 0.01971186467978571, 0.0157179634552449, 0.011076287748957319, 0.004952891729772091, 0.054760354437998364, 0.026056184067523906, 0.06467352035854544, 0.01552242153723325, 0.05666602003787245, 0.016896773861455064, 0.017323696220825826, 0.020854403996574025, 0.0533917968028358, 0.014461267406919172, 0.04768366167055709, 0.04760903638920613, 0.035890848575426, 0.015179350839129515, 0.05245398337553654, 0.014238936926371284, 0.03809197546382036, 0.040110067530934296, 0.015012812900489994, 0.003710397843471063, 0.020027624343388846, 0.048219059727021625, 0.05465753941929766, 0.022316473935331618, 0.07527942982103143, 0.043501453407640965, 0.031918555298554044, 0.03554669561396752, 0.020698144167129482, 0.012227594586355346, 0.022331690083124807, 0.006852218964403229, 0.08000853391630308, 0.02404795111423092, 0.09274149459919759, 0.027291692859892334, 0.01873492861964873, 0.007597844981189285, 0.047345808906746764, 0.03191239080790963, 0.0694176336484296, 0.0373729929727103, 0.02933814429811069, 0.05573232871081148, 0.01562505165514137, 0.033658549788274934, 0.03367996435346348, 0.06481226041380848, 0.046086563263088465, 0.01761039422958025, 0.03386336558365396, 0.022069119083295976, 0.035708451577063115, 0.009534086217172444, 0.10196864125984055, 0.043715079980237145, 0.07982560087527547, 0.02660567868900086, 0.05609153836433377, 0.01978862056109522, 0.09907915416572775, 0.04725738900846668, 0.02125405433720776, 0.030947117068405663, 0.0335369257788573, 0.024270234097327505, 0.06978148448147944, 0.02977079858205148, 0.051467108473713906, 0.027501567133835385, 0.039914350890155346, 0.04369956188436065, 0.038231994557593546, 0.03749597744484033, 0.056596426093684774, 0.01533759368716606, 0.05562811251729727, 0.07235716270016772, 0.033443223485457044, 0.035416919006300826, 0.006582693828802023, 0.046520689968019724, 0.007538878591731191, 0.023964260605030825, 0.05160512588918209, 0.05946427131337779, 0.017817313483517085, 0.012313384313269385, 0.03553120805216687, 0.051809646521828005, 0.008634868709902679, 0.01916285521084709, 0.02563503773749939, 0.026313856044518094, 0.07378662563860416, 0.03764883102849126, 0.05458621521081243, 0.03554509087864842, 0.02264908162344779, 0.015438976996977414, 0.037775384594819376, 0.06129800541592496, 0.018304949460018958, 0.015055151789316108, 0.009980971924960613, 0.010359044852001327, 0.022720453329384327, 0.051772394949304204, 0.039565322654587884, 0.030467942423586334, 0.042363750349198065, 0.03462745708280376, 0.0319367502150791, 0.101848330215684, 0.0231198068109474, 0.03222599273015346, 0.0192425474524498, 0.013410946088177817, 0.047160826689962826, 0.036665423440613916, 0.031884662474372556, 0.03628151511241283, 0.01057892497296312, 0.04525995833267059, 0.03222826921514102, 0.06852156708815269, 0.004127937335787075, 0.055418017719473155, 0.05521607551989811, 0.035755894745567014, 0.06098433903285435, 0.01297428590312068, 0.03149532247334719, 0.07231779409838573, 0.03452449278639896, 0.021113931766844223, 0.007635383234758462, 0.02038118688921843, 0.019923364045098424, 0.06175791645156486, 0.048151803335973194, 0.023607843123110275, 0.02028174079688532, 0.019767192425206304, 0.02159558645715671, 0.02216884507132428, 0.04042819528175252, 0.015423026335026537, 0.06910218271825995, 0.053271400941801925, 0.04449502884277275, 0.0779720399794834, 0.074535036193473, 0.0225525871584458, 0.026639028685167432, 0.04315082382942949, 0.00678562160049166, 0.008546724466473928, 0.07147778810134955, 0.10566907948149101, 0.035499306728265116, 0.04216987932366984, 0.01808593701571226, 0.00948087465284126, 0.029757584112563303, 0.025183598211567317, 0.027632553230172822, 0.017267303175425956, 0.0663466045100774, 0.06059426282133375, 0.024578940389411788, 0.02862348746774452, 0.03207229437040431, 0.03586442642179983, 0.03539576567709446, 0.04780858675284045, 0.041661280007766824, 0.03384019022009202, 0.014579972019419074, 0.06526107061654329, 0.04053152598706739, 0.03105042063231979, 0.0354334481193551, 0.01949678604224963, 0.020793010148086717, 0.05284526737939034, 0.054970662974353345, 0.0500158917025796, 0.03369880048558116, 0.028524384035595825, 0.008322493239705051, 0.01871488130252276, 0.04046582004853657, 0.050952049504433355, 0.07131729421338864, 0.004780057834328285, 0.03034780779853463, 0.04365392361900636, 0.06590403004416398, 0.035283732760165415, 0.016499673116153905, 0.02336460188962519, 0.05193230529714908, 0.021203886850603988, 0.04935605710904513, 0.03453018230253032, 0.03215090943766492, 0.06206061092338391, 0.06815175193228892, 0.09370215769324984, 0.12020041580711092, 0.06575444699930293, 0.03695882537535258, 0.04523321048223546, 0.020584121446258256, 0.03262621643287795, 0.021286679997241924, 0.015547815710306168, 0.055427191512925286, 0.011107897302801055, 0.04977317972640906, 0.05655943575714316, 0.04753978171252778, 0.023248336610517333, 0.028120816851566945, 0.03546032828411885, 0.01391807128675282, 0.01859363727271557, 0.03719818199585591, 0.05591999114091907, 0.039980385918170214, 0.04594656791804092, 0.04813198672075357, 0.021907281695998142, 0.019792464461975863, 0.02679556162495698, 0.07163830234536103, 0.04406661879537361, 0.011152818017373127, 0.005251024749928287, 0.06798953456538064, 0.023516639534916197, 0.003503924302224602, 0.07710679926510368, 0.026351472329614416, 0.051419482100754976, 0.01908909166896982, 0.037661563738116195, 0.032788443977811506, 0.026395327744207213, 0.027465092483907938, 0.0162867623980024, 0.02467066984224532, 0.03569263153310333, 0.009518612226072167, 0.057080021394150596, 0.04545165804613914, 0.020780993292906454, 0.04453095727201019, 0.01446656506907727, 0.07657197117805481, 0.05507449918825712, 0.03456190042197704, 0.02922920889354178, 0.01749946053938142, 0.03989441553130746, 0.046534515119024684, 0.038750378348465474, 0.012051142402924597, 0.05192678541477237, 0.06384756682174546, 0.10490316272314106, 0.008427507560034948, 0.02097615523130766, 0.023072112584486604, 0.043525361589023044, 0.07155849984181778, 0.060135383158922195, 0.042858734859951904, 0.014425198181665369, 0.01535728307706969, 0.0636366984940001, 0.029489169229886363, 0.019246900254594426, 0.030179157919649566, 0.03515233784647925, 0.1338785554149321, 0.07709124724247626, 0.10896703787147999, 0.2134544418326446, 0.1561627175126757, 0.07421277277171612, 0.11217954156122037, 0.062686701970441, 0.11094850940363747, 0.10416275209614209, 0.08902211167982646, 0.14765877383095877, 0.08594868052750826, 0.08049152192792722, 0.11206353242908206, 0.27023471359695705, 0.15319472391690525, 0.2239038132663284, 0.15770125495535986, 0.06299632428480045, 0.10903896258345672, 0.06520625855773687, 0.11940505062895161, 0.15715810124363216, 0.09206853713840246, 0.09503784030675888, 0.10783929909978594, 0.18467181415430137, 0.16770273899393423, 0.14866219141653605, 0.12743287985878332, 0.09835146607032844, 0.09525115814592157, 0.06539535269673381, 0.1011325843366129, 0.05721144684191261, 0.12318290291087967, 0.0957469976107989, 0.1454639844596386, 0.20404907794935362, 0.11549652607313224, 0.1458382915173258, 0.176969831011125, 0.1154499107173511, 0.08758549019694328, 0.15628075546451978, 0.06584737915545702, 0.14321540083203996, 0.19686145149171352, 0.300578311085701, 0.15928218726600918, 0.11559240307126727, 0.08254431427589484, 0.1303379868290254, 0.09400908622358527, 0.11592671727495533, 0.12281683326831885, 0.11252265636410032, 0.18517178589744226, 0.11930612022323267, 0.060343238791184764, 0.12078149962638106, 0.13535968879503862, 0.0696990764034646, 0.11775631909923893, 0.08785164555800812, 0.09869661647826433, 0.09306768673871245, 0.18235148223383085, 0.08710864292723791, 0.1637955850788525, 0.10644744735743318, 0.13047206534871034, 0.13659346901944705, 0.0899143513025982, 0.15996053229485238, 0.1140534585075719, 0.15245115810206958, 0.09960269143006631, 0.09203375543334655, 0.11958089976438455, 0.06139269497777734, 0.16523462214640208, 0.1666218869920288, 0.14923742626394543, 0.10762890574655362, 0.09231806839151041, 0.08786703473223106, 0.2190354195024286, 0.10563446741018977, 0.12301573902368546, 0.13600554556718894, 0.10503179939197642, 0.18577589919524534, 0.16338486783206463, 0.16478137432464532, 0.10094358519251857, 0.07332304372851338, 0.1308053888912712, 0.16703211569360324, 0.21433925149696215, 0.14984117315283843, 0.18226980018828595, 0.12788714548306807, 0.1406524112182004, 0.1986750941723585, 0.1726805940270424, 0.08199972206992762, 0.08863474282303027, 0.11768309160002641, 0.16067824592547758, 0.12399185236011233, 0.10911592202527182, 0.1363633099411215, 0.1692984090851886, 0.1452656758150884, 0.12490539119711944, 0.10301131209624664, 0.10300622986895697, 0.14335973880120687, 0.2105175115700279, 0.10761481257421629, 0.11738374909119946, 0.08729398476758174, 0.1598259788006544, 0.08479683340660163, 0.30522592312523295, 0.13975878059864044, 0.09813084719436509, 0.15712080895900726, 0.15370357089809009, 0.08813112734683923, 0.14843854627438954, 0.1294010385338749, 0.15745239545192036, 0.2525079319519656, 0.09597586068723883, 0.09825549407729081, 0.1342314886195319, 0.09301453030535153, 0.16485108701246126, 0.10418943887842552, 0.12755433762712137, 0.11811610550752707, 0.08981184501733099, 0.19451475170041832, 0.17106398434511252, 0.08380843858633723, 0.0874409486672708, 0.07334791203694684, 0.17340806499123573, 0.11546174436807632, 0.13800161917294773, 0.07075043927345957, 0.18643289751240186, 0.17264383099973202, 0.2136862293950149, 0.099454845434853, 0.12004648335278034, 0.13135002180933952, 0.10631385738296167, 0.18817680036383017, 0.144148766462292, 0.10487243865749665, 0.10297376196831465, 0.09656032361090183, 0.11062864799584661, 0.1385259638939585, 0.1282453169780118, 0.17561301881713526, 0.06592159731579678, 0.22841896169951983, 0.09635613206773996, 0.11849900281855039, 0.15672907712204115, 0.24894589451806887], [0.06403922582311289, 0.006196986534632742, 0.003702507329372955, 0.020998087179447924, 0.06720389279403857, 0.03443860721641353, 0.019486943891804134, 0.030749300361743996, 0.05662261076005442, 0.04283748653584293, 0.056742853950709105, 0.013601702637970448, 0.019723409953128015, 0.035899289551057985, 0.021378007418076907, 0.07544778114450829, 0.03940717989046659, 0.008700108155608177, 0.05204176317368235, 0.05191375754241433, 0.0661427318783743, 0.029675786716065237, 0.0610939088676657, 0.06827914688204016, 0.06410703861287662, 0.03422022411333663, 0.026957948625619923, 0.020782421609120708, 0.03953888014491115, 0.016517074146707143, 0.04679508613688605, 0.04229732855622258, 0.01984754963112729, 0.04681429885593908, 0.016712439645613943, 0.03653446278933968, 0.03388342986415539, 0.028562724656824554, 0.04060469920347844, 0.016301406880042384, 0.010012478002214005, 0.06831266651196138, 0.015794388550732816, 0.038481705622481446, 0.037600370057459385, 0.026812509733385274, 0.018302846001461148, 0.06429186476660625, 0.049197262951305935, 0.030964148297373737, 0.036767210478761365, 0.029867778199591806, 0.027560837167714323, 0.03147630313677447, 0.06736620515584946, 0.02958968740754894, 0.06190812374864306, 0.04371810963909541, 0.06101109366863966, 0.08814265565680605, 0.014776204346812196, 0.047571906952985694, 0.046498688470040045, 0.06712720476623092, 0.03562119197366493, 0.12198547859277044, 0.05856936504798276, 0.03416437389595168, 0.023389495643121854, 0.04721965567607965, 0.03775237547233701, 0.10516342840024404, 0.06955789362213441, 0.032754880243114064, 0.03783770464360714, 0.023242938864443983, 0.03894820862582751, 0.026664560261581625, 0.007402981598196285, 0.0069700537798261, 0.04509158665314317, 0.07835224350648266, 0.04172170694385256, 0.032220737476434023, 0.033990031108260155, 0.015562154851587755, 0.025857575171227967, 0.019008905793141042, 0.019356773733826618, 0.047781268932989666, 0.04349530248769692, 0.07372299262455531, 0.02510409935244492, 0.011233689213570739, 0.03292492451146245, 0.01625045738182962, 0.09939834382385015, 0.03691989442865763, 0.04879311053082347, 0.0135566445200571, 0.0304161498456129, 0.040984271692910364, 0.03720952710136771, 0.010581597552767821, 0.02441702497058681, 0.023219921260273883, 0.030773181401725327, 0.02183266998534756, 0.03520939924887248, 0.10315432013677699, 0.05938562231936625, 0.06379726702081305, 0.10677960381976195, 0.012272846934917783, 0.06268161295780114, 0.037551688562546454, 0.036623310164681504, 0.044187404814043214, 0.036325372223343165, 0.04132550356111356, 0.02674547047354281, 0.016661749687045813, 0.03757819892572505, 0.022407633418749486, 0.020873557343812923, 0.03170845710805484, 0.0337903518229723, 0.019696465327537487, 0.016263558196702173, 0.056950624766094346, 0.04686034084962947, 0.0858520164287516, 0.03174532191561801, 0.01619970296243472, 0.02547169739513525, 0.036731159913220575, 0.05689203326723405, 0.05702275982392686, 0.03609382214822939, 0.06185600547386067, 0.016383706392454248, 0.029953741801104376, 0.047066880123955865, 0.022966122021898627, 0.03552816482260823, 0.03985189174168876, 0.013196635891550353, 0.05604389163532427, 0.06422222671764237, 0.08473315289510147, 0.03497919945844582, 0.027128140475334864, 0.01732467331125268, 0.06950700349573578, 0.04965118591540626, 0.02129524141283972, 0.06037347431161574, 0.012508194261629666, 0.04015699840549912, 0.04524590926510947, 0.015830725797318985, 0.031438634265214205, 0.0033341605656979872, 0.0617960976170642, 0.0548538124587919, 0.021191418769636323, 0.03118248051032424, 0.034770044431622536, 0.036975612331713946, 0.02529446065558919, 0.025617651973984072, 0.025888155048180903, 0.04824319521763495, 0.049024270448301516, 0.0467778920595135, 0.017332927689754536, 0.02828218096068927, 0.01714260200969875, 0.00944919724549566, 0.03375897975638509, 0.0193942865423326, 0.04431396516572152, 0.034391197974660566, 0.005914104013105056, 0.047895045684916634, 0.05267067014106682, 0.03352214728615113, 0.011252527042025966, 0.025917021624211754, 0.02388581686786243, 0.025181364135018418, 0.03459278394335082, 0.025935374300128648, 0.034531712398997376, 0.03534451931981104, 0.020957907728318657, 0.017509090647633587, 0.037036056231175146, 0.012771016319415398, 0.00830456125549972, 0.04036171581330044, 0.021487811347469687, 0.04049651697278023, 0.03734085076887693, 0.028407279069402387, 0.0064137763526689795, 0.0008582391871771376, 0.0662530752431069, 0.03716185662363257, 0.03619036750335779, 0.028023603139445186, 0.034335167945495675, 0.012942143699287303, 0.015076001474101628, 0.07816314258213554, 0.06672944753829922, 0.022523176058062484, 0.039804513034011633, 0.014268322581691402, 0.022229930186378102, 0.046639168967625926, 0.058273048805339, 0.024607939279771278, 0.07627807730542761, 0.031059309441064085, 0.0383523056017501, 0.09534856184784855, 0.07996034435927868, 0.041717014874198606, 0.008646579376155776, 0.03333331099046128, 0.020587117178365588, 0.02626036712899804, 0.007657245633059314, 0.055411788768001964, 0.030983242272798504, 0.010696188546717167, 0.08748342495943819, 0.011679190709920866, 0.14506769286734716, 0.02511604835412332, 0.023189706095893468, 0.030915707682392428, 0.07191060523369483, 0.047854957836014886, 0.04108828093324389, 0.043553775242928944, 0.07518665372793164, 0.002847548752989886, 0.030668337563318864, 0.016537606616371443, 0.019826304699693407, 0.0493242439946958, 0.018210534704849124, 0.005886021569105131, 0.019575606366353374, 0.0648724939674139, 0.028680484409310987, 0.03764236798243863, 0.050124481054289, 0.04097989514204008, 0.05122470523097685, 0.04820557723620108, 0.07724496256560087, 0.0424592677237732, 0.05389354291505047, 0.039599965259964974, 0.01366113976109773, 0.03248952216069613, 0.02213286066294781, 0.02862610322024141, 0.03348948600302849, 0.04844936129770108, 0.040480408551437516, 0.03167804516851902, 0.020276963910354034, 0.08232263009995222, 0.031160373839416673, 0.01187102188954928, 0.04486839612945914, 0.041882037983409, 0.03997627060328211, 0.00893079733941704, 0.03820406605622598, 0.030007780329989533, 0.06199756823480129, 0.025759419991767833, 0.00906033137081457, 0.03907305228390864, 0.01645133428142539, 0.019234801975211928, 0.06629392305122954, 0.04987620169829045, 0.04759713488497904, 0.02709353688572134, 0.009688897374352174, 0.044384766902242384, 0.035332390506352694, 0.014795815705188682, 0.025635953759774566, 0.024209025149632777, 0.025843680470383594, 0.010646574914322367, 0.058893630148044655, 0.06127119649733816, 0.10822305815028292, 0.0948117660092456, 0.04146561425711427, 0.03899314121476241, 0.027446524373122623, 0.03909859912736075, 0.045411220751702785, 0.01264915312640369, 0.022288029747349874, 0.011448337829538753, 0.05565297404038055, 0.012530507885717919, 0.014468972172055925, 0.012877649793933545, 0.04981663989435349, 0.010394761239045432, 0.019091089954599738, 0.04840827260964683, 0.08389708918652364, 0.05239840117948396, 0.04232258702229176, 0.08363072347960301, 0.028116618416139057, 0.06392109966171639, 0.013223393920010753, 0.016702100468267287, 0.0488854184347604, 0.015483536391652055, 0.06656509957143239, 0.10628949119044201, 0.02775219761367355, 0.03138727255697761, 0.012361226969265511, 0.014931900992191263, 0.02983714234349983, 0.04467610948319946, 0.027479925259415592, 0.009332067682407796, 0.02125356070298169, 0.033403993983353884, 0.009425334017058569, 0.008359686288583492, 0.05050400604626962, 0.043459509765463214, 0.08355558929698807, 0.012519380759580858, 0.046844354564590115, 0.20450452422457083, 0.08466348770473685, 0.06325747205742768, 0.18536833035094397, 0.21072939091495105, 0.14422806006457123, 0.08852370056722846, 0.07198891496019703, 0.09591125058276312, 0.0993853702342936, 0.088883683750672, 0.12079470391784396, 0.189188170379826, 0.11154549808374473, 0.09393908855106149, 0.14404206004525932, 0.09871837709631238, 0.11724705142634255, 0.12044129573873111, 0.10769517147647482, 0.12066461518406868, 0.15672928068254674, 0.14007691852748394, 0.12239333242177963, 0.16355393161731108, 0.08096451511872665, 0.10664325899311475, 0.0915961546291198, 0.14665873534977436, 0.12831547749894007, 0.09443947420056377, 0.13711638881691865, 0.0641067468428186, 0.08476614326770816, 0.15271734738988535, 0.1354433928749391, 0.1144442403955119, 0.10466656434748854, 0.16689042401100906, 0.11382245804582324, 0.11227547284215689, 0.11746955662965775, 0.09211174624839, 0.10660285901810442, 0.1509101643626179, 0.12624609496976646, 0.12246628850698471, 0.3719960759793009, 0.18339040077158383, 0.09591795450874738, 0.15145911276340485, 0.1288851483591965, 0.08587721043399402, 0.08446021218385015, 0.1246700616819518, 0.09457133391073771, 0.14861865660973958, 0.10997714581234114, 0.10924258415720292, 0.20092892966100148, 0.07397583512855427, 0.2685106646801744, 0.18515039847365447, 0.17957008576818875, 0.13396312801965646, 0.2078662309795618, 0.06853088337395873, 0.1534012971179826, 0.1101249171687024, 0.13362048140593938, 0.10173433633255106, 0.17540611991924898, 0.13274639259491647, 0.09936395566910505, 0.09432832337915897, 0.18085801308708532, 0.10063432928706918, 0.14896671793290547, 0.09989524858870677, 0.07386973939303841, 0.18633168722902024, 0.10646139125206641, 0.08611546443509203, 0.13204782722251757, 0.17672189431531088, 0.11780245948050704, 0.08835218048521451, 0.19624061909105095, 0.13494158908724785, 0.1187810291137014, 0.13001022727361747, 0.06680731621703931, 0.09444026130118541, 0.06957532518676349, 0.11772393940814904, 0.06887687516531774, 0.16246679638113293, 0.19689802452921867, 0.10737232451460191, 0.08961137863142149, 0.12855710381908075, 0.12875508676682199, 0.15025715583137103, 0.15288392773696355, 0.10377097276172467, 0.06646236258425883, 0.11088096802788121, 0.1366889931793724, 0.1881100189472948, 0.23257946701986448, 0.1087514605107052, 0.1473169143178633, 0.22533621426139558, 0.06175320741853543, 0.18378597311675549, 0.15314106536763056, 0.11843454199177877, 0.16187451673405512, 0.10121915861964226, 0.14735183172992297, 0.08898142672010831, 0.1064454253230776, 0.11112221436841146, 0.11145724103386913, 0.12620550500495092, 0.15824900913451398, 0.09861292596906424, 0.10949985070952348, 0.11168907609369073, 0.16043140845639364, 0.15210235039038317, 0.2545922286808491, 0.08743393261517797, 0.06816079001873732, 0.07711310285542693, 0.12637211249342986, 0.12493154193673815, 0.10048452232565198, 0.130560397037438, 0.2670688863311495, 0.18029861524701118, 0.1253343338945082, 0.11662924529186317, 0.08469982325498547, 0.1161998954734632, 0.11937575148684637, 0.10708728552396808, 0.12891152980072157, 0.21031450746314867, 0.15628283178167685, 0.16681712865829468, 0.07719048298895359, 0.17488718990768704, 0.1919277012348175, 0.11445253209343978, 0.10911791691822664, 0.21306264214217663, 0.09502475815159933, 0.1271824597248009, 0.09849070824150528, 0.14229324460029602, 0.08532930019178561, 0.12460538372397423, 0.1537712344101497, 0.18491344047444208, 0.14953934720584325, 0.08353903982788324, 0.13737051375210285, 0.1698899016316448, 0.1540020720234939, 0.07793102932295629, 0.11599177521254335, 0.1445327630000455, 0.250838572957686, 0.0853458157341395, 0.15381932897227152], [0.04477631892742855, 0.01967695914208889, 0.012669804339696254, 0.07700725139251777, 0.011658621768999313, 0.05128902017271944, 0.016199758941573755, 0.021968003794816986, 0.040629055217972825, 0.02232153750290828, 0.03264567681721278, 0.02727320108429662, 0.012107246222772768, 0.09901393337973527, 0.04075032299650567, 0.02169903929877494, 0.04570304848519819, 0.06335136773330824, 0.015930772393143604, 0.04317522055602499, 0.039995300117880106, 0.026131520114306892, 0.05738745882575001, 0.034220956931156774, 0.010260807400170182, 0.008618689042383006, 0.029438628549022332, 0.01769872082929526, 0.07062583310263497, 0.05460628288398896, 0.03641383283372436, 0.06390125251242093, 0.012341395935176738, 0.03783923813274928, 0.03607864331986223, 0.016062589694878886, 0.05284365585872105, 0.01920444262214005, 0.015526675951800175, 0.016335013023178493, 0.02936643242303814, 0.013689088618515857, 0.05859571256275688, 0.03202142120738115, 0.03545554121956229, 0.03441642251397882, 0.07565168091761214, 0.038503103224294524, 0.09787531769169228, 0.026642977758975964, 0.04068469848217709, 0.0196771813623075, 0.05890417458223445, 0.0697937523946166, 0.06301279911505324, 0.02584178905401911, 0.03401273828265922, 0.043893113998430114, 0.038644180832696814, 0.05609790641548378, 0.08464309094207627, 0.02105856839833515, 0.03416734927200845, 0.014041574838172113, 0.021618084982037544, 0.028178950339289646, 0.04904564769406404, 0.06692838722041675, 0.04728559910186699, 0.040733488542693, 0.014317178799371635, 0.022721162398478816, 0.02756494908992733, 0.033756038307079246, 0.03046330124405878, 0.03989664112616863, 0.012011576177818435, 0.04109774310407894, 0.024688220150502663, 0.05256384498040591, 0.03799128086705293, 0.062335376893835406, 0.015548439962523324, 0.042804950781698735, 0.10025563210781131, 0.012667267466895282, 0.03573006291740707, 0.03038928664422461, 0.05225827352010778, 0.04468812294570463, 0.039924152328499725, 0.019683924304055314, 0.023252029537356327, 0.06359839519219739, 0.04597433017832892, 0.027838649760399545, 0.05612419286210622, 0.07666847921375718, 0.03816325217485428, 0.042582496468509944, 0.07685078800256763, 0.030950553848275116, 0.01728733692185155, 0.07510875112244061, 0.028387470935870494, 0.03783144176538501, 0.031715147463338714, 0.01847097001570676, 0.018155797284894755, 0.032875900356365104, 0.058196564338036945, 0.09654701075383595, 0.05226998842720475, 0.026160305266135504, 0.047763345430472066, 0.047187615252499066, 0.04845407711608069, 0.062140549133930884, 0.018590334503512298, 0.09866720877055611, 0.04402380323569689, 0.004667678016370961, 0.03854642089988504, 0.023216350469738245, 0.07545975050223724, 0.041220079575266154, 0.11274204709167991, 0.054955138093126674, 0.012827339814975858, 0.012127317288624389, 0.024443357218323008, 0.051577014183359485, 0.03783995059451886, 0.025189835644726242, 0.022218216975618685, 0.04592905153653451, 0.04636340894337211, 0.03708780470437237, 0.013527085838307227, 0.010086585900613239, 0.028111202010352696, 0.033221803938171694, 0.04731126808162246, 0.030354511724518876, 0.03269992569195373, 0.044784926144140105, 0.04404978434156094, 0.07419513764658145, 0.010657065065710672, 0.029629028867930174, 0.08671642254505839, 0.021343603996293883, 0.06255427907620158, 0.028799231430249553, 0.06375808840883629, 0.010629581004780318, 0.05857412836381367, 0.03807936828317387, 0.031338306077356846, 0.05500928858028991, 0.03541008955133813, 0.028353649357865964, 0.03836150314392788, 0.04975770912798388, 0.02921943798927324, 0.02168695628643036, 0.034536872657814195, 0.029035144485533237, 0.024092561399031962, 0.01459752063133887, 0.03430436584832413, 0.013012066732959023, 0.07234648934432439, 0.009680929676895695, 0.04254936360354934, 0.037434230758143325, 0.009487017939266349, 0.03520923300779291, 0.0199272673177932, 0.01844715852556484, 0.019794072589970062, 0.04090857432622995, 0.031773684679397514, 0.02303092211617955, 0.01924534301672663, 0.04694136132353118, 0.04127247604940619, 0.10560913769794361, 0.010699623630249074, 0.020685910180743252, 0.07063419265406472, 0.026033112180552313, 0.028539454298360006, 0.032890977404479466, 0.022685829383720244, 0.05671928842951145, 0.04795650399423071, 0.0736185253730842, 0.03509005172444241, 0.08919074120266096, 0.012342973529095096, 0.01019356882066599, 0.022686460421287587, 0.06357271264174155, 0.026447568155292953, 0.03962140018120408, 0.038336889286126406, 0.028452308349577442, 0.045698973882411204, 0.038068525293575864, 0.054494389066738744, 0.022542281907850077, 0.028137227220992957, 0.026430767628231218, 0.02018188588720347, 0.058282656861203055, 0.06633894384971686, 0.0227511655206659, 0.06155149931354182, 0.032671427221170495, 0.03718902516577925, 0.07926524630082504, 0.02997365001855152, 0.032429682157401524, 0.02807266291763101, 0.03356240137613245, 0.02904358206849013, 0.029539201009486402, 0.013871641679933029, 0.00525290089925485, 0.026697813566508036, 0.023188405004995208, 0.11445929030222551, 0.017472863662987947, 0.03876568949116128, 0.01915430566961212, 0.06482739853007452, 0.05263136260743652, 0.04263984285561102, 0.03911252945129361, 0.011815815432263272, 0.039511406262006075, 0.024243445534791266, 0.008833575145607548, 0.057178795736815245, 0.03369514996718083, 0.02635101431847683, 0.11400731812630381, 0.08710601021136556, 0.01373638675015952, 0.07658840529620647, 0.07991071630801473, 0.02808922086842358, 0.07601407290037189, 0.030379912682941983, 0.052915916445532014, 0.013036521983199885, 0.0026738791992621763, 0.01942064762780709, 0.028587314765900373, 0.04328738578728267, 0.017746944313070605, 0.02199831056142492, 0.02184994887959744, 0.019642888202465007, 0.023459506886345998, 0.014631286230204361, 0.03003299129860742, 0.028816238910491978, 0.06473578951720681, 0.03945660098854985, 0.06065970752388239, 0.04236843563350184, 0.048407159812216244, 0.03283131042761462, 0.05276211291285498, 0.019016132191089646, 0.030972674089883055, 0.039357836823910475, 0.0067758854711428285, 0.06157000296350036, 0.02831413656739252, 0.018642442600269402, 0.03624074872849243, 0.03911638692287462, 0.05925697207983051, 0.009263539886368173, 0.00932240195106715, 0.0431193431972393, 0.036086456650601964, 0.031934124284556935, 0.07905010998781238, 0.03509490664250084, 0.0759372559509107, 0.041399694580052576, 0.1575810999742576, 0.04553868355495589, 0.07224392877625567, 0.008282904114042009, 0.016886850286807333, 0.04910796095750161, 0.07526179469589676, 0.07776091380843095, 0.009984982066920825, 0.021407769660332372, 0.01679058143469904, 0.030623852807496275, 0.014766455494931765, 0.01588199590332806, 0.04167490838361638, 0.02339543112819748, 0.047952361537941864, 0.025730941877035157, 0.016745540280161158, 0.018023157259449363, 0.021846795388098274, 0.06457862723618746, 0.015419274036373411, 0.06282858364284039, 0.014379844901018908, 0.01004479153613959, 0.08558241410979203, 0.016754471497344117, 0.04997164782668863, 0.06226775409387691, 0.03778749983757734, 0.11673813659165587, 0.026409056203972017, 0.04653030480923397, 0.004276153980754316, 0.03789513245491045, 0.01706631262121456, 0.026640538425583924, 0.03529032812054668, 0.036168644204735756, 0.08863882760384253, 0.026077194904376353, 0.01070780336989888, 0.02469638123043946, 0.04066412530041166, 0.021737797219040136, 0.008567918507781411, 0.019492290747751082, 0.06993576977401972, 0.07054261078259774, 0.0528957435994276, 0.032419643231800625, 0.03241600289142557, 0.046631627050893645, 0.02880590482215796, 0.034345980401017835, 0.0660410737618804, 0.10389937194330351, 0.15168971967484268, 0.10256421180175883, 0.16203691730541842, 0.11005259890641485, 0.24709441672478402, 0.1409361067094973, 0.14770860544272832, 0.12238375150731631, 0.17695996511195386, 0.12113059232277529, 0.21552117807524546, 0.1513357958091157, 0.17423445279044764, 0.14990403263696603, 0.14307892029838903, 0.16234081956957067, 0.2077127192169428, 0.08645534262593303, 0.19278869431998047, 0.08065892330237798, 0.2037793467087405, 0.18358849228492805, 0.26927480367677553, 0.10128155669995717, 0.12530390838427202, 0.08973395598254033, 0.16149294935166836, 0.11477262420313698, 0.08559366422040121, 0.12122775853744575, 0.16926354595593043, 0.13729430069880827, 0.11270154533641678, 0.141559273270624, 0.072357827664486, 0.17335690345082963, 0.07060203687953097, 0.08262892759272031, 0.09991344011255673, 0.12896205351821013, 0.1426319828523057, 0.19435543167803968, 0.0830680076032877, 0.1636860016733408, 0.15798089280724525, 0.1285652055272034, 0.14333874492772988, 0.2677140917096819, 0.14738894759544305, 0.11181818773703915, 0.09349956749273197, 0.13823164254426956, 0.14224970979349955, 0.19486938124256475, 0.11519119888544083, 0.24558133791599954, 0.10138729959726334, 0.1354755282934223, 0.1456577062074627, 0.13544301289532865, 0.11727166867681912, 0.19696138612926006, 0.09906044695526361, 0.14781441619353636, 0.081583447621337, 0.11100144870579243, 0.12112437694200448, 0.1376505722956998, 0.07544835111392395, 0.14290512033871242, 0.2864065101104123, 0.1528551849935736, 0.1384444311261177, 0.16842172827039445, 0.18848280608654022, 0.1143189285482679, 0.104951589767422, 0.07325086117322956, 0.19980227654533728, 0.07092701444136244, 0.18313827072935446, 0.0931259932528649, 0.08008012614612069, 0.21349425826753887, 0.06043025412197624, 0.14878539980522223, 0.059246787269200595, 0.08471673234765019, 0.1291359213313886, 0.17033698835543223, 0.16420349319066319, 0.07450346395905529, 0.09612049721181393, 0.11925182385104043, 0.172396735687341, 0.13151637145451137, 0.11560783295759133, 0.16467207590384142, 0.14324526994356088, 0.14249003332640442, 0.20138437593621866, 0.15697804519108363, 0.1664642904485975, 0.15748967416584492, 0.1317688136228493, 0.09942509845963546, 0.09082093515566417, 0.16788124798664025, 0.12467721344104835, 0.1151848885097674, 0.18151687059019292, 0.10359019746205636, 0.07717871040638004, 0.09997934621891805, 0.14966832314218792, 0.07125444829996143, 0.1674853228032589, 0.13395774045160838, 0.3633907863071987, 0.11128219256975821, 0.17402084996657713, 0.1268215605190822, 0.12032276924167361, 0.18370229617825576, 0.15060356152909143, 0.18941359328372137, 0.1305365533168827, 0.08262814049209867, 0.09484867831426007, 0.15524562315217086, 0.12632974476686545, 0.09483413052346025, 0.11657569530819144, 0.07296431583485433, 0.11552681587636471, 0.15835153577583178, 0.1346108711191586, 0.1436182199312108, 0.05136542321581926, 0.15476167840617044, 0.10173280284340892, 0.13661109735923155, 0.1167598090001515, 0.21023761587483542, 0.13398060708173684, 0.08793706633150578, 0.14341115818492003, 0.17927906209869043, 0.11355054870780025, 0.29557112976908684, 0.1347320574734892, 0.14523633596088203, 0.08155537662761551, 0.09387376598481621, 0.1311087076153074, 0.12569785224539892, 0.18744799947100027, 0.09297938219138555, 0.1713048235646316, 0.150694946625403, 0.1055727953623448, 0.0828227646914976, 0.14142585971525737, 0.12746967002749443, 0.08741792597408805, 0.11273613705166749, 0.20138984492846898, 0.22345824646098272, 0.12139147546674524, 0.12205751187035016, 0.13155552292508738, 0.10757382227373974, 0.10411144806338207, 0.08317758422344923, 0.11960493347474507], [0.018785238598606417, 0.06579356454312801, 0.047615719959139824, 0.07124119651104723, 0.02950420217322452, 0.032628828792699745, 0.04384173871949315, 0.01996723303039159, 0.008446800855121442, 0.010009511956013739, 0.021143663475023847, 0.04604813443230731, 0.01614881622871118, 0.06964925836239542, 0.023120422581476823, 0.07126495880740029, 0.03802403375240309, 0.04491989015202437, 0.028295894153416157, 0.041295851580798626, 0.023913585913500617, 0.03748540586924978, 0.052189673629722426, 0.02511689143388399, 0.021544530089678507, 0.06222092839223998, 0.052903085348329375, 0.033614078603152714, 0.010080853976043207, 0.03779239886041198, 0.019464781241757528, 0.011917880669768368, 0.01520469072940094, 0.0336148928451751, 0.04731384990736842, 0.019297042296135, 0.037975101199533255, 0.011597793649083801, 0.03882413510499256, 0.048389653608735116, 0.03488722064399293, 0.009227614001637059, 0.02388941988881145, 0.03177665666277919, 0.020720618943284665, 0.01299430862335222, 0.04703722135829074, 0.055520293302834034, 0.08360835896538836, 0.06487598842275993, 0.030031542626342604, 0.014823466007198607, 0.031225401242928844, 0.09576303817863975, 0.015047187484534723, 0.030269565925534283, 0.015375104799334492, 0.016117807178358947, 0.01621014392003417, 0.024311144669939364, 0.03273958606379373, 0.03923117129930428, 0.03684919447238956, 0.039978998314057074, 0.09033195567982537, 0.034992196796728034, 0.026649291527324488, 0.014450889213808944, 0.03953631188986557, 0.015883137538496937, 0.006832387930314455, 0.0035638499705653104, 0.04732761059754661, 0.026336532684841325, 0.06000334024429321, 0.01659937874813165, 0.02169860334002546, 0.03207217223410096, 0.027133889363280365, 0.015116672863119414, 0.017209515740562762, 0.031074274530900375, 0.006740065183423991, 0.0585823454228895, 0.01745786295006318, 0.010456526585455452, 0.03415713731997779, 0.020607627595641782, 0.05226188671908208, 0.04476072619270001, 0.037989431859127114, 0.033721293921449354, 0.021858352535803403, 0.07569871017975466, 0.043476066019918234, 0.0034505689732863432, 0.06486060603388719, 0.030525655219597474, 0.08164715527423791, 0.023139287551332797, 0.04031167724835021, 0.013222908767472421, 0.017559024039655924, 0.008294555408480977, 0.027562815097293684, 0.009194307262077928, 0.04063937234293137, 0.03773045539855957, 0.03352060701165881, 0.03157988829272134, 0.033345107321760485, 0.042015845089086463, 0.07471233739384583, 0.033013792242854834, 0.028811916642423187, 0.025196534481697848, 0.023265252488532236, 0.006125894724391401, 0.037486759546611986, 0.04701072795848761, 0.033459857771439214, 0.026107888435944915, 0.009640647597344858, 0.07418550244931664, 0.018669319372358065, 0.03920114951740418, 0.02227208247807409, 0.050173274507480006, 0.042722356106553755, 0.011795427999459207, 0.09305240613009248, 0.02158515398124499, 0.016227093724800006, 0.0011827940428962133, 0.008355376743046301, 0.021173595351033976, 0.022718220949172974, 0.013508164889312215, 0.07387598870056016, 0.01441055369962539, 0.05274336159761463, 0.06966701562383346, 0.00880234981221812, 0.043889412589903386, 0.022797601064667106, 0.04536502269495811, 0.0497526269006942, 0.04639167331957391, 0.07700364158621856, 0.02962666078071509, 0.06008070680711951, 0.035664696246385574, 0.03931380668655038, 0.013411913848748165, 0.01302024392810251, 0.01727562371109213, 0.06021770302738462, 0.053578020738703866, 0.03327967618991222, 0.04235730426652091, 0.03653517525110926, 0.016480373883885995, 0.033808997965284755, 0.02141754056460091, 0.0522957150824368, 0.04335704419229712, 0.07371739471065146, 0.0323426939680108, 0.061180591716298034, 0.03162720932492188, 0.006023944837839476, 0.057509344071149826, 0.0429367019262697, 0.04049444744097335, 0.061804660728999546, 0.050811368839016983, 0.01704610075934657, 0.043086108552025895, 0.02727758781319218, 0.014222805604471691, 0.014389972036172236, 0.024471653824938194, 0.013690103028368737, 0.031001576289002384, 0.045551300913627656, 0.03374754983399596, 0.019256772939115763, 0.027783771544428806, 0.036994112588997395, 0.07415467660341944, 0.015525430840040957, 0.06903289072215557, 0.07001728897116014, 0.03533338795283011, 0.014872076255934579, 0.037351093254983425, 0.010726377417865609, 0.023554501788956777, 0.11444057630641119, 0.03653037461585232, 0.05703103116580418, 0.06334304889397961, 0.06494293947304998, 0.03667819346966488, 0.02561513800173998, 0.027733308895091926, 0.01048865182591336, 0.034867152970816405, 0.007580952003731259, 0.027451520087197423, 0.032153430195259194, 0.01360820809246174, 0.014238724884177958, 0.02195951871440879, 0.019431589004982795, 0.017255805399534956, 0.02198332341920052, 0.036493482666888406, 0.04292214735011969, 0.017706620673249875, 0.030456481967121363, 0.04537748059790049, 0.024808777163603475, 0.016189684392884374, 0.07286233202155147, 0.009883231500030627, 0.0075706637165110025, 0.025441868995715464, 0.05017009557091764, 0.05048661858641675, 0.03478995604174478, 0.03982824818896396, 0.014048370366383876, 0.030416529825223342, 0.06209547405264207, 0.037771846034697125, 0.012959212247681404, 0.05235067641894732, 0.011373414840948368, 0.03736699472314545, 0.06412866352392094, 0.03844833866293941, 0.050560578903449435, 0.01626115957541125, 0.013486107412193502, 0.014631119989124792, 0.0236692301862474, 0.010613714311537998, 0.08057745160268885, 0.01896820217370987, 0.06938118953257799, 0.028883108536579778, 0.04711548698001674, 0.007350912517202752, 0.0423841165777828, 0.0529437363812966, 0.04361818178689905, 0.01880137076867478, 0.028305342753550837, 0.010423115521137203, 0.016206730888890367, 0.04169706255197525, 0.0660830411527838, 0.03078781740207757, 0.04333468985610774, 0.03414447246385472, 0.04781560959028346, 0.02481582374977214, 0.02492301192666803, 0.03390469175896474, 0.07890540560973541, 0.057704667161617956, 0.06353853483285223, 0.04056323053581374, 0.07505817312215056, 0.02007699285500816, 0.05878230969288519, 0.03029029517035399, 0.00994982716760465, 0.042520841384040456, 0.07668300664850644, 0.03185598419180938, 0.021866520401090384, 0.020169945367212807, 0.0506356486252376, 0.037290764706475396, 0.002191186138328963, 0.00996745890006423, 0.03137921495363116, 0.007299173373862037, 0.014991545916668006, 0.06340281425842217, 0.050989840512296984, 0.025530422904661725, 0.045970594843051264, 0.11639645349766527, 0.046176716818341186, 0.0270593692548573, 0.03334055435178535, 0.06277161384267466, 0.0363723947001355, 0.023774486234677688, 0.0443188438325056, 0.07909055067492382, 0.03928179679704564, 0.013214716305291014, 0.0076048873265140825, 0.020960879711700336, 0.01986637558521969, 0.049109406237091334, 0.07672421408018895, 0.014914586474852902, 0.03854671945529325, 0.0286151143456144, 0.05524552393970745, 0.041524270216801336, 0.12902764071311268, 0.06873356178402901, 0.043640302028506994, 0.01986839422690017, 0.0322927402199379, 0.022702575627980486, 0.018356071984661475, 0.0030105095398279703, 0.008705672142761094, 0.01095595465241266, 0.06737198627420835, 0.036425513814070394, 0.025443319364317825, 0.06396392200674329, 0.11954583307462079, 0.006938372555721019, 0.062125424588365216, 0.019376805783914666, 0.02268882850850267, 0.02463016639064465, 0.0398079939186573, 0.026407392096838782, 0.030090500534112965, 0.01627903218780245, 0.07953429222106934, 0.012175821516263698, 0.03456659249163099, 0.01017096936370113, 0.026498724606686404, 0.02153533254750073, 0.06540563928761653, 0.04545006348884531, 0.04223530027749283, 0.03328499251178332, 0.04116966103070548, 0.04023993234815342, 0.13478228263556957, 0.23159298566835268, 0.28041390595691545, 0.2291535979935101, 0.09076080338231154, 0.0711636942412172, 0.10038867246891771, 0.08606977188693625, 0.19618877901562623, 0.061786082440188954, 0.07389867891158376, 0.09498228864478213, 0.08909225184470415, 0.2005762000169073, 0.0939543963010822, 0.21292905216770514, 0.19444184989801475, 0.1827503251177924, 0.07138495772544827, 0.14785834455064364, 0.11050594172307424, 0.11508694876517568, 0.16520380308585508, 0.16294439003935882, 0.10335170597370182, 0.11595190449484757, 0.1436594748603446, 0.05426400946453214, 0.1383263524621725, 0.09015951279018607, 0.2324594206043652, 0.08995397774768726, 0.10655307490378618, 0.15531125105917454, 0.19884330300348146, 0.11837492590504033, 0.0667088200737323, 0.07938956070159163, 0.14063706275607857, 0.12024509055273873, 0.09638990954096828, 0.09902011483375515, 0.07321251715932574, 0.0869462898533259, 0.09564200110201325, 0.10804233034806592, 0.1465074491820165, 0.12281178496778011, 0.19954444680895123, 0.11566511488386563, 0.11442160446728979, 0.09847645222076348, 0.07551524109606232, 0.18070868110018118, 0.09514500134225402, 0.07003296313009091, 0.11244834320885794, 0.09866082375603062, 0.10182205055441175, 0.12020973887826715, 0.07907942270061799, 0.10079314719353404, 0.13311277436358587, 0.114951241761446, 0.26871734644685474, 0.13907115321074212, 0.10688829834439925, 0.0870821461347597, 0.09596364027155296, 0.12356109118887357, 0.10267040253217731, 0.06509723833629064, 0.15406787634960242, 0.11026584210672549, 0.16577039339712688, 0.12828240570213112, 0.16729835926422051, 0.07349838396268231, 0.18394692162317888, 0.19939188499535832, 0.15247140558702604, 0.15176072157919407, 0.09835094359836408, 0.09500930112387453, 0.12824945604162558, 0.12443243871842112, 0.12715280774448598, 0.1639354582875967, 0.15245874412357807, 0.1288392251091344, 0.18400988967290946, 0.15070555891309464, 0.07591630278953485, 0.1899801293121917, 0.19705397901790483, 0.07839292168085064, 0.20710643460708006, 0.08264722768217325, 0.1949582557593073, 0.09509494581392833, 0.10353491721408707, 0.10481874618147101, 0.07016808659370456, 0.1639089954218694, 0.22209311542766436, 0.07306665248636689, 0.11192320460187537, 0.1020978411127414, 0.13587606751493045, 0.13193361620817864, 0.1395508096154247, 0.11114398177180972, 0.13049174286425114, 0.08365856377141816, 0.06784808715539319, 0.148644250950643, 0.10600728169083595, 0.07897308269249541, 0.13102108160299913, 0.2033682901944433, 0.14142249418156488, 0.11092990397342614, 0.08154895090098892, 0.2078639239604984, 0.09201273441846881, 0.16412996713604244, 0.1620729746563094, 0.24915078495229992, 0.08618268011403935, 0.1074312688516719, 0.13664506482226507, 0.11796263445700918, 0.07574877249343054, 0.10791076919330017, 0.1249865439853498, 0.06926750099020344, 0.10335610966597285, 0.12337696392621313, 0.23431833514145442, 0.15026684531143733, 0.22731750937444822, 0.21645481511950493, 0.09689456317573786, 0.13731262114431175, 0.14747212241802896, 0.12872162141970225, 0.16209267931325094, 0.09194114897400141, 0.16649607302887098, 0.14431009494832583, 0.1327208253954138, 0.12000085865812642, 0.23161730436342104, 0.15273663135511534, 0.1384981032460928, 0.13479944957154139, 0.20803852459149702, 0.12829555571079254, 0.25580373938594547, 0.08499542025050946, 0.08256922329642943, 0.13124407535152777, 0.1364862062036991, 0.0668222304167492, 0.2644530524100576, 0.15758593114359037, 0.105106010766966, 0.11662441412253038, 0.11770313552447728, 0.0977456835763795, 0.1507221151675497, 0.23483396747282573, 0.14548942952283792, 0.07985777700585978, 0.12309100212795393, 0.14360102585383824], [0.032319813767181974, 0.03815431926133377, 0.0670314227629985, 0.034723557997494936, 0.07517024675118071, 0.0668729373386928, 0.021420739857213836, 0.04701182718521782, 0.007812896477324622, 0.03699969693220087, 0.03486091384131994, 0.014491061879588025, 0.0675977688016636, 0.03631511955921139, 0.09386238695255347, 0.021027389714228253, 0.02942233353054949, 0.036839854437857866, 0.015833136292972734, 0.07329071832022496, 0.03598135496888842, 0.014162281128977026, 0.011261632133807455, 0.07379741434540067, 0.069482596591115, 0.022511227056384087, 0.015253613104245492, 0.0013468823640973174, 0.03594707198707121, 0.04406577741195049, 0.03175423786576305, 0.013242409863908376, 0.07197712202157293, 0.09763547591865063, 0.0663346622937492, 0.017558391305751035, 0.013468775083310902, 0.07597086379038435, 0.007577631422983748, 0.04160769949001925, 0.09103685178394828, 0.027298549456255775, 0.029834896392588104, 0.03844509865822537, 0.03994936329711761, 0.02108425603780363, 0.046237031796148846, 0.05066942949114101, 0.03423391355733786, 0.01851284071537001, 0.028659137697624307, 0.011984190504465784, 0.023150739526110034, 0.027936406300536225, 0.03770332756851401, 0.04122177930548787, 0.06082792314035552, 0.008610305742227604, 0.035775331381176195, 0.007063053789482052, 0.013618255499750376, 0.028631918265351226, 0.024698937611122216, 0.026343531773558686, 0.016936790464179854, 0.04594250688595431, 0.04623073499117579, 0.010544936305710247, 0.008741599723829754, 0.06396247672715358, 0.013105095580353268, 0.007925599447584577, 0.02874062636068889, 0.022333247320992605, 0.015796831276799952, 0.09149505291134119, 0.04204756660120828, 0.0480552613735199, 0.05474167097625988, 0.036420034643794806, 0.0597565977701119, 0.027924618450924754, 0.02222106173368437, 0.015713385040206567, 0.040744501166045666, 0.08205538908285753, 0.029078194139791385, 0.07395184213029486, 0.03973675113437431, 0.02784959622658789, 0.030059413452233587, 0.06781009597969906, 0.024787898641079664, 0.02684204975542213, 0.01860848531526114, 0.0272796115438853, 0.016949175424607735, 0.01745563226618937, 0.03827701196340578, 0.07214584653931004, 0.011284939811698027, 0.03997862511979682, 0.004675739012392504, 0.018427481010024036, 0.03319870321346181, 0.021383218567020128, 0.10119813760476452, 0.014824100437441042, 0.03976500533255083, 0.061120968844209395, 0.034921388274856975, 0.07150359278810875, 0.04033707142142313, 0.03653429654826011, 0.08541795079197202, 0.039188868033566644, 0.04168517461844853, 0.03770764305123261, 0.038111761544964144, 0.09954279714397021, 0.025087641485567604, 0.017983741160216074, 0.02546863041685096, 0.05754377293799605, 0.0740227083276425, 0.033672171378774304, 0.029893141838588884, 0.034034179989248514, 0.048647632622825246, 0.04196764874671187, 0.048951120980616124, 0.04105109042887177, 0.062438792416027615, 0.020199587169502462, 0.029504253063350916, 0.01170391567783164, 0.029447242551084076, 0.05116924856390272, 0.0398354067334107, 0.07514203326510531, 0.023035929704617177, 0.07597481964954308, 0.05223949167079159, 0.033177373465150595, 0.05785329347210271, 0.04206213474805866, 0.0035938615744401303, 0.044955201114394834, 0.05694865022919007, 0.05180954134890011, 0.08082892346595015, 0.06804672149675232, 0.018555529049730728, 0.007898974581621587, 0.016062269087082574, 0.006673653992558164, 0.051130392256059816, 0.051833025445895534, 0.0547522018397493, 0.042866629614893875, 0.054184854961931705, 0.04646043945103884, 0.025909189633759003, 0.04329703116257276, 0.05029041679309947, 0.005666814894149346, 0.061570871488324234, 0.07655004092625209, 0.024216733307444623, 0.018315112218260765, 0.033676568285695145, 0.005340635901250477, 0.03133883872734649, 0.06548475647079093, 0.05276537327361958, 0.053775610136134286, 0.012763851837787245, 0.031108669470995665, 0.013123661994801035, 0.008937558092709099, 0.04815559295405235, 0.08980225731751748, 0.04913144844717213, 0.020163534907624125, 0.053107198859964094, 0.03150153446144291, 0.018884606659412384, 0.011346706006276821, 0.031422206932412725, 0.04701415795300688, 0.010472584964840539, 0.04329027295378702, 0.047771894971707037, 0.03852364247930901, 0.029633938068790094, 0.024869999681998576, 0.05220652165423546, 0.025066262543467537, 0.031243569018053155, 0.01967532726536904, 0.07399929208414895, 0.04173022934368678, 0.005974742567299732, 0.03552323526569775, 0.015364390731390034, 0.017788923578336835, 0.034729501964258294, 0.05139611674738782, 0.04479701763817242, 0.06143342064959662, 0.028043779378224696, 0.02730369784070977, 0.01992285853650953, 0.03354611653568489, 0.036026067033942254, 0.06248987253223147, 0.01661055930890143, 0.022130882733368447, 0.042821344187749286, 0.01795300013119621, 0.045047356347952566, 0.02290358653824244, 0.03372446607266154, 0.016772897115775516, 0.056296713783272674, 0.0786425004314099, 0.027661172140921866, 0.0183505894217108, 0.08795677777379751, 0.057700867365513525, 0.02756241476163268, 0.024288822564163377, 0.06896651642663137, 0.06694561522454023, 0.05632210795634559, 0.09099299128034286, 0.056496230220156055, 0.03425626450085214, 0.03748437788869653, 0.031915844551154544, 0.021519812755286694, 0.054361263888755014, 0.028332044802872196, 0.07495891023427248, 0.0192644844896027, 0.05325756900544677, 0.011409945470014853, 0.024779459361785224, 0.01962996889570994, 0.03593515691214374, 0.043833175607557805, 0.044717296558831415, 0.03053862541647894, 0.03759695702631559, 0.036738433808620484, 0.024818833052579845, 0.08655786248190062, 0.03279922929193292, 0.04263691497700555, 0.029745397623628378, 0.058902871794998646, 0.04057351712669645, 0.06355574248092515, 0.06245174564953361, 0.005032333761586675, 0.03772188889394913, 0.0678617867774197, 0.023962874697255235, 0.024078749818727374, 0.019556921208277345, 0.05363293457776308, 0.00445140091635819, 0.01528957037122122, 0.011753979687845069, 0.01664432999677956, 0.04530711651646665, 0.0312027822780822, 0.03781808141086783, 0.01907941067059125, 0.013672138813750019, 0.020589564993445362, 0.04161191997783525, 0.02343456054638539, 0.03224361089191266, 0.020584618473159413, 0.06609980096774441, 0.02468371807065393, 0.05405065769861851, 0.03559395218534129, 0.046859601246459145, 0.06053512170910835, 0.0308152132534555, 0.01750203557977719, 0.093820453488401, 0.05435226990708283, 0.049523146357387304, 0.018960202245840004, 0.07769082792635475, 0.10576778597065381, 0.06624308042228222, 0.07993094343692064, 0.008919495490512677, 0.014132445944207055, 0.03079664853534528, 0.019008876955402747, 0.01772221171164087, 0.050420882113810093, 0.03685346585033195, 0.059237565978297164, 0.0374543255727206, 0.028162679069542458, 0.048367675859481096, 0.013033555936999619, 0.011256437100070928, 0.02269621436218066, 0.01909406533065651, 0.019197041501424143, 0.045032805164477656, 0.045989057780908685, 0.02902430828128542, 0.03153131536341139, 0.029192252483751093, 0.046419561108840365, 0.10910066177270242, 0.01835715594435377, 0.025667787230174457, 0.049369970469602516, 0.010827215355155724, 0.011696255865639873, 0.03327881445043853, 0.0266040027075048, 0.011180419125594199, 0.03407321610887136, 0.010372976024102951, 0.04828297094042812, 0.043197534180113246, 0.04571666668302246, 0.007906753137441618, 0.016630350479057858, 0.0036747259852875558, 0.07117978230650936, 0.026317073996844034, 0.025841208906578164, 0.055826387235096524, 0.03404109086841345, 0.01289551901364965, 0.03140232585636633, 0.0230844398694379, 0.05045821511053613, 0.018268946391929473, 0.016621892540050403, 0.014573122208405818, 0.07050627523234912, 0.21115217251437052, 0.18324219515281065, 0.07664093069200005, 0.20214274738516125, 0.15543337379183086, 0.09537502471357584, 0.1516467005546604, 0.09959113597869873, 0.11350003177566187, 0.15169199955250534, 0.12287165889782564, 0.15737592455531868, 0.13264877854713372, 0.24359765435968125, 0.1648625135421753, 0.10060963061239038, 0.07667014840990305, 0.08787312797669854, 0.19879113723124775, 0.16756640773798737, 0.18758163015757287, 0.14270116628280707, 0.10472881993544952, 0.21092934161424637, 0.13997274983142102, 0.11538680696061679, 0.14199350854115828, 0.08735853380390576, 0.08816115252141442, 0.0798121319551553, 0.10282757838389703, 0.10734579379537276, 0.17423504990126404, 0.17103198463363306, 0.07939819845237903, 0.22615764875497135, 0.11701800514544759, 0.20493519040090696, 0.13904146051832608, 0.22504867826189312, 0.11249673632638794, 0.0702675191153373, 0.10803937193538461, 0.18332349721874508, 0.14070769825151988, 0.14646365653191293, 0.12880246208182403, 0.11221757344901562, 0.13384689497096197, 0.08522023247288806, 0.09817338455468416, 0.17058891483715602, 0.14014901965856552, 0.17483723615961416, 0.1020892101473042, 0.1401949700500284, 0.1252381176288639, 0.0994403383561543, 0.15151780604251794, 0.10633946529456548, 0.09307991393974849, 0.12621538447482245, 0.05921542538063867, 0.07686513901821204, 0.11712902704519884, 0.25291209455047337, 0.12443366008145468, 0.0844473335891962, 0.11609244266791002, 0.15309146445776733, 0.08392691080059324, 0.15714856104126998, 0.11186651978641748, 0.13703333613063606, 0.21248325466045312, 0.1380544091973986, 0.22099008890134947, 0.09833816678396293, 0.12375744565257005, 0.1730952196355377, 0.13344388588198594, 0.12692012451589108, 0.14012848718890122, 0.1472226386623723, 0.1547826315675463, 0.18514665296035154, 0.171534249825137, 0.10502112603613309, 0.08627038076519966, 0.16331287526658603, 0.10499707875507218, 0.15572316252759524, 0.11621935585779802, 0.18861041138214724, 0.1568796169012785, 0.09711290217403855, 0.0963306055803384, 0.10651996918022633, 0.14022200288517134, 0.08071486172931534, 0.17759282115314687, 0.105935967660376, 0.09811136645397969, 0.08382381418985979, 0.13675664312073163, 0.1964044581566538, 0.1205388962158135, 0.26425882854631966, 0.1739993675478867, 0.16146637792033808, 0.23712215040411266, 0.15958433890981333, 0.1119395572958248, 0.19804919990045683, 0.08875866367348603, 0.10299695429525205, 0.16665167467934744, 0.15972418497715676, 0.15450113452970982, 0.08874362733747278, 0.1702150691832815, 0.22718510005090917, 0.22190326132944652, 0.18071999906429223, 0.10176066349127463, 0.12318305218858377, 0.11332052533647843, 0.16438726761511394, 0.11947948592049734, 0.1025449006951281, 0.13524109444447927, 0.12125146655099732, 0.08357084276420729, 0.09712982483740364, 0.11072108482143708, 0.09093812493873493, 0.17275992834142276, 0.0878830820854221, 0.2696351600544793, 0.13767208185579094, 0.21130031027964183, 0.12439392507076263, 0.1464651357382536, 0.09627198694007737, 0.0710569131853325, 0.12510052429778235, 0.11849060255501952, 0.13604176576648438, 0.21074148240898335, 0.1533941589295864, 0.13064771092363767, 0.044434065864022286, 0.1346196649330003, 0.14109371682362898, 0.16943195834755898, 0.118299486381667, 0.1329567384506975, 0.11130522204829113, 0.13571407406457833, 0.07717045263520309, 0.11288802033024174, 0.12649034043507917, 0.06304437813482114, 0.14022064581513405, 0.06801200764519827, 0.11435832429145064, 0.24911349266767502, 0.10469025200498955, 0.10529670624860696, 0.07422860977905137, 0.09002238764826741, 0.13291404502732412, 0.13417092258376734, 0.1310334987938404, 0.0859351030417851], [0.0317630995331066, 0.01876036180848522, 0.009203062908324813, 0.03165735663580043, 0.01686850778891572, 0.1292739896369832, 0.03068144685987915, 0.05579999561554619, 0.03005351359024644, 0.06856609934142657, 0.03484168076621635, 0.024971695117918507, 0.07997943154935326, 0.026758496649563313, 0.029570094708885466, 0.022387441912932054, 0.06087734084576368, 0.05662122654861637, 0.08568475754665476, 0.025009711738675833, 0.04637474047818354, 0.01966057252138853, 0.02052477507718972, 0.012677840738823372, 0.024095267057418823, 0.01660809961945883, 0.04303856021059411, 0.04543117307392614, 0.02472256250413401, 0.04563090664201549, 0.07477364303278071, 0.04322736597220812, 0.019153262422020947, 0.021243749086612036, 0.035615064802446535, 0.03861384692468813, 0.0734101336981569, 0.020673241931945086, 0.03179414929555995, 0.049205510544457605, 0.0710575170814991, 0.04186778535534229, 0.029170142420168434, 0.03253330124009933, 0.05137691759903516, 0.03624582077775683, 0.015459801236699735, 0.017360420232372623, 0.038016278097139936, 0.055171773968530555, 0.016368778622043983, 0.019731021419699703, 0.011957732727751136, 0.021028025840808238, 0.043612709401973655, 0.06815228797495365, 0.065676693671516, 0.03244522400200367, 0.04949278530797788, 0.003260733746823722, 0.02863858487190945, 0.07326441151755196, 0.08321440831891128, 0.017223632661625743, 0.04587989167443343, 0.03533734720466392, 0.038805438072553704, 0.030349928220467906, 0.07547507182295833, 0.010382622247561812, 0.08205693614270006, 0.00884042665295835, 0.01868929374696953, 0.02672444436965244, 0.03184030664020351, 0.08949975283550364, 0.037322129987712414, 0.03584542065592749, 0.019207139798839177, 0.07992032436387879, 0.03652483777010015, 0.003555574599886313, 0.03829419247007795, 0.020541095540725758, 0.026019721291959286, 0.09226841319884573, 0.03256983695817845, 0.04900503398052283, 0.03665101814216801, 0.013941447666314031, 0.017459650889837315, 0.03317559909607683, 0.08237760500716311, 0.05346746363544038, 0.01614859570483012, 0.01887185189739934, 0.027524337072723677, 0.04245495902640479, 0.03586908456470285, 0.007789577773239995, 0.03511427203193307, 0.07455769247774567, 0.02702826351326491, 0.00491138531859698, 0.004044660732948354, 0.009107762664955641, 0.055083381211651225, 0.018870761152356863, 0.08131478846605335, 0.012612822665167707, 0.0144292744807899, 0.03273081599867769, 0.03339362257559385, 0.04564097949436732, 0.06628609954246453, 0.034502840733953884, 0.044981843791902065, 0.02046042960137129, 0.047048803951059065, 0.034883203716682534, 0.06497252359986305, 0.07238000218889543, 0.07168999992843185, 0.02249152579211763, 0.019379401180360998, 0.017311173857056668, 0.04326110951868551, 0.03747505481754031, 0.007567812173095132, 0.005172752342852098, 0.02679944284526365, 0.011835078193273927, 0.03680480471146958, 0.010969560975874109, 0.01373625613216843, 0.05301395118502634, 0.01732934672119362, 0.021751286495210867, 0.10398456880024501, 0.008887403328636927, 0.06913973284619195, 0.08041304256767035, 0.08648561885846512, 0.05946556052991322, 0.031989380783800564, 0.0066235865898696435, 0.09925441976104464, 0.029899767733045986, 0.05964282780353512, 0.18277062688555035, 0.03516868714775358, 0.0647326275440199, 0.07925454580358096, 0.019994133551205908, 0.023868107103875706, 0.07919024782521383, 0.08196687418967485, 0.01552341559103557, 0.04919272015935608, 0.01763448222274227, 0.03602208064070769, 0.03190568009657519, 0.009512452824440385, 0.03585870297891753, 0.03234029534671988, 0.03318399257425751, 0.010574888537770935, 0.03624803280191762, 0.03926874178328684, 0.03897449167977486, 0.01742268430202135, 0.04707336013338395, 0.057360955247921605, 0.04239773816828217, 0.024616388737090995, 0.07907970089997564, 0.010238980624957808, 0.03282579054523792, 0.016017165168055465, 0.025579520002273575, 0.05174250887440784, 0.0258838904555887, 0.05101993354037404, 0.0212530297493296, 0.01438812811725906, 0.008335029174174582, 0.047422697102384906, 0.02240054103146706, 0.044980327266135385, 0.013837070320732892, 0.009021465733115162, 0.0415861390398017, 0.038463799083339315, 0.02938194034088935, 0.027158372603090744, 0.011960038050476993, 0.10198026456471, 0.0332213459270341, 0.026595811093492166, 0.030379553059382097, 0.016481052418904643, 0.04422123317739793, 0.008909958680825574, 0.024423357398648347, 0.03399414303047316, 0.008209328865632415, 0.03413817226620657, 0.02449801830308778, 0.045463132073304484, 0.013243524357676506, 0.01567379761088107, 0.020884159453479306, 0.009581774506451828, 0.056015349059764824, 0.03929753541680319, 0.052327843715569804, 0.042673043574073484, 0.051144013846559186, 0.05148244336513536, 0.03254755726084113, 0.046600665497992716, 0.026153874450496266, 0.050585793264742406, 0.040656125372541804, 0.03287518789459552, 0.00903122900386474, 0.02941175177693367, 0.04005236830562353, 0.027709008859736577, 0.031078657867120843, 0.02660134115389415, 0.022519795257332068, 0.022896877523245554, 0.01756445740881775, 0.024979437202481285, 0.025808591728231738, 0.04336842322455985, 0.04846589380343046, 0.04140479716339281, 0.012659002062199371, 0.02386340655253402, 0.03686795596565519, 0.0333600588408964, 0.008273512341215141, 0.07429127927337374, 0.027420131057234745, 0.01993907891613032, 0.01707055007240602, 0.06123034868921552, 0.02286924248827355, 0.02599394035392574, 0.045296690825905116, 0.022260820493102074, 0.054783757110791545, 0.05578207889837878, 0.053175788572324176, 0.019844854150765708, 0.0029974867564825608, 0.04069411994091102, 0.035244655928441455, 0.021079696282478314, 0.05123365171519773, 0.05368243710004857, 0.004953568144368806, 0.055371551641396115, 0.04026727391672986, 0.027134651018838798, 0.043573988801134486, 0.04281950196517365, 0.005558140725562615, 0.02530822134576738, 0.037709376708205254, 0.03217045124620199, 0.029555092299623147, 0.07636686361261777, 0.02799320307427219, 0.04644190865967955, 0.044297802461577315, 0.005474414169189653, 0.04477307553003941, 0.04361366952902504, 0.019844660768285394, 0.02166465962571757, 0.0208124722287591, 0.005590899548094187, 0.04063895843657, 0.032930468142564805, 0.06922545896044799, 0.016229611089719192, 0.02738741209863552, 0.06624983863106795, 0.029612900090536902, 0.032000196631997824, 0.025192731292918324, 0.011209418015953685, 0.0379882817422705, 0.01708065176249615, 0.09648623437221561, 0.05890968428658588, 0.08542374548103128, 0.0025806705400879893, 0.016445643068956475, 0.0518686892464757, 0.05280775796355946, 0.03428669001108833, 0.021008848744843687, 0.04896500380709767, 0.03042022105572479, 0.0943388474572982, 0.03843903594783374, 0.032464111024247747, 0.01469300577550062, 0.019709136969010745, 0.019862441778449074, 0.04480445098930171, 0.06957297745559897, 0.0417574827027108, 0.04771644848265818, 0.02861433063766786, 0.035220618825405836, 0.035173487783010514, 0.02773008924642844, 0.06635680289140769, 0.052145612958286486, 0.08396083755152565, 0.034556495890553506, 0.030755278255258287, 0.03707797612462725, 0.04719707063798394, 0.02968036343476602, 0.04879302910662123, 0.0971166951847928, 0.04590075323358178, 0.037455652108682055, 0.04899169058938112, 0.05119522288441658, 0.05011799765218582, 0.036319278978875706, 0.06574715953320265, 0.09119957805212055, 0.05716690780328853, 0.02934951993769833, 0.007223827997222543, 0.02561233225943787, 0.0663607655359166, 0.026682443051998104, 0.02625139519971396, 0.06540973763912916, 0.10137882469488041, 0.05142922925629786, 0.03293828147330454, 0.023386679722794464, 0.1104703593466963, 0.0983285383720483, 0.10456203602786575, 0.13872598244675569, 0.13797054226909364, 0.17149918313537324, 0.13355151510664395, 0.13438943800117287, 0.06618490961513349, 0.08278091265154736, 0.12689731216856412, 0.08760866895318031, 0.2363343983888626, 0.09534902325166122, 0.09268081321247987, 0.12931087480059691, 0.20035693821098122, 0.15906452680272715, 0.19580700807273388, 0.0684618152944105, 0.18776858012591088, 0.13586347390498432, 0.14445295371115208, 0.09832062665373087, 0.11038246192038059, 0.15441445846642765, 0.185192915477923, 0.12596561573445797, 0.13943752140871116, 0.12782675586640835, 0.14467590674757957, 0.08914954734167882, 0.07849431516868727, 0.09197911979364497, 0.09742416654314313, 0.13986615197999136, 0.11676466731088501, 0.10214181018194982, 0.08998006063380412, 0.09822603887213127, 0.11919805673616272, 0.12296647738133158, 0.1995889858475753, 0.19434575576867374, 0.1285969881074769, 0.0987421190366149, 0.0961961131542921, 0.14885602172996315, 0.13607035923217023, 0.1230035661054509, 0.10910779317574841, 0.19499638942735537, 0.14847783345196927, 0.05914386707757201, 0.19445248932710715, 0.17048903448241098, 0.11078254652342626, 0.11466008238494396, 0.10467730555683374, 0.05720067849116666, 0.1093476145927395, 0.15875759827239172, 0.182238763996533, 0.11599680994238172, 0.08915305536772523, 0.13851624727249146, 0.14271389559975692, 0.10723886346178395, 0.255069971616779, 0.11772070958146028, 0.14851056598126888, 0.13735963005040372, 0.09558250715157815, 0.12264472964618887, 0.1141115411051682, 0.13142882686640533, 0.15697439467268332, 0.12455456145107746, 0.11402725348515169, 0.09932088905147143, 0.10416488948145083, 0.07781597013984408, 0.15966113550322397, 0.1399602105042764, 0.08292892149516515, 0.21150491572916508, 0.11519581292356763, 0.1763813104480505, 0.1347881858902318, 0.15288554265030793, 0.09634128572153193, 0.11729108834905283, 0.24340953731111117, 0.197359224781394, 0.09994039830884763, 0.118143355473876, 0.08984248087342296, 0.10811726097017527, 0.1842767439250435, 0.07410439715853759, 0.1571305255804743, 0.1232295318373612, 0.07185877872897045, 0.11388500540384225, 0.08641988917120866, 0.11145407227533204, 0.08179025830967085, 0.05755093148244279, 0.15997324804110186, 0.12521041982940265, 0.09070411856685366, 0.10108358732291631, 0.09715689838464771, 0.2012672879334007, 0.1434362232685089, 0.07690447369324309, 0.1643297007041318, 0.09916165723864521, 0.13426460112844193, 0.15317416430584022, 0.20281727904719965, 0.2465211089168276, 0.17166133943412984, 0.12105935971651759, 0.09332738923174994, 0.0840914419719151, 0.1263755594513246, 0.1248305080724614, 0.08317842560687236, 0.09292792209557124, 0.10506115960223333, 0.07896875363907643, 0.1648319930370365, 0.11022033954837493, 0.061112609292779646, 0.14138609756316456, 0.15786938236228057, 0.11116962361016444, 0.26338525542191094, 0.14756217758570397, 0.14648439256208284, 0.14835398724036558, 0.23883876257709094, 0.23194682810987743, 0.07868355180003814, 0.10146005212196282, 0.14314711306776318, 0.14035259373486042, 0.20711286711905683, 0.22904704085418157, 0.09083160851150751, 0.09630142178918634, 0.10543049299823386, 0.144010101045881, 0.11914321753595557, 0.20687946464334214, 0.1624991896429232, 0.11375332889812333, 0.1322780812957457, 0.1656610406935215, 0.10923673518534217, 0.12357797314013753, 0.1197588387876749, 0.18133557960391045, 0.12630682385393552, 0.1647721326776913, 0.1766177663313491, 0.12756774547908986, 0.1047190965286323, 0.11747779404478413, 0.10093431640416384, 0.1716039760836533, 0.13148635306528636, 0.14696734664695604, 0.11945007821278912, 0.217726824006864], [0.05299235341538276, 0.07735001335718802, 0.05438211526987808, 0.050719535909593105, 0.01817836027060236, 0.030100532674363682, 0.04244390569095101, 0.049760043288448026, 0.03281334282032081, 0.033977549456592114, 0.05383992847055197, 0.08017668846462454, 0.035830075586480756, 0.06481764119650636, 0.03454310839463558, 0.020642656965979507, 0.038348919712007046, 0.057950839666383605, 0.011015441817497569, 0.08593256532081536, 0.02018870346780334, 0.012521979548702282, 0.018528860927160298, 0.04540750577247568, 0.03696551573063646, 0.07619937402861458, 0.041472525136279206, 0.04368077664236937, 0.011899243009143641, 0.009751140239781566, 0.02032338927632996, 0.05472072120755911, 0.03625805476414306, 0.030291238334029913, 0.09120869756277118, 0.07276254666170903, 0.028728198991822343, 0.08470911239939076, 0.035752379934170415, 0.05858544632792473, 0.10976903912212167, 0.025162509343187724, 0.037024531313883405, 0.014575212096263255, 0.011089032332945083, 0.10258298686572484, 0.025949693085359674, 0.016626026514651518, 0.05087311891838908, 0.10399950335600547, 0.048696029133030345, 0.005814142234157771, 0.019223903006474887, 0.01317843418967511, 0.04986855460863028, 0.04453207006944077, 0.034686387849173377, 0.014717044574873788, 0.02270698780193925, 0.012298666040546127, 0.04875436278858355, 0.052531695991222344, 0.019983141283903803, 0.08048954739102296, 0.03942524249266301, 0.048895878052072864, 0.035372763339962275, 0.04760042577981949, 0.03517670403899891, 0.03768373826252563, 0.02594058375273432, 0.0829904917627573, 0.04681063137416329, 0.015084062470123172, 0.022452006216294, 0.015048941497557929, 0.012790927929537637, 0.04396724734189255, 0.03256889379450253, 0.00890390360395291, 0.018379537421943884, 0.05735063473028796, 0.013763347490956741, 0.029907825336392437, 0.07383744112615075, 0.0558843341256891, 0.024210010721747364, 0.09191498466368232, 0.06620089590017285, 0.014568706641771963, 0.006496360849788678, 0.03502069526751127, 0.020105464184390645, 0.06037166262311595, 0.06566013741706099, 0.047832878306508064, 0.013795795035548508, 0.025737398137737597, 0.029192425510180846, 0.016500361829197834, 0.005420036796879555, 0.07361602157886539, 0.040267545330737314, 0.023667540634050965, 0.02984461301405515, 0.04107331584340759, 0.030361914541572332, 0.022355503269604275, 0.05315733241981693, 0.030136936078114167, 0.03218737730224218, 0.008828403860596674, 0.039335570697273524, 0.009712904791480728, 0.08548325978751693, 0.04497291087838156, 0.04271047156570213, 0.02797912177629769, 0.03810658432277186, 0.07499642643545355, 0.055726863111236265, 0.02601428622645991, 0.02074611489661038, 0.03510766649352653, 0.04283285553434065, 0.0736334870702454, 0.08214200407798801, 0.05127053687881146, 0.05926136898675135, 0.018472325389406512, 0.040921191684901714, 0.02475217716502292, 0.0039057845465971953, 0.05636505922302604, 0.07563099917024374, 0.027246078343263695, 0.05144494412732976, 0.05087125633976289, 0.06192752306482621, 0.050300594818379195, 0.01858525736523526, 0.012098197110130318, 0.008325717977381178, 0.036714919177549224, 0.05620110480647002, 0.041124976107052395, 0.04032397908823831, 0.03388921098251428, 0.048904397059232, 0.021727023779281547, 0.026964352299858416, 0.10559859326375381, 0.01543442063432719, 0.05263439226629479, 0.030205315444618464, 0.01443972222373954, 0.05385623027437499, 0.06844371876546315, 0.10206808735217367, 0.02759808534756303, 0.025996881803231578, 0.018981637167079107, 0.03569312347099185, 0.030555731284299066, 0.04424716678581067, 0.0315571166574955, 0.04583317453839949, 0.013257932200628732, 0.024761887001139776, 0.06819645381931748, 0.04333401810643928, 0.024764645245990584, 0.06576155126094818, 0.052360990151230774, 0.020956077380105853, 0.036094015530709705, 0.005007436191330531, 0.0397564354352653, 0.018130041791924408, 0.05650498332189662, 0.04387713449874094, 0.03789412483040776, 0.02866331747333918, 0.01676200153971357, 0.019070549003247703, 0.02050933670917792, 0.0789555154208626, 0.09183413043086018, 0.03623191420254963, 0.018367924295099716, 0.02814910328015685, 0.006558562579032565, 0.0035183681923496935, 0.04598861334047147, 0.029141481100980724, 0.023394155482362424, 0.016980357501389723, 0.0031458257497953518, 0.014029356118823801, 0.03343566121267421, 0.051468214485794306, 0.06642414749200855, 0.07966982280569417, 0.035951017668204646, 0.010901581096862043, 0.07113894806908709, 0.0424905990782593, 0.08001552282699517, 0.07802120662693467, 0.03081327603597726, 0.08351294337106602, 0.04729377205616661, 0.019073444651439786, 0.027585279695423584, 0.039600569156131575, 0.04055183793285063, 0.038857614022812674, 0.012415554723702371, 0.014270449788974864, 0.023586934066510627, 0.043221028455133946, 0.037438251078128815, 0.014946000949878777, 0.02541311607430024, 0.06081451528838702, 0.0598117694524782, 0.05294343104053821, 0.014748090944652046, 0.026597178341554742, 0.04106668316360031, 0.03143772163561412, 0.05819763642336641, 0.07283930932836873, 0.019639303841228997, 0.013413907045365443, 0.05146552748712046, 0.028365908789315393, 0.04861121904104948, 0.058627040524567874, 0.05416789497914059, 0.013681158240485405, 0.03436742550028222, 0.03217821707949042, 0.06732657871076039, 0.06701873415814978, 0.06777276298297302, 0.06318328782383885, 0.049121440055647066, 0.049936567566224506, 0.026188116720212356, 0.017346182871343832, 0.06749185627060277, 0.04633522599137255, 0.017110056077529277, 0.027830612513103654, 0.05563451788787331, 0.012376260760772442, 0.05586928761165057, 0.030559609111930643, 0.012434830207244625, 0.02554960169696382, 0.06262799512062754, 0.049693570605346134, 0.04385230350973351, 0.07259825297764369, 0.002633247462134542, 0.019655746441068392, 0.07344989585024969, 0.03084518075255411, 0.02137668088211545, 0.029643871821463108, 0.054465093317308595, 0.027734664268791676, 0.055898410334650955, 0.06698931287974119, 0.05236541759222746, 0.027289241652137468, 0.09991142486355134, 0.021840045661000267, 0.017907602745773535, 0.034255619892584424, 0.041236676541822295, 0.043514135227139504, 0.022349454129913023, 0.017814005625301173, 0.03998294738786561, 0.03457468741440347, 0.050602610755179606, 0.019442562612571886, 0.028037072059565356, 0.008907559211365879, 0.029157932182507854, 0.051447013659136634, 0.01284298683250589, 0.07926743796893529, 0.057510402585778914, 0.06009956329528775, 0.07202981705112116, 0.06367626387093749, 0.01777663530914911, 0.01078087735056345, 0.06053006662321942, 0.03173776642818536, 0.03262652177363634, 0.02923787378572992, 0.032988805190793107, 0.03410735659833465, 0.019340677186846733, 0.029651047329285314, 0.05812991184315511, 0.011113241614241685, 0.028964257932135036, 0.031742166727781296, 0.040883590666843314, 0.07238685539258377, 0.041435029291148694, 0.03815655503422022, 0.00731327333154955, 0.09212634153664112, 0.02540570477555905, 0.04763051541522145, 0.048731031361967325, 0.036114201947514496, 0.003314551751827821, 0.059429129984761984, 0.013320967255692397, 0.02216241255934749, 0.0857520614351545, 0.012267792697197624, 0.10519807439829622, 0.08757624854998929, 0.01844186764875693, 0.052447123386498005, 0.01063558179885149, 0.006037328516997929, 0.021950173590864454, 0.04552717220836452, 0.09179021564445325, 0.04199879350406783, 0.014886893764404314, 0.03179911956457155, 0.023607678578368256, 0.05873665785683053, 0.019576405341337835, 0.07014199013688735, 0.015158838725515773, 0.008934564905108085, 0.030326661254678453, 0.0333038829267025, 0.002364995003777689, 0.022676319715433886, 0.03013737712587629, 0.0941341741542731, 0.13460427575877734, 0.08506974019110203, 0.15503579298300402, 0.09698558186313935, 0.09814721345901489, 0.10026597298149552, 0.15796707783426556, 0.09301474065120731, 0.10438714362680912, 0.15855767471449717, 0.20157410789813313, 0.09389729757926293, 0.12346165866724082, 0.18708032848579542, 0.08195961386497531, 0.1056038790515491, 0.1156885786248105, 0.13774619145052774, 0.1763224814619337, 0.1067741619689124, 0.07509556718702827, 0.07146364064621073, 0.16948909099612916, 0.1110070398343461, 0.25708304931010517, 0.15342272525387152, 0.10194354903485094, 0.11632383667996951, 0.1327188169317586, 0.17454979515501431, 0.11731227221233503, 0.18467264196702413, 0.10306520813277789, 0.2195918182177203, 0.12119679019919463, 0.15104338792817934, 0.10834689757653646, 0.11649778591735022, 0.11052838766149112, 0.3018265169646059, 0.10700360180011817, 0.07259978646678583, 0.1029677162212985, 0.14233140540974482, 0.27172871200101717, 0.07525548432022333, 0.07021680540804352, 0.1403289535748107, 0.17372191457876138, 0.11380081277872835, 0.06094384406294141, 0.08426233101636171, 0.11767589912882873, 0.10624720488807984, 0.154085762532694, 0.1454741217728172, 0.1105703686230949, 0.09764230876628842, 0.11214918390448604, 0.12015969013529164, 0.13656913675367832, 0.09763177790279899, 0.2049424642963069, 0.18166521191596985, 0.10344586627823965, 0.0848121140152216, 0.18734741343983582, 0.11977243662944861, 0.2212430874684027, 0.12594976515642234, 0.24741832220128604, 0.14751668859805378, 0.1254506076553038, 0.12608144166214125, 0.07703483384102583, 0.15259510252092565, 0.14852556160518102, 0.11754195631614753, 0.1750265745712178, 0.0707166346588305, 0.2597847586231572, 0.10030690899917058, 0.24000847552503857, 0.1692575884184667, 0.13551013357937336, 0.15422008532498563, 0.16886782433305467, 0.27176196021693094, 0.0651570444128343, 0.09469152281859092, 0.22197856514581613, 0.08645154961517879, 0.11892996755029474, 0.19858149705188616, 0.1825040304767234, 0.10411407399390425, 0.16019003997956002, 0.17806413157710008, 0.08580025099217892, 0.0849752202630043, 0.1652731765061617, 0.12063577744577612, 0.10186931051846061, 0.11866578672613416, 0.1794809941202402, 0.17437914359782422, 0.10128939377942256, 0.09326499115143504, 0.14219656693083899, 0.1103287423029542, 0.11115904524922371, 0.17560505281601632, 0.09536580342267241, 0.23023444999541554, 0.14715493443821157, 0.22400484713060514, 0.11450216014470373, 0.12835731596818992, 0.14485653276954377, 0.14455685099320753, 0.1570480835757085, 0.1419918800571135, 0.09137614643467323, 0.13078159945351736, 0.09577905160507985, 0.14278043274368557, 0.2013315859117678, 0.10182369939450707, 0.11367746868303844, 0.07872972610805716, 0.09490672019975525, 0.07626673898526601, 0.1957325863518885, 0.2382611392864159, 0.08142002246209554, 0.183896167203784, 0.149210339146001, 0.227871872484684, 0.11385903108332839, 0.1471651667462928, 0.06335858056055647, 0.11804237589240074, 0.08621462554271732, 0.13693163730204105, 0.11108824012002774, 0.06847909758133547, 0.0906116206731115, 0.15814371407032013, 0.06423954971666847, 0.11289044270025832, 0.18194624754999364, 0.07083881845963852, 0.2767038664647511, 0.2190788864557232, 0.11080681772104331, 0.12722520743097576, 0.24663173726626805, 0.14901977937136376, 0.09225963295570441, 0.06783095414617232, 0.22897837311029434, 0.16120955241577967, 0.0993949104366558, 0.07456055589552436, 0.12654264191431658, 0.15259872589792522, 0.08784745221159287, 0.1259773951023817, 0.1502877984728132, 0.1160387434065342, 0.14082414843142033, 0.12192417973918573, 0.19638984251235211, 0.08594842946955136, 0.1023921285356794], [0.07709079940936395, 0.04481492756998964, 0.0657510475388595, 0.0176427247268813, 0.03032273253692048, 0.028604077973536084, 0.07336995085435254, 0.028127742997769798, 0.06634904723614454, 0.018694772917245115, 0.031010057976735488, 0.08795543427446059, 0.12587921108518327, 0.04459374890263591, 0.029630138272685663, 0.003375486741008769, 0.02626994125811117, 0.01476791434522186, 0.043724450548844676, 0.054570680151560476, 0.009083496556351227, 0.0452541263241853, 0.043697061482816935, 0.03877554181963205, 0.0500884847715497, 0.043640753254294395, 0.051552223906453164, 0.027270693897402713, 0.03164526174909302, 0.024686471226492097, 0.02695007253039096, 0.020134926174900362, 0.04121009832514184, 0.060084106267562935, 0.030368699891758815, 0.06223340665123292, 0.06077986250498465, 0.07301869363124881, 0.019567767590550438, 0.057894249845828326, 0.028704236527638774, 0.0031344674976675636, 0.03733817734090345, 0.01218376207231943, 0.00975375429594091, 0.019787780874009644, 0.002006653875079272, 0.022343518644837395, 0.0346585611280586, 0.029131333609776836, 0.061236509787184853, 0.02207624539732933, 0.030107755679637194, 0.0813464964074748, 0.027940564023862993, 0.04218053910881281, 0.10534938770745482, 0.008271989030098277, 0.053725452827555795, 0.009416794653848877, 0.06408195317323719, 0.017668034083076885, 0.05550168787262269, 0.03899634050737534, 0.043330262415111065, 0.04734241623165352, 0.10870614794215985, 0.04609887528100184, 0.06757887160139424, 0.03159869049808808, 0.04102247321446027, 0.03503022189917309, 0.02940831838973931, 0.024334213164235865, 0.03584074215697391, 0.024006665651021258, 0.03933740613449897, 0.021431543831048266, 0.006984632528786148, 0.11188235679375273, 0.02288988691621593, 0.05815714145345347, 0.036721114202269485, 0.0419002600413348, 0.0430175324103662, 0.015086379667211856, 0.07275973074138165, 0.028803750473473753, 0.020683638784768324, 0.03626965092761176, 0.0482112905010581, 0.03924304905480572, 0.008733960267688547, 0.05170436842100961, 0.014195896601969642, 0.0199301273428968, 0.019763826891513805, 0.09429747039186102, 0.059384604516838274, 0.036076807882636786, 0.07957237160631589, 0.031978330841021876, 0.007915805642759162, 0.07300886844417878, 0.04332739560465727, 0.07930898466812712, 0.018824698802615916, 0.020502603945455382, 0.05725764829133238, 0.04018732213548251, 0.061852307458009036, 0.011256479508509594, 0.016702137787693312, 0.06529109579111848, 0.032261473326278586, 0.0833675197458693, 0.06619025647108044, 0.018513749952294996, 0.023988279048353434, 0.017445869843608568, 0.0384968403460724, 0.021085448563098907, 0.015365318628028035, 0.05372463180018323, 0.04776229030851807, 0.038360461592674255, 0.0414215230516025, 0.0334780866147152, 0.01874809728802315, 0.08107655482100588, 0.03158676863781043, 0.02471451338247529, 0.02287051983044616, 0.06395079235413245, 0.04418857189427529, 0.0327051605896226, 0.01779646549506911, 0.02143295348754951, 0.04138077363105757, 0.029563000625265495, 0.000670206531399994, 0.038764861678438525, 0.00952169786406947, 0.005481261435696589, 0.035696102239723713, 0.022531873180664012, 0.06404840640191521, 0.03305820235982537, 0.02195447719922023, 0.04418893151783517, 0.013829631032422185, 0.012399123998225799, 0.05107943427615932, 0.009967167978174984, 0.031265760505838056, 0.020585035772195885, 0.007166194929076093, 0.10579388921282121, 0.037079479079693556, 0.03474711673334241, 0.004721987535179193, 0.034494576177426746, 0.023561789255057062, 0.09509399586490222, 0.03165058485631432, 0.031454087900263925, 0.024685806262173822, 0.0681701402312943, 0.062476878586624346, 0.033712798663015874, 0.04625066356467349, 0.011682071939243801, 0.02387989834616227, 0.0411135767187391, 0.008388715713018817, 0.01304192142561078, 0.046671440093112845, 0.037115193770400116, 0.043837759111608775, 0.060638014759336195, 0.03783420679558601, 0.028343350892620425, 0.0696047871772732, 0.03089578589424491, 0.04776266011010323, 0.023677094407113533, 0.0368743240168052, 0.05313132077987705, 0.1102827037019389, 0.018171831067385416, 0.010678763767438275, 0.04036781584311809, 0.022265940039817776, 0.04085776223135846, 0.02732200132283781, 0.008750676826041724, 0.035167092590459754, 0.05793128428714616, 0.043197137237127335, 0.042875728769493957, 0.01649672657783542, 0.026765332889876196, 0.026375906375635947, 0.017805912398866246, 0.05961851589381695, 0.027122496760317256, 0.03479044797963329, 0.022495328980897154, 0.04785800785092371, 0.023058743748281683, 0.079501023649105, 0.05619236866810492, 0.01919559113282178, 0.06290261181337492, 0.00993878485834492, 0.041250840960336585, 0.07500627197857414, 0.01756191799151046, 0.02123222586565784, 0.027081460658726946, 0.026805293513461947, 0.04039110655763319, 0.046067462502313514, 0.04194993559005005, 0.04095412438203182, 0.04034064730097141, 0.00658380874665454, 0.03352045434127961, 0.0325972735216575, 0.040326686442962716, 0.025596086434753876, 0.030335173476487398, 0.0257895825696843, 0.010136952706878739, 0.012312959380713957, 0.06392220567379679, 0.054257753371660195, 0.03677739868206637, 0.028294528601691127, 0.0411570504573839, 0.04038354428485036, 0.012817695287854543, 0.01537844997697643, 0.015925026897873198, 0.06145424488931894, 0.052503265373940976, 0.04086983336934021, 0.006554022755673421, 0.016307518784222857, 0.010964859576363648, 0.01606904934825642, 0.01529142277182213, 0.06051902685846601, 0.03409480709316475, 0.03223867794232709, 0.029426513306264366, 0.03866549701030765, 0.05849342340869563, 0.01758778205008379, 0.04185480837311063, 0.04590617812105587, 0.017070879161890064, 0.07373000867664814, 0.06056824100336858, 0.046182145098490376, 0.033871535145278485, 0.020109623604054962, 0.037569171017301936, 0.018688496468322616, 0.07432861227009978, 0.07314269590590682, 0.047972045838832855, 0.02789180280108537, 0.029179187291967015, 0.02976676808404071, 0.04708633033026542, 0.013145229230368776, 0.035980757858072004, 0.02880504647535937, 0.041761458917920075, 0.028739310002752712, 0.024017566316095845, 0.047488660884222815, 0.09207773128790514, 0.06264858865844351, 0.044928694143891335, 0.05036326092002647, 0.011587792042908924, 0.03939131913440568, 0.022749465790444186, 0.008587334787340035, 0.09050407965800591, 0.052925198804587126, 0.03459631911079798, 0.050945851087038, 0.013479829266933458, 0.0407676290321563, 0.02966497086786798, 0.01655495336412319, 0.032146868761628866, 0.03380360021921141, 0.024232867173850536, 0.03607657039538026, 0.05178082235423582, 0.015806196756394844, 0.04961590887978673, 0.02426042756997049, 0.02879693798188652, 0.04387754501242723, 0.012885169658277715, 0.03870044495644314, 0.06146529822477272, 0.006196313088626734, 0.03180838496025119, 0.02779005647503904, 0.017894469700487595, 0.03482121615005391, 0.04241388051637581, 0.017886196662272726, 0.04399721144831606, 0.05263675356815968, 0.01849358219520322, 0.026316010393202305, 0.010032855256992792, 0.023082831741443703, 0.08693674965096371, 0.034806149279964824, 0.052690510505012104, 0.024123008961656263, 0.014309543584074293, 0.03902977532041924, 0.026836655402023877, 0.014406423117699367, 0.021533232481618012, 0.0446046495677105, 0.05447406694293022, 0.01534905583996858, 0.016446616766708236, 0.030046941978590827, 0.05812736055148499, 0.071417622401246, 0.00980640182803784, 0.042608392757496664, 0.07435673754662275, 0.05451735747711999, 0.023238674271851778, 0.03131515106984547, 0.03990475979766675, 0.047534027735569646, 0.04705944338015147, 0.028742950343127762, 0.01864575215482286, 0.18127415861402238, 0.14913736949009554, 0.23856799996324948, 0.14525043591856956, 0.07299511453935079, 0.07874348001288516, 0.23694008588790894, 0.09989426471292973, 0.1769650676952941, 0.0355029267125896, 0.11158759439630167, 0.18427939021161624, 0.2311504722705909, 0.13817129363971098, 0.09170446917414665, 0.07881129958799907, 0.08622029809547321, 0.14629821612366609, 0.0896303029730916, 0.11155568289437465, 0.09931103672300066, 0.14234798880560057, 0.13059550443930285, 0.09271045840744462, 0.09474465889590127, 0.06895006195242916, 0.07911169382610492, 0.1315698671553816, 0.12287069537809917, 0.11891901599509375, 0.10100962700588362, 0.13642768934369087, 0.1276477447577885, 0.0925033763051033, 0.23702406138181686, 0.15803269217056887, 0.16116567834147386, 0.15899994383965219, 0.053027528670749495, 0.13107175459819181, 0.1922108403273991, 0.084766027916755, 0.12726859296006815, 0.1338582400764738, 0.08098864382398979, 0.11471952205257756, 0.09555036494774477, 0.16257310924785479, 0.1493201261120183, 0.15090590316270078, 0.13492571136781148, 0.14372686695839676, 0.15237813416336263, 0.1675243385668312, 0.07601563353091478, 0.12478742109877722, 0.1714083408670766, 0.08819864158119474, 0.08945108830396618, 0.1290430570287364, 0.13459974314485276, 0.11299609060266189, 0.1656304659055812, 0.09251947115574564, 0.11035005508788995, 0.1460673242275204, 0.33744010595338686, 0.14250487967261247, 0.21045082514839514, 0.11636670652244772, 0.17010388443512575, 0.12999356245355947, 0.10276075625526053, 0.15988578487719807, 0.08807731273451022, 0.08891651127487421, 0.07682961092463561, 0.30329144692846705, 0.11438457002597195, 0.14493636919983796, 0.13215625711849757, 0.1111432353832892, 0.11139003892562219, 0.1413811713989292, 0.1705674867012671, 0.12095652094909123, 0.13711326755583286, 0.0873350225655096, 0.11017194643084492, 0.20389228207724436, 0.14445793415818894, 0.09344610571861267, 0.11943441762455873, 0.16325039576206887, 0.20238151028752327, 0.08646528994930641, 0.08707732853612729, 0.18022035301796027, 0.15951831745249884, 0.09735473884003502, 0.1427193238799061, 0.09458950507853713, 0.10322361213288136, 0.16349318916244165, 0.18605491279491357, 0.16448223537632398, 0.12309906312397548, 0.16019168203430517, 0.19639691284724645, 0.12374643981456757, 0.11069835389831237, 0.12643635618899549, 0.12356654661042349, 0.10946203595293419, 0.11711089658950057, 0.18023518579346792, 0.22515243983694486, 0.08317396084644965, 0.13014703350407736, 0.104003343864211, 0.14940806425043515, 0.10130514257720538, 0.10068469694150345, 0.12722224901829446, 0.16085736559970037, 0.12231159609343324, 0.11491252455328192, 0.13616208359599113, 0.06424263705100332, 0.10482223385146686, 0.12706550742898667, 0.14305867281343254, 0.05812497210821935, 0.23413029951708658, 0.20476565164114746, 0.17433088618729795, 0.13080504962376185, 0.10292736374373947, 0.14683385166738713, 0.156615802486028, 0.10753625178975718, 0.12381398119032383, 0.1338231326746089, 0.08928961054022823, 0.07836188548909766, 0.11226701829582453, 0.13937995449772903, 0.07773911247828177, 0.1138807577746255, 0.09685008520526545, 0.11742592682795865, 0.18592555687895843, 0.14513910189270973, 0.09897620683269841, 0.08510813170245715, 0.13595494042549813, 0.1317874597651618, 0.1470288626317467, 0.16073319369128772, 0.1287450308778456, 0.13231911909367355, 0.08815464537058558, 0.13232845573553018, 0.1956021583506039, 0.1390225158206054, 0.08096151599394423, 0.15688481447952135, 0.12019391544163227, 0.1551313849964312, 0.10230995794492108, 0.16520503801958902, 0.22976419808609144, 0.14208255947700568, 0.12466084717639855, 0.1549727570797716, 0.06593259636844907], [0.03251905200470771, 0.011342533864080906, 0.04142221515732152, 0.07871331234595605, 0.05440711589264018, 0.012559322723453599, 0.019393657201102803, 0.04524499324283429, 0.03473895734974316, 0.043306581542960236, 0.027102020269791995, 0.09018194515790258, 0.0460147539020649, 0.06708588876894542, 0.009601602147865509, 0.05247463458882911, 0.02431852713094226, 0.1129224356263876, 0.10855786768453461, 0.04137476520346744, 0.08071087194340569, 0.007143387670761773, 0.03643100316237126, 0.03256628822003092, 0.014198267233691044, 0.036113550553896596, 0.02694505306759051, 0.047129922812538486, 0.029558790315474783, 0.06028618078146662, 0.05992349702864885, 0.039245515529598506, 0.04536123986222914, 0.015175937807985714, 0.061802075510578494, 0.03350627635206495, 0.08726951679480927, 0.012596591259352863, 0.029726086516997645, 0.011245367649410452, 0.06883649554635797, 0.057785297477883954, 0.013228253927081823, 0.0478108700231782, 0.060468842408486774, 0.06325065956584044, 0.08018328382500581, 0.04182780607204352, 0.01617494152326669, 0.01576262293383479, 0.054113330585615974, 0.043593140452035835, 0.01837548996055765, 0.039184433807219775, 0.024426361612443413, 0.027911490494651452, 0.032125613652169704, 0.01052550391094493, 0.05525956282924328, 0.0840894877910614, 0.03966666525229812, 0.025253003862287317, 0.028856974760336534, 0.01919936209118792, 0.029665846178042035, 0.04448857258207031, 0.0420542807052178, 0.022158319296847497, 0.019393775944731066, 0.01654374735829021, 0.07899192560996328, 0.013342610826449735, 0.018369617239971246, 0.02514560703587319, 0.0554470624109464, 0.008243202181932117, 0.027802066544869115, 0.023416021273338368, 0.06556729347045932, 0.047309646382927895, 0.02611406480095216, 0.030578038123037134, 0.0115723545230659, 0.030186272359320095, 0.07365948174680982, 0.019939662456246357, 0.05994248243847063, 0.008029197326063045, 0.04940308637118765, 0.038473132332520824, 0.047434130417449136, 0.023684178312708224, 0.07882814761251211, 0.012344509562743562, 0.026430991544787372, 0.06971316957580191, 0.010094585828483105, 0.02354794374800154, 0.0347078634825136, 0.024301746959931085, 0.038464375838105164, 0.039571439647780995, 0.030430707814438, 0.04259850650227495, 0.012449398354095007, 0.05637890473008156, 0.02333605083237801, 0.015725995613528148, 0.024237023200839758, 0.06611360237002373, 0.0574173347226211, 0.02160277044666665, 0.014345102211726564, 0.05278542059074555, 0.07927622499742679, 0.049887590908578465, 0.019936091665710722, 0.016281089845246503, 0.015492839106757725, 0.01891132567210921, 0.019799809603552734, 0.061365723210786066, 0.021071603056043386, 0.009723364408793194, 0.006543243802817804, 0.0275565573080842, 0.10219476305480514, 0.027797372778877616, 0.03276455954515508, 0.03818022912102086, 0.02451812838470297, 0.08496250451675483, 0.013173040684445627, 0.06374517588743142, 0.06873404354389225, 0.054867909023804326, 0.02308779861778021, 0.00724687019828707, 0.04916032350489071, 0.05997085877295051, 0.03540983510070613, 0.030243625531771352, 0.005039323944531913, 0.06735827986683164, 0.03978427911975554, 0.06187822071037122, 0.06706555985978671, 0.03679951213832412, 0.03429812332615256, 0.021414731429623704, 0.040605818786259205, 0.057951830327510834, 0.00521221466728353, 0.005916614168589669, 0.05363846803084016, 0.017897495966670767, 0.025975407866228904, 0.032800644037446806, 0.045351221292678795, 0.056031576224735806, 0.05206181388348341, 0.012269352479571742, 0.038202210262949975, 0.028486555708306174, 0.02602309700367706, 0.02841187614415373, 0.04409917151289327, 0.06627428624778986, 0.02489878822650228, 0.041090455637978654, 0.0579488854855299, 0.012129237542727163, 0.02540800331293472, 0.07121345799948488, 0.03337343276611396, 0.03529186160968883, 0.04545378864609769, 0.013995299598069062, 0.03324419559378709, 0.03873838524201086, 0.04865340695583394, 0.03437349160334893, 0.03377906439293708, 0.03439233112814171, 0.021258173044770956, 0.02776840272625642, 0.0376546833930271, 0.07343802148742334, 0.007626050833745727, 0.03324051793398602, 0.03176320470603449, 0.044998264339353354, 0.014605444224019135, 0.09086588810064963, 0.023875024768390825, 0.008630159676873257, 0.03616411837616137, 0.005396855072051818, 0.020107153736587082, 0.038418917384530814, 0.036884922733796496, 0.07662946345018488, 0.02946407700489674, 0.07325875253549644, 0.04540609781231199, 0.016706202212455015, 0.053957912139594555, 0.09533700639648096, 0.04558715470401304, 0.04146491875872016, 0.005833553000619369, 0.03402285863246236, 0.042908369696566036, 0.04221727160204734, 0.04182724288797804, 0.0030798238003626466, 0.02820456164356853, 0.013984846766106784, 0.009934948590983237, 0.025606691937095354, 0.019052980035277348, 0.06778961779283625, 0.03671935340389609, 0.00972254338142063, 0.031918073538690805, 0.029854584086154188, 0.026245832908898592, 0.020084675567756807, 0.04055848418335829, 0.04723407793790102, 0.1273427161255053, 0.02904227588857923, 0.056762538251600096, 0.015749688360041807, 0.047909322061708996, 0.11043318919837475, 0.025548945214333277, 0.017313073755108883, 0.008269899990409613, 0.022668803243764808, 0.06339073633509022, 0.029721187494163002, 0.0318927743605205, 0.019636235166607157, 0.03161393717995711, 0.02209317314970706, 0.015798083173909357, 0.04032309360003897, 0.03109484092731561, 0.024437591367002045, 0.026167251768388917, 0.05854069694344487, 0.06039838333215032, 0.03957868979445525, 0.0330855982112033, 0.021796105429530144, 0.014968984627297946, 0.018266980336712937, 0.02800695867543774, 0.011443957037824606, 0.040243582866553745, 0.04589567779164229, 0.05415144729028855, 0.019761906637411033, 0.016697669634595513, 0.012926457665993698, 0.03600327843534095, 0.045896756662321944, 0.025234551102455174, 0.00975726910733751, 0.017665484487744312, 0.06081584521702357, 0.04035436049369829, 0.019694156612136533, 0.05370508320629597, 0.043626232604895315, 0.04746509875570025, 0.013976234460382589, 0.05867917915540082, 0.07046457247010299, 0.012958523534637476, 0.054399489159030576, 0.04806678629081164, 0.05547565926930734, 0.03382575099489518, 0.09742379334888288, 0.03214553544031722, 0.021866262557783296, 0.03352611671601023, 0.024842172960883806, 0.008616460054846746, 0.03763193889920201, 0.051761209299521785, 0.071457683108747, 0.03932456146659596, 0.09002352758709874, 0.034082576499453614, 0.036329660564661026, 0.009338143963499792, 0.0295216812353049, 0.015069794575018542, 0.07250032001840216, 0.03168845728838018, 0.038586705523942194, 0.014739853529525655, 0.04250570326777441, 0.049380447050290446, 0.10613591835967132, 0.020532235569719757, 0.015474805342299598, 0.012639119289815426, 0.07724972588143178, 0.016437215664024864, 0.013808305524954838, 0.02644869452342391, 0.010837654616417629, 0.03469537504549537, 0.01402169545846326, 0.041187418292143514, 0.023972594711397375, 0.037127519359013865, 0.06332626872296844, 0.13517864208136285, 0.03810986843226211, 0.02157658408395946, 0.04078930483332702, 0.03344589352075543, 0.005618671562323081, 0.044104097677128654, 0.01042689920203494, 0.04693211289122701, 0.05043409319062318, 0.010337464893901986, 0.05384518711694649, 0.048377833528710265, 0.08252619739089694, 0.054013175424188375, 0.05519086794395532, 0.07228658148752791, 0.057891725695558956, 0.03823439317888447, 0.021946702884244065, 0.047263848661844216, 0.024729676943804537, 0.01652542352011161, 0.03356760573972549, 0.04773459250905684, 0.0029898171903499004, 0.045201733242720366, 0.06993142714990036, 0.007249917668689574, 0.04800769606871264, 0.07847600150853395, 0.0786499303898641, 0.16991707017379148, 0.15808574003832682, 0.16150620792593273, 0.09859353343823127, 0.15787098370492458, 0.10973697834249053, 0.09772327835006372, 0.14051825127431325, 0.09579947550914117, 0.2557211752448763, 0.21300365030765533, 0.0872181924059987, 0.134189975847091, 0.10189106435115848, 0.07250836744372334, 0.26520864186542376, 0.16173993609845638, 0.09049468194799763, 0.13528101944497653, 0.09292802387582404, 0.1120541143630232, 0.08752700047833578, 0.08081802619355065, 0.11900228581258229, 0.11464823516351835, 0.16768574847706727, 0.12511258865041391, 0.10953245431716953, 0.15682925603219441, 0.1449285660471235, 0.11842006205448083, 0.07208360452204943, 0.13144418889922754, 0.08675885812512465, 0.21672715193458966, 0.12581519809152397, 0.09783229178615979, 0.12000989674457482, 0.14367657394281455, 0.1491297563271863, 0.09827413343425308, 0.13818570572350705, 0.17669365368783474, 0.18228698069495813, 0.2001767735928297, 0.1036127655367766, 0.12518535474581377, 0.09549929840224129, 0.11334504759205238, 0.14455318690410682, 0.07596024471734251, 0.14184283305491718, 0.20312071990753922, 0.06596589886716434, 0.07934570698333637, 0.058389831467398574, 0.15377663554889814, 0.25627217282141956, 0.13890989257821015, 0.07225389645567962, 0.11544094048440456, 0.10288565419614315, 0.1834444257297686, 0.1304311632577862, 0.11723676483545985, 0.09843806749475853, 0.13158467278948852, 0.08654068876057863, 0.2824232652783394, 0.12879631455455506, 0.1191931984254292, 0.1892285296427352, 0.119374937244824, 0.08178931514599494, 0.12545811225261005, 0.09973723135356392, 0.23763346725276538, 0.10275688860565424, 0.15947187851582253, 0.1624695240919079, 0.13672589191368648, 0.20436733801450047, 0.1669720517737525, 0.09690903632768563, 0.14226146202002252, 0.0953763003594109, 0.16094381096107618, 0.14664783807737486, 0.13016372546553612, 0.13769949467054435, 0.15962496958673, 0.06444750712918383, 0.12308577740831034, 0.14321575367024966, 0.08982939193291323, 0.0950685982991542, 0.07679274611707244, 0.17163529726011412, 0.133820771372744, 0.07007407556687083, 0.1621524446776935, 0.12238468788564205, 0.0627882108092308, 0.2081590731229101, 0.15169862205428736, 0.10154065529682807, 0.15949337450521334, 0.21544215588697366, 0.11309448496571609, 0.09388382187379257, 0.13330220777009213, 0.14633100293576717, 0.10961933394095727, 0.1377637247954096, 0.11648703792265483, 0.16061203447835787, 0.12440486305526324, 0.2155351558966296, 0.14612763241997787, 0.1273167146635907, 0.1325108188071421, 0.10408342456711189, 0.08322947858167545, 0.12872749753296375, 0.14104984274932317, 0.08994443754532508, 0.08643850138677017, 0.09577354868607861, 0.09316965019596474, 0.192639823736889, 0.057646055306707106, 0.14009846879967622, 0.14953718946448394, 0.24079538615686552, 0.08384827537728207, 0.17286801896989346, 0.16224566181855543, 0.11200219964874641, 0.07752235446657453, 0.07003461875553642, 0.1888017039746046, 0.09801290423742362, 0.1281567681580782, 0.16727253422141075, 0.16362852975726128, 0.19790244634662355, 0.07706403120287827, 0.13432925194501877, 0.14428359137049743, 0.14227755687066487, 0.12064047290810517, 0.13837322566126073, 0.13256495233092988, 0.18314274906047753, 0.06722825220120804, 0.11201629960643393, 0.14168310591152736, 0.13781731549118245, 0.23817719093390874, 0.10174344227250133, 0.17608591701303208, 0.20595779695681163, 0.1413891916828496, 0.13951464369893074, 0.0854879484644958, 0.11715372571987764, 0.09098396676459483, 0.13750631575073513, 0.13691518961318902, 0.10266950008060251, 0.0804204453847238, 0.2698948218354157, 0.13070128804871015, 0.18797001003154687], [0.04073420439713767, 0.009691737043405218, 0.01893373598743762, 0.043124815582164695, 0.057963053296719275, 0.05316243161048208, 0.004759406196951334, 0.05837341770529747, 0.021372994740626643, 0.057164132595062256, 0.06283499579876661, 0.01853477775252291, 0.002801835636741349, 0.03309933515265584, 0.025265399000740478, 0.003617702326404729, 0.07339816434042794, 0.03401428194982665, 0.05753797824893679, 0.024799594888463616, 0.04008328914642334, 0.013723700689817113, 0.06029001450432198, 0.029935095658791915, 0.026730527436094623, 0.04987083448629294, 0.017315794680533663, 0.05944251748067992, 0.04761807108297944, 0.06332935605730329, 0.021142947620579174, 0.011036635858805051, 0.01952454660620008, 0.06278471635388476, 0.04117196804976889, 0.045655086237405024, 0.017299497965723276, 0.022198863460549285, 0.061793715959148746, 0.04268589163465159, 0.06707425867872578, 0.05633921721684081, 0.02622611298491912, 0.04517145022483809, 0.0175226121542177, 0.034562802873551846, 0.014977756388751524, 0.006422955235133746, 0.05549278210050293, 0.0571174222443785, 0.006451616978405842, 0.03729688169966851, 0.026388243838612522, 0.012500474229454994, 0.06758280031915222, 0.027926448799137558, 0.04888693496052708, 0.04328900070062705, 0.025738821364939213, 0.019409433140286377, 0.006060419911851308, 0.01885141442263765, 0.04985528585634061, 0.01034778795604195, 0.023042462300509214, 0.06571351776697806, 0.04178945188011442, 0.034568020807845254, 0.05910818970629147, 0.02251977490128151, 0.016654915143070475, 0.026506339465933185, 0.006492976232298783, 0.01984191609413496, 0.05980746754045997, 0.05025639843993953, 0.013172825249577207, 0.03199463264484491, 0.025542466901242733, 0.0036683129811925547, 0.11497668682464532, 0.02711501082272402, 0.034861690763916285, 0.01001284780379917, 0.0382344304983105, 0.03978226726342525, 0.07179985474795103, 0.023204623688278452, 0.05657750175201467, 0.030346511796649014, 0.03946885872366173, 0.026185080276003907, 0.06398003721343619, 0.0544912474496024, 0.015932807998199548, 0.023861940916893736, 0.044891184728060446, 0.01000289199873805, 0.020179653506992117, 0.03152492017086063, 0.028075433036844646, 0.021983267440061485, 0.05439097693722163, 0.03420940147978919, 0.0152575757487544, 0.045654044686151404, 0.034583786569003544, 0.05254424210371716, 0.011814024947982813, 0.036658668624503274, 0.009028206978525435, 0.029645049079720463, 0.007809706514568201, 0.0314777959138155, 0.019111703848466277, 0.015407431903960449, 0.02750274778476783, 0.012719139772733408, 0.020699287498635904, 0.05628805567643472, 0.012759282752605421, 0.03966510462175522, 0.06646441854536533, 0.06879204471728631, 0.04468884558549949, 0.02153256073194955, 0.06288241182586976, 0.026264621543564966, 0.06098199808704002, 0.02012167777866125, 0.031225068760769706, 0.05929632032556193, 0.008958711421915462, 0.04268219701147505, 0.023400269082880447, 0.05773393237697227, 0.05482102564669081, 0.06963609478303365, 0.0391845220167722, 0.04612673592886754, 0.044741130101361444, 0.03708443917067988, 0.05459401836352689, 0.05659764067136815, 0.007335553028886872, 0.009030916877756161, 0.00549722185158836, 0.025624142161437442, 0.01694421363728387, 0.03274406100224171, 0.03748045934896384, 0.019270687996010696, 0.032917243495051346, 0.015683972243485705, 0.00883351153294955, 0.06804759680692639, 0.046237700153142214, 0.038585046505821605, 0.028182816292558397, 0.01203330880629697, 0.03176002237679703, 0.008624394673721066, 0.03250612930527755, 0.02525897157777633, 0.03869642802913274, 0.015948624649484242, 0.037190056539007595, 0.003226297882585121, 0.0789053106148328, 0.010375204163470438, 0.032789980859628746, 0.0247881327356611, 0.02575649380949991, 0.031411693032298765, 0.01916421397722193, 0.062027803755232265, 0.023710349408377494, 0.05771411915442773, 0.01675093632989696, 0.030491653829813004, 0.018956377004672374, 0.015022432830716883, 0.02552384281131838, 0.1038180970187698, 0.04796983042199697, 0.007460026885382831, 0.06839890152748142, 0.0546374887094966, 0.03075856915009873, 0.014781742888901914, 0.005295376343253467, 0.013937379848877234, 0.024178547052932636, 0.03966293330969555, 0.04420273970546467, 0.06110442616045475, 0.04091000942779439, 0.02005146467126906, 0.049596502778253386, 0.04340315403948937, 0.029108477157673666, 0.08594390364097697, 0.04136844804244382, 0.06526888055460793, 0.036443813903523345, 0.029216588142194917, 0.047073590835290294, 0.0694661285462124, 0.0700112839362451, 0.07305813008653265, 0.02721930674410292, 0.04253888363018632, 0.012813057501002081, 0.00937254399260772, 0.07675940969160625, 0.03878989622795156, 0.02558861067518592, 0.044149298287395916, 0.06843931507319212, 0.05188076377713254, 0.0417969395140452, 0.031895156018435955, 0.011441329410964889, 0.02137841623542564, 0.05934814004493611, 0.022688048193231225, 0.06309835559555463, 0.02285765819916768, 0.016285425684015666, 0.01245809462852776, 0.05329547875693866, 0.03952138072678021, 0.04258495955062764, 0.014647771238482423, 0.021266446082985828, 0.02059278803478394, 0.018918472342193127, 0.014725068251469305, 0.07713590163205351, 0.006217113579623401, 0.028359744298670973, 0.03028802207804152, 0.061940571293234825, 0.020048647054604123, 0.01328486664819398, 0.01369232777506113, 0.017022620055026243, 0.06805856193282775, 0.054045314235346656, 0.030958859116903374, 0.027392204252204726, 0.05095549985500319, 0.032943957418735535, 0.05703226609953812, 0.05115966086408921, 0.024293889524415135, 0.06010683040533747, 0.028092253919956938, 0.07197883871517011, 0.008627007033542862, 0.028201835629131113, 0.01846864603326789, 0.03564650472253561, 0.015548348360295807, 0.01399937759353114, 0.033074538090399334, 0.030200643731015067, 0.07336000353097916, 0.01438761073430734, 0.051203046393181594, 0.01936392718926072, 0.01115053559520415, 0.03502654763204711, 0.004085265964801822, 0.021198059931131344, 0.011434165777505507, 0.025768800738400648, 0.024331527861899564, 0.08627863175102643, 0.023189575477902378, 0.02852820758042591, 0.015641104097345045, 0.02548300687755857, 0.040275833635990105, 0.06200708129576274, 0.02263444901577064, 0.025238059128501585, 0.036487810114132505, 0.04815743178395288, 0.02952118929741638, 0.015217718601758991, 0.0362378004938364, 0.06206914010856833, 0.04078195629907506, 0.0501164980897946, 0.032213914806821516, 0.018906569141628485, 0.03151407718126263, 0.035877776598291736, 0.027159295410716107, 0.029644516429730823, 0.06733204091766051, 0.03256480562101517, 0.06621796105589185, 0.028877775251333202, 0.016026713852105395, 0.01251140797311174, 0.015466413560456463, 0.026009460146139775, 0.020668468438088894, 0.04020250096384968, 0.027223666331597736, 0.04458038176276854, 0.06004097179642745, 0.031062942996088947, 0.03795784605400903, 0.04452646537018674, 0.026498558365606835, 0.07245518386896167, 0.05452958128548094, 0.010767018272807556, 0.01218949314872069, 0.01202275843492576, 0.03358935617974826, 0.022820996952110102, 0.06330043689480849, 0.025037638543705856, 0.05759684794715472, 0.04653131921908685, 0.048874629727963886, 0.035848779404269795, 0.038245670430894406, 0.06073630055678742, 0.06909269679869924, 0.039742481362606795, 0.012197100374448513, 0.03902711885582123, 0.056529549682246785, 0.019071181737152592, 0.011887869914062321, 0.03044808509626559, 0.04108133952000311, 0.023985115378828983, 0.07558162896228687, 0.06564362866005727, 0.01438895084096917, 0.01920212372871382, 0.05039033107459545, 0.06732338959617273, 0.03955455430384193, 0.04350251192227006, 0.02504620504831629, 0.14550276952130453, 0.17758305024887833, 0.07078059336968831, 0.12033566140702792, 0.1985282049115215, 0.13169842240001473, 0.10140449367463589, 0.18609831189470633, 0.0864707250148058, 0.180772531245436, 0.11742940092725412, 0.16452061331697873, 0.0815493648073503, 0.10410607406603438, 0.0941234804423792, 0.09519017820379563, 0.14786386782569544, 0.08713814562984876, 0.13943807780742645, 0.08291827528072254, 0.15409938751586846, 0.04372640133702329, 0.2046139176402773, 0.07981108701122658, 0.15832853343869957, 0.19317905551620893, 0.09536059227372919, 0.13756192848086357, 0.09900479351303407, 0.11443997919559479, 0.10725615253405911, 0.16373260345842156, 0.110488286241889, 0.12213818968406745, 0.17706519232264586, 0.13521449587174825, 0.12191998639277049, 0.07770762845341649, 0.13894117304256984, 0.11007925854729754, 0.16914208818759235, 0.12028295280677931, 0.17713898979127407, 0.18294794165662356, 0.1032912145767893, 0.1160009897180966, 0.13143812279616082, 0.06875321894351925, 0.21661338875336306, 0.1511892865278891, 0.16299686793770107, 0.07059051535491433, 0.06139465594398124, 0.1028430557676724, 0.22584489839417593, 0.11784623855991022, 0.19469798329685414, 0.17557012183325632, 0.09001517482101917, 0.11819955174412046, 0.11827651118593556, 0.10137380353574242, 0.1689668633043766, 0.09823366560574089, 0.11930036624627453, 0.08547148720494338, 0.1490480335695403, 0.18392405499305042, 0.1152581295796803, 0.06883686195526804, 0.10981156969709055, 0.204335446868624, 0.09110810474625655, 0.11052015703171492, 0.0818511839689953, 0.18442995713225432, 0.14123440427439554, 0.103489468938538, 0.09428935511303799, 0.15345901330666883, 0.20466190363679612, 0.15643915267927305, 0.12775541469454765, 0.12187961355916091, 0.2372294675026621, 0.10578401652829987, 0.12301579330648695, 0.12765093387237617, 0.14405948482453823, 0.06195847104702677, 0.0900129017287067, 0.12373205487217222, 0.13361170116279805, 0.1999145062374217, 0.08260263436074768, 0.11501819959708623, 0.15595182882887976, 0.09592615799712283, 0.11514241221760001, 0.09257297364196607, 0.16576964700860636, 0.07348889125777142, 0.16800517562244618, 0.08462808853281395, 0.1577247865498066, 0.13191985551800045, 0.09683823798383985, 0.1378417563225542, 0.13977263628372125, 0.11033605012510504, 0.121514195310218, 0.1964111349412373, 0.08670005628040858, 0.10657797035362039, 0.06266171831105437, 0.10787712742707559, 0.12282578993056502, 0.13475917173283442, 0.12120045428829533, 0.1527820389185633, 0.1445646948580231, 0.09327138973666088, 0.11841764646981444, 0.15863650691296372, 0.11628841715199606, 0.16106000329766954, 0.12756015945758137, 0.23144805058836937, 0.15337852548275674, 0.1206521572811263, 0.13372488080390862, 0.13907097679163727, 0.07291591593197413, 0.11544856721801416, 0.09271852618881635, 0.1145165315163987, 0.11462668489132609, 0.19262435313846382, 0.10416076398853745, 0.19515463736440453, 0.10500828136823007, 0.11794702815158026, 0.1240848387990679, 0.10763869700687272, 0.10410875427935805, 0.13483549335173198, 0.06917599375758852, 0.1394638078553336, 0.05775157428745713, 0.1469751497996705, 0.11665118911436625, 0.10266407858580351, 0.12765432654746942, 0.08907200435974769, 0.06955028045922518, 0.15675810485013894, 0.20598269919199602, 0.10269116570374795, 0.1541907319000789, 0.09335048656378474, 0.16819832740085466, 0.22132577374577522, 0.13857115432620049, 0.07297532167285681, 0.14523556243096078, 0.15877870071147168, 0.12925933328058037, 0.15406901628843375, 0.17571437837822096, 0.0983914453536272, 0.07405681828302996, 0.09784289050315108, 0.14511699522180216, 0.15814063352133545, 0.1749830397644213, 0.1977254572723593], [0.046699144677924256, 0.04759442413757954, 0.01753172996853079, 0.054405636686299524, 0.03843516829822745, 0.12898378020950726, 0.008626180068988885, 0.03919828270695039, 0.01704308297485113, 0.023527940535651784, 0.04482219468003937, 0.0635248962789774, 0.03471771581098437, 0.04780086163165314, 0.028688026326043264, 0.06933254535709109, 0.06617586474333491, 0.05207797998030271, 0.012780171453154512, 0.018447141562189375, 0.029018869823110954, 0.04072307642283184, 0.008752273079673094, 0.015466137057436364, 0.04709248464288456, 0.05059768459094422, 0.04805631649547389, 0.05277058102988771, 0.0352889642651592, 0.049001580237277916, 0.050124331776584895, 0.006572923348617873, 0.030990957215960537, 0.015364490815305283, 0.03391658987051674, 0.06276375640715871, 0.059590580607099194, 0.0428178191983274, 0.01575988843770964, 0.021005332237109542, 0.014461582925702845, 0.01858414287146713, 0.046079625242522786, 0.037339456379413605, 0.038940639567694495, 0.05162791788045849, 0.03814179689756461, 0.012476173345930874, 0.024040324380621314, 0.02851325606128999, 0.08914431583668504, 0.04984962348160999, 0.03567053164754595, 0.03475262983036893, 0.037693325962339125, 0.018988013699916855, 0.018773959650258933, 0.04075521184131503, 0.0110652768219422, 0.015297868854499288, 0.0395179235908602, 0.04682516898693783, 0.02289817522146872, 0.014243995404935308, 0.034024063032120466, 0.0036953428477448013, 0.03218853759712406, 0.018019896898684756, 0.05876635733459677, 0.005702798454357045, 0.03958447091281414, 0.02334188962621348, 0.01716625065143619, 0.042302427746887715, 0.017757420893758535, 0.025148324568622878, 0.026884780498221517, 0.032573623183582506, 0.030087175712521588, 0.03276462061330676, 0.02332196105271578, 0.023040927115029523, 0.0565203046426177, 0.07494968894336905, 0.060500699627612314, 0.04414137299837811, 0.02512981922232679, 0.033153685807649574, 0.031386312429926226, 0.01377602931045528, 0.005102328889604125, 0.02443832079214709, 0.03279651175918324, 0.055025288436029635, 0.03789408751098173, 0.03186034717197929, 0.049747266474046876, 0.018899800754817467, 0.023980711686557958, 0.027451106180836047, 0.03216434782370925, 0.03211747801729611, 0.012632503573383604, 0.026405346313757554, 0.03262369906795876, 0.02750018292239734, 0.0714783648561154, 0.01651170354203454, 0.02079562420424606, 0.03048303982775126, 0.06406791428370134, 0.041805801181388755, 0.009525026926504714, 0.05021910276263952, 0.060230025223323276, 0.023561490699648857, 0.005620286475667464, 0.009946796660577613, 0.041695291575576575, 0.029649266174861362, 0.05114366440102458, 0.01565158915972071, 0.03970631205343774, 0.03499435793076243, 0.0354567931166717, 0.009964275722657996, 0.006085782278595226, 0.026780274230986834, 0.03382881118782929, 0.038458133315933604, 0.03988264973408409, 0.018617606522249322, 0.032470302656292915, 0.005290905221564961, 0.05401630347062435, 0.02402822270856372, 0.030639065562614372, 0.01791850341084812, 0.027046563602717857, 0.025082706839644482, 0.032317198014685085, 0.012992139007630093, 0.03954675793647766, 0.04441484635961907, 0.03870374263663377, 0.03319463200334992, 0.02380812630456473, 0.043811367492058446, 0.09180688046451126, 0.029612723671432053, 0.025279819566224302, 0.07690880953201226, 0.02940335829875299, 0.01151801659060376, 0.030146001305963312, 0.015050717562969242, 0.07676361660872187, 0.06704848113336734, 0.02340403664857149, 0.012856211480019348, 0.037347402024481974, 0.07498196685420615, 0.028808775025286844, 0.03286965783419354, 0.04648252237322075, 0.03900507325306535, 0.02943085932305881, 0.02368977792294962, 0.015756536474717513, 0.0032095291618523853, 0.043030007276684046, 0.0166514376510999, 0.01089846238028258, 0.12743635395807879, 0.03706985406045403, 0.049393709017229934, 0.06949512234755925, 0.026910956682903425, 0.03358041987355266, 0.04422919578584177, 0.026244501283924495, 0.10635909531265497, 0.035848026230399094, 0.02805797941982746, 0.026786051956670623, 0.03158566262573004, 0.00581244207985167, 0.05338424810075334, 0.05329629639163613, 0.02439507605907108, 0.01790531608276069, 0.03475828881242445, 0.03811771229707769, 0.0036462724674493074, 0.022817443124949932, 0.0577767886487501, 0.02423037525399455, 0.04213721125519701, 0.0047760027394230875, 0.04287546414083668, 0.03515858036865081, 0.046128527261316776, 0.01816027731235538, 0.04167789393769843, 0.04278631142473646, 0.055867598059454134, 0.038003748948020596, 0.040005698667040894, 0.034995111104633124, 0.07268695107528142, 0.061476507623280795, 0.017318690328725746, 0.06805380540234701, 0.05568368114264948, 0.019818923935028057, 0.0232719971266176, 0.020664919699941362, 0.11495512298175267, 0.04661725567919867, 0.032551007611410956, 0.04478867165744305, 0.03886214324406215, 0.02118682678389762, 0.041481386803622754, 0.0315835727378726, 0.03700024654556598, 0.03807316647310342, 0.01711045132417764, 0.07328509326492037, 0.019106338332806314, 0.037155597138085535, 0.03477253465514098, 0.09109751959996563, 0.00946677045430988, 0.08899482778672661, 0.022062535597277538, 0.010999513207934797, 0.04752963761399899, 0.021321314120931283, 0.08406465340937887, 0.026625527534633875, 0.0162014925985464, 0.04073674211810742, 0.02953484820734177, 0.05767730862966605, 0.016289732685046535, 0.07066014661852803, 0.022266533757959093, 0.028098075750416944, 0.012277115768353854, 0.016486158394919972, 0.00670603834857632, 0.05066865935389485, 0.016418359175856625, 0.03696752419429166, 0.03949716381196465, 0.03204695448013289, 0.01841593234400664, 0.04457063799990075, 0.07543963193893433, 0.050525390077382326, 0.02558785580497767, 0.030967011715152433, 0.011374649774682308, 0.04760567085551364, 0.047512419787900786, 0.023192238727850572, 0.07910739191408668, 0.02054313793113189, 0.015741610400644795, 0.0591616921925119, 0.049215386621654034, 0.015836671460419893, 0.014837372582405806, 0.012415709090419114, 0.011584207681672913, 0.07795363132442747, 0.03271760152918952, 0.031809979517545016, 0.02007619896903634, 0.01859234635984259, 0.02393596399841564, 0.06637402411018099, 0.038188629384551726, 0.04201830817120416, 0.03211370196991733, 0.014886003187192338, 0.020641744336379424, 0.06571483412491423, 0.0332122603431344, 0.058590080722102096, 0.05025879366855536, 0.005216610301951212, 0.004244275557409439, 0.03009014091055308, 0.03958125465682574, 0.07485279414270606, 0.013533105292091412, 0.016350312291511467, 0.017511781038982526, 0.04291795739637954, 0.016452638764998744, 0.01706462137268058, 0.03702856859724436, 0.04648782512439149, 0.050963296222367456, 0.036299930552818944, 0.017339499301410148, 0.05079049031649317, 0.06759634387812444, 0.06455368428890194, 0.035702412615397146, 0.05934825539588928, 0.02676889010971146, 0.04186530191717403, 0.02397958022941436, 0.02092229312152735, 0.024742998282558153, 0.027000368938648274, 0.04531202571732657, 0.03476809025076883, 0.04829351198194282, 0.02219663277667548, 0.05169589691130178, 0.023944983425151025, 0.04656785154449088, 0.011950771806628575, 0.07179102700735841, 0.023598793162299053, 0.03944986313581467, 0.023692480188661387, 0.015118194477898734, 0.0029796046021926615, 0.02010531660302409, 0.05326124666524785, 0.054894561879336834, 0.04045896345217313, 0.011118027830629476, 0.032794031713690074, 0.04903653496876359, 0.01901729418230908, 0.026321659197232554, 0.019536378560587764, 0.03361226012930274, 0.037102447490074804, 0.05114759990413274, 0.01412682852242142, 0.01910967333242297, 0.04984758787655404, 0.05824626702815294, 0.0100848106833707, 0.08860762856368508, 0.14015265660626547, 0.10443904477038554, 0.10509633485760007, 0.14737427766833985, 0.11548159830272198, 0.2600579639630658, 0.08939823042601347, 0.14640968585652964, 0.04785406216979027, 0.10203211142548493, 0.10089034054960523, 0.13859070970543794, 0.1117120852161731, 0.15703440430973256, 0.07897432441157953, 0.1351085358432361, 0.10191479272076062, 0.18363893457821437, 0.1194440663925239, 0.04631038821701493, 0.15421652980148792, 0.11448154625083719, 0.22890739834734372, 0.23019015522939817, 0.14861366259200232, 0.09227297295417104, 0.10898356019918408, 0.18343073289309228, 0.16794063337147236, 0.1254295323576246, 0.13709345433328832, 0.06763578711875848, 0.08715484437665769, 0.11594921749617372, 0.07590037757264716, 0.08882483440850462, 0.14143298433295318, 0.1411225138498204, 0.11051200782614094, 0.1369275525212288, 0.12080063431390695, 0.14897088413791998, 0.09473696430878979, 0.10994330048561096, 0.15458388866058417, 0.11024367436766624, 0.14036488878939832, 0.12096526048013143, 0.07457629112260682, 0.09745003229805402, 0.15310450590082578, 0.1028738816135696, 0.2776634506881237, 0.10263894564871277, 0.1931978373655251, 0.09039231815508433, 0.17701890266367368, 0.06891739049128123, 0.13217324763536453, 0.08102103708578007, 0.1290093066969088, 0.11656763431216989, 0.1368590747671468, 0.13929994164833, 0.17888644816620008, 0.08833604492247105, 0.07946167540337358, 0.09665460605174303, 0.20679006086928503, 0.1065937802195549, 0.15973755211702415, 0.11412266907947403, 0.1721583663352898, 0.08065954755459513, 0.10325545578130654, 0.13600964391870157, 0.11330055605087962, 0.1348250439124448, 0.05799799785017967, 0.10850885031478745, 0.21354604406016214, 0.0810591775391783, 0.15065812931529113, 0.20023197920194694, 0.17299528499799116, 0.15346889277654036, 0.1484917298491512, 0.06966130235897643, 0.13259362722081797, 0.10783860699406692, 0.06330418919346162, 0.08792116825601884, 0.13883448019623756, 0.08501551167241164, 0.1822391982589449, 0.1213704544518675, 0.06540080133293356, 0.09023405664733478, 0.09460604776229177, 0.09181766917130776, 0.08671484834381513, 0.09411723792020764, 0.10092102390314851, 0.07910575664469174, 0.14591275395027228, 0.0639269214921764, 0.1447935647198132, 0.10561324283480644, 0.09715226399047033, 0.12335841277880327, 0.16252046850110802, 0.11408088489302567, 0.12602888233959675, 0.0933037626424006, 0.08810598083904811, 0.12697788141667843, 0.10835775413683482, 0.095185279180961, 0.10742952501667397, 0.12122539723558085, 0.06974081987781183, 0.09548751903431756, 0.16424886004201003, 0.13223070598074368, 0.12687162283275807, 0.12651022151112556, 0.15137923562100955, 0.19417829332607134, 0.124547667535288, 0.13193903091762746, 0.0985928074057613, 0.09764819845025029, 0.12693271812583717, 0.09781095864517347, 0.14928625364388737, 0.10096372411187206, 0.20366660133004189, 0.09439003613910504, 0.1401036935193198, 0.13369598878281458, 0.1543798531804766, 0.13013665191829205, 0.10990564857742616, 0.09368972014635801, 0.05953373972858701, 0.18814843760005065, 0.09000319867794003, 0.23101405959044183, 0.21943616228444235, 0.16505550247217926, 0.07251582454357829, 0.19177275097795896, 0.08586305619350501, 0.13655570176030907, 0.08694692089089326, 0.12993074368153298, 0.2591981515288353, 0.1549781175064189, 0.0923965477517673, 0.23833702664290154, 0.1695181458656277, 0.19248532131314278, 0.13039758934506349, 0.08942982980183192, 0.10417660778122288, 0.13543086711849484, 0.13038282442305768, 0.07941680388259036, 0.15096180087753705, 0.1361705788544246, 0.1368462640259947, 0.08876774925738573, 0.06800458447209426, 0.18142165855637618, 0.0988853917058025, 0.13129363554928983], [0.010142011185442763, 0.030426599284900085, 0.05001954222097993, 0.039383858641875644, 0.049488574998187165, 0.041788644423442226, 0.03574475998591099, 0.05660162027925253, 0.023658494065914835, 0.040736043227038214, 0.02405333868227899, 0.015134353789367845, 0.05449042981490493, 0.036392706645918746, 0.02241670203927372, 0.09651436643408877, 0.02549761064749743, 0.018428826205698506, 0.024405120073684623, 0.014324367877894213, 0.06445938149201018, 0.038293951590146334, 0.0890318350866437, 0.07711096547011818, 0.0024005038015145275, 0.004223637490732861, 0.04757487215101719, 0.07708260270633868, 0.06331776667918478, 0.01954903663136065, 0.014719539887404867, 0.05227725214457937, 0.04752472162778888, 0.06323686494891133, 0.04328033920111401, 0.009466476987914314, 0.03875355049967766, 0.01720571594445833, 0.019887612034965838, 0.029863713774830103, 0.027552670998764888, 0.0033232257618302746, 0.04534614245806422, 0.058571258160684786, 0.022858077194541693, 0.033520759682038, 0.020994428179359863, 0.023518978784392987, 0.031096174248627255, 0.05583966277273638, 0.06226782873272896, 0.03852522346590247, 0.03322463342919946, 0.05881037390125649, 0.010766654408403804, 0.0569856371730566, 0.04870106725554381, 0.077595215556877, 0.039500478455530744, 0.01022934288318668, 0.006104991180888776, 0.02151873049193195, 0.058355748653411865, 0.031229428348264525, 0.02474784471892885, 0.04710861002760274, 0.02929056202992797, 0.01916969145115997, 0.013404873199760914, 0.03545133430244667, 0.03683711654905762, 0.0464098037752722, 0.02010727417655289, 0.005845338729808905, 0.023432509674291526, 0.038000380021653006, 0.0413259378235255, 0.007413129089400172, 0.03937885105343802, 0.04820038644330842, 0.04464036765109215, 0.042351329765681706, 0.02569366485944816, 0.031961699947714806, 0.012534021848945745, 0.012589267321995326, 0.028491305453436713, 0.014140065892466476, 0.03787744304697428, 0.01363856066018343, 0.019981763857815946, 0.03759021917358041, 0.03599940400038447, 0.04087916661852172, 0.02022207890903311, 0.025829857015716176, 0.027933734568900297, 0.07195768877863884, 0.030576284110013927, 0.07084339178566422, 0.0571129032011543, 0.029194383083709648, 0.03502172324806452, 0.030106442714376108, 0.027659927029162645, 0.02437364961951971, 0.012614507976520275, 0.05950732436031103, 0.020042406228770102, 0.05933088489941188, 0.03505143629653113, 0.04281457580093827, 0.009051810667317892, 0.02821930281684867, 0.016579188938651766, 0.01727725558781198, 0.0349622394756547, 0.037375601939857006, 0.04326234445241945, 0.030963758139738014, 0.017942063843033144, 0.012492572689162833, 0.055550956300326755, 0.010439940645093364, 0.05007340433076024, 0.012144797198873545, 0.01338119147944131, 0.06105110009333917, 0.02154941893448787, 0.01824669213965535, 0.03953139929633055, 0.033655947606478415, 0.022221129587186233, 0.046518820604043346, 0.05827961702431951, 0.018284603587484786, 0.011860576691105962, 0.0387530280277133, 0.017462587250130515, 0.04093902697786689, 0.03107989619352988, 0.003961690743121186, 0.01203638341810022, 0.021448169635342698, 0.03387280061308827, 0.031165238935500383, 0.09000505107854094, 0.0386939886957407, 0.018912524982754673, 0.03978744109294244, 0.02914707562220948, 0.018791669414245656, 0.028933849385274307, 0.054845642897167375, 0.026912391784467866, 0.03819069213100842, 0.01774170941540173, 0.017432195666645254, 0.030254573694297245, 0.027791223555271114, 0.02268893537776811, 0.0869322373930897, 0.03333387417452676, 0.04042374748470528, 0.05116924856390272, 0.013248315663076937, 0.02809720722559307, 0.017237372995753373, 0.02477069947469447, 0.009340288134158721, 0.049977306808744154, 0.027382243358130966, 0.020060251699760556, 0.003796757963885154, 0.032564381536628516, 0.03382315220577376, 0.058011731398957114, 0.04474457705925618, 0.01745975436642766, 0.01812468815062727, 0.052282497220273526, 0.03475029906257987, 0.014713258349469729, 0.03951659705489874, 0.03624969182003822, 0.03218141637210335, 0.012756194570101798, 0.020950915424951484, 0.018176914991012642, 0.014732869707846215, 0.05357456699545894, 0.11307529599538871, 0.019886304158717394, 0.037403214922440906, 0.033710013276764324, 0.01439291178914053, 0.022859922809792415, 0.05352431129930275, 0.007942395733802446, 0.041982417061392746, 0.056354837092970095, 0.030918594848896776, 0.027079474247459854, 0.028646242139594894, 0.09248081501573324, 0.00470599446478965, 0.007174544302480561, 0.032545521655785184, 0.04559783484520657, 0.0448154025445027, 0.0313432492049677, 0.020345311046444943, 0.02741796144151262, 0.014915692486933299, 0.013542987306469252, 0.04358336276241711, 0.045018040242471864, 0.06276478778038706, 0.025328255092192973, 0.029719732036548, 0.008897528767452707, 0.014602497685700655, 0.06345973656113658, 0.009240022710790592, 0.05367975349404982, 0.05743266961404255, 0.022074635572997586, 0.016039098812533275, 0.03860466295321073, 0.010847875898304795, 0.013791959616355598, 0.04231506885428514, 0.06498781777918339, 0.07295056871537652, 0.0067591006352034, 0.046235847752541304, 0.04253830687542047, 0.05710592786116259, 0.04199411839778934, 0.06857139191457204, 0.03125307868633952, 0.04027195580835853, 0.02608689965148057, 0.04231680929660797, 0.034622500384492536, 0.00871529376932553, 0.06016187995140042, 0.05925670066582305, 0.05607801855408719, 0.008347840763495436, 0.007972345421356814, 0.013615356458883201, 0.02115839277394116, 0.02751018283223467, 0.01983889322062688, 0.018392882509423152, 0.027120228757017424, 0.06416440874870334, 0.033935069771749635, 0.010911340974936528, 0.018007946200668812, 0.022226345825142095, 0.01923080370761454, 0.06568757058786494, 0.044540511045072756, 0.026961979123630693, 0.022442028358844773, 0.033531639991062026, 0.0030747394526510364, 0.06542059419942753, 0.023502207095069543, 0.03347923333889671, 0.02843286662495562, 0.07599165410335575, 0.03281043190509081, 0.007269927666389516, 0.06043914971607072, 0.04548292154712336, 0.06547793719385352, 0.07038930936583451, 0.04031123959326318, 0.018547904012458663, 0.03612693804981453, 0.039723475596734455, 0.04495070581989629, 0.05070500508216875, 0.040255216349448474, 0.03777905207659517, 0.028855319134891033, 0.04576075788853424, 0.045433541161141226, 0.027580470578478913, 0.03607742195682866, 0.018541632652548806, 0.05187562048169119, 0.05512565055063792, 0.02520504839984434, 0.045750013286513944, 0.014266845071688294, 0.019567776072238172, 0.019893381278961897, 0.030880135484039783, 0.006684371029093329, 0.07960846288395779, 0.050430276431143284, 0.023614967740806084, 0.006923261156771332, 0.02918892426948462, 0.04696014656552246, 0.052549266655530245, 0.0407929282103266, 0.062357632842447074, 0.03271544039515512, 0.06084093065666301, 0.027694216796330044, 0.051496031028883796, 0.001038039622861626, 0.030968741979449987, 0.04787026897871068, 0.08223335524754864, 0.012237985501997173, 0.03724586943696652, 0.04962361025224839, 0.010783828129725797, 0.023097620412175144, 0.036882785348487754, 0.03256398459364261, 0.06174212694168091, 0.04998922188367162, 0.07825966418853827, 0.0011803622370020353, 0.027945893916434476, 0.019947859159271632, 0.0465884756163827, 0.031009854416229894, 0.038208798837981055, 0.06691062317362853, 0.05543280978287969, 0.07110422743218285, 0.011198485968634486, 0.049109857462878735, 0.039989084737109284, 0.004724136370766375, 0.032195204203682284, 0.04321847377078874, 0.03738764932911311, 0.02065503683739475, 0.04105144665975656, 0.026805162895470858, 0.026883542171812484, 0.029002839433295385, 0.02465720770747534, 0.12251100396471364, 0.15451360600335257, 0.14106763393751212, 0.30804417761308805, 0.15779037374470914, 0.12585326390607016, 0.08942420474652733, 0.12970572789864881, 0.13614677584597043, 0.26768988158021656, 0.04434812940391047, 0.09980470487581831, 0.08825491249029126, 0.12173015943595342, 0.15308167998279842, 0.25572758061545237, 0.12257870818887438, 0.06803933903574944, 0.06309584501598563, 0.11554576057408537, 0.19731168661798748, 0.1962904099907194, 0.1781948445630925, 0.1494262625596353, 0.11481710895895958, 0.10936304447906357, 0.16238822202597344, 0.12621531662132057, 0.11621491823877607, 0.07601870050919907, 0.10829625172274453, 0.11756537934499127, 0.12099331111780234, 0.1720243828105075, 0.11191698922110455, 0.09241674095392227, 0.18610972485372, 0.1445547068225486, 0.10364623088389635, 0.14779321875955376, 0.23238046626959527, 0.18249710941953318, 0.06380376060094152, 0.11704995057412557, 0.12843339331448078, 0.08092577076916184, 0.19587267669183867, 0.10942299304796116, 0.09417688793369702, 0.14078909531235695, 0.14367324912122317, 0.09581377902733428, 0.11266024290983166, 0.10316147868122373, 0.12374623625406198, 0.15946163263704094, 0.10782984710697617, 0.22076155830706867, 0.08954419009387493, 0.07812051022691385, 0.11628099397889205, 0.17175140817250523, 0.11429189571312495, 0.14740264043211937, 0.10878467479986803, 0.13188804579632624, 0.09756239769714219, 0.15914333185979299, 0.06336198002099991, 0.1377355113093342, 0.1391053106635809, 0.12257686257362366, 0.1953961415482419, 0.10680746446762766, 0.11361836828291416, 0.14586999267339706, 0.13626914285123348, 0.06987898996365921, 0.13549151457846165, 0.09285398891993932, 0.07147983727710587, 0.17483893249716076, 0.11547148813094411, 0.08529855577009064, 0.13988010265997478, 0.12323368447167532, 0.12266822052853447, 0.12343899559761796, 0.13362065782504423, 0.09093716141900846, 0.08324638767434017, 0.13240010903349944, 0.17637395512844833, 0.1051572673022747, 0.09608711328889642, 0.10631511267274618, 0.07877905560391289, 0.21387586636202677, 0.0998307674058846, 0.1843205230044467, 0.1770943828991481, 0.19113457522221974, 0.12695926241576672, 0.14250084917460168, 0.14363187205578598, 0.18779489371393407, 0.08654900759990726, 0.08240803051739931, 0.15816542719091686, 0.14929097624761717, 0.1374241451599768, 0.1337564598236765, 0.06439223366656474, 0.12129757979086467, 0.06681417620607785, 0.07763307781091758, 0.13498682023159095, 0.11114391391830784, 0.141275428501623, 0.13125833815761975, 0.05074743726955993, 0.15954241901636124, 0.09820245978023324, 0.125952845705407, 0.11762168418083872, 0.09165956372661249, 0.1262928188911506, 0.15584415889212064, 0.1564314038093601, 0.11778192701084272, 0.08776247927120753, 0.15915612903024468, 0.18990782462060452, 0.12608155022774423, 0.1308519635349512, 0.17343249225190707, 0.051483739367020984, 0.20632858920310224, 0.09629203764987843, 0.1665992374931063, 0.08195273351988622, 0.06901412922888994, 0.20525091274508409, 0.3017864019743034, 0.1625879013112613, 0.1413309190954481, 0.15586117655038834, 0.07914461634520974, 0.10757100635341235, 0.11298580401177917, 0.10346395602183682, 0.10813695205641644, 0.09381959174892732, 0.18729466412748608, 0.08716773654201201, 0.0760109041418348, 0.0930709708482027, 0.15014610679021903, 0.12623483128845692, 0.11469343916646071, 0.18399545044771262, 0.18920098112097808, 0.08770497342837708, 0.12155391675020967, 0.12730140691357, 0.10209205999438252, 0.16009614430367947, 0.06333099811204843, 0.20227968932262488, 0.11497505834060055, 0.14261830358632974, 0.12272285616823606, 0.08656792515622717, 0.10885518815900598, 0.09090759764824595, 0.06880102852093321], [0.04126876446285418, 0.0433570543703224, 0.05720094990517412, 0.015337172995454498, 0.05246879918766873, 0.0877546150503414, 0.02973079215735197, 0.0637828820784177, 0.047911635866122584, 0.03397019074431487, 0.05363654777673738, 0.044414741186691184, 0.027191362975697433, 0.02420861802862159, 0.0627226914678301, 0.06545315709497247, 0.08076780781682048, 0.05151568479569895, 0.04697129828855395, 0.050326077201004536, 0.009610010893084109, 0.011674122053331562, 0.029468368738889694, 0.039595106949231455, 0.009034515657861317, 0.0774973165243864, 0.01004454302268901, 0.02966776643214481, 0.01595706562511623, 0.007595950172149709, 0.04567561192171914, 0.029065759985574653, 0.10114681321595397, 0.02374950936064124, 0.035831381766391654, 0.005850688554346561, 0.03910022761140551, 0.011434546605284725, 0.05654819582455924, 0.03960166499018669, 0.01580196269787848, 0.048948915741805515, 0.05098002550325223, 0.038488555433494706, 0.028652220033109188, 0.042010701793645105, 0.03941556658329708, 0.08360099007508584, 0.011346763681753405, 0.042797602247446775, 0.049502702097275426, 0.014046187179961374, 0.03519344349790897, 0.021062015356229882, 0.08105142188391515, 0.05117029011515634, 0.005681803732711289, 0.0639530179489936, 0.054283480026892254, 0.04297786186050091, 0.08552309657846179, 0.05479325320837753, 0.04532539285719395, 0.010646624956279993, 0.047936466855130026, 0.04439866329942431, 0.045236905105412006, 0.03373925813606807, 0.01884115158048059, 0.02001230980801795, 0.04536152145426188, 0.021295965748972127, 0.0449305702932179, 0.0464570942733969, 0.05468443315476179, 0.009882182315258043, 0.045707248616963625, 0.022068973198266964, 0.032779724802821875, 0.05303321818688086, 0.06592363292085272, 0.040399812161922455, 0.0629909299314022, 0.016809290341500725, 0.003862501645926386, 0.02939375363556402, 0.06894739530980587, 0.029963485563972166, 0.06898839918098279, 0.0383607906821583, 0.042687414945768457, 0.05195256635280592, 0.010074075411206909, 0.016323092859238386, 0.035151621992034573, 0.03208797192201018, 0.06654544241194214, 0.008568346833011933, 0.011168487087291266, 0.04640216347096222, 0.014841927248718483, 0.029277069361082146, 0.022189944117729152, 0.027592032815196683, 0.0326585689825671, 0.017935548210516572, 0.011545055362928127, 0.040257787997169156, 0.03347498231700488, 0.023628039717940346, 0.06941955390253238, 0.08802799002400466, 0.05091767152771354, 0.05390070145949721, 0.04395224153995514, 0.08844980810369764, 0.0457786983544273, 0.030487189069390297, 0.014060255755404276, 0.016148443034450923, 0.01049301226157695, 0.030480973688619475, 0.07606819285345928, 0.07357881071844272, 0.06219768178250108, 0.032215465259339125, 0.03981339166473065, 0.018043564200135212, 0.027517818047532012, 0.06159428773181779, 0.04485103241833193, 0.037739293317177465, 0.013225295514400517, 0.058479778069470606, 0.046422285426940234, 0.04907380011198776, 0.03364091466314026, 0.025629522944135324, 0.030516654452575103, 0.034658920751618486, 0.08096009107040507, 0.02535450252305184, 0.0799617353560669, 0.08992985582777432, 0.06962892266788653, 0.02405316735218678, 0.014689591048019273, 0.09892032268856253, 0.02448911083463047, 0.0384823332673737, 0.019608352466353347, 0.04020035679319075, 0.02183976406896753, 0.05150865517290575, 0.03220887668430805, 0.02596419507504574, 0.07034299256546156, 0.06578964261072022, 0.012491663452237844, 0.05064783850684762, 0.0703410180285573, 0.033106381738824506, 0.03171989381579416, 0.020959090075588653, 0.09746236127934285, 0.1237991348441158, 0.04709447953583939, 0.0021508881556136267, 0.05024464960609164, 0.024212941993027925, 0.026355509612975375, 0.06554963798927409, 0.0735794146146093, 0.002388425030013812, 0.019057207308443527, 0.047121539512383084, 0.024758879394669617, 0.008931014470623007, 0.06163729328129973, 0.07295983750373125, 0.005385007850626218, 0.045319781372589726, 0.03353828963424478, 0.007791753326143537, 0.0197722644744707, 0.0306522053932505, 0.026647395021947365, 0.02126945199311844, 0.052443048783711026, 0.015483485501525658, 0.04735986136698297, 0.04072235378303698, 0.04172252118587494, 0.026713162028629864, 0.008427480418634201, 0.02931646171158978, 0.06428609043359756, 0.036755553247140985, 0.011671896458470395, 0.03151402629113623, 0.020369938474946787, 0.0235911138422255, 0.03867027728951403, 0.06281131492661578, 0.038024396768638065, 0.014951771890212382, 0.017890247516334057, 0.029736105086547986, 0.10490382768745933, 0.02082842797972262, 0.04153013615203755, 0.03051978928436126, 0.032004091423004866, 0.015348529975329126, 0.026323104476822273, 0.07152217786226954, 0.032337737269699574, 0.09063233634723084, 0.024756755580061247, 0.09116324928722211, 0.0112616719977398, 0.037309207288282256, 0.03826111049524375, 0.08508005392338548, 0.03381938294374517, 0.06376030043299709, 0.020403464890218208, 0.010603926443893994, 0.025512404407241514, 0.038214525673538446, 0.05484982267288225, 0.041871425695717335, 0.024106786885697926, 0.023950121631579738, 0.016104423075116107, 0.025725009784634625, 0.015490560925432613, 0.05163574817457369, 0.04694189736619592, 0.02476767829752394, 0.06657334377190896, 0.053291078457342725, 0.011356190229499978, 0.04120286174916795, 0.04261117135839803, 0.07515664212405682, 0.0487339049577713, 0.016729241869013225, 0.018521802466628805, 0.06287428976169654, 0.023662490637174675, 0.020731572194823196, 0.0509837540531797, 0.025810379668005874, 0.02978121070191264, 0.038486675891493044, 0.032411209041518826, 0.03437584951253874, 0.09079321021480219, 0.052531044597604444, 0.02508006394574685, 0.033094938245735, 0.024398070094840865, 0.05635808388303433, 0.044111568347683976, 0.032716794072517326, 0.0645818706335766, 0.04386828640209777, 0.049821477849036455, 0.043650442734360695, 0.012444340723699756, 0.0774398378229567, 0.04028553668675678, 0.0413014359240021, 0.03887943231633731, 0.04544795663761241, 0.08312525560281106, 0.038120986228542666, 0.03325859071420772, 0.03145587244736297, 0.017304307082667947, 0.017083946050011685, 0.05098622052797249, 0.012863190212686147, 0.03808334789105824, 0.02486663414830608, 0.02750794536301068, 0.02979405876249075, 0.0511443565067436, 0.043522745836526155, 0.056698294556034465, 0.010279279667884111, 0.03667384066752025, 0.04375731199979782, 0.05355943227186799, 0.014591110171750188, 0.006025577138643712, 0.025161038618534803, 0.044232025276869535, 0.052515350082623105, 0.004918538349946695, 0.02649613599559026, 0.050124820321798325, 0.016017348372510502, 0.07225811694349561, 0.04565752896347216, 0.034312111325562, 0.04723473272419401, 0.01785941488508667, 0.038118475648973665, 0.03478550485202244, 0.055567906105092595, 0.03133193802620683, 0.07816674560308456, 0.04535062078918729, 0.022000928010259355, 0.010830203453744096, 0.022657449656565274, 0.03898615569674543, 0.048205550094800334, 0.012047552952675946, 0.00859222702482449, 0.057007879550967894, 0.037863756995648146, 0.004381652181369385, 0.07085327125553574, 0.060965360408382754, 0.03117007010483316, 0.04852076353771346, 0.07146498414554767, 0.016858068527653813, 0.03477315551468304, 0.0332897252935384, 0.039344160950609615, 0.02005275558414204, 0.04619103729990976, 0.08424242279891457, 0.023316203683082546, 0.05231522974957313, 0.00914240866300783, 0.06323199985282761, 0.11306543009621756, 0.02397098658340318, 0.03417602773489697, 0.01046733055928988, 0.01873287435487977, 0.02365342201665044, 0.06650369893759489, 0.02764511969871819, 0.01780397178871291, 0.013558913371525705, 0.014076834062247403, 0.1271101821746145, 0.13932757159428938, 0.15576984573687824, 0.10822409630886146, 0.09911772209618773, 0.1789191264126982, 0.11166021799934761, 0.11412132558013711, 0.1207946767764432, 0.167742501146027, 0.09412508178502321, 0.17395993109260285, 0.15595044461744173, 0.1050167969827141, 0.1259622909128666, 0.11292611328618866, 0.13168884148555143, 0.13116544671356678, 0.10913334001920053, 0.093417227268219, 0.11661119626036712, 0.2002779838762113, 0.07844340468623809, 0.13819623658699648, 0.11588227323123387, 0.13221098775310175, 0.15342054037111147, 0.10519294467355524, 0.2059009221515485, 0.08518262127680437, 0.1140580725456987, 0.09210829250514507, 0.21017008806977952, 0.09478389179067952, 0.11393018226538386, 0.12852498197129794, 0.09963742563767092, 0.08883977574961525, 0.16152026717151913, 0.14253374455230577, 0.08533607197127172, 0.12726065410034998, 0.12311342092497007, 0.20267770439386368, 0.08209889674825327, 0.1841430046728679, 0.1287139132618904, 0.10870182567409106, 0.12488137105745928, 0.10173500129686934, 0.09297952468373946, 0.1209426788347108, 0.12134370660143239, 0.11924784763583116, 0.14739943774683134, 0.19535148037331446, 0.1042507988001619, 0.1714864538184234, 0.18622804779027188, 0.11376033816486597, 0.10764188612146036, 0.08820971527269908, 0.0787045524588653, 0.096946600026318, 0.1529483207102333, 0.21402290490056786, 0.12020004939820085, 0.09944086082811866, 0.12640464146222385, 0.1564767842314073, 0.12055284689579691, 0.14310501675520623, 0.09915605932474136, 0.19087450632027217, 0.13892346327858313, 0.11042304509984595, 0.17168084053056581, 0.10479376252208437, 0.08243174531630107, 0.1318985495184149, 0.20003950595855713, 0.10661642971847739, 0.15270483520414146, 0.12493574885385376, 0.06799677453402962, 0.09031474124640226, 0.1349891543920551, 0.07974235819918768, 0.20013357805354254, 0.12040607977126326, 0.21669235665883335, 0.14479543747646467, 0.12454808822699956, 0.1087475928610989, 0.0690319679145302, 0.11500941935394492, 0.1096245925873518, 0.0801458354773266, 0.11113494368536131, 0.12314888116504465, 0.1678071112505027, 0.14577923182930264, 0.1558488950665508, 0.08599120431712695, 0.07884246470140559, 0.08770605229905673, 0.19331093558243342, 0.14172632859221526, 0.1369848344475031, 0.12849022740764277, 0.12701140104659966, 0.11628503804760319, 0.11223392614296504, 0.16437742885734352, 0.18486986495554447, 0.21601577582103865, 0.14946887455880642, 0.1400531426604305, 0.2855982120547976, 0.1353379756744419, 0.09814342044826065, 0.10929029873971428, 0.16397595325750963, 0.12160373479127884, 0.1432978564075061, 0.1352978064013379, 0.14588956162333488, 0.0902405705835138, 0.1541337078171117, 0.12065123447350093, 0.14108385092445783, 0.13021377420851163, 0.09211380899484668, 0.11808266730180808, 0.09506373998842069, 0.16761632077395916, 0.1143436815057482, 0.15082781735275472, 0.170839429966041, 0.19340350132967743, 0.14186132991952555, 0.16470787541142531, 0.09813083362366472, 0.14378412174327032, 0.15502790840608732, 0.0807813513757927, 0.09597645779805523, 0.2130027139293296, 0.12362420851630823, 0.09495290129312448, 0.12666340757693562, 0.13433800504675933, 0.09713623699332986, 0.12510671253715241, 0.09315379283257894, 0.15516561030277184, 0.13396684639155865, 0.16251007334462234, 0.09785917534359864, 0.11828666206981454, 0.1452580083693777, 0.11152569164655038, 0.15883039150919231, 0.05792731485728707, 0.16321940028241702, 0.19539098468210014, 0.12097034949277129, 0.08026839925774507, 0.1313008280204875, 0.16802443244627543, 0.09996930390064206, 0.17632611840963364, 0.11044978616493088, 0.04959944762023432, 0.11351898325873272, 0.11392183628465448], [0.03145736861707909, 0.04970971295343978, 0.015919523978871957, 0.045469306741974184, 0.01782907249539026, 0.0057764572473908106, 0.04409512405150703, 0.06842784783137695, 0.0010883698518487758, 0.026950109849816987, 0.07031948811241559, 0.05074338980817369, 0.008807002866108502, 0.002203617535997182, 0.07221033450748239, 0.022883245754720907, 0.01861237671359309, 0.019913041831127236, 0.10696562419512443, 0.053048607361103804, 0.009519529096516115, 0.015262966709477561, 0.02135260306697871, 0.04570602046857987, 0.010681010566518774, 0.0085976196818852, 0.043630666831242185, 0.028075338041942035, 0.029161915183067322, 0.029508795855300765, 0.00997129686376346, 0.023341241625270674, 0.01916197481166039, 0.01666962238959968, 0.05231010002483215, 0.008129645105717438, 0.025892155012115836, 0.035102407847132, 0.027923091747132794, 0.020240250076832514, 0.02982198726385832, 0.07118969570313181, 0.059183853146220954, 0.008499182062223554, 0.020035943182717477, 0.011869006640543895, 0.051641631073185375, 0.026730844651215842, 0.052100490379546366, 0.03299512913716691, 0.055276872257569006, 0.006382655768123056, 0.03245358694610851, 0.021096966695040464, 0.027736703266522715, 0.006786989696723009, 0.046132028502013, 0.006380125680672271, 0.04468443850055337, 0.028055360274655477, 0.085766269958445, 0.04547402934570398, 0.05564609369529145, 0.03418452638600554, 0.006217974895012698, 0.037700806810919724, 0.04215854100350823, 0.010527344437183013, 0.004168232137869511, 0.01662155327254108, 0.03880384351525988, 0.014709545066580176, 0.024220623009439026, 0.0741001223879201, 0.03765704808756709, 0.06584215443581343, 0.036145485804549286, 0.07566810825041362, 0.01919178624770471, 0.006840353083264614, 0.05398682790941425, 0.041654677862035375, 0.022382637885000025, 0.03378187013523919, 0.013866650206702096, 0.003413486398390627, 0.04106220483247723, 0.011116185608053846, 0.028225365527240292, 0.034241984731384685, 0.03495597320475748, 0.013395850380350436, 0.018632741245840276, 0.05066602663802249, 0.009269994450733066, 0.08357095811516047, 0.06536049635282584, 0.01934510123516832, 0.016176359661455666, 0.020148595262851034, 0.020262417815891758, 0.03385876511622753, 0.04665442582752023, 0.0773629733760442, 0.036089021512972455, 0.0916424917855433, 0.02092162985354662, 0.04342500286708985, 0.08174850804997341, 0.03640325786545873, 0.029315382840910127, 0.04776490606101496, 0.014089749128158604, 0.06478556006082467, 0.04337017723758306, 0.024829370701419454, 0.025159849485914623, 0.033317304349371364, 0.025926709407940507, 0.023576091076912623, 0.02693039331851261, 0.04919174985427942, 0.028019284264051487, 0.022355321761486784, 0.02469639140846474, 0.03235245130157896, 0.019156936689146926, 0.02399202116898128, 0.024530969659930894, 0.05426184154514756, 0.019377681094088724, 0.055311460580144606, 0.009482012895335044, 0.030749510707599775, 0.010126574513768511, 0.022291468223556876, 0.02246945983331118, 0.02919663242729647, 0.056851880957505534, 0.035906644870660136, 0.03959398397377559, 0.0678237345335739, 0.049392491046871455, 0.01765048038214445, 0.031361199848886044, 0.0266088966413268, 0.040923006766076596, 0.006113683638562049, 0.035314677349690876, 0.03400369680353573, 0.020966497981654744, 0.03449312750516193, 0.022568576836160252, 0.033657525200396776, 0.03274056315422058, 0.02681684217947934, 0.04142037293474589, 0.0702349833611931, 0.02163048690584089, 0.012033752398565412, 0.00836475070432893, 0.04773915565705725, 0.028979097492992878, 0.019819478637405803, 0.044607054974351606, 0.04388004880664604, 0.022538551661585058, 0.017365639863003577, 0.03544390095131738, 0.025049278811950768, 0.036094297122742446, 0.01928407040291599, 0.025726982625201344, 0.08322983141988516, 0.017688978762765015, 0.02404648717492819, 0.05232283612713218, 0.019409936952537725, 0.05631002664033856, 0.04069792991504073, 0.05936129005359752, 0.022614837657394152, 0.029341655716832196, 0.01645089153732572, 0.030042918265930245, 0.050100257354123254, 0.022963589389941523, 0.03485645925892251, 0.057862277275749614, 0.022154641637046422, 0.06455755193850823, 0.06042988771306617, 0.06281474831381015, 0.04813365591689944, 0.07809524158281939, 0.07223970150308949, 0.021942904784477184, 0.06153784718896661, 0.07643880189529487, 0.0406972412019968, 0.05331003672576376, 0.03840556720803891, 0.04329568087788565, 0.03592141657801611, 0.01812890524576817, 0.039008642347263436, 0.010267982059823615, 0.07470164368195192, 0.056442256152097664, 0.03282675745763949, 0.018638408709583536, 0.07601372684751238, 0.05341970155547772, 0.03738724560077701, 0.02664315587441836, 0.0627314784963216, 0.043798516038805246, 0.034290662833622525, 0.08730026121650424, 0.01572786328116698, 0.0426562192982861, 0.0033004481894230203, 0.0402125331041004, 0.03069544503731387, 0.041371647335056744, 0.034198283683508635, 0.04638776835054159, 0.060127315377550464, 0.049258585553616285, 0.011505275399291089, 0.04162417432027204, 0.026118315822843994, 0.05045520580772843, 0.008161800032082413, 0.04266529470416052, 0.03845365159213543, 0.04545811091416648, 0.031055153414074863, 0.03355129375787718, 0.04517181324107306, 0.05143610620871186, 0.02142325722213302, 0.04170927618231092, 0.011207548651977308, 0.028798135596194437, 0.045752035320869515, 0.06677349124635969, 0.00994532848043101, 0.010978491344888295, 0.028906792801405703, 0.05799686469669853, 0.020738138717466166, 0.022005387681669424, 0.028066517086699605, 0.032913952600210905, 0.030009042405124222, 0.028269448251064335, 0.013065232496176447, 0.04058934734868152, 0.009223324812150427, 0.014582514829401459, 0.0462618559998061, 0.017247679942686642, 0.030868505393820148, 0.04905995121225715, 0.037035194491701465, 0.0351964901201427, 0.04315725973408137, 0.04346109075205667, 0.05181036237627268, 0.017379040929621885, 0.02468605392745563, 0.048118734931839366, 0.025353135274989263, 0.061157541881714544, 0.038452141851718934, 0.038415836835546155, 0.042928891988205056, 0.0173603320228202, 0.05460486813847508, 0.02497743382783873, 0.06669092031994037, 0.056477804601724656, 0.03965810214036277, 0.021719570072101693, 0.041815714578011205, 0.03409906490040677, 0.017976068625492708, 0.007279416978625315, 0.05387148713426931, 0.05244924380843129, 0.05157137895002961, 0.033536712040326426, 0.05608431875173535, 0.02584818085389478, 0.03913555892982653, 0.03374579242829766, 0.03870861791074276, 0.03399528975465468, 0.03279300034046173, 0.07323796222252504, 0.009868404661704386, 0.03135660955948489, 0.023843684932217002, 0.11515268523778234, 0.02316835429519415, 0.030212711476321732, 0.047867581980036836, 0.022321627408798252, 0.04083048851628389, 0.03732369061825531, 0.046137972468776364, 0.03279342442484839, 0.019114584229620438, 0.03427018464675971, 0.034179206671459336, 0.05012858958382692, 0.022580110235139728, 0.027886423714725033, 0.00928349984211049, 0.031200594002647058, 0.03562710201367736, 0.015313950134441257, 0.032551550439425876, 0.03286415830786739, 0.006106598036629813, 0.028229195857420564, 0.05470463314226695, 0.027974207486425127, 0.04123204214764493, 0.024488808886547173, 0.01842102305298405, 0.016904861998877356, 0.04329387258206095, 0.03066856147987502, 0.00849063930633877, 0.01980011833698622, 0.018521039114732827, 0.05239218579871314, 0.034903912605451684, 0.04417297576687165, 0.06165906068469797, 0.05097014264070562, 0.03815259238971131, 0.0587824589705893, 0.04038923040830663, 0.03198299916195018, 0.04208769855488624, 0.023884251148306897, 0.03531578675444637, 0.010782612703873642, 0.08066961022892169, 0.12349194847047329, 0.08944004853921277, 0.11792386296604361, 0.11910429676728589, 0.13719405393515313, 0.14273319313568728, 0.10260121910167591, 0.13626623872135366, 0.13775703444012574, 0.17957222993884767, 0.18799873920423643, 0.1794898829289845, 0.1063920653292111, 0.20172250350671156, 0.14723140533481324, 0.15883439486580236, 0.2052919641137123, 0.13231100381485053, 0.2776237971016339, 0.11447356667901788, 0.04074815507712109, 0.14261961994426592, 0.16946520656347275, 0.12046256102621555, 0.1132595928918038, 0.09356925982449736, 0.14901101269892283, 0.10134242129112993, 0.12168851095650877, 0.08410718398434774, 0.0875250327267817, 0.15283041846539291, 0.11585518611328942, 0.13792718388140202, 0.17801273933478765, 0.18148978347224848, 0.05413407340113606, 0.07001413378332343, 0.12356010052774634, 0.12496838638825075, 0.11295467282512359, 0.20017954201570579, 0.17587418694581303, 0.1266982571354934, 0.11516793870500155, 0.08559637157512562, 0.11846989366625037, 0.13649441647742475, 0.15771893757794583, 0.07769629013325487, 0.10359271482697555, 0.20814251686845506, 0.1346465213490384, 0.10603033831076962, 0.06940537252064262, 0.1221107497279133, 0.12158701568841934, 0.08088641573808023, 0.126907313774739, 0.12648367722119602, 0.12064177569534097, 0.09855810712490763, 0.0818756790831685, 0.13653014813150677, 0.19762297134314263, 0.09968011906104428, 0.13303673772939614, 0.08654340290065322, 0.1528852576656001, 0.11660451947578362, 0.186478712196861, 0.06369969368513141, 0.16053020315510885, 0.18055881985596248, 0.1278804008449827, 0.11002121666180235, 0.1487521380186081, 0.14689102502805845, 0.21573590726724692, 0.10239224388663258, 0.12114839708166462, 0.12765626715762274, 0.1102608141622373, 0.10843228442328316, 0.09764976586614336, 0.11636298815054552, 0.08292710980666534, 0.08887909006859575, 0.22952554374933243, 0.11283719805734498, 0.10381536930799484, 0.14926418768508093, 0.11660936421581677, 0.12263742860938821, 0.1661377251148224, 0.14131095659519943, 0.15892530498760088, 0.091961437171059, 0.09128229825624398, 0.1847642713359424, 0.17434896236019476, 0.10805681028536387, 0.1345696026193244, 0.16414002302501882, 0.06918891984969378, 0.3055571567799364, 0.1449571866542101, 0.16918436091925415, 0.12431179519210543, 0.13185094350150653, 0.12093430571258068, 0.07071953878871032, 0.13775191828608513, 0.1644354843135391, 0.19669088135872567, 0.16461916374308722, 0.16097464359232358, 0.1225628847522395, 0.12460059326674257, 0.11087143461086921, 0.11973329872957297, 0.137003059898104, 0.10019367507525853, 0.1515714917331934, 0.12170726566442422, 0.0820321696145194, 0.1857067429061447, 0.12623606622219086, 0.1522803572671754, 0.1546249400292124, 0.0719166441953608, 0.11006386258772441, 0.1732382955295699, 0.07106006837316922, 0.07199798697339636, 0.11536377748208386, 0.0683859618646758, 0.06105443848563092, 0.12468831427395344, 0.12345515830176217, 0.13083654721932753, 0.08907172616039004, 0.13280355238488742, 0.0978284173512033, 0.09618327527173928, 0.1781010710235153, 0.08526285125740937, 0.16392352964196885, 0.10610049204634768, 0.12383258662053517, 0.13506227332566464, 0.2216196744037526, 0.12050969206861087, 0.1490371905799423, 0.08553250785917044, 0.07387863498713289, 0.11032998402203832, 0.11405362135597638, 0.11802599605705057, 0.08584979083389044, 0.059489411035818715, 0.07709590199270419, 0.11500579597694532, 0.12016851109053407, 0.15784096531569958, 0.1044312823297722, 0.17210345928158077, 0.1664395374911172, 0.1323745689753975, 0.06328725295939616, 0.11220800610525267, 0.1319501046091318, 0.07037740786160741, 0.1285538197095905, 0.07405935600399971, 0.14616026995437487], [0.05361162179282733, 0.06426756642758846, 0.04328568605706096, 0.03167344130841749, 0.047625579072960784, 0.028058842855638692, 0.021715958569464937, 0.011079472622701099, 0.06654447210686547, 0.09068688377737999, 0.040658649522811174, 0.061191237930740626, 0.02688401544998799, 0.02149400637218995, 0.02466374878505511, 0.024536962820483104, 0.0360923124078129, 0.08085478922086102, 0.04451735603756138, 0.027850642866854156, 0.004227912261350346, 0.03537141644795026, 0.013874171767383814, 0.07481061640594687, 0.03693332263667669, 0.027342487991388355, 0.012005950274345065, 0.03527851143319692, 0.02332148777454027, 0.024104870024270246, 0.022414603669728552, 0.002650957862247846, 0.027482544404587576, 0.021056943306965486, 0.030775200043405806, 0.07744785132152693, 0.04076964767383678, 0.018041302982185568, 0.03577574189486248, 0.02646942207190607, 0.024232991006491438, 0.06581082647400242, 0.01599075997780476, 0.030286240923617567, 0.025039575761184096, 0.017323490963982682, 0.025929995213768313, 0.0291931515426508, 0.029686429537832737, 0.02414558212538915, 0.031927966579262695, 0.0064325921287361, 0.025877653022429774, 0.02161583903112582, 0.03603867421458874, 0.028073295651535903, 0.02471681870520115, 0.003853868560067245, 0.04056478777368154, 0.018406831493069018, 0.0340654129561569, 0.022042462835088372, 0.05552963333736573, 0.08010874675320727, 0.02248895075172186, 0.03475291820775185, 0.08220500605446951, 0.03204381286299654, 0.04576326168275305, 0.07059317521218743, 0.020718775024371486, 0.03615985378356917, 0.03832447209528514, 0.03906569696430649, 0.055048246668385606, 0.08571947139820882, 0.014927938347682357, 0.07032741340143339, 0.02802882107373859, 0.06127748651696103, 0.04102916356974414, 0.039781792288912196, 0.0331953953552459, 0.033277345422123156, 0.04784221834103976, 0.013348364803407873, 0.024545493702005063, 0.02333928914075451, 0.035380169549690824, 0.03608745748975447, 0.04599217225664428, 0.03727662064401167, 0.025615743594244123, 0.06773333331303936, 0.05685072744797383, 0.030484800626124655, 0.07002140089337315, 0.014325758874682444, 0.049164859511490376, 0.015971494672287787, 0.05320497914882643, 0.02465345031980957, 0.10282793122210673, 0.047547903776701005, 0.017092047758134346, 0.06146506752286639, 0.0033384179488556193, 0.010586400732531078, 0.0551749121929918, 0.023092733263703327, 0.046987878291734626, 0.05234804370307496, 0.059541882148810794, 0.03381123713084629, 0.019996503334758536, 0.040539953391999006, 0.08224645775875875, 0.021124672976189425, 0.01502693660690316, 0.013273171248978801, 0.018438863434961865, 0.08251082857272454, 0.02143509087285825, 0.026922578291435326, 0.03386535029858351, 0.033384598059845824, 0.0658098358128752, 0.018481550072985034, 0.05502422313605036, 0.04949509571971638, 0.024525483704305122, 0.01696131271975381, 0.035549850801804235, 0.03243980250720467, 0.07376042061618396, 0.025964025441291075, 0.0371398008428514, 0.049151879136583636, 0.03538139430539949, 0.04417690787730472, 0.07731154720698084, 0.06520963766212974, 0.05698054137506655, 0.02555045665108732, 0.05414192405130182, 0.01833592288728271, 0.042023671990526576, 0.025831098734800304, 0.03788744465314916, 0.03608411570478763, 0.034524296011243544, 0.04937493395326393, 0.02961551584303379, 0.018804476762722646, 0.037616305452372344, 0.07339364529720374, 0.008969849574246576, 0.04429580756862249, 0.06275460296975714, 0.02345778001472354, 0.08278041053563356, 0.05578739522024989, 0.05827488084988935, 0.03422531991132668, 0.027462045861674205, 0.015155510511249304, 0.029483303294650147, 0.046217425526785, 0.016898914639438902, 0.04317262515957866, 0.0645473264157772, 0.006869449937117419, 0.02452257787808776, 0.03286484023556113, 0.043176726903766394, 0.023404413235506842, 0.035020841152540276, 0.04903400403314403, 0.03585389555831041, 0.0329917703888246, 0.03088536698903356, 0.005753371789718845, 0.031728843692690134, 0.0040928201799813125, 0.02737264208761709, 0.023485723783129027, 0.0033631935948505998, 0.05574530230036803, 0.007956849377868431, 0.06568509393504687, 0.01643565164080688, 0.027210022688710263, 0.03641443672989096, 0.028756775494132723, 0.05857636074402502, 0.024767099846420542, 0.04156699078157544, 0.023321575984092693, 0.044216028813804896, 0.02734918173934732, 0.027793718867802193, 0.014930089303691472, 0.01990730481754456, 0.010496131826325186, 0.00829573521124465, 0.021444704017734954, 0.06519951391965151, 0.0077170780028349584, 0.04947011545300484, 0.1249198168516159, 0.00452451645729265, 0.048184373016868315, 0.031924658721046786, 0.03363717593518751, 0.030732588044234684, 0.024662442605144212, 0.026269020146823356, 0.016707036810527955, 0.0174741172564349, 0.05565433789576803, 0.04258182132616639, 0.08228411645229373, 0.05067397567576595, 0.03396188208301153, 0.03903157004554357, 0.04192429035902023, 0.05118674798203366, 0.014475038275122643, 0.026667284579681497, 0.03280946160001414, 0.018255923608584062, 0.04194836138880678, 0.04973471357620188, 0.0238598510290363, 0.012338105888505067, 0.016877286335719482, 0.03778489087043064, 0.02836556952180607, 0.0342222970378186, 0.07176348527095147, 0.0038562273174258216, 0.009597033910852457, 0.017999763068343912, 0.034852866415998766, 0.05576270333092127, 0.09255632917795863, 0.04404742982504623, 0.031411248591861556, 0.03764275135472417, 0.05777399308447327, 0.012617332378535398, 0.04141711935933147, 0.01376953742666436, 0.04154352364795549, 0.023076548507171016, 0.06236652165119137, 0.05209714859457953, 0.04359479607748134, 0.005410080143649663, 0.03961090324446559, 0.06497343962213822, 0.04803955668051328, 0.022315544342356067, 0.041657914474074326, 0.046106356129582436, 0.016794304895613874, 0.08006806179348912, 0.060287402144500186, 0.045202947820403745, 0.09015401665653501, 0.015805048335875784, 0.013239096916679825, 0.04671176542927112, 0.04225501850513475, 0.022974108379068117, 0.027722740712176477, 0.022545788237558942, 0.005574324633926153, 0.08641397913119622, 0.0613241425848433, 0.039810392539948225, 0.05377526069059968, 0.031465066596865654, 0.08142133203468152, 0.061891221441328526, 0.03364906386871423, 0.0506897651856499, 0.06668270326086453, 0.020985116982566457, 0.039885611539440494, 0.050906831930790625, 0.029256747237273624, 0.021927447756752372, 0.025020503838147436, 0.01598975744231471, 0.010740516391316695, 0.017722666330103363, 0.04007116372564009, 0.021956748595195155, 0.07871606041278158, 0.03257999123473253, 0.07203317579946347, 0.0625688743644527, 0.03592787283871855, 0.010119215801491268, 0.05712088277297361, 0.021852320359487618, 0.021312813773485165, 0.028265134464683275, 0.0057756849897227115, 0.009177952871790953, 0.02629858561392341, 0.03975245582738093, 0.010787116480059922, 0.050603750694010935, 0.05171893656785999, 0.012401569268799253, 0.00733586006598281, 0.12463119519608361, 0.03318878642416426, 0.004638587523783956, 0.020690305391326547, 0.0038720138587190634, 0.037745281388717036, 0.06834407589797463, 0.031558399088680744, 0.008093962645424264, 0.03630684821733406, 0.051008439157158136, 0.04902873181604913, 0.034965686433549435, 0.026261132177231566, 0.01753465106178607, 0.03161756734230688, 0.036521451880357096, 0.031627097366643805, 0.03309034795633384, 0.027576541860720942, 0.034214873864714584, 0.050650294803615124, 0.018517459842509458, 0.006242101479853902, 0.015947111516392658, 0.013889562637944306, 0.02177617515969489, 0.04104445774906448, 0.04547066041933639, 0.039403821142124276, 0.03751856926828623, 0.04210911990542497, 0.04544040793552995, 0.011993973283097148, 0.09071108712149517, 0.15338084607252053, 0.14367425335305078, 0.06017076876014471, 0.0932429659047297, 0.07481286235685859, 0.08669842779636383, 0.08284873901201145, 0.09723419709397213, 0.09081521510545697, 0.16000052514885152, 0.12890146034104483, 0.14452042723340647, 0.20663181293223584, 0.05616970559848206, 0.14844556232648237, 0.11955871166927473, 0.18457372513200554, 0.16508834356708185, 0.08124828524887562, 0.12986508863312857, 0.10532868560403585, 0.11075765107359205, 0.14518532369818005, 0.14933537957923754, 0.20480263179966382, 0.08924813169453825, 0.08016967241253171, 0.09721445851027966, 0.10291835279869181, 0.1213893855788878, 0.08773520216345787, 0.2661912419966289, 0.13850644922682218, 0.08512004677738462, 0.1638940405100584, 0.16189823831830705, 0.13083152606018952, 0.14731915348342486, 0.08132643891232354, 0.13763724586793355, 0.20570015721023083, 0.1780761552176305, 0.18918964958616666, 0.13794775706316742, 0.17780855457697595, 0.10732427066458122, 0.0817307982859867, 0.09920410638941185, 0.11885536941034452, 0.08475053017692906, 0.09907162242702075, 0.0895622323400208, 0.08696600129561764, 0.14164888060518674, 0.10426858320300068, 0.0943244421588523, 0.08381751738488674, 0.08551593124866486, 0.10070550082517521, 0.10295487155339547, 0.19254049978085927, 0.12961312143930367, 0.16907177838896, 0.03764181497639843, 0.09644186496734619, 0.15247196198574134, 0.11989135667681694, 0.11909862421452999, 0.18999131156929902, 0.14499853657824652, 0.09791826895837273, 0.20188136212527752, 0.1443610122161252, 0.13329125621489116, 0.14944119033004555, 0.04994037414767912, 0.14619106187352113, 0.09718010428228549, 0.22704013782952512, 0.16028556413948536, 0.1449134618576084, 0.14932167317186082, 0.18233432886855944, 0.10582208912819624, 0.13641611353627273, 0.13920487889221736, 0.13374701461621694, 0.1511241335953985, 0.11811747614826475, 0.1974184201764209, 0.2505348878247397, 0.1208301777286189, 0.15111365701471055, 0.12641745220337594, 0.14571216542805943, 0.14188758922474726, 0.12521477602422237, 0.1116756411003215, 0.07039160281419754, 0.12859525105782918, 0.06866938594196524, 0.16625933216086455, 0.13447554409503937, 0.09234826319984027, 0.2141625066953046, 0.1328050723033292, 0.1440323434237923, 0.23055344287838253, 0.1088523179558771, 0.07477970235049725, 0.11899114426757608, 0.18322205623345716, 0.06382419129035302, 0.1146141727055822, 0.11707796049969536, 0.16344628882195267, 0.10686121801180498, 0.19205599863614353, 0.1160570638520377, 0.12522708464946064, 0.14428565411695413, 0.08998444397002459, 0.08723693354321377, 0.1113747718877026, 0.13433348600353512, 0.17210066371730395, 0.09800841233560018, 0.1664448572056634, 0.15697587387902395, 0.12067224191767828, 0.18048652873507567, 0.10749345658613102, 0.10804174680794988, 0.11438608994441372, 0.11465579404362611, 0.08643934955554348, 0.0965659147394555, 0.10778812398867947, 0.08850554975547961, 0.15805106689887388, 0.12170296375240598, 0.21981486624905042, 0.06369731202721596, 0.10218547391039984, 0.07727249073130743, 0.18497776559420995, 0.14744367823004723, 0.11900159370686327, 0.08919230861855404, 0.10566947303180184, 0.13014843128621578, 0.09206764825752803, 0.09856397645281893, 0.11362772528082132, 0.1857064850628376, 0.058841172605752945, 0.14836097615105764, 0.15034247482461588, 0.1195078215428761, 0.16008093154856137, 0.1621012288544859, 0.13354382051953248, 0.14525038163576806, 0.11018116093639817, 0.08573524055204221, 0.1724475986723389, 0.16019337837185177, 0.14225918214235986, 0.14126537261264666, 0.1380641529602664, 0.12357341338481222, 0.13351249934307166, 0.17812947449939592, 0.13594370388558932, 0.08971248034920011], [0.05829926061310938, 0.07233584312988178, 0.016423578806487576, 0.023344988834911158, 0.02551995310932398, 0.01405218373318868, 0.00904732894351972, 0.025366980782044784, 0.060748392050819736, 0.05651654216593929, 0.05686071887612343, 0.0603282092405217, 0.02482834780987884, 0.04860235058835574, 0.02932916727981397, 0.01701240979933313, 0.059109010733664036, 0.005168003021805946, 0.010125909549450236, 0.03550961706787348, 0.04118872447205441, 0.09976510557213, 0.027416648476251533, 0.018938358507252166, 0.027197948158053414, 0.014765456352116806, 0.03703143880037325, 0.00819154700729996, 0.02955980133265257, 0.039172240532934666, 0.016039108990558555, 0.030309833586215973, 0.038228798657655716, 0.02354206933107759, 0.02223959082870611, 0.005298704981604325, 0.02981962596199342, 0.011860491874228631, 0.011204727642637278, 0.040814950064356835, 0.009553881628172738, 0.03396052162029913, 0.036960162089339325, 0.060228736006787846, 0.043952007445373704, 0.009895453612054033, 0.0325607751230044, 0.08546115990195956, 0.01894931515146579, 0.02255512148674045, 0.04636830796620675, 0.027187720938984836, 0.04683658194595149, 0.03802072250151208, 0.00557566134791289, 0.015183598468346255, 0.05073070798867515, 0.028145535882296305, 0.05274207577375429, 0.058517735318413804, 0.029064623439418416, 0.06843512851212706, 0.0033929399339415666, 0.02121676205258284, 0.037535953335464, 0.054654787959797044, 0.0026021226367447525, 0.06063538882881403, 0.009507685267765607, 0.06661931451942239, 0.04397979345438736, 0.02146813552826643, 0.018524428397150974, 0.07442611775227956, 0.020842334554929818, 0.03471407207793423, 0.04428362107968756, 0.0286725964397192, 0.027560694675360407, 0.044259807893208096, 0.03806583150955183, 0.021795174140217047, 0.014802353390093361, 0.06147937782640968, 0.05633879313245416, 0.027091869385913014, 0.007869809450182532, 0.04942375794053078, 0.03927327100453632, 0.0789068712453757, 0.053346507983016114, 0.05468633983816419, 0.010058395315094717, 0.018918618227222135, 0.04157783716384854, 0.08249165995844773, 0.014747994253411889, 0.03964364934446556, 0.020523736918611184, 0.03093323084924902, 0.047876786307564805, 0.04722305513652308, 0.02928473680679287, 0.021774180266740065, 0.029357228095510175, 0.028214023814403584, 0.12457152482654367, 0.03146453394687601, 0.03137100807258061, 0.07517829417650189, 0.02716119191609323, 0.009870491156886731, 0.0042887543760506165, 0.061600408117685995, 0.007620998292363116, 0.040521731334073205, 0.025757443758526018, 0.045337304539446316, 0.02353552825349782, 0.041160253142671924, 0.019968568048040782, 0.01980883751197585, 0.0333750680355089, 0.025557338692513958, 0.02645711853568043, 0.056025812069752386, 0.029939346680683748, 0.04172086216775434, 0.055422736930527856, 0.03938139555975795, 0.037205961399844716, 0.03521328725452934, 0.066132642062647, 0.04280341729255659, 0.041606396702783446, 0.02827408943059189, 0.01676497861210789, 0.04685835613469992, 0.054045541544577906, 0.018839509525735463, 0.040750991353499036, 0.016636640498680726, 0.059485869083021364, 0.020821868242429833, 0.0007057608121873013, 0.056363841252667565, 0.024760538412790214, 0.0563869148359767, 0.06551593515489783, 0.08535009050475699, 0.04472439403512648, 0.03286047725539122, 0.035148290385093005, 0.01660798766118075, 0.022767955869702355, 0.037598348023103814, 0.10871929116547108, 0.018167464694540416, 0.08327462151646614, 0.008944904930623514, 0.04018369197313275, 0.019147184444591403, 0.04755982563697866, 0.05332504592037626, 0.048065938122038326, 0.03871525737590023, 0.03960300848952361, 0.013822912687568792, 0.01334424948851977, 0.07495034033698694, 0.04487334943509527, 0.015237234965232866, 0.06130949979914086, 0.0189675847068429, 0.02990976594654577, 0.06436410839004175, 0.042293152173182795, 0.0453817451904927, 0.010936728362659258, 0.019097327387758663, 0.010110114102384873, 0.02946111180686525, 0.015367500118112989, 0.05010802658008678, 0.03578511246347001, 0.06657866348645516, 0.06221587330635105, 0.041221965902618, 0.016110923440594758, 0.024507103886987482, 0.06807547102549247, 0.03106992851410593, 0.022336680708186965, 0.029469176195561886, 0.021139393793419003, 0.016324975793915134, 0.02766615937330893, 0.10076166316866875, 0.027770901431462595, 0.04530761863238045, 0.031775482797196934, 0.053625874420894046, 0.011805919847185058, 0.035425034285123856, 0.03791803301178983, 0.02452402315767748, 0.023890369837837558, 0.01515748504815357, 0.05322804933946047, 0.10121693981013127, 0.006160145051710839, 0.038879951395626576, 0.03208120692787426, 0.03523297155542033, 0.04122139932587743, 0.011100452925477709, 0.09027354060006992, 0.015198568647195185, 0.03267229235331927, 0.006951167181666408, 0.02670500094869307, 0.02640059487228947, 0.03308762024555888, 0.04062805098614522, 0.005514326447155327, 0.026926116851557578, 0.03775542887992092, 0.040765169342713695, 0.019402157548548918, 0.03013686483193721, 0.010373087982381029, 0.019775543494948318, 0.019601480602951984, 0.015258301781224353, 0.06172117378030505, 0.0018829064751376531, 0.029391029317464148, 0.035258833917656114, 0.01476333593018353, 0.025825334579816887, 0.033490123825946023, 0.03295965871906706, 0.09259015414863825, 0.0416577278769442, 0.03840901416593364, 0.03317484252953103, 0.021946000600499765, 0.04606605114947472, 0.029356997393603836, 0.012853476983894194, 0.02438683864394469, 0.002437076414935291, 0.05531298049858638, 0.049289024634552855, 0.025483061160360063, 0.022562846607927765, 0.050465672210391076, 0.025212692096829414, 0.0599924497572439, 0.061153409603450976, 0.0022803106528174666, 0.017683117916541438, 0.02232637206491615, 0.039626855602754016, 0.021222197118082216, 0.07464870437979698, 0.054019892920872996, 0.07268924452364445, 0.019776585046201944, 0.08372476843318769, 0.028791017763848816, 0.06196682381310633, 0.06382244745535509, 0.045136800834110806, 0.0577599202681865, 0.0652892841026187, 0.042173923392380984, 0.02399233159875231, 0.056654722429811954, 0.01059559318569622, 0.04381861085338252, 0.0320005087581064, 0.055074994518820725, 0.05073142723579492, 0.02551785304344126, 0.04940262836005006, 0.011904929132599915, 0.037042756764484305, 0.008369134040549397, 0.0627663212695292, 0.04075004818982311, 0.030847487771617513, 0.02664845353657646, 0.03559326007962227, 0.037826746303055964, 0.032937579189560244, 0.03333450181941901, 0.01241297204978764, 0.03965682310185262, 0.031065663921513727, 0.03883901198527642, 0.051223422799791606, 0.00807143104196127, 0.08815338329545089, 0.046374866007161994, 0.06472885488931622, 0.02516958985610732, 0.03871316070269261, 0.03520506001742823, 0.04304743544863803, 0.0248934583339308, 0.012718929426877626, 0.022992157410564165, 0.011224980216606386, 0.06014106249702828, 0.028475597367755005, 0.012429752220798816, 0.03246692355190005, 0.044010863572891266, 0.02045095046716077, 0.02551899298227259, 0.028979826918137924, 0.022532188699447682, 0.05697302320705993, 0.016465405401374613, 0.051251202023455074, 0.020323467307857106, 0.011448891683747726, 0.06562066024967603, 0.02983393965821181, 0.006889509128606213, 0.029896846639790704, 0.013584841042757034, 0.010773831612563558, 0.03769005203087415, 0.06043220151747976, 0.07162475200103861, 0.031177140439727476, 0.022975699543686848, 0.06563219534499304, 0.01676300577154117, 0.07679660019597837, 0.06867657841316291, 0.017039712352145995, 0.025480570936841623, 0.07575318297105176, 0.021872854525489465, 0.05443792138248682, 0.030625925731978247, 0.04305246000045112, 0.020638019179127047, 0.015258831038538898, 0.17739990007664475, 0.13943703286349773, 0.07690034141497952, 0.09093181456306151, 0.094536450425429, 0.15459131183368818, 0.08389726560562849, 0.17396158671804837, 0.15530025879187243, 0.17573447658547334, 0.07226425090006419, 0.14700754306146077, 0.16177783906459808, 0.15168628628764833, 0.13858777843415737, 0.19366393664053508, 0.18118445628455707, 0.14677738398313522, 0.08511043193617038, 0.07862263292606388, 0.12807204627564975, 0.3066117630473205, 0.20347114253257, 0.05839753283986023, 0.10052318525101457, 0.10652448143810034, 0.1320034781736987, 0.09724294341036252, 0.14673910103738308, 0.13635414971836976, 0.11577650319252696, 0.11843205855361053, 0.13253018419657434, 0.1995638936225857, 0.12877587707979338, 0.14180985625301087, 0.11000502003090722, 0.197927022884999, 0.1236755329051188, 0.16188708320260048, 0.16735568190259592, 0.08278229686298541, 0.1241845970175096, 0.08897270754511867, 0.08299640180276972, 0.0712316698793854, 0.12885921475078377, 0.14507105840103968, 0.13304964346545084, 0.10874808819166251, 0.09000484751803534, 0.09626924565860204, 0.14124725572764874, 0.08441032628927912, 0.07268407408680234, 0.1070733687707356, 0.09399267924683434, 0.06930128524878196, 0.14508802177650587, 0.12788937107792922, 0.09111632180533238, 0.15053812361189298, 0.0875298571107643, 0.13303125516644546, 0.09821440878191165, 0.17167138175240584, 0.14526826781885965, 0.14647158182093076, 0.11260135964091335, 0.15312795607107027, 0.12099409821842398, 0.09258053252207381, 0.11265162551509482, 0.12385307837809835, 0.11847541694130216, 0.07175334795777287, 0.08459269614624125, 0.133303985531841, 0.12964907022459166, 0.11710502047623907, 0.1341480016708374, 0.10127511061728, 0.1554966675383704, 0.19083725474774837, 0.13727053840245518, 0.08783171698451042, 0.11844066237764699, 0.10916170278298003, 0.09473732393234968, 0.10733009928039142, 0.18140796571969986, 0.15433156862854958, 0.16201259861035006, 0.0935096980205604, 0.12435575069061347, 0.2302507348358631, 0.09510333929210901, 0.1228008469832795, 0.08772332780063152, 0.20994888565370015, 0.08594129806650536, 0.14860881785196917, 0.1943813788571528, 0.09366915374994278, 0.10695661325007677, 0.12005926695253168, 0.21989204282207148, 0.1700673113976206, 0.12225624120661191, 0.20422886258789472, 0.15601935663393565, 0.15727111803633825, 0.16783479547926358, 0.24959185985582216, 0.11941752210259438, 0.08145333853151117, 0.1417328289576939, 0.19038597467754567, 0.09325525417391743, 0.1750823501497507, 0.14528470193701132, 0.07815110537090472, 0.12879619241825171, 0.07898714872343199, 0.11281819907682282, 0.1632169439856495, 0.11973532076392855, 0.21554498108369963, 0.16062944568693638, 0.060572726119841845, 0.09411274601838418, 0.1367281853620495, 0.13480795840067522, 0.1089422306311982, 0.08154742419719696, 0.0802514630236796, 0.14979823545685836, 0.10846510516213519, 0.17608483135700226, 0.08065115407641445, 0.10438229888677597, 0.0910586870408484, 0.12655112360204968, 0.08977802004665136, 0.07034176441707782, 0.10847376326897315, 0.08399653527885675, 0.12448183606777873, 0.16555898902671679, 0.23442046823246138, 0.11423962137528829, 0.0912701389087098, 0.12298950685986451, 0.08089614593024765, 0.1484292774860348, 0.10853288402514798, 0.12178054744643824, 0.0983823122722762, 0.15910833302353108, 0.089550378333245, 0.14461246372333594, 0.0902632607945374, 0.14568914952022688, 0.18682848342827388, 0.18783177887754782, 0.17500616423785686, 0.1714620672698532, 0.08973230035709483, 0.16055239125021867, 0.18986190137054237, 0.17536854264991625, 0.10315113780753953, 0.145911179749029, 0.14148862420448235, 0.09199419005640916, 0.17966406286827155], [0.008968913195920842, 0.005669317840199385, 0.0743587256542274, 0.02667013612309737, 0.034938955546489785, 0.04048159938039524, 0.04818072249846799, 0.08017985722316162, 0.04351631671722446, 0.013492323641133095, 0.010320498973929455, 0.04177955544686743, 0.045372327124433856, 0.058658863816942484, 0.03406362501638276, 0.017518278011786084, 0.042759136097239595, 0.02845924297746803, 0.022859946558518068, 0.028450103110766838, 0.033578445336648395, 0.0533004286698997, 0.018515407274078046, 0.020706658085275973, 0.02350852425609316, 0.05164478626102209, 0.008296296698972583, 0.006431920379067638, 0.035011077033621926, 0.03940444878701653, 0.055665353911795785, 0.0117706309372027, 0.03677733761391469, 0.027468008488150578, 0.04241545132494398, 0.026074170334530727, 0.02978665933811239, 0.017910727399534414, 0.022194717611585344, 0.03714627067425421, 0.016618542273395827, 0.03671775545392718, 0.030515388984765326, 0.016044596642521874, 0.13943183528525488, 0.044169576306428225, 0.014392240039472069, 0.05779654758849314, 0.026128000213897655, 0.02912251265453441, 0.029987322499177287, 0.025401240015136342, 0.019652967840167027, 0.05792817659676075, 0.03999055376542466, 0.006675335911235639, 0.03465159257341709, 0.018864810400243317, 0.02153566333332232, 0.045391631445714405, 0.04189057395394359, 0.027873738502551402, 0.07522221574825899, 0.03764419663431389, 0.035442733871085305, 0.054894823115319014, 0.015222100241641914, 0.022071921432922994, 0.037490650944943936, 0.028880815088216747, 0.0501174548241709, 0.08182827662676573, 0.00966823598303433, 0.03598620988694685, 0.04782903101295233, 0.04662504865388785, 0.04084801507581558, 0.051750430770750554, 0.037886335248393674, 0.02788639996599938, 0.07683350571564265, 0.011874985382226961, 0.06427689628409487, 0.016695601799126183, 0.015928687594298805, 0.06894739530980587, 0.07498848757573537, 0.02658950411049383, 0.0654132863772767, 0.033539497426577976, 0.0021899064636922306, 0.029667535730238472, 0.01261021793886487, 0.019852029658587914, 0.04408269328996539, 0.03727633905197893, 0.042258258509848795, 0.010978442151099443, 0.03599592650841389, 0.02689769641230149, 0.057700514527303834, 0.051673997193574905, 0.005846184354075896, 0.03529586496629885, 0.06959873464490686, 0.02332029864192009, 0.07905287841068846, 0.043906789871730974, 0.07372726060982261, 0.046603508559720855, 0.012752761182907437, 0.017312551283144524, 0.050695498806557486, 0.0497727556420224, 0.05587726379079478, 0.02731385381360139, 0.02683228224382869, 0.04692233180893319, 0.02837148804350623, 0.07222756251160588, 0.02878616963114057, 0.037867702676781585, 0.08364181752715792, 0.04076298785262874, 0.03878924822700875, 0.01873409402157579, 0.04288983211985656, 0.05174571495237095, 0.023864692376394357, 0.054019272061330934, 0.02024685900791415, 0.006976460422655302, 0.06472883453326565, 0.052041973519538126, 0.07090386282652617, 0.038921179183359654, 0.047281585567231686, 0.051315503394497294, 0.02804796933196485, 0.02420338143461517, 0.00880673569294491, 0.027904927364683578, 0.05661043784181986, 0.00888655600803239, 0.06097606090562684, 0.0051964849532981005, 0.013574131215656442, 0.006169594075929905, 0.031129507281418358, 0.07905758744371788, 0.05002065501841051, 0.028733484779617617, 0.022195333382114768, 0.052422431497169394, 0.006614945870491543, 0.03827125459377255, 0.047084220086357424, 0.05079348265592541, 0.0063748411651301596, 0.09158863646111318, 0.03796929633244872, 0.05124210626153009, 0.022760346099468212, 0.04711763793602586, 0.04857593522007976, 0.05799859496099608, 0.04700578822355185, 0.018651238110448633, 0.028642472877566303, 0.07107521327478544, 0.020128732846517648, 0.029243715972240483, 0.009739205656972314, 0.01868029297994716, 0.04992952437273093, 0.032854105811566114, 0.02285939864149051, 0.03409301236804042, 0.03843402835939612, 0.01626070834962385, 0.03190837727327432, 0.016965504369831512, 0.020839047052764466, 0.03757952546168651, 0.049755758339805264, 0.02091190135771675, 0.06009458963360105, 0.0475850094641958, 0.08939499381397452, 0.009657811988810343, 0.022026978665962815, 0.039507592895201275, 0.011052823159843683, 0.03198290416704757, 0.03778833104297519, 0.03203923275162067, 0.04469551219205771, 0.05667684606409498, 0.02719819243066013, 0.022688209345298152, 0.024387488341225044, 0.030885556978838782, 0.058276896098894734, 0.009633499230923397, 0.030601294910801307, 0.023947673816499964, 0.05611991130613855, 0.01791697501071862, 0.02311775424251599, 0.06085724263851132, 0.05862679625196116, 0.012681725351805133, 0.045866225979157856, 0.01888896115789456, 0.020636958968160406, 0.020798594491290193, 0.03603838922988091, 0.04020668413223965, 0.04845697106793523, 0.028459953742900064, 0.03880882735497185, 0.015927216869645884, 0.011375016183592379, 0.010057280821326588, 0.03406533831730485, 0.04118200019001961, 0.06857931720358984, 0.012087555136531591, 0.02500798486705337, 0.08883189117269856, 0.06355591890003, 0.04716818879491516, 0.01637877174653113, 0.0029629359653751764, 0.04779394057446292, 0.07243898045271635, 0.05320710635610989, 0.01975642068178526, 0.03495269248794232, 0.00994106219150126, 0.03489485755562782, 0.023668275148208653, 0.013026635727978178, 0.020442256737234335, 0.043890739125864844, 0.0181494495897953, 0.025392522536484257, 0.060796825880450864, 0.037238171457179954, 0.03937238461471029, 0.022144387276577096, 0.021434207080996463, 0.03410767890246851, 0.008026350871659815, 0.023830770714474574, 0.030324377984340702, 0.017947744877476777, 0.011316455218807926, 0.012155690230429173, 0.05967534998697894, 0.049824585539421866, 0.028286913742444346, 0.03290473809465766, 0.008537054494289415, 0.03537000848778656, 0.04474484168791345, 0.030497879388609102, 0.020187938419569815, 0.009376977370785815, 0.02785884465889207, 0.036861889862588475, 0.023385901103860567, 0.09156726939337594, 0.05511312140151858, 0.035474889645619054, 0.01953563217206725, 0.04272402869537473, 0.033427400048822165, 0.07327819256378071, 0.01527621001670403, 0.0876935672547136, 0.02746063790151051, 0.0109111289327432, 0.028344711355332817, 0.037298595000590594, 0.04270568110847047, 0.0410003190461014, 0.011838881382053452, 0.048051997620080195, 0.08589402453175612, 0.01108192213411842, 0.0724439269730023, 0.08374044259211846, 0.02934239532000252, 0.1097666642495564, 0.037958599227879725, 0.06331170736146824, 0.03689201681741646, 0.025836968062711612, 0.025131366282169307, 0.022190680328224386, 0.02312950138002634, 0.025479926328573908, 0.019160466767581444, 0.02979696967772075, 0.05938158503600529, 0.03949104342609644, 0.0280875041748264, 0.06112040566014392, 0.011400853948933738, 0.03841764173869576, 0.0431399740544813, 0.02621964824252895, 0.05838419284139361, 0.05581589029835803, 0.0428956369869411, 0.023329458864671842, 0.06045302575720208, 0.028214490307228904, 0.033785235668931685, 0.0697334577728595, 0.014730011379080159, 0.03160165908879467, 0.019729287762727057, 0.021385852979230027, 0.022298613197303245, 0.05997355255697455, 0.027957827651074955, 0.03648139117285609, 0.047790340946188996, 0.01044988542396043, 0.010865032656251319, 0.054401392449757884, 0.05353058096287506, 0.059935262825872214, 0.02878815434607012, 0.027291497781074474, 0.02091449505782553, 0.07415990132306303, 0.023319913573297005, 0.03110552785385932, 0.03388267669028469, 0.005863589201388615, 0.029913053448711122, 0.03162120429000684, 0.04725613032600709, 0.08675937381173883, 0.02587508985639683, 0.0191321498049157, 0.005078776939106839, 0.0728795328842742, 0.032597589040441174, 0.13214841325368198, 0.1344373290027891, 0.16911508249385016, 0.09649014273392302, 0.15133321737604483, 0.20683744975498744, 0.11725664591150624, 0.14079776698989527, 0.1204851291009358, 0.057553883109773905, 0.11960980535617896, 0.11519776710442134, 0.12181447419737067, 0.107273577313338, 0.1226755351360355, 0.1597519234887191, 0.11600161397031375, 0.09516484849154949, 0.05981910441602979, 0.14318379467087133, 0.06948463219617095, 0.09748895306672369, 0.0889390114960926, 0.057713644179914675, 0.15639090883944715, 0.10547127295285463, 0.12000338280839579, 0.12101528208170619, 0.11256892566702195, 0.1482779641768762, 0.15413719548710755, 0.13601011889321463, 0.11788482006107058, 0.14870416559278965, 0.1244381655539785, 0.13539977664394037, 0.08727926055767707, 0.1223213127149003, 0.07418700879705803, 0.09651564886527401, 0.11815064293997628, 0.1955847064299243, 0.1777253390422889, 0.13696139784795897, 0.18121695811195032, 0.16217727905937604, 0.12905427999794483, 0.17652927179421696, 0.0917673490143248, 0.13376046318028653, 0.2178193490420069, 0.07538400563810553, 0.07295512168535165, 0.12823375474129403, 0.10806895606219769, 0.17365757588829311, 0.09332160811339106, 0.12784000086997235, 0.15376602326120647, 0.1566346657595464, 0.11248538443552596, 0.045340283308178186, 0.10925502170409475, 0.09548581591142075, 0.10433465894311666, 0.1293706265943391, 0.16135714735303605, 0.09845133285437312, 0.10845427574323756, 0.09914871757583958, 0.1167690913592066, 0.24547483505947248, 0.10704998645399298, 0.09793564624020032, 0.15050174056419305, 0.1315096675285271, 0.22867088818124362, 0.2018791636718171, 0.0842092763632536, 0.11217863232429538, 0.140322778906141, 0.09461311809718609, 0.16092273566339696, 0.16263780077653273, 0.13049922032015665, 0.13588244574410574, 0.11889924348465034, 0.11629476823977061, 0.26227590494922226, 0.13153375552168914, 0.08983720187097788, 0.09685428533703089, 0.07391683650868279, 0.15994964859315328, 0.09890148655644485, 0.10529002946402345, 0.13410659746399947, 0.15396875595407827, 0.07716634749834027, 0.10508695750364236, 0.11541816884917871, 0.1290422970695155, 0.08230582957289048, 0.08571445023907082, 0.18205446031476769, 0.10317779066307203, 0.12587747403553554, 0.17977190922413552, 0.16812493705323764, 0.08671277202665806, 0.2079247206981693, 0.07870814869446413, 0.08373559785208531, 0.16119328114603246, 0.11556660516985826, 0.13432674136544975, 0.13782049103506974, 0.08566617925784417, 0.11500768230429717, 0.09552990711693253, 0.20145294868520328, 0.13833198430282728, 0.14916326238640717, 0.10932913808418171, 0.07513633357094866, 0.08581545017659664, 0.07206075146262135, 0.12479203513690404, 0.09462772695613758, 0.17999083176255226, 0.20044963966522897, 0.06738252392304794, 0.24456622238670075, 0.11139966055218663, 0.20139188053352491, 0.1704090487744127, 0.15414718352258205, 0.26958057869757923, 0.08642944294427123, 0.12242274012948785, 0.10626039560884237, 0.11484845727682114, 0.13077542478484766, 0.13001850540084497, 0.145067177180733, 0.06059271576149123, 0.22678662357585772, 0.09482545206057173, 0.14433422365358897, 0.1504104911748852, 0.18255486632032053, 0.09795411596340792, 0.08070619005177702, 0.10351111420563289, 0.05426878635106342, 0.11851395773036139, 0.15051418489643506, 0.10912567935883999, 0.12932979235691683, 0.13880288760576928, 0.1168713601572173, 0.10677802961851869, 0.15962150905813488, 0.15077357526336396, 0.07984466770929949, 0.09252082822578293, 0.14678304296519074, 0.10006655832486493, 0.1437021004302161, 0.20312773595963204, 0.16063139986779007, 0.10452534763940743, 0.21772937529853412, 0.13918973399060114, 0.24665958434343338, 0.09241845764751945], [0.026810526714793274, 0.07334112668676035, 0.009748218298357512, 0.09586349528815065, 0.05436365572469575, 0.03416224329599312, 0.03205428944368448, 0.05945794736700399, 0.01248736323655716, 0.03186555832092251, 0.04036556310685618, 0.03574230368914349, 0.07401393486985139, 0.008543654943683317, 0.018076707243121097, 0.04801376895712955, 0.04793783071051751, 0.013690133562444575, 0.028026067917900424, 0.03605831101802843, 0.003765938479253756, 0.06854676787874528, 0.04338496930098959, 0.04015544116763132, 0.06019323505461216, 0.031178894452750683, 0.01783554911214326, 0.02417108486406505, 0.0554531386920384, 0.036291818666671, 0.020487470918201973, 0.010365694495184081, 0.03526782111397811, 0.012924167610305761, 0.0245150512283934, 0.01318378359012838, 0.06310326818908964, 0.017799184724156345, 0.06022013218275138, 0.06482338838811431, 0.016565187368541956, 0.02369358789707933, 0.01856963579276843, 0.028217145075489367, 0.043940801439540725, 0.04438276183126228, 0.04191362718120217, 0.07101488472627741, 0.05784631134676082, 0.06618516745844058, 0.017026221379637718, 0.014879613083654215, 0.029173670802265406, 0.03667353871943695, 0.14354835796569074, 0.044444600120186806, 0.02179480094595679, 0.015611614965434586, 0.00835145141796342, 0.025393026348735605, 0.06495581128235374, 0.033800540026277304, 0.03714732240353312, 0.006738954930499728, 0.016848021120365177, 0.03528659278526902, 0.05232296844146081, 0.030340255703777075, 0.026518000090228658, 0.06218120016689811, 0.03487899340689182, 0.03783910921109574, 0.02234269422478974, 0.0462506567793233, 0.05947684456727334, 0.0311421857082418, 0.023962253837713172, 0.021941476468262926, 0.04436224293229835, 0.03708652227318712, 0.02432877300972385, 0.03792172084961619, 0.009681204483578247, 0.01951572056194501, 0.00448644470556506, 0.04164595529437065, 0.010671569599903055, 0.01165458363746958, 0.02912249229848385, 0.03742176267717566, 0.03883145310516868, 0.02199010707304946, 0.017512043971302252, 0.10873320791870356, 0.00770748097316495, 0.029125793371349573, 0.0026161021544664565, 0.03455407012786184, 0.043934189115784, 0.057611260030950816, 0.0036361728977811125, 0.02513292521637465, 0.03443286681015577, 0.023200094467028975, 0.03115703205444983, 0.06862330662884883, 0.031542850458728414, 0.05696563396070685, 0.00926642959737884, 0.036288181718971045, 0.04243935950632606, 0.017943288598741804, 0.016785209133688892, 0.031646157415317636, 0.0488676984927484, 0.028417552089584724, 0.008356200314925184, 0.05682229683069246, 0.03361226012930274, 0.07368236873298883, 0.010699659253337553, 0.04878388923992004, 0.030284167999135594, 0.06329186699752297, 0.010281930195300706, 0.013942895490410072, 0.03431405872106552, 0.02258296517123069, 0.03815438711483564, 0.04240604004423533, 0.018432459760723368, 0.022292562361274446, 0.04091057939721005, 0.00802269102340298, 0.021749466325023344, 0.027501597667911222, 0.016451626051483408, 0.03163241708119001, 0.006427784708128976, 0.03733079827257565, 0.02520980323398752, 0.05532754186008658, 0.05182193139834063, 0.02839636822630252, 0.035375480872711966, 0.010260781106938208, 0.021627559027235423, 0.02021853017088558, 0.027376704816041247, 0.022825186905850257, 0.027120432317523018, 0.04523633513599634, 0.05238801959369864, 0.007933935250288673, 0.05900108973894801, 0.02437040622213057, 0.01604568738756435, 0.02976649667003325, 0.07203209692878382, 0.043188418062137704, 0.011134037864394486, 0.01636979981724705, 0.02882424901638712, 0.06833190297974007, 0.030585678427347114, 0.024589656153693795, 0.04709879501855799, 0.040136432009083886, 0.022826143640226552, 0.0515146025323442, 0.03954128555155226, 0.08225273420768124, 0.05622825299256614, 0.022760254497240697, 0.03210813119741423, 0.008193672518245876, 0.05747579051447766, 0.03731173822390182, 0.026499292879764522, 0.06378437485545874, 0.03600879492504256, 0.057540733101112504, 0.02179844637534448, 0.05151949476982866, 0.043238334490784576, 0.06124669459781476, 0.045166574950729094, 0.03614953665861061, 0.10242066771856376, 0.03128096308293087, 0.015731037128716707, 0.013073340989649296, 0.013789885843704854, 0.037239857616701295, 0.024477667341540967, 0.051445201970636845, 0.016913681257782236, 0.020420389249920845, 0.014455382811969944, 0.07606100038226161, 0.04244682339153119, 0.028296060394495726, 0.03161748591810465, 0.0100538355597694, 0.05214209814688989, 0.03614621522969433, 0.007566829993655639, 0.019426328662250723, 0.00540722139079922, 0.057591670724962435, 0.03933932978127684, 0.0050898913427123, 0.03465937876275607, 0.02044825498679919, 0.023274419496634176, 0.05699805436389787, 0.03416432300582528, 0.02808687652993415, 0.022843229151996117, 0.05895796205316271, 0.06781568710825273, 0.02647319811928485, 0.01840434975123831, 0.016780333859579902, 0.0318535143243415, 0.07352818522070136, 0.027061786535861235, 0.09702161885797977, 0.04245126101055315, 0.0502619895684932, 0.07986262853124312, 0.03569648561200925, 0.015533378181446875, 0.023362247373110483, 0.03101918088006122, 0.0314591701275536, 0.03575914832098143, 0.013899352201925856, 0.0348649477320058, 0.04514299925150616, 0.03388395233611975, 0.04551263798826507, 0.024311054764049392, 0.060504445140915256, 0.04645844116540892, 0.04443829992253866, 0.06396254458065544, 0.03245661999764187, 0.017676634514438253, 0.00735990734704371, 0.07691161866698946, 0.07658274631415095, 0.03878497006371617, 0.06081805724118437, 0.011947612377947994, 0.04578474070876837, 0.04524721544502037, 0.03137494018301368, 0.03608633451429861, 0.025245763893638338, 0.06464109995535441, 0.02785926195792854, 0.009839299750248236, 0.03565089823678136, 0.006770986448308187, 0.05740178269999368, 0.005280978678326521, 0.02343679971194693, 0.043726435263774226, 0.031106983311474323, 0.04877048138795154, 0.053353978653571436, 0.03967764734157494, 0.011302643638503338, 0.027970833471044898, 0.026468928437680006, 0.05741663583155189, 0.06726234180054494, 0.02499056517678712, 0.0571787685954145, 0.034333067879612954, 0.015374170117346304, 0.01429852587170899, 0.0375345996581018, 0.02309629557255123, 0.058901765782918246, 0.011380739626474679, 0.0479888904706708, 0.02300994859875313, 0.055398805000420125, 0.07577233801462821, 0.05436144030785986, 0.061079293223364015, 0.02926069631108216, 0.04402759963912623, 0.033715122645454745, 0.016949536744505167, 0.02776906599423715, 0.0400248706739928, 0.01987675208199237, 0.06085344284240689, 0.015103008864181382, 0.055415473213153224, 0.013589367719500192, 0.06767040597540991, 0.04499832201482994, 0.021552840447319404, 0.01701539196074009, 0.017321565620867268, 0.013109709618480077, 0.08343635033816099, 0.020909390778147748, 0.05235820137230413, 0.03345401219225355, 0.038652635379029174, 0.0226689084166927, 0.004134133632760495, 0.022117605499391044, 0.011972662194498947, 0.04735427702377949, 0.0013965764665044844, 0.01070376014935651, 0.07186175749770232, 0.04033544972272856, 0.031139447819441557, 0.06539685904447522, 0.0532306447359068, 0.030115300989044563, 0.035019881025488885, 0.04296175004648311, 0.03980429929548076, 0.03233090442206178, 0.00607944857828053, 0.055321153452886004, 0.05610438981758697, 0.015105611045977898, 0.024445531923057776, 0.06268960610032082, 0.06681327375450305, 0.03719106077083519, 0.05164886764915926, 0.058424782806209156, 0.06112971516059978, 0.040889130905270576, 0.022054930916056037, 0.012298021432278412, 0.025147759688219855, 0.05948907855365958, 0.06310948356986046, 0.01329310067064528, 0.03236696855830295, 0.02667005469889513, 0.12165359354444913, 0.11793519450085503, 0.10271112820399658, 0.22227284578340395, 0.13819459453225136, 0.1128350335306355, 0.2085364471588816, 0.22795552228178295, 0.10102408658713102, 0.14237798005342484, 0.15113855924989494, 0.1456176454999617, 0.16010820865631104, 0.1504294087312051, 0.1884489200477089, 0.11001807504466601, 0.07000485820961849, 0.08592498608465705, 0.13121411124510424, 0.15048477718872683, 0.1160287553710597, 0.16205378568598203, 0.06884940806776285, 0.18520039293382848, 0.13174627268952982, 0.14019669352897576, 0.0721741821616888, 0.07652254668729645, 0.1540300412369626, 0.1301917896739074, 0.1151302664407662, 0.06423181441745587, 0.14859485360128538, 0.08850375163768019, 0.08989993921880211, 0.09118943395359175, 0.09809984492936305, 0.07804902656269924, 0.1712764608008521, 0.22023321022944792, 0.12174618643309389, 0.07030563242733479, 0.10380949319473334, 0.1164243005748306, 0.28016178948538645, 0.10662693344056606, 0.11226293351501226, 0.1230543205248458, 0.09859497871782098, 0.15113519371620246, 0.08712578272180897, 0.1339126043021679, 0.1469796145600932, 0.13600132507937296, 0.21988524390118463, 0.11178567233894553, 0.050605419890156815, 0.08066345591630254, 0.04368461036522474, 0.07206932814525706, 0.11972753118191447, 0.06182159696306501, 0.09109376730131251, 0.07613949331321887, 0.10028248173849923, 0.1335235187517745, 0.13785728120378085, 0.16313789465597697, 0.19465009229523794, 0.18442237111074583, 0.20753362668412073, 0.06982870373342719, 0.10124345695866005, 0.15329282650990145, 0.14661095291376114, 0.13657968118786812, 0.10617531410285405, 0.0900861495839698, 0.09172246392284121, 0.15916147588619164, 0.19523528803672108, 0.10460610687732697, 0.11833752505481243, 0.09690016108964171, 0.13571521400340966, 0.13443198214684213, 0.11443258316389152, 0.09100025160504238, 0.13471741468778678, 0.15073252389473574, 0.1959669387766293, 0.13206560484000615, 0.12038355240864412, 0.2702557753239359, 0.2188175961907421, 0.1736570873430797, 0.09426899227712836, 0.11322703678160906, 0.16085295512207917, 0.16124611188258442, 0.18770152729536804, 0.09026765770145825, 0.16783514831747326, 0.11138377604740006, 0.14960857134844574, 0.13772160134145192, 0.11609607961560998, 0.11133786636803832, 0.169559563643166, 0.1465444971940347, 0.07101810098226581, 0.10239118537200348, 0.18586712144315243, 0.16350705841822283, 0.14247456272797926, 0.10346978463764701, 0.12525897579533712, 0.10987835111362593, 0.10064151497291667, 0.19368395342358521, 0.20851986376302584, 0.13516804336437158, 0.07195297296025924, 0.11440595744975976, 0.10560007247009448, 0.11756284162402153, 0.1485795322805643, 0.104012985846826, 0.14973201043903828, 0.14037225767970085, 0.09286774282476731, 0.150523860805801, 0.09675850333379847, 0.14143455853419645, 0.1469538573707853, 0.07328670817826476, 0.06896921021065541, 0.11972818257553236, 0.09724607824214868, 0.2482661652777876, 0.08875197331820216, 0.1570802732769932, 0.14351263988230908, 0.17988244257867336, 0.0702561265123742, 0.09903690179011651, 0.176814609340259, 0.11561102207217898, 0.13848536035844258, 0.18407059141567775, 0.12067256761448723, 0.10051701736769506, 0.12529655306466989, 0.18696313191737446, 0.13221989013254642, 0.13909765678857053, 0.05778304474162204, 0.13529832208795206, 0.1297108033405883, 0.11357034157429423, 0.1188756711781025, 0.15950846512402805, 0.13172868506184646, 0.1452721490391663, 0.09560058332447495, 0.12738025268273695, 0.10763370298913547, 0.18128246388265065, 0.13337877366159642, 0.1111877201391118, 0.1153933751795973, 0.14529091731778213, 0.12373847381344863, 0.11056420073977538, 0.11846798019749777, 0.16171440961105482], [0.023854069910677414, 0.011362466678422476, 0.030917912921203033, 0.030696456054491655, 0.03893371851050428, 0.07280460226216487, 0.03306453987689955, 0.044001696564789326, 0.027112013394279138, 0.01624081709555217, 0.040674554383648295, 0.01819340169562825, 0.04531349813831704, 0.03065816293071423, 0.06757570962820734, 0.024402863944747617, 0.026183925070134655, 0.010820178098843565, 0.04758036828466824, 0.02405684331565031, 0.01188927363338215, 0.04567179176956415, 0.041153542431337495, 0.005124540309355195, 0.0670854477211833, 0.027379327353888323, 0.11879538691469602, 0.06239271988826139, 0.08130404047135796, 0.019500782613509467, 0.02898220518337829, 0.006582165843740637, 0.045214937534183264, 0.008302037105230349, 0.05752235158745732, 0.09059222814227853, 0.05351512393515025, 0.007002802000248006, 0.03347852087712713, 0.05657318287662097, 0.016947404448209063, 0.031629190647176335, 0.021835038072562644, 0.03605161727006946, 0.031702652240970304, 0.035588238920484266, 0.02297920417705817, 0.05945152164037738, 0.053904409653374126, 0.024231998649026667, 0.029936934488692453, 0.026095639182520763, 0.042184104810335805, 0.04164963973952191, 0.018881183450243304, 0.008911877238590802, 0.0359565138018557, 0.050605233293026686, 0.03768659150227904, 0.013200059100719435, 0.034784653290574036, 0.050715118646621704, 0.033293884713202715, 0.04241039963173015, 0.010572738429930593, 0.06546802379723106, 0.0018031480763706245, 0.05436495511925646, 0.05030277970113924, 0.019712295549522554, 0.008723261466782008, 0.034397403177406104, 0.016538300418428013, 0.004259499338721591, 0.02100599041607763, 0.04047449851142509, 0.021352338438321437, 0.06612677952008587, 0.04327467343370829, 0.015494314920423287, 0.011510995449498296, 0.024593120074963996, 0.010071535993899618, 0.01094757135225726, 0.07501219558928694, 0.02956854086369276, 0.0030098674760665745, 0.04363564049292888, 0.039915226200329404, 0.03974800803033369, 0.0051227790868974155, 0.043054495605507066, 0.012000951167595173, 0.02482469898781606, 0.016254867859450833, 0.04591179978368538, 0.05410885564716799, 0.0724579794332385, 0.04574910744226404, 0.03001493208908609, 0.010411934960367424, 0.048169842189443965, 0.04606639041698404, 0.05107983461182032, 0.013091605456013764, 0.06733776096786771, 0.013535058624776346, 0.005306908894064171, 0.07579248371933188, 0.04991861352963107, 0.018942143036318675, 0.011647928905274187, 0.022769457128431116, 0.05550842572535787, 0.037873185239732265, 0.07146015297621489, 0.05809829889663628, 0.02893437524991376, 0.030976470493312393, 0.019909939229754463, 0.015896584406229, 0.03154599546853985, 0.023806920208569084, 0.015590634662657976, 0.021348353741424422, 0.045466500999672074, 0.02280669513025454, 0.01183733347404216, 0.021084810740181377, 0.01445428528157728, 0.008611757807167513, 0.018291302424456393, 0.029864952101239135, 0.005726669316313097, 0.03334885283506342, 0.03344121841447694, 0.08486861562622444, 0.04836542312321918, 0.04513544037139841, 0.02298198447429708, 0.06490714675081627, 0.00901917228475213, 0.04070369067734905, 0.009573118944120194, 0.06409536102520567, 0.020485073993248597, 0.03766119393653103, 0.07636966596224479, 0.04794701807467001, 0.07272120352302279, 0.020547673937731555, 0.04740790503897837, 0.034224858507514, 0.012841531374890889, 0.06425261151577745, 0.11166259287191288, 0.04057133563661149, 0.05664263432845473, 0.022251281987077424, 0.04176369129813143, 0.01671088919309633, 0.00954696990083903, 0.009101437022244292, 0.02865630142124636, 0.03541422522227679, 0.021515711011098962, 0.06670785655400582, 0.026399159770725027, 0.024015257600694895, 0.04861309519037604, 0.0291274354260947, 0.05102245769064341, 0.02061149863792317, 0.009267636541543263, 0.02759805990249983, 0.0672728523079838, 0.02009201392398349, 0.03886394475453666, 0.027013210213876197, 0.0643184022711856, 0.005755591023314212, 0.057911701766507964, 0.031860791612416506, 0.026569346531427333, 0.01266122087171035, 0.036470843345991204, 0.04499084455892444, 0.04748655064031482, 0.05780171123998506, 0.06505902324404035, 0.052465012962264676, 0.015429236626784717, 0.05358124038736735, 0.010313897676366781, 0.025753966266555444, 0.015496386148567711, 0.01793070855949606, 0.040758624872458835, 0.028292832264144505, 0.03375818247773817, 0.10100322842065777, 0.022141520466123308, 0.07962641692055122, 0.010923100834978479, 0.06654990038701467, 0.0492180159448513, 0.04011038304971797, 0.013618629542179406, 0.024387227105242864, 0.014078634724553143, 0.06090096064976283, 0.06980330616767917, 0.06703446259988205, 0.06148922336953027, 0.04539478663355112, 0.02228997883919094, 0.0691989960947207, 0.03673322944502745, 0.02525351954890149, 0.04924707420702491, 0.033377076499164104, 0.0884610242875559, 0.034209713605897765, 0.057634811981448104, 0.025764629444373504, 0.010120559300828193, 0.01406057212235672, 0.006157321073780102, 0.050886893179267645, 0.023585168179124594, 0.024773011582770517, 0.055668997644845924, 0.03711356867903045, 0.054743574266987186, 0.05045934147866709, 0.022785417968407273, 0.018573518709412644, 0.013064281698981566, 0.009219339267084641, 0.08220700094742434, 0.005692863853515259, 0.02567705771486674, 0.007928265242039092, 0.0878116934161101, 0.021839804781068648, 0.01071551746489214, 0.012201960381519581, 0.05196393859971847, 0.02984981398497309, 0.05277294233175261, 0.010260189085134437, 0.044905084517917464, 0.011038752888063235, 0.007047992432489991, 0.03084414259397558, 0.03927496394940785, 0.0565505299850234, 0.05488024139776826, 0.05730090489877122, 0.01776549037146781, 0.036224630129124434, 0.015567698482690113, 0.017119430038811903, 0.0283867398143879, 0.09437420591711998, 0.06370844678687197, 0.03730760594563825, 0.06082130063857351, 0.03064261090808681, 0.05917660639222179, 0.0490579664973276, 0.025874241687623516, 0.061461260941411765, 0.058506302003349574, 0.01954448875039816, 0.02066442945839039, 0.034790824566568644, 0.024083312966727784, 0.05586355399074299, 0.02317421853409282, 0.03442914504557848, 0.032834591144429784, 0.02677376877649554, 0.038764973636716604, 0.06852987914213113, 0.03964048058592847, 0.0982665406273944, 0.017795434121840766, 0.02112687482232494, 0.01971115730702877, 0.03391753981954285, 0.085664462564247, 0.03503446274303964, 0.025701941290338124, 0.04850114709032433, 0.02208111897510077, 0.02214130333491734, 0.005568253441846797, 0.05455067354653563, 0.03979596349277666, 0.010138540478822376, 0.036554411718887944, 0.011747998401655682, 0.0786680540602122, 0.03698088115613375, 0.03396689645679934, 0.032865332173449655, 0.07376960798033647, 0.049179227490510256, 0.03138496553791421, 0.037654883560857604, 0.02204291575721332, 0.08376413024961948, 0.04753963243482368, 0.03744350972452334, 0.009086878205250417, 0.056135921339903555, 0.02939308188589556, 0.02903958549723029, 0.036976507997938564, 0.045145832135209014, 0.03404092462733388, 0.07090621055769068, 0.03688307711854577, 0.07176863535174302, 0.01175426212804658, 0.07938773544239146, 0.06760986029569592, 0.0380431548692286, 0.016929944045841694, 0.07377585728785821, 0.05733516413186278, 0.0511829651493047, 0.0903068430987852, 0.017862475078020777, 0.05282720477719392, 0.07892359034823519, 0.041480586132300754, 0.039669783120708804, 0.021185959955411296, 0.04710484415824924, 0.04192065341132028, 0.04097683834178107, 0.07567420149488108, 0.05833738071045705, 0.012379099581656712, 0.03218545365546431, 0.04901322389819792, 0.024396299118442193, 0.03710470022633672, 0.030053042008408477, 0.01722881497283067, 0.13129089426781448, 0.18916636226432665, 0.06806055682578258, 0.08476008394999163, 0.10557592340878078, 0.23816185604248727, 0.10128835562084403, 0.09792845376900264, 0.0871577010090862, 0.0627410186986838, 0.09361896929996354, 0.10165747188563858, 0.15716088323720864, 0.11492632595556122, 0.16546617900686605, 0.09470404178968497, 0.12407111882099084, 0.07214424519666604, 0.11537246273032256, 0.07965952942946128, 0.06059351643281324, 0.14081344114882605, 0.1193054009761129, 0.17764525833938802, 0.13179557504398481, 0.11357786652765103, 0.23227890314800398, 0.10467826907656022, 0.18373022467962333, 0.084123529892947, 0.12946954342935765, 0.2187282738408872, 0.1192885868783508, 0.14656516537070274, 0.12513126193412713, 0.19657201559415885, 0.20327983636941227, 0.12623321637511253, 0.11237468144723348, 0.1260285023599863, 0.1602781681077821, 0.1719533944768565, 0.13049955958766596, 0.10504959058016539, 0.10550190880894661, 0.13541038893163204, 0.11223962583712169, 0.16460876858660153, 0.09425885496394974, 0.0941407491586038, 0.2037621797727687, 0.08859133015253715, 0.1296938806772232, 0.07684667608035461, 0.12705337522285326, 0.193170980949487, 0.09341095760464668, 0.08063443497355495, 0.12019135057926178, 0.07384360222412006, 0.1621061957308224, 0.14440472344202654, 0.0839945539566023, 0.1708276913102184, 0.05821881350129843, 0.1290795893541404, 0.07254820423466818, 0.15914691452469143, 0.10424145537295512, 0.11171269589768988, 0.10152538147355829, 0.07006709344152894, 0.07882216293364763, 0.12431163234370095, 0.22974245782409394, 0.12479331078273909, 0.12562143563159875, 0.12084978739065783, 0.13481782429984637, 0.12446802109479904, 0.14378326678914682, 0.1387455513966935, 0.12241678259202413, 0.08922601145293031, 0.16348126051681383, 0.07751260391835656, 0.11418335725154195, 0.12864320991294725, 0.13378905664597238, 0.16721363738179207, 0.12431735917925835, 0.15343388036957809, 0.07913244342697517, 0.1513990895556552, 0.16461558107818874, 0.11014662350394896, 0.1281937211751938, 0.14338318897145136, 0.10960823989340238, 0.0694279270246625, 0.11210273818245955, 0.17234579127814087, 0.15463882285569394, 0.20208269703601087, 0.11800984692360673, 0.11100501779999052, 0.1286702970308917, 0.08650815979178463, 0.1552880723029375, 0.16947926580905914, 0.2893938826663153, 0.11991183486367975, 0.10159290927861418, 0.11413596836583954, 0.2293307770575796, 0.2113159437264715, 0.11197115667164326, 0.10895228652017457, 0.13434157414095743, 0.13364792136209352, 0.11004058205123458, 0.08583917176084858, 0.1435009419385876, 0.10680852298225675, 0.09378090168216399, 0.1024932913216097, 0.06759283585207802, 0.11009103791522128, 0.11845218390226364, 0.11142340927783932, 0.08512202809963908, 0.13043439308447496, 0.17759367610727037, 0.11983833595045976, 0.1167595104447433, 0.06771357437329632, 0.19297545429851326, 0.1536541599780321, 0.2602630443871021, 0.129772902865495, 0.12184830595340047, 0.05557957351473825, 0.07770401864711728, 0.1908135467341968, 0.1669320860611541, 0.10823962119008813, 0.17330950099442685, 0.1723057305706399, 0.1610340696892568, 0.1611351306949343, 0.1379786575479167, 0.18435484330568994, 0.09916373355580227, 0.10656008417052881, 0.18343545549682208, 0.15670850394027575, 0.0979436868801713, 0.17097330492522034, 0.1327950299850532, 0.10791306264166321, 0.11806334262447697, 0.0979738070496491, 0.17192034982144833, 0.15980236578200543, 0.0923110998368689, 0.11544759012758732, 0.12089154443570546, 0.0885266929066607, 0.11492996290326118, 0.12750795297324657, 0.08091181330382824, 0.19983806248222077, 0.06366369740239211, 0.14058605049337658, 0.10542300197162799, 0.1839367707392999], [0.018240548005061488, 0.01885600640837635, 0.010149812641819673, 0.025571672744782906, 0.013530495476775935, 0.02528200953799699, 0.049148564493017535, 0.0016637109323970176, 0.04336345634822335, 0.03391434391960502, 0.04867178846948913, 0.02670655818656087, 0.03870070619242532, 0.060961804884885035, 0.05592668828155313, 0.014446672118668045, 0.011091844012428607, 0.026110643288120627, 0.03661957143672875, 0.03825254399063332, 0.028776113742164204, 0.03663198184221983, 0.05133103845374925, 0.06860989877688033, 0.023064702982082963, 0.0616322856928621, 0.009113163803704083, 0.03753151571644204, 0.010992734643098499, 0.02501524179907782, 0.03563838605103748, 0.03978296954716955, 0.07656671931701046, 0.018181732589645044, 0.03673455598098891, 0.05053884203412703, 0.03421851759776473, 0.02675440508340086, 0.031928231207919974, 0.04989654757082462, 0.006072540243621916, 0.027658882085233927, 0.061610620069716654, 0.013603218315568353, 0.045421283426029344, 0.017884186502279978, 0.001380591347697191, 0.023272456834092736, 0.07411051075905561, 0.04255170454936368, 0.02625901175529829, 0.02000023188468601, 0.051305359295968495, 0.03433258951242481, 0.019464689639530013, 0.027571966838357703, 0.06130367796868086, 0.03125085309147835, 0.025991433167031834, 0.011746073058540267, 0.028990564734808037, 0.011580380744167736, 0.016327535567272986, 0.016425473615527153, 0.055740311675305874, 0.02112361106888524, 0.017170642469344393, 0.04061097565240093, 0.0347290982359222, 0.044131452816405466, 0.05803541227110794, 0.023100209023271288, 0.032210973357515674, 0.007891006884165108, 0.046982748566993644, 0.04129214338692171, 0.03245310179357018, 0.07731624945466008, 0.00881357362959534, 0.048630608179207356, 0.07452731446496078, 0.01484181359410286, 0.03557931279231395, 0.004798010598668563, 0.0734648507620607, 0.006925014745710152, 0.022606070984953215, 0.02304576337337494, 0.030065635618354594, 0.026845724022548114, 0.02419371739961207, 0.03997826549623694, 0.09825109038501978, 0.02558189826751394, 0.060822040241743834, 0.041760376654565334, 0.025002858534987484, 0.017513901460915804, 0.05322119274309703, 0.022533695047189082, 0.06890722603670188, 0.02721324742638639, 0.022764076345733235, 0.03444291591378195, 0.019438011338934302, 0.018569757929071784, 0.04507290319140468, 0.05978384095111063, 0.01739654882944056, 0.01326652499847114, 0.0077130771907312524, 0.04830259078049234, 0.013056953520780163, 0.021537398686632514, 0.01971040413315807, 0.02443521310176168, 0.025502950718094195, 0.012784721878623324, 0.011747554809387242, 0.0303729746623763, 0.042117414996027946, 0.12370377353259496, 0.03365560833896909, 0.017682252784392664, 0.025933221647781984, 0.013893945974164774, 0.039669206365942955, 0.02598558080249599, 0.0342831921630672, 0.057414193105484755, 0.0344045854705785, 0.02267391430879278, 0.006284802960830608, 0.018348647115219916, 0.050513939798942635, 0.0691470881657941, 0.036106683779507875, 0.017393900846530284, 0.018023939271058356, 0.048672979298446856, 0.03402616649067827, 0.013487238021168326, 0.0823287640565208, 0.024605684847171818, 0.010227666053521847, 0.08007192944309541, 0.030228226179523126, 0.00979415511912001, 0.04317523751940046, 0.060665332579186985, 0.014644775506375092, 0.03617151780053973, 0.05543813628277608, 0.04952464931245361, 0.07660226098128728, 0.05282118617157851, 0.023565353260242512, 0.05877587039555822, 0.0320102491282991, 0.024177659868395755, 0.019591239813183035, 0.08109315178756203, 0.043418349831232, 0.011978349166123994, 0.02261602339733924, 0.041753713440682204, 0.0241645590535232, 0.008222195585923535, 0.02712017108154084, 0.014157511027795928, 0.025007053577740277, 0.010928909942906882, 0.04681471276230045, 0.04661188507452607, 0.0424245810136199, 0.0532927510461637, 0.04839892918244004, 0.04508814987327371, 0.04890455312228628, 0.0554497222682195, 0.03470793133601546, 0.05328485289854663, 0.035423670429736376, 0.015575917238103492, 0.08789089880883694, 0.02370575742263879, 0.05124889500439167, 0.04880732244678906, 0.06897949001618794, 0.015402173257565923, 0.06590949903641428, 0.03611848350348217, 0.05369337847722428, 0.02181546064093709, 0.012802042333143098, 0.023880536169079796, 0.018540954117530158, 0.03822822190288987, 0.028260934332917844, 0.0414006377437285, 0.033852006907441785, 0.01911612450411277, 0.03576327720656991, 0.02499715714449329, 0.03994194012401359, 0.03755009061257754, 0.043253917047487836, 0.03270065850977387, 0.02291170012072793, 0.048655937891453505, 0.03264903217288, 0.017197861901617477, 0.04451094388163515, 0.05387624705742512, 0.01912087933825595, 0.09267854690551758, 0.027349700818636587, 0.01905841679711427, 0.04266737780666777, 0.014793985356975878, 0.04760834428348711, 0.012836634048393794, 0.01184541397794549, 0.07638076000979968, 0.013752203401444214, 0.06523101830056735, 0.02487794871974204, 0.048148454765656164, 0.07485835134450879, 0.04712387028017214, 0.017000976484268904, 0.0281259855920715, 0.044183292891830206, 0.016305327116112624, 0.04841196044747319, 0.03247494722849556, 0.01818370203753667, 0.04612881903137479, 0.05175236120287861, 0.05854267826569932, 0.017271862930751274, 0.06310450312282358, 0.015684555783601742, 0.052147726594869576, 0.03464664266045604, 0.08026252314448357, 0.03700833468298827, 0.008598791851129915, 0.006042629995915506, 0.08072535866605383, 0.0632532379989113, 0.011808496583918375, 0.01989649745103504, 0.00900470931082964, 0.02936114663524287, 0.021105624801878418, 0.0514017960854939, 0.046788979321718216, 0.012479143632975007, 0.034856883343309164, 0.04954855749383569, 0.013739868482973958, 0.0537482414261571, 0.03569181729108095, 0.004411912298694785, 0.04085268000406878, 0.032348810961203914, 0.014292899120066847, 0.07372749131172895, 0.05835759426866259, 0.015305656740175826, 0.033014036515461545, 0.007638118579052389, 0.0692515147051641, 0.058988604694604874, 0.021505592357633368, 0.03578974346497229, 0.04002001575593438, 0.03064480936154723, 0.04971471714920231, 0.04764392326718994, 0.017675362261278287, 0.059387691851173124, 0.032875788398087025, 0.009609613101929426, 0.03172077251864331, 0.07930357674402849, 0.0775775465049914, 0.01503760487373386, 0.02481556081745241, 0.049952296007956774, 0.039586591334747415, 0.05305017477699688, 0.04514677869156003, 0.01772803863111351, 0.029932205099612474, 0.06032474192657641, 0.04409864904092891, 0.05654845706054142, 0.004454941172817988, 0.015824574877374938, 0.06865173724613019, 0.019218332233971784, 0.0771803863878761, 0.0713780638096588, 0.052937093523464034, 0.01883869189103799, 0.048223884111004214, 0.02534040595803942, 0.008845828639875566, 0.03404576936736703, 0.017728513605626564, 0.02959725646568196, 0.02001949379752789, 0.04091885413176247, 0.012879897441182817, 0.030972026088940244, 0.058479404875210354, 0.0318085308452802, 0.015007438903142298, 0.06079533988876002, 0.0735670652772699, 0.05990727325635297, 0.03455264520432268, 0.026205565248216902, 0.06358633083956582, 0.050978888957096, 0.016805948556533883, 0.020899428187736442, 0.008750649684640979, 0.05353120182241712, 0.04319396508591516, 0.014753936523837703, 0.07483411407364265, 0.03480054797338588, 0.07296312161322151, 0.021494053869641254, 0.028205328388139606, 0.01602335340742554, 0.03689294980306711, 0.03464455955794879, 0.07179551890918187, 0.020582335202821662, 0.047081621297236, 0.04939833662605711, 0.022372651545863067, 0.1275521256029606, 0.03048088208639196, 0.015552612952888012, 0.11298215349337884, 0.028617421364677802, 0.04428199938099299, 0.09575465827115945, 0.20038896506386145, 0.14843930623361043, 0.11228750326803752, 0.15118708807442868, 0.11460035773260252, 0.0904116699738162, 0.09680836208696876, 0.1349743894700493, 0.1070100614534957, 0.14458020616854939, 0.07644053894494261, 0.1760460598660367, 0.1311885711870023, 0.20174454232411726, 0.14315787463315896, 0.15029987639614514, 0.09281749052128621, 0.09277704304882459, 0.12663522123226098, 0.06799202478889908, 0.09647624633674111, 0.10850870782243353, 0.18541508141372884, 0.06699274626693555, 0.11722851384963308, 0.09643018737967525, 0.1382442768663168, 0.12016467058232852, 0.08593167643994093, 0.1490836702287197, 0.10304069266255413, 0.13896542388413632, 0.1025018272921443, 0.14587003338549817, 0.09185926336795092, 0.14544898883572646, 0.19175054931214877, 0.12153940967151097, 0.22634932132703917, 0.10421193231429372, 0.09603000778172698, 0.13002614570515497, 0.1006530432828835, 0.1594490118856941, 0.08888071176729032, 0.07542664477867739, 0.11064716521650553, 0.08668813442013093, 0.0683799364737102, 0.1263924278318882, 0.1502225369747196, 0.16688069381884166, 0.14092473446258477, 0.08108642072017704, 0.08523420350892202, 0.14822338281997613, 0.11799205573541777, 0.2176550892846925, 0.11716653646102973, 0.1145020244377, 0.07382819947919675, 0.12513316183217935, 0.11185601606432881, 0.1505855939217976, 0.1317322270146438, 0.07281691088740315, 0.1667588289294924, 0.11523119173943996, 0.1496913390500205, 0.16486711400960172, 0.14653037009494646, 0.13740343627120766, 0.10633447127682821, 0.19513494627816336, 0.12237836393926825, 0.18311072220759733, 0.20058902432875975, 0.07633854834628956, 0.10605348992560591, 0.10381490111883197, 0.0830650424052562, 0.08059371608708586, 0.07208017113485507, 0.18391380911426886, 0.14925862369792803, 0.1600303128361702, 0.05214186405230846, 0.13516995683312416, 0.16069721776459897, 0.14778659625777177, 0.0685840058805687, 0.17031233039285454, 0.1496516718928303, 0.11593248482261385, 0.06944627461156674, 0.14747414445238455, 0.09774375653692655, 0.14977982001645224, 0.10254859192562954, 0.13031906927270548, 0.10786379421395914, 0.10060691647231579, 0.17284049758953707, 0.12401921089206423, 0.04142188946051257, 0.11942618020943233, 0.1352315949542182, 0.07769555731543473, 0.14320508709975652, 0.09565168379672936, 0.20164276207131998, 0.09164963675928967, 0.1439535112253257, 0.11552161829812185, 0.10396068436758858, 0.13739872723817825, 0.12261681471552167, 0.08083535597792693, 0.08667538474713053, 0.2051131972776992, 0.14320693271500723, 0.11684770642646722, 0.08402324920254094, 0.1118222318057503, 0.1522437570882695, 0.11493921812091555, 0.20112422561006887, 0.10641757146056209, 0.14282888014401707, 0.11355681837137256, 0.1705963108688593, 0.12382014228829316, 0.08415360256497349, 0.1581599853400673, 0.12289958739919321, 0.11476178121353899, 0.07663002663425036, 0.11602230928838253, 0.057285149315638204, 0.15268601264272416, 0.08136010103459869, 0.19545739968972548, 0.11351680516132287, 0.28766910093171255, 0.20732782701296465, 0.16127284616231918, 0.0952827235949891, 0.1260896519358669, 0.21245031857064792, 0.16487216231014046, 0.10924411764634506, 0.14854332565196923, 0.12676450929471425, 0.20299434954566614, 0.2313596239047391, 0.061628804808216434, 0.20600758785648005, 0.1457217734839235, 0.1868799299533878, 0.07430381181516818, 0.16234900270189556, 0.13364007749727794, 0.07574052150760378, 0.10426150608275618, 0.131591458139675, 0.15181087888777256, 0.10415973940065928, 0.17321506249053137, 0.15717156337840216, 0.18623912148177624, 0.11416297405958176, 0.09662308131477662, 0.26102085943732944, 0.13246774540415832, 0.17377193618033612], [0.029607576983315603, 0.03531499286847455, 0.03709683261279549, 0.03966639044561556, 0.03680420420797808, 0.055694123796586475, 0.045120132621377707, 0.05890253931283951, 0.029255471591438566, 0.0244913058954158, 0.04887458901586277, 0.02311748791752117, 0.0619321981711047, 0.011673502041958272, 0.029403955409569398, 0.05115127417125872, 0.03068295999297074, 0.0184484850615263, 0.05623924865254334, 0.035965643490531614, 0.06896930520555802, 0.008264783836369003, 0.03474949839125786, 0.0523273449923311, 0.043541096816105504, 0.013324898517956691, 0.016462226464812244, 0.027610122558793852, 0.06651929845767361, 0.0958938936569861, 0.0729372219315597, 0.04186084054942642, 0.055665669430579455, 0.032555557188711, 0.021918996603095105, 0.05124207233477916, 0.04207554260002715, 0.02724524713786585, 0.01191335144851889, 0.08290067408233881, 0.01745511488323765, 0.04053172954757299, 0.06133175574775253, 0.043961154097425084, 0.01349352888895997, 0.008954445132985711, 0.04527700991768922, 0.05393640936485358, 0.037867831598435125, 0.036754644010216, 0.040905107012284656, 0.051145917137286494, 0.014152624727492886, 0.032509922316031795, 0.03162552995075073, 0.03657722067353981, 0.023128804185294678, 0.04293770955077239, 0.048087712310786755, 0.011678225493856838, 0.030099060253373215, 0.038287427475942035, 0.07495232844459158, 0.048764554384563646, 0.028082315078271285, 0.07174089005483048, 0.009752830640146775, 0.06233529546963317, 0.018908121290483644, 0.046073525212705135, 0.02954233923394765, 0.006566478962278259, 0.015372782513233168, 0.035689710439848046, 0.03985638025083712, 0.04224409069865942, 0.027831867802888155, 0.060756113779331954, 0.021825738750132065, 0.016178709088957736, 0.09784751811197825, 0.008960501058027148, 0.006865508072743458, 0.051624291110783815, 0.0835461848016296, 0.04791097768715449, 0.0459434161228793, 0.061544286486293585, 0.013188239868863352, 0.022815417697919265, 0.05056354749415602, 0.0620441021663802, 0.03088027119104351, 0.054591273689376454, 0.024199842874492918, 0.06128535073782716, 0.04279521380418113, 0.01439292196716581, 0.02398010270137872, 0.023151964281818697, 0.02459605982793229, 0.012227968628784376, 0.023175170179456472, 0.009182880732363887, 0.005723162138435457, 0.011347240352604007, 0.03405638165505869, 0.004518532626596945, 0.04304173236180629, 0.07893507794610091, 0.008804979983584156, 0.04619822298575725, 0.01802161698495703, 0.012376203085295856, 0.06791040381150586, 0.016484546874250685, 0.033190523473812, 0.028040887122707706, 0.03581640989120517, 0.07887644573513951, 0.0215874321625701, 0.012404232518747449, 0.030812441437904323, 0.03531889444483178, 0.0336202634498477, 0.03752246066661818, 0.03604754605995757, 0.013589173488851105, 0.022631227670769607, 0.026229961974812404, 0.009908517107500561, 0.04566069432933416, 0.01812307154094534, 0.14350213616022042, 0.008130855442556952, 0.059486228706581254, 0.04307154040517552, 0.03484404206808124, 0.005687667547525572, 0.053603126534393856, 0.07342109203870807, 0.02631845820828208, 0.02240203380850809, 0.06045238793428455, 0.013036680590760494, 0.036236623235579045, 0.07390148804656096, 0.01572538323567382, 0.057310628305588446, 0.02903532768998827, 0.03862141598282116, 0.04491336264514497, 0.054051264987460206, 0.10060983417289597, 0.03117095898570759, 0.049885216036013195, 0.019823001930490136, 0.02289981727621385, 0.0679419149777719, 0.03127747880561011, 0.03582758197028722, 0.07005078145968062, 0.02531688114894288, 0.10061047199581351, 0.03522141949672784, 0.05712728814354964, 0.024651874422228763, 0.0417699304276279, 0.04141410327117358, 0.007109728517077331, 0.04471136616276843, 0.034845992856259854, 0.05865353053169591, 0.03183932615710156, 0.01669627694146974, 0.039389453163104396, 0.04960846874330725, 0.025648781464302113, 0.06815729556339127, 0.015607771064553942, 0.010047314838240189, 0.025974132220393846, 0.062253884838095734, 0.005065749490833176, 0.0590123873470085, 0.04583905404433608, 0.007216962919171367, 0.04090228769928217, 0.08330996640558753, 0.09001701365091971, 0.014457274228334427, 0.02203784031527383, 0.02668475855274924, 0.08020403342587606, 0.009483048509407257, 0.029601005371659994, 0.02929555604766522, 0.029661900496908596, 0.04317703902987497, 0.0616867042013577, 0.059398561982171874, 0.01878181199676224, 0.012692519995783056, 0.00716121108936412, 0.014941319058250104, 0.028088428678789308, 0.093217615836433, 0.015787325001188686, 0.10260512746338334, 0.03607032108785851, 0.0393712786026299, 0.0006213308588485233, 0.05359785770997405, 0.032841179719460864, 0.019025411157469665, 0.0927903830472912, 0.022806837622608458, 0.032120897833790095, 0.012483855210510748, 0.02174537645519844, 0.03717450451638017, 0.02971809676715306, 0.050089390615799596, 0.039961027314088175, 0.012566264136694372, 0.01771479532388704, 0.06973168001111064, 0.05963217480374234, 0.06088135777307408, 0.02495378179342619, 0.03147305973938533, 0.025375192752107978, 0.05117965729108878, 0.029132649967713014, 0.015953754374225224, 0.010718341866907264, 0.04153595458982246, 0.031904116073357205, 0.0649831901703562, 0.024540864396840334, 0.01848372138504471, 0.02568529173731804, 0.03469834702887705, 0.05454025464132428, 0.06627339736691543, 0.038862553757748435, 0.04849044320040515, 0.0337795054406992, 0.07580405274139983, 0.04909594749499645, 0.017578221491671035, 0.0605258597061038, 0.026512354678873504, 0.049586375643100054, 0.07147649209946394, 0.07008499319532088, 0.08877913507499866, 0.022752317333860055, 0.01663050314943705, 0.05204441624560526, 0.09704305377921887, 0.08094261879367487, 0.04218170618904488, 0.0863610737557922, 0.052248377086860795, 0.02914771344512701, 0.03618834207632712, 0.042424591191645177, 0.06389211943106991, 0.007338731965449239, 0.03982545941003731, 0.014556377660483122, 0.045576555987021754, 0.033062904607504606, 0.09093860669859818, 0.014506276331043668, 0.039008849300444126, 0.05673220773626651, 0.025134048191830516, 0.033415892094905884, 0.021266166187290634, 0.014873345116419452, 0.029400159006140063, 0.05663973359125001, 0.09742918770228114, 0.06861597845064742, 0.04007198814568775, 0.05594652186014822, 0.0342672805168799, 0.03323511000988739, 0.025596113576154624, 0.05298811935686639, 0.024953413688178574, 0.04793714878282376, 0.0583980010290231, 0.044176707709474225, 0.055965218892587085, 0.04351717506402305, 0.04701607481443456, 0.007707009391326989, 0.056012811338795085, 0.01419117399823985, 0.0716291285519089, 0.004471993181921009, 0.05953452004385846, 0.03320132914398398, 0.03565296098323805, 0.0440239491207259, 0.04136724364278572, 0.07075465297592537, 0.026301766246823326, 0.01326831802725792, 0.06553131754377059, 0.024182796378486922, 0.021436013680483614, 0.003601220286717372, 0.056957579750035486, 0.05110645014792681, 0.022179328437362398, 0.022341588212709342, 0.03672510738085423, 0.03451181435957551, 0.004624336592054793, 0.02189843020667987, 0.014890096449692334, 0.03952941458140101, 0.0905616737103888, 0.029737747141293118, 0.025080908721845065, 0.06337789166718721, 0.01605515125473695, 0.03634075461221593, 0.0332478562902127, 0.048030521986739974, 0.02983352235917534, 0.02762666015353586, 0.016892556766314164, 0.03814012770141874, 0.0174012476844447, 0.02890508289315871, 0.06175522266754082, 0.04361167802874531, 0.06043942113007818, 0.013195657952954727, 0.023065800512475625, 0.07686741211052452, 0.029567424673587084, 0.031242551215525185, 0.0408083411332752, 0.06906879200999226, 0.04503507825679012, 0.01799416515444006, 0.09510608735893454, 0.16087039347205842, 0.10301771746682269, 0.11184158362448215, 0.10757635320935931, 0.1375663796705859, 0.084727968887559, 0.09408920763858727, 0.11453797322298799, 0.11047752467649323, 0.18556773822222436, 0.06067711873246091, 0.15699074736663274, 0.15583828277885914, 0.10794566624930926, 0.21283911913633347, 0.13180223825786794, 0.14510430661695345, 0.10255535691976547, 0.09252045503152267, 0.23907144580568584, 0.14411156917256968, 0.07747778150119952, 0.22576130287987844, 0.11241795841072287, 0.08076524973980018, 0.06551385205239058, 0.14971014804073743, 0.1617821952594178, 0.14669756112354143, 0.17003570523645195, 0.1412150931677648, 0.2084034542952265, 0.11295263043471745, 0.15379832152809414, 0.22284254378506116, 0.10737992410681077, 0.12387909341071333, 0.10785198770463467, 0.14941109051661833, 0.13517936132848263, 0.10242701202098813, 0.12216235910143171, 0.12916550545820168, 0.13063058469976696, 0.12519323932273047, 0.10953178935285125, 0.13350662322981016, 0.11040834124599185, 0.059459609777799675, 0.10114788530128342, 0.1441032231918403, 0.11528307252696582, 0.08146222734025546, 0.11428414684321199, 0.10463060877685036, 0.17961841103221687, 0.0952735837282879, 0.26288066964064327, 0.1370259943817343, 0.08493087121418544, 0.17608899756201676, 0.17949768608169897, 0.10574934338884694, 0.14623119043452398, 0.16201170294412545, 0.08340851683169603, 0.21826121104615076, 0.11554505489766598, 0.12194716850561754, 0.09049659541675023, 0.07145490111517054, 0.18319946101733617, 0.11530615628830024, 0.10847634170204401, 0.14431670387940748, 0.10245562584272452, 0.17412519508174487, 0.15495787002146244, 0.17782091748501572, 0.18026768762086118, 0.0847640669505511, 0.0898928146011063, 0.17914153662111076, 0.16314288867371424, 0.14228295800941332, 0.1713453863880464, 0.2694008212004389, 0.13360414228269032, 0.10429564317954437, 0.1541055350431374, 0.15545657968946866, 0.1414546160293477, 0.18313935638538428, 0.09873986630035297, 0.07566153324608292, 0.08579404918210846, 0.0975580754290734, 0.16654086991080216, 0.05245985609612294, 0.09359712725771324, 0.16803747388933385, 0.11942243469612938, 0.061189195540334494, 0.13478103413113526, 0.0814727514183947, 0.13723924436739512, 0.11823773969496999, 0.29045421576925684, 0.11167552574936833, 0.14747892133891582, 0.15281854410256657, 0.11433282494544983, 0.10271030717662402, 0.2038051038980484, 0.10560390619294983, 0.0714548739737698, 0.16205207577773503, 0.14573363427604946, 0.16459954051034792, 0.12152674820806299, 0.11324182884501559, 0.10471052663134676, 0.0787431136039751, 0.17826801777950355, 0.11008582676627807, 0.13877699470945767, 0.14744221259440693, 0.18442271037825517, 0.10307837849748985, 0.1548369550811393, 0.08233551547995635, 0.12104447265820843, 0.18397905704166206, 0.18868686870804854, 0.09272535903645412, 0.17295177733259542, 0.1148684062063694, 0.056753947998264005, 0.1887147022145135, 0.19264202219034943, 0.15258064972502844, 0.10310566239058971, 0.1261744959545987, 0.0795867226219603, 0.07264509903533117, 0.17155521655721323, 0.09524540416896343, 0.11956016373421464, 0.16869653495294706, 0.19635876560849802, 0.1334207614085504, 0.1326999943703413, 0.1329045183956623, 0.05101755866780877, 0.15500111984355108, 0.10995075758546591, 0.10402667868350234, 0.12055402754672936, 0.21359920049352304, 0.09181844270122902, 0.08717292054955449, 0.09250450945858445, 0.19052656713340962, 0.14321329737348215, 0.17666337745530264, 0.13753363357058593, 0.0578393902895706, 0.16093272369887146, 0.12491095518427235, 0.22880556381174497, 0.08467637308474098, 0.1101786367861288, 0.132002216098564, 0.18653417564928532, 0.09386314012642417], [0.055908401762800555, 0.02336823205197496, 0.03252289929826345, 0.04474871612286993, 0.019596679967695048, 0.009327872639655002, 0.08105176115142447, 0.024840576707252433, 0.06915512880576508, 0.01754232868552208, 0.04132503876462579, 0.045608755866331716, 0.033355770499578545, 0.016134999559393952, 0.04709838450487171, 0.11254745003368173, 0.019040199828201106, 0.013289582466573586, 0.05459612860743489, 0.03843302752024361, 0.0760268700708236, 0.06524209877742188, 0.030052852018603256, 0.10614708704607827, 0.01044731801708362, 0.02773198575180556, 0.031100845962230648, 0.0838273832840579, 0.056741880252957344, 0.0642350171027439, 0.030767949896731546, 0.042940844382558546, 0.02009426835658295, 0.045517089177987406, 0.044266525389892716, 0.04816221884850945, 0.040748392564377615, 0.03548972920647689, 0.023762599997488514, 0.03694838272141559, 0.09823011686759335, 0.018730216193944216, 0.027386567322537303, 0.018036062995504056, 0.04415747802704573, 0.018919842982930795, 0.020218117960861752, 0.05480694943772895, 0.05678867881319352, 0.025626099734966244, 0.012606699734793177, 0.05067346677450197, 0.04082345550081559, 0.0085098647479234, 0.02730020847437637, 0.010633097512514463, 0.022095622661124383, 0.01128594743620072, 0.025657234314296926, 0.007027289904986641, 0.048135270830243826, 0.07166153538439955, 0.02375990790980203, 0.056818585244140456, 0.019161722057365944, 0.06308800115117005, 0.006822496586080108, 0.02519499759988061, 0.03713725294385638, 0.02720668938543115, 0.026638151678655828, 0.03417721177850451, 0.019723340403288603, 0.028202441221635257, 0.026657410198822618, 0.019444791600108147, 0.0415179123436766, 0.020303304639777968, 0.08394708364669766, 0.02107156064760472, 0.054954313673079014, 0.04419866171000259, 0.0251259736251086, 0.04755697239722524, 0.09679020448986973, 0.02764512987674347, 0.025104989929656898, 0.0905408358999661, 0.04443279021818723, 0.050195028340177875, 0.09383558481931686, 0.011390134791976638, 0.020184649221066917, 0.003695360659289041, 0.020360725665731088, 0.054754780272820165, 0.05045761460704463, 0.039317579341254065, 0.035432722086885145, 0.006800487030497087, 0.01932652633903282, 0.04661164419459445, 0.049447679692613225, 0.02799945747080658, 0.006354341774048018, 0.05756767772670303, 0.09392283085201468, 0.013746203455541815, 0.03295008458995393, 0.005321022846536445, 0.015198015641154987, 0.053805068733968904, 0.020748304868383066, 0.07181993259915284, 0.007964264069284712, 0.03583942919171282, 0.029595085153622285, 0.03586558332400663, 0.00932831792826099, 0.021486500078546147, 0.04775882299457278, 0.07054056160684143, 0.042766956213329516, 0.030613932625523636, 0.0036732030982550767, 0.016035524629322544, 0.03253640553780964, 0.04219438461586833, 0.0667485279430236, 0.021709975586938005, 0.03663757975612368, 0.013427959505601652, 0.04356265048097287, 0.047108070592262914, 0.009992216946557164, 0.050454055690871816, 0.04377365451572197, 0.06876550042735678, 0.025997982726299336, 0.040007568031017265, 0.03119461950180786, 0.021028770532991205, 0.04605055680232389, 0.01693384731853647, 0.017861647265298024, 0.006682667482112135, 0.017228304375229136, 0.0393016473390162, 0.027316645985203128, 0.03631197454939995, 0.020665260663788234, 0.01620436449801283, 0.07006220798939466, 0.06379823732588973, 0.05722514646393912, 0.0419873092988772, 0.08375604889754738, 0.012024573516100645, 0.01918424093829734, 0.031641404277512004, 0.028088345558249524, 0.0357441018069429, 0.020665657606774142, 0.019581180531531572, 0.056796807662716935, 0.06290886790624686, 0.04033657609085951, 0.015880584550489272, 0.06688777011420045, 0.018649068494726504, 0.05712109311882939, 0.042208647421960316, 0.011592042216631984, 0.07865263095923833, 0.03172571564625416, 0.021749920943485837, 0.0573925817651408, 0.04531073310811605, 0.03122174393917833, 0.04002599704212376, 0.024852554546669126, 0.0357466123865119, 0.011859584333641189, 0.030414975980030637, 0.05307675977902753, 0.01659952463316066, 0.04304033797234297, 0.01662075938656926, 0.03899550251662731, 0.012465139518358877, 0.026995312156421796, 0.07830085804952042, 0.03121647172208343, 0.020673599859167422, 0.05326998958896313, 0.03777091304904648, 0.045033252997589965, 0.047734025932316265, 0.03781312810523169, 0.055118715922747336, 0.03286712011322379, 0.022197502997836897, 0.0711430124938488, 0.025046873405309658, 0.07049085213137524, 0.02268292016482779, 0.028757677945707525, 0.04615148549367275, 0.08821681953434433, 0.045714865172547955, 0.08621434734335967, 0.011044332142254072, 0.037372100699160776, 0.04542427576546158, 0.022930680441537073, 0.025506893006552542, 0.01808788950022842, 0.03814000217244029, 0.027198691153898835, 0.01916920969129673, 0.05551921782482948, 0.006295437300910375, 0.08168326690793037, 0.057895376213959286, 0.02912436505513532, 0.047894180552767854, 0.009734830802439578, 0.01549807739710169, 0.06838220278067247, 0.00830284456190254, 0.0690381493685501, 0.03588193941063114, 0.011000555607357194, 0.017917906300031712, 0.016094976171318973, 0.03628764567630632, 0.026391566963866353, 0.004092717127475355, 0.014943556527474096, 0.0266679614183626, 0.05428414838388562, 0.02399884892760643, 0.03534579835832119, 0.033880030403711965, 0.048400751048965115, 0.038959889606173546, 0.03479003068059683, 0.052764389397842545, 0.09237886512918131, 0.07349760364741087, 0.028741220078830208, 0.012104140228724905, 0.024554236625720347, 0.024644245992281606, 0.06310142257383891, 0.055031293470944674, 0.016028550985668386, 0.05838466781590666, 0.007033454395631062, 0.031126304596130337, 0.04303377653871264, 0.007408142705181879, 0.017719407665676305, 0.05196365361501064, 0.06817134802362748, 0.013168419012799859, 0.10021783092192241, 0.03468036924355796, 0.03085912125451224, 0.03084474988281727, 0.012806482496671379, 0.04786420626831906, 0.06949510877685887, 0.05706091384802546, 0.050849906235401116, 0.024517137723575746, 0.01888610452546605, 0.03278988247205104, 0.054316558609051366, 0.05053912701883486, 0.02221678357039179, 0.022021051662574922, 0.07393542836819376, 0.013157893238323075, 0.04336505090551717, 0.020954515053225414, 0.043892031735075374, 0.08115141080426318, 0.05213419999927282, 0.06650766836745398, 0.0649647204471486, 0.03307316744966166, 0.06403084591563259, 0.03329411880778415, 0.040230286972863336, 0.04367335686194045, 0.0022914049124145614, 0.056390178589416404, 0.018650851345488002, 0.03284080313252551, 0.01400636141521058, 0.0300887770551656, 0.019503305067441294, 0.03318053883101259, 0.03682936428646956, 0.005289728387391993, 0.060222649547670565, 0.033633593270289044, 0.01642868647884045, 0.04340785289449351, 0.06290755154831068, 0.019483961730397174, 0.06319436151534319, 0.04964969313836523, 0.04239101388624736, 0.05138833395072392, 0.09674869850277901, 0.04730165324040821, 0.07012267903025661, 0.03104277354265962, 0.03147931922493236, 0.035001360412154875, 0.0216724763491324, 0.02462702986252095, 0.03459493150668485, 0.09664153746728386, 0.030441801861992905, 0.024887304021311656, 0.036881285786096535, 0.01712216792761215, 0.031890721792089086, 0.03136181053040283, 0.034462813953203816, 0.037616271525621414, 0.012310283408234162, 0.03951685829088092, 0.03444485652393528, 0.009630483990934278, 0.05880125439060586, 0.05108570054705654, 0.015504577762580343, 0.03972712272245969, 0.016075225713263665, 0.05154752165877393, 0.036923080150570185, 0.026356619017730867, 0.06137071044317313, 0.06112649890461138, 0.023122573537485938, 0.02880733653104731, 0.00865894737320819, 0.053401062198515446, 0.19489357780132974, 0.1428782639226743, 0.11414267229182379, 0.09651093304689441, 0.07730411046317645, 0.072821599564382, 0.12525485030242375, 0.11331816403461353, 0.24156112649611064, 0.10697525260703904, 0.15712350952838147, 0.20010943577757903, 0.22662811779550143, 0.13415128578032764, 0.1414745378174952, 0.17213787457772664, 0.2568257488310337, 0.10150340372430426, 0.10889690449195248, 0.1471224326108183, 0.16705431735941342, 0.12738683447241783, 0.11776504505957876, 0.19588893439088548, 0.12440780789724418, 0.09138700299497161, 0.10254127053277833, 0.16391331090458802, 0.18546001400266374, 0.15262828288333757, 0.10554998301501785, 0.11144673731178045, 0.13435718044638634, 0.22465195240718977, 0.16092329206211226, 0.09046555922499724, 0.08085113870246069, 0.10764451205198254, 0.14257320814899035, 0.2310857671712126, 0.19147173927298614, 0.09088558597224099, 0.20012580204222882, 0.07810205407440662, 0.19298850931227207, 0.10366143685366426, 0.16607183936451161, 0.18249500596097537, 0.13417696154543332, 0.12597259107444966, 0.11352556504841362, 0.11720514510359083, 0.1864246872386762, 0.07835146997656141, 0.13461817215595925, 0.11298788711428642, 0.1443665897739785, 0.10904108639806509, 0.06331054028123617, 0.12514008288936956, 0.1660463943013123, 0.1395965021635805, 0.10102420872343437, 0.2289001244519438, 0.14824098401835986, 0.20537599389042172, 0.15425021227981361, 0.06310046583946262, 0.12105587204652173, 0.0613911614886352, 0.13712561689317226, 0.17655892377453192, 0.11822809092700481, 0.09220910923821585, 0.14886577906353132, 0.09502785227128438, 0.07001334668270179, 0.0985956233260887, 0.17609290592372417, 0.11425815895199776, 0.10370845254510641, 0.18936384309615406, 0.10922117637736456, 0.12838315458170005, 0.25475629844835823, 0.11354625358113221, 0.06846554723701306, 0.13543966093233653, 0.10569937607007367, 0.10236401004450661, 0.22663788869976997, 0.11490520994578089, 0.11581899305539471, 0.11966544522770814, 0.1465696572725262, 0.08693791673119579, 0.1671718124832426, 0.18262698102210248, 0.20126734221620218, 0.09457427875271865, 0.11566122009285859, 0.0939976664792214, 0.17148060484656266, 0.12720137728112085, 0.10147730048213686, 0.0771375640428492, 0.15208358211176737, 0.0987712824717164, 0.1450555878026145, 0.09039474731045109, 0.13865229354373046, 0.21567490696907043, 0.11556440671639782, 0.1325358296079295, 0.14912770715142998, 0.2084522952458688, 0.15330175603074686, 0.1496090056108577, 0.08677913275148187, 0.10086091927119664, 0.09602686616459064, 0.16028536057897977, 0.10983716403799397, 0.13021590480847017, 0.13077835605612823, 0.16621243182037557, 0.10243941564112902, 0.11355470812746457, 0.12154456653765269, 0.06554097309708595, 0.13599528611770698, 0.06478743960282632, 0.09625933226197958, 0.16071329904454096, 0.1134201478479164, 0.11614916819546904, 0.11701036484113761, 0.14422183111310005, 0.1472756186766284, 0.2210635199610676, 0.12315182600702558, 0.16286861124847615, 0.13479099502520903, 0.16148191637226514, 0.06752177287957498, 0.14023558715624468, 0.10902593471109867, 0.10417928799454655, 0.10318497634891953, 0.1418290180819375, 0.1143931331379073, 0.126726769176977, 0.16456292676074163, 0.18516215070017747, 0.19388409411268576, 0.10025289082633597, 0.105121874915702, 0.08029697236738034, 0.10747983160295657, 0.08789452218583652, 0.11086946685931512, 0.16024710477462836, 0.1262006466942174, 0.10002223641744681, 0.13275985472968646, 0.15669501466410501, 0.19800790425922188, 0.11567514363144125, 0.09060252151851143, 0.11167942732572556, 0.1831057553312608, 0.1861306915857962, 0.08853054698556662, 0.1498814509915454, 0.14378028123506478, 0.11135585433138268], [0.03256922966933676, 0.08182702812233142, 0.09160321817866393, 0.005328595721428948, 0.02707123343965837, 0.019317361027268425, 0.04817828316507595, 0.046142966486513615, 0.03845738692741309, 0.05688344979924815, 0.03346984919958881, 0.10243001114577055, 0.06933629765574421, 0.030866534249590974, 0.021685935091227293, 0.014888959903536099, 0.01960596232675016, 0.0682895148971251, 0.008887812994154436, 0.03908156789839268, 0.044284160515027385, 0.04511797148734331, 0.050965688058308194, 0.05786349863878318, 0.060991531504052024, 0.027028063345434408, 0.015196449921599455, 0.006315979524515569, 0.016122663792754923, 0.05495833060038941, 0.04046172508969903, 0.03496689422588263, 0.004647242237946817, 0.08424844818988017, 0.0364253102535648, 0.024196129591603364, 0.017865760883848582, 0.023613882084776248, 0.03220008287046637, 0.004132437719298261, 0.04579442340348448, 0.021186258510819504, 0.021098568037684475, 0.05979272975985493, 0.07086738478392363, 0.015709281599681293, 0.03244153955685241, 0.03285620587744883, 0.031052045723689452, 0.036362060611801486, 0.058055904028671126, 0.02878154202231339, 0.0018394064432608762, 0.03682491309674723, 0.012079981837554701, 0.04377104554857526, 0.02727229693638427, 0.011022837849200835, 0.02159851772843727, 0.055450892741126676, 0.027398012511964356, 0.03465621678956917, 0.0441930841521493, 0.04471933216388736, 0.039354708777474504, 0.041175092703529766, 0.05944010189601353, 0.0094511980756319, 0.05027781639780317, 0.04575434233993292, 0.023958945979497263, 0.047713225441319604, 0.05108000085289989, 0.0612009409815073, 0.01133282742063914, 0.01886418614802616, 0.010827869293279946, 0.03237740442688976, 0.017203280003741384, 0.08997315993266446, 0.019630348875320384, 0.006832779784287725, 0.041286362268562825, 0.025347863057894365, 0.014105305391629892, 0.02425192722252437, 0.039972267246672084, 0.0257948802318424, 0.05780213871704681, 0.012240139850681382, 0.013771306706725486, 0.049116968509874175, 0.07075096174542393, 0.028353135367589336, 0.005992647834188704, 0.05126246909743973, 0.041664710002286096, 0.10241861175745726, 0.037015981772648435, 0.06062793851430927, 0.018192801192136746, 0.04477179649152926, 0.05006866815633007, 0.05497531433190618, 0.029635719223214046, 0.0663280805040683, 0.04262111868177142, 0.08458848244377545, 0.026656628187213625, 0.01003076452096658, 0.05553325671436531, 0.029297489872468368, 0.042232250262584, 0.07374205267322914, 0.04343653117705669, 0.013305642542296221, 0.024496411871431128, 0.03579550422728062, 0.007486136064731649, 0.04962775610121233, 0.07033555582165718, 0.016340553261605755, 0.023112505774146745, 0.029813773597457578, 0.029136856884828637, 0.054400008238319836, 0.043138080941779275, 0.046459316475582976, 0.053924687672406435, 0.030877163500658104, 0.030913264956325293, 0.025609100736411552, 0.033104732898729186, 0.014555668591388633, 0.040339609142392874, 0.017850346264562438, 0.07066611772669212, 0.017778760820095028, 0.052674626000225544, 0.022662423318251967, 0.033754559100738595, 0.027544827133949314, 0.032041933320994885, 0.05115764561508383, 0.009880783684950854, 0.033866836290274344, 0.08012779323118073, 0.035836491135082076, 0.008658027110089148, 0.03563537335555468, 0.044657246209681034, 0.025643334524439912, 0.029669761325099638, 0.02562113625130483, 0.01620921602339617, 0.030096753234309808, 0.05298370548657008, 0.03329599156443562, 0.018700482789427042, 0.05064988089725375, 0.011339804456968392, 0.06847284148846354, 0.01401167773708169, 0.032849206788731475, 0.040416202175297906, 0.03934865624510816, 0.06888321268239192, 0.04932782665959426, 0.028576305535222803, 0.04472772224939295, 0.0411569011796798, 0.04768818071378129, 0.01988594962417015, 0.049190996680408716, 0.06198468964014735, 0.05772456180836473, 0.0831657030752727, 0.03449561772868037, 0.016237415938771198, 0.05547235480376652, 0.02272433285335345, 0.01803759309197111, 0.057472560687788894, 0.046893738343247345, 0.04804057448304125, 0.05072477419993707, 0.03771886941311615, 0.07543402723968029, 0.027730969645615135, 0.037199620490095446, 0.058661354040460925, 0.037176628330988545, 0.021794768715543405, 0.034907960066837926, 0.025232311936893632, 0.03952523819836123, 0.026994701474905014, 0.010005961521528661, 0.051620660948434045, 0.013033659413589962, 0.036906764776046784, 0.06754337743456874, 0.02914918925879257, 0.027914335252717137, 0.04117922837446843, 0.019049024176118628, 0.0218408073165587, 0.04854467850444572, 0.017688468165163482, 0.04594466123463852, 0.06957548803516797, 0.02330120636283287, 0.034581055465553484, 0.017787909168483954, 0.023710293429238454, 0.014342693412410361, 0.03303971567324229, 0.02232895389066211, 0.044728414355111976, 0.04446073229025517, 0.0114508373829137, 0.02412471717356571, 0.04510221929688539, 0.05151237354480794, 0.05480874416285327, 0.020659145366932665, 0.02479891974612006, 0.062232056366545815, 0.049822302269084115, 0.13446315404559883, 0.05625482442389641, 0.016881001314946582, 0.04320807861430304, 0.026344958393435394, 0.011356999382509716, 0.09554822756243603, 0.01237906311039946, 0.04870306893384882, 0.0900961851168956, 0.0317055665488754, 0.0693879613120641, 0.03364279420514192, 0.0753019368276, 0.02561203540036721, 0.02833288618629532, 0.037785053718835115, 0.02706056347649012, 0.03276132632579122, 0.039270621325288496, 0.07355483807623386, 0.02583779757177191, 0.0826011144423059, 0.06404532585293055, 0.05805975810757705, 0.01918703310989908, 0.0639322412067226, 0.03479906198169504, 0.016117688434730684, 0.026412735560110638, 0.034124425146728754, 0.02557797124609351, 0.0619971136163388, 0.01903203026657658, 0.049321889478181086, 0.03254655981436372, 0.056800342830164094, 0.04511190877695169, 0.014985481509938836, 0.08335162845573255, 0.028397650657487766, 0.006574948351564152, 0.032258440274745226, 0.042991673440805504, 0.023190360882186463, 0.032917698113513846, 0.036354857962578535, 0.06087493883179767, 0.03801989129611424, 0.03199792353968535, 0.013980772163319801, 0.03965899780658739, 0.03258042888981955, 0.033765558153390884, 0.024091480832014765, 0.05115197306232793, 0.029754028589065586, 0.06597546621092729, 0.018433497919301902, 0.038146149699709246, 0.06064387730189732, 0.037330401329589744, 0.04232808315594282, 0.02648475526698998, 0.027419912229691232, 0.050671495630272796, 0.024974974138396125, 0.08297403728855507, 0.029060684543635164, 0.011695908116442817, 0.019007514796352813, 0.027089133193450313, 0.016764072767857994, 0.06185065183256354, 0.04198788944631815, 0.022826460855347768, 0.0489435553151582, 0.039364669671548266, 0.025649137695186904, 0.017054667263957005, 0.05312669656372496, 0.059762012479560714, 0.03522732614406517, 0.05678486544638872, 0.0467210613590266, 0.03734324599749275, 0.027961851363735538, 0.028687554744205306, 0.02547368041372725, 0.02342348006953086, 0.011091955122537911, 0.0166168493285243, 0.033769225635166676, 0.05260824831202626, 0.0399319961933153, 0.017197112120421867, 0.03412795013615063, 0.046028792791600735, 0.025440500051315342, 0.07993743023169891, 0.08072111782218729, 0.020076000497543385, 0.046054482127406766, 0.01815589058345982, 0.029123265828405107, 0.023879576042028408, 0.019847285002470016, 0.04207614988886884, 0.013991165623467947, 0.059646139054426124, 0.03811858421457665, 0.018042500596493483, 0.03807261346706322, 0.025790283157091056, 0.040565055795013905, 0.0457482796295413, 0.06286111261163439, 0.013013399206101894, 0.06916642641382557, 0.009159048038002635, 0.051418749282934835, 0.048354949935206344, 0.052204991557768414, 0.12875123268791608, 0.1195015518793038, 0.1153103903468166, 0.15008364085640225, 0.12150819706065313, 0.10585271141358785, 0.1232553840215717, 0.1089732057547995, 0.14826102794281074, 0.11054257582873106, 0.08116364479064941, 0.23031131444232805, 0.16127579100430012, 0.08937794222895588, 0.12154908558087689, 0.10099820047616959, 0.08185299565749508, 0.14844556232648237, 0.12393853307834693, 0.16436638230723993, 0.0969571987433093, 0.1403985305556229, 0.16835194772907666, 0.11475624436778681, 0.12298327790839331, 0.1278190477085965, 0.08374773684356894, 0.06817441500191178, 0.14239444131297724, 0.13720136854265416, 0.08429257332214288, 0.17795107407229288, 0.05480490365464773, 0.1969499188874449, 0.10458641579108578, 0.09859132141407047, 0.07206798464592014, 0.09698241988995246, 0.11493026145866939, 0.0759922783555729, 0.12780222004013403, 0.09694014715829066, 0.11214876999812466, 0.13684718683362007, 0.0956725962460041, 0.07871473726949521, 0.12255737504788808, 0.18037557468882628, 0.1998006616319929, 0.08046202601066657, 0.10111266254846539, 0.10221105468060289, 0.09348772705665656, 0.23418802927647317, 0.06434462086430617, 0.08213321026414633, 0.12684297508427075, 0.10719448727156435, 0.17231504007109574, 0.1464629101433924, 0.10697526617773942, 0.23325257375836372, 0.1958648735391242, 0.09435583118881498, 0.12204331691776003, 0.15907797536679677, 0.1399855605725731, 0.12049081522439208, 0.09851189210478749, 0.1582168194332293, 0.09638603510601179, 0.13987916628164904, 0.1542433455054249, 0.22817696897046907, 0.09244934456156832, 0.16416275394814356, 0.1338787046926362, 0.11126822831907443, 0.09115075745752879, 0.18336298795683043, 0.17522310545401915, 0.10496142173984221, 0.08435413680438485, 0.09217003919184208, 0.09509191276239497, 0.1307862542037453, 0.10943388353501048, 0.09139230913881745, 0.1854330218796219, 0.11210635477410895, 0.12540821278733866, 0.12368370246674333, 0.12450930316533361, 0.14145329967141151, 0.05528521823829838, 0.17134439572691917, 0.11770399047860078, 0.09921127850455896, 0.06076219345309904, 0.16395780923111097, 0.13590373817299092, 0.1871750655450991, 0.0901129110051053, 0.11438348436994211, 0.10476717752005373, 0.08570269122719765, 0.12613846574510845, 0.15397984321628297, 0.10239995204444442, 0.10762866147394691, 0.17933523122753414, 0.13813998603395053, 0.19217220454343728, 0.1990928953247411, 0.09739401923226458, 0.1385939395321267, 0.11969477151121412, 0.09589799879384892, 0.1379240354789155, 0.19956668918686254, 0.3999186062387058, 0.08840731145547968, 0.10065900082034723, 0.1495822984725237, 0.1158692996416773, 0.13591064565948077, 0.1534701141395739, 0.12806816505534308, 0.06878962913261992, 0.11325216293334961, 0.0949355104405965, 0.10689574187355382, 0.1224367722336735, 0.13993492828948156, 0.10338836043540921, 0.1090013242459723, 0.15977518366915838, 0.14602229664368288, 0.1286229488572904, 0.1229389560009752, 0.07689620235136577, 0.09997606889477798, 0.10893822048923799, 0.1469660031476191, 0.10050664935261011, 0.09903085604310036, 0.14082285921488488, 0.23210633812206133, 0.08764787470655781, 0.11362072279942886, 0.1284456340862172, 0.10153834827776466, 0.16341800748237542, 0.1349432582833937, 0.09222362988761493, 0.1375868578574487, 0.09013488875435931, 0.12698121980897017, 0.0655075688181179, 0.09996530054403202, 0.06344410989965711, 0.10595532626445804, 0.15559365733393601, 0.10840175034744398, 0.1662567537277937, 0.15524368254201754, 0.1537525611264365, 0.17000689463956015, 0.15388703319643224, 0.2552131696471146, 0.1177896215979542, 0.15233735420874187, 0.07951866555958986, 0.15260279710803712, 0.17388412516031945, 0.19318989850580692], [0.06389871479145118, 0.06706960392849785, 0.07302110243056502, 0.039943069884819646, 0.026296434657914296, 0.09695101050393921, 0.06540235517812626, 0.027873882691242864, 0.012466374452092817, 0.05036335252225399, 0.027036209158333283, 0.011175289400853217, 0.06078075138585908, 0.05193727895883577, 0.015292579674028924, 0.026922367945579544, 0.03394521387027843, 0.034383849440408606, 0.02695651352405548, 0.03622431800301586, 0.009502476663328707, 0.017225929502663866, 0.04263868934607931, 0.038043555204889605, 0.04208768837686096, 0.06180577352643013, 0.06411549315920897, 0.036686783723000965, 0.02514960869614567, 0.016436225002897636, 0.021800717771319405, 0.04324407150436725, 0.01960455606292401, 0.04880685765030129, 0.04514897035967026, 0.03328442932771785, 0.05196961793782456, 0.0399237146734127, 0.009563295453387712, 0.02394702920823225, 0.0284851375701172, 0.0720099224043744, 0.028158992928053652, 0.02244731075396495, 0.03510852823300021, 0.020101603320134536, 0.029104419518262148, 0.03357920529586928, 0.02232434494154794, 0.04598072876355477, 0.040846491764698706, 0.053635543544909785, 0.07988243496843747, 0.0338822220718222, 0.01609114244846361, 0.07855531546686377, 0.041399826894381216, 0.05365215747484139, 0.07228024397045374, 0.009718127814786775, 0.04897063225507736, 0.06502996837454182, 0.045645162662757297, 0.021479865702401315, 0.014605213522112795, 0.04386646792824779, 0.02496773756242224, 0.014864873606711626, 0.022364522696339657, 0.013671670624587153, 0.04952106325488005, 0.02074809112985219, 0.007782289458970938, 0.03566344774195126, 0.023481672929067696, 0.019098813379449502, 0.06608803517052106, 0.06423095267798219, 0.03466221164645893, 0.02840316714718938, 0.057154884162758074, 0.02804164877826614, 0.03517985583416053, 0.017683616639780145, 0.04574656293594411, 0.0357128281279334, 0.03217433246650866, 0.032707471001361094, 0.05127177520522049, 0.013216847753418344, 0.014767597130100642, 0.04561716630788786, 0.03148305456021002, 0.016873128612392714, 0.028316882937880497, 0.041722487259124, 0.02298146709134536, 0.09624251137886729, 0.02273917750322393, 0.05371462680133326, 0.030519504299653426, 0.021791038469278386, 0.03330937906035355, 0.0354967520439199, 0.044049831839012246, 0.034626123761492114, 0.020540898765570352, 0.040572760560150654, 0.0417411673281874, 0.024774324548031603, 0.03365259564348629, 0.07458781264722347, 0.021014461925785457, 0.0515572281022157, 0.020690490292119126, 0.007145163736173085, 0.060344141242759566, 0.021942658815532923, 0.04144329384767583, 0.04370848122718079, 0.022462862776592374, 0.03300628764554858, 0.02227678642209087, 0.011582987166808119, 0.047529685111450296, 0.08085177652537823, 0.06449037018631186, 0.0448442199267447, 0.02411883257861648, 0.01477425016595849, 0.013862447530430342, 0.011712441470340958, 0.020861971358369504, 0.024465910026005337, 0.03934933138745172, 0.0380165461184723, 0.029953239685190574, 0.04715900143076267, 0.0066283961308987015, 0.045778128385011635, 0.03440600700144257, 0.03655940912930029, 0.020868961965399127, 0.04164765841726746, 0.08385045347469193, 0.04343094683385321, 0.05129054348383631, 0.028033687866159847, 0.04399405626047935, 0.028922996217651025, 0.024707914629418935, 0.01931411593354174, 0.04627776425331831, 0.020927214196750095, 0.07146097400358745, 0.017397083175767745, 0.027643972974536673, 0.009863571796034063, 0.011032541748136282, 0.041512819938361645, 0.010377337307935315, 0.009043334068597426, 0.056402544890131266, 0.018236412334122827, 0.07869276630559138, 0.018603318271094134, 0.07249080695744071, 0.06005727020757539, 0.027892974970330085, 0.030585753066199164, 0.014605249145201274, 0.058194318387125216, 0.027751016962741102, 0.025835812856842364, 0.055987848035459004, 0.012127235016253377, 0.003198709708937843, 0.0525418604458017, 0.02407879731617868, 0.02232487589520003, 0.040921748083617, 0.01965851486394448, 0.034642754654799185, 0.017832543202010647, 0.04362126572855881, 0.009989441738330891, 0.03693300372521792, 0.01990650753889765, 0.05984058004937001, 0.04247480956837535, 0.04273791830720646, 0.023588745755010417, 0.03181338915601373, 0.02473036226417337, 0.028495776999209608, 0.0078610648301297, 0.004707015659992716, 0.06114311622721808, 0.031109378540090153, 0.04613708019522684, 0.04307563875668815, 0.05212530779785343, 0.02219525195791253, 0.07853315451315471, 0.020669990052868212, 0.0543284397572279, 0.0030998681488979074, 0.0678737357790981, 0.028340104102556194, 0.015465892784829651, 0.04232478208307709, 0.005358617503329047, 0.04140834929421544, 0.021922855771013668, 0.06357886695436069, 0.011625646663430547, 0.012839368544518948, 0.02320088665666325, 0.015193116618320346, 0.037095845344343355, 0.00821440854841577, 0.010906977146597845, 0.03199972505015986, 0.02890466559412224, 0.030113441803093468, 0.04264746619654553, 0.034930260120225806, 0.04427942094792213, 0.024191742862707803, 0.029065413932715143, 0.021291277071993266, 0.06701783170657498, 0.013892410788685083, 0.030382932163774967, 0.048428041727415154, 0.02560955874754914, 0.03012609648119126, 0.05297550539086972, 0.01624452698576663, 0.011660545415777181, 0.005237359054652708, 0.046321960631757975, 0.0009894518505981459, 0.01890912721864879, 0.01334453362505883, 0.03044121153652668, 0.02968431929392474, 0.008202929432237787, 0.03630360481994493, 0.02804978102046464, 0.07632940847958837, 0.014659146878070064, 0.05481355497613549, 0.024068047625145743, 0.027817345457151532, 0.09815474519772188, 0.02437821276752012, 0.07451136889202253, 0.05606490586485181, 0.03957038113315191, 0.05795223066317184, 0.0425569156983069, 0.024116479758439318, 0.03585784463211894, 0.026810786254437904, 0.03195256008101361, 0.0564608140848577, 0.02455314927335296, 0.10005490787859474, 0.03530879105840411, 0.01109917982414897, 0.015445955729644214, 0.029457790377948965, 0.06017203762062958, 0.056953053921461105, 0.03914699563756585, 0.03438278414042933, 0.019456238485872746, 0.03425641038588115, 0.05930328888020345, 0.028294699931783334, 0.013649391775418605, 0.055043941363692284, 0.022175313206389546, 0.03328302136755415, 0.009982618220549608, 0.012173303303175738, 0.02160488747592483, 0.055839913830693276, 0.005162434793809163, 0.04080996283196977, 0.048663815683020015, 0.07203956759933915, 0.011093026359698601, 0.061070160142013004, 0.012667621153273752, 0.00856448257608073, 0.057881228758820465, 0.01951724217672433, 0.005564744143547224, 0.058977008531136174, 0.06392811571380921, 0.03098019225788968, 0.025498301056878905, 0.02844924815664334, 0.032017431421471496, 0.043059004470705986, 0.03782928063135062, 0.04882382781111768, 0.01359662295518709, 0.012813889554568698, 0.03741802055654781, 0.02645788697658905, 0.040601048685078106, 0.03415184135415724, 0.055985608869897466, 0.02504363000792052, 0.03210010412814362, 0.029115415178239346, 0.014511350076645613, 0.023156842948602777, 0.013712235992508275, 0.021700954463865076, 0.020464814633929303, 0.015920523121686916, 0.09936534666589328, 0.035252286054726155, 0.029601361602544785, 0.04298346655975495, 0.01838510310543435, 0.04434678929724863, 0.02652617304452828, 0.035018819118184705, 0.03367876673915556, 0.04186708985694817, 0.047213823667594364, 0.020815642683633735, 0.026992998352008205, 0.02751747369101005, 0.019045992820922817, 0.02299409462804241, 0.011615623004867561, 0.04131220427474805, 0.04017008734600885, 0.011850799849656011, 0.03152821445837617, 0.03716700331174901, 0.056974414203848155, 0.015010287053883076, 0.06660108906882149, 0.01392292111579861, 0.0734931660283889, 0.10614859339381967, 0.19311041491372244, 0.18338053487241268, 0.17194834617631777, 0.07155277979161058, 0.17968646809458733, 0.18290298192628793, 0.10703918417649609, 0.1417989046978099, 0.16318423859775066, 0.09337403172893183, 0.12530495332820074, 0.1378589096878256, 0.16057831128793104, 0.13443291852516787, 0.07152844074049167, 0.1457728671708277, 0.11990534806890146, 0.09838335721620492, 0.09841277849461351, 0.06034899955349309, 0.16454903036355972, 0.11554159436907087, 0.12087087625903742, 0.10675316809543542, 0.15965615505618708, 0.1971650416297572, 0.17626753369612352, 0.08406567799725703, 0.1255327511046614, 0.0934657221660018, 0.11972360924950667, 0.08251679968088865, 0.060800096419240744, 0.11895136854478291, 0.12175379959600312, 0.11115903167852334, 0.11459327382700783, 0.17757440571274075, 0.11725473244275365, 0.0762046869578106, 0.12213483772107533, 0.10045100948108093, 0.10268767124840192, 0.13429742865264416, 0.09603583639753716, 0.10519255112324442, 0.1558896071676697, 0.1149616369179317, 0.07916470098176173, 0.07245850190520287, 0.16774699304785046, 0.09603338010076966, 0.107884347039674, 0.08625844533422164, 0.24419799500278064, 0.11442555354109832, 0.13142590916582517, 0.2020779201494796, 0.0900230458272355, 0.23725970302309307, 0.09896511278514351, 0.12052409058170659, 0.11029857463602509, 0.08718316642833607, 0.09806129056960344, 0.12120063070740018, 0.1222265756555966, 0.11279598384031228, 0.06127614980297429, 0.12015335261821747, 0.09143686853349209, 0.11203691350030047, 0.19685146345623902, 0.1609651848141636, 0.14965978717165335, 0.23111353282417568, 0.16639128008059093, 0.08800846857151814, 0.15253125237567083, 0.14355864455657347, 0.11577663889953069, 0.15545752963849477, 0.11619534928883825, 0.10891902473356042, 0.10813639565770115, 0.06024612007396562, 0.08326745618666921, 0.08607454877346754, 0.13897818034248693, 0.18771754072180816, 0.09757663336183343, 0.10637620796582528, 0.08331921483789172, 0.10648191693638052, 0.1292487752756902, 0.10103506528373275, 0.14865437469312123, 0.12233668831842286, 0.11860828766865389, 0.10878146532922983, 0.12172979302704334, 0.10783281909035784, 0.14706551709345408, 0.13599622249603271, 0.11206117112721715, 0.1207711858940976, 0.10800998458372695, 0.0988933237801705, 0.0821074666455388, 0.1375462543219328, 0.18640259413846902, 0.17930191515811852, 0.04697664175182581, 0.14079966688794748, 0.14319653755852155, 0.26211571640201975, 0.03640038426965475, 0.1368254330009222, 0.15391203042651924, 0.09673716340746198, 0.13151088889156068, 0.06654487922787666, 0.0886625424027443, 0.25203208891408785, 0.1413433498569897, 0.150537105809365, 0.14399186202457973, 0.16621092547263416, 0.08704843651503325, 0.12153413066906588, 0.14928533083626203, 0.13995141669043473, 0.09086162690073252, 0.10916107853076287, 0.13103755643325193, 0.11017270639006581, 0.12400532806558268, 0.05809757286416633, 0.1270536059247596, 0.13968746656818049, 0.08725369335817439, 0.07373093826962368, 0.1320807768830231, 0.256611521754946, 0.18648306839168072, 0.12029306297855717, 0.19040984553950174, 0.16655684262514114, 0.18498098185019834, 0.11273002345114946, 0.09022267761507205, 0.14257843286863395, 0.07839602258588586, 0.12161813330437456, 0.12281448553715434, 0.10415915586054325, 0.10698846368385212, 0.11434493001018252, 0.23768229463270732, 0.15713728378926003, 0.07602396594094378, 0.10638055058994464, 0.11832886694797448, 0.1057021716343505, 0.09476335253566504, 0.17355822479086264, 0.1585917371724333, 0.10317932415221419, 0.12897688629371779, 0.07251309004745313, 0.22363481484353542, 0.10981152898498944, 0.108147014730743, 0.10105850188327686, 0.12239034686769758], [0.022536680601271133, 0.03500206269589918, 0.0030938531479997827, 0.05365992670080491, 0.11098743017230715, 0.011668450348744435, 0.05599162069016269, 0.028973703139594624, 0.07873429264873266, 0.025740098707111816, 0.004629197871379022, 0.055952757596969604, 0.04656691177349005, 0.03554527069042836, 0.05179808089243514, 0.034020283592066596, 0.016138051270640323, 0.06452563365123101, 0.03987612561987979, 0.03742674651688763, 0.015560763854799526, 0.014870600442269018, 0.028188672049769332, 0.03583844870861087, 0.06452270237995045, 0.019010715785303285, 0.030351984181574414, 0.028859380166977644, 0.018810285022482276, 0.10129548702389002, 0.03053106992904629, 0.027893512709332362, 0.09824256119983536, 0.005611603771935084, 0.05318692333198019, 0.04239547525399497, 0.01931975455954671, 0.05340094006221209, 0.023630855638267736, 0.041662925455187044, 0.016551457212439606, 0.02411019822050418, 0.050373014860919545, 0.038759718382997174, 0.010772897778744144, 0.06125876573579652, 0.02532293028863413, 0.04959638403462512, 0.028962164651602507, 0.01658025593496859, 0.05135171002309237, 0.019358624438089982, 0.02282756008207798, 0.019583879404568245, 0.03434037909443889, 0.014142961540658559, 0.046352494707597156, 0.05437008484399744, 0.024779779969581535, 0.08062306951199259, 0.0027174835558980703, 0.011389974488078483, 0.04682818507509572, 0.038252594880759716, 0.020048993107463633, 0.02636349936281996, 0.04688646784052253, 0.014015298569574952, 0.026270355164472545, 0.019297004976708974, 0.05952921390001263, 0.04484065083254661, 0.039636110820408375, 0.009804807270744016, 0.021942219464108348, 0.03199998289346695, 0.09759046869086367, 0.03024343214929104, 0.03389819817883628, 0.04232132155448198, 0.008170782987560545, 0.010918027937545307, 0.02122538792900741, 0.02752173489092716, 0.050368414393493106, 0.07647209760865994, 0.026217519338907938, 0.09612431057861873, 0.015580373516838466, 0.037138477699565034, 0.08103497419506311, 0.012877687961528344, 0.0431700467265078, 0.030970882757433822, 0.04681963214118566, 0.06099016086331435, 0.021348153573593924, 0.0313290406816772, 0.029985599020229917, 0.039163986154432805, 0.030191307089158466, 0.03752935118973255, 0.04522824699857405, 0.020061271198626076, 0.008585873392543622, 0.011276162113063037, 0.027132527204230428, 0.018443740405408398, 0.02776559698395431, 0.028064213460311294, 0.05033397534862161, 0.017240636749193072, 0.04043102816545537, 0.006855831315208758, 0.02613435299800975, 0.016134022468967096, 0.04382989149806755, 0.049720382916608026, 0.030478480072425942, 0.012394958641380072, 0.08413305652460881, 0.02495715920148151, 0.01805753693250673, 0.03406777765069689, 0.008832022148583616, 0.03941655385174921, 0.013367507124452718, 0.05873498187533446, 0.04861702730080911, 0.03125742131045886, 0.018062583536707928, 0.04092734939019595, 0.041996988600918224, 0.04355041649458664, 0.030334939381905963, 0.03030256647616625, 0.01906780432909727, 0.0034907921051074353, 0.0431859617653702, 0.0687115772494248, 0.011659786304725068, 0.031912424734660556, 0.0048764403410522, 0.07042059661554438, 0.03870229396436896, 0.023079335589760115, 0.07905172490115676, 0.05288320427228298, 0.026990121363529136, 0.029545141583574668, 0.07782058417797089, 0.04080302481140409, 0.06247517546372754, 0.04487372262935553, 0.06930779918496098, 0.06777382828295231, 0.03157568137560572, 0.01913050266115793, 0.03335235746843474, 0.026350137311965227, 0.007682543114892074, 0.0631139754716839, 0.041737404851508994, 0.027055282777707492, 0.05200219101139477, 0.02498374759618725, 0.036900162630315335, 0.04307690422449793, 0.021455552096345594, 0.03526525964428272, 0.02642785501666367, 0.04297017745141472, 0.013947635905684104, 0.03809037072850125, 0.0512388391154153, 0.012096485505545778, 0.020563717898247496, 0.0417343887633511, 0.04360527265816927, 0.02260914983760033, 0.04017598042264581, 0.06931073724159173, 0.058727782618786604, 0.06339077704719134, 0.07042772801859037, 0.034614697231778076, 0.06389014489416565, 0.022027519797640185, 0.014127624104730785, 0.05909714994153806, 0.04695991586361613, 0.07171691741262164, 0.031186232808977365, 0.037937103238488944, 0.0392314630693623, 0.05899291339197329, 0.04550034971907735, 0.031593401317617724, 0.03228746461016791, 0.057654957686151774, 0.025413107592612505, 0.03218844938757164, 0.04161298188513943, 0.040300420352390835, 0.0488632269469755, 0.07035050394811801, 0.05487797509080597, 0.04764988419732877, 0.03429066961897271, 0.028773728691573654, 0.02691201859020761, 0.03875576252383845, 0.0391846712944763, 0.019308563820751648, 0.016408169276214073, 0.04097520985773631, 0.0630037813846554, 0.018392424498285567, 0.009635345694342894, 0.031808876898139715, 0.037650605397565026, 0.04458474813561354, 0.06309693067201547, 0.053716469023908885, 0.02656474436766335, 0.01961628793339644, 0.02216341848751264, 0.02566838773366596, 0.03765469017837729, 0.03406392696446606, 0.0387190402086292, 0.03882530218522463, 0.03274729761428066, 0.026163353584706783, 0.022003221458622386, 0.07932640266205583, 0.07452828477003745, 0.03382982559768217, 0.016279391811362336, 0.013277842962582196, 0.057443526174340925, 0.049592869223228524, 0.04308089740308268, 0.009033572494185396, 0.05777190998196602, 0.04478506185114384, 0.05669276788830757, 0.029441369830497673, 0.038933002656059604, 0.054138867251042805, 0.0203652888137315, 0.055451690019773583, 0.016017668980306814, 0.00875231548811176, 0.06621066001909119, 0.03464905485244734, 0.04824054893106222, 0.032558977005204985, 0.0528479000952627, 0.0026036909008066034, 0.06237560044974089, 0.028948634663330655, 0.054603158230228085, 0.012514870198044394, 0.036042138135858943, 0.02732431173457631, 0.03248665874291744, 0.03860029658036573, 0.009668235134865557, 0.05862709480736937, 0.009419621600370322, 0.05783704255840608, 0.032893074077687094, 0.04058693515669022, 0.026406944263726473, 0.1260393996323858, 0.030251204767929654, 0.07736636605113745, 0.003211000734674079, 0.011479194209511791, 0.08555986639112234, 0.014344825708706464, 0.02628210060564535, 0.04751297618661608, 0.021927249285259416, 0.009066235473645585, 0.00867707867707525, 0.03808335128373333, 0.03899948890986187, 0.08715396906648364, 0.06586381327360868, 0.09566570911556482, 0.024625467535640513, 0.028285174996459057, 0.07040358574262687, 0.016814682998561432, 0.03434374462813139, 0.008813911200767117, 0.046409227020506344, 0.026295774782608663, 0.01286726735997945, 0.05032884223120553, 0.0179027512203902, 0.0277374377806804, 0.037530311316783936, 0.020110770328236476, 0.01190663904084691, 0.042611422416354926, 0.021315307389678698, 0.06031622631209237, 0.019691318639421036, 0.05599467070507152, 0.022619500889309814, 0.03502046117292983, 0.02613660573427166, 0.027366397869107977, 0.025808517089379684, 0.03172120678105524, 0.019922183394165974, 0.006352918970930789, 0.08722826865102563, 0.01683733249748392, 0.025104184169322252, 0.05301531504041382, 0.008328976641808237, 0.020095545698755553, 0.021491809615067074, 0.03226439102685877, 0.10364327247121505, 0.04911036297146763, 0.014578679410208548, 0.021864981822935597, 0.05352276763213532, 0.021896776277571917, 0.04346032740016069, 0.05079336051962205, 0.03682583251169749, 0.012635813976105834, 0.035103021921323876, 0.037118274319384775, 0.03875107384685959, 0.020908262713679245, 0.0464324939862958, 0.0380464661201196, 0.07272861991077662, 0.06288072227367333, 0.006715545896440744, 0.054877337267888446, 0.02076188744311886, 0.02981025878606098, 0.02898864448070526, 0.02630240237340331, 0.07540478916572672, 0.13605876985405171, 0.13132988288998604, 0.10777876020542212, 0.11022934370807239, 0.17733469286135264, 0.13518542743154935, 0.10732979393963303, 0.16700164947126592, 0.08760642300226859, 0.19335993938148022, 0.07034426142594644, 0.11181940231472254, 0.16593693303210394, 0.1664492269711835, 0.154811292886734, 0.16523759412978375, 0.1561984491667577, 0.07668196170457772, 0.11564538308552333, 0.13224552518555097, 0.12843993439206056, 0.10956332087516785, 0.10980386153927871, 0.15390034605349812, 0.08056444408638136, 0.15482429361769132, 0.15107340631740435, 0.11567648713077817, 0.15045747293957643, 0.11211977619677782, 0.08516840596816369, 0.20261160151234694, 0.10119673982262611, 0.08124843452657972, 0.16049791845892156, 0.06281600360359464, 0.08592515571841172, 0.11631610138075692, 0.11912432712103639, 0.15651660066630158, 0.07625453892563071, 0.08608282011534486, 0.1373959316739014, 0.11935506973947797, 0.16440915715481552, 0.17801576560097082, 0.16207950216318878, 0.16182946200881684, 0.10421969475490706, 0.12253810465335846, 0.12101885117590427, 0.0857557255242552, 0.11093014146068267, 0.1434800566307136, 0.16533661953040532, 0.09287507100296871, 0.1437515520623752, 0.12462023007018225, 0.27688462819371906, 0.13171397442264215, 0.13639551321310656, 0.12761942270611012, 0.05685965696881924, 0.10702465674174683, 0.10327590004141841, 0.137148931356413, 0.07526862754353456, 0.17088721240205423, 0.13671850945268357, 0.16163029841014318, 0.13199190236628056, 0.0994282400767718, 0.1710028483399323, 0.15144470067960875, 0.08282021339982748, 0.18890804398272718, 0.13510579456176075, 0.13607400975057057, 0.06860440942857947, 0.1306112871638366, 0.19960961331214222, 0.2392631998019559, 0.12881304722811493, 0.18668662889727525, 0.14161605308098452, 0.15462552356932843, 0.1274126595152276, 0.08171346171626023, 0.12125727481075696, 0.10444336025310413, 0.11933335661888123, 0.08046972738312823, 0.12335066390889031, 0.12032027223280498, 0.11920269791569028, 0.1130648058440004, 0.14864613727799483, 0.11557565682700702, 0.1752085169511182, 0.11481425911188126, 0.11951029141034399, 0.11350484937429428, 0.08630204799451999, 0.12761790278766835, 0.15227350406348705, 0.08321472044501986, 0.10362934214728219, 0.15321551422987664, 0.08472568222454616, 0.13165306911936828, 0.0979810877303992, 0.08975228999874421, 0.19366457446345262, 0.10819926192717892, 0.17646433599293232, 0.13547056141708577, 0.17285511323383876, 0.12317739320652825, 0.09753620624542236, 0.22234306058713368, 0.07665412141276257, 0.10127456778926508, 0.15498934047562735, 0.07723717976893697, 0.09878683449434382, 0.11180317854242665, 0.16421472973057202, 0.18547468392976693, 0.11289511102118663, 0.055109457312417884, 0.12778461884175027, 0.09892061445862055, 0.10940136813691684, 0.07117899520588772, 0.13564301787742547, 0.16417599895170756, 0.11652118180479322, 0.19440189775611671, 0.12371923056031976, 0.14104939491621085, 0.17647987444485935, 0.10871724877506495, 0.09552893002650567, 0.1769650676952941, 0.20639538419033798, 0.10492535760360104, 0.13913304917514324, 0.07014051093054668, 0.14101318828761578, 0.12238004670611449, 0.13087044682885918, 0.13328699501497404, 0.11327754014304706, 0.10916614718735218, 0.16170239954122476, 0.1050291938175048, 0.10170793453497545, 0.12005942980093615, 0.16366283648780414, 0.12424095613615853, 0.0867285140390907, 0.11409049294888973, 0.18355765965368065, 0.11137061246803828, 0.10582380582179342, 0.08071490244141646, 0.09408504143357277, 0.10472016182861157, 0.10634491393076521, 0.14320827621434415, 0.20715348422527313, 0.16833377656127724, 0.12374226003885269, 0.10171304390366588, 0.16276917872684343], [0.053602950115289004, 0.03627762371408088, 0.0709242799452373, 0.021713105329711522, 0.06055414104568107, 0.030880043881812265, 0.05530682618596724, 0.03755134590236204, 0.08361314942262002, 0.017120234102809002, 0.04425607255793043, 0.02678666263818741, 0.0392889451634671, 0.04384610848501325, 0.011498134666388589, 0.06507518594818455, 0.053474975018096824, 0.026911833689415028, 0.027113110924671804, 0.08254672986056123, 0.011417654475995472, 0.026229831356821314, 0.02098633156024984, 0.012097545716512417, 0.03936732613614627, 0.03805602328585727, 0.026891291041725447, 0.011250248860700853, 0.022261095299784626, 0.013764438235999217, 0.07600592369479792, 0.07080160081386566, 0.010446368068057512, 0.04892647319606372, 0.027789815595107417, 0.042079023484672816, 0.02486389286683074, 0.004507725684171808, 0.035828182473778725, 0.058477179280349185, 0.04730627067121012, 0.060827522804694514, 0.07293427708957877, 0.02695538885226207, 0.03401929293093937, 0.03398637719718473, 0.04971085289227111, 0.04667090065777302, 0.045472919940948486, 0.008938330774461585, 0.027720533777028322, 0.027657151820936372, 0.013435351296461054, 0.03993576545534389, 0.016261429293081164, 0.020356230371232544, 0.04684469383209944, 0.08035418644015278, 0.045052686240524054, 0.03514396133167403, 0.04215749266690441, 0.02474648255987891, 0.011984422054540898, 0.08302229469908134, 0.014243873268631952, 0.0417413641033428, 0.02734703247967575, 0.036974696309438775, 0.04169906083760517, 0.02510923077352345, 0.012596645542154354, 0.06794772323753152, 0.007577109799188162, 0.04672985178019319, 0.005698949888548148, 0.011515745194628835, 0.1268010823322194, 0.030055257425244366, 0.023118512505399327, 0.06434717894132648, 0.027946682713393654, 0.024681728266711746, 0.0535360329917499, 0.04187431964757187, 0.04213187118460025, 0.02267704574790384, 0.011575189951275076, 0.04030912934935518, 0.024450653166111027, 0.009186868821935994, 0.010117009714511889, 0.04460843579311456, 0.03431315626949072, 0.034900679386087825, 0.045308473586503945, 0.06353474860744816, 0.048773361769105704, 0.024068819458729455, 0.018798454764432142, 0.055334792006760836, 0.10579165004725967, 0.0427740435115993, 0.008441102009133568, 0.0234190170054457, 0.017787780246830413, 0.01591918301502509, 0.03446592164358922, 0.029877484643033574, 0.025726069995601262, 0.04013758891129068, 0.025887254292943647, 0.020987247582525015, 0.03053974499925971, 0.03902513414089169, 0.03699288104793855, 0.09983005494411502, 0.051653698818492036, 0.04063856827893427, 0.03176652274227568, 0.02543042041361332, 0.030935381805258136, 0.034062746313533614, 0.015348238205271108, 0.006863952531213207, 0.044750687267099104, 0.035696499182709625, 0.01023742847610265, 0.018169303524440954, 0.02013663269047226, 0.016534755072955574, 0.012063696148938366, 0.021399737502049123, 0.01031314195798976, 0.014652861947459834, 0.011672144123752202, 0.05399898386427334, 0.035855608859232495, 0.033450130971946886, 0.037862647590892654, 0.045600409885602336, 0.03949523677251168, 0.030573057676000253, 0.0027631739836319214, 0.05443090533039399, 0.03694381957341518, 0.011852660731944655, 0.02646517105001424, 0.003137568402702787, 0.051420489725257666, 0.05231746891513467, 0.052742347187761746, 0.037074013480118344, 0.05008524476683565, 0.035308394115418196, 0.029127218294888735, 0.08422820070492369, 0.014005478471517563, 0.0180783119784402, 0.07575913372316531, 0.03728568587186081, 0.0087411247493167, 0.029481020024312393, 0.020896792079188993, 0.04810020074780498, 0.018228120636194944, 0.06354384097669806, 0.027000430006799952, 0.030460963690919534, 0.028223823556410413, 0.04329822199153049, 0.028364577164341296, 0.012795164532560323, 0.058891832030245235, 0.09819102646516902, 0.07279150653630495, 0.09181676671973296, 0.07077434406216655, 0.04735951192144837, 0.07577883838010685, 0.033609067622039995, 0.044141223720674, 0.06854506475584847, 0.030183059496006796, 0.015163094836420246, 0.02986941346898675, 0.009726835963582354, 0.06392577476799488, 0.008843812542701406, 0.046395761493061266, 0.030221389939210246, 0.04029409640601703, 0.016530571904565607, 0.05027754498379571, 0.0289697472804359, 0.04322745757443564, 0.03326101986957448, 0.011467420778769468, 0.007791728729249111, 0.04670312089313354, 0.051072472506867986, 0.036115117969789674, 0.02175784114349101, 0.03138651599043182, 0.04488045030406543, 0.018388332932123115, 0.01582162155370627, 0.04365639348647424, 0.0418565827421844, 0.03562962616394673, 0.07541154058916227, 0.004265866541702832, 0.07391721648829323, 0.030768231488764286, 0.019812428658562045, 0.013617554912343621, 0.029572333874447004, 0.02803317896489586, 0.033497401114021025, 0.04340631601267627, 0.06694485526531935, 0.030896491570664302, 0.027854052505322864, 0.04522768720718367, 0.029635111934372356, 0.036012567579746246, 0.018718043275709664, 0.06262021232396364, 0.035834221435444694, 0.016822589627866234, 0.04302004977528538, 0.039845055501375876, 0.0037657904738028136, 0.02651043442477073, 0.03744332652006831, 0.09274343520935092, 0.012888060217457158, 0.008398361936477678, 0.03282743599265814, 0.016023867397702167, 0.04065012373030186, 0.03530948655679822, 0.02916365901806525, 0.0364297309092113, 0.02045812936765807, 0.039876821118273904, 0.06856059642242533, 0.04560532247913735, 0.02498325056928609, 0.03472142061218619, 0.06991179034646068, 0.009894780166048025, 0.06173718042139496, 0.053113994388175864, 0.034620807439621, 0.048424767795950174, 0.035175496246665716, 0.03855315535994513, 0.02783987281977066, 0.020490892431033508, 0.008535945937702698, 0.017097019723483493, 0.023645220224612525, 0.009427049014318203, 0.041283610809062204, 0.03716632477673037, 0.009909232113776463, 0.037165999079921415, 0.04748511553875037, 0.026885167263182144, 0.028321588578234826, 0.036029849866671224, 0.038534926516669135, 0.035372502103980095, 0.058037983918828626, 0.06597795643444572, 0.047657080061201534, 0.09307760013533489, 0.011046015757269092, 0.017200920398214033, 0.027842215461922542, 0.027763125420148884, 0.03623005501659853, 0.03484976551096354, 0.05451671626152737, 0.04842339036986232, 0.010191059089265764, 0.008299434075265058, 0.018459801329299808, 0.03514418864090528, 0.04746591978307281, 0.02761819034016558, 0.052770669239440134, 0.05185922368296555, 0.047498533568744145, 0.05141054918723447, 0.07468585417206798, 0.037856744336230416, 0.05465925611289484, 0.039576230105012655, 0.013788196291508419, 0.022637599114594713, 0.023115513380616903, 0.043074302042701414, 0.010301991083127047, 0.026615517446771264, 0.021292271125795584, 0.018568411037059765, 0.049134440786604366, 0.04624804102682641, 0.02724679759038346, 0.012281411743190671, 0.0460688229650259, 0.014690447698480316, 0.007077768669530217, 0.019708304067275355, 0.028813755472323725, 0.057033684237727096, 0.08658349753490516, 0.03705683975879635, 0.04898912911968572, 0.01932692328201873, 0.041552314069122076, 0.0275240249466151, 0.006686641576899481, 0.06169085005032165, 0.054600891923265796, 0.04250965573425804, 0.028782542861465896, 0.024890381177621226, 0.041425902995147874, 0.0394595356525055, 0.023726905662832514, 0.05273844900407961, 0.027225729078054428, 0.0755728826458965, 0.10772123400654111, 0.028901910741946528, 0.022698334784113934, 0.01696428979214813, 0.059437625243195465, 0.04871315535690103, 0.004810038055958492, 0.016675746168142984, 0.09130383495773588, 0.05065832865823593, 0.01845772670848029, 0.032928072913948975, 0.013226087704034788, 0.040818037398691685, 0.04017136977719409, 0.07085367159119674, 0.026053726074418852, 0.20568301741565975, 0.10238714808864252, 0.10454560869506427, 0.12090583438319819, 0.12047887300806386, 0.08347816845136029, 0.18527492322027683, 0.1393573321402073, 0.29103287043316023, 0.0961508277271475, 0.134193178532379, 0.05862525597746883, 0.15172173295702251, 0.09785509056278638, 0.08162242267280817, 0.16320812303040708, 0.10893125871994666, 0.08865121765328304, 0.10173377993383578, 0.1570361549300807, 0.08590748666652612, 0.08372653262423617, 0.08541286177933216, 0.1603015097124236, 0.1286643666348287, 0.07117024888949734, 0.14236943051218987, 0.08482073819530861, 0.080609804152378, 0.09996933782739298, 0.1692793286804642, 0.17878195377332823, 0.13842429220676422, 0.15613678390426294, 0.11362579145601817, 0.15524297686559813, 0.09331411708678518, 0.13059372667755398, 0.15828783490828105, 0.11427502733256135, 0.13803173255707535, 0.14721395341413362, 0.1152175667562655, 0.11090876082224504, 0.12272745663566248, 0.1113114170730114, 0.11703806264059884, 0.1604209861585072, 0.15705640241503716, 0.10631052577602011, 0.11149379371532372, 0.09779669583908149, 0.0947558411530086, 0.11104103443878037, 0.06562437183622803, 0.0956088343103017, 0.1559989055884736, 0.09244612152022974, 0.12447904050350189, 0.16431682210947784, 0.10228579531290702, 0.0671245041968567, 0.12523262149521283, 0.22417483372347696, 0.11393664191876139, 0.13339343001799925, 0.14035072097820894, 0.18969348897891386, 0.21212839441640036, 0.1287365084780114, 0.12369362264871597, 0.1725422271660396, 0.11547042961631503, 0.1681870637195451, 0.11112760872180973, 0.15079978028578417, 0.2713538892567158, 0.12870245959077561, 0.12134388302053724, 0.2136713694781065, 0.06423525459000043, 0.11009614049856152, 0.14116931919540676, 0.14312491140195302, 0.09717494063079357, 0.161206363301192, 0.08473244721868209, 0.06833154335618019, 0.08113308357340948, 0.034299829841724465, 0.10105585559670414, 0.08942581287452153, 0.10259431840053626, 0.21806031039782933, 0.09958795364946127, 0.22068195257868084, 0.11003001726099423, 0.08922843382294689, 0.1155809358294521, 0.16618936162974152, 0.16259039832012995, 0.09573709099952664, 0.1406718444611345, 0.1053855943360499, 0.08962260838598013, 0.14205871575645038, 0.13133847314332212, 0.15606252503182205, 0.1127150481832879, 0.1153760589659214, 0.08201784574027572, 0.09474111694310393, 0.20703379064798355, 0.08217442448117904, 0.08161459237869297, 0.15794092709464685, 0.1471017644341503, 0.13432668708264828, 0.14705806677894934, 0.12679684827370302, 0.17566624310399803, 0.16340001273368085, 0.11076772731861897, 0.11085162138832466, 0.13724798389843532, 0.1114421911271555, 0.08512872524027314, 0.07654896205557243, 0.07800920334245477, 0.11131735425442457, 0.0817616716293352, 0.09912173902349812, 0.1571812935705696, 0.062128878331610134, 0.08375817949750594, 0.11738940807325499, 0.14125655165740422, 0.1643858291208744, 0.09120123367756605, 0.1679908178214516, 0.16890555088009152, 0.10226611101201602, 0.15128882761512483, 0.13570963644555636, 0.17631508543023042, 0.11451001758021967, 0.17041921322899206, 0.11018031276762486, 0.10284083695816142, 0.20074721798300743, 0.2030321710876056, 0.08079610272709813, 0.07847108212964875, 0.16194393086646283, 0.08345665889126913, 0.11094644665718079, 0.126510710056339, 0.11147225701383182, 0.25009886122175623, 0.11446726987404482, 0.1202945557555982, 0.20600391019667896, 0.12061789126268455, 0.12310774837221418, 0.0931485341861844, 0.14001085635806831, 0.10534253450376646, 0.17657847915376934, 0.1466690490820578, 0.11213528072195393, 0.10716166653271232, 0.07946329031671796, 0.1649116530482258, 0.14038105149354252, 0.15460660601300852, 0.18971832336059638], [0.042980073884661706, 0.0837485578709415, 0.014560038356908729, 0.07237014986042466, 0.011833800002932549, 0.039196464233100414, 0.05718537074114595, 0.06132833593125854, 0.030562740551041703, 0.023535112650798898, 0.036259055603295565, 0.061666728130408695, 0.02180045483899968, 0.020989435857960155, 0.01819360695247139, 0.03940224354820592, 0.03588868404871651, 0.033621284645050764, 0.023880481886278306, 0.06082633536841188, 0.01869714948614793, 0.025052188030843223, 0.0024552594570975217, 0.037345569979931624, 0.03232136761237468, 0.03200370465804424, 0.030872664813484465, 0.008121466214236404, 0.05740395401205335, 0.023408343649602363, 0.019759480874719362, 0.03149123429985983, 0.03171076073444315, 0.04380879245166268, 0.06444969201194388, 0.019471917733816162, 0.04213958952043738, 0.05857322591223887, 0.033767651433923414, 0.013059361471927591, 0.05777247995138168, 0.03881672889526401, 0.050069204198994806, 0.07698021177202463, 0.02645090315490961, 0.06796236602323395, 0.011693287274933286, 0.01985462675137179, 0.017883731883817484, 0.013313187851703592, 0.019893367708261524, 0.03714294585266283, 0.029007076884486845, 0.06404763287199394, 0.02074461194154407, 0.015016410832426377, 0.03709325673324721, 0.08773007922406707, 0.011302058402049755, 0.03259592323697039, 0.03888567144583378, 0.024897543114743063, 0.06655688929770674, 0.05205522191577724, 0.04951558069192937, 0.044192721135914326, 0.03673820649938924, 0.04340480627225978, 0.05410911688315017, 0.029084565583616495, 0.05197854067331978, 0.016709722112864256, 0.05377490445971489, 0.07890128011682204, 0.033746440429240465, 0.023175429719101106, 0.007507069718225726, 0.0252373975568584, 0.019016929469736557, 0.044491385109722614, 0.03745805412264807, 0.07361053223056452, 0.03832838724234274, 0.05671525114615049, 0.012964637135155499, 0.041777943926198144, 0.016797538114977733, 0.04397488086085234, 0.03963235512908016, 0.016743748947711926, 0.03621444531849452, 0.04723048170230218, 0.01592321351303586, 0.031988973662789376, 0.047587285949183364, 0.0650052289877619, 0.022085410709093724, 0.036234319609190734, 0.038968323796455345, 0.027857334918475578, 0.05296656908467412, 0.021451506331296902, 0.02274844459524112, 0.012538587541452475, 0.022063434656177248, 0.04544632136821747, 0.034744080289133956, 0.050419297734541554, 0.03295261552557349, 0.018622354571042315, 0.04166888299265078, 0.04419839368867023, 0.046238487253763845, 0.0335435041758631, 0.030215303480092968, 0.01861772356954004, 0.047258813932005844, 0.028684633650950024, 0.022125371332679476, 0.02873455347227199, 0.07890552774603878, 0.09661734090851885, 0.01708123699894973, 0.015092440681265933, 0.0561695359647274, 0.033680849841662815, 0.042075847940785546, 0.031146487620260035, 0.034993747249245644, 0.018233601502808075, 0.015152441836627466, 0.016978410105886202, 0.03455063674066748, 0.05996225494891405, 0.0251501447388104, 0.0296391051129571, 0.013921581009136779, 0.02424678223074547, 0.022712324479860917, 0.04946826983775411, 0.02766928233073226, 0.011122891230375638, 0.04275106153051768, 0.04504962604758995, 0.06708572592054095, 0.02220272771748049, 0.03669105510094336, 0.03304486914670893, 0.037206144604299746, 0.0509798422987972, 0.06174746701227767, 0.06505358817854098, 0.029930885349001204, 0.023813198353829126, 0.025675861796896373, 0.0290021303642009, 0.06765828055462667, 0.04196510763306703, 0.0393226785319192, 0.02066498076809304, 0.020641825760581663, 0.018667305819690228, 0.014413140614383986, 0.02238311625218817, 0.009073832521348127, 0.00977185506573213, 0.029684292152523994, 0.04466810276997941, 0.024883124245596782, 0.03729168072875057, 0.04861872363835573, 0.033305796395455084, 0.022058213329208747, 0.03839258344045707, 0.019579328130930662, 0.06148248551679509, 0.04368174694744604, 0.08426134035523448, 0.03775666381365486, 0.041509936164532385, 0.026587758579158356, 0.02134559888924871, 0.03459697389709098, 0.03175964239718659, 0.02126285493639963, 0.010702686367689498, 0.06216175335326365, 0.05213886832020112, 0.029146936522530656, 0.0536861385085753, 0.05258794993694339, 0.02313766924531332, 0.05064470028238637, 0.05875801135386739, 0.04285364584731204, 0.05363690400762217, 0.014976180491170712, 0.03643299466265099, 0.010514247863154327, 0.01748333515466324, 0.015132998415668095, 0.07391891282583986, 0.023814024470214332, 0.05994367666010346, 0.02299152806933437, 0.05180923600814172, 0.04626683983951807, 0.006978069398818272, 0.05133285692759922, 0.03252434118517807, 0.04143717685448272, 0.017749191960319877, 0.023566991922312548, 0.044567543880215714, 0.028688521656606878, 0.02787987924447017, 0.04133974601115499, 0.06937675191355602, 0.06162501179746219, 0.04638868776549186, 0.030965105031750033, 0.034905317172940285, 0.030082069736506258, 0.03200226955647979, 0.02296969959778445, 0.049344413448125124, 0.12384370102414063, 0.02714056445152632, 0.021166401183498756, 0.020982318025614535, 0.003361708451328533, 0.03715371759608388, 0.04061860238601055, 0.03843389265239239, 0.05538349046504923, 0.02797293184059007, 0.05507231769817216, 0.050851273483463695, 0.02203482422711594, 0.02036950081985976, 0.030823287820177417, 0.06966921407729387, 0.02763483141149793, 0.04143790627962776, 0.028723293183637515, 0.015386095370299049, 0.03576256813747542, 0.019694867377568568, 0.007549392491845148, 0.035473359549152, 0.03798962863428252, 0.011755564067113613, 0.037650469690561295, 0.08383333403617144, 0.02890611087371196, 0.0260169528690832, 0.014375207114166446, 0.011331679848288851, 0.01021956095272409, 0.04237189616209694, 0.06724539878112928, 0.00748671027499118, 0.01649294374510646, 0.044617365313959975, 0.0628442442310708, 0.014077011329521025, 0.03165016755727785, 0.04614917847460934, 0.03718050276594503, 0.018853093796808804, 0.0419987052945154, 0.011210154226448919, 0.008983432997151144, 0.010398261631572885, 0.040853582455643585, 0.07773192679243428, 0.011496847994359476, 0.030365748264427696, 0.03097730509138533, 0.05536340922117233, 0.021154676098376513, 0.06451452603297574, 0.07016789660389934, 0.03301218072218554, 0.006107989457502429, 0.03427173849195242, 0.022722200557057346, 0.006715098063328436, 0.05332691867702773, 0.013071754065874432, 0.02561571984551847, 0.03236379301441567, 0.08016947563737631, 0.022948134058554257, 0.025322957430034876, 0.029956958057092767, 0.07980584193553243, 0.086425432802311, 0.017078071633087735, 0.04225851635315588, 0.04596987898860659, 0.021774426235684326, 0.06393986115498201, 0.003509025401269485, 0.04993094251091991, 0.016843875271401236, 0.03232601218457733, 0.009083974923539375, 0.009889206849038601, 0.02956800482102803, 0.06565504161907093, 0.06521291498626981, 0.05058557952621153, 0.018865629731278335, 0.01758801275199013, 0.028214656548308473, 0.03961220942437649, 0.020608815031924417, 0.017197364874716316, 0.05031914596578904, 0.04991735823984657, 0.017138944705948234, 0.020040626770683696, 0.02237810187840036, 0.02404132521977382, 0.01906723266334406, 0.021660705462896397, 0.029235597300742353, 0.019945056809644614, 0.025406927834930162, 0.01537685711602015, 0.027425121682296907, 0.031100432055869272, 0.02931216319224664, 0.007861688234178084, 0.019427237899175713, 0.002567697162573625, 0.01776694243640772, 0.02886523592418858, 0.011229337259594883, 0.036491759187941036, 0.008282493600355727, 0.0417850956852947, 0.01012904692574271, 0.0060355821374936825, 0.02165599642986698, 0.03423286861340914, 0.029186722423349108, 0.051556831159229786, 0.03349735022389463, 0.0510545422190002, 0.03277390975771206, 0.06885674303131444, 0.15331969649663993, 0.08198538462498359, 0.16587905399501324, 0.12602219198431286, 0.1656687624220337, 0.1238304153084755, 0.16385237845991338, 0.13388441795749323, 0.10534275842032262, 0.20176736824214458, 0.1310233614806618, 0.1495047283491918, 0.10008506197482347, 0.18907238516424382, 0.10024117252656392, 0.10455590207129717, 0.10601650976708957, 0.09762725207422461, 0.18869435973465443, 0.1555081619215863, 0.0978946830811245, 0.09832515248230525, 0.13217111703540596, 0.07729079082076039, 0.17650949928377355, 0.06762402132153511, 0.080008276072996, 0.16234966766621384, 0.1190745769334691, 0.13299580849707127, 0.08895474672317505, 0.139471936704857, 0.11916977539658546, 0.16161303647926875, 0.1380263857011284, 0.14260720275342464, 0.1448962813509362, 0.1792283212499959, 0.08246234046029192, 0.21200997648494585, 0.13960676161306246, 0.162438854309065, 0.19345577566751412, 0.08397019454943282, 0.15434186879013265, 0.10736327285745315, 0.09342779884380953, 0.08835416180746895, 0.09139163060379879, 0.20735986743654522, 0.17765468997614725, 0.09582350243415151, 0.1811020007090909, 0.09070498030632734, 0.09097425014312778, 0.08271865706358637, 0.13459785681750092, 0.11071022147578852, 0.09494720838431801, 0.2098729982972145, 0.18745280349893229, 0.12486782749848706, 0.1016158369768943, 0.21699790097773075, 0.24149194306560925, 0.10113828403076955, 0.07312093528785876, 0.13389511166938714, 0.08482816815376282, 0.17425734656197683, 0.22312173380383424, 0.13017462273793562, 0.10886698109763009, 0.10413255050246205, 0.09741442278027534, 0.07601213229021855, 0.13087435519056662, 0.11856783341084208, 0.13658794574439526, 0.13224502306963715, 0.11217482574284077, 0.08356588945857116, 0.1407759181622948, 0.15106070414185524, 0.09130808937230281, 0.101741501662348, 0.21174209085958345, 0.15522970472063335, 0.05223549509953175, 0.1430280708840915, 0.09883201814123563, 0.11993808059820107, 0.17156299256852695, 0.1394325409616743, 0.19467097760311194, 0.07465076712625367, 0.07209349077727113, 0.1136359151984964, 0.11439105682075024, 0.13463409058749676, 0.13412904340241635, 0.13031545946640627, 0.11584599874913692, 0.13246020009475096, 0.11847905388900212, 0.1366356603269066, 0.1455382433320795, 0.07926659658551216, 0.2286630714578288, 0.1605941347245659, 0.10095961897500924, 0.2149065746260541, 0.14602852559515409, 0.1646669597498008, 0.12624570141945565, 0.19356320133166655, 0.10384544198002134, 0.1050881856520261, 0.11560951572443758, 0.2787158042192459, 0.20066788366862706, 0.153671476191708, 0.07698139920830727, 0.1412085113780839, 0.0748216425999999, 0.11585604106741292, 0.08423658061240401, 0.1327251544488328, 0.06831128908587353, 0.18739602368857178, 0.08587969387216227, 0.11302646183009658, 0.13922773195164545, 0.11005610014711108, 0.09346597322395869, 0.1408883107027837, 0.12022814074797289, 0.09356594857360635, 0.09200974886438676, 0.1969695014080831, 0.06310746832085506, 0.2105650904455355, 0.21692566413964542, 0.19227702463311808, 0.11431238747068814, 0.1429090965539217, 0.1281301560146468, 0.13361843223018305, 0.12344346035804067, 0.10199888356562171, 0.1906732799751418, 0.12477847800723144, 0.11124194187245198, 0.0865268534315484, 0.11423879356256553, 0.2203752411795514, 0.08647299810711827, 0.16379245024706635, 0.11017006688884326, 0.14455554820597172, 0.13985988231641905, 0.13142801262438297, 0.14706337292279514, 0.10609359134520803, 0.13118074089288712, 0.17263754776545934, 0.11237719881215266, 0.1037262776600463, 0.13041557052305766, 0.08865461711372648, 0.11953722925058433, 0.136578839804445, 0.1542985239731414, 0.11418499930628709, 0.09742529969662428], [0.06678556238434144, 0.014368394622579217, 0.03177087215174522, 0.026281946238928607, 0.02429252227635256, 0.11963755743844168, 0.030751319003424475, 0.029469396719442945, 0.027708162387300814, 0.029460470591272627, 0.0474600504551615, 0.030652056115546396, 0.04670224558295948, 0.038802557691399536, 0.04518948568563376, 0.09712514973112515, 0.028421497770718167, 0.019563044986820648, 0.034888665923582654, 0.04872625447543604, 0.03262430296412536, 0.06500087957829237, 0.0027429746322533382, 0.045307781480784924, 0.01866614891748343, 0.04273009819111653, 0.03300639621115156, 0.04076123723228063, 0.036028954200446606, 0.04414912186829107, 0.024645435124901787, 0.019840998375522237, 0.03636043891310692, 0.07271370571106672, 0.03789590259215661, 0.06206377289657082, 0.01839709960456405, 0.06801802625081368, 0.013532152798558985, 0.067043229272323, 0.029821647996348993, 0.03527558694726654, 0.017779042412127768, 0.048944369557180574, 0.028112231687243496, 0.03205259989148804, 0.08978586391146694, 0.02837786796901907, 0.08160336262413434, 0.05247939790466002, 0.036584698129445314, 0.019211244935702, 0.05576589583818402, 0.038083456456661224, 0.0528192319907248, 0.053436549579990764, 0.08278887186731611, 0.01725027194645788, 0.0035967657043199453, 0.024116059066727757, 0.047456762952996154, 0.02396017582421856, 0.02666183085446911, 0.030100851585822444, 0.07655848190188408, 0.006228072344258959, 0.037414624488779476, 0.04770710505545139, 0.043658710683562925, 0.06483832294387476, 0.03312939764665706, 0.03523031169814723, 0.017521470519048826, 0.01879269739479891, 0.015518567458327328, 0.03334578585677913, 0.02599469183145889, 0.050147737842053175, 0.005541742654583816, 0.013307298167741724, 0.03535910443003688, 0.009952964543897127, 0.04824507136696151, 0.028361888469329903, 0.042292473638164144, 0.04582031290712101, 0.04866971554500716, 0.017171198868059685, 0.042315129922436814, 0.08570877768631492, 0.00607051608884441, 0.05436157601486359, 0.055886569898575544, 0.0327252927236259, 0.0149359993437039, 0.027777593483084013, 0.017146664738122906, 0.01086969334366066, 0.03513563570699521, 0.02676071715541184, 0.03447305643931031, 0.09135177345680338, 0.04116031081814851, 0.04890447169808405, 0.005916499241720885, 0.029408416777317013, 0.016436024835067134, 0.026910362964762107, 0.046630819594221454, 0.023715765814163854, 0.06308287821177926, 0.03988755214959383, 0.05665117369166442, 0.04080872789823583, 0.057907420210540295, 0.03317580604925752, 0.07026894403887646, 0.023325798168246235, 0.04719834628381899, 0.027357407280110886, 0.016707910424364463, 0.043657757341861725, 0.04248059747208442, 0.00837956227561725, 0.02662995327929301, 0.04684426635503769, 0.04390395698802812, 0.07538579697055475, 0.0317636525391468, 0.0756096321025065, 0.08291319305343287, 0.044374748332692046, 0.012950165679545274, 0.02390916016884148, 0.024521270001839315, 0.04289535878758345, 0.0492900051176548, 0.09204611834138632, 0.04998358665034175, 0.03493840254044958, 0.01846745520431016, 0.06846625969878264, 0.04852724354714155, 0.029198376262294393, 0.04886771884879895, 0.05596096108534506, 0.02790332432570202, 0.05281095386349729, 0.05030206723936966, 0.0822939280686634, 0.0155671268169369, 0.026407229248434305, 0.015152202653033393, 0.013792278527814363, 0.030906818873648132, 0.04153368149750999, 0.025500357017985413, 0.015195498276235802, 0.04824177707944598, 0.046238259944532595, 0.003719751872787518, 0.05975184802498136, 0.12504622792559011, 0.023130802470924597, 0.02407624602450856, 0.01650245171705527, 0.0826519231445023, 0.025689681858888695, 0.0275571832566389, 0.08345172594168357, 0.03629253112844058, 0.030592110939323902, 0.06441189082605497, 0.03460890593539391, 0.06609631329774857, 0.006355669582262635, 0.019949333276599646, 0.0449828785578055, 0.0698445543114628, 0.0583316810163004, 0.047131473265056095, 0.018495882428916435, 0.07840189869914736, 0.03867641124608261, 0.029693530406802893, 0.011201755659255599, 0.07703317143023014, 0.05320947105064988, 0.06702837614076478, 0.03154040773266128, 0.017518905656678335, 0.038273900880345275, 0.04156682454049587, 0.05129296924652798, 0.023276712944997207, 0.07098323785300766, 0.028642968208129917, 0.02122424459750099, 0.038403134659997056, 0.024147665227896402, 0.04498662407110844, 0.04365041220028486, 0.04045198132683124, 0.023871270773400153, 0.014074292100433792, 0.01824479054526559, 0.044793797989508936, 0.03318800271621772, 0.04278924269601703, 0.03636177223441856, 0.04617333432127323, 0.05711373101387705, 0.04771566138203655, 0.021964324438678365, 0.011322463646398058, 0.011121831867577774, 0.03520885302818247, 0.02328404281953616, 0.04734923550859094, 0.11249059558446918, 0.019176281722528592, 0.027272790570610335, 0.02799764069329415, 0.07686643502009766, 0.012262818187342157, 0.014278368292642491, 0.04587310632424695, 0.025620605297652737, 0.042491976504347155, 0.0326694662549666, 0.015109192014538815, 0.042539100761392286, 0.07600483803876809, 0.0317033070272633, 0.04116006993821689, 0.03980574118239539, 0.033065781595983675, 0.06357611888753516, 0.08246483746916056, 0.02752940233663789, 0.06801532568143946, 0.014783675017367517, 0.0395654617542667, 0.016229319319661175, 0.060631860446717055, 0.07517532897847039, 0.1015224094901766, 0.021151325831721936, 0.02476435517227011, 0.010705360643831747, 0.02370753857706274, 0.05516837450808712, 0.06967349563326154, 0.036728578087474616, 0.027506099747759954, 0.00635028031787702, 0.0892201964078205, 0.013236537143321974, 0.016827317320608666, 0.09197458039437022, 0.025026800643120493, 0.013157459824079914, 0.048004408566547294, 0.009590510644816926, 0.12545881792902946, 0.027264100233358995, 0.01108271602009024, 0.02366465686022171, 0.0731481716835073, 0.01103818546315389, 0.012362943662862693, 0.035834672661232095, 0.017730121733620763, 0.03604418731161526, 0.03230194794014096, 0.02963359880128077, 0.02209835885358708, 0.10965784080326557, 0.05599689969260778, 0.04353872872889042, 0.008282553820338632, 0.016314088699540923, 0.01120301943072783, 0.07712528934436184, 0.03400502333949719, 0.003959080079636935, 0.008765457863254207, 0.06233731750398874, 0.039612019434571266, 0.008164191019854375, 0.0523858788157148, 0.025157422026885406, 0.019897342227133255, 0.03480447329846876, 0.021811867798013345, 0.02833190909586847, 0.02198238534453724, 0.02298411337791809, 0.03213439728798611, 0.04279115955744471, 0.01727958974827613, 0.048666302513863356, 0.0309628624735134, 0.02449882067074733, 0.011187397858260997, 0.04112784970285637, 0.006038937493160899, 0.05934293568134308, 0.03701236518099904, 0.06612736306020192, 0.025603490948144878, 0.03873332337077175, 0.051691296443875344, 0.04451526954237904, 0.01937040889502636, 0.013898811918417258, 0.021558814948158603, 0.036502310407481024, 0.06916958838701248, 0.00785695290791669, 0.008774170252893652, 0.013404268455425543, 0.046228743490896056, 0.06475194543600082, 0.06028702216488974, 0.11308157922966139, 0.01737151767260262, 0.05720474970127855, 0.05901592929980584, 0.016253422579861114, 0.052408830262720585, 0.04410592293632882, 0.05438387267557638, 0.10181458666920662, 0.019343669526278973, 0.006356159823813609, 0.03964510480208056, 0.08716855756938457, 0.024608621207465018, 0.051723285977329524, 0.02993613721004554, 0.016025826667568514, 0.04826716107449361, 0.0037149194312015815, 0.042503969610801766, 0.050830676552972624, 0.018294388062453697, 0.061158091495079656, 0.013548936362245252, 0.05274606555966394, 0.05373999383300543, 0.013324392161199024, 0.10231109788375241, 0.13412585428782872, 0.12108808888920716, 0.13403642337237084, 0.12722425748194965, 0.24586504697799683, 0.10496587971491472, 0.11294069500373942, 0.08224421859319721, 0.11626202213977065, 0.16048270570380346, 0.22564348205924034, 0.13292102036731585, 0.11495250383658068, 0.09116265896175589, 0.1722305760319744, 0.10563787365598337, 0.1295399482228926, 0.06536874055330243, 0.17504345652248177, 0.1660196871629783, 0.11801499021904809, 0.09173319834683623, 0.14593169864799294, 0.10025614779442549, 0.09333566735897746, 0.11057436519435473, 0.11489625328353473, 0.10735176490353686, 0.09803740613694702, 0.20254507793911866, 0.11459763002182756, 0.09928430244326591, 0.1265941970050335, 0.1321192362478801, 0.13945413194596767, 0.14787570147642068, 0.11741973858858858, 0.0692730989041073, 0.11116500957203762, 0.12966182668294224, 0.1435196559344019, 0.11081682611256838, 0.1959664366607155, 0.10238560102880001, 0.10054256421114717, 0.13535780246768678, 0.18670984836561338, 0.23149134112255915, 0.10711770424885408, 0.11324622575193644, 0.13102608919143677, 0.17967837995716504, 0.15613271269415105, 0.13618110971791403, 0.1813836877367326, 0.16116178355046681, 0.11638006009161472, 0.14639513806572982, 0.05883689783513546, 0.12333372767482485, 0.1560459823480674, 0.15420427545905113, 0.12678569315799645, 0.12410944247884409, 0.08393319403486592, 0.09087979128318173, 0.2001833010997091, 0.15062623816941464, 0.18285657013101236, 0.20682508684694767, 0.09897774032184056, 0.12123377035771098, 0.07990549158837114, 0.14223282784223557, 0.21706749152924332, 0.2020752602922065, 0.17841937180076325, 0.11855821178427764, 0.10579038118677479, 0.16791350554142678, 0.09349308748330389, 0.07010199728288821, 0.10338777010994298, 0.14755873062780925, 0.0952997887507081, 0.12786205325807842, 0.08595919103494712, 0.18595457103635582, 0.1587316103811775, 0.07673093157687358, 0.131410112870591, 0.24566455345068658, 0.1288389672658273, 0.11307432569031205, 0.21748818324080535, 0.09994380455464125, 0.12212351975696427, 0.12775260555957044, 0.17443991319409438, 0.09171719170574631, 0.190256998741201, 0.15284370418105805, 0.12662236977900776, 0.0628456420132092, 0.10468446410128049, 0.075587891840509, 0.1920039685709136, 0.16791366838983127, 0.06437891402414866, 0.16063566106770719, 0.09575130630816732, 0.236176354012319, 0.14642949907907418, 0.15963425194578512, 0.10476244813097374, 0.3086935899087361, 0.07405227888375521, 0.11034888122230768, 0.1315895039588213, 0.12996084349496023, 0.1353936833994729, 0.16695415201996053, 0.09330288733222655, 0.14514176174998283, 0.10174711314695221, 0.11667032380189214, 0.1165348475000688, 0.1489610725215503, 0.16563885259841168, 0.11737996286579541, 0.07700016748692308, 0.07510029657610826, 0.10923271825803177, 0.1051661018282175, 0.07817493552075964, 0.18020037694701127, 0.12581792580229895, 0.15153068463717187, 0.2524974282298769, 0.09338170595999275, 0.1414877963917596, 0.19171419340584958, 0.133709030225873, 0.11861409592841353, 0.10573550127446651, 0.20253715265010083, 0.1647031120955944, 0.10191281818385635, 0.23340006013001713, 0.11699101302240576, 0.1576523868633168, 0.19002295844256878, 0.12590285124523298, 0.08301628966416631, 0.12322945041315896, 0.16261957532593183, 0.12910265954477446, 0.10064050395573888, 0.16477420899484838, 0.11900459283164569, 0.1741783379444054, 0.1748573343668665, 0.17099028187138693, 0.09463751143110649, 0.08273818530142307, 0.09015307349285909, 0.061730897187122276, 0.04713627050763794, 0.22787906495588167, 0.21525201680404799, 0.18174582187618527, 0.11302135924675635, 0.1604729619409357, 0.15291636171085493, 0.08360088829483305], [0.021723805826955607, 0.03473698281283889, 0.014856877071516854, 0.07258785103580781, 0.016732006899214218, 0.019428737461566925, 0.043048751806574206, 0.019115300084065114, 0.035415809601545334, 0.03357581940612622, 0.019076382708070532, 0.02928334241732955, 0.01692332324039723, 0.022038644379270927, 0.07350574606763464, 0.01916700614882367, 0.02635143501018839, 0.008483420541909124, 0.01562164880202285, 0.024409544122006212, 0.015327877065699016, 0.011926753363305969, 0.028710523154586554, 0.030806511041841338, 0.041918434601809294, 0.022268798368583833, 0.04004163388162851, 0.01264792328168239, 0.036117024653192074, 0.025551099563017488, 0.054339900213692865, 0.04755506232114775, 0.051000612255718024, 0.07569115129964692, 0.023270590862791454, 0.050808658091617484, 0.018153183228735412, 0.011563841453088182, 0.02160078742807465, 0.0335597686602601, 0.01486088551713952, 0.01591803289816848, 0.08878661253090415, 0.06189271421836955, 0.013111510280785816, 0.006049177434761077, 0.047793065264288864, 0.09231693523802928, 0.043435174107019386, 0.018598860296021615, 0.03550026346264141, 0.03167319703581078, 0.024908464135868207, 0.0626691821962595, 0.050246868415602615, 0.05864884185471705, 0.0380221202836505, 0.045897262170910835, 0.044858112931251526, 0.019766166140990596, 0.035070265643298626, 0.02999096962490252, 0.01311742965065475, 0.029853165947965214, 0.020304948390860642, 0.040477691018687825, 0.07030745090118476, 0.00574574717653117, 0.015512942403022732, 0.012302013762694384, 0.03957677632570267, 0.019664898182132413, 0.0561944890900382, 0.007713341819388526, 0.030543307308107615, 0.0620471623593143, 0.037710221484303474, 0.03462984213339431, 0.015612758296941007, 0.044618260980184586, 0.08621735325349228, 0.03780070412904024, 0.04521696296121393, 0.0396868041716516, 0.047608595341444016, 0.042453551066241095, 0.03617839136027864, 0.0032892754742143942, 0.06403339042195252, 0.09164166397282056, 0.031161442532071044, 0.037920496093907526, 0.04327655976106014, 0.02879445454371827, 0.034421745621200116, 0.03372956865600177, 0.03304907606382455, 0.013996261421457996, 0.07875512367380516, 0.023637213511392474, 0.015717042343957082, 0.03402513851012502, 0.04083923822534936, 0.052332481502422264, 0.09455804140972239, 0.06941996780889374, 0.03943380560459835, 0.06120339049292462, 0.042860085144639015, 0.05219998736200588, 0.055257961486599276, 0.067510712758771, 0.04162254922890237, 0.019571499533153007, 0.040897449744599204, 0.07373349634664399, 0.035149396397173405, 0.04081191362014838, 0.0344122155968632, 0.0029967874413289663, 0.05690332408994436, 0.027354979821081673, 0.040890586362885575, 0.049782380661261935, 0.012719031207130423, 0.055618826765567064, 0.051160173158028295, 0.05409953257601176, 0.005678918262544487, 0.019334797680910145, 0.024328593197943907, 0.01818478260455387, 0.03324544070554631, 0.05455381516367197, 0.04641014304278152, 0.033942849175738435, 0.0270148149491953, 0.04372496962813394, 0.02822738077624568, 0.017117177302549993, 0.02449524139852396, 0.04361490785543408, 0.04278008247326527, 0.033458880681012354, 0.05816974863409996, 0.033091335224785974, 0.08734406065195799, 0.014432556893942612, 0.008304368721188178, 0.03173897761319365, 0.0416915630256491, 0.011339686561508902, 0.05644733498671225, 0.014472173161006399, 0.0596041309514216, 0.03703183574335916, 0.03767398092895746, 0.02391103801450559, 0.01284970432919051, 0.007796299510768482, 0.022515298266495978, 0.016775553580373526, 0.06354314887097903, 0.024656359538702027, 0.03031131618523172, 0.0100154432002455, 0.026728125422128608, 0.03611022233963013, 0.018311431165784597, 0.04507360208247389, 0.052312189912689586, 0.04165935296831386, 0.008162581195522631, 0.023794698096545677, 0.04589972525302853, 0.04263206005894712, 0.03528766147792339, 0.031337820924818516, 0.021882935859529034, 0.07802337793899433, 0.02907886928213494, 0.015500737254374793, 0.08192521213952984, 0.026185791041435938, 0.06064551257129226, 0.03099033296374338, 0.022077965483601605, 0.04080263804644346, 0.030235656137977327, 0.030243896945778812, 0.0698963672454868, 0.06270711908915214, 0.03633262576269252, 0.02653542486950755, 0.07156314102134534, 0.01760857575573027, 0.022738824665014232, 0.023179857160097787, 0.016190234006249478, 0.032315457572362254, 0.057512818170445304, 0.025107320697445954, 0.013998923823237419, 0.026244501283924495, 0.055798814964613745, 0.038546003600848575, 0.025177184359303544, 0.04830687233646001, 0.017072887625545263, 0.01807129762268492, 0.031585747442607365, 0.08021562280399458, 0.02338786207006446, 0.037973903585225344, 0.03608833279992853, 0.034712236640708785, 0.022535248892381787, 0.014150690902689738, 0.04583545780873724, 0.05952820288283484, 0.011474534370271223, 0.032646060189498324, 0.03807147352823189, 0.06384781787970237, 0.04598976006465299, 0.050717381560908895, 0.020480875557820712, 0.054039553473038335, 0.010597498172761073, 0.10138893486665827, 0.025875663218487586, 0.03447458314310227, 0.03353347882096257, 0.01633384424660887, 0.05129384455670204, 0.05560430950884308, 0.03327239550916212, 0.022355533803680112, 0.03290925035253167, 0.038146780737276585, 0.031982554721512964, 0.036931388811873536, 0.05901022282029901, 0.013134313298256269, 0.027574509648340087, 0.015622669997225915, 0.05634275238428797, 0.04402793551396046, 0.030789622305227176, 0.02752282902864473, 0.019055276876315475, 0.024732426706967608, 0.027896683164206997, 0.012893189094029367, 0.05902148650160857, 0.022048671430509006, 0.0797274372141276, 0.09308759495615959, 0.016057593980804086, 0.07398018453802381, 0.03474956963743482, 0.016374062713501707, 0.07882003911903926, 0.02997048126001443, 0.012875310544456755, 0.0621085629931518, 0.041501088067889214, 0.0376799859638725, 0.024194967600383928, 0.03537032739924533, 0.04508919142452734, 0.030762297700026205, 0.011683459543356938, 0.008896431237060045, 0.025094961182081273, 0.09570184789065804, 0.04984163033909031, 0.022023585990869572, 0.04421315861067601, 0.07444283006978886, 0.051217227775071344, 0.026956581377557347, 0.013456309546849557, 0.054018671557839425, 0.031586422584950924, 0.027395917535094277, 0.026009244711271355, 0.025303402050797428, 0.021691636481721486, 0.02238092797675303, 0.01924580442053931, 0.016065822914242744, 0.04180519049987197, 0.03042286055694733, 0.07618797464030129, 0.05231847993231245, 0.03506279158006821, 0.05937141379607575, 0.043386645282485654, 0.046011228912643025, 0.018768159872187034, 0.03077370048101459, 0.05712911340274981, 0.09542522951960564, 0.043021121860614846, 0.0271288257957037, 0.02485811853382204, 0.02651184408127197, 0.043457345238753727, 0.059988432829933505, 0.011002668395771511, 0.059643709899059365, 0.027867764001712203, 0.06538208055176906, 0.020375302294269204, 0.018470958141343932, 0.01562133158690163, 0.012936458423999804, 0.058185599212135584, 0.025791487556749156, 0.02907392954719918, 0.03203905633251582, 0.06294909146215234, 0.02316360963907625, 0.02745623929825212, 0.06576117806668792, 0.0281122791846948, 0.030235381331294775, 0.04106851860082575, 0.028115644718387296, 0.04238471368859921, 0.030850364760096585, 0.06831134336867503, 0.0720627802823271, 0.03885507969451802, 0.06149391204650913, 0.021445038196231638, 0.011768825185884322, 0.04389149908508573, 0.020556262494730096, 0.07389055684741054, 0.032264458880360634, 0.0621687558346561, 0.014332038716280034, 0.03270371870270797, 0.037700155417301824, 0.02694653905928135, 0.1047333525493741, 0.02553206156673176, 0.030055081006139517, 0.034270869967128546, 0.02176584446403597, 0.14006713405251503, 0.13142506778240204, 0.08268285755600248, 0.16072642191180161, 0.14227877823369844, 0.11446705274283886, 0.14933322183787823, 0.14846152147012098, 0.13037124861563953, 0.1395054291933775, 0.07907824204968554, 0.16818747084055627, 0.06362225926880326, 0.09918542632034846, 0.15283453038760594, 0.1771162317267486, 0.12000567625675883, 0.10766060011727469, 0.2206774606768574, 0.16718389040657453, 0.09655001666396856, 0.11012920551002026, 0.11806946301034518, 0.09800747595727444, 0.19865977285163744, 0.13474389112421445, 0.13356438013059752, 0.11447799072733947, 0.10903411105807338, 0.18052409243370804, 0.1246536411345005, 0.08710542667124953, 0.0795933451237423, 0.12786471311535152, 0.18056249751576356, 0.14702001453510352, 0.17182511064623082, 0.10342186649463006, 0.11313365000699248, 0.0951766414301736, 0.1478452623954841, 0.11233371150280748, 0.14830228287194455, 0.21893500989036901, 0.0608314447371023, 0.17503297994179384, 0.14526293453361305, 0.20975194764988764, 0.206371187631573, 0.10034057112144572, 0.10782249178737402, 0.15213322373373167, 0.07659425426806722, 0.18934261852077075, 0.15129790641367435, 0.11646989812808377, 0.11010797414928675, 0.09723213434751544, 0.21308698797864573, 0.13713925544704708, 0.07647050983671631, 0.0923972534281867, 0.09057371092161962, 0.14227337709495, 0.14473207587642328, 0.15481201213385376, 0.2219376087720905, 0.1045494084911687, 0.18429990911058017, 0.06555517483502626, 0.10552406976265566, 0.11394003459385463, 0.17541647436363356, 0.14543129264244012, 0.065831223236663, 0.15802168633256639, 0.1205357885254281, 0.09637851015265499, 0.13238725758024625, 0.18301895713167532, 0.2019777683807271, 0.2111508697271347, 0.06590711059314863, 0.1578841201428856, 0.12498069501348905, 0.08440287597477436, 0.12287791499069758, 0.09678105783781835, 0.15776515938341618, 0.14585910897169793, 0.17806548864713737, 0.08417608243014131, 0.10889385108436857, 0.1269358800990241, 0.11297990075711693, 0.13423261498766287, 0.10994201126907553, 0.08696891899619784, 0.14585403352975845, 0.2470845372549125, 0.15655257659299032, 0.1304496465516942, 0.1530472104038511, 0.21053324001176016, 0.1561411672404834, 0.18883400224149227, 0.12838288316769259, 0.1845458373427391, 0.09799252783081361, 0.13208444097212382, 0.08769398116107498, 0.1701206849621875, 0.10979255714586802, 0.12533670876707348, 0.17966194583901338, 0.14812682728682244, 0.15405928609626635, 0.09806023884032454, 0.1247308041368212, 0.1373813296003001, 0.10610045811959676, 0.13018615783325263, 0.15958428462701185, 0.14663768719349587, 0.1786187525306429, 0.16099147126078606, 0.18254396904792103, 0.15493868105113506, 0.0932918136407222, 0.1674140223434993, 0.09892384428530931, 0.10502544830420188, 0.08550641818770341, 0.13537087105214596, 0.15881296672991344, 0.182777927922351, 0.08886521402746439, 0.10131907290113823, 0.10781518396522317, 0.08455909509211779, 0.09828063379973173, 0.08708233612456492, 0.14846308210066386, 0.17453208539102757, 0.08455431142023631, 0.07449532153883151, 0.19444590753742627, 0.11293998932732002, 0.09322550041334969, 0.14482772217265197, 0.13646851001041277, 0.10399072989821434, 0.1441792326846293, 0.07479682178901774, 0.13203554573868, 0.10144865951899971, 0.15214969856398447, 0.17405325679906777, 0.15322486444243363, 0.1468445182378803, 0.11345083120145968, 0.0772392764421446, 0.15571754425764084, 0.08666361216455698, 0.17678365457270825, 0.1460870967379638, 0.11059926064418894, 0.08650534387145724, 0.12197536842099257, 0.08550715100552354, 0.09334727709314652, 0.14108899421989918, 0.11522182795618262, 0.23375748523644038, 0.07789474127015897, 0.09133460652083158], [0.0377546383866242, 0.10146034389202084, 0.08010103859539543, 0.028512489316718917, 0.023737655353865454, 0.06065491706665073, 0.0571584871837071, 0.1156806397650923, 0.10633289707558495, 0.06155305315873452, 0.04821092409214803, 0.0656819658886109, 0.03783906510631953, 0.03142453770020178, 0.025404829465384995, 0.011453526077925094, 0.059489295684865544, 0.06121396885386535, 0.07788380328565836, 0.025675890634634664, 0.0026908813784497655, 0.058048419787415435, 0.020249673231903995, 0.02316533142168607, 0.0223172847846789, 0.02039817231707275, 0.0035845376551151276, 0.023627125392002717, 0.06204732520771878, 0.009036588582343288, 0.03347032078142677, 0.024956441650699292, 0.04716637371374028, 0.026174037118575404, 0.028205654084948555, 0.03643768333962985, 0.050137373219643316, 0.09441698076469557, 0.02197890106721648, 0.04911006780873452, 0.029166994017681906, 0.026407278442223157, 0.06660563525344644, 0.04590386770931738, 0.01986176663610552, 0.02647535246796906, 0.05364598280617169, 0.0913759089474167, 0.003083943568136809, 0.07138889322855643, 0.03324053489736148, 0.05692036210426262, 0.011740131636283227, 0.03549545943470938, 0.010845257601301585, 0.049589181385402165, 0.05310070527983563, 0.05817491907094206, 0.03225313752357449, 0.03219130941267524, 0.03160523496834295, 0.03186754982120224, 0.02830477787314781, 0.032461566517927816, 0.05897106456437281, 0.12086103750126702, 0.009203735506162047, 0.09541417618415185, 0.055226267115878205, 0.06498550397476979, 0.0320765148582203, 0.028407148451411297, 0.03400358145258256, 0.04427766014954873, 0.05167236192417996, 0.030928460748067925, 0.04589801534478154, 0.018719301958169256, 0.028455855391387428, 0.06858752747731549, 0.03651099565571972, 0.010669694298745265, 0.03531936602666974, 0.05142885266936251, 0.043254700755434375, 0.096541663897889, 0.01954504514911345, 0.043178993210728676, 0.05020611560238259, 0.0543084602936038, 0.022713752796075175, 0.03474113205447793, 0.017370323450969796, 0.00884300678236676, 0.054543012886175087, 0.04087409456925733, 0.0269136555559401, 0.041679152620158026, 0.04613035252051694, 0.021612236010176793, 0.049072236088769774, 0.05777608975768089, 0.006712014969837452, 0.04365911780457411, 0.009119159508762615, 0.0303371310500162, 0.05990949885121413, 0.03425822885973113, 0.02343007712624967, 0.05278478616050311, 0.007676925693106438, 0.05237678983914001, 0.02730171482211777, 0.051305718919528384, 0.044726429640182426, 0.03778448035674436, 0.032325706843818934, 0.015607989892097456, 0.03586084036422627, 0.0647956363058516, 0.06304796079971961, 0.01226675623495664, 0.03122694491009627, 0.02037086128257215, 0.02744986955076456, 0.021726462291553617, 0.042369735028062544, 0.058186745936317105, 0.026016247192663804, 0.047509841354829926, 0.028723662985222678, 0.025460498174652457, 0.05942650405423982, 0.033578896562435796, 0.02479400036723486, 0.056462503637054136, 0.07547010494662182, 0.028317754855379462, 0.016541944151478152, 0.021674673106255274, 0.017266665352508426, 0.055610769162220616, 0.034597920453441997, 0.012007230161023992, 0.0321812908431249, 0.029160948270665746, 0.034933808858373334, 0.02139513873096023, 0.04903896751680544, 0.0707759725462113, 0.044036362918892076, 0.0177986045767154, 0.10412588050322873, 0.042025066379989894, 0.01298403475500111, 0.03399604971387556, 0.062133180243628364, 0.03527721882398639, 0.05619196154709373, 0.022739798362765993, 0.006999227817037276, 0.031193021551838944, 0.03260910377970763, 0.01860225636378995, 0.016202871720971804, 0.016568999039009213, 0.04009703626590116, 0.050563924081091366, 0.012367795188246029, 0.04643273825890251, 0.04532504680433443, 0.04266207505549703, 0.025859507299693565, 0.0551935888693801, 0.03130014526790806, 0.026936639233359268, 0.015277996260140623, 0.015899971992309605, 0.03547153428995183, 0.02691513136960566, 0.03679547146228807, 0.03836529954735722, 0.09991874625640255, 0.09729905825640474, 0.05197147033842547, 0.019310448451765945, 0.05280543737379568, 0.06073798332363367, 0.06108166131057909, 0.028817684190081697, 0.04311199466298733, 0.048165611523602686, 0.07177987867700202, 0.018145020452461073, 0.06139676618788924, 0.023265454352700284, 0.010171088955498167, 0.1019586260829653, 0.039206720289907286, 0.04704806774056383, 0.023383733184475983, 0.010832298430614173, 0.010040648231681968, 0.03448670177853533, 0.019408125264037932, 0.003887910661952836, 0.03930521982588938, 0.05371377523988485, 0.015837287230949317, 0.026321326715073416, 0.047284072398075035, 0.007785175777306514, 0.048753891206745587, 0.027728564238974025, 0.054686835168727806, 0.0551580472051033, 0.04090390939797674, 0.009915627306327224, 0.08992020027445895, 0.013173022024732615, 0.01202484408193933, 0.030929088392960172, 0.05189631240708487, 0.11078027343111378, 0.06930818594992161, 0.04070268305284636, 0.01983155825707529, 0.053977681257362874, 0.028927399909922054, 0.02584576018021575, 0.05763753969222307, 0.01705228560604155, 0.05155463270576937, 0.03579592831166727, 0.06138342618942261, 0.05299687585128205, 0.015403766118522202, 0.02615096353526626, 0.010216357419267297, 0.04980397164555533, 0.04811644148347633, 0.04637468280270696, 0.03854868381417223, 0.052070095403386016, 0.057582449434059005, 0.057425646776599545, 0.024481965860884105, 0.06188625456499202, 0.02117946128627019, 0.027789349102282097, 0.010408000305428036, 0.03084053278767637, 0.05107867092426334, 0.01743653489808951, 0.008497456038769866, 0.015123202066336359, 0.03629365749657154, 0.027752180650298084, 0.060695357753762176, 0.04888420385707702, 0.011455870416414524, 0.09791096113622189, 0.018888696529237286, 0.07290292877171721, 0.01055181325812425, 0.051960891977484734, 0.04442326019385031, 0.027458191782768284, 0.07903973518737725, 0.025516923450465714, 0.032355660772217174, 0.0887013478204608, 0.024197861552238464, 0.0319388095688607, 0.0638622028220977, 0.011524634851541902, 0.035323284566402435, 0.020207361484478627, 0.02279221180028149, 0.014073947743911828, 0.01647943750556026, 0.06073850579559803, 0.0046447804280822826, 0.014547432872599788, 0.04355042327993682, 0.06976085701691252, 0.019095785416928784, 0.048184488367821486, 0.03257004730403423, 0.008388768299482763, 0.048834575805813074, 0.07853942417672702, 0.06253712571093015, 0.023927824970866953, 0.08547224716416427, 0.023800884639578204, 0.05190141159775002, 0.006180146143638662, 0.005780859243324292, 0.017124985544277087, 0.03185730054974556, 0.052290690530623705, 0.05313913071794169, 0.008967231277243366, 0.021007457748055458, 0.02477308452528502, 0.032373903186193535, 0.04344678044851337, 0.03131636564752885, 0.027408322851572717, 0.01550084921265287, 0.03479538092921887, 0.09284355983670269, 0.043764650356024504, 0.04050409960161362, 0.056376862339675426, 0.024216531443276575, 0.0544248799394284, 0.011936952592805028, 0.0423961130769125, 0.012970561594037073, 0.014194468285755386, 0.056562404347849746, 0.06165667902678251, 0.018942578995068158, 0.05036659252696803, 0.07066692518336432, 0.023586364097094963, 0.0652104586895023, 0.050954617759478946, 0.03331616780321513, 0.017645644123799036, 0.04418310629470008, 0.006117718377416688, 0.04270089404391391, 0.044972507150045464, 0.036906825844198465, 0.012075174416947578, 0.0752313556149602, 0.021225467656872103, 0.04217574525890606, 0.04229624290019274, 0.05020328611135483, 0.03011671912723354, 0.029530278273991177, 0.012233069515787065, 0.05056253308430314, 0.05988239137721913, 0.0673940454476646, 0.019802152245704616, 0.06950889660843781, 0.03567157319879957, 0.16024699620902538, 0.09762478899210691, 0.12099921437246458, 0.13776410477502005, 0.15025418384798936, 0.13009792113942759, 0.1582959908992052, 0.22098197362252645, 0.11145577539822885, 0.13724531047046185, 0.07583699561655521, 0.1470832811402423, 0.17756432268236363, 0.10130951234272548, 0.10417196660169534, 0.10151635017246008, 0.16341109999588557, 0.13109117427042552, 0.19325700561915124, 0.12251816929451056, 0.1266739112990243, 0.1373809360499893, 0.09498645484979663, 0.1030662055792553, 0.17105376560773167, 0.11088149728519575, 0.11326068533318383, 0.10813356616667338, 0.12048248281436306, 0.05505723386470761, 0.18504484556615353, 0.1537857007767473, 0.08226152123617274, 0.09644301847687789, 0.10549220575817994, 0.0907704114381756, 0.14388079941272736, 0.1371218849505697, 0.15206209969307694, 0.12318795121141843, 0.08740060297506196, 0.164854533970356, 0.15157079962747438, 0.13116254258368695, 0.0996642956244094, 0.1516202919717346, 0.1356136780232191, 0.1825140185121979, 0.13281753020627157, 0.1539393618170704, 0.10876959775175367, 0.14978357910045556, 0.06371040775307588, 0.1472141026918377, 0.11287262437066861, 0.0997095267687525, 0.10470408054866961, 0.1102518235732402, 0.18891143665782043, 0.1791338420339993, 0.17089311565671647, 0.09869633827890668, 0.10490493369953972, 0.12702361467693532, 0.12845896051398345, 0.1794510164431163, 0.20122755292270864, 0.3021433385355132, 0.11273530245359455, 0.13828475826552936, 0.12118800995605332, 0.15814344265631267, 0.1288569891559226, 0.07489094816680465, 0.1512606276997498, 0.12439919050250735, 0.13035849215728895, 0.10886945775044815, 0.15854151201035294, 0.10801552142947912, 0.0874514931014606, 0.11554954679948942, 0.17103274459285395, 0.16019877951060021, 0.09449100214987993, 0.27770560128348215, 0.05812698057187455, 0.16259654584739888, 0.1397145672568253, 0.09178585266428334, 0.1147962643631867, 0.11256355845502444, 0.09439209210021154, 0.07383858785033226, 0.1044680317863822, 0.21701814846268722, 0.16109796054661274, 0.11369813685970646, 0.10049911082855292, 0.13379048156951154, 0.08694827796093055, 0.1403797079942056, 0.1198130537356649, 0.16480935710881436, 0.10171912357743297, 0.20307738866124833, 0.1688437227691923, 0.12358082298721586, 0.10418631083198956, 0.21856618539563247, 0.08746110794267484, 0.11938014839376722, 0.14849709027579852, 0.1329021028109959, 0.12499448284506798, 0.14352095872163773, 0.15999156848660537, 0.14455020135002478, 0.13963421513991697, 0.1624842754432133, 0.14932919133986744, 0.16095774807035923, 0.10712293575384788, 0.12232444754668645, 0.09497929630534989, 0.11831878391759736, 0.17254726189587796, 0.09264908491500787, 0.07828095661742346, 0.1116952643330608, 0.08568900517587151, 0.10145560093224049, 0.15634331639323915, 0.1660061436040061, 0.14310771732458047, 0.17297951584415777, 0.2548424723957266, 0.1560965467776571, 0.08000715649021523, 0.14396666123398713, 0.09533279947936535, 0.1215176558388131, 0.09002960047551564, 0.11649903442178454, 0.13297192406441483, 0.09250299632549286, 0.13078041880258492, 0.1694748553314379, 0.08205042899187122, 0.16877656137304647, 0.11292531261486666, 0.05701311784131186, 0.17468471505812236, 0.12112862457122121, 0.1100721542856523, 0.11901699645178658, 0.29673384023564203, 0.16369269202862466, 0.15984604986650602, 0.08848246599414519, 0.25041188299655914, 0.06853800120630435, 0.17913686830018247, 0.11552480741270951, 0.1493295170366764, 0.1302080609436546, 0.11659886049372808, 0.08842599152454308, 0.08759831450879574, 0.09899507689156703, 0.14674153019274983, 0.14547368751040526, 0.14046091506523745, 0.16191461815365724, 0.13879705220460892, 0.1263875016676528], [0.04104453917326672, 0.04072785670203822, 0.032548334183437486, 0.06259620575500385, 0.02691628148646227, 0.021385154088160822, 0.007219525237035538, 0.013399436437923993, 0.04241652001759835, 0.07836945793990578, 0.028475159712667977, 0.03369398967229894, 0.02283016565654959, 0.005509567372168281, 0.039762464218905995, 0.01838677060524268, 0.013813431008851953, 0.0328182689845562, 0.083136933190482, 0.015001586538606455, 0.031036653156791414, 0.03207331895828247, 0.06681686999010188, 0.0487155811195927, 0.02401751881864454, 0.0227442376781255, 0.03049161990306207, 0.07451482263526746, 0.016269174770319035, 0.01125857702988599, 0.053003820657197914, 0.04128872696310282, 0.03206622148198741, 0.009059190583814467, 0.033985654557389874, 0.022101307088243108, 0.023828718146043162, 0.032624306356800456, 0.03448650500337992, 0.03298867626913956, 0.029088806427483047, 0.009471413330174983, 0.021770763842921172, 0.015460181216310178, 0.029268852302006314, 0.0337863348956619, 0.014801221932949764, 0.043911783889468224, 0.055753712741924186, 0.05039287558091538, 0.0738537327519485, 0.015273526410705276, 0.034730964207223484, 0.02132897138861673, 0.1005979258833187, 0.05184286081099084, 0.04405019824792232, 0.004043662438302168, 0.0510108174223985, 0.03031736871759806, 0.04527797683009079, 0.06555714937193052, 0.0099013687410791, 0.037732986334179125, 0.011658420753000038, 0.028441076898681264, 0.031038953390504633, 0.019705817236432006, 0.044758029016000886, 0.08203375738646303, 0.04102036636322737, 0.01845864442709301, 0.01577100114497755, 0.03903194323980382, 0.02059269473621888, 0.06187966598996094, 0.023321289303047315, 0.011849815125710197, 0.024870045483112335, 0.0282157744347517, 0.009043387503230145, 0.03666451081101384, 0.053642128727265766, 0.011319405997970274, 0.05711603803294046, 0.08980024885386229, 0.017806786012702754, 0.029433573463133404, 0.03052191309896963, 0.029779582217867886, 0.010247234155290892, 0.02810917149430939, 0.027039008115285208, 0.057771116095994196, 0.02053078859379249, 0.04341499447556479, 0.02720928647821503, 0.035959356863583834, 0.055686982215515206, 0.017506800591945648, 0.00836517902955945, 0.02212333063861089, 0.02271757634090526, 0.03736853839031287, 0.010133713550333465, 0.02822997447635446, 0.046703463553317955, 0.02699460817633995, 0.040528262233627696, 0.044898668969316144, 0.06442074570804834, 0.03735310511131372, 0.06047053874603339, 0.04853281092696956, 0.018950938546497906, 0.0037879828097564833, 0.07968759363783257, 0.049860110240323205, 0.08142533539129154, 0.01687578677332827, 0.03360533907211252, 0.022255008840667348, 0.04474837685536061, 0.03072056101102914, 0.022492090672520653, 0.08590078952589206, 0.03159096198422568, 0.04667991499549576, 0.020696715850915228, 0.035962708826575956, 0.05596749198489955, 0.02951345399820379, 0.05478698015213013, 0.011602641781792045, 0.0051924353714899295, 0.03795725233586771, 0.015384100477344223, 0.018084483254434805, 0.01615929450573666, 0.03141395255391087, 0.05105418259544032, 0.06506923519607101, 0.01087690023372748, 0.04518432203414185, 0.018806631111406853, 0.016293542659176246, 0.05431017359452588, 0.013321903634018131, 0.02488162977221821, 0.041578298567661216, 0.011452862809944366, 0.04538747202605009, 0.06155885463314397, 0.05483049799555114, 0.018619715069819773, 0.07854732232434408, 0.06841956970414945, 0.03177584242075682, 0.006185892487077841, 0.03221629646473697, 0.06612831979457821, 0.02704787317530385, 0.01634036496813808, 0.06424799747765064, 0.006759816489648074, 0.022143048866252815, 0.0547113879583776, 0.07106712513736316, 0.0853907483230744, 0.0383590841665864, 0.06316548306494951, 0.04065613215789199, 0.05682381674913423, 0.04538745506267462, 0.029270345079047338, 0.018490265855299573, 0.034510721918195486, 0.02775756312933351, 0.058769953570195606, 0.05778825589056526, 0.07030357646622828, 0.05159469341327037, 0.011550343695229717, 0.026815293423299278, 0.037627273970948796, 0.01637669712571161, 0.050326148447181494, 0.04305102829156177, 0.03177346754819155, 0.07157829270831176, 0.11682177281805448, 0.009510351910388895, 0.045395987640534124, 0.03089903268430914, 0.03995450319988387, 0.0140028364257887, 0.06955131183245353, 0.05034193117171526, 0.024091158527880907, 0.028423733543604612, 0.0740193495793002, 0.014202328265777655, 0.016263324102120738, 0.04858979429783566, 0.05021527921780944, 0.008113939564542046, 0.04610000504180789, 0.018034532899037004, 0.037263691159231324, 0.03981354772778494, 0.04723407454522593, 0.022918680549732277, 0.08242601848074368, 0.016242611820676496, 0.029376474741314138, 0.03777093001242195, 0.04588513335745249, 0.0066810716525651515, 0.03428799958367433, 0.017076327798089812, 0.056725870219192336, 0.02852813633424895, 0.028615070240838186, 0.008353492960200777, 0.011255803517997265, 0.03337582799472979, 0.03934504304613386, 0.035664638570908985, 0.024687672233475105, 0.04266568825447133, 0.05240125781191247, 0.025143028602802327, 0.05777269708258765, 0.027860485017299652, 0.02632969814086599, 0.025400776914986115, 0.035398788550602536, 0.019377299418140734, 0.020908216912565485, 0.015310543888647641, 0.020398589616109217, 0.05958980029182775, 0.0389287889535938, 0.054882195578621965, 0.021818485210782716, 0.08262624059404645, 0.04121014582259314, 0.02026310483259814, 0.07696359444941793, 0.05327513288440449, 0.005195100741860057, 0.07802596994276557, 0.03748467644410474, 0.021430732981700982, 0.03780527066971574, 0.05295572270240102, 0.06649692715810877, 0.03681496577337384, 0.04631850349583796, 0.043170589554522715, 0.04308060224034956, 0.061859995259770324, 0.03735352919570037, 0.02487121765235705, 0.0507555355850075, 0.06841436534055642, 0.04389670005600367, 0.057138952160520215, 0.011303200885387403, 0.05879467938627515, 0.026299980003386736, 0.05007460194506815, 0.02037523444076734, 0.05057422763534954, 0.026889737196532742, 0.026659796945750713, 0.023407052736729383, 0.03278962802141905, 0.02429237130231091, 0.03811800067446061, 0.02205235417932272, 0.021169223889176334, 0.05353941548881786, 0.004074710504417973, 0.01920586415300412, 0.10065111624343054, 0.10639040291841541, 0.06611470159675394, 0.04957121717078345, 0.013552313770300575, 0.014543823066300579, 0.012829924185228134, 0.012157325499824114, 0.04550244978496006, 0.04083792186741318, 0.022224386555275748, 0.0547075203087713, 0.04058634822389909, 0.02621281030587852, 0.018330771110153625, 0.04210997825222356, 0.0430721001965659, 0.012481423510637666, 0.021288518827142458, 0.05142553124044623, 0.03124580139826451, 0.06688973108040434, 0.01932289108767041, 0.021074554683374505, 0.04704451560974121, 0.01284346095885017, 0.001726944458953637, 0.03924949174480779, 0.019548095164022276, 0.04571614081838301, 0.012038636154362133, 0.03937141091695853, 0.054887287983936925, 0.025036098269213523, 0.0732454736051815, 0.031304124875792434, 0.00923809312683131, 0.03719203446858695, 0.039601709094962904, 0.032787972395973544, 0.03960118323032345, 0.023870987485029867, 0.06513496488332748, 0.01841734200050788, 0.04300282855651208, 0.03593044448643923, 0.03061939822509885, 0.06981079719428505, 0.05804079983915601, 0.007561496708409062, 0.04327527732987489, 0.07169829162635974, 0.04471210915861385, 0.04086423545543637, 0.009526757190802267, 0.04510958479451282, 0.02142859559639224, 0.021365649599049772, 0.017376087605953217, 0.027352954394051006, 0.07811252386974436, 0.0338992906202163, 0.042443298402109315, 0.07160265890083142, 0.05159908014216593, 0.010376687610654958, 0.024201118520327976, 0.10357388548020806, 0.12817271373101644, 0.2056906848613705, 0.16597889363765717, 0.13425211608409882, 0.12999365744846209, 0.15136436213340076, 0.11655512212642602, 0.07805134036711284, 0.1367746242987258, 0.10446407592722348, 0.10353298338928393, 0.10310765728354454, 0.10057699307799339, 0.17569433445377008, 0.1419097501784563, 0.08698747014360768, 0.11227654492748634, 0.10649689220424209, 0.10548084708196775, 0.23736935428210668, 0.1249328718653747, 0.1425568283136402, 0.21590662667793886, 0.1372490017009633, 0.16330699915332453, 0.13958450566445077, 0.14230247267654964, 0.1059660403324025, 0.06953949853777885, 0.06871474600796189, 0.12286699057689734, 0.08785927907696792, 0.09692311592932258, 0.14806746904339108, 0.11167256733668701, 0.1504275088331529, 0.08678435068577528, 0.07639870047569275, 0.08568811629499708, 0.125512870028615, 0.07319600840232202, 0.13297598170382635, 0.0932056668347546, 0.12743563471095903, 0.1568928211927414, 0.10951870719769172, 0.11646613904408046, 0.11273836264652864, 0.0902938898652792, 0.1465632247605494, 0.17789851474974835, 0.06546235124447516, 0.1227452206824507, 0.24127160917435372, 0.11533527901130063, 0.14882339776626655, 0.13128638879529067, 0.10481504816561937, 0.07219311328870909, 0.17250945392463887, 0.0936686380633286, 0.06182088450129543, 0.11723500064441136, 0.10911429354122706, 0.23376250639557838, 0.10215057685439076, 0.1001025681783046, 0.10563764973942723, 0.3108435959688255, 0.19880172237753868, 0.10179206609193768, 0.13061588763126306, 0.10156151346330132, 0.23268018875803265, 0.16815300126160893, 0.104736514522561, 0.11726602326546397, 0.07795996205615145, 0.14582214238388197, 0.24558076794658387, 0.10762771831027099, 0.13380412012338638, 0.07371550838329963, 0.13868300403867448, 0.2879048782799925, 0.06808648364884512, 0.12501724090959343, 0.16949009522795677, 0.10106263416154043, 0.11118591523596219, 0.09508402818547827, 0.12021509930491447, 0.18438425101339817, 0.09258908206330878, 0.1274019115205322, 0.11982047690876893, 0.10864390592489924, 0.153478012287191, 0.08307623144771371, 0.06992800054805619, 0.048847111740282605, 0.13584086511816296, 0.13500640275222914, 0.13314531690308026, 0.13078994543424674, 0.14978770459336893, 0.1714779314185892, 0.11723867830421243, 0.19685280695557594, 0.17237628464187893, 0.22058881686202117, 0.12533919220524176, 0.07949691851224218, 0.1048131821943181, 0.11899939525340285, 0.1305768582969904, 0.15672485663422517, 0.11575770777251039, 0.09169295443488018, 0.1760984563401767, 0.1413882417338235, 0.17455541342496872, 0.10065115695553166, 0.11063972168735095, 0.13126212438302381, 0.07853576008762632, 0.07483160349407367, 0.08586032848273005, 0.075510681340737, 0.14573235863021441, 0.08688299610678639, 0.10504753461905889, 0.12541507956172737, 0.12375205808452197, 0.08046520833990403, 0.0992345115435975, 0.086944037117064, 0.10363338621599333, 0.06549694295972586, 0.17425985714154585, 0.14561649199043, 0.08343587536364794, 0.18871790489980153, 0.12633701866226538, 0.08855911330985171, 0.16337834032518522, 0.12568257163677896, 0.11372722565595593, 0.10968931804278068, 0.11835067506347384, 0.16060341708362103, 0.16143121623567172, 0.15941364664052213, 0.08698035231126205, 0.15798752887972764, 0.2856400098119463, 0.18959746270307473, 0.12451018526085786, 0.11537175705390317, 0.14660305476614408, 0.2151655171598707, 0.15552921007786477, 0.19950672026191438, 0.1401688057397093, 0.13645420649221965, 0.16823420833264077, 0.14745739820812429, 0.09579896660787718, 0.14365463012031146, 0.15313905690397533, 0.10941174293735198, 0.21843176760843822, 0.15221996765051568, 0.07231972792318889, 0.10330283788165875], [0.04739171519343342, 0.01977147058849888, 0.030309331470302174, 0.028995463757642677, 0.08976571820676327, 0.033980490905897956, 0.007070782727428845, 0.06320999496217285, 0.01767035636917821, 0.023097179364413023, 0.09027925386492695, 0.018786665218483125, 0.05603756429627538, 0.02546300196887127, 0.08289775638175861, 0.03725814752812896, 0.05698611893291984, 0.0671140615429197, 0.04850202579317348, 0.02453940554655024, 0.05460774512695415, 0.014241606961669666, 0.03360321865017925, 0.03715470486453601, 0.02349449384824506, 0.01559655148802059, 0.1509628322507654, 0.03283220948651433, 0.045966910397900004, 0.02830642501690558, 0.04205295077658125, 0.05705750760223184, 0.06603371165692806, 0.022302509684647833, 0.05644265648775867, 0.03678023495844432, 0.0609912940167955, 0.018295660315613662, 0.12364098190196923, 0.03201699037370937, 0.05169699953070708, 0.02516635663674346, 0.06103909680885928, 0.006581688748805651, 0.05637364608368703, 0.049043802078813314, 0.04281635695536222, 0.039074755406805446, 0.02502494993885713, 0.02864437616829361, 0.05672514079404729, 0.051216803690684695, 0.05050269986635872, 0.01208660433933671, 0.03576409823394247, 0.015624130543853556, 0.025661376770585775, 0.04056263003232224, 0.034518070452447445, 0.0614196260326675, 0.05336750524916819, 0.01442951027170888, 0.04929354028510196, 0.03699255874380469, 0.15804007463157177, 0.044570390334618945, 0.02012869213441653, 0.04477088386192918, 0.01494294754229486, 0.06740597409329244, 0.062377921039504666, 0.03738844321508493, 0.0370689142894532, 0.004574672493617982, 0.008291022785540138, 0.0869069891050458, 0.023959822986008864, 0.03399253829515406, 0.018391198046239357, 0.022839529439806938, 0.03955852373370102, 0.05289953661018184, 0.03541536516110812, 0.06348408918295588, 0.011949251888186803, 0.039826090447604656, 0.04288416974512594, 0.03810084730918918, 0.01648531192248421, 0.03360442304983735, 0.07494573308421032, 0.009192843322775193, 0.018553230512355055, 0.06607966204839093, 0.034987409732171466, 0.047897081289972575, 0.0637999540194869, 0.049537704326212406, 0.029883985008512224, 0.043436934905392785, 0.03890959319791623, 0.04319897945970297, 0.031900560549859486, 0.029598457472664968, 0.029135350537087237, 0.011004905016826732, 0.03027945218075599, 0.09570123042379107, 0.08783956763467618, 0.028705339147044078, 0.010305286218811358, 0.05029584846592375, 0.06611509514706475, 0.01858211914077401, 0.027658541121387055, 0.021000309381633997, 0.08577780505376202, 0.046775167741413624, 0.07991316581943206, 0.012734091291869325, 0.04481236270761915, 0.03816388660509672, 0.07051534724554845, 0.04506730867017593, 0.027880394931084344, 0.032659040564405065, 0.046920476015657187, 0.057668487674423625, 0.023074341572022865, 0.020740729024899856, 0.03622413140588573, 0.0040695273450442725, 0.09756630605884961, 0.06282136403024197, 0.03014606237411499, 0.009717836044728756, 0.021348362223112156, 0.08758930356374808, 0.046538986664797576, 0.027029661295403327, 0.06061686482280493, 0.04615425391654883, 0.04664716550282069, 0.08142212592065334, 0.013466101655337428, 0.03510910838044115, 0.06364770433200256, 0.09721114047403846, 0.02481347432227007, 0.009745351487903722, 0.06636516244283744, 0.07672428193369082, 0.0399335534311831, 0.04277806383158479, 0.04638930523235883, 0.018188363573114787, 0.03283703047782183, 0.02079502709342965, 0.02335601333262665, 0.018024872256708995, 0.03633043409458228, 0.023282097120370184, 0.03633240184613636, 0.053767135233751366, 0.01730167436679559, 0.06423065412257399, 0.04440631717443466, 0.01393256733925747, 0.020537034508639147, 0.057865948150200505, 0.08675524153347526, 0.0496683833854539, 0.023195059737190604, 0.04172824802143233, 0.01494542249877538, 0.01686324235717101, 0.014730425285441535, 0.01894290978088975, 0.00470711023081094, 0.027801001244889836, 0.0045868509249495605, 0.027199471469170282, 0.026138366532645056, 0.039328558037855794, 0.040360321423837116, 0.08234400395303965, 0.03617484262213111, 0.08783190697431564, 0.0723861904282655, 0.013236789049447646, 0.004159337391943804, 0.07381097826042346, 0.04244422799508486, 0.057810586478028975, 0.0566072555125824, 0.04748914942943624, 0.023913828489769782, 0.038049468637577126, 0.012415099257071103, 0.026437385041000586, 0.014318317041865416, 0.03008373553997704, 0.02785231375933758, 0.025724054746595875, 0.01759054877662233, 0.012227840555299605, 0.06422445909785372, 0.023153472325897644, 0.06362518375473362, 0.0573003620707563, 0.021443121334803954, 0.06340170146099158, 0.06650305432932717, 0.012006824736350348, 0.06220448748873813, 0.07384512214256184, 0.07600544872028486, 0.008452872047200799, 0.038901684872273884, 0.03321472681792719, 0.016186490189284086, 0.013841943050335561, 0.024730721887733256, 0.0663984174441014, 0.08163838860179697, 0.04384012719882386, 0.0019777853906686816, 0.07019860031349318, 0.02103211740697069, 0.046555804155234776, 0.0397478994647307, 0.008733268161969525, 0.0924657243969185, 0.014416619802692106, 0.03590029378288558, 0.042099715410066504, 0.019791694324729697, 0.017003975609051328, 0.00593972676766238, 0.02935328919972692, 0.0075755839435649765, 0.04766092396208218, 0.02446732816419431, 0.01665514245230172, 0.04248732514679432, 0.047110971329467635, 0.028968200220593383, 0.05011579241337521, 0.02627107610792986, 0.04308230536324637, 0.03079546449173774, 0.03083380850564156, 0.06332578017775502, 0.02620758388989738, 0.028463773895055056, 0.06157653047037976, 0.014688354417947786, 0.051039549987763166, 0.033945152802126746, 0.003653545514680445, 0.028650835821671144, 0.03434301181031125, 0.03632349268134151, 0.06002461910247803, 0.03341673008565392, 0.050500620156526566, 0.04611941792869142, 0.05086760242868747, 0.10003497251974684, 0.05483559379354119, 0.010036324267275631, 0.017179565204839622, 0.03442931467933314, 0.07017230708152056, 0.12061375219907079, 0.02850821115342634, 0.028207828789683323, 0.09727384389511176, 0.058994630085570474, 0.03287140166919146, 0.03775011255804982, 0.014059210811475558, 0.05184265046513506, 0.03441887881074633, 0.031950809460665495, 0.008404931003626968, 0.007987182437708336, 0.005553633556701243, 0.07097945162760359, 0.011729235212052507, 0.10490441801292555, 0.00614155616079058, 0.02382574785899903, 0.021886847613911544, 0.030303377325513532, 0.022299359585823755, 0.039856448104338985, 0.03160523157566786, 0.05721312960875886, 0.030330803710967302, 0.05923357619238751, 0.03156696220061608, 0.030299380754253695, 0.015201119938865304, 0.015464854626251119, 0.007165142351628414, 0.03301393473520875, 0.06943467166274786, 0.010420735559559293, 0.08662194332906178, 0.009295932299989675, 0.05132121665935431, 0.0367049413201, 0.042036160427544794, 0.015653668869552866, 0.03507943604407566, 0.08936080921973501, 0.02466233743221632, 0.04441899560125811, 0.02294584909187896, 0.033091918764902015, 0.0074132732780916345, 0.025498072051310113, 0.07668996163244758, 0.03374263724046094, 0.05475099404741611, 0.03725439862215093, 0.03297004369752748, 0.04317568535251277, 0.05485187863398876, 0.043645391041146855, 0.012033212115056813, 0.06963920247341905, 0.04435069765895605, 0.02172438258172146, 0.004732822043089462, 0.06428169352667672, 0.018378249901746, 0.017382443782740405, 0.03459031068320785, 0.059615089291972775, 0.06997793394007853, 0.021161561532478248, 0.056831246707588434, 0.028167310071044734, 0.0068499314532216105, 0.015804861738745655, 0.025946610840037465, 0.01902294298633933, 0.009731988588880216, 0.04637713231412428, 0.03658555308356881, 0.08107162187142031, 0.11447652509169919, 0.10876427803720747, 0.11942285538784095, 0.12489557958074979, 0.133262214916093, 0.1002074968335884, 0.22643233330122062, 0.13669482858053275, 0.19125937138284954, 0.17204910862658704, 0.14114991309387342, 0.21003192476928234, 0.09659090518419232, 0.12522077427378722, 0.14384771404521807, 0.1506495662033558, 0.12721646789993557, 0.18655724583991937, 0.14921671737517628, 0.1157875768840313, 0.10374412991638694, 0.12165789545646735, 0.12713836851928914, 0.08972862269729376, 0.10445218120834657, 0.25793205946683884, 0.14764502671148094, 0.1457415052822658, 0.10604562570473977, 0.1131120997348002, 0.12697265669703484, 0.15904906977500233, 0.1295096855610609, 0.15963813316609177, 0.15586374141275883, 0.18334972938256605, 0.069815743714571, 0.23761218839458056, 0.11562518988336835, 0.11582503201706068, 0.1352258138358593, 0.17173263989388943, 0.16151759374354566, 0.12658803590706416, 0.07413473445922136, 0.0901272145232984, 0.13518222474626132, 0.120556415989995, 0.06927562983972685, 0.11720889061689377, 0.21298235787877015, 0.19554258297596658, 0.06971429594393287, 0.11604409026248114, 0.1001152228564024, 0.1374845483473369, 0.11564868076571397, 0.08429240368838821, 0.0846506023247327, 0.09300875597234283, 0.15911031434578554, 0.10905620415828057, 0.08752933463879994, 0.16897321439215116, 0.1476842596062592, 0.13666835214410508, 0.09854564243661505, 0.1394498978874513, 0.19903272283928736, 0.09326047210821084, 0.15251523894923075, 0.11858049487429005, 0.1262874991766044, 0.11002228196178164, 0.15845415741205215, 0.1782180368900299, 0.142285929992795, 0.11014215874352626, 0.11555810991142478, 0.14944617077708244, 0.13242140146238462, 0.13260923352624687, 0.14987163937517575, 0.10578774168555226, 0.11294302237885338, 0.1128469282495124, 0.17903922711099896, 0.1357390305825642, 0.13820543752184936, 0.11895773320325784, 0.2522112764418125, 0.10604382080159017, 0.19755669204252108, 0.1008729904091784, 0.1460401556853737, 0.08074588435036795, 0.15531346308333532, 0.1740692566548075, 0.06222003272601536, 0.15398748352059297, 0.283980557428939, 0.17198702267238072, 0.06787666705037866, 0.11008620674588851, 0.042236206121742725, 0.10630737737353359, 0.2499983837561948, 0.1798695639840194, 0.1023094015462058, 0.08962216055286781, 0.14012319461575576, 0.1586085105580943, 0.13266217282840184, 0.14144644646772317, 0.08284911220627171, 0.1333476153335401, 0.1795917988887855, 0.1211900319904089, 0.08836389199963637, 0.12377066351473331, 0.10520172491669655, 0.15857332173202718, 0.13241327261286123, 0.16762135550379753, 0.08329408868615117, 0.11921424658170768, 0.10735059782330479, 0.0814296780154109, 0.07887277486068861, 0.09744801704904862, 0.1573021270866905, 0.1719507346195834, 0.17549956776201725, 0.10718369177941765, 0.12243267388216086, 0.10238054594291107, 0.10238009132444859, 0.14073960296809673, 0.10483670021806445, 0.12312885081129414, 0.12833838484116963, 0.09262072215122835, 0.15710209496319294, 0.11087345664522477, 0.10361300980938332, 0.13563047855028085, 0.17102467002613203, 0.11638992599078588, 0.20998537726700306, 0.11828558998448507, 0.14046875893005303, 0.12002122827938624, 0.08426728432199784, 0.1400140319019556, 0.10907107764588934, 0.1621742392224925, 0.17327822053006717, 0.0958433427980968, 0.0451590432120221, 0.11149865881140743, 0.13290284919951642, 0.11843402630516461, 0.11993582786193915, 0.1451344878545829, 0.10251510622245924, 0.10153238395495073, 0.11363741476088762, 0.05331029456907085, 0.12038448878696986, 0.22352428148899758, 0.07813068825219359, 0.07251861332250492, 0.0836689860693046, 0.15872686063604696, 0.05915306801242488], [0.06301205272653274, 0.033255384636244605, 0.02997613006404468, 0.03553774234439645, 0.04743761808744498, 0.026869269187695215, 0.022671335875721912, 0.03814683502007808, 0.03299712063744664, 0.058441630830722194, 0.053115392170314274, 0.02066061948426068, 0.014426333031484058, 0.015446954872459173, 0.04743979957752994, 0.05583410896360874, 0.035546722755368264, 0.028434832680172155, 0.037241408069218905, 0.02360183808819524, 0.03172968846878835, 0.0360227320343256, 0.020599558117932508, 0.04608591526214566, 0.06095657337989126, 0.06182814482599497, 0.030968080407806804, 0.034968363254198005, 0.03777447196521929, 0.04620479120473776, 0.0588482225845967, 0.019305091417793716, 0.01808917023507612, 0.009208888131459909, 0.07259957612093006, 0.03424528241157532, 0.07660619648439543, 0.02681396688733782, 0.01805173545809729, 0.018976799212396145, 0.009297996742783912, 0.05158113628359778, 0.06391808018088341, 0.047562349787248034, 0.07677520598684039, 0.04882699656965477, 0.019584191530676823, 0.05220667432461466, 0.09084939291434628, 0.05049534793943167, 0.027434120752981732, 0.018184808049617068, 0.0360917627944478, 0.008872833485448999, 0.05407334790964212, 0.020337445129241263, 0.03324946781088199, 0.05181309347972274, 0.01748848693179233, 0.009403799860072988, 0.05297815167744245, 0.021363111878080026, 0.03718531697190233, 0.03712978905865124, 0.004300256392785481, 0.011531297217256256, 0.009633283796054977, 0.037903695566845794, 0.03493813451911722, 0.03728620495115008, 0.10228895050074373, 0.060776843024151664, 0.024214407628668205, 0.009912632422388663, 0.0485024702336107, 0.023851153906434774, 0.038535659334489276, 0.03173641614349825, 0.06242153727050338, 0.02166692423634231, 0.04583147480817778, 0.014143452630378306, 0.051227439727102, 0.03087262749405844, 0.027447506552562118, 0.030595534148492982, 0.025539947839986, 0.04117017671731966, 0.06331843164350305, 0.0493416144911732, 0.02262448303268424, 0.013936255177083825, 0.019076085848999873, 0.02409704990818032, 0.026653951366565058, 0.030420814773866107, 0.018896871179874455, 0.023382427004565085, 0.039748096239886115, 0.07323224217231784, 0.04776129286204066, 0.05118232732638717, 0.07063795173806803, 0.01715936352099691, 0.030859083935086216, 0.07292731532028743, 0.006404996109527669, 0.024061386107600162, 0.09592816646077804, 0.01453988247417978, 0.021334250391061817, 0.033867796417325735, 0.06684650839971644, 0.045917051644729714, 0.05149541695469192, 0.04285251608650599, 0.023465493261548023, 0.03721996296995452, 0.019767175461830835, 0.05878313072025776, 0.033021666641746245, 0.014089649892412126, 0.005670258883453373, 0.05977902335247823, 0.045895671006292105, 0.06136788773749556, 0.011382084822149148, 0.07701734120824508, 0.02145034264373992, 0.03603441301467163, 0.04243626199396593, 0.017364335379430225, 0.032362805745963535, 0.079247997940651, 0.0513574198952743, 0.015690146912155405, 0.04418325896507927, 0.01730175070198519, 0.08314368461391755, 0.025549527058111768, 0.008002940565347672, 0.014849516662902065, 0.06070922700954335, 0.042729131278714964, 0.05910445097833872, 0.05430556973442435, 0.02829601798605706, 0.023098738298618367, 0.04403129765497787, 0.06879287253000907, 0.10410945317042725, 0.0252496230615569, 0.014091614251291113, 0.026786713528313806, 0.016718509141355753, 0.02623145475185343, 0.048556318772690635, 0.031394953573388715, 0.0402967223365392, 0.03622155636548996, 0.021644330716558864, 0.07061337519969259, 0.043644040756459744, 0.028626808896660805, 0.012104728857853582, 0.0287422277033329, 0.060314672466899664, 0.14362200615661486, 0.03832365106791258, 0.039469951165041754, 0.027913151209109595, 0.06199730360614402, 0.0458451676448541, 0.06941278890839644, 0.032013275394482274, 0.05201582617259451, 0.06633204314857721, 0.01965263535800789, 0.026067274722403715, 0.048333850888801475, 0.060744239416505606, 0.03262741404718586, 0.02253653301990458, 0.03054111563999738, 0.07372041419148445, 0.040527285143200836, 0.03630946396983095, 0.009718150715343654, 0.06419140087174517, 0.0547429635854704, 0.014649377670139074, 0.03963114733674696, 0.044455989330474815, 0.07138064902807985, 0.0010477007952951162, 0.018843015855444328, 0.01767652085982263, 0.13214412491236413, 0.024719446332060864, 0.056020400752978664, 0.019079651550522873, 0.06627029646188021, 0.0365989643282124, 0.022264372623924698, 0.03401901812425681, 0.042207673724208555, 0.050203282718679736, 0.0605029184371233, 0.05961097736975976, 0.01241098648668932, 0.06022670718708208, 0.008327964776461678, 0.09421945243541684, 0.010061610722914338, 0.021493792633659074, 0.0754248805876289, 0.09100961538829974, 0.04365685489028692, 0.09612932495240654, 0.06013389716723135, 0.018853590823709965, 0.021163524195019687, 0.030667811698679413, 0.050107571961624284, 0.021438225704644407, 0.026561950499724065, 0.029449576711548225, 0.012133630208804138, 0.0230493969283998, 0.03504634049854108, 0.019320370330076133, 0.00967639875930867, 0.04729415542845215, 0.07505397299038512, 0.02149100385473243, 0.01177000074780413, 0.02347343212126621, 0.009037507997293557, 0.03317989083006978, 0.0392343739845923, 0.0454301417006978, 0.012497174004758043, 0.024782080203294754, 0.0053638731811328656, 0.04392501532233187, 0.039524128793605735, 0.044358056371233294, 0.06695506043199982, 0.02943004508103643, 0.04164373648485967, 0.006415300087870232, 0.00661492975528485, 0.05501641319798572, 0.03156946260215981, 0.03541989777503269, 0.03791301524532693, 0.018260118651336858, 0.09170760400593281, 0.02306795146848474, 0.01695422881415912, 0.015392427798360586, 0.03219728052083935, 0.09125973696687392, 0.03929104862202491, 0.041087972199810405, 0.07553428757403578, 0.022271677053400447, 0.038765496108680964, 0.04746502750952329, 0.01528731593862176, 0.020106113881671002, 0.042077975148069005, 0.03563150231327329, 0.018068636069074273, 0.05604900439668979, 0.025246890261769295, 0.06181261994476829, 0.04456715372257999, 0.04022677555414183, 0.05060168794755425, 0.02748630688126598, 0.020827423747895018, 0.03213735570066741, 0.044806741044989655, 0.028854372578540018, 0.032268499556396685, 0.022640530385875275, 0.03382008522748947, 0.013706975649776203, 0.029087300079741647, 0.05731546626027141, 0.06692884183887925, 0.014367938307779176, 0.060894385645432134, 0.018160126338313733, 0.036719200733516894, 0.022849768533238342, 0.04628764033051474, 0.03212308271655014, 0.07246979951326336, 0.03815940488129854, 0.11116787298981633, 0.026581821397745183, 0.04506005173815148, 0.05479751440829464, 0.010554993891024163, 0.04397185120199408, 0.017735290474125316, 0.026404481181608777, 0.0695061417562621, 0.024154319960091795, 0.04689113276877573, 0.026516437763348222, 0.03147916994722826, 0.08887172796364341, 0.04491362388112715, 0.024167417382289256, 0.05801617580332926, 0.026383063223745142, 0.03041968501306006, 0.0237909220491669, 0.05888067691453865, 0.03560581976281745, 0.034788022216941626, 0.09107626788318157, 0.05617727465661509, 0.08735267804669482, 0.018114871445244977, 0.03788201976567507, 0.025137501935075437, 0.02391796585704599, 0.05152256853346314, 0.0776220787582653, 0.06578329152294568, 0.07217461642410074, 0.03466375531362636, 0.024186706436531882, 0.017405235774016807, 0.04344422576416816, 0.025481358037463257, 0.025490533527252928, 0.08964643853583507, 0.03416036036131637, 0.10045474820903369, 0.0537848891025143, 0.0038192178970868035, 0.006934689806907305, 0.01757779740728438, 0.012439169438688882, 0.041178159681814056, 0.09697283897548914, 0.08829429466277361, 0.15169547365180083, 0.11968073940702847, 0.12160985517714705, 0.08194417719330106, 0.11650792323052883, 0.10798126898173775, 0.19409267577741826, 0.15746986094330037, 0.23964155092835426, 0.1282927601465157, 0.10162993693458182, 0.10716638913644211, 0.11184772436640092, 0.15300914458930492, 0.10154986301703112, 0.1089279203276549, 0.15438897269112722, 0.16459679922887258, 0.10164642533553497, 0.09802326546715838, 0.12091799373073236, 0.20580237172544003, 0.1253290277506624, 0.12649409951908247, 0.12208062277308532, 0.14233984638537678, 0.12309462550495352, 0.21571138501167297, 0.1754465334649597, 0.13765923040253775, 0.15219707387898648, 0.09809315457407917, 0.19131475341107163, 0.13096293115190097, 0.18794531135686807, 0.09054371967379536, 0.20521674172154494, 0.09574591874011926, 0.09658477801297392, 0.1474731130791562, 0.19048683212271758, 0.1277342036898647, 0.22201018487768515, 0.12878894566425256, 0.20510654763451644, 0.117442822349923, 0.09002373793295451, 0.10412462521344423, 0.1978233563048499, 0.09096563953374114, 0.12400958926549979, 0.05961677205881902, 0.2125888889921563, 0.11883922027690069, 0.14746297576597758, 0.06687844025769404, 0.1404325794428587, 0.14199365781886236, 0.11194740794599056, 0.05164637742564082, 0.11644627153873444, 0.09640665578522853, 0.24928863612668856, 0.12609410312558922, 0.0779592360236815, 0.19504094203667982, 0.13164625662778104, 0.1421711082969393, 0.1134150249085256, 0.14753509046775953, 0.21872811099248274, 0.16573269399149076, 0.06733432079532317, 0.25752860254475046, 0.09264472872018814, 0.09114803653210402, 0.16512035684926168, 0.06717470221753631, 0.11002900624381644, 0.10309163028640406, 0.1197611050946372, 0.14588599252913678, 0.13234507984348706, 0.0780957911961845, 0.12972160561808518, 0.1764802544244698, 0.11462084949016571, 0.13879531515496119, 0.12832853251269885, 0.13281060914908135, 0.07846999647361891, 0.15122911653348378, 0.11785028262862138, 0.0901861520750182, 0.15594143367239408, 0.11823873035609722, 0.08518339480672564, 0.09965398189212595, 0.19550575209515436, 0.1873661545770509, 0.18160369593117917, 0.14695301598736218, 0.16387189312704972, 0.17313908013914311, 0.12496633721249444, 0.1546807156077453, 0.1530547421425581, 0.09234147784965378, 0.15621846594980784, 0.18139857479504176, 0.07829928384827715, 0.1425858967538391, 0.09732383835528578, 0.12063621170818806, 0.10568767812635217, 0.1748903790222747, 0.10778562019446067, 0.16663662477263383, 0.1237943172454834, 0.17380156101925032, 0.198946440326316, 0.12871631527585642, 0.08281625754066876, 0.10972455436629908, 0.17091811288680347, 0.16668079740234784, 0.15857845145676816, 0.15657225410853112, 0.1480189130774566, 0.092079909385315, 0.059723553114703724, 0.16258995048701763, 0.14806396780269487, 0.178474631692682, 0.15550386000956806, 0.15636223394955906, 0.1310031275664057, 0.10752663016319275, 0.20799851816679749, 0.05936151397015367, 0.08449831871049744, 0.10993748544050114, 0.198775354506714, 0.15289797341184957, 0.07425564939954452, 0.16474797683102743, 0.13283069378563336, 0.09450952615588903, 0.14801461116543838, 0.203107977019889, 0.2126379877861057, 0.10866110678762197, 0.1447910541402442, 0.08196720667183399, 0.09966048904295478, 0.12643077863114222, 0.191183633304068, 0.1813263108155557, 0.22596759109624795, 0.10916151957852499, 0.12651859463325568, 0.12348464743367263, 0.14662852697074413, 0.11988729903740541, 0.11440329759248666, 0.22174711685095513, 0.12542689964175224, 0.25613367025341305, 0.2105552652584655, 0.07512281036802701, 0.11425363990877356, 0.09604056578661714, 0.1842445813651596, 0.1516898146697453, 0.2099580458764519, 0.13681528211704322], [0.07867395731487445, 0.05237642343022993, 0.02324828572039093, 0.028556543202804666, 0.022212729323655367, 0.005472325977669763, 0.046248794200697114, 0.03559674435694303, 0.024878951255232096, 0.03586323220016701, 0.05742032706205334, 0.0025154864373949488, 0.10116755603147404, 0.09907484546835933, 0.03661400744957583, 0.06882654143763439, 0.028542453423142433, 0.06129202073706048, 0.018189172726124525, 0.02102850590433393, 0.03381413447537592, 0.04691905787746821, 0.03972337720915675, 0.02800069240454052, 0.08165750971862248, 0.055258629843592644, 0.02286409240748201, 0.029616767740143195, 0.03613907364862306, 0.025720115850812623, 0.07828949937330824, 0.023934459347011786, 0.02664655533486179, 0.0057068679681313884, 0.012415569142571517, 0.05402043914156301, 0.047846815415791104, 0.04641069265614663, 0.026095189653070908, 0.027715156387005533, 0.06923606446278946, 0.04573876317590475, 0.026720391819253564, 0.045923904848418066, 0.05595299508422613, 0.04195870904784117, 0.07692672964185476, 0.014509794535115361, 0.026089949666389396, 0.03616130584850907, 0.030650916176715066, 0.04220246257526534, 0.02909291156434587, 0.036674885611448965, 0.04742822037743671, 0.01942341435434563, 0.02269582081186984, 0.0693145641790969, 0.04326786772747125, 0.029693208102669035, 0.07629326291914497, 0.09352839166032416, 0.02649226495330887, 0.07060827940170254, 0.03316234391448753, 0.02029484330809542, 0.04720716045371123, 0.03388954685734851, 0.026069897260250788, 0.02789437784148114, 0.0645713736968381, 0.008913968822785785, 0.03749282564967871, 0.050176996272057295, 0.018741752985598784, 0.04027999644832952, 0.03543041167514665, 0.008761729313326734, 0.053904986408139975, 0.050322484358080795, 0.02532231112542961, 0.07258686716003077, 0.02785262927812125, 0.01591171743348241, 0.04997033146875245, 0.036213427515966554, 0.010432290162758102, 0.04312347547550287, 0.031866345421544144, 0.03807452354314072, 0.05243968664269362, 0.03743955047268953, 0.016352755017578602, 0.05383276653343013, 0.05215752464053886, 0.02815319654265685, 0.019375121320730875, 0.05076763725706509, 0.032477783504873514, 0.01747297901394112, 0.022017078840040734, 0.050912372169217894, 0.0404632958982672, 0.038878438262534995, 0.016334443053762828, 0.01933566790207156, 0.09558244608342648, 0.053205759464097876, 0.021080781938508153, 0.07645577884146146, 0.0240554421408368, 0.05001685522230608, 0.04910125024616718, 0.10319169384560414, 0.0788193198719195, 0.031561113228755336, 0.02520779985934496, 0.03228680643119982, 0.00745559435537351, 0.037903566645192246, 0.006405480837981615, 0.06675614110593285, 0.0359563136340252, 0.03293554697717939, 0.058708308663751395, 0.026873791623594503, 0.015060481681887592, 0.03532264335080981, 0.0140350795617061, 0.09868414500462157, 0.022162643261253834, 0.02532137474710388, 0.022834099463320205, 0.02875100794647421, 0.06646658985742501, 0.03555814589240721, 0.057263931525605063, 0.01697309039134, 0.01324485258997551, 0.11435976278569017, 0.04500912768500192, 0.021556545248521224, 0.06272444208817822, 0.03848921361246279, 0.03210832457989454, 0.04339609048994524, 0.04822850493448121, 0.029797821239169155, 0.04936240819681968, 0.018802503922155926, 0.009128578422990228, 0.10445940760629517, 0.030910377789820944, 0.027787976765206883, 0.05368739040568471, 0.041112328214304786, 0.027148935877318894, 0.021137431130877564, 0.014057696830215198, 0.01581439345942012, 0.03229367320558854, 0.06350352242588997, 0.02962765483451741, 0.051662380674055645, 0.03716179894815598, 0.013796570261807313, 0.04722368956676551, 0.006861052218092871, 0.03535900943513427, 0.02341352935348238, 0.0031500082820587394, 0.03642131028962987, 0.04275131598114967, 0.06781804841011763, 0.025366875609116893, 0.03664196648501924, 0.056273589309837134, 0.033787220383861234, 0.06330567518515245, 0.011015052508030618, 0.07548704118068729, 0.028638527196432863, 0.05815163853445223, 0.02104216651059687, 0.02198678394779563, 0.010391461014348482, 0.051561465553407154, 0.03611919257257666, 0.048822942322918346, 0.041358052885958126, 0.050934427949999056, 0.014521173567378094, 0.06064783316105604, 0.023985893997762884, 0.019654350355267525, 0.034338927029498985, 0.025803351741550223, 0.016490375490060875, 0.026496349734121134, 0.01436728352148618, 0.038413383931453736, 0.03502872233678188, 0.05041122316781964, 0.0395312262699008, 0.025166319317317436, 0.04753504553809762, 0.06475163330989224, 0.027764837024733424, 0.04809941364718335, 0.04031063908977168, 0.02245866264482694, 0.03215885169005819, 0.026427790555836897, 0.015326301168118204, 0.03167008934542537, 0.025824496589068855, 0.11069855067346777, 0.02043385647370347, 0.04607800693650331, 0.03058777849322983, 0.05354394471006734, 0.02137776484180774, 0.030253976583480835, 0.03654556701491986, 0.016078287602535317, 0.03182764856943062, 0.0386591968126595, 0.014393927895330956, 0.07201454322785139, 0.02413284432675157, 0.03415289308343615, 0.07912597698824746, 0.022384620903592025, 0.021945247426629066, 0.03595353503312383, 0.01722047238477639, 0.024132304891411747, 0.09061119998139994, 0.023375236229704957, 0.04093104401337249, 0.08854674361646175, 0.02001796200472329, 0.01822473474645189, 0.09239126196397202, 0.030054022491510426, 0.0038571115333719975, 0.032393451780080795, 0.026453571493870447, 0.02268078617219414, 0.05071820258828146, 0.03337052524355905, 0.08045219403824636, 0.03453338498781834, 0.0260944653169385, 0.03542203176766634, 0.07402425538748503, 0.041482662449457815, 0.04004061947177563, 0.0162422335374036, 0.011122870026156306, 0.011842361418530345, 0.014959035607587014, 0.041140779187636714, 0.0153423179872334, 0.036335604531424384, 0.04068492239873324, 0.018804130709863136, 0.06401034737271921, 0.01787389991139727, 0.012617666557032083, 0.06203177997044154, 0.01431108555490417, 0.019399053250838603, 0.04755074683842914, 0.05729778363768544, 0.013291747841451849, 0.02871665032580495, 0.03136577656758683, 0.010920693731999822, 0.010455334060160177, 0.016748213708134632, 0.03624717445511903, 0.11441609476293836, 0.07046625523694924, 0.0075149067976911154, 0.04114459594711661, 0.02390788621934397, 0.08394479698368482, 0.006017391885896879, 0.036173227708786726, 0.050015196204185486, 0.019190539439607943, 0.019434876507148147, 0.012241696240380406, 0.014451627120641726, 0.03620465066550033, 0.024211873300373554, 0.06292702550334589, 0.04019631950982979, 0.04775154909917286, 0.0635682682373694, 0.04310748240511332, 0.02367576108580189, 0.01503772531369967, 0.07058638307665076, 0.05186699630160417, 0.05091307445296219, 0.06961189822426864, 0.011843280833480614, 0.06318668049893209, 0.051493018333400996, 0.05415722840864744, 0.053772722969629934, 0.038409811444580555, 0.0459436671808362, 0.05086864737261619, 0.04759362007358244, 0.011818013885723693, 0.013166830392687448, 0.03211358661896416, 0.0935187361070088, 0.027191843039223125, 0.04184703914714711, 0.008265112077684274, 0.03332926692175014, 0.029255858356399194, 0.03309592890686222, 0.05757918568061931, 0.04009153334689992, 0.007837590911159558, 0.01575982567322041, 0.01859003764444164, 0.030425354173140864, 0.01410062943718263, 0.03393198922276497, 0.013961317716166377, 0.02608324065139251, 0.03859536363078015, 0.059795260695474486, 0.03178946061858109, 0.04905939820621695, 0.029031178448349237, 0.008298500241445643, 0.023785883926653435, 0.01861125204179968, 0.026566425438172052, 0.041200517410678525, 0.05951304441051824, 0.0666769899960075, 0.0919102756306529, 0.043914945862655125, 0.0045249960967339575, 0.18772044485168798, 0.12782535808426992, 0.17822594860834734, 0.08720116117703063, 0.12268707023135253, 0.12301835816885744, 0.223838958889246, 0.12461273904357638, 0.0941808641489063, 0.1876366322061845, 0.09833307777132307, 0.14617443776556424, 0.1685828531959227, 0.1995884973023619, 0.10249639222664492, 0.13464490643569402, 0.14358280040323734, 0.13750216311642102, 0.06619556940027646, 0.0975926128615226, 0.12034102183367525, 0.1274168257202421, 0.07039094463522945, 0.10150379048926489, 0.1518963607294219, 0.20352059416472912, 0.08850713074207306, 0.07034493996096508, 0.1261262521147728, 0.10150440117078167, 0.12624388294560568, 0.10084165566201721, 0.09841370130223887, 0.12139180116355419, 0.1036168842443398, 0.13323393357651575, 0.18499175698629447, 0.09810726131711688, 0.07291219077472176, 0.09644350023674113, 0.1198131623012679, 0.13288602153105394, 0.14496060647070408, 0.11873425090951578, 0.1881752804453884, 0.16168451335813316, 0.1750507711299828, 0.14987375640443393, 0.16814085548477514, 0.08367889946592705, 0.08984031634671347, 0.17873094151062624, 0.15859693475067616, 0.10387113810117755, 0.0663327013275453, 0.19782011290746077, 0.10560429295791046, 0.10469050306294646, 0.11782257125845977, 0.13864717738968985, 0.16208440118602344, 0.25387127165283474, 0.09463466836937837, 0.19334803787725313, 0.14828807434865407, 0.0964904548600316, 0.14141850439565523, 0.1496939446244921, 0.12409880304975168, 0.18245491811207362, 0.19146454680178845, 0.04494918929412961, 0.13717547564634255, 0.09274697716214828, 0.12197962962090969, 0.20251572451421193, 0.12160301554415907, 0.09186030831187963, 0.12206889768796307, 0.18279616694365228, 0.1661054404186351, 0.14124573580920696, 0.1696046862219061, 0.12514946024332727, 0.06843317433127336, 0.09083343377070767, 0.08966923731246165, 0.1014573515525886, 0.1672440493213279, 0.11274781463933842, 0.09631569816597871, 0.1617122654403959, 0.12044949244175639, 0.1594745112316949, 0.1780719483005149, 0.1404002947466714, 0.13020884804427624, 0.13301877012210234, 0.15487663580902986, 0.08477103550519262, 0.09878386929631233, 0.15043968175138744, 0.14645491700087274, 0.0834105863635029, 0.12559577343719347, 0.14508152141102723, 0.15333203226327896, 0.20923236624470778, 0.07447987129645688, 0.25599896748151096, 0.13013929820486478, 0.23102070923362458, 0.11659344578427927, 0.29990148597529953, 0.1758562329092196, 0.14924098178744316, 0.10430202819406986, 0.08588217052498034, 0.07846515851893596, 0.1641571628195899, 0.10830408880220992, 0.1327890453061887, 0.16725763359240123, 0.2383213931960719, 0.19540488107928208, 0.11470846193177359, 0.1079705006309918, 0.19692304890070642, 0.12737181170710496, 0.22811473373855862, 0.1812644555632557, 0.15261484788996832, 0.0641217085399798, 0.14770156224923475, 0.12124594327594553, 0.09618781467101403, 0.12268697523644992, 0.08453567884862423, 0.09477585115070854, 0.16692234229828629, 0.09149072385792222, 0.06529829504766635, 0.13602211539234432, 0.11729643520499979, 0.19168868048914842, 0.19643993196742876, 0.134827744481819, 0.13545460227344716, 0.10233125037380628, 0.1330198422074318, 0.09156845682965857, 0.22618972989065306, 0.07837886243526425, 0.14292862479175839, 0.1577324675662177, 0.09235521139843123, 0.1311858706176281, 0.10762105509638786, 0.08873622452041932, 0.0859469570485609, 0.1267531913306032, 0.151327694100993, 0.18010273575782776, 0.0697412405695234, 0.17033341926123413, 0.09918662732733147, 0.0853062639279025, 0.1721093218241419, 0.08079355822077819, 0.09494743908622436, 0.16555233938353403, 0.13449832930096559, 0.14452505484223366, 0.13147515723747866, 0.07967783630426441, 0.091042117215693], [0.05799809963043247, 0.020095004567078183, 0.04618660307356289, 0.07575842126139573, 0.02373275633103081, 0.10068856459110975, 0.013122195510991981, 0.06641493977180549, 0.08830853711281504, 0.04832832422107458, 0.031023591357682432, 0.016497362704415406, 0.0376292281518025, 0.013807626141767417, 0.027692969988233278, 0.010436697247704225, 0.022543703438714147, 0.05324958264827728, 0.010081917579684938, 0.016766734321468642, 0.04746036258127008, 0.017170053840215718, 0.04163968563079834, 0.054872170223721435, 0.07897831419748919, 0.038050082711769004, 0.032108083699962923, 0.057795244801257334, 0.01960150944069028, 0.03816200367041996, 0.04322059080004692, 0.0409839018913252, 0.02978525816329888, 0.04325635977355497, 0.042099515242236, 0.053433238329099755, 0.026871235242911747, 0.0608860668061035, 0.016275895659678748, 0.031135322326528173, 0.013962256638998432, 0.012100188610410052, 0.044471293687820435, 0.050715549516358545, 0.028768707532435656, 0.008108779305725225, 0.031174317734049897, 0.07315701978015048, 0.03102106720741306, 0.051881652658006976, 0.07425130677542516, 0.043957133777439594, 0.019996693324563757, 0.03613146387838891, 0.07782939834786312, 0.0464621663226613, 0.011471151025034487, 0.011671340059755104, 0.04036913898640445, 0.018131736433133483, 0.04974105448595115, 0.05175865461517658, 0.021834234008565545, 0.016691746023882712, 0.007117121580189892, 0.030909804427730184, 0.02113396212059472, 0.06632224510290793, 0.016220951286543692, 0.011672368040308356, 0.11837020330131054, 0.08099403817738805, 0.023697732049705725, 0.03356962438140597, 0.032278697937726974, 0.027318410176251615, 0.02136920512254749, 0.014158606013682271, 0.013441073043005807, 0.0511110743640789, 0.02806707687808999, 0.0158403576019087, 0.01882981665299407, 0.0663307403613414, 0.026664209119709473, 0.028563583003623143, 0.03157489766765918, 0.10210308618843555, 0.053471473777400594, 0.019070928982858146, 0.024430697451212575, 0.08288921362587384, 0.058295861152665954, 0.025777231536007354, 0.05023407803050109, 0.03151646562452827, 0.03114369884133339, 0.08375149592757225, 0.01393380481749773, 0.03630980323734028, 0.023785770272037814, 0.03738202427380851, 0.014732854440808296, 0.10587116756609508, 0.03609649218352778, 0.04714159022218414, 0.05361325366954718, 0.05565007669585092, 0.03871324212689485, 0.04220420641026326, 0.057151918964726586, 0.02293108925888581, 0.015709134018314735, 0.028525099890040498, 0.0642486692273191, 0.06939378992787429, 0.03292597284806626, 0.03055426225598369, 0.02445248860333647, 0.02182973362505436, 0.05603962025738188, 0.06240612095487969, 0.03618284933535116, 0.024744180629828146, 0.021308355798412646, 0.009757141033852739, 0.020917714706489017, 0.03278959409466811, 0.01069582298597587, 0.053047022981835265, 0.08055748231709003, 0.03170145462666239, 0.06366085434066397, 0.020903363690844605, 0.08788127039692231, 0.03804376894342048, 0.024660071125254035, 0.0352448357402214, 0.03834301306466971, 0.01979600471843566, 0.016025767295754383, 0.047368889275406084, 0.013808470069696861, 0.01811487483792007, 0.01643000283677663, 0.03427730926445552, 0.032947102428546975, 0.03863470169848629, 0.04100813916219132, 0.045211290408458026, 0.07166197643216167, 0.025068846065551043, 0.033208463939705064, 0.06481898469584328, 0.052234884418014965, 0.02292358805425465, 0.04260931217244693, 0.03980983614123293, 0.026456575707665513, 0.04061156937054225, 0.02841268020815083, 0.034745165945163796, 0.010621325778109687, 0.0304051541856357, 0.028198702493682504, 0.059027349044169695, 0.019148587315742458, 0.015063287424189704, 0.011372128168919256, 0.016006693676380173, 0.024188624994297112, 0.015831238091258065, 0.036336693580129316, 0.07701776189995663, 0.03343187837994524, 0.03612368447440011, 0.04401840888229864, 0.02007830242759415, 0.028665529497499977, 0.08907528846923794, 0.023132095080135123, 0.08170658815652132, 0.06291490686791283, 0.05416827156607594, 0.0337805605626532, 0.07485938950308732, 0.013321171664366764, 0.01745775608079774, 0.03412520206932511, 0.04680445331281849, 0.046157575345465114, 0.028272299794480205, 0.05109399903033461, 0.05184334257085409, 0.012536553632734078, 0.04447498152564679, 0.017305243460993682, 0.04709321067535451, 0.01137993047346494, 0.029722727768655335, 0.021301212521003823, 0.022811709504042352, 0.03018842331532921, 0.07219983078539371, 0.022087393727685724, 0.03574608312919736, 0.0362777119236333, 0.03574207977258733, 0.036986702986593754, 0.009503011857824666, 0.04110998048314026, 0.04036607540079525, 0.018795586257640804, 0.028320521581918, 0.045573994517326355, 0.0445094137851681, 0.08167769613542727, 0.01857348987167435, 0.01947165310515889, 0.057640837372413704, 0.041472165512719324, 0.013111798658168741, 0.06493634411266871, 0.08575357456824609, 0.02367826148734561, 0.012391809390724769, 0.07230532262474298, 0.02246539031953684, 0.04389368396784578, 0.04157243602510009, 0.05797137213604791, 0.07544850717697825, 0.016002853168174624, 0.054958052401031764, 0.018556333113727824, 0.0652960558821048, 0.01631857211967664, 0.021812113766957606, 0.041784454469702074, 0.018671032673280154, 0.03625845509980406, 0.05870297537850482, 0.029673367738723755, 0.015675794200173447, 0.0361551651065903, 0.0474927829844611, 0.07025424018502235, 0.03713509859517217, 0.009550248921316649, 0.04610299738124013, 0.07039357056575161, 0.07195813661175114, 0.02318508696875402, 0.03061427528570805, 0.13801737475608075, 0.028158506079177772, 0.038789611243243725, 0.006099313539120236, 0.022802130285916582, 0.02600265952891537, 0.01934427342244557, 0.032956028556717296, 0.05051894399470516, 0.022592971866418208, 0.023290802724659443, 0.05054655358461397, 0.02271799703261682, 0.02399922551454178, 0.03572082466312817, 0.035141294689050744, 0.011651404700907213, 0.04650285128237946, 0.010172481648623943, 0.02149506488681904, 0.07987326796033553, 0.024283853991489326, 0.020717450184747577, 0.047890852338501384, 0.030352442192712, 0.08203425950237683, 0.0390411441746567, 0.017862395350156084, 0.021491064922884107, 0.09253608169300215, 0.01844772679864296, 0.0404879470754947, 0.03571996631632958, 0.022109754849225283, 0.05696557967790535, 0.07484597486576863, 0.016824782992314016, 0.08996273084942784, 0.04889087385631033, 0.09103864311639752, 0.019717857840337923, 0.09999377187341452, 0.03519727722076433, 0.00598015176365152, 0.027379742956587245, 0.017354113249374286, 0.05207975434937647, 0.018627993197047284, 0.05991766841283866, 0.035599930078855584, 0.04262813812653933, 0.0532288907228836, 0.01844231378553169, 0.009351100589680885, 0.04076695049713765, 0.03425412033019321, 0.03835286878581558, 0.016074257104524543, 0.027252843337399617, 0.02725239041527467, 0.023791341044540917, 0.001013876248699879, 0.0161157970183662, 0.0172391168307513, 0.052039038855582476, 0.056814351185624085, 0.029306378681212664, 0.021862452583653585, 0.05530653102323413, 0.04508103543360319, 0.02541233745536634, 0.062076929690582414, 0.08686090979192938, 0.06057795083948544, 0.028241363686642477, 0.06976325903087854, 0.028049316223976866, 0.03560441858800394, 0.05067921396610992, 0.024444517513204898, 0.025262542368311967, 0.025473802550030605, 0.03396605507337621, 0.025969494433541383, 0.04046066996774503, 0.008097273048146494, 0.07770265479172979, 0.0527340385264584, 0.00603320641675964, 0.03774634329602122, 0.0746599884171571, 0.06008170425359692, 0.0208189997356385, 0.02781601552851498, 0.044944239381168566, 0.016939301043748856, 0.0384785673980202, 0.022107196772204976, 0.15565845742821693, 0.14020191824861936, 0.1078703420768891, 0.2872480292405401, 0.06744406704923936, 0.15121051110327244, 0.1286833927567516, 0.17235104313918523, 0.22980526302542004, 0.20314004458487034, 0.12187669585858073, 0.08757044029022966, 0.13714600008513245, 0.07325949892401695, 0.13302598973470076, 0.105849624079253, 0.11581003639314856, 0.16368963862104075, 0.09661993969764028, 0.12071547816906657, 0.11769488453865051, 0.08825538067945413, 0.10583382099866867, 0.159695849354778, 0.2078855149447918, 0.14088208175131253, 0.11865586654416152, 0.1617147217371634, 0.07841511656131063, 0.1434649388704981, 0.13789367782218115, 0.15956951970500605, 0.092838986510677, 0.12456289386110646, 0.09755055726106678, 0.14549624201442513, 0.10799610854259559, 0.10962404975933687, 0.14365438584770474, 0.15109269028263433, 0.20893660640077932, 0.12020204429115568, 0.10180670887764011, 0.16274502288017953, 0.14204011032623903, 0.08813253191432782, 0.11900643844689641, 0.1232160289904901, 0.11415575444698334, 0.1449237484484911, 0.16479810699820518, 0.08632624455328498, 0.12903791373329504, 0.08771761453577451, 0.2771758282823222, 0.1379977379526411, 0.10553565235542399, 0.09565086276935679, 0.10003379865416459, 0.18566092822168553, 0.1246466657945088, 0.11911800317466259, 0.09181019850075245, 0.12247111967631749, 0.11452801232891423, 0.13191304302641324, 0.09168152111981596, 0.11987176058547837, 0.1153888561363731, 0.09528882362480674, 0.2573772078113896, 0.2004658837935754, 0.06495705978678805, 0.17832835311336176, 0.15321579921458447, 0.11785448954573699, 0.09332019676055227, 0.12472179319177355, 0.19728565801467213, 0.10256505318518196, 0.10036872353936944, 0.17924422611083302, 0.17086266300507955, 0.12382455276591436, 0.11448869800993375, 0.11211873803819929, 0.21507318211453302, 0.16400826509509767, 0.0970241633642997, 0.14097877299146994, 0.10819711097116981, 0.13523162209561893, 0.1605117062905005, 0.07755263748445682, 0.12531716695853642, 0.21550143270620278, 0.10633331098194633, 0.16246975479381426, 0.11100668699613639, 0.16967285184987954, 0.09872280114463397, 0.11905247026256152, 0.07252830958792142, 0.26100481886948856, 0.12920750677585602, 0.12770175614527293, 0.22602304097797188, 0.17635264912886278, 0.12846413095082554, 0.16112119358565125, 0.19745515606233052, 0.10111547846879278, 0.1197256041424615, 0.13462642314178602, 0.09886011627635785, 0.1993590710418565, 0.14046010082321508, 0.2043122002588851, 0.28546348214149475, 0.10042267385870218, 0.14466065328036035, 0.1040032488693084, 0.15686763397284917, 0.1236526391335896, 0.08026527799665928, 0.13722954131662846, 0.13290058289255413, 0.07922383530863694, 0.11925115888672215, 0.17427349569542067, 0.1968480572104454, 0.11764597573450633, 0.11516918720943586, 0.13218217715620995, 0.1650209921811308, 0.0972480663497533, 0.08476515260658093, 0.0836169288626739, 0.12631132932645933, 0.08279531794999327, 0.13575642822044237, 0.0953309131520135, 0.14345215527074678, 0.12471317579703671, 0.10464175710720675, 0.10891781015587704, 0.1411496823919671, 0.15824738065046923, 0.140964075922966, 0.12165637553802558, 0.1425456324858325, 0.20941006099539144, 0.09661179049206631, 0.10464291061673846, 0.14236360868172987, 0.1334956038211073, 0.07500211934426002, 0.12734705874962465, 0.14460303208657674, 0.09455285740217992, 0.11022880088005747, 0.06846787461212703, 0.09028968294816357, 0.07521215307393245, 0.22574492304452828, 0.0965330261471016, 0.15278351812490396, 0.1031019033065864, 0.115686814433762, 0.14737640826829843, 0.09094729873218707, 0.10898923275193997, 0.11971960589289665, 0.21028664681528295, 0.1113074476431523, 0.14846240356564522], [0.013561233961289483, 0.018790946774450795, 0.030743356394980634, 0.009812456904910505, 0.04737373062276414, 0.021715570108166764, 0.017196289396711757, 0.03551355257098164, 0.02922790271363088, 0.041891371232590506, 0.006893802983021098, 0.017095754255673716, 0.048693766218743155, 0.010791290318593383, 0.03377814158531172, 0.12481984150196825, 0.027357071405276656, 0.02960235226367201, 0.03644924896902271, 0.04182091215625405, 0.026771348102816513, 0.036744479555636644, 0.05603488069027662, 0.06780945137143135, 0.018190904686759626, 0.003992393604546253, 0.021005396697936312, 0.04255612859768527, 0.014917646667787006, 0.012884790526836045, 0.017701974404709678, 0.04707357047923973, 0.014688895549625158, 0.027765274679820453, 0.02590215322561562, 0.042928593432796855, 0.05140740417742303, 0.01892345109289246, 0.008560335030779243, 0.025845724557127272, 0.05690332069726927, 0.0263647088514907, 0.021585949563554356, 0.005805208048384104, 0.027897171709420424, 0.0393791597868715, 0.018750366987660527, 0.020694592036306858, 0.013186931144446135, 0.051533893282924376, 0.04973982973024249, 0.060045076933290274, 0.03327388150085296, 0.08266229794493743, 0.08161801898053714, 0.02855713352827089, 0.01531765323930553, 0.023175404274037907, 0.050055755634925196, 0.05079472437500954, 0.10278658129807029, 0.01592279621399939, 0.04783360773165311, 0.0037934874250952688, 0.008817669436601656, 0.02957723968263183, 0.053236676912222586, 0.04338564444333315, 0.018756361844550287, 0.026933502705235566, 0.026576255714254718, 0.03822446281888655, 0.0632830596129809, 0.05219944453399096, 0.007175587550071734, 0.051987741608172655, 0.07675130119813339, 0.06362753148589816, 0.037634775175579956, 0.02023289306089282, 0.024091546989179084, 0.03645399871415325, 0.040658968434269936, 0.08279132137873343, 0.036433863187474866, 0.016437130847147534, 0.04827960201406053, 0.06813235940145594, 0.047402113742594204, 0.06798110037509884, 0.027728708427665488, 0.05483667266422084, 0.004707051707165582, 0.016782963182777166, 0.009801016804496092, 0.025033265385510664, 0.0667704174827252, 0.011392703895190997, 0.07892947324684688, 0.05989928011383329, 0.05789623116808278, 0.03637454565614462, 0.03548062326652663, 0.01307472265658102, 0.018606758443638682, 0.021021128532343676, 0.06394427163260323, 0.015720536799303124, 0.008100037230178714, 0.01061796533342983, 0.054522619516189606, 0.014951756623174463, 0.0583068330639175, 0.06212876298065696, 0.021844671573489904, 0.026349901521046246, 0.05459847294592431, 0.043901236062603335, 0.012757991839732443, 0.041649724556399245, 0.03506262533898864, 0.053043392819485495, 0.031036653156791414, 0.055538484826684, 0.04020317271351814, 0.04443393015701856, 0.0037796296195925345, 0.021315663620563488, 0.04869019373186997, 0.030960202616240298, 0.03993843209796718, 0.12484791928103992, 0.018726384167426398, 0.011472241770076965, 0.024498606932216456, 0.009601371445959168, 0.013885027479513415, 0.01866183682743992, 0.0656629940494895, 0.027965327159368565, 0.04115629389083811, 0.030000173952430487, 0.03287036351061293, 0.024887154743607556, 0.0341533714506243, 0.10514394765985863, 0.011819744150021246, 0.02279457649482148, 0.020402045055691684, 0.011670304445682891, 0.060460632134761126, 0.08924331409590584, 0.045935728321118016, 0.04366937046870589, 0.05347281388406243, 0.0654954637533852, 0.06495686301163264, 0.041301123797893524, 0.04451687427769814, 0.007440846396743187, 0.05222590739971825, 0.0021802248291870846, 0.027541202060612183, 0.04634224543614047, 0.05609800819573658, 0.030752754104988914, 0.005737283724426691, 0.03850041961829577, 0.04896350085203137, 0.08483141833650214, 0.08322229968117816, 0.03137429557474596, 0.03693746170029044, 0.018472181200715046, 0.05869670571493251, 0.0697305943550808, 0.010405914658414466, 0.021903688853074397, 0.005937444345493401, 0.05648086818733385, 0.04107844217547348, 0.05680445135970201, 0.07656771676348788, 0.05361364043450781, 0.0189913809299469, 0.038123245750154765, 0.043257845765245814, 0.03227483368079577, 0.02613884659617075, 0.03522853393639837, 0.03086161147803068, 0.02688628006061273, 0.016527525282331874, 0.05035723552906087, 0.04033882204177124, 0.02800951335978295, 0.06059651555759566, 0.06557568016328982, 0.036364516908569, 0.031865877232381275, 0.07932751545948641, 0.006706681684590876, 0.048076316315148554, 0.006100795714051596, 0.04548303011272635, 0.020145962546978678, 0.021972293832472393, 0.04982773733458348, 0.02214321680366993, 0.06877337143357311, 0.03441726389740195, 0.06681775887097631, 0.04681631749761956, 0.055306632803486924, 0.014670671795361807, 0.01611808537771659, 0.07052376107977969, 0.018663628159889152, 0.049671253588582785, 0.043551943198378594, 0.022324372082948685, 0.07404117805085011, 0.010290684993378818, 0.04400213421987636, 0.045390922376619916, 0.016947523191837326, 0.07380517000066382, 0.018982699074383293, 0.0489013334736228, 0.0866537666214364, 0.03688071242400578, 0.007266336519803319, 0.02448478347754904, 0.007618333346077374, 0.04962477054713028, 0.11995661817491055, 0.11859044219766345, 0.022097527648189237, 0.013146468404946583, 0.018849928430946808, 0.05783707648515701, 0.01160517695825547, 0.03995422500052622, 0.019723732257261872, 0.023596406415370957, 0.05361220194026828, 0.025316384122041718, 0.025519734281780462, 0.059766579020236216, 0.031851136059101136, 0.08370082293237958, 0.024344399671203325, 0.08353131809937102, 0.03681733725326402, 0.01913752210592585, 0.085443165153265, 0.01851512398570776, 0.01648260117508471, 0.02478220233959811, 0.08103444493774857, 0.032312109002045224, 0.004121753761345255, 0.06188411717968328, 0.06069078442773648, 0.029505813693893806, 0.034081059973686934, 0.05012941061119948, 0.05692977338497128, 0.00861792144964316, 0.009127927029372325, 0.06482382265052625, 0.02246953107948814, 0.021129714491377984, 0.01784536921020065, 0.035553274010973315, 0.03564501873084477, 0.02816486225596496, 0.029525918686496358, 0.03989330951922706, 0.027274754929489324, 0.011796777435977544, 0.041798764773245366, 0.022455802619723336, 0.03304974102814283, 0.009911490787219788, 0.06655089783349208, 0.08428730789039816, 0.02279834745318762, 0.0115234431744154, 0.045575941912829876, 0.01110955632092165, 0.01942390968490924, 0.05761680366205318, 0.004396715234698994, 0.010569975944235921, 0.014523193905396121, 0.030738311487116983, 0.06690220933939729, 0.02852850952850921, 0.027619508394439305, 0.11432648742837564, 0.028598418991480554, 0.044670776197952886, 0.007925144829122084, 0.029022554268262217, 0.023769733096872057, 0.04144517338967749, 0.003837791520969144, 0.024586685866649662, 0.02722277066537312, 0.045904783731592555, 0.007337335031479597, 0.02498282478856189, 0.06479138189128467, 0.020060534988130842, 0.017106687151161686, 0.04217200313827821, 0.04092847236565181, 0.0114659229127158, 0.04255458153784275, 0.01574983254873327, 0.05770391398774726, 0.02868729011554803, 0.043523570256573815, 0.03781375914279904, 0.03017706803179213, 0.022746163021240915, 0.03648163205278771, 0.05076842096501163, 0.019286628479936292, 0.03915677332718458, 0.0638609000348619, 0.025665632881490246, 0.0075162452080154, 0.04458759119734168, 0.06729495897889137, 0.013684735816371228, 0.028472048629607474, 0.06632881332188845, 0.0426227844852422, 0.08323554468474217, 0.0783484640664288, 0.010051735493886684, 0.040801280976406167, 0.044570068030485084, 0.06285280055765595, 0.022067700945107, 0.024888410033392053, 0.02236054478479283, 0.025568346226853982, 0.018618634502802576, 0.019706516127501215, 0.11128513741173915, 0.10471480818731443, 0.11493725036936146, 0.1333216003009251, 0.12165504560938903, 0.15021396029208386, 0.2397455024932112, 0.13254853178347858, 0.07820600563926355, 0.09739418886601925, 0.13543545401522092, 0.12408205680549145, 0.1059027330151626, 0.10696099658629724, 0.10275657647954566, 0.17507333920470305, 0.09834709630480834, 0.09992169788373367, 0.2300867736339569, 0.10140661070389406, 0.2254722062498331, 0.11312283415879522, 0.13188271251107964, 0.1623729821294546, 0.17449473882360117, 0.03385770660159843, 0.11746376194059849, 0.08002342775996242, 0.16651192360690661, 0.08358035582516875, 0.10698061303368636, 0.14531765159751686, 0.14769829171044485, 0.14041386544704437, 0.060315982039485655, 0.13355307573718683, 0.1261441654392651, 0.09874164406210184, 0.0802359449278031, 0.12435941477971417, 0.10919965324657303, 0.1036088028922677, 0.10122703641120877, 0.14678228300596985, 0.10130770743957587, 0.12884838533188614, 0.15196002088487148, 0.1942334853644882, 0.11597209769700255, 0.11643180517213685, 0.1709793574575867, 0.15787934325635433, 0.16399945771055563, 0.21724872823272431, 0.2040962361331497, 0.11605521823678698, 0.12259933565344129, 0.12972165990088666, 0.11498790979385376, 0.12501052341290883, 0.2761162822800023, 0.09736603644809552, 0.1455383383269821, 0.09265853012246744, 0.15502937404172762, 0.10762146221739904, 0.13296227529644966, 0.1706354080566338, 0.10651205746190888, 0.17252926714718342, 0.13203877556536878, 0.10881639631198985, 0.08449893617736441, 0.07563376080776964, 0.19784069965992654, 0.20015706893588814, 0.19287717528641224, 0.14177544095686503, 0.13063135822968824, 0.09528062013643128, 0.12205641264361994, 0.1329029713358198, 0.09875808496560369, 0.1787845864892006, 0.157407300014581, 0.09707668876009327, 0.07890950396124806, 0.14346924078251633, 0.16013606930417673, 0.11550921467798096, 0.10252983721771411, 0.13331999895828112, 0.11981059743889741, 0.1174829373402255, 0.14850029296108655, 0.1045569402298757, 0.12957106583884784, 0.14312103018164635, 0.12754254468849727, 0.1549627147614956, 0.10877229153577771, 0.1264187821320125, 0.1334358655980655, 0.11892661558730261, 0.12819425043250832, 0.07162063329347543, 0.23235620185732841, 0.12209742330014706, 0.07139949194554772, 0.16438019728021963, 0.2225181633340461, 0.14256007171102933, 0.16091291047632694, 0.13136332109570503, 0.13819725438952446, 0.20370573922991753, 0.20064277787293705, 0.13864069059491158, 0.14857038562851294, 0.11168362745749098, 0.10167009942233562, 0.1406667283070939, 0.07435564510524273, 0.09100149332412652, 0.16280466610831873, 0.13133094140461513, 0.07242182030209474, 0.07313012943736144, 0.15317109732755593, 0.1278700599712985, 0.16395390086940356, 0.16532154248229095, 0.06064700534833329, 0.07736917518611465, 0.20285512773053987, 0.1008266464674047, 0.11893664433487824, 0.12835519893893174, 0.08281663073492901, 0.12257992955190794, 0.1297908704727888, 0.1232120120631797, 0.05538349725039942, 0.1326421153332506, 0.14887270012072154, 0.25183067257915226, 0.12775660891618046, 0.11870865656861238, 0.10762880396630083, 0.091396950318345, 0.1368830677654062, 0.16940020290868624, 0.2273411631051983, 0.09307592415383883, 0.10701646003872156, 0.15504986579929078, 0.12140997233135359, 0.10835529784006731, 0.11875263920852117, 0.1416128503956965, 0.1430188428078379, 0.15128589634384426, 0.2941269358353955, 0.15083724898951395, 0.18461138382554054, 0.09966337960213423, 0.16175395463194164, 0.18402160118733132, 0.15934848013733113, 0.1152675205043384, 0.1351141134010894, 0.19849981500634126, 0.17308388810072625, 0.09961005353501864, 0.10920526473117725, 0.19470624785338128], [0.0627073362203581, 0.011462671033638929, 0.052143706274884086, 0.01948896422982216, 0.03296440167884741, 0.035505216768277545, 0.02755015533018325, 0.020822611238275255, 0.010777451596888048, 0.009013196087575384, 0.0572411734610796, 0.05360284833503621, 0.07092376425862312, 0.030879867462707416, 0.06533798934625727, 0.03821503796747752, 0.0425443119103355, 0.05699764724288668, 0.0666860823652574, 0.07512901896344763, 0.03780575921492917, 0.017994746998218552, 0.08103298608745847, 0.051851864970688305, 0.049837287714970965, 0.009930379505801414, 0.0384861466341785, 0.01854672166518867, 0.037109090347907374, 0.041751827113330364, 0.004414399129538131, 0.028558789153716395, 0.028438289816092168, 0.04518292085932834, 0.005321596208627203, 0.023629719092111503, 0.057423997936504226, 0.03408997253115688, 0.05510970837037478, 0.013521308112623436, 0.03494357976264187, 0.008414556022866495, 0.018046800812174166, 0.057408113431717665, 0.020748722167419534, 0.03648824776921954, 0.0064636189906325725, 0.020617841244009987, 0.05034112710771816, 0.012931781621383769, 0.06633568009627716, 0.03464433903406773, 0.006534876617869096, 0.019727409917062948, 0.02351224602067045, 0.03989942990509527, 0.06264046659427029, 0.04545168858021498, 0.035336980795753856, 0.014067888426195298, 0.04801684272076402, 0.04869962197595409, 0.05931018279599292, 0.033927582137818844, 0.04016225705189364, 0.022786454430648258, 0.057925340320382795, 0.026758961446051086, 0.0371780566472028, 0.03787114963467632, 0.03336133787940655, 0.009479058723497604, 0.009521013391869408, 0.03334386899535145, 0.007526069546916655, 0.04743053757452539, 0.03011831029185227, 0.1373436709067651, 0.08753584857497897, 0.13559732532926969, 0.2216052623199565, 0.2670917122491768, 0.4538655328963484, 0.37562043006931034, 0.3312181569635868, 0.372878470058952, 0.027305180439725518, 0.10938627751810209, 0.07150797612432923, 0.0473882105600621, 0.06402505801192351, 0.03626523366464036, 0.025447997863271406, 0.03224230131932667, 0.06307516326861722, 0.024968176913846816, 0.01170608020454113, 0.025067986022414904, 0.05560002116752522, 0.057287748104759624, 0.033464800899050066, 0.05352412470217262, 0.03507221303880215, 0.009274987620301545, 0.04539479002622621, 0.024397656188479493, 0.039718108384736946, 0.016529888280534318, 0.06461711374244519, 0.027092471585742066, 0.01031862960995308, 0.09010519606194325, 0.06765327296618905, 0.07263714660491262, 0.03547179213325892, 0.05676197846020971, 0.019865311981577958, 0.042054572475275824, 0.028120837207617502, 0.031144635219659125, 0.010884405679202505, 0.06857405855719532, 0.027908162280384983, 0.030488244191344296, 0.0007269778600727607, 0.017510035507647053, 0.0571101890610797, 0.03252306214666792, 0.020258176972025206, 0.021658076139699136, 0.0946304818083133, 0.036758135072886944, 0.029583197220095565, 0.025890076998621225, 0.027638429343434315, 0.023485679678352814, 0.04597150747265134, 0.010489054706080683, 0.02640330731602652, 0.028142394265159965, 0.03641800243141396, 0.028373644088527987, 0.03243538185155817, 0.0530363123065659, 0.014580659036125456, 0.012037942352305566, 0.030780818313360214, 0.016643208717661243, 0.014327473871942078, 0.004241111039716218, 0.05002326737823231, 0.07103368693164416, 0.00950321541833026, 0.07455474085041455, 0.01441340015402862, 0.04222616719614182, 0.015794288466817567, 0.0559771577162402, 0.02580484451859125, 0.04296133274744664, 0.014994387282058597, 0.017830185292820846, 0.025111525918224027, 0.04781343488554869, 0.04522472879450236, 0.03373774500297649, 0.011226154082188649, 0.011398864144991552, 0.023619549548519508, 0.014389145919787032, 0.07616037862109286, 0.053854774816759994, 0.053202129301748106, 0.029637839645147324, 0.06325458828359842, 0.049816741674606285, 0.031844771400626214, 0.016813824651762843, 0.040378448486860306, 0.03986706717738083, 0.03517828502559236, 0.003960030876831817, 0.041722772243831835, 0.055176615315888605, 0.03363526246643492, 0.022170719524313296, 0.014535120854686414, 0.04591468016483954, 0.042880288524819274, 0.04481602001136967, 0.08442511156733547, 0.023720408690028956, 0.020066501007282307, 0.09930837686572756, 0.03063078404271177, 0.04780871906716909, 0.06609005720487662, 0.05525179360327976, 0.030570099263318946, 0.06334999030722038, 0.017278880679181645, 0.014785754727199674, 0.00970406093568142, 0.01935262618852513, 0.002355129104606541, 0.08299755531230144, 0.05805897779230561, 0.03504385366769774, 0.019236625538074544, 0.015683933227722133, 0.05172210871907217, 0.05107704244021859, 0.04357592262593763, 0.03061913020376648, 0.012199286105377334, 0.02330031748195844, 0.037385403378201384, 0.03112727150853191, 0.02642301536564316, 0.011974004845667099, 0.036147202498146465, 0.04583120678684541, 0.025116642072264637, 0.03459027336378183, 0.051567477373672385, 0.018457217807216302, 0.0031180032695244464, 0.059296143906457086, 0.04624976111309869, 0.02167414893795337, 0.015557747766641634, 0.036274261573063474, 0.03271648194640875, 0.02051672256285591, 0.01935724022665194, 0.03988330791305218, 0.031363730784505606, 0.010466053217117275, 0.03196954041985529, 0.04039300645568541, 0.021007367842165486, 0.01566106659759368, 0.043878284615597556, 0.02428058345269944, 0.0028702351472540094, 0.02632298573319401, 0.02624873025342822, 0.022567686258948276, 0.05193734681233764, 0.015199847685705339, 0.05523247231862374, 0.03838902113160916, 0.05448436371183821, 0.10627812572887965, 0.08847202334020819, 0.17444439152521746, 0.42905945969479425, 0.5177499034575054, 0.5975304767489433, 0.5826749024646622, 0.4326854965516499, 0.4312909170985222, 0.08366859251899378, 0.08906346838921309, 0.04316462862438389, 0.03427936861823712, 0.06365164662046091, 0.07112117723694869, 0.041605721560439894, 0.08647075894155673, 0.022531423651214157, 0.04398049234545656, 0.02369144881543304, 0.010418828876156892, 0.06005377575222935, 0.05198240153757589, 0.02551811427942344, 0.07989580889365502, 0.024031611990981867, 0.027646091700132405, 0.05652117316744157, 0.011479904974943824, 0.0071307321444952065, 0.01423546452341335, 0.03751485768173422, 0.020245240701894675, 0.04040543721722705, 0.043113032821565866, 0.057573397776910236, 0.055127526699964485, 0.03875898556517703, 0.02162877530125635, 0.03801834762894681, 0.03244033515719431, 0.012676187657884188, 0.03704848699271679, 0.045720286667346954, 0.007039537462073245, 0.04769002293635692, 0.010556146552387093, 0.007889962788405163, 0.021518532020438994, 0.06812674791685172, 0.026566221877666454, 0.04571772859032665, 0.01856607009124543, 0.0407889621731426, 0.0632329633725541, 0.03810676752722689, 0.022039480673681413, 0.017857976390847137, 0.04457011892061148, 0.04760951814906938, 0.036697860807180405, 0.04042913505275335, 0.038439721268202574, 0.03711862715759447, 0.05554514804056712, 0.06755143843059029, 0.03364620045093553, 0.07508914824575186, 0.026227276672476103, 0.01402096264064312, 0.023011717878814255, 0.012759867989059006, 0.05916936642357281, 0.029926084713744264, 0.014295389343585287, 0.003023726341780275, 0.021275363729468415, 0.03244199078263981, 0.005836242119715149, 0.0022560778348374045, 0.04963203426450491, 0.05874126510960715, 0.020218287594616413, 0.046127217688730786, 0.10908399695264441, 0.04287169827148318, 0.05160091218671628, 0.05495705495455435, 0.03612051571586302, 0.02891037885897926, 0.031096187819327627, 0.007398261538972812, 0.024188674188085964, 0.04870631233123796, 0.10830191070480005, 0.06257772246109587, 0.023608121322467923, 0.010994909347833266, 0.05669448458190475, 0.12291399948298931, 0.09594025795481034, 0.14200094528496265, 0.203456296186362, 0.1156022689704384, 0.06185495374458177, 0.12431088595518044, 0.10660184800092663, 0.1290770923452718, 0.06600356434604951, 0.1226857810148171, 0.135007488408259, 0.10905258756663118, 0.1222733131476811, 0.12758812867105007, 0.0548869453237525, 0.14655540803713457, 0.18028718871729715, 0.09071129746735096, 0.12705840995269163, 0.19003813048558577, 0.1547435208090714, 0.14910908815051827, 0.20337001367339066, 0.09737480990588665, 0.10128750745207071, 0.1422760369522231, 0.0859567415235298, 0.09539480400936944, 0.165762793804918, 0.17804110209856713, 0.06694239896855184, 0.140475707128644, 0.15583978912660054, 0.07296195453298943, 0.12006887500839573, 0.08183706365525723, 0.15422726422548294, 0.1117651059425303, 0.16713912066604408, 0.12910327022629126, 0.06433795086507287, 0.07643865261759077, 0.1685345007904938, 0.18007336876222066, 0.13270349561103753, 0.07404864193605525, 0.11893667147627898, 0.16362908615597657, 0.11065733645643507, 0.14946052857807704, 0.11080513495419707, 0.18183616202856812, 0.10831361543387175, 0.08006777680878129, 0.07753137219697237, 0.12308702591274466, 0.15879924675183638, 0.110788904396551, 0.08913686552218028, 0.09438415324049336, 0.09113059818212475, 0.15647886054856436, 0.09881498012691736, 0.12801053029085907, 0.10543711550001587, 0.20549450681677886, 0.11353252681770495, 0.08614476357719728, 0.1671986146164792, 0.10349176917225122, 0.07499091673110213, 0.15385203436017036, 0.15466714490737232, 0.1321069411933422, 0.15624559377985342, 0.0796385762680854, 0.3854164944163391, 0.33857529503958567, 0.343509384563991, 0.6807653903961182, 0.8544828402144569, 0.705000924212592, 0.7021901064685413, 0.4904731756874493, 0.5691159814596176, 0.15765827654727868, 0.261624809886728, 0.13963600647236618, 0.11126743443310261, 0.1294651600931372, 0.20218792424670287, 0.09789901213454348, 0.22264001465269498, 0.08368218357541732, 0.16365800531847136, 0.06029285078069993, 0.10706164368561336, 0.2222859143678631, 0.15956817620566913, 0.18996780711625302, 0.12309640326670238, 0.12418698546077524, 0.08580535357551915, 0.14523759803601674, 0.12427923908191067, 0.09932160151324101, 0.12019774237913744, 0.1338591357426984, 0.09616674615868501, 0.10648093306060348, 0.17377503030002117, 0.16195571023438657, 0.13777785189449787, 0.06533235072025231, 0.12382007443479129, 0.1225064034972872, 0.12248042917677335, 0.1506289251680885, 0.1519328930548259, 0.08183291780629329, 0.14089536746697767, 0.09494405998183147, 0.0880251537476267, 0.10900241668735232, 0.11038164767835822, 0.12111061625182629, 0.1683392319828272, 0.10705787781625986, 0.1453664925481592, 0.17658529164535658, 0.12262149660715035, 0.07046113908290863, 0.08712337392249278, 0.08555133042058774, 0.09661770731742893, 0.18103273585438728, 0.10132389049977064, 0.12537776013570173, 0.06905627982424838, 0.10631383702691112, 0.09868430785302605, 0.12235238961875439, 0.14359660180551664, 0.2793516186731202, 0.09615968939449106, 0.23913601519806044, 0.08928159704165799, 0.1327203232795, 0.13391153221683844, 0.11356090315218483, 0.12597369030117989, 0.1323469661708389, 0.16044069081544876, 0.11868102662265301, 0.13936537956552847, 0.10275507013180427, 0.171246985239642, 0.16504084611577646, 0.12025209303413119, 0.10929391533136368, 0.1609407439827919, 0.21142655850521155, 0.12817953979330404, 0.1167626181351287, 0.14415536182267324, 0.10429489679102387, 0.13705788552761078, 0.12188312837055751, 0.07986490162355558, 0.130631276805486, 0.22081289626657963, 0.12549681589007378, 0.15532594812767847, 0.18404760264924594, 0.11562143079936504], [0.020747417683846185, 0.10624404291489295, 0.01663189923523792, 0.033779417231146774, 0.026480319344305565, 0.009252074340890561, 0.0371046086241092, 0.02254380182629185, 0.02851836882265551, 0.02272327773139945, 0.01692493136839143, 0.05570789805746504, 0.02765230368822813, 0.031083692596959214, 0.06758443558854715, 0.05271675963220852, 0.08516672998666763, 0.020371873996087482, 0.05554473074153066, 0.029334354680031538, 0.0340109910549862, 0.020327635209209154, 0.052665513274925094, 0.0377558427862823, 0.047183330303856304, 0.013281010024781739, 0.07189290225505829, 0.045442066953650544, 0.015190853704033154, 0.04188501675214086, 0.04810774266453726, 0.01616552684988294, 0.05932764150202274, 0.034648403458829434, 0.037188953919602294, 0.026874841656535864, 0.011706448309788746, 0.01919620351067611, 0.05785617046058178, 0.04230215972555535, 0.04496208145948393, 0.0168890758816685, 0.02527800278871187, 0.046509487354861836, 0.054734627782766304, 0.03766878674338971, 0.05904969998768397, 0.06823326434407916, 0.07231283400739942, 0.009407284137393748, 0.029556524008512497, 0.06953288282134704, 0.051019977645150254, 0.02736225032380649, 0.05137650369267378, 0.051216800298009596, 0.06563300958701543, 0.024528835667297244, 0.011340649233066609, 0.05141926496954901, 0.03139540819185121, 0.030324873314904313, 0.07730101634349142, 0.027111828493486558, 0.027727173242185797, 0.03900253213942051, 0.05634360055306128, 0.05930851359984704, 0.06660777942410537, 0.012570785724424889, 0.09073185707841601, 0.09074028448334762, 0.0965069229049342, 0.07799703720957041, 0.2264866025320121, 0.18057213271302835, 0.2854759671858379, 1.2145991793700626, 1.876666533095496, 2.69649338722229, 6.236623585224152, 5.227527150085994, 5.954337818281991, 10.215886882373265, 8.452217817306519, 5.804062179156712, 4.328058958053589, 1.7211837619543076, 0.38941447702901705, 0.29225616050618036, 0.08573936604495559, 0.09056700699563537, 0.02819026999973825, 0.19416515688811029, 0.155513535918934, 0.1218348845307316, 0.3105221060769898, 0.4364658865545477, 2.234008912529264, 1.3147455198424203, 2.206377012389047, 1.4822945977960313, 0.09820233764392988, 0.21641745498137815, 0.04876806580328515, 0.10849573423287698, 0.02795470808632672, 0.01923386050787355, 0.021843577435772334, 0.05715213609593255, 0.1237719798726695, 0.03226715944973486, 0.0429360471399767, 0.07529570787612881, 0.07163503859192133, 0.03906542555029903, 0.02868207896660481, 0.023398672829249074, 0.021243735515911664, 0.027538603271490762, 0.02922411648822682, 0.07849904455776725, 0.03381907421031168, 0.062246753435049734, 0.029530960201684917, 0.033581549634358714, 0.04870861256495118, 0.034334136572267325, 0.057335937661784034, 0.05998464660452945, 0.03306137790371265, 0.013778500026091933, 0.01871533931366035, 0.020253328839316964, 0.02176685378487621, 0.02728813055104443, 0.0162982601738934, 0.007075223739125899, 0.04614335325147424, 0.02294585757356669, 0.009473647406723882, 0.01526946877129376, 0.01762734233800854, 0.03328839536490185, 0.02396847939650927, 0.041895968307341845, 0.09576445631682873, 0.009954377593073462, 0.05391286080703139, 0.06837082374840975, 0.0537085810543171, 0.05675319143171821, 0.054315187968313694, 0.04670665606058069, 0.05490398673074586, 0.05782064236700535, 0.016019183809735944, 0.07498639768787793, 0.018849232932552695, 0.02504027125957821, 0.032408230272786956, 0.007991290967246252, 0.015234949998557568, 0.03053913771041802, 0.030212935392877886, 0.10171979532710143, 0.06482360551932029, 0.011229735898918338, 0.044481118874890466, 0.049572740481900315, 0.02970109267958573, 0.04076112527400255, 0.05256318001608763, 0.009798757282883992, 0.019650363962032964, 0.07808031381240912, 0.03821273434108921, 0.04258604520665748, 0.01085833297111094, 0.028385759331285954, 0.04312171467712947, 0.050314874587846656, 0.013367091521753796, 0.05215568920331342, 0.07624828961810895, 0.04268521649230804, 0.02822216453828982, 0.03827223846954959, 0.019292982960385934, 0.09351942142737762, 0.07037998629467827, 0.046767798851111105, 0.057583127969077656, 0.005021892379902835, 0.044769489472465854, 0.02823458512180618, 0.03894137577818973, 0.011979075198593949, 0.05761160608381033, 0.07397288350122315, 0.04947092630235212, 0.0441792793571949, 0.04616480174341372, 0.0270432794932276, 0.016858226287045648, 0.015744180352027928, 0.03891481452488473, 0.026136242718036686, 0.030793934395270686, 0.028957204560616186, 0.0207413091723408, 0.024578938693074242, 0.04713241982140711, 0.007595716077568275, 0.042961726297757456, 0.012717733508907259, 0.044319427372621636, 0.031588665143187554, 0.0597076482538666, 0.06400031862514359, 0.039676989162606854, 0.041843178282891, 0.020931558517206992, 0.04072157686044063, 0.08114212844520807, 0.02504192179601107, 0.01612734907705869, 0.03898881894669362, 0.028151808938543712, 0.016993812850809524, 0.0416728897419359, 0.05902350853596415, 0.05573228121336017, 0.010633604717440903, 0.014798886076148068, 0.037742268693234236, 0.008693852910905011, 0.037292569609625, 0.05557015884135451, 0.05456537061503955, 0.028522847153778588, 0.014669185803670968, 0.028061355131545236, 0.11977041459509305, 0.054067407335553846, 0.05620606489745634, 0.05671502383691924, 0.08635716539408479, 0.11797393885041986, 0.1536590861422675, 0.19992718127157005, 0.15767331288329192, 0.7247618724192891, 3.271924304110663, 4.887676426342555, 5.868011227675846, 9.21405131476266, 8.818193333489553, 10.582624094826834, 14.549651179994855, 13.656612242971148, 8.5131995507649, 6.992613647665296, 2.3660060124737874, 0.7315249123743602, 0.38229743178401676, 0.13392671783055576, 0.1711139923759869, 0.02162711967581085, 0.14221522664385183, 0.1251897109406335, 0.2803078373628003, 0.6427953849945749, 0.9688036143779755, 3.009643703699112, 2.5930129970823015, 3.7568232331957137, 2.6802834570407867, 0.6398941863860402, 0.5178566234452384, 0.11008292942174844, 0.0528600492647716, 0.04068588252578463, 0.06622018665075302, 0.050157369646642885, 0.04381195103217449, 0.06536959550742592, 0.03590271615290216, 0.12276996006923062, 0.07127793239695684, 0.025677317254511372, 0.03623168010796819, 0.014342316825475012, 0.019032177847943137, 0.06170241228703942, 0.04125556695674147, 0.028772938198276928, 0.05582717772839325, 0.035758398539785824, 0.012626977753825486, 0.021732201001473835, 0.06081791474883046, 0.059312951218869, 0.01030085199246449, 0.045027448130505424, 0.07579160162380763, 0.02832009071218116, 0.03954067826271057, 0.05492118080811841, 0.025724807920466577, 0.07351645335022892, 0.020887860862006034, 0.027816831466874907, 0.024906442101512636, 0.02728362677485815, 0.05039034125262073, 0.02433002829950835, 0.041571014494236024, 0.05608991666563919, 0.010936107503117194, 0.029358727657901387, 0.07472954504191875, 0.046795971625085385, 0.018771187834707753, 0.026514341090140597, 0.020317849037902694, 0.03902088651167495, 0.034479702689817975, 0.029662399220147302, 0.0025313310782491627, 0.07320068350860051, 0.09875131997146777, 0.06886435619422368, 0.015673193714714477, 0.009986641085041421, 0.04350937869665878, 0.015365880115755966, 0.045882833123739274, 0.007273688446730375, 0.04265006837834205, 0.03366445304293718, 0.029941121049757515, 0.023237446123468022, 0.03660573610769851, 0.030535473621317318, 0.01713452913931438, 0.05041404587349721, 0.028144747085337127, 0.038971241497035534, 0.08379679492541722, 0.15673694812825748, 0.014294066200298923, 0.1952053510716983, 0.2356384385909353, 0.09018799090491873, 0.20345404345010007, 0.16452372100736412, 0.16417857738477842, 0.09324373943465096, 0.11238751254443612, 0.1655996875571353, 0.06120885269982474, 0.13552740908094815, 0.14695476660771029, 0.10750894754060678, 0.17360750000391686, 0.12135832224573408, 0.10610671421246869, 0.16588385802294525, 0.10542578396520444, 0.08184608817100525, 0.11548960501594202, 0.12567300429301603, 0.10619431308337621, 0.23647108248301915, 0.30596940751586643, 0.08452622685581446, 0.1408464993749346, 0.13393917573349817, 0.16910324884312494, 0.10507708481912102, 0.15564891722585472, 0.13298379842724117, 0.1048898837928261, 0.09613089236829962, 0.11987926518278462, 0.14409296374235833, 0.10481230688414403, 0.12256919512791292, 0.07693451922386885, 0.22077542756284985, 0.1313257302556719, 0.14239730473075593, 0.23578340081231935, 0.1555855284844126, 0.1230303275265864, 0.20222850064081804, 0.16013431868382863, 0.20798015700919287, 0.18089464040739195, 0.23997582441994122, 0.13044033705123834, 0.14359559757368906, 0.14018510415085725, 0.1621652961309467, 0.10772258429122822, 0.12271432019770145, 0.15207314624318055, 0.17375234008899756, 0.0537439225507634, 0.10003934228526694, 0.1096571215561458, 0.07445555260138852, 0.10030806250870228, 0.12150533364287444, 0.14699614367314748, 0.09392646779971463, 0.24564669440899575, 0.14369937271944114, 0.23026359985981668, 0.17060585107122148, 0.1592164100813014, 0.1646073708044631, 0.16179347251142773, 0.18999042947377476, 0.3098204465849059, 0.36076605000666206, 0.3103218839636871, 1.0271692425012589, 3.77906311409814, 5.901807699884687, 6.966430229800088, 10.071870701653616, 9.556861536843435, 11.991195917129517, 16.816978658948624, 14.996416875294276, 11.138189026287623, 8.348415204456874, 3.1199780574866702, 1.2489797345229556, 0.5630873335259301, 0.45271264761686325, 0.3394405357539654, 0.1758012037192072, 0.29705796284335, 0.472787187567779, 0.4624211809464863, 1.0376896836927958, 1.596696253333773, 3.946552046707698, 3.4471350737980435, 5.244059954370771, 3.3550401755741666, 0.9301806411572865, 0.729475193790027, 0.20118270175797598, 0.22796352899500302, 0.1440139686954873, 0.12280062985207353, 0.13333690805094583, 0.12039468038294997, 0.2837924403803689, 0.1103875305769699, 0.25384717008897234, 0.17721388648663247, 0.1331100466528109, 0.11524168189082827, 0.09564187896570989, 0.05225732357108167, 0.15232400063957485, 0.06462365482002497, 0.09531918806689126, 0.17472388009939874, 0.17400331662169524, 0.19823388356183255, 0.08780250605195761, 0.10718279611319304, 0.11389993317425251, 0.1793383796300207, 0.14239130648119108, 0.19582815122391495, 0.23493745763386997, 0.10938221987869058, 0.18146254707659992, 0.12209886179438659, 0.1525463294237852, 0.11266440232949597, 0.22066990179674967, 0.08980600283082042, 0.1925415854368891, 0.13197051494249276, 0.10592260730585881, 0.12385261697428566, 0.0872897846358163, 0.110054424165615, 0.15463334029274328, 0.16791327483952045, 0.16806384176015854, 0.08450405233140502, 0.10015895443835429, 0.16703943030110427, 0.15415911216820988, 0.18971733269946917, 0.12191713654569217, 0.1991221537547452, 0.13830725848674774, 0.19778708182275295, 0.12948122780237878, 0.12210157593446118, 0.10005059239587613, 0.12455336722944464, 0.17745591992778437, 0.0807971680270774, 0.08459796157798596, 0.11885227529065949, 0.12097037663417202, 0.17338082859558718, 0.16598543471523694, 0.12934770568140916, 0.09564535306500536, 0.09792285585509879, 0.14030702332300798, 0.1076690818050078, 0.12019019706973008, 0.10882852851812329, 0.2321765800671918, 0.24969733133912086], [0.05054861293839557, 0.03600119872550879, 0.009391945853297199, 0.019590135497440184, 0.07383991099361863, 0.035314623066889386, 0.018527200212702155, 0.030910272616893053, 0.06729088776877948, 0.023247630934097936, 0.0224506491462567, 0.0010615311413338141, 0.036500305336500914, 0.019035175276388015, 0.038734724545585256, 0.07340549930397954, 0.06174756879253047, 0.07780320011079311, 0.05865063318716628, 0.026422409773139015, 0.021651165260534202, 0.03305679100698658, 0.12808967461543425, 0.04115367813834122, 0.01976647148174899, 0.024183873552829027, 0.023639754625037313, 0.06258766978446927, 0.028525062570614473, 0.020326418935188224, 0.018768271830465113, 0.0037895841524004936, 0.05214307862999184, 0.0274897606245109, 0.05828388500958681, 0.020684266429660574, 0.022959972798292125, 0.041917070746421814, 0.02706541500187346, 0.04639221954026392, 0.00582567648130602, 0.01665241813420185, 0.016620365836258446, 0.05498662890334215, 0.024179169608812247, 0.027347135956266096, 0.05429095409012266, 0.0558637507658984, 0.08419497963041067, 0.04742197446259005, 0.02315569113540862, 0.10015564997281347, 0.016621480330026576, 0.04366826445662549, 0.03314698527434042, 0.022170202141361575, 0.07021755179656403, 0.08923768904060125, 0.04719887214845844, 0.023834489086376767, 0.06760438451809542, 0.06811651560877051, 0.05134668207860418, 0.020914644335529635, 0.019981073448434472, 0.054245295468717813, 0.009032701424855207, 0.03859390138781496, 0.0758912648473467, 0.0725794236308762, 0.1467663917158331, 0.0737227958493999, 0.12309421838394233, 1.6823458288397108, 3.92963752576283, 10.004879644938878, 15.696572950908116, 32.28110483714512, 31.219211646488734, 35.68761900493077, 39.93543495450701, 42.760885170527864, 50.2633068220956, 53.478071553366526, 47.29727717808315, 36.873103278023855, 32.8738626071385, 25.48830791882106, 11.826217021260943, 9.931621313095093, 5.01813189472471, 3.736342115061624, 4.78812871660505, 3.1067254543304443, 2.88219267981393, 6.411026843956538, 11.1558643749782, 11.809389352798462, 19.436942849840435, 22.12012869971139, 20.93211007118225, 22.03811911174229, 16.397552388054983, 7.955327817371913, 3.1388995221682956, 0.46617309962000164, 0.07535020102347646, 0.05652151922030108, 0.03240597753652504, 0.03855948269899402, 0.018449071994317428, 0.030559948379439966, 0.028905103249209266, 0.016202121939776198, 0.055980038097394366, 0.02205746015533805, 0.05183551227673888, 0.02562451365936015, 0.04584139838282551, 0.03256622715187924, 0.03037640804957066, 0.08090177777090243, 0.029082662292889187, 0.028989977802016904, 0.043172801578683515, 0.05405244903106775, 0.021026249775396924, 0.05100105669615524, 0.025323529095788087, 0.032897437057857, 0.046604763849505355, 0.09630177462739603, 0.028745074157736132, 0.048187087156942914, 0.032361998289291344, 0.03444774369043963, 0.04615316826051899, 0.05165192784209337, 0.046420436419014416, 0.05416574063045638, 0.021778349864429662, 0.059262033951069625, 0.018016319322798933, 0.031014739868364165, 0.04922867912266936, 0.038625287025102546, 0.03993713270340647, 0.0877207765089614, 0.04970084110807095, 0.0831420561298728, 0.021884990124297992, 0.04923526091235025, 0.040034885850868056, 0.038161240318523984, 0.0275319315759199, 0.029760162545634166, 0.057750149363917966, 0.10455947116549526, 0.04318444863227861, 0.06585309920566422, 0.040171447808721235, 0.07829019826437746, 0.037588885852268765, 0.02697209608075874, 0.07056214580578463, 0.10225304921290704, 0.015358456942651953, 0.030252572015992234, 0.018958641615297114, 0.06472949271223374, 0.01231903226913086, 0.05520294247461217, 0.06960630031036479, 0.10364378815782921, 0.05775071254798344, 0.03249600895547441, 0.04774096056020685, 0.04645921130265508, 0.05445627575474126, 0.05334975477308035, 0.03990055627322622, 0.03460300946608186, 0.007557475540254797, 0.07088081977729287, 0.10126945842057467, 0.05358699097165039, 0.03382807158465896, 0.04451703712610262, 0.04014941577666572, 0.03142846302528467, 0.044780193362385035, 0.027049382915720344, 0.05975265548165355, 0.08797889801540545, 0.05642943523292031, 0.031200770421751907, 0.03300007565745285, 0.08946279981838805, 0.12338628699736935, 0.04169155624029892, 0.06536216554897172, 0.04570889067170875, 0.017661413277632425, 0.032011158365224085, 0.042121170687356164, 0.020206910258691226, 0.009544918180576392, 0.05202286597341299, 0.03574339273784842, 0.023864470156175748, 0.010643824302990521, 0.0448465778359345, 0.02409501769579947, 0.005194762322519506, 0.07362985690789563, 0.04960120502593262, 0.032481749542057514, 0.017479191002036844, 0.027283087339518324, 0.06391767305987221, 0.02450856952262776, 0.06978881265968084, 0.027070631239829317, 0.05428595667971032, 0.045543687750718424, 0.023645756267277256, 0.03945926084582295, 0.042301494761237075, 0.042269464515681775, 0.021352509768413644, 0.027311456888648014, 0.05209561510543738, 0.02997596382296511, 0.072489361677851, 0.016794145439884493, 0.01714918888839228, 0.03608541849202343, 0.01007554359135351, 0.01231888892860817, 0.022142014100349376, 0.05326640692406467, 0.051760218638394556, 0.020023354661784003, 0.10261847424720015, 0.09248988702893257, 0.10258363825934273, 0.13008075420345577, 0.15344351556684288, 0.7334617770143917, 2.9695122114249637, 6.677217977387564, 17.692467314856394, 23.483452115740093, 42.294018336704795, 44.33350222451346, 47.76417180470058, 52.43627255303519, 58.218552998134065, 63.847615242004395, 63.84433569226946, 59.31638922010149, 47.37745244162423, 41.404412678309846, 32.86291919435774, 16.23189170019967, 12.095090593610491, 6.856679958956582, 4.843475026743753, 5.812050001961844, 4.471320824963706, 4.492029062339237, 8.668539558138166, 14.173102242606026, 16.107265336172922, 24.829462357929774, 28.876511846269878, 28.49572798183986, 29.537521771022252, 23.857892274856567, 11.706456133297511, 4.126360135419028, 0.6496466345020703, 0.11052661668509245, 0.07626454731715576, 0.020897468917870095, 0.04958081165594714, 0.03562415377902133, 0.003908152209727892, 0.02741826169325837, 0.06995157285460404, 0.014543850207701325, 0.01427984410630805, 0.003099105433128508, 0.001325293818289148, 0.05225573240646294, 0.06717497363154377, 0.010765349924830454, 0.01314224028361163, 0.0227511655206659, 0.031080547587147782, 0.05657596826287253, 0.04628386089046087, 0.06141845216708524, 0.03701771542962108, 0.04005412571132183, 0.012166912351468844, 0.02680791774764657, 0.023417965276166797, 0.03732879998694573, 0.047272476234606335, 0.03761521979634251, 0.08298710587301425, 0.04123774862715176, 0.07861340484981026, 0.02591294702142477, 0.04553469716172133, 0.05441081730116691, 0.01727368988628898, 0.06712248894785132, 0.04494947088616235, 0.03297378242548023, 0.03730983493317451, 0.049543163140437434, 0.03288858217586364, 0.0533069561767791, 0.04589328256302646, 0.08003807733101503, 0.07716851202504975, 0.07940229001854147, 0.038736576946186166, 0.03678905591368675, 0.022373704971479516, 0.030143103961433684, 0.008158596498625619, 0.13145603612065315, 0.023674412497452328, 0.05005422214578305, 0.05782858801207372, 0.04077808864946876, 0.0269181237090379, 0.040210175194910595, 0.023413478463355984, 0.052111828699707985, 0.07196332061929361, 0.01756412662299616, 0.07117980266255991, 0.05987775019769158, 0.007877635503453868, 0.03725583033104028, 0.048609956965914795, 0.023822858996157135, 0.019352729665115476, 0.15317056807024138, 0.13079647294112615, 0.16634740600628511, 0.10589393920132092, 0.17185284915779317, 0.13767565094998904, 0.11313845403492451, 0.20769616296248777, 0.1789597842310156, 0.20550665259361267, 0.13050516428692, 0.13735976575740746, 0.12160221487283707, 0.10991251535181489, 0.12554003857076168, 0.14589774475565978, 0.20449834955590113, 0.20915687243853295, 0.11199108524514095, 0.2639457524887153, 0.17441581163023198, 0.14736031341765607, 0.2062183272625719, 0.15340709180704185, 0.15254604443907738, 0.1043121519365481, 0.2641995788684913, 0.17886854841240815, 0.11515256310147898, 0.1732138954102993, 0.11187857735369887, 0.17435004801622458, 0.10784464595573288, 0.07825827997710023, 0.11343622234250818, 0.0963009400293231, 0.1294388057930129, 0.11030493250914983, 0.11426927335560322, 0.23542814701795578, 0.08024555976901736, 0.15399965643882751, 0.12858436735613005, 0.19319624959358148, 0.15294085682502814, 0.17537344167275087, 0.1125356163829565, 0.16356453033430235, 0.18876244393842562, 0.1288683885442359, 0.1759246020976986, 0.20245933825416224, 0.12661192033972057, 0.10669345022844416, 0.15140293006386074, 0.12939187831112317, 0.1123321915843657, 0.20024183153041772, 0.09599848983011075, 0.11342943699232169, 0.1798958775720426, 0.10060218029788562, 0.16878876143268176, 0.15446092454450472, 0.07425853317337376, 0.13975625644837106, 0.09755133079098803, 0.21711402546082223, 0.1498879784984248, 0.21605308167636395, 0.21930719991879805, 0.39768413613949505, 0.9173021550689424, 3.364067405462265, 6.991054645606449, 19.910695348467144, 26.487382446016582, 47.4477265221732, 53.43473563875471, 55.07454177311489, 62.25698498317173, 68.03083378928048, 72.92680549621582, 74.73864555358887, 69.54935564313615, 57.298350947243826, 48.45480537414551, 39.09907681601388, 19.999469007764542, 15.696696281433105, 9.220592175211225, 7.580971905163356, 7.74644238608224, 5.856558859348297, 6.791520186832972, 11.667638284819466, 17.521161215645925, 20.68357821873256, 28.11242539542062, 34.273605006081716, 34.22970281328474, 33.425751073019846, 27.31989128249032, 13.441201584679739, 5.065931158406394, 0.8109914053763662, 0.1730676982551813, 0.15068341153008596, 0.1416036087487425, 0.10034273564815521, 0.12187400885990687, 0.1177853061152356, 0.10662132195596184, 0.17018321874950612, 0.15437635193978036, 0.1122303366927164, 0.13201761884348734, 0.1078796312212944, 0.13542169332504272, 0.18482751079968043, 0.10105673769222838, 0.1658419245587928, 0.11636039614677429, 0.14060445236308233, 0.08330894181770937, 0.15161016822925635, 0.12167584949306079, 0.1269505364554269, 0.1262960894299405, 0.06809286866337061, 0.14622728207281657, 0.27782564769898144, 0.20517098131988729, 0.23172025169645036, 0.15734351772282804, 0.21595142355987004, 0.19035082656357968, 0.15798611752688885, 0.11299285399062292, 0.09355374851397105, 0.12377466687134334, 0.13459618762135506, 0.13951017893850803, 0.10741326053227697, 0.23046954880867684, 0.06992004133228745, 0.14781125422034944, 0.16623117295759066, 0.1533388447548662, 0.19852473081222602, 0.14552756319088594, 0.17793436854013375, 0.14629327638873033, 0.13719968577580793, 0.12991200254431792, 0.08547955498631511, 0.08344278963548796, 0.1644136897687401, 0.27375948588762966, 0.1364921908825636, 0.17172704876533576, 0.13518716448119708, 0.20051735746009008, 0.12777118384838104, 0.19728877927575791, 0.17003641091287136, 0.15147342985229834, 0.17093865892716817, 0.09401508447315012, 0.13247915836317198, 0.1719512774475983, 0.1316188166716269, 0.15078759379684925, 0.20634460262954235, 0.2241424811737878, 0.11360220557876996], [0.06488740138177361, 0.011300496075169315, 0.04290641212303724, 0.02967436857787626, 0.07267386213477169, 0.03807786872078266, 0.0247791455393391, 0.0071795323830364, 0.007602548925206065, 0.07003388593771628, 0.0664368225261569, 0.024767720705962608, 0.05039206812424319, 0.03899639818285193, 0.016261313942127993, 0.039333406170564036, 0.053526346904358695, 0.015388865489512682, 0.05430913882862244, 0.08966739848256111, 0.07046350717012372, 0.03711882732542498, 0.03280614356377295, 0.06055294682404824, 0.04648280057257839, 0.05746774308915649, 0.01740207549716745, 0.033134327203567536, 0.038483181436147006, 0.06586835945823363, 0.03929820716647165, 0.03103426132085068, 0.05415721823062215, 0.01011596985959581, 0.005073003454266914, 0.018371679986427938, 0.03678066243550607, 0.008763574080408683, 0.026961470222366706, 0.004718891295072223, 0.0787759411281773, 0.05470738799444266, 0.0132833882900221, 0.05063569273001381, 0.029817454649933746, 0.033767692146024535, 0.016782544187403152, 0.04919885750859976, 0.021456295092191015, 0.07087398692965508, 0.04520501395953553, 0.039070504384913614, 0.056195374578237534, 0.12719890741365297, 0.04409058465223227, 0.011853446984397513, 0.02719588710793427, 0.03995851334184408, 0.0617584457088794, 0.04909851914271712, 0.03460868201883776, 0.044117213759039126, 0.043250585440546274, 0.06010157854429313, 0.010091333949406232, 0.021327113899003183, 0.08678169761385236, 0.14799067244998046, 0.5366208851337433, 1.2883810145514352, 3.9041676010404314, 9.932492443493434, 16.303880248750957, 20.666747944695608, 37.69013500213623, 52.4892213003976, 61.01948996952602, 66.5804946081979, 78.43501772199357, 68.973954473223, 66.5400560923985, 67.37784903390067, 74.25687830788749, 67.13104901994977, 73.60808331625802, 68.75901194981166, 61.850994791303364, 55.99836383547102, 49.477469035557334, 35.840368202754426, 30.278731278010778, 29.082666635513306, 29.380280562809535, 33.08005387442452, 37.04964658192226, 43.07899454661778, 52.21784550803048, 50.40005431856428, 56.702872957502095, 62.71128599984305, 57.421379225594656, 61.523317745753694, 57.7594507762364, 40.14678873334612, 21.04839859689985, 8.783661655017308, 1.8623560667037964, 0.4815331239785467, 0.05138977923031364, 0.04404827460114445, 0.018292932604838694, 0.1062154494492071, 0.07947532752794878, 0.0391758876586599, 0.055449148906128745, 0.05867211560585669, 0.06030308308878115, 0.09660389912979943, 0.044727942773274014, 0.01468411018140614, 0.022105576769847955, 0.036362542371664724, 0.036810680824731074, 0.043397291496928246, 0.03283270142440285, 0.028452075951333557, 0.031717491801828146, 0.0117810608686081, 0.022188783822847263, 0.06421039985226733, 0.0715887692889997, 0.05724669673613139, 0.004217468759244574, 0.08900409657508135, 0.10159991176000663, 0.07386625172304255, 0.04995937312820128, 0.029799303838184903, 0.04837464441412261, 0.010650501935742795, 0.06910483579018287, 0.027637586263673644, 0.05866184937102454, 0.06969132753355162, 0.03940622315609029, 0.05774444288441113, 0.04509918285267694, 0.02623601789985384, 0.05729422811418772, 0.040306052193045616, 0.056387169286608696, 0.07015689076589686, 0.012273695951859866, 0.12707617399947985, 0.08129118223275457, 0.04173938278108835, 0.028517018537968397, 0.03847623323755605, 0.07483437191694975, 0.04371144642521228, 0.05024097194629056, 0.06369341045085873, 0.06109923536756209, 0.051920549677951, 0.04078433456431542, 0.024834651400202086, 0.08700344964329686, 0.06985687650740147, 0.07000556388603789, 0.008574474852399101, 0.036414925275104384, 0.05807497764804533, 0.030250923175896918, 0.047022541253162284, 0.01050305797252804, 0.006456715320902211, 0.06664640163736683, 0.04884815329153623, 0.05261089799127408, 0.10858546370374304, 0.023396040113376718, 0.04224201777417745, 0.026801140879147818, 0.047363264220101495, 0.039298963733017445, 0.012818001476781709, 0.07819125428795815, 0.021683899486171346, 0.08053690913532462, 0.08441788516938686, 0.06329422151403767, 0.05853218811431101, 0.017492580194292322, 0.02475672504598541, 0.06656606987650905, 0.05384436608957393, 0.06041521778596299, 0.05990202818065882, 0.06683085459683623, 0.07816216549170868, 0.0358336175392781, 0.0372344836193536, 0.04117595783567854, 0.04148482019081712, 0.024126006390101144, 0.05937458933996303, 0.02592615470556276, 0.05864839402160474, 0.03540674437369619, 0.011046874104067683, 0.004122013300989887, 0.10492821423602955, 0.04957891854324511, 0.018915200107065693, 0.023625658060024892, 0.0342885152702885, 0.08476012466209275, 0.061069155910185406, 0.07320842559316329, 0.0629996694624424, 0.048478568837578805, 0.043606721330434084, 0.04512592391776187, 0.03808999753424099, 0.02080390233147357, 0.08062543081385748, 0.020936744221087013, 0.04747539891728333, 0.10301396516816956, 0.04532292977507625, 0.0079399343480223, 0.05976008544010775, 0.09720953234604426, 0.028301746517952, 0.044883873513234515, 0.01754920224526099, 0.05348057632467576, 0.0053748972547639695, 0.021024468620972972, 0.057751472507204325, 0.037988064611064534, 0.13513653219810554, 0.11300654004194907, 0.3676522033555167, 0.8276636621781758, 2.5152070692607333, 7.3646353994097025, 16.42792991229466, 25.70592028754098, 30.210951600755962, 50.90164130074637, 63.35518945966448, 73.75403022766113, 75.9868824822562, 89.335935320173, 78.81508418491909, 80.56639153616769, 80.49070480891636, 82.74532576969692, 75.7261026927403, 81.85485853467668, 79.87168284824916, 73.43883909497941, 65.92145102364677, 58.34107058388846, 44.91142211641584, 36.61573157991682, 36.37661279950823, 36.32564776284354, 39.20276478358677, 44.689034598214285, 51.74451337541853, 60.30654226030622, 60.48452731541225, 64.41409492492676, 73.08147934504917, 67.28509058271135, 70.92812837873186, 67.9782498223441, 49.89936712809971, 29.656280381338938, 13.62766865321568, 3.6941617727279663, 0.6741429971797126, 0.03614057660368936, 0.08068982378712722, 0.0613667613693646, 0.0253131305466273, 0.05364835089338677, 0.08962732420435973, 0.029806526843458414, 0.006835889171010682, 0.03152929672173091, 0.041322507829006226, 0.017745220834123235, 0.030645375938287804, 0.036297949230564494, 0.08775874054325478, 0.011890036137109357, 0.009025147633760102, 0.02113405881183488, 0.04974525122504149, 0.028175549182508672, 0.02157920322913144, 0.03235505687605057, 0.03174152551218867, 0.005685740932156997, 0.023493966287268058, 0.03305735079837697, 0.04365263440247093, 0.029094923420676162, 0.02399121710498418, 0.07438647773649011, 0.053594308971826515, 0.06785063166171312, 0.010213864651242537, 0.022511062511642064, 0.05610042717307806, 0.04594303953594395, 0.018965070734598806, 0.04054381425625511, 0.045166113546916416, 0.0719501773959824, 0.07087780029645988, 0.0665803530386516, 0.03606483852490783, 0.025612983653055768, 0.09244274241583687, 0.02955151302739978, 0.04251880917165961, 0.029157691302576234, 0.046551108692905734, 0.03249677909272058, 0.01706245175695845, 0.010622480135810162, 0.041211455395179133, 0.04803273740357586, 0.03950479054557426, 0.08095235577119247, 0.032940103339829614, 0.03259676801306861, 0.018807177332096865, 0.013284954857746405, 0.0785713085372533, 0.07938363030552864, 0.023462159958268915, 0.00897811328260494, 0.036168267617800405, 0.012794424081221223, 0.026449289937902774, 0.025732539827004075, 0.025847665167280605, 0.27687157317996025, 0.23613127214568003, 0.13601590001157352, 0.20770416967570782, 0.10877066983708314, 0.0965154588754688, 0.12283781357109547, 0.15375931933522224, 0.13855406881443091, 0.1326601236526455, 0.15218285178499563, 0.0570392075127789, 0.17287922836840153, 0.11426825555307524, 0.10319298984748976, 0.1875569179121937, 0.12928815744817257, 0.05658042623794504, 0.12673394807747432, 0.19691755276705536, 0.18310268835297652, 0.11956555130226271, 0.1816787961870432, 0.18809880954878672, 0.22787130251526833, 0.114149593349014, 0.12740473422620976, 0.15042768525225775, 0.1440195326826402, 0.12582209200731345, 0.1442771317171199, 0.2636733885322298, 0.14257121325603553, 0.08650334219315223, 0.12044026436550276, 0.15832397368337425, 0.17268363386392593, 0.1723546122333833, 0.07879761353667293, 0.2700169309973717, 0.12984727030353888, 0.15441277569958142, 0.13843812075044426, 0.19454675141189778, 0.14698615563767298, 0.15836479435009615, 0.16043547966650554, 0.0705644663955484, 0.10082015967262642, 0.18670182808169297, 0.10842545836099557, 0.10920736140438489, 0.204885670915246, 0.20971367827483586, 0.11931308199252401, 0.09803323314658233, 0.17781457996794156, 0.10520756031785693, 0.23948160665375845, 0.07615231083972113, 0.17961541190743446, 0.22514721511730126, 0.12767257913947105, 0.11583571215825421, 0.0979094480031303, 0.17829370711530956, 0.16188272700778075, 0.5213573755962508, 1.047547983271735, 3.103232030357633, 8.977056077548436, 18.25890530858721, 28.81691540990557, 35.29437875747681, 58.61282852717808, 73.24737453460693, 85.05738748822893, 88.40998363494873, 98.61456666673932, 90.7156321661813, 91.41992936815534, 90.92028440747941, 95.18417848859514, 86.99153668539864, 91.6988022668021, 89.36679227011544, 85.25915622711182, 76.56383310045514, 67.79139191763741, 53.325499534606934, 42.19689294270107, 44.971614360809326, 44.56487723759243, 47.354537282671245, 53.95638901846749, 61.550047465733115, 68.86115741729736, 71.32733712877545, 75.00358731406075, 83.17544705527169, 80.3762401853289, 79.99748693193708, 77.97879205431256, 57.62945345469883, 34.910431725638254, 16.78613039425441, 5.2926035438265115, 0.7846493731651987, 0.15369835974914686, 0.13704077287444047, 0.19360480909901007, 0.13709136444543088, 0.2396470606327057, 0.32223970017262865, 0.13950359714882715, 0.20641332465623105, 0.12925428498004163, 0.14224729420883314, 0.09998478806976761, 0.141180243609207, 0.3038830208991255, 0.11299615167081356, 0.12133116727428776, 0.1604785802108901, 0.10039011774850742, 0.11585547109799725, 0.15415475597339018, 0.11079757607408933, 0.16062599872904165, 0.19878029424164975, 0.21005807550890104, 0.07284850347787142, 0.08214141375252179, 0.13379087511982235, 0.19418274451579365, 0.1499816977552005, 0.1503845982785736, 0.09219142661562987, 0.14562645288450377, 0.12291921063193254, 0.10991972139371292, 0.20887162988739355, 0.1362510666783367, 0.2005436031946114, 0.15295251405664853, 0.15919644758105278, 0.140772796901209, 0.260355786553451, 0.21912037208676338, 0.1437254013227565, 0.2390214242041111, 0.1868278727467571, 0.11668926849961281, 0.21310313711208956, 0.15589162920202526, 0.17730774145041192, 0.09719679624374424, 0.06785616850746529, 0.1273181124457291, 0.2147882788309029, 0.11823582622621741, 0.16537967936268874, 0.28221970477274483, 0.16348777445299284, 0.20355135894247464, 0.0760227038658091, 0.17691539893192904, 0.22958213356988771, 0.12594437758837426, 0.08332540986261197, 0.14169446458773954, 0.13522609882056713, 0.17078568999256405, 0.0730719111327614, 0.1363044809550047, 0.1072002344631723], [0.03672243056020566, 0.02537654134045754, 0.02273377636447549, 0.01971010218507477, 0.019336952029594352, 0.10881868976035289, 0.08380662011248724, 0.07030038056629044, 0.03142382184575711, 0.07444992076073374, 0.028914151513682942, 0.047264282924256155, 0.034528713274214945, 0.06860642467758485, 0.03687839861959219, 0.03652841364964843, 0.018966538066576635, 0.06817998577441488, 0.03070173505693674, 0.04040083674980061, 0.060040272905358245, 0.018598115603838648, 0.016422871433730637, 0.059999418311885426, 0.06299394941223518, 0.018031710193359425, 0.08037854584732226, 0.022002374986186624, 0.013172997427838189, 0.0437344284062939, 0.025546653462307792, 0.036607466371996064, 0.04588459052943757, 0.06199203138904912, 0.014436489004375679, 0.03262752939813903, 0.02423448208719492, 0.03696001281163522, 0.07148829182343823, 0.029738564775990586, 0.06362151966563293, 0.01577464657436524, 0.033359302274350605, 0.023131326639226506, 0.022008900796728473, 0.017752107964562516, 0.03767803856836898, 0.10285001075161354, 0.025096491278548325, 0.03327801717179162, 0.0070295752957463264, 0.00964962546381035, 0.01228023533310209, 0.07781506768826928, 0.015211063869563597, 0.052520791933472664, 0.006432200698847217, 0.07172079184757811, 0.01758724431108151, 0.03919557195955089, 0.03361419056143079, 0.1098448857665062, 0.14042181787746294, 0.20784101661826881, 0.22029180851365837, 0.7758896489228521, 1.4468508596931184, 5.326316203389849, 13.739784785679408, 24.977040358952113, 35.163203716278076, 56.69391672951834, 58.89694731576102, 66.76193986620221, 65.0552260535104, 67.43162809099469, 68.3585455758231, 63.94189534868513, 62.843871525355745, 67.06730624607631, 72.5160071509225, 66.05243151528495, 65.85857677459717, 61.275565828595845, 61.27099391392299, 55.907978194100515, 64.07505062648228, 64.61783000401088, 66.70472145080566, 62.94683688027518, 67.11344228472028, 70.46040344238281, 68.12023626055036, 69.67901597704206, 64.02952602931431, 72.87552084241594, 69.94540296282086, 59.954060145786826, 64.08827999659947, 65.5716370173863, 62.60859162466866, 64.69518429892403, 63.27407618931362, 63.06738812582833, 60.70429883684431, 45.361946787152974, 20.72435024806431, 10.667166301182338, 2.3168983161449432, 0.9001989471060889, 0.19705602819366114, 0.12145732050495488, 0.11550458706915379, 0.08830915457968201, 0.06300593912601471, 0.012651056417130997, 0.0649363983954702, 0.02336493776445942, 0.039870520920625756, 0.04400237849248307, 0.0320673308867429, 0.03810363269544073, 0.06256685911544732, 0.04566105056021895, 0.015982751568247165, 0.033672412258705924, 0.026760761260188053, 0.047593348659574986, 0.06538284729634013, 0.01670471961343927, 0.008842803221861166, 0.0034109088134885368, 0.006913952080399862, 0.03121016134641, 0.05928896500595978, 0.03739719970950058, 0.07498706943754639, 0.008287466413873647, 0.019543194444850087, 0.07552054723990814, 0.04408024377854807, 0.053471626447779794, 0.01461708958127669, 0.022686306054570844, 0.008913973911798425, 0.036054528185299466, 0.04879286286554166, 0.04846975127501147, 0.028031031401561837, 0.03482900573206799, 0.0259749820855047, 0.02174705413303205, 0.05620709627068468, 0.04896226591829743, 0.005822427994904241, 0.017614804707201462, 0.0022316849250013805, 0.04821027609120522, 0.0445554489935083, 0.011438328589844917, 0.04554875979998282, 0.034584858654333014, 0.048052971317831955, 0.008778108300508132, 0.00917761614878795, 0.054901879879512956, 0.013571434038957315, 0.02621705284608262, 0.013403733260929585, 0.02088124175289912, 0.030565943236329725, 0.03679047744455082, 0.03624544758349657, 0.056528969534805844, 0.052935973940683265, 0.025541004658277546, 0.01087001564779452, 0.03264478115098817, 0.029016579767423015, 0.013834668306766875, 0.0719321555058871, 0.0710098228550383, 0.07112798294318573, 0.0215176007311259, 0.029584974981844425, 0.04016541563240545, 0.026595441291907003, 0.011160735672871982, 0.04783370951190591, 0.05667285288551024, 0.023412362273250307, 0.01768820862551885, 0.006772198057400861, 0.010042908601462841, 0.029339199420064688, 0.0739444393132414, 0.008795563613862863, 0.03876572341791221, 0.04835086854706917, 0.06582612743867294, 0.04498131114191242, 0.0092084530208792, 0.06077625269868544, 0.019083887305376784, 0.04375118822125452, 0.04622637201100588, 0.0512117282487452, 0.03433732907953007, 0.058028308009462695, 0.013714678718575408, 0.01612831429312272, 0.02500795942199017, 0.07221220726413385, 0.027929252845102122, 0.026787968818098307, 0.06047720195991652, 0.019058264126735072, 0.013205520459450781, 0.021363076254991547, 0.028949462476053407, 0.028565632179379463, 0.020292853504153233, 0.033782972754644494, 0.030633586392338787, 0.055942847593022246, 0.04884135437064937, 0.05413334397599101, 0.04219501904611077, 0.017529317776539495, 0.057025602885654995, 0.03582009433635643, 0.05726534966379404, 0.013411946927330323, 0.08420241637421505, 0.0195426600985229, 0.04997222458145448, 0.095448238642088, 0.13114988112023898, 0.09822801340903554, 0.2028183647032295, 0.4730748864156859, 0.9939754179545811, 2.432349366801126, 7.668883987835475, 20.12971646445138, 34.01323168618338, 46.475649220602854, 69.35945442744664, 71.96978146689278, 78.37110124315534, 73.51383100237165, 75.35244246891567, 76.15035275050572, 72.81799670628139, 71.99026475633893, 75.22871589660645, 78.11840220860073, 75.86919389452252, 75.27011326381138, 70.10592719486782, 70.60703822544643, 65.4056931904384, 70.62190737043107, 74.37664440699986, 78.83439322880336, 75.06000668661935, 76.35305949619838, 78.87252494267055, 77.33742468697685, 78.79319041115897, 74.01000881195068, 80.78437042236328, 77.25979246412004, 67.78512464250836, 72.37828690665108, 74.65709454672677, 70.67080879211426, 75.06186880384172, 71.3739595413208, 72.26643480573381, 72.34524127415249, 56.44659907477242, 31.388462815965923, 17.85891662325178, 4.324850627354213, 1.321786759155137, 0.21470232201474054, 0.11836671563131468, 0.05974204997931208, 0.057926330981510024, 0.034095838466393094, 0.024992227587582808, 0.036987883637526205, 0.019934161233582666, 0.021919232394014086, 0.061763019034905095, 0.07044452176030193, 0.05344410506742341, 0.004182074252249939, 0.05340506894780057, 0.044196866984878264, 0.02236449725127646, 0.017358852816479545, 0.07497260985629899, 0.027777396707928607, 0.010277883582083243, 0.03389829656641398, 0.009818808840853828, 0.03411091551450746, 0.011618314244385277, 0.04978689291913595, 0.05990843355123486, 0.033976263632731776, 0.09964495737637792, 0.006143449697576995, 0.005727844030064131, 0.08809492071824414, 0.05897837917187384, 0.029532452978725945, 0.03154800393219505, 0.037974035899553976, 0.020093191182240844, 0.05067554309165903, 0.03304800058581999, 0.030696656222322156, 0.026448837015777826, 0.035338921405907185, 0.03930407649438296, 0.012496058662821139, 0.06074554220374141, 0.09562604874372482, 0.022365698258259466, 0.015600224058809025, 0.03571504354476929, 0.04280707459630711, 0.01343748189641961, 0.006943479379905122, 0.060132947218205245, 0.04093834844284824, 0.04387607937678695, 0.03636156188856278, 0.032527940813452005, 0.03174723877704569, 0.012402814380558473, 0.014834234357944556, 0.06336130827133145, 0.0415087283721992, 0.015176996322614806, 0.00980906083714217, 0.030918530388070003, 0.087275874667934, 0.02137657062017492, 0.1259740838514907, 0.11933168742273535, 0.09278488691364016, 0.09681282684739147, 0.13208552662815365, 0.20973889263612883, 0.19368615187704563, 0.11251957581511565, 0.08818504373942103, 0.24832419359258243, 0.12218502217105456, 0.15737555814640863, 0.12515961112720625, 0.10830683008368526, 0.07345684404884066, 0.16814556451780455, 0.134255033784679, 0.11714651967797961, 0.1253703369625977, 0.24789780218686375, 0.1528635581157037, 0.16099187838179724, 0.1440723498484918, 0.19264913323734487, 0.15034509396978787, 0.04638239774586899, 0.18470119472060884, 0.11584587661283356, 0.10577672227684941, 0.09570389028106417, 0.20795460338039057, 0.11686830674963337, 0.19217752425798348, 0.15648221251155647, 0.11823323422244617, 0.16262337512203626, 0.19410292165619986, 0.10253232065588236, 0.19200360216200352, 0.09064406821770327, 0.10711689679218189, 0.1702596896461078, 0.09193954084600721, 0.14021548894899233, 0.0723388015425631, 0.11261567672980682, 0.11862240119704179, 0.10835187802357332, 0.17198409140110016, 0.10204871517739125, 0.13429407668965204, 0.10698403963553053, 0.12140854740781443, 0.21415364502796105, 0.06789458037487098, 0.13167923342968735, 0.08635114678846938, 0.22725739117179597, 0.07305342105350324, 0.10815061775169202, 0.16427962481975555, 0.20048387854226998, 0.306854000048978, 0.3096770042819636, 0.6670558346169335, 1.4038082893405641, 3.212236455508641, 9.655762195587158, 22.585232428142003, 38.61026062284197, 55.19410637446812, 80.27757576533726, 83.6796430860247, 88.03016035897392, 83.81700202396938, 86.94504628862653, 87.95367458888462, 84.84486988612584, 82.20363725934709, 86.42172186715263, 90.24430806296212, 84.10517856052944, 85.98222746167863, 82.14031832558769, 81.77097293308803, 75.59239155905587, 82.6278247833252, 84.9249826158796, 90.06828934805733, 86.21298408508301, 87.29873044150216, 90.85891791752407, 88.90257617405483, 89.36950206756592, 85.18024553571428, 92.77457101004464, 89.73324026380266, 78.27921826498849, 82.68681498936245, 85.29971286228725, 81.03169849940709, 83.08910873958042, 80.07821110316685, 81.43299170902797, 82.00929614475795, 64.84863526480538, 37.9453249658857, 20.429150819778442, 5.32108507837568, 1.74696418430124, 0.4055099519235747, 0.16431201808154583, 0.22158747113176755, 0.12518246418663434, 0.24262949345367296, 0.11774213771734919, 0.14653748114194187, 0.13967215881815978, 0.11055529157498054, 0.17034092385854038, 0.14573936111160687, 0.1302217673510313, 0.09804503965590682, 0.18695887071745737, 0.08985030438218798, 0.0934734031824129, 0.07517775813383715, 0.20207859868449823, 0.2049147393554449, 0.15288827036108288, 0.10236011525349957, 0.10712607058563403, 0.09767037297465972, 0.19140943618757383, 0.1490794633116041, 0.14843150308089598, 0.13122565991112164, 0.16084669902920723, 0.0606382658172931, 0.13565729425421783, 0.26782998549086706, 0.1729580605668681, 0.0819825144218547, 0.09705101978033781, 0.15231859950082643, 0.15804586932063103, 0.1286645566246339, 0.12892716324755124, 0.0747601944687111, 0.2057354681726013, 0.2383070353950773, 0.09636676471148219, 0.10190635174512863, 0.17102506357644284, 0.1741131850119148, 0.14053498394787312, 0.07344037600393806, 0.1974823246044772, 0.14686446716742857, 0.10446545335331134, 0.11757548951676913, 0.18777573188500746, 0.11367008622203555, 0.0895579643547535, 0.08453791122883558, 0.1857572394822325, 0.11685495318046638, 0.15242371814591543, 0.10411777200975589, 0.16770598239132337, 0.11530386283993721, 0.1380117293447256, 0.14751630861844334, 0.16444851218589715, 0.15942808586571897, 0.12275252171925136], [0.08504903808768306, 0.008162791541378413, 0.05544396150591118, 0.030492064343499284, 0.06402370094188622, 0.06487473991832562, 0.01958094474061259, 0.02111685964544969, 0.05011208761217339, 0.029211929999291897, 0.04891323497784989, 0.022808486462703774, 0.02404992056212255, 0.08790712258113281, 0.04152742540463805, 0.07717393351984875, 0.03864140223179545, 0.019142665401367203, 0.05591528210788965, 0.04764896138970341, 0.06107365459735904, 0.07748442435903208, 0.01108875752626253, 0.03521751792037061, 0.039572691544890404, 0.0336389876236873, 0.09709300752729177, 0.0599157413733857, 0.014930599901293005, 0.04701645140136991, 0.022973010848675455, 0.07702637250934329, 0.03966633955548916, 0.02196387660556606, 0.046001149274941, 0.02170549047046474, 0.0048682186170481145, 0.05119183699467352, 0.07906100047486168, 0.04594287329486438, 0.07251625880599022, 0.04027309913986495, 0.04252216113465173, 0.03417192259803414, 0.056505383657557626, 0.03813956791002836, 0.05434911811192121, 0.026467293168285062, 0.056556921784899065, 0.03584639096100416, 0.026679922294403826, 0.02853969517829163, 0.029154614146266664, 0.0029014941953521755, 0.07925656105258636, 0.052909090383244414, 0.1636747515627316, 0.32485965958663393, 0.35389989987015724, 0.5928005448409489, 1.288696397628103, 1.2038063470806395, 2.0452276596001218, 3.909366156373705, 7.442706227302551, 10.144087672233582, 21.941803182874406, 30.039306776864187, 49.80483341217041, 65.64574650355748, 72.21040453229631, 65.54783248901367, 62.85949107578823, 54.9343375478472, 61.14980343409947, 50.31794398171561, 59.50740214756557, 47.00410141263689, 45.34914820534842, 41.505821636744905, 44.817371300288606, 40.64428322655814, 45.301500933510916, 36.719099930354524, 35.45868975775582, 34.35144567489624, 43.96789843695504, 44.16594641549246, 52.375180516924175, 64.3690983908517, 61.28998334067208, 65.94621440342495, 56.87913485935756, 57.957071440560476, 61.92622988564627, 62.11630480630057, 52.7096529006958, 50.891913822719026, 48.82560988834926, 51.09021193640572, 48.44955601011004, 47.58549540383475, 47.87771579197475, 57.44439860752651, 64.83343260628837, 64.70821911948067, 65.87163938794816, 50.48553800582886, 24.47141821043832, 12.73874478680747, 3.963676316397531, 1.0105271126542772, 0.1297992164535182, 0.12380908216748919, 0.06123320532164403, 0.09884871688804456, 0.007645011646673083, 0.056455582579863925, 0.02695647281195436, 0.07227408287248441, 0.03502734151801892, 0.03222050677452769, 0.08650278579443693, 0.02605142753704318, 0.05625676164137466, 0.06235730714563813, 0.056366100774279664, 0.02270731858776084, 0.02839359810708889, 0.05995291830705745, 0.06309391797653266, 0.006463289901148528, 0.05420145532116294, 0.010638048273644276, 0.011572958419232495, 0.07602954349879708, 0.06741870341024228, 0.041053495835512877, 0.019495844574911252, 0.008461684520755495, 0.018081512967390672, 0.007043669740336814, 0.0517076830645757, 0.055379649956843684, 0.011870680077533637, 0.016160314004602175, 0.06762389239988156, 0.043591830879449844, 0.07276232953050307, 0.007680028294479209, 0.019688467096005167, 0.07144862466624805, 0.02611644476253007, 0.03166579082608223, 0.022576349454798868, 0.030831067224166224, 0.03162261564284563, 0.019160548191783682, 0.06435581669211388, 0.020257008195455586, 0.01446002908051014, 0.034392765390553644, 0.036734569551689286, 0.016668194073385427, 0.01760591589845717, 0.010233670240268111, 0.007753783354668745, 0.02841179641628904, 0.026849075985540236, 0.05130812432616949, 0.047174030981425724, 0.016906256388340677, 0.00782930854308818, 0.04516746383160353, 0.027963892057804123, 0.023158004939822213, 0.033362036770475764, 0.006692236098128238, 0.02512522554025054, 0.0357642339409462, 0.10184239981962101, 0.019920946764094487, 0.007715330775161939, 0.038331559393554926, 0.012143986349526261, 0.08343166844653231, 0.0854785575398377, 0.006761413591448218, 0.0619560486770102, 0.0737678777160389, 0.09617406755153622, 0.052599607168563774, 0.03304768167436123, 0.013116163334676197, 0.0253537697052317, 0.03638149046206048, 0.08794457771416221, 0.04158990151648011, 0.05018426677478211, 0.04356682686401265, 0.02870361227542162, 0.013171092440773333, 0.06691029747681958, 0.07713694657598223, 0.01053243175348533, 0.04038228899506586, 0.06024394876190594, 0.023382703507585183, 0.01878619024397007, 0.0645135964400002, 0.031327117034899335, 0.03252697390105043, 0.06209128749157701, 0.025175883268405284, 0.053468386443065744, 0.054663917648472955, 0.027655253619221703, 0.025204040775341646, 0.09231655525841884, 0.016462501271494796, 0.0828205526673368, 0.05297027727855103, 0.006405406623213951, 0.025396273138799837, 0.041952598839998245, 0.04741887016487973, 0.032832050030784946, 0.04184356504785163, 0.0017883341726181762, 0.04536169448069163, 0.06130088918975421, 0.09352538575019155, 0.06473477850002901, 0.3748612036662442, 0.5855617704136031, 0.7073450184294156, 1.5548231516565596, 1.731072568467685, 2.509516711745943, 5.671251271452222, 9.430731756346566, 14.851513930729457, 32.59943308149065, 42.08862958635603, 62.911477497645784, 75.24129213605607, 81.99189785548619, 73.28808403015137, 72.51349885123116, 62.19288090297154, 70.54099559783936, 57.88039459500994, 68.0726341520037, 54.362532070704866, 54.24980449676514, 51.394779273441856, 51.74001094273159, 52.02652338572911, 54.45830604008266, 47.544674737112864, 45.430925028664724, 41.83937685830252, 54.48327439171927, 55.54959011077881, 61.29427037920271, 75.06178542545864, 70.3382054737636, 74.82174600873674, 66.11597279139927, 66.52779252188546, 71.18329402378627, 70.9109663282122, 62.00944151197161, 58.56673417772566, 57.796335288456504, 59.763373783656526, 56.710116454533164, 56.07327931267874, 56.1906795501709, 63.713105065482004, 72.10825906481061, 70.30112293788365, 75.86071709224156, 61.42112364087786, 34.958950996398926, 19.039597954068864, 6.018149205616542, 1.5087813479559762, 0.3306373581290245, 0.08406421236161675, 0.06860222454581942, 0.05116624265377011, 0.02764561163660671, 0.06199722218194178, 0.03202221170067787, 0.020478176684784036, 0.023917889521856393, 0.03135975796197142, 0.05705961784613984, 0.04278878468487944, 0.09017487482300826, 0.049188299503709586, 0.08644525959555592, 0.029267230603311743, 0.07497569040528365, 0.07201292831450701, 0.012923493316130978, 0.0035181156500974403, 0.04807926794247968, 0.04705313300447805, 0.07988305243530444, 0.0168838291096368, 0.0571440818852612, 0.01733076316304505, 0.09592083828257662, 0.016313956385212283, 0.03995396037186895, 0.05407863709011248, 0.025354103883728385, 0.06841534921633345, 0.06809235976210662, 0.029661819072706357, 0.058992574124463966, 0.03406463942623564, 0.050576795890395126, 0.01698768907226622, 0.040342638801251135, 0.09991684635835034, 0.03341187516759549, 0.045802284231675525, 0.0681894581232752, 0.1160710688148226, 0.04928989315937672, 0.012115018841411387, 0.0024050069415742265, 0.05613932419302208, 0.05774392041244677, 0.017016491187470298, 0.04575454929311361, 0.01990605122409761, 0.012346947199798055, 0.04893052405012505, 0.028752724640071392, 0.013751702133699186, 0.0238717491405883, 0.03192526940256357, 0.07501335588416883, 0.027349405655903474, 0.020394511620647142, 0.02330823428928852, 0.026896142567108785, 0.06170499072011028, 0.21995685648705277, 0.08172072882630996, 0.11004468040274722, 0.1456511787005833, 0.18869423759835108, 0.1224569518651281, 0.13434808807713644, 0.10419277727071728, 0.15295712809477532, 0.18589567419673714, 0.2656677115176405, 0.15989296377769538, 0.13164473670933927, 0.12280217691191606, 0.23079592415264674, 0.15419146471789905, 0.15777019411325455, 0.11145135134990726, 0.16411696640508516, 0.09291912828172956, 0.24433106929063797, 0.18659197326217378, 0.19505512341856956, 0.10028037827994142, 0.12780443206429482, 0.1384052253727402, 0.15576734872800962, 0.1847873550972768, 0.10269849388194935, 0.11641917085008961, 0.1349358351102897, 0.23589742183685303, 0.06627108356250183, 0.1949629783630371, 0.15911042291138852, 0.1435183667178665, 0.12141305288033825, 0.19196202153606073, 0.1834717028375183, 0.14234796166419983, 0.09313843758510691, 0.1324702695544277, 0.17242527487022535, 0.18388560919889382, 0.12423284085733549, 0.2649686304586274, 0.0952094689543758, 0.12015401758253574, 0.12172576252903257, 0.12038661938692842, 0.11562848756355898, 0.14560779317149095, 0.08340335318020412, 0.1460175197571516, 0.15578386427036353, 0.20331639583621705, 0.3637054094246456, 0.7890685360346521, 0.8658200747200421, 1.0778434319155556, 2.4230175018310547, 2.4099909322602406, 3.5446906047207967, 7.8689599718366345, 12.78654144491468, 19.72794382912772, 39.11456782477242, 49.500068051474436, 71.03583935328892, 83.54408373151506, 90.79113129207066, 84.2517786026001, 82.99965763092041, 76.36294678279332, 80.7489901951381, 69.78008447374616, 78.31498064313615, 65.21580587114606, 62.95340987614223, 61.40946456364223, 64.92288371494838, 60.12554168701172, 62.022823742457796, 54.400580406188965, 52.90216316495623, 50.863606861659456, 62.71919304983956, 64.13536099025181, 72.28099822998047, 82.56136526380266, 80.53936999184745, 85.21495178767613, 76.33322238922119, 76.70251219613212, 81.381012235369, 79.63065678732735, 70.55822018214634, 70.16418784005302, 68.1205975668771, 67.23925331660679, 67.41444519587925, 65.04770810263497, 66.25283145904541, 76.52576392037528, 81.65290219443185, 80.50275993347168, 85.12501430511475, 70.97729383196149, 41.50750657490322, 21.612185852868215, 7.614331075123378, 2.01026280437197, 0.6614212798220771, 0.30636955318706377, 0.15714610474450247, 0.19166171550750732, 0.11494045305464949, 0.13473022542893887, 0.1826497255159276, 0.1523929533681699, 0.13426802094493592, 0.13829965889453888, 0.16642446044300283, 0.09254815283098392, 0.23681803100875445, 0.32469222428543226, 0.20838410247649464, 0.09872497245669365, 0.18267488559441908, 0.19216005876660347, 0.12273872031697206, 0.15444434114864894, 0.14996229165366717, 0.09840086341968604, 0.16882084256836347, 0.14594528291906628, 0.21785463286297663, 0.07104374960597072, 0.27806348779371803, 0.10318149546427385, 0.08837153230394636, 0.112917719808008, 0.13408465364149638, 0.21586451679468155, 0.13453753505434307, 0.09049359629196779, 0.19180472354803765, 0.14581477349357946, 0.21951633798224585, 0.12968119207237447, 0.14136306808463164, 0.18539453537336417, 0.10605779862297432, 0.09381135433380093, 0.1801471390894481, 0.19047328856374535, 0.18578347164605344, 0.13195258804730006, 0.11151215487292834, 0.10866356986973967, 0.10260973471615996, 0.1391938187714134, 0.11065032040434224, 0.11040609529508011, 0.18879681852247032, 0.18261391243764333, 0.15849117828266962, 0.071906099761171, 0.1723821336137397, 0.09233568994594471, 0.15758534760347434, 0.1367954553237983, 0.05489035835489631, 0.13658315528716358, 0.1440886618303401, 0.21395619133753435], [0.03736367668690426, 0.006551945166263197, 0.04251542328191655, 0.034218897577375174, 0.056982963745083125, 0.04893469364781465, 0.06678603057350431, 0.04631355358287692, 0.008325807883271148, 0.010352439313594784, 0.03645762209115284, 0.007482203106129808, 0.024327741636495506, 0.028291965435658182, 0.044520154994513304, 0.09494268255574362, 0.06076971162110567, 0.06253918845738683, 0.05088150221854448, 0.02408020188366728, 0.06068026034959725, 0.05372680989759309, 0.02985575795173645, 0.04895130757774625, 0.039225502139223475, 0.04303285373108728, 0.020088682317041924, 0.06868432728307587, 0.006521802944397288, 0.017773167995203818, 0.06886995410812752, 0.02914727239736489, 0.02354647302334862, 0.022147199804229394, 0.04267842774944646, 0.08696378248610667, 0.020775953474055444, 0.06118415402514594, 0.012150781877738024, 0.09219272940286569, 0.018048354657366872, 0.06998488892401968, 0.005740472839014339, 0.04316287121868559, 0.013553367195917028, 0.045990669301577976, 0.1105516410565802, 0.027448782198397175, 0.03158702648111752, 0.05296950374862977, 0.04771783269409623, 0.052608702930488756, 0.1767532562038728, 0.5750080538647515, 0.46377846811498913, 0.8964347605194364, 1.3554234227963855, 0.9768012080873761, 2.9425223682607924, 7.677438957350595, 11.717062558446612, 16.411438362939016, 20.257427828652517, 28.382541826793126, 31.35337093898228, 47.79914903640747, 59.094519342694966, 65.99304526192802, 62.566909381321494, 61.07486711229597, 57.61202737263271, 44.834814752851216, 50.03475625174386, 42.50769281387329, 42.94833367211478, 38.82611683436802, 30.753324508666992, 29.21932554244995, 19.994379452296666, 17.41067443575178, 30.862546716417583, 33.325394766671316, 22.230518204825266, 17.832133054733276, 19.7578193460192, 28.563144615718297, 20.065965005329677, 28.922092029026576, 38.26757894243513, 35.80673892157418, 40.06202071053641, 41.767657552446636, 42.577754974365234, 36.335114683423726, 46.18767418180193, 44.491205487932476, 34.759603704724995, 30.100079195840017, 30.450796467917307, 41.07912581307547, 26.239809444972447, 35.172840867723735, 32.92037384850638, 38.978973729269846, 45.26430375235421, 56.31089728219168, 58.87876388004848, 60.73684419904436, 59.66968427385603, 46.35337134769985, 26.53201072556632, 17.02289547239031, 6.258688458374568, 0.6725811181323869, 0.27014973387122154, 0.11657265547130789, 0.04152927441256387, 0.12574353122285434, 0.012090801926595824, 0.05981765913644007, 0.010482251544349959, 0.04003548974703465, 0.057264515065721104, 0.0355520288992141, 0.10811530678932156, 0.03364757787702339, 0.022961736989340613, 0.05420878689203944, 0.06734189324613128, 0.08855388859020812, 0.017971174691670706, 0.03703088240165796, 0.036775288438158374, 0.019835246094901646, 0.03638334286266139, 0.0860798888440643, 0.02736483554222754, 0.03229434495525701, 0.02349733860631074, 0.04900052172264882, 0.03056365657331688, 0.010941738495603204, 0.03825376535366688, 0.011993768026254006, 0.015947326951261078, 0.10545920860022306, 0.05047681714807238, 0.0597899341955781, 0.0495354990874018, 0.0438076287641057, 0.013994800874830356, 0.056495595789913616, 0.013470035462108041, 0.024239474408594624, 0.03061882486300809, 0.04755436343007854, 0.059427223301359584, 0.046003914305141995, 0.04400799336976238, 0.05415214618135776, 0.05498090885313494, 0.02679805693748806, 0.009941042683619474, 0.029356627592018673, 0.041969643639666696, 0.05102638301572629, 0.06735658352928502, 0.0434421969444624, 0.029523984861693213, 0.01281600573565811, 0.012261287242706333, 0.045310176709400754, 0.04643696892474379, 0.018088907302756394, 0.04185917813863073, 0.029282477285180773, 0.0484492527320981, 0.03306515055841633, 0.01819585799239576, 0.018596863706729243, 0.07503686033721481, 0.09179841913282871, 0.04057473848973002, 0.08946142239230019, 0.022395423181088905, 0.009598695473479373, 0.05680792885167258, 0.07719785187925611, 0.010877095312545342, 0.015996953306187476, 0.032411409209349325, 0.020602765892233168, 0.06271847776536431, 0.11496748588979244, 0.0649169719378863, 0.04200182655560119, 0.08893563239169971, 0.034268457775137255, 0.05426375162122505, 0.054822915366717746, 0.06042266810046775, 0.020964345329308083, 0.058891065285674164, 0.023026523512921164, 0.06202389539352485, 0.0230650863543685, 0.08643601116325174, 0.06370365632964031, 0.03146788930254323, 0.10929206293076277, 0.03830135779987488, 0.03703274837295924, 0.015356769086793065, 0.009727407629335565, 0.060453466804964204, 0.05871540614004646, 0.036739841768784184, 0.15567371089543613, 0.05233854082013879, 0.01685426364253674, 0.00900661853873836, 0.024113875880305256, 0.09123370836355857, 0.02180101632672761, 0.023378562747633884, 0.014329959006447877, 0.05936892357255731, 0.08755479327269963, 0.12455239013901778, 0.5223883145621845, 0.5357681566051075, 1.0510708285229546, 1.3276944650071008, 1.0387086804424013, 3.223096924168723, 8.863724010331289, 13.109623994146075, 18.46753886767796, 26.410497154508317, 35.58093636376517, 39.29281691142491, 59.28776264190674, 69.40076146806989, 74.58971091679165, 70.87101418631417, 68.20822129930768, 65.17606217520577, 53.56369073050362, 58.65098108564104, 50.97226626532418, 51.68380001613072, 48.253912108285085, 41.65332841873169, 39.4005000931876, 31.470712116786412, 28.401564257485525, 39.22071892874581, 43.51102311270577, 33.35216270174299, 30.33990321840559, 31.110361167362758, 41.99064956392561, 30.090483733585902, 37.8899929864066, 51.52186182567051, 46.93532119478498, 50.317624364580425, 50.44185120718819, 54.90040602002825, 47.70726605824062, 54.42566340310233, 54.359520026615684, 44.679911613464355, 37.79743603297642, 40.10908085959298, 49.68987546648298, 37.57303353718349, 44.8375106539045, 42.70644950866699, 48.85883617401123, 53.959293365478516, 62.81020055498396, 64.86189242771694, 67.99493939535958, 69.41192722320557, 57.77090835571289, 36.93033906391689, 25.263575383595057, 8.74735905442919, 1.5899497696331568, 0.3789180288357394, 0.19507082471890108, 0.040287959056773355, 0.05744562963289874, 0.05468939324574811, 0.03312024420925549, 0.025125052513820783, 0.08115423350994076, 0.03894838165225727, 0.06394064147025347, 0.03866884218794959, 0.029978291198079075, 0.049677601283682246, 0.05351327492722443, 0.031186578861836876, 0.04791993095672556, 0.06317836165960346, 0.04484616732224822, 0.0737201359921268, 0.07878058230770485, 0.029895224941096137, 0.033690132200717926, 0.013761366168702287, 0.05290034067417894, 0.07175721560737916, 0.014962523277582867, 0.05826048233679362, 0.060268314954425604, 0.05363433914525168, 0.04552826125706945, 0.05026762819449816, 0.05694440259997334, 0.016834067047706673, 0.011465883048783456, 0.033724276082856317, 0.06553716651563134, 0.06216675415635109, 0.07680468154805047, 0.04818479710125497, 0.05458973341488412, 0.022300043209855045, 0.03198905508699162, 0.06703965339277472, 0.004465413512662053, 0.03829734426523958, 0.036714043867375167, 0.05203602276742458, 0.053865417638527494, 0.022049857170454094, 0.010958000435493886, 0.003676589412082519, 0.04421931292329516, 0.05261088442057371, 0.026798352100221173, 0.05803404163037028, 0.01796915435365268, 0.014667087434125798, 0.09951794919158731, 0.015299380291253328, 0.0522729705886117, 0.019630107995388762, 0.06171476162437882, 0.18125255405902863, 0.0908010405089174, 0.09376240481755563, 0.09502037481537887, 0.11784714779683522, 0.12106447587055819, 0.14655648012246403, 0.1742066057132823, 0.055489223184330125, 0.1125307445015226, 0.1718588066952569, 0.0965716347896627, 0.10328761155584029, 0.07678625253694397, 0.17686929926276207, 0.13183009890573366, 0.11459782001163278, 0.24057266382234438, 0.2131287178822926, 0.1117217204134379, 0.24272437979068073, 0.08909137653453009, 0.21511630980031832, 0.15683074880923542, 0.16725259886256286, 0.10378050617873669, 0.11169967481068202, 0.12718036983694347, 0.11178871896117926, 0.1141848364578826, 0.14091068878769875, 0.21868230987872395, 0.09858212047921759, 0.1588761383401496, 0.11956262003098216, 0.23052163315670832, 0.11500871367752552, 0.20646145993045398, 0.1253462489694357, 0.18802878473486218, 0.14456018938549928, 0.21333869732916355, 0.1467210655765874, 0.13650163609002317, 0.10292767586984805, 0.10338219255208969, 0.2326633068067687, 0.20497059635818005, 0.07454414213342325, 0.11036023989851985, 0.19136797769793443, 0.1801936323089259, 0.35610098604645046, 0.6211298704147339, 0.8030058081660951, 1.5002110706908363, 1.9586911031178065, 2.110847967011588, 5.08161541393825, 11.179557732173375, 16.263238498142787, 22.264811038970947, 32.38490744999477, 44.22274446487427, 46.425448485783164, 68.58446625300816, 78.51160076686314, 86.62814589909145, 81.57142066955566, 79.27003138405937, 75.11757946014404, 65.41306522914341, 66.99494075775146, 58.882231031145366, 59.15227276938302, 56.224107333592, 46.15170683179583, 44.04687861033848, 34.22628777367728, 31.425118037632533, 48.879093647003174, 48.02057075500488, 35.4178204536438, 32.51663834708077, 35.004388741084504, 44.262734821864534, 34.94231353487287, 44.572325706481934, 54.975536891392295, 55.77723741531372, 58.95319298335484, 59.179092815944124, 61.87181854248047, 52.59547315325056, 64.05856949942452, 60.79886381966727, 54.14028351647513, 45.07613958631243, 45.53209774834769, 57.043213094983784, 43.237118176051546, 52.691879408700125, 50.39715691975185, 56.35195418766567, 61.74946771349226, 72.03980541229248, 74.29965141841343, 78.86160237448556, 78.76237515040806, 65.89453370230538, 44.33842502321516, 27.001769747052872, 10.378220251628331, 2.634706748383386, 0.6526797946010316, 0.3991087611232485, 0.15092995044376167, 0.18333842498915537, 0.13552975681211266, 0.1447040523801531, 0.12855726666748524, 0.18168077750929765, 0.11957864702812263, 0.13013537627245697, 0.2912564070097038, 0.12808659406644957, 0.11853451734142643, 0.10874445802931275, 0.11446283225502286, 0.18484345637261868, 0.13025601979877266, 0.14195770903357438, 0.17731057772678988, 0.12060372345149517, 0.1430158165416547, 0.26867402877126423, 0.12614890161369527, 0.11711172440222331, 0.20904325853501046, 0.17020098279629434, 0.19363576386656078, 0.13002655282616615, 0.2945319398173264, 0.11461430841258594, 0.10051975186382021, 0.17013931753379957, 0.11068286972918681, 0.13423101364501885, 0.24012165516614914, 0.21351673134735652, 0.1983509308525494, 0.14873957155006273, 0.1319456805608102, 0.1470518106860774, 0.12320030054875783, 0.09483915846794844, 0.16192026356501238, 0.06939409526863269, 0.1335122822118657, 0.13878140518707888, 0.15858572535216808, 0.13715347754103796, 0.16684920979397638, 0.07432464284024068, 0.1297676781458514, 0.13949356840125152, 0.14004890860191413, 0.12636660278907844, 0.1390166397073439, 0.1264973429164716, 0.08287765817450625, 0.20013422944716044, 0.1796479815883296, 0.1851270432983126, 0.08096237094806773, 0.13846911623009614], [0.025763153630707945, 0.051177421518202336, 0.022187006061098406, 0.03874857344531587, 0.005964447494729289, 0.014288527658209205, 0.037112442310899496, 0.0233732074099992, 0.04466983981962715, 0.02309417345428041, 0.021934026153758168, 0.01060520124156028, 0.020435534151537076, 0.029603997711092234, 0.008392351812549999, 0.06350068614951201, 0.061462197319737503, 0.06529511950377907, 0.03872713852407677, 0.062291170337370465, 0.029172259449426616, 0.038541321709219895, 0.03730383329093456, 0.03000586007588676, 0.05201592795284731, 0.057975965818124156, 0.048751363663801124, 0.057060357449310165, 0.03766464767977595, 0.029911340147789036, 0.05961483144866569, 0.018464289838448167, 0.06080265449626105, 0.021264849829354456, 0.015140352038932698, 0.045117265810923915, 0.07983416398721081, 0.04260624858683773, 0.04017368697428277, 0.010920921889399844, 0.03415674037699189, 0.05050784655447517, 0.03181865119508334, 0.059559578342097144, 0.04699654996927295, 0.011629297181830874, 0.047835032655192275, 0.11455881781876087, 0.10077249937291656, 0.07145450077950954, 0.05942273818488632, 0.39000496534364565, 0.8824883145945412, 2.1670200271265845, 4.677636291299548, 6.7374493053981235, 9.092763560158865, 16.834502015795024, 21.57774189540318, 24.731459753853933, 27.08278747967311, 31.06434324809483, 42.494428702763145, 55.91084780011858, 55.684319155556814, 54.89118923459734, 57.63933726719448, 51.202550411224365, 42.66334635870797, 33.786327838897705, 30.449917520795548, 28.341022866112844, 32.18468121119908, 29.12741650853838, 22.172928060804093, 18.35219529696873, 17.80327023778643, 22.722983939307078, 15.241891520363943, 22.09415807042803, 14.139605845723834, 20.194623061588832, 27.57770245415824, 14.576403481619698, 14.012000441551208, 13.48288643360138, 15.778156961713519, 20.719943353107997, 10.408754110336304, 15.170283385685511, 19.56347475733076, 20.63245337350028, 14.0683833360672, 25.56593493052891, 26.384644644601003, 26.718060902186803, 27.94083615711757, 39.740944453648154, 27.553046771458217, 20.37543429647173, 22.64187240600586, 20.039237022399902, 23.542720249720983, 30.356266226087296, 44.595299925122944, 38.34454413822719, 43.96649490083967, 52.5555488041469, 60.61686965397426, 61.83461093902588, 59.67064312526158, 50.147390025002615, 32.97997202192034, 20.985946450914653, 9.173061285700117, 6.1966171605246405, 3.33772656747273, 1.2689626451049532, 0.16604024677404336, 0.04266603430733085, 0.006648188573308289, 0.035914274996944835, 0.051064333479319296, 0.0589695650019816, 0.01286033951743905, 0.04071923591462629, 0.10097624986831631, 0.07625949901661702, 0.039670400587575774, 0.01448110437818936, 0.046789617144635746, 0.011859971098601818, 0.09535388834774494, 0.026500339520030787, 0.06905864791146346, 0.047580062943909845, 0.05221027734556368, 0.06026082392781973, 0.04233121798772897, 0.021186891244724393, 0.05403787409886718, 0.03998271329328418, 0.046416975890419314, 0.024282586827342, 0.006212837960837143, 0.032706351418580325, 0.042892298594649346, 0.09049603901803493, 0.029929938792650188, 0.05390937313703554, 0.023831150694085017, 0.04085177415981889, 0.03103718241410596, 0.03995813675490873, 0.0128944528655016, 0.04097694351470896, 0.09832158338810716, 0.033986367019159455, 0.10242956331265823, 0.05522376671433449, 0.05623288060139332, 0.013862968306057155, 0.03731449307607753, 0.009588341877263571, 0.052489962694900374, 0.06475800475371735, 0.002008161283031638, 0.04673013676490102, 0.05045488350359457, 0.111119941276099, 0.054107552859932184, 0.05344553338363767, 0.025250279544187442, 0.017987376411578486, 0.013057750799427075, 0.023412540388692702, 0.04514354207952108, 0.04555928727079715, 0.046352138476712365, 0.052586796427411694, 0.04694987015266504, 0.02454510863338198, 0.032697130127676895, 0.022473690499152457, 0.09581766024764095, 0.03881646426660674, 0.029283138856823956, 0.04922135772981814, 0.06444699822791985, 0.02427123493648001, 0.06396010863993849, 0.03245998213865927, 0.04047701587634427, 0.026396471075713634, 0.02762528951279819, 0.07684504759630986, 0.017717599369851605, 0.08992490930748837, 0.011272641364485025, 0.05106062189276729, 0.022023284042786275, 0.04417202242517045, 0.03762318579746144, 0.09150350745767355, 0.057104041533810754, 0.061442567301648, 0.03460204255368028, 0.02282751428096422, 0.02338603511452675, 0.02463998648870204, 0.04847900988534093, 0.09530860292060034, 0.03248033479654363, 0.010543908325156994, 0.04903633140825799, 0.0843237859330007, 0.021407949472112314, 0.06022138747253588, 0.0579583714050906, 0.171551932447723, 0.07096090048019375, 0.027241454127111604, 0.06406520692897694, 0.14715357736817428, 0.0619427901027458, 0.0958313870110682, 0.18400085158646107, 0.46146591220583233, 1.2034372240304947, 3.0406936832836697, 5.919018822056906, 8.072279027530126, 12.119486587388174, 19.95258777482169, 24.708310093198502, 29.674852916172572, 35.00598335266113, 42.7951397895813, 52.56737811224801, 67.1835218157087, 66.73600918906075, 66.44450446537563, 65.02311842782157, 61.47886317116873, 49.15985992976597, 44.584835938044954, 39.43399388449532, 34.94410964420864, 39.3865897996085, 38.41290051596505, 36.10781478881836, 31.79715585708618, 29.712202957698278, 34.336392402648926, 22.04539908681597, 29.696208204541886, 28.572512524468557, 33.89448697226388, 39.144042083195274, 26.09751902307783, 23.034431729997905, 23.29020013128008, 28.48336018834795, 32.23292255401611, 21.443457535334996, 28.781165191105433, 31.43058279582432, 32.66619832175118, 26.949415070669993, 33.967915534973145, 38.920042582920615, 39.08320713043213, 40.22825288772583, 50.042951651981895, 36.595248290470664, 31.064940793173655, 31.966709273202078, 31.45200409208025, 30.02673748561314, 40.455483300345286, 52.89179992675781, 47.541759967803955, 49.65405055454799, 58.74159254346575, 65.98244231087821, 68.99279103960309, 66.45033400399345, 58.33487973894392, 41.583109923771445, 28.932298932756694, 15.002298525401525, 9.063754831041608, 4.814352086612156, 1.7977331514869417, 0.28433019295334816, 0.0621100693408932, 0.08685806673020124, 0.029039392114749978, 0.04402122480262603, 0.012355546782990652, 0.051927467342466116, 0.020477448955976536, 0.11660614795982838, 0.011479118722490966, 0.03821271059236356, 0.030973040498793125, 0.05459209132407393, 0.050369533976273875, 0.016236769634165933, 0.06729218377066509, 0.026814811663436036, 0.06627614543374095, 0.10897248650767974, 0.029787443046058928, 0.05317093026159065, 0.018181615542354326, 0.030771990572767596, 0.032197935307132344, 0.01630468590052, 0.00457549436915932, 0.008226619634245123, 0.06132588641984122, 0.009324941368374442, 0.051017992930220704, 0.0100126942852512, 0.011655191774480045, 0.05237526652802314, 0.016316806232290607, 0.036031217114733796, 0.055869525098907094, 0.032918810910944424, 0.05780348900173392, 0.03850409388542175, 0.022674731943490248, 0.06021021878612893, 0.0797112745099834, 0.0223381955376161, 0.03789935972807663, 0.06911088153719902, 0.02453825034068099, 0.06883652268775872, 0.05872450529464653, 0.029928673324840407, 0.04807651309030397, 0.013932423150566007, 0.08275747605200325, 0.07714099064469337, 0.052273574484778304, 0.013780511882422226, 0.04850700284753527, 0.07044395179088626, 0.03755982759009514, 0.1442004301186119, 0.11527410229401928, 0.14634382724761963, 0.20906668156385422, 0.21375997258084162, 0.11827140860259533, 0.12020460915352617, 0.08739484221275363, 0.3188247148479734, 0.08878044464758464, 0.10954514292201825, 0.11099950809563909, 0.16168487976704324, 0.11321221079145159, 0.1504426673054695, 0.1314997880586556, 0.11449907959571906, 0.06954437720456294, 0.2301175519824028, 0.1502161451748439, 0.15470554998942784, 0.13988171757331916, 0.11925246167395796, 0.1159384830721787, 0.15478135592171124, 0.23886712534087046, 0.20432288040007862, 0.11305116050477539, 0.13169336052877562, 0.11704368091055325, 0.15518608848963464, 0.15691623065088475, 0.14039122951882227, 0.12841220945119858, 0.09865865244397096, 0.17972798086702824, 0.18842852328504833, 0.14213085759963306, 0.16636877985937254, 0.16097722202539444, 0.13271587208977767, 0.16404622234404087, 0.10019419754722289, 0.23740271106362343, 0.147468485470329, 0.2309036755136081, 0.17563087785882608, 0.3416930820260729, 0.1593655249369996, 0.21045717623616966, 0.2506395179246153, 0.7546098679304123, 1.7971294181687492, 4.598500217710223, 8.68434931550707, 11.706966825893947, 17.651224545070104, 25.114632061549596, 28.766589607511246, 36.02319615227835, 42.70222500392369, 52.16762740271432, 61.878822326660156, 75.90465750013078, 77.93838133130754, 77.0971212387085, 77.29539503370012, 72.54261875152588, 61.931385449000764, 51.00288002831595, 47.332094601222444, 44.736247607639854, 47.03232152121407, 43.674177237919395, 35.73377936226981, 31.59188870021275, 30.332715306963237, 36.65887294496809, 25.07015143121992, 34.835776805877686, 29.352609361921036, 30.927078110831125, 39.39084209714617, 23.387308154787334, 23.132613250187465, 22.634851251329692, 25.96205346924918, 34.28743192127773, 18.400493962424143, 27.328244754246303, 35.396909849984304, 34.912703786577495, 25.53569289616176, 39.39790146691458, 43.215286936078755, 39.758902072906494, 40.02440316336495, 53.50781331743513, 41.84369168962751, 33.661138670785085, 36.1409090587071, 34.24518687384469, 35.86613212312971, 45.44096864972796, 59.40172004699707, 57.369722843170166, 58.49096407209124, 69.19979872022355, 75.75708471025739, 78.63243688855852, 77.03685256413051, 67.06303310394287, 48.03181988852364, 32.87344571522304, 17.466650860650198, 10.519788929394313, 5.683628618717194, 2.231673015015466, 0.30553378803389414, 0.14871686776833876, 0.1419855018279382, 0.14082374131040915, 0.14812200968819006, 0.11686183352555547, 0.15182725872312272, 0.0991755739918777, 0.28475783286350115, 0.13568216934800148, 0.09974861717117683, 0.08656544850340911, 0.13528544349329813, 0.11161169596016407, 0.20173318364790507, 0.16834483668208122, 0.18942735397389956, 0.24475108246718133, 0.1458860875240394, 0.20159130197550568, 0.15351820870169572, 0.12725814352078096, 0.11266662792435714, 0.0937810984573194, 0.11727122084370681, 0.14708642954272882, 0.10216211194970778, 0.1408724058419466, 0.10481953328209263, 0.11328805743583611, 0.05401430857766952, 0.10835596958973578, 0.1353635700153453, 0.08461366966366768, 0.12891192335103238, 0.15939367056957313, 0.17402941307851247, 0.15840630712253706, 0.2107161594820874, 0.11333953788770096, 0.23227616186652864, 0.3128581664391926, 0.1457641954932894, 0.10866673184292656, 0.17251433937677316, 0.14238195626863412, 0.10276304291827337, 0.11936147511005402, 0.09489807566361767, 0.16648951838059084, 0.20186684147587844, 0.2660584662641798, 0.15642510700438703, 0.14444471629602568, 0.07840571206595216, 0.12261762895754405, 0.13739761444074766, 0.13284715504518577], [0.031987212864415984, 0.016972003038972616, 0.060865385058735094, 0.03886475899655904, 0.009365408348717859, 0.03632020517917616, 0.015538228010492665, 0.03274377941020897, 0.11111626361629792, 0.005737966924373592, 0.048999744800052474, 0.03829258094940867, 0.03762853265340839, 0.06412222422659397, 0.026172188110649586, 0.047296737254198105, 0.04625614612762417, 0.0412337113437908, 0.009799634289395596, 0.016504897835797498, 0.03510694046105657, 0.06002202709870679, 0.020181188692471812, 0.03302994816164885, 0.054651965254119465, 0.048630309623799155, 0.021464408674676503, 0.02073638640078051, 0.01676234759257308, 0.09182584551828248, 0.004834847416662211, 0.01698284942124571, 0.019183046716664518, 0.04801819979080132, 0.01334400860858815, 0.03585862834006548, 0.05631648629371609, 0.011399989664953734, 0.018662137079185674, 0.02473404840566218, 0.030933308880776167, 0.06089926431221621, 0.032045288676662106, 0.00810083790150072, 0.03706263444785561, 0.07177814841270447, 0.02244209960502173, 0.054795709505145035, 0.09835895709693432, 0.5813342801162175, 2.6471477150917053, 6.623793278421674, 9.809138468333654, 12.079972182001386, 22.135888951165335, 32.93610109601702, 36.620136737823486, 36.130337374550955, 37.27118641989571, 41.309663568224224, 47.003479548863, 55.47984756742205, 56.283149651118684, 51.856330735342844, 50.90226663861956, 42.384872981480186, 46.27865389415196, 39.36335154942104, 30.19755894797189, 17.517848661967687, 19.556976454598562, 30.496074404035294, 21.532206875937327, 17.818290506090435, 10.747208680425372, 16.017336538859777, 20.89540794917515, 22.190835305622645, 25.301036596298218, 23.888730117252894, 17.316019126347133, 22.25083647455488, 30.568221024104528, 32.801861899239675, 32.75178623199463, 30.956166744232178, 21.540456124714442, 21.207790272576467, 28.448318685804093, 22.968743460518972, 15.69178216797965, 20.29926814351763, 21.12434240749904, 16.452611650739396, 11.24481087071555, 17.541512489318848, 10.25270972933088, 20.849560260772705, 20.036339623587473, 16.299186740602764, 22.55043237549918, 18.619348321642192, 20.177902221679688, 26.652912855148315, 32.712945801871165, 25.393597023827688, 29.451061861855642, 34.975491183144705, 35.11410427093506, 47.67290026800973, 48.39529752731323, 48.05248383113316, 56.055464131491526, 54.99688523156302, 49.87556259972708, 33.79659032821655, 23.400021621159144, 8.990658913339887, 4.584859601088932, 1.965814309460776, 0.21011637523770332, 0.05051966663450003, 0.01851093572830515, 0.06788928780172553, 0.024594414380512068, 0.017394097621685693, 0.015686794949163283, 0.04840891382523945, 0.027753544505685568, 0.0680746974955712, 0.04996344433831317, 0.03641246219298669, 0.025016363078196133, 0.07444051626537528, 0.03244395514151879, 0.027015625798542584, 0.02772890859549599, 0.011893299042380281, 0.02376797060216112, 0.053562336401747804, 0.025985177074159895, 0.03744338758821998, 0.0231043684429356, 0.0626041174733213, 0.024198607940758978, 0.05058982715542827, 0.04327367937990597, 0.028074043736393963, 0.009544263394283397, 0.0752566039030041, 0.00807129533495754, 0.0266463738267443, 0.014379213863451566, 0.06681066139468125, 0.028430183018956865, 0.0303557059461517, 0.11671505283032145, 0.006220117793418467, 0.01980452542193234, 0.06321659032255411, 0.15765150476779255, 0.11097466692860637, 0.057711181097796986, 0.03263840970716306, 0.024641089108107344, 0.0457070586271584, 0.03348084146689091, 0.07013865852994577, 0.04403322808710592, 0.036459447350353, 0.038275848275848796, 0.026085752927299057, 0.06895826544080462, 0.050065272088561735, 0.0359088738581964, 0.005269287944039596, 0.039111179166606495, 0.03167997220797198, 0.03415290326146143, 0.05020516226068139, 0.04722782523770418, 0.033048702869564295, 0.058095862955919335, 0.009375383661660765, 0.0600508376955986, 0.043056096948151074, 0.08568924266312804, 0.01981848119092839, 0.011568121312718307, 0.01805171849472182, 0.05409355128982237, 0.008592346616621529, 0.013834673395779516, 0.04098742688074708, 0.00820754686303969, 0.08473682376955237, 0.025623604422435164, 0.02065179174366806, 0.03953895139108811, 0.04065686836838722, 0.07412224262952805, 0.07494155330849545, 0.02066433446348778, 0.05729606015873807, 0.028269312544060603, 0.009547444027183312, 0.033004665946854014, 0.04126256265278373, 0.02781561010384134, 0.022871513884248476, 0.019733961172667996, 0.010989751633522766, 0.04166035380746637, 0.06480681177760873, 0.05853121102388416, 0.08220770662384373, 0.04454172562275614, 0.07427389520619597, 0.02618068506542061, 0.08760432632906096, 0.03154834998505456, 0.07320983016065188, 0.013873665410626148, 0.12340120119707924, 0.15024670639208385, 1.3057508596352168, 3.7535918865885054, 8.352606705256871, 13.12130217892783, 15.59092559133257, 26.6185679095132, 38.302174023219514, 43.34396062578474, 43.39778137207031, 47.816842624119346, 53.128924574170796, 58.7275641305106, 68.59793881007603, 65.84003898075649, 61.84461634499686, 60.62947368621826, 51.65512480054583, 55.25740793773106, 44.19347170421055, 36.3283679825919, 23.405085120882305, 26.012417486735753, 42.06045464106968, 34.62610796519688, 32.1071115221296, 19.275953088487896, 24.159452778952463, 25.113633258002146, 33.24194342749459, 31.706645148141043, 39.31406102861677, 24.556007317134313, 26.16085880143302, 34.19220338548933, 30.4800066947937, 27.93991552080427, 22.98084201131548, 24.177865505218506, 28.099621602467128, 26.031952347074235, 27.155592441558838, 24.851936306272233, 23.92250531060355, 21.86306619644165, 27.981698513031006, 22.240346431732178, 23.984479767935618, 19.396287202835083, 35.057976722717285, 30.520785672324045, 24.70475435256958, 32.42644725527082, 30.517801421029226, 29.395872320447648, 35.18907185963222, 43.58272852216448, 34.187860761369976, 39.42695188522339, 44.402504784720286, 44.99751377105713, 53.51945849827358, 54.0643744468689, 54.92874424798148, 64.13866138458252, 62.47224017551967, 61.90649005344936, 42.45864200592041, 30.815507411956787, 12.482675875936236, 7.799590894154139, 3.8477608220917836, 0.468104644545487, 0.03315714633624468, 0.026105237060359547, 0.049581161101481745, 0.013180055040200906, 0.014752128228013004, 0.020272175149459924, 0.0487632753460535, 0.054664029606751034, 0.041893332198794396, 0.04330968923334565, 0.039433357771486044, 0.04376743234960096, 0.053427901651178084, 0.013845443442863013, 0.029419029065008675, 0.06984595209360123, 0.012383719556964934, 0.05247792887634464, 0.02298724990604179, 0.054829744821680446, 0.08806917709963662, 0.051406423694321086, 0.013346826225253088, 0.052602660576147695, 0.04613877653277346, 0.03238713461905718, 0.020284132632826055, 0.011290606427272516, 0.06523996139211313, 0.03295003030715244, 0.1380090694874525, 0.048505004561905346, 0.039317358817373, 0.1027923488457288, 0.012609359592066278, 0.03510040956150208, 0.015523507193263088, 0.07230077644011804, 0.06622819336397306, 0.06156994189534869, 0.019318497573424662, 0.04483649819823248, 0.03924229248825993, 0.01767934186916266, 0.05037255684978195, 0.02134890335478953, 0.028411207787160362, 0.012883543718739279, 0.06961732650441782, 0.007182001402335507, 0.032194773333945444, 0.05686420654611928, 0.027994941820257475, 0.05512824594708426, 0.06116075813770294, 0.09230703541210719, 0.1530438991529601, 0.1890885750097888, 0.10918558721563645, 0.12900938812111104, 0.11680212244391441, 0.250771805111851, 0.11408070847392082, 0.17157025289322647, 0.23435380895222935, 0.12680212727614812, 0.08041454213006155, 0.08084891989294972, 0.18365595223648207, 0.11474659559982163, 0.1376837119460106, 0.20532696294997418, 0.1413309598075492, 0.10357461829802819, 0.1504367369094065, 0.14941041198159966, 0.10518155207059213, 0.12646595388650894, 0.10058234671929053, 0.12421971799007483, 0.15489069505461625, 0.08755539038351604, 0.14376624913087913, 0.14462184107729367, 0.23066320270299911, 0.12816982317183698, 0.12855400969939573, 0.09872692663754735, 0.14415962302259036, 0.0937097572854587, 0.09931657356875283, 0.18529118091932364, 0.17551805105592522, 0.08836588010724102, 0.2229594960808754, 0.11895849316247872, 0.3046408359493528, 0.13993133205388272, 0.22583273904664175, 0.12633944781763212, 0.2571490571967193, 0.18224924057722092, 0.15629473328590393, 0.4001199411494391, 2.126664672579084, 5.448138100760324, 11.342123866081238, 19.77067698751177, 22.84547025816781, 33.486822264535085, 45.230577196393696, 50.79730715070452, 52.616547039576936, 59.64997223445347, 61.990959303719656, 68.38080065590995, 80.44124058314732, 78.99650859832764, 72.8855401447841, 73.15895870753697, 61.381588390895296, 65.09276022229875, 56.395133767809185, 46.86968503679548, 29.085289580481394, 31.49146638597761, 46.092980657305034, 36.52177456447056, 30.255423545837402, 18.297031811305455, 25.294958659580775, 32.03962366921561, 33.68434565407889, 38.421054227011545, 38.909839153289795, 27.21824434825352, 31.557762622833252, 43.029752663203645, 43.7823919568743, 44.04399510792324, 42.4734069279262, 31.656409672328405, 31.652727127075195, 41.34475197110857, 34.40721886498587, 29.607121876307897, 31.304142951965332, 32.05641399111067, 28.72383213043213, 21.896942138671875, 28.025762251445226, 19.07677255358015, 30.75563825879778, 29.405797822134836, 27.200248513902935, 34.85655886786324, 30.379250867026194, 32.28514174052647, 40.345771244594026, 47.154675824301584, 39.071565423692974, 46.25316095352173, 52.421101161411826, 51.14748593739101, 63.67078358786446, 61.77222306387765, 65.36402484348842, 74.22411755153111, 71.71374034881592, 70.7836058480399, 48.50120544433594, 36.09938662392752, 17.24093689237322, 11.015719209398542, 5.285505090441022, 0.6150780980076108, 0.19866146918918404, 0.08937070904565708, 0.15787437638001783, 0.0854897058701941, 0.13307112588414124, 0.14047307441277163, 0.16102964564093522, 0.11625911800989083, 0.27000564017466133, 0.19123426558715956, 0.11947105851556573, 0.09286022465676069, 0.2526498814778668, 0.13599293838654244, 0.0972392793212618, 0.10169996853385653, 0.06859334252242531, 0.09270929132721253, 0.19225433442209447, 0.09164202359638043, 0.11746525471763951, 0.11605307406612805, 0.13669923905815395, 0.13647856589938911, 0.15148948399083956, 0.1838851206536804, 0.14238475183291094, 0.07799099824790444, 0.1720522434583732, 0.15403367818466254, 0.22578566228704794, 0.1763648356177977, 0.11434449574777059, 0.21076483758432524, 0.1928330569394997, 0.20930526804711136, 0.21390376772199357, 0.19264321641198226, 0.21321179770997592, 0.2237758415618113, 0.2531357396926199, 0.20530907676688262, 0.1102190435464893, 0.05546924372070602, 0.21295797133019992, 0.20076042227447033, 0.10780014762920992, 0.19155846961906978, 0.14416536342884811, 0.094395382995052, 0.13562562023954733, 0.3299631385930947, 0.17471401420022759, 0.13563951663672924, 0.23658849618264607], [0.043434478608625274, 0.06068055211965527, 0.028799889609217644, 0.021357522445863912, 0.01901407283730805, 0.07649599561201674, 0.07804551853665284, 0.0457894429564476, 0.04642142029479146, 0.05841687108789172, 0.03016437603426831, 0.06476299877145461, 0.03772494230153305, 0.026446745431582843, 0.022118121186005216, 0.051991928169237714, 0.010246534416052912, 0.026031919655257037, 0.02031988464295864, 0.07319730440420763, 0.025587162002921104, 0.033571425891880474, 0.036182486319116185, 0.017487769381010106, 0.06202895047941378, 0.1011485502656017, 0.031199922252978598, 0.03308889249871884, 0.004702975408041051, 0.01867601481665458, 0.03411862027964421, 0.05280170203851802, 0.0550166744339679, 0.01484661253302225, 0.01910504911627088, 0.03138462287772979, 0.02658711397089064, 0.036869333391743045, 0.05473525542765856, 0.027128140475334864, 0.07879919452326638, 0.026519684553412453, 0.075863913100745, 0.026921087210731845, 0.03935637797362038, 0.056992727864001475, 0.07900730121348586, 0.5624273632253919, 5.843570504869733, 11.418416823659625, 19.36666876929147, 27.03701274735587, 33.56396811349051, 35.975805963788716, 41.727809633527485, 48.322668007441926, 56.78554957253592, 58.51118332999093, 52.62692070007324, 53.04611941746303, 47.06056942258562, 43.69783238002232, 38.26737397057669, 37.916677543095176, 34.90910809380667, 27.43117015702384, 24.42417046001979, 39.19609798703875, 18.809826237814768, 29.609682287488663, 59.62522969927107, 9.1016720192773, 14.21986014502389, 16.204897948673793, 27.02839524405343, 36.74579838344029, 55.0498617717198, 30.57643379483904, 41.2400460924421, 37.41645588193621, 38.51152672086443, 49.34684985024588, 50.1377980368478, 47.923448835100444, 42.215163230895996, 46.0687210219247, 53.440228189740864, 43.32796239852905, 48.03164618355887, 45.215020179748535, 37.07027578353882, 40.76645687648228, 43.000254086085725, 26.015542439052037, 38.9111454146249, 27.679432766778127, 33.76056391852242, 28.05568814277649, 22.99449348449707, 22.5338157585689, 25.849822691508702, 18.99613697188241, 20.66539999416896, 35.94121783120291, 37.98563494001116, 18.140865836824688, 13.028792125838143, 22.177162987845286, 25.540587902069092, 35.51921204158238, 34.49661438805716, 45.565709659031455, 48.84622171946934, 55.35370997020176, 57.29342467444283, 55.655327796936035, 53.76356608527047, 37.788059438977925, 32.53962993621826, 18.5588173525674, 13.15594937120165, 6.199313061577933, 2.191378022943224, 0.3803279160388878, 0.07182506910924401, 0.05466250629563417, 0.04475373049665775, 0.010099523867081319, 0.04604519637567656, 0.033307859141911776, 0.01190677220334432, 0.05115642085937517, 0.048627948321934254, 0.00945305556524545, 0.01761279285087117, 0.08929025514849595, 0.07363253033586911, 0.0404749938419887, 0.041283410641231706, 0.010303230257704854, 0.029005852128778185, 0.0076711013181401146, 0.0058490664315676046, 0.03057435367788587, 0.06613674719950982, 0.024893093621358275, 0.020713826807747995, 0.0029743947255026016, 0.035817030750747235, 0.04795775928401521, 0.027681921741792133, 0.0412650393056018, 0.04203514601769192, 0.05640071623825601, 0.03737794627834644, 0.03677623499450939, 0.054548417417598624, 0.012957187668819512, 0.01631511328741908, 0.025489108603713766, 0.042313464118966033, 0.10810893534549645, 0.049167047786925516, 0.04310517877872501, 0.07725826185196638, 0.05790306401572057, 0.04809874529018998, 0.020282797615176866, 0.017521121073514223, 0.05175495320664985, 0.030945369840732644, 0.033330925939870734, 0.001460119044557879, 0.04852655144142253, 0.013167134037108293, 0.013748881972527929, 0.0706440449825355, 0.02953934350184032, 0.034079828432628086, 0.0398171337853585, 0.06849887687712908, 0.0921966377645731, 0.010639019426889718, 0.004759527061001531, 0.006459767032148582, 0.044428769898201735, 0.025320233111935, 0.03373275437791433, 0.017365775570007305, 0.07229481211730412, 0.01634185604884156, 0.015764358287144984, 0.02309377142228186, 0.06030342914164066, 0.027443055362839783, 0.08030187139021498, 0.008821167284622788, 0.013544491109704333, 0.0357009266237063, 0.052135363686829805, 0.04895370959171227, 0.05298537468271596, 0.02332691096567682, 0.010802239329288048, 0.02635744513411607, 0.008744676880139326, 0.006355161529167422, 0.04075012622135026, 0.040754356887191534, 0.025758495487804924, 0.05381078199882593, 0.03263265233752983, 0.01590206696917968, 0.01831731236805873, 0.06523816327431373, 0.10383730634514775, 0.014660804199853113, 0.05823773105761834, 0.041120748833886216, 0.01734143651888839, 0.0357357185067875, 0.028343461154560958, 0.06851069017180375, 1.040728434920311, 7.510491115706308, 16.06945150239127, 23.897432735988072, 32.29880884715489, 39.22006927217756, 43.522817679813926, 51.25580835342407, 56.37279878343855, 66.72587176731655, 68.66730267660958, 64.20332826886857, 64.02906050000871, 57.32792942864554, 53.52646228245327, 47.21354096276419, 45.363086291721885, 44.684660707201274, 33.84959118706839, 33.647297859191895, 48.8579363822937, 28.217263289860316, 40.2654743875776, 60.71061474936349, 20.531440462384904, 21.1658387865339, 23.27716531072344, 25.331362009048462, 39.3096523966108, 49.470267227717805, 29.680540016719274, 34.53344678878784, 28.063461439950125, 33.48853152138846, 32.962980202266145, 37.43242631639753, 31.56365122113909, 35.52317598887852, 35.957778862544465, 35.792526381356375, 33.065480027879985, 38.59967156818935, 35.660604408809114, 28.291028840201243, 32.74876029150826, 35.98736776624407, 24.467985800334386, 31.765617983681814, 28.930853707449778, 28.849366971424647, 29.147456850324357, 23.92855371747698, 25.551336765289307, 26.07773229054042, 21.355326584407262, 23.187483174460276, 41.50148596082415, 44.27722529002598, 26.009738956178936, 24.72995546885899, 35.639485359191895, 33.75790275846209, 44.19439581462315, 43.68245254244123, 51.82586983272007, 57.477649211883545, 61.390273639133994, 63.99453490121024, 61.21366432734898, 62.49818474905831, 48.349303926740376, 40.06236812046596, 25.374902895518712, 18.62878050122942, 9.06342305455889, 3.5089625333036696, 0.5988724018846239, 0.05847726070455142, 0.04384970811328717, 0.061091696843504906, 0.052849501437906704, 0.0631994301719325, 0.011474153542492007, 0.03270544896700552, 0.045916159371180196, 0.04484459312100496, 0.011248675507626362, 0.0011658191111304664, 0.024549261267696108, 0.017808234684967568, 0.03943773092968123, 0.0296579819571759, 0.09255319434617247, 0.03570013613040958, 0.03601801621594599, 0.022628935918744122, 0.03524383829374399, 0.06363874088440623, 0.043952753833894215, 0.017623483170089976, 0.047849152968930345, 0.019488960837147067, 0.0552664838864335, 0.016817809348659854, 0.04491409207029002, 0.03420239221304655, 0.07233117480895349, 0.024163290193038325, 0.017352372807051455, 0.028051562174888592, 0.017403217132336328, 0.07012664846011571, 0.051991938347263, 0.043682639220995564, 0.030893258351300443, 0.010992876287283642, 0.015986385123272027, 0.019116709740566354, 0.04652858811563679, 0.032176347715514045, 0.005323621635657868, 0.020978821873930947, 0.026150670068870698, 0.023934740939044526, 0.02716543954530997, 0.05996323882469109, 0.026659179478883743, 0.05045830671276365, 0.03848176669063313, 0.1688311155885458, 0.07338187949998037, 0.13894217727439745, 0.1243147671754871, 0.1401543529438121, 0.11239691703979458, 0.14491352971111024, 0.1322088028703417, 0.10428991634398699, 0.15384879096278123, 0.1655083160315241, 0.10763916519603559, 0.13923979630427702, 0.12978883486773285, 0.08075758907943964, 0.16168641325618538, 0.16873941836612566, 0.10402043616133076, 0.13699760447655404, 0.13425693368273123, 0.10301758854516915, 0.07656698394566774, 0.11462531425058842, 0.1301180057759796, 0.10931432566472463, 0.15646439418196678, 0.09392045597944941, 0.10046156070062093, 0.1428623047790357, 0.13647381615425858, 0.1511555497667619, 0.18934221139975957, 0.11368453223258257, 0.08045530172863177, 0.08023726807108947, 0.14700744806655816, 0.09355821327439376, 0.19436579969312462, 0.16477427684835025, 0.24661124550870486, 0.13747492672077247, 0.13288638793996402, 0.21266465421233857, 0.16834010050765105, 0.14064535445400647, 0.15581553828503403, 0.3025565120790686, 1.8148895565952574, 9.540743453162056, 21.266221148627146, 30.737711906433105, 40.01323740822928, 46.231565952301025, 52.48083482469831, 60.09052276611328, 65.14043181283134, 75.05164105551583, 78.57159846169608, 75.56091621943882, 74.08021341051374, 67.76691341400146, 61.79842472076416, 58.70373180934361, 57.51755966459002, 52.33919927052089, 44.16583524431501, 38.46668652125767, 55.486997263772146, 32.2037227494376, 45.79138714926583, 73.66495432172502, 17.990505082266672, 23.17913143975394, 23.531276566641672, 37.77575765337263, 51.84556450162615, 68.35864979880196, 43.82201753343855, 55.48001779828753, 48.10258034297398, 53.77710812432425, 63.208429609026226, 63.06794398171561, 64.54431806291852, 55.92607825142996, 62.31761496407645, 69.36618723188127, 56.82544960294451, 62.45503643580845, 60.13156577519008, 51.84626974378313, 55.749003410339355, 56.446877002716064, 36.03539024080549, 55.131461415972026, 41.05644341877529, 46.89139468329293, 39.65977212360927, 31.57537283216204, 35.59555537360055, 36.721830572400776, 27.540772778647288, 31.39782551356724, 49.34185062135969, 49.64995459147862, 30.526913983481272, 24.777491569519043, 35.242694582257954, 38.46377522604806, 50.21725068773542, 51.31007031032017, 62.41975348336356, 65.34072753361293, 71.08747836521694, 71.38323538643974, 72.62795652662004, 70.10113293784005, 56.602791104997905, 47.60124002184187, 31.837319919041224, 22.6363068989345, 11.745697821889605, 4.970640957355499, 1.1222388382468904, 0.17808576327349457, 0.2274499051272869, 0.12434859893151692, 0.15652083472481795, 0.14139732053237303, 0.11146655731967517, 0.11050615206893001, 0.14235242642462254, 0.09110414210174765, 0.11720395088195801, 0.1633037014731339, 0.15543234241860254, 0.09832587172942502, 0.12359273806214333, 0.13602134186242307, 0.12359817991299288, 0.14748985932341643, 0.10065369467650141, 0.09999222481357199, 0.10993204358965158, 0.2592735503401075, 0.11496056483260222, 0.13133118567722185, 0.0831091743228691, 0.14680700882204942, 0.16079860446708544, 0.13921255990862846, 0.1413532021854605, 0.19900863484612533, 0.14167547917791776, 0.15234103186854295, 0.08845028307821069, 0.16180783031242235, 0.08028655006949391, 0.1188544330320188, 0.2659462094306946, 0.11066756197916609, 0.16514204282845768, 0.12251143822712557, 0.12499875761568546, 0.256467726613794, 0.16432440813098634, 0.17114163589264664, 0.20429793745279312, 0.19155757395284517, 0.13590580091944762, 0.13956808511699947, 0.13539953237133368, 0.1469408023570265, 0.1081652876787952, 0.23515836149454117, 0.08501268218138389], [0.013450900774582155, 0.039313874540052245, 0.028760385300431932, 0.02701512537896633, 0.07806426645921809, 0.04363527408401881, 0.015172697803271669, 0.056056451318519454, 0.052743056256856234, 0.036620297469198704, 0.0927797911156501, 0.01722229764397655, 0.02977810979687742, 0.09137997337217842, 0.04293296319831695, 0.022680338339081833, 0.0012680697795336268, 0.04373453697189689, 0.019339435467762605, 0.022342103899323514, 0.02928220247849822, 0.07748528609850577, 0.02989336914782013, 0.010688445613985615, 0.02893670941037791, 0.02937210158311895, 0.0293835213274828, 0.012766219076833554, 0.093697251885065, 0.021957513643428683, 0.08332299427794558, 0.04459744352581246, 0.011939557319107865, 0.03437839401885867, 0.0256022509253983, 0.029005241447261403, 0.011634310707449913, 0.049180272434438975, 0.01582295317868037, 0.0028370918922259337, 0.004812912499931241, 0.046649723579841, 0.053446201740631034, 0.026252034718969038, 0.09970212395169906, 0.5258545428514481, 6.8435995408466885, 20.674014023372106, 34.3607771056039, 45.663345745631624, 50.81055736541748, 52.58620078223092, 56.68866389138358, 59.67934226989746, 64.09244196755546, 62.95847511291504, 59.27977221352713, 55.55266121455601, 45.71053443636213, 46.315156255449565, 38.69442762647356, 31.35130384990147, 31.163278647831508, 25.352809361049108, 17.81242275238037, 13.5065997668675, 14.911570685250418, 8.73334801197052, 10.976897018296377, 13.951913288661412, 27.991564955030167, 22.38810682296753, 33.98348644801548, 43.30329629353115, 47.6437143598284, 39.10636895043509, 51.324470451899934, 50.25817557743618, 36.04124757221767, 48.55419588088989, 30.620349884033203, 30.23990821838379, 23.95748601640974, 21.204840762274607, 14.806305476597377, 10.003565566880361, 14.570174421582903, 18.021341187613352, 15.155966622488839, 17.06812824521746, 15.45501014164516, 12.765692506517683, 22.69819971493312, 37.64741052900042, 33.277903829302105, 33.31446525028774, 42.96641983304705, 46.75012043544224, 58.37119797297886, 50.57899475097656, 63.725889750889365, 49.47538457598005, 50.116029330662315, 37.09733901705061, 34.09243420192173, 20.878650631223405, 24.86220226969038, 14.315861667905535, 16.11837203162057, 17.194918973105295, 18.942502089909144, 25.366028308868408, 25.26590129307338, 37.356461661202566, 40.299920082092285, 50.19933475766863, 50.55331073488508, 51.972310066223145, 52.03519473757063, 51.99719156537737, 46.87980508804321, 37.93596574238369, 20.686041355133057, 12.642961263656616, 3.7434957197734287, 0.6586871093937329, 0.11913656789277281, 0.07360461540520191, 0.026711012768958296, 0.05893437617591449, 0.0458070136207555, 0.03361665703622358, 0.04400602222553321, 0.026352345943450928, 0.022602562958906804, 0.07700237951108388, 0.00602342448629705, 0.04194007986890418, 0.028134506295568178, 0.024918482705418552, 0.011231238853984644, 0.04196421196684241, 0.11125258130154439, 0.08892757818102837, 0.024731042495529567, 0.01149357745556959, 0.0035316006854243043, 0.055254945398441384, 0.03964425663330725, 0.027291078785700456, 0.05929364011223827, 0.0768460857548884, 0.033899640065750906, 0.0871716041916183, 0.08033549280038901, 0.054613818015371046, 0.08199279422738723, 0.018838323785790374, 0.05195843568071723, 0.14538503012486867, 0.024637365647192513, 0.049974395893514156, 0.10569592911217894, 0.024296937842986414, 0.04124758399224707, 0.03358086431398988, 0.028488750769091502, 0.08314710443041154, 0.055796996490763764, 0.04783286473580769, 0.010484121756495109, 0.01056814898869821, 0.03796126587050302, 0.021785119947578226, 0.030126171120043312, 0.1553074512630701, 0.0409841020591557, 0.03778794088533946, 0.03881902912897723, 0.04998431946816189, 0.0891877624339291, 0.08921628804611308, 0.021398734966559068, 0.03478174576801913, 0.009534184604750147, 0.07161233481019735, 0.05279068262981517, 0.037223932399813614, 0.049436042817043405, 0.07411245815455914, 0.08802334205912692, 0.007686771236227027, 0.043579780097518644, 0.06731298765433685, 0.04296281195378729, 0.030076780556035892, 0.03152012971362897, 0.024534845791224922, 0.03778494515323213, 0.010375830960193915, 0.03998815853680883, 0.06580013276210853, 0.024744857468509247, 0.013009064215501505, 0.05864390890513148, 0.03808111211817179, 0.01178541621525905, 0.03932144699086036, 0.04471590895471828, 0.03516343867938433, 0.08196308796427079, 0.042387102131864855, 0.018186558669965183, 0.02402824815362692, 0.04884877415107829, 0.037649458673383505, 0.015829957356410365, 0.018356921849772334, 0.08722734584340028, 0.017733093717002442, 0.13026123094771588, 1.0885538629123142, 8.617211478097097, 25.793848003659928, 41.675844056265696, 52.61101279939924, 59.7501791545323, 59.84436198643276, 64.9935052054269, 69.18772275107247, 71.81793553488595, 70.95601844787598, 67.4533759525844, 63.479791504996165, 51.20738288334438, 53.12952559334891, 48.50697592326573, 38.66041966847011, 40.08453287397112, 35.21073981693813, 27.51642107963562, 26.59945341518947, 25.146435703550065, 23.380768162863596, 22.104858296258108, 23.735049860818044, 34.19196367263794, 18.75167850085667, 33.688657011304585, 34.15857757840838, 40.12784446988787, 34.13030535834176, 45.11262110301426, 37.91982855115618, 28.77348916871207, 27.84797521999904, 19.69054341316223, 20.2438736302512, 16.664590767451696, 12.108631764139448, 10.95350330216544, 8.423750179154531, 9.989260094506399, 11.455710411071777, 10.647125959396362, 11.819503324372427, 12.466543895857674, 13.28289817060743, 16.22668402535575, 23.146514858518326, 28.790057148252213, 25.700884580612183, 31.927121911730083, 33.42124169213431, 36.629492487226216, 38.5615085874285, 52.17215762819563, 30.68755633490426, 46.18330029078892, 45.16519464765276, 38.48266042981829, 26.552688564573014, 27.447745084762573, 22.6514869758061, 25.32503741128104, 27.650311129433767, 28.644664355686732, 37.12267214911324, 33.281436988285606, 45.40953847340175, 47.783536434173584, 58.650050027029856, 57.330729552677695, 59.22148377554757, 58.98483507973807, 59.218961579459055, 55.787618024008616, 46.131261757441926, 28.504418441227504, 17.280239377702983, 5.271460609776633, 0.928834101983479, 0.12678025130714687, 0.0852242765415992, 0.015581874775567224, 0.07991162554493972, 0.04410141067845481, 0.08100192953965493, 0.04432613129860588, 0.01997016090899706, 0.10135076727185931, 0.03918303941775646, 0.04593152818935258, 0.03414271166548133, 0.03030114494530218, 0.05497751957071679, 0.03478621052844184, 0.030461801681667566, 0.05707766687763589, 0.04187783785164356, 0.03425685143364327, 0.008243060537746974, 0.06109633802303246, 0.04504405188241175, 0.011088892385097486, 0.06957000547221728, 0.043282259455216784, 0.07986230961978436, 0.07259811727063996, 0.04748735809698701, 0.04209515226206609, 0.06703643035143614, 0.01729891442560724, 0.052471292803862264, 0.015775983288351978, 0.049543539727372785, 0.008917385246604681, 0.04383914332304682, 0.00748374083611582, 0.06952821450041873, 0.046969578202281675, 0.02979440481535026, 0.0287824919713395, 0.02957757216479097, 0.009849683880539877, 0.014345317646594984, 0.01821337267756462, 0.021955435629934072, 0.02734240487084857, 0.03960922047761934, 0.038367789770875654, 0.04865129331925085, 0.12146713212132454, 0.13201209556843552, 0.11732375302485057, 0.12924163708729403, 0.17336227744817734, 0.13271181445036614, 0.1295515104596104, 0.08704997678952557, 0.1325621839080538, 0.12687770250652516, 0.1290249265730381, 0.1455147388790335, 0.12366952108485357, 0.23754433489271573, 0.18466478453150817, 0.04680473490485123, 0.12177084439567157, 0.16742730805916445, 0.10983333031513862, 0.10365221556276083, 0.19651808563087667, 0.12464913566197668, 0.10691333628658738, 0.08618510926940612, 0.16967160334544523, 0.11652533443910734, 0.10727600646870476, 0.11634206213057041, 0.13400928197162493, 0.1431724088532584, 0.1280749232641288, 0.09465611686131783, 0.146528388772692, 0.1546260935387441, 0.26640563192112104, 0.09710833563336305, 0.07999946868845395, 0.2326909096113273, 0.17554289900830813, 0.1116680075813617, 0.111387121225042, 0.12372460455766746, 0.1877134559409959, 0.10412999242544174, 0.24108153794492992, 2.341040483542851, 11.821742381368365, 31.420431477682932, 51.489434582846506, 63.38302394321987, 69.49231093270438, 70.58741651262555, 76.44145447867257, 77.19346496037075, 81.52617400033134, 80.20766993931362, 76.89572075435093, 70.46952642713273, 60.977286611284526, 62.70761040278843, 55.57141440255301, 47.940944399152485, 46.82058211735317, 41.39904866899763, 29.79586969103132, 25.562611954552786, 24.642746891294205, 18.18284685271127, 22.28893518447876, 22.293135370526993, 37.08822992869786, 30.4933055468968, 44.94933148792812, 55.3084841455732, 62.1137478692191, 50.09746721812657, 59.261262212480815, 61.452598980494905, 45.912852082933696, 59.81777123042515, 38.75171899795532, 38.158224718911306, 29.388680934906006, 26.06721271787371, 17.702378920146398, 13.799268313816615, 18.816505193710327, 22.780290944235666, 19.67776220185416, 21.445079939705984, 20.397199528557913, 18.315199613571167, 27.814573492322648, 46.57003355026245, 44.41948618207659, 45.44510977608817, 57.09345899309431, 59.90533937726702, 74.23169108799526, 65.67679105486188, 78.97520542144775, 64.08254773276192, 66.78259686061314, 51.117407185690745, 47.1333726474217, 32.16497959409441, 36.35714742115566, 24.14358483042036, 26.428235905511038, 29.422466550554546, 29.237317902701243, 39.24410656520298, 37.04095785958426, 52.013412134987966, 55.217521803719656, 66.36670548575265, 63.99536868504116, 68.60597787584577, 67.46146365574428, 68.52092497689384, 65.42134748186383, 53.25034434454781, 34.84651524680001, 20.442897830690654, 7.271300681999751, 1.2074123535837447, 0.20209796407393046, 0.16271370170371874, 0.164448688605002, 0.13967120886913367, 0.1038409432928477, 0.1714972968080214, 0.10141990320490939, 0.13833602837153844, 0.18597986682185105, 0.16121138446033, 0.1971568584974323, 0.0826605066124882, 0.17418107922588075, 0.18394552384104046, 0.12633249961904117, 0.08343095598476273, 0.19412364411566937, 0.18207706910158905, 0.10152856380279575, 0.1077667772769928, 0.2231343002723796, 0.18537086807191372, 0.10779693815857172, 0.1596484197569745, 0.15781603593911442, 0.1784412341990641, 0.141513499298266, 0.17789039947092533, 0.15807077155581542, 0.13772525185985224, 0.13033263997307845, 0.09142557771078177, 0.20952880462365492, 0.20786118267902307, 0.13784221772636684, 0.14078529551625252, 0.20908786542713642, 0.18002467708928244, 0.11747692551996027, 0.18989314112280095, 0.10035252012312412, 0.15241849342627184, 0.12370073369571141, 0.10859157051891088, 0.15877298744661467, 0.14330310826855047, 0.16556884135518754, 0.09405274995203529, 0.14033837164086954, 0.2651613344039236], [0.0052863942359441096, 0.04846761728237782, 0.035630426835268736, 0.07021980453282595, 0.04066497686186007, 0.029312380323452607, 0.0059737586915226916, 0.007895520838376666, 0.01237323958360191, 0.011986889377502459, 0.041613843624613116, 0.02723157635357763, 0.005935051237299506, 0.0314349226786622, 0.03062466365684356, 0.0660523713699409, 0.03721015813893505, 0.031566351519099305, 0.005700409162922629, 0.02729791502601334, 0.08913029730319977, 0.012710779373134886, 0.04086408617773226, 0.03930990511019315, 0.01982623684619154, 0.019946832875055925, 0.03094267605670861, 0.0214613993718688, 0.0317404568195343, 0.05094754063923444, 0.013516122408743416, 0.10008815609450851, 0.02593888571885015, 0.06959315030170338, 0.010342557299216943, 0.008611393942763763, 0.008528431162371166, 0.060087227528648715, 0.019131208337577324, 0.012385239475406706, 0.02840565058535763, 0.10901471852724041, 0.03293072598587189, 0.5424721368721553, 4.339872198445456, 15.931342158998762, 37.48721981048584, 48.6650960786002, 56.20177582332066, 66.97167818886894, 58.7811347416469, 57.7596001625061, 53.95911618641445, 54.08204024178641, 51.450979777744834, 45.957348346710205, 44.140925952366416, 38.479974951062886, 32.55083390644619, 25.36501908302307, 17.5006970337459, 16.737583330699376, 14.968603236334664, 7.33828696182796, 9.745401774133954, 8.77678380693708, 14.25749158859253, 16.599444457462855, 16.64082098007202, 23.941331454685756, 16.79595341001238, 41.02931417737688, 35.61498253686087, 42.97866950716291, 29.022694996425084, 30.626759597233363, 18.743927785328456, 15.058683156967163, 8.916857753481183, 6.426463569913592, 8.040080206734793, 3.1790522933006287, 3.1382463915007452, 2.2683586350509097, 2.616803629057748, 1.4604586895023073, 1.7545219787529536, 0.574183715241296, 1.5214831978082657, 1.514935931989125, 1.2452766703707832, 1.5507074296474457, 3.000043898820877, 4.449526931558337, 6.662080458232334, 14.056857143129621, 17.59407213756016, 20.880616971424647, 33.11630610057286, 37.216986996786936, 38.78595624651228, 49.84290954044887, 39.31243862424578, 35.96577276502337, 34.94729539326259, 45.509012358529226, 55.39397130693708, 56.29016385759626, 26.515479224068777, 23.25198677607945, 32.77144268580845, 24.259538105555944, 24.030416045870098, 22.565954651151383, 22.861432007380895, 34.75030354091099, 38.22057090486799, 42.07571635927473, 43.64045068195888, 47.95329829624721, 50.76817682811192, 55.204177788325715, 50.844065053122385, 34.673543316977366, 19.088455949510845, 4.655883652823312, 1.0664864927530289, 0.0864917053175824, 0.09913212060928345, 0.049551278419260464, 0.015678279334679246, 0.1033044188682522, 0.026223285190228905, 0.017361107249079005, 0.06638608846281256, 0.05001544726214238, 0.04198797426319548, 0.05430786318278738, 0.029802123151187385, 0.044610495146896155, 0.014125014289415308, 0.003278844482598028, 0.03419577310393963, 0.020538841108126298, 0.01741047915337341, 0.045484963937529495, 0.06313969873424087, 0.032682724829230986, 0.02907504912997995, 0.026727328143481697, 0.0053992994944565, 0.036381327613656006, 0.037414302184645615, 0.047257056526307545, 0.04352852016953485, 0.019922615960240364, 0.03448524632092033, 0.04470864184466856, 0.08475202973932028, 0.005726558630288179, 0.030718606830175434, 0.013240631253990744, 0.04599533083715609, 0.036158001382968256, 0.05129139843795981, 0.11864750699273177, 0.060734346375933716, 0.06645924132317305, 0.024971978406288793, 0.020362152285607796, 0.03337882372683712, 0.03231166456160801, 0.016703063987993767, 0.0777331210140671, 0.013534918676928749, 0.0041926263199586955, 0.03530392935499549, 0.06028451158532074, 0.027900530457762734, 0.026398508377107124, 0.031545245687344244, 0.027617986779659986, 0.03983352719140904, 0.009244681701862385, 0.045953760389238596, 0.017400501295924187, 0.038176995901657004, 0.055166501751435656, 0.047694121287869554, 0.03481429848553879, 0.027578538450013314, 0.03777929974187698, 0.024626531139282242, 0.019186804104330282, 0.026457154158768908, 0.05097245644511921, 0.016191099138398255, 0.020244436637897576, 0.018184484049145664, 0.06268182330365692, 0.007829305150413086, 0.02403777478528874, 0.05641950826559748, 0.030344150494784117, 0.02066664657156382, 0.02617701419096972, 0.018360331488241042, 0.03610192385635205, 0.00631892224607457, 0.10426976385393313, 0.03206565151257174, 0.02396724446277533, 0.0542095570292856, 0.12949857115745544, 0.0337711221405438, 0.008270581918103355, 0.011182680343543845, 0.05974287100668464, 0.018599968004439558, 0.699656782405717, 5.316010722092219, 18.740014212472097, 43.24683175768171, 56.592869077410015, 64.54998779296875, 74.78576128823417, 66.1362476348877, 66.6446612221854, 63.3381872177124, 61.627610206604004, 59.48211070469448, 52.80746964045933, 50.22695732116699, 44.54615879058838, 41.27228920800345, 32.43916940689087, 27.381474903651647, 26.47581195831299, 26.476220164980205, 19.350267546517507, 17.0752466746739, 17.634192773274012, 23.830606698989868, 22.317582607269287, 20.833294527871267, 24.579995972769602, 26.309131622314453, 34.5900433404105, 30.377510343279155, 31.415348870413645, 22.949682814734324, 21.00313455717904, 14.020194104739598, 9.845265626907349, 5.583716997078486, 5.20207633290972, 4.2373124446187695, 1.9346492503370558, 1.860841142279761, 0.9971661610262734, 0.9103151985577175, 0.6564379557967186, 0.3394743539392948, 0.1284230388700962, 0.7802664712071419, 0.9142569984708513, 0.8747976358447755, 0.9805371676172528, 1.892091533967427, 2.9037733503750394, 4.71135025365012, 9.129651546478271, 12.181502733911787, 14.293044652257647, 24.35704391343253, 32.42677729470389, 31.955963884081157, 41.10914203098842, 33.901407378060476, 26.778369528906687, 31.259149891989573, 38.921852588653564, 47.95713717596871, 48.266300746372764, 23.40493052346366, 25.456226348876953, 31.81813246863229, 27.126217194965907, 30.575909205845424, 32.172511441367014, 30.19965730394636, 45.61192560195923, 46.26250628062657, 50.14866154534476, 50.036976201193674, 54.128301348005024, 57.76914003917149, 62.34804112570626, 59.99706949506487, 44.842461245400564, 25.989813259669713, 8.046859911509923, 1.7294446272509438, 0.04629976235862289, 0.05274113600275346, 0.027533692374293293, 0.029526397053684508, 0.016782391517023956, 0.056009913994265456, 0.010617517500317522, 0.07969036206070866, 0.12938760354050569, 0.07594256209475653, 0.06814132284905229, 0.057934398762881756, 0.038640048554433246, 0.006623151479288936, 0.04697177326306701, 0.049560224903481345, 0.08022495944585119, 0.037285275358174524, 0.023950822218986492, 0.021949757988165532, 0.03416054356577141, 0.009670005263095456, 0.019673122026558434, 0.10067616775631905, 0.10532937092440468, 0.04674289322325161, 0.04998822104451912, 0.08390252425202302, 0.05707870503621442, 0.02030689748270171, 0.0715529222839645, 0.06071297252284629, 0.022219658862533312, 0.03783392520355327, 0.04064386424475482, 0.05762426076190812, 0.08462868564363037, 0.01689906052446791, 0.02830881515650877, 0.08103460778615304, 0.06467702838459186, 0.06290474919868366, 0.042255564725824764, 0.026995916052588394, 0.031040758293654238, 0.025385426756526743, 0.035877552681735585, 0.06708423314349991, 0.02676320737893028, 0.09369266498833895, 0.14381941913494042, 0.06898656035108225, 0.09878038162631647, 0.18484779899673803, 0.07971397507935762, 0.1257511715271643, 0.13515599258244038, 0.11642662116459437, 0.08377759916973965, 0.11644875497690269, 0.2433268374630383, 0.1581737460302455, 0.1744539588689804, 0.14139631630054542, 0.1591513521437134, 0.23094740031020983, 0.17147941062492983, 0.07165508930172239, 0.11642903674926076, 0.11046266475958483, 0.09476159512996674, 0.10236394897635494, 0.15139915740915708, 0.12524733213441713, 0.06804937456867524, 0.20907182485929557, 0.08796914068183728, 0.15737372610185826, 0.1603482472045081, 0.13540570704000338, 0.23493691480585507, 0.15905305956091198, 0.19693309121898242, 0.13913460980568612, 0.28083530334489687, 0.09144440705754928, 0.23015747698290007, 0.08630794446383204, 0.10168568537171398, 0.1494594972048487, 0.20217022805341653, 0.12254057452082634, 1.351280233689717, 8.657461524009705, 25.983483450753347, 53.043986320495605, 72.10466684613908, 78.35823317936489, 85.48058141980852, 75.8415470123291, 76.6613302230835, 70.44322749546596, 70.75867571149553, 69.38305050986153, 63.35523809705462, 60.19021551949637, 53.767929553985596, 48.396714959825786, 40.15161773136684, 30.42187806538173, 28.202381985528127, 27.112084559031896, 17.026263611657278, 17.02788427897862, 15.503208058220999, 22.43713504927499, 24.764564446040563, 25.14930530956813, 35.19284125736782, 27.141138451439993, 51.80321870531355, 47.3209879057748, 55.33829539162772, 37.763303007398335, 39.10457631519863, 22.57368799618312, 18.496835947036743, 10.862625207219805, 7.860738515853882, 9.901689342090062, 3.9962542482784817, 4.087328629834311, 2.6582871973514557, 3.739961692265102, 2.2014618132795607, 2.552837210042136, 0.8646326384374073, 2.3744873745100836, 2.23915188227381, 2.0980157298701148, 1.9842016313757216, 3.8384319969585965, 5.923538190977914, 8.661099774496895, 17.956821952547344, 23.24593836920602, 27.119988134929113, 41.17372553689139, 46.099414689200266, 50.84884193965367, 65.38111741202218, 52.32230125154768, 48.911739758082796, 50.21763283865792, 61.99947084699358, 70.76219844818115, 66.83187348502022, 39.596421922956196, 36.53033127103533, 45.34060539518084, 35.096306460244314, 37.28152533939907, 34.77821445465088, 36.168180738176616, 51.610274178641184, 51.3954428264073, 55.61730030604771, 57.535367897578645, 61.80359418051583, 64.90366499764579, 70.27713080814907, 68.02022389003209, 52.41071707861764, 30.608927045549663, 10.062338641711644, 1.9418247853006636, 0.22206324631614344, 0.22003799570458277, 0.15756344449307236, 0.15388160491628305, 0.17805968038737774, 0.21168521605432034, 0.09799265675246716, 0.18821055069565773, 0.21704443490930966, 0.18374622453536305, 0.26045675256422585, 0.16006679087877274, 0.13419387063809804, 0.08930884022265673, 0.15682853678507463, 0.17243267090192863, 0.17527544764535768, 0.2130702824464866, 0.14615699941558496, 0.0926287356497986, 0.1369612214288541, 0.05694008033190455, 0.14280578281198228, 0.16009765065142087, 0.155052674934268, 0.1624829319438764, 0.14539165262665066, 0.21359356865286827, 0.21954457860972199, 0.15712840855121613, 0.16837470579360211, 0.12027334475091525, 0.07968423488949027, 0.14191865255790098, 0.17594869009086064, 0.16543321577566011, 0.18981026485562325, 0.1273163211132799, 0.2514348423906735, 0.17390061356127262, 0.20387212958719048, 0.151261835492083, 0.19736743505511964, 0.10831653991980211, 0.18182153281356606, 0.1559149165238653, 0.2470642083457538, 0.12421838806143828, 0.06603114679455757], [0.032720780465751886, 0.04745391649859292, 0.07297147437930107, 0.05516461542408381, 0.05447161403883781, 0.024510637358097092, 0.08224826944725853, 0.05126047759716, 0.005789545339731765, 0.03475270786189607, 0.03288291980113302, 0.017200626931818466, 0.024646634435547248, 0.09904591273516417, 0.06717062422207423, 0.01360682727369879, 0.03414779050009591, 0.02541362158288913, 0.033563252937580855, 0.03654912593109267, 0.011048321079994951, 0.031229031405278614, 0.09562597410487277, 0.01970946436215724, 0.027578850576121892, 0.01618087022299213, 0.03917398776060768, 0.048491498322359154, 0.09149357370500054, 0.06594445716057505, 0.038705876629267416, 0.1421125778662307, 0.06390910316258669, 0.02344332043347614, 0.008784029366714614, 0.05170695024675556, 0.05170713005853551, 0.030106809123286178, 0.016788615379482508, 0.024102856471602405, 0.09235202228384358, 0.08148973514991147, 1.494615490947451, 5.746668321745736, 18.167816162109375, 39.429682527269634, 61.93842397417341, 63.71170847756522, 63.67911447797503, 61.004134450639995, 55.81589024407523, 59.41578320094517, 56.90329027175903, 47.18374361310686, 45.770295892442974, 31.23829139981951, 35.76644631794521, 31.000364235469274, 16.543480191911968, 12.574592726571218, 14.336708000728063, 11.512978332383291, 14.309800233159747, 15.636841024671282, 18.951500007084437, 32.91967902864729, 28.451815366744995, 37.05755015781948, 33.301555497305735, 33.33137369155884, 26.15040349960327, 20.076140642166138, 20.246930837631226, 11.093717081206185, 8.043640289987836, 6.184682326657431, 3.570274740457535, 2.294590473175049, 1.5409550900970186, 0.2550670674868992, 0.1277674926178796, 0.08994073274412326, 0.029099099803715944, 0.04301918125046151, 0.02042917288573725, 0.015917084645479918, 0.04673050995916128, 0.0331653701806707, 0.07145011065793888, 0.005397472963003176, 0.16793345447097505, 0.1177952941507101, 0.1373538760734456, 0.240805482757943, 0.33601952503834454, 0.8967877072947366, 1.9252572400229317, 4.47482966525214, 3.5691736681120734, 7.271517378943307, 13.404298833438329, 10.56340103490012, 19.669217654636928, 31.462436812264578, 37.39514228275844, 41.908719880240305, 39.024817943573, 66.59741347176688, 74.16658646719796, 51.05342469896589, 67.55850914546421, 57.083790574754985, 41.403443404606406, 27.522163765771047, 29.98632676260812, 22.220842838287354, 19.69075185911996, 20.87748507090977, 34.62288052695138, 33.19573790686471, 42.869825976235525, 50.27308293751308, 55.95227296011788, 56.19877420152937, 48.42901366097586, 36.30956963130406, 16.205540657043457, 2.695496972118105, 0.7759846438254628, 0.04948218659098659, 0.04207290309880461, 0.099190176065479, 0.06897036372018711, 0.017535253261615123, 0.015818866701530557, 0.050424909219145775, 0.055459927434899976, 0.028136496099510362, 0.05761359419141497, 0.06184987151729209, 0.04421192706961717, 0.0017195768409042753, 0.08979862036981753, 0.053060675106410465, 0.0347361753561667, 0.03546600422954985, 0.047610932894583256, 0.048702743237039874, 0.0552307895517775, 0.03349955885538033, 0.02344457233058555, 0.1353675869426557, 0.03790192798312221, 0.02109840010026736, 0.02107114334856825, 0.04270186095631548, 0.11207203447286572, 0.01277221563006086, 0.0704605962548937, 0.0601685635213341, 0.02079714073001274, 0.0678440702280828, 0.03604769194498658, 0.028870464036507264, 0.03724980154739959, 0.10684565920382738, 0.07446106230573994, 0.05499818096203463, 0.034690872965646644, 0.05016304559207388, 0.06707491007234369, 0.11075493014816727, 0.011687924303779644, 0.05843488619263683, 0.023446864082611034, 0.0598497267014214, 0.011571727726342422, 0.07704582610832793, 0.05353090665968401, 0.057034165997590335, 0.020423349358939698, 0.014255713704707367, 0.042502212205103466, 0.05036116085414376, 0.08041459641286305, 0.023010649186159884, 0.035785363521426916, 0.009048478212207556, 0.016450679495132396, 0.04188338148274592, 0.029712682057704245, 0.053978122305125, 0.016535447178674594, 0.015604989070977484, 0.012837259996948498, 0.015467560284637978, 0.012680027317920966, 0.015361885240833675, 0.028841873963496516, 0.06414953526109457, 0.04522673386548247, 0.005081040701562805, 0.05242447049490043, 0.0029786372657067007, 0.08960149237619978, 0.0508935937125768, 0.06574302725493908, 0.08179398346692324, 0.0863388856606824, 0.05677266877942851, 0.026132325874641538, 0.031892109396202226, 0.062236975745431015, 0.0560829345402973, 0.028939097853643552, 0.058943068209503374, 0.02198899766829397, 0.2672951641891684, 1.9682311969144004, 7.1111807482583185, 22.144060032708303, 45.86707387651716, 70.03564616612026, 73.275757925851, 74.23989691053117, 68.90308284759521, 65.28353691101074, 66.4122439793178, 63.42005784170968, 54.80446529388428, 52.519869804382324, 36.052903175354004, 42.956195558820454, 36.46877023151943, 21.425828218460083, 22.28480969156538, 22.76018806866237, 19.228616748537334, 22.04839723450797, 18.233129228864396, 21.56337128366743, 29.45079435620989, 25.234111547470093, 31.39944096973964, 27.298638480050222, 23.926491839545115, 20.40325835772923, 16.37957739830017, 12.06425883088793, 7.198268600872584, 5.212315806320735, 3.5164107850619724, 2.174712985754013, 1.270913677556174, 0.4050508008471557, 0.13645751774311066, 0.07621143838124615, 0.016256299568340182, 0.020101106293233376, 0.05031136316912515, 0.031772453138338666, 0.05536050848396761, 0.13115241884120873, 0.1896849258669785, 0.0708184013409274, 0.043048185229833634, 0.12978997480656418, 0.11850641242095403, 0.02439753574851368, 0.10743722638913564, 0.23550796987754957, 0.5376731572406632, 1.1058477120740073, 2.7411861547401974, 3.4610266940934316, 5.055620900222233, 10.45154459135873, 12.066445776394435, 16.293114015034266, 26.652520281927927, 33.03127057211739, 42.28861263820103, 40.871405942099436, 58.038063117435996, 64.45865372249058, 57.15127147947039, 74.69966615949357, 66.64895520891461, 47.72726992198399, 32.88647358758109, 33.77737855911255, 29.81323323931013, 27.57314269883292, 28.524960790361675, 39.6922584261213, 43.38952691214425, 50.57930394581386, 58.00429834638323, 62.40309170314244, 65.15446022578648, 58.051278591156006, 45.16176571164812, 22.427431889942714, 4.511246476854597, 1.056213146873883, 0.08519465170268502, 0.021082454527329122, 0.06417218476001706, 0.03836392890661955, 0.024745120400828973, 0.04340803609894855, 0.03989698039367795, 0.018230609163375835, 0.0184878943754094, 0.009531575637603444, 0.06414575582104069, 0.03011512117726462, 0.012999076180026999, 0.014022480862747346, 0.00988129258621484, 0.07074949610978365, 0.030301524924912622, 0.036968335043638945, 0.05028696983520474, 0.07682850491255522, 0.03920544803674732, 0.019574904082609073, 0.06485293180282627, 0.03711683921782034, 0.049918996901916604, 0.0408050807725106, 0.02728314501499491, 0.012866684668032187, 0.0899314164583172, 0.057371635389115126, 0.009812943753786385, 0.04648548417857715, 0.07655801371272121, 0.041060043698442836, 0.05262860096991062, 0.029823388438671827, 0.046927434392273426, 0.06790106716964926, 0.04855170473456383, 0.01434031005815736, 0.08268006199172565, 0.050280187877693346, 0.04066372496475067, 0.1224745259221111, 0.0492329742493374, 0.038758069542901855, 0.0392561142465898, 0.11544126618121352, 0.17510410398244858, 0.1460043561777898, 0.1545614834342684, 0.13822957979781286, 0.10706285147794656, 0.11056929653776543, 0.1266419251582452, 0.1387935916760138, 0.14147531134741648, 0.08864187422607626, 0.11342838526304279, 0.09704222596649613, 0.26043474088822094, 0.13841726258397102, 0.15619730922792638, 0.12610703600304468, 0.16592493653297424, 0.1359423603862524, 0.09338967196111168, 0.10542299518627779, 0.13564589486590453, 0.21500148810446262, 0.1966578367033175, 0.10151763260364532, 0.10839038488588162, 0.1449252955083336, 0.24973386366452488, 0.22818570850150927, 0.06354760006070137, 0.1463766819132226, 0.1776333296937602, 0.16545444035104342, 0.20042409960712704, 0.16998370231262275, 0.15304760395416192, 0.14984939699726446, 0.11149405834398099, 0.13655582389661244, 0.16987471601792745, 0.15447581160281385, 0.46471506357192993, 3.7781915494373868, 11.951422691345215, 29.073413372039795, 57.73605966567993, 80.33339759281704, 82.12225995744977, 84.15066841670445, 79.35214519500732, 73.27866922106061, 75.53220626286098, 71.28980990818569, 64.38128553118024, 59.58926582336426, 45.619544301714214, 49.77642222813198, 43.149883542742046, 26.01444809777396, 22.540527718407766, 22.97110758508955, 20.360867398125784, 24.478229182107107, 24.44575330189296, 28.3731461252485, 42.54231916155134, 39.48194340297154, 50.36469841003418, 45.187974316733225, 44.933468750544954, 34.32640784127371, 28.247731140681676, 24.881217752184185, 14.086897679737636, 10.027528166770935, 7.47695129258292, 4.732287347316742, 3.4374885857105255, 2.627896862370627, 0.5801109086189951, 0.3721652754715511, 0.35542098539216177, 0.3403993600181171, 0.11597747169435024, 0.2787483467587403, 0.11927004930164133, 0.2198043760976621, 0.28057243887867245, 0.22826097160577774, 0.23181483947804996, 0.2685936630836555, 0.3443200710628714, 0.32406449796898024, 0.532150750713689, 0.8101299915994916, 1.489304895911898, 2.7466296340738023, 6.1185988783836365, 5.095672053950174, 10.118024979318891, 17.30550476482936, 14.382098845073156, 26.62118911743164, 38.80660629272461, 46.18776798248291, 51.39461599077497, 52.66344043186733, 79.71989250183105, 86.890273639134, 66.32737868172782, 76.43376977103097, 67.76274449484688, 52.02571044649397, 39.256533418382915, 44.21966641289847, 34.61450794764927, 33.61990111214774, 33.92311355045864, 48.10608223506382, 50.88953059060233, 58.69367776598249, 65.30849484034947, 70.38698182787213, 71.6556464603969, 65.54195431300572, 51.1041430745806, 26.94964436122349, 5.375131641115461, 1.347177973815373, 0.23405807624970162, 0.09058098481701952, 0.14871384150215558, 0.2406616061925888, 0.15148841190551007, 0.17469595159803117, 0.1617252661713532, 0.14432483272893087, 0.22928127114261898, 0.09922970073031527, 0.15104346935238155, 0.09483858849853277, 0.13308257955525601, 0.16230027031685623, 0.1473251517329897, 0.1025236693343946, 0.10653854746903692, 0.17978174798190594, 0.12627611335899147, 0.2998502972934927, 0.11658090645713465, 0.09721162901925189, 0.2359231247433594, 0.12103156692215375, 0.1212664350335087, 0.1070761779057128, 0.1488559945885624, 0.12458476983010769, 0.12943100264029844, 0.12115563026496343, 0.11817592515477113, 0.1522153536123889, 0.2070198535387005, 0.18454933858343534, 0.15899303635316236, 0.11191444471478462, 0.11972907824175698, 0.24324763885566167, 0.16765393875539303, 0.22473370230623654, 0.13885495838310036, 0.15070489394877637, 0.1610840234373297, 0.22415692039898463, 0.2090274350983756, 0.15045922355992453, 0.13315200725836412], [0.029901464070592607, 0.05214932793751359, 0.04090490684445415, 0.03999583955321993, 0.03431211471823709, 0.017598938862127916, 0.024817618474896466, 0.07366010599902698, 0.02456401601167662, 0.07031127105333976, 0.021918272266962698, 0.08006461483559438, 0.01932676721896444, 0.03723380847701004, 0.017998098961210678, 0.00880051776766777, 0.047220615803131034, 0.029187024371432405, 0.018665926697264825, 0.017697448576135293, 0.011450594806644534, 0.024832502140530517, 0.018258040637842247, 0.0472311229178948, 0.05231148762894528, 0.04076648570064988, 0.0360803667988096, 0.009615961645197655, 0.011079545565215605, 0.007836161746776529, 0.01515899648490761, 0.036954146876399, 0.0386004119313189, 0.055814251636288, 0.061892246029206684, 0.06173159607819148, 0.02894294514719929, 0.05349426916135209, 0.07627125124314002, 0.008926033175417354, 0.20779655900384697, 3.273515875850405, 12.718795640127999, 28.356057030814036, 48.981569153921946, 64.60909611838204, 62.90838554927281, 63.2195953641619, 54.20555141993931, 53.92429876327515, 45.08864286967686, 41.18680204663958, 49.78332873753139, 33.63970347813198, 27.256676571709768, 25.766944578715734, 18.34578905786787, 19.338132517678396, 24.561261892318726, 14.083635500499181, 18.190602779388428, 26.63971996307373, 33.0935993875776, 46.88410949707031, 40.042965275900706, 40.37602717535836, 34.94190011705671, 27.907067911965505, 21.54059508868626, 14.781533411570958, 9.193257093429565, 3.9126205188887457, 1.913178882428578, 1.558366841503552, 0.30295600635664804, 0.10619579907506704, 0.12408747151494026, 0.0453614094959838, 0.12183687942368643, 0.0190434415292527, 0.06111991711493049, 0.08117123081215791, 0.05201014344181333, 0.024941613964204277, 0.05075675355536597, 0.031103258154221942, 0.04142956369157348, 0.20016902472291673, 0.03427493099921516, 0.031250771667276106, 0.0519087499539767, 0.02840640884824097, 0.037754763915602646, 0.06454178957002503, 0.024209739307739904, 0.019953070308214853, 0.09377232499952827, 0.18521912050034317, 0.2153259092675788, 1.567685787166868, 0.7389927602240017, 2.0164045776639665, 2.549490566764559, 2.1915680127484456, 4.531846148627145, 9.131572723388672, 15.378795351300921, 24.929625851767405, 30.689206532069615, 31.867509841918945, 29.472604751586914, 33.66493933541434, 56.40732438223702, 74.0080702645438, 44.30408355167934, 29.049963201795304, 22.2974727834974, 21.56711288860866, 27.332370247159684, 21.39125919342041, 28.471060139792307, 37.00243009839739, 38.47008071626936, 44.73495176860264, 52.81396968024117, 53.20574385779244, 42.06002732685634, 17.748782464436122, 4.144017245088305, 0.8321506785494941, 0.12121711910835334, 0.022924176683383327, 0.07914474526686327, 0.03311458522719996, 0.05123267462477088, 0.05777767752962453, 0.02752461696841887, 0.02609463155801807, 0.008449850021861494, 0.08280886150896549, 0.023310400512335554, 0.013494109036400914, 0.05664401514721768, 0.03752387880480715, 0.03415851813874074, 0.028946459958595887, 0.020673542183690836, 0.053503358137926886, 0.017728651008967842, 0.06123229608471904, 0.040224933331566196, 0.08857661951333284, 0.06282256503722497, 0.01995880562545998, 0.048177024482616355, 0.09144756903073617, 0.05305242072790861, 0.02887375493134771, 0.058944927395454476, 0.01680029466349099, 0.056975167377718856, 0.04625619362507548, 0.050644086208194494, 0.041395016081098995, 0.03073099009426577, 0.047769194402332814, 0.023695674392261674, 0.06038100605032273, 0.05528387813163655, 0.02542713121511042, 0.03717941710991519, 0.027920535366450037, 0.046820364959005795, 0.047004224200333865, 0.03490850968020303, 0.03263646909700973, 0.03584412465404187, 0.01523994401629482, 0.07378217444888183, 0.017293691402301192, 0.04901387868449092, 0.032557385840586255, 0.024840715806931257, 0.03222731248076473, 0.029021702706813812, 0.0018333941989112645, 0.07681243041796343, 0.0524978337011167, 0.0021274485874788036, 0.03839340786050473, 0.04079464490392378, 0.005933634795448077, 0.0520898814845298, 0.04322231088631919, 0.049298374847109826, 0.06845807656645775, 0.018636222130485942, 0.03398677414017064, 0.027763622447050045, 0.017652709369680712, 0.04872931127569505, 0.035738799055772166, 0.01599436130241624, 0.016657156004969562, 0.019568619151998843, 0.07850513101688453, 0.010018505937685924, 0.019467568324346627, 0.017044457008263895, 0.026522875364337648, 0.0532837129597153, 0.05997313865061317, 0.02998121568400945, 0.05524485558271408, 0.06648663378187589, 0.008433834899083843, 0.4438086939709527, 3.698739332812173, 14.145078420639038, 32.428531714848106, 55.554978438786094, 72.9188984462193, 73.42277485983712, 71.34370013645717, 62.00794070107596, 63.91999462672642, 53.13287809916905, 50.18640763419015, 58.96727698189871, 41.94011878967285, 34.81959097726004, 33.57061753954206, 28.643854890550884, 26.725743872778757, 31.53880098887852, 17.304655347551616, 21.066377060753958, 27.53970796721322, 32.8704788344247, 39.55217579432896, 30.675980636051722, 29.68566083908081, 23.431839159556798, 17.225977420806885, 12.665086933544703, 8.588082892554146, 5.525233141013554, 2.6815406467233385, 1.1892718012843813, 0.6824412090437753, 0.20916741687272275, 0.1065076809110386, 0.015955968094723563, 0.05297158345846193, 0.13753672769027098, 0.050591723660805395, 0.05552707186767033, 0.0766650458265628, 0.06681752816906997, 0.059227896854281425, 0.18182450479694776, 0.17636425207768167, 0.2577426124896322, 0.4380143848913056, 0.024306260914142643, 0.06027461854474885, 0.07082953610058342, 0.0544074585528246, 0.05119916517287493, 0.046962507867387364, 0.09452659809695822, 0.007950931704337043, 0.12120371125638485, 0.05766617387001004, 0.09858821372368506, 0.9706471668822425, 0.9092334508895874, 1.6358591232981001, 2.379482477903366, 2.0096431119101386, 4.518472169126783, 8.900901215417043, 14.843938657215663, 24.391932555607386, 37.29749229976109, 35.330648354121614, 30.117588656289236, 34.8961774962289, 49.96480178833008, 73.79525388990129, 52.886203152792795, 38.50667340414864, 30.214314528873988, 31.372575759887695, 39.32814850125994, 30.43366915839059, 35.37981033325195, 43.1679801259722, 45.06538724899292, 51.403982162475586, 59.42908205304827, 61.274440220424104, 50.83337524959019, 23.64664966719491, 7.104595593043736, 1.1616578144686562, 0.1302472666970321, 0.017104152822867036, 0.02531966653519443, 0.04172180872410536, 0.015408658356006657, 0.022084845828690698, 0.04284455347806215, 0.0825300243284021, 0.05888831043349845, 0.049661173950880766, 0.04487849273053663, 0.02710365893186203, 0.016670760632093464, 0.06620517067079033, 0.038351253872471194, 0.05655997858515807, 0.03126422701669591, 0.01802618182929499, 0.05614475925852146, 0.03154768502073629, 0.05511243608114975, 0.07020680380186864, 0.11649104127926485, 0.05863644501992634, 0.01618747067238603, 0.042829289832817655, 0.01160048573677029, 0.038848820208970986, 0.03444360801950097, 0.0573009116841214, 0.029738276398607662, 0.048689759469458034, 0.029226131737232208, 0.012092800212225743, 0.042464081929730516, 0.058329089012529166, 0.05390446732885071, 0.06925357745162078, 0.04843303235247731, 0.08313340480838503, 0.021562102450323955, 0.00915443739255092, 0.0642808453579034, 0.0600179558885949, 0.00903254875447601, 0.05032493047682302, 0.10554602037050895, 0.14609401779515402, 0.09249403287789651, 0.1467703136482409, 0.1301178429275751, 0.151554921908038, 0.10629388809736286, 0.19844300805458, 0.13273008061306818, 0.17909968458116055, 0.13412053457328252, 0.14279656830642903, 0.07140108650284153, 0.17822584004274436, 0.09726194239088468, 0.06318340317479201, 0.12590639319803032, 0.16350623060550007, 0.12591448133545263, 0.12309469335845538, 0.07474042195826769, 0.1163549135838236, 0.11240164642887455, 0.10563917644321918, 0.12642476681087697, 0.13869899032371386, 0.09140593412199191, 0.07982851857585566, 0.12552523293665477, 0.14872064042304242, 0.11239609601242201, 0.15961898490786552, 0.09848306115184512, 0.1344088576734066, 0.16586157493293285, 0.1040984880445259, 0.19624353679163115, 0.2287382259964943, 0.18006107370768273, 0.11955477616616658, 0.9031765216163227, 6.679689364773886, 21.01053786277771, 44.180224963596885, 66.87091541290283, 82.99955340794155, 82.3108549118042, 81.02091489519391, 69.565308707101, 71.61606257302421, 62.576233863830566, 58.230910369328086, 64.0955478123256, 47.216125692640034, 40.391125610896516, 38.49520540237427, 30.120159489767893, 31.505602496010916, 37.834647110530305, 22.781175102506364, 28.06515680040632, 36.051583017621724, 43.81420081002371, 60.115223612104145, 51.73747485024588, 51.44639049257551, 43.088801928928916, 34.53971058981759, 27.032218490328106, 18.89509974207197, 12.05416657243456, 4.909515048776354, 2.771252747092928, 2.3479919391019, 0.6777513378432819, 0.3026665433176926, 0.34283527359366417, 0.179531490696328, 0.4631280515875135, 0.2473757644849164, 0.26932729514581816, 0.21053409496588366, 0.2592518643609115, 0.2669671875025545, 0.343118602676051, 0.20721377884703024, 0.37598616044436184, 0.605454354413918, 0.1348366332905633, 0.17752556476209844, 0.17902832983859948, 0.17235444938497885, 0.17454469257167407, 0.20464970357716084, 0.14992149812834604, 0.23084898559110506, 0.28250314242073465, 0.38126812130212784, 0.5680768457906586, 2.565507250172751, 1.424182470355715, 2.9766306408814023, 3.6874202830450873, 3.0395509217466627, 6.008097333567483, 12.174768192427498, 19.142238480704172, 30.77523217882429, 38.03497757230486, 40.93277938025338, 41.16463381903512, 44.89594152995518, 70.9911137989589, 83.66460023607526, 55.51105887549264, 42.94894858769008, 34.87001058033535, 34.0301262310573, 40.84453725814819, 34.02086428233555, 40.56182547977993, 51.23509577342442, 53.927133628300254, 61.04797758374895, 69.05738844190324, 70.24870572771344, 56.867892674037385, 28.92474797793797, 8.969510333878652, 1.7567736293588365, 0.24790640601090022, 0.1238842774182558, 0.19651854703468935, 0.14850808254310063, 0.14749021216162614, 0.16482408131871903, 0.11641585959919862, 0.17835447671157972, 0.14497212799532072, 0.11733238399028778, 0.15283260334815296, 0.10334697658462183, 0.1598473255123411, 0.12590935161071165, 0.10206930192985705, 0.10182068669902426, 0.14081373970423425, 0.13524972540991648, 0.10752466919698886, 0.10354859648006302, 0.10570244304835796, 0.2004316584872348, 0.2307400671499116, 0.11660971705402647, 0.18690852341907366, 0.21585098680640968, 0.15798902165676865, 0.11110132227518729, 0.13690829569739954, 0.1458229294845036, 0.13370485045015812, 0.17292383526052746, 0.18962887887443813, 0.10424001009336539, 0.11706983165017196, 0.18381652076329502, 0.17101986599820002, 0.18248039031667368, 0.147112743130752, 0.19626032374799252, 0.09761111651148115, 0.11285815121872084, 0.18048336676188878, 0.17741003738982336, 0.054384127126208374, 0.0985621376229184], [0.05926650549684252, 0.04166118162018912, 0.025349304944808995, 0.029107757910553898, 0.02299089024641684, 0.019124249960961084, 0.014564752478950789, 0.04489709816074797, 0.019516461861452887, 0.04367507355553763, 0.10248314043773071, 0.033841900128339014, 0.04419092980346509, 0.07468050731612103, 0.024160713456305008, 0.008637188451497682, 0.09181232910071101, 0.024166754114308527, 0.014496797196833151, 0.02533714729361236, 0.03262421475457294, 0.027806829860700027, 0.03138056184564318, 0.027491519726546745, 0.01821548292147262, 0.035744152697069306, 0.017366632220468352, 0.01640044754770185, 0.019219862330438833, 0.011839908514437931, 0.014699020988440939, 0.04584930331579276, 0.010778925714216061, 0.04509057563596538, 0.016753558867744038, 0.07789802537964922, 0.03956394522850003, 0.017138849711045623, 0.0939104747293251, 0.5609339347907475, 4.8489033068929395, 18.607435635157994, 32.52500050408499, 47.06753499167306, 61.754720551627024, 63.66160501752581, 62.227573258536204, 58.185875620160786, 53.9294056892395, 41.612719672066824, 37.361304555620464, 30.391146183013916, 20.594679491860525, 21.57017704418727, 21.895311049052648, 13.350742118699209, 19.46760698727199, 25.522416625704082, 13.50315693446568, 34.54971946988787, 45.548981870923726, 45.04895823342459, 35.38203723090035, 29.73233536311558, 20.558851105826243, 18.3096410546984, 10.12504265989576, 7.626763139452253, 2.857691377401352, 1.1322274165494102, 0.6130598091653415, 0.1285200829484633, 0.04503930213728121, 0.08196180553308555, 0.049369291934583864, 0.07947264052927494, 0.010824133109833513, 0.03721614960314972, 0.18620469261493, 0.3209081973348345, 0.04723379295319319, 0.030097499622830322, 0.10098294700895037, 0.04489882163969534, 0.018024395585858395, 0.014952725231913584, 0.1697440573147365, 0.18123853552554334, 0.08095623020614896, 0.046371500473469496, 0.06361423219953265, 0.04524438256131751, 0.03989147747467671, 0.07839181566877024, 0.03367497033572622, 0.00815134380744504, 0.0289804409923298, 0.08025136802877698, 0.040624695630478005, 0.029940964986703227, 0.04350330241556678, 0.04736261621915868, 0.14196435867675714, 0.25510020713721004, 0.43561638785260065, 0.7865199585046087, 2.631004009928022, 2.8019577051912035, 5.9103696175983975, 17.726681981767925, 32.39463145392281, 46.47237661906651, 59.254897662571494, 49.24434307643345, 27.3002313545772, 21.76236595426287, 22.382077523640223, 16.377558946609497, 13.119093520300728, 21.00922986439296, 46.91798543930054, 29.869579655783518, 33.077288491385325, 40.14848409380232, 47.69409227371216, 58.2822436605181, 52.35636132104056, 44.640338148389546, 29.134646109172277, 15.565906865256173, 3.4463319054671695, 1.3197260754449027, 0.07780961226671934, 0.02672354531075273, 0.08157403634062835, 0.04042211560798543, 0.06005013880452939, 0.09445056824811868, 0.03398044001577156, 0.033719852034534724, 0.006116264616139233, 0.038919221609830856, 0.028431151627695987, 0.025187740667856166, 0.0073117076119940195, 0.013040922282795821, 0.02086843440442213, 0.041817767146442614, 0.036876888879175694, 0.00523764785612002, 0.015989604771935513, 0.01807699562050402, 0.02921301226264664, 0.035484521450208764, 0.022828365842412626, 0.041471833030560186, 0.05316314407225166, 0.01638346042350999, 0.028760534578136036, 0.05519769061356783, 0.03236663268346872, 0.007721734449400434, 0.021544708205120902, 0.06808169319161347, 0.03834262290703399, 0.052460069834653816, 0.06664865437362875, 0.00996828671278698, 0.02038189935098801, 0.011266262287140956, 0.029096280490713458, 0.04927520626889808, 0.052750282654804845, 0.03500477344329868, 0.0432425889053515, 0.026860025844403675, 0.03919589765635984, 0.026164893859199116, 0.025813029347253696, 0.010225330196720148, 0.016644614981487393, 0.03598630827452455, 0.020217873688255037, 0.012620587650287365, 0.05637468424226556, 0.061699860995369296, 0.05934921891561576, 0.0263671939859965, 0.04232231221560921, 0.023920177881206785, 0.03656109868149672, 0.042342668266168663, 0.07481369695493154, 0.045311303077531714, 0.006940878894446152, 0.08219586618776832, 0.05041888722085527, 0.01915656858389931, 0.07972796647144215, 0.0058938323553385475, 0.03997141907789877, 0.029030822217464447, 0.012353410245850682, 0.04899754295391696, 0.05198759572314365, 0.04626854296241488, 0.016615982500037978, 0.02642310018252049, 0.013018794407668923, 0.02146784884722105, 0.04410579401467528, 0.045935894562197585, 0.08489100049648966, 0.08206889192972865, 0.01786959121402885, 0.535313646708216, 4.946140740598951, 20.996563298361643, 37.07654653276716, 56.405785356249126, 72.03422600882394, 72.21150234767369, 69.1864720753261, 66.68136160714286, 61.79206711905343, 49.66075904028756, 46.72112907682146, 36.07470314843314, 27.399936267307826, 29.560190268925258, 28.543990169252666, 21.058621134076798, 27.696315152304514, 30.894734246390207, 18.377432891300746, 35.63122047696795, 40.55468967982701, 37.86929430280413, 31.369383062635148, 26.422289984566824, 17.14921372277396, 10.765206251825605, 6.472781564508166, 4.300013422966003, 1.8645056656428745, 0.8063224330544472, 0.3252235714878355, 0.07977907372904675, 0.07469107889171157, 0.1395206419484956, 0.07630637900105544, 0.087202884655978, 0.053230709196733575, 0.05444616897563849, 0.3614931138498442, 0.2612687689917428, 0.029942339020115987, 0.029136293700763156, 0.015996629305716072, 0.07632884529552289, 0.06668008411569254, 0.0556986292691103, 0.39525603928736275, 0.5788034530622619, 0.36597288346716333, 0.28241805412939613, 0.06793199479579926, 0.21148759951548918, 0.1325093260301011, 0.17167497798800468, 0.09330062781061445, 0.0477277868028198, 0.12633476592600346, 0.08978266801152911, 0.12456525516297136, 0.029711257134165083, 0.09730241700474705, 0.03656577039510012, 0.31066389275448664, 0.2561183353619916, 0.23565879464149475, 0.70498447652374, 1.4804375831569945, 2.95603010058403, 5.983904140336173, 13.304116232054573, 23.913785321371897, 37.762017590659006, 59.72001007625035, 57.006735052381245, 31.62352384839739, 29.288234301975795, 30.283789566584996, 21.269167184829712, 21.48314390863691, 26.75231899533953, 52.436630385262625, 36.929588658469065, 38.35346909931728, 48.01115247181484, 52.947635650634766, 64.21080453055245, 60.3034850529262, 56.976857798440115, 43.03395979745047, 25.615901163646154, 5.952034056186676, 1.27082183105605, 0.05146717632721577, 0.00998935692145356, 0.052748935762792826, 0.06895684051726546, 0.04247184776301895, 0.027539844990574887, 0.021531247766688466, 0.05486774617539985, 0.03600256597357137, 0.025940848381391594, 0.07474588416516781, 0.02485540439374745, 0.019001718410956006, 0.028375018121940748, 0.0369117282597082, 0.015446447667532733, 0.06672780548355409, 0.023397919655378376, 0.08121982070484332, 0.05297061993873545, 0.01279701099597982, 0.00989090827559786, 0.02122361695260874, 0.015553875028022697, 0.01080762774550489, 0.015733854745381644, 0.046992797670619826, 0.006448270528510745, 0.01412304993053632, 0.04278492721329842, 0.0033891363210776554, 0.05844148833836828, 0.06721428795052425, 0.007896957636278654, 0.03485998085566929, 0.028171747690066695, 0.01692757765496416, 0.0589450631024582, 0.024486663019550697, 0.021021690020071607, 0.036324174609035254, 0.08254039912883725, 0.06875453530145542, 0.05285448527761868, 0.17420527578464576, 0.15395344820405754, 0.08617047326905386, 0.1345954548035349, 0.08164089918136597, 0.11838856445891516, 0.1006933618336916, 0.2084613333323172, 0.1312196480908564, 0.22353777076516831, 0.16908093861171178, 0.07174971779542309, 0.12286742483930928, 0.1721950207969972, 0.12950740568339825, 0.11600316103015627, 0.19954986151840004, 0.10360466382865395, 0.07789170143327542, 0.15487275458872318, 0.10599303924079452, 0.13423865394932882, 0.162458721814411, 0.10728926504296915, 0.1405459355030741, 0.12048945815435477, 0.07855588543627944, 0.2599707043596676, 0.13618093329880918, 0.1501432162310396, 0.15281576210899012, 0.18072957997875555, 0.10205486270466022, 0.0991484597325325, 0.13167155241327627, 0.1476476594273533, 0.13433071758065904, 0.21424991557640688, 0.19671769706266268, 1.4131460168531962, 9.546405366488866, 28.96522991997855, 49.33750452314104, 66.65778636932373, 82.34319877624512, 79.54932812282017, 77.29146235329765, 72.92930684770856, 71.3047902243478, 56.65290151323591, 51.87023755482265, 43.32416868209839, 32.23722348894392, 33.47818217958723, 32.789778981889995, 23.977376971926006, 29.299191611153738, 36.52751725060599, 24.004360301154, 48.09182105745588, 55.64087206976754, 56.53597722734724, 44.76964065006801, 36.41763148988996, 25.471467222486222, 22.04093313217163, 12.241367544446673, 9.467726571219307, 4.117708759648459, 1.777490334851401, 0.9527949648244041, 0.27339706676346914, 0.17068055777677468, 0.20029941201210022, 0.17236413886504515, 0.2536281118435519, 0.17451761902443, 0.22205255260424955, 0.7225133702158928, 0.6617712953260967, 0.14906688327235834, 0.12128738819488458, 0.29414183646440506, 0.17073576338589191, 0.16003831954939024, 0.09545211307704449, 0.34897004440426826, 0.6496238900082452, 0.3060073511941092, 0.24188310493315968, 0.11377810899700437, 0.1935789840562003, 0.1587785921458687, 0.15526247796203407, 0.08622882728065763, 0.10231501303081002, 0.13869145858500684, 0.32569849171808785, 0.3068532943725586, 0.13333187332110746, 0.1156700546188014, 0.15590173937380314, 0.5200720131397247, 0.7527193608028548, 0.9746184966393879, 1.2418212443590164, 3.570446491241455, 4.162354843957083, 8.869747229984828, 22.56810859271458, 39.14590767451695, 55.3625168119158, 67.21706771850586, 58.87524809156145, 38.45005600793021, 32.93670906339373, 34.63443538120815, 25.10251440320696, 23.99954867362976, 32.41148083550589, 57.46106038774763, 42.6037586075919, 46.323834555489675, 54.59626947130476, 62.074045862470356, 72.75060612814767, 69.99189335959298, 65.03672994886125, 50.20247186933245, 29.156041349683488, 6.865191067968096, 1.6833609172276087, 0.11480319899107728, 0.12930228454726084, 0.1893016350056444, 0.30168481171131134, 0.14041489682027272, 0.16282183304429054, 0.1332743199808257, 0.13464576138981751, 0.15840109597359384, 0.10997588373720646, 0.15085243460323128, 0.12399197449641568, 0.12295287953955786, 0.10321259272417851, 0.14515039271542005, 0.1455550574298416, 0.15508698166481086, 0.1224510350397655, 0.24064556562474795, 0.13412958623043128, 0.07819105751280274, 0.11899190422679697, 0.07724659783499581, 0.1510734741709062, 0.1763204594275781, 0.07167952334774391, 0.1095141406570162, 0.1500967230115618, 0.11389010798718248, 0.1435665562748909, 0.07210683756108795, 0.16571928613952228, 0.11980005300470761, 0.10706593881228141, 0.1392615365662745, 0.11094389536551066, 0.06149096041917801, 0.12472487374075822, 0.09257343504577875, 0.12793043601725781, 0.17388369089790753, 0.18105622673673288, 0.18213128404957907, 0.16289024294487067], [0.022995407593303492, 0.024495901273829595, 0.036534975083278756, 0.057728538023574014, 0.023593622725456953, 0.00837571158938642, 0.030468498822301626, 0.043857402700398646, 0.08673673109816653, 0.017851647355460694, 0.05633710018758263, 0.013076502962836196, 0.056844644381531646, 0.0448717311290758, 0.024232019005077224, 0.0148841643572918, 0.037540764148746214, 0.05814606097659894, 0.021767535712569952, 0.0585965064487287, 0.05931145165647779, 0.0608146781367915, 0.07249827084264585, 0.06197844711797578, 0.03119065346462386, 0.016810871328094175, 0.057344114008758745, 0.012936017376237681, 0.01628118653648666, 0.02220111958948629, 0.03201092087796756, 0.05816360789218119, 0.04324185269485627, 0.038786503552858315, 0.054452180795903714, 0.08159184788486787, 0.051917173966233215, 0.04113646709759321, 0.4279115412916456, 2.6622633039951324, 16.288311072758265, 27.42593468938555, 51.87858581542969, 61.19810731070382, 63.4063629422869, 59.56644793919155, 64.94551399775914, 48.70153243201119, 38.610562869480674, 34.46987077168056, 27.375581094196864, 27.77672665459769, 25.0336560181209, 19.76592094557626, 17.36421183177403, 19.222662142344884, 34.360488755362375, 39.76989759717669, 30.836143561771937, 36.04603835514614, 34.237321513039724, 27.109894139426096, 13.193716304642813, 10.093231201171875, 4.104257047176361, 2.3279635395322527, 0.5792760391320501, 0.06568548748535769, 0.08259080749537263, 0.0466462596585708, 0.10727608110755682, 0.06766891998371907, 0.09443276348922934, 0.11427126824855804, 0.0557070634593921, 0.1399650281029088, 0.07893656393779175, 0.03129188749673111, 0.05197033718494432, 0.07193881871977023, 0.07595847374094383, 0.051965048004473956, 0.028029872803017497, 0.10548439582011529, 0.3212114753467696, 0.5450446531176567, 0.5036400663001197, 0.7282113273228917, 0.3166715332439968, 0.18662588644240583, 0.03211494368900146, 0.11849242102886949, 0.15423102330948624, 0.1076069279972996, 0.015446149112124528, 0.16178512653069838, 0.05133156092571361, 0.08262110408395529, 0.0515576284378767, 0.19413626486701624, 0.04392688129363315, 0.07142303032534462, 0.0454757256832506, 0.051287720778158734, 0.07671532527144466, 0.05543535089652453, 0.07933772741151707, 0.173030500965459, 0.8078494625432151, 1.4459141556705748, 2.4282872761998857, 7.113184869289398, 13.059859258787972, 24.68119822229658, 30.20748792375837, 42.64244965144566, 38.78751959119524, 36.19510848181588, 33.83692462103707, 22.015398502349854, 20.88658721106393, 17.065877028873988, 26.02948921067374, 26.259577069963726, 35.16992609841483, 41.17881856645857, 55.92178773880005, 53.34333208629063, 53.87013408115932, 46.9303115436009, 25.930067437035696, 4.975471692425864, 0.6738744058779308, 0.1250219363719225, 0.06558863339679581, 0.020752706864316548, 0.10019548676375832, 0.018423891559775387, 0.0305234330174114, 0.04849646180602057, 0.024148370904315795, 0.022514772401856523, 0.06639699252056223, 0.020149735201682364, 0.05071226540686829, 0.023681294538878968, 0.008138890993515295, 0.02005390909367374, 0.006293678198874528, 0.030424499219017367, 0.07928502559661865, 0.040945547699396095, 0.025967182325465337, 0.035454910181994946, 0.021709855146972195, 0.03905938658863306, 0.04256849829107523, 0.04937795004142182, 0.026104207383468747, 0.020662407424034815, 0.03782143337385995, 0.03926344921014138, 0.02935671919424619, 0.030371376712407385, 0.006236501869612506, 0.06988062523305416, 0.06436349092317478, 0.041044590063393116, 0.046862010045775344, 0.0289043840020895, 0.02202672591166837, 0.027725307270884514, 0.02858955393146191, 0.015512409753033092, 0.03640056747410979, 0.04568571870082191, 0.052284159631069214, 0.03524078827883516, 0.030624728117670332, 0.07434914473976408, 0.04437160332288061, 0.03920429113454052, 0.0762300438114575, 0.00709241145523265, 0.0391262867487967, 0.05520291533321142, 0.02742293001418667, 0.0014914461582001032, 0.03653330249445779, 0.03371053574872868, 0.07972068579069205, 0.03112871678812163, 0.053761516963796954, 0.0498721610222544, 0.04377442126029304, 0.03261686282764588, 0.05431570365492787, 0.02991133675511394, 0.053346246747033935, 0.03204013181052037, 0.052883424796164036, 0.03625818029312151, 0.06612758697675807, 0.06089655017214162, 0.04146918674398746, 0.0442234078821327, 0.13709580206445285, 0.029512113891541958, 0.06338997637586934, 0.060127261094748974, 0.05417259383414473, 0.03821539759103741, 0.13358734175562859, 0.07414498712335314, 0.4815571169768061, 3.2454477591173987, 19.780442680631364, 33.69588661193848, 60.778950282505576, 68.92273930140904, 73.1541644505092, 69.07000637054443, 73.22912161690849, 54.89224188668387, 47.78624970572335, 43.70086874280657, 34.182475907461985, 35.97669185910906, 31.798521178109304, 24.887665680476598, 20.662271567753383, 25.05835165296282, 34.989022799900596, 40.55860846383231, 30.733456134796143, 32.35349464416504, 28.507847377232142, 21.46711962563651, 10.072998915399824, 7.640152318137033, 2.691117435693741, 1.8071651139429636, 0.4254520961216518, 0.147175507619977, 0.04139417130500078, 0.1183615859065737, 0.07165546249598265, 0.2891908921301365, 0.07851347021226372, 0.2876701323049409, 0.5282858152474675, 0.3813692501613072, 0.18142623188240187, 0.4226989538541862, 0.16515460929700307, 0.11365914145218474, 0.14782988679196152, 0.10607736757291214, 0.06524937945817198, 0.11224888105477605, 0.15800128956990583, 0.2681363033396857, 1.2030168580157417, 0.9021361374429294, 0.7980691130672182, 1.1261054021971566, 0.49206930718251635, 0.7489198903952325, 0.7434213683009148, 0.5049785716193063, 0.6016248656170708, 0.7214026355317661, 0.3971471706671374, 0.2035410723515919, 0.19378839353365557, 0.6259357982448169, 0.2281022486942155, 0.3941107264586857, 0.2969952662076269, 0.05677367640393121, 0.09350057172455958, 0.1860113644174167, 0.08166308727647577, 0.05473604252828019, 0.6165843371834073, 1.4661744513681956, 2.946312827723367, 8.376519799232483, 14.684121404375349, 22.14218054498945, 29.75097390583583, 35.703464371817454, 38.390516894204275, 33.84846905299595, 34.49407829557146, 29.9153995513916, 30.41955041885376, 22.570186104093278, 34.62215444019863, 35.934370381491526, 40.245380197252544, 50.17438725062779, 61.50641972678048, 61.453398023332866, 62.644208090645925, 58.05424894605364, 35.258526052747456, 10.719704236303057, 1.2159669974020548, 0.036554411718887944, 0.04435156618377992, 0.06649930203067404, 0.04520187573507428, 0.022018839638414126, 0.03445140777954033, 0.03339101021577205, 0.014481569174677134, 0.022872343393308774, 0.05825122033378907, 0.06445847904043538, 0.02156452990935317, 0.0060085391243254495, 0.01483957442854132, 0.0037958542400571916, 0.025478928882096494, 0.03873068047687411, 0.02646909298242203, 0.09741247538477182, 0.06503371388784476, 0.025153671424569826, 0.019127296583194817, 0.038603563726480515, 0.029369940449084555, 0.006463660974986851, 0.03812686912715435, 0.01846767233551613, 0.04995446392734136, 0.03806627594998904, 0.043210182072860856, 0.03938385185652545, 0.039439461193978786, 0.023660923221281598, 0.07857276060219322, 0.06832217278757266, 0.07147481611796788, 0.07216274206127439, 0.06399731950036117, 0.016099171214071766, 0.07094211184552737, 0.05391805838527424, 0.03910501128328698, 0.04513081954792142, 0.09149189093815428, 0.15477383775370462, 0.23598044738173485, 0.1311965507588216, 0.17860294266470841, 0.08554803274039711, 0.12830527233225958, 0.11211479574974094, 0.1649503159735884, 0.15664351385618958, 0.1309273216341223, 0.13325205046151364, 0.1349866438124861, 0.14471937370087418, 0.15395730228296348, 0.2502268872090748, 0.20421587542763778, 0.162184919363686, 0.18190421909093857, 0.1861315465399197, 0.19006517689142907, 0.08054667325424296, 0.13145136779972486, 0.17437617161444255, 0.13003371815596307, 0.06631213493113007, 0.18860221467912197, 0.11827946959861688, 0.09576307889074087, 0.22755928497229302, 0.19437909897949013, 0.08898914844862052, 0.15974523313343525, 0.1903697576906, 0.11474717913993768, 0.15458835342100688, 0.30831523878233774, 0.1437013540416956, 1.1303725732224328, 5.019056873662131, 28.61388383592878, 46.64819383621216, 73.1783789225987, 77.4568989617484, 82.50809342520577, 75.3571047101702, 82.35199519566127, 64.06205749511719, 53.039765289851594, 47.38709306716919, 40.157683508736746, 38.65230417251587, 36.8505459512983, 30.870311328342982, 28.744951180049352, 30.875241075243267, 45.395621231624055, 51.974985122680664, 44.65431792395455, 46.703098501477925, 44.204029491969514, 32.698281628744944, 16.946310690471105, 12.451076337269374, 5.32867511681148, 3.3298711947032382, 0.9982981745685849, 0.30246325422610554, 0.1779359970241785, 0.2169072622699397, 0.2498390365924154, 0.33986671002847807, 0.2127295628722225, 0.41718069996152607, 0.32311786019376343, 0.34884036279150415, 0.36229394802025383, 0.4810078293085098, 0.19757756377969468, 0.16217495846961225, 0.4158297910221985, 0.25006441878420965, 0.17941129500312464, 0.5005125626921654, 0.4790603795221874, 2.169469484261104, 1.949248501232692, 2.2080361119338443, 0.6348723215716225, 1.2619822025299072, 0.5739051901868412, 0.3636119072990758, 0.45051454699465204, 0.3542229639632361, 0.4967669951064246, 0.3338046781718731, 0.28983647748827934, 0.16338330720152172, 0.26584505343011444, 0.583939040345805, 0.2698960160570485, 0.35736099843467983, 0.27776297820465906, 0.1750163829752377, 0.22139123880437442, 0.23584308475255966, 0.19562775269150734, 0.3959994151123932, 1.0917644734893526, 1.9755826081548418, 3.562018326350621, 9.671760422842842, 17.82776437486921, 33.36918578829084, 43.114381722041536, 56.87130423954555, 52.510816301618306, 48.483744621276855, 41.91521297182356, 31.514864444732666, 30.69130836214338, 26.70974564552307, 39.67256028311593, 39.82823119844709, 51.046466078077046, 58.143460341862266, 72.38551998138428, 70.89265087672642, 72.67240415300641, 67.26698357718331, 40.93042394093105, 12.884499754224505, 1.558253390448434, 0.21999782643147878, 0.1499557505760874, 0.1816021353006363, 0.15682366490364075, 0.1368860261780875, 0.15387025981077126, 0.0979340991803578, 0.15343895581151756, 0.09832754092557089, 0.20834804512560368, 0.18172368806387695, 0.1650726965495518, 0.0954703792397465, 0.08885723445564508, 0.14906894601881504, 0.05517917339290891, 0.11418646494192736, 0.15988731836634024, 0.17781539420996392, 0.09705846330949239, 0.14007286088807241, 0.1051311640601073, 0.11616105612899576, 0.14509923117501394, 0.1441935904856239, 0.14354655306254113, 0.1323433020817382, 0.17421406959848745, 0.14725853316485882, 0.09112114618931498, 0.09224684935595308, 0.1654946774776493, 0.12914292381278106, 0.14740268114422048, 0.3182717359491757, 0.1861533817968198, 0.0929933125153184, 0.20557096414268017, 0.13411655835807323, 0.2400193049439362, 0.17752578189330442, 0.12729945273271628, 0.19565414770373277], [0.017035658105409572, 0.018867136079019735, 0.031246907410344908, 0.04834850045985409, 0.02346041951594608, 0.021264352802453295, 0.057392846393798075, 0.05325556732714176, 0.05671498991016831, 0.03573393735236355, 0.03510364617354103, 0.059894991772515435, 0.009472437069884368, 0.012713491816871932, 0.03191334414961083, 0.02036145169820104, 0.018903838038178425, 0.044479154516011477, 0.05358062970585056, 0.04238651519907372, 0.03309362188779882, 0.06036907061934471, 0.03609501636986222, 0.055177158143903525, 0.0305892509142203, 0.0218252196708428, 0.01997141619878156, 0.027595615480095148, 0.03608105890452862, 0.014278059559209006, 0.0232598479571087, 0.007872416720991688, 0.05343572176726801, 0.005855454414683793, 0.08613708934613637, 0.0250284528758909, 0.0757405622197049, 0.8782380255205291, 4.490213411194937, 12.691635131835938, 28.487054892948695, 49.44261687142508, 64.97541904449463, 59.664160455976216, 60.24445315769741, 58.87708936418806, 45.84930733272007, 34.800900323050364, 25.875230516706193, 24.564855848039898, 22.169648511069163, 16.967414106641495, 21.69732734135219, 24.71714472770691, 35.941700731004985, 29.62617036274501, 44.23349680219378, 45.60757255554199, 28.961252076285227, 24.489045790263585, 14.14308168206896, 6.308045421327863, 4.089839535100119, 0.7189216943723815, 0.239212553948164, 0.025865159496398907, 0.034393722124929936, 0.07167431898415089, 0.21677760779857635, 0.014271248763959323, 0.0934569351375103, 0.06205391378274985, 0.11364392869706665, 0.05682917717578156, 0.18617267933275017, 0.17540789768099785, 0.20439401801143373, 0.37824057947312084, 0.15141857708139078, 0.1418545717107398, 0.08240254116909844, 0.13294624829930918, 0.15941972631428922, 0.19227367267012596, 0.2803888815854277, 0.07634363735892943, 1.4087741885866438, 0.27932279450552805, 1.0882030874490738, 1.6183423889534814, 1.252057460801942, 1.338988978947912, 0.8632343677537782, 0.7017431961638587, 0.8109199692096029, 1.1696099191904068, 0.7761810932840619, 0.16957468140338147, 0.15473450986402376, 0.12021741989467825, 0.1892620628433568, 0.15650953033140727, 0.11261879120554243, 0.08114692568778992, 0.11891615257731505, 0.08374679367989302, 0.11482940401349749, 0.028701010093625103, 0.05742892410073962, 0.14024317317775317, 0.3655664952737944, 0.8435336734567369, 3.877101327691759, 9.712774770600454, 15.803285121917725, 37.08062512534005, 47.93060547964913, 44.768226691654746, 44.21583795547485, 24.538251195635112, 15.920727048601423, 22.288855280194962, 14.868153129305158, 22.533985989434377, 28.32867591721671, 35.869147641318186, 37.49469607216971, 38.464553424290244, 47.96202870777675, 54.791513851710725, 50.51344197137015, 43.26441764831543, 21.198830570493424, 7.27799483707973, 0.9063926147563117, 0.19745158696813242, 0.0460749501362443, 0.03196617488616279, 0.016461524181067944, 0.07711555236684424, 0.05294797043981297, 0.04621048750621932, 0.025898651984919394, 0.08816302527806588, 0.0541700459351497, 0.01268261592901711, 0.02616442058102361, 0.01175451064149716, 0.017617047265438095, 0.04949280566402844, 0.028507681896111796, 0.011611394883532609, 0.03506159057308521, 0.03555629009913121, 0.017130680149421096, 0.031124838960490057, 0.0207248445201133, 0.019456947554967234, 0.02111187919841281, 0.04527725758297103, 0.016182167921215296, 0.059785157309046814, 0.051480821666440794, 0.03218142315745354, 0.03908652120402881, 0.041382334261600456, 0.015727386610316377, 0.006472989559240107, 0.024721704157335416, 0.027373427491901175, 0.034879838182990036, 0.046013447722154, 0.04061051085591316, 0.007263910757111651, 0.028739951218345335, 0.028145327232778072, 0.004053896018636546, 0.02787819817396147, 0.05478784189160381, 0.03857364033215812, 0.03653348230623773, 0.04732252158490675, 0.022686937092138187, 0.03770142767046179, 0.04543992278299161, 0.027464568315606033, 0.03616242543128984, 0.0794327494555286, 0.053130900088165484, 0.06129415812236922, 0.01866179781167635, 0.05953100523246186, 0.02081036877020129, 0.05662423585142408, 0.01970183932488518, 0.045600467561078925, 0.01197160707254495, 0.03571121321458902, 0.04271136723192675, 0.05496682585882289, 0.03269568145541208, 0.022448874777182937, 0.03641425691811102, 0.03049657999404839, 0.016172770211207013, 0.025924483813079338, 0.035867354300405295, 0.047894747129508426, 0.14408391208520957, 0.005621876368033034, 0.10825131234845944, 0.023242955827819448, 0.03464481061590569, 0.8288702060069356, 4.75450508083616, 13.767125947134835, 32.647789069584434, 55.696728638240266, 73.75942202976772, 68.75331442696708, 67.6076329095023, 67.29432473863874, 53.54696989059448, 43.736606802259175, 34.27016912187849, 33.165544509887695, 30.08727366583688, 23.551012924739293, 25.854959147317068, 29.426795278276714, 34.77191243852888, 28.783600534711564, 41.55281925201416, 40.769583565848215, 27.554792506354197, 21.197967256818497, 10.947559118270874, 4.81313875743321, 2.433094995362418, 0.5156441650220326, 0.18743259672607693, 0.054913628713360856, 0.18927502286221298, 0.3157753241913659, 0.42682851797768045, 0.5264204953398023, 0.5761881619691849, 0.4221114510936396, 0.6167752497962543, 0.4239145629107952, 0.8752497030155999, 1.3069950214454105, 1.0001861304044724, 1.4696071871689387, 1.1734745289598192, 0.24279198901993887, 0.03157587815076113, 0.028565930734787668, 0.20959873444267682, 0.11849554228995528, 0.3669644131192139, 0.9558361044951847, 0.9272542553288596, 2.333505162170955, 1.7797143012285233, 3.0733115673065186, 4.287330789225442, 3.089212954044342, 3.043857284954616, 2.933931354965482, 2.623943554503577, 2.855051496199199, 2.455699873822076, 1.6989489836352212, 1.1533465747322356, 0.6618658559662955, 1.2123110507215773, 0.7617586957556861, 0.964177416903632, 1.1433489854846681, 0.5042547104614121, 0.29110826924443245, 0.24699898755976132, 0.22082683337586267, 0.11575799275721822, 0.13958342000842094, 0.21258970323417867, 0.7063138623322759, 2.4687010390417914, 7.989496452467782, 13.180165580340795, 31.555448872702463, 43.31968709400722, 46.61081600189209, 41.99517284120832, 29.668523107256206, 21.99825382232666, 28.67105187688555, 24.172572714941843, 28.50549020086016, 38.3233243397304, 44.13436337879726, 45.4214893749782, 47.70573050635201, 56.324713775089805, 61.86266776493618, 63.19886193956648, 53.73686415808541, 31.045718601771764, 11.373289142336164, 1.5310368623052324, 0.0466284888264324, 0.03894115186163357, 0.06856515617775065, 0.0550906720704266, 0.05936359707266092, 0.05196812176810844, 0.059870035254529545, 0.04843989234151585, 0.05579359703032034, 0.028081909653597643, 0.04386627454576748, 0.016633553164345876, 0.017556303114231144, 0.014114179781505039, 0.03352977741243584, 0.05637909811256187, 0.0484530660989029, 0.012788546271622181, 0.04630822708298053, 0.027344837418890426, 0.061603312247565815, 0.026763500845325843, 0.01173117327769952, 0.03532589692622423, 0.053677616108741076, 0.07100266431059156, 0.028989645319857767, 0.034658978427095075, 0.03636799440053957, 0.04062266341809716, 0.030016129703394005, 0.010945940323706185, 0.03337292725752507, 0.041286012823028226, 0.030149458441883326, 0.06873544811138085, 0.03684547270781227, 0.05906303320080042, 0.03438399193276252, 0.02896278551114457, 0.03915703456316676, 0.14520335915897573, 0.12030227748411042, 0.09889153244772128, 0.09469389769115619, 0.15190885934446538, 0.07746457720973662, 0.13515889671232018, 0.09281695447862148, 0.1607638363327299, 0.14362976859722817, 0.14872525446116924, 0.22550094899322304, 0.0946371585928968, 0.14149018483502523, 0.15132240152784757, 0.1256981779422079, 0.11794242768415383, 0.18718775414994784, 0.2065035698137113, 0.12376541165368897, 0.07670346447931868, 0.1283414111073528, 0.18498749578637735, 0.2049334669219596, 0.09748062744204487, 0.09419389880661454, 0.09191260300576687, 0.11150079619671617, 0.12876717826085432, 0.0908282972606165, 0.1309705443148102, 0.24446430642689976, 0.2089741700994117, 0.13774125171559198, 0.22670207811253412, 0.15765390678175858, 0.20662664249539375, 1.5995316611868995, 8.58008291040148, 22.12070540019444, 42.86655337469918, 69.01697771889823, 83.26156302860805, 77.48733901977539, 75.2051476069859, 74.4307986668178, 59.03377819061279, 48.041571685246055, 38.663191999707905, 37.00532054901123, 33.362911564963206, 25.68649138723101, 30.7725328036717, 38.178152152470176, 52.62980072838919, 41.40041051592146, 55.32502433231899, 56.10408067703247, 37.995536123003276, 30.288462230137416, 17.126722403935023, 7.560727460043771, 4.8713425142424445, 1.1779902066503252, 0.3936735327754702, 0.1808195672929287, 0.2124597773488079, 0.28328913024493624, 0.5327308167304311, 0.43458365755421774, 0.3451751066105706, 0.4065122295703207, 0.34590996003576685, 0.18312385864555836, 0.34985669968383654, 0.8093457679663385, 1.0390144011804034, 2.065034802470888, 2.1779773363045285, 0.5976729691028595, 0.2547739403588431, 0.32493671402335167, 0.46998168953827446, 0.8127245466623987, 1.1936640398842948, 2.361493591751371, 5.5574041690145215, 4.1666457908494134, 1.98124560713768, 4.9453955463000705, 3.0996283037321906, 2.5740494089467183, 2.0472786809716905, 2.5539730233805518, 3.199655222041266, 3.6191125426973616, 3.1031681937830786, 0.873936764895916, 0.7193820125290326, 0.43759252609951155, 1.2907438363347734, 0.6360224112868309, 0.9219286782400948, 0.8120105649743761, 0.48893860088927404, 0.2725680598190853, 0.22951474147183554, 0.18734418361314706, 0.2962264860314982, 0.3954543343612126, 0.6655463384730476, 1.658570287483079, 5.061979370457785, 12.200437443596975, 19.391803877694265, 44.95167303085327, 56.83926609584263, 60.29299327305385, 55.812211172921316, 35.21832724979946, 24.303422927856445, 34.64621605191912, 24.98112416267395, 35.58111701692854, 41.88901131493704, 50.49382373264858, 54.130358014787944, 56.80412905556815, 66.47370079585484, 73.156631061009, 72.88729803902763, 61.67688683101109, 33.97905002321516, 13.902971046311514, 2.0583358705043793, 0.42274012735911776, 0.17437465169600078, 0.15526988756443771, 0.1666156987526587, 0.1738143174776009, 0.23813732021621295, 0.19726933246212347, 0.11550479062965938, 0.19494999120278017, 0.17288165752376827, 0.18933588745338575, 0.06643864100000688, 0.10914473940751382, 0.1745858932180064, 0.14865683098988874, 0.10917103942483664, 0.1197626521544797, 0.08765889411526066, 0.22736222483217716, 0.1641294921615294, 0.13438335832740578, 0.10800712795129844, 0.10877292257334505, 0.1711574728999819, 0.0947766721780811, 0.21552109665104321, 0.09191958513110876, 0.17392671001808985, 0.1358126380613872, 0.15776875561901502, 0.11403587087988853, 0.143967529758811, 0.18469179022525037, 0.12251341954938003, 0.14783022605947085, 0.16420482311929974, 0.2119398702468191, 0.09500634271119322, 0.10375963444156305, 0.12751765602401324, 0.1457999950008733], [0.04001625667193106, 0.02587741892784834, 0.030013486809496368, 0.04894574698326843, 0.057696640092347345, 0.0381431098628257, 0.04352572460525802, 0.030139928417546407, 0.031491800876600404, 0.023706322303041816, 0.036476766956704, 0.03493870448853288, 0.05080182524397969, 0.06949932247932468, 0.018004154886252115, 0.0643619235072817, 0.03413004002400807, 0.019271386887079904, 0.052797909027763774, 0.025056038717074052, 0.029191943750317608, 0.034565754500882964, 0.02779211922149573, 0.043436090129294565, 0.03157665168068238, 0.009081169181237263, 0.025935138509209667, 0.0958388712523239, 0.04890184237488678, 0.04159952314304454, 0.0075349091618720975, 0.008241001183965375, 0.0799430620723537, 0.05095122169171061, 0.06296475205038275, 0.10512517259589263, 0.09089910917516265, 3.083189082997186, 19.50715787070138, 40.260120800563264, 51.78297165461949, 64.96284280504499, 59.0092579977853, 57.549156597682405, 47.902090072631836, 50.02200630732945, 39.998208454677034, 26.994121517453873, 18.396064485822404, 17.047457354409353, 19.284942320414952, 20.077653612409318, 29.416126319340297, 30.553740978240967, 34.79616512571062, 50.47352804456438, 33.799380029950825, 21.518654414585658, 12.523720622062683, 4.267265694481986, 1.1252020278147288, 0.7822509418640817, 0.093881399503776, 0.1580404546111822, 0.07871513081980602, 0.17472567143184797, 0.06933411955833435, 0.21520203591457435, 0.22675215399691037, 0.5707321975912366, 0.3085321257156985, 0.19952071165399893, 0.10054734109767846, 0.5965936641607965, 2.544306342090879, 0.8483411212052617, 0.647781314594405, 1.43171084352902, 1.3818374340023314, 0.15261830841856344, 0.08668582740106753, 0.10749203166259186, 0.14537026520286286, 0.11871385414685522, 0.35889348334499765, 0.07240810032401766, 1.0302912635462624, 1.2015999683312006, 2.1596773011343817, 1.7754388792174203, 1.505782114607947, 3.2319369869572774, 4.09758460521698, 3.5450768811362128, 1.3570065264190947, 3.427109931196485, 2.686005732842854, 1.6472622028418948, 0.6619482572589601, 1.632438438279288, 0.5722210119877542, 1.182205157620566, 0.5921609848737717, 0.4721119095172201, 0.3049228351031031, 0.22125718742609024, 0.11741945360388074, 0.03933240533141153, 0.09438839408435992, 0.0802232970350555, 0.09903054391699177, 0.11778180487453938, 0.10654913261532784, 0.43813527269022806, 2.5055690492902483, 5.619539303439004, 18.453371490750992, 27.201127461024694, 36.42866175515311, 37.74250357491629, 33.60920088631766, 19.762254033769878, 17.792615175247192, 22.03077139173235, 14.318288326263428, 25.253576925822667, 30.550850527627126, 37.745355810437886, 38.36125455583845, 43.57481104987008, 57.69126810346331, 54.87303706577846, 54.06569807870047, 41.99180991309029, 18.893454756055558, 5.277756980487278, 0.5856228928480829, 0.137265110122306, 0.11978884360619954, 0.004828415752854198, 0.029379080315785747, 0.07035917562565633, 0.03554082289338112, 0.024586848715054135, 0.02932773217824953, 0.015423901645200593, 0.04958756647205778, 0.024492240577403988, 0.03769462535689984, 0.03450585003676159, 0.048989641413624795, 0.00036211540022382645, 0.050871290266513824, 0.04498428991064429, 0.03829484386369586, 0.05966183356940746, 0.024333134293556213, 0.04483319712536676, 0.014686724237565483, 0.03706294657396419, 0.018766853692276136, 0.010485913937113114, 0.041980456095188856, 0.011800668834309493, 0.05728020279535225, 0.02900271051164184, 0.04704532985176359, 0.07306848453091723, 0.027927066266004528, 0.014949515761275376, 0.04344797467014619, 0.07803563906678132, 0.01772124819191439, 0.010661433983061994, 0.04915315817509379, 0.03580605883949569, 0.11154934537730046, 0.030067711935511658, 0.04146097647026181, 0.01978474951881383, 0.01707114718322243, 0.04555210837029985, 0.025335978517042737, 0.029913436820996658, 0.014746386125417692, 0.022513189718925526, 0.032633639605981965, 0.004143561876844615, 0.07366301012890679, 0.04126470343076757, 0.030370827099042277, 0.07344273052045278, 0.019539012972797667, 0.042618587746151855, 0.01626067272653537, 0.03283509326034358, 0.01656954695603677, 0.04138938084776912, 0.06073404782052551, 0.05132041259535721, 0.0056080376463276994, 0.01735345846308129, 0.028624233856265033, 0.03698805666395596, 0.03210507778983031, 0.04160216264426708, 0.03373462713456579, 0.009794429077633789, 0.02681681334174105, 0.026698853421424116, 0.06270197579371077, 0.12419831699558667, 0.13956638877945288, 4.338640195982797, 20.88785352025713, 43.85874571119036, 58.74573366982596, 73.25741468157086, 69.47347436632428, 64.26930141448975, 55.46252918243408, 57.847387177603586, 47.61472300120762, 35.09480217524937, 25.261744533266338, 24.69432510648455, 28.69640585354396, 27.287662063326152, 31.59495632989066, 35.559306621551514, 44.15425954546247, 43.070298876081196, 28.144388845988683, 21.34127732685634, 10.379218186650958, 4.080247112682887, 1.2735202291182108, 0.4716501800077302, 0.11605092989546911, 0.2352853018258299, 0.159212501719594, 0.7716856630785125, 0.5693110195653779, 0.6942300764577729, 0.9098550975322723, 2.1340833944933753, 2.0830065352576117, 3.129367245095117, 3.2929690948554446, 2.657963671854564, 5.256933229310172, 4.014934045927865, 2.8404941516263142, 2.180724697453635, 1.08671150462968, 1.245156271117074, 0.07595132198184729, 0.26972860789724756, 0.10403926550809826, 0.08396590620811496, 0.0007808773953001946, 0.15740013468478406, 1.4572061726025172, 2.1587779436792647, 2.824363474334989, 4.857138225010463, 5.4281207748821805, 3.617953496319907, 5.947203321116311, 5.662083123411451, 4.9943981511252264, 7.9354776825223645, 5.833029219082423, 5.3930193441254755, 3.9455614941460744, 3.3618676492146085, 2.117521494626999, 2.608849895851953, 1.6174356490373611, 2.2398868714060103, 1.7687985726765223, 1.4329424117292677, 0.8081635971154485, 0.5225834612335477, 0.43181303622467176, 0.07654670253396034, 0.06433985076312508, 0.04776765412784048, 0.13600538271878446, 0.16448435240558215, 1.6821609416178294, 5.944386695112501, 16.383539608546666, 22.77262360709054, 35.03532212121146, 32.506052766527446, 35.061183316367014, 28.34493296486991, 20.541223526000977, 25.966599328177317, 28.26410804476057, 36.04512466703142, 42.101918016161235, 48.50777844020298, 47.48610837118966, 51.86509241376604, 64.43169471195766, 62.79328863961356, 64.48591845376151, 50.63600124631609, 26.726027011871338, 8.568941473960876, 1.5603881158999033, 0.1085507430668388, 0.10243098145084721, 0.016069059526281695, 0.00886539843798216, 0.06316829219992671, 0.04814776265993714, 0.032123123428651264, 0.022859497029068213, 0.024050359913547124, 0.02519410871900618, 0.013971362578948694, 0.059669507800468376, 0.048854670620390346, 0.01562794391065836, 0.04660482152498194, 0.047832376190594265, 0.016079629405534694, 0.015090194730354207, 0.07330550359828131, 0.011876473070255347, 0.023980131539117013, 0.020232760746564184, 0.03024466708302498, 0.004644083233350622, 0.04521304102880614, 0.0659624044118183, 0.01148357754573226, 0.05234430158244712, 0.10046236137194292, 0.03244331053325108, 0.03316446094374571, 0.06258904721055712, 0.02013905845316393, 0.040628264724676094, 0.036261786706745625, 0.02794574633506792, 0.02661628249500479, 0.03411758890641587, 0.033231696978743584, 0.12080077002091066, 0.1986796267862831, 0.14103906761322701, 0.11605144558208329, 0.14822392564799103, 0.16041192093065806, 0.10390884429216385, 0.10375349369964429, 0.11357089797300951, 0.0752756775223783, 0.09324006856020008, 0.211630770404424, 0.15339593669133528, 0.09919880703091621, 0.06378388631024531, 0.16690313975725854, 0.1261208238346236, 0.09849368701023714, 0.25364662227886065, 0.10365314515573637, 0.10726721944021327, 0.2174302227795124, 0.17148209762360367, 0.15989673643239907, 0.18737340133105004, 0.21746146253177098, 0.15890093200973102, 0.22796947296176637, 0.1268046378557171, 0.1601514041955982, 0.1082838141758527, 0.08605604512350899, 0.15612755582800933, 0.1572337443275111, 0.20445573755673, 0.32310681364365984, 0.264836424695594, 6.515009241444724, 29.153015409197124, 56.151307582855225, 70.73958900996617, 82.58915110996791, 77.01470865522111, 73.9140680858067, 63.39635058811733, 64.9873491014753, 54.73475749152047, 41.96758501870291, 30.276264667510986, 27.145005123955862, 29.320991584232875, 31.638177599225724, 42.82313755580357, 44.96884897777012, 49.48240573065621, 61.826057706560405, 41.11597211020333, 26.771758317947388, 15.412184919629778, 5.346875923020499, 1.5472336560487747, 1.0806704802172524, 0.31077682812299046, 0.3406761480229241, 0.4078123840902533, 0.5852044267313821, 0.4705601270709719, 0.9239872992038727, 0.43106130084821154, 1.5299995179687227, 1.8322814404964447, 2.6392033185277666, 2.664471311228616, 3.3152530533926825, 6.017054864338466, 4.7639802524021695, 4.218688666820526, 6.504359824316842, 4.203433462551661, 3.5261163328375136, 0.2822040170431137, 0.6805617756077221, 0.40734807614769253, 0.35932223605258123, 0.5544926290001188, 0.7704448125192097, 3.743741078036172, 5.586221822670527, 6.5249938028199335, 6.697438103812082, 10.302467516490392, 7.339482920510428, 9.93992441041129, 8.358482275690351, 7.690626638276236, 10.290144886289324, 11.032825674329485, 6.370335587433406, 3.734062237398965, 4.437006277697427, 2.323272419827325, 4.432943752833775, 2.3790121717112402, 1.7598347451005663, 1.5514301508665085, 1.0931755006313324, 0.5228201885308538, 0.3545134040926184, 0.3215022954557623, 0.29431239302669254, 0.2615108702863966, 0.3097772103335176, 0.42775895233665195, 0.6896428540349007, 3.1612316838332584, 7.891914214406695, 24.68934324809483, 35.163485118321006, 48.642795835222515, 47.9166430745806, 44.150590896606445, 29.593781335013254, 28.0033404145922, 35.485013008117676, 25.73915352140154, 39.318945612226216, 42.878702299935476, 54.449999468667166, 56.62812423706055, 60.93540981837681, 71.23416873386928, 71.31013338906425, 73.89776761191231, 60.86350985935756, 31.926705019814626, 12.037048816680908, 2.464349512542997, 0.23836845638496534, 0.38009829978857723, 0.12255666937146868, 0.15269586497119494, 0.27177284391863005, 0.2527924009731838, 0.14141352394861834, 0.09985146950930357, 0.14133170619606972, 0.15900196587400778, 0.09928329142608813, 0.1431500714804445, 0.1722861480500017, 0.11099226134163992, 0.1440536222819771, 0.12556662357279233, 0.07822368826184954, 0.14058078506163188, 0.2360493051154273, 0.17139734859977449, 0.08376151788979769, 0.12273934456918921, 0.05043270219383495, 0.07825883637581553, 0.19320701115897723, 0.18480435918484414, 0.1348557544073888, 0.14037632888981275, 0.22067899416599954, 0.12919215831373418, 0.1392621879598924, 0.16341306774743966, 0.1521990687719413, 0.1390744780323335, 0.13815648800560407, 0.1347650478460959, 0.14201921144766466, 0.18941239906208857, 0.09574425632932357], [0.011366380977311304, 0.010967154721064227, 0.078318235331348, 0.0792767678254417, 0.01583179788264845, 0.04390244724761162, 0.05268899058657033, 0.048556284845939705, 0.05311705458110996, 0.01813538186252117, 0.037430654878595045, 0.03685884324035474, 0.029144076497427056, 0.009816891979426146, 0.04899019781234009, 0.04888300285009401, 0.03444502955036504, 0.049690449344260354, 0.00846988461645586, 0.034513693901577165, 0.05896412315113204, 0.04583752055519393, 0.025701807279671942, 0.03807623005871262, 0.02659789419599942, 0.04422168779586043, 0.009529023497764553, 0.034873141042355976, 0.034856045352561135, 0.11160057477120842, 0.06689745280891657, 0.054541214768375666, 0.02824551801729415, 0.03979988881785955, 0.05363673098119242, 0.15264429630977766, 3.8466747317995345, 19.23496045385088, 37.25801958356585, 48.67349992479597, 65.87487724849156, 58.03444310597011, 62.1491767338344, 54.527464934757774, 46.294103213718955, 39.50373642785208, 31.512863363538468, 22.72289534977504, 31.18917805807931, 23.359272173472814, 25.418454204286846, 27.983888932636805, 32.87448794501168, 45.157051358904155, 29.5786029951913, 22.204010827200754, 12.826269507408142, 4.4526362504277905, 1.9686648079327174, 0.3350767142006329, 0.1946073988718646, 0.10611572515751634, 0.07059879348214183, 0.037920380742954354, 0.045271174516528845, 0.4009291077298777, 0.7904653953654426, 0.5946851351431438, 0.9420323137726102, 2.4406381334577287, 1.8066115379333496, 2.377673340695245, 3.6667111771447316, 3.7968987056187222, 4.361115881374904, 4.2304602180208475, 0.7597830189125878, 0.7565662743789809, 0.3688191207391875, 0.42047002060072763, 0.24351004191807338, 0.12212008636976991, 0.06224534208221095, 0.16969795764556952, 0.02690482951168503, 0.7117648326924869, 0.6696444185716766, 1.1819495941911424, 1.7662504294088908, 3.302980146237782, 7.776198046548026, 4.547177783080509, 7.407479728971209, 4.792674141270774, 2.886344228472028, 3.589939228125981, 2.8999524925436293, 5.815434643200465, 4.487859274659838, 2.1319739648274014, 2.171225207192557, 1.5910337971789497, 1.8539774077279227, 2.6666645535400937, 1.4721592387982776, 0.8154741334063667, 1.149775743484497, 0.7909504664795739, 0.4816826188138553, 0.17445128544100694, 0.10190895731960024, 0.0709877365401813, 0.05213436624035239, 0.07118557699556861, 0.057922680463109694, 0.5698146553976196, 4.106172578675406, 12.707841805049352, 21.010847057615006, 45.70200899669102, 41.212277616773335, 27.337440695081437, 26.101995400020055, 20.581566504069738, 16.22375362260001, 19.825526067188807, 22.985648427690776, 21.277449437550136, 31.216776302882604, 41.312616552625386, 38.16878598076956, 46.59672505514962, 55.68826573235648, 65.44713919503349, 54.27160446984427, 39.80008404595511, 14.828341688428607, 4.863691244806562, 1.1650356160742896, 0.07073448691517115, 0.03275110080306019, 0.030688194890639613, 0.06054001394659281, 0.056566719830568345, 0.03995798069185444, 0.0502610803315682, 0.0511758846363851, 0.04821710554616792, 0.02391815754318876, 0.05597875905888421, 0.03203029983810016, 0.022611256688833237, 0.031444208430392404, 0.07978486163275582, 0.013752127066254616, 0.009365594097679215, 0.0659414173236915, 0.02813976663830025, 0.05465475403304611, 0.024679506064525673, 0.02872301159160478, 0.056132016370871236, 0.019330521213955114, 0.060595212770359855, 0.018284746079838703, 0.07875544937061411, 0.04246408532240561, 0.07486876685704504, 0.032536900868373256, 0.08514207880944014, 0.08522158954292536, 0.015105256511430656, 0.025755679567477534, 0.03810488798522523, 0.014564280897112829, 0.041803144716790745, 0.03229795476155622, 0.019887800328433514, 0.011931187589652836, 0.03471591090783477, 0.017187824672354118, 0.041089410694049935, 0.057028649507888725, 0.03773963937003698, 0.08467156227145876, 0.024005517230502198, 0.039050864188798835, 0.018206667055242827, 0.0160233228733497, 0.03009396784805826, 0.029652682598680258, 0.020348885229655674, 0.013120935980363615, 0.03639079656984125, 0.036816390696913004, 0.027104368000956516, 0.04551940637507609, 0.04005806799978018, 0.04053218416603548, 0.057575623371771405, 0.042094938523535214, 0.026077164370300512, 0.06206325042460646, 0.054414542458419285, 0.06117926178766148, 0.028219445309202586, 0.03942147662330951, 0.021880465992061154, 0.04375584636415754, 0.03848337142595223, 0.054249560061310015, 0.12959078406648977, 4.412866933005197, 21.929661205836705, 43.19775663103376, 56.68235840116228, 73.8701832635062, 66.38629940577916, 68.43223817007882, 61.94824177878243, 53.28393541063581, 47.32168967383248, 38.2426244871957, 30.05891111918858, 36.717223916734966, 23.405231033052715, 26.212902545928955, 24.208922215870448, 33.205409799303325, 40.39404385430472, 30.69104780469622, 22.446139914648874, 11.136429394994463, 4.198416863168989, 1.7717089993613107, 0.31402573521648136, 0.10525406710803509, 0.3503083868750504, 0.34215223310249193, 0.8823840373328754, 1.3232620571340834, 1.6484059414693286, 2.019500217267445, 2.6918461280209676, 3.642355569771358, 5.519262901374272, 6.449316195079258, 3.5669819457190375, 5.127876954419272, 5.338350049086979, 8.00371333530971, 7.444210512297494, 4.1741059848240445, 3.337186779294695, 1.7992151805332728, 1.3131985685655048, 0.14554690143891744, 0.08198977474655424, 0.1185919214040041, 0.1873006352356502, 0.15737623668142728, 0.16228038924080984, 0.19218706446034567, 2.421699298279626, 3.794967540672847, 5.511857424463544, 7.052788955824716, 5.788380529199328, 6.699107842785971, 7.553647245679583, 7.274270168372563, 6.859041912215097, 6.468004243714469, 10.137440851756505, 6.776146863188062, 5.987465092114039, 3.0989471631390706, 3.857593825885228, 3.1306240005152564, 4.765652596950531, 4.224844770772116, 4.258556127548218, 3.541863339287894, 3.5562639151300703, 1.8732879715306419, 0.9749146636043275, 0.5820498902882848, 0.3287405813378947, 0.06339630032224314, 0.13237004993217333, 0.09654549762074437, 0.273873642619167, 3.2467066858495985, 10.946024434907095, 20.29371132169451, 37.93357556206839, 30.16633721760341, 24.91257323537554, 29.839830943516322, 27.69924555506025, 20.932250772203716, 27.206331661769322, 35.11302382605416, 32.211313656398225, 42.89099366324288, 51.547083786555696, 48.04888119016375, 53.91869504111153, 61.5857264654977, 73.18769645690918, 61.42950316837856, 48.286453996385845, 21.121719462530955, 7.48327328477587, 1.511547816651208, 0.09879905491002969, 0.03719092506383147, 0.033097679527210336, 0.030837119756532565, 0.009669291953157102, 0.01489451710533883, 0.07333764580211469, 0.029123201367578337, 0.043854864979428906, 0.01789113978988358, 0.016205506133181707, 0.04522237427798765, 0.023490790743380785, 0.019294750544109514, 0.031276287976652384, 0.021841092301266532, 0.04311590641736984, 0.0332513711016093, 0.006725404586177319, 0.05659582559019327, 0.059058812712984424, 0.01693497707934252, 0.004465982633908945, 0.02883054582136018, 0.0488592609097915, 0.031161130405962467, 0.02706531491795821, 0.05955998546310833, 0.0964175123455269, 0.06096377942178931, 0.06109485203134162, 0.03675229627905147, 0.0163618914916047, 0.040189666473971944, 0.10129407567105123, 0.030203330729688917, 0.04308563018483775, 0.11157797955508743, 0.10050669006471123, 0.13507303489106043, 0.25565397313662935, 0.14313005469739437, 0.17578460675265106, 0.1854317190923861, 0.1699039608772312, 0.10369719564914703, 0.0688860828855208, 0.10895949256207262, 0.1221547323678221, 0.1004174423537084, 0.11483268812298775, 0.17544649275285856, 0.11146084405481815, 0.09480535385331937, 0.17601799565766538, 0.13908551101173672, 0.13813436776399612, 0.1711922138929367, 0.11644905353231089, 0.11087710037827492, 0.11461926171822207, 0.1452130214976413, 0.11941689785037722, 0.18776452248649939, 0.15655131451785564, 0.2060653040451663, 0.2600282169878483, 0.12396700440772943, 0.1289238655673606, 0.15741926937230996, 0.14155623343374046, 0.12038891283529145, 0.4752072777066912, 7.483285444123404, 32.35304995945522, 52.08113275255476, 68.7608254296439, 83.75245325905937, 74.36182389940534, 78.79059873308454, 70.98187964303153, 60.50299562726702, 51.95471027919224, 43.894723483494346, 33.94310004370553, 43.42039775848389, 33.239779063633506, 36.56743465151106, 39.938311508723665, 45.607315472194124, 57.11554731641497, 39.09286165237427, 28.855900015149796, 15.879254988261632, 5.394483242716108, 2.2746721591268266, 0.5095574344907488, 0.31812878219144686, 0.5387528421623367, 0.32259921516690937, 0.5962776839733124, 0.8009203714983804, 1.0990921088627406, 2.021112850734166, 2.255639740398952, 4.754263196672712, 6.158573601927076, 8.436696410179138, 7.048823271478925, 9.245042886052813, 11.880090747560773, 11.488532832690648, 13.649466889245168, 8.372548035212926, 5.051497578620911, 2.3408448483262743, 2.123998301369803, 0.9711638305868421, 0.6173966250249318, 0.436332106590271, 0.5768992666687284, 0.4802582381027085, 2.013860885586057, 1.9592365367071969, 4.7366964135851175, 9.279547640255519, 13.238826615469796, 19.633316312517437, 15.764284883226667, 16.92950473512922, 12.854663320950099, 12.44921943119594, 12.98225656577519, 11.964528730937413, 16.230165072849818, 11.917360016277858, 5.609117005552564, 6.3979668361800055, 5.609514789921897, 7.703106471470424, 7.576210652078901, 5.11335391657693, 4.541947526591165, 3.7656999911580766, 2.900112518242427, 1.5156965426036288, 0.9834385833569935, 0.5065552698714393, 0.19716399668582849, 0.23184678490672792, 0.3020548032862799, 0.3197212224560124, 0.8631192339318139, 5.296085894107819, 14.756891625268118, 27.307763201849802, 57.5543121610369, 53.76310403006417, 39.18171869005476, 39.63265677860805, 31.228959969111852, 25.89929560252598, 30.11310706819807, 35.935509886060444, 34.756094864436555, 46.96685559409005, 57.28876938138689, 58.573182106018066, 65.18839522770473, 71.39413016183036, 80.90442834581647, 71.83923176356724, 59.3166949408395, 28.86583593913487, 11.471634813717433, 1.8915239529950278, 0.16539528566811765, 0.15840147595320428, 0.14629542055938924, 0.17973175352173193, 0.16037369226770742, 0.10259303596935102, 0.1200600133410522, 0.17481609300843307, 0.15022173630339758, 0.0845186272636056, 0.15277503643717083, 0.134948143735528, 0.11061671935021877, 0.11353473884186574, 0.11817341457520213, 0.09993357903191022, 0.11057112858231578, 0.15212660123194965, 0.13542822083192213, 0.1633715821163995, 0.11085625578250204, 0.08978816414518015, 0.09015941100993327, 0.19595376162656716, 0.16827523255986826, 0.07936488238296338, 0.12000454988862787, 0.21541202893214567, 0.25098334518926485, 0.14000804722309113, 0.17983570508658886, 0.21618078196687357, 0.12239618226885796, 0.12459108020578112, 0.10903876580830131, 0.14921806087451323, 0.1494287188564028], [0.04253972840628453, 0.03496433275618723, 0.021451631860275353, 0.028751452386911427, 0.04846348500411425, 0.017941225852285112, 0.054447919595986605, 0.0216266413086227, 0.06600541674665042, 0.0202569759650422, 0.010399499109813144, 0.07510358068559851, 0.032647817595196624, 0.023985583567991853, 0.034216990893972773, 0.06334291997232608, 0.017054762258859615, 0.1041563670816166, 0.02489555500713842, 0.0669694250183446, 0.05587067521576371, 0.056213844301445146, 0.016901515124897872, 0.04184228940201657, 0.031264800378786664, 0.09843447804450989, 0.030530527101031373, 0.034622666625572104, 0.04558286975537028, 0.04835854956348028, 0.026787673655365194, 0.038554461539856026, 0.023787571782512323, 0.05431880795263818, 0.07122499988015209, 2.2368374807494025, 11.902605516569954, 41.204259395599365, 53.922978605542866, 66.43482562473842, 69.6192684173584, 56.26449373790196, 49.742966651916504, 39.330351080213276, 40.09919357299805, 28.80652264186314, 32.14555590493338, 23.391418014253887, 22.33603354862758, 36.60953378677368, 40.93239722933088, 57.58366135188511, 44.739422934395925, 27.34844490459987, 17.35159911428179, 6.0220145753451755, 1.8229248225688934, 0.5938752900276865, 0.10070445588124649, 0.06639682288680758, 0.13649079310042517, 0.12247263959475926, 0.1445769356297595, 0.8618098241942269, 0.7062808583889688, 2.7379450372287204, 1.5940918730837959, 1.7059335517031806, 3.2245273845536366, 4.350051743643625, 5.004416584968567, 4.606421598366328, 4.789928734302521, 2.7476890172277177, 7.098928902830396, 3.676949347768511, 2.195974907704762, 1.099584345306669, 0.29265025364501135, 0.6779411105172974, 0.13968346321157046, 0.051698095364762206, 0.08491860330104828, 0.07527095491864852, 0.20744452146547182, 0.006285888192776058, 0.8485586323908397, 1.5104743199689048, 1.3160744713885444, 4.501778253487178, 2.6319433195250372, 2.0251143617289404, 3.913568513734, 5.955747434071132, 5.414171397686005, 7.8947751351765225, 4.424459568091801, 6.547080823353358, 5.281820373875754, 6.7271585890225, 2.633684060403279, 1.6639664322137833, 1.4726193398237228, 3.899185742650713, 3.9018208469663347, 3.580632984638214, 2.7167756131717136, 2.88427540234157, 3.1335318216255734, 0.5987311037523406, 0.46689104395253317, 0.15517346773828777, 0.11749686087880816, 0.054941760775234015, 0.1511912542794432, 0.061098950382854254, 0.17076616175472736, 0.7675085472209113, 6.643276461533137, 18.78103290285383, 41.90761511666434, 37.71354348318917, 31.509861741747173, 25.13357285090855, 22.9169203213283, 18.38210208075387, 64.03989274161202, 52.21315894808088, 21.40077301434108, 25.672344854899816, 26.348941326141357, 44.61389677865164, 46.01313195909773, 54.442231382642476, 56.8140093939645, 58.32304000854492, 52.40596798488072, 37.3205429485866, 10.06798665864127, 1.2521457246371677, 0.0899554705247283, 0.06624265973057065, 0.007705022131891123, 0.027675950633628026, 0.06376049042280231, 0.04826867760026029, 0.02934309421107173, 0.04626105532848409, 0.013597682317984956, 0.028616668190807104, 0.028188130918091962, 0.05939896910318306, 0.05428599399913635, 0.03408044250681996, 0.0024079880427702195, 0.07092115189880133, 0.022053083604467765, 0.06880361373935427, 0.047500497927623134, 0.05313628087086337, 0.010460193219062473, 0.043708250525274446, 0.026268852209406238, 0.02039241834011461, 0.05325028832469668, 0.0364985581088279, 0.03821962486420359, 0.03974971454590559, 0.013419546519539185, 0.020280957088938782, 0.06677982197808367, 0.02244667293104742, 0.035031219345650504, 0.040830088180622885, 0.04642231596101608, 0.0685036809050611, 0.02755307642343853, 0.00894178366953773, 0.019830096014110104, 0.056670267667089186, 0.028380548182342733, 0.03604795318096876, 0.003412325891466545, 0.016093882033601403, 0.019840989893834506, 0.02855715049164636, 0.030376041640660593, 0.05573736683332494, 0.018974510853045752, 0.029135068945054497, 0.04336047757949148, 0.028272871460233415, 0.04329568087788565, 0.06674870436212846, 0.04467998731083103, 0.061493423501295705, 0.059299136245889325, 0.023638874225850617, 0.04250623591776405, 0.030726976559630463, 0.03254556915323649, 0.03761691952656422, 0.03591679575453911, 0.05177436609353338, 0.024779934336298277, 0.04887327944327678, 0.03793122033987727, 0.031071553605475595, 0.022992713809279457, 0.09219284475381885, 0.05245528616277235, 2.7848629653453827, 15.311564581734793, 48.12974432536534, 61.37325750078474, 75.20161097390312, 75.77104364122663, 65.90127345493862, 56.88862262453352, 49.51926245008196, 46.49660151345389, 35.781926904405864, 40.61948510578701, 25.895776339939662, 30.490925788879395, 40.80119092123849, 35.98670073917934, 46.88963678904942, 39.11577333722796, 27.97915894644601, 15.23211019379752, 5.476753822394779, 1.7053305783442088, 0.40788664296269417, 0.08615786608840738, 0.15681280834334238, 0.7339365343962396, 0.45698220708540505, 0.755757352071149, 1.8916514090129306, 2.775741066251482, 4.311942611421857, 4.488594915185656, 4.549310880047934, 6.316611681665693, 7.519823414938791, 6.663758448192051, 6.857190651553018, 7.643968616213117, 8.08627530506679, 10.310133116585867, 6.604187633310046, 5.042955202715738, 3.2493791367326463, 2.4666819359575, 0.9190992414951324, 0.07082838259105172, 0.366980426545654, 0.487689770758152, 0.30904080984847887, 0.20838145618992193, 0.12884492480329104, 0.2517148602221693, 0.9443631087030683, 1.7963983373982566, 2.704790839127132, 3.792870921748025, 5.49795755318233, 5.587635346821376, 6.4050969907215665, 7.917090143476214, 9.858127611024038, 7.7834233045578, 10.691557952335902, 7.975934437343052, 6.067808849470956, 3.942060036318643, 3.1530803612300327, 5.383407814162118, 4.848022188459124, 6.896208695002964, 5.964491307735443, 6.807107167584555, 5.914839046342032, 2.5307821077959876, 1.9807705240590232, 2.0198888821261267, 0.5967953247683389, 0.5434048239673887, 0.09086799155920744, 0.30041182573352543, 0.01510806564640786, 0.20264151133596897, 0.42490861671311514, 5.221602942262377, 16.272959027971538, 36.572593688964844, 33.50062138693673, 30.34458977835519, 26.74268184389387, 20.345617839268275, 23.920446906770977, 62.055014746529714, 45.57057687214443, 33.394098554338726, 38.66556828362601, 34.9682685307094, 56.01163142068045, 56.68313659940447, 62.89097336360386, 65.8866058077131, 65.7553265435355, 60.652896063668386, 44.4221647126334, 12.913468531199864, 1.7349224133150918, 0.05607410340702959, 0.05735067544238908, 0.03855130635201931, 0.06377981510013342, 0.0363711428030261, 0.022977638457502638, 0.02093597747651594, 0.08269501011818647, 0.03534824447706342, 0.03613797781456794, 0.011790137122651296, 0.02041120358210589, 0.07677782513201237, 0.045053714221077304, 0.011467500506634158, 0.04862559041274445, 0.04878639981948903, 0.024733468258221234, 0.07113773349140372, 0.06569137038396937, 0.03551442788115569, 0.07774249836802483, 0.04089462025357144, 0.024378105898254683, 0.066732168463724, 0.07264505832323007, 0.04415724393246429, 0.019258087600714395, 0.025872545350076895, 0.04670302589823093, 0.021428787282535007, 0.026399694117052213, 0.03144836785005672, 0.0024808395911739872, 0.02737534435332886, 0.016922946653461883, 0.20335371526224272, 0.10523268646959748, 0.12191462596612317, 0.128743443105902, 0.10487641487270594, 0.17083776076989515, 0.11464961937495641, 0.13153057997780188, 0.17018986839268888, 0.15170202830008098, 0.14517638060663426, 0.13020512967237405, 0.09163184557110071, 0.16623774117657117, 0.2412557585963181, 0.11891647827412401, 0.1848434835140194, 0.2746024435119969, 0.13703765161335468, 0.11351345998368093, 0.11886889939861638, 0.12469253476176943, 0.08783771523407527, 0.1289374226970332, 0.28152189935956684, 0.1751451553510768, 0.14383232487099512, 0.11616481521299907, 0.08673968951084784, 0.14951880116547855, 0.14646852841334684, 0.1545159944466182, 0.10167336996112551, 0.13169230201414653, 0.2393318404044424, 4.269056158406394, 22.086308343069895, 61.23658643450056, 74.97898374285016, 85.42792797088623, 83.99093627929688, 72.23475102015904, 64.83553791046143, 54.794762134552, 54.999518598829, 42.09338910239083, 43.31760263442993, 35.16281809125628, 31.70368868964059, 47.81857967376709, 54.99011421203613, 73.91174043927873, 55.93782070704869, 34.30410412379673, 21.207659993852886, 7.977413535118103, 2.6728438905307224, 0.8898079161133085, 0.25976893518652233, 0.25518749388200895, 0.5111779932464872, 0.4147089868783951, 0.5538232677749225, 2.242835513183049, 2.8134680475507463, 7.429979733058384, 7.579279150281634, 8.655755741255623, 11.472533736910139, 15.783248254231044, 12.334198951721191, 12.779265812465123, 14.722930567605154, 9.226651004382543, 17.10361443247114, 13.936881729534694, 7.8982535770961215, 3.804233397756304, 2.1714723025049483, 1.4840320817061832, 0.35764742163675173, 1.0158169716596603, 1.3741068031106676, 0.9718640787260873, 0.4030575363763741, 0.49052045600754873, 2.1752547281129018, 5.295979065554483, 7.3974074465887885, 12.875446251460485, 12.85860902922494, 11.604929055486407, 13.17615646975381, 15.31187551362174, 14.219545739037649, 21.257379565920147, 16.838144608906337, 17.529938527515956, 14.323297108922686, 15.923667873655047, 9.077578272138323, 7.36005653653826, 5.941546184676034, 9.308711835316249, 9.494609151567731, 10.383283751351492, 7.6134330204554965, 9.107348697526113, 8.23156213760376, 1.112255362527711, 1.6806302751813615, 0.43357983284762924, 0.5955202760440963, 0.12583579841469014, 0.3009093004677977, 0.25138530933431213, 0.501310194177287, 1.2728930456297738, 8.355975713048663, 23.014358384268625, 52.356847694941926, 49.66525452477591, 43.43985966273716, 37.75386387961251, 35.00735214778355, 29.023893560682023, 71.83953053610665, 61.93292794908796, 32.79736988885062, 38.523870195661274, 39.044349329812185, 63.564059257507324, 63.824172019958496, 72.52239254542759, 75.9675178527832, 75.06437015533447, 70.62948090689522, 52.31481456756592, 16.16018976484026, 2.4434171957629065, 0.20994121820798942, 0.16115524247288704, 0.1560291682503053, 0.1470066745366369, 0.21429342324180262, 0.14311047217675618, 0.07686364624117102, 0.16532693005033902, 0.1251522015248026, 0.17498198124979222, 0.10286354073988539, 0.17439468204975128, 0.18137226120701858, 0.15812955982983112, 0.12579617196960108, 0.15530211797782353, 0.16049912625125476, 0.1361649605844702, 0.13423558697104454, 0.13134524492280825, 0.12051893371556487, 0.19760915637016296, 0.1092746245807835, 0.07734366226941347, 0.1602667280073677, 0.19159162284008094, 0.13573874559785637, 0.1639922245272568, 0.11074812444193022, 0.14749292630170072, 0.1413720247468778, 0.16343151032924652, 0.12730603452239717, 0.12714138121477195, 0.18700916373303958, 0.1885338183492422], [0.02295497878055487, 0.027925634557115178, 0.05430990557319351, 0.04981539138991918, 0.0803782269358635, 0.053702046762087514, 0.02118861811634685, 0.03166608938149043, 0.02527799261068659, 0.018628016945772936, 0.01103149341153247, 0.04075193790985005, 0.05767430950488363, 0.0508951475577695, 0.03776990881721888, 0.026055140819932734, 0.09082762551094804, 0.016031911430348243, 0.0440880096118365, 0.011653631143937153, 0.04071776010096073, 0.03906389545383198, 0.02003874383600695, 0.026671011433271424, 0.01448713316183005, 0.03690211681116905, 0.05827040930411645, 0.012020005279087594, 0.03385469051344054, 0.037730577534862926, 0.007482082666163998, 0.034386353234627416, 0.08866729214787483, 0.060299968613045554, 1.8134294578007288, 11.189166222299848, 39.86279501233782, 63.01319217681885, 75.18404592786516, 65.5316709790911, 54.015486921582905, 54.57307638440813, 52.89697980880737, 29.124909945896693, 25.39503356388637, 28.790100574493408, 14.721183095659528, 24.937645809991018, 30.120899472917827, 31.779413631984166, 41.10225289208548, 35.18585136958531, 15.867967639650617, 8.06443885394505, 2.251275186027799, 0.961592469896589, 0.06185067218861409, 0.09121920128485986, 0.0717255212366581, 0.12480241672268935, 0.565262391098908, 0.3247770954455648, 0.9763445811612266, 2.7136851847171783, 4.401497943060739, 3.41482920731817, 2.4039968081883023, 4.702522133077894, 4.254335965429034, 5.998819751398904, 7.663860440254211, 2.291043200663158, 2.914088168314525, 5.042932186807905, 7.170563527515956, 5.646092278616769, 1.7193081825971603, 3.1569817747388567, 1.146729718361582, 1.0739752394812447, 0.1977652601365532, 0.31212955553616795, 0.15996244576360497, 0.6392357360039438, 0.08528239306594644, 0.13684701041451522, 0.7739326453634671, 2.102191597223282, 1.6598244373287474, 2.607310435601643, 4.1276147195271085, 3.319343153919492, 4.770242316382272, 4.7695666040693006, 8.287582857268196, 5.461697510310581, 4.681757875851222, 10.702879173415047, 5.403969270842416, 7.113229164055415, 2.5689007937908173, 2.7110387895788466, 2.5561054689543585, 4.148022881575993, 5.763177675860269, 3.654400272028787, 5.520269521645137, 4.6062683037349155, 2.280729251248496, 2.9529338095869337, 2.214363749538149, 1.0463333513055528, 0.5353237433092934, 0.17815540810780867, 0.07909226736852101, 0.0535690131863313, 0.08867131586053542, 0.17752997523971967, 0.6526751805629049, 3.919834920338222, 10.415512101990835, 24.518964733396256, 38.533472606113975, 27.252731731959752, 36.48666879108974, 40.232758794512065, 60.29277787889753, 59.1337627683367, 22.118666103907994, 21.554559230804443, 28.033625875200542, 28.60743417058672, 31.23015853336879, 42.243751593998496, 47.04973718098232, 51.81521477018084, 50.15194456917899, 52.93229750224522, 27.710406099046978, 4.73617399590356, 0.7420628326279777, 0.05794660560786724, 0.03752450305702431, 0.08017438144556113, 0.04094069956668785, 0.03505808933238898, 0.08845487676028695, 0.024949089723772237, 0.052533670528126616, 0.02834646706469357, 0.02020235050336591, 0.04711797720353518, 0.042817954905331135, 0.03337038614388023, 0.045261915906199386, 0.029320108837315013, 0.01607717989411737, 0.07360767559813601, 0.00827222566918603, 0.027589832665398717, 0.009810925112105906, 0.0222963265342904, 0.02955829837758626, 0.09106899398778166, 0.014081332749421043, 0.03949778467150671, 0.015033677852313434, 0.01096664836430656, 0.021700852683612278, 0.01813047775067389, 0.04970108877335276, 0.02805766899005643, 0.05685905646532774, 0.04765872550862176, 0.015309658400448305, 0.020296576965068067, 0.029411521075027328, 0.03154714219272137, 0.047955112997442484, 0.03805814031511545, 0.0737823440826365, 0.027670344238036444, 0.03765007274757538, 0.046813538896718195, 0.0495868540102882, 0.051889506700847826, 0.03115922032988497, 0.045302071608603, 0.05765499161290271, 0.05250180313097579, 0.011897506807664675, 0.024010602850466967, 0.04024278898058193, 0.009168038626999726, 0.0477790908355798, 0.034287239624453444, 0.04735173251745956, 0.06965642369219235, 0.034231732067252905, 0.02197279764472374, 0.027985608571075966, 0.028943623682217937, 0.015475224337673612, 0.028602208609559705, 0.05993615849209683, 0.06817888654768467, 0.05202875226469977, 0.058494671913129945, 0.08110294304788113, 0.06476464082619973, 2.24540547813688, 13.662046602794103, 44.131545884268625, 71.99917234693254, 85.08242879595075, 75.20399420601981, 62.52524103437151, 61.032663754054475, 58.73945944649832, 36.27235507965088, 33.513558932713096, 34.532804080418174, 21.498570646558488, 33.889341831207275, 27.569034576416016, 31.483673981257848, 39.87261281694685, 38.192027705056326, 18.493045704705374, 7.9906012160437445, 2.2747407725879123, 0.6470599504453796, 0.27023015384163174, 0.13133788960320608, 0.36212803263749394, 0.9938400366476604, 1.7051936771188463, 2.0884443691798618, 3.0883819929191043, 5.20602638380868, 6.815521001815796, 5.995356508663722, 6.411567934921809, 7.849296569824219, 6.868853637150355, 6.8213483691215515, 6.722315260342189, 6.328524802412305, 9.293373686926705, 8.358089702469961, 9.807824390275137, 8.58770682130541, 8.604594417980739, 5.824941515922546, 5.007353067398071, 1.4396583884954453, 0.24948888538139208, 0.3520431566451277, 0.9286175136055265, 0.6643457657524517, 0.07947223340826375, 0.11562726620052542, 0.7089395757232393, 2.489612511226109, 2.4164935776165555, 0.8589876613446644, 2.9983893590314046, 4.304888887064798, 5.443748576300485, 5.365564405918121, 9.438150695392064, 7.541530455861773, 8.311482054846627, 7.856657317706516, 8.184141550745283, 7.4520671878542215, 5.848526741777148, 4.423574975558689, 5.9952905007771085, 6.562507127012525, 7.926207917077201, 7.648521423339844, 6.652285235268729, 8.307579772812979, 5.797459653445652, 3.918262456144605, 4.161661761147635, 4.777980438300541, 2.7600055677550177, 1.775387744818415, 0.8961598724126816, 0.07287871864225183, 0.20778059986020836, 0.0895706122475011, 0.683605466570173, 3.3222828933170865, 12.883739795003619, 21.55678960255214, 38.14311238697597, 27.280468940734863, 30.23205327987671, 34.74844489778791, 56.15895754950387, 63.20563643319266, 32.3688188961574, 31.01511526107788, 40.536575726100374, 42.66359996795654, 37.61540712629046, 51.00700725827898, 54.547559125082834, 58.886260986328125, 59.35460431235177, 60.333529063633506, 33.3473128591265, 6.798464911324637, 0.8210213471736226, 0.03238630002098424, 0.03838419335495148, 0.05313637586576598, 0.05355967315179961, 0.007371762201988271, 0.02868087456694671, 0.014997793527852212, 0.0009180507768178359, 0.04965800179966858, 0.01583321432449988, 0.09048243439091103, 0.06261152707572494, 0.08181485520409686, 0.02338134983022298, 0.011749788885936141, 0.058237948188824315, 0.01867103097694261, 0.03867417547319617, 0.047109159640967846, 0.025010047613510063, 0.03872927251671042, 0.020059478169839298, 0.021875249754105295, 0.016170912721593465, 0.03754484214420829, 0.027877395806301917, 0.03656168561428785, 0.007501220746364976, 0.07469158779297556, 0.023489133421597735, 0.03372765179457409, 0.0684966037848166, 0.018884796649217606, 0.006091146097917641, 0.013256054354964622, 0.132059158757329, 0.07280445298446075, 0.11658709469650473, 0.14847001672855445, 0.18134499766996928, 0.12908680896673883, 0.11087768391839095, 0.13431877536433084, 0.12899137980171613, 0.0923555778073413, 0.07823571190237999, 0.10936340410262346, 0.11087520726557289, 0.18016016696180615, 0.0877228324700679, 0.10714363785726683, 0.17514147769127572, 0.09869606686489922, 0.136426820818867, 0.08140164094844035, 0.12854399452252047, 0.14915506568338188, 0.13726368519876683, 0.08467974540378366, 0.1304367408156395, 0.09115855382489306, 0.13116345182061195, 0.14837622961827687, 0.2232614713055747, 0.23687090245740755, 0.11028242550258126, 0.11520897650292941, 0.2276244650461844, 0.17471467916454586, 3.666215683732714, 19.972690650394984, 58.42783273969378, 80.89636148725236, 89.40208217075893, 82.9134999683925, 71.6110668182373, 69.56832422528947, 66.74898147583008, 41.474412305014475, 36.84216642379761, 42.80710458755493, 22.515389135905675, 33.68161848613194, 42.48466648374285, 42.34762716293335, 52.53692763192313, 44.73648732049124, 20.60974144935608, 9.801874126706805, 3.0425788164138794, 1.252837938921792, 0.32900773414543694, 0.3943070944930826, 0.41658101071204456, 0.782540540610041, 0.9649070863212857, 2.1142302198069434, 4.552513999598367, 7.199202265058245, 12.005201748439244, 10.451401284762792, 10.79166064943586, 14.06717608656202, 14.002743703978402, 15.80813843863351, 19.439463308879308, 11.231214983122689, 12.876287852014814, 15.85394617489406, 18.416693687438965, 16.56307932308742, 11.357008644512721, 10.233281697545733, 5.525592710290637, 3.0788306082998003, 0.44039205302085194, 0.6590780541300774, 1.9095545283385684, 1.5286975992577416, 0.49227444188935415, 0.4892148460660662, 0.3481858479125159, 2.605468511581421, 4.221714607306889, 8.988806349890572, 10.982474684715271, 12.525258779525757, 12.422747663089208, 15.6086973462786, 19.20368834904262, 12.09429589339665, 12.413833992821829, 23.33603392328535, 14.802746261869158, 16.09663806642805, 10.982404334204537, 11.223377415112086, 9.761715275900704, 13.315938591957092, 16.97086215019226, 15.78440339224679, 15.09738462311881, 13.91203670842307, 7.827248198645456, 9.213784677641732, 6.056638751711164, 5.696035061563764, 2.389282477753503, 0.7804505441870008, 0.6264300431524004, 0.1671471002378634, 0.24940385137285503, 0.2726901146982397, 1.2802672556468417, 5.290234642369406, 15.592653955732073, 32.80882746832711, 52.56759350640433, 40.46626343045916, 52.156607559749055, 53.5248190334865, 66.69220079694475, 67.971100125994, 33.51721021107265, 31.379506587982178, 42.00165203639439, 42.23997177396502, 43.65974235534668, 57.34958348955427, 63.48049327305385, 68.57088947296143, 69.83865083966936, 72.25421292441231, 41.85136944907052, 10.304113371031624, 1.2233490241425378, 0.1768959928303957, 0.07625792481537376, 0.2553243951073715, 0.20604437802519115, 0.1814037180904831, 0.11851220711001328, 0.11160828971437045, 0.10745794206325497, 0.09911333197461707, 0.06080781814775296, 0.31105158052274157, 0.12140860169061593, 0.14552064213369573, 0.20286925482962812, 0.08805530105850526, 0.2612055838108063, 0.17137613759509154, 0.10665712824889592, 0.19362669863871165, 0.13587967732122966, 0.10945033122386251, 0.11838431682969842, 0.15424536753978046, 0.14726545422204904, 0.16576773353985377, 0.06635933382702724, 0.13004969087030205, 0.08036903957171099, 0.18929290904530457, 0.14750311789768084, 0.14337320093597683, 0.13732060071613106, 0.12985892753515924, 0.11950316679264818, 0.07529397082648107], [0.006088663083833775, 0.1565917009221656, 0.12638678242053303, 0.009054702922834881, 0.0295749462342688, 0.05557955315868769, 0.06446878598736865, 0.05458925844037107, 0.033822833294315, 0.05488847881289465, 0.014389061102909701, 0.09287750015833549, 0.04402411875448056, 0.043754285733614645, 0.03770605527928897, 0.07155690528452396, 0.05181358541761126, 0.029913443606346846, 0.018732255191675255, 0.04948577943391033, 0.025903768138960004, 0.021049689767616134, 0.049314052398715696, 0.10294434747525624, 0.028314916882663965, 0.027263090912518755, 0.04729843698441982, 0.04431694393445339, 0.007748438195059342, 0.005069651491274791, 0.047463012260517905, 0.04293582322342055, 0.09267495066991874, 0.712803316967828, 12.896233524594988, 34.69563511439732, 65.52142238616943, 66.70745209285191, 62.22088214329311, 58.59709085736956, 46.355167457035606, 36.89641795839582, 36.87258563722883, 41.024752685001914, 17.49901556968689, 22.150289092745098, 40.83660241535732, 29.29931320462908, 45.842122895377024, 51.03080483845302, 32.15675640106201, 12.732598236628942, 5.858906047684806, 2.624890680824007, 0.3847432519708361, 0.09518481099179812, 0.016542658309585283, 0.037485226057469845, 0.2103658997054611, 0.8608196516122136, 4.039133318832942, 1.3289601228066852, 1.213534367935998, 3.5166852389063155, 3.411992822374616, 3.285184072596686, 4.8265579002244134, 3.658666900226048, 4.070224770477839, 3.90540394612721, 3.9309754882540022, 6.744670220783778, 7.192839886460986, 9.356481569153921, 7.792111158370972, 5.292953125068119, 6.678401342460087, 3.089684997286115, 4.7009283900260925, 0.9627935311623982, 0.5675526910594532, 0.7659096473029682, 0.6006997781140464, 0.1582985557615757, 0.14490941778889724, 2.9499213312353407, 14.78512910434178, 18.44911571911403, 19.39355829783848, 11.185132793017797, 1.4271231868437357, 2.6166255814688544, 3.3853104369980946, 4.240615878786359, 7.750788484300886, 9.371832745415823, 6.2259277020181925, 5.083944797515869, 6.226171323231288, 3.2191240744931355, 1.711740942937987, 1.56727834045887, 4.663568360464914, 1.9067897966929843, 3.9275122455188205, 5.741439802306039, 7.822364483560834, 5.627683460712433, 1.904460413115365, 2.5115677331175124, 3.525765665939876, 3.177642894642694, 1.3141783731324332, 3.641673343522208, 0.9422828831842968, 0.15888035882796558, 0.095841130773936, 0.08391537570527621, 0.07104554093841996, 0.11359425993370158, 2.819133217845644, 8.742768900735037, 14.26514937196459, 25.16965310914176, 32.98174033846174, 48.00054257256644, 43.922617026737754, 21.51135012081691, 19.783699648720876, 16.428947823388235, 10.08097197328295, 19.51359016554696, 31.488103457859584, 28.31063665662493, 40.47802325657436, 42.81001935686384, 51.81300176892962, 51.47778592790876, 39.00985847200666, 16.079885959625244, 1.7475939733641488, 0.14285490874733242, 0.09493044178400721, 0.04239738193739738, 0.0814896197989583, 0.03358241815918258, 0.10435484535992146, 0.15152297647936003, 0.10865788374628339, 0.061519648879766464, 0.03252483990841678, 0.022908332890697887, 0.033343604366694174, 0.03726626619962709, 0.04345729774130242, 0.0330751589499414, 0.05788591065044914, 0.028776609072727815, 0.07942979782819748, 0.12397961158837591, 0.09160093151565109, 0.024574395901124393, 0.08286811797214405, 0.04656703390979341, 0.034495956996189694, 0.040824907565755506, 0.011925778817385435, 0.027576026174106767, 0.031031482719949315, 0.05727729866547244, 0.08110759779810905, 0.05919164272823504, 0.0599980748125485, 0.058675684700054784, 0.12504047394863196, 0.12078458017536572, 0.061174159204321246, 0.0892714529431292, 0.06300551843430315, 0.03797906045136707, 0.06638272971447025, 0.013984476964521621, 0.055750357386256964, 0.042444940456854444, 0.0010208192522571022, 0.011198899874995862, 0.04031197241108332, 0.02789724974094757, 0.019768110143819025, 0.051481116829173904, 0.07400451680379254, 0.04899163630657962, 0.09078751052064554, 0.0373606436353709, 0.02106248015271766, 0.02678131578224046, 0.025229925189965537, 0.006469411983354283, 0.06922733850244965, 0.09546581269907099, 0.011169018040943359, 0.013169962679967284, 0.044686504639685154, 0.011699333021949445, 0.014258538106722491, 0.017258641675912907, 0.02016110744859491, 0.03068621696106025, 0.09803238497780901, 1.0584532895258494, 15.827282462801252, 40.757729939052034, 76.84271989549909, 75.72316360473633, 70.99204485757011, 64.77865300859723, 54.98126915522984, 43.972835132053916, 49.2074099268232, 42.53525979178292, 24.458949668066843, 29.487439155578613, 31.66490731920515, 23.75688978603908, 44.62828649793352, 42.37406505857195, 31.869538715907506, 13.321325182914734, 5.1526364258357455, 1.8878238201141357, 0.335343242755958, 0.04710145826850619, 0.3170213316168104, 0.6096753850579262, 0.7762611604162625, 3.1479777778897966, 6.288649959223611, 4.019381761550903, 5.1490055578095575, 6.977045774459839, 5.9462896330016, 6.184887298515864, 5.786213559763772, 9.329185570989337, 6.882500767707825, 5.791767341750009, 7.03353636605399, 6.6551127178328375, 9.04946151801518, 10.867099847112383, 7.662992783955165, 7.3210936444146295, 10.536783354622976, 6.947155926908765, 7.755886725017002, 3.4495311166558946, 1.5029608202832085, 0.7252659425139427, 1.074301696249417, 0.4338274709880352, 0.14264016598463058, 3.391715156180518, 14.767513683864049, 20.576155594417028, 18.54281391416277, 10.213091969490051, 2.320768245628902, 3.231980630329677, 4.980359315872192, 6.582460182053702, 8.468992505754743, 6.26529141834804, 5.56862507547651, 8.240580899374825, 7.194149187632969, 5.754235344273703, 4.884698688983917, 5.506568976811, 6.283905208110809, 6.485124605042594, 8.039986406053815, 7.816539287567139, 10.253331593104772, 9.238728710583278, 6.440854157720294, 7.577296308108738, 5.367266280310495, 7.391394649233137, 5.264437283788409, 3.174693601472037, 2.71721573812621, 0.9613821783236095, 0.7361660376191139, 0.05867184419184923, 0.04722105685089316, 0.1880429254046508, 2.0632975356919423, 8.484823107719421, 14.809060437338692, 25.867387737546647, 34.91862712587629, 43.00868919917515, 43.359667028699604, 31.67277615410941, 24.963180439812795, 24.93833715575082, 17.641875743865967, 26.14409974643162, 42.15257385798863, 38.589683532714844, 47.8783723967416, 50.04143694468907, 58.925671168736045, 61.19532803126744, 49.001652921949116, 20.2510233266013, 2.4394443460873196, 0.15144745553178446, 0.06364182821874108, 0.03383714359785829, 0.04298657764281545, 0.04549870087898203, 0.1278160350131137, 0.035119143913366964, 0.14507578100476945, 0.0038727225037291646, 0.028165934341294423, 0.005696507162481014, 0.003983367816545069, 0.04085576733840363, 0.02473096107132733, 0.07864891258733613, 0.029784226790070534, 0.036855040051575215, 0.012617034671295966, 0.09296494296618871, 0.049353112267064195, 0.026749431421714168, 0.031193706872207776, 0.06795221513935498, 0.03427912434563041, 0.02919539749356253, 0.06797230656125716, 0.03503006922879389, 0.0136473358143121, 0.06170776592833655, 0.04692861843588097, 0.05440604719998581, 0.016964841101850783, 0.02440933377615043, 0.04101846307250006, 0.056007342346544774, 0.10591245642197983, 0.17088063061237335, 0.16507678133036408, 0.07311897432165486, 0.08783992047288589, 0.2213663501398904, 0.1272941194474697, 0.14552180921392782, 0.10450580583087035, 0.18396387142794474, 0.1228811719587871, 0.14421230448143824, 0.11805320531129837, 0.10238838980772666, 0.10052425733634404, 0.15445264641727718, 0.20700701565614768, 0.0735042125784925, 0.06378862248467547, 0.15450403865958962, 0.1442067947770868, 0.10519569952573095, 0.20321407275540487, 0.1555618340415614, 0.15304575833891118, 0.13179466580705984, 0.1245260765509946, 0.17412481510213443, 0.14942025073937007, 0.08523292786308698, 0.09238290241254227, 0.10772687941789627, 0.20061627429510864, 1.8821341139929635, 20.36590310505458, 51.09886244365147, 85.57715443202427, 84.34441893441337, 81.14904662540981, 74.84582846505302, 61.49376705714634, 51.453932762145996, 50.64625678743635, 54.68756880078997, 28.085574081965856, 30.779581751142228, 52.40523147583008, 39.61848592758179, 58.3265905380249, 64.2003961290632, 41.43260151999337, 16.37813217299325, 7.258980657373156, 3.2672123398099626, 0.7535033130220005, 0.20943558748279298, 0.22835634648799896, 0.4317784309387207, 0.6098809540271759, 2.7800997580800737, 9.18685780252729, 6.819205718381064, 6.761153519153595, 10.673067058835711, 11.66301599570683, 13.919300181525093, 12.996876444135394, 14.753233398709979, 13.41748651436397, 14.359266195978437, 15.55987582887922, 14.089955755642482, 16.97707383973258, 18.209873608180455, 17.9649270262037, 15.289137533732823, 16.143199682235718, 13.280410715511866, 15.115680967058454, 4.058983887944903, 1.6653088458946772, 1.6131263545581271, 1.6269799768924713, 0.501984060875007, 0.7045850636703628, 2.7147871255874634, 11.811862911496844, 12.71273159980774, 12.060952356883458, 9.053699919155665, 7.698076844215393, 11.460601074354988, 12.023623159953527, 14.546935302870613, 17.59547393662589, 19.219281843730382, 16.537278924669536, 18.290189572743007, 14.380532026290894, 12.023852450507027, 7.835981215749468, 7.751437272344317, 13.423013806343079, 10.751639025551931, 17.23355790546962, 14.616473742893763, 17.130130495343888, 13.977216022355215, 10.313612427030291, 11.980181285313197, 8.418860384396144, 7.241470328399113, 5.018797619002206, 7.8173461471285135, 2.6989482726369585, 0.7835687654359, 0.5757509682859693, 0.19178505960319722, 0.18394692162317888, 0.41499554578747067, 3.8309283767427718, 11.251023428780691, 18.99145041193281, 35.458627223968506, 46.27256727218628, 64.67056683131626, 57.85842439106533, 33.51166902269636, 28.176562479564122, 26.181515795843943, 18.646592208317347, 30.436271258762904, 46.49448926108224, 41.70135089329311, 57.565561294555664, 58.57034029279436, 68.92375373840332, 69.2524938583374, 62.467070715767996, 27.1286438533238, 3.793311263833727, 0.24803502910903522, 0.15967459763799394, 0.10601541732570954, 0.278643255255052, 0.12730744587523596, 0.18627049694103853, 0.2454250305891037, 0.2462557474417346, 0.12117950112691947, 0.08683051820844412, 0.21445030053811415, 0.19161815355931008, 0.13253278977104596, 0.08648517102535282, 0.12207668726997715, 0.13936125407261507, 0.10608840055231537, 0.1545038622404848, 0.18114268566880906, 0.23382362883005822, 0.14550293236970901, 0.25881301505225046, 0.13313717448285647, 0.10606560856103897, 0.16437265197081224, 0.10854741145989724, 0.15398753780339444, 0.07962649834475347, 0.11135223773973328, 0.13419847110552446, 0.1942578719130584, 0.14668365115565912, 0.09394194518349, 0.18656929662185057, 0.1735286678054503], [0.081939990632236, 0.16434010943131788, 0.20242921129933425, 0.043176594589437754, 0.06598129482673747, 0.016386303485238125, 0.04695113901314991, 0.06698205934039184, 0.02362681835490678, 0.1239435678081853, 0.030566930504781858, 0.02832352409937552, 0.07781142395521913, 0.05294243698673589, 0.03831429407000542, 0.05920486059039831, 0.04894978426662939, 0.07302139420062304, 0.04405253580106156, 0.060132892935403755, 0.02157898779426302, 0.11722103639372758, 0.09763304676328387, 0.2514643450932843, 0.11066427108432565, 0.05856958217918873, 0.09846582636237144, 0.014713690915544118, 0.10471678950956889, 0.017931531283206174, 0.0524352795577475, 0.08729804240699325, 0.1774835634444441, 5.20371914761407, 30.101395879473003, 56.50873681477138, 72.18771866389683, 63.54413877214704, 57.10546548025948, 51.76131411961147, 39.08716065543038, 34.47316769191197, 27.79050145830427, 24.711369037628174, 26.729587963649205, 21.994823149272374, 33.9104574067252, 47.64708423614502, 39.61486939021519, 28.9764529977526, 12.57544822352273, 4.439379956041064, 0.5463126993605069, 0.07755521591752768, 0.2135194590581315, 0.1569411600274699, 0.30512636846729685, 0.5784400839890752, 0.8287640288472176, 3.72694901909147, 4.23467994587762, 4.118405750819615, 4.658705055713654, 7.66541770526341, 5.833875596523285, 4.74384480714798, 4.6372959188052585, 6.100067598479135, 2.9169252046516965, 5.5447962284088135, 4.592861754553659, 4.694768377712794, 7.663328034537179, 9.56359781537737, 7.039300765310015, 6.950183604444776, 10.034647464752197, 5.2880112188203, 6.219259602682931, 1.3457241718258177, 0.867139743907111, 1.1061464846134186, 0.2955017020659787, 0.1281358828502042, 1.2684313250439507, 18.249127456120082, 49.48966312408447, 56.28377846309117, 58.11256865092686, 45.760735171181814, 17.748243979045323, 3.9627218076160977, 4.507470565182822, 4.681702724524906, 7.78650917325701, 3.575616819517953, 5.525717777865274, 4.552756318024226, 7.932081750461033, 3.705873395715441, 4.067628749779292, 2.55593849505697, 4.542380486215864, 4.795813858509064, 6.235352064882006, 5.021970774446215, 4.827657886913844, 9.246941481317792, 6.688210027558463, 5.140039776052747, 3.534635475703648, 7.704921688352313, 7.156918568270547, 6.264404220240457, 3.2025237424033026, 0.7259724331753594, 0.682076211486544, 0.3664835760635989, 0.08198568996574197, 0.18250370477991446, 0.020695016120693514, 0.7279854023030826, 5.070522614887782, 14.428166270256042, 22.03513833454677, 30.466106823512487, 36.006204332624165, 27.308492762701853, 34.712421962193076, 39.69029903411865, 41.1128488949367, 25.73065413747515, 18.090939555849346, 21.464694704328263, 28.390619107655116, 35.15405641283308, 40.93433230263846, 49.990395477839876, 49.18668692452567, 32.17053815296718, 6.020007848739624, 0.31718770840338295, 0.11455547942646913, 0.013857806350902786, 0.036336130396063836, 0.0449721848459116, 0.1625947816563504, 0.10828223318925925, 0.09790647601974861, 0.03338769557220595, 0.1495884188583919, 0.026458109196807657, 0.0272528026252985, 0.055763663457972665, 0.06367802806198597, 0.06098739244043827, 0.05076206987723708, 0.13555658608675003, 0.1036787327112896, 0.1551781767713172, 0.12601126757051262, 0.129595778084227, 0.06904589823846306, 0.014335646826241697, 0.05805127641984394, 0.047425865860922, 0.06859478101666484, 0.02649809017644397, 0.05680697550997138, 0.09095050820282527, 0.13882559138749326, 0.021452003358198062, 0.041941331766013584, 0.07091735888804708, 0.16523676631706102, 0.1340284709419523, 0.08600288190479789, 0.06912910698779992, 0.14308110518114908, 0.003636578322454755, 0.06039117729025228, 0.01947678961525006, 0.012075494176575115, 0.04787111036213381, 0.046191064441310506, 0.043477772535490136, 0.009759793257606881, 0.09832670632749796, 0.05759211177272456, 0.03229417532150235, 0.0442217997541385, 0.08159317781350442, 0.0340574299916625, 0.028869656579835073, 0.02695414374050285, 0.02952691613297377, 0.11297985325966563, 0.030141139602554694, 0.08380997207547937, 0.10159318069262163, 0.010978161407235478, 0.00579767843009904, 0.03785347719011562, 0.08675062749534845, 0.05199189763516188, 0.04437616986355611, 0.04042797815054655, 0.06918818024652344, 0.3355647980102471, 7.262590246541159, 35.385462692805696, 66.44255202157157, 79.33599758148193, 73.54793970925468, 66.00264767238072, 58.45572280883789, 45.17771182741438, 40.40293754850115, 34.070714133126394, 35.1923131942749, 25.70783625330244, 27.992612395967754, 46.62663010188511, 54.87899167197091, 38.59164292471749, 31.61722878047398, 12.07609248161316, 4.66233331816537, 0.5589384990079063, 0.13233338189976557, 0.14631619730166026, 0.3802411992635046, 1.032158266220774, 2.976710328033992, 3.5829934179782867, 5.784041813441685, 5.223970540932246, 6.68610863174711, 6.453362217971256, 9.624865293502808, 7.49541699886322, 8.710892302649361, 7.774989928518023, 9.146273374557495, 6.197356275149754, 7.627550022942679, 5.467028949941907, 5.204960269587381, 8.047771862574987, 8.694846306528364, 5.779916320528303, 3.379504348550524, 6.823393310819354, 4.158254104001181, 4.73522686958313, 2.85191981281553, 1.5154584582362856, 0.9817406173263277, 0.4374554620257446, 0.10958289661045585, 2.062236849750791, 20.912332023893082, 49.13135494504656, 58.44399424961635, 60.370701926095144, 45.49592890058245, 16.849028961999075, 3.3076182859284535, 2.404626488685608, 4.597161386694227, 6.849637959684644, 6.121593117713928, 3.956203963075365, 4.229452294962747, 4.57350537606648, 4.854814486844199, 4.295486237321581, 4.657811343669891, 4.827877623694284, 5.580829152039119, 7.451652901513236, 10.755319833755493, 10.158056156975881, 11.85963785648346, 8.423532179423741, 5.2708704471588135, 6.184942884104593, 8.299436484064374, 5.483709837709155, 9.051965475082397, 6.0781117251941135, 2.458891268287386, 1.4850514041525977, 1.3189734986850192, 0.51126614851611, 0.08713319232421261, 0.17652108866189206, 0.6094062509281295, 3.587920342172895, 15.499561991010394, 28.609152112688335, 36.30194745744978, 41.03153760092599, 28.451907430376323, 24.687173673084803, 28.972909416471207, 29.356625420706614, 26.415126391819545, 26.26813898767744, 30.1150803565979, 36.42037602833339, 42.116109711783274, 49.597103118896484, 56.56791809626988, 58.93718433380127, 37.93975598471505, 8.822025265012469, 0.28720715429101673, 0.01961092241773648, 0.06382180284708738, 0.11131417192518711, 0.05283035996503063, 0.11442243228001253, 0.06297433975019626, 0.03344179516924279, 0.022683289966412952, 0.02329593075306288, 0.07755307853221893, 0.029376691872520105, 0.1178440401064498, 0.027367410582623312, 0.02132314277280654, 0.1315558621925967, 0.03010625611724598, 0.02890584963772978, 0.08296347249831472, 0.07070793583989143, 0.10476014111191034, 0.0823989992163011, 0.04918787881199803, 0.0349595287282552, 0.04624991378347788, 0.06832025931882006, 0.03346809179389051, 0.04427663556167057, 0.12142484581896237, 0.1051913094041603, 0.022961725114977787, 0.04735753059919391, 0.025123183149844408, 0.08808727362858397, 0.04746518696525267, 0.23451245043958935, 0.37458832402314457, 0.2573965867715222, 0.11051953956484795, 0.1637657702501331, 0.10199197607913188, 0.14099336149437086, 0.05924264142023666, 0.15343567170202732, 0.1895634816693408, 0.11322071962058544, 0.1568488385528326, 0.18827328804348195, 0.15441987317587647, 0.16322428573455128, 0.12911903938012464, 0.10567051119038037, 0.09716871846467257, 0.13684226066938468, 0.13970155295516762, 0.17608769477478095, 0.2333458587527275, 0.2228506047810827, 0.24106175186378614, 0.27247865604502813, 0.1994071520332779, 0.23389077665550367, 0.205900175763028, 0.2593967451580933, 0.11414336439754282, 0.15222528736506188, 0.11961169168353081, 0.7041827738285065, 11.257755364690508, 45.903544970921104, 77.11301176888603, 88.53483581542969, 81.69848932538713, 72.38082299913678, 67.66547666277204, 52.88518871579851, 47.80214371000017, 40.732306480407715, 35.049993242536274, 38.59319584710257, 32.19546134131295, 46.42851958956037, 61.37081173488072, 52.592304774693076, 37.283839089529856, 16.038505962916783, 5.290785721370152, 0.8750134642635072, 0.1478130862648998, 0.33648874557444025, 0.39727131543414934, 1.0480140554053443, 1.9559174690927779, 2.868425041437149, 8.917782732418605, 10.793349930218287, 12.645577260426112, 12.911415338516235, 17.70588081223624, 15.764616659709386, 13.124723298209053, 12.80080088547298, 18.308772529874528, 14.433726566178457, 15.016561440059117, 12.874903423445565, 11.776082294327871, 18.625818831580027, 18.42271603856768, 19.560096195765905, 15.147590569087438, 18.97870394161769, 13.159363542284284, 14.687906435557775, 7.068133618150439, 5.168860903808048, 2.4656416603497098, 0.5776206851005554, 0.22695727513304778, 2.8632119383130754, 20.13796397617885, 42.695714541843955, 48.81919322695051, 50.571897166115896, 37.10223402295794, 19.239469834736415, 12.450825333595276, 10.77276154926845, 11.4452212367739, 16.403230803353445, 10.970800842557635, 13.00873007093157, 12.824477740696498, 17.68568239893232, 10.726318052836827, 11.569184916360037, 8.551141926220485, 12.219738670757838, 13.79340056010655, 12.960762313434056, 16.886266095297678, 12.37179912839617, 20.04181480407715, 15.98342411858695, 10.056173852511815, 12.089168122836522, 17.50658563205174, 12.898932899747576, 15.41250627381461, 8.424616966928754, 2.770738580397197, 1.5964092058794839, 1.1231410184076853, 0.5006503324423517, 0.5526694325464112, 0.2104669471404382, 1.20872534598623, 7.5463707447052, 18.593294313975743, 28.59984847477504, 40.064754826681956, 47.77924592154366, 41.596033573150635, 50.28127486365182, 53.06388248716082, 53.730558667864116, 37.381329263959614, 27.805424451828003, 34.25763804571969, 40.66796268735613, 50.82586424691336, 57.34403187888009, 67.71855395180839, 66.80152375357491, 49.88821874346052, 12.02782334600176, 0.7166009417601994, 0.18350006560129778, 0.1090467996629221, 0.21079258966658795, 0.06732799006359917, 0.19198862010879175, 0.15584816224873066, 0.19377901617969784, 0.09648143034428358, 0.17175674145775183, 0.1936153263917991, 0.13826974907091685, 0.2248555129127843, 0.18792548456362315, 0.13941698893904686, 0.1532890945672989, 0.22157774093960012, 0.2318155722958701, 0.2711579283433301, 0.19198400607066496, 0.32616133402500835, 0.13357381176735672, 0.1864769615765129, 0.19883832255644457, 0.15485404059290886, 0.17267397152526037, 0.1072964710848672, 0.1790418191147702, 0.21504789989973816, 0.24051800104124205, 0.12464552585567747, 0.1546299611883504, 0.19850559612470015, 0.25010564657194273, 0.17820442547755583], [0.0676273393577763, 0.10422588977962732, 0.18753905887050287, 0.04010492084281785, 0.017229634303865687, 0.09520492276975087, 0.09331935537712914, 0.021793708504576768, 0.09055861351745469, 0.05508741849501218, 0.03935881391433733, 0.031140743821327175, 0.12153014088315622, 0.04674171257231917, 0.0389696028349655, 0.06891562630023275, 0.0716373116842338, 0.09195744738514934, 0.03166328024651323, 0.01772443561016449, 0.022215294186025858, 0.0345629250098552, 0.08560525359851973, 0.22813595831394196, 0.15280544837670668, 0.04652223702786224, 0.008476949862337537, 0.03745527212907161, 0.053130455647728274, 0.0519104055794222, 0.029333638825586865, 0.07434428642903056, 3.378923522574561, 31.69125141416277, 59.18476949419294, 71.48458181108747, 66.07031617845807, 57.200311865125386, 53.93886913572039, 39.22916793823242, 31.714170047215053, 27.697004761014664, 29.205620220729283, 22.728617191314697, 29.083451781954082, 34.40068408421108, 29.615744590759277, 26.743828296661377, 24.836610317230225, 9.939977390425545, 2.5322640282767157, 0.45819689333438873, 0.16179146404777253, 0.13675086200237274, 0.0694820401923997, 0.3862065263092518, 0.5443014672824315, 2.650176478283746, 3.8446562801088606, 4.692585774830409, 3.9852205089160373, 3.1144060364791324, 4.852358732904706, 5.622168328080859, 3.822208821773529, 2.9712840020656586, 3.009527321372713, 8.349902987480164, 4.482739320823124, 4.221966913768223, 3.0513674191066196, 3.410657899720328, 5.069871655532292, 6.045542478561401, 2.6546285365309035, 3.990432526384081, 8.862554107393537, 6.2779110840388705, 8.474320037024361, 9.477600829941885, 6.5055171336446485, 5.137140640190669, 1.9491529635020663, 0.5240544165883745, 9.648474403790065, 32.62460987908499, 70.68780408586774, 69.96929086957658, 67.94507912227085, 73.55035768236432, 43.48081929343087, 11.155320678438459, 3.546932267291205, 6.608405189854758, 5.99859002658299, 5.068967521190643, 5.302444364343371, 8.565863421985082, 4.734574173177991, 4.1222693834986, 1.7957186081579752, 4.212991143975939, 3.9113303252628873, 5.405884802341461, 7.76315975189209, 11.279651744025093, 13.65413521017347, 9.67349660396576, 5.646734552724021, 7.876635125705174, 4.8559392264911105, 8.445883665766035, 7.674314005034311, 3.016421671424593, 4.910904688494546, 1.8120406866073608, 1.2565414373363768, 0.2884921096265316, 0.41406318438904627, 0.16645864503724234, 0.04628631718722837, 0.06978765236479895, 0.13675960153341293, 1.0512639667306627, 7.18240977185113, 21.36392150606428, 39.81671803338187, 45.70045607430594, 68.63568837302071, 100.46931879861015, 80.39504201071603, 43.66278566632952, 33.541014739445274, 16.217533247811453, 26.73995988709586, 35.938594886234824, 41.695934772491455, 45.85756179264614, 49.803697381700786, 52.76712492534092, 13.940596410206386, 1.5062487295695712, 0.01663465578375118, 0.06925760794963155, 0.02144405771312969, 0.1317232432109969, 0.08104989518012319, 0.10120220881487642, 0.0724993497133255, 0.04538846268717732, 0.09157831594347954, 0.2141804335904973, 0.025527184596285224, 0.07965422328561544, 0.03897394545908485, 0.030007899073617797, 0.026740456099755, 0.08448588794895581, 0.10278219796184983, 0.13093888387084007, 0.15363355965486594, 0.06966455254171576, 0.034949187854571004, 0.031714604635323794, 0.04224622469129307, 0.01210690101808203, 0.012671572771588606, 0.14530410803854465, 0.026785498950630426, 0.04460308215181742, 0.09491625361676727, 0.02425053622573614, 0.021737944800406694, 0.09568766650876828, 0.17514246835240296, 0.08046391233801842, 0.05057807153623019, 0.04155137769079634, 0.050957362433629375, 0.03753676757748638, 0.018013888471094624, 0.052428935255323134, 0.07788319938949176, 0.04386638989672065, 0.05608523477401052, 0.05435854635600533, 0.05344579801229494, 0.0323428432457149, 0.09036624883966786, 0.05747799575328827, 0.025374600730304207, 0.09787923283874989, 0.049444107205740044, 0.020600290935752646, 0.029819955051477467, 0.030330766391541277, 0.028999948874115944, 0.04262630947466407, 0.025701245791944008, 0.21464243451399462, 0.07620126714131661, 0.009304485233899738, 0.025736093654164245, 0.03709445774023022, 0.019454496347212365, 0.009260909715002137, 0.02716900355049542, 0.09000211302191019, 4.87377438374928, 38.2971956389291, 67.35160568782261, 81.4597978591919, 76.02207510811942, 66.40560150146484, 58.69091933114188, 48.84464795248849, 37.482189314705984, 38.407161303928916, 37.319278376443044, 27.247119324547903, 30.033445971352712, 33.83237355095999, 29.509155750274658, 28.147230659212383, 24.403485672814504, 10.15046785558973, 2.635999981846128, 0.42947499454021454, 0.18087329369570526, 0.303525622934103, 0.6312044869576181, 1.0855512640305927, 2.9620077226843153, 4.971069574356079, 5.932244283812387, 7.404972297804696, 8.757985455649239, 7.460382444517953, 9.1351249899183, 9.73821038859231, 6.969696317400251, 6.922828112329755, 6.655696366514478, 6.732489160129002, 8.86287111895425, 7.536771808351789, 5.002134535993848, 4.3725287318229675, 5.079289070197514, 5.5199668407440186, 2.7798218301364352, 4.835918860776084, 5.554718255996704, 5.695042337690081, 7.762950437409537, 7.015232639653342, 6.559528521129063, 5.23395379952022, 1.974272872720446, 1.3171468824148178, 9.564761638641357, 36.25657572065081, 74.18967533111572, 73.99842616489956, 74.1245151247297, 77.25681168692452, 46.912965365818565, 11.68788012436458, 3.4545357738222395, 4.240968934127262, 4.7004333308764865, 3.753057743821825, 3.059475532599858, 3.065184997660773, 3.3083697770323073, 2.6553776391914914, 3.3182079919746945, 5.197247769151415, 6.088938321386065, 9.149965473583766, 8.240318604878016, 8.838437778609139, 9.516538534845624, 11.021371568952288, 9.53408099923815, 14.230856537818909, 10.981322152273995, 8.609533718654088, 9.678362080029078, 6.971201470920017, 7.608727352959769, 4.7110501783234735, 3.714275504861559, 1.8910827423845018, 1.6281001567840576, 0.33419573147382053, 0.08812303242406674, 0.06105449276843241, 0.20696707708495005, 1.8182801689420427, 9.000357730048043, 26.43647473199027, 43.38592079707554, 45.57228265489851, 56.10385833467756, 79.23605469294957, 75.38543946402413, 48.28274713243757, 40.45912068230765, 22.3443192754473, 34.96201515197754, 47.08989429473877, 47.29156575884138, 55.94764198575701, 57.93573004858834, 61.59443255833217, 19.190665687833512, 1.894948112113135, 0.03981784285445299, 0.035113776701369455, 0.029553402747426714, 0.06541768328419753, 0.05127663690862911, 0.08857720305344888, 0.03879602000649486, 0.052521487431866784, 0.037763126859707494, 0.0405014024249145, 0.04459039693964379, 0.02894144897748317, 0.016892778986532773, 0.02211469967317368, 0.1216812642025096, 0.07039868671979223, 0.07614656364811317, 0.029713465765650784, 0.012837254059767085, 0.05946249355162893, 0.028861341133181537, 0.00664789044198447, 0.042410484448607476, 0.02445358443739159, 0.0248732753098011, 0.0453030249503042, 0.027086497084902864, 0.04606542011190738, 0.01413439164337303, 0.015375720569863915, 0.07384654028075081, 0.010038754270811166, 0.037990554834582975, 0.08456301702452557, 0.2216625442462308, 0.2706684060394764, 0.29786892075623783, 0.24225081663046563, 0.15590851115328924, 0.18880532735160419, 0.2739851666348321, 0.12231197607304369, 0.16021551218416008, 0.14514277955251081, 0.14792180114558764, 0.08635906529213701, 0.2425666611109461, 0.1283343814845596, 0.2119578378541129, 0.18148795142769814, 0.33258877055985586, 0.1757117456623486, 0.1403416014675583, 0.11598119006625243, 0.08468462407056775, 0.14253725936370237, 0.17298422487718718, 0.44733403623104095, 0.20939939442489827, 0.14339845600937093, 0.0861240682591285, 0.14895092163767132, 0.13028002636773245, 0.1649995504745415, 0.16485920229128428, 0.22733658977917262, 7.296833140509469, 49.730866364070344, 81.34314455304826, 91.98421342032296, 84.62847518920898, 74.10549790518624, 70.74321596963065, 57.72901766640799, 44.93750217982701, 40.74434770856585, 40.72545903069632, 33.567994594573975, 39.95466409410749, 46.95675638743809, 39.72347668239048, 35.61435372488839, 31.130514417375835, 12.437937293733869, 3.122016485248293, 0.7673979188714708, 0.29740599702511517, 0.3678755228008543, 0.42792332065956934, 0.6436501762696675, 2.928463122674397, 7.24453752381461, 9.3704674243927, 12.279352477618627, 15.052999530519758, 11.332065480095999, 16.807577746255056, 14.380447779382978, 11.807886804853167, 11.880128962653023, 12.844275764056615, 15.82965874671936, 15.779357263020106, 12.922567197254725, 10.349584119660513, 8.74431574344635, 14.713666881833758, 12.243081143924169, 8.976454189845494, 10.218997938292366, 14.342444607189723, 12.567039166178022, 15.991256475448608, 16.386244194848196, 14.847648995263235, 10.935933913503375, 3.022971434252603, 2.0702183757509505, 11.93477133342198, 40.272940226963584, 68.47524751935686, 69.57034615107945, 67.4291684286935, 72.68560573032924, 42.74105501174927, 18.951303720474243, 7.6121024404253275, 11.62347206047603, 10.451040846960884, 9.214645385742188, 10.479799440928868, 16.249677351542882, 12.458682877676827, 10.863616194043841, 6.0027424437659125, 10.472038303102766, 10.070952670914785, 14.169589928218297, 20.043808937072754, 20.7949925831386, 22.477441549301147, 16.46504545211792, 12.502861261367798, 16.74783366067069, 10.14465742451804, 14.422767519950867, 17.57022418294634, 10.439459936959402, 13.322449922561646, 8.72084993975503, 4.820777867521558, 2.7004601572241103, 1.6943234375544955, 0.2057002657758338, 0.26653213798999786, 0.26777876966765946, 0.2875198503690106, 2.0386613948004584, 9.934229493141174, 28.417543377195084, 48.95834132603237, 53.32878603254046, 73.13864912305559, 101.61630657741001, 84.5499049595424, 54.863472870418, 46.46052994046892, 25.713895082473755, 41.24151563644409, 50.98092719486782, 57.32345478875296, 66.11692469460624, 69.97104876382011, 72.740204674857, 27.80990777696882, 3.0865042422498976, 0.1578374369336026, 0.1190755268824952, 0.18019857204386167, 0.27869387396744316, 0.17871617658862046, 0.22912485525012016, 0.14835543930530548, 0.19770249564732822, 0.1373924711453063, 0.23914776742458344, 0.19144998544028827, 0.2016939643238272, 0.09808959226523127, 0.16471919337553637, 0.20462625340691634, 0.15485083790762083, 0.41752650854843004, 0.2461023171033178, 0.30027820861765314, 0.11005974388016121, 0.09220794894333396, 0.11495092963533741, 0.11205245873757771, 0.10656108840235642, 0.13200495738003934, 0.2219541378851448, 0.09274246490427426, 0.21717471363289015, 0.13128199188836984, 0.10218200659645454, 0.3383044238601412, 0.32285114164863316, 0.2876857657517706, 0.24314428440162114], [0.049537622902010164, 0.15402720496058464, 0.09926117118448019, 0.1154450388359172, 0.0022543827695439434, 0.009556616972466665, 0.04991087144506829, 0.1007912065833807, 0.04205831798857876, 0.0585048838651606, 0.03863534291407891, 0.0460547162219882, 0.04238084264631782, 0.04635352947350059, 0.044841444718518426, 0.054580050720168014, 0.12054747289844922, 0.07795352954417467, 0.04906936927831598, 0.0360086761814143, 0.03326277048992259, 0.10650485820536103, 0.12369960732758045, 0.17812936593379292, 0.11084419142987047, 0.036999164282211235, 0.02020328348901655, 0.07019507193139621, 0.13573098315724305, 0.15733267473323004, 0.04517975888614144, 1.0004725264651435, 19.921048164367676, 60.92955248696463, 68.53062466212681, 63.448698316301616, 63.36775875091553, 43.24905865533011, 39.320283140454976, 33.34542989730835, 27.539668015071324, 19.48564624786377, 21.452003819601877, 25.6438398701804, 25.85276872771127, 55.74469552721296, 55.07804366520473, 45.24882663999285, 10.838773778506688, 2.6556288599967957, 0.023589746594162922, 0.17201918523226464, 0.11562476919165679, 0.10930372694773333, 0.3771582618355751, 1.9307028906685966, 2.828151762485504, 6.849657501493182, 6.591600971562522, 5.739662366253989, 5.0801480412483215, 5.709156734602792, 7.338865399360657, 7.872601696423121, 6.0481432761464795, 6.208762177399226, 6.406376762049539, 6.4537652134895325, 5.224875109536307, 5.604043083531516, 2.4088221149785176, 2.440774057592664, 6.606047579220363, 9.785677875791277, 9.388864517211914, 12.81873505456107, 15.942931754248482, 17.792783669063024, 16.556068590709142, 16.23652614865984, 14.544624158314296, 10.5880115543093, 11.672900676727295, 7.451909984861102, 21.261930635997228, 37.27658517020089, 70.49524171011788, 57.98751497268677, 63.45994744982038, 53.43246010371617, 48.915015833718435, 28.838510411126272, 12.255944865090505, 12.691688980375018, 15.334537063326154, 16.94736507960728, 13.437556385993958, 10.024217350142342, 10.758687973022461, 7.5816867010934015, 5.808585456439427, 4.687757211072104, 4.9372709308351785, 6.366840643542154, 3.9989614401544844, 10.510262080601283, 9.76797820840563, 13.42911432470594, 9.21884296621595, 8.881529637745448, 10.497837832995824, 6.564791781561715, 4.415745658533914, 6.704289896147592, 6.204457334109715, 2.8777742769036974, 3.2279174540724074, 2.533131467444556, 0.7829937477196965, 0.6096355414816311, 0.2538470615233694, 0.09203988260456494, 0.11857940921826021, 0.18357824640614645, 1.8427315311772483, 6.323845190661294, 20.666073969432286, 43.20362091064453, 60.85517202104841, 69.49347128186906, 53.10700300761631, 39.69206040246146, 26.209860971995763, 21.480168342590332, 22.872993809836252, 23.287050860268728, 28.095190388815745, 39.46533373423985, 50.86329419272286, 48.06778029033116, 31.90299081802368, 6.925490140914917, 0.1666868906468153, 0.12782136829836027, 0.03883466257580689, 0.1370201725512743, 0.07359370456210204, 0.15223166559423718, 0.06270193508160965, 0.10968851737145867, 0.06408034504524299, 0.20725788362324238, 0.14366406175707067, 0.20588101393410138, 0.08607708649443728, 0.0804868128948978, 0.13764739675181253, 0.03955117180677397, 0.08635179818208728, 0.05887687033308404, 0.04848808868389044, 0.09687530635190861, 0.05682555379878197, 0.043366143346897194, 0.039773405596081696, 0.058196957888347764, 0.03734271674017821, 0.08382586336561612, 0.06127566125776086, 0.047346575651317835, 0.02759143231170518, 0.11570767260023526, 0.08696141439889159, 0.14936918419386658, 0.17369034912969383, 0.085393462463149, 0.04998964936073337, 0.06623476158295359, 0.06966708347733531, 0.03161666828340717, 0.0511110709714038, 0.021589900333700434, 0.0663225097315652, 0.11000012779342276, 0.0472284630606217, 0.0681980483766113, 0.020235128833779266, 0.06154693277286632, 0.030533322665308203, 0.04158872765089784, 0.04903283016756177, 0.018475331299539124, 0.006072066965446408, 0.04831810548369374, 0.03646866864125643, 0.04888841416686773, 0.020955502321677547, 0.0805639691118683, 0.023884909327274988, 0.13060333473341806, 0.01820135921505945, 0.04392664719905172, 0.024502096298549856, 0.03636663393782718, 0.04640182759612799, 0.03672170452773571, 0.044419192376413515, 1.1749896705150604, 23.18763950892857, 69.84824630192348, 77.82791192190987, 73.26848316192627, 72.29160118103027, 54.231443881988525, 51.95651681082589, 42.72198568071638, 38.43709414345877, 27.458935158593313, 29.652048928397043, 30.29993370601109, 30.93788603373936, 42.91751146316528, 44.55915192195347, 33.5651319367545, 9.885535648890905, 2.3318467140197754, 0.0900949841099126, 0.34792181636605946, 0.15826499541955336, 0.6290972286037037, 1.5273416148764747, 3.0645346896989003, 5.213689378329685, 5.7197331956454684, 9.409716929708209, 5.951551590647016, 7.800846781049456, 7.732148204530988, 7.9573193447930475, 7.576680524008615, 9.727788959230695, 9.95810784612383, 9.020902684756688, 10.160651309149605, 7.375439848218646, 8.360819475991384, 4.218753806182316, 3.9378572446959357, 3.86269554070064, 6.986922204494476, 9.726824028151375, 13.017019271850586, 14.185270275388445, 16.803476572036743, 14.806821380342756, 16.869105781827653, 16.158558675221034, 12.240755234445844, 12.568281156676155, 10.24960822718484, 23.351420709065028, 47.11837496076311, 76.00269658224923, 65.28817135947091, 70.61974648066929, 63.300722530909944, 57.51058367320469, 33.81675400052752, 14.308883939470563, 13.240040813173566, 14.521248681204659, 17.001630510602677, 13.49035314151219, 11.595350963728768, 10.575212972504751, 6.459722859518869, 3.9294560040746416, 5.214320795876639, 4.671140594141824, 6.777654188019889, 11.38213506766728, 15.279029641832624, 11.653417927878243, 16.654098987579346, 11.35096458026341, 12.950591019221715, 13.4941303559712, 13.894284929547991, 8.713886976242065, 9.392763325146266, 8.200997012002126, 7.735975793429783, 6.048858506338937, 5.136243454047611, 3.621994742325374, 2.8755004789148058, 0.7174930796027184, 0.06079908540206296, 0.03761914851410048, 0.03667182881118996, 1.4280284068414142, 6.956142118998936, 26.72173649924142, 52.82719905035836, 68.9144709450858, 75.99767998286656, 63.75508608136858, 48.25713259833199, 30.46692671094622, 22.59988096782139, 30.849143641335623, 34.04530804497855, 37.81982660293579, 44.91832515171596, 58.53071471623012, 58.05034405844552, 38.47413846424648, 9.856129135404315, 0.21659789101353713, 0.06981014580066715, 0.031481941762779436, 0.13906982328210557, 0.13884427824190684, 0.10742989142558404, 0.03261486454201596, 0.04313013868938599, 0.06773723488939659, 0.11951916664838791, 0.06347587890923023, 0.056188005687935014, 0.022610959829762578, 0.11260679470641272, 0.0665741783699819, 0.041338578930922916, 0.09351138078740664, 0.013428153736250741, 0.04613834905571171, 0.05786784126290253, 0.05420544510707259, 0.04242298984900117, 0.016913465822913816, 0.030675214515732865, 0.04884592091132488, 0.029268353578767607, 0.04238733622644629, 0.07135535324258463, 0.04465201809736235, 0.05092564770685775, 0.03797885689086147, 0.08748486345367772, 0.024316681515691534, 0.02316731444027807, 0.12843749166599341, 0.40975114862833706, 0.19966057129204273, 0.22635584883391857, 0.16864963461245808, 0.12461253548307077, 0.24464930221438408, 0.3345527766006333, 0.10993089008011989, 0.35164290240832735, 0.14968669787049294, 0.11378739814140967, 0.13615442972098077, 0.14491222692387445, 0.17783060696508202, 0.1531171945056745, 0.20471790991723537, 0.18836997928363935, 0.1262015016483409, 0.16964989022484847, 0.15090834588876792, 0.20202331165117876, 0.20923324834023202, 0.39127203449606895, 0.2411667619432722, 0.2023600007274321, 0.076307308594031, 0.22056742943823338, 0.19470636998968466, 0.22751830145716667, 0.17076731526425906, 1.9297001787594386, 30.94466052736555, 84.25773320879254, 86.17820835113525, 82.0116376876831, 80.61404923030308, 59.8029020854405, 56.63572209221976, 47.52492448261806, 40.702276366097585, 28.46187288420541, 32.087764263153076, 38.517936434064595, 38.736113343920024, 69.31894642966134, 68.40971211024693, 53.89267403738839, 13.620059507233755, 3.8204847999981473, 0.19160200442586625, 0.45713989862373894, 0.351015746061291, 0.46011655032634735, 1.1114372121436256, 4.162355712481907, 8.578156522342137, 13.912312030792236, 15.412219660622732, 15.645255293164935, 16.106038979121617, 17.334225143705094, 17.200130122048513, 15.497677292142596, 16.492402247020177, 16.82311565535409, 15.877208743776594, 17.56172479901995, 13.989756652287074, 11.694717151778084, 8.374391913414001, 6.885728640215738, 11.512746436255318, 14.104678988456726, 15.33686818395342, 16.721734489713395, 20.854335410254343, 22.560503789356776, 19.968170847211564, 19.529951436179026, 19.364886556352886, 15.273410286222186, 15.789918524878365, 11.38353773525783, 28.416384765080043, 49.85221317836216, 78.12816442762102, 66.81292574746269, 74.83709457942417, 64.32825687953404, 56.89083909988403, 41.20767790930611, 18.44750894818987, 17.558516468320573, 18.878028018133982, 23.881083624703543, 19.097195046288626, 14.796906300953456, 15.431019748960223, 13.89253658907754, 13.301218833242144, 13.439873610224042, 12.846684183393206, 13.806575213159833, 11.87850568975721, 21.50006972040449, 19.800100871494838, 25.171054908207484, 20.097676583698817, 17.740389040538243, 24.82753423282078, 17.711986541748047, 11.627539362226214, 15.59126431601388, 17.535240003040858, 9.651553324290685, 10.951983383723668, 7.505911384310041, 4.062562644481659, 2.595641587461744, 0.8555005341768265, 0.30690035756145206, 0.23113033335123742, 0.3028671182692051, 1.9295156172343662, 8.040345106806074, 27.12014968054635, 51.4367116519383, 66.46612725939069, 72.53269672393799, 59.17473629542759, 51.03515441077096, 33.92410019465855, 32.33628395625523, 34.04367174421038, 35.070445265088765, 43.49891587666103, 53.97393321990967, 67.33499254499162, 65.53244222913469, 48.19907692500523, 14.576024804796491, 0.5808258131146431, 0.24510264503104345, 0.1357913049204009, 0.31314811802336145, 0.28569260984659195, 0.3208279402128288, 0.19609803174223217, 0.12918995986027376, 0.21509094616132124, 0.31980451941490173, 0.2333170345851353, 0.27322659162538393, 0.12605311961046287, 0.2439834965126855, 0.34394522117716925, 0.15332224778831005, 0.24046339254294122, 0.19676986283489636, 0.1227329256279128, 0.17518674954771996, 0.13922861404716969, 0.10244115947612695, 0.11963165418377944, 0.124074253652777, 0.2039128959711109, 0.19160366005131177, 0.18394876723842962, 0.1703665317701442, 0.11760816776326724, 0.24191081630332129, 0.2730684115418366, 0.3053084872663021, 0.40760912214006695, 0.1968068022813116], [0.13889078503208502, 0.09982632978686265, 0.04530296388215252, 0.04157246316650084, 0.04042059908221875, 0.05977831089070865, 0.07907342445105314, 0.07421430626085826, 0.03248798527887889, 0.14583461385752472, 0.13000625105840818, 0.07049858064523765, 0.04675093725589769, 0.05541894391977361, 0.05165074719116092, 0.07451383197414023, 0.049044721493763585, 0.07047089641647679, 0.059836061006145816, 0.03942942226837788, 0.03328337420576385, 0.03528023830481938, 0.14414351460124764, 0.12184751885277884, 0.1963786602552448, 0.05405449142147388, 0.04343356937170029, 0.02336733808208789, 0.2744611453797136, 0.08687465012605701, 0.3132468584392752, 9.155174885477338, 44.807473591395784, 61.80713776179722, 58.12526648385184, 60.10612147194998, 47.157187598092214, 29.771530151367188, 20.43152015549796, 19.47733620234898, 19.28221688951765, 28.956535986491613, 26.15411557470049, 35.56940582820347, 50.80584648677281, 46.977368218558176, 30.203319004603795, 8.597958019801549, 2.0329098062855855, 0.05079639017848032, 0.08882704643266541, 0.038419483961271386, 0.09627434145659208, 1.0854317333017076, 2.2223626460347856, 3.8310747231755937, 3.4840951476778304, 3.3032172535146986, 6.543670994894845, 6.5142557961600165, 6.718318743365152, 4.949727313859122, 6.850008385522025, 8.610559446471077, 5.235943589891706, 7.072272138936179, 4.753710380622318, 6.1057464480400085, 6.486634969711304, 7.381917306355067, 7.184696163449969, 10.776709863117762, 16.40862260546003, 25.14447978564671, 22.103621516908916, 30.53854874202183, 29.78220953260149, 32.92007507596697, 34.17399910518101, 33.97591985974993, 32.61277709688459, 22.673080239977153, 26.43237008367266, 27.127209050314768, 36.0062529700143, 32.243563720158164, 60.27615778786795, 47.21322134562901, 53.43994331359863, 41.094873905181885, 46.29086882727486, 36.666998863220215, 28.601081780024938, 30.174053192138672, 33.299557890210835, 35.18282195499965, 31.572961807250977, 33.0590946333749, 31.80109201158796, 22.540164675031388, 21.858928544180735, 17.141086067472184, 13.550492405891418, 10.538203392710004, 9.816071033477783, 8.483898128782, 7.385862146105085, 11.538876005581447, 9.847387433052063, 21.144782270703995, 13.782584820474897, 10.259901114872523, 8.993525913783483, 3.0877675116062164, 6.431726396083832, 4.702097424439021, 4.004772305488586, 2.070016009466989, 3.1079882894243513, 2.4852859548160007, 0.5687900132366589, 0.28696190459387644, 0.06703514792025089, 0.04270482276167188, 0.12094233956720148, 1.045637337224824, 3.512264664684023, 12.795046039990016, 27.10917500087193, 35.97483321598598, 39.24487434114729, 31.33702530179705, 35.12183066776821, 28.132648127419607, 21.017929009028844, 19.460653577532085, 31.39205503463745, 42.18912833077567, 42.86535133634295, 51.60713011877877, 44.33438464573452, 21.497212273733957, 0.7170832987342561, 0.11243756807276181, 0.03759501641616225, 0.10120008500026804, 0.02636071228023086, 0.18216157385281154, 0.11425830822970186, 0.10789117310196161, 0.05020054143720439, 0.035148538050374815, 0.16824623197317123, 0.07614703183727604, 0.1277369721127408, 0.07184695186359541, 0.037852642592042685, 0.026560929304521, 0.0210681069043598, 0.06606663417603288, 0.02104886365123093, 0.058180232000138075, 0.056956419455153603, 0.025958570019741143, 0.04160735343715974, 0.030743970469172512, 0.045070311187633445, 0.011955096619203687, 0.07009242993912526, 0.07645290185298238, 0.03414323753012078, 0.07493237272969314, 0.16163346038333007, 0.13289400110287325, 0.08294734372092144, 0.03957616225151079, 0.03755120341000812, 0.05858065587069307, 0.10007902979850769, 0.0640421842357942, 0.03166739556140133, 0.048449707350560596, 0.0690538574542318, 0.06934184128684656, 0.03855418673317347, 0.06040290916072471, 0.18282070276992662, 0.06308645409132753, 0.048777816351503134, 0.004089000451910708, 0.09767666977963277, 0.030596453563443253, 0.03459853452763387, 0.041358744991677146, 0.013784733218406993, 0.03373903421951192, 0.02103876874649099, 0.05814920259373529, 0.06647957023233175, 0.15612212754786015, 0.15645395831337996, 0.07115293267582144, 0.02798939310014248, 0.06116651211466108, 0.12375427010868277, 0.05406891707597034, 0.3667954850409712, 13.499553424971444, 55.49628700528826, 71.28066607883999, 69.49864074162075, 68.84118134634835, 57.6015043258667, 39.112306186131065, 27.212885550090245, 28.36363925252642, 26.198214054107666, 29.758797577449254, 25.953920602798462, 28.026474441800797, 46.010686193193706, 48.18383605139596, 29.44460698536464, 10.884128144809178, 2.2187313437461853, 0.03321017724062715, 0.1305484412504094, 0.2100231038140399, 0.8218568137713841, 2.835433257477624, 5.641941598483494, 5.616002670356205, 7.984690036092486, 7.5745274509702405, 11.202092477253505, 8.880060962268285, 10.754572033882141, 8.839595522199359, 8.624060664858137, 6.525857985019684, 9.15109281880515, 10.864391786711556, 8.190498283931188, 11.87864031110491, 7.084375900881631, 5.845707075936454, 6.7464763181550165, 10.142768383026123, 14.893666914531163, 22.857348203659058, 22.987051963806152, 30.11627197265625, 30.11580296925136, 32.80944585800171, 34.76406792231968, 35.88484014783587, 35.32040670939854, 27.24202455793108, 28.924998113087245, 31.606670992715017, 39.321328844342915, 42.04621083395821, 65.69501617976597, 54.99234805788313, 58.98924718584333, 49.820908069610596, 54.526860441480366, 42.16910014833723, 31.988071509769984, 33.43675354548863, 33.931368010384695, 35.13886070251465, 31.808467524392263, 34.54776702608381, 32.88402087347848, 23.89365986415318, 20.615348645618983, 15.618063517979213, 10.757835950170245, 4.961406367165702, 6.9857058354786465, 9.943451489721026, 10.417444569723946, 17.356806789125713, 14.748136895043508, 11.181208797863551, 12.684554048946925, 15.259154319763184, 14.391769000462123, 10.347735898835317, 9.653995616095406, 8.525975550924029, 8.780933618545532, 6.11026668548584, 5.9949352741241455, 4.811888950211661, 2.872180325644357, 1.407248081905501, 0.14733755535313062, 0.25224398182971136, 0.05915333942643233, 0.6984785199165344, 4.881446497780936, 15.69857576915196, 36.15880414417812, 45.40382358006069, 42.95568834032331, 33.30206618990217, 35.173500946589876, 31.7221257346017, 24.81049030167716, 21.04123326710292, 33.72674356188093, 46.10622392381941, 50.336387974875315, 57.910025187901084, 52.339095047542024, 25.937637499400548, 1.297821227993284, 0.14741861314645835, 0.07066358000572238, 0.12827749310859612, 0.01832269654343171, 0.1061671581119299, 0.02085329289548099, 0.09016673240278449, 0.08134059315281254, 0.04738053632900119, 0.08897250398461308, 0.11819341778755188, 0.03448228451556393, 0.06059981323778629, 0.03979115607216954, 0.07495621645024844, 0.06707379048956291, 0.06724658621741192, 0.09181109416697707, 0.0061081773268857175, 0.031554714643529484, 0.015198193756597382, 0.023547355118872862, 0.04242565988429955, 0.07676692785961287, 0.05478801491803356, 0.04533709419359054, 0.08505432387547833, 0.04454876881624971, 0.05503781419247389, 0.13902875834277698, 0.09547854201602084, 0.013726998370007744, 0.029367202560284307, 0.2069219137941088, 0.15869619085320405, 0.2389835619500705, 0.13956222257443837, 0.12901075876184873, 0.12404623015650681, 0.24143073920692715, 0.19662127723651274, 0.1618636873151575, 0.32441445919019835, 0.2999430394598416, 0.18256820631878717, 0.1140222866088152, 0.15675549927566731, 0.15028227519776138, 0.17163042537868023, 0.2557479366660118, 0.1679674219340086, 0.23256581489528927, 0.12180156846131597, 0.09473182101334844, 0.1986819745174476, 0.3092897507761206, 0.3449927978217602, 0.39014653488993645, 0.11679858049111706, 0.12133184580930642, 0.10627627332827874, 0.33789138602358954, 0.218648545976196, 0.8562275980200086, 19.513923679079326, 71.93401908874512, 85.81355299268449, 79.67261001041958, 78.15160070146833, 63.42562334878104, 44.5467598097665, 33.66478647504534, 31.507561888013566, 30.13752998624529, 40.17175361088344, 35.90139423097883, 49.682246344430105, 69.47309916360038, 60.29561274392264, 37.355801582336426, 10.880234548023768, 2.854446134396962, 0.19369316792913846, 0.26537230451192173, 0.4258695308651243, 1.2303643162761415, 2.7528686821460724, 7.176700089659009, 11.655117630958557, 13.198058928762164, 13.478423084531512, 16.220020702907018, 15.775754622050695, 18.89029679979597, 15.929354974201747, 20.096887963158743, 19.84293130465916, 15.092574732644216, 16.13422782080514, 14.778446674346924, 13.342934080532618, 14.178839717592512, 13.716697658811297, 14.761793579374041, 17.78615508760725, 21.552660635539464, 28.95438551902771, 25.785702977861675, 35.19132307597569, 34.720780645098, 35.584243706294465, 41.49683066776821, 41.13139016287667, 40.08569669723511, 29.958627768925258, 32.82129948479788, 34.37356179101126, 45.43118211201259, 45.52402741568429, 72.53444072178432, 58.74039050510952, 64.62441689627511, 55.40862158366612, 57.27391760689871, 48.91666603088379, 36.95247255052839, 36.59733969824654, 37.09167970929827, 40.362551144191194, 34.60278286252703, 38.534493991306846, 37.11275359562465, 28.736415318080358, 26.65756814820426, 25.41619430269514, 20.95523020199367, 17.745560237339564, 19.505556310926163, 18.15680500439235, 16.664510863167898, 21.091343675340923, 22.429783855165752, 29.041995355061122, 24.117669786725724, 17.21409773826599, 22.642991065979004, 15.740799971989222, 16.940244913101196, 15.387098448617117, 12.971984522683279, 10.043126004082815, 7.910914931978498, 6.896351567336491, 2.408246065889086, 1.0038912573031016, 0.24004959474716867, 0.16775689965912274, 0.2778019261147295, 1.4663445736680711, 4.607681827885764, 17.24744735445295, 35.56242983681815, 46.183473995753694, 49.60972799573626, 42.28754608971732, 48.608117376055034, 40.37210839135306, 31.634748663221085, 30.06307656424386, 43.02832480839321, 55.38045358657837, 60.276109150477815, 68.62456430707658, 60.41163376399449, 34.7309284891401, 2.570432437317712, 0.26139788063509123, 0.2589036130479404, 0.22251975110598973, 0.16066802718809672, 0.35498105042747086, 0.20443852990865707, 0.16752808408013412, 0.17875238321721554, 0.1717843171209097, 0.32310084253549576, 0.20255817366497858, 0.24701367105756486, 0.15702130858387264, 0.16755579545029572, 0.23975858464837074, 0.24617625027894974, 0.20819677252854618, 0.19867441563733987, 0.230648899184806, 0.10260690522513219, 0.048594839205699306, 0.14984740210430963, 0.128314093287502, 0.20323362813464232, 0.10666003237877573, 0.11447667436940329, 0.1730238648929766, 0.11319427711090871, 0.21992944367229939, 0.37376053844179424, 0.3948883818728583, 0.17397263326815196, 0.12450675187366349], [0.02263616570936782, 0.02999456586050136, 0.07821777143648692, 0.04031153814867139, 0.03132989902847579, 0.052944896676178486, 0.05265544381524835, 0.05538761595796261, 0.05027847457677126, 0.0423170467838645, 0.09403831072683845, 0.07643328540559326, 0.018232061228315746, 0.03933211016867842, 0.04838896828836628, 0.07003453054598399, 0.058881972916424274, 0.05669801974935191, 0.07256892669413771, 0.00812252557703427, 0.06823570707014628, 0.02630396978929639, 0.05380969634279609, 0.2075332467045103, 0.06671321698065315, 0.11012453718909196, 0.016697798556249057, 0.05279830936342478, 0.054039125995976586, 0.1453213428280183, 1.1326035963637489, 32.0387864112854, 56.67128644670759, 58.03106280735561, 55.79865871156965, 48.121100766318186, 40.96157966341291, 22.410910810743058, 26.37310889789036, 25.3289509841374, 26.142783062798635, 25.555908679962158, 43.05070495605469, 47.23008114950997, 46.670674732753206, 28.684281247002737, 18.064699683870586, 4.327385417052677, 0.4177830219268799, 0.050118048542312214, 0.24413649258869036, 0.07071785602186408, 0.12944856312658104, 0.88648086892707, 4.0653045773506165, 1.9865238496235438, 4.882379727704184, 2.873386489493506, 9.091908931732178, 2.8172272401196614, 5.121938415936061, 5.87720890556063, 6.914650516850608, 4.7786209753581455, 9.627152119364057, 12.257562058312551, 7.271605968475342, 11.000495706285749, 7.268296020371573, 16.015554325921194, 18.01583300318037, 26.16760723931449, 32.34504910877773, 41.7635372706822, 43.42790181296212, 46.06499678747994, 45.74186038970947, 50.162773336683, 52.57257189069475, 50.1684604372297, 49.92550277709961, 40.44294875008719, 43.567828110286165, 41.215442521231516, 43.056746414729524, 25.75883255686079, 46.162612029484336, 44.63479348591396, 49.31186219624111, 43.2015677179609, 38.53162438528878, 42.27923257010323, 36.63444307872227, 45.34282187053135, 52.54237501961844, 51.98581389018467, 55.556385449000764, 54.17653921672276, 51.658494676862446, 48.360198702131, 41.8221765926906, 35.42598458698818, 26.885427372796194, 18.642623049872263, 24.37457595552717, 18.699902262006486, 9.978337526321411, 21.40770036833627, 10.87734409740993, 8.789657950401306, 9.885780572891235, 15.924685784748622, 9.119778156280518, 12.086517385074071, 5.52082450900759, 6.975386457783835, 5.396802638258253, 5.138707458972931, 5.491769313812256, 4.51507363149098, 2.088570305279323, 1.4161442731107985, 0.29228710170303074, 0.0429245018666344, 0.0902424772669162, 0.08657200315168925, 1.2589421485151564, 8.890629172325134, 21.219365971429006, 28.426739318030222, 35.91735771724156, 28.76100672994341, 23.21896893637521, 22.598267248698644, 19.762994016919816, 25.290748051234655, 34.59365292957851, 40.35908399309431, 44.56770168031965, 49.59046064104353, 52.826115131378174, 36.96962765284947, 7.217202876295362, 0.044798547734639475, 0.01764621239687715, 0.12190014602882521, 0.06957356778106519, 0.058549260055380206, 0.0037708082402657184, 0.07254766819200345, 0.1178425880415099, 0.12135958432086877, 0.14796666588102067, 0.08492780423590116, 0.06293047246124063, 0.04651016588988049, 0.02811561757698655, 0.039110582055790086, 0.11412642816347734, 0.0826931848589863, 0.01394792937207967, 0.039947633032820055, 0.05195564350911549, 0.10630375399653401, 0.1423265335283109, 0.06298298428633384, 0.03339080326259136, 0.039974265532302, 0.040550721742744954, 0.11294986201184136, 0.01769484469800123, 0.04248605967898454, 0.04710046760737896, 0.18253947714609758, 0.16272062276090893, 0.08242389466613531, 0.010974299694810594, 0.02726104512943753, 0.0903195927717856, 0.022920955338382294, 0.07011459089283432, 0.032343857655567784, 0.05541512376761862, 0.03249005481068577, 0.0518162758089602, 0.04500171808259828, 0.12003102632505552, 0.03721894516742655, 0.01295269576699606, 0.08679279166140727, 0.05615067608388407, 0.016789488993319016, 0.04711822147614189, 0.02246076610338475, 0.05902130329715354, 0.05366046613614474, 0.01623629805232797, 0.03247721353545785, 0.056996792288763184, 0.08050352521240711, 0.08324214004512344, 0.057770892179438045, 0.037509585464639325, 0.02180104686080345, 0.02526652197619634, 0.2565250763935702, 2.1963650924818854, 38.501323291233604, 68.30338382720947, 69.17533411298479, 65.77119622911725, 57.72558525630406, 47.668800830841064, 29.4069790158953, 37.38803080150059, 29.841964040483745, 28.962037222726003, 30.295889854431152, 30.778014932359966, 40.30894579206194, 44.4950339453561, 29.29258734839303, 17.690558297293528, 2.701768155608858, 0.28577775242073195, 0.03918669672150697, 0.4326147117785045, 1.1802909289087569, 2.8408391731125966, 5.637542085988181, 6.452772489615849, 8.102393388748169, 7.961791379111154, 9.828462277139936, 10.205104146684919, 10.658269132886614, 11.755768367222377, 10.277889132499695, 11.715675524302892, 9.772838473320007, 10.129279323986598, 12.98642201083047, 9.73335794040135, 7.031778037548065, 5.209787096296038, 12.122355324881417, 16.44510064806257, 24.227962017059326, 34.678653717041016, 41.92694500514439, 45.00991977964129, 45.380752086639404, 46.43937267575945, 50.337329455784385, 51.9652750151498, 51.49933923993792, 52.75302355630057, 45.39795235225132, 48.37327521187918, 46.4969037600926, 46.65455491202218, 35.174435479300364, 52.702986104147776, 52.02723210198538, 54.68451854160854, 51.6478396143232, 47.96134778431484, 48.72806412833077, 42.86606352669852, 48.89963252203805, 52.29904910496303, 52.62465558733259, 54.811288424900596, 56.978615692683626, 54.119991302490234, 49.72885833467756, 41.65096255711147, 36.32135725021362, 24.352795089994157, 17.34144605909075, 13.555893761771065, 8.25726786681584, 8.365905557359968, 12.202054636819021, 12.718271051134382, 14.557169999395098, 12.659348590033394, 20.42721574647086, 15.931694780077253, 9.34432395866939, 9.749665362494332, 12.498038343020848, 9.184122817856924, 7.716210774012974, 7.164194200720106, 6.879479604107993, 5.887663338865552, 2.291735197816576, 1.5112629405089786, 0.03503015065299613, 0.028524977753737142, 0.14569364142205032, 1.25734167439597, 6.970076297010694, 19.456105981554302, 27.411805527550833, 37.334772859300884, 33.42992346627371, 26.681565489087784, 28.27159993989127, 22.007703372410365, 29.65129852294922, 39.594816889081685, 44.73866210665022, 50.883270263671875, 57.14784949166434, 59.56496797289167, 44.98493753160749, 10.550268071038381, 0.010920292548170047, 0.02606549526431731, 0.11745829294834818, 0.021040750068745444, 0.07105357479304075, 0.012953498134655612, 0.10981830754982573, 0.06797727343759366, 0.06796788251293556, 0.02099622629715928, 0.07003697327205113, 0.07122834505779402, 0.03815745070044484, 0.014602955696838242, 0.04437044642067381, 0.0633639409872038, 0.07389787145491157, 0.06562587139861924, 0.058035086574299, 0.05234090890735388, 0.04596792480775288, 0.06599829212895461, 0.029855615459382534, 0.03591719609020012, 0.02249913725868932, 0.05520205020106264, 0.07367406346436058, 0.03520210499742201, 0.047409021229084046, 0.020676646481401155, 0.07613611420882599, 0.11582257572029318, 0.024437445481973033, 0.07026648095675878, 0.09502480564905064, 0.20920301281980105, 0.10882373806089163, 0.17654630302318505, 0.08011135232767888, 0.22166577407291957, 0.18429116957953998, 0.16804953824196542, 0.1397654709539243, 0.263196486979723, 0.13578636518546514, 0.11346062924712896, 0.3203961205269609, 0.1411546085562025, 0.16675105291817868, 0.15691232228917734, 0.18945125197725637, 0.16781713999807835, 0.2097598865096058, 0.24150583946279117, 0.1926188434341124, 0.17037132222737583, 0.28668810214315144, 0.28161442439470974, 0.16266585141420364, 0.19602305362267153, 0.2145423370280436, 0.10173712511147771, 0.4319599526269095, 4.554129455770765, 49.07616192953927, 81.72050816672188, 79.98074872153146, 74.82497692108154, 65.15989371708461, 54.69081360953194, 35.368373598371235, 40.01755223955427, 38.4389979498727, 38.88881737845284, 38.74060535430908, 60.88865539005825, 63.41273444039481, 56.292095456804546, 36.733256884983604, 21.66661282948085, 5.060919335910252, 0.5730601698160172, 0.20235279468553408, 0.41893720999360085, 1.4183403381279536, 1.6696154262338365, 5.77334462744849, 10.738849128995623, 11.56192752293178, 14.834697553089686, 12.302443078586034, 17.23359785761152, 11.93804132938385, 13.320749350956508, 16.00092315673828, 17.980739389147075, 12.449894274984088, 19.82841304370335, 21.1488139629364, 13.698040008544922, 20.355360950742448, 15.406261580330984, 23.768243142536708, 25.144377299717494, 30.57663529259818, 38.76248870577131, 44.28702572413853, 50.50826208932059, 48.26683228356497, 49.89772040503365, 53.10184049606323, 53.61294303621565, 52.08060468946184, 53.57907056808472, 47.371233803885325, 53.029165812901084, 51.152961117880686, 52.74847248622349, 38.635826519557405, 58.46991103036063, 56.41857351575579, 60.74454975128174, 55.5798773084368, 51.82260765348162, 55.243598393031526, 46.873256410871235, 52.0326760155814, 55.66044167109898, 55.116074630192344, 58.116671562194824, 59.64419828142439, 57.15870257786342, 54.70957721982683, 45.591657706669395, 41.48687389918736, 31.545231546674454, 22.98554767881121, 32.80369274956839, 30.457852363586426, 24.081177847726003, 35.29093939917428, 19.93730000087193, 20.257575477872575, 20.499793154852732, 25.633895260947092, 17.922251190458024, 19.50735763141087, 10.779941643987383, 18.731599943978445, 11.24891378198351, 15.684137412479945, 13.756243331091744, 12.984093495777675, 8.622494714600698, 2.61588277561324, 1.4534986572606223, 0.20717194037778036, 0.15117772429117135, 0.23072492224829538, 1.7994083187409808, 11.068058252334595, 27.86298680305481, 38.38479505266462, 48.936280795506065, 43.1048036302839, 32.94197927202497, 34.28567402703421, 29.721433639526367, 36.581563813345774, 47.39125503812517, 54.22007662909371, 60.59025110517229, 64.2524242401123, 67.03220394679478, 52.59969765799386, 16.377044779913767, 0.23132615855761937, 0.08205251209437847, 0.28368251770734787, 0.2306375540792942, 0.21541334529008183, 0.10016397559749228, 0.20345339205648216, 0.2516464910336903, 0.1587429961987904, 0.26023997419646805, 0.3016113399394921, 0.1662409302911588, 0.14970481475549086, 0.14131436284099305, 0.10971509558813912, 0.22745640549276555, 0.16964653826185636, 0.1924808836941208, 0.289080480911902, 0.13747723373983586, 0.20676089743418352, 0.150997166122709, 0.16573223258767808, 0.12322381857250418, 0.11968742976231234, 0.11720100603997707, 0.1623142481382404, 0.15428465471736022, 0.12946784709181103, 0.23734511701124056, 0.2966356426477432, 0.3392666679407869, 0.15876461432448455], [0.027595842789326395, 0.13932983790125164, 0.03825314449412482, 0.01898597470218582, 0.015180305877168263, 0.0358182046163295, 0.02478298944021974, 0.030316303417618786, 0.05925007816404104, 0.02621265933183687, 0.033405289985239506, 0.051537676115653346, 0.023251719107585292, 0.024689816404134035, 0.0804646722972393, 0.0533396378159523, 0.01750066493903952, 0.07825627829879522, 0.026580077562747256, 0.05299738135987094, 0.025070837565830777, 0.028655867158834423, 0.016280550409906676, 0.13583672605454922, 0.09253904010568346, 0.019068864540063908, 0.03233617324648159, 0.07949304407728569, 0.05625070571633322, 0.291137799088444, 19.080340453556605, 47.6696172441755, 61.952292578560964, 60.7604889188494, 47.79414980752127, 37.00900656836373, 23.031421422958374, 24.78232056753976, 20.452559300831386, 31.263336181640625, 28.2586259160723, 32.02553967067173, 34.53649704796927, 24.987782273973735, 31.82392031805856, 21.274657998766216, 2.697316965886525, 0.21575756610504218, 0.045500787374164374, 0.13345447102827684, 0.08902120922825166, 1.2098706045321055, 2.8157796263694763, 5.363705328532627, 5.750016484941755, 5.5714742711612155, 5.125385156699589, 7.47710154737745, 8.700138228280203, 11.441794037818909, 14.268111041613988, 9.156229274613516, 4.715937801769801, 4.669857782976968, 6.230136573314667, 9.42021131515503, 7.003345140389033, 14.403481926236834, 17.15826027733939, 25.543191739491053, 38.1618447303772, 46.91984060832432, 47.52908297947475, 55.46506527491978, 54.550421782902305, 57.53100790296282, 58.5982095173427, 60.306757654462544, 65.02030440739223, 61.042877605983186, 63.800075667245046, 56.89802701132638, 55.01814324515206, 49.77878114155361, 44.27174316133772, 21.811668634414673, 42.730813367026194, 48.1853403363909, 46.94301979882376, 45.32343987056187, 39.880815165383474, 36.71196413040161, 42.11927809034075, 53.27942950384957, 56.743269784109934, 58.21744128635952, 60.284794398716514, 60.61295781816755, 59.190953390938894, 57.953142234257285, 58.590774944850374, 51.774335043770925, 44.8724079813276, 36.65722969600132, 26.529115063803538, 20.067450182778494, 13.461406946182251, 14.55109987940107, 11.775166869163513, 8.391870975494385, 9.087929350989205, 17.09068557194301, 15.051493508475167, 6.736931230340685, 9.633774621146065, 8.05224997656686, 10.652568135942731, 4.810554027557373, 4.827336532729013, 3.1143684727805, 4.587678398404803, 3.552277603319713, 1.16867929484163, 0.7732362513031278, 0.049473555625549386, 0.08012653115604605, 0.07279390855027096, 0.4418750320162092, 7.741269452231271, 22.072620391845703, 32.518761021750315, 38.55524131229946, 38.94257211685181, 31.475099904196604, 26.92997748511178, 15.670340027127947, 18.45680216380528, 25.88478602681841, 37.618537289755686, 49.55118247440883, 53.7530187198094, 50.06227459226336, 30.96035303388323, 2.937535515853337, 0.08062568187181439, 0.07601120269724301, 0.023815926064604094, 0.030864349366830926, 0.12211300246417522, 0.05784559209964105, 0.09308902666504894, 0.018448793794959784, 0.07887924808476653, 0.04106501057477934, 0.12967758226607526, 0.005637451291217336, 0.035669239038335424, 0.05167712184733578, 0.032208975071885755, 0.05992315097578934, 0.07915047210242067, 0.04799873601379139, 0.03297629979039941, 0.04399418518213289, 0.08178077239011015, 0.07592421450785228, 0.1268019372863429, 0.05614104088661926, 0.02379871841653117, 0.012758566049991973, 0.030525319344763244, 0.01587009779177606, 0.06647581793367863, 0.050710799771228006, 0.055054740248514075, 0.1204759960195848, 0.03253754886931606, 0.0705946476331779, 0.00510626651313422, 0.0059803383607816485, 0.033134011684783866, 0.033667401277593205, 0.06743414686726672, 0.0658667174034885, 0.07495263378534998, 0.011233746889047325, 0.038514254947326014, 0.05079608144504683, 0.013732867697919053, 0.03826270165986248, 0.09409140609204769, 0.06029964970158679, 0.060118840475167544, 0.048985583774213276, 0.037351262888738086, 0.051510008850267956, 0.031651938533676524, 0.02261935670061835, 0.05034674198499747, 0.013489258359186351, 0.021822610703696097, 0.07534261500196797, 0.03296839485743216, 0.09732014712478433, 0.013959821546450257, 0.26476159585373743, 22.330646957669938, 57.190018108912874, 71.32026386260986, 69.56923443930489, 55.62801442827497, 48.88899482999529, 34.26867525918143, 29.03791502543858, 28.628607068743023, 38.26476839610508, 26.095905303955078, 23.517814431871685, 28.205062253134592, 26.569499731063843, 29.85132326398577, 18.543880462646484, 3.0885619946888516, 0.339219333337886, 0.05930456452603851, 0.6705600608672414, 1.5571874933583396, 2.968127565724509, 5.24660907472883, 8.148848176002502, 8.514594401632037, 8.399647746767316, 13.448555384363447, 13.485401681491307, 10.818676114082336, 16.1506290435791, 11.93915217263358, 15.870034728731428, 10.55003183228629, 7.278144657611847, 7.775094151496887, 5.793166969503675, 6.645073873656137, 9.29364206109728, 14.869483709335327, 23.531002112797328, 36.690146786826, 45.44013139179775, 50.757327216012136, 56.53839520045689, 56.45068114144461, 58.26261499949864, 61.67856134687151, 59.94194943564278, 65.30944674355644, 61.214039530072895, 65.60071522848946, 61.82299355098179, 59.11307798113142, 52.828175272260395, 47.083057267325266, 28.58054985318865, 48.08279882158552, 53.73270566122872, 53.66411304473877, 51.82004376820156, 46.866085869925364, 42.52930865968977, 46.979278973170686, 56.1603923525129, 57.233503409794395, 57.99228491101946, 63.79011195046561, 62.38055174691336, 61.99195984431675, 59.57575157710484, 62.293970244271414, 55.33739559991019, 47.69202518463135, 38.000750746045796, 26.425863095692225, 19.01280048915318, 13.880284309387207, 14.012724791254316, 15.733382769993373, 9.637641293661934, 11.46958943775722, 19.958092485155376, 15.284695897783552, 9.482299549239022, 11.055219718388148, 10.663478544780187, 9.665135315486364, 13.146663972309657, 7.637862018176487, 7.423843605177743, 8.17681814943041, 8.13851707322257, 4.279027691909245, 1.940412129674639, 0.6537692504269736, 0.2755709301148142, 0.0943116449884006, 0.606343181005546, 8.4213730267116, 21.982936518532888, 33.749933174678254, 37.126069818224224, 27.73615438597543, 25.103895357676915, 26.568813596452983, 21.116275548934937, 26.39931402887617, 34.26959589549473, 45.6870391028268, 55.441351073128835, 62.61346926007952, 58.856529644557405, 37.06568997246878, 3.9041602185794284, 0.14431622890489443, 0.007984002652977194, 0.03151381594528045, 0.0273748218813645, 0.06057180331221648, 0.044356187007256916, 0.06763415184936353, 0.026084602810442448, 0.03823383338749409, 0.03937582139457975, 0.04289403225162199, 0.016749217939962233, 0.016547633667609522, 0.00961420763217445, 0.0543318527883717, 0.08803001205836024, 0.008591372918869768, 0.05877749209425279, 0.0300316444065954, 0.03554192551278642, 0.06369072345218488, 0.04885467740574053, 0.13034450076520443, 0.06629492728305714, 0.05810152193797486, 0.021061270664046918, 0.013322901080495544, 0.06312249787151814, 0.02319151608805571, 0.07064950718943562, 0.10134299126054559, 0.03837732997323785, 0.1444013307669333, 0.360634658485651, 0.19984016594077858, 0.09350032066660267, 0.09024624313626971, 0.12236658457134451, 0.16069149092904159, 0.22432825049119337, 0.16144614400608198, 0.20633783085005625, 0.10230009204574994, 0.10360405993248735, 0.0819412459220205, 0.10634179266967944, 0.17599573970905372, 0.12935968860983849, 0.11942987143993378, 0.19254633518201963, 0.18233757226594857, 0.1890900813575302, 0.1679306181945971, 0.1042491499600666, 0.18073389546147414, 0.21437122406704084, 0.23422258027962276, 0.1535374383841242, 0.2506275757082871, 0.20695907037172998, 0.1790332288614341, 0.7783151673419135, 29.441476821899414, 71.27068151746477, 82.62710217067173, 79.9023105076381, 63.05989101954869, 52.472695010049, 36.38569756916591, 36.7160461970738, 32.82266133172171, 45.799898692539756, 41.60671642848423, 45.66331100463867, 49.679449694497244, 35.94933680125645, 41.87847784587315, 26.26225733757019, 3.657540423529489, 0.3700176035719258, 0.1822369998054845, 0.33480057758944376, 1.3011963154588426, 2.524643374340875, 8.587025897843496, 12.303051045962743, 14.210638148444039, 13.392047422272817, 15.53923967906407, 18.423720053264073, 23.322502306529454, 25.31373790332249, 24.146721942084177, 14.905360732759748, 12.078758852822439, 13.765362841742379, 11.700947080339704, 17.04262661933899, 13.19389522075653, 24.309587717056274, 25.370244128363474, 31.150914328438894, 47.181113719940186, 53.90761613845825, 53.07254689080374, 58.832794598170686, 57.916928223201204, 60.81899275098528, 63.74084922245571, 61.08564376831055, 67.43605409349713, 63.722408703395296, 67.81498105185372, 61.54863003322056, 61.92894663129534, 56.803441183907644, 50.98091677256993, 32.75704601832798, 52.413590158735005, 60.092266763959614, 56.224107333592, 57.70247902188982, 50.97290202549526, 49.75405250276838, 52.2209061895098, 59.097486223493306, 58.947606631687705, 60.239735330854145, 64.31149087633405, 65.8630931036813, 62.70132923126221, 62.925165448869976, 63.90686253138951, 59.29668412889753, 49.69102191925049, 41.9237870488848, 29.808685643332346, 26.007909842899867, 20.180856943130493, 22.693631274359568, 20.253012248447963, 16.864780528204783, 17.103447675704956, 25.306556940078735, 23.130950893674576, 16.47869692529951, 20.512833186558314, 14.830085686274938, 18.232328448976787, 15.87424533707755, 15.10911318234035, 14.569060104233877, 16.211908681052073, 10.117846063205175, 5.346786464963641, 1.9594100245407648, 0.38894463224070414, 0.17617633858961718, 0.25838363809244974, 0.5625936314463615, 9.994898557662964, 27.39971045085362, 41.710991518838064, 51.97479404721941, 54.44435058321272, 43.507733140672954, 38.213105065482004, 25.136704751423427, 29.517973014286586, 38.24822473526001, 52.831149101257324, 64.41477584838867, 69.94210256849016, 67.69012192317417, 46.335323401859824, 5.551518176283155, 0.23339072348816053, 0.15996980108320713, 0.24657335611326353, 0.2691723720303604, 0.18011469154485635, 0.17095041115369114, 0.18026584200561047, 0.12631628263209546, 0.16272938943334989, 0.1915627308189869, 0.1933979102011238, 0.11745142617395946, 0.10214566426085574, 0.13629355654120445, 0.27434943137424334, 0.19929190964571067, 0.21733578427561692, 0.17215677856334619, 0.1147877283926521, 0.13429843288447174, 0.1707037908158132, 0.14008259108023985, 0.277946834053312, 0.17804681536342415, 0.14880920281367643, 0.16328809516770498, 0.10410070006868669, 0.19474037816481932, 0.21876802242227963, 0.23390578585011618, 0.24562707117625646, 0.27985213324427605], [0.06898565789950745, 0.07812458822237593, 0.057219039648771286, 0.052558230103126595, 0.017182204706062163, 0.08526684782866921, 0.05191450732360993, 0.01939204568043351, 0.017327701273773397, 0.07549865770020656, 0.06290873898459332, 0.07941548752465419, 0.0522564075488065, 0.03887779365426727, 0.07276726926543883, 0.07029194637600865, 0.05346291745081544, 0.07530516665428877, 0.11403900571167469, 0.028609153415475572, 0.04726708527388317, 0.007060883749675537, 0.05717578982668264, 0.10299827065318823, 0.06167740148625203, 0.01756796204218907, 0.0901722488924861, 0.1597053895571402, 0.05968009294675929, 6.210487936224256, 35.23642383302961, 57.618291173662456, 61.94928400857108, 56.46351446424212, 50.78999069758824, 33.17420891353062, 18.95411252975464, 23.5053528376988, 39.319355555943076, 33.20344693320138, 37.777536392211914, 34.82963807242257, 29.782146998814174, 41.831122398376465, 20.282324961253575, 3.618708895785468, 0.4235041035073144, 0.013196099000716848, 0.39062897328819546, 0.8116537098373685, 1.289704429251807, 2.8823220900126865, 5.832303132329669, 6.781152606010437, 4.750649264880589, 7.910257458686829, 9.00726250239781, 9.889308520725795, 5.188803102288928, 9.853345513343811, 12.236560259546552, 14.586527006966726, 7.978771907942636, 7.562950015068054, 8.651818718229022, 8.8834308385849, 21.465526751109532, 23.028294733592443, 34.164570399693076, 45.958369731903076, 51.89452845709664, 59.49206052507673, 65.97305529458183, 58.96469920022147, 57.86641134534563, 61.18792125156948, 62.76896299634661, 66.95728152138847, 65.25142233712333, 61.41829572405134, 62.27555056980678, 63.470126560756135, 60.887203216552734, 49.756637232644216, 42.23590012959072, 23.908096483775548, 42.5189836365836, 50.19627060209002, 47.013794149671284, 46.06281157902309, 35.00749111175537, 37.266419955662315, 46.24733141490391, 57.352161271231516, 55.096105507441926, 62.64654963357108, 59.32474790300642, 55.80583620071411, 55.3443021093096, 55.93600722721645, 56.12885100500924, 56.22835268293108, 57.27450472967965, 54.7255094391959, 43.7757112639291, 37.746029785701204, 31.51771320615496, 27.309816394533428, 18.12105652264186, 9.011756249836512, 8.465051140104022, 22.34937408992222, 14.098132916859218, 5.868665661130633, 10.880863359996251, 12.575595872742788, 9.659027848924909, 7.866463831492832, 4.918498635292053, 4.499311208724976, 5.9482811604227335, 5.011346544538226, 2.967815113919122, 1.8336528411933353, 0.23839538065450533, 0.09435543763850417, 0.16824928538075515, 0.10227822964744908, 0.8105433551328523, 6.040679608072553, 18.839581898280553, 32.677409240177695, 36.71391657420567, 34.69910226549421, 28.910408633095876, 28.407227039337158, 18.444363151277813, 16.81011036464146, 28.41922310420445, 41.40820639474051, 49.32410492215838, 54.534868240356445, 46.63804599217006, 14.117322972842626, 0.6091242517743791, 0.06457287325922932, 0.06051706589226212, 0.06303950625338725, 0.0326795560706939, 0.01806087532479848, 0.0162488594318607, 0.050423541971083195, 0.1362796194319214, 0.064517009471144, 0.05685159258012261, 0.13616578839719296, 0.036769005203885693, 0.01849663390644959, 0.0032866671431942707, 0.06544423435947724, 0.013893308151247246, 0.03734793467447162, 0.014860208678458418, 0.028931901989770786, 0.08571670976068292, 0.14027857913502625, 0.05964748255376305, 0.05996065360627004, 0.02438157151586243, 0.026886799139901996, 0.023605955099420886, 0.017494206981999532, 0.11468613812966005, 0.0851366233878902, 0.09042492854808058, 0.011986440696221377, 0.06939341673361403, 0.024700774744685208, 0.04440056998282671, 0.06459440317537103, 0.033184331841766834, 0.07418960080082927, 0.060213278979063034, 0.012518042349256575, 0.04683527915871569, 0.05095483489068491, 0.045819474916372976, 0.10192275872187954, 0.08719698140131575, 0.04253377765417099, 0.06528619676828384, 0.04536138913993325, 0.02985867565231664, 0.05373915923493249, 0.06714494167161839, 0.06464207704578127, 0.054193774304751835, 0.02988809353805014, 0.08925063548875706, 0.04030046784984214, 0.07089631751711879, 0.06498842846070017, 0.057709403336048126, 0.055365848554564376, 0.00909427338878491, 7.092795380524226, 43.17452185494559, 67.46663311549595, 72.951263155256, 62.623842920575825, 56.963524205344065, 38.4034857068743, 25.259533269064768, 34.950665269579204, 46.92036172321865, 31.962078298841202, 28.106623649597168, 23.112345354897634, 30.33383744103568, 44.703973225184846, 22.60121849605015, 4.482759731156485, 0.3819723592272827, 0.026775778936488286, 0.2869347631931305, 2.6079813710280826, 4.189355543681553, 5.733868871416364, 10.056420513561793, 8.137949057987758, 11.157756890569415, 10.658941371100289, 10.977738618850708, 12.054892659187317, 13.907538618360247, 16.314613478524343, 17.088887725557598, 17.626530647277832, 11.436010531016759, 6.843859229769025, 6.661368267876761, 7.819480112620762, 11.826893602098737, 21.09226952280317, 32.305503436497276, 43.95605523245675, 53.09115069253104, 60.4117796761649, 64.76172024863106, 61.11910629272461, 59.58709798540388, 61.29502773284912, 62.73126207079206, 66.2562986101423, 64.36259487697056, 61.22066116333008, 60.87319564819336, 65.54451819828579, 62.47280992780413, 53.89409841809954, 44.04021181379046, 29.298448153904506, 47.86034876959664, 54.678202629089355, 51.70330708367484, 51.40401690346854, 41.68307713099888, 42.929413727351594, 50.96791321890694, 59.01891599382673, 56.30779491152082, 64.43814958844865, 61.96117237636021, 58.63750158037458, 58.96736036028181, 58.33884021214077, 59.94485378265381, 60.233294350760325, 59.48026943206787, 56.88668407712664, 46.55419513157436, 35.972839082990376, 27.94812481743949, 20.8974837235042, 16.51893741743905, 7.3786846569606235, 8.974461793899536, 16.237109797341482, 17.977758611951554, 9.833479745047432, 16.05009729521615, 18.897590671266826, 13.598275167601448, 13.132613846233912, 8.916946343013219, 9.587184344019208, 11.343075769288198, 5.819423343454089, 6.60331129176276, 5.122702283518655, 1.4815519005060196, 0.5243216508201191, 0.07573001778551511, 0.15963459121329443, 0.9533924013376236, 6.5834607226508, 18.510324137551443, 34.319935594286235, 34.65778827667236, 34.23641129902431, 30.20386791229248, 28.119015761784144, 20.872730766023906, 23.34212749344962, 34.649488653455464, 47.93961729322161, 55.323603425707134, 63.28931358882359, 54.20390469687325, 16.986547708511353, 0.7040152571031025, 0.023812999882336174, 0.031049969406532388, 0.02602350921370089, 0.04758351329447968, 0.060469670221209526, 0.046360837295651436, 0.01963097821655018, 0.0459109346515366, 0.049972669021891694, 0.03988148265385202, 0.04856841026672295, 0.00970538831981165, 0.011414017528295517, 0.041863680218479464, 0.062240063079765866, 0.00925694452598691, 0.028124504689393297, 0.0393084225111774, 0.132416393873947, 0.011027937039865978, 0.04314590445054429, 0.11654627402978283, 0.07461700322372572, 0.052412721661052535, 0.05631348038358348, 0.024930279036717753, 0.03047089065824236, 0.15200643268014702, 0.08547585697046348, 0.06691668249134507, 0.019741784681433013, 0.2724787917520319, 0.24799960958106176, 0.19286912786109106, 0.13217138844941342, 0.11179824559284107, 0.2671471621309008, 0.22189986865435327, 0.11951179775808539, 0.10359783098101616, 0.20602650541279996, 0.1190193984657526, 0.20100092222648008, 0.1777571216225624, 0.13564191865069525, 0.14976244951997483, 0.21109841897019319, 0.1140076709645135, 0.15063699973481043, 0.3748336551444871, 0.2838654507483755, 0.1629922946116754, 0.09682185814848968, 0.14090196282735892, 0.19160038951252187, 0.2822532244026661, 0.21628763766161033, 0.15008784777351789, 0.34669323371989386, 0.21694904645638807, 10.836268952914647, 56.853391783578054, 79.63465894971574, 81.62816660744804, 72.49913692474365, 66.38771683829171, 44.22445024762835, 30.869963918413433, 36.11404732295445, 53.441541399274556, 45.54126589638846, 56.77510643005371, 51.130303042275564, 44.64097043446132, 52.97153050558907, 24.176580088479177, 4.577132769993373, 0.5853427935923848, 0.18181310540863446, 0.6516098805836269, 2.8937772810459137, 4.59130014692034, 9.254233615739004, 16.02843107495989, 16.73144112314497, 14.588206733976092, 17.184204850878032, 17.34434345790318, 20.802468844822474, 19.647930111203873, 21.288092340741837, 22.96331344332014, 27.655963488987513, 16.612326417650493, 14.869306530271258, 13.974048512322561, 14.501039845602852, 30.267242431640625, 29.55810580934797, 40.06950044631958, 53.341605458940776, 58.599515778677805, 64.44190161568778, 68.74462223052979, 62.216073989868164, 63.182658740452354, 63.508758544921875, 64.41373361860002, 68.98392513820103, 66.24541773114885, 60.85499136788504, 62.540089334760395, 64.69137668609619, 63.77685478755406, 58.09827273232596, 49.14805146626064, 36.0740395954677, 53.72207144328526, 59.942088399614605, 55.78210810252598, 56.02183485031128, 44.60674013410296, 48.979741777692524, 53.64819819586617, 60.10353674207415, 58.362109729221885, 67.62498950958252, 63.73602022443499, 61.072796549115864, 59.60710184914725, 60.708634512765066, 61.40475368499756, 62.80213369641985, 62.992993763514924, 60.03526374271938, 49.832063402448384, 42.397042751312256, 36.106765610831125, 34.94086136136736, 24.055313178471156, 18.44620268685477, 13.837629318237305, 31.186972005026682, 23.62047232900347, 14.580516815185547, 22.047495705740793, 18.699839728219168, 19.523638997759136, 15.10122697693961, 15.020883219582693, 12.765768936702184, 14.668873582567487, 11.91083652632577, 7.410744513784136, 6.164729271616254, 0.8191770889929363, 0.3732721289353711, 0.48154946310179575, 0.35717535125357763, 1.2056898517268044, 8.143880214009966, 23.311588423592703, 45.21139669418335, 49.70378923416138, 47.116036891937256, 41.578753403254915, 41.752899578639436, 27.27990961074829, 27.219680888312205, 41.01149899618966, 56.71856893811907, 62.94400896344866, 70.2458917072841, 63.00912053244454, 23.784329959324428, 1.4920751644032342, 0.24494587630033493, 0.3111561563398157, 0.17989282416445868, 0.13740365340241364, 0.1330561845430306, 0.14282593530203613, 0.24236432196838514, 0.23796280100941658, 0.13991835846432618, 0.15974004912589276, 0.32676794433168, 0.09333458170294762, 0.060663575173488686, 0.08829713093915156, 0.20672952197492123, 0.06409885548055172, 0.18687509878405503, 0.17305548462484563, 0.24570936390331813, 0.2384956952716623, 0.21987563584532055, 0.1625115389802626, 0.13902594920779976, 0.16832696406969003, 0.14144043464745792, 0.10447203514299222, 0.08383509822721992, 0.22557937407067843, 0.32186911148684366, 0.3336100200457232, 0.11420327903968946], [0.047875008545815945, 0.07175671349146537, 0.02210929005273751, 0.06141057437551873, 0.009082080114499798, 0.05750128307512828, 0.041746795776167085, 0.05949283763766289, 0.004700362624134868, 0.018950444912271838, 0.05621740661029305, 0.008159219902674002, 0.025478477656309093, 0.049241018281983476, 0.03167677291535905, 0.033159863868994374, 0.04504293569230607, 0.04362622921222022, 0.017340683345017687, 0.04324317244546754, 0.017499608120747974, 0.07157085596450738, 0.029013282087232386, 0.05046258148338113, 0.04794409019606454, 0.0320625607855618, 0.026136660017073154, 0.045444988046905825, 0.6509653265987123, 15.660827943256923, 51.23275423049927, 60.58554022652762, 60.27223205566406, 55.90057488850185, 42.00578621455601, 33.61418969290597, 28.56628520148141, 20.369121858051844, 32.15459551130022, 45.03508268083845, 37.485552242824006, 36.06885971341814, 43.71601234163557, 21.633259739194596, 3.468899654490607, 0.3688588286084788, 0.25737690925598145, 0.05595879655863557, 0.1491697220397847, 2.214752414396831, 4.542746135166713, 4.985001581055777, 5.0056959220341275, 5.0075050592422485, 9.06438798563821, 6.846592477389744, 15.289630855832781, 13.12324593748365, 10.705819998468671, 16.843757016318186, 12.59042159148625, 23.695835965020315, 16.018620218549454, 7.336934668677194, 17.774044377463206, 20.019453763961792, 26.710096529551915, 41.20952613013131, 54.036522592817036, 55.48408249446324, 62.68844032287598, 63.13864885057722, 61.948811531066895, 61.2979598726545, 54.69633742741176, 60.04954923902239, 60.83092280796596, 61.45776149204799, 62.508016450064524, 60.76797907693045, 58.413915497916086, 59.91772106715611, 63.208130836486816, 53.51213162285941, 44.71649387904576, 29.684941700526647, 39.47602353777204, 53.97610453196934, 46.668600695473806, 40.792846134730745, 30.06062732424055, 39.69375228881836, 51.199076311928884, 55.75704595020839, 55.897611481802805, 60.6946964263916, 59.00101743425642, 54.83415494646345, 51.64378534044538, 52.02038812637329, 56.842861788613455, 53.07532269614083, 57.71726826259068, 54.88301815305437, 55.89801447732108, 49.158776010785786, 46.09996359688895, 44.32037707737514, 45.96635321208409, 16.87690339769636, 18.170451266424998, 23.23028060368129, 19.853509937013897, 8.279382245881216, 8.960121580532618, 16.494656937462942, 9.145294547080994, 18.808226415089198, 5.002078516142709, 6.9739924754415235, 9.518838388579232, 7.018687197140284, 6.120400633130755, 4.056443887097495, 1.9255510185446059, 1.435852404151644, 0.05548318422266415, 0.032828959303775, 0.040271497797220945, 1.2336385462965285, 5.5006300040653775, 16.92462362561907, 27.44584996359689, 33.46470962251936, 35.78306988307408, 31.637253488813126, 27.02036660058158, 20.219560146331787, 29.076498372214182, 35.40571321759905, 40.74037333897182, 47.264335768563406, 46.72113602502005, 31.173110348837717, 4.500891055379595, 0.03585971738877041, 0.09846490355474607, 0.03451897968937244, 0.0369805554593248, 0.03554473125508853, 0.03471933411700385, 0.06666852187897478, 0.001873617754816743, 0.062301063377942355, 0.007222487890560712, 0.04419931649629559, 0.08688210044056177, 0.023370557730751376, 0.0254765166901052, 0.04880867612415126, 0.0710037024691701, 0.02374787239490875, 0.049963542725890875, 0.05114763383088367, 0.05803750215896538, 0.03968582708122475, 0.1531175880559853, 0.047626719011792114, 0.024600926620353545, 0.028398439454446946, 0.06513106330697026, 0.08194250799715519, 0.09695932255791766, 0.10136539648686137, 0.0412016336007842, 0.01951188175007701, 0.041778127130653174, 0.014066125931484359, 0.03094779221074922, 0.008168319057274078, 0.03238979108365519, 0.013443118826087033, 0.031192583896751915, 0.04279773795445051, 0.023825159229870354, 0.010313022366192724, 0.05104455757620079, 0.021017308380188685, 0.07074528919266802, 0.04337616191644754, 0.04885331015767796, 0.0053893776161463135, 0.05931648638631616, 0.017864339352984513, 0.09551795132990394, 0.0633660512311118, 0.08468463085591793, 0.03709723973380668, 0.029586650963340486, 0.0801869004166552, 0.028849772111113583, 0.030608908073710542, 0.07154549911086049, 0.05766732059419155, 0.8473155562366758, 19.373691661017283, 59.38637147630964, 70.28202928815568, 70.15603760310582, 65.68987451280866, 51.86008971078055, 41.83035462243216, 36.152873856680735, 27.120024612971715, 29.310277462005615, 31.192457607814244, 37.48384298597063, 41.09477663040161, 51.681722504752024, 28.136438369750977, 5.160711535385676, 0.4780764494623457, 0.14591154615793908, 0.48649793756859644, 1.1814494324581963, 4.031550228595734, 8.197713119643074, 9.09280959197453, 8.912329265049525, 9.888735294342041, 13.45549750328064, 13.583135042871747, 11.819214974130903, 12.086936882564, 13.881167599133082, 8.722081507955279, 10.171488761901855, 16.160757780075073, 11.693540300641741, 9.871100766318184, 14.128255094800677, 18.08536536352975, 26.124160153525217, 40.448020935058594, 52.55701487404959, 59.29025704520089, 63.49345166342599, 63.64159420558384, 64.64410809108189, 62.94558620452881, 56.64146825245449, 60.75013610294887, 60.364184515816824, 61.10752364567348, 61.16404724121094, 60.20467472076416, 57.74841703687395, 61.92021969386509, 63.355793952941895, 57.97994143622262, 48.39689908708845, 35.55903911590576, 44.897352014269146, 57.99761765343802, 52.5776857648577, 46.921567235674175, 36.2273759160723, 47.43439640317644, 56.109642710004536, 58.10532862799508, 55.86044209344046, 62.29020432063511, 61.21692303248814, 58.447134835379465, 55.18519530977522, 54.49400935854231, 59.76397827693394, 56.3362477847508, 60.33617632729666, 58.35047149658203, 56.64684615816389, 52.33315086364746, 46.38977990831648, 38.02744572503226, 29.872525691986084, 16.402834756033762, 11.729299204690115, 14.266568541526794, 12.83429033415658, 8.045050774301801, 15.63136237008231, 16.705032757350377, 14.414669394493103, 12.940570848328726, 12.32950370652335, 14.196977990014211, 12.04501840046474, 13.37854186126164, 12.162094678197588, 8.239395362990242, 4.79867217370442, 3.1462963138307845, 0.23452089141522134, 0.08175249105053288, 0.04939549356432898, 1.649972868817193, 5.9342401538576395, 17.699905361448014, 29.240236146109446, 33.65412793840681, 34.69654185431344, 33.549147605895996, 31.727990014212473, 23.671593700136455, 32.95470142364502, 43.169401032584055, 48.98627655846732, 54.19976009641375, 54.94319302695138, 36.82586942400251, 6.0880515575408936, 0.018745372969923273, 0.12602270767092705, 0.04419571008267147, 0.05120399294953261, 0.012773746574696685, 0.03800277864294393, 0.11993540717022759, 0.027149838328893696, 0.019173973007127643, 0.02344651972608907, 0.07512916145580155, 0.08284096300069775, 0.021159296921853508, 0.009541620500385761, 0.05685357050970197, 0.06747502860214029, 0.03877743832500918, 0.04746124467679432, 0.08507131439234529, 0.04105029654289995, 0.04442621521385653, 0.08144174236804247, 0.05545211749683533, 0.05120998441374727, 0.028374054602214267, 0.02062911679968238, 0.032734150998294353, 0.11553311268133776, 0.05216591472604445, 0.05430980379294072, 0.03964683845905321, 0.16794067408357347, 0.19857871505830968, 0.16298424718635424, 0.13631046563386917, 0.06741078490657465, 0.2019445744476148, 0.14172482224447386, 0.14781163419995988, 0.10286214974309717, 0.1273671705275774, 0.17047770294759954, 0.15260465629398823, 0.16910531158958161, 0.19836021321160452, 0.12935465388000011, 0.23256459353225573, 0.12321944880698409, 0.11292919383517333, 0.2614779477672917, 0.13563505187630653, 0.20048231791172708, 0.10928089424435582, 0.09185082917766911, 0.19285006102706703, 0.12280577314751488, 0.11784490863127367, 0.14727076036589487, 0.09294989305947508, 1.6188539500747408, 25.763069220951625, 71.458803994315, 81.40348965781075, 80.03736959184918, 73.25018160683769, 56.20969329561506, 46.14019366673061, 40.63571957179478, 29.71334593636649, 43.246466977255686, 58.74591432298933, 47.85559620176043, 49.00431408200945, 55.88291604178292, 27.99024306024824, 4.7977385095187595, 0.6570748016238213, 0.38107045048049515, 0.6289568532790456, 0.6006036975554058, 6.141663423606327, 13.520028897694178, 14.108544792447772, 14.635819264820643, 14.434007968221392, 22.721010650907242, 18.083668266023906, 26.156325101852417, 24.757051706314087, 19.237586872918264, 28.072155373437063, 23.33260498728071, 34.76062856401716, 24.739820173808507, 14.037234561783926, 23.709786210741314, 26.39904304913112, 30.456431456974574, 47.574600628444124, 59.15501730782645, 62.82978752681187, 67.951735496521, 68.059328351702, 66.98961148943219, 65.51805945805141, 57.47901800700596, 63.845669746398926, 59.980324336460654, 61.63102177211216, 63.27737658364432, 62.79321915762765, 59.43941402435303, 59.1519045148577, 64.28823525565011, 60.32318319593157, 52.29391091210501, 42.47791630881173, 51.29612874984741, 63.1126070022583, 55.26285532542637, 52.34983696256365, 41.44642496109009, 50.298631463732036, 57.714478560856406, 58.993923323495046, 57.99744742257254, 65.30432592119489, 63.79221030644008, 59.93937860216413, 55.13794755935669, 56.67741823196411, 60.3244686126709, 57.90618283408028, 63.04630034310477, 60.14259256635393, 60.574284144810264, 54.44804702486311, 53.5963785307748, 51.500416210719514, 50.49206583840506, 23.77793935367039, 26.548684665134974, 31.22426298686436, 29.6739114352635, 18.294381073543004, 17.64002752304077, 29.486292702811106, 18.333968435014995, 31.485935619899205, 15.419850519725255, 19.99918760572161, 19.26927239554269, 22.555629628045217, 17.853868756975444, 9.73225143977574, 6.6068123153277805, 2.9728204224790846, 0.27933527954987114, 0.2877203438963209, 0.15035045439643518, 1.8210610768624713, 6.9989760262625555, 21.40948258127485, 37.44723987579346, 46.46341691698347, 47.9197176524571, 44.068303380693706, 40.64347376142229, 29.82772023337228, 42.09751633235386, 49.23752689361572, 55.8858516556876, 63.14354733058384, 63.575954573495046, 45.720182010105674, 9.25878815991538, 0.17030981981328555, 0.30172329821756905, 0.07591455216918673, 0.17644799686968327, 0.08892568506832634, 0.14423343406191894, 0.20224912810538495, 0.22182494481759413, 0.11224023651863847, 0.10416220926812716, 0.193499106913805, 0.15975490904280118, 0.11028771807572671, 0.1049991347161787, 0.1376047440405403, 0.16771084070205688, 0.17716360704175063, 0.1421207067157541, 0.18765880673059396, 0.19169117749801703, 0.22001455910503864, 0.24277890686477932, 0.21160566460873398, 0.1684796480195863, 0.15902560603405747, 0.19827285861330374, 0.18811877204903535, 0.2290447066937174, 0.2353218612926347, 0.2688615487090179, 0.1562468558549881], [0.0889267096562045, 0.019685454400522367, 0.04473966107304607, 0.030442901088723114, 0.017998295736366084, 0.04219187742897442, 0.06739941944501229, 0.03828545633171286, 0.07484239898622036, 0.03491400920652917, 0.0288990133974169, 0.035146801000727076, 0.06280442101082631, 0.061201958784035275, 0.0796582130715251, 0.02008105388709477, 0.07127797989440815, 0.026307435406904136, 0.06233067464615617, 0.0719389815681747, 0.05478227790445089, 0.09890671806143862, 0.05727704082216535, 0.0557013400165098, 0.025843853496813347, 0.021580236298697333, 0.027227617101743817, 0.11328980127083403, 3.8971112711088995, 35.87124252319336, 55.743583815438406, 53.31426429748535, 45.8275351524353, 36.921150071280344, 35.160869121551514, 33.165784222739084, 44.599656445639475, 50.079276834215435, 77.21477508544922, 58.62983076913016, 55.9581789289202, 57.33917508806501, 23.3623936516898, 6.947767802647181, 1.653675064444542, 0.0804104505638991, 0.16596691070922784, 0.34407780691981316, 0.9428044323410306, 2.7640305289200375, 4.562042585441044, 4.761790267058781, 6.887490442820957, 4.888838512556894, 9.715595739228384, 9.673300317355565, 7.746864489146641, 9.929892948695592, 13.85872665473393, 12.155621562685285, 17.258595739092144, 24.44755114827837, 28.374721629279, 29.15897696358817, 37.138917037418906, 42.52805798394339, 45.897611209324424, 56.3969680922372, 60.11491094316755, 61.011242457798545, 56.77648912157331, 59.69776889256069, 59.73622717176165, 59.157435280936106, 56.973369802747456, 53.38980858666556, 61.32990768977574, 60.26575633457729, 61.96486186981201, 59.6893824168614, 57.07412910461426, 58.107760497501914, 59.363477161952424, 58.75406455993652, 50.88982936314174, 39.40195574079241, 35.58910049710955, 49.51536103657314, 46.44361802509853, 35.40556035723005, 33.564933913094656, 44.222028800419395, 50.83592176437378, 57.538637025015696, 57.89466272081648, 60.56619644165039, 57.068758147103445, 50.88047708783831, 48.259477615356445, 52.275939396449495, 55.86385713304792, 53.488420895167756, 55.74968433380127, 54.049425397600444, 56.74002497536795, 55.94226408004761, 55.32296071733747, 48.44302122933524, 45.71100343976702, 33.51236036845616, 29.991777624402726, 31.37548358099801, 29.262150764465332, 12.482402290616717, 27.742630107062205, 24.068240301949636, 12.968949896948677, 12.628166811806814, 10.984084929738726, 11.353789022990636, 8.496146934373037, 7.198514827660151, 10.008468389511108, 7.104110521929605, 5.423785098961421, 2.5250305192811147, 0.5103993607418877, 0.1946601074721132, 0.08135003836027213, 0.09533396655959742, 0.5618997886776924, 5.776591607502528, 15.827749729156494, 42.951734815325054, 42.965335914066856, 31.578159059797013, 17.179238625935145, 19.35160854884556, 20.116699014391216, 25.31189489364624, 37.32149485179356, 50.01607949393136, 52.65924024581909, 44.07231249128069, 16.356999226978846, 1.4519003544534956, 0.04993977364418762, 0.06245180671768529, 0.03291683637404016, 0.026662684112255062, 0.03984967971752797, 0.07261211544807468, 0.029137138476861373, 0.043251297902315855, 0.0430656235798129, 0.06079767404922417, 0.01442331524698862, 0.014111469882274312, 0.037625984754413366, 0.018129171570762992, 0.03645514543833477, 0.09873138461261988, 0.032512840016611984, 0.007751214251454387, 0.015484727220609784, 0.13100783659943513, 0.05314971247155752, 0.08747908912066903, 0.024428137677854726, 0.03591688735676663, 0.055489799939095974, 0.037713770222451, 0.07952489451106105, 0.07006650990141289, 0.037432788871228695, 0.026433132322771207, 0.010836093985874738, 0.01574668244990919, 0.007065570306232465, 0.02836741683339434, 0.03438610556934561, 0.03663252467023475, 0.06789143197238445, 0.018343084824404547, 0.02037526497484318, 0.013681029318831861, 0.021599744180483476, 0.027540859400427768, 0.0782442953703659, 0.018967555869104605, 0.056820566566394906, 0.01986019073852471, 0.016542807587289383, 0.025785562249698808, 0.04280991765803524, 0.08215529657900333, 0.04243966145440936, 0.028461650080446686, 0.017294176554839526, 0.11773646516459328, 0.021808951793770705, 0.029224832342671495, 0.026352157649983252, 0.05878661839025361, 4.980536929198673, 40.21018409729004, 66.14334174564907, 65.52463940211705, 56.37261118207659, 49.640081201280864, 42.732116154261995, 42.8606995173863, 43.16528769901821, 36.63133028575352, 54.92712531770979, 57.386940479278564, 58.8679107938494, 64.68550545828683, 31.184078080313547, 8.394074422972542, 1.435805286679949, 0.051084984692611864, 0.18615893221327237, 1.0375167386872428, 3.914672843047551, 6.0124338780130655, 8.711745194026403, 8.718609145709447, 15.565133878162928, 13.515707118170601, 14.227240868977137, 12.951757448060171, 12.728947826794215, 13.498289721352712, 14.193675858633858, 12.82720490864345, 12.097840343202863, 16.708876848220825, 20.079522677830287, 23.93096821648734, 32.72016150610787, 37.10016693387713, 46.14845160075596, 56.002793312072754, 63.64383847372872, 62.04386983598982, 60.833069801330566, 61.11883531297956, 60.72649138314383, 60.504920278276714, 58.08741269792829, 54.65778534752982, 59.5563383102417, 58.87840952192034, 60.749545506068635, 58.58178397587368, 57.33191769463675, 57.662752696446006, 61.787745339529856, 60.66028894696917, 54.60947799682617, 43.55444587979998, 41.28610570090157, 53.754001889910015, 52.15097257069179, 41.79563447407314, 38.97699349267142, 50.38865579877581, 54.458462374550955, 56.98889555249895, 57.090700558253694, 62.72936521257673, 59.60848454066685, 54.05543211528233, 50.823887484414236, 53.15461206436157, 58.5276575088501, 55.123641218457905, 57.97913891928536, 56.35097449166434, 58.56691483088902, 55.99432693208967, 55.120500632694785, 49.15355443954468, 44.056658199855256, 32.85554368155343, 24.236270325524465, 20.84486848967416, 19.611969709396362, 14.193753157343183, 16.667079959596904, 13.4614451612745, 13.88812448297228, 11.33218881062099, 11.00970641204289, 10.576049361910139, 12.542254073279244, 12.160264696393694, 11.996782268796649, 8.889437556266785, 7.3822760071073255, 5.3410733086722235, 3.028919960771288, 1.0199452872787202, 0.038400773358132155, 0.012078540798808848, 0.7041918933391571, 5.321754276752472, 18.134643724986486, 40.13038403647286, 39.56135783876692, 31.674617426736013, 23.17184451648167, 23.832604306084768, 29.122540610177175, 31.340065138680593, 43.824932302747456, 55.372372831617085, 58.61231436048235, 51.75771842684065, 21.209760086877004, 1.9816540309361048, 0.04885069779785616, 0.08391595246004206, 0.025096375927595154, 0.041783161860491545, 0.060497544439775605, 0.060358784028462, 0.036172555959118266, 0.08288070479673998, 0.0633438563506518, 0.040656854797686846, 0.034602307182337554, 0.048460316245577166, 0.020640719748501266, 0.07642018289438315, 0.0871984606076564, 0.050645843613892794, 0.0871912342097078, 0.07344579749873706, 0.053259747102856636, 0.06902626143502337, 0.08258096873760223, 0.025577080668881536, 0.016824340248214345, 0.045769599199827225, 0.03709241874249918, 0.02196908605817173, 0.04594865441322327, 0.025906414425532733, 0.015370909756581699, 0.06931347173771688, 0.14531370252370834, 0.15540719591081142, 0.14325677789747715, 0.06801195336239678, 0.10915678340409483, 0.15494755628917897, 0.19454105171774114, 0.12449589531336512, 0.1706289891153574, 0.1110387613464679, 0.12512899562716484, 0.15745083482137748, 0.1872687033776726, 0.14147912471422128, 0.22157797164150647, 0.1284187233873776, 0.14175386354327202, 0.08409609672214303, 0.11178611338670764, 0.11812826485506125, 0.1893780380487442, 0.3096401191183499, 0.19651595503091812, 0.23112300517303602, 0.11223266406783036, 0.22754171091531003, 0.1668508518487215, 0.28430709562131334, 7.814713648387364, 53.07795606340681, 78.68159539358956, 74.30749593462262, 63.43996443067278, 52.9533748626709, 48.403642313820974, 45.01575974055699, 56.05528347832816, 63.17266723087856, 85.22130938938686, 65.60723958696637, 65.80231026240757, 68.08872617994035, 29.52321195602417, 9.114782401493617, 2.2220519312790463, 0.20221544562705926, 0.4080918862351349, 1.1387503636734826, 4.799118161201477, 12.825124791690282, 14.52586054801941, 13.624886768204824, 19.759834323610576, 15.008386884416852, 22.358118397848948, 17.77414686339242, 17.86238898549761, 18.78467549596514, 22.662743057523453, 22.11747796194894, 26.415796892983572, 35.62319530759539, 36.29391186577933, 38.80803067343575, 42.04510259628296, 44.514513220105854, 49.919864313943044, 60.01068101610456, 65.44257422855922, 66.44182940891811, 64.25506455557687, 63.26006167275565, 63.13722446986607, 62.475095885140554, 60.51222283499581, 55.97913122177124, 60.949160303388325, 60.62253243582589, 62.303961753845215, 60.01351588112967, 56.48823962892805, 57.60556207384382, 60.263616289411274, 62.51037188938686, 58.21513448442732, 50.744893414633616, 47.12022318158831, 59.35051877158028, 55.69053084509713, 45.24736404418945, 44.85175098691668, 53.95850821903774, 58.334747723170686, 58.703377451215474, 59.24798420497349, 67.68436881474086, 61.71581063951765, 55.6637351172311, 50.79963479723249, 55.70071690423148, 60.89378316061837, 57.23936421530587, 58.01752076830183, 57.743831225803916, 61.4987211227417, 58.32252584184919, 59.64453179495675, 53.95510012762887, 50.345486640930176, 37.12691402435303, 33.36026430130005, 36.311317103249685, 36.163403851645334, 17.998841183526174, 38.504515988486155, 36.48229142597744, 28.314227138246807, 21.83102978978838, 18.754405668803624, 22.831457478659495, 17.13631091799055, 12.32924575465066, 17.16202620097569, 16.725053991590226, 10.068171654428754, 6.565629908016749, 2.206359859023775, 0.8906874060630798, 0.3336173753653254, 0.16381253488361835, 1.0427411326340266, 7.026840473924365, 21.024215391704015, 53.10927159445626, 57.07545968464443, 44.50141586576189, 27.606709446225846, 31.952861513410294, 31.65443638392857, 36.74558993748256, 50.77007021222796, 64.35322870526994, 65.92368834359306, 60.634483337402344, 27.401018449238368, 3.338336271899087, 0.14697593690029212, 0.1637947844075305, 0.08264889009296894, 0.11128229435001101, 0.1934199354478291, 0.1816872235919748, 0.1411451090659414, 0.10036580583878926, 0.16780626986707958, 0.13824549822935037, 0.13025977888277598, 0.14741516618856362, 0.11665835444416318, 0.1350839864462614, 0.19831446638064726, 0.12210865984005587, 0.15413879682975157, 0.13731560669839382, 0.14084871139909538, 0.19804827709283146, 0.20174906136734144, 0.190999994586621, 0.14607968713556016, 0.12808879251990998, 0.14875117449888162, 0.15162054981504167, 0.13703056770775998, 0.1793267223984003, 0.1880004626831838, 0.12748799047299794], [0.0752157357388309, 0.018877025726916533, 0.05282002587669662, 0.02886945301932948, 0.022607947134279778, 0.027559105207079222, 0.03218366571569017, 0.05949262050645692, 0.12972512042948178, 0.04994275241291948, 0.04265992749216301, 0.04203831138355391, 0.046343080034213405, 0.0802588861967836, 0.03859778939347182, 0.0344386716772403, 0.05182684738455074, 0.07671360857784748, 0.03646735906867044, 0.005076047107909939, 0.004139241729197758, 0.02797870956627386, 0.03610982200396912, 0.01876912678458861, 0.01586872206202575, 0.03130836232698389, 0.0429490512636091, 0.6673960792166846, 10.045837538582937, 48.19396652494158, 58.570479256766184, 51.77637781415667, 38.11807107925415, 25.751769712993077, 22.285242216927664, 32.02461208615984, 59.5789338520595, 76.11406925746373, 59.56614916665213, 58.30825424194336, 56.1851418358939, 24.512949330466135, 10.166748353413173, 2.2771761161940436, 0.28164522988455637, 0.0779798770589488, 0.27009238409144537, 0.898087780390467, 3.719166168144771, 3.3827016055583954, 7.16167938709259, 9.63108045714242, 9.972009454454694, 13.534329158919197, 12.32322427204677, 12.855564849717275, 11.669502139091492, 11.396053177969796, 18.05088840212141, 13.737669927733284, 18.194314854485647, 32.92049196788243, 32.15439748764038, 40.82569374356951, 47.725404330662315, 50.46639224461147, 57.19385004043579, 58.25768525259835, 58.289410727364675, 55.981750692640034, 55.839059012276785, 54.61666243416922, 57.66801248277937, 59.24466296604702, 55.58362238747733, 52.78113596779959, 57.9112480708531, 56.89008869443621, 61.022303989955354, 61.37577274867466, 57.72871194566999, 56.07218497140067, 56.282996790749685, 60.3842648097447, 61.85701193128313, 43.74520519801548, 31.292734009878977, 48.51610585621425, 45.90458025251116, 34.132876191820415, 37.132135595594136, 47.15336261476789, 50.73276533399309, 57.0234454699925, 58.90419428689139, 57.98669161115374, 54.9318014553615, 48.29884958267212, 46.62432329995291, 54.24075794219971, 57.95541429519653, 57.21945762634277, 57.782445839473176, 54.83779580252511, 53.057097571236746, 56.69130768094744, 56.28715876170567, 57.755108152117046, 54.447341782706125, 50.11948605946132, 39.7536735534668, 37.30852951322283, 31.107290063585552, 25.695768969399587, 32.25603921072823, 17.79489244733538, 19.280045577457972, 7.9979923622948785, 11.909457308905465, 10.535457117216927, 11.260102118764605, 15.830971956253052, 11.936649084091187, 8.31995712007795, 6.617964174066271, 6.465867238385337, 2.961087954895837, 0.3382343447634152, 0.07598697899707726, 0.04560388737757291, 0.06860182421015841, 0.47721503568547113, 5.662346720695496, 18.72283479145595, 36.02807378768921, 36.75518887383597, 29.393982410430908, 15.280629464558192, 17.219449588230678, 33.88014241627285, 30.61779294695173, 36.86659629004342, 46.06661571775164, 50.96217748097011, 36.209383555821006, 8.86873539856502, 0.3291316074984414, 0.058727694409234185, 0.045930391643196344, 0.004268451760123883, 0.04964749129222972, 0.05313276266679168, 0.022893121831917336, 0.03413777193054557, 0.038749913551977704, 0.006291438185144216, 0.061134424193629196, 0.03700990888423153, 0.011002791380243642, 0.026710922863068323, 0.05935247588370528, 0.032227943518332074, 0.01924968564084598, 0.04245256379778896, 0.07572426380855696, 0.07902803724365574, 0.04948761147846069, 0.020195612650630728, 0.02041717299393245, 0.05537150414394481, 0.03946242281900985, 0.030120715698493377, 0.013459891363579248, 0.12096724180238587, 0.01807692098165197, 0.08905570594859974, 0.032783989395414076, 0.00606012178052749, 0.047054062597453594, 0.14436013012060098, 0.018937420432588885, 0.029499479569494724, 0.02182649022766522, 0.04740552677373801, 0.0319133068301848, 0.010621291851358754, 0.04275068833625742, 0.02629916406502681, 0.04995356486844165, 0.07094524667731353, 0.08398189927850451, 0.051130599209240506, 0.041708200704306364, 0.01276985093552087, 0.05793647508003882, 0.00828581502927201, 0.05211170656340463, 0.006243467455663319, 0.06086256235305752, 0.011361504006864769, 0.038391854015312026, 0.005866667629951345, 0.031538965845746655, 0.7821167004959924, 14.813894646508352, 56.459025927952354, 67.23283318110875, 62.37256826673235, 49.054275103977744, 35.21664578574044, 32.30402347019741, 35.16602121080671, 60.17742388589041, 66.62389305659703, 59.66583497183663, 63.912546157836914, 68.62888608660016, 36.625622340611045, 12.387278846332006, 2.137046366930008, 0.1838760689965316, 0.04494149809969323, 0.7161110937595367, 4.739671545369284, 6.469312676361628, 9.293682013239179, 8.732550706182208, 9.34880120413644, 11.612346257482256, 12.141928400312151, 12.530149442808968, 17.504591499056133, 10.792038457734243, 11.771505168506078, 16.175818000520977, 12.275575263159615, 16.484225954328263, 28.430119616644724, 35.20742552621024, 37.28230701174055, 47.258735520499094, 51.047932147979736, 58.36372865949358, 61.35128729684012, 60.445617403302876, 59.8303405216762, 58.364784785679404, 57.100434984479634, 59.90976537976946, 59.764353479657856, 57.371060371398926, 53.02307571683611, 57.12460081917899, 57.41295106070382, 60.6047728402274, 60.496971539088655, 59.257572719029014, 56.61533260345459, 57.86961446489607, 61.399827412196565, 64.0313742501395, 49.45918485096523, 37.015169620513916, 52.720985412597656, 51.35823522295271, 42.134244510105674, 42.96841744014195, 53.329477378300254, 54.231159005846294, 56.74509368624006, 58.988031251089915, 59.75115885053362, 56.732201303754536, 51.25272682734898, 48.47766842160906, 56.28473384039742, 60.16493102482387, 59.91916629246303, 58.65310723440987, 55.99342366627285, 54.57450076511928, 57.3417980330331, 57.51953642708914, 58.58964238848005, 53.51384435381208, 49.369500977652415, 39.286264760153635, 34.88548421859741, 26.001861436026438, 22.273960079465592, 23.0881221975599, 12.881387829780579, 10.679211003439766, 6.936401852539607, 11.27782610484532, 14.672028064727783, 10.692595839500427, 14.406346321105957, 13.820515036582947, 8.967841897691999, 11.230982218469892, 9.239313227789742, 6.267209989683969, 1.6753601751157214, 0.226991812565497, 0.12502311702285493, 0.12791917233594827, 0.6145036774022239, 5.801274648734501, 22.103147302355083, 37.317770617348806, 36.56047255652291, 24.519994803837367, 18.139246906552994, 17.518517426082067, 34.85863637924194, 39.54036038262503, 43.787314755576, 53.70101145335606, 58.27268641335623, 43.44727686473301, 10.721470815794808, 0.40395892943654743, 0.05463747513879623, 0.06815471034497023, 0.03001571918970772, 0.023127521754109433, 0.008788075131763304, 0.06599355595452444, 0.042465014915381155, 0.02532993277002658, 0.039908250860337696, 0.06562562034066234, 0.01211685427863683, 0.03315768237890942, 0.009927954591278518, 0.08785775915852614, 0.04767069825902581, 0.0889422209667308, 0.027514544116067033, 0.05159741433869515, 0.0527813290245831, 0.022149058990180492, 0.0661529777571559, 0.012200424347871115, 0.05186183943546244, 0.06298289607678141, 0.028108277524422322, 0.0360671625073467, 0.028704643648649966, 0.09616452056382384, 0.05920382921716996, 0.11637024847524506, 0.0995635399594903, 0.09806781807648283, 0.18340363220444747, 0.1305912703807865, 0.09283805013235126, 0.17048104133989128, 0.09013756896768298, 0.24490098442350114, 0.1703692866223199, 0.18943005454327377, 0.09427425770887307, 0.08224555530718394, 0.1569853462278843, 0.16241856611200742, 0.1256988700479269, 0.17666895501315594, 0.15461060936961854, 0.20794500889522688, 0.04955226229503751, 0.16840533486434392, 0.05991369898297957, 0.13995954553995812, 0.15521911957434245, 0.12754766084253788, 0.13059793359466962, 0.15506142803600856, 0.954024578843798, 21.151654039110454, 69.01144000462124, 77.70655468532017, 69.2948500769479, 58.18677888597761, 40.00283942903791, 34.25891998835972, 42.79101255961827, 69.86367130279541, 84.30451542990548, 64.78096675872803, 64.61040932791573, 64.82383714403424, 33.16221979686192, 13.186800241470337, 2.848791169268744, 0.4541000888815948, 0.23049755873424665, 1.1023883777005332, 4.908776368413653, 12.479883568627493, 11.07175816808428, 17.78859043121338, 20.50863300051008, 19.58207161085946, 22.49238017627171, 17.943040200642177, 22.68865810121809, 23.62885011945452, 24.268652405057633, 28.918244464056833, 25.411000524248394, 25.878504855292185, 45.66611807686942, 40.949104172842844, 44.4765830039978, 50.7376012802124, 53.24451480593, 62.311431067330496, 64.42314147949219, 62.40217454092843, 62.43947941916329, 62.71754632677351, 59.64447620936802, 63.13287489754813, 62.89471844264439, 57.69667727606637, 53.27973869868687, 57.9409099306379, 56.41828169141497, 62.84072399139404, 62.29123265402657, 60.5392096383231, 55.28052112034389, 56.36619799477713, 62.120821135384695, 66.90685149601528, 54.28946134022304, 42.114059993198936, 57.82005296434675, 54.570522921425955, 47.16508769989014, 48.81661891937256, 54.525244985307964, 56.89148875645229, 58.92756802695138, 61.31172425406319, 63.2987631389073, 59.4248297555106, 52.43483427592686, 50.14167513166155, 59.25004781995501, 62.22647544315883, 62.218158449445454, 60.10441221509661, 56.946039063589915, 56.29252277101789, 60.25746018545968, 60.39134502410889, 62.635599272591726, 58.70717811584473, 54.375952516283306, 45.70470837184361, 42.38275725500924, 35.92757504326956, 32.21949168613979, 43.03375482559204, 25.61853105681283, 30.344016551971436, 18.684131588254655, 23.44158227103097, 21.699027912957327, 18.111245666231426, 26.490755796432495, 24.08051429476057, 19.377070222582134, 17.4423634324755, 14.208350454057966, 7.267365396022797, 1.4866803224597658, 0.2586239480546543, 0.3243621305695602, 0.19309434720448085, 0.8273794374295643, 7.7290849174771985, 25.296284028462, 46.725746154785156, 49.85479096003941, 41.51646280288696, 25.187086139406475, 25.654114518846782, 45.04289593015398, 44.129075799669536, 51.16869878768921, 61.27847017560686, 67.74494321005685, 52.761861664908274, 15.163439410073416, 0.5978538936802319, 0.20679677836596966, 0.14503717236220837, 0.15391828651939118, 0.12091632453458649, 0.1511880380234548, 0.13605412867452416, 0.1310364572065217, 0.11083826103380748, 0.08242497353681497, 0.18488302853490624, 0.1253743538899081, 0.08914317589785371, 0.058885005967957635, 0.16413407905825547, 0.1451783754995891, 0.18821942593370164, 0.10940111707895994, 0.38994932547211647, 0.10743882773177964, 0.13367091012852533, 0.11101392696478538, 0.08842164890042373, 0.15596170829875128, 0.14435782310153755, 0.07026251152689968, 0.12732200723673615, 0.22514982069177286, 0.18348341435194016, 0.16766601667872497], [0.03461723156007273, 0.03142166071172271, 0.05356152215972543, 0.07462661806493998, 0.03498368796759418, 0.003832579099772764, 0.041078350573245964, 0.07004989936415638, 0.01088905449224902, 0.030785445922187397, 0.07240031752735376, 0.02524641189458115, 0.029588679783046246, 0.06205929456544774, 0.018938555282407572, 0.005450585715672267, 0.007496259807209883, 0.031177859686847244, 0.037158738755221875, 0.059931469815117974, 0.027946536828364645, 0.028198010387963483, 0.05047102924436331, 0.06634051805096013, 0.028691751483295645, 0.046444846716310294, 0.03735486590968711, 1.307112489427839, 25.33485868998936, 46.71712344033377, 50.681657859257285, 47.16722774505615, 37.328033106667654, 25.560718570436748, 18.195266757692607, 48.52020876748221, 56.288346903664724, 56.91289963041033, 62.766301836286274, 44.84770713533674, 22.377335378101893, 17.73005359513419, 4.497259318828583, 0.14686106092163495, 0.08439649774559907, 0.12843009563429014, 0.4435005576482841, 3.488732635974884, 3.8033757294927324, 6.744848268372672, 5.291077979973384, 6.269421688147953, 12.882243326732091, 15.881372451782227, 14.397634148597717, 20.001725435256958, 11.790543232645307, 22.43950959614345, 26.989464487348283, 29.427278178078787, 36.87265164511544, 42.472503662109375, 53.84686803817749, 49.50223241533552, 58.16927637372698, 56.74223797661917, 61.13958263397217, 56.058962549482075, 56.67739738736834, 54.45112855093819, 52.62482581819807, 53.41286618368966, 59.261373383658274, 58.43874141148159, 57.61193357195173, 54.25112812859671, 57.5208809035165, 57.834880420139854, 58.888352394104004, 60.51328590938023, 57.285385608673096, 55.143884795052664, 58.35058266775948, 60.13620717184884, 61.73522390638079, 50.15563753673008, 31.261734621865408, 45.400293895176475, 41.9944224357605, 35.78811427525112, 42.03293282645089, 51.778434480939595, 51.82239573342459, 56.61590930393764, 60.131968770708355, 56.04699427740914, 52.46287720543997, 42.60760790961129, 47.52705757958548, 55.19122634615217, 58.563037736075266, 56.20744207927159, 55.37399523598807, 55.53655876432146, 53.28838920593262, 56.45243556158883, 55.65453222819737, 53.247516427721294, 54.6874680519104, 54.76889746529715, 51.199812820979524, 48.63897780009678, 44.12144667761666, 44.675624574933735, 34.7073324067252, 25.98342960221427, 19.609501361846924, 11.47026080744607, 9.941686647278921, 10.867838961737496, 10.931400213922773, 11.493094325065613, 10.0710768699646, 4.319078845637185, 6.00404783657619, 6.262701043060847, 6.597872155053275, 2.054302224091121, 0.30716436196650776, 0.07181480287441186, 0.033150866494647095, 0.17953573832554476, 1.0840648923601424, 6.730877612318311, 24.694580452782766, 47.97214528492519, 40.99476425988333, 48.4154577255249, 82.34786796569824, 69.37250314440045, 44.89794955934797, 33.39660685403006, 38.583596910749165, 51.65611491884504, 48.837289810180664, 24.538803577423096, 2.7836830743721555, 0.09027845997895513, 0.008404180374262589, 0.07500456207032714, 0.04645829528037991, 0.008682195679284632, 0.021101255036358322, 0.007642000647527831, 0.024651078839919398, 0.06767599710396358, 0.025438299901517372, 0.0443985140217202, 0.05819902742015464, 0.05361431896952646, 0.03735583282208868, 0.048184637645525594, 0.044023450397487195, 0.07182972385947194, 0.07693008160484688, 0.04048745853028127, 0.054971711310957155, 0.01576596641513918, 0.03677342585953219, 0.030370501402233328, 0.017258380439930728, 0.03861719210233007, 0.059853648633829186, 0.11413602264864103, 0.03015704107071672, 0.011321109969035854, 0.01878246508671769, 0.05958458235753434, 0.07115718709038836, 0.04815224777641041, 0.025488372393218533, 0.031578867097518275, 0.03688242233225277, 0.043529948485749106, 0.027550621823008572, 0.02804400838379349, 0.035073047636875083, 0.020844003751075695, 0.03489259124866553, 0.017728272725694945, 0.03537117556801864, 0.006172207708004862, 0.04330612013914755, 0.020497776168797697, 0.055026017861174684, 0.05370701363842402, 0.040752056653478315, 0.0747340844411935, 0.05960029722856624, 0.039728917447584014, 0.0600350753271154, 0.09458583420408623, 0.03262407226221902, 1.811131123985563, 31.013187135968888, 56.5800461769104, 61.16082327706473, 56.529310430799214, 46.74793522698538, 30.869164875575475, 20.418073654174805, 42.2960124697004, 55.27177333831787, 65.00729737962995, 71.37039511544364, 58.94274984087263, 33.0661609513419, 16.598648888724192, 4.26692089012691, 0.3247782082429954, 0.18052684728588375, 0.4686462240559714, 1.919124151979174, 7.181882577283042, 8.169337545122419, 12.385673812457494, 6.865200621741159, 10.307457191603524, 16.424198729651316, 14.07773300579616, 15.201883792877197, 17.732108524867467, 10.989250915391104, 11.665550351142883, 19.684046847479685, 25.7729651927948, 32.0559276172093, 38.45258862631661, 47.00379221779959, 50.60707589558193, 58.32531206948416, 58.01321635927473, 62.318754468645366, 58.840382031032014, 58.90541022164481, 56.33603239059448, 55.160991259983604, 56.21951110022408, 59.335712160382954, 60.61416680472237, 57.052131107875276, 56.23092351640974, 57.17872033800398, 56.29337739944458, 58.43914440699986, 62.215601512363975, 58.24736022949219, 55.47712734767369, 58.02598367418562, 60.46783774239676, 63.36936378479004, 54.5991599219186, 35.43540981837681, 49.26056364604405, 48.019337449754985, 41.45307786124093, 48.38669913155692, 55.881154673440115, 54.776901790073936, 56.75381367547171, 59.53891222817557, 58.41801493508475, 55.080781255449565, 45.72184262956892, 49.80340903145926, 58.36031709398542, 60.61398615155901, 58.7502361025129, 55.02840920857021, 56.187709195273264, 54.613226549965994, 56.376964228493826, 56.92423561641148, 55.5454455103193, 56.62373297555106, 56.49070971352713, 51.939997468675884, 46.49627842221941, 41.04294654301235, 34.37485415594918, 28.588708775384085, 23.298438957759313, 16.48859463419233, 10.217150585991995, 8.664948207991463, 10.984084061213903, 13.297829849379402, 15.85973402432033, 14.634240286690847, 12.876602258001055, 9.852320654051644, 8.484500885009766, 10.183174763407026, 3.51605338709695, 1.0684507702078139, 0.3191542928772313, 0.09194614299173866, 0.19526590353676251, 1.1178367201771056, 7.55494829586574, 24.78688379696437, 43.6259115764073, 39.24731315885271, 27.38633516856602, 62.04561383383614, 69.65060479300362, 50.6058669090271, 41.74251202174595, 43.93479721886771, 59.756015641348704, 55.95116124834333, 29.548145566667827, 3.1414340947355543, 0.05077775760686823, 0.07222918421030045, 0.05190081448693361, 0.03085817809083632, 0.03360451465206487, 0.03180935187265277, 0.03903544108782496, 0.028335574881306717, 0.019787950507764305, 0.03104077186435461, 0.06631033681333065, 0.04854249022901058, 0.03642696927168539, 0.023453208385035396, 0.05142788914963603, 0.03503626086083906, 0.0482206271429147, 0.08433935152632849, 0.0574145730850952, 0.04567326419055462, 0.02270219904104514, 0.06329509003886155, 0.02228384488262236, 0.015496433646019016, 0.061996523290872574, 0.049126841194395504, 0.08785681599485022, 0.03357679649655308, 0.027174733778727905, 0.15057696295636042, 0.148220940093909, 0.12089651131204196, 0.13200054690241814, 0.13605520075985364, 0.0612333206725972, 0.15940420143306255, 0.18616060140941823, 0.1258913432913167, 0.12429203625236239, 0.1503587868064642, 0.1599427546773638, 0.09166809291179691, 0.1552526392042637, 0.19144162588885852, 0.06450688572866575, 0.12047223693558148, 0.11507951202137129, 0.09189141914248466, 0.12212570463972432, 0.10636757700038807, 0.12329781960163798, 0.15320482051798276, 0.16064416989684105, 0.13767817510025843, 0.15577116209481442, 0.13949345983564854, 2.951229763882501, 40.28254263741629, 67.43399742671421, 74.31476375034877, 65.5172951562064, 55.0470095361982, 37.406412260872976, 29.66364199774606, 60.05362088339669, 65.22526236942836, 64.31834874834333, 70.06557900565011, 51.009651047842844, 31.173242364610942, 21.90528518812997, 5.667995171887534, 0.33076424417751177, 0.28704699288521496, 0.28938720588173183, 3.0779062807559967, 12.081530315535408, 13.048982722418648, 20.28822919300624, 13.681467686380659, 14.647660732269287, 22.904559476034983, 23.659889459609985, 22.647132192339214, 33.166274070739746, 24.393704346248082, 37.36253438677107, 33.80905539648873, 35.64249045508248, 40.39165019989014, 45.47387531825474, 58.77887657710484, 52.379401547568186, 60.809306962149485, 59.299088205610005, 65.59195355006626, 60.41894326891218, 62.01176915849958, 59.332932880946565, 59.70197950090681, 58.88776874542236, 62.71132074083601, 61.49234962463379, 59.917922564915244, 57.16100590569632, 58.76452854701451, 57.503864765167236, 60.28780991690499, 63.6979649407523, 58.517374174935476, 56.72526700156075, 58.20202323368618, 61.61813286372593, 65.23205770765031, 58.15140560695103, 42.24669415610177, 54.85122319630214, 49.44231115068708, 46.40444755554199, 52.4826899937221, 57.43921177727835, 57.246093545641216, 58.06560230255127, 62.04947008405413, 62.08913040161133, 56.602071966443745, 45.845107146671836, 49.90408148084368, 61.08303819383894, 62.98265484401158, 58.23472840445382, 56.45438800539289, 57.500630378723145, 55.618547507694785, 60.38649518149239, 59.966837882995605, 59.18162196023123, 58.34800488608224, 60.231216839381624, 54.19384370531355, 51.224287850516184, 48.757659980228965, 49.38414430618286, 40.89949403490339, 33.59578044073922, 27.577219554356166, 18.28418459211077, 22.95697147505624, 20.978768961770193, 22.554787158966064, 20.985567774091447, 18.372100148882183, 14.611339024135045, 15.952654021126882, 16.647050040108816, 16.381205013820104, 6.396223272596087, 1.100192095552172, 0.2870887635009629, 0.25776391848921776, 0.438352783875806, 1.5751161256006785, 8.626486454691205, 30.61038269315447, 61.13708128247942, 54.92371722630092, 60.32152257646833, 90.0258150100708, 76.65168612343925, 53.85719306128365, 45.24719728742327, 51.844383307865684, 67.168534551348, 66.05874742780412, 35.918007373809814, 4.37290176323482, 0.1670686887311084, 0.1302289462515286, 0.14363082711185726, 0.12284071770097528, 0.09391929568456751, 0.10633820321943079, 0.16542273919497216, 0.17128389754465648, 0.09669417142868042, 0.05934895428695849, 0.11652762788747038, 0.12983568092542036, 0.11493365413376264, 0.1275199901844774, 0.10934623716665165, 0.13629371938960894, 0.10084739606827497, 0.1676804016211203, 0.15266382454761437, 0.1547542688037668, 0.11690596544316836, 0.1451502570084163, 0.09442413252379213, 0.09091974342507975, 0.10417440254241228, 0.23117340675422124, 0.15863044080989702, 0.1599886914981263, 0.15439057403377124], [0.05358180017875774, 0.04073893039354256, 0.05862421103354011, 0.021524971317765967, 0.007984877963151251, 0.028994194897157804, 0.01857317265655313, 0.06269532615052802, 0.015072976904256003, 0.016865277962226952, 0.03198767766090376, 0.0566801030321845, 0.04027878526332123, 0.04870324535295367, 0.05433897062071732, 0.021838612255773375, 0.028493327487792288, 0.03296031689803515, 0.07144471630454063, 0.03688102115743926, 0.06859548669308424, 0.03598153138799327, 0.04401668879602637, 0.06694305714751993, 0.03427015072000878, 0.1376501108918871, 0.057987114148480554, 6.558562287262507, 39.83007941927229, 48.22601161684309, 52.25370168685913, 45.58995887211391, 37.251147815159385, 33.35284015110561, 40.37068053654262, 47.15088210787092, 36.88199002402169, 37.07078300203596, 23.683120761598857, 22.661283935819352, 27.374319996152604, 8.26091480255127, 0.556869238615036, 0.08727069066039153, 0.16810278967022896, 0.32219727816326277, 1.2606092819145747, 5.191553286143711, 6.40976357460022, 11.089594193867274, 7.679711886814662, 7.256805002689362, 12.569494485855103, 10.525134699685232, 19.552414962223597, 22.696995939527238, 15.562359809875488, 21.146012101854595, 41.67166471481323, 36.90669434411185, 43.95460653305054, 51.96046686172485, 55.61527490615845, 54.545853342328755, 57.27106537137713, 59.94807079860142, 57.437311444963726, 54.755140032087056, 54.371074880872456, 50.50829683031355, 52.33464820044381, 55.32068518229893, 57.110169410705566, 56.15980175563267, 52.38808332170759, 53.78616510118757, 54.24373524529593, 53.35636690684727, 58.89709322793143, 62.52539389474051, 57.525206157139365, 57.702722208840505, 57.2266594341823, 58.752153805324006, 61.65458311353411, 52.573791299547466, 33.68788228716169, 38.27880375725882, 42.181290762765066, 38.858533654894146, 44.82903037752424, 54.28996161052159, 53.3048529624939, 59.23017597198486, 61.30943134852818, 56.314777851104736, 51.195584842136924, 42.42190340587071, 50.064143657684326, 54.74323776790074, 57.52300705228533, 54.28928068705967, 54.249974727630615, 53.31755774361746, 53.2898587499346, 53.96860047749111, 53.49347570964268, 51.592104639325825, 51.98136704308646, 51.78497273581368, 54.94634403501238, 55.29928820473807, 47.01171316419329, 43.34005226407732, 38.95326886858259, 30.032699040004186, 24.434212344033376, 18.628057888575963, 16.581373929977417, 19.746406929833547, 9.373285787446157, 13.729692527226039, 13.22906700202397, 7.958804522241865, 9.21085340636117, 7.564089519636972, 7.817833389554705, 4.981289505958557, 1.6129857621022632, 0.4694779451404299, 0.16404990000384195, 0.01918567773619933, 0.34298471414617127, 1.6940481151853288, 11.182113800730024, 32.1865884917123, 46.29730633326939, 66.22918673924038, 74.06173120226178, 52.908722264426096, 36.28191580091204, 32.179886954171316, 38.4102463041033, 47.68676539829799, 52.02497741154262, 36.96980135781424, 6.7712449090821405, 0.6856984485472951, 0.046913266581084044, 0.022179506552804793, 0.023343071973483478, 0.018628795564706837, 0.0640417839001332, 0.03680360031181148, 0.04965908745569842, 0.021106274499158775, 0.005648937192745507, 0.007691163054135228, 0.04425160440483263, 0.039824143052101135, 0.04011105140671134, 0.04203020967543125, 0.03571062967447298, 0.09398924585963998, 0.04188482676233564, 0.09959057279463325, 0.030507799570581744, 0.08936564038906779, 0.038905932501490624, 0.034329909299101145, 0.06735806952097587, 0.0611340713554195, 0.10563021978097302, 0.02444356756417879, 0.04135217677269663, 0.037955854553729296, 0.005658578327191728, 0.03737240603991917, 0.01643372460135392, 0.033185006984110386, 0.011903709465903895, 0.037345213749046834, 0.03045493151460375, 0.04612208117863961, 0.027317266844745194, 0.0577765375907932, 0.09093884418585471, 0.02226473224748458, 0.012376801892449813, 0.006979859034929956, 0.02464484649577311, 0.019489729278055683, 0.05204491496884397, 0.025665905991835252, 0.041917484652783187, 0.03198998807264226, 0.0637963442131877, 0.0584686365244644, 0.019352880639157126, 0.10273600329778024, 0.029230345439698015, 0.09293568453618459, 0.07534638765667166, 8.715897611209325, 47.703479290008545, 57.49475915091378, 62.96290806361607, 53.296852111816406, 45.90596989222935, 36.59487656184605, 40.82793801171439, 52.34368085861206, 47.32338850838797, 49.433889933994834, 36.897046770368306, 27.856000389371598, 22.236813272748673, 8.310039435114179, 0.7812809624842235, 0.0967095945296543, 0.480415766792638, 2.01461780497006, 6.018650778702327, 8.437122855867658, 13.777157408850533, 17.58419006211417, 15.922179222106934, 8.339536275182452, 10.493324978010994, 14.492099251065936, 15.106795958110265, 14.401261976787023, 14.678392614637103, 24.34712709699358, 31.358665466308594, 35.73251131602696, 43.036339555467876, 52.49713182449341, 54.513676234654014, 56.0851468358721, 56.2163461957659, 61.21467181614467, 59.96913078853062, 57.511118684496196, 55.013345514025005, 52.689607347760884, 55.24642630985805, 57.12940897260393, 59.33528137207031, 56.923711027417866, 53.8852915763855, 54.609273024967735, 54.92815017700195, 54.7332775252206, 58.03487042018345, 62.35903317587716, 57.6898124558585, 59.63891070229666, 56.79385961805071, 59.81271294185093, 60.99951389857701, 55.815546308244976, 37.509322030203684, 43.01796504429409, 48.43455137525286, 43.70168168204171, 51.36118125915527, 57.50031076158796, 56.062134402138845, 59.233941895621165, 60.47404943193708, 56.913934912000386, 53.1485914502825, 44.69902263368879, 51.684029306684224, 57.914770807538716, 60.29699543544224, 54.26100846699306, 54.557112898145405, 54.025725092206685, 54.81446375165667, 55.948444502694265, 55.525782108306885, 52.361478669302805, 54.069807938167024, 53.8059709412711, 57.475849628448486, 57.350924491882324, 49.70133304595947, 44.102405139378135, 37.89713226045881, 28.133059808186122, 23.135694776262554, 17.20315953663417, 12.542748263904027, 10.37185309614454, 14.298550231116158, 14.40966408593314, 13.278686693736486, 13.21236092703683, 11.655815056392125, 11.543797067233495, 9.029929263251168, 5.918546778815133, 4.13960166488375, 1.5953716444117683, 0.2900429421237537, 0.1404418075191123, 0.10849145946225949, 1.8127101021153587, 10.932341694831848, 35.45316593987601, 41.511473996298655, 64.51138360159737, 87.00291088649205, 66.6718008858817, 43.22299943651472, 37.75529520852225, 43.11147737503052, 55.2839743750436, 59.01237773895264, 44.829951013837544, 9.994216765676226, 0.8766369000077248, 0.046913436214838705, 0.031601503025740385, 0.05479669677359717, 0.07028942901108946, 0.052026462209011824, 0.057895355857908726, 0.05878959037363529, 0.0549794228614441, 0.042432262030031, 0.018010736675933003, 0.02122977126522788, 0.04525715937571866, 0.041737761082393784, 0.007900173892267048, 0.02408320949013744, 0.03548553925273674, 0.04283430081393037, 0.03367843086432133, 0.0646497919889433, 0.04749197552778891, 0.044572799133935144, 0.03970700755183186, 0.07947912732405321, 0.09217955225280353, 0.10314049159309693, 0.0353292760306171, 0.041656872922820706, 0.05862927969012942, 0.16488069828067506, 0.08256034127303533, 0.11605312834892954, 0.12846297744129384, 0.07061086462012359, 0.1160622885716813, 0.10667909242744956, 0.13350063855094568, 0.11953542434743472, 0.16207062692514487, 0.14225621015897819, 0.10040985633219991, 0.13549116174025194, 0.15724306739866734, 0.13623445614108018, 0.09947827524904694, 0.14724988862872124, 0.16767092927226, 0.14991908254367964, 0.13857088291219302, 0.1653223160122122, 0.11264843640050717, 0.08855181905840125, 0.1365814996617181, 0.11258390772023372, 0.23198018489139421, 0.3447659228529249, 13.687073145593915, 57.752294131687705, 69.36592320033482, 70.90501172201974, 64.5311164855957, 52.506828035627095, 49.379423005240305, 53.60626234327044, 59.31935610089983, 47.802709988185335, 46.191002368927, 33.6251608984811, 32.758307116372244, 33.6849536214556, 9.64726802280971, 0.7585317460553986, 0.3074592261442116, 0.31256501216973576, 1.6357082171099526, 5.052550230707441, 16.552153280803136, 20.34200303895133, 20.484625237328665, 22.865296942847117, 15.191423279898506, 19.980498688561575, 20.6629125390734, 30.598181656428746, 36.65003483636038, 24.58849014554705, 27.692960909434728, 48.41195583343506, 38.23899752753121, 46.82558829443795, 55.220426150730674, 55.74339968817574, 54.55766527993338, 57.31870916911534, 62.91852297101702, 62.66827665056501, 59.958270754132954, 59.225624901907786, 54.99440472466605, 59.058715275355745, 59.53853007725307, 61.81336334773472, 57.22272675377982, 53.78399726322719, 55.13753761563982, 54.587424414498464, 56.005812304360525, 61.26383032117571, 65.55716391972133, 59.55030032566616, 60.620225633893696, 58.617970194135395, 60.169391768319265, 62.09457778930664, 57.73966230664934, 43.466238498687744, 47.618541036333355, 49.64026880264282, 49.81789255142212, 54.335708550044465, 58.59593745640346, 59.53274917602539, 60.55223056248256, 64.0083201272147, 60.80971690586635, 54.9516316141401, 45.93640300205776, 53.41417244502476, 60.37723323277065, 60.62180287497384, 54.92716005870274, 55.613009793417795, 55.15288271222796, 55.37686136790684, 56.42299257005964, 56.05106592178345, 55.04947962079729, 57.143312317984446, 56.67325278690883, 60.03302642277309, 60.05735206604004, 51.16460977281843, 46.643413475581575, 39.64410393578665, 32.18526138578142, 29.072496209825786, 25.34857095990862, 21.754945278167725, 28.449173314230784, 16.45661555017744, 23.433709962027415, 25.77520772389003, 16.665170942034038, 17.436200380325317, 18.5631582396371, 16.815156493868145, 7.724059632846287, 4.119009375572205, 2.33933795775686, 0.47121222636529375, 0.19399531957294258, 0.6476049497723579, 2.415304567132677, 13.633600677762713, 40.12224074772426, 60.006567682538716, 75.2130685533796, 77.38622188568115, 58.769843918936594, 44.18033613477434, 45.42898995535714, 51.43413039616176, 63.54195703778948, 66.48459557124546, 54.774688788822715, 14.781634160450526, 1.0180466920137405, 0.06321738420852593, 0.21032612398266792, 0.18022005446255207, 0.24463453729237827, 0.17135396307068212, 0.12427748846156256, 0.16391039320400783, 0.24582995314683231, 0.17186648771166801, 0.15675800985523633, 0.08080372267535754, 0.14942130925399916, 0.18334647241447652, 0.13020301264311585, 0.149515069222876, 0.2063140007002013, 0.18675087259284087, 0.13651574961841106, 0.11623318440147809, 0.22850098301257404, 0.07372472288885287, 0.20497966158602918, 0.19171939098409244, 0.13091894851199218, 0.2013376791562353, 0.16832434492451803, 0.18572287846888813, 0.1533676960638591], [0.052554599940776825, 0.03999803800668035, 0.015006533058892404, 0.03446103958413005, 0.011401747070652033, 0.030322037038526366, 0.044693076251340766, 0.037731286603957415, 0.012663297188867415, 0.0772409320675901, 0.04214629005374653, 0.03679317122857485, 0.040797929013414044, 0.05459749585549746, 0.052948584514004846, 0.043801783184920035, 0.01892151726808931, 0.16242953123790876, 0.047333442606031895, 0.03737953065761498, 0.01991989164214049, 0.03005632272522364, 0.019056773046031594, 0.044027477502822876, 0.059579839397753985, 0.07053006467010293, 0.11072801266397748, 20.668443305151804, 48.618588311331614, 48.01901088442121, 47.576959541865754, 41.974439416612896, 28.75707404954093, 30.266665731157573, 33.55991036551339, 33.39829526628767, 42.77587243488857, 28.25947185925075, 35.79057393755232, 35.21845579147339, 14.188622781208583, 1.712095843894141, 0.10900386196694203, 0.05883404120270695, 0.7981481488261903, 3.968518776553018, 4.460711794240134, 6.393868267536163, 9.509550384112767, 13.751377855028425, 6.603568809373038, 6.661328749997275, 16.117936032158987, 17.026725666863577, 22.12440184184483, 26.717183692114695, 31.454790319715226, 38.04333278111049, 38.76900264195034, 55.86028923307146, 56.11517347608294, 57.92204557146345, 54.758412633623394, 56.50299760273525, 58.76311111450195, 59.90287276676723, 54.94257116317749, 54.17113699231829, 48.361605712345664, 49.904362882886616, 51.382963861737935, 55.581829752240864, 56.63176161902291, 55.90834297452654, 54.959861755371094, 53.49216944830758, 53.55451563426426, 54.77533844539097, 59.917630740574424, 58.02353096008301, 54.32860401698521, 55.69256666728428, 60.04936858585903, 58.2807081086295, 58.57777486528669, 52.95965950829642, 42.19592366899763, 28.2786853654044, 37.856454031808035, 41.81078849520002, 47.65712090900966, 53.191204752240864, 54.84815556662423, 55.14071989059448, 58.31924629211426, 55.00603253500802, 49.56755937848772, 39.92606183460781, 49.94271693910871, 56.76858901977539, 56.844036034175325, 52.699341773986816, 54.55986091068813, 51.85198811122349, 53.59180661610195, 56.08701590129307, 54.502388886043, 47.57324225561959, 48.884409018925254, 49.388907296316965, 53.84575980050223, 51.50122914995466, 58.38186345781599, 51.55315998622349, 49.931870801108225, 43.93773283277239, 38.2457720211574, 25.356406790869578, 21.252894503729685, 15.345027106148855, 24.762349707739695, 20.30018183163234, 14.319699679102216, 19.663000753947667, 10.801124964441572, 6.818516543933323, 7.299428292683192, 3.41537464090756, 2.9179296536105017, 1.0028252516474043, 0.32463153611336437, 0.22367490269243717, 0.019471198486696397, 0.23691769423229353, 2.545541384390422, 16.390703201293945, 35.943722656794954, 27.66752702849252, 23.413409062794276, 16.5564090524401, 21.99921441078186, 30.024236134120397, 37.174332005637034, 46.868503843035015, 42.0594436781747, 43.915449959891184, 17.04989617211478, 1.6544649877718516, 0.10113338500793491, 0.011196825254176344, 0.06279595289379358, 0.01342100536982928, 0.07738204699541841, 0.025113865167700818, 0.08042106963694096, 0.04393024682732565, 0.10698846368385212, 0.027884094643273523, 0.023936145506533127, 0.008601220158327903, 0.08610677918685333, 0.020865401352888772, 0.037740602889763455, 0.06121857610664197, 0.042594045134527345, 0.006022941878265036, 0.07334739635033266, 0.049724291278315444, 0.04495667692806039, 0.03826891364795821, 0.003450004304925512, 0.05850324859576566, 0.012616323905863931, 0.056835477373429706, 0.027295036341196725, 0.03925061132758856, 0.031930012362343926, 0.04273206933534571, 0.04651600129104086, 0.05632327842925276, 0.03426180473927941, 0.06161704579634326, 0.027319926702018296, 0.03400294702234013, 0.024239995184221437, 0.02384868573530444, 0.029406472774488584, 0.03120964565979583, 0.02355294455108898, 0.024744046619161963, 0.020354852945144688, 0.03450857096218637, 0.05489448045513459, 0.16184175706335477, 0.006082294184514987, 0.04263149008953145, 0.06255752247359071, 0.03224300699574607, 0.047485909424722195, 0.041915913844215016, 0.011124696133525243, 0.0569205249526671, 0.3877777691398348, 25.86827710696629, 58.12834800992693, 60.34762001037598, 58.93949808393206, 50.05459335872105, 37.55927610397339, 39.24672256197248, 41.55584519250052, 39.10601806640625, 36.57743658338274, 31.88246931348528, 29.155044283185685, 25.762122528893606, 14.382453203201294, 2.099873504468373, 0.07421445553856236, 0.18909973012549536, 1.6587151139974594, 6.272432429449899, 8.260440587997437, 12.305046047483172, 12.120840617588588, 12.062705039978027, 12.689346568925039, 9.190462180546351, 9.377662284033638, 13.131307584898812, 17.23081684112549, 21.776588916778564, 25.271756887435913, 34.568368434906006, 41.71875613076346, 51.17945459910801, 56.108294759477886, 56.604205063411165, 55.91299826758248, 56.02002484457833, 59.672185625348774, 59.20537090301514, 57.31360224315098, 56.09431845801217, 51.654857294900076, 51.3845272064209, 52.95318726130894, 57.9551294190543, 58.17749261856079, 56.989215169634136, 55.65898949759347, 54.428147384098594, 52.798982415880474, 56.34752123696463, 60.619134766714915, 59.42963790893555, 56.23981373650687, 57.04284484045846, 59.567886216299875, 57.70197875159127, 58.1897040775844, 56.13835266658238, 43.45816816602434, 34.65411267961775, 46.42817217963082, 46.26348945072719, 53.86408914838518, 55.32673011507307, 56.80608149937221, 55.19654171807425, 59.95890304020473, 57.66769633974348, 53.537436962127686, 42.777154377528596, 52.437804630824495, 57.74242768968855, 57.82603536333357, 53.539055892399375, 54.047591073172434, 51.47881426130022, 54.82921477726528, 57.387378215789795, 54.78280775887625, 51.07557208197457, 51.760984080178396, 52.94331387111119, 54.081001486097065, 54.2050963129316, 58.75594752175467, 51.87456280844552, 47.15668037959507, 43.10295193535941, 36.32055473327637, 26.89354807989938, 21.30715298652649, 14.571393830435616, 13.786854488509041, 14.971700395856585, 14.950466700962611, 14.963656118937902, 12.530458637646266, 11.122871722493853, 14.308427095413208, 10.65392564024244, 6.279931707041604, 3.208981224468776, 0.770436127270971, 0.341759089912687, 0.17014005035161972, 0.13153927879674093, 3.161602326801845, 17.119251353400095, 39.843746525900706, 39.15643072128296, 33.2682249886649, 22.701272555759974, 24.742097445896693, 36.86419916152954, 43.72633389064244, 53.700254099709646, 50.24571050916399, 51.93003722599575, 22.536463022232056, 2.3860522168023244, 0.0800202793574759, 0.041968744580766985, 0.022499598662502, 0.017851579501958828, 0.02187690877222589, 0.038682735192456415, 0.06739073419677359, 0.018949147214048674, 0.0559430715095784, 0.04166960223977055, 0.061991990676948, 0.04383324346105967, 0.06415883119085006, 0.04684438170599086, 0.008208456948133451, 0.07351787827376809, 0.03399983933195472, 0.0467948588276548, 0.046585530774401765, 0.035088972853762765, 0.03245332231745124, 0.04753797680937818, 0.03753493892561112, 0.07710463473839418, 0.05520389920898846, 0.042540274626974545, 0.01927986857481301, 0.007950483871224736, 0.2055970063166959, 0.12916733750275203, 0.14480584620365075, 0.1049115765573723, 0.15881627798080444, 0.12846474163234234, 0.1595576996249812, 0.12784701692206518, 0.1394669698285205, 0.12902092321642808, 0.1057431890762278, 0.12549627306205885, 0.10161145364067384, 0.17193550829376492, 0.12491829693317413, 0.14542392375213758, 0.09692198956119162, 0.26533037104776924, 0.16252080776861735, 0.19879048583762987, 0.24463784854326928, 0.12499590776860714, 0.13658814930490085, 0.1449799175773348, 0.13682019471057824, 0.2017007361033133, 1.0741325510399682, 34.18189573287964, 68.86140060424805, 70.31208024706159, 67.07905564989362, 58.12305695669991, 42.36064461299351, 43.73417493275234, 45.31862129483904, 42.85691622325352, 52.75841883250645, 41.174691336495535, 47.86528546469552, 41.71184614726475, 16.881471838269913, 2.3368131560938696, 0.33530942457062857, 0.3390728511980602, 2.119050315448216, 7.830753564834595, 13.29692484651293, 15.120723622185842, 19.870724099023, 24.979942968913488, 14.189482620784215, 16.860448326383317, 26.82313677242824, 27.602521419525146, 33.82440396717617, 32.73268215996878, 36.23519958768572, 41.066858768463135, 44.148506437029155, 56.67608765193394, 58.35920538221087, 58.738167081560405, 56.134423460279194, 56.14384521756853, 62.2486332484654, 63.914484705243794, 61.12793745313372, 58.278898102896555, 53.966384002140586, 54.05886105128697, 56.7743421282087, 60.24266052246094, 61.900507654462544, 58.16977664402553, 56.868955748421804, 54.603724888392854, 53.69096435819353, 56.91184350422451, 64.38464151109967, 61.85589327130999, 59.02273750305176, 58.05325535365513, 61.48879909515381, 58.92440659659249, 59.82294763837542, 55.91418988364083, 48.22629301888602, 38.068638120378765, 49.55262769971575, 51.11114338466099, 56.66077034814017, 55.44886554990496, 57.709041595458984, 57.18703038351876, 60.80518668038504, 59.44915539877755, 54.3206969669887, 43.05015952246529, 54.35600076402937, 60.431269373212544, 60.122811044965474, 52.747301714760916, 54.71599735532488, 51.67431225095476, 55.511840547834126, 59.29421057019915, 58.22845765522548, 52.77284329278128, 54.859783376966206, 55.398147174290244, 57.623940059116904, 56.292866706848145, 62.91247803824288, 53.6929862839835, 52.886296953473774, 49.179436479296, 43.05218839645386, 29.12435930115836, 27.77270017351423, 21.361380202429636, 33.49145323889596, 32.092419556209016, 23.58319698061262, 28.916875668934413, 21.92312295096261, 15.842948913574219, 20.58767397063119, 15.617248841694423, 9.078083753585815, 2.4965305285794392, 0.766805422093187, 0.6227060258388519, 0.24931819311210088, 0.44271285991583553, 3.213016825062888, 20.587887627737864, 45.75093821116856, 38.17583840233939, 31.989770344325475, 25.73757106917245, 31.767070157187327, 41.318376609257285, 49.09931680134365, 61.271577562604634, 58.965845652988975, 61.4635979788644, 31.11902904510498, 3.47205913066864, 0.20844054301934584, 0.13989915592329843, 0.11622801396463599, 0.10580370761454105, 0.1649522701544421, 0.2561282419732639, 0.09791576516415391, 0.11784778561975275, 0.21102435008755752, 0.22554953210055828, 0.10059190727770329, 0.10128545149096421, 0.164417760978852, 0.13338311628571578, 0.11787799399878297, 0.1498972201453788, 0.13463874533772469, 0.1661429362637656, 0.11156448349356651, 0.12074899779898779, 0.15582425067467348, 0.15278688365859644, 0.13025797397962638, 0.2665746142821652, 0.17375281506351062, 0.13395269215106964, 0.0914731565862894, 0.09195040419165577], [0.030718043646109954, 0.0689088748767972, 0.06239470121051584, 0.03828616540080734, 0.02241566388069519, 0.04090688477403351, 0.014167758602915066, 0.00461723784350657, 0.05141552284892116, 0.026450624955551963, 0.00894283879149173, 0.026053357969171236, 0.04111320013180375, 0.0386049784719944, 0.02592331842918481, 0.043379873502999544, 0.05032227401222501, 0.033126466375376494, 0.05191891101588096, 0.07994028007877724, 0.00576059945992061, 0.03746860194951296, 0.03323627369744437, 0.07851407410843031, 0.0850996228733233, 0.24048838977302822, 3.974694856575557, 38.24442754473005, 44.331560203007285, 43.7685580934797, 39.912759508405415, 30.701101848057338, 32.75755671092442, 35.75740671157837, 37.557351452963694, 46.32778460638863, 47.04556826182774, 34.931241580418174, 35.614110537937705, 22.297061102730886, 4.17176878452301, 0.3721856586635113, 0.09689145548535244, 0.05139952977853162, 1.3953713306358881, 3.1500144686017717, 7.825046488216945, 8.39725148677826, 11.224306736673627, 17.17815296990531, 17.655129432678223, 9.818532432828631, 9.71234485081264, 25.132016454424175, 29.431304659162247, 34.60918910162789, 33.70741714750017, 54.20598915645054, 51.49038301195417, 56.555953298296245, 56.31586177008492, 60.909395762852256, 55.50706366130284, 58.037180696214946, 57.45851387296404, 54.23592894417899, 53.2846337045942, 48.07347086497715, 49.0363313811166, 52.901690687452046, 53.574283259255544, 56.5018059866769, 55.2009642464774, 54.908333914620535, 53.2212279183524, 54.789002077920095, 51.667617661612375, 55.756059306008474, 56.86608266830444, 54.08590344020298, 52.831406184605186, 55.819260120391846, 57.621292795453755, 58.12883785792759, 59.719287463596885, 53.360177993774414, 46.7247907774789, 22.193157741001674, 29.49057626724243, 44.98143911361694, 45.584525380815776, 52.83869137082781, 53.66820205960955, 57.53185905729021, 57.234139169965474, 54.32913555417742, 47.88220085416521, 41.85321419579642, 46.53184625080654, 54.21686656134469, 55.28055933543614, 54.847064699445454, 51.14137152263096, 50.49406691959926, 49.66808591570173, 53.89798246111189, 53.31724854878017, 51.67456933430263, 48.35514041355678, 46.72976916176932, 51.01169729232788, 51.674287932259695, 51.22886323928833, 53.02214813232422, 54.01260689326695, 46.230537618909565, 44.90382773535592, 41.42697695323399, 31.94857794897897, 21.418744529996598, 22.10391855239868, 16.493585177830287, 13.427663888250079, 10.9370082787105, 9.726952569825308, 12.139648522649493, 7.380634495190211, 8.205325739724294, 6.5816633105278015, 3.7573990651539395, 0.6440310786877359, 0.13569925485977105, 0.017812563738386546, 0.03810562080304537, 0.47389309108257294, 4.845879971981049, 22.21917700767517, 34.23575816835676, 36.546715123312815, 41.28649827412197, 24.669817073004587, 12.037402306284223, 22.24636357171195, 38.48698568344116, 40.33355631147112, 45.780516692570274, 27.69857852799552, 5.76089562688555, 0.16500215604901314, 0.034967932384461164, 0.04429701536095568, 0.1014582065067121, 0.02559009666687676, 0.07625525138740029, 0.03220099210739136, 0.027443576138466597, 0.08141696226916142, 0.046819157166672606, 0.033093282620289495, 0.020883350300469568, 0.02707841234015567, 0.07492593343236617, 0.06425676415009157, 0.06988283725721495, 0.07830968579011303, 0.02850347837167127, 0.028462006311331476, 0.041508195722209554, 0.05215620488992759, 0.07169814913400582, 0.0347371829806694, 0.011908259043203933, 0.04137840215116739, 0.05554163662184562, 0.03043871113498296, 0.033369259775749276, 0.033895036205649376, 0.0968231473650251, 0.06322025441165481, 0.013848345028236508, 0.05220328504219651, 0.02831364971851664, 0.02284869984058397, 0.012154706354652132, 0.05007394376610007, 0.04811251615839345, 0.011738270753994584, 0.02863519898216639, 0.021574497588777115, 0.012163830954315407, 0.05246078908177359, 0.06118846272251435, 0.0635528112096446, 0.03230170027485915, 0.03507683725495424, 0.0478496279434434, 0.023751986013459306, 0.05535081900390131, 0.0473044725534107, 0.07115463579871825, 0.04839983502668994, 0.22448082587548665, 4.480955805097308, 45.2554725919451, 56.38443354197911, 55.91423852103097, 48.090132645198274, 40.44541188648769, 37.391181809561594, 37.41048737934658, 37.28861250196184, 49.22895976475307, 54.3727320262364, 34.224123409816194, 39.36977515901838, 20.511949028287614, 3.9712398648262024, 0.4671405277081898, 0.11176752152719668, 1.14411241880485, 3.493553165878568, 7.918971368244716, 11.703768048967634, 12.94509586266109, 12.502064824104309, 19.290334122521536, 9.385086434228079, 12.654471823147365, 13.666304111480713, 19.24440131868635, 24.604272978646414, 32.527335098811555, 36.17559099197388, 47.3525778906686, 49.59760338919503, 58.88924871172224, 56.510668413979666, 59.50865282331194, 55.459503241947715, 58.0880970954895, 59.629711287362234, 56.17343759536743, 54.630180154527935, 51.45862627029419, 50.74964598246983, 54.60762282780239, 54.46979488645281, 57.21814094270979, 56.205906527382986, 56.09862286703927, 53.78763117109026, 55.52001510347639, 54.0080349785941, 56.12263931546892, 58.39615590231759, 55.74786390577044, 54.777655669621055, 57.29208714621407, 59.30559171949114, 60.29867689950125, 58.637202807835166, 56.66163192476545, 46.82507412774222, 29.724348408835276, 37.49405683789934, 47.75310679844448, 51.06487185614449, 54.07863562447684, 56.299161774771555, 57.09088815961565, 57.25879485266549, 55.68265506199428, 50.126646178109304, 43.27298477717808, 49.92017698287964, 56.43473849977766, 56.882490839277, 55.235667024339946, 51.540205069950645, 51.78549037660871, 51.41357067653111, 55.244362694876536, 55.71649626323155, 54.31841448375157, 48.6791627066476, 47.88845770699637, 54.09358467374529, 53.499267033168245, 54.72928231103079, 56.44863142286028, 53.45766816820417, 46.7181066104344, 45.37835495812552, 37.569785254342214, 31.278125422341482, 23.56297598566328, 20.41264189992632, 16.195602996008738, 14.27995945726122, 12.474239025797162, 13.698496852602277, 13.179858122553144, 10.822714754513331, 8.502464583941869, 11.072371346609932, 7.948656678199768, 2.3694047672407965, 0.7209344463688987, 0.19924712633447988, 0.04342964065394231, 0.5182686299085617, 5.49752459355763, 21.664444991520472, 37.43748460497175, 37.2422958101545, 33.45510026386806, 26.431803805487498, 20.477463381631033, 31.94087587084089, 45.99866580963135, 48.55364349910191, 53.93298053741455, 35.843581744602744, 7.395188365663801, 0.08641207244779382, 0.04412058947075691, 0.03681884699368051, 0.005576145228198064, 0.043085005932620594, 0.03595632720472557, 0.04379062467653837, 0.05931311406727348, 0.08477834332734346, 0.060804418687309535, 0.030826327657060962, 0.05930026261402028, 0.033301033079624176, 0.07774247122662407, 0.016144879029265473, 0.05542640441230365, 0.06419226261121885, 0.039014175800340514, 0.04792349665824856, 0.0037760494992003907, 0.060401647085590024, 0.07447679753282241, 0.023976704937272837, 0.04177756733926279, 0.03749963814126594, 0.029801247841013328, 0.040376572337533743, 0.0691644111648202, 0.08946510005210127, 0.1952057174806084, 0.16485893087727682, 0.12286296007888657, 0.19698008655437402, 0.16067213911030973, 0.0985662495451314, 0.1297072885291917, 0.1577121793691601, 0.1952878473592656, 0.07200807678912367, 0.08465318075780358, 0.0967144121282867, 0.1171657493604081, 0.14661119718636784, 0.11781586733247552, 0.20297220216265746, 0.09424098235155855, 0.22350043776844228, 0.21094345514263424, 0.08896444298859153, 0.14997398959738867, 0.15850740884031567, 0.2500526936990874, 0.24744296659316334, 0.3749491146632603, 6.818252078124455, 55.80217102595738, 66.06032466888428, 67.64434024265834, 57.99861471993582, 47.27457046508789, 46.295141969408306, 49.163601534707205, 48.42197513580322, 58.5600916998727, 57.78539882387434, 49.29226132801601, 43.68960223879133, 26.37898186274937, 5.359880345208304, 0.6105865218809673, 0.17411477278385842, 1.3219855427742004, 3.486561758177621, 10.009731224605016, 18.177561010633195, 19.417540005275182, 17.82584319795881, 24.909952027457102, 25.978994914463588, 14.892671585083008, 15.009482962744576, 28.49412989616394, 33.22193261555263, 38.596475396837505, 40.15045738220215, 59.071166447230745, 54.37701906476702, 60.06339005061558, 58.08067294529506, 61.2697571345738, 54.149653162275044, 59.57304872785296, 62.49868501935686, 59.392214911324636, 57.85640593937465, 52.83398744038173, 54.316003458840505, 56.061036586761475, 57.51528065545218, 59.36674281529018, 58.20995112827846, 56.12333413532802, 55.03051451274327, 54.300241470336914, 54.28712327139718, 58.73781272343227, 60.68607371194022, 58.486142022269114, 57.071794509887695, 60.25962107522147, 59.29084069388253, 61.13792201450893, 60.581711769104004, 54.85856744221279, 50.248395987919395, 33.15228039877755, 38.11609779085432, 53.13969080788748, 53.25752878189087, 54.764853613717214, 55.72643913541521, 57.27243069240025, 61.021088055201936, 58.39928259168352, 52.54487637111119, 44.82473291669573, 50.93074383054461, 58.24832950319563, 58.789833886282786, 56.487273829323904, 52.3624792098999, 51.56797007152012, 53.418806893484934, 56.3878207887922, 57.37245348521641, 56.02501712526594, 52.32986089161464, 50.14038276672363, 57.231887953622, 56.46179131099156, 56.88120542253767, 58.78676973070417, 54.28098801204136, 49.03666836874825, 49.5104729788644, 44.18966061728341, 35.240095955984934, 24.556401627404348, 30.536856855664933, 24.708115543637955, 24.40406584739685, 19.31761622428894, 18.406465939113072, 22.389376606260026, 18.860575880323136, 17.311582701546804, 14.635640348706927, 9.584320817674909, 1.9682036212512424, 0.8202529198357037, 0.38954413150038036, 0.2801783728812422, 0.7167396343180111, 6.603400315557208, 27.000583342143468, 45.16803993497576, 51.8800379889352, 54.362789154052734, 33.21072169712612, 20.01694893836975, 34.70686687741961, 52.29598147528512, 55.501849038260325, 60.73567690168108, 46.36117764881679, 11.692241856030055, 0.3625759200326034, 0.18455319266234124, 0.18635854364505836, 0.17480723134108953, 0.10923689803374664, 0.16922282028411115, 0.08963860145636968, 0.15278206605996403, 0.23590553711567605, 0.14999855256506375, 0.18657236360013485, 0.11509700465415205, 0.09805369097739458, 0.21500816488904612, 0.09247029772294418, 0.15262586729867117, 0.24872615773762974, 0.054833256240401945, 0.13356933343623364, 0.1360251416585275, 0.2042541719440903, 0.19977457874587604, 0.11205465040568795, 0.10891619524253265, 0.1247634416712182, 0.08360861002334527, 0.1676165514758655, 0.10089037447635617], [0.04071962607226201, 0.009876740464408482, 0.05317098793706723, 0.0190974597020873, 0.06840616185218096, 0.05241611772882087, 0.0632800537028483, 0.024101979465090802, 0.009569740687896098, 0.06148879589246852, 0.048560400160827806, 0.023207917975793992, 0.048404689944748364, 0.00554605177603662, 0.026772391350407685, 0.007308138517795929, 0.06138487146901233, 0.053570047952234745, 0.08332305534609727, 0.04084139596670866, 0.13809109080050672, 0.009469320897811224, 0.06140629281955106, 0.057485432497092655, 0.1901354052658592, 0.03644705390823739, 12.080601862498693, 32.306114877973286, 37.4866361618042, 39.20972687857491, 34.919745785849436, 22.532281943729945, 26.033599070140294, 37.706199237278526, 49.36119440623692, 36.26741143635341, 13.059008972985403, 45.39173024041312, 19.794260910579137, 5.86476902450834, 0.9639405267579215, 0.11263683345168829, 0.14804419529225143, 0.9926416895219258, 4.339322856494358, 10.603033559662954, 7.094862469605037, 10.77419374670301, 12.547407031059265, 9.995175617081777, 12.009580850601196, 21.48780962399074, 23.39084652491978, 33.1561644417899, 36.34670775277274, 44.99618319102696, 47.489794390542166, 51.667308466775076, 53.64582886014666, 60.71693066188267, 60.26330362047468, 54.59031139101301, 56.856316975184846, 58.02032436643328, 55.09160654885428, 53.620068413870676, 47.380759784153526, 49.51728221348354, 49.75520242963518, 53.020546572549, 55.976372786930625, 56.01806197847639, 54.36622503825596, 55.88039037159511, 59.09312970297677, 54.355219091687886, 52.250960622514995, 56.561098439352854, 55.49100637435913, 49.19962099620274, 45.70195688520159, 51.840666021619526, 57.122919355119976, 58.6767589024135, 58.77309567587716, 51.52442571095058, 53.37061766215733, 24.718244280133927, 23.154666832515172, 45.609959261757986, 45.60877111979893, 52.702298232487266, 51.42604269300188, 59.63663169315883, 55.20137071609497, 54.16391086578369, 45.23590299061367, 42.374506269182476, 42.47227784565517, 50.175175871167866, 53.759866169520784, 55.8272887638637, 53.17894465582711, 50.721411977495464, 49.73764085769653, 53.97592735290527, 53.74260337012154, 51.140346663338796, 48.45092133113316, 45.18118592670986, 45.27638666970389, 47.17900841576712, 51.50390420641218, 51.2987516948155, 54.405416352408274, 53.83958980015346, 47.10673672812325, 46.33310692650931, 39.57591431481497, 35.199442046029226, 26.645358426230295, 27.799494164330618, 21.146559272493633, 13.930321761540004, 12.44653308391571, 9.965269701821462, 12.792535134724208, 8.881916999816895, 7.386781045368739, 6.348456144332886, 2.100038741316114, 0.468438700905868, 0.37421168280499323, 0.02664592090461935, 0.2441712064402444, 1.149475559592247, 12.95243055479867, 32.29087747846331, 49.46388183321272, 35.283570834568565, 24.734344993318828, 25.712328263691493, 32.74992411477225, 34.494099140167236, 41.22460372107369, 43.7817006111145, 40.452266284397666, 20.63564780780247, 0.2825581580400467, 0.07552474737167358, 0.050244099992726526, 0.0715476975643209, 0.046755154351038594, 0.032935988024941514, 0.04613928882671254, 0.02149270867396678, 0.11742880381643772, 0.010485185360136842, 0.05290848648707781, 0.02381396170572511, 0.014149311780264335, 0.024651148389758806, 0.08856631935174976, 0.05110202609960522, 0.025341422064229846, 0.04480461383770619, 0.05079010355153254, 0.03958186533834253, 0.045654207534555874, 0.0755124387464353, 0.021534365635099154, 0.08632495533674955, 0.05191869727735009, 0.09811203820364815, 0.042342871826674254, 0.0182532179501972, 0.021935649548790286, 0.05948225249137197, 0.1030973367659109, 0.035223757049867084, 0.024245045181097727, 0.05815212707966566, 0.021947149021018828, 0.01896364750739719, 0.009882362975206758, 0.08991137931921653, 0.0411576543535505, 0.05156653081732137, 0.00811864181222128, 0.005119399982504547, 0.03927063489598887, 0.00903470310316022, 0.038414018361696174, 0.1008999418201191, 0.08040377377931561, 0.037409518512764146, 0.013182636017778089, 0.015666315065962926, 0.01600376410143716, 0.028707595275981084, 0.057320955608572276, 0.055209748180849214, 16.606092146464757, 44.46108157294137, 49.99941076551165, 50.89399480819702, 43.51680748803275, 31.520905903407506, 34.517035143715994, 41.17769643238613, 44.27668333053589, 39.49020481109619, 23.77146189553397, 41.32263238089425, 18.86770646912711, 7.200041694300515, 1.0832569471427371, 0.11223664706838982, 0.09669833763369493, 2.9103980234691074, 4.862672030925751, 9.27220686844417, 10.609566603388105, 13.3162590776171, 16.66535680634635, 10.667504157338824, 12.294869542121887, 13.679969481059484, 18.158152954918997, 26.844728299549647, 33.093512535095215, 41.76323849814278, 43.6462003162929, 52.498507567814414, 55.23717825753348, 60.13165610177176, 60.76528317587716, 56.048929350716726, 56.325644833701, 58.42950030735561, 56.46668631689889, 54.91571984972273, 49.97459527424404, 53.09309271403721, 52.88411174501692, 55.51252841949463, 57.16697440828596, 56.976249831063406, 54.53953048161098, 55.63705750874111, 57.394111020224436, 54.68796484810965, 52.15093435559954, 58.10887915747506, 57.56290708269392, 51.14673900604248, 48.3499744279044, 54.571044036320274, 57.93970789228167, 59.54508917672293, 58.771893637520925, 54.33941888809204, 53.634242738996235, 29.640646934509277, 30.559973512377056, 48.672148500170024, 50.481428146362305, 54.72512034007481, 53.04950319017683, 59.84712042127337, 56.94999258858817, 55.17956032071795, 48.63329069955008, 44.93780442646572, 44.11255645751953, 52.7927359853472, 55.02881915228707, 57.147178990500315, 53.0819582257952, 51.32569333485195, 51.61943885258266, 54.52274015971592, 54.25837509972708, 53.28238596235003, 50.893491063799175, 47.595445224217, 47.43811368942261, 49.34297970363072, 53.14293214253017, 54.380291666303364, 55.39684438705444, 51.61611066545759, 48.07415526253836, 46.45331423623221, 38.85392699922834, 31.74459273474557, 26.872875452041626, 22.307962826320104, 16.011041470936366, 10.649722848619733, 9.506522706576757, 15.895487717219762, 14.347447310175214, 8.94621389252799, 11.661866068840027, 8.79401968206678, 4.497286677360535, 1.7822979454483305, 0.6368208570139748, 0.021012806300339953, 0.24517158418893814, 1.0272121259144373, 12.873091680662972, 29.212252276284353, 46.30895151410784, 40.56069639750889, 25.66408692087446, 21.91048070362636, 32.71991484505789, 41.46207925251552, 47.348318644932334, 51.20340851375035, 47.619510310036794, 24.317343643733434, 0.6216659130794662, 0.009079144602375371, 0.015732168585860302, 0.019212461209722927, 0.011652086628600955, 0.03361628044928823, 0.029833508788474968, 0.05286455134462033, 0.053316391206213405, 0.01606343616731465, 0.03169383807107806, 0.0214916213215994, 0.03902817737045033, 0.029635329065578322, 0.012460143804284078, 0.022017460515988723, 0.022172029096899287, 0.055080388872218985, 0.09014171481664691, 0.009711783512362411, 0.017758706717618873, 0.07969724919114794, 0.018925861588546207, 0.10724341643175908, 0.016242627087714415, 0.03264343425897615, 0.05968744148101125, 0.03925212785335524, 0.1789590921252966, 0.13094115017780236, 0.18085618104253495, 0.09925259450184447, 0.11405970102974347, 0.1147605191384043, 0.09177862626633473, 0.07262407802045345, 0.09801859714623008, 0.16068949603608676, 0.18415743032736437, 0.07929789062057223, 0.09307818367545094, 0.10927518097949879, 0.17478830021406921, 0.10401190697614636, 0.06886975054762193, 0.2249055073729583, 0.1549336463212967, 0.11430121878428118, 0.1881640303347792, 0.14146256845976624, 0.17591046142790998, 0.16330100090375968, 0.2777690850198269, 0.13833319209516048, 22.815837928227015, 55.97122417177473, 62.12471907479422, 60.909437452043804, 51.166482312338694, 35.5836044720241, 37.780496324811665, 52.70521647589547, 60.244244711739675, 45.15929215294974, 23.076030594961985, 56.192288058144705, 25.29776746886117, 7.058688844953265, 1.560170441865921, 0.2587977615850312, 0.4624642814908709, 2.6763379658971513, 8.90314895766122, 16.626775196620397, 18.44082999229431, 23.13161792073931, 25.805255208696636, 16.515489373888286, 19.534799541745866, 34.63567910875593, 27.910283190863474, 36.57051617758614, 40.32768855776106, 51.57432419913155, 50.218914781297954, 52.71820265906197, 56.281916345868794, 61.06264523097447, 60.621663911002024, 55.3949544770377, 59.757440022059846, 62.06166417258126, 60.740498951503206, 58.46436636788504, 50.75678178242275, 56.0158246585301, 56.31053944996425, 58.017062187194824, 58.97125135149275, 58.628927503313335, 56.649330139160156, 56.2709937776838, 59.82487228938511, 56.38001101357596, 51.69946820395333, 61.49289853232247, 60.32494109017508, 53.67138433456421, 48.98859378269741, 56.587776047842844, 59.633630071367534, 60.94340719495501, 60.68861675262451, 53.26637383869716, 55.484398637499126, 34.729434626443044, 33.67927694320679, 53.67934002195086, 51.99672256197248, 56.50865691048758, 54.215581144605366, 62.327140944344656, 59.41258702959333, 57.35703195844378, 50.6234632219587, 46.55382340294974, 46.101453985486714, 54.06627477918352, 57.442456586020334, 59.051523889814106, 54.27092702048165, 51.63641677583967, 50.4080308505467, 57.23468460355486, 57.11097192764282, 55.725515025002615, 52.47127410343715, 49.72971991130284, 49.417943818228586, 52.10676465715681, 55.6735702923366, 56.658692836761475, 58.33915982927595, 54.40766062055315, 48.12894875662667, 48.30042682375227, 43.85274941580636, 39.56954629080636, 29.678789070674352, 33.36301926204136, 25.916765110833303, 24.70992033822196, 23.94002866744995, 20.718953234808787, 20.01927658489772, 17.63098270552499, 17.595531259264263, 14.393044863428388, 6.532921697412219, 1.8048738368919917, 0.8859720219458852, 0.11608811361449105, 0.50612594719444, 1.6197465764624732, 15.94596985408238, 39.358689308166504, 60.29157584054129, 47.946423053741455, 36.15850189753941, 35.00353758675711, 43.69796092169625, 47.9915828704834, 56.229384490421836, 59.38587120601109, 56.774227482931956, 30.885058879852295, 1.171732810991151, 0.17008284984954766, 0.14942767391247408, 0.14829313621989318, 0.15617890735822065, 0.0942994449287653, 0.1338406524487904, 0.12433513679674693, 0.23364425131252833, 0.10875847656279802, 0.17857677835438932, 0.10026144715292112, 0.12362985392766339, 0.11187266052833625, 0.22654939416263783, 0.09510209757302489, 0.1671443318149873, 0.10521993001124688, 0.1077016650566033, 0.1073812133233462, 0.07480378355830908, 0.24027462410075323, 0.11499460014913764, 0.341850854988609, 0.18651935644447803, 0.16300741237189087, 0.1489295477845839, 0.1345040832779237], [0.05462897988036275, 0.029374951430197273, 0.02297409820104284, 0.03443462082317897, 0.04742457664438656, 0.052036362034933906, 0.025034262831988077, 0.0069098422786087865, 0.04919289657846093, 0.060588345995971134, 0.012690149364061654, 0.048775648432118554, 0.03411870848919664, 0.02609391400723585, 0.05398618669382163, 0.07564016617834568, 0.09089356554406029, 0.009242262724520904, 0.03559971634032471, 0.011739328420454902, 0.04809171227472169, 0.04240572452545166, 0.028013084150318588, 0.01774719706736505, 0.0848074864063944, 0.7849826695663589, 20.33869743347168, 37.493782384055, 37.47700943265642, 39.21046686172485, 31.108384404863628, 23.014988933290752, 28.046441827501567, 28.33441686630249, 50.11090156010219, 32.75469752720424, 37.380325249263215, 35.40684577396938, 13.069862059184484, 2.6522220713751654, 0.13171820848115853, 0.1065749508727874, 0.3355775816099984, 4.109368750027247, 3.953467241355351, 9.724967122077942, 10.527493613106863, 11.019943714141846, 10.572576131139483, 19.428090844835552, 15.72607500212533, 22.3114629813603, 36.529650347573416, 40.09880099977766, 42.27858986173357, 48.050260407584055, 51.80904476983206, 58.275278091430664, 59.00567967551095, 57.97852400371006, 53.59862279891968, 58.12089606693813, 56.55384104592459, 53.977952752794536, 51.24016448429653, 48.56460428237915, 48.39130926132202, 51.57620368685041, 54.23078727722168, 56.00461721420288, 55.21405117852347, 52.033391680036274, 52.60795906611851, 51.863355364118306, 55.84038264410836, 55.45694283076695, 54.2917994090489, 53.56566401890346, 54.75476482936314, 45.02979857581002, 44.07704768862043, 52.14494500841413, 56.8940943309239, 58.1168452671596, 59.587230001177105, 51.62129749570574, 54.95987217766898, 30.372670922960552, 21.59015311513628, 46.70058325358799, 42.470787457057405, 52.987320286887034, 51.71795736040388, 56.36367927278791, 54.51449612208775, 54.04170594896589, 49.17424617494856, 43.480131421770366, 40.59474604470389, 44.37941939490182, 50.0549442427499, 53.23741027287075, 53.22648423058646, 52.711146763392854, 51.11598627907889, 51.08583804539272, 53.40935386930193, 53.945271900721956, 49.60340860911778, 47.31184755052839, 43.14867803028652, 45.328407832554404, 46.31657716206142, 51.13317264829363, 53.15322242464338, 51.9480573790414, 47.54558147702898, 50.63986097063337, 48.491905280521934, 47.09044320242745, 42.93320744378226, 32.37010431289673, 25.6426499911717, 15.05418246132987, 11.506729296275548, 14.660928317478724, 12.379414354051862, 4.7507500137601575, 11.078832302774702, 9.900634952953883, 5.873644479683467, 1.5221986451319285, 0.3342029782278197, 0.14692449037517818, 0.017021130670660307, 0.11974049120077065, 2.3609045147895813, 19.80872184889657, 45.68594823564802, 42.89734779085432, 33.28945868355887, 29.752068247113908, 24.03819455419268, 24.91768363543919, 39.84933982576643, 50.09116172790527, 45.138190473829, 26.837298938206263, 1.6615836343594959, 0.031005294660904577, 0.038799473749739785, 0.008126755394706768, 0.06462106960160391, 0.027370426670781205, 0.06430301988231284, 0.021386141356612955, 0.036440780851989985, 0.049649893306195736, 0.039704429118760994, 0.03720367134415677, 0.029206427080290656, 0.06821457070431539, 0.019133469555526972, 0.047050225481923134, 0.019485790382272432, 0.02546739887579211, 0.04386737716517278, 0.02608853322453797, 0.045470297403101406, 0.00988219927863351, 0.052927848483834944, 0.010352590287636434, 0.04127487467069711, 0.024096971876653175, 0.014658003546563643, 0.058985910910580835, 0.051641461439430714, 0.029102217672126632, 0.01823509088717401, 0.050137183229838095, 0.05025183189926403, 0.05150116753897496, 0.05853314484868731, 0.022678282377975326, 0.004028952223182256, 0.026042369094544222, 0.033196063712239265, 0.034270686762673516, 0.0046248857813355115, 0.024264391910816942, 0.02284781095970954, 0.0347728739226503, 0.0553286343014666, 0.0005350254453203109, 0.08442418197435991, 0.024607869729931866, 0.04156450395073209, 0.022349745899971043, 0.09728012034403426, 0.04492940321298582, 0.09732420476419584, 0.9223078978913171, 27.36862768445696, 44.88243423189436, 50.47370522362845, 46.93941020965576, 38.952733857291086, 26.67516619818551, 29.317586966923304, 35.02473654065813, 54.410280091421946, 37.136704036167686, 28.02089330128261, 34.628393922533306, 14.905096701213292, 2.420675741774695, 0.11358851274209363, 0.12212653245244708, 0.8947291948965618, 3.4167275854519437, 6.509887116295951, 11.416335838181631, 10.157637528010778, 13.418840544564382, 19.398145845958165, 16.74402952194214, 10.372776338032313, 18.953905820846558, 27.996637140001567, 35.058765343257356, 42.21203654153006, 49.42524984904698, 54.654342515128, 57.74302176066807, 58.363089425223215, 59.139863286699565, 55.330944197518484, 57.13070133754185, 59.03145749228341, 54.889948981148855, 55.030691691807334, 50.385067054203574, 50.79209252766201, 53.476087842668804, 56.77768768583025, 57.8629025050572, 56.79908118929182, 53.474444593702046, 52.93338142122541, 52.48901980263846, 56.286033153533936, 55.934440408434185, 55.452020032065256, 54.534875188555034, 56.95405033656529, 46.75385856628418, 46.150188650403706, 53.114850997924805, 58.01363672528948, 58.80341761452811, 60.79340948377337, 52.40830257960728, 56.52457175936018, 33.403881617954795, 27.5703147820064, 51.581873416900635, 47.171990735190256, 53.89472028187343, 53.07144560132708, 57.48450360979353, 56.7769581249782, 55.1762877191816, 51.165103094918386, 45.72215877260481, 41.72700016839163, 44.97527606146676, 53.55056210926601, 55.91461372375488, 54.632400103977744, 52.008548395974294, 51.33362817764282, 51.407136644635884, 54.54045111792428, 56.11629908425467, 52.13288640975952, 47.90553290503365, 46.445379393441335, 48.63316215787615, 49.75016498565674, 52.69491924558367, 56.72802196230207, 52.028976099831716, 48.42865235464913, 49.38292489733015, 47.63363599777222, 43.99058777945382, 37.77842228753226, 27.26748275756836, 20.323762280600413, 12.038533125604902, 11.961744240352086, 11.380806224686758, 15.197098221097674, 13.733470610209874, 9.361283642905098, 12.410002929823738, 6.854098268917628, 4.331281619412558, 1.6097675519330161, 0.24857620149850845, 0.00929908494332007, 0.341096324047872, 2.816557824611664, 21.614054918289185, 46.24161652156285, 41.1623443875994, 34.23569563456944, 34.38320241655622, 30.62289639881679, 30.734421934400284, 44.58031613486153, 56.6105591910226, 52.391602584293906, 32.367467471531455, 2.051298430987767, 0.022927538824400732, 0.039083881702806265, 0.023684644805533544, 0.03483531271506633, 0.01465047350419419, 0.034101643333477635, 0.043187949872974835, 0.05833497191114085, 0.04342049060921584, 0.02095095274437751, 0.019065012157495533, 0.042269579866634946, 0.051571328059903214, 0.0676995829812118, 0.03589384091485824, 0.10581566340156964, 0.06817109696567059, 0.01645304588600993, 0.035600269346364906, 0.04306536912918091, 0.07125191736434187, 0.019476903269865682, 0.062394884414970875, 0.050295227606381686, 0.09536189506096499, 0.03422786781032171, 0.05668862882469382, 0.15097660651164396, 0.15423708941255296, 0.07511725995157446, 0.1505285698388304, 0.13604081581745828, 0.1634406569812979, 0.20124511340899126, 0.11082817800343037, 0.07890244041170393, 0.06334711331874132, 0.10312482421951634, 0.14886136858591012, 0.13002478863511766, 0.10310087193335805, 0.1584315893373319, 0.2688760150756155, 0.19769804445760591, 0.13137317342417582, 0.2333566067474229, 0.1502402467387063, 0.16771377197333745, 0.16461206626679215, 0.15123614615627698, 0.13290723253573689, 0.128111279170428, 1.5391500783818108, 36.52564818518502, 59.35774489811489, 62.97210053035191, 56.68946293422154, 46.52729170663016, 34.00661700112479, 39.421838011060444, 40.33499458857945, 61.9421968460083, 44.41514703205654, 53.196992601667134, 43.41499205998012, 16.914368084498815, 3.405910325901849, 0.2241041168038334, 0.2707226888409683, 0.8325373892273221, 9.225785953657967, 10.770275831222534, 19.950284446988785, 21.779932737350464, 17.483262266431534, 21.564180748803274, 33.15499019622803, 26.0626859664917, 29.33285563332694, 42.633246762411936, 41.12687035969326, 48.611428192683626, 53.79465579986572, 57.514419078826904, 60.88186700003487, 59.76052502223423, 59.73476110185896, 56.25965779168265, 59.6297390801566, 60.479427337646484, 57.26453406470162, 56.56916529791695, 52.41161339623587, 53.42006451742989, 55.10798692703247, 58.072039808545796, 60.19921343667166, 56.23670441763741, 53.11195012501308, 53.17317417689732, 52.52604675292969, 55.53807347161429, 57.25152703693935, 58.89917073931013, 57.37187678473336, 59.346877915518625, 50.07740429469517, 48.193730286189485, 55.90538304192679, 60.133837836129324, 61.831039564950125, 61.49982588631766, 52.537337575639995, 57.86811712809971, 37.10136897223336, 32.07142210006714, 54.81815324510847, 49.09917436327253, 53.779498304639546, 55.84069878714425, 58.16130678994315, 58.982688086373464, 57.944995471409385, 53.49470206669399, 46.82028681891305, 44.19309650148664, 47.17360619136265, 53.96055793762207, 57.7486115864345, 57.01178986685616, 51.83124426433018, 51.95255981172834, 52.74030487877982, 54.20947715214321, 57.25592177254813, 55.01441553660801, 52.26074021203177, 47.765443325042725, 50.55925144468035, 50.90790510177612, 56.0150534084865, 59.359106745038716, 52.776046412331716, 48.8476356778826, 51.594967297145296, 49.8803915977478, 47.83162144252232, 44.598669801439556, 35.169880935123985, 30.509373256138392, 23.38984772137233, 20.20070273535592, 28.49662603650774, 22.06787998335702, 12.37958892754146, 24.736584050314768, 17.483095509665354, 10.874028938157217, 5.5799601929528375, 1.727192108120237, 0.4827994331717491, 0.16573995431619032, 0.38204270973801613, 3.2579655902726308, 24.250222308295115, 54.473067487989155, 53.81975269317627, 46.79791709354946, 40.5423983165196, 34.01482629776001, 37.29669673102242, 53.41048642567226, 63.48485674176897, 59.86508846282959, 39.525717054094585, 4.090267717838287, 0.06429479603788682, 0.10592651566756622, 0.10063864476978779, 0.24431999559913362, 0.11194274641041245, 0.11751334927976131, 0.12181509844958782, 0.29668582709772245, 0.12605383885758265, 0.1303199649389301, 0.12067377540682044, 0.11638448413993631, 0.2225071167839425, 0.175731626738395, 0.13911248956407818, 0.16892497055232525, 0.102080470616264, 0.14194450474211148, 0.061778991749244075, 0.22972199320793152, 0.1179675877626453, 0.12577857077121735, 0.18590993700282915, 0.19421808261956486, 0.13050074023859842, 0.08572579534458262, 0.18445282376238278], [0.061096948704549243, 0.05314896269036191, 0.049287450433309586, 0.03631765388750604, 0.06397447322628327, 0.07377290566052709, 0.05613795015960932, 0.03566423484257289, 0.010552576610020228, 0.022608730842226317, 0.017597809101321867, 0.031036653156791414, 0.026410282656018223, 0.02954590493547065, 0.037262846383133104, 0.03635219810530543, 0.02476240268775395, 0.03332562318869999, 0.0604058268613049, 0.08847940580121108, 0.026609929710892693, 0.028323834529146552, 0.022416549368894527, 0.013064028944687119, 0.09208223676042897, 2.6501793009894232, 31.753503799438477, 46.0863972391401, 44.49548210416521, 41.951423508780344, 37.94349064145769, 34.759294509887695, 44.96277625220162, 40.796698910849436, 26.558707441602433, 16.790361847196305, 42.16407312665667, 23.25861883163452, 4.714571177959442, 0.4571803935936519, 0.06739574857056141, 0.07990660438580172, 0.657347029873303, 2.1810232528618405, 4.523428406034197, 6.220502461705889, 7.15628411088671, 13.360184720584325, 27.665678807667323, 8.094824194908142, 17.65362514768328, 22.819273812430247, 30.611105305807932, 43.043190479278564, 51.958059310913086, 55.25348915372576, 56.05558225086757, 56.58501761300223, 58.79011876242501, 58.73112160818917, 58.48297364371163, 54.300894601004465, 52.623550823756624, 51.35200963701521, 49.02852507999965, 48.45190102713448, 51.74586132594517, 52.6849798474993, 55.95319707053048, 53.721758774348665, 54.38372755050659, 52.68408005578177, 51.03005790710449, 50.078884260995046, 54.61432783944266, 55.09019259044102, 54.734232902526855, 51.47533668790545, 50.46085453033447, 39.52020713261196, 41.92095218385969, 49.91350323813302, 55.7618784223284, 54.719707693372456, 59.393785204206196, 51.25541230610439, 55.16446883337838, 38.9169019971575, 22.44150025503976, 46.409578800201416, 45.52306509017944, 53.196127550942556, 51.432157107761924, 55.62802485057286, 54.23231588091169, 53.49511548451015, 52.48719242640904, 50.289300033024375, 45.213988372257774, 40.51162821905953, 44.11702414921352, 51.47380461011614, 54.49438108716692, 51.544426100594656, 52.21334654944283, 49.514926774161204, 51.477358613695415, 51.00665637425014, 52.330058915274485, 48.38629266193935, 45.63395486559187, 41.10125929968697, 47.24771915163313, 47.747211251940044, 53.77248062406267, 52.90138496671404, 50.817703587668284, 48.80878829956055, 50.764108657836914, 45.70654617037092, 47.740516662597656, 37.353724070957725, 32.08737168993269, 17.175014121191843, 10.919365933963231, 14.939212356294904, 10.941258839198522, 14.111360549926758, 7.549812708582197, 8.235864809581212, 4.857978088515146, 3.787398781095232, 0.5742023342422077, 0.3419939987361431, 0.039961305513445816, 0.07983664064002888, 0.5234853156975338, 5.477993207318442, 24.18367419924055, 42.64908518110003, 44.60457577024187, 27.762927532196045, 15.563591378075735, 30.35445969445365, 36.529306411743164, 42.682749203273225, 45.55316468647548, 35.17304236548287, 4.483081519603729, 0.1111887718683907, 0.01560425286048225, 0.06052915060094424, 0.03754861479891198, 0.026652882673910687, 0.07466099264898471, 0.0075695229295109, 0.030065669545105526, 0.036785744662795744, 0.03563783983034747, 0.0511134322732687, 0.09246762429497071, 0.008330251439474523, 0.02405843448026904, 0.04405063929568444, 0.012097010522016456, 0.04187861477423992, 0.042647584940173795, 0.01174563285894692, 0.08371478039771318, 0.025118847311075245, 0.04670825740322471, 0.10321956806417022, 0.03156531675319586, 0.06253005537603583, 0.01733179283993585, 0.03116662653961352, 0.015608817704820206, 0.01668978505767882, 0.04974802643326776, 0.049194735408361466, 0.05913746849234615, 0.0137500015553087, 0.009537293991473104, 0.05315583285742572, 0.043358435189085345, 0.018939427199906538, 0.02527308340982667, 0.0043884561912688825, 0.06325781811028719, 0.037866579701325724, 0.02073762981620218, 0.026074884492637854, 0.022467339411377907, 0.07149662423346724, 0.010914544508393322, 0.0737187789220895, 0.04319226196301835, 0.03167451000107186, 0.05092813453770109, 0.048983734766287465, 0.08986624995512621, 4.538602403232029, 39.58379357201712, 56.879986013684956, 52.25613703046526, 47.78834111349923, 40.03377628326416, 37.39650065558297, 48.40283284868513, 41.79100349971226, 30.395297731672013, 23.383290358952113, 38.95414086750576, 23.292043140956334, 5.059854958738599, 0.7180591406566756, 0.12124587542244367, 0.5957558091197694, 2.705248985971723, 6.251401969364711, 7.9451252562659125, 12.224740505218506, 10.30913952418736, 14.589975050517491, 15.028581823621478, 9.608563082558767, 19.44155819075448, 23.680195569992065, 35.48643044063023, 43.03592961175101, 52.266739981515066, 55.636324473789756, 57.77602570397513, 58.348852566310335, 60.92222908564976, 57.737338134220664, 57.913756370544434, 56.795054708208355, 55.05246039799282, 53.20813056400844, 51.62322562081473, 49.42765392575945, 52.955824102674214, 54.99164628982544, 57.221139090401785, 55.296953610011506, 55.384007590157644, 53.169526372637065, 52.21917608806065, 52.345108713422505, 54.876844678606304, 55.897851194654194, 56.616451263427734, 54.903584820883616, 51.277719497680664, 42.15623903274536, 44.22500262941633, 51.73057528904506, 56.031965323856895, 55.787145546504426, 58.8614559173584, 52.53337710244315, 55.02821813310896, 39.691365582602366, 28.07503887585231, 49.79873636790684, 47.66865839276995, 53.40261064256941, 51.672821862357004, 55.71582923616682, 55.04223959786551, 56.14367846080235, 55.17952905382429, 52.1607208933149, 45.392876693180625, 42.46676445007324, 46.86535630907331, 52.95553922653198, 56.754383427756174, 53.52598633084978, 52.62036507470267, 50.06146860122681, 51.28004019601004, 53.48809085573469, 54.45815665381295, 52.01658398764474, 46.77252490179879, 43.4539749281747, 48.65582718167986, 51.156139918736045, 55.046985217503135, 53.90062277657645, 49.80075134549822, 51.41185794557844, 50.476515769958496, 47.23407288960048, 43.15355566569737, 34.124927452632356, 27.373976060322352, 17.59351107052394, 9.160661356789724, 11.385834983416967, 14.28115975856781, 14.817292315619332, 9.680740100996834, 11.592077493667603, 8.581615856715612, 5.948513925075531, 2.0612402175154005, 0.6564927814262254, 0.32577902025410105, 0.12793632570121968, 0.6632017557110105, 6.176619810717447, 25.43798211642674, 41.25048228672573, 42.41831118719918, 26.27460081236703, 19.8684172970908, 34.29526254108974, 42.80978659221104, 48.98419904708862, 52.29248653139387, 41.71590389524187, 7.559578401701791, 0.0600506884178945, 0.07449441908725671, 0.022112192486279776, 0.0698233229507293, 0.04365221710343446, 0.052771154391978464, 0.09182244605783906, 0.025311988911458423, 0.01747121482289263, 0.06182515927191291, 0.026544295018538833, 0.06305729065622602, 0.09175599033811263, 0.06068106780626944, 0.04440098388918808, 0.01257001728351627, 0.05120979442394205, 0.06301791526909385, 0.015432612338502492, 0.03523962798395327, 0.015855643299541304, 0.05742686813963311, 0.024490997161982313, 0.03279937178428684, 0.11002337440316166, 0.040081949039761505, 0.060326031143111844, 0.17834347087357724, 0.15669471610869679, 0.09223445252116237, 0.12831521965563297, 0.1738924439996481, 0.12597983782844885, 0.194543738716415, 0.12746428245944635, 0.15411404387227126, 0.1150322181305715, 0.10762372173901115, 0.11524800583720207, 0.14626038101102623, 0.10072336665221623, 0.14685259280460222, 0.09733302571943828, 0.11480611669165747, 0.12758341963802064, 0.17390726320445538, 0.19364850675421102, 0.1428100982947009, 0.12417094489293438, 0.1477951593697071, 0.17469668441585132, 0.18910579622856208, 7.622468284198216, 49.068511962890625, 67.41812774113247, 65.6208302634103, 55.20193004608154, 51.29370035443987, 49.236953667231965, 56.60107489994594, 51.59939329964774, 37.38933706283569, 27.702570268086024, 53.18690381731306, 29.304642472948345, 5.9921672855104715, 0.784868349986417, 0.38797052736793247, 0.7512272894382477, 3.5604912425790514, 8.112433535712105, 11.515111429350716, 16.038971492222377, 14.974451882498604, 25.20848659106663, 37.64256068638393, 14.32320157119206, 23.51568133490426, 26.247756447110856, 33.39524848120553, 45.12902579988752, 54.70181955610003, 57.50438240596226, 59.63454723358154, 58.63549355098179, 59.54993207114083, 58.4140614100865, 59.38725389753069, 58.287472179957796, 56.78823505129133, 55.55867140633719, 53.77898413794381, 52.70233644757952, 54.95236464909145, 56.38563558033535, 58.9853492464338, 56.22181442805699, 55.74258327484131, 54.21042210715157, 52.8244058745248, 52.409292697906494, 57.52073499134609, 58.68988404955183, 58.601669720241, 56.464362144470215, 53.848045757838655, 44.10250241415841, 45.328331402369905, 54.402216706957134, 59.22462436131069, 58.61906106131417, 62.2138158253261, 53.4436536516462, 55.43527487346104, 43.404396057128906, 33.059330872126985, 54.581911018916536, 51.24291944503784, 52.454278809683665, 53.55539805548531, 56.605150018419536, 56.50211518151419, 58.69016892569405, 57.13260514395577, 53.95977626528059, 48.16130999156407, 43.66400160108294, 49.01509421212332, 56.281958035060335, 58.76254136221749, 52.776765550885884, 52.71154975891113, 50.73267500741141, 51.95914322989327, 53.912900243486675, 57.03025817871094, 54.35765096119472, 50.71507869447981, 46.121586390904014, 51.61872666222708, 52.27314274651663, 58.23187269483294, 55.20679725919451, 51.330268723624094, 50.29444169998169, 51.924794810158865, 48.12722212927682, 47.65751348223005, 38.954453536442344, 35.709940092904226, 20.67006049837385, 17.165964092527116, 26.12006766455514, 20.021718876702444, 27.09043918337141, 13.14260014465877, 17.774145126342773, 15.929141317095075, 11.43951676573072, 2.6786022101129805, 0.6537312524659293, 0.6822770035692624, 0.2888926352773394, 0.820351605968816, 7.025650594915662, 30.319419928959437, 54.45452969414847, 54.809683391026084, 36.52977541514805, 25.569996152605327, 41.8311710357666, 49.73522635868618, 56.00695180892944, 61.01894801003592, 50.1364118712289, 11.242188794272286, 0.15217275518391812, 0.2501741243260247, 0.14124249241181783, 0.17772613971361093, 0.13794429653457232, 0.16826941072940826, 0.21004310702638967, 0.0927909869434578, 0.16865149379840919, 0.11991977372339793, 0.13006782132600034, 0.21054729925734655, 0.12319013609417848, 0.1003067461507661, 0.08903190972549574, 0.15107685327529907, 0.18493604926126345, 0.12453081272542477, 0.09184667654335499, 0.18455077707767487, 0.08618040023637669, 0.1425544670117753, 0.20461857239050524, 0.1251272450068167, 0.223758620343038, 0.13379531273884432, 0.11340574933482067], [0.04024404427036643, 0.027607218428914036, 0.0440821877813765, 0.01574395813180932, 0.03456686729831355, 0.01854827211770628, 0.08717033533113343, 0.023030989969681417, 0.018240249449653283, 0.0823434746957251, 0.031178165027605634, 0.029760203257735287, 0.01321335244990353, 0.025562305568850467, 0.03234407139409866, 0.021317242910819392, 0.018858756171539426, 0.024288191526596035, 0.04594398609229496, 0.04315497985641871, 0.029668244799332957, 0.026650266921413795, 0.017531131161376834, 0.018650539219379425, 0.1339006485151393, 7.0738732644489835, 35.45008788790022, 53.45483330317906, 46.676104749952046, 34.15910564150129, 22.39430809020996, 29.544619355882915, 28.49356188092913, 63.57067394256592, 61.240845680236816, 53.366386209215435, 33.12314312798636, 12.098873019218445, 2.613996773958206, 0.05128829753292458, 0.07814864228878703, 0.5083358000431741, 2.354785974536623, 3.1027384911264693, 7.023939601012638, 10.368654319218226, 7.183788555009024, 12.415478110313416, 17.90739941596985, 25.571651560919626, 23.08786858831133, 35.20754017148699, 44.9446553502764, 49.5332213810512, 54.83889709200178, 54.76793166569301, 56.09464502334595, 55.50105346952166, 54.27986935206822, 53.80407408305577, 56.38650063105992, 53.571986879621235, 51.59686068126133, 47.02798931939261, 49.0712182862418, 50.725400243486675, 55.18011270250593, 53.87728377750942, 53.41535016468593, 52.8460807800293, 54.46048082624163, 51.17476109095982, 51.25135803222656, 50.6714266368321, 55.19622210093907, 51.77114929471697, 49.56502676010132, 46.729105608803884, 44.38462012154715, 39.327116693769185, 42.297732148851665, 50.46945640019008, 54.01675844192505, 55.06082255499703, 59.263492584228516, 49.68313571384975, 54.351067543029785, 41.61605480739048, 26.381333827972412, 46.71455260685512, 46.64813130242484, 53.279450348445344, 49.352797508239746, 55.36224235807146, 50.755465098789756, 54.965486322130474, 53.00784873962402, 54.03618907928467, 53.095034735543386, 42.05309649876186, 40.60124608448574, 46.27346011570522, 54.34040553229195, 51.7901109286717, 52.18318789345877, 49.48105778012957, 50.82979345321655, 50.20813117708479, 51.91995191574097, 50.78332390104021, 46.51017829350063, 39.527030263628276, 41.35780416216169, 48.004166058131624, 50.42453629629952, 49.76862982341221, 52.674599238804404, 49.916091442108154, 52.05640063967024, 52.60272707257952, 48.3963953426906, 42.017434869493755, 37.88486174174717, 28.206257343292236, 20.917402471814835, 8.556095123291016, 19.460330486297607, 18.83720908846174, 8.04105990273612, 13.028723512377058, 6.251148794378553, 4.45515410389219, 2.895337151629584, 0.3102814704179764, 0.11450214657400336, 0.06872865597584418, 0.08337781990745238, 2.21551867042269, 15.617855072021484, 35.74090473992484, 46.063912868499756, 38.42022739137922, 27.376034464154923, 23.317372798919678, 27.927030086517334, 42.282296725681846, 46.43563454491751, 39.887975284031455, 8.301570449556623, 0.5777668686849731, 0.044114092497953346, 0.063738356610494, 0.0030806929613130963, 0.042517866007983685, 0.05898727476596832, 0.10233635974249669, 0.04709369582789285, 0.02436225871289415, 0.021992699076820697, 0.03857366068820868, 0.0638043712824583, 0.06680946038769824, 0.044401516539177725, 0.026631234014140706, 0.0483592891666506, 0.00700230200475614, 0.014926513424143195, 0.01345421456997948, 0.01180165186191776, 0.0640218078291842, 0.052704915803458006, 0.027353702478909066, 0.02525939396582544, 0.06762177537062339, 0.032738965204251666, 0.042835946261350594, 0.033625810473625145, 0.036845672875642776, 0.10763422546109983, 0.03763265136097159, 0.05182278974513922, 0.023670281915526305, 0.055966711669628105, 0.05207058394859944, 0.05320924034874354, 0.011497784372685211, 0.05707320211721318, 0.03853431244247726, 0.02639019293045359, 0.0225068538981889, 0.05171108591769423, 0.0425734821307872, 0.020186940973092402, 0.02509379749452429, 0.029757248237729073, 0.06498266091304165, 0.01848694442638329, 0.021310640765087943, 0.04356767164011087, 0.020674758457711766, 0.11915072213326182, 8.983286006110054, 43.5560439654759, 61.08498368944441, 55.560092312949045, 42.86996841430664, 27.56283504622323, 35.09911353247506, 36.90661791392735, 60.38990674700056, 47.24801792417254, 39.13132340567452, 34.978902748652864, 13.518416915621076, 3.169416444642203, 0.06092829204031399, 0.15680113754102162, 0.6817785788859639, 4.755280239241464, 8.653022493634905, 9.871105108942304, 12.649588976587568, 12.432013085910253, 9.235285878181458, 15.459069626671926, 15.08228966167995, 20.1423465524401, 34.481981481824604, 43.09564243044172, 51.03771134785244, 56.48767682484218, 56.554984024592805, 58.08933734893799, 56.50154195513044, 54.20375183650425, 55.82031972067696, 58.6583114351545, 56.023596218654085, 54.715538774217876, 49.4778789792742, 50.70427424567086, 52.809703486306326, 56.163432189396445, 55.10326215199062, 54.7873067174639, 53.806405203683035, 54.19329479762486, 51.790010179792134, 52.20303542273385, 52.54268421445574, 57.95736673900059, 54.0210211617606, 52.22706229346139, 49.929862771715435, 45.99043219430106, 40.68318619046892, 43.702484198978965, 52.690361227308, 55.28263684681484, 55.02006094796317, 59.54501274653843, 50.8220670563834, 54.27084016799927, 42.834598609379356, 32.35166379383632, 50.127684933798655, 48.03558928625924, 54.666137082236155, 50.44679832458496, 54.23688084738595, 51.41802794592721, 56.844987937382285, 54.38237265178135, 56.57403251102993, 54.2777293069022, 43.090097767966135, 42.5786269732884, 49.32170779364449, 54.26106405258179, 53.783792291368755, 50.907151222229004, 49.63955661228725, 51.55850315093994, 50.44567271641323, 53.90613617215838, 51.89410809108189, 50.0731519971575, 40.92926011766706, 43.280620847429546, 49.01984677995954, 52.87535701479231, 52.61890247889927, 52.82857479367937, 51.24481977735247, 52.58820881162371, 53.925865582057405, 51.75216334206717, 43.94124167306082, 34.93553556714739, 26.703947373798915, 17.93894076347351, 9.632025412150792, 8.139566251209803, 12.52856091090611, 11.830095853124346, 11.750931552478246, 10.495933158057076, 7.608313066618783, 3.902674606868199, 1.5753224002463477, 0.28361526131629944, 0.13986250146159104, 0.1466258806841714, 2.1984808189528326, 17.470065900257655, 33.94841194152832, 45.828601700919016, 40.22296878269741, 26.75055241584778, 30.020984377179825, 33.91620356695992, 47.15902887071882, 53.10337257385254, 47.23046677453177, 12.7870260817664, 0.44480073930961744, 0.020828433068735257, 0.046982768923044205, 0.035773872530886104, 0.03611333342269063, 0.04964155750349164, 0.06253359732883317, 0.02786087687127292, 0.0412190040972616, 0.04467755815546427, 0.08617909744914089, 0.023069135512092283, 0.011264922180479127, 0.020829995395615697, 0.016744213744199703, 0.035086818505078554, 0.010776470265617328, 0.021866779940735017, 0.013172346882389059, 0.019627838295751383, 0.0410724099991577, 0.010983159665816596, 0.08351620033915554, 0.10125666125012295, 0.021491090367947305, 0.022133342422811047, 0.039404737164399455, 0.1072128348584686, 0.08884268666484527, 0.1961818036756345, 0.0759354035503098, 0.22759340171303066, 0.10442523658275604, 0.13656149644936832, 0.16270535572298936, 0.11563690139779023, 0.13310429267585278, 0.1435326702360596, 0.08632042272282497, 0.11213477860604014, 0.06169186785284962, 0.12740372999438218, 0.12278902690325465, 0.11427903068917138, 0.1200625239206212, 0.17283025171075547, 0.11270180996507406, 0.08982486610433885, 0.165731065507446, 0.1464187917964799, 0.0842868397012353, 0.4665187724999019, 13.661495089530945, 53.751111439296174, 70.11903844560895, 64.31967585427421, 50.140573842184885, 34.954132420676096, 42.19243219920567, 37.85865313666207, 71.40029321398053, 71.94589356013707, 67.79938929421562, 41.68170486177717, 16.100803511483328, 3.3951045743056705, 0.3300246681485857, 0.1904570037232978, 1.2057646534272601, 5.337961384228297, 9.748366049357823, 17.449082340512955, 24.168099812098912, 17.407294137137278, 22.026550361088344, 26.53336215019226, 30.282490253448486, 25.465267692293438, 37.38231938225882, 45.996407645089285, 51.045812947409495, 57.87323795046125, 58.18800176892962, 59.12975365774972, 57.14747428894043, 56.30951806477138, 56.56875188010079, 59.99095508030483, 58.30093778882708, 57.32846791403634, 50.847598212105886, 53.24768665858677, 56.306929860796245, 57.40823670795986, 56.63308525085449, 55.56680079868862, 54.455589294433594, 54.63556848253523, 52.198428767068044, 54.88593292236328, 54.71132469177246, 58.929471833365305, 56.99138648169381, 54.45641960416521, 50.57390866960798, 48.04091855457851, 42.92536292757307, 46.488941124507356, 54.94513504845755, 57.68050534384591, 57.990283829825266, 61.51516056060791, 52.220277377537315, 54.64220748628889, 44.7515093258449, 37.67776720864432, 53.77531896318708, 49.714336599622456, 54.26883213860648, 52.28820991516113, 53.45238058907645, 51.6529152733939, 58.90404142652239, 57.530848094395225, 58.41972419193813, 57.68405587332589, 45.437734263283865, 44.45057937077114, 50.111658913748606, 59.28596305847168, 55.69975805282593, 52.95920787538801, 49.20624957765852, 52.83467878614153, 51.893496649605886, 55.84266512734549, 54.80948536736624, 51.35721036366054, 42.87571457454136, 45.77815777914864, 51.32013130187988, 55.03124407359532, 51.71791219711304, 55.774899346487864, 51.84893785204206, 53.93666655676705, 54.91636603219168, 53.32696213041033, 46.30225692476545, 41.43603393009731, 31.595574719565256, 25.442633935383387, 12.217873947960989, 32.38149241038731, 28.61462034497942, 17.30044300215585, 25.39159073148455, 12.931701472827367, 11.17956989152091, 8.414602875709534, 1.6702494493552615, 0.2931385545858315, 0.32342249527573586, 0.2518584925149168, 3.12986729826246, 20.252802065440587, 45.02266277585711, 58.90082441057478, 52.96435996464321, 36.845859391348704, 34.90476894378662, 41.11480481284005, 54.619281905038015, 59.19874232155936, 53.78584548405239, 19.597786699022564, 1.032057408775602, 0.15108127732362064, 0.15205355015184197, 0.06740638799965382, 0.16561247115688665, 0.1391241332249982, 0.22871227881738118, 0.14829287837658608, 0.10483659843781165, 0.1407809393214328, 0.16853021244917596, 0.17648929251091822, 0.139144502846258, 0.07116824042584215, 0.10225644188800029, 0.09507887131933655, 0.08931795294795718, 0.2926525878054755, 0.093337906524539, 0.17626439886433737, 0.14405830417360577, 0.07217609563044139, 0.1823473431702171, 0.1830270859811987, 0.18898303567298821, 0.10168830451688596, 0.17242064726139816], [0.06788898246096713, 0.035790523780243735, 0.0760804336251957, 0.01085699031994279, 0.042806172144732306, 0.06892246593322073, 0.016623046049582105, 0.055116432652409585, 0.04107791631083403, 0.06408950526799474, 0.012018819539142507, 0.02466575724871031, 0.0732042526027986, 0.03674112419996943, 0.026904695501018847, 0.03049002873844334, 0.04441212882686939, 0.02732189106089728, 0.06406891173017876, 0.004606250241132719, 0.05636448246826019, 0.05502108830426421, 0.045033588872424195, 0.060716813031051836, 0.6354046730058533, 14.734725134713308, 43.31982953207833, 49.3886502129691, 39.122718061719624, 27.915016651153564, 28.611778531755718, 28.619661263057164, 54.402303559439524, 59.62056745801653, 56.75861835479736, 47.44775431496756, 19.016491719654628, 4.804047908101763, 0.2708965837955475, 0.08097871685666697, 0.0672383623729859, 1.1461006892578942, 4.170603224209376, 8.662692649023873, 8.797949756894793, 12.929145404270717, 7.579203588621957, 10.935281651360647, 12.103009802954537, 16.605155876704625, 32.99530322211129, 36.69017110552107, 50.72818994522095, 52.50480958393642, 55.251401220049175, 56.16112886156355, 58.200109004974365, 53.12847294126238, 55.39546169553484, 56.49406221934727, 53.88835225786482, 51.7039532661438, 46.55849954060146, 48.94596311024257, 51.42146035603115, 54.22318594796317, 54.71093906675066, 51.752020903996055, 49.956814834049766, 52.44814355032784, 52.04554407937186, 51.73709617342268, 51.46132564544678, 51.782867431640625, 51.34661088671003, 48.278616428375244, 44.21521609170096, 40.38812051500593, 40.75619438716343, 38.20110552651541, 42.07129383087158, 49.747913769313264, 52.246065616607666, 54.335708550044465, 56.10265629632132, 50.643491404397146, 55.738942418779644, 44.41119698115757, 27.09932940346854, 48.73509570530483, 51.20308542251587, 48.77870259966169, 47.84222091947283, 56.66890321459089, 47.270498820713584, 50.484370708465576, 52.13030167988369, 54.990089893341064, 53.540247508457725, 47.29853480202811, 38.077625615256174, 45.02150937489101, 48.483838421957834, 50.78066968917847, 52.051234654017854, 50.71779196602957, 48.82605804715838, 49.33113302503313, 50.84614951269967, 52.757849080221995, 46.6469292640686, 42.513838495527, 40.25701495579311, 46.18844543184553, 49.43074934823172, 54.652827807835166, 53.48395667757307, 52.276832239968435, 49.209452697208945, 50.73994977133614, 50.829967158181326, 49.05795417513166, 40.14676441465105, 37.30849824632917, 21.629740476608276, 15.312080485480172, 10.902079684393746, 7.310861553464617, 9.694490586008344, 6.852548386369433, 6.133639991283417, 5.569494903087616, 1.4772630163601466, 1.2359813920089175, 0.32442295444863184, 0.05082542129925319, 0.16282304083662374, 0.33036135722483906, 5.854768395423889, 22.566915239606583, 43.43937676293509, 27.03415356363569, 17.23013244356428, 17.555511372429983, 28.694323131016322, 38.05005863734654, 49.128700733184814, 42.19957842145647, 21.787417684282573, 1.8790864603860038, 0.0570921196735331, 0.039384404862565656, 0.07531796382474047, 0.05365529230662754, 0.005276893473429871, 0.020964981455888067, 0.009214446181431413, 0.027921705839357207, 0.009147664764896035, 0.0238549316501511, 0.03891729796305299, 0.020634852116927505, 0.046848408811326535, 0.057344527915120125, 0.06070127457912479, 0.04266218362110002, 0.04741990153810807, 0.04439185080783708, 0.003418698819587007, 0.043976570413048775, 0.0360690183006227, 0.06397097877093724, 0.02138290135189891, 0.016488326314304556, 0.04444159421005419, 0.046902192889579704, 0.050591221544891596, 0.04732514751542892, 0.05679591199649232, 0.025280297933412448, 0.04147982617307987, 0.026069205154531767, 0.038843079802713225, 0.021070654803354825, 0.023784106164904575, 0.06168806805674519, 0.022246801959616796, 0.05173244280740619, 0.03637910880414503, 0.06471495170678411, 0.027967264376846806, 0.014909219262855393, 0.028615636817578758, 0.02892896732581513, 0.05672149366832205, 0.0354563384982092, 0.04050718015059829, 0.024328177595244985, 0.044982420546667914, 0.03563890852300184, 0.6133577674627304, 17.603539058140345, 51.40633760179792, 59.860162190028596, 48.025424071720664, 34.90982028416225, 30.849303449903214, 30.042228494371685, 39.8203832081386, 61.07516588483538, 67.72618307386125, 51.77550234113421, 20.362171922411235, 6.037130815642221, 0.2636077334838254, 0.21740134432911873, 0.4121534882911614, 1.9494400109563554, 4.8703398023332864, 12.751233305249896, 10.970326628003802, 9.758566873414175, 12.193603021757943, 10.839446885245186, 13.690336193357195, 17.350478717258998, 28.54706995827811, 34.568649836948936, 50.973242487226216, 52.02132960728237, 55.92212472643171, 56.00141756875174, 57.80524287905012, 54.60762282780239, 57.28226934160505, 57.145494052342, 55.973002910614014, 53.31667879649571, 50.02804776600429, 51.37482057298933, 52.94219521113804, 54.89682422365461, 55.70997537885393, 52.813855034964426, 51.971497126988, 52.45283358437674, 52.65215308325631, 51.457875864846365, 52.8575314113072, 53.30319929122925, 52.57180758884975, 50.84159844262259, 46.51538249424526, 43.752726622990195, 41.58457251957485, 39.625333377293174, 44.170150075639995, 50.679816586630686, 53.35121134349278, 55.4985590662275, 57.7961094720023, 51.69792570386614, 54.49241822106497, 45.304905550820486, 30.444862706320627, 53.024117946624756, 51.08073459352766, 50.81443446023123, 48.57375158582415, 56.38501371656145, 46.04863725389753, 51.069343021937776, 52.79773868833269, 57.38094070979527, 55.35312632152012, 47.90501873833792, 40.11315597806658, 46.25171225411551, 50.62291431427002, 52.09348317555019, 52.616821493421284, 49.495840072631836, 48.96745041438511, 48.740501403808594, 50.99068593978882, 54.4377567427499, 47.99308368137905, 44.96591336386544, 41.42541708265032, 48.21558584485735, 50.856953961508616, 55.07057435171944, 54.56660761151995, 53.59584699358259, 52.325778824942454, 52.43109267098563, 51.46812445776803, 48.533910615103586, 41.12040853500366, 32.76394557952881, 23.791182620184763, 17.767540863582067, 12.138144237654549, 10.849066666194371, 9.163944380623953, 10.231211134365626, 9.443843875612531, 7.781573346682957, 6.371191084384918, 2.909812420606613, 0.8637259528040886, 0.085433122834989, 0.13563578469412668, 0.3914371356368065, 6.412841626576014, 26.31148532458714, 42.36310427529471, 30.393428666251047, 21.56615056310381, 21.159383910042898, 33.17264209474836, 44.289551394326345, 54.04322413035801, 48.96829809461321, 25.226046425955637, 2.627130823475974, 0.007183358472372804, 0.02364983256640179, 0.011696309300272592, 0.045946645949568064, 0.029273781858916794, 0.04372270671384675, 0.02378922062260764, 0.04301058081910014, 0.05604747090754764, 0.020782804981406246, 0.06094105528401477, 0.05135418328323534, 0.07187424254204546, 0.03278067475184798, 0.0626262037881783, 0.029834930319339037, 0.06703520898840257, 0.044353903736919165, 0.017742735699617436, 0.028558833258492605, 0.0229742932798607, 0.06261916738003492, 0.02422857883253268, 0.07480290824813501, 0.032343525173408647, 0.025476092605718544, 0.1586977243423462, 0.12741195383880818, 0.13081359916499682, 0.09221176909548895, 0.15313186443277768, 0.13464152733130114, 0.1336444201213973, 0.1410207607384239, 0.12229195928999356, 0.21417231831167424, 0.13581175596586295, 0.1590141523629427, 0.2326798087784222, 0.14775500366730349, 0.21461867221764155, 0.09725631055022989, 0.13023594873292105, 0.11605633103421756, 0.15801791367786272, 0.11137627823544399, 0.2077025683330638, 0.12915356324187346, 0.12934265738087042, 0.1297558716365269, 1.2396544920546668, 23.119232756750925, 62.90768378121512, 65.01724025181362, 55.37261254446847, 43.25552742821829, 43.515956333705354, 40.78297969273159, 61.904871123177664, 66.40326690673828, 65.41784558977399, 56.731162548065186, 24.057114498955862, 6.544906037194388, 0.5022466267858232, 0.22342741382973536, 0.5752056975449834, 3.1808631675583974, 8.62522622517177, 19.788207292556763, 19.440135547092982, 22.179692132132395, 17.335670369012014, 19.44574621745518, 18.999765668596538, 18.312149354389735, 34.75608096803938, 39.36805895396641, 53.700486864362446, 54.23795434406826, 57.25862809589931, 58.581130845206125, 60.16987119402204, 56.34752123696463, 60.21071965353829, 59.52385548182896, 58.677557945251465, 54.681753158569336, 51.5458539554051, 53.4347425869533, 56.81035464150565, 58.1478203364781, 57.38254574366978, 53.478439807891846, 52.32629646573748, 53.39635031563895, 52.90075615474156, 54.16075985772269, 55.03068821770804, 56.167302336011616, 54.10031400408064, 52.51224068232945, 48.64498104367937, 45.098293917519705, 44.881051540374756, 41.32494960512434, 45.818172454833984, 52.691424301692415, 55.09501116616385, 58.931486810956685, 58.58504268101284, 52.626931122371126, 55.19860533305577, 45.494785921914236, 36.70817388807024, 55.15716627665928, 53.032108375004356, 51.55502210344587, 49.46997887747628, 56.562324796404155, 47.76743050983974, 51.49024057388306, 54.107255254473, 59.4394348689488, 58.01773616245815, 50.14448915209089, 41.646137033190044, 49.033722332545686, 51.8475204195295, 53.449823651994976, 54.127029827662874, 50.5005704334804, 50.12459993362427, 49.62784889766148, 52.75866549355643, 56.50463042940412, 49.564036641802105, 47.13620056424822, 44.63350459507534, 51.14062459128243, 54.310420581272666, 60.08200427464077, 56.23484924861363, 55.95316580363682, 52.6211120060512, 53.82065943309239, 53.441461494990754, 51.59747212273734, 42.19236619131905, 39.90590858459473, 25.513743536812918, 19.925305673054286, 17.60575900759016, 14.554051995277405, 21.001428774424962, 17.51736228806632, 16.509074449539185, 14.31961977481842, 5.183052599430084, 3.7452492713928223, 1.1304196906941277, 0.27339931949973106, 0.4325255794184548, 0.6198582415069852, 7.0801761490958075, 29.027982575552805, 53.389231886182515, 39.178783076150076, 26.445373637335642, 26.317361763545446, 39.489999839237754, 51.578392369406565, 61.01734297616141, 56.606522287641255, 33.14998401914324, 4.602652634893145, 0.11602726259401866, 0.14069513178297452, 0.09550225002957241, 0.1651938964745828, 0.16415953769215516, 0.09847609938255378, 0.08357275623295989, 0.14041092060506344, 0.16393448119716986, 0.05719878537846463, 0.21480910985597543, 0.15637608963463986, 0.1396794327135597, 0.22606684719877584, 0.1885575670748949, 0.12502352414386614, 0.13599680603614875, 0.14529516494699887, 0.08834487944841385, 0.1597926491605384, 0.07762420257287365, 0.1928026992827654, 0.17166720197669097, 0.13735376750784262, 0.22432081374738896, 0.15941081036414417], [0.05091304052621126, 0.022932699083217552, 0.005312749808321574, 0.03613062249496579, 0.01278112394668694, 0.07271322395120348, 0.07306657106216465, 0.04754912174705948, 0.03755626528124724, 0.02574948115008218, 0.03701946944264429, 0.003619254899344274, 0.05111841272030558, 0.024741639516183307, 0.04558845070589866, 0.013412024110688694, 0.024861855565437248, 0.09277780979339566, 0.07798993294792515, 0.034401559204395325, 0.04970957385376096, 0.0230034855527005, 0.08240138087421656, 0.06017536922757115, 2.9763201432568684, 21.563211475099834, 41.68420621326992, 47.23251301901681, 37.27025188718523, 26.021040201187134, 19.726250205721172, 26.303204808916362, 49.31137234824044, 39.02554750442505, 22.18843296595982, 23.93557139805385, 11.978957533836365, 1.5143026688269206, 0.25920968662415234, 0.05414952703618577, 0.7513238042593002, 0.5330809408000537, 5.420056521892548, 9.712022628102984, 5.560663742678506, 7.8353376388549805, 14.527464713369097, 9.438058631760732, 22.349959475653513, 25.666440623147146, 28.117737293243408, 45.50774778638567, 49.71361746106829, 54.798726081848145, 54.76771627153669, 57.56569331032889, 53.57747943060738, 56.00731658935547, 55.48858492715018, 51.07599244798933, 51.706385135650635, 47.38479668753487, 47.934854303087505, 52.01620183672224, 52.60477679116385, 52.349256787981304, 51.489219188690186, 52.21986048562186, 51.265681743621826, 50.6871851512364, 50.27117565699986, 50.65950700214931, 52.82290506362915, 48.6086871283395, 45.92972578321184, 40.96847227641514, 37.47398001807076, 38.33305181775774, 40.31994479043143, 44.41594607489449, 49.031731673649375, 52.42746571132115, 52.0727219581604, 53.953641005924766, 55.90208959579468, 52.10334266935076, 52.7936600957598, 46.98923921585083, 27.446166106632777, 57.58825411115374, 47.17228255953108, 48.98217017310006, 53.61306462969099, 55.4002559525626, 51.71314920697893, 54.28996161052159, 47.95908267157418, 53.49348265784127, 55.191452162606375, 49.249797412327354, 39.68174580165318, 39.411342757088796, 46.018541131700786, 49.87135893957955, 52.864413602011545, 48.7930645261492, 49.67528077534267, 51.03443874631609, 47.59575094495501, 52.97188833781651, 50.20501491001674, 47.425992556980674, 39.467748233250205, 41.40217883246285, 47.31181280953543, 51.14984137671334, 51.80720002310616, 51.477521896362305, 49.68204484667097, 52.53446796962193, 52.58079160962786, 50.62863615580967, 46.511939661843435, 37.76160069874355, 32.71270261492048, 27.829439163208008, 9.593633140836443, 11.635860698563711, 7.66718602180481, 7.416721701622009, 8.369901640074593, 7.188641003199986, 6.405803535665784, 2.4665968205247606, 0.6769416012934276, 0.022578210337087512, 0.02811621129512787, 0.06333418722663607, 2.262860872915813, 12.423113312040057, 34.28218950544085, 43.58948564529419, 21.374590465000697, 18.67558877808707, 18.973077637808665, 32.00290938786098, 43.33639751161848, 50.17315394537789, 35.00817550931658, 6.142818995884486, 0.09487263738576855, 0.08707715211702244, 0.07848100909697157, 0.04536184036572065, 0.05833425944937127, 0.09334657141672713, 0.02633855980820954, 0.01950499292330018, 0.04029588434579117, 0.03051295643672347, 0.007720698835328221, 0.05449379195592233, 0.015322034879188453, 0.03969188639894128, 0.04108612997723477, 0.03610569651105574, 0.0950617790222168, 0.03776833800865071, 0.050693982280790806, 0.031334095767566135, 0.01966303899618132, 0.04155609350917595, 0.0838716576940247, 0.08731213557933058, 0.05204114570681538, 0.00821626094901668, 0.03810336467410837, 0.019942907549973046, 0.03680156809943063, 0.016522439662367105, 0.031047004208500897, 0.03898545002032604, 0.04004759141909225, 0.022798734218148247, 0.030433079294328178, 0.02642839784467859, 0.055479082478476424, 0.02196000556328467, 0.027296993914725523, 0.03209086926653981, 0.012926472084862846, 0.04016865902979459, 0.029127133478011404, 0.034992118765200884, 0.012891655604887222, 0.0052052338141947985, 0.04763342972312655, 0.007404497275794191, 0.0846234473532864, 0.04701523682368653, 3.2263278365135193, 26.766302245003835, 51.250708375658306, 54.715872287750244, 43.41221278054373, 32.9987599509103, 27.39860568727766, 33.37917729786464, 51.49372509547642, 46.032698086329866, 36.389703205653596, 28.08114981651306, 11.773107596806117, 2.168747740132468, 0.3376477376690933, 0.020089764580396668, 1.0809651272637504, 3.0922026336193085, 7.417325326374598, 15.79009917804173, 12.498957242284503, 10.730008414813451, 10.423205494880676, 8.80511508669172, 16.967935221535818, 20.302024841308594, 30.47829396384103, 42.72370188576834, 51.33205441066197, 53.88316542761666, 55.32495485033308, 57.81139898300171, 57.34670346123831, 57.336399282727925, 57.39445843015398, 53.16799429484776, 53.14983170373099, 49.12850965772356, 50.61991964067732, 53.48613493783133, 54.67886618205479, 54.61160067149571, 53.30573190961565, 51.60843290601458, 51.31051499502999, 51.92456899370466, 51.20131710597447, 51.61339044570923, 54.287043367113384, 51.39949015208653, 48.7162869317191, 44.27626991271973, 39.9574989591326, 39.89488179343087, 41.67165776661464, 46.48771129335676, 51.202421869550435, 53.68398141860962, 54.275665691920686, 55.49839925765991, 55.28325523648943, 50.588635376521516, 52.0630396434239, 47.42609330586025, 32.13303525107247, 59.06905419485909, 49.12122099740164, 50.02671371187483, 53.39694786071777, 56.39982727595738, 53.908397810799734, 55.82591649464199, 48.90256813594273, 53.49497652053833, 56.93502616882324, 49.55687999725342, 41.48336158479963, 41.68908037458147, 48.31205463409424, 52.356281416756765, 54.402355670928955, 49.69110877173287, 49.542118549346924, 51.8926420211792, 47.99412243706839, 54.07203483581543, 52.516732692718506, 48.41707665579659, 41.32707922799246, 44.080170903887065, 49.64154379708426, 52.15456131526402, 53.74847459793091, 51.59783690316336, 51.600859369550435, 54.92041335787092, 54.70461968013218, 53.418344838278635, 46.608453614371165, 35.93299463817051, 26.786269630704606, 23.605856793267385, 13.974778941699437, 12.627307840756007, 8.936178956712995, 6.59006324836186, 14.562991721289498, 8.86154227597373, 11.272989290101187, 4.334843873977661, 1.1217179404837745, 0.3746634785618101, 0.06096037317599569, 0.05974952743521758, 2.4716409955705916, 13.818906528609139, 36.456777640751426, 41.17370121819632, 23.694752046040126, 23.78320608820234, 24.92728951999119, 36.54778167179653, 49.04743807656424, 57.37896047319685, 39.43460880007063, 7.543531537055969, 0.16373425908386707, 0.13697958258645876, 0.05628209474629589, 0.026602971334276453, 0.022367416648194194, 0.07095849168087755, 0.05307314658005323, 0.021407226832317452, 0.003109916192313124, 0.038274650661540885, 0.020428624968709688, 0.04880954125630004, 0.021620731268610274, 0.0641054372702326, 0.034850053888346465, 0.049652081581630876, 0.1084480807185173, 0.016130007237994244, 0.03460758618478264, 0.025435070074828606, 0.04037597183404224, 0.01704503545936729, 0.010627413085395736, 0.0769082870600479, 0.06458421157939093, 0.007574026705697179, 0.1959409373147147, 0.09712018285478864, 0.10485787051064627, 0.1377422830888203, 0.12020536911274705, 0.17800233060760157, 0.17976030627531664, 0.11546580200748784, 0.13263575067477568, 0.0957770702828254, 0.12934458442032337, 0.10900271524276052, 0.09353546199521848, 0.1395814386861665, 0.1381425644670214, 0.12606743669935636, 0.13404289659644875, 0.17287344725004264, 0.15493285922067507, 0.14580603396253927, 0.1766515980873789, 0.07579964904912881, 0.21161662973463535, 0.18157484462218626, 5.3960986988885065, 33.708646978650776, 59.99431800842285, 63.20143972124372, 50.755201067243306, 37.543854577200754, 31.969915866851807, 38.09513507570539, 58.129449299403596, 50.754537514277864, 35.4770781653268, 33.008848735264365, 14.727738721030098, 2.250362583569118, 0.5540222685251917, 0.2141975462436676, 1.864088122333799, 3.5933266920702795, 12.828847289085388, 21.148351907730103, 16.26043837411063, 16.017374753952026, 21.490743500845774, 15.316089596067156, 27.463783264160156, 28.61176984650748, 32.5899418422154, 46.060661111559185, 53.103754724775044, 54.738905566079275, 57.0822411264692, 58.83212062290737, 58.89858709062849, 58.99135249001639, 59.354944774082725, 55.038668223789756, 56.071187904902864, 51.5893531526838, 51.621790817805696, 56.68733331135341, 56.12482104982649, 54.3047890663147, 53.96512637819563, 52.31036424636841, 52.31704493931362, 52.094514983040945, 51.75402545928955, 52.63738816125052, 57.09672812053135, 54.171546936035156, 50.227593081338064, 45.38366685594831, 42.05462857655117, 42.0277737889971, 44.8940029825483, 48.94717904499599, 53.68957471847534, 56.57353571483067, 56.53164849962507, 57.35290820258004, 57.25985097885132, 51.55581419808524, 51.48196874346052, 49.23205171312605, 38.098282609667095, 60.04394899095808, 48.919629437582834, 49.543060030256, 54.73439271109444, 58.61216844831194, 55.709266662597656, 57.1468836920602, 48.75278581891741, 55.105099950517925, 58.743739536830354, 52.63165589741298, 43.945771898542134, 44.75693586894444, 50.467194761548726, 54.30524417332241, 55.47384432383946, 50.611178806849885, 49.83457170213972, 52.39296095711844, 48.363544259752544, 56.46763474600655, 54.842374665396555, 51.89873211724417, 43.76783200672695, 47.29490784236363, 51.089603969029014, 56.2371768951416, 55.92365680422102, 56.338280132838655, 54.66492114748274, 57.43001931054251, 57.20410210745675, 56.41465820584978, 51.08150584357125, 39.115488461085725, 35.89482470921108, 32.112030846732004, 13.115800074168614, 17.13218716212681, 21.067714588982717, 21.406555652618408, 20.26126323427473, 16.897395372390747, 20.545022453580582, 5.215049488203866, 2.329592240708215, 0.4247355360005583, 0.1396064359162535, 0.19880331014948233, 3.1011582102094377, 16.51840761729649, 43.537377629961284, 55.1766733442034, 31.064923422677175, 27.32219113622393, 28.39851573535374, 43.24243354797363, 57.40014900479998, 64.24561500549316, 48.29738351276943, 10.982828174318586, 0.32568812370300293, 0.3183778588260923, 0.12353888952306338, 0.1324652891073908, 0.1956884137221745, 0.24611325508781842, 0.14015025459229946, 0.07722190594566719, 0.11528708945427622, 0.07815206210528101, 0.09424538604382958, 0.08992530285779919, 0.07896709122828074, 0.15309601064239228, 0.10902586007224661, 0.20075099063771112, 0.2130080879266773, 0.1361920748438154, 0.15432297837521347, 0.08722115081868001, 0.19489097222685814, 0.08569522055664233, 0.11953475938311645, 0.1736003618155207, 0.10494859742798976, 0.05479478669751968], [0.08209530051265444, 0.007531218779539424, 0.035969670595867295, 0.021320355690217445, 0.040569673225815804, 0.043096269613930156, 0.04775422591982143, 0.025283066356288533, 0.04281401261687279, 0.02116576166424368, 0.02239451733683901, 0.014075241201291127, 0.027367834667009965, 0.0526704801512616, 0.020547148073092103, 0.04336486770106213, 0.011223464539008481, 0.0658136016822287, 0.019886545038649013, 0.049456602428108454, 0.0572137606463262, 0.07266890882913556, 0.02137223817408085, 0.13258709971393856, 6.086466933999743, 29.40839297430856, 41.42461109161377, 51.698530197143555, 40.87662403924124, 25.53017255238124, 17.058822870254517, 16.324486868722097, 11.935293316841125, 29.512369292122976, 31.783155236925396, 25.68105094773429, 4.211372647966657, 0.8798802973968642, 0.08413974687989269, 0.14030783756503037, 1.061087199619838, 3.50658147249903, 3.0870320882116045, 13.133810673441205, 10.106588244438171, 7.107179888657161, 7.996529766491481, 10.898208669253759, 19.955203771591187, 25.596114431108745, 41.30968441282, 46.442499365125386, 55.1763676234654, 55.48524284362793, 55.950862475803916, 53.408638204847065, 54.005717754364014, 53.1391419001988, 52.026533808027, 50.06360517229353, 49.65369272232056, 50.4643668447222, 54.27868121010916, 53.583750179835725, 53.86641679491316, 50.86424262183053, 50.09243672234671, 49.98421852929251, 49.91242626735142, 49.593312876565115, 51.00670153754098, 51.20910951069423, 51.09964411599295, 49.17283569063459, 45.48266478947231, 39.84854078292847, 39.654078074863975, 37.693706376211985, 44.16131544113159, 50.96453639439174, 49.6419016293117, 52.548485960279194, 54.253900459834504, 56.86451932362148, 51.857376439230784, 52.267132554735454, 50.864645617348806, 46.641544410160606, 26.82652054514204, 56.967724391392295, 48.924149240766255, 56.8442097391401, 53.797907556806294, 52.674755573272705, 51.272275584084646, 52.3453414780753, 53.438616207667756, 50.393523011888774, 52.448935644967214, 50.881939683641704, 41.77062790734427, 38.57937935420445, 43.29165458679199, 48.41025005068098, 52.03733825683594, 51.9100090435573, 47.18224975040981, 46.57494592666626, 48.54416963032314, 50.3805958884103, 51.672074931008474, 49.31412730898176, 43.0330148424421, 39.50653655188424, 41.895289012363975, 46.00598921094622, 47.30649743761335, 46.350915159497944, 47.040961606161936, 47.83476550238473, 51.59612417221069, 53.83128670283726, 50.102824279240195, 43.58602544239589, 35.2706298146929, 37.295484270368306, 28.97496608325413, 19.47282334736415, 6.263378058161054, 5.080301770142146, 9.700378315789358, 5.015682654721396, 8.761039188929967, 5.359860369137355, 0.552938023848193, 0.27146313339471817, 0.04776382040498512, 0.02495862653345934, 0.2703409993222782, 6.762098039899554, 23.579592602593557, 41.06520162309919, 35.33183997017996, 16.521299804959977, 19.554853779929026, 30.542724609375, 44.103513377053396, 48.17670719964163, 40.63783877236502, 9.335821100643702, 0.8290896713733673, 0.037157283297606876, 0.027422828233933876, 0.012345747040983821, 0.08333029531474624, 0.005364424914919904, 0.03351348917931318, 0.032441770258758745, 0.03040532721206546, 0.07286247451390539, 0.023927579001922692, 0.0027550663383278462, 0.021705115579866936, 0.0390876814989107, 0.050479307371590815, 0.036943178357822556, 0.041762157808989286, 0.016968790175659314, 0.024846152568768178, 0.014511652024728912, 0.0769074321059244, 0.044891059199082, 0.028940471887056316, 0.031453918266509256, 0.04560657776892185, 0.006808274916173624, 0.03998568527666586, 0.05570208640503032, 0.032450251946491857, 0.056284554435738494, 0.07886613200285605, 0.0371323708843972, 0.007454616416777883, 0.06561033294669219, 0.08656879368105105, 0.05107059635754142, 0.03738394792058638, 0.030601603644234792, 0.008961004022109722, 0.01941288518719375, 0.035944021972162385, 0.09277880045452289, 0.022384931333363056, 0.08084118459373713, 0.05024158941315753, 0.0823871519948755, 0.02631319108019982, 0.07908977035965238, 0.04773677399914179, 0.03623318984838469, 7.842733996255057, 34.65538419995989, 49.38620097296578, 59.30567509787423, 45.975219113486155, 30.01706211907523, 21.81605815887451, 23.333577735083445, 19.766966649464198, 34.852445534297395, 33.51311077390398, 24.003592525209697, 5.023240123476301, 0.8790954223700932, 0.018084939569234848, 0.31655615514942576, 2.000187699283872, 7.3769736630575995, 12.109977977616445, 13.548819627080645, 13.103837881769453, 14.544859528541565, 10.913520761898585, 12.671198742730276, 17.65837597846985, 29.253785133361816, 41.34155579975673, 46.97950826372419, 55.70574740001133, 55.361703872680664, 56.00007656642369, 54.85582290376936, 55.9019957951137, 54.019638470241, 54.404130935668945, 51.20860229219709, 50.53568662915911, 49.703806604657856, 55.16386434010097, 54.03968402317592, 54.91494165148054, 51.94942617416382, 50.9973909514291, 50.11820411682129, 51.062467779432026, 51.16693047114781, 52.90179491043091, 51.701326847076416, 52.62579161780221, 51.37706136703491, 47.97840908595494, 41.00666652406965, 40.95541313716343, 39.69658715384347, 45.93923091888428, 52.85775375366211, 53.11465644836426, 53.988371576581685, 55.13552611214774, 56.88751091275896, 52.42618376868111, 52.09690168925694, 51.47938748768398, 48.364583015441895, 30.50753198351179, 59.31950896126883, 48.374084677015034, 56.60569545200893, 54.13404403414045, 53.97778599602835, 53.10458850860596, 56.65254715510777, 54.16980641228812, 51.14359147208077, 55.10670845849173, 52.84983280726841, 42.66717481613159, 41.065941606249126, 45.36905826841082, 50.9240596635001, 53.39151784351894, 51.647026675088064, 47.89839015688215, 46.93340696607317, 48.7969103540693, 51.618111746651785, 53.32850810459682, 50.0421838760376, 46.05483852113996, 42.02999026434762, 44.479192052568706, 47.74699238368443, 49.34883008684431, 49.209487438201904, 49.244447299412315, 51.08852352414812, 52.948115076337544, 54.02846963065011, 52.59544883455549, 43.86497824532645, 36.052611351013184, 29.1800126348223, 22.216682604381017, 12.60116524355752, 6.497966613088336, 8.046459521566119, 8.535391228539602, 11.023338777678353, 10.989349058696202, 6.706584104469844, 2.864143431186676, 0.759508130805833, 0.40633282491139, 0.023843196387003576, 0.4892018181937081, 8.096468312399727, 26.538121666227067, 44.60002817426409, 33.01897573471069, 15.748752185276576, 21.7258358001709, 34.50680044719151, 49.3728152683803, 54.39932973044259, 49.18102414267403, 12.072918023381915, 0.9864407479763031, 0.02103773398058755, 0.05975847052676337, 0.058552177755960395, 0.0428250014914998, 0.013984296304572905, 0.05953218588339431, 0.08560470398515463, 0.03173193781237517, 0.020339772504355227, 0.040052731321858506, 0.025362337906179682, 0.02407365232439978, 0.01375163852104119, 0.027733570131074105, 0.056391637439706495, 0.03927631762677005, 0.02152564306743443, 0.06240267399698496, 0.021018668842901076, 0.036864977196923325, 0.02983847905748657, 0.017931504141805426, 0.01619717033047761, 0.008855618203857114, 0.044185199575232606, 0.22609344577150686, 0.11658523551055364, 0.10862018434064728, 0.14814778044819832, 0.11773779509322983, 0.1301930517490421, 0.15425258715237888, 0.1100263667425939, 0.17273765882211073, 0.20338583711002553, 0.16302829767976487, 0.1423127321260316, 0.06752876857561724, 0.10749359229313475, 0.11002794094383717, 0.18026365712285042, 0.07999516677643571, 0.1426562608352729, 0.16517033773873532, 0.11768823489546776, 0.10397149343043566, 0.19479125472051756, 0.10585163932825838, 0.14573193793850286, 11.484243188585554, 43.41037845611572, 59.33669185638428, 66.92789758954729, 54.47993925639561, 37.803366320473806, 28.644125870295934, 26.56698795727321, 19.534431287220546, 42.40750673839024, 40.612092222486226, 31.747792380196707, 5.258887410163879, 1.4351680065904344, 0.1542788464576006, 0.7028634303382465, 1.622559945498194, 13.735053062438965, 17.37747767993382, 22.778409719467163, 20.39458179473877, 12.36854042325701, 14.70584147317069, 12.909100719860621, 23.318491458892822, 29.034830025264196, 45.33542551313128, 47.745043413979666, 56.74234219959804, 54.9725387437003, 57.63401147297451, 55.29123871667044, 57.56867756162371, 56.36262314660208, 56.97320999417986, 53.28631516865322, 54.45313310623169, 52.94361959184919, 58.39182022639683, 54.917679241725374, 56.09966162272862, 53.261058466775076, 52.25090503692627, 50.337124483925955, 51.090548924037385, 50.856498854500906, 54.71002537863595, 53.49633836746216, 55.10440513065883, 53.96794734682356, 51.29916511263166, 42.52502856935774, 43.62725257873535, 42.62838649749756, 49.513419015066965, 55.97935356412615, 53.83138745171683, 56.169928755079, 57.48102951049805, 61.17795753479004, 55.06088856288365, 52.35165044239589, 50.70314516339983, 47.89845616476876, 35.579300062997, 56.22063670839582, 49.21661976405552, 58.72176238468715, 57.49856676374163, 55.11363581248692, 54.95248624256679, 58.29006385803223, 56.6240873336792, 50.98990774154663, 56.8776409966605, 55.96096863065447, 47.18430641719273, 43.36474616186959, 47.12237712315151, 52.71889400482178, 55.80851125717163, 52.32985046931675, 48.51449040004185, 46.429902281079976, 51.35038028444563, 51.563863686152864, 55.924587862832205, 55.08129889624459, 49.34211812700544, 43.88267183303833, 47.122630732400076, 49.65613848822457, 52.086719104221885, 50.88262408120291, 51.83050080708095, 51.921424933842246, 56.531891686575754, 56.49572631290981, 52.83988993508475, 45.363558769226074, 38.05886895315987, 37.44152845655169, 33.18311997822353, 25.029639959335327, 12.87786248752049, 14.400540232658386, 20.310055221830094, 14.569907784461975, 17.971616404397146, 12.210127575056893, 3.2722491323947906, 0.82028771511146, 0.5357191935181618, 0.1882939969322511, 0.5534368285111019, 8.681921788624354, 30.630987576075963, 50.80405385153634, 46.17810998644148, 23.99611278942653, 30.143984862736293, 40.8514472416469, 56.39451885223389, 61.316907610212056, 56.15843643460955, 16.791166101183208, 1.15482654103211, 0.1592485997825861, 0.08803932834416628, 0.15137436373957566, 0.13954276219010353, 0.09180069901049137, 0.21671662107110023, 0.20899939803140505, 0.103186849105571, 0.14458362598504337, 0.13684509694576263, 0.1427405620259898, 0.054562259531979046, 0.10845198908022471, 0.12449482322803565, 0.17130936974925653, 0.0801050215959549, 0.1396750086652381, 0.19444286770054273, 0.09885712393692561, 0.14051362366548606, 0.11423366383782455, 0.12714332182492527, 0.1037209579455001, 0.17152836014117512, 0.09676908848008939], [0.04779767251706549, 0.00912852244385119, 0.05029411141627601, 0.010054866084828973, 0.04908955569512077, 0.027243175909721425, 0.02691322298986571, 0.020747804448806813, 0.05852376749472959, 0.026202089452583874, 0.06509375066629478, 0.03782257331269128, 0.03558935850326504, 0.03823299539674606, 0.04875084797718695, 0.015811402816325426, 0.03806405374780297, 0.028415991459041834, 0.029038062186113427, 0.006880385377111712, 0.02880928392655083, 0.01953680094863687, 0.0631882343441248, 0.02939272565501077, 11.70098442690713, 32.402361324855256, 39.9890125138419, 51.8451371874128, 34.293841634477886, 29.512925148010254, 18.375756638390676, 23.739762476512364, 30.825300897870743, 44.01315205437796, 37.97189487729754, 9.136196749550955, 2.181779520852225, 0.050443694461137056, 0.1974898563431842, 0.16707110431577477, 1.955495148897171, 2.6077040944780623, 8.041016476494924, 13.875211255890981, 13.106461695262364, 16.952004739216395, 16.79319323812212, 17.407511268343242, 22.637910195759364, 34.74265704836164, 44.012582302093506, 53.95566987991333, 53.60675566537039, 54.00385563714163, 49.27444614682879, 55.80810478755406, 53.6316545350211, 51.841711725507466, 51.03457076208932, 50.15238230569022, 51.55811752591814, 52.46786601202828, 52.48742866516113, 51.088551316942485, 49.131427901131765, 50.310043879917686, 50.425234590257915, 50.76066582543509, 48.25840064457485, 48.867670808519634, 51.55754082543509, 51.35518496377127, 49.771436895642964, 45.32414163861956, 41.067365986960276, 39.151358536311555, 40.128723417009624, 38.78698457990374, 49.759861196790425, 51.24810627528599, 54.20582587378365, 52.89477028165545, 53.1740357535226, 42.69286230632237, 45.742454460689, 55.59976305280413, 50.167473793029785, 49.83324112210955, 24.20038982800075, 52.1966152872358, 49.37946816853115, 53.56176955359322, 51.48794419424874, 50.87623173849923, 46.27381099973406, 50.166959626334055, 50.312163080487935, 52.94419976643154, 51.263381889888215, 51.54828235081264, 40.99780062266758, 36.44153676714216, 42.83421993255615, 47.0034830229623, 52.5922074999128, 51.53364249638149, 48.48051370893206, 47.414788586752756, 48.14602395466396, 49.434140069144114, 50.87789930616106, 51.97467245374407, 45.74808944974627, 42.940450940813335, 39.46348203931536, 40.19648224966866, 41.28182908466884, 43.99689326967512, 46.20255374908447, 51.172923292432515, 49.82050854819161, 52.125205176217214, 50.41621582848685, 50.80702420643398, 39.052933829171316, 36.32128082002912, 33.42150224958147, 21.48826125689915, 8.456194792475019, 2.755898096731731, 13.366057685443334, 7.212166735104152, 8.304183840751648, 4.51141540493284, 1.9109667497021812, 0.8599350047963006, 0.09801097719797067, 0.05546692652361734, 0.10833481286785432, 1.5344361599002565, 13.630493095942906, 33.851498467581614, 40.264043058667866, 31.091354370117188, 28.312462295804703, 30.28603036063058, 41.96915183748518, 49.169948714120046, 46.2511876651219, 19.307096651622228, 1.6021952096905028, 0.03587952721863985, 0.05693480811480965, 0.013823374091381473, 0.04744356883955853, 0.025555155506091456, 0.05431466888902443, 0.047834971587040594, 0.0330807772198958, 0.008708841749466956, 0.054818348826042244, 0.03140940636928592, 0.013941865813519274, 0.05269295323107924, 0.07481294378106083, 0.056486506813338826, 0.014211454561778476, 0.023771044365795593, 0.047501787144158564, 0.02956165712592857, 0.02968170014875276, 0.06832120248249599, 0.13874471001327038, 0.06809501961937972, 0.012565665329540414, 0.018997738803071634, 0.03890555930723037, 0.09597189804272992, 0.016955708020499775, 0.043481528226818354, 0.03345414450658219, 0.047851507485445054, 0.04264688604910459, 0.011918170743488839, 0.10289617827428238, 0.025483473370383893, 0.0424239805101284, 0.03151922047670398, 0.0811322693313871, 0.0711572210171393, 0.007729734377270299, 0.08418255565421921, 0.040691110638103316, 0.021976799304996218, 0.04944679420441389, 0.06648248114756175, 0.050082971674523184, 0.03129444218107632, 0.06518698137785707, 0.08153888144131217, 13.917797633579799, 38.44447660446167, 49.397721086229595, 58.1896276473999, 42.53255346843174, 33.337244919368196, 23.992096730640956, 22.810143879481725, 21.870247159685405, 38.07727473122733, 34.650562150137766, 11.415741767202105, 2.2840900080544606, 0.22233065696699278, 0.025687488494440913, 0.9043637407677514, 1.7891177109309604, 9.3502151625497, 11.007988469941274, 11.319871391568865, 14.249414307730538, 18.358459097998484, 7.722961817468915, 15.032952240535192, 21.51793701308114, 34.829318455287385, 47.462918758392334, 53.33870111192976, 56.19789178030831, 54.16046455928257, 51.795016356876914, 56.33711978367397, 56.19617557525635, 53.42991358893258, 51.2378820010594, 51.86887570789882, 53.35908712659563, 54.02812222072056, 55.14183855056763, 52.32184961863926, 50.266482148851665, 50.4196343421936, 51.99788638523647, 51.19443491527012, 49.989308084760395, 49.27395282472883, 52.25471612385341, 54.58153929029192, 52.201388699667795, 48.79169225692749, 43.46853487832205, 41.1750283241272, 41.57220125198364, 40.491968291146414, 50.72039754050118, 53.129438740866526, 56.38801186425345, 55.11700568880354, 53.69894436427525, 46.95438357761928, 48.786515848977224, 54.77003002166748, 50.687685421534944, 49.11983830588204, 28.24479031562805, 52.222938537597656, 49.78168896266392, 55.15327875954764, 53.76779753821236, 53.103806836264475, 48.33727312088013, 51.94480562210083, 52.3016095161438, 55.167081356048584, 53.0917204448155, 53.26691232408796, 45.571928296770366, 38.31746700831822, 43.139798232487266, 50.434041431971956, 53.58227021353585, 52.30378777640206, 49.181027616773335, 48.626940046037944, 47.825298581804546, 49.17694902420044, 53.58890574319022, 54.22338744572231, 47.74651295798165, 44.58960240227835, 40.395815644945415, 42.74639122826712, 43.26606437138149, 44.52634252820696, 48.06311804907662, 51.799320765904014, 52.904417855399, 53.499840259552, 52.27111039842878, 50.759119851248606, 40.15606457846505, 34.561764172145296, 26.130887746810913, 13.360918624060494, 7.131455591746739, 6.399355173110962, 13.607369491032191, 10.334302425384521, 8.923157164028712, 7.639678972108023, 4.914905548095703, 1.5430145795856203, 0.32531604224017685, 0.11300022966627564, 0.1617161873728037, 1.8276202848979404, 15.862753016608101, 34.53981481279646, 37.31575216565813, 25.505739212036133, 27.56638557570321, 33.81200838088989, 47.903865337371826, 53.514007636478965, 51.18337338311331, 24.026330505098613, 1.9142682296889169, 0.03868061816319823, 0.007369005653475012, 0.041194437736911435, 0.06845712661743164, 0.016943850621048893, 0.01671509611021195, 0.00317241350837451, 0.029874125894691263, 0.07338671745466334, 0.04031588077279074, 0.040348664192216735, 0.06449817333902631, 0.019317011581733823, 0.04986113143552627, 0.053008349878447394, 0.04629000841772982, 0.024065886491111348, 0.03329735202714801, 0.02955537728433098, 0.009315770119428635, 0.047902132983186414, 0.014381503919139504, 0.06572553462215833, 0.042952667855258496, 0.041441580546753745, 0.15420677246791975, 0.12277563262198653, 0.1875947258834328, 0.13102266937494278, 0.14714027808180877, 0.16678685242576258, 0.07948381600103208, 0.08315543005509035, 0.17408775351941586, 0.1155934344444956, 0.12273489337946687, 0.1404971352645329, 0.12412025832704135, 0.14958908382271016, 0.15760229740824017, 0.18723272745098385, 0.1195741415555988, 0.11931851027267319, 0.16906090825796127, 0.1504354884049722, 0.1672409823430436, 0.11093930846878461, 0.18244791563068116, 0.42133862684879986, 16.808448008128575, 47.329179831913535, 56.54855694089617, 64.94836275918144, 50.425321442740305, 41.03873940876552, 27.393686362675258, 33.820269789014546, 43.93118068150112, 56.3531562260219, 46.709160804748535, 12.120164036750793, 2.949764345373426, 0.417189032371555, 0.452634154685906, 1.062190986105374, 4.245832673140934, 9.024859683854238, 17.15061899593898, 23.302818059921265, 24.027275460106985, 32.91729579653059, 26.416222470147268, 21.466624566486903, 25.820636783327373, 36.884064061301096, 48.318387917109895, 54.33149446759905, 55.83286121913365, 55.2852771622794, 52.347988741738455, 56.23550237928118, 57.28305448804583, 56.477251052856445, 53.464307171957834, 53.724642276763916, 57.293487208230154, 55.511906555720735, 55.7073837007795, 52.74540833064488, 49.23617546898978, 50.956476484026226, 53.065921783447266, 52.23210321153913, 50.12919269289289, 51.26097086497715, 53.9375559261867, 56.483177866254536, 54.2155498777117, 49.9603271484375, 44.76291479383196, 42.48721647262573, 43.829921109335764, 43.05094119480678, 54.28693567003523, 55.37656954356602, 57.25523737498692, 56.7924804006304, 53.853764125279014, 47.09105116980416, 49.60543748310634, 54.88459192003523, 52.36753055027553, 49.81012446539742, 33.0630863734654, 54.613716397966655, 50.3656051499503, 56.22963809967041, 55.941343443734304, 55.635605335235596, 50.30713258470808, 54.46718583788191, 55.27107504435948, 55.98803186416626, 55.28836563655308, 56.06438214438302, 46.753545897347585, 40.75014598029, 45.90392017364502, 51.777850832257954, 54.30737727028983, 54.882497038160054, 49.79152413776943, 48.69995171683175, 47.9512312071664, 50.22589077268328, 54.22007662909371, 57.053023951394216, 49.710355281829834, 48.24405608858381, 41.911599908556255, 44.19089044843401, 45.17205251966204, 48.78950010027204, 50.30774750028338, 55.536534445626394, 54.83058704648699, 55.759668895176475, 51.58553164345877, 52.70236076627459, 40.862390654427664, 39.98354428155081, 35.3863068989345, 25.522362777165004, 11.691920501845223, 9.425927077020917, 26.542012657438004, 17.24470976420811, 16.88035317829677, 16.93884311403547, 6.462761827877589, 2.114069325583322, 0.6802133885877473, 0.28228712401219774, 0.3311250348176275, 2.1042955986091068, 18.448976755142212, 42.27857249123709, 51.810642855507986, 42.79820047106062, 39.41592161996024, 40.56208256312779, 54.3118553842817, 59.905867440359934, 58.93151460375105, 30.234353133610316, 2.912057340145111, 0.16662240267864295, 0.16772565990686417, 0.09209968189575843, 0.07700037783277885, 0.1780033212687288, 0.1410240177065134, 0.12081329577735492, 0.16434656908469542, 0.17706706507929734, 0.127172675249832, 0.12084456267101423, 0.12433827162853309, 0.11069971775369984, 0.14255977315562113, 0.18417311805699552, 0.12272981793752738, 0.11862127482891083, 0.06434869885976825, 0.12862007186881133, 0.07780638244003057, 0.16838938929140568, 0.23786737184439385, 0.14867519214749336, 0.10393314263118164, 0.07649187011910336], [0.015802668374297873, 0.04259873041883111, 0.052343857142009904, 0.03521346028095909, 0.01904208106654031, 0.04166872692959649, 0.04770346132240125, 0.023972308030351996, 0.026772275999454514, 0.062199255983744345, 0.046351521009845395, 0.0396147132185953, 0.05916424348418202, 0.029264133090951612, 0.017618192293282067, 0.036947249567934444, 0.06546737240361315, 0.061905945651233196, 0.014073205596235181, 0.025365208109308566, 0.07788139448634215, 0.028530504421464035, 0.016637614196432487, 0.865403237087386, 12.857149038996015, 34.95862095696585, 47.25721039090838, 46.51401717322213, 27.23620023046221, 21.408370869500295, 14.9857930796487, 34.17647961207798, 41.67940500804356, 38.00936303819929, 24.449357679912023, 6.071087530681065, 0.4449965645159994, 0.009612501116602548, 0.07694108065749918, 0.09854675523404564, 2.370712765625545, 10.53722630228315, 10.09889919417245, 7.931862882205418, 11.306524770600454, 18.427722215652466, 13.211138044084821, 26.315494435174124, 26.411358731133596, 38.361164229256765, 49.49113266808646, 50.76458808353969, 56.742814677102224, 49.29122257232666, 54.61651304789952, 53.60367413929531, 53.07432215554373, 53.35983058384487, 52.628279072897776, 52.54618263244629, 53.14734077453613, 50.14189747401646, 51.345756258283345, 49.62203672954014, 51.96095323562622, 50.37095178876604, 50.91766037259783, 49.12962831769671, 49.76346036366054, 50.26694767815726, 51.50579759052822, 48.118192945207866, 48.76262446812221, 44.10208204814366, 41.054970400674, 40.53196212223598, 39.43408421107701, 40.49810355050223, 45.55246639251709, 51.69567101342337, 50.99481316975185, 52.738717215401785, 52.61637333461216, 51.131185463496614, 49.13635764803205, 49.05704396111624, 52.41124166761126, 48.52447843551636, 19.582028184618267, 49.50308009556362, 51.3330271584647, 50.90936074938093, 53.42718642098563, 49.00464759554182, 41.093011787959504, 44.84725897652762, 51.415686403002056, 51.55077675410679, 51.95172602789742, 50.676307746342246, 42.10607998711722, 37.09052283423287, 40.143259048461914, 45.771935667310444, 50.42647136960711, 50.89491891860962, 47.049698965890066, 46.23548821040562, 47.60391855239868, 47.13216018676758, 50.115386622292654, 51.18190383911133, 49.477910246167866, 45.28427634920393, 44.724922043936594, 42.85267434801374, 44.83847645350865, 43.93707970210484, 47.09089136123657, 48.179437841687886, 50.37418270111084, 50.81933641433716, 51.975551400865825, 51.10156181880406, 50.65641505377633, 44.01568119866507, 34.3678434235709, 15.873010294778005, 9.885603393827166, 9.972342099462237, 5.180609004838126, 9.792221341814313, 6.8819518600191385, 4.572283361639295, 4.712213567325047, 1.5079714485577174, 0.3462004273065499, 0.13086170729781899, 0.06430114034031119, 0.6412755751184055, 7.548130375998361, 29.477298259735107, 51.64264930997576, 38.43687874930245, 22.441243171691895, 31.352276597704204, 38.08445569447109, 44.289558342524934, 45.534119674137656, 22.15153455734253, 2.415967902966908, 0.16182678858084337, 0.0627219450793096, 0.026092567115223834, 0.04137981689668127, 0.04282634159816163, 0.02914600692955511, 0.10643884353339672, 0.03942500839808157, 0.044486482694212875, 0.03699400741606951, 0.05315596856442945, 0.0262016755462225, 0.04930185912443059, 0.10734592950237648, 0.02445662597061268, 0.018732134751709442, 0.040418051183223724, 0.010233477705956569, 0.04244031624070235, 0.03625775620873485, 0.03150256583467126, 0.027045761235058308, 0.020098205556028655, 0.030000421617712294, 0.05808872476752315, 0.05785241137657847, 0.02166853066799896, 0.06544216482767037, 0.061107072447027476, 0.027804034296423197, 0.01546543138101697, 0.06542845842029367, 0.02312489243091217, 0.026756700228101442, 0.07622565368988685, 0.054720130882092884, 0.022396547852882316, 0.014987284716750895, 0.021975438842283826, 0.020456987732489194, 0.08074324484914541, 0.0518335445251848, 0.041967075384621105, 0.04230804601684213, 0.04926362367612975, 0.021923685280073966, 0.07552196537809712, 0.057361552358738015, 1.0352878868579865, 17.025980472564697, 39.97122165134975, 54.44877658571516, 53.71733972004482, 34.61435161318098, 25.96064645903451, 18.234798533575876, 37.09950338091169, 47.800326756068635, 41.597826208387104, 27.03705791064671, 6.165080155645098, 0.5438997202685901, 0.048212946126503606, 0.17420296876558236, 1.1237750415291106, 5.839037673813956, 11.264879873820714, 14.584124667303902, 15.071085691452026, 13.777882627078466, 14.511219825063433, 12.475299494607107, 16.89874505996704, 26.09046139035906, 41.37249960218157, 48.17825664792742, 52.12858200073242, 55.882999420166016, 51.86855609076363, 53.97287361962454, 54.021351201193674, 53.66657618113926, 55.90617861066546, 54.82308299200875, 54.05472339902605, 54.72930662972586, 50.632541043417795, 50.97069944654192, 51.09050376074654, 51.28443840571812, 50.978707245418, 51.38492325374058, 51.633460317339214, 50.80365433011736, 52.21309641429356, 52.07063055038452, 50.51658255713326, 50.219335147312705, 46.13272435324532, 41.88382795878819, 41.95853846413748, 41.258146149771555, 42.82788664954049, 47.652389185769216, 52.372529779161724, 53.559250831604004, 53.67870078768049, 54.68906961168562, 51.56336341585432, 49.10349266869681, 49.10227673394339, 52.442307063511436, 48.34037201745169, 22.513190031051636, 52.32591084071568, 50.709672995976035, 52.43385805402483, 54.856830392565044, 50.235948290143696, 42.24662814821516, 47.3820139339992, 52.926016330718994, 51.96997199739729, 53.32067748478481, 54.45684691837856, 43.60189512797764, 37.90252406256539, 42.285142013004844, 48.895154408046174, 53.1993202481951, 51.69166885103498, 48.13049473081316, 47.07694285256522, 47.46241153989519, 47.53854295185634, 49.257801737104145, 51.82000207901001, 51.81646892002651, 47.841272490365164, 46.98602914810181, 44.63389022009713, 46.829041549137656, 46.188792841775076, 49.78072663715908, 49.72975812639509, 52.30758844103132, 52.83443212509155, 53.39860848018101, 53.084681919642854, 51.075447014399934, 42.913019452776226, 33.36413097381592, 16.00215298788888, 9.771827510425023, 11.345790777887617, 9.323658279010228, 11.140830210277013, 9.315108520644051, 10.719758084842137, 7.972480314118521, 3.4010785051754544, 0.8268154391220638, 0.18854766046362265, 0.11784113597656999, 0.8335209935903549, 7.8064826386315485, 28.27701779774257, 46.640627247946604, 39.782157693590435, 26.986459391457693, 34.564241204942974, 42.729399408612935, 49.8701742717198, 53.50004175731114, 29.005908148629324, 3.1071277984551022, 0.12464350382132189, 0.022815146283911805, 0.02911057722355638, 0.06394783394145113, 0.024360940658620427, 0.03641643162284579, 0.10852089431136847, 0.07072872615286283, 0.02101189536707742, 0.04664153026949082, 0.03483956712963326, 0.06292891861604792, 0.018928227979423742, 0.013907447972867106, 0.021425157120185237, 0.09058950721685376, 0.027420838429991688, 0.057560261338949203, 0.016857524003301348, 0.023737268588904823, 0.009460419366535331, 0.06744638763900314, 0.03912947925605944, 0.04289554538471358, 0.04951188267607774, 0.1502353341451713, 0.11043198819139174, 0.10080434980669192, 0.2285254102732454, 0.059508640718247206, 0.08898159635386296, 0.14260186946817807, 0.09614178964069911, 0.13001923821866512, 0.16999586166015693, 0.1384344430906432, 0.13571426405438355, 0.1492684217435973, 0.09103556935276304, 0.07774745167366096, 0.2610636071435043, 0.14428296711828026, 0.14943843547786984, 0.09396963619760104, 0.16667502985468932, 0.18471384261335644, 0.16612180668328488, 0.16004518632377895, 1.6164171951157706, 20.528574330466135, 48.66580826895577, 61.70538139343262, 59.60873467581612, 40.254881858825684, 32.11490045275007, 24.641624757221766, 43.49144308907645, 52.57462508337838, 49.39325686863491, 31.2656603540693, 7.566867930548532, 0.663161423589502, 0.27319695321576937, 0.26645288509981974, 1.4658616738659995, 9.80836808681488, 25.165192365646362, 20.222467967442103, 14.338571855000087, 20.725778102874756, 27.589224304471696, 20.05726064954485, 30.934408460344585, 30.522397654397146, 42.512695516858784, 51.40951640265328, 51.79193830490112, 55.68812329428536, 52.31879241125924, 55.10230330058506, 54.07139212744576, 56.040865966251914, 56.130178110940115, 56.445820876530235, 55.78023208890642, 55.95035525730678, 50.66065692901611, 51.939295700618196, 49.844764709472656, 52.91764375141689, 52.386808327266145, 53.59785849707467, 54.0592223576137, 54.2648959841047, 54.87185934611729, 54.73353460856846, 52.01103237697056, 54.10606363841465, 48.30242095674787, 44.59247200829642, 43.12746170588902, 43.56739384787423, 44.49988031387329, 49.743859495435444, 54.40054219109671, 55.792367117745535, 55.31078052520752, 55.397129263196675, 52.13195187704903, 48.595940658024375, 50.10191406522478, 53.059036118643625, 49.67316852297102, 27.513464621135167, 52.39966596875872, 51.64015143258231, 55.445280279432026, 58.75521101270403, 52.026412214551655, 43.71816975729806, 50.088632583618164, 55.0193452835083, 55.32017796380179, 55.91994299207415, 55.65930216653006, 46.82272563661848, 40.89431415285383, 45.03500277655465, 50.783188411167686, 55.460844244275776, 54.4727965082441, 48.33472660609654, 47.606975759778706, 47.968434946877615, 48.6976066998073, 50.37155280794416, 54.56236226218087, 53.41860886982509, 50.321331228528706, 50.403375557490754, 46.53397587367466, 49.88266713278634, 47.94059351512364, 52.582698890141074, 51.74252271652222, 55.364319869450156, 53.606957163129536, 53.36109168188912, 53.67847497122628, 52.47750663757324, 46.74656295776367, 39.72221905844552, 21.58348110743931, 14.916714089257376, 17.58116238457816, 9.161372678620474, 19.71614405087062, 20.667517457689556, 14.191344738006592, 12.115249923297338, 5.911760125841413, 0.8156739483986581, 0.34744689613580704, 0.1783699473100049, 0.9659086040088108, 9.816245606967382, 33.85121359143938, 58.095097405569895, 47.25201313836234, 33.08666508538382, 44.24490227018084, 50.372737475803916, 57.66073077065604, 60.06342479160854, 37.15254592895508, 5.0623884456498285, 0.3575156772775309, 0.1073402976617217, 0.1358595248311758, 0.1335222702473402, 0.0847732068172523, 0.11916854046285152, 0.22546338529459067, 0.129741975239345, 0.13483446197850363, 0.18217282396342072, 0.12469758306230817, 0.17388153315654822, 0.20058424744222844, 0.13268484946872505, 0.13771233255309717, 0.22203588778419153, 0.08758661656507424, 0.12048884747283799, 0.2228466421365738, 0.14661254068570478, 0.12297375127673149, 0.15836992407483713, 0.17985676681356771, 0.10726852222744908, 0.106826979134764], [0.0668596380523273, 0.036978977865406444, 0.035492830111512115, 0.03505997905241592, 0.053596687237066884, 0.043162043405962844, 0.03577995899000338, 0.052818156512720246, 0.01746628017696951, 0.11602480629725115, 0.049023035514567576, 0.035798269257481606, 0.05747239105403423, 0.009059837736588503, 0.08267593649881226, 0.027303816584338034, 0.01641714629451079, 0.018558166854615723, 0.018212580487930348, 0.016569791228643486, 0.023732846236920783, 0.05063756209399019, 0.08504442404955626, 0.996066934296063, 12.763335330145699, 41.59327861240932, 49.15555204663958, 46.23877123423985, 37.83648838315691, 20.86817101069859, 16.435256787708827, 14.563976628439766, 21.88833679471697, 30.18654257910592, 16.649224826267787, 2.4519107171467374, 0.16161455639771052, 0.10359148667859179, 0.29374679337654797, 1.4526643306016922, 2.5250715570790425, 7.104027577808925, 12.930132916995458, 15.316687141145978, 13.563759991100856, 15.215134007590157, 9.493329814502172, 18.181148018155778, 34.65773269108364, 48.54806409563337, 50.649612767355784, 54.068112577710835, 52.53881754193987, 51.72138977050781, 51.52366140910557, 51.89482375553676, 50.377111366816926, 51.549091815948486, 52.97978149141584, 51.91919456209455, 50.88715778078352, 48.98617580958775, 47.65423045839582, 49.331383160182405, 47.845295497349326, 47.968827520098, 52.15167086465018, 49.79926095690046, 49.83615936551775, 51.01188489368984, 50.485148906707764, 48.43642391477312, 44.6984007699149, 41.00054516111101, 37.011334214891704, 38.96175956726074, 38.1021214893886, 39.27532829557146, 41.65275866644723, 48.8893735068185, 51.90875141961234, 51.99754939760481, 51.0465737751552, 53.13577202388218, 50.3375517981393, 46.72688218525478, 47.946225030081614, 47.336701256888254, 17.842386858803884, 49.213190828050884, 49.59388262884957, 51.05801745823452, 52.394218581063406, 50.58740554537092, 44.3025723184858, 38.09624678747994, 41.67515271050589, 49.66529968806675, 51.06437158584595, 48.78540761130196, 37.86765800203596, 36.44252341134207, 38.74624381746565, 44.29090281895229, 49.4634302003043, 49.43275390352522, 49.10919713973999, 48.64958422524588, 48.98964296068464, 49.76039273398263, 49.84821796417236, 50.86791821888515, 47.61219038282122, 48.16065338679722, 46.705669334956575, 46.643121651240754, 48.22527858189174, 47.656512941632954, 48.12917457308088, 51.14611366816929, 53.041603088378906, 52.1592687198094, 52.73618459701538, 52.790151255471365, 53.572337763650076, 45.35373749051775, 30.72408648899623, 18.24516871997288, 11.99081550325666, 10.246032510484968, 11.278682470321655, 9.363163999148778, 6.692800181252616, 4.9589393224034986, 6.87891332592283, 1.442250283701079, 0.5448976552912167, 0.17145133284585817, 0.12507182226649352, 0.1533075642905065, 2.8293509781360626, 18.062512738364084, 39.424617290496826, 39.05335072108677, 26.298391444342478, 26.398824180875504, 31.818813392094203, 45.83738422393799, 45.770931652614046, 33.46560246603829, 8.34755710193089, 0.33953990042209625, 0.10305448727948324, 0.05377657026318567, 0.09498855830835444, 0.020147647010162473, 0.0008146564058344146, 0.056545675066964965, 0.024920555629900525, 0.034798047571842156, 0.006477336424203324, 0.04287556931376457, 0.043116829224995205, 0.02427136216179601, 0.043736290984920094, 0.036275913805833886, 0.08068579328911644, 0.03333493268915585, 0.02065524548691298, 0.007996586933066803, 0.0045549737738578445, 0.027109614772988216, 0.03423460566305688, 0.03650022391229868, 0.03388045448809862, 0.0613565222759332, 0.027372628516916717, 0.026207529607095888, 0.010492636522810374, 0.032464107631572654, 0.061847835912236145, 0.03478207825017827, 0.009846739886727716, 0.03073511558717915, 0.028674828819930553, 0.05436174225594316, 0.014462605817243457, 0.042771427759102414, 0.005734539898445031, 0.005905962016965661, 0.06815520567553383, 0.0067203372018411756, 0.021810790623671243, 0.003498372613518898, 0.03917808950479541, 0.012733301646741373, 0.07318549789488316, 0.04705483952004995, 0.029005916589604955, 1.3906816222837992, 16.00863913127354, 48.63527093614851, 55.003645828792024, 50.735947608947754, 41.67541674205235, 25.686901330947876, 20.648335218429565, 19.986614840371267, 28.075327226093837, 33.249673298427034, 16.57822118486677, 2.8490955872195105, 0.3193683571049145, 0.0693113072110074, 0.6845482502664838, 2.976022456373487, 5.167428706373487, 11.412965961865016, 15.767939635685511, 13.022413679531642, 7.8918004376547675, 13.616986666406904, 11.041397145816259, 18.180710281644547, 31.858487606048584, 46.95563077926636, 51.51633105959211, 55.55796269008091, 52.071328844342915, 53.936301776341026, 51.233667918613975, 52.89035470145089, 51.63782378605434, 52.56814588819231, 51.366781507219585, 52.19436754499163, 51.413654054914204, 49.671553066798616, 48.7125175339835, 49.943026133946006, 48.398153236934114, 49.56712859017508, 55.12324864523751, 52.16785669326782, 52.79708555766514, 53.59020158222744, 52.70538670676095, 51.10009227480207, 45.16694211959839, 43.21886873245239, 39.658253942217144, 41.15723746163504, 39.544692584446494, 40.87735707419259, 44.01780039923531, 49.170025144304546, 55.057754925319124, 53.543276923043386, 53.31510155541556, 55.189513615199495, 50.62194504056658, 48.74463905606951, 48.242565699986045, 48.37689522334507, 20.975532838276454, 49.60335302352905, 49.725894927978516, 53.090976987566265, 54.84676940100533, 52.026745728084016, 45.85870129721505, 40.641444887433735, 44.13637835638863, 51.4869783946446, 52.518445423671174, 51.30245508466448, 39.69285249710083, 39.40555838176182, 40.71673904146467, 46.2269731930324, 51.33651168005807, 52.05691480636597, 51.038024016789024, 48.46735034670149, 49.17018495287214, 49.78925207683018, 49.59979901994978, 51.57239954812186, 49.94136551448277, 49.45755202429635, 50.007904938289094, 47.19712584359305, 49.54161480494908, 49.230738503592356, 51.189258507319856, 51.76706027984619, 54.417026792253765, 52.024188791002544, 52.142537457602366, 53.11048752920968, 51.21369532176426, 46.2621762411935, 33.14251470565796, 22.860966478075298, 14.486145513398306, 13.290027022361755, 13.580205508640834, 10.15976107120514, 8.732272778238569, 11.480716109275818, 9.164065974099294, 5.7969324588775635, 1.2959203528506416, 0.4342624933591911, 0.20173220655747823, 0.09607169018792254, 3.500449252980096, 20.148987293243408, 46.96116154534476, 44.10654279163906, 34.39963838032314, 34.33867488588606, 36.43745470046997, 51.16786847795759, 51.53433731624058, 39.3239483152117, 10.640227266720363, 0.39299510632242474, 0.045946031875376186, 0.042474314237811735, 0.04388657631352544, 0.04820419302476304, 0.09683709125965834, 0.019069397190053548, 0.012078181175248963, 0.022112404528473104, 0.031181608592825275, 0.05059207310634, 0.023791902532268847, 0.01470291069043534, 0.04561284403981907, 0.028467919744018997, 0.04994619937081422, 0.02123547435205962, 0.062005466382418356, 0.004153462975019855, 0.017849738975720744, 0.006898450523814452, 0.013529828816120113, 0.03645655679117356, 0.024271173868328333, 0.026038513319300752, 0.10637833178043365, 0.10426049506557838, 0.18840432672628335, 0.10779254803700106, 0.2261124583227294, 0.13281172194651195, 0.11016684384750468, 0.1157112145530326, 0.13973803099777016, 0.29909090804202215, 0.08839990863842623, 0.19052109814115933, 0.11179598607122898, 0.13836462183722428, 0.16369837815208094, 0.12541866222662584, 0.12082458660006523, 0.09626068933201687, 0.2072335784988744, 0.10220620994056974, 0.13492496497929096, 0.07940040369118963, 0.2525851492370878, 1.731139879141535, 20.783284868512833, 56.791135924203054, 63.48393957955496, 58.748054368155344, 50.17411627088274, 31.05409812927246, 24.91988100324358, 23.585079942430767, 32.28053508486067, 38.759139674050466, 20.996874230248586, 3.361489406653813, 0.48497601066316876, 0.35092172824910706, 0.883201536323343, 3.375736253602164, 7.965035319328308, 16.472533873149327, 19.645465237753733, 21.819266489573888, 19.730398280279978, 21.83110795702253, 14.75194103377206, 23.07718399592808, 35.6885917527335, 50.701706886291504, 52.77312816892351, 54.42984969275338, 53.01589822769165, 54.217748982565745, 51.57025602885655, 52.488589014325825, 51.19174248831612, 53.21594033922468, 52.958009311131065, 53.526774951389854, 52.84510455812727, 49.85051086970738, 48.94699839183262, 51.02807419640677, 50.01452309744698, 50.68647990907942, 56.56178283691406, 53.576444149017334, 54.166683197021484, 56.05862208775112, 54.06708771841866, 53.30881690979004, 48.78460509436471, 45.69549853461129, 40.38976376397269, 43.44766248975481, 41.33214099066598, 43.0817460332598, 45.86534377506801, 52.88200296674456, 57.18424762998308, 55.43794992991856, 55.59069217954363, 56.9774866104126, 53.162605966840474, 50.36279112952096, 50.42527627944946, 49.28757129396711, 24.329317126955303, 50.90537248338972, 48.642076696668354, 54.43659291948591, 57.52630049841744, 54.45440115247454, 49.28280482973371, 43.53031478609358, 46.249968256269185, 54.37917995452881, 54.506321566445486, 53.55072886603219, 43.29718882696969, 41.37483767100743, 43.75558928080967, 48.071851934705464, 53.073783670152935, 52.76113557815552, 53.06476143428257, 49.63615894317627, 50.78139230183193, 51.58048725128174, 51.28929172243391, 53.84003448486328, 51.63663216999599, 52.77496944155012, 51.98605012893677, 51.2637049811227, 51.60681397574288, 52.23121036802019, 54.791152545383994, 54.68563372748238, 58.3239780153547, 53.63069568361555, 53.962037903921946, 54.73843308857509, 53.593012128557476, 49.09305994851248, 38.71082190104893, 25.13639381953648, 18.059726510729107, 16.166361502238683, 18.20029204232352, 19.19905390058245, 13.85566771030426, 15.645390783037458, 13.368180360112872, 8.577608483178274, 1.8182372855288642, 0.5228329992720059, 0.31311424555523054, 0.4176099954971245, 3.9661125285284857, 22.962371962411062, 49.426389353615896, 47.302880900246755, 36.58017417362758, 37.4883245740618, 42.28928313936506, 56.83207818440029, 58.519396100725444, 49.46920067923409, 14.209376181874957, 0.6262678461415427, 0.17371024377644062, 0.14109948437128747, 0.16901484930089541, 0.10635055255677019, 0.21822727072451795, 0.1199748164841107, 0.11963193916848727, 0.07600286350186382, 0.11650048648672444, 0.17820826598576137, 0.11005946568080358, 0.1379888898559979, 0.1765926605356591, 0.0709886389917561, 0.17858298016445978, 0.15531691004123005, 0.11864806339144707, 0.15547344807003224, 0.12545432602720602, 0.10776453132608108, 0.11004571177597557, 0.11877279169857502, 0.16177186795643397, 0.12015633817229952], [0.025364178432417766, 0.05021335896370666, 0.04252344695851207, 0.015010778991771596, 0.020066758850589395, 0.02866271696984768, 0.011939672670061035, 0.05291108866887433, 0.035661235717790465, 0.0553634227918727, 0.035725459057305536, 0.026679806943450655, 0.05104151773931725, 0.03140422575441854, 0.01776158370609794, 0.023688617628067732, 0.04273003712296486, 0.03509991083826337, 0.016441122329394733, 0.019422006394181932, 0.040969455880778174, 0.09746723316077675, 0.02676747875687267, 1.1398309171199799, 19.10065872328622, 46.93518223081316, 47.708735602242605, 46.61082295009068, 37.85380676814488, 15.24696717943464, 18.363765784672328, 28.221691029412405, 38.718114035470144, 26.826124497822352, 9.934037549155098, 0.7522659365619931, 0.05801952776632138, 0.02247711201198399, 0.4774640308959143, 2.009560602051871, 5.658339781420572, 8.601129872458321, 16.427082232066564, 18.52495183263506, 8.074413861547198, 15.236649104527064, 16.838023015430995, 23.14021805354527, 37.91363770621163, 47.36900690623692, 53.38203355244228, 54.923126629420686, 53.809208801814485, 48.43922751290457, 50.321035930088584, 53.57159430640084, 48.45048706872122, 50.60990033830915, 50.08369936261858, 49.118521622249055, 47.76705878121512, 48.86302593776158, 49.61174644742693, 50.472756794520784, 50.61797414507185, 52.71408585139683, 51.70651715142386, 51.493669509887695, 48.805706773485454, 48.38809224537441, 46.35998255865914, 45.01472445896694, 40.987479073660715, 37.39333227702549, 37.005991050175254, 38.75283765792847, 37.56915296827044, 38.20639657974243, 38.75525215693882, 39.27639831815447, 43.31950644084385, 47.52749184199742, 49.91901315961565, 49.31765004566738, 53.57401575360979, 46.46726621900286, 46.45361648287092, 45.76646743501936, 15.161497388567243, 48.66960545948574, 49.87052862984793, 51.11207791737148, 51.87290218898228, 51.88598217282976, 48.96497685568673, 44.42218208312988, 37.289849281311035, 38.72154297147478, 41.595363071986604, 39.62933553968157, 39.235952854156494, 37.55583674567086, 37.57939461299351, 43.80343805040632, 48.72878674098423, 48.5684084211077, 48.20674773624965, 47.68682445798601, 46.874507086617605, 47.248181206839426, 47.61532749448504, 49.30008847372872, 51.737092699323384, 51.52261223111834, 51.0919246673584, 52.68765837805611, 49.22515215192522, 51.23117004122053, 51.59577676228115, 49.48186724526541, 48.55634634835379, 52.12479175840105, 52.549583775656565, 53.97430494853428, 53.68923078264509, 51.718989167894634, 42.73733425140381, 27.43424126080104, 20.26417452948434, 14.887747049331665, 17.559477056775773, 8.668305924960546, 5.188178632940565, 13.538661360740662, 7.661223598888942, 4.14032427753721, 1.441650893007006, 0.6197448990174702, 0.06857089658400842, 0.04869048210925289, 0.6160709847296987, 7.109821072646549, 26.654034989220754, 41.75303159441267, 19.14249382700239, 17.166167327335902, 23.401751722608292, 35.81818607875279, 46.77784027372088, 40.18810272216797, 16.75955179759434, 0.2456211814922946, 0.03943155626101153, 0.0851181468793324, 0.06746533912207399, 0.027333911308752637, 0.072981550624328, 0.01629117626829871, 0.08015585065420185, 0.013182906583616776, 0.07855681502925498, 0.01605864740642054, 0.03605990218264716, 0.05275635215054665, 0.04077827524659889, 0.022540792523484145, 0.044283638043063026, 0.08489296824804374, 0.057833595600511344, 0.04180481730561171, 0.07417645757751805, 0.04854757924165044, 0.008268435202938105, 0.062185305303760936, 0.06419389109526362, 0.022647649914558445, 0.05822719340877874, 0.01005174991275583, 0.02319684937330229, 0.023601534443774393, 0.010795695707201958, 0.06706148186432463, 0.024597157358324954, 0.0292497820753072, 0.03890329300026808, 0.06641887527491365, 0.021627065393009355, 0.006775708627953593, 0.006793078276262219, 0.030205227235066037, 0.017998584113749008, 0.023830880976415107, 0.08602555854512112, 0.05409912206232548, 0.020049705569233214, 0.055682001768478324, 0.06893055407064301, 0.12739338912069798, 0.031860957853496075, 1.606255671807698, 23.436612571988785, 54.188146182468955, 53.58827345711844, 54.51866851534162, 40.98009661265782, 18.86016767365592, 20.66016800062997, 22.483953748430523, 35.9267829486302, 29.659146513257706, 10.183986834117345, 0.8765506989189557, 0.0820579200184771, 0.04831048214275922, 0.7121075743011066, 4.420575090817042, 8.043862632342748, 9.186640671321324, 13.373074497495379, 16.430815151759557, 7.776476843016488, 14.684821435383387, 15.396539313452584, 22.257866314479283, 39.30405909674508, 47.37361008780343, 52.46831069673811, 55.06268119812012, 53.49656070981707, 49.61529002870832, 50.91204275403704, 54.01081425803048, 50.135102135794504, 50.704743249075754, 50.79052223478045, 49.99689204352242, 48.610055923461914, 48.338541167122976, 50.68296064649309, 51.4862835747855, 51.4347140448434, 53.21863971437727, 55.64581571306501, 52.25207928248814, 50.34073754719326, 50.84947769982474, 48.73267078399658, 47.280396529606406, 43.6029234613691, 39.48746027265276, 38.917694091796875, 40.696804659707205, 38.955158778599326, 40.00571945735386, 40.565664359501426, 40.936729431152344, 46.33517401559012, 49.088373388562886, 52.177907262529644, 52.50102628980364, 54.252469130924766, 48.89622095652989, 47.735253402165, 46.71994093486241, 17.70055501801627, 47.98544413702828, 49.242029326302664, 51.49843944822039, 52.77002232415335, 52.08105979646955, 50.5369998386928, 45.91813966206142, 38.94767904281616, 41.193128381456646, 43.25176150458199, 41.97416148866926, 40.43007026399885, 39.90343849999564, 40.20108890533447, 45.390528202056885, 49.97357388905117, 50.80148996625628, 48.68494013377598, 48.48120158059256, 48.49970810753958, 47.993174007960725, 48.18406186785017, 50.09744637353079, 52.92848294121878, 52.548298358917236, 51.7057980128697, 53.13788775035313, 52.31292118344988, 53.505193846566335, 53.18789740971157, 52.11751004627773, 50.503002302987234, 50.74070017678397, 52.47799301147461, 53.98590496608189, 54.51021255765642, 53.217830249241416, 42.5793947492327, 31.036901337759836, 16.873929568699428, 12.229246412004743, 12.042504021099635, 9.03533583027976, 9.647069999149867, 12.48433996949877, 9.878502334867205, 6.331753543445042, 2.8000745262418474, 0.830387138894626, 0.04718962710882936, 0.135860624057906, 0.7935351420726094, 8.070581061499459, 29.043906109673635, 40.94074896403721, 23.652112688337052, 21.98371819087437, 28.737408910478862, 41.04484340122768, 53.47988155909947, 47.44821637017386, 22.705627339226858, 0.37235214401568684, 0.04643639556265303, 0.04377325078738587, 0.017880527502191917, 0.033434304142636914, 0.05558564979583025, 0.08188209123909473, 0.04130613138633115, 0.032717096020600626, 0.04194642756400364, 0.02712498019848551, 0.018391476245597005, 0.04715893018458571, 0.0336456644082708, 0.030265861124332463, 0.025077546580827663, 0.03564738681805985, 0.0703510535614831, 0.08091054444334336, 0.06126934409673725, 0.040058753320149014, 0.02049115197067814, 0.013710648220564638, 0.0771629208964961, 0.039154167752712965, 0.14013259911111423, 0.14775984840733664, 0.1295528132468462, 0.08806409487234694, 0.047757839118795734, 0.10348576413733618, 0.11492933865104403, 0.13518963434866496, 0.10803166377757277, 0.16922638937830925, 0.14400072369192327, 0.09953363013586827, 0.12941758121762956, 0.20409152710012027, 0.11417145574731485, 0.14439875233386243, 0.17172133550047874, 0.17979162745177746, 0.11214340957147734, 0.09871587330209357, 0.1933656255049365, 0.28091949597001076, 0.25451699271798134, 2.6757419407367706, 29.994004522051128, 60.31376143864223, 61.122135707310264, 58.54983615875244, 48.882345403943745, 24.134147439684185, 27.698748758860997, 39.373610564640586, 49.920044967106406, 34.0399683543614, 11.434161441666738, 1.0782182003770555, 0.20803005647446426, 0.2528938555291721, 0.9763102744306836, 4.22607329913548, 16.14529456411089, 17.433817148208618, 23.217435121536255, 31.009400367736816, 15.105336836406163, 21.179339136396134, 20.70028168814523, 27.005096197128296, 39.83799341746739, 48.74752950668335, 53.47025830405099, 56.132474490574424, 53.27335330418178, 51.95302881513323, 51.73099912915911, 53.20189455577305, 50.513223103114534, 50.22800997325352, 51.979949610573904, 51.62308318274361, 49.02903229849679, 51.22742496218, 52.63929891586304, 52.09792307444981, 52.981508118765696, 55.86042124884469, 57.52097470419747, 55.10302938733782, 53.22064079557146, 53.79125118255615, 50.92162431989397, 49.307519572121755, 45.356725215911865, 42.03096996034895, 41.47518008095877, 44.68113449641636, 40.68683052062988, 43.31966624941145, 42.05726889201573, 42.95230804170881, 47.56236137662615, 51.574112279074534, 54.1029508454459, 54.266514914376394, 56.148330279758994, 49.370529311043875, 49.11829580579485, 48.32923058101109, 20.993375812258037, 47.81439338411604, 49.95689126423427, 53.97297089440482, 54.03106825692313, 54.264124734061106, 52.33758381434849, 47.64304733276367, 41.26544870649065, 42.83623143604824, 44.62468038286482, 44.56648921966553, 43.09919990812029, 42.30126878193447, 42.613162994384766, 47.304517201014924, 53.916766916002544, 53.636146545410156, 50.4447659764971, 48.71360840116228, 49.89929417201451, 48.588342802865164, 48.20546579360962, 51.653380802699495, 54.7277432850429, 54.99560328892299, 55.11293057032994, 55.838082790374756, 54.152818066733225, 55.67313602992466, 55.52231843130929, 53.621541431971956, 52.44346741267613, 52.51692724227905, 54.76507248197283, 57.781949043273926, 57.59684208461216, 59.42350264957973, 47.799795218876426, 33.20079272133963, 22.14543230193002, 21.453065156936646, 24.692690542766027, 16.405726943697246, 12.723563841411046, 23.013427325657435, 15.77766363961356, 11.868537630353655, 4.988573389393943, 1.4480724398578917, 0.2193360376570906, 0.1899040655366012, 1.0099490008183887, 8.968589697565351, 34.11498458044869, 52.332400458199636, 29.21436105455671, 27.67591003009251, 34.74763890675136, 47.22695098604475, 59.70389025551932, 55.01301547459194, 29.253701754978724, 1.1822210081986018, 0.22149558391954216, 0.24111169204115868, 0.10840125501688037, 0.11216455272265843, 0.1675083522817918, 0.08652635131563459, 0.11755806473749024, 0.15640616230666637, 0.13815871360046522, 0.13854044383125647, 0.08358853217214346, 0.16820793545671872, 0.07708688426230635, 0.09856232082737343, 0.14666782771902426, 0.20033962199730532, 0.12656915906284535, 0.10402739114527192, 0.12821749704224722, 0.14035505003162793, 0.11759323999285698, 0.1479588762990066, 0.18416239720370087, 0.2243408305304391], [0.03646415299070733, 0.014665557337658746, 0.05696935233260904, 0.0648116022348404, 0.02662239609552281, 0.03667139454877802, 0.07377320421593529, 0.07252645718732051, 0.02731435084050255, 0.032100623207432885, 0.05978423450142145, 0.07142320674444948, 0.04555741451414568, 0.0421862659443702, 0.059286447641040595, 0.11639808198171002, 0.06259867562247173, 0.06281453796795436, 0.02240744173260672, 0.10280662522252117, 0.0604608967634184, 0.07436540243881089, 0.0741371703999383, 2.3801518934113637, 19.131281171526226, 50.101802894047324, 45.100301946912495, 44.0629289490836, 47.46082387651716, 17.80435241971697, 20.202276502336773, 33.2271854536874, 39.531067167009624, 16.439986773899623, 3.5661568471363614, 0.20140988885291985, 0.1142523642629385, 0.04062813241034746, 0.6110879864011491, 6.212930228028979, 4.832679263183048, 9.909823945590428, 14.954025915690831, 8.432280829974584, 5.419170192309788, 20.058610337121145, 17.645091022763932, 26.82807173047747, 39.575837884630474, 49.209240777151926, 53.71940680912563, 51.84324727739607, 52.58557197025844, 49.01185635157994, 48.771775245666504, 47.77056414740426, 46.933650153023855, 48.10670757293701, 47.87766020638602, 49.495332854134695, 48.359694957733154, 49.12966305868966, 48.340479714529856, 51.060466698237825, 51.061967509133474, 50.50760201045445, 47.664409569331575, 44.98226942334856, 43.40840516771589, 44.19385038103376, 42.13876778738839, 41.41700281415667, 36.60361739567348, 35.99442713601248, 35.67803396497454, 36.90153530665806, 41.76429809842791, 43.718805517469136, 46.593539306095664, 43.02422884532383, 41.84406341825213, 41.02156693594796, 46.33566733769008, 47.93405178615025, 49.95750617980957, 46.89952754974365, 45.71966436931065, 40.84090682438442, 16.27846200125558, 46.72981432506016, 46.157894202641074, 48.170585836683, 48.90946422304426, 50.858531202588765, 50.423598289489746, 50.686125550951274, 43.02371120452881, 38.95343215124947, 37.208718640463694, 37.507692677634104, 39.385728222983225, 37.601000036512104, 38.177047388894216, 41.216425691332134, 47.98471457617623, 52.00388962881905, 49.22167805262974, 47.51286588396345, 46.51205430712019, 46.59641933441162, 48.456611905779155, 47.60116011755807, 47.65895175933838, 47.73786245073591, 48.764246872493196, 49.31130634035383, 50.13444900512695, 49.85340479442051, 50.0277316229684, 45.93463815961565, 46.7773608480181, 46.86024590900966, 50.25994389397757, 48.29405879974365, 39.309544699532644, 30.22976384844099, 28.9224967615945, 24.393193653651647, 19.49225398472377, 14.633521148136683, 15.458043030330114, 5.1663747514997205, 8.525318946157183, 8.528614129338946, 9.627110430172511, 4.678820524896894, 1.9338347911834717, 0.2537197412124702, 0.2021098384367568, 0.027172209628458534, 0.17638654873839446, 3.9865810530526296, 23.717601197106497, 42.28756693431309, 39.779517378125874, 23.59118914604187, 25.751910414014542, 41.245608125414165, 35.377239499773296, 46.91197872161865, 30.331631387983048, 3.7944012624876837, 0.2531443163752556, 0.006621834273183984, 0.09295298717916012, 0.01193677362919386, 0.08952447186623301, 0.024821810124974166, 0.08824462589940854, 0.013892113929614425, 0.05754467538957085, 0.016317233709352355, 0.02425483474507928, 0.029982854346079484, 0.04522250659231629, 0.020259622251614928, 0.03421432085867439, 0.06745040456631354, 0.06482965805168663, 0.027582077010135566, 0.03504965174943209, 0.011958557147798794, 0.10066647149090256, 0.041950444491314035, 0.02898145540218268, 0.04050738371110388, 0.022862153493666222, 0.03544846749199288, 0.005271099632539387, 0.034916865838957686, 0.04408236080780625, 0.0397317876507129, 0.05233099551073142, 0.009591664154348629, 0.024055789890033857, 0.04856777922915561, 0.06582715881190129, 0.04252801689186266, 0.030252436308988502, 0.03641611271138702, 0.054800052129264386, 0.050206756817975214, 0.0062958715633223096, 0.11209745239466429, 0.02666614294451262, 0.08788100576826505, 0.08551837397473198, 0.08449312791760479, 0.00928918257289167, 2.9939307868480682, 23.724076918193273, 57.00629384177071, 50.98712846211025, 47.43920455660139, 52.212860175541465, 20.776553801127843, 19.275430236543926, 33.46358054024832, 37.46428728103638, 18.17530632019043, 3.7631209066935947, 0.4270144908555916, 0.0420992132941527, 0.26955180881278856, 1.9043963594096047, 5.6517368214471, 8.4964839220047, 9.714857493128095, 16.35761066845485, 12.641501273427691, 7.24892748253686, 13.95777496269771, 20.652203627995082, 29.442314079829625, 43.14070497240339, 48.78989962169102, 54.58276564734322, 51.65608365195138, 52.61891637529646, 49.98060199192592, 51.561258111681255, 49.435144083840505, 48.50235537120274, 49.15900877543858, 50.03665658405849, 49.04635763168335, 49.6422837802342, 48.32070861543928, 49.58250495365688, 52.340502057756694, 52.69685084479195, 52.47172573634556, 50.35257380349295, 48.782812459128245, 45.30282803944179, 45.32757404872349, 45.299048219408306, 43.30336577551705, 40.017409801483154, 38.71588018962315, 37.888620717184885, 37.94559941973005, 43.976712226867676, 46.12366042818342, 47.69576678957258, 44.113237380981445, 42.67291750226702, 43.015355995723176, 48.625175203595845, 50.492507049015586, 51.088165691920686, 47.73188699994768, 47.8574652671814, 41.650305952344624, 17.88989516666957, 46.750825677599224, 46.67962053843907, 48.27984973362514, 50.81254802431379, 52.59942320414952, 52.29359129496983, 51.62081112180437, 46.08690445763724, 40.52332203728812, 38.85277707236153, 39.41781152997698, 40.860598019191194, 40.024740150996614, 39.97890288489205, 42.6984486579895, 49.23351778302874, 53.338009766169954, 50.459614276885986, 49.10210997717721, 47.57206801005772, 47.487796783447266, 49.80900580542428, 48.51141234806606, 49.65544714246477, 49.17012241908482, 53.584458896092, 52.69355045046125, 53.13264880861555, 51.988895416259766, 50.00090115410941, 48.02838747841971, 49.330003942762104, 50.909767218998496, 52.86809267316546, 50.801865168980186, 42.496144907815115, 34.16797154290335, 32.84171329225813, 25.504118544714792, 18.37666164125715, 10.888898951666695, 7.479720149721418, 5.092485436371394, 8.009463838168553, 11.726511240005493, 11.677427428109304, 7.114871544497354, 3.0702860610825673, 1.6833234620945794, 0.23499985571418489, 0.04415469942614436, 0.260709601853575, 4.527124847684588, 24.259906360081263, 43.22876991544451, 31.303180626460485, 28.927004405430385, 32.62557915278843, 45.06789207458496, 44.08657366888863, 51.0557210786002, 36.97014529364449, 5.201109230518341, 0.22559476324490138, 0.06314815328057323, 0.039391176642051766, 0.06525853968092374, 0.032853844575583935, 0.024235316685267856, 0.000858904787621993, 0.026114867168611715, 0.07112540451011487, 0.052184788177588155, 0.03437380033678242, 0.052443140385938544, 0.004881834270366068, 0.026223210551376854, 0.021629078945677196, 0.07749403241489615, 0.026259415483634387, 0.03960338507645896, 0.01130109657866082, 0.025264783230211054, 0.026779398920812776, 0.022875736068402017, 0.039284636466098685, 0.04313478326158864, 0.13403330211128506, 0.15313657346580709, 0.14460607192346028, 0.1770904338253396, 0.23785401827522687, 0.13004538895828383, 0.1341203445834773, 0.14149103978914873, 0.11681478390736239, 0.15454116809581006, 0.12876322918704577, 0.19566052593290806, 0.09125955376241889, 0.11936800261693341, 0.21190857621175901, 0.21177295063223156, 0.20516161753662995, 0.3118828944861889, 0.06177935137280396, 0.2060589665280921, 0.1518616604485682, 0.22336564000163758, 0.1546543070248195, 4.3868289930479865, 32.11696754183088, 63.764000620160786, 58.963643074035645, 54.940722942352295, 55.92273269380842, 27.005294220788137, 29.334196635654994, 42.54114491598946, 48.64653396606445, 21.72909450531006, 4.47128130708422, 0.6170283162168094, 0.41458424500056673, 0.4658373604927744, 2.198217438799994, 9.860710603850228, 12.330151626041957, 19.214049850191387, 26.498534304755076, 18.467611823763164, 10.594108598572866, 22.96168409075056, 20.8084043434688, 29.91212694985526, 42.39852966581072, 51.62364598682949, 53.865384987422395, 51.152728353227886, 52.43532064982823, 51.94862018312727, 52.78020143508911, 49.575125966753276, 48.55553688321795, 51.04090404510498, 49.343208994184224, 50.81516054698399, 50.87578705378941, 49.951850346156526, 49.46756785256522, 54.015382698604036, 55.39973136356899, 54.87332541601998, 51.15384006500244, 49.796457358769004, 47.041791915893555, 46.79770517349243, 46.3311892236982, 45.80173996516636, 41.7917434828622, 40.64848688670567, 39.28872094835554, 41.458615575517925, 46.954564230782644, 49.90965046201433, 51.13225548607962, 46.8750490461077, 46.55125951766968, 45.26025990077427, 50.79189797810146, 53.96201705932617, 52.97896160398211, 49.843399388449534, 48.65411445072719, 43.121764183044434, 22.041600159236364, 47.39679275240217, 46.89390645708357, 49.488266536167686, 52.9944143976484, 54.548424175807405, 53.446967942374094, 54.03019625799996, 47.21873821531023, 43.62293079921177, 41.46499054772513, 41.432452133723665, 43.33371550696236, 41.78601469312395, 41.90850101198469, 46.55384772164481, 52.45388971056257, 55.25678607395717, 53.10267080579485, 49.630218233381, 47.62805312020438, 48.12970263617379, 50.922614438193186, 49.373273849487305, 50.67169066837856, 50.1116623878479, 52.82380485534668, 52.98600707735334, 52.673914841243196, 53.21765654427664, 51.14789240700858, 49.69858503341675, 49.241730553763254, 51.87061275754656, 55.76611334936959, 53.653638635362896, 43.969499996730256, 34.32864168712071, 33.69029678617205, 28.74480526787894, 23.30235426766532, 20.818937812532695, 21.906289202826365, 13.822427528245107, 16.050953660692485, 17.73080747468131, 17.52282009805952, 13.637357916150775, 7.625666192599705, 1.5933513471058436, 0.6390925379736083, 0.2236278395035437, 0.4464723238987582, 5.56063551562173, 29.171935353960308, 52.42833423614502, 51.601112978799, 34.806062834603445, 36.729306834084646, 51.99008355821882, 51.20165409360613, 59.05884034293038, 44.37271090916225, 8.099917224475316, 0.43323340000850813, 0.14709208852478436, 0.1694372644914048, 0.16675749900085585, 0.2050003840454987, 0.1601021018411432, 0.22647071124187537, 0.1279331637280328, 0.20001585222780704, 0.1532288949404444, 0.07673775085381099, 0.194400052140866, 0.13784893522305147, 0.1139771504593747, 0.09612208498375756, 0.1279119120112487, 0.11070112910653863, 0.14415984015379632, 0.15345961041748524, 0.12048833178622381, 0.18386800800051006, 0.14708497747778893, 0.1828566515552146, 0.17431054370743887], [0.011053271841124764, 0.008392481582372316, 0.04409913758614233, 0.006171940958925656, 0.04370354827759521, 0.02883843718362706, 0.01824801697927926, 0.035546017078948874, 0.06348079150276524, 0.06440803674714905, 0.014740328504038709, 0.0110841791112242, 0.1118640499189496, 0.0881395683224712, 0.06478133957300868, 0.02411168590853257, 0.013864094674188112, 0.04929243088034647, 0.04041811903672559, 0.017406063586739556, 0.016339949365439158, 0.03765117197430559, 0.13994794259113924, 4.113819939749582, 33.42921127591814, 49.45604426520211, 48.02000447681972, 40.649657658168245, 26.757533618382045, 12.552860498428345, 19.865919419697352, 33.97423492159162, 29.0737555708204, 14.152123025485448, 0.9791148496525628, 0.10698872152715921, 0.08997763826378755, 0.31480073077338083, 1.6535860406500953, 6.609115208898272, 5.951952414853232, 4.212032726832798, 9.551045894622803, 14.18562810761588, 7.682510273797171, 14.993126903261457, 23.419375828334264, 30.01435579572405, 48.35570669174194, 48.24323967524937, 56.35169015611921, 53.85607092721121, 54.115103244781494, 46.42953402655465, 51.0142160143171, 49.158491134643555, 50.75647258758545, 48.41168137959072, 49.27630131585257, 49.8073000226702, 49.53800868988037, 48.077149936131065, 50.99582065854754, 47.690857887268066, 49.557057176317485, 48.071681703839985, 45.778574671064106, 39.59329175949097, 37.82970346723284, 38.47426700592041, 38.66897637503487, 35.87870488848005, 37.07396527699062, 37.076720237731934, 37.2992536681039, 42.05578197751726, 50.11187778200422, 51.80384404318673, 51.23340736116682, 48.89687756129673, 49.546217986515586, 46.725454330444336, 49.00864280973162, 46.6430869102478, 53.022804737091064, 47.15588828495571, 50.0330365725926, 32.547137464795796, 18.187062672206334, 47.841838768550325, 45.049072878701345, 48.87001582554409, 47.17521817343575, 49.261866433279856, 50.47403526306152, 49.54303571156093, 46.49919319152832, 42.43835326603481, 39.017501490456716, 39.09353910173689, 37.0868924004691, 38.61235897881644, 37.305548736027305, 37.95896775381905, 43.150963987622944, 48.421426228114534, 50.959571906498496, 49.30127314158848, 48.6845440864563, 46.13957527705601, 46.53183930260794, 46.8132517678397, 48.50656597954886, 48.53177056993757, 46.96415274483817, 48.28792701448713, 48.06984390531267, 47.167915616716655, 45.932223660605295, 44.62615687506539, 47.94306359972273, 46.833200045994346, 47.88931233542306, 45.93170254571097, 41.907295499529155, 31.5797050339835, 21.335633652550833, 19.82012731688363, 15.423901319503784, 10.702680281230382, 6.195253576551165, 3.129232406616211, 5.997319374765668, 9.330649035317556, 8.92427408695221, 5.551105626991816, 1.825713872909546, 1.0976795618023192, 0.1310323452843087, 0.016269683671583022, 0.09116835187056235, 0.7427352879728589, 12.028175098555428, 27.94826899256025, 40.39963715417044, 17.836861303874425, 23.285629953656876, 27.525521482740128, 38.566823959350586, 52.514689922332764, 34.183855124882285, 9.839702725410461, 0.16933487355709076, 0.05132038884663156, 0.012113975593820214, 0.028644630618925606, 0.07416044415107795, 0.05028045250635062, 0.01798237900116614, 0.03385934526366847, 0.05594519193151167, 0.03237273949863655, 0.08780137289847646, 0.07142184288906199, 0.03876637141885502, 0.03047715692913958, 0.037085090564297776, 0.014865882927551866, 0.018857862201652358, 0.024599084397777915, 0.03170371414827449, 0.01728049898520112, 0.04255681052537901, 0.04953709703737071, 0.03076111026374357, 0.0718588058703712, 0.03374540566333702, 0.06146312691271305, 0.023570019884833267, 0.03557653419141259, 0.028091287007555366, 0.023822865781507323, 0.0010354098755799765, 0.06498883558171135, 0.03731112414970994, 0.020804448552163582, 0.06729305229548897, 0.0221258853229561, 0.030529913026839495, 0.08273060606526476, 0.02977825907458152, 0.013344678661919065, 0.03873928090823548, 0.05083197255485824, 0.019331530534795353, 0.024719068048787967, 0.03407110247228827, 0.12416405097714492, 0.07277848544929709, 5.411647464547839, 38.1641480582101, 55.71087517057146, 52.708343165261404, 45.398219857897075, 34.08161238261631, 15.365840435028076, 19.32692333630153, 34.63274349485125, 33.71499415806362, 13.815514939171926, 1.4533653387001582, 0.15510239798043454, 0.0819927060178348, 0.4927077272108623, 2.2339670062065125, 9.244937794549124, 9.155430231775556, 9.762224231447492, 12.910638877323695, 14.191944020135061, 7.6334447009222846, 19.473174231392996, 24.706943035125732, 33.21690559387207, 48.0041834286281, 52.704674516405376, 55.59802600315639, 53.73444618497576, 52.94496406827654, 47.82995040076119, 50.99056087221418, 51.02837296894619, 49.592406136649, 48.86963367462158, 48.716714245932444, 49.73653956821987, 50.335710525512695, 49.477719170706614, 51.982687200818745, 50.373192582811626, 51.610103947775706, 49.36838926587786, 47.06632947921753, 41.950669629233225, 39.42550318581717, 40.45593840735299, 40.3029842376709, 37.94764913831438, 38.866266999925884, 37.80323430470058, 38.46787813731602, 42.40011732918875, 50.94004052025931, 53.70993294034685, 53.16236972808838, 51.63510704040527, 51.282023906707764, 48.09932163783482, 49.99395295551845, 47.56297976630074, 55.06638806206839, 47.8324830191476, 50.319701875959126, 33.84632553373064, 20.476032052721294, 49.250339371817454, 46.408196108681814, 51.07203892299107, 48.29715769631522, 50.69496018545968, 51.955863680158345, 52.28618104117257, 49.17333943503243, 44.69007682800293, 40.96207645961216, 40.26660346984863, 39.035997595105854, 40.78911147798811, 39.79148217609951, 40.63192932946341, 45.74239887510027, 50.89890023640224, 51.44053316116333, 50.765505245753694, 49.2483799798148, 47.65256983893258, 48.2514454977853, 47.058478014809744, 47.385529722486226, 48.372285093579976, 47.501078265053884, 48.59597887311663, 49.49439484732491, 49.49864714486258, 49.004755292619976, 46.03368820462908, 48.39971310751778, 50.07829019001552, 52.08854648045131, 49.779541969299316, 45.712080410548616, 31.75048828125, 22.212557111467632, 20.357256071908132, 15.791709423065186, 10.070455874715533, 8.870278767177037, 6.464881462710244, 7.967482822281974, 7.31327257837568, 10.864817363875252, 6.925488838127681, 6.104096685137067, 4.161197534629276, 0.29355015392814365, 0.2506411735500608, 0.12893602491489478, 1.1827891319990158, 13.994790622166224, 33.03016928264073, 42.310707909720286, 22.58948298863002, 25.121201583317347, 32.690176555088584, 42.45722804750715, 57.55755002158028, 41.53168283190046, 13.270014473370143, 0.2876276288713728, 0.04368920065462589, 0.04294414884809937, 0.011622030919949924, 0.01894383428485266, 0.03344799019396305, 0.00696089058848364, 0.04165927493678672, 0.08055211510509253, 0.01585794862226716, 0.028068447518827658, 0.06251669502151863, 0.049184615058558326, 0.012397475158130484, 0.05835181993565389, 0.06334384277995143, 0.028091524494811893, 0.030512556101062467, 0.016246311532865678, 0.047149864956736565, 0.026601319101506045, 0.07431864459067583, 0.0291471163343106, 0.02969429375869887, 0.22176258744938032, 0.1292850904698883, 0.07643289864063263, 0.1147932516677039, 0.21084531183753694, 0.13970156652586802, 0.0782830532906311, 0.12306618131697178, 0.09833218889044863, 0.1280814100589071, 0.11973336658307485, 0.13456397077866963, 0.16151173120098455, 0.15673696169895784, 0.13834125309118203, 0.06577344597982508, 0.10175277212900774, 0.16827671176620893, 0.17897194357854979, 0.10970560288322823, 0.11184404670659985, 0.19934377686253615, 0.24323290107505663, 8.08951837675912, 46.51254415512085, 64.19037682669503, 61.463181086948936, 52.133952958243235, 37.87775026048933, 19.543846096311295, 30.005726133074077, 45.196336473737446, 38.505929946899414, 17.054395130702428, 1.5198992256607329, 0.29635310066597803, 0.2421595672411578, 0.7810158995645387, 3.2486013727528706, 13.57216123172215, 16.831731421606882, 14.198768888201032, 16.518539633069718, 26.213894401277813, 11.774031707218715, 17.8998658316476, 26.262754133769445, 32.68208537782942, 49.81020089558193, 51.12570333480835, 56.96974631718227, 53.93518659046718, 54.83337327412197, 50.107590743473594, 52.916653633117676, 50.97846753256661, 50.43418387004307, 48.503904819488525, 48.90244306836809, 50.60378244944981, 51.67564630508423, 52.0741810798645, 53.901512145996094, 52.60499218532017, 54.358648027692524, 51.72926902770996, 49.793723242623464, 44.86862121309553, 42.05136987141201, 42.32259280341012, 43.38063669204712, 40.090306827000205, 39.83874034881592, 40.13739129475185, 41.99808413641793, 46.2983728817531, 54.03580345426287, 56.81206737245832, 55.077171666281565, 53.734571252550396, 53.30248015267508, 50.20839173453194, 53.08567551204136, 50.05575370788574, 57.09102712358747, 49.78910616465977, 52.62779269899641, 37.4084724017552, 24.64024380275181, 50.30627795628139, 47.81343453271048, 52.87149381637573, 50.30924136298043, 52.48312425613403, 54.133703572409495, 54.22087914603097, 50.788719177246094, 46.24505935396467, 43.674788679395405, 43.46498434884207, 41.992216382707866, 42.65254538399832, 40.98996305465698, 42.015121119362966, 47.09178420475551, 52.80587502888271, 54.908702169145855, 53.32938357761928, 51.610899516514365, 47.05320085797991, 47.72989634105137, 47.47896909713745, 48.404149532318115, 48.54961354391915, 47.82739346367972, 49.39701236997332, 50.52084527696882, 49.45061772210257, 48.00886304037911, 46.221696036202566, 48.26345198495047, 49.621619837624685, 51.576822076525005, 52.02344880785261, 47.72737414496285, 36.11610746383667, 27.45992006574358, 24.136966671262467, 19.090208632605417, 15.094798156193324, 10.109589866229467, 8.079829113824026, 14.323415228298732, 18.51607550893511, 16.616913965770177, 11.2368951354708, 7.558167917387826, 4.128800690174103, 0.5952237833823476, 0.37828188868505613, 0.20235369035175868, 1.3680670814854758, 16.25033221926008, 39.026367391858784, 53.12593337467739, 26.75381633213588, 32.63164145605904, 38.71501513889858, 50.770615645817344, 63.71474484034947, 49.64398261478969, 18.170419999531337, 0.8043583184480667, 0.14458240462200983, 0.13120241330138274, 0.16403654643467494, 0.12438537552952766, 0.13752037499632153, 0.13311369717121124, 0.14039268158376217, 0.1318220921925136, 0.19176299364439078, 0.2001386127833809, 0.20443850276725634, 0.12565253967685358, 0.15361973111118588, 0.15173594148031302, 0.07822771197451012, 0.12867016132388795, 0.09341964963823557, 0.09074057625340563, 0.20522358135453292, 0.13181097778890813, 0.16789978556334972, 0.16961103730968066, 0.18490068401609147], [0.024914961108671765, 0.02804969620358731, 0.033468590517129214, 0.013595042816762413, 0.020307011137317334, 0.017079574588154043, 0.037257346856806955, 0.04155870586899774, 0.06154788950724261, 0.04224458942189813, 0.02716988734235721, 0.028500513173639774, 0.03742476858730827, 0.029769974162003825, 0.03250919967623694, 0.05812049377709627, 0.1078172263556293, 0.026738294965720603, 0.03234617824533156, 0.04707889358646103, 0.04975391272455454, 0.032664207608572075, 0.15280358919075557, 6.139468661376408, 34.27511971337454, 52.09719351359776, 48.51535892486572, 39.702632086617605, 24.9499580178942, 19.206161907741002, 22.18018545423235, 33.36049011775425, 23.474492413657053, 5.450287699699402, 0.5158533709389823, 0.07503614109009504, 0.19382279525910104, 0.7347925741757665, 1.6617558194058282, 6.134689603533063, 5.552229063851493, 8.153050967625209, 20.05706783703395, 9.993457674980164, 8.835403152874537, 22.75171995162964, 30.83659519468035, 40.84857416152954, 45.99848863056728, 55.061100482940674, 57.355948039463584, 57.490621498652864, 51.411243030003135, 48.268687452588765, 51.99000365393502, 51.795103209359304, 50.034954275403706, 49.716726779937744, 48.48185818535941, 47.482728072575156, 46.16129534585135, 48.82891028267996, 49.16717290878296, 47.010500703539165, 45.94063445499965, 42.37157065527779, 39.24673645836966, 35.94720023018973, 37.23766483579363, 37.40415409633091, 38.670907974243164, 37.04219463893345, 36.38886594772339, 35.6216458593096, 40.83727639062064, 49.92760113307408, 50.174574851989746, 48.65946108954293, 53.06993784223284, 49.65626702989851, 51.29847376687186, 50.46914720535278, 50.1564678464617, 51.50040578842163, 51.46270138876778, 47.3469637462071, 45.89112506593977, 25.077648537499563, 25.77326570238386, 47.91885954993111, 51.367820262908936, 50.05963775089809, 50.12208815983364, 49.581528731754844, 46.36097962515694, 48.475253922598704, 44.47503008161272, 41.21790565763201, 35.765101841517854, 37.29127713612148, 36.768039567129954, 36.64404548917498, 35.83287109647478, 36.201038769313264, 40.352083683013916, 45.01159429550171, 47.53513833454677, 50.218977315085276, 47.546818256378174, 47.12693166732788, 47.794271400996614, 48.207956722804475, 46.85743883677891, 45.049184049878804, 46.76752914701189, 44.48221799305507, 46.32840647016253, 44.545974663325715, 47.97288874217442, 47.384456225803916, 47.67001676559448, 48.690241609300884, 49.66297551563808, 46.59470312935965, 44.6136257989066, 40.654399803706575, 42.64792830603463, 34.61869771139962, 27.127130883080618, 16.26869457108634, 14.196279696055822, 6.669520676136017, 6.569909129823957, 7.858304909297398, 10.509502121380397, 3.593641532318933, 4.034003811223166, 3.631126629454749, 0.2527883026216711, 0.08473485601799828, 0.10399746775094952, 0.7551091611385345, 6.939533318792071, 28.126629250390188, 32.29406322751726, 23.977291856493267, 21.226821388517106, 40.18624407904488, 39.4910420690264, 45.29198884963989, 40.089552947453086, 15.802098717008318, 1.3981475702353885, 0.05676468920760921, 0.038455514170761616, 0.01925655920058489, 0.09713680696274553, 0.09131028782576323, 0.06635295559785195, 0.02371087866569204, 0.08166384045034647, 0.04231058034513678, 0.03392626238720758, 0.06602915190160275, 0.025866430053221326, 0.04527150360601289, 0.011969453572029514, 0.04370031166555626, 0.027455253726137534, 0.04855798796883651, 0.04014640647385802, 0.03323637208502207, 0.04179216262751392, 0.015176987840927072, 0.037944981030055454, 0.07203329115041665, 0.012701864271158618, 0.016337667791438953, 0.027903337896402394, 0.04361549139555011, 0.018306895159184933, 0.025670272364680256, 0.04914001834445766, 0.016504651866853237, 0.04946840554475784, 0.01270431378257594, 0.007531056779303721, 0.03803424570443375, 0.05692992266267538, 0.015059521554836204, 0.032338395448667664, 0.059641857498458455, 0.13648415702794278, 0.04803614364936948, 0.018316460806610327, 0.026831681740337184, 0.04177731967398098, 0.09382689278572798, 0.2332435899547168, 8.055615510259356, 41.90500954219273, 56.91817331314087, 54.05393130438668, 44.23047086170742, 28.26157021522522, 18.64427672113691, 25.176649945122854, 37.60613822937012, 26.70767160824367, 6.761216921465738, 0.5492626982075828, 0.19436452404728957, 0.5021529346704483, 1.737058115856988, 5.851186164787837, 8.005584137780325, 8.532813446862356, 8.910262175968715, 15.006932973861694, 10.34078596319471, 9.471634932926722, 19.87516052382333, 28.902515479496547, 40.76716906683785, 48.77102484021868, 54.529097761426655, 56.08981949942452, 55.264651434762136, 52.80907467433384, 49.808755670275005, 52.21982227052961, 52.18445941380092, 50.69429663249424, 49.50497347967965, 48.7979074205671, 46.79451942443848, 48.70057010650635, 50.09977402005877, 51.64024175916399, 50.43396847588675, 48.47200563975743, 44.446827343532014, 42.03174121039254, 38.067901611328125, 39.798767362322124, 39.43684959411621, 41.17852326801845, 38.52825798307146, 39.35952309199742, 38.20764030729021, 41.125254903520855, 52.184872831617085, 51.99902241570609, 51.0237454686846, 54.28462886810303, 50.41973161697388, 53.86947052819388, 51.07256351198469, 53.68300519670759, 52.66581324168614, 53.04885005950928, 47.36044672557286, 47.42560693195888, 27.472279173987253, 26.95779112407139, 47.45206567219326, 53.53607164110456, 52.56365735190255, 50.53787183761597, 51.07426929473877, 48.67191573551723, 50.03420039585659, 46.116819926670615, 42.62862621034895, 37.95352036612374, 38.888581139700754, 39.70822538648333, 39.06228263037545, 38.71324334825788, 39.172428948538645, 42.23977722440447, 46.49171692984444, 50.698284898485454, 50.306931086948936, 50.2623097555978, 49.64998238427298, 48.102215562547954, 48.46274716513497, 48.313388688223704, 45.918862274714876, 48.1699674470084, 45.26591573442732, 47.31542239870344, 47.6239641053336, 48.535022326878135, 48.36417654582432, 49.590345995766775, 49.761129243033274, 50.47337171009609, 48.69263873781477, 49.19286387307303, 47.50325652531215, 46.659964084625244, 37.724466051374165, 27.798111472811016, 15.537665912083217, 10.382963265691485, 7.344093918800354, 7.88882052898407, 11.49569468838828, 11.771713614463806, 9.500678403036934, 5.436440374170031, 7.785297581127711, 0.8152346376861844, 0.22256411372550897, 0.11728541579629694, 0.5609040792499269, 8.539180602346148, 27.207412106650217, 37.535829407828196, 22.711750439235143, 25.804341520581925, 41.07036760875157, 45.051664556775776, 50.479489598955425, 45.31422308513096, 17.53662269456046, 1.8900702595710754, 0.01411383627315185, 0.0015508837054117716, 0.013182940510367709, 0.03964445001578756, 0.08457436213003737, 0.04851996965174164, 0.01031849390294935, 0.04749433343697872, 0.062360014500362534, 0.03305333387106657, 0.02300502752353038, 0.051620097764368565, 0.02299886642556105, 0.019821319163643887, 0.012323496181384792, 0.10033177052225385, 0.01986812281289271, 0.04264154937118292, 0.06770921139312641, 0.08692878364984478, 0.012942299762341593, 0.06034452122237001, 0.007041205810050347, 0.0775930510301675, 0.13896238404725278, 0.10679354771439518, 0.08516466724021093, 0.16568103033517087, 0.0882923404819199, 0.14335812388786248, 0.09264787712267467, 0.16614009998738766, 0.09373864252120256, 0.12191401528460638, 0.10865082019673926, 0.19787932187318802, 0.1518660844968898, 0.10896570115749325, 0.1417865146483694, 0.2239641078880855, 0.15075587907007762, 0.121867318504623, 0.20334925050182, 0.20539341866970062, 0.09400292512561594, 0.5311724660652024, 11.235813822065081, 49.895965984889436, 63.38733182634626, 61.518002373831614, 48.53698171888079, 33.72785874775478, 26.07154839379447, 32.12584733963013, 43.875925132206504, 30.790323666163854, 7.328455260821751, 1.1409684675080436, 0.246483463793993, 0.6642134242824146, 1.5742011346987315, 5.458253375121525, 11.026858908789498, 16.158675057547434, 19.15511522974287, 28.288534436907085, 18.088551112583705, 12.880724276815142, 25.394691365105764, 32.25864131110055, 41.17555638722011, 48.69443484715053, 57.59291287830898, 56.45152882167271, 55.79056058611189, 55.53644411904471, 52.7770539011274, 51.625435147966655, 53.46220186778477, 50.82581908362252, 50.20099885123116, 47.54735326766968, 49.07350076947893, 48.91295916693551, 52.96317877088274, 51.62705755233765, 52.28015347889492, 50.692729813711985, 47.06636422021048, 43.95835508619036, 39.422557149614605, 41.3540312903268, 41.46577222006661, 43.11258908680507, 41.11291837692261, 41.48357350485665, 40.592744963509695, 43.27321754183088, 54.5141521862575, 53.761283602033345, 52.269946575164795, 55.73277589253017, 52.232662541525706, 54.76969303403582, 54.49125092370169, 54.52036387579781, 55.72772107805525, 54.22960955756051, 48.43356820515224, 49.5018606867109, 30.34810209274292, 30.95519052233015, 50.289765562329976, 55.64701427732195, 53.61184869493757, 53.502629961286274, 54.19127287183489, 50.15359476634434, 52.01144926888602, 48.432369640895296, 45.64545413425991, 40.4038963999067, 40.925042561122346, 41.86354616710118, 40.329109464372905, 39.84772089549473, 41.13892201014927, 44.357011454445974, 49.27217755998884, 53.204468863351, 52.754152638571604, 51.20765038899013, 50.96288619722639, 49.53256477628435, 49.327242033822195, 49.914229324885774, 45.900185516902376, 49.41599137442452, 44.35437808718, 47.901145117623464, 50.4407707623073, 49.26558024542672, 47.537479877471924, 49.56026029586792, 49.18461288724627, 51.44894395555769, 49.270013196127756, 50.16757454190935, 48.79773718970162, 51.33226980481829, 40.43154328210013, 31.80348219190325, 18.301289319992065, 17.89870548248291, 15.238893372671944, 16.134239980152675, 14.329289061682564, 21.972700084958756, 16.259819984436035, 8.679824301174708, 7.9799713407244, 0.2866899477584021, 0.29993701406887596, 0.22108171827026776, 1.2538106867245264, 9.54864181791033, 34.02986567361014, 44.01958956037249, 35.09867579596383, 32.988594736371724, 49.65916790281023, 50.59167521340506, 57.607674326215474, 53.57179233006069, 23.208812407084874, 2.761293807200023, 0.10850965777145964, 0.09661187191626855, 0.1379055521850075, 0.15594124368258885, 0.22810116303818567, 0.1587182975241116, 0.14083153089242323, 0.16982702857681684, 0.1300713497080973, 0.12818726152181625, 0.10714870651385613, 0.13010295586926596, 0.12280174264950411, 0.11036897264420986, 0.15515608367111, 0.28478991399918285, 0.16473887089107717, 0.11703123657831124, 0.15929118464035646, 0.11510986967810563, 0.12435055311237063, 0.19885293820074626, 0.14091465143220766], [0.03530129324644804, 0.028467845105166947, 0.019280879591990794, 0.03619092729474817, 0.057762471559856615, 0.019664843899330924, 0.04875259181218488, 0.0314707662910223, 0.027796339709311724, 0.0396199820430151, 0.020015729624511938, 0.06524547788181476, 0.04892228324232357, 0.04107936159042375, 0.029442262104047195, 0.06836745142936707, 0.04515226125451071, 0.019250696658023765, 0.041527228629482646, 0.037460720765271356, 0.028370556754193137, 0.02759738645649382, 0.1478096800191062, 11.659158876964025, 42.475463594709126, 47.42101069859096, 43.657800333840505, 29.734940937587194, 21.39317168508257, 21.44807287624904, 34.74720117024013, 34.737143652779714, 20.884692089898245, 3.656429580279759, 0.16900902747043542, 0.07977054454386234, 0.3772944031017167, 1.8812004498073032, 7.621130755969456, 12.165004236357552, 7.103367064680372, 5.59196537733078, 10.317035283361163, 12.278919083731514, 10.260172963142395, 30.60248953955514, 31.3309143611363, 43.850741386413574, 59.09094796861921, 56.7881030355181, 58.09305463518415, 50.52632393155779, 49.126446042742046, 51.663261141095845, 49.089203698294504, 46.63098662240164, 47.91463157108852, 48.70257118770054, 48.69462939671108, 46.10805824824742, 46.459383487701416, 50.08423784800938, 49.69110877173287, 44.201639311654226, 41.826345511845176, 38.911176681518555, 38.13182503836495, 36.942870140075684, 38.22093915939331, 39.50909348896572, 38.783277715955464, 37.16921465737479, 35.57611778804234, 38.36875513621739, 47.24659006936209, 49.614355495997835, 51.10567167827061, 50.67448384421212, 47.422205788748606, 49.935872963496614, 48.23096220833914, 49.30074160439627, 49.306644099099294, 47.458461488996235, 46.4095892224993, 46.540785108293804, 42.063765457698274, 29.576410838535853, 30.352135522024973, 49.62405170713152, 50.8365158353533, 48.68338026319231, 47.51171595709664, 46.94618122918265, 44.627515247889924, 45.47549424852644, 42.81735665457589, 39.99378592627389, 38.318665572575156, 38.94835301807949, 38.18362038476126, 38.91630792617798, 36.542375973292756, 35.16142497743879, 36.72463764463152, 42.89243541445051, 46.9333062171936, 47.95343031202044, 47.20391075951712, 45.910646029881065, 44.3177923474993, 43.57896259852818, 46.23758309228079, 45.04615810939244, 45.74119336264474, 47.004344599587576, 41.352627754211426, 39.52936833245413, 44.963346004486084, 46.012923513139995, 47.529426915305, 48.36535426548549, 50.146987029484336, 52.14813423156738, 52.025863306862966, 47.32049805777413, 43.69301380429949, 41.94274173464094, 35.440857206072124, 23.779249089104788, 15.942827531269618, 10.538391862596784, 6.027155373777662, 6.204312290464129, 8.818904655320303, 6.202790200710297, 7.341183492115565, 8.893120970044817, 1.8318326302937098, 0.21401417894022806, 0.18440871898617062, 0.02680985157244972, 3.6704063160078864, 18.623242786952428, 38.60468469347273, 23.877124888556345, 15.802234206880842, 22.804871933800833, 33.712350368499756, 46.106255190713064, 46.375268595559255, 22.638356617518834, 2.067961948258536, 0.0788389973874603, 0.05195727199316025, 0.0064485627226531506, 0.03458228361393724, 0.038381034774439673, 0.035995241188045056, 0.030333188761557852, 0.03369405074045062, 0.04934687992291791, 0.1312735237713371, 0.02796355787930744, 0.033328174480370114, 0.02213374784748469, 0.030765456280538013, 0.05564357972304736, 0.024066093444292034, 0.030638400598296096, 0.03869758493133953, 0.018317130859941244, 0.028563959590558494, 0.06112057529389858, 0.036748167393463, 0.021837618201971054, 0.027800619568941847, 0.006406777263951621, 0.03494177825216736, 0.04765331758452313, 0.03167233868901219, 0.036327828520110676, 0.012485261474336897, 0.023334598767438104, 0.010869173416202622, 0.028210670155073916, 0.04088518522413714, 0.044916086963244846, 0.014787281430991632, 0.049604394140520265, 0.03746286154325519, 0.07054976932704449, 0.02539832061821861, 0.021205717198816792, 0.03941488465560334, 0.03842676464202149, 0.11302151530981064, 0.08795850125274488, 0.2539496288767883, 14.920153447559901, 48.16203260421753, 54.05840594427926, 51.846228054591585, 35.51115907941546, 25.158841712134226, 22.697614329201834, 32.873001030513215, 37.03773736953735, 22.642058270318167, 4.083342100892748, 0.1595740251775299, 0.06555374312613692, 0.3171894725944315, 3.1799097444329942, 7.183362977845328, 11.941112433161054, 8.48842922278813, 9.915249620165143, 12.5536447763443, 7.529837506158011, 11.29509585244315, 24.73487479346139, 33.09515578406197, 43.47256830760411, 57.76864671707153, 58.10080187661307, 57.36450822012765, 51.48959786551339, 51.81038924625942, 51.47954382215227, 50.15607527324131, 49.13442604882376, 49.58974150248936, 49.41010625021798, 49.32185023171561, 46.42089741570609, 48.17757225036621, 51.6803537096296, 50.837829044886995, 47.104037352970664, 44.36868790217808, 40.49422645568848, 38.74745280402047, 38.456802708762034, 40.6666043145316, 41.157883644104004, 41.03282996586391, 39.473126138959614, 37.05177273069109, 40.143835748944966, 48.33717584609985, 52.315884590148926, 51.96065446308681, 51.3748414175851, 48.16240780694144, 49.78074400765555, 48.82671812602452, 50.573849609919954, 50.33500180925642, 48.415999685014995, 48.42818682534354, 48.92707443237305, 42.92026989800589, 31.063610213143484, 33.4303160394941, 51.13776193346296, 51.82653685978481, 49.91484424046108, 51.120881284986226, 48.52844933101109, 46.977607931409565, 47.646472794669016, 45.64002064296177, 42.578474112919395, 41.639313902173726, 38.93227488654, 39.793253966740195, 39.75649104799543, 38.42683860233852, 37.7049172946385, 38.84789596285139, 43.54998166220528, 48.23735455104283, 50.93548597608294, 48.66446031842913, 48.69646372113909, 45.71895217895508, 45.311680044446675, 47.27765199116298, 45.64241777147566, 44.927983147757395, 47.29958745411464, 44.04343925203596, 42.57411411830357, 45.16072695595877, 45.661563532693044, 47.43110295704433, 47.208920410701204, 49.386881896427695, 51.14254229409354, 50.16824156897408, 45.486621788569856, 45.85216999053955, 44.894822869982036, 37.05132804598127, 25.58701923915318, 15.987870965685163, 7.94772561958858, 12.592664122581482, 13.085241896765572, 10.307800258908953, 10.532724738121033, 10.572473645210266, 3.910334995814732, 3.232624424355371, 0.22245448960789613, 0.18199872544833592, 0.174719523904579, 3.7065981796809604, 21.245261907577515, 41.86566884177071, 25.06310943194798, 18.733078173228673, 32.644464356558665, 39.47368546894619, 52.6883601461138, 51.33837379728045, 25.803450414112636, 2.917982633624758, 0.03405337913760117, 0.03433494742161461, 0.030631367582827806, 0.07255163083651237, 0.019741011151511754, 0.03650240879505873, 0.05323474648009453, 0.02980489835941366, 0.07652509797896657, 0.003398086197973628, 0.04085094295442104, 0.007834349210107965, 0.07022219976144177, 0.04286157792168004, 0.05875727853604725, 0.01541555396813367, 0.06343075633049011, 0.052734398150018284, 0.028552763762750795, 0.019394383233572756, 0.029960859633449997, 0.007524860906414688, 0.01083496761774378, 0.11728473726127829, 0.14828074617045267, 0.06212563493422099, 0.16035389261586325, 0.21103874860065325, 0.16443354370338575, 0.08187936352831976, 0.11394515074789524, 0.16448632015713624, 0.226438277267984, 0.10559475275554828, 0.172209568587797, 0.10605703866375343, 0.12024614906736783, 0.1921856395368065, 0.20516377527798924, 0.1595522849155324, 0.13332313379006727, 0.20923674958092825, 0.11004548785941941, 0.17898517501141342, 0.13957115209528378, 0.5273468856300626, 20.72518229484558, 56.75185080936977, 59.09777109963553, 56.59743751798357, 40.35980313164847, 31.397450310843332, 28.385055337633403, 44.20829568590437, 45.55026728766305, 26.301372221538, 4.9717331273215155, 0.2526019497641495, 0.24711694408740315, 0.930971541575023, 3.7940273625510077, 11.591056108474731, 21.99239127976554, 16.534906114850724, 12.891551307269506, 16.16288045474461, 18.464851651872905, 13.988353984696523, 33.13067497525896, 34.234552655901226, 45.98895222800118, 59.26670265197754, 60.788476262773784, 58.58026232038225, 53.30021503993443, 52.20462656021118, 51.3499355997358, 51.05842045375279, 49.032933712005615, 49.84598411832537, 50.45472969327654, 50.55993584224156, 47.56684643881661, 48.5924630846296, 53.798894201006206, 52.72674894332886, 47.96349825177874, 46.24473278863089, 42.42247315815517, 41.38021557671683, 40.25913415636335, 43.41666657584054, 44.72901105880737, 43.60390315737043, 41.30766943522862, 39.26644849777222, 42.52495561327253, 51.70078141348702, 55.117853369031636, 54.33824464253017, 51.34339039666312, 48.230371611458914, 49.74108716419765, 47.847894123622346, 49.4555162021092, 50.56900324140276, 49.142558915274485, 47.845483098711284, 49.016511644635884, 45.18324259349278, 34.34122487476894, 35.348863056727815, 52.52159643173218, 54.75337866374424, 51.85842561721802, 52.84018523352486, 50.83301394326346, 48.440189838409424, 49.26205750874111, 47.08406823022025, 45.01237596784319, 44.77637345450265, 42.117850235530305, 43.00464187349592, 43.23881353650774, 40.90415627615792, 38.81995030811855, 41.63017702102661, 46.338411876133506, 51.288850511823384, 51.484261648995535, 50.741412367139546, 49.71688311440604, 48.473506450653076, 45.69991758891514, 47.48106050491333, 44.624034200395855, 46.02210555757795, 47.11994525364467, 43.943833351135254, 43.59957790374756, 45.586943353925435, 47.341116837092805, 47.4461110660008, 48.56170688356672, 50.843575205121724, 51.50587054661342, 51.123024804251536, 48.706305844443186, 48.12691988263811, 45.85127714702061, 37.09583820615496, 26.04177188873291, 19.81520972933088, 15.794591188430786, 15.390400579997472, 15.501712458474294, 19.081749200820923, 15.442864690508161, 18.048267194202968, 15.26835720879691, 5.318927662713187, 0.6781828861151422, 0.5215341203979084, 0.2179746249956744, 4.843097218445369, 24.41472612108503, 48.30973046166556, 33.99411024366106, 24.51426775114877, 32.662307330540244, 44.70002317428589, 58.10878883089338, 58.45636204310826, 31.42761591502598, 4.32728944505964, 0.19654484705201217, 0.14395218129668916, 0.17362795104937895, 0.2818595383848463, 0.16949394930686268, 0.10284241115940468, 0.28840039883341106, 0.12912264918642385, 0.1558209801358836, 0.15660346671938896, 0.1047604125259178, 0.08475560561886855, 0.10499607452324458, 0.14220400367464336, 0.11816141807607242, 0.13577237379338059, 0.11554497347346374, 0.09506110048719815, 0.0822993970609137, 0.06713997479528189, 0.1670492012053728, 0.08777457076523985, 0.1599053538271359], [0.005684125594728227, 0.042138510649757724, 0.06729597678141934, 0.05176513801727976, 0.024550793060500706, 0.004704586504625955, 0.05116818665659853, 0.04301082509170685, 0.015923398413828442, 0.008892937629882778, 0.017576379269095402, 0.057303652965596745, 0.02926250799958195, 0.024015306794483746, 0.06229798961430788, 0.0446777447525944, 0.03983392413439495, 0.03924743578370128, 0.03868343408352562, 0.023730841165940677, 0.14696358756295272, 0.13791161828807422, 0.4418823059116091, 13.266159960201808, 44.54504707881382, 44.64281518118722, 40.11309691837856, 30.329130036490305, 18.8770135811397, 26.536765030452184, 27.890937668936594, 33.32965053830828, 12.950866341590881, 1.4486527230058397, 0.027654001722112298, 0.06349607211138521, 0.3620031007698604, 2.1050670657839095, 6.244560599327087, 5.244443408080509, 3.9924422928265164, 10.82112101146153, 15.206116982868739, 6.356013178825378, 11.831638353211538, 21.47158558028085, 39.44649369376046, 57.858076981135774, 58.947349548339844, 50.300938265664236, 51.93901082447597, 48.31049476351057, 50.71577698843819, 50.41369015829903, 49.87272426060268, 50.25710555485317, 50.76761402402605, 47.0935629435948, 47.386565004076274, 46.80806493759155, 46.744144984654014, 47.51472452708653, 48.962624890463694, 45.28909492492676, 41.05619328362601, 35.889735153743196, 37.394576004573274, 37.737344537462505, 41.3401974269322, 40.99561888831002, 41.07596785681588, 37.03483302252633, 35.49735648291451, 38.476629393441335, 46.704495089394705, 50.223743779318674, 48.838995592934744, 45.00640051705496, 44.892995493752615, 45.90527507237026, 46.87487881524222, 46.136038643973215, 45.6253981590271, 48.61323125021798, 47.155318532671245, 45.49639442988804, 41.33225563594273, 27.472324337278092, 33.63388088771275, 51.89731468473162, 46.764513628823416, 47.99627637863159, 43.391274384089876, 40.687483651297434, 39.92718744277954, 40.42145102364676, 39.252093519483296, 38.22990928377424, 37.36346891948155, 42.31357404163906, 41.18051045281546, 41.51103278568813, 39.741708755493164, 37.27675887516567, 35.65401751654488, 37.8367280960083, 43.71237843377249, 48.778865882328574, 48.79739325387137, 49.532457079206196, 48.48589161464146, 45.7813470023019, 46.33460773740496, 47.0857184273856, 45.66362019947597, 45.839809145246235, 46.81673976353237, 49.57546990258353, 47.428368840898784, 49.80584437506539, 48.98166642870222, 49.642672879355295, 49.586444582257954, 52.02458483832223, 48.663463251931326, 49.682649339948384, 47.50447940826416, 46.95317459106445, 37.942927837371826, 28.74596561704363, 18.04794236591884, 8.828052827290126, 7.875311493873596, 13.496904424258641, 8.394333243370056, 8.035137431962148, 5.45547843830926, 5.570004727159228, 3.928933152130672, 0.23961394812379563, 0.04543668617095266, 0.07623072234647614, 1.642044757093702, 11.593592200960432, 34.8186251776559, 44.588758196149556, 34.84477819715227, 17.083386489323207, 31.726041044507706, 40.96037415095738, 42.077161584581646, 26.73695479120527, 6.081360442297799, 0.06483478777642761, 0.08434769750705787, 0.005160973823097135, 0.03479736225147333, 0.07497605681419373, 0.029896263099674667, 0.08019085627581392, 0.023951751811962043, 0.015306438751784819, 0.033425588360322375, 0.0815758208877274, 0.03786522941663861, 0.019847743013607602, 0.013794615232784833, 0.03899549912395222, 0.09019208925643138, 0.0846330418384501, 0.03985992220363446, 0.10307727927075964, 0.011674106786293643, 0.009116830437311103, 0.01657926697017891, 0.0235435722861439, 0.03703354565160615, 0.027480761553826075, 0.007267673233790057, 0.025646923974688565, 0.04215496173128486, 0.0434869802556932, 0.03604305076545902, 0.04935547696160419, 0.025221172088224973, 0.014731894313756908, 0.018200639967939684, 0.041442720485585074, 0.0071851531974971294, 0.00871089262156082, 0.06403556851936237, 0.053414924668946435, 0.015920864085533788, 0.09168770257383585, 0.036808495941971026, 0.04446565166914037, 0.10652133303561381, 0.11787712547395911, 0.6355264836124012, 18.731153522218975, 50.31299339021955, 51.04546901157924, 44.27527632032122, 34.04761484691075, 24.659655332565308, 30.228252615247452, 33.99486064910889, 38.274144990103586, 13.882124713488988, 2.080923161336354, 0.08262216938393456, 0.14799428225627967, 0.7664078005722591, 3.0995525249413083, 6.201488281999316, 9.411627684320722, 8.506762044770376, 11.705532022884913, 9.904166374887739, 5.179269305297306, 11.242987837110247, 19.803441217967443, 39.18747527258736, 53.824533053806846, 61.9683290209089, 52.372453348977224, 56.17173181261335, 50.168665409088135, 52.49512032100132, 50.2351735660008, 50.03548928669521, 50.56809302738735, 52.029608385903494, 49.10759905406407, 49.864650453839985, 47.26135151726859, 47.00284031459263, 49.487974711826865, 51.51535831178938, 47.3367394719805, 43.309330804007395, 37.70744296482631, 39.51128911972046, 40.12423835481916, 43.60944781984602, 42.75492014203753, 42.14009141921997, 38.69666494641985, 37.96109390258789, 40.84844214575631, 48.41996015821184, 53.16942909785679, 50.828681741442, 45.14235591888428, 45.68729966027396, 46.10373994282314, 46.04991224833897, 46.71682466779436, 46.535872731889995, 49.16712774549212, 47.616004943847656, 45.44578375135149, 42.59725161961147, 30.139808995383127, 35.38832187652588, 52.35685811723982, 49.440702642713276, 50.63469845908028, 45.23191819872175, 43.148792675563264, 41.60377039228167, 42.71541615894863, 41.454036712646484, 40.27174513680594, 40.29571642194475, 44.318594864436555, 43.68894910812378, 43.345096656254356, 41.98767573492867, 39.12099143436977, 37.64526353563581, 40.165107658931184, 45.033293519701274, 50.96293136051723, 50.40919467381069, 50.31375074386597, 50.334355626787456, 47.12736940383911, 46.79345635005406, 46.532322202410015, 45.97638988494873, 47.00462252753121, 45.39947400774275, 48.60870449883597, 47.72752353123256, 48.82900408336094, 49.53115776606968, 50.83589744567871, 50.99395159312657, 51.639352389744346, 49.931783948625835, 49.760059220450266, 48.58727625438145, 46.90816763469151, 39.09338624136788, 27.858607700892858, 17.527979135513306, 6.834421404770442, 8.41493204661778, 13.182448063577924, 7.929425801549639, 14.046387944902692, 7.970248205321176, 10.311739887510027, 4.566115532602582, 0.8050683374915804, 0.24827208210315022, 0.013610599928402474, 1.7842090257576533, 13.185756274632045, 35.7041974067688, 42.13949040004185, 30.488042286464147, 19.834160940987722, 35.2291316986084, 45.92944785526821, 47.86897495814732, 32.1965765271868, 6.977856108120509, 0.14119082875549793, 0.03730967208477003, 0.04714345280081034, 0.024497378783832704, 0.03923304744863084, 0.02990234616611685, 0.04078057208763702, 0.018924511303859096, 0.013561108432311033, 0.03709512948989868, 0.07194924101765666, 0.09739633982202836, 0.025653936634106294, 0.03894796096054571, 0.07447074500045606, 0.061298242903181484, 0.07193835731595755, 0.028601960944277898, 0.01311634314645614, 0.029174610573266233, 0.06133430703942265, 0.036567056218960454, 0.021085906574236493, 0.17765886975186213, 0.1542871652969292, 0.16965970184121812, 0.15893983920770033, 0.1895398415092911, 0.16264469469232218, 0.12906002040420259, 0.07961448827492339, 0.09633786590503794, 0.1115511367097497, 0.15310424805751868, 0.137648360271539, 0.12749286235443183, 0.09575813237045493, 0.10373122418033225, 0.13080627098679543, 0.12145140367959227, 0.16404888220131397, 0.16423674140657696, 0.14503957437617437, 0.19963978097907134, 0.22142306209674903, 1.1385090223380496, 26.570253610610962, 57.35613216672625, 57.443665572575156, 51.02352312632969, 40.96478625706264, 27.284646545137676, 36.82622378213065, 38.17382342474801, 42.71641322544643, 16.875022172927856, 2.213760559047971, 0.29241805896162987, 0.3222696642790522, 0.682737050311906, 3.117989787033626, 10.109660216740199, 13.463302067347936, 12.70421745095934, 20.760225534439087, 24.738748414175852, 10.576530524662562, 16.499842030661448, 22.669715574809484, 41.3939208984375, 56.73187473842076, 61.32587078639439, 55.84566674913679, 57.590439319610596, 53.53125653948103, 51.970062323978965, 51.293488434382844, 49.95311491830008, 51.47641365868704, 52.866418157305034, 50.43083483832223, 51.63110140391758, 49.2244017464774, 49.13198375701904, 49.12344094685146, 51.68210812977382, 49.82540355409895, 44.91725165503365, 39.659268379211426, 40.959915569850374, 41.707423618861604, 46.1449670791626, 46.017888001033235, 44.796328680855886, 41.16869156701224, 39.93716158185686, 43.2433819770813, 49.592541626521516, 54.338237694331575, 51.78705024719238, 45.30428716114589, 46.95132984433855, 46.896512031555176, 46.48432404654366, 46.17843655177525, 45.84144197191511, 49.29640940257481, 47.63628326143537, 45.32001788275582, 43.06202704565865, 32.88764088494437, 38.01494591576712, 54.26989868709019, 50.91182735988072, 51.7396878514971, 47.5953687940325, 45.94740547452654, 43.62247221810477, 44.57405580793108, 43.51965972355434, 43.46951804842268, 42.139066559927805, 47.38728414263044, 44.800132819584434, 44.78568056651524, 43.939459460122244, 41.082662446158274, 38.889995098114014, 41.93913909367153, 46.97863973890032, 53.544847215924946, 51.810830456869944, 52.63325745718819, 51.760191985539024, 46.17674813951765, 47.39411769594465, 47.29182284218924, 46.22247076034546, 46.890800612313406, 47.283029896872385, 50.49089854104178, 50.63595955712454, 52.06471068518502, 51.7891069139753, 53.62125308173043, 51.9149283681597, 53.28822244916643, 52.018710136413574, 50.83769008091518, 50.21474238804409, 50.137957845415386, 41.53551128932408, 30.913765362330846, 18.986564091273717, 12.419890216418676, 14.393412249428884, 25.663875000817434, 13.188880358423505, 18.987210273742676, 11.375028797558375, 17.329807826450892, 9.416857072285243, 0.4301996970815318, 0.5123890968305724, 0.2321360579558781, 2.1416171959468295, 14.124845266342163, 43.052358627319336, 55.33629431043352, 44.70964642933437, 26.38892126083374, 42.3539708682469, 53.524169376918245, 54.517383098602295, 38.61529459272112, 9.979206919670105, 0.2960449100605079, 0.11130627377757005, 0.16956264419215067, 0.1789439743650811, 0.15446974549974712, 0.1521232628396579, 0.14925550243684224, 0.08838099108210631, 0.14131528564861842, 0.13649152591824532, 0.2597911368523325, 0.2748435405748231, 0.09038816552077021, 0.11653313759182181, 0.17561573295720986, 0.26307486636298044, 0.20144225497330936, 0.11050410967852388, 0.1653016342648438, 0.11647688703877584, 0.14610750707132475, 0.1527717930397817, 0.073853678469147], [0.10317473047013793, 0.037542830287878, 0.03952168946021369, 0.051970622169652154, 0.03979530870648367, 0.0419206907307463, 0.040928285768521686, 0.07022410644484417, 0.026118339571569647, 0.03414655556636197, 0.024057618541909114, 0.04964228353596159, 0.046399001497775316, 0.037096669764391015, 0.01730806447033371, 0.010735395148263445, 0.031606724352708886, 0.026855325293061987, 0.10898117854126863, 0.01591787683511419, 0.08762023118989808, 0.05812622739800385, 1.2094817225422179, 18.284328767231532, 49.7908501625061, 45.9059351512364, 45.620558738708496, 28.41321291242327, 15.848345926829747, 16.64275084223066, 29.83149310520717, 30.73743745258876, 9.056776234081813, 1.144919604063034, 0.04756615636870265, 0.07932181576532976, 0.6203223594597408, 3.928184049470084, 3.5706247559615543, 10.33383515902928, 8.68075796536037, 8.755824565887451, 9.564144986016409, 5.833612867764064, 15.529496567589895, 28.52936942236764, 47.99517856325422, 35.555551120213096, 38.63560765130179, 45.077876635960166, 42.88862780162266, 46.73073843547276, 50.42410898208618, 50.342766421181814, 52.1226030758449, 48.83487531117031, 52.78083719526018, 51.30145454406738, 50.62591593606131, 44.462245396205354, 46.22842536653791, 47.03495488848005, 51.11940826688494, 44.09064531326294, 41.477618898664204, 37.17436327253069, 38.61304337637765, 40.593620436532156, 42.29840612411499, 43.30514451435634, 42.23627533231463, 36.587660857609336, 35.90232181549072, 41.90732676642281, 51.075551237378804, 48.65676866258894, 46.953879833221436, 46.92003515788487, 51.582276412418906, 46.43898357663836, 49.119747979300364, 47.375305448259624, 48.90379101889474, 48.40721368789673, 50.37479414258684, 44.489412852696006, 47.958068234579905, 20.866048336029053, 34.63061039788382, 53.49723815917969, 45.647253717694966, 46.675573212759836, 37.58922283990042, 38.035238129752024, 36.81245592662266, 36.798799242292134, 36.87149824414934, 36.18313673564366, 37.92149611881801, 42.15508215767996, 44.57252720424107, 46.246539320264546, 42.73415892464774, 39.35281113215855, 36.19482013157436, 36.432194914136616, 39.85249778202602, 40.84267166682652, 45.18619210379464, 48.17266682216099, 48.94249595914568, 49.10491010120937, 46.00483928407942, 47.2132282938276, 46.79710415431431, 48.05215379170009, 50.32090391431536, 47.73083087376186, 48.8259607723781, 47.09239217213222, 48.690345832279746, 47.67225408554077, 48.82587391989571, 50.78020415987287, 51.755349091121126, 50.693250928606304, 47.97795745304653, 48.744524410792756, 44.38802126475743, 33.59686435971941, 25.37781071662903, 9.913634163992745, 9.810025232178823, 11.513130324227468, 6.607740334102085, 13.488299080303737, 6.847480978284564, 2.908762808356966, 1.5689776092767715, 0.8830989418285233, 0.5650960143123354, 0.07850344825003829, 0.45646505483559197, 6.4883129596710205, 30.960881096976145, 33.16819177355085, 29.768872465406144, 33.199500356401714, 31.89432294028146, 36.17365591866629, 41.88418231691633, 35.98032924107143, 12.732542651040212, 0.276429114065, 0.01118149799627385, 0.02079085579940251, 0.02413765344369624, 0.028880787946816002, 0.08877783228776284, 0.05573425914293953, 0.018246329123420373, 0.009955831354350915, 0.055819035308169465, 0.038476053425776105, 0.053337642922997475, 0.014993684998314296, 0.036290817827518494, 0.03502915320651872, 0.014163100460012044, 0.10668603384069034, 0.045838504430970976, 0.007165846331710262, 0.04327443255377667, 0.07739723939448595, 0.017538425412827303, 0.009224137357835258, 0.0344713533164135, 0.02865821149732385, 0.026004941102915576, 0.013587455098916377, 0.04092806185196553, 0.03341034507112844, 0.024907773726486733, 0.0908722256177238, 0.03382733537416373, 0.016677135468593667, 0.020664361604888524, 0.02016728211726461, 0.01739136821457318, 0.0354409255752606, 0.023301613483844057, 0.10893406785492386, 0.023057900668521012, 0.008666544420910733, 0.015007410065404006, 0.038393275546176095, 0.020912515431908623, 0.06326406741780893, 1.380042301756995, 22.697437150137766, 56.69965941565377, 51.24515676498413, 51.785827364240376, 32.5670405796596, 18.899845361709595, 22.332892962864467, 26.683248690196447, 30.76150253840855, 10.988729800496783, 0.8972095932279314, 0.06764128325240952, 0.09613621886819601, 0.6492891822542463, 4.368105334894998, 7.456189206668308, 8.00621121270316, 6.608768667493548, 12.205815349306379, 8.409707869802203, 8.584891932351248, 14.956060000828334, 29.138453722000122, 46.56711878095354, 41.26093585150582, 42.0175529888698, 51.5277886390686, 48.209252561841694, 49.69776862008231, 51.272188731602256, 51.35605001449585, 52.02085712977818, 49.97481066840035, 53.25736549922398, 54.052625043051584, 51.61646154948643, 47.731647287096294, 47.34452840260097, 48.80151006153652, 51.02480159487043, 45.385779108319966, 42.62724004473005, 39.70787450245449, 40.1744703565325, 42.50797769001552, 44.43304211752755, 45.824450152260916, 44.3303199495588, 39.77799572263445, 37.169461318424766, 44.008739948272705, 51.85875218255179, 49.95388616834368, 45.81709895815168, 47.98656627110073, 51.57139205932617, 47.64031669071743, 49.41199616023472, 48.499881812504356, 50.020640986306326, 49.26212351662772, 51.94043867928641, 46.163727215358186, 47.41363171168736, 23.316290616989136, 37.744032178606304, 55.25031730106899, 47.406666142599924, 47.08094848905291, 40.83868340083531, 40.82157693590437, 38.514514446258545, 38.527181012289866, 37.85604061399187, 38.20378405707223, 40.16157449994768, 43.58519860676357, 46.89612988063267, 47.90809679031372, 44.22518328257969, 40.5020431791033, 38.47260291235787, 38.27412067140852, 40.06323317119053, 44.54812513078962, 47.31687804630825, 50.96624565124512, 51.24839809962681, 48.64300775527954, 46.45512424196516, 48.47612244742257, 46.305637223379954, 49.51567717960903, 51.142695154462544, 50.393071378980366, 49.46365949085781, 50.31092977523804, 50.35458878108433, 50.78961896896362, 49.525286538260325, 52.78588853563581, 52.306751183101106, 52.103905473436626, 50.01150063105992, 50.88982588904244, 43.97517320087978, 32.695787225450786, 20.24051070213318, 10.827667083059039, 9.52390536240169, 12.469051327024188, 8.966605986867632, 8.346414991787501, 11.968522208077566, 7.340988074030195, 5.076713459832328, 1.0608124200786864, 0.5939964492406163, 0.09568482344704014, 0.5662956642253059, 8.142852749143328, 32.334067480904714, 43.74324580601284, 34.959267139434814, 34.94670132228306, 36.8608466557094, 42.00205503191267, 49.96279028483799, 40.44148962838309, 15.991397176470075, 0.4328939696507794, 0.011296540216010596, 0.0254387375566044, 0.011075213119121534, 0.07931161738399949, 0.035869803811822615, 0.06078323482402733, 0.026658188817756515, 0.02160318265669048, 0.0469072174413928, 0.012857602476807577, 0.055056158386703045, 0.05431035001363073, 0.03562478142391358, 0.04995584474610431, 0.043219980118530135, 0.01638514149401869, 0.05208213261461683, 0.011134494179194527, 0.04854211024940014, 0.008893522866336363, 0.02876357441501958, 0.037771116609552076, 0.21608027735991137, 0.1773828145648752, 0.1331940492881196, 0.08529849470193897, 0.09064637523676668, 0.09736130027366535, 0.20987990578370436, 0.19419293611177377, 0.12661198819322245, 0.05893189952309642, 0.11418904337499823, 0.15948181226849556, 0.14240574570638792, 0.13101268133946828, 0.09094955825379916, 0.14731932990252972, 0.19648466099585804, 0.043242371774145534, 0.17625935056379863, 0.14443479611405305, 0.16827443188854627, 0.13552259148231574, 2.1409223760877336, 28.882327488490514, 62.5822023664202, 59.46173858642578, 56.45052480697632, 39.711164474487305, 23.469703367778234, 26.474161761147634, 39.31210511071341, 38.62281601769583, 12.364380189350673, 1.6088431158236094, 0.1806985302163022, 0.3059645492051329, 0.8271492240684373, 8.498520612716675, 10.78262972831726, 21.23190746988569, 18.9630183832986, 18.62785291671753, 16.3667597089495, 9.960625699588231, 19.404178619384766, 33.11290495736258, 53.503418581826345, 39.624041012355256, 47.06586047581264, 54.42336354936872, 49.79298325947353, 49.05691541944231, 51.80491406576974, 50.4702137538365, 54.56231015069144, 51.6878091267177, 56.31099108287266, 55.04713807787214, 53.585139819553916, 48.95516947337559, 49.10784224101475, 51.43345294679914, 54.84609195164272, 47.43732506888253, 45.12052467891148, 40.948402404785156, 42.67618662970406, 45.293652943202424, 46.96973214830671, 48.624942438943044, 46.90609359741211, 40.983473437173025, 39.987928594861714, 45.91138253893171, 56.863365922655376, 51.8419896534511, 47.54769720349993, 48.91171891348702, 51.57795810699463, 47.8861335345677, 50.34459727151053, 50.24720784596035, 52.211095333099365, 50.52272823878697, 53.34464182172503, 46.03686353138515, 49.160488741738455, 25.70848764692034, 39.504545892987935, 55.48792484828404, 50.046512603759766, 50.364146028246196, 41.525922775268555, 43.00374902997698, 41.06823451178414, 39.12472261701311, 40.308136326926096, 39.92611742019653, 41.25878538404192, 44.99766663142613, 49.72991793496268, 49.660894530160085, 46.4301107270377, 41.07324416296822, 39.86908313206264, 40.33658920015608, 42.94809395926339, 45.46564517702375, 49.258006708962576, 53.49003635134016, 54.25964662006923, 51.27975879396711, 48.10870170593262, 47.68003606796265, 47.46149785178048, 51.672589097704204, 53.34433262688773, 51.60805422919137, 52.87188638959612, 52.52975361687796, 53.37757280894688, 52.82391255242484, 53.65692513329642, 56.540330273764475, 55.627451624189106, 53.847145966121126, 51.74702514920916, 52.42507553100586, 47.746457372392925, 35.50809144973755, 27.238025869641984, 13.980160321508135, 18.170982803617203, 22.085622208459036, 15.46464729309082, 22.74540056501116, 18.227727004459926, 5.775508991309574, 7.447105305535453, 3.3389008130346025, 1.071908910359655, 0.40590190089174677, 0.749555053455489, 9.29067691734859, 38.62733929497855, 45.550916944231304, 41.89508751460484, 44.140575068337576, 43.66916411263602, 48.36628532409668, 56.11413124629429, 47.30135924475533, 18.68952512741089, 0.7649763088141168, 0.1453693559659379, 0.144617050620062, 0.10710832689489637, 0.14399838953145913, 0.21455186365970544, 0.1463023687579802, 0.10345312660293919, 0.13904402538069657, 0.07958710260157074, 0.14331039573465074, 0.19361365719565324, 0.1581373494118452, 0.1041671082909618, 0.1889406679464238, 0.15450036099978856, 0.1812276111117431, 0.12898201601845877, 0.10622973939669983, 0.09430937868143831, 0.12650658456342562, 0.07704999909869262, 0.17513243960482733], [0.014709858889026301, 0.050851741672626564, 0.09496313360120569, 0.05897587537765503, 0.07682503759860992, 0.06023339754236596, 0.036206900009087155, 0.042920152457164865, 0.0400825563286032, 0.02911437701966081, 0.032648343459836075, 0.016497213426711302, 0.00828880736870425, 0.06587908709687845, 0.10229200390832764, 0.03651427637253489, 0.08361608747925077, 0.020608582633680532, 0.04278324444645217, 0.0297745033832533, 0.03969397289412362, 0.10460618830152921, 1.1278971689088004, 22.962361540113175, 43.24651214054653, 43.90130690165928, 36.7959018434797, 26.400027956281388, 24.15822468485151, 28.182815858295985, 48.821562562670024, 30.218973296029226, 4.315647738320487, 0.36291070921080454, 0.07495468974645648, 0.12244477894689355, 0.7788688519171306, 1.7973565374101912, 6.312054966177259, 6.274674092020307, 4.428964172090803, 8.274913685662405, 5.946122441973005, 6.660777236734118, 13.415583576474871, 19.27150797843933, 24.35909363201686, 28.21609251839774, 39.49279301507132, 39.308561529432026, 50.59282166617257, 47.03670583452497, 50.236528464726035, 49.65549577985491, 46.10403871536255, 46.83353008542742, 48.39409548895699, 46.73043966293335, 51.74131720406668, 46.757249287196565, 44.16596726008824, 46.73520612716675, 48.578472886766704, 43.449663570949006, 41.92657675061907, 36.53271450315203, 38.762784004211426, 42.025220326014924, 46.49992275238037, 45.2113550049918, 41.91384417670113, 36.307533809116904, 34.83767713819231, 42.83909061976841, 51.22068173544747, 50.376930713653564, 45.609076840536936, 49.05306959152222, 52.40421009063721, 50.79077236992972, 48.422499724796836, 45.75046920776367, 46.66992780140468, 44.868735858372276, 48.96243034090315, 46.46624483380999, 51.15222808292934, 21.62917767252241, 33.48770121165684, 52.93144634791783, 44.33544772011893, 45.752195835113525, 39.15755632945469, 39.95586265836443, 37.05355494362967, 36.934237003326416, 34.66620601926531, 34.76068067550659, 36.80002212524414, 41.87399278368269, 43.84037814821516, 46.8114869253976, 44.06685120718819, 42.641775676182334, 39.53313078199114, 37.0821988923209, 36.04101480756487, 36.634762695857454, 37.95917272567749, 43.19432074683053, 47.887432847704204, 49.52879537854876, 47.99630764552525, 47.16907943998064, 49.79980986458914, 48.227825096675325, 49.14219413484846, 49.3303131375994, 47.5685487474714, 45.297349384852815, 47.324816363198416, 44.56032269341605, 46.563443183898926, 47.76788214274815, 46.79664557320731, 48.492283957345144, 49.32004370008196, 49.757519653865266, 48.70956107548305, 36.909247807094026, 25.64526425089155, 12.174805538994924, 5.65402842419488, 8.78631499835423, 6.6240182263510565, 8.260807973997933, 8.410975047520228, 14.8706180027553, 4.332259578364236, 2.068103952067239, 0.4132108629814216, 0.07109442938651357, 0.30561295949987, 3.544342109135219, 20.95887974330357, 31.915007727486746, 30.36203670501709, 21.198040212903702, 25.34033387047904, 38.12311894553048, 45.815702370234895, 44.78468002591814, 17.10782504081726, 0.34773730912378853, 0.012305903464688786, 0.05362801519887788, 0.020568949403241277, 0.04434293182566762, 0.06809645811361925, 0.033809540793299675, 0.06840330521975245, 0.008080563275143504, 0.04068411833473614, 0.02519446155721588, 0.10941566486975976, 0.0033995323257321225, 0.0304308095946908, 0.029795853487615074, 0.0824682776417051, 0.09404780343174934, 0.06836779748222657, 0.008910683865126754, 0.10322387676153864, 0.021760752058721015, 0.023129257107419626, 0.01500295039399394, 0.004666542318383498, 0.0441584958295737, 0.028934928255953958, 0.06990646384656429, 0.02578414580784738, 0.03593385412490793, 0.018725943119664277, 0.03316286638645189, 0.03477465507707425, 0.0027483019803185016, 0.007471031027047762, 0.008200133019792182, 0.020844035981489078, 0.09185203697000231, 0.007851755329673844, 0.021442042464124303, 0.04081355906756861, 0.05085570431713547, 0.021309324407151768, 0.01968601419191275, 0.04095388689477529, 0.04380452446639538, 1.7817562030894416, 27.77825699533735, 50.45578581946236, 48.83418049131121, 42.20828104019165, 27.634941714150564, 23.026594161987305, 21.359625782285416, 44.806344509124756, 29.564397403172084, 5.789264687470027, 0.3360904183770929, 0.0578607777133584, 0.1624142099171877, 1.639953892145838, 4.458840557507106, 11.185772895812988, 8.5858907358987, 10.124937568392072, 6.349041095801762, 5.805857854230063, 9.65718310219901, 15.127048219953265, 24.0615804536002, 27.71947523525783, 32.02936117989676, 42.76949051448277, 45.04635960715157, 50.00891242708479, 48.79358564104353, 49.730282715388704, 51.340697969709126, 47.91297789982387, 48.60279158183506, 50.217705794743125, 49.7495049067906, 53.20842933654785, 49.1665232522147, 46.50409514563424, 49.1163329396929, 48.385180950164795, 46.348146302359446, 43.63141802379063, 39.51858472824097, 40.3113602910723, 45.15414353779384, 47.99740546090262, 46.906364577157156, 42.843054567064556, 37.81023808888027, 37.48016391481672, 46.38923447472708, 52.74517209189278, 51.92093855994088, 47.372929164341514, 49.1244797025408, 53.42138467516218, 51.4441670690264, 51.877203123910085, 48.30492230824062, 48.9530850137983, 47.525320529937744, 50.74946880340576, 47.354572023664204, 51.463948590414866, 22.883436952318462, 34.59061656679426, 54.634769439697266, 45.172855036599294, 47.99486936841692, 40.2873785836356, 41.3769325528826, 38.87583466938564, 38.13390949794224, 37.34188781465803, 36.65029886790684, 37.788726466042654, 44.29035043716431, 46.435241971697124, 48.820165974753245, 46.170081342969624, 44.93132175718035, 41.81662498201643, 38.02243259974888, 37.622549874441965, 38.77239683696202, 40.78433459145682, 44.63756234305245, 49.35397522790091, 51.241088594709126, 48.89223269053868, 47.55374561037336, 50.27511528560093, 49.14416742324829, 49.94602428163801, 49.307835715157644, 49.86639445168631, 47.80261271340506, 49.75731120790754, 46.36696202414376, 48.823869364602224, 50.31971229825701, 51.350550515311106, 50.734318256378174, 51.55626583099365, 51.48126350130354, 50.1484774180821, 37.874314376286094, 21.948780911309377, 11.057678512164525, 7.720584665025983, 13.970741169793264, 9.934617723737444, 12.156312039920262, 8.920062610081263, 9.033338223184858, 7.919235399791172, 2.1681847189153944, 0.32368590256997515, 0.22171012312173843, 0.34649233307157246, 3.7708325386047363, 23.409467697143555, 32.154623304094585, 35.60789884839739, 27.466157811028616, 28.847162655421666, 43.493482385362896, 49.430308137621196, 50.40918772561209, 20.900910922459193, 0.7585295747433389, 0.10555867504860673, 0.07698627108974115, 0.08007556639079537, 0.021139468432271054, 0.04094990050154073, 0.007672050418997449, 0.050269657014203925, 0.06517674906977586, 0.06882949985031571, 0.033486011903733015, 0.09553657711616584, 0.06093447349433388, 0.030005188326218298, 0.0448975867059614, 0.0295102852396667, 0.037586453304226906, 0.05323741651539292, 0.051141353989286084, 0.050238430832645724, 0.014666169715513076, 0.05237130727618933, 0.021218393929302692, 0.11383429169654846, 0.07933348656765052, 0.1705252682524068, 0.13677243941596576, 0.12898050967071736, 0.1674675994685718, 0.14487721451691218, 0.10450793643082891, 0.11827253497072629, 0.0845782637063946, 0.09874304184424025, 0.09507113602012396, 0.08812684579087154, 0.2314232433480876, 0.1531997857881444, 0.11201598748032536, 0.23896963841148786, 0.13450814091733523, 0.12214083597064018, 0.15491243531661375, 0.1153912717210395, 0.20228853741926806, 2.7603966210569655, 35.361116204942974, 57.82102918624878, 55.5767263003758, 48.36356510434832, 34.81055137089321, 32.69522442136492, 37.93655286516462, 58.606109619140625, 37.190747124808176, 6.338806399277278, 0.5914976490395409, 0.23199807107448578, 0.3757402593536036, 2.15162108199937, 7.458275403295245, 16.3513468674251, 14.7627854347229, 12.465074351855687, 19.320430244718278, 12.36452089037214, 11.792926464762006, 20.46678226334708, 26.805186101368495, 33.486523491995676, 36.824549266270225, 49.566874980926514, 46.36414105551583, 52.03716107777187, 47.646187918526785, 50.90510150364467, 52.77916267939976, 50.26466866901943, 50.127830845969065, 52.067392689841135, 51.11741760798863, 55.302484376089915, 51.06584807804653, 47.87220587049212, 49.96342257090977, 50.76885775157383, 47.12525020326887, 45.79690054484776, 40.80723932811192, 42.64156028202602, 47.1734151159014, 51.223071915762766, 48.802750314985005, 45.34868615014212, 39.543049335479736, 38.709498269217356, 47.84275940486363, 54.242856298174175, 53.74907214300973, 47.03932877949306, 48.915547370910645, 55.0066682951791, 53.426661831992014, 52.65140267780849, 50.97097042628697, 50.84194932665144, 49.52100644792829, 53.51270137514387, 51.070791721343994, 51.7317008972168, 25.9235291821616, 37.868821825299946, 55.60710729871477, 48.44101667404175, 50.27889857973371, 43.45908880233765, 44.60488149097988, 41.766618796757285, 40.14190762383597, 39.22890043258667, 38.493169580187114, 40.91767747061593, 45.472284180777415, 48.560678550175254, 50.45801271711077, 48.908428941454204, 46.01763786588396, 44.059659821646555, 40.03687170573643, 39.35954393659319, 40.05676439830235, 42.900585651397705, 46.438483306339805, 52.20544992174421, 52.69095877238682, 49.957711151668, 49.260775566101074, 52.0189220564706, 50.747592789786204, 52.93620586395264, 53.658123697553364, 51.62822484970093, 49.69571195329939, 52.61583137512207, 48.639016015189036, 50.37837246486119, 53.301017556871685, 51.8541316304888, 52.595587798527305, 53.21274764197213, 54.048379693712505, 53.079401288713726, 41.198179721832275, 27.207683086395264, 16.86059250150408, 10.32805860042572, 15.199297325951711, 14.535240616117205, 18.66548957143511, 17.80449312073844, 25.527012859072002, 11.011359214782715, 4.328583547047206, 0.7212636172771454, 0.39009857603481835, 0.5871729925274849, 3.988837480545044, 25.910617692129954, 42.23236002240862, 43.466565064021516, 32.99416371754238, 34.3308025768825, 48.887653827667236, 57.91568102155413, 57.845935004098074, 27.06313102585929, 1.6463580685002464, 0.21535006511424268, 0.21324979567102023, 0.1885922537850482, 0.1154259584311928, 0.14755231168653282, 0.15124389502618993, 0.1285131076084716, 0.1328745950013399, 0.1903095580637455, 0.08996615745127201, 0.18975680986685411, 0.13043607585132122, 0.13331763765641622, 0.14372346071260317, 0.07881283986249141, 0.19340370489018305, 0.1935019703315837, 0.09180664976260491, 0.1860425498868738, 0.08354879037610122, 0.08753373833107096, 0.2125990263053349], [0.06654078766171422, 0.05334886249953082, 0.025944529433867762, 0.04171753395348787, 0.03755761217325926, 0.04076666211975472, 0.026145575967218195, 0.025052949686401656, 0.0005759139655440647, 0.04371667453753097, 0.018074910821659223, 0.011877692736951368, 0.032381387427449226, 0.023248124568324004, 0.03339733076947076, 0.055453844368457794, 0.016659052510346686, 0.04180479694956115, 0.022426854619490247, 0.0898478345147201, 0.04965983384421893, 0.008280815074353345, 2.3513589927128384, 24.738427059991018, 42.67500196184431, 47.922997202192036, 38.557131222316194, 20.658820050103323, 16.387369803019933, 33.05484580993652, 33.5276255607605, 15.890940121241979, 3.3766688321317946, 0.13254771754145622, 0.09859011362173728, 0.057754878752997944, 1.6894148609467914, 3.50879773071834, 10.625481452260699, 3.2287108514990126, 4.4652168325015476, 7.474779111998422, 6.922987920897348, 14.564071297645569, 14.386013286454336, 20.652187994548253, 26.20295967374529, 39.40170560564314, 37.74030099596296, 50.082320145198274, 49.70978205544608, 50.146952288491384, 48.83294023786272, 50.58660997663225, 48.25472157342093, 43.80240624291556, 41.77048199517386, 43.71507086072649, 47.41494492122105, 47.09485878263201, 47.286681175231934, 47.210525444575715, 45.68129989079067, 42.27499416896275, 37.84736578805106, 36.71731424331665, 40.47235005242484, 44.56337295259748, 47.59546259471348, 46.28929158619472, 42.416970184871126, 35.77016707829067, 37.542975630079, 42.538660934993196, 54.984746728624614, 44.2248706136431, 41.71258613041469, 55.12546512058803, 50.75740017209734, 44.55683469772339, 46.18671533039638, 43.78621694019863, 44.1333315713065, 41.86048548562186, 47.343458380017964, 44.76835175922939, 52.28982189723423, 24.614872455596924, 31.548375606536865, 54.9830687386649, 45.0304273877825, 47.817613874162944, 41.951913356781006, 46.247147287641255, 42.31457805633545, 42.23077583312988, 35.70986366271973, 34.93750538144793, 33.771500383104595, 38.44680772508894, 43.66781963620867, 47.58045448575701, 46.910477910723, 44.817704813820974, 41.811775139399934, 40.06424413408552, 36.47648620605469, 36.53312792096819, 34.320741585322786, 37.28233133043562, 42.56221880231585, 48.05849402291434, 47.86902012143816, 49.65875448499407, 48.056673594883506, 47.644447394779746, 46.32373033251081, 46.15743562153408, 42.43923568725586, 42.79189150674002, 41.39980602264404, 41.45381784439087, 41.144584792000906, 43.67174536841256, 44.02455057416643, 43.82377890178135, 43.81737266268049, 46.614807741982595, 48.183346203395296, 43.66146898269653, 21.23167470523289, 12.269222004073006, 8.364051256861005, 16.466938836233957, 7.10497123003006, 5.180343670504434, 8.448605622564044, 8.31742797579084, 4.684945361954825, 0.78382601163217, 0.2845830151012966, 0.14131576062313148, 0.14016310604555265, 1.8102598850216185, 13.18946487562997, 40.58361503056118, 30.965789999280656, 17.742848702839442, 30.367643901279994, 40.98490824018206, 46.38984244210379, 43.3562832559858, 25.51412742478507, 3.126945363623755, 0.15846732099141392, 0.009706926897966435, 0.03351021185517311, 0.036792672505336146, 0.04261599574238062, 0.04800058502171721, 0.06101696978190115, 0.041293510634984286, 0.09350046994430677, 0.056287305895239115, 0.07700423869703497, 0.03088204895279237, 0.07981817091682128, 0.04731661493756941, 0.03203958898250546, 0.028558558451810052, 0.049513042970959625, 0.042083121836185455, 0.024100422227223004, 0.06448787996279341, 0.018941530658464347, 0.039326892234385014, 0.00983170694338956, 0.00618678645696491, 0.08585541588919503, 0.052209483459591866, 0.009068166753942413, 0.02113098674453795, 0.05310459328549249, 0.009495223972148128, 0.05925993049251182, 0.04364553353350077, 0.015484981671241778, 0.03534226658354912, 0.019788778320487057, 0.041817176820976396, 0.026142542915684835, 0.0605667753677283, 0.0581834346854261, 0.029550264522965466, 0.06529741973749228, 0.031752361716436486, 0.03187986183911562, 0.10373778561396257, 2.808956278221948, 31.243304525102886, 50.11890241077968, 53.06134639467512, 43.706601006644114, 26.461234637669154, 19.289344004222325, 33.44179793766567, 38.054283142089844, 19.10234366144453, 3.8201617087636675, 0.1066578339253153, 0.06647820637694427, 0.1381532988910164, 1.7300098197800773, 6.3212543811116895, 10.434063792228699, 10.039604135922023, 11.257058807781764, 7.526965294565473, 6.305328241416386, 13.45454820564815, 17.728705644607544, 22.493337290627615, 30.34288052150181, 44.740013531276155, 42.54125608716692, 50.005375794001985, 49.41755471910749, 49.85200820650373, 49.291371958596365, 50.839691162109375, 49.68395560128348, 45.69020400728498, 44.603422369275776, 45.77297094890049, 50.37106990814209, 49.77226720537458, 50.86861998694283, 49.82575791222708, 48.02768571036202, 45.08824334825788, 39.68955210277012, 37.690635272434776, 43.04111296789986, 44.77534164701189, 49.714986256190706, 47.56100647790091, 43.2785815511431, 37.3205429485866, 38.296969822474885, 44.42882456098284, 55.03221682139805, 46.95188570022583, 45.05616351536342, 55.3091824395316, 53.29979467391968, 46.786834716796875, 49.25256279536656, 46.71045316968645, 46.151609557015554, 44.82051188605172, 48.040928976876394, 48.16461385999407, 53.34429441179548, 25.825707231249126, 34.28533703940255, 55.22193043572562, 47.119372027260916, 50.17040940693447, 45.24332019260952, 48.05060434341431, 42.53890412194388, 43.59399502617972, 37.36892325537545, 35.43473236901419, 35.33100618634905, 39.390546798706055, 46.0887839453561, 50.80802822113037, 48.69700568062918, 46.09625325884138, 44.23685278211321, 41.78073753629412, 38.91387953077044, 37.80663544791085, 36.94066061292376, 39.622512408665244, 44.34466103145054, 49.99712480817522, 50.61887741088867, 49.70845147541591, 50.11131150381905, 48.53114523206438, 48.25611121313912, 48.400324548993794, 45.30536413192749, 44.68927083696638, 43.841368266514365, 42.18533114024571, 44.99652017865862, 44.998590741838726, 46.74197367259434, 46.44537591934204, 47.181926659175325, 47.85617985044207, 50.28989062990461, 44.077968324933735, 26.511256456375122, 16.614185060773575, 11.865182518959045, 8.019049746649605, 10.555295961243765, 7.990401455334254, 11.706756642886571, 9.7334143945149, 4.944120117596217, 3.43743017741612, 0.3661816008388996, 0.2449168621429375, 0.055791870158697875, 2.0668906228882924, 15.145054476601736, 41.27814653941563, 39.989102840423584, 26.422576597758702, 32.89411660603115, 45.557357924325125, 50.61714036124093, 50.158128465924946, 31.40222372327532, 4.034185332911355, 0.1637565286031791, 0.004919964969823403, 0.11027621012181044, 0.018391123407387307, 0.013543828689892377, 0.00994662193781031, 0.010127105467420603, 0.03210178350231477, 0.02165981149300933, 0.036443491599389484, 0.09782028171632971, 0.013959426299801894, 0.026977325889414976, 0.021213959702955823, 0.024865841958671808, 0.03579472051933408, 0.058185042813420296, 0.05180415717352714, 0.027267935652551905, 0.046057379471936395, 0.019722208946145008, 0.018965691594140868, 0.14699446090630122, 0.2024129128881863, 0.1768321426851409, 0.12038113682397775, 0.0825424347338932, 0.16988198991332734, 0.10323953056441885, 0.09843453232731138, 0.14824988639780454, 0.13321653593863758, 0.09584481521908726, 0.06428132033241646, 0.11326193383761815, 0.12700277008116245, 0.17868913018277713, 0.11572295320885521, 0.18013288985405648, 0.11374984122812748, 0.11333924611764294, 0.11156942322850227, 0.18539028774414743, 0.2074840257742575, 4.367024890014103, 38.16390487125942, 57.00958381380354, 59.038016591753276, 50.330957957676475, 30.8536182812282, 24.31477107320513, 44.27146175929478, 42.965971674237935, 21.222409282411846, 4.657354933874948, 0.2859049370246274, 0.2412655566419874, 0.1889965928026608, 3.2057196966239383, 9.589493751525879, 19.62541447366987, 13.947340505463735, 13.01199746131897, 15.997852052961077, 12.633508239473615, 18.630402905600413, 19.977352891649517, 27.77385183743068, 36.836725984300884, 49.83300835745675, 43.861399923052105, 50.87005131585257, 50.935447760990684, 51.817681380680625, 49.44890151705061, 53.716485091618125, 53.096605028424946, 48.26352146693638, 46.11871331078665, 47.24327230453491, 52.81744030543736, 51.280276434762136, 51.94295392717634, 52.096342359270366, 51.128135204315186, 46.71960047313145, 41.93335124424526, 40.44646801267351, 45.65539353234427, 47.83700629643032, 51.61092036111014, 49.372089181627544, 45.03401265825544, 39.36396646499634, 40.57279668535505, 47.091228348868235, 59.415720667157856, 48.956374985831125, 46.61858408791678, 56.94541719981602, 54.89834935324532, 48.1412991796221, 49.529059410095215, 49.45617280687605, 49.35189076832363, 48.135539122990195, 50.660917486463276, 49.370230538504465, 54.403564657483784, 29.312028408050537, 35.30761854989188, 55.21445417404175, 48.75534970419747, 52.359317779541016, 46.8312406539917, 50.50703573226929, 46.38728550502232, 45.66880355562483, 39.84453862054007, 37.07449334008353, 36.89429875782558, 42.07900980540684, 48.294857842581614, 52.303131171635215, 50.636619635990684, 48.03265367235456, 46.34479379653931, 45.44948714120047, 40.255611419677734, 40.065258571079795, 39.02006537573678, 41.17138746806553, 46.587522166115896, 51.1838458606175, 52.73143202917916, 52.441817215510774, 51.99011829921177, 50.25679636001587, 51.11475992202759, 51.11564581734793, 46.56462785175869, 47.83209044592721, 46.07573870250157, 44.20077426092965, 45.7778068951198, 47.764258657182964, 49.28762340545654, 49.09140280314854, 49.27894163131714, 50.489008631025044, 52.451593330928254, 46.238236222948345, 25.468851225716726, 18.96197615350996, 15.051724536078316, 29.049023457935878, 15.308236394609724, 11.394042543002538, 20.139407464436122, 16.93815871647426, 10.33802318572998, 3.9346254638263156, 0.6169316928301538, 0.31009861880115097, 0.39029958524874275, 2.75209504365921, 16.80287207875933, 49.85264049257551, 42.11346592221941, 29.501248700278147, 42.00638028553554, 50.53681571143014, 56.40862022127424, 57.18745769773211, 38.61986303329468, 6.191767752170563, 0.3493900847222124, 0.12713541010660784, 0.17477709081556114, 0.12534166207270964, 0.1265339566660779, 0.09154198039323092, 0.15824254948113645, 0.080593940003642, 0.2012190848056759, 0.14090410699801786, 0.2642577700316906, 0.08897612736161266, 0.12836213356682233, 0.08355229161679745, 0.10083196618195091, 0.121074911739145, 0.1906023459242923, 0.10140912128346306, 0.13402704601841314, 0.15895836321370943, 0.12993634838078702, 0.10801490396261215], [0.05043226793142302, 0.013029204831192536, 0.030150873187397207, 0.029681835855756487, 0.0349630435396518, 0.01906703249551356, 0.05045967735350132, 0.10190081489937645, 0.04456913843750954, 0.04030232364311814, 0.04173218352454049, 0.016646896555487598, 0.054182870247002156, 0.003686931558019881, 0.05967892586652722, 0.009119038220628031, 0.07184592727571726, 0.007142648915760219, 0.049157972381051095, 0.044095958649579964, 0.08960107168448822, 0.15085372381976672, 2.8020556313650946, 29.18794400351388, 43.21819475718907, 40.09321812220982, 27.491998161588395, 17.899693863732473, 17.585324355534144, 31.473863124847412, 36.102853775024414, 13.93420319897788, 1.492857705269541, 0.07143357475953442, 0.05473658196362002, 0.3399993229125227, 2.7330155074596405, 3.28107008763722, 9.690257396016802, 10.197739924703326, 14.988933665411812, 1.9710156874997276, 4.8403796042714795, 9.482085023607526, 13.38388763155256, 28.17219032560076, 34.834446225847515, 47.9403190612793, 50.14380128043038, 47.01557983670916, 46.8187130519322, 47.82941191537039, 47.400999886649, 48.70113638469151, 47.040739263807026, 43.572212423597065, 39.281592096601216, 35.817060470581055, 37.25702599116734, 39.73185273579189, 39.35989482062203, 39.69466945103237, 39.45050627844674, 37.42888273511614, 35.94336829866682, 37.563372067042756, 40.13921519688198, 44.72328574316842, 49.25591877528599, 45.959029810769216, 43.06699848175049, 35.318780830928254, 34.90284776687622, 43.09361008235386, 51.07515866415841, 46.51744958332607, 51.01514707292829, 48.4117682320731, 47.571720600128174, 46.276628494262695, 42.78848341533116, 39.88305595942906, 37.651516914367676, 38.09057705742972, 45.83743633542742, 43.496987751552034, 52.79984399250576, 24.362211636134557, 28.341076714651926, 47.37503446851458, 44.72117001669747, 51.18479428972517, 47.80072627748762, 49.29586049488613, 46.60776226861136, 48.43496131896973, 44.07450117383684, 38.41279281888689, 34.74239649091448, 35.438946451459614, 41.81854615892683, 47.082689012799946, 48.641003199986045, 47.51868152618408, 45.58968789236886, 44.75349303654262, 41.389626911708284, 37.72099542617798, 37.163270473480225, 36.630656310490195, 36.32694707598005, 43.6259046282087, 47.93310683114188, 48.21620076043265, 48.1490672656468, 48.168098381587434, 44.482391698019846, 42.94710036686489, 39.05654689243862, 35.84921325956072, 36.972257546016145, 37.12200859614781, 38.8019232068743, 39.565446853637695, 40.993162700108115, 41.25731584003994, 43.612223625183105, 48.520865372249055, 50.810098784310476, 46.139589173453196, 26.225174801690237, 15.494710411344256, 10.469717604773384, 7.552837780543736, 10.516645738056727, 12.07994178363255, 6.0274693455014905, 5.988366620881217, 6.197163028376443, 4.003987159047808, 0.3152590947491782, 0.2854149804583618, 0.05309347209653684, 0.8671814873814583, 8.97575763293675, 29.05056769507272, 30.8835163797651, 18.19941656930106, 21.198576961244854, 34.557115827287944, 42.71347761154175, 49.066934721810476, 33.30576263155256, 7.048961366925921, 0.6260475665330887, 0.06674731336534023, 0.017514308581926992, 0.09386385258819376, 0.024248368306351558, 0.025274878134950995, 0.08678906650415488, 0.07508654267128025, 0.131425977019327, 0.021954365240942155, 0.07735715833093439, 0.08070950808801822, 0.05029652360826731, 0.07579771522432566, 0.053131727900888236, 0.04710401634552649, 0.041361903572188954, 0.05454733515424388, 0.06913285928645305, 0.03646374926237123, 0.011832589666093034, 0.062416678959769864, 0.02824817448189216, 0.043605428721223555, 0.056210811249911785, 0.03195188833134515, 0.03409102765311088, 0.03089003191728677, 0.03504657459312251, 0.027628906104447584, 0.027565712441823313, 0.04276346854333367, 0.0293053065958832, 0.04007640880133424, 0.05440289879749928, 0.015613475847723228, 0.0849770794489554, 0.03585634506972773, 0.030552189331501722, 0.057665868529251645, 0.03454346801819546, 0.036952148590769084, 0.041931326767163615, 0.01965484568583114, 3.7105738520622253, 35.20807865687779, 49.83053132465908, 46.604354177202495, 32.54733548845564, 21.417780467442103, 15.70207245009286, 32.22118009839739, 37.313163961683, 15.059628111975533, 1.6829905999558312, 0.035957735164889267, 0.03190208725365145, 0.48365080463034765, 3.071259243147714, 6.583267910139901, 11.326092634882245, 9.590383120945521, 17.756102391651698, 6.442645490169525, 9.011489612715584, 9.933617183140345, 16.65735595566886, 28.12682901109968, 40.023986271449495, 48.67312472207205, 49.9303491456168, 47.32595934186663, 47.154057434626985, 48.035141127450125, 47.65162140982491, 51.1435671533857, 49.02612100328718, 46.51272133418492, 41.32179512296404, 38.3537609236581, 40.88975266047886, 41.85262707301548, 42.35693427494594, 41.30756173815046, 42.10500301633562, 38.98336846487862, 38.656886509486604, 39.36020401545933, 41.83179289954049, 46.343918323516846, 48.92400680269514, 49.17230762754168, 44.10102244785854, 36.29903963633946, 36.587309973580496, 44.49643748147147, 52.144903319222585, 48.266054085322786, 52.02957364491054, 50.634357997349326, 48.27877276284354, 47.623112951006206, 45.16237367902483, 40.964720249176025, 39.595244203295024, 39.80776180539812, 47.66552822930472, 45.37734399523054, 54.56965092250279, 25.431970187595912, 31.66759627205985, 49.31969976425171, 45.76852410180228, 52.79345164980207, 49.32746090207781, 52.33903251375471, 49.022111892700195, 49.54404320035662, 45.29419142859322, 39.01417677743094, 35.830970764160156, 37.370396273476736, 42.91714320863996, 50.05480180467878, 49.07522392272949, 48.481753962380544, 47.40912927900042, 46.06901284626552, 43.76804392678397, 39.82547971180507, 39.16882978166853, 38.116215910230366, 39.61398696899414, 47.48287745884487, 49.21279130663191, 50.15507820674351, 50.22350754056658, 50.39014271327427, 47.30887024743216, 44.91187374932425, 39.93487215042114, 38.47463526044573, 38.781992299216135, 40.979193346840994, 40.953589235033306, 43.26709965297154, 44.12590047291347, 43.75091661725725, 45.804880550929475, 49.68730810710362, 52.26403365816389, 47.05914156777518, 30.68909536089216, 20.72696624483381, 10.112700922148568, 9.271918518202645, 15.168308360236031, 10.315330369131905, 9.923598749297005, 7.6173752546310425, 6.961296379566193, 3.4083250420434132, 1.1583348384925296, 0.24829314383012907, 0.12165872326919011, 0.9994452787297112, 10.113251566886902, 32.5479017666408, 32.702603408268516, 21.99720811843872, 28.936549493244716, 38.691995756966726, 47.93506274904524, 53.56986420495169, 38.291842051914756, 8.032801968710762, 0.4488651912127222, 0.04871672445109912, 0.023589268226974776, 0.03453989213864718, 0.025543937625895654, 0.03682736600083964, 0.035225497492189915, 0.050648798633899005, 0.034578833263367414, 0.06449043803981372, 0.030803925823420286, 0.0586484143776553, 0.05057443458853023, 0.09085473977029324, 0.024411255726590753, 0.01818244674775217, 0.004559397398095045, 0.03692865092307329, 0.06707501185259648, 0.017782572490562285, 0.04588612062590463, 0.03535576603774514, 0.15203718388719217, 0.08816060290804931, 0.1755902471819094, 0.11165542754211596, 0.07585895300975867, 0.21960169768759183, 0.14557938969561032, 0.1642827596515417, 0.30561133101582527, 0.1775361770497901, 0.08789687670235123, 0.17254028655588627, 0.141088478533285, 0.13904082269540854, 0.18477721778409822, 0.2044492100498506, 0.08582964512918677, 0.09134153436337199, 0.13396619499794074, 0.1893106188092913, 0.1743139906653336, 0.30712180425013813, 5.483761080673762, 42.67643676485334, 56.37063441957746, 51.881816727774485, 38.25920983723232, 27.927787440163748, 25.748250450406754, 42.48208522796631, 45.05216135297503, 18.192035845347814, 2.221733399799892, 0.2433717836226736, 0.30774969341499464, 0.9043702547039304, 6.262559473514557, 12.81119886466435, 18.74533826964242, 16.468592507498606, 20.511757952826365, 7.968845537730625, 9.916154623031616, 13.338575822966439, 19.131510462079728, 33.329466411045615, 41.74636479786464, 50.67768348966326, 51.26798159735543, 48.51309381212507, 47.17566633224487, 49.90919188090733, 48.76779392787388, 51.601595878601074, 51.33857529503958, 49.533818926130024, 43.29224170957293, 39.36326469693865, 41.56435326167515, 44.43564074380057, 44.40401601791382, 42.79374320166451, 43.34411001205444, 40.8842705317906, 40.12338720049177, 41.32757255009243, 44.29230635506766, 48.746487276894705, 52.677875314440044, 50.73039252417428, 46.88054507119315, 38.226647104535786, 38.270087242126465, 45.63299254008702, 54.516035148075645, 49.922970158713206, 52.94335903440203, 53.36257859638759, 50.74988569532122, 51.272654260907856, 46.98840890611921, 44.25920513698033, 41.51555953707014, 42.33141354152134, 49.58137934548514, 47.98936639513288, 54.366614137377056, 28.629060438701085, 35.05536767414638, 51.02111210141863, 48.03898000717163, 56.14206647872925, 51.79703133446829, 53.16040686198643, 51.450896399361746, 52.019867011478965, 47.189927509852815, 41.24188041687012, 38.01333393369402, 38.05637454986572, 44.9014618737357, 51.00793136869158, 52.01908186503819, 50.90542459487915, 49.19243655885969, 48.48921980176653, 46.2098319871085, 41.966386454445974, 41.35723440987723, 41.42314502171108, 39.94882413319179, 47.07800245285034, 52.09512989861624, 51.87887416567121, 51.503744397844585, 53.30112177985055, 49.230662073407856, 48.37721831457955, 43.181011472429546, 40.31012003762381, 41.26678623471941, 42.02370909282139, 43.75340059825352, 45.174612930842805, 45.99264866965157, 45.87417493547712, 48.014682156699045, 53.39567634037563, 55.60198300225394, 51.12792328425816, 29.984061649867467, 19.209373712539673, 16.74896100589207, 13.707015344074794, 18.11501506396702, 21.197411400931223, 14.121076737131391, 13.98725095817021, 11.70797778878893, 7.662766967500959, 1.5357995267425264, 1.2324226115431105, 0.3031207003763744, 1.4813851437398364, 11.260195919445582, 37.36703681945801, 41.21317046029227, 27.185902220862253, 33.05969565255301, 46.06913096564156, 53.51943417957851, 59.76661164419991, 45.14509698322841, 10.832593355860029, 0.8927966185978481, 0.12507475353777409, 0.07545909232326917, 0.20627776693020547, 0.11754481973392622, 0.0827113628121359, 0.14327560045889445, 0.19102980941534042, 0.23934524825641088, 0.06665723105626446, 0.15666259426091397, 0.17765105302844728, 0.208579724122371, 0.12640180518584593, 0.18145078127937658, 0.1063061220837491, 0.109694569903825, 0.15511130035987922, 0.2815004305115768, 0.11471249242978436, 0.1161103288510016, 0.11060037344161953], [0.06967949388282639, 0.03618622843974403, 0.04676494900403278, 0.029821322299540043, 0.009051343326323798, 0.06882065853902272, 0.017741249707926596, 0.0112158242346985, 0.005928440609880323, 0.024185809073969722, 0.018900548839675527, 0.04632180456870368, 0.03182489710993, 0.02036758735110717, 0.015461908087932637, 0.02802198483342571, 0.19363869513784135, 0.024141331103497317, 0.040929931215941906, 0.050022531167737076, 0.028100036716620837, 0.0647454789972731, 4.943693671907697, 26.63076547213963, 42.15878207342965, 38.08822161810738, 30.719465936933243, 15.082452944346837, 20.412862505231583, 37.29484503609793, 29.213499477931432, 8.851312790598188, 0.7599007040262222, 0.1664165487246854, 0.0537109389635069, 0.6442126546587262, 0.8878566122480801, 7.252517095633915, 6.502812113080706, 10.363642930984497, 15.962329387664795, 7.630940743855067, 5.987284004688263, 12.780261141913277, 24.729229382106237, 34.502339703696116, 44.03434406008039, 51.69512905393328, 48.16050052642822, 48.774724755968364, 47.602153709956575, 48.23804589680263, 46.801359925951274, 48.23117412839617, 48.097303186144146, 44.624034200395855, 44.54085036686489, 38.58014365604946, 34.21895047596523, 33.05828864233834, 34.42547525678362, 33.412869112832205, 34.228719643184114, 34.3766120501927, 35.493628774370464, 37.50888081959316, 41.7125027520316, 44.88280596051897, 46.14372682571411, 46.15616757529122, 43.5190726007734, 36.619869232177734, 35.128900459834504, 39.50044992991856, 47.74597794669015, 48.45036547524588, 46.458525385175435, 47.82982185908726, 46.02465902056013, 37.46604864937918, 35.764810017177034, 34.70053012030465, 35.220800808497835, 38.71725245884487, 43.7289012500218, 45.61714022500174, 51.390217781066895, 29.735437733786448, 23.53100037574768, 42.79027952466692, 45.29167965480259, 46.215102195739746, 46.683358669281006, 48.8692306791033, 45.963855334690635, 46.89451095036098, 46.536918435777935, 46.553580215999055, 37.07880817140852, 34.33493675504412, 40.563093526022776, 48.89985139029366, 49.47963339941842, 49.678935527801514, 48.4638797215053, 50.11977440970284, 46.05047157832554, 42.75387791224888, 34.57474340711321, 34.69459635870797, 33.853909492492676, 35.05956091199602, 40.76556403296334, 44.36996637071882, 44.03324971880232, 45.36435433796474, 43.97727850505284, 40.86506223678589, 36.62439250946045, 37.1489953994751, 36.851320675441194, 37.776841572352815, 38.538867882319856, 39.470280851636616, 42.6747726712908, 42.406113624572754, 46.46832929338728, 48.03910160064697, 50.32101855959211, 47.939398424965994, 37.21425288064139, 33.098178250449045, 18.092911107199534, 3.792464452130454, 14.47740728514535, 4.384875246456691, 11.308452895709447, 7.2215094566345215, 4.563638499804905, 2.0766919255256653, 1.2299563267401286, 0.1518453484667199, 0.04522368724324873, 0.4458243500973497, 5.236340505736215, 26.082726308277675, 36.725179604121614, 30.88579191480364, 17.936170169285365, 27.372556890760148, 38.49114070619856, 48.561279569353374, 39.30889156886509, 9.285705481256757, 0.715137640280383, 0.021636052589331354, 0.051375061805759153, 0.054952515555279594, 0.043656094931066036, 0.017415515579549328, 0.024467621630589877, 0.02086950988242669, 0.00751411375988807, 0.03562141589022108, 0.029146451369992325, 0.035331386274525096, 0.03498257517016359, 0.022149457629503946, 0.020315592908965688, 0.030741619345332896, 0.037809280811675956, 0.016443836469469324, 0.037818447819777896, 0.03253265663183161, 0.02068755732450102, 0.02659828944264778, 0.04577621491625905, 0.006912952937584902, 0.05315018066072038, 0.016197955734761696, 0.015546390786767006, 0.05168982741555997, 0.08801119628229312, 0.017902863178668276, 0.04472785456372159, 0.035028603593153615, 0.03420323020379458, 0.07440027913876943, 0.0584239074960351, 0.022602006560191512, 0.0107249889655837, 0.011470796490487243, 0.0434357203277094, 0.029887845872768333, 0.04061291626255427, 0.03938549730394568, 0.031844082687582285, 0.08850071858614683, 6.367024336542402, 35.21027428763253, 49.81407104219709, 42.73274844033377, 34.08758088520595, 19.669059583118983, 24.62914058140346, 42.87310552597046, 31.074869768960134, 10.72600451537541, 0.8577768291745866, 0.08269322557108742, 0.1213375726448638, 1.1265114375523158, 3.02435325724738, 8.779628225735255, 9.311457242284503, 12.202994380678449, 17.44755894797189, 6.401786174092974, 5.945503183773585, 11.384348937443324, 23.828213044575282, 36.67891502380371, 44.35418006352016, 51.46026257106236, 48.12014191491263, 48.504332133701865, 47.182030882154194, 48.36647639955793, 48.23087535585676, 49.32925353731428, 50.59625060217721, 47.44889381953648, 45.09639358520508, 40.337350027901785, 35.84748315811157, 36.463698046548025, 35.51712410790579, 35.25700787135533, 35.497627462659565, 36.760219369615825, 36.714719091142925, 40.137769971575054, 42.386735098702566, 45.371458871024, 47.42723628452846, 49.66046721594674, 44.734913553510395, 38.223506518772666, 36.73937129974365, 41.39676965985979, 48.17522375924246, 49.84407336371285, 49.67290449142456, 50.46758386066982, 47.84290531703404, 39.246246610369, 37.55632659367153, 35.91592638833182, 37.74766608646938, 40.72790479660034, 45.08186837605068, 47.60715988704136, 53.035419191632954, 30.366678101675852, 28.433383532932826, 46.12971230915615, 45.497898714882986, 49.01591409955706, 47.518177781786235, 50.33072171892439, 47.86605324063982, 48.774005617414204, 49.622366768973215, 47.21118204934256, 38.05303594044277, 36.755032539367676, 42.19841112409319, 52.573680128370015, 51.020233154296875, 50.45697743552071, 50.188141209738596, 52.0260682787214, 47.238207067762104, 43.81687934058053, 36.74352979660034, 36.45790324892317, 35.44296251024519, 37.695335728781565, 43.59199741908482, 46.83850499561855, 46.713809149605886, 46.63812589645386, 45.25481946127755, 43.67035920279366, 39.101665019989014, 39.542267663138254, 38.80046755926949, 39.958617619105745, 41.14072854178292, 41.736762387411936, 44.3788948059082, 44.51900175639561, 48.18020561763218, 50.458558150700156, 52.97918742043631, 49.53153644289289, 37.93662582124983, 25.901915073394775, 12.91971583025796, 7.426602040018354, 13.582882302148, 9.898554836000715, 12.16988274029323, 7.380018711090088, 6.242284195763724, 3.6793851256370544, 2.200652131012508, 0.3436240298407418, 0.04391905778486814, 0.5183846322553498, 6.191818560872759, 29.640042441231863, 35.21136515481131, 27.777497904641287, 22.99710774421692, 33.39659990583147, 44.87976612363543, 53.78179815837315, 45.74711322784424, 12.406755515507289, 0.917945840529033, 0.05308002692514232, 0.0477699034714273, 0.0180584309023938, 0.05364991830927985, 0.03876774884494288, 0.036106833057211976, 0.022378712559917142, 0.03944166982546449, 0.02122680776353393, 0.023350966728425453, 0.028810729206140553, 0.015193673017035638, 0.022508360245930295, 0.06356187643749373, 0.019803794300449745, 0.07422585492687565, 0.037386991150145016, 0.017270972353539298, 0.02663762411767883, 0.05651038785332015, 0.09165426436811686, 0.11753887576716286, 0.09653219154902867, 0.13190570127751144, 0.07750062777527741, 0.15288206855101244, 0.19037148116954736, 0.2116071166736739, 0.11263439751097135, 0.15364019572734833, 0.08078756675656353, 0.09069696002240692, 0.17847866219069275, 0.1746262117688145, 0.10764782330287354, 0.07526077689336878, 0.08698288324688162, 0.25904838527951923, 0.11791817684258733, 0.19203314557671547, 0.08331654140991823, 0.1794361158141068, 0.15130376895623548, 9.14308762550354, 41.97270236696516, 56.232959338596885, 49.84181867327009, 40.48909521102905, 24.59273723193577, 30.37415436335972, 49.22722618920462, 36.874312264578684, 11.871644343648638, 1.3769062757492065, 0.24778606103999273, 0.21146391864333833, 1.2969912439584732, 5.452082506247929, 13.136079260281154, 16.126313822610037, 20.52399025644575, 25.249698093959264, 14.81607290676662, 9.847173775945391, 17.956988709313528, 29.12192222050258, 40.31805488041469, 44.9200622013637, 52.75225578035627, 48.66315058299473, 49.34559917449951, 48.109181131635395, 48.657682350703645, 47.88553251538958, 50.51431049619402, 53.07587855202811, 50.47092594419207, 48.31410435267857, 42.62853935786656, 37.42328943525042, 37.9175078528268, 38.32246276310512, 37.11987897327968, 37.63968413216727, 38.67905126299177, 40.003586360386436, 41.486724512917654, 46.128287928445, 48.47800888334002, 48.87244769505092, 52.41555649893624, 47.2581136567252, 40.87267746244158, 39.35442658833095, 43.397604193006245, 50.61796719687325, 51.99045181274414, 51.91135004588536, 52.866685662950786, 49.66696378162929, 40.68381152834211, 40.119075843266074, 37.295397417885916, 39.78506204060146, 43.49843645095825, 48.089465618133545, 50.425227642059326, 54.411899021693635, 32.80311952318464, 32.16615036555699, 48.972161293029785, 47.066145351954866, 50.17446368081229, 48.81724773134504, 50.4072596005031, 48.63882146562849, 49.1769802910941, 50.90600824356079, 50.30610077721732, 40.96764196668352, 39.02393899645124, 44.31334202630179, 54.055737836020334, 52.32640763691494, 51.18679537091936, 52.309367179870605, 55.123630796160015, 50.55387006487165, 45.330725056784495, 38.64312907627651, 37.90771089281355, 37.68395110539028, 39.224144390651155, 43.99988446916853, 49.38057293210711, 47.76002025604248, 49.21757166726248, 48.727793148585725, 45.274548871176584, 40.64866753986904, 40.795309271131245, 41.30692250388009, 41.44474349703108, 44.08095952442714, 42.76077052525112, 46.560108048575266, 46.66417121887207, 50.792853355407715, 54.78917925698416, 54.23117637634277, 50.76688098907471, 42.033839566367014, 34.00590133666992, 22.26700493267604, 6.93038992370878, 24.006821700504847, 12.326981510434832, 19.894926411764963, 17.368196623665945, 13.054612500326973, 7.02863267489842, 3.163083378757749, 0.7781499847769737, 0.3193572834134102, 0.8703003600239754, 6.903526450906481, 34.51009389332363, 47.184619086129324, 41.4660188811166, 27.42662082399641, 38.271546363830566, 50.078394412994385, 60.04533863067627, 52.95231873648507, 16.040784972054617, 1.5069774218967982, 0.1339558676949569, 0.15881322457322053, 0.15508631670049258, 0.11534795404544898, 0.1467586157045194, 0.08951107758496489, 0.09940175685499396, 0.13387134937303408, 0.1608817521482706, 0.1629442950444562, 0.13279565423727036, 0.08897081443241664, 0.09706782030739955, 0.11091351056737558, 0.13904528745583125, 0.13073611046586717, 0.057754430919885635, 0.113993462441223, 0.07882566417434386, 0.11935808243496077, 0.17428770421871118], [0.02862823721287506, 0.08309719139443976, 0.027030806323247294, 0.10260041843035392, 0.019221132887261252, 0.02462124535148697, 0.009763727912546268, 0.04897933785936662, 0.06569436272340161, 0.04691829113289714, 0.011303373911817158, 0.047466998653752465, 0.03248986142820545, 0.0050450236386885595, 0.010633549586470638, 0.027899248026577488, 0.12772524702761853, 0.03164052218198776, 0.03781135712883302, 0.029855629030082906, 0.0438663627553199, 0.1288499052503279, 4.480788614068713, 33.29054955073765, 43.59389080320086, 35.98102753502982, 27.54062339237758, 17.773898465292795, 16.600273030144827, 26.410922731672013, 27.3737085546766, 6.558226602418082, 0.25276748516729897, 0.09019690006971359, 0.06735456149492945, 1.261261435491698, 3.09292893750327, 5.719406196049281, 9.310262152126857, 5.668573175157819, 19.562264033726283, 4.617862241608756, 9.62250464303153, 15.891247579029628, 28.464242219924927, 39.55961384092058, 48.06611967086792, 47.04741995675223, 51.51502479825701, 47.18754775183541, 48.92402069909232, 47.54182597569057, 48.334045682634624, 46.5496266910008, 48.73509917940412, 45.69809716088431, 46.65129968098232, 43.62651606968471, 43.135201999119346, 38.65159893035889, 36.57335451671055, 35.3268928527832, 33.873489516122, 34.80720928737095, 36.09940052032471, 35.319159507751465, 39.994435582842144, 41.83641345160348, 46.37653316770281, 46.511203152792795, 44.701332909720286, 38.72377681732178, 35.54608072553362, 33.57631158828735, 39.08383246830532, 42.241854735783164, 45.8439051083156, 41.515031473977224, 38.03978572572981, 34.41847842080252, 36.30328845977783, 33.859937054770334, 37.31780883244106, 42.222236497061594, 48.227748666490825, 46.14187165669033, 46.7324789592198, 30.697697230747767, 30.32595818383353, 47.929796014513286, 39.80998522894723, 45.17474842071533, 43.726299149649485, 48.04418420791626, 46.21783978598458, 45.77394022260393, 46.85630975450788, 46.62321506227766, 41.59500176565987, 34.408215931483674, 41.38087912968227, 48.68467957632882, 47.724212714603965, 48.368571281433105, 45.87858009338379, 47.21420104163033, 48.997869627816335, 45.11898217882429, 37.51213952473232, 35.465332235608784, 33.81217166355678, 32.68992641993931, 31.34916033063616, 32.27668925694057, 35.96341732570103, 34.0399614061628, 36.15150853565761, 35.39865732192993, 35.665245805467876, 36.60211311067854, 38.61387716020857, 39.40145199639456, 41.74728890827724, 44.14930895396641, 45.51442500523159, 47.23765121187483, 49.26012938363211, 50.22374725341797, 49.97532136099679, 46.908525466918945, 37.743785517556326, 29.475554261888774, 11.339612092290606, 13.466288924217224, 17.923911809921265, 9.546055350984846, 9.593266623360769, 4.267547530787332, 7.306428602763584, 3.2631988865988593, 1.2963732885462897, 0.6316162762897355, 0.09423007150845868, 0.19359353184700012, 3.458076749529157, 18.060027020318167, 35.98781245095389, 22.38475431714739, 14.79781825201852, 26.678445747920446, 37.801212378910606, 47.30586167744228, 41.45020130702427, 11.694660697664533, 0.7041213256972176, 0.013629397044756582, 0.07131225269820009, 0.023972046794369817, 0.0440880605019629, 0.050968683790415525, 0.044503751410437484, 0.018866194611681358, 0.004336153439778302, 0.06450429372489452, 0.06936061635081257, 0.024485422996804118, 0.04786044379164066, 0.053197705253426514, 0.040742889645376375, 0.03043988160789013, 0.04214978111641748, 0.018097521304818134, 0.02141413262246975, 0.03530359687283635, 0.031020904359008585, 0.03483986568504146, 0.02679051162808069, 0.03534785431942769, 0.04877872219575303, 0.07063937666160719, 0.04219688501741205, 0.038263254665902684, 0.06123652335788522, 0.02362673862704209, 0.04699228876935584, 0.06850266988788332, 0.053196751911725314, 0.013606092759541102, 0.058830974224422655, 0.05065975697445018, 0.04630353840600167, 0.012370823150766748, 0.06788142358085938, 0.037450468101139577, 0.05094421921031816, 0.03445905826187559, 0.07811872567981482, 0.13374755744423183, 6.064188838005066, 40.157752990722656, 49.73773465837751, 41.46436520985195, 30.301153114863805, 19.343670231955393, 21.877980504717144, 33.19793701171875, 30.434520312717982, 6.993410084928785, 0.4745980075427464, 0.029795860272965262, 0.41232059789555414, 2.4361771728311266, 6.757034974438803, 7.815678579466684, 11.311166167259216, 9.843898568834577, 14.721202203205653, 5.393322025026594, 7.5047631944928845, 18.1787109375, 31.105129173823766, 39.65591934749058, 48.490869998931885, 46.92156376157488, 49.7847809110369, 47.683482374463765, 48.61113289424351, 47.69751426151821, 47.978572368621826, 46.61469309670584, 49.46453843797956, 48.23006589072091, 47.7029755456107, 45.1510967527117, 45.28719111851284, 39.43294470650809, 38.04899903706142, 36.70809745788574, 36.009452615465435, 35.10894523348127, 37.977397850581575, 37.423751490456716, 41.89932591574532, 44.081689085279194, 47.54794039045061, 49.326137270246235, 45.98895570210048, 40.40775612422398, 37.05102232524327, 36.58344330106463, 41.22965158735003, 44.77870804922921, 47.797008991241455, 43.78404910223824, 39.799865177699495, 36.70986577442714, 37.544059549059185, 35.17488363810948, 39.28612927028111, 43.89339985166277, 49.60354062489101, 48.599741322653635, 49.91191210065569, 32.340491090502056, 33.70410285677229, 50.6567450932094, 42.12602479117257, 45.968906675066265, 44.79592915943691, 48.59034388405936, 46.78730372020176, 46.26609155109951, 48.195370061056956, 49.42729956763131, 42.60993208203997, 37.142648220062256, 42.96265390941075, 50.50339835030692, 48.074759755815776, 47.5863048689706, 46.849896567208425, 50.02141571044922, 49.73352405003139, 48.82878521510533, 40.36050489970616, 37.05143574305943, 35.8922677721296, 34.876868452344624, 33.55539403642927, 36.10429900033133, 38.260450090680806, 38.207754952566965, 38.3856566292899, 37.70879091535296, 37.30949878692627, 38.82246208190918, 40.23848411015102, 41.807668754032676, 43.344606808253694, 46.45385619572231, 45.68099764415196, 49.70006499971662, 50.30469376700265, 52.13328940527779, 51.167785099574495, 48.0464632170541, 37.18938875198364, 27.44335034915379, 13.713726435388837, 11.475915772574288, 10.894278594425746, 10.910022343908038, 12.348831857953753, 8.277072838374547, 8.04495176247188, 5.345607876777649, 2.811332996402468, 0.7032299478139196, 0.133992182889155, 0.14054860893104756, 4.222517124244145, 20.829509496688843, 40.89642640522548, 26.84842995234898, 20.655160086495535, 30.95070893423898, 43.675215993608745, 52.22561011995588, 47.25416707992554, 14.379343015807015, 1.0048053796802248, 0.06691597002957549, 0.047453953818018944, 0.03223680857835071, 0.07460152583995036, 0.017107460681082945, 0.027035606958504235, 0.04786899672555072, 0.0531787368069802, 0.0356033838221005, 0.02857177292129823, 0.058125759208840985, 0.05773221568337508, 0.007091518333514354, 0.022620566189289093, 0.09162285498210362, 0.0319295238171305, 0.0024704122042749077, 0.07196271672312703, 0.022232193100665296, 0.06395181015666042, 0.017274526180699468, 0.09502471743949822, 0.15222729582871708, 0.13029347493180207, 0.1423896915678467, 0.09727569629571267, 0.18804497458040714, 0.1647668672459466, 0.14920719074351446, 0.14980086817273072, 0.12881506926247052, 0.10654847443635974, 0.17325428181460925, 0.1276631746441126, 0.12899216690233775, 0.2158138302287885, 0.20151073272739137, 0.19452282626714024, 0.11347272074116127, 0.19621110281773976, 0.12211346386798791, 0.1943618913314172, 0.2871231787971088, 8.592437676021031, 47.447031702314106, 54.11832026072911, 48.16941853931972, 36.94890465055193, 26.62861326762608, 25.436875615801128, 36.75130830492292, 35.42466442925589, 8.641031639916555, 0.554684898683003, 0.3460440385554518, 0.5296222578201975, 3.7214942489351546, 7.685864516666957, 13.825486472674779, 18.64991692134312, 14.89006427356175, 28.87475916317531, 11.683394193649292, 17.86035316331046, 17.91165692465646, 31.657900060926163, 41.39496660232544, 50.18738038199288, 47.27542161941528, 50.20684576034546, 48.28996978487287, 48.594551018306184, 47.472326619284495, 48.161195346287315, 46.939566544124055, 51.216478075299946, 51.14013474328177, 51.035119669778005, 47.92600229808262, 47.989203112465994, 41.60566030229841, 40.180150508880615, 40.18176596505301, 37.561485631125315, 38.180160181862966, 40.188012395586284, 39.79375771113804, 43.78426102229527, 46.46950353894915, 49.616895062582834, 51.68963302884783, 49.28944730758667, 42.536381925855366, 38.73707914352417, 38.74800865990775, 42.47946228299822, 47.040985924857004, 49.23174599238804, 46.20721599033901, 41.17559807641165, 38.10121127537319, 40.19386625289917, 38.13010883331299, 41.17880119596209, 46.36477334158761, 51.72958517074585, 51.21967772075108, 50.562933989933555, 35.927568095070974, 35.86107383455549, 48.29606335503714, 44.564821652003694, 47.42380040032523, 46.68172236851284, 50.04944126946585, 48.157328673771445, 45.39129250390189, 48.701921531132285, 51.32043007441929, 46.06306171417236, 39.324215820857454, 45.1825338772365, 52.141147817884175, 49.382150173187256, 48.92590018681118, 47.43911075592041, 49.683222566332134, 51.75997311728341, 50.198153563908164, 41.93376118796212, 39.909198556627544, 38.140326159340994, 36.857615743364605, 35.06863178525652, 37.79217972074236, 39.8761841910226, 38.35498033251081, 40.90192243031093, 39.441678592136924, 39.93792240960257, 41.03443847383772, 42.4677927834647, 45.66984578541347, 46.62216935838972, 49.39443111419678, 48.65533038548061, 51.94834920338222, 54.53262744631086, 53.28221573148455, 52.901621205466135, 48.98307343891689, 41.16867767061506, 32.16239833831787, 16.630396945135935, 19.705709593636648, 24.80014964512416, 17.830482857567922, 17.75760841369629, 9.955975617681231, 12.559207677841187, 7.358393311500549, 3.955144362790244, 1.1341337199722017, 0.27203158289194107, 0.41063954095755306, 4.5137899518013, 24.482684714453562, 47.289186000823975, 33.419098172869, 24.519303458077566, 37.33339711597988, 49.97540821347918, 59.86909062521798, 56.590572697775706, 18.621505737304688, 1.6469756982156207, 0.18473143024103983, 0.16499412219439233, 0.09946353746844189, 0.14623361958989076, 0.1266695008214031, 0.21743206839476312, 0.10893478710204363, 0.17772782248045715, 0.16030688370977128, 0.13753026803689344, 0.08415118019495692, 0.12776750618857996, 0.11222122396741595, 0.09696969057300261, 0.16251816148204462, 0.09357795864343643, 0.1227572171815804, 0.12360178971929209, 0.19665706317339623, 0.12560163597975457, 0.08173299673944712], [0.035618118210030456, 0.013525672789130892, 0.038930254589234076, 0.02736111717032535, 0.05849784067166703, 0.019163241975807717, 0.029966080960418497, 0.03653965697490743, 0.002887212941589366, 0.03588926758883255, 0.011205070302821696, 0.028083132712968757, 0.022609631597463573, 0.04943865856954029, 0.025403017776885202, 0.012141539382615259, 0.026715991519657627, 0.06538638924913746, 0.005606753518804908, 0.025309227273932526, 0.018500771273725798, 0.08938919233956508, 4.462588676384517, 31.870615686689103, 42.65834365572248, 41.81947374343872, 29.97061688559396, 16.045935324260167, 23.601420368467057, 36.40585776737758, 23.31628714288984, 3.7422068289348056, 0.2139666136354208, 0.08076964664672102, 0.2699204161763191, 1.4927928916045596, 6.190339028835297, 5.837740097727094, 8.042908123561315, 10.126810107912336, 9.33612768990653, 1.754472472837993, 7.69422493662153, 21.055240835462296, 33.81260245186942, 44.59419516154698, 46.730589049203054, 50.80332081658499, 48.418674741472515, 49.59722818647112, 48.74248511450631, 48.447676522391184, 48.251997879573274, 48.46585300990513, 46.93485566547939, 48.34637526103428, 46.95688492911202, 45.70654617037092, 46.50508873803275, 45.742940834590364, 42.81689807346889, 39.012252126421245, 37.46956443786621, 33.80556392669678, 33.948936530521934, 34.05245426722935, 35.636209283556255, 38.43436697551182, 42.85021121161324, 43.49838433946882, 42.40516172136579, 39.50789492470877, 36.17883927481515, 36.14795453207833, 36.00908088684082, 34.866466999053955, 35.70067119598389, 33.34385960442679, 34.79791259765625, 32.40556444440569, 35.10724639892578, 33.61412368501936, 42.301147188459126, 44.78710494722639, 49.20740645272391, 46.14766298021589, 49.81098256792341, 34.49938324519566, 33.90850843702044, 45.956611837659565, 43.586883544921875, 49.69904361452375, 44.75393077305385, 47.12718527657645, 45.39708035332816, 48.64551258087158, 47.31818778174264, 50.02121073859078, 46.06254407337734, 35.43650068555559, 36.328809193202424, 49.04772295270647, 47.598012583596365, 48.54412794113159, 44.553902557918, 49.420104707990376, 49.50648818697248, 45.715082032339915, 39.1972096988133, 34.060997077396934, 32.49646077837263, 35.143821716308594, 39.30251659665789, 42.03357553482056, 38.005645751953125, 38.36856058665684, 33.90279006958008, 33.92807456425258, 34.211297035217285, 36.217412199292866, 38.30361924852644, 44.005189418792725, 44.441716943468364, 47.50962802342006, 48.50188636779785, 49.029390130724224, 47.316909313201904, 47.799666677202495, 47.42802143096924, 48.27746650150844, 40.510415758405415, 30.156675747462682, 20.99232316017151, 14.914381231580462, 4.607396083218711, 10.072471720831734, 13.78943748133523, 9.902014170374189, 7.213066526821681, 3.8828718066215515, 2.1620987483433316, 1.4143772593566348, 0.1607035824230739, 0.015623090688937476, 2.1155618854931424, 17.292674916131155, 35.55070127759661, 24.287436859948293, 12.868498052869525, 26.295412404196604, 42.27614756992885, 43.98905917576381, 40.29764454705374, 15.814916406358991, 2.6754498992647444, 0.03601836905415569, 0.10942084887730223, 0.018610924648653184, 0.03749902745974915, 0.02829156001098454, 0.09172477772725479, 0.05058284163741129, 0.0493229887049113, 0.06414732323693377, 0.03958099002816847, 0.022415212654907788, 0.03487406384998134, 0.014229238964617252, 0.028646432129400115, 0.07201843801885843, 0.01550816890916654, 0.01528627099469304, 0.018490630567872098, 0.01122263418177941, 0.03559934653873954, 0.031084238817649226, 0.03849704729925309, 0.030666759969400506, 0.02518999170778053, 0.032889443915337324, 0.029443252765174423, 0.03780200691627605, 0.033108003437519073, 0.0315096734889916, 0.010934311081655324, 0.06604445286627326, 0.024642042449808547, 0.07124357816896268, 0.05814913474023342, 0.006190779211465269, 0.042167117686143944, 0.0022782481184029685, 0.028216853305431347, 0.03597702930814453, 0.02128784029212381, 0.03704805951565504, 0.04316126987604158, 0.05647633896608438, 6.348119590963636, 38.648871762411936, 49.09457465580532, 45.280371461595806, 36.21532426561628, 20.86898394993373, 24.236041034970963, 36.6953718321664, 25.317260640008108, 5.086970738002232, 0.1831081166331257, 0.05761267138378961, 0.275121522801263, 2.2316007103238786, 7.695956775120326, 9.381678342819214, 14.797931160245623, 10.604077526501246, 10.618647030421666, 6.698220644678388, 9.757390890802656, 20.477692672184535, 34.71681669780186, 46.661114011492046, 47.956859248025076, 49.97328553880964, 49.59345531463623, 48.51159994942801, 48.35236113412039, 47.80991874422346, 48.1693560055324, 48.65736968176705, 48.35696084158761, 49.3828067779541, 49.150379112788606, 47.665705408368794, 47.752547468457905, 47.42928600311279, 44.979570048195974, 41.235248361315044, 38.742915630340576, 35.09855420248849, 35.525719029562815, 36.581487383161274, 38.89082193374634, 41.007475989205496, 44.308356693812776, 46.42577505111694, 44.94414813177926, 41.49927295957293, 37.591282980782644, 37.342603479112896, 36.47034747259957, 37.56863532747541, 37.515985352652415, 35.7379343850272, 37.15346309116909, 34.383581093379426, 36.320870876312256, 34.71552780696324, 44.024296964917866, 46.2401886667524, 50.74891642161778, 47.07077285221645, 48.79609394073486, 35.64087152481079, 34.88153069359915, 46.679954051971436, 46.29079587118966, 50.31472001756941, 47.28471483503069, 49.432392597198486, 47.70126976285662, 49.29875789369856, 48.66967494147164, 51.813849449157715, 46.46304866245815, 36.880221707480295, 37.95742177963257, 49.62529196058001, 49.66312142780849, 48.194470269339426, 45.26493603842599, 49.37780407496861, 51.1477951322283, 48.55114562170846, 41.78394760404314, 35.639742442539756, 34.389591285160606, 35.949427127838135, 39.2375613621303, 42.02145092827933, 39.851754324776785, 38.63380459376744, 35.85719673974173, 36.100967339106965, 36.59655107770647, 38.10236815043858, 40.04843350819179, 44.99981362479073, 47.171705859048025, 49.44430180958339, 49.382372515542166, 50.31484508514404, 49.29635729108538, 49.92862946646554, 48.283257825034006, 48.72426346370152, 42.6412649835859, 29.309363773890905, 19.18195959499904, 11.75113478728703, 11.747369732175555, 10.653292485645839, 13.012320552553449, 7.130023394312177, 10.026269674301147, 6.787140650408609, 3.267605347292764, 2.429200530052185, 0.18284185949180806, 0.08335085492581129, 2.3991493540150777, 18.429403679711477, 39.974577631269185, 30.354862689971924, 16.331089394433157, 30.868348462241038, 45.50389501026699, 49.8847724369594, 47.077130453927175, 18.608717577798025, 3.0418090862887244, 0.008287722560843187, 0.09784135701400892, 0.026785288604774644, 0.06608478498778173, 0.02098510510820363, 0.038022208493202925, 0.021806945026453053, 0.045760398264974356, 0.022317037119397094, 0.015364239757348384, 0.007716160284222237, 0.03076824845213975, 0.017493862625477568, 0.0547683679365686, 0.04307706368022731, 0.06454712285527162, 0.04470222968874233, 0.026092226151376963, 0.01774943114391395, 0.02704514716086643, 0.01894681474992207, 0.10875203048012086, 0.08953281784696238, 0.14175306287195, 0.08905710373073816, 0.1690306184547288, 0.08099515776016883, 0.1136656893151147, 0.08474846743047237, 0.1390711667814425, 0.1892255169472524, 0.10744437814823218, 0.11832623423210212, 0.11073080822825432, 0.09826014204216854, 0.1300830612225192, 0.08442789356091193, 0.08288979716598988, 0.07361602836421557, 0.05598421448043414, 0.11380556252385889, 0.17589967272111348, 0.29065633778061184, 9.392427206039429, 46.87750176021031, 55.083491052900044, 52.78900827680315, 41.68185077394758, 25.395539045333862, 32.21323830740792, 46.58057744162423, 29.227979523794993, 5.585418002946036, 0.4671863966754505, 0.23957790434360504, 0.5366614886692592, 5.0164578131267, 12.477828638894216, 13.471655539103917, 16.572584458759852, 16.507375614983694, 15.860357625143868, 7.688688959394183, 12.138654930250985, 24.1002801827022, 38.23422064099993, 50.10174036026001, 50.41184193747384, 50.844568797520225, 50.568200724465505, 50.01806320462908, 49.23015138081142, 47.839181082589285, 49.88426521846226, 50.59136601856777, 49.674460887908936, 49.1536899294172, 50.74165207999093, 50.14543758119856, 49.847464084625244, 50.64985942840576, 46.82571336201259, 43.06016492843628, 42.11343118122646, 37.3095508984157, 37.39374916894095, 38.19671426500593, 41.27469675881522, 42.54057168960571, 46.58811971119472, 48.119916098458425, 46.38899476187569, 43.30076714924404, 39.52215610231672, 39.556101526532856, 39.72402906417847, 39.56977558135986, 38.432244300842285, 36.3782491002764, 39.46733134133475, 36.31327996935163, 37.527904987335205, 37.61294746398926, 45.73920617784773, 48.6923052242824, 52.38647828783308, 49.457600661686485, 49.05050918034145, 38.77546099254063, 37.505677700042725, 46.31636871610369, 47.211623259953086, 52.033322198050364, 49.522944995335166, 51.11658035005842, 49.35833522251674, 52.00633886882237, 49.92831332342965, 53.32749714170183, 50.502324853624614, 37.813569750104634, 39.27678394317627, 53.21554429190499, 51.62530313219343, 51.11176177433559, 45.83128023147583, 50.77879367555891, 52.907874584198, 49.35987772260393, 43.92961733681815, 37.64483969552176, 35.7275572504316, 38.7677206993103, 43.84852491106306, 46.118477072034565, 42.18437576293945, 41.810600893838064, 36.9560786655971, 38.68428325653076, 38.23380027498518, 41.45389774867466, 42.32543461663382, 47.93775517599923, 49.148054940359934, 51.80987855366298, 52.05484076908657, 51.4264943259103, 49.98949221202305, 51.07940053939819, 49.02274765287127, 50.3616828918457, 44.457788126809255, 35.64826440811157, 25.008498328072683, 19.831409454345703, 12.716083237103053, 18.442817177091325, 25.386122499193462, 18.991830825805664, 17.346462658473424, 8.603911757469177, 6.4377270340919495, 3.6372631915978024, 0.4541773875909192, 0.25649467802473475, 2.8391403385571072, 21.526040349687847, 44.246924195970806, 34.72848619733538, 21.85302778652736, 37.31101696831839, 52.476711068834575, 55.9594087600708, 55.146966321127756, 25.41173529624939, 4.178335266453879, 0.1390748715826443, 0.2993972258908408, 0.09190513233521155, 0.1358507310173341, 0.074586740561894, 0.22785599476524762, 0.10341305232473783, 0.12810076187763894, 0.1405882082347359, 0.15156028233468533, 0.1577407864055463, 0.1558594802128417, 0.07261493815375225, 0.08153823683304445, 0.11721726373902389, 0.11343172365533453, 0.09618841856718063, 0.14595419886921132, 0.04934678153534021, 0.17152939151440347, 0.12811028850930078], [0.04125369080741491, 0.07508930430880614, 0.02854456366705043, 0.03370509050520403, 0.022232839405270557, 0.037539946514048746, 0.019177696468042474, 0.061608733742364814, 0.03944439075088926, 0.05129525251686573, 0.015200292126142552, 0.04739295012716736, 0.023642550189314143, 0.04492812078180058, 0.010670971640917872, 0.02012810350528785, 0.06953720508941583, 0.037448727658816745, 0.02756856568157673, 0.01878502655641309, 0.04513602391151445, 0.38985709899238175, 7.8655649083001276, 39.23234673908779, 44.17524310520717, 36.29971708570208, 13.949568271636963, 18.264590672084264, 28.64568052973066, 34.53502402986799, 22.844613892691477, 2.6929046426500594, 0.16405565398080008, 0.06134935016078608, 0.6170486722673688, 2.066191460405077, 7.199734670775277, 6.206298606736319, 11.632093906402588, 7.184508127825601, 10.203341041292463, 4.700668701103755, 10.501500402178083, 26.836821249553136, 41.05584934779576, 41.09051391056606, 50.82869911193848, 50.40653698784964, 50.94004052025931, 50.70423603057861, 52.54583869661604, 49.09246935163225, 48.70070907047817, 48.950594084603445, 45.9078493799482, 45.9160030909947, 46.96813406263079, 46.785650048937114, 47.564372880118235, 46.90009730202811, 45.9799473626273, 45.459138189043315, 43.69465010506766, 40.71858031409127, 40.16276959010533, 35.03058344977242, 32.32596240724836, 33.851397718702046, 36.18132325581142, 38.39757626397269, 40.650936126708984, 37.81316328048706, 35.439752442496165, 32.20801673616682, 34.64431571960449, 34.33244582584926, 34.00276075090681, 33.527913911002024, 35.008627142224995, 33.57100316456386, 34.4537023135594, 36.100668566567556, 45.535509313855854, 45.67502566746303, 46.33508368900844, 44.11920935767037, 48.11065067563738, 35.512743268694194, 34.8990922655378, 47.57759182793753, 44.85475260870797, 46.40538556235177, 43.06824915749686, 43.49221086502075, 42.295289857046946, 45.29130097797939, 47.06553391047886, 49.29677070890154, 44.360707896096365, 36.93723167691912, 33.609850542885916, 40.872305733816965, 47.06184789112636, 47.51976197106497, 49.31505141939436, 45.472506523132324, 50.0963659286499, 47.29612725121634, 41.858776228768484, 38.83192900248936, 40.82096896852766, 43.591618742261616, 47.07757861273629, 47.841341972351074, 48.63117149897984, 46.276343618120464, 43.926125867026194, 38.52655567441668, 35.6742958341326, 39.020114013126914, 42.633538586752756, 44.984732559749055, 47.19598633902413, 48.407109464917866, 47.2237548146929, 45.89600270135062, 44.61834362574986, 47.22152444294521, 45.20590761729649, 45.766901697431294, 41.66568578992571, 34.19984292984009, 21.823906149183, 12.971146396228246, 13.16515052318573, 11.481633271489825, 7.143704831600189, 5.280183204582759, 4.364945641585758, 8.131152851240975, 2.838072487286159, 1.092690538082804, 0.44624452612229754, 0.11388222341026578, 1.2517085309539522, 11.993857945714678, 34.102477822984966, 30.528008324759348, 23.872057914733887, 22.258264098848613, 35.037076541355674, 48.66128499167306, 43.99577808380127, 18.85236484663827, 2.755891799926758, 0.062397299999637265, 0.022784144018909762, 0.03762012221185224, 0.05316778525177922, 0.05030539545363613, 0.03698853163846901, 0.04012427944689989, 0.05311916143234287, 0.04065078869462013, 0.05533925337450845, 0.017227025336718986, 0.06865493993141822, 0.029614050207393508, 0.031144669146410058, 0.03610387464453067, 0.02784876841386514, 0.01075920494206782, 0.05192031558336956, 0.04750988206693104, 0.11513536902410643, 0.03665527934208512, 0.07179805663015161, 0.07311542558350734, 0.013077459697212492, 0.03680270464558687, 0.042373181985957284, 0.038081288537276645, 0.03291115364325898, 0.024781411846301386, 0.04346322474469032, 0.04548490626205291, 0.048810989928564856, 0.036978004167654684, 0.047559265845588276, 0.025336224485986998, 0.041339939393635304, 0.011572225601412356, 0.03470564128032752, 0.049189439442540915, 0.06160511715071542, 0.03909180699182408, 0.05411243152671626, 0.40306719871503965, 10.233971306255885, 47.05829388754708, 49.02345984322684, 43.80585254941668, 18.887230907167705, 18.884418623788015, 29.829630987984793, 35.68502037865775, 24.76902171543666, 3.4010496267250607, 0.1871770332966532, 0.03536478376814297, 1.3486305815832955, 5.1821536762373785, 11.571949430874415, 10.862347279276166, 11.84675850187029, 8.26973032951355, 7.890104208673749, 6.3845754861831665, 12.771847741944448, 26.009136199951172, 40.48138271059309, 43.73946598597935, 52.784054211207796, 52.975838388715474, 52.50848170689174, 51.965768337249756, 52.70013386862618, 49.00887904848371, 48.64469616753714, 48.01665544509888, 46.79926156997681, 46.785274846213206, 48.19720785958426, 47.762177671704976, 48.70589590072632, 48.14139298030308, 47.93863412312099, 46.99636459350586, 45.4752962248666, 42.398988246917725, 39.99660342080252, 35.59071595328194, 33.92209216526577, 36.8517792565482, 37.96972009113857, 41.5589406149728, 43.030492646353586, 39.769776003701345, 37.34482690266201, 34.36622101919991, 36.07759012494768, 36.82214171545846, 36.34588786533901, 36.41525520597185, 36.1312232698713, 34.128186157771516, 36.638358388628276, 38.41106966563633, 46.38724728993007, 46.28968415941511, 49.3994094984872, 45.764052936008994, 47.91299179622105, 36.366815839494976, 36.061505045209614, 49.167992796216694, 46.50831617627825, 47.21843249457223, 45.31337193080357, 46.13331495012556, 45.47035952976772, 48.478804452078684, 48.28906304495675, 50.19434595108032, 45.70309291567121, 38.1182656288147, 35.335150786808555, 43.72833149773734, 48.41257074901036, 50.027345997946604, 48.6398845400129, 45.77359628677368, 50.730444635663716, 48.79058401925223, 43.287086146218435, 40.8111754826137, 41.683782373155864, 45.77447175979614, 47.40521049499512, 49.59679044995989, 49.89987087249756, 49.27611371449062, 44.97534901755196, 39.50650528499058, 36.892224720546174, 39.90335859571184, 43.832495416913716, 47.71397801807949, 47.69855301720755, 50.61609465735299, 49.03336450031826, 48.298606395721436, 45.88809217725481, 47.69541937964303, 46.2797760282244, 47.50890193666731, 42.45295490537371, 34.65179892948696, 21.88683077267238, 12.355988502502441, 13.605830465044294, 10.072233745029994, 9.759794967515127, 12.813027109418597, 8.034585918698992, 4.809674646173205, 2.151849069765636, 2.0347013558660234, 0.7770465782710484, 0.06493768761200563, 1.387150526046753, 12.902473875454493, 36.04702499934605, 30.719243594578334, 24.048946891512188, 26.72619550568717, 41.42418725149972, 53.38741840635027, 49.55141176496233, 23.30631821496146, 3.3850312062672208, 0.10487164477152483, 0.011203851484294449, 0.04071088993389692, 0.06838166673800775, 0.01765158130521221, 0.04807018914393016, 0.0662994666823319, 0.051152824623776336, 0.07373110790337835, 0.023428706485512, 0.03184285114652344, 0.048924298491328955, 0.072698506526649, 0.059509665306125364, 0.05523374117910862, 0.004471225589181164, 0.049570046697876284, 0.058821006544998715, 0.06386303063482046, 0.08066707929330212, 0.06052589363285473, 0.13154349928455694, 0.17530488249446663, 0.14229738366390976, 0.2124282254704407, 0.110517503959792, 0.11529396979936532, 0.12762368390602724, 0.10137098761541502, 0.10335559397935867, 0.13557369873992034, 0.1063136945345572, 0.14218946945454392, 0.11427867785096169, 0.09954578948340245, 0.10927476707313742, 0.13621027315301554, 0.1114503267620291, 0.13414869377655642, 0.11097426659294538, 0.15047765257103102, 0.12757415084966592, 0.6702737733721733, 13.652729937008449, 55.018782479422434, 54.93994474411011, 49.40203939165388, 23.458250999450684, 27.779947144644602, 38.83176571982247, 43.85396187646048, 28.35121587344578, 4.0175765327044894, 0.2795715725847653, 0.18064028477030142, 1.4186018726655414, 3.843865922519139, 12.448976244245257, 12.620978900364467, 18.471226624080114, 16.59549614361354, 17.496526377541677, 10.310704605919973, 14.833052567073278, 30.216499737330846, 42.86939518792288, 45.69965703146798, 55.176273822784424, 53.88435009547642, 54.59379938670567, 53.06321198599679, 54.31182411738804, 50.34022685459682, 48.3718786239624, 47.45678002493722, 47.21169621603829, 45.97915179388863, 49.137653487069265, 47.96788951328823, 51.34580489567348, 50.63519178118025, 49.09723581586565, 48.66382455825806, 49.48905863080706, 45.33106551851545, 44.0059745652335, 38.815861293247764, 35.41805669239589, 37.46993964059012, 38.5831035886492, 42.47015864508492, 46.1894668170384, 42.21816485268729, 39.83021490914481, 36.28015095846993, 36.925412791115896, 38.07812588555472, 36.25088514600481, 38.60841587611607, 39.29150717599051, 36.66212470190865, 38.22860649653843, 41.06458323342459, 48.743735790252686, 49.23137773786272, 48.863804136003765, 47.26908833639962, 48.325589724949424, 39.38239656175886, 39.376535756247385, 48.7314270564488, 49.88480370385306, 49.09405354091099, 48.375293663569856, 47.893786975315635, 46.327006408146445, 49.47022901262556, 51.536658014569966, 52.63596030644008, 48.675243922642295, 39.777648312704905, 38.02221720559256, 44.17776182719639, 51.2821489742824, 51.34553739002773, 50.99529954365322, 45.08736787523542, 52.1225266456604, 51.80436863218035, 46.61472436359951, 43.50746216092791, 44.23448692049299, 47.843916279929026, 50.53809070587158, 52.348280566079275, 52.77101591655186, 51.05701344353812, 48.40275641850063, 43.03932728086199, 38.40591410228184, 42.878393105098176, 47.819441250392366, 50.21000024250576, 51.252886635916575, 52.39855773108346, 49.591916288648335, 49.06049721581595, 47.6053637777056, 50.0708451952253, 46.475392137254985, 48.782246180943076, 43.5272193636213, 37.783289500645225, 23.535777262278966, 15.677432400839669, 17.42557484763009, 17.57645845413208, 16.13485836982727, 18.27922705241612, 12.80461197240012, 14.156179904937744, 6.611533182007926, 2.3383721581527164, 1.12119964829513, 0.17651131775762352, 1.7686563517366136, 15.296754496438162, 44.153575147901265, 41.05933039528983, 35.06447328839983, 33.234616552080425, 46.31282860892159, 60.274267877851216, 59.193628447396414, 30.675504684448242, 4.6968207018716, 0.17992153976644787, 0.16214363729315145, 0.08917295679982219, 0.20958717220595904, 0.112881662457117, 0.12462464054780346, 0.19679688209933893, 0.1622703197811331, 0.17676955461502075, 0.09446550958922931, 0.11506024162684168, 0.17716082504817418, 0.13035121826188906, 0.11243418896836893, 0.14693584905139037, 0.17172444319086416, 0.1049734725217734, 0.16778744730566228, 0.12879714236727782, 0.20228137208947114, 0.06462091353854962], [0.015374701070998396, 0.04803127855328577, 0.010351394369666065, 0.07584846964372055, 0.03304933051445654, 0.04936074578602399, 0.09272236669702189, 0.05435987967731697, 0.028350351677675332, 0.02032770136637347, 0.02704314548256142, 0.05071997695735522, 0.023941020780642117, 0.01327339346919741, 0.05468750013304608, 0.050992948202682395, 0.01385572664107063, 0.06955849751830101, 0.08759089812104191, 0.0633977727432336, 0.06464337983301707, 0.3180529219763619, 9.964659128870283, 36.94244282586234, 41.65544067110334, 36.138921873910085, 31.44172075816563, 20.04256694657462, 28.509466307503835, 34.61503253664289, 14.631377628871373, 1.809655066047396, 0.0762114655226469, 0.18755060753652028, 0.49880873411893845, 3.4414981305599213, 9.126714195523943, 12.526723112378802, 16.81331695829119, 10.166531222207205, 7.626807434218271, 8.351726021085467, 15.068822315761022, 28.821192026138306, 42.190542289188926, 48.97710493632725, 47.799093450818745, 51.071205139160156, 45.103480747767854, 49.49143838882446, 47.48005301611764, 50.82108736038208, 51.196477685655864, 50.397226401737754, 48.53329917362758, 46.03896883555821, 43.98334080832345, 46.23330647604806, 46.75669343130929, 49.07542542048863, 48.44541488374983, 46.271174158368794, 46.661860942840576, 45.82277911049979, 45.769173758370535, 44.262644495282856, 38.241332122257774, 32.53950834274292, 33.11346081324986, 33.59098618371146, 34.066204752240864, 34.025463989802766, 34.78985268729073, 35.74042878832136, 34.543695381709504, 31.377474239894322, 33.88746234348842, 33.41084371294294, 34.00946576254708, 32.93881089346749, 34.298771381378174, 35.49219397136143, 43.89248268944876, 45.80329636165074, 45.927446774074006, 44.47512040819441, 48.54291895457676, 36.29171276092529, 32.46713590621948, 51.827339376722065, 43.976437773023335, 45.62977205004011, 39.99169799259731, 35.80701337541853, 35.45989179611206, 36.179499353681294, 38.58608783994402, 41.18022905077253, 40.10516554968697, 35.67274638584682, 33.971028327941895, 34.87399884632656, 42.12657369886126, 46.990416935511995, 47.897149903433665, 46.35714769363403, 48.36198091506958, 50.06432431084769, 44.79104457582746, 46.24345432009016, 46.47471121379307, 46.80171080998012, 47.65012059892927, 48.53123555864607, 46.135420254298616, 49.09847606931414, 48.114069189344136, 45.733536447797505, 42.98461716515677, 42.84018496104649, 44.39080401829311, 47.11197566986084, 47.49606513977051, 46.93140588487898, 43.02484376089913, 43.50894560132708, 48.16902944019863, 48.18606642314366, 47.73309251240322, 46.9493739264352, 44.692380155835835, 37.23130028588431, 28.66690901347569, 17.757681369781494, 18.06927854674203, 8.495732648032051, 10.363274676459175, 4.970152846404484, 8.306225742612567, 4.276969288076673, 1.3052299618721008, 1.4481052266699928, 1.0534042290278842, 0.044261483874704154, 0.5861224574702126, 8.34080605847495, 29.34440701348441, 38.73434502737862, 23.764402525765554, 22.393177270889282, 28.81644640650068, 44.8790157181876, 50.040012563977925, 26.636864253452845, 5.174115478992462, 0.05242456548980304, 0.057605519624693055, 0.0963196675958378, 0.06368592620960303, 0.04069713602906891, 0.024793615298611776, 0.06911677122116089, 0.029937165190598795, 0.037858179437794855, 0.030215205092515265, 0.0423908442524927, 0.07159341046852724, 0.017365117391039218, 0.01282344332763127, 0.014023144978896847, 0.049633055459707975, 0.02507053392140993, 0.047857610907937796, 0.024046746714572822, 0.0391209161441241, 0.028955121458108937, 0.05690861327041473, 0.030671004205942154, 0.06548516359180212, 0.04926115720133696, 0.06791673454322986, 0.03501900571531483, 0.04342513518141849, 0.03961322044155427, 0.062142632236438136, 0.007756071714019137, 0.017184165672266057, 0.04582365469208785, 0.05190172711653369, 0.01849533281555133, 0.04689021674650056, 0.0670124984213284, 0.00920262694957533, 0.03263167863977807, 0.04119268711656332, 0.017467413330450654, 0.03977100018944059, 0.2772963089602334, 13.102729644094195, 43.06137391499111, 49.06062923158918, 42.29790585381644, 33.577788080487935, 26.216024024145945, 33.337863309042795, 37.55162961142403, 17.44894163949149, 2.3753526423658644, 0.13872077129781246, 0.109594872753535, 0.8402920674000467, 4.71195387840271, 11.321561540876116, 12.375400032315936, 13.948444400514875, 6.964927247592381, 6.48207608291081, 7.66019526549748, 15.669926609311785, 27.833328417369298, 42.79771409715925, 50.012056486947195, 50.062820025852744, 52.256956917899, 48.570447717394146, 51.56506225040981, 49.88470295497349, 51.52310902731759, 51.49900572640555, 49.95754092080252, 48.80162818091256, 47.38596051079886, 45.094906670706614, 46.336063385009766, 47.2784058707101, 50.586311204092844, 50.73534311567034, 48.27728584834507, 47.67508200236729, 47.570522035871235, 48.133499826703755, 45.35791335787092, 41.30970178331648, 33.762023040226524, 34.060166767665315, 35.34841142381941, 36.253056458064485, 36.90749338694981, 36.16907010759626, 35.978623458317344, 36.461769921439036, 33.54406499862671, 35.74096032551357, 33.79867131369454, 34.96009397506714, 34.92908763885498, 35.962444577898296, 37.27159636361258, 46.39962550571987, 46.3015273639134, 48.06328133174351, 44.39608464922224, 48.80403920582363, 37.14774819782802, 34.524702480861116, 52.18518550055367, 46.12721790586199, 46.96069254193987, 42.91677148001534, 37.69427612849644, 36.87443733215332, 39.41549777984619, 41.1634977885655, 43.70150102887835, 41.749519280024934, 36.94016381672451, 34.98248107092721, 36.25425154822213, 45.230129037584575, 49.406246525900706, 49.46966620853969, 45.564629214150564, 50.525024618421284, 50.081816400800435, 46.075335706983296, 46.95651320048741, 48.77305024010794, 49.4655876159668, 50.707626751491, 50.572213309151785, 48.99637576511928, 51.321795395442415, 50.01846967424665, 48.19143738065447, 44.47377940586635, 44.521159172058105, 46.39826018469674, 48.00182451520647, 50.218574319567, 48.10616213934762, 45.958522592272075, 45.011806215558735, 49.34343481063843, 47.14070299693516, 48.32408543995449, 46.31247425079346, 47.10791097368513, 35.801934242248535, 26.306209904806956, 13.31293957574027, 15.12638292993818, 6.45299048934664, 11.326928155762808, 11.130343641553607, 8.662332211221967, 6.548444407326834, 3.245800814458302, 3.5781257706029073, 0.751455114356109, 0.029249989028487886, 0.8320625232798713, 9.951423679079328, 31.480568136487687, 38.569078649793354, 25.982849427631923, 25.43902955736433, 31.670142786843435, 50.627559185028076, 55.62351894378662, 30.01436969212123, 5.7317414198602945, 0.20464181900024414, 0.08305383979209832, 0.06753679564488785, 0.008015222049185207, 0.041183849197945425, 0.07199959510139056, 0.06295912020972796, 0.0234296089370868, 0.01888382973681603, 0.03484024227197681, 0.04776728093358023, 0.03471075404169304, 0.007475589934204305, 0.01508373168430158, 0.030573441048285792, 0.0793948939868382, 0.05656591237389615, 0.055166556034237146, 0.011356057915171342, 0.014720216726085969, 0.03189250633918813, 0.09560040012001991, 0.11362148275864975, 0.15862208125846727, 0.20078674943319388, 0.1853889442448105, 0.10825167875736952, 0.16967323182948998, 0.1920743462230478, 0.14384428065802368, 0.10649843247873442, 0.05611924973449536, 0.15309968830219337, 0.10030123644641467, 0.16825946340603487, 0.16732503926115377, 0.1153092368372849, 0.09842988436243363, 0.11065181318138327, 0.24114453313606127, 0.16227786509054049, 0.16366719268262386, 0.7028865005288805, 18.496509381702968, 51.2125176021031, 55.51270907265799, 48.45329066685268, 42.48029954092843, 29.122540610177175, 39.57188088553292, 44.55625452314104, 20.016552891050065, 3.0817501544952393, 0.32458623711551937, 0.5430931864040238, 1.3223326270069395, 5.9232763307435174, 16.707914522715978, 21.411850179944718, 29.55979422160557, 17.805875812258037, 13.903896025248937, 13.472048112324305, 17.71347345624651, 31.150851794651576, 43.14685412815639, 53.200723784310476, 51.865085465567454, 54.65889705930437, 51.19871500560215, 54.47236224583217, 51.23673207419259, 53.586675371442524, 53.86551700319563, 50.79525048392159, 48.183818680899485, 47.84744596481323, 44.82579946517944, 46.270385537828716, 47.78400543757847, 52.756417751312256, 51.61759410585676, 50.173827920641216, 50.99574770246233, 49.52703053610665, 49.532470975603374, 48.31104367119925, 43.6858571597508, 36.14385509490967, 37.23511137281145, 37.46339443751744, 38.28887864521572, 38.35643250601632, 37.08048963546753, 37.6723267691476, 38.98025567190987, 33.774314403533936, 38.123914514269146, 35.248586654663086, 37.07888460159302, 37.2463709286281, 37.78554419108799, 40.102167401994976, 47.52306236539568, 50.24226767676217, 47.91850866590227, 48.04942314965384, 49.51034443719046, 38.92668506077358, 37.04672833851406, 54.10037653786795, 48.80794756753104, 50.13185385295323, 45.75633001327515, 39.39944396700178, 38.86761147635323, 39.556560107639854, 41.66525500161307, 45.380505425589426, 43.352402687072754, 38.47593457358224, 38.09699024472918, 37.93174818583897, 46.68434878758022, 51.3028233391898, 52.6983551297869, 46.59863928386143, 51.22979082380022, 54.157403877803254, 48.931677613939556, 49.563147272382466, 50.880157470703125, 51.50674254553658, 51.03211457388741, 51.83286666870117, 50.68255417687552, 53.12437697819301, 52.15819869722639, 50.156120436532156, 47.26530851636614, 46.82170425142561, 48.20484740393502, 51.79732663290841, 52.15593358448574, 50.5174788747515, 46.032482692173545, 45.95860597065517, 48.569127559661865, 48.18289109638759, 49.97300066266741, 48.0737418447222, 47.81399733679635, 40.833760602133616, 31.265045438494, 21.09707420212882, 23.12230212347848, 15.222205536706106, 21.541772808347428, 12.491322040557861, 15.478569746017456, 12.192473939486913, 7.024122425488063, 3.28839196903365, 2.043149931090219, 0.2968310335917132, 0.9906369170972279, 10.717179434640066, 39.494134017399375, 48.500215326036724, 32.569062505449565, 31.845226969037736, 38.4707407951355, 56.35323960440499, 62.0176681791033, 37.29072822843279, 8.345262459346227, 0.34463803257261005, 0.18616347839789732, 0.19156819981123718, 0.13110888403441223, 0.11857977562717029, 0.1756427657923528, 0.16774278613073484, 0.12169087225837366, 0.17229237700147287, 0.11405478843620845, 0.15851549697773798, 0.12405815880213465, 0.14175329357385635, 0.16524079681507178, 0.1740310958453587, 0.17018612287938595, 0.1497717590204307, 0.13644131432686532, 0.12206720135041646, 0.09819564728864602, 0.2275471527661596], [0.026569188772035495, 0.030238563660532236, 0.03591276525652834, 0.03963402093255094, 0.02460501140116581, 0.05715688584106309, 0.14313371878649506, 0.03244019266484039, 0.0728611581559692, 0.04691703584311264, 0.045598333568445275, 0.03555646312556096, 0.030048187090350047, 0.031129717627274137, 0.01906390275274004, 0.030992969072290828, 0.015409331802012665, 0.048831488471478224, 0.013501293874079627, 0.05924346923295941, 0.09757172755364861, 0.20822953219924653, 16.599585158484324, 40.53546748842512, 45.14806038992745, 33.88776111602783, 15.011880091258458, 9.807810493877955, 28.97206347329276, 37.88589007513863, 15.015411513192312, 1.2698020743472236, 0.06617993595344679, 0.09902066444712025, 2.461122508559908, 10.77496325969696, 13.7283775806427, 10.11058953830174, 6.216661410672324, 3.273125473942075, 2.271104476281575, 7.049431238855634, 20.601052727018082, 28.583250965390885, 44.706220967429026, 47.889270646231516, 46.401730809892925, 46.65455143792288, 46.78332935060774, 44.26586151123047, 44.654022625514436, 45.87967096056257, 45.44732625143868, 48.459210532052175, 48.554164613996235, 49.14971555982317, 47.70031091145107, 46.21041563579014, 46.49432945251465, 46.93514401572091, 46.395154339926584, 45.61650793892996, 47.00556748253958, 46.68206630434309, 45.88689708709717, 45.63674109322684, 45.84655237197876, 39.71679251534598, 33.82514047622681, 32.29059607642037, 32.56635618209839, 32.557743889944895, 34.87240423474993, 33.17448336737496, 33.41981383732387, 33.70560366766793, 34.25499078205654, 33.81712572915213, 34.33900145121983, 34.79480675288609, 34.90835421425955, 35.28383834021432, 43.01461601257324, 45.17483874729702, 46.99856717245919, 42.44167103086199, 46.371648584093364, 37.846900258745464, 32.502894810267854, 49.270089626312256, 44.21955524172102, 44.646845136369976, 40.04722452163696, 38.07178218024117, 34.608157294137136, 33.19335467474801, 32.842936175210134, 34.05352428981236, 35.161511829921174, 33.98379911695208, 34.65559264591762, 34.65491172245571, 38.58392695018223, 47.02192006792341, 48.11453471864973, 46.12648139681135, 45.646729128701345, 50.068962233407156, 48.75006559916905, 48.38387468882969, 48.559782232557026, 49.377595629010884, 45.18793262754168, 46.11118146351406, 46.11427688598633, 48.267356872558594, 48.64862537384033, 48.581568309238975, 47.44416904449463, 46.79677064078194, 47.48281145095825, 49.88486623764038, 47.17531892231533, 46.189178466796875, 47.97190209797451, 47.74071816035679, 47.76626321247646, 48.52422482626778, 51.857341698237825, 50.08056919915335, 51.09657301221575, 42.41811663763863, 28.327034405299596, 18.447158064161027, 20.782831498554774, 6.520941265991755, 4.362642313752856, 16.462995733533585, 6.812132886477879, 3.751648562295096, 1.4502701333590915, 3.456113883427211, 0.9224125551325935, 0.11880571421767984, 0.17908315546810627, 5.701766891138894, 28.310985803604126, 34.278962067195344, 27.563608033316477, 28.310956273760112, 34.07217672892979, 41.33584438051496, 47.74152762549264, 31.916046483176096, 5.639165793146406, 0.5239609416042055, 0.05704612856996911, 0.013995788991451263, 0.01467607293411025, 0.02703636691772512, 0.04754300136119127, 0.04927642084658146, 0.048821215451295884, 0.0716909227360572, 0.035045044496655464, 0.03808243526145816, 0.04415090980806521, 0.04216613041769181, 0.0484091920245971, 0.03179378288664988, 0.025296255380713513, 0.01975046144798398, 0.016830587859398553, 0.1089424816891551, 0.041838930653674264, 0.02536778654237943, 0.013632523394855005, 0.025139842880889773, 0.07103225522275482, 0.02169992309063673, 0.08783916729901518, 0.03705444113750543, 0.05993664703731026, 0.0071067845232651704, 0.04285584769344755, 0.05934127327054739, 0.02452743618882128, 0.06616539494799716, 0.0969704030347722, 0.05588100591142263, 0.019365099358505437, 0.03780405269935727, 0.04353249299206904, 0.045073680114001036, 0.10368916857987642, 0.00249177375891512, 0.0814121039584279, 0.2446162168468748, 21.39265057018825, 47.20281294413975, 51.01909017562866, 40.00652544839041, 22.714904921395437, 12.95916770185743, 29.98615653174264, 38.65183516911098, 15.674484627587454, 1.7952717521360941, 0.10508986163352217, 0.3161047665136201, 1.2539635470935275, 10.634439417294093, 14.735319205692836, 14.625072138650076, 14.507601550647191, 7.116017997264862, 8.888246808733259, 8.744842069489614, 17.230926275253296, 31.789050783429825, 45.758841787065776, 49.68037380490984, 49.238301617758616, 48.59898396900722, 48.5825514793396, 45.93194225856236, 47.066169670649934, 46.98651204790388, 48.41190024784633, 49.30784266335623, 50.13192333493914, 50.246707575661794, 46.600358963012695, 46.260189056396484, 46.433623041425435, 46.74863699504307, 47.183806146894185, 46.455704416547505, 48.38434716633388, 48.84947695050921, 48.82534238270351, 47.786468573978965, 46.43540178026472, 41.082679816654746, 35.6302616255624, 33.595915930611746, 34.124892711639404, 33.861865179879324, 36.030634198869976, 35.715384006500244, 34.6650595664978, 34.29560995101929, 35.607909270695274, 35.91299424852644, 36.649197578430176, 35.66744838442121, 35.88468381336757, 36.10130432673863, 45.171142305646626, 47.82766791752407, 49.27979278564453, 44.46502120154244, 46.05094058173043, 38.87860352652413, 34.776939460209434, 50.06419924327305, 46.02795941489083, 46.56244611740112, 41.21602964401245, 39.59892674854824, 35.98433835165841, 34.70753737858364, 35.04043599537441, 37.146136215754915, 36.87753970282418, 35.214217390332905, 35.14409269605364, 35.93921675000872, 40.45132827758789, 48.16241822923933, 49.1709839957101, 47.85971300942557, 46.16837556021554, 51.307131222316194, 49.96735177721296, 50.10657630647932, 49.69146312986101, 51.08660929543631, 48.04659175872803, 46.18912288120815, 46.548452445438926, 49.08939477375576, 51.40189075469971, 49.622332027980256, 48.37683268955776, 48.31367703846523, 50.16399621963501, 52.09064136232649, 47.169802052634104, 45.89977904728481, 47.597866671425955, 47.36275700160435, 48.38075147356306, 47.86968714850289, 53.29273183005196, 51.27660083770752, 51.34349809374128, 42.372140407562256, 27.688184022903442, 17.195768390383037, 15.269861493791852, 9.071763498442513, 13.201879569462367, 13.393737571580068, 11.16548936707633, 7.293409415653773, 6.287163478987558, 3.928936626229967, 0.9791544760976518, 0.14381135813891888, 0.20247554167040757, 6.503525606223515, 31.343323843819753, 36.05693313053676, 25.266321659088135, 30.206570761544363, 36.48558487210955, 46.76935652324131, 53.25109822409493, 35.98406389781407, 8.45778158732823, 0.4234577731362411, 0.058233062736690044, 0.019809473638555834, 0.07321154006889888, 0.029750113442007984, 0.043520123298679075, 0.05311503933210458, 0.04053470492362976, 0.06695148455245153, 0.04999995630766664, 0.05042435960578067, 0.0401682994062347, 0.033934547299785275, 0.023345202573442032, 0.023721021067883288, 0.011793863976241221, 0.07420342255915914, 0.010665421224465328, 0.059141112225396295, 0.05018417517255459, 0.037678730674088, 0.17616626912994043, 0.1291717208389725, 0.14952674002519675, 0.15540503816945211, 0.19203918453838142, 0.11370215378701687, 0.17539017434631074, 0.08174295084817068, 0.11006942657487732, 0.12865866694067205, 0.18341524872396672, 0.1054406642381634, 0.18613119370171002, 0.07216588367841073, 0.17818352659898146, 0.09613985581589596, 0.09889278773750577, 0.12058296027992453, 0.2685237196939332, 0.10395059455186129, 0.18974155639963491, 0.534247369638511, 26.08392139843532, 55.112826347351074, 57.793635913303916, 46.53790855407715, 24.09421614238194, 16.927963972091675, 38.01464019502912, 46.647571972438264, 18.75006651878357, 2.2318239212036133, 0.2639691212347576, 0.27426773575799807, 4.136094127382551, 17.857858760016306, 24.148811612810405, 18.016989878245763, 12.344812325068883, 9.469407166753497, 7.882719142096383, 13.214298605918884, 24.65040033204215, 31.120856421334402, 47.49997002737862, 52.59335395268032, 50.464655194963726, 49.948077474321636, 51.71190547943115, 47.991690567561555, 48.27599695750645, 49.291524818965364, 50.08315045492989, 51.87982954297747, 51.60532011304583, 50.75692074639456, 48.25635092599051, 45.91502686909267, 46.123757702963694, 46.49196359089443, 47.69758721760341, 46.046007360730854, 47.093149525778635, 50.60756574358259, 50.150322164808, 49.324712889535085, 49.94912665230887, 44.33412756238665, 38.01924337659563, 35.783128942762104, 35.736846991947715, 35.42196158000401, 38.06987837382725, 36.85417638506208, 35.90642472675869, 36.00920595441546, 36.97949756894793, 37.44132348469326, 38.05557550702776, 38.448013237544465, 39.07664803096226, 38.1928197996957, 47.07530655179705, 50.2302577154977, 50.203944887433735, 46.52375159944807, 47.32688692637852, 41.30409458705357, 37.30260617392403, 50.888964312417166, 49.170271805354524, 48.60526166643415, 43.53343105316162, 42.208277566092356, 39.09263931001936, 37.690079416547505, 37.086256640298025, 37.69022880281721, 39.241139684404644, 37.101890087127686, 38.16596501214163, 38.97306081226894, 41.32277829306466, 50.19449186325073, 51.18356793267386, 48.16850137710571, 47.367304597582134, 53.316070829119, 53.48880304609026, 52.63104445593697, 52.74128804888044, 51.222780091421946, 47.09660625457764, 45.98087842123849, 47.689099993024556, 50.426290716443745, 51.74928331375122, 51.930780683244976, 51.772413866860525, 50.90828725269863, 52.9258565221514, 53.56284999847412, 50.25005660738264, 46.882653849465505, 48.48282745906285, 46.78977727890015, 48.763089997427805, 48.68415151323591, 54.57736342293875, 52.1621070589338, 53.78865255628313, 47.53838661738804, 34.23423998696463, 21.810120923178538, 23.692476511001587, 14.441066469464984, 16.88469580241612, 22.648744174412318, 17.94923104558672, 10.155143124716622, 5.5452956301825385, 7.175209266798837, 1.2271093023674828, 0.4084666004138333, 0.33458816898720606, 7.959367326327732, 35.85609197616577, 45.90484080995832, 38.67995800290789, 39.64995779309954, 44.3035763331822, 53.568342549460276, 58.94366700308663, 43.720063141414094, 11.341924105371747, 0.7916795930692128, 0.23669361482773507, 0.11592339245336396, 0.14325521726693424, 0.10237661722515311, 0.17011334321328572, 0.14024181610771588, 0.08889019090150084, 0.2219585890748671, 0.17524517141282558, 0.1779267689479249, 0.09086907721523728, 0.1914841564638274, 0.20362343293215546, 0.0798038470425776, 0.07436043556247439, 0.17442669533193111, 0.07861560330327068, 0.40601611190608566, 0.14044887785400662, 0.07858487245227609], [0.02000611987231033, 0.08990388150726046, 0.038342388812452555, 0.02005580559905086, 0.05202005344576069, 0.07804466358252934, 0.03452631465292402, 0.014403094903432896, 0.01645365996020181, 0.03909907070919871, 0.050343790357666354, 0.01734131607892258, 0.07228314131498337, 0.024325051245146563, 0.008424289607709008, 0.062154845866773806, 0.07244797104171344, 0.07067193955715213, 0.03615956540618624, 0.033494371455162764, 0.04015211634603994, 0.421993793121406, 14.792464665004186, 43.50602388381958, 42.75753961290632, 34.423567976270405, 17.8200101852417, 30.97448566981724, 46.97970281328474, 40.85545635223389, 11.782110725130353, 0.6276313215494156, 0.14393449867410318, 0.18300527786569937, 0.2687371868108, 6.377355005059924, 10.665775792939321, 14.739152874265399, 21.024705239704677, 5.788086533546448, 7.791396362440927, 8.182744094303676, 16.483795166015625, 35.12253243582589, 46.377815110342844, 48.91306686401367, 45.855293205806184, 48.03494310379028, 41.60640375954764, 41.01575824192592, 41.812831265585764, 42.60984522955758, 43.12935856410435, 45.096956389290945, 46.400702476501465, 46.579681124006, 49.65170553752354, 48.985144002096995, 48.527024950299946, 49.90172951562064, 49.01168612071446, 47.826497146061485, 46.633491447993684, 46.5592360496521, 46.17715113503592, 47.18821477890015, 46.08106797082083, 46.20564569745745, 37.52798836571829, 31.440758432660783, 31.72885159083775, 31.898384162357875, 32.43174525669643, 35.67680760792324, 38.11553151266915, 39.06521129608154, 38.96017190388271, 39.54043333871024, 40.33970546722412, 35.92461511066982, 34.97974000658308, 32.64322410311018, 39.111913612910676, 42.642223834991455, 48.063371658325195, 43.14318200520107, 47.95941271100725, 37.10023294176374, 31.091264043535503, 49.767104693821494, 45.202919891902376, 47.459215368543354, 43.7331257547651, 45.34715059825352, 43.2826566696167, 38.5403721673148, 34.579996245247976, 32.92336852209908, 33.867121492113384, 35.592623233795166, 33.20380476542881, 32.45385789871216, 36.742313861846924, 44.278052125658306, 47.60215718405587, 47.04789243425642, 46.18514503751482, 44.89415584291731, 46.27866084235055, 47.32229764120919, 48.37493583134243, 44.07897581372942, 46.63930014201573, 47.160376821245464, 47.8197261265346, 44.201003551483154, 46.14237540108817, 49.497768197740825, 47.77100535801479, 47.50223514011928, 48.72740404946463, 45.813183648245676, 46.77237898962838, 44.23133243833269, 46.30504662649972, 44.14842653274536, 49.16667263848441, 46.27085106713431, 48.93754884174892, 46.22057042803083, 51.56271028518677, 45.71135779789516, 39.56845194952828, 18.418359518051147, 19.80935413496835, 3.623898331608091, 13.676110625267029, 13.939206770488195, 6.881161936691829, 4.942986258438655, 3.2947419711521695, 4.572379333632333, 0.02893972210586071, 0.11915224205170359, 0.0630300406898771, 3.8439436554908752, 28.044854164123535, 51.361969879695344, 49.81419958387102, 42.70708874293736, 32.799357073647634, 40.66288355418614, 45.36002213614327, 32.14106042044503, 6.6533661144120355, 0.7641836713467325, 0.03515510626935533, 0.05151625815778971, 0.027883239689150026, 0.03089307514684541, 0.06595298634575945, 0.05369153625464865, 0.01034292031545192, 0.025790474843233824, 0.04072756153930511, 0.02426356409809419, 0.08704264861132417, 0.08262896151947123, 0.009210112038999796, 0.03810462335656796, 0.034786302130669355, 0.061911421428833685, 0.025072184457842792, 0.055176279441054375, 0.01950649927104158, 0.019811777264944146, 0.05629358234416161, 0.053864484652876854, 0.0645196693284171, 0.02912550838664174, 0.0605603496411017, 0.04903172076280628, 0.062009971854942184, 0.022251470280545096, 0.0508284272093858, 0.06491975393146276, 0.019507064151444604, 0.010523791458191616, 0.03587692503684333, 0.022948300299633826, 0.04174953027229224, 0.0605649704645787, 0.01444500292252217, 0.010213091969490051, 0.033005378408623595, 0.04619669628196529, 0.06122363797788109, 0.5354217237659863, 18.63289209774562, 50.26310532433646, 48.47591747556414, 39.82517051696777, 20.471197843551636, 26.119756732668193, 40.333122049059185, 43.54132768086025, 13.337033322879247, 1.071935074669974, 0.0933196267911366, 0.16664615140429564, 0.44089055912835257, 2.6352971281324113, 5.510219820908137, 10.91383169378553, 7.64511593750545, 7.401592867715018, 9.6568443775177, 9.07335637296949, 20.658842631748744, 36.50344869068691, 49.86726992470877, 50.969834395817344, 48.06465360096523, 48.869216782706125, 44.966580390930176, 43.53058576583862, 43.587894507816856, 44.21061291013445, 45.0168262890407, 46.66205549240112, 49.64716836384365, 48.73805216380528, 50.15319871902466, 49.9449577331543, 50.41835239955357, 48.48261553900582, 48.919174330575125, 47.56210429327828, 45.48749378749302, 47.425016335078645, 45.4520023890904, 48.20392329352242, 48.94285379137312, 46.99051421029227, 38.7921644619533, 32.8703224999564, 34.09371614456177, 32.18550109863281, 35.48104558672224, 36.93106515066964, 39.755174364362446, 40.06796489443098, 41.02717413221087, 41.59309448514666, 41.079035486493794, 37.15754515784127, 36.83495766775948, 35.349457127707346, 40.447979245867046, 44.587712492261616, 48.818203108651296, 45.67936481748308, 48.65939508165632, 39.20401198523385, 33.21000255857195, 50.570455414908274, 46.528292247227256, 48.7421863419669, 46.38737235750471, 48.048023087637766, 44.15929004124233, 40.77408947263445, 35.70109156199864, 35.34163345609392, 35.6445505959647, 36.10393074580601, 35.511405740465435, 33.90639965874808, 38.19745772225516, 45.080148696899414, 49.57483761651175, 48.15966674259731, 47.80689280373709, 46.572573116847444, 48.26465054920742, 47.896316119602744, 48.1628976549421, 45.19913312367031, 45.92484814780099, 48.16408232280186, 48.857269355228965, 45.104022707257954, 46.91672434125628, 51.18708372116089, 49.81219850267683, 49.42944656099592, 50.055104051317485, 47.26158428192139, 46.74022272654942, 45.48329012734549, 46.22108112062727, 45.78687082018171, 48.55947303771973, 49.14797156197684, 49.51852594103132, 50.54290928159441, 51.5589165687561, 49.23595660073416, 36.56661476407732, 20.236225400652202, 11.962329626083374, 7.973485197339739, 7.22182125704629, 13.629260659217834, 9.411478298051016, 7.818793978009905, 8.1723678282329, 2.6059448974473134, 0.6885257139801979, 0.10072350235921995, 0.29786319392068045, 4.016666752951486, 30.94186040333339, 49.65295621326992, 47.361725194113596, 45.26410225459507, 42.10572910308838, 46.31781741550991, 51.977420466286794, 37.906842367989675, 10.120858107294355, 0.8975251934358052, 0.10006507233317409, 0.06225378305784293, 0.0534121833874711, 0.03942504232483251, 0.07509339587496859, 0.038771932013332844, 0.01020453988374876, 0.03966037184000015, 0.057322210898356776, 0.024996300494032245, 0.03197939953367625, 0.08821065165102482, 0.014563330948086721, 0.010577237965273005, 0.030844091703849177, 0.058918735943734646, 0.03290907393342682, 0.05417139621983681, 0.021092513808980584, 0.05391212798921125, 0.1479585098900965, 0.21011328111801827, 0.145552343289767, 0.0992184438343559, 0.14171961109553063, 0.18380430713295937, 0.1697077149791377, 0.08267649289752756, 0.11421015938477856, 0.17843047263366835, 0.1383527067622968, 0.08091692267251865, 0.18156520942492144, 0.12904974738402025, 0.17717609208609375, 0.19508887375039713, 0.10910144887332406, 0.08209587048207011, 0.18305643940610544, 0.09086839868021862, 0.3238825148769787, 0.9074270821043423, 23.887816429138184, 57.90757247379848, 57.27447346278599, 45.954374517713276, 26.762527636119298, 41.57742282322475, 57.79133953366961, 48.94037675857544, 15.48678251675197, 1.3016412172998701, 0.33104040793010164, 0.6864933116095406, 0.9032452979258129, 10.14516464301518, 17.261809280940465, 24.63131536756243, 31.50203112193516, 12.324814540999276, 13.882517286709376, 14.536214232444763, 19.3081944669996, 38.57739564350673, 50.73333508627755, 54.2091749055045, 50.09911394119263, 51.43412344796317, 47.12141827174595, 46.11479105268206, 45.659017017909456, 46.40331847327096, 46.69362810679844, 49.94307477133614, 51.58233894620623, 50.15430695669991, 53.06604337692261, 51.096708502088276, 50.85379253114973, 50.451707226889475, 50.125583103724885, 48.577753748212544, 45.89513070242745, 47.179331507001606, 45.94882638113839, 50.34372527258736, 50.54793630327497, 50.29134975160871, 41.05280603681292, 34.33516604559762, 36.382678576878135, 34.97736719676426, 37.11416755403791, 40.544312545231406, 43.7975355557033, 43.05617666244507, 43.85327747889927, 44.56391838618687, 43.94422939845494, 40.19723612921578, 39.27782964706421, 36.65537800107683, 41.80238812310355, 46.805289132254465, 50.56964247567313, 47.48820672716413, 50.133017676217214, 41.66804470334734, 36.636590072086875, 50.53896270479475, 49.086810043879915, 50.22194072178432, 48.725274426596506, 50.664603505815776, 48.026316915239605, 42.90034246444702, 37.55649682453701, 37.34142228535244, 38.088440486363, 39.32906913757324, 37.286941460200715, 35.774082388196675, 39.80696971075875, 47.712800298418315, 52.817259652274, 48.45249857221331, 47.38545676640102, 45.98680523463658, 49.046861376081196, 50.517537934439524, 48.902331897190635, 43.92405877794538, 46.91567516326904, 48.55577312197004, 49.61649554116385, 45.275740487234934, 47.52760648727417, 52.64326981135777, 51.170074531010215, 51.32094076701573, 52.13320255279541, 47.89172683443342, 47.1681136403765, 45.41361011777605, 47.257766246795654, 45.9239170891898, 50.93639966419765, 49.885922363826204, 52.9841935975211, 49.70531088965279, 56.03386565617153, 49.495110511779785, 42.18392065593174, 24.001379523958477, 24.747176579066686, 10.668245877538409, 20.718489442552837, 23.859347922461374, 12.367284536361694, 13.310288837977819, 10.851989252226693, 9.216216547148568, 0.6371473680649484, 0.2960105219057628, 0.5513680023806435, 4.888526712145124, 33.29246725354876, 60.40533174787249, 57.44699028560093, 51.47840779168265, 46.05033608845302, 50.77747351782662, 58.772810799734934, 44.70022814614432, 14.697328192847115, 1.4061621001788547, 0.3198742728148188, 0.17091417738369533, 0.1555138887571437, 0.09224955671067749, 0.2341765756053584, 0.14106334559619427, 0.13501297097120965, 0.21597727574408054, 0.10510601755231619, 0.0817189442792109, 0.21211949203695568, 0.22079701854714326, 0.059649918494479995, 0.059461401110248904, 0.10060355772397347, 0.1489170898816415, 0.1523855301950659, 0.270058023078101, 0.07258242275565863, 0.08255537439669881], [0.01328274792259825, 0.031191874827657427, 0.051751275546848774, 0.06972066738775798, 0.004826873782024319, 0.015112672899184483, 0.023269445834947482, 0.07730100277279105, 0.0698129820770451, 0.018570682433034693, 0.05045079533010721, 0.012903794596370841, 0.022279936520914947, 0.0564261748721557, 0.025154514504330497, 0.015494040113740733, 0.07611024845391512, 0.06938290622617517, 0.025108599735956107, 0.008500329634573842, 0.01422534162910389, 0.132908291050366, 12.954240560531616, 39.64912748336792, 42.915173394339426, 37.888252462659565, 21.941454035895212, 41.7039668900626, 50.004861627306255, 36.16045781544277, 9.128419978278023, 0.7974506691098213, 0.32724452018737793, 8.348811251776558, 23.235328469957622, 28.98515909058707, 14.915319238390241, 10.041573081697736, 8.868965557643346, 6.532633347170694, 14.257546305656433, 9.633875370025635, 21.003622668130056, 38.8749418258667, 45.908863816942485, 44.029344831194194, 50.636543205806184, 44.329955169132774, 46.66786766052246, 41.27168818882534, 38.73154490334647, 34.19384316035679, 37.69926493508475, 39.22885179519653, 42.369694641658235, 42.40943833759853, 44.98657383237566, 45.00968701498849, 47.269102232796804, 46.88034357343401, 48.10703066417149, 46.67384311131069, 50.070230279650005, 46.07915374210903, 47.19084814616612, 45.52733128411429, 47.44063935961042, 45.17214284624372, 39.3708347593035, 30.87099920000349, 32.904420784541536, 34.48911380767822, 43.261951037815635, 43.44818360464913, 46.90921333857945, 46.285289423806326, 46.97824021748134, 42.72125611986433, 41.28451108932495, 36.96730695452009, 36.54375866481236, 33.67991270337786, 36.28676216942923, 41.03541122164045, 47.57048034667969, 42.47577278954642, 47.756243910108296, 36.64389262880598, 31.957902431488037, 49.16750642231533, 43.03889649254935, 45.75400236674717, 44.17812660762242, 46.42098079408918, 45.406967639923096, 44.17986365727016, 37.12514918191092, 33.94583068575178, 34.69393627984183, 33.939316749572754, 35.453155517578125, 36.18476608821324, 31.632615566253662, 42.10912677219936, 46.54957457951137, 47.29578331538609, 45.02563313075474, 47.94534608295986, 47.30254738671439, 46.389957087380544, 47.12154333932059, 48.371117796216694, 47.99266331536429, 46.200952189309255, 47.20735011781965, 48.540084089551655, 43.983907086508616, 43.6076204436166, 45.3460180418832, 44.41451474598476, 44.789724418095176, 45.44949756349836, 44.064718110220774, 45.187956946236746, 44.68549101693289, 47.30585820334298, 49.702097347804475, 46.790333134787424, 45.984446321214946, 48.47052219935826, 47.01887675694057, 48.97340849467686, 39.95660611561367, 28.170658247811453, 14.802791425159999, 10.692487273897443, 8.107240625790187, 9.498730301856995, 10.485458748681204, 7.660497512136187, 8.12414733001164, 2.1648528405598233, 0.7807445941226823, 0.0653948030833687, 0.3093319285128798, 1.846587564264025, 20.682641948972428, 41.444566317967, 54.346179485321045, 37.912081309727256, 23.71424174308777, 45.64470025471279, 45.66758762087141, 30.156512464795792, 11.000284654753548, 0.4869624897837639, 0.06164600567093917, 0.012191194575279951, 0.006222618194962186, 0.03570683666371873, 0.040496377873101404, 0.06640063625361238, 0.02229429771458464, 0.03878029156476259, 0.08263723286134855, 0.0250549598463944, 0.02858128598225968, 0.04712026047387293, 0.03558125000979219, 0.014198399548019682, 0.028622686796422516, 0.04193419357761741, 0.02481666682953281, 0.022906351568443433, 0.06889455778790371, 0.025533262573714768, 0.01680866439294602, 0.03309941996953317, 0.022663359696577703, 0.04403732643861856, 0.028281169943511486, 0.06329443864524364, 0.04778909244175468, 0.06393027345516852, 0.06289527684982334, 0.03323647386527487, 0.026888527707862, 0.034441721692149124, 0.056847280490079095, 0.0486407794191369, 0.03231798850798181, 0.02415127503419561, 0.03632225435493248, 0.05314303907964911, 0.04264724567266447, 0.07291991250323397, 0.02962167694100312, 0.5205824343221528, 16.711204494748795, 46.89315257753645, 48.73724964686802, 43.463994230542866, 24.788547890526907, 37.70197125843593, 51.42255817140852, 38.72641365868704, 10.910913450377327, 0.7544475623539516, 0.4643392094544002, 8.300929478236608, 18.30065529687064, 13.552686299596514, 11.036939007895333, 12.34164047241211, 10.552307367324829, 11.151987280164446, 11.054715973990303, 9.089109676224844, 24.187921285629272, 40.79913772855486, 45.37085437774658, 48.45420435496739, 50.28908463886806, 46.276044845581055, 46.80581372124808, 43.54650408881051, 39.56450884682791, 36.94464193071638, 40.29072414125715, 42.919682775224956, 44.51191111973354, 46.90826490947178, 46.7056484903608, 47.193870612553184, 47.87803888320923, 48.22244719096592, 49.729709489004954, 49.097298349652974, 49.20927899224417, 47.262174878801616, 46.40553494862148, 46.7205627986363, 47.80655581610543, 48.0229400907244, 40.27455915723528, 33.00492647715977, 33.45988409859793, 34.98901585170201, 44.14913524900164, 46.308499881199424, 49.15077863420759, 48.72122015271868, 48.61763293402535, 43.585844789232524, 43.222377572740825, 39.30530629839216, 38.919615268707275, 35.91842079162598, 37.73314435141427, 43.874691826956614, 49.21795381818499, 45.61307552882603, 48.59115334919521, 38.705714975084575, 32.8521842275347, 49.63474498476301, 43.32294579914638, 48.22997209003994, 44.81846216746739, 48.55675629207066, 47.264342716761995, 45.694296496255056, 39.1065947668893, 36.47906746183123, 35.88728591373989, 36.643639019557405, 35.821055684770855, 37.49620383126395, 34.101466860089985, 43.89868743079049, 47.445391927446636, 50.60292782102312, 46.02571514674595, 47.97476475579398, 46.858936173575266, 46.34903219767979, 47.697545528411865, 49.130913734436035, 48.112207072121755, 47.28589602879116, 48.928272996629985, 49.857229777744834, 44.95847879137312, 44.65830618994576, 44.90044396264212, 45.24075630732945, 45.73469679696219, 45.3963577406747, 43.79267181668963, 46.117268085479736, 46.243805204119, 47.98084442956107, 50.92999342509678, 48.391166823250906, 48.66493279593331, 50.115591594151084, 49.41310092381069, 50.088608264923096, 44.02660376685006, 27.747754403523036, 16.874044213976177, 9.59104493686131, 10.283240982464381, 9.034773026193891, 11.234818492616926, 8.905946476118904, 10.656733580998011, 3.2195804842880795, 1.2565045250313622, 0.04943296905340893, 0.1758509674774749, 2.9912722323622023, 24.66275770323617, 46.74240098680769, 57.84865869794573, 45.78016928264073, 29.566256046295166, 51.88668046678816, 51.77409880501883, 35.77552761350359, 13.250837445259094, 0.8777179419994354, 0.027431106361161386, 0.011905296389678759, 0.04932701920292207, 0.05238016215818269, 0.014671033115259238, 0.037412171584687064, 0.07738187057631356, 0.03409523117755141, 0.0701065231114626, 0.024446676950901747, 0.030515192209609916, 0.047960819476949315, 0.019152137750227536, 0.041999438112335544, 0.04839688679203391, 0.010677147157756346, 0.013360411344495202, 0.052611244044133594, 0.0880550296444978, 0.011969155864790082, 0.1345009891582387, 0.12486455695969717, 0.13801201432943344, 0.20043083067451203, 0.07239851940955434, 0.12453359471900122, 0.2080769296735525, 0.15324492193758488, 0.2129152507654258, 0.1148862788187606, 0.20043615038905824, 0.17096908443740436, 0.1319440385060651, 0.1191598145025117, 0.07985171090279307, 0.10985013084220034, 0.21231041822050298, 0.15176112870020525, 0.15239850378462247, 0.14709242779229367, 0.10711401301835265, 1.239205030458314, 21.081583193370275, 56.0355783871242, 54.56875460488455, 50.10177162715367, 31.70006172997611, 50.64469344275338, 57.03249202455793, 42.34821775981358, 11.888558864593506, 1.246826987181391, 0.6708151357514518, 11.378562825066702, 30.22973952974592, 34.8413735798427, 23.064484425953456, 19.869568961007253, 19.251040322440012, 14.224143709455218, 22.832753317696707, 15.330649546214513, 24.095251423971995, 41.382810728890554, 49.4498291015625, 48.740869658333914, 52.74153470993042, 47.39633764539446, 49.91348934173584, 46.54863657270159, 42.01941858019148, 38.04681035450527, 41.38018083572388, 44.20706238065447, 45.802608489990234, 48.62985134124756, 48.439710412706646, 49.127790519169395, 51.82112768718174, 50.84586116245815, 52.30909967422485, 49.77959755488804, 52.45835392815726, 49.13587474822998, 47.33793108803885, 46.74390527180263, 49.03990970339094, 48.75943871906826, 44.492087909153526, 34.889687878744944, 35.39799724306379, 37.74528285435268, 47.8853622845241, 48.715282917022705, 52.070745195661274, 50.92956611088344, 50.56384072984968, 45.767596517290386, 44.86654717581612, 40.966717856270925, 40.15131548472813, 38.96064438138689, 37.9875283241272, 45.99645280838013, 51.764419964381624, 47.56692981719971, 50.117377281188965, 40.039334842136924, 37.39953007016863, 50.01314388002668, 44.42955412183489, 47.93773433140346, 46.388859272003174, 49.45571075166975, 48.56154360089983, 49.751895087105886, 42.163520744868684, 37.34287098475865, 37.48276948928833, 38.72482252120972, 38.11294330869402, 40.20049830845424, 35.317255701337544, 46.05937222072056, 49.15214742933001, 52.02065215791975, 50.15136786869594, 48.71302127838135, 47.502707617623464, 47.00155142375401, 49.24095582962036, 50.92999689919608, 51.4449348449707, 49.82945435387747, 50.65350375856672, 51.0692492212568, 44.771221365247456, 43.59692716598511, 43.814648968832834, 45.43219307490757, 45.326952184949604, 45.41212320327759, 43.41883093970162, 46.71931559698922, 47.29588059016636, 48.49840532030378, 51.972515038081575, 50.84461743491036, 50.59252289363316, 54.03256559371948, 50.68636873790196, 54.14794390542166, 47.609768935612266, 34.054851395743235, 19.108562299183436, 17.577076843806676, 16.396543162209646, 15.996181011199951, 14.54866453579494, 17.511233976909093, 17.495411191667827, 5.852279203278678, 2.802935881274087, 0.2526739559003285, 0.376382370612451, 3.49176487326622, 26.59703196798052, 50.60114213398525, 59.685845783778596, 45.16457973207746, 36.02124718257359, 57.23770012174334, 60.22162137712751, 40.84871659960066, 16.921286753245763, 1.3393047962869917, 0.19759702416402952, 0.13819042832723685, 0.18308241372661932, 0.18743224388786725, 0.18358074341501507, 0.1056624637650592, 0.18644759458090576, 0.10002744756639004, 0.17325961509985582, 0.11785561591386795, 0.09225280010806662, 0.12539913398878916, 0.1467540016663926, 0.09017710041786943, 0.13669216872325965, 0.1499568090907165, 0.08798298279621772, 0.11974948857511793, 0.16611229362232344, 0.08281684786613498], [0.03559403700221862, 0.02452207067316132, 0.0046303373861259645, 0.059492491584803374, 0.05580945100103106, 0.015516014470319663, 0.09779394777225596, 0.0783468559384346, 0.042015376899923594, 0.061057308688759804, 0.019581981202853576, 0.03295658156275749, 0.025686760765633414, 0.052612407731690576, 0.02121045676592205, 0.034677366726100445, 0.015434439294040203, 0.034757847764662335, 0.08889827903892313, 0.08383637387305498, 0.03287104883098176, 0.13809517558131898, 20.411361694335938, 44.668891770499094, 48.030913148607524, 27.730594090053014, 22.105226550783428, 44.88849653516497, 50.021318435668945, 33.39419930321829, 6.648946625845773, 0.4393916481307575, 0.022132976013900976, 3.055326372385025, 27.083683797291346, 29.97616502216884, 3.7486148050853183, 6.378029848848071, 3.2759774923324585, 8.644093189920698, 8.696104798998151, 10.78745698928833, 32.84412431716919, 36.03542845589774, 40.59194592067173, 50.310335704258506, 48.25160878045218, 49.30660240990775, 45.55817781175886, 42.38614797592163, 37.2758903503418, 34.98711551938738, 34.1932247706822, 34.09578670774187, 33.3184882572719, 35.89971971511841, 39.47847625187465, 39.91035543169294, 43.31933968407767, 43.59092044830322, 44.060097558157786, 43.093269620622905, 43.81282159260341, 47.005157538822715, 47.60680900301252, 48.44669335229056, 47.103071553366526, 47.469821793692454, 36.11031266621181, 33.755363191877095, 35.069997106279644, 41.32546724591936, 46.79645102364676, 48.14470032283238, 46.80109589440482, 46.91303832190377, 42.85340738296509, 42.41920403071812, 42.79077284676688, 36.456082820892334, 34.84122766767229, 32.6147642816816, 33.39747537885393, 37.537886074611116, 46.17763403483799, 44.41908318655831, 47.43163102013724, 37.356631892068044, 29.41368055343628, 49.556998116629465, 44.57349647794451, 45.77608026776995, 44.363959653036936, 45.39769179480416, 41.87733139310564, 43.43754938670567, 39.794601917266846, 34.63276086534773, 33.752601282937185, 34.34561961037772, 34.72176728929792, 37.49333075114659, 32.215694495609824, 40.01364387784685, 48.81983593532017, 45.554530007498606, 45.5170236315046, 49.58636120387486, 47.32209266935076, 48.548811026981895, 48.62124252319336, 47.76241738455636, 42.32855435780117, 42.29002659661429, 42.48758820125035, 47.62762233189174, 46.36166402271816, 45.95268610545567, 45.69976472854614, 46.6649181502206, 46.00170564651489, 44.6933251108442, 44.02381406511579, 45.50691747665405, 45.92128372192383, 48.133051667894634, 46.29374190739223, 45.17466156823294, 41.538905484335764, 44.54287576675415, 45.74292346409389, 45.90997205461775, 41.16047532217843, 26.72397903033665, 13.194697737693787, 9.299360428537641, 5.26412114075252, 9.181690948350088, 12.720470155988421, 6.25737828867776, 8.233684812273298, 1.5991290999310357, 1.0678789551768983, 0.09654536191374063, 0.045948243899536986, 1.9267215728759766, 14.157348070825849, 41.27664572851998, 47.21189423969814, 18.70767729622977, 30.249948365347727, 39.58347395488194, 51.58337075369698, 34.69405787331717, 13.115183421543666, 0.7717735469341278, 0.030496793732579266, 0.01922995044982859, 0.056392933441592116, 0.026084685930982232, 0.07583225265677486, 0.03428465440603239, 0.0451340391965849, 0.03752738343817847, 0.0500521865407271, 0.012613613158464432, 0.05482144633840237, 0.07580297387072019, 0.05009553475039346, 0.10769771598279476, 0.010527283369031335, 0.018830671607117568, 0.018141247797757387, 0.0306646056207163, 0.022135181252711585, 0.014261854446626135, 0.046070624475500414, 0.03020274718957288, 0.05748759023845196, 0.042195497413298914, 0.05926289569054331, 0.0252840875514916, 0.036412811638521295, 0.03746834749888096, 0.012199878975349878, 0.05576176695259554, 0.049386302807501385, 0.018869524522285377, 0.05296079475166542, 0.014407047369916524, 0.05977832446140902, 0.010379738473732556, 0.03124195071203368, 0.0369229749776423, 0.035045455010341744, 0.03984980185383132, 0.08318215076412473, 0.42018088325858116, 24.294463225773402, 50.23773397718157, 53.15750598907471, 34.1172080039978, 24.153414794376918, 44.66647032329014, 49.75145387649536, 38.75570378984724, 7.943705218178885, 0.6492396220564842, 0.04001353574650628, 5.30333069392613, 32.19744157791138, 37.77113362721035, 10.673898237092153, 11.127331597464424, 6.236293111528669, 8.549447434289114, 11.269885182380676, 11.724588326045446, 30.800818920135498, 36.75561271395002, 43.575384276253835, 49.981425353458945, 51.46452876499721, 50.76054770605904, 48.15914910180228, 44.894221850803916, 39.16652992793492, 36.11107349395752, 36.48495258603777, 36.18356057575771, 36.59603343691145, 37.768757343292236, 42.78635726656233, 42.45832586288452, 44.42922060830252, 46.10455635615757, 46.74779278891427, 46.596516609191895, 46.172412463596885, 48.32153197697231, 48.59033693586077, 47.905192443302695, 47.879793303353445, 48.166170256478445, 38.55257320404053, 34.13666990825108, 36.8467835017613, 43.21871239798409, 49.0171856198992, 49.92008318219866, 49.17427396774292, 46.69931868144444, 45.88770307813372, 45.639808722904746, 45.0658597264971, 38.940282685416086, 37.770393644060405, 34.996002265385215, 35.41664620808193, 39.706182616097585, 47.36720732280186, 45.82118797302246, 48.306555134909495, 37.75438846860613, 31.75697442463466, 49.49545444761004, 45.600054604666575, 46.40265839440482, 45.22446278163365, 46.084225927080425, 44.08961003167288, 46.20022957665579, 42.0836512020656, 36.33640010016305, 35.28088188171387, 35.5025954246521, 36.42808158057076, 38.97250495638166, 33.562505517687114, 42.739533356257844, 49.9784654208592, 47.70661987577166, 48.28849676677159, 49.80944354193551, 50.0361076763698, 48.88856751578194, 50.918608801705496, 49.02472441537039, 43.950117996760774, 44.5076379776001, 45.18192590985979, 49.631156240190776, 48.04635551997593, 44.62753956658499, 45.08374438967024, 45.63622692653111, 46.00432859148298, 43.94244371141706, 45.31245476858956, 45.6865805217198, 46.72437388556344, 48.460770402635845, 48.22468103681292, 47.8048917225429, 44.19455214909145, 47.39106048856463, 48.51140539986746, 47.71053171157837, 45.28955350603376, 29.509273869650706, 17.375997713633947, 8.865986517497472, 8.78784533909389, 10.397957478250776, 14.34009177344186, 10.931920460292272, 7.880722403526306, 3.991327541215079, 1.7157124898263385, 0.16826470169637883, 0.039379424415528774, 2.5540012504373277, 17.294403280530656, 45.161202907562256, 53.49307271412441, 26.836685759680613, 31.423158645629883, 44.49206359045846, 58.07606281552996, 41.28450414112636, 15.886312620980398, 1.2515679384980882, 0.023459437336506586, 0.009442829194345644, 0.04511605462591563, 0.03279986032950027, 0.05075095547363162, 0.02963809748845441, 0.06051270969744239, 0.02377470675855875, 0.09097311020429645, 0.01162685700027006, 0.05994171569389956, 0.0551056303749127, 0.08605386702609913, 0.039304239342787435, 0.02479214796663395, 0.047663051169365644, 0.03568601581667151, 0.019332868945119635, 0.030443457487438406, 0.0862091158383659, 0.145206643268466, 0.08490517509302922, 0.1365396204803671, 0.13488791696727276, 0.14432294640157903, 0.13234810610967024, 0.19952280154185636, 0.10030023899993726, 0.13344651859785828, 0.09869882171707493, 0.09237415609615189, 0.17147234029003552, 0.14696558245590755, 0.1724357378802129, 0.12447985474552427, 0.116084218823484, 0.11221570069236414, 0.13275446716163838, 0.1495862068342311, 0.19016634646270955, 0.19462311374289648, 0.9332530477217266, 31.149448258536204, 57.957696778433665, 59.81542273930141, 40.106711523873464, 32.19787931442261, 51.42600447790963, 53.312054770333425, 41.001945223127095, 10.000985179628644, 0.802078115088599, 0.16581476958734648, 4.798470675945282, 31.520158972058976, 35.59916148866926, 6.310761298452105, 11.526402252061025, 9.431782671383449, 15.151082038879395, 15.14352239881243, 14.845234496252877, 33.69515010288784, 40.924278259277344, 45.154563903808594, 52.88563340050833, 51.48587015696934, 54.06092119216919, 49.67589916501726, 47.35490206309727, 40.800899096897666, 38.01480695179531, 37.81654705320086, 37.68031372342791, 36.912291118076865, 39.07558495657784, 43.21523135049002, 44.51045199802944, 46.04865115029471, 48.92809581756592, 48.458689417157856, 48.5584898676191, 48.319940839494976, 50.61851610456194, 49.90715953281948, 50.16136285236904, 49.75340632029942, 51.09064967291695, 39.5055707522801, 36.64726250512259, 38.664588587624685, 45.68347815104893, 50.96501929419381, 50.967993123190745, 49.927239826747346, 51.35129049846104, 48.59604140690395, 47.52371202196394, 47.48457629340035, 39.731873580387656, 38.7549638066973, 37.45515387398856, 37.31717654636928, 42.64525324957711, 49.385638168879915, 48.50883804048811, 48.56860644476754, 39.893575532095774, 35.78468186514718, 49.460011686597554, 47.76742703574044, 48.025569983891074, 45.632363728114534, 47.7805243900844, 46.502653394426616, 48.94560180391584, 43.30229575293404, 38.0948224067688, 37.05938795634678, 37.85181958334786, 38.994475160326274, 41.37961803163801, 35.89271593093872, 44.762987749917166, 51.6637544631958, 49.35062619618007, 49.924839224134175, 53.06347254344395, 51.85949216570173, 52.84097385406494, 53.30202504566738, 51.80699505124773, 46.29563181740897, 47.601545742579866, 46.735021999904085, 51.700586863926475, 48.294986384255544, 45.964748178209575, 45.95952313286917, 47.14993020466396, 46.6430104800633, 43.69410119737898, 44.85257434844971, 46.794748714991975, 46.83833476475307, 50.75345706939697, 50.21496820449829, 50.32320029394967, 44.228230067661826, 49.69452381134033, 49.78842176709856, 51.33206483295986, 47.2282954624721, 31.195118767874582, 15.371346882411412, 14.200252328600202, 11.445382782391139, 18.78886178561619, 25.793894904000418, 13.05845138004848, 15.006694998059954, 7.5726375409535, 2.6112426817417145, 0.3113129250705242, 0.23227681326014654, 2.485359562294824, 20.126304898943218, 50.29685272489275, 55.76688807351248, 28.501034668513707, 40.33109664916992, 50.76219095502581, 65.00031444004604, 47.82375955581665, 19.056747845241002, 1.6733475859676088, 0.0905562929276909, 0.09003381417798144, 0.11529540829360485, 0.08370117577058928, 0.07537847557770354, 0.0774381279147097, 0.10275022539177112, 0.1015793928610427, 0.12057346078966345, 0.08952690780694995, 0.09086978967700686, 0.16300586531204836, 0.21785026309745653, 0.20493172987231187, 0.10196657172803368, 0.09525780100375414, 0.15490274583654745, 0.09735950894121613, 0.10489172940807683, 0.13721687985318048], [0.013595381236102964, 0.038861559703946114, 0.024980097077786922, 0.042397293727844954, 0.026095157422657524, 0.03630316037950771, 0.010929035471885331, 0.03768781286531261, 0.03903876251674124, 0.03318044722878507, 0.024607413415131823, 0.030683027846472602, 0.020019246132246087, 0.016730546352586577, 0.0625169121527246, 0.019805008878133128, 0.05727393991713013, 0.005986505395932389, 0.022460491296702197, 0.03041988518089056, 0.028761277573981454, 1.068014336483819, 15.569766589573451, 44.61708600180489, 41.14606475830078, 27.947525535311016, 30.075416564941406, 37.7395783833095, 38.06090130124773, 22.775562695094518, 7.10240821327482, 0.18503535964659282, 0.0733479323929974, 0.12864224639322075, 0.12417498896164553, 0.5074510446616581, 11.903496623039246, 13.004927669252668, 10.449956059455872, 9.598866871425084, 12.9111921276365, 12.212185978889465, 26.894058772495814, 36.97157662255423, 44.171814169202534, 48.108305658612935, 45.63414246695382, 47.048368385859895, 46.97515174320766, 45.3043566431318, 37.3715809413365, 32.93802227292742, 35.13124200275966, 31.498887062072754, 31.682649544307164, 29.194951261792863, 31.835228511265345, 33.613272530691965, 33.954915455409456, 33.857595511845176, 35.196843419756206, 36.62539652415684, 40.539973395211355, 41.98192262649536, 45.61401006153652, 48.016749245779856, 46.87991278512137, 41.61176776885986, 33.31965902873448, 31.62279428754534, 40.668372631073, 45.55070849827358, 48.276962757110596, 44.251117433820454, 44.591544423784526, 44.42575693130493, 46.3052932875497, 42.67665215900966, 40.695904867989675, 34.35356140136719, 33.73644324711391, 31.77000229699271, 33.961373805999756, 34.652222769601, 42.78520386559622, 43.480979101998464, 50.0203526360648, 38.68820551463536, 27.654282024928502, 49.09660700389317, 43.219042437417166, 46.609534059252056, 45.149220739092144, 45.548895018441335, 42.71169887270246, 43.25599643162319, 36.5833877154759, 34.35246011189052, 33.19849981580462, 34.39062656675066, 33.239341327122276, 33.56745958328247, 31.44315903527396, 33.69706085750035, 40.659235749925884, 47.343312467847554, 46.93511274882725, 43.76155778339931, 43.28804152352469, 43.52857426234654, 41.177255221775596, 40.03310578210013, 37.08641644886562, 38.59300477164132, 43.31172445842198, 46.24154356547764, 46.143421104976106, 48.35806907926287, 47.4529515675136, 46.33463553019932, 48.42271859305245, 46.13755335126604, 44.843489578792024, 41.730449948992046, 46.501906463078086, 47.13720457894461, 46.62029334477016, 43.10001632145473, 42.953965187072754, 45.503120286124094, 47.94306707382202, 46.50987952096121, 48.4702581678118, 27.338272741862706, 18.56886271068028, 5.717907556465693, 10.501527326447622, 4.949295657021659, 6.040295720100403, 9.803225551332746, 5.413167382989611, 2.6970079881804327, 1.6275458208152225, 0.10548774778310742, 0.028788100063268627, 1.6139336483819144, 12.970929265022278, 38.695219721112935, 37.83958727972848, 18.756542239870342, 29.52689102717808, 41.70372717721121, 45.52099452699934, 31.870872770036968, 8.49285956791469, 0.5853989220091275, 0.03539798787928053, 0.042743682462189875, 0.046573880328131576, 0.04423308718417372, 0.05793996275003467, 0.024923230754211545, 0.025060411875269244, 0.10084633076829569, 0.03841738389538867, 0.03057014336809516, 0.05232491922963943, 0.020262979303619692, 0.04250209006880011, 0.02018742442929319, 0.038850899918803146, 0.01910938834771514, 0.10752008908561297, 0.034180346610290666, 0.05167238228023052, 0.03452498811696257, 0.007791999295087797, 0.03233226488477417, 0.08621163320328508, 0.05610915991876807, 0.05163174481796367, 0.03771352594984429, 0.06747660280338355, 0.009912543364667466, 0.02220697365035968, 0.027969980213258947, 0.030434616176145415, 0.05505499469914606, 0.012097186941121305, 0.04061605787969061, 0.020629310182162693, 0.03240993678835886, 0.042798162038837156, 0.03168921046225088, 0.03927228034340909, 0.047730327916464636, 0.02842716862713652, 1.240883237549237, 19.613936049597605, 50.33141653878348, 48.221592562539236, 33.777159690856934, 34.43054049355643, 44.464906556265696, 47.12140784944807, 30.329314163752965, 7.362269537789481, 0.32987224204199656, 0.10443734164748873, 0.25308227113315035, 0.9606290587357112, 3.286876827478409, 10.196927853993007, 11.798894098826818, 7.51150381565094, 8.481641701289586, 11.612545149666921, 14.674348763057164, 27.44609488759722, 36.67295694351196, 45.663536821092876, 48.209071908678325, 47.385303906032014, 48.05098302023751, 48.51294789995466, 47.19857801709856, 39.36397688729422, 34.65966081619263, 37.24447059631348, 33.80809307098389, 33.560712882450645, 31.899457659040177, 34.11649581364223, 35.47757148742676, 36.35239485331944, 37.407860960279194, 37.81947224480765, 40.913602352142334, 42.96396017074585, 43.46578686577933, 47.55977317265102, 49.412909848349436, 48.47859948022025, 44.131313119615825, 35.257289273398264, 33.01892709732056, 41.779174191611155, 46.9645140511649, 49.604047843388145, 46.36136872427804, 47.533578463963096, 46.347322940826416, 47.73805700029646, 44.59244768960135, 42.17748662403652, 35.93716008322579, 35.222652503422324, 33.24007436207363, 36.49610791887556, 37.09755441120693, 45.709679807935444, 45.746321133204866, 49.59909725189209, 40.352656909397666, 31.10285016468593, 50.52984666824341, 45.05854327338082, 48.33737734385899, 47.08001743044172, 47.57502794265747, 44.511768681662424, 45.46499899455479, 39.155510084969656, 35.03430768421718, 34.82403782435826, 35.56686973571777, 33.909519399915425, 35.507136072431294, 33.40132468087332, 35.76587656566075, 43.524995940072195, 49.76009048734392, 47.336082867213655, 46.49746656417847, 44.89460400172642, 45.01567983627319, 44.89296770095825, 43.60959720611572, 40.088712215423584, 41.32850013460432, 45.07827615737915, 48.765980448041645, 47.83104474203927, 47.52219384057181, 48.742165497371126, 47.73355456760952, 49.4780387878418, 46.919013772692, 44.84899950027466, 42.27274295261928, 46.831605434417725, 50.95367635999407, 48.85388558251517, 44.99758325304304, 44.08834545952933, 46.591972487313406, 49.382817200251985, 49.79222590582711, 49.68375757762364, 30.385076931544713, 19.1491310937064, 9.163789783205305, 13.580942017691475, 14.766292537961688, 13.40870920249394, 11.399934615407672, 8.089638233184814, 5.2974564262798856, 1.1642276708568846, 0.2320820465683937, 0.004272461902084095, 1.5952780608619963, 14.521974767957415, 44.92753151484898, 40.55496760777065, 19.7824923992157, 37.816901411329, 45.21106318065098, 54.005168846675325, 37.31233365195138, 12.376443999154226, 0.7644131790314401, 0.09935492436800684, 0.03932415773825986, 0.042753002140671015, 0.048305338847317865, 0.07284027284809522, 0.0394151051794844, 0.04888781366337623, 0.09107602361057486, 0.013193230493925512, 0.06921154220721551, 0.03322919996987496, 0.019518472021445632, 0.015871948496039425, 0.07811679185501166, 0.02330589503981173, 0.06291526649147272, 0.03034595539793372, 0.04352432003776942, 0.0499683976439493, 0.012909565536704446, 0.08809653563158852, 0.11217253907982792, 0.2202586688633476, 0.22317479524229253, 0.06272341071494988, 0.09316527364509446, 0.12886922992765903, 0.18681232072412968, 0.10092406374003206, 0.06944788952491113, 0.1067273701940264, 0.1042683728571449, 0.10361058065401656, 0.14571501527513775, 0.11791205645671912, 0.13029120862483978, 0.19992306934935705, 0.07569774666002818, 0.20761477947235107, 0.0976637029754264, 0.1100366533334766, 1.9499231278896332, 25.394043445587158, 58.2870066506522, 52.375746795109336, 40.18735926491873, 40.402847221919465, 44.91388177871704, 45.97519132069179, 29.59675168991089, 9.480502571378436, 0.40188551640936304, 0.20624918703522, 0.5712241626211575, 0.5196355251329285, 1.8685859952654158, 18.3607120513916, 24.119448525565012, 19.259074177060807, 16.337040526526316, 20.228702238627843, 15.85742895943778, 30.116876465933665, 41.467457158224924, 46.72246313095093, 49.18285151890346, 47.24257401057652, 50.87189258847918, 50.98113216672625, 51.12580060958862, 40.64028453826904, 37.09831176485334, 39.50827360153198, 34.57878725869315, 34.94711821419852, 33.210905824388774, 34.543250696999685, 37.687925474984304, 37.57616370064871, 37.512778759002686, 39.14457709448678, 41.61306708199637, 44.212228366306846, 44.936025687626426, 48.75783021109444, 51.770100116729736, 49.54735401698521, 45.81545223508562, 37.12123039790562, 35.293381690979004, 44.075737953186035, 50.55786180496216, 50.50086225782122, 47.14647694996425, 48.77852194649832, 48.25652115685599, 50.244779450552805, 47.80392592293875, 44.83573538916451, 37.77883570534842, 36.58860581261771, 34.96368966783796, 37.44327940259661, 38.168223176683696, 47.564355509621755, 48.92905466897147, 52.6085079738072, 42.32962785448347, 34.621473516736714, 50.91808073861258, 46.89730065209525, 51.184036936078755, 50.100784982953755, 48.954582350594656, 46.69335017885481, 47.67074632644653, 41.57153769901821, 38.13397203172956, 36.43626308441162, 37.44154582704817, 36.08657414572579, 37.75152581078665, 34.56177112034389, 37.846181120191304, 44.83401918411255, 50.580412183489116, 50.71362999507359, 47.684194564819336, 47.75543791907174, 46.2763158253261, 45.22751304081508, 44.329656396593364, 40.953075068337576, 43.963111128125874, 47.23785618373326, 50.2249492917742, 47.164306027548655, 49.30081108638218, 50.26743057795933, 48.952789715358186, 53.43001086371285, 47.84997163500105, 45.35875408990042, 41.35795702253069, 47.97246490206037, 51.40502439226423, 50.562284333365305, 47.144093717847554, 47.18539381027222, 49.684914452689036, 53.20199530465262, 50.91148689814976, 51.89145735331944, 30.236930915287562, 23.37404751777649, 9.486885360309056, 17.50140401295253, 13.493692619459969, 13.377470101628985, 17.469020196369716, 9.663437349455696, 9.682877540588379, 3.2930631126676286, 0.4916063834513937, 0.07683353964239359, 2.278258732386998, 18.056113447461808, 46.08820029667446, 44.46225929260254, 28.13181608063834, 42.688314710344585, 52.766457898276194, 57.89412423542568, 45.11322907039097, 15.119375671659197, 1.2589266236339296, 0.16806437101747307, 0.1455125675669738, 0.12692093875791344, 0.15144807978400163, 0.19265271590224334, 0.10192223624991519, 0.11704332807234355, 0.2672450883047921, 0.08327730851513998, 0.19791972184819834, 0.12183150542633873, 0.052827584756804366, 0.11761673087520258, 0.15651295014790126, 0.10774421598762274, 0.14181795796113356, 0.22322620105530533, 0.13165306911936828, 0.08149045439703123, 0.05473866167345217], [0.04368172659139548, 0.02627944583738489, 0.0064655489986762404, 0.005756825108879379, 0.0450288662686944, 0.02521421880062137, 0.0848316422530583, 0.046430746758622785, 0.03599465086257883, 0.055323718315256495, 0.00546847062651068, 0.022018624203545705, 0.05213477675403867, 0.03030910076839583, 0.0281822123963918, 0.0660407752064722, 0.03167513086061392, 0.05607270562489118, 0.04366714148116963, 0.08469964683588062, 0.046776328036295514, 2.0371751316956113, 17.33600214549473, 43.96097803115845, 38.463455608912874, 29.170465809958323, 23.587556975228445, 15.675229821886335, 25.9446291242327, 26.26499319076538, 5.237235086304801, 0.18908974209002086, 0.49515159321682795, 8.152936322348458, 6.0610538976533075, 4.535749299185617, 11.244457381112234, 12.498083506311689, 4.398351277623858, 4.0605246509824475, 7.97964824948992, 14.317760263170515, 32.94669015066964, 34.340404987335205, 47.75034488950457, 46.4375696182251, 48.002178873334614, 47.4124435697283, 46.287620544433594, 44.08282164164952, 36.987814562661306, 32.33259098870413, 33.361785956791465, 33.82549136025565, 38.12565156391689, 34.31720495223999, 33.97614220210484, 30.8676084790911, 32.29285771506173, 30.381165095738, 32.98276172365461, 31.676677567618235, 34.275859696524485, 37.594600745609824, 41.21979556764875, 40.99122762680054, 40.54894699369158, 34.70456007548741, 29.909302507128032, 34.26265117100307, 44.566503116062705, 47.68270765032087, 46.064229011535645, 41.940500940595356, 47.687390736171174, 44.728712286267964, 44.86577245167324, 38.214578083583284, 35.60889938899449, 33.998279162815635, 34.00505713054112, 33.53308684485299, 35.13280534744263, 37.33204221725464, 44.29855973379952, 43.85195732116699, 47.64980098179409, 38.29667452403477, 28.642102207456315, 48.07719162532261, 44.63413340704781, 43.29798092160906, 40.16382571629116, 40.39810855048043, 39.73638296127319, 36.19752645492554, 33.020889963422505, 32.73785509381975, 32.08684015274048, 34.5636818749564, 37.163055079323904, 38.25936964579991, 35.719295842306956, 31.458281789507183, 30.6220417703901, 33.75975445338658, 35.698833397456575, 35.86046239307949, 36.22092798777989, 34.78629520961216, 35.41292544773647, 33.25313350132534, 34.913228375571116, 39.376542704445974, 45.66723326274327, 46.32631506238665, 47.4546434538705, 46.32108654294695, 43.360695362091064, 42.779402119772776, 44.80324213845389, 44.86470937728882, 47.64556605475289, 43.28161096572876, 46.114523547036306, 47.67691632679531, 46.37407350540161, 39.757745197841096, 44.15501342500959, 44.882604462759836, 51.08385780879429, 48.09207814080374, 45.983004570007324, 31.42817177091326, 20.155423062188284, 7.111735301358359, 9.922954303877694, 11.524387274469648, 16.1538964339665, 12.024943317685809, 9.834656596183777, 4.26368476663317, 0.6545827867729324, 0.04081368459654706, 0.02589556634692209, 0.9152099873338426, 10.19333563532148, 32.528227942330496, 44.27804865155901, 28.97040980202811, 26.758235386439733, 41.282763617379324, 44.48281553813389, 35.55812195369175, 7.675060936382838, 0.4166335021810872, 0.0395574787897723, 0.010150409752636083, 0.05154918067689453, 0.04269548611981528, 0.07119203664894615, 0.03721491127674069, 0.06444641468780381, 0.014793238968455365, 0.028883284955684627, 0.046117558742740324, 0.014111228154173918, 0.008165096015935498, 0.07857033823217664, 0.050462343996124606, 0.021886879844324927, 0.012875893236404019, 0.02526506482224379, 0.00961888358662171, 0.05644406444792237, 0.021615228349609033, 0.07063253702861921, 0.04830260435119271, 0.030803430492856672, 0.005554833715515477, 0.15127419840012277, 0.030600979392017637, 0.03034886292048863, 0.04957719845697284, 0.03464695478656462, 0.09366253803351096, 0.016332765375929217, 0.008178515742266817, 0.05041017143854073, 0.023877640520887713, 0.026008586532303264, 0.045765222648956945, 0.024722453938531022, 0.06914695924414055, 0.06840082178158419, 0.02514004474505782, 0.08436367700674705, 2.7458840055125098, 20.219297851834977, 50.01671872820173, 44.11773633956909, 33.610236167907715, 29.697146211351665, 23.390052693230764, 33.002581460135325, 26.092380830219813, 6.687472215720585, 0.2593025916389057, 0.5887290090322495, 7.072055441992624, 3.2612729328019276, 3.772104493209294, 5.2360091635159085, 7.415306006159101, 8.903366088867188, 6.354074197156089, 15.091136455535889, 15.29209920338222, 28.207094601222447, 36.66443150384085, 49.20786155973162, 47.48179006576538, 48.943024022238596, 50.2487781388419, 49.694398743765696, 46.298108850206646, 39.43226725714547, 33.69435453414917, 34.81115239007132, 35.40361833572388, 38.468020575387136, 35.50246688297817, 35.579664843423025, 32.38397986548287, 34.54393856866019, 32.14649043764387, 34.889722619737896, 33.85402066367013, 36.827637740543906, 40.485711438315256, 43.422186919621055, 43.54882478713989, 43.30875410352434, 36.58043473107474, 32.23744583129883, 36.05215971810477, 47.84294353212629, 48.98360845020839, 46.4786821092878, 43.028064250946045, 48.16499948501587, 47.05370112827846, 47.24555826187134, 40.77598633084978, 37.72699866976057, 34.93582044328962, 36.13599668230329, 34.516298634665354, 36.66734627314976, 39.02495690754482, 45.5799743107387, 46.58995056152344, 49.075852734701975, 39.61076995304653, 30.629479816981725, 49.11474527631487, 46.2549501146589, 44.88185058321272, 42.50375318527222, 44.54195860454014, 41.51282889502389, 38.734115736825125, 35.460256576538086, 34.101508549281526, 33.762068203517366, 35.121785504477366, 37.78794479370117, 39.38928917476109, 37.31211825779506, 33.32736458097185, 32.94879198074341, 36.39871849332537, 38.352496351514546, 38.495073386601035, 38.08149576187134, 37.00785664149693, 37.30493034635271, 35.17950766427176, 37.41571242468697, 40.929492882319856, 46.09922708783831, 47.84395796912057, 48.00724063600813, 49.34235783985683, 45.722242150987896, 45.577285357883994, 46.822110721043174, 47.51427984237671, 46.914598192487446, 42.866841724940706, 45.199362414223806, 49.07427896772112, 48.49465329306466, 43.346281324114116, 45.07762997491019, 49.54962607792446, 52.641869749341694, 52.18476166043963, 47.88723829814366, 31.358543872833252, 21.102174179894583, 15.157450062888008, 12.863944377217974, 15.285385506493704, 11.045639889580862, 10.307134968893868, 6.1651070799146375, 2.4372997411659787, 1.6733578996998923, 0.22601211656417164, 0.0915029307029077, 0.8322345997606004, 12.318757448877607, 34.620479924338206, 47.056515148707796, 29.543785572052002, 32.51982409613473, 47.33746903283255, 48.57453325816563, 41.33279412133353, 9.437488879476275, 0.4054272792169026, 0.04157086182385683, 0.08102628894682441, 0.02639151268106486, 0.041201413076903136, 0.04870349980358567, 0.018874284445441196, 0.048596647501524, 0.028664097788610628, 0.04357758164405823, 0.006016771450439202, 0.0675010775615062, 0.07109314695532833, 0.015797460618029748, 0.06675954735172646, 0.04495673460353698, 0.027353980678266714, 0.046771619003266096, 0.015209745815289872, 0.0236096124031714, 0.0375733066882406, 0.1173854861408472, 0.2144974587219102, 0.09321157687476703, 0.09296973342342035, 0.2579755942736353, 0.08084780709551913, 0.2476617262831756, 0.10207263353679862, 0.17401660233736038, 0.15863783684160027, 0.07962850680840866, 0.1409912851772138, 0.16181912113513264, 0.09813950530120305, 0.1642838588782719, 0.13324170958782944, 0.07029620757592575, 0.15335806086659431, 0.20610674896410533, 0.10112195847822086, 0.11456131482762949, 3.925077770437513, 26.56700359072004, 57.399384702954976, 51.631705897195, 40.92446238654, 33.1620773587908, 24.206519876207622, 36.25875398090908, 32.56344141278948, 7.473386866705758, 0.5562469405787331, 0.6799107076866286, 11.939818331173488, 10.106124452182225, 9.826814685549055, 19.754135063716344, 23.212990011487687, 12.429914729935781, 9.304164239338466, 13.945333344595772, 18.071710416248866, 34.80888727733067, 35.19575950077602, 49.97636359078543, 48.29911361421858, 49.91418068749564, 51.783218315669465, 52.12450688225882, 49.39161361966814, 41.441509110586985, 35.14674343381609, 36.063391481127056, 37.49280268805367, 41.37799562726702, 39.22942502158028, 38.78377798625401, 34.442286423274446, 36.42934615271432, 34.11109011513846, 37.15949065344674, 35.71037435531616, 37.74642930712019, 41.502340589250835, 46.42775876181466, 44.75675868988037, 45.614562443324495, 38.742933000837056, 34.779590197971885, 38.227484362465994, 49.87337391717093, 50.79101208278111, 47.48457281930106, 43.97921357836042, 50.03839363370623, 50.04877076830183, 50.002461024693076, 42.12565653664725, 39.153898102896555, 36.203758989061626, 37.75057738167899, 36.62599059513637, 38.553136008126394, 41.31266519001552, 49.172331946236746, 48.55011034011841, 48.94027253559658, 40.3925221988133, 34.747440883091514, 50.073044300079346, 49.99978596823556, 46.97997031893049, 43.34701088496617, 45.25990901674543, 44.06712566103254, 39.34242010116577, 37.184021268572124, 36.23153093882969, 35.34251935141427, 37.33664539882115, 41.8127235685076, 42.13294867106846, 40.36297151020595, 35.54008790424892, 33.01602969850813, 36.86574860981533, 39.503858021327424, 39.21054676600865, 39.402560234069824, 38.509556906563894, 38.1803686278207, 36.04516635622297, 39.94527360371181, 43.43198387963431, 50.18825238091605, 49.57134962081909, 50.062357970646445, 50.651287283216206, 47.7916693006243, 47.245992524283274, 49.77979905264718, 49.858654158455984, 50.25774826322283, 43.22444118772234, 46.36872686658587, 51.454756123679026, 51.71191937582833, 44.7354416166033, 49.307404926845, 50.84063264301845, 56.53626905168806, 53.73804535184588, 50.701741627284456, 35.846979413713726, 22.94344333239964, 11.234544907297407, 16.696088688714163, 21.11777114868164, 23.136563301086426, 20.746725184576853, 19.05533388682774, 9.514866624559675, 1.9504776809896742, 0.4442499317228794, 0.13965032356125967, 1.1094412335327692, 13.660215752465383, 40.590153285435264, 52.96555158070156, 37.38600540161133, 38.02363463810512, 52.79744686399187, 56.41868816103254, 49.89397185189383, 13.183319193976265, 0.7833127134612629, 0.09862917688276086, 0.09669056162238121, 0.22753774827080114, 0.14265965351036616, 0.14776963288230555, 0.1582065871251481, 0.15513639258486883, 0.15663520858756133, 0.08898038177617959, 0.17014083745224134, 0.2046928448336465, 0.1527651705379997, 0.16844558556165012, 0.1439008569078786, 0.10954768742833819, 0.10770676763994352, 0.11435710292841707, 0.08707232773303986, 0.13085836890552724, 0.06472080746399504], [0.02258432054493044, 0.022910426171230416, 0.027189593695636307, 0.044659980705806186, 0.07730552181601524, 0.015108896851805704, 0.023037352931818793, 0.02084823272057942, 0.009582977209772383, 0.010782779793121984, 0.07202938957405941, 0.07732775062322617, 0.03373198763334325, 0.08144547431064503, 0.0731484702389155, 0.03386818996763655, 0.06334026690040316, 0.04067300393113068, 0.0644716222637466, 0.17538117697196348, 0.07040917687118053, 2.000617619071688, 19.608078718185425, 39.90019716535296, 40.56654678072248, 27.66916332926069, 16.397646188735962, 19.700795480183192, 38.52803911481585, 28.607055493763514, 5.369156190327235, 0.2887476459145546, 0.21493339032999106, 15.589739186423165, 28.45943580354963, 20.406520536967687, 6.6604337351662775, 4.717459891523633, 4.759174704551697, 5.41472464799881, 15.796109369822911, 19.452147245407104, 30.46561697551182, 39.724946226392476, 45.377983229500906, 43.38052552086966, 49.28475032533918, 45.07212700162615, 46.27591977800642, 40.13517829350063, 35.070789200919016, 31.320665768214635, 36.45542969022478, 44.67012160164969, 45.74290261949812, 43.72454125540597, 41.17241580145699, 35.65214497702462, 32.13960129874093, 31.828520025525773, 33.065486976078574, 32.43986770084926, 33.1819874218532, 33.43107686723982, 33.67766843523298, 33.78117574964251, 32.806312220437185, 31.46275990349906, 30.56215524673462, 39.41475084849766, 46.371794496263774, 47.627427782331196, 42.80705942426409, 47.66645581381661, 42.853053024836946, 40.20272173200335, 39.589018617357524, 34.33399180003575, 33.477244172777446, 32.10675368990217, 32.99035610471453, 36.70734010423933, 39.84726578848702, 40.17212881360735, 44.30442748750959, 44.05161728177752, 45.83818326677595, 39.45698199953352, 26.685602392469132, 47.81884370531355, 43.070948532649446, 42.021440505981445, 39.35124431337629, 36.859116554260254, 33.510609422411235, 33.30787835802351, 31.621835436139786, 33.509664467402864, 34.482856954847065, 37.20662028448922, 40.83728333881923, 42.480931827000205, 40.158274105616975, 37.35956055777413, 35.651696818215505, 32.83762080328805, 31.743734632219585, 31.122808865138463, 30.35794769014631, 31.213423797062465, 31.92654868534633, 32.88076911653791, 37.530277797154014, 41.86659642628261, 45.685711996895925, 45.504287583487375, 47.08137232916695, 45.03348806926182, 41.575932434626985, 41.337956632886616, 41.565940925053184, 45.185469491141184, 46.109993321555, 44.976929732731406, 45.61977359226772, 48.7618601662772, 43.710992268153596, 42.07537589754377, 45.49950722285679, 50.51838214056832, 48.795562403542654, 48.642580441066194, 43.152405738830566, 33.44258655820574, 22.89304804801941, 25.308856793812343, 17.270131485802786, 22.816867998668126, 11.779776998928615, 8.161782247679573, 4.032127797603607, 1.34490558717932, 1.3867708721331187, 0.3048176078924111, 0.029497711985771145, 0.5934066666024072, 9.50190041746412, 37.72745030266898, 39.533109937395366, 28.029628923961095, 32.2121821812221, 37.412123680114746, 48.24247189930507, 31.136357852390834, 9.098195314407349, 0.14409668211426052, 0.09660499157117945, 0.04389943115945373, 0.00450730838513534, 0.008192586862216038, 0.0322353090159595, 0.021956930103312646, 0.05755101969199521, 0.005754071104872439, 0.027212480681815317, 0.05185595653685076, 0.05445159047043749, 0.03464342301179256, 0.07115228128220354, 0.04852628342009016, 0.04390012665784784, 0.012539572265398289, 0.06559693188007389, 0.05220196868426033, 0.05775488553834813, 0.042049374897032976, 0.029870153072157075, 0.07569003850221634, 0.05950401310942002, 0.05966361811650651, 0.019435254790421044, 0.02691443926388664, 0.004788708731731666, 0.003924248332623392, 0.04248553042166999, 0.016102952350463186, 0.03052556361736996, 0.011857202675725733, 0.06856352090835571, 0.027773020157058324, 0.014407220396346279, 0.023870249578197087, 0.0485885661494519, 0.008999879837834408, 0.03755233656348927, 0.040742238251758475, 0.012285957927815616, 2.888264319726399, 23.96203534943717, 45.86588226045881, 46.4154326575143, 34.41507032939366, 21.817553758621216, 21.890171119144984, 37.97300658907209, 31.312463419778005, 6.283923012869699, 0.5237593895622662, 0.3732585853763989, 17.79097192628043, 23.090349095208303, 12.085102558135986, 7.14450170312609, 9.323005148342677, 9.433615258761815, 9.68931417805808, 11.230845860072545, 18.62186704363142, 32.41360003607613, 39.16246175765991, 46.03354229245867, 45.02560881205967, 50.75666018894741, 47.702124391283306, 46.34619385855538, 41.61640569141933, 37.66572250638689, 33.3603754724775, 37.808219637189595, 46.52604797908238, 46.694771085466655, 44.67400911876133, 41.40628521783011, 36.92313378197806, 33.197179658072336, 33.79703848702567, 34.02152436120169, 34.704146657671245, 34.003323554992676, 35.595923628125874, 36.103496483394075, 35.704888752528596, 35.05334922245571, 33.82300043106079, 31.664094379970006, 40.7320111819676, 48.67269045966012, 47.9315573828561, 44.331414290836875, 47.54949331283569, 44.74431446620396, 44.27827794211251, 41.7094281741551, 36.46165527616228, 34.96812956673758, 33.46767997741699, 35.589826583862305, 38.2431560243879, 40.66302599225725, 42.99008192334856, 46.38961315155029, 45.82712868281773, 48.4310633795602, 40.51458120346069, 29.524028369358607, 49.67334222793579, 43.99673693520682, 44.472740650177, 41.46225643157959, 39.23582431248256, 35.88720253535679, 34.16671391895839, 33.199364866529194, 35.56701217378889, 35.402381556374685, 38.8146835735866, 41.63938685825893, 44.926739420209614, 43.40859276907784, 39.17813341958182, 36.10070678165981, 34.822655132838655, 32.71504415784563, 32.621858392442974, 32.359852245875764, 33.31024769374302, 33.078094482421875, 35.01297671454293, 38.15753337315151, 44.44956145967756, 47.76663146700178, 46.9917961529323, 48.31618186405727, 47.25869730540684, 42.90341704232352, 42.2707314491272, 43.75099304744175, 48.705763884953086, 47.19789014543806, 44.87933186122349, 46.42189448220389, 49.57300329208374, 46.99129935673305, 43.53919458389282, 47.21533359800066, 50.670116901397705, 50.77565656389509, 49.595164571489605, 46.531269550323486, 35.346900190625874, 23.798104763031006, 17.475285734449113, 15.16462060383388, 14.849641391209193, 15.35689810344151, 11.382823807852608, 11.82018598488399, 4.19632762670517, 2.5823968010289327, 0.33174497155206545, 0.0037633104283096535, 0.9468205996922084, 10.114739349910192, 39.16304193224226, 42.11982004983084, 29.567683901105607, 34.91647318431309, 41.109117712293354, 52.695224966321675, 38.949482100350515, 12.152401941163198, 0.17499403203172342, 0.0935051789773362, 0.017888144057776247, 0.04853445298171469, 0.013069751539400645, 0.03841577237471938, 0.005971404175007982, 0.04139793717435428, 0.007679299717502934, 0.03340621279286487, 0.037254673428833485, 0.09385022760501929, 0.015367074337388788, 0.06214147872690644, 0.045120784014995606, 0.01648522710560688, 0.010062296891451945, 0.032297011597880294, 0.0058706552954390645, 0.004329384204798511, 0.030210601232413734, 0.07500249253852026, 0.1521463194595916, 0.11352168382810694, 0.11020073667168617, 0.1398368664085865, 0.09114074228065354, 0.14613694192043372, 0.1145975621683257, 0.07809941457318408, 0.07027106106813465, 0.15837825648486614, 0.1207164688301938, 0.1086288628035358, 0.14232240803539753, 0.17559881029384478, 0.08158506253468138, 0.18461967552346842, 0.19592174834438733, 0.1695578130228179, 0.24349071724074228, 0.0888272092810699, 3.8723161901746477, 29.255928652627126, 52.848418848855154, 51.669924463544575, 39.062529291425435, 26.234725100653513, 31.258892808641704, 48.61751134055001, 36.39692933218819, 7.113471048218863, 0.6159313150814602, 0.5940531747681754, 17.939786706651958, 33.807877676827566, 28.868510995592388, 16.29583076068333, 13.40197205543518, 11.01264202594757, 14.022235138075692, 19.837548187800817, 22.18222301346915, 33.581018992832725, 41.46874604906355, 47.112760816301616, 46.209859779902864, 52.37057386125837, 50.73505476542881, 50.19068772452218, 43.875713212149485, 39.630488940647666, 34.55683095114571, 40.52431215558733, 49.327790941510884, 49.506377015795024, 47.86707809993199, 44.345932551792686, 39.48503882544381, 34.388014044080464, 35.905253955296104, 36.13797344480242, 36.07057244437081, 36.191248757498606, 37.138197898864746, 36.9265627179827, 35.85078007834298, 35.021943364824565, 34.83766324179513, 32.52256516047886, 43.78931931086949, 51.214435304914204, 48.80327490397862, 44.247712816510884, 50.370121479034424, 47.13702392578125, 45.829484122140066, 43.716335432870046, 38.62404237474714, 36.52755199159895, 35.92728321892874, 37.040551389966694, 40.63977037157331, 43.68742397853306, 45.38964925493513, 48.129570620400564, 48.46135752541678, 49.08934613636562, 41.73125941412789, 33.6536728313991, 52.836850098201204, 48.16437414714268, 46.787407943180625, 43.98551212038313, 40.27183198928833, 37.51941081455776, 36.95787477493286, 36.128065313611714, 36.68850701195853, 38.663396971566335, 41.39818361827305, 45.9095447404044, 47.77873870304653, 45.441635676792686, 41.07852131979806, 38.34225123269217, 37.203952176230295, 35.41511760439192, 34.25904853003365, 33.82647453035627, 34.39609479904175, 35.696606499808176, 37.01296009336199, 40.604056630815776, 46.253748076302664, 49.48513289860317, 48.999068192073274, 50.95218249729702, 49.27975457055228, 44.993942396981375, 45.34667812074934, 46.13744912828718, 51.85087292534964, 49.12846449443272, 46.31768192563738, 46.696984086717876, 50.431623458862305, 48.803976672036306, 45.83084944316319, 49.49248061861311, 55.20325020381382, 52.09390006746565, 51.2560133252825, 47.45559188297817, 38.84409877232143, 25.877233334950038, 31.02841063908168, 24.628320693969727, 30.130463668278285, 25.924458503723145, 16.839787857873098, 14.85903709275382, 10.770133393151418, 4.569427217755999, 0.7052789064390319, 0.2585042273359639, 1.0567561920200075, 12.539302825927734, 46.20496824809483, 50.49177401406424, 38.15034198760986, 43.04387835093907, 48.073300634111675, 59.79437664576939, 44.87011507579258, 16.3273286819458, 0.4194176670696054, 0.1822983529418707, 0.21241781674325466, 0.15641047778938497, 0.12795453758112021, 0.12034552730619907, 0.1687988716044596, 0.18419690749474935, 0.11756043961005551, 0.10111910184579236, 0.11598280497959682, 0.12851906514593534, 0.08620091913534061, 0.11311003020299332, 0.17212053122264998, 0.1816086085247142, 0.1203630335096802, 0.11180353138063635, 0.16593507384615286, 0.11911104140537125, 0.14496037576879772], [0.039293986678655655, 0.019971076931272234, 0.08670131835554327, 0.02592141683479505, 0.04061781528538891, 0.015739842816921215, 0.01861323506039168, 0.02720432638722871, 0.0709977245756558, 0.05097315533618842, 0.01851905439980328, 0.0981496697557824, 0.07578098255076579, 0.010429643028016602, 0.05128719491351928, 0.029810550556119, 0.005790717508976481, 0.05864740336047752, 0.02843933136734579, 0.045107630613659105, 0.05548748274200729, 0.7649354338645935, 12.992700576782227, 40.34728247778756, 40.746456486838206, 28.589768375669205, 20.950020790100098, 25.650169679096766, 42.21672657557896, 24.725564207349503, 4.926727473735809, 0.1008737842951502, 0.11463333453450884, 2.482170339141573, 23.6246395111084, 22.566508769989014, 1.9782561446939195, 5.003413438796997, 9.39115047454834, 4.887440621852875, 17.60630965232849, 19.411156347819738, 28.9759509904044, 42.042663778577534, 45.65348277773176, 48.063243116651265, 47.17127507073538, 45.17640209197998, 42.74448047365461, 37.2066376549857, 32.47444541113717, 32.56601572036743, 41.46813808168684, 47.18372971670968, 45.448934759412495, 45.056635992867605, 44.082700048174175, 41.61997011729649, 38.652821813310894, 36.475249426705496, 37.297464506966726, 34.33737904684884, 34.89151872907366, 34.779816014426096, 33.67103637967791, 31.347419806889125, 32.35043396268572, 31.47605528150286, 33.72701454162598, 41.87925951821463, 47.70314925057547, 44.95015484946114, 46.06863416944231, 44.66349649429321, 40.98623187201363, 40.06309420721871, 34.73998894010271, 32.00302055903843, 32.02917357853481, 32.3907265663147, 36.39225319453648, 40.693400042397634, 43.46982029506138, 45.01246976852417, 44.7671914100647, 46.58752564021519, 45.79301997593471, 41.726409571511404, 28.48490616253444, 48.27404798780169, 42.703965527670725, 41.64117949349539, 37.10178586414882, 35.390607833862305, 34.206784180232454, 33.16801806858608, 31.905971595219203, 32.33035019465855, 34.087504455021445, 37.48584406716483, 42.911185128348215, 47.14538608278547, 46.68164941242763, 45.99973930631365, 44.144973278045654, 40.21710102898734, 36.71131099973406, 35.43709823063442, 35.877825941358296, 33.51116875239781, 31.6421936580113, 34.92279257093157, 39.215681484767366, 44.023049763270784, 46.687868050166536, 46.502361570085796, 45.99145705359322, 41.223690032958984, 38.46991743360247, 35.58132893698556, 39.02342482975551, 43.224246638161794, 46.09081629344395, 45.2892929485866, 44.135704381125315, 48.489393506731304, 46.51935338973999, 42.306177684238975, 41.828902448926655, 46.50154168265206, 48.60195084980556, 49.471351146698, 47.0211557660784, 35.94191265106201, 27.45160480907985, 21.529609986713954, 12.867500986371722, 10.404559135437012, 7.489715133394514, 8.033216255051748, 6.656959201608386, 0.9794463004384721, 2.5451514167445044, 0.40938104848776546, 0.07902324678642408, 0.7308891522032874, 7.593282376016889, 32.32952683312552, 37.86647680827549, 26.899035419736588, 29.356215476989746, 37.485093661717, 42.62908826555525, 36.4241350037711, 7.93123493875776, 0.25655129498669077, 0.019174302096611688, 0.042533431601311476, 0.09496436174958944, 0.01559382038457053, 0.032251760097486634, 0.09024745771395308, 0.06761300869818244, 0.05189438197495682, 0.018122890032827854, 0.026914946468813077, 0.026064642006531358, 0.023964716919830868, 0.014239442434960177, 0.03516841573374612, 0.05086555325293115, 0.028908092195966413, 0.05206748304356422, 0.020906802167051604, 0.060142697766423225, 0.053070965089968274, 0.018463955659951483, 0.04922123220083969, 0.030546764444027628, 0.030235822379056896, 0.060937845813376565, 0.060451186927301545, 0.033721931744366884, 0.029929789514946084, 0.016303970046075325, 0.026113245469917144, 0.017435293179005384, 0.023893270575042282, 0.11746505115713392, 0.03213428532970803, 0.0416689237047519, 0.042707167100161314, 0.006111455923278949, 0.010147738021000155, 0.012113646504336169, 0.026113160653039813, 0.018084330584055612, 1.6174330434628894, 16.107723917279923, 45.915311745234895, 46.46822507040841, 34.81390387671334, 26.07838715825762, 31.580257415771484, 44.11052410943167, 28.001596416745866, 5.760592511722019, 0.19775173014828137, 0.06560672992574317, 2.792749170746122, 32.70560850415911, 31.191220828465053, 5.202990021024432, 4.75551734651838, 10.725633655275617, 10.947075349943978, 13.070357118334089, 22.372921534946986, 32.226012570517405, 42.749396324157715, 44.791586535317556, 49.333314759390696, 48.8221218926566, 46.99978310721261, 44.57781130926949, 38.21389716012137, 35.17697157178606, 34.9771865436009, 44.071364062173025, 49.528552191598074, 46.50588083267212, 46.78338493619646, 45.94204841341291, 43.06708533423287, 39.821689469473704, 37.72731133869716, 37.777682304382324, 36.04794910975865, 35.863022804260254, 35.266394887651714, 34.81966045924595, 33.02416951315743, 33.404475688934326, 33.02677856172834, 34.60310247966221, 43.61550317491804, 49.58407524653843, 45.27407986777169, 46.85523278372628, 47.330090045928955, 43.27030277252197, 42.12494087219238, 36.41995913641793, 33.62211758749825, 34.31486340931484, 34.78984226499285, 37.006508690970286, 42.262306758335654, 44.14038051877703, 45.77140065601894, 46.16561712537493, 49.00607892445156, 47.26979010445731, 41.99085453578404, 31.13121271133423, 49.16640860693795, 45.39951917103359, 44.48067201886858, 39.369994027274, 37.77276297977993, 35.85820770263672, 34.31572151184082, 33.34056963239397, 34.06208447047642, 36.813953263419016, 39.82311732428414, 44.684799671173096, 48.43659067153931, 48.247773374829976, 48.17947605678013, 45.17811829703194, 41.444569792066304, 37.75892564228603, 36.18265730994088, 36.344289779663086, 33.57614483152117, 32.8258227620806, 37.425530229296, 40.00723763874599, 45.16392312731062, 48.686503478458945, 47.69269568579537, 48.64897278376988, 43.8696300642831, 40.27512543542044, 37.599860531943186, 40.65467078345162, 45.12233468464443, 48.071372509002686, 45.471408707754954, 43.40475041525704, 48.96870109013149, 47.848665373665945, 43.59423473903111, 43.44330596923828, 49.32628665651594, 50.99242993763515, 51.29918595722744, 47.02478272574288, 36.24931137902396, 24.02143723624093, 18.487643480300903, 14.989956787654332, 14.874773025512695, 10.683479802949087, 14.133784123829432, 8.964881096567426, 3.728572291987283, 2.3127217973981584, 0.7202084681817463, 0.023606864336345876, 0.7043050186974662, 8.941102623939514, 36.86597095217024, 42.33143091201782, 33.10538700648716, 33.875862325940815, 42.16216584614345, 48.246150970458984, 42.24642317635672, 10.72457492351532, 0.25489561525838716, 0.02025661973415741, 0.057593977744025845, 0.040186473966709206, 0.017582849100498215, 0.05460864079317876, 0.05564612422936729, 0.047957284309502156, 0.07685320358723402, 0.03993918866451297, 0.09229631455881254, 0.06393611564167909, 0.0693858510681561, 0.0283434153534472, 0.057161642371543815, 0.06175013365490096, 0.03917409632621067, 0.03410865260022027, 0.032429332711866925, 0.06663709892226116, 0.04303039404164467, 0.1122115548434002, 0.1816312987357378, 0.21965450128274305, 0.14534431802374975, 0.12499218939670495, 0.24561580749494688, 0.19059865469379084, 0.12415528430470399, 0.13457353812243256, 0.1027572617999145, 0.0929243801427739, 0.13252508161323412, 0.2107657061091491, 0.09530616019453321, 0.11180504451372794, 0.20653202757239342, 0.08159240428358316, 0.21391507211540425, 0.11677603955779757, 0.12921327432351454, 0.17726864426263741, 2.851139008998871, 22.556972367422922, 53.71064165660313, 52.85464096069336, 40.65123837334769, 30.148254530770437, 34.86978128978184, 51.0636385508946, 32.62252541950771, 6.497395123754229, 0.6413067877292633, 0.33094036472695215, 3.392655985695975, 29.35162271772112, 26.712233100618633, 4.472506361348288, 10.028793607439313, 15.253475904464722, 13.012676647731237, 23.592007296425955, 22.012299605778285, 30.003982135227748, 42.98398835318429, 47.43147815976824, 49.45625965935843, 51.516796588897705, 49.3610554422651, 47.00295148577009, 40.36373233795166, 36.55066864831107, 36.11621516091483, 45.43628903797695, 50.7342209815979, 48.55393532344273, 47.76414748600551, 49.11021852493286, 45.334490980420796, 42.927725315093994, 39.51329714911324, 40.47610207966396, 38.73255934034075, 38.87627935409546, 38.466339111328125, 37.245575359889436, 34.43295151846749, 35.99807146617344, 34.87754242760794, 36.98725175857544, 45.89898347854614, 50.90383693150112, 44.59844398498535, 49.027309145246235, 49.15911994661604, 44.554395880017964, 44.94764654976981, 37.60900436128889, 35.3438012940543, 35.76858983721052, 36.716647216251914, 40.37904964174543, 44.42782054628645, 46.686992577144075, 48.05419308798653, 49.227323463984895, 50.85113137108939, 47.450735092163086, 41.94132430212838, 35.01874024527413, 51.44492442267281, 46.718464442661826, 46.61744805744716, 40.28040954044887, 40.37636416299002, 38.3608307157244, 36.5923022542681, 36.001246792929514, 36.839015415736604, 38.91019698551723, 42.25319072178432, 47.21619517462594, 50.684986046382356, 49.90633964538574, 50.23553139822823, 47.93341950007847, 44.359509331839426, 41.068772997174946, 39.31948062351772, 40.30833435058594, 36.35533046722412, 33.994739055633545, 38.931510584695, 41.61638137272426, 47.15615579060146, 49.81923007965088, 49.42794227600098, 50.403000354766846, 46.64050218037197, 42.659861837114605, 40.0960008757455, 43.5415917124067, 48.12642308643886, 49.91961070469448, 46.96744271687099, 43.72854341779436, 50.674000944410054, 49.69164725712368, 45.815334115709575, 45.35780913489205, 50.69378593989781, 53.4942295891898, 53.82028423036848, 49.50757210595267, 38.136605398995535, 30.15364980697632, 25.81728948865618, 16.927157981055124, 16.327339104243688, 15.298330000468663, 17.131271736962454, 14.167413405009679, 6.776872949940818, 6.587645275252206, 0.9439194010836738, 0.24834321971450532, 0.9211712160280773, 10.521735293524605, 41.71922166006905, 48.248061725071494, 38.37376478740147, 40.42150313513619, 48.560140064784456, 55.43554932730538, 48.98070410319737, 14.156810453959874, 0.5640560101185526, 0.2044433882193906, 0.1614762573902096, 0.15685193267251762, 0.12539811618626118, 0.11983837666256086, 0.19945317027824266, 0.17232111974486283, 0.20190836781901972, 0.11796313657292298, 0.13715554028749466, 0.26818513071962763, 0.1706752109208277, 0.0763592097376074, 0.11162647445287023, 0.11658748824681554, 0.07674820707844836, 0.13717145871903214, 0.09083339984395675, 0.23852297237941197, 0.10977104758577687], [0.0271239318618817, 0.03915196929925254, 0.029501823907984153, 0.019133659545332193, 0.031568373553454876, 0.02329838365715529, 0.0346768883589123, 0.06252008769661188, 0.05847913346120289, 0.04418954898470214, 0.07323704620024987, 0.007787329277821949, 0.01977952988818288, 0.036486449651420116, 0.04044604075274297, 0.006078535948680448, 0.05221113569236227, 0.026129996803190027, 0.0533668504628752, 0.024155816129807915, 0.02294561330095998, 1.3852935114077158, 17.44627353123256, 36.700544766017366, 42.869593211582725, 30.993728705814906, 21.122916289738246, 21.87961333138602, 32.023879051208496, 22.08096170425415, 5.285074302128383, 0.2176278800304447, 0.08504067175090313, 0.11415584944188595, 0.7714601180383137, 1.6753894878285271, 4.298552564212254, 7.995114939553397, 13.556106550352913, 13.686541608401708, 9.528829898153033, 24.119217497961863, 37.626305375780376, 41.87496900558472, 45.19750377110073, 46.015171255384175, 45.38396562848772, 42.50596271242414, 39.895618302481516, 34.25985104697091, 33.515358516148154, 33.995715277535574, 41.28441034044538, 47.51704869951521, 46.79540531975882, 46.42120313644409, 45.48253624779837, 45.11424003328596, 43.977285453251426, 42.90826688494001, 42.51883772441319, 44.99662440163748, 42.730212347848074, 41.254835333142964, 40.145315715244834, 38.152822494506836, 36.285615716661724, 35.51983043125698, 38.19798231124878, 43.34395020348685, 45.23643452780587, 44.341774054935996, 45.07751185553414, 44.350546155657085, 41.12833990369524, 35.59138992854527, 31.874419825417654, 32.63595976148333, 32.041440623147146, 34.434250831604004, 39.45571395329067, 45.54166194370815, 45.96114901133946, 46.68150350025722, 45.301997729710166, 44.331372601645334, 42.31266382762364, 40.68416588647025, 28.215270893914358, 45.78159366335188, 43.33781147003174, 42.673626218523296, 39.782373087746755, 38.22691808428083, 34.62633030755179, 33.771594183785574, 32.328151089804514, 32.79516383579799, 33.259091581617085, 39.52520636149815, 43.56528506960188, 44.06381137030465, 44.174360683986116, 44.79013436181204, 44.48962824685233, 47.79608140672956, 45.33692979812622, 45.827066149030415, 46.43460273742676, 43.11641754422869, 34.18322283881051, 34.934340476989746, 41.412594182150706, 43.22056061880929, 45.13001939228603, 43.30423430034092, 42.285274028778076, 37.861640862056184, 35.54958956582205, 33.541660921914236, 36.68486615589687, 43.25976930345808, 46.020934786115376, 47.85044411250523, 44.80754654748099, 45.59941189629691, 48.19561324800764, 44.919673102242605, 44.246340547289165, 42.145351205553325, 45.250581060137065, 45.08171898978097, 49.61589452198574, 47.76880625316075, 28.59727590424674, 15.708666290555682, 22.990430525371007, 15.857380322047643, 15.996170588902064, 14.372301016535078, 12.556343282972064, 3.034446818487985, 1.2206542087452752, 0.9541392241205487, 0.05080780313749399, 0.5242662280797958, 7.5771868739809305, 29.648272582462855, 28.083828347069876, 21.71488196509225, 24.79569411277771, 38.490039416721885, 43.961808340890066, 36.47994640895298, 7.0558609281267435, 0.17435045513723577, 0.00910350400954485, 0.03738428718809571, 0.004009945609141141, 0.09520431887358427, 0.008707781538500317, 0.038358442950993776, 0.05442233543310847, 0.04256554666374411, 0.003811561901654516, 0.06354685367218085, 0.025225531675719788, 0.041446089411952665, 0.020730388151215653, 0.05473453618053879, 0.033680680207908154, 0.08341890520283154, 0.018859237931402664, 0.027386034672547663, 0.04113467237246888, 0.04113389205719743, 0.08580300584435463, 0.020806933686669384, 0.025261868922305957, 0.02776810247451067, 0.03967570333874651, 0.03565739860226001, 0.038090879629765234, 0.05087994498067668, 0.04508727117042456, 0.046666761594159265, 0.056131992622145584, 0.06094915699213743, 0.03578387413706098, 0.033725826535373926, 0.02493987012920635, 0.08987848394151245, 0.025257874047383666, 0.04972011150260057, 0.0784247178318245, 0.0666479826239603, 0.05092982069722243, 1.8531232135636466, 20.483108792986187, 43.3409173148019, 48.81937388011387, 36.38240759713309, 23.95974244390215, 23.10844394138881, 39.63032913208008, 25.570468630109513, 5.889496794768742, 0.26712794601917267, 0.09611582210553543, 0.11426362794424806, 0.6840852179697582, 2.7214193982737402, 6.029461307185037, 8.861279981476919, 10.316147650991168, 12.586372528757368, 11.51421250615801, 23.553578547069005, 32.64952611923218, 39.96127183096749, 45.55210856028965, 47.48771340506417, 48.99623332704817, 45.84912320545742, 41.002671309879844, 36.03593567439488, 36.28779397691999, 34.938054289136616, 44.07496670314244, 48.459373814719065, 47.71291841779436, 45.842369556427, 45.98093400682722, 46.877335003444124, 46.17007092067173, 43.80902787617275, 44.90717329297747, 46.71304832186018, 44.1842861856733, 41.91542141778128, 39.88696779523577, 39.40460647855486, 37.11534874779837, 36.17072377886091, 39.22142417090279, 45.395117487226216, 48.096007347106934, 43.936475208827424, 48.15611273901803, 45.91385957172939, 42.62831006731306, 36.89696339198521, 33.64837482997349, 33.293589387621196, 33.237308979034424, 35.3149037361145, 41.80778687340872, 47.88507393428257, 47.716729504721506, 48.43663930892944, 47.04729836327689, 44.58815022877285, 43.19928870882307, 42.27124561582293, 30.734352452414377, 46.7407751083374, 44.375577041081016, 46.10571323122297, 40.7847341128758, 39.65793432508196, 36.908097880227224, 35.27399621691023, 34.63495649610247, 34.21175561632429, 35.28286559241158, 41.55229466302054, 45.82717037200928, 47.38415050506592, 46.109076159340994, 46.28514698573521, 47.12128278187343, 49.27598517281668, 47.806878907339915, 46.75109665734427, 47.55513177599226, 44.24435683659145, 34.77611262457711, 36.57343094689505, 43.86503035681588, 44.191074575696675, 46.000190939222065, 45.12234163284302, 44.83748286111014, 40.224320207323345, 36.80657080241612, 34.33639587674822, 38.34850113732474, 46.46489340918404, 48.33140884126936, 48.35823931012835, 44.79794761112758, 48.082510471343994, 50.15363645553589, 46.097295488630024, 44.59895467758179, 44.04289729254586, 47.3966885294233, 46.08320801598685, 52.26402670996529, 47.06603070667812, 28.342680011476787, 17.483038187026978, 11.383109552519661, 11.041907838412694, 13.705018605504717, 15.172386952808925, 10.777571439743042, 4.008265946592603, 2.8497317816529955, 0.46949900686740875, 0.05010482050212366, 0.48561529921633856, 8.520781772477285, 34.920096669878276, 38.43142441340855, 27.44440473828997, 29.06862780026027, 43.31420496531895, 49.44969708578927, 43.09511089324951, 9.719971367291041, 0.16937231511941978, 0.0539298241824976, 0.05316067420478378, 0.022674979608772055, 0.10490506940654346, 0.041927530363734276, 0.04514356243557163, 0.0017768232501111925, 0.06662607951355831, 0.038289653070803197, 0.04951936013198324, 0.006765659100243023, 0.007663589087314904, 0.05511707386800221, 0.02607844171247312, 0.030628337923969542, 0.036229200062475035, 0.0024714450617986067, 0.042490985843219926, 0.035932198499462435, 0.044236903943653615, 0.2212367770927293, 0.15442033457968915, 0.15971209348312446, 0.11458050379795687, 0.11250392879758563, 0.13820057921111584, 0.12272096984088421, 0.15647504718175956, 0.174207759222814, 0.11019549159599201, 0.15283397398889065, 0.12580455866243156, 0.1415792086294719, 0.1341278763221843, 0.10970077849924564, 0.25319995624678476, 0.11700056679546833, 0.1271979303232261, 0.22346214125198977, 0.1332741028496197, 0.1578246397631509, 2.887389063835144, 24.3897317137037, 49.819407258714946, 54.4098527772086, 41.974422046116416, 29.741771016802105, 30.212615694318497, 43.59461688995361, 29.564171586717876, 7.083781829902104, 0.5136370584368706, 0.3390494281692164, 0.29625997852001873, 1.234890416264534, 3.092560031584331, 9.826408215931483, 15.930793251310076, 25.88689306804112, 21.746484109333583, 13.902218903814044, 25.316023860658916, 39.044425759996685, 43.40361785888672, 46.78179727281843, 48.05599267142159, 51.455329350062776, 47.329617568424766, 43.03913620540074, 37.520324502672466, 37.02653687340872, 38.25715664454869, 46.12515776497977, 50.28586414882115, 47.79311105183193, 45.95534379141671, 47.675061157771516, 49.675558703286306, 48.069083077566965, 46.44973938805716, 46.8961854662214, 49.169021129608154, 46.62722764696394, 45.22935778754098, 43.00915125438145, 42.03503465652466, 39.25987550190517, 38.86321326664516, 42.20999724524361, 48.31374304635184, 48.10083287102835, 44.38617304393223, 48.68878943579537, 48.47060905184065, 45.07786968776158, 38.908723967415945, 35.189235142299104, 36.10910715375628, 34.65700660433088, 37.540283203125, 44.84173168454851, 51.22878680910383, 48.7494923727853, 49.26642097745623, 47.94142035075596, 45.94822883605957, 42.92821168899536, 43.01945890699114, 34.69630561556135, 47.26689617974417, 47.25716175351824, 46.91871500015259, 43.62864569255284, 41.61269882747105, 39.37520865031651, 38.32380029133388, 36.63390459333147, 35.19289684295654, 37.923726490565706, 43.61982148034232, 47.65506076812744, 47.27282994134085, 45.77132075173514, 47.20005798339844, 47.63982684271676, 52.63172190529959, 49.758812018803184, 50.17165313448225, 49.21376058033535, 46.729560715811594, 37.36641842978341, 38.626925877162385, 45.623713220868794, 46.04036889757429, 49.24409294128418, 47.00166606903076, 46.56395387649536, 41.71964202608381, 38.53402498790196, 35.904569557734895, 40.923652921404155, 47.968778882707866, 50.84521845408848, 50.62697206224714, 47.050133228302, 48.374341760362896, 53.348755155290874, 48.64047166279384, 48.34126833506993, 46.3709329196385, 49.53842905589512, 49.803294386182515, 54.338453088487896, 52.75493083681379, 31.459244115012034, 20.319753170013428, 30.748089041028702, 26.80160083089556, 29.174384593963623, 25.91106758798872, 19.478480918066843, 8.287046108927045, 6.4197311997413635, 1.8064915729420525, 0.22695062548986503, 0.8476994442088264, 9.548680901527405, 37.18524415152413, 39.7303032875061, 31.820008482251847, 34.97075251170567, 49.910310540880474, 57.87346376691546, 49.972816535404746, 13.784826483045306, 0.4409433491528034, 0.14865778093891485, 0.1004057511953371, 0.17267884340669426, 0.14581770476486, 0.15632806292601995, 0.14020965354783194, 0.11584327103836195, 0.10736949502357415, 0.12513377251369612, 0.09895862599036523, 0.10729490366897412, 0.11350651857044015, 0.21496087099824632, 0.1911058867616313, 0.11586107579725129, 0.1515126491763762, 0.1561952329107693, 0.10961649087922913, 0.08204151982707636, 0.11609052919915744], [0.0272895266368453, 0.1037289375173194, 0.04278692889160343, 0.007018019420294357, 0.031128065394503728, 0.024484942933278422, 0.08938904306186096, 0.07232463373137371, 0.05230839690193534, 0.01307450043636241, 0.05584168480709195, 0.05452121155602591, 0.033731024113616774, 0.07223757768848113, 0.007839040431593145, 0.019961842069668428, 0.02799081463100655, 0.04100198145689709, 0.07079543971589633, 0.02991265311305012, 0.11853368952870369, 1.0519331651074546, 9.91701967375619, 35.14091736929757, 41.84752362115042, 37.64867162704468, 29.98744194848197, 30.19152443749564, 39.462648255484446, 24.23830267361232, 5.30632667030607, 0.25329125991889406, 0.033288195197071345, 0.16757267740155968, 0.9550838534321103, 3.6794915199279785, 4.428483009338379, 2.151815197297505, 7.042517781257629, 11.78131776196616, 14.065316574914114, 29.59011616025652, 33.31745992388044, 40.798387323107036, 45.934356757572715, 47.20203821999686, 44.20263985225132, 42.72600868770054, 37.18064096995762, 33.68819843019758, 36.94861282621111, 32.232005391802105, 36.424854142325266, 44.70427199772426, 47.114723682403564, 46.911912713732036, 46.312974521092, 47.261650289808, 43.82961886269705, 45.541853019169395, 44.721920422145296, 46.01936796733311, 44.74969932011196, 42.496957847050254, 46.18853228432791, 43.76566069466727, 42.85968508039202, 42.3453551019941, 43.583256585257395, 47.39045252118792, 45.20278787612915, 44.24149070467268, 47.82580927440098, 43.238910811288015, 40.346233299800325, 33.96823862620762, 31.87062610898699, 32.62544713701521, 31.91737011500767, 32.69887222562517, 41.27890041896275, 44.31822313581194, 46.14698553085327, 46.376991748809814, 45.768065520695274, 43.86206347601754, 42.41671657562256, 41.51076875414167, 27.62537751879011, 45.44656889779227, 45.962083544049946, 42.20052685056414, 43.83056034360613, 41.86079815455845, 38.3021879196167, 37.520161220005576, 31.670504093170166, 33.56179332733154, 33.429523944854736, 37.53191409792219, 43.79251200812203, 46.939882687159944, 46.011450495038716, 44.56686094829014, 47.532643931252615, 45.114055906023296, 47.32604619434902, 47.936330795288086, 48.80083608627319, 47.42032977512905, 37.11689124788557, 34.42803219386509, 40.54604264668056, 42.87194865090506, 41.75918769836426, 38.279442991529194, 36.031766755240305, 33.652616705213276, 31.892280169895717, 32.32392658506121, 34.50326034000942, 41.109899384634836, 45.669394152505056, 46.0408934865679, 47.14864131382534, 46.088367053440635, 47.81601578848702, 48.3062424659729, 44.87147344861712, 45.12188305173601, 44.95989274978638, 48.32682997839791, 48.17398350579398, 47.9172614642552, 32.35416514532906, 24.502209152494157, 13.34722111906324, 16.35733621461051, 7.449531963893345, 14.48160833971841, 8.110895378249031, 3.0171303876808713, 1.6584861491407668, 0.32744726645095007, 0.10618615030710186, 0.48096418593611034, 6.710964943681445, 27.816836868013652, 24.696308817182267, 26.815669195992605, 27.521349089486257, 31.019569056374685, 44.93961443219866, 32.21035133089338, 11.994851538113185, 0.2735936790704727, 0.025249404234013388, 0.010123046979840313, 0.01783931498149676, 0.06526865663805179, 0.05720515003693955, 0.05255552953375237, 0.04437576274254492, 0.0425970272959343, 0.02686029895474868, 0.06733618676662445, 0.006807408087687301, 0.047613535076379776, 0.030751006877315894, 0.041586793826094696, 0.029073932939874272, 0.023629715699436407, 0.06992860444422279, 0.03522758398737226, 0.08376503270119429, 0.10156216485691921, 0.030589305197021792, 0.048236199521592686, 0.014546591489176666, 0.015507444573034133, 0.03291422401421836, 0.01419895255405988, 0.04591501603967377, 0.045874378577406914, 0.02592784765043429, 0.03749195033950465, 0.05228464478360755, 0.05306700583813446, 0.027736513276717494, 0.06300424278846808, 0.01996828306333295, 0.016865837753617337, 0.014249530554349934, 0.07157344796827861, 0.0480105764498668, 0.05010185530409217, 0.04642187152057886, 1.2228974997997284, 13.779117669378008, 41.09240729468209, 47.941524573734824, 40.814858027866904, 31.418353966304235, 31.137094361441477, 39.55148097446987, 25.625783239092144, 6.30991622379848, 0.2343271832380976, 0.16857336727636202, 0.4698912001081875, 2.385548255273274, 9.129693235669817, 9.156202350343976, 7.625693985394069, 7.352634123393467, 11.97667852469853, 14.152939438819885, 25.649933440344675, 31.227691922869, 42.16586923599243, 45.443574224199565, 49.19444458825247, 46.05286175864083, 44.85960939952305, 40.34467690331595, 35.38411821637835, 38.16028138569423, 33.45684426171439, 39.115488461085725, 47.38684640611921, 48.64185435431344, 47.10797003337315, 46.296316214970176, 47.642345564705984, 45.570913859776084, 45.85087415150234, 46.56541299819946, 47.425857067108154, 47.81823573793684, 44.25884730475289, 46.83041034426008, 44.684893471854075, 44.00860793249947, 42.86432300295149, 43.63462809153965, 48.116132804325645, 45.19924429484776, 44.8020018850054, 49.18141324179513, 44.52937541689192, 41.96643509183611, 35.99530955723354, 34.11291054316929, 33.32972696849278, 34.585037163325715, 33.78660576684134, 42.609681946890696, 46.60038675580706, 48.460023471287315, 47.71876185280936, 45.904430866241455, 45.71648556845528, 43.88089656829834, 42.089835098811555, 29.556872504098074, 45.26687111173357, 46.75064155033657, 44.91067518506731, 44.60374893460955, 43.79908152988979, 39.609762464250835, 38.36410331726074, 33.71778038569859, 34.31695829119001, 35.77661848068237, 39.744640895298545, 45.87348706381661, 47.91794238771711, 47.120511531829834, 43.97162961959839, 46.45650693348476, 45.95814738954817, 48.472992283957346, 48.211027826581685, 50.622688497815815, 49.54670436041695, 38.5122458594186, 36.69527803148542, 42.928805759974885, 43.69934361321585, 42.88977772848946, 41.21363946369716, 39.08193908418928, 35.6403226171221, 34.38359498977661, 34.40550265993391, 35.803476742335725, 41.93392447062901, 48.54262018203735, 47.4810014452253, 47.9544551713126, 45.3796785899571, 50.42415761947632, 49.646247727530344, 47.81190940311977, 47.32010201045445, 46.08590391704014, 48.949249608176096, 49.8906957762582, 48.97955765042986, 33.718412671770366, 20.816954101834977, 10.503616997173854, 6.971056427274432, 13.263878345489502, 11.363545162337166, 10.588531800678798, 4.005729419844491, 2.8437526396342685, 0.830284055854593, 0.012731344921381345, 0.6221214000667844, 7.274826892784663, 31.329410076141357, 30.935204029083252, 30.855998039245605, 30.17983409336635, 37.335193225315635, 52.417269229888916, 38.52513129370553, 15.008861098970685, 0.43079051109296934, 0.08809237621192421, 0.01610180562628167, 0.01910095924644598, 0.05287650713164892, 0.055934141988732984, 0.020382189424708486, 0.020670990892020718, 0.045774874809597216, 0.013710895885846444, 0.025523579878998653, 0.04518298192748001, 0.04759776592254639, 0.04267631072018828, 0.06693186131971222, 0.014808275304468614, 0.035051890914993625, 0.05858673554446016, 0.03770497301593423, 0.03961444180458784, 0.0836362060425537, 0.07908977035965238, 0.182368879871709, 0.06642574204930238, 0.08377935657543795, 0.19675963052681514, 0.0897544070280024, 0.22450312253619942, 0.2311041961823191, 0.16901609780532972, 0.0790683218677129, 0.1668905054352113, 0.18183745124510356, 0.16996261344424315, 0.19044377229043416, 0.18068675084837846, 0.15577053784259728, 0.18993553599076612, 0.14708381039755686, 0.1378467639109918, 0.11924644985369273, 0.1504493983728545, 1.8755257257393427, 17.556616136005946, 48.00757762363979, 53.549339226314, 49.86533832550049, 38.50498846599034, 37.97559131894793, 48.51585572106497, 31.802742208753312, 8.207120980535235, 0.4206282006842749, 0.26795741436736925, 0.7577473052910396, 5.614127959523882, 14.340223789215088, 12.332500985690526, 6.824755592005594, 14.64286126409258, 18.983275856290543, 19.103189604622976, 32.56978164400373, 33.89722456250872, 43.17240612847464, 46.876598494393484, 49.75567838123867, 48.51933676855904, 46.890001569475444, 42.2479760987418, 37.42491878782, 40.4713008744376, 36.014938218253, 40.02304826463972, 50.52778305326189, 50.259603432246614, 47.492306164332796, 46.95846217019217, 48.46953902925764, 47.13793066569737, 48.466183049338206, 48.126579420907156, 47.17900146756853, 48.66341808864048, 45.62713868277413, 48.815184116363525, 47.415250641959055, 48.56382608413696, 45.754106589726035, 47.94487707955496, 50.921815395355225, 46.155451910836355, 44.47123983928135, 51.94914129802159, 47.72945165634155, 44.24135174070086, 37.80234146118164, 35.64111123766218, 35.57665974753243, 35.22831528527396, 35.0616523197719, 45.14627817698887, 47.896215370723176, 50.56885732923235, 49.35128974914551, 48.07698665346418, 46.60422910962786, 44.893339429582866, 42.39805024010794, 32.4682754107884, 46.55761364528111, 49.05929170336042, 46.88709374836513, 48.19096142905099, 45.50226565769741, 41.28908995219639, 41.03940296173096, 35.49586609431675, 36.84845454352242, 37.11752005985805, 41.851504938943044, 48.44556079592024, 50.1925185748509, 50.83134290150234, 45.67486585889544, 48.2418326650347, 46.096687521253315, 49.89676850182669, 48.06967714854649, 52.22032254082816, 51.84449795314244, 41.16753816604614, 38.77262265341622, 45.059328419821604, 46.008643422807964, 45.02372932434082, 43.5588823046003, 40.2836126599993, 36.83439833777291, 35.4598640033177, 36.317337717328755, 37.16615397589547, 44.32228088378906, 50.753821849823, 49.234150069100515, 48.74469116755894, 46.62751252310616, 51.622794832502095, 51.52188614436558, 49.69695568084717, 49.82629639761788, 48.133763858250205, 52.29075295584542, 52.007217815944124, 51.944353989192415, 37.48493037905012, 31.631611551557267, 20.018022435052053, 25.833687237330846, 12.645151683262416, 21.47562595776149, 13.87925945009504, 5.8207630429949075, 4.389568754604884, 1.2069652804306574, 0.12106298309351717, 0.9458668508699962, 8.764200619288854, 36.58686181477138, 35.94150965554373, 37.01084784099034, 38.103472914014546, 42.51403651918684, 58.4412636075701, 45.531666960035054, 18.643404722213745, 0.6142389944621495, 0.2091836202889681, 0.11362740636936255, 0.0797596744128636, 0.13044533106897557, 0.16757231099264963, 0.20529089202838285, 0.09977305121719837, 0.09523131778197629, 0.2008253445050546, 0.09185461540307317, 0.17579922239695275, 0.13317971862852573, 0.16449520896588052, 0.15134791444454873, 0.0877167663670012, 0.12239212462944643, 0.25075155762689455, 0.18486735437597546, 0.22711472239877495, 0.30613681567566736], [0.03884160738172276, 0.057717104708509784, 0.06948798415916306, 0.07081240309136254, 0.02188497146458498, 0.034943087824753354, 0.03500288711594684, 0.02659566860113825, 0.026037788983168345, 0.04591091090281095, 0.03142120270058513, 0.012887289232042218, 0.06816760929567472, 0.03468169577951942, 0.03996120712586811, 0.024514901950689297, 0.012609131434666259, 0.03503974174548473, 0.02327877060244126, 0.02129144161673529, 0.01920214238842683, 0.6496646563921655, 9.263658847127642, 30.81610495703561, 43.93650994982038, 43.68223367418562, 26.111762830189296, 27.792440005711146, 35.88749435969761, 22.9558493409838, 6.316418869154794, 0.24889147600957326, 0.11079039038824183, 0.1450677200087479, 1.078049055167607, 5.689175886767251, 7.516012328011649, 11.488238402775355, 6.648552749838148, 12.235448547771998, 12.82895759173802, 24.398882491247996, 31.481057984488352, 42.38484866278512, 46.02933515821184, 47.23179040636335, 45.122383322034565, 41.780793121882844, 36.76434659957886, 33.20101853779384, 32.54287474496024, 32.32079642159598, 34.692011628832134, 39.78595835821969, 45.49252775737217, 46.20082017353603, 43.245129449026926, 44.125893524714876, 45.14896018164498, 44.98774460383824, 46.47834512165615, 48.6040700503758, 46.72356442042759, 44.72559254510062, 45.236371994018555, 43.57084362847464, 45.29634189605713, 46.79578052248274, 45.40382010596139, 47.30450677871704, 46.57043307168143, 47.57850899015154, 44.664879185812815, 42.23537901469639, 37.83291700908116, 31.964093276432582, 30.943955285208567, 32.18957969120571, 30.919021674564906, 33.25970302309309, 36.67188344682966, 43.684724603380474, 43.6677953175136, 43.69511216027396, 44.51268931797573, 45.27736289160592, 43.145294257572715, 41.750901971544536, 26.126595497131348, 42.55657339096069, 44.22501652581351, 45.123984881809776, 44.12326710564749, 42.95568486622402, 41.91177708762032, 40.37035397120884, 33.937506743839805, 31.49542338507516, 31.76576042175293, 33.9309024810791, 37.57961000714983, 43.4411416053772, 44.88510581425258, 46.30963243756975, 44.906836305345806, 46.87499693461827, 44.45670420782906, 45.53319903782436, 46.977965763636995, 43.32910885129656, 34.605301584516255, 35.06470605305263, 39.602001326424734, 36.91484458105904, 35.96204853057861, 34.06482206072126, 32.76439373833792, 32.87574209485735, 31.61376162937709, 32.04509884970528, 32.039543764931814, 34.22820200238909, 40.89094080243792, 44.972531523023335, 47.51371356419155, 47.99319832665579, 46.69044235774449, 46.89346177237374, 48.33548048564366, 49.84947906221662, 48.77640274592808, 47.696951457432334, 48.138651915958945, 48.86256388255528, 39.45658595221383, 21.760778290884836, 7.973806551524571, 2.4556614415986195, 14.1599988085883, 11.09874757698604, 10.393183197293963, 4.09906370299203, 1.1903853586741855, 0.4252885691821575, 0.08984328833009515, 0.25647489194359097, 6.542968358312335, 33.75009298324585, 41.295885290418354, 29.271148681640625, 26.73377251625061, 35.88099431991577, 43.19216333116804, 35.56028979165213, 11.365403805460248, 0.30374782958200996, 0.1269355679729155, 0.03715711027117712, 0.033054989496512074, 0.05934486272079604, 0.04124002171946423, 0.016486925139491047, 0.04836659359612635, 0.07062337002051727, 0.025388151074626615, 0.032381384034774134, 0.036057123581745794, 0.011743800814396568, 0.05984368773975542, 0.05762533963258777, 0.03215058374085596, 0.03863582467394216, 0.08785680242414985, 0.1092904887295195, 0.031523305257516246, 0.024770626532179967, 0.038926271588674614, 0.06194052379578352, 0.017178891758833612, 0.010970426108022886, 0.003701375872229359, 0.02032920262510223, 0.006934800917016608, 0.029635668333087648, 0.02376545493357948, 0.06629403161683253, 0.043006431577461104, 0.0589833189068096, 0.03051663070384945, 0.01689722339090492, 0.06658132334372827, 0.004490724141110799, 0.021480262645387223, 0.006125998625066131, 0.07976595086178609, 0.03973437626180904, 0.017414674196126204, 0.9516213706561497, 12.13237202167511, 36.948703152792795, 50.225734438214985, 49.20509270259312, 31.311956201280864, 27.54297535760062, 45.32790061405727, 29.107139928000315, 7.409575479371207, 0.3233351271067347, 0.08551393635571003, 0.43573024602872984, 2.952551441533225, 7.381468279021127, 9.01656527178628, 12.490825244358607, 10.585342577525548, 9.428016747747149, 16.719877583639963, 28.20706680842808, 33.58906500680106, 44.288523060934885, 46.14776720319475, 48.603583676474436, 47.2759496825082, 43.684939997536794, 37.75741788319179, 34.38441487721035, 34.28294685908726, 33.29391942705427, 36.350557054792134, 42.85334832327706, 47.87802498681204, 47.05562230518886, 43.542137145996094, 44.854655333927695, 43.92137677328927, 45.8419075012207, 47.29136773518154, 49.132122720990864, 45.61821372168404, 46.358950751168386, 45.96999059404646, 44.83610016959054, 47.1903270312718, 48.96927431651524, 46.445386341639924, 47.47227798189436, 46.95794105529785, 47.89979716709682, 46.360458510262625, 44.892634187425884, 39.34805161612374, 33.83839763913836, 31.594761780330114, 32.74770763942173, 33.02468367985317, 34.855447156088694, 38.840662888118196, 46.92611483165196, 45.32937363215855, 46.50770820890154, 45.90554257801601, 48.59268542698452, 45.08187532424927, 42.50647340502058, 29.031771080834524, 42.82742806843349, 45.47368424279349, 47.36251034055437, 47.1885552406311, 45.6501476424081, 44.81655488695417, 42.082032271793906, 35.940439632960725, 33.86570405960083, 33.7095502444676, 34.89955084664481, 39.89891869681222, 44.93868684768677, 46.63975177492414, 47.30306850160871, 48.05163615090506, 47.24855293546404, 44.452556133270264, 47.00034243719918, 48.064726557050435, 45.797258377075195, 36.51933227266584, 36.97164610454014, 40.75688573292324, 38.86316115515572, 38.58627891540527, 35.58267341341291, 33.66210099628994, 33.66786800112043, 32.85908726283482, 33.98351076671055, 34.987049511500764, 37.22651645115444, 43.01107243129185, 46.294429779052734, 48.28176048823765, 49.70023175648281, 47.719651222229004, 49.49228259495327, 49.28974608012608, 52.32545573370797, 50.61102942058018, 50.70160266331264, 50.42561674118042, 51.98537962777274, 38.07106304168701, 22.73034381866455, 10.653804915291921, 9.075041311127798, 13.072368621826172, 9.062409486089434, 13.98405304976872, 5.291722425392695, 1.5756701358727045, 0.5116876001868929, 0.0033930868791815427, 0.3013558036514691, 6.962852341788156, 34.25846488135201, 39.867231437138145, 32.06523820332119, 32.33867761066982, 40.42024898529053, 48.51247194835118, 41.37012331826346, 14.414665051868983, 0.41597567605120794, 0.04524742918355124, 0.04749617565955434, 0.024824917815359573, 0.0466982184776238, 0.03259853220411709, 0.03960801607796124, 0.045308219135871956, 0.024612210657713667, 0.0718210521819336, 0.009225611475163271, 0.01975317728439612, 0.060606381456766806, 0.003461418960276725, 0.04905699958492603, 0.050670633890799115, 0.042323811778000424, 0.03065562860241958, 0.06632494567228214, 0.013262558113118368, 0.029737390910408328, 0.09398138163877384, 0.14225331959979876, 0.19362137892416545, 0.09321923074977738, 0.041427287206585915, 0.11344646143593959, 0.19813841368470872, 0.12185491488448211, 0.0577846189428653, 0.14131164870091847, 0.10899365680026156, 0.14262773522308894, 0.1419990046748093, 0.13841464343879903, 0.13362056283014162, 0.06872701392109905, 0.08163928426802158, 0.11847557978970663, 0.15862970799207687, 0.07742078455963305, 0.14507265974368366, 1.2978524948869432, 15.057609660284859, 43.945361954825266, 55.83214208057949, 55.44247668130057, 37.55217504501343, 37.396893228803364, 47.003708839416504, 31.6376564843314, 8.690296973500933, 0.49226640803473337, 0.3609510729355471, 1.0656995006969996, 2.712899386882782, 7.697487115859985, 18.32775674547468, 22.35269011769976, 14.388236710003444, 19.61369981084551, 17.878355945859635, 25.254853657313756, 33.76287072045462, 46.020684650966096, 46.493999413081575, 49.64910691125052, 50.51422364371163, 46.54710796901158, 41.12271186283657, 36.877647399902344, 36.51777240208217, 35.100002901894705, 39.025002070835654, 43.20734861918858, 50.00693219048636, 46.88340425491333, 42.835223947252544, 44.43124600819179, 44.5801111630031, 45.9728740964617, 47.787899902888704, 51.60792916161673, 48.22214494432722, 46.86261177062988, 47.31220538275582, 44.884643759046284, 48.656515053340364, 50.53571442195347, 48.89387246540615, 48.04577534539359, 47.63893747329712, 49.915903840746196, 48.13481651033674, 47.263623578207834, 41.52380704879761, 34.718251500810894, 33.18722288949149, 35.24053021839687, 34.63833679471697, 35.670088699885774, 39.19502796445574, 48.23799378531319, 47.800354548863, 47.77558422088623, 49.57675184522356, 50.017903396061485, 46.24000106539045, 43.68687159674508, 32.328578404017854, 43.38434355599539, 46.14105176925659, 48.35337209701538, 50.540460041591096, 46.37603637150356, 46.85054969787598, 44.266802992139546, 37.87788575036185, 34.376136098589214, 35.302772181374685, 36.48366369519915, 42.173161370413645, 46.596568720681326, 49.65397065026419, 50.764247621808735, 49.62356880732945, 49.082453523363384, 44.590960775102886, 48.119631222316194, 50.70735924584525, 47.09745046070644, 37.740311418260845, 39.20060041972569, 44.08523266656058, 40.048666272844585, 40.62380688531058, 36.32674557822091, 36.11256735665457, 35.83611590521676, 34.81463343756539, 36.04204314095633, 36.3065402167184, 38.3795804296221, 44.07575879778181, 48.81115763528006, 51.4324836730957, 50.32453434807913, 50.42584950583321, 49.66056101662772, 51.35205480030605, 54.339001996176584, 53.12866054262434, 52.84903029033116, 52.036306449345176, 54.78783825465611, 45.082643100193565, 27.2637619972229, 11.386343938963753, 9.44151188646044, 22.9748717716762, 20.64357222829546, 21.42928668430873, 9.785238402230398, 4.173913172313145, 1.155233444912093, 0.17567049073321478, 0.4811108037829399, 9.056765811783926, 40.207651478903635, 51.06550761631557, 39.8608842577253, 37.87614870071411, 48.605494431086946, 55.7365974017552, 48.86206361225673, 17.176065036228724, 0.8153443432279995, 0.2169155811092683, 0.14418282892022813, 0.19278389029204845, 0.1306966468691826, 0.09346408011125666, 0.07552096114626952, 0.10427536855318717, 0.16162055464727537, 0.1413279063999653, 0.18105518179280417, 0.15993816778063774, 0.2770632728934288, 0.14360439138753073, 0.2621923094349248, 0.15042894732739243, 0.1721125787922314, 0.15235070777790888, 0.17097717257482664, 0.08671185600438289, 0.09948304535022803], [0.01834976500166314, 0.03291356922792537, 0.02959515300712415, 0.0609308976147856, 0.02796825673431158, 0.06741277301417929, 0.02052173693664372, 0.01671276703876044, 0.021766699418159466, 0.06677847169339657, 0.011378245162112373, 0.022298438474535942, 0.016825470009020398, 0.03598288845803056, 0.023442345039386834, 0.03913305852828281, 0.02435774475868259, 0.029879184373255287, 0.0212327737826854, 0.029483354184776545, 0.04135400203189679, 0.4360719019813197, 5.9681256498609265, 26.866726296288626, 45.367102350507466, 42.67384161267962, 26.61660851751055, 28.116677692958287, 24.770562478474208, 19.833895172391617, 7.736706222806658, 0.46046510019472664, 0.12481049128941127, 0.5867750995925495, 3.9145603690828596, 10.631053907530648, 7.28266532932009, 8.964544977460589, 5.641047886439732, 8.619593841688973, 18.05355998447963, 30.550596918378556, 33.30808680398123, 48.869807379586355, 45.2244210924421, 50.678930691310335, 42.59467731203352, 43.19166653496878, 34.2245055607387, 33.74453789847237, 32.698024545397075, 33.05128485815865, 32.57228994369507, 41.25514105388096, 42.87031235013689, 46.84606116158621, 44.75857216971261, 45.78187159129551, 43.45918607711792, 44.40246309552874, 43.003693444388254, 45.59156390598842, 45.50708423342024, 48.53402178628104, 44.528378350394114, 45.429090704236714, 45.689415386744905, 45.82193490437099, 45.89413363592965, 45.31294461659023, 44.92118433543614, 45.94011681420462, 43.21916055679321, 42.65582840783255, 35.22330215999058, 31.227087429591588, 31.388994353158132, 31.69040025983538, 32.654737268175396, 32.7675655909947, 31.679533277239116, 33.69379867826189, 37.57019867215838, 38.844977719443186, 39.23914555140904, 42.95243310928345, 45.33040543964931, 45.104641096932546, 26.799521582467214, 41.22583702632359, 43.70696578707014, 42.69448471069336, 43.72108800070626, 45.568832874298096, 44.32034928458077, 43.85493115016392, 38.125047070639475, 31.56811543873378, 33.89663396562849, 31.597079004560197, 33.87052958352225, 38.40954801014492, 39.88943093163626, 42.19528790882656, 42.44998802457537, 46.23854889188494, 46.80444145202637, 46.21074914932251, 45.7315388407026, 43.47563941138131, 35.72889825275966, 33.333402565547395, 36.099115644182476, 36.73255511692592, 34.74154186248779, 35.7581501688276, 36.217002255576, 40.675685610089985, 40.53216709409441, 38.05437694277082, 33.84269162586757, 32.51820169176374, 33.91088819503784, 40.16019875662667, 44.25885772705078, 46.778962407793315, 46.516966683524, 47.68794659205845, 46.79916429519653, 48.86514861243111, 47.61826310838972, 48.32719128472464, 46.022185461861746, 49.68598447527204, 39.75807523727417, 22.995773690087454, 13.563555019242422, 8.702405946595327, 18.262014627456665, 6.063081034592219, 10.526014515331813, 2.806790611573628, 2.25144367984363, 1.2932172864675522, 0.08150186735604491, 0.37683845471058575, 5.129941872188023, 26.72360382761274, 36.348576818193706, 37.17669786725725, 25.954247168132238, 30.518110615866526, 43.84778492791312, 39.41586256027222, 10.927999939237322, 0.3542388416826725, 0.036781015273715766, 0.05796029844454356, 0.04102428151028497, 0.0782178867874401, 0.04238587737615619, 0.03030934843367764, 0.026881131676158736, 0.03457411065963762, 0.050473248053874285, 0.011511738445343716, 0.02136403807838048, 0.06367131735065154, 0.06460644038660185, 0.005136303562072239, 0.01965114427730441, 0.1115200123084443, 0.05931672387357269, 0.024172794772312045, 0.014517502692927207, 0.03622215347630637, 0.014107882976531982, 0.029850143074457134, 0.017822037783584425, 0.10633027114506279, 0.043837799823709896, 0.029094275419733355, 0.01495272183923849, 0.01917742844671011, 0.026257006684318185, 0.03410494779901845, 0.08122341015509196, 0.035963397539619885, 0.0046693777465926746, 0.024568401044234633, 0.04497842736808317, 0.012662627983705273, 0.06912679996873651, 0.03840499723862324, 0.02142298750446311, 0.01897674492959465, 0.05247110959940723, 0.645634049815791, 8.292474389076233, 33.90543038504464, 51.06759902409145, 47.06355367388044, 29.65996640069144, 36.11663205283028, 30.523234912327357, 24.8821279661996, 8.200686948640005, 0.6427853426762989, 0.17523960742567266, 0.9769435375928879, 4.995423010417393, 6.280388116836548, 9.561925905091421, 11.21803251334599, 10.002285361289978, 9.131474580083575, 18.925751720155986, 30.252859660557338, 36.14563730784825, 45.42469596862793, 47.50311408724104, 50.24280963625227, 45.374064445495605, 44.260035446711946, 37.64620154244559, 34.90703753062657, 34.897980553763254, 35.200657980782644, 35.1892386163984, 41.84994854245867, 46.20255722318377, 48.043065547943115, 45.01101064682007, 46.17544535228184, 45.860257693699424, 46.13311692646572, 45.94753054210118, 47.215601103646414, 47.020825726645334, 48.6162919316973, 47.018946238926475, 45.33590841293335, 46.79485641207014, 47.121696199689595, 45.418029172079905, 44.75292328425816, 45.37071541377476, 48.291060652051655, 45.49526882171631, 45.277137075151714, 37.08353989464896, 33.21986205237252, 33.54125445229666, 33.64087772369385, 32.99216611044747, 33.780272483825684, 33.877790451049805, 36.66926745006016, 39.196532249450684, 41.32263238089425, 41.40791457039969, 45.47060966491699, 47.693387031555176, 46.594956738608225, 29.351376056671143, 43.321236542293, 43.57144117355347, 42.9528534752982, 44.199683393750874, 46.30310113089425, 46.999473912375315, 45.238112517765586, 38.81116083690098, 34.18758978162493, 35.48933826174055, 34.15273414339338, 35.10752432686942, 39.96129962376186, 42.428625788007466, 43.941338947841096, 43.82925060817173, 49.20279284885952, 48.966706957135884, 45.58115897859846, 48.43729938779558, 45.64744131905692, 37.76538051877703, 34.15621519088745, 39.45328555788313, 37.53643042700631, 36.711377007620676, 36.77656153270176, 39.04291105270386, 41.41782964978899, 42.558949674878804, 40.31057167053223, 34.828804288591655, 34.74612767355782, 36.09789970942906, 43.82081549508231, 46.37255184991019, 48.24570281164986, 49.706068243299214, 50.00496585028512, 49.23376096997942, 50.554471084049766, 50.33445290156773, 50.97050837108067, 49.156920841761995, 50.60744415010725, 42.42986951555525, 25.069093567984446, 15.97778912952968, 6.619275646550315, 11.17425104549953, 7.75463604927063, 10.35850647517613, 7.40091107572828, 1.0379793367215564, 0.7041128032973835, 0.08329182916453906, 0.3803573101758957, 6.983761642660413, 30.681619099208287, 42.68198837552752, 43.2576014654977, 30.93820912497384, 38.41218832560948, 50.526935373033794, 45.72449336733137, 13.762445466858999, 0.29128311414803776, 0.017660739831626415, 0.052610311058482954, 0.05515924481941121, 0.05680875666439533, 0.005877780761303646, 0.037686666141131094, 0.0038518935990785913, 0.01565672566981188, 0.0188852258226169, 0.06379009490566594, 0.01742381915184004, 0.06512815239174025, 0.030758647181625878, 0.019405573972367814, 0.022128462059689418, 0.02289566464189972, 0.04028409479984215, 0.024100155902228186, 0.0195049064100853, 0.014232636728723134, 0.0508831985560911, 0.1269695082945483, 0.09037510372166123, 0.18072797863611154, 0.05118103810985174, 0.08897119441202708, 0.13425640442541667, 0.10763711602027927, 0.10158045816102199, 0.14884185391877378, 0.1832784153521061, 0.09968916393284287, 0.14502565083759172, 0.09883161102022443, 0.12715206135596546, 0.11628003045916557, 0.09874747267791203, 0.1402770999286856, 0.08305946484740291, 0.19711871125868388, 0.11296110533710037, 0.8730495125055313, 10.697621124131338, 39.98872068950108, 57.94112532479422, 52.99778427396502, 36.789050919669016, 38.67964880807059, 33.96515710013253, 27.506844724927628, 10.766315358025686, 0.9531961147274289, 0.46223607659339905, 1.1048790897641863, 7.623557414327349, 19.161403349467687, 13.218810592378889, 14.027469737189156, 9.404313836778913, 12.869011351040431, 19.818755047661917, 33.00980063847133, 35.63680682863508, 49.297222341809956, 47.6674667767116, 55.091026374271934, 46.25503696714129, 48.45679603304182, 39.227997166769846, 36.75934042249407, 37.168672697884695, 37.61917652402605, 35.11108875274658, 45.29409415381295, 49.02163594109671, 48.93423802512032, 45.5926512990679, 47.212325028010774, 46.73830154963902, 49.0849791935512, 46.81065661566598, 50.297603130340576, 48.826725074223106, 51.95294543675014, 47.13217060906546, 45.888248511723106, 47.45782225472586, 46.47624676568167, 46.63725389753069, 45.1511801310948, 45.7154016494751, 49.79643998827253, 46.77063846588135, 47.37937709263393, 38.60536214283535, 34.65831286566598, 34.94706957680838, 35.84176826477051, 35.71644013268607, 35.68836246218, 35.51688092095511, 38.337436131068635, 41.078125272478374, 42.97464650017874, 43.150852816445486, 47.3511118207659, 50.25755718776158, 47.5755421093532, 33.630670819963726, 42.55155331747872, 43.76255832399641, 45.422830377306255, 45.37064593178885, 48.80622788837978, 47.84330136435372, 48.85254110608782, 41.06689350945609, 35.62114558901106, 36.929348945617676, 34.87877573285784, 36.58642060416085, 42.0837311063494, 43.96936103275844, 46.403453963143484, 46.36536046436855, 51.9136255809239, 50.4469963482448, 47.213662556239534, 49.856118065970286, 48.77489498683384, 39.91554921013968, 36.32900374276297, 40.006956236703054, 39.4026575088501, 39.15502718516758, 39.62572247641427, 41.54505116598946, 44.91346836090088, 45.34832484381539, 43.91552986417498, 37.657964842660085, 36.007798944200786, 37.30055298124041, 45.650508948734824, 47.73554522650582, 51.79312992095947, 50.50086920601981, 52.261483669281006, 51.46947588239397, 52.987594740731375, 51.4940516608102, 53.064282008579795, 50.506469454084126, 53.75952918188912, 44.446879455021445, 27.142484664916992, 17.632664169584, 14.804307869502477, 26.964569091796875, 12.368994661739894, 23.31998532158988, 10.027934636388506, 5.473763057163783, 2.455110796860286, 0.1776248344353267, 0.5738889596291951, 7.3007058926991055, 34.76118094580514, 48.46029445103237, 47.82101501737322, 36.96762309755598, 43.88388776779175, 55.10906042371477, 53.27289472307478, 17.82795545033046, 0.7468219686831746, 0.11363985748695475, 0.23061217686959676, 0.13362299198550837, 0.14810957892664842, 0.25418559621487347, 0.17342817676918848, 0.1171686127781868, 0.12132564399923597, 0.13244774219180855, 0.14136656932532787, 0.11774303338357381, 0.10508368017950229, 0.20468562522104808, 0.09440201906753437, 0.15914976437176975, 0.14924541940646513, 0.08655677004052059, 0.17781798621373518, 0.07935650926083326, 0.08840873637901885], [0.016507058969831893, 0.02506360438253198, 0.030592962500772307, 0.05166453502273985, 0.024187544427279915, 0.052091004459985664, 0.023910144044618522, 0.054505591679896624, 0.05874098012489932, 0.060894589205937724, 0.02551589038089982, 0.05216530404452767, 0.040217282849230936, 0.055787534319928715, 0.024254926347306797, 0.01178674359938928, 0.024442383520571247, 0.02405483485199511, 0.056858279542731385, 0.04259444547018834, 0.017237261037475297, 0.4274536930024624, 4.024291966642652, 26.167322363172257, 46.89903770174299, 44.03072057451521, 23.305845737457275, 18.303127118519374, 22.78921937942505, 24.700217178889684, 9.470089827265058, 0.7170492634177208, 0.16419357300869056, 1.2983730669532503, 5.481662724699293, 5.1983642578125, 7.753735389028277, 13.411894951547895, 19.230593511036464, 6.343026127134051, 20.917871475219727, 28.59941942351205, 39.924814632960725, 44.79942410332816, 47.98281076976231, 44.16524812153408, 43.22569186346871, 39.300706590924946, 34.85683332170759, 34.384043148585725, 32.819433893476216, 32.84000750950405, 34.634456225803916, 40.45656721932547, 43.481545380183626, 46.13668482644217, 43.89028011049543, 47.58383131027222, 40.53130899156843, 40.15727356501988, 40.518482616969514, 40.443528924669536, 40.4945182800293, 43.476271697453086, 43.82333769117083, 45.27323566164289, 43.97471809387207, 48.91284452165876, 45.373498167310444, 46.393198422023225, 45.64732319968087, 46.06799146107265, 41.93302467891148, 40.0249034336635, 32.79360743931362, 31.494513171059744, 31.682385512760707, 32.3369961466108, 31.050144604274205, 32.75060851233346, 32.71380043029785, 33.11455168042864, 31.90880993434361, 34.73236676624843, 38.371464933667866, 40.79109866278512, 42.66366250174386, 45.3531607900347, 27.23042975153242, 42.2775684765407, 42.59800549915859, 44.00577654157366, 44.3273218018668, 45.22424738747733, 45.355762890407014, 43.0799012865339, 36.83537803377424, 32.24479355130877, 33.85858563014439, 31.866915770939418, 31.49865082332066, 32.36492443084717, 34.91510091509138, 38.79165029525757, 42.41547632217407, 41.8763621194022, 46.583037103925435, 45.69412279129028, 44.358717237200054, 42.66510425295149, 38.77523865018572, 38.7653374671936, 37.0473050389971, 37.12848431723458, 38.96441030502319, 43.62225682394845, 42.132170472826274, 46.26331227166312, 46.999328000204905, 46.54645136424473, 42.75941910062517, 35.20078304835728, 31.080205985477992, 33.07850790023804, 38.622854232788086, 42.9179596219744, 45.07817888259888, 47.43628978729248, 45.54408686501639, 47.07663713182722, 46.55032498495919, 44.78708062853132, 44.64520536150251, 49.37892968314034, 44.995384148189, 29.58274064745222, 19.054071051733835, 11.66195205279759, 5.1172657523836405, 5.117777747767312, 8.687449080603463, 5.802232197352818, 0.5649899457182203, 0.4085099995136261, 0.09780363046697207, 0.10651861889553921, 6.2826158830097745, 25.53258878844125, 38.56531967435564, 21.238819190434047, 22.017531599317277, 35.6465516771589, 47.3455810546875, 34.888847146715435, 9.252966438020978, 0.14280309581330844, 0.08305863024932997, 0.014861942335431064, 0.006603483717689025, 0.024677372071892023, 0.06348506627338273, 0.021257679410544888, 0.010085072767521654, 0.0656250910833478, 0.02749972491125975, 0.024268055999917642, 0.0391420016198286, 0.0464652774057218, 0.019844177312084606, 0.06728045190019266, 0.06381980795413256, 0.01545974356122315, 0.054024903901985714, 0.08670713340065309, 0.07156581444931881, 0.0325506378098258, 0.02503804736105459, 0.0033203012758998996, 0.010843202488363853, 0.033618407656571696, 0.0502065125453685, 0.03915082936042121, 0.01798389383059527, 0.021700542253841246, 0.027170184201427867, 0.07921484471963984, 0.057980620568352084, 0.013385241485333868, 0.09432949045939104, 0.03625987323799303, 0.023338515610833253, 0.0072572178573214585, 0.008958269525984568, 0.06720472060676132, 0.017614853900990317, 0.007366114246126796, 0.05820450998310532, 0.6567839543734277, 5.722068658896855, 32.786158970424104, 52.0094655581883, 49.86912509373256, 29.32176283427647, 24.17501848084586, 29.27100624356951, 26.68464354106358, 10.739453622273036, 0.7953275058950696, 0.17767344468406268, 0.6348239555954933, 2.382881884063993, 5.048043889658792, 7.847077488899231, 8.79583924157279, 8.827985950878688, 9.809914929526192, 17.643004826137, 27.44521246637617, 40.753213609967915, 45.947940485818044, 49.33746630804879, 46.662305627550396, 46.15881483895438, 42.095692430223735, 35.620655741010395, 34.45106199809483, 34.55040734154837, 33.37331996645246, 36.332300662994385, 42.273138999938965, 46.36279310498919, 46.18239007677351, 43.44973305293492, 48.26034961427961, 43.60582433428083, 43.81955439703805, 42.42771209989275, 42.33443600790841, 42.01722294943673, 43.99857473373413, 45.23181397574288, 47.93465280532837, 44.96062925883702, 47.932488441467285, 46.78263800484793, 46.26559822899954, 46.815346649714876, 48.91005481992449, 44.53448234285627, 41.20943232945034, 34.27836799621582, 32.83420576368059, 33.18048661095755, 33.20351641518729, 34.40053817204067, 33.99488844190325, 33.61884846006121, 33.77635022572109, 34.73484032494681, 36.60205405099051, 40.421336378370015, 42.622292927333284, 44.7335968698774, 47.22032240458897, 29.441535881587438, 40.53290012904576, 43.674778257097515, 45.31444195338658, 44.90012434550694, 46.16406420298985, 48.27128260476248, 45.76697812761579, 39.41329172679356, 33.838842323848176, 35.5859112739563, 34.041715826307026, 32.49358769825527, 34.743403979710166, 37.176732608250205, 40.3464869090489, 44.08050789151873, 45.20816230773926, 48.131620338984895, 46.60437502179827, 46.97532892227173, 44.42048324857439, 40.06612362180437, 40.16150501796177, 38.093266010284424, 38.51215900693621, 41.122597217559814, 44.61547401973179, 44.236717292240684, 48.21628761291504, 49.09583922794887, 48.11412477493286, 46.26866585867745, 36.549285956791465, 33.32011413574219, 36.27046169553484, 41.57233674185616, 45.36721699578421, 47.05234622955322, 48.78013392857143, 48.86289044788906, 49.228859015873496, 49.04903268814087, 47.892914976392476, 48.764493533543174, 51.04658072335379, 45.90463931219918, 29.277912752968923, 18.737655299050466, 4.46635981116976, 10.104712230818611, 6.08469774893352, 8.820984772273473, 3.8843565498079573, 2.4557435171944753, 0.6456166793193135, 0.039417307025619915, 0.5008570956332343, 6.702996228422437, 29.366568292890275, 41.94991227558681, 28.236030374254497, 27.102360555103846, 39.418381282261436, 52.13092701775687, 41.7910486630031, 11.188581705093384, 0.2085354293563536, 0.06770955744598593, 0.03523566194676927, 0.023475579684600234, 0.04517796076834202, 0.08256223438573734, 0.038186681989048205, 0.009578345360101333, 0.07123468936021839, 0.06619010719337634, 0.03522817770551358, 0.01216048068766083, 0.04489796668557184, 0.03070829649056707, 0.04627725195937923, 0.08389487037701265, 0.06059627128498895, 0.04367969437901463, 0.05776486000312226, 0.020721713081002235, 0.018828232273725525, 0.1100455489275711, 0.15849518163927964, 0.09172800076859337, 0.15888082023177827, 0.1483198297875268, 0.1245783373181309, 0.08459053840488195, 0.0928557531109878, 0.10988154701356377, 0.13487110286951065, 0.173115534973996, 0.09597732632287911, 0.21991876353110584, 0.12057004097316947, 0.11696894706359931, 0.09013332133846623, 0.12622055491166456, 0.1428341455757618, 0.17894765202488216, 0.18488547126097338, 0.12351713569036551, 0.7528264607701982, 7.6837383678981235, 41.29472841535296, 58.784893717084614, 54.65813970565796, 33.92941209248134, 27.191634484699794, 33.53203419276646, 33.01624856676374, 12.764908228601728, 1.206228337117604, 0.33533170766064097, 2.2625423414366583, 8.351978761809212, 11.645308511597769, 17.65610044343131, 22.023588691438945, 26.824482985905238, 10.42020126751491, 25.72800166266305, 30.404413768223353, 42.59029647282192, 47.6309609413147, 51.39601257869175, 48.652057783944265, 47.36968782969883, 44.63872616631644, 37.718382903507774, 37.452777590070454, 36.74942534310477, 35.933922222682405, 39.29836852209908, 44.84588670730591, 47.52338893072945, 47.594976220812114, 44.82244348526001, 50.31234720775059, 45.90036964416504, 46.31001458849226, 45.60659980773926, 43.737273829323904, 44.244120597839355, 47.23532009124756, 47.44261612210955, 50.238262040274485, 47.13845525469099, 50.697461536952424, 47.99445595060076, 47.35287318910871, 47.57841171537127, 52.58496052878243, 46.74832432610648, 42.74183668409075, 36.7217332976205, 34.49931723730904, 35.841285364968435, 34.51336302076067, 36.016571044921875, 36.51910993031093, 35.780530316489084, 36.213284969329834, 35.71196549279349, 38.43101099559239, 42.6901490347726, 45.512510776519775, 47.01780673435756, 50.18633467810494, 34.05673435756138, 40.75389800752912, 44.4904967716762, 47.35251883098057, 45.55572509765625, 48.898569447653635, 49.34187841415405, 48.394262245723176, 40.21685436793736, 35.38950654438564, 36.264058930533274, 35.92773485183716, 33.529817717415945, 36.129444531032014, 38.05742372785296, 41.700624806540354, 46.633390699114116, 45.82772970199585, 50.0189699445452, 48.70042419433594, 48.13657440458025, 46.99328654153006, 42.72334405354091, 42.09750938415527, 41.106664998190745, 41.89415993009295, 43.023561818259104, 48.43937689917428, 45.69776364735195, 50.0429481778826, 50.958706855773926, 50.795802865709575, 48.59560367039272, 39.36251081739153, 34.938488551548545, 36.69863748550415, 42.76246241160801, 47.52887453351702, 49.410884448460166, 52.00229154314314, 51.140061787196565, 50.94285454068865, 51.56321750368391, 50.72815520422799, 48.85513973236084, 55.359747954777305, 48.18681335449219, 31.92663206372942, 20.40661781174796, 18.553708689553396, 12.38353897844042, 10.706923024994985, 16.911170176097325, 13.31599852016994, 3.99032005241939, 0.9621386634452003, 0.28225414721029146, 0.5559668956058366, 8.450820360864912, 33.25868511199951, 48.45837674822126, 31.43604407991682, 30.813356944492885, 48.14413057054792, 59.44124834878104, 48.637591634477886, 14.876746313912527, 0.6575445107051304, 0.2101263361317771, 0.08962436579167843, 0.14875000741864952, 0.1285281168030841, 0.24954186539564813, 0.11300801924828972, 0.06000538942004953, 0.2901139168867043, 0.10161941285644259, 0.08736637766872134, 0.11639166304043361, 0.1723239560212408, 0.11777359460081373, 0.15224850683340005, 0.15190260325159344, 0.14060000117336, 0.12763433690582002, 0.14474890354488576, 0.13171866988497122, 0.13703087983386858], [0.050886645513985834, 0.03931463110659804, 0.016126763840605105, 0.010102809672909123, 0.02550153766891786, 0.025614742755091617, 0.05228953702109201, 0.03808537331808891, 0.03425359107287867, 0.0650523193180561, 0.031023255482848202, 0.03697163272382958, 0.025848397985100746, 0.03450510025556598, 0.05958851107529231, 0.04157645295241049, 0.07683768549135753, 0.03794108284637332, 0.055090899379657846, 0.01071986517802413, 0.07066452995474849, 0.07032446855945246, 5.12200312103544, 27.23966043336051, 42.907856941223145, 38.43036828722273, 26.341454642159597, 28.169847045625957, 22.82545597212655, 24.948137589863368, 9.361081276621137, 0.8655276532684053, 0.023095927467303615, 0.8102375801120485, 3.1855568928377966, 2.9553068365369524, 5.6771650569779535, 5.869931536061423, 5.345422446727753, 12.332609551293508, 17.259985378810338, 29.61656447819301, 42.16928080150059, 47.06798315048218, 46.347920485905235, 43.82563059670584, 41.70477288109915, 38.29166834694998, 34.35194941929409, 34.79151330675398, 35.07547228676932, 35.02208232879639, 38.50534629821777, 41.2176833152771, 46.17861025674002, 47.01072651999337, 47.67601653507778, 42.7690805707659, 37.65527936390468, 37.971019404275076, 37.25954123905727, 37.8665497643607, 38.713225977761404, 38.90422848292759, 41.12768677302769, 40.50333901814052, 44.22304671151297, 44.16648490088326, 43.65903016499111, 44.35755688803536, 44.43865278788975, 43.34270995003836, 39.8810270854405, 34.639379024505615, 32.197611808776855, 32.20263188225882, 30.7174231665475, 31.285024983542307, 31.916105542864116, 33.153614452907014, 30.825339112962993, 31.3191545350211, 31.956241812024796, 32.30809511457171, 35.749034132276265, 42.153522287096294, 43.91358436856951, 45.75330407278878, 26.67499075617109, 41.30495963777815, 43.53994151524135, 46.23735727582659, 45.19886909212385, 44.36672156197684, 44.91293682370867, 41.0071633202689, 35.218632970537456, 33.02607331957136, 34.3690767288208, 34.396348408290315, 34.72275740759713, 33.18789686475481, 34.00470277241298, 32.85851403645107, 40.823244503566194, 43.59998089926583, 45.3071984563555, 45.25472913469587, 46.41895192010062, 46.41113519668579, 45.042194162096294, 42.64240101405552, 43.26600531169346, 44.21853038242885, 44.9033830506461, 46.148489815848215, 45.98999098369053, 44.668196950639995, 44.96734816687447, 44.66428164073399, 47.8829026222229, 44.40884154183524, 35.129192284175325, 31.511873245239258, 32.55495418821062, 35.659850529261995, 40.038299560546875, 41.277646269117085, 44.2663756779262, 43.521678175245015, 43.93609305790493, 41.37672758102417, 46.513200759887695, 46.65107039042881, 45.805756023951936, 33.25478022439139, 25.401894909994944, 1.9609132238796778, 9.631795253072466, 6.473101615905762, 4.572163505213601, 3.9482183115822926, 1.0980765862124306, 0.6817961122308458, 0.07961950943406139, 0.48811969054596765, 6.111051397664206, 28.391815934862407, 36.570210456848145, 34.75342675617763, 24.212807995932444, 40.92711312430245, 46.99570451463972, 38.47077553612845, 8.348672287804739, 0.6045223187123026, 0.06418727537883179, 0.09050215261855296, 0.0898059621187193, 0.025587713312623755, 0.036374219959335666, 0.03722972030352269, 0.04816607292741537, 0.060880658882004876, 0.04450246558657714, 0.02950409360762153, 0.029280635062605143, 0.05256085603364876, 0.05462745317657079, 0.03909008351287671, 0.02240730432926544, 0.014990506061751927, 0.029067826124706438, 0.015246010119361537, 0.05252480886078306, 0.1227862856217793, 0.08067796299500124, 0.08848701896412031, 0.022937679530254433, 0.08960130238639456, 0.05862929326082979, 0.02569388029431658, 0.07290821455951248, 0.010697797522880137, 0.04728544982416289, 0.005060855132926787, 0.018006319412961602, 0.03977326649640288, 0.08705887238362006, 0.045139901739146025, 0.07281239184417895, 0.027973812239776765, 0.061302755161055496, 0.037435635325631926, 0.026085562937493836, 0.04482689353504351, 0.061264404361801486, 0.12622425971286638, 6.158410753522601, 32.588176999773296, 48.813252517155235, 42.29988956451416, 29.31256341934204, 31.094293458121165, 25.78325547490801, 30.528095177241735, 10.452432223728724, 1.106143770473344, 0.07562033938510077, 0.4816436437623841, 4.011767404420035, 5.925151910100665, 9.1726895570755, 12.129388638905116, 12.384087886129107, 11.940684250422887, 15.70867497580392, 28.831131424222672, 41.785319873264854, 48.12767028808594, 48.80389329365322, 45.16541699000767, 43.83606331689017, 40.555332388196675, 36.39466421944754, 36.26643868855068, 36.46472985403878, 36.278938497815815, 40.02312469482422, 42.854665006910054, 47.913363524845664, 48.17917728424072, 47.99608530317034, 45.30808087757656, 39.517177718026296, 39.21366303307669, 39.72194807870047, 39.581094196864534, 40.785668645586284, 41.978983538491384, 42.086156027657644, 43.64920541218349, 45.71984502247402, 47.36922230039324, 46.232156549181255, 46.84178107125418, 47.28356490816389, 44.31574957711356, 42.56675945009504, 36.37177337918963, 32.84185573032924, 32.95093897410801, 31.84467806134905, 32.08032621656145, 33.26383720125471, 34.89149441037859, 33.55185740334647, 33.032430921282085, 32.4855694770813, 33.76459387370518, 38.210850375039236, 44.191220487867085, 45.79162686211722, 47.382243224552695, 28.695158651896886, 42.750296115875244, 45.02879456111363, 47.608594690050396, 46.05829177583967, 46.75318111692156, 45.649532726832796, 43.56428452900478, 36.77189234324864, 34.63776356833321, 35.56754718508039, 35.3631728717259, 36.60020930426461, 34.30593844822475, 34.387173312050955, 35.28508901596069, 43.01923656463623, 46.46329532350813, 47.60422427313668, 46.02958876746041, 47.244192940848215, 47.706731046949116, 47.29267399651663, 45.21034056799752, 45.27263811656407, 46.390033517565044, 47.41900961739676, 47.56610992976597, 46.736953599112375, 47.0379182951791, 46.377714361463276, 45.837200096675325, 48.76516056060791, 46.14329603740147, 36.41292061124529, 33.19135706765311, 35.49961812155587, 38.54358918326241, 43.05668388094221, 44.07202761513846, 46.74811935424805, 47.63475465774536, 46.84096465791975, 44.21627916608538, 47.321720940726145, 50.607166222163606, 48.72332893099104, 33.18418652670724, 23.604786770684377, 6.889080277511051, 6.633330549512591, 5.800592422485352, 8.19651108128684, 8.23018639428275, 1.2556227552039283, 0.8423270753451756, 0.06558334760900054, 0.19036697569702352, 7.553219062941415, 31.653025899614605, 44.596620082855225, 35.90343005316598, 28.134788172585623, 47.877347537449424, 53.41267163412911, 44.19322156906128, 11.584014977727618, 0.4826447271874973, 0.04584348148533276, 0.05245564917900732, 0.02554976793804339, 0.028974829507725577, 0.007041534051365618, 0.03257947215544326, 0.026062950757997375, 0.02588483870827726, 0.006765701084597302, 0.0016378401944945964, 0.05742353653269155, 0.008098841312208345, 0.02932908246293664, 0.05230094998010567, 0.023057232311527644, 0.04444021339129124, 0.020299881430608884, 0.0481779540755919, 0.034904214553534985, 0.015589705069682427, 0.1326258983463049, 0.18599843153996126, 0.11463288670139653, 0.1623849786285843, 0.10134504043630191, 0.10801672243646213, 0.16507455573550292, 0.09817822250936713, 0.17346549619521412, 0.14917924867144652, 0.08656272079263415, 0.13612332567572594, 0.17633153311908245, 0.1851631956441062, 0.17267505718129023, 0.15069464806999477, 0.15220889395901135, 0.14077186052288326, 0.13495544477232865, 0.10638189408928156, 0.13694276527634688, 0.43369903787970543, 8.573508177484785, 39.26636164528983, 56.699322428022114, 48.83704662322998, 36.23947967801775, 37.29657861164638, 32.66834878921509, 34.93665075302124, 12.85176592213767, 1.6066908027444566, 0.181259298697114, 1.5193043947219849, 6.739988437720707, 7.680550013269697, 14.519106898988996, 13.76084303855896, 11.51129252570016, 18.30080120904105, 20.8919894354684, 32.70130409513201, 44.60317570822579, 50.37326206479754, 51.93185765402657, 47.44398839133126, 44.62985331671578, 43.27025066103254, 38.50612449645996, 38.31603567940848, 39.381191049303325, 38.106585706983296, 43.26625197274344, 45.267423493521555, 50.83636992318289, 48.19274364198957, 51.38932146344866, 46.52740287780762, 41.6371808052063, 41.42625086648123, 41.45761850902012, 41.99666322980608, 43.39199352264404, 42.170844146183555, 45.128529003688264, 45.449893610818044, 48.93007952826363, 48.855059828077046, 49.03956229346139, 50.242093971797395, 49.43408100945609, 46.88534280232021, 44.30570943014962, 38.58014713014875, 35.320702007838655, 34.56379304613386, 32.98586062022618, 34.12527486256191, 35.44653388432094, 37.08051742826189, 34.14475066321236, 34.90458134242466, 34.72418873650687, 36.38256393160139, 40.11579629353115, 45.89566918781826, 49.02142054694039, 49.79300062997, 32.9964462007795, 43.19032205854143, 45.89336585998535, 48.96032503673008, 47.9350141116551, 48.91921254566738, 48.28235108511788, 45.53515148162842, 38.87006419045584, 35.44037430627005, 38.33076238632202, 37.25140489850725, 38.44178070340838, 37.38959067208426, 38.284372738429475, 37.418484755924766, 44.8958546774728, 49.389147009168354, 50.18165159225464, 45.9704144341605, 47.95187738963536, 49.00075660433088, 50.788420404706685, 47.73915828977312, 49.20899759020124, 49.008576801845, 49.64439950670515, 48.96919788633074, 49.527892112731934, 47.659306117466514, 45.6696651322501, 46.625115394592285, 50.33717312131609, 49.00331354141235, 38.518655572618755, 35.90323897770473, 36.654530320848735, 39.578617164066856, 44.808779852730886, 45.95030287333897, 48.64029795782906, 48.71312550136021, 48.41333852495466, 46.99134104592459, 50.119673660823274, 53.185392584119526, 50.8960097857884, 37.024445465632844, 28.849393027169363, 5.222788912909372, 15.680458341326032, 14.555556280272347, 12.464754734720502, 11.779826504843575, 2.7632136813231876, 1.9309352210589816, 0.233603050666196, 0.727945721575192, 8.321583867073059, 35.96362229755947, 47.43679353169033, 45.207293782915386, 35.56691142490932, 52.5719187600272, 59.030408314296174, 51.9515905380249, 14.54776040145329, 0.7284908837505749, 0.184033122711948, 0.16739522692348274, 0.17752380057104997, 0.11851994240922586, 0.0855438733207328, 0.11089765320398978, 0.10513725051922457, 0.13704143783875875, 0.09647682309150696, 0.09005524909922055, 0.13199663854071073, 0.13303217797407083, 0.1268166479255472, 0.16541546529957227, 0.1023721524647304, 0.15483065827616624, 0.11753888933786324, 0.19397299577082905, 0.12296499817499093, 0.16912787966430187], [0.047239272123468776, 0.03516778130350368, 0.013038847661976303, 0.011488024494610727, 0.013168643777524787, 0.053072705532291105, 0.023148156004026532, 0.056643818372062275, 0.026621948262410502, 0.042276148085615466, 0.08937201861824308, 0.02168398260671113, 0.03275512112304568, 0.033299272281250784, 0.02498102667076247, 0.054264287663889785, 0.031795574219099114, 0.009246933589955526, 0.018363262759521604, 0.04986852068187935, 0.06456340769571917, 0.028486949258616993, 3.367087266274861, 20.67715460913522, 40.042235715048655, 42.00403874261038, 30.94859320776803, 24.336011716297694, 25.837996857506887, 23.372895853860037, 12.663448027202062, 1.2896668655531747, 0.09925199060567788, 0.16200277342328004, 1.531448325940541, 4.7029277341706415, 7.878460764884949, 8.464742813791547, 12.612426536423818, 11.013392431395394, 10.944679958479744, 30.168928895677837, 41.39813845498221, 47.38133995873587, 44.54706900460379, 42.26274796894619, 39.18480716432844, 35.722554547446116, 34.661040033612935, 36.54771566390991, 37.748638834272114, 39.354589870997835, 43.44618252345494, 45.93000371115548, 45.94330603735787, 45.91359901428223, 44.70398017338344, 40.701897689274375, 37.275775705065044, 36.039159638541086, 34.155694075993125, 32.26962293897356, 32.95324230194092, 34.36152056285313, 34.739964621407644, 37.08495732716152, 37.988150187901084, 40.316168444497244, 39.622599261147634, 40.235562392643516, 38.04089048930577, 36.04692077636719, 31.666224002838135, 31.175048896244594, 30.196134567260742, 31.05558851787022, 31.84358719417027, 32.363986424037385, 33.477063519614084, 33.5985631942749, 34.03108855656215, 35.73016629900251, 35.551941531045095, 38.112158162253245, 39.60365847178868, 40.34801203863961, 41.940577370779856, 44.33447844641549, 26.686778375080653, 41.706232002803254, 46.59011731828962, 42.78233773367745, 42.648595333099365, 40.17211839130947, 39.542490005493164, 34.598919664110454, 33.67954444885254, 31.113397530147008, 33.8785582269941, 34.276297433035715, 34.00059986114502, 32.61954116821289, 34.346828596932546, 32.89669091360909, 39.02540854045323, 43.99419042042324, 46.63752487727574, 46.917863845825195, 46.153419562748496, 44.80645915440151, 42.55343280519758, 45.84505156108311, 45.104074818747385, 45.40729073115757, 45.25208534513201, 45.67146471568516, 45.23924160003662, 46.86288275037493, 44.115981919424875, 44.434775693076, 46.24267264774868, 46.56263024466378, 42.23765802383423, 32.43584469386509, 32.84428412573678, 32.12152208600725, 33.65477759497506, 33.71778385979788, 37.67555768149239, 37.70840876443045, 39.77873917988369, 42.10009411403111, 45.4242582321167, 49.93025881903512, 47.71263354165213, 33.482955592019216, 21.329500130244664, 6.98696345942361, 8.0745849609375, 2.6408413563455855, 6.5818087884358, 4.219787350722721, 1.0126883281128747, 0.8928727773683411, 0.0644763380821262, 0.44036719149776865, 5.7346223167010715, 30.749965054648264, 39.97230904442923, 26.461620262690953, 24.965374333517893, 36.946472781045095, 44.14578969138009, 40.43706709997994, 4.350355293069567, 0.3963547231895583, 0.029509111374084438, 0.053564626457435746, 0.022882599450115646, 0.024423710236858045, 0.07300417976719992, 0.047501380023147376, 0.055612987971731594, 0.012486731350821043, 0.006676850316580385, 0.007097425404936075, 0.045303740804748874, 0.05938407525952373, 0.03812496583642704, 0.005823122221045196, 0.07385335277233805, 0.05659313180616923, 0.01829281895022307, 0.052460422672863515, 0.04967118912775602, 0.015340547010834728, 0.04822944809815713, 0.023163295816630125, 0.020608611471418823, 0.028553557648722614, 0.020210862725174854, 0.03605086748887386, 0.03495042957365513, 0.04870988481811114, 0.05033809066350971, 0.020855560898780823, 0.03305574267038277, 0.032902614280049286, 0.007897549658082426, 0.023933316015505364, 0.009337320391620909, 0.024914917003895556, 0.020296083330842, 0.03927099112687366, 0.02076714439317584, 0.08387028705328703, 0.06018940133175679, 0.0307516073808074, 4.994351250784738, 26.330290624073573, 44.79860074179513, 47.59434740883963, 36.08998918533325, 27.322460378919327, 29.473264830453054, 27.896152291979107, 14.198446665491376, 1.772661445396287, 0.03601957345381379, 0.41765013762882774, 1.2455957446779524, 2.964224632297243, 6.945198706218174, 8.570518715041024, 7.389559456280299, 9.126579574176244, 16.336403029305593, 26.90803333691188, 41.009602137974326, 48.88289083753313, 46.94237014225551, 43.18770258767264, 42.54564734867641, 38.295246669224326, 35.74413217817034, 37.95749126161848, 40.87513017654419, 40.821087087903706, 45.57088259288243, 46.87870379856655, 47.92034993852888, 44.64517756870815, 46.31510761805943, 41.804462160382954, 39.993226596287315, 37.617682661329, 35.005111353737966, 34.51005915233067, 36.093859331948416, 36.24597971779959, 37.25518471854073, 39.35107755661011, 41.72427647454398, 42.17607266562325, 43.45998511995588, 43.86159099851336, 40.25718518665859, 38.44496297836304, 34.34230184555054, 32.046651772090364, 32.349169390542166, 33.84512002127511, 33.08947563171387, 34.4736818586077, 34.70804112298148, 34.464322635105674, 35.699649810791016, 35.558372088841026, 35.97654594693865, 38.910798004695344, 40.97003214699881, 42.09663043703352, 44.05214534487043, 46.746059213365825, 29.106306144169398, 42.88499389375959, 47.61717224121094, 43.78879819597517, 44.687704018184114, 42.077161584581646, 41.9655179296221, 38.119773387908936, 34.861836024693076, 32.18584156036377, 35.203155858176096, 36.50785732269287, 36.08262409482683, 33.8247583253043, 35.65825939178467, 34.52417441776821, 41.40809522356306, 46.20443671090262, 48.995423861912315, 46.59945569719587, 45.296116079602925, 45.87808677128383, 45.3075840813773, 48.38863073076521, 48.06568888255528, 47.99276059014456, 47.55806391579764, 45.4242582321167, 46.02771970203945, 46.48935454232352, 45.76817669187273, 45.02046367100307, 48.631546701703755, 46.983513900211875, 43.96143313816616, 34.19508688790457, 35.70883532932827, 34.560958181108745, 35.23965474537441, 35.478870800563264, 38.333552088056294, 39.096658842904226, 42.3742561340332, 43.74944012505667, 50.02382673536028, 52.41667863300869, 48.29698051725115, 35.75473860331944, 25.918599435261317, 12.010647399084908, 9.92152384349278, 6.345491434846606, 8.71314525604248, 5.563021353312901, 2.2877851469176154, 1.2841785486255373, 0.05531034778271403, 0.4189081144120012, 6.549768039158412, 33.41937262671334, 41.482864788600374, 30.194341932024273, 29.086788654327393, 41.48879855019705, 50.23745257513863, 45.31536258969988, 6.299581212656839, 0.38271364516445566, 0.003314910951303318, 0.017027568271649734, 0.021960427951333777, 0.03955987401838813, 0.0901480455483709, 0.0760718501572098, 0.002943160698383248, 0.01992321476739432, 0.03841076139360666, 0.032122845229293616, 0.02282433195172676, 0.05729916784912348, 0.012376427850020784, 0.04811230241986258, 0.025516394193151166, 0.02597535358342741, 0.028709725875939642, 0.05018128122070006, 0.007362299182984445, 0.08569064044526645, 0.1349629493696349, 0.07189313974231482, 0.11570421207164015, 0.1743211695658309, 0.125556133421404, 0.18367443553039006, 0.08622643883739199, 0.11370665247419051, 0.14607447598661694, 0.07801708113402128, 0.176681874319911, 0.10950489222471203, 0.10017836053988763, 0.14204448009175913, 0.09388006957513945, 0.10394885750221354, 0.12122921060238566, 0.1542261242866516, 0.0876865851293717, 0.16774427890777588, 0.1906624234148434, 0.13449655153921672, 6.359030868325915, 31.37068932397025, 52.71983201163155, 53.28852469580514, 41.16858386993408, 33.27848400388445, 36.63800403050014, 32.64619793210711, 17.247876405715942, 2.0372467849935805, 0.3143642156251839, 0.446041182747909, 3.98542765208653, 9.47390351976667, 13.74553268296378, 16.626578910010203, 21.610688516071864, 17.109112194606237, 12.47467155115945, 31.665299892425537, 47.25132874080113, 50.60994897569929, 49.418902669634136, 45.45889500209263, 44.689892700740266, 39.2201109613691, 38.19610629762922, 39.86343772070748, 42.44578783852713, 42.58993516649519, 48.768405369349885, 50.15820837020874, 47.86114433833531, 46.85759169714791, 47.973340375082834, 44.30131469454084, 41.6858355658395, 39.16978515897478, 37.60693727220808, 35.03238303320748, 37.46343960080828, 38.99769565037319, 37.99435840334211, 39.681450503213064, 42.16032109941755, 43.65753977639334, 45.0318135534014, 43.85188089098249, 41.7701484816415, 39.82222100666591, 35.27135590144566, 34.78348813738142, 33.49771009172712, 35.89203500747681, 35.14705957685198, 35.86279351370675, 36.9181032861982, 36.49635110582624, 38.05978264127459, 38.66336570467268, 39.09417833600725, 41.99336978367397, 45.303147656576975, 45.18740456444876, 46.77963638305664, 48.34082365036011, 31.727840627942765, 44.867794377463206, 50.39264753886631, 45.7871105330331, 46.66458116258894, 45.46321678161621, 44.09009640557425, 39.535878794533865, 37.053131103515625, 34.247382504599436, 36.73106125422886, 37.39917918613979, 37.24303579330444, 35.523196833474294, 36.771847179957796, 36.015765053885325, 43.73932007380894, 48.2553642817906, 50.77819960457938, 48.34002808162144, 45.99640417098999, 45.798397881644114, 45.54092196055821, 50.02275323867798, 49.56228222165789, 47.95540707451956, 47.87672914777483, 47.881551197596956, 46.08966636657715, 47.38361896787371, 45.41510050637381, 45.07752227783203, 49.234302929469514, 50.13497359412057, 47.61501135144915, 36.44589328765869, 37.54667207172939, 35.407207080296104, 36.53205789838518, 37.728221552712576, 41.0747241292681, 41.076721736363, 44.21270431791033, 46.73476144245693, 51.680221693856375, 53.50352280480521, 51.44934695107596, 37.924240657261436, 26.39955026762826, 10.158581614494324, 14.716395786830358, 9.882164904049464, 14.67725658416748, 9.404395478112356, 4.190504602023533, 1.8900780762944902, 0.16911331830280169, 0.9581074054752077, 8.196622252464294, 38.421808106558665, 51.06635182244437, 37.86525739942278, 35.44038125446865, 50.812627928597585, 57.60589211327689, 51.2869154385158, 9.178799629211426, 0.47874597353594645, 0.12924414766686304, 0.19723104951637133, 0.11066700558045081, 0.1131095891552312, 0.20012468924479826, 0.15115493908524513, 0.1358171571046114, 0.07664184671427522, 0.10127873399427959, 0.0676095142428364, 0.16367662431938307, 0.18950738039399895, 0.054132434739066024, 0.12434445986790316, 0.1398627728755985, 0.14137026055582932, 0.09901577899498598, 0.21004521048494748, 0.1205619392650468, 0.14696251547762326], [0.031599464028009346, 0.07152513627495084, 0.01378800206085933, 0.05519137005986912, 0.014380576022501503, 0.03866417725969638, 0.05236262542062572, 0.02216127431685371, 0.02217944378831557, 0.043104744516313076, 0.01542524344819997, 0.0226539467195315, 0.016250053653493524, 0.09347695192056042, 0.049632322641887834, 0.028042452842263237, 0.04420807299071124, 0.04969001168917332, 0.027272831282711456, 0.0598289906712515, 0.06961413738983017, 0.028974320606461594, 2.2993695310183933, 20.007238830838883, 37.66593442644392, 42.203003883361816, 31.890595231737407, 27.217328923089163, 21.462233304977417, 29.997760023389542, 13.689225350107465, 2.882485155548368, 0.07529352299336876, 0.2963925642626626, 2.446040792124612, 3.6882076007979254, 6.716020626681192, 11.38253024646214, 8.404326489993505, 6.22934274162565, 22.197945049830846, 22.883181606020244, 36.35047715050833, 48.286652020045686, 46.28475093841553, 42.669707434517996, 38.53596006120954, 36.416398184640066, 35.356478282383506, 35.79386738368443, 42.82337032045637, 45.89669057301113, 46.07961579731533, 45.8615847996303, 43.255461420331685, 44.134127140045166, 43.446137360164094, 39.62141806738717, 36.45490510123116, 33.3802091053554, 32.76861129488264, 31.755223478589738, 32.03608703613281, 32.921047823769705, 30.831491742815288, 30.842442103794642, 30.885416712079728, 33.26900666100638, 31.345901625497, 30.762975556509836, 30.84422779083252, 31.177355698176793, 32.08172975267683, 35.15024185180664, 30.590212072644913, 31.335524490901403, 31.06785556248256, 32.17858764103481, 35.314511162894114, 41.15149824959891, 40.895293848855154, 43.227421964917866, 41.942196301051546, 44.24365854263306, 42.05635172980172, 47.103509289877756, 45.835605485098704, 43.975458077022004, 25.707992587770732, 42.269049985068186, 46.8938022341047, 39.59714106151036, 37.59835277284895, 37.69958802631923, 35.8091846874782, 32.538844789777485, 33.13876615251814, 31.515041623796733, 33.095801966530935, 31.548643112182617, 33.112404687064036, 31.05506045477731, 32.5586645262582, 31.386930738176616, 35.8410838672093, 41.17458363941738, 45.43136971337454, 46.06956870215279, 45.69573824746268, 45.845492771693635, 46.28328834261213, 44.35820654460362, 45.84745216369629, 47.17892503738403, 46.79553386143276, 46.2305133002145, 45.27931533540998, 46.72682659966605, 45.821354729788645, 46.24518442153931, 44.035202162606375, 46.509942054748535, 46.72357831682478, 42.395653111594065, 35.52100120271955, 32.7213704926627, 33.604903425489155, 33.83808497020176, 36.44208567483084, 40.59905045373099, 43.222676345280235, 44.25429970877511, 47.772276878356934, 48.73786803654262, 47.320098536355154, 35.99601827348982, 26.771098239081248, 17.650406394686016, 2.9843225138528005, 4.502362336431231, 7.46809320790427, 6.72641339472362, 1.2610515781811305, 0.7016017894659723, 0.33009586004274233, 0.19917711509125574, 7.118089428969792, 29.256175313677105, 49.52826384135655, 40.730736187526155, 28.228429044995988, 38.937767437526155, 45.83021368299212, 37.40957369123186, 9.426682693617684, 0.3828907699457237, 0.03458643624825137, 0.013116137889612998, 0.07357625264142241, 0.04756052792072296, 0.028300379269889424, 0.06308479168053184, 0.07240198672349964, 0.01703631628437766, 0.02434959724944617, 0.013799176684447696, 0.03524514786632998, 0.050631607949201546, 0.024737924536956207, 0.0358857765261616, 0.03617246435689075, 0.0060153732442164, 0.04967507713341287, 0.033076668690357885, 0.019163009577563832, 0.07738872378000192, 0.026702989092362777, 0.11805343601320471, 0.05192788803417768, 0.032648156862705946, 0.00845617990541671, 0.05155845285792436, 0.03246193631951298, 0.009642427903600037, 0.06263002394033329, 0.03727366901668055, 0.07145848378006901, 0.021060354641771743, 0.028636437308575426, 0.03052905128736581, 0.05772484000772238, 0.11592006763177258, 0.08241681754589081, 0.029071161124323095, 0.0707097068162901, 0.03848427387752703, 0.02435584825330547, 0.020122025527858307, 3.3853126083101546, 23.577544621058873, 44.41140195301601, 46.4629340171814, 36.227271693093435, 33.06374297823225, 26.451052052634104, 34.26340505055019, 16.20394778251648, 2.4868412656443457, 0.173128196437444, 0.013186658034101129, 1.4453464661325728, 4.461945968014853, 6.349157043865748, 11.786175421306066, 9.746067064149038, 7.965696266719273, 16.920750004904612, 26.34403763498579, 40.481869084494456, 49.59805849620274, 48.26707199641636, 43.9051388331822, 38.79780292510986, 37.69266414642334, 36.80673408508301, 38.43856716156006, 44.37189449582781, 46.324814251491, 47.885574204581125, 46.903585297720774, 44.45789234978812, 45.308181626456125, 45.968701703207834, 42.32720988137381, 38.684450013296946, 34.862086159842356, 34.48325995036534, 34.03511503764561, 34.45962217875889, 34.123666354588096, 31.73064422607422, 32.90669631958008, 34.31882735661098, 35.85835361480713, 33.174368722098215, 33.589030265808105, 32.79198503494263, 33.12718003136771, 33.578851154872346, 35.836619649614605, 32.33755547659737, 32.717885971069336, 33.79749706813267, 33.67725849151611, 37.28471456255232, 42.08151463099888, 42.48282173701695, 44.24596187046596, 43.333503586905344, 45.01931027003697, 43.14555134092058, 48.17905569076538, 48.5672550201416, 44.50162778581892, 29.38543960026332, 44.67210183824812, 48.27783128193447, 42.60735430036272, 41.22439527511597, 39.36178820473807, 37.7461895942688, 35.27421508516584, 34.644114221845356, 33.184520040239605, 34.00418513161795, 33.77331733703613, 34.07481357029506, 32.487580980573384, 34.28326300212315, 33.2075046811785, 37.91335283006941, 42.96615580150059, 47.34731463023594, 48.13042524882725, 47.15851122992379, 45.99644238608224, 44.3898138999939, 43.515674931662424, 46.87102951322283, 47.27453572409493, 46.58134869166783, 47.07359034674508, 46.991334097726, 47.029330321720664, 47.231731346675325, 46.36633668627058, 45.213630540030344, 48.88419362476894, 51.48456736973354, 43.51470218385969, 37.62120887211391, 33.78319420133318, 35.36754328863961, 36.09974445615496, 37.27212790080479, 41.624545506068635, 44.09222602844238, 46.431608063834055, 50.43328407832554, 50.331576347351074, 49.45959826878139, 34.683267320905415, 20.95287823677063, 5.988478660583496, 4.9850806168147495, 8.645242248262678, 8.262428641319275, 9.13770364012037, 1.8604728877544403, 1.1112572103738785, 0.10286132193037442, 0.40110886522701805, 7.314079437937055, 32.52359349387032, 53.02509069442749, 41.09388031278338, 31.04674346106393, 46.13009793417794, 49.53520509174892, 43.11815806797573, 11.017740266663687, 0.38676243647933006, 0.023781059542670846, 0.11445606047553675, 0.0444858211225697, 0.04798852406176073, 0.017360561028388993, 0.028043465555778573, 0.046507502639932294, 0.03637911219682012, 0.0531858648173511, 0.08158559179199593, 0.01105381127646459, 0.024328476150653193, 0.028576865326613188, 0.04957338509016803, 0.006122632243204862, 0.03736418898084334, 0.034167753000344546, 0.07261091444109168, 0.08014198818377086, 0.023286719640184726, 0.1434706657060555, 0.2321800541664873, 0.11517161636480264, 0.20015842600592545, 0.09058532744113888, 0.15987731676016534, 0.19206604095441954, 0.03984649399561541, 0.1357856866504465, 0.118977424289499, 0.1654524454580886, 0.1754033514963729, 0.1200933972639697, 0.20126381383410522, 0.11711054375129086, 0.1556307189166546, 0.13721358217298985, 0.11941260950905935, 0.18207662126847676, 0.11195941801582064, 0.10380190038787467, 0.1949038915336132, 4.157130232879093, 28.782514878681727, 48.525538035801475, 53.77019119262695, 40.44020768574306, 37.692730154309956, 32.08475569316319, 39.898369789123535, 19.02027153968811, 3.829832298415048, 0.3658035211265087, 0.5251854530402592, 4.207370051315852, 11.418255278042384, 14.344171234539576, 18.928435461861746, 18.144904477255686, 10.158624172210693, 25.18789734159197, 27.07432631083897, 41.41048540387835, 51.591229166303364, 51.411159651620046, 45.69613776888166, 41.61467906406948, 39.70110695702689, 39.20633268356323, 40.25349569320679, 47.14106777736119, 49.95206226621355, 49.31334563664028, 46.42700488226754, 45.023072719573975, 45.33462299619402, 47.10749060767037, 45.59565986905779, 40.87858690534319, 36.96509395326887, 37.113535267966135, 35.550159318106516, 35.605922085898264, 36.70579065595354, 33.94979810714722, 34.74382087162563, 35.155776091984336, 37.204917975834434, 34.82794966016497, 34.238214356558665, 35.01181289127895, 35.330429485866, 35.80900403431484, 39.194492953164236, 34.182809420994346, 34.09496334620884, 34.70824262074062, 36.318949699401855, 39.492042609623496, 45.30084432874407, 45.70254053388323, 47.121463435036794, 47.608396666390554, 47.33194521495274, 46.010463850838796, 49.20027412687029, 51.57448053359985, 43.94977058683123, 31.490170546940394, 45.44687114443098, 50.931883335113525, 45.01235512324742, 42.34440319878714, 42.386689935411724, 39.84925644738333, 37.50242246900286, 36.2844032560076, 35.350065095084055, 36.221261501312256, 34.75001866476876, 35.612696579524446, 33.73731872013637, 35.14731666019985, 35.03893518447876, 39.66066149302891, 45.439200333186555, 49.54934120178223, 50.350913184029714, 48.351395334516255, 48.06342376981463, 45.696155139378135, 44.237742151532856, 46.6088878767831, 49.11510310854231, 48.891742842538015, 48.6248972756522, 48.208978107997346, 48.817164352961946, 49.57182557242257, 47.545011724744526, 46.038263593401226, 50.89736468451363, 52.13123621259417, 47.44543014253889, 40.3683112008231, 35.606481415884836, 36.97600957325527, 38.10908358437674, 39.835137707846506, 44.15126139777047, 46.5825194631304, 48.701185022081646, 52.248372418539866, 52.859591552189414, 49.949783257075715, 38.87261765343802, 28.829387426376343, 20.87103714261736, 7.0152921336037775, 8.584917119571141, 14.309819340705872, 16.00449800491333, 3.29874478493418, 1.8145075142383575, 0.6528098561934063, 0.537150251013892, 9.265713776860919, 37.20875685555594, 59.02138260432652, 50.58745418276106, 39.279934951237266, 51.80499049595424, 59.3149995803833, 49.340738909585134, 14.044388600758143, 0.49597164349896566, 0.15631571358868054, 0.1641603655048779, 0.14340381643601827, 0.10579731581466538, 0.11932148225605488, 0.11209399186606918, 0.1527231963617461, 0.08058446765478168, 0.1053499441061701, 0.1439152689916747, 0.09298448477472578, 0.14264415577054024, 0.1220062824764422, 0.13708202780357429, 0.11313567204134804, 0.08723012783697673, 0.17803536169230938, 0.18113580532371998, 0.20657242754740374, 0.15270501162324632], [0.05462680856830307, 0.03712606390139886, 0.04011495637574366, 0.03645768655197961, 0.07034464819090706, 0.12110510654747486, 0.028488961114947284, 0.10778046332831893, 0.04209259757772088, 0.05108430615759321, 0.05778215586074761, 0.02670866164511868, 0.039278536436281035, 0.052269404887088707, 0.06273196704153504, 0.0513826715759933, 0.021629436872899532, 0.035451419119324, 0.054570083040744066, 0.022126132988237908, 0.05477535345458558, 0.03397079464048147, 1.2446320078202655, 14.690730878284999, 38.38708101000105, 48.268214975084575, 34.2039840562003, 19.9167628628867, 24.812877007893153, 28.584188972200664, 20.529680831091746, 3.3337435126304626, 0.234755311693464, 0.04162936850583979, 0.3562994711101055, 3.2068611553737094, 5.104055489812579, 6.9068958929606845, 3.625735261610576, 5.257129515920367, 11.943513904299055, 21.120880467551096, 38.88587829044887, 45.09472949164254, 44.398214272090364, 41.14576945986067, 38.4313132422311, 34.811704771859304, 37.43629993711199, 40.15965332303728, 42.45066894803728, 45.276254653930664, 43.59315776824951, 43.067846161978586, 42.49775341578892, 45.48281070164272, 43.33899961199079, 39.9106958934239, 38.44222886221749, 33.68728126798357, 32.0763692174639, 31.882980006081716, 31.621567930494034, 31.836909975324357, 30.41778210231236, 31.041942255837576, 31.456579480852398, 31.683153288705007, 31.22562483378819, 30.78810371671404, 33.39521721431187, 31.353381361280167, 31.969908918653214, 46.00963354110718, 33.3726737839835, 30.264181750161306, 32.06049953188215, 36.3099239894322, 42.87430756432669, 45.31344836098807, 46.69147416523525, 46.93927819388253, 46.3276560647147, 44.560065610068186, 44.16189908981323, 39.81755181721279, 38.7804081099374, 41.37466049194336, 22.656116213117325, 40.49801322392055, 46.67908900124686, 38.10513353347778, 35.05441229684012, 31.447942870003835, 31.864820889064244, 32.03756352833339, 32.69689893722534, 32.426558426448274, 33.11602817262922, 34.01092141015189, 34.33826494216919, 33.4074946812221, 32.84456205368042, 32.37298781531197, 33.49869326182774, 36.826908179691856, 42.57601792471749, 43.202293804713655, 44.51240791593279, 44.08609424318586, 45.93578461238316, 48.80508838381086, 45.896027020045686, 46.56980078560965, 45.73884834562029, 42.27455643245152, 44.041111605507986, 41.876466342381065, 45.04474762507847, 47.13686759131295, 47.78032636642456, 44.25533151626587, 49.49124036516462, 45.6113315309797, 44.675690582820344, 35.6763733455113, 34.51393624714443, 33.76841190883091, 39.24847003391811, 38.27231066567557, 43.452748571123394, 45.08429329735892, 48.44189214706421, 48.38138028553554, 50.22030094691685, 32.61039733886719, 25.99782453264509, 8.442849908556257, 9.683486376489912, 7.419100591114589, 5.928613415786198, 3.8278846314975192, 1.8302857875823975, 1.532329227243151, 0.02892136773360627, 0.5677924039108413, 7.158792410578046, 26.969834089279175, 35.23384257725307, 34.28880419049944, 31.046264035361155, 34.41443109512329, 44.36399786812918, 39.33045877729143, 7.552123853138514, 0.2958059843097414, 0.01978721938628171, 0.041933589681450806, 0.03334771628890719, 0.022799975937232375, 0.007890424192217844, 0.06502879450895957, 0.017149032825337987, 0.013766083683419441, 0.02732934646441468, 0.02635323312798781, 0.06056092639586755, 0.03398238401859999, 0.12329013858522687, 0.02954320775877152, 0.0358014380160187, 0.08375465790075914, 0.04057997678007398, 0.061775158026388714, 0.08866664753960711, 0.12219209250594888, 0.0311072954375829, 0.027966636731954556, 0.034238690443869145, 0.09279414891664471, 0.06472550292632409, 0.05857237095811537, 0.01531155320948788, 0.06351693706320864, 0.011164765322713979, 0.06711780027087245, 0.04731617388980729, 0.020671966286110025, 0.028402995817097168, 0.03971385397017002, 0.022274574397930076, 0.02243335159229381, 0.01835275734109538, 0.013407810408222889, 0.05121884608109083, 0.02551445527933538, 0.011649097681843808, 0.049014859167592864, 1.8732158839702606, 18.54314395359584, 44.09252827508109, 51.99907105309622, 39.339918749673025, 23.325458765029907, 30.8151912689209, 33.50013153893607, 22.891288416726248, 3.7445448977606635, 0.23513523702110561, 0.06131930463016033, 0.4847633849297251, 2.074508019856044, 5.249346664973667, 9.499128086226326, 5.483150507722582, 6.005199934755053, 13.678652797426496, 27.70324945449829, 41.14975077765328, 49.76319285801479, 45.56701592036656, 43.41624273572649, 39.744950090135845, 38.27118158340454, 38.5167760848999, 43.29588951383318, 45.78142690658569, 47.68529238019671, 43.91699940817696, 44.258378301348, 43.357283796582905, 47.01632329395839, 47.13381038393293, 42.2172337940761, 39.61374725614275, 36.221629755837576, 33.498012338365825, 33.892221859523225, 32.56627280371529, 33.149327414376394, 31.74514511653355, 31.82390989576067, 32.90189511435372, 31.993279184613908, 33.59470346995762, 32.53371007101876, 33.64585263388497, 33.34675005504063, 34.11392845426287, 47.648762226104736, 33.966637066432405, 31.79866361618042, 33.491126673562185, 37.778196471078054, 44.89932877676827, 47.32574394771031, 47.5523281778608, 49.76156003134591, 47.80030938557216, 46.153985840933665, 45.78586680548531, 43.17215599332537, 40.41814020701817, 43.342901025499614, 25.75109052658081, 42.74563734872, 48.48357439041138, 41.404815673828125, 37.66779654366629, 32.591289792742046, 33.464080810546875, 33.29526390348162, 34.306765283857075, 33.49901635306222, 34.7129465511867, 35.81685549872262, 35.6897416796003, 35.85699871608189, 35.03673607962472, 33.43953282492501, 33.416874749319895, 39.822898456028526, 46.27828563962664, 46.862722941807334, 45.904132093702046, 45.56492798668997, 47.84064367839268, 49.966934885297505, 46.65971394947597, 47.6699264390128, 48.366201945713584, 44.43075268609183, 45.84176158905029, 45.0524913924081, 46.557370458330425, 48.47088697978428, 48.78401449748448, 45.4936637878418, 50.25741127559117, 47.443984917231965, 44.56323398862566, 37.81980575834002, 36.07593297958374, 36.03367403575352, 39.44075100762503, 41.59695073536464, 45.88465281895229, 46.872474738529746, 50.21051440920149, 51.845998764038086, 50.041839940207346, 34.518622807094026, 21.85903103010995, 8.041640077318464, 11.788514358656746, 15.736992359161377, 11.671761172158376, 6.97152065379279, 2.6384186063494, 0.7263187574488776, 0.14858471628810677, 0.5371387973427773, 8.477722917284284, 29.74086775098528, 41.7766033581325, 42.79515368597848, 38.548018659864155, 39.99906655720302, 50.74732181004116, 45.624595642089844, 10.033284749303546, 0.4581769715462412, 0.07551401973302875, 0.008782475521521909, 0.007229296989472849, 0.01192259055096656, 0.029287712182849646, 0.06730792578309774, 0.004543896689678409, 0.04867213452234864, 0.009045216155105403, 0.020951912871428897, 0.0347806058291878, 0.03451690337221537, 0.08891146297433547, 0.037355188213820965, 0.02086246499259557, 0.01619542988815478, 0.015313244458021862, 0.013399606071678656, 0.023212048557720015, 0.11665417466844831, 0.08271987164126975, 0.09117777672197137, 0.10596642709736313, 0.1634293525878872, 0.15849679655262403, 0.14914841604019913, 0.11152219040585415, 0.22283993821058953, 0.11788639426231384, 0.11040610886578049, 0.20597831585577556, 0.1278113124093839, 0.15140249580144882, 0.14746541849204473, 0.15474479645490646, 0.10755925412688937, 0.10946538113057613, 0.15560456817703588, 0.15697508677840233, 0.12415383223976408, 0.10693271524671998, 0.07202763216836111, 2.7039902763707295, 22.83739992550441, 51.16327919278826, 58.39033331189837, 44.59177024023873, 29.53165749141148, 35.47026545660836, 38.22601481846401, 26.01477987425668, 4.906064399651118, 0.40984332082527025, 0.25606549105473925, 0.5192527770996094, 5.979166771684374, 10.367903913770403, 12.496719922338213, 7.165255538054875, 10.74292424746922, 15.74267772265843, 24.729906831468853, 43.88821302141462, 49.95968096596854, 49.755153792245046, 44.72202811922346, 43.056732518332346, 39.027242864881245, 41.55887113298689, 45.71499170575823, 47.35332482201712, 48.671926157815115, 46.92675059182303, 43.85969066619873, 43.56171369552612, 46.23159374509539, 48.548435824257986, 43.0700626373291, 42.84652519226074, 37.311791692461284, 35.63044227872576, 34.57380192620413, 34.89656312125069, 34.89103235517229, 33.83526400157383, 33.94015400750296, 34.85196263449532, 34.51163291931152, 35.98099626813616, 33.571854318891255, 35.56126601355416, 35.027456760406494, 34.84603929519653, 49.10503169468471, 36.452643462589805, 32.92555373055594, 35.25966555731637, 40.665711471012656, 48.278060572487966, 49.623669556209016, 50.31313235419137, 52.39320761816842, 50.15955632073538, 47.03247438158308, 48.750176770346506, 45.20583118711199, 39.92000995363508, 46.47892529623849, 30.26847573689052, 45.21766744341169, 49.84457015991211, 42.55574655532837, 39.57386112213135, 34.30027914047241, 35.921377250126426, 35.56107841219221, 36.35322516305106, 35.88963093076433, 37.162214347294395, 37.937525612967356, 37.60122585296631, 38.35855518068586, 37.39660487856184, 36.28149543489729, 36.22103221075875, 41.481718335832866, 49.084583146231516, 48.0799674306597, 48.47148452486311, 48.05408191680908, 50.16744947433472, 53.401665687561035, 48.55924722126552, 49.29091337748936, 51.12203468595232, 46.163219996861045, 48.77486024584089, 46.26908622469221, 49.153450216565815, 49.059944834027974, 50.145760672433035, 46.06127602713448, 53.23360613414219, 48.76291976656233, 49.15910952431815, 39.89414528438023, 38.3859623500279, 38.25228248323713, 42.95409720284598, 43.067981651851106, 47.94425521578108, 49.817159516470774, 53.47038337162563, 54.27386263438633, 53.307236194610596, 37.37347779955183, 27.520951305116924, 12.586737309183393, 19.52693244389125, 17.337753091539653, 13.690184201513018, 10.44864284992218, 3.65141384942191, 2.3046110783304488, 0.23927872468318256, 0.9562857832227434, 9.768977880477905, 35.32286984579903, 46.97251490184239, 46.15978411265782, 42.29526553835188, 46.884498596191406, 58.20605318886893, 53.11856828417097, 12.461732268333435, 0.5858944697039468, 0.16389473261577742, 0.20610056072473526, 0.13987350729959352, 0.06346768899155514, 0.09761575090565852, 0.09184467486504998, 0.0945060791979943, 0.1673811948192971, 0.12745684571564198, 0.13263732487601892, 0.15859099078391278, 0.16291108754064354, 0.17585007181125029, 0.23452998378447124, 0.13522855511733464, 0.09961018924202238, 0.1045215003458517, 0.15156317289386476, 0.14262667670845985, 0.2271109904561724], [0.03899688672806535, 0.019016252631055455, 0.02390717375757439, 0.01606341920393918, 0.034030515900147815, 0.03863224879439388, 0.1453055872448853, 0.053222556598484516, 0.015464423756514276, 0.03273519594222307, 0.01698606737357165, 0.03727986064872571, 0.04505379225260445, 0.04874737048521638, 0.05561010419790234, 0.05047452709238444, 0.0284611411791827, 0.019739525159820914, 0.05302001389541796, 0.03325748470212732, 0.06386068290365593, 0.019583110963659625, 1.395439944096974, 12.800117356436592, 38.28307342529297, 43.75616250719343, 36.755220140729634, 29.970074926103862, 21.0607716015407, 34.36508846282959, 20.909955739974976, 4.50796388728278, 0.37500687156404766, 0.014775128868807639, 0.45224880107811516, 1.876019916364125, 5.134036532470158, 14.903674057551793, 9.449016809463501, 5.860511515821729, 7.306276610919407, 31.021830695016043, 36.75890268598284, 46.78526094981602, 43.80373682294573, 42.781132221221924, 37.289265632629395, 38.9787722315107, 40.19855976104736, 42.440045152391704, 46.36473512649536, 45.43692479814802, 41.56492648805891, 45.767579146793906, 45.208495821271626, 44.62164054598127, 44.28316599982125, 42.53347063064575, 36.75656461715698, 35.05064984730312, 33.1985901423863, 33.907844884055, 31.2006391116551, 31.17882524217878, 28.998414516448975, 31.406931127820695, 31.782425676073345, 33.07503727504185, 33.110723223005024, 30.936861174447195, 30.78043637956892, 31.204154900142125, 30.167640004839214, 33.33669253758022, 30.71505730492728, 31.452546051570348, 31.22363417489188, 40.768746307918, 47.28366913114275, 48.39078119822911, 45.09666803904942, 44.94506181989397, 44.859414849962505, 43.409016609191895, 39.34164885112217, 40.41974524089268, 37.73593405314854, 41.057819162096294, 27.418923957007273, 38.703863280160085, 43.70504808425903, 35.228280544281006, 35.315720149448936, 33.74755689076015, 34.61646386555263, 32.269643783569336, 33.945226192474365, 32.498812743595664, 33.31543452399117, 32.634827205113, 33.02884217670986, 31.489461830684117, 31.977478981018066, 31.251889024462017, 31.837312970842632, 32.19013902119228, 34.575476442064556, 40.07865469796317, 41.21241658074515, 41.15029968534197, 42.502009187425884, 44.35295370646885, 44.01933247702462, 42.97133220945086, 41.093063899448936, 40.29794331959316, 39.371321133204866, 40.74265234810965, 42.26138612202236, 43.166791984013145, 45.5891181400844, 46.25489452907017, 45.03568370001656, 47.70504263469151, 44.848791054316926, 41.57079771586827, 35.27368007387434, 35.38641112191336, 38.91051312855312, 42.448483739580425, 44.193037441798616, 45.8911771774292, 47.46982874189104, 50.77844973972866, 49.69337388447353, 33.614797660282676, 16.792866672788346, 1.3911259812968118, 3.8621839795793806, 16.086834158216202, 9.337908165795461, 9.328070385115486, 2.404647550412587, 0.2505837966288839, 0.06193679863853114, 0.6187568977475166, 7.2591678244727, 27.896133184432983, 37.30797018323626, 32.91003492900303, 23.63200112751552, 39.237787178584504, 44.94321359906878, 36.97041974748884, 7.6544152327946255, 0.5849817043968609, 0.056646641077739854, 0.049563967024109194, 0.031036402098834515, 0.049113809929362366, 0.030521611150886332, 0.06063632520713976, 0.09158177647207465, 0.016114412806928158, 0.005161952185777149, 0.04364036648933377, 0.09453308489173651, 0.04219134817165988, 0.04220656771212816, 0.07510099546717745, 0.04030318877526692, 0.03246042657909649, 0.05346563498356512, 0.036644996143877506, 0.036096505754228146, 0.03321631119719573, 0.019467950000294616, 0.10236524497824055, 0.026543680944346955, 0.01851407564910395, 0.009625458590952414, 0.06612130374248539, 0.082073634889509, 0.03132006705605558, 0.050117448038820706, 0.05304179486951657, 0.01738874228405101, 0.08337076314325843, 0.011656044184097221, 0.021262239165870205, 0.04568402236327529, 0.06283898558467627, 0.015357518867988671, 0.03165358737377184, 0.021063055211145962, 0.07982970601213829, 0.036749327688344886, 0.029325051964925866, 1.7311982874359404, 16.172215359551565, 43.56585829598563, 49.54195874077933, 38.94583082199097, 33.03010674885341, 24.870965685163224, 37.611151354653494, 25.001225301197596, 5.0779024703162055, 0.4120849833956787, 0.037985859372253926, 1.0848976991006305, 2.3652708062103818, 6.267723287854876, 8.704607657023839, 6.977147391864231, 11.101331438337054, 10.816370180674962, 27.93714840071542, 39.52514035361153, 48.016516481127056, 46.0389723096575, 44.626153400966096, 40.37615919113159, 39.51746259416853, 41.3393497467041, 44.82979815346854, 47.72712400981358, 47.819364820207866, 43.3077118737357, 45.3201881136213, 44.06606606074742, 43.02588946478707, 46.36953285762242, 44.979510988507954, 39.128325257982524, 37.66555922372, 35.497780323028564, 34.80645193372454, 32.432724952697754, 32.69363675798689, 30.788756847381592, 32.243257999420166, 33.776833125523154, 33.802913188934326, 34.352717195238384, 33.380351543426514, 33.46996593475342, 32.6525034223284, 32.00368063790457, 35.954391615731375, 33.44264909199306, 32.294570446014404, 32.78803150994437, 41.38560043062483, 48.95818499156407, 49.79124273572649, 47.01609052930559, 46.32684312547956, 45.329481329236714, 44.18288959775652, 40.04772479193551, 39.99954598290579, 37.79463243484497, 43.002981254032676, 30.531322615487234, 40.679388999938965, 46.866085869925364, 37.16400350843157, 37.43549394607544, 34.46153988157, 36.22999538694109, 34.12327378136771, 35.678245885031565, 33.84822934014456, 34.69945314952305, 33.29193919045584, 35.52998522349766, 32.34814453125, 33.63063260487148, 32.48778247833252, 33.35254832676479, 33.86021498271397, 37.88327407836914, 41.837949003492085, 43.057552405766074, 42.89038569586617, 44.84451443808419, 45.578452655247276, 46.576776776994976, 45.23128938674927, 43.40370123726981, 43.20460408074515, 41.544762815747944, 42.01727853502546, 44.48101942879813, 46.12105485371181, 46.44966295787266, 46.97164290291922, 47.691695145198274, 48.50643048967634, 48.24395186560494, 43.37513024466378, 37.03513526916504, 36.92753546578543, 40.74759251730782, 43.607359886169434, 45.760120255606516, 47.073649406433105, 49.99370629446847, 52.33943550927298, 52.23847470964704, 37.064887455531526, 18.446993044444493, 8.086856348173958, 7.216306558677128, 14.737038884844099, 8.289830599512372, 7.30818475995745, 1.6705097896712167, 0.2611075762127127, 0.10839159267821483, 0.7037361349378313, 9.31054789679391, 31.916529382978165, 41.25237914494106, 34.98469059807913, 28.800661836351665, 45.46076059341431, 52.22877849851336, 43.50053480693272, 9.671224543026515, 0.6916633141892297, 0.052251969929784536, 0.007832608767785132, 0.030882439110428095, 0.0103788758860901, 0.033443902020475695, 0.03902009262570313, 0.033162428731364865, 0.027515159886596457, 0.060351849400571415, 0.038490462116897106, 0.02361280660677169, 0.03518181001501424, 0.04378231940791011, 0.026379548412348543, 0.07314177309828145, 0.043063191031771045, 0.12151169830134936, 0.022856560668775013, 0.05908950963722808, 0.03674454062378832, 0.12474821534539972, 0.17997625683035168, 0.07054627487169844, 0.11525468262178556, 0.13529376233262674, 0.162990679698331, 0.25710986501404215, 0.11902163763131414, 0.12317970022559166, 0.12922646504427704, 0.08965700332607542, 0.13189800669039997, 0.1142156148063285, 0.06338744544024978, 0.20296408688383444, 0.07818309829703399, 0.10560376370059592, 0.09654910742704358, 0.07783366633313042, 0.1875446228576558, 0.11072212298001562, 0.13193989944245132, 1.9454033247062137, 19.00848044667925, 51.73129095349993, 55.520077637263704, 46.91285766874041, 38.604125363486155, 29.95625843320574, 43.36052860532488, 28.931661435535975, 6.5538609623909, 0.9450860470533371, 0.17562740375953062, 2.6642854469163075, 4.382093361445835, 11.564999495233808, 25.799170323780604, 17.906640325273784, 11.257706727300372, 9.938817041260855, 34.70729071753365, 41.67494426454817, 50.855116162981304, 48.02946792330061, 48.09604556219918, 41.18846961430141, 41.22562510626656, 44.11741672243391, 48.318697111947195, 50.16317285810198, 48.18824815750122, 45.34834916251046, 47.40407446452549, 45.74183259691511, 43.95151111057827, 48.71231256212507, 48.687945229666575, 40.63163750512259, 39.71465941837856, 37.03340516771589, 36.465876306806294, 34.63061039788382, 34.49853556496756, 32.528141089848106, 34.873668806893484, 35.896502699170796, 37.05163376671927, 36.67243235451834, 34.75835302897862, 34.16157225200108, 35.30200787952968, 32.94859395708357, 37.68812002454485, 35.36687626157488, 33.86596461704799, 34.403630120413645, 42.8699996812003, 52.34606409072876, 51.36567326954433, 48.187129497528076, 47.06949438367571, 47.429355485098704, 44.38025317873274, 40.27097041266305, 39.92732640675136, 37.44786868776594, 43.517877510615754, 33.79991504124233, 44.247660705021445, 48.29164777483259, 40.33269126074654, 39.21733863013131, 37.80472469329834, 38.49024438858032, 35.65842962265015, 37.190590790339876, 36.54531506129673, 37.3189240183149, 35.37913983208792, 36.52942453111921, 34.190243993486675, 35.92315598896572, 35.35661377225603, 35.955086435590474, 35.705343859536306, 38.422023500714985, 44.65965761457171, 45.70036574772426, 45.764862401144846, 47.52609177998134, 48.619599274226594, 48.729432923453196, 47.42866761343819, 44.555768149239675, 45.82002067565918, 43.939650535583496, 44.57282945087978, 47.34277398245675, 48.815114634377615, 47.962296213422505, 46.7348621913365, 47.39233200890677, 49.766420296260286, 50.601110867091585, 44.73247126170567, 39.46610498428345, 39.66392019816807, 43.05517612184797, 45.73080580575125, 49.99193797792707, 49.886662346976145, 52.9725102015904, 54.16134350640433, 53.06678336007254, 36.94359622682844, 20.725995234080724, 5.098283273833139, 11.452066080910818, 25.49410445349557, 19.84765781675066, 16.125063146863663, 5.711046210357121, 1.305669869695391, 0.33821211595620426, 0.9059146004063743, 10.034570166042872, 37.102789878845215, 49.225798334394185, 43.54757758549282, 32.95382595062256, 53.43170622416905, 59.91343402862549, 50.10316126687186, 13.212238465036664, 0.7674778231552669, 0.17286617335464272, 0.11874077841639519, 0.18879410438239574, 0.11126852008913245, 0.1196104838911976, 0.17830190381833486, 0.21502914519182273, 0.13078712272856916, 0.1273234457309757, 0.07165251765400171, 0.19219649609710487, 0.17375136299857072, 0.10619560229991164, 0.10520753996180636, 0.14008474882159913, 0.19271485613925116, 0.16323461303753511, 0.089722481955375, 0.1591545141169003, 0.11504162262592997], [0.029195241430508237, 0.0394800681221698, 0.023441245812656622, 0.024812829714002352, 0.021793292901877846, 0.02357817248308233, 0.05944318923034838, 0.011932341947353311, 0.029925148335418532, 0.05562248067664249, 0.02491844368965498, 0.020251625716420155, 0.07828046128685985, 0.0272162787815822, 0.020524476521781514, 0.04397033806890249, 0.03419430407562426, 0.012254710542038083, 0.06513311926807676, 0.014071897719986737, 0.03885528664769871, 0.1107153037030782, 0.6374009773135185, 11.575463482311793, 35.885267462049214, 43.866958481924875, 34.59032474245344, 23.001182862690516, 32.57877608707973, 29.260889666421072, 28.569107907158987, 7.27885684796742, 0.8309211730957031, 0.04781717700617654, 0.23925389030150004, 0.8063410520553589, 1.5859022268227168, 4.7063288773809155, 2.86977972303118, 4.7187674556459696, 9.759709852082388, 22.87701334272112, 38.73822907039097, 48.09147712162563, 42.82061535971505, 40.80781602859497, 37.71410976137434, 42.03067466190883, 42.809567723955425, 47.93267256872994, 46.05553681509835, 45.0219019481114, 46.630079882485525, 45.71257025854928, 44.385603291647776, 47.072311878204346, 46.03660297393799, 44.18309804371425, 40.479913166591096, 38.26055778775896, 34.51470054898943, 33.21430696759905, 31.580907072339738, 31.499870232173375, 30.29287086214338, 33.51405572891235, 36.001375334603445, 40.20530993597848, 39.74480765206473, 38.41341815676008, 32.90340287344796, 32.579919065747944, 31.195806639535085, 31.74673625401088, 31.01032100405012, 30.258178506578716, 31.697747979845317, 37.843488693237305, 45.15195485523769, 46.93896552494594, 46.28625522341047, 47.65252467564174, 46.04368666240147, 48.77645485741751, 44.1325603212629, 47.66389887673514, 42.68286732264927, 48.00556264604841, 29.18511608668736, 35.68531567709786, 46.286797182900564, 36.80016803741455, 33.7353697504316, 35.28702061516898, 36.85616704395839, 35.91705199650356, 38.10136413574219, 36.6457964352199, 34.79891313825335, 32.62558610098702, 32.84222398485456, 31.621519293103898, 33.269684110369, 31.614796910967144, 31.191665513174875, 32.21290826797485, 31.484521661485942, 31.815822192600795, 33.65348523003714, 36.38433224814278, 37.62330722808838, 40.209572655814036, 38.873239517211914, 38.70521123068673, 37.02432039805821, 38.19274336951119, 38.35308000019619, 40.20708172661917, 40.85178075517927, 43.238156931740896, 44.325643811907085, 46.26495204653059, 43.31908260072981, 47.05446195602417, 47.23763036727905, 44.88073539733887, 35.36031021390642, 35.68450273786272, 40.93355757849557, 43.09884902409145, 44.00118725640433, 44.32983704975673, 46.136629240853445, 49.25678382601057, 46.02388777051653, 31.61259433201381, 14.290531141417366, 11.699592181614467, 13.34029289654323, 17.032532623835973, 12.97276793207441, 4.420701026916504, 1.1808460248368127, 0.055498088244348764, 0.14219723189515726, 0.7781994906919343, 8.099403057779584, 30.60007504054478, 40.6196414402553, 40.18900946208409, 32.021176201956614, 32.34008114678519, 48.600623743874685, 32.703058515276226, 6.173635125160217, 0.18531521462968417, 0.07168876499469791, 0.049221466295421124, 0.0139857424323314, 0.056150533591530154, 0.0317396052580859, 0.06233566187854324, 0.05490202237186687, 0.0709957161120006, 0.021872381247313957, 0.025428116787225008, 0.05471954734197684, 0.039832278686974726, 0.020437759746398245, 0.05856780441743987, 0.05659172723868063, 0.021667132885860543, 0.06336079937006746, 0.04612361127510667, 0.03543762450239488, 0.01608349196612835, 0.09172148004706417, 0.0442387699149549, 0.019924161323745335, 0.05340193072333932, 0.028300940757617354, 0.07593186838286263, 0.03725412042279329, 0.012341875998702432, 0.05482678980167423, 0.04544903550829206, 0.03184461533757193, 0.018248059387717928, 0.027959106689585105, 0.06422661683921303, 0.020583639686395015, 0.053702311390744786, 0.04740087202351008, 0.019045125992436494, 0.018272435758262873, 0.03579652202980859, 0.0866157550896917, 0.016215838525178175, 0.934158267719405, 14.721374171120779, 41.68778453554426, 49.82338162830898, 41.19470909663609, 27.499206917626516, 30.86543369293213, 35.336120060511995, 29.459080083029612, 8.500209893499102, 0.6427767117108617, 0.058793580159544945, 0.2707448905067784, 1.4459260978869029, 3.3637375831604004, 7.970774531364441, 6.395979217120579, 8.043563859803335, 12.136688590049744, 27.131808757781982, 41.224496023995535, 49.20670815876552, 45.181731360299246, 43.205295426504954, 40.66286965778896, 44.59706824166434, 44.432215281895225, 49.37124497549874, 47.64468363353184, 45.459145137241904, 47.49312605176653, 46.79723964418684, 45.84991530009678, 46.6649181502206, 47.01775114876883, 46.01904140199934, 42.53792790004185, 40.16815791811262, 36.60588250841413, 35.4863018989563, 32.973444189344136, 32.57044519696917, 31.98870379584176, 35.452846322740825, 38.31084884916033, 40.88948515483311, 40.815761293683735, 38.73392466136387, 34.28256123406546, 34.317722593035015, 32.52288130351475, 32.54827002116612, 32.94914633887154, 31.77563033785139, 33.205538340977256, 39.867592743464876, 46.358023166656494, 48.47066463742937, 48.15426104409354, 48.32718086242676, 45.92952081135341, 47.847859382629395, 44.60642051696777, 47.20694364820208, 43.53517852510725, 46.225118024008616, 31.067403929574148, 37.80047239576067, 46.302593912397114, 39.68542834690639, 35.67864888054984, 37.007689884730745, 36.54926858629499, 37.7789295060294, 39.45892402103969, 37.54106487546648, 35.989962918417795, 33.57575920649937, 34.95277404785156, 32.58209037780762, 33.417896134512766, 34.31661088126046, 33.62109272820609, 33.692950998033794, 33.32204226085118, 33.98526866095406, 37.466951915196006, 39.47109726497105, 40.965467180524556, 42.48037944521223, 41.470931257520405, 41.53490332194737, 40.32966184616089, 40.73702083315168, 40.81808546611241, 41.83092784881592, 42.18698133741106, 45.14289787837437, 47.56465080806187, 47.18484142848423, 45.79778296606881, 48.52790042332241, 48.955162525177, 47.18533475058419, 37.53349481310163, 37.29157938276018, 42.86401380811419, 45.903701305389404, 47.36756168093, 47.41389226913452, 49.207746914454866, 51.27648271833147, 48.29084178379604, 35.1887800352914, 16.808348996298655, 12.63904161112649, 4.5544538497924805, 6.329078921249934, 9.936779482024056, 6.878391776766096, 2.5869200783116475, 0.22868017054029874, 0.1936223153024912, 0.5886536645037788, 9.59205937385559, 32.11822516577584, 45.72708851950509, 45.03606932503836, 33.22795670373099, 39.38183723177229, 54.43543604442051, 38.63257128851754, 8.692577719688416, 0.2815336787274906, 0.0327869410227452, 0.07157647423446178, 0.02024583611637354, 0.0731547534731882, 0.05435749462672642, 0.06500842488769974, 0.026884765231183598, 0.05573514802381396, 0.04369574512488075, 0.045111355770911486, 0.03460851917043328, 0.06861687411687203, 0.011762891397146242, 0.026368476417181746, 0.04563259619421192, 0.036060831775622706, 0.05096358459975038, 0.07655225973576307, 0.03243774654609816, 0.02905367188421743, 0.141037466270583, 0.1585938406309911, 0.15794332910861286, 0.1428081305431468, 0.1310059909841844, 0.12803338335028716, 0.1608267772410597, 0.16798773727246694, 0.12175829149782658, 0.11628463092659201, 0.1674617776381118, 0.10059555101075343, 0.09792079989399229, 0.12616074883512088, 0.13950742408633232, 0.20365744110729012, 0.11854922798063074, 0.13533173315227032, 0.12466582762343542, 0.07519647891500167, 0.128578070551157, 0.17469338673566068, 1.1049570398671287, 17.475178037370952, 47.61932618277413, 57.75004986354283, 46.419618947165354, 32.93807438441685, 40.378570216042654, 38.01474094390869, 35.05647938592093, 9.841585687228612, 1.2587828827755791, 0.17278673047465937, 1.4472740484135491, 3.7453070282936096, 7.063378010477338, 11.056585039411273, 6.390634749616895, 9.35030027798244, 12.939731853348867, 27.219884123120988, 43.20677539280483, 52.33559315545218, 46.75943796975272, 45.20729725701468, 42.59912068503243, 47.00029032570975, 46.33748776572091, 51.77092695236206, 48.35537665230887, 45.974308899470735, 48.49675859723772, 47.969438961574006, 46.768870149339946, 48.38050481251308, 49.01562227521624, 47.90067958831787, 45.08348035812378, 43.01014484677996, 39.12812723432268, 36.3556535584586, 35.087982518332346, 35.03709391185215, 32.94315699168614, 37.602816990443635, 40.75421067646572, 43.2105586869376, 44.61509534290859, 41.5424108505249, 36.94960641860962, 36.61732619149344, 35.13599109649658, 34.39618165152413, 34.40316111700875, 34.43231923239571, 34.92966433933803, 41.08757829666138, 50.030184337071006, 50.13670369556972, 48.373844964163645, 49.51992947714669, 47.89239386149815, 49.85117442267281, 44.94317190987723, 46.53220755713326, 45.136008739471436, 46.7653717313494, 33.28924328940255, 41.47627789633614, 48.959616320473806, 43.20217915943691, 36.73946510042463, 39.24242510114397, 39.48311764853341, 40.66553776604788, 42.03729282106672, 40.16716432571411, 38.63169581549508, 35.48720516477312, 36.68244123458862, 34.48245048522949, 35.16209895270211, 35.02160290309361, 34.082651138305664, 35.68447494506836, 33.84391450881958, 35.19817747388567, 38.30435923167637, 41.35425015858242, 42.36000885282244, 44.54963288988386, 43.45676462990897, 43.7650978905814, 41.39810023988996, 43.079505239214214, 43.42676230839321, 45.42683253969465, 46.473922593253, 46.83407204491751, 48.66235154015677, 47.90854147502354, 45.768385137830464, 49.80635159356253, 51.855712345668245, 50.458516461508616, 39.431020055498394, 39.05443811416626, 45.53347001756941, 46.89257935115269, 48.70942211151123, 49.52049575533186, 51.240272181374685, 52.96573223386492, 51.456614766802105, 35.19874027797154, 16.900539432253154, 18.487563576017106, 22.198803152356827, 24.641055004937307, 21.092302526746476, 10.193845459393092, 4.191582875592368, 0.8710920204009328, 0.4749286983694349, 1.0515184445040566, 10.911096709115164, 38.65939828327724, 53.13082143238613, 51.585861682891846, 41.48724215371268, 46.11150802884783, 64.03431333814348, 47.42810480935233, 11.599459954670497, 0.4388060452682631, 0.11446602136961051, 0.13886007453714097, 0.16855398831622942, 0.1577718768801008, 0.10261174317981515, 0.17868024137403282, 0.1370277992848839, 0.14609445205756597, 0.13438016921281815, 0.14942193350621633, 0.18154873459466866, 0.07915571039276463, 0.052415697037109306, 0.14687274529465608, 0.10892604078565325, 0.125016969495586, 0.12052536622754165, 0.20406062661537103, 0.08860055144344058, 0.1278380738305194], [0.05552765880046146, 0.022331294836476445, 0.041065051286880455, 0.020033424121460745, 0.05745411132063184, 0.08986448576407773, 0.06310292892158031, 0.04436167974823287, 0.033832136009420664, 0.037375110001968484, 0.07527494470455817, 0.06907987248684679, 0.0033124455367214978, 0.029741027858108282, 0.016330539781068052, 0.057839152802314074, 0.05271374693672572, 0.014910578029230237, 0.044821332940565686, 0.05797163676470518, 0.03485300890835268, 0.08179730150316443, 0.32005658160362926, 8.919164555413381, 34.31500584738595, 48.01165621621268, 38.24760634558541, 31.848332813807897, 28.74813345500401, 39.479685238429475, 27.67910967554365, 11.010273558752877, 1.0653773865529468, 0.18603549312267983, 0.3153063479278769, 1.58613412295069, 5.387918063572474, 6.847622982093266, 6.691998967102595, 11.551484380449567, 11.135839666639056, 22.312663282666886, 37.945755754198345, 46.18986633845738, 43.526180607931956, 41.18174723216465, 41.978597913469585, 45.621441159929546, 47.289116518838064, 45.90167243140084, 46.57187829698835, 46.31601783207485, 43.500437532152446, 43.381602491651265, 44.89994369234358, 47.12531968525478, 44.34622090203421, 45.471057823726106, 42.7953656060355, 40.856519426618306, 34.47886174065726, 32.753036907741, 30.878381661006383, 31.40006630761283, 34.287376335689, 37.28071240016392, 42.15605837958199, 46.8568308694022, 46.75534895488194, 44.785753522600444, 42.374429838997976, 35.78807953425816, 31.807296752929688, 32.12005254200527, 31.255800860268728, 31.40841109412057, 30.891440800258092, 33.980495248522075, 41.14736754553658, 45.164478983197895, 43.22594199861799, 46.22446141924177, 44.425993170057026, 46.67539255959647, 44.142579623631065, 45.53176423481533, 42.45051261356899, 48.79329034260341, 29.906165395464214, 34.66296468462263, 48.953793730054585, 37.85745457240513, 42.11489030293056, 36.78686571121216, 40.541449887411936, 39.95466409410749, 41.96578890936715, 38.65669890812465, 37.993510723114014, 31.08026157106672, 31.264882155827113, 32.4120888028826, 32.35172632762364, 30.89448411124093, 32.21990510395595, 31.492084775652202, 32.127285616738455, 31.736904553004674, 33.44211755480085, 31.762543405805314, 30.773258890424454, 31.26641423361642, 34.2147433417184, 36.03369140625, 32.407944202423096, 32.5457478250776, 32.5007895060948, 36.52853168760027, 40.12972395760672, 40.928395066942485, 44.44874504634312, 46.46135330200195, 45.23839044570923, 45.88453469957624, 47.82698004586356, 45.10832364218575, 35.302567209516255, 35.1548033441816, 38.39978231702532, 43.34021554674421, 44.240062849862234, 45.89252165385655, 46.095655713762554, 49.936150891440256, 45.84158788408552, 34.07099553516933, 16.25090718269348, 8.483999746186392, 1.3655090587479728, 4.239582768508366, 3.6193392276763916, 6.772539445332118, 1.4485094164099013, 0.21199921491955007, 0.19877965641873224, 0.8419616978083337, 10.316739984921046, 33.46830184119088, 39.42928300585066, 27.680375984736852, 33.52488102231707, 40.53136805125645, 44.40391526903425, 28.766707726887294, 7.310076407023838, 0.3015773860471589, 0.06478209274687938, 0.017856134168271507, 0.01650173925528569, 0.02319028115432177, 0.006760578145206506, 0.0509127725048789, 0.043699643308562894, 0.044953687981303246, 0.0291339629329741, 0.03631810850596853, 0.01355897868052125, 0.06382454412856273, 0.03114582265594176, 0.031682520106967, 0.07033529797835009, 0.03648729782019343, 0.024499947038878287, 0.016640190933165804, 0.08247642684727907, 0.029339131566562822, 0.04009157745167613, 0.024660766623648148, 0.06800522908036198, 0.052001431052173884, 0.050964225815343, 0.0579583714050906, 0.05716515039759023, 0.019361282599025538, 0.05275440814771822, 0.00248841310219307, 0.05409341219014355, 0.08838584939283983, 0.07031408697366714, 0.051250157079526355, 0.03410223026626876, 0.08523836292858634, 0.03257288697308727, 0.022705186291464736, 0.07735440347875867, 0.06825846513467175, 0.020215997538928474, 0.04603618882330401, 0.30616311569299015, 11.81215386731284, 39.7366852079119, 53.02610513142177, 42.02401828765869, 35.94555698122297, 33.953671727861675, 36.461408615112305, 33.385309083121165, 12.333885414259774, 1.162447412099157, 0.10845314937510661, 0.13521023467183113, 1.0864610437835966, 5.493621442999158, 6.5096995149339945, 11.229484013148717, 9.323798980031695, 12.099646874836512, 23.38660638672965, 40.004958629608154, 49.40411342893328, 46.25744799205235, 42.58763531276158, 43.16642025538853, 47.39289133889334, 48.390221868242534, 47.292660100119456, 46.17806829724993, 48.38270044326782, 45.1760060446603, 45.5126497404916, 47.343072754996165, 47.83846194403512, 46.53003624507359, 47.10398871558053, 43.8812370300293, 41.898335797446116, 36.40523590360369, 34.06689262390137, 32.40934426443917, 32.551646845681326, 34.83096865245274, 38.173496859414236, 43.25755282810756, 48.50314399174282, 48.132770265851704, 47.942632811410085, 43.62966012954712, 36.29088592529297, 34.28227983202253, 33.93946960994175, 32.80240385872977, 32.38221502304077, 32.69087832314627, 35.95692423411778, 44.270968437194824, 46.92403384617397, 46.52196591241019, 48.02730008534023, 47.18073851721627, 47.76606866291591, 46.976336411067415, 47.80393634523664, 44.60695205415998, 48.95943914140974, 31.193499837602886, 36.626970291137695, 51.68416479655674, 39.806632723127095, 42.67021812711443, 38.31438200814383, 41.526506423950195, 41.77864612851824, 43.1326242174421, 40.85504988261631, 40.32533311843872, 32.45836727959769, 31.906148774283274, 33.35717582702637, 33.284695693424766, 32.946558134896414, 33.52008329119001, 33.132752486637656, 33.780856132507324, 33.63651772907802, 34.595824241638184, 32.71844530105591, 32.752887521471294, 34.04968541009085, 36.17070640836443, 36.719923291887554, 33.76020608629499, 34.674922534397666, 34.82115432194301, 39.58618722643171, 41.2534943308149, 42.15010724748884, 45.376155853271484, 47.23930140904018, 45.66898768288748, 47.27263191768101, 49.056592328207834, 46.77197599411011, 37.08590228216988, 37.330485820770264, 41.170994894845144, 44.36295563834054, 46.58284602846418, 47.2899364062718, 49.37626504898071, 51.70923737117222, 47.41341284343174, 34.237828731536865, 17.62201258114406, 9.00470643384116, 6.505719065666199, 9.567748495510646, 10.289053150585719, 6.860366412571498, 1.6999413818120956, 0.27488322130271364, 0.19545362703502178, 1.2832437987838472, 11.138047456741333, 36.698547158922466, 46.145008768354145, 34.74308088847569, 37.42358820778983, 44.74235854830061, 51.6799715587071, 35.77937344142369, 7.793043954031808, 0.24515576075230325, 0.02797076222486794, 0.02108538749494723, 0.023835483140179088, 0.03325563230152641, 0.044097705877252986, 0.031066437451434985, 0.05029739552576627, 0.09848720021545887, 0.034293224303317923, 0.08779852305139814, 0.038715925732893605, 0.007764129317365587, 0.06035000378532069, 0.01200915635230818, 0.05546305887401104, 0.02485746544386659, 0.03565189568325877, 0.018779506674036384, 0.04947316546791366, 0.052356956260544915, 0.15246916642146452, 0.09174070972949266, 0.12754462100565434, 0.18872595232512268, 0.199178580726896, 0.1269394899053233, 0.11704851207988602, 0.09861662398491587, 0.11834589817694255, 0.12143802296902452, 0.15814667248300143, 0.2640271224081516, 0.08963122578071696, 0.09156856539526156, 0.11216308708701815, 0.23221023540411675, 0.09445524335439716, 0.2660999654659203, 0.12318860260503632, 0.09620371953185115, 0.16520430520176888, 0.12428624156330313, 0.554611508335386, 13.692497951643807, 45.948576245989116, 60.03688962118966, 48.719125270843506, 42.53812592370169, 39.35382209505354, 47.688276631491526, 37.29426138741629, 14.586459262030465, 1.7006503151995795, 0.3960454197866576, 0.8162840870874268, 3.9327768087387085, 8.646549378122602, 12.616010069847107, 17.108990601130895, 20.511195148740494, 15.558949981416974, 26.280416454587662, 40.62936544418335, 50.62846939904349, 47.31294189180647, 44.56648227146694, 45.61460760661534, 50.61584104810442, 50.115379674094065, 47.27445234571184, 46.88753843307495, 50.24368858337402, 47.65082236698696, 46.43831654957363, 48.49224574225289, 49.39527532032558, 47.479674339294434, 50.16070624760219, 47.7885981968471, 44.984767300742014, 37.72002962657383, 36.46515022005354, 33.493864263807026, 34.474616391318186, 37.08331407819475, 40.14117806298392, 45.913470472608296, 52.102894510541645, 50.491298062460764, 50.063764980861116, 47.096870286124094, 39.90333775111607, 37.086857659476145, 36.105375971112935, 35.102017879486084, 33.68289000647408, 34.691771915980745, 38.53001240321568, 45.4973498071943, 49.081237588609966, 50.04734986168997, 50.18324620383126, 49.06113645008632, 49.86559540884835, 48.664293561662944, 48.948443617139546, 47.081837858472554, 48.865311895098, 35.58597033364432, 40.03877203805106, 53.170332363673616, 43.31557376044137, 45.378684997558594, 41.08984688350132, 44.610485213143484, 45.21261957713536, 45.328567641122, 43.06953457423619, 41.613115719386506, 33.385746819632395, 34.21887404578072, 35.54265873772757, 34.54238564627511, 34.53073351723807, 35.73702417101179, 35.722717830113, 36.717171805245535, 35.03821952002389, 37.74235071454729, 34.77080767495291, 34.51802526201521, 34.376660687582834, 37.85247966221401, 38.147941384996685, 35.478947230747764, 35.32906763894217, 37.08800411224365, 41.92513847351074, 44.956717423030305, 44.35801894324166, 47.406871114458355, 48.02213409968785, 45.905028411320274, 47.51415130070278, 50.957966872623985, 48.81709834507534, 38.721494334084646, 39.39398963110787, 43.7025397845677, 48.10844809668404, 49.26001821245466, 49.26896401814052, 51.178249086652485, 54.9248046193804, 50.71727432523455, 38.007872649601524, 19.79246653829302, 11.385549238749913, 6.107786178588867, 14.485979625156947, 11.33084259714399, 16.367143596921647, 4.560401942048754, 0.8987584444028991, 0.6110377748097692, 1.4568615853786469, 13.821746604783193, 42.02769388471331, 50.7863324710301, 38.9428083556039, 44.283770493098665, 53.938264642442974, 59.158755438668386, 42.9937401499067, 10.918977703366961, 0.5532660005348069, 0.1097023052030376, 0.07804716737674815, 0.09684492833912373, 0.10046821034380368, 0.11777366245431559, 0.17389295968626226, 0.16465876304677554, 0.1960027382842132, 0.1275072337261268, 0.14201158471405506, 0.1031906624723758, 0.20471846631595067, 0.13995160668023995, 0.09192045365593263, 0.14330742375126906, 0.1124984665906855, 0.11927425621875695, 0.10480375055755888, 0.19374834639685495, 0.1285712987716709], [0.02550834507149245, 0.02585431820313845, 0.04039871632786734, 0.005350517491543931, 0.07259840225534779, 0.01473879162222147, 0.06399693952075072, 0.0370314625490989, 0.03360378861959491, 0.019262479418622594, 0.04575837962329388, 0.05309355352073908, 0.02799780523803617, 0.03373981453478336, 0.0072969401454819095, 0.031885035668632815, 0.026524137439472333, 0.022491602127307227, 0.012062425592115946, 0.03350256476551294, 0.019963908208800212, 0.0587492718228272, 0.26492745695369585, 7.311949815068926, 35.455444949013845, 46.065396308898926, 41.569210052490234, 24.453535284314835, 27.83362545285906, 46.89139468329293, 28.897575310298375, 15.486878054482595, 1.1762492486408778, 0.19725041490580353, 0.26410490966268946, 0.6854597127863339, 3.226663304226739, 6.537402851240976, 8.69306148801531, 3.509332307747432, 9.099184564181737, 18.414574486868723, 35.48133741106306, 47.25548723765782, 43.72534377234322, 41.106494767325266, 43.56160599844796, 46.97884818485805, 47.277394907815115, 46.90077127729143, 46.066219670431956, 40.89769097736904, 40.371566431862966, 41.62116868155343, 43.154976572309224, 45.466041224343435, 43.4822610446385, 43.726632663181846, 43.807909216199604, 38.78300673621041, 37.24427604675293, 32.0077349117824, 31.396970885140554, 32.39478778839111, 33.277990681784495, 37.01777866908482, 41.941838468824116, 47.267448561532156, 46.771347182137625, 46.06989179338728, 44.594313280923025, 44.21067544392177, 36.30601910182408, 32.982351779937744, 31.456937313079834, 31.220827102661133, 32.22398369652884, 32.59897102628435, 32.36271142959595, 38.89271184376308, 40.27327026639666, 41.81310224533081, 40.92295462744576, 45.2710782459804, 41.838650771549766, 46.57357018334525, 41.453890800476074, 50.89994594029018, 32.952168805258616, 34.32822132110596, 48.3190028326852, 38.932545866285054, 42.66462482724871, 41.33530936922346, 42.81535904748099, 42.244533266339985, 44.654588903699604, 41.76638950620379, 41.834217820848735, 37.32540321350098, 32.390910693577354, 32.041086265019004, 31.66627958842686, 30.760015623910085, 31.96461091722761, 35.20030014855521, 33.65456567491804, 32.79455239432198, 33.414866719927105, 32.53636775697981, 32.066384656088694, 32.722430092947825, 33.126037052699495, 34.104878425598145, 32.90590769904, 34.27354942049299, 33.305936336517334, 33.75876433508736, 36.94159861973354, 41.9512254851205, 42.75506952830723, 47.08776119777134, 45.642278807503835, 44.34413991655622, 46.28828409739903, 46.72933489935738, 38.11116804395403, 32.89789295196533, 35.990869658333914, 38.82624190194266, 41.05024562563215, 43.93292120524815, 47.10851199286324, 49.84101268223354, 42.325910568237305, 30.326785019465856, 12.862566896847316, 8.625008225440979, 4.755705382142748, 1.9168201727526528, 9.604117103985377, 4.826925720487322, 2.0017681973321095, 0.21116430472050393, 0.08498824813536235, 0.8402693229062217, 10.705077409744263, 30.193685327257427, 35.77733761923653, 30.517471381596156, 33.61444330215454, 45.55212593078613, 45.36875949587141, 31.25009638922555, 7.686739121164594, 0.045191867343549214, 0.03057593127180423, 0.026973936606996825, 0.023471472851399864, 0.0485899232194892, 0.019649240986577103, 0.0482251461861389, 0.0160144120122173, 0.02962041486586843, 0.05953798057245357, 0.040360358743263144, 0.02103282986874027, 0.010241514105083687, 0.00631098381044077, 0.061865586388323984, 0.005768872074051095, 0.04630208634106176, 0.028187209806804146, 0.04332881035017116, 0.06782210604952914, 0.010914375722807432, 0.032031965641570945, 0.01956300766739462, 0.02375057466062052, 0.03140462948275464, 0.08130790812096425, 0.012412592070177197, 0.02797174610064498, 0.02244571958934622, 0.04732675225074802, 0.018718740470441322, 0.017454907930056964, 0.01999964495189488, 0.023440131318888495, 0.03766151963333998, 0.031218025567276136, 0.03474394118945513, 0.03246270984943424, 0.01846509729512036, 0.02626291842066816, 0.04161483767841544, 0.06482828062559877, 0.06111990354423012, 0.31657656548278673, 8.93094435759953, 40.62891728537423, 51.25308118547712, 46.62019606998989, 30.270313535417827, 29.49841730935233, 49.37196411405291, 33.13201597758702, 16.207675491060527, 1.9124410705907005, 0.06335487575935465, 0.16715615189501218, 0.7006447836756706, 4.767487355640956, 6.807986983231135, 7.926141909190586, 5.767078655106681, 11.455529757908412, 26.348896162850515, 36.6429511478969, 51.22110904966082, 44.59221839904785, 44.53506946563721, 45.126739842551096, 48.411386081150596, 47.7158123425075, 47.712209701538086, 48.29909971782139, 44.054514680589946, 42.893098967415945, 44.434171199798584, 43.50055912562779, 47.88094670431954, 44.93624108178275, 46.74902956826346, 45.7066399710519, 41.105532441820415, 39.17587178094046, 34.054413659232004, 32.25195714405605, 34.01391608374459, 34.70067950657436, 38.99171325138637, 44.36185087476458, 48.876873697553364, 47.59064401899065, 48.12697894232613, 47.38628707613264, 45.869505746024, 37.35102122170584, 35.59785175323486, 33.27763979775565, 33.021748065948486, 33.5669002532959, 33.77989728110177, 34.500185762132915, 42.3003967830113, 42.39998531341553, 44.80046285901751, 44.07846164703369, 47.70133924484253, 44.5614344051906, 47.737358706338064, 43.694201946258545, 51.231020654950825, 34.712362902505056, 35.83731099537441, 48.7905319077628, 40.20812395640782, 43.99649722235543, 42.807938371385845, 44.634977613176616, 44.04235533305577, 47.41002559661865, 43.559879371098106, 43.57444626944405, 36.88775702885219, 33.33431625366211, 33.35732521329607, 33.57688134057181, 32.63115855625698, 33.26164851869856, 36.724939891270225, 35.06619644165039, 34.62365525109427, 34.223303522382466, 34.67952224186489, 33.39584255218506, 34.47725670678275, 35.188720975603374, 36.58831746237618, 33.81577777862549, 34.79552936553955, 34.78582968030657, 35.6988195010594, 39.192509242466514, 43.95449536187308, 44.60791437966483, 47.876173291887554, 45.30829627173287, 44.85005562646048, 49.57949985776629, 48.72296415056501, 40.37347371237618, 35.03404017857143, 38.47409330095564, 41.17981563295637, 44.05944095339094, 46.27258811678205, 49.38263654708862, 50.36010912486485, 46.11970690318516, 31.124931539808, 16.118015936442784, 10.42052696432386, 7.443273374012538, 10.430954473359243, 10.094086698123387, 7.119380925382886, 3.519901603460312, 0.25241643829005106, 0.06886211702866213, 0.9488438282694135, 12.011804274150304, 37.237240995679585, 40.83936085019793, 33.148340770176475, 36.24231801714216, 50.44037471498762, 53.06134639467512, 37.72827019010271, 9.082054649080549, 0.02401511850101607, 0.08569810433047158, 0.0228485335995044, 0.05563716756712113, 0.03479306373213019, 0.04392828925379685, 0.02474232144387705, 0.009897527384704776, 0.01683431980200112, 0.0287245077613209, 0.030639245374394313, 0.05331382295116782, 0.028410614069019045, 0.06827556421714169, 0.08528294946466174, 0.05919329835368054, 0.040905758405902555, 0.021955298226592795, 0.010519302100874484, 0.024177563177155595, 0.030254512626145567, 0.1370216246162142, 0.12004923820495605, 0.08609383273869753, 0.11075760357614074, 0.13423940033784934, 0.1094299548172525, 0.20217716268130712, 0.13318864814937115, 0.1501597724854946, 0.07231795016144003, 0.09491181599774531, 0.12711893527635507, 0.04986071752916489, 0.12632012314030103, 0.09706632753035851, 0.15152581275573798, 0.08984790915357214, 0.07336382368313414, 0.12678565244589532, 0.11113494368536131, 0.14201480097004346, 0.19055347783224924, 0.6022723508732659, 11.660730038370405, 45.63608448845999, 57.05402101789202, 53.66806309563773, 35.78493200029646, 37.97662660053798, 55.20897899355207, 37.833403382982524, 19.76703613145011, 2.237181850842067, 0.39292635715433527, 0.45386944125805584, 2.2514753809997012, 6.967949279717036, 12.535025341170174, 17.33019518852234, 7.723103387015207, 10.492727432932172, 20.738653114863805, 40.608326298849924, 50.65495245797293, 48.279439789908274, 45.27832521711077, 48.487604345594136, 49.99216379438128, 48.09445442472185, 49.01463563101632, 49.99465472357613, 43.91557502746582, 45.20083890642439, 45.36596632003784, 45.60439028058733, 47.82449606486729, 46.49181767872402, 47.539109230041504, 48.93792404447283, 43.005982875823975, 42.083567823682515, 35.097498076302664, 34.11899716513497, 36.09522465297154, 36.176216329847065, 41.03336150305611, 46.17297874178205, 50.37949807303292, 47.96017006465367, 49.18237556729998, 49.119661126817974, 48.48696858542306, 40.283171449388774, 36.97942808696202, 35.233946800231934, 34.98077528817313, 36.59451872961861, 36.218774046216694, 35.20853723798479, 43.47183179855347, 43.58600459780012, 46.942849567958284, 46.786087785448345, 48.42013038907732, 44.92372737612043, 50.14189747401646, 46.492696625845774, 52.68602555138724, 36.585517338344026, 39.62005969456264, 50.4977251461574, 43.15604312079293, 47.14557021004813, 45.528467314583914, 46.37056466511318, 48.22193997246878, 48.81795992170061, 45.9775641305106, 45.08214977809361, 40.56553929192679, 36.45948396410261, 34.82767868041992, 35.63053955350603, 34.38738523210798, 35.51238196236746, 37.92616878237043, 37.17430421284267, 36.42927667072841, 36.10518836975098, 37.366811003003804, 34.320116247449604, 37.01593392235892, 37.59241206305367, 37.93347133908953, 36.85322100775582, 37.15829903738839, 37.103734833853586, 36.645490714481895, 41.85404450552804, 46.56867517743792, 47.337215423583984, 50.36267301014492, 46.42024081093924, 45.63234635761806, 50.74775259835379, 51.5064993585859, 42.670694078717915, 36.22395045416695, 39.81376852308001, 42.942167145865305, 46.150563853127615, 48.49090126582554, 51.95854915891375, 54.27155235835484, 47.350052220480784, 34.10296767098563, 16.413029500416346, 13.279745425496783, 10.017715573310852, 9.699480261121478, 20.018793685095652, 7.433142031942095, 5.982870161533356, 0.7311439556734902, 0.19002903811633587, 1.3683124397482191, 13.908343740871974, 41.10845068522862, 49.03651203427996, 41.11749723979405, 45.03876175199236, 56.86747925622122, 61.28573104313442, 45.4141138621739, 10.650034649031502, 0.14638426793473108, 0.14988447725772858, 0.07645884581974574, 0.12528904846736363, 0.10405542821224247, 0.14479770378342696, 0.16007882809000357, 0.06411473319998809, 0.07225716020911932, 0.14369565434753895, 0.08914819027164153, 0.10158621892333031, 0.09049859030970506, 0.2618199294166905, 0.187165891751647, 0.0950593159400991, 0.08890190920127289, 0.10627028186406408, 0.1168377183909927, 0.1468877952013697, 0.13122063875198364], [0.01901207964069077, 0.0384673206800861, 0.004565149678715638, 0.018788709305226803, 0.007863905347351517, 0.02704382062490497, 0.07675990502216987, 0.020881553879007697, 0.05842463352850505, 0.046752063624028645, 0.0586733166128397, 0.029808871181947843, 0.0645741828318153, 0.07177614673439946, 0.0913456937830363, 0.08554491147931133, 0.04094215841697795, 0.06256643163838557, 0.045720585222755156, 0.003884604075990085, 0.014980914969263332, 0.045884916226246526, 0.05945747239249093, 7.627698540687561, 33.890679359436035, 49.556817463466096, 45.64256368364607, 38.65610831124442, 33.261447020939414, 33.33894027982439, 35.93209832055228, 18.35022027151925, 3.605675160884857, 0.0851769894361496, 0.25510251415627344, 0.6968008556536266, 5.668840246541159, 6.206306857722146, 9.175381984029498, 6.556347983224051, 9.069646034921918, 21.047557864870342, 31.5072283744812, 45.09735591070992, 45.55043404442923, 44.986028398786274, 45.47091885975429, 49.48725209917341, 42.94283069883074, 44.40291125433785, 43.9076714515686, 41.266789708818706, 38.2833548273359, 38.992564405713765, 38.87520238331386, 45.208332538604736, 44.7382938521249, 46.391714981624055, 43.251209122794016, 40.66165024893624, 35.698027406420024, 30.584663936070033, 29.36978530883789, 30.299666200365337, 31.07193762915475, 34.44496842793056, 41.01243352890015, 42.80041694641113, 45.06875365121024, 46.41263600758144, 45.54829052516392, 43.47506618499756, 41.99660069601876, 35.95738281522478, 30.720258031572612, 31.938916478838237, 31.437388556344168, 31.72346326283046, 29.997159004211426, 33.001688616616384, 34.82362788064139, 37.72361837114607, 37.342843191964285, 41.610680375780376, 41.51344381059919, 43.137672083718435, 39.454595293317524, 48.05162920270647, 36.13007681710379, 32.60829550879342, 48.34422826766968, 41.781838825770784, 46.89897864205496, 42.73026098523821, 47.403595038822715, 43.66849708557129, 46.655857699257986, 44.000138078417095, 44.31649303436279, 42.14433676855904, 34.78814343043736, 30.67678315298898, 32.03198759896414, 31.29428345816476, 33.33942665372576, 32.124482018607004, 35.34745257241385, 34.94169167109898, 34.76768445968628, 33.46374382291521, 32.042409896850586, 30.6162018094744, 32.35492249897548, 32.134754930223735, 33.136619159153526, 33.32885149547032, 32.84117133276803, 33.546444756644114, 37.12475313459124, 40.22772829873221, 42.14068896429879, 47.09400415420532, 48.578886304582866, 44.31445026397705, 45.52120644705636, 44.24749394825527, 43.76181834084647, 37.740294047764365, 34.17909213474819, 38.78856182098389, 40.68340853282383, 43.058309759412495, 46.93393850326538, 49.80986043385097, 42.392370087759836, 25.493022271565028, 13.529213547706604, 5.831603969846453, 10.990709168570381, 13.604021327836172, 9.33108937740326, 10.494915246963501, 2.224337237221854, 0.11454033452485289, 0.07676499403480973, 1.3879239474024092, 12.957508819443838, 35.7533837045942, 43.60921852929251, 36.52746513911656, 29.6267957006182, 44.36650964191982, 46.92070913314819, 31.37696007319859, 5.337695615632193, 0.04268616304865905, 0.011064791669403868, 0.05265332678599017, 0.018916377365323048, 0.07439229956695012, 0.026500521028148274, 0.02885245910978743, 0.02087763194659991, 0.05137240194848605, 0.029347138279782872, 0.02256598143971392, 0.02931591888357486, 0.0455062461883894, 0.018407666091141955, 0.07308292375611407, 0.07056455460510083, 0.010600543946826031, 0.01733748065972967, 0.0491307088440018, 0.03618726659832256, 0.022875652947862233, 0.005948291151850883, 0.043435245353196344, 0.01869351932379816, 0.016723145231870667, 0.029220601676830223, 0.056998251139053276, 0.03858928056433797, 0.007495875586755574, 0.04419023769774607, 0.040402227746588845, 0.016834141686558723, 0.0517384105228952, 0.033501258585602045, 0.018607265648565123, 0.06104500006352152, 0.03419671626761556, 0.07809857997511115, 0.05500783651535, 0.09328076030526843, 0.05355073006025382, 0.015802096708544662, 0.022832949346463596, 0.11462710558303765, 8.728895953723363, 38.40695285797119, 54.533916337149485, 50.894811221531455, 40.33329227992466, 34.68462221963065, 40.6743619782584, 40.8788856778826, 20.571875504084996, 3.5874641495091573, 0.18561097447361263, 0.05879159883729049, 0.24097487223999842, 4.729932342256818, 7.111000095094953, 6.634264213698251, 6.063371121883392, 8.891701800482613, 23.728487287248882, 33.10117292404175, 47.4210558618818, 48.03901822226388, 45.51407412120274, 47.59757832118443, 51.171551023210796, 43.302636214665, 46.58628191266741, 46.691307408469065, 43.22536877223423, 39.99415070669991, 40.80318852833339, 42.46934223175049, 46.771913460322786, 45.933029651641846, 47.352094990866526, 45.73332800183977, 42.24627031598772, 37.98868172509329, 31.63811159133911, 31.397582326616558, 32.212943008967805, 32.606134619031636, 35.790441921779085, 41.25112846919468, 45.90318366459438, 46.40932519095284, 47.826087202344624, 48.206782477242605, 46.12092978613717, 44.63741643088204, 37.58307368414742, 33.18031638009207, 33.972768851688926, 32.59513562066214, 33.59344237191336, 31.591937337602886, 34.23184980664934, 37.840897015162874, 39.877327169690815, 40.8474555015564, 44.73922143663679, 42.752328463963096, 45.878646101270405, 42.335179465157644, 50.19504771913801, 38.591733251299175, 35.38881172452654, 49.05952794211251, 43.74817207881382, 46.92040688650948, 43.86635051454817, 47.47615507670811, 45.87209047589983, 47.76414053780692, 44.93638004575457, 46.478803702763145, 42.78256702423096, 36.67997462408883, 31.639053072248185, 33.02689668110439, 33.15098108564104, 33.681152956826345, 34.22430406297956, 35.314108167375835, 34.83020087650844, 36.5218996320452, 34.04124682290213, 33.48417847497122, 32.69037457874843, 33.57024928501674, 33.16718775885445, 34.07853433064052, 35.66848019191197, 35.22510869162423, 35.44532489776611, 40.05853966304234, 42.362739494868684, 44.81719759532383, 48.887316840035574, 49.512140546526226, 44.61742646353585, 47.72399732044765, 47.82003879547119, 44.78523588180542, 38.80679389408657, 36.75789867128645, 41.010098934173584, 42.99769367490496, 45.84308522088187, 50.02600152151925, 52.221548897879465, 45.7723525592259, 29.121748515537806, 15.332176412854876, 10.034550189971924, 10.572801079068865, 13.712336795670645, 7.551801630428859, 5.935631964887891, 1.1785941570997238, 0.03590248205832072, 0.054134324459092956, 1.3769322229283196, 13.878759179796491, 39.47972692762102, 48.497001784188406, 40.83800942557198, 35.67641503470284, 50.075156552451, 53.91763891492571, 37.041263580322266, 7.282579779624939, 0.10509206008698259, 0.006334016681648791, 0.029804755867059742, 0.023670697518225228, 0.03193056197570903, 0.01092103893669056, 0.02713983502638127, 0.0414567661604711, 0.022521579804431115, 0.012805526610463858, 0.008322232003722872, 0.037770553425486596, 0.05792185265038695, 0.06584511963384491, 0.005556049565452018, 0.08251222635486297, 0.034502915372805934, 0.05248396783801062, 0.06614212119685751, 0.00521098991157487, 0.02113773307896086, 0.13485513015517167, 0.1698580783392702, 0.07080411139343466, 0.10878224564450127, 0.14558655502540724, 0.2590924900557314, 0.14860879071056843, 0.0773581557774118, 0.08740504059408392, 0.1768744561289038, 0.14624641676034245, 0.12612465077212878, 0.16146698860185488, 0.25243863995586124, 0.23914839167680058, 0.14650811414633477, 0.1412108726799488, 0.15304412985486643, 0.19716555731637136, 0.07640067501259701, 0.0999105970508286, 0.10737096065921442, 0.25536043888756205, 10.530834828104291, 43.808767318725586, 60.347550528390066, 57.02560635975429, 49.09195865903582, 43.343415192195344, 44.639737129211426, 46.29416922160557, 25.031663622174943, 5.124590456485748, 0.47541219528232304, 0.43378798024994986, 1.5117226072720118, 13.168315427643911, 14.38741682256971, 16.65760956491743, 14.0239383152553, 13.453490342412676, 27.61226453099932, 33.28320530482701, 48.91099977493286, 49.58512095042637, 49.42013250078474, 50.002151829855784, 52.12161990574428, 45.362134388514924, 48.722665378025596, 47.56226757594517, 46.246984004974365, 40.98749644415719, 42.734707832336426, 43.532079628535676, 50.15572786331177, 47.52448327200753, 49.35406902858189, 47.63466433116368, 44.72916044507708, 40.14700412750244, 33.256423473358154, 32.736406394413535, 33.33434404645647, 34.709309169224326, 37.326000758579795, 44.91565356935774, 47.206613608769004, 48.028126920972554, 48.928074972970144, 49.83474540710449, 48.40918002809797, 46.63012504577637, 39.69159139905657, 35.23313733509609, 35.68515239443098, 35.370207922799246, 35.253988879067556, 32.98643732070923, 36.086407388959614, 39.073976448604036, 41.21811410358974, 42.05815826143537, 45.46524912970406, 44.9107620375497, 46.59856980187552, 43.761328492845806, 52.93637262071882, 40.69843053817749, 39.10263081959316, 50.707762241363525, 46.227577686309814, 48.92475025994437, 47.15848691122872, 51.5662191254752, 48.201724188668386, 50.591713428497314, 47.77504920959473, 47.51911578859602, 45.591796670641216, 38.299884591783794, 33.837907791137695, 35.07731008529663, 34.99052013669695, 36.73469168799264, 34.97886105946132, 38.25501312528338, 37.40195151737758, 38.60052967071533, 36.43387290409633, 35.573345456804546, 35.117189271109446, 35.8630610193525, 35.08620030539376, 35.26605790002005, 36.63854946408953, 36.82261071886335, 38.27606269291469, 42.15132665634155, 44.73852661677769, 45.92828055790493, 50.6396837915693, 49.583682673318044, 45.27692168099539, 48.22402443204607, 49.87398188454764, 48.49032456534249, 42.43530995505196, 38.58232191630772, 42.57772718157087, 45.530200890132356, 49.098580292293, 52.68316636766706, 55.23656334195818, 48.49173157555716, 30.722106252397808, 18.022560596466064, 10.932004707200186, 19.155700615474156, 20.76720326287406, 17.15686890057155, 19.66264639581953, 5.558965342385428, 0.36466825061610764, 0.4216647036373615, 1.8584830973829543, 16.41659392629351, 45.94032873426165, 55.8443465914045, 47.913665771484375, 42.015944480895996, 57.98839044570923, 60.80426951817104, 43.85639374596732, 9.083089930670601, 0.2946757620998791, 0.07547978764133793, 0.18181280685322626, 0.08370946068316698, 0.2015404389905078, 0.10083079910171883, 0.22879001178911754, 0.05250372338507857, 0.12589341960847378, 0.09785127719598156, 0.08321190452469246, 0.11086879510964666, 0.12841155805758067, 0.24266841422234262, 0.27680152122463497, 0.2798307458204882, 0.12395892984100751, 0.13652272495840276, 0.10447835230401584, 0.13341605237552098, 0.13399451704961912], [0.034286323602178266, 0.007620357076770493, 0.07391756932650294, 0.02178386296145618, 0.006942260561377874, 0.036308106899793656, 0.062374887987971306, 0.007917100796476007, 0.05858654555465494, 0.048080625012516975, 0.046367269807628224, 0.04858322947153023, 0.07004091556050948, 0.021398193834881698, 0.05647377410371389, 0.011746112922472613, 0.01916800020262599, 0.021735396901411668, 0.03883332246914506, 0.027135714622480527, 0.12073394789227418, 0.029066937243832008, 0.04580372951126524, 4.1148586954389295, 25.1554023538317, 43.325005940028596, 43.75278220857893, 33.776405811309814, 28.437118189675466, 27.843846252986364, 36.143087318965364, 21.762979132788523, 5.042567406381879, 0.29109377573643413, 0.03388184548488685, 0.3568101908479418, 3.1961789514337267, 4.595408703599658, 4.040556396756854, 2.2832301684788296, 5.449868202209473, 18.56720903941563, 26.104175397327968, 42.88893352236067, 45.73256022589547, 46.39976099559239, 47.03188031060355, 41.29256405149187, 41.02019119262695, 46.95764923095703, 42.902531147003174, 40.37168107713972, 36.446143422807964, 36.997239794049946, 37.51032951899937, 42.46413803100586, 45.64803886413574, 45.88765096664429, 44.17297451836722, 40.03559671129499, 33.97489847455706, 31.429881027766637, 30.90106405530657, 30.4866943359375, 30.583969116210938, 31.52614484514509, 35.202572209494456, 41.949700355529785, 42.23295061928885, 46.056127411978586, 44.42080633980887, 45.582381861550466, 43.237479482378276, 43.45263392584664, 36.0301582472665, 32.11603995731899, 31.182865619659424, 32.10752493994576, 32.200714179447715, 33.44272552217756, 35.02708155768258, 33.25671877179827, 33.80650888170515, 34.93785626547677, 35.68164355414254, 41.29086521693638, 42.2782632963998, 46.52557897567749, 39.491552761622835, 27.312811068126134, 43.77391862869263, 42.40553344999041, 43.97193881443569, 43.54379429136004, 46.17445523398263, 43.44361516407558, 45.92701598576137, 44.680210386003765, 46.1354341506958, 45.00199883324759, 41.80172804423741, 30.566946029663086, 32.781204904828755, 31.353228500911168, 31.417263099125453, 34.60362706865583, 40.082451888493125, 42.83225359235491, 43.980287075042725, 41.57201017652239, 35.9164822442191, 31.993341718401226, 33.16779225213187, 31.563501834869385, 31.19206850869315, 32.05681698662894, 32.80911234446934, 34.51415164130074, 39.29571083613804, 40.33280938012259, 41.950600147247314, 47.48606320789882, 46.22957181930542, 45.167470182691304, 48.86356789725167, 48.38938461031233, 47.268400464739116, 43.57537732805525, 41.273331437792095, 36.55489662715367, 41.09960215432303, 41.229255540030344, 47.69163955960955, 47.842269556862966, 38.83203322546822, 26.61831430026463, 15.563273497990199, 13.466942054884774, 6.852636541639056, 15.112274612699236, 6.3118677990777154, 4.28394831929888, 2.304313825709479, 0.09495248060141291, 0.2090015286313636, 1.5949650662285941, 14.987794160842896, 34.14090830939156, 33.232980251312256, 25.731324638639176, 35.459148338862825, 46.958319732121055, 47.04505409513201, 29.41770703451974, 3.838474988937378, 0.06744788720139436, 0.029636689528290714, 0.01821272467662181, 0.09572976282132523, 0.01741042995958456, 0.025215423200279474, 0.027353107064430202, 0.01922472403384745, 0.08688761693026338, 0.0045288751966186935, 0.04543290673089879, 0.045099433910633833, 0.04892207968181797, 0.007664930890314281, 0.015623779401981404, 0.028754224202462604, 0.07075005250849895, 0.004136318091436156, 0.026292197206722837, 0.023590280940490108, 0.01157828831180398, 0.019259380209924917, 0.04227579864008086, 0.012038674321956933, 0.0322154788300395, 0.031092286242970398, 0.012345242380563701, 0.0732103254912155, 0.06073012588811772, 0.06154158591691937, 0.046956764068454504, 0.020472512613715868, 0.04576860175334981, 0.033927717844822576, 0.016439763563019887, 0.03900457452982664, 0.03699106935943876, 0.03562316990324429, 0.06508869558040585, 0.02524325161773179, 0.038415219368679185, 0.145771021555577, 0.05561507785958903, 0.10400610550173692, 5.4224028417042325, 30.87134313583374, 51.75569997514997, 49.993362358638215, 40.064848627362935, 34.79303843634469, 36.666766098567415, 41.97147600991385, 24.66134374482291, 5.709025153091975, 0.39487073996237343, 0.09738851631326334, 0.1597417454634394, 1.6269189630235945, 5.1398678081376215, 7.174463638237544, 6.303429211888995, 7.379554918834141, 17.871946232659475, 30.2661863054548, 45.114879267556326, 48.71107578277588, 48.48261553900582, 48.119909150259836, 43.40064402988979, 43.88801499775478, 49.90325811931065, 44.769029208592, 42.41151237487793, 38.4876492364066, 39.18688814980643, 39.554631982530864, 44.158383301326204, 46.71884311948504, 48.744548729487825, 46.21585954938616, 42.55304718017578, 36.7194299697876, 33.35915258952549, 32.07479197638375, 31.897536482129777, 32.1420887538365, 33.13835620880127, 37.71802854537964, 43.93741321563721, 44.93437896456037, 46.136938435690745, 45.465947423662456, 47.88331951413836, 45.437237467084614, 44.19385732923235, 36.474922861371724, 33.791643210819785, 32.304586274283274, 33.59795870099749, 32.602122034345356, 36.12675557817732, 37.392501967293875, 34.92252159118652, 34.706144264766145, 36.05276073728289, 37.97082485471453, 42.59014708655221, 44.654786927359446, 49.15767124720982, 39.94049671718052, 29.424689974103654, 44.827626841408865, 43.20658084324428, 46.23818063735962, 45.307375635419575, 46.90942178453718, 45.128883361816406, 48.640857287815635, 45.469616072518484, 46.517352308545796, 47.65729808807373, 44.26990188871111, 31.823482581547328, 34.16602604729788, 33.809291635240825, 33.62264912469046, 35.213616371154785, 41.92456177302769, 44.23696742738996, 44.77077668053763, 42.04040561403547, 36.035411085401265, 34.756018434252056, 35.06599146979195, 33.481121267591206, 32.59965194974627, 32.77527461733137, 35.05795587812151, 36.699867316654746, 42.69577707563128, 42.47838183811733, 44.240476267678396, 48.783934593200684, 45.75708736692156, 45.70741122109549, 48.10593632289341, 49.7805529321943, 49.672376428331646, 45.22449057442801, 40.92546987533569, 39.03338507243565, 42.93205751691546, 45.36849546432495, 51.0196772984096, 51.563300882067, 43.527740478515625, 29.240027700151714, 20.42679190635681, 12.94111715044294, 8.56215134688786, 15.471300193241664, 8.64473763534001, 5.89064541884831, 2.25549122265407, 0.3783936026905264, 0.08051975577005319, 1.7689111552068164, 16.06249635560172, 41.198315211704795, 41.85723720278059, 32.38682515280587, 37.82249123709542, 51.733055795942036, 52.14490679332188, 34.01344360624041, 5.675200453826359, 0.0717208529157298, 0.03404498565942049, 0.02586612131978784, 0.055764219856687954, 0.04276301731754627, 0.01285513854652111, 0.026648075253303562, 0.024080588648627912, 0.061271433984594684, 0.007332367306974317, 0.04251426637970975, 0.06435108730303389, 0.026545015961996148, 0.0351417696635638, 0.040631860960274935, 0.03512865697432842, 0.0458248862331467, 0.005580461559085441, 0.05549585586413741, 0.04268117920894708, 0.0424118279479444, 0.1255440826394728, 0.10434753753777061, 0.21334496699273586, 0.08399356329547507, 0.07693622913211584, 0.1893291970981019, 0.17950120089309557, 0.1367715708911419, 0.17018738495452063, 0.1348551030137709, 0.08911080977746419, 0.2036420383623668, 0.15230105258524418, 0.08400129180933748, 0.15582463065428392, 0.11721008483852659, 0.11502913758158684, 0.15001426743609564, 0.19706440131579125, 0.1654228749019759, 0.25679773890546387, 0.14160725926714285, 0.24509721675089427, 6.3062784075737, 34.940420150756836, 56.38977670669556, 56.61324119567871, 43.73872947692871, 37.70684194564819, 38.89426129204886, 45.5210223197937, 29.23648759296962, 7.479166030883789, 0.6230479532054493, 0.3341194641377245, 1.0205187307936805, 6.949236912386758, 10.556125402450562, 10.250810265541077, 8.03545618057251, 9.09132180895124, 22.56309199333191, 29.082206317356654, 46.76217903409685, 50.24387271063668, 50.85903147288731, 47.899585247039795, 43.69099187850952, 45.617831570761545, 50.98595074244908, 46.194459097726, 43.76546614510672, 40.66389799118042, 40.199487345559255, 42.62046207700457, 45.3546268599374, 49.3338497706822, 49.23879146575928, 49.004317556108745, 44.176882880074636, 38.44982671737671, 35.403486319950645, 34.221802711486816, 33.967752252306255, 33.088016510009766, 34.63879190172468, 39.05286087308611, 47.462276050022666, 46.627182483673096, 48.998915331704275, 46.63032306943621, 49.46672364643642, 47.820702348436626, 48.285519463675364, 40.23814017432076, 35.822316782815115, 34.220694473811555, 35.682393959590364, 35.19773973737444, 37.48676470347813, 38.401852880205425, 35.89735385349819, 37.03309597287859, 38.02164050510952, 39.31979676655361, 44.736772196633474, 48.6805453981672, 50.04248264857701, 43.83297831671578, 32.353525911058696, 46.94857835769653, 45.01764965057373, 47.507828439985005, 46.697849137442454, 47.473149980817524, 46.01777335575649, 50.53188249043056, 46.75051300866263, 48.03258766446795, 49.28829043252127, 47.34492792401995, 34.354252747126985, 36.253973620278494, 35.59673656736101, 34.730247565678184, 37.68914835793631, 44.30736310141427, 47.66550391060965, 48.28625249862671, 46.618761266980854, 39.4519237109593, 37.13979945863996, 36.360659735543386, 34.574781622205464, 34.52650901249477, 34.68783923557827, 37.08854259763445, 38.66491862705776, 45.277265616825645, 45.50651100703648, 45.953050885881694, 51.421053886413574, 46.22331149237496, 48.36962045942034, 52.03003570011684, 51.66364329201834, 54.16039855139596, 47.22772571018764, 44.04139995574951, 40.87409489495413, 45.790723596300396, 47.0628206389291, 53.17910099029541, 53.224243436540874, 45.29066869190761, 30.963000297546387, 18.478918279920304, 21.411339487348283, 12.752491797719683, 23.82308006286621, 15.971283878598895, 9.585759094783239, 4.140615667615618, 0.4691740157348769, 0.560229018330574, 2.2666437327861786, 19.117996215820312, 42.953888756888254, 44.245218413216726, 37.42680869783674, 46.5932092666626, 58.94602939060756, 60.205793380737305, 39.92856318610055, 9.251008783067975, 0.21229261346161366, 0.0869191348818796, 0.14881169982254505, 0.11882494390010834, 0.15530219940202578, 0.09446678523506437, 0.13272743432649545, 0.1715229454317263, 0.2225247858358281, 0.0632960671292884, 0.15861426453505242, 0.1479331733925002, 0.14051080095980847, 0.09192966816148587, 0.16401328625423567, 0.1364450326987675, 0.1248500363102981, 0.09479222420070853, 0.11688087321817875, 0.1305763426103762, 0.17297338188758918], [0.02472662183988307, 0.02802489065964307, 0.06487381032535008, 0.0499576055444777, 0.004325722236119742, 0.09420428039239985, 0.035488619801721404, 0.06507097903106894, 0.02343044353515974, 0.01986325262779636, 0.017997554436858212, 0.0012390852020221896, 0.032642168791166375, 0.037405325166348896, 0.018110074202663133, 0.057025209335344176, 0.016382837867630378, 0.06982476823031902, 0.03362439572811127, 0.022525895287149718, 0.03954233728083117, 0.02621966690224196, 0.05543171055614948, 2.3171354234218597, 18.0454774924687, 40.478606905256, 45.135056836264475, 40.786492007119314, 21.469150236674718, 26.437725407736643, 34.42557600566319, 23.8479893548148, 7.930255242756434, 0.6152522372347968, 0.05473787118015545, 0.036796302667685916, 2.319444613797324, 4.425216053213392, 5.635566192013877, 7.070375280720847, 3.797628266470773, 7.205562472343445, 19.761745078223093, 32.39357532773699, 46.10177707672119, 46.057412828717915, 49.354322637830464, 43.24457359313965, 48.888098512377056, 47.105461733681814, 44.39025163650513, 40.24153784343174, 35.86238704408918, 34.975567613329204, 37.18568536213466, 40.08417851584298, 45.3642327444894, 45.63679667881557, 42.223487172807964, 39.02770144598824, 34.107261657714844, 31.652671541486466, 30.39396367754255, 29.49110780443464, 30.06310088293893, 32.53495727266584, 36.71364906855992, 40.39278623035976, 41.95743022646223, 47.04604768753052, 45.33808319909232, 41.866082259586875, 45.783855301993235, 42.59926659720284, 42.717900139944895, 35.881004742213655, 31.910029343196324, 31.824559552328928, 32.0613819531032, 32.79954814910889, 33.04915176119123, 32.58493219103132, 32.2383907863072, 33.401088442121235, 33.903054101126536, 40.58137771061489, 42.90853091648647, 45.30962337766375, 40.60507106781006, 31.6797764641898, 44.96913037981306, 38.43625341142927, 45.775767598833355, 41.46393094744001, 46.55542843682425, 42.015437262398855, 46.49876587731497, 44.85589906147548, 46.357106004442485, 45.63700859887259, 44.45811469214303, 33.4172534261431, 32.94378580365862, 32.82311643872942, 31.15001106262207, 35.66249431882586, 43.67416681562151, 46.29081671578543, 46.99648271288191, 44.5644325528826, 44.62321778706142, 34.944707189287456, 32.325090408325195, 32.23774807793753, 32.646823269980295, 32.33581147875105, 33.68615565981184, 34.282960755484446, 40.05543034417288, 43.24646002905709, 46.73905542918614, 42.78269556590489, 46.118021965026855, 42.40041610172817, 42.875012806483674, 46.68050643375942, 48.40332269668579, 45.70630298342024, 46.511408124651226, 41.09445701326643, 42.69961942945208, 40.1201354435512, 47.37660823549543, 43.981822626931326, 41.84730475289481, 25.386120762143815, 19.62562813077654, 11.842598267963954, 6.927251509257725, 12.986988289015633, 4.30996367761067, 2.8878591528960635, 0.3735944330692291, 0.29368751655731884, 0.0875071668997407, 2.2716394875730788, 15.960340465818133, 38.13617808478219, 34.3646958896092, 31.05018629346575, 38.77125038419451, 48.410510608128135, 45.38838815689087, 24.401408161435807, 2.652613341808319, 0.04500311925741179, 0.11319082336766378, 0.06231696145342929, 0.05478316339265023, 0.009840398976978446, 0.05741566552647522, 0.05844545776822737, 0.026307650841772556, 0.0715607525780797, 0.08157341208841119, 0.029535496208284582, 0.023071776709652374, 0.06384295278361865, 0.07185319438576698, 0.045765483884939125, 0.019343813714970435, 0.09802686170275722, 0.07067665537553174, 0.004378281982748636, 0.04364640884367483, 0.031887675169855356, 0.03853389514344079, 0.034342496123697074, 0.03970033415992345, 0.010540218790993094, 0.008586696964422507, 0.06982877837227923, 0.07593026704021863, 0.00462456899029868, 0.015941092910777246, 0.1010953870468906, 0.03536584906812225, 0.07509145526481525, 0.0422367184156818, 0.0250735856326563, 0.05393189371430448, 0.04276577216972198, 0.022857439371624162, 0.015108320097039853, 0.031977842295808453, 0.009635278689009803, 0.025871775212830732, 0.027734248666092753, 0.02463675326933818, 3.0323391258716583, 22.77948669024876, 45.485079288482666, 51.31833866664341, 43.31031744820731, 26.106447458267212, 29.241014344351633, 39.51046575818743, 28.776443890162877, 8.973499468394689, 0.6726974461759839, 0.06446108461490699, 0.27982271196586744, 1.1483829553638185, 3.9965569291796004, 7.466148580823626, 6.63602123941694, 4.70902955532074, 9.525221177509852, 20.820440360477992, 36.43316766193935, 49.347249371664866, 48.78707865306309, 48.891510077885215, 45.200939655303955, 47.71052476337978, 48.557044642312185, 46.35928773880005, 42.07893337522234, 37.189562456948416, 36.671233790261404, 39.503670419965474, 42.12716082164219, 45.82565219061715, 46.25828177588326, 44.21520914350237, 41.27558265413557, 35.409173420497346, 32.808757986341206, 31.040358066558838, 31.369768687656947, 30.966359751565115, 33.72689642224993, 36.95393862043108, 42.85250759124756, 44.27419934953962, 47.84495850971767, 46.186631952013286, 43.54346425192696, 46.84341737202236, 45.46948753084455, 45.21174757821219, 36.59357724870954, 32.96196229117257, 32.77488899230957, 33.20121308735439, 34.34244775772095, 34.47891385214669, 34.099226066044395, 33.50761822291783, 35.22231898988996, 35.822994232177734, 40.916030747549875, 43.30351168768746, 46.86764574050903, 41.90383529663086, 33.575033119746614, 46.02304703848702, 40.680333954947336, 45.631422247205464, 43.73189244951521, 46.386260645730154, 43.80310453687395, 48.36743525096348, 46.85109165736607, 47.56123924255371, 47.53355761936733, 46.60676867621285, 35.50625365121024, 34.282300676618306, 33.48218434197562, 33.562112944466726, 37.656773226601736, 47.47204174314226, 48.22913135801043, 48.748255593436106, 47.588066237313406, 46.31293283190046, 35.631262166159495, 33.39398390906197, 34.42777511051723, 33.66053070340838, 34.41379533495222, 35.458797454833984, 35.846406187329976, 42.282828262874055, 45.7934889793396, 49.27541542053223, 44.76844555991036, 46.05918114525931, 44.67169189453125, 45.820760658809114, 47.62035799026489, 49.96059465408325, 48.33943401064192, 47.301380089351106, 42.78879261016846, 43.95527703421456, 42.93793569292341, 51.03751332419259, 46.797364711761475, 44.16681841441563, 28.133066756384714, 19.29602469716753, 10.16412193434579, 10.349276661872864, 19.95397220339094, 7.632250479289463, 4.87110801254, 1.7730865882975715, 0.4655308797955513, 0.1393189677702529, 2.5235561983925954, 18.56100082397461, 40.39341851643154, 34.894165992736816, 31.918464456285747, 41.475593498774934, 55.58720418385097, 52.55751861844744, 30.402694089072092, 4.027329632214137, 0.04887719459033438, 0.06457083765417337, 0.05092283517920545, 0.026850718040285364, 0.07289889148835625, 0.022520677352856313, 0.033306675098304234, 0.06669598219117948, 0.03886812113757644, 0.030426100561661378, 0.016470731901271, 0.033930374309420586, 0.022789412843329564, 0.0493432226191674, 0.035225161617355685, 0.06862533544855458, 0.06269451869385582, 0.007544557929837278, 0.022653297022251145, 0.041857688754264794, 0.09785665119332926, 0.10301629932863371, 0.13578403102500097, 0.09450880690876927, 0.10105569274829966, 0.06928822344967298, 0.21402641971196446, 0.1562660719667162, 0.18674682852412972, 0.10711260166551385, 0.1297927296587399, 0.09795374955449786, 0.16181430353650025, 0.23417603277734347, 0.13899180532566138, 0.16231256537139416, 0.1473846456834248, 0.07329333746539694, 0.11224393453449011, 0.18271741616938794, 0.1304144984377282, 0.18966718896159104, 0.1604183398719345, 0.1010106923058629, 3.5486552034105574, 26.303951740264893, 52.86028984614781, 57.530514580862864, 50.22066920144217, 30.584667410169327, 36.29756661823818, 44.529406683785574, 32.11062036241804, 10.879220111029488, 0.9726228437253407, 0.13175480866006442, 0.7247350024325507, 5.07909278358732, 9.45956243787493, 11.347671134131295, 13.17951592377254, 7.389750531741551, 8.617476378168378, 22.284780161721365, 35.64184774671282, 51.368480341775076, 49.80396836144583, 50.30255372183663, 46.40649380002703, 48.46071481704712, 50.566046782902305, 49.53792878559658, 43.492478370666504, 38.697338921683176, 37.8456461088998, 40.75375556945801, 43.600303990500315, 47.9886611529759, 48.244142941066194, 46.57142666407994, 42.38923992429461, 37.23073400769915, 35.01969562258039, 33.173531464168, 31.774671486445836, 33.684119837624685, 36.370599133627756, 39.896080357687815, 44.2666779245649, 46.459015233176096, 49.49284539903913, 47.124055113111226, 43.992731298719136, 49.07160043716431, 47.62218189239502, 46.89350693566458, 39.613038539886475, 34.93935360227312, 35.5111278125218, 35.65780428477696, 35.80066272190639, 36.212419918605256, 36.51182474408831, 35.8328606741769, 38.03039870943342, 37.740398270743235, 43.514611857278005, 46.14105871745518, 48.51406308582851, 44.85217135293143, 38.16535357066563, 47.407816069466726, 42.62313365936279, 46.21464361463274, 45.47474384307861, 48.09287370954241, 44.49198368617466, 48.96218020575387, 49.67695876530239, 47.54906252452305, 50.77837678364345, 48.74414920806885, 37.027488776615684, 36.63138239724295, 36.76202590124947, 34.10705321175711, 40.083014692579, 48.933907985687256, 51.60589681352888, 50.21600348608834, 48.876623562404085, 49.90699972425188, 39.033020292009624, 35.531350544520784, 36.53189461571829, 35.95804636819022, 36.219639096941265, 37.597501618521555, 38.35028682436262, 43.47629254204886, 48.64111089706421, 50.65194041388375, 46.63039949962071, 46.30969844545637, 46.35145364488874, 46.2342722756522, 49.36410917554583, 51.12366056442261, 51.06332240785871, 51.39794765199934, 46.454710824149, 47.331288610185894, 45.440204347882954, 52.58738892418997, 51.204127652304514, 47.2830924306597, 28.04747189794268, 23.284650257655553, 15.643685000283376, 15.290414265223912, 25.763416630881174, 11.200091396059308, 8.75566041469574, 0.8973322180765015, 0.7727668136358261, 0.3592583994780268, 3.4656587541103363, 20.935281923839025, 46.69684164864676, 44.99567944662911, 42.511357988630024, 51.04438509259905, 62.66271809169224, 59.307815143040244, 34.486122608184814, 5.551601120403834, 0.19147142714687757, 0.17108622672302382, 0.20644388587347098, 0.09320212488195725, 0.12748094727950438, 0.13831977067249163, 0.1852476189711264, 0.12870931279446396, 0.178436063762222, 0.22252922345485004, 0.12280523031949997, 0.14732323826423713, 0.15816575288772583, 0.09383221250027418, 0.09818031918257475, 0.20924075293753827, 0.1493339275142976, 0.11825981922447681, 0.08356113292809043, 0.11949392514569418, 0.1418690380773374], [0.05010495960180249, 0.025901632449988807, 0.015182975912466645, 0.04893255626250591, 0.010759808838234415, 0.022473159545500363, 0.059901892473655086, 0.006653598193744463, 0.04008998967973249, 0.03421039553359151, 0.03322413809863584, 0.04457068210467696, 0.014594350176464235, 0.049924184302134175, 0.040841667380716117, 0.019278331692995768, 0.020533507822879722, 0.04440560810534017, 0.018638490133785775, 0.018203433835878968, 0.09370879376573221, 0.09283205188278641, 0.09934112975107771, 0.8245302960276604, 13.335179890905108, 37.4396003314427, 46.461836201804026, 42.789348466055735, 33.46716928482056, 28.094683170318604, 31.084836959838867, 26.843986579350062, 11.907256467001778, 1.5633681331362044, 0.09428131447306701, 0.033310888800770044, 0.2708338057356221, 2.143718591758183, 9.256446616990225, 6.347437798976898, 4.932196140289307, 6.342419896806989, 11.735113978385925, 28.849990572248185, 37.509245600019185, 46.77845171519688, 44.20925106321062, 44.434205940791536, 47.49381044932774, 43.96086685998099, 43.62523065294538, 37.55354731423514, 34.275550501687185, 33.11263745171683, 32.86024761199951, 36.28419828414917, 39.67629146575928, 42.63280555180141, 40.69622448512486, 38.43932104110718, 34.944655077798025, 32.01504789079939, 31.762821333748953, 31.22513845988682, 31.624211720057897, 37.0370877129691, 43.758309500558035, 41.4132125718253, 43.73307364327567, 47.35500628607613, 44.99203511646816, 45.831943784441265, 42.212588923318044, 44.87689651761736, 43.02314492634365, 42.66130358832223, 35.38254792349679, 30.38970790590559, 32.36793647493635, 31.622981888907297, 30.46796546663557, 31.36323390688215, 31.276937280382427, 33.330178601401194, 39.32021018436977, 42.56159346444266, 42.76072883605957, 47.25985765457153, 41.537380354745046, 28.628669602530344, 40.19804906845093, 46.370905126844136, 43.2954135622297, 42.597581659044536, 46.78981549399239, 44.02990068708147, 44.566520486559185, 45.66933856691633, 46.10709244864327, 46.75509187153408, 42.37321390424456, 33.10193722588675, 31.341809136526926, 33.60982969829014, 31.77832623890468, 36.83528423309326, 45.339368615831646, 48.5876271384103, 47.950411319732666, 46.601036412375315, 44.679835183279856, 41.219333512442454, 33.263385568346294, 32.272165979657856, 33.574810777391704, 32.59539270401001, 33.82632514408657, 37.408211844308035, 42.334210191454204, 45.576541900634766, 46.473342418670654, 43.505367279052734, 44.15805673599243, 43.98492847170149, 46.362028803144185, 43.16454771586827, 45.586978094918386, 50.336137839726035, 49.37882546016148, 47.7467109816415, 47.28568410873413, 44.733603818076, 43.679437024252756, 43.0191775049482, 36.76606975282942, 25.799971103668213, 23.220704248973302, 11.300884570394244, 9.072914293834142, 16.559794562203543, 7.97652416569846, 5.264672654015677, 4.307894417217799, 0.6306081361004284, 0.04225899472034403, 3.065821192094258, 18.969747713633947, 45.78514071873256, 40.25777925763811, 33.27809143066406, 41.77372332981655, 44.994303703308105, 43.27579184940883, 21.555043867656163, 3.0579658193247656, 0.09061554939086948, 0.030889638366975954, 0.022291071280570965, 0.017061893661905612, 0.03813032287039927, 0.02813713561876544, 0.03029775566288403, 0.014927814515041453, 0.09760082313524825, 0.04343438361372266, 0.09375751936542136, 0.026157487649470568, 0.09099466726183891, 0.0592122973342027, 0.0846840473158019, 0.07493903594357626, 0.0382578738832048, 0.04275086136268718, 0.04805983809222068, 0.034976929758808444, 0.025283744891307185, 0.013613264874688216, 0.04247807671449014, 0.10318905434438161, 0.09748154346432004, 0.02211285405792296, 0.05558152769559196, 0.016018535808793137, 0.028613550322396413, 0.04064367086227451, 0.046332209903214655, 0.04382909761209573, 0.019477905805355737, 0.011733092683633524, 0.06870397765721593, 0.10770977355007615, 0.05247509938531688, 0.02876914179484759, 0.021773673061813627, 0.016506667115858624, 0.05047531419300607, 0.06728718975292784, 0.06526814095143761, 0.03632226792563285, 1.4332103516374315, 17.197411639349802, 43.29319708687918, 53.67093617575509, 48.49675859723772, 33.85256501606533, 33.01455668040684, 37.0805139541626, 30.501869201660156, 13.048525878361293, 1.329576124038015, 0.08530216557638985, 0.10524576183940683, 0.88241986398186, 3.8650583624839783, 6.543872058391571, 9.431838256972176, 8.070867674691335, 6.880900076457432, 13.905563592910767, 30.859503405434744, 39.50115864617484, 48.29114750453404, 45.81248882838658, 44.94431141444615, 48.55069746289934, 47.132156712668284, 44.8149220602853, 40.626676491328645, 36.53525754383632, 35.383610997881206, 35.59897041320801, 38.53567865916661, 42.53661469050816, 44.851570333753315, 43.278560706547324, 40.42386899675642, 36.62392003195626, 33.862938676561626, 33.319579124450684, 32.84526034763881, 33.158064774104524, 37.128859519958496, 44.23576538903372, 44.45419590813773, 46.20815052304949, 48.088093348911826, 46.3698524747576, 45.39707687922886, 44.929827894483296, 46.778295380728586, 44.20518636703491, 45.233926228114534, 36.123281478881836, 32.03116423743111, 33.67490652629307, 34.31588132040841, 32.52939523969378, 32.11639084134783, 32.78308439254761, 35.23005928312029, 40.27042497907366, 45.8154730796814, 45.093895707811626, 47.789984362465994, 42.8845214162554, 32.528373854500906, 40.076750891549246, 45.424407618386404, 45.942975997924805, 43.29945393971035, 47.498969486781526, 45.98408154078892, 45.324329239981516, 48.12391478674752, 47.78265748705183, 48.64253180367606, 44.971013341631206, 34.37769944327218, 33.750687054225374, 35.31733560562134, 33.476969718933105, 39.211477824619834, 46.60428122111729, 48.871436732155935, 48.82559251785278, 47.814664363861084, 46.81491238730294, 43.15800251279558, 36.530386856624055, 33.508035114833284, 35.49243368421282, 34.45687069211687, 34.72120795931135, 39.16703019823347, 44.63279587881905, 47.94621808188302, 49.45176417487008, 43.21129172188895, 43.70149755477905, 45.83501141411917, 47.75982918058123, 44.996155398232595, 47.813875743321006, 50.608941486903596, 51.171867166246685, 50.19166742052351, 48.84137535095215, 45.085613455091206, 47.18514714922224, 46.99267510005406, 41.27564866202218, 28.072407245635986, 18.86572449547904, 12.27976850100926, 10.815444333212715, 14.135723539761134, 8.534718121801104, 5.819215331758771, 2.696639950786318, 0.4317119073654924, 0.0654431487034474, 3.4298106091363088, 20.912547418049403, 47.173866748809814, 38.75727408272879, 38.39506449018206, 46.315250056130544, 51.31376327787127, 50.24013805389404, 26.49531728880746, 3.618722575051444, 0.09380775809820209, 0.062332798460764546, 0.024290858169219325, 0.041812230300690444, 0.07745448739400931, 0.02018854740474905, 0.009182513475285044, 0.04348958583016481, 0.05286908735121999, 0.055929507594555616, 0.02506787745681192, 0.019118828466162086, 0.04886675193639738, 0.05972468626818486, 0.021235771211130277, 0.011421387266766812, 0.03227730694093874, 0.059982278517314365, 0.07808963009821517, 0.03209299308114818, 0.03481272767697062, 0.16062002762087754, 0.0941838293469378, 0.1409281407083784, 0.1815439984202385, 0.1126286978168147, 0.10590116559926953, 0.1662633626588753, 0.15162155404686928, 0.1721227839589119, 0.118259425674166, 0.12483960044171129, 0.11250375237848077, 0.06970651993261916, 0.21471848471888474, 0.1621557559285845, 0.1546054660741772, 0.11339804117700883, 0.12499141586678368, 0.13499625186835015, 0.15055088007024356, 0.21668059086161, 0.19922765237944468, 0.1378043419016259, 1.5244770028761454, 18.84590302194868, 48.390822887420654, 58.84080587114607, 54.25556802749634, 43.498523303440635, 38.42326375416347, 41.695788860321045, 36.07963636943272, 16.712757417133876, 2.358073775257383, 0.3280098262642111, 0.28463322669267654, 1.4981469128813063, 8.544145958764211, 17.28079523359026, 12.83404106753213, 10.657905220985413, 9.792490584509713, 15.244097573416573, 32.169158935546875, 39.805062430245535, 48.3472854750497, 47.51878227506365, 46.60682078770229, 50.64731291362217, 48.29439926147461, 47.21719571522304, 42.5283637046814, 38.23495715005057, 37.34948219571795, 37.152003969464985, 39.395657198769705, 44.32142972946167, 46.58216857910156, 44.4928800037929, 43.3667437689645, 38.89979553222656, 36.80785621915545, 35.40920121329171, 34.31465148925781, 34.95093624932425, 39.93614714486258, 46.88121209825788, 45.388811997004915, 48.44294827325003, 51.146217891148154, 48.6212876864842, 47.76508549281529, 44.2805187361581, 48.10380322592599, 47.054302147456575, 47.82007006236485, 39.194725717817036, 34.497767789023264, 35.602628639766145, 35.239658219473704, 35.645401750292095, 34.299490519932334, 34.764113085610525, 36.516049248831614, 41.8694486618042, 47.920492376599995, 46.705738816942485, 49.38568680627005, 44.72102757862636, 37.566905226026265, 44.32329879488264, 46.05023881367275, 43.49161679404122, 43.70310606275286, 48.60447999409267, 47.291972228458945, 47.76770843778338, 49.826688970838276, 48.94329500198364, 51.25630167552403, 46.79809774671282, 36.914264406476704, 34.761670793805806, 37.24308443069458, 35.35623509543282, 41.36435978753226, 48.87033544267927, 51.842986719948904, 50.41719205038888, 51.07580484662737, 49.36864982332502, 45.06305265426636, 38.62498038155692, 34.985413210732595, 37.46920313153948, 35.79097693307059, 36.974359376089915, 41.859290395464214, 46.50941399165562, 50.15671798161098, 51.079515184674946, 45.96422358921596, 47.290634700230186, 47.27907984597342, 48.57233762741089, 46.15362800870623, 49.13110480989729, 53.34800474984305, 53.0313058580671, 52.06933123724801, 51.02254343032837, 47.6884503364563, 49.635339055742534, 48.3027787889753, 41.40905407496861, 30.12403311048235, 27.743059158325195, 16.040486199515207, 17.3002119745527, 25.416819640568324, 18.93063804081508, 12.431189724377223, 5.674891693251474, 1.6316733764750617, 0.28490721913320677, 4.694917763982501, 25.017287799290248, 56.244218894413535, 50.21956096376692, 45.1012990134103, 54.10990251813616, 59.74120208195278, 59.07027012961251, 31.981269223349436, 4.3580886381013055, 0.1511152854987553, 0.16115892013268812, 0.11315820618931736, 0.12970642000436783, 0.11091097284640584, 0.11914176547101565, 0.18169208190270833, 0.0917508334719709, 0.15432903090757982, 0.14022525985326084, 0.1335014256515673, 0.10812323886368956, 0.15600037122411387, 0.1072989816644362, 0.10390587230878216, 0.12349072710743972, 0.1793437807687691, 0.22189084413860524, 0.17516199659023965, 0.11473442268158708, 0.11427649296820164], [0.0351258546247014, 0.010588715385113443, 0.024844658095389605, 0.04453268414363265, 0.020196940882929733, 0.048954493299658806, 0.05415268222402249, 0.052138301743460555, 0.022173722041770816, 0.02293798147833773, 0.04643662965723446, 0.00560345287002357, 0.11719194081212793, 0.015609670962606157, 0.012528300102400993, 0.055350656155496836, 0.10715762246400118, 0.03538188285061291, 0.07874271326831409, 0.027057247136586478, 0.03293311782181263, 0.08828999275075537, 0.013974743379679109, 0.15918735521180288, 7.535204989569528, 30.440728528159006, 45.24949714115688, 40.37886898858206, 27.506445203508648, 15.374584742954799, 27.673999275479996, 27.189378057207378, 17.062437670571462, 2.803338659661157, 0.21583688684872218, 0.07181210230503764, 0.6227729022502899, 3.2447016962936948, 4.269770520074027, 7.129470143999372, 3.991702309676579, 2.8130787312984467, 4.940982571669987, 17.33855734552656, 31.009268351963588, 39.909208978925435, 41.630882263183594, 47.32999971934727, 47.9938132422311, 44.05305208478655, 41.30567877633231, 36.74462066377912, 32.973048142024446, 32.522447041102815, 32.67642259597778, 34.57631369999477, 37.676554747990195, 39.44680288859776, 37.272947788238525, 35.26810414450509, 33.434856687273296, 31.255654948098318, 32.9684727532523, 32.150037493024556, 36.05568592888968, 42.10612515040806, 43.05117743355887, 44.667338848114014, 46.824615546635215, 45.73671872275216, 45.22570998328072, 45.3668452671596, 45.5926512990679, 45.12698302950178, 45.25265857151577, 44.43987219674246, 41.754417760031565, 34.22792060034615, 30.827135222298757, 33.14395298276629, 30.59963035583496, 32.05712270736694, 32.32428094318935, 40.15527595792498, 43.67038699558803, 43.284032412937705, 43.906438146318706, 48.20039013453892, 39.166734899793354, 24.945959329605103, 39.7309946332659, 35.675793170928955, 41.042609555380686, 44.78537484577724, 47.436637197222026, 46.17407308306013, 43.637278829302105, 44.34823587962559, 41.609092712402344, 44.48931557791573, 37.64214032036917, 33.373055934906006, 33.13971110752651, 32.59138011932373, 33.239702633449006, 37.59004620143345, 43.584639276777, 46.140186718532014, 47.70910038266863, 46.71837411608015, 46.92640665599278, 42.17272015980312, 36.805142947605674, 32.35264348983765, 32.41781064442226, 33.72950199672154, 33.88597195489066, 34.779906341007774, 43.17120409011841, 45.291981901441304, 48.20021990367344, 43.42372941970825, 46.989395550319124, 46.241710322243826, 49.302770478384836, 49.12016487121582, 44.52348681858608, 46.06921781812395, 49.22261953353882, 47.38333409173148, 49.94794545854841, 47.483721664973665, 45.81693567548479, 42.047235693250386, 36.30668612888881, 24.57058811187744, 14.688151359558105, 8.595970835004534, 9.557302747453962, 16.140581948416575, 4.480081634862082, 4.016550370625087, 3.0895634038107733, 0.46912222994225367, 0.11030113949839558, 3.896119850022452, 22.33289122581482, 41.18911927086966, 42.899331501552034, 38.34400912693569, 40.18163742337908, 49.490719250270296, 41.26705721446446, 15.934953485216413, 0.9574295218501772, 0.01437483900891883, 0.07889287985329117, 0.02369627489575318, 0.048080906604549715, 0.02711900569764631, 0.011752542041774307, 0.020198241973827993, 0.01402172853704542, 0.04871730799121516, 0.025299033981614878, 0.021956896176561713, 0.05201637239328452, 0.046634398866444826, 0.06704280179526124, 0.02987274507592831, 0.020829815583835756, 0.03569853478776557, 0.07012833122696195, 0.013986929020445262, 0.012988684416216398, 0.02932906549956117, 0.054587182123214006, 0.04512012244335242, 0.12067118340304919, 0.04073264037391969, 0.07207450536744935, 0.08402357489934989, 0.033418009124164066, 0.10355511720159224, 0.02535970349396978, 0.08216335078967468, 0.020265939412638545, 0.015470589943496245, 0.014728055501888906, 0.022126441721671393, 0.10256199977759804, 0.002387480594084731, 0.06431899938200202, 0.014448037670393075, 0.02012008322136743, 0.009008365766411381, 0.025583180698699186, 0.08007358506854091, 0.02053531781504197, 0.3306247373776776, 9.732369559151785, 35.8750536101205, 50.57757384436471, 44.898946625845774, 34.530969755990164, 20.4455155645098, 31.534837041582378, 34.377928733825684, 18.661204269954137, 3.841211710657392, 0.09703278754438673, 0.04273826775274106, 0.660463459789753, 3.352384443793978, 5.187022626399994, 7.937490923064096, 7.234738826751709, 4.403985398156302, 7.420530182974679, 19.733782052993774, 32.38530697141375, 42.908593450273784, 42.24556507383074, 47.032033170972554, 49.23290981565203, 45.55324111665998, 43.294128145490376, 38.296601567949565, 34.72945547103882, 33.891725063323975, 35.16577107565743, 36.34514788218907, 38.91177075249808, 41.49490254265921, 39.46807132448469, 37.491058690207346, 35.22166933332171, 32.608156544821604, 34.06524590083531, 33.52121237346104, 38.06815869467599, 43.80734988621303, 45.50608021872384, 46.53583799089704, 48.34285947254726, 48.764813150678364, 47.24980708530971, 47.31854213987078, 46.67303712027413, 47.51291104725429, 46.35360411235264, 46.18968915939331, 41.84537315368652, 34.869294915880474, 33.11843919754028, 34.537018162863596, 32.95395449229649, 33.90596192223685, 34.17152554648263, 40.620169503348215, 46.42886005129133, 44.309471879686626, 46.64793675286429, 49.74639211382185, 40.491377694266184, 29.405728340148926, 42.9606910433088, 39.08374908992222, 41.03699541091919, 43.65371479306902, 47.95793621880667, 46.81455455507551, 45.67732204709734, 44.88784687859671, 43.75557885851179, 46.92068828855242, 39.77141925266811, 36.153318541390554, 34.57130752290998, 34.08425964627947, 35.00834921428135, 39.700255802699495, 44.55045277731759, 48.01062788282122, 48.81529528754098, 48.61249821526663, 48.80234037126814, 43.57830599376133, 39.163743700299946, 33.358065196446006, 34.4513121332441, 34.49400881358555, 35.08291728155953, 36.56176144736153, 44.74441868918282, 46.50198984146118, 49.298163822719026, 45.77724061693464, 48.629007135118755, 48.0567569732666, 50.96123252596174, 49.62589297975813, 46.36448499134609, 47.216382775987896, 49.665654046194895, 49.153088910239084, 51.942964349474224, 49.40525640760149, 48.09376655306135, 46.24738005229405, 37.615278584616526, 26.90606525966099, 13.852723411151342, 10.99280057634626, 11.950794747897557, 11.195852126394, 7.379562735557556, 2.589904329606465, 0.8850357521857534, 0.20096740259655885, 0.1387893711881978, 4.302618563175201, 25.20656888825553, 46.621780259268625, 45.158395835331504, 39.19112307684762, 48.87039450236729, 55.8792404447283, 49.38071884427752, 19.84029620034354, 1.4297369037355696, 0.046500371236886294, 0.06858108817998852, 0.07104325427540711, 0.10479190333613328, 0.035288899804332426, 0.05480208094897015, 0.033289280853101184, 0.034807910078338215, 0.017702693651829447, 0.02539797965437174, 0.03312073614714401, 0.0646242858575923, 0.02537944377399981, 0.02849033514836005, 0.017573225777596235, 0.07732097205838986, 0.022046919113823345, 0.057832462447030206, 0.03482299730447786, 0.05967067488070045, 0.029115761231098856, 0.12384494952857494, 0.11506742052733898, 0.21167271743927682, 0.12690584813909872, 0.1576184601123844, 0.1098508500893201, 0.13936778157949448, 0.10168639104813337, 0.08446745215249912, 0.12926583364605904, 0.12185243144631386, 0.09221268511776413, 0.19230620163891995, 0.052720179448702505, 0.1841137326721634, 0.14785762530352387, 0.23457376286387444, 0.10849102519984756, 0.17912379971572331, 0.1515870030437197, 0.10077217367610761, 0.18633702051426682, 0.09729892933475119, 0.5500008357422692, 10.980262551988874, 39.83771548952375, 57.611697333199636, 51.804622241428916, 38.826505933489116, 24.37011694908142, 37.68406922476632, 36.38517298017229, 23.474817241941178, 5.000396617821284, 0.4103954854820456, 0.34603440335818697, 1.9721443355083466, 7.768367426736014, 10.377152834619794, 14.432861515453883, 8.912198117801122, 5.038679455007825, 6.592375261443002, 18.984507424490793, 31.531891005379812, 42.6024488721575, 44.52265650885445, 49.30187068666731, 51.080491406576975, 47.62763622828892, 45.45179394313267, 40.36637612751552, 36.557665484292166, 36.322121552058626, 36.720885617392405, 38.87421921321324, 40.35826757975987, 43.27752889905657, 40.44197947638375, 39.264972005571636, 37.417525904519216, 34.06981086730957, 36.571367331913535, 35.12863990238735, 39.77500799724034, 46.376098905290874, 47.55528811046055, 47.46637201309204, 50.828782490321565, 48.731875215257915, 49.414348125457764, 48.29735919407436, 48.455135413578574, 47.89828940800258, 48.37858016150338, 49.08502088274275, 43.4824868610927, 37.05123771939959, 34.584985051836284, 36.35900953837803, 34.433566434042795, 35.41684423174177, 35.72490998676845, 43.270709242139546, 48.66038519995553, 46.44537591934204, 48.356721128736226, 52.03428452355521, 42.33432136263166, 32.75614275251116, 42.536381925855366, 41.147575991494314, 42.41804715565273, 45.21701431274414, 49.597797938755576, 48.03540515899658, 48.04049471446446, 48.08613395690918, 47.09324680055891, 48.978994846343994, 41.64717926297869, 37.9203531401498, 36.41142674854824, 36.897338594709126, 36.75899996076311, 41.96263442720686, 46.996934345790315, 50.10741703850882, 51.71333680834089, 49.825744015829905, 51.18078865323748, 46.51340920584542, 41.73934364318848, 34.895288126809255, 35.398848397391184, 35.70252636500767, 37.867053508758545, 38.47649390356881, 49.05094344275338, 49.577140944344656, 51.92949526650565, 46.20027821404593, 51.83521168572562, 49.33554513113839, 53.359476225716726, 52.20522410529, 48.31878743852888, 48.215314865112305, 51.331213678632466, 50.19348784855434, 55.409469263894216, 52.499417781829834, 49.89336388451712, 47.461400577000205, 41.80267299924578, 26.9327689238957, 16.49881717136928, 13.941978233201162, 17.25981167384556, 24.939061505453928, 11.02488214629037, 8.45035309450967, 4.778849397386823, 0.9938647896051407, 0.4275285761271204, 5.4500440784863065, 28.98689787728446, 53.68880694253104, 53.58351741518293, 49.23227058138166, 54.00668355396816, 64.38013213021415, 57.18097502844674, 24.55832280431475, 2.0523578141416823, 0.09721459421728339, 0.10485433534319911, 0.1229469355727945, 0.19468528112130506, 0.13143550365098886, 0.09186948210533176, 0.16275148253355706, 0.14965129191321985, 0.07064194830932788, 0.1297831351735762, 0.18712177340473446, 0.1660089934510844, 0.10836918745189905, 0.1268547951642956, 0.11289288542632546, 0.137465522225414, 0.08712964358606509, 0.21630340681544372, 0.10378938141678061, 0.1409714583839689, 0.09084483994437115], [0.07232884743383952, 0.046548170636274984, 0.04056750191375613, 0.034645679140729566, 0.0077404984871723825, 0.03481595750365939, 0.0981403331139258, 0.04667500240196075, 0.015136567509866186, 0.021370633438761746, 0.04224466745342527, 0.02319710891294692, 0.1336759448583637, 0.017540710379502604, 0.01523274475974696, 0.005484766917236681, 0.06127571554056235, 0.05595046075593148, 0.036823111586272717, 0.031425294266747575, 0.03452259288834674, 0.007841302497711564, 0.08158722027604069, 0.03734203141980937, 4.28198241336005, 28.143615858895437, 46.116562843322754, 44.582984243120464, 29.1914667401995, 26.889601503099712, 31.885616847446986, 30.10172939300537, 22.042307138442993, 6.286747889859336, 0.22301111902509416, 0.06958405114710331, 0.39784874873501913, 2.3688117819172994, 4.410530166966574, 8.368414725576129, 9.739612187658038, 2.56271060023989, 3.065598849739347, 11.024189932005745, 19.308267423084803, 31.111361707959855, 44.550741127559114, 51.77793073654175, 46.93543584006173, 43.54157086781093, 39.56153849193028, 35.269809927259175, 32.64878613608224, 32.58106551851545, 33.540469305855886, 33.0126632962908, 33.052476474217, 34.67070150375366, 33.521730014256065, 32.24952180044991, 32.43052237374442, 32.48859889166695, 30.611539568219865, 34.69330051967076, 41.622624329158235, 43.41853216716221, 45.31261110305786, 45.57776478358677, 44.93959706170218, 43.180212429591585, 43.16677461351667, 44.71408632823399, 46.60040760040283, 47.45717607225691, 46.15528515407017, 48.151995931352886, 44.53607695443289, 39.31986624853951, 32.49445969717843, 32.02760328565325, 30.22973952974592, 31.952760764530726, 37.17350517000471, 45.30287320273263, 44.07070050920759, 46.68449122565133, 45.480653285980225, 47.84146009172712, 40.09411096572876, 30.93925482886178, 47.9006552696228, 43.64391088485718, 49.6747179712568, 45.7420723097665, 45.46338701248169, 43.98423017774309, 43.82305976322719, 40.89680160794939, 42.98829276221139, 38.92773076466152, 36.0622102873666, 31.40821307046073, 32.67985153198242, 31.759361130850657, 32.99266290664673, 38.401099000658306, 44.518834999629426, 44.85383892059326, 47.31367145265852, 45.05468007496425, 47.90970529828753, 44.574503966740195, 40.26064191545759, 32.88067184175764, 32.20886789049421, 31.522076674870082, 32.35187918799264, 34.20408827917916, 38.974377495901926, 46.10605716705322, 46.897995471954346, 47.33304303033011, 45.55352599280221, 46.06474665233067, 44.307411738804404, 44.975154467991416, 47.54521322250366, 48.51863847460066, 48.35135017122541, 46.1926907811846, 46.93329232079642, 48.11861678532192, 50.589166913713726, 43.268426758902415, 34.20186138153076, 21.644343852996826, 13.97032254082816, 15.699586732046944, 13.604656219482422, 7.946131876536778, 6.9891508391925266, 2.130310956920896, 0.932207235268184, 0.10877733983631645, 0.17162916330354555, 4.689087356839861, 21.795712096350535, 39.39146743501936, 33.19173574447632, 35.90049096516201, 36.51824835368565, 42.84733813149588, 36.66272224698748, 10.832371882029943, 0.6818203766431127, 0.05100196593308023, 0.06361759773322515, 0.011490826844237745, 0.018223713551248823, 0.029731080534734895, 0.038502641820481846, 0.008306378033012152, 0.01877557117092822, 0.045281349149133475, 0.006837645304455821, 0.024397391559822217, 0.015429019495578749, 0.09502662412290062, 0.06473808296556983, 0.058566318425749025, 0.02575031914083021, 0.05989913762147937, 0.04370754824153014, 0.08524889379207577, 0.06435513137174503, 0.08763009708906923, 0.011995304059902472, 0.055551085221980295, 0.07028563600033522, 0.03614399642018335, 0.020295725403619663, 0.007594524400441774, 0.024939731029527526, 0.03255735530651041, 0.02997800282069615, 0.03890552877315453, 0.010895068008851792, 0.018969393002667596, 0.06836022503141846, 0.009397593809158673, 0.0667359818305288, 0.0262336294565882, 0.060728266702166626, 0.03535610191257937, 0.02400253846177033, 0.017263674709413732, 0.0336752349643835, 0.04254232380273087, 0.01943466446495482, 0.04389334809301155, 5.3758716242653986, 33.0803040095738, 52.01428760801043, 50.26062829153878, 31.76091057913644, 25.37291397367205, 32.59904398236956, 32.740418979099815, 24.633048943110875, 6.15657729761941, 0.3241156323679856, 0.05903351014213903, 0.2941662094422749, 2.2330455013683865, 5.709121125085013, 5.71893892969404, 6.023376856531415, 6.161957808903285, 6.550174943038395, 13.40865101133074, 23.68803140095302, 33.85100514548165, 45.52664341245379, 50.9059978212629, 47.9167195047651, 45.99122428894043, 42.18654012680054, 37.49691949571882, 34.94338008335659, 33.21409852164132, 34.17328691482544, 34.927024023873464, 35.67224958964756, 37.7557190486363, 35.40700905663626, 33.05925096784319, 33.84683970042637, 33.753313473292756, 33.264146396092, 35.566630022866384, 43.445751735142295, 45.52438872201102, 46.367934771946494, 47.11720766339983, 47.374853815351216, 44.357150418417795, 45.96086066109793, 46.18069124221802, 47.082317284175325, 47.22652019773211, 47.22679465157645, 48.614096300942556, 46.251107760838096, 42.001099654606406, 33.670716762542725, 33.08189167295183, 31.071096897125244, 32.53988354546683, 39.36932005201067, 46.85211304255894, 45.27382625852312, 48.37755530221121, 46.80811357498169, 48.51556737082345, 40.60879182815552, 32.37499237060547, 46.70526286533901, 41.98347554888044, 50.145381995609824, 48.300940990448, 47.873929023742676, 47.316891942705425, 45.480027948107036, 44.21617841720581, 44.09217044285366, 42.2724198613848, 38.41333130427769, 34.25063426154, 35.59392254693167, 33.05618681226458, 34.17513860974993, 40.339142663138254, 46.46536588668823, 46.22925220217024, 48.52350221361433, 46.51479884556362, 50.00438567570278, 45.8585901260376, 43.44241312571934, 35.57313353674752, 33.78015089035034, 34.0045360156468, 34.91144963673183, 35.12755945750645, 42.81973641259329, 48.50234147480556, 49.002670833042686, 49.50649513517107, 48.22199903215681, 48.063903195517405, 47.477044446127756, 47.07387522288731, 49.17348534720284, 49.56873709814889, 48.99909945896694, 47.642963954380576, 49.49113266808646, 51.219913959503174, 53.115855012621196, 46.781116349356516, 34.86638362067086, 21.60499620437622, 11.000576479094368, 9.23355143410819, 10.581488064357213, 7.409151639257159, 5.348380642277854, 3.095384474311556, 0.7536251779113496, 0.14288969045238836, 0.3305202972676073, 4.928205702986036, 26.745513234819683, 47.073031016758506, 41.009490966796875, 42.538883277348106, 42.3658766065325, 48.1131728717259, 42.90560572487967, 15.005030904497419, 0.7611669046538216, 0.04367201675527862, 0.11317066409225975, 0.007964379420237882, 0.06791755557060242, 0.05675309982949069, 0.06275313733411686, 0.04333154145362122, 0.0384965892881155, 0.07544675655663013, 0.045416998477386575, 0.018466208396213393, 0.019386734447575042, 0.04680165774854166, 0.05675621430522629, 0.02917072256760938, 0.056307417673191855, 0.02655634919314512, 0.008434839979080217, 0.030940318147518804, 0.02879356566284384, 0.06699444938983236, 0.15969411230513028, 0.09192971565893718, 0.13783879790987286, 0.07903796421097857, 0.08063427891050066, 0.155149569734931, 0.1763327680528164, 0.16962996843670095, 0.13468928262591362, 0.07956405276698725, 0.07088831080389874, 0.11455269743289266, 0.19062579609453678, 0.09376007744244166, 0.10886584115879876, 0.13902932831219264, 0.14006243859018597, 0.1608013864606619, 0.06714724190533161, 0.0791404637108956, 0.08823971330587353, 0.09197144556258406, 0.24129139525549753, 0.11547132528253964, 5.987979693072183, 36.85098021371024, 57.628400802612305, 57.253903320857454, 40.784178256988525, 36.55283996037075, 41.1294481413705, 39.60979373114449, 29.24598925454276, 8.130221792629786, 0.8099788139973367, 0.20395045966974326, 1.7313754665000098, 5.442455777100154, 12.54614245891571, 16.81054810115269, 17.983365808214458, 7.148289774145399, 4.6740749052592685, 13.583673528262548, 23.103481190545217, 33.7073963029044, 45.29745708193098, 54.43195847102574, 51.551690442221506, 49.12684556416103, 44.35864775521414, 39.074146679469514, 36.39533472061157, 35.317443302699495, 36.15246738706316, 36.58353362764631, 36.83810520172119, 39.82998561859131, 37.84546545573643, 35.35229546683175, 35.85544579369681, 35.54950966153826, 34.80996077401297, 38.508202007838655, 46.02041367122105, 47.899800641196116, 48.68762561253139, 47.17555168696812, 48.97247396196638, 46.57370914731707, 47.05057443891253, 49.73483031136649, 48.99279744284493, 49.49729919433594, 48.49035930633545, 50.826621600559776, 49.02711112158639, 42.88165181023734, 35.84472124917166, 34.79334415708269, 33.180361543382915, 34.113118989127024, 41.26843990598406, 47.53517654963902, 47.00792639596121, 50.874890736171174, 48.58006402424404, 49.535938126700266, 41.60066107341221, 36.15068517412458, 46.73939936501639, 46.02773012433733, 52.279489925929475, 49.95342411313738, 48.58242293766567, 49.579670088631765, 47.168662548065186, 45.42787824358259, 46.41680840083531, 43.341108390263145, 40.76410838535854, 36.655440534864155, 36.991014208112446, 34.92736448560442, 36.21950708116804, 42.15125717435564, 48.92603915078299, 49.087959970746724, 49.78535066332136, 47.70983689171927, 52.21143579483032, 48.955565520695274, 45.50314807891846, 37.08471761431013, 34.5686811038426, 35.43493734087263, 36.00163589205061, 36.921028477805, 43.434877804347444, 51.13834210804531, 51.464709418160574, 52.30527469090053, 48.81588935852051, 49.23936121804373, 49.408671447208945, 49.85342563901629, 51.16655874252319, 52.937703200748985, 52.227256843021934, 48.53194080080305, 51.217377867017476, 51.70305347442627, 55.54834985733032, 47.457645075661794, 38.5000205039978, 24.386063064847672, 15.839396647044591, 20.470577716827393, 20.101949725832256, 15.599414552961077, 12.991243192127772, 6.163119026592799, 2.7586443722248077, 0.5222122211541448, 0.5274882380451474, 6.307678035327366, 29.466538974217006, 51.510869775499614, 44.45571061543056, 46.78114761625017, 48.87228441238403, 54.322812693459646, 52.285201345171245, 19.778314794812882, 1.6806033509118217, 0.14721457766635077, 0.22318232698099955, 0.05001709270956261, 0.1604938879609108, 0.11953485437801906, 0.11608834431639739, 0.09752203843423299, 0.11942491813429765, 0.2158428579568863, 0.18616289485778126, 0.09750844737780945, 0.08087894506752491, 0.2076230983116797, 0.15438952908984252, 0.1414170116186142, 0.09668497727917773, 0.1438576342271907, 0.1354431486023324, 0.1208982483616897, 0.14265996563647473, 0.2829293981194496], [0.03933891587491546, 0.051510846841015985, 0.027795405027323535, 0.019349803482847552, 0.03617378750017711, 0.05869226809591055, 0.05784262011625937, 0.05974899139255285, 0.016025137954524586, 0.04272673944277423, 0.009360208225968693, 0.04880928002031786, 0.019621169992855618, 0.043502318539789746, 0.04791314221386399, 0.02725330983022494, 0.04421560133674315, 0.038036332199616094, 0.043997055385261774, 0.018280191413526024, 0.05923464149236679, 0.03663914717201676, 0.07821625151804515, 0.023319219771240438, 1.3618892644132887, 18.202838557107107, 39.939940861293245, 47.53852558135986, 41.674589906420024, 26.387481246675762, 29.877472809382848, 37.75324548993792, 29.314797265189036, 9.283018265451703, 0.8503591929163251, 0.10610587961439576, 0.26819047757557457, 1.8490446209907532, 3.9450942277908325, 4.0858886156763345, 3.5240329589162553, 3.739018908568791, 5.232460805347987, 4.161395124026707, 12.844368696212769, 25.591236795697892, 38.01117999213082, 48.64731216430664, 45.067020075661794, 41.5439464024135, 38.441075461251394, 36.53779363632202, 35.348341941833496, 34.275335107530864, 32.36786699295044, 32.93684802736555, 32.29780830655779, 32.90755442210606, 30.992630890437535, 32.7295936856951, 31.695006915501185, 32.399710587092805, 30.923204490116664, 39.21305853979928, 43.57458175931658, 46.09976557322911, 45.40555020741054, 45.15055479322161, 44.758328982761924, 42.08163969857352, 42.306813444410054, 41.49708080291748, 43.831234318869456, 46.409224442073274, 44.89896052224295, 45.370889118739534, 46.82125261851719, 40.485572474343435, 34.61483451298305, 30.670759064810618, 30.910808903830393, 33.10156202316284, 41.758096831185476, 44.3676734651838, 45.349547726767405, 46.050346510750906, 45.80882017953055, 45.568096365247456, 41.42520516259329, 30.544680527278356, 48.782048157283235, 44.84336451121739, 44.611815793173655, 42.33073609215872, 43.57898691722325, 41.95209053584507, 43.63538891928536, 41.11674336024693, 41.38153920854841, 37.210330622536794, 33.2308714730399, 33.870501790727886, 32.40367453438895, 33.18699707303728, 34.32739795957293, 40.34360688073294, 42.45372268131801, 45.111175877707346, 46.56682000841413, 44.727743012564524, 47.30820322036743, 43.70197350638253, 41.27618019921439, 33.466773237500874, 34.489020006997244, 32.556920528411865, 31.604975632258824, 31.529962880270823, 33.254269531794954, 38.33989231927054, 42.903750555855886, 44.43186092376709, 45.06224666322981, 41.502469130924766, 41.60472924368722, 41.50622810636248, 42.167585441044395, 45.371458871024, 47.71806355885097, 50.00146048409598, 47.477134772709434, 49.12563310350691, 44.863135610307964, 39.52918073109218, 25.578509432928904, 17.33739525931222, 5.161578323159899, 5.577571749687195, 9.729024870055062, 6.137601767267499, 5.439053331102643, 2.089591473340988, 0.1979095031108175, 0.07388376471187387, 0.376759907496827, 6.0458933625902445, 27.552240780421666, 35.61361026763916, 25.807383094515117, 28.519162518637522, 42.92072153091431, 49.21822827202933, 39.45885106495449, 10.227119513920375, 0.2902400701173714, 0.016366871938641583, 0.06425329683614628, 0.01372379229204463, 0.034300796754126034, 0.03619337680616549, 0.03210908114644034, 0.026286268506997397, 0.06811141302543026, 0.040742105937429836, 0.01206580045566495, 0.03246028408674257, 0.030678393452295234, 0.09394712240568229, 0.04574325168505311, 0.018557408591732383, 0.07289104083819048, 0.0393636993664716, 0.019207969307899475, 0.029878210675503527, 0.04885633642386113, 0.04946145734616688, 0.04302095561953528, 0.03146296992365803, 0.006188324186950922, 0.02802682957345886, 0.03428258826690061, 0.015631686031286205, 0.008241036807053854, 0.029194098099001815, 0.07360872732741491, 0.059894462515200884, 0.04882605340597885, 0.00601352084361549, 0.01948627214213567, 0.05989793661449637, 0.059836339205503464, 0.020971678596522127, 0.032694510982504914, 0.044177287856915166, 0.017606596129813364, 0.049280885607004166, 0.008515796840323933, 0.04600895582033055, 0.06630410107650928, 0.007036224938929081, 2.0840789462838853, 22.291606766836985, 46.58116456440517, 50.80602019173758, 46.024193491254536, 31.66078356334141, 33.24457679476057, 40.29769318444388, 31.325998510633195, 10.164477160998754, 0.9042537095291274, 0.12952242844871112, 0.13213704100676946, 1.7017974193607057, 4.904118469783238, 5.612752650465284, 6.751531566892352, 8.053907121930804, 6.67117087330137, 7.203784167766571, 15.545894316264562, 27.564221211842128, 39.62066766193935, 50.30579853057861, 46.72843163354056, 43.402276856558665, 41.01295811789376, 38.16903611591884, 36.42312404087612, 35.60134669712612, 34.92580461502075, 34.834147453308105, 34.857284954616, 34.053513867514475, 33.682473114558626, 33.37747846330915, 33.25751086643764, 33.19740547452654, 32.61520896639143, 40.17591905593872, 45.269264766148154, 48.61842155456543, 47.15600987843105, 46.39221525192261, 47.052648476191926, 45.20683520180838, 45.08374091557094, 44.05042566571917, 45.88032061713082, 48.404587268829346, 46.64508104324341, 46.30444213322231, 47.937008244650706, 42.85170160021101, 36.904599462236675, 33.37291349683489, 33.37948996680123, 34.58795540673392, 42.25179065976824, 46.9503675188337, 46.7702180998666, 48.570249693734304, 46.67976992470877, 44.98488194601876, 42.45130818230765, 32.83741930552891, 47.31008618218558, 48.568818364824565, 45.81976011821202, 43.31921114240374, 45.19878223964146, 44.363803318568635, 45.73825774874006, 43.414349351610454, 43.420335224696565, 38.87184292929513, 35.54902676173619, 35.48270273208618, 33.56527090072632, 34.33810860770089, 35.92127302714756, 41.213083607809885, 45.32384634017944, 47.481654575892854, 47.543604714529856, 45.635855197906494, 48.86747973305838, 46.297619002205984, 42.64196327754429, 36.017137323107036, 35.21043062210083, 33.6678923198155, 33.84014858518328, 33.429746287209646, 35.346650055476594, 43.51485851832798, 45.15760374069214, 48.33763095310756, 46.533017022269114, 43.867385796138215, 44.931155000414165, 44.00954246520996, 44.968647480010986, 47.71886954988752, 49.51071963991438, 51.050152097429546, 48.70747661590576, 52.613253593444824, 48.40913833890642, 42.40211146218436, 27.80877869469779, 19.257839134761266, 7.918333002499171, 6.286300165312631, 7.023095829146249, 8.653251784188406, 5.274194725922175, 1.7298554394926344, 0.4774663650563785, 0.056196049720581086, 0.3528070513691221, 6.8451164194515774, 28.999441112790787, 42.68144294193813, 32.386522906167166, 32.627785205841064, 46.220160484313965, 53.90152951649257, 45.99846431187221, 11.974210177149091, 0.3937946105641978, 0.009438153239898384, 0.024490033642255833, 0.015251031278499534, 0.07805858033576182, 0.018708995011235987, 0.025506740336173346, 0.06715240555682353, 0.026854979240202477, 0.03997415696669902, 0.02734529203735292, 0.03264348514910255, 0.025246693486613885, 0.051858830132654736, 0.06822955954287734, 0.05741330422461033, 0.003965084690467587, 0.016568525760833706, 0.016896471913371767, 0.013680834240014, 0.026846068379070078, 0.041678643718894036, 0.07271212472447328, 0.27885137551597183, 0.12114903490458216, 0.16059522038059576, 0.11055697434182678, 0.10602408221789769, 0.0908302039440189, 0.13629138522914477, 0.07504229540271418, 0.19596674878682407, 0.15647153237036296, 0.2273892712380205, 0.1824288759380579, 0.1164814332234008, 0.14979448994355543, 0.18791743713830197, 0.10804201143660716, 0.1372654222484146, 0.14040334815425531, 0.09926160544689212, 0.14207736189876283, 0.13449634797871113, 0.1811925172805786, 0.18064906501344272, 2.564374476671219, 24.9251321043287, 52.02777753557478, 58.66350868770054, 53.20915194920131, 37.08449527195522, 39.46976668494088, 48.5950026512146, 37.256352015904014, 13.00141622338976, 1.5544998432908739, 0.2873198725283146, 0.9242646843194962, 5.45569600377764, 8.7333436693464, 9.523313896996633, 11.42624396937234, 8.41967853478023, 7.504391465868268, 5.387892442090171, 15.16297561781747, 28.158318247113908, 40.35228518077305, 53.16946036475045, 49.12814835139683, 46.07769809450422, 42.2522040775844, 40.36773450034005, 38.39268473216465, 38.26267351422991, 36.79531819479806, 36.37114804131644, 36.392840317317415, 35.968534673963276, 34.398432867867605, 36.13144908632551, 34.71739339828491, 34.87989786693028, 33.93246929986136, 44.003629548209055, 48.59531879425049, 52.11858354296003, 49.24157769339425, 46.75411564963204, 48.211465563092915, 47.31574548993792, 46.73981973103115, 45.23217180797032, 48.001397200993125, 50.90301356996809, 48.46052026748657, 46.244222096034456, 50.85260786328997, 45.01005179541451, 39.10074438367571, 34.89918259211949, 35.08233710697719, 36.946344239371165, 46.24832500730242, 48.81900909968785, 49.68513332094465, 49.55301332473755, 48.277278900146484, 46.19212102890015, 43.254836082458496, 36.40412071772984, 50.11351408277239, 51.14152438299996, 46.811830861227854, 46.337776115962434, 46.64244072777884, 46.134690693446565, 47.08961636679513, 46.70258433478219, 45.69523450306484, 39.91660533632551, 35.903628076825825, 38.23306376593453, 35.14494385038103, 36.758666447230745, 37.63518169948033, 43.65270383017403, 47.41017150878906, 51.12202078955514, 47.85808365685599, 46.880937644413535, 51.46948283059256, 48.38345432281494, 46.6466964994158, 38.40257896695818, 38.48460939952305, 35.747592381068635, 35.45940889630999, 35.55822270257132, 37.15122924532209, 44.03758886882237, 46.990118162972585, 51.52781295776367, 49.932298115321565, 45.10386984688895, 46.31583023071289, 46.88889333180019, 47.05342320033482, 50.2865172794887, 51.47784498759678, 53.718861375536235, 48.65135948998587, 52.20660332271031, 48.72710180282593, 43.1855833871024, 28.712067093167985, 20.539331878934586, 6.884326841150012, 9.043995022773743, 18.0452846799578, 12.735387069838387, 14.100043671471731, 7.474127718380519, 1.5543424231665475, 0.1936288292386702, 0.8044509249074119, 8.38031438418797, 34.65547800064087, 46.745843819209504, 36.7955196925572, 39.02008622033255, 55.07177291597639, 62.08503096444266, 52.385873794555664, 14.894617080688477, 0.5228937960096768, 0.14944196385996683, 0.20544205605983734, 0.11391624515610081, 0.13450495180274757, 0.22099688782223634, 0.10279120212154728, 0.1423640429441418, 0.11721207973148141, 0.1844012958130666, 0.16645325746919426, 0.10801657315875803, 0.2105154488235712, 0.20778134624872888, 0.13957753032445908, 0.10745277162641287, 0.14377397085939134, 0.11177446972578764, 0.15419447741338185, 0.0822516485516514, 0.11929636288966451, 0.1895323097705841], [0.044911011521305354, 0.047266596728669744, 0.05251859687268734, 0.020830388945926512, 0.018550104162256633, 0.027995571161487272, 0.020131112808095555, 0.02742666026045169, 0.03472423313983849, 0.034517083183995316, 0.02279529913461634, 0.050382405785577636, 0.024643664148503115, 0.02405436666283224, 0.06152513822806733, 0.016142256491418396, 0.01476421463303268, 0.08127674979290792, 0.040467173725898774, 0.01697300048545003, 0.022258910417024578, 0.019483362923243215, 0.024392226211992756, 0.04264975625223347, 0.5359882190823555, 11.958149416106087, 35.54717854091099, 50.10758032117571, 42.266329765319824, 31.632396697998047, 30.83312109538487, 33.5675881249564, 33.98471280506679, 13.229609830038887, 2.3298473698752264, 0.11863777680056435, 0.06805098948201962, 0.8216841401798385, 3.6141230847154344, 3.498961252825601, 4.553915798664093, 10.562983274459839, 8.358866163662501, 3.8716704419681003, 7.107097378798893, 17.653651203427994, 34.391022614070344, 44.249154567718506, 44.95225320543562, 40.72182512283325, 39.52466440200806, 35.659756728581016, 34.713714327131, 32.630005155290874, 34.081768717084614, 33.64553649084908, 33.14427954810006, 31.52689525059291, 31.59528636932373, 32.454257420131135, 32.508050373622346, 32.51821558816092, 34.0581031526838, 37.902562277657644, 42.78827149527413, 44.12504237038748, 45.30340473992484, 46.32120813642229, 43.90494080952236, 42.638812269483296, 40.157006059374126, 38.70267513820103, 42.39748396192278, 42.96547487803868, 46.33269698279244, 45.742940834590364, 45.11791215624128, 42.47379602704729, 36.05902106421334, 32.24770137241909, 31.031311511993408, 35.06251737049648, 41.92618070329939, 44.38341113499233, 43.67737340927124, 44.92312983104161, 43.0671443939209, 44.351095063345774, 40.199570723942344, 32.90122808728899, 49.57730770111084, 41.39303500311715, 43.51733555112566, 41.7896659714835, 42.617252009255544, 40.743103981018066, 40.757552759987966, 37.36315277644566, 37.60595757620675, 34.22341816765921, 33.392305919102256, 32.58005108152117, 34.52105467660086, 34.26448202133179, 36.155892848968506, 40.52671275820051, 42.06448459625244, 44.08765063967024, 46.50517559051514, 45.549958092825754, 47.040815693991526, 42.698347909109934, 39.775056634630474, 33.30038472584316, 32.605165345328196, 32.61082465308053, 33.43491574696132, 32.23035519463675, 33.57821886880057, 32.847671372549875, 36.543567589351106, 37.78079162325178, 38.424681186676025, 37.891295773642405, 37.36996895926339, 37.346188749585835, 41.75607143129621, 42.77978079659598, 46.385711738041465, 49.06970010484968, 50.18413209915161, 42.391560622623985, 38.61712544304984, 31.08007049560547, 17.723963499069214, 9.046238422393799, 5.164648124149867, 3.8686293022973195, 3.9913253699030196, 6.674929848739079, 2.9594077936240604, 1.2903565828289305, 0.27792156540921753, 0.09154518986386911, 0.5213643237948418, 7.45902407169342, 29.198133536747523, 38.98729419708252, 33.40323543548584, 34.07467460632324, 46.52658993857247, 50.81296491622925, 33.62016861779349, 6.1964061089924405, 0.10020530516547815, 0.012145248424660946, 0.055879723480237384, 0.033252690852220566, 0.015787309734150767, 0.03925695902268801, 0.01197593188512006, 0.03946775271158133, 0.08115187220807586, 0.05726532930774348, 0.018391033501497338, 0.05060717390318002, 0.036698854860982726, 0.03868512702839715, 0.05647242721170187, 0.06759710383734532, 0.029296777410698787, 0.01783746766990849, 0.02034729576137449, 0.04109160236216017, 0.05779090217713799, 0.018308219998808842, 0.06225450909031289, 0.018708696455827782, 0.045019539804863076, 0.06988911370613746, 0.01783693501991885, 0.040291796172303815, 0.013270591119570392, 0.01737237093038857, 0.028940912934818437, 0.029878794215619564, 0.016297759754317145, 0.034545194889817915, 0.07188418986541883, 0.008468581829220057, 0.043527342911277495, 0.05098487024328538, 0.02607775978477938, 0.08651875172342573, 0.047358046285808086, 0.03420301307258861, 0.09070669699992452, 0.020037530954661112, 0.0062070364864276984, 0.05257591951106276, 0.7348121159843036, 14.590636866433279, 41.053275040217805, 55.361995697021484, 45.92742245537894, 33.13036578042166, 34.294519083840505, 40.131381102970664, 38.51263843263899, 15.222716229302542, 2.035353400877544, 0.09814994795514004, 0.021625555652592863, 1.0869130023888178, 2.4175403671605245, 6.267757160323007, 8.277140583310809, 8.008956619671412, 6.170801997184753, 5.87744905267443, 9.963358078684125, 21.21047748838152, 36.75539037159511, 47.75266906193325, 47.26500974382673, 44.872981207711355, 41.40402705328805, 37.383017676217214, 36.531217166355674, 34.33160161972046, 35.091376713344026, 34.66485806873867, 34.37882852554321, 33.30805206298828, 33.61551332473755, 35.186320372990195, 33.89978149959019, 35.312041078295024, 35.297953605651855, 39.460143429892405, 44.94921684265137, 47.05348573412214, 45.54073783329555, 48.054307733263286, 45.757657119206016, 44.59789855139596, 42.6819293158395, 41.5067492212568, 44.31509992054531, 45.2699248450143, 46.670101506369456, 46.81967190333775, 47.149895463671, 43.84977558680943, 37.31557151249477, 34.2927542413984, 32.301886899130686, 36.61452954156058, 42.979649203164236, 47.43847499574934, 45.7207795551845, 45.75961651120867, 44.632764611925396, 44.38746888296944, 40.5351687158857, 35.67732524871826, 51.872391496385845, 43.74202639716012, 45.52349935259138, 43.983604839869905, 44.47653784070696, 42.64202928543091, 42.969966888427734, 39.582845142909456, 38.28961515426636, 36.12073496409825, 34.82348196847098, 34.54276432309832, 35.27646630150931, 35.58381291798183, 37.07675150462559, 42.5749374798366, 43.68236916405814, 46.727451937539236, 46.32949038914272, 45.20921843392508, 48.77054194041661, 44.991051946367534, 42.14587926864624, 35.233477796827046, 35.19706228801182, 34.77198192051479, 35.32230704171317, 33.270503997802734, 35.71858365195138, 35.16815778187343, 39.4564574105399, 40.53830930164882, 41.19263505935669, 40.55113220214844, 40.09558398383004, 39.72216694695609, 44.11839641843523, 45.47142955235073, 47.668363094329834, 51.93348005839756, 51.738471916743684, 45.59706340517317, 40.00278731754848, 33.819769518715994, 23.173056977135793, 13.037215948104858, 7.502049054418292, 5.24706939288548, 3.970153774533953, 6.92107195513589, 5.29641853911536, 2.50831185068403, 0.8041600776570184, 0.15245110381926807, 0.6848235183528492, 7.943525433540344, 35.10644735608782, 43.07968589237758, 32.761541502816335, 38.037666525159565, 52.47155203138079, 57.1433470589774, 39.02769102369036, 7.719051718711853, 0.286595957087619, 0.0949242196178862, 0.020193339558318257, 0.01552821452995496, 0.02012502125996564, 0.04736057722142764, 0.01223787693639419, 0.021583147213927338, 0.010999727794634444, 0.03568273509985634, 0.0523432091410671, 0.06982219658259835, 0.013227217464840837, 0.02391048500846539, 0.018863229413649867, 0.03118961530604533, 0.020320234088493244, 0.035943513070898395, 0.06481781083026103, 0.003550149712412219, 0.05201158193605287, 0.06245700429592814, 0.10907309289489474, 0.11672395520976611, 0.17543518835944788, 0.08239640042717968, 0.1012563423386642, 0.09537832239376647, 0.14901659025677613, 0.0817863160212125, 0.129270271265081, 0.18377038038202695, 0.12574141419359616, 0.13735444604286126, 0.15984709481043474, 0.14404716262859957, 0.1489456154938255, 0.12515795550176076, 0.18486747651227883, 0.20804461783596448, 0.1475025207868644, 0.09333257323929242, 0.10364716726222209, 0.1248488285179649, 0.10939969894077096, 0.17145872887756142, 1.0510642060211726, 16.265255212783813, 46.65436036246163, 62.406426838466096, 52.271773951394216, 40.39741025652204, 41.696250915527344, 43.09956816264561, 43.46746832983834, 17.88095804623195, 3.4201877883502414, 0.34851529023477007, 0.7232087871858052, 2.344713692154203, 8.108180369649615, 10.695398569107056, 13.16445483480181, 18.199988058635167, 14.790816204888479, 6.752404868602753, 9.869365453720093, 21.79515102931431, 37.95506634031023, 50.252769878932405, 49.66678312846592, 46.58222763878958, 43.21403626033238, 40.34612560272217, 38.80582114628383, 37.04432773590088, 37.92876393454415, 36.64796774727957, 36.24029609135219, 35.0358293397086, 34.27257319859096, 37.337166513715474, 36.378718103681294, 37.04313611984253, 37.631811823163716, 41.371801308223176, 46.82606424604143, 48.193396772657124, 46.965591021946494, 50.739421708243235, 48.84877518245152, 46.01966673987252, 43.92607722963606, 42.38177408490862, 46.263169833592, 47.74645389829363, 49.89266906465803, 48.72025087901524, 47.86902012143816, 45.02256202697754, 39.14570617675781, 36.21790552139282, 34.01357214791434, 37.79524040222168, 45.58249650682722, 47.610977922167095, 46.832779679979595, 47.95933975492205, 44.525102274758474, 44.68373312268938, 41.16800716945103, 39.30783544267927, 51.7420780318124, 45.881988184792654, 48.767401354653494, 46.528094223567415, 45.921099594661165, 45.41299172810146, 43.81848437445504, 41.442450591496055, 39.51983192988804, 37.95384693145752, 36.51626811708723, 36.683229855128694, 36.72024290902274, 38.12240328107561, 39.24495424543108, 43.69325699125017, 45.03834138597761, 47.6021328653608, 48.39628069741385, 47.66539968763079, 49.718929358891074, 45.6785067149571, 43.3127041544233, 37.209951945713584, 35.98389366694859, 37.04283387320382, 38.20699759892055, 35.720657689230784, 36.86076675142561, 36.482058661324636, 41.32603699820382, 42.29707554408482, 43.36794580732073, 41.299185684749055, 41.643847601754324, 41.63926526478359, 45.406349250248496, 48.56602866309029, 51.86020088195801, 53.4511889730181, 54.339429310389924, 47.06751067297799, 42.117926665714805, 33.40549012592861, 20.82481598854065, 10.277256846427917, 8.915838973862783, 8.7029835156032, 9.624597787857056, 12.719225559915815, 10.19496238231659, 7.405720966202872, 1.6134137277092253, 0.5128213507788522, 0.9257977391992296, 10.332223176956177, 38.865891797201975, 51.28182240894863, 44.73666449955532, 46.754820891789024, 59.41354588099888, 63.45912061418806, 45.135650907244, 9.895924074309212, 0.45399573019572664, 0.13354452619595186, 0.11482097660856587, 0.1735771694885833, 0.17777040733822755, 0.10949000516640288, 0.06928587571850844, 0.09635943653328077, 0.1507397706487349, 0.11360076708453042, 0.13269862372960362, 0.2121581413916179, 0.09227238941405501, 0.1774740775248834, 0.16917924476521357, 0.12421947371746812, 0.11731163438941751, 0.120655821370227, 0.18322973724986824, 0.12697641578103813, 0.09579547893788133, 0.14805890593145574], [0.06448399195713655, 0.03794446195076619, 0.027291772587757026, 0.03126993688887783, 0.013810625266549843, 0.02455287955568305, 0.013520476907225592, 0.05177012524966683, 0.08698523776339633, 0.022838789836636612, 0.08078493404069118, 0.08245213529361145, 0.024365356225254278, 0.03140612565247076, 0.009038412145205905, 0.01703167680118765, 0.03756044505696211, 0.047315841407648156, 0.035970617152218304, 0.010961318471735077, 0.02007344750953572, 0.04539351098771606, 0.05131269765219518, 0.006909061115168567, 0.14571838080883026, 6.495944253035954, 27.67877095086234, 46.935408047267366, 47.06242111751011, 35.7235620362418, 25.832794393811906, 36.55282606397356, 32.492597579956055, 19.132806301116943, 3.8644538692065646, 0.2150521068168538, 0.22205370611378125, 1.0385247703109468, 1.67520948605878, 4.801140521253858, 5.353114102567945, 6.071485749312809, 2.61391795533044, 3.3158820824963704, 4.331159591674805, 9.895924074309212, 25.90607009615217, 42.24407121113369, 44.961605480739046, 41.32710007258824, 40.99937438964844, 39.934601170676096, 39.97548089708601, 41.34161138534546, 39.871007783072336, 39.74035733086722, 39.060298919677734, 35.48266451699393, 34.45877449853079, 34.50053317206246, 34.51192126955305, 33.60603945595877, 34.42965112413679, 39.983606815338135, 43.451251234327046, 44.92695828846523, 45.176714760916575, 46.22303009033203, 44.53339842387608, 41.64442777633667, 39.044880867004395, 35.61616373062134, 40.51260791506086, 42.19566658564976, 45.73536034992763, 45.42247254507882, 43.89521680559431, 43.29919685636248, 37.077279567718506, 32.82485348837716, 32.06271253313337, 34.72925744737898, 41.28102656773159, 45.23742117200579, 45.06961522783552, 44.207041536058696, 44.11433172225952, 44.08453089850289, 40.34497914995466, 34.13819851194109, 49.225332805088584, 42.02172538212368, 41.161795479910715, 37.17595441000802, 38.74708802359444, 36.811910493033274, 36.29586083548409, 34.27106196539742, 34.928729806627544, 32.360300404684885, 32.80389772142683, 32.13366058894566, 33.82112094334194, 33.42627566201346, 38.80037375858852, 43.20603540965489, 43.57716301509312, 45.4379427092416, 45.764358656747, 46.98759944098336, 46.373038223811555, 44.140213762010845, 40.27183893748692, 34.710611956460134, 35.48597880772182, 34.06095538820539, 34.30399990081787, 32.52973917552403, 33.60098811558315, 33.5500682422093, 33.129757813044954, 33.9465011869158, 32.42184059960501, 34.87545449393136, 34.35871001652309, 36.596596240997314, 37.40797560555594, 41.39417103358677, 43.77433899470738, 48.85946498598371, 48.94557053702218, 45.53102077756609, 33.16504771368844, 23.497365883418492, 14.586342879704066, 8.505287289619446, 4.04694960798536, 4.369999153273446, 2.746860010283334, 7.734262193952288, 3.2877538204193115, 0.6332983917423657, 0.7622581518122128, 0.1035599619416254, 1.1282897421291895, 9.097930414336068, 35.447683811187744, 46.30802740369524, 39.896834237234934, 39.276832580566406, 48.776124817984446, 48.197794982365195, 24.59113219806126, 4.789586969784327, 0.06384567370904343, 0.035830302895712, 0.043632950101579936, 0.06323126703500748, 0.032879045366176536, 0.05357967636414936, 0.009716785163618624, 0.03816081962681242, 0.06916517112404108, 0.04510160183001842, 0.0405419652483293, 0.016676533268764615, 0.028437397542542646, 0.05646855956209557, 0.05908053261893136, 0.051420133494372876, 0.05840694412056889, 0.028723710482673984, 0.0691288627151932, 0.010361541860869952, 0.031122586224228144, 0.0560371537825891, 0.07949195842125586, 0.034098851161875894, 0.04355079986687217, 0.04777952849066683, 0.0074638690899259275, 0.0023864977785186575, 0.014850773649024112, 0.022894105707694377, 0.08551657585693256, 0.02380792104772159, 0.07676614075899124, 0.035000593667583804, 0.04807004665157624, 0.019525411738348857, 0.027806083472179513, 0.060123949843857966, 0.033942754180835824, 0.04019983432122639, 0.05190064146050385, 0.06714199004428727, 0.05403948901221156, 0.03861532273835369, 0.02119096415117383, 0.03209473352347102, 0.22467586398124695, 8.128486480031695, 33.890481335776194, 52.27004732404436, 52.01282153810774, 39.64350986480713, 29.690191064562114, 36.20917510986328, 35.260092871529714, 21.362834112984793, 3.9840527772903442, 0.2199913803488016, 0.09197406470775604, 0.6356277210371835, 3.2817212641239166, 4.784983788217817, 8.017970170293536, 7.839827912194388, 6.099807475294385, 5.584636330604553, 6.404277971812657, 14.794354575020925, 28.887357984270366, 42.92590488706316, 47.83019011361258, 44.23638377870832, 42.58459894997733, 41.07947669710432, 42.15857710157122, 40.49939244134085, 40.97025796345302, 41.19624464852469, 39.165018694741384, 37.43615402494158, 34.92417526245117, 34.707808358328684, 35.198427609034944, 34.02671813964844, 36.243804931640625, 41.51030322483608, 44.57933643886021, 45.81659868785313, 46.261491843632285, 48.53254876817976, 45.50890466145107, 43.71545648574829, 40.91268171582903, 37.56989989961897, 42.6657087462289, 44.60123716081892, 47.952099731990266, 47.76325464248657, 45.49700239726475, 45.79028933388846, 39.13307435171944, 33.15379510607038, 32.84079613004412, 36.10199567249843, 43.99493735177176, 47.16521624156407, 47.26705946241106, 45.54308979851859, 45.6332357270377, 45.26495688302176, 41.111560004098074, 35.913101945604595, 50.05233866827828, 44.93046365465437, 43.65008435930525, 39.908274446214946, 41.27531167439052, 38.727778979710166, 38.9129067829677, 36.230554716927664, 36.23595346723284, 34.539759227207725, 34.522274085453574, 34.052680083683555, 36.142111097063335, 36.02899442400251, 39.22922352382115, 44.4905732018607, 45.61751195362636, 47.72980948856899, 47.65918452399117, 47.79132189069475, 48.578594480242046, 46.3541009085519, 41.46979522705078, 36.236926215035574, 36.936630657741, 34.351362296513145, 35.4074433190482, 34.45881618772234, 35.165868350437705, 34.83023909160069, 35.24712405885969, 35.81967299325125, 34.410824980054585, 36.77418177468436, 36.25518955503191, 37.58305631365095, 39.71481227874756, 42.42708676201956, 45.04993098122733, 49.434636865343364, 51.443520886557444, 46.59238937922886, 36.09895583561489, 26.433415787560598, 15.632468870707921, 9.839856454304286, 7.290817737579346, 6.001123079231807, 5.87896419422967, 6.410381095749991, 4.535170861652919, 1.839728172336306, 0.38954334439975874, 0.09960688477648155, 0.9942093768290111, 10.028393217495509, 36.3428167615618, 44.0331072807312, 39.169677461896626, 42.26838295800345, 53.76702281406948, 56.03317778451102, 29.031573057174683, 6.387022120612008, 0.08652364396091018, 0.035286260303109884, 0.08737917483917304, 0.030974791119141237, 0.01508254764069404, 0.039877720177173615, 0.03526002813928893, 0.03270876021789653, 0.03723782540432044, 0.021459234845159308, 0.043068432714790106, 0.04974647598075015, 0.016792065730052333, 0.025080932470570718, 0.028171652695164084, 0.0575258731842041, 0.0389792923150318, 0.037860744300165346, 0.04880398405449731, 0.030878944655082056, 0.06240946613252163, 0.0091308642378343, 0.11232779467744486, 0.18598172600780213, 0.12380558092679296, 0.14666416362992354, 0.11424441183251993, 0.1271150947681495, 0.1261015941521951, 0.0853080213336008, 0.14350175618060998, 0.12578175988580498, 0.13369801081717014, 0.14364990751658166, 0.2339303216763905, 0.14728963721011365, 0.08743096741714648, 0.14151609130203724, 0.09298809458102499, 0.17924300474779947, 0.11785530378775937, 0.1268704964646271, 0.1180778361324753, 0.11834523321262427, 0.1241897131715502, 0.08791702919240509, 0.3801656647452286, 10.374892933028084, 38.9953019959586, 58.13200623648507, 58.43191133226667, 47.15017339161464, 35.55065264020647, 46.48819419315883, 44.12947184698922, 24.955042362213135, 5.596558570861816, 0.46747756962265286, 0.46925017450537, 2.9483243312154497, 7.678190231323242, 13.073265807969229, 12.574604885918752, 11.940686855997358, 5.228387423924037, 7.69985818862915, 6.189118317195347, 14.197844777788434, 29.311413492475236, 46.44335051945278, 49.59046064104353, 46.68286187308175, 44.90352896281651, 43.26204136439732, 44.59467806134905, 44.33748006820679, 44.18735728945051, 43.1044979095459, 41.87077924183437, 39.663777760096956, 36.21112060546875, 36.98270763669695, 36.93003681727818, 36.80410419191633, 36.94571195329939, 43.00069877079555, 46.664021832602366, 47.42588485990252, 45.796271732875276, 50.79565347943987, 47.52810328347342, 45.97926296506609, 42.71379722867693, 38.58727250780378, 44.608755111694336, 46.0345185143607, 49.77138131005423, 49.29754890714373, 47.06160817827497, 47.89709779194423, 40.26415770394461, 36.130208832877024, 33.83729634966169, 37.804429394858225, 45.56779064450945, 49.49197340011597, 48.44407735552107, 47.269310678754536, 46.61342505046299, 45.642004353659495, 42.16442401068551, 40.69335487910679, 51.91576215199062, 45.86088650567191, 45.28365795952933, 41.000315870557515, 42.909691265651155, 41.144209589277, 40.75265080588204, 37.68885653359549, 38.198767457689556, 35.92355898448399, 36.42953722817557, 35.851575647081646, 37.93487140110561, 36.89130408423287, 42.27306604385376, 46.65072992869786, 46.57816641671317, 49.90277869360787, 46.998879841395784, 48.35586997440883, 51.823100975581575, 48.55277150017874, 43.85049819946289, 38.93651328768049, 37.96303244999477, 36.90421731131417, 37.306733403887065, 35.87646409443447, 37.63057851791382, 37.41564989089966, 36.44103649684361, 37.749882561819895, 35.649997983660015, 39.54864263534546, 37.85239280973162, 39.506612982068745, 41.23727723530361, 45.92700556346348, 47.33790329524449, 53.039928572518484, 51.81125429698399, 47.43605702263968, 34.820956298283164, 27.109777757099696, 17.002092565808976, 11.951782260622297, 8.122732503073555, 9.431811332702637, 8.408616134098597, 14.738638707569667, 10.475411653518677, 4.522446972983224, 1.849987838949476, 0.21117828254188808, 1.59778408067567, 11.81330292565482, 43.70781346729824, 57.030574321746826, 51.3168864931379, 49.95883675983974, 61.01878125326974, 61.44059944152832, 34.84944043840681, 7.441998379571097, 0.2555657635842051, 0.16910129466227122, 0.16197381354868412, 0.14388867041894368, 0.1391875898199422, 0.24617296616945947, 0.07387072326881544, 0.08473573132817235, 0.18695672654679843, 0.1870947541402919, 0.1890269233179944, 0.11245486393038716, 0.11455842426845006, 0.18043459366474832, 0.12330942255045686, 0.1418504055057253, 0.16120544049356664, 0.11229135734694344, 0.14504165069333144, 0.12642589317900793, 0.17021156794258527, 0.105585246479937], [0.06585258351905005, 0.02188437944278121, 0.04926813932667885, 0.01945054896974138, 0.031482314957039695, 0.06606801838747092, 0.012691325774150235, 0.024043623757149492, 0.044599608052521944, 0.0037025819682250066, 0.040481517956193, 0.028985251805612018, 0.021666627377271652, 0.05594840479482498, 0.017451462668499777, 0.0037966392202568905, 0.05474365569118943, 0.03489026726622667, 0.041206651367247105, 0.0681602946881737, 0.061880371666380336, 0.046232217590191534, 0.04988288866089923, 0.015606826204540474, 0.0907737294744168, 4.077587689672198, 22.097753763198853, 46.128440788814, 44.41956956045968, 34.48295770372663, 28.330713476453507, 36.76433270318167, 34.04748977933611, 26.32654901913234, 5.693167192595346, 0.7541636633021491, 0.0742570607523833, 0.20945135663662637, 2.0114867729800086, 3.155129428420748, 7.021676225321634, 5.106484319482531, 5.315904762063708, 3.421322298901422, 4.055114609854562, 7.109187049525125, 19.776483944484166, 37.20530707495553, 47.33502326692854, 43.973366669246126, 44.76029532296317, 41.127269881112234, 43.10911846160889, 41.98209285736084, 43.12894514628819, 41.21534524645124, 41.17748103822981, 37.84834895815168, 39.83810806274414, 38.89897564479283, 39.340217522212434, 37.75305788857596, 39.3081168447222, 39.51090349469866, 43.097369057791575, 45.33405671800886, 44.289044175829204, 45.300684520176475, 42.86697374071394, 42.08116374697004, 36.61879226139614, 34.08006988252912, 36.32592569078718, 38.25939049039568, 40.974364348820274, 45.1507111276899, 43.6293683052063, 42.32251984732491, 38.29433298110962, 34.27935464041573, 30.768871103014263, 34.44522551127842, 41.24001135144915, 43.706944942474365, 46.38872725622994, 46.15414912360055, 43.76107488359724, 45.164030824388774, 41.12047106879098, 32.66477741513933, 47.92844458988735, 40.61592762810843, 40.601475375039236, 35.063139234270366, 33.6665096282959, 34.70395558220999, 36.40577786309378, 32.476227624075754, 33.119537012917654, 32.452138219560894, 31.66726623262678, 32.216726303100586, 33.63842500959124, 33.04917260578701, 39.021368162972585, 43.959577969142366, 43.68676042556763, 46.51017829350063, 45.130467551095144, 46.242738655635286, 47.654480593545095, 43.93631192616054, 41.94687243870327, 35.33331298828125, 36.22796303885323, 34.613076618739534, 36.93645347867693, 38.86696529388428, 36.51064702442714, 34.192533424922395, 34.28108474186489, 33.57593291146414, 33.87567819867815, 32.1668312890189, 35.007577964237754, 35.83561910901751, 38.26228094100952, 39.190522057669504, 43.234665461948936, 45.218647139413015, 49.36531468800136, 39.16160365513393, 28.051781518118723, 17.694847072873795, 9.094893183026995, 4.310865206377847, 5.57414368220738, 3.643322237900325, 2.506671641554151, 3.7893464480127608, 3.338761631931577, 1.398739904165268, 0.6933871188334056, 0.1276965042842286, 1.1923059927565711, 12.356333306857518, 35.18446520396641, 47.500025612967356, 29.50286763054984, 31.98883581161499, 51.121617794036865, 44.48352772848946, 21.353870936802455, 3.4293251037597656, 0.04639067926577159, 0.021888800098427703, 0.017095979868567417, 0.06675202239836965, 0.024455438534330045, 0.00623820668884686, 0.0821805652230978, 0.0008566342928263891, 0.06028535296874387, 0.0347117786295712, 0.016788130226944174, 0.031365372839250734, 0.0851247693811144, 0.09243972972035408, 0.07989367150834628, 0.01628115091339818, 0.050935459323227406, 0.03121813413287912, 0.07601519248315267, 0.05726497646953378, 0.028776802455208132, 0.027435167393247997, 0.06660818654511656, 0.027739770244807005, 0.03538225943754826, 0.05236251685502274, 0.011145678132639399, 0.055679721890815666, 0.06549469700881413, 0.024687753657677343, 0.062038857090686045, 0.010009740961582532, 0.015307334418009435, 0.045920681807079484, 0.024741435955677713, 0.03821898704128606, 0.03963714558631182, 0.04814495691763503, 0.08946849272719451, 0.047761879794831784, 0.06113665657384055, 0.03976058806957943, 0.03453078959137201, 0.04745562979951501, 0.012108561732540173, 0.07851597400648253, 0.146974077714341, 5.12934866973332, 26.114276341029576, 51.53297199521746, 50.769055775233674, 39.68673460824149, 31.875469003404888, 39.56512723650251, 42.08064958027431, 28.410612549100602, 7.009251977716174, 0.49484625245843616, 0.040022197246019325, 0.5020167391215051, 1.7865321125302995, 5.543001421860286, 6.0610017861638745, 5.527481751782553, 8.917629872049604, 4.0555315017700195, 5.426395016057151, 9.389800786972046, 23.435881274087087, 41.128892285483225, 48.00138677869524, 46.03999022075108, 46.183011940547395, 44.053726060049875, 45.36002908434187, 43.829354831150596, 44.69633020673479, 43.2149464743478, 42.60096543175833, 40.22170073645455, 41.874545165470664, 39.403519085475374, 40.08618654523577, 39.050807680402485, 40.44329268591744, 41.224951131003245, 45.28327580860683, 47.134036200387136, 45.27551467078072, 47.59283964974539, 45.94354575020926, 45.14599677494594, 38.539263929639546, 36.347649233681814, 38.1229521887643, 40.20369100570679, 43.55109337397984, 47.031532900674, 44.555160181862966, 43.888084479740684, 40.683856691632954, 36.01071718760899, 31.84163475036621, 36.49897057669503, 42.674456528254915, 45.61335693086897, 47.282053674970356, 45.98260504858834, 44.35439198357718, 44.8263692174639, 41.510890347617014, 35.383079460689, 50.15535960878645, 42.135516030447825, 42.71050378254482, 36.6381881577628, 36.242380550929475, 36.58474261420113, 37.861574854169575, 33.619814259665354, 34.89103235517229, 33.739198207855225, 33.19329908915928, 35.11162723813738, 35.11661604472569, 35.18967635290963, 41.56973811558315, 45.29708535330636, 45.65542132513863, 47.89805664334978, 45.89720473970686, 47.44156347002302, 49.285198484148296, 45.138152258736746, 42.64075081689017, 37.65444905417306, 36.97561352593558, 36.091121741703574, 38.26704740524292, 39.43419885635376, 37.325229508536204, 35.97510766983032, 34.54217720031738, 35.380821296146934, 35.44806943620954, 33.936103207724436, 37.092044489724294, 37.721874373299734, 38.36177567073277, 41.34916407721383, 46.11642735345023, 48.68310580934797, 50.793899059295654, 42.210066727229524, 29.467869554247173, 22.682251862117223, 11.476419516972133, 7.167431627001081, 5.816255399159022, 7.4391626460211615, 6.590984753199986, 6.544566443988255, 5.128919184207916, 2.7764289379119873, 0.9086092529552323, 0.10888524047498192, 1.437334107501166, 12.844141142708914, 39.42192486354283, 50.9016169820513, 37.949007511138916, 38.96401425770351, 56.50024264199393, 51.1730865750994, 25.221179212842667, 4.304775978837695, 0.04446732425796134, 0.04360940493643284, 0.010206236221295382, 0.06790803572429077, 0.027603059009249722, 0.025694463834432617, 0.026224689757717506, 0.02200811369610684, 0.08208584851984467, 0.0956337908282876, 0.04897599946707487, 0.04190364593107786, 0.05189108429476619, 0.03223001305013895, 0.10172660781868867, 0.031351025216281414, 0.06554487467344318, 0.02818732346141977, 0.05182122572192124, 0.021139750024303794, 0.012757166571516012, 0.028130847295480113, 0.15769874437579087, 0.13326655754021235, 0.16499842410641058, 0.07092099583574704, 0.12512523654316152, 0.2307092345186642, 0.24695225006767682, 0.1199382705880063, 0.16389580470110687, 0.09171647924397673, 0.07683265754686934, 0.10233011722032513, 0.16231815649994782, 0.16362095730645315, 0.04216042733086007, 0.12449400898601327, 0.17809526276375565, 0.10148162953555584, 0.12342797618891511, 0.14888628439179488, 0.16425793884055956, 0.12818173824676446, 0.13042493430631502, 0.1785045957991055, 0.1867388489523104, 6.493525845663888, 30.14856025150844, 57.6370895249503, 55.353807244982036, 45.78714874812535, 38.59266778400966, 47.92424440383911, 44.55550411769322, 33.93977880477905, 8.581999744687762, 1.0897564440965652, 0.2279773439679827, 1.0792340487241745, 3.425254545041493, 11.009913989475795, 15.181808710098267, 11.768252543040685, 12.682001454489571, 6.701302605015891, 7.1953577399253845, 9.836063606398445, 23.349054847444805, 42.16007791246687, 52.097120557512554, 47.82900891985212, 49.98913090569632, 44.627998147692, 48.6707831791469, 45.62468944277082, 47.638169697352815, 44.8963167326791, 44.760646206992014, 40.769211837223594, 43.07249103273664, 41.521479402269634, 43.677359512874055, 41.424572876521516, 43.50982107434954, 43.56486470358712, 47.01241840635027, 47.53285585130964, 45.13774578911917, 50.21403019768851, 48.4485867364066, 47.08071572440011, 40.31583145686558, 37.526060240609304, 39.98780352728707, 41.5115886415754, 46.3731563431876, 48.80307340621948, 47.36377143859863, 45.98479373114449, 42.920297690800254, 37.6179849079677, 33.66517210006714, 38.38970742906843, 46.19881909234183, 47.084641456604004, 49.520930017743794, 48.29272474561419, 47.332608767918174, 46.02946022578648, 42.08539867401123, 38.5333058493478, 51.73556409563337, 44.30137722832816, 44.8482734135219, 38.993189743586946, 37.10188661302839, 38.20347138813564, 39.117659773145405, 34.498994146074565, 36.35658809116909, 36.61447395597185, 34.49783379690987, 36.65554475784302, 36.39389991760254, 36.27849381310599, 42.523329734802246, 47.51241077695574, 48.307354177747456, 49.1890458379473, 47.58967127118792, 47.716152804238455, 53.332284450531006, 47.00722115380423, 45.440787996564595, 39.44652843475342, 39.36691944939749, 38.45848764692034, 40.53170156478882, 43.68998438971383, 40.52283566338675, 37.14890507289341, 36.87173100880214, 37.314758573259624, 37.107153347560335, 35.1236788885934, 39.69497169767107, 40.251032556806294, 40.33868408203125, 42.166206223624094, 47.54438986097063, 50.30060822623116, 53.228822299412315, 43.71861096790859, 31.947118827274867, 21.325887066977366, 12.427142398697988, 7.643639445304871, 8.855931605611529, 8.417931931359426, 9.578707541738238, 11.813230838094439, 11.972145693642751, 6.215081998280116, 1.6169988896165575, 0.37051380266036305, 1.7445548964398248, 15.855059623718262, 44.86857257570539, 59.794133458818706, 41.84495278767177, 42.93833868844168, 61.8587281363351, 58.299853869846885, 31.04410661969866, 5.2535998310361585, 0.16760432427482946, 0.16271994422589028, 0.09482945541718177, 0.1914943480598075, 0.08038890707705702, 0.14937964720385416, 0.11777649873069354, 0.08482945737029825, 0.24202006044132368, 0.20094140113464423, 0.19319983225847992, 0.15564001484641007, 0.14296143874526024, 0.13734073963548454, 0.19233242023204053, 0.11727568560412951, 0.1539836023002863, 0.1483381638037307, 0.18804162261741503, 0.12748457065650395, 0.1337312047502824, 0.16930804428245338], [0.032380766567907164, 0.036324021938656054, 0.02183525181109352, 0.04584173425765974, 0.010238135000690818, 0.07782362401485443, 0.02395860501565039, 0.02695217089993613, 0.04221962272588696, 0.05546475860423275, 0.06511814400021519, 0.05216653558558651, 0.03229032802794661, 0.014791742798739245, 0.03887912697557892, 0.05550421880824225, 0.05998267885297537, 0.037400052949254, 0.06085344284240689, 0.04796322488359042, 0.03950236817555768, 0.03237312626359718, 0.02590718286644135, 0.04383529942216618, 0.03271145060924547, 1.4172114729881287, 15.984961407525198, 40.73452990395682, 48.60772132873535, 42.51159075328282, 31.936519350324357, 30.081218310764857, 27.44166714804513, 26.518347093037196, 10.49360464300428, 1.147131736789431, 0.08446165746343987, 0.31849440400089535, 1.6837449137653624, 3.714983786855425, 4.736476676804679, 4.758492044040135, 7.917413234710693, 4.76096647126334, 3.3185471509184157, 5.583358730588641, 14.102318337985448, 33.301239354269846, 45.19444308962141, 46.280331884111675, 47.30377721786499, 45.854532378060476, 46.17518132073538, 45.391327244894846, 45.854178019932334, 47.292118140629356, 46.033306053706575, 44.309127943856375, 43.2505281993321, 42.181315081460134, 43.57010364532471, 40.77694518225533, 40.69368144444057, 42.585224287850515, 44.83891419001988, 45.87994194030762, 45.30698653629848, 43.265810762132915, 42.37163666316441, 40.81643526894705, 34.76480443137032, 33.69155788421631, 34.25619282041277, 37.75002499989101, 42.03476020268032, 42.932811396462576, 42.22366782597133, 43.557916504996165, 39.65458876746041, 35.29954126902989, 31.16532141821725, 35.095545632498606, 37.67498445510864, 42.2579676083156, 44.082554136003765, 45.56508779525757, 44.928240231105256, 43.03003753934588, 41.41773932320731, 30.75080231257847, 48.436830384390696, 42.701505865369526, 41.0082402910505, 36.95770106996809, 33.991101673671174, 33.71714462552752, 33.36284555707659, 31.637868404388428, 32.846848011016846, 33.480245794568745, 33.43056617464338, 32.815066950661794, 32.91249459130423, 35.05148710523333, 40.1142121042524, 43.2250144141061, 43.51493494851248, 45.16251959119524, 43.24827698298863, 45.358646392822266, 46.990934576307026, 46.47683041436331, 42.176333223070415, 40.29582759312221, 41.21235057285854, 42.43463945388794, 42.454341070992605, 42.558015142168315, 43.30534948621477, 40.04782206671578, 38.534983839307515, 38.16470043999808, 35.14285591670445, 35.08866344179426, 34.91180052076067, 35.83865199770246, 36.709018094199045, 40.49387904575893, 42.0725861958095, 46.43900442123413, 45.933217253003804, 37.08673259190151, 21.713931798934937, 13.493432930537633, 4.048804777009146, 2.9210915182318007, 3.131095609494618, 7.077119810240609, 5.923388804708209, 4.800530816827502, 2.0998867494719367, 2.1753431005137305, 0.06812003720551729, 0.055970246837075265, 1.7150742326463972, 14.055975590433393, 36.24791826520647, 36.538766384124756, 28.316721541540964, 30.788961819240026, 43.56009129115513, 47.449310711451936, 22.186129638126918, 1.9204286762646265, 0.07029832460518394, 0.05974494732384171, 0.0520091052832348, 0.05915155487933329, 0.05789746610181672, 0.028733640842671906, 0.03513791897733297, 0.011227375445222216, 0.056592704329107485, 0.03778733020382268, 0.02819065676469888, 0.026052134909800122, 0.014588282377059971, 0.07281334857855525, 0.03361996828711458, 0.04510292158062969, 0.007819876058160194, 0.03937234390260918, 0.07136513771755354, 0.028226902409057533, 0.03391910384276083, 0.028755462528871636, 0.0515315726931606, 0.07906186899968556, 0.0668993459216186, 0.031181975001735345, 0.011593161799412752, 0.012781727842853537, 0.05423472050045218, 0.06327059492468834, 0.09708364374403443, 0.025822011454563056, 0.06253892382872955, 0.0368991278644119, 0.03388946882582136, 0.030623235340629305, 0.0542092550812023, 0.04868804616853595, 0.03684476363871779, 0.02330201042682997, 0.06006133463233709, 0.046135801156716685, 0.026928905630484223, 0.01730858694229807, 0.061184425439153395, 0.0902343959148441, 0.02094773988106421, 2.2950355921472823, 20.013648544039043, 47.32715095792498, 53.536252294267925, 47.128640924181255, 34.79396949495588, 38.541397026606965, 37.117144857134136, 31.091003486088344, 11.333570633615766, 1.4650669736521584, 0.11675134088311877, 0.25132451259664124, 1.1373807000262397, 3.0589027404785156, 5.645978501864842, 5.795918456145695, 6.677537160260337, 5.61380877665111, 6.4086640221732, 6.720831385680607, 17.527178355625697, 38.04390948159354, 47.242132799965994, 47.897653647831504, 48.41628456115723, 47.57677888870239, 47.50622340611049, 47.48044211523873, 46.78565352303641, 49.11440134048462, 46.822044713156565, 45.174929073878694, 45.24785736628941, 43.708567346845356, 44.485160555158345, 43.740508215767996, 42.11520644596645, 44.0636168207441, 47.56786782400948, 46.49683427810669, 44.76091718673706, 46.19739123753139, 44.37422909055437, 43.11105006081717, 36.008295740400044, 35.63405534199306, 35.82670109612601, 38.80642563956124, 43.64287560326712, 44.23183618273054, 43.77779572350638, 46.047275406973704, 39.73608766283308, 35.9086412021092, 32.490367208208355, 37.066325732639854, 39.64792891911098, 44.492987700871055, 46.24486827850342, 47.347505705697195, 44.82403114863804, 43.636903626578196, 41.15330825533186, 33.81451668058123, 49.723063537052695, 44.763081550598145, 43.16550309317452, 37.44094133377075, 36.3103061403547, 35.73361955370222, 34.90726682118007, 33.837487425122944, 34.302467823028564, 34.024897711617605, 34.61391387666975, 34.42988041469029, 35.27597992760794, 37.24182333265032, 41.59302152906145, 46.06209938866751, 44.995571749550955, 47.92238228661673, 44.241313525608604, 45.9769526890346, 48.72567047391619, 45.84349169049944, 43.84957408905029, 41.59601272855486, 41.84579699380057, 43.66428647722517, 45.05724743434361, 43.900021484919954, 44.38118771144322, 41.465535981314524, 39.975057056971956, 39.37793581826346, 36.00902182715279, 36.095676285879954, 36.43455730165754, 37.52915913718087, 37.93647296088082, 41.36067724227905, 44.6990886415754, 47.129703998565674, 48.90387439727783, 40.04853425707136, 25.113179888044083, 15.911147219794136, 7.832579204014369, 4.874227319444929, 5.84038953270231, 7.12088086775371, 8.09431437083653, 5.724004600729261, 5.38014954328537, 2.380752261195864, 0.806289971939155, 0.03506542768861566, 1.7756704496485847, 15.911157642092023, 41.33133152553013, 45.96920197350638, 33.82771825790405, 33.87396546772548, 51.29280056272234, 53.562141282217844, 26.512684311185563, 2.472391183887209, 0.02786336200577872, 0.09971486005399909, 0.03722364741510578, 0.015606868612979139, 0.04836595916588392, 0.034042020461388996, 0.06721447794032948, 0.07050555598522935, 0.03752515445064221, 0.026546919252723455, 0.03223770085190024, 0.03216639021411538, 0.03205118514597416, 0.04224714749891843, 0.011877434045475508, 0.028616535876478468, 0.0885856304583805, 0.041432193014770746, 0.011667346033001584, 0.030759295182568685, 0.02056573484359043, 0.04712312049897654, 0.12227551160114151, 0.16170657931693963, 0.13072369327502592, 0.11167716780411345, 0.08940351621380874, 0.16572155244648457, 0.19771603920630046, 0.11533640537943159, 0.1337564598236765, 0.20689541021628038, 0.20594243492398942, 0.15194764440613134, 0.1348571657602276, 0.14144755926515373, 0.12467213799910885, 0.11976780902062144, 0.1666872841971261, 0.16206888987549714, 0.21783860586583614, 0.10549130330660514, 0.1200895296143634, 0.11127716462527003, 0.14177754441542284, 0.1484434317265238, 0.09271587311689343, 2.630262072597231, 22.1261145727975, 50.71635021482195, 59.489635603768484, 54.270520550864084, 42.12473937443325, 41.06027882439749, 38.719573157174246, 34.10419750213623, 14.661612715039935, 1.94341179728508, 0.3419552408158779, 0.8855343397174562, 4.823408629213061, 8.879796062197004, 10.86336258479527, 14.112973400524684, 16.676010131835938, 10.462773748806544, 6.60089418717793, 8.451480439731053, 17.702896560941422, 38.91997310093471, 50.489936215536936, 49.76921347209385, 51.846373966761995, 50.872663838522776, 49.411561897822786, 49.7700229372297, 49.920302050454275, 51.75572081974575, 50.30157055173601, 48.01129838398525, 46.98809623718262, 46.125800473349436, 46.537974561963765, 45.14313759122576, 43.938834122249055, 46.38985633850098, 49.57120370864868, 47.37116084780012, 46.40627840587071, 47.6633951323373, 46.42435067040579, 45.4370116506304, 38.34595809664045, 38.14218480246407, 36.597489084516255, 40.770226274217876, 47.660275391169954, 46.26027938297817, 46.43104178564889, 48.198034695216585, 42.34768622262137, 38.91810403551374, 33.363554273332866, 39.4111829485212, 41.14318125588553, 46.38835900170462, 47.573471546173096, 49.21312482016427, 46.32970578329903, 44.32173892429897, 42.49103103365217, 37.93290506090437, 52.50334003993443, 46.85972479411534, 45.443421363830566, 40.23035471779959, 37.00745364597866, 37.118954862867085, 35.96946225847517, 35.18371827261788, 36.50712776184082, 36.95090920584542, 37.13917759486607, 37.25801958356585, 35.816365650721956, 38.930273805345806, 43.201480865478516, 48.1652843611581, 46.61405038833618, 49.72984150477818, 45.733526025499614, 45.68139369147164, 50.10594054630825, 49.78538540431431, 45.81574405942644, 43.25024332318987, 44.93869726998465, 46.47959232330322, 47.26659740720476, 45.865809304373606, 47.78832026890346, 44.417672702244346, 43.11381196975708, 43.07986307144165, 39.46293660572597, 38.640884808131624, 38.66910491670881, 39.57362835747855, 41.14421306337629, 44.81023550033569, 46.77642978940691, 49.70126356397356, 51.29119552884783, 40.74160664422171, 25.346882547651017, 16.394045284816197, 7.5129629373550415, 6.001188652856009, 8.026720557894025, 13.979280505861555, 14.528900384902954, 13.236609271594457, 8.882107206753322, 4.236877747944423, 0.839909373649529, 0.23949411883950233, 2.3739276102610996, 17.966681446347916, 45.95970378603254, 49.8508756501334, 39.32780456542969, 41.83915451594761, 56.47007703781128, 60.160046441214426, 29.774097510746547, 3.1322047156946997, 0.15989297734839575, 0.2627762295305729, 0.12636026527200425, 0.1330899077334574, 0.1915750258735248, 0.08756705440048661, 0.1275940319257123, 0.1593522663627352, 0.16494555265775748, 0.11805608229977743, 0.08892852134470429, 0.09990388633949415, 0.1631653481828315, 0.1897360331245831, 0.12773191024150166, 0.09042441964681659, 0.17512078237320694, 0.07697906504784312, 0.12725728856665747, 0.09277704304882459, 0.11928257505808558, 0.13046120878841194], [0.08031188656709023, 0.05455618664356215, 0.03223354143223592, 0.04218457639217377, 0.013667918325934027, 0.027211834377210056, 0.04293550431196179, 0.05647734659058707, 0.04463272734678217, 0.04147798055782914, 0.045411722867616584, 0.00939253533059465, 0.04143485626471894, 0.06823727448603936, 0.052625052231763086, 0.05306732814226832, 0.035076101044459004, 0.08599370132599558, 0.05210175245468106, 0.037632437622440715, 0.009180834949282663, 0.004609636979044548, 0.04748457271073546, 0.026782701690016047, 0.0500166448764503, 0.5398838243314198, 9.978339263371058, 35.36925254549299, 47.25541428157261, 42.66184207371303, 25.88404083251953, 22.47259865488325, 37.216618742261616, 33.11964470999581, 14.337011115891592, 2.0908021969454627, 0.12452625297009945, 0.12824991744543823, 0.22052943147718906, 2.97868926184518, 3.4626523554325104, 3.1574173399380276, 4.818321245057242, 3.408278141702924, 4.8926639301436285, 2.7849515548774173, 13.60195163318089, 28.17142949785505, 43.76189129693167, 48.79051453726632, 47.98372098377773, 47.36104427065168, 46.40051140104021, 44.70115920475551, 45.2656169618879, 45.9967029435294, 47.545525891440256, 46.67425305502755, 43.817143372126985, 46.96865517752511, 45.053832394736155, 40.64964028767177, 39.57223524366106, 43.4758756501334, 46.27834469931466, 43.120186941964285, 45.57513836451939, 42.53823014668056, 43.14733355385916, 38.63932146344866, 33.24830797740391, 32.93341909136091, 32.45993757247925, 33.1832137789045, 37.477071966443745, 39.18719039644514, 41.48006813866751, 39.461925642830984, 39.26392977578299, 35.10136822291783, 32.61972876957485, 33.88734075001308, 37.64609037126814, 39.54709318705967, 43.489855425698416, 45.39016342163086, 47.19087246486119, 45.118283884865896, 45.2085896219526, 31.287099020821707, 47.37544093813215, 43.03611373901367, 44.26366588047573, 40.187258516039165, 33.32574217660086, 32.86051859174456, 34.04818112509591, 33.50027745110648, 34.24932105200631, 33.127968651907786, 33.82187482288906, 32.87994575500488, 33.013309478759766, 34.537608759743826, 37.618492126464844, 43.16499934877668, 45.70926986421858, 47.691226141793386, 47.59176615306309, 46.92058059147426, 46.611333642687114, 45.755524022238596, 43.18425628117153, 44.55417353766305, 40.85596704483032, 42.08361298697335, 43.821961947849815, 45.925876481192454, 44.98343672071184, 46.90720878328596, 45.15373706817627, 41.91276025772095, 41.40011174338204, 39.993733814784456, 41.61611386707851, 41.049957275390625, 42.01947069168091, 42.476335593632285, 43.48876803261893, 45.71074983051845, 45.14563546861921, 32.90751273291451, 17.03195766040257, 10.593940104757037, 4.672040820121765, 3.383431166410446, 3.944865805762155, 6.99049357857023, 4.942223259380885, 4.250674699034009, 4.686130898339408, 1.0648499748536517, 1.4427504454340254, 0.02785761820684586, 2.722685273204531, 15.34523902620588, 37.236924852643696, 29.086189372198923, 26.3099775654929, 35.89923334121704, 44.82569176810128, 42.87812212535313, 16.1903293132782, 0.8466275217277663, 0.07362480860735689, 0.08379613674644913, 0.04670734138094953, 0.04478758600141321, 0.03571973561442324, 0.08845847978123597, 0.00783987672600363, 0.012612768382366215, 0.06477178579994611, 0.05542833484443171, 0.0015392369698799613, 0.03694600445617523, 0.11065056467694895, 0.029924968523638587, 0.0011713785393762269, 0.07296814277235951, 0.05334161913820675, 0.017877497843333652, 0.02658170265411692, 0.014468736381136944, 0.03580316828031625, 0.045615205341683965, 0.053479765475328477, 0.031487308974776945, 0.011240524605714848, 0.051480221162949286, 0.04259821812489203, 0.025582744739949703, 0.05561436200514436, 0.06028772105595895, 0.058955152918185504, 0.007804510632662901, 0.04585708611245666, 0.023044701466070752, 0.02075813684080328, 0.015450135505359088, 0.015277806270335401, 0.052131082130862136, 0.03512405650690198, 0.04936668636011226, 0.02803244784341327, 0.02988305202286158, 0.02582757204904088, 0.02114969565133963, 0.06576613815767424, 0.037532984744757414, 0.029391687496432235, 0.7550167175275939, 13.813182950019836, 40.88362782342093, 52.38845157623291, 47.448803492954795, 32.32178653989519, 26.458227804728917, 36.58523941040039, 35.467767579214915, 16.513175623757498, 2.052211684840066, 0.3318381208394255, 0.17296677295650753, 1.333798240338053, 2.8567129841872623, 4.14060263974326, 6.7851104736328125, 6.8415063960211615, 6.252037295273372, 8.464257308415004, 4.599310985633305, 15.398781844547816, 32.15926817485264, 46.047011375427246, 53.51952450616019, 51.17899601800101, 49.37101221084595, 48.12030519757952, 47.22623184749058, 46.04473236628941, 47.459489822387695, 48.612261976514546, 48.953689507075715, 45.872809614454, 48.95002085821969, 46.853822299412315, 42.74576589039394, 42.293462480817524, 45.83067921229771, 46.79589516775948, 43.46863562720162, 45.746567794254844, 45.423500878470286, 43.06255510875157, 40.600978578839985, 34.891171319144114, 35.189311572483604, 34.2791496685573, 36.65515913282122, 39.257731982639854, 42.151885986328125, 43.15793303080967, 42.84047678538731, 40.59491280147007, 36.69697686604091, 33.56287029811314, 34.90669706889561, 40.190499850681846, 41.16228880201067, 45.18089062826974, 46.46172503062657, 49.0194924218314, 46.24447570528303, 44.93022741590227, 33.11944668633597, 48.0210918698992, 44.52402877807617, 46.20579855782645, 41.01212085996355, 35.88564613887242, 34.022538798195974, 34.9646554674421, 35.58461543491909, 34.60145228249686, 35.735474722726, 35.26900741032192, 34.27342782701765, 35.78519950594221, 36.94000400815691, 39.42088958195278, 44.59078707013811, 46.46993432726179, 48.39672885622297, 47.966197626931326, 46.27787569590977, 47.61019624982561, 47.82704605375017, 45.550962107522146, 45.95004578999111, 44.65400178091866, 43.43313380650112, 46.08442047664097, 48.622857979365754, 45.57929686137608, 48.958587987082346, 45.954826150621685, 43.14427982057844, 43.60753011703491, 41.55475779942104, 42.37846326828003, 42.91571882792881, 42.7781514440264, 45.09075512204851, 46.97276503699166, 47.41304458890642, 48.916096278599326, 35.20713370186942, 20.64167537008013, 12.893175448690142, 6.01443669625691, 4.419458167893546, 6.186552260603223, 7.533583453723362, 8.002340197563171, 5.839541852474213, 6.14847309248788, 2.879920184612274, 0.5115731177585465, 0.14489651205284254, 2.691356062889099, 17.33159351348877, 42.12826211111886, 36.24973521913801, 29.763400759015763, 40.114865234919954, 50.23977327346802, 50.06195844922747, 20.431485414505005, 1.5597450818334306, 0.04197264615712421, 0.018387113265427094, 0.03232754906639457, 0.018191981861101728, 0.044017475896648, 0.019777071895077825, 0.05654299146096621, 0.05138157574193818, 0.0837481100378292, 0.03549771217097129, 0.031130613293498755, 0.04619400928329144, 0.045891559084079096, 0.05271939913343106, 0.03863601805642247, 0.04025025286578706, 0.039713053298848014, 0.06261570006608963, 0.03295627961467419, 0.01099943432823888, 0.06744116970470973, 0.052525697741657495, 0.15841999995921338, 0.1524231753179005, 0.08315143348383051, 0.10377154273114034, 0.05882449421499457, 0.1192216154720102, 0.22996613010764122, 0.15994673089257308, 0.15373700910380908, 0.059722406390522204, 0.10402296709695033, 0.13087092180337223, 0.0903364068695477, 0.11543924414685794, 0.15319909368242535, 0.08430006434874875, 0.07300637143531016, 0.18967425929648535, 0.15574696553604944, 0.1530006764722722, 0.08627907279878855, 0.0815594003402761, 0.1493231930903026, 0.11715991395924773, 0.12252286475683961, 0.8865437284111977, 15.215215648923602, 45.38007116317749, 57.44059794289725, 52.20432431357247, 36.32058252607073, 30.467260224478586, 45.67960105623518, 43.164426122392925, 19.826674257005962, 3.0844503981726508, 0.4623729778187615, 0.6462211183139256, 2.0295097487313405, 6.935882908957345, 11.885750923837934, 9.66036798272814, 12.663724218096052, 10.623609781265259, 10.43286349092211, 4.585327301706586, 17.433164017541067, 31.140137672424316, 46.96503864015852, 53.26887171609061, 50.90145369938442, 48.85373967034476, 49.680248737335205, 48.76683507646833, 48.6893070765904, 48.10146515710013, 49.947545937129426, 50.293976170676096, 46.98499386651175, 50.38687358583723, 49.69432578768049, 44.93767588479178, 44.1190356527056, 47.01666028159005, 48.43047625677926, 44.253587518419536, 48.06039782932827, 46.51353427342006, 46.246167591639924, 43.50522831508091, 35.70100123541695, 36.7734591620309, 36.06328725814819, 39.27338627406529, 40.8402293750218, 43.52991873877389, 45.1884502683367, 44.00732251576015, 43.51456669398716, 39.593177114214214, 35.74468455995832, 36.594779287065776, 41.08661944525582, 43.03944192613874, 47.98118836539132, 48.891048022678916, 51.237760407584055, 47.315648215157644, 46.54349837984358, 36.27532196044922, 50.00157165527344, 46.117017950330464, 48.8004469871521, 43.211882318769185, 37.44713217871529, 35.93806682314192, 36.97025646482195, 37.97835322788784, 36.382980823516846, 36.57195445469448, 36.64528226852417, 36.69757093702044, 36.06118195397513, 37.781601088387625, 40.131530489240376, 47.20148583820888, 49.10945769718715, 50.81132861546108, 50.36077962602888, 46.60841539927891, 47.61603621074131, 49.725550992148264, 46.76077549798148, 49.36583580289568, 45.86152573994228, 46.42467028754098, 46.77879217692784, 49.872067655835835, 48.820808683122905, 51.84848969323294, 49.116892269679475, 45.500341006687705, 47.710517815181184, 44.15979378564017, 45.68242202486311, 45.06827769960676, 45.75801842553275, 47.96002067838396, 49.01329115458897, 50.27350677762713, 50.653361320495605, 37.67070089067732, 21.639886583600724, 14.03538373538426, 8.653908388955251, 8.006646343639918, 9.132033041545323, 15.313447543552943, 11.261509128979274, 12.329621825899396, 10.705214636666433, 4.87147149017879, 3.729038255555289, 0.3451397142239979, 3.659800325121198, 19.102282864706858, 45.842675277165, 41.50312920979091, 38.34601020812988, 49.09885127203805, 58.707004410879954, 54.134381021772114, 24.115559271403722, 2.099130698612758, 0.24712120528732026, 0.10503822511860303, 0.11750182775514466, 0.14331591900970253, 0.14550548366137914, 0.17632400138037546, 0.1976640091410705, 0.11266709611352001, 0.20738951941686018, 0.12521158690963471, 0.19027507491409779, 0.089313617109188, 0.11669104626136166, 0.15051334351301193, 0.15987889096140862, 0.28959198775035994, 0.13693650918347494, 0.17978982254862785, 0.17000328483326094, 0.10737944234694753, 0.13641685992479324, 0.15724336595407554], [0.06715116383773939, 0.04290199146739074, 0.04745316332472222, 0.02245332087789263, 0.0076555475991751465, 0.04788876923599413, 0.04658056729074035, 0.04414813799251403, 0.018732063505532484, 0.02107089737962399, 0.044535832546119175, 0.05678273484643016, 0.06401419466627495, 0.016553966095671058, 0.07044956327549048, 0.0689288102356451, 0.06906723137944937, 0.07078214042953082, 0.02109357062727213, 0.03528877766802907, 0.021504430366413932, 0.05328872733350311, 0.06705524612750326, 0.04719644299309168, 0.06677617145968334, 0.14378847793809005, 5.110146454402378, 25.053385428019933, 49.030248233250205, 40.562878131866455, 27.7566203049251, 27.9729038306645, 32.42883048738752, 26.87875883919852, 21.482824291501725, 4.323010223252433, 0.37432597524353434, 0.1006954177947981, 1.3160919504506248, 1.693071784717696, 1.9779491211686815, 5.332303379263196, 3.7917453135762895, 4.90312487738473, 9.709351045744759, 6.1507151893207, 11.192866138049535, 26.48546995435442, 39.61583171572004, 50.93126147133963, 49.00305993216378, 49.009129183632986, 45.019980771201, 46.04949535642351, 45.07199845995222, 47.444433076041086, 44.18530409676688, 45.56149557658604, 44.156517710004536, 46.539645603724885, 45.513778822762625, 44.58262293679373, 44.71629932948521, 42.29916000366211, 41.82283319745745, 44.41713769095284, 44.174489225660054, 44.386030605861116, 43.23027767453875, 42.78672552108765, 37.35497127260481, 33.2126532963344, 32.620145661490305, 33.11927645547049, 34.490864753723145, 39.773851122174946, 41.27001019886562, 37.159532342638286, 36.51935659136091, 32.646906648363384, 32.407582896096365, 32.05137654713222, 34.33595814023699, 36.94421114240374, 41.63320990971157, 41.747994150434224, 44.69253996440342, 46.086094992501394, 45.498635223933626, 29.06093614442008, 45.46356419154576, 45.76232630865914, 42.19712918145316, 43.402252537863596, 35.50611468723842, 34.148019790649414, 33.67343003409249, 34.78999859946114, 35.21373101643154, 35.063264301845, 33.908188819885254, 35.09567070007324, 34.91645581381661, 34.188100474221365, 35.3957599231175, 40.40611287525722, 43.770538330078125, 44.318174498421804, 46.13978024891445, 46.84777389253889, 44.83693395342146, 44.86936467034476, 48.190377780369346, 46.385739530835835, 43.14958477020264, 47.25837421417236, 48.74237046922956, 49.60134499413626, 46.75247240066528, 44.486164569854736, 48.66266073499407, 47.30140093394688, 43.47209930419922, 45.05765390396118, 45.208520139966694, 44.80830042702811, 44.17141464778355, 43.983896664210725, 44.093796321323936, 47.129248891557964, 42.23723765781948, 29.712272439684185, 13.950701696532112, 6.964830407074519, 2.626395834343774, 2.2188713933740343, 3.9462532741682868, 4.646757193974086, 6.645967585699899, 4.0426564897809705, 5.027874137674059, 2.069264952625547, 0.18391158351940767, 0.27169597947171753, 2.6981872277600423, 17.887194054467336, 37.848307268960134, 39.7087082862854, 35.30215726579939, 38.936568873269216, 46.73958001817976, 39.24998474121094, 13.231639572552272, 0.9316927428756441, 0.05275231486718569, 0.07634349486657552, 0.06052024822149958, 0.03022040267075811, 0.05905725208244153, 0.007141221447714737, 0.03372203352461968, 0.046913602455918274, 0.03899682565991368, 0.018088549375534058, 0.007488509240959371, 0.030453462486288378, 0.02997999432097588, 0.036732581444084644, 0.018891568428703716, 0.07957750811640706, 0.06956279264496905, 0.05483203827004347, 0.032533833890088966, 0.041643176693469286, 0.023511876219085286, 0.027495819942227433, 0.0426137938962451, 0.06570371293595859, 0.03345517248713544, 0.029806055261620452, 0.015933598491496274, 0.03730887819879821, 0.04467184489060726, 0.020449391532955424, 0.03462071923006858, 0.03623876401356288, 0.04133284870269043, 0.015987760853022337, 0.028824679886123965, 0.01506403211637267, 0.01478492352180183, 0.01625260664150119, 0.05413393769413233, 0.02533026016317308, 0.01895700634590217, 0.05891486829412835, 0.04201927847628083, 0.00686145679459774, 0.05871955877436059, 0.022270040087667958, 0.07648338164602007, 0.1616841605199235, 6.462301509720938, 31.232948235103063, 53.82873323985508, 46.51916231427874, 30.50537804194859, 28.016331808907644, 40.20680379867554, 35.41997439520699, 23.461247410093033, 5.096289575099945, 0.38459307860050884, 0.05865298091833081, 0.5553150134427207, 2.9859889958586012, 5.023572334221431, 9.142121825899396, 8.200005156653267, 6.334402544157846, 5.966975722994123, 6.537502297333308, 13.738417727606636, 29.485385962894984, 40.926671913691926, 51.5779059955052, 49.413465704236714, 49.049227237701416, 44.99651323046003, 46.185697419302805, 46.959434917994905, 48.01438338415963, 45.43431574957711, 44.73755039487566, 44.255831786564414, 46.783061844961985, 47.14924233300345, 44.73665755135672, 45.35965388161795, 43.14756631851196, 42.805374486105784, 43.911437375204905, 45.76337201254708, 46.23348018101284, 44.48099511010306, 44.22325168337141, 38.0601613180978, 34.66010202680315, 33.85510458265032, 34.67166035515921, 36.6009110723223, 42.54729754584176, 42.948298931121826, 39.82306521279471, 38.73363283702305, 34.481515952519004, 32.721596309116904, 34.90259415762765, 36.225145544324604, 39.83334854670933, 43.39075674329485, 44.37608425957816, 46.71826989310128, 47.73801531110491, 45.87549161911011, 31.329041821616038, 46.64701959065029, 48.502268518720356, 44.49600321905953, 45.154094900403706, 36.24372502735683, 35.79877628598894, 35.303578172411235, 35.93383537020002, 34.96095207759312, 36.71047374180385, 34.80707032339913, 36.50574507032122, 35.4344231741769, 36.29544046946934, 36.519926343645366, 42.01865080424717, 46.05423402786255, 45.228801931653706, 48.902290207999094, 48.128542287009104, 45.48401968819754, 45.94511604309082, 50.20526851926531, 47.525098187582834, 43.811220032828196, 48.790281772613525, 50.04112774985177, 50.45478875296456, 48.777462346213206, 47.10406167166573, 49.61786781038557, 48.46429313932146, 45.506583963121685, 46.2792375428336, 45.69151026862008, 46.77384853363037, 44.860477924346924, 45.78045763288225, 47.0398325238909, 47.93844304765974, 44.85160854884556, 32.309964179992676, 17.368943555014475, 8.33351479257856, 3.8357378329549516, 4.210018617766244, 6.968489067895072, 8.014041832515172, 9.216781956808907, 7.902269635881696, 3.408060141972133, 2.169582826750619, 0.23761908231037004, 0.1780584454536438, 2.9578038454055786, 20.70963396344866, 39.34091929027012, 37.27373988287789, 36.50403928756714, 43.88514191763741, 53.97701127188546, 46.49301276888166, 15.178621223994664, 1.235210359096527, 0.02832443163996296, 0.06182133233440774, 0.047389543881373744, 0.06400537371103253, 0.03712879161217383, 0.015481383739305394, 0.021870420281110064, 0.0186167651388262, 0.03324958994718535, 0.03352248655366046, 0.031211525201797485, 0.04832701464848859, 0.08017852050917489, 0.03674764492149864, 0.02720926781850202, 0.061243132288966856, 0.020152439163731675, 0.039852763659187725, 0.018474727403372526, 0.03089571125539286, 0.04186172603762575, 0.028612963389605284, 0.13599414617887565, 0.09317347713346992, 0.12382635766906397, 0.12919610738754272, 0.13165100637291158, 0.15830942589257443, 0.12867268547415733, 0.07165190018713474, 0.14040528876440866, 0.07610781251319818, 0.1769414275352444, 0.14525405929556914, 0.1576193014958075, 0.08008773930902992, 0.10290073124425751, 0.12767111350383076, 0.11680788999157292, 0.13222743544195378, 0.12512822209724359, 0.09921736496367625, 0.15602813687707695, 0.07260324699538094, 0.14818018728068896, 0.11231711453625134, 0.14895652633692535, 0.25435303151607513, 7.519433447292872, 34.78911965233939, 61.33638341086251, 52.7586099079677, 39.3412423815046, 38.565621920994346, 41.52098955426897, 37.67813546316964, 28.370742048536027, 6.4600033930369785, 0.856398805975914, 0.23556301263826235, 2.5036593803337643, 4.1826231735093256, 6.9096890687942505, 16.519541910716466, 12.300920554569789, 11.455356921468463, 15.658905029296875, 10.91612720489502, 15.065111977713448, 30.199431487492152, 41.030550956726074, 51.85207496370588, 49.871021951947895, 50.073190212249756, 45.92893716267177, 48.342466899326865, 47.52646698270525, 48.82277849742344, 45.269181387765066, 45.53687116077968, 44.341464860098704, 47.928173610142295, 47.118531295231406, 45.988792419433594, 46.18263326372419, 43.31595243726458, 43.1622964995248, 43.799765927451, 47.70509474618094, 49.11858068193708, 45.93247379575457, 47.494262082236155, 41.52453660964966, 36.85809516906738, 36.206176962171284, 35.7215644291469, 37.83585262298584, 43.15610218048096, 44.81293140138899, 40.73107317515782, 41.08106436048235, 35.99572992324829, 34.42923075812203, 35.55397735323225, 37.54922553471157, 41.420671463012695, 45.33342095783779, 47.272291455950054, 48.60604681287493, 48.84839997972761, 47.80355766841343, 34.42361313956124, 47.775535583496094, 49.87329053878784, 45.892955916268484, 48.39028787612915, 38.44941677365984, 37.748930658612935, 37.4135411126273, 38.17385469164167, 36.9835970061166, 38.85264505658831, 37.24642998831612, 39.19939143317086, 37.763285636901855, 37.08835847037179, 39.2679180417742, 44.75066859381539, 48.730023520333425, 48.29182495389666, 50.50970731462751, 50.170037678309846, 46.62039409364973, 48.12391478674752, 53.01151738848005, 49.7869348526001, 47.052922930036274, 50.10537774222237, 52.936077322278706, 52.404234409332275, 49.87535415376936, 48.91982051304409, 52.34550823484148, 52.5553959437779, 46.75338956287929, 49.86066566194807, 50.246929918016704, 49.29874052320208, 46.83881419045584, 47.682735443115234, 48.59744494301932, 51.92741775512695, 46.75900023324149, 32.240666321345735, 17.43502960886274, 10.77625128201076, 6.006758502551487, 7.176412173679896, 10.510999458176748, 10.936602677617755, 16.35055650983538, 11.349561044148036, 12.20175325870514, 5.042710712977818, 0.7735772015792983, 0.41054842727524893, 3.653211695807321, 22.697876623698644, 46.77619702475411, 51.35919407435826, 45.88577842712402, 50.43529905591692, 60.662053789411274, 51.97751079286848, 19.17519552367074, 2.203742342335837, 0.17997286415525846, 0.22441777640155383, 0.11837898354445185, 0.1162290589085647, 0.11944665839629513, 0.08753993335579123, 0.13812667317688465, 0.10547957143613271, 0.1021607955917716, 0.20237868758184568, 0.13347714766860008, 0.15729706521545136, 0.16195819367255482, 0.11936207222087042, 0.14269079826772213, 0.17328933493367263, 0.13068412111273833, 0.11417197143392903, 0.16628347443682806, 0.1419313411627497, 0.07510415065501418, 0.15480741166642734], [0.06231466121971607, 0.0712909127718636, 0.03878318212394204, 0.05758278191621814, 0.03956601136763181, 0.03473285731992551, 0.027244716184213758, 0.0529362046425896, 0.0257749482656696, 0.0989807258759226, 0.009164108212904205, 0.022208569903991053, 0.03716181591153145, 0.037496130115219524, 0.06852780961032424, 0.015611538630244988, 0.0673122141244156, 0.010856930948128658, 0.021294466186580912, 0.021844491761709963, 0.025849795767239163, 0.017259615373664668, 0.08446032753480331, 0.032105372952563424, 0.03732960405094283, 0.0845088835007378, 2.591452257973807, 18.9173652444567, 43.98156554358346, 41.93029056276594, 32.98601695469448, 22.835235561643326, 24.598068237304688, 37.8707013130188, 25.2251900604793, 7.078579366207123, 0.874875368816512, 0.13117318201277936, 0.6076918914914131, 3.1770492579255785, 3.194473168679646, 5.622272985322135, 6.313616139548166, 5.317000840391431, 4.738616721970694, 3.4869250186852048, 9.570226396833148, 23.70783029283796, 38.43409252166748, 49.77388960974557, 48.14613165174212, 47.36088446208409, 46.88618006025042, 47.89714295523507, 45.190743173871724, 46.6370975630624, 46.02138989312308, 47.747496128082275, 45.580769879477366, 48.12811844689505, 46.23925065994263, 43.88167129244123, 42.822578225817, 43.87664427076067, 43.793613297598704, 44.08653892789568, 44.80026136125837, 46.21996940885271, 41.91163117544991, 42.974101066589355, 43.000556332724436, 37.56271546227591, 33.22966596058437, 32.790053435734336, 33.05312613078526, 37.10777868543352, 36.551842893872944, 34.63193055561611, 33.88690301350185, 32.105402265276226, 31.60416269302368, 31.729925087520055, 33.27308872767857, 34.62306465421404, 38.81323487418038, 41.36177853175572, 43.70075062343052, 43.660920075007844, 47.327578272138325, 32.65866994857788, 41.00944232940674, 46.918489183698384, 43.590295110430034, 42.28915112359183, 37.38673843656267, 33.68052761895316, 37.093444551740376, 41.19879116330828, 40.46236201695034, 40.392206055777415, 35.14633696419852, 35.90405191693987, 35.19575602667672, 33.43300151824951, 33.74776186261858, 35.52610812868391, 40.08768040793282, 42.56082221439907, 44.86043970925467, 45.770236832754954, 47.785912718091694, 44.944568497794016, 46.352895396096365, 47.701318400246755, 46.25835820606777, 44.09814589364188, 46.053990840911865, 47.10111216136387, 50.003781182425364, 48.53870487213135, 49.40001399176461, 48.27583714893886, 48.54013967514038, 46.51184238706316, 46.94646610532488, 48.774127210889546, 46.90781675066267, 48.27298491341727, 49.9117488179888, 49.66865566798619, 40.50077165876116, 25.790787322180613, 12.666743210383824, 6.271368486540658, 2.5189858036381856, 2.5879963976996283, 6.113857167107718, 6.251086260591235, 7.095070481300354, 5.572301975318363, 3.3198586234024594, 1.5798387293304716, 0.24656290667397635, 0.3946225047111511, 3.742049191679273, 21.79974726268223, 40.59662900652204, 40.11340263911656, 30.668163912636892, 44.18410553250994, 48.00527082170759, 39.828335421425955, 11.75965588433402, 0.2708496020308563, 0.07446884510240384, 0.047557559330016375, 0.04348819822605167, 0.04618207724498851, 0.026770092813032012, 0.01149662577414087, 0.022917313301669698, 0.02772059993419264, 0.026770723850599358, 0.009609098263484026, 0.04352859141571181, 0.05385998257302812, 0.036544549212391884, 0.016014123634834374, 0.003001867124112323, 0.05835910740175417, 0.06858178707105772, 0.025278567669114897, 0.02683141371900482, 0.041635112304772647, 0.06231721251138619, 0.04518442381439464, 0.03658253360273583, 0.05118375564260142, 0.021049138457913483, 0.016039472006793534, 0.0675421425008348, 0.011924943371143724, 0.03680006175168923, 0.03290818505255239, 0.009295950959702688, 0.06932276088212218, 0.011877150757105222, 0.02939184016681143, 0.07617394253611565, 0.03182199976540037, 0.0070965954717913905, 0.06637052965483495, 0.060651897585817745, 0.04460147402382322, 0.09590344743004867, 0.037064340963427506, 0.08490434728030648, 0.006356528353145612, 0.057929927217108865, 0.13924935007733957, 0.031504676078579257, 0.08972805951322828, 3.2717486449650357, 23.951112781252178, 48.247471128191265, 45.39714288711548, 36.854047843388145, 29.700259004320415, 25.486270359584264, 33.2426312991551, 30.685124465397426, 7.471837418419974, 1.0730217077902384, 0.06259058069969926, 0.525583834520408, 2.3361986747809818, 4.003331857068198, 6.621423074177333, 9.495667014803205, 7.251669849668231, 7.457214065960475, 6.474876012120928, 11.177280460085187, 26.783571992601665, 39.880995818546836, 50.68938078199114, 48.2947883605957, 48.85229444503784, 48.393636907849995, 48.715790135519846, 47.29213898522513, 47.849196910858154, 46.84243072782244, 48.09088652474539, 46.365867682865684, 48.33761010851179, 47.5710848399571, 43.90463856288365, 42.47928857803345, 44.90312596729824, 43.74910313742501, 45.65684223175049, 45.907766001565115, 49.3615974017552, 43.48971993582589, 45.51475504466465, 44.68580368586949, 39.81695774623326, 34.89977666309902, 34.558161531175884, 36.361396244594026, 37.60035037994385, 38.2594495500837, 36.101679529462544, 35.90881143297468, 33.09881401062012, 32.988886560712544, 33.089722292763845, 34.48334680284773, 37.630703585488455, 42.11967761175973, 44.18507480621338, 44.55501079559326, 44.775154045649934, 48.642066274370464, 36.26020268031529, 43.2106420653207, 47.882753235953196, 46.03078038351876, 43.50866767338344, 38.79133415222168, 34.95396913800921, 38.54341547829764, 41.46763433728899, 41.543553829193115, 40.95587171827044, 36.118382998875205, 36.78111260277884, 37.82193190710885, 34.723122188023154, 35.62738854544503, 37.47937876837594, 42.5660194669451, 44.3440009525844, 46.59869139535086, 48.335803576878135, 48.67766189575195, 44.71962751661028, 46.65403379712786, 49.51422848020281, 47.749698707035606, 45.91515193666731, 49.21826648712158, 48.814524037497385, 50.87252834865025, 49.760427474975586, 50.682328360421316, 50.20464318139212, 49.69675070898873, 48.85058518818447, 48.15735994066511, 50.37040982927595, 49.0122697693961, 50.50139726911272, 51.5809770992824, 51.33853360584804, 42.36974327904837, 28.829998867852346, 14.544682349477496, 5.957913100719452, 5.042264291218348, 4.9871507457324435, 6.441682296139853, 8.087902052061898, 6.940850002425058, 6.288147517613002, 3.122028861727033, 0.7313911052686828, 0.015256714009280716, 0.5292398354836872, 3.9892565437725613, 22.180944544928415, 45.07807813371931, 49.4695828301566, 37.62261240822928, 48.94972903387887, 53.954766614096506, 44.84360074996948, 14.134190593447004, 0.5906947521226746, 0.07242481264152698, 0.01769387778559966, 0.038637388697160144, 0.019365752448460886, 0.027833012830732123, 0.04413794978920903, 0.018396007163184028, 0.06234836405409234, 0.03847127653924482, 0.03289998495685203, 0.015805223058643084, 0.032954155800065825, 0.022272455672334348, 0.06840372591146401, 0.060476815194955895, 0.09369398813162531, 0.025637217531246797, 0.03428491224933948, 0.08654737233051232, 0.0354655801451632, 0.03684288409671613, 0.06551461879696165, 0.11304432087178741, 0.1104942098526018, 0.07654453122190066, 0.12762418602194103, 0.2500853719455855, 0.12051938154867717, 0.1311277744493314, 0.11649355185883385, 0.10611833751733814, 0.1800516556416239, 0.10039492177643947, 0.056339349531169446, 0.19488160844360078, 0.09997060668787786, 0.12000194431415626, 0.14251762256026268, 0.1755663220371519, 0.15201430368636334, 0.1461773690368448, 0.07510552129575185, 0.17349615240735666, 0.24449467765433447, 0.19941089754658087, 0.2113865113684109, 0.09890016341315848, 0.1553541344723531, 3.9813173583575656, 27.13232466152736, 55.414614404950825, 53.6377272605896, 44.13846281596592, 32.960253034319194, 33.51986789703369, 47.02975068773542, 33.52249084200178, 10.067337002073016, 1.4951521307229996, 0.42114885417478426, 1.8978127241134644, 7.263478747435978, 9.503896287509374, 13.618909580366951, 14.707774809428624, 12.55230290549142, 11.972087502479553, 6.509239196777344, 12.031980105808803, 29.516899517604283, 40.07400982720511, 53.4598742212568, 50.282501220703125, 50.105200563158306, 48.87240253176008, 51.050958088466096, 49.205259459359304, 49.961942604609895, 49.313828536442344, 50.074260234832764, 47.70702287128994, 50.353303364345, 49.09243113654, 44.64526442119053, 42.72531039374215, 45.16440255301339, 43.41024991444179, 45.781308787209646, 46.116667066301616, 50.95160927091326, 43.873173645564485, 48.134166853768484, 47.944630418504985, 42.07794325692313, 36.707927227020264, 36.8557779448373, 37.93429817472185, 40.19284834180559, 38.789041246686665, 38.22112328665597, 37.06143767493111, 35.20618527276175, 34.76327582768032, 34.5603780065264, 36.2200733593532, 38.622510296957834, 43.749863965170725, 47.79828398568289, 46.91434805733817, 46.405142375401084, 50.760446957179475, 40.33466107504708, 44.56651701245989, 48.94920791898455, 47.9702136857169, 46.90729563576834, 41.4882253238133, 36.31939785821097, 40.59265463692801, 43.69259343828474, 44.34642934799194, 43.30896602358137, 38.362432275499614, 38.90183482851301, 38.57013825007847, 37.33043370928083, 36.78765433175223, 38.49500390461513, 43.38117170333862, 46.67427737372262, 48.191885539463584, 50.32869979313442, 50.84307493482317, 44.613142899104524, 46.0767878804888, 48.91661044529506, 48.938650131225586, 48.31364924567086, 50.32158136367798, 48.0479223387582, 52.69879286629813, 49.79025261742728, 51.68152448109218, 51.69956200463431, 52.854849406651084, 50.1719970703125, 51.28374011175973, 53.41297388076782, 50.131141662597656, 52.755267824445454, 53.9057297025408, 53.20533043997628, 44.763818059648784, 30.190037522997173, 15.526818037033081, 9.04006494794573, 8.77817257813045, 10.662830625261579, 12.760176505361285, 14.75147897856576, 14.80536573273795, 15.286283561161586, 10.736806358609881, 3.734183830874307, 0.8885068659271512, 0.8576607182621956, 4.857366647039141, 27.302395718438284, 50.002864020211355, 49.76365838732038, 41.25462688718523, 54.66401440756661, 61.04204382215227, 51.99123348508562, 16.07721437726702, 0.7479138129523822, 0.22893410548567772, 0.1650218471352543, 0.1310284233519009, 0.17048519397420542, 0.12401032208331994, 0.13004278338381223, 0.11641132698527404, 0.11517373339406081, 0.13840139843523502, 0.0937346595206431, 0.14732830013547624, 0.15476519321756704, 0.11084816764507975, 0.19649310197149003, 0.22765194571443967, 0.1524841349039759, 0.15284430129187448, 0.20136350419904503, 0.1662402924682413, 0.13182111510208674, 0.14307216208960327, 0.14015452936291695], [0.036375492212495635, 0.03491501004568168, 0.03310209679018174, 0.024652505459796106, 0.010546519836810018, 0.026730865007266402, 0.021344949191968356, 0.0470815195169832, 0.024648659862577915, 0.027133322786539793, 0.03569414805887001, 0.012505542886044298, 0.03637386033577578, 0.05295286946264761, 0.047058551106601954, 0.05881338659673929, 0.03203288505652121, 0.039684768566595655, 0.09365570518587317, 0.04655523757849421, 0.05650452191808394, 0.04262005338179214, 0.012061538407579064, 0.016237768776980892, 0.018154082287635123, 0.10439451930246182, 0.3282504347818238, 11.447307433400836, 39.91442360196795, 46.36098657335554, 38.47563580104283, 21.34355981009347, 30.00602490561349, 39.395733628954204, 25.246316058295115, 11.774763873645238, 1.7668421119451523, 0.14831490362329142, 0.12954150885343552, 1.0051434529679162, 4.362869867256709, 6.994830557278224, 9.026528120040894, 5.579158544540405, 3.841134411948068, 7.447633368628366, 10.596152237483434, 19.19034433364868, 28.00385284423828, 40.37058326176235, 45.10572154181344, 49.15298816135952, 46.34593677520752, 45.34410033907209, 43.082541601998464, 43.027327741895405, 43.292248657771516, 44.88219451904297, 45.98024613516671, 46.6840500150408, 47.3919290133885, 45.00930486406599, 47.238248756953645, 45.90312807900565, 44.44611167907715, 44.74891764777047, 45.69925056185041, 45.58230890546526, 46.62137726375035, 45.89331374849592, 43.81586490358625, 44.41927773611886, 38.89497000830514, 33.363408361162456, 31.28111662183489, 32.65814535958426, 32.43394783564976, 32.82325887680054, 32.507355553763254, 31.712137699127197, 31.306960446493967, 32.488432134900776, 33.00357852663313, 34.21807847704206, 34.45510237557547, 36.9220290184021, 43.35470601490566, 43.457792963300435, 44.8123060635158, 33.115764141082764, 39.83747925077166, 46.762283257075715, 43.35308013643537, 43.76611927577427, 37.561159065791536, 34.87339435304914, 40.44421679633004, 43.40227338245937, 43.67521946770804, 43.555300508226665, 37.37375920159476, 34.152675083705354, 35.503182547433035, 36.724186011723106, 34.54914276940482, 34.86989940915789, 37.27498013632638, 40.90064396177019, 43.36145618983677, 42.75345754623413, 45.736854212624685, 45.79064021791731, 42.36690146582467, 44.314255714416504, 44.57009880883353, 45.73812920706612, 47.12973179136004, 49.00748593466622, 46.90622908728463, 44.368479456220356, 45.10180623190743, 47.522131306784495, 48.037010192871094, 46.2742417880467, 48.34718472617013, 48.679114069257466, 48.14923749651228, 51.83032362801688, 45.88928031921387, 46.42349256787981, 35.21379355021885, 23.82587844984872, 11.071777275630406, 2.950547971895763, 2.4452697592122212, 2.3523130672318593, 4.821459659508296, 8.050013525145394, 4.407290135111127, 3.8970886894634793, 0.8785236073391778, 0.41967211770159857, 0.0992083540186286, 0.4134642008159842, 5.040063449314662, 22.61194477762495, 33.85899557386126, 28.524585587637766, 28.5657571383885, 39.52617563520159, 47.535440581185476, 30.988587038857595, 5.697168052196503, 0.2052507091845785, 0.035159591385828595, 0.007982838965420212, 0.05899409404290574, 0.058343100760664256, 0.02225506821248148, 0.06839717804853405, 0.046331952059907575, 0.042718871829233, 0.030136322003922293, 0.022948817682585547, 0.015659965674525926, 0.01711101790091821, 0.02270021432611559, 0.050719291636986394, 0.05586176605096885, 0.07228960775371109, 0.01770451382201697, 0.0325778945615249, 0.04987528228334018, 0.018589713643970232, 0.021606504085606763, 0.012560656892934015, 0.06136049849114247, 0.0921595897525549, 0.01717531418294779, 0.06608053735856499, 0.03023679946948375, 0.010253035629700338, 0.021916526735627224, 0.04802479175850749, 0.15528165336166108, 0.05976889282464981, 0.05994175640600068, 0.027175064564549496, 0.04875216094244804, 0.05381708898182426, 0.04179751966148615, 0.046202290803194046, 0.04552235800240721, 0.02644010427008782, 0.05709673371165991, 0.017091878124379685, 0.03615866634728653, 0.04363854801548379, 0.015105572030214327, 0.02142504176923207, 0.017396994966215322, 0.1255778736834015, 0.8745972237416676, 14.708573852266584, 45.2095172064645, 51.460405009133474, 42.88605349404471, 24.666598320007324, 32.352435043879915, 46.260824816567556, 27.738421235765728, 13.053829090935842, 1.707633797611509, 0.1507687305233308, 0.12748444852020058, 1.3084173394101006, 3.376250854560307, 7.609338794435773, 8.835491742406573, 7.395883185522897, 4.974972290652139, 5.46070522069931, 10.044586862836566, 20.137376853397914, 34.10465260914394, 45.6656699180603, 49.08600752694266, 51.05492203576224, 48.82848644256592, 48.0413041796003, 45.90826974596296, 46.596732003348215, 45.07120983941214, 48.05252552032471, 49.550539766039165, 48.69928816386631, 48.19150686264038, 46.783027103969026, 48.06985432761056, 46.38518020084926, 44.981157711574006, 45.41435357502529, 45.93733058656965, 46.13422516414097, 47.53067759105137, 47.43139130728585, 45.82582242148263, 45.55056258610317, 39.74634320395333, 35.51114518301827, 33.23533916473389, 35.10611036845616, 33.641826152801514, 34.28377716881888, 33.807936736515586, 33.44537973403931, 33.49627528871809, 34.38485608782087, 34.490392276218955, 35.74389941351754, 36.09268856048584, 38.969770840236116, 46.48892722811018, 45.54785973685128, 46.4896811076573, 36.094029562813894, 40.98382779530117, 47.42178542273385, 45.69258376530239, 44.86161395481655, 38.839797837393625, 37.46686853681292, 41.14363636289324, 44.80183512823922, 45.38753352846418, 46.0169951575143, 38.82441452571324, 36.86624193191528, 37.36334385190691, 38.4175523349217, 36.63840702601841, 36.26271792820522, 39.08974191120693, 44.04377971376692, 44.94961288997105, 45.76550163541521, 48.227971008845735, 48.45316212517874, 42.87124688284737, 45.54027577808925, 44.71959972381592, 47.696982724326, 49.27032586506435, 49.774935313633506, 48.99132442474365, 47.49133341653006, 47.71845613207136, 49.000252859933035, 49.84621688297817, 48.96447311128889, 49.224818638392854, 50.50464902605329, 49.06260599408831, 53.69100604738508, 49.129739488874165, 47.09630748203823, 38.44709954942976, 26.324415922164917, 12.355367507253375, 5.668759473732539, 5.404735309737069, 5.331042281218937, 7.698520660400391, 9.529245921543666, 9.684409618377686, 10.120891979762487, 4.143391038690295, 0.8456722529871123, 0.09984684868582658, 0.36287325407777515, 5.472395130566188, 25.542106083461217, 37.38283702305385, 29.72167682647705, 32.04779822485787, 45.42484188079834, 54.08752237047468, 37.09527540206909, 8.012002536228724, 0.2995285088462489, 0.057145235394792895, 0.053492613535906584, 0.07047326450369187, 0.04601285739668778, 0.02990616292559675, 0.05504191593666162, 0.08287541900894471, 0.05742722097784281, 0.037947484824274264, 0.024955610445301448, 0.03613226115703583, 0.005257879225869796, 0.03937753130282674, 0.1149689108133316, 0.023476502492225597, 0.0037836919239323053, 0.0043163609973687145, 0.03719263157940336, 0.015963062178343534, 0.004158751731405833, 0.056748054921627045, 0.041254895207073004, 0.22674984697784695, 0.15317835765225546, 0.06939766436283078, 0.11281561385840178, 0.09550291499389069, 0.06162531713822058, 0.1136651329163994, 0.11388203342046056, 0.24567817843386106, 0.1379626848335777, 0.1506017701966422, 0.1507075402353491, 0.12080089215721403, 0.15415430814027786, 0.11326004072491612, 0.0863584613959704, 0.058833742647298744, 0.13805700120116982, 0.19766493194869586, 0.17694959709686892, 0.11113281987075295, 0.09644404306475605, 0.09826087485998869, 0.12827495538762637, 0.07965155664299216, 0.2579901692058359, 1.250628194638661, 16.535215309688024, 50.55861915860857, 58.59058734348842, 48.922269753047395, 31.46033845629011, 40.26216009684971, 50.78955296107701, 33.36087574277605, 16.582278932843888, 2.5193966158798764, 0.43272072608981815, 0.7806399911642075, 2.467910247189658, 8.471503411020551, 13.461473822593689, 20.72533515521458, 12.086910826819283, 11.621999910899572, 13.775849410465785, 14.61637646811349, 22.913619926997594, 35.736548219408306, 46.70888982500349, 49.03406279427664, 51.818598542894634, 49.43824298041207, 49.565221309661865, 46.44192613874163, 47.157239709581646, 47.00891651426043, 50.992673124585835, 50.91803904942104, 49.610815388815745, 50.278103010995046, 46.48902450289045, 51.09848376682827, 48.252498149871826, 45.06248985018049, 46.10549783706665, 46.40504857472011, 46.78822783061436, 49.57067911965506, 50.27514655249459, 48.24197857720511, 48.1618241582598, 42.96025330679757, 38.46090562002999, 34.24055937358311, 36.50372314453125, 34.047184058598106, 35.37434210096087, 35.241357054029194, 34.93561894553048, 35.63660880497524, 36.93487623759678, 35.81559092657906, 37.126570088522776, 38.1805180140904, 41.02359928403582, 48.3550466128758, 47.32031045641218, 48.14947720936367, 39.73715421131679, 42.32650811331612, 48.867406776973176, 47.51318550109863, 47.89939069747925, 40.69194092069353, 37.405168533325195, 43.13163409914289, 46.12790577752249, 47.51898724692208, 48.000205584934776, 40.31885739735195, 38.21458503178188, 39.68918037414551, 40.75581223624093, 38.595909118652344, 38.66937589645386, 40.71120132718767, 45.0178268296378, 47.817169189453125, 47.26484646115984, 50.66352653503418, 49.59229496547154, 45.295223236083984, 44.92021853583199, 45.70924554552351, 49.0810604095459, 50.4698281288147, 51.0708646774292, 51.65757404054914, 48.21786137989589, 49.39974648611886, 50.03846311569214, 50.77027170998709, 49.434911319187705, 49.85504109518868, 50.89018719536917, 48.16133778435843, 53.513340609414236, 47.02313600267683, 47.7639286177499, 37.99284717014858, 27.430341584341868, 14.17211994103023, 6.410571736948831, 8.14169066292899, 7.641692212649754, 13.03680774143764, 16.138903958456858, 13.98606194768633, 13.004677534103394, 5.219297443117414, 3.3068253227642606, 0.21323511217321667, 0.8856151125260762, 6.978417609419141, 28.9128509249006, 43.49577529089791, 38.44896166665213, 38.230951513562886, 52.92791666303362, 61.418573651994976, 43.138606616428916, 9.789490699768066, 0.3881922997534275, 0.15234739652701787, 0.08063426533980028, 0.1911903100886515, 0.13028288978551114, 0.1475347647709506, 0.21609524584242276, 0.1292930700417076, 0.08794495769377265, 0.0674193005210587, 0.10905633307993412, 0.11127533258071967, 0.1251558249018022, 0.10261494586510317, 0.19309235231152602, 0.12974721352968896, 0.13473801501095295, 0.13320812210440636, 0.1355149783194065, 0.16541819301034721, 0.07192154321819544, 0.11073226029319422, 0.12039561676127569], [0.026731127939586128, 0.015851787524297833, 0.018550272099673748, 0.04266946090917502, 0.011979031093817736, 0.014174655911379626, 0.019708904570766857, 0.010202451692228871, 0.03239966716085162, 0.07249364323381867, 0.05506488434704287, 0.08106701461864368, 0.02056914278572159, 0.03292556572705507, 0.0207356366195849, 0.07503076030739717, 0.06668547168374062, 0.034123044327965806, 0.08141815649079424, 0.03058482686589871, 0.011197175547879721, 0.05716820380517414, 0.02788537707445877, 0.017301408041800772, 0.021904085796060305, 0.048232043494603465, 0.21519875180508408, 7.336364047867911, 29.409626279558452, 42.276303904397146, 43.54496158872332, 31.411384923117502, 19.850994689123972, 25.022571904318674, 37.07881164550781, 15.385856458118983, 3.870437570980617, 0.24290231881397112, 0.059148501471749375, 0.6752018917884145, 2.008631714752742, 3.8584449802126204, 6.561065810067313, 6.789408802986145, 6.743740899222238, 4.004390588828495, 9.01595035621098, 18.573280027934484, 34.89060156685965, 45.68605593272618, 53.64485958644322, 47.41460793358939, 46.62806143079485, 43.7294362613133, 41.31310987472534, 40.38456998552595, 40.76244081769671, 42.313296113695415, 41.551398345402305, 44.02260855266026, 44.38769122532436, 44.44523273195539, 43.32001713344029, 44.120251587459016, 46.44705738340105, 43.66203873498099, 42.695971625191824, 42.907085691179546, 42.80423150743757, 45.65411158970424, 46.83196326664516, 43.63343300138201, 42.71554817472185, 34.323597294943674, 33.748057161058696, 34.21798815046038, 33.755481311253135, 33.72322082519531, 33.23400511060442, 32.26250103541783, 31.986963272094727, 31.246882847377233, 32.503325598580496, 31.32621737888881, 35.907407896859304, 38.63489893504551, 41.92572212219238, 41.96945408412388, 47.48414550508772, 35.55095141274588, 39.63795478003365, 46.56072643824986, 43.63752896445138, 43.32527691977364, 36.15257508414132, 33.308948380606516, 36.176772185734336, 40.99686261585781, 40.23487799508231, 41.33217225755964, 39.061921324048726, 37.31899002620152, 38.74780716214861, 34.7982565334865, 34.1993739264352, 33.55408082689558, 33.51444482803345, 35.06545645850045, 40.757465907505576, 44.65557902199881, 44.718300410679404, 45.25087635857718, 43.746237005506245, 48.01920543398176, 48.19373376028878, 45.32592732565743, 46.497480460575645, 46.40428079877581, 45.83864532198225, 44.559711251940044, 44.43588393075125, 45.3853691646031, 46.36560712541853, 49.37018537521362, 48.96065160206386, 48.542046955653596, 48.16715342657906, 46.8376920563834, 46.18852186203003, 42.635696002415244, 34.42124032974243, 21.415697744914464, 10.342146941593715, 4.095163592270442, 3.7369830863816396, 4.284307020051139, 4.7193524071148465, 7.513931342533656, 5.971504211425781, 7.056758114269801, 2.454290475164141, 0.3651912925498826, 0.030965457869959728, 0.5993221348949841, 6.001202983515603, 20.758191449301584, 32.2531487601144, 41.145244870867046, 32.04180540357317, 41.30081851141793, 52.06973075866699, 25.413277796336583, 3.817192656653268, 0.25155385743294445, 0.1482169638786997, 0.05089507631159254, 0.04111091346879091, 0.059669528156518936, 0.052227328930582316, 0.03284733063940491, 0.021871729853696058, 0.03701682315607156, 0.027019495144486427, 0.04168716611872826, 0.04696300319795098, 0.019663513970694373, 0.04014105961791106, 0.07017128249364239, 0.02851952233218721, 0.06571558051343475, 0.03294207787673388, 0.05478466295504144, 0.03350520765941058, 0.0287023671636624, 0.04929080578897681, 0.021552368865481446, 0.05159208783879876, 0.025518884416669607, 0.012486923885132586, 0.01829819125123322, 0.028932013948048865, 0.03854765244094389, 0.010015478823333979, 0.02741303527727723, 0.03594017807128174, 0.04412386340222188, 0.023562192983393158, 0.05943292299551623, 0.06573571264743805, 0.016856060063998615, 0.024594000474150692, 0.08004317991435528, 0.023358951389257396, 0.06091602412717683, 0.03388447480808411, 0.011634158037070717, 0.04407359752804041, 0.07108535737331424, 0.02755239449574479, 0.0014484201466465102, 0.06963886320590973, 0.0330547757579812, 0.3704345497701849, 9.588177936417715, 36.05334786006382, 49.15565626961844, 48.07096603938511, 32.68676151548113, 26.829494374138967, 31.846790313720703, 38.23926503317696, 16.599637269973755, 4.351279403482165, 0.487078709261758, 0.13380702425326618, 0.47484743701560156, 2.559717663696834, 6.692282974720001, 7.3027573483330865, 6.724311564649854, 6.721393755504063, 6.560019671916962, 9.172158019883291, 21.344084399087087, 35.25669172831944, 45.82021522521973, 54.04291146142142, 50.35042681012835, 46.823302337101524, 46.79202849524361, 43.46049233845302, 44.127977984292166, 42.43534469604492, 44.335214955466135, 44.035493986947195, 45.23676109313965, 45.549520356314524, 45.56828049251011, 45.7220093863351, 48.21297679628645, 46.92520114353725, 44.4069481577192, 44.59215586526053, 43.993391377585276, 45.4327836717878, 46.887997014181956, 47.68966627120972, 46.45138611112322, 44.45803131375994, 36.26991973604475, 35.555353096553254, 34.450374126434326, 33.902091775621685, 36.08367327281407, 35.146611418042866, 34.39327730451311, 33.30870519365583, 33.0357208933149, 33.945809841156006, 33.680809020996094, 37.094486781529014, 39.95385462897164, 44.384640966142925, 44.896896907261436, 49.57639053889683, 38.36002125058855, 40.653288091932026, 48.67392029081072, 46.567421027592246, 45.772811140332905, 38.522584778921946, 34.686060496738975, 37.85261862618582, 43.304005009787424, 42.793576444898335, 41.818740708487375, 39.18579728262765, 39.50280884334019, 40.03063917160034, 35.33233676637922, 35.99422911235264, 36.48903117861067, 36.33383274078369, 37.99720369066511, 42.711726665496826, 45.63704333986555, 48.122146470206125, 47.001454148973735, 44.02345623288836, 48.93652398245675, 48.33641849245344, 47.91486086164202, 47.77334690093994, 46.996368067605154, 48.12640919004168, 47.21656690325056, 47.405755928584504, 46.333318846566335, 47.88898229598999, 48.55226080758231, 48.015126841408865, 48.85038716452462, 46.954640660967144, 47.50665072032383, 46.38278654643467, 45.24465077263968, 37.427239486149375, 23.869365487779888, 9.78037987436567, 5.47728796516146, 7.360084329332624, 7.085437672478812, 8.060875296592712, 10.688632760729108, 8.808086310114179, 7.529240829604013, 3.028258361986705, 0.9513406200068337, 0.22518997639417648, 0.585382094340665, 6.807547943932669, 23.997794253485544, 38.495709146772114, 40.748829296657014, 34.80050080163138, 46.47460004261562, 57.55795649119786, 30.675692285810197, 5.40509922163827, 0.20654258557728358, 0.028902311077607528, 0.10041848729763712, 0.010111913916521838, 0.08651458551841122, 0.026919010893574784, 0.045928186404385736, 0.025723062389131104, 0.04729015546451722, 0.06868273951113224, 0.08681658109916107, 0.05657535079600556, 0.04016819084063172, 0.04647977430639522, 0.055371982511132956, 0.008730894137573029, 0.008663725956077022, 0.05846355429717472, 0.08772055937775544, 0.0037576870693426046, 0.01976449185583208, 0.03506144468805619, 0.0440807798212128, 0.07825805606054408, 0.0930433544729437, 0.13775916504008429, 0.1333219531391348, 0.11854255119604723, 0.12211563518004757, 0.09714779244469744, 0.09363147470035724, 0.10425891407898494, 0.13101797391261372, 0.13706948847642966, 0.12112380697258882, 0.2510449561689581, 0.1154507656714746, 0.09805694794548409, 0.21890826203993388, 0.12291645577975682, 0.15741910652390548, 0.1033978056428688, 0.17183823351349148, 0.08086421407227005, 0.16772496780114515, 0.0805649326315948, 0.0950041917551841, 0.2419139647058078, 0.13898112518446787, 0.575910396873951, 10.850272178649902, 39.164469787052695, 55.08547823769705, 54.98720986502511, 40.08449465887887, 29.183406829833984, 34.82359661374773, 45.211236885615754, 20.876163176127843, 5.81071594783238, 0.7507589917097772, 0.5287409222551754, 2.2781790452344075, 5.958849370479584, 10.351092747279576, 14.030892593520027, 17.237066745758057, 13.245950256075178, 9.274829813412257, 12.97153549534934, 25.094294684273855, 37.95711953299386, 46.05045420782906, 55.93856416429792, 50.97203002657209, 50.14753246307373, 47.363868713378906, 45.049218790871755, 45.29019968850272, 43.10730845587594, 45.570107868739534, 46.67754650115967, 47.49226794924055, 47.69631917136056, 48.235304832458496, 47.69999476841518, 47.47797550473894, 47.58886528015137, 45.53503336225237, 43.11977352414812, 44.450242383139475, 46.15051521573748, 47.3450425692967, 51.53949287959507, 47.27644647870745, 46.49285296031407, 38.008605684552876, 38.16754920142037, 37.08428682599749, 37.49840988431658, 39.49009016581944, 35.98858370099749, 35.73971659796578, 35.460711683545796, 33.96978807449341, 35.87172194889614, 34.60574279512678, 40.59752532414028, 42.00251013892037, 46.343935694013325, 48.04201636995588, 50.82415499005999, 41.06296082905361, 41.796607221875874, 49.345703397478374, 48.601009368896484, 47.211675371442524, 40.0926970073155, 36.677695614951, 38.97933503559658, 44.55855090277535, 44.20415803364345, 44.2584547315325, 42.141293457576204, 40.857478278023855, 42.278593335832866, 36.40350580215454, 37.505882671901155, 37.68030677522932, 37.92091941833496, 39.4108772277832, 45.28405053274972, 48.21451234817505, 48.68407160895211, 47.833323751177105, 44.590137413569856, 50.72585187639509, 50.814649854387554, 49.55948209762573, 50.54712336403983, 49.85222012656075, 50.076963084084646, 48.797862257276265, 48.09981843403408, 48.501726559230256, 50.28177513395037, 51.70213631221226, 50.635198729378835, 49.69783810206822, 48.43701798575265, 47.01199804033552, 49.15809161322457, 45.583778449467246, 38.66576630728585, 27.24605277606419, 13.73829960823059, 8.186251197542463, 8.278472900390625, 9.266082031386238, 13.141874057906014, 18.460132087979996, 15.071690184729439, 15.452727658408028, 6.7540368267468045, 1.3594267794064112, 0.5991067407386643, 0.9883046022483281, 7.644976105008807, 27.66264418193272, 43.63110188075474, 52.907777309417725, 42.73571184703282, 54.20826121738979, 65.5263625553676, 37.46736533301217, 7.380855969020298, 0.4381798117288521, 0.2755950859614781, 0.22073782315211637, 0.11890197119542531, 0.1934904216655663, 0.18682123667427472, 0.10457771018679653, 0.12200951230313097, 0.10010445450565644, 0.129155001736113, 0.1537480420832123, 0.16139319113322667, 0.12387519861970629, 0.24356975299971445, 0.15546156013650553, 0.12468857211726052, 0.0903986624575087, 0.11767332069575787, 0.21957657832120145, 0.10189232642629317, 0.095373138386224, 0.17522922583988734, 0.10289925882326705], [0.01890055392868817, 0.06242693162390164, 0.032900948476578505, 0.04660973072584186, 0.0019367900011794908, 0.05403190977605326, 0.11181267124733754, 0.041501875168510845, 0.028485415769474845, 0.05042513652837702, 0.04613433212840131, 0.008658505477277296, 0.02398082534117358, 0.0700001898886902, 0.05300968319975904, 0.03899075277149677, 0.018108118325471878, 0.06870602004762207, 0.048475165984460285, 0.04453039748061981, 0.10335189596350704, 0.0229019512688475, 0.035312974226794074, 0.01731688542557614, 0.024634688826543943, 0.10865447750048977, 0.12529124692082405, 3.6410039280142104, 21.33164538655962, 40.91161864144461, 47.012216908591135, 34.437064852033345, 27.871946505137853, 31.882041999271937, 29.595803260803223, 21.128387996128627, 6.410038462706974, 0.7624752830181802, 0.13255135448915617, 0.4476883400763784, 1.5511033684015274, 7.360897268567767, 5.501089453697205, 4.2482219849314005, 2.1298951506614685, 4.652882899556841, 8.766133955546788, 20.61674002238682, 31.317400114876882, 43.587543623788015, 47.68270765032087, 48.451432023729595, 44.994293281010215, 43.93500566482544, 43.58896453039986, 40.95483991077968, 37.51717349461147, 38.85863440377371, 40.73382118770054, 41.328031131199424, 42.05031721932547, 41.421046665736604, 44.13118805204119, 44.341954708099365, 45.569433893476216, 44.21000146865845, 44.32938541684832, 42.15366472516741, 45.29067216600691, 42.48873117991856, 47.53533288410732, 44.6621207509722, 44.209862504686626, 35.0288325037275, 34.688162326812744, 34.43918752670288, 32.99638019289289, 33.94240174974714, 33.7163907459804, 34.99273313794817, 32.76040199824742, 35.19827822276524, 34.469565050942556, 35.728401456560405, 37.600913184029714, 38.76949943814959, 44.11022881099156, 44.6330703326634, 44.796328680855886, 36.075721059526714, 43.106019565037315, 47.63465390886579, 42.78696870803833, 43.203846727098735, 35.33197546005249, 33.93125336510794, 34.98414863858904, 35.55786139624459, 36.61163214274815, 36.34201424462454, 37.13867385046822, 37.65055111476353, 38.782291071755544, 36.59488351004464, 34.606698172433035, 33.573226588112966, 34.465045247759136, 37.69073254721505, 40.66458933694022, 43.49475390570504, 43.86530133656093, 47.89039625440325, 45.68212672642299, 45.13533476420811, 43.47852986199515, 41.8863571030753, 40.61623682294573, 41.46773508616856, 38.80305576324463, 38.99065712520054, 40.60223967688424, 42.03732408796038, 42.31183699199131, 44.92771216801235, 46.49087619781494, 49.186645235334126, 48.18878664289202, 47.94805588041033, 46.37618228367397, 43.02987425667899, 30.879614966256277, 20.82944175175258, 8.588107211249215, 4.4125416704586575, 4.942597593579974, 7.4338854891913275, 5.417257700647626, 5.267147949763706, 8.563115409442357, 8.440193959644862, 2.806415625980922, 1.051876493862697, 0.12023959441908769, 0.9457514456340245, 7.2721956968307495, 23.630722658974783, 31.486620017460414, 27.332213912691387, 32.72316312789917, 38.95980364935738, 43.699037892477854, 25.236032724380493, 3.039443224668503, 0.10456668399274349, 0.055088127564106665, 0.038431568669953516, 0.0188274926705552, 0.05417464979525123, 0.06784343919051544, 0.004851714100888265, 0.025503296770953705, 0.04441560971151505, 0.06569105147251061, 0.07136519200035504, 0.07619748770126275, 0.05773642938584089, 0.03629283646919897, 0.0388028799955334, 0.030424597606595074, 0.04949507197099073, 0.08498039748519659, 0.07767984922975302, 0.011412400070444813, 0.023306780528011065, 0.0632151382576142, 0.06971635869038956, 0.019696178646492105, 0.0368087096805019, 0.027171305480546186, 0.06876522901334933, 0.02725815287392054, 0.04314857448584267, 0.02511384311531271, 0.026424514928034375, 0.03278309033651437, 0.03653940591695053, 0.020778893227023736, 0.041589148342609406, 0.03315897498811994, 0.03867242146017296, 0.01508164858179433, 0.09851071823920522, 0.04729024028139455, 0.05134329279618604, 0.030320469622633288, 0.021677975875458548, 0.06159020973635571, 0.034821036338273964, 0.025771160343927995, 0.03873711638152599, 0.06043364679706948, 0.030866924407226697, 0.0867392620337861, 5.2138895733015875, 25.64501585279192, 46.57561642783028, 51.6535336630685, 38.485470976148335, 27.269522053854807, 36.41717985698155, 36.4335880279541, 24.350198200770787, 7.440555759838649, 0.8192808234265873, 0.10305814458323376, 0.5716710186430386, 1.852705453123365, 6.597661972045898, 6.654707551002502, 6.0626228877476285, 6.105036863258906, 2.955929134573255, 9.839010511125837, 22.69642445019313, 34.553652150290354, 45.728123801095144, 49.69419377190726, 50.772185938698904, 47.305340562547954, 44.325959954942974, 44.50721761158535, 42.53137922286987, 40.28726741245815, 41.20481872558594, 42.91587863649641, 43.869546685900005, 44.909966468811035, 42.88455268314907, 46.27381099973406, 45.84076452255249, 46.68474136080061, 44.75314910071236, 44.54163898740496, 42.27717242922102, 45.42969519751412, 44.142805440085276, 48.573115825653076, 46.306957381112234, 45.6707421030317, 35.41763980048043, 35.74355895178658, 35.536926473890034, 34.33183438437325, 34.72958748681204, 34.715295042310444, 36.39345523289272, 34.44784498214722, 35.92989226749965, 36.45959166118077, 36.9245616367885, 39.318361963544575, 41.07269178118025, 44.699463844299316, 46.151831899370464, 46.34419277736119, 37.34348242623465, 44.008149351392476, 49.570022514888215, 44.620983941214426, 43.53775978088379, 38.06706782749721, 35.855716773441856, 36.085198402404785, 37.96761131286621, 38.55893427985055, 39.86615099225725, 37.60157673699515, 40.666517462049214, 41.14708614349365, 37.36474738802229, 36.270756993974956, 35.093468121119905, 37.00728341511318, 38.02319342749459, 42.904341152736116, 45.29487930025373, 45.974361010960166, 48.50563839503697, 46.907632623400005, 47.10690695898873, 45.71553713934762, 45.13208300726754, 43.48775012152535, 43.73470299584525, 43.07269253049578, 41.973709855760845, 43.512843540736604, 44.32453557423183, 44.14380945478167, 46.21922942570278, 47.48009123120989, 50.086343152182444, 49.6144562448774, 48.13355541229248, 47.76126398359026, 43.743294443402974, 34.99893093109131, 21.356479985373362, 12.50183379650116, 4.964647701808384, 8.53037897178105, 8.522439786366053, 9.194356645856585, 6.412129436220441, 7.38363698550633, 5.046712006841387, 2.150953620672226, 0.9597619452646801, 0.1768828292510339, 1.0457735870565688, 7.586335914475577, 26.64117213657924, 33.216172558920725, 35.82614871433803, 38.29025786263602, 47.95196771621704, 49.548833983285085, 29.65380334854126, 3.6780619280678883, 0.07021236778902155, 0.09824366721191577, 0.025844591403646127, 0.016956605383061936, 0.04859686124005488, 0.08332221396267414, 0.008535264010008956, 0.01688986467862768, 0.11914209116782461, 0.10200034241591181, 0.050462140435619016, 0.03915407954316054, 0.19319350831210613, 0.014256517768704464, 0.09924460814467498, 0.0832654070109129, 0.06788940315267869, 0.010307132682230855, 0.07051114032843284, 0.03642537132171648, 0.03031966895131128, 0.03615112103787916, 0.08744417849395957, 0.08462783068950687, 0.23108728708965437, 0.10773496755531856, 0.11447809929294245, 0.121797239407897, 0.1310910385634218, 0.13156795368662902, 0.1276786316718374, 0.19938233122229576, 0.07215192621307713, 0.12417132487254483, 0.17001422281776155, 0.07469112638916288, 0.1297899205237627, 0.10036535800567695, 0.19724413167153085, 0.10155578662774392, 0.21653800351279123, 0.1302259335560458, 0.08469719732446329, 0.1996243510927473, 0.1201881750353745, 0.08634408323892526, 0.1435592280966895, 0.13097416769180978, 0.21736203001013824, 0.2699865869113377, 5.407683517251696, 29.97808619907924, 53.18447194780622, 58.6458672114781, 44.218558175223215, 36.77899687630789, 41.22446475710188, 39.30032444000244, 27.094326700483048, 9.458421196256365, 1.2919079852955682, 0.41910016696367947, 1.5891155515398299, 6.231590918132237, 15.97785861151559, 13.172311510358538, 11.220559920583453, 7.788862007004874, 8.82372670514243, 12.466080103601728, 24.387589931488037, 32.981340817042756, 46.35542801448277, 50.75352655138288, 52.82332195554461, 48.86920983450753, 47.363222530909944, 46.518835748944966, 45.3254131589617, 40.80105543136597, 43.50364759990147, 43.67402785164969, 45.21425240380423, 45.5791266305106, 44.265847614833284, 48.488656997680664, 48.185138838631765, 49.681568895067485, 46.786560262952534, 44.608914920261924, 42.92525175639561, 45.23263038907732, 44.03689752306257, 49.74151447841099, 49.016261509486604, 47.27920491354806, 37.232026372637065, 37.31915330886841, 37.217337880815776, 36.12788813454764, 36.22968619210379, 35.98354278291975, 39.56786135264805, 35.48013537270682, 39.48000485556466, 38.132353101457866, 39.61581434522356, 40.41240446908133, 43.59168822424752, 46.61421019690377, 49.65705565043858, 47.06598901748657, 41.755147320883616, 44.60571527481079, 50.69593293326241, 46.10658523014614, 45.05075086866106, 37.896190779549734, 38.254943643297466, 37.18369817733765, 38.57538414001465, 39.755174364362446, 41.329851559230256, 40.38966996329171, 41.50633927753994, 42.43142243794033, 38.86013521466936, 37.85620042255947, 36.545075348445344, 39.401625701359336, 41.0339868409293, 44.729629448481965, 47.751105717250276, 48.321535451071604, 51.03798232759748, 47.269831793648855, 47.443126814705984, 47.07146419797625, 45.47101960863386, 43.912302425929475, 45.49889925548008, 44.37646641050066, 42.83686719621931, 44.53203657695225, 47.85421698434012, 46.2488773890904, 48.21191372190203, 48.30625636237008, 52.06466899599348, 51.464796270642964, 51.04448584147862, 47.97706113542829, 46.59000614711216, 36.14432062421526, 24.540255750928605, 10.844825659479413, 9.304086072104317, 9.525781376021248, 15.320538180215017, 13.810873542513166, 13.203380380358015, 19.831781182970317, 18.052727937698364, 7.590966020311628, 2.795991373913629, 0.443912075566394, 1.4075983145407267, 9.667246699333191, 30.744184153420584, 41.24708114351545, 38.862983976091655, 46.265976905822754, 51.16107313973563, 57.62276928765433, 34.32223892211914, 5.215009536061968, 0.20956995098718575, 0.21086794776575907, 0.09407797109867845, 0.13530509386743816, 0.1317561657301017, 0.21654083978916916, 0.07363514948104109, 0.06845861939447266, 0.19373801909387112, 0.12197618266301495, 0.1386217458971909, 0.13375618840966905, 0.3051214558737618, 0.11834011705858366, 0.24205678275653295, 0.14877691811748914, 0.2594202496111393, 0.08014699577220849, 0.1435829768223422, 0.07478055730462074, 0.1904535431947027, 0.19402185029217175, 0.1782985518553427], [0.07080823688634805, 0.02741041104309261, 0.011551274984542812, 0.021586987722132887, 0.020424619915762117, 0.031487118984971724, 0.07012220405574356, 0.0342151181373213, 0.05055370195103543, 0.01113324482659144, 0.019462112902796695, 0.0027841394434549977, 0.041013251923556836, 0.02620819117873907, 0.04528620406719191, 0.040895156296236176, 0.025388095095487576, 0.02482263624135937, 0.05619891653103488, 0.04019110157553639, 0.021948767327038304, 0.06311719851302248, 0.027837503036218028, 0.015932312667635933, 0.036571789000715525, 0.025333776670907224, 0.03148252869557057, 1.3890162259340286, 11.83335542678833, 34.29115268162319, 45.98346315111433, 37.356941086905344, 29.01092301096235, 25.600734983171733, 31.787845270974294, 26.572049719946726, 10.13031200000218, 1.2440852714436395, 0.11461102430309568, 0.02142803410866431, 1.0747778649841035, 3.8379021968160356, 5.1641726068087985, 4.156866201332637, 6.219969187464033, 3.3916372060775757, 6.879836133548191, 15.457923173904419, 28.27563336917332, 42.114445618220735, 49.83302572795323, 45.71775361469814, 46.95139585222517, 43.68756989070347, 43.06979513168335, 42.590077604566304, 42.38278157370431, 37.53690637860979, 36.90828895568848, 37.083428723471506, 37.99199948992048, 38.772282191685264, 40.84609712873186, 43.631671633039204, 47.19222041538784, 46.186440876552034, 45.56115164075579, 45.217292240687776, 46.3531038420541, 41.648495946611675, 45.80693374361311, 44.71081372669765, 41.72186197553362, 33.127152238573345, 31.331869738442556, 32.273003237588064, 33.13394757679531, 33.15797792162214, 35.72568818501064, 35.02192946842739, 36.80263464791434, 37.64155667168753, 38.43487071990967, 38.32137884412493, 41.293672289167134, 39.98053918566023, 42.90347262791225, 42.91815764563424, 47.7054352079119, 36.00710065024239, 41.8616805757795, 46.98306574140276, 44.053364753723145, 42.67225047520229, 37.03005266189575, 34.001822744097026, 33.25777489798409, 34.486199038369314, 33.35541098458426, 35.67273596354893, 36.25998033796038, 35.38329138074602, 37.213064738682334, 33.88493667330061, 33.58305828911917, 35.33828789847237, 37.56115211759295, 38.163411549159456, 44.195500578199116, 44.57802322932652, 46.065257344927105, 47.26714631489345, 45.60546725136893, 47.14022009713309, 45.88929074151175, 42.86164794649397, 35.9622917175293, 34.40760101590838, 35.49796792439052, 38.78402117320469, 39.93448999949864, 42.04744413920811, 43.61848742621285, 42.250064032418386, 45.026161193847656, 47.12149122783116, 48.2865651675633, 46.29489183425903, 47.81423010144915, 42.87413733346121, 33.66496018001011, 21.55274748802185, 12.802073274339948, 4.812350136893136, 10.949688741139003, 5.8295729245458325, 7.5265466656003674, 7.062753541128976, 4.432328837258475, 2.4234152862003873, 1.5928433686494827, 0.875830203294754, 0.14470418808715685, 0.8623782194086483, 10.525960666792733, 28.06003076689584, 33.41498483930315, 32.33409527369908, 32.44823680605207, 42.7371883392334, 44.9581800188337, 16.59733394214085, 1.4185541038002287, 0.11016212802912508, 0.035200544366879125, 0.05891672069472926, 0.02508766184161816, 0.028637214231171777, 0.023083152349240015, 0.03146532104749765, 0.052635959682187865, 0.03987484658136964, 0.010726089040482683, 0.03742066684312054, 0.023811062664857933, 0.056578187072383504, 0.053278454313320775, 0.03621444531849452, 0.009501472431501108, 0.04159418646512287, 0.054644067106502395, 0.0594652687598552, 0.04774754574256284, 0.05294808239809104, 0.0446048531282161, 0.02126332651823759, 0.06309795525989362, 0.045117547402956655, 0.08653177959578377, 0.04593515156635216, 0.038592958224139044, 0.03323740006557532, 0.03358821963359203, 0.041142560342060666, 0.0490082638072116, 0.02659610964890037, 0.07526125865323202, 0.05836567562073469, 0.009410441869736781, 0.022950746418376054, 0.020254504401236773, 0.02416162269323, 0.03322701169443982, 0.06150233945144074, 0.010745281403485154, 0.03801432730896132, 0.09033637294279677, 0.06386710863028254, 0.1097262032063944, 0.02566232163059924, 0.06416607115949903, 0.011113151708351714, 0.02520801529421338, 2.2593233713081906, 15.268421479633876, 41.070100103105815, 51.67603193010603, 40.44144099099295, 32.97802652631487, 28.854896000453405, 33.22874185017177, 26.91350678035191, 11.622646961893354, 1.4724415093660355, 0.0619062442066414, 0.15737378038465977, 0.8965414262243679, 5.327251604625157, 6.793195136955806, 5.651457156453814, 5.943144704614367, 5.075907034533365, 9.026066064834595, 19.16164653641837, 29.087938581194194, 43.40191902433123, 51.65186956950596, 47.68170016152518, 47.127150535583496, 46.621050698416575, 44.578978606632774, 43.53879158837454, 42.724990776606965, 37.828147070748464, 39.02852133342198, 39.80426686150687, 39.71433285304478, 42.02307333265032, 44.26772362845284, 45.467809540884836, 49.763762610299246, 46.909706660679404, 45.44541549682617, 45.63371862683977, 47.781959193093435, 42.92892040525164, 47.62400579452515, 46.61139965057373, 43.58702598299299, 35.5779938016619, 33.571013586861746, 33.52419662475586, 34.77548033850533, 35.230354581560405, 36.25346640178135, 36.629850319453645, 38.62062733513968, 38.2513062613351, 41.66176700592041, 40.26057938167027, 41.614547048296245, 41.6540093421936, 44.964023453848704, 45.08622489656721, 48.83640044076102, 37.02351788112095, 43.771205357142854, 47.66233900615147, 44.798204694475444, 44.23988567079817, 37.757661070142476, 34.823478494371685, 34.89162642615182, 35.777330671037944, 35.82933793749128, 37.23066105161394, 38.50860847745623, 37.74435874394008, 38.38408286230904, 35.771758215767996, 35.61881446838379, 35.992019585200715, 38.66839967455183, 40.040425709315706, 45.46482528959002, 45.54813419069563, 47.127893992832725, 48.18883875438145, 45.897176946912495, 48.773157937186106, 46.40073026929583, 44.85961634772164, 38.0566212109157, 36.84495612553188, 37.33538777487618, 40.21055235181536, 42.258321966443745, 44.11218472889492, 45.09265545436314, 44.767875807625906, 47.83528661727905, 47.792034081050325, 49.74088566643851, 48.32656247275216, 48.92602872848511, 43.80338246481759, 34.59903430938721, 22.779038531439646, 13.19780879361289, 4.688378206321171, 7.177383184432983, 8.98721694946289, 7.359895859445844, 7.433266230991908, 6.204790847642081, 3.6919192416327338, 1.91447537285941, 0.2879726232162544, 0.045964291252728016, 1.2001826443842478, 10.834378174373082, 27.31426497868129, 41.25292110443115, 35.99599742889404, 37.17168126787458, 47.78023951394217, 50.28220592226301, 21.613255875451223, 1.956990314381463, 0.06847607810050249, 0.017607914184087088, 0.04623041268704193, 0.02154640114999243, 0.05027987575158477, 0.02238587788971407, 0.017432852149275795, 0.028331334037440162, 0.044993629945175986, 0.046763700499598465, 0.037058017017053704, 0.01612814805204315, 0.045064998258437426, 0.04375474713742733, 0.015796337642573884, 0.092213153306927, 0.041382147664470334, 0.08512225880154542, 0.06839520351162978, 0.09170894071991954, 0.03519227981035199, 0.080194934271276, 0.05386986543557473, 0.11692005183015551, 0.1273159682750702, 0.1426894004855837, 0.13512035592326097, 0.060392703994044235, 0.11230735720268317, 0.14321017611239636, 0.11539437941142491, 0.13647719525865146, 0.07240907062909432, 0.15419546807450907, 0.10254462928112064, 0.11702586258096354, 0.12139181473425456, 0.10743483794586998, 0.17016864381730556, 0.08444046681480748, 0.18088805861771107, 0.0999134536832571, 0.0913867112249136, 0.1777792690055711, 0.12306816263922624, 0.10122120779539857, 0.10529555952442543, 0.15709942153521947, 0.08936090421463762, 0.07700174168816634, 2.560004928282329, 17.52095798083714, 46.84387942722866, 58.12054170880999, 49.49683019093105, 38.776871476854595, 33.525513308388845, 41.45439107077462, 34.588612011500764, 13.520298140389578, 2.042218003954206, 0.32353396500859943, 0.8886239539299692, 3.2414746923106055, 9.062233175550189, 12.448000022343226, 12.174897602626256, 14.104235172271729, 6.588871198041098, 9.512331400598798, 18.848958492279053, 31.87465259007045, 44.46838065556118, 53.60327461787632, 48.74202305930001, 50.262726647513254, 48.74430206843785, 47.66086598805019, 46.01059586661202, 45.94655779429844, 40.87941721507481, 41.85480533327375, 39.72394915989467, 41.280946663447786, 42.76372003555298, 46.030168942042756, 46.51439585004534, 50.445797783987864, 46.827505997249055, 45.92631074360439, 44.806215967450825, 47.53558301925659, 44.24722991670881, 48.31637641361782, 49.172210352761404, 46.00696890694754, 36.76166459492275, 34.33369997569493, 35.47252709524972, 37.442546367645264, 36.51470129830496, 38.83867917742048, 39.10847772870745, 41.102721895490376, 40.50825834274292, 44.04242481504168, 42.19585766111101, 45.99448994227818, 44.56661081314087, 46.206284931727815, 45.00281524658203, 49.0697591645377, 38.99010474341256, 44.00636713845389, 50.362318652016775, 47.83920192718506, 45.372219698769705, 40.73559297834124, 37.55992923464094, 37.01939065115792, 37.40065220424107, 36.943617071424214, 38.553737027304514, 39.797370774405344, 39.1012898172651, 39.853255135672434, 37.70338521684919, 37.20072821208409, 37.356690951756065, 40.995907238551546, 41.7436272076198, 48.64600937707083, 48.34018441608974, 49.372297627585276, 48.8607816696167, 45.939776352473665, 51.30627659388951, 48.25647946766445, 46.95943144389561, 40.12285566329956, 37.496304580143516, 39.440514768872944, 42.144743238176616, 44.09734337670462, 47.218456813267295, 49.18177454812186, 46.42113018035889, 50.439203943525044, 49.365471022469656, 51.042262417929514, 48.66574920926775, 49.225419657570974, 46.04511799131121, 38.28394195011684, 25.50658515521458, 17.744589226586477, 8.956932357379369, 18.124290909085953, 15.645387308938162, 14.034814851624624, 14.094507694244385, 11.70399820804596, 5.929908820561, 3.615229368209839, 1.1761626132896967, 0.510771740760122, 1.524961639727865, 13.314973660877772, 34.541159289223806, 44.4140179497855, 42.77499696186611, 43.66788911819458, 54.9562452180045, 57.29876783915928, 25.424643312181743, 2.9859340616634915, 0.1759742030075618, 0.16078297102025577, 0.10420110968074628, 0.0827272269608719, 0.08054833566503865, 0.09978938355509724, 0.1864318661391735, 0.11675804480910301, 0.13417400313275202, 0.11365216611219303, 0.13724932739777224, 0.20472086832991668, 0.13116311255310262, 0.12520121889454977, 0.10104902274906635, 0.18418545382363455, 0.16752399929932185, 0.15787951967545918, 0.17407172652227537, 0.14768554882279464, 0.11799209644751889, 0.2073635993791478, 0.15661342761346272], [0.018408870490800058, 0.05314411795032876, 0.026889767730608582, 0.03207075409591198, 0.09791273889797074, 0.03898981978584613, 0.007242361333088151, 0.0408389634186668, 0.006768732015708727, 0.013073722665597285, 0.021392029344237277, 0.04664437333121896, 0.03720286049480949, 0.04224794817024043, 0.02715135824733547, 0.013483827534530844, 0.02723630065364497, 0.06363110736544643, 0.030724550796938793, 0.04462129742439304, 0.05129640602639743, 0.031628949767244716, 0.01284334306339068, 0.02412903604895941, 0.048200671428016255, 0.08899002375879458, 0.04260513578940715, 0.3641745485365391, 8.43158427306584, 27.206442832946777, 48.82082952771868, 42.94686412811279, 34.59177344185965, 40.6025002343314, 38.600849287850515, 29.964339188167028, 12.757652572223119, 2.949064314365387, 0.11421062078859125, 0.2733785834695612, 0.8189910075494221, 5.308425026280539, 4.445855677127838, 4.3154623082705905, 3.7709975583212714, 1.634909717100007, 8.677460176604134, 16.64085919516427, 27.68837857246399, 40.397677762167795, 47.3181426184518, 49.519265924181255, 47.4073748588562, 49.073160307747976, 49.912832736968994, 47.353738239833284, 46.32239627838135, 42.771932806287495, 36.55050189154488, 35.12799024581909, 37.736847741263254, 39.743980816432405, 41.88776411328997, 43.80090543201992, 45.261642592293875, 44.9940778868539, 43.85567808151245, 42.91700077056885, 44.581090859004426, 45.63545567648751, 46.8310843195234, 43.92641074316842, 39.99157987322126, 33.84058632169451, 32.21069874082293, 34.76748296192714, 33.930544648851665, 34.27596739360264, 35.820979254586355, 35.36285325459072, 39.162128244127544, 38.428023270198274, 39.98413487843105, 40.503064564296174, 41.0532020841326, 42.55073343004499, 43.82249001094273, 42.96034015927996, 46.56287343161446, 33.23946292059762, 41.29697963169643, 46.87922491346087, 44.307707037244526, 44.83760445458548, 40.800794873918804, 38.263691425323486, 34.44175836018154, 32.431217193603516, 31.477351120540074, 33.853145190647666, 34.89282499040876, 34.284082889556885, 33.817181314740864, 34.28462137494768, 32.711674281529014, 36.500544343675884, 40.02495207105364, 44.64819656099592, 43.1244010244097, 43.84510292325701, 46.980950014931814, 46.60627882821219, 45.16310323987688, 47.87932429994856, 46.35523346492222, 41.39578996385847, 35.6897486277989, 32.87143073763166, 40.91574239730835, 46.08972542626517, 47.07221807752337, 48.232841696058, 44.98636886051723, 46.544491972242085, 45.66799061638968, 47.9157953943525, 47.605558327266145, 47.34459441048758, 47.48282534735543, 42.648397309439524, 33.106536933353965, 20.920638595308574, 14.313025065830775, 4.252050008092608, 5.970511921814509, 6.771813358579363, 6.350233146122523, 5.746303107057299, 4.890007546969822, 3.0170409296240126, 1.1324187091418674, 0.6960293341960225, 0.060530575524483404, 2.464665872710092, 10.836929031780787, 35.52712951387678, 24.276029654911586, 24.463789088385447, 41.270142214638845, 46.6138072013855, 38.3400799206325, 14.712760141917638, 0.5774412804416248, 0.10652442036994866, 0.02266595509302403, 0.05859996019197362, 0.05319870269990393, 0.028046340847920095, 0.05152995438714113, 0.07367202785930463, 0.0439817272791905, 0.08679569579128708, 0.010005977636735355, 0.03736857910241399, 0.03650756226852536, 0.049554111302963326, 0.014015074653018798, 0.019253000284412077, 0.030228110828569958, 0.0657351833901235, 0.018097779148125222, 0.031341115212334056, 0.010946157454912151, 0.052210847314979346, 0.039093645821724615, 0.04131583104442273, 0.009349320283425706, 0.019625619486240403, 0.02904758203242506, 0.025348797739882554, 0.03228080478895988, 0.009218545381112822, 0.030173220738236393, 0.022977619797789624, 0.060009535269013474, 0.04681330140946167, 0.01689463817248387, 0.06043841689825058, 0.009026530997029372, 0.017846300499513745, 0.053519330852265866, 0.040850009968770404, 0.017468794149213603, 0.07533397046583039, 0.03790366842544504, 0.014077301403241498, 0.10222029632755689, 0.02930572728759476, 0.017842750065028667, 0.05107075581327081, 0.0370017936054085, 0.02843277163005301, 0.09845563476639134, 0.5325200366122382, 10.424217326300484, 33.69950662340437, 53.15191616330828, 47.426260062626426, 34.64875909260341, 37.31375803266253, 40.82088559014456, 35.62162501471383, 14.728195565087454, 2.7729950078896115, 0.1753946662481342, 0.27137744799256325, 0.6529710218310356, 2.9757838291781287, 5.074481351034982, 5.081374398299626, 4.577758976391383, 4.1195526378495355, 7.705397639955793, 17.063556330544607, 29.415966510772705, 41.99353654044015, 48.25206388745989, 50.39708743776594, 49.851341179439, 49.93817976542881, 50.22162110464913, 48.5005384172712, 47.78015266145979, 43.08607128688267, 37.85064533778599, 38.299877643585205, 39.64739738191877, 41.29497160230364, 43.43851171221052, 46.98670312336513, 47.474153995513916, 45.91123315266201, 44.947851521628245, 44.15478066035679, 44.624096734183176, 46.2604079246521, 47.79764475141253, 45.709533895765034, 41.52176080431257, 35.95513507298061, 33.535827909197124, 35.730416434151785, 36.92341865812029, 35.76628998347691, 36.50641557148525, 36.80063009262085, 42.003493309020996, 40.4120431627546, 42.07290928704398, 42.47830193383353, 43.723401750837056, 43.69487244742257, 44.709160055433, 45.675105571746826, 48.6078324999128, 36.11634717668806, 43.835316385541645, 49.16015522820609, 45.33299016952515, 46.069520064762656, 41.70096526827131, 38.936301367623464, 36.67364828927176, 34.516340323856895, 35.20459760938372, 35.60475478853498, 36.071427072797505, 36.74276549475533, 36.725113596235005, 35.383267062050955, 34.47612067631313, 38.263691425323486, 41.062460558755056, 45.69629062925066, 45.61390931265694, 46.81061840057373, 48.983952386038645, 46.869625977107454, 46.456288065229145, 48.44117995670864, 47.59611572538103, 44.066177231924875, 38.32703815187727, 34.56419256755284, 42.99040501458304, 47.02670042855399, 48.1526768548148, 49.240306173052105, 47.374558516911094, 46.59472049985613, 47.843690463474815, 48.95520421436855, 48.22381946018764, 48.37815979548863, 50.08911548342024, 44.39906890051705, 34.6000383240836, 22.47252917289734, 12.66591203212738, 3.759672428880419, 6.438103105340685, 10.11084314755031, 7.311493839536395, 5.744769292218344, 5.639621334416526, 3.8847938520567755, 1.6578769875424249, 0.5309498522962842, 0.24877360090613365, 2.050696977547237, 13.485798597335815, 39.42703526360648, 27.838850498199463, 32.89659711292812, 44.57685245786394, 51.01086350849697, 46.98106813430786, 18.23537870815822, 0.7712051517197064, 0.1504724007099867, 0.02278877162773694, 0.03533925388806632, 0.009199414934430803, 0.03876921787325825, 0.035166434411491664, 0.0929728207577552, 0.04384011023544839, 0.013955377990246882, 0.022910064851332988, 0.028626266068645885, 0.05147401596020375, 0.08654178120195866, 0.0772966533633215, 0.0570215859583446, 0.02177821076475084, 0.04002857208251953, 0.036823762979890616, 0.04219165690509336, 0.04617732410718288, 0.06442777533084154, 0.016494575621826307, 0.08881878866148846, 0.12353840097784996, 0.12196607249123709, 0.13496651846383298, 0.10576360619493894, 0.1598543551351343, 0.10679622792771884, 0.06590344650404793, 0.09202924996082272, 0.09789756685495377, 0.08510632679930755, 0.10907595631267343, 0.09299827260630471, 0.11552065477839538, 0.16119674167462758, 0.1895519330033234, 0.08579620692346777, 0.13915561724986347, 0.14548120567841188, 0.06489817651786975, 0.09973911768091576, 0.19527753362698214, 0.13179648428090981, 0.15628361888229847, 0.10965987640832152, 0.15877605442489895, 0.21909150720707007, 0.19159607402980328, 0.6486979882631982, 11.69672691822052, 39.39932584762573, 60.93821689060756, 55.12993976048061, 44.12186009543282, 50.09125205448696, 49.077301434108186, 39.909184660230366, 18.295880147389003, 4.341667873518808, 0.3840322286954948, 0.9317100048065186, 2.390673420258931, 10.20033073425293, 13.669939756393433, 9.777550220489502, 10.142757092203412, 4.776984674589975, 10.862347279276166, 19.335506098611013, 32.63835688999721, 43.34316158294678, 50.588798659188406, 52.176013878413606, 50.92720372336251, 53.124008723667686, 52.76334163120815, 51.09586777005877, 49.58273424421038, 47.73334959575108, 40.212761878967285, 39.617874486105784, 41.56933512006487, 43.234665461948936, 45.59039660862514, 48.37115601130894, 48.793891361781526, 46.042800767081125, 45.342342444828574, 43.776979310171946, 45.421808992113384, 46.333839961460654, 51.006076199667795, 47.74856615066528, 43.08584894452776, 37.67083985464913, 36.00040258680071, 37.663624150412424, 39.29971994672503, 36.67340510232108, 37.89107690538679, 39.836329323904856, 43.66530091421944, 42.73284224101475, 43.341341154915945, 44.04592323303223, 44.59647764478411, 45.7612041745867, 46.73251370021275, 46.31632702691214, 49.50485536030361, 39.86594949449812, 44.68477882657732, 49.840561049325125, 48.09090389524187, 48.03606523786272, 43.8106815474374, 41.759416988917756, 37.917174339294434, 35.75748661586216, 35.561338969639365, 38.10721451895577, 38.43558985846383, 38.653905732291086, 37.957668440682546, 37.90810694013323, 35.70687593732561, 39.283099855695454, 42.58317109516689, 48.536276476723806, 46.91492475782122, 47.51547145843506, 50.56081826346261, 47.66014684949602, 45.88982922690255, 49.83430767059326, 50.185636384146555, 45.019504819597515, 39.76991844177246, 36.6265082359314, 45.27803686686924, 50.145778042929514, 50.75407893317086, 52.13613469260079, 49.28947510038103, 49.536681583949495, 50.63079357147217, 50.91953986031668, 49.79412276404244, 50.897941384996685, 50.89101750510079, 46.5407121522086, 37.320615904671804, 26.509502036230906, 17.98786997795105, 7.43739606652941, 13.469697884150914, 16.72704812458583, 12.946115510804312, 12.867864029748098, 13.753390227045331, 10.153005685125079, 4.037344591958182, 1.7798195012978144, 0.35308905052287237, 3.0336084749017442, 14.051586934498378, 43.49142919267927, 33.046639987400596, 35.957504408700125, 53.15047441210066, 58.643178258623394, 50.64558628627232, 21.075724124908447, 1.2795289009809494, 0.2617610054356711, 0.17910556069442204, 0.16566584472145351, 0.19836493581533432, 0.1641157450420516, 0.15725408680737019, 0.18119451217353344, 0.09445941634476185, 0.17602548668427126, 0.1285023596137762, 0.11442182159849576, 0.2030741995466607, 0.16707026293235167, 0.12325100068535123, 0.19160064735582896, 0.09351917036942073, 0.08435043200318303, 0.08800062470670257, 0.12096047002289977, 0.11947636465941157, 0.10127924289554358, 0.05341942335612007, 0.2001331980739321], [0.034963087644428015, 0.02667503005691937, 0.019704874072756087, 0.018071446900389025, 0.04336559712620718, 0.006307678072646792, 0.018722297690276588, 0.06856865741844688, 0.022991926708657826, 0.10211453307420015, 0.07152407776032176, 0.02016049167806549, 0.02553867219415094, 0.04207763248788459, 0.007174279673823288, 0.018891468344788467, 0.008383335778489709, 0.027760066923552325, 0.020064329695222632, 0.02476763249641018, 0.0462756099046341, 0.03733515786007047, 0.009734818928076752, 0.012501520021552486, 0.04256565862202218, 0.03367021719792059, 0.046759605540760925, 0.12596782775861876, 2.9518516276563918, 23.776744263512747, 46.42517750603812, 47.17121948514666, 38.221199716840474, 32.160136699676514, 26.19038690839495, 25.216939074652537, 19.722300154822214, 4.132511028221675, 0.44876186390008244, 0.0585747661867312, 0.332572947123221, 1.8304175862244196, 3.3821870046002522, 2.6359689320836748, 3.497717091015407, 5.7155716589518955, 5.4592508758817395, 13.987252695219857, 27.512281690325054, 39.135648659297395, 50.37447452545166, 47.36407021113804, 49.65495034626552, 48.01377541678292, 43.73156935828072, 46.70245231900896, 44.47767039707729, 42.78150742394583, 35.71782629830496, 34.08691038404192, 38.063889026641846, 40.70232847758702, 43.123094763074604, 44.90620401927403, 46.829812799181255, 44.66710608346121, 43.789308888571604, 42.33468614305769, 46.94194630214146, 45.36464616230556, 44.04197665623256, 42.69702775137765, 35.78582831791469, 31.659668377467565, 32.64795582635062, 34.14136689049857, 34.26829310825893, 35.733751569475444, 35.623904023851665, 35.70183849334717, 36.973775727408274, 38.364072050367085, 40.21429395675659, 40.49506718771798, 40.412442684173584, 40.61638968331473, 44.506185804094585, 43.370756353650776, 46.65762254170009, 35.76461894171578, 39.92186164855957, 45.929975918361116, 45.268107891082764, 45.33729805265154, 41.24638284955706, 43.50412702560425, 40.39697252001081, 38.27353702272688, 31.725759642464773, 33.6630528994969, 33.04920039858137, 31.72703811100551, 32.031605448041645, 33.51356588091169, 34.95372942515782, 39.11874369212559, 43.47136974334717, 45.51905597959246, 47.6538622038705, 47.3915433883667, 44.694197109767366, 45.31310442515782, 46.80280862535749, 49.11451251166207, 44.47686440604073, 42.16443790708269, 35.67004353659493, 34.37855059759957, 44.65859454018729, 45.48302262169974, 45.81871788842337, 46.686676434108186, 47.16752651759556, 45.62285164424351, 46.98512935638428, 45.97069583620344, 50.73017365591866, 50.196260179792134, 47.91344690322876, 38.84489434106009, 35.21234137671334, 20.551685776029313, 7.677649140357971, 2.5472219799246107, 6.041878172329493, 6.0673797982079645, 4.452957170350211, 4.485306245940072, 3.083437046834401, 2.1736744471958707, 1.5463315844535828, 0.30936699520264355, 0.22161207481154374, 2.420501385416303, 13.043929644993373, 32.3680476461138, 63.94236782618931, 35.129741191864014, 44.01792894090925, 48.957281725747244, 40.40895816258022, 8.456233876092092, 0.09670078035976205, 0.06579156965017319, 0.04721531644463539, 0.035932547944997034, 0.02084259070189936, 0.06733203413231031, 0.05802109518221446, 0.02123466180637479, 0.03228952396394951, 0.030373208756957735, 0.15122699950422558, 0.06648936149265085, 0.05663337232545018, 0.049348695004092794, 0.06059981323778629, 0.05871342481779201, 0.018009430496022105, 0.0031231115780039026, 0.048077517322131565, 0.019647466617503336, 0.021089680925277726, 0.02170770419096308, 0.050311882248414416, 0.028753345499613454, 0.028377011318558028, 0.033021778600024324, 0.025455061412815536, 0.013163134073173361, 0.05600771554080503, 0.04159641545265913, 0.021134023188746402, 0.0448437178108309, 0.03612448175304702, 0.035508507663117986, 0.023219619312190583, 0.04380560672975012, 0.023817854800394604, 0.03724666332293834, 0.014805186273796218, 0.02479180021743689, 0.0548303181837712, 0.030817829005952393, 0.03488160915938871, 0.035303824182067595, 0.039498520882001946, 0.0522537951889847, 0.019780047271134596, 0.017330880210335766, 0.023138649728415266, 0.016379552061802576, 0.0352707388145583, 0.23569804110697337, 4.791030458041599, 27.454552582332067, 52.09550510134016, 51.215755462646484, 43.65208196640015, 37.529242515563965, 32.27036987032209, 31.391012804848806, 22.228636980056763, 5.03968824659075, 0.49460431401218685, 0.10167072367455278, 0.09408284976546254, 2.9358755477837155, 4.971591992037637, 6.013342354978834, 4.48031222820282, 4.549769026892526, 6.889614854540143, 16.801258359636577, 29.306101594652446, 40.25148071561541, 50.931737422943115, 49.4084803717477, 48.75919553211757, 49.598517077309744, 46.04572248458862, 47.93683106558663, 46.12270505087716, 45.9957024029323, 37.46853263037545, 35.276935304914204, 38.16881029946463, 42.057953289576936, 44.62445109231131, 45.71402243205479, 47.10219260624477, 44.98643486840384, 43.180730070386616, 44.18296602794102, 46.62104375021798, 47.82010480335781, 45.16883897781372, 45.15995570591518, 38.32689223970686, 32.48158121109009, 34.433340617588584, 35.418004580906455, 36.13442986352103, 37.681091921670095, 37.58742673056466, 36.99363367898123, 38.47268629074097, 39.845580850328716, 42.227749892643516, 41.825153895786826, 42.24012116023472, 42.74118702752249, 45.282327379499165, 45.35437325068882, 48.089156423296245, 38.305432728358674, 41.023502009255544, 47.14003596987043, 45.708172048841206, 47.299253940582275, 43.53677313668387, 45.20216253825596, 41.60494463784354, 37.98424877439226, 33.89794717516218, 37.286229269845144, 34.531612464359824, 34.47240686416626, 34.01165097100394, 35.63582713263375, 36.596502440316335, 40.92327771868025, 45.03830664498465, 47.15195560455322, 48.54075806481497, 49.9639436858041, 45.29158238002232, 45.23715019226074, 47.613319465092246, 49.58504799434117, 47.40326499938965, 44.13153893607003, 37.06843451091221, 36.42415584836687, 45.71964699881417, 48.25046927588326, 47.46022980553763, 48.38062640598842, 48.43843541826521, 47.69694103513445, 48.69351768493652, 48.154799529484336, 50.0993640763419, 49.957054546901155, 49.350285734449116, 42.31351498195103, 37.314039434705464, 21.946230922426494, 9.291098151888166, 2.8443558301244463, 3.353446649653571, 8.612070679664612, 6.42082554101944, 6.636271808828626, 5.8791999987193515, 3.5134352190153937, 1.081068481717791, 0.381109886935779, 0.062482211871870925, 3.201539486646652, 13.374151468276978, 37.374975136348176, 50.32149798529488, 32.16975648062569, 49.11159079415457, 53.59541967936924, 45.83600500651768, 12.605852672031947, 0.3539378706898008, 0.09584377706050873, 0.0398617135360837, 0.06461102728332792, 0.05658417175124798, 0.024806914584977285, 0.032669496789042435, 0.0507187352382711, 0.029464741969215016, 0.028533649431275468, 0.032195244915783405, 0.0336743291201336, 0.026181370385789444, 0.03950759628787637, 0.052888174541294575, 0.011779656301119497, 0.1320765292538064, 0.029308047877358537, 0.07157513752047505, 0.032899845857173204, 0.027667256903701594, 0.051702807790466716, 0.028845232711838822, 0.01790478004009596, 0.1628475630921977, 0.13734282952334198, 0.16915750450321607, 0.2365690900811127, 0.1950962290699993, 0.09083690787000315, 0.17029722620333942, 0.16306943047259534, 0.11916551419666835, 0.22171850981456892, 0.25467555278113907, 0.07276732354824032, 0.11748012820524828, 0.12974239593105658, 0.07661859331918613, 0.1044189804898841, 0.08729756064713001, 0.10675032503370728, 0.09321680159441062, 0.09946046370480742, 0.09119317946689469, 0.11781596232737813, 0.12399232733462538, 0.10379097597407443, 0.14639900571533612, 0.1504667145865304, 0.1385618991085461, 0.4413311183452606, 4.951939012323107, 31.387545653751918, 57.24270977292742, 58.53728076389858, 49.40226868220738, 43.448068959372385, 36.02158069610596, 35.84595455442156, 26.09512710571289, 5.778793752193451, 0.7886330794010843, 0.3356795518526009, 1.8660826895918166, 6.951835538659777, 11.225578257015773, 10.270715117454529, 8.576303958892822, 9.554324575832911, 7.16824152639934, 18.285723618098668, 32.28072616032192, 42.10338756016323, 52.28512838908604, 49.82965932573591, 49.73017849240984, 49.5257694380624, 48.111272539411274, 49.183737414223806, 48.862852232796804, 47.64168201174055, 39.43275710514614, 38.11831079210554, 41.880670002528596, 44.387899671282085, 47.14139781679426, 47.80979020254952, 48.5706387928554, 44.56239325659615, 44.3631397656032, 44.07047816685268, 48.380883489336284, 48.47090087618147, 48.31923907143729, 48.71789196559361, 39.78566653387887, 34.412683623177664, 35.86640657697405, 37.33311223983765, 37.97818299702236, 39.53236648014614, 39.50786018371582, 39.126567363739014, 40.083035537174766, 41.652168069567, 43.752615451812744, 45.550239494868684, 44.29686784744263, 43.2131017276219, 47.608997685568674, 47.948191370282856, 49.07704782485962, 41.080477237701416, 42.093771253313335, 46.66236121313912, 49.15044512067522, 48.53956297465733, 44.951607022966655, 48.044753960200715, 43.51411158697945, 41.72063214438302, 35.86266844613211, 37.56722136906215, 36.62822791508266, 35.22172839300973, 35.81058127539498, 36.867906025477815, 38.12101364135742, 42.91885246549334, 47.579120431627544, 50.15075990131923, 50.43852996826172, 51.30588749476841, 45.23840781620571, 45.49690164838518, 47.72217689241682, 52.078634875161306, 47.89040667670113, 44.97215979439871, 39.16717611040388, 37.89142778941563, 47.62539890834263, 49.39561925615583, 47.612555163247244, 49.86934396198818, 49.903563840048655, 48.85213463647025, 48.44770431518555, 49.323014054979595, 51.379104137420654, 52.94123635973249, 51.876268591199604, 42.715395314352854, 37.62926183428083, 24.561578035354614, 10.13190140042986, 5.523648517472403, 10.981764231409345, 14.073907153947012, 11.337536317961556, 15.152744395392281, 11.317544613565717, 6.374446315424783, 3.9378450853484015, 0.5672235201512064, 0.48098817893436974, 3.4229520857334137, 16.628130095345632, 39.92936222893851, 68.07521193368095, 45.9015508379255, 54.45738887786865, 61.0255001613072, 50.48107378823416, 15.10177935872759, 0.669303142598697, 0.1792160804782595, 0.085814262740314, 0.12370909324714116, 0.19891750759312085, 0.10258080876831498, 0.10266714556408779, 0.16584504581987858, 0.12115948434386935, 0.1585174375878913, 0.34780225849577356, 0.12042741291224957, 0.1287754156759807, 0.12555575344179357, 0.12788093010229723, 0.11977194808423519, 0.25493537741047995, 0.07091871595808438, 0.16138968989253044, 0.10307146422564983, 0.12236377543636731, 0.1496958988053458, 0.09263250830450229, 0.15169414372316428], [0.03287834308243223, 0.01357222707676036, 0.053492131776043346, 0.03991892760885613, 0.026651618902438452, 0.05833784211426973, 0.03150221299646156, 0.009240488355447139, 0.054103138989635875, 0.09568388028336422, 0.008490020991303027, 0.04518781988216298, 0.05768606173140662, 0.012984326525059129, 0.03318954977606024, 0.03825413515525205, 0.028195382761103765, 0.032193694463265796, 0.028351243951224854, 0.01623667633560087, 0.018884462470720922, 0.031077327938484292, 0.01593950344249606, 0.06204403431287833, 0.05835537545915161, 0.03985200709264193, 0.044738683982619216, 0.03545239281707576, 1.2671655586787631, 16.468609877995082, 39.943046706063406, 44.44750826699393, 38.33112369264875, 32.88036264692034, 29.58123288835798, 28.693958350590297, 17.53111277307783, 7.239818828446524, 0.8604581824370793, 0.15035889537206718, 0.30555335698383196, 2.4348752541201453, 2.677963410105024, 5.7798581293651035, 2.9306776438440596, 1.5011822985751289, 6.833310127258301, 15.381183794566564, 25.295887981142315, 38.38482631955828, 46.65711184910366, 53.74322523389544, 48.27888740812029, 42.96339736665998, 42.335763113839285, 48.77170923777989, 44.71367638451712, 41.63827167238508, 35.39631230490548, 35.17249345779419, 37.27876343045916, 41.96421166828701, 43.06381620679583, 46.87772757666451, 44.9102999823434, 41.91841261727469, 44.799396310533794, 46.44119657788958, 45.495685713631765, 45.19254970550537, 44.12277378354754, 37.86377395902361, 32.67178119931902, 32.583365372249055, 34.343524728502544, 35.863891329084126, 35.3786951473781, 34.21807847704206, 34.42568022864205, 33.752385888780864, 34.53520815713065, 35.04471608570644, 36.18445689337594, 37.05813728060041, 39.325014863695415, 40.11250979559762, 44.46998221533639, 42.216198512486045, 45.74442080089024, 36.03639078140259, 38.06513622828892, 47.291878427777974, 46.47572565078735, 48.04644932065691, 44.4065660067967, 47.14804029464722, 44.65353625161307, 44.853651319231304, 40.100256647382466, 34.20339345932007, 31.582070895603724, 35.87334087916783, 32.425797598702566, 34.076991830553325, 33.79666675840105, 41.49008396693638, 45.16087981632778, 45.89733675548008, 46.70566586085728, 42.642418384552, 42.12202957698277, 45.172761235918315, 45.929315839494976, 46.449409348624094, 45.01787199292864, 42.215034689222065, 34.170900208609446, 33.643448557172505, 43.744281087602886, 47.794094221932546, 47.279778139931814, 44.69595152991158, 47.00246511186872, 44.64394078935896, 48.18879359109061, 45.673253876822336, 45.1976774760655, 45.50556605202811, 46.55971547535488, 42.77433340890067, 29.197661059243337, 17.772712060383387, 10.060671074049813, 1.4307806534426553, 1.6482082435062952, 7.85457980632782, 4.620909895215716, 1.8641838771956307, 3.031659722328186, 1.9749160153525216, 0.39396131304757936, 0.47728587474141804, 0.5596754966037614, 3.56401332787105, 16.70845648220607, 31.68257658822196, 40.15891681398664, 36.83216796602522, 36.00430747440883, 49.698477336338584, 27.629723617008754, 7.021743535995483, 0.10053655239088194, 0.020235778531059623, 0.020649269289736236, 0.027126286378396407, 0.03114328154229692, 0.035346504034740586, 0.01735172650244619, 0.043371924465256076, 0.07072608665164028, 0.02347594778984785, 0.07418484427034855, 0.047025214681135755, 0.01070048367338521, 0.056484708695539405, 0.03580628275605185, 0.013646988913283815, 0.017877687833138874, 0.042397463361599615, 0.031226208699601035, 0.035597277006932666, 0.058797169609793594, 0.04354264387594802, 0.021517327620780895, 0.03821544508848872, 0.03840264272210853, 0.0683666236166443, 0.0432880236102002, 0.013561999857691782, 0.03584442660212517, 0.03145346364804676, 0.047584592165159326, 0.06053753729377474, 0.0539249556937388, 0.05995237547904253, 0.03450116814513292, 0.038305065993751795, 0.06325303443840571, 0.03697476416294064, 0.017577682056331208, 0.017420272110030055, 0.01803944549257202, 0.03832019053931747, 0.03447232362149017, 0.05608348076098731, 0.012688043360997523, 0.013055709257189716, 0.03387560296271529, 0.017387408962739364, 0.04251461582524436, 0.05080885825944798, 0.06240112693714244, 0.050685578624584844, 1.7988092537437166, 20.982930932726177, 46.34804555347988, 51.23024245670864, 43.29726178305489, 35.83916616439819, 32.94576951435634, 33.51080049787249, 22.809138127735682, 7.383319105420794, 0.7058654321091515, 0.18122296993221554, 0.27745432619537624, 0.8805851052914346, 3.064290199960981, 5.041505200522287, 4.219388263566153, 4.358633637428284, 6.319736199719565, 15.294459853853498, 28.78009169442313, 39.99040215356009, 47.67773274012974, 51.617271014622276, 47.803182465689524, 44.62212691988264, 45.53307744434902, 50.5031030518668, 47.73452384131295, 43.280165740421836, 37.66272783279419, 36.862590653555735, 39.30840866906302, 43.74278722490583, 43.599324294498985, 48.247307845524375, 46.20167132786342, 44.408789430345806, 45.16548299789429, 48.418504510607036, 47.318906920296804, 46.31037242071969, 46.63064268657139, 40.287475858415874, 34.03702926635742, 34.642481395176475, 34.98504843030657, 36.1273809160505, 36.486370018550325, 36.026861327035085, 36.86534908839634, 35.87070403780256, 35.62808336530413, 37.171160152980256, 38.160691329411094, 40.16536474227905, 42.20060675484793, 42.49626650129046, 46.206423895699636, 45.182947295052664, 48.53352499008179, 38.80106857844761, 39.42114666530064, 46.91648810250418, 48.924493176596506, 49.10493789400373, 47.168832778930664, 48.28580781391689, 47.236834798540386, 46.5335624558585, 41.178155013493125, 35.59621892656599, 33.87216935838972, 36.847686767578125, 34.26548951012747, 35.75017016274588, 36.02552727290562, 43.28011015483311, 45.94492149353027, 47.36057179314749, 48.55346284593855, 44.96002129146031, 43.26629713603428, 46.42251982007708, 49.02829926354544, 48.4080787386213, 48.07014962605068, 42.74269131251744, 36.467547348567415, 36.67567368916103, 46.34793438230242, 49.45005144391741, 48.474500043051584, 47.17340121950422, 48.9771466255188, 47.08151824133736, 48.58857209341866, 48.671241760253906, 47.45995535169329, 47.142860412597656, 48.49182537623814, 44.076894828251426, 31.671504633767263, 20.14744131905692, 9.66717461177281, 3.011550549949918, 2.951663157769612, 5.722154642854418, 6.591267892292567, 6.4281628387314935, 5.157213985919952, 2.9724875603403365, 1.3554124576704842, 0.20700384011226042, 0.5932066887617111, 3.311572245189122, 18.368464503969463, 34.85703134536743, 53.459318365369526, 42.11073528017317, 41.601880482264924, 55.78098596845354, 33.22416993549892, 8.463492138045174, 0.15846134988324984, 0.038807704379515987, 0.028496954257466962, 0.029358103405684233, 0.045152247683810334, 0.022908242984807918, 0.028705637702452283, 0.024391374650544355, 0.07269131405545132, 0.024382769130170345, 0.03113701187872461, 0.02111546355964882, 0.026564123508121287, 0.03856535881225552, 0.04033183313107916, 0.08019545674324036, 0.037201371110443554, 0.018227333535573313, 0.04550828179344535, 0.06232066625463111, 0.00131331364640833, 0.047623258483197005, 0.03828616879348244, 0.030478435967649733, 0.1703680788299867, 0.1597921470446246, 0.1522739790380001, 0.11310452049864189, 0.16525211477918283, 0.09389585229967322, 0.12588188451315674, 0.1952474338135549, 0.1775984258524009, 0.17890200018882751, 0.07679440174251795, 0.11687901403222765, 0.10671072573001895, 0.16661363600620202, 0.09364672816757645, 0.10694655057575021, 0.12044186570814677, 0.11028900729226214, 0.2114806648875986, 0.09720493187861783, 0.07746273837983608, 0.1251435705593654, 0.09874233616782085, 0.17489693367055484, 0.18237555665629251, 0.15492870658636093, 0.2162358925810882, 0.08647085393645934, 2.382773969854627, 23.284193413598196, 51.09821973528181, 56.7638920375279, 49.19958278111049, 43.341573919568745, 40.12859834943499, 38.2971956389291, 24.76877679143633, 9.84988704749516, 1.1830799792494093, 0.5303171862448964, 1.269412323832512, 6.078649776322501, 9.499438149588448, 13.996149863515582, 9.728143317358834, 4.631238826683589, 10.213272622653417, 18.642343384878977, 29.092036281313213, 42.31251444135393, 50.09316975729806, 54.646484102521626, 48.42650883538382, 45.15296581813267, 47.458596978868755, 52.05263124193464, 50.935166358947754, 45.391434941973, 39.13051046643938, 39.67901168550764, 40.31254495893206, 47.227374826158794, 45.94337551934378, 49.70503643580845, 48.10756914956229, 45.136238030024934, 45.78277138301304, 51.272386755262104, 49.527009691510884, 49.86814192363194, 48.78298963819231, 41.20948791503906, 35.09490639822823, 36.80111646652222, 36.95129483086722, 38.84256322043282, 38.43644796098982, 37.463734899248394, 37.24364723478045, 37.00687347139631, 36.96310676847185, 39.04074668884277, 39.11819478443691, 42.1727340562003, 43.94991649900164, 46.178071771349224, 49.17115075247628, 48.13788761411394, 48.89764533724104, 41.52607216153826, 40.56691156114851, 47.49236522402082, 49.621550355638774, 50.73046548025948, 48.878398827144075, 50.24087108884539, 48.951726640973774, 48.35807255336216, 44.142006397247314, 37.4587391444615, 35.089396476745605, 39.10607712609427, 36.39225319453648, 36.925496169498985, 38.12960508891514, 45.097324643816265, 48.690071378435405, 49.09079136167254, 49.183890274592805, 45.55265746797834, 42.65432759693691, 46.189324378967285, 50.17335196903774, 49.109871115003315, 50.789268084934776, 44.925110067640034, 37.500258105141775, 36.91732856205532, 48.590187549591064, 51.35543162482125, 50.254253319331575, 47.34068604878017, 49.91753666741507, 47.06440830230713, 48.5973025049482, 48.108941418784006, 49.291861806597026, 48.82615532193865, 51.95314693450928, 45.54596635273525, 32.81181866782052, 20.261918101991924, 12.618325557027545, 3.824700619493212, 8.02674400806427, 15.588698693684169, 12.270082712173462, 10.198610186576843, 10.704099450792585, 6.857990562915802, 2.13839344893183, 1.1511197856494357, 0.8604025425655502, 4.851160168647766, 21.54015040397644, 40.67616850989205, 48.082715443202424, 46.27951547077724, 48.75394269398281, 61.77015944889614, 38.50470706394741, 11.324608325958252, 0.4622510586466108, 0.17541704433304922, 0.07585079023348433, 0.13483664686126368, 0.14652605461222784, 0.11209711312715497, 0.061924089677631855, 0.2047715684665101, 0.18629921254302773, 0.1481472919029849, 0.17603805315281662, 0.12030881856169019, 0.12390220431344849, 0.1273420104490859, 0.14112497014658792, 0.19550428645951407, 0.0758652633854321, 0.15777431960616792, 0.08981988565730196, 0.08861089231712477, 0.1385037757988487, 0.06997716719550745, 0.10154810561133282, 0.12937050445803575], [0.07016794410135065, 0.030109401127057414, 0.04763742968706148, 0.0762816531849759, 0.07393512302743536, 0.017939950206450055, 0.012509469059295952, 0.021303366869688034, 0.10315809957683086, 0.06610845907458238, 0.009365085196415228, 0.03550440931160535, 0.00788228601283793, 0.03070329568747963, 0.018913235748186707, 0.04719817665006433, 0.10656658453600747, 0.0162484336511365, 0.023171979368531277, 0.037872096191027334, 0.034286004690719504, 0.03511782755543079, 0.005125601792574993, 0.018605496368503997, 0.042512176491852315, 0.06599139142781496, 0.008473728517336505, 0.0888751002826861, 0.17487703902380808, 8.317915218217031, 33.45246689660208, 45.7974841935294, 40.81996495383126, 39.1730751310076, 29.971474988119944, 26.092915841511317, 31.523511477879115, 12.152992538043431, 1.7925038720880235, 0.011253916342476649, 0.11211905694965806, 0.852418031011309, 2.049660176038742, 2.976443256650652, 2.6316371645246233, 4.439285721097674, 4.026447210993085, 11.762291857174464, 25.033643858773367, 38.75490127290998, 54.71736962454659, 48.510199887411936, 44.03604984283447, 49.93287481580462, 50.266798291887554, 45.28588833127703, 45.71792384556362, 40.16098042896816, 34.463002477373394, 34.408671038491384, 39.84364577702114, 44.65001004082816, 45.32420069830758, 46.18902908052717, 42.87755584716797, 41.95350102015904, 47.47412272862026, 45.58768333707537, 44.51031650815691, 42.42643710545131, 37.903284890311106, 34.01128966467721, 32.45381620952061, 32.74948637826102, 33.89181538990566, 35.89644711358206, 36.26420136860439, 33.83766113008772, 34.18914270401001, 32.62803881508963, 34.33760486330305, 33.1543995993478, 35.52815784726824, 34.354905877794536, 37.98727124077933, 37.60716308866228, 43.56764398302351, 41.74266140801566, 48.417629037584575, 34.23387173243931, 39.41339594977242, 47.04523127419608, 42.29026978356497, 44.308169092450825, 42.13027014051165, 46.60217244284493, 46.83504479272025, 46.585437706538606, 45.284324986594065, 37.0989579473223, 30.53878150667463, 33.69490691593715, 33.39873995099749, 35.031900133405415, 33.914904253823416, 43.231663840157644, 43.2657482283456, 46.64085306440081, 44.20259468896048, 44.195059367588584, 43.879083088466096, 45.86201211384365, 47.25528226579939, 45.41444042750767, 44.879790442330496, 39.03598369870867, 32.39890112195696, 35.88715042386736, 41.00190005983625, 45.28070844922747, 43.889922278267996, 48.152468408857075, 48.176325048719136, 48.87342391695295, 45.90148483003889, 49.646685464041575, 42.31428623199463, 48.52050059182303, 42.35007987703596, 39.61235066822597, 29.85659694671631, 16.069111040660314, 5.636442099298749, 2.1471555616174425, 1.6112859504563468, 3.8665387630462646, 4.776369759014674, 5.257900765963963, 4.6019812652042935, 1.8038305214473178, 1.1408876946994235, 0.1019612927255886, 0.5909539524997983, 5.487734147480555, 18.81769159861973, 28.253795181001934, 27.756062711988175, 36.56578098024641, 44.95175640923636, 38.577729157039094, 22.596795967647008, 4.835034268242972, 0.042242943974477906, 0.010958084404202444, 0.037735347636044025, 0.07955849556518452, 0.020985425715999942, 0.044344254968953986, 0.010081993914874536, 0.0158373194613627, 0.040442861816180606, 0.07473995376910482, 0.040716959429638724, 0.07388020918837615, 0.0457790986900883, 0.041034035451178036, 0.04331007260563118, 0.06670424674770661, 0.01100773026701063, 0.019991278615114943, 0.05229830030085785, 0.04595397073509438, 0.05004609329625964, 0.0498233132862619, 0.05022176940526281, 0.06734221215759005, 0.04835860384628177, 0.03435472671740821, 0.051455383388591666, 0.07199321687221527, 0.039679699910006354, 0.07116864076150314, 0.03364776447415352, 0.04443530758310642, 0.041150363494775126, 0.08722643660647528, 0.05876029123153005, 0.05977057559149606, 0.02720331706638847, 0.02333590664368655, 0.03148370595382793, 0.020184574582214867, 0.06143966995711837, 0.029879326865609204, 0.0045256962600563255, 0.0468050029261836, 0.03461494150438479, 0.0240403311659715, 0.012479798419268003, 0.03950026132432478, 0.02385319460050336, 0.07527023567152874, 0.04193963882114206, 0.05507809203118086, 0.4899074946131025, 11.671978303364344, 38.32383850642613, 51.28589752742222, 46.08139106205532, 43.183988775525776, 33.395342281886506, 28.77665059907096, 29.05141884940011, 13.2555022920881, 1.7399086143289293, 0.10264575135494981, 0.2476338249232088, 1.1477541433913367, 3.7276195202554976, 4.241580375603267, 4.688509353569575, 3.994868951184409, 5.803764709404536, 12.496576615742274, 25.131246941430227, 38.64347301210676, 52.91447537285941, 49.516229561397004, 45.86131034578596, 50.03948450088501, 51.162751129695344, 47.47514063971383, 47.62047610964094, 42.6960688999721, 36.43722193581717, 36.22358914784023, 41.107436248234336, 45.952314376831055, 46.861319405691965, 48.12178863797869, 44.58991854531424, 41.796871253422324, 47.04247631345476, 49.28163405827114, 45.37702785219465, 45.548860277448384, 39.486081055232454, 35.509897981371196, 33.698440074920654, 34.811336517333984, 34.98900890350342, 38.10211801528931, 37.923889773232595, 35.89164243425642, 36.046823501586914, 34.17825835091727, 35.427193573543, 35.51970188958304, 36.770843165261404, 35.876870564052034, 39.36436251231602, 40.73401921136038, 45.99889857428414, 43.65666430337088, 48.983111654009136, 37.918480600629536, 38.95581190926688, 46.886642115456716, 43.44500132969448, 45.19626004355294, 44.444659505571636, 47.6947523525783, 48.06406995228359, 48.57557896205357, 45.9025513785226, 39.04720156533377, 32.11344827924456, 35.328737599509104, 34.143698011125835, 36.45803526469639, 34.787882872990195, 44.77894081388201, 46.6219539642334, 48.010891914367676, 46.3178973197937, 43.85148136956351, 43.77582938330514, 46.66828802653721, 48.1768079485212, 46.90798698152815, 47.70963191986084, 41.87432629721505, 34.643690381731304, 37.03050429480416, 43.78527545928955, 47.57575402941023, 46.085709367479595, 48.62148223604475, 50.27293702534267, 49.45573854446411, 47.537156786237446, 49.65352249145508, 45.849866662706646, 50.39067425046648, 46.0561135155814, 42.00191954204014, 30.4655579158238, 17.709535564695084, 7.038632001195635, 3.258320599794388, 2.963171980210713, 5.375200688838959, 5.649136892386845, 6.657161133629935, 5.062947775636401, 1.7920450738498142, 0.7443675718137196, 0.2967108514692102, 0.45204239072544233, 6.535569829600198, 20.232940639768326, 32.68282536097935, 28.492206982203893, 39.56300456183297, 48.747380120413645, 45.125186920166016, 26.408638511385234, 6.598348540919168, 0.05822547671518155, 0.03284730010532907, 0.03150911709027631, 0.07936283320720706, 0.0343552356186722, 0.05428389732592872, 0.010720938959691142, 0.02446034943152751, 0.048223246288086684, 0.02796926096613918, 0.02031486857283328, 0.017991566365318637, 0.036253013248954497, 0.07791645439075572, 0.020263540791347623, 0.015980156171800833, 0.010694281015145992, 0.03364188836089202, 0.030475280779813017, 0.034683649960373125, 0.02537215800423707, 0.03484801149794033, 0.05160358900736485, 0.05470553559384175, 0.13027971424162388, 0.29656713775226046, 0.14009031280875206, 0.1411362609692982, 0.09015139072601284, 0.1042862997523376, 0.09944187184529645, 0.0815395192642297, 0.18298223481646606, 0.16863389260002545, 0.17096832447818347, 0.16915614743317875, 0.147167867315667, 0.11007104148822171, 0.12978662284357206, 0.15823321283927985, 0.15699363792581217, 0.11554322285311562, 0.08595190356884684, 0.07983901551259415, 0.13440351081745966, 0.12378498060362679, 0.12911751946168287, 0.09837073646485806, 0.2078388724476099, 0.17225538327225617, 0.1333502209080117, 0.16241863396550926, 0.6650052475077766, 12.94835022517613, 42.689343043736045, 58.21475233350481, 52.85935531343733, 51.17472287586757, 38.020754609789165, 36.21529647282192, 38.236284255981445, 15.768274886267525, 2.7928175670760016, 0.23405118233391217, 0.6764686352440289, 3.146927514246532, 6.9196271640913825, 9.677417993545532, 7.966053230421884, 10.068808283124651, 6.717296055385044, 14.223281264305115, 28.39348350252424, 40.6234837940761, 56.371645382472444, 50.202141829899375, 48.56562566757202, 51.07358142307827, 52.69944947106497, 48.920324257441926, 49.68420573643276, 44.15188673564366, 39.37125512531826, 38.304088251931326, 43.73455013547625, 47.389379024505615, 50.17696155820574, 49.887638568878174, 45.339445046016145, 43.12133686883109, 49.15732036318098, 52.07866266795567, 48.75846597126552, 46.99301208768572, 40.610521929604666, 36.84407717841012, 34.60940449578421, 37.01133074079241, 36.33379452569144, 39.13030549458095, 39.10888419832502, 38.138578687395366, 38.71259369168963, 35.129699502672466, 36.58921030589512, 36.361962522779194, 38.81922422136579, 37.898316928318565, 41.45810488292149, 41.39886106763567, 47.800069672720774, 45.44734362193516, 49.15373509270804, 40.416420527866904, 40.277831758771626, 46.31300926208496, 44.694839818137034, 45.545344488961355, 45.93345349175589, 47.74243089130947, 50.70363848549979, 49.58326230730329, 48.63037593024117, 40.71509231839861, 34.109387806483674, 36.42982905251639, 36.95148243222918, 37.85165977478027, 36.03171811785017, 46.577478545052664, 46.99722269603184, 49.24298817770821, 46.73812089647566, 43.834638936179026, 44.09865311213902, 46.9210079056876, 49.22229644230434, 48.36015353884016, 48.703655106680735, 42.4651837348938, 37.01111534663609, 39.386919839041575, 45.667702266148154, 50.19644430705479, 47.7871356010437, 51.74410343170166, 52.64740398951939, 50.74250323431832, 48.59560019629342, 50.61280468532017, 45.26744086401803, 52.43762745176043, 48.060790402548655, 45.991286822727744, 32.97535146985735, 20.167886393410818, 7.528791802270072, 4.141593192304883, 4.602551017488752, 10.920825055667333, 10.13169469152178, 13.761674216815404, 10.017308235168457, 6.300193956920078, 2.5117397010326385, 0.4830386031951223, 1.0991936177015305, 8.285540955407278, 24.7737204347338, 38.39158344268799, 37.11106865746634, 44.60399212156023, 56.452022143772666, 51.55964960370745, 31.34441123689924, 7.756840365273612, 0.30983827848519596, 0.15462967620364257, 0.1618346188749586, 0.16017094600413526, 0.10845344114516463, 0.09997372116361346, 0.13811498880386353, 0.1846130123095853, 0.14344801620713302, 0.12434420202459608, 0.1611405996871846, 0.13591034710407257, 0.11756991195891585, 0.2350507186991828, 0.2110509622309889, 0.11887191209409918, 0.07790147912289415, 0.10743436975670712, 0.09476240937198911, 0.17857300569968565, 0.10141560129289116, 0.1188011137502534, 0.13712807318993978, 0.1452390229595559], [0.038962413756442923, 0.022034298362476484, 0.02400911516243858, 0.017402820189350417, 0.037382614599274736, 0.060107882134616375, 0.044988917519471476, 0.036438836849161556, 0.011044774038184966, 0.058406442004655085, 0.054526548233947585, 0.07737913608018841, 0.041642986703664064, 0.024106371282999004, 0.022321205020749142, 0.0035492621037909494, 0.025424313598445485, 0.03577183014047997, 0.04851854133552738, 0.05179930225546871, 0.04612765534381781, 0.033084359884794266, 0.025839412485116293, 0.034131461554872136, 0.04900995335940804, 0.037289791008723636, 0.02117176669915872, 0.0418306287777211, 0.03664227521845272, 4.8299442785126825, 31.354152611323766, 48.89762796674456, 45.63443776539394, 43.20205756596157, 38.4939477784293, 52.92635331835066, 43.152833053043906, 17.265229531696864, 2.9349605568817685, 0.24684634432196617, 0.014930565974542072, 0.15789931932730333, 1.7466861477919986, 3.204271648611341, 2.716231916631971, 2.0695769701685225, 2.979595350367682, 10.694804498127528, 16.389306613377162, 36.91799211502075, 46.5684563091823, 37.05643149784633, 51.155695234026226, 48.5173739024571, 47.48813724517822, 43.654242856161936, 42.75257165091378, 35.51032182148525, 37.08715990611485, 37.86028248923165, 43.584962368011475, 43.18172366278512, 46.47883496965681, 44.620931829724995, 45.69861132758004, 46.03922591890608, 47.73003877912249, 44.72664867128645, 42.39163705280849, 37.69256339754377, 36.27391495023455, 36.02967187336513, 35.74337829862322, 33.205812794821604, 34.83542244774954, 33.1021317754473, 32.462112358638215, 32.71970639910017, 33.5707426071167, 33.8662633895874, 35.324731963021414, 34.95194721221924, 36.34386246544974, 35.44685002735683, 40.45354127883911, 40.90108169828142, 44.43586656025478, 41.99429736818586, 50.49722834995815, 31.923171860831125, 37.42848321369716, 47.0517452103751, 44.6424434525626, 46.147048064640586, 46.829246520996094, 47.75781767708914, 47.529385226113455, 46.802124227796284, 45.50056682314192, 41.70410237993513, 31.111254010881694, 32.492340496608186, 33.61543689455305, 32.99369124003819, 34.689611026218955, 42.13197592326573, 45.36322178159441, 46.53685242789132, 44.254126003810335, 45.38762385504586, 45.48696919849941, 46.59819112505232, 46.32160765784127, 44.87576396124703, 42.64734813145229, 36.55438593455723, 35.57890748977661, 33.1417920930045, 35.396531173161094, 40.99272843769619, 42.78400182723999, 45.59917218344552, 45.365181173597065, 47.108223642621724, 47.914318902151926, 48.51231561388288, 47.74858004706246, 40.789375509534565, 46.09930004392351, 31.14266334261213, 25.684351342064993, 13.857442106519427, 5.462629871709006, 2.812542200088501, 1.383863593850817, 3.49045535496303, 4.093012690544128, 4.975506433418818, 3.791289338043758, 1.1032811126538684, 0.2706197143665382, 0.20018526885126317, 0.8623208424874714, 5.634435372693198, 19.322361843926565, 31.662958349500382, 40.38227707999093, 39.175180435180664, 44.71449974605015, 39.36736066000802, 17.673394509724208, 2.08333939739636, 0.06436456979385444, 0.0641569991462997, 0.073576055866267, 0.02605536812916398, 0.026838277100718448, 0.042445184729461155, 0.031902022792824676, 0.029657788574695587, 0.03106039170441883, 0.030872654635459185, 0.01843030032302652, 0.05084667640871235, 0.02664823640537049, 0.011941166295270835, 0.013628692216505962, 0.01568516985779362, 0.02679148193315736, 0.02229567344433495, 0.011879821640572377, 0.06764418738228933, 0.05407790427229234, 0.03342216854382839, 0.027539831419874514, 0.013737695474576737, 0.045381416101008654, 0.04891721119305917, 0.01040799352007785, 0.07192212675831147, 0.027265219816139767, 0.04273324998627816, 0.01221648951260639, 0.06902452438537564, 0.042057846406740804, 0.038114621570067744, 0.032343538744109016, 0.013390823284031024, 0.03001102033470358, 0.020549762129251446, 0.011714064017204302, 0.003506341583228537, 0.04132923211104103, 0.01858139310830406, 0.039817981954131804, 0.02850749869165676, 0.0725292731076479, 0.036102103668132, 0.04175604420847126, 0.018755193067980663, 0.03319778719118663, 0.05098788972411837, 0.0074841386272705025, 0.010382592561654747, 0.030463413202336857, 6.75450496162687, 35.81863076346261, 55.12344666889736, 49.75255864007132, 48.325867652893066, 36.600257941654746, 47.30803298950195, 44.517573901585166, 17.908422538212367, 3.3364936964852467, 0.24046051555446216, 0.0775908457913569, 0.7965027828301702, 2.0993875648294176, 4.619527637958527, 4.239766895771027, 3.8932094233376637, 3.5435083253043036, 11.981672542435781, 22.920194659914287, 40.32040337153843, 50.102671418871196, 40.89631175994873, 51.283062662397114, 48.85400022779192, 48.79533658708845, 46.0865535736084, 44.453275271824424, 37.19010441643851, 38.22669574192592, 38.90866838182722, 45.326549189431326, 45.982841287340435, 48.341285705566406, 47.04174675260271, 44.69058404650007, 47.103088923863, 48.97947079794747, 46.67880759920393, 46.68260826383318, 39.6638229233878, 36.586031505039756, 36.0628217288426, 36.25316762924194, 34.38631868362427, 35.832263129098074, 35.11735602787563, 34.51084777287075, 34.478542123522075, 35.29805088043213, 35.39631230490548, 37.09081813267299, 36.46227713993618, 37.728614125932964, 36.86849314825875, 41.459223542894634, 42.9392523765564, 46.83768858228411, 44.06183808190482, 49.39288166591099, 33.74336017881121, 39.43166276386806, 46.81103876658848, 44.82594537734985, 44.91963836124965, 46.92875862121582, 48.71879175731114, 47.664041314806255, 47.05534437724522, 47.966642311641145, 43.47156776700701, 33.011593273707796, 33.719312463487896, 35.34193570273263, 35.55744103022984, 36.40964106151036, 44.05605718067714, 47.67540161950247, 48.312162331172395, 45.288688455309185, 46.571735858917236, 45.262455531529014, 47.655019078935894, 48.63119234357561, 46.73107194900513, 44.56803866795131, 38.83621951511928, 35.9877290725708, 35.10357427597046, 37.2672780581883, 44.204658303942, 46.25463049752371, 49.21379879542759, 48.27732406343733, 49.05074194499424, 48.21683652060372, 50.364326681409565, 47.7369452885219, 44.6077823638916, 47.8923556464059, 36.305459771837505, 28.315625463213237, 14.616041217531476, 6.15805161850793, 4.044892941202436, 3.824427034173693, 5.644516774586268, 6.321518846920558, 7.305232644081116, 5.021392771175929, 2.4277018904685974, 0.6858542401875768, 0.11353555308388812, 1.138600434575762, 6.459994273526328, 22.206368003572734, 38.47259596415928, 42.86681045804705, 44.0384087562561, 50.702290534973145, 44.617311818259104, 20.934463773454937, 2.9672145290034155, 0.04444926504844001, 0.022439332878483192, 0.019164322542824914, 0.02108805244123297, 0.06344957889190742, 0.034834020105855804, 0.01771515834012202, 0.02594168297946453, 0.05288978945463896, 0.0060949980564016315, 0.042411006920571835, 0.09206307493150234, 0.045955181920102665, 0.040838094893842936, 0.02690499066375196, 0.03644578844042761, 0.045640277210623026, 0.004941429576969573, 0.015352879384798663, 0.059150537076805315, 0.04619410427819405, 0.03450366176132645, 0.013024683243462017, 0.061558746067540984, 0.12739930594606058, 0.09361704904586077, 0.08816215675324202, 0.1004944017955235, 0.09011310099491052, 0.16186470511768544, 0.14946269989013672, 0.2761069456381457, 0.10595367063901254, 0.07907286126698766, 0.1576877792498895, 0.1982386875897646, 0.1181610788085631, 0.09969926731927053, 0.09718776494264603, 0.09098693196262632, 0.07935345585324935, 0.13479769895119326, 0.08790215570479631, 0.11751030944287777, 0.17361733876168728, 0.1092037380273853, 0.11195555715156452, 0.10570813595716443, 0.11310346876936299, 0.09438618206019912, 0.07642029824533633, 0.1422734178070511, 0.2659653441182205, 8.99783900805882, 38.81976270675659, 61.88770907265799, 56.198280879429404, 52.67534269605364, 46.544175829206196, 60.83041558946882, 50.301605292728965, 22.325423649379186, 3.855034717491695, 0.5992111808487347, 0.26731649733015467, 3.2703835410731177, 6.353404564516885, 7.972737397466387, 8.250233684267316, 6.49328830412456, 5.643438066755023, 13.798256482396807, 26.058517047337123, 47.25381619589669, 54.874232155936106, 43.39073242459978, 50.4615285055978, 51.48860427311489, 50.68785565240042, 48.7329626083374, 45.24373708452497, 38.78535870143345, 39.587681089128765, 42.58045087541853, 48.67022384916033, 47.37072311128889, 49.00567940303257, 46.89530304500035, 44.18733297075544, 49.96481221062796, 51.97728845051357, 49.05154793603079, 47.58117362431118, 41.013486180986675, 39.086358138493125, 38.87488276617867, 38.59748983383179, 35.682060446058, 37.8042174748012, 37.826955454690115, 36.232166699000764, 36.0694259916033, 35.544180393218994, 39.06002793993269, 38.10117653438023, 38.63077517918178, 40.04243721280779, 39.372881003788535, 43.4808748790196, 45.17049264907837, 48.10735722950527, 46.73878444944109, 50.1113531930106, 36.139300550733296, 40.584049292973106, 46.32423407690865, 45.58120066779, 46.033340794699534, 47.98915100097656, 49.61668314252581, 48.40875966208321, 48.98125301088606, 49.978329930986675, 44.434275422777446, 34.76585360935756, 35.030493123190745, 37.12449952534267, 36.465911047799246, 37.73102167674473, 46.20510026386806, 48.96594612939017, 49.85706649507795, 45.185511180332725, 46.84875358854021, 45.63606711796352, 48.53925725391933, 49.76587833677019, 49.74544368471418, 47.10932493209839, 39.50712020056588, 38.753883361816406, 37.334988253457205, 39.42580195835659, 45.753102575029644, 48.292860235486714, 49.91830791745867, 49.8916893686567, 50.42658601488386, 50.531430857522146, 51.728313650403706, 48.448180266789024, 45.86436407906668, 50.63725887026106, 40.552139690944124, 30.140271050589426, 16.368168456213816, 6.819749414920807, 4.798143242086683, 4.622367279870169, 8.34289572920118, 11.23320129939488, 13.153362904276166, 9.596276930400304, 4.799779108592442, 1.2220080218144824, 0.675519120480333, 1.3175345701830727, 8.188067282949175, 26.038822378431046, 44.022236824035645, 50.72375699451992, 48.836921555655344, 56.14788212094988, 50.82688215800694, 24.562823499952042, 4.072109035083225, 0.1699794139713049, 0.15449154004454613, 0.14663924782403878, 0.07337114507598536, 0.08387818520090409, 0.09213865694722959, 0.15334761142730713, 0.13165023284299032, 0.1885012350976467, 0.10911679733544588, 0.17746592153395924, 0.2507255833063807, 0.14930317630725248, 0.16644643140690668, 0.07927828095853329, 0.12788057726408752, 0.16157339646347932, 0.1804623728884118, 0.1094202653371862, 0.12395457364618778, 0.15153490512498788, 0.14673971171889985, 0.13595694888915333, 0.11743050015398435], [0.02782159478270582, 0.032550949935934374, 0.06014125927218369, 0.02347773403328444, 0.01147514335545046, 0.009320668294094503, 0.04505707636209471, 0.06403784161167485, 0.04598617400707943, 0.038996873157364983, 0.007763942720235458, 0.04430184653028846, 0.05532664619386196, 0.0240303906279483, 0.035482112650892565, 0.06121998745948076, 0.02191682020202279, 0.03451271681115031, 0.07938464132270642, 0.0655687116086483, 0.08404242460216794, 0.02747235111226993, 0.010120620368979871, 0.03968451750863876, 0.018612500546233993, 0.03219443406643612, 0.03989699735705342, 0.011320777486876717, 0.10923283360898495, 3.274793258735112, 26.516194888523646, 45.78047847747803, 49.21213470186506, 32.5407520702907, 50.31797872270857, 64.24471868787492, 57.48405197688511, 24.003582102911814, 3.83393086705889, 0.28433944817100254, 0.1229024101048708, 0.1781912754688944, 2.3754842238766805, 2.795415759086609, 4.05517931495394, 1.9155623316764832, 3.352564445563725, 11.612862161227635, 20.259682519095286, 29.088470118386404, 35.569263390132356, 52.17416565758841, 52.50099502290998, 48.18289804458618, 45.24505376815796, 42.465023926326204, 39.33466591153826, 38.13359335490635, 36.87410381862095, 39.25539738791329, 43.052195344652446, 45.106989588056294, 46.709160804748535, 46.46342733928135, 46.01900666100638, 47.61562279292515, 44.01578194754464, 42.97082846505301, 38.71641520091465, 34.75182172230312, 35.3335075378418, 33.95569017955235, 33.742012228284565, 34.07376439230782, 35.228148528507774, 34.72182287488665, 36.52953570229666, 33.60360411235264, 34.77568531036377, 36.817201546260286, 38.77063546861921, 39.84124864850725, 42.30449274608067, 40.386640548706055, 43.74537542888096, 41.81455441883632, 44.5695846421378, 43.715664931706016, 51.069120679582866, 34.327269417899, 36.8699175289699, 49.068459851401194, 45.49688080378941, 49.916588238307405, 46.19784981863839, 48.16396767752511, 45.539282185690745, 47.33293880735125, 46.08282586506435, 41.18950489589146, 31.008427619934082, 34.30530963625227, 31.773796013423375, 34.325921467372346, 33.47578852517264, 43.50382130486624, 43.88470418112618, 48.165440695626394, 43.94680718013218, 43.83773783275059, 43.59445708138602, 46.52026012965611, 45.44427251815796, 43.38141141619001, 42.10714306150164, 39.66206155504499, 32.69980328423636, 34.51550306592669, 32.74771458762032, 34.79058224814278, 38.62418828691755, 39.18914631434849, 43.181713240487234, 43.44501175199236, 45.254284449986045, 45.40392085484096, 50.12491260256086, 43.165680272238596, 39.991100447518484, 31.38473163332258, 21.666701419012888, 11.018069437571935, 4.586989658219474, 3.156605269227709, 3.6850031784602573, 4.513293589864459, 5.147697125162397, 5.444211500031607, 3.327227622270584, 1.2491733069930757, 0.4076083893222468, 0.23327957945210592, 1.4331785419157572, 9.77890338216509, 19.3849355833871, 21.116060154778616, 19.97827352796282, 35.4035974911281, 44.50691189084734, 34.20099285670689, 12.631605301584516, 1.1907057357685906, 0.0063167759549937075, 0.01881298389551895, 0.06043602166963475, 0.028321719196225916, 0.046582969304706366, 0.06943319924175739, 0.0919649994799069, 0.03644818366904344, 0.06860563757696322, 0.04887084689523492, 0.05184545281476208, 0.05860443173774651, 0.035019752103835344, 0.05213751464283892, 0.0540254128032497, 0.06297074351459742, 0.049047171005180905, 0.03862354319010462, 0.008941781973200185, 0.019765781072367514, 0.009233621581058418, 0.04965398147968309, 0.04244218221200364, 0.039818416216543744, 0.058173575571605136, 0.010598261524657053, 0.04559117502399853, 0.03048714157193899, 0.03818300093657204, 0.011629471904598176, 0.027258811052888632, 0.05173192372811692, 0.0170908671072019, 0.036758097753460915, 0.034802797316972695, 0.054861527401953936, 0.01816971573446478, 0.009395451334837292, 0.026728306930246096, 0.02755792116347168, 0.008170793165585824, 0.026819856571299688, 0.05370808233107839, 0.03027425120983805, 0.07158577016421727, 0.013389235512087387, 0.05078658534746085, 0.021524620175893818, 0.0333458503176059, 0.044699658041021655, 0.0812166655170066, 0.051645115350506136, 0.09440153730767113, 4.293107347829001, 31.243415696280344, 51.361448764801025, 54.36955322538103, 38.77096550805228, 50.706963198525564, 64.45550618852887, 56.44789143971035, 29.317830153873988, 5.441802646432604, 0.40897696731345995, 0.08490111066826753, 0.3577023558318615, 1.7173115525926863, 3.4493391726698195, 4.165853261947632, 2.59240785241127, 2.8175066879817416, 10.871764693941389, 19.78455775124686, 35.95034776415144, 41.99013539722988, 50.77063649041312, 53.03006560461861, 49.235400744846885, 47.28133453641619, 44.13721214021955, 41.755849088941304, 40.38239172526768, 37.56594984872, 40.573237895965576, 45.3649206161499, 46.843747411455425, 48.648138999938965, 45.67621728352138, 46.24012265886579, 48.78067588806152, 47.179421833583284, 44.824368136269705, 41.86761086327689, 36.74631255013602, 37.40314660753523, 34.75242621558053, 34.582226616995676, 35.52725110735212, 36.52817732947213, 36.58198765345982, 37.691382203783306, 35.192212445395334, 35.57632623400007, 38.64892387390137, 39.821939604622976, 39.66417728151594, 43.748328413282124, 42.3458970614842, 44.947302613939556, 43.97698668071202, 46.949221066066194, 45.63120337894985, 51.3726145199367, 36.402171748025076, 38.166225569588796, 48.4239935874939, 47.18813140051705, 51.406066622052876, 47.928698199135916, 48.8168169430324, 48.06435830252511, 49.02869531086513, 48.23841067722866, 43.09226908002581, 32.736844130924766, 35.229916845049175, 34.66194677352905, 35.67101281029837, 35.74537590571812, 45.20370503834316, 45.61611189161028, 49.256610121045796, 44.640310355595176, 43.997615882328574, 45.00052234104702, 47.448428290230886, 46.63292864390782, 44.9395866394043, 43.035790647779194, 39.77806173052107, 33.42988177708217, 35.758671283721924, 34.939836502075195, 37.583987372262136, 40.57134451184954, 41.726600646972656, 44.68412569590977, 46.47374194008963, 47.42061117717198, 48.13179404394967, 50.89982434681484, 45.42259413855416, 42.52151625497, 34.385974747794016, 24.923243931361608, 12.012839555740356, 4.900323450565338, 3.462259347949709, 4.052843851702554, 6.568546848637717, 6.490908980369568, 6.198619978768485, 5.612117758819035, 1.68107485132558, 0.4046083145907947, 0.3450808988085815, 1.6905861752373832, 9.465720278876168, 22.737820080348424, 27.746034724371775, 26.823739528656006, 39.344362122671946, 49.54214634214129, 38.777903284345356, 15.672799689429146, 1.7011357120105197, 0.017037502024322748, 0.03408481227234006, 0.03021144261583686, 0.027644980599039366, 0.0454573475622705, 0.013571419620088168, 0.031236837950668166, 0.02740804634855262, 0.03573096197630678, 0.03233673982322216, 0.01713807278844927, 0.05980397308511393, 0.01642824543107833, 0.11512067195560251, 0.017970753999959146, 0.08700876935784306, 0.06481415352651052, 0.007701881362923554, 0.08179183251091413, 0.014229531582844044, 0.03137017008183258, 0.028326007537543774, 0.025627270207873414, 0.028984213647033488, 0.19501460130725587, 0.10305674001574516, 0.13972669946295874, 0.11706904454955033, 0.12716100444751127, 0.08558210876903363, 0.12606470898858138, 0.1184002895440374, 0.1537624948791095, 0.09781226143240929, 0.18218657108289854, 0.11530310288071632, 0.08677633040185485, 0.13344273237245424, 0.08663103569831167, 0.0941616819639291, 0.10911921970546246, 0.08814903388598136, 0.20449666678905487, 0.19384435910199369, 0.09332649356552533, 0.1113891296886972, 0.0857367536851338, 0.10406025259622506, 0.13935783425612108, 0.1283565288675683, 0.15074561962059566, 0.11064445786178112, 0.20437189776982578, 4.977589590208871, 35.70213031768799, 57.544372762952534, 60.14018154144287, 43.16363402775356, 59.25794097355434, 70.5229719706944, 62.04940755026681, 28.887128693716868, 5.690512980733599, 0.5956915382828031, 0.32968151941895485, 1.1837447264364787, 6.693190148898533, 9.467423456055776, 8.192120688302175, 5.0115037475313455, 6.4699883886746, 16.75567470278059, 29.954778466905864, 39.8887882232666, 45.467437812260215, 52.00365686416626, 54.192606925964355, 50.71478339603969, 48.96337529591152, 47.11143718447004, 43.083785329546245, 41.59005812236241, 39.659191949026926, 43.27537495749337, 46.718558243342805, 48.7471056665693, 49.01369762420654, 45.989803382328574, 47.46695218767439, 51.599494048527305, 47.6843752179827, 45.51195839473179, 43.016940185001914, 38.47593109948294, 38.19459853853498, 36.5973744392395, 36.97569343021938, 38.031611170087544, 38.18912335804531, 39.13790682383946, 40.57470049176897, 37.081934860774446, 37.61668906893049, 40.89920221056257, 42.013345854622976, 43.033595017024446, 47.628351892743794, 43.28589105606079, 46.97718409129551, 45.918803215026855, 47.49730886731829, 46.83242184775216, 51.92332526615688, 38.894104957580566, 39.188600880759104, 47.34010240009853, 47.956258228846956, 51.19517489842006, 51.12285804748535, 51.323931966509136, 49.28116852896554, 51.269788128989084, 50.32149451119559, 44.880193437848774, 33.50399126325335, 37.619006293160574, 35.31932973861694, 35.84828567504883, 37.08048268726894, 47.42984880719866, 46.465025424957275, 50.596677916390554, 46.06381906781878, 43.817084312438965, 45.01212583269392, 48.814378125326975, 49.22093112128121, 45.68189743586949, 43.70106676646641, 42.56319849831717, 36.12539720535278, 37.92421633856637, 36.524109159197124, 38.89716216496059, 41.68790265492031, 42.781055791037424, 46.16724647794451, 47.76827819006783, 48.36586148398263, 49.59665148598807, 54.72110775538853, 46.497310229710166, 44.966663769313264, 38.15049484797886, 30.875675337655203, 14.760384832109724, 7.229923290865762, 6.526484625680106, 8.98481547832489, 12.411231892449514, 12.063555325780596, 13.837490354265485, 9.597659621919904, 4.564990358693259, 1.1278416918856757, 0.5622926333120891, 2.086915982621057, 11.953732967376709, 26.66186387198312, 28.652910130364553, 29.67987298965454, 46.43865353720528, 56.28428568158831, 45.06076669692993, 19.19748534475054, 2.0901219248771667, 0.09601704776287079, 0.10875857834305082, 0.081502925870674, 0.10106101924819605, 0.13733521636043275, 0.088164375562753, 0.1858253643981048, 0.07459225705159561, 0.15665689456675733, 0.08668346609920263, 0.19966804874794825, 0.21907375673098223, 0.104490219881492, 0.15277025955063955, 0.21135367027350835, 0.1344932402883257, 0.1277188823691436, 0.12070057754005704, 0.30000655033758705, 0.1805144708071436, 0.1794593624238457, 0.1189823504537344, 0.19370300668690885, 0.22197909440313066], [0.040616929797189574, 0.06506673818720238, 0.014692880246522171, 0.022839315701276064, 0.040470712286021025, 0.029663230425545146, 0.06428775962974344, 0.044214159449828525, 0.034053335032824955, 0.037252413907221386, 0.01958906341211072, 0.0466152845349695, 0.0301761282607913, 0.0709689071934138, 0.009850332729651459, 0.011481163657403417, 0.02678268133396549, 0.023280297306233218, 0.0094407681442265, 0.02964711861152734, 0.10090419623468604, 0.007245625934696623, 0.028599206092102186, 0.05846019554883242, 0.02990571509248444, 0.08053507709077426, 0.01761783945507237, 0.045110378680484634, 0.03532146948522755, 1.400189146399498, 16.565731797899517, 41.43390430722918, 48.336696420397075, 50.34125171388899, 64.3560357775007, 68.10805606842041, 38.42625147955758, 17.71616414615086, 7.0633775762149265, 0.9032023602298328, 0.026009007224014828, 0.34566918866974966, 0.33888020153556553, 1.5179990019117082, 2.484476923942566, 3.1265549617154256, 3.2970982789993286, 12.416000962257385, 17.06420772416251, 28.087932995387487, 45.23336689812796, 48.666145256587434, 49.91893672943115, 46.941084725516184, 45.80628061294556, 43.12182671683175, 40.28681230545044, 41.013906547001426, 39.28259263719831, 41.42517736979893, 46.541754381997244, 47.145233222416465, 47.32658815383911, 45.589576721191406, 46.49072681154524, 45.63883250100272, 43.21957050051008, 40.83890574319022, 34.367749622889924, 33.51326016017369, 31.71829727717808, 33.05871248245239, 32.93535763876778, 36.74513135637556, 36.64138085501534, 33.77557897567749, 39.14421231406075, 35.46238967350551, 36.002636432647705, 39.243807792663574, 44.105243478502544, 43.532388823372976, 43.29189082554409, 41.976034028189524, 43.27927984510149, 45.98945944649832, 44.71113681793213, 45.9835638999939, 33.10555376325335, 25.81817885807582, 40.76532779421125, 47.84388848713466, 46.48425456455776, 45.927418981279644, 43.75965745108468, 45.143227917807444, 45.13569607053484, 46.7156434740339, 43.47448601041521, 35.24989291599819, 31.820658138820104, 33.16168131147112, 36.009831292288645, 34.31287275041853, 33.54547895703997, 39.88455677032471, 44.308589458465576, 46.85262720925467, 46.34993198939732, 44.720985889434814, 41.70122929981777, 45.040985175541465, 47.05725165775844, 44.18187863486153, 44.72021116529192, 40.404358455113, 34.2644681249346, 35.14741740907942, 35.44601624352591, 33.781422410692485, 33.95348065240042, 37.81691183362688, 37.9294969694955, 40.7241701398577, 41.630659920828684, 46.67262717655727, 45.718830585479736, 47.36624499729702, 41.09022208622524, 33.57358094624111, 19.43069989340646, 8.837797675813947, 3.470849926982607, 2.651054774011884, 2.9377667605876923, 3.403956796441759, 4.7781237448964795, 4.038605690002441, 3.598453159843172, 1.1012388850961412, 0.6391736364790371, 0.3474140278995037, 2.9746495357581546, 8.635638100760323, 20.74181628227234, 33.412268093654085, 33.12439380373274, 36.84044327054705, 41.39773893356323, 22.11190550667899, 8.261118037360054, 0.5747807174921036, 0.06588895978139979, 0.01012079678808472, 0.030732343771627972, 0.005007464604984436, 0.08729595251913581, 0.017425629144002284, 0.0280989001704646, 0.010972781472706368, 0.1035032771261675, 0.07029235349701983, 0.09393419631357704, 0.03063185273536614, 0.052332087952111445, 0.01577132344911141, 0.0633607722286667, 0.058628485804157596, 0.031016880646348, 0.00592520781460085, 0.030116705556533167, 0.022434388054534793, 0.02128127376948084, 0.10997392955635275, 0.04285715048068336, 0.09336425403931312, 0.03648271770881755, 0.03746684454381466, 0.05045353661158255, 0.03577657988561051, 0.04137099254876375, 0.021719427579747777, 0.04532996279054454, 0.026388323566477214, 0.02858023764565587, 0.01713861052745155, 0.03209436372188585, 0.021004847084571208, 0.01764050591737032, 0.029454747148390328, 0.04422744516549366, 0.05550492787733674, 0.05173983544643436, 0.03170057592381324, 0.07936747438673462, 0.04884451634383627, 0.05969909871263163, 0.026721792994067073, 0.016936910904145668, 0.02124279913758593, 0.08948519825935364, 0.08030032433037247, 0.03746670883681093, 0.056495239559028826, 0.053076705496226034, 2.2536191173962186, 21.355425596237183, 48.66244881493704, 52.89081675665719, 47.972801889692036, 64.79473808833531, 73.09899575369698, 50.65869058881487, 21.64055708476475, 6.904851385525294, 0.8485809969050544, 0.12290661702198641, 0.3186785312635558, 2.2202988139220645, 2.9450469527925764, 5.416992800576346, 1.9925587943622043, 2.7095023691654205, 14.052722096443176, 20.70240088871547, 31.76824787684849, 45.8012501171657, 50.76752717154366, 51.591270855494905, 49.36286892209734, 46.9545190674918, 44.76004866191319, 42.10929352896554, 41.69054297038487, 41.33571931294033, 42.83976806913103, 48.51839876174927, 49.0085802759443, 48.31591435841152, 46.3837697165353, 47.268296241760254, 48.208651542663574, 45.1890686580113, 42.988859040396555, 37.10429416384016, 35.02086986814226, 33.9052323613848, 34.60915783473423, 35.987885407039094, 36.72509969983782, 37.00980908530099, 37.14786284310477, 40.334296294621055, 36.022814001355854, 37.75218588965279, 41.580751010349815, 44.176650115421836, 45.40382705415998, 44.7722601209368, 44.434084347316194, 46.00128528050014, 46.537776538303916, 46.33706739970616, 47.06802831377302, 36.77858345849173, 30.674910613468715, 40.40263877596174, 47.71855340685163, 48.577350752694265, 46.94309622900826, 44.7289137840271, 47.18428904669625, 45.28508234024048, 48.36493042537144, 45.85311494554792, 37.42451579230172, 33.288510254451204, 35.13569927215576, 37.962341104234966, 35.8275522504534, 34.742785590035574, 41.417103563036235, 45.9359895842416, 49.299612522125244, 47.150336674281526, 45.67649521146502, 42.92962564740862, 45.89507164273943, 48.50798341206142, 44.953854765210835, 45.13928828920637, 42.60103491374424, 36.45194516863142, 37.0924196924482, 36.61901807785034, 35.192983695438926, 35.1591876574925, 38.97760493414742, 40.33961861474173, 43.58567108426775, 44.70236471721104, 48.94650159563337, 46.81336293901716, 49.1748263495309, 43.14735092435564, 36.28032118933541, 23.24809925896781, 11.782776883670262, 4.157749491078513, 1.5529397555759974, 4.377020742212023, 7.8999228818075995, 10.435440404074532, 4.150395691394806, 4.08419976915632, 1.0127923339605331, 0.38066411656992777, 0.31512523336069925, 2.9217739616121565, 10.374502096857343, 25.77971884182521, 31.241428511483328, 32.75611843381609, 41.35622692108154, 46.755553926740376, 28.096748522349767, 10.211097836494446, 0.658485394503389, 0.05678959144279361, 0.022132414526173046, 0.053636788656669, 0.05306569965822356, 0.092897822282144, 0.006278242375369051, 0.031889296868549924, 0.00997956226845937, 0.059914764282958846, 0.07368483860045671, 0.04343285012458052, 0.02782392724683242, 0.07255683520010539, 0.06371595138417822, 0.01417731067964009, 0.09848029272896902, 0.020494201985586966, 0.014340159084115709, 0.06851495137172085, 0.04550370507474456, 0.04337953423549022, 0.06449629379702465, 0.03426388105643647, 0.06102249984230314, 0.11828875195767198, 0.21003330898072037, 0.16074586872543606, 0.11680464659418378, 0.167735987209848, 0.09606392096195902, 0.12211459023611886, 0.12471753199185644, 0.10452307454709496, 0.15380509330758027, 0.15236834968839372, 0.11204858430262123, 0.11936068800943238, 0.14957482101661818, 0.09001588049743857, 0.10506185170795236, 0.17245959517146858, 0.1279357150197029, 0.1432489747447627, 0.12748803118509905, 0.23442451230117253, 0.0536036557917084, 0.13620293140411377, 0.1237450691738299, 0.1673671491444111, 0.21970184945634433, 0.16047634104532854, 0.14215004656996044, 0.13860813448471682, 2.8537791073322296, 24.346864802496775, 55.196347168513704, 58.5969032560076, 59.778062275477815, 70.89524255480084, 73.66376617976597, 43.26045717511858, 24.235337529863628, 10.120053853307452, 1.6716725272791726, 0.37801495300871985, 0.7386581067528043, 3.379263550043106, 7.160669726984842, 8.151619638715472, 7.405548998287745, 4.572853113923754, 15.67842251913888, 21.066670622144425, 32.71080923080444, 45.57445049285889, 50.58461931773594, 52.84911714281355, 51.32205247879028, 49.95559542519705, 45.88532332011631, 43.81910971232823, 45.06850699016026, 43.200167655944824, 45.89567961011614, 50.19873373849051, 51.14630126953125, 49.284871918814524, 46.168031624385286, 46.9213171005249, 49.298035281045095, 48.70584031513759, 45.47504261561802, 37.821091175079346, 36.85878651482718, 35.3443397794451, 36.986595153808594, 38.02865123748779, 39.826035567692344, 38.043214661734446, 37.587055001940044, 41.68394218172346, 38.88852208001273, 40.10252523422241, 42.96026720319475, 47.60234131131853, 46.98731803894043, 45.801878929138184, 45.33629751205444, 47.30217218399048, 48.81596578870501, 46.689427920750205, 48.2280717577253, 37.99855164119175, 33.38986015319824, 42.941771098545615, 46.743630817958284, 50.29944787706648, 48.45030641555786, 47.77221087047032, 49.256290503910606, 47.33131987707955, 51.638872964041575, 47.17312329156058, 38.42686986923218, 35.55779538835798, 36.82680743081229, 39.476419585091726, 38.080050536564414, 36.80855451311384, 42.59596272877285, 47.43076596941267, 50.668452807835166, 49.25120789664132, 47.036980288369314, 45.399335043770925, 46.477150031498496, 50.72597694396973, 47.33794845853533, 47.25132526670183, 44.53424957820347, 38.402589389256065, 37.84350953783308, 38.25439126150948, 36.91408722741263, 37.126156670706614, 40.678068842206685, 40.51551921027047, 45.10822984150478, 46.176487582070486, 51.286766052246094, 48.515164375305176, 51.34785114015852, 45.67335115160261, 38.30384853907994, 24.497253349849156, 12.49839356967381, 5.228245854377747, 5.196785279682704, 7.4814528567450385, 10.076922910554067, 13.299939496176583, 10.564140149525233, 9.305158700261797, 3.3562480764729634, 1.6472452666078294, 1.2990039416721888, 4.218424201011658, 12.346081239836556, 28.335205486842565, 44.252281257084434, 43.31736986977713, 48.29124130521502, 54.059795583997456, 31.1014883177621, 12.414587872368948, 0.9068686749253954, 0.1679904514125415, 0.1792096479662827, 0.10375072527676821, 0.18328716845384666, 0.12430986815265246, 0.1754363282982792, 0.11259466250027929, 0.0872738187068275, 0.11744610645941325, 0.11216251711760249, 0.17786646075546741, 0.06534044564302478, 0.13845645476664814, 0.1301237733236381, 0.15186893434396811, 0.2033653182110616, 0.20074409672192164, 0.048507806911532364, 0.09270329986299787, 0.1377129160932132, 0.1767776156110423, 0.2597960765872683, 0.07451159280857869, 0.17687704813267502], [0.026278443301894834, 0.028139322197863033, 0.0709010808329497, 0.04339228390849062, 0.01750034942025585, 0.004225778268716697, 0.029347884668303386, 0.013848582515493035, 0.05926859538469996, 0.009941711040612842, 0.024038963917908922, 0.017179563508502076, 0.011253553326241672, 0.008834656560793519, 0.024508959680263485, 0.05677058228424617, 0.040720535309187005, 0.024790855357423425, 0.02241126697377435, 0.051965326203831604, 0.045829619014901776, 0.018042726209387183, 0.041250654363206456, 0.03792841459757515, 0.017905696062371135, 0.0194229766992586, 0.06809575922255005, 0.015372161653691103, 0.08407348114997149, 0.5655581780842373, 11.29506458554949, 35.15874644688198, 47.62068802969796, 49.57578257152012, 43.99987404687064, 28.249798229762487, 22.234735761369976, 31.256172588893346, 11.287922705922808, 2.07082308615957, 0.08921206755829708, 0.5191240182944706, 1.8787928989955356, 2.1832927082266127, 3.9870118413652693, 1.7650039877210344, 0.815688604755061, 2.7530758253165653, 11.533478123801094, 26.983127730233328, 35.16783816473824, 47.60407836096627, 52.0894775390625, 48.127388886043, 45.79826586587088, 44.201132093157085, 42.52301706586565, 40.62203509466988, 39.607483455113, 42.359783036368235, 45.6582145009722, 46.40381179537092, 46.93663787841797, 44.476430143628804, 46.17101240158081, 45.69726685115269, 42.77329812731062, 40.42275381088257, 33.059716497148784, 33.79385273797171, 32.50963108880179, 34.78466585704258, 34.325202328818186, 37.931313923427034, 35.48639917373657, 34.46738679068429, 36.53992673328945, 37.99870450156075, 37.4840201650347, 41.99168831961495, 46.54449544634138, 44.09593289239066, 46.20539903640747, 47.01386710575649, 44.56632246289934, 44.24556929724557, 41.87360715866089, 41.81340101787022, 33.827669620513916, 29.02571051461356, 42.36277423586164, 49.68145424979073, 42.76676682063511, 44.47648572921753, 41.709570612226216, 40.29039410182408, 39.74509947640555, 37.56485898154122, 34.063932691301616, 32.250890595572336, 32.86870356968471, 35.91039214815412, 35.921471050807405, 36.70074278967721, 33.92811277934483, 35.090219838278635, 42.005431856427876, 43.77357121876308, 46.05675274985177, 45.32535409927368, 45.567203521728516, 43.97797679901123, 45.747068064553396, 48.220209871019634, 45.42477239881243, 43.923586300441194, 37.24911546707153, 35.87958383560181, 35.862831728799, 35.68178251811436, 35.20895760399954, 35.58714805330549, 37.55730281557356, 38.648124831063406, 42.49870184489659, 45.80158363069807, 46.66708946228027, 48.29177284240723, 42.72454956599644, 28.269833360399517, 17.06559910093035, 5.804991066455841, 2.3316200290407454, 1.831557525055749, 1.93081254192761, 5.767343555177961, 7.048136702605656, 2.0098721853324344, 3.547541971717562, 0.3490426205098629, 0.17114459430532797, 0.7299089676567486, 4.071543625422886, 9.69168438230242, 18.4003324168069, 34.09099245071411, 36.17053270339966, 41.835736002240864, 40.8473721231733, 14.902320895876203, 4.0270799313272745, 0.16306512856057712, 0.0483884084969759, 0.04508294211700559, 0.07956707224782024, 0.03486373315432242, 0.03516298745359693, 0.08729203737207822, 0.027749166258477738, 0.05689397048471229, 0.02598915498570672, 0.04918639960565737, 0.04772090985040579, 0.046436938390667946, 0.03902219947693603, 0.054220081107424836, 0.00894136043331985, 0.05210758446316634, 0.0807241237323199, 0.030205535968499522, 0.055722673157496114, 0.06438915990293026, 0.04644797815542136, 0.06599200210933175, 0.011248529622597354, 0.05942943532552038, 0.023075739354161278, 0.024356938998347948, 0.027630498965403864, 0.05180121911689639, 0.027048288778002774, 0.010002471307026488, 0.03180829675069877, 0.05372392612376383, 0.029025621246546507, 0.04613395893414106, 0.11251929083040782, 0.004509494116064161, 0.053642203366117816, 0.029109674771981578, 0.06244177797010966, 0.0379241737537086, 0.04326397293646421, 0.022682823473587632, 0.026075839530676603, 0.06285909057727881, 0.02439103029402239, 0.01002457204075264, 0.035301154146769216, 0.03784243742536221, 0.06514298516724791, 0.01986878438453589, 0.017178966397685663, 0.015870418399572372, 0.0749600026756525, 0.8518071323633194, 14.277449420520238, 40.716440268925254, 53.08455337796892, 55.233763217926025, 53.81303725923811, 40.68394354411534, 27.798691647393362, 30.06303834915161, 12.121990544455391, 1.996095427445003, 0.11896552278527192, 0.3237166537770203, 1.2720995396375656, 3.2268550310816084, 3.72300808770316, 2.0979310486997877, 1.0647327240024294, 4.712074603353228, 12.270513500486102, 30.08171510696411, 39.08521515982491, 49.30609866550991, 53.06096771785191, 50.003371238708496, 47.515964780535015, 44.16949347087315, 43.111817836761475, 43.7482693535941, 40.310759271894185, 44.87852239608765, 47.21540655408587, 47.930859088897705, 47.11939287185669, 44.6186180795942, 46.143379415784565, 48.09010485240391, 44.41539716720581, 42.15702417918614, 35.481907163347515, 35.92606381007603, 34.45242037091936, 35.65767921720232, 36.66161400931222, 40.9983286857605, 38.34060798372541, 37.39542715890067, 37.70578581946236, 39.71304396220616, 39.00732585362026, 43.135459082467214, 47.74749960218157, 46.74973133632115, 47.83511986051287, 48.68133749280657, 44.38836867468697, 46.29605565752302, 44.82556322642735, 42.93081726346697, 36.05512312480381, 31.122246061052593, 42.33293867111206, 52.073805877140586, 45.3065071105957, 47.224116121019634, 44.21534810747419, 42.92908716201782, 42.7265054838998, 41.08044249670846, 36.668680327279226, 33.648319244384766, 33.13788720539638, 37.60976866313389, 38.052619048527305, 37.4874838420323, 35.06747143609183, 37.388600553785054, 44.19572639465332, 45.19966466086251, 47.88926369803292, 46.62545933042254, 45.45763042994908, 45.59460721697126, 48.16002457482474, 49.50057874407087, 47.90440034866333, 44.178897857666016, 38.10810041427612, 36.765329769679475, 37.07522637503487, 36.99405404499599, 35.963472911289756, 37.90116221564156, 39.42884179524013, 40.1401184626988, 44.484629017966135, 46.59392145701817, 48.951622417994905, 48.09753247669765, 43.80649178368704, 30.65711280277797, 18.92972261565072, 6.1795888628278455, 3.002736108643668, 3.2154517344066074, 5.339156908648355, 7.711780428886414, 8.248246499470302, 4.635591873100825, 2.8320625126361847, 0.9896997788122722, 0.2268034919564213, 0.6542335312281335, 4.678517843995776, 12.598590067454747, 20.6855845110757, 38.29485409600394, 40.4463221005031, 46.64786032267979, 46.31579896381923, 19.108869756971085, 5.266215588365283, 0.3265613168478012, 0.06558471824973822, 0.014177010427894337, 0.1202070518795933, 0.03756584958838565, 0.0824605016303914, 0.0064072810762029675, 0.012166599377191492, 0.03460039710626006, 0.006052063329012266, 0.07993351508464132, 0.03313107702082821, 0.05124827414484961, 0.0856347902278815, 0.017383558276508535, 0.02456089305425329, 0.04032550918470536, 0.03024306913305606, 0.012699729430356195, 0.020770435288016285, 0.028060186354975616, 0.07813045755028725, 0.05382292777565973, 0.058436358613627296, 0.06283587110894066, 0.09748013889683144, 0.09479938953050546, 0.15459766292146274, 0.10700824297964573, 0.1257516872137785, 0.11653620457010609, 0.09345114044845104, 0.09963816524084125, 0.15753259829112462, 0.09688239025750331, 0.20213958541197435, 0.0672340468902673, 0.15320024719195707, 0.1314485315233469, 0.10201596907739129, 0.1713845378586224, 0.12524293522749627, 0.109830324405006, 0.08963303746921675, 0.1403826799775873, 0.12211239178265844, 0.11971055423574788, 0.1351856445627553, 0.10501627451074974, 0.30006845987268854, 0.07813943456858397, 0.18128903210163116, 0.11152170864599091, 0.13553734283362115, 0.9972953540938241, 17.281846148627146, 47.55444737843105, 58.90852996281215, 61.08979879106794, 53.96218729019165, 38.089972564152305, 32.51444271632603, 38.88025024959019, 15.363636119025093, 3.0502283488001143, 0.2823428453079292, 1.0971268543175288, 3.5437721397195543, 4.945252673966544, 9.901628545352391, 4.86337206193379, 1.9419157632759638, 3.541917622089386, 13.770990014076233, 30.750048433031353, 39.88566153390067, 50.270803928375244, 54.90005166190011, 51.02063614981515, 50.13631459644863, 46.7184088570731, 46.660565103803364, 44.831132207598, 42.047534465789795, 46.27143471581595, 49.883865697043284, 50.13066223689488, 47.91783121653965, 44.35994012015206, 46.92499269757952, 51.36072615214756, 46.82425076620919, 43.63103239876883, 37.34240892955235, 38.03597116470337, 36.77541160583496, 37.3425235748291, 37.71205309459141, 43.250549043927876, 40.276612349918906, 39.06166076660156, 39.6498327255249, 42.445843424115864, 41.27707999093192, 45.19894552230835, 49.426844460623606, 47.53193868909563, 49.87896374293736, 50.20463623319353, 46.93180888039725, 46.80954490389143, 46.833533559526714, 44.927072933741975, 37.873390265873496, 35.02518122536795, 44.79246548243931, 52.198696272713796, 46.48342078072684, 47.708728654044016, 45.76235410145351, 44.22148336683001, 43.678631033216206, 41.16622148241316, 37.17094128472464, 34.663836683545796, 34.5907381602696, 40.46627732685634, 40.12549250466483, 40.05883148738316, 36.99160827909197, 38.87690816606794, 45.59301955359322, 47.436129978724885, 49.53330475943429, 47.935274669102256, 45.49053709847586, 43.71333033697945, 48.08066919871739, 52.99016557421003, 49.920284679957796, 46.32302509035383, 39.536187989371165, 39.75092901502337, 38.68011781147548, 39.21908957617623, 38.276597704206196, 38.811188629695344, 41.619417735508506, 41.36872673034668, 46.53088045120239, 49.14481013161795, 50.45009524481637, 51.63934891564505, 45.32095241546631, 30.867344447544642, 19.72218029839652, 7.567188416208539, 4.204480469226837, 4.946571963174002, 7.941217763083322, 14.330378191811697, 14.368942431041173, 11.044341444969177, 9.442574960844857, 2.3810803464480808, 0.6981288301093238, 1.172173370208059, 5.826200442654746, 14.820980072021484, 25.59439648900713, 47.952346393040244, 46.872439997536794, 53.2739508492606, 54.18637439182827, 22.9651495047978, 5.266455735479083, 0.3679391693856035, 0.17231934198311397, 0.1984426959284714, 0.3918431167091642, 0.22717830113002233, 0.19152534353945935, 0.1571070754102298, 0.13307549564966134, 0.12392957641610078, 0.08705635501870088, 0.21524486504495144, 0.17532177801643098, 0.13989433832466602, 0.10396709652351481, 0.08010926243982144, 0.16081878409854003, 0.128691521606275, 0.15307132553841385, 0.08862060893859182, 0.17367521779877798, 0.13890801982155868, 0.13283731628741535, 0.17665299586951733, 0.1053200817799994, 0.2635304076331002], [0.07604429485010249, 0.024342961176963787, 0.017454093688034585, 0.0419587463672672, 0.012034642975777388, 0.06830514155860458, 0.008594277048749583, 0.06709736958146095, 0.09099854848214559, 0.017416094030652727, 0.024245740679491843, 0.0366001653351954, 0.08373411864574466, 0.03134018222668341, 0.02339362452871033, 0.05787137643034969, 0.03003516939601728, 0.023661394803119556, 0.06631033002798047, 0.03469856416008302, 0.0515123464034072, 0.03815881794850741, 0.08094996054257665, 0.020718413704474057, 0.03845821134746075, 0.06810666328029973, 0.031155919257019247, 0.01749833586758801, 0.05630291559334312, 0.011742168937676718, 6.963164142199925, 30.939313888549805, 43.15089103153774, 41.19361475535801, 27.71888290132795, 29.307911600385392, 35.87655789511544, 21.915294068200247, 13.50478368146079, 3.592069502387728, 0.2549750309969698, 0.17025272787681647, 2.0871913049902235, 2.4207556460584914, 2.4653465790407996, 2.82928757582392, 1.1336892523935862, 4.03865476165499, 7.530128461974008, 18.146587678364344, 32.53880657468523, 42.450165203639436, 49.24289090292794, 49.41051271983555, 45.87606137139456, 47.78426946912493, 44.397606304713655, 40.66685444968087, 41.2216785294669, 42.125354290008545, 45.54444122314453, 48.09788336072649, 48.12181295667376, 46.16370637076241, 45.53595747266497, 47.02501549039568, 44.81496722357613, 42.05512537275042, 39.030501570020405, 37.92624521255493, 36.45851469039917, 33.887559618268696, 34.38968855994088, 34.57204055786133, 35.16355807440621, 34.16638387952532, 34.05597005571638, 33.97090673446655, 38.21395969390869, 43.03313991001674, 45.993423393794465, 46.28125946862357, 45.232658181871685, 45.68017428261893, 48.08056150163923, 44.89897094454084, 43.560351848602295, 41.289041314806255, 51.508889538901194, 35.753244740622385, 38.90166459764753, 50.85447692871094, 42.27300698416573, 43.87980917521885, 37.07192250660488, 34.9516658101763, 34.44289091655186, 32.356680393218994, 31.91188451222011, 32.54881198065621, 35.7237218448094, 41.30992065157209, 37.67193767002651, 38.67922496795654, 34.75738375527518, 35.07143190928868, 36.57386173520769, 44.02554069246565, 43.53161409923008, 47.22294534955706, 46.03919465201241, 45.453079359872, 45.230754375457764, 45.41560772487095, 45.3628465788705, 44.444086279187886, 39.22335924421038, 35.76395538875035, 34.50354521615164, 36.22109474454607, 38.15634870529175, 39.90399088178362, 39.51457561765398, 42.88869033540998, 42.13597808565412, 44.608306952885215, 45.174612930842805, 47.28031315122332, 37.47466788973127, 24.70356968470982, 11.604670235088893, 4.4396439875875195, 1.351899926151548, 1.837683882032122, 3.722602052348001, 6.010848820209503, 9.939643876893179, 3.120453791958945, 2.0941922664642334, 0.8780928190265382, 0.20227488529469284, 1.0174462156636375, 5.020837783813477, 16.184713431767054, 30.521327631814138, 32.695134094783235, 36.20160157339913, 42.84035171781267, 34.296009472438264, 10.397317375455584, 1.1901625820568629, 0.0305965790924217, 0.021783971527059163, 0.04204231474016394, 0.0833964321230139, 0.012806687753514519, 0.040061280863093476, 0.050262508647782464, 0.03139695185901863, 0.08133363138352122, 0.05741873250475951, 0.030178520096732036, 0.013964163322400833, 0.025020522497860447, 0.034989011074815474, 0.03330161661974021, 0.07654719107917377, 0.08832396021378891, 0.024734543736225793, 0.051421911256121736, 0.05154420701520784, 0.08030472802264349, 0.0324301978440157, 0.03456679944481168, 0.03506379241922072, 0.019584985416648642, 0.021809604883726155, 0.012647082746428038, 0.02826927013562194, 0.032723450501050265, 0.008649103526425148, 0.008459711680188775, 0.033830022372837575, 0.05892654588179929, 0.023221118874581795, 0.0034215654179986033, 0.04979768501860755, 0.03715008404105902, 0.1063889983509268, 0.06100194023123809, 0.04482995712065271, 0.05166284886321851, 0.027651397843978236, 0.02879535360261798, 0.029162569969360317, 0.008031259224350964, 0.03421548454623137, 0.04207153245806694, 0.0425446647485452, 0.03393937846911805, 0.05165854016585009, 0.03223396890929767, 0.04801497674946274, 0.014728157282141703, 0.027836296940222383, 0.13235246230448994, 8.689905268805367, 35.80421672548567, 49.46932922090803, 46.43562412261963, 32.72039079666138, 29.961480004446848, 35.192202023097444, 31.6356588772365, 16.646059921809606, 4.301952838897705, 0.3314917965659073, 0.09099957985537392, 0.651075194988932, 3.989042886665889, 3.93188396521977, 4.428146021706717, 2.7888655619961873, 3.1057744196483066, 8.106760331562587, 19.735748393195017, 33.53640808377947, 43.347917624882285, 50.99772793906075, 50.58536277498518, 49.03063038417271, 47.89827898570469, 46.59123250416347, 41.79952893938337, 41.503292492457796, 43.46941729954311, 46.60180071422032, 48.4773314339774, 49.54239647729056, 46.41253873280117, 46.8883444241115, 48.82088163920811, 46.12454979760306, 43.41826466151646, 40.31619623729161, 38.896119935171946, 36.87439911706107, 35.19351175853184, 35.81117187227522, 37.590091364724294, 35.239032881600515, 36.12487956455776, 35.29721014840262, 35.655862263270784, 40.04862110955374, 44.094115938459126, 48.12635360445295, 47.81654385157994, 46.75879178728376, 46.544936656951904, 48.84514127458845, 45.478791168757844, 44.85581915719168, 42.15625640324184, 48.87785339355469, 37.551487173352925, 40.77948127474104, 51.33236707959856, 43.84452622277396, 44.77308348246983, 39.96552760260445, 36.40521158490862, 36.10626186643328, 34.167047432490754, 33.069836548396516, 34.4912816456386, 36.56042044503348, 41.95643663406372, 40.93403353009905, 39.870285170418875, 36.00500576836722, 35.16151877811977, 39.396094935280935, 44.91399294989449, 45.866031646728516, 49.41172170639038, 47.2046194757734, 46.394028731754844, 46.17157520566668, 47.89126477922712, 46.96253034046718, 45.15757942199707, 41.147996357509065, 37.94510957172939, 36.37733541216169, 37.044299943106516, 38.690151010240825, 41.414807183401926, 41.632264954703196, 44.29027400697981, 43.40302378790719, 46.23856973648071, 47.120702607291086, 47.6907571383885, 40.18506635938372, 25.43656815801348, 13.662218570709229, 5.5140756368637085, 3.1138731964996884, 3.5443809756210873, 5.382772922515869, 6.906554562704904, 7.841247950281415, 5.8721992543765476, 2.7831202702862874, 0.9108607407127107, 0.16307278243558748, 0.8311565976057733, 6.043748540537698, 16.34475302696228, 28.06232714653015, 36.527816023145405, 40.103067193712505, 47.00928129468645, 40.33413301195417, 12.827997871807643, 2.092284985951015, 0.06068423656480653, 0.05981719773262739, 0.006940038783276188, 0.06914927983390433, 0.017920920691852058, 0.05129899463749357, 0.052401424052992036, 0.01404307609690087, 0.05043313306357179, 0.05816096160560846, 0.012359968286805918, 0.032508365078164, 0.060500624988760264, 0.023099695032994663, 0.04331209124731166, 0.04386910064412015, 0.025131313695705364, 0.04371923600722637, 0.012942341322611486, 0.019987773981743624, 0.03686865824939949, 0.017973329040354917, 0.028096582973375916, 0.051214313467166254, 0.02681039779313973, 0.10653829641108002, 0.08415903763047286, 0.14532162781272615, 0.08886311056890658, 0.1490997922207628, 0.11979032281254019, 0.0888665643121515, 0.16847578036997998, 0.15729758090206555, 0.0766342267660158, 0.13290549548608915, 0.15227416902780533, 0.21299024245568685, 0.12302252437387194, 0.0752732212256108, 0.1997745923165764, 0.1157723098461117, 0.20604063251188823, 0.13852419970291002, 0.13274917458849295, 0.11428748523550374, 0.10892257347170796, 0.11171653640589543, 0.12068335632128374, 0.14006701191621168, 0.1762644395764385, 0.09951416975153343, 0.11814484825091702, 0.15344447908656939, 0.32882982226354734, 10.194965856415884, 39.769723892211914, 57.068664346422466, 51.493283884865896, 39.556476729256765, 40.70613261631557, 44.184678758893696, 30.09984643118722, 18.340968745095388, 5.330539405345917, 0.7804550496595246, 0.4559920345033918, 3.957889335496085, 7.383642196655273, 10.347807117870875, 6.88693458693368, 1.8185032712561744, 5.693057758467538, 9.205511110169546, 20.879687649863108, 34.77102306910923, 45.15518576758248, 52.3308162689209, 53.06089128766741, 49.91496583393642, 51.849702153887065, 48.62022808619908, 44.82879066467285, 44.22189678464617, 45.896926811763215, 48.22923558098929, 52.63090549196516, 50.78955296107701, 46.772170543670654, 46.902897426060264, 51.43167073386056, 48.35164894376482, 46.41622822625296, 42.18569244657244, 42.251074995313374, 39.12412159783499, 36.96467706135341, 37.85383456093924, 38.39121866226196, 38.11436421530587, 38.256538254874094, 37.43869359152657, 37.14719581604004, 40.35846560341971, 46.19472312927246, 49.32999004636492, 49.048626218523296, 46.27095181601388, 48.49430935723441, 49.88343838282994, 47.20668656485421, 46.74626765932356, 44.72640201023647, 49.51326615469796, 39.03606707709176, 43.189912114824565, 53.24001932144165, 45.31722123282296, 47.74284430912563, 42.19569785254342, 37.64294283730643, 37.6470388003758, 34.77349662780762, 34.266434465135845, 35.043972628457205, 37.97267654963902, 44.054170744759695, 42.55185209001814, 42.69420678274972, 37.63770042146955, 36.86365720203945, 39.963206904275076, 46.1967658996582, 48.33551870073591, 52.20644351414272, 49.77008547101702, 46.437402861458914, 45.79247454234532, 48.194775990077424, 49.87805005482265, 48.35421282904488, 43.84328249522618, 39.52493190765381, 37.47875690460205, 40.68436738422939, 40.20900290352957, 43.34322759083339, 43.205038343157085, 47.58882359095982, 45.67241661889212, 48.69068281991141, 49.69889770235334, 49.34578330176217, 41.77563061032976, 27.91707852908543, 14.790897846221924, 6.783501531396594, 3.5174119770526886, 4.74241521528789, 10.580865332058497, 13.965324180466787, 17.534496545791626, 8.315120305333819, 5.395427763462067, 2.134473796401705, 0.8411114662885666, 1.5899977556296756, 7.099364902291979, 21.48492612157549, 37.46701097488403, 43.21108327593122, 48.20061247689383, 53.05752141135079, 43.583496298108784, 15.362712008612496, 2.3125802278518677, 0.12070133749927793, 0.1395314849380936, 0.1705212513250964, 0.10550334051783596, 0.08703578183693544, 0.11129585826503378, 0.1250122876039573, 0.10176884662359953, 0.19663301589233534, 0.16478874321494782, 0.09554507237459932, 0.05829349985080106, 0.11219224373676948, 0.14040171967021056, 0.12998573215944426, 0.1444989719561168, 0.13802584287311348, 0.21820072643458843, 0.09064498423997845, 0.13644467986055783, 0.45097847495760235, 0.12441300547548703, 0.15300181641110353, 0.1440345011651516, 0.05496079368250711], [0.031096856176320995, 0.023198825606544102, 0.04389481372865183, 0.023495744049016918, 0.03788102910454784, 0.03282623837835022, 0.0429017132680331, 0.0856123985722661, 0.015043745615652629, 0.03510613300438438, 0.06863558811268636, 0.038563659082033803, 0.029963068264935697, 0.018835835258609483, 0.06422019111258642, 0.03710951443229403, 0.16448873574180262, 0.06340111792087555, 0.05223239419449653, 0.04779591850404229, 0.053198865548308404, 0.017063282962356294, 0.09320176525839738, 0.028809884430042336, 0.026943195577976958, 0.07825475159500327, 0.055639369413256645, 0.0893420884385705, 0.02922562283596822, 0.019122650314654623, 2.0016429126262665, 16.914185694285802, 40.075500215802876, 51.10921178545271, 39.28615706307547, 29.303805215018137, 28.109154530933925, 25.40813786642892, 17.751924787248882, 6.8152274404253275, 0.22453072534075805, 0.07256834315402166, 0.8784957602620125, 3.276380922113146, 2.05474973150662, 2.5560383754117146, 2.452399696622576, 1.0510043863739287, 2.9318731682641164, 13.137268270765032, 22.920328412737163, 37.96766689845494, 45.70454508917672, 51.3578530720302, 48.347441809517996, 45.792498861040386, 44.465333870479036, 42.237790039607454, 40.622465882982524, 42.416824272700715, 44.3578382900783, 46.18191759926932, 47.712963581085205, 45.37135464804513, 46.709758349827354, 45.3995087487357, 45.557566370282856, 43.796521118709016, 44.66269397735596, 42.63300010136196, 42.016628878457205, 39.11188582011631, 36.03982319150652, 33.69634171894619, 34.09184013094221, 33.48632894243513, 34.04087856837681, 33.41753135408674, 35.84048284803118, 42.94111449377877, 46.629728998456685, 43.2192508833749, 46.01582786015102, 45.16652522768293, 45.96701676504952, 44.90351159232003, 47.43492446626936, 45.82427644729614, 45.753901617867605, 34.43106855664934, 38.15871109281267, 50.39532259532383, 41.9013478415353, 44.407160077776226, 36.52078097207205, 35.43215111323765, 34.483395440237864, 33.90381840297154, 32.70140831811087, 34.87005226952689, 36.73053319113595, 39.96548243931362, 39.99873651776995, 40.45180075509207, 37.96143436431885, 34.25072111402239, 33.152276924678254, 36.33605963843209, 42.081261021750315, 43.80949687957764, 45.12816769736153, 48.3793375151498, 45.9565805707659, 48.0054931640625, 45.93108415603638, 45.28722585950579, 41.19389615740095, 34.31954302106585, 36.201778752463206, 37.95580979755947, 42.28170265470232, 42.25583103724888, 43.672780650002615, 43.100738934108186, 44.74740294047764, 46.2816937310355, 47.485420499529155, 43.609711851392476, 35.303946426936555, 19.88559671810695, 8.121940408434186, 1.5608414858579636, 1.718222743698529, 3.5469183708940233, 4.827693930694035, 4.615541543279376, 5.069432181971414, 4.923884791987283, 1.622305901987212, 0.43757271287696703, 0.34925592477832523, 1.6678775080612727, 9.034430827413287, 22.638460840497697, 30.48206683567592, 36.80680704116821, 41.83069855826241, 42.43942328861782, 21.080950907298497, 5.7068851079259595, 0.2148552638079439, 0.014994426297822168, 0.03150263708084822, 0.05242179028157677, 0.04789630097470113, 0.048433541253741295, 0.024692644198824252, 0.042796309638236246, 0.05133212071710399, 0.028905968381358043, 0.12506126426160336, 0.004803886711930058, 0.03901188574465258, 0.048179009197545905, 0.02654431028557675, 0.06619183745767389, 0.04441575559654406, 0.04135749648724284, 0.05481207237711974, 0.035231302359274456, 0.02846894772457225, 0.009198719436036689, 0.05082838310460959, 0.020815515458317738, 0.07885186919676405, 0.01978440346595432, 0.0590883968397975, 0.06870705142085042, 0.056266559687043936, 0.06843735410698823, 0.1026888790407351, 0.02914851750912411, 0.0356383283755609, 0.02076328861793237, 0.02907675564555185, 0.039188901960317574, 0.04031447281262704, 0.02476913884415158, 0.0425328175271196, 0.00442499911878258, 0.02429875631683639, 0.007130381850791829, 0.08202507892357451, 0.03239644072683794, 0.03558177926710673, 0.028930860438517163, 0.049146315149430714, 0.05391028915931072, 0.08174067775585822, 0.019223000554900085, 0.015552129496687224, 0.05599332042038441, 0.009086956236777561, 0.04828445353944387, 0.024348033226228187, 0.05828752874263695, 2.9482934985842024, 21.75730245453971, 46.00424173900059, 55.18594571522304, 41.82711328778948, 36.2133857182094, 31.547274317060197, 24.522543055670603, 21.18262563432966, 7.123616286686488, 0.5077796184590885, 0.06392074003815651, 0.4729293542248862, 2.390332741396768, 2.287896969488689, 4.235261857509613, 5.02442479133606, 3.398561085973467, 4.270636873585837, 15.038741827011108, 25.641194343566895, 38.74327693666731, 48.620071751730784, 52.393402167728965, 49.852550165993826, 48.27982541493007, 46.218513761247905, 43.6711026600429, 42.62959548405239, 43.85298565455845, 45.75922046388899, 46.84381341934204, 48.58519526890346, 46.16150031770979, 47.45388262612479, 47.321790422712056, 47.84106751850673, 45.929315839494976, 46.38772324153355, 43.461909770965576, 42.83607162748064, 40.16040025438581, 36.744808265141074, 36.47643756866455, 36.3186856678554, 34.71896716526577, 35.961037567683626, 35.97518410001482, 37.96232373373849, 44.65606539590018, 48.75592640468052, 45.12538146972656, 46.417492798396516, 46.927855355399, 48.272408212934224, 47.87716688428606, 48.26110349382673, 46.94224507468087, 46.91389642442976, 35.657286643981934, 40.59279012680054, 50.318524156297954, 44.61993476322719, 47.245596476963584, 40.15569632393973, 37.27161373410906, 35.16706691469465, 35.24568230765206, 34.874853474753245, 36.045117718832834, 37.18100227628435, 41.75092281614031, 42.164045333862305, 42.36739131382534, 38.90774427141462, 36.46474722453526, 36.30927433286394, 39.40109763826643, 45.02000856399536, 47.30958938598633, 47.51834453855242, 48.64015899385725, 46.71581717899868, 49.175368309020996, 47.2625744002206, 46.30732216153826, 43.59644774028233, 36.630235944475444, 36.9602267401559, 39.641706807272776, 42.992777824401855, 43.77607257025582, 43.93925448826381, 44.72033970696585, 46.27184118543352, 47.022521087101524, 48.23048278263637, 47.2975412096296, 37.44854266302926, 22.484436648232595, 9.731279560497828, 2.981289190905435, 2.5685564236981526, 5.361341203962054, 6.420618832111359, 7.615501846585955, 6.1824363214629035, 6.0730330262865335, 2.1237833414758955, 0.5690780377813748, 0.42667340487241745, 1.8727746733597346, 8.528486456189837, 23.83100622040885, 33.94566740308489, 39.48086643218994, 45.393717425210134, 46.702344621930806, 26.78693492071969, 7.713865756988525, 0.3848179993884904, 0.04903267410450748, 0.041510122761662514, 0.048317820498985906, 0.0337494361613478, 0.07160861643829516, 0.0398028234818152, 0.02028471786927964, 0.06204516068100929, 0.0681768102305276, 0.09351948249552931, 0.012458831687191767, 0.016649332496204546, 0.071989532427064, 0.037589669560215304, 0.06352224320705448, 0.04424593863742692, 0.04462977911212614, 0.06218074554843562, 0.05065608949267438, 0.08439431286283902, 0.057119118581925116, 0.03669227307130184, 0.035731650689350705, 0.036965396987008195, 0.013948679153275276, 0.11192487379802124, 0.2128126019878047, 0.13610847932951792, 0.14652620388993196, 0.1886433067598513, 0.10709698857473475, 0.12021853269210883, 0.14472379774919578, 0.11949578433164529, 0.10954905128372566, 0.1406681260892323, 0.0767705240952117, 0.13796269840427808, 0.1201785398381097, 0.16836971177586488, 0.11431320171271052, 0.29909421929291313, 0.13132787442633084, 0.14755892061761447, 0.11598838253745011, 0.15819577127695084, 0.1229704807379416, 0.1905198089246239, 0.09319099690765142, 0.11023007652589253, 0.1534053004745926, 0.08464798317956072, 0.13367646054497787, 0.1302072602723326, 0.23074782959052495, 3.594612325940813, 25.234870638166154, 52.175225257873535, 62.79640143258231, 49.55198846544538, 41.12299673897879, 38.26977457318987, 32.471211024693076, 24.095895869391306, 8.938068866729736, 0.8581242391041347, 0.48332434786217554, 1.4581780518804277, 5.656992265156337, 7.06388783454895, 8.885570015226092, 5.812310125146594, 2.1333510109356473, 3.945091187953949, 16.140766075679235, 25.951351506369456, 41.774953160967144, 50.249674456460134, 55.28430094037737, 51.39495645250593, 49.77596712112427, 48.90073381151472, 45.64556877953665, 44.4464556149074, 45.798217228480745, 47.96476282392229, 49.287505286080496, 49.055991309029714, 46.21975401469639, 48.040612833840505, 49.151862553187776, 49.520655563899446, 47.88009902409145, 48.036478655678884, 46.28931243079049, 45.58775976725987, 42.8467892238072, 39.73779344558716, 37.47472347532, 38.8834672655378, 37.346994740622385, 36.748317105429514, 38.83423580442156, 39.00717299325125, 46.98912804467337, 49.250064917973106, 46.06028938293457, 48.19463355200631, 47.769490650721956, 49.18149662017822, 50.62603405543736, 50.187772955213276, 49.628675733293804, 48.21867084503174, 39.39286749703543, 42.51569366455078, 53.02163743972778, 45.9811806678772, 49.37247133255005, 41.70270579201834, 37.63629688535418, 36.73746401923043, 37.282869815826416, 37.17241082872663, 37.83807952063424, 39.181843757629395, 42.946419443402974, 43.79624319076538, 44.27807991845267, 40.50421796526228, 37.81683887754168, 37.16729348046439, 39.78521490097046, 47.19946738651821, 48.32200445447649, 48.96241297040667, 51.57645729609898, 47.143006324768066, 50.25568812234061, 50.7346830368042, 49.290128231048584, 45.021752561841694, 39.32204450879778, 40.492020402635845, 41.1639528955732, 45.62787519182478, 46.391972064971924, 47.22753463472639, 47.50631373269217, 49.037238121032715, 49.68664108003889, 49.53298166819981, 48.52845627920968, 38.83883898598807, 23.351788963590348, 10.739386745861598, 2.7162060780184607, 4.373568790299552, 8.39238166809082, 10.800147005489894, 13.60367044380733, 11.929236224719457, 13.205825277737208, 4.309522467000144, 1.6308064801352364, 0.775295686508928, 2.8903600701263974, 11.912975702966962, 28.894116844449723, 39.90079818453108, 47.54150635855538, 52.02687079565865, 53.39951522009713, 28.868054151535034, 8.843519517353602, 0.5140895055873054, 0.12707877957395144, 0.14030945247837476, 0.0918339675824557, 0.2304165687944208, 0.1586325578391552, 0.10843845230660268, 0.14478747147534574, 0.22008930652269296, 0.14439473540655204, 0.18792498244770936, 0.08719639107584953, 0.10198742989450693, 0.13642965709524496, 0.09407122646059309, 0.2047443049294608, 0.10637212318501302, 0.17500836269131728, 0.2834453290062291, 0.23076159028070314, 0.1309647224843502, 0.11794841236301831, 0.20202758642179625, 0.1155438335346324, 0.08357322442212275, 0.1148115721132074], [0.0740820530003735, 0.03243267110415867, 0.03014580113813281, 0.04217212188190647, 0.03045145741530827, 0.09714567541543927, 0.04293260018208197, 0.06125816183962992, 0.06939320638775826, 0.02104089086476181, 0.0224335805978626, 0.06683657464704343, 0.057854514835136275, 0.03125388275033661, 0.0206227792826082, 0.06238434676613126, 0.009062724903092852, 0.04109368885734251, 0.02503667163130428, 0.058175794381116114, 0.04132313886657357, 0.06344061544431107, 0.02874371369502374, 0.03482636623084545, 0.06619161354111773, 0.014036822548535253, 0.03172333059566362, 0.040967810433357954, 0.02592355422010379, 0.05571630849902119, 0.8623596004077366, 8.169697982924324, 22.910088505063737, 44.95225667953491, 42.451895305088584, 27.98292487008231, 19.888876267841884, 24.230390412466868, 17.848565544400895, 10.47472551890782, 1.074707840170179, 0.08302399782197815, 0.10816862607108695, 2.729246109724045, 1.030561591897692, 3.0568988365786414, 6.915049169744764, 3.2660634985991885, 2.056374958583287, 7.786275540079389, 21.208240168435232, 30.355724266597203, 44.62442329951695, 49.671577385493684, 49.70156233651297, 46.818879808698384, 45.629250935145784, 43.03398411614554, 44.30708517347063, 44.61814907618931, 46.099782943725586, 47.759002344948904, 47.71157741546631, 45.41147007261004, 44.91061265127999, 47.117502961839946, 47.158671038491384, 47.06463759286063, 47.164667333875386, 44.97611331939697, 46.57416425432478, 42.7940628187997, 41.61467906406948, 39.047145979745046, 33.714681489127024, 33.823531968253, 35.53284788131714, 32.812162603650776, 34.82434701919556, 38.40181466511318, 43.97839369092669, 43.97941855021885, 47.34948941639492, 45.678079400743755, 43.951073374067036, 43.26677656173706, 42.99668966020857, 43.60835000446865, 49.67645502090454, 37.62949807303292, 38.83411421094622, 48.726035254342214, 42.32052224023001, 43.50657279150826, 36.51564972741263, 35.93832738058907, 34.80750458581107, 37.27200630732945, 38.258073806762695, 39.492744377681184, 38.50603069577898, 42.70483752659389, 40.29639387130737, 39.87535040719168, 38.52565588269915, 34.81786434991019, 32.58913237707955, 34.02319540296282, 36.27077783857073, 42.15163932527815, 43.98100273949759, 46.24115446635655, 45.512528147016255, 46.55124909537179, 45.694098472595215, 44.89110558373587, 41.24184567587716, 35.37328944887434, 34.169312545231406, 41.16107634135655, 44.19579587663923, 46.93068674632481, 46.09545769010271, 45.73741006851196, 45.54204756872994, 45.863064765930176, 45.44901466369629, 40.05420746122088, 28.693258319582256, 16.1320287159511, 5.416496004377093, 1.961968047278268, 1.9075625666550227, 4.443000401769366, 4.004890859127045, 3.799884693963187, 3.7582528250558034, 3.8425309998648505, 2.194884257657187, 0.6276399525148528, 0.7665809084262166, 3.8885897397994995, 9.45148776258741, 17.553395645959036, 24.560424634388514, 38.26149232046944, 42.07186010905674, 36.60987424850464, 13.316630806241717, 3.408947991473334, 0.2628904405449118, 0.043499753677419255, 0.044271811177687984, 0.0660697350810681, 0.011885637533850968, 0.10969119079943214, 0.10592657673571791, 0.033639357425272465, 0.034887787220733504, 0.03410296986943909, 0.032202932717544694, 0.04968284975205149, 0.013765540007235748, 0.024433294543996453, 0.0074844914654802, 0.05716939802680697, 0.0392493831792048, 0.04465291715626206, 0.03344815304236753, 0.04396282329357096, 0.031030332603092705, 0.03481411188840866, 0.08244168585432426, 0.04184465409655656, 0.03911911802632468, 0.042351984551974704, 0.0180185703627233, 0.07345697975584439, 0.064874753489026, 0.03826254898948329, 0.024700990179553628, 0.03614001002694879, 0.018995905062183738, 0.014930055376940539, 0.04145287476213915, 0.07098579593002796, 0.03590741840058139, 0.019393036341560737, 0.04029138565861753, 0.020163329650780985, 0.01771462569013238, 0.08052810175078255, 0.031088954636028836, 0.06664064087505851, 0.06796156535191195, 0.05728174985519477, 0.05390914922047939, 0.061192493220525127, 0.004867895464745483, 0.012947716168127954, 0.033101981439228566, 0.03545380416991455, 0.04035331894244466, 0.047656167431601455, 0.07451366234038558, 0.0968568434140512, 0.9812723738806588, 10.159199135644094, 31.58269623347691, 51.42070995058332, 48.07808099474226, 32.122269017355784, 24.692905936922344, 28.197217736925396, 19.305628844669886, 11.583775264876229, 1.2203031075852258, 0.034200862116579495, 0.14117868297866412, 1.3455397188663483, 2.455799754176821, 5.574889310768672, 6.147362683500562, 2.44859425510679, 3.5070050954818726, 9.020806278501238, 23.487735680171422, 33.59678445543562, 45.49328163691929, 52.55265835353306, 50.95437465395246, 48.0911922454834, 47.69596133913313, 45.795688084193635, 45.22769021987915, 46.738239015851704, 47.99553986958095, 49.197164808000835, 49.010998249053955, 46.526621205466135, 46.05569314956665, 48.443792479378835, 48.63897432599749, 47.91181060246059, 48.69323975699288, 46.033632619040354, 48.39261204855782, 45.82339055197579, 42.71563502720424, 39.37641416277204, 35.32270656313215, 35.886809962136404, 35.557882240840364, 34.211957114083425, 36.33744927815029, 39.69872372491019, 46.34392874581473, 46.90553426742554, 48.84548173631941, 46.11427688598633, 46.842058999197825, 43.57446711403983, 45.71999093464443, 45.98131615774972, 51.16219874790737, 39.310625144413535, 39.76586764199393, 53.19544315338135, 44.19999606268746, 46.265556539808, 38.776287828172954, 37.84987408774239, 34.995936257498606, 39.337167263031006, 40.30651044845581, 41.518943309783936, 40.09345088686262, 43.29784195763724, 43.062141690935405, 43.09159510476248, 39.310951709747314, 36.533517020089285, 34.14348609106881, 35.5052843775068, 38.95701742172241, 44.942275592258994, 45.337311949048726, 47.538800035204204, 45.81888117109026, 46.9333062171936, 48.492662634168354, 46.385781220027376, 43.621141638074604, 37.91442632675171, 35.9366910798209, 42.226290770939414, 46.77620397295271, 48.35284750802176, 46.944756848471506, 47.71086522511074, 48.53876740591866, 47.23429870605469, 48.55582523345947, 42.803498472486226, 30.5843061038426, 17.616097927093506, 9.215995941843305, 3.9480598058019365, 3.897926381656102, 6.974178774016244, 7.169510875429426, 9.346028004373823, 6.643149222646441, 5.192548181329455, 2.066199711390904, 0.2130693324974605, 0.9411261166845049, 3.680343977042607, 12.83466466835567, 22.61949052129473, 27.55430265835353, 43.23620448793684, 47.13091993331909, 42.647462776729036, 17.317473036902292, 4.117604970932007, 0.25415194087794846, 0.01271141380337732, 0.047077183678214035, 0.062388221201087744, 0.05697177470262561, 0.05994341203144618, 0.06110865343362093, 0.026448562209095274, 0.018061472435614893, 0.042619130574166775, 0.04725842716704522, 0.060521863134843965, 0.025812763022258878, 0.0472151094914547, 0.039493540434965065, 0.020481677925480262, 0.031825640105775425, 0.01139417292350637, 0.05986597082976784, 0.0564126211351582, 0.00717296586039343, 0.017136488409180726, 0.01602485975516694, 0.039844438034508906, 0.039870782156607935, 0.03265582091574158, 0.1261142420449427, 0.18454659730196, 0.11317692697048187, 0.15626779544566358, 0.1266477605594056, 0.14392276001828058, 0.06742681868906532, 0.15130953650389398, 0.15822402547512734, 0.09512920504701988, 0.07788457681557961, 0.140716763479369, 0.1093275435268879, 0.1459080177758421, 0.1364758246179138, 0.2391760487641607, 0.08568266087344714, 0.12769605645111629, 0.14622055100543158, 0.14374032909316675, 0.06490509078970977, 0.11362245306372643, 0.10503770943198885, 0.10896684788167477, 0.12140860169061593, 0.15017806578959736, 0.15464604246829236, 0.14089140482246876, 0.09813719149678946, 0.1350180192717484, 1.1618438959121704, 12.093711376190186, 34.580826554979595, 56.26555333818708, 54.241536140441895, 41.637580326625276, 30.11559452329363, 34.36551577704293, 23.800977843148367, 13.475587350981575, 2.0484548807144165, 0.29073797911405563, 0.6890199588877814, 5.644713061196463, 3.7619939957346236, 9.86485607283456, 12.819574918065753, 8.101821899414062, 3.7066641875675748, 9.719180141176496, 23.496165582111903, 34.26247746603829, 47.62208114351545, 53.36357913698469, 53.465248652866904, 50.601121289389475, 49.0644542149135, 48.62872920717512, 47.33087171827044, 48.78616843904768, 50.358830656324116, 50.92433064324515, 49.48266281400408, 46.52665247235979, 45.66796282359532, 49.29627043860299, 50.800551959446494, 50.87297303336007, 52.016087191445486, 48.866764068603516, 51.41479703358242, 47.285927295684814, 44.91064044407436, 42.48653902326311, 37.462501593998496, 38.05653435843331, 38.23920249938965, 35.074416160583496, 37.8226614679609, 41.09882743018014, 47.67831638881138, 48.65999262673514, 50.29915952682495, 49.53171362195696, 48.204586846487864, 47.85034336362566, 46.14541176387242, 47.89252587727138, 51.919076442718506, 42.37196670259748, 43.55187504632132, 53.200518812452046, 46.814488547188894, 46.645720277513774, 40.783705779484336, 39.01688657488142, 37.99257271630423, 40.579995019095286, 42.38411562783377, 43.228012561798096, 42.73260252816336, 46.81519378934588, 43.931059088025776, 44.221514633723665, 41.50423744746617, 38.49788045883179, 34.930960178375244, 37.5237569127764, 39.075115953172954, 46.57614796502249, 47.11182280949184, 49.044262749808176, 46.260619844709126, 46.78460781914847, 50.06768723896572, 48.049145221710205, 44.574806213378906, 39.611548151288716, 36.5531039919172, 44.237603187561035, 49.284461975097656, 50.75311313356672, 47.945745604378835, 49.959378719329834, 50.0292706489563, 49.34059647151402, 48.76787730625698, 44.51822703225272, 30.715366499764578, 19.017754554748535, 6.95593888419015, 4.105351388454437, 5.055032908916473, 10.287221431732178, 11.071463738168989, 13.073689648083278, 13.559220211846487, 11.146015303475515, 6.561129646641867, 1.1516689104693276, 1.4919251267399107, 4.896106328283038, 14.431063669068472, 24.92825879369463, 34.86252042225429, 47.593999998910085, 54.37806824275425, 46.35427461351667, 21.455392803464616, 4.696421180452619, 0.4202133986566748, 0.13289140909910202, 0.15409302285739354, 0.18664525183183805, 0.09759581554681063, 0.3014064223638603, 0.15401368854301317, 0.1212624723889998, 0.16089262227926934, 0.18176874278911523, 0.16860706332538808, 0.21255542364503655, 0.12536207240607056, 0.19129979849926063, 0.12043736023562295, 0.17693325797361986, 0.1654476278594562, 0.11532440888030188, 0.07828401681035757, 0.0738910318219236, 0.08104083673762423, 0.14257917925715446, 0.21830017252692155, 0.19571174175611564, 0.1159498281776905, 0.14023360583399022], [0.04170390897031341, 0.028912855511797324, 0.05578338847096477, 0.06900720817169972, 0.013831711590423115, 0.057406166036214144, 0.034577788319438696, 0.08005966831530843, 0.011923044321260281, 0.04107950747545276, 0.043751486776662726, 0.031225214645798718, 0.046350811940750906, 0.055739263338702064, 0.0809783029503056, 0.03739894354449851, 0.057567840575107505, 0.026176362797351818, 0.09270032787961618, 0.02428519070547606, 0.026533485955691764, 0.01721054032844092, 0.0505391100554594, 0.04507658085120576, 0.0116506455898551, 0.020679628642808114, 0.07546910071479422, 0.07045794996832098, 0.00552213892972629, 0.061443585104175975, 0.046511397430939336, 2.4024647303989957, 12.357958316802979, 39.79770081383841, 39.04762887954712, 32.30324179785592, 22.267602477754863, 17.636994634355815, 24.62820952279227, 15.000469412122454, 1.8233955630234309, 0.30100299258317265, 0.1809515016419547, 0.6511504309517997, 2.1675730603081838, 3.231278645140784, 4.718158619744437, 3.185220773730959, 1.7502194153411048, 4.5662175842693875, 14.248583997998919, 25.45512679644993, 39.253781931740896, 48.745080266680034, 48.06352799279349, 47.56245517730713, 46.55732529503958, 46.173666613442556, 44.7153856413705, 46.71057823726109, 46.68471704210554, 47.91655969619751, 45.55459948948452, 44.028806345803396, 47.18508114133562, 44.52336869921003, 46.709681919642854, 46.958552496773855, 47.23111643110003, 47.03667804173061, 46.03397308077131, 47.637801442827495, 43.66876459121704, 42.82287005015782, 39.20442887714931, 35.53538049970354, 35.1367449760437, 33.980717590876985, 33.80517135347639, 34.39387484959194, 37.980812890189036, 41.43907029288155, 41.82321882247925, 39.91426031930106, 38.82341398511614, 38.85593155452183, 42.70165177753994, 42.38825675419399, 46.10435833249773, 37.77813393729073, 37.58741283416748, 50.220853328704834, 42.288762024470735, 45.05022975376674, 37.60793086460659, 37.8255866595677, 37.403084073747905, 37.892417907714844, 37.07532017571585, 39.442693029131206, 39.474557467869346, 41.989360673086985, 40.894814423152376, 40.744097573416575, 37.511354378291536, 37.19016695022583, 33.94637959344046, 34.67529078892299, 34.21168960843767, 38.931357724326, 44.52520997183663, 45.63705723626273, 47.66084514345442, 46.90930366516113, 47.96196617398943, 46.285202571323936, 42.586905751909526, 35.9761255809239, 34.33932106835501, 41.036074774605886, 46.92937353679112, 46.42837020329067, 46.29266841070992, 47.39591727937971, 49.022924831935335, 49.3575222832816, 47.501516001565115, 36.06333589553833, 26.738962820598058, 13.427260024206978, 8.261891024453298, 2.1564218529633115, 1.6009118556976318, 4.991414334092822, 7.09221260036741, 7.125865765980311, 3.025595247745514, 3.435848810843059, 1.10519468997206, 0.04944968815626843, 1.40252699809415, 3.9125710129737854, 8.473890117236547, 21.525611298424856, 29.347113336835587, 34.96952962875366, 34.55897099631173, 24.651223693575176, 10.342681084360395, 1.459606558084488, 0.03574599152696984, 0.05425559902297599, 0.04629338752212269, 0.02875631069764495, 0.034664403314569166, 0.07582664795752082, 0.027812071543719088, 0.015829762277592505, 0.05780984687485865, 0.039215863549283574, 0.044900691003671715, 0.07086802939219133, 0.03955674936462726, 0.03563829105613487, 0.0700322167415704, 0.050472087758992396, 0.10302910328443561, 0.038741570963923416, 0.04282903538218566, 0.008229270161661719, 0.06448140673871551, 0.027173505630344152, 0.02846240664699248, 0.005773088745107608, 0.018661492470917956, 0.0425297539415104, 0.05556904265124883, 0.02687563723884523, 0.04504406206043703, 0.046275189212922535, 0.018885269927393113, 0.05114821737099971, 0.12799790953951223, 0.02048083484571959, 0.045604884824050326, 0.046731697395443916, 0.07191381470433303, 0.021782147964196544, 0.007987020437472632, 0.04051107154893024, 0.10098965093493462, 0.031200760243726627, 0.02450959411050592, 0.11491475014814309, 0.09046288579702377, 0.005181381187867373, 0.013025025055477661, 0.0317575762580548, 0.025640406645834446, 0.05016467407611864, 0.021606242849624584, 0.0022324516695724534, 0.051754267886281013, 0.05044235774715032, 0.03124657492818577, 0.06324070545711688, 0.07313650766653673, 3.8095995783805847, 16.586355788367136, 45.85317053113665, 46.257642541612896, 38.21329961504255, 25.316487652914866, 20.748684576579503, 27.935327972684586, 17.471832479749406, 2.1512239490236555, 0.22302467615476676, 0.17079100970711025, 1.886659128325326, 2.9904931655951907, 5.534152456692286, 5.743066115038736, 4.472555867263249, 3.878045414175306, 7.800839832850865, 15.302815062659127, 27.185990810394287, 40.79769945144653, 50.86569479533604, 50.268052441733225, 49.16131905147007, 48.95091370173863, 47.70067916597639, 46.91871847425188, 48.03760426385062, 49.01323904309954, 49.32010970796858, 46.744937079293386, 44.77596698488508, 46.852477822984966, 46.00855309622628, 47.399606772831504, 48.66170883178711, 49.31826148714338, 47.70438602992466, 48.06641149520874, 48.48697900772095, 45.895307881491526, 43.80540439060756, 40.40919440133231, 36.672331605638774, 36.3770991734096, 34.839754649571006, 34.79456009183611, 36.65193864277431, 40.50931446892874, 44.75752993992397, 45.34942960739136, 41.91816595622471, 40.58448355538504, 40.443827697208945, 43.616663524082725, 43.82205574853079, 48.4314420563834, 39.66549049104963, 38.91299363545009, 50.100705078669954, 44.087803500039236, 46.68527637209211, 40.63543816975185, 38.22388519559588, 38.23311240332467, 39.40613508224487, 38.8592597416469, 41.69146360669817, 40.765980924878804, 44.28167561122349, 42.876850605010986, 43.253762585776194, 39.79558161326817, 38.0300304549081, 35.32930735179356, 35.30970648356846, 35.947349616459434, 40.476894174303325, 46.96878719329834, 46.83835213524954, 47.868036951337544, 47.58541202545166, 48.90997838973999, 48.393188749040874, 43.93612085069929, 37.273760727473665, 36.78378765923636, 43.033087798527305, 47.89972768511091, 47.94893135343279, 47.498688084738596, 48.680517605372835, 48.57393223898751, 50.642622879573274, 47.768549169812886, 39.206436906542095, 28.04493580545698, 15.528977189745222, 7.895657556397574, 3.9919858830315724, 4.585232198238373, 9.101170880453926, 7.174220017024449, 7.67963285105569, 4.659414640494755, 3.8236831426620483, 1.0145388288157327, 0.1942695834274803, 1.1050051344292504, 5.284031203814915, 11.799760018076215, 24.410209792000906, 34.75927019119263, 40.24334784916469, 43.00776161466326, 30.7306455884661, 12.612337078366961, 1.8164690775530679, 0.04122285817616752, 0.020160983615954007, 0.0925366109503167, 0.03181218136368053, 0.03518547410411494, 0.03276208628501211, 0.041143228699054034, 0.1024163318797946, 0.01517560871850167, 0.058142369746097496, 0.0760307377204299, 0.0755559667678816, 0.011164453196605402, 0.03557681917612042, 0.03524075435208423, 0.03957688489130565, 0.02944910173703517, 0.04538243390353663, 0.01070807732841266, 0.03620131905855877, 0.04891392369089382, 0.024273882919390286, 0.03613671913210835, 0.013772318572072046, 0.018006633235407726, 0.013628334289283624, 0.1475006208888122, 0.06146768666803837, 0.12354354427329131, 0.1504859035568578, 0.0967218895841922, 0.10756208361791712, 0.17444044245140894, 0.13106923044792243, 0.08901690053088324, 0.12362293287047318, 0.2017173059284687, 0.14738849976233073, 0.11655555638883795, 0.1341013591736555, 0.18016579880246095, 0.12128856884581701, 0.1482279018632003, 0.21287023675228867, 0.18215972823756083, 0.21083552736256803, 0.11986384886716094, 0.13374202059847967, 0.14947992110891, 0.132767223619989, 0.06403832337153809, 0.1299516832722085, 0.08361276265765939, 0.2821833895785468, 0.25107663018362864, 0.14159301003175123, 0.22066724193947657, 3.752317326409476, 20.011334793908254, 52.956004755837576, 51.83002485547747, 43.33567837306431, 33.13596602848598, 28.172110421316965, 31.417183194841655, 19.335403612681798, 2.7479072340897153, 0.6727682309491294, 0.8717279977032116, 3.736078952039991, 8.804686903953552, 8.623084442956106, 10.68832356589181, 7.082668815340314, 3.0121650312628065, 6.096370722566332, 15.800208806991577, 28.49134193147932, 41.75665855407715, 53.50734083993094, 51.57225711005074, 52.065916197640554, 51.921143531799316, 50.22432395390102, 48.933331285204204, 50.08000986916678, 51.40846722466605, 51.188521998269216, 48.04419115611485, 46.34767729895455, 47.85926832471575, 45.53369583402361, 48.26428229468209, 49.08910294941494, 50.68770626613072, 49.459257807050435, 48.91220876148769, 51.02967575618199, 46.938048362731934, 46.22339487075806, 43.60181522369385, 39.168937478746685, 37.88269737788609, 35.72905806132725, 37.47550514766148, 39.23404209954398, 40.01462704794747, 45.24058607646397, 45.68676812308175, 43.31536531448364, 41.33221742085048, 42.31127766200474, 44.13935565948486, 44.94610404968262, 48.46312236785889, 42.257119928087505, 41.12213863645281, 52.680390562329976, 45.81307247706822, 48.29327712740217, 42.40884774071829, 40.944730281829834, 41.42522253308977, 40.27922487258911, 40.43551070349557, 43.05396713529314, 43.6216002191816, 45.38987159729004, 44.65607581819807, 44.381142548152376, 40.78251068932669, 40.372104917253765, 36.87025451660156, 37.149019718170166, 37.255684988839285, 41.21317393439156, 48.734018734523225, 49.258100509643555, 50.86627149581909, 47.37600026811872, 51.82112768718174, 50.49688441412789, 44.88169077464512, 39.40615245274135, 38.15575463431222, 45.25476734978812, 50.106555461883545, 49.91246100834438, 48.44714845929827, 49.48010587692261, 51.40617084503174, 53.1830267224993, 50.43224879673549, 38.405994006565635, 29.428865841456822, 16.420622144426616, 10.355402367455618, 5.025541279997144, 5.660063803195953, 13.040696127074105, 14.029326643262591, 16.673675537109375, 10.788925664765493, 9.537422214235578, 1.536443863596235, 0.5128463208675385, 2.1418239048549106, 6.154047719069889, 14.092469266482762, 31.295940603528702, 39.39629643304007, 46.470288685389924, 47.22536679676601, 34.70234707423619, 15.363808086940221, 2.0543213316372464, 0.25342376423733576, 0.0896721210862909, 0.15914510962154182, 0.0668788066666041, 0.19045967715127127, 0.11480412179870264, 0.10016227247459547, 0.1361189287688051, 0.09937687497586012, 0.14181277395359107, 0.11856460358415331, 0.22749638477606432, 0.12267253601125308, 0.09189150735203709, 0.11649541104478495, 0.14311682326453073, 0.16805861704051495, 0.10938790600214686, 0.21037963325423853, 0.17091347170727594, 0.11012560248907123, 0.14027762918600015, 0.1172935717872211, 0.050789499655365944, 0.11250538086252553, 0.21745626495352813], [0.02785046475141176, 0.05448833314169731, 0.07302686997822352, 0.05553079702492271, 0.024226946955812827, 0.05495312962947147, 0.044370327677045546, 0.04145570086049182, 0.05340434630800571, 0.02773796025264476, 0.02079945114175124, 0.04356017043547971, 0.023117072314822247, 0.01996305495101426, 0.02508764318190515, 0.04801021682630692, 0.015061799736161317, 0.03220640342416508, 0.02946904388123325, 0.031778271576123576, 0.07784319296479225, 0.024943512165918946, 0.04409312576587711, 0.02040323588464941, 0.04084469364689929, 0.06400914636573621, 0.03125147395102041, 0.012996374762484005, 0.07961205233420644, 0.03853063817535128, 0.04284730493756277, 0.5066239376153264, 11.04002400806972, 29.52624831880842, 38.33606038774763, 32.47509854180472, 23.823132174355642, 17.869311128343853, 26.065562520708355, 17.289662872041973, 5.581468386309488, 0.5462723129561969, 0.08477738659296717, 0.9077179293547357, 1.1210631813321794, 5.767779554639544, 5.2095855985369, 0.2121037364538227, 3.4073483858789717, 4.04987610237939, 11.60256232534136, 22.44329115322658, 34.94386993135725, 45.433978761945454, 52.909983362470356, 48.27628878184727, 49.55728646687099, 49.53894322259085, 46.77819463184902, 48.020299775259836, 47.91860941478184, 48.08362913131714, 43.92034496579851, 43.78324658530099, 46.71405233655657, 45.383857931409565, 44.28134904588972, 45.64909151622227, 43.676921776362825, 45.507320472172324, 47.884681361062185, 48.212869099208284, 47.832809584481375, 44.229595388684956, 41.62771735872541, 36.42673710414341, 34.52674177714756, 34.25185367039272, 34.28407941545759, 33.65561137880598, 32.72401428222656, 33.01901742390224, 34.87249803543091, 32.948326451437815, 34.85322373253958, 33.03698893955776, 40.44219487054007, 42.83547060830252, 48.12628064836775, 38.933351857321604, 36.60682051522391, 51.00740677969796, 43.03462335041591, 43.62153421129499, 40.184128352573936, 36.571290901729036, 34.692595277513774, 33.94822086606707, 34.65830939156668, 37.706233978271484, 39.06657314300537, 39.18040200642177, 38.86769832883562, 37.54941313607352, 35.04079382760184, 36.4524940763201, 34.28544126238142, 34.280445507594514, 35.48356778281075, 38.48301131384713, 43.818352358681814, 44.61470971788679, 45.622066497802734, 44.288665499006, 45.564545835767476, 44.99732269559588, 43.07538495744978, 37.55069160461426, 35.192323616572786, 39.19307552065168, 45.2251159123012, 46.14307369504656, 49.22448165076119, 46.71829768589565, 47.30716446467808, 45.77208852767944, 41.82961811338152, 32.46168157032558, 21.22939395904541, 10.20876932144165, 5.994539226804461, 5.579105998788561, 7.381200773375375, 7.38533582006182, 3.94870468548366, 7.01436368056706, 4.391602405479976, 2.5298549575465064, 0.5481103828975132, 0.19325810484588146, 2.1384381779602597, 7.732746618134635, 18.23966227258955, 20.627207483564103, 27.941933972494944, 35.14115013395037, 31.662871497017996, 14.803149257387433, 5.499784929411752, 0.27510816923209597, 0.057851318935198445, 0.028194641461595893, 0.011598730027409536, 0.051059492131961245, 0.017394140030124357, 0.03245719335973263, 0.025760419134582793, 0.06008600616561515, 0.07473863062581845, 0.06812950955437762, 0.06966728025249072, 0.035989670415541956, 0.007560875000698226, 0.04744738220636334, 0.04126153467223048, 0.048097255905824046, 0.08873836190572806, 0.004336796351708472, 0.08982296620628663, 0.0674410814951573, 0.026660195585074167, 0.024778071757672087, 0.06335408187338284, 0.05313017066302044, 0.013077949090594692, 0.024681165082646266, 0.019150115715871965, 0.009698221293677176, 0.03134302868108664, 0.03135200230670827, 0.03743243942569409, 0.019863347622698972, 0.036089170790676556, 0.025936495579246963, 0.013163451288294579, 0.07863816459264074, 0.029190902199063982, 0.019470104348978827, 0.04593451374343463, 0.012543919130361505, 0.04407242366245814, 0.05533231874661786, 0.08743375619607312, 0.064708580262959, 0.022733939212879965, 0.004939671323102499, 0.04600691682259951, 0.06773724167474679, 0.009569344593078961, 0.0063312486828570914, 0.053746070114097426, 0.06247410337839808, 0.04068912931584886, 0.006568200320803693, 0.06303196094397988, 0.02100509644619056, 0.05114322674593755, 0.8986814171075821, 12.77565882887159, 35.9615204674857, 44.874231883457725, 36.51991592134748, 30.963879244668142, 21.863662004470825, 29.285336903163365, 21.896485294614518, 5.559007031576974, 0.5918260057057653, 0.13004116847046784, 0.8651111413325582, 1.909959695168904, 8.424279110772268, 7.494787318365915, 3.5920981637069156, 6.878880321979523, 4.814146680491311, 11.943086590085711, 22.78243793760027, 35.514383043561665, 47.70160327638899, 52.8995714868818, 50.177256856645855, 50.54953438895089, 50.77751520701817, 49.73065791811262, 48.637532574789866, 49.391589300973074, 48.26320879799979, 46.477323736463276, 45.632589544568745, 46.97597163064139, 45.137019702366416, 45.46509974343436, 45.5473837852478, 45.668098313467844, 46.90678146907261, 48.07250159127371, 51.06821393966675, 50.52542066574097, 44.97562347139631, 42.46158456802368, 38.70433923176357, 35.16698006221226, 36.59259755270821, 35.545278208596365, 34.6655980518886, 34.57589333398001, 34.60738604409354, 36.31418323516846, 35.74645982469831, 36.29145220347813, 35.555988856724326, 43.68111848831177, 44.07375076838902, 49.82533754621233, 41.278667654309956, 39.11110067367554, 52.38846199853079, 44.33566658837454, 44.781244141714915, 41.189946106501985, 38.31146723883492, 36.66756166730608, 35.305645261492046, 36.68227795192173, 40.66934190477644, 41.02581228528704, 42.10117455891201, 40.93020159857613, 40.81222813470023, 37.464738913944785, 38.30359492983137, 36.205037457602366, 35.93397780827114, 37.30820294788906, 40.33682196480887, 44.59707866396223, 45.02006414958409, 48.069958550589426, 45.06818042482649, 47.29322985240391, 47.50401387895857, 44.82105384554182, 39.43474081584385, 36.73436164855957, 42.36947577340262, 47.257439681461875, 48.14597531727382, 49.21093266350882, 47.913280146462576, 48.95649310520717, 47.5746214730399, 45.357041358947754, 35.157638209206716, 24.39367481640407, 14.090963244438171, 8.449831111090523, 5.104283911841256, 7.259788819721766, 5.322246730327606, 6.835084523473467, 3.4003964960575104, 1.6174259866986955, 0.7764565242188317, 0.45480723093662945, 0.22778445003288134, 1.9017045838492257, 8.031266416822161, 18.837445327213832, 23.418720960617065, 33.39436258588518, 40.76462950025286, 36.65466928482056, 19.793986456734793, 7.789812173162188, 0.5466172258768762, 0.05402665452233382, 0.004277018688818706, 0.05613114445337227, 0.019070879789069295, 0.05802509853882449, 0.045574571272092204, 0.03214482976389783, 0.026725577523133585, 0.041945358871349266, 0.0985203195097191, 0.030150072516075203, 0.02112320394787405, 0.05266773886978626, 0.09485746534275157, 0.0050688537885434926, 0.028913076035678387, 0.036703509611210654, 0.0416946266112583, 0.07044796193284647, 0.03536248353442975, 0.029029302299022675, 0.0028659003686958124, 0.007178980225164975, 0.07603030345801796, 0.005766626123139369, 0.053703247769070525, 0.2181725672313145, 0.23028504156640597, 0.20119134629411356, 0.11032176696296249, 0.12963734513946942, 0.16523061878979206, 0.1422412959592683, 0.07017517049929925, 0.19110420399478503, 0.190443148038217, 0.10067806086902108, 0.08370135897504431, 0.15890522035104887, 0.08890656395150082, 0.10320053515689713, 0.19200038590601512, 0.14659868500062398, 0.13377091261957372, 0.15576367106820854, 0.0776785532278674, 0.09870287257113627, 0.1297482449029173, 0.09603878123951809, 0.17760150640138558, 0.14109568457518304, 0.17968436463602952, 0.1633358776037182, 0.15869213321379252, 0.11596012833927359, 0.07508382853120565, 0.10271407983132771, 1.2781038688761848, 14.916453531810216, 39.04435975211007, 51.39862857546125, 45.21273422241211, 34.699265548161094, 26.53107098170689, 31.29751784460885, 23.514625208718435, 7.980377810341971, 1.0243789979389735, 0.40764101328594343, 2.503691081489835, 3.7291628888675143, 15.952115535736084, 11.587659307888575, 2.5303230924265723, 7.049847262246268, 5.659405027117048, 13.134165900094168, 22.77058952195304, 37.35469681876046, 49.879964283534456, 55.40560606547764, 50.7742669241769, 52.56852803911482, 53.96920844486782, 51.178308146340505, 50.34359673091343, 49.78239073072161, 49.29846259525844, 48.804445675441194, 44.97435542515346, 46.79220220020839, 46.27784095491682, 45.47734941755022, 45.471092564719065, 45.2940559387207, 47.83954586301531, 48.70301934650966, 52.797175884246826, 53.29569523675101, 46.87744964872088, 44.924731390816824, 40.2091383934021, 36.69901268822806, 38.87183598109654, 36.30827031816755, 36.1741874558585, 35.07090384619576, 35.49692569460188, 37.601145948682515, 36.39179808752877, 37.33101735796247, 36.6193585395813, 44.43632166726248, 46.76374932697841, 51.009376593998496, 45.299270561763215, 41.523668084825786, 53.21686792373657, 47.68179048810686, 46.106692927224294, 44.43203462873186, 40.233745438711985, 37.29137441090175, 37.744772161756245, 38.036103180476594, 41.8496219771249, 44.60620164871216, 43.04419796807425, 42.34075886862618, 41.25254590170724, 38.023714542388916, 40.47645991189139, 37.496321950639995, 37.46924134663173, 38.74778284345354, 42.364594663892476, 46.65052843093872, 47.271846771240234, 48.02013301849365, 43.97483621324812, 47.73520476477486, 50.61838756288801, 46.97185134887695, 41.3906135559082, 38.55445963995797, 44.55799157278878, 48.52623632975987, 50.42269502367292, 49.43164913994925, 48.377086298806326, 47.904250962393625, 48.42480305262974, 46.22070244380406, 37.151118074144634, 24.799322809491837, 13.409078325544085, 9.469878775732857, 9.474958777427673, 15.367483683994838, 14.641819034303937, 12.263377700533185, 12.805681994983129, 10.027252844401769, 7.878670947892325, 1.5285173803567886, 0.49215561683688847, 3.3246583087103705, 11.993328145572118, 25.656886850084575, 29.891813891274587, 38.43532930101667, 48.57979999269758, 42.22534234183175, 22.50184883390154, 8.118457623890468, 0.505174206835883, 0.1164964424180133, 0.11174204253724643, 0.11775349639356136, 0.13291192799806595, 0.10865993292203971, 0.09030236476766211, 0.07021116678203855, 0.1727820485830307, 0.1827636786869594, 0.15144847333431244, 0.2060249312115567, 0.11820649994271142, 0.10232585602040802, 0.15670203071619782, 0.20360249334147998, 0.0728339014042701, 0.10118874668010644, 0.13986406209213392, 0.1360392551869154, 0.18612067640892097, 0.10540258485291686, 0.08355860199247088, 0.12236480680959565, 0.10890991200825997, 0.12107674378369536, 0.16978935631258146], [0.07327512558549643, 0.032583818172237704, 0.02821085335952895, 0.04659675374361021, 0.018279658763536384, 0.03889141185209155, 0.06873947860939161, 0.016386607129658972, 0.02934916709948863, 0.02582932436572654, 0.05141972637336169, 0.011781914974562824, 0.06654876723353352, 0.03891548966722829, 0.030519188780869757, 0.023243244205202376, 0.032174400320010524, 0.025411295904112712, 0.03556112466113908, 0.015264842858804124, 0.014459654189912336, 0.09674815567476408, 0.0011207321554788255, 0.03599343967757054, 0.020905592678380863, 0.03183258491169129, 0.03301377188680427, 0.07348541037312575, 0.0822629461597119, 0.015604537845190083, 0.07818922546825238, 0.20631195152444498, 4.010245314666203, 21.553447519029888, 38.53881924492972, 43.122545855385916, 23.04148415156773, 26.66265422957284, 35.51413638251168, 18.046752486910137, 9.399689810616628, 1.045471123286656, 0.45742238632270266, 0.534137664096696, 1.9372239921774184, 4.355505645275116, 3.944026376519884, 4.6456146495682855, 7.168314916746957, 4.506732753344944, 6.260650455951691, 20.336123125893728, 28.22915686879839, 36.752743107931956, 44.804885387420654, 48.5566485949925, 49.46660552706037, 47.03412805284773, 48.10618993214199, 46.252170835222515, 46.837382861546104, 44.02934830529349, 45.1650139944894, 46.10733216149466, 46.20844234739031, 46.105595111846924, 46.564718178340364, 45.94962542397635, 47.14929097039359, 46.46009220395769, 46.36842809404646, 48.109677927834646, 47.62574284417288, 45.315494605473106, 43.587713854653494, 40.60502243041992, 35.690241949898855, 34.229647227696006, 34.66819320406233, 33.79556199482509, 34.5997326033456, 33.42968027932303, 34.414896624428884, 34.52577945164272, 36.785945074898855, 39.057846205575125, 44.65002046312605, 42.54092952183315, 51.09673629488264, 37.22972304480416, 34.97980948856899, 52.1030056817191, 43.49058151245117, 46.49752214976719, 39.49440152304513, 36.528166907174246, 36.50864246913365, 37.026762689862935, 34.82890503747122, 37.554151807512554, 38.779845305851524, 35.53858361925398, 35.610389777592246, 35.02318361827305, 36.59162827900478, 37.375034196036204, 37.92914955956595, 38.85102960041591, 38.82000241960798, 41.163285868508474, 43.46838549205235, 46.057266916547505, 45.75187621797834, 47.666695526668, 48.178544998168945, 45.575951303754536, 43.81357199805123, 39.37070621762957, 36.97077063151768, 36.62583426066807, 43.89639799935477, 43.8959950038365, 47.98870631626674, 45.55027770996094, 44.79883003234863, 39.47899041857038, 30.330988679613384, 21.07133460044861, 12.82838089125497, 5.738557168415614, 3.7629081181117465, 1.9707609925951277, 1.048870095184871, 4.491827130317688, 5.252886772155762, 2.039232232740947, 1.4659334357295717, 1.0239193311759403, 0.48594468725579126, 0.403101451162781, 2.9951056838035583, 12.390788555145264, 25.3423227923257, 31.459508146558488, 35.549933501652305, 32.43257556642805, 27.72380917412894, 14.284689443452017, 1.553016185760498, 0.062263160411800654, 0.04642442620492407, 0.016661868430674076, 0.03982920492334025, 0.02598729749609317, 0.013578197336755693, 0.10448026577276842, 0.02716576524211892, 0.04502633872574993, 0.00628843906036179, 0.024614648294768164, 0.07265900900321347, 0.009513208542817404, 0.053137546338673146, 0.08482409015830074, 0.05233872741726892, 0.05123928355585251, 0.010730061863016869, 0.06070269950266395, 0.040977018153561015, 0.03673463061984096, 0.016960968363231847, 0.08136766670005662, 0.021246951771900058, 0.07368850268955741, 0.009032134848114635, 0.026775870538715805, 0.04358450270124844, 0.02888197199042354, 0.031923756269471984, 0.022378717648929784, 0.06908508363579001, 0.11734766459890775, 0.036818450050694604, 0.03239376390618937, 0.0034293083507301553, 0.01703497957039092, 0.016910741504813944, 0.07667466745312725, 0.07574092862861496, 0.04538411327770778, 0.06227189315749066, 0.0969341489087258, 0.02529253700881132, 0.054292494364614995, 0.01878123015298375, 0.08784851072622196, 0.02427447324485651, 0.09509523758398634, 0.06791068879621369, 0.05338137450494936, 0.013393206638284028, 0.009067072616224843, 0.04297349548765591, 0.06810061074793339, 0.033204572541373115, 0.018397645825254064, 0.010916509715441083, 0.33746887583817753, 6.156869556222643, 26.611852475575038, 45.4629145349775, 47.34667887006487, 25.410918882914952, 25.80350078855242, 33.02981145041329, 19.993986879076274, 9.175071052142552, 1.2738175903047835, 0.27110152851258007, 0.7697442386831556, 1.2969756105116435, 5.353641731398446, 4.799505523272923, 7.404947979109628, 7.423391103744507, 4.123055398464203, 10.555877872875758, 21.001604216439382, 32.31651285716465, 39.662294319697786, 49.43594660077776, 49.661863803863525, 52.608785901750835, 49.557751996176584, 49.790381159101216, 47.99470261165074, 47.98156704221453, 45.92650876726423, 46.2572534424918, 47.12804337910244, 47.72097832815987, 47.526050090789795, 47.15787546975272, 47.07798160825457, 47.02514403206961, 47.00335448128836, 47.328186239515034, 50.59298842293875, 48.913643564496724, 46.602158546447754, 46.18734761646816, 41.36764975956508, 36.327471664973665, 35.67062023707798, 35.74833236421858, 35.604122502463206, 36.21983017240252, 35.0984673500061, 35.96998337336949, 36.37684556416103, 37.835772718702046, 40.34768199920654, 45.58713790348598, 45.39010088784354, 51.65663603373936, 40.07536472593035, 37.3902507509504, 51.713646003178184, 45.35372012002127, 48.23063216890608, 41.85092823845999, 38.84384863717215, 37.430223737444194, 38.43805646896362, 36.845637048993794, 38.33562959943499, 41.0383676801409, 38.32081604003906, 38.430031299591064, 37.60821574074881, 37.43650490897042, 38.05774334498814, 38.98425088609968, 39.41719661440168, 40.97148084640503, 42.85284110477993, 46.135677337646484, 46.56735501970564, 47.99202755519322, 47.35033362252371, 49.511685439518516, 46.85830736160278, 46.2881555557251, 42.08104910169329, 38.25810159955706, 39.72883721760341, 45.444918700626914, 45.82185500008719, 49.234646865299766, 47.28854676655361, 46.95977190562657, 42.65244810921805, 35.908814907073975, 27.005318539483206, 15.797721351896014, 6.31131454876491, 3.8577875069209506, 3.1250283122062683, 3.0675740923200334, 5.2423394066946845, 3.5161241718700955, 2.0601964678083147, 1.6717453747987747, 0.5046775192022324, 0.48965849940265926, 0.29184008283274515, 3.3797338562352315, 13.099415353366307, 26.787223270961217, 33.73963247026716, 38.9311979157584, 39.96023654937744, 33.53150265557425, 15.933577741895403, 2.734642037323543, 0.1665796956845692, 0.0332106556078153, 0.022502005765480653, 0.03490619248311434, 0.040470227133482695, 0.012332841304929128, 0.025038276366623383, 0.020492653229406903, 0.026754116706017936, 0.016394819099722163, 0.06284436636737414, 0.02792633853719703, 0.06135110756648438, 0.04259196203202009, 0.02552630758977362, 0.04152876211862479, 0.059826724364289215, 0.09589682492826666, 0.07405738825244562, 0.02169745831218149, 0.026631637742476802, 0.039694162883928845, 0.03115868428722024, 0.07024426572024822, 0.05292950410928045, 0.05497593179877315, 0.04329057150919523, 0.14323825389146805, 0.1693595586610692, 0.11963504685887269, 0.14772125333547592, 0.11414117951478277, 0.18921406327613763, 0.09641044879598276, 0.07040926508073296, 0.1257542927882501, 0.09396782450910125, 0.220106446317264, 0.13152300752699375, 0.12831949442625046, 0.13331383786031178, 0.09869626364005463, 0.19458815561873571, 0.1462606117129326, 0.204200893374426, 0.12939711660146713, 0.14080029114016465, 0.09552551699536187, 0.20033442441906246, 0.13119629291551455, 0.13037686688559397, 0.11732019750135285, 0.11899123926247869, 0.12284159979649953, 0.12117722124925681, 0.21351005456277303, 0.08435917153422322, 0.16258995048701763, 0.4202635559652533, 6.3861401336533685, 29.697448457990372, 51.2946765763419, 54.25302498681204, 32.385254859924316, 34.84329128265381, 43.952633244650706, 24.796732868467057, 11.743711505617414, 1.8203037232160568, 0.8262966041054044, 1.0704711760793413, 3.704177600996835, 9.488578983715602, 9.980372479983739, 11.062906163079397, 11.420067020824977, 6.3066427537373135, 9.462308713368007, 25.287296533584595, 34.056737831660676, 41.570617062704905, 50.284627369471956, 51.20337724685669, 53.99093198776245, 48.900706018720356, 49.27776738575527, 47.98859861918858, 48.419730867658345, 48.032987185886924, 45.835734026772634, 48.561349051339285, 47.65057223183768, 47.873053550720215, 47.211355754307334, 46.86614840371268, 48.02956172398159, 47.23733854293823, 48.35523074013846, 52.004382950919016, 51.38815764018467, 47.804916041237966, 48.36877972739083, 43.8164416040693, 37.74301079341343, 36.52595043182373, 38.12520340510777, 36.940976755959646, 38.01114525113787, 36.38228600365775, 37.70913485118321, 37.74742637361799, 39.586499895368306, 42.86222117287772, 46.70076390675136, 47.419245856148855, 54.570043495723176, 41.914351395198274, 41.46348278863089, 54.13973460878645, 47.67827122552054, 49.70497390202114, 44.239197799137656, 41.37870781762259, 39.86380597523281, 41.0550468308585, 38.24424689156668, 40.23429087230137, 41.577655587877544, 38.62803758893694, 39.77651923043387, 38.64380305153983, 39.24627440316336, 40.487663882119314, 41.582151072365896, 41.406170572553364, 42.85094772066389, 44.02205269677298, 48.34618418557303, 48.49987486430577, 48.657612868717735, 48.50316136223929, 50.56227043696812, 49.263151850019185, 47.93917260851179, 43.59524917602539, 40.11252021789551, 40.2224302973066, 47.60411310195923, 48.11708470753261, 50.892462730407715, 47.23694249561855, 47.82803269795009, 45.819475242069785, 38.45146649224417, 28.090594155447825, 16.46851086616516, 8.134407213756017, 6.881211008344378, 6.154739499092102, 10.392352887562343, 18.821408884865896, 13.849812984466553, 9.56100961140224, 6.689266588006701, 1.9072498977184296, 1.9145463747637612, 0.9232076896088464, 5.157053743089948, 16.657487971442087, 32.65115547180176, 41.281617164611816, 47.50930493218558, 46.88416855675833, 38.01653357914516, 17.45369941847665, 2.753431703363146, 0.17606991715729237, 0.1580117525798934, 0.10184883911694799, 0.14584346195416792, 0.11766154132783413, 0.12918217027825968, 0.1535858450723546, 0.09069371662501778, 0.10752631803708416, 0.0873835174632924, 0.10077551206839935, 0.15070607459970883, 0.13323626773697989, 0.13300849710191998, 0.16582744462149485, 0.15779443138412066, 0.14260252086179598, 0.15899311777736458, 0.22323624337358133, 0.16387570649385452, 0.223491331828492, 0.12094753714544432, 0.19221407015408787, 0.1483340518815177, 0.22188473732343741, 0.1090532321748989, 0.12616803630122117], [0.05715415134493794, 0.011494067697120565, 0.06154662064675774, 0.014236555268455828, 0.07268217418875013, 0.08127604411648852, 0.05515200824343732, 0.04334091880757894, 0.08019092412931578, 0.022966963405321752, 0.03358146821015647, 0.06334173932139363, 0.017596099193074873, 0.027720104603629028, 0.03823851188644767, 0.00972305313085339, 0.04496237662221704, 0.02591466371502195, 0.008242868851604206, 0.05068740388378501, 0.015665697599095956, 0.02283652183333678, 0.022355684777721763, 0.004957757249940187, 0.06362704294068472, 0.03997811621853283, 0.029330324182020764, 0.012175777411487485, 0.05992279135222946, 0.09433022327721119, 0.06869869186942067, 0.04854530275666288, 1.199927406651633, 13.266965082713536, 30.702686037336075, 37.078168937138145, 41.20635427747454, 32.174053941454204, 32.14377021789551, 25.51386513028826, 11.51792197568076, 3.8075828637395586, 0.3961046966058867, 0.834305542920317, 1.289457333939416, 1.792467611176627, 3.1208965224879126, 7.071156084537506, 5.965735469545637, 0.35076927500111715, 5.1503760899816236, 7.395068509238107, 16.823978969029017, 27.690033980778285, 38.71937165941511, 45.61658089501517, 50.82705238887242, 48.41397081102644, 47.246934005192344, 46.93235083988735, 48.16837630953108, 47.77304812840053, 48.53306640897478, 46.33224534988403, 46.65825482777187, 47.06133025033133, 47.58791337694441, 45.611630303519114, 47.772999491010395, 45.91750737598964, 45.075319698878694, 46.0324444770813, 48.15622738429478, 45.347848892211914, 45.9375181879316, 41.758260113852366, 38.12093373707363, 35.955961908612935, 36.23615843909127, 34.766103744506836, 35.17376845223563, 35.70867204666138, 33.79873384748186, 35.01705183301653, 41.75872564315796, 44.03570590700422, 45.946064472198486, 43.49799524034773, 51.773890359061106, 36.69420453480312, 33.165766852242605, 53.191538265773225, 42.76440095901489, 45.207738467625205, 39.85183422906058, 38.49851621900286, 35.073961053575786, 34.93534101758684, 31.948119367871964, 39.033475399017334, 35.31028665815081, 32.683593136923655, 34.84866224016462, 35.42804472787039, 38.81439522334507, 41.15743548529488, 43.644268717084614, 44.14376776559012, 43.885051591055735, 44.32810694830758, 44.36990731103079, 47.302804470062256, 45.21046563557216, 46.378860814230784, 46.53630352020264, 46.05862528937203, 44.039569105420796, 41.4659355027335, 37.015982559749055, 37.43324967793056, 40.369481972285676, 45.00378452028547, 45.213175433022634, 46.22443362644741, 41.47294276101248, 35.85713768005371, 23.02853618349348, 15.768221037728445, 7.153466616358076, 2.1182916590145657, 1.328194409608841, 3.210430358137403, 3.799780470984323, 2.571123783077512, 2.1271106600761414, 1.3319184269223894, 0.6564908815281731, 0.455716929265431, 0.25487810905490604, 0.9457932433911732, 6.441579810210636, 16.053124972752162, 25.78413963317871, 27.5183196749006, 36.0225430216108, 29.380996227264404, 18.293057441711426, 6.983058571815491, 0.44977136115942684, 0.02801675332843193, 0.012186085206589528, 0.026294226026428596, 0.05589650025857346, 0.03084816291396107, 0.04079787812328764, 0.02746502123773098, 0.057828323383416445, 0.04478154703974724, 0.055788782824363024, 0.04807710341577019, 0.05309972818940878, 0.04740266674863441, 0.027871456928551197, 0.03365796964083399, 0.09496347286871501, 0.01954611553810537, 0.04110667262492435, 0.016743696361247982, 0.04643895363967333, 0.059526676179042885, 0.05560603638046554, 0.025310735318011472, 0.04020874348602124, 0.01705319993197918, 0.04464681373376932, 0.028234988850142275, 0.009695198420169098, 0.018181566348565475, 0.015214995979996664, 0.04059849739340799, 0.0363447851102267, 0.0161502360632377, 0.055588017883045335, 0.01965897117874452, 0.05230355216190219, 0.04449084567438279, 0.01720298144833318, 0.027608449969972883, 0.05875795028571572, 0.02965144087959613, 0.020107029903946177, 0.00405782346414136, 0.048043750026928525, 0.08251912705600262, 0.006674875779676118, 0.05008647291521941, 0.01681750570423901, 0.042921607914779863, 0.014497760716559631, 0.012844438049277025, 0.0452209425690983, 0.012298051966354251, 0.021209366020879576, 0.025096803404656903, 0.04789683023201568, 0.04280222307092377, 0.08491379927311625, 0.038375464001936574, 1.9750810350690569, 16.599797078541346, 37.591633864811485, 42.68229062216622, 41.29551356179373, 34.974942275456016, 32.65952457700457, 25.385309559958323, 14.672373737607684, 3.314461175884519, 0.3168283019747053, 0.0647505951513137, 1.089670785835811, 3.478853383234569, 5.6143450907298496, 5.338074292455401, 5.165043302944728, 2.3345895154135565, 7.028369511876788, 12.915641580309186, 20.470176458358765, 31.760306085859025, 42.20010301045009, 47.2468193599156, 50.544844354902, 49.178359508514404, 47.43662677492414, 46.84808656147548, 49.003383023398264, 48.59265068599156, 50.17529051644461, 48.13987479891096, 48.465231146131245, 47.77147436141968, 47.08943223953247, 46.049026353018625, 48.45999567849295, 47.133289269038606, 46.81032657623291, 46.60635525839669, 49.952698026384624, 46.82654019764492, 46.82764496122088, 43.288809299468994, 39.94849409375872, 37.352028710501536, 38.61772298812866, 35.14614241463797, 36.38081298555647, 36.76451335634504, 35.45778996603829, 36.317483629499165, 42.778491905757356, 45.51030124936785, 47.51993220193045, 45.43361745561872, 52.31354652132307, 38.68644067219326, 35.50020177023751, 54.679984842027935, 46.08111660821097, 47.61879811968122, 43.30231659752982, 39.83459227425711, 36.53376368113926, 36.75981984819685, 33.1464786529541, 39.765600136348176, 35.38724837984358, 35.17698546818325, 36.329917430877686, 36.28067902156285, 39.74686779294695, 42.20917388371059, 44.96562501362392, 44.54997335161482, 45.76803772790091, 45.6013400214059, 45.35957745143345, 47.93700129645211, 46.504515511649, 46.28600508826119, 48.3738032749721, 47.616963795253206, 46.84540803091866, 42.43881184714181, 38.58474683761597, 39.245718547276084, 43.42295816966465, 46.704880714416504, 47.02720417295183, 47.416202545166016, 44.018067904881065, 38.810302734375, 27.995603595461162, 19.211345263889857, 7.153009338038308, 2.3099802987916127, 2.5415118634700775, 2.3566919522626057, 4.171625912189484, 3.6546360765184676, 3.086575678416661, 0.8282379199351583, 0.050242400262504816, 0.2917104283613818, 0.10345451759972743, 0.8044539104614938, 6.987768147672925, 19.529779468263897, 28.361492259161814, 33.962871142796104, 41.57797867911202, 34.12009498051235, 24.37731007167271, 9.640402334077017, 0.7030997776559421, 0.021206711252619113, 0.051858416226293357, 0.030676612297871282, 0.006131118171781833, 0.020575134249936258, 0.04155683989769646, 0.05533532465675047, 0.0704915781638452, 0.055685652286878655, 0.026191943657717535, 0.06616674523268427, 0.039731519629380534, 0.07981071381696633, 0.05834823048540524, 0.010679058930171388, 0.09784723312727042, 0.05337701152477946, 0.03484052725668464, 0.03372974507510662, 0.03757281814302717, 0.10813404114118644, 0.012863566799621497, 0.05608423732753311, 0.0340499491430819, 0.014006018755026162, 0.03069554003221648, 0.0230997001220073, 0.10559412850333111, 0.10966598322348935, 0.14827436794127735, 0.1724053259406771, 0.29868294564741, 0.16716415860823222, 0.10382290783205203, 0.0878409111340131, 0.23983449914625712, 0.12683941956077302, 0.17860453043665203, 0.13436840341559478, 0.13952046552939074, 0.1012396232358047, 0.08485785406082869, 0.11651630992335932, 0.0910078240558505, 0.23410646936723165, 0.0932688723717417, 0.1515745451407773, 0.09694341769708054, 0.09366977121680975, 0.060983036245618544, 0.12081119231879711, 0.15950756945780345, 0.17134463999952587, 0.15684037043579988, 0.09951041066753012, 0.1564903956438814, 0.2490221889955657, 0.2439356462231704, 0.1357576631541763, 2.248111584356853, 19.28346582821437, 41.630705084119526, 49.764610290527344, 51.385732718876426, 42.02461930683681, 40.383065700531006, 33.6299204145159, 16.414839506149292, 4.298802699361529, 0.6725470828158515, 1.686499765941075, 3.1514075824192593, 6.403939247131348, 8.414083497864858, 14.305048533848353, 11.920244387217931, 2.51775575535638, 6.74259444645473, 10.781557968684606, 19.44138969693865, 30.67388575417655, 43.52592005048479, 48.306461334228516, 51.081717763628276, 49.41926745006016, 47.423258440835134, 48.36920356750488, 49.685557161058696, 49.57250649588448, 52.044487953186035, 49.13033355985369, 49.19500044413975, 49.44148431505476, 49.51916170120239, 46.58687250954764, 48.228572028023855, 46.97185482297625, 47.58118404660906, 46.58147723334176, 50.474455629076274, 48.072647503444124, 50.09740815843855, 45.3478593145098, 40.87191316059658, 39.6304646219526, 39.97230904442923, 37.00107172557286, 38.20718172618321, 39.539196559361045, 35.98480388096401, 38.53631441933768, 45.22900342941284, 47.76347698484148, 49.571728297642295, 47.33079528808594, 53.00845670700073, 41.1026246207101, 38.65162672315325, 54.41350405556815, 48.459887981414795, 48.55988992963518, 44.833491121019634, 41.66926063810076, 38.559500558035715, 37.93634441920689, 35.47221095221383, 40.826117583683555, 37.78382451193673, 36.642551626477925, 38.5684255191258, 37.58612394332886, 41.126439571380615, 43.888230391911094, 46.913764408656526, 45.949656690870015, 46.207177775246755, 47.67685031890869, 46.858884062085835, 49.84500094822475, 47.141839027404785, 46.38455833707537, 47.706592082977295, 48.210124560764854, 49.74608986718314, 44.97114883150373, 41.226253918239046, 41.372332845415386, 44.88225357873099, 48.404740129198345, 48.3332952771868, 47.58478668757847, 47.57151215417044, 42.30939817428589, 29.595549651554652, 20.374907970428467, 9.141776153019496, 4.545792485986437, 5.417748417173113, 9.858564479010445, 12.889377389635358, 8.62851619720459, 7.005374448640006, 5.7786734615053446, 1.5675274985177177, 1.4375062925474984, 1.1492034941911697, 1.6729820455823625, 9.385241900171552, 22.367920569011144, 34.95398303440639, 38.36916855403355, 47.08138969966343, 40.73211540494646, 28.111322368894303, 9.860434412956238, 0.927925625017711, 0.15149584864931448, 0.11268000863492489, 0.12397065492612974, 0.21391782696757997, 0.13222147790449007, 0.19118356545056614, 0.12120790460280009, 0.1639781245695693, 0.19404013002557413, 0.10819417969988925, 0.21909906608717783, 0.1640932448208332, 0.13817296283585684, 0.11751911682741982, 0.12698343183313096, 0.1452302834285157, 0.12895552601133073, 0.10458173389945712, 0.10123682767152786, 0.13824935230825627, 0.20407015324703284, 0.10246741199599844, 0.10554619678961379, 0.11411949353558676, 0.11510132013687066, 0.1666894012263843, 0.08394426772637026], [0.03342807858384081, 0.054125472969774685, 0.019611716303708296, 0.020003307344658033, 0.021959807091791714, 0.04923163414267557, 0.03830685054085084, 0.03892523682277117, 0.030540820477264266, 0.044246671455247064, 0.050962027361882586, 0.05331863037177494, 0.05755991528608969, 0.04596026075471725, 0.06701932448361601, 0.014084213130575205, 0.03496698582811015, 0.06275567505508661, 0.05290998944214412, 0.04757316563544529, 0.026712458048548018, 0.0643768444923418, 0.018326489554185952, 0.04192437517589756, 0.004151011343180601, 0.07447615292455469, 0.035391599472079954, 0.025355705226372396, 0.099750442430377, 0.031390163116157055, 0.06712474168411323, 0.03903709671327046, 0.4181771422071116, 4.884095498493739, 23.49576084954398, 42.030108383723665, 40.2630147252764, 30.50372784478324, 19.700286524636404, 25.273737124034337, 15.076044968196324, 5.972242023263659, 1.1325330287218094, 0.5357750505208969, 0.4634887065206255, 3.654818900993892, 5.8248390299933295, 3.7867482560021535, 3.0345753601619174, 2.5491279576505934, 2.932684153318405, 4.0626972658293585, 11.11295143195561, 21.532269409724645, 31.868975911821636, 41.57295513153076, 47.67751734597342, 46.07781968797956, 47.590432098933626, 49.636395181928364, 50.24070085797991, 47.50727258409773, 49.00479698181152, 47.669846534729004, 49.34380306516375, 47.101577690669465, 49.63136468614851, 46.9320833342416, 46.73685285023281, 43.48030512673514, 46.90055588313511, 46.19750588280814, 47.88034568514143, 48.13729006903512, 46.266449383326936, 44.44397510801043, 41.38532945087978, 36.70386600494385, 34.77706800188337, 38.02072334289551, 40.69815608433315, 37.501296860831125, 38.62129783630371, 36.593090874808176, 45.71406759534563, 44.27921594892229, 48.37982388905117, 43.344248976026265, 52.879032611846924, 43.87102665219988, 30.385712691715785, 52.68976020812988, 42.560037067958284, 47.24792064939226, 42.54048831122262, 39.462158407483784, 34.54826382228306, 35.803615706307546, 38.635294982365195, 34.100455897195, 34.11543621335711, 35.1257563999721, 36.008629253932405, 39.49032293047224, 39.1095929145813, 41.98501457486834, 44.02539825439453, 45.08624574116298, 45.45244359970093, 46.91511583328247, 48.26611661911011, 46.56757388796125, 45.29215213230678, 46.03778764179775, 45.445874077933176, 46.84337568283081, 43.712037972041536, 41.70754868643624, 38.1463954108102, 39.430610111781526, 41.24092503956386, 43.29955121449062, 46.50433138438633, 46.49570172173636, 40.278001989637104, 30.58175958905901, 19.283616951533727, 8.274462921278817, 1.5621569752693176, 0.7009937678064618, 1.3726849194083894, 0.1375846051211868, 0.7074643320270947, 2.6265864755426134, 2.0152896089213233, 0.5741862122501645, 0.0795813011271613, 0.24054967505591257, 0.3536452321069581, 2.023421172584806, 6.591173657349177, 15.217642307281494, 27.436047792434692, 29.551699570247106, 35.12878581455776, 28.2339928150177, 10.959584712982178, 2.6942334856305803, 0.15926514246634074, 0.04756952868774533, 0.05375414128814425, 0.07496204506605864, 0.02750252895722432, 0.04986348595204098, 0.05954332064305033, 0.03408350948510425, 0.011212800513021648, 0.006785720412153751, 0.031046441024435417, 0.04257284430786967, 0.029635824396141937, 0.03739408523376499, 0.02793360055823411, 0.05280459599037256, 0.05186545602711184, 0.046277659080390415, 0.016744417304705297, 0.014205581841192074, 0.060838623637599606, 0.08676079873527799, 0.03772703558206558, 0.05203472676553896, 0.07718595716037921, 0.010113334599217134, 0.007570901203767529, 0.05578318491045918, 0.05319337620000754, 0.02483448007010988, 0.02951720290418182, 0.03143158767904554, 0.027299945542056645, 0.007468746060372463, 0.024189524053196822, 0.05218373644830925, 0.020728415310648934, 0.039892820974013636, 0.04241847080577697, 0.06133366243115493, 0.03258302428626588, 0.06944260373711586, 0.01981032859267933, 0.05494162167555519, 0.011250926547550728, 0.04754666205761688, 0.023889304537858282, 0.028268676417480623, 0.009641358362776893, 0.06325838129435267, 0.03857593717319625, 0.03123351312907679, 0.0799539050619517, 0.03361611081553357, 0.012496621846886618, 0.037887963732438426, 0.027489495995853628, 0.05080767082316535, 0.08419628241764647, 0.05217984165730221, 0.4921444888625826, 6.714335688522883, 27.716735907963344, 46.39788498197283, 46.91961479187012, 35.25759499413626, 23.918956518173218, 31.045280865260533, 16.694386380059377, 7.514913644109454, 1.3358157149382999, 0.24733000408325875, 0.4415147570627076, 3.4662389286926816, 4.329986214637756, 8.685126645224434, 4.902665862015315, 3.6735447304589406, 2.9306713470390866, 5.1324640682765414, 13.28568092414311, 25.622211865016393, 34.03656373705183, 44.568448611668174, 49.20286233084542, 48.46423407963344, 49.80231121608189, 49.034125328063965, 50.837092535836355, 49.78495809010097, 50.01741702216012, 51.03029414585659, 49.680464131491526, 49.68515763963972, 49.039451122283936, 48.036892073495046, 46.47826869147164, 45.01619747706822, 48.241297653743196, 47.369142396109446, 49.09178147997175, 49.43872240611485, 48.73288270405361, 45.44458518709455, 43.44361516407558, 38.420967374529155, 38.09421443939209, 39.729660579136436, 41.71052598953247, 39.23883983067104, 39.537192004067556, 38.60160664149693, 45.78409848894392, 45.77783121381487, 50.265273162296836, 45.5037282535008, 50.799600056239534, 43.793509074619834, 33.84884425571987, 53.153472559792654, 45.76823575156075, 48.71022810254778, 44.599142278943745, 40.242920534951345, 35.53445986339024, 37.91141428266253, 39.59654004233224, 36.59934772763933, 35.256448541368755, 36.690348284585134, 36.51319006511143, 40.47872155053275, 41.671101910727366, 44.30723108564104, 46.374170780181885, 46.5878278868539, 46.69261714390346, 47.489707538059776, 49.65854951313564, 47.559682846069336, 45.97491339274815, 47.42529426302229, 47.13444267000471, 47.67571428843907, 45.8329929624285, 43.267818791525706, 39.07551200049264, 41.45628098079136, 43.2395396232605, 44.966048853737966, 47.75442348207746, 46.890672070639475, 41.949168818337576, 34.11385897227696, 21.430724961417063, 10.471986191613333, 4.498759695461818, 2.185142231839044, 1.3424916309969765, 0.9703600108623505, 0.9760042279958725, 0.6494111557091985, 0.5308920411126954, 0.24985795414873532, 0.056313683944089074, 0.12030216891850744, 0.20557328473244393, 2.4882471902029852, 8.910750286919729, 18.712815489087784, 32.577362128666465, 33.84731217793056, 40.9199286869594, 34.00936501366751, 14.767470257622854, 3.6434529508863176, 0.1954809855669737, 0.02227805188990065, 0.030836329263235842, 0.012968476795192276, 0.06776145858956234, 0.012977691300745522, 0.012381746716398214, 0.02485586579756013, 0.0370159003484462, 0.0448692205495068, 0.026829310260447006, 0.0537894081457385, 0.03365270760176437, 0.01254607517538326, 0.050133766806019206, 0.03601570919688259, 0.03764881745779088, 0.061988292661096366, 0.04655947842236076, 0.0353468975850514, 0.027750971161627343, 0.02657702754783843, 0.019574909171621715, 0.013923077178852898, 0.011659403780608304, 0.05563815144289817, 0.06921990854399544, 0.07118700870445796, 0.15646466559597424, 0.10628846660256386, 0.12155452743172646, 0.12970152098153317, 0.1383090226777962, 0.09601501215781484, 0.09661770053207874, 0.16365690609174116, 0.05910460025604282, 0.14820769509034498, 0.14855192947600568, 0.21233670466712543, 0.1944642686950309, 0.13679333829454013, 0.1089132639712521, 0.09451294597238302, 0.10215659546000616, 0.16144725680351257, 0.12463167017059666, 0.18037959161613668, 0.10921460815838405, 0.13295927617166722, 0.09612155572644301, 0.1555204162640231, 0.11204410597149815, 0.1236045445714678, 0.0802825331421835, 0.1564797969268901, 0.16311497374304704, 0.11881137319973537, 0.13129172208053724, 0.14714468855942997, 0.6192806724991117, 7.521797571863447, 32.224741050175254, 54.787817410060335, 52.027371065957205, 41.2495790209089, 30.442972796303884, 34.57003600256783, 21.29397225379944, 8.932316626821246, 1.9360425812857491, 0.7754338905215263, 1.7458130632128035, 10.171860490526472, 10.937062995774404, 12.85645248208727, 7.159216250692095, 5.088299146720341, 5.069433484758649, 5.421957288469587, 12.636604530470711, 24.267043897083827, 33.2869747025626, 43.67060933794294, 50.48585762296404, 49.07299355098179, 50.80084030968802, 50.40030792781285, 52.10103586741856, 51.59522785459246, 51.361525194985525, 52.48668868201119, 51.725996426173616, 50.29666512353079, 51.02492666244507, 50.02110998971121, 47.042615277426584, 46.57096113477434, 49.10174867085048, 47.73912007468087, 49.33488852637154, 51.32798971448626, 49.579010009765625, 47.86982611247471, 45.89849015644619, 41.05141292299543, 39.34630414417812, 41.6662312235151, 44.30174895695278, 40.790754726954866, 41.23532479149954, 40.488164152417866, 48.86583995819092, 49.10308619907924, 51.16822631018502, 46.59298345020839, 51.664279052189414, 44.65216050829206, 38.87300327845982, 52.80469730922154, 46.57646063395909, 51.49118900299072, 46.59583568572998, 42.250689370291575, 37.839323248182026, 39.41288873127529, 41.50711400168282, 36.92370353426252, 37.64363070896694, 37.75760548455374, 39.1399495942252, 42.51685053961617, 41.49699395043509, 44.178366320473806, 48.82601983206612, 48.5189094543457, 48.2906368119376, 48.63376317705427, 51.26912457602364, 48.61412756783621, 45.690600054604666, 46.99036829812186, 49.29082652500698, 49.216279302324565, 47.34379536764962, 44.82373237609863, 40.97921071733747, 44.54459892000471, 45.31997619356428, 46.32016590663365, 49.957853589739116, 49.06416933877127, 42.32406234741211, 36.00484248570034, 23.43376554761614, 10.298045856612069, 2.740285494497844, 2.0610656440258026, 4.833192127091544, 3.897163382598332, 3.2319289531026567, 6.217993293489728, 6.75987548487527, 1.7604209993566786, 0.2858872136899403, 0.6860251224466732, 0.7529837723289217, 2.858784850154604, 10.811388322285243, 21.749249492372783, 39.193763392312185, 40.65821783883231, 45.707348687308176, 37.668143953595845, 16.603340659822734, 4.325892422880445, 0.4153436342520373, 0.09965610570673432, 0.1595238135861499, 0.1721450806196247, 0.1586472684783595, 0.15779620914586953, 0.1933456358632871, 0.1776686135147299, 0.08599068184516259, 0.21258958109787532, 0.1383804181324584, 0.13387160721634114, 0.16020620268370422, 0.1092408946050065, 0.13778203167021275, 0.10412045900842973, 0.18486227893403598, 0.12960579326110228, 0.1230362986347505, 0.08550869806536607, 0.19679731636175088, 0.24333839969975607, 0.08991844286876065, 0.09200449021799223, 0.1092958627268672, 0.16972083784639835, 0.1435106314186539, 0.14988229237496853], [0.04801884779174413, 0.019500383974186013, 0.022501622393195118, 0.06071689445525408, 0.0023716149610533777, 0.04452059943495052, 0.03546378542003887, 0.042993559768157344, 0.05968377060656037, 0.04855705498318587, 0.05196998095405953, 0.03491288283839822, 0.09159357619604894, 0.025851500586473515, 0.04166039451956749, 0.03093974817810314, 0.02685071125493518, 0.01995461736805737, 0.013825572544841893, 0.03711908856140716, 0.02809617924503982, 0.06562286548848663, 0.026685706805437803, 0.05240810423025063, 0.035733574336128573, 0.016706365060859492, 0.06314192432910204, 0.03843260682853205, 0.07658287523580448, 0.05472570504727108, 0.04325897213337677, 0.05629117015217032, 0.035999560063438754, 1.0503104350396564, 9.260867408343724, 29.990655490330287, 39.48221785681588, 30.20903389794486, 15.663351876395089, 20.39790824481419, 22.91536045074463, 8.873402850968496, 3.027085853474481, 0.15686517767608166, 0.3433923237025738, 1.9883334210940768, 4.5664955122130255, 4.548618231500898, 3.842996094908033, 3.4921081577028548, 1.1689420236008508, 1.6534912628786904, 5.5625662463051935, 13.500718985285078, 24.307866300855363, 35.76623092378889, 41.49958215441023, 49.32625191552298, 51.13321781158447, 50.54762710843767, 49.553044591631206, 48.741984844207764, 46.61648920604161, 47.0660446030753, 46.55799232210432, 47.702888693128315, 48.46859060014997, 47.33035407747541, 44.71966225760323, 43.72308908190046, 47.62479788916451, 46.27284172603062, 47.846195289066856, 48.24858978816441, 46.29143510546003, 44.4028000831604, 45.77128601074219, 43.451233863830566, 39.487470694950645, 36.553010191236226, 40.48632287979126, 37.7589499609811, 39.042112009865896, 37.8443398475647, 45.24007885796683, 45.55688892092024, 51.222477844783235, 45.340654032570974, 56.86677401406424, 44.427302905491416, 28.653426034109934, 52.46150146211897, 43.46862520490374, 45.745848655700684, 43.75930309295654, 44.21668216160366, 34.29339000156948, 39.34952463422503, 34.756310258592876, 33.05445671081543, 33.73269469397408, 34.61792646135603, 40.2444943019322, 42.06495359965733, 46.19167981828962, 46.527878829411094, 46.551488808223176, 47.446180547986714, 46.18305710383824, 45.98477636064802, 46.450274399348665, 44.963047231946675, 48.13394103731428, 45.08188227244786, 44.271079608372276, 46.4972094808306, 44.24812970842634, 42.434934752328054, 41.95922980989729, 39.98867900030953, 42.31916734150478, 43.25363057000296, 45.400981766836985, 44.57305874143328, 35.29759577342442, 21.77901210103716, 10.689774002347674, 3.5290897275720323, 1.2409509824854987, 1.1372076464550835, 3.9163686377661566, 3.9398379155567715, 1.5751238337584903, 0.6346676754099982, 0.10685908062649624, 0.043847733576382907, 0.06547785576965127, 0.1314124334603548, 0.4651569255760738, 4.0606957503727505, 12.013096639088221, 24.00173388208662, 24.074003832680837, 28.44514857019697, 30.093308176313126, 18.03721261024475, 6.52656626701355, 0.529919510441167, 0.10433242656290531, 0.02106603397987783, 0.04180468838395817, 0.027715285308659077, 0.026522057729640176, 0.033034243288316896, 0.05495165042313082, 0.07764329654829842, 0.03007395106500813, 0.04313608265614935, 0.0657317703589797, 0.09413010294416121, 0.010633376560040882, 0.05756672777767692, 0.10100033107612814, 0.028461585619619915, 0.03013794370261686, 0.0352651680420552, 0.0335056487071727, 0.01838852801094098, 0.05701623910239764, 0.026192011511219398, 0.08467057839568172, 0.045538415533623526, 0.021149276655965617, 0.01480121854027467, 0.04210304023165788, 0.05708635212587459, 0.023562666261568666, 0.026984671030991843, 0.05438538920134306, 0.036664934895400486, 0.0764716701315982, 0.08027265367231198, 0.05787718469010932, 0.053228710911103656, 0.050350005738437176, 0.07147062277155262, 0.05743762291967869, 0.0506936837253826, 0.03056129187877689, 0.032917691328163655, 0.08655610507620232, 0.018570368610588566, 0.023438874332766448, 0.10563294070639781, 0.004994250983665032, 0.07134547377271311, 0.055427432392856905, 0.10255294133509908, 0.025541242145534073, 0.00735244685451367, 0.031747832495187006, 0.008084412265036787, 0.01811486465989479, 0.04406603525525757, 0.033895243158830066, 0.05903405297015395, 0.030654295281107937, 0.051967405913663764, 0.08165379134672028, 1.6238191979272025, 14.0409448998315, 34.95901353018624, 44.06850140435355, 36.47514867782593, 18.1491185597011, 22.52256488800049, 26.00578543118068, 10.30679624421256, 3.2364789375237057, 0.1436905517641987, 0.24137496362839425, 1.146102100610733, 4.251574490751539, 3.18537580541202, 4.3652544021606445, 5.824570221560342, 0.4897710276501519, 1.458410490836416, 6.610081442764827, 18.042230946677073, 27.54189317567008, 39.25082547324044, 44.32687016895839, 50.37625673839024, 50.67267731257847, 53.568717752184185, 51.305769375392366, 50.870638438633506, 48.353976590292795, 50.053485121045796, 47.578460352761404, 49.06778587613787, 49.88065562929426, 48.5752523967198, 46.22312389101301, 44.9246688570295, 47.05287776674543, 45.43907526561192, 48.84298038482666, 49.01879760197231, 47.20910106386457, 47.376636028289795, 46.18753521783011, 44.26744570050921, 39.247195039476665, 37.389278003147666, 42.374950953892295, 40.64364051818848, 40.695929186684744, 39.29156970977783, 48.70095920562744, 46.72288697106497, 51.86978244781494, 46.759719371795654, 54.23689474378313, 47.41110951559884, 32.04521002088274, 52.51493310928345, 45.72176619938442, 48.67867980684553, 44.790349755968364, 44.337282044546946, 35.36274903161185, 40.49841969353812, 36.745857443128315, 34.261925084250315, 35.71559592655727, 35.639690331050325, 41.377936567579, 44.26956490107945, 47.05693898882185, 47.97092587607247, 48.08199977874756, 49.905613558632986, 47.38061734608242, 47.740985666002544, 47.31472757884434, 45.570093972342356, 48.534046104976106, 45.53028079441616, 46.926034927368164, 47.96959529604231, 46.25473124640328, 44.3149470601763, 43.48851442337036, 41.7127285684858, 43.91525541033064, 45.0219783782959, 48.108861514500205, 46.93364667892456, 38.35328149795532, 25.15034406525748, 13.93730730669839, 4.971322315079825, 2.305802260126386, 2.873740630490439, 3.2033751138619015, 4.0907041515622815, 0.3696212576968329, 0.436166951166732, 0.1622936613857746, 0.03306678243513618, 0.023721457026632767, 0.20052410209817545, 0.5579290560313633, 4.211430839129856, 11.137713074684143, 23.22610821042742, 30.484967708587646, 34.02796881539481, 35.62684311185564, 21.902905430112565, 8.98197887625013, 0.9062841577189309, 0.1340337770857981, 0.034196041125272, 0.06222875190100499, 0.017544349023540105, 0.06061357392796448, 0.08848182138587747, 0.0042821988796017, 0.028501575080943958, 0.10918239810104881, 0.06894186524940388, 0.05218318683494415, 0.006666586626254554, 0.025164329513375248, 0.07010676059871912, 0.030060617851891687, 0.020790336720113243, 0.09779321495443583, 0.009539133669542415, 0.007468316886973168, 0.02311308422525014, 0.0390847705836807, 0.046990198881498406, 0.04675945287038173, 0.057372198573180606, 0.07987905586404459, 0.04624906900737967, 0.04073818061234696, 0.023638735126171793, 0.09394344474588122, 0.08788428309240512, 0.11471295383359705, 0.17148038771535667, 0.12426173287842955, 0.14460814824061735, 0.14656857161649636, 0.14222403402839387, 0.12455363864345209, 0.13126766122877598, 0.08770725330603973, 0.08979806397110224, 0.262486820774419, 0.1271026504359075, 0.1710589767566749, 0.14921226618545397, 0.08399025204458407, 0.15785467172307627, 0.11973749207598822, 0.1962764321693352, 0.1750519382102149, 0.17209163920155593, 0.06471492456538336, 0.10338803473860025, 0.07515016889997891, 0.14013228698500566, 0.20133070381624357, 0.15359606380973542, 0.13980057835578918, 0.11961889772542886, 0.10197427310049534, 0.1465439000832183, 0.1571154756737607, 1.8135327036891664, 16.053661721093313, 40.11750555038452, 53.7709242275783, 41.63857044492449, 22.578334603990825, 29.05424850327628, 30.723349979945592, 11.693850364003863, 4.329879820346832, 0.41300521258796963, 1.3238006510904856, 4.184307243142809, 11.948434965951101, 9.812178305217198, 12.62910829271589, 9.689798814909798, 3.3064162475722174, 5.096503232206617, 7.937216469219752, 18.21226031439645, 27.250489200864518, 40.65323598044259, 45.125245979854036, 52.25435829162598, 52.56466484069824, 54.77703033174787, 51.859881264822825, 51.868840966905864, 48.903318541390554, 51.412952286856516, 47.74075984954834, 51.0674010004316, 52.28484698704311, 48.89607851845877, 46.878804547446116, 46.11835200445992, 47.750984123774934, 47.437099252428325, 49.13564198357718, 50.83245808737618, 49.19375671659197, 49.895455292293, 48.23986979893276, 47.02220146996634, 42.69267817905971, 39.65337978090559, 42.83832631792341, 42.96396711894444, 41.707048416137695, 41.22735868181501, 49.53331865583147, 50.07250234058925, 53.99614661080496, 48.504127161843435, 54.538957255227224, 50.36208241326468, 34.323982919965474, 51.91089493887765, 46.407063552311485, 50.33546386446272, 48.0156375340053, 46.81209141867501, 36.809568950108115, 41.92829295567104, 37.58288608278547, 35.406310762677876, 36.36430753980364, 36.169459206717356, 44.27869830812727, 45.82217114312308, 48.72861303601946, 50.463995116097585, 49.688763754708425, 49.81035028185163, 47.80985968453543, 48.39604445866176, 45.87763513837542, 44.64476415089199, 48.77445377622332, 46.310344627925325, 49.64959675925118, 50.4577625819615, 48.57151426587786, 45.98850059509277, 45.65503222601754, 44.654724393572124, 45.66884871891567, 46.79820891789028, 49.24644490650722, 47.82987397057669, 37.86271783283779, 25.297609397343226, 14.07090813773019, 5.6600260223661145, 2.4525223757539476, 3.3944234337125505, 8.573239803314209, 7.005798288754054, 2.608167452471597, 2.818653575011662, 2.553773045539856, 0.28301627774323734, 0.15038416401616164, 0.3429778202303818, 1.109108805656433, 5.516776749065944, 16.71357035636902, 32.591991560799734, 35.18137672969273, 40.019073895045686, 40.70150859015328, 25.73488732746669, 9.67169267790658, 1.079838433435985, 0.2690310467566763, 0.11830575604523931, 0.21117989745523247, 0.11164545986269202, 0.2559948148471968, 0.18857847952416965, 0.100767457857728, 0.13689682845558437, 0.1816788911819458, 0.1684176977723837, 0.14856607014579432, 0.14656022563576698, 0.10898939560034446, 0.24034625025732176, 0.12257695756852627, 0.07271069980093411, 0.13689026023660386, 0.10870494693517685, 0.07841628364154271, 0.09957972301968507, 0.16268149843173368, 0.17921766825020313, 0.17415581058178628, 0.14144932345620223, 0.13149611039885453, 0.10372116150600569, 0.17847650444933347, 0.14110819676092692], [0.036003963755709786, 0.007163323877778436, 0.0196227085710104, 0.05903315730392933, 0.04373046576178499, 0.034625862525509934, 0.05880768011723246, 0.019488959140809517, 0.011235442378425171, 0.02997413177841476, 0.037453606325600824, 0.06089524059955563, 0.029532273166946003, 0.02712186741908746, 0.04731828413371529, 0.02729594727445926, 0.014994714675205094, 0.06107674193169389, 0.04875320927905185, 0.03980751894414425, 0.029015314299613237, 0.017675755811589103, 0.026948075941098586, 0.12435756916446344, 0.039833513620708666, 0.01435338712430426, 0.0563585520721972, 0.020989391753183942, 0.061750276147254875, 0.018592171637075286, 0.027330138654048954, 0.006896593882369676, 0.04563066236940878, 0.08446414768695831, 3.380399146250316, 20.747050012860978, 40.23641702107021, 31.995617253439768, 27.522396530423844, 25.169818128858292, 18.69322851725987, 15.724033968789236, 4.206373853342874, 0.9027885081512588, 0.19291631318628788, 0.6770500583308083, 1.5800545577492033, 7.042313243661608, 2.286860602242606, 3.440242895058223, 0.11579315444188458, 0.3643764534166881, 2.8558755091258456, 10.590055193219866, 16.339133671351842, 25.64235816683088, 39.08575364521572, 47.219478198460166, 50.03780998502459, 49.595612730298726, 49.56770876475743, 47.89348472867693, 48.0414639881679, 49.108616965157644, 49.133863244737896, 50.58713803972517, 47.95721360615322, 46.41262558528355, 46.020931312016074, 47.239954539707725, 47.65915673119681, 46.58321080889021, 45.77198083060128, 47.893932887486045, 47.53955738885062, 46.292407853262766, 46.59333780833653, 45.57211937223162, 43.8567133631025, 36.75832251140049, 36.74596514020647, 36.9453124318804, 37.390643324170796, 37.57580239432198, 43.97519057137625, 46.552558830806184, 47.35339430400303, 48.19754137311663, 38.46207639149257, 32.84091077532087, 31.680481706346782, 47.9471560886928, 46.35039751870291, 46.65936653954642, 45.40351438522339, 44.33840070452009, 39.83770159312657, 34.11919171469552, 34.16229139055525, 35.86483628409249, 36.03588703700474, 39.07059962408883, 45.32411731992449, 44.957113470349995, 45.6484557560512, 46.04540981565203, 48.95810161318098, 46.018395219530376, 47.134859561920166, 44.915229729243684, 44.69728210994175, 44.59427159173148, 44.28212377003261, 45.39902237483433, 48.23863649368286, 44.99334485190255, 44.9162163734436, 40.312878472464426, 40.93856722967965, 44.14933327266148, 43.91453627177647, 44.91253730228969, 46.18629843848092, 40.37102099827358, 31.185999257223948, 16.210845606667654, 5.707731919629233, 1.190449520945549, 3.186416949544634, 1.3252849600144794, 0.8702993829335485, 0.8881317717688424, 0.25790969495262417, 0.14641431346535683, 0.13301228332732404, 0.024101270395996313, 0.05673807027882763, 0.31305781858307974, 1.0644864972148622, 5.79597100189754, 14.565527813775198, 22.890722138541086, 23.812932218824113, 31.50232294627598, 29.01458818571908, 10.727330752781459, 3.2370469527585164, 0.048453466434563906, 0.1065552258597953, 0.036316707331155024, 0.031728019272642474, 0.026270938704588583, 0.016656491040651287, 0.03354373827044453, 0.032299949654511044, 0.05977024310933692, 0.06467586130435977, 0.0392035990288215, 0.11995918303728104, 0.02494959014334849, 0.07777709008327552, 0.07158106791653804, 0.016570839565247297, 0.038449658413550684, 0.0736294226454837, 0.09963724921856608, 0.0528310317146991, 0.03361164266243577, 0.07059617433696985, 0.010791908633629126, 0.039349606194134266, 0.010014429638561393, 0.06235542081828628, 0.07059912596430097, 0.013188433251343668, 0.026834110895703946, 0.041171615211559195, 0.04325825967160719, 0.011057819722087255, 0.049477877893618176, 0.056786856946668456, 0.04367728897237352, 0.07429203244724444, 0.030103843925254684, 0.031149045697280338, 0.018220717819141488, 0.04926981870085001, 0.032213168418301005, 0.025557099508919885, 0.013239921336727483, 0.009433892888150044, 0.015444839539538537, 0.03716296942106315, 0.03947043292490499, 0.09097737140421357, 0.022721520325701152, 0.039217739698610136, 0.028259631545682038, 0.03890063314299498, 0.0194792035035789, 0.019344846784536327, 0.017367444766153182, 0.017534177783610563, 0.03377755465252059, 0.008497922531595188, 0.029867879979844605, 0.007273713891793574, 0.023477335393960987, 0.026471740965332304, 0.2119144116129194, 4.768314625535693, 25.61965319088527, 46.58440242494856, 35.618203026907786, 23.552902834756033, 26.270030634743826, 23.157656294958933, 19.3577663898468, 4.6415534274918695, 0.6934481327022824, 0.27034781181386536, 0.850787375654493, 1.9673618035657066, 1.1978914758988788, 1.224369757941791, 5.791787752083369, 0.6385195830038616, 0.09439022612891027, 4.425376730305808, 14.489904488836016, 19.91860239846366, 28.846297604697092, 40.428666727883474, 49.40525640760149, 52.48551096235003, 52.53449576241629, 50.71343197141375, 50.71097230911255, 50.446225098201204, 50.65809999193464, 50.6537504196167, 51.082704407828196, 49.7848538671221, 47.82774087360927, 46.98957967758179, 47.850200925554546, 47.559561252593994, 47.46870313371931, 46.90966149738857, 49.79256636755807, 49.36738177708217, 48.0913416317531, 48.05259847640991, 48.12795863832746, 46.7645240511213, 37.749597685677664, 36.929373264312744, 38.464056628090994, 38.139857155936106, 38.89482757023403, 46.832265513283865, 47.51765319279262, 50.17822960444859, 49.39389957700457, 40.96746826171875, 36.00832353319441, 34.87808438709804, 48.69918394088745, 48.11781426838466, 48.46302161897932, 46.83429091317313, 46.23655128479004, 40.25772367204939, 36.44653252192906, 35.448336941855295, 37.781729630061555, 37.31811802727835, 41.34360899244036, 47.216184752328054, 46.93383775438581, 47.20452914919172, 48.880149773189, 49.869691371917725, 47.07982982907976, 47.44087559836251, 45.531924043382915, 46.020813192640034, 46.01466751098633, 45.369020053318565, 46.93733617237636, 49.36880268369402, 46.10568543842861, 46.50985172816685, 42.675641196114675, 43.31200933456421, 45.56918723242623, 46.552920137132915, 46.09227541514805, 48.033511774880544, 44.255310671670095, 33.21813195092337, 17.836560794285365, 8.872239896229335, 2.7959064756120955, 3.1931556165218353, 2.330546532358442, 1.653587343437331, 1.7689664150987352, 0.1893037384642022, 0.13260373739259584, 0.1973939657743488, 0.03084420705480235, 0.17483111577374594, 0.5504939407110214, 1.3298530748912265, 7.1995653084346225, 18.090651205607823, 27.53099318913051, 26.171927281788417, 33.735786642347065, 33.42950310025896, 13.647431067058019, 4.274807529790061, 0.07910800938095365, 0.054046776478311846, 0.04397286900452205, 0.057929323320942264, 0.017690563142033558, 0.03931197464200003, 0.009909176134637423, 0.05855089532477515, 0.026676478729184185, 0.047411884646862745, 0.0442667832331998, 0.07337776079241719, 0.032176239149911065, 0.045872139411845377, 0.015423679424981986, 0.04533484485000372, 0.06112777455044644, 0.02372633060440421, 0.0537869484562959, 0.029169935466987745, 0.023183853731357625, 0.027138435547905307, 0.07678542472422123, 0.05289427796378732, 0.03060811079506363, 0.012615771747992506, 0.04572896852291056, 0.029629483486392667, 0.04115700635260769, 0.0644656443702323, 0.07855666575155087, 0.09459589687841279, 0.24565926087754114, 0.16002415173820086, 0.1398506678108658, 0.2173701860010624, 0.1267245164407151, 0.13218608551791736, 0.14901885656373842, 0.12652803984071526, 0.11666470553193774, 0.09877446480095387, 0.12891838300440991, 0.1685238613614014, 0.11823039794606821, 0.05945976584085396, 0.13008380761103971, 0.21958100236952305, 0.06789248370166336, 0.11988386565021106, 0.16317526836480412, 0.062473608047834465, 0.2881764279944556, 0.1498801482043096, 0.11562281501080308, 0.18286324691559586, 0.08963310532271862, 0.10422182535486561, 0.12927936363433087, 0.1148229715015207, 0.07772985726062741, 0.09069699394915785, 0.2580786773136684, 6.267790164266314, 28.689542770385742, 51.888917786734446, 41.608408314841135, 37.50904410226004, 36.434192521231516, 26.424372707094463, 21.064011199133738, 5.739520796707698, 1.4070330134459903, 0.44995898966278347, 2.729010739496776, 4.8471128429685315, 15.276550871985298, 9.500215479305812, 10.290117962019783, 1.4186284712382724, 0.6532008009297507, 6.773846575192042, 16.26025598389762, 20.063538346971782, 29.539168494088308, 42.15399823869978, 50.63167251859392, 52.75752598898751, 52.622265407017295, 52.06653458731515, 52.12343685967581, 52.553731850215364, 52.455974170139854, 51.84234748567854, 53.83630330221993, 51.06607042040144, 48.32851491655622, 48.854003701891216, 47.99182605743408, 49.453612395695274, 48.154688358306885, 47.30080338886806, 50.675956862313406, 51.065535409109934, 49.40933152607509, 50.000119481767925, 50.69481427328927, 50.09784589494978, 40.95447860445295, 39.79241670880999, 40.45301668984549, 39.5682886668614, 41.00157349450247, 49.80081040518624, 49.772142137799946, 52.39690405981881, 50.56660611288888, 43.25819206237793, 40.758091245378765, 37.788486753191265, 47.56129135404314, 50.472475392477854, 50.20822845186506, 48.4737183707101, 47.55645888192313, 42.25517095838274, 38.23702423913138, 37.24311569758824, 39.34499440874372, 39.415337971278596, 44.003705978393555, 49.10860306876046, 48.228846481868196, 49.47208070755005, 49.065270628247944, 51.894524982997346, 46.582161630902974, 47.75372518811907, 44.4613664490836, 44.986174310956685, 45.971960408346995, 45.796435015542166, 46.81591640199934, 49.69621222359793, 48.669713156563894, 48.71200336728777, 44.56345633098057, 43.95738581248692, 47.759106567927766, 47.7659262248448, 47.41642141342163, 49.053385734558105, 44.66633135931832, 34.51566982269287, 18.64185701097761, 7.541600806372506, 2.6100382549422125, 6.989511276994433, 3.732794625418527, 1.8433088830539157, 2.410722013030733, 0.4830660160098757, 0.3537354501230376, 0.5290536454745701, 0.2968771196901798, 0.4253849482962063, 0.9503491989203862, 4.105073460510798, 8.52972844668797, 23.617823328290665, 33.06618874413626, 33.5197879927499, 41.80701214926583, 40.47613682065691, 15.44113632610866, 4.501542883259909, 0.21452484439526284, 0.18525121520672524, 0.12784358353487082, 0.1112043781738196, 0.11574572484408106, 0.14121923223137856, 0.11207797843962908, 0.10426558407821826, 0.09546429278062922, 0.11824187875858375, 0.1081921440948333, 0.21795596528266156, 0.19563087395259313, 0.11497386411896773, 0.15491183820579732, 0.15723659417458943, 0.16605782083102635, 0.17349634239716188, 0.2299896345606872, 0.11535254094217505, 0.12941285861389978, 0.10572120454162359, 0.19833546025412424, 0.17170038233910287, 0.14355814244065965, 0.15188146010041237, 0.15928781910666398, 0.09814578175012555, 0.123591598123312], [0.033085913729986975, 0.05057699266555054, 0.021462700462767055, 0.04809537636382239, 0.04469539684110454, 0.04408047448045441, 0.055473769549280405, 0.049681567320866246, 0.04748523088970354, 0.05280345944421632, 0.0272333473299763, 0.025071285398943082, 0.03524552784594042, 0.05354468770591276, 0.014595050763870989, 0.05950324636484895, 0.042265780070530515, 0.026841115073433945, 0.0151449694697346, 0.022520190503980433, 0.04862063710710832, 0.026871566028733338, 0.03428846098748701, 0.054244063927658966, 0.037426461532179794, 0.014893309313005634, 0.013235678796523383, 0.028448952993910228, 0.02779322862625122, 0.027471714985689948, 0.06273763280894075, 0.026291540724092295, 0.04594358914930906, 0.03315550088882446, 0.7231175920792988, 13.17012803895133, 33.047077723911826, 39.914378438677105, 36.92436708722796, 26.457974195480347, 24.734225136893137, 14.617647988455635, 6.248213180473872, 1.6075647558484758, 0.2785494274326733, 1.003735682794026, 1.2535886700664247, 0.4734354870659964, 1.458082405584199, 4.734840376036508, 0.3241810160023825, 0.12662299403122493, 2.344902379172189, 11.11006532396589, 13.630277701786586, 23.519052948270524, 32.652663230895996, 39.12853022984096, 48.50662851333618, 49.575622762952534, 49.77548769542149, 50.08157321384975, 51.36227560043335, 48.49759932926723, 49.90617983681815, 52.90248973029, 47.07232230050223, 46.832936014447895, 48.58748817443848, 48.76796415873936, 46.51925958905901, 47.128290040152415, 46.24437148230416, 45.84346389770508, 49.001361097608296, 47.92585291181292, 51.15001508167812, 47.8157274382455, 46.02933863231114, 38.11589281899588, 35.505419867379324, 35.92488261631557, 36.22641706466675, 36.9696797643389, 40.94538688659668, 43.80403559548514, 46.74620165143694, 46.72698293413435, 45.42983763558524, 39.37764399392264, 31.492939404078893, 49.61493567058018, 48.00609070914132, 47.43299634116036, 46.03199284417288, 46.60931519099644, 42.16502502986363, 35.18695265906197, 32.84673336574009, 38.20528139386858, 38.3894989831107, 44.59713077545166, 45.717201232910156, 45.744702202933176, 48.09781387874058, 46.49613945824759, 44.039551734924316, 46.41632897513253, 45.76819058826992, 46.835611070905415, 44.508433546338765, 46.196286473955425, 47.780844007219585, 46.17819683892386, 45.731313024248394, 45.679649693625315, 41.988193375723704, 42.34387860979353, 43.08718647275652, 46.078017711639404, 44.84953798566546, 46.06594869068691, 43.7077648299081, 35.282080445970806, 22.7980192729405, 9.836130482809883, 3.8217689139502387, 1.4981312794344765, 1.5752447758402144, 4.255174091884068, 1.7567101184810912, 0.3611814220036779, 0.041017007614885054, 0.1574769719902958, 0.06480324268341064, 0.0643719183281064, 0.09772675244935922, 0.1667008956096002, 2.8609496482781003, 6.156756213733128, 11.134423102651324, 21.993265015738352, 31.527947902679443, 37.03691053390503, 24.3846595287323, 6.935799096311841, 0.9841874688863754, 0.042290797656668086, 0.00930586435632514, 0.04426002163173897, 0.06235749035009316, 0.0673058901780418, 0.029022248927503824, 0.042284958862832615, 0.037182049825787544, 0.029874787466334443, 0.036687441901969056, 0.01960373842822654, 0.05992705933749676, 0.037836652914328237, 0.011785153282939323, 0.08844652399420738, 0.03409200135086264, 0.011397750499392194, 0.03168486783813153, 0.051620606665632555, 0.024958745277087604, 0.04494530128847275, 0.03596382501668163, 0.008118795330769249, 0.06176299189350434, 0.01897868893242308, 0.03137389184640987, 0.08184386257614408, 0.04478801687115005, 0.03160798303516848, 0.02337777564701225, 0.03978431983185666, 0.03275593197239297, 0.09243981114455632, 0.04764352632420404, 0.023296168240319406, 0.031394444672124724, 0.018577286275103688, 0.055961510698710165, 0.019989244706396545, 0.030161692428269556, 0.05259240451934082, 0.06777245085686445, 0.011533223408540445, 0.006710697339648115, 0.034295884160591025, 0.011380751500837505, 0.038208330648818185, 0.03322686241673572, 0.026011092022859623, 0.02694190466510398, 0.08508852204041821, 0.0535313646708216, 0.03933919407427311, 0.02364962900589619, 0.030751498815204416, 0.033435627285923274, 0.034500842448323965, 0.02942411129229835, 0.04385091590562037, 0.03339143090748361, 0.008814766154890614, 0.046333784104457924, 0.09025599368448768, 1.6325883673770087, 16.573036091668264, 39.150750568934846, 43.464352062770296, 39.077176094055176, 28.07388026373727, 24.17247544016157, 16.329902989523752, 7.2912841354097635, 1.5311633412327086, 0.09436237905174494, 0.31483810448220795, 1.4297562284129006, 0.882756905896323, 1.1737130475895745, 4.420676273959024, 0.7849596536585263, 0.09044358826109342, 2.9850750906126837, 12.096522791045052, 17.257810592651367, 25.77094500405448, 35.8848922593253, 42.8152756690979, 49.68408414295742, 51.266751766204834, 51.83382552010672, 53.30287619999477, 53.7817634173802, 51.67099101202828, 52.98844936915806, 53.21056243351528, 48.740383284432546, 48.37559243610927, 50.2328702381679, 50.41180372238159, 47.57798787525722, 46.616735867091585, 47.18879842758179, 46.82106154305594, 50.18510137285505, 49.493112904684885, 51.750940459115164, 48.465238094329834, 48.05168826239449, 40.19354663576399, 36.85595859800066, 37.14989866529192, 37.909517424447195, 38.40120669773647, 43.38207496915545, 46.91651242119925, 48.199097769601, 49.89538581030709, 44.096686771937776, 41.003918511526926, 35.62477254867554, 48.68795565196446, 48.13429192134312, 47.947315897260395, 48.82183354241507, 48.1456105368478, 42.790745053972515, 37.72757189614432, 34.7813515663147, 41.75197546822684, 38.812689440590994, 45.9868677684239, 46.9479078565325, 46.997476305280415, 48.75701379776001, 47.79452153614589, 46.404937403542654, 46.905068738119944, 46.52158028738839, 46.75867019380842, 46.35264873504639, 46.88172626495361, 48.92119625636509, 48.341240542275564, 47.42724323272705, 47.05802985600063, 43.977313246045796, 43.60679013388497, 45.167511871882844, 47.498000213078086, 46.55960430417742, 48.05536733354841, 45.67234713690621, 37.960531098502024, 24.86496591567993, 13.122162887028285, 4.417209991386958, 1.2318746809448515, 0.9080169733081545, 2.5081991595881323, 0.8874348348804882, 0.4050486838178975, 0.030447735650730983, 0.1004855672695807, 0.08545367566070386, 0.07498468777963094, 0.16455217876604625, 0.47453612514904564, 2.825769616024835, 8.753284130777631, 16.658135890960693, 25.8114686352866, 34.44653524671282, 40.89603035790579, 30.068131378718785, 9.080215113503591, 1.2845639565161295, 0.015051328244486024, 0.011435555926124965, 0.03246216023606913, 0.0289328485461218, 0.05189357451828463, 0.020467927413327352, 0.03302349190094641, 0.06453956397516386, 0.06090265020195927, 0.03934609477541276, 0.06408031111849205, 0.03460519095616681, 0.026351494382002523, 0.04545326617413333, 0.03673222182052476, 0.05717828005020108, 0.02108120602289481, 0.01732811009112213, 0.036872200202196836, 0.044354972429573536, 0.05123280693909951, 0.042116797529160976, 0.016898621173043336, 0.04664664642353143, 0.01680999432158257, 0.04470911681918161, 0.09022233156221253, 0.04008834423231227, 0.034252892181809456, 0.11367285464491163, 0.13422785167183193, 0.1748496533504554, 0.19030536471733026, 0.07625266616897923, 0.1000281193160585, 0.19057525880634785, 0.15858891446675571, 0.15517489266182694, 0.12463162945849554, 0.11182401635284935, 0.08703315590641328, 0.14077890371637686, 0.18096387812069484, 0.08182525714593274, 0.17324113180594786, 0.11151013283857278, 0.16599671196724686, 0.11911243918750967, 0.09647218869732958, 0.1553050899612052, 0.11467233672738075, 0.17301831447652408, 0.11842046917549201, 0.11898951578353133, 0.08098325625594173, 0.06265775566654545, 0.11975043852414403, 0.12032502197793551, 0.16195224970579147, 0.13126445854348795, 0.14550792638744625, 0.19266445455806597, 0.32157918704407557, 1.9869535522801536, 19.117193698883057, 46.20159837177822, 51.41561344691685, 47.67391470500401, 36.12244422095162, 35.48144858224051, 20.397614683423722, 9.79553997516632, 2.480520576238632, 0.5368519127368927, 1.308856270142964, 4.1985653809138705, 2.0559022639478957, 8.298641783850533, 13.184346658842903, 0.6214029671890395, 0.21849172296268599, 4.214911886623927, 15.861636093684606, 16.717179945537023, 27.307221242359706, 36.3748653275626, 44.92948048455374, 50.02988903863089, 52.87034041540963, 51.1801563671657, 53.06598431723458, 55.265353202819824, 52.078659193856375, 53.022495542253765, 54.836003167288645, 50.88553537641253, 49.8239791733878, 50.22131190981184, 51.20376287187849, 48.16210903440203, 46.669156551361084, 47.106337206704275, 46.62798500061035, 50.08879934038435, 50.44899048124041, 53.47748095648629, 50.779280049460276, 49.483465330941335, 41.80730397360665, 39.8273001398359, 38.7505829674857, 39.077860491616384, 40.979106494358604, 44.95617893763951, 48.066689423152376, 50.747224535260884, 50.92529296875, 46.56929704121181, 42.45409093584333, 39.53881440843855, 48.29378434589931, 48.92684514181954, 50.38246495383126, 50.88027559007917, 50.03580890383039, 45.34595898219517, 38.880014010838096, 35.93665633882795, 43.22237409864153, 40.83871119362967, 48.34655244009835, 50.455935205732075, 48.745448521205354, 50.64110469818115, 49.83331407819475, 45.93491261345999, 47.61862094061715, 46.14886849267142, 46.61730214527675, 46.80404887880598, 47.671072891780305, 50.792672702244346, 50.17659330368042, 49.38299090521676, 49.44405514853341, 45.71821914400373, 45.6874976839338, 46.14685698917934, 50.23926258087158, 47.65519625799996, 48.713497229984824, 46.43411636352539, 38.44023125512259, 25.70778066771371, 12.143087880952017, 5.440243210111346, 3.343528313296182, 2.7631057671138217, 9.283580201012747, 4.714413106441498, 1.1134726000683648, 0.18409919845206396, 0.41536469597901615, 0.32242705726197785, 0.37670665606856346, 0.6728971526026726, 1.4477744272777011, 7.465908867972238, 15.459465673991613, 20.633554662976945, 32.75623655319214, 40.96977506365095, 46.56890099389212, 32.20369495664324, 10.137418270111084, 1.453900349991662, 0.1431847581905978, 0.1143081398414714, 0.1726503177945103, 0.15219758956560067, 0.15954921793724808, 0.09643532388976642, 0.1650882214307785, 0.17370178923010826, 0.13191980123519897, 0.16919284260698728, 0.17523211639906677, 0.16739620401390962, 0.10664066020399332, 0.16330100090375968, 0.15816295732344898, 0.1504637561738491, 0.15884097665548325, 0.14529832692018577, 0.12042290743972574, 0.10334008266883236, 0.1050519383113299, 0.16340312042406627, 0.11873992346227169, 0.1799312156758138, 0.14762635342776775, 0.2052524190928255, 0.18843097958181584, 0.17531470768153667, 0.12181079653756959], [0.006068206949359072, 0.013625072232181472, 0.023786458985081742, 0.016122124357415096, 0.03625055695218699, 0.025106922058122497, 0.01634250913879701, 0.02730722283013165, 0.011839171455773925, 0.04994555136987141, 0.0352421216001468, 0.0338374930433929, 0.037930653763136694, 0.034330262137310844, 0.07098430993833713, 0.04507855199543493, 0.0583883115489568, 0.0173178591233279, 0.017831912164443305, 0.0023475791302709176, 0.03786424554086157, 0.031317485230309625, 0.04710439632513693, 0.058057172889156, 0.05094144739476698, 0.01687063499619918, 0.023351892928725908, 0.09274121639983994, 0.03668796098125832, 0.019066611803801994, 0.021068215469962785, 0.05011912741299186, 0.03751666937023401, 0.059398039510207515, 0.1272240946335452, 6.1216009344373425, 29.82031692777361, 42.86807155609131, 36.17273875645229, 26.88796693938119, 24.580042873110088, 28.65189048222133, 17.781576224735804, 4.487998238631657, 0.39257365465164185, 0.3358486699206488, 1.2723396867513657, 0.26525510794350077, 0.35460544058254784, 2.6302329770156314, 1.5613700917788913, 0.22606713218348368, 0.35191209082092556, 1.572113526718957, 6.798194365842002, 13.236531972885132, 22.57746955326625, 32.29861429759434, 39.29114586966378, 45.219317640577046, 46.50646448135376, 49.23966693878174, 48.2700388772147, 49.56430067334856, 48.50308493205479, 50.109967027391704, 51.687409605298726, 47.96303967067173, 49.027291774749756, 47.49574899673462, 48.14640263148716, 47.06674289703369, 46.476507323128835, 46.46910401753017, 49.568268094744, 49.45295579092843, 49.72487006868635, 48.718413080487935, 45.55012832369123, 37.50127254213606, 36.540618079049246, 36.57194403239659, 36.04259204864502, 37.28156702859061, 40.203552041734966, 45.30680588313511, 46.46413605553763, 49.35722003664289, 50.77044888905117, 42.98704208646502, 31.220048904418945, 48.470820971897666, 43.9927590915135, 48.83722727639334, 45.74274975912911, 48.05893175942557, 43.218510900224956, 37.54600504466465, 32.40078755787441, 36.438288484300884, 37.333334582192556, 44.18012074061802, 45.11587980815342, 48.67015436717442, 47.15632254736764, 49.031742095947266, 47.67900078637259, 47.22794457844326, 46.312884194510325, 44.132365771702354, 46.353795187813894, 47.17846645627703, 43.82983078275408, 45.654677867889404, 43.19968128204346, 43.19813183375767, 41.80518477303641, 43.672266483306885, 45.02702624457223, 46.42875930241176, 47.36161749703543, 46.313235078539165, 37.67051676341465, 23.7311258656638, 10.576887488365173, 3.9096505982535223, 1.2970170825719833, 1.6341673455068042, 1.4664024391344614, 1.677721259849412, 1.2421458555119378, 0.17116678240043776, 0.10625439057392733, 0.07622635936630623, 0.08539118258548634, 0.11799790470727853, 0.026820206016834294, 0.8173643691199166, 4.952186976160322, 13.36800926072257, 18.688842466899327, 28.32357941355024, 33.606293065207346, 31.15852607999529, 13.404940673283168, 2.1809403087411607, 0.12884501979819366, 0.058275138693196435, 0.019219826707350354, 0.031130104392234768, 0.016157990022163306, 0.047335797122546604, 0.04579520032608083, 0.012735334707290998, 0.05172396111967308, 0.013605363334396055, 0.13875547157866613, 0.033639299749795876, 0.04769538675567933, 0.03434481332078576, 0.02028230737362589, 0.08478981056915862, 0.0012249443201913632, 0.05224196153825947, 0.007652511154966695, 0.024642490282920853, 0.036287381047649045, 0.03682305391079613, 0.03179580152833036, 0.01812455413996109, 0.06997610868087836, 0.09335170114146811, 0.030321819907320396, 0.044305639541042705, 0.06742928177118301, 0.03235588808144842, 0.03792596847883292, 0.05429762408935598, 0.021164715023977414, 0.014463499787130525, 0.03769458803747382, 0.03669079386496118, 0.06959366598831755, 0.009081608532661838, 0.06551036438239471, 0.029096294061413834, 0.010670238823097731, 0.04101900250783988, 0.019357735557215552, 0.05857981448726995, 0.05052861311872091, 0.04109366850129195, 0.02300997743649142, 0.05647940594436867, 0.010557788607132221, 0.022018488496541977, 0.02082219733191388, 0.06693419548017637, 0.0017181588087363967, 0.0815313361319048, 0.0373461840541235, 0.04792172907452498, 0.02479824630011405, 0.07531065600258963, 0.0254642657403435, 0.06147853644298656, 0.02856666355260781, 0.011580307801653231, 0.027733169795413102, 0.07590144965797663, 0.08020319882780313, 8.420712947845459, 34.66295426232474, 47.51868500028338, 39.490517480032786, 28.404532875333512, 25.783069610595703, 22.612702131271362, 15.617394753864833, 4.616715354578836, 0.41168516342129025, 0.1286315798227276, 0.9362248139722007, 0.9315838515758514, 0.5951535414372171, 0.4797130216445242, 0.6579105939183916, 0.12191415099161011, 0.5281650902969497, 2.3844769299030304, 8.108645898955208, 17.09592625073024, 26.753574882234844, 35.38900627408709, 42.65137461253575, 49.30051926204136, 49.07794066837856, 52.551202705928254, 51.5548414502825, 51.418087005615234, 50.86675092152187, 52.03750501360212, 52.75688328061785, 50.63336787905012, 50.37533262797764, 49.005672454833984, 48.423246656145366, 47.718827860695974, 46.93485566547939, 46.028025422777446, 49.682708399636404, 50.01999132973807, 51.1105180467878, 51.34508228302002, 47.242657388959614, 39.82475709915161, 39.017286096300396, 38.64933034351894, 37.14740078789847, 38.209804671151296, 41.90719822474888, 48.497960635593955, 48.46481425421578, 50.2440116746085, 52.109349387032644, 44.26094218662807, 34.58101415634155, 48.24338558741978, 44.919690472739084, 50.384750911167686, 47.40732969556536, 48.900000776563374, 45.06993137087141, 39.23128366470337, 34.45238562992641, 37.36554643086025, 39.62810918263027, 46.35523346492222, 46.49824823651995, 49.7936224937439, 47.653327192579, 47.387819153921946, 47.70897878919329, 47.4313530921936, 46.09796598979405, 44.79575892857143, 47.2508875301906, 48.85617501395089, 46.659217153276714, 47.308154582977295, 45.42383439200265, 45.704149041857036, 42.01385307312012, 44.77407707486834, 45.92430966241019, 48.88044507162911, 49.17168228966849, 47.778752599443706, 40.38467768260411, 26.487695114953176, 13.381883944783892, 5.735581602369036, 2.3283732661179135, 1.8142312147787638, 1.249920021210398, 1.5151899755001068, 0.6816591567226818, 0.3392986947936671, 0.07169156734432493, 0.018320129984723668, 0.12733404444796698, 0.09260867815464735, 0.03707034260566745, 0.8382240555116108, 5.622118387903486, 12.398825015340533, 19.661041361945017, 30.57175418308803, 37.90758582523891, 35.88668836866106, 16.413468973977224, 3.3022197527544837, 0.239332736070667, 0.04815845297915595, 0.058203322546822686, 0.06777605387781348, 0.04349288011768034, 0.014708629044305001, 0.01691242427166019, 0.021290907270408103, 0.05734739133289882, 0.05924724188766309, 0.14202157274952956, 0.018550633419571177, 0.051973743430737934, 0.044008953496813774, 0.014142387330399027, 0.09213080629706383, 0.0783559890197856, 0.04696079456646528, 0.0318914206831583, 0.09235671774617263, 0.04709794006443449, 0.031717339131448946, 0.012031636217476, 0.0474868593737483, 0.03767764501805816, 0.044386995889778645, 0.005262555604401443, 0.025258036895788143, 0.012096840888261795, 0.026440608082339168, 0.1068261173952903, 0.12122984842530318, 0.0730822045089943, 0.09987099096179008, 0.1615677781935249, 0.11558845399745873, 0.10436748646731887, 0.08674696340624775, 0.14135451854339667, 0.11296428088098764, 0.13481615510370049, 0.11222302208521537, 0.15977782995573112, 0.12403864413499832, 0.26362803525158335, 0.14400795687522205, 0.1575421927762883, 0.11737376105572496, 0.1199844516813755, 0.12811995084796632, 0.18497547214584692, 0.23930125204580172, 0.10597982816398144, 0.18976693360933236, 0.13360828134630406, 0.09921838276620422, 0.10102893811251436, 0.23367272264191083, 0.05278861988335848, 0.11269693129828998, 0.11095378840608255, 0.10238356542374406, 0.09117394978446619, 0.20807189494371414, 0.21793639633272374, 9.27760214465005, 37.923177582877024, 53.75692360741751, 47.700811181749614, 35.89960159574236, 33.72112594332014, 36.671393598829, 20.228054319109233, 5.768527354512896, 0.8747285338384765, 0.6904599187629563, 3.1732145036969865, 1.3962719908782413, 2.0041464354310716, 10.345513343811035, 4.753424201692853, 0.3416732959449291, 1.593450358935765, 3.924798539706639, 9.764282635280065, 17.27279611996242, 26.80024766921997, 35.904896123068674, 43.118918895721436, 48.35148218699864, 49.95246178763253, 54.83844893319266, 51.83787284578596, 50.98896278653826, 50.67912524087088, 51.911450794764924, 53.6610106740679, 51.669375555855886, 51.778632504599436, 49.4010214805603, 49.30381270817348, 49.15601757594517, 46.86813906260899, 47.22318506240845, 50.05900546482631, 51.51201622826712, 53.38672358649117, 52.69561753954206, 49.85472495215279, 41.253911222730366, 40.36849880218506, 39.703670842306956, 39.31755944660732, 40.005611760275706, 44.123621463775635, 51.316837855747764, 49.13457196099417, 53.5517954145159, 51.41981015886579, 44.81403269086565, 37.83732564108712, 47.72035993848528, 45.034168992723735, 50.904510906764436, 49.73385756356375, 51.48601606913975, 48.48125369208199, 41.17537225995745, 38.03099972861153, 39.42833457674299, 41.5382593018668, 48.84604801450457, 48.02011564799717, 51.49444423403059, 49.665344851357595, 47.77874217714582, 48.09949881689889, 47.87907069069998, 45.699698720659526, 45.03213317053658, 48.428544657570974, 51.063589913504465, 47.63330248423985, 49.74237258093697, 45.97992304393223, 46.9878044128418, 43.99817868641445, 46.688802582877024, 48.04902015413557, 49.08045939036778, 48.39330339431763, 49.35892581939697, 41.37102658408028, 26.715422323771886, 12.508218322481428, 6.54692405462265, 2.9382175249712805, 4.947543842451913, 4.66143092087337, 4.823605350085667, 2.9774144845349446, 0.5350052118301392, 0.2224900448428733, 0.10439614100115639, 0.308370227260249, 0.32052637210914064, 0.20986600938652242, 1.2677102323089326, 7.850666233471461, 18.61139784540449, 25.9518917288099, 37.04926790509905, 44.044471059526714, 41.02309206553868, 20.45392288480486, 4.09906587430409, 0.34372467015470776, 0.08937861397862434, 0.11879943098340716, 0.11145437083074025, 0.158671410754323, 0.07143273337611131, 0.11372965481132269, 0.07128739117511682, 0.1431120735194002, 0.14612111848379883, 0.37417276203632355, 0.11338694034410374, 0.13612020441464015, 0.09448813873210124, 0.1123865150979587, 0.17480419150420598, 0.23819610849022865, 0.13788229200456822, 0.05743504448660782, 0.11796194235129015, 0.15498174088341848, 0.12582005640225752, 0.10701380018144846, 0.2021690881145852, 0.20557780377566814, 0.17670164683035441, 0.05977027025073767, 0.15861536376178265, 0.24108604341745377, 0.1646966388715165], [0.027754418119522076, 0.008456972943219756, 0.039988728506224494, 0.009102436165059251, 0.08445136408720698, 0.04821595542931131, 0.04909451917878219, 0.05150903854519129, 0.057491661448563845, 0.022933452257088253, 0.021654749621770213, 0.053868599967764955, 0.029676516141210283, 0.038599132892808745, 0.026141133259183595, 0.027367035692025508, 0.02899647138214537, 0.045048238443476815, 0.020989205156053816, 0.019388629256614616, 0.01399472453964076, 0.02512053686327168, 0.03442871756851673, 0.015396264913891042, 0.036945807681019814, 0.01619942476307707, 0.08255404446806226, 0.021231720357068946, 0.03619338359151568, 0.02510778379759618, 0.019626767906759466, 0.017854488720851283, 0.058998090614165576, 0.027179542895672575, 0.02900546875649265, 1.8060223524059569, 13.955681817872183, 39.26833840778896, 44.212186677115305, 29.176986694335938, 33.33590391704014, 44.74384546279907, 26.902059623173304, 8.291212422507149, 1.004764776144709, 0.1531992293894291, 0.5035818208541188, 0.14201300963759422, 0.5741285096321787, 0.2753686452550547, 0.7275745900613921, 0.2905072772077152, 0.11919918310429369, 0.25652966329029625, 1.8026630069528307, 6.651305973529816, 13.283841388566152, 22.222402708871023, 31.26991265160697, 34.070672443934846, 38.543207032339915, 46.36361994062151, 50.111141272953574, 45.101166997637065, 44.36732952935355, 46.274099349975586, 52.079395702907014, 46.22108459472656, 47.570073877062114, 49.4642014503479, 47.95956904547555, 47.988226890563965, 49.25649200166975, 50.28249774660383, 50.21392250061035, 47.960580008370535, 47.97769342150007, 46.11755990982056, 42.81836414337158, 37.478638785226, 38.69411148343767, 37.05932542255947, 35.78237853731428, 38.57735048021589, 41.46287134715489, 43.96658175332205, 47.109210286821636, 48.29752942493984, 49.858028820582796, 43.263135705675396, 31.51388474873134, 47.7261825289045, 41.10360084261213, 47.402660506112234, 48.62402180262974, 45.05492326191494, 42.49420983450753, 35.55337980815342, 33.24028280803135, 32.80898380279541, 37.739564486912315, 45.89934478487287, 46.88159077508109, 46.3235878944397, 48.77038213184902, 42.95582035609654, 43.42276014600481, 48.36202607836042, 45.86637905665806, 45.91552366529192, 47.59456627709525, 46.35730402810233, 44.92712157113211, 42.96242461885725, 43.02654259545462, 41.15445818219866, 44.3380081312997, 45.78950418744768, 46.87313134329659, 46.05686044692993, 45.08033977236067, 37.28239733832223, 25.68811900275094, 14.246586390904017, 4.507964755807604, 2.42013486794063, 0.36276843398809433, 0.5277810937591961, 1.0296412812811988, 0.9084198602608272, 0.28466313651629854, 0.05287090582506997, 0.07523355406842061, 0.12620565428265504, 0.04395591580708112, 0.022654803369992545, 0.07086059943373714, 1.9432485146181924, 9.059378334454127, 21.3750889982496, 24.959391934531077, 28.568378346306936, 36.99619409016201, 24.35215585572379, 9.800242168562752, 0.7252311472381864, 0.016369531795914685, 0.06109211753521647, 0.0262319738311427, 0.033076933319015164, 0.037498661050839086, 0.016619124117174318, 0.0352218910785658, 0.03710068669170141, 0.04299852325181876, 0.03507912731064217, 0.013116923293897083, 0.04379339309941445, 0.07097168918699026, 0.027057995221444538, 0.005373187770601362, 0.02298581480447735, 0.058788416508053026, 0.011179101919489247, 0.016847420616873672, 0.01624760583841375, 0.020455201489052603, 0.02702070463315717, 0.06975199534956898, 0.02955780304702265, 0.03633381998432534, 0.03349085325109107, 0.022183162160217762, 0.02876195271632501, 0.05132602068728634, 0.04843559042949762, 0.09613598138093948, 0.028757850972137282, 0.030505268634962182, 0.03205088659056595, 0.004587669407815805, 0.03967603921358075, 0.07591234014502593, 0.02416213837984417, 0.026079091409753476, 0.022148621335093464, 0.03853170008265546, 0.08310698265475885, 0.06343195733747312, 0.03706063276955059, 0.03641534596681595, 0.0408310313442988, 0.00573309970786795, 0.030163378587790897, 0.012285711958871355, 0.054971507750451565, 0.026113881596497128, 0.06858397873916797, 0.026732866685571413, 0.07664065927799259, 0.03273410689351814, 0.030389167900596346, 0.03351521944361074, 0.024234488872545104, 0.04006214599524226, 0.060264033398457935, 0.049595712284956656, 0.0058222816857908454, 0.05793189496866294, 0.004173395789361426, 0.0461633530711489, 2.0450148710182736, 18.840269769941056, 45.222899436950684, 48.675997802189414, 32.22687414714268, 31.051322323935374, 42.185310295649934, 25.831373487200054, 9.454042962619237, 1.1988561898469925, 0.0566875295979636, 0.514609480542796, 2.3533490002155304, 0.8616011068224907, 0.12068380415439606, 0.5283907439027513, 0.1721229875194175, 0.21367615993533814, 0.5898566799504417, 1.6804096698760986, 7.043080585343497, 16.011182171957834, 24.876569407326834, 31.955199582236155, 36.89297860009329, 41.88990068435669, 47.171636377062114, 50.71515512466431, 47.3784738268171, 48.41471426827567, 47.766902446746826, 52.49246610913958, 48.28263943535941, 49.51851551873343, 51.20478425707136, 47.82393326078142, 48.29119266782488, 49.00930636269705, 51.03832973752703, 51.28441408702305, 50.876957825251985, 48.219070366450715, 48.91349417822701, 44.6909453528268, 38.80285426548549, 40.93305035999843, 38.48271948950631, 37.33776753289359, 39.49626016616821, 44.10585491997855, 45.1879117829459, 47.958280154636924, 49.581351552690776, 50.83115530014038, 44.21064417702811, 34.614028521946494, 47.7716098512922, 41.80149180548531, 48.41806329999651, 50.288056305476594, 47.03220340183803, 43.905965668814524, 37.383240018572124, 35.9888025692531, 35.551993642534526, 39.19556992394583, 47.45367070606777, 50.405810901096885, 49.54554401125227, 49.05298968723842, 45.37085785184588, 43.82348360334124, 47.65328202928816, 45.73067031587873, 47.649307659694124, 49.69527421678816, 47.355009760175435, 46.19765179497855, 44.57478884288243, 43.814718450818745, 43.36072662898472, 44.63134717941284, 48.05941118512835, 48.07230009351458, 47.025644302368164, 46.342820508139475, 40.76572731563023, 29.153512205396378, 16.885166542870657, 5.738774733883994, 3.267335453203746, 2.093675277062825, 1.1314504125288554, 1.0445054322481155, 0.8618436423795564, 0.19141053541430406, 0.054960135503539016, 0.1460900551506451, 0.0901468445413879, 0.05365697507347379, 0.07462036875741822, 0.04013059660792351, 2.0600021353789737, 10.41487547329494, 23.840346336364746, 25.541030849729264, 31.045030730111257, 41.886166027614046, 29.916320187704905, 12.439864550318037, 1.3281067971672331, 0.06107554092471089, 0.017754701664671302, 0.015649677387305667, 0.016547565814107656, 0.025837690702506473, 0.015193533917356814, 0.052856856757508855, 0.04608255312112825, 0.05091782080541764, 0.008357837280657674, 0.030528460961899588, 0.020655067371470586, 0.024223964794405868, 0.022681038926488588, 0.017850371709625636, 0.09451595866786582, 0.03217363357543945, 0.03749341258246984, 0.012745829947691942, 0.07186927566570894, 0.02062354433084173, 0.007386157322408897, 0.02280005905777216, 0.004028668086643198, 0.0402219681335347, 0.021946056579638804, 0.024511468563494936, 0.0168647012074611, 0.04793162890044706, 0.030539432873151133, 0.16443329943077906, 0.11746503758643355, 0.15814131205635412, 0.09662048931100539, 0.09824200480112008, 0.15733927009361132, 0.13293279973523958, 0.1870730681610959, 0.1846799837159259, 0.13155788422695228, 0.2061045505106449, 0.1491397036505597, 0.1038803051092795, 0.10382820040519748, 0.09942930537675108, 0.15950725733169488, 0.16026020050048828, 0.13709643988737039, 0.10443380648004157, 0.1520233689142125, 0.24724776563899858, 0.15487621511731828, 0.155427592673472, 0.11965008319488593, 0.18931861195181096, 0.08024921028741769, 0.1457179058343172, 0.09774625354579516, 0.14773067140153476, 0.16809494580541337, 0.1585095530109746, 0.08984087953077895, 0.1468999409782035, 0.10602480146501746, 0.09421940493796553, 2.794514447450638, 22.165788786751882, 50.940936837877544, 53.434079033987864, 39.01732431139265, 40.23304714475359, 51.66174643380301, 31.545929840632848, 11.20814870085035, 1.6711338247571672, 0.5502993911504745, 1.3248075970581599, 2.4384891859122684, 2.09528117946216, 3.345276002373014, 3.211520139660154, 0.6964410692453384, 0.8044123298355511, 1.0688052369015557, 4.003380060195923, 9.048612100737435, 16.01802441052028, 24.3694030216762, 33.52445718220302, 38.60776621954781, 41.25928218024117, 48.21451582227434, 52.57762670516968, 48.169276101248606, 50.52934292384556, 47.07754387174334, 55.6114672933306, 49.412162917000906, 49.227177551814485, 51.61522477013724, 48.30292470114571, 48.5641839163644, 49.7602607182094, 51.41122913360596, 52.33785479409354, 51.34763922010149, 50.03116055897304, 49.98080348968506, 45.187064102717805, 40.441941261291504, 42.497242723192485, 41.220292363848, 38.69557407924107, 41.58155352728707, 45.08449479511806, 48.13658135277884, 50.38660260609218, 52.683954988207134, 51.04160928726196, 45.348286628723145, 38.97620139803205, 46.500902448381694, 43.54255403791155, 50.64124713625227, 51.93232318333217, 47.952030250004356, 46.330411025456016, 39.33844920567104, 37.28545454570225, 36.400782108306885, 40.53539105824062, 50.685990061078755, 51.591177054813926, 50.2709915297372, 50.07602160317557, 45.308386598314556, 43.69589730671474, 48.990219661167686, 46.47692768914359, 47.37862321308681, 50.284814970833914, 49.13099363871983, 49.122072151729036, 45.681192193712505, 47.65633576256888, 44.67105960845947, 47.10504484176636, 50.56602941240583, 49.25136423110962, 48.74362461907523, 47.545550210135325, 41.82453203201294, 29.425294467381068, 16.59172327177865, 5.950032540730067, 3.869648516178131, 1.4063566497394016, 1.2078948191234042, 2.129037699529103, 2.7092546224594116, 0.7927422331912177, 0.1776193111602749, 0.25561160541006495, 0.3672285260898726, 0.13149518759122916, 0.22249634164784635, 0.22679026052355766, 2.808675310441426, 12.715217317853655, 27.642350230898174, 33.59692341940743, 38.328681400844026, 48.355880396706716, 33.84841346740723, 13.489923221724373, 1.4236917538302285, 0.11107192813817944, 0.15760802424379758, 0.058010163983064036, 0.10123187436589173, 0.12402842539761748, 0.1653881339090211, 0.11111780389079026, 0.15783043445221015, 0.12695403769612312, 0.1004680474953992, 0.09804580640047789, 0.13876064201550825, 0.2579704374074936, 0.21769702274884495, 0.10980437722589288, 0.1464254278689623, 0.10590539965778589, 0.08493398568992104, 0.06635322022650923, 0.16710028132157667, 0.09319398246173348, 0.11469147141490664, 0.21191101893782616, 0.09490114264190197, 0.12645992849554333, 0.10731279663741589, 0.10204775165766478, 0.12903127766081265, 0.16911130983914646, 0.12911104623760494], [0.0129705353008051, 0.031746187047766786, 0.05153903318569064, 0.047417194183383665, 0.060967626715345044, 0.08043850798692022, 0.01773301907815039, 0.01589172100648284, 0.03387497531782303, 0.020226180653220842, 0.01825789814548833, 0.057395228051713536, 0.054440123228622336, 0.03674054065985339, 0.022269956967128173, 0.07052599345999104, 0.04069264751992055, 0.011240743433258362, 0.029205188753881624, 0.0371766995771655, 0.028217738793630685, 0.07039835423763309, 0.0007851356796371484, 0.08373475646866219, 0.041231234690972736, 0.005345556128304452, 0.08436296454497746, 0.032896103736545355, 0.029156866882528578, 0.0044563355622813106, 0.025631095449041044, 0.014991332178137131, 0.07462494208344392, 0.014346839261374303, 0.023316816060936878, 0.3118492934320654, 6.506230192525046, 27.0361841746739, 40.26027366093227, 33.1101256779262, 30.112401826041086, 29.65993513379778, 21.825525079454692, 11.884711299623762, 3.6195908827441077, 0.2743134418768542, 0.406107307012592, 3.7216232248714993, 0.5472855557288442, 0.08937169970678431, 0.21758084398295197, 0.06818962097167969, 0.04625434800982475, 0.06011786338474069, 0.21750210677938803, 0.953022409762655, 5.880978737558637, 11.025150520460945, 18.51935679571969, 25.14103695324489, 30.166472707475933, 33.9971535546439, 39.3964319229126, 43.72870322636196, 47.09380265644619, 44.764419078826904, 47.19782413755144, 49.77619293757847, 46.29718473979405, 50.356763567243306, 51.33351353236607, 51.10978848593575, 49.38731615883963, 49.777335916246685, 47.5545585496085, 47.242021628788535, 45.48379039764404, 40.77571187700544, 38.4450672013419, 39.3633063861302, 38.536689622061594, 37.77882875714983, 39.42429419926235, 38.313374519348145, 40.42865283148629, 45.77359281267439, 47.12774460656302, 48.65365586962019, 50.80020802361624, 43.88758768354143, 32.79763739449637, 49.25367103304182, 50.2213397026062, 48.56784214292254, 46.889668055943076, 43.31743587766375, 39.759690693446565, 34.60566636494228, 32.44869886125837, 33.1653847013201, 35.83881180627005, 44.648860113961355, 46.05654082979475, 46.33182845796858, 47.06656224387032, 46.5639191355024, 45.08124303817749, 45.58961493628365, 45.99257223946707, 44.076818398066926, 47.979833466666086, 45.953644956861226, 43.96823195048741, 44.80349922180176, 43.70580543790545, 44.12015778677804, 45.41027845655169, 46.41244493212019, 47.772996016911094, 41.706395285470144, 37.72482735770089, 28.022340263639176, 17.221740756716045, 5.962447234562465, 1.3648257468427931, 1.2332256713083811, 2.7402600901467458, 0.9955487506730216, 0.46954047892774853, 0.2772277226405484, 0.15829134971967765, 0.3623439153390271, 0.058344858166362555, 0.12322189153305121, 0.035154800928596935, 0.15364225847380503, 0.5518692497696195, 4.717159381934574, 7.827477489198957, 15.520755733762469, 32.253735882895334, 32.742555550166536, 32.380742004939485, 17.926388842718943, 3.5514249290738786, 0.16486610977777413, 0.02885414526930877, 0.028611110989004374, 0.007471788441762328, 0.07399815214531762, 0.007233009424193629, 0.023124079885227338, 0.08793394507041999, 0.05779484446559634, 0.05135273800364562, 0.05843062499271972, 0.015651982710031525, 0.07627230297241892, 0.0199966729685132, 0.11162230146250554, 0.04150834160723856, 0.04396122195092695, 0.034982931401048384, 0.009644170042260416, 0.05374438734725118, 0.03503100221444454, 0.01480112354537206, 0.02594083989970386, 0.12388895930988447, 0.04539631673001817, 0.056599873051579506, 0.022194763412699103, 0.04028363339602947, 0.02139339150328721, 0.016360239258834293, 0.030426243054015294, 0.029071154338972907, 0.022815673844888806, 0.06293918485088007, 0.019190800675590123, 0.11448979723666396, 0.03765546031562345, 0.011052793473936617, 0.016993677143805792, 0.025346356710152965, 0.04009675806654351, 0.022521866485476494, 0.05395334559891905, 0.03618022340482899, 0.02387893821911088, 0.042620233193572075, 0.040240929794630835, 0.05945224767284734, 0.021039062212886553, 0.07039072071867329, 0.047017659193703105, 0.054274689605725665, 0.0322162828940366, 0.041787670725690465, 0.07609896441655499, 0.03079435508698225, 0.04782834569258349, 0.03995339379512838, 0.028477273349251066, 0.014053083640257162, 0.015247999923303723, 0.047429519771997414, 0.023488351409988742, 0.017811841098591685, 0.02853968839294144, 0.003147046688744532, 0.38516787918550627, 8.362488780702863, 33.41593674251011, 46.291747774396626, 36.64825957162039, 31.20688901628767, 32.56821482522147, 28.941375017166138, 13.670649341174535, 3.3591042203562598, 0.35717535125357763, 0.0734288137672203, 1.226420127919742, 1.3293216462646211, 0.09337152114936284, 0.23743161665541784, 0.08855672486658607, 0.08199580013751984, 0.32384782816682545, 0.5354308975594384, 1.4082344004086085, 6.831259105886732, 11.548500997679573, 19.64840953690665, 28.01313737460545, 30.54523638316563, 36.18047904968262, 41.512373788016184, 45.64343915666853, 49.0223377091544, 48.03048930849348, 49.37507690702166, 52.34338903427124, 48.96278469903128, 50.752668448856895, 51.253494603293284, 50.57830340521676, 51.354337283543174, 51.242433071136475, 49.32239219120571, 48.34212643759591, 48.03345966339111, 43.19160747528076, 40.84024327141898, 40.953689983912874, 40.55098628997803, 41.04925898143223, 40.575972012111116, 40.16485057558332, 42.50439936774117, 47.74442502430507, 49.83821603230068, 49.651351179395405, 51.307965006147114, 44.89564970561436, 35.17746836798531, 49.61494261877877, 49.26735551016671, 50.89821236474173, 49.799966199057444, 44.57313517161778, 41.58279378073556, 36.148920331682476, 34.50923579079764, 34.759832995278494, 37.941906452178955, 46.94082069396973, 46.909102167402, 48.42501149858747, 47.23097051892962, 46.90564891270229, 44.75233963557652, 45.45832872390747, 46.75172199521746, 45.413380827222554, 48.77898400170462, 47.51236908776419, 44.55927351542881, 46.33372531618391, 45.5346268926348, 45.34402738298689, 45.9308374949864, 47.81942387989589, 48.56551102229527, 45.48977974482945, 40.93820244925362, 29.842832565307617, 18.048421791621617, 6.870025711400168, 3.9348087225641524, 2.471457302570343, 4.535340223993574, 0.9637188357966286, 0.4049412581537451, 0.4131868157003607, 0.22123437507876328, 0.40904710069298744, 0.04015855225069182, 0.2319436797073909, 0.08865648308502776, 0.2534686561141695, 0.7633049956389836, 6.407786812101092, 10.201318246977669, 20.25910929271153, 35.17753437587193, 35.22437913077218, 37.30454472133091, 21.9122941834586, 4.88243922165462, 0.21553332385207924, 0.014618321122335536, 0.03128662545766149, 0.0038665058507051852, 0.05280760529318026, 0.035976079359118424, 0.023847364288355623, 0.028918192189718996, 0.04767677114744272, 0.07012585457414389, 0.03357368541349258, 0.017856164702347348, 0.004764938377775252, 0.04059116582253149, 0.03726871231836932, 0.064917725111757, 0.038403460356806, 0.039567175055188794, 0.046325967381043096, 0.06356915711824383, 0.0484654188289174, 0.027419053882892643, 0.04044186436970319, 0.026345519881163324, 0.032182186509349515, 0.01335754114136632, 0.04135196642684085, 0.024824671846415316, 0.025541812114949738, 0.07518678264958517, 0.0816197492448347, 0.15337862047765935, 0.13038822556180613, 0.1597306446305343, 0.1317564642855099, 0.21937216286148342, 0.150476268359593, 0.08184895837413413, 0.06171734005744968, 0.17185219776417526, 0.08696148225239345, 0.0692520100357277, 0.11475925706326962, 0.1347798534802028, 0.09772174486092158, 0.1245900352618524, 0.22280761280230113, 0.09350646819387164, 0.1667285119848592, 0.20398319219904287, 0.13087930849620275, 0.13017047010362148, 0.12566231058112212, 0.16509442324084894, 0.2569577374628612, 0.11296151245811156, 0.1653577626815864, 0.19449119296457085, 0.1144448375063283, 0.1296556248728718, 0.13418814380254063, 0.15360588899680547, 0.17528053665799753, 0.1687274897204978, 0.06591112073510885, 0.15972836475287164, 0.43331352142351015, 10.208022390093122, 38.42165872028896, 52.642074721200125, 43.667531285967144, 40.3132814679827, 39.247889859335764, 31.25169447490147, 16.111429044178553, 4.566475101879664, 0.6143331751227379, 1.1697267357792174, 5.878694951534271, 1.4698757784707206, 0.451632311301572, 0.7908289272870336, 0.22836790872471674, 0.24161614211542265, 0.8449297728283065, 0.6654367957796369, 1.5052566570895058, 7.889645627566746, 12.565909215382167, 21.069076435906545, 27.762934480394634, 32.95546572549002, 36.95332023075649, 41.41446672167097, 47.00655065264021, 48.862331117902485, 49.46840858459473, 50.354085036686485, 53.89785391943795, 50.58766262871878, 50.85678373064314, 52.86074147905622, 52.8464629309518, 52.02054793494088, 54.207681042807444, 52.12745291846139, 50.90109586715698, 49.70032555716378, 43.75991800853184, 43.10909414291382, 42.181968212127686, 41.694913387298584, 42.32036937986101, 42.78848688943045, 41.5148195539202, 44.48128693444388, 50.402715478624614, 50.89040606362479, 51.100575174604145, 51.60100180762154, 44.679001399448936, 39.08893244607108, 48.257563386644634, 51.18049682889666, 51.0032274382455, 50.39959921155657, 46.0236793245588, 41.81990800585066, 37.17463772637503, 35.50988755907331, 35.87118346350533, 39.30464274542672, 47.725730895996094, 49.7604934828622, 49.289655753544395, 48.10332727432251, 47.80038581575666, 44.86100946153913, 46.19390671593802, 46.42466681344168, 44.61161776951381, 50.9045421736581, 49.91606364931379, 47.18537991387503, 48.562412125723704, 47.359449659075054, 47.42327233723232, 47.641292912619456, 50.023270879473, 50.65549094336373, 45.687615803309846, 42.21418006079537, 30.92249924795968, 19.727653741836548, 8.151036858558655, 2.9990253363336836, 4.145040367330823, 6.175598859786987, 2.1426746249198914, 2.5213388545172553, 1.1783472789185387, 0.4976997364844595, 1.102542323725564, 0.106658695664789, 0.4456791164619582, 0.2533547436552388, 0.466521649488381, 1.0201496077435357, 6.053870763097491, 12.9730258839471, 25.048196860722133, 42.55093840190342, 41.971788678850444, 42.48691075188773, 25.847931044442312, 5.832102937357766, 0.3429271200937884, 0.13349008054605552, 0.19164483355624334, 0.12165250788841929, 0.11145903915166855, 0.06921626481094531, 0.11919705250433513, 0.1636865580720561, 0.13405038762305463, 0.15521198138594627, 0.17353401466139726, 0.058069501870444844, 0.3311242748584066, 0.1510809923389128, 0.19949355668255261, 0.15916680917143822, 0.07331681477704219, 0.07703841650592429, 0.2366782527949129, 0.11226973243589912, 0.1287369155990226, 0.10796630728457655, 0.09698533759053264, 0.18213072765086377, 0.1531016289123467, 0.10354502060051475, 0.1573441826871463, 0.10624955261924438, 0.11550164222717285, 0.15821544879249164, 0.14336319932980196], [0.023855080927855203, 0.013813654925408108, 0.06519052333065442, 0.015809667463015233, 0.04040690963821752, 0.027405493360544955, 0.05910972319543362, 0.02991989647437419, 0.020857465885845677, 0.022036242365304912, 0.03494253142603806, 0.04393439606896468, 0.010538743825496306, 0.028616579981254678, 0.034319850017449686, 0.012675359845161438, 0.02398250810801983, 0.02122991545391934, 0.02899472415447235, 0.05371041309886745, 0.028615487539874654, 0.04412698466330767, 0.030448990940515484, 0.01526188783879791, 0.04281905073938625, 0.015149997414222785, 0.0371255414294345, 0.040876649253602536, 0.04588415626702564, 0.01615964395127126, 0.005765118927229196, 0.043541341088712215, 0.036171334596084695, 0.010671081902858402, 0.0412633293973548, 0.04022218526474067, 1.423654732959611, 14.585788760866437, 42.55259207316807, 40.9067896434239, 33.98554311479841, 22.760083845683507, 18.055502005985804, 19.491866622652324, 7.5435654095241, 1.2780938808407103, 0.17044524183230741, 1.7907002717256546, 1.5523611009120941, 0.1043569827452302, 0.06754129433206149, 0.02525633546922888, 0.0876061651589615, 0.4391468326960291, 0.08128166238644294, 0.06091621411698205, 0.9909340611525944, 4.055759489536285, 6.877944052219391, 13.596892476081848, 19.117846829550608, 21.39577899660383, 29.910355159214564, 35.06198583330427, 39.708635330200195, 44.35044540677752, 45.46035759789603, 49.132619517190115, 50.57566656385149, 50.19639219556536, 51.78370468957083, 50.04142304829189, 49.12697063173567, 48.885131631578716, 46.295544964926584, 44.50322239739554, 39.851240158081055, 39.48054681505476, 40.98342479978289, 43.886166776929585, 41.88438034057617, 43.475844383239746, 41.00351551600865, 37.78965752465384, 40.88872085298811, 44.14558124542236, 47.32700157165527, 49.97246217727661, 49.27425159726824, 46.588276045663015, 32.46559688023159, 49.72126742771694, 47.9480767250061, 47.605276925223215, 46.09003809520176, 43.745927810668945, 37.459284578050884, 35.61174120221819, 35.00197424207415, 35.62534230095999, 36.26126228060041, 44.93641478674752, 47.43098136356899, 48.01639836175101, 49.72715255192348, 47.44543014253889, 46.95763880865914, 47.081358432769775, 47.84959643227713, 46.77707249777657, 46.04996088572911, 45.66806009837559, 45.089452334812705, 44.734260422842844, 44.96899836403983, 45.28524909700666, 45.45585863930838, 48.16526699066162, 46.82154444285801, 37.86035891941616, 29.81941713605608, 19.60730573109218, 7.413156407220023, 1.8010923883744647, 1.6671732429947173, 2.217151931353978, 6.759768222059522, 1.2927584882293428, 0.4930593711989266, 0.25591605050223215, 0.1627260646117585, 0.25939207683716503, 0.09151418759886708, 0.12654591245310648, 0.010499735695442982, 0.10522305805768285, 0.9912816882133484, 4.264875514166696, 14.122097253799438, 25.77431661742074, 29.527811663491384, 32.84327663694109, 27.517541476658412, 10.478352478572301, 2.0249964594841003, 0.0778327231694545, 0.018691113917157054, 0.031336358681853325, 0.007353493494779936, 0.05752861446567944, 0.024516320088878274, 0.053402914599116356, 0.03421735391020775, 0.01596233614587358, 0.0486989129068596, 0.04142516678465264, 0.03427283771868263, 0.023451379733160138, 0.020196016378966824, 0.0063632848655938035, 0.05706727172115019, 0.0760577434141721, 0.03564854372026665, 0.05984688363969326, 0.05455984055463757, 0.003924293285568378, 0.06419893939580236, 0.03310745043147888, 0.038819918009851656, 0.0547963812548135, 0.021010360181597725, 0.040190884444330416, 0.007332179013506642, 0.013423196189770741, 0.022481663285621574, 0.051719682956380506, 0.03940929013437458, 0.028410010172852447, 0.06833735161593982, 0.03339868783950806, 0.022367723685290133, 0.023293952823483517, 0.04009074963895338, 0.020045729354023933, 0.018315892533532212, 0.013161259620184345, 0.020157745307577506, 0.020541974243574908, 0.020458314268450652, 0.0789336326665112, 0.03841416085405009, 0.012184406680587147, 0.03460086190274783, 0.025910997929583703, 0.02297183867943074, 0.05945263443780797, 0.03503886643531067, 0.0804084963830454, 0.02398124772922269, 0.050330582673528364, 0.04099094508481877, 0.03430290699803403, 0.015993131457694938, 0.04449567345104047, 0.02576479229277798, 0.03061086903991444, 0.06084621644445828, 0.053149125538766384, 0.028651320974209478, 0.02809954817140741, 0.04883330015997801, 0.021671132849795476, 2.09922428216253, 18.33745469365801, 49.35861662455967, 44.63308770315987, 34.97635970796858, 23.502519709723337, 20.797488723482402, 23.227817467280797, 9.108764392989022, 1.5605455360242297, 0.04191688075661659, 0.15823412207620485, 0.31947407286081997, 0.028314840547474365, 0.03468659140967897, 0.06297143562031643, 0.1044306852189558, 0.2661957474691527, 0.6200310779469353, 0.23111972106354578, 1.7042435109615326, 3.1163241735526492, 6.3567861659186224, 15.552785192217145, 20.578625679016113, 23.033304384776525, 30.827576432909282, 39.01275587081909, 42.315095697130474, 47.54006808144705, 47.19745240892683, 50.87852464403425, 50.98253917694092, 50.60998024259295, 52.54804127556937, 51.96633114133562, 50.80682270867484, 49.36634649549212, 49.31258828299386, 47.19650050571987, 41.8741317476545, 41.508951800210134, 42.389573437826975, 44.97157614571707, 44.36310849870954, 45.81143965039934, 42.88534130368914, 39.80470807211739, 43.209919452667236, 45.66344649451119, 47.98050396783011, 52.04036767142159, 50.55391870226179, 46.8992600440979, 36.45122255597796, 47.28675413131714, 49.32136385781424, 49.087299891880576, 47.7792181287493, 45.99784592219761, 39.10182135445731, 36.85174451555525, 35.48523187637329, 36.206166539873394, 38.48321975980486, 45.3354046685355, 47.87500599452427, 49.16472019468035, 49.03947196687971, 47.43484108788626, 47.37292569024222, 46.431993688855854, 48.42154087339129, 47.90082550048828, 47.304201057979036, 47.190003940037315, 46.491505009787424, 45.535200119018555, 45.358945165361675, 44.66446229389736, 45.77905757086617, 47.896677425929475, 47.03922455651419, 38.329195567539756, 31.586948531014578, 20.883992058890207, 8.917196478162493, 2.476605700595038, 2.6045952098710194, 3.504020844187055, 2.6407288823808943, 0.8325119305934224, 0.17096871802849428, 0.2385563834437302, 0.10580737170364175, 0.2284756600856781, 0.030695482356739894, 0.26313270468797, 0.09455394305820976, 0.1600349811570985, 1.2991840520075388, 5.015812064920153, 14.31057756287711, 27.204810006277903, 33.28260775974819, 37.330023765563965, 32.138597284044536, 12.479116661208016, 2.656930995838983, 0.038660957611032894, 0.07528329747063772, 0.04293271214036005, 0.03699257231450506, 0.021774522926924483, 0.07878683161522661, 0.03344149322115949, 0.020258640072175434, 0.023657254043168256, 0.03925798021789108, 0.03937241514878614, 0.05780403182974883, 0.042156417188899856, 0.0283182366152427, 0.018845556969089166, 0.063752510850983, 0.12421537536595549, 0.009597168769687414, 0.004258605792918908, 0.020929197215342095, 0.02189682038234813, 0.032616730513317246, 0.07389614119061402, 0.024730808400948132, 0.062376401121062894, 0.028830203161175762, 0.023987875320017338, 0.04938441987282463, 0.021587978383260112, 0.028595338442495892, 0.01060128100549004, 0.23967346921563148, 0.06634536279099328, 0.19699410508785928, 0.1106441185942718, 0.1603385577244418, 0.08617545371609074, 0.1482410654425621, 0.14709225137318882, 0.0837643202394247, 0.0885397411350693, 0.08770457309271608, 0.11233668348618916, 0.13087557655360016, 0.14165456672864302, 0.0909651577738779, 0.09923763959003346, 0.1428909253861223, 0.11199291050434113, 0.11857729218900204, 0.22535372046487673, 0.13432078382798604, 0.13984271538044724, 0.14717014719332966, 0.22308030245559557, 0.10107047802635602, 0.089703598325806, 0.1313348633370229, 0.2092638909816742, 0.1339696283851351, 0.19346006400883198, 0.12374766117760114, 0.2505950331687927, 0.12995530664920807, 0.11881160390164171, 0.1595599659319435, 0.12759898523134844, 2.5553724340030124, 23.63707331248692, 55.356593472617014, 51.409530299050466, 45.74944087437221, 31.864806992667063, 25.77525462423052, 28.251995597566875, 9.843214171273367, 2.304294283900942, 0.39589397077049526, 3.9145126002175465, 3.9115683010646274, 0.3090144826897553, 0.562937567276614, 0.26269461533852984, 0.4838975742459297, 0.8766003676823207, 0.8677153044513294, 0.6661294986094747, 2.2108896502426694, 5.0747353945459635, 8.365948115076337, 16.21073964663914, 21.198483160563878, 23.420261723654612, 32.67275047302246, 37.378105299813406, 43.303112166268484, 49.123659815107075, 50.354925768715994, 51.58177614212036, 51.07115650177002, 51.96460451398577, 53.0492183140346, 53.306138379233225, 52.010382720402305, 52.17530516215733, 51.486321789877756, 48.54451356615339, 42.39198446273804, 43.14383513586861, 44.4972608430045, 47.87574945177351, 45.62930652073452, 47.733113356998985, 45.56408725466047, 42.07702956880842, 45.01135458265032, 46.96407284055437, 50.37842457635062, 53.77587481907436, 50.77394035884312, 47.45040852682931, 38.81226907457624, 48.21752439226423, 50.349335942949565, 51.318307399749756, 49.80679280417306, 48.37006861822945, 40.528911863054546, 38.27676446097237, 37.7676317351205, 38.816403252737864, 39.719172273363384, 47.077953815460205, 50.16106407982962, 51.61723279953003, 50.01392902646746, 47.88160678318569, 47.72364296231951, 47.64293268748692, 49.4421443939209, 47.23232889175415, 48.05807018280029, 48.0565242086138, 48.899299008505686, 47.65889269965035, 46.96551806586129, 46.69491352353777, 47.627424308231895, 50.3658309664045, 49.22798006875174, 40.03957455498831, 32.79714754649571, 23.96557719366891, 9.504866429737636, 3.1401636600494385, 3.9729834284101213, 5.235956617764064, 12.111764533179146, 4.380582128252302, 1.0223943101508277, 0.8091214714305741, 0.4554606058767864, 0.7201890349388123, 0.26633042309965405, 0.594212820487363, 0.5129624860627311, 0.2001313931707825, 1.8759421833923884, 7.676195229802813, 21.982104471751622, 35.076670851026265, 40.7221725327628, 42.7845333644322, 37.00181518282209, 13.921526210648672, 2.750405111483165, 0.1309464563216482, 0.3258735808942999, 0.132986702557121, 0.1293841294412102, 0.1446517916130168, 0.14254073346299784, 0.22257402033678123, 0.06316561877195324, 0.10146090707608632, 0.11475613580218383, 0.1941966409129756, 0.12129912685070719, 0.1364172806165048, 0.08311025997889893, 0.14658762487982, 0.13280997132616384, 0.20556052827409335, 0.17910671420395374, 0.14270525106361934, 0.1626547234398978, 0.13686302384095533, 0.09610916567700249, 0.142581309857113, 0.13445620584700788, 0.1351896614900657, 0.11401666833886079, 0.14791101243879112, 0.11612147039600781, 0.1065611494705081, 0.08202223586184637, 0.09541917698723928], [0.010805011993008, 0.02692982504543449, 0.04940091845180307, 0.03835489082017115, 0.026740808937964693, 0.033256768847682645, 0.005580459014579121, 0.07724562074456896, 0.10238960438541003, 0.040536207878696065, 0.04451901166300688, 0.03368685148390276, 0.0022841636715124226, 0.0509663869493774, 0.024615028274378607, 0.04511820897459984, 0.035744071272867065, 0.0290411359497479, 0.02405232427242611, 0.03842053569055029, 0.045867426986140866, 0.04646366249237742, 0.06981211355222122, 0.005019730397699667, 0.03487018941502486, 0.024500399961003234, 0.016059799219614694, 0.06414408662489482, 0.05091535772329994, 0.05020467710814305, 0.04826501690383468, 0.009717992107783045, 0.03602340378399406, 0.03868852988151567, 0.04368801321834326, 0.06431589847696678, 0.31454367456691606, 6.662675831999097, 27.922411271503993, 43.06528575079781, 39.46514613287789, 28.111582926341466, 25.64220530646188, 21.713733775275095, 12.895095757075719, 6.910174574170794, 0.1179862203342574, 0.1603626050055027, 0.16210220594491276, 0.10380030583058085, 0.11552202541913305, 0.05593545495399407, 0.036725212553782124, 0.02214264853059181, 0.4573058954307011, 0.12912711394684656, 0.5180365709321839, 0.08535686906959329, 0.6089111917785236, 5.7344842212540765, 9.267966730254036, 14.913818427494594, 17.230033431734356, 25.821331603186472, 30.150238241468156, 37.007321630205425, 40.64341470173427, 45.051577704293386, 52.986601148332866, 50.912074020930696, 52.83542224339077, 50.75445760999407, 48.399209363119944, 45.67886454718453, 45.2833696092878, 44.27564457484654, 45.50439875466483, 44.91809933526175, 47.5067514692034, 48.61520453861782, 47.281365803309846, 46.50761093412127, 43.782249518803184, 42.77899217605591, 41.46928800855364, 44.716424397059846, 47.71169900894165, 50.52419430868966, 51.207077162606375, 43.44978516442435, 34.34407016209194, 47.53350550787789, 50.29640456608364, 45.97127948488508, 46.439324038369314, 40.94984763009207, 36.581598554338726, 34.94101422173636, 34.44722311837332, 37.377299308776855, 35.63472236905779, 42.31385891778128, 47.49852480207171, 47.42854601996285, 48.223454679761616, 43.80870131083897, 46.348316533224924, 46.62231527056013, 46.354062693459646, 46.89819349561419, 47.943129607609336, 46.00398465565273, 47.348363808223176, 45.855293205806184, 46.9389967918396, 45.8723440851484, 45.010743141174316, 45.7154016494751, 39.31157009942191, 27.632398673466273, 18.454752445220947, 7.377600737980433, 1.7874464520386286, 0.5011340464864458, 3.4851139272962297, 3.5843096673488617, 2.834351075547082, 0.20409578830003738, 0.19420057641608374, 0.07356089739395039, 0.20608774998358317, 0.12030086613127164, 0.1929458158888987, 0.6186887728316444, 0.05773602905017989, 1.0064721873828342, 6.0344635759081156, 19.47599867412022, 28.143761771065847, 28.602565220424108, 33.76671654837472, 32.305555547986714, 21.272121906280518, 4.051287889480591, 0.4384494072624615, 0.06044123960392816, 0.05522699993369835, 0.03823527188173362, 0.02492423837871424, 0.04831630736589432, 0.02593533867704017, 0.010148398744474565, 0.018125329366219894, 0.019082933963675584, 0.03609995949747307, 0.029353469011506865, 0.02006291494970875, 0.03679160720535687, 0.033841062137590985, 0.05837923275040729, 0.03345919619979603, 0.024704343838883296, 0.08298537560871669, 0.03223431835483227, 0.01273062652243035, 0.08363725098648242, 0.016782622218930295, 0.05478564343814339, 0.058984994888305664, 0.03944183945921915, 0.045523369019584994, 0.03293500075648938, 0.03500032564625144, 0.015648537448474338, 0.01931656035594642, 0.01931113377213478, 0.027670227190745727, 0.06984948726104838, 0.031729501871658225, 0.028827468665050607, 0.0113072687028242, 0.012798256107739039, 0.0585027261238013, 0.04627033429486411, 0.030008608142712286, 0.03723181697673031, 0.021573885210922787, 0.01775569741481117, 0.0167130384527679, 0.024863417892317687, 0.023901397728228142, 0.011087147701930786, 0.015572039410471916, 0.0916397844308189, 0.04953159411836948, 0.014543814584612846, 0.0934210406350238, 0.10686847155115434, 0.018422858490209495, 0.007289955475633698, 0.02217698409887297, 0.011608759623153933, 0.013533484423533082, 0.05480934466634478, 0.037692392976688485, 0.03055007230224354, 0.041496450281036754, 0.03878284285643271, 0.0040126538120343214, 0.02752682051089193, 0.06337694850351129, 0.04951198784900563, 0.28192389064601486, 8.846528087343488, 33.29294320515224, 47.92180906023298, 44.310243129730225, 28.912623371396744, 24.304487739290508, 27.047617435455322, 16.339983088629587, 8.235357591084071, 0.3119668428386961, 0.04116949139695082, 0.1997331745390381, 0.17874387438808167, 0.05318585463932582, 0.03422508920942034, 0.019618048731769835, 0.1419859089489494, 0.7975445783564022, 0.38976449253303663, 0.8174390622547695, 1.033647134900093, 2.384999564715794, 7.798573851585388, 12.566155876432147, 16.092813083103724, 18.466467108045304, 27.92537294115339, 31.864939008440288, 38.991372789655415, 44.34256614957537, 47.33867107118879, 52.12034491130284, 51.49018151419503, 53.80384826660156, 52.2674104826791, 49.1719845363072, 48.735450063432964, 47.726366656167166, 45.673062801361084, 46.43920244489397, 48.55247272763933, 48.28178480693272, 50.657669203622, 48.25553798675537, 48.89361538205828, 45.71189628328596, 44.304590770176475, 43.045830794743125, 47.04124995640346, 50.93894965308053, 51.68676342282976, 51.82767636435372, 44.81889295578003, 37.815070561000276, 48.29354463304792, 50.58311850684029, 47.69106633322579, 49.33675064359392, 43.709036350250244, 37.22019011633736, 38.49183552605765, 34.88242353711809, 39.022406918661936, 36.7759222984314, 44.75797462463379, 48.89748205457415, 48.53125292914254, 48.96122830254691, 47.20048182351248, 46.70109742028372, 46.995701040540425, 46.75023855481829, 47.089838709150044, 48.879951749529155, 46.682622160230366, 48.73413337979998, 46.64898245675223, 47.24378994532994, 47.22600603103638, 46.55089473724365, 46.842726026262554, 41.903171743665425, 30.294441155024938, 21.010765416281565, 9.787284646715436, 3.3675421561513628, 2.0977493098803928, 6.051233487469809, 3.4530538533415114, 2.152209507567542, 0.06681252736598253, 0.13563472617949757, 0.0943296125956944, 0.7794156968593597, 1.038765243121556, 0.23854321986436844, 0.11171192236776863, 0.04934732775603022, 0.8890464912567819, 5.043392070702144, 19.41978427342006, 35.49148872920445, 32.74883324759347, 37.7757750238691, 35.88829687663487, 25.517571994236537, 5.592617205211094, 0.7030078768730164, 0.0044909289738695535, 0.014882342490766729, 0.0504039119529937, 0.01377006244313504, 0.014122228054994983, 0.036696211967085085, 0.03690987585910729, 0.03191640434254493, 0.02892990709681596, 0.014568231667258909, 0.020110826307375516, 0.047086669597774744, 0.049946012773684094, 0.04403572848864964, 0.04457649375711169, 0.04497947570468698, 0.03894626801567418, 0.050596704107842276, 0.022210525781182305, 0.04965070415554302, 0.07708748815847294, 0.023216345380725603, 0.05401261563279799, 0.020286387065425515, 0.03256384549396379, 0.02902158396318555, 0.007623524138970035, 0.045597207200314314, 0.03800383037222283, 0.015762022430343286, 0.01693696349060961, 0.14201250752168043, 0.121449028807027, 0.11276213851358209, 0.17379366287163325, 0.11275040664310966, 0.1458176097699574, 0.10325350838580302, 0.19434266164898872, 0.12711029074021749, 0.12394238715725285, 0.11098415963351727, 0.13027592801621982, 0.09606696758419275, 0.16164336699460233, 0.08500961520309959, 0.11251021881720849, 0.13785462134650775, 0.16480561159551144, 0.15503838498677525, 0.10114606004208326, 0.1833173632621765, 0.08994975047452108, 0.14038877322205476, 0.0990731016333614, 0.1092761784259762, 0.12639862964195864, 0.17464968908045972, 0.16855491112385476, 0.12551684624382428, 0.20235578023961612, 0.21652944040085587, 0.15159700464989456, 0.17422677177403653, 0.11725056623773915, 0.17726359596209867, 0.1476767821503537, 0.5700743986027581, 11.336864948272705, 39.00159011568342, 55.67960132871355, 50.858367919921875, 38.00168875285557, 36.10181154523577, 29.371473721095494, 19.823683057512554, 16.835785695484706, 0.890208034643105, 0.5846201809389251, 1.2547740978854043, 0.4258819616266659, 0.20348068273493222, 0.17959359022123472, 0.21009310148656368, 0.38637141031878336, 1.261301930461611, 0.381633037435157, 1.088808449251311, 0.6186540318386895, 1.7674673412527357, 7.424874544143677, 12.550097720963613, 17.48740860394069, 18.90752485820225, 28.44400211742946, 33.36113282612392, 40.35398054122925, 46.83621556418282, 49.758367334093364, 55.5420686858041, 53.31075545719692, 55.62842437199184, 54.91420514242989, 51.697578293936594, 50.64038903372628, 50.78322662625994, 48.19258383342198, 49.86096443448748, 49.53420107705252, 52.889819690159385, 53.29005329949515, 50.96341078622, 50.259363719395225, 48.89510924475533, 46.61707632882254, 44.93002939224243, 50.154720374516074, 53.02443061556135, 52.08803578785488, 52.98444373267037, 44.06127527781895, 42.566564900534495, 49.28326688494001, 52.04084014892578, 48.96886089869908, 50.785957268306184, 44.39399324144636, 39.060368401663645, 39.132640089307515, 37.45992381232125, 41.18162563868931, 38.78020313807896, 47.33523171288626, 51.29392964499337, 50.513490608760286, 51.61036103112357, 47.516916683741975, 47.02076319285801, 46.13926955631801, 47.76036071777344, 46.92717095783779, 48.81852967398507, 47.4333541733878, 50.977150848933626, 48.310585090092246, 49.24142483302525, 50.2101982661656, 47.43229457310268, 48.41454403741019, 40.9388382094247, 30.313882214682444, 21.742745978491648, 9.100690586226326, 2.709920129605702, 1.5452840349503925, 7.973126496587481, 6.363572818892343, 6.008878571646554, 0.8615299963525364, 0.5055227567042623, 0.24893932629908833, 0.8257522018892425, 1.8567495218345096, 0.43097925239375656, 1.2742914791618074, 0.4843512156179973, 1.955281708921705, 7.560012664113726, 25.0852689743042, 36.38576010295323, 36.51526757649013, 43.65687274932861, 43.71062748772757, 29.46571213858468, 6.979759480272021, 0.9462131751435143, 0.12703053573412554, 0.21040184849074908, 0.14471230336597987, 0.1652849287326847, 0.21589939349464007, 0.10094847064465284, 0.11607527573193822, 0.12846563729856694, 0.11764841846057347, 0.07704007213136979, 0.16119695880583354, 0.14015739278069564, 0.1032858948622431, 0.12516042536922864, 0.15099260636738368, 0.19949917495250702, 0.09900794191552059, 0.2556667024535792, 0.09559796417930297, 0.17375869117677212, 0.13770249379532679, 0.10861096983509404, 0.18558476945119246, 0.13070709630846977, 0.1644022496683257, 0.18291942961513996, 0.1610547921487263, 0.14275284350982734, 0.15378310877297605, 0.10481738232608352, 0.12319447871829782], [0.040456737857311964, 0.06153295495148216, 0.02721033481481884, 0.04029999966067927, 0.031315575154232125, 0.05001180352909224, 0.005444398748555354, 0.040202558639326265, 0.052927739918231964, 0.025534468669710413, 0.020933012278484445, 0.0943414123196687, 0.015775123245215843, 0.04388635918231947, 0.013807257188351026, 0.07499025176678385, 0.026726135618186424, 0.0336407450293856, 0.023627378146297166, 0.03672837791964412, 0.011626655136102011, 0.037724850699305534, 0.017716003116220236, 0.07118365674146584, 0.032256418240389655, 0.019048248949859823, 0.028433858982420394, 0.026827093147273575, 0.051134846838457246, 0.011596657951096339, 0.05531115523938622, 0.02416287119766431, 0.04601458426831024, 0.04146964814780014, 0.040303280377494435, 0.04267020729769554, 0.030376004321234565, 1.3773067742586136, 17.533650602613175, 35.88015011378697, 39.082380294799805, 32.03891495295933, 15.277176209858485, 21.762984343937465, 21.103876488549368, 6.5210098794528415, 2.6923240338053023, 0.09083200884716851, 0.04834285844117403, 0.012186197164867605, 0.030938730375575166, 0.061357587575912476, 0.019389433320611715, 0.041489661538175175, 0.21290645695158414, 0.30969651894909994, 0.25127796509436195, 0.03617136173748544, 0.7250547824161393, 1.062149514045034, 2.9016945362091064, 6.4234020199094495, 11.731892619814191, 18.444073063986643, 22.177588565008982, 28.255457537514822, 35.207168442862375, 38.87193325587681, 49.34006493432181, 51.32037796292986, 49.73713711329869, 50.3081887108939, 48.30360215050833, 47.83627673557827, 47.07539687837873, 47.204001086098806, 45.515623569488525, 47.720269611903596, 48.375748770577566, 48.139030592782156, 48.508191858019146, 47.96892826897757, 44.83295610972813, 43.02994721276419, 41.53402784892491, 43.81858164923531, 46.82806880133492, 50.20080777576992, 51.58315535954067, 51.22528144291469, 35.08187157767159, 46.89890916006905, 49.75214869635445, 48.63136952263968, 46.40385348456246, 42.02893761226109, 35.00863061632429, 36.526912757328574, 37.32805047716413, 35.372153418404714, 35.60622433253697, 38.00034080232893, 45.10156304495675, 47.578015668051584, 47.017087595803396, 47.271006039210725, 48.58237430027553, 47.77416678837368, 47.186206749507356, 48.16637870243618, 47.55669859477452, 47.23217255728585, 47.20395244870867, 47.88902051108224, 47.529746532440186, 45.767141410282676, 43.8956858089992, 36.50499813897269, 29.21486132485526, 17.963483537946427, 9.373471651758466, 1.9887190461158752, 0.48587135119097574, 3.0244956953184943, 4.1047012976237705, 3.5145532275949205, 0.5837364569306374, 0.20326908837471688, 0.033291811788720746, 0.17902718989976815, 0.2903544711215155, 0.25351653354508535, 0.2740762803171362, 0.06774581157203231, 0.3654130649353777, 2.9029278414590016, 10.668976306915283, 9.918325935091291, 12.739163415772573, 22.0874183177948, 27.658025366919382, 26.629011051995413, 11.86346457685743, 1.9682420534746987, 0.050881987371082814, 0.021852352589901005, 0.023070521419867873, 0.007189360962781523, 0.035278029673333676, 0.029802089224436452, 0.04871675498517496, 0.04596740912113871, 0.0404916586620467, 0.045843121861772876, 0.011592617275060287, 0.03509493378390159, 0.02948640419968537, 0.028729216794350317, 0.017156082804181745, 0.028238422237336636, 0.08458633827311651, 0.03926062650446381, 0.025751908609111394, 0.014117993148309844, 0.033923171660197635, 0.023374243872240186, 0.05485012801364064, 0.024246889100010906, 0.04722485664699759, 0.06262059908892427, 0.039913957339844534, 0.018601370875590613, 0.04549850071115153, 0.033144074359110424, 0.029451249300369194, 0.022959506305466806, 0.008190838786374246, 0.04823134460353425, 0.05698308588138648, 0.053636982039149315, 0.02051158605276474, 0.024177381669038107, 0.015496671133275543, 0.03111520715590034, 0.020674985766943012, 0.032450692994253974, 0.02410796075128019, 0.010909357108175755, 0.03613175225577184, 0.04484089171247823, 0.06259567649768931, 0.0315208184266729, 0.015686788163813095, 0.022303434188610742, 0.05106789239549211, 0.02660699504693704, 0.04658005838947637, 0.02463375753723085, 0.03652264949466501, 0.019002980486090695, 0.0035043971563157228, 0.0266558122488537, 0.01819990884645709, 0.06319335049816541, 0.06305458330150161, 0.08432941777365548, 0.06476334482431412, 0.04524206197155373, 0.03239644072683794, 0.04556981474161148, 0.031466562766581774, 0.04752307618036866, 0.07693315536848136, 1.8500712173325675, 21.38278239113944, 41.105233669281006, 45.32702166693551, 37.32546922138759, 20.77219033241272, 23.540020874568395, 24.034793410982402, 8.1173962865557, 2.8503558167389462, 0.04963496553578547, 0.12123149048004832, 0.0728865150096161, 0.08261952309736184, 0.12391432294888155, 0.07879595112587724, 0.034117168214704306, 0.9282005131244659, 1.6219085518802916, 2.4405334762164523, 2.700496635266713, 2.0576149949005673, 3.961942740849086, 4.879169659955161, 9.567375898361206, 12.331516947065081, 20.55689866202218, 25.07964961869376, 32.03083419799805, 38.0612348147801, 42.243980884552, 49.34630789075579, 51.782419272831504, 51.68202822549002, 51.0430406161717, 49.63285854884556, 47.87322378158569, 47.379078320094514, 48.569176197052, 47.83284085137503, 50.8574264390128, 50.61763368334089, 48.96106154578072, 49.84569576808384, 49.590498856135774, 46.61232376098633, 44.24574647630964, 43.748964173453196, 46.68594339915684, 49.05733578545706, 51.91326080049787, 52.583129678453716, 50.45258617401123, 37.3172356060573, 48.84293174743652, 51.538721629551475, 48.7921473639352, 47.48102228982108, 42.977665492466514, 36.81984186172485, 38.07406118937901, 38.87700196674892, 37.46708393096924, 37.14703253337315, 39.943157877240864, 47.906675883701865, 49.38739606312343, 46.65697635923113, 49.18107278006417, 50.2847489629473, 49.147575514657156, 47.22208029883248, 48.69344820295061, 47.970717430114746, 48.13928420203072, 47.33150053024292, 48.99404811859131, 47.24667344774519, 47.65612036841256, 45.55897685459682, 40.23663936342512, 31.16310841696603, 21.344494342803955, 10.82366839476994, 3.9782058681760515, 2.9234510830470493, 4.793438443115779, 5.244135081768036, 5.7445478183882575, 0.8541975298098156, 0.36531657725572586, 0.1132883152791432, 0.2622122312230723, 1.1308077041591917, 0.6095884782927377, 0.163900975137949, 0.10220881551504135, 0.3022167831659317, 3.9567893488066535, 14.07718322958265, 19.71567678451538, 19.214513642447336, 26.460777793611797, 35.171906335013254, 31.194861684526714, 15.46899860245841, 2.9984390820775713, 0.12767451974962438, 0.037824693734624555, 0.022656711749732494, 0.03734141056026731, 0.03905297104003174, 0.02153895592450031, 0.05743408775223153, 0.01412647229153663, 0.052675297749894004, 0.03287875698879361, 0.037209886724927595, 0.02253958982016359, 0.03710751275398901, 0.03810528492821114, 0.017339112536449517, 0.0406352400646678, 0.07369952209826026, 0.018374063340680938, 0.002585993647309286, 0.022611231243770038, 0.11311995717031614, 0.060709240580243726, 0.015508967884151, 0.05727155825921467, 0.05573479179292917, 0.06960356581423964, 0.023816808160128336, 0.026949463545211723, 0.07289120368659496, 0.05934045224317482, 0.03106185734005911, 0.004882275742212576, 0.18691244535148144, 0.11901680646198136, 0.11058583922152009, 0.11848739986973149, 0.11119646645550217, 0.10947350998009954, 0.08824121286826474, 0.20758215550865444, 0.12988902734858648, 0.15292006651205675, 0.093660610994058, 0.24226767144032887, 0.09284757676401309, 0.19287933302777155, 0.09596282602953059, 0.1579985890005316, 0.07385751897735254, 0.0928168459130185, 0.09785702438758952, 0.1318111406373126, 0.13128003770751612, 0.08253932025815759, 0.10663005470165185, 0.17681036171104225, 0.08066868063594614, 0.09474023484757968, 0.11982283821063382, 0.1068791856190988, 0.13949730034385407, 0.15524970793298312, 0.2563146762549877, 0.10266321006097964, 0.13422885590365954, 0.17852387976433548, 0.08418022827910525, 0.18362003059259482, 0.20904910750687122, 3.2420629007475714, 24.571713720049175, 49.22246319907052, 50.49709633418492, 43.24548380715506, 25.189071587153844, 28.98227732522147, 29.4521700995309, 13.310637984957014, 5.130396110670907, 0.18487062491476536, 0.17350614044283116, 0.27919251578194754, 0.22531866734581335, 0.28055289707013537, 0.3629447716687407, 0.1283213264708008, 1.5783003547361918, 1.6393562385014124, 2.514741539955139, 3.231411095176424, 1.2819745583193642, 2.0813142146383012, 3.8367322938782826, 7.934191397258213, 12.6065422807421, 20.99585805620466, 24.029780285699026, 33.7049366406032, 40.790858949933735, 43.78277063369751, 51.182449272700715, 54.678647313799175, 53.377037797655376, 53.20279087339129, 51.81256750651768, 50.64038208552769, 50.333938734872, 49.90010711124965, 48.81256117139544, 52.797439915793284, 52.211842264447895, 50.673271383558, 52.41411474772862, 51.997598034994944, 48.94431986127581, 45.57602425983974, 44.386999879564556, 47.528450693402974, 51.96345458711897, 54.11459950038365, 53.622201510838096, 51.42686952863421, 41.475808892931255, 48.576405797685894, 53.0768860408238, 54.06218923841204, 50.28262281417847, 44.99885824748448, 38.026191575186594, 40.12560020174299, 40.7308577810015, 38.11040026800973, 38.57940367289952, 40.67038413456508, 48.281190735953196, 51.01839535576956, 49.403140681130544, 50.18189825330462, 52.56607532501221, 51.00743109839303, 49.05558136531285, 50.00854417255947, 50.04692254747663, 48.973061084747314, 47.538139956338064, 49.196633270808626, 49.88460568019322, 47.753951004573274, 46.81500966208321, 39.67421742847988, 32.61736985615322, 20.072214909962245, 10.870990838323321, 3.190734169312886, 2.1742826317037856, 6.4477046472685675, 6.37030518906457, 5.531933375767299, 2.0620761726583754, 0.5563961640000343, 0.16727182854499134, 0.5454473229391235, 1.6152014774935586, 1.5204821143831526, 0.9685306804520744, 0.31217930572373526, 0.6428035816976002, 4.612246360097613, 14.299619385174342, 16.63515646117074, 21.633152042116436, 33.286804471697124, 43.05513095855713, 38.88800096511841, 18.926674093518937, 3.6568060857909064, 0.2171139983194215, 0.14829316336129392, 0.1362494517649923, 0.14919296864952358, 0.10477913330708231, 0.11578623338469438, 0.2148107790521213, 0.1127910508907267, 0.1570054172937359, 0.20915859591748032, 0.16377407551876136, 0.08487527884010758, 0.14150471905512468, 0.14376903112445558, 0.12998719779508455, 0.07686853847865548, 0.24634004863245146, 0.068953149286764, 0.07259124371090106, 0.09289573239428656, 0.20136140074048722, 0.08760342387748615, 0.22048544883728027, 0.0772878188373787, 0.13526922650635242, 0.15698829106986523, 0.14341482227402075, 0.15344403125345707, 0.15413458991263593, 0.08562172842877251, 0.08176861982792616, 0.10326529453907694], [0.028522321289139133, 0.04795009523097958, 0.03481216110023005, 0.06800662686250039, 0.042188271015350304, 0.053162655527038236, 0.008545243563795728, 0.022737581249592558, 0.050088715473456044, 0.01923204373036112, 0.035492307639547756, 0.017273844253005724, 0.038452745747885535, 0.020997196602235948, 0.02932343365890639, 0.07394214586487838, 0.03347569477877446, 0.030508067591914108, 0.024293402675539255, 0.015049138272713338, 0.08123555593192577, 0.014079070683302624, 0.021950163412839174, 0.03145583852061203, 0.030103999988308976, 0.027767042263544033, 0.006290922498530043, 0.015297373523935676, 0.05310163148013609, 0.032946071055318625, 0.03525648618649159, 0.02156894886866212, 0.05971730380718197, 0.06308785865881614, 0.02913052276042955, 0.02039288992195257, 0.04441381498639073, 0.07033067036952291, 6.450879539762225, 26.13629518236433, 38.83521550042288, 30.821479388645717, 20.68025697980608, 24.842966181891306, 18.824978521892003, 11.461989845548358, 3.9983078752245222, 1.1588292462485177, 0.09781610194061484, 0.08201136573084764, 0.005979747611231038, 0.055866142601839135, 0.03401018020563892, 0.08020275778004102, 1.0338058578116553, 1.8979649330888475, 1.0251670756510325, 2.4691294389111653, 2.638658102069582, 4.151793147836413, 1.1023687273263931, 2.87240093094962, 3.4100334303719655, 9.970945511545453, 14.676924807684761, 19.073039633887156, 24.519326039722987, 33.833235127585276, 39.09864950180054, 47.2338991846357, 47.491663455963135, 53.89711046218872, 48.988162994384766, 49.691782746996196, 48.48934486934117, 48.460478578295024, 47.78792769568307, 51.29776157651629, 48.38146366391863, 50.722947529384065, 49.39663369315011, 47.10000739778791, 44.90986919403076, 43.54709815979004, 39.26774781090872, 43.674840790884836, 46.49019527435303, 49.32696410587856, 48.70710488728115, 51.373573371342246, 34.30268669128418, 46.17135286331177, 50.47485862459455, 46.17244373049055, 45.91366502216884, 40.6662951196943, 37.941631998334614, 37.28321375165667, 36.57294109889439, 36.72254971095494, 35.407276562282014, 37.182746274130686, 37.944855962480815, 44.20512383324759, 45.50068146841866, 45.62076718466622, 45.852694579533164, 47.25246477127075, 45.634149415152415, 46.572795459202354, 46.331404617854524, 46.823416982378276, 46.895858900887625, 47.56777054922921, 45.84656974247524, 41.45800065994263, 33.69905151639666, 24.928479398999894, 18.16707444190979, 9.317517808505468, 2.825218537024089, 1.553937582033021, 2.6800435270581926, 3.8457857966423035, 6.8646769012723645, 5.475625608648572, 0.8030714903559003, 0.06096320266702345, 0.1285064308238881, 0.05526700635839786, 1.3997980930975504, 0.38366790967328207, 0.11679723699178014, 0.15114332256572588, 1.057087859937123, 4.127077102661133, 10.049065845353262, 13.069095151765005, 17.783697162355693, 28.098940679005214, 28.629046542303904, 17.61797046661377, 5.712526610919407, 0.8037026907716478, 0.029057400434144905, 0.0694931885227561, 0.02137595654598304, 0.02278539930869426, 0.02144076851462679, 0.046546341984399726, 0.03679493541962334, 0.02211276924104563, 0.02948791054742677, 0.029889901833874837, 0.016053638121645366, 0.031331758214426894, 0.030785218612956147, 0.051170927938073874, 0.07208875460284096, 0.07087500473218304, 0.09041665720620326, 0.03782936544822795, 0.09524515311100654, 0.05008203868887254, 0.08229217744831528, 0.02879754527072821, 0.03654018283954688, 0.06907789794994251, 0.03322167840919324, 0.04272831703669258, 0.009258686664647289, 0.03914068865456751, 0.04285842273384333, 0.08175994136503764, 0.02046373237057456, 0.052417529081659656, 0.014913884191108602, 0.07395901424544198, 0.03438282485253044, 0.07428678737155028, 0.05065415566787124, 0.007243391858147723, 0.04253676999360323, 0.07301173186195747, 0.028869354631751776, 0.11481933455382075, 0.03563965830419745, 0.03210190563861813, 0.05196922778018883, 0.010886493022553623, 0.005411773512605578, 0.11147218237497977, 0.004833725713459509, 0.04660823116345065, 0.02653725352138281, 0.03753588208928704, 0.08506501758737223, 0.03718044848314353, 0.0578182064262884, 0.02372603035265846, 0.027536050283483098, 0.04813540314457246, 0.017139672434755733, 0.03811526617833546, 0.07708632107824087, 0.10370376386812755, 0.012504164611787667, 0.015135281686005848, 0.04291728903938617, 0.04619281166898353, 0.0180812483387334, 0.013835083909465798, 0.06315242126584053, 0.15852135952029908, 8.120443071637835, 30.716030052730016, 45.21943228585379, 35.26766293389456, 19.566106387547084, 24.167161805289133, 23.17637995311192, 19.54960788999285, 5.097645776612418, 1.000735580921173, 0.024452637881040573, 0.15287893371922628, 0.10168205520936421, 0.0636207325650113, 0.05415097570845059, 0.0731525889464787, 2.27601272719247, 4.029158311230796, 4.96365932055882, 6.01269964660917, 2.8760569861957004, 5.614253895623343, 2.2682663542883734, 4.609576080526624, 6.480898797512054, 11.078617777143206, 17.884774344308035, 22.859800917761667, 28.779954467500957, 36.303601128714426, 42.89241109575544, 49.236439500536235, 49.82237761361258, 54.69188015801566, 50.21650723048619, 51.50618668964931, 50.66925532477242, 48.66319922038487, 49.34964302607945, 52.0633453641619, 50.74163818359375, 52.73073720932007, 51.244343825748985, 48.42171457835606, 46.24722024372646, 45.05927283423287, 41.01605354036604, 45.32114001682827, 48.25047622408186, 51.476483140672954, 50.53957067217146, 52.94139616830008, 37.89525624683925, 46.84510578427996, 52.721798351832796, 48.361751624516074, 48.25160878045218, 42.06131969179426, 38.64211463928223, 39.085621629442485, 37.778272901262554, 37.802869524274556, 37.00015108925955, 38.2549957547869, 39.950324944087434, 46.63470043454851, 47.44042049135481, 48.229343278067454, 47.09364979607718, 48.95121594837734, 47.31693710599627, 48.2584353855678, 48.0621383530753, 47.84357929229736, 46.570120402744834, 48.49887432370867, 46.39647102355957, 43.01704093388149, 36.63346685682024, 27.693383012499126, 20.61737925665719, 14.038951635360718, 6.010869230542864, 2.1505022048950195, 4.775805217879159, 7.795054588999067, 6.238280296325684, 8.962916493415833, 1.4999139266354697, 0.3687730346407209, 0.35042558344347136, 0.3269497374338763, 1.7566058955022266, 0.7260173250521932, 0.21018037466066225, 0.04643591719546488, 1.3311914716448103, 5.373949144567762, 13.108031119619097, 12.686501281602041, 19.736248663493566, 31.778253282819474, 34.551404408046174, 22.73221288408552, 7.329845769064767, 1.1592857646090644, 0.028008992584156137, 0.015095451680411185, 0.011742938226754112, 0.01896825645651136, 0.036844000286821804, 0.07070412247308663, 0.06888961126761776, 0.033908274423863204, 0.047764763568661044, 0.035818587988615036, 0.03982653488804187, 0.031075964083096812, 0.019619178492575884, 0.014967296771439058, 0.026358490078044788, 0.029673588262604814, 0.0025287297446214196, 0.030951700572456633, 0.03961393968867404, 0.026848970812612345, 0.061978358908423355, 0.05599897940243993, 0.028223394383011118, 0.015665122540667653, 0.034913602085517983, 0.03553046166364636, 0.02104842260346881, 0.017070561946768845, 0.050032369925507476, 0.016149491371054734, 0.03735344437882304, 0.03664820561451571, 0.10380767472088337, 0.14488934672304563, 0.12027995368199688, 0.1523493914199727, 0.0997466290635722, 0.1384220394705023, 0.14845730098230497, 0.11523697285779885, 0.11178878002933093, 0.17869880609214306, 0.09740854666701385, 0.09625010418572597, 0.1601166632026434, 0.07034916044878108, 0.10523050837218761, 0.19640139117836952, 0.12336437031626701, 0.1415431105664798, 0.1216867874775614, 0.15605591610074043, 0.2944141189966883, 0.08357619640550443, 0.17374547331460885, 0.09650924349469797, 0.07392219693533011, 0.09356909697609288, 0.10115076907511268, 0.09458423286144223, 0.1756004523485899, 0.15485135359423502, 0.10526168027094432, 0.05966292601078749, 0.1376402857048171, 0.1638041210493871, 0.1903063960905586, 0.18872577590601786, 0.1343420898275716, 0.26464909474764553, 10.67954625402178, 35.34307868140084, 51.47716406413487, 40.18174164635794, 27.72172471455165, 34.352255140032085, 28.085582767214092, 16.071047851017543, 7.560037851333618, 2.02944786633764, 0.18567197477178915, 0.6025375223585537, 0.16327007327760967, 0.18418469386441366, 0.13733774051070213, 0.3091446528477328, 2.4992023280688693, 3.316172386918749, 4.993765430791037, 8.54361355304718, 5.796817813600812, 7.350858858653477, 2.678904022489275, 5.286872582776206, 4.740649504320962, 11.445850917271205, 17.06848086629595, 23.828319004603795, 28.91693299157279, 36.724488258361816, 46.072983741760254, 51.53282955714634, 50.47145748138428, 58.13341672079903, 52.65452241897583, 53.34170968191964, 52.633695193699424, 51.290299211229595, 51.09704548971993, 54.54617990766253, 52.988411154065815, 54.67909894670759, 53.60085664476667, 50.61764063153948, 49.4332263810294, 48.23171608788626, 42.70871114730835, 48.11237382888794, 50.81864159447806, 52.6165748323713, 52.447514738355366, 53.960776805877686, 40.42115225110735, 49.37931183406285, 54.50952468599592, 50.98737859725952, 49.52134690965925, 45.34789752960205, 40.3344144139971, 40.20377785818917, 40.395530768803184, 39.15605204445975, 38.843862533569336, 41.724481446402415, 41.37790182658604, 49.280275685446604, 48.713514600481304, 50.921120575496126, 49.24938746861049, 49.841221128191265, 48.732528345925466, 50.12801149913243, 49.29687145778111, 49.293661390032085, 47.349048205784385, 48.68206010546003, 46.148145880017964, 43.19976118632725, 35.815927914210725, 27.640196289334977, 19.882800068174088, 12.152319431304932, 4.516169275556292, 2.6434267376150404, 6.157478826386588, 7.932497773851667, 12.765652554375784, 14.16986438206264, 3.6325842312404086, 0.2708709351718426, 0.7685800897223609, 0.33579579847199575, 3.313487776688167, 1.5525717181818826, 0.41450067662767, 0.41647999041846817, 1.810322418808937, 6.153518787452152, 16.59839527947562, 21.518353904996598, 28.523282800401958, 39.93511881147112, 41.74749040603638, 27.008947236197336, 9.310988238879613, 1.36549331673554, 0.10613884963095188, 0.22225077982459748, 0.12167310821158545, 0.11690620971577508, 0.1174910661897489, 0.20550887818847383, 0.09971344870116029, 0.1010762591447149, 0.10180326191974537, 0.11385493273181574, 0.100026463690613, 0.07931555288710765, 0.10273576581052371, 0.08763288586799588, 0.1926282343587705, 0.09957836594964777, 0.1786345759672778, 0.14058909033026012, 0.1673988774418831, 0.12452526230897222, 0.1543409866946084, 0.14260030883763516, 0.08863322968993868, 0.1496522690036467, 0.13114924329732144, 0.09903836064040661, 0.12626467325857707, 0.1488796076072114, 0.14663141752992356, 0.16114605510873453, 0.15297082093145165, 0.09558959105717284], [0.07274210240159716, 0.01692561668876026, 0.07995087201041834, 0.14626384153962135, 0.018855855434334705, 0.02882424901638712, 0.007939402546201433, 0.04660155098619206, 0.03176002576947212, 0.030693999757724147, 0.04457536060363054, 0.009432117670907505, 0.06181707791984081, 0.034503291959741285, 0.029796830578041927, 0.06259522866457701, 0.03309971513226628, 0.021262490223827105, 0.06336928105780057, 0.014454578747972846, 0.020068624821890677, 0.04465900022270424, 0.014903885977608817, 0.08762415312230587, 0.06413557779576097, 0.03475557127967477, 0.047910889477602074, 0.01733093788581235, 0.03766280545720032, 0.06451435639922108, 0.02612178144045174, 0.05329325994742768, 0.04996512371248432, 0.03307486717988338, 0.018760996238727654, 0.10491711340312447, 0.04084667157647865, 0.011049539050353425, 1.7663390189409256, 16.415633337838308, 35.20078999655587, 40.42208330971854, 32.65501172201974, 18.76150151661464, 20.826125723975046, 18.935852663857595, 12.201500517981392, 2.946058349949973, 0.4967135265469551, 0.014894138822065932, 0.11791018370006766, 0.041592588515153954, 0.04033259987565024, 0.16775803959795407, 1.6713845027344567, 2.8953145699841634, 5.096948351178851, 3.3427266648837497, 4.150853403976985, 6.54685457263674, 0.8572580484407288, 2.005605991397585, 2.805159956216812, 4.132526661668505, 9.894779358591352, 11.762532438550677, 16.997904539108276, 23.75437453814915, 29.587152753557476, 39.962998458317344, 43.32055214473179, 50.56702300480434, 51.44680391039167, 50.842126505715505, 49.19101912634713, 50.84218903950283, 49.90523140771048, 48.804859093257356, 50.5344637462071, 50.37443631035941, 48.179660184042795, 47.540241786411826, 45.437213148389546, 44.24790389197213, 42.591595785958425, 43.720896925245015, 44.054017884390696, 49.121446813855854, 47.90915986469814, 51.31092841284615, 35.36587919507708, 47.615754808698384, 50.73604835782732, 47.14113031114851, 47.66114739009312, 43.36672639846802, 36.99785818372454, 38.092717102595735, 39.339609554835725, 38.28222574506487, 41.82422283717564, 41.93992076601301, 41.737592697143555, 41.117462498801096, 41.35516037259783, 44.16519948414394, 43.83602510179792, 45.769885948726106, 46.02405105318342, 47.57464231763567, 46.89936079297747, 49.24041387013027, 46.790986265454976, 43.93378278187343, 37.975407191685264, 31.306908335004533, 21.426226002829416, 13.206408057894025, 7.1978981750352045, 5.39278484242303, 1.6311837456056049, 1.2553454786539078, 7.167826805795942, 9.399000201906476, 4.682004971163614, 7.949883035251072, 0.25162358369146076, 0.45012482362134115, 0.47861004940101076, 0.3407757026808602, 1.6291981892926353, 0.12724031162049088, 0.035504338065428395, 0.3462017572351864, 2.577545004231589, 6.712205197129931, 16.611895629337855, 27.78454164096287, 26.68776328223092, 25.505713156291417, 25.265658106122697, 11.286279456956045, 2.2162857949733734, 0.0957240020590169, 0.05810224797044482, 0.05269349605909415, 0.04194698057004383, 0.026071108445259075, 0.028291512513533235, 0.07131098383771521, 0.04531937085890344, 0.04099457185449345, 0.02169512415171734, 0.03931934353230255, 0.04966331133618951, 0.07123672496527433, 0.009167925820552876, 0.02855282143822738, 0.00985167029180697, 0.028917900419660976, 0.030306305204119, 0.05259297788143158, 0.02330569487198123, 0.021741244176934873, 0.05489561360861574, 0.08936749957501888, 0.06486910129232065, 0.04381737591964858, 0.009488451344493245, 0.04309970300112452, 0.048446935535009415, 0.05842173618397542, 0.02907674546752657, 0.08076776031936918, 0.01015895081218332, 0.02009751514664718, 0.06716354710182973, 0.025937113046113933, 0.07010582422039338, 0.06541602087340184, 0.05385352631232568, 0.02344799553975463, 0.029042951030922786, 0.030251547428114072, 0.04468472009258611, 0.040614666882902384, 0.04426007930721555, 0.030788794492504427, 0.014703989561114992, 0.03380127962944763, 0.016722241083958318, 0.06189259886741638, 0.09010096200342689, 0.021568093914538622, 0.03972934153197067, 0.01267573728026556, 0.040203813929110765, 0.024822682042473128, 0.02656869004879679, 0.022369216462331157, 0.06633137139890875, 0.034302930746759684, 0.09006069773542029, 0.07203025809888329, 0.03944201927099909, 0.04794036843148725, 0.04274399458829846, 0.024640637882319943, 0.06103087974978345, 0.062227225197213035, 0.04818542813882232, 0.06430264668805258, 0.04105642032144325, 0.033269504949982674, 2.0418121857302527, 19.22542926243373, 40.025445393153596, 45.05747325079781, 33.535126141139436, 22.11951204708644, 22.619626011167252, 17.50013075556074, 13.654917751039777, 3.70207142829895, 0.4647854140826634, 0.01420672093185463, 0.12711208207266672, 0.1831401977688074, 0.19486810559672968, 0.3284997285476753, 3.492733061313629, 3.8301150032452176, 4.063575778688703, 4.237691555704389, 6.437476030417851, 7.193805251802717, 2.5338095682007924, 2.9773693212441037, 4.444646256310599, 6.399750786168235, 14.114424705505371, 15.063199486051287, 20.074843066079275, 26.85613203048706, 33.59392179761614, 42.51511001586914, 44.991482734680176, 53.12664556503296, 53.27531269618443, 51.81218188149588, 51.536803926740376, 52.93610511507307, 50.74250323431832, 50.70442015784127, 51.89427137374878, 50.63175589697701, 49.89388847351074, 50.13736377443586, 48.650480542864116, 47.16923230034964, 44.34868403843471, 45.03468663351876, 45.593314852033345, 50.59075457709176, 49.26702894483294, 52.649012497493196, 37.59037971496582, 47.56601960318429, 53.18076508385794, 48.84544699532645, 49.329600947243826, 44.85556902204241, 38.540823800223215, 39.18738147190639, 40.57825796944754, 40.6242550441197, 42.333293029240195, 43.59519706453596, 42.367697034563335, 43.005673680986675, 43.28292070116316, 45.4058837209429, 46.638647011348176, 47.14592456817627, 48.13657093048096, 47.97663034711565, 48.03333806991577, 49.22868878500802, 47.12620210647583, 43.876046725681846, 40.41380105699812, 33.073334966387065, 25.99514252798898, 16.37996302332197, 11.244374002729144, 3.354453269924436, 2.1594069727829526, 4.370545021125248, 6.929819302899497, 9.729009236608233, 7.292415823255267, 7.241892431463514, 1.6885325482913425, 1.1570587583950587, 0.9032313472458294, 0.9396867539201463, 0.40593979028718813, 0.30496395432523316, 0.08875684519963604, 0.286214891821146, 3.634808740445546, 9.038656200681414, 22.30566818373544, 28.957508734294347, 27.76123217173985, 32.58485576084682, 29.969724042075022, 14.591149296079363, 3.0519653984478543, 0.15354499726423196, 0.009634743494513844, 0.07458097979958568, 0.03275000157632998, 0.05458334840035864, 0.07764748310936348, 0.04682793401713882, 0.029387782527399913, 0.012187127606011927, 0.04874340444803238, 0.03228299306439502, 0.044362039371792755, 0.0657774561217853, 0.014206311266337122, 0.03286698440622006, 0.03135713881679943, 0.0068903746848393765, 0.009763602383567818, 0.005088093224912882, 0.017681151861324906, 0.01284098091335701, 0.04600463015958667, 0.10606012599808828, 0.04002729643668447, 0.012995885369101805, 0.02203498368284532, 0.045760527186627896, 0.02286226375560675, 0.06033162905701569, 0.09674137032457761, 0.05949903266238315, 0.03244523757270404, 0.0626016543912036, 0.18829652108252048, 0.09470033698848315, 0.14717306489390986, 0.34602829654301914, 0.11754529470843927, 0.17389563311423573, 0.06465222792966024, 0.12668821481721743, 0.14026187360286713, 0.16910445663545812, 0.07520728797784873, 0.07848252901541335, 0.17729472714875424, 0.15160596131214074, 0.09852760697581939, 0.15014384048325674, 0.1425910536199808, 0.1302482709288597, 0.0934425230537142, 0.08842435625514813, 0.1670131709958826, 0.09768652889345374, 0.11522988895220415, 0.2205438164195844, 0.23555503306644304, 0.12755390336470945, 0.1352898675416197, 0.08842468873730727, 0.15374497510492802, 0.15400645535971436, 0.139405060293419, 0.13972087763249874, 0.13676881603896618, 0.14860581872718676, 0.11633320046322686, 0.1984788075621639, 0.1519146268921239, 0.11029622690486056, 3.1138708080564226, 22.618481295449392, 46.13794592448643, 53.01740946088518, 41.069165570395334, 28.66135219165257, 30.72161987849644, 24.241125379289898, 17.481110061917985, 4.958871577467237, 0.9754951638834817, 0.15697268476443632, 0.24156647335205758, 0.28300121426582336, 0.2898039620901857, 0.4276870276246752, 6.384983258587973, 6.311367094516754, 12.096748607499258, 11.2121274130685, 9.457106249673025, 8.825456806591578, 3.488992976290839, 5.270423591136932, 4.518463918140956, 5.725750335625239, 12.439657841409955, 14.884517874036517, 21.142223596572876, 26.819204092025757, 35.499444416591096, 45.59733785901751, 46.26285021645682, 52.968834604535786, 54.005262647356304, 53.19078091212681, 53.347254344395225, 53.74251651763916, 53.17727361406599, 51.73673486709595, 54.11692367281233, 52.70885385785784, 50.90840537207467, 52.2665558542524, 49.84299986703055, 48.14920622961861, 47.72489711216518, 45.92904485974993, 48.003224577222554, 54.45775018419538, 51.63278981617519, 52.64026471546718, 40.48873390470232, 50.05174459729876, 53.72313104357038, 51.56342247554234, 52.11988285609654, 47.37970018386841, 39.28469794137137, 42.27774912970406, 42.130669661930625, 42.16315943854195, 45.031330653599326, 45.95768186024257, 44.512856074741904, 45.30109446389334, 44.4951103755406, 47.160230909075054, 48.402304785592214, 48.789159638541086, 49.7216773714338, 50.34943321772984, 49.25742653438023, 51.94602850505284, 46.97405045373099, 44.800177982875276, 39.70580741337368, 33.019302300044465, 24.06768270901271, 15.934343780790057, 10.097896916525704, 7.30215459210532, 3.331923953124455, 3.646130612918309, 10.470009429114205, 16.195351123809814, 12.757430229868207, 16.27140610558646, 2.599257690565927, 1.5611757593495506, 0.8101347142032215, 0.9808650357382638, 4.11745992728642, 0.9308605875287737, 0.9672335386276245, 0.7349013026271547, 4.275180995464325, 12.593958224569048, 28.211593559810094, 37.626631941114155, 38.00561448505947, 40.60277468817574, 37.46855000087193, 17.34660162244524, 3.3190222339970723, 0.2114322174872671, 0.16224222843136105, 0.12422426417469978, 0.13731496887547628, 0.110052022151649, 0.16803657822310925, 0.12404747866094112, 0.10944771207869053, 0.11314576185707535, 0.10506565828940698, 0.20578525907226972, 0.2066525761038065, 0.19693531681384358, 0.14319161139428616, 0.07120045048317739, 0.08872046215193612, 0.12496203530047621, 0.08407163553472076, 0.1130781187010663, 0.08866731250392539, 0.12199542591614382, 0.1425589724842991, 0.21492019960922853, 0.1786986296730382, 0.1089624102626528, 0.06181102538747447, 0.2008330255214657, 0.11330543471766369, 0.1617412795977933, 0.15266386525971548, 0.16534249564366682, 0.07466570846736431, 0.1466366286788668], [0.03536242585895317, 0.015807031354467784, 0.050031131599098444, 0.011239611976114767, 0.05545795289799571, 0.019513936014845967, 0.053232656592237096, 0.025329322088509798, 0.016535045146676045, 0.021681969054043293, 0.07063027072165694, 0.02025660446711949, 0.02662379727033632, 0.04276120562904647, 0.07359002690230097, 0.057709939378712855, 0.04016451318083065, 0.022434377876509513, 0.009644530513989074, 0.08435025558407817, 0.1103435547224113, 0.07813100716365234, 0.031449463684111834, 0.011625806119159927, 0.005264684508022453, 0.05833934846201113, 0.016164992503555756, 0.01627738674038223, 0.0687124322035483, 0.022900453402793834, 0.0438643034015383, 0.034503159645412645, 0.07265672912555081, 0.04612405910821898, 0.0735010981027569, 0.022302348532580903, 0.03164455946534872, 0.05344228320089834, 0.14553957326071604, 3.977988736970084, 24.74073212487357, 43.03282029288155, 35.19425868988037, 16.99602505138942, 18.16154714993068, 26.421021938323975, 13.707704084260122, 9.349440438406807, 2.0023891925811768, 0.17965642256396158, 0.03832662983664444, 0.024817898370591656, 0.07066444174519607, 0.3254387213715485, 3.0923680875982558, 6.657782997403826, 3.1004232210772376, 1.8046067655086517, 2.3313392783914293, 6.951209332261767, 2.0396163378443037, 0.9697836360761097, 1.4661698916128703, 2.6364064514636993, 7.1700606516429355, 8.536958047321864, 8.745492594582693, 16.168835060937063, 18.21516466140747, 27.006649119513376, 34.05107157570975, 42.58370610645839, 48.492061614990234, 50.04896879196167, 50.73692035675049, 50.53951161248343, 50.40207624435425, 50.92431327274868, 51.5260237966265, 50.21409273147583, 47.568427153996055, 46.97134760447911, 45.87076684406826, 45.348356110709055, 42.167439528873985, 46.75365012032645, 46.27317871366228, 48.6694769178118, 49.17556980678013, 52.10071277618408, 36.46791212899344, 47.770442553928916, 51.645595346178325, 46.72958156040737, 47.294966902051655, 44.42376627240862, 42.23661579404558, 39.49602740151541, 40.41223771231515, 45.63414246695382, 46.749248436519075, 45.92551864896502, 45.819357122693745, 44.24678175789969, 42.2663506099156, 41.907966000693186, 42.67624568939209, 44.17369365692139, 44.537994657244, 46.15373223168509, 48.153573172433035, 47.43491056987217, 44.87923111234392, 37.11097833088466, 26.894882134028844, 17.192019837243215, 10.567757555416652, 4.8694808312824795, 2.833765906947, 0.6272991108042854, 3.5943897664546967, 3.75679326908929, 5.479768906320844, 11.65702404294695, 5.522849474634443, 5.108330803258078, 1.4012246451207568, 0.8814757232155118, 0.5283234875117029, 1.6315814214093345, 0.32682426273822784, 0.12335624146674361, 0.1957880633750132, 2.077014365366527, 6.687586860997336, 13.485558015959603, 13.950250932148524, 17.435123409543717, 29.91645220347813, 26.671787636620657, 16.6392228943961, 5.0816375613212585, 0.43417178679789814, 0.02542760449328593, 0.021065150188016038, 0.039653376143957884, 0.03477122847523008, 0.012088110687078109, 0.021679458474474292, 0.020342101575806737, 0.04399415125538196, 0.03765333989369018, 0.031179410139364854, 0.04712975996413401, 0.03598443212519799, 0.015829360245593956, 0.03524765166054879, 0.06761511894209044, 0.03387803890343223, 0.04826199063765151, 0.03446641358147774, 0.04600819246843457, 0.046669065220547576, 0.04781649847115789, 0.009179129281879535, 0.00936748381770615, 0.013211090383785111, 0.019348953617736697, 0.03803046626437988, 0.043398604462189336, 0.0608070989006332, 0.039321209503603835, 0.028573170703436648, 0.05547031919871058, 0.04047558416745492, 0.052192475979349444, 0.050533396790602376, 0.029633768435035433, 0.0376137677314026, 0.03474282839202455, 0.021536696402888213, 0.05947630852460861, 0.015593701640942266, 0.015240208644952093, 0.04056832633380379, 0.04167128839929189, 0.04157748771831393, 0.015893831250390837, 0.025587748935712234, 0.01898535044996866, 0.053321405580001216, 0.06118245768759932, 0.04309873269604785, 0.05707561091652938, 0.00949396104884467, 0.06329824522669826, 0.04250526222001229, 0.011365487855593008, 0.003954175967789654, 0.08150298693882567, 0.04251118583072509, 0.035283434204757214, 0.04192823264747858, 0.04440115691561784, 0.058174131970320425, 0.02899320423603058, 0.029716006879295622, 0.02072636952756771, 0.015949511834021126, 0.07334211734788758, 0.021103417866730263, 0.07390733023307153, 0.016079498787543604, 0.04483847612781184, 0.10324212935354028, 5.111622078078134, 28.478286266326904, 48.621239049094065, 38.23627035958426, 21.209866046905518, 16.4175614629473, 24.348680019378662, 17.963526964187622, 10.311701672417776, 2.754011009420667, 0.31286780163645744, 0.1313428021967411, 0.16768483924014227, 0.27276866191199844, 0.7930131043706621, 2.135047891310283, 4.251412076609475, 5.368648103305271, 5.930920651980808, 7.272171378135681, 6.84711663212095, 4.972642472812107, 2.606530500309808, 4.029441450323377, 3.942685374191829, 5.928542196750641, 8.377596770014081, 12.299002851758685, 18.962874208177837, 22.755225317818777, 30.907404286520823, 37.252478395189556, 45.17814261572701, 50.20383024215698, 53.090702533721924, 53.15994480678013, 51.82145077841622, 51.53645304271153, 52.808758531297954, 52.62661150523594, 50.44373069490705, 49.87773043768746, 49.1155686378479, 47.752175739833284, 47.10720225742885, 44.22498525891985, 48.20003925051008, 48.19057232992989, 50.4097956929888, 51.13768202917916, 51.5775968006679, 38.554977280753, 48.11900241034371, 52.2088371685573, 48.959616320473806, 48.94773142678397, 46.13532992771694, 44.131014347076416, 40.628924233572825, 40.802709102630615, 47.371379716055735, 46.96617119652884, 47.708728654044016, 46.931892258780344, 45.317742347717285, 43.08537299292428, 43.40212399618966, 43.72172723497663, 45.49995190756661, 44.73877327782767, 46.66853468758719, 47.78419303894043, 48.89370570863996, 45.7041768346514, 38.97837618419102, 30.697728497641428, 20.04240713800703, 13.420520271573748, 7.9899202925818305, 4.387128634112222, 1.912302540881293, 2.656788774899074, 6.618148735591343, 10.58494131905692, 8.100255949156624, 8.445505857467651, 6.8184574842453, 3.825246487345014, 2.122195678097861, 1.2682346041713441, 1.5128937044313975, 0.2330372610262462, 0.1409837127264057, 0.17159923990922316, 2.2412543637411932, 6.0149469545909335, 15.502111979893275, 17.51581457683018, 22.614854335784912, 35.638814858027864, 32.99569926943098, 21.114807741982595, 6.721608281135559, 0.745099629674639, 0.04891211200239403, 0.03444537560322455, 0.016660333245194385, 0.04618638933503202, 0.04807716787659696, 0.025697727587872317, 0.024837519906993424, 0.014220136417342084, 0.042910971878362555, 0.035984520334750414, 0.05370043184874313, 0.01886113952579243, 0.031087797733822038, 0.0575285330414772, 0.04518982834581818, 0.03464426778789077, 0.02287548840312021, 0.019492207627211298, 0.04014803835057786, 0.022397840462092842, 0.0375479023371424, 0.047818812275571485, 0.027731962003079907, 0.059786521164434295, 0.05353009581033673, 0.06495331427348511, 0.04288473292919142, 0.028749169116573672, 0.02486205064425511, 0.022015255277178118, 0.026298124210110733, 0.061384993605315685, 0.027900510101712177, 0.16336475605411188, 0.10584824665316514, 0.12737605933632168, 0.12154002035302774, 0.11891855459128108, 0.16085629351437092, 0.16069733990090235, 0.08547738367425543, 0.13869752468807356, 0.12668434716761112, 0.11299337646258728, 0.09396494073527199, 0.13972213970763342, 0.11297572098140206, 0.12498623185924121, 0.09521796421280929, 0.10458100786698715, 0.1384797149470874, 0.10827493215245859, 0.10806319529988936, 0.16765963844954967, 0.0851190493309072, 0.07253607881388494, 0.1950147912970611, 0.09188706973301512, 0.13725158013403416, 0.10195238356079374, 0.12320902650909764, 0.17087887999202522, 0.08773364153291498, 0.17822240665555, 0.06975357633616243, 0.14289335454148905, 0.1352510689092534, 0.16001311875879765, 0.23045958791460308, 0.15225238805370672, 0.21816101856529713, 0.3022913948765823, 6.769781010491507, 34.08478076117379, 54.6886944089617, 46.45652430398123, 26.534783056804113, 27.097502027239116, 36.39199958528791, 19.45326590538025, 11.550205043384008, 3.288090156657355, 0.45677642098494936, 0.1515952404588461, 0.3813677845256669, 0.34980703092047144, 1.197883767741067, 7.422740578651428, 14.773431812013898, 12.350113800593785, 12.598794170788356, 9.878234829221453, 15.626100846699305, 4.035297478948321, 2.237884053162166, 3.4929782024451663, 5.180274188518524, 9.5265291758946, 12.077810423714773, 13.587126782962255, 18.440475634166173, 23.64857952935355, 33.74655982426235, 37.187273025512695, 46.08657441820417, 53.33735316140311, 55.28771250588553, 54.847106388636995, 53.26739869798933, 52.97202730178833, 53.222923278808594, 54.03598410742623, 53.15045356750488, 51.11150469098772, 50.378205708095, 50.57249471119472, 49.15556941713606, 45.87599883760725, 51.56899493081229, 50.15900393894741, 52.28112622669765, 53.4325122152056, 52.79212801797049, 42.006338596343994, 49.22177880150931, 52.69880328859602, 50.49842344011579, 51.16330003738403, 49.316489696502686, 46.34100355420794, 42.86613648278372, 44.31459270204817, 50.95106036322457, 50.14725800922939, 49.15090717588152, 49.390157972063335, 47.608612060546875, 45.580092430114746, 45.241260051727295, 45.771258217947825, 47.673244203839985, 48.23671184267317, 49.367357458387104, 51.193778310503276, 49.42798743929182, 47.1927102633885, 39.94875117710659, 30.614773954663956, 19.90287341390337, 12.998675159045629, 6.867580814020974, 4.240656265190669, 1.9359257646969386, 7.169344987188067, 9.29286994252886, 12.452409522874014, 19.74356164251055, 15.002357585089547, 14.194567833627973, 6.92617974962507, 2.500555924006871, 1.4627889416047504, 4.844759140695844, 1.3863302043506076, 0.35340885764786173, 0.5736412672059876, 3.005707332066127, 9.362344111715045, 21.748533827917917, 23.867209809167043, 28.949256011417933, 43.075794901166645, 42.145813260759624, 25.53660658427647, 7.593863419124058, 0.8610000876443726, 0.09661725948431663, 0.16109569423965045, 0.1729310413024255, 0.1386282326919692, 0.1304408527378525, 0.12828877036060604, 0.10767256947500364, 0.14682646920638426, 0.14310401252337865, 0.10979354780699525, 0.10185765328684024, 0.11392540537885257, 0.09840846979724509, 0.11201279836573771, 0.13643507180469377, 0.06703151775790112, 0.185971751543028, 0.13821318639176233, 0.1465265838695424, 0.1498418788292578, 0.1563582441636494, 0.07539917089577232, 0.12383117526769638, 0.10791620425879955, 0.06676125725997345, 0.0810396493013416, 0.2387740303363119, 0.14630582928657532, 0.13523151353001595, 0.14823088741728238, 0.15454028600028583, 0.13189232056694372, 0.1242719516158104], [0.04779730271548033, 0.02406617656483182, 0.07586259674280882, 0.025666060358551995, 0.001277941297822898, 0.023792274030191556, 0.016568474870707308, 0.049783764872699976, 0.010754338997815336, 0.04501797238897, 0.012935628914939505, 0.049559441195534806, 0.0400995230967445, 0.05715071117239339, 0.05743906819926841, 0.08446549797164542, 0.04734512358637793, 0.006549447733310184, 0.031881049275398254, 0.01460390564586435, 0.033731058040367703, 0.0183908757421055, 0.04391877280016031, 0.017120206961408257, 0.05435597810095974, 0.023208608385175467, 0.05927315514002528, 0.03158325721908893, 0.06199097287442003, 0.03754205675795674, 0.05426115622477872, 0.0628901742664831, 0.03748369935367789, 0.052710601926914284, 0.09617238478468997, 0.03571727592498064, 0.0642937985914094, 0.04739846661686897, 0.03978205013221928, 0.1804110077875001, 9.69624240057809, 32.113118239811485, 41.307443618774414, 28.109821557998657, 24.44897379193987, 18.097602878298076, 19.582193204334803, 14.241217170442853, 4.53950914314815, 1.1084097517388207, 0.04111576160149915, 0.2037061056388276, 0.33130975919110434, 0.6339993998408318, 1.0611340999603271, 2.140318534203938, 2.6741043371813635, 3.4554238404546465, 7.487217256001063, 7.209088683128357, 8.313436235700335, 4.367406606674194, 6.892685089792524, 1.7647444073643004, 3.2049061059951782, 1.6210305818489619, 4.932284729821341, 8.525999869619097, 12.270776663507734, 13.618628178324018, 24.41269724709647, 28.59293328012739, 37.995279039655415, 44.90314333779471, 48.24493850980486, 50.26834774017334, 49.967810358319966, 50.152535166059224, 51.562974316733225, 49.86988244737898, 48.03903211866106, 50.271748883383616, 48.253252029418945, 48.28360523496355, 45.025928429194856, 46.62714079448155, 48.59996713910784, 50.02551862171718, 48.8638527733939, 52.63114520481655, 37.2452974319458, 46.42861686434065, 51.457250526973176, 49.01206479753767, 49.1950421333313, 45.09285000392369, 43.99473932811192, 40.96994529451643, 45.95177241734096, 46.008042403629844, 48.38979802812849, 48.826520102364675, 47.78432158061436, 45.95676817212786, 45.610216345105854, 44.18436261585781, 43.8490286554609, 44.154388087136404, 45.260374546051025, 46.366600717817036, 47.077971185956685, 44.763835430145264, 37.40206616265433, 25.7379949092865, 15.037682226725988, 6.229145586490631, 3.6304821840354373, 2.381520471402577, 2.4187708497047424, 0.7912244860615049, 0.8998849210994584, 6.743416505200522, 7.495836496353149, 4.543406648295266, 4.783385702541896, 3.4186151070254187, 2.42303552372115, 1.3451555051973887, 2.0718021307672774, 0.5053741303937775, 0.1323233260107892, 0.2554753012955189, 1.2760134381907327, 4.21819360767092, 11.067623121397835, 15.248410667691912, 22.20634021077837, 25.059838567461284, 23.008905785424368, 20.924711976732524, 11.754464711461749, 1.371251419186592, 0.2049464133701154, 0.03431425888889602, 0.013321710251537817, 0.027360757546765462, 0.034261587608073435, 0.0044419213580632845, 0.005142114366338189, 0.06115855968424252, 0.0403562128942992, 0.03715266247412988, 0.06905096010970217, 0.019671464704775384, 0.031407374156905074, 0.021060944967237965, 0.03461717049192105, 0.059212663743112764, 0.07226070216191666, 0.051636847401303906, 0.05490232431995017, 0.03296920570677944, 0.02170648452426706, 0.028370829864538143, 0.07973990190242018, 0.08545823541602918, 0.03922405685963375, 0.02978525816329888, 0.018251319748482535, 0.05789264850318432, 0.08295164563293968, 0.05061781333227243, 0.03501080222693937, 0.01683587025451873, 0.03931754880717822, 0.03748332955209272, 0.053985789750835726, 0.05748564962829862, 0.050653986034116576, 0.03166908511359777, 0.011216871723133539, 0.012014348841538387, 0.04126877464087946, 0.026432360489187495, 0.0456980714308364, 0.0764601214655808, 0.027216869107048427, 0.009241874263222729, 0.04704804738451328, 0.11914373322256974, 0.056095534935593605, 0.08085232613874332, 0.01985531037540308, 0.024562647067276493, 0.05322687886655331, 0.020535154966637492, 0.021900068868749907, 0.032032148846025975, 0.015620893931814601, 0.015423726922433292, 0.06541222107729741, 0.011088356342432755, 0.030861343456698314, 0.07482273504137993, 0.03573351666065199, 0.04179109054218445, 0.020937595782535415, 0.00567136489553377, 0.015459129487031271, 0.020334486716559956, 0.02990099588142974, 0.06559309137186833, 0.05247104513858046, 0.013368474885023065, 0.026524710801563094, 0.4262673423758575, 12.14006541456495, 36.585955074855256, 46.88676718303135, 28.440010377338954, 22.517478806631907, 22.716582911355154, 23.098349945885793, 14.914268323353358, 5.294083944388798, 0.8621776444571358, 0.2979971638747624, 0.10113485064357519, 0.25193285995296066, 0.6764193464602742, 1.412640101143292, 1.4096046068838664, 2.257969775370189, 3.230299166270665, 6.3865205475262234, 8.008171473230634, 9.582055704934255, 4.534874260425568, 4.026395968028477, 4.297616294452122, 4.429667242935725, 3.5465574988297055, 7.237229321684156, 11.59538049357278, 14.506369982446943, 17.867749520710536, 26.895418882369995, 33.54126487459455, 41.474050998687744, 46.37996905190604, 50.261733055114746, 49.81611728668213, 51.86175727844238, 50.784904616219656, 52.20667975289481, 51.53641830171858, 51.57706873757498, 51.2319586617606, 49.48349659783499, 49.19075856889997, 47.21275234222412, 48.51131854738508, 48.78083569662911, 52.268324170793804, 51.266195910317556, 53.23763261522566, 39.88799612862723, 47.967236382620676, 52.74882337025234, 50.492635590689524, 51.45269250869751, 47.207436970302034, 45.22499431882586, 42.85254233224051, 48.559608527592246, 48.39189291000366, 49.05633177076067, 49.84069306509835, 50.43346125738961, 47.65813882010323, 45.94951772689819, 45.00162015642439, 45.69246564592634, 46.6877429825919, 46.40220676149641, 48.44643974304199, 47.56196185520717, 44.53606653213501, 39.1933708190918, 29.71078552518572, 17.51344002996172, 9.567503571510315, 5.457824758120945, 4.024778774806431, 1.819747433066368, 2.6212098726204465, 4.194605341979435, 7.0080534134592325, 11.437212569372994, 6.911372704165323, 8.155926653317042, 5.54179938350405, 2.933480590581894, 1.568714446255139, 1.5810357736689704, 0.4114157850188868, 0.15564525313675404, 0.08666795478867632, 1.4567649619919913, 6.002196141651698, 14.674281018120901, 21.97345917565482, 26.064964975629533, 28.067011969430105, 30.14934539794922, 25.504068170275005, 14.224232298987252, 2.2155366923127855, 0.3624596462718078, 0.0322389222149338, 0.030518686664955955, 0.0256629204377532, 0.04697906072916729, 0.012148980367263513, 0.012378443947194942, 0.02163261411312435, 0.011421652743592858, 0.037155281619301865, 0.03537603387875216, 0.06125182432255574, 0.03090037957632116, 0.027374487702867815, 0.059630539534347396, 0.024666364537552, 0.019453945037509714, 0.0378163375758699, 0.01298912546397852, 0.055568225016551356, 0.024089423174570714, 0.024141281909708465, 0.07420151587575674, 0.019897823986996497, 0.02397927488865597, 0.013258100138045847, 0.004067213540630681, 0.07534253357776574, 0.07605844230524131, 0.03877583019701498, 0.042692446282931736, 0.019296241624812995, 0.021878291287326386, 0.02714951941743493, 0.20257886898304733, 0.17505214177072048, 0.17426669677453382, 0.10925734907920871, 0.12514846958220005, 0.07864307718617575, 0.09258387769971575, 0.13675273475902422, 0.09355172647961549, 0.17163432016968727, 0.06409329827874899, 0.07652448729744979, 0.19920295370476587, 0.17247910983860493, 0.12494807104979243, 0.24993243015238217, 0.1334634412612234, 0.0676888349865164, 0.11656809571598258, 0.09435077610292605, 0.1542172354779073, 0.14724686236253806, 0.13355365927730287, 0.09406310439641986, 0.0924799804176603, 0.0970787922186511, 0.17695083203060286, 0.19731400720775127, 0.23673543972628458, 0.1568159024630274, 0.16034851861851557, 0.25404940066593035, 0.1302554634000574, 0.1960495300590992, 0.216577874230487, 0.13024900374667986, 0.16083251764731749, 0.1174184222306524, 0.12641167108501705, 0.6697431047047887, 14.836045503616333, 42.309575353349956, 54.7198987688337, 36.987032890319824, 34.134213720049175, 27.133434636252268, 27.00779036113194, 18.75959597315107, 6.713070682116917, 1.5494475258248193, 0.9773596695491246, 0.6441937099610056, 0.7799965771181243, 2.5104110751833235, 2.729509924139295, 5.180179953575134, 8.369557704244341, 8.634229353496007, 19.110922949654714, 17.949618407658168, 20.912165267126902, 12.53439566067287, 9.984562243734088, 4.18186799117497, 5.207506784370967, 3.732419856957027, 7.891922031130109, 11.177687798227582, 14.52830718244825, 18.540170124598912, 27.88047194480896, 34.55578177315848, 42.04904569898333, 47.04270212990897, 51.82919454574585, 51.078191552843364, 51.1425735609872, 52.56368167059762, 52.569511209215435, 52.60023266928536, 53.61552429199219, 54.76169565745762, 52.045627457754954, 52.57005316870553, 49.02042695454189, 49.85171638216291, 51.7061002595084, 53.55037450790405, 52.98015669413975, 53.238914557865684, 43.284136635916575, 48.298401423863, 52.42791039603097, 53.51805148805891, 53.307528018951416, 48.20865849086216, 47.23393045152937, 45.307201930454795, 49.45884091513497, 49.615609645843506, 51.683164255959646, 52.25288527352469, 51.65551042556763, 49.65929991858346, 48.77981431143624, 46.20218896865845, 46.93034281049456, 48.35361875806536, 47.29684291567121, 50.401961599077495, 49.71594163349697, 46.12554686410086, 39.79498406818935, 29.455967290060862, 17.686814955302648, 7.9908226898738315, 5.788269358021872, 4.185323417186737, 5.285219345773969, 3.772331612450736, 5.600340562207358, 14.490742615291051, 17.553604091916764, 13.466607672827584, 14.304272072655813, 12.428430421011788, 8.962401458195277, 4.2319536464554925, 5.8559417724609375, 1.9985841853278024, 0.7627162443740028, 0.6616950279900006, 2.017289170197078, 7.075808337756565, 18.143455777849468, 26.074527433940343, 31.577043873923166, 36.43819120952061, 36.6340331350054, 31.620414529527935, 16.776845863887242, 2.685011054788317, 0.5827273396509034, 0.21422394125589303, 0.08507594200117247, 0.06811383539544684, 0.14399558039648191, 0.09809395524540118, 0.14520238206854888, 0.10909031411366803, 0.11931405908295087, 0.20763755110757692, 0.1464741059712001, 0.17463056796363421, 0.11572935857943126, 0.12958406656980515, 0.12348977715841361, 0.15831222145685128, 0.16876061580010823, 0.13933158852159977, 0.14978925165321144, 0.08740564449025051, 0.104896465582507, 0.10775155095117432, 0.13421953283250332, 0.20847240702382155, 0.1373740557049002, 0.13667897800249712, 0.11852237156459264, 0.2297698977802481, 0.14445010386407375, 0.1221094469406775, 0.14899900262909277, 0.10916915988283497, 0.12029152948941503, 0.08884415908583573], [0.0027618317565481576, 0.04605735572321074, 0.059791610177074156, 0.018396831583231688, 0.07559074168758732, 0.0052367848443931764, 0.03737673509333815, 0.0034656659533668843, 0.028407416472743665, 0.022369219855006253, 0.0979922835582069, 0.060203684493899345, 0.03202448140031525, 0.04529818360294614, 0.017578050161578825, 0.021054480224847794, 0.10515551668192659, 0.015497205479602729, 0.01990945916622877, 0.07115057815930673, 0.029942125281585113, 0.06210207619837352, 0.06598373755280461, 0.029170471509652476, 0.016223850327410867, 0.019153813731723597, 0.0412076081016234, 0.026770074153319, 0.020982901565730572, 0.021830815888409103, 0.027498893705861907, 0.05128550875399794, 0.035526074934750795, 0.0015075240454669775, 0.01615978474728763, 0.026780871341803243, 0.03195046680048108, 0.06378692614712886, 0.06949033189032759, 0.10145668658827033, 2.925782637936728, 19.420859507152013, 37.735791615077424, 41.563866887773784, 26.22257443836757, 15.60711315699986, 13.501356482505798, 16.962011882237025, 10.949834653309413, 4.368800154754093, 0.6003928631544113, 0.12911414035729, 0.21006951560931547, 0.47878190875053406, 1.1959076566355569, 2.0298734435013364, 2.033729042325701, 4.220437007290976, 5.109806861196246, 5.9460785814694, 6.592539846897125, 2.3107437321117947, 3.4776828289031982, 3.2876389580113545, 0.7472078651189804, 1.2063576387507575, 1.384425095149449, 3.1832676785332814, 5.46131796496255, 7.348233308110919, 11.569112828799657, 21.00710024152483, 28.20811424936567, 36.807863167354036, 43.03934465135847, 49.214219161442344, 48.168348516736714, 53.11094263621739, 51.94362095424107, 52.13831295285906, 49.73528889247349, 50.42408813749041, 49.87886299405779, 50.2346385547093, 48.01500177383423, 47.30534403664725, 48.74884271621704, 49.64334685461861, 50.033571583884104, 52.29984814780099, 36.288884844098774, 47.77902010508946, 52.905119623456685, 47.36719342640468, 49.55463225500924, 47.519456250326975, 45.718993868146626, 46.33789423533848, 47.01726130076817, 48.148976939065115, 49.40001746586391, 49.23977810995919, 50.092019830431255, 49.86659247534615, 46.568716866629465, 47.03915507452828, 46.167208262852256, 46.75246892656599, 47.7945145879473, 47.94505425861904, 43.13804381234305, 37.45961114338466, 23.301221711294993, 13.218003732817513, 6.048494594437735, 2.4119498900004794, 0.9173136630228588, 2.259481442826135, 0.8436886508549962, 2.619415283203125, 1.5348509890692574, 3.909586761678968, 13.259375044277736, 3.572536813361304, 6.847896567412785, 4.617787548473903, 3.080310357468469, 1.147351256438664, 0.5756086387804576, 0.29982633143663406, 0.20962738219116414, 0.7648495041898319, 3.3133314422198703, 7.377548626491001, 10.342552542686462, 11.698447465896606, 19.547504322869436, 24.874118430273874, 24.548878465379985, 13.254196899277822, 3.6655560391289845, 0.09046194941869803, 0.04541197053289839, 0.058424558889653, 0.04745150769927672, 0.0449008979568524, 0.12216978227453572, 0.03342556121892162, 0.02683726777987821, 0.07739747009639229, 0.01008906340160008, 0.09215544390359096, 0.020875699818134308, 0.028710333164781332, 0.046802034335477014, 0.03211484190874866, 0.029332848332290138, 0.042460699432662556, 0.06335256195494107, 0.042698359715619257, 0.012593081536968904, 0.011813947764624442, 0.03721322172454425, 0.017372518511755124, 0.04089846754712718, 0.02221760120508926, 0.011163421823377056, 0.038403470534831285, 0.04885944750692163, 0.025413820054382086, 0.014965574988829238, 0.06938490111913, 0.004423150110856763, 0.013524650745759053, 0.07396838481404952, 0.004171590886211821, 0.013354377471841872, 0.057865629238741736, 0.025550722976082137, 0.022375423361414244, 0.05187478927629335, 0.05603753715487463, 0.04133701490770493, 0.02925036900809833, 0.05829455836543015, 0.012688408073570048, 0.07206920600895371, 0.02465915510297886, 0.09986136254987546, 0.03409151280564921, 0.044457692453371625, 0.04241921719429748, 0.03072189772501588, 0.017888351010956934, 0.02945825517443674, 0.034482114881809266, 0.03905046046046274, 0.015135654880266105, 0.08271675716553416, 0.05212342825585178, 0.05587310776380556, 0.011137054800721151, 0.011903230250546975, 0.10209363419562578, 0.04944424630541887, 0.03768171283549496, 0.03728700222979699, 0.00912431552673557, 0.04554142483643123, 0.0075841682597196525, 0.04283603447090302, 0.013776742620393634, 0.00956927758774587, 0.030161787423172166, 0.057804771432919164, 0.07902124510811907, 4.0242051141602655, 23.54093282563346, 43.23786858149937, 43.50985581534249, 31.824375425066265, 16.3409332547869, 17.85454968043736, 22.361222505569458, 11.829511335917882, 4.73009649344853, 1.0119207692997796, 0.12292476104838507, 0.07664142602256366, 0.2577492349914142, 1.0757122891289848, 1.412205078772136, 2.3475889435836246, 3.7860069700649808, 5.160902610846928, 5.999680459499359, 7.203943107809339, 5.4310498748506815, 5.729323446750641, 2.9686866785798753, 3.440103496823992, 2.8804447736058916, 2.7673967140061513, 5.744313316685813, 8.140056099210467, 10.75573672567095, 16.48303607531956, 25.164862326213292, 31.00334848676409, 39.69101817267281, 43.95593016488211, 50.88552148001534, 49.45407097680228, 53.97879001072475, 52.251724924360005, 54.17700474602835, 52.4738518851144, 51.38100446973528, 51.793387004307334, 52.76908779144287, 49.7472710609436, 48.8507137298584, 50.56630734034947, 52.839955942971365, 51.28131519045149, 52.36929191861834, 38.471682276044575, 48.13974625723702, 52.39605985369001, 50.34203686032976, 50.060593128204346, 48.245018414088655, 46.3447972706386, 48.21378626142229, 48.9753783089774, 49.83042362758091, 51.494715213775635, 50.36741515568325, 51.23381730488369, 50.64564882005964, 46.90676409857613, 47.74179513113839, 47.14972523280552, 47.9393185206822, 48.221745422908235, 48.40280852999006, 44.59930903570992, 39.93326016834804, 26.03419314111982, 17.631125143596105, 8.771422403199331, 4.6667879819869995, 1.980811344725745, 4.648409128189087, 2.141060688665935, 4.864510263715472, 6.798367202281952, 7.044058544295175, 4.796011013644082, 7.465505872453962, 4.861142124448504, 3.873976375375475, 3.6232992666108266, 1.4088144664253508, 0.88657765516213, 0.12304662593773433, 0.24575189447828702, 0.6864048306431089, 4.277277614389147, 10.543120111737933, 15.333804028374807, 17.93692752293178, 22.41602294785636, 30.2259875025068, 29.882656165531703, 16.31453357424055, 5.8582168732370645, 0.47333707234689165, 0.05870678874530962, 0.0859289283731154, 0.08411859015801124, 0.044122567400336266, 0.00920960059322949, 0.03111328011644738, 0.05593287652092321, 0.03346952689545495, 0.042606262157538106, 0.06233098677226475, 0.02148609635021005, 0.02369212226143905, 0.004777118929528764, 0.04482458312330501, 0.06768933031708002, 0.10281444873128619, 0.07332936767488718, 0.047564239507274966, 0.03818586774702583, 0.055805098198886426, 0.008835044173922921, 0.06973324064165354, 0.026976152023832713, 0.021377612171428542, 0.040881792549043894, 0.013586514479746776, 0.02951087217245783, 0.013066256235885833, 0.023282972430544238, 0.016164244418697696, 0.0556102263342057, 0.04636133262621505, 0.046674059238284826, 0.023011612705886364, 0.0827337069703, 0.16626619893525327, 0.15320085787347384, 0.0988443810492754, 0.1551965514996222, 0.1278297414204904, 0.14621003371264252, 0.09258432553282805, 0.20673417672514915, 0.049571491977466006, 0.18634068460336753, 0.10925169009715319, 0.18537352792918682, 0.10860363487154245, 0.2060779519379139, 0.09711300395429134, 0.19815902757857526, 0.1533656468881028, 0.08042045217007399, 0.20397389626928739, 0.2234343620283263, 0.11379106901586056, 0.16150128176169737, 0.1973615318004574, 0.09798446683479206, 0.20655285859746592, 0.18087531573006085, 0.22099905913429602, 0.14529938543481485, 0.10649349274379866, 0.13761565488364014, 0.2706712558865547, 0.10996297800115176, 0.18503734096884727, 0.1464307882956096, 0.1351368443242141, 0.14799880129950388, 0.17291935692940438, 0.13812120418463433, 0.169220486123647, 4.992602476051875, 28.679525205067225, 48.88465220587594, 52.83534928730556, 38.01999030794416, 23.284426178250992, 21.354015111923218, 26.559476954596384, 14.413581132888794, 5.914130764348166, 1.7421258496386665, 0.40100751923663275, 0.602829672396183, 1.0847584094320024, 4.819121590682438, 4.707494871956961, 6.440486771719796, 10.446492382458278, 12.297066041401454, 14.509563548224312, 15.770190852028982, 9.012990423611232, 7.844511866569519, 7.9706876788820535, 2.2140738793781827, 2.7711908646992276, 2.811473480292729, 4.742360932486398, 7.772961923054286, 9.787931697709219, 16.67457011767796, 24.092131682804652, 31.163104942866735, 40.59877252578735, 44.07123899459839, 51.034459590911865, 49.93807554244995, 55.42560992922102, 54.57663038798741, 56.99147680827549, 55.047211033957346, 55.19231721333095, 53.51717948913574, 54.69250896998814, 53.218069962092805, 50.10515887396676, 52.835342339106965, 51.936724867139546, 53.078869751521516, 53.46445655822754, 42.39805371420724, 50.5083315713065, 53.370117391858784, 51.516035761152, 51.871432644980295, 51.12662744522095, 49.393357617514475, 50.54343039648873, 50.899932043892996, 51.44838115147182, 51.732864720480784, 51.531158515385215, 52.817026887621196, 53.58564008985247, 48.99247087751116, 50.66637877055577, 48.29075493131365, 50.07773780822754, 50.82110125677926, 50.49509177889143, 45.314038957868306, 40.4589330809457, 26.691956520080566, 16.919032062802994, 9.345001408032008, 4.733349118913923, 2.016346820763179, 5.0354806780815125, 3.080642568213599, 6.959932361330305, 6.952104781355176, 11.463728632245745, 20.869942801339285, 12.713917136192322, 14.819312504359655, 8.956303545406886, 8.220200095857892, 5.2703423840659, 2.276547521352768, 0.639265102999551, 0.5029235333204269, 1.3621232232877185, 5.240023050989423, 12.9373824937003, 18.106044939586095, 23.24002718925476, 29.99907670702253, 37.42525577545166, 38.50554084777832, 19.009684222085134, 6.214448843683515, 0.684093251824379, 0.1311650803046567, 0.18557824194431305, 0.12313560902007989, 0.17801530419715814, 0.187051422894001, 0.10512268915772438, 0.1574054408286299, 0.1674327634807144, 0.07008316115077053, 0.13787963214729512, 0.2223047369292804, 0.09775047403361116, 0.09550087260348455, 0.10580155665853194, 0.13705639275056974, 0.1752703586327178, 0.12295397876628808, 0.1276985534599849, 0.1543152430760009, 0.15209000105304377, 0.09791199929480042, 0.21091202540057047, 0.19390185815947397, 0.15853946283459663, 0.18646031032715524, 0.11660198175481387, 0.1297016702592373, 0.13945058999317034, 0.14765756603862557, 0.11431454521204744, 0.1286509587828602, 0.1473432279058865, 0.20169359791491712, 0.09080973932785646], [0.035365279098706584, 0.009837572878625776, 0.03567783946969679, 0.009398595496479954, 0.005530887790622988, 0.01992944541520306, 0.01593262649008206, 0.04012086980843118, 0.0051291047296087655, 0.028442925906607082, 0.025856531923636794, 0.00965246428469462, 0.015061418060213327, 0.04547615994566253, 0.020247885292129855, 0.04310978263882654, 0.019003616612670676, 0.0335185001604259, 0.07012054843029805, 0.04280324087345174, 0.024292281396420937, 0.01266890952164041, 0.09225131411637578, 0.021015028502526026, 0.018282193091831038, 0.025574604016063467, 0.042628803090857606, 0.03225567524454423, 0.018749149017302052, 0.01107340567146561, 0.017833754387018935, 0.01975363020652107, 0.04342412755691579, 0.005029271872315023, 0.03028056158551148, 0.011939659947529435, 0.01593299798800477, 0.03215888561680913, 0.007816059298680296, 0.023187388898804784, 0.1420659896518503, 6.390927876744952, 28.5003467968532, 40.385810238974436, 29.844385487692698, 26.515647717884608, 17.84012869426182, 16.66524042401995, 16.2845173563276, 7.282824269362858, 3.3112930144582475, 0.7786057431782994, 0.1670631111732551, 0.25190577283501625, 0.42252728449446814, 0.3346699188862528, 0.997248670884541, 2.2114678706441606, 1.619840594274657, 3.386417589017323, 5.762418150901794, 3.428408158676965, 2.5187332800456455, 3.7892083525657654, 7.161018005439213, 1.2960814642054694, 1.8653477004596164, 2.5203435250691006, 1.6987249042306627, 3.680628853184836, 4.852246258940015, 10.443687915802002, 16.68248064177377, 22.411735909325735, 32.48544440950666, 41.64380938666207, 43.15934004102434, 48.472116810934885, 50.449056489127024, 52.79299654279436, 52.63918774468558, 53.63270023890904, 52.46691410882132, 50.9360522542681, 50.815004212515696, 48.62452207292829, 50.049427373068674, 53.54199845450265, 51.76779331479754, 51.22916201182774, 37.822942870003835, 48.54447535106114, 52.86187750952584, 48.37423406328474, 49.7542644228254, 48.37499836512974, 45.77830369131905, 47.12931489944458, 50.11730432510376, 49.097829886845176, 47.06523166384016, 46.155872276851106, 50.23998866762434, 48.6976066998073, 49.62204715183803, 48.43004894256592, 47.305847781045095, 48.51197862625122, 45.504148619515554, 41.320537499019075, 34.7799654006958, 25.35897762434823, 14.27617963722774, 5.680849773543222, 1.36687633395195, 1.3707091339996882, 1.613222217985562, 2.7781032366412024, 1.8508578836917877, 4.127731536115919, 7.541344591549464, 4.237457922526768, 4.509160280227661, 6.292853619371142, 4.681392226900373, 4.09555355991636, 1.2653724891798837, 1.0318656819207328, 0.3601827270218304, 0.0707188466829913, 0.7352931158883231, 2.3677630381924764, 7.907763923917498, 13.147397007261004, 17.931521824428014, 19.174047333853586, 29.19587884630476, 26.549806799207413, 19.12258550098964, 7.986772758620126, 1.8649457905973708, 0.017929456662386656, 0.0805835584178567, 0.055553779006004333, 0.023250728446458067, 0.020200389537162015, 0.033487521644149504, 0.05042500760672348, 0.05010869154440505, 0.02759120500247393, 0.05074384781931128, 0.04912484969411578, 0.035831303734864504, 0.05553042043798736, 0.05472202060211982, 0.05998413770326546, 0.02412793173321656, 0.03027667018717953, 0.04665089066007307, 0.044700275507888625, 0.024645005951502492, 0.02000993154277759, 0.025226025309945856, 0.03829858259164861, 0.04615907830053142, 0.033041649498045444, 0.0746375492640904, 0.06411301650639091, 0.05170977295243314, 0.07597498928329774, 0.03430720551737717, 0.05915082884686334, 0.03886607535449522, 0.04653704266196915, 0.030013212002813816, 0.0401510815801365, 0.03799414089215653, 0.10787910196397986, 0.017453571216070225, 0.01848433037022395, 0.030490914226642678, 0.01595253640386675, 0.04512876358681491, 0.0517713432200253, 0.10056943419788565, 0.016652984710942422, 0.08464259561151266, 0.01578101123284016, 0.07075572506125484, 0.009657758554177625, 0.061324006877839565, 0.05910204217902251, 0.03744293636243258, 0.042554025139127455, 0.04053601788889084, 0.02431328035891056, 0.023153791237356405, 0.010774711163581481, 0.0573582478931972, 0.031723907350429466, 0.020957753361601914, 0.05015947649787579, 0.02982014504128269, 0.05274516310808914, 0.01997594881270613, 0.01322354404588363, 0.04295205378106662, 0.0005401341248736051, 0.028803584232394184, 0.0210091439075768, 0.02654467330181173, 0.06973909639886447, 0.03680510665955288, 0.024986164877191186, 0.03868828221623387, 0.014234696082504732, 0.23135788685509137, 8.292597719601222, 33.339270319257466, 44.31969962801252, 34.3408705166408, 24.915036371776036, 19.858566488538468, 23.26124698775155, 20.964446987424576, 9.483839443751744, 3.1489073165825436, 0.8693807008011001, 0.18181032341505798, 0.3133973032236099, 0.3776134231260845, 0.4290070767913546, 1.3880525976419449, 2.7120358560766493, 3.6223321642194475, 4.891125772680555, 6.678588943822043, 5.465641915798187, 5.5206499355179925, 5.892942667007446, 8.85565367766789, 7.226972043514252, 3.376919184412275, 2.8283163479396274, 3.2960093660014014, 5.150895467826298, 8.166284680366516, 14.986536536897932, 21.339312723704747, 25.441819259098597, 35.045577662331716, 43.291484355926514, 44.438732692173545, 50.83553613935198, 51.3421744619097, 53.79441261291504, 54.241303375789094, 53.735325132097515, 52.19518395832607, 53.99476391928536, 52.778155190604075, 50.12259885243007, 51.64201007570539, 55.5718104498727, 52.061156681605745, 51.694131987435476, 41.059656960623606, 47.99344498770577, 53.63510084152222, 49.86321912493025, 51.07652398518154, 51.089958327157156, 46.91361502238682, 49.5158508845738, 51.837379523685996, 51.024905817849294, 49.270371028355186, 47.691910539354595, 50.833826882498606, 49.92997741699219, 49.84771769387381, 49.99401201520647, 48.06454242978777, 49.581014565059114, 47.645982946668354, 44.04744488852364, 37.9567825453622, 29.06848188808986, 17.498320749827794, 8.207246916634695, 3.6359495478016988, 2.5915167459419797, 3.9919077157974243, 4.477305395262582, 3.095712125301361, 7.456954377038138, 9.010308418955121, 7.599426320620945, 5.083322499479566, 7.313181383269174, 4.516815458025251, 2.3862723878451755, 2.1076094550745825, 0.6382648338164602, 0.17310657831174986, 0.15257526215698036, 0.2157213051936456, 2.7490020096302032, 9.591153502464294, 14.065184559140887, 18.501369646617345, 19.639590535845073, 32.714033194950645, 32.37501321520124, 23.742684194019862, 10.672189848763601, 2.5463421642780304, 0.09503467833357197, 0.06488250235893897, 0.01914491135227893, 0.0430506109925253, 0.03393863886594772, 0.04338643493662987, 0.04428819101303816, 0.06087109153824193, 0.01444170524233154, 0.022002724431721226, 0.061197636515966485, 0.029828345136983053, 0.047410402047846995, 0.005545217177963683, 0.0450344370411975, 0.0362994012955044, 0.03203472049374666, 0.012795716690431749, 0.03807977879686015, 0.060927613505295346, 0.04401423589193395, 0.016466976209942783, 0.019284160308805958, 0.019675323872693946, 0.08411435609949486, 0.042587965460760255, 0.037605513352900743, 0.03456628715087261, 0.052538155644599877, 0.03821501761142697, 0.098421565523105, 0.02547763966556106, 0.023478254808911254, 0.0342308296156781, 0.04401736054569483, 0.1626842939960105, 0.13059260030942305, 0.09943417047283479, 0.09177298764032976, 0.15526399788047585, 0.0688126857525536, 0.1108905625130449, 0.1966051145323685, 0.23031063590730938, 0.06688362426523652, 0.13892636740846293, 0.1147927495517901, 0.1457498919750963, 0.12860294564494065, 0.1176464914211205, 0.10944524899657283, 0.12709021967436585, 0.07470003555395774, 0.11635826554681573, 0.14213412813842297, 0.07633479604763643, 0.10144632535853557, 0.14735158745731625, 0.13948701375297137, 0.12763813670192445, 0.10174825308578354, 0.12751095209802898, 0.11633723096123763, 0.15273276370550903, 0.10409863053687982, 0.13303611347717897, 0.10911882615515164, 0.2047443456415619, 0.16088437129344257, 0.14199432278318064, 0.1527483428695372, 0.11935775673815183, 0.17352835567934172, 0.09001305779176098, 0.15222146042755672, 0.5093425288796425, 11.013379403523036, 39.3752955027989, 52.13441153935024, 41.196189062935964, 36.79756246294294, 27.31611146245684, 27.523025342396327, 23.434899841036113, 10.70776983669826, 4.3811423267636975, 1.5307353756257465, 0.3468850148575646, 0.8254205339721271, 0.9085369482636452, 3.017337965113776, 3.7182381493704657, 9.006103021757943, 10.678510103906904, 10.96828212056841, 13.20499062538147, 9.142001969473702, 9.260280285562787, 10.448126077651978, 15.635475703648158, 5.392515165465219, 6.0846934063094, 5.39093097618648, 3.66363833631788, 4.700008622237614, 7.5170701912471225, 13.308333788599287, 20.478950296129497, 24.972871439797537, 35.45587573732649, 43.360035283224924, 45.000459807259695, 49.81448098591396, 52.23954473223005, 54.688656193869456, 55.68573658806937, 56.53370516640799, 55.889541149139404, 56.30021790095738, 54.56000682285854, 51.41991785594395, 54.273230348314556, 58.45130375453404, 54.95490074157715, 51.753368854522705, 44.67374161311558, 50.41297796794346, 53.633495807647705, 51.733361516680034, 53.30349111557007, 52.90278502873012, 48.67497641699654, 52.78571483067104, 53.823365756443565, 53.02061605453491, 49.394333839416504, 49.60837657111031, 51.189866474696565, 50.90887784957886, 52.32763746806553, 50.35986246381487, 49.857490335192, 50.969862188611714, 47.586822509765625, 45.53936903817313, 37.294105052948, 28.67461109161377, 16.826744352068218, 8.909279005868093, 2.8302388276372636, 2.5693142116069794, 5.336317700999124, 7.05060852425439, 5.219387769699097, 11.671360782214574, 13.367733069828578, 10.441058022635323, 14.411215271268572, 12.49776475770133, 12.246139219829015, 9.492275425365992, 4.487623904432569, 2.988193746123995, 1.1562766517911638, 0.33612988197377747, 1.1252892059939248, 3.531264296599797, 12.142739602497645, 20.031253542218888, 25.380009821483068, 27.271714210510254, 41.85333578927176, 40.04800966807774, 28.21159703390939, 12.7539769751685, 3.031344447817121, 0.16096791252493858, 0.22521766062293733, 0.12008278497627803, 0.11802535823413304, 0.11835418987487044, 0.1440784838050604, 0.14227917178400926, 0.143381248361298, 0.17382535045700415, 0.11498600989580154, 0.1392275962446417, 0.12141446423317705, 0.0915439413594348, 0.13915723216320786, 0.15573575613754137, 0.12927134335041046, 0.10328814081315484, 0.0714429249720914, 0.1446214746683836, 0.1473142137484891, 0.1446801679474967, 0.14986459618168219, 0.10968456151229994, 0.12245031579264573, 0.14929021628839628, 0.17964206476296696, 0.13150911112981184, 0.12324777085866247, 0.17903336456843785, 0.11849915209625449, 0.22553298941680364, 0.17743979793574127, 0.13843894856316702, 0.09211714738713843, 0.1628865652850696], [0.04404224581750376, 0.04552587281380381, 0.034499197000903745, 0.014584611502609082, 0.041723450778850486, 0.022091166382389407, 0.0515256490824478, 0.02952817142275827, 0.005872992000409535, 0.06258332037499972, 0.019153506694627658, 0.03301546822435089, 0.07758733776531049, 0.10546057924096074, 0.016785891061382632, 0.014002632017114332, 0.034465243108570576, 0.0032529664292399374, 0.026208197964089255, 0.04472600894847086, 0.03435291502890842, 0.024490856365965943, 0.026715570827946067, 0.012585637159645557, 0.03671319569860186, 0.015087865658902695, 0.06110096563185964, 0.020640047998832803, 0.058616740362984796, 0.03060838220907109, 0.02937624743208289, 0.022840162173711827, 0.020556126787726368, 0.03554206461246524, 0.036743997795773406, 0.0284172128220754, 0.019020897203258107, 0.03158656846997993, 0.04728379419871739, 0.038766995671072176, 0.04786545138007828, 0.8514757358602115, 16.392763342176163, 34.19828653335571, 42.196621962956016, 35.01329285757882, 17.814366510936193, 11.992227724620275, 14.495813063212804, 13.280111074447632, 7.941242950303214, 3.127933744873319, 0.9422822317906788, 0.25409923227769987, 0.4390831861112799, 0.28933308592864443, 1.1413598465068, 1.8983145143304552, 1.8462223495755876, 2.2536247628075734, 4.35427234002522, 3.6018319385392323, 5.427217509065356, 1.6681146153381892, 6.025670630591256, 6.898294457367488, 2.1818911262920926, 1.5699834695884158, 1.4260108236755644, 2.038918261017118, 3.9680636695453098, 4.930400030953543, 6.4819953101021905, 13.786440202168055, 19.73270681926182, 29.400701318468364, 37.89993238449097, 42.55115727015904, 47.20829854692732, 50.6931779725211, 50.51237194878714, 53.379285539899556, 55.642223494393484, 53.244824000767295, 52.429925373622346, 50.32438496180943, 51.381265027182444, 54.00198309762137, 51.11763647624424, 51.67537185123989, 39.274702957698274, 47.45608173097883, 52.95682116917202, 52.27546691894531, 50.859173910958425, 49.22086163929531, 50.14036887032645, 48.78269781385149, 49.47979320798601, 51.03123215266636, 47.62315811429705, 51.07407821927752, 48.95552383150373, 47.791526862553184, 48.887824058532715, 49.29038878849575, 48.203516823904856, 46.38976601191929, 42.778088910239084, 34.35142135620117, 25.153484651020594, 14.738414628165108, 5.832710470472064, 2.2781106489045277, 1.128714559333665, 2.0994880965777805, 2.0390561393329074, 5.489786905901773, 3.3623110311371938, 5.419308287756784, 9.122979538781301, 6.808847691331591, 1.3396518805197306, 5.677704845155988, 1.5989892674343926, 0.41410129091569353, 2.25347363948822, 0.47754268667527605, 0.14346617380423204, 0.27342716657689636, 2.9659453971045355, 5.745799796921866, 11.777187057903834, 14.726314340318952, 17.59482775415693, 24.76421182496207, 28.83530902862549, 25.06128552981785, 13.61469897202083, 3.3105048281805853, 0.3274755206491266, 0.04702219520030277, 0.022152154806203077, 0.032051381921129565, 0.07224310774888311, 0.0945300314841526, 0.03695030636819346, 0.0175046411542488, 0.09794973262718745, 0.029840368777513504, 0.012216213009586292, 0.027975415278758322, 0.037177751306444407, 0.07866558419274432, 0.09587364617202963, 0.04172538799632873, 0.029099004808813334, 0.028568220790475607, 0.04508068598806858, 0.009003153769299388, 0.04069676622748375, 0.029494322703352997, 0.06720083938645464, 0.059635533552084646, 0.019974347470062118, 0.01329244758068983, 0.07513948875878539, 0.04296865074762276, 0.008109916700050235, 0.03573476177241121, 0.08284846081265382, 0.02787136532632368, 0.07321515666054827, 0.05264580861798354, 0.03778513853571244, 0.052520605336342535, 0.023042782908305526, 0.020673201219843965, 0.059467012594853125, 0.04160556210471051, 0.024877823190763593, 0.007861383741588464, 0.03390405732872231, 0.03289396635123661, 0.05855259844767196, 0.02776473863715572, 0.03640544953356896, 0.019141496624797583, 0.02518777289826955, 0.010337313919860338, 0.08179181215486356, 0.04148089147305914, 0.03815769497305155, 0.0544136807189456, 0.013667345812012042, 0.036029456316360405, 0.06794803536364011, 0.04447403496929577, 0.024154640567888106, 0.042025483679026365, 0.05474156919600708, 0.07145071455410548, 0.036003828048706055, 0.06635140175265924, 0.04319144432832088, 0.05940465522663934, 0.018960387146632587, 0.07401643866407019, 0.004801511839364788, 0.08257062786391803, 0.06751723348030023, 0.03721003939530679, 0.020196705092010752, 0.027235851124195114, 0.06203649578882115, 0.003469327285919072, 0.14421149023941585, 1.2340239541871207, 20.100030285971506, 40.19836173738752, 46.74128580093384, 38.34379373277937, 20.991614443915232, 16.694235256740026, 21.533273424421036, 17.884221962520055, 10.220253825187683, 3.1080256359917775, 0.7162783933537347, 0.33411229880792753, 0.15314322310898984, 0.38601612938301905, 1.1101147745336806, 1.4750069145645415, 1.9576890426022666, 3.381803116628102, 5.059519708156586, 6.917751150471823, 5.554551064968109, 7.249558900083814, 7.405721834727696, 10.166831731796265, 6.4192995429039, 3.4333007761410306, 3.4652692207268307, 4.678135693073273, 5.734308344977243, 8.142613904816763, 10.613534893308367, 17.24063811983381, 25.162105628422328, 34.71503448486328, 40.4171188218253, 43.21670436859131, 47.833469663347515, 50.85003702981131, 51.612726892743794, 53.97188697542463, 57.16729402542114, 53.77401270185198, 53.51270137514387, 50.93307842527117, 53.62883704049246, 55.13280936649868, 52.290860652923584, 52.93110588618687, 41.69576454162598, 47.783383573804585, 53.43586124692644, 54.600834437779014, 52.31237227576119, 50.7422114099775, 50.76145444597517, 50.80314711162022, 50.00929110390799, 52.61386156082153, 50.08283083779471, 51.60040773664202, 51.29677493231637, 48.64965718133109, 50.305121081215994, 49.291979925973074, 47.54754434313093, 47.48040737424578, 44.56380026681082, 37.32487167630877, 28.32807489803859, 18.725977114268712, 10.930291107722692, 3.271873712539673, 2.323038786649704, 3.5457430396761214, 4.761478900909424, 4.984474386487689, 5.684254825115204, 8.508727516446795, 9.957655344690595, 7.347403866904123, 4.895606926509312, 6.573345448289599, 2.65542779650007, 1.484675332903862, 1.1529790801661355, 0.06021023914217949, 0.31972743783678326, 0.16989484136658056, 2.549182891845703, 8.590295025280543, 16.750031028475078, 16.96493012564523, 18.498977729252406, 26.74122793333871, 36.81208419799805, 27.349296058927262, 16.965925455093384, 5.383850761822291, 0.740246692938464, 0.06826443624283586, 0.05342967941292694, 0.047397737191723924, 0.07084204828632729, 0.04599544618810926, 0.03294228143723948, 0.01945458286042724, 0.03392995022503393, 0.05891137383878231, 0.04576442197763494, 0.029704614276332513, 0.021690450741776397, 0.06174625243459429, 0.017102444610957588, 0.02191801442365561, 0.007497582102327475, 0.12633556659732545, 0.01528823874624712, 0.05255581112578511, 0.014433920749330094, 0.03149756503158382, 0.08542228663074118, 0.05450230078505618, 0.0596512212817158, 0.05173502124047705, 0.032276228070259094, 0.02180653451276677, 0.018479852039100866, 0.046478688650365384, 0.04305516056982534, 0.06390562227794103, 0.030789934431335757, 0.04716794452230845, 0.006192905146495572, 0.06177798073206629, 0.12982744351029396, 0.17912264620619162, 0.1459850450711591, 0.05279585985200746, 0.09281065767364842, 0.04657304233738354, 0.14841749811811106, 0.13412376439997128, 0.1765763892659119, 0.18325237317809037, 0.11727225221693516, 0.1439927848322051, 0.13060302260730947, 0.27365455723234583, 0.14769227989017963, 0.17252922643508228, 0.08340548378016267, 0.16800413067851747, 0.0889672656942691, 0.12227985422526087, 0.1508809466447149, 0.09907061140984297, 0.12077577279082366, 0.156422813556024, 0.15770653395780496, 0.15484179982117244, 0.16708114663405077, 0.12245634118361132, 0.1184479905558484, 0.08749774883368186, 0.12683158926665783, 0.15512648597359657, 0.0896139367084418, 0.15396775172225066, 0.17827579379081726, 0.07569144306970493, 0.1494354092116867, 0.16802458172397955, 0.14194389406059468, 0.09390537214598485, 0.282940254679748, 1.857301903622491, 23.95054476601737, 44.85522856031145, 53.884937218257356, 45.703488962990896, 27.959599767412456, 20.04822451727731, 23.979028906141007, 19.502980266298565, 11.571985040392194, 4.15055593422481, 1.4062720771346773, 0.5042440167495182, 0.886978805065155, 1.166415593453816, 3.2334933834416524, 5.375301003456116, 10.018042138644628, 9.894883581570216, 11.870814902441841, 11.918825217655726, 13.297433802059718, 8.687138148716517, 10.202626245362417, 11.643539326531545, 6.334739531789507, 6.383713475295475, 4.274431458541325, 4.726710549422672, 6.663978184972491, 9.95811218874795, 9.609523671013967, 17.3416770866939, 23.53326027733939, 32.78583935328892, 41.474186488560264, 44.36787496294294, 49.70085709435599, 52.2023058618818, 51.99250847952706, 52.84318685531616, 59.75848225184849, 55.69530773162842, 55.80302912848336, 52.97706127166748, 55.85592923845564, 57.7828175680978, 54.056550775255474, 53.27859224591936, 47.32292645318167, 49.5858678817749, 53.73269176483154, 55.553043365478516, 54.051836422511506, 54.283416407448904, 52.66381910869053, 52.17952619280134, 53.145284107753206, 52.596595287323, 49.871543066842214, 51.89290605272566, 52.05119296482631, 49.01161663872855, 49.66235017776489, 51.18589210510254, 48.41250474112374, 48.6831613949367, 44.19532339913504, 37.72347245897566, 27.4925731250218, 16.881860937391007, 7.476085373333522, 4.14641307081495, 3.4295185676642825, 5.480062033448901, 6.245996270860944, 9.963834030287606, 10.735862272126333, 13.380024433135986, 15.281143631253924, 16.431702784129552, 6.821307114192417, 14.507712721824646, 7.914167557443891, 5.228049567767552, 5.599759953362601, 1.1589565937008177, 0.6055529319814273, 0.5052586708750043, 3.8760135003498624, 9.580843244280134, 17.702080147606985, 21.97221197400774, 27.780959844589233, 35.28181988852364, 43.27271032333374, 33.944263866969514, 18.581338201250347, 5.287551769188472, 0.7210824212857655, 0.10859193692782096, 0.1579446590372494, 0.09682242811790534, 0.20266255949224743, 0.1985144985041448, 0.13056731809462818, 0.09775696761373963, 0.15333216797028268, 0.2066017131188086, 0.09422939297344003, 0.14941894795213426, 0.11552666659866061, 0.1680058270160641, 0.18747896780925138, 0.1056356548464724, 0.0818679505693061, 0.2884514789496149, 0.12290627775447709, 0.08354231715202332, 0.19223400551293576, 0.10472169531775372, 0.20668950197952135, 0.19855147866266115, 0.15845772650625023, 0.10160000675490924, 0.13526701448219164, 0.09700441120990685, 0.07332630748195307, 0.1599897907248565, 0.1705985093223197, 0.13026984834245273, 0.2646053156682423, 0.14099097305110522, 0.1518051791936159, 0.11106362286955118], [0.08556441936109747, 0.06414719431528024, 0.029594912127192532, 0.03716970048844814, 0.06409361040485756, 0.06024419981986284, 0.018558979400300553, 0.05056748299726418, 0.04778585582971573, 0.03989538922905922, 0.07427319631512676, 0.023350381491971866, 0.06609036933098521, 0.025261385466105173, 0.07614990882575512, 0.07690061961433717, 0.04690732939967087, 0.023383414273017218, 0.07415912100779158, 0.05771926923521927, 0.020877740512202893, 0.04883183452433773, 0.021528757543170025, 0.03981524745800665, 0.0850969155185989, 0.0268833827160831, 0.031922843639871905, 0.06289035068558795, 0.0348405001152839, 0.04118282800274236, 0.03278191647093211, 0.043308976771576066, 0.018664377941084758, 0.008052115694486668, 0.006460679661748665, 0.0370054068043828, 0.021669594271640693, 0.05867125386638301, 0.07198105752468109, 0.05388462696490543, 0.10481793872479882, 0.11278339023036615, 3.9178182056971957, 16.908774784633092, 35.535588945661274, 30.632339000701904, 19.334623677389963, 11.459237490381513, 11.781011172703334, 13.005691971097674, 13.131508214133126, 9.681322012628828, 3.792069273335593, 1.1521148979663849, 0.4857847701225962, 0.053047806689781804, 0.6490608145083699, 0.660102153463023, 1.634670547076634, 2.916430796895708, 4.483284320150103, 4.617806656020028, 3.2899379432201385, 7.176945447921753, 6.897742075579507, 14.319641487939016, 6.1166581596646985, 0.8998828040702003, 3.168456507580621, 3.0801244931561604, 2.1606554772172655, 2.1590519632611955, 3.8037049004009793, 5.314991508211408, 12.17033611025129, 17.59077000617981, 25.054797649383545, 33.84722532544817, 41.72755255017962, 47.294862679072786, 50.71629810333252, 51.74037919725691, 53.36839771270752, 54.074244362967356, 53.615975924900596, 51.56190082005092, 53.2415201323373, 53.12188604899815, 49.09022160938808, 48.67136335372925, 43.78742592675345, 48.98954916000366, 53.21629122325352, 51.39780173982893, 53.15149927139282, 51.46374709265572, 50.15042291368757, 50.26460266113281, 52.03628213065011, 47.60040623801095, 52.78885889053345, 48.33356973103115, 45.02749177387783, 50.170346873147146, 49.53607709067208, 48.80776344026838, 44.46489265986851, 37.95924915586199, 32.91261965887887, 24.54350577081953, 16.50294440133231, 8.3991231577737, 3.823371776512691, 0.9882697526897702, 2.116720063345773, 2.276017938341413, 3.9942080037934438, 3.0829419876847948, 3.3972526533263068, 6.404134230954306, 7.2966073240552625, 7.194349816867283, 3.1150213863168443, 4.288461608546121, 1.5125621450798852, 1.3275890478066035, 0.3492947912641934, 0.38010918349027634, 0.16024937108159065, 3.3936000721795216, 5.070479622909001, 11.505331839833941, 16.872142144611903, 12.436256698199681, 22.29449200630188, 26.200529541288102, 27.116804122924805, 20.995984860828944, 5.582787241254534, 1.3651101887226105, 0.100261515006423, 0.04664569986718042, 0.08074879526559796, 0.03412653199796166, 0.028078545816242695, 0.011711211625619658, 0.051714756792145114, 0.019297384956319417, 0.018967852728175263, 0.06285915164543049, 0.08304062871528523, 0.07445101998746395, 0.02582402670356844, 0.0008508581574590478, 0.011981762197267796, 0.0040304835919024685, 0.050212965413395844, 0.060787584233496866, 0.024988560105807016, 0.08826188104493277, 0.007449607132002711, 0.06917583769453423, 0.02754832837464554, 0.06263035642249243, 0.07554599908845765, 0.04070124116593173, 0.0225570553115436, 0.030478001705237796, 0.03404644450971058, 0.009709309404050665, 0.029126339592039585, 0.0512617837770709, 0.05116931302472949, 0.004961389532711889, 0.02601455424779228, 0.01842867523165686, 0.047888887979622395, 0.02808022010140121, 0.024227603438443372, 0.055319396047187705, 0.03327786450141242, 0.08455913580421891, 0.06621806283614465, 0.02085206305075969, 0.1237074104802949, 0.07308016890393836, 0.031644908910883326, 0.030149797709392648, 0.03522795718163252, 0.006024263325213853, 0.021605433696614842, 0.0568279490273978, 0.017911287190924798, 0.031130250277263776, 0.017424282251990268, 0.018659083671601753, 0.02817679938328053, 0.021568584156089594, 0.039146737794258764, 0.026560741011053324, 0.034315673634409904, 0.023143560625612736, 0.053186655310647826, 0.06788039220763104, 0.015148133139259048, 0.018602726249290363, 0.023065010019178902, 0.02738178365065583, 0.03775124910420605, 0.06176012847572565, 0.023763721276606833, 0.03525712061673403, 0.013964552631867784, 0.01058912165795586, 0.03149514266156724, 0.004895997840711581, 0.07678433906819139, 0.2476377332849162, 5.620823851653507, 22.139634030205862, 40.95015682492937, 35.92580325262887, 19.798044204711914, 12.93416200365339, 12.265561171940394, 18.97707632609776, 15.610427447727748, 10.27857266153608, 4.3236099396433145, 0.8386246083038194, 0.18781223706901073, 0.03715609925399933, 0.2354223116167954, 0.5263011274593217, 0.9079101447548185, 3.2055323123931885, 4.5269546168191095, 4.323549577168055, 7.116773613861628, 5.611883691379002, 9.582730548722402, 13.906647511890956, 6.449362661157336, 4.5526633858680725, 4.01768205847059, 4.487941784518106, 3.740915332521711, 3.9199556452887396, 5.36018910578319, 8.50093684877668, 14.752588953290667, 22.57621192932129, 28.37231581551688, 35.524312019348145, 42.69192082541329, 49.19230454308646, 51.05578361238752, 52.94374813352312, 54.01967321123396, 56.752719334193635, 55.1114228112357, 54.1574490410941, 53.81141832896641, 54.26276636123657, 52.446107728140696, 50.70639344624111, 45.815514768872944, 49.10481630052839, 52.356281416756765, 52.69165359224592, 53.29052577699934, 52.385085174015586, 53.15262835366385, 51.112484386989046, 53.12456805365426, 49.85075058255877, 52.97971895762852, 50.86716086523873, 48.784285477229524, 48.877978461129324, 49.86868040902274, 48.31020293916975, 46.20501341138567, 39.31358160291399, 35.06475816454206, 27.25301139695304, 19.03517368861607, 8.949166008404323, 5.343790488583701, 1.4780368719782149, 3.560936144420079, 7.4066025188991, 4.701122505324228, 5.867829271725245, 5.539853453636169, 6.582488409110478, 7.7382895435605725, 6.234316783291953, 4.80801750080926, 4.367470008986337, 1.8529488572052546, 0.46623715332576204, 0.14799544933651174, 0.10017806876982961, 0.1891521265996354, 2.168997658150537, 6.571997497762952, 12.965721590178353, 15.478918892996651, 13.84941520009722, 23.415910414287023, 31.282058102743967, 32.17279631750924, 24.61779591015407, 8.690369929586138, 1.7421361633709498, 0.15257975405880383, 0.049733119018908055, 0.032435090081500154, 0.04934988244037543, 0.040787564391004186, 0.052268502435513904, 0.042429473251104355, 0.07296761351504497, 0.038597558691565476, 0.045219992620072195, 0.049142705343131504, 0.028002985852903554, 0.04903559180508767, 0.002278638700123078, 0.035435419263584275, 0.01820206149880375, 0.05922653978424413, 0.029518159638558115, 0.032812969626060555, 0.06158678313451154, 0.07017010862806014, 0.035576439196509976, 0.050709022009479146, 0.08085575274058751, 0.04688704798796347, 0.030104322292442833, 0.05819997736918075, 0.025165289640426636, 0.05050571595451661, 0.037264152563044, 0.011549174918660095, 0.023869045178538988, 0.026266022718378475, 0.05236376535945705, 0.007735416259882706, 0.04229625647089311, 0.1493875589221716, 0.15271227194794587, 0.17222023515829019, 0.13265369114066872, 0.16149324790707656, 0.20239840580948762, 0.10261685254850558, 0.12012014511440482, 0.22553764416703156, 0.16598491902862275, 0.1812684860612665, 0.14844214250998838, 0.09251227189919778, 0.09977682387190205, 0.1268297572221075, 0.18409143601145062, 0.27669746109417503, 0.17044554038771562, 0.14479881658085755, 0.12045760772057942, 0.1161495888871806, 0.1597859723759549, 0.17364110105804034, 0.15560675305979593, 0.12458216425563608, 0.15469225070306233, 0.10268688414778028, 0.20578999524669989, 0.1588382353740079, 0.2296820410660335, 0.1388506293296814, 0.07798975652882031, 0.11705537885427475, 0.132413191188659, 0.08176680135407619, 0.06968926478709493, 0.22588923387229443, 0.1926098596304655, 0.20129573212138244, 0.14028137469930307, 0.23028780998928206, 0.37310404224055155, 7.1795766438756665, 27.64715838432312, 47.427555901663645, 43.115660190582275, 28.145278215408325, 19.29501894542149, 19.305729593549454, 21.68803586278643, 19.733144555773052, 13.77003811086927, 5.154667036873954, 1.6181865973131997, 0.8935672715306282, 0.36534700276596205, 2.155588503394808, 2.897628971508571, 4.951003176825387, 7.802517822810581, 12.133593167577471, 14.495777453695025, 8.987143124852862, 16.788543156215123, 15.542329890387398, 23.220891850335256, 11.82091120311192, 4.467987860952105, 7.855438777378627, 8.045672638075692, 5.50820962020329, 4.609761076314109, 7.037538528442383, 7.873563153403146, 15.24837418964931, 21.050556012562343, 27.49250190598624, 35.23504114151001, 42.990821906498496, 49.565068449292866, 50.894665309361045, 53.07595845631191, 56.6804233278547, 59.45783369881766, 57.948716231754844, 55.39802210671561, 56.770214898245676, 55.82224784578596, 53.46737132753645, 52.4000620160784, 50.08857699802944, 52.828018937792095, 52.899005208696636, 53.816386290958945, 56.00701781681606, 54.596762793404714, 55.18947540010725, 53.61432572773525, 52.959350313459126, 49.69725445338658, 52.6985114642552, 51.02733768735613, 48.422756808144705, 50.768155983516145, 50.16236686706543, 48.70768158776419, 44.572832924979075, 39.37172065462385, 34.81766285215105, 27.213691541126796, 18.549451180866786, 10.80789337839399, 5.560725407941001, 2.6660496379647936, 7.631691149302891, 9.82956964629037, 8.638322710990906, 9.738567352294922, 8.531044261796133, 12.32544595854623, 17.705053976603917, 16.87153591428484, 10.19177576473781, 13.316350272723607, 9.119417718478612, 2.6523406250136237, 1.2845254157270705, 0.6756022817322186, 0.6404916771820613, 3.877664566040039, 7.811494895390101, 16.487755639212473, 23.363335132598877, 20.57205789429801, 32.52069609505789, 39.69636481148856, 37.19231046949114, 27.052149397986277, 9.719257439885821, 2.278930753469467, 0.23902571254542895, 0.12423252873122692, 0.2516195396227496, 0.1349660163479192, 0.1514303700200149, 0.1936351124729429, 0.20054101119084017, 0.1382713368428605, 0.09316352302474634, 0.10451006024543728, 0.18099233587937696, 0.07963895624769585, 0.11901877421353545, 0.12295594651784215, 0.07088761869817972, 0.12497939222625323, 0.3098476422684533, 0.12990641141576426, 0.11125444048749548, 0.1776180626558406, 0.1297707044120346, 0.2176939964826618, 0.14260798985404627, 0.18924235818641527, 0.1510028386754649, 0.07657940792185919, 0.1727873140147754, 0.18901853662516388, 0.1115838692390493, 0.10306892650468008, 0.14445869411740983, 0.11205832806548902, 0.22425385591174873, 0.10514119280768291, 0.11609355546534061, 0.11093003289507967], [0.015016061386891773, 0.03836181187736137, 0.05402399466506072, 0.020231865080339567, 0.013071430065403027, 0.003558194381184876, 0.044609260213162215, 0.1047615185379982, 0.02373006593968187, 0.03708734669323478, 0.03563357863043036, 0.030649861054761068, 0.043602792612676106, 0.06863979502980198, 0.02635241549329034, 0.02604027072499905, 0.04529825145644801, 0.02425272110849619, 0.0683744064133082, 0.07224855638508286, 0.06561967637389898, 0.03381910813706262, 0.013967675589291113, 0.10345552183155503, 0.08469394714172397, 0.007399711907575173, 0.03678022478041904, 0.046509673951991966, 0.050308150305811844, 0.014692427324397224, 0.09981503896415234, 0.025072445693824972, 0.039660636468657424, 0.006368776334316603, 0.02633890077205641, 0.0685467068105936, 0.030427854574684585, 0.04267849560294833, 0.05213729411895786, 0.02709896007685789, 0.03526892712605851, 0.045426073883260996, 0.460713444011552, 8.51928096158164, 27.945654732840403, 36.16220528738839, 34.28918981552124, 24.2150296824319, 21.973448753356934, 29.612930570329937, 20.136878320149012, 13.100368125098091, 9.012217436517988, 4.626657358237675, 1.964459844997951, 0.5196128349219049, 0.18548350488500936, 0.18651179756437028, 0.29481342328446253, 1.6866018176078796, 2.2331599295139313, 4.274665525981358, 6.547900710787092, 5.432158546788352, 8.494875414030892, 11.825889587402344, 6.708199126379831, 4.8759092177663526, 2.750478284699576, 3.6616889323507036, 3.6162279546260834, 2.6424103464399065, 1.7673883054937636, 3.2288717457226346, 4.6924216236386975, 10.607896430151802, 16.292281968253, 23.814113412584575, 30.84318903514317, 41.38824074608939, 46.73425074986049, 51.33360038484846, 52.83714539664132, 55.319583892822266, 51.6622953414917, 53.34177916390555, 51.65755319595337, 52.50164467947823, 46.514701570783345, 46.89614725112915, 44.910765511649, 48.3017851965768, 57.43858643940517, 54.34324734551566, 50.523162501198904, 51.09861578260149, 52.51943901606968, 53.15816954204014, 48.254356792994905, 58.82552678244454, 51.89964580535889, 41.807686124529155, 49.588348388671875, 48.830292974199565, 46.19937147412981, 42.70964568001883, 38.121562549046104, 29.417578492845806, 23.23263951710292, 15.824965238571167, 7.210001936980656, 1.3130864202976227, 3.5202316428933824, 0.9236144849232265, 2.39948308467865, 5.753117118562971, 3.1512097758906226, 4.201887922627585, 5.179830806595938, 7.555911489895411, 6.2008559959275384, 3.3615408667496274, 4.44767393384661, 3.375375815800258, 1.0132888044629778, 0.37900281857166973, 0.2622151624943529, 0.28951819028173176, 2.7887387573719025, 7.044111958571842, 9.888460840497698, 12.150129011699132, 16.03460281235831, 27.407016481672013, 30.219021933419363, 29.371473721095494, 17.253023283822195, 9.767561316490173, 2.181639471224376, 0.47388017177581787, 0.10998012458107301, 0.04543517643053617, 0.027791362654949938, 0.007069175871687808, 0.008338868834211357, 0.0444199523356344, 0.010509146976151636, 0.027957451064139605, 0.07710817669119154, 0.03001287952065468, 0.05657639913260937, 0.0771446954458952, 0.02354263760415571, 0.019707747668560063, 0.0212404547990965, 0.01281386665401182, 0.03766087841774736, 0.08246501388826541, 0.09068068196730954, 0.03146553478602852, 0.025070160727149675, 0.062034670529620986, 0.03141585584463818, 0.046193374853049, 0.03510073186563594, 0.004156268717321966, 0.01737331409406449, 0.05015135104102748, 0.07418963472758021, 0.021523785577820878, 0.055447707019214115, 0.035046581378472705, 0.02995349413582257, 0.0545213710117553, 0.021614258044532368, 0.02780616150370666, 0.022813059788729464, 0.0732592750074608, 0.05905447008886507, 0.06827829871326685, 0.022845269846064702, 0.027290792104655077, 0.04237409461555736, 0.02885025047830173, 0.007862111470395965, 0.03717959692169513, 0.057262906937726905, 0.03168549209034868, 0.056962702689426284, 0.09759835326778037, 0.04080996283196977, 0.01856207351998559, 0.037482698514525375, 0.019387801443891864, 0.04936091881245375, 0.05028481887919562, 0.036245512044323344, 0.10643499623984098, 0.10972485292170729, 0.07847410839583192, 0.02641291876456567, 0.00851471203246287, 0.041409909924758334, 0.00892623164691031, 0.013281218674299973, 0.040089134725608995, 0.035245032515376806, 0.04441726194428546, 0.03877839845206056, 0.056077109317162206, 0.05590055450530989, 0.02380233840085566, 0.03058680479547807, 0.0293080173432827, 0.051434311483587535, 0.031270154020083804, 0.03826328180730343, 0.09984363242983818, 0.884938043143068, 10.446309123720441, 32.26620442526681, 41.873054776872905, 36.75153759547642, 23.06058301244463, 20.945857082094463, 26.707457951137, 23.854544980185374, 19.328141008104595, 10.325550300734383, 4.930442588669913, 1.5435483966554915, 0.22244033536740712, 0.21891455884490693, 0.28480055342827526, 0.3063940890133381, 0.9655268873487199, 1.3443367034196854, 3.1829741171428134, 6.316084921360016, 4.606887996196747, 8.637354305812291, 10.652747052056448, 7.8217374086380005, 4.6000613910811285, 7.380882893289838, 4.509682697909219, 4.224919898169381, 4.403654490198408, 3.249875281538282, 5.762900182179042, 6.856441114630018, 13.987748622894287, 20.254598174776348, 27.858578171048844, 33.27941158839634, 44.10580628258841, 48.12466866629464, 51.643750599452424, 53.840114389147075, 57.13631200790405, 52.91662931442261, 55.43017142159598, 54.27625281470162, 54.84868710381644, 48.872774260384695, 49.73601497922625, 47.33603770392281, 51.068853173937114, 53.64196566173008, 53.00549330030169, 53.44962215423584, 52.57844659260341, 50.787742955344065, 55.70107126235962, 49.24836955751692, 54.96955796650478, 55.07401718412127, 44.80655990328108, 50.0430280821664, 48.60021727425711, 46.95486995152065, 43.90812308447701, 39.934212071555, 30.92465318952288, 25.654578311102732, 19.329155445098877, 9.288744449615479, 3.5045697518757413, 1.2456432964120592, 2.2890082470008304, 3.847136352743421, 6.459656851632254, 6.571041251931872, 6.351438224315643, 6.06984771149499, 7.631881356239319, 6.554168854440961, 4.524375966617039, 2.79385957973344, 2.1513563990592957, 0.8577662983110973, 0.5930471516081265, 0.06476659500705344, 0.41254579009754316, 1.8787529468536377, 7.004089031900678, 14.065411244119916, 16.48287626675197, 14.557170867919922, 24.660509960991995, 33.40602513722011, 34.024227210453574, 21.910711731229508, 13.53747842993055, 2.9541662463120053, 0.6542073669178146, 0.018549664810832058, 0.06581780181399413, 0.05736881946878774, 0.018336457233609896, 0.03260225396869438, 0.010960997863938766, 0.009872282489335962, 0.044812793577356, 0.018629165366292, 0.042177366957600625, 0.06200156480606113, 0.0507801324794335, 0.02234742870288236, 0.028744982555508614, 0.04267172043078712, 0.027225352491119077, 0.04218252043106726, 0.04183628775977662, 0.011856228129805198, 0.04752430093607732, 0.057458698217357905, 0.05572008793907506, 0.047990902327001095, 0.056735539343208075, 0.058975230769387314, 0.0092414238856041, 0.010948578976759953, 0.014507416269874998, 0.07947774311261517, 0.05062092102265783, 0.049442051244633536, 0.0471443247183093, 0.0018962362955790013, 0.03588646184653044, 0.047674633762133975, 0.027886937705001662, 0.10947882969464574, 0.13125297773097241, 0.15535824639456614, 0.22981169553739683, 0.1151510431830372, 0.10686958434858493, 0.08152731920459441, 0.16301555479211466, 0.11326669715344906, 0.09890344073729855, 0.14150960450725897, 0.14240402222744056, 0.19666000801537717, 0.25171700439282824, 0.11793914357466356, 0.15118746805403913, 0.10556679032742977, 0.07293935931686844, 0.19296742044389248, 0.13852265264306748, 0.13545741140842438, 0.16168853028544358, 0.14826291427016258, 0.30192569164293154, 0.12881648061530931, 0.1515902735825096, 0.0910565225141389, 0.22525188592927797, 0.14363335126212665, 0.12785989551671914, 0.15878559462726116, 0.11733969859778881, 0.12520662003329822, 0.12450969671564442, 0.11958013980516366, 0.19846594253821032, 0.18757420698446886, 0.12591965177229472, 0.1734318815703903, 0.08979408097054277, 0.13722211814352445, 0.20922978781163692, 1.1527203683342253, 13.12275869505746, 38.31702579770769, 48.698329312460764, 45.17275776181902, 32.84888730730329, 32.19034399305071, 39.9608862059457, 28.770767211914062, 19.99755825315203, 12.329027754919869, 6.404265378202711, 2.646790099995477, 0.8540431495223726, 0.5460877514311245, 1.1247881757361549, 1.2868217953613825, 5.769745894840785, 8.034503408840724, 9.343279123306274, 15.540874242782593, 12.160507014819554, 17.17367833001273, 20.661602803639003, 14.585908617292132, 10.074418084962026, 8.415030189922877, 8.438033938407898, 7.961866940770831, 6.539224147796631, 3.9451945424079895, 6.424198891435351, 7.159191931997027, 16.344416039330618, 21.689276116234915, 28.78339729990278, 34.51252228873116, 45.49128402982439, 49.03759595326015, 52.857149260384695, 54.78050095694405, 59.630656242370605, 54.58638913290841, 56.77679484231131, 54.8981374331883, 54.721045221601216, 49.147290638514924, 53.40842628479004, 51.707715715680806, 53.253717694963726, 54.493311064583914, 53.135296072278706, 53.41503749574934, 54.68978180204119, 52.54752363477434, 55.95822409221104, 49.37153679983956, 56.544033663613455, 52.74387277875628, 46.80708524159023, 49.38437359673636, 49.1337069102696, 47.27467816216605, 43.78307288033621, 39.776498385838096, 31.922765391213552, 26.15008040836879, 16.69612864085606, 9.165184634072439, 2.9558516187327246, 6.237097799777985, 5.03761898619788, 5.46745365858078, 11.953633087021963, 10.092726588249207, 11.604610306876046, 12.699501361165728, 16.45050287246704, 15.752905470984322, 8.618954607418605, 10.01217612198421, 6.930495883737292, 2.2417809069156647, 0.9832327429737363, 0.7250491370047841, 0.7148261112826211, 3.198601918561118, 8.628682953970772, 13.69590778010232, 18.54349831172398, 22.938902684620448, 36.053031717027935, 42.15510647637503, 39.981306961604524, 26.59230719293867, 14.819800615310669, 3.4725116321018765, 0.6366653910705021, 0.15210528166166373, 0.1609541925468615, 0.09707443602383137, 0.1737707555294037, 0.08240050556404249, 0.09988220036029816, 0.07263021876237222, 0.11263265367597342, 0.2457657094512667, 0.13696617473449024, 0.20625794013696058, 0.2248047992054905, 0.1486085057258606, 0.14284293938960346, 0.09163800666907004, 0.15484323831541197, 0.2346530428954533, 0.1499659557427679, 0.19637169848595346, 0.1426475484456335, 0.0931001885661057, 0.1214106237249715, 0.10829894550676857, 0.13560385283614906, 0.1435008876557861, 0.07209886477461883, 0.12236780593437807, 0.09667245152273349, 0.22373536016259873, 0.11439459877354757, 0.15429913465465817, 0.11947408478174891, 0.0872043367209179, 0.12292925295020853, 0.13932682520576886, 0.15553761034139565], [0.024643650577802743, 0.058167977657701285, 0.07712058031133243, 0.08143790185983692, 0.023176057363993356, 0.02461905707605183, 0.038212557921984365, 0.03581079840660095, 0.018224027373694947, 0.016749709877850752, 0.028264493249090653, 0.026713453798687885, 0.07328537146427802, 0.013552054230655943, 0.031332524958997965, 0.015386799350380898, 0.020737589104101062, 0.02237519944485809, 0.07734852058014699, 0.012914094757953925, 0.03068842559254595, 0.040859176976872344, 0.022564719364579235, 0.01592778683906155, 0.05563950172758528, 0.013676511971945209, 0.13863096040274414, 0.01593581390833216, 0.014653981530240603, 0.05836488852011306, 0.05710645033312695, 0.016167253721505404, 0.015174455208969968, 0.07137832165296588, 0.012557546658042287, 0.04985111965132611, 0.04286045155354908, 0.0394128965479987, 0.02711314824409783, 0.03283274892185416, 0.02166828639539225, 0.025282364072544233, 0.05024358430611236, 2.0413153895309994, 12.048578483717781, 24.129436561039515, 38.669692039489746, 30.56521245411464, 20.937618255615234, 17.649770634514944, 12.151151265416827, 18.521213701793126, 17.054558413369314, 10.863785556384496, 5.65807227577482, 1.390101122004645, 0.3138314299285412, 0.3721036644918578, 0.2802831386881215, 0.6438311008470399, 1.448529826743262, 1.3039281517267227, 4.421735439981733, 3.4242348968982697, 7.452155777386256, 10.92777064868382, 4.008868268557957, 5.506217224257333, 4.550558950219836, 3.003966591187886, 1.5943531904901778, 3.3660207177911485, 1.700714151774134, 3.1367106224809373, 2.520072328192847, 3.7667578543935503, 6.594736780439105, 13.713728172438485, 20.935441732406616, 28.436511959348405, 40.43342276981899, 46.361712660108296, 50.45507362910679, 54.641311168670654, 54.62695619038173, 55.657565116882324, 53.28858722959246, 50.09441001074654, 47.008485725947786, 45.63188777651106, 42.87254272188459, 35.8981146812439, 65.42484937395368, 55.76782260622297, 49.813216413770405, 52.82619850976126, 47.318590777260916, 50.03121614456177, 58.74672031402588, 55.09763758523123, 42.26696899959019, 45.74079384122576, 50.64710099356515, 46.02655587877546, 40.745184966496055, 33.434530121939524, 27.562501532690867, 19.020705802100046, 13.305709975106375, 6.245650597981044, 1.6541943337236131, 0.8966550944106919, 0.32344317702310427, 0.4961283579468727, 3.551542179925101, 4.8776792713574, 4.932357685906546, 4.2623693857874185, 3.6049060821533203, 4.683491017137255, 4.260565459728241, 2.281957345349448, 2.314666207347597, 1.558107044015612, 0.58949021675757, 0.24741802364587784, 0.055308454670012, 1.208784731371062, 6.539824298449925, 8.50138327053615, 8.192502839224678, 14.392162442207336, 28.741503136498586, 31.652355398450577, 29.616390773228236, 23.755503620420182, 12.0420115675245, 3.988095326083047, 0.7850973148431096, 0.04165498659546886, 0.09229301009327173, 0.07033334379749638, 0.09946579020470381, 0.011887106562166341, 0.06754342493202005, 0.02729161991737783, 0.03805680699380381, 0.040772450023463795, 0.03734070149117282, 0.032028837595134974, 0.10725060211760656, 0.05577592797843473, 0.0637082839384675, 0.06274200257446085, 0.018496771309790865, 0.009749610991483288, 0.01890273202609803, 0.04785082216507622, 0.0357699573838285, 0.024291609646752477, 0.020036004250869155, 0.09571777310754571, 0.04037963592314294, 0.05068478813128812, 0.04582773608022502, 0.018706640494721274, 0.028709135550473417, 0.041722059782062254, 0.04735440933810813, 0.04217520582356623, 0.014557946772713746, 0.031879461503454616, 0.06210121445889984, 0.04901324764692357, 0.05466456564941576, 0.024142065617655004, 0.0620388299492853, 0.05741717865956681, 0.015540877689740487, 0.035759545263967345, 0.041476131549903324, 0.042164535860397985, 0.037509789025144916, 0.032038584750677855, 0.04945999849587679, 0.0480930625594088, 0.02457877414833222, 0.0008301937975504968, 0.060126867544438155, 0.027919924684933255, 0.012061574878836316, 0.041941257127161534, 0.05910622874008758, 0.049427588270711045, 0.036696568197969875, 0.009015570960140653, 0.08283439478171722, 0.04667969786428979, 0.04043123511863606, 0.051709803486508985, 0.03556046648217099, 0.03658378549984523, 0.01790100399271718, 0.07568845751562289, 0.0357745273171791, 0.029294670559465885, 0.024720289411821535, 0.03946559836289712, 0.04547288940687265, 0.0649105462112597, 0.039834263401904275, 0.022145491592319946, 0.034108187803732495, 0.030620921536215713, 0.005279687341369156, 0.0760100966851626, 0.04773707255455, 0.07904482420001711, 0.12068811963711466, 3.11289958017213, 15.780573197773524, 29.155898911612375, 42.68316956928798, 33.671446323394775, 22.550350734165736, 22.37211033276149, 17.794650997434342, 21.589883872440883, 19.4677528994424, 12.86976957321167, 5.658632040023804, 1.7209963777235575, 0.10434130180094923, 0.12068540549704007, 0.107130799974714, 0.7488826523934091, 1.026379536305155, 2.0310411751270294, 4.458351578031268, 4.45627840927669, 5.353940503937857, 5.987589291163853, 8.928946750504629, 8.218809587614876, 7.727066465786525, 5.125788152217865, 5.627478923116412, 4.935570793492453, 4.240589823041644, 3.232922545501164, 4.564451004777636, 5.112075882298606, 9.079758269446236, 17.977987902505056, 24.86075530733381, 32.516110283987864, 41.290087018694194, 48.185378551483154, 51.645088127681184, 54.81347015925816, 56.435756410871235, 58.03310557774135, 55.64331088747297, 53.03772251946585, 48.29378087180001, 49.628300530569895, 45.36190857206072, 40.51387248720442, 56.17096403666905, 53.856863021850586, 52.29695769718715, 53.1553589957101, 49.81161832809448, 49.74966124125889, 54.94261980056763, 58.94399356842041, 45.266693932669504, 48.65271438871111, 51.25945268358503, 47.36858654022217, 42.65821858814785, 36.50523785182408, 30.92446906226022, 21.921995605741227, 15.512412684304373, 9.972496696880885, 3.499387047120503, 1.7160931208303996, 3.7551213588033403, 5.046685082571847, 7.548740948949542, 8.143413816179548, 7.72956086908068, 6.465860724449158, 5.187016112463815, 5.770568822111402, 3.9390089086123874, 4.16897908278874, 3.2932370347636084, 0.524335438651698, 0.3029666729271412, 0.17007330964718545, 0.20319256319531373, 1.0977284163236618, 4.753083739961896, 12.129575371742249, 14.642454794475011, 8.909753220421926, 26.197369847978862, 36.67070920126778, 35.12171254839216, 28.44696205002921, 15.33254987852914, 5.285535054547446, 0.9461762628384999, 0.0533103692079229, 0.026348763278552463, 0.0632405426087124, 0.028072815588010207, 0.03275259697277631, 0.10552283482892172, 0.0421103107343827, 0.05882095904754741, 0.019198376519073333, 0.02439512694919748, 0.03844763637919511, 0.03885034012741276, 0.02888373618147203, 0.08078477797763688, 0.0963638402255518, 0.0042568441463767415, 0.03233799172033157, 0.062111575688634596, 0.020016384410804937, 0.019549652401890074, 0.04475472455046006, 0.024260714251015867, 0.07661644914852721, 0.04155332508629986, 0.018766773964411447, 0.0029431312245183756, 0.025444328685158064, 0.008394095647547926, 0.05192644614726305, 0.10273849352129868, 0.04666998802817293, 0.022631644969806075, 0.011187966131339116, 0.07368457397179944, 0.055178620386868715, 0.0542698516510427, 0.039532376386757405, 0.15049605444073677, 0.16218052245676517, 0.1326950274940048, 0.1467562136905534, 0.17636783474258014, 0.10153057905180113, 0.15584687303219522, 0.1122297802940011, 0.10032179605747972, 0.1778058132955006, 0.07781644511435713, 0.13289063556918077, 0.12821462005376816, 0.10244772090975728, 0.10322618378060204, 0.12082118035427161, 0.09368324013692991, 0.07412554709506886, 0.10018011794558593, 0.1394852359912225, 0.18668381976229803, 0.08878291451505252, 0.1659725018377815, 0.11396230411316667, 0.18481034386370862, 0.08707369837377753, 0.1744785625487566, 0.13465948136789457, 0.12217468129737036, 0.13970642483660153, 0.12447501000549112, 0.13878443145326205, 0.1228820269129106, 0.19523840929780686, 0.06828914848821503, 0.10961290142898049, 0.12949148725186074, 0.08655344521892921, 0.15659768560103007, 0.17217965876417501, 0.1378603753234659, 0.15052497360323155, 0.370193642697164, 3.386472306081227, 18.257986409323557, 35.54184579849243, 50.79108156476702, 40.80592264447893, 29.430203369685582, 27.252029963902064, 20.34496644565037, 28.775290489196777, 23.369492973600114, 14.955137627465383, 7.280437563146863, 2.2221420407295227, 0.4379078820347786, 0.6386729862008775, 0.9545063929898399, 2.2416799409048895, 4.781094968318939, 7.346573557172503, 13.620842916624886, 10.80794722693307, 16.233371666499547, 17.914158276149205, 11.95912390095847, 11.624931182180132, 11.269749692508153, 8.68771311214992, 6.38146139042718, 6.869249250207629, 4.593435849462237, 6.165071470396859, 5.35962803874697, 5.625528650624411, 10.092935034206935, 18.01650697844369, 25.019572019577026, 31.946146079472133, 42.987802914210725, 49.32228102002825, 52.61761358806065, 56.45325892312186, 56.371586322784424, 57.359498568943565, 56.53102663585118, 54.155131816864014, 51.74991907392229, 51.77761459350586, 47.79267678941999, 41.563884258270264, 57.716048853737966, 53.773588861737935, 53.89486966814314, 53.90020588466099, 49.2566796030317, 50.17373759405953, 56.067338602883474, 55.294594696589876, 48.0146369934082, 48.978772503989084, 51.77154534203665, 46.9061735016959, 41.52526617050171, 36.070353576115195, 29.990419251578196, 20.208641052246094, 15.194242511476789, 8.01358151435852, 2.795268544128963, 3.1799746666635786, 3.5960403978824615, 6.907838242394583, 11.29650981085641, 11.273836101804461, 13.599412066595894, 12.760992050170898, 10.719185726983206, 9.987062726702009, 8.813399076461792, 7.4541646753038675, 7.4360706976481845, 4.318922511168888, 1.8018919740404402, 0.6287816826786313, 0.439092794167144, 1.659505580152784, 7.600362590381077, 11.861361009734017, 13.96212887763977, 20.88495785849435, 36.756686210632324, 42.93261684690203, 39.711094992501394, 33.71478918620518, 17.809897082192556, 6.142620537962232, 1.0646603107452393, 0.1726962003324713, 0.15095390272992, 0.16933616277362618, 0.14709812748645032, 0.1551866584590503, 0.1887194655303444, 0.15243882233543055, 0.12343693285116128, 0.11932464422924177, 0.05358284851536155, 0.09735322570694344, 0.14650225160377367, 0.08809221336351973, 0.23290326393076352, 0.13307373145861284, 0.09196265853409256, 0.06332554269049849, 0.07582708221993276, 0.16915669026119368, 0.06732367458088057, 0.12345948735518114, 0.16845310372965677, 0.28423481807112694, 0.1344784889370203, 0.11710951237806252, 0.16330668702721596, 0.12881249082939966, 0.12928576900490693, 0.1539292245038918, 0.1971769431339843, 0.11495160817035607, 0.08696042373776436, 0.11431073184524264, 0.1498629269855363, 0.15671127236315183, 0.13626570946403913, 0.13198396350656236], [0.014725836692377925, 0.047828148917428086, 0.008259116372625743, 0.04284506577200123, 0.03249798009970358, 0.031238907482475042, 0.019411170189934115, 0.0895938045744385, 0.014252779040751713, 0.04213711286761931, 0.03499521627756102, 0.036326681795929155, 0.047565250524452755, 0.04372412824471082, 0.01869973131189389, 0.05030726142493742, 0.04702236483405743, 0.010477171861566603, 0.04311357904225588, 0.017205027231414403, 0.04096214466595224, 0.06947623193264008, 0.009608528294068362, 0.025102937361225486, 0.06811303472412483, 0.026103942754811475, 0.033067708635436635, 0.057094514902148924, 0.0199768427825932, 0.09485678680773292, 0.06529420348150389, 0.017859900037625005, 0.05160849820822477, 0.0635608925617167, 0.02901514805853367, 0.09495982235031468, 0.10079141014388629, 0.016792384641511098, 0.04285871111122625, 0.006770558123077665, 0.01117121649440378, 0.04934355849400163, 0.011305607140197285, 0.22122012584337167, 2.4648009283202033, 13.480654324804034, 30.82089226586478, 38.21489422661917, 31.254011699131556, 19.27691193989345, 19.56584756714957, 19.00673818588257, 20.4595422404153, 16.59678156035287, 13.47260136263711, 5.555198115961892, 1.9847299115998405, 0.5107123553752899, 0.15776841635150568, 0.17759006630097116, 0.10483684949576855, 1.5199676219906126, 2.8593079192297797, 2.3562053612300327, 4.163637655121939, 4.004992042269025, 8.111259290150233, 4.6694517476218085, 8.88501068523952, 2.7749181389808655, 5.8050549030303955, 2.636854176010404, 3.4464754291943143, 2.76464153613363, 2.4942638959203447, 2.245626300573349, 3.4203187184674397, 5.733131059578486, 12.197804944855825, 20.056491136550903, 26.010204485484532, 36.1639666557312, 44.91443763460432, 51.71750920159476, 50.87734692437308, 51.88755246571132, 50.125753334590364, 49.13568714686802, 50.13582822254726, 47.43901695523943, 39.287550176892964, 27.74311821801322, 63.98297309875488, 59.479122979300364, 48.79949508394514, 52.418888160160606, 52.67704153060913, 60.6241374697004, 50.09263474600655, 46.2224394934518, 46.6084223474775, 49.56484610693795, 44.5262313570295, 39.202743938991, 28.349299907684326, 24.923137971333094, 16.670666967119487, 12.092154111180987, 4.737937535558428, 4.353509775229862, 1.360871896147728, 1.736216081040246, 2.920566494975771, 3.3823822055544173, 4.233523505074637, 6.371722187314715, 5.525006021772112, 4.143450966903141, 3.7580704348427907, 4.857803949287959, 3.1556538002831593, 4.495105377265385, 0.5530395869697843, 0.24977009743452072, 0.2044025268405676, 0.3957341079201017, 1.0458739016737257, 5.500484526157379, 12.562237960951668, 5.5188090971538, 22.07671114376613, 39.02216025761196, 32.574958051954, 24.17889210156032, 29.713564804622106, 19.68309494427272, 6.4945615615163526, 0.7165192461439541, 0.0833489957398602, 0.016780890258295194, 0.02137410075270704, 0.06096118063266788, 0.04844511366848435, 0.012612306978553534, 0.038003626811717234, 0.05309436097741127, 0.056841068501983366, 0.05640656521011676, 0.05676529310377581, 0.06029112730175257, 0.047564256470650434, 0.04227521509996482, 0.007713705683792276, 0.04793034986193691, 0.01082101948226669, 0.04306934195171509, 0.04335818752380354, 0.036394328344613314, 0.029899004381150007, 0.057169615158012936, 0.09165062063506671, 0.052404406214399, 0.02589311683550477, 0.03495145416153329, 0.033526513658996136, 0.037146318171705515, 0.041071843422417126, 0.03051998605951667, 0.06255047928009715, 0.01822071273012885, 0.06466823457075016, 0.0700374889586653, 0.00999137810764036, 0.033924569442336044, 0.013027961415770863, 0.06870302092283964, 0.01249439625202545, 0.06378659366496972, 0.052583783731928894, 0.05130383259217654, 0.03394248955217855, 0.013261637849999326, 0.04863758012652397, 0.1406628606574876, 0.01883924998609083, 0.06688133081687347, 0.010226347151079347, 0.04337906604632735, 0.009615336544811726, 0.06514038637812648, 0.04832055838778615, 0.0788391941626157, 0.09831185319593974, 0.014452125843880432, 0.046908052039465735, 0.04788137998964105, 0.03617895454434412, 0.05497130418994597, 0.06696698229227747, 0.08398912567645311, 0.042546154132911136, 0.025750950178397552, 0.03005227187116231, 0.08960624890668051, 0.04232936219445296, 0.01228545920457691, 0.03851158491202763, 0.037406186905822585, 0.027337020695475594, 0.06119169254920312, 0.08379746667508568, 0.07762050455702202, 0.08027898440403597, 0.03184006915294698, 0.1088936814506139, 0.014332379680126905, 0.00716308130150927, 0.054848153476736376, 0.06460637931845017, 0.2633818084640162, 3.3555777924401418, 16.820821012769425, 36.6311913217817, 41.13657351902553, 32.88284315381731, 18.356591769627162, 19.222064597266062, 23.487323999404907, 28.62604492051261, 22.8763358933585, 15.237545422145299, 5.671020678111485, 2.624424717256001, 0.6518747806549072, 0.1541106104850769, 0.045043281745165586, 0.12173043084996087, 0.69700474185603, 2.1278248046125685, 3.7058612363679067, 5.661410885197776, 4.742528992039817, 7.375863688332694, 9.80563483919416, 8.87456406865801, 6.412108591624668, 5.75890496798924, 6.422776682036264, 4.784716282572065, 4.3377677627972195, 5.091603015150342, 3.8480739252907887, 4.969417640141078, 9.445567897387914, 15.98130144391741, 20.465456894465856, 29.706064224243164, 38.411663736615864, 47.19106354032244, 51.471261569431846, 53.29364204406738, 53.98209735325405, 53.4412704195295, 51.75059652328491, 53.299902370997835, 51.02334942136492, 42.788688387189595, 30.88749769755772, 54.39320836748396, 57.49754885264805, 53.0676623071943, 51.445417744772776, 50.237021786826, 60.06899724687849, 54.110190868377686, 46.95666258675711, 48.754126821245464, 51.96396180561611, 47.38211815697806, 39.82843964440482, 31.968814577375138, 27.3129517691476, 21.81350122179304, 13.386370744024005, 8.540111660957336, 6.323553800582886, 2.3030664069311957, 4.726190737315586, 7.512611184801374, 7.265564509800502, 7.114486353737967, 7.078100374766758, 8.062072123800005, 5.504807608468192, 5.702954598835536, 4.842583920274462, 3.209255026919501, 1.4677525609731674, 1.2995789051055908, 0.2769995177430766, 0.10357999229537589, 0.3472132086753845, 1.2001994720527103, 4.2829338823046, 14.040426390511648, 12.327973365783691, 12.06317230633327, 28.550478049686976, 36.93595668247768, 29.75423608507429, 32.63524062292916, 23.41470316478184, 8.608336022921971, 1.531147056392261, 0.07330188700663191, 0.03605523046904376, 0.022089246128286635, 0.06409826515508549, 0.054021046430404694, 0.08717945484178406, 0.03126241872087121, 0.06112092134675809, 0.06967861178730216, 0.03784115838685206, 0.03485553305862205, 0.026253736145528297, 0.06212619811828647, 0.03902047939066376, 0.016574634272339087, 0.015442817505182964, 0.026183350011706352, 0.008719161418931825, 0.024557072902098298, 0.01675038332385676, 0.026712736247905662, 0.006214579675413136, 0.01656897189760847, 0.03226862508537514, 0.04413250793835946, 0.02180738268154008, 0.047596731156642945, 0.03173263670344438, 0.00476957404420578, 0.03345647866704634, 0.04938571587471025, 0.02767513639160565, 0.036579687148332596, 0.004735952209947365, 0.03374128695577383, 0.040981689867164404, 0.019637868739664555, 0.018920075381174684, 0.13954082157995018, 0.18795737570949964, 0.15998349391988345, 0.1598616833133357, 0.14602627285889216, 0.17781931614237173, 0.1892976587904351, 0.22938847967556544, 0.11079923169953482, 0.22347943032426493, 0.14363348696913036, 0.13125683180987835, 0.17800522116678102, 0.15282488161964075, 0.1347243764570781, 0.14660175197890826, 0.21430054785949842, 0.09280495119414159, 0.09770286801670279, 0.12307516512061868, 0.22187641848410877, 0.16809908486902714, 0.16903897800615855, 0.13079708362264292, 0.1048869728775961, 0.0912889614701271, 0.14278404254998478, 0.22513641283980437, 0.10141542487378631, 0.19861752726137638, 0.25250985899141853, 0.14024292890514645, 0.1513633443308728, 0.10953130759298801, 0.11826530178742749, 0.16639137507549354, 0.2011368463614157, 0.10784799791872501, 0.30085800322038786, 0.15209298660712584, 0.16746964864432812, 0.10843976187918868, 0.1711223247860159, 0.361623365432024, 4.0018201896122525, 20.05594049181257, 42.654657636369976, 50.117686476026265, 40.6312484060015, 26.621154376438685, 29.268466676984513, 29.39966951097761, 30.028721196310862, 23.76871040889195, 18.356741155896867, 7.016856346811567, 3.046975071941103, 1.2263841927051544, 0.38118607284767286, 0.6513627852712358, 1.1872389103685106, 3.725994510310037, 8.554884399686541, 6.966254787785666, 10.357571073940822, 13.064880200794764, 15.63445952960423, 11.627762573105947, 17.069067989076885, 8.515850288527352, 12.498814804213387, 7.837204098701477, 9.993105053901672, 6.002030253410339, 5.830836193902152, 4.415225412164416, 5.539288912500654, 9.450156314032418, 17.122622966766357, 24.481757129941666, 28.94618317059108, 39.53526735305786, 47.37669856207711, 54.681707995278494, 54.64561905179705, 56.60266603742327, 52.515092917851035, 53.50547177450997, 54.48416723523821, 54.5885500226702, 46.67562879834856, 34.884087630680625, 56.56641033717564, 58.71177782331194, 53.60520274298531, 54.12676927021572, 51.42590372903006, 59.92506531306675, 54.30151646477835, 51.89308670588902, 50.317488874707905, 53.38081761768886, 46.20089660372053, 39.746794836861746, 30.326263904571533, 27.241944653647288, 18.29207079751151, 13.502960647855486, 7.1238303780555725, 7.097190116133008, 4.582176727907998, 6.093726933002472, 8.252218263489858, 8.832508359636579, 10.972054123878479, 13.289057748658315, 12.032068695340838, 11.95470484665462, 13.07120566708701, 13.183525034359523, 9.635529041290283, 7.708618130002703, 4.207283198833466, 1.620061416711126, 0.5102498659065792, 0.9366993542228426, 1.677487626671791, 6.506623200007847, 15.142205715179443, 10.647064294133868, 28.060119356427872, 44.649596623011995, 41.41402898515974, 35.60534191131592, 39.97845820018223, 26.00683982031686, 9.0246581860951, 1.460889260683741, 0.21099901358996118, 0.34239696711301804, 0.07711863970117909, 0.16900752112269402, 0.22822796766247067, 0.1266122596072299, 0.19894946659249918, 0.13306360771613462, 0.24273477494716644, 0.19513856965516294, 0.13290099001356534, 0.25946744850703646, 0.14290586672723293, 0.13176604519997323, 0.14787399156817368, 0.24296224702681812, 0.21123458737773554, 0.16382754407823086, 0.11038710988525834, 0.0681286681709545, 0.12101724983326026, 0.14617998818201677, 0.23835776267307146, 0.18252509220370225, 0.14162595969225678, 0.1343625680144344, 0.14440697617828846, 0.12415353368435587, 0.09945679283035652, 0.10189994637455259, 0.10452675899224621, 0.14202705531248025, 0.13058035953768662, 0.14471618458628654, 0.1336453700704234, 0.13879432449383394, 0.08924911557031528, 0.19748497089104994], [0.07459370911653553, 0.025063570455781052, 0.0426531523200018, 0.059274817550820966, 0.05373570549168757, 0.03866659284436277, 0.06427456890898091, 0.01695883267426065, 0.03057874719213162, 0.016462706528337936, 0.041735192827348194, 0.03421498582299266, 0.03625418711453676, 0.041930427708263905, 0.046294724236109426, 0.012019292817318013, 0.022056745997230922, 0.035879160809729777, 0.08689677715301514, 0.04689198772289923, 0.020485560842124478, 0.04185714931892497, 0.005595910529206906, 0.05209006468898483, 0.027637034953970994, 0.03025659912132791, 0.04414019574012075, 0.010925889613905122, 0.06036176958254405, 0.0966505484123315, 0.02207726998520749, 0.0628891700346555, 0.022368649885590588, 0.08103498776576348, 0.01990101988693433, 0.05750283692032099, 0.12040115360702787, 0.029822038153984716, 0.02503662752652807, 0.027422505929800015, 0.029410530413900102, 0.06583606119134597, 0.026778813684359193, 0.05834375215428216, 0.13071717933884688, 4.698686293193272, 18.7693738256182, 35.60768345424107, 42.1130941935948, 34.80635813304356, 25.23244571685791, 24.34980389050075, 18.339839662824357, 19.681811264583043, 15.113612140927996, 12.804222873279027, 5.876387715339661, 3.0030140365873064, 1.801745627607618, 0.5326397301895278, 0.13776049496872084, 0.3303744936628001, 1.3135967871972491, 2.476389003651483, 3.3912107603890553, 3.4017246876444136, 6.081985345908573, 10.71078188078744, 5.045585964407239, 6.18459460565022, 4.254164431776319, 6.488515760217394, 4.924816284860883, 2.3912475151675086, 3.80156181539808, 1.4469913435833794, 1.1943007771457945, 2.946844147784369, 4.420197282518659, 7.947446823120117, 16.63419587271554, 24.167703764779226, 32.62106282370431, 41.67033413478306, 48.15806865692139, 50.92483786174229, 52.088230337415425, 50.87114565713065, 50.03313732147217, 50.26508208683559, 47.09081145695278, 40.46603413990566, 49.48776626586914, 49.94943584714617, 50.93520457404, 58.86102512904576, 56.89710637501308, 45.80776057924543, 49.67257097789219, 52.31652729851859, 47.36829471588135, 45.089410645621165, 38.15959003993443, 29.73059136526925, 19.639666966029576, 13.5490654196058, 11.571459582873754, 4.455815051283155, 1.9140215686389377, 2.8937972571168626, 1.385126211813518, 2.977354122059686, 9.99355147566114, 7.027022429874965, 6.65826198884419, 6.429714024066925, 6.7595080988747736, 4.51177236863545, 2.8665574959346225, 2.6097062613282884, 1.7011191014732634, 1.9164549580642154, 0.8313881137541362, 0.40906134992837906, 0.3949489343379225, 1.247415087052754, 3.476094079869134, 15.144941568374634, 12.562053833689008, 25.552820205688477, 44.19879749843052, 20.703667197908672, 26.17087115560259, 30.784042494637625, 22.40868043899536, 8.967482328414917, 1.2057237241949355, 0.0870345536885517, 0.0383058666650738, 0.02430298867901521, 0.06670567845659596, 0.04167694738134742, 0.03005660431725638, 0.028756775494132723, 0.02556349809414574, 0.0662456520700029, 0.031498945850346766, 0.040368195822728534, 0.02132683909232063, 0.08574910980782338, 0.03965040076790111, 0.07878049409815244, 0.041090791512812884, 0.06469982716121844, 0.07515641142215047, 0.01797074212559632, 0.06290723942220211, 0.03249062478010144, 0.0368661951672818, 0.02816924898486052, 0.024020967472876822, 0.02959171961992979, 0.017528001418603317, 0.0585174842604569, 0.03659739691231932, 0.04278235895825284, 0.05026329914107919, 0.029848562087863684, 0.031242459613297666, 0.0556472234560975, 0.06771836483052798, 0.0495311802120081, 0.02286213483395321, 0.033724998722651174, 0.033309077112270255, 0.059774680728358884, 0.022691145705591356, 0.06202327114130769, 0.05678290787285992, 0.031874277495912144, 0.025294214686644927, 0.031474362526621134, 0.0771622152200767, 0.027906581293791533, 0.005904714360700122, 0.018540151749870608, 0.009798593586310744, 0.04781742127878325, 0.07927986194512673, 0.07701194006949663, 0.0490053528919816, 0.08654897367315632, 0.011496296684656824, 0.006915947397439075, 0.012767184292897582, 0.032581219383116276, 0.015420125597821814, 0.04146804680515613, 0.04653959734631436, 0.05006466140704496, 0.035022557846137455, 0.030443949425326924, 0.04998977149703673, 0.023184637439304163, 0.013375677534246018, 0.09244658292404243, 0.06950679314988, 0.020560265851340125, 0.03137587316866432, 0.08388244640082121, 0.10273130783545119, 0.036416984628885984, 0.007634814113511571, 0.00863094932200121, 0.025700314502630914, 0.04473343890692506, 0.03477370173537305, 0.017932199640199542, 0.005347374602154429, 0.02159529468709869, 0.26803104898759295, 5.641301495688302, 23.083694458007812, 42.21580593926566, 44.53010497774397, 36.60371119635445, 27.490113462720597, 23.294546229498728, 20.247969593320573, 25.583394016538346, 24.083830322538102, 17.05639100074768, 6.868576577731541, 2.679758216653551, 1.2021487674542835, 0.3313710716153894, 0.30317373467343195, 0.30507990238921984, 0.41587433006082264, 1.9165279141494205, 0.9505484168018613, 4.8667745079313, 10.163034541266304, 8.233309609549385, 7.522243993622916, 4.964073606899806, 6.848231817994799, 6.0150429265839715, 6.731316217354365, 4.955242880753108, 5.497932800224849, 4.201604783535004, 3.5973553444658006, 3.7568961892809187, 6.270037472248077, 11.351334571838379, 18.741707835878643, 25.969326496124268, 36.11004168646676, 43.020278794424875, 50.21505158288138, 53.58870077133179, 54.676059109824045, 54.81655863353184, 53.63819278989519, 53.80226755142212, 51.0936929838998, 43.126044273376465, 44.531741278512136, 53.978543349674766, 54.36102083751133, 57.27667604173933, 58.64118412562779, 50.90672390801566, 48.364728927612305, 51.12540108816964, 49.99411971228463, 46.50523812430245, 39.39583437783377, 32.47607823780605, 22.058392218181066, 15.861983503614153, 15.568540232522146, 6.388619772025517, 4.448167255946568, 6.153167034898486, 4.592104400907244, 4.41197452374867, 8.95523612839835, 7.934484090123858, 8.659636310168676, 7.508492640086582, 5.880298248359135, 4.899640790053776, 4.652181565761566, 3.0235731048243384, 2.0735022681100026, 0.9036603442260197, 0.40142726099916864, 0.07672880097691502, 0.18277271677340778, 1.1720479769366128, 4.874636394636972, 14.536289794104439, 15.879230669566564, 16.165861231940134, 34.84113734109061, 29.673967020852224, 29.27770778111049, 33.774467263902935, 26.24374212537493, 12.445142575672694, 2.0647195279598236, 0.0745128006009119, 0.07569345831871033, 0.04620160548282521, 0.06601241922804288, 0.02103371705327715, 0.030443125005279268, 0.015788551453234892, 0.009523981134407222, 0.05359560836638723, 0.002392203197814524, 0.03703252784907818, 0.049203247630170414, 0.06837576348334551, 0.05311288498342037, 0.023649893634553467, 0.02480695190440331, 0.0848261189780065, 0.056230509121503146, 0.0320309308756675, 0.024217932618090084, 0.02598764863796532, 0.018260651301326494, 0.016134661988222172, 0.036158371184553416, 0.05036822101101279, 0.010276322951540351, 0.045752069247620444, 0.06064419621335609, 0.030632473594908203, 0.05495588108897209, 0.052643104655934234, 0.04823482548817992, 0.017324247530528476, 0.05980516730674675, 0.05406139551528862, 0.07327234359191996, 0.02466589634838913, 0.055819798660065444, 0.05909799811031137, 0.20085042315934384, 0.14226429829640047, 0.15842005424201488, 0.11910570812012468, 0.13890998757311276, 0.1260191657181297, 0.20407467229025705, 0.12805300658302649, 0.10415664528097425, 0.20081657783261367, 0.11909984557756356, 0.16014449670910835, 0.1868143563291856, 0.1250389947422913, 0.10972722779427256, 0.2052394590739693, 0.09366489255002566, 0.1174807253160647, 0.22247867259596074, 0.17678564946566308, 0.0932983954304031, 0.09954302784587656, 0.12131522170134953, 0.13206078724137374, 0.0949584042121257, 0.11874394038958208, 0.14899935546730245, 0.20811897170330795, 0.16967410035431385, 0.18740624242595263, 0.07321143828864608, 0.0905241710799081, 0.13216923070805414, 0.24249726054923876, 0.2610193123774869, 0.1301865242421627, 0.2270796149969101, 0.11050333614860262, 0.10246788018516131, 0.08916866167315415, 0.0816689430336867, 0.11753369175962039, 0.10699705393718821, 0.11007957067340612, 0.38492887201053755, 7.2702862450054715, 26.383103881563457, 46.72179610388619, 52.48235648018973, 46.948699951171875, 34.00498417445591, 31.71347870145525, 26.51646934236799, 28.941870076315745, 22.715162004743302, 18.118909529277257, 8.56094583443233, 4.645559498241969, 2.660983749798366, 0.9418907442263195, 0.9008092486432621, 1.3923152089118958, 3.0914114075047627, 7.9869725193296155, 11.468194586890084, 7.0890485644340515, 13.2012003830501, 22.620402472359793, 13.525196620396205, 12.801608613559178, 14.792647055217198, 14.727834258760724, 13.263800178255353, 8.982393162591116, 8.46870241846357, 6.624861998217447, 2.9598618149757385, 4.267566638333457, 6.165934349809374, 10.146034904888698, 20.74217585154942, 27.982250894818986, 36.62365600040981, 44.79260792051043, 51.18926545551845, 53.12512043544224, 56.18927253995623, 57.233666692461284, 55.54939208711897, 55.10687868935721, 52.05363178253174, 43.80970185143607, 49.63059343610491, 54.88947302954537, 54.64835664204189, 58.00775507518223, 59.101050649370464, 53.354536056518555, 51.47624690192086, 53.56498309544155, 48.13467754636492, 47.09359768458775, 40.59031656810215, 31.17794976915632, 21.21106287411281, 15.413591929844447, 14.338924476078578, 6.793244208608355, 4.162614098617008, 6.690461678164346, 5.871963015624455, 8.394209044320242, 16.960445063454763, 14.497034209115164, 13.136240805898394, 15.026038782937185, 14.739833797727313, 9.761305332183838, 7.911339640617371, 7.848436730248587, 4.897908517292567, 3.697057000228337, 2.3809963166713715, 1.1626582465001514, 0.5279873141220638, 1.9786489350455148, 4.916347299303327, 17.777355194091797, 18.115883588790894, 31.389254910605295, 47.99500138419015, 30.63788366317749, 35.44792352403913, 40.991404805864605, 29.999094077519008, 13.598176155771528, 2.110725287880216, 0.19608881723667893, 0.1556695718318224, 0.09601998581950154, 0.15351579311702931, 0.12162802634494645, 0.20912928320467472, 0.09339607733168773, 0.07513655070215464, 0.11914048982518059, 0.16929390361266478, 0.11744907844279494, 0.12826055687453064, 0.22403983239616665, 0.23957272033606256, 0.1491875403693744, 0.14552965307874338, 0.16098037042788096, 0.1152396055736712, 0.10383860234703336, 0.11689753803823676, 0.17077868751117162, 0.1056438379787973, 0.16040808042245253, 0.18755248029317173, 0.29090709718210356, 0.10530622609491859, 0.12376112331237112, 0.15109509229660034, 0.12335902346032006, 0.16508929351610796, 0.18694171735218593, 0.14108695861484322, 0.20104121363588742, 0.22561133307005676, 0.16072674760861055, 0.16744474640914372, 0.06705680675804615, 0.15547853708267212, 0.17001822617437157], [0.005155057845903295, 0.0699570622029049, 0.021777160731809478, 0.020987527478220205, 0.04831563900890095, 0.04417674842157534, 0.007346725956137691, 0.011462252886433686, 0.025897447585261295, 0.01468920089038355, 0.035601840154933076, 0.061082020934138975, 0.10113212971815042, 0.03894592196281467, 0.033057381332452805, 0.061373336373695304, 0.06983158072190625, 0.06387513569955315, 0.011753525917551346, 0.027187396938513433, 0.05548169144562312, 0.06389306259474584, 0.050257551949471235, 0.10318842330681426, 0.001332922778341786, 0.09083187314016478, 0.011205884544844074, 0.05193229851179889, 0.01489173002274973, 0.06342006261859622, 0.01761461471739624, 0.023772706776591282, 0.00414260768697464, 0.00555536339691441, 0.049979763105511665, 0.07692047354898282, 0.07455156530652728, 0.029623726116759435, 0.051266991533339024, 0.0559455278063459, 0.023005281974162375, 0.03841034409457019, 0.0216900470134403, 0.015752716322562525, 0.011342329455406537, 0.4445878964449678, 4.968064044203077, 17.671106815338135, 36.41143022264753, 32.42505414145333, 32.00777660097395, 35.780572005680625, 20.178471973964147, 21.00690916606358, 14.888375861304146, 15.905857903616768, 15.34075743811471, 7.586128337042672, 3.78607862336295, 1.5695469272988183, 0.353099988507373, 0.18124841499541486, 0.22162994742393494, 0.7751160647187914, 0.9735955915280751, 4.32843850340162, 9.011905636106219, 6.006617367267609, 4.660980156489781, 4.1685135534831455, 4.379895559379032, 4.712970920971461, 3.8861991252217973, 5.438276435647692, 5.353673432554517, 5.807658306189945, 2.42741636293275, 1.499003495488848, 2.451766759157181, 2.8465505923543657, 6.348253343786512, 12.53195423739297, 21.19923530306135, 31.515461989811488, 38.93321289334978, 52.62520796912057, 54.59410163334438, 53.440964698791504, 52.46002149581909, 56.97851494380406, 49.045256342206685, 50.834125655038015, 37.14674765723092, 37.1082581111363, 61.55119391850063, 51.24661936078753, 48.94336448396955, 50.997929436819895, 51.55009930474417, 46.90683705466134, 42.79908289228167, 35.06015845707485, 28.674374852861675, 20.26707019124712, 12.736974733216421, 6.31769733769553, 6.276352516242436, 1.9062799726213728, 2.1629512054579596, 7.249657911913736, 3.6242179487432753, 4.539838748318808, 8.798141700880867, 6.146580142634256, 6.893040750707899, 5.940325038773673, 6.538248794419425, 4.590468534401484, 3.504181738410677, 2.263031538043703, 2.209393833364759, 0.4038709912981306, 0.058385828110788546, 0.41640858139310566, 0.8016131828938211, 4.703054104532514, 7.594559107507978, 22.013918536049978, 43.02024405343192, 37.001704011644634, 12.697866797447205, 20.156062296458654, 30.70348855427333, 25.10365390777588, 14.481346045221601, 1.7310989499092102, 0.1153922216700656, 0.06848417302327496, 0.023444865796981112, 0.03583750215225986, 0.08361635889325823, 0.009133935456962457, 0.02114846071760569, 0.08510973304510117, 0.021546440165756003, 0.01841558120213449, 0.05092943053958671, 0.05964390667421477, 0.003861424895668668, 0.004701588228012302, 0.054498338140547276, 0.015170685946941376, 0.04108281872634377, 0.05055720319173165, 0.03509126630212579, 0.04617524439735072, 0.022718828238014663, 0.05638063499437911, 0.014387363069025534, 0.019722656779257313, 0.07943019816385848, 0.0536162052968783, 0.08263933631990637, 0.02339009614661336, 0.04197202869025724, 0.06523846182972193, 0.050299417560121844, 0.03164857978533421, 0.02910735078954271, 0.1246657461992332, 0.05970034043171576, 0.042927453493965526, 0.027572489310322062, 0.010601209759313081, 0.014839228375681808, 0.030526279471814632, 0.01128968786049102, 0.009888427381935929, 0.040386302529701164, 0.06273227916764361, 0.011573631017069732, 0.03439548631597843, 0.04801964846306613, 0.013111292301411075, 0.025011608244052956, 0.06265610682645015, 0.03397864529064723, 0.04379884512828929, 0.10775164594607693, 0.01488552482000419, 0.03273367263110621, 0.07636576438588755, 0.04803519030766828, 0.011409313584278737, 0.011540451502826597, 0.026854573815528835, 0.0079887184713568, 0.06428254848080021, 0.06266483957214014, 0.06426633827920471, 0.043566290821347914, 0.040228522781814845, 0.045297274366021156, 0.02606422470749489, 0.02017925656400621, 0.055742503343416114, 0.011450059612148573, 0.11542890327317373, 0.04430263363091009, 0.03376150729932955, 0.028627752060336725, 0.025748632981308868, 0.032248411527169604, 0.020980506337114742, 0.021100805506908467, 0.11647266655095986, 0.02804615594712751, 0.04411355645528861, 0.053563707042485476, 0.02612260077148676, 0.06260463994528566, 0.7105478122830391, 6.92158134494509, 22.547474179949077, 42.85107626233782, 37.71004506519863, 31.03292349406651, 39.53962387357439, 20.85047742298671, 22.8748767716544, 18.84297435624259, 22.095177718571254, 17.88123423712594, 10.38820481300354, 4.419225403240748, 0.9929678205932889, 0.28499974416834967, 0.19338121823966503, 0.11799588267292295, 0.5342373816030366, 0.9527058324643544, 2.98860325557845, 7.118626177310944, 4.503031969070435, 4.794410756656101, 5.1536851695605685, 4.732455841132572, 5.9257915786334445, 6.612047782966068, 5.508269114153726, 6.758819358689444, 5.307156111512866, 6.665822063173566, 4.261104813643864, 4.036149067538125, 5.107341987746103, 8.569348812103271, 16.595409291131155, 24.145070007869176, 35.98537710734776, 41.26240886960711, 55.17193814686367, 58.14724016189575, 56.957795415605815, 54.25240659713745, 59.53099128178188, 52.39085565294538, 52.031873498644146, 36.370543548039024, 43.313242639814106, 60.91483620234898, 54.649569102696006, 49.75341674259731, 49.32676608221871, 52.14874914714268, 48.638619967869346, 44.0345664024353, 37.93562180655343, 29.83433144433158, 23.383252143859863, 16.81470833505903, 10.636255502700806, 4.052360951900482, 3.0289486220904758, 4.011575894696372, 5.31744031395231, 4.6308236718177795, 8.820772852216448, 9.73891910484859, 6.926087685993739, 7.516544733728681, 5.549196175166538, 7.324429648263114, 3.415989339351654, 2.539231551545007, 1.9154483377933502, 0.6200213070426668, 0.6804712318948337, 0.05846981717539685, 0.3892345024006707, 1.0709977192538125, 5.719007977417537, 8.932375686509268, 25.00640865734645, 37.775358131953645, 33.67326675142561, 21.861891950879777, 21.64736979348319, 33.276350906917024, 30.96574831008911, 18.619739157812937, 2.6275857133524756, 0.24683304503560066, 0.043475716574383635, 0.04532422238428678, 0.019076952677486197, 0.03458168650312083, 0.007741323755388814, 0.029949470423161983, 0.04051562791158046, 0.023668229347094893, 0.044429221123989136, 0.04217694287321397, 0.05895921055759702, 0.0643046483663576, 0.02708881937100419, 0.1007360281156642, 0.012139853223093917, 0.057613804537270746, 0.05594687130568283, 0.02492823325363653, 0.015075511232550656, 0.02604898141830095, 0.06300146758024182, 0.07957706706864492, 0.02695583668537438, 0.02074411491464291, 0.042156495220427, 0.044579536986670325, 0.02025547979532608, 0.005305370315909386, 0.023031948400395255, 0.040983715294195075, 0.025163196359894106, 0.03266673854419163, 0.05675195989065936, 0.03066578966432384, 0.0538600436411798, 0.036363159838531695, 0.004764356109912374, 0.026671167496325712, 0.035033933485725095, 0.1335657507713352, 0.17570605953889235, 0.14652112844799245, 0.19671298802963325, 0.19447725585528783, 0.17057459774826253, 0.09411708864250354, 0.16071841519858154, 0.20253465564123221, 0.09325811080634594, 0.1042240916618279, 0.1517224114920412, 0.16082414452518734, 0.14333873135702951, 0.07723864540457726, 0.12384204539869513, 0.17893972673586436, 0.15397921896406583, 0.07635150836514575, 0.10479245294949838, 0.05380839016288519, 0.1736919233309371, 0.12977309285530023, 0.2584346910672528, 0.12977801901953562, 0.24055173780236924, 0.13492989114352635, 0.07977433755461659, 0.048340738019240756, 0.20447720640472003, 0.10877462569624186, 0.23595640010067395, 0.18703170466635907, 0.07542435811566454, 0.09057628256934029, 0.19672085903584957, 0.13317587812032017, 0.11336408049932548, 0.11484051841710295, 0.22281946002372674, 0.18836702087095805, 0.12847278905766352, 0.13977678891803536, 0.07267604023218155, 0.12208644460354533, 1.060767582484654, 8.51798859664372, 26.758061681474956, 48.45813356127058, 43.53809676851545, 40.042895793914795, 45.87269844327654, 29.276193073817662, 30.38227333341326, 22.95226580756051, 23.55376614843096, 20.606930903026036, 10.815512946673802, 5.0605814797537665, 2.190345346927643, 0.8086099645921162, 0.6596245733754975, 1.3452819841248649, 2.924321779182979, 5.273690112999507, 8.554785387856619, 14.557024955749512, 13.290655834334236, 12.703672885894775, 11.419842072895594, 9.340360879898071, 11.07934125832149, 10.089393189975194, 10.505414843559265, 12.51136064529419, 11.007903354508535, 10.360977428300039, 4.767439152513232, 3.7525674615587508, 4.87422775370734, 9.69396686553955, 16.52957684653146, 26.136371612548828, 37.263265473502024, 45.665207862854004, 57.359859875270296, 60.871493339538574, 59.63093417031424, 58.336033139910015, 58.9599883215768, 52.49182687486921, 51.056547914232524, 42.677545002528596, 46.338283334459575, 61.051083428519114, 56.312880992889404, 54.030679157802034, 50.79480579921177, 53.48676027570452, 50.815587861197336, 43.406067098890034, 36.870299679892405, 30.848063196454728, 23.687532867704117, 15.469776800700597, 9.220203944614955, 8.716248495238167, 4.254340742315565, 7.556106907980783, 12.44772469997406, 7.0984746643475125, 11.263031652995519, 16.647449561527797, 13.471247332436697, 14.665510654449463, 11.6716091803142, 15.431665931429182, 11.891978246825081, 7.843346306255885, 6.647213918822152, 5.108918360301426, 1.23659239922251, 0.6643737756780216, 0.590381703206471, 1.125160338623183, 5.749537927763803, 9.999578169413976, 26.68588032041277, 46.66338259833199, 42.211029052734375, 21.442681074142456, 27.260713475091116, 41.29087911333357, 35.67599466868809, 20.637270212173462, 3.5068978326661244, 0.37250978127121925, 0.17929325705128057, 0.14755792995648725, 0.07116843041564737, 0.09591754738773618, 0.09065236670098134, 0.07814104948192835, 0.17773299291729927, 0.11139446297394377, 0.12045160947101456, 0.15725916224930966, 0.17522898156728062, 0.12994839916271822, 0.10867433822048561, 0.17762456302131924, 0.0664329616619008, 0.11329728551208973, 0.10334830651325838, 0.07681878829108817, 0.09485070713396583, 0.11338638394538846, 0.20410564062850817, 0.15523577082370008, 0.11193923159901585, 0.17565174959599972, 0.17546220762389048, 0.19557876246316092, 0.06534328870475292, 0.12184601250503745, 0.17786825208791665, 0.13200957141816616, 0.16558010503649712, 0.11007268354296684, 0.1815274828778846, 0.14559794084302016, 0.1498706487140485, 0.10933219827711582, 0.15338052037571157, 0.09181846305727959, 0.08682995502437864], [0.01703292191294687, 0.034498840770018954, 0.06195724289864302, 0.017903421273721114, 0.05962369990135942, 0.01398425644064056, 0.030077065540743724, 0.03629141154565981, 0.036020981413977485, 0.022580593691340516, 0.040040829817631414, 0.04940258086259876, 0.05296641302161983, 0.016917036613449454, 0.020916064170056155, 0.05296420439013413, 0.056743057511214695, 0.039106259787721295, 0.07499732210167817, 0.04870740816529308, 0.017533344881875173, 0.0239374907022076, 0.032116144695984464, 0.07497563612248216, 0.025700385748807873, 0.055691653929118595, 0.05714365440819945, 0.07274867062057767, 0.03290372368480478, 0.024566321334402477, 0.0149954899014639, 0.0061821529109563145, 0.020736388097118055, 0.04094944249040314, 0.018803542080734457, 0.07416238476123128, 0.029994555682476078, 0.02483217474738402, 0.02855068744559373, 0.06342943997255393, 0.042882941596742184, 0.037258843026523075, 0.06611310025410992, 0.018156336720234582, 0.053049204471920214, 0.015429684459897024, 0.6047620315636907, 6.626493522099086, 23.861411537442887, 36.853318282536094, 39.758287157331196, 31.272813524518693, 22.989706175667898, 21.2334360735757, 22.487191608973912, 16.239937714168004, 13.941193955285208, 16.005460330418178, 11.37319621018001, 6.237953296729496, 2.1525041546140398, 0.7524262879576001, 0.014994562004825898, 0.3209492622741631, 0.22075667285493442, 3.1505483942372456, 9.097424064363752, 2.364307395049504, 2.827798707144601, 2.13548258798463, 2.9630948986325945, 3.8314091052327837, 6.101948823247637, 3.43155460698264, 4.708148871149335, 3.0502068528107236, 4.901744791439601, 2.8794023266860416, 2.301663956471852, 1.5575799580131258, 1.605607535157885, 4.953166672161647, 9.018494265420095, 18.25684690475464, 29.254386152539933, 44.08551754270281, 49.50085667201451, 55.436077390398296, 49.6191462789263, 58.928811754499165, 49.75842291968209, 54.426014287131174, 27.529530593327113, 31.848756653921946, 50.37981769016811, 46.56796646118164, 53.81574010848999, 41.75979913984026, 43.7468067577907, 41.008462633405415, 30.73311914716448, 22.636055026735576, 17.30264731815883, 9.52033485685076, 6.406616474900927, 2.9874300956726074, 1.4553462266921997, 1.320051229425839, 3.1184016849313463, 4.101887711456843, 4.285160779953003, 5.403279662132263, 5.576132604054042, 4.465663254261017, 6.504208700997489, 5.6000513434410095, 3.5741635603564124, 1.9374545855181557, 3.169003678219659, 1.1953934899398257, 0.4631941680397306, 0.22256290593317576, 0.5250713505915233, 0.8148424444454057, 4.66295952456338, 5.0531608036586215, 16.28749987057277, 41.07095125743321, 16.191401072910853, 7.15607305935451, 16.127944912229264, 30.157297611236572, 29.91958236694336, 17.560951811926707, 4.2784557683127264, 0.21465998142957687, 0.009281466781560863, 0.06122034029769046, 0.09656466623502118, 0.021157726113285338, 0.04152003276560988, 0.04780731110700539, 0.0398962000784065, 0.01724455868160086, 0.02104449558204838, 0.04504549716200147, 0.03232796975810613, 0.03440281788685492, 0.024894800136930177, 0.05230737231405718, 0.04435686554227557, 0.04269342337335859, 0.0780073848686048, 0.0455633788369596, 0.03547415682779891, 0.08232888619282416, 0.017028089047276547, 0.03744650545663067, 0.05457184383911746, 0.03849914397246071, 0.06608783161001545, 0.026621000009721944, 0.014787283127329178, 0.03127913782373071, 0.0419352012021201, 0.017930747575259635, 0.0029439600974520935, 0.05870908897902284, 0.012986601313709148, 0.07224591688386031, 0.055765139271638224, 0.05562847553353224, 0.05747530196926423, 0.07761131040751934, 0.03675689335380282, 0.01926999249761658, 0.07830896654299327, 0.020298726224739636, 0.10111495599682842, 0.015670544035466652, 0.02926187017666442, 0.028891803962843757, 0.012616021957780634, 0.05327754846907087, 0.037332531929548295, 0.034688837360590696, 0.026599258051386902, 0.0259844459526773, 0.05045048998934882, 0.020519965960245048, 0.03142439181517277, 0.0081620451528579, 0.047195116457130225, 0.04853309591167739, 0.0156803844895746, 0.009930836668770229, 0.06706657087696449, 0.08357433043420315, 0.045464818232825825, 0.03966633955548916, 0.009448734145345432, 0.01750806436341788, 0.07351906571005072, 0.05264769833801048, 0.019938252799745117, 0.022367404773831367, 0.02133867613572095, 0.025935150383572494, 0.0772425876930356, 0.04795984917187265, 0.04728647780471614, 0.05010469497314521, 0.012134849027331387, 0.04555441538936325, 0.05190115036176784, 0.04657375479915312, 0.04726474093539374, 0.0432598576215761, 0.05989902905587639, 0.0896161962300539, 0.03173617526356663, 0.027167595590331724, 0.8345327164445604, 8.635912554604666, 29.546477999005997, 40.591355323791504, 41.61850752149309, 33.99912336894444, 24.512808629444667, 20.050909996032715, 19.624926362718853, 19.30986898286002, 19.41954629761832, 17.915419374193462, 12.253318446023123, 7.502984455653599, 2.080495195729392, 0.3557158224284649, 0.12890892422624997, 0.13278205639549664, 0.3106375113129616, 1.7506455353328159, 2.737339892557689, 1.0834019907883234, 3.243322478873389, 2.7374182769230435, 4.5838581919670105, 4.704662612506321, 5.773992112704685, 7.481964417866298, 5.643326895577567, 7.174203080790384, 4.908195759568896, 7.722826327596392, 4.669995878423963, 2.3743694722652435, 2.7932546521936144, 7.361687626157488, 12.060242772102356, 22.48606947490147, 33.44660609109061, 47.352918352399556, 52.47770118713379, 58.081315653664724, 52.02674225398472, 59.79980318886893, 49.53768212454659, 57.66507339477539, 29.705456256866455, 35.92912449155535, 58.039049761635916, 47.71528080531529, 54.940132345472065, 45.81745679037911, 46.7860426221575, 43.420335224696565, 33.241717611040386, 26.69678204400199, 19.29690190723964, 11.868471622467041, 7.447190420968192, 4.8593946525028775, 2.011337820972715, 3.032632904393332, 4.80989351442882, 3.7499849029949734, 6.512476188795907, 7.091558166912623, 11.549150654247828, 6.795339959008353, 8.581183331353323, 5.9261029447828015, 5.0423077174595425, 2.7389738048825945, 2.652225762605667, 1.267387249640056, 0.5145376101136208, 0.15646001084574632, 0.3356138968041965, 1.1144588100058692, 3.813724637031555, 8.466303552900042, 13.283584305218287, 34.9675806590489, 28.018629925591604, 14.634872572762625, 18.29323983192444, 31.229415076119558, 33.987801279340474, 20.46928882598877, 5.99188631772995, 0.33691521840436117, 0.042119823795344145, 0.03026536918644394, 0.055668532848358154, 0.048902615904808044, 0.025562800899414078, 0.02974639507010579, 0.019386714091524482, 0.03294961979346616, 0.06017768981733492, 0.005403950003840561, 0.007411024782673589, 0.04098991031891533, 0.009111773655084627, 0.02716132762309696, 0.053857285396328995, 0.020032475868772184, 0.0425726305693388, 0.023542054064039673, 0.02201671921648085, 0.06693958983357463, 0.016614240361377597, 0.047949498120163164, 0.016748485122142092, 0.005674407276923635, 0.052996716395552666, 0.06077428494713136, 0.029221829825213978, 0.01620279029676957, 0.03189918312377163, 0.06751014278935534, 0.03954736522531935, 0.03405710090217846, 0.0347061535742666, 0.06056360660919121, 0.00457226242204862, 0.03491072170436382, 0.029832535090723207, 0.0646329236083797, 0.013394039540019418, 0.014065197186677583, 0.19452045139457497, 0.1074743422546557, 0.15209959553820745, 0.07877004465886525, 0.14319162496498652, 0.10194901124175106, 0.12898156818534645, 0.142551291467888, 0.15809612162411213, 0.09253323863127402, 0.18972966846610817, 0.17137317918241024, 0.2068632747977972, 0.0870345536885517, 0.14199075368898256, 0.1264617605400937, 0.1484835467168263, 0.10556370299309492, 0.1656621399202517, 0.12368058120565754, 0.12184147989111287, 0.22762328439525195, 0.15368898239518913, 0.13071339311344282, 0.11824113237006323, 0.19256734262619699, 0.18058126579437936, 0.21143319457769394, 0.10923980894897665, 0.1983619231198515, 0.15311647525855474, 0.1042029077985457, 0.13721930900854723, 0.1931071715163333, 0.1385916189423629, 0.25618021775569233, 0.20956769825092383, 0.1469439236181123, 0.13180344605020114, 0.14030263998678752, 0.11287300435027905, 0.10330688873572008, 0.2172197819288288, 0.19474752992391586, 0.13535698822566442, 0.2632866235716002, 1.1897595865385873, 11.332225288663592, 34.547350134168354, 46.86164597102574, 49.068588393075125, 42.69008650098528, 32.728252683367046, 29.977460861206055, 32.627024378095356, 24.867997067315237, 22.120726244790212, 22.488270316805156, 14.843655518123082, 8.211171780313764, 2.8805324946131026, 1.0485248565673828, 0.22889304054634912, 1.0057797559670039, 0.49043436348438263, 6.140057521206992, 14.214343275342669, 7.320391876356942, 9.182174716676984, 6.477876331124987, 9.387772781508309, 9.990534220423017, 12.745970913342067, 11.034402915409633, 11.113545502935137, 9.16693992274148, 12.849476490701948, 8.493860108511788, 4.50368162563869, 2.8208461659295216, 2.847651013306209, 7.626187307494027, 11.856099486351013, 24.392988681793213, 35.08469602039882, 47.88490717751639, 54.32403557641165, 61.215512548174175, 54.82359715870449, 60.991391454424175, 51.581425258091514, 55.240134716033936, 37.98077467509678, 42.42248705455235, 58.61832455226353, 50.94199643816267, 56.049169063568115, 49.230470997946604, 49.247417654309956, 44.9106890814645, 33.48523460115705, 25.721722228186472, 18.930975028446742, 10.881188188280378, 8.196716053145272, 5.143536022731236, 4.315309013639178, 4.150675790650504, 8.303368295942034, 9.074217081069946, 9.297572135925293, 12.142544184412275, 15.999170473643712, 9.756701282092504, 13.288442833083016, 12.971686618668691, 10.325298428535461, 7.033343553543091, 6.693311742373875, 2.8812644439084187, 2.19622916834695, 0.777794106730393, 0.685078538954258, 1.3207964237247194, 5.499992506844657, 7.90552920954568, 20.87147487912859, 46.1014609336853, 24.01971755708967, 14.82738631112235, 23.7691707270486, 41.587671416146414, 40.140198366982595, 25.61584210395813, 6.851432331970759, 0.6315094477363995, 0.13537487440875598, 0.09150740903403078, 0.15112470356481417, 0.12251616083085537, 0.13235817556934698, 0.17030265448348864, 0.1514307228582246, 0.08413271725709949, 0.1790792335356985, 0.13229090560759815, 0.17234143508332117, 0.16409191489219666, 0.11104371465210404, 0.13594022978629383, 0.15430191664823464, 0.09558949606227023, 0.10843672204230513, 0.10642357649547712, 0.10828171750264508, 0.16257403205548013, 0.10457549137728554, 0.1278145829481738, 0.14924870351595537, 0.09571484862161533, 0.14644950229142392, 0.17851337604224682, 0.16611154723380292, 0.06669477439884629, 0.06438628291445118, 0.1723786595144442, 0.08965815005025693, 0.15336192851620062, 0.11618622977818761, 0.15939319559506007, 0.14885299546378, 0.18215469350772245, 0.2373221553862095, 0.1935944410839251, 0.13306146354547568, 0.14001711245094026], [0.03241966698052628, 0.025139540932806473, 0.06184423967663731, 0.049051493273249695, 0.0309731524570712, 0.033152532298117876, 0.02844495472631284, 0.06554964477462427, 0.03131049631961754, 0.01301724904416395, 0.03524293923484428, 0.040930653855736764, 0.013877651803860707, 0.02583630818740598, 0.024576567213184068, 0.07564249355345964, 0.022167009634098837, 0.06432569652263607, 0.009134872683456965, 0.03956781287810632, 0.01880397125413375, 0.02503499564980822, 0.0830990777217916, 0.04616091713043196, 0.01942186220549047, 0.038335505074688365, 0.03234107226931623, 0.04641970020851918, 0.025960571698046157, 0.04500930071143167, 0.058276896098894734, 0.030616280356688157, 0.008921839829002107, 0.0180721118647073, 0.0898616359169994, 0.02216267549166722, 0.04406487835305078, 0.061063055880367756, 0.07832547529999699, 0.09972936713269778, 0.08091378105538231, 0.054876869078725576, 0.025049346665452634, 0.004223665480302381, 0.05419702109481607, 0.012936795147002807, 0.0016698532646322356, 0.8387025041239602, 8.539411629949297, 23.451471294675553, 36.12775959287371, 39.53475318636213, 29.038489988871984, 24.980062825339182, 16.53263579096113, 19.18219062260219, 13.709991778646197, 15.913391487939016, 17.83877205848694, 8.484624215534755, 6.268154076167515, 2.4658611799989427, 1.0480854915721076, 0.2134847180651767, 0.41299785726836746, 0.7017809227108955, 3.1597640940121243, 0.44734567989196095, 1.646614283323288, 2.7722400426864624, 3.8571895275797163, 3.6234221628734042, 4.698893436363765, 7.5511102846690585, 6.285292676516941, 6.496284714766911, 6.2541868942124506, 5.708091054643903, 3.345816441944667, 0.7025136319654328, 0.5185856414692742, 1.2613254891974586, 3.21621082510267, 7.532133017267499, 17.42078753880092, 37.35002415520804, 50.586533546447754, 53.42577593667166, 55.57416936329433, 49.49157040459769, 52.19013261795044, 40.69328539712088, 16.51697976248605, 30.139538015638077, 40.92317696980068, 52.65283400671822, 47.48481600625174, 43.941457067217144, 34.8377639906747, 33.54332848957607, 26.708887542997086, 20.197893926075526, 8.962675043514796, 6.178785911628178, 1.5226267193044936, 2.9655469613415852, 1.5245779688869203, 2.8469609703336443, 4.420126932007926, 3.513392661299024, 4.453903428145817, 8.782981600080218, 10.322189978190831, 7.610461797033038, 6.596164200987134, 3.1803635486534665, 4.76760938337871, 2.0380964194025313, 1.0380069123847144, 0.5809106571333749, 0.08154637246791806, 0.22743584588170052, 1.1962460556200571, 3.703715111528124, 7.99650023664747, 12.870641572134835, 41.135246413094656, 18.23757086481367, 6.763863750866481, 18.71723801749093, 27.520464931215557, 32.432992458343506, 21.593854767935618, 6.526678306715829, 0.6517314197761672, 0.09729378603930984, 0.033735309062259536, 0.053130136736269505, 0.02797225839458406, 0.012770783073002738, 0.022399575815403035, 0.013839303549113018, 0.03546798215912921, 0.05658129137009382, 0.013091750492874001, 0.09617891229156937, 0.04322960853044476, 0.04870312321665032, 0.017690870179129497, 0.019215338198201995, 0.06464988698384591, 0.013633124746515282, 0.02005335608763354, 0.02478364422651274, 0.05156974368063467, 0.07929660818938698, 0.003266072121082938, 0.04039900131257517, 0.07303643732198647, 0.021961145502116, 0.0629662855395249, 0.019566936385152594, 0.05631926489461746, 0.07273522884185825, 0.02319138207738953, 0.028802362869360616, 0.01307619592574026, 0.057785555321191034, 0.10606700634317738, 0.02314302119027291, 0.10356742582683053, 0.05988183497850384, 0.023341842128762176, 0.014958083962223359, 0.045433720972921164, 0.040106308446930986, 0.007177339866757393, 0.02606042830406555, 0.03348967938550881, 0.03004264345924769, 0.06118105312011071, 0.0132313658583111, 0.08019991471831288, 0.03630304502855454, 0.016287390042894652, 0.02041893718498094, 0.031986971984484365, 0.0965516994308148, 0.09186660511685268, 0.014370319965694631, 0.03540364346866097, 0.038996815481888394, 0.014807973356385316, 0.06087979714253119, 0.027474369753950408, 0.014916155587083526, 0.040110566254173, 0.06692366461668696, 0.059958970839423795, 0.022045539991397942, 0.08949865360877343, 0.06433916544275624, 0.019741265602143745, 0.029157199364687716, 0.07957407472921268, 0.0697448503758226, 0.07962824896510158, 0.030145207419991493, 0.04163949564099312, 0.017805858116064752, 0.02144664802056338, 0.05942106220339026, 0.07363129540213517, 0.03251356944175703, 0.020880517416766713, 0.028078415198251605, 0.03291062777861953, 0.03616505475448711, 0.040508764529866834, 0.05967168589787824, 0.044732282004718266, 0.016067103649090444, 0.043972750260893784, 1.4800079890659876, 11.19422537939889, 28.540886061532156, 40.77312019893101, 43.127656255449565, 32.62590224402291, 25.603323187146867, 17.384861877986364, 17.975001914160593, 19.395703554153442, 22.09408164024353, 18.667353425707134, 11.57968885557992, 7.411862305232456, 2.5498809686728885, 0.9840384083134788, 0.2443175528730665, 0.4815720447472164, 0.20856989893530095, 0.676070688026292, 0.9251063934394291, 2.4289649426937103, 2.136840743677957, 2.4178754006113325, 4.361508020332881, 3.9164915340287343, 3.532719509942191, 4.064139017036982, 5.590123670441764, 5.870815260069711, 8.53897476196289, 5.919952051980155, 3.91438319001879, 1.9454100557735987, 3.0948362180164883, 5.530851628099169, 8.180365204811096, 21.77501688684736, 40.414287430899485, 52.674703461783274, 56.3679906300136, 56.74289458138602, 52.701433181762695, 52.445798533303396, 47.929504190172466, 19.862627710614884, 34.44873087746756, 46.66625220435006, 53.30243498938424, 51.40348884037563, 44.94795227050781, 38.4311569077628, 34.66205447060721, 29.67787538255964, 19.459769419261388, 10.864109516143799, 5.937478882925851, 3.7812261751719882, 2.9011113217898776, 3.0296149977615903, 4.89388290473393, 4.531804893698011, 5.435811996459961, 6.426206486565726, 8.430076513971601, 8.358590841293335, 6.137347723756518, 8.458181977272034, 5.871378064155579, 2.444618799856731, 1.7010161812816347, 0.4590146094560623, 0.2798861957022122, 0.18064464096512112, 0.3781237086015088, 1.1859348203454698, 3.030196692262377, 10.37110355922154, 10.526641590254647, 33.72713960920061, 29.397480828421457, 7.8928678546633035, 18.97149692262922, 28.966722045625957, 35.3684743472508, 25.65386959484645, 9.136787346431188, 0.9726056903600693, 0.052662168097283156, 0.026213471877521703, 0.03722337260842323, 0.039266261737793684, 0.09862237796187401, 0.006284950118112777, 0.009189504930483443, 0.030841981459941183, 0.010316455753387084, 0.07311509988669838, 0.08322578056582383, 0.0632500828110746, 0.018953493230843117, 0.013667766503723604, 0.07587360936616148, 0.06225931990359511, 0.006236492963840387, 0.0367121202205973, 0.08559295175863163, 0.037539403686033826, 0.07280874811112881, 0.04286652444196599, 0.05943364902798619, 0.029456630083067075, 0.020860595628619194, 0.0032973345618561973, 0.05376689435381975, 0.06705931055226497, 0.005965212967047202, 0.050435385799833705, 0.03335798930908952, 0.06971853678779942, 0.018011520383879542, 0.03987823586378779, 0.02576105186848768, 0.0796724690922669, 0.04803514281021697, 0.04653413174673915, 0.03290334031251924, 0.02314550632477871, 0.05154726042279175, 0.13319798479122774, 0.13013731688261032, 0.15983953593032701, 0.12353872667465891, 0.15033536377762044, 0.13024652030851158, 0.17263914910810335, 0.17338439768978528, 0.17962085375828402, 0.2527495989842074, 0.16465018636413983, 0.18386435748210975, 0.17506732738443784, 0.10025402397981711, 0.14404049941471644, 0.13656863463776453, 0.08127212896943092, 0.2043267209082842, 0.20333026509199822, 0.16487237944134644, 0.19073133543133736, 0.10364032084388392, 0.2566682201411043, 0.23828355808343205, 0.1402716716485364, 0.10545972428683724, 0.1036104110202619, 0.17542806374175207, 0.194892749988607, 0.13830814058227198, 0.14081424182014807, 0.10959914752415248, 0.16088832036725112, 0.20122022474450724, 0.2059323111815112, 0.22495106421411037, 0.11884641274809837, 0.11186659442526953, 0.17583918810955115, 0.2250860926828214, 0.19384487478860787, 0.19564706379813807, 0.13869673758745193, 0.14173289681119577, 0.108453454715865, 0.06819201620029551, 0.13674406308148587, 1.8721063435077667, 13.699374931199209, 31.750505651746476, 47.85596098218645, 50.469560623168945, 40.31271518979754, 33.802423340933665, 24.63698509761265, 27.325394255774363, 23.44344786235264, 23.804075002670288, 22.509083645684377, 12.882535151072911, 8.794886469841003, 3.3583601117134094, 1.659908032843045, 0.7320856537137712, 1.3440973162651062, 2.797499133007867, 7.062076526028769, 2.7650319380419592, 5.524142273834773, 7.974206072943551, 7.98069395337786, 7.142307375158582, 11.317444733210973, 15.994136503764562, 15.183835847037178, 14.186011127063207, 11.502694998468671, 11.006483316421509, 7.911719185965402, 3.5442524339471544, 1.2545672804117203, 2.238477472748075, 4.411056927272251, 9.432412351880755, 22.064699445452007, 43.3064820425851, 53.70946741104126, 57.559439931597026, 59.852248191833496, 55.57568407058716, 51.44215556553432, 47.44296700613839, 26.583832127707346, 40.93785503932408, 50.90559829984392, 55.856228010995046, 54.94511072976248, 49.697278772081646, 39.75693573270525, 35.74267653056553, 29.105190958295548, 21.82989375931876, 11.393915738378253, 7.962791051183428, 3.2789756400244574, 5.456465951034001, 3.3216180375644138, 7.798813564436776, 9.995397090911865, 10.922519547598702, 12.204629812921796, 16.12448123523167, 19.413381508418492, 16.531826325825282, 14.824542760848999, 6.363158532551356, 8.771541391100202, 3.793740315096719, 2.6626641282013486, 1.6504776988710677, 0.3897990435361862, 0.6443867938859122, 1.8845701089927127, 4.789637344224112, 11.180765850203377, 16.974839993885585, 47.03181430271694, 25.991317544664653, 12.913980960845947, 27.728843144008092, 38.51295804977417, 40.75459977558681, 32.107778549194336, 10.855941040175301, 1.3060055545398166, 0.16290370507964066, 0.17640507274440356, 0.16061328298279218, 0.20236739675913537, 0.1742355248757771, 0.08372915176940815, 0.1320746157850538, 0.10858872745718275, 0.09388124344072171, 0.10794777649321727, 0.259657546877861, 0.15035785042813846, 0.1422342120536736, 0.1739089052592005, 0.1942983940243721, 0.19363205906535896, 0.09805514982768468, 0.1264681794813701, 0.19030260986515454, 0.14314928437982286, 0.23447437105434282, 0.2056066415139607, 0.13218558340200356, 0.16917578423661844, 0.06991098288978849, 0.14405174952532562, 0.11874756376658167, 0.15100372077098914, 0.15174100335155213, 0.14483963724757942, 0.12321920453437737, 0.12513660879007407, 0.1786477259759392, 0.1730688110526119, 0.06883570166038615, 0.16906223818659782, 0.09511596004345588, 0.18273869502757276, 0.0917017821754728, 0.09468342111046825, 0.1347468766782965], [0.06418063252099923, 0.019843926254127706, 0.037030068159635575, 0.03903474219675575, 0.05150513357615896, 0.08971150325877325, 0.05849454977682658, 0.05733536769236837, 0.062163395408008776, 0.011550504847296646, 0.03623083872454507, 0.028661593994391815, 0.03425817796960473, 0.09707676339894533, 0.06193048826285771, 0.01960598098646317, 0.04879883397370577, 0.047230977032865794, 0.033942550620330234, 0.05823777176971946, 0.03389296328116741, 0.07685038088155643, 0.03176107410607593, 0.06324033226285662, 0.02143966080620885, 0.045690597367605994, 0.023747641693002412, 0.04500112436445696, 0.10819471574255399, 0.033398328215948174, 0.017723192194742814, 0.03346076361568911, 0.041717181115278175, 0.047620588447898626, 0.07532636408827134, 0.07236519655478851, 0.057225132893238745, 0.09810388221272401, 0.02711290566782866, 0.024141575376104032, 0.06994670775852033, 0.033161543243165524, 0.05052816189293351, 0.07067573256790638, 0.016458219715527127, 0.07855819245534283, 0.025218776859609143, 0.08916191024971859, 1.1069276141268867, 10.646704724856786, 22.97440103122166, 34.09087085723877, 39.03459753308977, 32.52112340927124, 25.315143176487513, 20.382000344140188, 12.810704674039568, 18.035479034696305, 36.54227869851248, 27.890614577702113, 16.68597732271467, 9.918162652424403, 3.8274534089224677, 1.4836159497499466, 0.45295325613447596, 0.7106915531413895, 0.13124989718198776, 0.2606909285698618, 1.6150367834738322, 0.9014823010989598, 0.956255493419511, 4.405401527881622, 2.3484583369323184, 2.398726816688265, 2.1068614380700246, 4.687396773270198, 1.711180093032973, 12.116174902234759, 5.699380619185312, 3.282231956720352, 1.3552224678652627, 1.4752141663006373, 1.8343665514673506, 1.5467063529150826, 8.893882666315351, 24.36094880104065, 39.65681219100952, 46.368983949933735, 49.25323677062988, 45.83373989377703, 45.13805845805577, 24.105268989290508, 21.617836475372314, 28.308090141841344, 32.109647614615305, 37.391369410923545, 34.175006593976704, 36.265823772975374, 29.28393336704799, 23.17627399308341, 21.430391447884695, 13.246470502444676, 3.5306498152869086, 0.7823318232383046, 3.3362898102828433, 2.9254625865391324, 2.2395590032849992, 4.105951973370143, 3.397125631570816, 4.9577859214374, 5.347619814532144, 4.786828100681305, 6.958739876747131, 3.7895192844527106, 8.674419471195765, 8.434963703155518, 1.5559616791350501, 1.691428318619728, 0.749147498181888, 0.6655455242310251, 0.4629431643656322, 2.0728506573608945, 4.854690722056797, 11.932304722922188, 9.225032074110848, 31.76248434611729, 29.942848409925187, 4.27079668215343, 21.637583255767822, 20.828053849084036, 34.327790532793315, 27.369713340486797, 9.282841954912458, 1.3811689955847604, 0.006266732725115227, 0.034356402698904276, 0.02722324733622372, 0.06768785111073937, 0.01913726595895631, 0.038941270605261834, 0.08713533649487154, 0.04640843313453453, 0.07441937989954438, 0.07932541878627879, 0.054290723388216326, 0.009432463723767017, 0.04036593630111643, 0.05088523416114705, 0.028927569543676715, 0.04708526503028614, 0.012466650955112917, 0.027976105688139796, 0.0699243296736053, 0.05315282355461802, 0.012009213179615992, 0.026910938023190414, 0.028384707602007047, 0.03060599376580545, 0.02011327921146793, 0.024813179159536958, 0.04790464695543051, 0.013029723062313028, 0.07740119525364467, 0.01722331714284207, 0.02451131589311574, 0.03707170306837984, 0.03462837649775403, 0.018606984056532383, 0.04553729255816766, 0.033494052543703995, 0.05261014142472829, 0.02744119448055114, 0.04588114017886775, 0.05861564792160477, 0.015962702554783652, 0.03252376443041222, 0.048360731053565226, 0.08219858032784291, 0.01624224371542888, 0.026362678335447396, 0.019274604839405844, 0.1370160063462598, 0.030376201096389974, 0.0285696287506393, 0.0066658924001136, 0.07965810450592212, 0.029813023816261972, 0.02252469088749162, 0.08686975110322237, 0.04101611873401063, 0.022335693439734832, 0.05108078116817134, 0.011596743616142442, 0.0797091167686241, 0.018911746363820772, 0.011452400557962912, 0.01618481081511293, 0.006309248457130576, 0.01489412525136556, 0.059986641497484276, 0.07505459045725209, 0.05210242420434952, 0.038043738409344635, 0.0462206892802247, 0.07081373301999909, 0.024596926656418612, 0.042159110972923894, 0.02075826745879437, 0.02267958516521113, 0.07823810034564563, 0.12496397591062955, 0.020182808694828833, 0.03433601611426898, 0.02107567256981773, 0.0037012791809892015, 0.04461920414386051, 0.05103567216013159, 0.03376687111865197, 0.06726561912468501, 0.015416268126240798, 0.032314093716974766, 0.029471184659217085, 0.01468695154679673, 0.11926299253744738, 1.7547774336167743, 13.422411918640137, 28.634841339928762, 40.02977759497506, 42.30025781903948, 35.10070466995239, 25.426204919815063, 18.84899844442095, 13.03311129978725, 16.35602821622576, 32.81672757012503, 28.01036330631801, 15.860401051385061, 8.837135859898158, 3.6947623576436723, 1.0220355008329665, 0.298342049654041, 0.163398126406329, 0.2387642865734441, 0.1734774112701416, 0.3975505461650235, 1.142768268074308, 1.177696862391063, 3.5701564039502824, 2.088411799498967, 4.670129631246839, 2.913621336221695, 5.9160875507763455, 5.419358662196568, 7.597375733511789, 5.996308411870684, 6.219088937555041, 4.082785376480647, 2.179595398051398, 1.9939221612044742, 2.8359515496662686, 11.402181489127022, 28.14575069291251, 43.48558575766427, 49.645268031529014, 51.8523667880467, 48.129317011152, 46.93006140845162, 27.442869186401367, 23.265954392296926, 33.31028938293457, 39.357327461242676, 43.96925333568028, 41.47806705747332, 41.99390826906477, 31.970607212611608, 26.660284893853323, 22.897552217755997, 14.264685579708644, 5.089592380183084, 2.047892293759755, 5.248512881142752, 4.484987931592124, 5.069758747305189, 6.042142638138362, 5.601956018379756, 7.3465666089739114, 5.121234042303903, 4.832210694040571, 6.925641264234271, 3.6436948350497653, 3.5262433545930043, 2.9608276145798818, 0.920725445662226, 0.8269287816115788, 0.2899631735469614, 0.3378666059247085, 0.43936673232487267, 2.1133308623518263, 5.459016374179295, 11.565581406865801, 12.852010846138, 27.260838542665752, 36.96602153778076, 9.206859929221016, 16.813577515738352, 23.38316181727818, 37.540818214416504, 32.321796962193076, 12.275150554520742, 1.73677693094526, 0.08013746235519648, 0.012745877445143248, 0.03607039911938565, 0.033922533837280104, 0.05514737045658486, 0.02983202618945922, 0.057495278040213246, 0.047219363906021626, 0.0488161366166813, 0.048941828443535736, 0.051506585641098876, 0.01769853592850268, 0.04975778376683593, 0.01991756765970162, 0.0470332247870309, 0.0452368067178343, 0.12907193547913007, 0.01255775785206684, 0.055354978423565626, 0.0478221676312387, 0.03189353771241648, 0.043764704638825994, 0.024021020059340766, 0.01801857545173594, 0.0490477240112211, 0.06492631536509309, 0.05695099117500441, 0.02146304481928902, 0.03714790255097406, 0.028649560175836086, 0.02352161828561553, 0.12782299678240502, 0.06070780887135437, 0.04087130239765559, 0.061949046195617745, 0.07944236429674284, 0.005710606696084142, 0.06752676011196204, 0.030780112636940818, 0.046951566490211656, 0.05905142346663134, 0.08544898019837481, 0.14675526374152728, 0.178721727005073, 0.17377794800060137, 0.1281981859356165, 0.092778040495302, 0.2408466019800731, 0.12175540093864713, 0.20721848788005964, 0.1879545258624213, 0.21124350332788058, 0.13704112571265015, 0.1940613274595567, 0.13721909187734127, 0.15623935125768185, 0.08359280015741076, 0.12843663671186992, 0.10550476544137512, 0.14429978121604237, 0.1124840070094381, 0.13378265127539635, 0.14806654623576573, 0.1848639752715826, 0.0699328181466886, 0.17083168109612806, 0.1406435766922576, 0.14559272969407694, 0.15892407005386694, 0.09037701040506363, 0.16258530930749007, 0.159736819299204, 0.08847810979932547, 0.10963918787560292, 0.13892209263784544, 0.1891899345708745, 0.33415260378803524, 0.21817891831908906, 0.09594662261328527, 0.1877595420394625, 0.13618294176246437, 0.1473708035690444, 0.25342143007687157, 0.11718379839190415, 0.1968818346836737, 0.22997174837759563, 0.09098533740533249, 0.19266605590070995, 0.13768858382744448, 0.1862144363777978, 2.0920428846563612, 14.881094149180822, 32.35615927832467, 45.72474002838135, 48.69272559029715, 43.00156382152012, 34.6780492237636, 29.397404398236954, 19.546972785677227, 25.805340324129375, 46.956245694841655, 33.39229202270508, 21.74604116167341, 12.833816119602748, 5.6013133100100925, 1.9992609832968031, 1.0352884296860014, 0.9844280502625874, 0.7250389861209052, 1.119255238345691, 5.860479814665658, 4.394492856093815, 6.3249998944146295, 12.352985143661499, 7.834542938641139, 9.11621720450265, 7.2554952672549655, 11.001351203237261, 8.544699209077017, 22.804734706878662, 12.890126058033534, 8.010140419006348, 4.795404349054609, 3.043161162308284, 3.4705463775566647, 2.3863201567104886, 11.76736056804657, 28.718098129544938, 45.44599914550781, 51.43798664637974, 52.58139610290527, 49.971298354012625, 48.66656562260219, 32.584848812648225, 32.68658086231777, 37.85548823220389, 42.04037087304251, 45.303644452776226, 46.785966191973, 45.37060076849801, 34.37015717370169, 29.220913205827983, 25.075313942773, 14.494525040899005, 4.790033391543797, 1.818337817277227, 5.282848707267216, 8.62319300855909, 7.043547851698739, 11.934989333152771, 9.941983682768685, 12.180053165980748, 12.43824301447187, 11.4052734375, 14.615766763687134, 10.834093298230853, 13.3887939282826, 14.351894157273428, 3.724943161010742, 3.1187332442828586, 1.734145300728934, 1.239653189267431, 0.8869266935757228, 2.794906803539821, 6.910922808306558, 15.106632675443377, 14.94345944268363, 38.3168625150408, 38.617990493774414, 10.5476598909923, 27.93111389023917, 30.35460560662406, 44.31679875510079, 36.18246970857893, 15.309224775859288, 2.461797352348055, 0.14641991816461086, 0.11551324517599174, 0.10800855966018778, 0.1203225249690669, 0.1251368530626808, 0.13846229016780853, 0.18505560713154928, 0.15484707882361753, 0.17229887736695154, 0.09834282831954104, 0.15750276989170484, 0.10852785608065979, 0.14958738748516354, 0.10920732747763395, 0.09466004557907581, 0.11781163327395916, 0.2647556247455733, 0.08880848171455519, 0.1513656106378351, 0.154431353988392, 0.10826766504240887, 0.18254210986196995, 0.13501754429723534, 0.11068453892533268, 0.07332503183611802, 0.09539740279849086, 0.17318418914718287, 0.06134670387421336, 0.10423781163990498, 0.15349113515445165, 0.14626006888491766, 0.1839124249028308, 0.17268599516579083, 0.08966728991695813, 0.17621201596089772, 0.1886986887880734, 0.11156712299478905, 0.2409232221543789, 0.09627920655267579, 0.13095596938260964, 0.14942362984376295, 0.11608852073550224], [0.013914987345093062, 0.03784176906836884, 0.03165954491123557, 0.0342796298542193, 0.04857381819082158, 0.07248852707977806, 0.040121612804276605, 0.03882645908743143, 0.041148806256907325, 0.02214056033907192, 0.08840085180210215, 0.0211714240389743, 0.030566516598420482, 0.02655198112396257, 0.03472491167485714, 0.060461812785693576, 0.050531880264835696, 0.03714384491156254, 0.01937518747789519, 0.058411646368248124, 0.10050581475453717, 0.02850989392027259, 0.07238893849509102, 0.08831950902406659, 0.056799036650253196, 0.08923325142157928, 0.014732287864067724, 0.06757679528423718, 0.04719170681866152, 0.02684697083064488, 0.0499697038238602, 0.026133777939581444, 0.012096605097342814, 0.07232358200209481, 0.06862021929451398, 0.05012493906542659, 0.041173718670117, 0.029694324292774712, 0.04036049445026687, 0.0737306804263166, 0.03366361505218914, 0.025776312121057084, 0.052736233587243726, 0.06417925509491137, 0.04185107643050807, 0.08754043547170502, 0.05373771056266768, 0.03364653632576976, 0.059525570166962485, 1.093899090375219, 8.904882533209664, 26.06194772039141, 34.13751758847918, 39.79547391619001, 34.92476238523211, 34.38333443232945, 31.889643328530447, 42.605891704559326, 28.29252096584865, 17.24002841540745, 18.878432750701904, 12.374707818031311, 9.08589960847582, 5.607483310358865, 2.4821746817656924, 0.6881537139415741, 0.22754427577768052, 0.38758913640465054, 0.21590680309704371, 0.6550761088728905, 0.4777776769229344, 1.3214618223054069, 1.8487795037882668, 2.224357864686421, 0.9454131552151271, 3.341088627065931, 5.1277028151920865, 4.714737066200801, 3.445580848625728, 7.676248209817069, 4.089556396007538, 2.911311060190201, 0.9796646258660725, 0.34986522208367077, 2.6349030349935805, 14.922517572130475, 26.349266154425486, 36.45569372177124, 42.637902055467876, 43.03506456102644, 24.845516170774186, 14.400914566857473, 17.12805645806449, 20.9516727243151, 18.349249260766165, 22.6251220362527, 15.43620136805943, 21.885126726967947, 16.84180804661342, 10.463524154254369, 16.329140424728394, 5.74856127159936, 1.7138200828007288, 0.47421086260250633, 3.54099286028317, 2.6744934363024573, 4.643326955182212, 3.973780299936022, 3.303722517830985, 4.742031327315739, 3.2147949125085558, 5.040788667542594, 3.9160759449005127, 2.2269797239984785, 2.8859286393438066, 3.3990346491336823, 0.9367057595934186, 0.5916270049554961, 0.032661364546843936, 0.8157535269856453, 1.1544943302869797, 4.483711200101035, 9.303329586982727, 21.861954484667095, 22.069750785827637, 38.952945777348106, 17.530867849077495, 23.13839762551444, 24.07917676653181, 33.67364195414952, 25.397760731833323, 14.065339156559535, 2.086915982621057, 0.1261591339217765, 0.04321243141644767, 0.06072164420038462, 0.011374452151358128, 0.01033909507428429, 0.019813217455521226, 0.052553605886974504, 0.022387255315801928, 0.02868025710007974, 0.07360068668744393, 0.03345912156094398, 0.07685253183756556, 0.026199914747849107, 0.03520152824265616, 0.04312470701656171, 0.051254418279443464, 0.050183282899005074, 0.0417969395140452, 0.026767941857022897, 0.05118828825652599, 0.008138023316860199, 0.014720722234674861, 0.06661260380808796, 0.009924214166988219, 0.02589707778367613, 0.04640546115115285, 0.024891773870747005, 0.018001092996980463, 0.03943577674882753, 0.03153595654293895, 0.03596741446693029, 0.08268549705722503, 0.03161512800891485, 0.06035581204508032, 0.02374349075502583, 0.05268662589203034, 0.05365246281559978, 0.04208718626094716, 0.08501219363617045, 0.03741663295243468, 0.03145273083022662, 0.03996589580284698, 0.004938662850431034, 0.05382413217531783, 0.032689181089933426, 0.03471757671130555, 0.033483596319066625, 0.045502100339425464, 0.022457378517304147, 0.03155814463804875, 0.00629313028184697, 0.008654764204818224, 0.014935541332566311, 0.08000930744622435, 0.022503615589812398, 0.030832912839416946, 0.06728331531797137, 0.045751041267067194, 0.052918742543884685, 0.03628448031044432, 0.023424643757087842, 0.06278992750282798, 0.011499027788106884, 0.035568049111004384, 0.06902514863759279, 0.03835606129307832, 0.029755674036485807, 0.06174276476459844, 0.026177363636504327, 0.02835351534719978, 0.04496893805584737, 0.08362085079508168, 0.021188165194221904, 0.054001687826322656, 0.025742795883810947, 0.042429320580725155, 0.07378638136599745, 0.049474695564380715, 0.06613511193011488, 0.07822890619614295, 0.07371424630816494, 0.03190113051927515, 0.05436368625877159, 0.07264740605439458, 0.023675216561449424, 0.06009093911520072, 0.038339301478117704, 0.016699791752866337, 0.03295113971190793, 0.019753497892192433, 0.024958996335044503, 0.10056524763682059, 1.8317262360027857, 11.698726262365069, 30.624876635415212, 39.29881320680891, 43.42905173982893, 37.57807445526123, 34.05555316380092, 25.65350307737078, 39.75655705588204, 37.11096790858677, 26.663882323673793, 26.46429705619812, 16.685642072132655, 10.404694625309535, 4.8491121871130805, 2.4060975526060377, 0.3646570955004011, 0.1525668211813484, 0.22605510854295321, 0.313446863421372, 0.33371511154941147, 0.631706385740212, 1.3299455727849687, 1.5314547313111169, 2.2866295746394565, 2.649133379970278, 2.5620446588311876, 3.8954654165676663, 6.097042092255183, 7.277567088603973, 5.678243764809199, 5.250751503876277, 4.1124016387122015, 3.4268667442458014, 1.8577650444848197, 2.86310185279165, 16.714287757873535, 29.050729240689957, 38.208953516823904, 43.25288363865444, 45.03079564230782, 29.772624492645264, 18.67488353593009, 22.806068761008127, 27.163162503923687, 23.49642092841012, 29.200113773345947, 24.408134017671856, 26.863957439150127, 19.454308135168894, 13.483226026807513, 17.408016749790736, 8.593185475894384, 3.6167529778821126, 0.5433136831436838, 7.696171300751822, 6.724830508232117, 5.054905670029776, 4.823554541383471, 4.9089487705911905, 6.326321354934147, 4.614516683987208, 2.877749958208629, 3.974236709730966, 1.5774831814425332, 1.6893005413668496, 1.5362514853477478, 0.5319147290928024, 0.20146556943655014, 0.13888530246913433, 0.7765726894140244, 1.416768525327955, 6.274431773594447, 12.143580334527151, 22.903208051409038, 19.093083449772426, 41.25164610998971, 24.367803198950632, 18.203917264938354, 24.70029013497489, 34.49462720326015, 31.26882873262678, 16.184803758348735, 2.931908126388277, 0.10339023997741086, 0.03529180393421224, 0.017833971518224905, 0.07563345546701125, 0.0215880106136735, 0.013944888687027352, 0.01479504387160497, 0.029537820190723454, 0.0177913747860917, 0.06431006307580642, 0.042950832418033054, 0.05504221109939473, 0.0635889974821891, 0.05673740192183426, 0.029821291765464202, 0.05204386663224016, 0.01651136257818767, 0.027101869295750345, 0.03701131005904504, 0.018658174434676766, 0.04414046036877802, 0.05076344051797475, 0.026923636806064417, 0.006204558985440859, 0.022820703485714536, 0.07067605147936515, 0.039560253997998576, 0.011151190381497145, 0.05304721636431558, 0.02386606640980712, 0.07405545442764248, 0.03655261020841343, 0.013376404414884746, 0.04247720479699118, 0.019104725115799477, 0.022864072051431452, 0.04202491710228579, 0.03646374247702105, 0.09430234227329493, 0.03491427722786154, 0.02647500641510955, 0.02465527388267219, 0.06574544283960547, 0.1926643324217626, 0.15901557728648186, 0.13376882273171628, 0.14428355065839632, 0.1428849542779582, 0.15043563768267632, 0.1322587566184146, 0.10377172593559537, 0.15605510185871804, 0.1136602678203157, 0.1515007476721491, 0.10057987685182265, 0.10827134270220995, 0.12301770677523953, 0.12376252109450953, 0.1593220444130046, 0.2543061040341854, 0.20268967375159264, 0.1144847082240241, 0.11202676940177168, 0.13946241007319518, 0.17375878617167473, 0.1645438192146165, 0.23501266645533697, 0.15544469175594194, 0.2017575701964753, 0.10640954439129148, 0.10356844362935849, 0.18021241415824207, 0.08216827695391007, 0.28259146053876194, 0.15458983262734755, 0.0924790779660855, 0.17998311003404005, 0.17900986011539186, 0.1274819922234331, 0.27006879821419716, 0.1499748852636133, 0.1361452423568283, 0.14188516006938048, 0.12393397332302161, 0.11839997741792883, 0.2079082051558154, 0.20928647262709482, 0.1090417852891343, 0.14393923484853335, 0.22179795269455227, 0.1452661236482007, 0.2609290400786059, 2.0997013194220404, 12.876162784440176, 33.34508943557739, 46.24962779453823, 50.22313928604126, 45.55373791285923, 45.59915828704834, 39.62896728515625, 50.0758444241115, 34.10852970395769, 24.5781147480011, 27.149438074656896, 18.077765771320887, 13.230798840522766, 7.367771642548697, 3.7288215586117337, 1.3334530017205646, 0.7741569961820329, 0.9482899265629905, 0.9310433034385953, 2.255513152905873, 3.1991060972213745, 3.2280629319804053, 6.954487144947052, 6.478750935622624, 5.816625824996403, 9.476736647742134, 10.643416489873614, 11.490289858409337, 9.596770252500262, 15.345470053809029, 9.81951560292925, 6.902653583458491, 3.2503086754253934, 1.2793220835072654, 3.524340416703905, 17.57988565308707, 28.98347588947841, 38.2842754636492, 43.48362636566162, 47.09376791545323, 31.280268941606792, 22.560526371002197, 23.866845028741018, 26.897784743990215, 25.414398193359375, 30.011024134499685, 28.72821991784232, 31.626949310302734, 20.33689958708627, 15.377252851213727, 18.93993125643049, 9.206823451178414, 3.7915056007249013, 2.1686702242919376, 12.343042271477835, 7.486822945731027, 12.292491521154131, 11.125325305121285, 10.237840584346227, 11.729278360094343, 10.753551517214094, 10.520885007722036, 11.152038523129054, 7.185317158699036, 6.433867744037083, 7.382202182497297, 1.9790766835212708, 1.0374399828059333, 0.5234755990760667, 1.3370537970747267, 1.7784215020281928, 6.091318513665881, 12.608028326715742, 28.773992913109915, 29.062120812279836, 48.3074757712228, 25.844668865203857, 29.965603760310582, 33.61574608939034, 41.97326864515032, 35.64780930110386, 19.724867514201573, 3.4936927812440053, 0.3085355726735932, 0.10685703145073992, 0.17472468077072076, 0.16940667613276414, 0.08159834825034652, 0.17793066373893193, 0.10196421042616878, 0.13740800959723337, 0.1512641967939479, 0.10681984773171799, 0.1440621175404106, 0.21006635363612855, 0.13099387234875134, 0.19328635904405797, 0.23892385086842946, 0.1252047744180475, 0.08797713382435696, 0.17671027779579163, 0.19565409342093126, 0.12125743765916143, 0.13958263290779932, 0.1189487629703113, 0.1378609724342823, 0.07284613539065633, 0.129292757915599, 0.20699762473148958, 0.10985146755618708, 0.17002581219588006, 0.10585525591990777, 0.11994771579546587, 0.2090607104556901, 0.20143633814794676, 0.10507894400507212, 0.09615240871374096, 0.08157360207821641, 0.19614221794264658, 0.24231302472097532, 0.0906260802543589, 0.15544302255979606, 0.07374368115727391, 0.1772858247693096, 0.13262982027871267, 0.16601640305348805], [0.0055170202311793605, 0.0214557997616274, 0.021394850353577306, 0.050179635773279836, 0.014470481912472417, 0.0283600072309907, 0.024656049108930995, 0.01067349748752479, 0.1056451950488346, 0.041523598467132876, 0.01784364233857819, 0.0657191224662321, 0.024896964663639665, 0.014819678085457002, 0.0685262761211821, 0.032798686463918, 0.05725444560604436, 0.0026897732459474355, 0.011155013078158455, 0.023201594029420188, 0.04366583190858364, 0.01711248353655849, 0.024049720394292047, 0.033827800170651505, 0.054676205917660675, 0.035002296790480614, 0.015519442768501384, 0.048484407631414275, 0.05149755773267575, 0.09130690193602017, 0.11715622272874628, 0.049895254961614094, 0.045006793524537764, 0.05914772115647793, 0.03416355626125421, 0.020910637586244514, 0.024671580775507858, 0.020536652832691158, 0.05100063939711877, 0.01749835622363857, 0.06029167691511767, 0.05605807980256421, 0.026940486526915004, 0.033325294099215946, 0.11154768296650477, 0.02305056570496942, 0.050210783923310895, 0.04336338849472148, 0.02440215996466577, 0.06950388902000018, 1.4792461842298508, 7.587925314903259, 21.765183448791504, 32.78617981501988, 41.18330362864903, 39.050481115068706, 35.922655718667166, 14.051076241901942, 10.837436250277928, 20.677727835518972, 21.25854512623378, 13.683015397616796, 11.956635577338082, 8.835804411343165, 6.188312760421208, 3.3989844918251038, 1.1898989847728183, 0.6142397544213704, 0.27396871894598007, 0.2617816600416388, 0.3534047050135476, 0.7036689328295844, 0.735577612050942, 2.4373855079923357, 1.7297819405794144, 1.8852013094084603, 1.6390598544052668, 4.3006192190306525, 5.374924497944968, 3.809683391026088, 7.299131257193429, 1.9503688982554843, 2.359187658343996, 1.5819766031844276, 0.05970513088894742, 1.698575300829751, 9.173281891005379, 16.992132323128835, 23.435052701405116, 18.48154296193804, 11.997193081038338, 11.41004945550646, 9.354182583945137, 9.673178723880223, 9.628992523465838, 8.90190783568791, 9.269008960042681, 7.220347370420184, 6.557658152920859, 5.173491443906512, 6.08900910615921, 1.3381161114999225, 1.1340877967221397, 3.777119789804731, 12.427817242486135, 3.8122954794338773, 3.7682990516935075, 3.9003660678863525, 2.7284329533576965, 5.245841298784528, 2.5464400904519215, 0.9136532651526588, 3.3500693908759525, 0.9176884314843586, 0.8773015929119927, 0.5453850605658123, 0.39818565494247843, 0.511436867926802, 1.3156716930014747, 2.565009585448674, 5.283675108637128, 5.766386006559644, 17.28803699357169, 33.14559275763375, 35.68428039550781, 25.43543212754386, 14.660836253847394, 30.89470992769514, 32.8741648537772, 27.217697177614482, 13.213605523109436, 3.3577306483473097, 0.07123515754938126, 0.029855951334216764, 0.024974914766581993, 0.046142980057213984, 0.01759257589999054, 0.05174114162634526, 0.03666625464601176, 0.015303845051676035, 0.0351087351861809, 0.06786049756088428, 0.05546842947868364, 0.07009491337729351, 0.05313491362280079, 0.04828294040635228, 0.0387507176159748, 0.008853435017434614, 0.08942424545862845, 0.045024289549993615, 0.029580676462501287, 0.03222473744036896, 0.012835269344837537, 0.029411877305912118, 0.02909131022170186, 0.007349391750592206, 0.03069730761594006, 0.08455950899847917, 0.03296451363712549, 0.05609898867883852, 0.03962916601449251, 0.10444341453590564, 0.049245055565344434, 0.05406654220340507, 0.03491423651576042, 0.036015312253896675, 0.02757201942482165, 0.08297067854021277, 0.027494225384933606, 0.032787806154893975, 0.03125416773504444, 0.051596447426293574, 0.03200742302994643, 0.0531518295008157, 0.037568811393742046, 0.023379526267360364, 0.027069111321387545, 0.02189749213201659, 0.015773969735684137, 0.05371217389724084, 0.047172466958207745, 0.0704626115038991, 0.011441335348146302, 0.04436839724491749, 0.018246580181377273, 0.03415114585576313, 0.05846549490732806, 0.031991704766239436, 0.026579019048118165, 0.0839305884603943, 0.04000736107783658, 0.006887422633423869, 0.02962693219472255, 0.0271719500888139, 0.005479291563720575, 0.048774959719074626, 0.008114955670732473, 0.031169822439551353, 0.05340415631820049, 0.10835624100374323, 0.04391066769936255, 0.05572440002911857, 0.037876554166099856, 0.03240804706833192, 0.002270033603833456, 0.08001607244036027, 0.06688831294221537, 0.04177503640364323, 0.023019051146028296, 0.03219120084707226, 0.019008586881682277, 0.04947921121492982, 0.04524202125945261, 0.010583532225739743, 0.08289007536534752, 0.04922826521630798, 0.02069819505725588, 0.05039079247840813, 0.040686130191066434, 0.016230635677597353, 0.023367595925394977, 0.028855536266097, 0.01226858573500067, 0.030079470947384834, 0.02250037558509835, 0.14962081212018216, 2.128248210464205, 10.519212228911263, 26.216100454330444, 37.27928107125418, 43.314132009233745, 42.23350300107683, 40.500337396349224, 21.02978437287467, 12.83175163609641, 18.27837242398943, 26.184440987450735, 21.892997298921856, 17.560793740408762, 13.168589881488256, 6.5975282192230225, 2.83158677816391, 1.0921783255679267, 0.295087605714798, 0.0744023961680276, 0.19706813325839384, 0.19646186221923145, 0.2510041083608355, 0.4504620283842087, 1.4007858229534966, 2.6282505691051483, 2.378587028809956, 3.8048183492251804, 2.9684995114803314, 6.575584939547947, 3.5352742757116045, 4.473264583519526, 2.6682626392160143, 3.2218445113727023, 2.239788510969707, 0.4580173258270536, 4.322036172662463, 12.9726802110672, 20.759311846324376, 29.740534237452916, 24.382880789893015, 14.108733262334551, 13.10811276095254, 12.019307460103716, 15.552012205123901, 13.556453091757637, 12.15003434249333, 12.091292534555707, 13.393142632075719, 7.971381630216326, 6.91738463299615, 7.91553635256631, 3.9796489221709113, 1.6040680749075753, 6.359162884099143, 7.235123148986271, 6.539260191576822, 6.630227744579315, 5.546075565474374, 4.470120523657117, 4.191344465528216, 3.4549633051667894, 2.4505870853151595, 1.8842554858752658, 1.208164061818804, 0.5959368422627449, 0.35310240409203936, 0.29530006859983715, 0.27725993948323385, 1.2657002487352915, 2.5324149344648634, 8.130967855453491, 8.12433840547289, 19.95305504117693, 35.84221642357962, 34.928816659109934, 30.894609178815568, 19.415405171258108, 31.526262964521134, 35.91138574055263, 32.18202352523804, 15.426960263933454, 4.5234323143959045, 0.16005311161279678, 0.041031752180840285, 0.022363728810367838, 0.011708425391199333, 0.07055600506386586, 0.030403790330248218, 0.014534240455499716, 0.025645534674237882, 0.0168021250117038, 0.03857549273275903, 0.012619243302781667, 0.028742173420531408, 0.0696669409849814, 0.023240206064656377, 0.019417443246181523, 0.03346755575122578, 0.09075984664793525, 0.06236966326832771, 0.015617297696215766, 0.03312986583581992, 0.008379240819652165, 0.021279031211244206, 0.04904673335009387, 0.057612440681883266, 0.05884432100823947, 0.016006512168262686, 0.00989194558600762, 0.018243102689406702, 0.022164208980809365, 0.04577540745958686, 0.03120680938341788, 0.028971413083906685, 0.05545932014605828, 0.03685409010254911, 0.03951747915042298, 0.046493582494024716, 0.0514887469554586, 0.015038858467180814, 0.026939370336809328, 0.06945593016488211, 0.009000970582876886, 0.028930833297116414, 0.0359041037570153, 0.03920225213680949, 0.1136459100193211, 0.0817580550376858, 0.08388024794736079, 0.09600416238286666, 0.11339878756552935, 0.1762926394918135, 0.07604242209345102, 0.13783402102334158, 0.13870269512491568, 0.10993274926607098, 0.17159822210669518, 0.13954396998243673, 0.08150665781327657, 0.12258022810731616, 0.12157550773450307, 0.27979809471539085, 0.13994662623320306, 0.1302484337772642, 0.16096958172108444, 0.13432991690933704, 0.09947158489376307, 0.13270733611924307, 0.11048661704574313, 0.2683923553143229, 0.14604381977447442, 0.17840390120233807, 0.13436483432139668, 0.10887940507382154, 0.28103796818426674, 0.16754948507462228, 0.27889952436089516, 0.1209008132240602, 0.12341880239546299, 0.16985343715974263, 0.12709187529981136, 0.10572412902755396, 0.1050715751147696, 0.10799467004835606, 0.27277845995766775, 0.11152492490197931, 0.16686466682170117, 0.16899004206061363, 0.1278703992388078, 0.05191819516143628, 0.16000976679580553, 0.13139770925045013, 0.13340215597833904, 0.09463353521589722, 0.11595301729227815, 0.3291499008025442, 2.2721959948539734, 11.479880588395254, 29.921006747654506, 44.65282753535679, 51.13928011485508, 49.24433960233416, 47.413697719573975, 23.4009005682809, 18.39562848636082, 30.318930080958776, 31.9178078515189, 24.52779589380537, 20.157882724489482, 13.902669668197632, 9.490494949477059, 4.402494141033717, 2.1652217464787618, 0.9232399335929325, 0.7735359466501645, 0.8023931724684579, 0.9108899448599134, 2.4200117545468465, 3.1269386325563704, 6.122069503579821, 5.742952338286808, 6.379573217460087, 8.316266758101326, 10.620601211275373, 13.67693485532488, 10.485613346099854, 13.66574478149414, 6.342659609658377, 5.108834113393511, 2.9008338281086514, 0.9266870000532695, 2.735402430806841, 13.994972143854413, 22.473706892558507, 28.03641905103411, 21.60965497153146, 16.029431615556987, 16.030296666281565, 12.287876180240087, 13.921908361571175, 13.763672692435128, 11.574158089501516, 12.793269038200378, 13.427142773355756, 8.996329511914935, 6.483238169125148, 8.071619817188807, 5.271874896117619, 4.4564425604684015, 8.50467584814344, 23.049867153167725, 10.739841852869306, 10.087469407490321, 13.550600102969579, 9.6997903244836, 14.24736111504691, 8.332014850207738, 4.907999038696289, 7.172564174447741, 4.147117878709521, 2.6550732212407246, 1.5414099799735206, 0.9665012636354992, 0.9018855680312429, 1.8237479669707162, 3.7623904773167203, 8.150595647948128, 8.9972015108381, 23.33152801649911, 40.97716794695173, 41.7313288961138, 34.334186349596294, 23.49394736971174, 39.866383756910054, 42.14701182501656, 36.61346646717617, 18.111667769295828, 5.4752369437898905, 0.23525259643793106, 0.09580923284270934, 0.11875440339956965, 0.118177594350917, 0.1651199904403516, 0.11457591690123081, 0.18226604110428266, 0.10934411335204329, 0.10916419979184866, 0.11681747090603624, 0.19249252735504083, 0.10541525988706521, 0.20709910642887863, 0.152834788230913, 0.21421518815415247, 0.10748469669904027, 0.20100081366087708, 0.18979996469404015, 0.1422554909118584, 0.11688579938241414, 0.0849281842155116, 0.14391608323369706, 0.20300273623849663, 0.18685430847108364, 0.14071191873933586, 0.2025099026837519, 0.11196475130106721, 0.17012006070997032, 0.1104699590110353, 0.14982655750853674, 0.11666119072054114, 0.1674259781305279, 0.15881653582411154, 0.15592844651213714, 0.11912288862679686, 0.1927719209343195, 0.08863665629178286, 0.14019460364111833, 0.17598796369774, 0.20839168849800313, 0.1051376915669867, 0.15762676538101264, 0.15202448171164307, 0.11325580666639976], [0.02912476539079632, 0.06287981982209853, 0.051273763312825134, 0.05163036399920072, 0.06614548673055001, 0.03547580906056932, 0.007884937388423299, 0.010314711918389159, 0.04212791532544153, 0.05209436660100307, 0.08568578213453293, 0.005403820234018245, 0.013606418456350054, 0.03981701164905514, 0.030979245701538663, 0.015058898998956596, 0.01337708464624094, 0.034873985818454196, 0.02277905330993235, 0.0673293878457376, 0.015435390939403857, 0.029810788043375527, 0.024921468259500604, 0.013859880123553532, 0.03156827516587717, 0.05438025947660208, 0.018118871409179907, 0.014224044779049498, 0.02604677957216544, 0.023270066694489548, 0.040249981451779604, 0.06386208068579435, 0.03270188665815762, 0.04655595343293888, 0.05084028460883668, 0.012885646329128315, 0.04557883247200932, 0.02378537502538945, 0.039994346776178906, 0.0407693321550531, 0.03560722433030605, 0.017638173453243713, 0.009600988921842404, 0.03170542066384639, 0.07492184865155391, 0.01129616956625666, 0.01157492192994271, 0.07878150511533022, 0.03566716272117836, 0.01803587470203638, 0.010678485568080629, 1.1631447289671217, 6.661743904863085, 23.72149392536708, 34.79216991152082, 41.221445764814106, 33.86467225211007, 33.55995552880423, 28.936695405415126, 24.161948919296265, 24.127689089093888, 15.763617856161934, 12.996014867510114, 15.252918311527797, 13.522085564477102, 7.528472185134888, 4.5512073040008545, 2.4663280120917728, 1.1998623758554459, 0.5452991308910506, 0.13958352857402392, 0.3455410269754273, 0.03564362434138145, 0.5838335145797048, 1.893860936164856, 1.188192442059517, 2.924849625144686, 2.9700965115002225, 6.822157399994986, 2.1531249327319006, 3.0649478903838565, 3.137160301208496, 5.265862098761967, 3.442636332341603, 0.7073404586740902, 0.3342031682176249, 0.6359597689339093, 1.4913702479430606, 4.20653235912323, 3.4301467282431464, 4.381867979254041, 4.517936723572867, 4.059040776320866, 5.32708180802209, 3.4618224799633026, 3.234766640833446, 3.4849929852145056, 2.817466301577432, 2.468157993895667, 1.3841945018087114, 2.181124653135027, 1.3381575835602624, 6.128483559404101, 6.256755556379046, 8.280357599258423, 5.912541798182896, 4.681538139070783, 2.312463194131851, 2.570794177906854, 1.8892158482755934, 1.6315221445901054, 1.7745909818581171, 1.309843240039689, 1.0220995545387268, 0.3107389115861484, 0.3045992281820093, 0.5473266478095735, 1.2452582142182758, 3.3419838590281348, 6.5096825786999295, 4.924917033740452, 12.046961290495735, 22.521069288253784, 58.877075467790874, 27.56162084851946, 17.047101259231567, 27.71735950878688, 30.855091299329484, 24.107030357633317, 13.103110057967049, 2.965094894170761, 0.35126373703990665, 0.03651674284732767, 0.09501405765435525, 0.026798350403883626, 0.018238924610029374, 0.02739748834366245, 0.02719063694322748, 0.02170047440033938, 0.024476160993799567, 0.0714924241017018, 0.057623941850449355, 0.058772830558674674, 0.037853918237877746, 0.046322707020278485, 0.028635958941387277, 0.022092635410704782, 0.05396517924964428, 0.044133189866053205, 0.01981178405029433, 0.010205641654985291, 0.03850402603191989, 0.042478415981999466, 0.03874955732109291, 0.027510366036689708, 0.019282148452475667, 0.02052884628730161, 0.07567762809672526, 0.03516259390328612, 0.020198375984494175, 0.032454082276672125, 0.02845345507375896, 0.042723160170550854, 0.05709205860538142, 0.01327618648896792, 0.0941715275070497, 0.01068669923448137, 0.05625837655471904, 0.026824667384581904, 0.070674517990223, 0.04067171471459525, 0.029296845264200653, 0.015271088773650783, 0.049419038729476075, 0.02032010007782706, 0.010311738238669932, 0.02606472682340869, 0.04440194062356438, 0.02080575473207448, 0.02333050380860056, 0.022089882254866616, 0.03246688283979893, 0.046250812842377594, 0.02451008265571935, 0.03889305051416159, 0.019844776119238565, 0.002988866393155019, 0.01882335021426635, 0.04446631324078355, 0.07615395289446626, 0.06613114250025579, 0.03891205967270902, 0.024365106863634925, 0.026424906782007644, 0.02478170022368431, 0.06503837542342288, 0.0048979057963671425, 0.02472591446712613, 0.019951231478314315, 0.04766446252220443, 0.05177853908389807, 0.03216199669986963, 0.021337955192263638, 0.03427557560748287, 0.03477530986336725, 0.019145491499719874, 0.03407755534031561, 0.019168700790032744, 0.01705664349719882, 0.019221534919259802, 0.03714834699141128, 0.03147360596007534, 0.04574955866805144, 0.02030695346184075, 0.03610872616991401, 0.018552056646772792, 0.010247894878765302, 0.0407081859718476, 0.06547111113156591, 0.04596403680209603, 0.0506966964208654, 0.10717626860631363, 0.03220876472602997, 0.024967104828517352, 0.04070465758975063, 0.01891594479924866, 0.06464266737124749, 1.5691897464650018, 9.393895012991768, 27.259059803826467, 42.35683700016567, 43.90514925548008, 38.14723266874041, 29.14186007635934, 26.490783589226858, 22.57176160812378, 24.643994092941284, 19.36470069204058, 18.47355600765773, 17.50087594985962, 17.342915603092738, 9.597935812813894, 4.852447756699153, 3.558096936770848, 0.9483213020222527, 0.2002398366374629, 0.30029020511678284, 0.2904292456805706, 0.09103643109223672, 0.3432699702680111, 1.4058654989515031, 1.4400035185473306, 1.762575700879097, 2.3230333583695546, 3.0919922334807257, 2.1612721298422133, 3.1288739229951585, 4.3539566312517435, 4.49534899847848, 2.4038072526454926, 1.070425687091691, 1.2802824548312595, 1.8600253803389413, 4.724684281008584, 7.381651537758963, 5.407580597060067, 5.90678391286305, 4.869755285126822, 5.444310077599116, 6.629959804671151, 6.2427970596722195, 4.837543436459132, 6.40371082510267, 3.8532420822552274, 4.4979680350848605, 1.9764580811773027, 3.93927424294608, 0.9236567169427872, 7.944946340152195, 12.298240286963326, 8.679812141827174, 3.7728088668414523, 3.0666864599500383, 3.0966685882636478, 1.8088096656969614, 2.7929573995726447, 1.6383672058582306, 1.2464403850691659, 0.7253301047853061, 0.35737036221793717, 0.17140112125447818, 0.13423261498766287, 0.6844813738550458, 0.8871934392622539, 3.542478689125606, 8.617729118892125, 10.150724938937596, 13.13828010218484, 24.901016644069127, 59.21785681588309, 29.95834984098162, 23.195650781903947, 27.191363504954747, 36.11934879847935, 28.34394805771964, 16.48692011833191, 3.9838156700134277, 0.5350618287920952, 0.014322306827775069, 0.025541552575305104, 0.05049957521259785, 0.023688656643831303, 0.03103599837049842, 0.01897224284974592, 0.08510797563940287, 0.052260495722293854, 0.02279701073920088, 0.04204874385946563, 0.05075660427766187, 0.06443521207464592, 0.018448334087484648, 0.03477877717731254, 0.0025370839949963348, 0.013182155106083622, 0.06778408773243427, 0.008874176136617149, 0.0014715555402550048, 0.050020960359168906, 0.038108260304267914, 0.05969254406435149, 0.01806154877080449, 0.013360384203094457, 0.013122679815361542, 0.02177055858607803, 0.0592421664457236, 0.02789991468723331, 0.026125019748828242, 0.013162763423419424, 0.03434009071705597, 0.02277989299701793, 0.07142966639782701, 0.11180180790168898, 0.04552841732012374, 0.03382100464243974, 0.04937796700479729, 0.05177235762987818, 0.018927525695679442, 0.013782415173149534, 0.042091328717236004, 0.05292633195806827, 0.026523072139493058, 0.06132465148610728, 0.14634694850870542, 0.1800825832677739, 0.08238796623689787, 0.13440551928111485, 0.11373751903218882, 0.13423627907676355, 0.14017846807837486, 0.0786167975249035, 0.10012941102364234, 0.10899616059448038, 0.2556469977966377, 0.07801477411495787, 0.14861093488122734, 0.17165652183549746, 0.11152989177831582, 0.16556054965725966, 0.11577103420027665, 0.1615900205714362, 0.14265130752963678, 0.12147089120532785, 0.08345526110913072, 0.1176954952201673, 0.10355434367167098, 0.16172876741204942, 0.12911290542355605, 0.27061727164047106, 0.06940511467733554, 0.12268164195120335, 0.08330729976296425, 0.048166117032191584, 0.13233639459524835, 0.12092798176620688, 0.09736622643790074, 0.11743253575904028, 0.12232948227652482, 0.11340482652719532, 0.09008337437574353, 0.15641665245805467, 0.09808101558259555, 0.12800012156367302, 0.10859734485191957, 0.2908987376306738, 0.23318073047058924, 0.09174941533378192, 0.14328157156705856, 0.1825103544230972, 0.08867256436496973, 0.17437049906168664, 0.09931627501334463, 0.10641166820589985, 0.15838295194719518, 1.814738107579095, 10.428956866264343, 29.690885884421213, 46.38667753764561, 51.76489591598511, 45.88097027369908, 42.85556827272688, 38.30762488501412, 33.87258972440447, 33.57491152627127, 23.223704133714946, 23.69204224858965, 23.17027769769941, 21.47451424598694, 11.377643057278224, 7.374573928969247, 3.5550753389086043, 1.8201988488435745, 0.9317367119448525, 0.7920533844402858, 0.8051734289952687, 1.0304186109985625, 2.0069932426725114, 4.276466412203653, 4.937831129346575, 8.135427730424063, 7.168096048491342, 13.540672864232745, 8.901710680552892, 8.870991826057434, 7.941070982388087, 11.412880846432277, 7.832805888993399, 1.2671498166663306, 1.061589315533638, 1.3577298990317752, 3.313246761049543, 6.4436225805963785, 5.449825210230691, 5.525475459439414, 6.572493859699794, 5.654177810464587, 6.696777156421116, 5.330683580466679, 4.648771303040641, 4.880692618233817, 3.6979815449033464, 4.1395039558410645, 2.833464963095529, 3.3732809339250838, 3.731701586927686, 18.913924149104528, 11.544828874724251, 15.271435260772705, 14.399977428572518, 11.191741398402623, 8.37291715826307, 7.111445648329599, 5.716302956853594, 6.746018605572837, 5.258484414645603, 3.006377616098949, 1.9352465782846724, 0.8842867580907685, 0.6880742982029915, 1.1087577044963837, 1.8505508601665497, 4.745856744902475, 9.25684266430991, 8.541626368250165, 18.055072954722814, 29.08360811642238, 63.11611584254673, 35.13576528004238, 25.355571269989014, 36.625142914908274, 40.82377256665911, 32.97865533828735, 18.587548153741018, 5.248165036950793, 0.4600483168448721, 0.11473362201026507, 0.15913661436310836, 0.12084370771689074, 0.14235298282333783, 0.1314941155058997, 0.08023297972977161, 0.1668810195156506, 0.2124985759811742, 0.15353441211794103, 0.14196623143340859, 0.14535605667957238, 0.12265730968543462, 0.08593466877937317, 0.09550087260348455, 0.09799075006906476, 0.15194350534251758, 0.13732042429702623, 0.08712485991418362, 0.08799253656928029, 0.1775369912918125, 0.13191976052309784, 0.09571847878396511, 0.0978711379159774, 0.07530482738677945, 0.06999936207596745, 0.171004911086389, 0.27602134166019304, 0.0972306551411748, 0.12688482712422097, 0.07920772010194403, 0.1504704872412341, 0.18773453123867512, 0.14057902087058338, 0.20931847233857426, 0.11479599294917923, 0.1502762498067958, 0.14260428505284445, 0.10092417230563504, 0.16915810161403247, 0.17436281804527554, 0.13635020064456121, 0.17605842277407646, 0.1078743115067482, 0.08370098578078405], [0.01942656614950725, 0.014985817384773066, 0.048249888965593915, 0.03354523783283574, 0.07292979875845568, 0.12064162641763687, 0.03080490630652223, 0.03741955065301486, 0.08736742939800024, 0.018550758948549628, 0.011362435296177864, 0.042532400228083134, 0.010261543610665416, 0.025804774968751838, 0.019487698762012378, 0.017354973292510425, 0.05546551177810345, 0.04097027690815074, 0.02716540392222149, 0.05156632047146559, 0.024035126802378466, 0.017931787430175712, 0.021137780576412166, 0.03515142182420407, 0.02254667372575828, 0.08148667495697737, 0.04629817458667925, 0.03411121406991567, 0.012775019676025425, 0.0269136810010033, 0.028606161076043333, 0.024898750907076255, 0.07415979275746004, 0.04064606948356543, 0.018625243433884213, 0.06129240071667092, 0.05569776752963662, 0.029711457301995585, 0.10633402344371591, 0.008169260524612452, 0.018436627662075416, 0.05081132812691586, 0.008740769366600683, 0.04427996038326195, 0.02470054573911641, 0.03826522581013186, 0.05600004130974412, 0.03293795916917069, 0.05527728616393038, 0.07575671813849892, 0.03309548107374992, 0.06576670134173972, 0.47432051386151997, 4.183531650475093, 18.20585060119629, 35.86616339002337, 41.06136621747698, 37.348957606724326, 26.7534168107169, 25.438664776938303, 29.626906871795654, 21.091821363994054, 15.06805453981672, 19.499780620847428, 15.42819356918335, 12.44819630895342, 7.4456870044980725, 7.312502196856907, 5.403534139905657, 1.7968463876417704, 0.6088940384132522, 0.22398806017424377, 0.027953861613890955, 0.42254161515406197, 1.3585913670914513, 1.0408403660569872, 1.884882343666894, 0.7822272202798298, 1.967271476984024, 0.700033993593284, 1.8570584995406014, 1.4683647624083926, 1.9692054646355766, 0.8949385093791145, 1.5880366265773773, 2.0195970577853064, 2.5659864587443213, 1.2487256910119737, 1.3781684594494956, 1.8435577154159546, 0.5102215302842004, 0.9257341197558812, 0.5193533631307738, 1.6127502833093916, 1.9587073879582542, 0.8460503869823047, 1.5943496078252792, 0.12645554515932286, 0.6509913823434285, 0.2564093183193888, 1.7311418333223887, 0.3628619632550648, 9.495387349809919, 6.333264342376164, 1.8378669236387526, 4.048439996583121, 3.218349350350244, 2.008344667298453, 1.821557764496122, 2.1666519897324696, 0.7399409179176603, 0.36801483961088316, 0.3945206973169531, 0.27226632886699265, 0.22845068999699183, 1.056952804327011, 2.015572313751493, 4.352028940405164, 7.176996690886361, 11.32111598764147, 15.246173347745623, 13.926515885761805, 22.64148678098406, 44.47021845408848, 22.09023928642273, 23.35857387951442, 34.65405361992972, 24.18057530266898, 13.104590024266924, 2.100205498082297, 0.07814273903412478, 0.04797789141801851, 0.015887466591915915, 0.027239155589735935, 0.05531384563073516, 0.024416816321068575, 0.01418071607726493, 0.016268972906150987, 0.01614982385321387, 0.027927296967910867, 0.037756595960153, 0.02402731856065137, 0.02620349232373493, 0.031245282318975245, 0.015160948969423771, 0.045472974223749976, 0.03474513880376305, 0.05415804943602, 0.04955005366355181, 0.010484618783396269, 0.048947589205844064, 0.005573753392257328, 0.030512885190546513, 0.02338033202769501, 0.025723176043746725, 0.033062507664518695, 0.033170771319419146, 0.04774809196325285, 0.03731292226750936, 0.025962909251185398, 0.024872545884656053, 0.08058045751282147, 0.022886767351467694, 0.012418965210339852, 0.024379883660003543, 0.0556067590202604, 0.02052555199978607, 0.01622280029446951, 0.0472461388978575, 0.022080068942159414, 0.09313419674124036, 0.06155024402375732, 0.07389975099691323, 0.0005618305471476301, 0.022707106545567513, 0.03348542497094188, 0.05271577914910657, 0.03654305643535086, 0.07392292296780006, 0.01956130963351045, 0.015175998876137393, 0.030529298952647617, 0.03760222585073539, 0.04270732994856579, 0.05214721769360559, 0.03181735519319773, 0.043911241061453304, 0.02117574630704309, 0.07936391207788672, 0.017578582811568464, 0.015657570445910096, 0.02072480889702482, 0.03910124541393348, 0.023746223554813435, 0.06993711327335664, 0.061088962347379754, 0.058613781950303485, 0.034637479045029194, 0.02372684289834329, 0.03105043081034507, 0.023645691806450486, 0.023440312827005982, 0.015048242606488722, 0.0689521518402866, 0.018160470694835697, 0.008513699318947536, 0.05668842526418822, 0.029014069187854017, 0.021504545717367103, 0.02839206631428429, 0.018943349132314324, 0.017960793105885386, 0.1456714668976409, 0.008970710465551486, 0.027811108023992608, 0.019831105334950343, 0.022642659289496284, 0.07176604334797178, 0.04723355546593666, 0.05410410590203745, 0.010648462089842983, 0.03277569091213601, 0.04483216575213841, 0.03352239495143294, 0.0391195115766355, 0.03251919788973672, 0.15091164356895856, 0.015405384424541677, 0.9164887815713882, 7.21689064162118, 22.97101899555751, 41.76208162307739, 44.93687684195382, 42.382517542157856, 29.723396505628312, 28.67175711904253, 28.21076672417777, 17.022575855255127, 17.52784538269043, 27.578982659748622, 23.355864082063945, 14.835088389260427, 10.293835248265948, 7.100980358464377, 6.146323927811213, 1.9395082124641962, 0.7539988607168198, 0.04669758404738136, 0.12005656638315745, 0.16045887555394853, 0.2979737679873194, 0.6780080412115369, 0.41370052099227905, 0.6486612930893898, 1.1145353487559726, 1.1786764498267854, 1.5214659358773912, 1.3298143169709613, 2.326285115310124, 1.793148426072938, 1.4813395461865833, 2.277374356985092, 2.3660268570695604, 1.6104800679853983, 1.1729201929909843, 2.3137171268463135, 0.9776128445352826, 1.7563190651791436, 1.7463533942188536, 2.590919635125569, 3.417352054800306, 2.5676696598529816, 3.189831772020885, 1.669919952750206, 1.7329685581581933, 1.0626810512372424, 2.1007459376539503, 1.3166754905666624, 10.421385066849844, 7.046877775873456, 2.2389015299933295, 2.431038328579494, 3.0735434634344916, 1.9433006261076247, 1.8828593322208949, 1.2589829691818781, 1.1965577474662235, 0.5477704097117696, 0.30752783960529734, 0.1882786891822304, 0.18873189629188605, 0.6386880225368908, 2.027389028242656, 5.616063901356288, 10.003043583461217, 12.851691229002816, 14.019582663263593, 15.29951640537807, 20.598733765738352, 51.00083030973162, 25.67246297427586, 24.203353234699794, 38.12196207046509, 27.48234016554696, 15.902086768831525, 3.204033455678395, 0.21015437319874763, 0.007587564327487988, 0.05245192062907985, 0.04384489730000496, 0.01902441880000489, 0.02623688303200262, 0.06226498567100082, 0.06547860894352198, 0.007399845918241356, 0.032212812187416215, 0.01911585309010531, 0.007566421176306903, 0.019894987710618546, 0.02589140014190759, 0.015671125879245143, 0.07126553556216614, 0.025012693900082792, 0.01336375652213714, 0.04497308390481131, 0.021181585100878562, 0.04435280790286405, 0.03803381144202181, 0.014477416540363004, 0.042378362600824664, 0.026270126158903753, 0.0037430061160453726, 0.02593015636583524, 0.012447147314170641, 0.033028102546398125, 0.032583143029894145, 0.013982359935263438, 0.04400884832388588, 0.0732087716460228, 0.03016702571351613, 0.019733018008992076, 0.04888720976720963, 0.008784109094579304, 0.020344608762700642, 0.06358396953770093, 0.005794420613840754, 0.10910886526107788, 0.011091363948902913, 0.0292545996739396, 0.023152612282761505, 0.03138494857453874, 0.00928506047265338, 0.1476097157491105, 0.11541742246065821, 0.13004442543855735, 0.09868725269500699, 0.1321436363671507, 0.24745773151516914, 0.12548277021518775, 0.16945848906678812, 0.118052282503673, 0.11872879548796586, 0.1364324933716229, 0.17204085764076027, 0.1233860155833619, 0.1329473882381405, 0.08020804356783628, 0.06436138746461698, 0.1296521643442767, 0.07746463149253811, 0.09231251797505788, 0.18185461818107537, 0.1730931976011821, 0.09896286683423178, 0.12034246032791478, 0.11633548034088952, 0.09453841817698308, 0.15026428044906684, 0.10996285586484841, 0.11842568032443523, 0.12265536907528128, 0.11294197064957448, 0.10848718469164201, 0.12175191326865129, 0.10412505269050598, 0.07104930002242327, 0.10325904523155519, 0.11139978268848998, 0.2590664343110153, 0.11639897764793464, 0.2225651993815388, 0.0976236897653767, 0.17945636329906328, 0.1791071348956653, 0.17817269718008383, 0.11382481256233794, 0.08254130836576223, 0.10339300161493675, 0.1625513011323554, 0.10740996285208634, 0.15754665753671102, 0.1519049374120576, 0.23352564339126858, 0.19088346298251832, 1.1725497671536036, 7.738437192780631, 24.67654119219099, 46.85080678122384, 51.740830830165315, 48.56839452471052, 37.954632077898296, 35.8617582321167, 39.351032393319265, 30.07107046672276, 24.247715745653423, 29.40002039500645, 24.00695719037737, 18.684583221163066, 13.011355621474129, 10.288598912102835, 7.30632437978472, 2.7853905941758836, 0.8771303849560874, 0.4648453965783119, 0.4167119679706437, 0.9581680936472756, 2.7426326828343526, 1.8369171917438507, 4.208883021559034, 3.8950828313827515, 6.272110206740243, 4.1114992414202005, 5.517367345946176, 5.484499326774052, 6.270093926361628, 5.115483973707471, 5.215835503169468, 6.361427128314972, 5.915524312428065, 3.6236397283417836, 5.328265173094613, 3.646501907280513, 1.9517961016723087, 1.781413352915219, 1.7456074399607522, 3.397655648844583, 4.1933802877153665, 2.174313247203827, 3.879883212702615, 2.3163411574704305, 1.1947204917669296, 1.4288788012095859, 2.510639497212001, 2.1067239940166473, 18.56574818066188, 13.591141973223005, 8.459539481571742, 9.399510894502912, 8.180226240839277, 6.823498402323041, 4.661468701703208, 6.089441631521497, 3.9878625614302496, 2.1345313361712863, 1.1152583956718445, 0.7676966371280807, 0.7766376659274101, 1.4473655692168643, 3.4409370635237013, 6.560656300612858, 10.803792204175677, 16.55119616644723, 21.819843190056936, 20.962781156812394, 29.785610675811768, 53.005062511989046, 30.23312677655901, 33.12692642211914, 44.20732293810163, 31.48945140838623, 19.241912126541138, 4.149732572691781, 0.3907521681061813, 0.0871427868093763, 0.16567528992891312, 0.14981252540435108, 0.10296887651618038, 0.0733204652954425, 0.10973492916673422, 0.13876506606382982, 0.10206101701727935, 0.10081949470830814, 0.20258414798549243, 0.09015767396028553, 0.07668787174459014, 0.17632782831788063, 0.05930881215525525, 0.14203886182180472, 0.20648813992738724, 0.19416848170970166, 0.11924583917217595, 0.07912075905395405, 0.15035695476191385, 0.1961917509990079, 0.13632246213299887, 0.07740943945412125, 0.10765150096267462, 0.11223157841180052, 0.11250535372112479, 0.09004207194915839, 0.12312407392476286, 0.17289662600627967, 0.18356270795421942, 0.10568109633667128, 0.12043498536305768, 0.06811751305524792, 0.1378448504422392, 0.12713067393217767, 0.17116607672401837, 0.12306780980101653, 0.10762637481093407, 0.10461434429245335, 0.23264615344149725, 0.14278086700609752, 0.14913013630679675, 0.06990083879125969, 0.12762942431228502, 0.17336423162903103], [0.04904925071501306, 0.034845246467739344, 0.012468164088204503, 0.02852282001237784, 0.02909535089773791, 0.03232583576547248, 0.011202866760348635, 0.04482204879501036, 0.04448208239461694, 0.01921117877853768, 0.07079616574836628, 0.06140211982918637, 0.034409114691827974, 0.05973204158778701, 0.02435770065390638, 0.04745157555277858, 0.03147325312186565, 0.045982587949505875, 0.027916253810482364, 0.029783497364925485, 0.019079797435551882, 0.019629203847476413, 0.06851304468831845, 0.011912842547254903, 0.030949576757848263, 0.04839771460475666, 0.03717259783297777, 0.04162744485906192, 0.007599615109419184, 0.051498687493481805, 0.017652434562998157, 0.05112003781167524, 0.08125595947993652, 0.04573740271319236, 0.04308623747367944, 0.04016638933015721, 0.02194094212193574, 0.010463767402273203, 0.03739100129210523, 0.040109619697821994, 0.08698694088629313, 0.015517705718853643, 0.05059911629983357, 0.061577643267810345, 0.058035771894667826, 0.04728959228045174, 0.001315765914374164, 0.03510276747069188, 0.027709307415144782, 0.034649007354996035, 0.05641873134300113, 0.01400297213279243, 0.02252032621098416, 0.2058709037623235, 3.434719945703234, 15.324712310518537, 28.001942089625768, 39.16353178024292, 43.44979906082153, 33.01506042480469, 32.41961022785732, 31.825820650373185, 23.27747450556074, 12.373749835150582, 21.126861129488262, 18.43517415864127, 16.394015754972184, 21.278321436473302, 13.15317269733974, 7.690766470772879, 4.354176368032183, 1.9100686950342995, 0.6657303028873035, 0.3669545607907431, 0.39224787641848835, 0.42677637934684753, 0.3125103765300342, 0.7733337432146072, 0.1749579475394317, 0.4299412023808275, 1.186121444616999, 0.9445105407919202, 2.155041767018182, 0.5427530503698758, 1.3016849692378725, 1.8240193809781755, 2.5035764362130846, 2.995855437857764, 1.3624670505523682, 0.847648526941027, 0.5082212090492249, 0.10720780012863022, 1.1493112998349326, 1.0903876445123126, 1.056813080395971, 1.2384123929909296, 1.5445423147508075, 1.4979054629802704, 2.5209256538322995, 0.6466945729085377, 8.931349090167455, 6.5664754169327875, 3.8875027809824263, 3.536080918141774, 1.6977247978959764, 1.1996920364243644, 0.7572455150740487, 0.6095403294478143, 1.2236470367227281, 0.9995154121092388, 0.9119499794074467, 0.20101760061723845, 0.2608221029596669, 1.111568576523236, 1.8210918009281158, 4.566619711262839, 6.303483494690486, 7.243990353175572, 7.182329433304923, 18.68558202471052, 22.71076900618417, 14.518139362335205, 25.47970257486616, 31.111990519932338, 29.036794628415787, 32.227384839739116, 28.06377237183707, 14.642543384007045, 2.3406572469643185, 0.20143738309187548, 0.04559443538476314, 0.017301793110423853, 0.029473305081150362, 0.023940113240054677, 0.0816707479368363, 0.05838673056236335, 0.06354823109826871, 0.040189537552318404, 0.048879661065127165, 0.03206511546990701, 0.006922924009683941, 0.01003759227959173, 0.06325741777462618, 0.03517149628273078, 0.020715855627453754, 0.02835941012017429, 0.03555133679349508, 0.052386825372065814, 0.026220951029764752, 0.0445259327201971, 0.017141512960993817, 0.026939441582986286, 0.06230765873832362, 0.01775387385194855, 0.0415475303972406, 0.027691126069320098, 0.08554573250668389, 0.018642927752807736, 0.03910094007317509, 0.03217559793431844, 0.037667904647865465, 0.0037536463933065534, 0.0570846354322774, 0.02082019904628396, 0.04089507826470903, 0.047813665587455034, 0.04909323335492185, 0.02182768953831068, 0.03459498578948634, 0.033963429142854044, 0.032531625258603265, 0.017362332004787664, 0.07249858975410461, 0.024462186565090503, 0.044766761761690886, 0.015584195365331002, 0.028033871070614884, 0.11079240563724722, 0.030229009887469665, 0.020965283403971365, 0.030972684267908335, 0.026184432275061096, 0.0257987953789, 0.020332081309918846, 0.06037501458610807, 0.014620044601282902, 0.028105107069547688, 0.018149946616696458, 0.015687220729887486, 0.0632720673456788, 0.018886957783252, 0.04308576589184148, 0.03850309983161943, 0.04146366007626057, 0.024979798522378718, 0.043003344243126254, 0.01837464688079698, 0.13439262711576053, 0.04484330051179443, 0.037076876897897036, 0.045757870722029886, 0.011637975644719387, 0.03599266614764929, 0.03464236788983856, 0.02739099645987153, 0.0530997146187084, 0.035007090640387366, 0.031346105837396214, 0.039803359524479935, 0.05239806191197463, 0.054900027478912046, 0.06385343614965677, 0.016343852638133934, 0.03322714740144355, 0.030482748057693243, 0.04705527038978679, 0.039455077677432976, 0.03210463674206819, 0.010971858665081007, 0.021287689318082163, 0.050135951688779254, 0.014737538028774517, 0.06515222002885171, 0.034908370580524206, 0.02769075457139739, 0.06263980162995202, 0.039942170825919936, 0.07343616908682243, 0.0411183977100466, 0.4434864712612969, 5.124984332493373, 19.432600225721085, 32.672538552965435, 41.92842149734497, 46.290691648210796, 37.13169091088431, 35.12327241897583, 29.940371377127512, 21.635212182998657, 15.477447611945015, 23.83530020713806, 24.608525276184082, 19.194699117115565, 19.95115123476301, 15.48526086126055, 8.207906126976013, 4.011564603873661, 2.3044732000146593, 0.8976775652595929, 0.28123726748994415, 0.18893979942159994, 0.16030739939638547, 0.0724883506606732, 0.357089638710022, 0.31904564585004536, 0.7637080454400608, 0.7529438744698251, 0.7816039994359016, 1.3182822614908218, 2.4270124988896504, 1.3188590705394745, 2.4053862307752882, 1.8312072924205234, 0.9637118875980377, 1.4065401256084442, 2.132555659328188, 0.5912218924079622, 1.633728306208338, 1.50074716763837, 1.879338983978544, 2.387670712811606, 3.3820836501462117, 2.086143429790224, 1.1059427069766181, 1.7693161049059458, 0.6196435530270848, 10.786796041897365, 10.26283151762826, 5.781617326395852, 2.2789357474872043, 1.6578170593295778, 1.1203298206840242, 1.4413145567689623, 1.0782703118664878, 0.6197840912001473, 0.7724993079900742, 0.2727888822555542, 0.20833294093608856, 0.2107180186680385, 0.8777186476758548, 1.7068097846848624, 5.478989839553833, 6.549715059144156, 9.979561277798243, 14.726972682135445, 22.941551685333252, 19.710627181189402, 14.780772583825247, 27.4480299609048, 38.39411953517369, 31.671522004263743, 33.60513619014195, 32.142919063568115, 16.6000246320452, 3.490126835448401, 0.2696089686027595, 0.010992571794694024, 0.030481329919504266, 0.021762802930814878, 0.08035774874900069, 0.07815109180020434, 0.060631154770297666, 0.06800966669938394, 0.02739452993098114, 0.044895021843590906, 0.04072346318779247, 0.030133886063205342, 0.023387588959719454, 0.056293327893529616, 0.06057005947721856, 0.06373452967298882, 0.022301016907606806, 0.00993387056847236, 0.03626692321683679, 0.03415958004604493, 0.049332461053771634, 0.017358547475721155, 0.012877598903807146, 0.014740771248138376, 0.011181457284172731, 0.04000806675425597, 0.014597373049972313, 0.02546033532624798, 0.018625165402357067, 0.03738230586584125, 0.02900240517088345, 0.06014723716569798, 0.023732844540583234, 0.06957829717014517, 0.07518623982157026, 0.018603905203885267, 0.008900925683389817, 0.035660302732139826, 0.01731553514088903, 0.008870869974738784, 0.023732875074659075, 0.03656202827447227, 0.03170331720528858, 0.025162392295897007, 0.05155364204464214, 0.03270895020770175, 0.04046380140685609, 0.13502648738878115, 0.13981325338993753, 0.07830026093870401, 0.08254693342106682, 0.08523459705923285, 0.137083981984428, 0.10300774978739874, 0.08823297545313835, 0.15236123864139828, 0.10841766199363129, 0.1317680808050292, 0.12743165849574975, 0.10521608271769115, 0.17622675374150276, 0.0866467844960945, 0.15679519357425825, 0.16208084566252573, 0.07131629676691123, 0.07222974739436593, 0.1123246123482074, 0.12707811460963317, 0.2042230407574347, 0.15136335790157318, 0.12252716666885785, 0.09808985010853835, 0.10915271219398294, 0.10976609428014074, 0.12317011931112834, 0.11312055428113256, 0.14337143674492836, 0.10011362829910857, 0.17007712301399025, 0.13021984031157835, 0.10471100839121, 0.10775033637349095, 0.10747036603944642, 0.10682366788387299, 0.12410060795290129, 0.08908981590398721, 0.14333864993282727, 0.19448116421699524, 0.18253373673983983, 0.15771345501499517, 0.13625971121447428, 0.10762904145355735, 0.07794817590287753, 0.11529008857905865, 0.12447822626147952, 0.07519098278135061, 0.09170435382319347, 0.20594859602195875, 0.15842128917574883, 0.2357011895094599, 0.8453147464564869, 5.790878840855189, 20.62028012956892, 37.12418685640608, 49.024675777980256, 54.9150458744594, 44.60836948667254, 42.18247195652553, 41.79352569580078, 33.79362692151751, 18.90845591681344, 33.801221302577424, 27.144697666168213, 23.24924397468567, 26.68759478841509, 16.88836097717285, 10.689813954489571, 6.033480405807495, 2.659298594508852, 1.461490388427462, 0.9255486897059849, 0.8205584777253014, 1.0773171058722903, 0.6745012636695589, 1.4915706600461687, 2.38486733181136, 2.429681258542197, 2.811065925019128, 4.98333705323083, 6.4499610747609815, 4.965347298554011, 5.424335743699755, 7.624424202101571, 7.089090687888009, 8.595181345939636, 6.152153900691441, 3.0986403567450385, 2.1670884234564642, 3.0123261426176344, 4.028689307825906, 3.4107421466282437, 3.1057681228433336, 4.6811863865171155, 5.858500446592059, 3.1909771391323636, 4.463715587343488, 1.759174883365631, 18.75112090791975, 15.198892593383789, 8.713438817432948, 10.879605736051287, 7.001820879323142, 6.738244874136789, 4.898219014917101, 4.581677760396685, 2.845754372222083, 2.60635375550815, 1.4987380525895526, 0.7638878843614033, 0.8220785047326769, 1.5930586542401994, 2.6883529211793626, 6.297468091760363, 9.114571349961416, 11.359506521906171, 13.733524458748953, 27.28681090899876, 30.054005690983363, 21.906765154429845, 34.86332988739014, 41.81062173843384, 36.96001134599958, 40.33540800639561, 37.22810411453247, 19.715174777167185, 4.017659042562757, 0.3647171322788511, 0.1897519922682217, 0.10051578243396112, 0.12854327527540071, 0.0995291993021965, 0.20634195634296962, 0.11521416051047188, 0.12963712800826344, 0.14698797411152295, 0.10961986319827181, 0.1003229563523616, 0.08576480432280473, 0.15577285843236105, 0.20051131849842413, 0.13887701077120645, 0.18147885905844824, 0.0992275837010571, 0.08512101708246128, 0.16973018805895532, 0.0851291391466345, 0.09255229189459767, 0.06331507968051092, 0.06068054533430508, 0.11813495521034513, 0.15410359443298408, 0.2191261396344219, 0.09790781951908555, 0.12871436109500273, 0.1182355819536107, 0.10140686854720116, 0.12181437920246806, 0.23904916271567345, 0.12697727073516163, 0.1068969564512372, 0.1358837756727423, 0.12171608661966664, 0.1670189249728407, 0.1542369265641485, 0.09747313641543899, 0.11654634188328471, 0.1637591477483511, 0.1257612138454403, 0.13797632338745253, 0.14472771968160356, 0.12098923990769045, 0.0935893716024501, 0.18184281167175087], [0.05845541866230113, 0.06845819191741091, 0.012054726764160608, 0.027209856447630694, 0.03969807803098645, 0.029743599505828958, 0.043460558102067025, 0.010584276069753935, 0.0297450854975198, 0.046728009557617564, 0.040813097663755925, 0.026356881950050592, 0.023306972214153836, 0.061894152712609084, 0.0511923017911613, 0.05262904201767274, 0.03584149193816951, 0.046986938520733795, 0.0315668061375618, 0.04830667895397969, 0.03652334499305912, 0.01885079695577068, 0.026552547700703144, 0.02079743080373321, 0.027191050849588852, 0.10624023633343832, 0.015876827162823508, 0.015529854888362544, 0.04972099020544972, 0.05168919637799263, 0.05412303702905774, 0.019232328715068952, 0.06287227451269116, 0.00965875175981117, 0.018438320606946945, 0.05728748347610235, 0.03162104144160237, 0.029052752469267164, 0.037478433921933174, 0.07747974246740341, 0.035122139645474296, 0.018665704477046217, 0.035484823398292065, 0.06355986797383853, 0.0305708761859153, 0.06611835211515427, 0.01708943539831255, 0.06397973865802799, 0.02972188638523221, 0.07856733232204403, 0.008652348620151835, 0.07441533583083323, 0.04161149589344859, 0.050943727272429636, 0.1146648321300745, 2.6285838655063083, 10.064972877502441, 23.80226673398699, 32.98022910526821, 38.90503099986485, 35.7759028162275, 32.476571559906006, 28.59898689814976, 22.48844575881958, 21.611907924924576, 21.60278841427394, 22.087638923100062, 19.31977711405073, 22.756328344345093, 16.941710983003887, 11.135817084993635, 7.017028748989105, 3.7228960480008806, 3.1158445307186673, 1.2411100310938699, 0.46030963425125393, 0.44619162753224373, 0.20324581462357724, 0.23286532025252069, 0.2627922700984137, 0.4803805372544697, 0.3382295678768839, 0.20410002235855373, 1.2237919718027115, 0.4453030452132225, 0.7145995891519955, 1.2529385792357581, 0.4934936878936631, 0.6848965830036572, 2.7295481392315457, 0.7469620183110237, 0.7753510549664497, 0.3769295683928898, 0.5218884785260473, 2.2253614451204027, 3.098191112279892, 0.9091208140764917, 0.8034128748944828, 1.3558930775948932, 1.0878301646028246, 5.573798443589892, 4.4850782581738065, 1.4406919330358505, 2.407322172607694, 0.4745783028858048, 0.4046656915119716, 1.0894557173763002, 0.10533633269369602, 1.142374066369874, 0.3043523228594235, 0.5423929382647786, 0.7192497796245984, 1.6897815955536706, 2.7209074028900693, 6.165620812347957, 8.302914925983973, 10.39945307799748, 13.230636426380702, 17.64632432801383, 12.130964142935616, 12.434194820267813, 13.18055728503636, 23.204038994652883, 28.577404056276592, 27.31895501273019, 26.901368277413503, 15.249505008969988, 3.4218019417354038, 0.17946892976760864, 0.041020122090620656, 0.0036225105951806264, 0.03970754698717168, 0.020034886364425932, 0.04715621604451111, 0.03504790791443416, 0.03017184670482363, 0.02099912364168891, 0.04268771689385176, 0.060034138948789666, 0.05140329904056021, 0.041582597087004354, 0.05542493877666337, 0.08026046718337707, 0.026440083914037262, 0.03695706457697919, 0.04621452818225537, 0.01918450217427952, 0.05120371475017496, 0.05252446620059865, 0.018232914486101696, 0.04700099776632019, 0.05778514141482966, 0.014394979624609863, 0.04817718393834574, 0.03768319543451071, 0.029784111439117363, 0.03479216467323048, 0.02390035448063697, 0.0669876504689455, 0.03044911307681884, 0.01490368411344077, 0.024237462552264333, 0.04145429629300322, 0.03911471772672875, 0.05388550566775458, 0.05434609523841313, 0.046956014287258895, 0.03361538817573871, 0.029097759697054113, 0.06112143024802208, 0.06050376660589661, 0.049401474850518365, 0.03223327001822846, 0.06734947248228959, 0.017482600640505552, 0.04203448444604874, 0.026366057439840267, 0.04427726999191301, 0.029519744017826657, 0.031079892800854783, 0.05948905819760902, 0.03856484651831644, 0.047591716782855134, 0.010811490306098546, 0.024053447247881974, 0.023931602714583278, 0.014578586111643484, 0.08321919199079275, 0.03451652678528002, 0.018084605390738164, 0.1010420677651252, 0.06349974298583609, 0.008696343134423452, 0.007576358321655009, 0.03453142062893935, 0.011895874082776052, 0.04858487831162555, 0.026797217250402485, 0.010809074721432157, 0.06046015037489789, 0.05394054503579225, 0.046598738458539755, 0.012113040911832025, 0.05423416070906179, 0.02660986016105328, 0.006452826042992196, 0.01371098663990519, 0.03320323243471129, 0.028488594706037214, 0.048868811290178976, 0.07375980993466717, 0.032331080841166634, 0.047425465525260994, 0.0391706663316914, 0.044886248385799785, 0.03497396795345204, 0.07221049057053668, 0.054209584170686345, 0.07025314095829215, 0.03813660271199686, 0.013622959443767155, 0.02863532111846975, 0.031933279508458715, 0.03970137571117707, 0.03653001838496753, 0.006427955190052411, 0.03196854975872806, 0.04439621718068208, 0.05068895433630262, 0.017754744073109965, 0.12788942536073072, 4.591334019388471, 13.610445805958339, 31.167989526476177, 39.95437226976667, 43.388779980795725, 38.6459014075143, 36.558916160038535, 30.62124272755214, 17.971140452793666, 22.24914285114833, 19.70014234951564, 24.754998513630458, 23.466463770185197, 22.854266677583965, 22.39555355480739, 13.244116800171987, 7.416586211749485, 4.549696505069733, 2.70901295542717, 0.9846920818090439, 0.46376674302986687, 0.11735706909426621, 0.06062382659209626, 0.16937462213848317, 0.32174781656691004, 0.09046690950968436, 0.38758631369897295, 0.5390763676592282, 0.8776569281305585, 1.09113381590162, 1.7935938707419803, 2.5359313743455068, 0.49321136304310387, 1.1020251171929496, 0.9970765944038118, 0.640035864497934, 0.22302171774208546, 1.8341311812400818, 2.894943492753165, 1.7388303407600947, 1.7872809980596815, 0.58951350407941, 0.3480862118303776, 0.8955533706716129, 0.8497887892382485, 7.017610660621098, 4.329811641148158, 2.0165374619620184, 1.235804321510451, 1.4177920818328857, 0.673291408589908, 0.4322772356016295, 0.25365433043667246, 0.3377322017082146, 0.18595913079168114, 0.23833580527986797, 0.40964887983032633, 1.5455867158515113, 3.052327790430614, 6.85003878389086, 10.637671198163714, 14.107481718063354, 15.283936807087489, 14.312524795532227, 15.562163523265294, 14.758197886603218, 16.001690932682582, 26.615943227495464, 32.76647472381592, 31.49982159478324, 32.462807178497314, 19.10297073636736, 4.946474688393729, 0.21177919315440313, 0.03513254837266036, 0.0014375664489177454, 0.03455721174499818, 0.05230714839750102, 0.01767951828826751, 0.04175398824736476, 0.04435261791305883, 0.014558377642450588, 0.07105062995105982, 0.04441809993503349, 0.08110945019870996, 0.028432917515082017, 0.10478525369295053, 0.04654581951243537, 0.0358147915851857, 0.0460442735680512, 0.03167227083551032, 0.02853616001084447, 0.029887720343789885, 0.05083931769643511, 0.0065348443874557105, 0.03736015848283257, 0.029807103598224263, 0.02666151533568544, 0.015437994817537921, 0.06669794994273356, 0.044303091642047675, 0.07083868953798499, 0.05071412120014429, 0.028789691227887357, 0.02786959265358746, 0.013897971383162906, 0.06209461231316839, 0.054404235511486015, 0.027767602054934417, 0.019915766149227108, 0.015460878411041839, 0.047112976400447745, 0.10985532163509301, 0.03716879464419825, 0.04127751417191965, 0.09818200873477118, 0.030835711796368872, 0.04638779888461743, 0.049544784839132, 0.04388487319062863, 0.011166860299584056, 0.18271487844841822, 0.19735988974571228, 0.20140712043004377, 0.14896286385399954, 0.16737455874681473, 0.10782152826764754, 0.17197430692613125, 0.15092190301844052, 0.15234726082001412, 0.16800632913197788, 0.1137312493686165, 0.14543537742325238, 0.07756423364792552, 0.12790873646736145, 0.10987700082893882, 0.14393217808433942, 0.1511606794915029, 0.13714860565960407, 0.14932653148259434, 0.17563998379877635, 0.07676761996533189, 0.07275291824979441, 0.09568086758788143, 0.1606604547372886, 0.15027432276734284, 0.15103193425706454, 0.10101762693375349, 0.09075017073856932, 0.09851419912385088, 0.1359110934925931, 0.16838613232331617, 0.12446654188845839, 0.16274827984826906, 0.21897007658013276, 0.18616377695330552, 0.06858087104878255, 0.1276014686695167, 0.11486787694905486, 0.19370186674807752, 0.14705238065549306, 0.1107039111001151, 0.16434502202485288, 0.09717817724283252, 0.1521849145314523, 0.09386133522327457, 0.23986079916357994, 0.12700141301112516, 0.08565812504717282, 0.08556644139545304, 0.13608601982040064, 0.10976412652858666, 0.13301684308264936, 0.1253231516374009, 0.12911211832293443, 0.3419693000614643, 5.091564800058093, 15.162881817136492, 33.29162652151925, 46.940528869628906, 52.45483466557094, 46.754907744271414, 43.640520163944785, 37.307931968144004, 31.649704660688126, 31.28653621673584, 32.02176679883684, 32.49756554194859, 30.970202105385916, 31.17652886254447, 24.386539016451152, 14.745956897735596, 10.731190477098737, 5.235405104500907, 4.399707479136331, 1.62460358440876, 1.0512855712856566, 0.5934135062353951, 0.47677398792334963, 0.8171497892056192, 0.7285055401069778, 1.7614244712250573, 1.5015545700277602, 1.657342084816524, 3.8887365204947333, 1.8329289257526398, 3.8665326833724976, 3.576445826462337, 2.2946317281041826, 2.3565736157553534, 7.322404248373849, 2.7806371578148434, 3.4187236726284027, 2.8943746089935303, 4.965587445667811, 6.091411880084446, 7.31949816431318, 4.049388859953199, 2.1905637809208462, 4.21569573027747, 3.235181361436844, 9.716457315853663, 11.135787555149623, 5.020052637372698, 4.851037706647601, 4.2436904566628595, 2.655721140759332, 3.4438268627439226, 1.2348588236740656, 1.7319605265344893, 0.8402794195072991, 0.8102927857211658, 1.007488687123571, 2.3799206486770084, 4.12884715625218, 9.338054946490697, 12.3310592344829, 16.594811746052333, 20.352258580071585, 24.860182080950054, 21.25279549189976, 19.863737685339792, 20.538022143500193, 33.85192230769566, 38.71361855098179, 37.904268060411724, 35.725691659109934, 20.597985097340175, 5.3189350451741895, 0.39637521494712147, 0.12931939720043115, 0.11946435458958149, 0.19650208577513695, 0.17014950912977966, 0.11887263134121895, 0.11955138349107333, 0.21985251137188502, 0.17142037807830743, 0.26516480850321905, 0.18633795689259255, 0.1395298700247492, 0.12553342963968003, 0.24421444269163267, 0.23557443916797638, 0.16697939352265426, 0.11591906339994498, 0.22063271807772772, 0.12111476888614041, 0.13170598128012248, 0.21095516665705613, 0.1241301242262125, 0.14816091688615934, 0.08307216023760182, 0.08206336186932665, 0.18007232381829194, 0.22945809736847878, 0.12786260965679372, 0.20535438933542796, 0.08683928488088505, 0.1534215853150402, 0.0877616989559361, 0.12162527149277073, 0.2507383126233305, 0.12138346875352518, 0.17050974337118013, 0.10723593897585358, 0.1356800930308444, 0.12656347293938908, 0.26505998841353823, 0.10286657379141875, 0.16273662261664867, 0.2251169253140688, 0.11616979566003595, 0.09461720287799835, 0.18046637624502182, 0.09601613174059562, 0.11883585474320821], [0.03420203598216176, 0.03977312061137386, 0.038842652325651476, 0.05610912599201713, 0.05280206844742809, 0.02152803659971271, 0.014093064619893474, 0.024662386626005173, 0.029551407854471887, 0.024677707946726253, 0.028361796867102385, 0.04472421422334654, 0.00737664765412254, 0.053633881134114096, 0.0329384511070592, 0.03063279589904206, 0.03424710427810039, 0.03639539364459259, 0.09173220090035882, 0.028503922812108482, 0.028587321551250558, 0.04219335663531508, 0.015840886859223247, 0.04530412078435932, 0.03100489093256848, 0.041429757074053795, 0.03501284122467041, 0.07477394158818892, 0.03153117626373257, 0.030587642786226103, 0.016362033983958617, 0.08161681118820395, 0.029077512212097645, 0.00332276923498804, 0.025105497134583335, 0.02190906454675964, 0.021362591102453213, 0.03127815394795366, 0.013251324965884643, 0.11800958908029965, 0.03626755425440414, 0.07758168556860515, 0.045639954906489165, 0.033404350214238675, 0.05343346224565591, 0.025061436463147402, 0.04595170782080718, 0.020617876867098466, 0.032444257089602094, 0.02694717009684869, 0.06138517002442053, 0.06428207350628716, 0.032334164782826386, 0.01754116839064019, 0.0598008246826274, 0.154382960870862, 1.632058675800051, 6.68549154485975, 20.443799359457834, 31.6202130317688, 36.159922804151265, 36.54296309607369, 29.41980539049421, 26.93957989556449, 17.65457705089024, 24.68300822802952, 13.793756655284337, 18.166848625455582, 29.45160034724644, 25.601711205073766, 23.15011055128915, 21.407069819314138, 11.718737942831856, 9.722750646727425, 6.570914013045175, 4.046410254069737, 2.132508324725287, 0.7955835035869053, 0.1806857194751501, 0.2464191929570266, 0.16357145139149257, 0.4107567918087755, 0.6320142235074724, 1.0539627990552356, 0.32010071352124214, 1.3076151481696536, 1.9605547402586256, 0.787452754165445, 1.2234436933483397, 0.7334519518273217, 0.42184340261987274, 0.2946999450879437, 1.1785023105995995, 2.1821799107960294, 1.5617995773042952, 1.2713597736188342, 0.7931570623602185, 10.816926905087062, 2.2634360534804205, 0.6114130318164825, 0.832454499389444, 0.5996657993112291, 2.1185669813837325, 0.24312707675354822, 0.7944115921854973, 0.3482028384293829, 0.13148882293275424, 0.3621076765869345, 0.4460872688463756, 0.5490308563624109, 1.3148826381989887, 3.26037466100284, 4.817349365779331, 9.625470655305044, 10.487671749932424, 15.635588611875262, 17.613659109388077, 10.157459480421883, 14.963907991136823, 20.267787592751638, 18.462322507585796, 23.747834546225413, 32.19821630205427, 28.96730395725795, 23.716216768537247, 12.795353497777667, 4.256419122219086, 0.20203411392867565, 0.03844228952324816, 0.010844875925353594, 0.008579800504126718, 0.04111230107290404, 0.014728330308571458, 0.019794652737411003, 0.05394804284774831, 0.035180843102612665, 0.03468254055561764, 0.04707253910601139, 0.055056870848472626, 0.03510168181466205, 0.04701816809496709, 0.023746320246053592, 0.04817182011902332, 0.036920610283102305, 0.011488879448734224, 0.07867184707096644, 0.06183843141687768, 0.04406472568267158, 0.029332207116697515, 0.03629261933799301, 0.07365509162523917, 0.03465962642803788, 0.059568670711347034, 0.02940306652869497, 0.027229459324319447, 0.009971689565905502, 0.055707294161298444, 0.01782715563396258, 0.04283941357529589, 0.0762120626334633, 0.016789953789806793, 0.025416993901931813, 0.038579774288726706, 0.0771966033748218, 0.04224502368431006, 0.055719246555651934, 0.036425998966608725, 0.012468661963274437, 0.026587424400661672, 0.017085942639304057, 0.038371426718575616, 0.021397176032353724, 0.04909806452425463, 0.010399824806622096, 0.04497594732259001, 0.013372743718459137, 0.04773397504218987, 0.06415963864752225, 0.041006517463496754, 0.07990895890231643, 0.08542488541986261, 0.032594589915658743, 0.023502904289801205, 0.027703202296314493, 0.03927682652803404, 0.024642444481807094, 0.08179975101458174, 0.031217235073979412, 0.018903904195342745, 0.03414179564320615, 0.004350660518477005, 0.016540939919650555, 0.01262345870158502, 0.04423869866877794, 0.03169424179941416, 0.025887887026848536, 0.047236351030213494, 0.049562399608216116, 0.042330973715122254, 0.050520806573331356, 0.03222243720665574, 0.0171714431406664, 0.033369575294532945, 0.05137013224884868, 0.04428175850106137, 0.013014055688732436, 0.03125796074579869, 0.03566942224279046, 0.08207725826650858, 0.016617515989180123, 0.022055972467309663, 0.022543683082663586, 0.044599387528640885, 0.03334736345069749, 0.031284423611525974, 0.039998197462409735, 0.060031892997877936, 0.014656088381473507, 0.030432278623006175, 0.057098633609712124, 0.026818876088197743, 0.02368692637953375, 0.08723195988152709, 0.11592567233102662, 0.016618438796805482, 0.03148588744391288, 0.0619253721088171, 0.07696444261819124, 0.04721469558509333, 0.052934121540082354, 0.04180188264165606, 0.16130507657570498, 2.584053077868053, 8.516638909067426, 24.10343987601144, 38.38049064363752, 41.437211649758474, 40.98977197919573, 32.143964767456055, 28.342608792441233, 20.669162443705968, 25.15445739882333, 18.53151614325387, 24.564412900379725, 32.01592336382185, 30.703957557678223, 24.644310235977173, 23.754273789269583, 12.794181857790266, 10.831059541021075, 6.552304565906525, 3.62778063757079, 1.8596458349909102, 0.8104330524802208, 0.20102697797119617, 0.20337590335735253, 0.07620460553360836, 0.06997023256761686, 0.1730132254638842, 0.0587715142007385, 0.41921065960611614, 0.8227309840066093, 0.4622212031057903, 0.35716053204877035, 0.21020872385374137, 1.082135898726327, 0.7120377123355865, 0.6783478515488761, 0.5028681105801037, 0.8847932166286877, 1.217308651123728, 0.39242228705968174, 1.2290959443364824, 9.171563948903765, 1.787182746188981, 0.8380786861692155, 0.40953057046447483, 0.5984482360737664, 0.5843600034713745, 0.4454430134168693, 0.17253993371767656, 0.20037434941955976, 0.2349125418279852, 0.22828534458364758, 0.10403010528534651, 0.634645690875394, 1.3142897614410944, 3.1334228217601776, 6.182886217321668, 8.820573091506958, 14.549654654094152, 17.231982401439122, 18.98788251195635, 15.079956804003034, 15.879791736602783, 21.951641832079204, 18.754181589399064, 25.76387173788888, 35.63766145706177, 33.35101624897548, 27.7588107245309, 17.032874822616577, 5.304844098431723, 0.3520580029913357, 0.13500329506184372, 0.0451004042157105, 0.007810557227847832, 0.03732111557785954, 0.024346686334216168, 0.036248972572918446, 0.05590174872694271, 0.04833422747573682, 0.041730419333492, 0.06151038687676191, 0.04044262093624898, 0.05206194280513695, 0.04195490925173674, 0.08706448386822428, 0.08075545847948108, 0.0675281375380499, 0.07324160595557519, 0.010566584965480226, 0.0540109532220023, 0.0197242208024753, 0.06721287659768548, 0.04826907793592129, 0.03155117608340723, 0.019555082378376807, 0.013163542042353323, 0.034164811551038704, 0.03681294373901827, 0.030476190016738007, 0.03637875935861042, 0.03003343234636954, 0.023178401702482785, 0.06439427605697087, 0.01567651005461812, 0.0550693355367652, 0.0387000649768327, 0.032724461518228054, 0.016446230001747608, 0.035142451591257534, 0.06648845904107605, 0.011177759268321097, 0.09312312304973602, 0.029836918426943675, 0.024055167334154248, 0.03077051815177713, 0.01143422260481332, 0.02161805614429925, 0.06267393194139004, 0.04821127014500754, 0.081374302772539, 0.24199313617178372, 0.12967959072973045, 0.1571904673640217, 0.2851920138512339, 0.14951582918209688, 0.19357465500278132, 0.14239874322499546, 0.17235393369836466, 0.11836752987333707, 0.20296312336410793, 0.1089183801252927, 0.0901406698727182, 0.15498788841068745, 0.09067415446043015, 0.12365272055779185, 0.06676312323127474, 0.14406439741807325, 0.17685895838907786, 0.14031105382101877, 0.12502964452973434, 0.1818220077880791, 0.11890621882464204, 0.13310419768095016, 0.17289320618978568, 0.11710153280624322, 0.12607590481638908, 0.14416764330651077, 0.14115679343896254, 0.08629230423165218, 0.07997640528317009, 0.19869380816817284, 0.17374156495290144, 0.12457490393093654, 0.12487515567668847, 0.0724073267940964, 0.1337571790707963, 0.08999591121183974, 0.14011437366051332, 0.17646995426288672, 0.1742920061307294, 0.1448435184678861, 0.23294185900262424, 0.15370821207761765, 0.11903794961316244, 0.09748767742088862, 0.12164116278290749, 0.21560777271432535, 0.09664903527923993, 0.08693776745349169, 0.1512733298752989, 0.16984256702874387, 0.12878308312169143, 0.09792234016848461, 0.13434512966445514, 0.3138695093137877, 2.420430383511952, 10.497304558753967, 26.24831404004778, 42.68203353881836, 47.30368341718401, 48.33380944388253, 40.8909581729344, 37.46829291752407, 28.39570345197405, 36.8949727330889, 23.6798985345023, 27.831537519182476, 40.95565979821341, 35.802688121795654, 30.48415129525321, 29.44841112409319, 16.82642994608198, 13.627590485981532, 8.286659615380422, 5.586375551564353, 2.843099508966718, 1.3624240585735865, 0.6099578727568898, 0.47826090242181507, 0.5068502426147461, 1.0285551909889494, 1.6552928004946028, 1.7677404923098428, 1.9334469948496138, 3.00157185111727, 6.041832140513828, 2.6706784410136084, 3.913974549089159, 2.6780428801264082, 1.1978526094130106, 2.5457661151885986, 3.43629458120891, 5.283763263906751, 4.933734732014792, 3.338462859392166, 3.930406604494367, 15.702822855540685, 4.011377002511706, 2.4433659527982985, 2.364888221025467, 1.0985644800322396, 5.444654447691781, 2.28230453814779, 1.8814260491303034, 1.2844194556985582, 0.7682096638849804, 0.9354305480207715, 0.9615668484142849, 0.9705703024353299, 2.0757497932229723, 4.365586178643363, 6.906350893633706, 13.033055714198522, 16.615185601370676, 22.613478592463903, 25.266957419259207, 18.615664039339336, 23.183668613433838, 31.157247611454554, 26.188033206122263, 34.566224915640696, 43.877015999385286, 40.212529114314485, 32.166483879089355, 18.93623307773045, 6.498116867882865, 0.5442035411085401, 0.20277020228760584, 0.12812098222119467, 0.12732210223163876, 0.12101958399372441, 0.10440070075648171, 0.15940182656049728, 0.19892426580190659, 0.09241352469793387, 0.14879574067890644, 0.17316236746098312, 0.1450630109757185, 0.10490774961986712, 0.13651805663747446, 0.14281689721558774, 0.1364737075886556, 0.24730389405574116, 0.09938283929867403, 0.21953431916024002, 0.09513932200414793, 0.1452651329870735, 0.18548742681741714, 0.1024681923112699, 0.268523421138525, 0.051429992608193836, 0.13139232168240206, 0.1327172155891146, 0.07493885952447142, 0.12097703984805516, 0.12409079633653164, 0.12188035994768143, 0.09100879436092717, 0.14194297125296934, 0.14001851023307868, 0.16667087722037519, 0.20973520140562738, 0.16129915975034237, 0.17618458957544395, 0.12295207886823586, 0.13220766293151037, 0.09076127157147441, 0.15435142256319523, 0.0959990665848766, 0.06858791424227612, 0.13058793198849472, 0.11419008831892695, 0.09754379226693086, 0.14766127083982739, 0.0834720887775932], [0.026775444757991602, 0.03485540413696851, 0.02315960797880377, 0.014871155144646764, 0.01766796114056238, 0.02787924651056528, 0.005468317532047097, 0.10864540548729044, 0.04243677428790501, 0.03060856880620122, 0.03674301052732127, 0.04182612330519727, 0.07327622481222663, 0.037447533437183926, 0.025059124355071356, 0.026897051804033772, 0.062761001554983, 0.011528247202347432, 0.04622111675728645, 0.05797556548246315, 0.03782028325700334, 0.10139732834483896, 0.030065829000834907, 0.05246777120711548, 0.007738612159820539, 0.04350598941424063, 0.048684354938034496, 0.017617016731362258, 0.06318971355046545, 0.046040952139134915, 0.04199615739552038, 0.039540033654442856, 0.05690472526475787, 0.026364181290513704, 0.05444458120369485, 0.014174769565995251, 0.03429284432370748, 0.03080960176885128, 0.053809876154576025, 0.08929917109864098, 0.020771307205515246, 0.02967780196507062, 0.04796118588585939, 0.013712096044660678, 0.0035175972069347544, 0.027225016616284847, 0.02810337850158768, 0.011603318620473146, 0.03306379348837903, 0.030851192572819333, 0.027481553743460348, 0.04389641507129584, 0.02913472628487008, 0.007393253950535187, 0.08950500469654799, 0.03873533183442695, 0.09897964700524296, 1.0861346955810274, 5.3627208556447705, 15.503550257001605, 27.278504337583268, 38.68785810470581, 41.560660294124055, 39.148923192705425, 29.17723682948521, 20.715493031910487, 15.680586882999965, 22.808830669948033, 41.61668014526367, 26.4506699017116, 26.86314102581569, 20.47759018625532, 23.110578775405884, 18.01979000227792, 18.64496111869812, 11.339988163539342, 8.37212940624782, 4.870384965624128, 3.1001372592789784, 1.5248104078429086, 1.0553424507379532, 0.4370826748864991, 0.4398172252944538, 0.2438951783946582, 0.4592278323003224, 0.5934994901929582, 0.21042983127491816, 0.12271742788808686, 0.34435929038694923, 0.654400993670736, 0.13407581911555358, 0.089682821583535, 0.3318937064281532, 0.6182444138186318, 0.5422804643000875, 0.5069796528135027, 0.7858313268848828, 4.869677986417498, 1.2928001774208886, 0.5515096262097359, 0.6349849583847182, 0.9150562584400177, 0.2579817825130054, 0.01987647218629718, 0.15618476990078176, 0.4486927347523825, 0.7608640609042985, 1.1930960246494837, 1.8433093173163277, 4.205084962504251, 6.1612043636185785, 8.528559412275042, 11.868927597999573, 9.72982564994267, 11.184056690761022, 15.320849112101964, 18.165960993085587, 14.854633671896798, 15.331300939832415, 27.59854531288147, 29.14475052697318, 33.47461427961077, 30.71375104359218, 22.8041284765516, 12.539401837757655, 4.769888826778956, 0.4794060524020876, 0.0519176353700459, 0.02936828482363905, 0.05278742226905056, 0.03408615916435208, 0.016569594453488077, 0.0205583947910262, 0.047562197116868835, 0.006455250109346318, 0.037712728671197376, 0.02123831062843757, 0.05258250130074365, 0.046842722687870264, 0.014365482011011668, 0.019998454122937152, 0.0846091438350933, 0.045994014479219913, 0.05407703235479338, 0.0645310687167304, 0.02123000196713422, 0.0196136229871107, 0.017719692650384138, 0.03521449504686253, 0.034832751245370934, 0.039111589680292776, 0.048390959788646014, 0.05288373692227261, 0.03603422302486641, 0.007715926189640803, 0.045391594126288376, 0.03333243568028722, 0.03842433887932982, 0.02171854718056108, 0.01406388676592282, 0.05470494866105063, 0.08720850292593241, 0.046545405606073995, 0.023928525558273708, 0.026113510098574415, 0.04313861359176891, 0.048446056832160266, 0.0665782427947436, 0.03720160520502499, 0.0020622373433850172, 0.04872480919584632, 0.0414584217859166, 0.00937641757939543, 0.002752322512346187, 0.05735583909388099, 0.027926823689735362, 0.010961835854686797, 0.02674270883601691, 0.01912813457394285, 0.05338339993198003, 0.05323513324505516, 0.09576718402760369, 0.017622640090329305, 0.005257247764218066, 0.05380302295088768, 0.010521475109271705, 0.010721144216534282, 0.014959305325256926, 0.04531314869278243, 0.030322427196162086, 0.007287796037936849, 0.027748565754986236, 0.03306360010589872, 0.008122432278469205, 0.01800360357654946, 0.07512975178126778, 0.021436702393527542, 0.04150120002616729, 0.06621152175856487, 0.007324567546934954, 0.0014759329392940604, 0.03074815703023757, 0.03845990429233227, 0.0369525930312063, 0.0730699569519077, 0.06171066327286618, 0.04274146704535399, 0.01330696398924504, 0.05959402756499393, 0.03554958278047187, 0.01887789085906531, 0.027849182320226516, 0.030567385123244355, 0.0060121493547090465, 0.020508831200589026, 0.042297728891883574, 0.06551446273390736, 0.02452260671582605, 0.030546184296586683, 0.040020531442548544, 0.0361760538071394, 0.038892765529453754, 0.07832460677517311, 0.02055611152068845, 0.06857931041823966, 0.022380413986476402, 0.033467230054416826, 0.044434608692037206, 0.023992776039189527, 0.02793875742437584, 0.0366242160089314, 0.1052389493478196, 0.051842382443802695, 1.5998087206057139, 8.453352979251317, 18.888783829552786, 31.791833536965505, 43.183446816035676, 44.03242635726929, 41.29075057165963, 30.883860315595353, 25.922922951834543, 16.981572798320226, 27.40881085395813, 44.727478981018066, 30.197406087602886, 33.32232713699341, 29.177796159471782, 29.340467384883336, 21.276018108640397, 19.71639244897025, 14.372658848762512, 9.366065740585327, 4.872062955583845, 2.938103748219354, 1.0145952829292841, 0.9174159318208694, 0.2837138388838087, 0.3126895640577589, 0.10727741103619337, 0.07151534501463175, 0.18666845772947582, 0.18367860173540457, 0.055546952943716726, 0.33247958070465494, 0.1496813374438456, 0.29976808599063326, 0.15522429001118454, 0.5431017088038581, 0.21748200857213565, 0.22152301030499594, 0.5059629902243614, 0.9503588612590517, 7.567317826407296, 2.275452962943486, 0.3180782449032579, 0.6199642558182988, 0.6128053313919476, 0.10381891804614238, 0.047898638527840376, 0.12335884704121522, 0.3437562356037753, 0.5379543964351926, 1.4709759822913577, 2.9129434525966644, 3.8281321610723222, 6.586436288697379, 9.733365757124764, 14.715911149978638, 15.114994832447596, 15.42772456577846, 18.844106912612915, 21.41539028712681, 13.981167810303823, 16.76985945020403, 31.357456479753765, 34.64464575903756, 37.77346127373831, 35.776086943490164, 26.865875141961233, 16.030736139842443, 6.276524484157562, 0.7321395565356527, 0.044917729017989974, 0.019610652700066566, 0.03357940885637488, 0.02172755473293364, 0.02185192341650171, 0.022641573633466448, 0.05095165256144745, 0.02933323848992586, 0.06968050490000419, 0.048501937583621056, 0.09173931194735424, 0.037405946025890965, 0.02999937328110848, 0.012917076919360884, 0.034221571005348644, 0.05359900782683066, 0.020551634885902916, 0.007283340607370649, 0.04750395167086806, 0.01776635041460395, 0.01352189843808966, 0.009713814028405716, 0.058797393526349745, 0.03470326301508716, 0.06601684327636446, 0.024009201675653458, 0.030217040529740707, 0.03701400723574417, 0.05289295482050095, 0.03504204537187304, 0.018376831763557026, 0.05328760775072234, 0.013534458121284842, 0.02291243463488562, 0.06016291132462876, 0.021978432878053615, 0.017566864511796405, 0.031113314043198313, 0.014605949732608028, 0.033372849225997925, 0.02691710421017238, 0.024219282902777195, 0.04454656697011419, 0.03836737586451428, 0.04457645304501057, 0.06422541583223002, 0.013297617169363158, 0.031150908275906528, 0.0331291737301009, 0.11755003088286944, 0.18643075334174292, 0.18018022445695742, 0.12508756427892617, 0.1261414105870894, 0.1491712826703276, 0.06701373335506235, 0.2173002968941416, 0.09949985944799014, 0.1534200111137969, 0.08060402303401913, 0.1099617023553167, 0.11989664924996239, 0.191808156935232, 0.1260868970836912, 0.18449569360486098, 0.11001875357968466, 0.0902216462418437, 0.2362487129867077, 0.11698983237147331, 0.08921779439385448, 0.21712211359824451, 0.14754210651985236, 0.09020810946822166, 0.09015532622912101, 0.11232315349791731, 0.23961340529578073, 0.12083770946732589, 0.17719867373151438, 0.10655654900308166, 0.14450735864894731, 0.10491778515279293, 0.15262072400322982, 0.11310650182089635, 0.09269889617072684, 0.12623816968074866, 0.1201549403901611, 0.08707572719348328, 0.10154371548976217, 0.13026366010308266, 0.10212809698922293, 0.07996926030942372, 0.17148562600570066, 0.15777506599468843, 0.14360448638243334, 0.09157406831426279, 0.14903754341815198, 0.10569219038422618, 0.18603231757879257, 0.09306948485651187, 0.13347336144319602, 0.14202740815068993, 0.11924836332244532, 0.14850169074322495, 0.1562504656612873, 0.14031596641455377, 0.2023366048399891, 1.7504694419247764, 8.352787358420235, 20.879067523138865, 35.27644198281424, 49.646591663360596, 52.35852221080235, 50.48681647436959, 39.44362408774239, 32.522961207798545, 24.04760241508484, 31.806059973580496, 52.85081945146833, 38.086105891636436, 36.97615201132638, 31.207496983664377, 33.3696026802063, 24.700045210974558, 23.90830840383257, 15.08641689164298, 11.54502602985927, 7.318776420184544, 4.317931090082441, 2.250768618924277, 1.6845700123480387, 0.8987155609897205, 0.9787640741893223, 0.6316160591585296, 1.4320012565170015, 1.5839060310806548, 0.8824841348188264, 0.2304209385599409, 1.368259242602757, 2.5463745168277194, 1.8804882594517298, 0.861892605466502, 1.8261281592505318, 1.6957495553152901, 1.7591166922024317, 1.6346343947308404, 1.6510095617600848, 6.814219951629639, 2.740914957863944, 1.2011712427650179, 1.5594785532781055, 2.2080569565296173, 1.9446151384285517, 0.7233207726052829, 0.48931847193411415, 0.7912038043141365, 1.245070178593908, 2.1284853177411214, 2.8927743520055498, 6.024650548185621, 8.768692629677908, 12.594849331038338, 16.799830504826136, 16.890403747558594, 18.326120444706508, 24.410956723349436, 27.852206672940934, 22.468591281345912, 23.825560569763184, 38.76500047956194, 40.31116574151175, 43.94934327261788, 40.125475134168354, 30.886896678379603, 17.363669872283936, 7.308496560369219, 1.0498850750071662, 0.20270578217293533, 0.1616733039596251, 0.16071656958333083, 0.13384670498115675, 0.0551982571903084, 0.10827491858175822, 0.233237374573946, 0.0763806514441967, 0.14114597759076528, 0.0793479054367968, 0.16412592306733131, 0.13841640762984753, 0.14648959014032567, 0.06092715210148266, 0.20588900707662106, 0.11787134435560022, 0.16146780284387724, 0.13980838150850364, 0.13172864434974535, 0.09405024615781647, 0.08507284109613725, 0.10322271646665675, 0.09797936425145183, 0.11404328048229218, 0.13678978277104242, 0.14866384704198154, 0.14196836203336716, 0.1380642886672701, 0.1841248335050685, 0.13942985396300042, 0.09027760502483163, 0.16497154054897173, 0.08465399499982595, 0.17100413755646773, 0.13349944432931288, 0.14695602868284496, 0.1084789065644145, 0.1452765730874879, 0.131553107340421, 0.12826884857245854, 0.13137994520366192, 0.06921714690646955, 0.10623935423791409, 0.11046937547091927, 0.12329304271510669, 0.13486491463014058, 0.08608258262808834, 0.10102503653615713, 0.08630217691617352], [0.046813572823469124, 0.05925151665828057, 0.025849412394953624, 0.04219336002799017, 0.06397483284984316, 0.02119351544284395, 0.046457793164466105, 0.026561858897496547, 0.023521558913801397, 0.022960586872484003, 0.0389533349578934, 0.05971249299389975, 0.03354496641882828, 0.010093708821971501, 0.032367185689508915, 0.05296355978186641, 0.014582290912845304, 0.042422755754419735, 0.011313527340202459, 0.032551621685602834, 0.025565990014001727, 0.07704648428729602, 0.02451190452224442, 0.029884595690029006, 0.060839797503181865, 0.03642474028414913, 0.046109107589083057, 0.007112384981675339, 0.03804683252902968, 0.027781087938430052, 0.04570052433492882, 0.01583521600280489, 0.021289188880473375, 0.038081288537276645, 0.007656179484911263, 0.04174561173255954, 0.09051773178258113, 0.061097756161221435, 0.030160715337842703, 0.01179332284456385, 0.010022828205754715, 0.03449025051668286, 0.09957414546183177, 0.06749425828456879, 0.02225462207570672, 0.036076841809387715, 0.028005752579442093, 0.0331842979150159, 0.04267330141738057, 0.07330525254032441, 0.02458323212340474, 0.02603657610182251, 0.05883488937148026, 0.051158656632261615, 0.015137061144092252, 0.04624286719730922, 0.0678656001442245, 0.0622116799599358, 0.31154669395514895, 2.935330114194325, 11.30523761681148, 22.98668197223118, 31.573232786996023, 39.874711172921316, 44.06740706307547, 35.31047773361206, 31.71414225442069, 28.092121022088186, 42.48907511574881, 30.871683597564697, 19.405069725854055, 22.507709639413015, 20.426847491945537, 29.383049419948033, 24.642019067491802, 19.416959830692836, 16.33650725228446, 13.4012850522995, 8.872493505477905, 6.059521819864001, 4.372266437326159, 3.6752014415604726, 2.0478664551462447, 1.3903552740812302, 0.7631081119179726, 0.6650203924093927, 0.3448033237031528, 0.6037445547325271, 0.21209035574325494, 0.2839298572923456, 0.44471440251384464, 0.4414642740573202, 0.3931194410792419, 0.193007318302989, 0.0707025279157928, 0.1883154929216419, 0.14148877348218644, 0.2249766449843134, 0.31586953199335505, 0.32951810104506357, 0.14045434684625693, 0.5413492971232959, 0.31870195429239956, 0.6931418691362653, 1.4983409196138382, 2.8030804906572615, 4.3658497759274075, 6.282997165407453, 9.027036207062856, 10.78822215965816, 11.929525443485804, 14.423953924860273, 19.486396653311594, 18.923966033118113, 21.586255175726755, 12.828086461339678, 20.624819040298462, 28.395286560058594, 26.3645886693682, 24.66451038633074, 26.547718865530832, 23.932380437850952, 17.77426150866917, 11.112418157713753, 3.095845226730619, 0.4439970552921295, 0.026473922455417256, 0.06204543888036694, 0.03513054330168026, 0.03386894992685743, 0.02069837656537337, 0.054545272407787185, 0.029021390580705235, 0.049057535627590756, 0.03414582274854183, 0.015390236130250352, 0.04437233614070075, 0.03345497910465513, 0.004427334551499891, 0.018331534462049603, 0.01424565103038081, 0.0423287922250373, 0.031243935426963226, 0.06322509236633778, 0.04222309682518244, 0.05725505628756114, 0.006351809566175299, 0.019464703210230385, 0.014472251192533543, 0.06357527750411204, 0.013851790289793695, 0.04108886447335992, 0.06392500802342381, 0.039964972995221615, 0.027836201945319772, 0.0376456961967051, 0.016889885034678236, 0.01785729276681585, 0.0495407204143703, 0.04602334415540099, 0.029595336211579185, 0.027780911519325206, 0.046345275094998736, 0.022973085487527505, 0.038923092652112246, 0.042878157924860716, 0.05104672210291028, 0.059029669633933475, 0.018614539543965032, 0.012304191011935472, 0.029575305857828686, 0.018568809676383222, 0.039601369827453575, 0.022210905760792748, 0.03770593314298561, 0.030577393514769416, 0.03586148836516908, 0.04421240543680532, 0.04692485256652747, 0.10412218927272729, 0.047966654878109694, 0.024303945413391505, 0.022497617340247546, 0.038632828941834826, 0.03774694719218782, 0.009504879525463496, 0.0781608016363212, 0.024802253049399172, 0.018108547498871173, 0.017492066204015697, 0.020033514027350714, 0.01540894334071449, 0.055018160425658734, 0.07010101340711117, 0.011241123412868806, 0.030456258050565208, 0.029912463123244897, 0.017734844337350557, 0.02377545993242945, 0.04002320147784693, 0.04356678954458662, 0.041390059382787774, 0.013144715240092149, 0.054811203852295876, 0.05456821367676769, 0.04825676931068301, 0.07713596270020519, 0.06091594948832478, 0.054679089691489935, 0.013173149250048612, 0.08213398379406758, 0.02391761132249875, 0.06988709167178188, 0.060328222811222076, 0.03326564747840166, 0.016967928436185633, 0.06659637325044189, 0.07074221542903356, 0.06962558427559477, 0.003850898697107498, 0.009584018761026008, 0.04577432180355702, 0.07655261257397276, 0.0255551605951041, 0.031346831869866164, 0.025382057830159153, 0.029141766085688556, 0.07727055690650429, 0.002369638091684984, 0.043922291004232, 0.048567114264837334, 0.11473435482808522, 0.04796819854527712, 0.0454909350456936, 0.70867798690285, 4.499519220420292, 15.172381741659981, 28.931201117379324, 37.4865597316197, 45.693573883601594, 46.909098693302695, 38.33968734741211, 31.60248122896467, 32.21640321186611, 48.27364499228341, 30.173396587371826, 22.38244230406625, 23.820570026125225, 26.42869622366769, 30.101812771388463, 30.880907331194194, 22.955189262117656, 18.018726927893503, 16.384741646902903, 10.159953883716039, 7.8697016920362195, 4.240349241665431, 3.0530475803783963, 2.5403109107698714, 1.517192468047142, 0.7784662363784653, 0.6042958508644785, 0.1619892841471093, 0.36789767018386293, 0.11418371008975164, 0.06933154791061368, 0.2927161529660225, 0.028328847206596817, 0.13558351035629, 0.16867655888199806, 0.22411832532712392, 0.25523168008242336, 0.2141821842108454, 0.10122973019523279, 0.11966035621506826, 0.2887266384703772, 0.21939293960375444, 0.5315131992101669, 0.31702111448560444, 0.4990176686218807, 1.3183044088738305, 2.247083902359009, 4.719296387263706, 6.570183149405888, 9.4295540366854, 13.399697388921465, 15.596333026885986, 21.02743935585022, 19.839778559548513, 21.68393121446882, 20.675212587629044, 15.178148746490479, 22.807619946343557, 28.53771594592503, 28.047275611332484, 29.99806227002825, 31.091809477124894, 30.749843461172922, 22.976080758231028, 13.994225212505885, 4.708861495767321, 0.6306952599968229, 0.01329542974209679, 0.06157236426536526, 0.07231306470930576, 0.037946728257728476, 0.024611209818561162, 0.0876399969149913, 0.01708683491285358, 0.04278758028522134, 0.05633610613378031, 0.02505586908331939, 0.034806597113077126, 0.035514268425426314, 0.029059364793023894, 0.04738587639959795, 0.013569853900532638, 0.04254032551710095, 0.017045255983248353, 0.02138522533433778, 0.05239774639319096, 0.029715654041085924, 0.0542199012956449, 0.058676770356084616, 0.016983207348468046, 0.03726952995306679, 0.030306223779916763, 0.013798020630409675, 0.04139795074505465, 0.05657647716413651, 0.035207149905285666, 0.06841169191258294, 0.0285072272776493, 0.04408654736887131, 0.07523128776145832, 0.016043583929006542, 0.025150775776377747, 0.02088647156155535, 0.04535029169970325, 0.028348356784720505, 0.018788327629278814, 0.03052413190848061, 0.028072773179571544, 0.06414954883179494, 0.03754357328372342, 0.015945737482979894, 0.026804652297869325, 0.01091120102708893, 0.10156626999378204, 0.024231075841401304, 0.03815532010048628, 0.02907613817868488, 0.21652507063533577, 0.17210853472352028, 0.16312447323330811, 0.2389990868312972, 0.12398894823023252, 0.06961316708475351, 0.1368616260588169, 0.10939492205423967, 0.11612829645829541, 0.08497235684522561, 0.17057511343487672, 0.15134164478097642, 0.08209528015660388, 0.09392984011875731, 0.10382795613259077, 0.10679301845708064, 0.11751775975738253, 0.1482180766761303, 0.09520795582128422, 0.13085119000502995, 0.1484380712998765, 0.16922994490180696, 0.12410409562289715, 0.10660831443965435, 0.12137585559061595, 0.12805668424282754, 0.09273116729621377, 0.12392068760735647, 0.2021269646606275, 0.17589515367788927, 0.24834837658064707, 0.1069655834830233, 0.11112699125494276, 0.16768592489617212, 0.21502712315746716, 0.08529984498662607, 0.11417754899178233, 0.1429890144084181, 0.09729555701570851, 0.10339319839009217, 0.05536635745582836, 0.17689933122268744, 0.1984806124653135, 0.09834772734237568, 0.11216714472642966, 0.17279883553939207, 0.2548411696084908, 0.14166209846735, 0.12370922895414488, 0.1301672945597342, 0.11892934329807758, 0.17407293431460857, 0.13889553477721556, 0.17957754965339387, 0.09804314654320478, 0.2584585483585085, 0.18240439439458506, 0.16646025995058672, 0.7855178979890687, 4.378601023129054, 16.35052524294172, 30.669324261801584, 43.26423004695347, 52.63129111698696, 56.71304164613996, 46.72468308040074, 42.332872663225444, 39.16836772646223, 54.068685804094585, 40.53591217313494, 27.95065917287554, 31.50147179194859, 30.587200028555735, 40.054155349731445, 34.28786618368966, 28.517705133983068, 22.780289207186016, 18.353001288005284, 12.922737428120204, 8.743045960153852, 5.967069957937513, 4.755100454602923, 3.0605186309133257, 2.1453455558844974, 1.2429184083427702, 1.5249290700469698, 0.7415098537291799, 1.4270804119961602, 0.5604656370622771, 0.9484481066465378, 1.0856876224279404, 0.6557134432452065, 1.2591530914817537, 0.9578236149890083, 0.8108710604054588, 1.1554129038538252, 0.8002668065684182, 0.5342748910188675, 0.6464440577796527, 0.6521363694752965, 0.7399474861366409, 2.373028252805982, 1.0008454493113925, 0.860527013029371, 1.9328894019126892, 3.6039556988648007, 5.786004679543631, 8.108834368841988, 11.837521740368434, 14.705365521567208, 17.153386116027832, 22.24488013131278, 27.723060505730764, 28.2741516658238, 31.284205096108572, 20.521316937037877, 30.410420485905238, 38.8618757384164, 35.05671215057373, 35.6681466783796, 36.62257555552891, 34.21155064446585, 26.329774720328196, 15.037105526242938, 5.412256300449371, 0.7542499729565212, 0.12162444368004799, 0.1265312968088048, 0.1671205830893346, 0.1149735791342599, 0.10204105451703072, 0.14724361896514893, 0.08272130335015909, 0.24226723717791693, 0.1246536411345005, 0.09677256936473505, 0.1584848136241947, 0.13837337493896484, 0.11919315771332809, 0.09481602042381253, 0.09939759064997945, 0.10690463068229811, 0.13942887687257358, 0.13965640323502676, 0.12572012176471098, 0.07855256061468806, 0.12964991160801478, 0.19220674197588647, 0.09491455727922064, 0.0892696955374309, 0.06487397317375455, 0.10650494641491345, 0.13666333098496708, 0.09307615485574518, 0.21939245105854102, 0.1801482518868787, 0.10649356738265071, 0.13693891119744095, 0.12434513840292181, 0.1251702369855983, 0.21889960393309593, 0.14884399808943272, 0.11535630002617836, 0.13671755950365747, 0.1471801216581038, 0.11840138877076761, 0.11371442170015403, 0.18307440701339925, 0.10879829978304249, 0.06085739191621542, 0.1133008138941867, 0.11708775854536466, 0.17255464435688087, 0.13834877125918865, 0.1443856566080025, 0.10759064315685204], [0.05852279718965292, 0.032380695321730206, 0.04239715462816613, 0.005252467060927302, 0.025851621026439325, 0.019796596740239432, 0.0831223311168807, 0.022305434170578207, 0.04120235963325415, 0.022509581608963863, 0.11077884172222444, 0.011029403523675032, 0.06741195198680673, 0.07968668440090758, 0.03699554429788675, 0.006477894943340549, 0.030912474463028566, 0.05459910059081657, 0.08345757491354432, 0.061758343928626606, 0.01843475490542395, 0.007895075549770678, 0.014445747614705136, 0.048971198831817934, 0.026012437218534093, 0.016407146384673457, 0.07169816270470619, 0.003216396360325494, 0.0213267033853169, 0.018361685165603246, 0.04450311358751995, 0.049210168687360625, 0.021836478263139725, 0.019772038861577, 0.03300472701500569, 0.03260664748294013, 0.025563230072813373, 0.052920499949582984, 0.04076123383960553, 0.024795657689017907, 0.08508660178631544, 0.06437430677137204, 0.024480067659169436, 0.009672775382309087, 0.04555561300367117, 0.02361892020728971, 0.05068573129496404, 0.03734087451760258, 0.045512349610882144, 0.027128839366404072, 0.11626861750015191, 0.059231622011533806, 0.050024529453366995, 0.04822384679157819, 0.03808284238246935, 0.062375837936997414, 0.024734287589256252, 0.062263818590768745, 0.04137108075831618, 0.09190678796065704, 1.4554812823023116, 5.20935457093375, 15.468187400272914, 25.626191445759364, 35.30730588095528, 38.670522349221365, 39.16903822762625, 27.620435612542288, 34.362333502088276, 37.139844621930806, 21.8909684249333, 27.42435050010681, 21.16419553756714, 23.284848281315394, 16.11932393482753, 19.026014225823538, 24.469917399542673, 21.23737743922642, 17.850156681878225, 14.229755248342242, 13.648342149598257, 9.112830826214381, 7.579269596508571, 6.4913671272141595, 4.801353744098118, 3.979485205241612, 3.3991466888359616, 2.2727627073015486, 2.4856153428554535, 1.9021256012575967, 1.5547161059720176, 1.661463017974581, 1.6965013721159525, 0.9353151427847999, 1.1728523394891193, 1.1395589602845055, 1.591331592627934, 1.2527832218578883, 1.297759779861995, 1.5570602544716425, 1.9177434146404266, 2.397385597229004, 3.103322356939316, 4.770111169133868, 6.059020246778216, 10.160748583929879, 13.287170444216047, 14.202230828148977, 18.002990995134624, 12.133873701095581, 22.37517101424081, 17.700489010129655, 28.13955637386867, 20.151186398097447, 21.278519460133143, 21.760151215962, 26.994274377822876, 33.852613653455464, 33.00563866751534, 28.335558107921056, 21.57178555216108, 11.674447519438607, 7.150264365332467, 2.624524597610746, 0.21920759097806045, 0.03318735132259982, 0.025071300665981004, 0.03949734362374459, 0.08682276933853116, 0.03024049409266029, 0.016394376355622495, 0.0371015450385, 0.014803547611726182, 0.020183706057390997, 0.02315419666203005, 0.04876739405361669, 0.047395443743360896, 0.03305752382480672, 0.03344422432460955, 0.04066033228965742, 0.06711761706641742, 0.07881814600633723, 0.01851494756660291, 0.04317977013332503, 0.049612807974751504, 0.003987327916547656, 0.028292772892330374, 0.03867573949641415, 0.0303505355093096, 0.05390117643401027, 0.03409143477412207, 0.036784329917281866, 0.03803833048524601, 0.031636525610727925, 0.032840579215969355, 0.034746414449598105, 0.03644789189898542, 0.048070107719727924, 0.031989984679967165, 0.04548165947198868, 0.03922718490606972, 0.0057388867634082475, 0.010439659053060626, 0.029229521019650356, 0.08000971456723553, 0.015859782363155057, 0.09147293945508343, 0.03835534883130874, 0.05911981301116092, 0.010013791815643864, 0.06586284296853201, 0.07329299819788762, 0.03743517731449433, 0.021563333991382803, 0.025477958577019826, 0.05470338124515755, 0.0024793446937110275, 0.026966079171480875, 0.07466367964765855, 0.018769355790157403, 0.03061669087037444, 0.03106021528531398, 0.0953358868137002, 0.02225415388654385, 0.009749802677626056, 0.07820671810103313, 0.06900583074561187, 0.013235526974312961, 0.03321228748453515, 0.07009807535048042, 0.054358777057911666, 0.0411950585964535, 0.010508152922349316, 0.03778058556573732, 0.049862468149513006, 0.03556877514347434, 0.06283137242176703, 0.07215202120797974, 0.045007078509245596, 0.07374582532793283, 0.031530691111194234, 0.03809088980779052, 0.012278927456853645, 0.05003317738217967, 0.045363628305494785, 0.04596766017909561, 0.0313726195932499, 0.016134651810196892, 0.09319607234959092, 0.038000790535339286, 0.019319763041234443, 0.03146184016285198, 0.022961949031533938, 0.04510757972353271, 0.023094232826094543, 0.030437442274498086, 0.020420485941161002, 0.05054060283250042, 0.055357258301228285, 0.054125306728695116, 0.023350613890215755, 0.05411055877006479, 0.016482689384637133, 0.028770807598318373, 0.014398813347465225, 0.013050703365089638, 0.0484608997856932, 0.07419607402490717, 0.03134228229256613, 0.038774537587804456, 0.03330092451402119, 0.03715142754039594, 0.02717288985981473, 0.04954536498657294, 0.07423430268785783, 0.15493196355445044, 2.386749859367098, 7.853043385914393, 19.855372054236277, 31.125855650220597, 42.93939481462751, 42.47082567214966, 43.85751240594046, 31.026062147957937, 39.41962153570992, 38.37403924124581, 23.144824709211075, 26.53043348448617, 22.703732218061173, 30.96218041011265, 24.99500318935939, 26.653545141220093, 31.28616796221052, 25.134653295789445, 23.55967559133257, 16.115894998822892, 13.768818702016558, 12.580114807401385, 8.347708225250244, 6.845918067864009, 4.754084714821406, 4.357223587376731, 3.2016515263489316, 2.78108640227999, 2.008020273276738, 2.022939358438764, 1.4940679946116038, 1.7651593450989043, 1.2895318099430628, 1.2324207659278597, 0.8529207983187267, 1.201657616666385, 0.9806673377752304, 1.146422694836344, 1.5103824734687805, 1.279597731573241, 1.6142732415880476, 1.9258057134492057, 3.482621261051723, 5.975362198693412, 7.40255171912057, 11.119486212730408, 15.27965497970581, 17.03509303501674, 20.160074881144933, 18.506410564695084, 22.06679606437683, 20.727562052862986, 29.522600514548166, 23.801679611206055, 23.300737074443273, 22.604883670806885, 29.82833514894758, 37.4726494380406, 35.56906189237322, 31.433254378182546, 25.64297308240618, 15.389667545046125, 9.836317215647016, 3.709574179989951, 0.4758050399167197, 0.04114422953820654, 0.07115441866751228, 0.05429202278277703, 0.03963460786534207, 0.012899575804892396, 0.06073389854282141, 0.05685341105397258, 0.011775115205507194, 0.042795434328062196, 0.0527342895844153, 0.03772771411708423, 0.02606012126696961, 0.044523283040949276, 0.03397943239126887, 0.042298482065754275, 0.05414425142641578, 0.04446169241730656, 0.009834276046603918, 0.029257995741707937, 0.08274924542222704, 0.03678487613797188, 0.0516764568830175, 0.06106005675558533, 0.034254032120640786, 0.03793969184958509, 0.023381120824654187, 0.10085798799991608, 0.015901651366480758, 0.07536070474556514, 0.02823920764162072, 0.06564538606575557, 0.032197823348854265, 0.03978828586904066, 0.01655531468402062, 0.053774819642837556, 0.030747933113681417, 0.009881165360898843, 0.012797351111657917, 0.035286932052778344, 0.015088710435000914, 0.012803809068697904, 0.05501781776547432, 0.04423406088192548, 0.03861498686351946, 0.03507372956456883, 0.09463415268276419, 0.01893999208030956, 0.03445500062246408, 0.04151116431291614, 0.058555936839963706, 0.03561711397820285, 0.13266476483217307, 0.07526485488883086, 0.1998226461665971, 0.10875310256545033, 0.13586044763880117, 0.06368907461208956, 0.16872333708618367, 0.13155298520411762, 0.15332741822515214, 0.08793130556919745, 0.24518157222441264, 0.06993591905172382, 0.2743869950728757, 0.1693125090428761, 0.10400869072015796, 0.12462560406752995, 0.09446278866380453, 0.1208850983530283, 0.15750005575163023, 0.1872641843344484, 0.12056135572493076, 0.1440405129854168, 0.16312551817723683, 0.13606252893805504, 0.07883492617734841, 0.16797963556434425, 0.26987962265099796, 0.16208001784980297, 0.13447224641484873, 0.12271868996322155, 0.10773251804390124, 0.14958588113742216, 0.13893071003258228, 0.15642202645540237, 0.13749088586441108, 0.1189835039632661, 0.08436134963163308, 0.11281186834509883, 0.11066093947738409, 0.1546269077807665, 0.16161583204354557, 0.30455544910260607, 0.12592502576964243, 0.250253892902817, 0.11856996401080064, 0.10902520189327852, 0.13083220459520817, 0.10956840310245752, 0.15072964690625668, 0.18047820989574703, 0.20542494340666703, 0.16856009513139725, 0.12188844808510371, 0.2005369264100279, 0.1660644161914076, 0.10971617445881877, 0.11025508732667991, 0.13803197682968207, 0.20973125233181886, 0.30866001599601334, 2.198714452130454, 7.697124072483607, 21.50111195019313, 34.624381337847026, 46.73533466884068, 49.47069454193115, 51.85961028507778, 39.13526998247419, 44.72047867093767, 47.967448302677695, 34.32648079735892, 37.65809685843331, 32.50866528919765, 36.55829777036394, 26.294971193586075, 28.430986404418945, 34.01845325742449, 30.225132874080114, 27.04572926248823, 21.242284604481288, 20.091028894696915, 14.451316799436297, 10.507033773830958, 9.463138154574803, 6.2987313611166815, 6.337990420205252, 4.5456982510430475, 3.048085046666009, 3.0114962671484267, 3.265392780303955, 2.3123924093587056, 3.214118331670761, 2.205928636448724, 1.9869337933404105, 1.8314817462648665, 1.621944704226085, 2.3971582608563557, 1.7654513865709305, 1.8475344734532493, 2.2538903142724718, 3.1811499978814806, 3.1460057922772, 4.04001921415329, 6.520773640700749, 8.656228218759809, 13.476437636784144, 17.844869102750504, 20.870251996176584, 23.562506982258387, 19.718440430504934, 31.02210167476109, 26.690106562205724, 39.07473380225045, 30.238497734069824, 31.320985385349818, 30.921887806483678, 36.600240571158274, 44.01013306209019, 41.22998857498169, 37.29200669697353, 30.723752975463867, 19.321072953087942, 10.21743198803493, 3.854953076158251, 0.5104412670646394, 0.20618665324790136, 0.2298914369727884, 0.18334595672786236, 0.14901441894471645, 0.1707606249089752, 0.2747965045273304, 0.1205542039658342, 0.12072606331535748, 0.1627591906913689, 0.12318438211722033, 0.1638225500604936, 0.07113558932074479, 0.08379885088652372, 0.11727958039513656, 0.11049572977104358, 0.23443167763096945, 0.13665843196213245, 0.09345156792551279, 0.24367943140012877, 0.1419334039092064, 0.11231630707957915, 0.15706560334989003, 0.19782946312001773, 0.10538091922977141, 0.12308618452932153, 0.12535565346479416, 0.17937620117196015, 0.1502977322254862, 0.1791209905807461, 0.158708268776536, 0.17106562639985765, 0.14541865832039289, 0.21107720796551022, 0.12487420572766236, 0.10242778555090938, 0.1975189654954842, 0.10909475173269, 0.11619684206587927, 0.21704914394233907, 0.12853330081062658, 0.09890024483736072, 0.12610766025526182, 0.22653901257685252, 0.12962152170283453, 0.2168381738343409, 0.25790437523807797, 0.12803596178335802, 0.12759908022625105, 0.15225508862308093, 0.1475347647709506, 0.10653400128441197], [0.014403546129220297, 0.04044597968459129, 0.058616095754717074, 0.04874854435079864, 0.04717951015170131, 0.024799223390540907, 0.09385668047304664, 0.04558700203363385, 0.03975532603050981, 0.011646956903859973, 0.035704546608030796, 0.015005508471014244, 0.07975276014102356, 0.15167302771338395, 0.023012184371639575, 0.024791980029216835, 0.06087225183312382, 0.0364174256766481, 0.05329143129555242, 0.03187635042039411, 0.041323627411786995, 0.07943261374852487, 0.0628142122711454, 0.03229292681706803, 0.034932071808725595, 0.07382662527795349, 0.06573911889323167, 0.04087218110050474, 0.02118149689132614, 0.030152365964438235, 0.024839657292302166, 0.049683304370513985, 0.039868461566844156, 0.11084202690316097, 0.01965854879069541, 0.030753602273762226, 0.00550081893535597, 0.006010173969636006, 0.05952639797968524, 0.08839364576020411, 0.029680566995271614, 0.02411782495411379, 0.05617868261677878, 0.02333373872430197, 0.038387284081961424, 0.04242143261113337, 0.03853020730561443, 0.08414700720459223, 0.03094771078654698, 0.03583635203540325, 0.01432951626234821, 0.07263743158962045, 0.031236145844949142, 0.06825061448450599, 0.025056790194607208, 0.028016515841175402, 0.04256806742133839, 0.03424115352598684, 0.01609813475183078, 0.004804532592450934, 0.05816385895013809, 0.7227715935025896, 3.785143656390054, 9.854362555912562, 19.574875014168875, 37.61862761633736, 39.305181230817524, 42.160453115190776, 31.057891845703125, 39.38300800323486, 31.038707869393484, 30.73835114070347, 16.72958595412118, 13.337485824312482, 10.725895949772426, 13.595068573951721, 20.238332441874913, 19.34336624826704, 14.960642337799072, 27.123767954962595, 19.129177604402813, 18.072488614491053, 16.878260033471243, 14.227194837161473, 11.558571543012347, 11.079227481569562, 9.889011485236031, 8.56223385674613, 8.325896961348397, 7.712291121482849, 7.481973971639361, 7.654467344284058, 7.101451098918915, 6.300729836736407, 6.04942261321204, 5.698381381375449, 6.803734685693469, 5.127298516886575, 5.609342387744358, 7.29859277180263, 7.850146855626788, 7.208348699978419, 8.823114395141602, 10.482223493712288, 19.609624692371913, 20.288310834339686, 20.21298541341509, 12.699392795562744, 19.603383472987584, 20.4046653679439, 29.588882855006627, 22.88555441583906, 19.859547921589442, 27.189902646201, 27.36955005781991, 33.26603978020804, 32.3045654296875, 32.857798371996196, 25.181228807994298, 18.26982613972255, 8.40157847745078, 1.923586632524218, 0.7563354639070374, 0.1028713710340006, 0.011249707729023482, 0.043710496476186175, 0.11475054467363016, 0.04303639229120953, 0.05163980242131012, 0.0365021204176758, 0.0548487404095275, 0.017930898549301282, 0.02104092818418784, 0.04791773250326514, 0.06475246790796518, 0.03378994130928602, 0.014098613340008472, 0.014019243402539619, 0.051030135314379416, 0.0832861837531839, 0.038037957290985754, 0.02559927724567907, 0.026522576808929443, 0.03661912699629154, 0.0326464740958597, 0.03595430517037, 0.014708362719310182, 0.0372101377828845, 0.06685152277350426, 0.04774091306275555, 0.028093069858316864, 0.04951088183692523, 0.1234170382044145, 0.050960863674325604, 0.01677944667504302, 0.0028370094078127295, 0.0774645364976355, 0.08393782842904329, 0.07622264099440404, 0.06548555714211293, 0.04987364022859505, 0.05084542790427804, 0.021701587197769965, 0.026627137358965616, 0.07709707585828644, 0.01857230413172926, 0.0199698640499264, 0.07206351988549743, 0.019737876319725598, 0.023296670356233205, 0.02316533651069871, 0.04565594458420362, 0.025102465779387524, 0.08625621973936047, 0.017402570827731063, 0.0397257113696209, 0.03030346553506596, 0.015811474062502384, 0.04295401135459542, 0.032883292995393276, 0.034542141482234, 0.05512491434014269, 0.039748360868543386, 0.03349049702020628, 0.019837676946605955, 0.05539709848484822, 0.039111660926469734, 0.04378315061330795, 0.032832107706261535, 0.11168547307274171, 0.013213209957549614, 0.05071766993829182, 0.08524076494255237, 0.06543630907045943, 0.021424778836912343, 0.09139471115278346, 0.009035067815732743, 0.01219541167042085, 0.025157033565587232, 0.011737897559734327, 0.034227321589631696, 0.09827004865344081, 0.06399432716092893, 0.019474838827071444, 0.05452171367193971, 0.05430105408387525, 0.019053570360743573, 0.03835706213223083, 0.05174086003431252, 0.021530428435653448, 0.017081717062475424, 0.05092036870441266, 0.05042989305885775, 0.010696638076167022, 0.04313683243734496, 0.01465762865596584, 0.012645594210230877, 0.01901322297219719, 0.011731411613124822, 0.04462077834510377, 0.08858337772211858, 0.011363777947346014, 0.04874781831832869, 0.0651763283780643, 0.0074311849062464064, 0.05611539565558944, 0.04221028269135526, 0.02312197133765689, 0.02075326326303184, 0.04589934188074299, 0.04982480945597802, 0.07638523834092276, 0.023187673883512616, 0.023022939151685153, 0.056788614352366755, 0.03048721281811595, 0.07865958594317947, 1.0444612460477012, 5.526567195143018, 13.74479009423937, 26.13491075379508, 43.51679359163557, 45.097102301461355, 43.22708150318691, 35.012330532073975, 45.09033128193447, 34.46766471862793, 33.404037952423096, 21.62976132120405, 16.9711366040366, 11.975466064044408, 13.468116300446646, 21.580352681023733, 25.22218496458871, 23.571487528937205, 27.323177780423844, 30.67229461669922, 23.04779311588832, 20.81834200450352, 18.718436581747874, 12.834032382283892, 13.59219115121024, 11.2397769008364, 12.136428901127406, 10.781590104103088, 8.87876946585519, 7.669250505311148, 7.993644527026585, 8.079869934490748, 6.664693849427359, 7.285533198288508, 6.937213488987513, 7.07178750208446, 6.173761061259678, 6.799030755247388, 8.597186769757952, 8.403457965169634, 8.265819362231664, 9.489992942128863, 13.637947644506182, 20.534176315580094, 22.953900371279033, 23.469053711209977, 15.855504308428083, 23.62106466293335, 19.93546567644392, 30.647909913744243, 21.44202446937561, 24.059584583554948, 27.96470148222787, 29.175725596291677, 35.997140407562256, 35.7957364491054, 38.10253143310547, 29.924925531659806, 21.752131257738384, 11.613093188830785, 3.7042201587132046, 1.1630920746496745, 0.19349294581583568, 0.04583043325692415, 0.049865195860287974, 0.08287665394267865, 0.019323137056614672, 0.03008268720337323, 0.039296079959188185, 0.009112062880636325, 0.0711477283122284, 0.07788216801626341, 0.06706382281013898, 0.022506814882425324, 0.05212884635797568, 0.03836735211578863, 0.03853213773774249, 0.03516162020553436, 0.04268785260085549, 0.03562925296968647, 0.022430666289957504, 0.03934585389548114, 0.0553330040669867, 0.018309332796239426, 0.047006507470671616, 0.04059063995789204, 0.06190971152058669, 0.08621560941849436, 0.012046245924596275, 0.020141667420310632, 0.047334060072898865, 0.025683430855029395, 0.07211413859788861, 0.029689065646380186, 0.02031475491821766, 0.009698376508562692, 0.04751382435538939, 0.008945387538655527, 0.0375004591686385, 0.06141505270664181, 0.03076131043157407, 0.029851852982704128, 0.009953610848502388, 0.08185893962425844, 0.02403472307404237, 0.05921256196285997, 0.031336175477398295, 0.05400097875722817, 0.04226523045716541, 0.0163220309519342, 0.09999499323644809, 0.0227973025092589, 0.04378410056233406, 0.08724272144692284, 0.08203212211706809, 0.11778720601328782, 0.13095083965786866, 0.13253379400287355, 0.12000275855617863, 0.1499281477715288, 0.07277246684368167, 0.15834105919514382, 0.11889819854072162, 0.09704370517283678, 0.10819760630173342, 0.15340869314968586, 0.1323451069848878, 0.2350883095392159, 0.2724937195224421, 0.14619007121239389, 0.14023926481604576, 0.15327918795602663, 0.14859713347894804, 0.09070556384644338, 0.20674698746630124, 0.15745314184044087, 0.13804177487535135, 0.13780229272586958, 0.13459025722529205, 0.15939059002058847, 0.2485134234385831, 0.20180964097380638, 0.08277332663003888, 0.11554198791938168, 0.25019771020327297, 0.11653959724519934, 0.14991370854633196, 0.15664635013256753, 0.17926916905811854, 0.10457485355436802, 0.18338527104684285, 0.17356631292828492, 0.05265382890190397, 0.1282359260533537, 0.1717402801981994, 0.1464794935392482, 0.1222078480890819, 0.1353369578719139, 0.14512714610568114, 0.12031430112464087, 0.1207896149052041, 0.0723293088376522, 0.21183325882468904, 0.1541711493794407, 0.1654418603117977, 0.14888244388358934, 0.11198883929422923, 0.10104406944343022, 0.10105583524065358, 0.10462380307061331, 0.1817283292434045, 0.19646378925868443, 0.14600351479436668, 0.11472482819642339, 0.10505132084446293, 0.14138140210083552, 1.1244683414697647, 5.776609846523829, 15.440908772604805, 29.86827686854771, 48.99123409816197, 51.754911354609895, 53.3945437840053, 40.73382118770054, 52.193610191345215, 44.26934603282383, 43.295694964272634, 27.89811168398176, 24.945641449519567, 18.18721726962498, 22.807206528527395, 31.501728875296457, 29.908128261566162, 26.380010196140834, 38.83017110824585, 30.703047343662806, 28.57838896342686, 26.166603224618093, 20.940923861094884, 17.207490001405986, 17.19657611846924, 15.09755311693464, 12.695677246366229, 11.122484360422407, 10.555977753230504, 10.047518134117126, 9.665516597884041, 9.589594500405447, 8.427906938961574, 8.496806144714355, 8.317060589790344, 10.296647531645638, 7.834227664130075, 7.437878966331482, 9.900366578783308, 10.404040626117162, 10.956663863999502, 12.332023297037397, 15.34500973565238, 26.373793295451573, 28.01798026902335, 29.938853195735387, 21.152270691735403, 29.564307076590403, 28.525738988603862, 39.21716839926583, 30.673045022147043, 30.154935223715647, 36.86675609861101, 36.844712938581196, 43.25610065460205, 43.1944979258946, 43.51842989240374, 33.14571435110909, 23.24998048373631, 13.464891467775617, 5.1329799720219205, 1.3213048364434923, 0.25851912796497345, 0.1295970944421632, 0.15571350018892968, 0.1928842184799058, 0.15235215984284878, 0.14313563225524767, 0.13573935627937317, 0.13767162045197828, 0.1640864594706467, 0.13289557530411653, 0.15732358236398014, 0.14816277607211045, 0.0737127603164741, 0.12748799047299794, 0.10753722209483385, 0.137585704347917, 0.11523030964391572, 0.26390555607421057, 0.09734681355101721, 0.13008815023515904, 0.09874205118311302, 0.12479658132152897, 0.1401893924921751, 0.17556974185364588, 0.13200164612914833, 0.21713695994445256, 0.12583640909620694, 0.14783393086067267, 0.09277390821703843, 0.20371435662465437, 0.1386232115328312, 0.09763877359884125, 0.10872082465461322, 0.20155238120683602, 0.12535380784954342, 0.17277533108634607, 0.1705694951649223, 0.18068432169301168, 0.1648300659975835, 0.13304120248981885, 0.10534383050565209, 0.13161242487175123, 0.10754982249013015, 0.10430779574172837, 0.13153253415865557, 0.15327584956373486, 0.14663117325731687, 0.08136158024093934, 0.19959786108561925, 0.14425229733543737, 0.17852440902165004, 0.1715606041252613, 0.14013714529573917], [0.10026065326694932, 0.03635254076548985, 0.024042738268950155, 0.04991785357041018, 0.022266365820541978, 0.040381854732653925, 0.02002722061505275, 0.0024821599779118386, 0.009911208347018276, 0.021083998194496547, 0.09232533550156014, 0.07583382685801812, 0.05913332264338221, 0.004198032547719777, 0.07523495863590922, 0.044581182434090545, 0.024034728163055012, 0.08928406690912587, 0.0651766744309238, 0.039837316809488196, 0.03816142691565411, 0.03243957180529833, 0.02877402724698186, 0.013523552367197616, 0.03187081357464194, 0.0704196873786194, 0.06737237982451916, 0.02121295377479068, 0.011394633479150278, 0.07597657705524138, 0.0184021479051028, 0.01970133211995874, 0.04135549141626273, 0.06223140497292791, 0.02750201496694769, 0.07796773128211498, 0.03086467845631497, 0.02421086228319577, 0.051204953076584, 0.05812619347125292, 0.04332787057917033, 0.05732816843582051, 0.05514097187135901, 0.032033651801092286, 0.036180878191121986, 0.01691158119189952, 0.023125291070235626, 0.048861890232988765, 0.012066937001821185, 0.044119252756770165, 0.03607862635648676, 0.021814463194459677, 0.06865068551685129, 0.05296629088531647, 0.02532033828486289, 0.011543716104435069, 0.02780082312944744, 0.06386022828519344, 0.029452735292060033, 0.09728981660945074, 0.02486319567209908, 0.06658403069845267, 0.33428508096507614, 1.428931564092636, 5.857844710350037, 15.459264176232473, 28.741511821746826, 38.891839844839915, 39.90744066238403, 39.037369864327566, 39.73643854686192, 38.253116267068044, 23.61066494669233, 22.590563433510916, 19.375994988850184, 28.619183574404033, 27.66634409768241, 18.044476951871598, 25.131033284323557, 22.462648834500992, 11.4978494984763, 17.13184322629656, 15.180340903145925, 15.108248131615774, 18.914108276367188, 16.176250525883265, 16.385422570364817, 9.360741683415004, 16.298901864460536, 16.845985651016235, 14.545365009989057, 15.547473294394356, 16.529302392687114, 14.962292534964424, 12.569165314946856, 15.39836495263236, 14.09292003086635, 21.013515165873937, 15.866710015705653, 13.255109718867711, 18.251508951187134, 21.726851974214824, 23.409219299043926, 23.329332385744365, 25.36411234310695, 31.49837636947632, 27.481268405914307, 28.826825278145925, 18.00638692719596, 25.663796833583287, 15.566021510532924, 22.323818615504674, 30.22996882029942, 34.17078556333269, 33.65864079339163, 28.913491896220616, 22.05499976021903, 17.113003185817174, 8.76202757017953, 5.357758104801178, 1.3688380058322633, 0.4278937093913555, 0.05012417232085552, 0.024776758792411004, 0.06558668600129229, 0.017426972643339207, 0.0389673942034798, 0.03383748286536761, 0.016951979470572302, 0.06547088721500975, 0.03671660194439547, 0.02194991065854473, 0.021479964089979018, 0.022087442921474576, 0.10369535681924649, 0.028470135160854886, 0.059749330660062175, 0.024190524892349328, 0.012163399236409791, 0.07117745493139539, 0.022502511274069548, 0.039146310317197015, 0.03176200369905148, 0.0757764567221914, 0.03412091712068234, 0.0644971283950976, 0.034966249617614915, 0.027895229402929544, 0.0491622369736433, 0.07620527049792664, 0.02859795080231769, 0.020852984162047505, 0.015387723854343806, 0.01006390671578369, 0.029486241351280893, 0.0469094226802034, 0.04405223385297826, 0.0508621130803866, 0.01815709498311792, 0.049203050855015, 0.031140285810189586, 0.02500961335109813, 0.03310167609847017, 0.01823197810777596, 0.03664875862055591, 0.06446166136967284, 0.006558260206864881, 0.01833348016121558, 0.046064605869885, 0.033331543406737704, 0.01661244733259082, 0.031231148434536796, 0.045591185202023814, 0.03430318180471659, 0.014225574027347778, 0.0338179614128811, 0.05617978184350899, 0.0020232930380318847, 0.03807993485991444, 0.031042756579284157, 0.029967275182051317, 0.012106526127484227, 0.045688110536762645, 0.015960197064227293, 0.013427001923056585, 0.046325288846024444, 0.037764829982604296, 0.020508376582126533, 0.03696481005421706, 0.008852016031076866, 0.03323004813864827, 0.013923989808452981, 0.027584953998614634, 0.029830333244587694, 0.01711848857147353, 0.022523411848981465, 0.03940598227615867, 0.06920847522893123, 0.039584874641150236, 0.021761786824624454, 0.05102514808199235, 0.03456765100626009, 0.0019034067143885685, 0.045226085864539654, 0.05464207560622266, 0.007153242543738867, 0.03082557109051517, 0.03566010256430932, 0.043574484131698094, 0.08218800196690218, 0.05845231097191572, 0.05997593421489, 0.06475372998309986, 0.04238956182130745, 0.03059174113773874, 0.059938913344272544, 0.03668563699881945, 0.07642858994326421, 0.0064162067802889, 0.011025972680986991, 0.015506269011114324, 0.03659162936466081, 0.0185885516527508, 0.06514370441436768, 0.008911660955553609, 0.036961339347596676, 0.016560532618314028, 0.06484013463237456, 0.07325074582227639, 0.02774400599966092, 0.0277825196473194, 0.03471146311078753, 0.04474879076172199, 0.04286610035757933, 0.02884013012849859, 0.04339679955903973, 0.04916582642389195, 0.0640296381232994, 0.4038632831403187, 2.388754631791796, 8.166522656168256, 21.026322432926722, 34.224491664341514, 46.10006087166922, 41.795019558497835, 43.84179558072771, 41.88599232264927, 44.927534988948274, 25.488459042140416, 25.084819078445435, 18.942408289228165, 22.037089041301183, 30.210496493748256, 19.471968718937465, 22.673078502927506, 29.313827991485596, 18.950103419167654, 23.522143159593853, 24.5745781149183, 21.481311321258545, 26.806551422391617, 23.735293047768728, 21.308169160570415, 17.374354464667185, 20.309440306254796, 22.185724905558995, 18.617496626717703, 21.71515120778765, 21.067584310259136, 20.938425983701432, 16.851287126541138, 17.222696134022303, 17.19134065083095, 22.29830309322902, 16.433679546628678, 19.696188824517385, 20.23010924884251, 23.702071973255702, 25.047566311700002, 24.280471290860856, 34.03610863004412, 34.524632998875205, 30.974586418696813, 26.683283431189402, 21.18378598349435, 25.165388652256556, 20.424261025020055, 24.122981684548513, 30.758257729666575, 38.59979316166469, 37.02233321326119, 34.740979058401926, 28.015510184424265, 21.409939425332205, 12.598711660930089, 7.10041321175439, 1.912090620824269, 0.587208547762462, 0.031004650052636862, 0.013587557727337947, 0.024911749941696013, 0.020898089777412157, 0.030413808899798563, 0.04264733388221689, 0.03296598605811596, 0.05979230906814337, 0.03264172774340425, 0.02152273554487952, 0.059157702406602244, 0.024874201510101557, 0.09777142040963684, 0.05031087462391172, 0.03468691371381283, 0.022474950877949595, 0.01572952908463776, 0.05063772154971957, 0.02375808434693941, 0.044405034743249416, 0.020608122926205397, 0.03487962783713426, 0.017445113277062774, 0.010343067048649703, 0.013928451176200594, 0.01669507423814918, 0.023670461727306247, 0.03596657647618225, 0.011451606671991093, 0.003807209099509886, 0.02989689413724201, 0.02032927217494164, 0.036431050659822564, 0.01580843761829393, 0.0561411732009479, 0.09360045207930462, 0.009382074016944637, 0.0072364665601136425, 0.02425682794169656, 0.021950450093884553, 0.0709568089140313, 0.06168291797595365, 0.030881485768726895, 0.04766566352918744, 0.038197531763996394, 0.02818751514756254, 0.05890263430774212, 0.026709747301148515, 0.0642851744113224, 0.037542287459863086, 0.022430922436927046, 0.027483416322086538, 0.02787935677250581, 0.0735213388023632, 0.1899441805269037, 0.1461997064096587, 0.1057498115780098, 0.08228307150836502, 0.18713322707584926, 0.1432049378220524, 0.07163072989455291, 0.07241946578558002, 0.169769909498947, 0.09439635330012866, 0.12389400761042323, 0.11780476649957043, 0.14053112986896718, 0.1585711097078664, 0.15123130141624383, 0.14145244471728802, 0.15168860687741212, 0.16286421434155532, 0.09329465670245034, 0.21157091004507883, 0.11254747038973228, 0.21004621471677506, 0.21273428547595227, 0.10010323314262287, 0.16271158467446054, 0.18119449860283307, 0.12562368836786064, 0.1197637649519103, 0.11081590330494301, 0.26618869070495876, 0.18178099713155202, 0.103392574137875, 0.14945831655391625, 0.2215103759829487, 0.10009212552436761, 0.16456892501030648, 0.11312923952937126, 0.14995843757476124, 0.10017328509794814, 0.14358244756502764, 0.14830878323742322, 0.10213275173945086, 0.0857214391497629, 0.16589562382016862, 0.09710300913346664, 0.1183483816151108, 0.16570685537798063, 0.23965265176125936, 0.1416493962918009, 0.13952864866171563, 0.11880652845970222, 0.12491885333188943, 0.17799754015036992, 0.13538864866963454, 0.13031953067651816, 0.13940348609217576, 0.08498948306909629, 0.13499123070921215, 0.1196334862283298, 0.16201320929186686, 0.10194117416228567, 0.2277558972792966, 0.5982314848474094, 2.617887330906732, 9.541608503886632, 22.6418011869703, 39.50740507670811, 50.803091526031494, 51.473269598824636, 52.366554328373496, 51.88033676147461, 53.09835944856916, 33.46517167772566, 35.88394383021763, 30.222562040601456, 40.4380259513855, 39.896465982709614, 26.761527095522197, 36.2338307925633, 37.48615673610142, 20.356524774006434, 29.213919843946183, 26.72406588281904, 25.188494886670792, 30.345239434923442, 27.496867111751012, 25.698598623275757, 15.687227623803274, 24.267601490020752, 25.62952831813267, 22.02939738546099, 23.005436897277832, 24.002663203648158, 23.4871381350926, 18.67094738142831, 22.499665362494333, 20.787262712206157, 29.522492817470006, 21.366358586720057, 18.59664855684553, 24.606023924691335, 31.116093431200298, 32.736347334725515, 31.126442773001536, 36.7347229548863, 44.46507331303188, 38.14184086663382, 37.88564688818795, 27.02794882229396, 34.55247443062918, 25.461326326642716, 30.636737210409983, 40.45324945449829, 45.391487053462434, 44.97656495230538, 40.19687829698835, 32.433840138571604, 23.453329937798635, 13.49751239163535, 7.517555696623666, 2.1337535721915106, 0.5044787898659706, 0.10617851000279188, 0.12451547783400331, 0.15795966823186192, 0.15390996768006257, 0.13988075405359268, 0.08853996505162545, 0.08487164189240762, 0.13873141072690487, 0.11783215217292309, 0.08410231210291386, 0.13134145869740418, 0.11279379895755223, 0.14474359740103993, 0.13106004308376992, 0.1031757957701172, 0.13330133924526827, 0.08933843113481998, 0.1849456573171275, 0.15655326869870934, 0.08600969439638512, 0.13733050732740334, 0.1996149601680892, 0.057631351452852995, 0.08934483650539603, 0.10748556522386414, 0.14042249641248158, 0.12081667488174778, 0.14028731866606645, 0.12278178014925548, 0.09325575628983122, 0.09375080865408693, 0.08710050050701414, 0.1274299757289035, 0.20421758533588477, 0.0806599614609565, 0.16254419008535997, 0.08707731496542692, 0.1667099879788501, 0.10473502174551998, 0.12864414629127296, 0.1612238830753735, 0.194312290421554, 0.09419349847095353, 0.17819191329181194, 0.08403616172394582, 0.07454712768750531, 0.0938680934320603, 0.12071967151548181, 0.19145603797265462, 0.07345536484250001, 0.12643913818257196, 0.10894208813884429, 0.13958978466689587, 0.14291932886200293], [0.015134343611342567, 0.023888873668121438, 0.035424657698188505, 0.007668241293036512, 0.0547873431683651, 0.014841233446661915, 0.0645636994657772, 0.03756909637844988, 0.031186745102916445, 0.06082800456455775, 0.0256383964858417, 0.035293537591184886, 0.02620535490236112, 0.08928614322628294, 0.04048916165317808, 0.019082822005397508, 0.002247099968371913, 0.052532154002359936, 0.0706668301884617, 0.055617856460490396, 0.040392215962388685, 0.006653678769777928, 0.007060115308766919, 0.03582269651815295, 0.024914576040048684, 0.012084876619545477, 0.05219881010374852, 0.06563469235386167, 0.049913049542478154, 0.022712814721411893, 0.05463893738176141, 0.009458242117294242, 0.03201616256098662, 0.038241259953273196, 0.04409049305000475, 0.09573155415377446, 0.029828630121690885, 0.089652294293046, 0.03423813743782895, 0.05571321098666106, 0.04595815051080925, 0.026149404601060917, 0.015368088747241666, 0.0297394129447639, 0.029775310839925493, 0.11297922900744847, 0.023010377772152424, 0.04223854706755706, 0.027662157713036453, 0.01926628769641476, 0.014699691041771854, 0.020388355611690452, 0.035374018629746776, 0.050915836090488095, 0.02217002402591918, 0.03768607581566487, 0.03739436004044754, 0.05149143395413246, 0.02751597243228129, 0.027873380575329065, 0.016765071910672953, 0.02327268075064889, 0.1013311915365713, 0.06444366662097828, 0.7275190587554659, 4.183942028454371, 11.328809380531311, 20.880286931991577, 30.782069206237793, 35.69082907267979, 42.90536601202828, 39.871108531951904, 35.67880174091884, 34.366634437016074, 30.640068871634348, 34.977791036878315, 22.241439035960607, 29.486063412257604, 26.04527725492205, 23.846349579947336, 23.874302182878765, 21.871895619801112, 25.976651634488785, 22.65971711703709, 11.025065405028206, 24.120395217623027, 26.56890913418361, 27.567222833633423, 23.01536066191537, 17.852449587413243, 19.937046391623362, 21.26829171180725, 24.562467404774257, 20.17553809710911, 15.31748444693429, 23.91510374205453, 23.426266704286846, 37.818165983472554, 43.683018820626394, 21.085910184042795, 28.50359160559518, 23.702970027923584, 21.09431403023856, 24.92020583152771, 21.53268803868975, 32.76431383405413, 33.36036852427891, 24.295166730880737, 18.09940767288208, 26.99170354434422, 30.434940678732737, 29.189430918012345, 35.051518372126985, 31.408393723624094, 26.80094943727766, 17.54983295713152, 8.775856222425189, 4.4331218004226685, 0.9912124233586448, 0.31780900220785824, 0.03151051487241473, 0.04901174469185727, 0.0159659646118858, 0.05097596447116562, 0.02148128892960293, 0.01994214759075216, 0.034822708927094936, 0.03587017022073269, 0.028343445887523036, 0.030944141692348888, 0.013178084744140506, 0.07388818197484527, 0.05587791518441268, 0.12692825336541447, 0.035095649638346264, 0.03197162691503763, 0.027330328643854176, 0.016451497129829865, 0.03713816896613155, 0.028702455373214822, 0.03667250395353351, 0.04883692692965269, 0.055228160228580236, 0.04102344691221203, 0.042274499245520146, 0.02145552495494485, 0.003196515708363482, 0.03234839366216745, 0.1313028364841427, 0.03944461466744542, 0.038262284360826015, 0.055795018561184406, 0.03918611318139093, 0.015628985461911986, 0.042115223327917714, 0.013131007984546679, 0.04777804249897599, 0.04153153732685106, 0.041762262981917174, 0.038807680630790334, 0.020246694463172128, 0.1006650940648147, 0.029313971488071338, 0.02663060467291091, 0.11673485248216561, 0.04449472010933927, 0.0331020153659795, 0.05885447867746864, 0.027611145450334464, 0.05380360988367881, 0.03260554486353483, 0.021652468047770004, 0.08743450258459363, 0.030581451154180934, 0.0030835716461297125, 0.060462688095867634, 0.020033765085307614, 0.022090857648955922, 0.012741748559554773, 0.033362990112176964, 0.03701688761689833, 0.013821898277715912, 0.034040520898997784, 0.00990795816427895, 0.06488656678370067, 0.026657245654080595, 0.010659197362006774, 0.031759862921067646, 0.012913042180506247, 0.04570767609402537, 0.06370902354163782, 0.027201094864202396, 0.026311621967969195, 0.019772242422082593, 0.14434153826109, 0.048472563802663765, 0.03973498694332583, 0.02519792378214853, 0.03673244234440582, 0.008530921385889607, 0.040257411410233805, 0.07525718065776996, 0.06671388194497142, 0.055421013451580486, 0.024968558589794805, 0.055484829670084376, 0.0721903991486345, 0.038795317722750564, 0.06315113883465528, 0.1278095075062343, 0.04079771188220807, 0.016509215014853647, 0.07051918096840382, 0.0013512863744316356, 0.027643469162285328, 0.09375008940696716, 0.06423775159886905, 0.052990110857146125, 0.041338314302265644, 0.02842581664611186, 0.04186172603762575, 0.12492637149989605, 0.07876996323466301, 0.027037021704018116, 0.010389612854591437, 0.09953814917909247, 0.02648764243349433, 0.03509693206953151, 0.05019185958164079, 0.005349814783715243, 0.03171824497569885, 0.027000187430530787, 0.024956596017416035, 0.07328311194266592, 0.011141405906528234, 0.08037877654922859, 0.03135335937674556, 0.029185568913817406, 0.05397638186280217, 0.18030876613089017, 1.1339367819683892, 6.023707330226898, 14.167016489165169, 25.546195098331996, 36.589050497327534, 42.44501311438424, 46.689375809260774, 45.04681124005999, 39.026641845703125, 38.378381865365164, 33.0497909954616, 39.62806054524013, 26.365544046674454, 28.868392876216344, 25.58716341427394, 26.65211728640965, 18.766747406550817, 19.625126123428345, 21.245338337762014, 22.02807722772871, 19.402087211608887, 27.37091885294233, 31.912450790405273, 24.58196405002049, 26.536973476409912, 24.99203109741211, 25.788984264646256, 22.9095413344247, 28.319123881203787, 25.90426877566746, 23.08080574444362, 31.400747231074742, 28.666073492595128, 46.88417897905622, 42.4178352355957, 20.39212908063616, 27.53773988996233, 31.211794444492885, 30.03831318446568, 25.84287796701704, 26.651469366891043, 41.27075713021414, 37.1258544240679, 27.05270004272461, 17.936778136662074, 28.846709285463604, 30.356137684413365, 30.577378749847412, 38.33975682939802, 36.556122984204976, 29.760902881622314, 22.057798147201538, 11.382519824164254, 6.49160293170384, 1.9102280693394798, 0.6407846957445145, 0.04145486965509398, 0.02134210104122758, 0.013108126087380307, 0.06443067267537117, 0.03653172829321452, 0.027457782965419546, 0.018887251249647567, 0.020532452700925723, 0.050949169123279195, 0.0343911810112851, 0.030482398612158637, 0.037503091884510856, 0.016955687664449215, 0.057376907606210024, 0.019757918547838926, 0.0532489210766341, 0.03495601052418351, 0.051931579264679124, 0.00169410665070505, 0.02163319256422775, 0.07724734422351633, 0.03780396788247994, 0.054994822213692326, 0.02867637248709798, 0.025765788042917848, 0.05812165407197816, 0.03531321510672569, 0.03245285752096346, 0.030356350554419414, 0.04717434989288449, 0.06061495813940253, 0.08451104802744729, 0.07811430163149323, 0.013273010945080646, 0.017569315719551275, 0.01927756834109979, 0.04335217909621341, 0.0384290682684098, 0.035040410102478096, 0.05241593452436583, 0.011330455940748965, 0.050185040304703374, 0.04523061169311404, 0.04182652024818318, 0.05355492001399398, 0.05543200571888259, 0.004799067841044494, 0.005371212385528321, 0.038015229760536125, 0.031471336260437965, 0.055560832377523184, 0.012224479262450976, 0.06209955204810415, 0.045395892645631514, 0.018281377153471112, 0.03207446228978889, 0.0938713096880487, 0.13430516395185674, 0.11613050848245621, 0.1407483967819384, 0.14116522084389413, 0.07344574321593557, 0.12521890151713574, 0.11945579147764615, 0.11775934536542211, 0.13134627629603657, 0.13440180090921267, 0.18909431541604654, 0.12087737662451607, 0.24442541279963084, 0.1450386108564479, 0.0784655317131962, 0.24109798563378199, 0.10204079667372362, 0.21335836127400398, 0.21130959263869695, 0.11975764456604208, 0.0943013516121677, 0.09980415526245322, 0.10573214931147439, 0.1431239614529269, 0.14009358334754193, 0.19031114583568914, 0.16037799417972565, 0.09143501613289118, 0.14745190207447323, 0.20655543703053678, 0.12074073324246065, 0.15070302119212492, 0.1680009008518287, 0.09901565685868263, 0.13694944206093038, 0.14186123492462294, 0.15528021486742155, 0.08601031186325209, 0.13419720903038979, 0.1336974272770541, 0.08391853767846312, 0.07426404287772519, 0.1329640666288989, 0.1106818722827094, 0.23085908219218254, 0.13446001921381268, 0.15354544509734425, 0.06621619007949318, 0.20288473899875367, 0.12770561022417887, 0.07026039449764149, 0.11985346728137561, 0.12564542862985814, 0.09301294253340789, 0.15386084174471243, 0.12193536199629307, 0.14451417114053453, 0.24840189942291804, 0.1826065028352397, 0.12272889512990202, 0.16091546176799706, 0.17399677554411547, 0.2159683597939355, 1.2489589984927858, 6.02436089515686, 15.86044795172555, 27.966574021748134, 40.703082357134136, 47.36477197919573, 53.267951079777305, 53.0271577835083, 49.759173325129915, 47.59799868719918, 42.18753719329834, 48.62183312007359, 32.86133847917829, 40.280711787087576, 36.68885442188808, 35.51053721564156, 34.084794657570974, 33.62334394454956, 36.49228640965053, 33.65614291599819, 20.53136055810111, 35.567442962101524, 37.182461397988455, 37.514637402125764, 33.11509016581944, 28.837848595210485, 31.94243574142456, 30.62168393816267, 34.911074434007915, 31.85971396309989, 24.744777713503154, 33.80747468130929, 31.239962441580637, 49.83104549135481, 54.47075373785836, 28.422610351017543, 37.312451771327424, 35.059536593300955, 33.62581402914864, 34.46340547289167, 30.162411485399517, 46.9891072000776, 44.433716092790874, 33.94932910374233, 25.664599350520543, 37.06865685326712, 39.815439564841135, 39.13878229686192, 45.26410572869437, 42.945363317217144, 34.27175678525652, 25.3446295942579, 12.7413911819458, 6.859157860279083, 1.9454530477523804, 0.6144013000386102, 0.10852756431060177, 0.119534379403506, 0.07600103145731346, 0.18311350420117378, 0.23315014211194857, 0.05621227688555207, 0.21423722697155817, 0.13360282592475414, 0.17893033581120626, 0.18653758189507894, 0.09919074603489467, 0.12926397446010793, 0.13290725967713765, 0.18216544150241784, 0.151320270927889, 0.11089094927800552, 0.08828848640301398, 0.10219436950449433, 0.09275135371301856, 0.1959696122046028, 0.19956413789519242, 0.16578099211411818, 0.19704418097223553, 0.15328259420182022, 0.12451182731560298, 0.23808851997767175, 0.07706431618758611, 0.1027732277289033, 0.2107920739799738, 0.2050824596413544, 0.13720705466611044, 0.1773409489542246, 0.1855913648115737, 0.06545414097074952, 0.13266293278762273, 0.10222970082291535, 0.1858277799827712, 0.18559270831091063, 0.15474657421665533, 0.08417987544089556, 0.13988281680004938, 0.1974765977689198, 0.1494438230459179, 0.13602953856544836, 0.172491011342832, 0.09191740024834871, 0.16578450692551477, 0.14173809438943863, 0.13844200197075093, 0.11213321119014706, 0.14195811615458556, 0.09425975063017436, 0.13187819346785545, 0.10990469184304986, 0.12309485620685987, 0.10960348336292164], [0.06386304420552083, 0.03525583818554878, 0.0660433264981423, 0.04768672525616629, 0.00739336760515081, 0.021051995090341995, 0.01943371960494135, 0.016310397469039475, 0.08631935063749552, 0.03179489568408046, 0.01667989371344447, 0.020093001192435622, 0.02418309323755758, 0.040979766220386536, 0.05555129556783608, 0.055374601656304936, 0.03650645625644496, 0.02993754517020924, 0.019332395666944127, 0.042053188263837776, 0.10576192342809268, 0.06818136320050273, 0.03647749298917396, 0.016011519756700312, 0.02867193826075111, 0.04728651851681726, 0.04550982206793768, 0.010049634579835194, 0.015232173093993748, 0.033585573347019296, 0.041137939518583674, 0.04473442956805229, 0.06039662592645202, 0.0640128715229886, 0.01864693110941776, 0.032827164578650675, 0.01305929192208818, 0.02939198605184044, 0.05565179678212319, 0.03374108000259314, 0.016735496265547614, 0.03770501033536025, 0.05192654114216566, 0.03015724123854722, 0.047777489492935796, 0.04082222395975675, 0.0789778595790267, 0.0628011097599353, 0.10666510103536503, 0.1087025652772614, 0.005468334071338177, 0.03554376773536205, 0.02891573928562658, 0.017879955836438706, 0.029754866579813615, 0.03569897922820278, 0.025936819579718367, 0.018463938696576015, 0.061220367439091206, 0.07221254653164319, 0.044628941121378114, 0.04227745087285127, 0.016455142559217553, 0.009157606151088007, 0.06761376865740333, 0.18122142287237303, 1.5951799175568988, 4.72306317942483, 11.294578211648123, 19.22991779872349, 28.679978575025284, 39.61958026885986, 42.41908243724278, 38.58383314950125, 44.8157627923148, 44.36209406171526, 38.81599678312029, 39.58656242915562, 38.92590338843209, 26.773530108588083, 35.402972153254915, 37.214464800698416, 36.68565477643694, 27.563217197145732, 25.842617409569876, 22.71913811138698, 16.83524547304426, 31.319286550794327, 25.335649047579082, 15.059324128287178, 21.730141946247645, 25.312264885221207, 27.02048819405692, 18.47211251940046, 21.307212046214513, 16.26636345045907, 22.07788712637765, 33.03973695210048, 67.65591594151088, 43.440530163901194, 39.45163188661848, 15.835818324770246, 20.27782426561628, 20.160627262932913, 23.015919991901942, 29.0053106035505, 39.10773079735892, 31.741761343819753, 30.85873215539115, 32.8112211227417, 35.37277180807931, 33.64141273498535, 27.14348520551409, 20.004732268197195, 10.97139665058681, 3.5023426370961324, 1.394330295068877, 0.1280795915850571, 0.08657716001783099, 0.02884293926347579, 0.03480995246874435, 0.027511597577748553, 0.04364987276494503, 0.019798798586374948, 0.04215221705713442, 0.024949466310707585, 0.030702128607247556, 0.044918421123708994, 0.036339048096644025, 0.015045409722785865, 0.026890296987923126, 0.06675339982445751, 0.02957240172794887, 0.021841168636456132, 0.05728635710797139, 0.029128809459507465, 0.031852333673409054, 0.03588023289505925, 0.011178833049988108, 0.0755135447585157, 0.04014528349840215, 0.019525089434215, 0.02956564351916313, 0.021076893932851296, 0.015726935384528976, 0.019753601368782774, 0.017055946302467158, 0.02621208088073347, 0.05853174706654889, 0.04167736468038388, 0.04293013370728918, 0.03212259417133672, 0.01969707940172936, 0.01652735734491476, 0.06348338350653648, 0.02570219913364521, 0.025182388722896576, 0.06834232527762651, 0.03998052841052413, 0.017062448364283358, 0.047264818966920884, 0.014499211085161992, 0.016267870286745683, 0.07802097592502832, 0.009318996553442307, 0.02946850105321833, 0.019465339336810366, 0.025799991296870366, 0.004193351928344262, 0.05652128512571965, 0.0068040035382312325, 0.05953251836555345, 0.04526954942515918, 0.01545946196919041, 0.02949443126895598, 0.018588573705138903, 0.04342649903680597, 0.06907958071678877, 0.026311387873387763, 0.012000465166888066, 0.039396299581442557, 0.03728395560756326, 0.03201998271314161, 0.1122496613700475, 0.029873732344380448, 0.03478485685107963, 0.024917171436495016, 0.0038037197331764866, 0.032675247373325486, 0.07920441563640322, 0.027995686512440443, 0.027459501355354275, 0.010116601745331926, 0.047892368864268064, 0.011550706711464694, 0.0074466393894648975, 0.040187105004276545, 0.045386135312063355, 0.0672726012500269, 0.03201328896518264, 0.05664839848343815, 0.09066004771739244, 0.05740949764315571, 0.055321136489510536, 0.09750153310596943, 0.03196187975949474, 0.12197203002870083, 0.046785420405545404, 0.012740724819845386, 0.031080561157848154, 0.037385478017053435, 0.01878470425227923, 0.03411040661324348, 0.014913957133623106, 0.0602312669424074, 0.04753970707367573, 0.04043948949713792, 0.04982073146051594, 0.0727437851684434, 0.1421761294560773, 0.010733331553637981, 0.020828524670962776, 0.008914883148723414, 0.03198441390746406, 0.07002050522714853, 0.029338110371359756, 0.028430554516879574, 0.03187859637130584, 0.03320183804524796, 0.057679805638534684, 0.05123639978202326, 0.035513389722577164, 0.03529081666576011, 0.021314101293683052, 0.037552065149481804, 0.03780832068462457, 0.030733521029885327, 0.009433789411559701, 0.01643161096477083, 0.0530283802321979, 0.02841682605711477, 0.4000946996467454, 2.9428619614669254, 7.435417566980634, 16.191738060542516, 25.221672534942627, 36.04505865914481, 45.25069570541382, 46.14863920211792, 45.6050295148577, 48.57106958116804, 47.68393053327288, 39.163740226200645, 41.93030098506382, 40.00357246398926, 31.569063867841447, 32.70416675295149, 35.46248000008719, 36.5418826511928, 27.820057358060563, 18.941282681056432, 25.645750624792917, 21.750295196260723, 26.08022321973528, 25.369533675057546, 17.297427483967372, 24.60150064740862, 26.079443284443446, 29.93051188332694, 23.38470605441502, 18.22039839199611, 18.822440692356654, 21.895019224711827, 40.14810194287981, 71.787919316973, 35.6437063898359, 42.64684438705444, 22.34964506966727, 20.480035952159337, 20.265763929912023, 20.860368183680944, 34.93549387795584, 43.50656584330967, 33.55866663796561, 29.609803880964005, 36.24772718974522, 39.79761743545532, 37.58167362213135, 31.658014706202916, 24.264068331037247, 14.851546934672765, 5.709657873426165, 2.282310400690351, 0.3368659024792058, 0.07320628820785455, 0.06886631037507739, 0.08375201161418643, 0.028365291322448423, 0.03503697671528373, 0.017330193193629384, 0.030113326452140297, 0.03107355528378061, 0.012527596970487918, 0.0241401589342526, 0.05967857302831752, 0.04030624896820102, 0.009825583164846259, 0.024200324634356157, 0.026854639972693155, 0.019834760942363312, 0.0693432797810861, 0.038612299864845614, 0.026948267627241354, 0.06955329994005816, 0.03727723132552845, 0.024137169987495457, 0.01714391158228474, 0.014866797253489494, 0.05608798623351114, 0.01798609228405569, 0.07873113746089594, 0.023971821181476116, 0.03550520319757717, 0.016196479921096137, 0.016894127574882338, 0.019037383907873715, 0.021782156445884278, 0.03199075820988842, 0.04775476535516126, 0.029740739480725358, 0.008560519083403051, 0.08657979273370334, 0.04515616961621812, 0.02612628860931311, 0.01992778978975756, 0.04415566633854594, 0.006866533932874778, 0.01663167871135686, 0.025381292781925628, 0.04519800469279289, 0.028654113145811216, 0.07047629076987505, 0.041423694363662174, 0.06422363807048116, 0.014024405357693987, 0.07965823342757565, 0.017034060155440654, 0.08620009132261787, 0.05070275573858193, 0.00182092230118412, 0.08270821440964937, 0.0382038557103702, 0.16323724575340748, 0.20950980564313276, 0.1106994870517935, 0.11823224356131894, 0.11140662232147795, 0.10533693658986262, 0.0887301652027028, 0.24331030834998402, 0.10950669712786164, 0.08152453721101795, 0.11669515818357468, 0.12288440178547587, 0.1375718486628362, 0.18666639498301915, 0.16368418319949082, 0.13523924882922853, 0.09794528143746511, 0.1335391929107053, 0.059109960682690144, 0.09889679787946598, 0.09963561394917113, 0.18809087068906852, 0.16785730927118234, 0.11114089443747487, 0.11380402224936656, 0.25122859488640514, 0.13108459248074464, 0.12590541610760347, 0.16985803762716906, 0.09176977816969156, 0.17087417095899582, 0.1923006105103663, 0.13654924210693153, 0.12407779560557433, 0.18846942537597247, 0.15704835498971598, 0.0668927166344864, 0.09660830282207046, 0.11354226379522256, 0.15548818585063728, 0.15341714769601822, 0.1667949269924845, 0.19749293689216885, 0.14897381540920052, 0.15891842464251177, 0.18732612101095064, 0.17649748921394348, 0.14602327373410973, 0.19107046723365784, 0.1900863471840109, 0.17786278309566633, 0.10665415626551424, 0.11124667126153197, 0.1904318436448063, 0.09238301776349545, 0.10806915962270328, 0.12283409519919328, 0.07667362929454871, 0.1236907456602369, 0.19761990436485835, 0.11874565029782908, 0.1965788280857461, 0.10878325666167907, 0.10093631808246885, 0.12312146835029125, 0.43039204818861826, 2.86027067899704, 8.262715254511152, 18.654815401349747, 27.94104286602565, 40.1248220035008, 52.02820137568882, 54.439049107687815, 53.033018589019775, 57.763432094029014, 57.19203308650425, 50.28627061843872, 50.23046963555472, 51.77409880501883, 41.02820941380092, 46.784586974552695, 49.58576365879604, 49.350730419158936, 37.157267229897634, 35.03040974480765, 33.20946059908186, 30.366969926016672, 42.19218553815569, 35.77941165651594, 28.122620139803203, 34.707054478781565, 38.08866630281721, 37.786857400621685, 28.788134234292166, 31.116065638405935, 26.317570209503174, 31.626977103097097, 41.843128885541645, 79.7808004106794, 54.92549596514021, 48.373382908957346, 25.45850362096514, 31.395765372685023, 29.514248779841832, 32.34456968307495, 41.93383066994803, 52.603005000523154, 42.28931788035801, 40.357572759900776, 44.7587319782802, 45.679889406476704, 43.66966438293457, 34.99695764269148, 26.831448554992676, 15.17345871244158, 5.84135012115751, 1.9756957335131509, 0.4457942231425217, 0.14847704635134765, 0.3764308180127825, 0.1981052468929972, 0.17469905928841659, 0.12305498548916408, 0.09959119026150022, 0.15601760601358755, 0.16050583017723902, 0.11892339933131423, 0.13105635185326847, 0.11859634545232568, 0.09412977724735226, 0.15062802950186388, 0.1702460375215326, 0.10604107952011482, 0.12289134998406682, 0.22919333300420217, 0.0976005449358906, 0.08617841212877206, 0.16388272254594735, 0.0859472556039691, 0.15542326362005301, 0.13663576889250958, 0.0614265538752079, 0.09435199068060943, 0.10734794475138187, 0.16024376638233662, 0.10791398544928857, 0.10767349228262901, 0.1237257852085999, 0.13415238500705787, 0.08910199560757194, 0.10289116390049458, 0.1004475625231862, 0.12641289244805062, 0.09639295616320201, 0.13119874921228203, 0.15670238355440752, 0.14746601560286113, 0.11228221748024225, 0.14656798807638033, 0.16220554682825292, 0.1073424079056297, 0.13213744812778064, 0.07919630714293037, 0.24711870827845164, 0.07998064612703663, 0.17863586518381322, 0.09617711417376995, 0.10757146097187485, 0.09923166169651917, 0.19336559836353573, 0.09421968313732318, 0.1800958282713379, 0.13944873080721923, 0.10391508002898522, 0.1411115215825183, 0.08277586435100862], [0.0009632299708235742, 0.042025911156088114, 0.042107796762138605, 0.05051476761166539, 0.044325374732060094, 0.06790294671165091, 0.05083767903436508, 0.04214203224650451, 0.050890326566462, 0.04550613762278642, 0.06890397585396256, 0.04034796190847244, 0.03106110416618841, 0.029136544758720056, 0.042227354632424455, 0.05619033306304898, 0.050266322014587264, 0.007623424055054784, 0.05786793625780514, 0.055175305743302615, 0.016318360077483312, 0.06427054519632033, 0.022208659809881022, 0.036166381290448565, 0.02788475451857916, 0.013210343995264598, 0.018059531825461557, 0.020062736834266355, 0.02572376636921295, 0.012265397468581796, 0.015095421146335346, 0.06870149421904768, 0.03265248591612492, 0.029605086759797165, 0.04618616881115096, 0.009329833605858897, 0.048896274995058775, 0.04214541135089738, 0.02651044969180865, 0.05638540509556021, 0.030070724630994455, 0.02834880631417036, 0.13284236458795412, 0.011716665350832045, 0.07903620680528027, 0.04294705297797918, 0.0393096778009619, 0.06480332410761289, 0.019038138778081963, 0.0860674377264721, 0.025624218496627042, 0.014483764235462462, 0.043774570537997146, 0.058600313030183315, 0.02354849505770419, 0.02153707468616111, 0.014401866755049144, 0.030427477987749234, 0.03059543576091528, 0.040707962055291445, 0.013345059489698281, 0.03922240123418825, 0.07045630791357585, 0.050904423131474426, 0.040957187967641015, 0.008083857562659042, 0.04310949765411871, 0.30883472519261496, 1.8265548220702579, 5.455471924373081, 11.537207569394793, 18.309983253479004, 26.390713896070206, 32.43229763848441, 39.135725089481895, 43.19040891102382, 43.90262358529227, 47.89449221747262, 46.59670073645455, 43.366160120282856, 48.83987801415579, 38.77557216371809, 34.479956081935335, 36.06582335063389, 34.923028809683665, 24.720498970576696, 21.085131985800608, 20.819285222462245, 29.116507836750575, 25.970410415104457, 23.281429767608643, 17.429293870925903, 21.250587701797485, 24.42634003502982, 41.64411163330078, 23.832347222736903, 28.36786723136902, 25.171892166137695, 69.33281503404889, 66.94678974151611, 27.724074942725046, 23.6367415360042, 28.29726137433733, 24.150965554373606, 30.78342410496303, 33.63214383806501, 36.4831599508013, 43.22072042737688, 34.84440994262695, 31.708587169647217, 24.22737489427839, 16.164615767342703, 6.8398957167352945, 2.7135746649333408, 1.17594005380358, 0.04979041451588273, 0.03661647392436862, 0.05516237286584718, 0.019899620408458368, 0.07817388379148074, 0.1297954437988145, 0.024514801866774048, 0.048092804716101716, 0.044701337415192804, 0.008427065664104052, 0.08024680148810148, 0.027166494667263966, 0.05043744176094021, 0.028727897043739046, 0.041219689417630434, 0.03314947549785886, 0.03536429861560464, 0.05849509939019169, 0.021197885208364044, 0.04239837938387479, 0.021370838695604886, 0.02395034724447344, 0.030436505896172354, 0.051537618440176756, 0.09820508571075541, 0.06437268507267747, 0.030942859261163642, 0.06400337203272752, 0.027091611542605927, 0.03450482544888343, 0.049238304141908884, 0.06048693893743413, 0.03144196587215577, 0.057463095124278746, 0.009584895767537611, 0.030623778168644224, 0.04803433196086969, 0.0556702156152044, 0.06842748820781708, 0.03176975596163954, 0.025626501766964793, 0.05761502590030432, 0.07371634976672274, 0.08345284552446433, 0.029104341486735002, 0.016010015105296458, 0.01769833915334727, 0.057525649267647944, 0.046422963961958885, 0.020618497726640532, 0.0670891593077353, 0.05003385591719832, 0.05712969694286585, 0.03673045423680118, 0.0698627322646124, 0.0307423691265285, 0.05251687678641506, 0.07881741997386728, 0.10492952380861555, 0.06455999466457538, 0.02407911283496235, 0.0097883748489299, 0.01614301136162664, 0.02022443342554782, 0.03170515264251402, 0.04162260351170387, 0.023303196166775057, 0.04252936378387468, 0.023299801795344268, 0.03545822482556105, 0.05352094576561025, 0.03462124170203294, 0.044863985651837926, 0.08809703096215214, 0.03594871064914124, 0.016759969327332716, 0.053426296915858984, 0.06192554174257176, 0.04039936772148524, 0.020183583921087638, 0.06701103957103831, 0.029599729725824933, 0.0918877346973334, 0.011294250160322657, 0.03656218094485147, 0.03881499184561627, 0.01083791330789349, 0.02377369234870587, 0.023435586830601096, 0.0066644768064309445, 0.007061929965857416, 0.026619890604966452, 0.009328881960495241, 0.0652494744530746, 0.02177853137254715, 0.05433688412553497, 0.01435009453312627, 0.015623879485896655, 0.037575847801885436, 0.039131996620978625, 0.04726188430296523, 0.03500163521883743, 0.03632875132773604, 0.0813650679109352, 0.022179450573665754, 0.041154570411890745, 0.027648039095635926, 0.02413472726142832, 0.027786784239911606, 0.03207146995035665, 0.02991548938942807, 0.032298677401351075, 0.03285089634092791, 0.022468199454514042, 0.011175677013982619, 0.02965074877387711, 0.025145897109593664, 0.04269730459366526, 0.019577499479055405, 0.030653447112334625, 0.05794710772378104, 0.01328091842255422, 0.020513445238715837, 0.02708647333617721, 0.03718747810593673, 0.011765536835550197, 0.09158264499689851, 0.11680692647184644, 0.4812750092574528, 3.0412734236036028, 7.777770945004054, 15.19290498324803, 24.06901502609253, 33.97869566508702, 39.04744822638375, 44.14143317086356, 50.612155028751914, 50.116904803684776, 53.48142058508736, 52.617919308798655, 46.11929695946829, 52.3690105165754, 41.66283008030483, 38.59212929861886, 35.62587036405291, 34.30363859449114, 25.857959032058716, 23.35414613996233, 24.24010920524597, 33.05536345073155, 29.507950237819127, 28.299252033233643, 23.342447110584803, 25.422852413994924, 25.063828570502146, 35.34745257241385, 22.476189136505127, 30.504266330174037, 25.177171060017177, 75.2155282156808, 65.68798460279191, 33.98667914526803, 20.294296707425797, 26.470824888774327, 22.895281893866404, 28.968038729258947, 36.17451054709298, 42.04232331684658, 47.07085970469883, 39.24077490397862, 36.581271989004954, 29.396959713527135, 20.162246193204606, 10.26204810823713, 4.652321832520621, 1.8227843386786324, 0.2287712570812021, 0.030112332398337976, 0.05720287694462708, 0.054354570140796046, 0.026591370081795112, 0.049853226502559016, 0.04885933894131865, 0.06596978687282119, 0.02995698180581842, 0.025917803635820746, 0.06940233946910926, 0.02988507066454206, 0.02454053870003138, 0.054170164678777964, 0.022887971751125794, 0.03589122176968625, 0.019149908762691275, 0.025245606134246503, 0.014366301342046686, 0.02337526167476816, 0.03588767981688891, 0.04312016761728695, 0.05991729521857841, 0.05717813755784716, 0.05818969077829804, 0.11440943154905524, 0.036557275136666637, 0.05114991031587124, 0.04419728767658983, 0.010292816441506147, 0.01396256367609437, 0.031843271838235, 0.03683617677805679, 0.027103926953194395, 0.02228273547786687, 0.017112909317282692, 0.023430241670991694, 0.08726974071136542, 0.0028643009344315423, 0.05865550506860018, 0.03199094819969364, 0.04763120412826538, 0.06949489164565291, 0.1023883151688746, 0.030655299512935535, 0.01625179748849145, 0.048146042573664866, 0.007316474320500025, 0.015142653968983462, 0.01639672917579966, 0.028065034487683858, 0.03713050491309591, 0.08334535200681005, 0.0947006626852921, 0.05856045588318791, 0.04363707559449332, 0.02899162324943713, 0.0551132130037461, 0.0044109538679809445, 0.08970016493861165, 0.036458497401326895, 0.1443917905645711, 0.17338305419044836, 0.12645284458994865, 0.11959660106471606, 0.1775617306785924, 0.11509306915104389, 0.10047715343534946, 0.11919406695025307, 0.1481430171323674, 0.1354709006845951, 0.13227972335049085, 0.1214984804391861, 0.2140932282699006, 0.13563068211078644, 0.09808843197034937, 0.20163259761674063, 0.1765679075781788, 0.11038511499230351, 0.21797225012310914, 0.18077224626072816, 0.11810188341353621, 0.2222372226949249, 0.18051228592438356, 0.12378519773483276, 0.1567548614527498, 0.08268608738269125, 0.17749934616897786, 0.10584124417177268, 0.0776353305471795, 0.10096373089722224, 0.11207978334277868, 0.10250166444373982, 0.13731312326022557, 0.08508045425904648, 0.19833408961338655, 0.06700353497373206, 0.15185993696962083, 0.10299348019595657, 0.14714918046125344, 0.11779975891113281, 0.11578544628407274, 0.10712313931435347, 0.21499995461532048, 0.08101707444127117, 0.2573187452341829, 0.1302484337772642, 0.09954167077583925, 0.09820516713495765, 0.0909201709021415, 0.15329738626522676, 0.11180915643594094, 0.12268028488116604, 0.12339102317179952, 0.12252504963959966, 0.08304767869412899, 0.1385302250938756, 0.13595765456557274, 0.13124848582914897, 0.13501635007560253, 0.13171497865446977, 0.08389237336814404, 0.13749631414456026, 0.18861864879727364, 0.13995596287505968, 0.09335896146616765, 0.15576722659170628, 0.2548684738576412, 0.6534781860453742, 3.381800945316042, 8.094773820468358, 16.57503022466387, 24.50158381462097, 35.78518908364432, 44.38861880983625, 50.78793750490461, 57.469957556043354, 60.38310446058001, 62.40034021650042, 60.410063471112935, 57.26978342873709, 61.811376162937705, 49.99863256726946, 47.176739828927175, 47.396615573338096, 46.88452638898577, 34.28166839054653, 34.005713735307964, 31.943561349596294, 41.781984737941194, 39.24883828844343, 36.178443227495464, 29.710080283028738, 34.80144228254046, 34.93378462110247, 54.8569415637425, 33.232893398829866, 39.33782039369856, 32.69657237189156, 77.29012135096959, 77.52563749040876, 37.22763511112758, 30.744343961988175, 37.00809982844761, 32.429511410849436, 39.18804155077253, 44.45797572817121, 49.48776626586914, 54.8982138633728, 45.48308515548706, 42.483992508479524, 33.013007232121055, 21.87852767535618, 12.05626666545868, 5.453394847256797, 1.9713509380817413, 0.3265910638230187, 0.12562744745186397, 0.16167854224996908, 0.12002935712890965, 0.16855149130736077, 0.3384657252047743, 0.16439212592584745, 0.13181362407548086, 0.09331727227462189, 0.06839417213840143, 0.19239970376448973, 0.12777815918837274, 0.0868406148095216, 0.17477257177233696, 0.13017915535186017, 0.1261050682514906, 0.07655567276690688, 0.18393720500171185, 0.08105998499585049, 0.10806248962346997, 0.1994829579655613, 0.1830781932388033, 0.08510567540568964, 0.10987797113401548, 0.22692014569682734, 0.29399996836270603, 0.10910351161978074, 0.17316084754254135, 0.14784980858010904, 0.09991447148578507, 0.09199581854045391, 0.10484130747084107, 0.08384676224419049, 0.08647816175861017, 0.11647432217640535, 0.12834641869579042, 0.12877279653080873, 0.13668945458318504, 0.18575274758040905, 0.2049493853534971, 0.19654631268765244, 0.14429393224418163, 0.1463931838848761, 0.12709028752786772, 0.12036692830068724, 0.1542154848575592, 0.1039363792432206, 0.14987861471516745, 0.15585095781300748, 0.13189424760639668, 0.09788070525974035, 0.13911882708115236, 0.17557455945227826, 0.2623344489506313, 0.1708167940378189, 0.11181738028036696, 0.14132962987891265, 0.12504366306321962, 0.1766032049698489, 0.16717764788440295, 0.12993481489164488], [0.07165690777557236, 0.12972536470208848, 0.07458444711353097, 0.053132325011704645, 0.044354500847735574, 0.03352647294689502, 0.05304244626313448, 0.01893617701716721, 0.028583782991128306, 0.053778765323970995, 0.04520269336977175, 0.03796871957768287, 0.1176718957722187, 0.03145991651607411, 0.012765394656785896, 0.07619907547320638, 0.036909088758485656, 0.05363272762458239, 0.07823877209531409, 0.0245690948462912, 0.02803299915311592, 0.05964900925755501, 0.0612236854753324, 0.03292135541726436, 0.03576372503968222, 0.010060659925719457, 0.04461240183029856, 0.0469930114091507, 0.04949733488527792, 0.03326852446688073, 0.008301545167341828, 0.03558458500940885, 0.05140820824142013, 0.033654753384845595, 0.029328509100845883, 0.08011222085250275, 0.06650029947715146, 0.03762389147388084, 0.013466091477312148, 0.04802368913910218, 0.05187600385397673, 0.027661279010187303, 0.03445434922884617, 0.020153005740472248, 0.015666216678385223, 0.08499059586652688, 0.06995263815458332, 0.01690356430065419, 0.037394661988530836, 0.016080180715237345, 0.09304815850087575, 0.05481583146112306, 0.03554258029907942, 0.07141206519944326, 0.02348743029870093, 0.02487842199791755, 0.03240082406305841, 0.08550861664116383, 0.04791439750364848, 0.036362545764339824, 0.03906582588596003, 0.0494419698204313, 0.056702073996088335, 0.04189781392259257, 0.051838060175733905, 0.05939539322363479, 0.0486580481353615, 0.02370672603137791, 0.03207580918180091, 0.1972154974937439, 2.0236654451915195, 4.183737925120762, 7.673706037657602, 13.597902570452009, 22.21614933013916, 30.150408472333634, 32.59690046310425, 39.06457553591047, 44.3862737928118, 43.8515682220459, 45.05542353221348, 48.66693040302822, 49.3608261517116, 45.49921192441668, 42.17999144962856, 44.51371765136719, 40.58551188877651, 37.17365803037371, 35.74238470622471, 45.54732819965908, 32.06200729097639, 35.559959752219065, 38.89668273925781, 35.160167353493826, 41.41095788138253, 30.541581630706787, 29.86499731881278, 33.48654086249215, 46.08440310614449, 68.62364019666398, 25.285330193383352, 36.19593184334891, 31.44759198597499, 33.50588812146868, 37.112857818603516, 38.34913689749581, 32.33895901271275, 31.857243878500803, 22.235976014818462, 15.480402333395821, 7.704980748040335, 2.438541514532907, 0.7105076430099351, 0.5579166252698217, 0.03957663383334875, 0.05906713155231305, 0.055529830112521134, 0.020630770728790333, 0.04913810487570507, 0.03968060914693134, 0.030438412579574754, 0.03186603668811066, 0.033649257251194546, 0.028158999713403837, 0.030319828407040665, 0.01820503857119807, 0.046178606538368125, 0.0036663761877987, 0.09074165512408529, 0.06343202519097499, 0.019293544448113868, 0.03955684096685477, 0.04470630089885422, 0.04725298870887075, 0.06185871282858508, 0.10633671044238976, 0.05098279731880341, 0.03638841491192579, 0.03314268336232219, 0.05588214924292905, 0.003673044914778854, 0.07947481184133462, 0.046308827586472034, 0.0457585187229727, 0.045297905403588495, 0.013441114603275699, 0.036008618505937715, 0.08395384864083358, 0.011950968581783985, 0.028887498658150434, 0.02466949088765042, 0.03221676126122475, 0.05145841644012502, 0.06664937362074852, 0.05583123197512967, 0.025977080455049872, 0.026138442867834653, 0.020053103333339095, 0.0640772712816085, 0.04320549339588199, 0.022512819917340363, 0.05376521497964859, 0.06095123330929449, 0.057138314337602684, 0.01811483921483159, 0.026632285743419613, 0.09356861521622964, 0.06492278698299613, 0.00803872395772487, 0.022801762180668966, 0.03413616719522646, 0.028268713736906648, 0.026683415053412318, 0.04355878961671676, 0.05017689788447959, 0.04549453128129244, 0.05121966710846339, 0.11961106743131365, 0.02558265144138464, 0.031536380627325604, 0.050439107564410994, 0.031572672072798014, 0.06574762093701533, 0.02606359706260264, 0.024538131597052728, 0.06803044344165496, 0.013697406609675713, 0.03237397443237049, 0.03251932341871517, 0.029996007747415985, 0.036524257622659206, 0.06036895526839154, 0.042803549606885226, 0.03586197351770742, 0.12173974035041672, 0.05262172401749662, 0.025035178854263256, 0.03209359358463969, 0.02881826433752264, 0.05268793207194124, 0.017181692412123084, 0.03012484119140676, 0.01793200456138168, 0.02417752585772957, 0.012108350538515618, 0.05957527285707848, 0.03203472049374666, 0.022376468305342963, 0.033738810302955766, 0.10017802805772849, 0.06794419485543456, 0.01615901291370392, 0.04927034117281437, 0.035943007562309504, 0.047324516477861574, 0.04396649416802185, 0.03919911730502333, 0.025670613328527127, 0.014771668340212532, 0.007388319304612066, 0.029406143685004542, 0.06537509842642716, 0.03501024582822408, 0.028047402755224278, 0.022029127925634384, 0.014498485052692038, 0.030835548947964395, 0.010085218652550663, 0.04536386240007622, 0.03868223646921771, 0.011734500643797219, 0.031231114507785866, 0.02815210579761437, 0.04753798698740346, 0.06089519988745451, 0.020855204667896032, 0.01849643373861909, 0.07098028622567654, 0.02641078137925693, 0.05693873683256762, 0.036948409862816334, 0.06461433174886874, 0.040645591116377285, 0.02084491977335087, 0.09411305135914258, 0.7216340973973274, 2.8796524618353163, 6.32674389226096, 11.423531566347394, 18.98279469353812, 27.8209901537214, 35.96391759599958, 40.016002791268484, 46.93447698865618, 50.119941166469026, 53.75829240253994, 51.57393510001046, 52.087320123400005, 52.1319067137582, 49.102596351078574, 45.80830601283482, 45.43059498923165, 42.57345403943743, 39.75942666190011, 39.17364488329206, 47.936886651175364, 36.62372548239571, 37.82420744214739, 40.38301706314087, 37.46155663899013, 47.88323266165597, 32.886532647269114, 32.90031092507498, 32.58234051295689, 51.74112960270473, 71.75098269326347, 28.120528732027324, 35.85388592311314, 32.547571727207725, 34.375760895865305, 40.10097926003592, 42.58567592075893, 38.29146337509155, 37.8673210144043, 26.801720687321254, 18.82215929031372, 10.8421071767807, 4.782045568738665, 1.4194571524858475, 0.5535447970032692, 0.05594702736873712, 0.025829341329102005, 0.06025027949362993, 0.01965034021330731, 0.019675093170787607, 0.05870437994599342, 0.03110673903886761, 0.009216681954317858, 0.018326587941763655, 0.024238096982506768, 0.0195583240794284, 0.013988171587698162, 0.019752325722947717, 0.017822534810485582, 0.014314758125692606, 0.02962412645242044, 0.06512708030641079, 0.008383672501492714, 0.014101985659051155, 0.012263850408739277, 0.08370396454951592, 0.053529549589646716, 0.03569993596257908, 0.02475976149019386, 0.02639246093375342, 0.024647350289991925, 0.03833703177848032, 0.015546426409855485, 0.01769038841926626, 0.015218498917030436, 0.023662665359941975, 0.013318192895634897, 0.02657322266272136, 0.06411081126758031, 0.022013484300779443, 0.03409006752605949, 0.02845484098153455, 0.0758411686069199, 0.028166511096060276, 0.0233080442994833, 0.062263913585671356, 0.06343662565840141, 0.045080679202718396, 0.01857957463445408, 0.05704282410442829, 0.09756254697484629, 0.07182476376848561, 0.025699956575408578, 0.012279689112412078, 0.008079530205577612, 0.01432330088157739, 0.04105610480265958, 0.04812526243871876, 0.0231714161844658, 0.025727674730920365, 0.059471708057182174, 0.0489287937858275, 0.03109998083008187, 0.060068689951939244, 0.0054171521748815265, 0.027848344329478483, 0.0630188991448709, 0.24481236775006565, 0.1462207409952368, 0.08350697226290192, 0.1705056857317686, 0.10158368798771075, 0.13850179447659425, 0.17086510573114666, 0.07546089044106857, 0.1023499643696206, 0.15186128046895775, 0.0853142977825233, 0.09084364572273833, 0.16968985593744687, 0.09197720632489238, 0.10371874592133931, 0.15811115796012537, 0.11323611558015857, 0.17829114225293907, 0.2839800146009241, 0.1593039682401078, 0.14333474157111986, 0.09835352881678514, 0.19479353459818022, 0.19535257960004465, 0.22119687923363276, 0.14056820502238615, 0.1403738861637456, 0.10025334544479847, 0.148197544206466, 0.16423987623836311, 0.07841493335685559, 0.11323919612914324, 0.10975227930716105, 0.23147682047316007, 0.15202388460082666, 0.17279861840818608, 0.25279158673116137, 0.12544661786939415, 0.18699506377535208, 0.12520059464233263, 0.1236895921507052, 0.1788421669708831, 0.1256129810852664, 0.08357694279402494, 0.08167256641068629, 0.15533292346767016, 0.1284737932894911, 0.10135115403681993, 0.1045083367664899, 0.13130757265857287, 0.1403641016887767, 0.1654742807149887, 0.2239384456936802, 0.15466863768441336, 0.0525464778766036, 0.0950939076553498, 0.07239454997969524, 0.1780576854944229, 0.14137818584484713, 0.07835024182817765, 0.08531885075249843, 0.1053120479253786, 0.17497197964361735, 0.154984997851508, 0.11652017757296562, 0.2553146784859044, 0.13030216018004076, 0.08501857186534575, 0.18193510600498744, 0.7488099134394101, 2.6425751490252356, 6.694623649120331, 12.337032079696655, 19.855547496250697, 29.623568262372697, 39.26780687059675, 43.75384528296334, 53.88860239301409, 59.50458117893764, 61.60766887664795, 60.74907997676304, 61.72434302738735, 63.673813002450125, 58.481007303510395, 56.053327560424805, 58.57188279288155, 53.37489775248936, 49.262689794812886, 48.406789847782676, 58.48294585091727, 44.71679959978376, 49.84493841443743, 51.21331664494106, 46.95675638743809, 55.52789088657924, 42.11014468329293, 41.16788905007498, 45.96151379176548, 56.0840733391898, 75.18289252689907, 36.69064705712454, 47.15514830180577, 42.81187105178833, 44.74315411703927, 48.65681382587978, 50.10603782108852, 44.25732217516218, 42.37655946186611, 30.417657034737722, 21.364055258887156, 11.965106299945287, 5.433902110372271, 1.685571095773152, 0.5769180485180446, 0.11303129978477955, 0.15569706607077802, 0.11334926807986838, 0.09014286154082843, 0.13999951125255652, 0.1085420103211488, 0.20768914691039495, 0.1484226007014513, 0.14539527600365026, 0.07297880934285265, 0.10167509344007288, 0.12043570461017744, 0.17420632072857448, 0.13614343745367868, 0.18855988766465867, 0.07692104351839849, 0.13209198628153118, 0.1726251170039177, 0.08143199860517468, 0.20218970200845174, 0.23215274991733686, 0.18732810233320507, 0.1520450141813074, 0.12521761230060033, 0.10393034028155462, 0.18216046105538095, 0.08014323668820517, 0.10693437087216548, 0.11430087951677186, 0.12548823920743807, 0.1543491698269333, 0.1286176834255457, 0.12254687132579939, 0.13655494180108818, 0.13564303144812584, 0.11832159305257456, 0.15791176365954535, 0.1336049565247127, 0.1129841348156333, 0.11992517486214638, 0.1306530577795846, 0.08769231875027929, 0.12308831512928009, 0.11856724987072603, 0.16329789321337426, 0.232166944869927, 0.14894317276775837, 0.13579291983374528, 0.21894893342895166, 0.15843042225709983, 0.17559349057929857, 0.11159338230001074, 0.17545456731958048, 0.0968696880819542, 0.08280362321862153, 0.08976525680295058, 0.11145083566329309, 0.13150844616549356, 0.1980149745941162, 0.13841315066175802, 0.12568520435265132, 0.198836300522089], [0.005837918525295598, 0.017984909936785698, 0.01282463246025145, 0.04624816316312977, 0.050335837927247794, 0.024733944929071834, 0.02564181969501078, 0.026333435172481195, 0.03837445637743388, 0.053614312184176276, 0.051851922646164894, 0.002984972238274557, 0.05452506224225674, 0.058238823498998366, 0.04428984663848366, 0.0417940285988152, 0.0005593290853929439, 0.09462809336504766, 0.037393684898103983, 0.04624507922147002, 0.028959229987646853, 0.052025905810296535, 0.07320513469832284, 0.024845419750948037, 0.03887594125366636, 0.03259774849617055, 0.031289946886577776, 0.022953777773571864, 0.04697870110560741, 0.056915748066135814, 0.026798426739073226, 0.026121752602713447, 0.0687494802155665, 0.09868901688605547, 0.048264820128679276, 0.041132887825369835, 0.05061985572267856, 0.021999464070956622, 0.04742238497627633, 0.003360272289553125, 0.021840132174215147, 0.027755938037963848, 0.07543695851096086, 0.016252498075898205, 0.05671366676688194, 0.02002951067074069, 0.04201213350253446, 0.09450682558651481, 0.030386782850005796, 0.06247395410069397, 0.0484305794483849, 0.01458804149712835, 0.06889955180564097, 0.012881247725869929, 0.010902375831002635, 0.03460995087932263, 0.029676621314138174, 0.012503868600885783, 0.05547019706240722, 0.08203558264566319, 0.05226875349347081, 0.03022147814876267, 0.03151623492262193, 0.04386466981044837, 0.010832027864775487, 0.04988617277038949, 0.031108035040753226, 0.03919680689328483, 0.03036803492744054, 0.050588690609272034, 0.028461317598287548, 0.2891440732138497, 1.1278748043945857, 2.213712138789041, 5.571203291416168, 10.345537662506104, 11.283131054469518, 17.405685629163468, 23.768109389713832, 23.86876620565142, 32.378813879830496, 35.381304195949006, 41.59669017791748, 47.647723470415386, 45.96599537985665, 46.89793988636562, 45.26735748563494, 46.8981031690325, 48.896415506090435, 48.68989072527204, 48.083556175231934, 45.86890820094517, 47.08660432270595, 41.38551010404314, 43.971848487854004, 42.948024477277485, 44.12369441986084, 46.99181352342878, 46.750346251896445, 48.64584262030465, 38.40243305478777, 42.64958892549787, 44.14828756877354, 35.867962973458425, 34.13474178314209, 27.0417548928942, 19.387438671929495, 10.693742292267935, 5.220945034708295, 2.7952998110226224, 0.6329580928598131, 0.12958820563341888, 0.12648302582757814, 0.0846255575971944, 0.0662963997040476, 0.05019129300490022, 0.053833858974810155, 0.007945820639309074, 0.015024521022236772, 0.02400384803435632, 0.026706285076215863, 0.023502929734864404, 0.027928397890978625, 0.08072419158582177, 0.03871513863227197, 0.043818101952118535, 0.07005736324936152, 0.05450788173558457, 0.04238792994458761, 0.018339607332433974, 0.017763034074700305, 0.03767470696142741, 0.07147804594465665, 0.014623723957421524, 0.05683434421994856, 0.01792854572912412, 0.03071177058986255, 0.04590045467817357, 0.04510207001918128, 0.011877084599940904, 0.03656570593427334, 0.06803836873067276, 0.04041355249605008, 0.02560502104461193, 0.0744232814759016, 0.009859857664975737, 0.03275273946513023, 0.031721478195062706, 0.01382025283029569, 0.024527120670037608, 0.03661164275503584, 0.04019242471882275, 0.02645339337842805, 0.02672222556014146, 0.035315332135983875, 0.04083716869354248, 0.019440920557826757, 0.04418205117274608, 0.05524658245433654, 0.04132475717259305, 0.042976877984723875, 0.044663254637271166, 0.029127052053809166, 0.0034639956970100422, 0.028729573025235107, 0.027332739139507924, 0.024065852564360415, 0.01717435066322131, 0.04284886556810566, 0.03982209726901991, 0.013162082343894457, 0.11329978930630855, 0.01785625291189977, 0.017975854886961833, 0.007724201772361994, 0.05842050125024148, 0.09814015669482094, 0.07409307240907635, 0.022594072789485966, 0.08291756960430316, 0.077944226829069, 0.017422616448519484, 0.08179181215486356, 0.08400925102510623, 0.0680057719083769, 0.04887712673683252, 0.04980236691023622, 0.01303340750746429, 0.008186194214171596, 0.031646228661494594, 0.004020926850249192, 0.03410789603367448, 0.0332433372469885, 0.018032968875819018, 0.018314576175596033, 0.058819357704903395, 0.02348248377841498, 0.034043852505939345, 0.06261418693299804, 0.019263001890586953, 0.036637732426502874, 0.02107627476964678, 0.00629410525185189, 0.04964732505115015, 0.05300946606855307, 0.06516408760632787, 0.01879317406564951, 0.03510434167193515, 0.019722215731495192, 0.02610652118788234, 0.016447239322587848, 0.023322992425944124, 0.07507369121802704, 0.03288755080263529, 0.03274985569130097, 0.03146304116983499, 0.04030704624684794, 0.041802466181772094, 0.020199921347999146, 0.0265761132219008, 0.03221309717212405, 0.024825406360573003, 0.04132279620638915, 0.024101557077041695, 0.028760415834507773, 0.051957210925008566, 0.022428552653374415, 0.03241327178797551, 0.05411349682669554, 0.011326366919092834, 0.02391242901129382, 0.027508740945320045, 0.030143192170986106, 0.006750935738507126, 0.060079668648540974, 0.056272900596793206, 0.06170910942767348, 0.008824228325725665, 0.06841585133224726, 0.038182325794228485, 0.039311720191368034, 0.029859198124281, 0.023571343028119633, 0.028766919592661516, 0.01794453031782593, 0.033342786731996706, 0.06142236052879265, 0.5827277196305138, 1.783649587205478, 3.5509040313107625, 8.659354039600917, 14.879662820271083, 15.95244210106986, 23.037669590541295, 30.530151844024658, 29.190521785191127, 38.428221293858115, 44.48644249779837, 48.129167624882285, 54.13567338671003, 52.422567231314524, 53.49345139094761, 51.024117197309224, 52.09023836680821, 52.49721867697579, 54.369289193834575, 51.92133460726057, 50.111082213265554, 51.53999662399292, 45.794899463653564, 48.70501000540597, 47.29912887300764, 47.185845443180625, 49.95635625294277, 50.05010134833199, 53.31172473090035, 40.89276123046875, 47.123231751578196, 49.207121576581685, 40.99497617994036, 39.11962611334664, 31.437197480882915, 23.873395442962646, 14.76804174695696, 7.7214071580341885, 3.8026131646973744, 1.0519143832581384, 0.11472803088171141, 0.06614918474640165, 0.019028841151988933, 0.07152658155454056, 0.02380401947136436, 0.024750954105651805, 0.015015265804582408, 0.04852046498230525, 0.0385456371919385, 0.05203294561111501, 0.022950403758191636, 0.05577300349250436, 0.0587189005953925, 0.06278732192835637, 0.040833039807954004, 0.024508348998746703, 0.029630996619484255, 0.07060089015534946, 0.009534519631415606, 0.010144838131964207, 0.03756880460839186, 0.03193441605461495, 0.015517510640035783, 0.018665543324979286, 0.05600192424442087, 0.014468069720481123, 0.009353528048710098, 0.02331411379522511, 0.026029349703873907, 0.03879450348072818, 0.025219799751149755, 0.01644271519035101, 0.05762485787272453, 0.01633130313296403, 0.04947638511657715, 0.05100612874541964, 0.028023944103292057, 0.027950487598510723, 0.06680209149739572, 0.048846399278513024, 0.06940463291747229, 0.03491118650085159, 0.07770532143435308, 0.028623280514563833, 0.01890302379615605, 0.032102845409618955, 0.02746803223687623, 0.06551801825740508, 0.06334243142711264, 0.03694024708654199, 0.07804724880095039, 0.024806251316996555, 0.015116421805162514, 0.038335803630096574, 0.014697183854877949, 0.029744484994028295, 0.05080024425738624, 0.009023733736414994, 0.009254762187733181, 0.007468557766904789, 0.04214338592386671, 0.02901373670569488, 0.024310103118685738, 0.02374657808936068, 0.025787150021642447, 0.16878154182008334, 0.21753914122070583, 0.17193041928112507, 0.1497327025447573, 0.1732822781694787, 0.14020251535943576, 0.12667359917291574, 0.12520033679902554, 0.10648275153445345, 0.16385921809290135, 0.12088105428431715, 0.10428024043462106, 0.1356986170368535, 0.06007313435631139, 0.16311467518763884, 0.16842680371233396, 0.08907317143997975, 0.19822635182312556, 0.12747484046433652, 0.19314378526593956, 0.19401982825781616, 0.119399133803589, 0.15890835518283503, 0.15767751980040753, 0.1598073597997427, 0.13548468851617404, 0.12962709926068783, 0.08457736804016999, 0.16331206102456364, 0.12415081954428128, 0.136227317952684, 0.10837448681039469, 0.1916253324598074, 0.19426149529005798, 0.08261365376945053, 0.06547129433602095, 0.2039510024977582, 0.12275770572679383, 0.07988983100014073, 0.11484608240425587, 0.1087326311639377, 0.09115591432367053, 0.19514840841293335, 0.11607596783765725, 0.18376746268144675, 0.11330153314130646, 0.11944203078746796, 0.09934498382998364, 0.10044191711183105, 0.22172636725008488, 0.16025976623807633, 0.08975015939878565, 0.15440039922084126, 0.10377059956746441, 0.09921374158667666, 0.10424921781356845, 0.08799214301896946, 0.12482403484838349, 0.21501302319977963, 0.23195043791617664, 0.09267680985586983, 0.13355200365185738, 0.2831537217966148, 0.19771392217704228, 0.11374896591795342, 0.1431490265365158, 0.1669767200946808, 0.1945031758930002, 0.09182604229343788, 0.17493799860988343, 0.1422247804169144, 0.6273985568966184, 1.8532654345035553, 3.295476960284369, 7.848761558532715, 14.11368819645473, 17.01714062690735, 23.494795049939835, 32.386529854365754, 33.44379901885986, 45.1003749029977, 49.916418007441926, 54.71211331231253, 60.72096756526402, 58.55989715031215, 61.35072449275425, 60.43684877668108, 61.30129500797817, 61.85753304617745, 62.39348929268973, 61.25785487038748, 60.01476655687605, 60.86437838418143, 55.09969425201416, 57.3115143094744, 56.400932039533345, 55.27946152005877, 59.2177734375, 55.793635163988384, 58.97245338984898, 49.04256738935198, 55.43033817836216, 57.36550876072475, 50.43328755242484, 44.449856758117676, 36.016710008893696, 28.079516989844187, 16.2742566040584, 8.85348583970751, 4.244562021323612, 1.1811484886067254, 0.30041166288512094, 0.1296335860554661, 0.1458109329853739, 0.13018280587026052, 0.10242568209235157, 0.07533015709902559, 0.08884138387760945, 0.07091168633529119, 0.16156093856053694, 0.15769715660384723, 0.06633686074720961, 0.13168706372380257, 0.14313464159412043, 0.14490544157368795, 0.12273164998207774, 0.15952806121536664, 0.11643588995294911, 0.1922195798584393, 0.06997844284134251, 0.038949019475174804, 0.1750736241894109, 0.17141946884138243, 0.10647731646895409, 0.1952630944017853, 0.15578360642705644, 0.14024272534464086, 0.11912458496434347, 0.1298122986086777, 0.1260540559887886, 0.1426284137581076, 0.12407353440565722, 0.061921504459210804, 0.10269397483872515, 0.14330669093344892, 0.09065680432000331, 0.1771221621228116, 0.11891229849840913, 0.21066122528697762, 0.12490673469645636, 0.1585434933326074, 0.17436593930636132, 0.13798761421016284, 0.13169929092483862, 0.07063070498406887, 0.20741514089916432, 0.11994246393442154, 0.07433950954249927, 0.20821062821362699, 0.1723390602107559, 0.1133428355678916, 0.16317700541445188, 0.09974008120064225, 0.06246282612638814, 0.13956769156668866, 0.12533812011991227, 0.13236086256802082, 0.14676392184836523, 0.07836928152080093, 0.0917570081406406, 0.09979893054280962, 0.24041499942541122, 0.12427085238908019, 0.11863722040184907, 0.07185069059154817, 0.11420036133910928], [0.01472700377261, 0.0769543256610632, 0.060754512436687946, 0.05616928151409541, 0.0063182301403555486, 0.02622966850841684, 0.046470722649246454, 0.0075530947485406485, 0.03866653856156128, 0.047888718345867734, 0.01937490588586245, 0.064536585206432, 0.01942215906456113, 0.032601032605660815, 0.06488989839064223, 0.029722927936485836, 0.04429549204983881, 0.06198226727013077, 0.03917446952047093, 0.04285113187506795, 0.07549618104738848, 0.07628207387668745, 0.05109307622270925, 0.03310683296461191, 0.020095940945403915, 0.026068720001993433, 0.023561716312542558, 0.014862488556121076, 0.007387024999063994, 0.036240721587091684, 0.07182347455195018, 0.031289570299642425, 0.05385275278240442, 0.011458619331408824, 0.02202311101635652, 0.08598070738038846, 0.049200458851243765, 0.02002658448847277, 0.01274939819372126, 0.03911717402349625, 0.014649978173630578, 0.056307095369057994, 0.050603676055158885, 0.05763078826878752, 0.05174220014097435, 0.07326454043920551, 0.006858157842153949, 0.020091438865555183, 0.019623346393927932, 0.09087873276855264, 0.07878846009927136, 0.015891997509502938, 0.051035709479557614, 0.06995943707547017, 0.038394473160484006, 0.07289137332034962, 0.058919740175562244, 0.05431478763265269, 0.030799226968416145, 0.032767660450190306, 0.018469129489468675, 0.045651408577603955, 0.046826916214610846, 0.02447903119692845, 0.04498369958517807, 0.04719630728608795, 0.03863589931279421, 0.015614240895956755, 0.016466102596106272, 0.03783149265551141, 0.014087110475104834, 0.04787539531077657, 0.06365238622363124, 0.04558859659092767, 0.08184305511947189, 0.4262251646390983, 1.3152455730097634, 2.8806119646344865, 4.211030883448465, 7.32432108266013, 10.793930104800634, 12.13785936151232, 19.92357383455549, 20.150211913245066, 23.92164373397827, 28.998980794634136, 30.2431287084307, 33.077288491385325, 32.310315064021516, 33.83304752622332, 39.60528782435826, 34.32509463174002, 38.69934000287737, 38.30070447921753, 38.930239064352854, 38.6018602507455, 42.56024898801531, 34.995067732674734, 36.23884391784668, 39.51220975603376, 35.49285405022757, 32.367477893829346, 28.40833180291312, 20.530811650412424, 14.250929015023367, 8.211977771350316, 3.0513535227094377, 1.4173183015414645, 0.5954215356281826, 0.08941556021038975, 0.023969015439174006, 0.030305837014956132, 0.028243119396003227, 0.03937883748273764, 0.0343234089336225, 0.044285897564675124, 0.04108256088303668, 0.029508561760719334, 0.03809176851063967, 0.06628155335783958, 0.015175242309591599, 0.028249697793009024, 0.01803409694028752, 0.027656909244667207, 0.04113043492127742, 0.011959300991812987, 0.033107874515865526, 0.059560141526162624, 0.02558788125004087, 0.016783517885154912, 0.044071850300367386, 0.025042210173394, 0.03800252419231193, 0.06840676574834756, 0.025612469662779143, 0.04099353030323982, 0.005921614971677107, 0.04854768780725343, 0.030048600996711423, 0.028513958345034292, 0.019651006873963133, 0.055525307676621845, 0.02572438044340483, 0.06449152369584356, 0.034025107976049185, 0.044175642409494946, 0.018349987221881747, 0.024212938600352833, 0.008285877793761236, 0.009223821839051587, 0.0330612014846078, 0.009595362170200263, 0.06496578574712787, 0.03891731153375336, 0.058563943553183756, 0.07020197263253586, 0.09044563743684973, 0.02935205426599298, 0.031384850186961036, 0.01478386331083519, 0.05738519251878772, 0.04753940851826753, 0.08254755767328398, 0.04626145566414509, 0.041574067901819944, 0.014810716334198202, 0.0407214920435633, 0.023403727915138006, 0.035621985859636746, 0.02373891064364995, 0.058633778377303054, 0.011417381365650466, 0.0217679886346949, 0.009123792206602437, 0.03319180251232215, 0.04974493231358273, 0.019834504795393774, 0.021114603516512682, 0.035271912680140564, 0.04793543548190168, 0.05583730825622167, 0.03449785350156682, 0.043571647855320146, 0.12929475280855382, 0.015518194264067071, 0.018846949662214944, 0.007990391060177768, 0.01845307195825236, 0.06743466255388089, 0.08483578131667205, 0.015324050128193838, 0.03593761660158634, 0.04593318381479808, 0.09074903079973799, 0.07700776029378176, 0.0376758672563093, 0.04585100983136466, 0.019583679236737744, 0.0841599740087986, 0.01769568438508681, 0.021854021786046878, 0.019796569598838687, 0.030864491859184842, 0.024158040028331534, 0.06809449714741536, 0.04955090522500021, 0.10861206227647406, 0.03584000933915377, 0.03405468871018716, 0.04706032886835081, 0.06884202560675995, 0.01762683004406946, 0.012001876519726855, 0.0169162596908531, 0.015995141617687683, 0.028328460441636186, 0.03188710520043969, 0.016623344604990313, 0.025385996725942408, 0.036540589960558076, 0.03304568338873131, 0.06567309743591718, 0.035883479685123475, 0.03530752219791923, 0.10114600575928177, 0.017749753448047807, 0.11020238551178149, 0.04366770127256002, 0.023989995741950612, 0.006120472381423626, 0.03565681166946888, 0.0566608258523047, 0.03419671966029065, 0.06908032710530929, 0.04408102748649461, 0.01593769684300891, 0.06365354651851313, 0.06990664026566915, 0.003058884633771543, 0.07673836153532777, 0.03725202374958566, 0.019662301089348536, 0.021247316484472582, 0.015245243374790465, 0.03405983200562852, 0.02713568917741733, 0.009814248237359737, 0.022266632145536796, 0.04591324167060001, 0.15134628596050398, 0.2784339136310986, 1.099791488477162, 2.90375554561615, 4.665568573134286, 6.399637009416308, 10.370974149022784, 15.588507618222918, 16.592706441879272, 26.387425661087036, 28.715065240859985, 30.282782077789307, 35.82615218843733, 35.93341153008597, 39.69576726640974, 39.63768032618931, 40.389134952000205, 46.63839340209961, 41.46108913421631, 45.508651052202495, 45.729669775281636, 45.2587000301906, 45.29238142286028, 47.68338162558419, 41.781692913600374, 41.99294941765921, 44.62973519733974, 40.60773917606899, 37.47079774311611, 32.98654154368809, 24.113203832081386, 17.742886917931692, 11.014470270701818, 4.709712215832301, 1.9683117525918143, 0.6655875391193798, 0.1428697415228401, 0.02692778265502836, 0.011988545002947961, 0.009393059498896556, 0.07535773276218347, 0.059381184700344286, 0.052802533243915865, 0.08510616395090308, 0.043212197321866236, 0.008410087869768696, 0.02328685873986355, 0.020517938836876835, 0.029848419595509768, 0.02466409483791462, 0.025843490480578372, 0.015999791278902973, 0.0029604113910214175, 0.055618579100285254, 0.03951123323557632, 0.06163777504116297, 0.029516904348773614, 0.04463087833885636, 0.02875752527532833, 0.020813203350241696, 0.06263709427522761, 0.04158758431939142, 0.03138679079711437, 0.030074090164686953, 0.025893552794254253, 0.04449436727112957, 0.07863053785903112, 0.04199943471966045, 0.016536239368308867, 0.0390340127716107, 0.04657795832359365, 0.022456888275753175, 0.0330746025512261, 0.020659918896853924, 0.04439074818843177, 0.010633293439501097, 0.07245452568999358, 0.06736554697688137, 0.010155847362641777, 0.0341634612663516, 0.06527134363672563, 0.0236027863408838, 0.008461108614158417, 0.02761758305132389, 0.0116945103343044, 0.014337989468393582, 0.06203715396778924, 0.04624744052333491, 0.02141955920628139, 0.043255633741085014, 0.03713915284190859, 0.07104277930089406, 0.038395704701542854, 0.01974092294195933, 0.03901357190417392, 0.04102656138794763, 0.04044949449598789, 0.008257891616917081, 0.012016617693006992, 0.0281251815280744, 0.06048885240618672, 0.021776974134679352, 0.02652757421934179, 0.12276582100561687, 0.1523053544972624, 0.1248892963464771, 0.11793695869190352, 0.19925769791007042, 0.12093152371900422, 0.13118603346603258, 0.19202641450933047, 0.2051158571349723, 0.08107472277645554, 0.16458242785717758, 0.13430160842835903, 0.11610978602298669, 0.1546203667031867, 0.09393941424787045, 0.14582264449979576, 0.1298887695052794, 0.1344267845685993, 0.13784297768558773, 0.15986582237694943, 0.19354384951293468, 0.15683761558362416, 0.13266985384481295, 0.09286209741341216, 0.06481710515384163, 0.07235419071678605, 0.1466845739632845, 0.05893244913646153, 0.19113784576100962, 0.1095203221110361, 0.1626883652061224, 0.11775089081908975, 0.15041198395192623, 0.1598824600556067, 0.15313187800347805, 0.16174517438880034, 0.15417736476021154, 0.07829734323812382, 0.1108816262068493, 0.08072385910366263, 0.2037769854068756, 0.1065572818209018, 0.14056981993573053, 0.12371745279857091, 0.16901035739907197, 0.19931704258280142, 0.12626299049173081, 0.1994661031556981, 0.12244783235447747, 0.13723449462226459, 0.2380855344235897, 0.12568297875779016, 0.15061076757098946, 0.11036952904292516, 0.14508994881595882, 0.13916130337331975, 0.12471540139189788, 0.14596709103456565, 0.10795312334916421, 0.0913198890962771, 0.13871575013867446, 0.21488984195249422, 0.06541457559381213, 0.183366828465036, 0.17984589668256895, 0.10327829527003424, 0.10857071235243763, 0.11460061557590961, 0.20917165093123913, 0.13340628147125244, 0.09233896727008478, 0.12704924972993986, 0.13086081163159438, 0.28777663516146795, 0.4312855159597737, 0.9073012002876827, 2.6382472898278917, 4.725561056818281, 6.658154726028442, 10.230903676577977, 16.07058926991054, 18.695446729660034, 28.11729781968253, 29.928969383239746, 32.82051086425781, 38.49675137656075, 38.73546021325247, 43.70883485249111, 42.90173557826451, 46.421762466430664, 50.69869484220232, 47.303850173950195, 50.19031946999686, 51.43254273278372, 50.549437114170615, 51.76423931121826, 54.68363612038748, 50.601343631744385, 49.68126664842878, 51.6357810156686, 48.22374650410244, 43.76483733313424, 39.400013719286235, 28.819812808717998, 19.58819992201669, 13.05525347164699, 5.885204545089176, 2.1541439294815063, 0.8860895984939167, 0.1946511643805674, 0.1077481514907309, 0.09499951664890562, 0.11879914599869933, 0.11628186250371592, 0.11425311065145902, 0.06624863762408495, 0.17089908676488058, 0.09493083533431802, 0.08425544388592243, 0.1506594456732273, 0.06306120580328362, 0.10350646624075514, 0.11017699473138366, 0.14095631348235266, 0.09241359933678593, 0.16815456189215183, 0.14085168338247708, 0.12730471816446098, 0.13373299608273165, 0.12513350109968865, 0.1514012472970145, 0.08646855370274611, 0.09825528373143502, 0.1490392940385001, 0.1217960316155638, 0.16707630189401762, 0.1083092185269509, 0.0697464110063655, 0.11027380132249423, 0.13224669226578303, 0.12758097691195353, 0.13933195493050984, 0.12267134178962026, 0.10661984274962119, 0.14166281771446976, 0.1335423006010907, 0.1264517725046192, 0.15359689162245818, 0.12286120945853846, 0.1329971927085093, 0.13530064267771585, 0.08504589647054672, 0.09701834831918989, 0.13618546591273376, 0.1737349017390183, 0.2108740545809269, 0.22475328482687473, 0.17009268860731805, 0.10955558557595525, 0.09853093858276095, 0.1507226037127631, 0.1531637284372534, 0.18082165718078613, 0.11851127073168755, 0.16369521617889404, 0.10603724579725947, 0.09453560904200588, 0.16149706127388136, 0.12084609616015639, 0.14702302723058633, 0.14645506627857685, 0.1556602351899658, 0.1160519476979971, 0.09316220666681017, 0.10694033519497939, 0.10689062571951322], [0.05767489304499967, 0.029135764443448613, 0.04881578377847161, 0.1347341202199459, 0.023543875930564742, 0.020822090462648442, 0.037878270859697034, 0.023126512433269193, 0.005765016722892011, 0.05530585927356567, 0.03167729199464832, 0.0548179688464318, 0.03189555974677205, 0.030459606620882238, 0.01560968962231917, 0.058169009030929635, 0.017111693043261766, 0.022955000832942978, 0.04756983063582863, 0.019977516228599206, 0.022670635288315158, 0.030659184125917296, 0.036331587604113987, 0.011433091147669723, 0.0774156344788415, 0.022410997256104435, 0.008471438461648566, 0.03750248120299407, 0.04321463326258319, 0.0318262032898409, 0.06606176907994918, 0.03199368608849389, 0.004465335057050521, 0.029812972926135575, 0.024025951312588792, 0.04223598220518657, 0.02084052625910512, 0.06254747336996452, 0.059741364658943245, 0.03378657916826861, 0.03349196265584656, 0.02458893521023648, 0.0428965394385159, 0.044697822603796206, 0.04411824173959238, 0.09449840496693339, 0.02895608837051051, 0.01842630035909159, 0.05456970984648381, 0.05985813375030245, 0.06397793375487838, 0.08289209739970309, 0.046204082135643275, 0.05119172842907054, 0.04827931024400251, 0.052110091650060246, 0.013313073348919196, 0.029615108722022603, 0.029020830789314847, 0.0066509574202687615, 0.007485853624530137, 0.04700524878821202, 0.029358137332435166, 0.06265695499522345, 0.070745906659535, 0.03984933366466846, 0.016543240153363774, 0.012221380901922072, 0.052867499579276354, 0.05333096953108907, 0.04660139153046267, 0.007252746311548565, 0.07396012025752238, 0.052099608284022124, 0.004363729951104948, 0.03356947849637695, 0.08366159003760133, 0.08568040135183505, 0.2752708819295679, 0.4020709464592593, 1.0506313549620765, 1.9889956712722778, 1.8242640878473009, 3.6043239533901215, 6.231151010308947, 6.82192029271807, 8.75882271357945, 8.390928626060486, 8.705698524202619, 12.540716784340994, 11.199989778654915, 12.18082789012364, 13.787879347801208, 11.938261934689113, 14.679636342184883, 15.997874634606497, 15.47129498209272, 16.55709171295166, 13.368814383234296, 15.073041609355382, 12.219267061778478, 11.8780323437282, 6.958642601966858, 4.57094018799918, 1.8618527565683638, 0.35482577447380337, 0.02309147797391883, 0.08622178408716406, 0.041212751397064755, 0.059288116837186475, 0.04598690003954938, 0.013223241249631559, 0.027221047186425755, 0.009919288850921606, 0.008267143441896354, 0.07049889277134623, 0.043311887686806064, 0.04095867735200694, 0.042594645638018847, 0.032686165001775534, 0.02994790979261909, 0.020908649478639876, 0.041058259151343784, 0.038343046991420646, 0.023430630132289867, 0.0513382919930986, 0.03235241398215294, 0.04430656234866806, 0.048041822987475565, 0.04247798850493772, 0.0004601816544891335, 0.028600824398121664, 0.025614440807008317, 0.028631015813776424, 0.02898718902309026, 0.03136136269729052, 0.04226543401767101, 0.06791872265083448, 0.026615223980375698, 0.019512480557230965, 0.05023941131574767, 0.06161891855299473, 0.03190077428839036, 0.0429567322800202, 0.01501097237425191, 0.04873663945389645, 0.052099221519061496, 0.0517451856950564, 0.05407535976597241, 0.03780858192060675, 0.012943125030558025, 0.012496265616001827, 0.03977188228496483, 0.007320637132839433, 0.03677564127636807, 0.03500493968437825, 0.07580132503062487, 0.006771061935329011, 0.047684828750789165, 0.028654937565858875, 0.038575129716524055, 0.028131208615377545, 0.03584386341805969, 0.035324760380067995, 0.024775837681123188, 0.06785750522145204, 0.04269413244245308, 0.055107794901622195, 0.04921787005982228, 0.024065601506403515, 0.06848248347107853, 0.0338634470078562, 0.027802475362217853, 0.01706501661932894, 0.07333405635186604, 0.0335393854682999, 0.06961377098092011, 0.04061514185741544, 0.015547778390880142, 0.0415578746635999, 0.044148623145052364, 0.022568380061004843, 0.024075070462588753, 0.037554124503263404, 0.06444009074143, 0.019565642079604522, 0.030099396128207445, 0.031401664284723144, 0.04105543644566621, 0.039120159577578306, 0.051373870976801427, 0.00804874676811908, 0.038569233247212, 0.015016739921910422, 0.010504008769722921, 0.05213793194187539, 0.006339104846119881, 0.050607703160494566, 0.04270157597160765, 0.05306195414492062, 0.04183799088267343, 0.08277125031288181, 0.035236798492925506, 0.01632249914109707, 0.06459608594221727, 0.02439480634140117, 0.0801464393734932, 0.058000209874340465, 0.011228928442246147, 0.04334639458517943, 0.038943068723061254, 0.05053637555933424, 0.05620117944532207, 0.01829314125435693, 0.05103497326906238, 0.011366218977075602, 0.024388959065877965, 0.03723332332447171, 0.05756485502102545, 0.03507483218397413, 0.05758332474423306, 0.04252758262945073, 0.005824322803943817, 0.0588129319782768, 0.09517403585570199, 0.010506299673579633, 0.04094176147399204, 0.03669863772977676, 0.005260430517539914, 0.054485856488879235, 0.04374632312517081, 0.020624044750417982, 0.015588777173044426, 0.04485803489972438, 0.029631848180932657, 0.07581880409270525, 0.021517673673640405, 0.046528062250997336, 0.002551201552185895, 0.03711051187877144, 0.03504938372809972, 0.01861683977767825, 0.03171608384166445, 0.03450440475717187, 0.04804543957912496, 0.10033821660493102, 0.038965704651283364, 0.08118474722972938, 0.10174127096044165, 0.05036662645371897, 0.035400902187185626, 0.013464174615884466, 0.040570633352867196, 0.19352719826357706, 0.3190444516284125, 0.7307183785097939, 1.5645970957619804, 2.6653695830277035, 3.335149654320308, 4.7497720548084805, 8.639648079872131, 10.050861954689026, 11.876482895442418, 12.876922743661062, 13.689519780022756, 16.21260176386152, 16.50448863846915, 16.989033426557267, 17.81303766795567, 17.025905779429845, 19.100841113499232, 20.06682484490531, 20.571984938212804, 20.460982254573278, 17.966780458177837, 18.90763255528041, 16.45695080075945, 14.344311935561043, 9.41542661190033, 5.791416457721165, 2.817130182470594, 0.5815351264817374, 0.12351168026881558, 0.07300534006208181, 0.03238845097699335, 0.08197636010923556, 0.04121200840121933, 0.023797390184232166, 0.027254904387518764, 0.041712000500410795, 0.04654062193419252, 0.013149387801864316, 0.07194257780377354, 0.041572832968086004, 0.032942084662084065, 0.041305748014045615, 0.06097158257450376, 0.03391315648332238, 0.038191190854247124, 0.0035090451211934643, 0.025991989565747123, 0.026393670422424163, 0.04942626512742468, 0.0366809415364904, 0.015663877428908433, 0.035279505486999235, 0.021548938870962177, 0.04007426802335041, 0.04761821696800845, 0.019620423604335104, 0.00301077904545569, 0.05156428825908473, 0.070014445909432, 0.011971887816408915, 0.01683924257356141, 0.024105329731745378, 0.04723233410290309, 0.02685209207369813, 0.05329790112695523, 0.07605771627277136, 0.010463229663270925, 0.07666817387299878, 0.014670866874179669, 0.024927135723243867, 0.0656713739569698, 0.03981369022013886, 0.04216300915660603, 0.05143373133614659, 0.04118808325646179, 0.030450948514044285, 0.08941260858305863, 0.015072086327044027, 0.010486232000403106, 0.02788853395863303, 0.044541729015431235, 0.0034726817934175153, 0.05033291004864233, 0.010881977372004517, 0.04712342583973493, 0.02100056383226599, 0.059428383596241474, 0.07696704140731267, 0.03756147643019046, 0.013948262702407581, 0.020013680448755622, 0.02709357929416001, 0.024334971427119205, 0.01045853759361697, 0.02207045579728271, 0.10430137001510177, 0.08104783921901669, 0.0037151840598588543, 0.2556033544242382, 0.1477036928491933, 0.12458865105041436, 0.30216820005859646, 0.130961112678051, 0.1852202604391745, 0.06251155851142746, 0.11516180474843297, 0.1529429331421852, 0.08454120212367602, 0.07665814512542315, 0.12300174763160092, 0.07691349142364093, 0.22666701142277035, 0.1432301521833454, 0.11161004033471857, 0.08591876391853605, 0.08010667043605021, 0.12280620740992682, 0.17974469996988773, 0.08780659761812006, 0.18390618238065923, 0.1402715359415327, 0.11720742498125349, 0.19408293201455049, 0.1505048753959792, 0.15211380406149796, 0.11901975130396229, 0.11206214143229382, 0.1292671635746956, 0.18906705187899725, 0.11656976491212845, 0.1386016205485378, 0.132670220253723, 0.10518660037113087, 0.12783633678087167, 0.12669468804129533, 0.12420886142977647, 0.19050583110323974, 0.14075877836772374, 0.17696825680988176, 0.0837534297523754, 0.09821611190480845, 0.14665752755744116, 0.13646743792508328, 0.17756999523511954, 0.08714051371706383, 0.11028917014066662, 0.14467833590294632, 0.08738076939646687, 0.13436172663101129, 0.18264949481402123, 0.1737280213939292, 0.13779847935906478, 0.15826830667044434, 0.10759390691029173, 0.0728382168869887, 0.08359591463314635, 0.1910639125853777, 0.12260044845087187, 0.13843694009951182, 0.095269621083779, 0.13459955315504754, 0.10478373377450875, 0.1783079427800008, 0.13957632253212587, 0.07907001820525952, 0.16718508462820733, 0.18905107916465827, 0.17147820283259663, 0.14015523503933633, 0.17018494222845348, 0.21732711259807858, 0.15343715090836796, 0.08934649891619172, 0.09724089423460619, 0.16753736643918923, 0.33765593437211855, 0.4185802462909903, 0.639796043080943, 1.4924263741288866, 2.609267004898616, 3.719385470662798, 5.091361130986895, 9.220746772629873, 10.290557435580663, 12.579908967018127, 12.552893502371651, 13.0073630128588, 16.240875720977783, 18.40949535369873, 17.304120336260112, 18.05145468030657, 18.22404793330601, 19.979334865297588, 21.737069300242833, 22.450317519051687, 24.90724570410592, 23.472936017172678, 22.412611382348196, 19.002668278557913, 16.361963714872086, 11.102832249232701, 7.12051739011492, 3.4214690795966556, 0.7440287385668073, 0.29571511490004404, 0.16254226304590702, 0.08791453218353645, 0.18374226189085416, 0.22462935719106877, 0.11077878065407276, 0.0729049915181739, 0.10328508062022072, 0.11371208753968988, 0.1528050819677966, 0.12188699602016381, 0.1327020435460976, 0.2408927423613412, 0.145053823611566, 0.14675603727144854, 0.09379132398005043, 0.1295596393091338, 0.1294191689895732, 0.09525427940700736, 0.11254295813185827, 0.25234171801379746, 0.12652613994266304, 0.12364191828029496, 0.09679817727633885, 0.14887989259191922, 0.14738152442233904, 0.08109435957989522, 0.05612347361498645, 0.14580916879432543, 0.13969381765595504, 0.1382939320589815, 0.08777744775371892, 0.07828680558928422, 0.056246352914188585, 0.10295592328267437, 0.14321511584733213, 0.12532919059906686, 0.16815699104751858, 0.09195334224828652, 0.1637931830648865, 0.14110431554062025, 0.10344937430428607, 0.15271539320903166, 0.09011563871588026, 0.18083564857287066, 0.19850533828139305, 0.17730977705546788, 0.07842352361019168, 0.24710668463792118, 0.08780179359018803, 0.14837629747177872, 0.2255976538040808, 0.12519429783735955, 0.14448929604675087, 0.17090174662215368, 0.09926595485636167, 0.14701727325362818, 0.1167711541056633, 0.1733973984207426, 0.18158397770353726, 0.1204633888389383, 0.11916745480682168, 0.08919802866876125, 0.14868193678557873, 0.1307037714868784, 0.20748089094247135, 0.17987842565136297, 0.19743288654301847, 0.15044177163924488, 0.07446441426873207], [0.029766815581492016, 0.15375319894935402, 0.019120916657681977, 0.03539668509204473, 0.00769755315767335, 0.01325690167556916, 0.02237314518008913, 0.03580630989745259, 0.03901910874992609, 0.013761260995774396, 0.013800318319616573, 0.032278606335499456, 0.02891811415819185, 0.048567826726606915, 0.02058735636195966, 0.03059357657496418, 0.05759140609630516, 0.0576077045074531, 0.028903959917702844, 0.023436363753197447, 0.02021503571553954, 0.03589714877307415, 0.025340935215353966, 0.06507277036351816, 0.012729489128105342, 0.03304577838363392, 0.040014713004763634, 0.06406309668506895, 0.028694882922406708, 0.02404546767606267, 0.015173914077292596, 0.01651659408318145, 0.020742120021688085, 0.027751819330400655, 0.043883465230464935, 0.043081993237137794, 0.03934574532987816, 0.08407860408936228, 0.05565200712797897, 0.06410777143069676, 0.02657596055152161, 0.02999673717256103, 0.03647369319306953, 0.039820119339440546, 0.018853224414799894, 0.03622077265754342, 0.001710417042236908, 0.07105352729558945, 0.02255811382617269, 0.016567918471992016, 0.029092311060854366, 0.026282154888446842, 0.008314638348695422, 0.02969703504017421, 0.07042591633009058, 0.03575590831626739, 0.05075142027011939, 0.02806269863088216, 0.0311440448941929, 0.017235839506611228, 0.02984288614243269, 0.030394575824694972, 0.039404323258038075, 0.015031823755374976, 0.03496409187625561, 0.02747027818778796, 0.02145067003688642, 0.014777354463668806, 0.0436022938894374, 0.031697244316871674, 0.051636470814368556, 0.02670222913314189, 0.059998176592801294, 0.015122158818745186, 0.032324641543839655, 0.013344713436838771, 0.03894427990806954, 0.01977048671272184, 0.03672240002612982, 0.012783040808114623, 0.05433895365734186, 0.06406820605375937, 0.028123681965683187, 0.0637480935880116, 0.09629946760833263, 0.31210330980164663, 0.48538687718766077, 0.516119193817888, 0.7920725462692124, 0.8080897182226181, 0.9629396604640144, 0.8446920141577721, 0.7317160421184131, 0.867307152066912, 1.053305977157184, 1.8426837623119354, 1.6388027710574014, 2.4170351028442383, 1.9326933324337006, 2.41017028263637, 1.8831578876291002, 0.9837222652775901, 0.3801419974437782, 0.10888889777873244, 0.03930027669827853, 0.047998403531632254, 0.023994769235806804, 0.008454280007364494, 0.014702026898573552, 0.05235035750748856, 0.075486084446311, 0.05277827561699918, 0.044015168877584596, 0.014420533253412162, 0.033150154032877514, 0.06669752246567182, 0.023227335951690162, 0.039682641359312196, 0.025111339321093898, 0.02018996554293803, 0.026871715306437442, 0.0360861377391432, 0.008897810359485447, 0.035645598878285716, 0.05253028463838356, 0.0324196059123746, 0.022692395906363214, 0.04037763424483793, 0.040386041293718984, 0.04609615774825215, 0.03061681639935289, 0.013477423012123575, 0.0327512975782156, 0.11442469858697482, 0.04914523967142616, 0.013629180761719388, 0.028428903980446712, 0.06289979589304753, 0.012524937961383589, 0.016382714034989476, 0.01057094709748136, 0.012749339670075901, 0.08026584118072476, 0.01892789380092706, 0.0319741035678557, 0.024214735021814704, 0.010981319139578512, 0.036443379641111405, 0.02991847155083503, 0.03807371608646853, 0.017984618166727678, 0.018576348200440407, 0.04158126376569271, 0.06603328417986631, 0.0563585520721972, 0.025206045846321752, 0.00899450499231794, 0.04241879310991083, 0.07593370721276317, 0.00789713829622737, 0.022594859890107597, 0.07293404638767242, 0.028343668107741644, 0.045869869712207995, 0.10121639698211636, 0.02755884057842195, 0.017319638581414307, 0.11149230772363287, 0.01675686163694731, 0.02897595926853163, 0.031154368804501634, 0.02461140150470393, 0.024595019973016212, 0.022754856751167347, 0.03565967847992267, 0.02021050819062761, 0.06549890392592975, 0.02126993884199432, 0.02057560922444931, 0.013534576016744333, 0.017694810771250298, 0.0346939535146313, 0.007403980741011245, 0.022388215442853313, 0.024477808137557337, 0.04329732293263078, 0.005007061300732727, 0.06634264865091868, 0.018970994345311607, 0.015837648550846746, 0.06487488919602973, 0.07398141947175775, 0.034851119188325744, 0.029580676462501287, 0.05737574052597795, 0.0508381166894521, 0.053061390960855145, 0.09559673603091921, 0.028600661549717188, 0.06611750394638095, 0.03535019865791712, 0.03332249853493912, 0.036132685241422484, 0.07479223489229168, 0.023082122672349215, 0.04395909135096839, 0.00845385592297784, 0.04373992793262005, 0.05809335916170052, 0.02180593740195036, 0.058859526978007386, 0.09895016465868268, 0.035607950362776, 0.0771486038076026, 0.019461305446124504, 0.05604651078049626, 0.05531174556485244, 0.029877423574881892, 0.03457358818767326, 0.010349149266923112, 0.0766648490514074, 0.028365335427224636, 0.013948344974778593, 0.07201741343098027, 0.038258728837328296, 0.056182336527854204, 0.06517322068767888, 0.03214489761739969, 0.044616276265255043, 0.012946923978493681, 0.020038141636177897, 0.041942739726177285, 0.02346547120915992, 0.008275385946035385, 0.010542385862208903, 0.02250973767201815, 0.021571145625784993, 0.0437634459563664, 0.061048365597214015, 0.0047792677651159465, 0.06060466476316963, 0.04960946958245976, 0.10367871235523905, 0.05453357446406569, 0.07623423037252255, 0.05757112468459776, 0.017039004979389052, 0.034029630411948474, 0.016179262094997933, 0.019812203045668345, 0.01149854772458119, 0.02347364755613463, 0.0507758678868413, 0.04195862762363894, 0.07160692688609872, 0.03611281434340136, 0.0319657677651516, 0.05023280917001622, 0.05419781498078789, 0.1151633925203766, 0.2119209934026003, 0.5092271779264722, 0.7785459235310555, 0.81433902574437, 1.3859633611781257, 1.6171618465866362, 1.8421682928289687, 1.628630825451442, 1.450747279184205, 1.8138190997498376, 2.0995069869927, 2.8222979051726202, 2.6005876192024777, 3.660720092909677, 2.604407174246652, 2.7244835538523535, 2.3403760620525906, 1.3712769321032932, 0.42210993117519785, 0.21868662536144257, 0.03918540411229644, 0.030118608847260475, 0.08809666455324207, 0.03614169618647013, 0.026730420566829186, 0.04165511212444731, 0.01376634746390794, 0.026835814018600752, 0.006396689144561866, 0.036572331828730445, 0.039877906774303744, 0.05537844555718558, 0.07697883434593678, 0.03945540676691702, 0.03725940960326365, 0.02346657552490277, 0.06330235714891128, 0.03850883345252701, 0.03330094826274684, 0.01816209069719272, 0.052191088375236304, 0.024712739013401524, 0.033414677517222505, 0.02982993969427688, 0.014781233987637928, 0.02392281568609178, 0.04793767464746322, 0.03812492512432592, 0.03780736055757318, 0.04168686756332006, 0.07470350965325322, 0.031145422320280756, 0.006997057353146374, 0.03257003712600895, 0.03343828035784619, 0.014371101977303624, 0.03579350933432579, 0.08762949319290263, 0.07298467188541378, 0.08701941557228565, 0.03054034211007612, 0.012221005163155496, 0.034684922213533094, 0.05402711592614651, 0.021202740126422474, 0.0484498566282647, 0.0035304461156816353, 0.004590739778775189, 0.019812033411913683, 0.08424941170960665, 0.025541839256350483, 0.015376395712207471, 0.011400675833491343, 0.04297532753220626, 0.009365381207317114, 0.026730171205209832, 0.03126888855227402, 0.037365607119032314, 0.041834384469049316, 0.02634318232802408, 0.048487176054290364, 0.05904212753687586, 0.03297377564013004, 0.019158380272399102, 0.05456969966845853, 0.03588892492864813, 0.022109527539994036, 0.008954356923433287, 0.03317610460466572, 0.08122847202633109, 0.026795785541513135, 0.07456492566104446, 0.13211847628865922, 0.2084383581365858, 0.12741169599550112, 0.19624505671007292, 0.0920471293585641, 0.1418786189918007, 0.06279581040143967, 0.1283527019300631, 0.08595965922410999, 0.09388287871011666, 0.06766209392143147, 0.12399342656135559, 0.1284803615084716, 0.08231571582811219, 0.11852010525763035, 0.16631307213434152, 0.1647777102355446, 0.09412500714617116, 0.11367852041231734, 0.08242096339485475, 0.1391624297414507, 0.1381424559014184, 0.10702560669077293, 0.13332609220274858, 0.11753568665257522, 0.07319951642836843, 0.1167682364050831, 0.1322747157620532, 0.08006886246481112, 0.1029143969395331, 0.09112213685044221, 0.11759584556732859, 0.14713932813278266, 0.15387913504881517, 0.13675722666084766, 0.17048010496156557, 0.2011419760861567, 0.2689763568341732, 0.14916989845888956, 0.1541165273104395, 0.11336990911513567, 0.08944088313728571, 0.11875755180205617, 0.13201544753142766, 0.18779535511774675, 0.18630352802574635, 0.05923873305852924, 0.18985138407775334, 0.1415389986442668, 0.1896455708358969, 0.1394097828971488, 0.08670328610709735, 0.15329813265374728, 0.1059097626379558, 0.11109367518552712, 0.17103019330118382, 0.20692339300044946, 0.07780751559351172, 0.08659283417676177, 0.07947439114962306, 0.14046991243958473, 0.30024900447045055, 0.11374598036387137, 0.0718029352969357, 0.21854280307888985, 0.10537902611706938, 0.18186843315405504, 0.11122335001294102, 0.17084609317992414, 0.08486514831227915, 0.11279348004609346, 0.11450361220964364, 0.16185561274843557, 0.13992204969482763, 0.06952754953610045, 0.06685696462435381, 0.12714534385928086, 0.08543869360749211, 0.135518343853099, 0.1361087914556265, 0.1652603114822081, 0.14247708687824862, 0.09011165571532079, 0.15514350363186427, 0.2785317583807877, 0.4651681078331811, 0.6919565498828888, 0.8067059953297887, 1.3847091027668543, 1.6448082945176532, 1.5277775057724543, 1.5442575471741813, 1.4493289781468255, 1.5467611785445894, 1.8451425560883112, 2.905985048839024, 2.888392210006714, 3.68633462701525, 3.2470471475805556, 3.3744601735046933, 2.59594709106854, 1.50508143220629, 0.8735752957207816, 0.3331712250198637, 0.14005806882466587, 0.18963058878268513, 0.10838851212923016, 0.11825733578630857, 0.152286274092538, 0.11806510681552546, 0.1589433675897973, 0.11693880653807096, 0.17829803616872855, 0.09916667161243302, 0.1046395722244467, 0.12137562488870961, 0.15077753790787288, 0.11175207807017223, 0.14397739565798215, 0.10314813189740692, 0.17468341227088655, 0.11711878116641726, 0.07638194066073213, 0.12089018736566816, 0.19466967481587613, 0.08372961317322083, 0.08226183336228132, 0.14248058811894485, 0.14962560257741384, 0.15442353726497718, 0.18164518156221934, 0.13890480356557028, 0.10261370414601904, 0.2058731700692858, 0.12939641092504772, 0.12464045041373797, 0.08305501365768057, 0.1330409717879125, 0.12224086560308933, 0.10036861497376647, 0.12536759568112238, 0.16570343556148664, 0.18341024113552912, 0.17237252555787563, 0.15655704135341303, 0.12944161492799008, 0.12384200468659401, 0.1396537298070533, 0.0922107920050621, 0.1530089545994997, 0.08198811233575855, 0.11371847255421536, 0.09241156373172998, 0.18909781665674277, 0.12013857412551131, 0.09873297916991369, 0.0940395931580237, 0.06272861507854291, 0.12545351178518363, 0.1259926485696009, 0.19222213115010942, 0.17736792750656605, 0.15407187970621244, 0.1394598452108247, 0.19689716957509518, 0.17015036408390316, 0.11228434129485063, 0.21581745360578808, 0.12718380322413786, 0.08179077399628502, 0.08640188763716392, 0.09114481349076543, 0.16677396026040825, 0.18337368166872434, 0.09153769883726325, 0.14429843771670545], [0.035690721457025835, 0.020382947687591826, 0.027767853112891316, 0.04650723461859992, 0.014250728168657847, 0.023653669681932245, 0.04404415589358125, 0.02109522116370499, 0.04781446625877704, 0.0378613176622561, 0.0156387410991426, 0.04561656580439635, 0.022372395398893526, 0.02489718179484563, 0.020490196932639395, 0.02692488531049873, 0.09709456137248448, 0.032827673479914665, 0.05866480099835566, 0.011243051300490541, 0.019789234635287097, 0.06055591880742993, 0.02078472523550902, 0.011917601622241949, 0.09457132034003735, 0.02773124275596014, 0.04285124722602112, 0.044173657694565396, 0.049141921635184965, 0.05088006711698004, 0.026310251327231526, 0.03835648198478988, 0.013303581492177077, 0.07556535090718951, 0.007209550772261406, 0.030695238084133183, 0.043899139389395714, 0.03030313305290682, 0.08335668354162148, 0.026177545144621815, 0.06881632270025355, 0.05339304869994521, 0.02588643496190863, 0.06809020202074732, 0.03859213719676648, 0.023632000666111708, 0.024368014386189834, 0.07057337556034327, 0.03114817038710628, 0.002989218595238136, 0.012171953866657401, 0.04773317776354296, 0.03336875426716038, 0.09568048760827098, 0.03184394358790346, 0.03163752644988043, 0.02028570174505668, 0.0026720901992770708, 0.04450256397415485, 0.014819443990875567, 0.03547609065260206, 0.044146920022155554, 0.045861849428287575, 0.065533515997231, 0.016457307085927044, 0.019083624373057058, 0.005552172585989216, 0.02233672820563827, 0.05621401393519981, 0.03214113853339638, 0.031182894416685616, 0.006037881098953741, 0.029790577877845083, 0.03130881694544639, 0.04595642363918679, 0.022847688823406185, 0.06606998613902501, 0.031826423813721964, 0.08354606266532626, 0.011183599758494114, 0.03805355681106448, 0.03341812447511724, 0.026930043872978007, 0.02684904375512685, 0.050021462475082705, 0.048694733131144724, 0.014128016806872827, 0.03238625252353294, 0.008616997793849026, 0.057760062760540416, 0.07613733557185956, 0.028551552577742507, 0.033888976887932847, 0.05339678403522287, 0.05493320784132395, 0.00597271162717204, 0.030388737030859505, 0.0437906586032893, 0.04717130327065076, 0.051702733151614666, 0.041176012118480036, 0.03556288545951247, 0.03499763864757759, 0.01620363168019269, 0.02289583088297929, 0.037832493494663916, 0.036145482411874194, 0.015380365142066563, 0.05489110474341682, 0.07509220843868596, 0.04107191127591899, 0.041759609909994264, 0.002104887510150937, 0.05204377503001264, 0.028451131091320088, 0.054287334105798175, 0.02960176533088088, 0.03463538915717176, 0.0345077024373625, 0.016162341127970388, 0.03444241379786815, 0.014891307634700621, 0.02728321117215923, 0.008275268898744668, 0.05948329743530069, 0.0661615612251418, 0.03881857790318983, 0.03700734741453614, 0.03186906973964401, 0.03532540498833571, 0.06688027908759457, 0.039895999910576005, 0.05660197311746223, 0.03417722534920488, 0.04232647502794862, 0.04520445416814514, 0.06840025181216852, 0.03750361096380012, 0.024901049444451928, 0.03666731655331595, 0.04437166778370738, 0.036388177424669266, 0.03692728028233562, 0.03699021779799035, 0.028529133780726364, 0.06727754777031285, 0.03504037617572716, 0.027323901220890026, 0.036307017851088724, 0.02041645035413759, 0.05802373468343701, 0.09592854644038848, 0.0791741461892213, 0.038208893832883666, 0.026492429498050894, 0.03653273591771722, 0.016660102543288043, 0.061217375099658966, 0.05946011867906366, 0.010145674426374691, 0.05197560600936413, 0.07237075375659124, 0.04240377712994814, 0.03331701257931335, 0.021622259668739777, 0.03494616837373801, 0.044122601327087195, 0.08088072961462395, 0.04239429121038743, 0.09087904489466123, 0.031628668175211976, 0.046368525097412724, 0.032741957543683906, 0.059429129984761984, 0.12290686129459313, 0.03047832061669656, 0.015681597370920435, 0.03031934325450233, 0.049635545683226416, 0.031934049645704884, 0.03428739908018282, 0.04435099960703935, 0.07783398524458919, 0.027369843130665164, 0.044412010083241124, 0.016760920972696373, 0.09663915580936841, 0.032254172289477925, 0.01230209942774049, 0.007556070124597422, 0.05661407478951982, 0.04186153944049563, 0.039839593294475756, 0.05504313390702009, 0.0030034097310687813, 0.072696796618402, 0.03439137778644051, 0.07363223856581108, 0.038173403058733256, 0.03143918387857931, 0.034891546304736815, 0.03396253686930452, 0.0719779905463968, 0.029715196029948335, 0.007619910939995731, 0.029800962856305496, 0.012708938846896802, 0.02105102817794042, 0.00655334464473916, 0.0274570535402745, 0.02451129044805254, 0.050061404438955445, 0.056739559663193564, 0.03170539691512074, 0.012816809799655207, 0.0639447873192174, 0.02446797616513712, 0.02403556615380304, 0.029220659352306808, 0.021775883389636874, 0.053518116274582486, 0.023770155484921167, 0.015634768276608417, 0.026190674797232662, 0.03660481330007315, 0.04202932079455682, 0.03720153056617294, 0.03239386568644217, 0.029193595983088017, 0.0715085935911962, 0.01868329889007977, 0.05167092003726533, 0.037467020962919505, 0.03592069393822125, 0.00832656869066081, 0.06105675229004451, 0.01661979077783014, 0.03314095309802464, 0.06427069447402443, 0.024930309570793594, 0.015357172815129161, 0.03431875418339457, 0.030935056108449186, 0.023226094232606034, 0.044714718125760555, 0.0036633210838772357, 0.042824163500751765, 0.012885628517584076, 0.04308163361357791, 0.006478732934088579, 0.01104863575060985, 0.02204107353463769, 0.05842916614242962, 0.046449525215263875, 0.03628421228911195, 0.030881747004709074, 0.025998033616425734, 0.05310292748202171, 0.01801014635046678, 0.038353221624025276, 0.04248516062008483, 0.02335054942938898, 0.012680057003828031, 0.01854688790626824, 0.13285429323358194, 0.09942936644490276, 0.0352177757636777, 0.04629085658650313, 0.027199987155784453, 0.010334185873424368, 0.08572514395096473, 0.02223390979426248, 0.023682505723887255, 0.02131403683285628, 0.03529019919889314, 0.04525348171591759, 0.038488857381578, 0.04918912731643234, 0.03969119429322226, 0.05052343928920371, 0.05813605937042406, 0.04753272494833384, 0.056107059852885346, 0.033933305580701144, 0.03279542949582849, 0.06222744911376919, 0.010108919880752052, 0.05086332765806999, 0.0453136677720717, 0.026074804764773165, 0.034571820603949685, 0.058119211345911026, 0.024377084703051617, 0.0525000932227288, 0.05557648278772831, 0.04721031903422304, 0.04735194964866553, 0.014720469480380416, 0.06975882141185658, 0.057784245748605044, 0.009930182730646005, 0.04925026671428766, 0.007695456484465727, 0.03680709476715752, 0.0354140182690961, 0.04968443413132003, 0.04240155153508697, 0.017411028766738515, 0.08096581112061228, 0.03456314553373626, 0.07719703763723373, 0.07438403501042298, 0.036011163012257645, 0.04829897079616785, 0.03533932174156819, 0.0628326887797032, 0.007125949320782508, 0.03024941004280533, 0.033522266029779396, 0.044223903212696314, 0.005556062712068004, 0.07172603013792209, 0.029157070443034172, 0.00130179084953852, 0.02442950662225485, 0.05633177708036133, 0.04632481387151139, 0.05679137598989265, 0.06701462223593678, 0.037420219010008235, 0.012142147519625723, 0.0033137029469279306, 0.0316140457455601, 0.010902503904487406, 0.07789135538041592, 0.012003915517457893, 0.06485333213848726, 0.0026078380220237053, 0.02598754346503743, 0.04497955034353903, 0.04061789331691606, 0.04302881984040141, 0.06720611838889973, 0.030641905231667415, 0.023982309636526873, 0.07178686080234391, 0.037166450305708816, 0.02752731753779309, 0.05688445742375084, 0.027398465434089303, 0.03543156518467835, 0.021540564052494507, 0.1461901254951954, 0.14936433945383343, 0.19727283370281967, 0.1548377014696598, 0.13953058927186898, 0.16089201159775257, 0.11265908261494977, 0.09910246184361832, 0.1517535291079964, 0.12469173409044743, 0.2023459957646472, 0.09662466230137007, 0.11337184293993882, 0.07498222469751324, 0.14744822441467217, 0.05376136429341776, 0.1190746176455702, 0.13451658189296722, 0.14720173978379794, 0.1590866877564362, 0.1307739998613085, 0.1622496923165662, 0.07625839300453663, 0.09780231410903589, 0.2661260754934379, 0.11750023998320103, 0.1486581609185253, 0.08409948939723627, 0.11561190416770321, 0.10206065060836927, 0.06635257561824151, 0.07229771624718394, 0.08285588398575783, 0.16914997276450905, 0.12104297988116741, 0.10664597991853952, 0.13070309295185975, 0.14396303785698755, 0.1014921400429947, 0.10074189744357552, 0.1228227908057826, 0.15070260050041334, 0.08456011967999594, 0.13529762998223305, 0.11726150422223977, 0.0599421974537628, 0.11311579096530165, 0.14229936498616422, 0.12660632921116693, 0.08480189527784075, 0.08864197600632906, 0.07950925427888121, 0.11666976740317685, 0.1530859547534159, 0.14837196841835976, 0.08525417957987104, 0.15037159754761628, 0.0933992460902248, 0.1023249603541834, 0.1557845835174833, 0.13868695311248302, 0.11330837955964462, 0.08755619784018823, 0.13006441508020672, 0.07836930866220168, 0.130515898710915, 0.11851743182965688, 0.11352006891476256, 0.11268601366983992, 0.12757146385099205, 0.15956023734595093, 0.12739404051431588, 0.14995766404483998, 0.08425302830125604, 0.12655769182103022, 0.07825741145227637, 0.17037499988717691, 0.19662978606564657, 0.18144723932657922, 0.10435569352869477, 0.19009049981832504, 0.12784107295530184, 0.1345298947500331, 0.22831921705177852, 0.1236940569111279, 0.1877733977245433, 0.08368537947535515, 0.20207173191010952, 0.2811922127647059, 0.14901250547596387, 0.1391434714730297, 0.10696314754230635, 0.11032910192651407, 0.22061848241303647, 0.15647952551288263, 0.05838754480438573, 0.1318728466119085, 0.21294765759791645, 0.07071418514741318, 0.1392208244651556, 0.17896705812641553, 0.14287704255964073, 0.14014292641409806, 0.1288932500673192, 0.16384129119770868, 0.10909932505871568, 0.1234264834118741, 0.08383331368012087, 0.11511657360408988, 0.12587876325207098, 0.10017550390745912, 0.19609417766332626, 0.10180142987519503, 0.1373580422784601, 0.18226422263043268, 0.1092204571302448, 0.18619279111070292, 0.09930432601166622, 0.20712231232651643, 0.09717156831175089, 0.13366808742284775, 0.0833805747596281, 0.13316475014601434, 0.1163418178579637, 0.08316674123385123, 0.1474861002394131, 0.10747025068849325, 0.12488253813769136, 0.1393744040812765, 0.12182106955775193, 0.137226759323052, 0.07532525807619095, 0.15331193405602658, 0.0851514833047986, 0.1653852162084409, 0.13186262787452765, 0.095129354324724, 0.12141731408025537, 0.1377237590828112, 0.18363639685724462, 0.1626139706266778, 0.08407421396779162, 0.11359122009681803, 0.13530860867883476, 0.10501992502915007, 0.15993237309157848, 0.1150524520448276, 0.10901635379663535, 0.17859819291957788, 0.05268939431490643, 0.22661751907851013, 0.19810211206121103, 0.18159396573901176, 0.10151529165783099, 0.08019456786236592, 0.1240146104246378, 0.14706569351255894, 0.15374353661068849, 0.17882452506039823, 0.19678247001554283, 0.23500118564282144, 0.13383531916354383, 0.17893480057162897, 0.11731668268995625, 0.0744192645485912, 0.15414453723600932, 0.13203082313495024, 0.13506437678422245, 0.22028369323483535, 0.23206600600055285, 0.19351079128682613, 0.22966377490333148, 0.152574447914958, 0.16565444533314022, 0.18168836353080614, 0.11577563466770308], [0.06786489446780511, 0.03065668711704867, 0.040603521945221085, 0.032348006897206814, 0.052439008107674975, 0.01600646467081138, 0.03768630651757121, 0.053405347147158215, 0.08519535737910441, 0.03188828585137214, 0.01996149432047137, 0.05755572872502463, 0.002875078615033999, 0.045572016587747, 0.01861910947731563, 0.022512036209393824, 0.01660629641264677, 0.04173345917037555, 0.022896473794909458, 0.06947851181030273, 0.016871683332802992, 0.03994440320613129, 0.0451807834740196, 0.06645461371434586, 0.03831884025463036, 0.01024980325850525, 0.03786473747875009, 0.04945747095293232, 0.0507098498222019, 0.03973825069676552, 0.02933625118540866, 0.048252470791339874, 0.024940631784764782, 0.021517829736694694, 0.08240966578679425, 0.025953784651522125, 0.05916775829557862, 0.04623731678085668, 0.0227777233812958, 0.04936782629894359, 0.06261322341327157, 0.00549771506173004, 0.05571185391662376, 0.023357660476384417, 0.04021650592663458, 0.02745021221094898, 0.02908425685018301, 0.017820602682019984, 0.023048828655321683, 0.046799998730421066, 0.05650117334776691, 0.029430133290588856, 0.03604658593290618, 0.045803668443113565, 0.05983726201312883, 0.02839471260085702, 0.020630543419559087, 0.026930802135861347, 0.043257862728621276, 0.018476092955097556, 0.03967619188395994, 0.011586278061648565, 0.0469196176688586, 0.07181469430880887, 0.05465206703437226, 0.07445254669125591, 0.013117796907733594, 0.0462959422064679, 0.04474769153499177, 0.04555256298876234, 0.05168068076350859, 0.04096770865310516, 0.028177683175142323, 0.026710670108773878, 0.07363898998924664, 0.07405036541500262, 0.037933663065944395, 0.069941455897476, 0.061781135919903, 0.05159103610951986, 0.03371887833678296, 0.017274192002202784, 0.009361348164800023, 0.03143063433734434, 0.060553645715117455, 0.043668495158531835, 0.011341360846667417, 0.049456809381289144, 0.028758292019899403, 0.038530549965798855, 0.055350822396576405, 0.02304382954857179, 0.02406981690520687, 0.03913249534421733, 0.02041018408324037, 0.05664510080324752, 0.03238941788939493, 0.039717993033783774, 0.07207439680184637, 0.07607058129672493, 0.05682720263887729, 0.06675814278423786, 0.042506846599280834, 0.026672768838969723, 0.021119215858301947, 0.038038354233971665, 0.036815335574959, 0.021754054918086956, 0.059103507814662795, 0.04112363600039056, 0.03424416282879455, 0.06842091320348637, 0.01967178361623415, 0.055554077561412535, 0.02843567236725773, 0.03417934916381325, 0.065589040517807, 0.06251031000699316, 0.030240697653165886, 0.04071354979117002, 0.02328044149492468, 0.10739285019891602, 0.0036088203030106214, 0.027837365632876754, 0.024239856084542613, 0.008929955107825143, 0.04512848199478217, 0.020796255241813402, 0.01898827832857413, 0.021908189236585583, 0.0238759153456028, 0.024867711322648183, 0.022721869771235755, 0.06915876575346504, 0.05034288451341646, 0.02318400640173682, 0.03765994203942163, 0.03641705587506294, 0.06442942417093686, 0.04926166610260095, 0.026073634291865995, 0.04376083020386951, 0.06889154509242092, 0.06666507492108004, 0.01802618013295744, 0.01810347884228187, 0.03638548364064523, 0.045594716976795874, 0.02473026218025812, 0.04949782003781625, 0.04812839727050491, 0.013323488861455448, 0.046785067567335706, 0.03889709119019764, 0.02961718164650457, 0.035410666306103976, 0.07735694798507861, 0.023398503195494413, 0.046354757621884346, 0.029081919297043766, 0.047142289113253355, 0.011308084641184126, 0.04836053767108491, 0.009740014809982052, 0.015415796544402838, 0.01617119261728866, 0.03172454856602209, 0.053563574728156836, 0.027173514112031887, 0.023185144644230604, 0.058295901864767075, 0.10014805716595479, 0.12608475291303226, 0.03264105599373579, 0.008240371842735579, 0.04590007469856313, 0.07273380391831909, 0.030271781342370168, 0.044853373364146264, 0.024458751481558596, 0.04955503071791359, 0.03329643261219774, 0.03725294655721102, 0.04610700413052525, 0.013435339422098227, 0.02257762340429638, 0.006665594692874167, 0.019460540397890976, 0.030282349525285617, 0.03634903273944344, 0.04223724088764616, 0.04516487522050738, 0.014332662968497192, 0.04192426661029458, 0.019543555764747516, 0.04260018248377102, 0.07287560416651623, 0.038763365508722405, 0.021478018390813043, 0.06159534624644688, 0.05017406160810164, 0.038837241008877754, 0.0195347534692181, 0.03371681559032627, 0.007492626252185021, 0.025743147025683095, 0.049987172707915306, 0.033100013687674484, 0.03916531269039426, 0.022182732986818467, 0.011192262954344707, 0.061146264629704614, 0.017968591169587204, 0.045247191696294715, 0.04435503689040031, 0.037965469394943545, 0.05890163007591452, 0.015109434590807982, 0.0590630399861506, 0.018105066614225507, 0.0707270298153162, 0.022050216794013977, 0.03736453842637794, 0.027975181184176887, 0.026092541670160632, 0.06683308697704758, 0.0381021942012012, 0.05510505362014685, 0.048791797565562386, 0.006864946585015527, 0.01104684781083571, 0.033050724903919866, 0.03428659162351063, 0.025203640439680645, 0.04186037236026355, 0.049362319987267256, 0.011193893982895782, 0.059157146007886956, 0.022723559323432188, 0.03012746712192893, 0.031044921105993644, 0.016412298161802546, 0.02400392267320837, 0.030182190971182923, 0.02422374257418726, 0.010234105350848819, 0.03272156078102333, 0.054770088022840877, 0.02815052990003356, 0.021897846666563834, 0.032458292586462836, 0.022411490890330503, 0.02654339765597667, 0.056301243004522154, 0.050617223006806204, 0.059385221983705244, 0.05623416303257857, 0.05251630003164921, 0.03713579748624137, 0.027874651132151484, 0.034221031570008824, 0.05116352851369551, 0.00573160989941763, 0.04756787306229983, 0.04556964171518173, 0.03225445727418576, 0.08956190664321184, 0.023005392236102904, 0.06792998633214406, 0.06243063642510346, 0.030956192474280084, 0.013342431862838566, 0.02362702870076256, 0.02314646984450519, 0.04190405983743923, 0.09365329638655696, 0.04999084697504129, 0.014765000037316765, 0.06716243430439915, 0.044824216714394946, 0.022590668240029897, 0.06173257316861834, 0.008603877471094685, 0.03835339804313012, 0.017681126416261708, 0.03917752632072993, 0.025882185636354343, 0.0963816653404917, 0.02797552214802376, 0.06286575379116194, 0.11327523312398366, 0.04082819167524576, 0.02997182815202645, 0.047005968035331795, 0.031708270510924716, 0.05842437568519797, 0.04198400144066129, 0.05628463925261583, 0.02980338522632207, 0.011188280801954014, 0.0257288367221398, 0.028784161167485372, 0.03823443389098559, 0.002969318223352145, 0.027935722676504935, 0.04212881438434124, 0.0057039439062854, 0.03718098113313317, 0.02814678947574326, 0.03875177952327898, 0.03372912421556456, 0.027272363093548586, 0.05091907609520214, 0.09153301694563457, 0.04448971591357674, 0.05126093900097268, 0.0466130250133574, 0.0487620709463954, 0.04549556943987097, 0.03605654343430485, 0.07617825801883425, 0.06254000269940921, 0.024041135229968598, 0.0341275158737387, 0.014631072491673487, 0.02338223871109741, 0.09660068287381104, 0.009610302663142127, 0.030626936749156033, 0.05235220312273928, 0.046280505534793646, 0.029997809257890497, 0.021921149255441766, 0.08020864746400289, 0.01657576233680759, 0.01621039497799107, 0.05895980088306325, 0.015987928790439452, 0.06773347580539328, 0.03845819438408528, 0.01015259972440877, 0.020994058377774696, 0.01692896525907729, 0.07289049801017557, 0.025173864626724805, 0.08060339878180198, 0.05199528352490493, 0.06365447611148868, 0.026313574452485358, 0.05140192161447235, 0.021345620941636816, 0.05579749182132738, 0.21633993914084776, 0.09794327297380992, 0.12870047826852116, 0.1448982898145914, 0.1196542629706008, 0.11573313123413495, 0.11473552190831729, 0.14789836454604352, 0.15000350587069988, 0.12155011695410524, 0.1405412128993443, 0.10816947423986026, 0.12119430676102638, 0.201068124334727, 0.1268048414162227, 0.12293206208518573, 0.20248650679630892, 0.12785134597548417, 0.11788724921643734, 0.15319008273737772, 0.12819342261978559, 0.18377485871315002, 0.1899227388203144, 0.2136767841875553, 0.08859053626656532, 0.11448663526347705, 0.12221042652215276, 0.088025309810681, 0.12822148682815687, 0.07309846899339131, 0.1833489965647459, 0.16806764155626297, 0.10485590954444238, 0.09334528898554188, 0.16541689022311143, 0.11051183819238629, 0.08934004604816437, 0.14316390002412455, 0.17269607819616795, 0.21660349571279117, 0.16122031398117542, 0.09531874701912914, 0.1337827326995986, 0.09374361618288926, 0.13240784433271202, 0.11189198520566736, 0.11690266776297774, 0.10289322664695126, 0.11957093887031078, 0.11812704349202768, 0.27270694236670223, 0.0879209850515638, 0.13844284335417406, 0.10395760381860392, 0.19409008377364703, 0.16734471677669457, 0.07924774009734392, 0.09171711706689425, 0.08620115662259714, 0.11215546713875872, 0.13025261355297907, 0.11575158738664218, 0.12317518118236746, 0.18026272074452468, 0.16310854123107024, 0.0707515792122909, 0.10990006423422269, 0.1481782059584345, 0.19714193072702202, 0.181385302650077, 0.1475345069276435, 0.14437209947832993, 0.05462387051167233, 0.13199366655732903, 0.19932830626411097, 0.14356305503419467, 0.14111756054418428, 0.1104113742975252, 0.10874069215995924, 0.11493756249547005, 0.14673454128205776, 0.1243834484900747, 0.10953894111194781, 0.05498687317594886, 0.1865054736179965, 0.10211247711309365, 0.04107419793893184, 0.12228476681879588, 0.10496896026389939, 0.10967487881758384, 0.18981870583125524, 0.14177970215678215, 0.10414292530289718, 0.15201049031955854, 0.1471042071602174, 0.1367539968341589, 0.11768980909671102, 0.11044272261538676, 0.1347681148243802, 0.17678301674979074, 0.10654796553509575, 0.14372238862727368, 0.25191475663866314, 0.15629378333687782, 0.1039888910683138, 0.21281653749091284, 0.16319485088544233, 0.12055870943835803, 0.13565486509885105, 0.10727326518722943, 0.12559225862579687, 0.13906781481845037, 0.07148742329861436, 0.253730869186776, 0.19412377982267312, 0.10596644745341369, 0.17726682578878744, 0.16241074938859257, 0.13076716022832052, 0.09118513882692371, 0.06876808564577784, 0.24201438788856777, 0.09196086720164333, 0.09565340727567673, 0.041321479848452976, 0.15300871032689298, 0.13725510851613112, 0.12839536821203573, 0.11991986871830054, 0.09696376017693963, 0.10888122354767152, 0.10722953360527754, 0.08193872855710131, 0.13375407138041087, 0.14614754063742502, 0.09122346927012716, 0.12404692226222583, 0.14634723349341325, 0.1113890821912459, 0.16189789905079774, 0.09016789948301655, 0.10282564455909388, 0.16607990036053316, 0.206985668944461, 0.14021156701658452, 0.12861970545990126, 0.16286435004855904, 0.11053152249327727, 0.13344478154821054, 0.19528129271098546, 0.19483043333249433, 0.06302596947976521, 0.0891199428588152, 0.10532110636787755, 0.09438841444041048, 0.14609039441815444, 0.09764490077005965, 0.08480471798351832, 0.2399312039571149, 0.1204584219626018, 0.2581219949892589, 0.12962965055235795, 0.1375213927988495, 0.13974793760904244, 0.07069623789616994, 0.06924821023962327, 0.10315388587436505, 0.1766343768686056, 0.14106065859752043, 0.17068251195762837, 0.19726726971566677, 0.20278765420828546, 0.2706998086401394, 0.20433175563812256, 0.09388484646167074, 0.16497962868639401], [0.04254083102568984, 0.06741009958620582, 0.02737135287108166, 0.03459048031696251, 0.03651899219091449, 0.052701624908617566, 0.027492288167455366, 0.07713594234415463, 0.007004645919161183, 0.0497184864112309, 0.012685959410321499, 0.0035980757009903236, 0.07996847320880208, 0.10511869937181473, 0.08061175154788153, 0.032773760480007956, 0.032596354106707234, 0.02756347836527441, 0.09275737910398416, 0.0567123334455703, 0.03839086674685989, 0.03390989612255778, 0.04939268442935177, 0.08513199577906302, 0.01447743350373847, 0.02128043577873281, 0.026152071243684207, 0.014066405827179551, 0.05869757423975638, 0.019461458116503697, 0.02605366670260472, 0.04666026122868061, 0.03174665862960475, 0.03266625678432839, 0.05417412732328687, 0.0820260356579508, 0.03986386109941772, 0.0213761295724128, 0.032970786693372896, 0.007957677190591182, 0.03903182449617556, 0.05624442926741072, 0.07071393408945628, 0.0350173636605697, 0.02875719957851938, 0.012145709828473628, 0.019985714627962028, 0.019830923826832856, 0.029571651946753263, 0.024509134403030788, 0.05427054375676172, 0.00838862665529762, 0.0765659525724394, 0.04608349967747927, 0.02020432673660772, 0.045877601618745496, 0.03665289429149457, 0.0419103498570621, 0.015682806859591177, 0.03221105817439301, 0.013027462692532157, 0.011878649471327662, 0.061955349785940986, 0.019910312424014722, 0.02527462538065655, 0.02673549940144377, 0.05561444342934659, 0.03860545005383236, 0.012607579285811101, 0.050854455812701156, 0.04336248943582177, 0.009199535374396613, 0.04361851766173329, 0.05965555712048497, 0.03993681039927261, 0.017622324571545635, 0.024935037263536027, 0.0741964607898678, 0.0472246496938169, 0.06841796157615525, 0.020354925887659192, 0.062469380774668286, 0.04796491443578686, 0.03078625677153468, 0.03250740495111261, 0.043034794341240606, 0.026051144248672893, 0.018549345899373293, 0.07741128506937198, 0.03980596849162664, 0.06567121110856533, 0.04035045213199087, 0.05835340092224734, 0.04852829866909555, 0.08011250583721058, 0.015262196572231395, 0.05888143687375954, 0.06413870584219694, 0.03627224971673318, 0.03439612413889595, 0.019823507439079027, 0.010939657089433499, 0.0311086016174938, 0.008475469807828111, 0.02440345596655139, 0.06128401402384043, 0.049890020063945224, 0.04006862261199525, 0.040645536833575795, 0.0055028693833654475, 0.01613818697764405, 0.03263219432639224, 0.044259600940027406, 0.017545007202508192, 0.004600790154654533, 0.03213892650923558, 0.018792202064235295, 0.02772853709757328, 0.020142183106924807, 0.023911633428984454, 0.003689775043832404, 0.029004732545997416, 0.03825688661475267, 0.00923437560309789, 0.046340691590947766, 0.026629327330738306, 0.024457894831097553, 0.058278375305235386, 0.011718494850876076, 0.005910425505135208, 0.03908193769997784, 0.025384290210370506, 0.04710665245407394, 0.03186137175985745, 0.06376443949661084, 0.04067696996831468, 0.04641278932935425, 0.017020114564469883, 0.008254782230194126, 0.01919113994309945, 0.053210617774831395, 0.01679905972975705, 0.005659867967811546, 0.04222673377288239, 0.033662912768444846, 0.004910356913959342, 0.03719971548499806, 0.023551248213542358, 0.03097882161715201, 0.025252993684262037, 0.01762067912412541, 0.01877989004632192, 0.041570061152534823, 0.023575724668002555, 0.0474466968859945, 0.03965763395119991, 0.0358851251325437, 0.028707344218024185, 0.023112982444997345, 0.026382106489368846, 0.03425256309232541, 0.000778769218803583, 0.012967994187160261, 0.0502525986438351, 0.07634912670723029, 0.059581936070961614, 0.00703650780321498, 0.020575320847066383, 0.01785299933648535, 0.09162275320185082, 0.026415965386799405, 0.062654173001647, 0.03267379191571048, 0.03431604004331997, 0.023683840741536448, 0.02992304487686072, 0.014823703494455134, 0.026130846668300883, 0.009847012997072722, 0.012839037758697356, 0.012993660622409411, 0.022695155847551565, 0.07386123734925475, 0.04055382264778018, 0.03792664362117648, 0.01131704808878047, 0.026664639989446317, 0.0020190530423341052, 0.014072598307393491, 0.07632279276315655, 0.025435295687722306, 0.0161071372151907, 0.05068341409787536, 0.029162888880819082, 0.04355095932260156, 0.04354455055935042, 0.011775848023327333, 0.062258397095969746, 0.037100001371332576, 0.02109344000928104, 0.00821573508437723, 0.042647194782538075, 0.040456571616232395, 0.028887549548276832, 0.025795982851247703, 0.011099100944453051, 0.0017169171956733667, 0.013228547393477388, 0.050991133121507506, 0.04244261308174048, 0.0360036550222763, 0.08914641929524285, 0.023975322422172343, 0.077871637152774, 0.03292398813313671, 0.018714720150455832, 0.013119699350292129, 0.03785046449463282, 0.05039664823561907, 0.0197701796756259, 0.023592080754627074, 0.010385505173222294, 0.02261324649277542, 0.022631909598463347, 0.052246785922242064, 0.01779904223180243, 0.07087459761117186, 0.04297557859016316, 0.02309374088820602, 0.024144654228751148, 0.016547499656943337, 0.012139702249052269, 0.0655653460749558, 0.036162316865686855, 0.01736657115231667, 0.0526856929063797, 0.03134150197729468, 0.03362131178645151, 0.013074028854524451, 0.013884177614402558, 0.04367097520402499, 0.029090892922665392, 0.0715520198323897, 0.024865560366639068, 0.031086718863142387, 0.03156162552269442, 0.022211463855845586, 0.002827129089772435, 0.008892596666035908, 0.02313323162629136, 0.0578135381053601, 0.02578592356959624, 0.025115378300792406, 0.039414012738104375, 0.04893606768122741, 0.058677984933767996, 0.02260864432901144, 0.06256234685757331, 0.04289295677361744, 0.041337120080632825, 0.0587749747293336, 0.0509402803145349, 0.01563841031332101, 0.002493972212375541, 0.07097788421171052, 0.010067461391112633, 0.030084712630403892, 0.05884700122156313, 0.009528512051994247, 0.030629684815981557, 0.07605631849063293, 0.010209347304355885, 0.007381372802358652, 0.05432635326204555, 0.013468708926146584, 0.03926264175346919, 0.030115314559744935, 0.005238606286833861, 0.02087705010282142, 0.02163922643688108, 0.014859246855069484, 0.058395612585757456, 0.021462761530918733, 0.048539820193712196, 0.029894074824239527, 0.03413184153448258, 0.01779174119500177, 0.01987344422377646, 0.036028988127197535, 0.01573706421601985, 0.01906205035213913, 0.0020104924749050823, 0.013392405118793249, 0.015047506395993488, 0.03018712731344359, 0.06256345965500389, 0.010852920806168445, 0.03561745324571218, 0.04810037716690983, 0.016190010089693323, 0.027020473931250826, 0.018794195260852575, 0.01087594689202628, 0.021904587911974107, 0.034468194735901694, 0.013233521903332855, 0.024001978670379946, 0.008422125080999519, 0.05277683712275965, 0.03581482551193663, 0.042667381199342866, 0.05084231003586735, 0.05259657411703041, 0.046006177219429185, 0.06682598271540233, 0.008226755341248853, 0.044708557027791224, 0.03147963135104094, 0.08786358098898615, 0.028647300654223988, 0.04549298422144992, 0.0357700082739549, 0.01847358576820365, 0.013902392886978174, 0.10233205783047847, 0.058587454791579924, 0.04039197168978197, 0.025069999575082744, 0.024551061081833074, 0.03601984486782125, 0.03721643119518246, 0.037018244686935625, 0.04360108609710421, 0.05532474968848484, 0.053905776901436706, 0.027096970272915702, 0.07892408567879881, 0.021993426805628196, 0.08291252808911459, 0.02037333623905267, 0.01840546933401908, 0.031021596464727606, 0.043154274179999313, 0.027331658572490727, 0.023036333432953273, 0.006929197914100119, 0.03035175008699298, 0.06724077795765229, 0.031729294918477535, 0.03254895843565464, 0.051143806893378496, 0.017762119748762677, 0.09783363528549671, 0.22862447638596806, 0.13858259442661489, 0.12936101853847504, 0.10844094253012113, 0.1572980558765786, 0.1460770679903882, 0.25084750247853144, 0.16574872098863125, 0.11074298114648887, 0.16926434662725243, 0.07254205670739923, 0.15261640852051123, 0.22477672142641886, 0.18164382449218205, 0.11644285172224045, 0.24430664202996663, 0.13489749788173608, 0.30301930010318756, 0.21410078715000833, 0.12118282594851085, 0.1410462193723236, 0.10784948391041585, 0.16064640906240257, 0.09054824550236974, 0.09098233149519988, 0.1559677336897169, 0.11839011151875768, 0.129352794694049, 0.10164508862154824, 0.06314220252845969, 0.1200357082166842, 0.12433308762099061, 0.11169242127133266, 0.10094686251665864, 0.16911206979836735, 0.0869514670755182, 0.10217868856021337, 0.1655466804014785, 0.1354737233902727, 0.06203636008181742, 0.09163107882652964, 0.16195701302162238, 0.09266468443508659, 0.09200678366635527, 0.10403823413486991, 0.08883944326745612, 0.12541545954133781, 0.11938287610454218, 0.12841619923710823, 0.08970796130597591, 0.09929397835263185, 0.1565566070910011, 0.0873794462531805, 0.12999120115169457, 0.12545041766549858, 0.09366730813469205, 0.09811864713472979, 0.10981190896459989, 0.07762509823909827, 0.1130119411806975, 0.06871778584484543, 0.13754571149391787, 0.10558325158698217, 0.06252162797110421, 0.10473353575382914, 0.13549588434398174, 0.1472595916794879, 0.11201900696115834, 0.18425854561584337, 0.1607142761349678, 0.13781931038413728, 0.10541916824877262, 0.14157631807029247, 0.10860694612243346, 0.0854846847110561, 0.15766686680061476, 0.2151311697172267, 0.11120940611830779, 0.18374235688575677, 0.10299587542457239, 0.22627869940229825, 0.16421965589480741, 0.15609216344143662, 0.14271038078836032, 0.117221524938941, 0.09038752091250249, 0.09421718612845455, 0.12439632708472864, 0.20298951837633336, 0.08475133763360125, 0.12240428397698061, 0.12041601352393627, 0.16319193318486214, 0.19606752480779374, 0.11254027791853462, 0.1446040498891047, 0.1216481381228992, 0.06577160714992455, 0.11854192694383008, 0.06143181252160242, 0.18823301020477498, 0.10931326036474534, 0.08504770815904651, 0.1261503536786352, 0.1658502026860203, 0.1355983159903969, 0.21875248397035257, 0.14500646186726435, 0.12901138301406587, 0.06971080827393702, 0.1406537275761366, 0.12218909338116646, 0.11627369294209139, 0.06717321622584548, 0.18921014134372982, 0.10508114245853253, 0.11488360539078712, 0.1429366043635777, 0.1869227455130645, 0.0630203512098108, 0.0756074743611472, 0.12812494486570358, 0.13491733824568136, 0.1598835592823369, 0.11735097584979874, 0.11071545298078231, 0.10469487282846655, 0.08752896144453969, 0.07021648649658475, 0.11947884809757982, 0.13982393353113107, 0.13748488761484623, 0.1048236655603562, 0.10762760295931782, 0.1172639469483069, 0.1432132159492799, 0.123332750584398, 0.11052182622786079, 0.13287447286503656, 0.20250352445457662, 0.1116090225321906, 0.1449024017368044, 0.1035219029124294, 0.14683770574629307, 0.10419576282479934, 0.07574386668524571, 0.1953549137605088, 0.07643538207880088, 0.16504958564681665, 0.1168413824800934, 0.056819100930754624, 0.1547492476446288, 0.07817311704690967, 0.08220090091760669, 0.11099827994725533, 0.15701437395598206, 0.1517653220466205, 0.14750386428620132, 0.13474057987332344, 0.2111598128186805, 0.11993863699691636, 0.15305623491959913, 0.12392919643649034, 0.1157177963427135, 0.13962092942425183, 0.09715522918850183, 0.15430963837674685, 0.08916203238602195, 0.10591745722506728, 0.10417426005005836, 0.17296225391328335, 0.08759699815085956, 0.17355465569666453, 0.12369062352393355, 0.10429520213178226], [0.06434271418090377, 0.053383403324655125, 0.12435429862567357, 0.03729036437081439, 0.0574974561376231, 0.011047774011136165, 0.0757685246478234, 0.05130901320704392, 0.06173476483672857, 0.04216277506202459, 0.02398123076584722, 0.021123127612684454, 0.033639672944056134, 0.05551171662019832, 0.019712108952392424, 0.0179271513396608, 0.008262604890790368, 0.11856256797909737, 0.07733210681804589, 0.030096373254699365, 0.0458461243792304, 0.030325687556926693, 0.03737443146694984, 0.010814727766306272, 0.05278707282351596, 0.033718566210674386, 0.02948386308604053, 0.03543947690299579, 0.024640128981055956, 0.034358533298862834, 0.0244957994935768, 0.008714696658509118, 0.05237011983990669, 0.012076701120739537, 0.06692101833011423, 0.016785137887511934, 0.05557453878489988, 0.016249510825478604, 0.024057401410703148, 0.022898056477840458, 0.05034991413620966, 0.06900112171258245, 0.04587959651170032, 0.041123625822365284, 0.060279503996883116, 0.02548460482752749, 0.04590099072083831, 0.01496785317015435, 0.025948012014850974, 0.03757327615416475, 0.07565809985888855, 0.05377365256260548, 0.053934377152472734, 0.015413177399230855, 0.03477046173065901, 0.048792374320328236, 0.05234749408970986, 0.05191660738949265, 0.010709073078552527, 0.017317421468240873, 0.03458580521068402, 0.03259183506348303, 0.00954835580861462, 0.05610467819496989, 0.04200199279668076, 0.008972460237730826, 0.023860130924731493, 0.054819563403725624, 0.0236582345262702, 0.04573706005300794, 0.01730214594863355, 0.014944772801495023, 0.07408533710986376, 0.02119011428606297, 0.06902805955282279, 0.07394295332155057, 0.030629097883190428, 0.021969557640009692, 0.07265341108930962, 0.055306351211454184, 0.05345489038154483, 0.03073874914220401, 0.06342932462160077, 0.06377472608749356, 0.039957302156835794, 0.07666687108576298, 0.046079530247620175, 0.01803786789865366, 0.06673449583883796, 0.06553156860172749, 0.010316571952509028, 0.06206734199076891, 0.042013168268437893, 0.009691713294679565, 0.035904175003192255, 0.06768345420381852, 0.06233590615114995, 0.023808104252176623, 0.01729722656974835, 0.013711554064814533, 0.015077214355447462, 0.035606817209294865, 0.044726165011525154, 0.036370946027870686, 0.008668863314336963, 0.017586194278140153, 0.03021991073286959, 0.03373560422499265, 0.042279679860387526, 0.03719289620806064, 0.03554252601627793, 0.04978523729369044, 0.020851552453158156, 0.06234062196952956, 0.02242175373248756, 0.060417246605668745, 0.04715655191934534, 0.012342039695275682, 0.08224435430020094, 0.004607243022681879, 0.032674005654241355, 0.05411149514839053, 0.037738170341721604, 0.02241989115386137, 0.0532376234685736, 0.01735951778079782, 0.02586703055671283, 0.020287425224004046, 0.04312106328351157, 0.023314285125317316, 0.03748994866119964, 0.02601919712365738, 0.019096024600522857, 0.04806710520227041, 0.06415877012269837, 0.02542670882706131, 0.03763624759657042, 0.05873509044093745, 0.03602533421612211, 0.011423477154624249, 0.06648912400539432, 0.04668856970965862, 0.03318162448704243, 0.030428485612251928, 0.02768747046190713, 0.02673938062175044, 0.04774621920660138, 0.004127403837628663, 0.04567581208954964, 0.04806816710957459, 0.04271690747035401, 0.03546204497771604, 0.01998541098354118, 0.023184355847271423, 0.03513515055445688, 0.009449120062137288, 0.0068362912030092305, 0.03653803188353777, 0.04471106421468513, 0.04773030077506389, 0.03080869253192629, 0.003393867194452988, 0.02886834361457399, 0.025347130240074227, 0.05322701457355704, 0.006844027350390596, 0.07445857886757169, 0.024741997443405644, 0.023738060778539096, 0.05749603121408394, 0.07533162273466587, 0.018058685353025794, 0.06052476047937359, 0.04894453579826014, 0.024995794985443354, 0.04322279603885753, 0.07779876927712134, 0.04037459101527929, 0.06003461392330272, 0.031295107145394595, 0.016003594467682496, 0.04824782282646213, 0.05964916532060929, 0.08224237976329667, 0.06200227726783071, 0.019531259013872062, 0.05168949493340083, 0.037062057693089755, 0.04087674424850515, 0.018037869594991207, 0.002925201360734978, 0.007199334579386881, 0.058016114735177586, 0.05949420827840056, 0.03400009378258671, 0.007998754852451384, 0.04728365509903856, 0.03222563989194376, 0.015255246677302887, 0.025697644467332532, 0.019743143447807858, 0.06646002842379467, 0.028536801226437092, 0.06669575148927313, 0.019301417150667736, 0.1162226806793894, 0.017056455203731145, 0.022452204687786952, 0.045269322115927935, 0.02203326529291059, 0.06522305908479861, 0.0103312325497557, 0.053114700064595254, 0.02072746875429792, 0.039366888481059244, 0.029423843270965984, 0.05389287116538201, 0.030599730887583325, 0.026144349515171986, 0.06334685547543423, 0.062226573803595135, 0.008616004588215478, 0.023020094393619468, 0.06796881210591112, 0.021161771878334026, 0.004652206569777003, 0.030749497136899402, 0.021957613727343932, 0.02593641245870718, 0.02632025462974395, 0.032499320206365416, 0.015558926721236535, 0.036824533117136786, 0.05221764284319111, 0.013272257771209946, 0.02293690260765808, 0.0185341043065169, 0.03153285563790372, 0.053855453351778645, 0.05760161804833582, 0.025222500320523977, 0.007636663969606161, 0.02873137453570962, 0.02749807437482689, 0.019363101072875515, 0.030668055971286128, 0.039945722956742556, 0.03624184116987245, 0.04313311067276767, 0.034666924072163444, 0.07240720465779305, 0.05030167708173394, 0.051715811914099116, 0.05433666699432901, 0.024684897025248835, 0.06212200477187123, 0.03168316471523472, 0.019994946096890738, 0.03134951547586492, 0.04529547964089683, 0.03892982032682214, 0.07334144559821912, 0.047265161627105305, 0.08246014200683151, 0.050504419952631, 0.02520091612158077, 0.04263517792735781, 0.03293197449030621, 0.014641364171568836, 0.020396175727780377, 0.013049672840030065, 0.03522560266511781, 0.024763249160189713, 0.06583399844488927, 0.042043661632175953, 0.018473346584609578, 0.05534605908074549, 0.025109685391985943, 0.04296126489394477, 0.014932523548070873, 0.024279331555590034, 0.032960157442305765, 0.016552120480420332, 0.030149085247623067, 0.051427614342953475, 0.029122665324913602, 0.03171566654262798, 0.0644620345639331, 0.027036188802282726, 0.019195463907505785, 0.06357983725943736, 0.058439371309110096, 0.07107962375240666, 0.10084388125687838, 0.059886496514081955, 0.05937118309416941, 0.07761601265519857, 0.09348607821656124, 0.06551828967141253, 0.056659421284816096, 0.05949332618287631, 0.06764692866376468, 0.026639864979577915, 0.018222436209076216, 0.04734751542231866, 0.02366070100106299, 0.008263095132341343, 0.009482262256954397, 0.028852832304047685, 0.041486852403197966, 0.011934704945555754, 0.03889213449188641, 0.050904775969684124, 0.025523437386644737, 0.038831592204847505, 0.02815414309900786, 0.025017255351745656, 0.013684760413265653, 0.0790995480492711, 0.058017139323055744, 0.05399088215615068, 0.00911663196581815, 0.024557118703212057, 0.010647993052511342, 0.04969838820397854, 0.016060862823256424, 0.08397951083523886, 0.053454805564667494, 0.013771858016428138, 0.03432995340387736, 0.021113629818760922, 0.05103388082768236, 0.03432347000177417, 0.011330388935415872, 0.04473305553463953, 0.08641154319047928, 0.06743866591049091, 0.030460397114178965, 0.040512713603675365, 0.02578469711755003, 0.03463560289570263, 0.019047731566908102, 0.04364567941852978, 0.017188540526798794, 0.02052234422548541, 0.026507330127060413, 0.04078998336834567, 0.028893975274903432, 0.0418908182265503, 0.036406636969851594, 0.009500196785666049, 0.020906313621838177, 0.17324859569115297, 0.15092214729104722, 0.17449815864009516, 0.11396547965705395, 0.1317546729530607, 0.09384403936564922, 0.11166435027761118, 0.19360239351434366, 0.2139589326190097, 0.07587606566292898, 0.17975117319396564, 0.1463502190474953, 0.14015724350299152, 0.12665434234908649, 0.09057264562164034, 0.12188320979475975, 0.09762244126094238, 0.26313088621412006, 0.2025821530925376, 0.0975165558712823, 0.1102840064891747, 0.09156937285193376, 0.1496664368148361, 0.07469373196363449, 0.10450041826282229, 0.12472533514457089, 0.1687625835516623, 0.21914193592965603, 0.07892152760177851, 0.1976007425359317, 0.14584447975669587, 0.07255282505814518, 0.1589481716177293, 0.08114348551524536, 0.16669390669890813, 0.10138137598655053, 0.19811353859092506, 0.12606204913130828, 0.1125447019668562, 0.14506287526871475, 0.1614419642303671, 0.08599055970885924, 0.0973410460033587, 0.12634636887482234, 0.19436708890966006, 0.1252026573887893, 0.08434552619499819, 0.14217541020895752, 0.15582244577152388, 0.08887848617242915, 0.1456102223268577, 0.1128375373248543, 0.09672171316508736, 0.10748712585440703, 0.1384297204869134, 0.128688210355384, 0.15842203556426934, 0.11274744823042836, 0.1105915524863771, 0.13091928777950151, 0.14119788551969187, 0.14638395580862248, 0.19716421381703444, 0.20902843933020318, 0.10957695942904268, 0.12168188845472676, 0.15831028084669793, 0.10406707187316247, 0.07556191751999514, 0.06081858649849892, 0.10895985897098269, 0.12685076466628484, 0.13256050114120754, 0.0687496294932706, 0.15128270722925663, 0.16594576755804674, 0.10727464261331729, 0.12737486511468887, 0.12057778984308243, 0.16816684337598936, 0.12681244100843156, 0.10939537667270217, 0.14648604818752833, 0.14415310908641132, 0.11649967224470206, 0.19339826303933347, 0.2086033099996192, 0.15411493953849587, 0.17397860437631607, 0.11567967624536582, 0.09898816940507718, 0.12394446347440992, 0.12797796060996397, 0.09570378850081138, 0.07663656771183014, 0.110224817879498, 0.11692735286695616, 0.16284887945013388, 0.17315278654651983, 0.0804372662678361, 0.1216225302112954, 0.11622791896973338, 0.09776116096015487, 0.07303714978375606, 0.097135768804167, 0.10183607587324721, 0.12059471250644752, 0.12210618997258799, 0.1480901049716132, 0.15604344462709768, 0.18258431474012987, 0.14886442199349403, 0.16257327209625924, 0.09839644615671464, 0.16715396701225213, 0.14064869284629822, 0.19723444219146455, 0.17799093121928827, 0.1422020766351904, 0.15125473801578793, 0.13033981887357576, 0.16870032117835113, 0.09047454981399433, 0.0913564417777317, 0.15176096585180077, 0.17406593183321611, 0.08548199092703206, 0.10492561544690814, 0.08771109381424529, 0.14584350266626903, 0.10068055109253951, 0.11704725000475134, 0.20653520311628068, 0.18111749844891684, 0.18296512216329575, 0.15637946873903275, 0.08672155905514956, 0.08744264500481741, 0.09494074873094048, 0.16473737811403616, 0.0713163171229618, 0.10068020503968, 0.13075132322098526, 0.08964644532118525, 0.14046196000916616, 0.10962938304458346, 0.07543890590646438, 0.09473927811320339, 0.10859451536089182, 0.14804082975855895, 0.13236791933221476, 0.17644754903657095, 0.09933148098311254, 0.13025079507912907, 0.09098535097603287, 0.1344311543341194, 0.05635431122833064, 0.1031033553715263, 0.1341233979910612, 0.17664390350026743, 0.1456067617982626, 0.0987590349146298, 0.125312349359904, 0.16034695798797266, 0.12589951285294124, 0.11131122708320618, 0.15154319682291575, 0.07683049302015986, 0.07180307100393943, 0.17045550128178938, 0.14394190827650682, 0.12661344025816235, 0.17162647630487168, 0.06694692479712622, 0.10898343127753053, 0.08364476915448904], [0.01604589942975768, 0.03587684700531619, 0.056180558766105344, 0.03586257741387401, 0.059131999500095844, 0.01128088217228651, 0.020790716699723686, 0.06718013728303568, 0.028967748994805982, 0.04793841764330864, 0.03432430120717202, 0.03952304653025099, 0.026738301751070788, 0.05161987045513732, 0.052250660357198546, 0.06162151734211615, 0.05696087743022612, 0.06486950162798166, 0.11964593056057181, 0.023678224167919586, 0.04112600069493055, 0.05596844193392566, 0.019515369420072863, 0.004417406311923904, 0.04037968681326934, 0.030363872115101134, 0.026417169786457504, 0.04966484143265656, 0.0723377973107355, 0.04133968155032822, 0.02457568681399737, 0.040451370645314455, 0.0333300879491227, 0.07011344416865281, 0.02304680153195347, 0.05991060486329453, 0.053922333155891726, 0.008418080164119601, 0.007362190617381462, 0.02729165554046631, 0.052130739470677714, 0.01287718754195209, 0.055765705848378797, 0.03237559273838997, 0.04502177218507443, 0.03350628653009023, 0.0174795896413603, 0.043827720186007876, 0.03427596237244351, 0.07060048981968846, 0.028940024053944007, 0.04679446527734399, 0.012719332307044948, 0.04508978174999356, 0.06020658862377916, 0.03824190116886582, 0.05839825887233019, 0.0393249923363328, 0.04142857642312135, 0.018365993862971663, 0.03534597138475094, 0.019657939805516174, 0.039779654903603454, 0.07409909780004195, 0.02125961662802313, 0.030828146130910943, 0.045093208351837735, 0.04123073596773403, 0.05738399151180472, 0.026992911838793328, 0.03240395210949438, 0.01999449996011598, 0.01642778402726565, 0.04021123370953968, 0.0144347468657153, 0.05216361449233123, 0.04942505733509149, 0.023142337566241622, 0.03079766294519816, 0.024882656056433916, 0.04990018451852458, 0.025166609391037906, 0.02757066235478435, 0.004719079588539898, 0.021905361441895366, 0.024463041519214, 0.024179851536505988, 0.042718033838484964, 0.05440587078088096, 0.016434321712170328, 0.03368420180465494, 0.024237949401140213, 0.037634083069860935, 0.03661366139671632, 0.03608212759718299, 0.020150668187333003, 0.06317615642079286, 0.021638395231483237, 0.005201144368454281, 0.02428842562117747, 0.029326032448027815, 0.03894940284746034, 0.042400289459952285, 0.018645453599414656, 0.04922426525237305, 0.04938600425209318, 0.06045179082346814, 0.06729320835854326, 0.027450213907286525, 0.07259241079113313, 0.010214755228454513, 0.022962442665760006, 0.012981239190724279, 0.04861338356775897, 0.03724371848095741, 0.03491629247686692, 0.04370216067348208, 0.01974865824117192, 0.02892129309475422, 0.01648467579590423, 0.0622683579900435, 0.04387579778475421, 0.015006543236917682, 0.05178049326475177, 0.027303719893097878, 0.01224405160506389, 0.06166011919932706, 0.06953084721629109, 0.025740597430350523, 0.027201222089518393, 0.05602000041731766, 0.03172910153599722, 0.052203271471496136, 0.017155355075374246, 0.040594032632985284, 0.029172289983502457, 0.07857484370470047, 0.032922726058002026, 0.0738825908462916, 0.05718280587877546, 0.02438784626844738, 0.03240207256749272, 0.05293551253687058, 0.018016763763236146, 0.021028510993346572, 0.05190451928813543, 0.08096971269696951, 0.04747623012268117, 0.042474952060729265, 0.007931604482499617, 0.03820368946929063, 0.04938339528494647, 0.02543674096731203, 0.04277777884687696, 0.06943666655570269, 0.025713216846010516, 0.04325394418888858, 0.04300828737073711, 0.09245541066463504, 0.028560074977576733, 0.06642985397151538, 0.05018263829073735, 0.032255614176392555, 0.012348311903354312, 0.024035394823710834, 0.028011313173919916, 0.02833876060321927, 0.017120693810284138, 0.0483675740792283, 0.012711166986264288, 0.03024244148816381, 0.01623827767824488, 0.010770210780070295, 0.023008944366925528, 0.007600487875086921, 0.06934776489755937, 0.03227429085278085, 0.004167759283778391, 0.009451135311142674, 0.014777988893911242, 0.0528449348972312, 0.007084539600847555, 0.018314564301233207, 0.03682914715526359, 0.032590196401412995, 0.05036087926211102, 0.04819983004459313, 0.02552912011742592, 0.018830802225108658, 0.060481829568743706, 0.05808032450399228, 0.13358599825629167, 0.057059814621295245, 0.04632257470594985, 0.05624627148998635, 0.054991110627140315, 0.014041886116111917, 0.04763011847223554, 0.038992930868906636, 0.016135997005871365, 0.026354586805350015, 0.03438286556463156, 0.08050537761300802, 0.027886045431452136, 0.08403540855007512, 0.016880288853177, 0.0300735134099211, 0.05221394482733948, 0.04767639456050737, 0.0810309097703014, 0.02585013673108603, 0.06290546844580344, 0.017421708907932043, 0.03247413977182337, 0.020274073351174593, 0.04135723525126066, 0.08293377980589867, 0.05464211631832378, 0.028790868486144712, 0.012061901423814041, 0.012981223075517585, 0.012348953118946935, 0.002296954268656139, 0.06226755053337131, 0.041325483205063004, 0.017733085235314708, 0.010441641223483851, 0.012038997474259563, 0.031146762426942587, 0.06071937110807214, 0.0500182496117694, 0.06171000509389809, 0.04674653695630176, 0.03483423384438668, 0.04480584537876504, 0.020667267431105887, 0.017099784753684486, 0.04953828786632844, 0.027150043585736836, 0.07021248313997473, 0.026213273406028748, 0.03490050296698298, 0.0646433662623167, 0.014873909996822476, 0.04368002007582358, 0.040772463594164164, 0.04172742699405976, 0.06141557517860617, 0.011831079925676542, 0.02339336838174079, 0.014155243024496096, 0.03827702892678125, 0.02546730896990214, 0.05502403653892023, 0.05797791321362768, 0.004227944067679346, 0.03200484120420047, 0.05416232420663748, 0.05718149630618947, 0.04142671384449516, 0.00858933646564505, 0.009742820552284164, 0.03482680727860757, 0.033598624968103, 0.03673960767420275, 0.033076987601816654, 0.07806962688586541, 0.04457536738898073, 0.008044716270108308, 0.04311081401205488, 0.017645459223006452, 0.06129628872232778, 0.016766281399343694, 0.022559542142386948, 0.052623298218739886, 0.026321386086887548, 0.0411033376253077, 0.06256133584039551, 0.056425540441913266, 0.019263843274010078, 0.04207044340936201, 0.02346542031903352, 0.04434345429763198, 0.017340369522571564, 0.03627465512337429, 0.023956024886241982, 0.05395416323361652, 0.07789386595998492, 0.027064122392662933, 0.05313889662336026, 0.03578394199056285, 0.06500353265021529, 0.019751292653381824, 0.03149237084601607, 0.013820950025027352, 0.032054174092731307, 0.021342419952686344, 0.023377782432362437, 0.04216285648622683, 0.013536608229125184, 0.06436566902058465, 0.027781951374241283, 0.042967463311340125, 0.018871778954884837, 0.020360415235960057, 0.008426230217862343, 0.05563211587390729, 0.025786675047129393, 0.07402108662894794, 0.05141404364258051, 0.048348741339785714, 0.012245395104400814, 0.02150653043229665, 0.022511595161631703, 0.03707479040271469, 0.03816004948956626, 0.08692093978502921, 0.01054009750285851, 0.057817996080432615, 0.02717894408851862, 0.01874953069325004, 0.020748169161379337, 0.01889365153121097, 0.07155714277178049, 0.015585949378354209, 0.025318265360380923, 0.025839156338146756, 0.03858941966401679, 0.03592065322612013, 0.020312171396134154, 0.06306461883442742, 0.06082341766783169, 0.02175020762453122, 0.05397942169968571, 0.02471012495724218, 0.027207123647843088, 0.06329917481967381, 0.07631935937596218, 0.021296157435114895, 0.010685683976459717, 0.005498762974249465, 0.06762295602155582, 0.03595703627382006, 0.03221362642943859, 0.0133567981455209, 0.002307732161300789, 0.025667590455019047, 0.024101285663034235, 0.04094302015645163, 0.049325336436075826, 0.0029858556060519603, 0.05341566087944167, 0.149365560816867, 0.1158805497522865, 0.13743302039802074, 0.09768755348133189, 0.12995727440076216, 0.12380353175103664, 0.12768152223101684, 0.09817717078008822, 0.10084147924291235, 0.08540966587939433, 0.10148340051195451, 0.08340523272220578, 0.08618778269737959, 0.1246351171284914, 0.16301506624690124, 0.2746073289641312, 0.16027392047856534, 0.11027136538177729, 0.22076607735029288, 0.12078797285045896, 0.09457900135644845, 0.13476141089839594, 0.08916270413569041, 0.0717687914147973, 0.0699676066370947, 0.1426067684910127, 0.14504960312375, 0.1205226249460663, 0.19968300365975925, 0.1298002613974469, 0.11260009756577866, 0.15561140781002386, 0.11315173975058965, 0.2271485948669059, 0.11316824172224317, 0.13860358830009187, 0.11088385180171047, 0.13650907283382757, 0.1324888342725379, 0.11003161860363823, 0.15398182453853743, 0.11940874185945306, 0.13551446263279232, 0.15307839587330818, 0.12109970540872642, 0.09073648468724319, 0.0974964712347303, 0.11245455858962876, 0.17415479277925833, 0.11641786806285381, 0.18125549890100956, 0.1960942590875285, 0.11100585239806346, 0.15478986475084508, 0.1105855745928628, 0.16658726813537733, 0.1751534877611058, 0.10733446226056133, 0.10059745769415583, 0.11690401126231466, 0.06588967902851955, 0.13702085108629294, 0.11820100380906037, 0.21424026680844171, 0.12259820928531033, 0.17099790860499653, 0.22672666822160992, 0.11959118635526725, 0.13315938971936703, 0.11405100221080439, 0.1148187103016036, 0.19724111897604807, 0.11591299729687826, 0.19747081665056093, 0.09538353354270969, 0.1941749413630792, 0.12296061483877045, 0.17127829284540244, 0.1909337288566998, 0.15659765845962934, 0.1529118019555296, 0.12910092249512672, 0.1404432595840522, 0.17210408353379794, 0.09730345516332559, 0.1085099834682686, 0.12023651387010302, 0.1313773939119918, 0.13009410777262279, 0.1424313671886921, 0.19258653159652436, 0.1424961265708719, 0.14915218869490282, 0.1855666118540934, 0.08964813487338168, 0.09941639964069639, 0.14907404860215528, 0.08768692439688103, 0.09071585043732609, 0.1335859846855913, 0.11012226409677948, 0.1425071731209755, 0.09342171917004244, 0.08996885802064623, 0.10269765928387642, 0.10795768988983971, 0.1568268947303295, 0.12035977654159069, 0.07624033040234021, 0.16696715275091784, 0.08509113440024, 0.13141742747809204, 0.08678752622966256, 0.17048064778958047, 0.10727303448532309, 0.17902391936097825, 0.0899791649675795, 0.0935255621692964, 0.10935486813208886, 0.09671515173145703, 0.12425873375364713, 0.1062719782016107, 0.14468760469130107, 0.1875874519880329, 0.14976730783070835, 0.09660313238522836, 0.0910779099379267, 0.12244772378887449, 0.11008100238229547, 0.11521321056144578, 0.09204718364136559, 0.09383975102433137, 0.1431298918489899, 0.10423055131520544, 0.09219474465187107, 0.055716892039137225, 0.16068142146936484, 0.13301613740622997, 0.1595897671899625, 0.0850494180672935, 0.1713049185595342, 0.2392928653529712, 0.10679761892450707, 0.10149693728557654, 0.07628588045814208, 0.20163033130977834, 0.11489604972302914, 0.13504023450825894, 0.17992968218667166, 0.11650448984333447, 0.1266420337238482, 0.12972403477345193, 0.11270286169435297, 0.11551164383334772, 0.1573582012206316, 0.14172267807381494, 0.20519164949655533, 0.09851049432264906, 0.1256611706422908, 0.10462532977440528, 0.18029234558343887, 0.1563505224351372, 0.13094493640320642, 0.10159072439585413, 0.10479770481054272, 0.1385525217545884, 0.139846162338342, 0.18882005156150886, 0.18195979110896587, 0.08535708620079926, 0.1183166533176388, 0.06438789104244538, 0.08826697684292283, 0.14155183652681963, 0.18467090491737637, 0.19072115740605763], [0.032870024243103604, 0.01065254771882402, 0.018774383734645586, 0.020250782636659484, 0.0282523457759193, 0.04531583229878119, 0.005035392258183232, 0.028380856915776218, 0.010078896402514406, 0.05519365333020687, 0.028953832241573503, 0.016970839351415634, 0.07019390485116414, 0.042492275059755356, 0.010412793307166015, 0.02538976938064609, 0.03681295730971864, 0.04868862631597689, 0.039346444220947366, 0.04498269535335047, 0.03586714056187442, 0.027703494066372514, 0.030422029351549487, 0.03602890331032021, 0.041822170838713646, 0.024115075190950717, 0.07365551910230092, 0.05820115123476301, 0.020764884871563742, 0.028041837071733813, 0.033172752641673596, 0.03705959800364716, 0.06491741298564843, 0.03214952861890197, 0.01833241825391139, 0.006771116218130503, 0.03651253593021205, 0.07263473102024623, 0.0604371480377657, 0.029157755763403008, 0.014035287363055562, 0.04153238210294928, 0.006970887529730264, 0.04377817016627107, 0.006586790483977113, 0.030592772510967085, 0.050067290730242214, 0.023251647861408334, 0.0199118035047182, 0.027648179891652296, 0.021423498102064644, 0.027732850883954337, 0.030795294857983078, 0.05157019490642207, 0.022526563644143086, 0.024260227402139987, 0.02745748441001134, 0.0382871424912342, 0.023740895358579497, 0.05541336636192032, 0.04118083310978753, 0.04633192831118192, 0.025521435708339726, 0.04190611579854574, 0.031334733590483665, 0.05123341083526611, 0.06512640177139215, 0.012856579585266965, 0.04143569764814206, 0.00420768979737269, 0.023044197653819407, 0.028124818511839424, 0.026472178620419333, 0.01264687324874103, 0.01897979833717857, 0.03387678700632282, 0.03708827289353524, 0.022620069162387933, 0.026502921345776746, 0.01182590694432812, 0.012652024177701345, 0.008578505350409873, 0.04565913030611617, 0.06128167986337628, 0.050910984565104754, 0.06114505683737142, 0.06098488186086927, 0.05292819453669446, 0.02668767116431679, 0.013198630784505179, 0.022727503308228085, 0.0606268189315285, 0.025690238257603984, 0.08463165762701205, 0.03560396057686635, 0.08381440969450132, 0.006344060696262334, 0.02901807932981423, 0.03623389552480408, 0.015215844148769975, 0.022312650390501534, 0.037311392171042304, 0.07530632016382047, 0.02418575479116823, 0.03739887908367174, 0.06494717353156634, 0.029269062647862092, 0.0049944774447275055, 0.058649235405027866, 0.061536429050777636, 0.018610783852636814, 0.0038060339616744644, 0.00986158538476697, 0.011431044516419726, 0.023315224896318147, 0.022003128160057322, 0.06882532007460083, 0.020720948032768707, 0.029889949331326143, 0.03989123998742018, 0.04164376023358532, 0.05286725530666964, 0.03252888397712793, 0.035402618880782805, 0.01982528350449034, 0.010138361515211207, 0.012967365694099238, 0.03470508148893714, 0.09107312626604523, 0.007313252127330218, 0.07326406546469245, 0.039069327126656256, 0.03750570085165756, 0.0351171184863363, 0.03239806242553251, 0.04365482946325626, 0.028321770086352314, 0.042204664421400855, 0.005296586256008595, 0.047640337209616385, 0.03451600092064057, 0.02813310512075467, 0.0450859989172646, 0.019150728093726293, 0.035776305078927956, 0.03144048327314002, 0.04178851889446378, 0.03228442816595946, 0.08084541865225349, 0.026181105757132173, 0.017347928402679305, 0.01866003531696541, 0.06416418483214718, 0.04229976449693952, 0.05374071986547538, 0.05332596194265144, 0.02920209463419659, 0.024030068323814442, 0.05595769054655518, 0.03197035126920257, 0.0677958196029067, 0.03689428651705384, 0.039485306412513764, 0.04537110576140029, 0.03286107775888272, 0.06600245833396912, 0.04626086873135396, 0.03628101638917412, 0.019711796826283847, 0.0836899188746299, 0.014203768456354737, 0.05584328614973596, 0.05040301289409399, 0.030663221409278255, 0.03760765752355967, 0.05740214910890375, 0.024363400348063027, 0.04819007949637515, 0.02465059538371861, 0.04226665538070457, 0.04468809919697898, 0.04661763905148421, 0.050593538741980276, 0.03245431637125356, 0.030090354649083953, 0.031909429002553225, 0.014680071201707636, 0.025238532406677092, 0.004147171259059438, 0.0667287011497787, 0.01812863552809826, 0.02467563162956919, 0.0009168564491639179, 0.03575386253318616, 0.04184383646185909, 0.021674142152603184, 0.06174708703266723, 0.05232061053227101, 0.05681433422224862, 0.07028465212455817, 0.06200235190668276, 0.036278309034449716, 0.08707891630807094, 0.03635413871545877, 0.03222823528839009, 0.04229295200535229, 0.024165775327544128, 0.030055447415049587, 0.03465372656605073, 0.05582119644220386, 0.024692075925746133, 0.04414924739726952, 0.05636287773294108, 0.03347864979878068, 0.022820659380938326, 0.02521852240897715, 0.036290614267012904, 0.054854904900171926, 0.04607282292896083, 0.028327245863952806, 0.026080935328666652, 0.04484114616311022, 0.05128815504057067, 0.030856237480682985, 0.029373719889138426, 0.012917015003040433, 0.027389317085700374, 0.052925365045666695, 0.013983629643917084, 0.04578533781958478, 0.06523409206420183, 0.07305783831647464, 0.03510594979992934, 0.03672679354037557, 0.07739730046263762, 0.009019594672801239, 0.017924491482387696, 0.03252619019310389, 0.032740047467606406, 0.04676143419263618, 0.0224179929521467, 0.02917042401220117, 0.009707032070894326, 0.015475024169843112, 0.02294566249474883, 0.04846239934808441, 0.033604429835187535, 0.011418073471369488, 0.009055184682698121, 0.011217389954254031, 0.03018573292398027, 0.04581903047593577, 0.011645345383190682, 0.013289858121424913, 0.022000483569822142, 0.06566406613481895, 0.01438014515276466, 0.04174514354339667, 0.03060348318623645, 0.012046167044900358, 0.028490481033389057, 0.030896793518747603, 0.0763560002669692, 0.027602319406079392, 0.039748856199107, 0.016765377251431346, 0.03299509181774088, 0.06459415890276432, 0.0335018828378192, 0.029640099166759422, 0.04300107115081378, 0.05231909739917942, 0.056299930039261065, 0.0501777460532529, 0.027051203085907867, 0.008064355618054313, 0.048405745066702366, 0.07543013923402343, 0.05514977925590106, 0.05414281293217625, 0.004505311795842967, 0.050925359329474826, 0.09333531452076775, 0.042187599265681844, 0.04525169716881854, 0.0634142950709377, 0.012415295184057738, 0.017553521120654683, 0.016753263705010926, 0.02964394985299025, 0.03787151265091129, 0.041704797851187844, 0.012669551585401808, 0.06517132078962666, 0.023386725523908223, 0.013795306490335082, 0.031995053336556466, 0.03195055161735841, 0.0335559519007802, 0.07641807265047516, 0.03823249328083225, 0.0343962530605495, 0.025435889405863624, 0.011371447089394289, 0.08419704916221754, 0.02997844386845827, 0.058040908404759, 0.022702426350276386, 0.039491314840103896, 0.026184411919010536, 0.046789108243371756, 0.024554879537650516, 0.003053129808644631, 0.048799142707139254, 0.029356108512729406, 0.03869860951921769, 0.049563047609158924, 0.03787718859634229, 0.019653989035370092, 0.01983900517890496, 0.028775299500141824, 0.024296610449839915, 0.032143961239073954, 0.019830944182883416, 0.029801346228591034, 0.028682570904493332, 0.02909701670120869, 0.06624531280249357, 0.04175023255603654, 0.0628185345392142, 0.0469775000986244, 0.06332530520324196, 0.01126195358977254, 0.022297622536176016, 0.0103399177979944, 0.01340414971179728, 0.003394320540662323, 0.050661446526646614, 0.016889839233564477, 0.03440518258139491, 0.0184124633337238, 0.01333869228671704, 0.046608336336378536, 0.041962027084082365, 0.035938444414309094, 0.03397007539336171, 0.11400146915444306, 0.00653299325910796, 0.018480254071099416, 0.08501296716609172, 0.033293433487415314, 0.04875418297680361, 0.14284405218703405, 0.11769284893359457, 0.062110211833247116, 0.1265779257352863, 0.11768647070441927, 0.13822157308459282, 0.12605303818626062, 0.16859951801598072, 0.21078371442854404, 0.1094963698248778, 0.08420337310859136, 0.10380629729479551, 0.11887294346732752, 0.13702592652823242, 0.08587282709777355, 0.11435193249157496, 0.10436089110693761, 0.1820043165768896, 0.1553440107298749, 0.16070362313517503, 0.12547483135546955, 0.14077950082719326, 0.16272595604615553, 0.18885101989975997, 0.11564807008419718, 0.1764483768492937, 0.24725655945284025, 0.11815674975514412, 0.07380645921719925, 0.09151213842311076, 0.11842131055891514, 0.10084364376962185, 0.15985720498221262, 0.08255599864891597, 0.12301766606313841, 0.10503122942256075, 0.19657022426170961, 0.2420559956559113, 0.10764943143086773, 0.08371478039771318, 0.08735980266439063, 0.1662988228989499, 0.11292157388691391, 0.11563740351370402, 0.17141794892294065, 0.14916406305772917, 0.1789597435189145, 0.05952810110258205, 0.1137678495475224, 0.10318874900362321, 0.1769226592566286, 0.12864030578306743, 0.09742310802851405, 0.25670673378876274, 0.1330242119729519, 0.2021520568856171, 0.15272532696170465, 0.08589185321969645, 0.12609498522111348, 0.06745937479926006, 0.12297278775700501, 0.09902677804763828, 0.1502787061035633, 0.12286925688385963, 0.0997834260176335, 0.14963135655437196, 0.1432393259767975, 0.12181835541767733, 0.12032219927225794, 0.1862261343215193, 0.12094953203839914, 0.10587441096348421, 0.13305684950734886, 0.11735174937972001, 0.132580056520445, 0.08201175249580826, 0.09254615115267889, 0.1482204786900963, 0.12330756336450577, 0.1506401209958962, 0.07152972317167691, 0.10961651802062988, 0.0924707455560565, 0.1413067089659827, 0.09266552581850972, 0.1858308333903551, 0.16538330273968832, 0.26592379063367844, 0.1165756138839892, 0.11442600137421063, 0.1656498855778149, 0.11303491637642894, 0.15316108215068067, 0.15696478661681923, 0.2203874955219882, 0.2835342985178743, 0.18402099050581455, 0.09846903583300964, 0.17831125403089182, 0.08786030366484608, 0.12485589885285922, 0.14338222545172485, 0.18174403054373606, 0.13072874157556466, 0.1433505785784551, 0.24256101569959096, 0.20957983045705728, 0.12216807236628872, 0.13145518116652966, 0.1559079818959747, 0.14912124749805244, 0.11902242473193578, 0.08968957979232073, 0.11744746352945055, 0.0941008445141571, 0.11947647322501455, 0.10771305087421622, 0.2293850870004722, 0.10310836974531412, 0.08122737958495106, 0.0803506105606045, 0.12091514388365404, 0.0767090759639229, 0.20511649495788983, 0.14666851982474327, 0.08138681495828287, 0.109340537472495, 0.11283588169940881, 0.13884087199611322, 0.13919486371534212, 0.15098291688731738, 0.11855749253715787, 0.16636366370533193, 0.14514999916510923, 0.20876398709203514, 0.07321224574531827, 0.09435278456658125, 0.115463006443211, 0.08556677387761218, 0.11449309491685458, 0.11681658881051199, 0.10517828831715242, 0.09901892061212234, 0.11706162137644631, 0.15501144714653492, 0.08391565390463386, 0.11399857859526362, 0.07363370420145136, 0.16300701882158006, 0.10963773581066302, 0.13244714508099215, 0.1586905318711485, 0.13949271344712802, 0.20276119134255818, 0.1957499568483659, 0.15116059806730064, 0.0940419544598886, 0.1469610905540841, 0.15333375574222632, 0.05184330864410315, 0.13753165224833147, 0.1382322260843856, 0.21342835894652776, 0.130840021318623, 0.1597149840423039, 0.21519343209053787, 0.25006637296506334, 0.13970246219209262, 0.09844152802335364, 0.16431767706360134, 0.2851747790617602, 0.16089680205498422, 0.10314491564141852, 0.11559902557304927, 0.1803571049656187, 0.1257183440029621], [0.011133005642997367, 0.05292343461353864, 0.07859657718134777, 0.043791147148502726, 0.03752676936398659, 0.011060877370515039, 0.011667787080763705, 0.03872338283274855, 0.053791056985833814, 0.042475101338433366, 0.010779145389928349, 0.03392999093713505, 0.06137974852962153, 0.02528143278323114, 0.036437106584864, 0.0546425098686346, 0.06679922807961702, 0.013701567725677575, 0.019120501054983054, 0.05010276114834206, 0.052227722480893135, 0.08588960048343454, 0.0327259916146951, 0.01698387909813651, 0.03166640490027411, 0.01733310580519693, 0.048046090972742865, 0.03550647205806204, 0.08317865630877869, 0.023395797537107552, 0.015485875641128846, 0.024773618871612207, 0.01822646501074944, 0.010541130572424402, 0.049904408399015665, 0.029340726123856645, 0.05219354127932872, 0.0318395093615566, 0.06735207805676119, 0.05298230431175657, 0.03971433912270835, 0.03810118318402341, 0.06607693433761597, 0.023704325713749443, 0.00362150848377496, 0.02552804463942136, 0.014616516219185931, 0.045615809237850566, 0.04515200001852853, 0.016675647780565277, 0.04712418579895582, 0.028009240249437944, 0.05203422125695007, 0.008671705527896327, 0.056472790227936845, 0.03636191472677248, 0.08799100308013813, 0.01732235441782645, 0.021262206935456822, 0.027564248502520577, 0.060667178194437704, 0.04960350186697074, 0.04282944589587195, 0.03609538617144738, 0.03147905459627509, 0.029434791433491876, 0.07289298144834382, 0.03139225300401449, 0.07947167700954846, 0.028233563926603113, 0.03256990481168032, 0.02702537634676056, 0.008470005056421672, 0.03258466973368611, 0.05040132673457265, 0.026918101656649793, 0.037081969303211997, 0.021655747068247626, 0.07833568046667747, 0.039465309985514195, 0.0893663799922381, 0.017538103108693446, 0.028150570612134676, 0.021343693902183856, 0.03914606265191521, 0.01335950125940144, 0.03537052417440074, 0.0713929780093687, 0.044465325972331424, 0.08662787372512476, 0.029737475727285658, 0.025557486273880516, 0.0028354670128984643, 0.011481376547765518, 0.039607581815549305, 0.023064991359465888, 0.03865226557744401, 0.021869472028421502, 0.008985542392890369, 0.01602411506298397, 0.06934869449053492, 0.07083758352590458, 0.042649569655103345, 0.00796701043977269, 0.040918704854058366, 0.03956771109785352, 0.0474912291392684, 0.0337418060350631, 0.02579416098472263, 0.004365387272887996, 0.02213045864898179, 0.0371718819785331, 0.03256186417170933, 0.030763098371348212, 0.023452526457341652, 0.0033589826489333063, 0.029008383064397743, 0.030137027680341686, 0.021883493954581872, 0.05644587952909725, 0.008634206290090722, 0.024698842616219605, 0.020120605693331788, 0.044927031733095646, 0.08184573533279554, 0.014009719315384115, 0.0282333196539964, 0.029598009639552662, 0.03578389110043645, 0.04357957314433796, 0.04383618151769042, 0.04261152758928282, 0.021385422109493187, 0.039150612229215245, 0.023036827067179338, 0.06689452832298619, 0.0253651402558067, 0.040468561330011914, 0.02954154195530074, 0.08257333521864244, 0.07916573914034025, 0.062244887463748455, 0.040290466243667264, 0.024342089259464825, 0.03635445084156735, 0.006986776275360691, 0.03005113193233098, 0.050077472148197036, 0.08109745369958025, 0.032097383202718835, 0.01714756040434752, 0.03934564354962536, 0.031861711027366776, 0.050413482689431736, 0.014937885671055742, 0.014825099580256003, 0.06977853963949851, 0.025223414646461606, 0.04624474334663578, 0.027958175400272012, 0.027452230852629458, 0.06198160909116268, 0.04990061878093651, 0.014281457323314888, 0.02432321071890848, 0.03232117762256946, 0.02510058623738587, 0.03234274825081229, 0.03399280631648643, 0.05634787532367876, 0.047539001397256336, 0.021278038853779435, 0.022896095511636565, 0.012819071865773626, 0.027960462063284855, 0.048714590458465476, 0.031879084916519265, 0.028346565452271273, 0.08097273217780249, 0.04408243205398321, 0.02853125420265964, 0.019781097304075956, 0.03202557723437037, 0.04923319477321846, 0.014977357749428068, 0.006899300813009697, 0.05194367075871144, 0.025721635769254396, 0.07801714898752314, 0.016328755233969008, 0.06537393813154527, 0.08590843661555222, 0.03322830430365034, 0.03910422757534044, 0.05786256904580763, 0.058890597096511295, 0.03565987864775317, 0.09941984659859113, 0.0958290799920048, 0.01114700806127595, 0.03278886127684798, 0.029795269947499037, 0.049059774793152294, 0.01691743016376027, 0.005289861549889403, 0.01991056857098426, 0.06709276232868433, 0.06253938523254224, 0.04105936855609928, 0.04427178742896233, 0.018315383632268225, 0.054908804329378266, 0.03079117275774479, 0.010914152654420053, 0.026541513024962375, 0.014482229049982769, 0.029358015196131806, 0.06102602822440011, 0.017492670100182295, 0.01220970501058868, 0.06256814833198275, 0.046401932769055874, 0.03204398928210139, 0.016454740527219007, 0.044881868442254405, 0.021047257219574282, 0.06448695036981787, 0.07150852573769433, 0.05724413865911109, 0.024573228820892315, 0.11421956388013703, 0.05980085182402815, 0.04559815036399024, 0.016541129909455776, 0.054273658232497315, 0.049553412411894114, 0.00831426854711026, 0.015901698863932064, 0.041314351838082075, 0.026713803244222487, 0.010392491539408053, 0.03471836381192718, 0.08214401932699339, 0.0302916963451675, 0.029117610239024674, 0.046589663052665334, 0.06045901722141674, 0.038516422866710594, 0.049586195831320116, 0.012172817302468632, 0.05490273483363645, 0.049872513860464096, 0.06476901737707001, 0.02761982730589807, 0.039497733781380315, 0.04629090069127934, 0.0591843349060842, 0.048416971428585906, 0.05582592583128384, 0.02707409516109952, 0.04495855986273714, 0.03815030572669847, 0.04827217205560633, 0.07159358010228191, 0.03905978353161897, 0.04232868365943432, 0.02859936554783157, 0.05730192270129919, 0.04185452678107789, 0.026883530297449658, 0.03683308944372194, 0.052068985998630524, 0.015165844599583318, 0.004831332181181226, 0.03637205543262618, 0.042915273790380785, 0.03074807899871043, 0.06979706364550761, 0.013457869329223675, 0.05871713640434401, 0.05333181091451219, 0.038301232270896435, 0.04449906612613371, 0.01829542113201959, 0.006386400009172836, 0.022898176917806268, 0.039428869262337685, 0.02554479258001915, 0.02924975493390645, 0.04392165657398956, 0.06024921419365065, 0.054392072771276744, 0.06682157223778111, 0.02656360442883202, 0.023544152433584844, 0.06149005118225302, 0.009482427649865193, 0.02347251440265349, 0.020743643332804953, 0.035212249095950804, 0.0065266400509114775, 0.02019423183186778, 0.03269825988848295, 0.039500010266367874, 0.04277036585179823, 0.05962578978921686, 0.04951927870778101, 0.029651929424809556, 0.016687963191153746, 0.011567088243152415, 0.05841740034520626, 0.021467054961249232, 0.016005292501566664, 0.027617074150059904, 0.016122270242444108, 0.03146928369200655, 0.014593091494004642, 0.036951836464660506, 0.007049823204787182, 0.06177449984742062, 0.14160382587994846, 0.06767770022686039, 0.021676055621355772, 0.04969316009165985, 0.014826617802360227, 0.007740003156608769, 0.03842928879229086, 0.06531369779258966, 0.027317195598568236, 0.046974521329892535, 0.07283814224813666, 0.028254111663305333, 0.060962944823716364, 0.00698357104556635, 0.035470977891236544, 0.01688703858027501, 0.026073323862094964, 0.01894399713325713, 0.015611587824033839, 0.04639071997787271, 0.10933156045419828, 0.017815722318898355, 0.022025828549106206, 0.05589376236977322, 0.017244478953736167, 0.01854179210827819, 0.023528652997421365, 0.03586440945842436, 0.07011400056736809, 0.031216179952025414, 0.031751669610717466, 0.07630652827875954, 0.09864888153970242, 0.1365681325218507, 0.14839354583195277, 0.10308107906686408, 0.1231876662267106, 0.1863921582698822, 0.0759988601452538, 0.10994347690471581, 0.15177877061069012, 0.10114329840455737, 0.19427640948976788, 0.11112293361553124, 0.2421766934650285, 0.08879172189959458, 0.11477665470114776, 0.18435383907386235, 0.10508121709738459, 0.19548059201666287, 0.24211863800883293, 0.1688579720045839, 0.10780718403735332, 0.23355748025434359, 0.1124158345961145, 0.0923814774890031, 0.051961400878748724, 0.1312772421432393, 0.18717083148658276, 0.13332967486764702, 0.10630353686532804, 0.10355324444494077, 0.09244721396160976, 0.12303187458642892, 0.15978886293513433, 0.11650249495037965, 0.10201672903661217, 0.12294589062886578, 0.13048391257013592, 0.057292721766446314, 0.17895707009094103, 0.14734720412109578, 0.14058054078902515, 0.11221153448734965, 0.10001174626605851, 0.15106747592134134, 0.1280001758464745, 0.20358426789087908, 0.10657799749502114, 0.11273335505809103, 0.14680645242333412, 0.12950911559164524, 0.17163115819650038, 0.2558696115655558, 0.12099089553313595, 0.09046692986573492, 0.30690858140587807, 0.2068792882242373, 0.1102670431137085, 0.1060548944930945, 0.13514892224754604, 0.13974709622561932, 0.18066241858260973, 0.08735702067081418, 0.12818465594734463, 0.18648215915475572, 0.0644804092922381, 0.07540284855557339, 0.20438635056572302, 0.08963539877108165, 0.22753339207598142, 0.11336564791521855, 0.14003676282508032, 0.11343895005328314, 0.1452426327658551, 0.06093910788851125, 0.3082544149032661, 0.09356851343597684, 0.13369486241468362, 0.2212076543697289, 0.18709692545235157, 0.1760960000434092, 0.1873367197279419, 0.1109702360949346, 0.12924649539802754, 0.11106161440589599, 0.10963254501777035, 0.14060469663568906, 0.09784173699361937, 0.14008986497563974, 0.10547456384769507, 0.20668548505221093, 0.10842954992715802, 0.10861740234707083, 0.10505539205457483, 0.12054995633661747, 0.10769863200506993, 0.10725908380533968, 0.14320397430232593, 0.21492988908929483, 0.1232114556644644, 0.1197911641959633, 0.1810088242803301, 0.20878293178975582, 0.12916680824543747, 0.13355037516781262, 0.10550578324390308, 0.07142623979598284, 0.12556678642119679, 0.08221909922680684, 0.11604901642671653, 0.06960696527468306, 0.13613410081182206, 0.11432423469211374, 0.1278706570821149, 0.17514985081340584, 0.12535977895770753, 0.09745261073112488, 0.11628198464001928, 0.0719726165490491, 0.08467805585158722, 0.18081479040639742, 0.09807336849293538, 0.1868678248886551, 0.08446256670036487, 0.17755172907241754, 0.12742936504738672, 0.07749598659574986, 0.12569300750536577, 0.09527042854045119, 0.16363884348954472, 0.15516666881740093, 0.18340192229620048, 0.1237524923469339, 0.07371012760060174, 0.13757910898753575, 0.09095283557793923, 0.15679242515138217, 0.15606101868408068, 0.1184968857892922, 0.10223877962146487, 0.10853464143084628, 0.17136714022074426, 0.11713081837764808, 0.11852094664105348, 0.15330411733261176, 0.2160893561584609, 0.137018014809915, 0.08647753750639302, 0.13536381428795202, 0.16161771837089742, 0.11293492067073073, 0.17160606597151074, 0.1277451959571668, 0.1392378828355244, 0.1640104092657566, 0.10851144910390888, 0.14471488179905073, 0.25014980563095635, 0.168410505301186, 0.09476209046053034, 0.05981921976698296, 0.1261441790099655, 0.13226426632276603, 0.10733061496700559, 0.1087287635143314, 0.15365269434239182, 0.12197473059807505, 0.22728502111775534, 0.1725509531263794, 0.129828827721732, 0.1919800569968564, 0.1278495682137353, 0.11092832298683268, 0.1520627646573952, 0.06736071580754859, 0.08135136828890868, 0.09290162886359862], [0.08432734145649842, 0.05927709064313343, 0.021659507848588482, 0.06657266523689032, 0.030372492902513062, 0.035869434010237455, 0.009969378305998231, 0.045463600262467346, 0.047708211067531786, 0.044653113931417465, 0.02593222420130457, 0.03215320288602795, 0.025246713842664446, 0.039145295907344134, 0.013790386263281107, 0.0371148002200893, 0.07226742644395147, 0.01588485253575657, 0.04157244620312538, 0.043324352375098636, 0.034698581123458486, 0.012968743968355869, 0.016958473050700765, 0.03247700658227716, 0.04913947551644274, 0.0932112376072577, 0.050722412898072174, 0.04095191575054612, 0.03144382505810686, 0.02193253337671714, 0.02256418501825205, 0.01878367966440107, 0.028749376069754362, 0.015102555942056435, 0.03296550769092781, 0.0184092759154737, 0.033812930075717826, 0.10836352168449334, 0.07276036177894898, 0.03691242715077741, 0.04762113466858864, 0.0319902187745486, 0.11419083470744745, 0.022284419941050664, 0.058673628738948276, 0.039197807732437334, 0.030531507584133318, 0.03033596396978412, 0.05644180831898536, 0.043727307181273184, 0.05813477693923882, 0.012408807541110685, 0.013465052470564842, 0.04237261540921671, 0.050095656886696815, 0.05728461327297347, 0.029195858897375207, 0.015285375328468425, 0.03755554264145238, 0.02577787953695016, 0.040824103501758406, 0.035120378847100904, 0.0562731041572988, 0.051420340447553566, 0.09155239590576716, 0.06117153327379908, 0.024898065586707423, 0.07167191697018487, 0.005721260119961309, 0.028378124115988612, 0.0169385241211525, 0.0410464526420193, 0.05419205082580447, 0.10915728552000863, 0.0466614215235625, 0.03636322429935847, 0.001502014447136649, 0.06214869833950486, 0.025439022541312233, 0.031249048188328743, 0.0023183289699123372, 0.06858520688755171, 0.062155219061034064, 0.044653388738100014, 0.03301632996382458, 0.0329106413493199, 0.04505767686558621, 0.021740150039217303, 0.027425075881183147, 0.015974271576851606, 0.037110362601067336, 0.040818977169692516, 0.026388367671253424, 0.06611251671399389, 0.012608607266364353, 0.030268907746566192, 0.008342477792341794, 0.053157057613134384, 0.03735783789306879, 0.037946219356464486, 0.016405787618298615, 0.03696030458169324, 0.01623149572073349, 0.020470677176490426, 0.053857919826571427, 0.04096450596781714, 0.06221056037715503, 0.009263695101253688, 0.032060084132743735, 0.04417332860508135, 0.04240489671272891, 0.026260952365451624, 0.050221613342208524, 0.0249647961131164, 0.018598217384091446, 0.018063463935894624, 0.013770137930155864, 0.06976275691496474, 0.045878253012363396, 0.047412261233798096, 0.04210136425016182, 0.026759750243010264, 0.05062911433300801, 0.059945705479809215, 0.017763695646343485, 0.03433974466419645, 0.0388692983958338, 0.016808874738801802, 0.04489020763763359, 0.018341500445136, 0.03538319920854909, 0.032768986986151764, 0.028257696024541343, 0.023922184648524438, 0.049209924414753914, 0.04994899493509105, 0.07332937446023736, 0.030969586755548204, 0.007115057137395654, 0.03588017521958266, 0.10036906959222895, 0.030135779175907373, 0.06643936703247683, 0.024898766174114177, 0.04159834249211209, 0.03793495906783002, 0.02201944692725582, 0.06476126172180686, 0.044152127778423686, 0.023682717766080583, 0.012205324218874531, 0.03400526421942881, 0.04926862447921719, 0.04221058803211365, 0.0516834865058107, 0.01490778076861586, 0.012514679360070398, 0.048392537382564375, 0.04961327277123928, 0.026735306018963456, 0.04335410613566637, 0.03217164546783481, 0.0204327368909227, 0.06971050293317863, 0.03788518173886197, 0.0552983139641583, 0.020841472815456133, 0.03428752121648618, 0.020320585230365396, 0.026667091197201183, 0.04620473352926118, 0.029375087137201, 0.03428931254893541, 0.054708589001425674, 0.03509735276124307, 0.041560914500483444, 0.03255059031237449, 0.035003494404788525, 0.015652345726266503, 0.008119154954329133, 0.0414614344813994, 0.0661712032077568, 0.04830101318657398, 0.0661908264404961, 0.08064651289688689, 0.06451662270618336, 0.062082520819136074, 0.009329202568291553, 0.04491190040217979, 0.02473503228143922, 0.017575244419276714, 0.06615162068711859, 0.027792399117190923, 0.04497831540980509, 0.03338799073493906, 0.02676635578141681, 0.04019966468747173, 0.018611594701984098, 0.024804076612261788, 0.03619684072743569, 0.06981615083558218, 0.020860308947573816, 0.024384662242872373, 0.04941030937646117, 0.06319447686629635, 0.04410766337865165, 0.011122026946395636, 0.04729347010808332, 0.034214724587010484, 0.047347400071365495, 0.02139076726910259, 0.030407776723482778, 0.04103177592956594, 0.01971966783250017, 0.05246093835947769, 0.021926923588450466, 0.08246440320674862, 0.06897999213210174, 0.04567862461720194, 0.06034641433507204, 0.04033521223547203, 0.016285323903762867, 0.022279710908021246, 0.024062191867934804, 0.012406407223482217, 0.08782442273305995, 0.03728141449391842, 0.02876604428248746, 0.02456563262135855, 0.07003002507346016, 0.020082227752677033, 0.06349163449236325, 0.019584035467622534, 0.005880179806678955, 0.07318331301212311, 0.056435972917824984, 0.044196646460997205, 0.03548663169411676, 0.05302179165716682, 0.05411856887595994, 0.08275356090494565, 0.005705532102313424, 0.05676066888762372, 0.020929599247340645, 0.048569920007139444, 0.07469880740557398, 0.022492933752281324, 0.020514848109866892, 0.027710616987730776, 0.03725537910525288, 0.04282139507787568, 0.02835969171220703, 0.08046817353793553, 0.08075678840811763, 0.038295732744570286, 0.015799335071018765, 0.031294401468975205, 0.03871556271665862, 0.025059109088033438, 0.042224474251270294, 0.0532731685255255, 0.016042869770899415, 0.024938513059169054, 0.021356304475505437, 0.033796743622847965, 0.033721965671117814, 0.014293708273076584, 0.05014877600063171, 0.0027792103106289035, 0.052399588615766594, 0.004616426994159285, 0.05236959736794233, 0.013019471246350025, 0.03467148722016385, 0.031061843769358735, 0.027316257523904954, 0.04934591979586652, 0.021861319430172443, 0.024073046731895635, 0.03623053338378668, 0.07456452532538346, 0.024212677364370654, 0.09473059286496469, 0.06508357264101505, 0.02023147831537894, 0.01032393066478627, 0.0655567626069699, 0.05474305858037301, 0.00532602661821459, 0.01804797807043152, 0.06511995568871498, 0.02231568344203489, 0.03979212298457112, 0.03521890213180866, 0.024121483954201852, 0.014341008949226566, 0.020279077546937124, 0.05222327807652099, 0.026453822551827346, 0.04716773417645267, 0.05576320205415998, 0.07474710552820138, 0.054293861612677574, 0.04765084432438016, 0.0188994597909706, 0.062218811362981796, 0.08891478779592685, 0.10124338910515819, 0.0365981602642153, 0.011517993690046881, 0.013360417281676615, 0.015588426031172276, 0.05086340908227222, 0.030272259709558318, 0.031715296741042814, 0.028151669838864888, 0.0397055283454912, 0.006184888255250241, 0.04547121003270149, 0.038870092281805615, 0.04608762517039265, 0.01620095655588167, 0.051529777968036275, 0.05980822749968086, 0.08479840082249471, 0.02692539760443781, 0.05634569383359381, 0.002314709621714428, 0.04205533243449671, 0.021001479854541164, 0.030484715809247324, 0.023604647223172442, 0.019439561791451912, 0.06490566075912543, 0.017284064686724117, 0.026173704636416266, 0.09553772384034735, 0.024087716658998812, 0.05485647910141519, 0.09793959531400885, 0.01832545648462006, 0.032019148115068674, 0.010245955964949514, 0.004476875241380185, 0.020981457982478396, 0.0326898969443781, 0.04860887809523514, 0.0073128339801249755, 0.027394538412668874, 0.009315776904778821, 0.033129272117678604, 0.022883162634181123, 0.2433677124125617, 0.16898487162377152, 0.053826154209673405, 0.11721545883587428, 0.084205252650593, 0.1225102711468935, 0.13060253406209604, 0.22920934643064225, 0.12984508542077883, 0.12432479592306273, 0.14543330110609531, 0.12201484558837754, 0.11015403989170279, 0.09878891759685107, 0.06351948156952858, 0.22194385129426206, 0.12938294879027776, 0.09503043748970542, 0.09888896758535079, 0.155256289722664, 0.1192817608160632, 0.10707618469106299, 0.18173097552997725, 0.05298031620415194, 0.16014210826584271, 0.14018770972532885, 0.10163478845996515, 0.23925459597791943, 0.2733257934451103, 0.17602221614548139, 0.13539517617651395, 0.1452205939484494, 0.10773528646677732, 0.057169330173305104, 0.07301439850458077, 0.0727103537480746, 0.09667315041380269, 0.19958703166672162, 0.09441778822136776, 0.1508247639451708, 0.10957310535013676, 0.1814856036965336, 0.20495220805917466, 0.1413021492106574, 0.23344473487564496, 0.1552823590380805, 0.179368737286755, 0.08318963500538043, 0.0823485501376646, 0.14237727437700542, 0.15756686430956635, 0.11099206456648451, 0.08042718323745898, 0.14598592716668332, 0.14266597745673998, 0.16170911703790936, 0.09738188024078097, 0.05059322322319661, 0.16699771396815777, 0.08029114375157015, 0.30608340139899937, 0.13573065746043408, 0.11308079891438995, 0.08898770995438099, 0.17951663077941962, 0.13462882515575203, 0.12367276448224272, 0.18314547677125248, 0.10812799539417028, 0.22882374855024473, 0.17951055110565253, 0.13321022556296416, 0.11533567256161145, 0.13861654831894807, 0.10123117547482252, 0.0777122899889946, 0.15248332066195353, 0.1527719423174858, 0.15034277338002408, 0.11908489066575255, 0.10019240621477365, 0.09296003037265368, 0.11007961138550725, 0.11786565823214394, 0.1616502066275903, 0.1447328629770449, 0.09805945852505309, 0.10965971355991704, 0.130035970892225, 0.08703800743179661, 0.08696876293314354, 0.10750422493687697, 0.15662304924002715, 0.10973231002156224, 0.0703489976003766, 0.07574504055082798, 0.10424980135368449, 0.1639254159693207, 0.13699493104858057, 0.12689537155841077, 0.13469939279769147, 0.11082368610160691, 0.11484301542597157, 0.12772167793342046, 0.17052416902567658, 0.11726712249219418, 0.12517717161348887, 0.1139349320105144, 0.06503172578024012, 0.1063189667516521, 0.18242183274456433, 0.18520073220133781, 0.10567960355963026, 0.08836945598678929, 0.10664847014205796, 0.1136704526309456, 0.1785092098372323, 0.1439598487423999, 0.09215192230684416, 0.14646862340824945, 0.11547161026724748, 0.14769401693982737, 0.1339197696319648, 0.19562608349536145, 0.11698839387723378, 0.1790269184857607, 0.17557548225990363, 0.16880287496106966, 0.1714229565113783, 0.15210070833563805, 0.18906927747385843, 0.1652577466198376, 0.14657869535897458, 0.0788033539429307, 0.2307281792163849, 0.09133875915514571, 0.15649840235710144, 0.08689681107976607, 0.09978621479656015, 0.17969028146139213, 0.10079932186220374, 0.1605618093162775, 0.21029803263289587, 0.062174747298870764, 0.16106270386704377, 0.06162074381219489, 0.1504509047205959, 0.27769341479454723, 0.3025849291256496, 0.1188482583633491, 0.10978793632239103, 0.09639117840145316, 0.10410668474755116, 0.05745880678296089, 0.09918544667639903, 0.1310215022947107, 0.0713383559403675, 0.1188819951244763, 0.13773561987493718, 0.1186604398701872, 0.17177540117076465, 0.14351829886436462, 0.1276406337107931, 0.1461288673537118, 0.10373699851334095, 0.11375898788017885, 0.10008838001106467, 0.14097875942076954, 0.11677766804184232, 0.1297429794711726, 0.15915425627359323, 0.10769633177135672, 0.0850900826709611, 0.20081014532063687, 0.0902656763792038, 0.11526507777827126], [0.08328223467937537, 0.020071006479806135, 0.028731764693345343, 0.03108243052182453, 0.03405795246362686, 0.09672601507710558, 0.04144229979387351, 0.04510982567444444, 0.01360509785757001, 0.03489423330341067, 0.06910947696971041, 0.02306949343931462, 0.027507195581815073, 0.02174392608659608, 0.02386874662313078, 0.023265659609543424, 0.033270183485001326, 0.002656139537326193, 0.0035361555637791753, 0.049067170824855566, 0.02706310628647251, 0.036949794074254375, 0.05402365879022649, 0.03242549220366137, 0.0522953622442271, 0.03724701955382313, 0.04372758198795574, 0.03698789720822658, 0.02131401138779308, 0.04515381509970341, 0.04621831101498433, 0.03734143430899296, 0.10252201370894909, 0.037695446384272406, 0.0038738984897333595, 0.057251270062157085, 0.03812357144696372, 0.03503817093691655, 0.08222386254263775, 0.031044870215867246, 0.07270711035068546, 0.029116368519940546, 0.050354402645358017, 0.01860304855342422, 0.016736264706456234, 0.03873479239908712, 0.03406779122139726, 0.020133452057572346, 0.016112747003457377, 0.052882281464657614, 0.036610306041049104, 0.026538856560364366, 0.03434846383918609, 0.017653852701187134, 0.028006770381970063, 0.013234254721152996, 0.05707147863826581, 0.0267128176721079, 0.02376968220674566, 0.08136274732117142, 0.03433723408462746, 0.013913782097266188, 0.05901851451822689, 0.06313465721905231, 0.0428294153617961, 0.03370598956410374, 0.052268054602401595, 0.053639957415206094, 0.01963807230017015, 0.01612836348691157, 0.025001657528004477, 0.03660098296989288, 0.005443213856779039, 0.04085988265329173, 0.0051015146475817475, 0.011533494822547903, 0.01995824753040714, 0.03796086214216692, 0.05063448833035571, 0.040128815453499556, 0.021608349700857486, 0.03164771465318544, 0.011610168431486403, 0.024509226005258303, 0.06840128318539687, 0.03314711758866906, 0.024521488829382827, 0.02403185117457594, 0.04139574211356895, 0.021618179976940155, 0.013201684192089098, 0.05234946184126394, 0.046200546968196116, 0.02361998550726899, 0.001611609196905712, 0.05475460385371532, 0.07660604042134114, 0.0687470171334488, 0.07143327620412622, 0.03534623262073312, 0.02678513084538281, 0.022062567827690924, 0.013709166469717664, 0.03900601641674127, 0.03188889314021383, 0.05476616948310818, 0.01007382435325001, 0.038071873863892894, 0.030742219848824397, 0.0358886365512652, 0.04114991905433791, 0.022898137902042696, 0.046759995698396645, 0.016513454162382653, 0.08479352215571062, 0.02013037320492523, 0.017540091216298084, 0.04571381683594414, 0.17763797087328775, 0.0505296207432236, 0.061754075943359306, 0.021070091619289348, 0.05130005993747285, 0.017611010000109673, 0.07100372961057083, 0.055112938197063546, 0.05236543116292783, 0.010440620028280785, 0.011138154875620134, 0.03666744547496949, 0.022127208466242467, 0.03136467394818153, 0.039326820988208055, 0.06422867280031953, 0.027003381634131074, 0.04268294000732047, 0.06956062811825957, 0.010360605482544218, 0.04194508067199162, 0.010971646622887679, 0.04603125926639352, 0.0268794166788991, 0.024776254980159656, 0.009436132901880358, 0.03588825657165476, 0.05835203706685986, 0.03062856523320079, 0.058280899455504756, 0.020487304677122405, 0.04152766628456967, 0.06219703038888318, 0.008516223469216908, 0.0012579778433843914, 0.04723867840532746, 0.02454512220408235, 0.04079038370400667, 0.013922118748139058, 0.04387600813060999, 0.013990937466067927, 0.05656576309619205, 0.059266919403203895, 0.05554181643362556, 0.010972745001449116, 0.029701319988816977, 0.06809364219329186, 0.06756035438073532, 0.02661491694327976, 0.02885544127119439, 0.014759502207328166, 0.06151965566511665, 0.02446141982051943, 0.05074149669547166, 0.040274639414357286, 0.027994948605607663, 0.029521148585315262, 0.01629966134870691, 0.018727569907371486, 0.046393719102655134, 0.027485339968864406, 0.038679668214172125, 0.028938388784549067, 0.06825500460607664, 0.03557163856125303, 0.020948114771662012, 0.021416251348065476, 0.019895254035613368, 0.060374241056186814, 0.024623226673741425, 0.017035183130896518, 0.025271880706506114, 0.03298141255176493, 0.026290490691150938, 0.07730387297591992, 0.02132276788220874, 0.06372795466865812, 0.15907581762543746, 0.05795590832297291, 0.02593361010908016, 0.026209397274734716, 0.0301189990048962, 0.0524104282126895, 0.03302613140216895, 0.0314547494719071, 0.02161866852215358, 0.02721498447603413, 0.045000567965741665, 0.01653066011411803, 0.058278802782297134, 0.11296789068728685, 0.03511298281539764, 0.02631334205424147, 0.04331854072266391, 0.030445537197270563, 0.021932672476395965, 0.1392939705401659, 0.027564604733405367, 0.02634580316953361, 0.04243131886635508, 0.027724779709907513, 0.044154329624559195, 0.04271864112732666, 0.009692577578659569, 0.025606970136452998, 0.0529363030301673, 0.040777742596609254, 0.025010442860158424, 0.03736887426514711, 0.010047973865377051, 0.016465150950742618, 0.01487050375102886, 0.04053428762459329, 0.10212938620575837, 0.036971497016825845, 0.03960806018273745, 0.015881709222282683, 0.013521873841195233, 0.06101687478699854, 0.028269709487046515, 0.0306971379821854, 0.008786595077253878, 0.013995252100617757, 0.022509152435564568, 0.048817968661231656, 0.05485208558716944, 0.0305822212914271, 0.0362799239477941, 0.024567120309386934, 0.05643066338130406, 0.045182744440223487, 0.0205553566504802, 0.03654572307797415, 0.024979951192757914, 0.03658517310395837, 0.02108100246238921, 0.06955301495535032, 0.02514535597791629, 0.03732340902622257, 0.05126700849671449, 0.02872095223782318, 0.04985572351142764, 0.05968258995562792, 0.019842618377879262, 0.016824243556974188, 0.012802585161158016, 0.06829188976969038, 0.004491587152837643, 0.024728045067084686, 0.04602300149521657, 0.030922442142452513, 0.09588841109403543, 0.022030418838507364, 0.03454385817583118, 0.028545795208109275, 0.06017677379505975, 0.009996731748937495, 0.02515610397261168, 0.009940040148129421, 0.05975064701799836, 0.043722241917358975, 0.024288849705564122, 0.005511491443030536, 0.0586595084252102, 0.023751662012987902, 0.05105575679668358, 0.03382592062864985, 0.027204082114621997, 0.034735279689942083, 0.0031835609905621304, 0.03237503294699958, 0.0297799757681787, 0.07979962655476161, 0.01806419845005231, 0.08255667718393461, 0.0756094353273511, 0.02285469469747373, 0.07991957797535829, 0.01279945032937186, 0.027931210418630923, 0.03714419774977224, 0.07321576734206506, 0.0633027981966734, 0.018723944834034358, 0.029094244885657514, 0.013432292799864496, 0.025217967706599405, 0.04590720270893403, 0.040778543267931254, 0.04452183097600937, 0.020936423613290702, 0.014611791919118591, 0.028697139051343714, 0.04889513166355235, 0.05913847950952394, 0.01627612127257245, 0.020282982515969446, 0.03387472425986614, 0.011399324700635458, 0.06620380003005266, 0.039135385903396776, 0.011771292508845883, 0.004973201131049011, 0.08207075790102993, 0.052274246234446764, 0.021103165112435818, 0.02055393172694104, 0.02701779032525207, 0.03126311421926532, 0.01705660448143525, 0.01670765258105738, 0.0587219132908753, 0.006758854242174753, 0.046714333684316704, 0.023884142582703913, 0.037521612497844865, 0.044761014570082934, 0.01937767430873854, 0.010063553877573992, 0.05288485311237829, 0.010264248420883502, 0.08091266147260155, 0.055409824409122975, 0.022886219434440136, 0.010617150243238678, 0.028755394675369774, 0.03372054074757865, 0.05823331379464694, 0.018933998919757347, 0.02727377275004983, 0.042761154738920074, 0.0479424040365432, 0.024396270280703902, 0.039662940095045736, 0.12991762081427233, 0.08712540952754871, 0.08568515109696559, 0.10906711500138044, 0.07957754882850818, 0.21040946165365831, 0.13641903123685292, 0.11319238399820668, 0.14141508457916124, 0.14281748075570377, 0.10763985051640443, 0.16266425007155963, 0.10993210465780326, 0.1161739347236497, 0.07998290564864874, 0.14697687327861786, 0.12134054462824549, 0.1556053552776575, 0.14828040690294333, 0.16115729164864334, 0.1518671294408185, 0.1273053695580789, 0.09975542966276407, 0.13390495042715753, 0.24665355895246777, 0.12445500679314137, 0.1503873395600489, 0.10047600671116795, 0.14709731324442796, 0.12739537044295243, 0.09500522312841245, 0.16152888456625597, 0.13353935575910977, 0.1558390155966793, 0.15145316879664147, 0.16595680053744996, 0.12247042757059846, 0.10614078345575503, 0.23749968728848866, 0.11946663446724415, 0.08777826199574129, 0.09045976453593799, 0.11005394240575177, 0.18349345667021616, 0.16551842620330198, 0.10424442057098661, 0.13633190734045847, 0.22799096895115717, 0.11213983369192906, 0.10186004851545606, 0.11004773381033114, 0.10078675539365836, 0.20908840825515135, 0.18267536056893213, 0.14266145841351577, 0.14378505812159606, 0.2072749962764127, 0.0980460506730846, 0.12546755746006966, 0.15618713120264666, 0.09495746783379998, 0.14899869050298417, 0.15115758537181787, 0.12378907895513944, 0.09052269865891763, 0.15679629280098847, 0.11977668425866536, 0.09686599006610257, 0.14191364496946335, 0.15650783399386065, 0.1586449071764946, 0.24382469217692102, 0.1319232074809926, 0.07399135322443076, 0.10161862575582095, 0.08174096952591624, 0.12170461937785149, 0.11770441117031233, 0.13495803677609988, 0.168374665081501, 0.10579639300704002, 0.09560040012001991, 0.09726720103727919, 0.16976560758692877, 0.19422265594559057, 0.11604885357831206, 0.12342071586421557, 0.17997909310672963, 0.15732864423521928, 0.11444402326430593, 0.09918985036867005, 0.25186622781412943, 0.14350247542772973, 0.13191826774605683, 0.10102528080876384, 0.218777969745653, 0.16368491601731094, 0.10789580749613897, 0.15746717394462653, 0.12026759077395711, 0.13509655291480677, 0.12080998452646391, 0.17247872985899448, 0.07013635151088238, 0.13547940951372894, 0.24755071795412473, 0.07894555452678885, 0.24062423248376164, 0.16800406282501562, 0.09458853477346045, 0.1558569832039731, 0.1726657748222351, 0.0778848414442369, 0.1188983071063246, 0.1337345295718738, 0.08462525225643601, 0.08033858692007405, 0.12188797311059066, 0.2688384785183838, 0.1488771377397435, 0.08746933857245104, 0.1340408609913928, 0.07956494843321187, 0.14619207967604908, 0.19837090692349843, 0.1884784906038216, 0.16710113627570017, 0.0542260759643146, 0.10710812333439078, 0.10507479137075798, 0.15299439323799952, 0.09531914735479013, 0.17698417524141924, 0.23043776622840337, 0.1570920255035162, 0.1066709907193269, 0.25751693174242973, 0.0637253490941865, 0.16485988082630293, 0.20646048284002713, 0.14022976532578468, 0.12481952937585966, 0.10121555559869323, 0.0749091464760048, 0.11504344109977994, 0.19118587246962956, 0.09351033584347793, 0.15081313385495118, 0.1408127626138074, 0.09503376909664699, 0.09463412554136344, 0.0835533704874771, 0.09604045043566398, 0.19719085310186657, 0.10096313378640584, 0.103912379459611, 0.14891025024865354, 0.1558215365345989, 0.11336765637887375, 0.15727824265403406, 0.13614752223449095, 0.13056340973292077, 0.07041709537484817, 0.16496338455804757, 0.12199686441038336, 0.24765879501189503, 0.12289224565029144, 0.09202375382717166, 0.1068115085363388, 0.17793470780764306, 0.11351607234350272, 0.14050119290394442, 0.1786647436342069, 0.1880807333758899, 0.1224862238658326, 0.1153240017592907], [0.03232123190537095, 0.030123429838567972, 0.017328500248757855, 0.022018544475681016, 0.04754757468721696, 0.04469289643956082, 0.013367296778596938, 0.07324514112302236, 0.002759670410471569, 0.011029314465953835, 0.012089753589992012, 0.004661197582858482, 0.03633934325937714, 0.026000228677211062, 0.05239888633202229, 0.00920811205703233, 0.02268243331595191, 0.024686031875067523, 0.013102684236530746, 0.024871668878144453, 0.03768575690420611, 0.05852919577487877, 0.0139921808814896, 0.031544702859329324, 0.0358408948273531, 0.05411495906966073, 0.0662436436063477, 0.04631142298291836, 0.013516226733502532, 0.03473658926252808, 0.028594527593148605, 0.0294631949093725, 0.026432723505422473, 0.03014864759253604, 0.07199493356581245, 0.027161029067688754, 0.04443180973508528, 0.039628216065466404, 0.024498947896063328, 0.020770194408084666, 0.043451754110200067, 0.016606218381119624, 0.017173904526446546, 0.08951957284339837, 0.038578739522823265, 0.025592166198683635, 0.020303348744554178, 0.058997547786150656, 0.03681887413508125, 0.04873824758189065, 0.002301638704791133, 0.006575440289452672, 0.017450465222022364, 0.035607187010880025, 0.025615456913198744, 0.045265973545610905, 0.020281147078744004, 0.029896269885024855, 0.06908085636262383, 0.036384207994810173, 0.0015753226284037478, 0.09118525417787687, 0.03712178234543119, 0.03834503170635019, 0.05652463708871177, 0.04881415529442685, 0.024817548925057054, 0.043951912450471094, 0.08441872655280999, 0.050318016204982996, 0.04160338739997574, 0.01716525829397142, 0.014733677164518406, 0.011835515848360956, 0.042317749067608795, 0.0289894281886518, 0.020256000570952892, 0.02654652570241264, 0.007659383018368057, 0.07452107194278922, 0.028093510906078985, 0.023973303780491863, 0.06364462378301791, 0.040755184699914286, 0.0523470225078719, 0.015107236137347562, 0.07292084209620953, 0.030969579970198016, 0.0381886429552521, 0.05685531434469989, 0.059105380571314266, 0.033636585609721284, 0.03426384373701044, 0.06703322766614811, 0.02079478112448539, 0.06135714652815035, 0.027321361803582737, 0.037596163140343766, 0.03223549900576472, 0.03950717220348971, 0.021531407222417847, 0.07590014687074081, 0.037563983617084365, 0.024850807318996106, 0.014510539227298327, 0.03411454228418214, 0.013417318380171699, 0.01436532594795738, 0.04455177133370723, 0.017208611592650414, 0.0765037512672799, 0.00921405856830201, 0.04018047910981944, 0.03972404556615012, 0.03236087192116039, 0.03853719960898161, 0.061176459438034465, 0.04304808684225593, 0.05712861128683601, 0.01836508632238422, 0.023083613753052692, 0.042548488293375285, 0.025853524317166636, 0.02047096216119826, 0.005303719355392137, 0.00453978349521224, 0.023834826657548547, 0.024146688137469546, 0.015121079948065537, 0.012063042210814143, 0.029158128957663263, 0.04703914161239352, 0.037942667225641866, 0.031605564057826996, 0.039818789410803995, 0.014482617511280944, 0.041666762570717504, 0.03039457243201988, 0.005267478800046125, 0.05569480911695531, 0.01677833727028753, 0.05502566163028989, 0.042708717552678924, 0.0556344195002956, 0.03903076258887138, 0.0075152146829558265, 0.04885954250182424, 0.031524967668311935, 0.024082524169768606, 0.03297547197767666, 0.03503227107492941, 0.059994288587144444, 0.03788490014682923, 0.04613777230094586, 0.014853587873013956, 0.06431684842599289, 0.027851105967004384, 0.014575994107872248, 0.06868193205446005, 0.07206968098346676, 0.051032907129930596, 0.04073196862425123, 0.09642586511160646, 0.03966480267367192, 0.0641706580562251, 0.035592092999390194, 0.023017519353223697, 0.0356597632968, 0.04121174716523715, 0.05852547061762639, 0.06472128922385828, 0.01890161244331726, 0.01725898263975978, 0.03853435993992856, 0.031157479887562137, 0.02260927197390369, 0.03511900142101305, 0.019279193432469453, 0.02534776467031666, 0.027177064546516964, 0.034527875283466916, 0.02375825398069407, 0.0320200878860695, 0.032237395511141846, 0.050729822500475814, 0.020311238410483514, 0.025067994504102638, 0.046497453536306105, 0.027714611862653067, 0.010327559130798494, 0.040222555066325834, 0.04093055207548397, 0.04325344885832497, 0.04123926854559353, 0.03700738134128707, 0.027865565548251783, 0.08205434413892881, 0.043401685011173995, 0.047265331260859966, 0.06510851558830057, 0.05328607765425529, 0.03465835417487791, 0.038438465978418074, 0.029489318507590463, 0.008651782891580036, 0.023024947615340352, 0.0894215109625033, 0.040744708119226355, 0.06099799115742956, 0.058565667032131126, 0.05699782366199153, 0.04550671777022736, 0.061449834411697726, 0.02752691211311945, 0.05573620653844305, 0.04135850411174553, 0.03725118575883763, 0.056777238712779114, 0.03491419919633439, 0.08624699844845704, 0.026095976753692542, 0.039559989369341304, 0.03453655374635543, 0.056073102567877085, 0.021729717563305582, 0.0022742534555228694, 0.004663674659760935, 0.0455040884470301, 0.01824612895558987, 0.037052816046135764, 0.00272468980983831, 0.03992033896169492, 0.02566493907943368, 0.05755404595817838, 0.007221275857383651, 0.025702597772968665, 0.056510913717959604, 0.03674504613237722, 0.03536536391558392, 0.023424287526203052, 0.02871949678020818, 0.03682674174862249, 0.009167189610057642, 0.023188091182549084, 0.06929139899356024, 0.003849047568759748, 0.034454372977571826, 0.0174215545412153, 0.008914904352942747, 0.05003649881109595, 0.015037377564502614, 0.047715339077902694, 0.06879667911146368, 0.02357218780421785, 0.027448766931359257, 0.04122952139005065, 0.044915150584919114, 0.02452272206677922, 0.031203521881252527, 0.022839431052229235, 0.0293657504953444, 0.0413928583397397, 0.02150049147063068, 0.017922508463795696, 0.019092937266188006, 0.02347771028455879, 0.04717693850398064, 0.026469978470621363, 0.031036161218902895, 0.05128235017348613, 0.022224283078685403, 0.0922680264338851, 0.06293693211461816, 0.05285543861931988, 0.03256180649623275, 0.030568494527999843, 0.028192566840776374, 0.1329490031514849, 0.05026957559000168, 0.063166846920337, 0.06418580974319152, 0.04837635432236961, 0.07401660151247468, 0.02896263962611556, 0.04159752146473952, 0.05709950213453599, 0.03379106767741697, 0.011899695083099817, 0.00877173600851425, 0.041870540207518, 0.05820768552699259, 0.020881272286974957, 0.023420886369422078, 0.051399407642228265, 0.048292728273996284, 0.014602155025516237, 0.02731181142319526, 0.05344970298132726, 0.03659480490854808, 0.025996593425848653, 0.029545955825597048, 0.039891002500163655, 0.022559170644464235, 0.0248785220818328, 0.02523089719137975, 0.024021506908216646, 0.027783040422946215, 0.06131516556654658, 0.030427559411951473, 0.035230773101959906, 0.032711610064974854, 0.03162978097264256, 0.03351911084194269, 0.062078015346612246, 0.02279774864603366, 0.06396907208753483, 0.024888674662049328, 0.021860747764419233, 0.053590851835906506, 0.0192020321264863, 0.046722374324287684, 0.043754136455910544, 0.029686158123825277, 0.028378081707549945, 0.03810513565050704, 0.027984441490843892, 0.05567763200295823, 0.034983423338936906, 0.03145903442054987, 0.0298202400361853, 0.004724575298106564, 0.08317854774317571, 0.016897335349182998, 0.024157783881361996, 0.0154466647987387, 0.034219905201877863, 0.07742883198495422, 0.004990418108978442, 0.025875753124377558, 0.03554270922073296, 0.08912286734474556, 0.043589340655931404, 0.006530881318862417, 0.029793821275234222, 0.027632003616807715, 0.02267737653372543, 0.051518928193088086, 0.032909277493932416, 0.01714437977144761, 0.025435899583888904, 0.04919497289561799, 0.03521931603817003, 0.07585452896143709, 0.14536722536597932, 0.12001274659165315, 0.12037892479981695, 0.1443258776728596, 0.1237544058156865, 0.11238217925918953, 0.13763333750622614, 0.14962678322834627, 0.07307193827416215, 0.15774849456335815, 0.07202350667544774, 0.11981042101979256, 0.1322852059134415, 0.09712178419743266, 0.134000298167978, 0.1254131660929748, 0.13329323753714561, 0.10294926685414144, 0.07856900151818991, 0.14033063634165696, 0.12235389596649579, 0.1619039922952652, 0.18706460004406317, 0.14178023141409668, 0.14252896766577447, 0.13242032937705517, 0.0919014411047101, 0.13989990231181892, 0.11617208910839898, 0.24046770802565984, 0.14445139308060917, 0.0917498292401433, 0.10869007344756808, 0.19881701655685902, 0.12012929176645619, 0.15197796135076455, 0.11401704831847123, 0.11435676366090775, 0.10666900939707245, 0.12409097275563649, 0.08951595625174896, 0.06178280511604888, 0.1812919769436121, 0.15405225647347315, 0.10428275101419006, 0.06659113496009793, 0.18050620625061647, 0.11966205255261489, 0.05781125822769744, 0.15103820392063685, 0.14418443026287214, 0.09183877161038773, 0.11277160407709223, 0.11081181173878056, 0.12885617491390022, 0.20695719761507853, 0.07381178571709565, 0.16167977718370302, 0.11808756632464272, 0.0953639510220715, 0.1667732410132885, 0.1560426846678768, 0.13557014321642263, 0.16597860865294933, 0.2054441323769944, 0.12202534931046621, 0.16485746524163655, 0.1699355941798006, 0.12376520809318338, 0.16174891990210327, 0.06093712656625679, 0.08063422462769917, 0.08378333957599741, 0.13476572638111456, 0.11669510390077319, 0.13424025529197284, 0.1437846238591841, 0.10144135169684887, 0.1446860847728593, 0.13685800268181733, 0.1335179004818201, 0.12044349419219152, 0.09652561654469796, 0.15523115678557328, 0.12793826631137303, 0.11670761608651706, 0.0949074530175754, 0.10901214687951974, 0.11989747706268515, 0.17769606704158442, 0.1271312574722937, 0.12743963806756906, 0.18813216633030347, 0.08469916507601738, 0.1621860321611166, 0.13533945488078253, 0.17565192601510457, 0.09303007554262877, 0.1143024672887155, 0.09091328377170221, 0.18891028314828873, 0.13098651702914918, 0.11248278564640454, 0.15181729782904896, 0.18831767780440195, 0.1289167816617659, 0.10486363805830479, 0.0800564724153706, 0.12304285328303065, 0.20818588882684708, 0.11832308582961559, 0.10391628103596823, 0.18112322528447422, 0.14995341641562326, 0.09182664618960448, 0.15445749115731033, 0.11317735444754362, 0.18920311172093662, 0.07617286366543599, 0.12322869045393807, 0.17400661430188588, 0.16298487143857138, 0.12477359255509717, 0.09703097585588694, 0.13992846863610403, 0.06496425225798573, 0.14295370344604763, 0.15771109371313027, 0.13914101517626218, 0.1033160693145224, 0.13033817681883061, 0.10710209794342518, 0.15467235605631555, 0.17744560619550093, 0.12288301757403783, 0.16741570511034556, 0.14207238145172596, 0.1010538199916482, 0.15719688630529813, 0.07556379027664661, 0.16300693739737782, 0.15766360983252525, 0.1571990033345563, 0.09193310154868023, 0.16588110317076954, 0.13442826377493994, 0.18108777861510003, 0.14969568167413982, 0.12942482797162874, 0.14161869936755725, 0.2064594378960984, 0.07626023183443717, 0.08333555396114077, 0.14098227423216614, 0.21974338937018598, 0.19177756857659134, 0.13718835424099649, 0.07253001949616841, 0.13475269850875649, 0.15113872209829943, 0.20336620030658586, 0.1920311099716595, 0.14554854349366256, 0.1699148988617318, 0.10165240322904927, 0.08381715097597667, 0.22085556254855224, 0.11869503158543791, 0.09815933887979814, 0.145779462531209, 0.09601700705076967, 0.10992856270500592, 0.08836346452257463, 0.14220149309507438, 0.16701831429132394], [0.04720410704612732, 0.05376277903893164, 0.055273126744266064, 0.027106403606012464, 0.0415999472274312, 0.0515402579413993, 0.08970809701297965, 0.02302187554804342, 0.04026244953274727, 0.011077943374402821, 0.055878040713391135, 0.04573107537414346, 0.03632651555484959, 0.0050384588123831365, 0.016368100087025335, 0.05446996859141758, 0.02495815495162138, 0.014644222500334893, 0.03637949896178075, 0.04552960814908147, 0.008080817725775498, 0.04549410380423069, 0.01076889272579657, 0.04710207573537316, 0.0382967810811741, 0.03608379679332886, 0.015421440259420445, 0.03128821322960513, 0.023201862050752555, 0.017484156182035804, 0.048065653137330494, 0.037183603670980246, 0.04200570099055767, 0.05252476814868195, 0.04124462218689067, 0.038963109254837036, 0.09756583786968674, 0.05886726227721997, 0.02411878338482763, 0.07483785280159541, 0.026812273942466294, 0.03866796687777553, 0.10787948872894049, 0.04427615719448243, 0.007458964978078646, 0.03642536453636629, 0.04349043060626302, 0.035373024575944455, 0.021453323108809333, 0.036240762299192805, 0.057672735303640366, 0.021845685983342782, 0.05595809088221618, 0.04931187090863075, 0.048738810765956125, 0.035660489329269955, 0.019641220702656677, 0.07140088294233594, 0.11261783447116613, 0.017564827210402915, 0.07744979871703045, 0.08545729225235325, 0.017994032840111425, 0.02797880965018911, 0.04157806108040469, 0.004809549510745066, 0.04032934969291091, 0.07381935816790376, 0.03437407175078988, 0.02748773859015533, 0.015027650765010288, 0.03471532058236854, 0.017289918747597506, 0.041563425080052445, 0.06935771900628294, 0.02512698294594884, 0.054405395806367905, 0.012810722492369158, 0.03151914244517684, 0.0441182824516935, 0.04793631757742592, 0.039672385302505324, 0.02880469702982477, 0.02799012082894998, 0.0316588290567909, 0.046199122044656954, 0.04091257768283997, 0.07241097731249672, 0.05799742109541382, 0.03084785757320268, 0.051326224247791936, 0.06494691568825926, 0.0722060122394136, 0.08152695279568434, 0.048622262198477983, 0.023921735119074583, 0.020642843563109636, 0.05587036308965512, 0.042836757110697884, 0.014158102201430925, 0.047456891874649694, 0.017597731069794724, 0.06302130794418709, 0.1370509508997202, 0.03997853012489421, 0.011586369663876082, 0.06823295221797057, 0.038557379240436215, 0.01718342606909573, 0.030813530486609255, 0.026010026722880344, 0.04666061067421522, 0.020330564784152166, 0.053492223378270864, 0.04494734707155398, 0.013082172971085777, 0.016985609362434064, 0.010051531933381088, 0.02203832546781216, 0.031631996389478445, 0.0735040158033371, 0.02446007462484496, 0.011292000816735839, 0.008388200874573417, 0.03597276132287724, 0.03741887551067131, 0.02160209700066064, 0.02888014673122338, 0.08497975966227905, 0.04869783742885504, 0.0633437070729477, 0.05567028346870627, 0.044087918009608984, 0.05212633577840669, 0.02481123515670853, 0.06413278223148414, 0.024509863828175833, 0.02376082562841475, 0.041124487561838965, 0.02576384912910206, 0.04355314081268651, 0.03548312366807035, 0.06546983548573085, 0.023766878160781095, 0.07269058802298137, 0.07514307142368384, 0.03937848125185285, 0.03326104701097522, 0.03931328082191093, 0.07711950144065277, 0.05972440128347703, 0.05631094605528882, 0.06573358204747949, 0.008777975138010723, 0.010626735398545861, 0.022533091151022484, 0.03669154703883188, 0.018300952888759117, 0.02712333814374038, 0.0744786092213222, 0.04730404846902404, 0.027747495365994315, 0.019822102871590426, 0.012826091310541545, 0.04202238616666623, 0.05859825706907681, 0.03199717375848975, 0.05724234054131167, 0.023335840486522232, 0.03314406757376023, 0.0301390293586467, 0.08934278732963971, 0.04388287151232362, 0.01761094723562045, 0.03863748708473785, 0.019377474140908037, 0.043346669391861985, 0.01743982240025486, 0.052663345355540514, 0.01649992587044835, 0.03501717706343957, 0.0420956475926297, 0.09279903436877898, 0.01869149220042995, 0.04989790464086192, 0.04168394986273987, 0.018377898759873848, 0.014572119672915764, 0.021794700862041542, 0.02705356608411031, 0.06425779552331992, 0.03813004806371672, 0.05734911481184619, 0.02219727059959301, 0.026405980743999993, 0.039178394845553806, 0.024820395379460285, 0.045295527138348134, 0.013591740895727915, 0.08222087020320551, 0.037559420469083955, 0.06132301621671234, 0.01391719258390367, 0.013315924044166292, 0.020726171056074754, 0.024237409965800386, 0.029651515518448184, 0.02067970158532262, 0.019485010067000985, 0.008672132156789303, 0.039473337054784806, 0.03086836290146623, 0.034874545609844584, 0.05151863642303007, 0.014499609724485447, 0.04138554712491376, 0.0553428428247571, 0.029648058382528167, 0.023465247292603766, 0.0056892659215788755, 0.003861692492916648, 0.0388599617539772, 0.06683671035404716, 0.017982244990499954, 0.07363394847405808, 0.02617023901880852, 0.02450083931242781, 0.012095898572754647, 0.003857496177910694, 0.02612417158005493, 0.06063594522752932, 0.03626312681340745, 0.05573377059772611, 0.03929603246173688, 0.02115747335899089, 0.013483542549823011, 0.04334596710811768, 0.04532400525308081, 0.03264686425349542, 0.07182035329086439, 0.006414715275501034, 0.03458314874608602, 0.03918189608625003, 0.012858070665970445, 0.041995682421007326, 0.06627936847507954, 0.022546164824494293, 0.0398889736804579, 0.024351468309760094, 0.044019331689924, 0.01838649240588503, 0.05776136554777622, 0.06123474559613636, 0.04529924890292542, 0.030323244830859557, 0.035467860022825856, 0.07501361372747592, 0.04648551810532808, 0.03499950461887887, 0.03955604029553277, 0.03516882964010749, 0.0088143217144534, 0.06984197587839194, 0.029848741899643625, 0.00809681079616504, 0.04215272256572332, 0.034869700869811435, 0.1047062925728304, 0.05746411292680672, 0.01307585581006216, 0.029589524559144462, 0.028955267343137945, 0.030933424231729338, 0.05495772331154772, 0.029731728535677706, 0.018821355321311524, 0.019602488227454678, 0.04629444603675178, 0.029541151797665016, 0.0997277522193534, 0.058460602669843605, 0.022773445218003223, 0.08828263743115322, 0.06674844651882138, 0.03691871377772518, 0.024190406148721064, 0.009043629231330539, 0.045775492276464186, 0.025212856641571437, 0.027397530752101114, 0.046871567211513004, 0.005660750063335789, 0.019153467678864087, 0.0030075875984039158, 0.019461736315861344, 0.00987079056046371, 0.04404078018186348, 0.022527971604306782, 0.040343856771609614, 0.053536507966262956, 0.11689426749944687, 0.023046949113320028, 0.04101896858108895, 0.018682854449642555, 0.08500648037131343, 0.023683155421167612, 0.07157973120255129, 0.041476769372820854, 0.07870983146131039, 0.05289583180898002, 0.03858271234535745, 0.02431685963113393, 0.03908555768430233, 0.053592965472489595, 0.03447037283331156, 0.015615368960425258, 0.051690943605665646, 0.022862184027742063, 0.014038271220800067, 0.026972923893481493, 0.04056734585070184, 0.0270579137972423, 0.05595686612650752, 0.04962296225130558, 0.018246016997311796, 0.07699161116033792, 0.07855137317840542, 0.04185270491455283, 0.023239008450348462, 0.03510772416900311, 0.04025388302813683, 0.007585658492254359, 0.03649844954322491, 0.05446933755385024, 0.030313864084226743, 0.022353786576007093, 0.01586275265019919, 0.02020758031202214, 0.08072063606232405, 0.09052674951297895, 0.05049941236419337, 0.04233369803322213, 0.01240745556008603, 0.022020539368635843, 0.05535055437524404, 0.048367394267448356, 0.04583464017403977, 0.05195706503997956, 0.04679387155920267, 0.00896102437816028, 0.06328975675361496, 0.04829672145258103, 0.0909658023821456, 0.1627811887966735, 0.08071767764964274, 0.18479868663208826, 0.14104673505893775, 0.2037342241300004, 0.1602067726531199, 0.10716468601354531, 0.09787725151649543, 0.13620229358119623, 0.1382628008723259, 0.13630677440336772, 0.12761213524000986, 0.06720991139965397, 0.08627666399947234, 0.09984652298901762, 0.09574472451848642, 0.07918952179274388, 0.125372494703957, 0.13487103501600878, 0.0736960412136146, 0.15396996374641145, 0.07092438851084028, 0.14924556868416922, 0.19299365260771342, 0.13147380016744137, 0.10275070715163435, 0.079914801088827, 0.12451816483267716, 0.12513316183217935, 0.14719880851251738, 0.10943669266998768, 0.11028013883956841, 0.09919245594314166, 0.14218777311699732, 0.13131108746996947, 0.16654057135539396, 0.11581375476505075, 0.10501902257757527, 0.134989005114351, 0.19915119505354337, 0.12601850075381144, 0.12815675458737782, 0.09389670725379672, 0.08048148639500141, 0.15834420759763035, 0.22546474236462796, 0.24874825083783694, 0.1495100073516369, 0.10479163192212582, 0.19748757646552154, 0.08333674818277359, 0.07264159779463496, 0.09867985666330371, 0.14705186496887887, 0.08807220336581979, 0.08369204268923827, 0.12241314564432416, 0.20016219866062912, 0.07109889414693628, 0.1424388853566987, 0.21832286273794516, 0.0908550043989505, 0.10692521743476391, 0.16561674592750414, 0.10052275098860264, 0.12343443584229265, 0.1582492534071207, 0.111878109164536, 0.18519803163196358, 0.05373996669160468, 0.17075689296637261, 0.1420890869838851, 0.13382328195231302, 0.13161874881812505, 0.09778784095708813, 0.19508307906133787, 0.20287063904106617, 0.12265710612492901, 0.1400180081171649, 0.14471566889967236, 0.11010597247098174, 0.08955272606440953, 0.1339940827872072, 0.12758119404315948, 0.08984163270464965, 0.1422242240181991, 0.18430175472583088, 0.12812328924025806, 0.1704065924776452, 0.2098184305110148, 0.14970436692237854, 0.12685201317071915, 0.10533874827836241, 0.09018586709031037, 0.11705793014594487, 0.08900153849806104, 0.2055573527302061, 0.1286244144929307, 0.06602674310228654, 0.13051923710320676, 0.08990318940154143, 0.13581820204854012, 0.1839305960706302, 0.15417650980608805, 0.1534511423004525, 0.1868451346776315, 0.05872764691178288, 0.13516201797340596, 0.09151513754789319, 0.09838303830474615, 0.16917955689132214, 0.13182437207017625, 0.10616277477570943, 0.1585462481847831, 0.11563034674951009, 0.08302857114800385, 0.11265995113977365, 0.09252487229449408, 0.2034843061119318, 0.19645564683846065, 0.0731915979247008, 0.14359007429863724, 0.10798311459698848, 0.13001811185053416, 0.09180310780980758, 0.10683040573660817, 0.2279329134949616, 0.14338427462748118, 0.15131549404135772, 0.1972311987940754, 0.15593738960368292, 0.15964019591254847, 0.13602572519864353, 0.11669566029948847, 0.14797997873808655, 0.1129256450970258, 0.21131626942328044, 0.13551212847232819, 0.13260105039392198, 0.11120377427765302, 0.08720677944698504, 0.11032971939338104, 0.16462636978498527, 0.17976109337593826, 0.1093502337379115, 0.14879905192979745, 0.18799776211380959, 0.10546528148863997, 0.12992671318352222, 0.16446704976260662, 0.09323138331196137, 0.1515725909599236, 0.19393646344542503, 0.12110198528638907, 0.146254477756364, 0.11968953322087016, 0.21121868251689843, 0.10107931255229882, 0.19476532111210482, 0.20194067965660775, 0.08238844121141092, 0.10910269059240818, 0.1754347812384367, 0.1495411249675921, 0.0963923590523856, 0.16863037778862885, 0.22815058752894402, 0.12137429496007306, 0.1597457081079483, 0.09971454114254032, 0.09785665797867946, 0.21178524568676949, 0.1041989858661379, 0.2591749184897968, 0.10849043487438134], [0.060189129917749336, 0.007854160736314952, 0.05714663317693131, 0.032617663498967886, 0.09144757581608635, 0.03283607713612063, 0.033683207750852616, 0.0488291407403137, 0.03521346028095909, 0.012479734806610005, 0.0461386543964701, 0.0675813550395625, 0.03506290693102138, 0.004167322052775749, 0.015898275654762983, 0.029944181242691617, 0.04137040900864771, 0.03701986977830529, 0.03790103231689759, 0.04524162092379161, 0.0366303397874747, 0.03146863569106374, 0.017869955926601375, 0.07751959961439882, 0.011403002360436534, 0.06227188637214048, 0.03343155946848648, 0.060405501164495945, 0.006322110936577831, 0.03599220135116151, 0.046871289012155364, 0.024049291220892752, 0.031908940457339795, 0.014483016150604402, 0.016474334922220026, 0.011834956056970571, 0.039542947962347946, 0.046478468126484325, 0.010195545053907802, 0.01884727705536144, 0.04210821406117507, 0.010418895881489983, 0.032601873989083936, 0.007735177924457405, 0.05466990911268762, 0.061712074625704966, 0.012136886328724878, 0.07118471525609493, 0.010974197914557797, 0.07283293788454362, 0.04638937647853579, 0.03374523602958236, 0.0006712776625395886, 0.028986398529793535, 0.05668846258361425, 0.06525690441152879, 0.030284541193395853, 0.03442934521340898, 0.018582387162106376, 0.06185194104909897, 0.0205464966794742, 0.08298903969781739, 0.025084113103470633, 0.05186132714152336, 0.02444389326098774, 0.03778564404430134, 0.040095255111477206, 0.06701638642698526, 0.10163735332233564, 0.015149873581581881, 0.03284122382423707, 0.004241963873417782, 0.02322597209630268, 0.014110643765889108, 0.01776541573261576, 0.07096352641071592, 0.01527290724750076, 0.013757126173004508, 0.03841894791860666, 0.0025150481461813407, 0.09046519960143737, 0.028691110267703022, 0.06010342415954385, 0.02722304207938058, 0.010623741362776076, 0.035508826574576755, 0.037326808486665995, 0.005482384411152452, 0.0549382561418627, 0.02868888806551695, 0.013236828913379992, 0.007120465061494282, 0.022987268565754806, 0.019382636096062403, 0.06997559299426419, 0.012410942381913108, 0.04025552847555705, 0.043963216843881776, 0.04360306741935866, 0.05355641957638519, 0.0388228594591575, 0.010388835931995084, 0.03006869920396379, 0.023640590919447795, 0.02092496146048818, 0.05022035805242402, 0.04676769707085831, 0.048396503419748375, 0.052805094713611264, 0.039272755317922146, 0.05693063512444496, 0.016257799130731394, 0.06491425101246152, 0.02330969483591616, 0.04355295421555638, 0.021343768541035906, 0.01357609048552279, 0.04920448934925454, 0.004256254669079291, 0.032243828023118634, 0.007210505810300154, 0.04635410283559135, 0.014532216724806597, 0.032532670202531984, 0.03616262899179544, 0.0476833563297987, 0.032269103452563286, 0.01887500369256096, 0.016762707216132964, 0.012793692111569856, 0.061819737777113914, 0.02431463573261031, 0.05210418500272291, 0.059663991310766766, 0.04326715187302657, 0.011763413869110602, 0.03943512196253453, 0.06582960832331862, 0.08452757035515138, 0.012629777558946183, 0.015344022806467754, 0.034162012594086785, 0.03753323580271431, 0.008464484325876194, 0.01898086872617049, 0.05419017467647791, 0.034381634023572714, 0.007815681863576174, 0.019773438340052962, 0.008825527720286377, 0.032628438635064025, 0.025501429103314877, 0.039544742687472274, 0.0158908609633467, 0.032610739049102576, 0.03530008206143975, 0.0521879772921758, 0.04016161583630102, 0.020757739897817373, 0.0474687865935266, 0.02630473823020501, 0.04006798139640263, 0.07546328566968441, 0.04716528466503535, 0.05778487678617239, 0.012377373558203024, 0.0235008737737579, 0.03727832715958357, 0.0941846232329096, 0.06417760625481606, 0.031177954681749855, 0.02488735151876296, 0.06260115906064, 0.04391636060816901, 0.024432086751663258, 0.05722486147923129, 0.01946121214755944, 0.045888787268527916, 0.048343462337340624, 0.01796491350978613, 0.028345033659466674, 0.03935272406254496, 0.014854174805805087, 0.12273677970681872, 0.01505720944676016, 0.06097431707062891, 0.010024576281596507, 0.07844492460467986, 0.02191047420326088, 0.03436518972739577, 0.0193186044426901, 0.034685434507472176, 0.03948032596547689, 0.024624688916706612, 0.03494999870391829, 0.06241950845079763, 0.028798474863703762, 0.007079121922808034, 0.024821387736925056, 0.02582977559151394, 0.01893828047572502, 0.044124324806034565, 0.03177811551306929, 0.03993442874135716, 0.02609444665722549, 0.03257125848904252, 0.02431840160196381, 0.02568336300152753, 0.03544540051370859, 0.029098366985895803, 0.029811436044318334, 0.025763891537540724, 0.04594340255217893, 0.0559547694532999, 0.06637274846434593, 0.027761939680203795, 0.009789090703374572, 0.021490606911746517, 0.021219126747122834, 0.025188217338706766, 0.012602202743957085, 0.036591449552880864, 0.03994156353707824, 0.06828772356467587, 0.01843745038578553, 0.10156791883387736, 0.07281685660460166, 0.018957571226305196, 0.03750320045011384, 0.03316606907173991, 0.0308799760283104, 0.013118371966161897, 0.01985670137219131, 0.02238864970526525, 0.013144884025678039, 0.02287844172678888, 0.05816364860428231, 0.0827247638787542, 0.009777009387367537, 0.04820303612255624, 0.026945933466777205, 0.02648277224839798, 0.041252089464770894, 0.019823539669492414, 0.07204705862594502, 0.03270433616957494, 0.022685619037864462, 0.02284747508487531, 0.03362851782834955, 0.0385388111296509, 0.036616741945700984, 0.017642239574342966, 0.059539412281342914, 0.021270554612523744, 0.07057613041251898, 0.02837076879638646, 0.042907280647861104, 0.03136286225968173, 0.042537903147084374, 0.030249325225928, 0.018338182408894812, 0.011729480332827993, 0.03429394355043769, 0.03407086498503174, 0.044351790100336075, 0.047548426248665364, 0.009940300535942827, 0.02186810308402138, 0.03289596124419144, 0.04666467849165201, 0.017104293618883406, 0.030548145262790576, 0.01982267962635628, 0.04939628066495061, 0.10410031330372606, 0.06414245135549988, 0.04909679227109466, 0.03554691613784858, 0.02350299758836627, 0.02378436570454921, 0.01997649503339614, 0.05120986567011901, 0.07259245150323425, 0.03548477590084076, 0.03338475073022502, 0.006030100846796164, 0.06247989806745734, 0.04076916591397353, 0.03731853714478867, 0.019862141526703323, 0.08294190187007189, 0.021341812663844655, 0.02639864238777331, 0.032578766479023864, 0.0048039286962843365, 0.0027202263216687633, 0.045149496224309714, 0.026123693212866783, 0.08093309894736324, 0.0436979300076408, 0.008670708929587687, 0.04221546330622264, 0.03815289094511952, 0.024180200982040594, 0.008179128120121146, 0.0488624771657799, 0.04991679844845619, 0.0596043820093785, 0.06471657340547868, 0.03761996954147305, 0.028213038242288997, 0.009523216934342469, 0.03389501924227391, 0.02382927284842091, 0.06123817219798054, 0.037432005163282156, 0.03210032804469977, 0.049015066120773554, 0.01122829910101635, 0.021318416776401655, 0.013843725052928286, 0.0828769321420363, 0.03535962350932615, 0.028221063615222062, 0.030649867840111256, 0.03474317444488406, 0.00948528088961861, 0.021219063982633606, 0.029821061063557863, 0.03273655979761055, 0.04230460584429758, 0.03919078489499433, 0.06935780043048517, 0.04892730100878647, 0.06306244073701756, 0.015957856118412952, 0.029056562443396876, 0.030544002806501727, 0.045946008126650534, 0.033005246094294956, 0.03227058944425412, 0.012624317896552384, 0.024521068137671267, 0.025204816001600454, 0.03995469318968909, 0.026992304549951638, 0.04572282099564161, 0.04344952172998871, 0.021389479748904705, 0.04060852614098361, 0.03881516147937093, 0.06801037916115352, 0.13816684244998864, 0.2209926401930196, 0.1424231297735657, 0.14470809644886426, 0.1341494130236762, 0.1390883880002158, 0.10842286635722433, 0.16619807401938097, 0.13075544871389866, 0.1493265586239951, 0.14031173235603742, 0.16425100421266897, 0.11800205734159265, 0.07280668536467211, 0.0957523173253451, 0.09329055156558752, 0.1344364604779652, 0.12225998671991484, 0.14150075641061577, 0.21166101949555532, 0.13134128227829933, 0.08652349468320608, 0.12003930445228304, 0.3284808381327561, 0.08404648902692965, 0.12283917064113276, 0.12878473874713692, 0.09662206351224865, 0.14003330229648522, 0.12009562285883085, 0.08839976614607231, 0.05905876521553312, 0.14338400321347372, 0.1555094782795225, 0.12688161086823257, 0.1451984058533396, 0.16718493535050324, 0.19577985310128757, 0.1470590302986758, 0.09883877635002136, 0.16625729655580862, 0.12383329229695456, 0.17701310797461442, 0.1059699554794601, 0.08622599778962986, 0.12643575907817908, 0.1441157218068838, 0.15997651857989176, 0.16747374699584075, 0.2603372489767415, 0.11826201767793723, 0.13674934208393097, 0.09994045259164912, 0.16734076770288603, 0.113742546976677, 0.22743663298232214, 0.08191220462322235, 0.09901089354285172, 0.1211237662604877, 0.16380318467106136, 0.11685196762638432, 0.21898607643587248, 0.05823704573724951, 0.10476159996220044, 0.07161523894007717, 0.19778818104948315, 0.10413457253681761, 0.14533603989652225, 0.2173538604485137, 0.14919911617679255, 0.11326607968658209, 0.07352118952465908, 0.12296361396355288, 0.15546537350331033, 0.1299348013209445, 0.10751241485455207, 0.09165920410305262, 0.1214399907205786, 0.16762651236993925, 0.05151425987215979, 0.1162442716636828, 0.11705056125564234, 0.1091402271496398, 0.10096392767237765, 0.05532649691615786, 0.1717023772320577, 0.14099631990705216, 0.055307586145188124, 0.12436944352728979, 0.12342404068580695, 0.09264552260615996, 0.08233822283468076, 0.09305237220334155, 0.13455888176602976, 0.14228465434695992, 0.11364846131099121, 0.0948270330471652, 0.08252031449228525, 0.19313740703676427, 0.14472837107522146, 0.08222108733441148, 0.11624960494892937, 0.12211570303354945, 0.11902720161846705, 0.1234141747866358, 0.16865829271929605, 0.1486199051141739, 0.1447557567485741, 0.08803330973855086, 0.14887788412826403, 0.07219261795814548, 0.08639462731246438, 0.18172184244862624, 0.09127679533724274, 0.09929545077362231, 0.09315636448029961, 0.11966296178953988, 0.12381366906421525, 0.08754932428044931, 0.2186215945652553, 0.2219533643552235, 0.08840820033635412, 0.1316447774214404, 0.15669745739017213, 0.09755511023104191, 0.13387105081762585, 0.15420331193932466, 0.08352807470198188, 0.08490643716816391, 0.1270210226731641, 0.15143277203398092, 0.11946902291050979, 0.2172397037169763, 0.14342810798968586, 0.07965709348874432, 0.11309529242238828, 0.1687391876642193, 0.11761867148535592, 0.14767288735934667, 0.08457772766372987, 0.06771991189037051, 0.10525162438196795, 0.08877068731401648, 0.09419041113661868, 0.07929842666323696, 0.19041264110377856, 0.1111420343763062, 0.09205750415899924, 0.11766352265008859, 0.18386336682098253, 0.08903905469924212, 0.11978163756430149, 0.10571017156222037, 0.08681680501571723, 0.08835892512329988, 0.08219297562858888, 0.12082481730197157, 0.09895943344703742, 0.12410249428025313, 0.12228620531303541, 0.11545835169298307, 0.08164556750229426, 0.18587573883788927, 0.07901502972734825, 0.11431250960699149, 0.11819888677980218, 0.14469669706055097, 0.1123899281291025, 0.17202578059264592, 0.19653893022664956, 0.13063456091497624, 0.08887835725077561, 0.08161387991692338, 0.10965440741607121, 0.0990366575175098, 0.17324508087975637], [0.05081666141216244, 0.032971665396222045, 0.049057270998933485, 0.04229384088622672, 0.06699174203510795, 0.036844102067074606, 0.021416454908571074, 0.038645483619932613, 0.05133332511676209, 0.03029322304895946, 0.013791787438094616, 0.03944670794797795, 0.027003736168678318, 0.026704768550449183, 0.02773054556122848, 0.05717300104775599, 0.01627676248816507, 0.08528440831495182, 0.043249727093747685, 0.022655566721888523, 0.03657569736242294, 0.027393888715388517, 0.05449533562308975, 0.0867876483659659, 0.016987270076892207, 0.05686565861105919, 0.06166836339980364, 0.016331376075478535, 0.02165970462374389, 0.029682921511786323, 0.017630989463733773, 0.022835729643702507, 0.009411460520433528, 0.04525913730529802, 0.02364113544380026, 0.031373722212655206, 0.0415815216089998, 0.012470952867131149, 0.07420802302658558, 0.04212991700374654, 0.05696574931166001, 0.05509776615404657, 0.025837286974170377, 0.021205048841823424, 0.015091880889875548, 0.024733371566981077, 0.05242602773276823, 0.0677827170916966, 0.013332862822738076, 0.06853537527578217, 0.03607860260776111, 0.0034541096538305283, 0.08697874418326787, 0.029994124812739234, 0.03367781339745436, 0.027926363982260227, 0.01473035743193967, 0.010974493925459683, 0.01122189118593399, 0.05765339705560889, 0.04196548082732728, 0.05729248427918979, 0.024570351832413247, 0.007639568947654749, 0.07478511705994606, 0.01599247327872685, 0.03490143934530871, 0.004975888977891633, 0.0501729284546205, 0.05927888876093285, 0.04122836109516876, 0.032545837174568854, 0.03677537325503571, 0.01449144525187356, 0.016480909926550727, 0.028204122292143956, 0.09253915545663663, 0.013563234791425722, 0.02935400844684669, 0.03496406473485487, 0.010569344058499804, 0.04107436418001141, 0.03915361135399767, 0.047906234727374146, 0.08833639097533055, 0.01144055588104363, 0.04834361840039492, 0.03065254126808473, 0.06033696234226227, 0.07909166347235441, 0.04527881142816373, 0.009928833294127668, 0.0639567906036973, 0.012653609405138662, 0.012939952879345842, 0.026960235288632766, 0.02746983544368829, 0.03501483951030033, 0.043520611843892505, 0.029736111871898174, 0.018845870791535293, 0.027630661813808337, 0.016050394724256227, 0.00779299165255257, 0.019685166023139442, 0.05748476753277438, 0.04403312291417803, 0.05502571252041629, 0.029081298437501703, 0.013693902824473168, 0.06069547989006553, 0.022036071035212705, 0.04973772627168468, 0.0420380671109472, 0.022619366878643632, 0.0665995759357299, 0.02441562549211085, 0.04462023890976395, 0.014620565376909716, 0.04231607308611274, 0.01661393671695675, 0.04739627155608364, 0.048727587796747684, 0.05939934229744332, 0.042912033785666735, 0.029070333311600343, 0.04282944928854704, 0.02298895811795124, 0.01416314541295703, 0.02728255299319114, 0.021926021136875664, 0.04303452292723315, 0.05611230832125459, 0.0605869549991829, 0.02573186468466052, 0.024289316198389446, 0.04304555929931147, 0.06121221823351724, 0.027559229039720128, 0.04594884779570358, 0.011221037928148039, 0.07772193197160959, 0.015956229330705743, 0.04405172834438937, 0.020158917476822222, 0.021694347229120985, 0.02797640085087291, 0.05806427036545106, 0.03771885584241577, 0.03938059488843594, 0.052688641141035726, 0.09179485003863062, 0.029471808911434243, 0.03479585590373192, 0.0053564873274548775, 0.051421670376190116, 0.05455042588125382, 0.07042134978941508, 0.028026430934135402, 0.0361829273668783, 0.0514897036898349, 0.019014515581407716, 0.08174879303468124, 0.0073158483719453216, 0.01793236079226647, 0.05121746526232787, 0.027725020589839135, 0.01734123465472034, 0.01637810169320021, 0.017300753255507777, 0.06129413776631866, 0.014171256450936198, 0.01030151526044522, 0.023504358051078658, 0.059037974902561734, 0.04166013328358531, 0.06590026417481047, 0.03198898044813957, 0.015999278984963894, 0.09278610827667372, 0.011904420231335928, 0.007540697913749942, 0.04335187714813011, 0.0225552724607821, 0.028933835814573934, 0.03772432144199099, 0.06492373693202223, 0.03058001944529159, 0.01650629561793591, 0.023254921792873313, 0.03702609533710139, 0.03657395013474992, 0.034620213721479685, 0.08054565545171499, 0.02251009559924049, 0.017203137511387467, 0.11448199408394949, 0.060240332170256546, 0.029159519954451492, 0.0581127991899848, 0.058796708205980916, 0.05305775740583028, 0.10979993960687093, 0.03701595802392278, 0.04972303259585585, 0.02078325959986874, 0.07203788483249289, 0.04461188953635948, 0.025250223565048406, 0.07740933767386846, 0.023333217948675156, 0.04786720878577658, 0.025825611082836986, 0.034606313931622674, 0.0751011718862823, 0.017349673934014778, 0.048975704304341755, 0.021082422296915735, 0.023475918952109556, 0.012345332286453672, 0.050301897605615, 0.046168917058301825, 0.04607365074168358, 0.032532181657318554, 0.04324599175847002, 0.03776601741888693, 0.04472832275288446, 0.04221107318465199, 0.010714498814195395, 0.026363747028101767, 0.031198656785168817, 0.05502431813095297, 0.03052810812368989, 0.021912827023438046, 0.016469792130270174, 0.0378821554726788, 0.09251044663999762, 0.05132312334275671, 0.03537703471790467, 0.028905466265444244, 0.07100136830870594, 0.12038488233728067, 0.016768785193562508, 0.04911271409530725, 0.017546717110755186, 0.05265619020376887, 0.0029766716345745537, 0.009916830857816552, 0.01228817249648273, 0.04439979645290545, 0.02650481106580368, 0.020346584995942454, 0.06662234078560557, 0.008776294067502022, 0.042675157210656574, 0.053406113891729286, 0.021279764029064348, 0.059465648739465644, 0.04924200215776052, 0.018209577970472828, 0.061461674847773144, 0.040226843407643695, 0.038954498645450385, 0.01389327846534018, 0.027320472922708307, 0.07077491403158222, 0.021513171593791673, 0.025465694056557756, 0.025146445026621222, 0.008479695384656745, 0.051509856179888756, 0.014617076010576316, 0.026207073292295848, 0.05495422885620168, 0.05640137102454901, 0.013955632440878876, 0.05865902666534696, 0.014384555630385876, 0.03427965360294495, 0.018293429631739855, 0.005305096781479993, 0.018397281112681543, 0.026489089409421598, 0.046052124218216965, 0.012254101556858845, 0.016838608143318976, 0.058689357180680544, 0.015979855920055082, 0.04825103229710034, 0.04460518221770014, 0.04627463620688234, 0.023617934635175124, 0.012768776305685086, 0.0196497685475541, 0.03363973740488291, 0.04752661134781582, 0.009712483251600392, 0.04486146828691874, 0.04507327638566494, 0.016288747112931948, 0.011377449579803007, 0.040791024919599295, 0.06640463282487222, 0.047375929076224566, 0.013316470264856304, 0.03472390744302954, 0.025092669430055788, 0.04588099090116365, 0.03905453845592482, 0.040341241019112725, 0.017147835211030076, 0.015562410998557295, 0.04684415439675961, 0.035738724416920116, 0.05854769942483731, 0.12300284685833113, 0.0020091258629690856, 0.015439314568149192, 0.053104043672127385, 0.04569141160962837, 0.07064271505389895, 0.02969223101224218, 0.05625369466309037, 0.003503726254816034, 0.033539829908737114, 0.04654993482732347, 0.07496135296033961, 0.04891141989667501, 0.04186236046786819, 0.020565083449972526, 0.025185347135577883, 0.10475131337131773, 0.03999684378504753, 0.017476829700171947, 0.03621284058317542, 0.01448408653959632, 0.037950483949056694, 0.028405051778203676, 0.0184236082714051, 0.0612402485151376, 0.040207908887948306, 0.01598547419000949, 0.0615268074242132, 0.10176607820072345, 0.03310239195291485, 0.08511320714439664, 0.02290758989485247, 0.029725513154906884, 0.02329743540446673, 0.04404075304046273, 0.008491312752344778, 0.03694399259984493, 0.1916685958525964, 0.09656332273568426, 0.11117028178913252, 0.1472321381526334, 0.19824068248271942, 0.12746785155364446, 0.06848790496587753, 0.09986756435994591, 0.1770504681127412, 0.10106291236089808, 0.11021436165486063, 0.07670776639133692, 0.11183642675834042, 0.06813259688871247, 0.1268458113606487, 0.15379586523132666, 0.040785053811435185, 0.1392340287566185, 0.19917605657662663, 0.07254786496715886, 0.2250473890453577, 0.12717552509691032, 0.1546440204339368, 0.16281250997313432, 0.10332014052463429, 0.11222598728324686, 0.18189663306943007, 0.09668847851987396, 0.17838920413383416, 0.11730089996542249, 0.15462826485080378, 0.18618417371596607, 0.10485937685838767, 0.1208230938230242, 0.10921426210552454, 0.11020325403660536, 0.21315735206007957, 0.11244691149996859, 0.12297575974038669, 0.10887155442365579, 0.1460401149732726, 0.09401079613183226, 0.09141981016312327, 0.07943829987198114, 0.19598288434956754, 0.11446174659899302, 0.09153464542967932, 0.12124765318419252, 0.09450053556689195, 0.13753006447638783, 0.17245641962758132, 0.08677109211151089, 0.1312768350222281, 0.14937617310455867, 0.10700100979634694, 0.15860595926642418, 0.11585473828017712, 0.20567986901317323, 0.1012337946199945, 0.1641543943967138, 0.18040081619152, 0.12751579683806213, 0.22461210883089475, 0.10747718531638384, 0.23978537321090698, 0.26882488067661015, 0.08802990349275724, 0.17493962709392818, 0.17033006729824202, 0.13255879123296055, 0.08594673313200474, 0.09435188890035663, 0.13295398359852179, 0.15676432023090975, 0.10543299000710249, 0.12409486754664353, 0.28574311999338015, 0.08785442755158458, 0.08717606895204101, 0.08408648188092879, 0.09780421400708811, 0.15400736459663936, 0.14274190552532673, 0.08671171351202897, 0.12999778294137546, 0.12513457318501814, 0.17067290390176432, 0.1097163101658225, 0.13233851162450655, 0.21025145798921585, 0.09471193315195185, 0.0830717191898397, 0.17662508093885013, 0.09816969332418271, 0.09696871348257576, 0.08694569952785969, 0.10653721075505018, 0.22080475384635584, 0.135176864319614, 0.1120521601821695, 0.07399411486195666, 0.10337548184075526, 0.14098565333655902, 0.08800600548940045, 0.12216051348618098, 0.15418845202241624, 0.1322004840310131, 0.1828475184738636, 0.14338997432163783, 0.15398960054985114, 0.1293224777494158, 0.11312081212443964, 0.07816802124891963, 0.07172900890665394, 0.21038263237902097, 0.2401825061866215, 0.09821551479399204, 0.08997816752110209, 0.07748556429786341, 0.15516232619328157, 0.06242101479853902, 0.2102086152881384, 0.1255662435931819, 0.1467534452676773, 0.13903113321534225, 0.13558884364153656, 0.17264406170163835, 0.2197287194430828, 0.08766261927251305, 0.12424042687884398, 0.11912719053881508, 0.12787700816988945, 0.10721738782844373, 0.0952468765899539, 0.14177719157721314, 0.06218180406306471, 0.09497488582772867, 0.10126700890915734, 0.1253330446779728, 0.3036304701651846, 0.15404661106211798, 0.12012372777930327, 0.07785246853849717, 0.0943534088187984, 0.1986268503325326, 0.08182761844779764, 0.22084201898958, 0.12704934472484247, 0.18383865457560333, 0.13156226756317274, 0.13621217305106775, 0.15554142370820045, 0.2012876711253609, 0.09783502628228494, 0.10169182611363274, 0.23118553896035465, 0.12665218460772718, 0.1132230469956994, 0.07639914152345487, 0.12439536356500216, 0.20593588027570928, 0.08322693407535553, 0.13456440504108155, 0.11774725387138979, 0.08166027814149857, 0.0927764323673078, 0.14672536748860562, 0.2075975989656789, 0.0812723393152867, 0.11496042912559849, 0.14051458718521254, 0.0693980036303401, 0.09076501029942717, 0.10288482638342039, 0.13375818330262387, 0.06719013210386038], [0.04204829263367823, 0.027183419026966606, 0.0316789069079927, 0.01394488274984594, 0.05124900017731956, 0.06025695627821343, 0.03026326233521104, 0.014130796255942966, 0.020305123113627945, 0.00782795062488211, 0.01087658217043749, 0.030628592374601533, 0.06284491598073925, 0.039072251612586636, 0.034595067213688574, 0.01514062175660261, 0.010692266614309378, 0.02595211545537625, 0.01856687245890498, 0.03383764571377209, 0.04738592728972435, 0.026736261057002202, 0.02074684262541788, 0.03334672223510487, 0.029346646341894354, 0.03614825762010046, 0.06473373355610029, 0.012754710274748504, 0.05530423078952091, 0.014148446648115558, 0.04963293332340462, 0.019648419959204536, 0.016853836165474992, 0.06354204964424882, 0.025075794264142002, 0.05107145131166492, 0.03756030934995838, 0.04307078044595463, 0.032334409055433104, 0.028563511757446185, 0.020587341094921743, 0.022055863901706677, 0.012101957890471178, 0.019769404449367096, 0.10496748105755874, 0.08728332498243876, 0.02823364535080535, 0.03459202737680503, 0.01914485028412725, 0.05974808894097805, 0.02386620720582349, 0.026151675997035842, 0.020868673588016202, 0.03496616819341268, 0.023082570505461524, 0.03109446434038026, 0.04448550221111093, 0.05839750569845949, 0.05602809534009014, 0.04604450426995754, 0.01930325767690582, 0.04334944120741316, 0.05637963415522661, 0.03394611971452832, 0.03882281196170619, 0.017085521947592497, 0.04254192007439477, 0.013014015824800091, 0.0439741989331586, 0.023385314171069434, 0.0506005581867482, 0.03762532996812037, 0.0124087880332289, 0.019138809626123736, 0.07085029927215405, 0.011436174241160708, 0.08043430106980459, 0.035514902855668745, 0.04355849106130855, 0.03250734727563603, 0.010334225737356713, 0.06074883309858186, 0.03010226633133633, 0.022082303018708314, 0.04293071385473013, 0.0317288131586143, 0.036923589051834176, 0.022015240010140196, 0.02428069371463997, 0.017888444309521998, 0.03073399600439838, 0.04301441114928041, 0.012258098128118684, 0.04805838602728077, 0.03621923916840127, 0.07766883660640035, 0.0849226066576583, 0.06787796305226428, 0.012679145222396722, 0.038583082146942616, 0.0372745477195297, 0.060738594005150456, 0.016350373359663144, 0.04148912549551044, 0.05064434405150158, 0.024691880846928273, 0.06771432076181684, 0.01912242639809847, 0.09104525883282934, 0.020083165827340314, 0.0351123483851552, 0.018548762359257256, 0.023521696317142675, 0.01826741629546242, 0.02154194826393255, 0.07468698732554913, 0.03410089694495712, 0.06069033659462418, 0.013703183487190731, 0.042086076856191666, 0.01787875822213079, 0.0601819713733026, 0.03811399731785059, 0.010741412905710084, 0.03178453106167061, 0.05136798129283956, 0.04081779991143516, 0.03230401407927275, 0.03147357203332441, 0.01961034057395799, 0.04068572646273034, 0.06471662768828017, 0.021600342987637435, 0.06768460092800004, 0.0312094590626657, 0.03361666721424886, 0.034995623398572206, 0.03446019480803183, 0.025740120759499923, 0.05664070389632668, 0.03167284759027617, 0.022976781807041595, 0.02642675578993346, 0.014330006503899182, 0.030015356173472743, 0.01788055125091757, 0.024142294623223797, 0.062192450277507305, 0.05516736688358443, 0.03099432953500322, 0.025685795549569384, 0.034145042433270385, 0.059215656082545004, 0.015622778562828898, 0.03000836047743048, 0.041082096086548905, 0.032960048876702785, 0.025127615679853728, 0.03413646914330976, 0.06636703519948892, 0.013866343169606157, 0.045227656673107824, 0.038995994454515834, 0.0059296547634793174, 0.023625559672447186, 0.04661113529333046, 0.004600669290604336, 0.08730792866221496, 0.02443642259043242, 0.020124030598838414, 0.03198520440076079, 0.05007340433076024, 0.05649730909083571, 0.04323077221800174, 0.05040631735963481, 0.03974595206922718, 0.019683527361069406, 0.024513171686391746, 0.03789935972807663, 0.02851203130558133, 0.06328633693712098, 0.0035740661634398358, 0.04956184320950082, 0.011500120229486908, 0.019853826080049788, 0.07856763766280242, 0.02545153133438102, 0.025875899009406567, 0.09568654014063732, 0.010158962686546147, 0.005937528738286346, 0.042273847851902246, 0.0019888872837847365, 0.022552478592842817, 0.06402399271194424, 0.03537263102563364, 0.037118949461728334, 0.023789349544261183, 0.026137489526133453, 0.05788810231855937, 0.04075795651546546, 0.018327809304797223, 0.02358228779797043, 0.025042870048699633, 0.03998476925439068, 0.020070368656888604, 0.031695727791104994, 0.015291879086622169, 0.03455392424283283, 0.02738893371341484, 0.041864487675151656, 0.038380050898662636, 0.030214275499539714, 0.054385884531906674, 0.019887108222714493, 0.04812448212344732, 0.05568981849189315, 0.023488617734983563, 0.035539489572069476, 0.003908179351128638, 0.020825486530416777, 0.025594949888597642, 0.05854495135801179, 0.03704358457720705, 0.025667274936235378, 0.0299309362391276, 0.048711632045784166, 0.03052369425339358, 0.07431311453027384, 0.017140931117215326, 0.01543551477204476, 0.019709949514695575, 0.04806729519207563, 0.06309872878981487, 0.06269778923264571, 0.03367784053885511, 0.029542478333626474, 0.07866391499659844, 0.04241797886788845, 0.02452081368703927, 0.09817701471703393, 0.013773462751747241, 0.11158198969704763, 0.041403100825846195, 0.005965086589899978, 0.07497919843133007, 0.04565101841996823, 0.018659536593726704, 0.04935763809563858, 0.030919819604605436, 0.055439551028289964, 0.006201969950260329, 0.03135842124798468, 0.03248920324923737, 0.05687677640733974, 0.008510184507550938, 0.018965316703543067, 0.02814665207240198, 0.02510211633385292, 0.003122278888310705, 0.051075556448527744, 0.03807904597904001, 0.014484069576220853, 0.029785390477627516, 0.010006316904244679, 0.030249257372426133, 0.004291756045339363, 0.054227582312055995, 0.04725576391709702, 0.043688627292535136, 0.06616546958684921, 0.05399939777063472, 0.04685260894309197, 0.02602038286360247, 0.0634406018736107, 0.018762651864173155, 0.041329225325690847, 0.06521253500665937, 0.020347825018689036, 0.07400105627519743, 0.03098698778610144, 0.02237003918604127, 0.03977065413658108, 0.036968579316245656, 0.03257284626098616, 0.029695606723959957, 0.020003802675221647, 0.015632283142102615, 0.03102539965350713, 0.07429026147084576, 0.004401595597820622, 0.056878255613680394, 0.03357752252902303, 0.044111300326351605, 0.05297455544184361, 0.05453108084787216, 0.03816098926056709, 0.028803424776664803, 0.033746888262352774, 0.02658545664910759, 0.06273104423390967, 0.027271821961871216, 0.04134599871135183, 0.020462466902764778, 0.03283249447122216, 0.08118837060672895, 0.0546038028384958, 0.040261916882757626, 0.05440647806972265, 0.040291266914989264, 0.031975786334701946, 0.010501278514441634, 0.046473212872764895, 0.04804206047473209, 0.01206462234923882, 0.04924821414585624, 0.009623981080949306, 0.01628714407395039, 0.04630524152889848, 0.05558643689645188, 0.052311721723526716, 0.029320926472012485, 0.02998383143650634, 0.0456949094576495, 0.030933183351797715, 0.04057716764509678, 0.011441761977039278, 0.02052835943842573, 0.02115238265001348, 0.0632255809115512, 0.019302224607339928, 0.08321902914238827, 0.022373019651110684, 0.020878955089886273, 0.045456061738410165, 0.05316827718966773, 0.038282243468399556, 0.05042706696050508, 0.03801662075732436, 0.04147584656519549, 0.042784133327326605, 0.03651162330061197, 0.021731291764548848, 0.08395347544657332, 0.027892622132120386, 0.023079150688967535, 0.047208646445402076, 0.0756535604596138, 0.03761126393718379, 0.02109395569589521, 0.01827984027165387, 0.12112287059426308, 0.1406375648719924, 0.20470238503600868, 0.18478438311389514, 0.1953992356679269, 0.1670485498117549, 0.2385818963604314, 0.16234242091221468, 0.060260986776224205, 0.08913046015160424, 0.17294542624482087, 0.12115043268672057, 0.14082057933722222, 0.17113121359476022, 0.22159887052008084, 0.12910747714340687, 0.09588858751314026, 0.11865845854793276, 0.08250725947852645, 0.10771026209528957, 0.11070707307330199, 0.189644919442279, 0.10858531442603894, 0.1272993441671133, 0.20320992012109074, 0.13465237032089913, 0.13303752483001777, 0.17736013792455196, 0.10288032091089658, 0.1512499339878559, 0.047887242532202175, 0.10506877955049276, 0.08743731850492102, 0.07306911556848458, 0.10750151758215257, 0.12392660443271909, 0.18214425763913564, 0.07655101123132876, 0.17735492677560874, 0.09365995960044009, 0.10246541710304362, 0.15982110691922052, 0.1396705846169165, 0.12225944389189992, 0.13362464761095388, 0.16779615969530173, 0.12300675522003855, 0.17244770723794187, 0.13453150966337749, 0.15547819781516278, 0.15997091388063772, 0.08365787845104933, 0.10799893803362336, 0.16020646052701132, 0.09372348404888596, 0.12710222974419594, 0.10964136597301279, 0.0892349545444761, 0.1571244459067072, 0.14252524929387228, 0.13646393668438705, 0.12113976611622743, 0.16321866746459687, 0.18420810332255705, 0.13993624464741775, 0.11701807299894945, 0.09610463984842811, 0.2628513297864369, 0.10420211391257388, 0.09056022164544889, 0.11916244721838407, 0.18663751653262547, 0.08402862998523883, 0.17223979053752764, 0.19727113736527307, 0.11547664499708585, 0.1179132235369512, 0.15017092760120118, 0.20236363767513207, 0.17441463097929955, 0.056424641383013556, 0.14760550883199486, 0.12474039862198488, 0.09072112943977118, 0.0760181848225849, 0.13725798550461019, 0.09068207974944796, 0.10199414739119154, 0.10490864528609173, 0.10917097835668496, 0.08446553868374654, 0.07930084903325353, 0.14885944154645714, 0.14481105735259397, 0.2638305372425488, 0.15083313706730092, 0.1954208809350218, 0.24533787955130848, 0.1696820663554328, 0.13246872249458516, 0.09997112237449203, 0.12196798595998969, 0.22350513323077134, 0.0873577602739845, 0.14233463523643358, 0.07003235923392431, 0.1037090089438217, 0.11942383247826781, 0.1272074162427868, 0.19132147090775625, 0.08514046389609575, 0.15436591607119354, 0.12113007663616113, 0.13064582459628582, 0.24970175538744244, 0.10129239968955517, 0.17640739333416733, 0.12196713100586619, 0.17960789373942784, 0.12106379733553954, 0.11127628252974578, 0.1904865742794105, 0.1158401904893773, 0.10518200668905463, 0.08976164021130119, 0.11573070207876818, 0.10359546967915126, 0.11533751817686216, 0.1047880763986281, 0.13129963379885468, 0.12471076021237032, 0.12045835410909993, 0.12291266955435276, 0.11178633051791362, 0.1362406172390495, 0.09596514661929437, 0.041933945912335596, 0.08666193618306092, 0.11995998370860304, 0.12183611946446554, 0.14179676052715096, 0.1304273498909814, 0.12156401335128716, 0.10690288684730019, 0.19522181233125074, 0.11964242931987558, 0.11467880995145865, 0.10977523414684193, 0.1216554120182991, 0.1601281033030578, 0.07233756660882916, 0.11626652761229447, 0.11636872855680329, 0.14509587921202183, 0.10982393939048052, 0.13383466776992592, 0.12340791869376387, 0.07866286326731954, 0.10656011131192956, 0.1265070323965379, 0.1247483239110027, 0.12664314652127878, 0.1495614538767508, 0.10879434392388378, 0.12200383975037507, 0.12442008938108172, 0.13086264367614472, 0.13016877376607486, 0.17552132159471512, 0.07406344078481197, 0.09850341041705438, 0.07171961119664566, 0.16708873265555926, 0.13151928915509156, 0.09469340236059257, 0.11510640914951052, 0.20004103944769927], [0.02175144255826516, 0.033049093027200015, 0.03497454810089298, 0.01631929136679641, 0.061864466805543215, 0.05428645879562412, 0.03568749163033707, 0.06596186836915356, 0.037177059200725386, 0.06667976520423378, 0.05185936278264437, 0.09981729848576443, 0.05317929320569549, 0.05541279299982956, 0.022823933312403302, 0.02690362511202693, 0.03242660500109196, 0.05751684188310589, 0.016925586154684424, 0.03448059496336749, 0.04842483225677695, 0.03377525441880737, 0.022512568859383464, 0.03648988303861447, 0.12690930866769382, 0.006429606998738433, 0.006969110192065793, 0.04011163155415228, 0.027859253476240804, 0.02936627296730876, 0.004886929644271731, 0.01207865190891815, 0.04488286928140691, 0.04011578079579132, 0.044596147523926835, 0.014539207331836224, 0.05060679053089448, 0.04051844043923276, 0.016719421770955836, 0.01924952448877905, 0.024707695801875422, 0.04702786775305867, 0.04070430475154093, 0.020270292214783173, 0.03282679816974061, 0.009296559944881924, 0.008532582100347748, 0.025992707116529346, 0.07051354234239884, 0.036921977531164885, 0.06822487086589847, 0.04042538275410022, 0.04026379642475929, 0.020913338155618737, 0.05206068412267736, 0.025206651438825896, 0.044584083171295266, 0.048010484847639284, 0.025415200873145034, 0.013285216941897358, 0.05056470100368772, 0.03899669673826013, 0.006389745610899159, 0.024501463564644967, 0.05033195670694113, 0.05141793164823737, 0.001984089829160699, 0.03979944098474724, 0.047759827226400375, 0.018166650452518036, 0.04555202694609761, 0.02055641686144684, 0.03728216427511402, 0.028601642032819133, 0.008163487887941301, 0.050331335847399065, 0.03106974870232599, 0.024452341021969914, 0.021885383674608808, 0.028253087075427175, 0.0632441049175603, 0.024154218179838996, 0.05358262799148049, 0.031496496338929446, 0.058451306740088124, 0.0396826888567635, 0.029318887474281446, 0.04646538257864969, 0.017036879468443136, 0.025360046154154197, 0.051109004832272015, 0.054600966562117846, 0.029319722072354386, 0.057906463476164, 0.012426711535746498, 0.016349991683715155, 0.04057540684672339, 0.04460940270551613, 0.00708594374425177, 0.007527435946810458, 0.02703966459791575, 0.063687052577734, 0.016011662249054228, 0.06463510849113975, 0.051392988700951846, 0.034893605658518415, 0.01769482094927558, 0.030730352271348238, 0.09232823963143996, 0.009516621573961206, 0.029076528336320604, 0.03172496925773365, 0.0215527675048049, 0.04344914175037827, 0.049242385530046055, 0.03671183862856456, 0.040690472815185785, 0.04564149857365659, 0.037769898639193604, 0.01501944218762219, 0.05036286397704056, 0.06105834684733834, 0.03322038919265781, 0.09668744036129542, 0.03417854509981615, 0.08232735948903219, 0.05318815826571413, 0.007717725155608994, 0.013433850885901068, 0.046996553361948044, 0.06237422302365303, 0.037033735641411374, 0.0048481178652894285, 0.04011901740783027, 0.019175723627475754, 0.031188078424228088, 0.02044325927272439, 0.06575665902346373, 0.060085958668163846, 0.040011344078396044, 0.043809192787323675, 0.07322856451251678, 0.04339726096285241, 0.031237672548741102, 0.08956923482141324, 0.013830377420942699, 0.03934841197250145, 0.036941560051803074, 0.02129526685790292, 0.023580591460423808, 0.0810548620564597, 0.050911551141845326, 0.022871200061802353, 0.019673225503148775, 0.04587345576978155, 0.06879409389304263, 0.058852300580058775, 0.03624650609812566, 0.030962984609816755, 0.03604151388364179, 0.03776120999827981, 0.02914639369451574, 0.00892472021015627, 0.033092590514570475, 0.05729003476777247, 0.0450363980074014, 0.1622770915606192, 0.04743842893679227, 0.020101499843544195, 0.0311653814278543, 0.05205866887367197, 0.07287634376968656, 0.0702949319300907, 0.03136221765141402, 0.014864563176940595, 0.007609655731357634, 0.040417287831327746, 0.034668725582637956, 0.052689370566180775, 0.056080851437790055, 0.058193612710705826, 0.060467872103410106, 0.041760074706482034, 0.027250480339197174, 0.011669111072218843, 0.047657548250364404, 0.0019267570127600006, 0.022711237127493535, 0.036350664616163285, 0.0696698993976627, 0.029846312744276862, 0.050914187250392776, 0.06118534146142857, 0.014389074673610074, 0.019972337310069373, 0.02350548272287207, 0.029961694231522933, 0.05310233376388039, 0.04082332657916205, 0.024446069662060057, 0.02147858666389116, 0.02990067357729588, 0.05000915384984442, 0.030409510380455425, 0.04916934123528855, 0.009109607432037592, 0.01088543959693717, 0.04930601515141981, 0.011932700722744423, 0.044919713732919524, 0.03958207229152322, 0.007172395042808992, 0.048255201894789934, 0.015040168039766806, 0.02696153468319348, 0.05755327921360731, 0.019598410231992602, 0.046790119260549545, 0.030202777723648717, 0.04325364224080529, 0.01860422920435667, 0.0336769923700818, 0.03346298581787518, 0.06328242857541357, 0.05402070377022028, 0.020559909620455334, 0.06489813580576863, 0.04742061739255275, 0.04128115111961961, 0.042454612973545275, 0.013733163708820939, 0.02147068681993655, 0.07086494884320668, 0.038780535837369304, 0.06017525387661798, 0.01635798821890993, 0.016322185318650942, 0.02539151151930647, 0.03577008291280695, 0.03537100932693907, 0.05680464134950723, 0.043258646436567814, 0.07846157585403749, 0.05103909536930067, 0.04095833469182253, 0.02252337961856808, 0.05220061500689813, 0.011088330897369554, 0.030320951382496526, 0.0015455454371736518, 0.03242354480815785, 0.06990408218864884, 0.10050844747040953, 0.03286322192954166, 0.0337692154571414, 0.019736553176439235, 0.02036977732287986, 0.051724415738135576, 0.015223148578245724, 0.003989112039562315, 0.05075093511758106, 0.012312456416631383, 0.05810962364609752, 0.0498964084711458, 0.06795548567814486, 0.035754103413117785, 0.02214365785143205, 0.05471236165612936, 0.007533624186180532, 0.0004036866167942727, 0.014926588062995245, 0.04329519233267222, 0.048597366748643775, 0.023854541492515376, 0.016763138085869805, 0.03886210253196103, 0.06850273774138518, 0.008455040814754154, 0.03870546950825623, 0.01311183428125722, 0.060800510325602124, 0.0337012364262981, 0.02466283445911748, 0.048417602466153245, 0.06485234826271023, 0.015226929714637143, 0.004767074066746447, 0.011263050271996429, 0.005012207564764789, 0.0582818290484803, 0.09366743027099542, 0.045226910284587314, 0.07007028934146677, 0.04474948965279119, 0.007244238330583487, 0.030246987672788755, 0.03151943421523486, 0.053145987314305136, 0.05662555220936026, 0.041779982923929176, 0.009618305135518312, 0.08611621082361255, 0.03587385805855904, 0.05164416540148003, 0.05705575019653354, 0.01640996230500085, 0.03813295897894672, 0.06111207325011492, 0.009087934175373187, 0.026286885973864367, 0.015499342864911472, 0.024805798394871608, 0.05327926516266806, 0.07322621678135224, 0.07291090155818633, 0.04734214481764606, 0.05719927392367806, 0.07282402871974877, 0.06802211781697613, 0.035556843105171404, 0.010588616149366965, 0.019656343551884805, 0.00699237673377086, 0.030085642223379443, 0.03702437864350421, 0.032643685316933055, 0.03290429026154535, 0.057561591267585754, 0.02402649414060371, 0.02580399634981794, 0.04634676787203976, 0.05253616753699524, 0.012016496404872408, 0.047227180629436455, 0.011574719217605889, 0.01934132688412709, 0.03929036330165608, 0.02455500337029142, 0.010423265647010078, 0.02899155200326017, 0.05500350746193102, 0.04547278084126966, 0.14244142307766847, 0.03758137446961232, 0.016205994678395133, 0.06369282691074268, 0.09604531553174768, 0.022248349019459317, 0.06396346060293061, 0.062251075703118525, 0.0012978377469283129, 0.03481226966583303, 0.1145076427076544, 0.1186703871935606, 0.14905612170696259, 0.1436742940651519, 0.12826892999666079, 0.1660496105573007, 0.12289561118398394, 0.12290171799915177, 0.20019847314272607, 0.16609618520098074, 0.1679446774401835, 0.18199042017970765, 0.1452524715236255, 0.12249779967325074, 0.12410647049546242, 0.14661344992262976, 0.1274004458848919, 0.12487899618489401, 0.1709135938435793, 0.09200647154024669, 0.11533818314118044, 0.13562081621161529, 0.2002424422119345, 0.11450275725552014, 0.21760635689965316, 0.08053383537169014, 0.10091431319181408, 0.11135385943842785, 0.09722269592540604, 0.09294488547103745, 0.1052911083347031, 0.12231663082327161, 0.10332669517291443, 0.16746253759733268, 0.07563882946435894, 0.08710898898009743, 0.18659528451306479, 0.06458421836474112, 0.11648349596985749, 0.21395228297582694, 0.07183207159063645, 0.2074517003659691, 0.13322333485952445, 0.1389820072799921, 0.11381266678550414, 0.2149983804140772, 0.061655532302601, 0.0847783772540944, 0.214846972110016, 0.05925064134810652, 0.13224533519574574, 0.21145220712891646, 0.13595845523689473, 0.1115038428189499, 0.14262673099126133, 0.07651046876396451, 0.14930586330592632, 0.10901799585138049, 0.133953723524298, 0.09688029358429567, 0.203837035756026, 0.10607324207999877, 0.09050487354397774, 0.11623159662953444, 0.1270163950643369, 0.12743819957332952, 0.20193728698151453, 0.1464764265609639, 0.08259956738246338, 0.15147482763443673, 0.10408330243080854, 0.07573310511984996, 0.11006491431700331, 0.14263043579246315, 0.07442792265542916, 0.14633691976112978, 0.19742034721587384, 0.12154950627258845, 0.15123309274869307, 0.07320713637662785, 0.15904369577765465, 0.09416433503585202, 0.1190791909715959, 0.09554716904780694, 0.14625641836651734, 0.17897654404597624, 0.11617601104080677, 0.13993494186018193, 0.09368377617959465, 0.11261341720819473, 0.1099566879815289, 0.18544959170477732, 0.08821698916809899, 0.07394393041197743, 0.10765974516315119, 0.091300856189004, 0.15170430817774364, 0.14986942735101494, 0.10420632761503969, 0.18383237134133065, 0.1282906024051564, 0.12216204697532312, 0.10662850085645914, 0.11901983272816453, 0.18771477229893208, 0.12869551139218466, 0.06563095362590891, 0.20460124260612897, 0.15365037375262805, 0.10346126902316298, 0.05058878899684974, 0.06891004195702927, 0.14542958273419312, 0.19051241289292062, 0.1064588874578476, 0.10823490537170853, 0.11730935451175485, 0.10074719680207116, 0.08001211658120155, 0.135243523599846, 0.18806671484240464, 0.08437958186758415, 0.17425909718232496, 0.10881428606808186, 0.0969571919579591, 0.17725245441709245, 0.16279868142945425, 0.10468386699046407, 0.10301842314324208, 0.15156899472432478, 0.09723252111247607, 0.10379141702183656, 0.09525906307888882, 0.0883105591471706, 0.09498711981411491, 0.209155637504799, 0.12405168557805674, 0.15867269997085842, 0.1340988621647869, 0.13059908710420132, 0.16370520421436854, 0.13163886059607777, 0.27264082591448513, 0.12913319362061365, 0.2220637212906565, 0.12618892160909517, 0.09110018624258892, 0.16570408695510455, 0.12378082796931267, 0.14550312235951424, 0.1128561698964664, 0.1038173981277006, 0.1037631288969091, 0.11527643645448343, 0.13368677427726133, 0.18056234823805944, 0.12823736454759324, 0.136537978425622, 0.09648795785116297, 0.16620370586003574, 0.09572345244565181, 0.10050201495843274, 0.13288455589541368, 0.1052366423287562, 0.13020248338580132, 0.12397393903562001, 0.4193637099649225, 0.1146385728248528, 0.0947484044092042, 0.1930425071290561, 0.1359170103179557, 0.09724672963576657, 0.11797900072165898, 0.16413786528365953, 0.10994514610086169, 0.11269845121673175], [0.012420603024241115, 0.03688630694523454, 0.01764233796192067, 0.015035942462938172, 0.009190082533418067, 0.02083999360911548, 0.0005871675218388971, 0.028952193579503467, 0.017418099101632833, 0.03772079645256911, 0.020329818395631652, 0.034713491930493286, 0.07669029411460672, 0.03308774238186223, 0.01350342871488205, 0.03196345396073801, 0.04154562032116311, 0.03611951826938561, 0.04261672856020076, 0.025387128183086003, 0.0352647168162678, 0.10753898628588233, 0.07756446434983186, 0.08704846365643398, 0.033501163590699434, 0.02476756803558341, 0.056264089819576056, 0.045107949525117874, 0.03996165156630533, 0.012200236054403442, 0.03127807591642652, 0.004276100122037211, 0.08185210677662066, 0.04382154891001327, 0.044495052591498406, 0.02417985492918108, 0.022225344985989586, 0.040484520473650525, 0.025602795449750762, 0.0074281094462743825, 0.024589669724394168, 0.0636730408295989, 0.041976846288889647, 0.06575650974575963, 0.047801543559346876, 0.00483702721040962, 0.03461886682946767, 0.04511268569954804, 0.03506147522213204, 0.023519918555393815, 0.01908194330254836, 0.07110092296664204, 0.06869584880769253, 0.01129500672686845, 0.01894801575690508, 0.08712841543768134, 0.08495869793530021, 0.05959018027143819, 0.036948148626834154, 0.01328761047417564, 0.005963115869755191, 0.033444051298179796, 0.03505072383476155, 0.025323249200092893, 0.017111543765557662, 0.015647319478115866, 0.1276750218655382, 0.05206798855215311, 0.06315668925110783, 0.05287600162306002, 0.02965214994869062, 0.04174087216545429, 0.03914924498115267, 0.01795558534961726, 0.04907605963359986, 0.04776786108102117, 0.030114479961672, 0.07061179421309914, 0.05364617279597691, 0.05562441450144563, 0.027284006754468595, 0.030133129496659552, 0.04848073336428829, 0.09704889596572944, 0.024695750192872117, 0.015179917415870088, 0.027713127567299774, 0.045262960850128105, 0.06277022284588643, 0.09980401955544949, 0.03995759392689381, 0.04754265870100685, 0.02360776000257049, 0.034118555818817446, 0.04377386146890266, 0.021548272210306356, 0.018457100759925585, 0.03732630976342729, 0.039896580058016946, 0.05206069430070264, 0.06671462154814176, 0.011954801456470574, 0.035067459900996516, 0.0350568747547056, 0.048258041563842974, 0.05867288913577795, 0.027281938918999264, 0.056760611212147136, 0.04951627279764839, 0.040151227465165515, 0.020797971935410584, 0.04565805822078671, 0.04269324695425374, 0.08608271833509207, 0.006291433520215962, 0.02676916491639401, 0.04336605853001986, 0.03660990909806319, 0.04820217777575765, 0.021033308235928416, 0.03476506398458566, 0.04116909106128982, 0.09010332330529179, 0.016741536923551133, 0.04159741289913654, 0.02083444658533803, 0.018233733817136714, 0.01823086022133274, 0.026250063574739864, 0.03556250547990203, 0.011474138275454087, 0.01244286830270929, 0.0024496939856492516, 0.02250144936676536, 0.029172812455466816, 0.012926899561924594, 0.017340715575431074, 0.03172433822016631, 0.017345645132341554, 0.03517166252381035, 0.06335594784468412, 0.043045606796762774, 0.04733880642535431, 0.020420484244823456, 0.021924399438181093, 0.021836464692439352, 0.03829548507928848, 0.04195569635235837, 0.030041703688246862, 0.018369698664173484, 0.06703651856098856, 0.042996165342628956, 0.06895760047648634, 0.05168552550354174, 0.04057146795094013, 0.0684070982305067, 0.03795166799266424, 0.08020068146288395, 0.02513492859101721, 0.0264644382321941, 0.016764618988548006, 0.06907576056463377, 0.04858616752816098, 0.04323901302580323, 0.021610230939196687, 0.04377120500430465, 0.014361258130520582, 0.003908622943397079, 0.048317630509180684, 0.06214514281600714, 0.015879297030291388, 0.030246587337127755, 0.04624253132247499, 0.04536976565473846, 0.0358909978531301, 0.014334759641704815, 0.034075713117739985, 0.06125785649887153, 0.01510124297679535, 0.04120171841766153, 0.020232278986700943, 0.02798763569444418, 0.029991539594318186, 0.0213003965826439, 0.05194984882005623, 0.017782667485464896, 0.0367643809877336, 0.05776633920946291, 0.0023881527678375797, 0.05935136987162488, 0.023889067050601755, 0.06105375995061227, 0.039581994259996076, 0.03615004216719951, 0.03657045567940388, 0.031226456364882842, 0.11933079175651073, 0.028433132949950438, 0.01956285838969052, 0.033770718412207704, 0.04208022449165583, 0.021216770534270575, 0.04294893251998084, 0.05927532645208495, 0.04149136805374708, 0.035233321000954936, 0.016029751992651393, 0.030646773720426217, 0.04367546710584845, 0.016744268027001193, 0.04738008510321379, 0.02239150633769376, 0.05971738523138421, 0.029566179561827863, 0.03526426898315549, 0.009196259746594089, 0.006383728701621294, 0.06515571448419775, 0.008149599124278342, 0.039769853465259075, 0.016205999767407775, 0.04333094095012971, 0.021440178189160566, 0.012419491074979305, 0.026968479489109347, 0.03661059441843203, 0.033077357403401814, 0.04552287708169647, 0.018218193668872118, 0.0218078746194286, 0.03026717748226864, 0.06460291200450488, 0.04267922502809337, 0.058050211119864664, 0.018941766449383328, 0.022575302814532603, 0.04356185659500105, 0.058263535744377544, 0.01189175367887531, 0.04958784467141543, 0.03728212356301291, 0.03581354308075138, 0.08483639199818883, 0.06791907548904419, 0.024286466351311122, 0.02734479501045176, 0.027974601036735942, 0.021768265137714998, 0.07210782822221518, 0.019890677316912582, 0.03267014139731016, 0.018406110549611703, 0.019375732002247657, 0.06523668406797306, 0.017238882736169865, 0.04076156292908958, 0.02592748124152422, 0.09082077909260988, 0.10895647986658982, 0.02553059932376657, 0.021106306729572158, 0.04275897324883512, 0.0985883426453386, 0.03722679581759231, 0.08916877023875713, 0.057716582236545425, 0.02945564959996513, 0.02528869141159313, 0.03142803554822292, 0.051210140476801565, 0.08007121019597564, 0.09156371386987822, 0.06561785111469881, 0.012297401420905121, 0.01640030675168548, 0.05934456416538783, 0.03195919954617109, 0.00917945328235094, 0.02464717217454953, 0.056424539602760754, 0.05274050496518612, 0.0312447021715343, 0.02334578102454543, 0.05401101089747889, 0.01351745318554874, 0.012021358956449797, 0.04546436022168823, 0.056833207673792324, 0.055565772112458944, 0.0697548451966473, 0.018022811206589853, 0.03068003211436527, 0.017861438615779792, 0.05358848035601633, 0.026393434631505182, 0.015460503520444036, 0.015260479878634214, 0.07383239961096219, 0.015901346025722365, 0.04890073975548148, 0.0799223260421838, 0.04926856341106551, 0.002324880225517388, 0.01421777596364596, 0.06437760445156268, 0.03660933912864753, 0.02166388270312122, 0.03486297658777662, 0.0472717400241111, 0.06067626377833741, 0.05100266482414944, 0.010519922960416546, 0.07592175142573458, 0.04052895773202181, 0.03564867264192019, 0.07365730364939996, 0.028576834792537347, 0.03449369068922741, 0.03469866933301091, 0.014251922390290668, 0.007410187640094331, 0.024136437169675316, 0.003907630585932306, 0.06946212518960238, 0.01867512084676751, 0.020153696149853722, 0.010230887398522879, 0.040565880215061564, 0.057228783411639075, 0.04771065040092383, 0.037689363317830224, 0.05984091253152915, 0.014639742472874267, 0.07004151945667607, 0.02689049206674099, 0.006776477492946599, 0.04253445279651454, 0.06342917534389667, 0.011961747110555214, 0.026475074268611412, 0.031285027507692575, 0.07947481184133462, 0.010676208234924291, 0.033735532978815694, 0.059307624718972614, 0.057160441364560804, 0.06268988429967846, 0.04554173356986471, 0.04311635085780706, 0.01447610866411456, 0.0377410812569516, 0.014585057639383843, 0.10504403337836266, 0.14095803696130002, 0.20303567232830183, 0.1287476093109165, 0.09889559008713279, 0.08859719948044845, 0.0963317658752203, 0.09489538866494383, 0.10498823744377919, 0.08543657657823392, 0.11944645483578954, 0.13444249943963119, 0.1673287304916552, 0.14062186357166084, 0.11561540540839944, 0.12296533744250025, 0.1084245830508215, 0.13724366841571672, 0.1648779162870986, 0.13056202552148274, 0.2197270773883377, 0.17202141082712583, 0.2632743556584631, 0.20483977480658463, 0.1297276174383504, 0.11250290420970746, 0.13908270187675953, 0.12723484262824059, 0.17686924497996057, 0.11972945822136742, 0.12863091485840933, 0.10055162265364613, 0.12040130288473197, 0.11688565010471003, 0.09370522467153412, 0.04138204249154244, 0.1382716761103698, 0.15737117481018814, 0.11657929154379026, 0.10745201166719198, 0.0859857624662774, 0.1696386265435389, 0.14160746282764844, 0.14885010490460054, 0.1674604612801756, 0.09085086533533675, 0.16122160319771084, 0.11624431237578392, 0.1073794559176479, 0.12656225157635553, 0.08851661666163377, 0.13570576879595006, 0.0940430061891675, 0.08633435983210802, 0.09028976437236581, 0.19063900038599968, 0.15321471355855465, 0.18246805455003465, 0.11343949288129807, 0.1082853205235941, 0.11933589433985096, 0.07864974040005888, 0.08069432925965105, 0.08886220133198158, 0.09936981821166617, 0.14071043953299522, 0.22708075493574142, 0.15012756921350956, 0.15229448436626367, 0.10938746495438473, 0.16489255907280104, 0.07966607050704104, 0.16250640925552162, 0.0645536028646997, 0.25879363609211786, 0.1571809407323599, 0.1864806120949132, 0.23463645949959755, 0.18937596173158713, 0.1296565748218979, 0.11496051054980073, 0.16212034997131142, 0.21156455895730428, 0.20865012891590595, 0.07847511262765952, 0.1796247756906918, 0.1507780807358878, 0.09780570678412914, 0.192397057477917, 0.2360616001699652, 0.06620652095547744, 0.07575576818947281, 0.14475507821355546, 0.11881040968000889, 0.13773880898952484, 0.1254681952829872, 0.15267276763916016, 0.10310912291918482, 0.1695286224463156, 0.12544356446181024, 0.15366811065801553, 0.12216134129890374, 0.08601018972694874, 0.18865439402205603, 0.13713541493884154, 0.19004419658865246, 0.10857872585100786, 0.10482826602778264, 0.10159660050911562, 0.14229006905640873, 0.09023521694221667, 0.15041156326021465, 0.18368635060531752, 0.197388333933694, 0.07286664750427008, 0.16219561307557992, 0.12424364313483238, 0.09740077744105033, 0.13636971531169756, 0.17761366574891976, 0.07263148083750691, 0.14688426681927272, 0.10917198937386274, 0.08114377728530339, 0.12669487803110055, 0.1414931568184069, 0.11606999672949314, 0.13416257660303796, 0.21279373871428625, 0.12349113422845091, 0.10231616654034172, 0.12904688396624156, 0.14681127002196653, 0.08844443410634995, 0.21987133393330233, 0.11617115273007325, 0.1234392805823258, 0.112732662952372, 0.1487348218049322, 0.19391918794385024, 0.19773161837032863, 0.1843813604542187, 0.10712803155183792, 0.09198186107512031, 0.12259166820773057, 0.1276704349688121, 0.07563251230333533, 0.14755921917302267, 0.11162810293691498, 0.09301195187228066, 0.15660467451172216, 0.22025185637176037, 0.09538297035864421, 0.20221564918756485, 0.0978179746972663, 0.1254919304379395, 0.1422978722091232, 0.1833423740629639, 0.1087051233542817, 0.1210539857191699, 0.10988321620970964, 0.1684826607150691, 0.09758407010563783, 0.15504457322614534, 0.07677083622132029, 0.18824537311281475, 0.15450242374624523, 0.155810842822705, 0.21014494156198843, 0.13698678862835678, 0.17282360206757272, 0.1209425295570067, 0.10888642791126456, 0.20623044589800493, 0.17546551887478146, 0.09697093229208674], [0.003946768909892333, 0.04353981099224516, 0.015146050036751797, 0.04702956748328038, 0.026628809947786585, 0.01618464118135827, 0.026179075241088867, 0.012414981361611612, 0.009192713552952876, 0.01626323758890586, 0.023538242393572415, 0.051658509631774256, 0.03205586703760283, 0.07986490840890578, 0.016350490406953862, 0.02846823526280267, 0.020126510644331574, 0.0452053294783192, 0.016604347320805703, 0.044805360226226706, 0.036626716410475116, 0.07036134693771601, 0.036629016644188335, 0.032647929553474696, 0.020482273339959126, 0.05384681560099125, 0.05008419643023184, 0.027267038289989744, 0.017670809291303158, 0.02812276763974556, 0.025428179551714232, 0.05224175797775388, 0.008976941961529, 0.049140934366732836, 0.0660592992124813, 0.034161052467035394, 0.045627625925200324, 0.021380679149712836, 0.015539091446303895, 0.02365127614965396, 0.052793359450463734, 0.013519698288291693, 0.0177733274509332, 0.044904636684805155, 0.03019380409802709, 0.04381809177409325, 0.04407401143440178, 0.04179364861920476, 0.013219194636414093, 0.02774039449702416, 0.026503374267901694, 0.03618220133440835, 0.022057487296738794, 0.034869775508663485, 0.0300556407975299, 0.11617968870060784, 0.04427141084202698, 0.09251732698508672, 0.05291090885709439, 0.023509221450824822, 0.02685077062674931, 0.01231262689855482, 0.023134083187739764, 0.07334822416305542, 0.0022385056862341507, 0.009540968258599085, 0.01748912814738495, 0.031882002617099454, 0.028064464518268193, 0.023694644715370874, 0.017246904716427838, 0.01766415116643267, 0.02043060289828905, 0.015202180149831941, 0.020145708096346686, 0.06143897785139935, 0.06096542826188462, 0.022026181387315904, 0.014756365679204464, 0.015371669715802585, 0.01229560754394957, 0.039326149238539596, 0.078591345676354, 0.024628924671560526, 0.04669157222711614, 0.061558115029973645, 0.04820013199267643, 0.05167772574350238, 0.03341328312775918, 0.06960235123655625, 0.017242226217474257, 0.010389606917410024, 0.04075182595157197, 0.015327666719843234, 0.03317379419292722, 0.03218308896092432, 0.04114484700507351, 0.009245620624694442, 0.024521027425570146, 0.02467509897957955, 0.015160211062590991, 0.02004648252789463, 0.03625238221138716, 0.0027597359315093073, 0.07917571360511438, 0.06039362001631941, 0.01505875141759004, 0.015360763961715358, 0.00455565018845456, 0.04859856775562678, 0.06418992166540452, 0.022574103503887142, 0.09440207335033587, 0.04532490431198052, 0.034891451309834204, 0.030919368378818035, 0.01323021065244185, 0.06699815419103418, 0.05015765463135072, 0.023247315415314267, 0.07013987989297935, 0.03652954001777938, 0.06863026161278997, 0.04823746498940246, 0.048654611355492046, 0.03370659685294543, 0.026168868378070847, 0.042988830379077365, 0.03171759018940585, 0.03398033145016857, 0.027632846696568385, 0.019126553587349396, 0.047420620785227845, 0.03550909459590912, 0.02061306096480361, 0.005313484322479261, 0.008121550182944961, 0.06042340091828789, 0.06211456124271665, 0.0819264335025634, 0.014998855435156395, 0.029964632288153683, 0.006078014324884862, 0.03581990434655121, 0.050913043918886354, 0.038356868749750514, 0.049201839670006714, 0.01670430740341544, 0.018658048905698315, 0.017965944883014475, 0.00983925479730325, 0.07124026691807167, 0.056077798030206134, 0.034428334196231196, 0.017028513131663203, 0.015331929616097893, 0.038207804784178734, 0.03267509809562138, 0.06263701963637557, 0.04031255255852427, 0.04317691010822143, 0.027020950602101426, 0.006268926937731781, 0.054780093021690845, 0.02548887620546988, 0.06846441408353192, 0.003454020808151524, 0.013823661620595624, 0.048723397843007527, 0.03376723752756204, 0.10943771725786583, 0.04510443132104618, 0.04031938879883715, 0.02495968165541334, 0.01793522760272026, 0.03466325319771256, 0.03238178437043514, 0.039380957904670916, 0.03675038959564907, 0.019506667208458697, 0.045805293534483225, 0.015959742445764796, 0.03329969636563744, 0.012942431228501456, 0.02171513923842992, 0.03040692855470947, 0.02233391228531088, 0.04660616841699396, 0.027809562660487633, 0.05630500548120056, 0.011240521213039756, 0.009503177250735462, 0.05981292974736009, 0.05849822065127747, 0.0394870468548366, 0.01678186225970941, 0.02895277033426932, 0.024460717536775128, 0.026241481803091507, 0.03086394563849483, 0.024111216023032154, 0.03470932233280369, 0.03653402852692774, 0.015753428784332106, 0.023422156926244497, 0.047521827675934346, 0.031068527339292423, 0.04021207170028772, 0.019750688757215227, 0.019059370138815472, 0.03299628264669861, 0.0605302294716239, 0.04227654502860137, 0.013140909506806304, 0.036204545492572446, 0.014338092944983925, 0.05648307342614446, 0.037107611141566715, 0.0145435363852552, 0.03654254414141178, 0.03481677853103195, 0.046327443194708655, 0.05026649843369212, 0.03216343519410916, 0.021302606910467148, 0.02991923490273101, 0.040398712935192246, 0.02585937498536493, 0.10171294890876327, 0.05642971343227795, 0.06524511147290468, 0.0224407594983599, 0.02240382174828223, 0.04773715737142733, 0.017205227399244905, 0.041158628051302264, 0.05329200805031827, 0.0186311738299472, 0.05278713728434273, 0.0703319256593074, 0.06096979124205453, 0.037686262412795, 0.010637009266896971, 0.03549754932256682, 0.030555941630154848, 0.037335062865167856, 0.013647183992101677, 0.04333077810172524, 0.05728455899017198, 0.027764253484617387, 0.036684320640883276, 0.03281178558245301, 0.014592857399423207, 0.05974724755755492, 0.03987477533519268, 0.006372563407889434, 0.04102199484727212, 0.04143728881276079, 0.035073648140366585, 0.041073359948183806, 0.039879063676510534, 0.016553445320044245, 0.02843465286839221, 0.04015727660485676, 0.04544120182150176, 0.05014588204877717, 0.029128202170665776, 0.02517160340877516, 0.013089451107329555, 0.04035131726413965, 0.03487935981580189, 0.011730450637904661, 0.03780651917415006, 0.023710342623027306, 0.03578699539814677, 0.0177044748062534, 0.01610809225322945, 0.020860519293429594, 0.0351062721040632, 0.045099159103951285, 0.062115674040147235, 0.015008402422868779, 0.016681508626788855, 0.05305211538715022, 0.02913467539474368, 0.02622261004788535, 0.0474622115891959, 0.024560584320819805, 0.025239485748378292, 0.07100302393415145, 0.005565396809418286, 0.056959561072289944, 0.04118414775335363, 0.05701528236802135, 0.09054451355976717, 0.04996600580800857, 0.03598506994811552, 0.04286735564736383, 0.053559479769319296, 0.07183378828423363, 0.011519278665738446, 0.07510223718626158, 0.0434692060308797, 0.03341227889593158, 0.04288879735395312, 0.03522838465869427, 0.014789023569652011, 0.09548025870961802, 0.02498050419879811, 0.05707954641963754, 0.034557018362517865, 0.02559418823303921, 0.00505727798112535, 0.06672285217791796, 0.03651358087414077, 0.01670212421699294, 0.03468123098303165, 0.05388681524034057, 0.027948136474671106, 0.03608295201723065, 0.016945818372602974, 0.06492081244609185, 0.03598632863057511, 0.014119138176153814, 0.008271078945004513, 0.023580211480813365, 0.033425232129437585, 0.04567270779183932, 0.03781272776957069, 0.0012279399462775992, 0.020399598936949457, 0.049318727504994185, 0.05874405388853379, 0.02629186642090125, 0.09760899269687277, 0.04300009406038693, 0.016582683393997804, 0.00903727559904967, 0.009160193914015378, 0.03002460121310183, 0.05519791113744889, 0.0716794826356428, 0.10879379431051867, 0.01550100018669452, 0.03420326752322061, 0.12698267187391007, 0.04441894471113171, 0.027560508078230277, 0.10596938551004444, 0.044789475721440146, 0.006637908767775765, 0.04272737048034157, 0.1527109963021108, 0.11780385726264544, 0.13769773047949585, 0.1546278577297926, 0.06424998558525528, 0.09229892691863434, 0.09174801755164351, 0.056427257135510445, 0.10278131586632558, 0.09410658492041485, 0.09094744122454099, 0.19128914549946785, 0.11021926746304546, 0.15529402984040125, 0.17365768445389612, 0.08720841471637998, 0.14187856470899923, 0.18349878995546273, 0.13257918799562113, 0.15859358278768404, 0.09426835445421082, 0.1506279209362609, 0.13289005202906473, 0.12842972922538007, 0.16540257313421794, 0.1383927267576967, 0.1367762799241713, 0.115501465808068, 0.08470836601087026, 0.08181902140911136, 0.10383409008915935, 0.13514183834195137, 0.09154772758483887, 0.10254047664680652, 0.18612206062035902, 0.16072211999978336, 0.15238059046013014, 0.11159799633813755, 0.08471739052661828, 0.09996017081929104, 0.1446353303534644, 0.08716196220900331, 0.06863514027957406, 0.15225920054529393, 0.09927479616765465, 0.1278513324047838, 0.1554428461406912, 0.08222779804574591, 0.07842328612293516, 0.10862513764628343, 0.16792380570300988, 0.11050191801041365, 0.24439045467547008, 0.16183540597558022, 0.1552010298307453, 0.1683217936328479, 0.22820934866155895, 0.1389444435813597, 0.18249139615467616, 0.08576559142342635, 0.14364162938935415, 0.10603013475026403, 0.1456086616963148, 0.17146744126720087, 0.08670007663645915, 0.09681608381548099, 0.10203652868845633, 0.09247447071330887, 0.19947581977716514, 0.052637082657643726, 0.09727075656077691, 0.12385514112455503, 0.15530829264649323, 0.12173447491867201, 0.06258421604122434, 0.2122342051672084, 0.1365903341876609, 0.14610149525105953, 0.07949289479958159, 0.09250731859356165, 0.18193813227117062, 0.09734462866825716, 0.08670698412294899, 0.2285908753318446, 0.12878207888986382, 0.12802023334162577, 0.16112721897661686, 0.10363106562622956, 0.1234346122613975, 0.11167522040860993, 0.10061834300202982, 0.13413764722645283, 0.1372276549892766, 0.19247194060257503, 0.1411965148789542, 0.09097663180104323, 0.18701916533921445, 0.06941650049494845, 0.10332645090030772, 0.05630701055218067, 0.0883554917361055, 0.09873126247631651, 0.16030596090214594, 0.10151695406862668, 0.15336703109954083, 0.13212147541344166, 0.07082650304905005, 0.11923334055713244, 0.09398408899349825, 0.11625409685075283, 0.15914630384317466, 0.13621393724211625, 0.08039471533681665, 0.19799050662134374, 0.15242504807455198, 0.2189962137490511, 0.14341307165367262, 0.1457769926637411, 0.14563038838761194, 0.11711812977279935, 0.12813839342977318, 0.25863439749394146, 0.11756077887756483, 0.1916000366743122, 0.15871464700571128, 0.20411577794168675, 0.09867797712130205, 0.17416863489363874, 0.17402824599828037, 0.13800157846084662, 0.12800071867448942, 0.10669948919011013, 0.0943474852080856, 0.10330891077007566, 0.07496061335716929, 0.1135223148656743, 0.0870407283572214, 0.13810083456337452, 0.1463135238736868, 0.12125029947076525, 0.14437637424894742, 0.1895801464893988, 0.09094286789851529, 0.206590666568705, 0.17661674852882112, 0.13902854121157102, 0.10586002602108888, 0.09637394361197948, 0.07984288316220045, 0.1301522310823202, 0.13337395606296404, 0.14407735743692943, 0.180577140301466, 0.14253024331160954, 0.06217068287410906, 0.1755300611257553, 0.1200378659580435, 0.07210075110197067, 0.16463593712874822, 0.12576456580843243, 0.12797855772078037, 0.11263822444847651, 0.07003445590713195, 0.1907078716903925, 0.10444851711924587, 0.100622169939535, 0.22654737212828227, 0.13906310578542097, 0.11906000200126853, 0.1854393593966961, 0.2289553029196603, 0.20288529539746897, 0.20367972419730254, 0.12208140987370696, 0.10400810039469174, 0.12419888696500234], [0.01152596393200968, 0.01502384418355567, 0.016861520574561188, 0.008543635435801531, 0.04511348297819495, 0.032338001898356845, 0.050247445170368464, 0.07742283373538937, 0.04770767502486706, 0.006575601441519601, 0.00630254198664001, 0.05432582400473101, 0.016979594149493744, 0.03635910219912018, 0.050659468597067256, 0.04718467719586832, 0.024208294028150182, 0.04206307791173458, 0.04573357577568718, 0.03162474624280419, 0.007860325226959373, 0.04730998904311231, 0.04499898019379803, 0.08486683786447559, 0.035724824627063105, 0.019635529490187764, 0.03644829562732151, 0.04444956021117313, 0.0334724615594106, 0.01683023332485131, 0.029315267489956956, 0.08521681944174425, 0.0544926554097661, 0.017302240943536162, 0.0621464184618422, 0.0075641353614628315, 0.04644521651789546, 0.041108548774250915, 0.05731333566031285, 0.05102832701855472, 0.02396568043955735, 0.035230349017573256, 0.042614285834133625, 0.02604888642339834, 0.03367163194343448, 0.02894237857045872, 0.0353288248048297, 0.011753634483154331, 0.010010571318811603, 0.028486776232187237, 0.036676459812692234, 0.02919387078977057, 0.03513646012704287, 0.06782788716788803, 0.04948626797912376, 0.039246842065559964, 0.029691169104937996, 0.025594139039250355, 0.03983001238001244, 0.05034182260611227, 0.00895779115879642, 0.011061622062698007, 0.03934231533535889, 0.01809765531548432, 0.03062291982184563, 0.016252840736082623, 0.030028289050928185, 0.03964195300691894, 0.03422248702762382, 0.017467338691598604, 0.02630242781846651, 0.028013201197609305, 0.0354530272473182, 0.022245497476043444, 0.009293028170109859, 0.016868970889065946, 0.03774053503626159, 0.03276130257706557, 0.01809145011273878, 0.012935370223463645, 0.048751740250736475, 0.022371662581073384, 0.024435591385034577, 0.031064459521855627, 0.03545903228223324, 0.014175499839309071, 0.015079078630411198, 0.03698375814461282, 0.07925997408373014, 0.07413206103124789, 0.025961033101858835, 0.01716101575376732, 0.026554418761017065, 0.013597599197445171, 0.01899431220122746, 0.07342246267944574, 0.025446533923968673, 0.03693760419264436, 0.00476076326698863, 0.03188967006281018, 0.044913817263607464, 0.025987857287483554, 0.049298446093286784, 0.016120916565081904, 0.042147752296711714, 0.033044455240347555, 0.058413254496242316, 0.03452824169237699, 0.12252194194921426, 0.05454593397943037, 0.01955719940763499, 0.014038575713389685, 0.03974527692688363, 0.05541589390486479, 0.002808700078665944, 0.046070451449070654, 0.0277119604870677, 0.02886790256681187, 0.058030235048915656, 0.06576678955129214, 0.05931210983544588, 0.07274886739573308, 0.02368380851112306, 0.011551327571006758, 0.04022982556905065, 0.01806180322143648, 0.03362260778833713, 0.04850779673350709, 0.03469177880989654, 0.019468469079583883, 0.049963111856154034, 0.011480977908442063, 0.06493473598467452, 0.021191961597651243, 0.03081532521173358, 0.04560127162507602, 0.03656478991199817, 0.06152186090392726, 0.034157256063606055, 0.03249390210424151, 0.03125326528346964, 0.030994702729263475, 0.009297129914297588, 0.01835922717249819, 0.05954823323658534, 0.06231211671339614, 0.05983588458704097, 0.010152121357220625, 0.03059860791212746, 0.035169039985963275, 0.0349204213624554, 0.07282799814960786, 0.04688129061833024, 0.025727267609909177, 0.061579013908548016, 0.0231061258486339, 0.04828772407823375, 0.02499069749111576, 0.01213457082797374, 0.05532389473436134, 0.08509506311799798, 0.08204809483140707, 0.002302510622290096, 0.06127961711691959, 0.033221617341041565, 0.029328159655311277, 0.056975221660520346, 0.049041970034262965, 0.0406516063293176, 0.07861588828797851, 0.030349412533853735, 0.048897906871778626, 0.02064362896739372, 0.039479135136519156, 0.016633544682658145, 0.022454029946987118, 0.06365231837012938, 0.019656374085960642, 0.020360101413513933, 0.009895367098839154, 0.026601831395445124, 0.010483897839938956, 0.039449055679142475, 0.058707134798169136, 0.048431763491992436, 0.04268502650250282, 0.016090577568060586, 0.03703641246205994, 0.023792594637987868, 0.01900162171971585, 0.01904244577911283, 0.054275938110159974, 0.03418574435636401, 0.016874173556321433, 0.059215622155794075, 0.041257704342050214, 0.020772411521258097, 0.03428032195993832, 0.04863606360075729, 0.039714549468564134, 0.053935031938765726, 0.03309202054515481, 0.02209038267444287, 0.014225065126083791, 0.06181703042238951, 0.009566186012567153, 0.03397182262103472, 0.08995503626231637, 0.045307279364871125, 0.04069835399942739, 0.05804609241230147, 0.006606177501713059, 0.05683129420503974, 0.024635542084329894, 0.04234444602791752, 0.06791836302727461, 0.04078946089638131, 0.06503021943249873, 0.039369734935462475, 0.02586626211580421, 0.015113804356328078, 0.04970170624021973, 0.08076616576207535, 0.019149939296767116, 0.06327360083482095, 0.052272957017911334, 0.02346894021944276, 0.011350875603966415, 0.013119678146072795, 0.013824843119696846, 0.022554914533559765, 0.055917453419949324, 0.043095648754388094, 0.0037011858824241373, 0.02752934635749885, 0.030053941067308187, 0.038041906364794285, 0.007180875882373324, 0.022214965096541812, 0.028629536607435772, 0.0181108918373606, 0.029211197181471756, 0.009603645386440414, 0.038366575193192275, 0.03871359835777964, 0.04436868562230042, 0.03330789306866271, 0.03333055953096066, 0.0030708200647495687, 0.041007660795003176, 0.019415514510391012, 0.07127965587590422, 0.012642116718260306, 0.03477632427322013, 0.0482364912916507, 0.022593636830736483, 0.006755792776987488, 0.03482997942981975, 0.006860542044575725, 0.0911968367706452, 0.027592056563922336, 0.016418891825846264, 0.018753425484257083, 0.05468055193445512, 0.008615348105584937, 0.03409424390909927, 0.022925873020929948, 0.09491932059505157, 0.04308738759053605, 0.0107101036036121, 0.03502585891900318, 0.028311648040211627, 0.035341408236750534, 0.02209374142278518, 0.05257160063566906, 0.036973088181444576, 0.006561468405249927, 0.012026336858980358, 0.05629969594467964, 0.051215395730520995, 0.03037526811073933, 0.026804360527811304, 0.016862439989511455, 0.0278244649858347, 0.1070703017924513, 0.05080385406368545, 0.003941555216442794, 0.04363041916596038, 0.05266313161700964, 0.02045472651453955, 0.020270151418766806, 0.020370608528277705, 0.013640737061255744, 0.046504961526287455, 0.06809931474604777, 0.019990891850154315, 0.012187079260391849, 0.03702024297256555, 0.02074345334299973, 0.025085059659821645, 0.01687255864297705, 0.00938734199319567, 0.07521803597254412, 0.038416094678853235, 0.023164037116137997, 0.09997838269919157, 0.03539420843922666, 0.01891692528235061, 0.012774278376517552, 0.028189126668231826, 0.014691141500536884, 0.06571683580321924, 0.024013233870001774, 0.03469162613951734, 0.006863516148379338, 0.06624712449099336, 0.06171324849128723, 0.022203116178778664, 0.024491931843970503, 0.07812481213893209, 0.002404344097677884, 0.040910246915050914, 0.024600003812728182, 0.020195485425314734, 0.02354235601212297, 0.048762678235237084, 0.03628752693267805, 0.07271764799952507, 0.03578209976798721, 0.04558629635721445, 0.02378149380508278, 0.044932083426309485, 0.04507135273888707, 0.013868820670592998, 0.022730731438579302, 0.027083408054230467, 0.01982715117212917, 0.030163198776010956, 0.0393743421882391, 0.04011619809482779, 0.015212103724479675, 0.01632760850978749, 0.06740165861057383, 0.012650550908542104, 0.0628136694431305, 0.05158020329794713, 0.0472938806217696, 0.04264545773289033, 0.028073495819366405, 0.05645615594195468, 0.002360106583052714, 0.055976943977709324, 0.15316144855959074, 0.15024739849780286, 0.09790162449436528, 0.10918120387941599, 0.12937411426433496, 0.1387099147375141, 0.11140219827315637, 0.15839990175196103, 0.19722505126680645, 0.09557380833263908, 0.11529882811009884, 0.11412181412535054, 0.10469994827040605, 0.11489267061863627, 0.09952683121498142, 0.1666676609643868, 0.13506141837154115, 0.09256592366312232, 0.1201251662735428, 0.07705630947436605, 0.1466836647263595, 0.18479191485260213, 0.1462446389985936, 0.12271813356450625, 0.09899515153041907, 0.10237426270863839, 0.16734745805816992, 0.14452840680522577, 0.20529986226132937, 0.10915294289588928, 0.08120292518287897, 0.26318943021552904, 0.16105353007359163, 0.09890610059457165, 0.18347463410879883, 0.08040950740022318, 0.15923873388341495, 0.07573151734790631, 0.13387309999338218, 0.14331153567348207, 0.15926609241536685, 0.1382468417286873, 0.09501631717596735, 0.15452109702995845, 0.14203629695943423, 0.1633737398577588, 0.13917924383921282, 0.09584276604333095, 0.1808010432869196, 0.2295479896877493, 0.1746142152696848, 0.09971350298396178, 0.1048755259918315, 0.09524526167660952, 0.10552330301808459, 0.11929430014320783, 0.07417944991695029, 0.1380525500114475, 0.16553590526538237, 0.07873694572065558, 0.12987203683171952, 0.08904856776020356, 0.15514537638851575, 0.08632610884628125, 0.09634836284177643, 0.10465848299541644, 0.09458156621881894, 0.11825652154428618, 0.22242246275501593, 0.15196610055863857, 0.13700258492359094, 0.2445186706525939, 0.10261387377977371, 0.13425556304199354, 0.05320394438292299, 0.20942716007786139, 0.18020154402724334, 0.11615535643483911, 0.1010669225028583, 0.1264586392790079, 0.13445216177829675, 0.12940524545099052, 0.09822962832237993, 0.13166520132550172, 0.19755323151392595, 0.14809686318039894, 0.06888039676206452, 0.09880028984376363, 0.13047004331435474, 0.14085712523332664, 0.10989713296294212, 0.12533497171742575, 0.05105204860280667, 0.0900958865614874, 0.09627027024648019, 0.16241980104574136, 0.10557247645088605, 0.14759763782577856, 0.12492686004510947, 0.11802649817296437, 0.10511240935219185, 0.11652126322899546, 0.1685794469501291, 0.10076664361570563, 0.13547996591244424, 0.10294792335480452, 0.15773993145142282, 0.09864605204867465, 0.20554015865283354, 0.18854008801281452, 0.059440285100468566, 0.11598891179476466, 0.10560485614197594, 0.10555576413337674, 0.13923022896051407, 0.1551288744168622, 0.11897363806409494, 0.2273675716881241, 0.25602589175105095, 0.12098702788352966, 0.1445755921304226, 0.10228031274995633, 0.09999947156757116, 0.0908853824117354, 0.26909154493893894, 0.1223551444709301, 0.15490347865436757, 0.154873840244753, 0.07141545108918633, 0.16718859943960393, 0.21106876698987825, 0.14264480716415814, 0.1251617960099663, 0.13352061462189468, 0.13459231997174875, 0.09796741524977343, 0.10418124217540026, 0.12221992601241384, 0.09402483502136809, 0.09139861272914068, 0.13659131127808774, 0.15054176055959292, 0.10455425323120185, 0.13238505912678583, 0.09419535087155444, 0.11238000794712986, 0.22865609611783708, 0.09800191197012152, 0.25103350249784334, 0.16006227183554853, 0.1595785306500537, 0.12212708885116236, 0.0995337183454207, 0.1460234908653157, 0.11515077176902976, 0.06752220035663672, 0.1299583464860916, 0.08204403040664536, 0.13699734663324697, 0.08705319983086415, 0.20723227571163857, 0.21196060627698898, 0.14796669302242144, 0.1942805214119809, 0.09947260948164122, 0.10407460361186947, 0.15180908755532332, 0.13978271931409836, 0.1773696509855134, 0.15769531098859652, 0.08760638907551765, 0.21638849510678224, 0.11095630577100174, 0.11700974058892046, 0.0748559832572937, 0.14183925039001874], [0.03389654255339077, 0.021259681088849902, 0.03288068402824657, 0.014302167908421584, 0.04289622052705713, 0.07143762561359576, 0.01743984954165561, 0.027509305825723068, 0.06691718460725886, 0.014907455071806908, 0.03271869397056954, 0.025998579837115746, 0.04135665171114462, 0.11768907627889089, 0.032203400906707556, 0.013911535298185689, 0.0729520343510168, 0.04389475605317524, 0.006435321959933, 0.05801502229379756, 0.04439650555806501, 0.03443484813241022, 0.020684191790808524, 0.049481260390686135, 0.05500871521819915, 0.06163514232529061, 0.025843884030889188, 0.06083565843956811, 0.03141896692769868, 0.019624710249315416, 0.021411805247355784, 0.028863556550017426, 0.02449989954142698, 0.002375322942888098, 0.008115853033294635, 0.012273908842221966, 0.04978540353477001, 0.019156648311764002, 0.037152492840375216, 0.04607095017230936, 0.021534540357866457, 0.040739561431109905, 0.04085222877828138, 0.026713482636426176, 0.0359277948071914, 0.0056067615764082545, 0.02032623064172055, 0.018855336355045438, 0.05503382779923933, 0.037417816996042214, 0.08200481108256749, 0.057447719520756176, 0.044064478017389774, 0.014849350421822496, 0.011950673419050872, 0.003618299013136753, 0.016190978698432446, 0.05844496922301395, 0.022231372073292732, 0.06423239795757191, 0.040279348447386704, 0.028067775769159198, 0.10437797661870718, 0.029821671745074645, 0.039902693658534966, 0.015259981155395508, 0.041423005650618246, 0.07002866121807269, 0.02004354277492634, 0.061006086080202034, 0.04586578493139573, 0.023884091692577516, 0.013581646839156747, 0.03294070723599621, 0.058527370515678606, 0.046650632816765986, 0.016604530525260737, 0.02430684954327132, 0.036017673555761576, 0.014469901765031474, 0.04551062273925968, 0.028766027319111993, 0.03181362325059516, 0.06696028515164341, 0.03503996566204088, 0.04524852501760636, 0.029875133519193957, 0.023242830298841, 0.032069420774600337, 0.05145024009315031, 0.021393778268247843, 0.01632955590529101, 0.020837320181142007, 0.015611289268625634, 0.03554154892585107, 0.03119912836700678, 0.03637097995462162, 0.020867197774350643, 0.03610372875950166, 0.024745909197788154, 0.01443719637713262, 0.01618324339921985, 0.06365902229611363, 0.017917763807677796, 0.0774714168427246, 0.014636017315621887, 0.01583805906453303, 0.022998484749613062, 0.05394660096083369, 0.040264441033027, 0.06999026970671755, 0.027204104167010103, 0.031504051826362095, 0.01901344010340316, 0.043109945487231016, 0.027901303987683992, 0.013935329824952143, 0.10587467559214149, 0.04102482773097498, 0.029505620311413492, 0.03078885216798101, 0.006310676773344832, 0.04581237404740282, 0.0257455303799361, 0.05642279576776283, 0.02252137624392552, 0.05433570686727762, 0.022126068527411138, 0.041696533294660706, 0.01663493228677128, 0.024127835041976402, 0.03185853887615459, 0.036627744391028366, 0.0169177660385945, 0.008519171703872936, 0.05203366485823478, 0.0817944516560861, 0.010378301675830568, 0.02933560996981604, 0.0015119927286702606, 0.0519182358735374, 0.04928195769233363, 0.012623342502463077, 0.09657205548137426, 0.05128109488370163, 0.044636852839695554, 0.05135153021131243, 0.022032532475090454, 0.0311145252282066, 0.02484705502034298, 0.032420179274465354, 0.04704697529918381, 0.031732222797083, 0.04027085318895323, 0.032948432357183526, 0.024110673195017234, 0.025208656509806002, 0.039649284577795436, 0.026037889067083597, 0.044271889209215126, 0.0708427471773965, 0.045750220239694626, 0.03230695552857859, 0.00768257280079914, 0.03076773276552558, 0.029270928619163375, 0.033050663835768185, 0.008704322706242757, 0.08126667354788099, 0.0037726008449681103, 0.03701169003865548, 0.05940220571522202, 0.028114309700738107, 0.031610463080661635, 0.014061192133730012, 0.01592162234841713, 0.04745921924976366, 0.09878396429121494, 0.03572726056778005, 0.02181631389872304, 0.06271436584315129, 0.012794193379314882, 0.020548762986436486, 0.037540207750030925, 0.031855892589581866, 0.03929266692804439, 0.0074172393152756345, 0.06127844325133732, 0.011309373857719558, 0.03899575357458421, 0.02244776876510254, 0.023352459505466477, 0.04142844071611762, 0.01922249504631119, 0.01622924468080912, 0.024968528055718968, 0.005880099654729877, 0.02388583722391299, 0.01727348123677075, 0.05836598774684327, 0.04141250192852957, 0.031752063161028285, 0.032321225120020766, 0.023986426647752523, 0.05069166508370212, 0.014160248068427401, 0.021974641563636915, 0.01872995326162449, 0.023041279953239218, 0.02746732486411929, 0.011983496702409216, 0.025574775346155678, 0.04951728042215109, 0.022371211355285983, 0.042667751000928025, 0.03290099258135472, 0.055842716180320294, 0.02300939898538802, 0.04873614073065775, 0.06591050326824188, 0.032752613936151774, 0.03142266833622541, 0.013010026038890439, 0.010146041683453535, 0.06554015885506358, 0.021127634781545827, 0.04879039299807378, 0.038258538847523074, 0.035244805206145556, 0.015269265210788165, 0.037725678512028286, 0.026397812878713012, 0.028497721002038037, 0.004843493225052953, 0.008882374535979969, 0.02673245108287249, 0.02645053674599954, 0.046699351631104946, 0.03780669898593, 0.02835694025270641, 0.03239690213065062, 0.020923936872610023, 0.06855371607733624, 0.03540420665272644, 0.034857575449028184, 0.015533379877784421, 0.02501254971139133, 0.025502085585945418, 0.029393899520593028, 0.028861015436372588, 0.03814965094040547, 0.03933671063610485, 0.039739193860441446, 0.017005805957264135, 0.01461297765906368, 0.07122076582163572, 0.04298930874626551, 0.045849327064518414, 0.03997671504371932, 0.10027908906340599, 0.02799990869659398, 0.025099963681506257, 0.05369844374113849, 0.029847612138837576, 0.017416852293536067, 0.05986727361700364, 0.01831660669163934, 0.022359369222873023, 0.03387390662516866, 0.018289945354419093, 0.04671239646683846, 0.049662836361676455, 0.05459724819021566, 0.030556881401155676, 0.06767421934221472, 0.05304295177172337, 0.01639387763238379, 0.025838177551382353, 0.08673120103776455, 0.05618472836379494, 0.09165424401206629, 0.01677878849607493, 0.00558893391696204, 0.022647448050390397, 0.028299724483596425, 0.004581936210992613, 0.06509296356567315, 0.04109348190416183, 0.03749691043049097, 0.007828979453604137, 0.0317324263575886, 0.019260766117700508, 0.035707633942365646, 0.029136324234838997, 0.03210895222478679, 0.02418707963079214, 0.03401106230116316, 0.049383324038769515, 0.04421868188572781, 0.06613316453461136, 0.03668198308774403, 0.04390631828989301, 0.011065876477264931, 0.009978827754301684, 0.045854402506457906, 0.03072314622945019, 0.043357084904398234, 0.04080925037020019, 0.03420576113941414, 0.08501822581248623, 0.04266839900187083, 0.049301445218069215, 0.022141076025686095, 0.007349865876936487, 0.028633489073919396, 0.02625722381552415, 0.052163254868771346, 0.07093960805130856, 0.05407120713165828, 0.04632053570821881, 0.028903111748929535, 0.04212900098147137, 0.061294035986065865, 0.02180498236391161, 0.03373646596446633, 0.03058584127575159, 0.044015966156231504, 0.0572124578590904, 0.019997153032038893, 0.01573924400976726, 0.06323094812354871, 0.028966286751840795, 0.052606623220656595, 0.09394757702414479, 0.048360171262174845, 0.056075199241084714, 0.029324878938496113, 0.011778075314526047, 0.0065623979982254756, 0.02736995169626815, 0.028361250646412373, 0.08164101453231913, 0.0058649123446749786, 0.031055624995912825, 0.0902170797011682, 0.005408602633646556, 0.029347460583916733, 0.07714954697127853, 0.03134572585778577, 0.0313245250311281, 0.07575013634881803, 0.020195585509229983, 0.08907931218189852, 0.24474250578454562, 0.12913860833006247, 0.13094994399164403, 0.16319209603326662, 0.23050350270101003, 0.06376970492835556, 0.08366380206176213, 0.20003995379166944, 0.17317867944283144, 0.10242243190961224, 0.18414269254675933, 0.0727704448093261, 0.16198761495096342, 0.09032490570098162, 0.10188690493149416, 0.13271527497896127, 0.14352086372673512, 0.06748954925153937, 0.09362592428390469, 0.1566254919660943, 0.07348170557192393, 0.09052751625755004, 0.19365029808666023, 0.15071021366332257, 0.13889404200017452, 0.1302687626864229, 0.13342374696263246, 0.12984613036470755, 0.17203625717333385, 0.11294431159538881, 0.14521524709250244, 0.17881950390126022, 0.10739052282380206, 0.1017761883725013, 0.09987135737070016, 0.13312543582703384, 0.10583057760127954, 0.1885481354381357, 0.1569076675389494, 0.0938096579962543, 0.16464241035282612, 0.11024463110204254, 0.15996739906924112, 0.15392032212444715, 0.10912264630730663, 0.08613645152321883, 0.10636680347046681, 0.1623315643519163, 0.07426998005913836, 0.18837381979184492, 0.11082329933664628, 0.14031275015856537, 0.12920644826122693, 0.07141972585980381, 0.12386820970901422, 0.13366526471717016, 0.17618176686976636, 0.06276886577584914, 0.19530961476266384, 0.14490336525653089, 0.24332773312926292, 0.1607332072619881, 0.10204310369278703, 0.10745465116841452, 0.13499413483909198, 0.1828855707177094, 0.14182714532528604, 0.11998549662530422, 0.10265046717332942, 0.11015167858983789, 0.12251329741307668, 0.05703118722885847, 0.13675938440220697, 0.10056071502289601, 0.09990951139479876, 0.12073556280561856, 0.1428207784358944, 0.07483126422656433, 0.14023303586457456, 0.1359979324042797, 0.19412151351571083, 0.14671008687998566, 0.19522004814020225, 0.1575631323669638, 0.14722779552851403, 0.19738310921405042, 0.10747073244835649, 0.08669711822377783, 0.0787701667951686, 0.07758378224181277, 0.1190384245876755, 0.12706320040992328, 0.0753441620618105, 0.11218026080834013, 0.1333000228873321, 0.10005736417536225, 0.1607761720993689, 0.09091320234749999, 0.12055043131113052, 0.11631618280495916, 0.09924321036253657, 0.2061910637255226, 0.12150584932948862, 0.20430724695324898, 0.13682897495371954, 0.0936218530737928, 0.14830458989100798, 0.18614533437149866, 0.1301976250750678, 0.13518286256917886, 0.09640429448336363, 0.107190544983106, 0.10098507082355873, 0.1869217548519373, 0.15142076196415083, 0.1416984543736492, 0.20921815772141727, 0.13362896309367248, 0.09392689527677638, 0.17689151449927262, 0.11412607532526765, 0.18132232102964604, 0.247319934623582, 0.13140377535351686, 0.1684798380093915, 0.09717756656131574, 0.12419309227594308, 0.127042559374656, 0.08186419148530279, 0.1596572949950184, 0.0655667574277946, 0.10986237839928695, 0.18753726753805364, 0.11267721985599824, 0.13807236323399202, 0.2074919646339757, 0.08538471614675862, 0.12134230881929398, 0.08918272770409073, 0.11383426455514771, 0.12457957225186483, 0.15007811758135045, 0.20994911635560648, 0.16519271582365036, 0.0962136872112751, 0.1822757577257497, 0.1587704497256449, 0.10337157347904784, 0.10306195795003857, 0.16697961065386022, 0.11306319093065602, 0.08776805682906083, 0.0966496527461069, 0.12566913664340973, 0.07918205112218857, 0.12399399653077126, 0.17219705640205316, 0.13153641537896224, 0.16794665876243794, 0.1824618120278631, 0.08566417079418898, 0.17087172823292868, 0.08790769933589868, 0.15539393733654702, 0.12978773564100266, 0.09854655167354004, 0.07560868215348039, 0.18192391017717974, 0.059431002741413455, 0.13220809719392232, 0.1102059953180807, 0.13287315650710038, 0.12290995541427817, 0.1678125938134534, 0.10934780458254473], [0.02337015569875283, 0.035775409412703345, 0.020695947410006608, 0.021463592736316577, 0.04084765884493079, 0.028972315535481487, 0.055133949033916, 0.027881010701613765, 0.007405227549108011, 0.03281307140631335, 0.005424911222819771, 0.03481102116139872, 0.031141452890421664, 0.03042200899549893, 0.04527181573212147, 0.07346050135259118, 0.026270377216860652, 0.022809005541993038, 0.08467704483440944, 0.019962103305650607, 0.0805558877597962, 0.05942021403461695, 0.06202749841447387, 0.014460273353116853, 0.02077925793959626, 0.026293211616575718, 0.014729767106473446, 0.04199396912008524, 0.045239649779562435, 0.03825655413259353, 0.04123659511762006, 0.021573367827971066, 0.017720159143209457, 0.066469901108316, 0.017128422324146544, 0.05472837508256946, 0.04436007501291377, 0.04953284262280379, 0.005811708413862756, 0.023306295375472734, 0.0647729393094778, 0.03053729548784239, 0.05809509621134826, 0.026720627610172545, 0.014397688675671816, 0.023934941106875027, 0.03889627355550017, 0.06613208566393171, 0.059167880431881974, 0.024393386506874646, 0.03840274789503642, 0.08265346341899463, 0.014483501303142734, 0.0731836658503328, 0.028514222973691564, 0.025185113040996448, 0.02638986044829445, 0.03987760482622044, 0.011003794763902468, 0.06346588408840553, 0.0011149937636218965, 0.04141057488907661, 0.024982622924393842, 0.09688150137662888, 0.03418250095897487, 0.0434191538952291, 0.06282335213784661, 0.07552001119724341, 0.04393207547920091, 0.04367254940526826, 0.04577333114242979, 0.022783928584041338, 0.029915828656937395, 0.016101242442216192, 0.03668030371357288, 0.022171628761238286, 0.03453634340049965, 0.05010997736826539, 0.06876829599163362, 0.019024315323414545, 0.020430840385545577, 0.03658702550455928, 0.02747976580368621, 0.020610708144626448, 0.0228540059844298, 0.06502985302358866, 0.006028152603123869, 0.05656387676884021, 0.043788653532309194, 0.017059576464816928, 0.08419329686356442, 0.021044816189844693, 0.05461622002933707, 0.06939509950046029, 0.02456633829777794, 0.0594316337789808, 0.037595677987805436, 0.026216287797849094, 0.06937669084540435, 0.008412243066621678, 0.0368658423290721, 0.030402894664023603, 0.024385715668488826, 0.02208010965426053, 0.08405776627893959, 0.05061320268682071, 0.022288089119164006, 0.06535402991409812, 0.011888693485941206, 0.045133598148822784, 0.017063279569681202, 0.07081671857408114, 0.03294412026714001, 0.022611472123701657, 0.019021750461044054, 0.02507788415199944, 0.04145065934530326, 0.03536372525351388, 0.09265124265636716, 0.05588789304186191, 0.06698872255427496, 0.03881433705932327, 0.007160929497331381, 0.037931590141462426, 0.018563211762479374, 0.06683107851339237, 0.10346392888043608, 0.05722733813204935, 0.006098380977553981, 0.03421395105708923, 0.036393846584750075, 0.04507377850157874, 0.03732448789690222, 0.05561429415164249, 0.033726515248417854, 0.03119413774194462, 0.034808520759854994, 0.06906882593674318, 0.07314700460327522, 0.02203506341071001, 0.043442485321845324, 0.029756881828819002, 0.028025962744972537, 0.003213614154706842, 0.04602249937930277, 0.05638506582805088, 0.04125847787197147, 0.02382291667163372, 0.03338159893506339, 0.015172794494511825, 0.025324436636375527, 0.023704203577446084, 0.024835338416908468, 0.007678816261302147, 0.02464601187966764, 0.051809324217694144, 0.05117251231734242, 0.012625174547013427, 0.006650529943207013, 0.05979105377835887, 0.05705653051180499, 0.028349035319739153, 0.0441588452751083, 0.017059668067044446, 0.0711372856582914, 0.010346333346595722, 0.0694259592731084, 0.044729924095528464, 0.009206790610083511, 0.003916284027842006, 0.06761583140386002, 0.030686264458511556, 0.06437012699565717, 0.033764099303100786, 0.03200617791818721, 0.010464795382826455, 0.01789974531025759, 0.04087458311447075, 0.021418853529861996, 0.026050703200910772, 0.08605779574385711, 0.019821929845160673, 0.050096925747181685, 0.022814513550006917, 0.04865621609081115, 0.037653831831578694, 0.030222886108926365, 0.03612322985593762, 0.07064023161573069, 0.03064154221543244, 0.016610998660326004, 0.04257039479645235, 0.016529140195676258, 0.04712207555504782, 0.025664554010810595, 0.030208915072892393, 0.060882972686418464, 0.035178597151700935, 0.02314399997703731, 0.02116560560118939, 0.04649954342416354, 0.02621210802213422, 0.021626829602090374, 0.04438980841743095, 0.008716476964764297, 0.02470213860007269, 0.010275906500672656, 0.04141895479655691, 0.03377685576145138, 0.020392521816704954, 0.022893301643697277, 0.004038036534828799, 0.05867565755865403, 0.025222323901419128, 0.01480619389829891, 0.028170824882441332, 0.03794366806479437, 0.051653006712773016, 0.03513866875852857, 0.039209315686353614, 0.028466471071754183, 0.0218491906167141, 0.02678745482782168, 0.10489320861441748, 0.02923661171059523, 0.012399118061044385, 0.01573151210322976, 0.0549927255404847, 0.03188603990046041, 0.0050072139711119235, 0.010286482317107064, 0.06246182189456054, 0.03271346925092595, 0.05067769744034324, 0.03787665255367756, 0.021191016737637774, 0.02886448275031788, 0.019790255830490162, 0.0760711512661406, 0.07897130493074656, 0.07030628382095269, 0.02417690330184996, 0.04616121568584016, 0.02800189171518598, 0.023651632380538752, 0.04149458770241056, 0.03136854838313801, 0.04705271909811667, 0.06769221409090928, 0.02255200531466731, 0.08294771012983151, 0.004259361511295927, 0.004874959014289613, 0.028713430677141463, 0.01552032316768808, 0.03755473857745528, 0.017380604952839867, 0.0069358242326416075, 0.030045177787542343, 0.02522415085695684, 0.010099148976483514, 0.03146530747679727, 0.08568387545113053, 0.10416328135345664, 0.0740316446338381, 0.017158491603497947, 0.05843116103538445, 0.015808391817180172, 0.05378358631527849, 0.03394805693200656, 0.06443563955170767, 0.06926131275083337, 0.015074467984959483, 0.024484349215137105, 0.02513699303381145, 0.02118529668743057, 0.05115557608327695, 0.04040708266464727, 0.003939066689261901, 0.004711365493546639, 0.017320072843826244, 0.027723834849894047, 0.06488081959209271, 0.047311743056135516, 0.014893899638471859, 0.0325449109742684, 0.038626708555966616, 0.031163556168654134, 0.03107771131076983, 0.024252771998622587, 0.02482212903643293, 0.018587720447352955, 0.013997554878837295, 0.03865371424970882, 0.05335439934528299, 0.011127053194546273, 0.006085017654446087, 0.008639147721364029, 0.030225763097405434, 0.0411482668215675, 0.02206541088941906, 0.09300602147621767, 0.032696773896792104, 0.0355792347607868, 0.028702760713973215, 0.04444692410262568, 0.046062373489673646, 0.04591864959469863, 0.0378345596337957, 0.027154316660016775, 0.039051803959799666, 0.05999860406986304, 0.021778765467128584, 0.020794029646952237, 0.05250104995710509, 0.047211995015719106, 0.018379956417317902, 0.0424019383000476, 0.010052897485106118, 0.06582206979926143, 0.046405355978224955, 0.06485591735690832, 0.05262010571147714, 0.02752934126848621, 0.0343965516159577, 0.030050253229481832, 0.0348840247440551, 0.01338755020073482, 0.041537494864314795, 0.06423589919826814, 0.01298205173640911, 0.052387486943709, 0.009304164626103426, 0.00804161197239799, 0.042791709170809815, 0.040855811443179846, 0.05171450234151312, 0.05482810615961041, 0.0630654873592513, 0.019448476045259407, 0.02317832367095564, 0.04509883001446724, 0.024599179392680526, 0.04632730748770492, 0.03843650161953909, 0.04526119665907962, 0.029640635209424154, 0.03669207290347133, 0.01950871977689011, 0.029523991647043397, 0.049479838859822066, 0.046516520370330126, 0.1392792599009616, 0.14231512056929724, 0.12298272150967803, 0.10788628086447716, 0.13243809342384338, 0.13993705888944014, 0.14759446228189127, 0.14657389133104257, 0.16086310600595816, 0.12418585909264428, 0.12919073339019502, 0.14894720326576913, 0.13758603004472597, 0.08653808318610702, 0.132306946175439, 0.1598931130553995, 0.1391802616417408, 0.10781610677284853, 0.10060146105076585, 0.17499453414763722, 0.1308292190411261, 0.1392353315438543, 0.14828656800091267, 0.1229826807975769, 0.15672165394893714, 0.09915211025093283, 0.09219946047025067, 0.15063587336667947, 0.09953268018684217, 0.07367278103317533, 0.09654550440609455, 0.12258370220661163, 0.1292388415230172, 0.13998387780572685, 0.11578726475792271, 0.1539938481790679, 0.14362641663423606, 0.16284068274710858, 0.09429834570203509, 0.16440804435738496, 0.1402588201952832, 0.11921472155622073, 0.20663646768246377, 0.08345779204475028, 0.13013925749276364, 0.14988234665777, 0.16114621795713902, 0.17354195352111543, 0.10832643296037402, 0.07869914453476667, 0.15309732700032846, 0.17919854713337763, 0.1252469385841063, 0.12967879005840846, 0.11159730423241854, 0.17567910812795162, 0.11338614645813193, 0.26265664451888626, 0.07554076079811368, 0.1537797296685832, 0.08433182657297168, 0.09151995514652558, 0.15131757035851479, 0.24176172858902387, 0.15282233032797063, 0.0926114194361227, 0.10904303379356861, 0.1659679285117558, 0.10652347042092256, 0.12589778937399387, 0.17050179094076157, 0.18468843826225825, 0.1582535688898393, 0.14528642541595868, 0.18895041170929158, 0.0721986365637609, 0.09618047292211226, 0.13646940567663737, 0.14471925156457083, 0.073375643763159, 0.11453472982559885, 0.11420889730964388, 0.12707628256508283, 0.13570270181766578, 0.13086877763271332, 0.10253267349409205, 0.19556243691061223, 0.12261692328112465, 0.1937734250511442, 0.08814722219748156, 0.20816606203360216, 0.09012538926409823, 0.10456136427819729, 0.11973240306334836, 0.18568774392562254, 0.10233668543930564, 0.20104905750070298, 0.11093668932361261, 0.16849182093782084, 0.06312510344598975, 0.11620991065033845, 0.09518021730972187, 0.11971982302410261, 0.07885005072291408, 0.30414561395134243, 0.10548526434493916, 0.15742209207798752, 0.15082937798329762, 0.04990774679130741, 0.10538671391883067, 0.13805469418210642, 0.1333120736692633, 0.11303537099489144, 0.10213427844324283, 0.08672676341874258, 0.09297600987234286, 0.11606375420732157, 0.09146249680114643, 0.19783548851098332, 0.20215725446385996, 0.11933011322149209, 0.09997576355401959, 0.11269147587674004, 0.11517483262079102, 0.11430603638291359, 0.14879853624318326, 0.20057742137994083, 0.1147481155182634, 0.11043795251420566, 0.19836978055536747, 0.10633178427815437, 0.12356888077088765, 0.09859350629683052, 0.19571062895868505, 0.12046698507453714, 0.09470721733357225, 0.16670523823371955, 0.08964227911617074, 0.17995925274278435, 0.12258051309202399, 0.14279882104269095, 0.192154766193458, 0.14717280705060276, 0.18391421623528004, 0.1159777973911592, 0.1598873726491417, 0.14582373015582561, 0.09003730863332748, 0.12018195965460368, 0.06578313545989138, 0.11803516985050269, 0.0760304323796715, 0.12208010708647114, 0.09522078691848687, 0.06938764918595552, 0.23689057997294835, 0.12635174287217005, 0.04079258555014219, 0.11559473723173141, 0.1155213468841144, 0.14685065219444887, 0.18982219350125107, 0.09925177347447191, 0.06742789755974497, 0.15849326817052706, 0.09893421230039426, 0.14729944882648333, 0.14821718100990566, 0.12896752251046045, 0.07491327875426837, 0.10555910252566848, 0.1740875363882099, 0.1069816511922649, 0.13846108237547533, 0.13994864826755865, 0.09000444718237434], [0.02793775828156088, 0.05132389687267797, 0.05254474761230605, 0.04416494530492595, 0.007361216919629702, 0.09068560813154493, 0.037007842745099745, 0.04558047791942954, 0.019560715915369134, 0.029175899789801667, 0.030845533590763807, 0.04293207771011761, 0.08579603050436292, 0.03380914045763867, 0.04388762465012925, 0.030736323379512345, 0.030427834218634025, 0.020624694447698336, 0.03328391703377877, 0.03220474101336939, 0.05245219204308731, 0.05216765856104238, 0.09943758350397859, 0.010553954884276857, 0.06887309572526387, 0.02740067067289991, 0.021709549806213806, 0.05742779094725847, 0.030286844819784164, 0.047865264782948155, 0.022790562960186174, 0.016631892449887734, 0.0543822068721056, 0.025863564939105084, 0.0566643881611526, 0.05006372842139431, 0.03165548727182405, 0.03238657482766679, 0.041836572744484456, 0.019863271287509372, 0.05218154478019901, 0.03696615355355399, 0.06602201371320657, 0.017491832109434263, 0.01839216156596584, 0.05393465195915528, 0.00819634085720671, 0.049351039342582226, 0.009908882668241858, 0.021801133374018327, 0.04976361577532121, 0.052269537201417346, 0.015774363285994956, 0.04006668200184192, 0.056687478707837205, 0.021825779462233186, 0.021957774879410863, 0.01599827814581139, 0.04062667016738227, 0.043464656453579664, 0.0800041098679815, 0.051405110729060004, 0.039245345895843844, 0.032193969269948344, 0.00894607964437455, 0.07832819622542177, 0.05621954060292669, 0.02073838299007288, 0.05637132888659835, 0.012042997438194496, 0.004665211541578174, 0.03001539349289877, 0.04770075057500175, 0.0611606767135007, 0.03732487466186285, 0.03653784867908273, 0.09327852792505707, 0.03182216600647994, 0.010047275822476616, 0.056983832269907, 0.03420468905408468, 0.02342262172273227, 0.025270158923896294, 0.016944366307663064, 0.051466039781059535, 0.028688165425722088, 0.013034703509349908, 0.0617213976968612, 0.029030452415879284, 0.030871345062873194, 0.031243172075067247, 0.045076842087187936, 0.03758397665140884, 0.02914141324747886, 0.009027768475269633, 0.018967001166726862, 0.03840106173551508, 0.027737697320325033, 0.01912474868419979, 0.04192181370620217, 0.008066657548105078, 0.006908233302445816, 0.03236460725643805, 0.04108794505840965, 0.01731235281165157, 0.05030932417139411, 0.05913381797394582, 0.050386463424989154, 0.012140183160746736, 0.048143253794738224, 0.019201859100056545, 0.07722052851957933, 0.040540268910782676, 0.03063841416899647, 0.05297736118414572, 0.02638934985069292, 0.037863882524626594, 0.057861008415264745, 0.0256867421059204, 0.0721602246963552, 0.03230134404397436, 0.06556345974760396, 0.08464703323053462, 0.07945216912776232, 0.045560186329696856, 0.07847733822252069, 0.009529455215670168, 0.03731457110760467, 0.026987866930929676, 0.07084148510226182, 0.043645798162158043, 0.026772718743554184, 0.04185434357662286, 0.002778048743493855, 0.010496674654340106, 0.04050032355423484, 0.027811194537207484, 0.022174576995894313, 0.02079791765260909, 0.03584756821926151, 0.054924346173980405, 0.040069365607840676, 0.02595879732897239, 0.029108056465962102, 0.03268381387793592, 0.06026863386588437, 0.026408879784867167, 0.01671890269166657, 0.06894605181046895, 0.04140965208145125, 0.03423106371025954, 0.023071585023509603, 0.021441845688968897, 0.07816804839032036, 0.029440555588475296, 0.015931562886440327, 0.03025205632937806, 0.05621450587308832, 0.021261852400909578, 0.043342662642576864, 0.021192370414999977, 0.04862365658794131, 0.013441813494344907, 0.057454844138451984, 0.018843324588877813, 0.02821482448572559, 0.05788802767970732, 0.08596466002719742, 0.05112726760229894, 0.044053607886391025, 0.013978437154686876, 0.028278722128431712, 0.00408026431354561, 0.05082450866965311, 0.0283802886426981, 0.04235079711569207, 0.09314267164362328, 0.0916137761835541, 0.0710308031578149, 0.040105799545667, 0.01127432837217514, 0.009249339844765407, 0.05166643152811697, 0.054935399509434185, 0.03539311939052173, 0.016390702088496516, 0.06250260184918131, 0.04464318696409464, 0.0580039078901921, 0.02895417490175792, 0.006964315918074655, 0.04856617110116141, 0.03205495440800275, 0.06376938601689679, 0.04536844929680228, 0.021943459486854926, 0.0332514219917357, 0.011825376838844801, 0.041815789216863256, 0.0373183234062578, 0.014657409828422325, 0.05918669620794909, 0.02986309291528804, 0.015616900753229856, 0.0445281922418092, 0.04324397990213973, 0.03774385985785297, 0.015520640382809299, 0.011318241462244518, 0.01963820291816124, 0.017168072517961264, 0.035507625567593744, 0.0229654078637915, 0.03799776087648102, 0.021933780184813907, 0.019676981194476997, 0.01620615243778697, 0.006053910640600536, 0.029290507747126476, 0.012653902871534228, 0.031468550874186416, 0.09110456279345922, 0.04655215024415936, 0.020056662249511907, 0.03473285731992551, 0.014352125049169575, 0.02421941182443074, 0.02532855873661382, 0.02287561393209866, 0.0760343000292778, 0.061235369848353524, 0.02182232741532581, 0.06660870901708092, 0.03290358119245086, 0.031659270104553015, 0.022703174435134445, 0.039360435613031895, 0.06244768122477191, 0.02576609168733869, 0.04401852423325181, 0.04967755717890603, 0.017313370614179542, 0.01552951562085322, 0.04662340659914272, 0.05025061732158065, 0.06045037947062935, 0.03863983142322727, 0.07588599263025181, 0.06888695819569485, 0.07667934934475593, 0.05201982952920454, 0.04987040700923119, 0.04870335391855665, 0.030378891487738917, 0.031227542020912682, 0.0486099535732397, 0.01640756368370993, 0.03821095657934036, 0.07265385892242193, 0.03410959576389619, 0.03522768237494996, 0.007948946989407497, 0.0674199994121279, 0.015423077225152935, 0.04988558244492326, 0.0255394457240722, 0.05978080111422709, 0.017295073917401687, 0.04827805156154292, 0.07204924350870506, 0.04389768732445581, 0.055261510224746804, 0.08924387727997132, 0.02086870921110468, 0.03704412740522197, 0.06268778762647084, 0.030111745465546846, 0.06726081509675298, 0.08249049287821565, 0.07030605311904635, 0.034065138149474344, 0.0401062507714544, 0.0702906164473721, 0.06694328784942627, 0.01632521328117166, 0.02470728868086423, 0.009452223511678832, 0.054231870653373856, 0.06905070905174528, 0.013054090103001466, 0.013070375791617801, 0.03902561929343002, 0.03623933059030345, 0.039342176235680065, 0.0748320852539369, 0.03702429382662688, 0.008318266814707645, 0.0541542326765401, 0.04245084371151669, 0.054557058561061106, 0.01518985625755574, 0.11315798905811139, 0.011270654953217931, 0.013915260455438068, 0.06500710852976356, 0.028590863504047905, 0.03292688208499125, 0.039565753524324725, 0.005383054517941284, 0.015894036507233977, 0.03267738815130932, 0.03301775149468865, 0.053041648984487565, 0.016428043566910282, 0.014653508252065097, 0.009985991387761064, 0.04022138459341867, 0.04787702040214624, 0.03486230144543307, 0.01130639508898769, 0.01833927315393729, 0.026855250654209937, 0.024437430214935114, 0.013300613749639263, 0.05630476460126894, 0.026892848279593245, 0.037513565072523694, 0.05973592959344387, 0.0019522483011574618, 0.1023762643869434, 0.009860999300144613, 0.03459467027070267, 0.04540787896673594, 0.07556548661419324, 0.032339891618383784, 0.005900741962250322, 0.06368957672800336, 0.03848734085581132, 0.033800037910363505, 0.05236592310081635, 0.06244008841791323, 0.023744817290987288, 0.03154313883611134, 0.056398107271109305, 0.04136753202016864, 0.03601544796090041, 0.07303905646715846, 0.03619429622111576, 0.059093764051795006, 0.03375695772202952, 0.021741744596511126, 0.019796467818585888, 0.1636774249907051, 0.2707306412713868, 0.18971043878367969, 0.22335008797901018, 0.17361659237316676, 0.18214003715131963, 0.12694243474730424, 0.12633956995393547, 0.0850850140143718, 0.12740092085940496, 0.20307143112378462, 0.11088839798633542, 0.24235281401446887, 0.13089000220809663, 0.11550223933798925, 0.15636173183364527, 0.15290735076580728, 0.19640809510435375, 0.11992233858576842, 0.07509300232465778, 0.18455790169537067, 0.16261487986360276, 0.13825754901128157, 0.17402896524540015, 0.19788762714181626, 0.14349779353610106, 0.09614279387252671, 0.1348024079842227, 0.12518064571278437, 0.13136771800262587, 0.0986711782004152, 0.08723504721586194, 0.09137253662837402, 0.11031565336244446, 0.10830539158944573, 0.09839483124337026, 0.15161634289792605, 0.10894126711147172, 0.05437524849548936, 0.0941146934138877, 0.16257101935999735, 0.10823512928826468, 0.13606734653668745, 0.10823804020349469, 0.09576054795512132, 0.12138676643371582, 0.10199044258998972, 0.0827126181019204, 0.15386563220194407, 0.08820862283131906, 0.18065485970250197, 0.13725767337850162, 0.10126555684421744, 0.11393580053533826, 0.13278276207191603, 0.09416895585932902, 0.12375173238771302, 0.11108639450477702, 0.12217637763491698, 0.11672403663396835, 0.2180536336132458, 0.18913964155529225, 0.0712885514699987, 0.06652937470270054, 0.1521733251533338, 0.1740905355129923, 0.1413500402122736, 0.10138957268957581, 0.1216061639466456, 0.0851642804752503, 0.0850809020921588, 0.12615669119570935, 0.1853558045944997, 0.21305053707744392, 0.11530827331755843, 0.19047388567456178, 0.1530984262270587, 0.08929151043828044, 0.09838551495756422, 0.16183444245585374, 0.11656931707901613, 0.13911103749913828, 0.11194759793579578, 0.07882872436727796, 0.13196333604199545, 0.08257929275610618, 0.11888921473707471, 0.08568572785173144, 0.09944545451019492, 0.09619181124227387, 0.17967907206288405, 0.13824297407908098, 0.19720227963158063, 0.13479317990796907, 0.09397585836372205, 0.28548533096909523, 0.13553784494953497, 0.09873783069529704, 0.20729029045573302, 0.1489842241363866, 0.1347739366548402, 0.14879316224583558, 0.1262714314673628, 0.2724640268300261, 0.08271595649421215, 0.12079398467072419, 0.12994020245969296, 0.11863286420702934, 0.1379716686372246, 0.13670848070510797, 0.13757327358637536, 0.1772529293916055, 0.1314290982804128, 0.09937714638986758, 0.1363612471946648, 0.11164040477680308, 0.158851738220879, 0.11188197681414229, 0.21244594880512782, 0.12881364433893136, 0.15788877489311354, 0.13097012362309865, 0.10858070038791214, 0.13999322801828384, 0.1317950864987714, 0.2800186185964516, 0.12636394293180533, 0.16985320645783628, 0.16518208996525832, 0.07617744377681188, 0.11401664119746004, 0.09722405978079353, 0.09862818622163363, 0.06397243762122733, 0.10999493021517992, 0.11929705499538354, 0.09155497433883802, 0.07103569539529936, 0.04578098501744015, 0.11881061324051448, 0.11739395425787993, 0.12973197363317013, 0.058152602054178715, 0.18270490398364408, 0.09689090587198734, 0.13385213326130593, 0.14544913811343058, 0.11577330050723893, 0.28543416942868916, 0.10320402282689299, 0.15298732290310518, 0.1796163889978613, 0.08526293946696178, 0.1911848953792027, 0.098476289372359, 0.16561709876571382, 0.1738903405410903, 0.14160062319466046, 0.09594657511583396, 0.14913635168756756, 0.16678215696343354, 0.17361223617834703, 0.15017281392855303, 0.1472992588366781, 0.19402060178773745, 0.09667372038321835, 0.19030194490083627, 0.16016474419406482, 0.0863920556647437, 0.1493867039680481, 0.11180439990546022, 0.06312801436121974, 0.18500817753374577, 0.14046403632632323, 0.1429495643824339, 0.11672353451805455], [0.11633462538676602, 0.015855661959254315, 0.04504401795566082, 0.03552639723888465, 0.04789841800395932, 0.0205707695734288, 0.06152279728225299, 0.06954936443695, 0.05826318969151803, 0.07900216470339469, 0.020143925245585184, 0.02995940756851009, 0.007662189608838941, 0.03655708175418632, 0.05493005943883743, 0.037616817746311426, 0.07141764954264675, 0.0723449287137815, 0.022044238900499682, 0.017401016982538358, 0.019167586296264614, 0.10088109890265123, 0.021891856898686717, 0.09640208245920283, 0.013229498190672269, 0.008029559494129248, 0.07465344733957734, 0.0033169628836081494, 0.07190739576305662, 0.02175688780178981, 0.0885252340563706, 0.08395792663629566, 0.05041667180401938, 0.10086631362459489, 0.038836565866534195, 0.0509256239581321, 0.038590732629277875, 0.05396454142672675, 0.015245986370635884, 0.026920300110110214, 0.04584077073793326, 0.06063057801553181, 0.04465014873338597, 0.03809470317459532, 0.0833642017096281, 0.02177090633527509, 0.05249316877286349, 0.017662761865981987, 0.029520897527358363, 0.016105196605037366, 0.0426571726399873, 0.0760091467361365, 0.053921172861009836, 0.0513385939411819, 0.012669379407140826, 0.123505546312247, 0.07246923632919788, 0.03859156044200063, 0.07313895039260387, 0.0258528389967978, 0.043145524470933845, 0.0156450175480651, 0.010046332658800696, 0.03638023517227598, 0.05641697732997792, 0.0315377885874893, 0.03808640808399234, 0.09142859040626458, 0.011309584203575338, 0.010567104892938264, 0.016465829485761266, 0.01997914640898151, 0.06681378265576703, 0.015889685401426892, 0.013987837409201478, 0.019992391412545527, 0.06390812607215983, 0.020088758652231524, 0.13716514834335872, 0.023592460734237517, 0.022440606827980707, 0.007778256416453847, 0.09173736455185072, 0.013105370387035822, 0.04805127498028534, 0.07749287890536444, 0.05728865734168461, 0.026059934669839482, 0.05091043834441474, 0.029040138503270488, 0.0224537127318659, 0.012340770834790809, 0.06001789482044322, 0.03937393506722791, 0.03643915915329542, 0.021997023041227033, 0.06733157951384783, 0.051906812736498456, 0.04988702433183789, 0.041117915950183354, 0.04849738800632102, 0.031239436739789586, 0.0459756940337164, 0.027401466255209277, 0.057287992377366335, 0.03337324277630874, 0.05585137089448316, 0.0363687306110348, 0.046286025417170355, 0.053469153187636814, 0.006900123960804194, 0.05438216616000448, 0.07323224217231784, 0.004461514480811144, 0.029025319298463206, 0.0258774647289621, 0.03646900112341557, 0.031874145181583505, 0.03210525760161025, 0.03464780295533793, 0.06606731271105153, 0.07204488052853517, 0.035363562405109406, 0.07842494853373085, 0.03288002924195357, 0.024912302947736213, 0.05635425355285406, 0.016096038078623157, 0.01977531618571707, 0.08210909512958356, 0.060187189307596, 0.015331310452893376, 0.09083285701594182, 0.01867809283014919, 0.04493951338476368, 0.03404547759730901, 0.037622483513717137, 0.010087066812307706, 0.01240265492482909, 0.043902823834546974, 0.013048810252387608, 0.02166146711845483, 0.0336146892846695, 0.04011367394455841, 0.053098578072552166, 0.04167178033718041, 0.03934687509068421, 0.04005636826955846, 0.028181949464072074, 0.0787168068013021, 0.018999053464670266, 0.042116346303373575, 0.09281620809010097, 0.032123703576092205, 0.04859950752662761, 0.022839863618303622, 0.02094712750320988, 0.05260528989934495, 0.05098918233332889, 0.06377423754228012, 0.022308204289791838, 0.03893697547859379, 0.0605261107640607, 0.0010675697849364951, 0.033208504651806185, 0.040069345251790116, 0.04155263637325593, 0.007400532086778964, 0.04110925105799522, 0.02042900494832013, 0.050073658781392236, 0.055752345493861606, 0.03921493734898312, 0.031120591331273317, 0.03838538418390921, 0.021512677959565605, 0.06506882128970963, 0.035920334314661365, 0.0336934570223093, 0.025802503572776914, 0.04168591761429395, 0.019051220933241502, 0.08485233757112708, 0.07595816840018545, 0.06510800668703658, 0.018505156306283813, 0.0267241373325565, 0.04093725600146821, 0.05527877554829631, 0.0027725089291509774, 0.03343196998217276, 0.06278948645506587, 0.12385759742132255, 0.04658574112025755, 0.04934639137770448, 0.0649084902501532, 0.009885274738605534, 0.017065201520121524, 0.02726091960045908, 0.019381216261535883, 0.005710355214042855, 0.05124172967459474, 0.006922577108655657, 0.04917624193642821, 0.04983900101589305, 0.031945031734981706, 0.07216726788984877, 0.030476417325969254, 0.025275948523942913, 0.07205587279583726, 0.06276312536959137, 0.0661811369604298, 0.04417297576687165, 0.015434513932892253, 0.03518448005031262, 0.029475276225379536, 0.036568460786449056, 0.032592031838638444, 0.044253385559256585, 0.020377095323055983, 0.0504451770601528, 0.029530149352337633, 0.01106023954759751, 0.03273084992542863, 0.10911336394825152, 0.012841155636124313, 0.04188194638118148, 0.056459884491882155, 0.010972418456471391, 0.029080087252493416, 0.030644982387976985, 0.013471911611434604, 0.033340523817709515, 0.060987792776099274, 0.036357717987682135, 0.013138783995860388, 0.05842139013111591, 0.03555704327300191, 0.01394151636798467, 0.07339546377105371, 0.06959995600794043, 0.026334843132644892, 0.011118432407134345, 0.0725200789581452, 0.03520594211295247, 0.010115127628003913, 0.014560647342087967, 0.032341370824724436, 0.016380690304296355, 0.02558807123984609, 0.0830963228696159, 0.062200402707925866, 0.05779273422168834, 0.038534454934831174, 0.01228336337953806, 0.009556298909176673, 0.06741890018539769, 0.019598813960328698, 0.04997292686519878, 0.012678971347798194, 0.04200771623956306, 0.03001499654991286, 0.0322134194762579, 0.04292822363121169, 0.08199041256947176, 0.046499570565564294, 0.03734125788988812, 0.02886964979448489, 0.01599899060758097, 0.018663704495078752, 0.027159056227122034, 0.02845157722809485, 0.0403968266078404, 0.061719484228108606, 0.009700810752942093, 0.032419046120984216, 0.051699123345315456, 0.012551880042467798, 0.07811423377799136, 0.03735538838165147, 0.034973879743899615, 0.030005276535770724, 0.05564491643703409, 0.025386001814955046, 0.07393717898854188, 0.05225493852049112, 0.015818771706627946, 0.015565747694511498, 0.08120561896690301, 0.009710063426090139, 0.04827573775712933, 0.03768447447302086, 0.0339171157351562, 0.014273852642093385, 0.03738679098231452, 0.03908531341169562, 0.03976011988041656, 0.04337933406765972, 0.030558095978839055, 0.04963480268738099, 0.011771680121975285, 0.02327374435429062, 0.038968517178935666, 0.032356095034629107, 0.010135653312318027, 0.0972479170720492, 0.03234519776222961, 0.010564063359717173, 0.05069254378655127, 0.037300657747047286, 0.015162188992170351, 0.03541528034423079, 0.015237136577655162, 0.07232487800398044, 0.018372212636417577, 0.015537508763372898, 0.04459394228511623, 0.04865239254598107, 0.01670222938992083, 0.11013757863215037, 0.04208369180560112, 0.013039607621197189, 0.044044233925108395, 0.024704969787438, 0.039226024611187835, 0.047922509389796426, 0.07589195695306573, 0.04004110123163887, 0.023906613966184, 0.03689150791615248, 0.05022805942488568, 0.013053755076336009, 0.05031302557992084, 0.03338959886293326, 0.025015798197793107, 0.09921572290893112, 0.032122509354459386, 0.05348660510831645, 0.09291560668498278, 0.027863075324733342, 0.04753852981541838, 0.036654180115354915, 0.09252271455313478, 0.06888992339372635, 0.05697752867958375, 0.04194488050416112, 0.03416559186631015, 0.015629569002028023, 0.005206246951794518, 0.07198027042405945, 0.010708140941070659, 0.0388189918095512, 0.2904660494199821, 0.11854101770690509, 0.13869512267410755, 0.13361115833478315, 0.1292516386934689, 0.128205771957125, 0.16349473622228416, 0.22731687155153069, 0.20132580479340895, 0.1172330736049584, 0.08682832654033389, 0.08770882072193281, 0.14554382088993276, 0.09872836513178689, 0.18194508046976157, 0.16921600779252394, 0.2500622203307492, 0.16056820111615316, 0.1155497096478939, 0.1797515396028757, 0.1305215305515698, 0.20514791112925324, 0.10596371295728854, 0.20265333141599381, 0.1067387627969895, 0.17735943224813255, 0.16839529254606792, 0.15237236661570414, 0.16191961217139447, 0.10360057904784169, 0.29102776784982, 0.10919969395867415, 0.09030720950769526, 0.16277098362999304, 0.17534061414854868, 0.11128426888691527, 0.08731453759329659, 0.1236585152468511, 0.18498859501310758, 0.10242764305855546, 0.1707781853952578, 0.11130475385912827, 0.09280149745089666, 0.13830945694020816, 0.15052618139556476, 0.12020859893943582, 0.14483617671898433, 0.10437377648694174, 0.14519793087882654, 0.10717124066182546, 0.0728967066055962, 0.15451401312436375, 0.17339445357876165, 0.22611211905522005, 0.09159000031650066, 0.1974707352263587, 0.23711349229727471, 0.11649098699646336, 0.16097715417189257, 0.20903375904474938, 0.1263087373226881, 0.08332055155187845, 0.1410464636449303, 0.1419289798608848, 0.10974272553409849, 0.1355933898261615, 0.1396364543054785, 0.27157020622066086, 0.0907466152150716, 0.13411552698484488, 0.08760464524051972, 0.11735090799629688, 0.16329251921602658, 0.2064799703657627, 0.15789011839245046, 0.12824618550283567, 0.19686137006751128, 0.07842495531908103, 0.1822947838476726, 0.10923372927520957, 0.14295493837978157, 0.11288094320999724, 0.16593804582953453, 0.11158925002174717, 0.10932058175759655, 0.13263481429644994, 0.1454534807375499, 0.10604426184935228, 0.16769380947308882, 0.18562583439052105, 0.0938684530556202, 0.07558083507631506, 0.14901717379689217, 0.08883423890386309, 0.11631839482911996, 0.10408207428242479, 0.0900927245883005, 0.12405073562903063, 0.13257734238037042, 0.08375114987471274, 0.10500463763517992, 0.1975494995713234, 0.18843715425048554, 0.10894888705973114, 0.1486059815755912, 0.11566788330674171, 0.08805822554443564, 0.1266471091657877, 0.1337164941110781, 0.20850676803716592, 0.12287511942642075, 0.15185874274798802, 0.1343970647347825, 0.088778056204319, 0.15983470476099423, 0.12223925068974495, 0.08846748394093343, 0.05964229854622057, 0.08777826878109149, 0.12118592006819588, 0.1323703077754804, 0.27230413683823174, 0.15046504539038452, 0.1917285919189453, 0.06726600588964564, 0.08204168267548084, 0.11045777252210037, 0.17236161471477576, 0.07855213313762631, 0.24604515731334686, 0.10250262117811612, 0.10838503802993468, 0.17796951665409974, 0.06959013760622058, 0.13011822290718555, 0.13955946772226266, 0.06862240417727403, 0.1510075477084943, 0.14337831709001744, 0.09339801115649086, 0.11024535713451249, 0.1377215606293508, 0.16946534227047647, 0.198352952886905, 0.10268763732165098, 0.06361487680780036, 0.12335491153810706, 0.18446416886789457, 0.1483881175518036, 0.14442981566701615, 0.1292654536664486, 0.10753219415034566, 0.16433198058179446, 0.14381308161786624, 0.10154493685279574, 0.07623185549995729, 0.15514800910438808, 0.20872589413608822, 0.09901305128421102, 0.18490285532815115, 0.12054378166794777, 0.18671419098973274, 0.1364087989287717, 0.13674919280622685, 0.13091143034398556, 0.16399227881005832, 0.1491385908531291, 0.15793399246675627, 0.1301891840994358, 0.07167583890259266, 0.09052900903459106, 0.13702405377158097, 0.13008749884154114, 0.10628145055047103, 0.10375299836908068, 0.10775045172444411], [0.04327207464458687, 0.03498559804367168, 0.0558701730998499, 0.12896075073097432, 0.025575691368430853, 0.04638997019667711, 0.03752723416047437, 0.03352901745321495, 0.03234372873391424, 0.03866867255419493, 0.019984886815239276, 0.057897825725376606, 0.05798224905239684, 0.022821112303063273, 0.00565499481412449, 0.03866591091666903, 0.05692911520600319, 0.034250666586948295, 0.016900636422048722, 0.026533966019217457, 0.06823375288929258, 0.052699640193688016, 0.03036267789346831, 0.04582689130412681, 0.019528884141306792, 0.050500375883919854, 0.03688367083668709, 0.06246205259646688, 0.007214015532684113, 0.0273983161563852, 0.007800135778130165, 0.02218190687043326, 0.022842674449618374, 0.02957981133035251, 0.05402451713702508, 0.07958801862384592, 0.08521421386727265, 0.04724991833791137, 0.03334739737744842, 0.037784134303884845, 0.021549656421744397, 0.0508673852974815, 0.040252397036445994, 0.06012113392353058, 0.038532904482313564, 0.018699166431490864, 0.0718424396057214, 0.03645356445174132, 0.015624938000525748, 0.029676017417971576, 0.019465069619140456, 0.018778149603999088, 0.017405110245038356, 0.024286805618820444, 0.0060658380139752156, 0.016796181044940437, 0.019449758476444652, 0.05928844931934561, 0.017946248707760657, 0.0315948703459331, 0.046651864357824833, 0.03665609697678259, 0.04085595393553376, 0.06018096035612481, 0.07744728813746146, 0.012322703991750521, 0.060903796926140785, 0.010330095155430692, 0.003948118770495057, 0.018240600591525435, 0.05673659107248698, 0.026887011182095324, 0.011736060426171337, 0.022310872628752674, 0.026451903994062116, 0.043066855120871744, 0.02378417062573135, 0.01672699931077659, 0.0418548762266125, 0.02102937612549535, 0.00559690288667168, 0.013314690806769898, 0.029764115012117794, 0.032305825767772536, 0.010164552118762262, 0.017561529530212283, 0.01809735336740102, 0.023939823166334202, 0.04388027950855238, 0.031796829508883614, 0.01572569366544485, 0.02473316970281303, 0.021780756967408315, 0.017798533330538442, 0.055408219673803875, 0.06417584884911776, 0.012575378558332366, 0.022343786666169763, 0.020371590707717196, 0.03868277929723263, 0.08135632837989501, 0.04341881802039487, 0.031078491626041274, 0.03343494196555444, 0.04992277973464557, 0.05460309037672622, 0.00917759579273739, 0.06042532117239066, 0.00723123929596373, 0.02329156268388033, 0.055085247182952504, 0.0562431841556515, 0.041313357784279754, 0.04247806653646486, 0.01862054966789271, 0.03475585287170751, 0.04656281681465251, 0.06101004872471094, 0.04830196652827518, 0.02325308635564787, 0.03674428956583142, 0.07791929745248385, 0.010457731833282326, 0.025604071095585823, 0.011991852861163872, 0.06692591735294887, 0.03410892062155264, 0.06789555067994765, 0.03644623288086482, 0.007938826639604355, 0.061859601709459505, 0.022596152499318123, 0.030390209451849972, 0.052298025494175296, 0.03324901658509459, 0.013624166387931576, 0.0596691956743598, 0.04461862399641957, 0.019169230047347288, 0.0467580109834671, 0.044662335222320895, 0.028516550348805528, 0.041483340984476466, 0.01358746103609779, 0.03148348203727177, 0.032553066965192556, 0.019168694004682556, 0.007757743454671332, 0.06579366632338081, 0.06102249305695295, 0.03069464097331677, 0.019846621734489287, 0.08055216260254383, 0.04659597682101386, 0.03455292679635542, 0.0275264591909945, 0.011670759064145386, 0.034405694875333986, 0.02596781505937023, 0.03437830920198134, 0.07057925845895495, 0.041967170379523716, 0.01336758176330477, 0.03758717933669686, 0.006746627889307482, 0.04955685258443866, 0.058731880970299244, 0.024241744108232002, 0.04734773255352463, 0.012716132166263248, 0.005762161786801049, 0.06836941918092114, 0.030372971269701208, 0.03924677760473319, 0.02660011130917285, 0.03419288933011038, 0.0461674717787121, 0.033668575143175464, 0.005877579745304371, 0.02032131126283535, 0.05272688676736184, 0.04851294342162354, 0.05829903669655323, 0.017025951661967804, 0.04081875325313636, 0.04037782423464315, 0.02530968189239502, 0.016523021506145597, 0.04555164357381208, 0.009458550850727727, 0.02758676907978952, 0.024258507315867713, 0.02414525982125529, 0.10777579500739064, 0.02006834831887058, 0.029395039459424357, 0.014521551850650991, 0.009250472150077777, 0.021466642751225402, 0.03261142097679632, 0.04212088570264833, 0.0026816354906519075, 0.02394169253031058, 0.027263263938948512, 0.042367417830973864, 0.0737787274909871, 0.07554877429668393, 0.05756624601781368, 0.03288685530424118, 0.04484902734735182, 0.07306178739028317, 0.05127018404060176, 0.019445585486079966, 0.020066607876547744, 0.02010128610501332, 0.06344393348055226, 0.023421212066231028, 0.0330279125565929, 0.09655570278742484, 0.03576103464833327, 0.0486492136094187, 0.05949136521667242, 0.06898065709642001, 0.018663696013391018, 0.03145162481814623, 0.028477324239377464, 0.03232322001297559, 0.015232459775039127, 0.09804257657378912, 0.021644834528810213, 0.07609809589173112, 0.05367930566093751, 0.017551702646804706, 0.022649317414366772, 0.011050612832020437, 0.036788146676761765, 0.019894197217321823, 0.06111202575266361, 0.025022924511826465, 0.040376222891999144, 0.07027862673359257, 0.03704950140256967, 0.06960149628243276, 0.02225134475156665, 0.07756888161280326, 0.025592206910784756, 0.021605247099484717, 0.008276228177627283, 0.0383840813966734, 0.023035527672618628, 0.02023554782915328, 0.045203449936317544, 0.0034553551896741347, 0.013824411401791232, 0.027905007092548267, 0.023764109737905006, 0.0005066620454142269, 0.06613242493144103, 0.050666494827185354, 0.02833671821281314, 0.017925677222332785, 0.06436830173645701, 0.0255030999957983, 0.0567386368555682, 0.010896879697351583, 0.04038968502676912, 0.015878272442413226, 0.05762519035488367, 0.0060739761933551305, 0.027738796547055244, 0.022088501436103667, 0.025007045096052543, 0.03902793649051871, 0.03694904429305877, 0.03582674737221428, 0.021216997843501822, 0.050710589425372224, 0.055866739712655544, 0.008687705383636057, 0.03099659244929041, 0.03606718625607235, 0.0181481179648212, 0.048590201418846846, 0.07759745472243854, 0.0290573529366936, 0.023125230002083948, 0.0901078355631658, 0.014956106032643999, 0.030311438321535076, 0.03093332584415163, 0.01026037653043334, 0.05019064500395741, 0.011981052280004536, 0.03309467361707773, 0.0552430879989905, 0.0073870224545576745, 0.06572731916925736, 0.026312259790886725, 0.013212993674512421, 0.03419636682208095, 0.010919301038874047, 0.003295993182941207, 0.060203698064599714, 0.029019334619598727, 0.030390572468084947, 0.08133416064083576, 0.024450883868017366, 0.032083714114768166, 0.015262386562036616, 0.04576750931196979, 0.0207145765889436, 0.041312648715185266, 0.01773724126230393, 0.04937918158248067, 0.03031764013160552, 0.04066006766100015, 0.028855207176612954, 0.039558788362358294, 0.01451738564563649, 0.014538649236783385, 0.06750924033778054, 0.03213977807068399, 0.030967201704957655, 0.02355238645603614, 0.036357758699783256, 0.03274995068620358, 0.04836633236014417, 0.029523537028580904, 0.058787575124629905, 0.056945813952812126, 0.06765652993427855, 0.008745291802499975, 0.07321959427957024, 0.027227910568139384, 0.04605746089613863, 0.03109170948820455, 0.07810031702475888, 0.05876106476145131, 0.02544057638650494, 0.02888470987922379, 0.05496037299079554, 0.007468362688086927, 0.02927546462576304, 0.024039830746395246, 0.026919747104070017, 0.005180181877221912, 0.04273104474746755, 0.010498419337506806, 0.026444445197869624, 0.042546259305839024, 0.020607948203438094, 0.06774803716689348, 0.10484119890523808, 0.06301289410995585, 0.11497295488204275, 0.15904670847313745, 0.11781885288655758, 0.14596483829830373, 0.10799618318144764, 0.10888267561261143, 0.19731434647526058, 0.13118937185832433, 0.10285406839102507, 0.11349212005734444, 0.15489657116787775, 0.08608874372605767, 0.21509838290512562, 0.10144582324262176, 0.1584988185869796, 0.10407385722334896, 0.08954432580087866, 0.14079019453908714, 0.13177380764058658, 0.17452341371348926, 0.14837481826543808, 0.11566274001130036, 0.10419600031205586, 0.11520810797810555, 0.12216381116637162, 0.09718802278595311, 0.09291477208690983, 0.11086697663579669, 0.1426070670464209, 0.17924252977328642, 0.16254090597586973, 0.13416199306292192, 0.16993995037462029, 0.09970040047275168, 0.11040285868304116, 0.13055852428078651, 0.08846388770533459, 0.17989380125488552, 0.10733442154846021, 0.15815763760890278, 0.14280228157128605, 0.17320236031498226, 0.13658322314066546, 0.0931038051577551, 0.20881172881594726, 0.11403540947607585, 0.08277659716882876, 0.1223823537251779, 0.11332961092037813, 0.14967343929622853, 0.15645591249423368, 0.11887358129024506, 0.12740685125546797, 0.13171919914228575, 0.11118062944816691, 0.22625370217221125, 0.09125820347773177, 0.1410095106278147, 0.14504546406013624, 0.11083996415670429, 0.19028445226805552, 0.1047991161633815, 0.19942644956920827, 0.06921346924666848, 0.15336685468043598, 0.06666180438229016, 0.11909187957644463, 0.10593056652162756, 0.1154525705746242, 0.14707399878118718, 0.1631139830819198, 0.147450002176421, 0.10126142456595387, 0.11210474664611475, 0.12200207555932657, 0.16515215300023556, 0.0882834041757243, 0.05605709931946226, 0.13122895759131226, 0.09417799394577742, 0.13133851385542325, 0.1664968194173915, 0.10333220487726585, 0.13405756652355194, 0.12307008967867919, 0.1125310023448297, 0.18186185136437416, 0.0953410572505423, 0.10914544508393322, 0.10086677502840757, 0.1401377288358552, 0.07248538546264172, 0.1146063966942685, 0.08072379125016076, 0.11750152919973646, 0.059638973724629195, 0.10927511991134711, 0.12269317704652037, 0.1366876768214362, 0.11952542274125985, 0.07347305425043617, 0.11810788166310106, 0.1452334996845041, 0.21727905874805792, 0.21083602947848185, 0.1611826145755393, 0.10487024698938642, 0.07892459458006279, 0.17262945962803705, 0.10501394713563578, 0.14747909775802068, 0.18096477378691944, 0.07423889636993408, 0.12895540387502738, 0.11815573195261614, 0.13910969399980136, 0.22232008539140224, 0.0631006761853184, 0.09674721251108817, 0.12472138607076236, 0.14788722300103732, 0.12158236093819141, 0.06677848526409694, 0.1397093425371817, 0.1550921792430537, 0.15868276943053516, 0.12648989260196686, 0.18609217793813773, 0.14931753410824708, 0.1329436291541372, 0.05041948433167168, 0.13368480652570724, 0.10506222490221262, 0.08899245969951153, 0.08474229276180267, 0.16463494646762097, 0.1827057996498687, 0.11207784273262535, 0.12052025007350103, 0.08015551817204271, 0.11425712757876941, 0.0661513153463602, 0.09098756978554384, 0.14416726332690033, 0.1374624009643282, 0.11711496779961245, 0.17924873158335686, 0.14463017348732266, 0.1453864143363067, 0.09154672335301127, 0.11319647556436913, 0.12780311570635863, 0.21701463365129062, 0.11100982861327273, 0.15188333285706385, 0.10273855458945036, 0.1217577758112124, 0.09189245051571301, 0.17437869576471193, 0.11197549251041242, 0.10473642631300858, 0.10047204406665904, 0.15247958871935094, 0.08107212398733411, 0.15188070014119148, 0.0786870326846838, 0.1240777684641736, 0.09708407800644636, 0.1349855445857559, 0.10856111108192376, 0.11510062803115163, 0.1984486806073359, 0.13785076726760181, 0.18630827777087688], [0.024675699483071054, 0.02102854152742241, 0.006302259122354111, 0.016636017942801118, 0.049921432842633555, 0.01585232187062502, 0.021483824954235127, 0.04363324526431305, 0.011688260178613876, 0.015012987623257297, 0.036981878602611165, 0.04126362116741283, 0.08874946273863316, 0.07294273842126131, 0.017253532307222486, 0.026417510750304376, 0.05025379965081811, 0.036045788654259274, 0.015631565591320395, 0.05453200704817261, 0.07981272906597171, 0.011872504488565028, 0.09567630783255611, 0.012211498039375459, 0.03497439882318888, 0.04335190089685576, 0.0075951096368953586, 0.05672269467530506, 0.014018562323014652, 0.020193449820258787, 0.04942293691315821, 0.08335193379649095, 0.03856119599991611, 0.030118649559361593, 0.017304322349705865, 0.027487178798764944, 0.03130190606628146, 0.021185288205742836, 0.018060456329424466, 0.025330687640234828, 0.054613387145634205, 0.027217854679163014, 0.025285697375823344, 0.03580960418496813, 0.03190216528517859, 0.013813349584649717, 0.0032126735355372405, 0.07400430645793676, 0.04169637383893132, 0.03964871121570468, 0.051522127485701015, 0.029776467742132287, 0.03468246591676559, 0.041839846675949435, 0.08616697202835764, 0.008612667044092501, 0.03774195317445057, 0.015886426736999835, 0.040246052734021626, 0.049072351439722946, 0.059280218689569404, 0.038784128680293045, 0.034182663807379346, 0.009300274075940251, 0.01382198733543711, 0.026348535969321216, 0.028919176065496037, 0.03944338991173676, 0.018656086243156875, 0.08280960789748601, 0.017794178832056265, 0.04039710819987314, 0.06427631952932902, 0.056084685160645416, 0.04679755600435393, 0.08992753523801054, 0.017902281334889785, 0.01729993222813521, 0.07726210914552212, 0.0876043059730104, 0.04253860203815358, 0.07029248920402356, 0.04176582868344017, 0.04730781773105264, 0.07589161090020623, 0.006021760379163814, 0.02900872572458216, 0.05003772356680461, 0.006913474985464875, 0.09229414324675288, 0.016937991471162865, 0.045690878959638734, 0.0464713502941387, 0.03791005683264562, 0.012901435839012265, 0.03613069374114275, 0.014635070759270872, 0.09296653073813234, 0.015343841298350265, 0.017900089666779553, 0.05485865719882505, 0.026064869315762604, 0.088712089029806, 0.0021008103628576335, 0.027621354009690027, 0.006728805742958295, 0.08385966798024518, 0.07252146316958324, 0.0395654651469418, 0.060466915369033813, 0.0333583998227758, 0.00828771323098668, 0.03249176132625767, 0.022256588130923252, 0.02968548298148172, 0.01803967958715345, 0.07437894599778311, 0.060628420274172506, 0.023556315173794116, 0.03759369666555098, 0.05128736454727394, 0.0583126548943775, 0.0192987742567701, 0.06297244663749423, 0.04512505878561309, 0.0439474917948246, 0.03319644369184971, 0.018513870392260805, 0.03857177775353193, 0.02465023915283382, 0.016944934580741183, 0.02789303264580667, 0.02335207613318094, 0.03760931654168027, 0.020209575204976966, 0.02832594477305455, 0.03258102600063596, 0.028381891681679657, 0.020073832578158805, 0.041443809534290006, 0.040052317415497134, 0.04468815347978047, 0.037090871682656665, 0.045591897663793395, 0.02723519973057721, 0.01199635154833751, 0.02492748007976583, 0.0578857817287956, 0.01649861460152481, 0.029189059976488352, 0.03225234363760267, 0.04537236105118479, 0.08564494111176048, 0.023326953374115483, 0.017006302984165292, 0.03147837945393153, 0.03428812511265278, 0.011458456483004349, 0.010671053065120109, 0.031573581309723, 0.012189645819099886, 0.044137305180941305, 0.043118623950119526, 0.05778830338801656, 0.03509685743067946, 0.02534174097568861, 0.028056771627494266, 0.021353237497221147, 0.033554106285529475, 0.03378260973840952, 0.01574195475716676, 0.07490650018943207, 0.027623825573495457, 0.021858369499178867, 0.004267017930812601, 0.029795120669794933, 0.025519325464431728, 0.024916418262624314, 0.06484902344111886, 0.037805481015571525, 0.021524618479556272, 0.02511486939952842, 0.0469157500192523, 0.15090100413986615, 0.0720228688525302, 0.04331541946157813, 0.05297118651547602, 0.0276688107488943, 0.016735516621598175, 0.016867298300244978, 0.017016638768836856, 0.04465844043131385, 0.015566248114087751, 0.018789185976077403, 0.03489969890298588, 0.05389785161241889, 0.014587804009871823, 0.066239070280322, 0.11061854460941893, 0.03934285816337381, 0.07043331914714404, 0.050980035681277514, 0.027514824011762227, 0.03545152768492699, 0.02406694500574044, 0.018110243836417794, 0.0449262514178242, 0.02885941070105348, 0.05441422015428543, 0.03172192942085011, 0.029291939456015825, 0.014342596721170204, 0.05274879327043891, 0.028402156130011593, 0.05269289555560265, 0.05650376874421324, 0.04052100530160325, 0.020127638708800077, 0.019540426021974002, 0.022862221347168088, 0.012115298737106579, 0.004979930926180843, 0.013839620764234235, 0.037490891824875555, 0.020613313719098057, 0.01232778197819633, 0.00706116237311757, 0.053027101193687746, 0.02353864612190851, 0.01120119756420276, 0.03439239558896848, 0.050413218060774465, 0.04680299785520349, 0.016075807557042156, 0.02177109632508031, 0.02993560116738081, 0.052546667866408825, 0.05888896182711635, 0.031416242609598806, 0.021358625065269213, 0.017658180058268563, 0.025712935253977776, 0.012289834059109645, 0.012099021530177976, 0.02756981418601104, 0.054231416034911356, 0.03925461129152349, 0.056390534820301194, 0.03635750764182635, 0.0680774659184473, 0.021570584138057063, 0.05589774197765759, 0.08112536184489727, 0.026129097744290317, 0.03508045045392854, 0.05187580029347113, 0.026893854207758392, 0.03853574075869151, 0.1384252014436892, 0.0275982006985162, 0.028272968151473572, 0.026696500601246953, 0.048131691558020454, 0.04328345028417451, 0.029106841888278723, 0.030897899530828, 0.05957668420991727, 0.03388953667932323, 0.01131937122305057, 0.03185418946668506, 0.030375783797353506, 0.041694324663175006, 0.01060537257165249, 0.13955393087651047, 0.027228992831494127, 0.0825141601796661, 0.0609163905360869, 0.027856327293972884, 0.014969147475702422, 0.058472952007183006, 0.059125960538429875, 0.030116105053041662, 0.02771516317235572, 0.020037018660722033, 0.046675606298127344, 0.028849337848701646, 0.012361339775712361, 0.027406331351292983, 0.032732861781758923, 0.025623402558267117, 0.04524714419884341, 0.011483334969463093, 0.03536909246551139, 0.04108072205313614, 0.005788538139313459, 0.017529161713485206, 0.06019757089338132, 0.00948799418152443, 0.009202044257628066, 0.03393445569755776, 0.03906295568283115, 0.040429236833006144, 0.06855636236390897, 0.013390231262227255, 0.027801469434052706, 0.014616134543237942, 0.05841239954211882, 0.06548568606376648, 0.014629973264943277, 0.024073346983641386, 0.01692555901328368, 0.03193618703101363, 0.05993351899087429, 0.017905063328466246, 0.03926456540024706, 0.0037856393194358262, 0.09384157628353153, 0.008909866230429282, 0.020901278891999806, 0.04174317918451769, 0.028011111309751868, 0.00239310840593784, 0.01907281531020999, 0.06163901676024709, 0.037243487779051065, 0.01809581139657114, 0.03258982320715274, 0.04935229802504182, 0.017905935245965208, 0.00400491724056857, 0.019275011960417032, 0.05632281702544008, 0.03201455443299242, 0.02600760604920132, 0.037397654327963076, 0.04122793361810701, 0.0026441455827028093, 0.06901459741805281, 0.04566086396308882, 0.02199314860627055, 0.019442528685820953, 0.002025859384697729, 0.03579198263053383, 0.019275498809292912, 0.018452688585966825, 0.058061963346387656, 0.016101690275328498, 0.011339319304430058, 0.03081357798406056, 0.058730238915554116, 0.03016083747414606, 0.007252775997455631, 0.1563837977924517, 0.1410661954432726, 0.12922581365065916, 0.08115238789469004, 0.0804788333230785, 0.16770112408058985, 0.1222599595785141, 0.20823991378503187, 0.07178955458636795, 0.2528428296957697, 0.10984997477914606, 0.13924005414758409, 0.14523010700941086, 0.1689833788467305, 0.14145557954907417, 0.15809143973248346, 0.11245170195720025, 0.06212455606354134, 0.12445552247975554, 0.17572353860097273, 0.11508746445178986, 0.15640959569386073, 0.21788018649177893, 0.11473985096173626, 0.15317001167152608, 0.14152056963316031, 0.13496095447668008, 0.14080048112996987, 0.09468287828245334, 0.15836518790040696, 0.13768805457012995, 0.22385182391319955, 0.10520589112171105, 0.15248181431421212, 0.20383364308093274, 0.11143472045660019, 0.1545368390423911, 0.12590523968849862, 0.13268731933619293, 0.09882935828396253, 0.10349626107407467, 0.09689081766243492, 0.13491849175521306, 0.11426742774035249, 0.0780224415606686, 0.09444722985582692, 0.07375044615140983, 0.16124451053994043, 0.1333491216812815, 0.15656823718122073, 0.14615524879523686, 0.16254119096057756, 0.0864741855434009, 0.1318758593073913, 0.19867351997111524, 0.11834619673235075, 0.15648804791271687, 0.07368221945528473, 0.1126722733357123, 0.10190015672040836, 0.15881517875407422, 0.12349714604871613, 0.1272303642971175, 0.06421548886490719, 0.0633386384163584, 0.12176492757030896, 0.1696569062769413, 0.18324451574257442, 0.10600761417299509, 0.15757530528519834, 0.12174184380897454, 0.16112268636269228, 0.13349457244787896, 0.07847083785704204, 0.06312785829816546, 0.1663728646401848, 0.17684472272438662, 0.13071027185235704, 0.19200537992375238, 0.16063719455684933, 0.0885883920959064, 0.170165712546025, 0.21757289155253343, 0.1658961395067828, 0.0818474180996418, 0.12899192262973103, 0.18161814872707638, 0.2507575830178601, 0.08215043826826982, 0.12822394312492438, 0.13647343617464813, 0.15964825690857, 0.08897303324192762, 0.10440519265830517, 0.09445480230663504, 0.12551627627440862, 0.10260490354682718, 0.35779971203633715, 0.1442954928747245, 0.12467399718505995, 0.1208362438316856, 0.14208331943622657, 0.22929039065326962, 0.14103172586432525, 0.14911957830190659, 0.05530227321599211, 0.10284665200327124, 0.15101655865354197, 0.14423910661467484, 0.15072557569614478, 0.12484186674867358, 0.18663671586130345, 0.14201234467327595, 0.08561519413654294, 0.14439396187663078, 0.07164014117526156, 0.12088797534150736, 0.1469434215021985, 0.13432429863938264, 0.06924042744295937, 0.16413447260856628, 0.155576191842556, 0.11960394281361784, 0.20165433787873813, 0.17974395358136722, 0.12046861355858189, 0.1987262014299631, 0.1034891703831298, 0.08149562483387333, 0.11548535738672529, 0.11832915193268231, 0.09349349460431508, 0.1371722865317549, 0.07440043520182371, 0.1490702759474516, 0.07834863370018345, 0.1384810313050236, 0.10849360363291842, 0.10576690387512956, 0.11508773586579732, 0.11780853915427413, 0.11911296844482422, 0.11624874999480588, 0.16198241737272057, 0.1205241855766092, 0.08931088261306286, 0.12065911905041762, 0.13377776582326206, 0.0925682917503374, 0.0950076047863279, 0.15618338568934373, 0.16458123363554478, 0.11824026384523936, 0.11038237371082817, 0.07733793543385607, 0.08802123181521893, 0.08066681466464486, 0.16445801167615823, 0.08008136107985463, 0.11653062701225281, 0.08772791469735758, 0.12168494186231069, 0.08679165850792613, 0.1259905993938446, 0.12185764259525708, 0.06065315966095243, 0.16645472310483456, 0.12335507438651153, 0.23572268549885067, 0.15883618619825157, 0.08935848184462104, 0.2330506145954132, 0.09493866562843323, 0.13950434353734764, 0.1109875523086105, 0.1538191389824663], [0.06365553462611777, 0.033710352544273646, 0.07447008003613778, 0.02446010855159589, 0.0488399328397853, 0.02364336103866143, 0.05237239632489426, 0.08768042403140239, 0.046667548694780896, 0.012239203472355646, 0.036855433601886034, 0.04145831661298871, 0.026335920306986997, 0.02836268405163927, 0.0330041163334889, 0.028293135908565352, 0.029340838082134724, 0.028782512327390056, 0.01285517162510327, 0.019830111281148026, 0.05400029004418424, 0.009617244924551674, 0.04088425563116159, 0.046190969446407895, 0.05681545380502939, 0.021450541115232875, 0.0581901589674609, 0.048006518810455284, 0.05630286470321672, 0.016403059907523648, 0.05400581671191113, 0.01765552020099546, 0.021967165804068958, 0.03717332047277263, 0.033017276520175595, 0.0545780456491879, 0.03193219045975378, 0.04456278395705989, 0.023699289287573526, 0.031957398035696576, 0.019262990016224127, 0.013685014015728874, 0.057192658207246234, 0.006993755432111877, 0.03598255258319633, 0.016990002876679813, 0.04398886886026178, 0.02061764955786722, 0.018240361407931362, 0.07253593632153102, 0.05648473244426506, 0.056590577121824026, 0.015269416184829814, 0.029485481392060007, 0.02591718447261623, 0.020776760930727636, 0.03776307936225619, 0.09212328812905721, 0.07435704967273132, 0.01999116496049932, 0.024023394931906035, 0.043772660461919646, 0.03580835907320891, 0.06716905680618115, 0.031004415958055427, 0.03821887169033289, 0.018972697468208413, 0.018103210820949504, 0.04298429776515279, 0.03845486277714372, 0.011674920180147248, 0.11344448011368513, 0.05269143670531256, 0.10006030901734318, 0.040565971817289076, 0.029515984933823347, 0.04360581548618419, 0.023830857227689455, 0.005841465567105583, 0.011259482025967112, 0.060697352646717, 0.027469733663435494, 0.04403178959286638, 0.03302596176841429, 0.02328683838381299, 0.02211451986139374, 0.08086244988122157, 0.021684576324852448, 0.02271900126444442, 0.008045002951153686, 0.044340753728257756, 0.02778293694635587, 0.11673418751784734, 0.08182172197848558, 0.03209741034411958, 0.04106005048379302, 0.05518933106213808, 0.05575647437945008, 0.03504441345908812, 0.04038852133921214, 0.023673169082030654, 0.052313699653106074, 0.020342895461778556, 0.06466083175369672, 0.05235667127583708, 0.023339372261294296, 0.023328352852591445, 0.013334781380503305, 0.1179143770464829, 0.04525883196453963, 0.08999946673533746, 0.08132960088551044, 0.022149003011041453, 0.012167862300494952, 0.0501743839122355, 0.0040341451364968505, 0.023372527178643004, 0.03559444412322981, 0.047677809306021245, 0.046572567362870486, 0.06969535803156239, 0.023701479259346212, 0.028086852781208496, 0.03709391151954021, 0.012053351882579071, 0.02171320541362677, 0.03143688703754118, 0.015348535064341766, 0.018739992187225392, 0.07074283968125071, 0.02710106862442834, 0.06395390004451786, 0.052201249437140565, 0.027323222685871378, 0.04601461819506117, 0.04383532317089183, 0.03376902546733618, 0.06450414444719042, 0.03176061609493835, 0.016016910717423474, 0.007792569264503462, 0.05278357836816992, 0.009145916689054241, 0.024304790189489722, 0.01887281032811318, 0.04944405292293855, 0.09028762020170689, 0.022881128725462725, 0.010851594270206988, 0.049390360446912904, 0.007227246117378984, 0.042963968855994086, 0.0359514417525913, 0.051807621094797335, 0.028832340546484505, 0.06294361568455185, 0.10237382844622646, 0.029905827050762515, 0.053219917097261975, 0.04929957924676793, 0.028641750237771442, 0.05067586539579289, 0.011324819859250315, 0.02562674434323396, 0.07052147441676684, 0.03929226998505848, 0.052741655082042725, 0.040591691687170944, 0.03052254413653697, 0.02412430496354188, 0.012110954416649682, 0.05234560436968293, 0.05364726523735693, 0.03594997611695102, 0.08803487715444394, 0.041751830506005456, 0.017925304028072526, 0.04972061701118946, 0.03979039950562375, 0.013814366539008915, 0.05312895608533706, 0.028863868676126003, 0.06470852598015751, 0.0538303204146879, 0.025512758941788758, 0.028512214510036365, 0.06363214552402496, 0.03970835105116878, 0.014528615400195122, 0.011546796653419733, 0.06584925869745867, 0.045112251437136104, 0.08872437729899373, 0.02967483676703913, 0.021525207108684948, 0.03060837203104581, 0.06611512907381568, 0.055216106053973944, 0.04940129843141351, 0.01375581999309361, 0.009412977894368981, 0.04415721000571336, 0.014931973934705769, 0.03763303812593222, 0.04498161987534591, 0.002102145380506824, 0.04172792571729847, 0.03502694457503302, 0.03287658906940903, 0.0529575920663774, 0.01135080266145191, 0.055240224581211805, 0.04131088113146169, 0.02127727210920836, 0.004557186646187412, 0.04671707835846713, 0.06564907729625702, 0.02845749574979501, 0.014721022486420614, 0.06369636207818985, 0.018863726440551024, 0.025960105205220834, 0.054671252612024546, 0.010533881273918917, 0.01759098982438445, 0.02844801152657185, 0.06069423138563122, 0.040322903610233746, 0.047686338491205654, 0.05082316517031618, 0.0502419558220676, 0.04963718434529645, 0.06625087678964649, 0.03242764315967049, 0.09640026398535285, 0.028315610684720532, 0.013647251845603543, 0.06093222754342215, 0.03175010219482439, 0.011645412388523775, 0.015916241565719247, 0.05525183770805597, 0.021199210047987953, 0.03956729379881706, 0.04029131101976548, 0.031588872096368244, 0.025078484655490944, 0.03817749123222061, 0.02682092526395406, 0.07478348857590131, 0.02903951085837824, 0.012806502004553164, 0.03608600203213947, 0.07133301586977073, 0.03836091960381184, 0.04740953352302313, 0.08125675336590835, 0.015437219591279115, 0.02844577745002295, 0.03025745407545141, 0.04570572530584676, 0.047090113162994385, 0.027047016524842808, 0.014039250007564468, 0.1194093253995691, 0.004118910699617118, 0.01371700270101428, 0.0608796410794769, 0.05942803754338196, 0.06044903597129243, 0.03255336891327586, 0.03428552632353135, 0.022573894854368906, 0.05526386474126151, 0.030168501527181694, 0.04122228481407676, 0.03083894501573273, 0.08863331111414091, 0.04659479617008141, 0.062916732127113, 0.05604014951469643, 0.05257621467379587, 0.01264699368870684, 0.015119124070874282, 0.07892717979848385, 0.027892727305048277, 0.01713809314449983, 0.021320812005017484, 0.008216382237151265, 0.005808834393974394, 0.03768762626818248, 0.04717408526422722, 0.03121896873095206, 0.03800224260027919, 0.01027699385304004, 0.02652219174030636, 0.09552047548017331, 0.03423936219353761, 0.035904785684709034, 0.017195597290992737, 0.03686676513669746, 0.0186696298021291, 0.011691270329590355, 0.024519200470032435, 0.021681100529219424, 0.033098242711275816, 0.023791846553129808, 0.020465220058602945, 0.08061778372419731, 0.052573476784995625, 0.021660948039165566, 0.023796150161485587, 0.04176902458337801, 0.01636946394241282, 0.028800934553146362, 0.09151630462812525, 0.007354365412278899, 0.01466426472844822, 0.03477916394227317, 0.02500683135752167, 0.023790397880864993, 0.023200208121644597, 0.08883296325802803, 0.03667907556518912, 0.021141495555639267, 0.0319087877869606, 0.015116801784772958, 0.04283696406387857, 0.0240899829659611, 0.02016405907592603, 0.007410084163503987, 0.06279515900782176, 0.08670984754072768, 0.05169742022241865, 0.00939948861819825, 0.0433209563073303, 0.0896193582032408, 0.054529876448214054, 0.04498096169637782, 0.07685946646545615, 0.05430788693151303, 0.04510953390438642, 0.03266734244035823, 0.02362031120407794, 0.12767344766429492, 0.011396141523229224, 0.015800593753478358, 0.015079484055084842, 0.03194993754316654, 0.06922709422984294, 0.04877077315800956, 0.0360386945706393, 0.1601173145962613, 0.1233200484088489, 0.29715276775615557, 0.11316840457064764, 0.21901781830404485, 0.13506162193204674, 0.1625844407826662, 0.14497995828943594, 0.0988651577915464, 0.09559709565447909, 0.22879427298903465, 0.11284542868712119, 0.08582431184394018, 0.11293417428221021, 0.12440027615853719, 0.085319162878607, 0.1644525019718068, 0.2120662270379918, 0.1076527630378093, 0.09315997428659882, 0.12908418982156686, 0.18846216505127295, 0.10641456555042948, 0.08769579963492495, 0.10598379080849034, 0.09409066648887736, 0.16962585651448794, 0.12394396135849611, 0.18179255936826977, 0.0754004872537085, 0.2109257182372468, 0.13010967336595058, 0.08198540498103414, 0.10929358284920454, 0.127822304676686, 0.1449857936905963, 0.16985252792281763, 0.12834644583719118, 0.09685461103383984, 0.20351304885532173, 0.28380535968712395, 0.057334159900035174, 0.10113155974873475, 0.14263696329934256, 0.10563655051269702, 0.12284094840288162, 0.15932690272373812, 0.15954912294234547, 0.15208888825561317, 0.1254597000245537, 0.11559145312224116, 0.12535090371966362, 0.07438516816390411, 0.14494295098951884, 0.08927626375641141, 0.09820427146873303, 0.15220993890294007, 0.1478474201368434, 0.15316341631114483, 0.10637337847479753, 0.13718957560403006, 0.12677143035190447, 0.12412382742123944, 0.12316731017615114, 0.08231763608221497, 0.2054593451321125, 0.11508940506194319, 0.07890834366636616, 0.11538231505879334, 0.12833862911377633, 0.0827724648905652, 0.21693141811660357, 0.12113583061311926, 0.2236448707325118, 0.14832342602312565, 0.13313161049570355, 0.1519500192786966, 0.15302316312279018, 0.2405743465891906, 0.12371897271701268, 0.14878088076199802, 0.05591092252039483, 0.12706059483545168, 0.08432327703173671, 0.08642360754311085, 0.13027595515762055, 0.1054895119741559, 0.1498579601091998, 0.1528362538665533, 0.06777832697012595, 0.10391016743545022, 0.13175387228173868, 0.21080174988933972, 0.11503258453948156, 0.09850740698831421, 0.19380298203655652, 0.09311684660081353, 0.23104551647390636, 0.0772571965519871, 0.13829466487680162, 0.1499660371669701, 0.2095765056354659, 0.09567673530961786, 0.15543403875614914, 0.13800854023013795, 0.12547413924975054, 0.08133707155606576, 0.11056995471673352, 0.2770909842635904, 0.08903540418084178, 0.11549200702990804, 0.13565527221986226, 0.1387857070990971, 0.07678976056299039, 0.17661354584353312, 0.10803658994180815, 0.10167640301265887, 0.08460657218737261, 0.16316616242485388, 0.1302198674529791, 0.1865022030792066, 0.1026510303573949, 0.12332570739090443, 0.08184627816081047, 0.1373676367636238, 0.08982378723365919, 0.1039788012525865, 0.07619356576885496, 0.0733385414683393, 0.13465570871319088, 0.12333554614867483, 0.12816159932741097, 0.1121198372649295, 0.16829279304615088, 0.09920813010207244, 0.13646352956337587, 0.09807975350746087, 0.14141481316515378, 0.1537835837474891, 0.1871503804411207, 0.07910078976835523, 0.14316976256668568, 0.09577970978404794, 0.0980526256774153, 0.11811432774577822, 0.09847661506916795, 0.2177940939686128, 0.09102163902883019, 0.1345517842897347, 0.09558310426239457, 0.08085707588387386, 0.11831891962460109, 0.0940985307097435, 0.11840684419231755, 0.10051341434674603, 0.14797839096614293, 0.12914799925472054, 0.11789015334631715, 0.0920553599883403, 0.10675930883735418, 0.1386706954134362, 0.14501981543643133, 0.08237915206700563, 0.11605833949787275, 0.19213210312383516, 0.13737610488065652, 0.17580930542732986, 0.12512689216860703, 0.1819361780903169, 0.17172989861241408, 0.13578275537916593, 0.1320175781313862, 0.07965716812759638, 0.12074538799268858, 0.17134591564536095, 0.10210745595395565], [0.06872835063508578, 0.07333208860031196, 0.052303223072418144, 0.008778992092369922, 0.009641297294625213, 0.02025449931222413, 0.007658679886454982, 0.036612701269664934, 0.014566915309322732, 0.024489972574104155, 0.008249831469064313, 0.07732378797871725, 0.021682917306731855, 0.07169629673340491, 0.017221739548923712, 0.0233631175942719, 0.035595383894230635, 0.018573515316737548, 0.05303371351744447, 0.01876093856325107, 0.050408892400030575, 0.017035625874996185, 0.03790525280471359, 0.013135858661761242, 0.057636107983333726, 0.02700644521974027, 0.050818591844290495, 0.10571925714612007, 0.06178775163633483, 0.020645839295216968, 0.01346511353871652, 0.0026700819476640648, 0.0380873342842928, 0.05726438614406756, 0.030466225729989152, 0.021995168944288577, 0.00944163158003773, 0.055262429639697075, 0.039451807138643095, 0.04142703614862902, 0.02330543363599905, 0.001083937639902745, 0.03896259017554777, 0.019646915307800685, 0.02760177488172693, 0.045126022305339575, 0.06535595695355109, 0.024397954743887697, 0.0072701736353337765, 0.052507570678634305, 0.016657225554808974, 0.021265362123293535, 0.05030682037717529, 0.06348006547029529, 0.052868995748992474, 0.02468750429605799, 0.05844811084015029, 0.004735169350169599, 0.0373779123515955, 0.06611611973494291, 0.047236931177654436, 0.014448419346341064, 0.03520128397004945, 0.061586925626865456, 0.0380005326920322, 0.06262483993279082, 0.07692874489086014, 0.028942236078104804, 0.04687685978465846, 0.03553356935403176, 0.04844269469114287, 0.01558517075942031, 0.06655346269586257, 0.006763609924486705, 0.025552787418876375, 0.053242739622614214, 0.041059310880622694, 0.009841317543759942, 0.045864468573459556, 0.02649171364360622, 0.05798461713961192, 0.03188043859388147, 0.016124955544780408, 0.021221596614590714, 0.0702280623040029, 0.04045630020222493, 0.011364002712070942, 0.006349609416377331, 0.008909786502564592, 0.0553433924381222, 0.0011473032687458076, 0.021211184494729553, 0.04684052423440984, 0.039687594664948325, 0.04035405854561499, 0.03015379428065249, 0.013874486437998712, 0.005983060982543975, 0.007746981889275568, 0.02638623707129487, 0.05440332627456103, 0.039745755294071775, 0.0314614296491657, 0.057638577850801606, 0.05585499766415783, 0.03542167553678155, 0.025423894603071467, 0.022901627268376093, 0.017966184066608548, 0.02292013431100973, 0.011046818973097419, 0.013260289261649762, 0.04475961678794452, 0.01780335771452103, 0.06292489490338735, 0.09666745750499622, 0.09044153908533709, 0.04413402446412614, 0.04916032350489071, 0.02255413930730096, 0.00716480308411909, 0.022822043592376367, 0.03670241038448044, 0.019763262011110783, 0.03429263737052679, 0.050828844508422275, 0.03799552510359457, 0.016836601376001323, 0.03300181949245078, 0.031978201919368336, 0.02189808415382036, 0.018768818051155125, 0.020505759133292095, 0.030281528497913053, 0.03686343692243099, 0.045877805179251094, 0.06596877585564341, 0.0453679878929896, 0.03584147497479405, 0.016955221171623895, 0.030678634332226853, 0.05351449968293309, 0.024720002730776156, 0.038841787193502696, 0.04857255611568689, 0.01152184946529035, 0.01647025183774531, 0.018224941699632576, 0.01679136005363294, 0.037890464133982144, 0.06120800453105143, 0.06603797964219536, 0.03384926223329135, 0.018615523419742073, 0.009790057615776147, 0.030358477761702876, 0.02641308161297015, 0.03093711885490588, 0.029042788182518313, 0.03020803297736815, 0.05175268350701247, 0.03585022807653461, 0.07595860944794756, 0.01344984395629061, 0.02065160345020039, 0.0563537310808897, 0.02187570946158043, 0.0090180705135156, 0.03907261462882161, 0.005984460036935551, 0.0050317417397829035, 0.03676942250292216, 0.022437417713393058, 0.013530336869215327, 0.032140989255692275, 0.028432769933715463, 0.01583165199761944, 0.03702044653307114, 0.018340289260127714, 0.009316346874194486, 0.047326613151069195, 0.038470346946269274, 0.02414822841196188, 0.04819643397682479, 0.021569135465792248, 0.012898069457150996, 0.023867340359304632, 0.028482192728136266, 0.02845964500946658, 0.05231707197214876, 0.04339787842971938, 0.03157475856798036, 0.03529612620228103, 0.059181390064103265, 0.03492833308077284, 0.008997552462720444, 0.020933114058737243, 0.008574607166727739, 0.02606728490042899, 0.019467463151418736, 0.010259504612934376, 0.016679596854373813, 0.0332290303361203, 0.03087215930489557, 0.04106600123590656, 0.07644494942256383, 0.021492345657731806, 0.04609361324193222, 0.046502861460404735, 0.02630808680052204, 0.04116761864029935, 0.018070401956460307, 0.02639980098631765, 0.01849301901113774, 0.031071858946233988, 0.011239726478899164, 0.0325385361377682, 0.010160125525934356, 0.0208028845289456, 0.011038627359084785, 0.014007508987560868, 0.018227077388603772, 0.033042735154075284, 0.0674476157873869, 0.03152972759146776, 0.0523090177614774, 0.04616923936243568, 0.002356870183055954, 0.01565781302217926, 0.04056890308856964, 0.028643544962895767, 0.043291423070643625, 0.026803819396133934, 0.020187225957800235, 0.06497014872729778, 0.03454744423340474, 0.04464351944625378, 0.04708958390567984, 0.00537340108504785, 0.04094303372715201, 0.022998364309647253, 0.08707157455916915, 0.04224859956385834, 0.05641905703981008, 0.04092791935961161, 0.030607591715774367, 0.04686139597158347, 0.042760913858988454, 0.03344135072880557, 0.005626076499798468, 0.03037486777507833, 0.02293760489140238, 0.02554139311957572, 0.01915495197421738, 0.07962705474346876, 0.03760304348543286, 0.0203293688661818, 0.002542940600376044, 0.017254726528855305, 0.008843134007682758, 0.035622620289879184, 0.07431738930089132, 0.02647008025087416, 0.010902867768891156, 0.02830807724967599, 0.041986549339656315, 0.011003183234216911, 0.03379931866324373, 0.0585592548762049, 0.03537589817174843, 0.030221203342080116, 0.004064769966394773, 0.03114862839824387, 0.03891075688547321, 0.017375931542898928, 0.03309555231992688, 0.03931003403184669, 0.020491591322102716, 0.0483133557385632, 0.049975681717374494, 0.024190524892349328, 0.052529059882674894, 0.05066018784418702, 0.03758588333481124, 0.03974071717155831, 0.035112300887703896, 0.03251673820029412, 0.026029841641762426, 0.014742297951930335, 0.00801600660530052, 0.03449783653819135, 0.05444996877174292, 0.04971741432590144, 0.03698051813989878, 0.03464507863723806, 0.02860251734299319, 0.03869095225153225, 0.05554652885933008, 0.02901174859809024, 0.04014263381915433, 0.06592245905527047, 0.041090866151664934, 0.02104693491544042, 0.008761893858068755, 0.06673942878842354, 0.016396503562905958, 0.01803726569882461, 0.02632016981286662, 0.053832159244588444, 0.030634244571306875, 0.03826238274840372, 0.0201481355553759, 0.05166745272332004, 0.04368245940921562, 0.025178080025528158, 0.020681486132421663, 0.05399339273571968, 0.04953256781612124, 0.028738702713911022, 0.01420280832930335, 0.027669560530089905, 0.02164909742506487, 0.03601658111438155, 0.04878911056688853, 0.032646094116249254, 0.04217842886490481, 0.026679320094574775, 0.0574174365028739, 0.0410725117794105, 0.024040337951321687, 0.09613357936697346, 0.060831152967044284, 0.027107945576842343, 0.017522690185744847, 0.015668873142983233, 0.013352162903174758, 0.024442079876150404, 0.02851695746981672, 0.03728756880653756, 0.03286676727501409, 0.03488999245954411, 0.04371074414146798, 0.02827725140377879, 0.06803914226059403, 0.03825800959020853, 0.10025135055184364, 0.046689003972070556, 0.020727967477536628, 0.03725191518398268, 0.020590457266994884, 0.030584769190422127, 0.036726199822234254, 0.11189009209296533, 0.15165344519274576, 0.133474162114518, 0.15871888106422766, 0.12389596179127693, 0.10100715035306555, 0.14215900323220662, 0.1315465798335416, 0.10142176239086048, 0.0910308671050838, 0.09681368180151496, 0.25975411598171505, 0.07250929703669888, 0.13276056040610584, 0.09516064835978405, 0.11629992510591235, 0.09394258979175772, 0.12089320006115095, 0.20778408753020422, 0.14284842195255415, 0.08232054699744497, 0.09260934990431581, 0.18358602241746017, 0.10575770294027668, 0.1109803734081132, 0.07144956782992397, 0.1024332002603582, 0.13832031350050653, 0.14128030038305692, 0.2463094602738108, 0.0707205565912383, 0.0993402883676546, 0.15509194854114736, 0.2025283859776599, 0.14838248571114881, 0.11556423029729299, 0.11119761996503387, 0.13810363012765134, 0.1258959166173424, 0.1100426312269909, 0.07126009371131659, 0.11667337720947606, 0.11582667407180582, 0.10318656412086316, 0.07296311482787132, 0.07589685597590037, 0.23650891759565898, 0.14877933370215551, 0.05641558972586479, 0.11886053984718663, 0.11354449617543391, 0.11258751752653293, 0.1638169317905392, 0.22777956458074705, 0.11258059646934271, 0.12064497838062899, 0.08681455906480551, 0.13031897427780287, 0.12885228012289318, 0.1402175109833479, 0.12645634583064488, 0.09186802325504166, 0.11393091508320399, 0.18257267107920988, 0.12920576972620829, 0.12237946316599846, 0.15426515362092427, 0.08484586434704916, 0.2710927075573376, 0.13991119313452924, 0.25577762935842785, 0.14371292984911374, 0.19270706655723707, 0.08959649835846253, 0.12857675419322082, 0.13323700055480003, 0.14097628955330166, 0.11049026756414346, 0.1597917942064149, 0.1511005341474499, 0.14546726856912884, 0.1288121651325907, 0.06905224254088742, 0.08140488434582949, 0.12504350021481514, 0.1337215152702161, 0.12522010930946895, 0.09558074974587985, 0.06129249571157353, 0.30811612946646555, 0.11797058688742773, 0.09207625208156449, 0.1329145607139383, 0.0905875258945993, 0.14161587666187966, 0.09971391010497298, 0.06955146789550781, 0.068023787013122, 0.05914239465658154, 0.10129552773599114, 0.1516293707702841, 0.1298067889043263, 0.15199970161276205, 0.10775704708482538, 0.1096459257283381, 0.13746423300887856, 0.1520677451044321, 0.13395324854978494, 0.13616407848894596, 0.13467750325798988, 0.04504549716200147, 0.11357565450349025, 0.13186033442616463, 0.12890972489757196, 0.1165944364454065, 0.13253953440913133, 0.2594740710088185, 0.10702684840985707, 0.10998240445873567, 0.10246967151761055, 0.12572219808186802, 0.08995229498084102, 0.07545692779655967, 0.1122357581875154, 0.17598020125712666, 0.09914894149239574, 0.10914803708770446, 0.09875151674662318, 0.17046269375298703, 0.11346640358013765, 0.11054668775094406, 0.08265680181128637, 0.1012624627245324, 0.10407590639910527, 0.13168797296072754, 0.08016568941197225, 0.20441387194607938, 0.1992787324956485, 0.15692738576659135, 0.09118483348616532, 0.14301779786390917, 0.15787653412137712, 0.08498041784124714, 0.08724684693983623, 0.14543764373021467, 0.08258282792355333, 0.13978100940585136, 0.1090461957667555, 0.1351070294954947, 0.15061926282942295, 0.10546191595494747, 0.20173956187708036, 0.15258215607276984, 0.08740825006472212, 0.2763283923268318, 0.17501069685178144, 0.12570214058671678, 0.18067501219255583, 0.0981013241357037, 0.07745898608118296, 0.16223462883915218, 0.1424909018512283, 0.16040293712701115, 0.13970031802143368, 0.10915962646582297, 0.14911938831210136, 0.14980017606701168, 0.2142906683896269, 0.1107609894658838, 0.17779885152620928, 0.08315154883478369, 0.14903018809854984, 0.1439707460147994, 0.06173126359603234, 0.09205143127058234, 0.10307190527341195], [0.01208279182070068, 0.04596046431522284, 0.04728643369993993, 0.03859267323943121, 0.016991244595763937, 0.03576994381312813, 0.02001569400142346, 0.022793612975095, 0.017223600431212356, 0.06093524702425514, 0.005712301761377603, 0.026014956279790828, 0.026025814536426748, 0.03821086497711284, 0.01691861590370536, 0.04066387424245477, 0.0015004745967287037, 0.030502822516219955, 0.07568959066910402, 0.02922779754070299, 0.06567414916519608, 0.032636204468352456, 0.023410978061812263, 0.007647515440891896, 0.013278501141550285, 0.029129664413630962, 0.044321256024496894, 0.03136998687737754, 0.03685085688318525, 0.05889325016843421, 0.065279289281794, 0.02371005085296929, 0.030812370191727365, 0.03293844432170902, 0.03334979599873934, 0.03825405373104981, 0.010965398163534701, 0.010184015047603419, 0.0619848117764507, 0.07348690993551697, 0.06851809977420739, 0.06962252408266068, 0.08412075468472072, 0.05089016032538243, 0.012751723872497678, 0.006132528676451849, 0.040799574460834265, 0.014068608521483839, 0.02383164263197354, 0.011471626847716314, 0.0557274500440274, 0.012719827637608563, 0.05815851887954133, 0.016853432437138896, 0.03272580841024007, 0.040157999244651625, 0.010632269699791712, 0.02043983436721776, 0.014998232879276787, 0.06961622049233743, 0.039716296696237156, 0.029608333549861397, 0.03738588174538953, 0.019836360588669777, 0.06792360131761857, 0.034433199292314906, 0.08955086009310824, 0.07237071304449014, 0.023620524942608814, 0.05326508038810321, 0.024369622514184033, 0.017178805245618736, 0.0023053231499423938, 0.042162907376353226, 0.07750606284077678, 0.05395633793835129, 0.00459854886867106, 0.0320081931671926, 0.023564242159149477, 0.010317987546191683, 0.03148395361910973, 0.05695878754236868, 0.02249133580231241, 0.020153289028842534, 0.006394750654830464, 0.010626187481518303, 0.0390359228476882, 0.05347634905150958, 0.10334682730691773, 0.01264874091637986, 0.05321388831362128, 0.029250596317329576, 0.005505339674917715, 0.031462539053921185, 0.02635518221982888, 0.023736213466950824, 0.04604888082082782, 0.029413705957787376, 0.03810699483645814, 0.04081333175833736, 0.1263187796409641, 0.023550199876938547, 0.004937244712242058, 0.07044745981693268, 0.01748954544642142, 0.01246265014300921, 0.046014126257172654, 0.01495916283290301, 0.04335341402994735, 0.0323871719384832, 0.015836013281451802, 0.044463120733520815, 0.019570575029190098, 0.02754781099169382, 0.05389556155673095, 0.06621412733303648, 0.06029473710805178, 0.02840346230992249, 0.011439093638078442, 0.06672904041728803, 0.019450935734702007, 0.0455209059374673, 0.00987259207093822, 0.06423458284033196, 0.03639551917357104, 0.02048433099740318, 0.03293451899662614, 0.02405233445045139, 0.02559590492663639, 0.039530992175319364, 0.04558681882917881, 0.020558583084493876, 0.03521423041820526, 0.03559894959575363, 0.030118510459682772, 0.009385593917353876, 0.03386083125535931, 0.033158944454044104, 0.031352575668799024, 0.04392964632383414, 0.05359837678926332, 0.03951433074793645, 0.044300526779677184, 0.05092959678066628, 0.02394695796205529, 0.02149845247289964, 0.023025743197649717, 0.016271137432860475, 0.06518597714602947, 0.034849158222121854, 0.007097368153543877, 0.0319496016683323, 0.03324272656547172, 0.04406482746292438, 0.03048805080886398, 0.005569446391226458, 0.010891263971903493, 0.057714376997734816, 0.012825399204822523, 0.01900810681815658, 0.03557286670963679, 0.06677706712590796, 0.02298417953508241, 0.05921239911445549, 0.0024042482546065003, 0.03680294891819358, 0.025027572476704205, 0.06346462201327085, 0.06013760196843317, 0.07218674863023417, 0.043690550939313004, 0.022916225949302316, 0.045740995556116104, 0.08054940096501793, 0.06529507200632777, 0.02739386835933796, 0.030722321809402535, 0.02488363653953586, 0.04660695551761559, 0.03478880931756326, 0.08346282677458865, 0.015668973226898482, 0.030227557822529758, 0.023233111981036406, 0.047308245208114386, 0.055410628473120074, 0.03819791852895703, 0.03549193783796259, 0.027023564658260772, 0.019038459385878274, 0.00937840568700007, 0.035402099801493545, 0.023586886569059322, 0.01897140316266034, 0.016712802661848918, 0.07788936727281127, 0.00875311276675867, 0.03485423027138625, 0.026541277234043394, 0.047801150009036064, 0.023089272735108222, 0.02204056972238634, 0.013780492374540439, 0.06407397360141788, 0.008866562973707914, 0.06641817638384444, 0.031028113793581724, 0.03943812447999205, 0.04435639056776251, 0.0714035699410098, 0.022204054253441945, 0.03658181096294096, 0.06935995817184448, 0.010880330228246748, 0.04817470728552767, 0.0281065811868757, 0.013259726925753057, 0.04867736263466733, 0.023440492638785924, 0.057996355795434544, 0.05147294726754938, 0.011325560310589415, 0.07452814227768353, 0.045487097930163145, 0.04588443446638329, 0.04208662307688168, 0.04507720510342291, 0.030229081133646623, 0.019573579242985164, 0.04659974269036736, 0.059965159078793864, 0.03758878067934087, 0.044151093012520244, 0.031829436509204764, 0.027477402805483768, 0.024344503147793666, 0.05944326386920043, 0.02463341996605907, 0.028242452735347406, 0.03870324052071997, 0.04996882851368614, 0.07808470393397979, 0.024186735274270177, 0.059753429011574814, 0.014280081593564578, 0.031401294483137984, 0.020221380017963902, 0.01176086936279067, 0.026563054815466915, 0.033185118942388465, 0.010972212351459478, 0.07385354276214327, 0.03714416043034621, 0.10089902579784393, 0.009474746633454092, 0.06739134487829038, 0.04938141057001693, 0.04489777669576662, 0.07003605724977595, 0.035140212425695996, 0.020095247143347348, 0.0762002696948392, 0.08505443922643151, 0.024510601735008613, 0.07925346014755112, 0.011624433782084711, 0.03284365637227893, 0.0408990578725934, 0.044551024945186715, 0.017122050880321434, 0.026659681594797542, 0.031756460067949126, 0.005308720158479575, 0.02994485299236008, 0.03730648297018238, 0.05163069648135986, 0.046409681638968844, 0.013986828936530011, 0.08535995640392814, 0.06620611383446626, 0.018118586424472075, 0.025623704506350414, 0.01656031039809542, 0.007650161727464625, 0.06853082909115724, 0.02051116536105318, 0.009420354418190462, 0.016683171037584543, 0.036180990149400065, 0.057856441874589236, 0.03425306860091431, 0.007609006034077278, 0.03311355046129652, 0.04391174317736711, 0.042895833762096505, 0.008879070918607925, 0.06817285437136889, 0.04506519164091774, 0.02167014727768089, 0.040611392951437404, 0.02129117868441556, 0.07304362300783396, 0.009247888627994274, 0.02909259943823729, 0.020199225849605033, 0.027741039105291878, 0.049825912075383325, 0.024233530441831266, 0.03275737725198269, 0.048605203828109164, 0.07732832059264183, 0.011257945144149874, 0.028608563090009347, 0.036526405185993226, 0.03180359789569463, 0.051141913780676465, 0.030161336197384765, 0.04132170376500913, 0.034564448320972066, 0.030503270349332264, 0.01735484437085688, 0.00870422092598996, 0.06641949274178062, 0.06624065126691546, 0.10387938230165414, 0.054105982051364014, 0.020034623432106206, 0.0368862730184836, 0.05311991799888866, 0.07596721327198402, 0.035971411038190126, 0.021075618287016238, 0.02056769241711923, 0.10137789510190487, 0.04478686675429344, 0.0675632788666657, 0.06466913702232496, 0.06417052234922137, 0.0026757258747238666, 0.018503836555672542, 0.018118238675275018, 0.023579627940697328, 0.04558698167758329, 0.03824236596535359, 0.038789424646113596, 0.08546174344207559, 0.05276611287678991, 0.04249035480565258, 0.01247543459092932, 0.054182123858481646, 0.06720867646592003, 0.04885420243122748, 0.18134993740490504, 0.11637224336819989, 0.11356581574571983, 0.09241205906229359, 0.14305139891803265, 0.12717287881033762, 0.1390239271734442, 0.09847527835518122, 0.12257087789475918, 0.1462218945047685, 0.16156380197831563, 0.10400341850306306, 0.0787806094491056, 0.13101445910121712, 0.1688326219362872, 0.08840823426310505, 0.06751160842499562, 0.11848053309534277, 0.1624047104269266, 0.17790369875729084, 0.15465630191777432, 0.10528025177440473, 0.1580576758299555, 0.08926634357443877, 0.10759947768279485, 0.16355443373322487, 0.08076153815324817, 0.12765063531696796, 0.0846513554986034, 0.12217606550880841, 0.11274254920759372, 0.08823156410029956, 0.13992133044770785, 0.18588023073971272, 0.13612742402723857, 0.11077202244528703, 0.14014953534517968, 0.07109291625342198, 0.17251070242907318, 0.14935564063489437, 0.09556185933096067, 0.18234040854232653, 0.19137917352574213, 0.13227726705372334, 0.12678424109305653, 0.06768583586173398, 0.1263609573777233, 0.08322767367852585, 0.13134798620428356, 0.15604409602071556, 0.14742189725594862, 0.11236752968813692, 0.11834801520620074, 0.1492803775306259, 0.13614430597850255, 0.15733579599431582, 0.15611337444611958, 0.14683961921504565, 0.055412090716085265, 0.12908180137830122, 0.07126789686403104, 0.06920458043792418, 0.1553132730935301, 0.11622888248945985, 0.12646246621651308, 0.12784989391054424, 0.14057386400444166, 0.21864494974059717, 0.08283119209642921, 0.11473534548921244, 0.12890496158174106, 0.08064341877720185, 0.09571142880512135, 0.14418247608201845, 0.11319055195365633, 0.2529747911861965, 0.08290919648217303, 0.16658957515444073, 0.09793323744088411, 0.22161132842302322, 0.09628775609391076, 0.2160837243178061, 0.13470543175935745, 0.12224413614187922, 0.06289062209959541, 0.15726503836257116, 0.17158402715410503, 0.08852401947868721, 0.23060232454112597, 0.1182246303984097, 0.08167548411126647, 0.17906955762633256, 0.11344445975763456, 0.11090853012033872, 0.09072687663137913, 0.10673020647040435, 0.08630402931677443, 0.09996510376887661, 0.10476039216986724, 0.0648800732035722, 0.1887038592249155, 0.08430603545691286, 0.15797260110931738, 0.19142177195421287, 0.07265948397772652, 0.08026027040822165, 0.1606590433844498, 0.11279442999511957, 0.14137268971119607, 0.05938495056969779, 0.08887222329420702, 0.1525126469454595, 0.11528080622000353, 0.13269832517419541, 0.07731207646429539, 0.16370037304503576, 0.18708488824112074, 0.1193883858088936, 0.09002798556217126, 0.131761851853558, 0.10542563468750034, 0.08249949703791312, 0.09085706036005702, 0.14599405601620674, 0.12670671168182576, 0.09659705271146127, 0.1002041312998959, 0.13276278600096703, 0.09353124829275267, 0.10885001772216388, 0.20521533036870615, 0.15378390944429807, 0.13241792736308916, 0.11255914797740323, 0.13019102971468652, 0.14792556022959097, 0.1328750564051526, 0.07601334686790194, 0.11039169678198439, 0.1427298276019948, 0.2806966650698866, 0.10741893987038306, 0.1313026329236371, 0.1866213266870805, 0.0960583026920046, 0.09266983451587812, 0.14473219801272663, 0.15794706105121545, 0.3134304428739207, 0.1623864306935242, 0.0975172615477017, 0.045302828175148795, 0.1171710147921528, 0.14684283547103405, 0.08263154673789229, 0.08424283670527594, 0.1063102815034134, 0.16107375041714736, 0.08445468212344817, 0.13957272629652703, 0.14906824034239563, 0.14095231012574264, 0.09503400658390351, 0.075505660181599, 0.06453516706824303, 0.14905323114778313, 0.11828070453235082, 0.1640635656991175, 0.0945202809359346, 0.18384770623275212, 0.13203644140490464, 0.11508686734097344, 0.22296463937631675, 0.21302020656211035, 0.15755066089332104, 0.13942366572363035], [0.005862500152683684, 0.023903703050954, 0.03105309066761817, 0.03927310476345675, 0.03931192375187363, 0.020421678466456275, 0.026303321788353578, 0.037411964631506374, 0.03273249198017376, 0.0501515410308327, 0.032074034812727144, 0.025256410108080933, 0.02262111071364156, 0.048586086103958745, 0.02113114620026733, 0.049116459608610184, 0.026812421523832848, 0.016136181906663945, 0.03608514368534088, 0.02586553438699671, 0.02776531539192157, 0.031032877109412636, 0.0213672916537949, 0.029632027992712598, 0.0320475515909493, 0.03809665396277394, 0.012196253902012748, 0.026286395732313395, 0.032445756651993306, 0.011695408545035337, 0.04124308530507343, 0.0161159717411335, 0.04341295547783375, 0.03355647098006947, 0.0314195097557136, 0.042853238726300855, 0.062643330012049, 0.02264738528590117, 0.022577967760818343, 0.03898420151589172, 0.060144455172121525, 0.039132688726697645, 0.02132356516085565, 0.029996720209185566, 0.049480927908527, 0.0308490009047091, 0.05436778461028423, 0.038937589552785666, 0.07226778606751136, 0.007196058951584356, 0.022199557262605855, 0.028974680230021477, 0.06307229985083852, 0.036604769195296934, 0.03888143738731742, 0.017149894564811672, 0.02370822729010667, 0.013229390473238059, 0.03478028013237885, 0.015787481064242975, 0.04680437528129135, 0.0262207271132086, 0.039005795892860205, 0.04153128966156926, 0.012504327460192144, 0.025883768319285343, 0.020677538754950677, 0.031748938507267406, 0.01077910213332091, 0.04582186335963862, 0.013557027892342635, 0.05876341249261584, 0.0012649579543254472, 0.03654403691845281, 0.048543318041733334, 0.04276895110628434, 0.008397562113324446, 0.009715096459590962, 0.0495696870743164, 0.04135656689426728, 0.07759584659444434, 0.035369024612009525, 0.04257759405300021, 0.014081049461050757, 0.04186754447541066, 0.03635051194578409, 0.015149003360420465, 0.056803165535841665, 0.031867861947310824, 0.039486677053251436, 0.02045061968133918, 0.05183700166110482, 0.043160937393882444, 0.040373488395873985, 0.012582761867504035, 0.024825311365670392, 0.04585949151909777, 0.041838652454316616, 0.10242379576499973, 0.031440988781728914, 0.04571332489805562, 0.05509925214573741, 0.018720418148274933, 0.024703943503222296, 0.018659506059650863, 0.0042182813049294055, 0.05765950387077672, 0.04408192993806941, 0.025211998294772844, 0.016878149771530713, 0.0775075556178178, 0.00300047973204138, 0.04142855606707079, 0.020666685587327396, 0.03766053915023804, 0.026156067814944044, 0.03229213632377131, 0.056242559903434346, 0.012649913933793349, 0.038907374388405254, 0.04076705567006554, 0.06012744429920401, 0.12642108915107592, 0.009371125006249972, 0.039143484218844345, 0.04998889957953777, 0.019884696030723195, 0.03838557078103934, 0.05407955650506275, 0.06485747798745121, 0.059471803052084785, 0.04600953596777149, 0.06375601209167923, 0.026077249187177846, 0.017538510229704634, 0.025837770430371165, 0.06546616461127996, 0.0545971260539123, 0.04516241553106478, 0.00720012083183974, 0.047133702252592356, 0.032696231068777185, 0.059289365341620784, 0.029299240492816483, 0.036897879359977584, 0.019339745897533636, 0.04999836514304791, 0.03639520026211228, 0.042039719343717606, 0.031780249505702934, 0.09752843023410865, 0.04032331412392003, 0.049255718743162494, 0.041486855795873065, 0.01178816004124071, 0.02740219228767923, 0.018119728059640954, 0.02627385301249368, 0.022933703315045153, 0.015290742540465934, 0.03101464148078646, 0.046595746119107516, 0.003146282700721973, 0.01085866121242621, 0.009296188446959215, 0.007050945332074272, 0.05209657523248877, 0.007651891143593405, 0.015424101813031095, 0.03662479954904743, 0.039076305859323056, 0.03600331575476697, 0.04541969226141061, 0.025708775834313462, 0.06192909048071929, 0.02892589016950556, 0.04143368239913668, 0.011092045876596655, 0.0790554229170084, 0.06733314014439072, 0.007002218460131968, 0.03076150720672948, 0.025118078870166625, 0.009478268230200877, 0.025279970540265952, 0.013823198520445397, 0.05862746121627944, 0.023129338531621864, 0.08712174543844801, 0.08629378343799285, 0.01568862360103854, 0.014553673698433807, 0.04116564749607018, 0.02998549723997712, 0.0479348248003849, 0.02611863812697785, 0.04253740781652076, 0.08574064847614084, 0.05391449607642634, 0.02251774268890066, 0.026758033549413085, 0.04463856614061764, 0.09110072228525366, 0.025571482754977684, 0.027839567479012266, 0.023073795351332853, 0.046235871501266956, 0.03043717086049063, 0.04197384037875703, 0.018473215966618488, 0.003326183114300615, 0.005971908411343715, 0.03194255168948855, 0.04989395556705339, 0.03675376870004194, 0.0368900388878371, 0.022032574883529117, 0.011533048685773142, 0.05163746147549578, 0.031058349314012697, 0.036082470257367404, 0.036222014376627545, 0.020021358072491627, 0.059500857921583314, 0.043832093344203064, 0.002219644109053271, 0.004836314324555653, 0.020905182164694582, 0.023699525078492503, 0.04482846434361168, 0.03123672938506518, 0.0681744082165616, 0.05492202897689172, 0.06393127768699612, 0.015452276283342923, 0.01665903385063367, 0.014907931742657508, 0.014879677544480987, 0.05254082567989826, 0.0620133306032845, 0.01474377715827099, 0.01301529401514147, 0.018157186585345438, 0.024249443784356117, 0.08226437108325106, 0.10528008214065007, 0.06167670259518283, 0.07388044667563268, 0.01657931107495512, 0.01567093249676483, 0.03664526077253478, 0.026436950778588653, 0.02232671302876302, 0.030997264198958874, 0.044452959671616554, 0.1099869099312595, 0.062328381197793145, 0.05614190941144313, 0.0396492540437196, 0.012486501497083476, 0.0035341748776513016, 0.057064740785530636, 0.01865984532716019, 0.02496362055119659, 0.030181268163557564, 0.04455507579924805, 0.03071828113336648, 0.030731251330247948, 0.023133737134880254, 0.0052215763301189455, 0.02097622647748462, 0.04826719160856945, 0.07602376238043819, 0.06481115440172808, 0.09013239174549069, 0.04150542051398328, 0.02632399505403425, 0.05805838068148919, 0.032902933191508055, 0.07619161158800125, 0.03912479057908058, 0.039084180258214474, 0.0639600000743355, 0.048728320614567826, 0.019521503376641443, 0.04785782125379358, 0.09008104700062956, 0.025413648724289875, 0.02351271251349577, 0.015377145493403077, 0.024544981408065984, 0.019612617058945552, 0.020624233043885658, 0.006133020190255982, 0.04340338474139571, 0.06740571624998536, 0.08431350612746817, 0.03386295846264277, 0.061984648928046227, 0.053146000885005505, 0.029543285790298666, 0.0589911017034735, 0.012625271238253584, 0.021270664874464273, 0.01647461990692786, 0.05013410607352853, 0.05356010062886136, 0.005203341125577156, 0.030518913974187205, 0.024336593125813773, 0.03593050216191581, 0.06958432934646096, 0.07282202704144375, 0.029558074461030107, 0.010174742018404816, 0.06807207835039922, 0.06751352189374821, 0.0019378601781292154, 0.023529005835631063, 0.03646759316325188, 0.03068620678303497, 0.029834553732403686, 0.019967400967808704, 0.052735728078654835, 0.019004332467115352, 0.03138668562418648, 0.020526876839409982, 0.056777873143021546, 0.042804672582341094, 0.043806929873036485, 0.03315028634720615, 0.05717408670378583, 0.009901182143948972, 0.020069910645751015, 0.0032478687228701475, 0.07069207847650562, 0.07723508988107954, 0.016737640436206545, 0.00344684614849809, 0.029512174959693636, 0.05295358531709228, 0.029953321109392812, 0.046693750324526, 0.025527106564758078, 0.012959581201097794, 0.11835072934627533, 0.05918149184435606, 0.053005265936787636, 0.04375968687236309, 0.023260263559807624, 0.11933037106479917, 0.025352502541084374, 0.11154208505260092, 0.12041697704366275, 0.18614479154348373, 0.22056140404726776, 0.10315712927175419, 0.24837022540824755, 0.10727570112794638, 0.08324172613876206, 0.10026469733566046, 0.08695642038115434, 0.07856212117310081, 0.08974956228796925, 0.2283625075859683, 0.14065775807414735, 0.19148887906755718, 0.122468554813947, 0.11144791117736272, 0.10047423573476927, 0.13716286846569606, 0.12749797850847244, 0.18212135029690607, 0.1502634390656437, 0.1400295974952834, 0.10878266633621284, 0.06019962685448783, 0.0815511222130486, 0.18530715363366262, 0.11509480620069162, 0.12458969599434308, 0.1558908149600029, 0.10958591609128884, 0.09302698820829391, 0.1133145203015634, 0.16243261178689344, 0.07192477983023439, 0.10131177186433758, 0.14935688913932868, 0.1668714386011873, 0.10827782271163804, 0.14492427770580563, 0.1444822528532573, 0.09825100217546735, 0.12844811752438545, 0.16272668886397565, 0.09842355363070965, 0.12324551812240056, 0.060739021482212205, 0.1563374674213784, 0.1847245634666511, 0.1162775063088962, 0.057811129306043894, 0.07671931505735431, 0.1228497964995248, 0.10106768246207919, 0.1722969367567982, 0.12922973558306694, 0.14661469842706407, 0.16766807942518167, 0.16619742262576306, 0.06506367799426828, 0.09735076262482575, 0.09145261054592473, 0.18224174955061503, 0.11896385358912603, 0.1096394050068089, 0.09471508833978858, 0.11374938660966498, 0.11397678405046463, 0.2377094088920525, 0.13397217967680522, 0.13423361921949045, 0.2550729028880596, 0.1260115254138197, 0.13737868331372738, 0.10961528987224613, 0.0803674314437168, 0.052419849671423435, 0.12605166754552297, 0.10898939560034446, 0.20343703936253274, 0.1834795195609331, 0.15292459912598133, 0.15601038640098913, 0.06706796865910292, 0.19326664081641606, 0.12119725160300732, 0.07203035987913609, 0.13021465630403586, 0.08578743346567665, 0.18102312779852323, 0.14054471414004052, 0.1477754275713648, 0.2029987871646881, 0.16681715579969542, 0.08663882528032575, 0.2583175759230341, 0.14926259991313728, 0.12047195195087365, 0.18739423235612257, 0.16776977825377667, 0.1304822705153908, 0.1147746733788933, 0.13690418377518654, 0.14863864625138895, 0.1575594682778631, 0.1543258417929922, 0.20402751410646097, 0.10366069725049393, 0.12947240684713635, 0.08589046222290822, 0.14384491848094122, 0.1440597969506468, 0.12335618718394212, 0.09752687638891594, 0.052607841191015074, 0.08865699877164193, 0.0585155775770545, 0.10695705429783889, 0.10447284259966441, 0.08675301593861409, 0.1091856143570372, 0.1741569098085165, 0.15459036188466208, 0.1140607324029718, 0.11403836788875715, 0.1913021326597248, 0.08522876844342266, 0.1346875320055655, 0.052983736020645926, 0.20184073144836084, 0.11051028434719358, 0.10025878051029784, 0.14830088508980616, 0.15740450445030416, 0.2127973756619862, 0.12020711973309517, 0.1696077667708908, 0.0997539572417736, 0.11384475470653602, 0.18978365271219186, 0.2028393450060061, 0.1447725844170366, 0.10123895148613624, 0.10666659381240606, 0.10363217842366014, 0.06477941931890589, 0.09662912706179277, 0.11944982036948204, 0.1261068731546402, 0.1328210857297693, 0.22292195952364377, 0.1288217053349529, 0.1111326434516481, 0.1484358457050153, 0.13740815887493746, 0.12859215693814413, 0.13817370922437736, 0.11872916189687592, 0.09330123170678105, 0.12838329028870377, 0.11612322101635592, 0.11076018879456179, 0.11191120131739549, 0.17822218952434404, 0.10677509834723813, 0.1316141076385975, 0.12064913101494312, 0.06414945383689233, 0.11679636846695628, 0.19314837216266564, 0.22365779003926686, 0.11493118426629476, 0.17530819374535764, 0.11231562175921031, 0.1491917608571904, 0.09672270382621459], [0.033606635073998144, 0.08288329680051122, 0.036233803922576566, 0.04614631844950574, 0.04817488709730761, 0.022565920371562243, 0.03462810508374657, 0.024304296555263654, 0.03518440541146057, 0.06110522683177676, 0.011218814877793193, 0.015963152084233503, 0.039303360639938285, 0.04440331804965224, 0.021673394067745124, 0.00976411298116935, 0.011675016023218632, 0.007779575318896345, 0.022019499513719763, 0.03933038668973105, 0.05648138726662312, 0.014444495717595731, 0.013342531946753817, 0.05654581416664379, 0.007316272456331977, 0.05539855733513832, 0.0430712452424424, 0.012442729203030467, 0.010994209608595287, 0.056670437300843854, 0.04555985384753772, 0.04384987435436674, 0.012807993933425417, 0.042061157657631805, 0.043638748183314285, 0.04213092462824924, 0.02478895545937121, 0.0394200245583696, 0.048745830210724046, 0.05302971355350954, 0.06437679699489049, 0.06566549784370831, 0.024428653364468898, 0.024211445823311806, 0.019711896910199096, 0.008511890174954065, 0.03097095400361078, 0.03735948334048901, 0.050862588054899655, 0.0594672297260591, 0.01237481039217008, 0.03602088302639978, 0.032997897560042996, 0.012614636898173817, 0.01989653816313616, 0.03417672323329108, 0.11470787839165755, 0.08267869813633816, 0.016973378768722926, 0.029925175476819277, 0.03194050590640732, 0.045078860728868415, 0.03676910698413849, 0.016052493093801395, 0.013616241947082537, 0.024921629411567534, 0.05910484452864953, 0.008615495686951493, 0.02011238524158086, 0.065880016689854, 0.033246478864124844, 0.02363999211229384, 0.0296198279330773, 0.023840935169053928, 0.027172730404085348, 0.029336464923939536, 0.025041684308754544, 0.06181394987340484, 0.033071114881230254, 0.12413439899682999, 0.03583195173580732, 0.05170472804456949, 0.004272101854439825, 0.01818979867467923, 0.044822282889591794, 0.05176609814433115, 0.01662230135739914, 0.0811182643686022, 0.05378186622900622, 0.059117071729685576, 0.03652100743991988, 0.07552596194935696, 0.03896860878116318, 0.11582523557756629, 0.033166913847838125, 0.014444261623014296, 0.02241217960337443, 0.037392548351947746, 0.0010420604729526012, 0.03367964544200471, 0.05089914073635425, 0.03187645220064691, 0.044899188048605404, 0.047369157296738455, 0.009278284452323402, 0.06308558556650366, 0.047698090717728646, 0.04387129570490547, 0.044844097790441344, 0.035636184204901965, 0.007727327274291643, 0.027491806407592127, 0.034990534385932345, 0.0284501455192055, 0.06488626144294228, 0.039385619440249035, 0.010500689885312957, 0.0370280970154064, 0.03471292535375271, 0.02374178932846657, 0.03134497268391507, 0.04450259790090578, 0.04205119337088295, 0.051930812520108054, 0.036787563136645725, 0.058958973070340495, 0.03752127323033554, 0.01333648111072502, 0.05013951739030225, 0.028991436652307, 0.06705759385866777, 0.01527201327761369, 0.0298995098897389, 0.015575649216771126, 0.02855545754677483, 0.03162098037345069, 0.06382770610174962, 0.04426579935742276, 0.015694358918283666, 0.012411141701574837, 0.03687679049159799, 0.03888948820531368, 0.01167584044326629, 0.010486351592200143, 0.04565199890307017, 0.10030698363802262, 0.009589940675401261, 0.039649752766958306, 0.012806132202968001, 0.05724441685846873, 0.030258122432444776, 0.04949080737839852, 0.034249468972640376, 0.02599438140168786, 0.017654765330787216, 0.02025207015685737, 0.022089502275256172, 0.015422624303027987, 0.024506925771545087, 0.02477839745448104, 0.050841655249574354, 0.04072112563465323, 0.056114259109433205, 0.02028781538163977, 0.005241100751196167, 0.011183073045685887, 0.024852062608780603, 0.02940759914261954, 0.05185242476207869, 0.03628039892230715, 0.044296564135168276, 0.07204278385532753, 0.049323874193110635, 0.03321137824761016, 0.07758036921066896, 0.03971126875174897, 0.019172074805412973, 0.07957916374185256, 0.01659820318621184, 0.035884416063449213, 0.01909940200857818, 0.02873293516625251, 0.030284680293074677, 0.03716475736083729, 0.03161491427038397, 0.03985827336353915, 0.0465529305594308, 0.05513392189251525, 0.0365432871372572, 0.034835295751690865, 0.024624302151745985, 0.008567703921081764, 0.006743145732408655, 0.027549069674153413, 0.0048200146411545575, 0.017981958309454576, 0.021297894484762634, 0.029548744604523693, 0.028618300067526952, 0.013648376517396952, 0.024627813570467488, 0.03616316842713526, 0.01275100462537791, 0.019175704967762743, 0.05123625050431915, 0.02067515709703522, 0.05147346295416355, 0.03313853072800806, 0.027348131706405963, 0.014677508035674691, 0.0809371362307242, 0.11402049527636596, 0.0146389723356281, 0.047327213654560704, 0.04895703780597874, 0.069971474286701, 0.045915144961327314, 0.04339714561189924, 0.021832581775795137, 0.01792718526641173, 0.023853488066898923, 0.050179445783474615, 0.03086830522598965, 0.014990226166056735, 0.04303653817623854, 0.02875419706106186, 0.04477586770164115, 0.02699835199330534, 0.03610664985275694, 0.022423310970355357, 0.0464495625346899, 0.03724235801824501, 0.011751359694504311, 0.03203485620075038, 0.007507305509144706, 0.08810149572257485, 0.054640569258481264, 0.03945691990000861, 0.056401181034743786, 0.037985408146466525, 0.04021697411579745, 0.02162994916683861, 0.04903725082320826, 0.029125355716262544, 0.022744190180674195, 0.06692535416888339, 0.025359009691913213, 0.03788511049268501, 0.014470202016777225, 0.024424780625849962, 0.04387576385800328, 0.04236947039940527, 0.07367020938545465, 0.07444821763783693, 0.022338297317868898, 0.035134129359253814, 0.009577918731208359, 0.012699409670728658, 0.028901143997375454, 0.04855786583253315, 0.011310104979202151, 0.05189677381089755, 0.02541704648839576, 0.058439819142222404, 0.015174046391621232, 0.08511574486536638, 0.04140570300764271, 0.015660924105239764, 0.03630573881257858, 0.018176937043400745, 0.05002109945884772, 0.00430477670826284, 0.02344270975195936, 0.054265651519277265, 0.020784141695392982, 0.03701227357877152, 0.07803269422480039, 0.02459031093998679, 0.03692649996706417, 0.004578841667223189, 0.036255669713552506, 0.031080510267721753, 0.06953869786645685, 0.0746880526255284, 0.0651020695056234, 0.005853382338370595, 0.013529933140879231, 0.03987705182018025, 0.009166326174246413, 0.019173623561593037, 0.03954661883679884, 0.0513444666617683, 0.03797374073682087, 0.012390835692973008, 0.021661577380395362, 0.017195290253896798, 0.04217786568083933, 0.02435660481985126, 0.04741253943315574, 0.1648877686155694, 0.03702723527593272, 0.02873647033369967, 0.020976123000894274, 0.030026511289179325, 0.027731597290507386, 0.015276768111756869, 0.03463654266670346, 0.00796187817052539, 0.03700295050761529, 0.08121992248509612, 0.05585896030866674, 0.03473201593650239, 0.025180510877232467, 0.03212326592100518, 0.058293730552707396, 0.02246900860752378, 0.04150826696838651, 0.033354162371584346, 0.0503023997215288, 0.019934985653630326, 0.07959050884736435, 0.07417550762849194, 0.03991916170343757, 0.03698403634397047, 0.0446038997865149, 0.030665884659226452, 0.03055349211873753, 0.057326417815472396, 0.09317520739776747, 0.04534692955868585, 0.06329498147325856, 0.04182680184021592, 0.03669483454099723, 0.10292461567691394, 0.0335163424190666, 0.014121658933748091, 0.052774377433317046, 0.08045597347830023, 0.00710604407192607, 0.013376721630005963, 0.030550455674529076, 0.03633507527410984, 0.058152602054178715, 0.01933706907688507, 0.020001188619062304, 0.11502597560839993, 0.01455221145546862, 0.012245121994055808, 0.0579634943444814, 0.04243288628224816, 0.051799977397812266, 0.030699312686920166, 0.14170405907290323, 0.2954957038164139, 0.09070104480321918, 0.1706872209906578, 0.18378357110278948, 0.07442767159747225, 0.12300381037805762, 0.06610270509762423, 0.10596723455403532, 0.12575274572840758, 0.16716565138527326, 0.08818265529615538, 0.08769453755979027, 0.14687851284231457, 0.08938058173017842, 0.11803458631038666, 0.047039541948054514, 0.046220546787870784, 0.17406247130462102, 0.12842842643814428, 0.14534467086195946, 0.11928626628858702, 0.10171873002712216, 0.1528364031442574, 0.142888767644763, 0.15165162671889576, 0.10759572538414172, 0.10465899189668042, 0.10311641717063529, 0.14476745469229563, 0.11460110412112304, 0.17965472622641496, 0.12894005541290554, 0.11374517290719918, 0.14180113029267105, 0.12306874617934227, 0.14875656206692967, 0.11475883637155805, 0.15159840243203299, 0.1833642500319651, 0.20741036401263305, 0.12054957635700703, 0.132597630577428, 0.09492075230394091, 0.17301070131361485, 0.11984395422041416, 0.1437203801636185, 0.09698767175099679, 0.16717958849455627, 0.1576834637671709, 0.12643669545650482, 0.08617408986070327, 0.11718594256256308, 0.0866704246561442, 0.09418986830860376, 0.10820281745067664, 0.15539507727537835, 0.26001087363277164, 0.0457948135611202, 0.16516885853239469, 0.23069465958646365, 0.1779344363936356, 0.10397687421313354, 0.11871810177607195, 0.08546236769429275, 0.09428096163485732, 0.12233386561274529, 0.07607192479606185, 0.08863635095102446, 0.11894370109907218, 0.13372148812881537, 0.12468992918729782, 0.11912047304213047, 0.12631901034287044, 0.1273930769945894, 0.11832505358116967, 0.17466848450047628, 0.13535595685243607, 0.08561393884675843, 0.25586879732353346, 0.09360955801925488, 0.11928337572940759, 0.0726358031055757, 0.10289994414363589, 0.10226729166294847, 0.1013680359880839, 0.10932433405624968, 0.0984269395204527, 0.1286089846066066, 0.18183114086943014, 0.1126720222777554, 0.17515014936881407, 0.18154687540871756, 0.19570245939706052, 0.06014334237469094, 0.1434012787150485, 0.18104083756250994, 0.17302298279745237, 0.08274318610451051, 0.1465422308870724, 0.16146401661847318, 0.09983948658087424, 0.17522180266678333, 0.12550892095480645, 0.12177267644022192, 0.20030142047575542, 0.13344870348061832, 0.11970272394163267, 0.16626922520143644, 0.06343924480357341, 0.08982857769089085, 0.1334244662097522, 0.11333803153995957, 0.12318930828145572, 0.17403889899807318, 0.10961786830531699, 0.10348464455455542, 0.11862993293574878, 0.1868274249136448, 0.10990173343036856, 0.16136406841022627, 0.09470038448593446, 0.19704403169453144, 0.2515339085033962, 0.13464865194899694, 0.1364697449441467, 0.18699012404041632, 0.0793029253504106, 0.11585040922675814, 0.09317467135510274, 0.17978856047349318, 0.07236101677907364, 0.10640612457479749, 0.16011806098478182, 0.11105988414159843, 0.09290810208767653, 0.15736589580774307, 0.09699552240116255, 0.08707342695977006, 0.07377018473510231, 0.133101171414767, 0.1256927903741598, 0.11777565734727041, 0.1530400857861553, 0.11909779640180723, 0.16559033734457834, 0.20650807528623513, 0.125722523778677, 0.11404341618929591, 0.10461089733455863, 0.10510909810130085, 0.095864526661379, 0.24344693816133908, 0.20589168050459453, 0.10888244491070509, 0.05613491032272577, 0.13099620650921548, 0.10417497929717813, 0.11472514032253198, 0.13695480248757771, 0.13361693945314201, 0.17274699546396732, 0.14205130615404674, 0.12356003267424447, 0.10323478081928832, 0.10380696225911379, 0.19304712116718292, 0.14374712801405362, 0.11197032207357031, 0.13799012478973183, 0.1274538194494588, 0.15888734773865767, 0.1330484085317169, 0.10399991726236683, 0.13709403787340435, 0.12902408518961497], [0.04258749387892229, 0.032318097073584795, 0.0221715710857617, 0.05128631281799503, 0.022983278779845153, 0.07090345570551497, 0.022925097794671143, 0.03656715799921325, 0.03551179516528334, 0.005725043800859047, 0.08472011145204306, 0.038936259624149115, 0.02524308198397713, 0.007595042631562267, 0.04027775049741779, 0.08671176100948028, 0.026038311455132704, 0.017037732726229087, 0.03500981156581214, 0.09062777659190552, 0.019709172592099224, 0.009041046557415808, 0.011295805701852908, 0.020022754158292497, 0.03106376063078642, 0.031760551634111574, 0.08804919424333743, 0.03846198060948934, 0.01942255431120949, 0.040601252245583704, 0.03803965362853237, 0.024504737496109943, 0.046369125600904226, 0.10059911331960134, 0.013042891730687447, 0.03359282010101846, 0.07733665300267083, 0.04317559035761016, 0.04390634882396885, 0.014525090410773243, 0.012924372018980128, 0.021556947280519774, 0.009551391404654299, 0.02641244209371507, 0.020097457471170595, 0.06241334056747811, 0.08154340048453637, 0.023832187156326005, 0.0615860503166914, 0.054140611086040735, 0.05233311253998961, 0.02407090086489916, 0.011067989265679248, 0.07025208244366304, 0.016440116401229585, 0.026683978237477795, 0.03977511889700379, 0.10497355394597564, 0.06750184430607728, 0.00594542603773464, 0.05079570146543639, 0.03780528424041612, 0.019488529967410222, 0.031476181000471115, 0.015235218019889933, 0.035339443877871544, 0.006275004915161324, 0.02985483853678618, 0.0202562482362347, 0.031154480762779713, 0.028586310534072772, 0.024479501082428863, 0.03788821818307042, 0.01590096265343683, 0.05501843862501638, 0.025228484999388456, 0.06355589175862925, 0.020965544639953544, 0.03520302441237228, 0.021919536038434932, 0.015336811675557067, 0.01868524119657065, 0.05117287872625249, 0.05783690006605216, 0.036173936777881215, 0.008580754693996693, 0.040210246441087553, 0.04331857804208994, 0.06814717860626322, 0.007134416589646467, 0.07457897812128067, 0.036488668460931094, 0.07838688271918468, 0.032218009765659056, 0.011919172430810119, 0.030696571405444826, 0.06657231239868061, 0.011104100899371718, 0.012088907117556249, 0.03116597853867071, 0.009738428734375961, 0.0520232595237238, 0.07879951343472515, 0.033407138993165324, 0.013434165556515967, 0.016359440283849835, 0.008245374342160565, 0.07132731617561408, 0.0020418706907158984, 0.03831261130315917, 0.05806040271584477, 0.0928949588643653, 0.032640692977500815, 0.03458990016952157, 0.04222392803058028, 0.015292791716222252, 0.049556245295596976, 0.021445175599572913, 0.008733536183301891, 0.039457829136933596, 0.02386622247286141, 0.01867407590283879, 0.007761739177762398, 0.0183259382444833, 0.02191988378763199, 0.04915506485849619, 0.01935949974826404, 0.01421979969433908, 0.06897729156272751, 0.05052042659372091, 0.05869553863470044, 0.043959905592990775, 0.02681915937656803, 0.05084541094090257, 0.0440544221284134, 0.024482071033811996, 0.014092442064013864, 0.014501273831618684, 0.04286916394318853, 0.03293244267946907, 0.01958963507786393, 0.039678278379142284, 0.0774231730028987, 0.03434179723262787, 0.04871100440089192, 0.0826258131169847, 0.03662979356678469, 0.035651600520525656, 0.017598161939531565, 0.049606785976461, 0.017924004633511816, 0.04496532824954816, 0.039472383713083606, 0.08779045527002641, 0.015775201276742985, 0.05055332197142499, 0.011251805250399878, 0.012530458691929067, 0.03469717994864498, 0.017951118892857006, 0.050415850776646814, 0.03188098820724657, 0.021919712457539778, 0.054056404890226464, 0.045632647084338326, 0.039473262415932756, 0.01218974420667759, 0.004609374470809209, 0.02481432588371847, 0.06551900213318211, 0.011059829033911228, 0.03325382061302662, 0.011654956831729837, 0.0648336410522461, 0.08875100979847567, 0.04215969451303993, 0.04172738967463374, 0.04004884331620165, 0.03360166819766164, 0.09181859876428332, 0.04764130072934287, 0.04591280740818807, 0.00700413786606597, 0.024612916334133064, 0.023654300719499588, 0.02258862754596131, 0.03599952274401273, 0.028957204560616186, 0.026070999879656092, 0.02841561656844403, 0.013026585686020553, 0.06567399988749198, 0.021177568173568164, 0.025552526182894195, 0.04949331456529243, 0.014923015576122063, 0.03689490398392081, 0.05279473687655159, 0.0035651260404847562, 0.02587368868158332, 0.015769152137051736, 0.07080958717103515, 0.03661190059834293, 0.046700189621852975, 0.008924783822814268, 0.044823592462177785, 0.020653969841077924, 0.03145557389195476, 0.028028266371360848, 0.021353474984477674, 0.059358284143464904, 0.030710050503590276, 0.08677428801144872, 0.04203548528520124, 0.012241613968009395, 0.01656245456875435, 0.020293589714648466, 0.007187539096256452, 0.04836473780285035, 0.002140522897077192, 0.04880609090573021, 0.03749691043049097, 0.01112967064338071, 0.00035839472236278065, 0.015520540298894048, 0.028603277302214077, 0.02091655271526958, 0.012874701559277517, 0.02993988272334848, 0.01500375785066613, 0.01176359283272177, 0.028320423194340298, 0.039230770963643274, 0.018220855222482766, 0.0032925667931392255, 0.016873113345354795, 0.028907149032290493, 0.01913746103777417, 0.02034241539825286, 0.07265941612422466, 0.045092706235923936, 0.0298275682143867, 0.04091008745932153, 0.02317686821334064, 0.03445153670119388, 0.037899821131889305, 0.029286477249115705, 0.07268421657915626, 0.005352293981039631, 0.006269564760649311, 0.06721873235489641, 0.09389093292078801, 0.0437485894321331, 0.020561516052111983, 0.05356142716482282, 0.07180618547967502, 0.02240204737920846, 0.03756051630313907, 0.04234544686707003, 0.028290114731394818, 0.01091349617178951, 0.016998265736869404, 0.03174198352332626, 0.05497272572081004, 0.04911798291972705, 0.034802186635455916, 0.07669929827430419, 0.034327646384813955, 0.007811369773532663, 0.054053728069577894, 0.010646320463690375, 0.04024836993111031, 0.07990980028573956, 0.03689215930977038, 0.007457219446743173, 0.030239588248410394, 0.030352961272001266, 0.04822587900395904, 0.045949794352054596, 0.03895382011043174, 0.02048567958575274, 0.020074032745989304, 0.028948726265558174, 0.03447847454143422, 0.03196426820276039, 0.07639933151326009, 0.01699231837743095, 0.025718763869787966, 0.047835066581943204, 0.027178240108436773, 0.01887100881763867, 0.016314823213698607, 0.002997230821555214, 0.03518130450642534, 0.08026189889226641, 0.01923386729322374, 0.039230214564927986, 0.027821781379835944, 0.011351145321636327, 0.03406424926859992, 0.012791525888522821, 0.07745842289711748, 0.0858033179704632, 0.016753046573804956, 0.04022978824962463, 0.05402700736054352, 0.019478373994518603, 0.03396241473300116, 0.05396347951942256, 0.06395639705338649, 0.04771749681926199, 0.029720339325389693, 0.03085225448012352, 0.007079836504999548, 0.07589963118412665, 0.01608297458317663, 0.019582965078630617, 0.02767769107595086, 0.08620199800602027, 0.029562980269214938, 0.014806020871869155, 0.04946485002126012, 0.04581748680876834, 0.04184229958004185, 0.029684543210480894, 0.025916419424382702, 0.018304566087733423, 0.027826831376712238, 0.049014577575560124, 0.03844990607883249, 0.032862502682421885, 0.034262008299785, 0.03021731533642326, 0.011086591303215494, 0.02644249949870365, 0.048663364457232614, 0.015217118098267486, 0.048045205484543524, 0.013755664778208094, 0.026240430073812604, 0.039550337208701034, 0.04822784336283803, 0.038148073346487114, 0.0344916856182473, 0.030060594103166034, 0.029806547199508975, 0.026539553755096028, 0.011569476686418056, 0.008627740699531776, 0.010971903618025993, 0.018678301479667425, 0.031031401295747076, 0.10885370895266533, 0.13729963398405484, 0.14122035859950952, 0.2889289776129382, 0.11152054835110903, 0.18346613885036536, 0.0799943186076624, 0.1552502779023988, 0.08422316597508532, 0.0985569671860763, 0.18812128262860434, 0.08752079188291516, 0.08122398012450763, 0.12927074623959406, 0.07111935197774853, 0.15269627209220613, 0.13774563505181245, 0.12983501596110208, 0.1285290260400091, 0.2347857914865017, 0.07624351273157767, 0.14430978282221726, 0.09059488799955163, 0.12897156657917158, 0.1629788460476058, 0.15815063512751035, 0.13676440556134495, 0.1259431697960411, 0.09827915459339108, 0.15019067297024385, 0.08213029256356613, 0.12734344894332544, 0.11261143588594028, 0.2016592776136739, 0.19310075257505688, 0.09418595316154615, 0.2010868111891406, 0.11891712966774191, 0.14997294465345995, 0.10553306035165276, 0.06821123909737382, 0.11377239573214736, 0.13209315336176328, 0.09192432809088912, 0.08911809045821428, 0.11896662201200213, 0.22079103386827878, 0.1123179898464254, 0.1511052024683782, 0.09148313105106354, 0.19889194039361818, 0.11296014860272408, 0.1741737239062786, 0.17774961702525616, 0.18442984856665134, 0.12147344249699797, 0.15360364983124392, 0.135438222438097, 0.08120297946568046, 0.11742986233106681, 0.18143323436379433, 0.15245942265859672, 0.0883148271324379, 0.20478630624711514, 0.10910563543438911, 0.08946830273738929, 0.1344116803790842, 0.25760207431656973, 0.1375980129731553, 0.13449670081692083, 0.0842472743242979, 0.10623512017939772, 0.06236292541559253, 0.106487100943923, 0.12927578096943243, 0.1451547760516405, 0.18901312191571507, 0.09823525337768452, 0.10686365395252194, 0.11544605663844518, 0.06062796565571001, 0.16756715412650788, 0.12968018784054688, 0.16968469907130512, 0.14315023432884896, 0.06984196909304176, 0.11010853054800204, 0.18521515785583428, 0.15844446793198586, 0.12208850735000201, 0.10420718256916318, 0.10336763119058949, 0.13548449852636882, 0.16438148649675505, 0.08624750056437083, 0.1094244858250022, 0.1709216141274997, 0.0927351163700223, 0.23031766553010258, 0.06352304387837648, 0.13351811761302607, 0.1417323268417801, 0.10177183217768158, 0.14115026593208313, 0.06849014413143907, 0.14559714017169817, 0.15767807619912283, 0.1487342111234154, 0.11033454377736364, 0.10554538254759141, 0.20644508009510382, 0.16315476303654058, 0.11870949795203549, 0.07428896546896015, 0.11825890998755183, 0.13332317450216838, 0.10127866614077773, 0.10483773837664298, 0.12824751543147223, 0.07088934217712708, 0.11606011725962162, 0.08068214277071611, 0.09318480866828135, 0.19823072158864566, 0.09929533542266913, 0.09474536457232066, 0.2298266233078071, 0.10292658342846803, 0.20673706728432859, 0.12827666529587337, 0.12855619458215578, 0.08922930913312094, 0.16705108753272466, 0.10431095771491528, 0.11641754236604486, 0.14158944093755313, 0.05777320598385163, 0.18397172886346067, 0.20783721682216438, 0.15847946676824773, 0.09340777527540922, 0.0918288446430649, 0.14448274139847073, 0.1562188459294183, 0.10768020299396344, 0.15340136497148446, 0.24454209368143762, 0.14680847445768969, 0.15047567124877656, 0.13814636426312582, 0.0773567987073745, 0.1266733141882079, 0.1964229821626629, 0.1799847385180848, 0.17855548592550413, 0.1268403966511999, 0.18000236685786927, 0.17874023744038173, 0.12653903210801737, 0.11975273197250706, 0.14385755280298845, 0.16630792883890017, 0.08682851653013911, 0.09179221053740808, 0.12247258531195776, 0.1077878118625709, 0.10978434687214238, 0.16304722880678518, 0.16661024333110877, 0.14372436994952814, 0.067088711474623, 0.09192022295402628, 0.1021872041746974, 0.08583184358264719, 0.1420067942568234, 0.15936775053186075], [0.016032725672370622, 0.027815767863233174, 0.02820127583774073, 0.03600124961563519, 0.007212823007388839, 0.06698351140533175, 0.012961256334425082, 0.0350950287788042, 0.013225304844257022, 0.060379893252892156, 0.04150251977677856, 0.02678952775230365, 0.02980489835941366, 0.01186992775183171, 0.03445696158866797, 0.05139559766809855, 0.02998003164040191, 0.03981909475156239, 0.019215058302506804, 0.04224446728559477, 0.032579404301941395, 0.033051447543714724, 0.06442106461950711, 0.0026728374359663576, 0.06014216172375849, 0.02495768167344587, 0.010314795887097716, 0.049001620949379036, 0.023079863150737116, 0.04933465950723205, 0.041271566812481196, 0.027745644661730955, 0.053333564927535396, 0.014652071454163109, 0.04711032672119992, 0.07522549307239906, 0.06516782633428063, 0.01373865220895303, 0.014708160855142134, 0.0604146613872477, 0.033337290598345656, 0.011867742869071662, 0.044808145612478256, 0.04219337699136563, 0.032168917757059844, 0.02213357651739248, 0.05944959460092442, 0.010222057113423944, 0.0376965015062264, 0.02639837606277849, 0.03757428717134254, 0.020607094945652143, 0.0231071809705879, 0.07762722883905683, 0.018593165690877607, 0.06430705038032361, 0.07077073425586734, 0.0920237402564713, 0.01198796570367579, 0.024459360466737832, 0.019925073953345418, 0.0158743199759296, 0.06856514260705028, 0.019862229736255746, 0.03697583285559501, 0.03825463048581566, 0.04450845365811672, 0.06342823218022074, 0.04803454569940056, 0.022110460525644676, 0.02222147903272084, 0.038060111459344625, 0.04727162467315793, 0.02869610089276518, 0.026899657378505384, 0.0568916091828474, 0.043472530852471075, 0.05773515374000583, 0.06639204600027629, 0.036763000168970654, 0.072804934744324, 0.02920639993888991, 0.005708727154082486, 0.03885591768526605, 0.06728904215352875, 0.06460399766053472, 0.05326757400429674, 0.08798902175788369, 0.016811970554824387, 0.05091086921415158, 0.012319262122868426, 0.009095551579126289, 0.03084116382524371, 0.01726558817816632, 0.07546019833534956, 0.04032633699742811, 0.02751682569006724, 0.018181768212733523, 0.017978351895830462, 0.031294269154646566, 0.05940609372087887, 0.04175252261172448, 0.05972548693950687, 0.002540924079117498, 0.08207896817475557, 0.06552349403500557, 0.03728099040953176, 0.0056663958987753305, 0.011811364242540938, 0.041954542842826674, 0.04257151098655803, 0.047091758610414605, 0.02135467259878559, 0.01183610362932086, 0.006840366653964988, 0.03693839468594108, 0.040861046340848715, 0.011833308065044028, 0.059734531811305454, 0.02076126997625189, 0.012474511783303959, 0.01522997803320842, 0.033861133203442605, 0.015450608783534594, 0.019555757520720363, 0.06339995762599365, 0.038238844368606806, 0.020446991215326955, 0.0243871846968042, 0.05905660068882363, 0.02072309050709009, 0.018135222406791787, 0.00935333127355469, 0.08773212839982339, 0.041705137118697166, 0.018377038716737713, 0.056344852450170686, 0.059867843586419306, 0.0326430067819144, 0.03271502309611865, 0.04142385721206665, 0.006614745278576655, 0.028261202354250208, 0.024058451443644505, 0.03585932383845959, 0.041988306745354614, 0.08054597436317376, 0.05992616367127214, 0.06274262004132782, 0.09763382707855531, 0.046565493635301075, 0.03846996357398374, 0.0243086171269949, 0.09423742682806083, 0.05512291605451277, 0.0530425853628133, 0.061643515447420735, 0.0546136924863926, 0.06870072068912642, 0.03314989958224552, 0.03930860910830753, 0.020131240033411553, 0.04107892054266163, 0.058919482332255156, 0.03174922688465033, 0.038416301632033925, 0.03671040352700012, 0.023501900057973604, 0.05188357291210975, 0.05197829979338816, 0.019800279489053146, 0.027988923214642063, 0.031810803937592676, 0.02059691183135978, 0.040626849979162216, 0.05299547467646854, 0.013957793574913271, 0.09004695061594248, 0.015344977844506502, 0.032977558472859006, 0.01104772905819118, 0.05885126920683043, 0.04205242830461689, 0.06575680830116783, 0.028843088541179895, 0.033272968871252875, 0.03693900876013296, 0.016776934399136474, 0.03763694648763963, 0.03514032099129898, 0.059552413012300215, 0.054284002498856614, 0.05576616385951638, 0.08543663086103541, 0.013525180851242371, 0.0071240333075236, 0.007272990403829941, 0.059610054562134404, 0.04263605323753186, 0.028545438977224485, 0.020462460117414594, 0.03502074276496257, 0.03792518477088638, 0.03185696467491133, 0.09398543927818537, 0.022393063575561558, 0.00760284748061427, 0.0446299046411046, 0.042458321167422194, 0.1328577809035778, 0.040803761021899324, 0.04808644005762679, 0.03150266422224896, 0.0303543997662408, 0.006236475576380534, 0.04666475991585425, 0.04241386016032525, 0.026952023318569576, 0.07604669686406851, 0.04007466496633632, 0.03834354232198425, 0.026722459654722894, 0.03877583019701498, 0.017071077633383017, 0.04427825386769005, 0.026749653641932776, 0.026734944699066024, 0.018212863776300634, 0.023429683575938855, 0.06792548085962023, 0.03645846347457596, 0.035137535605047426, 0.045218065580619235, 0.04493085867060082, 0.025180370081216097, 0.017315896460786462, 0.03817054981897984, 0.01792038804186242, 0.028908624845956053, 0.07454882402505193, 0.008615007141738065, 0.006367544793257756, 0.05453476868569851, 0.027010932032551085, 0.00956518602158342, 0.0331709443458489, 0.03400309630004423, 0.01575393768559609, 0.0875520994886756, 0.018831068550103476, 0.02157823970940496, 0.09545127169362136, 0.043021993778113804, 0.019674701316814338, 0.04016420105472207, 0.04053023337785687, 0.017922221782750318, 0.07750499075544731, 0.04567605296948126, 0.011260197032243013, 0.028975962661206722, 0.013850576560279089, 0.06365117164594786, 0.08759524074516126, 0.037645102478563786, 0.03915870036663754, 0.017609561327844858, 0.12012345636529581, 0.02626849088950881, 0.01066199122994606, 0.0260152209084481, 0.10180654602923564, 0.005321790015191904, 0.053093037834124904, 0.014658369955473712, 0.02179574071695762, 0.03202600131875702, 0.008889527143245297, 0.03729436433474932, 0.019135779967265468, 0.05753143038600683, 0.026051042468420098, 0.07342759240418673, 0.052581371539937596, 0.010473751196903842, 0.06239827709006412, 0.05145701526531151, 0.02813074381888977, 0.011579928670211561, 0.06229404054049935, 0.0030491811589204837, 0.030677518142121177, 0.02296187948169453, 0.06745839092348303, 0.05401402698563678, 0.033431125206074545, 0.07418008773986783, 0.020975802393097962, 0.04385063770626273, 0.019651493722839013, 0.021474337338336875, 0.031786074728838036, 0.010382681619375944, 0.021848676626437476, 0.012282637347068106, 0.036499172183019776, 0.034570884225623946, 0.028714597757373537, 0.009394671867734619, 0.04228192920397435, 0.032798265772206445, 0.06402826748256173, 0.050011772995016406, 0.07043967702026878, 0.029678507641490017, 0.04456606128119996, 0.025522009070430483, 0.021614403929561377, 0.025653996005920426, 0.023049642897344062, 0.028526185546070337, 0.018171902313562374, 0.04158761485346726, 0.035463140811771154, 0.019867412047460675, 0.0229680931661278, 0.037938847073486874, 0.02990288899413177, 0.022165203034611683, 0.0686084059998393, 0.06586663597928626, 0.049905867249305756, 0.10674862191081047, 0.020224670912804346, 0.04435621414865766, 0.06516227591782808, 0.056531476721699746, 0.03126157733744808, 0.03084219859114715, 0.0248786968046001, 0.015714150088440095, 0.026271293239135827, 0.026148542861587236, 0.03456324052863887, 0.004658180222447429, 0.03547381416761449, 0.037162219639867544, 0.07226702610829047, 0.041976313638900004, 0.020255768172709004, 0.06228526708270822, 0.07640722966087715, 0.1337142956576177, 0.2738695442676544, 0.09744993730315141, 0.1852351746388844, 0.07319431206477539, 0.11800582999629633, 0.12126955629459449, 0.22638210813914025, 0.09345440420189075, 0.14501429216137954, 0.12273696969662394, 0.08947212967489447, 0.12331356161407062, 0.11000960692763329, 0.12647070363163948, 0.1541049922151225, 0.12199499165373189, 0.1511619415666376, 0.09604675402598721, 0.16572285523372038, 0.036583985667675734, 0.0875490800078426, 0.24883931023733957, 0.11622361705771514, 0.11394595141921725, 0.13830913124339922, 0.11771540343761444, 0.09692011001918997, 0.111420450865158, 0.12129954754241876, 0.13042023884398596, 0.18769991238202366, 0.11010682063975505, 0.19947834392743452, 0.1691947832171406, 0.17036073708108493, 0.07580052435930286, 0.09024199550705296, 0.13907835925264017, 0.13579704532665865, 0.08579428666936499, 0.12805943909500325, 0.16585257755858557, 0.1343006177672318, 0.10150823489363704, 0.09367796113448483, 0.17237903949405464, 0.08354235107877425, 0.12793399154075555, 0.0781523199485881, 0.17832907236048154, 0.18556408770382404, 0.1013734574828829, 0.25921473492469105, 0.08550106454640627, 0.1387189935360636, 0.09931945734258209, 0.08384260282452617, 0.10501048660704068, 0.09037281027329819, 0.12039636314979621, 0.08369211732809033, 0.1029518452872123, 0.20882418671888964, 0.08314630375908953, 0.17301303547407898, 0.13184296392968722, 0.13008071349135467, 0.08483557775616646, 0.0719441045075655, 0.10080344056976692, 0.08588624852044241, 0.2646571014608656, 0.11709419105734144, 0.14356734337551252, 0.2649153790303639, 0.2019162523959364, 0.1226009912788868, 0.16491690490927013, 0.0954919702240399, 0.14645703403013094, 0.09966280963271856, 0.1710452296371971, 0.12244813090988568, 0.15088011883199215, 0.11167876236140728, 0.14229031332901546, 0.21028056714151586, 0.1362493567700897, 0.13044461182185582, 0.1294521050793784, 0.18455982873482363, 0.14790939752544674, 0.1168926932982036, 0.14823841915598937, 0.2243352529725858, 0.07237103874129908, 0.13593539861696108, 0.13401917501219682, 0.07634147283221994, 0.15829893574118614, 0.13680032720523222, 0.13080130411045893, 0.08812618082655327, 0.2082965307469879, 0.11358349836830582, 0.12877724772053106, 0.14251652333353246, 0.10219194713447775, 0.12265398486384324, 0.15152619273534843, 0.10900701715477876, 0.11108919006905385, 0.13152329251170158, 0.05382528229217444, 0.12439617780702454, 0.11912218295037746, 0.12349801457354001, 0.14776994500841412, 0.1032453795362796, 0.08862236634429012, 0.14441359868007048, 0.22820424607821874, 0.129261938855052, 0.09766198628182922, 0.07830129909728255, 0.13981102779507637, 0.19333226872341974, 0.09478898758866958, 0.2060435637831688, 0.12507928615169867, 0.10916315484791994, 0.11079104178185974, 0.18726692561592373, 0.07860713518623795, 0.11637035704084805, 0.21767187624105386, 0.198459672874638, 0.0466177442244121, 0.0746490436473063, 0.13716597615608148, 0.11443251531038966, 0.0963018967636994, 0.11267361683504921, 0.12982067173080786, 0.13810945195811136, 0.1926906867218869, 0.2243860616747822, 0.17951866638447556, 0.22017853387764522, 0.10548902342894248, 0.13368335446076735, 0.08112344159079449, 0.1708755280290331, 0.14891702202813967, 0.19155890388148172, 0.1629944523530347, 0.14126013432230267, 0.14029665530792304, 0.1720615258174283, 0.18051950553698198, 0.13383401637630804, 0.1626480602260147, 0.1104753805058343, 0.08187536017170974, 0.16243698155241354, 0.13217384474618094, 0.07820387503930501, 0.2667024502796786, 0.13536780407386168, 0.09076731731849057, 0.11089340557477304, 0.11778426117130689, 0.09810206373887402, 0.160905962277736, 0.20085494220256805], [0.07225078197994403, 0.027202268729784658, 0.005871085317007133, 0.03222205044169511, 0.0021748364129702425, 0.01083950701701854, 0.03641939003552709, 0.06640529778919049, 0.04610443248280457, 0.01634782037165548, 0.06790984062744038, 0.050603940683816157, 0.015872460789978504, 0.034110450718019686, 0.021899147757462094, 0.03037746317152466, 0.06371584960392543, 0.0647366444713303, 0.08161371028316872, 0.009838318418977516, 0.020314145933038423, 0.020825503493792245, 0.03223192312621644, 0.02288865198248199, 0.05574780270191176, 0.022505720744707754, 0.05561290994020445, 0.089061500637659, 0.05765166679131133, 0.025362738241840686, 0.027367017032312493, 0.030853794754615853, 0.0700031550867217, 0.031513391860893795, 0.03916667993845684, 0.036862863560340235, 0.030876352651310817, 0.02296015769908471, 0.08377464075705834, 0.022749939068619694, 0.06859345787337848, 0.03385442927745836, 0.030613298195281198, 0.02232315411259021, 0.0297807798321758, 0.030848827878279344, 0.013195853031772588, 0.010174142363082086, 0.019425092032179236, 0.06206898404551404, 0.04720496539292591, 0.04092316622180598, 0.010614247809696411, 0.07740787882357836, 0.06702320570392267, 0.022564371615382176, 0.012684653230410601, 0.03235497545184834, 0.08040922241551535, 0.023593809322587082, 0.05118785060143896, 0.04894095652603677, 0.025357795114229833, 0.03613359447834747, 0.022206636079187905, 0.08933049906045198, 0.07311664016119071, 0.024216650186904838, 0.008109788626565464, 0.09383697581610509, 0.027232639957219362, 0.13223393580743245, 0.07752575392701797, 0.05307845611657415, 0.034035550629986186, 0.046351368339466195, 0.05098214592518551, 0.018325824589867677, 0.020687348674982786, 0.03754973777436784, 0.030687604565173388, 0.0562957468708711, 0.025244603598756448, 0.022025034663134387, 0.050042714191866774, 0.033534798571573834, 0.013988281849638691, 0.017675821968753423, 0.023730571448270763, 0.028269602617781078, 0.03587193101910608, 0.03938231836738331, 0.01678898518106767, 0.0016913337749429047, 0.01071218925062567, 0.07237717948321785, 0.0460772571553077, 0.06155529910964625, 0.002714093425311148, 0.05095677550083824, 0.023689072246530225, 0.006415675402552421, 0.008854139845685234, 0.0520483110366123, 0.08447654452174902, 0.037754634993949106, 0.03719916587163295, 0.020931409239502888, 0.030505886101829152, 0.0588024893243398, 0.07050727946417672, 0.04286402404042227, 0.07077395729720592, 0.013915472497631396, 0.021332331833296587, 0.007854971585662236, 0.06278632448187896, 0.05203794302152736, 0.06985062041452952, 0.026107791744704758, 0.03539464948698878, 0.045062752307525704, 0.015818025318107436, 0.04072316463238426, 0.02197248042960252, 0.02657250511193914, 0.018526100985971943, 0.0460995979207967, 0.02768281231900411, 0.024173471610993147, 0.028833673867796148, 0.026819395167487006, 0.09445857496133872, 0.01679226759422038, 0.009789107666750039, 0.04045549613822784, 0.015244546180058802, 0.013997365737200847, 0.014336566241191966, 0.028718940381492888, 0.05231849689568792, 0.06110903341323137, 0.029908222279378345, 0.027912593114056757, 0.07362443541309663, 0.05865109459097896, 0.05538744293153286, 0.013897240261680313, 0.013853449307914292, 0.028249568871355484, 0.03940931049042514, 0.04451837384008935, 0.04006596614739724, 0.045443637762218714, 0.04142707007537995, 0.015661528001406362, 0.07110606626208339, 0.018922138127631376, 0.006352258671540767, 0.0493117928771036, 0.04619857921664204, 0.06794919565852199, 0.038100463936903646, 0.08177505912525312, 0.04406405732567821, 0.03367929599647011, 0.0316715787297913, 0.02578221876839442, 0.02264788231280233, 0.07424925759966884, 0.01482669753022492, 0.057736212254634926, 0.03634421174813594, 0.005151497657477323, 0.04424652557021805, 0.015167298360860773, 0.015205815401194351, 0.005372930351378662, 0.006075353619442987, 0.05169080111331173, 0.021007096428158026, 0.02898863430267998, 0.043708060535469224, 0.02996830316260457, 0.06807812409741537, 0.05567057863143938, 0.02264937339350581, 0.04285042619864855, 0.007438245911284217, 0.07572149538568088, 0.05548620370349713, 0.033696697027023347, 0.028723082837781737, 0.03736153251624533, 0.033918957957731824, 0.012114481102409107, 0.028525018465838263, 0.05056088763688292, 0.0067045773778642926, 0.011549500615469046, 0.06399848658059325, 0.063776815975351, 0.13150141654270037, 0.057630469357328754, 0.005818044658683772, 0.018448015176025883, 0.03214863295267735, 0.058044660703412125, 0.05305313318967819, 0.026054682808795145, 0.009372142808777946, 0.00864840717986226, 0.06893795010234628, 0.01241340970487467, 0.05842140370181628, 0.04510977817699313, 0.011395742883905768, 0.016830394476918236, 0.022836058733186552, 0.023711433368069783, 0.02606078962396298, 0.05406830639445356, 0.013471289903723767, 0.007373766424799604, 0.03862647106871009, 0.06874458797808204, 0.020881106045895388, 0.005660435392720891, 0.02634460385888815, 0.03195416481633272, 0.06006653221057994, 0.018232371658086777, 0.044757727067917585, 0.03382357968283551, 0.01157104070963604, 0.04123395561639752, 0.03281564644670912, 0.08018571298037257, 0.006064224796968379, 0.022378692203866582, 0.038799185372356854, 0.016976269327902367, 0.03743596441511597, 0.05703327711671591, 0.05727658620370286, 0.04861933771254761, 0.02825274780791785, 0.03812817869974034, 0.060599609677280696, 0.084443723782897, 0.02619110736330705, 0.06875779226954494, 0.029637510555663278, 0.005222370216090764, 0.03865064387874944, 0.022164485483829464, 0.03622265559222017, 0.04497407117326345, 0.026508157939783165, 0.039916953071951866, 0.06901762368423597, 0.04300923053441303, 0.032115642580070665, 0.03073354477861098, 0.06229941453784704, 0.03898979942979557, 0.024887444817328026, 0.05483981428135719, 0.03704210876354149, 0.0652356662654451, 0.03205505618825555, 0.04928302977766309, 0.048873988512371264, 0.03143260548157351, 0.04558163482163634, 0.05287320266610809, 0.07372800021299294, 0.05142074078321457, 0.03170735788132463, 0.04740624602085777, 0.07288262021860906, 0.0032550304479497883, 0.05927738241319146, 0.047173192990677695, 0.007422519165889493, 0.017969615757465363, 0.08702780226511614, 0.008226195549858468, 0.07195925619453192, 0.07316507399082184, 0.03394444373303226, 0.0833131962322763, 0.03247798367270401, 0.03232705034315586, 0.05922003263341529, 0.05848396463053567, 0.018275755490841608, 0.03473179201994624, 0.037741183037204404, 0.034176414499857595, 0.015443377296573349, 0.044279726288680515, 0.030733205511101654, 0.010752657079137862, 0.010710412337045585, 0.010284709644370844, 0.027295328111254742, 0.05730342904904059, 0.01321663910390011, 0.03052749065682292, 0.03086945873552135, 0.012461248120026929, 0.06175656616687775, 0.002570195231653218, 0.008225128553541643, 0.05219997039863041, 0.07737997067826134, 0.06056583220405238, 0.03629659894587738, 0.002766063482600397, 0.05700914841145277, 0.041001967886196714, 0.006003623986284116, 0.09316741781575338, 0.025146268607516373, 0.021544290906084434, 0.012565511810992445, 0.02520909077221794, 0.024729566681864004, 0.037163152625518184, 0.044838096148201396, 0.005741778170756463, 0.024969956371933222, 0.030378609895706177, 0.02722393604926765, 0.07023858638214213, 0.0409275258093008, 0.0232334173217948, 0.0685488645519529, 0.009519318750660335, 0.04632303610976253, 0.025197431844260012, 0.02533522534317204, 0.02674475122642304, 0.05511763705206769, 0.034474067456488094, 0.029357312912387506, 0.026254470659685985, 0.05274768725835851, 0.02954607456922531, 0.03280428098514676, 0.022027066875515238, 0.14470800145396165, 0.06968122414712395, 0.1256909854710102, 0.11361144722572394, 0.06105376673596246, 0.16926453661705765, 0.08371440720345293, 0.12002854288688727, 0.15492029275212968, 0.15132390787558897, 0.08798716257193259, 0.1446397408310856, 0.07818827551922627, 0.19300176788653645, 0.12657981206263813, 0.13564080585326466, 0.13533820637634822, 0.16555585419493063, 0.16206427583737032, 0.06994000383253608, 0.19069668943328516, 0.15585000786398137, 0.09913462440350226, 0.07642038645488874, 0.17984600524817193, 0.18394850939512253, 0.2049776395516736, 0.1695426002676998, 0.16734211120222295, 0.12873276296470845, 0.18639344748641762, 0.11291282757052354, 0.2234018330595323, 0.13445350527763367, 0.13345660162823542, 0.1485905788306679, 0.1755013998065676, 0.0834490457283599, 0.14874809394989694, 0.10632436110505036, 0.1068218561953732, 0.12890899207975182, 0.053511269856244326, 0.08903912933809416, 0.10254557923014675, 0.1027615229998316, 0.07818588029061045, 0.10779899411967822, 0.10753581752734524, 0.21392881923488208, 0.10237674614680664, 0.10213065506624323, 0.12823816521891526, 0.15756737999618053, 0.21562609315982886, 0.10845364470567022, 0.10624145091112171, 0.13236516448003904, 0.12374215147324971, 0.09576972853392363, 0.06509639016751732, 0.28389823756047655, 0.1524774581193924, 0.057219541764685085, 0.07094002874302012, 0.15294126394603932, 0.191407441294619, 0.0882819996082357, 0.10952896664717368, 0.18798159940966538, 0.12370423493640763, 0.25559154791491373, 0.14601378781454905, 0.1685351114720106, 0.08710468028272901, 0.19445961394480296, 0.13655853803668702, 0.09010816804532494, 0.11468037058200155, 0.1001042238037501, 0.08375354510332857, 0.12021053954958916, 0.126705992434706, 0.08399901193167482, 0.1779958438128233, 0.17900572105177812, 0.10285149674330439, 0.0741353654967887, 0.1281765406685216, 0.15140202082693577, 0.09188803325274161, 0.1994804066738912, 0.14333403589470045, 0.11893933133355208, 0.07973960334701197, 0.19926315333162034, 0.09732595538454396, 0.1573934443295002, 0.10874806105026177, 0.12819689671908105, 0.13756168420825685, 0.10649796428957156, 0.21579076003815445, 0.16378035875303404, 0.1959366218319961, 0.13254744612744876, 0.12795395404100418, 0.17700435487287386, 0.1096657593069332, 0.16603956823902472, 0.2315623430269105, 0.18235022015869617, 0.1318893757249628, 0.1286604039903198, 0.12508585437067918, 0.1405132029737745, 0.14670380364571298, 0.10808878964079277, 0.16607831258858952, 0.1603907642087766, 0.153310929824199, 0.09029090431119714, 0.13257108628749847, 0.10763346550187894, 0.11225173768720456, 0.11737898577536855, 0.12428161395447594, 0.08993687866521732, 0.09385816646473748, 0.04257415388045566, 0.08906389586627483, 0.14902433912668908, 0.11207018207226481, 0.08921130081372601, 0.07870094943791628, 0.08238066520009722, 0.14488697185048036, 0.10803020492728267, 0.08273773746831076, 0.13174714121435369, 0.1413647508514779, 0.15422531004462922, 0.11513656324573926, 0.12580963410437107, 0.23508643678256444, 0.12747140707714216, 0.15380032999174936, 0.19994858226605824, 0.09601333617631878, 0.09408356222723212, 0.11693876582596983, 0.13194460847548076, 0.16423378299389566, 0.1444067590470825, 0.12795571823205265, 0.06119655764528683, 0.1733295720602785, 0.10544615358646427, 0.13151204240109238, 0.10280040305640016, 0.09287701161312205, 0.15806911593036993, 0.14848744150783333, 0.17922559353922093, 0.09319400281778403, 0.21003580598958901, 0.10547321356300797, 0.11225017027131148, 0.09158705547451973, 0.14689785109034606, 0.1268294450959989, 0.1832623883549656, 0.17651431688240596, 0.12725704429405077, 0.10828217212110758, 0.06402341595717839], [0.03699988692200609, 0.05308777579505529, 0.040492466118718894, 0.02393128041044942, 0.04312428632485015, 0.03683412420962538, 0.014710820712415236, 0.014618024263264877, 0.07788345723279885, 0.02637383175481643, 0.007519699799429093, 0.024404456805703894, 0.01044791003888739, 0.02465766402227538, 0.004527709812724164, 0.045042097701558044, 0.039980945709560595, 0.0463655225799552, 0.01989685368191983, 0.049417298287153244, 0.06753203232905694, 0.055129328210439, 0.026702573489663855, 0.04792414465919137, 0.056326182559132576, 0.01062307385395148, 0.004843307900175984, 0.026951651820646863, 0.023929624785003916, 0.009804741961748471, 0.0933975904647793, 0.04621962737292051, 0.01629228058404156, 0.0722836773576481, 0.04097725564081754, 0.028965363944215432, 0.023625449410506656, 0.02556166096058275, 0.021814987362761582, 0.024823201121762395, 0.038007463927247694, 0.028350970840879848, 0.028278615259166275, 0.08710773369031292, 0.032688563623066456, 0.01329185301437974, 0.054988474518592866, 0.013354492822795041, 0.022282292733767202, 0.02902149236095803, 0.0383357391692698, 0.029581334641469375, 0.009434205014258623, 0.012315829583842839, 0.04565618546413524, 0.014267223354961191, 0.04295677638479641, 0.046936184101338894, 0.034813969396054745, 0.026688758516684175, 0.03080640926158854, 0.037059648893773556, 0.0287303804819073, 0.04122851376554795, 0.042960806882807186, 0.018032734781237583, 0.012414072972855397, 0.012341489233741803, 0.043258982311402044, 0.030644388669835668, 0.00830544759186783, 0.06611067788409335, 0.060933781388614855, 0.03246476241786565, 0.05208533190722976, 0.050076610408723354, 0.043692627256470065, 0.050842557701149156, 0.022609909796821218, 0.03886677424556442, 0.04264854845990028, 0.02156118642804878, 0.03140419182766761, 0.014574703194999268, 0.025140283928651894, 0.037504007906786034, 0.03997880153890167, 0.05834464103515659, 0.038547923854951344, 0.03456617519259453, 0.0912747054493853, 0.024399311813924993, 0.017785057625068084, 0.09233776626310178, 0.011451534577645361, 0.04453377997768777, 0.06632608561111347, 0.030270529445260763, 0.009545361772844834, 0.03258270876748221, 0.029582545826477662, 0.07614173926413059, 0.08193288637059075, 0.004554045453135456, 0.051965048004473956, 0.06488721139196839, 0.03314265622092145, 0.007451671574796949, 0.008603226925645555, 0.06954139843583107, 0.05755045650792973, 0.02681323406951768, 0.029615101936672415, 0.04951176393244948, 0.008486812368833592, 0.02435616377208914, 0.007100469906747873, 0.04039738979190588, 0.03241676624332156, 0.05288711941934057, 0.015538865833410194, 0.04998356629429119, 0.04891212896576949, 0.051132502499967813, 0.0416190208468054, 0.023605313883828263, 0.05659936075764043, 0.05546194268390536, 0.08790841179766826, 0.0061906295096767795, 0.03032084960224373, 0.04452300823426672, 0.011299908294209411, 0.03930376776094947, 0.03482503969488399, 0.01997930756104844, 0.06342054437845945, 0.024792058060743978, 0.053283282089978456, 0.025626932636701634, 0.03453930520585605, 0.0221834946423769, 0.024127874057739973, 0.0398016190821571, 0.06057526384081159, 0.06612383467810494, 0.03420162546847548, 0.07764548821640865, 0.030502734306667532, 0.02974609312202249, 0.03758304027308311, 0.06399934153471674, 0.07164171537650482, 0.027696137050432817, 0.015923929367480532, 0.03909341851249337, 0.08141819720289536, 0.05143190946962152, 0.026734834437125495, 0.08104911486485175, 0.049825538881123066, 0.03724622566785131, 0.005156197784734624, 0.0478335093440754, 0.0038186657392153783, 0.030292914315525974, 0.0318278589152864, 0.06729434829737459, 0.019254313249673163, 0.04362361685239843, 0.05897033174655267, 0.01170855007200901, 0.01092300668824464, 0.03265267590593014, 0.04822630987369588, 0.031256512073533874, 0.03446290555543133, 0.07863625112388815, 0.0667017972362893, 0.014222660567611456, 0.07426275366118976, 0.036636103942458115, 0.026419047632121613, 0.05574863051463451, 0.061008053831756115, 0.011271005246921309, 0.07631289293723446, 0.027784224466553757, 0.05129149682553751, 0.03482049011758395, 0.008009705559483596, 0.07474224721746785, 0.0425465239344963, 0.07223273294844798, 0.047920500926141224, 0.019333744255293692, 0.025882908276149204, 0.06052991734551532, 0.019878134597092867, 0.047712404413947036, 0.02671722136437893, 0.02390176583347576, 0.007217412448621222, 0.013526214768977037, 0.004847047900381897, 0.015566699339875152, 0.011914175868566548, 0.02356983837671578, 0.06808168640626328, 0.02708757765192006, 0.030940681163753782, 0.03403514350897499, 0.05264788154246552, 0.03093289497441479, 0.04234989805679236, 0.02308528634187366, 0.08946432652218, 0.053211119890745194, 0.0052660665990385625, 0.010076844682251769, 0.020080076796667914, 0.05767367846731629, 0.030206492702875818, 0.017215050889977386, 0.10860689862498216, 0.06134115345776081, 0.049409858150673766, 0.026760683228660907, 0.01195062422526202, 0.03587988344952464, 0.02465720770747534, 0.030689158410366093, 0.018853204058749334, 0.03447273413517645, 0.02555232771140124, 0.07934671121516398, 0.04414226866460272, 0.045708778713430674, 0.025373089293550168, 0.04802356700279883, 0.0507019177478339, 0.04094048243548189, 0.04174061092947211, 0.03735431290364691, 0.032896405684628656, 0.020708585124728934, 0.05972917138465813, 0.04335977190307208, 0.04156708238380296, 0.040638276508876255, 0.030533658540142432, 0.010814754059538245, 0.024658390054745332, 0.03148657615695681, 0.03939652689067381, 0.07850446605256625, 0.05004562171442168, 0.018232895826388682, 0.004983304941561073, 0.021428000181913376, 0.018223581236920187, 0.03117140003346971, 0.02886385510542563, 0.03915086328717215, 0.007794538712395089, 0.031118182531957115, 0.030033072722809653, 0.009666460765791791, 0.04554268691156592, 0.061615464809749804, 0.017606772548918213, 0.04967769967125995, 0.03528979207788195, 0.015504345364336456, 0.01850672541851444, 0.05315138506037848, 0.01791379098514361, 0.03142464965847986, 0.023867635522037745, 0.021362854034772942, 0.07315050584397145, 0.07972214464098215, 0.0500057509967259, 0.032808966269450526, 0.043626042615090094, 0.041726945234196525, 0.032355664164892266, 0.08471472388399498, 0.012096939275839498, 0.036215208670390506, 0.02687127934768796, 0.02724895024273012, 0.012164466232726616, 0.032683586568704674, 0.043916462388421805, 0.02207233533928437, 0.017910785075010996, 0.01653847174852022, 0.019098899892664382, 0.030462846625596285, 0.026042012863659432, 0.01489046455493995, 0.007194340561649629, 0.032251159593995125, 0.08993715686457497, 0.09009999169835023, 0.04109445560191359, 0.05252409979168858, 0.029037054561610733, 0.006568436959891447, 0.036030691250094345, 0.026827583388824548, 0.02394551268246557, 0.03735843839656029, 0.022835595633036325, 0.02826774343182998, 0.026994428364560008, 0.04369390629498022, 0.043810169877750535, 0.08142616998936449, 0.02590559170182262, 0.03783652399267469, 0.1004944017955235, 0.06576210087431328, 0.04812345753556915, 0.05637810745143464, 0.019331598388297216, 0.037697298784873316, 0.057805857088948996, 0.0163788362073579, 0.061326381750404835, 0.012578472678017403, 0.03747586566688759, 0.030158438852855136, 0.008992579649202526, 0.0027798911781116787, 0.050701483485421965, 0.05814644095620938, 0.03622879972681403, 0.05471187989626612, 0.03394153621047735, 0.03453033497290952, 0.02942021650129131, 0.07430984399148396, 0.054640626933957846, 0.045387760403433015, 0.021509353137974228, 0.029932557937822173, 0.022708941982792955, 0.048478891141712666, 0.08023195514189345, 0.019579524906086068, 0.19696443953684398, 0.1306470459593194, 0.14323427767625876, 0.10620644528950964, 0.18999185439731392, 0.09647642954119615, 0.09397103397973947, 0.11269454285502434, 0.1447359435260296, 0.057268199510872364, 0.12112107926181384, 0.07886752978499446, 0.1472607451890196, 0.09636253065296582, 0.06714844291231462, 0.1956479594643627, 0.135006470605731, 0.17586053482123784, 0.17857045440801553, 0.08884546187307153, 0.12583274500710623, 0.14369671286216804, 0.0992777342242854, 0.12775888879384312, 0.12859759878899368, 0.12055751521672521, 0.09156349673867226, 0.1344812980719975, 0.10928463975765876, 0.10347808312092509, 0.16267961210438184, 0.19165528299553053, 0.11392293551138469, 0.134355239836233, 0.10116688428180558, 0.1514920759946108, 0.1461884155869484, 0.07782217194991452, 0.18862527129905565, 0.13662147894501686, 0.09658936490969998, 0.16162383875676564, 0.1465289858835084, 0.15536892653575965, 0.10996745633227484, 0.1541416466768299, 0.13826303157423223, 0.14062195856656345, 0.12305048001664025, 0.09175478254577943, 0.1497149656393698, 0.07407792750746012, 0.060859210390065394, 0.16985327431133815, 0.11920269791569028, 0.12337676036570754, 0.13554636734936917, 0.0825213458655136, 0.1438573763838836, 0.18665314997945512, 0.11200224714619772, 0.15678310208022594, 0.11539640144578048, 0.1989160826695817, 0.12048835892762456, 0.12829741489674362, 0.1186526638588735, 0.08974685493324484, 0.078909028986735, 0.11278757679143123, 0.11363640374370984, 0.11200444559965815, 0.11854350114507334, 0.16092771611043385, 0.1363136140363557, 0.1305689194372722, 0.11328742639826876, 0.11106651342873063, 0.08506150956132583, 0.13469598655189785, 0.13490573529686245, 0.09039699326136283, 0.1002929379631366, 0.07312812097370625, 0.09788637781249625, 0.1193619365138667, 0.1343393214046955, 0.1488643948520933, 0.15046999869602068, 0.11426643707922526, 0.10729558220399277, 0.07105091493576765, 0.135434001950281, 0.24468111193605832, 0.1521199515887669, 0.19173442732010568, 0.13133814744651318, 0.11425340920686722, 0.09975338727235794, 0.16180525187935146, 0.09742776277874197, 0.15248923748731613, 0.26018210873007774, 0.0864900496921369, 0.22699232825211116, 0.21783638027097496, 0.23698120511003903, 0.07136313603924853, 0.1455685602767127, 0.1868111400731972, 0.12360667517142636, 0.17808589898049831, 0.20642798101263388, 0.1296068789171321, 0.13643288692193373, 0.12388304248452187, 0.15434166522962706, 0.12747971234577044, 0.10953364175345216, 0.16061611925917013, 0.1491114901644843, 0.11188565447394337, 0.04925851430743933, 0.10825180089367287, 0.15843320425067628, 0.17573431373706885, 0.15290199033915997, 0.14268394506403378, 0.2250017643507038, 0.22053989448717662, 0.07865411695092916, 0.12827210554054805, 0.2080999320106847, 0.1576029352311577, 0.17123806928949697, 0.19394407660833426, 0.1487947093056781, 0.18288171663880348, 0.1314766907266208, 0.09470041162733521, 0.13165354409388133, 0.2828466168471745, 0.14691452948110445, 0.19506378152540751, 0.12929608273719037, 0.2059913030160325, 0.26060049342257635, 0.13078994543424674, 0.1843908735151802, 0.1115659966266581, 0.09538772010377475, 0.1762838049658707, 0.15780793423099176, 0.09335125330835581, 0.14724133908748627, 0.10913600666182381, 0.1316897100103753, 0.16373108353997978, 0.1187037711164781, 0.10456097751323666, 0.17838758922048978, 0.12470765252198492, 0.14215858254049504, 0.15690324349062784, 0.15904992472912582, 0.11284238206488745, 0.07633172228400197, 0.16363847708063467, 0.12861363935683454, 0.1398926419871194, 0.1548642593302897, 0.1265024726412126, 0.1022609948579754, 0.10561000622276749, 0.17048713458435877, 0.10723269557846443], [0.02831929682620934, 0.010931287359978472, 0.044757201203278134, 0.05366705810385091, 0.046103977864342074, 0.04830388678237796, 0.01232278541595276, 0.01916394256321447, 0.03330846982342856, 0.00543809515823211, 0.06965667475014925, 0.03408961969294718, 0.039294943413031955, 0.019285137399232814, 0.05446140208680715, 0.05390593296449099, 0.06575555979673352, 0.03595831870500531, 0.03781464123832328, 0.01865444079573665, 0.020844660233706236, 0.022068284485223036, 0.03785239831943597, 0.026782257249578834, 0.016457642960761274, 0.01277849038264581, 0.008693487350163715, 0.03297607587384326, 0.011773452794711505, 0.0018621433035670115, 0.07605728201035943, 0.04631368250453046, 0.018262739492846385, 0.02100012617717896, 0.012114042599153305, 0.026045722753873894, 0.031338343396782875, 0.06530879198440484, 0.07698383514902421, 0.028030454646795988, 0.07953733884330307, 0.10676134444241013, 0.017319879461345927, 0.08263308701238462, 0.07456261185663086, 0.019718519411981106, 0.02864589947941048, 0.08796976493405444, 0.041322134634745974, 0.01218256021716765, 0.03667609001110707, 0.014091209674786245, 0.03206995003191488, 0.04814354556479624, 0.0467469169359122, 0.033698861553732834, 0.03222208097577095, 0.04878610126408083, 0.0013831249338441662, 0.11664441733488015, 0.018756059896466986, 0.04148331045040062, 0.02321317492585097, 0.028918066660740545, 0.04032107495835849, 0.050057998193161826, 0.030923137640846626, 0.023770314940650548, 0.07082815867449556, 0.026013090308489542, 0.022523447472069944, 0.06128542537667921, 0.045433815967823775, 0.033723014007721624, 0.03072744474879333, 0.04078888074894037, 0.021222153013306003, 0.013885035113032376, 0.0810751366828169, 0.06356676867497818, 0.03062247538140842, 0.05135414596380932, 0.050597972968327146, 0.048478758827384026, 0.0029539356224371916, 0.049826940055936575, 0.037734523215996366, 0.06107606339667525, 0.028612685190247636, 0.027710069070703218, 0.0337951694216047, 0.02850510346304093, 0.007081255491357297, 0.036544192981507094, 0.07361891213804483, 0.0467197551791157, 0.019600678235292435, 0.09707619342952967, 0.011681562189811041, 0.06574563282941069, 0.017601814154269438, 0.023036090856684104, 0.037444741265582185, 0.016028832577701126, 0.009900170278602412, 0.031954592293394465, 0.037489205665354214, 0.036429483243929486, 0.037146620119788816, 0.006313526620423155, 0.07776688491659504, 0.014041641843505204, 0.07993512321263552, 0.04297533092488136, 0.01102078952161329, 0.0013849113893229514, 0.04439847330961909, 0.04164547353450741, 0.04644303163513541, 0.02156223476465259, 0.07139641139656305, 0.04004086374438234, 0.028818725741335323, 0.03804786729493311, 0.046019235625863075, 0.015196083512689387, 0.021905704102079784, 0.061142763389008384, 0.06388594476240021, 0.013729043304920197, 0.038894244735794406, 0.07608187890478543, 0.056738311158759255, 0.02491536144433277, 0.04940187857885446, 0.027687199047899673, 0.011163040147429066, 0.030863731899963956, 0.09820220193692616, 0.023231281632823602, 0.015349680092185736, 0.054075505651001415, 0.03513516073248216, 0.029379256734890596, 0.06739717349410057, 0.027727027357156788, 0.017723117555890764, 0.0664079576464636, 0.022621958882414868, 0.05380832230938332, 0.016006456189123646, 0.05103167558887175, 0.03430907488135355, 0.014345085248351097, 0.04628829850948282, 0.033379044250718186, 0.014327762249325002, 0.048129805230668614, 0.03304064187354275, 0.04928394919261336, 0.010761056494499956, 0.06851852725126914, 0.023540371297193424, 0.03326317421825869, 0.002877062269752579, 0.03171378021527614, 0.032675654494336674, 0.023959015529336672, 0.06839351395943336, 0.008111741959250398, 0.044154109100678136, 0.05986650687243257, 0.012487561708050115, 0.034647694389734945, 0.02209216382886682, 0.009744983382656105, 0.008980238793550857, 0.027892204833083918, 0.020175719700221504, 0.012934977521321602, 0.012000386287192149, 0.05598141552348222, 0.03467441170609423, 0.03244681177394731, 0.06363131092595202, 0.03703507235539811, 0.0352144136226603, 0.025457429500030618, 0.05036276898213795, 0.04510152040581618, 0.013288688496686518, 0.057312087155878544, 0.038709578037794144, 0.019357194425538182, 0.00758823607715645, 0.007383278637592281, 0.029892894173307077, 0.016838133168805922, 0.021868632341335927, 0.0749019675755075, 0.027314866527116725, 0.035426737408020666, 0.009890087248225297, 0.08070720785430499, 0.04057793438966785, 0.052754659205675125, 0.032557290845683644, 0.018048101903072426, 0.03476643462532333, 0.04181113785931042, 0.0642173887629594, 0.0685768269800714, 0.041523147241345475, 0.023313326694603478, 0.005134848952626011, 0.027914392928193723, 0.06198684059615646, 0.049832249592457495, 0.03521783683182938, 0.05424334128786411, 0.0015373154435240264, 0.02415959896253688, 0.06654881473098483, 0.03945783592228379, 0.049179712643048594, 0.03780917563874807, 0.05520319692524416, 0.10282418570880379, 0.018079750472679734, 0.061503560814474306, 0.00380485415891079, 0.025210055988281965, 0.018673246393778493, 0.05385859157623989, 0.025258070822539072, 0.04894004389643669, 0.008518084351505553, 0.10973429812916688, 0.03977363969066313, 0.03460759975548301, 0.037467960733920336, 0.05099864111148885, 0.0256921381556562, 0.03488348870139037, 0.08761572571737425, 0.0042289478754225585, 0.07651682663708925, 0.07245434248553854, 0.02488525484555534, 0.014726362557017376, 0.021503546574552144, 0.023173351705606495, 0.018938339847539152, 0.045121740749371905, 0.06565084827265569, 0.06088629750800984, 0.031262445862271955, 0.06803703880203621, 0.0507038244312363, 0.01823874988726207, 0.0248933819987412, 0.014985539185415422, 0.012959501473233104, 0.06064214025224958, 0.01842030041318919, 0.060910025877611976, 0.02391073097740965, 0.0038466001777643605, 0.05156208641294922, 0.06279792064534766, 0.020387485390529037, 0.06032044679990836, 0.017295262210869362, 0.08100112208298274, 0.01566689182072878, 0.052347338026655574, 0.04880757350474596, 0.03607279095532639, 0.05847816315612622, 0.015893676883674095, 0.020171014059867178, 0.03916051205513733, 0.02688556250983051, 0.0612639972407903, 0.0463915274345449, 0.03255799652210303, 0.05605838175064751, 0.07444242973412786, 0.021817876225603477, 0.057663588651588986, 0.032694775611162186, 0.06469940646950688, 0.007776243711954781, 0.007766124210320413, 0.015377223524930221, 0.04330542803342853, 0.03803013378222074, 0.028872248583606312, 0.02185776051399963, 0.1655732382621084, 0.006594923150260001, 0.04117937765217253, 0.022469408943184783, 0.01641497158977602, 0.008772459496477885, 0.01914590031706861, 0.04276990444798555, 0.02376259321213833, 0.040587986885969124, 0.03660766653982656, 0.024455637005822997, 0.04482676122071488, 0.04603379698736327, 0.028566639803882157, 0.03759121662005782, 0.005713668585355792, 0.03528065560385585, 0.047938129265925715, 0.00641718938381278, 0.029765974198068892, 0.04303234482982329, 0.04118715366348624, 0.06592512569789376, 0.05032342073640653, 0.03756573084475739, 0.06606751627155713, 0.035821916202881506, 0.039062460352267535, 0.0028884508439140128, 0.06490092458469526, 0.024693712891478623, 0.027395384885104637, 0.025828878228951777, 0.04086324479430914, 0.009882077990498925, 0.00842743122484535, 0.11412106773683003, 0.037109724778149805, 0.02450969928343381, 0.04990542620154364, 0.03879888003159847, 0.007899363042919763, 0.031095075021897043, 0.019514955513711487, 0.07390706560441426, 0.004560028859746775, 0.0361199728878481, 0.013833223027177155, 0.018436481777046407, 0.04272004569481526, 0.02315951298390116, 0.022229007378752743, 0.16585991930748734, 0.09313364034252507, 0.09283934613423687, 0.1255855139877115, 0.10997834681932415, 0.15576352179050446, 0.08145475666970015, 0.09316849668643304, 0.09203619815941368, 0.06753378294940506, 0.15591003107173101, 0.11008265800774097, 0.24967550965292112, 0.09530223147677523, 0.12810551162276948, 0.11061245815030166, 0.159553872687476, 0.1910835901009185, 0.11090899830950157, 0.07523546075182301, 0.09634809142776898, 0.08986627709652696, 0.16214589002941335, 0.23864014180643217, 0.1060049475303718, 0.07491345517337322, 0.08055404892989568, 0.14175660482474736, 0.11557914449700288, 0.1564057009028537, 0.10426740933741842, 0.19369149873299257, 0.12326116513993059, 0.09673890724245991, 0.328802083751985, 0.2016322719199317, 0.1159952628825392, 0.21130816771515779, 0.17015223684055464, 0.11056443144168172, 0.15389687195420265, 0.17502099701336452, 0.12337268915559564, 0.15128666987376554, 0.1610644816287926, 0.14671175607613154, 0.11471878923475742, 0.16952315345406532, 0.10857277509889432, 0.08016549263681684, 0.15844088526708738, 0.15052989976746695, 0.085621382375913, 0.09459279597337757, 0.15370997626866612, 0.12039990510259356, 0.1536686263446297, 0.11711160226591996, 0.14709252278719628, 0.23261312235678944, 0.09729734834815774, 0.1899662193443094, 0.15845627444131033, 0.12408867930727345, 0.1376874167472124, 0.1338101319436516, 0.10562012996524572, 0.16995023696550302, 0.2193839829415083, 0.1262311264872551, 0.16684805628444466, 0.13699930081410067, 0.1233669351786375, 0.14142583257385663, 0.06551411668104784, 0.09613942155348403, 0.05699569306203297, 0.12964856810867786, 0.2432327110852514, 0.22679256754262106, 0.14197469955044134, 0.16034451526190552, 0.15453633692647728, 0.1012643219104835, 0.0546184625875737, 0.11124850330608231, 0.16653145184474333, 0.14709758465843542, 0.16790244542062283, 0.19146589030112537, 0.1369208757366453, 0.10461460213576045, 0.192640040868095, 0.14183376782706805, 0.13544084158326897, 0.14367953235549585, 0.12277306775961604, 0.2123365553894213, 0.057750108651816845, 0.1528912287737642, 0.09970989996301276, 0.07126409028257642, 0.17765010307942117, 0.18041072280279227, 0.12259607868535177, 0.15650917749319757, 0.11918762086757592, 0.10969978105276823, 0.18833153348948273, 0.0853273935083832, 0.24629165551492146, 0.13704439625144005, 0.17514924013188907, 0.11191334548805441, 0.08275001216679811, 0.11826508465622153, 0.11122769942241055, 0.17771167334701332, 0.07347923570445605, 0.07989187339054686, 0.1522077675908804, 0.09942062012851238, 0.12508531154266425, 0.2253871722412961, 0.06326186217899833, 0.19224654484008039, 0.15733513102999755, 0.1104007755805339, 0.11815645119973592, 0.09761524878974472, 0.12456091253885201, 0.12880290991493634, 0.24241040806685174, 0.17044986944113458, 0.11206127290746995, 0.18013301199035986, 0.12036707757839135, 0.15602941252291203, 0.2868917983557497, 0.08778877928853035, 0.10838936029800347, 0.1359301060438156, 0.08908606360533408, 0.07969489467463323, 0.20137123949825764, 0.07056821869420153, 0.123947340462889, 0.1958523884947811, 0.08843950794211455, 0.13717546207564218, 0.06013361218252352, 0.14620384547327245, 0.11702145210334233, 0.11321400890925101, 0.09892960504761764, 0.19177043038819516, 0.11915701893823487, 0.15883747541478702, 0.08082798030227423, 0.09298871883324214, 0.2346230245062283, 0.12435843768928732, 0.13563874310680799, 0.11240668794406311, 0.10457543709448405, 0.07275677911405053, 0.19224191723125322, 0.09663096589169332, 0.14669467056436197, 0.07700913093451943, 0.1081093153251069, 0.12351554791842188, 0.1486395826297147, 0.26050962401287897, 0.09898370464465447, 0.22754405864647456], [0.006034507507657898, 0.04153883497097662, 0.015406900950308357, 0.013718877154003297, 0.01292534317222557, 0.01962665085946875, 0.04001334575670106, 0.013760060836960162, 0.04067656284730349, 0.03293989299397383, 0.05230671752776418, 0.01937629857898823, 0.01270369631570897, 0.01864650532869356, 0.0781628575974277, 0.010851458563203258, 0.007610500507455851, 0.01520968644347574, 0.025409611440928917, 0.12230449861713819, 0.03408320753702095, 0.03051231861380594, 0.038292818436665196, 0.010053510711129223, 0.018803263881376812, 0.06979888890470777, 0.012617988012997168, 0.07388333723481212, 0.03936807591734188, 0.016706366757197038, 0.0134321401294853, 0.05111432454681822, 0.035060630446033816, 0.046191010158509016, 0.04607377627066203, 0.10899617416518075, 0.04185181603367839, 0.021390153194910715, 0.09386976262820618, 0.041019409628851075, 0.024642264670027152, 0.02703576471789607, 0.12010068473006998, 0.0727218481312905, 0.12331878633371421, 0.07783034829688923, 0.03827514599210449, 0.048230211450053115, 0.06266357749700546, 0.04719458719981568, 0.018596478638106158, 0.025657923027340854, 0.09039052003728491, 0.023414190925125564, 0.01923282234929502, 0.023029609150918465, 0.031877738024507246, 0.04849449744714158, 0.061414679512381554, 0.010178293301058667, 0.01355239689084036, 0.03168273723817297, 0.04362412914633751, 0.07726434152573347, 0.052716664637305906, 0.01912784619655992, 0.039336228876241615, 0.02266837576670306, 0.04890825113813792, 0.05494283625323858, 0.014731166584949409, 0.04098383743049843, 0.03921359384964619, 0.07056933827698231, 0.08623966348490544, 0.09664802426206213, 0.018330625225124613, 0.052213374857923815, 0.016160444622593265, 0.021380609599873424, 0.06698652410081454, 0.08260584383138589, 0.05680056335404515, 0.03046506204243217, 0.04104860020535333, 0.017553214083558748, 0.030075359025171826, 0.0392176548817328, 0.04426780442840286, 0.0430499595989074, 0.04628548937450562, 0.033608636752303155, 0.03945405648222991, 0.05467515418838177, 0.03301015529515488, 0.033505319617688656, 0.034960828122815917, 0.030390528363308737, 0.011503298317880502, 0.01740148856437632, 0.021448788798547218, 0.04395240778103471, 0.052033610575433285, 0.033418192328619103, 0.06794134500835623, 0.07509533648512193, 0.061109616953347407, 0.049119719969374795, 0.014294256190104144, 0.08223867496209485, 0.055719945446721146, 0.01659771124832332, 0.05759489376630102, 0.03289888573012181, 0.05004240885110838, 0.003572406297150467, 0.0313955608622304, 0.08967581910214253, 0.02833611092397145, 0.02810101889606033, 0.06248219830117055, 0.0394884514223252, 0.04642634306635175, 0.02652282447421125, 0.05873499544603484, 0.09264070500752755, 0.032392498438379595, 0.01161280962904649, 0.058908252577696524, 0.030541831494442055, 0.0279058196382331, 0.032202600235385556, 0.06332830432802439, 0.01888609943645341, 0.11208265354590756, 0.072444680146873, 0.0585119134879538, 0.009026600546868784, 0.05183420270415289, 0.020914554429639663, 0.023722403582983782, 0.01851441491661327, 0.06049310003540345, 0.010961204817119454, 0.03185925812327436, 0.028135561417522173, 0.04401509423873254, 0.04679001748029675, 0.0339066221910928, 0.04785764144201364, 0.06349869125655719, 0.027656712469511797, 0.12302758624511105, 0.04175697719412191, 0.014719645060332758, 0.03581533441320062, 0.08801684169364826, 0.06053346608366285, 0.020721543447247574, 0.06286579450326306, 0.02156182425096631, 0.007068781049123832, 0.008522095341634537, 0.013917044154368341, 0.023577643225767782, 0.04425689019262791, 0.029582603501954248, 0.04061900272167154, 0.016785821511543224, 0.04517840860145433, 0.02719148002298815, 0.05080585913466556, 0.024543900841048787, 0.020329813306619014, 0.062483290742550573, 0.01289085069272135, 0.005842465982173702, 0.04983131999948195, 0.0592056205496192, 0.03196131996810436, 0.027017664796273624, 0.057242659452770434, 0.03426256809117539, 0.01989068919127541, 0.04179280045043145, 0.040838169532694986, 0.031523888797632287, 0.02494613979277866, 0.042303815351000855, 0.03430010125573192, 0.016303323741470064, 0.02322555988627885, 0.014802120991849473, 0.030108885440443243, 0.05710995835917337, 0.03513421417613115, 0.02759646195253091, 0.021106026833876967, 0.028957306340868984, 0.02619874257860439, 0.03778558636882475, 0.049687250051647425, 0.023832002255533422, 0.045369049800293784, 0.018865361709945967, 0.08098549542150327, 0.014141099810201143, 0.0168250917257475, 0.021704856040222303, 0.038412389877651415, 0.012471650910031582, 0.020400196047765867, 0.010199147226688052, 0.0549853430794818, 0.08238819693880421, 0.025411596155858467, 0.020769098574029546, 0.06869509563382183, 0.04419717911098685, 0.008998018107376993, 0.06521180218883924, 0.022193453840113113, 0.05345360795035958, 0.03720042794676764, 0.02125404924819512, 0.027584604553080032, 0.029677092895976136, 0.05316656728142074, 0.04711176860811455, 0.04663845311318125, 0.03463781152718833, 0.00965878229388701, 0.06997426985097782, 0.06385491535599742, 0.04041821742430329, 0.05085161275097302, 0.026186622246833782, 0.02102087068903659, 0.05773494339415005, 0.047733601847929616, 0.005652895596410547, 0.008761553742390658, 0.029478146428508416, 0.04616900866052934, 0.017705484127093638, 0.03673865433250155, 0.04746958726484861, 0.06880928629211017, 0.033884142325924974, 0.03625250095501542, 0.07639679379229035, 0.10140591181282486, 0.030343478745115653, 0.05161468305491975, 0.012059993892242866, 0.011197253579406865, 0.03957769234797784, 0.01946203826394464, 0.039901702997407744, 0.00891630892043135, 0.01437083734864635, 0.015869246230327656, 0.026707866062809314, 0.014595072816259094, 0.005795060133095831, 0.035077726135828664, 0.038859781942197254, 0.05129579534488065, 0.025880148334960853, 0.030007339282227413, 0.026120342946212207, 0.06047487458480256, 0.1860076460455145, 0.052123350224324634, 0.021219286202852215, 0.02470715806287314, 0.03518010689211743, 0.00999331786962492, 0.024980287067592144, 0.041745245323649476, 0.04130689813090222, 0.007997161143326333, 0.02925506786310247, 0.026269776713369147, 0.029880745003798177, 0.0117900353423985, 0.05659509616504822, 0.013062382649098123, 0.04742373186828835, 0.050855541468730996, 0.03384201887196728, 0.009736967339579548, 0.06975944566407374, 0.07592853677592107, 0.03831923719761627, 0.026629172964021564, 0.029496080109051297, 0.006053580278863332, 0.03637366695329547, 0.01615798832582576, 0.07227048663688557, 0.05275896451036845, 0.04855120261865003, 0.014344170922413468, 0.03288099954703024, 0.02771983149328402, 0.024234970632408346, 0.015492004508684789, 0.02194194296108825, 0.07561546750366688, 0.07174471020698547, 0.02247557004115411, 0.06812014577112027, 0.019981132820248604, 0.035345398022660186, 0.03229402604379824, 0.04858349070751241, 0.024247472640126944, 0.08258555563432829, 0.01399470163908388, 0.029311969809766327, 0.029690897690930536, 0.06091740155326469, 0.036758976456310065, 0.037487977516970465, 0.061613673477300575, 0.048896865320525, 0.030936134979128838, 0.06077182186501367, 0.03563921047108514, 0.02331537926303489, 0.01633523354705955, 0.02799614961259067, 0.012784913564766092, 0.04407850333622523, 0.0748767125021134, 0.02961875924042293, 0.042258014237242084, 0.0031733982323203236, 0.018185715590204512, 0.029124792532197068, 0.03190811603729214, 0.027006840466388633, 0.0197415404088263, 0.023989407112821937, 0.04495400350008692, 0.021105063314150487, 0.018767196352460554, 0.02230155125393399, 0.020486180005328994, 0.015616782009601593, 0.0093966141742255, 0.07494025730660983, 0.10695003824574606, 0.18900142397199357, 0.08855744411370584, 0.1292763373681477, 0.07724829417254243, 0.1335186061582395, 0.06669393980077334, 0.11490872475717749, 0.13244072613971575, 0.11040666526449577, 0.06492165382951498, 0.16385136065738543, 0.1790915693023375, 0.1637574378401041, 0.0792251041691218, 0.07676080068839447, 0.10732605521168027, 0.2076029729630266, 0.24418662275586808, 0.10525070835969277, 0.10737011249044112, 0.11075528977172715, 0.13468633778393269, 0.138046782463789, 0.18381288381559507, 0.13437182323208877, 0.16391922772995063, 0.08739913055407149, 0.15331540815532207, 0.14701515622437, 0.10113458601491791, 0.09179841234747853, 0.1261340281260865, 0.07710380014032125, 0.1554919042225395, 0.09243744305734124, 0.13338236989719526, 0.26144345104694366, 0.09205598424055747, 0.0716924358691488, 0.10593254784388201, 0.23926211414592607, 0.16176825815013476, 0.18820878650460923, 0.1039530508486288, 0.12214311584830284, 0.12633126468530723, 0.152835697467838, 0.10456504193799836, 0.08270222973078489, 0.10802428131656987, 0.11971645749041013, 0.14716710735644611, 0.1314842767481293, 0.08866601650203977, 0.17918629279094084, 0.08272979860859257, 0.10116155778190919, 0.1333616610084261, 0.1078713530940669, 0.09058562599654708, 0.1485779852207218, 0.11804152093827724, 0.08907910183604274, 0.08969038046364274, 0.10601429095757858, 0.1814737157630069, 0.19753891442503246, 0.13078136875161103, 0.09080156976623194, 0.10750966000237636, 0.10219014901667833, 0.13756274272288593, 0.24671774836523191, 0.25900086068681305, 0.08767441899648734, 0.1197417668466057, 0.1021520085632801, 0.08703132386186294, 0.1762022314859288, 0.10092125460505486, 0.15053939925772802, 0.13863478734024934, 0.10931652411818504, 0.10126305304999862, 0.10943540345345225, 0.17479982173868588, 0.06615143069731337, 0.16747681397412503, 0.17819085477718286, 0.17152423464826175, 0.06279469760400908, 0.08195133573774781, 0.06362594371395451, 0.12380973356110708, 0.22973564533250673, 0.3376256174274853, 0.09639780768858534, 0.1357590609363147, 0.11143121921590396, 0.13900096554841312, 0.2644592135080269, 0.1570605007665498, 0.12537233185555252, 0.1545274888298341, 0.13929911383560725, 0.11136858364833252, 0.11008387258542435, 0.16318427930985177, 0.18711751220481737, 0.07590328848787717, 0.1483670693955251, 0.1091763252126319, 0.12359585932322911, 0.09933737745242459, 0.09456602776689188, 0.17525719505335602, 0.13471445627510548, 0.07874686590262822, 0.12174094814274992, 0.10994707992566483, 0.1354836571429457, 0.10587751865386963, 0.19598239580435411, 0.20957635635776178, 0.2590170098202569, 0.15112923617873872, 0.1379471192402499, 0.13375101797282696, 0.09472499495106083, 0.0966639087668487, 0.19824463155652794, 0.17514341830142907, 0.25068408410464016, 0.20765705220401287, 0.1644401526344674, 0.10316141761307206, 0.14782707765698433, 0.13337584239031586, 0.07463927274303776, 0.11856254083769661, 0.15984610414930753, 0.060604325495660305, 0.12076712825468608, 0.1304552105388471, 0.11561905592679977, 0.16829896771482059, 0.1300625287528549, 0.22934092794145855, 0.18560767679342202, 0.08470399624535016, 0.25693149172833984, 0.13197808739330086, 0.07370414970708744, 0.14794990606606007, 0.2218682217810835, 0.08843685487019164, 0.1252203264406749, 0.12158698854701859, 0.07501521507011992, 0.12735620540167603, 0.08312577807477542, 0.06511289213917085, 0.13578190042504243, 0.2420639752277306, 0.13440874910780362, 0.12838700866060598, 0.11479975203318254, 0.12246091450963702, 0.07367910497954913, 0.1809853741100856, 0.19341523998550006, 0.14885163839374269, 0.10503069337989603, 0.06791051237710885], [0.032660482451319695, 0.011093532716456269, 0.01953333872370422, 0.04894870200327464, 0.027573652997879044, 0.007071937509213707, 0.00942262411782784, 0.03513750846364668, 0.038296682693596394, 0.01711224265662687, 0.03300700010731816, 0.09565629783485617, 0.03456482490790742, 0.027864583368812288, 0.003934892002559666, 0.007384644189317311, 0.045286275313368866, 0.017162990290671587, 0.04331562302208372, 0.031815462080495696, 0.003541357594908082, 0.02678379073872098, 0.07335071438657385, 0.031575250505868874, 0.04731462343728968, 0.01791095470876566, 0.024563697100217854, 0.056964799362633906, 0.01726134224528713, 0.01746168819123081, 0.06839563777404171, 0.04496258357539773, 0.05245792905666998, 0.05620468407869339, 0.03672603018847959, 0.027260320793305124, 0.013630471674592366, 0.03493099972339613, 0.016770327164392387, 0.009153843674409603, 0.01850271358021668, 0.03205657949937241, 0.04337032990796225, 0.054981516141976626, 0.0014194065193545871, 0.06213867637727942, 0.03472295070865324, 0.046432297211140394, 0.04762865283659526, 0.14036184895251477, 0.04801066126674414, 0.029101026843168905, 0.02359278473470892, 0.031325607294482846, 0.04032178742012807, 0.01802754059566983, 0.06618372896420104, 0.02328794269955584, 0.0163394777836012, 0.04563564281644566, 0.030779973537261997, 0.03292473452165723, 0.004640017112251371, 0.018588602542877197, 0.032528476856116734, 0.014593602091606175, 0.028910697770438025, 0.026958562699811797, 0.013574924253459488, 0.07625633704343013, 0.018353568190442662, 0.04147276940888592, 0.06279308269066469, 0.05687396727236254, 0.03983884351328015, 0.0621012348149504, 0.02760207513347268, 0.02898493628682835, 0.07143567143274204, 0.02822313823604158, 0.0458394984847733, 0.02097979048267007, 0.05529026993151222, 0.0685917411797813, 0.05889705674988883, 0.04425678841237511, 0.024863709662375704, 0.05576234370736139, 0.07898823437946183, 0.03958389755072338, 0.11032366007566452, 0.0070110644363532105, 0.023755641620872275, 0.020600012736395, 0.04147952761767166, 0.013255973778931158, 0.0316297063337905, 0.023696953430771828, 0.006381415745376476, 0.057680606309856684, 0.05291434902963894, 0.029718049269701754, 0.010358404484577477, 0.026682929900873984, 0.00752479220474405, 0.04452087763430817, 0.05945551821163722, 0.051452367300433774, 0.09006734059325286, 0.01620105155078428, 0.015890840607296144, 0.008385686902329326, 0.027401934444372143, 0.00507115275000355, 0.026277072661157166, 0.01915105039786015, 0.02179694002760308, 0.003061419598192775, 0.009399320680781134, 0.013170911780824619, 0.024235157229538475, 0.05555420309039099, 0.04967421539393919, 0.050654413511178324, 0.04398442106321454, 0.055871397855558565, 0.04910542323653187, 0.017344220208802393, 0.025426065915131142, 0.0460323245663728, 0.034068619034120014, 0.03204448461266501, 0.018531261244788766, 0.015412032371386886, 0.017126457965267555, 0.067083690315485, 0.011351971438021531, 0.023603120519380485, 0.0349234849480646, 0.06862796137907676, 0.025509697052517107, 0.014404633481587683, 0.03010507546631353, 0.013605575376589383, 0.07904067835105316, 0.0161135629418173, 0.038188364755894454, 0.023365458540086235, 0.06992008882973876, 0.07281510598425354, 0.008870790246874094, 0.019040839347456182, 0.03318518001054015, 0.053108956265662394, 0.03708835431773748, 0.05220670146601541, 0.014957101782783866, 0.012152145733125508, 0.010828789556398988, 0.05042168617780719, 0.05871009321085044, 0.03230159849460636, 0.02496731517437313, 0.028453538194298744, 0.015538426481985619, 0.027818286924489906, 0.06026104784437588, 0.05214513119842325, 0.014377431012690067, 0.021570171928033233, 0.0030637003240242067, 0.09068202546664647, 0.04386837461165019, 0.05592555173539689, 0.031757257346596034, 0.013713362360639232, 0.033886279711233716, 0.03982830586444054, 0.05865481974823134, 0.02273987639429314, 0.07049541867205075, 0.026641501945310404, 0.020065919163503816, 0.0384118436569614, 0.01836134080908128, 0.031160302593239715, 0.03801069375393646, 0.062238957067685466, 0.016480719936745505, 0.010224166509163166, 0.030722016468644142, 0.025816238817891905, 0.025013501356754984, 0.007322421679938478, 0.1105372832555856, 0.019393777641068612, 0.05206019897013903, 0.042923918326518366, 0.08961516485682555, 0.02924713578873447, 0.0052927669520223776, 0.07623661881578819, 0.025906852080619762, 0.02575037851264434, 0.01755616910356496, 0.0067617825448646075, 0.037047991662153175, 0.05469311840300049, 0.029189083725214005, 0.04607023431786469, 0.01585924462415278, 0.02435968367249838, 0.028385075707254664, 0.04373053361528686, 0.032480813163731775, 0.05485713728038328, 0.047674104504819424, 0.030325677378901413, 0.025798868321414505, 0.025353681495679275, 0.023294482080798064, 0.03697752580046654, 0.00734887521580926, 0.10816450736352376, 0.012492139274919671, 0.10685084321136985, 0.0591110870508211, 0.06272305109139, 0.057872211028422625, 0.010601201277625347, 0.033880176288740974, 0.022401558833995035, 0.041204761647220166, 0.022275877185165882, 0.033183473494968245, 0.016312709577115517, 0.010469422991653638, 0.019407918310857246, 0.04817542313997235, 0.026731155080986873, 0.08542297195111002, 0.02586089151113161, 0.046761362946459224, 0.024770356814510057, 0.03424293468041079, 0.02695610131403165, 0.038739179127982686, 0.05419283453375101, 0.044108871170984845, 0.06277712354702608, 0.07963015564850398, 0.036660670302808285, 0.0405319738201797, 0.014254845179883497, 0.09452275758875267, 0.018164491014821187, 0.05152243282645941, 0.016804096155932972, 0.016638133275721754, 0.047661052883735726, 0.07696088709469352, 0.022121325567630783, 0.10005116915064198, 0.06778943458838121, 0.037082189827093055, 0.042234876193106174, 0.025761280874056474, 0.05557405702503664, 0.039954530341284614, 0.0024788536039912806, 0.02846079512632319, 0.0052675190880628565, 0.024344153702259064, 0.030959340876766613, 0.04755732523543494, 0.02524129574054054, 0.024498883435236554, 0.011066978248501462, 0.02254695531779102, 0.033491959263171465, 0.06074435476745878, 0.02603001975720482, 0.1403756367840937, 0.048377059998789, 0.03582250652834773, 0.045796801668724844, 0.05578327651268669, 0.008680509519763291, 0.059907130763999054, 0.050251974391617944, 0.0050991898169741035, 0.0073853091536355865, 0.014325355146346348, 0.04506564965205533, 0.013211320237522679, 0.024663526564836502, 0.03263234021142125, 0.03648665321192571, 0.019772232244057313, 0.03372123624597277, 0.012170765582205994, 0.036919768899679184, 0.05575516480686409, 0.06110322515347174, 0.0278122903712626, 0.05910419313503163, 0.010262736984129463, 0.04559998240854059, 0.04063245467841625, 0.014092638839169272, 0.04199251366247024, 0.04935368562915495, 0.014083234343810805, 0.02523947217767792, 0.04916338369782482, 0.06952196519289698, 0.06109557127846139, 0.027726509974205067, 0.014452298870310187, 0.00571993867301249, 0.0224448018707335, 0.04094219573640397, 0.025963156916467205, 0.019238411781511137, 0.05827482656708785, 0.040629503051085133, 0.03398407357079642, 0.03583603651661958, 0.025673249437074577, 0.0727891723758408, 0.03179168960611735, 0.023328980497483696, 0.035096507985144854, 0.047503028863242695, 0.07947854378393718, 0.02723960342284824, 0.02537081959391279, 0.02139358488576753, 0.06426166995827641, 0.009852934063279202, 0.03139878051089389, 0.06978403577314955, 0.006039011283844177, 0.02344757824071816, 0.03919056097843817, 0.0578800073957869, 0.07276844313102108, 0.12191115186682769, 0.03262387548706361, 0.008686288941784628, 0.010347835453493255, 0.04529661279437797, 0.12739957736006804, 0.08597920781799726, 0.17977971237684998, 0.11011968566370861, 0.16481519250997476, 0.06660345715603658, 0.12281809534345355, 0.10117966788155691, 0.20279651587562902, 0.09640333096363715, 0.1087441323325038, 0.19200413141931805, 0.0921194204794509, 0.04868848382362297, 0.055509328176932674, 0.07549134309270553, 0.1032008540683559, 0.12136028999728815, 0.14121658594480582, 0.12096044288149901, 0.12622852091278347, 0.1600561650203807, 0.16548031967665466, 0.13282040719475063, 0.0474378623600517, 0.15968119299837522, 0.09018611814826727, 0.09827274922281504, 0.11423012188502721, 0.05575822839247329, 0.15245179592498712, 0.12444983635629926, 0.11558546844337668, 0.1396244985184499, 0.14966666751674243, 0.15276962172772202, 0.18466844862060888, 0.13097002862819604, 0.12169258216662066, 0.07364251837134361, 0.09599858482501336, 0.10320338500397545, 0.10643576976976224, 0.25664314148681505, 0.12505249758916243, 0.18916930710630758, 0.07843529619276524, 0.17124956367271288, 0.1244050394743681, 0.2128906063735485, 0.12231656296976975, 0.13179155811667442, 0.09952368959784508, 0.11838358401187829, 0.14606277804289544, 0.0951402448117733, 0.12265949456819467, 0.12651098147034645, 0.11010718704866511, 0.09470857440360955, 0.1432967707514763, 0.13032510823437146, 0.13917457551828452, 0.06823983934840985, 0.10855123839740242, 0.07812311580138546, 0.11378494862999235, 0.09123719603355442, 0.14347716607153416, 0.1873753826533045, 0.10006542517138378, 0.0903654278122953, 0.14370592736772128, 0.17341281473636627, 0.09556876681745052, 0.14381623002035276, 0.1590617855212518, 0.10490480477788619, 0.27310535098825184, 0.13082678988575935, 0.11698287060218197, 0.09868712377335344, 0.11249784912381854, 0.14817629248968192, 0.20483898770596298, 0.11104648307498012, 0.11087591294199228, 0.16895216623587267, 0.19195296987891197, 0.07944478666675941, 0.1675930605935199, 0.19143835535006865, 0.2669483513704368, 0.11441750611577715, 0.13031085899897984, 0.13102819264999457, 0.162300297458257, 0.0924774698380913, 0.12712429570300238, 0.13790281090353215, 0.1373838401798691, 0.15310964919626713, 0.13712520977216108, 0.07882156582283122, 0.14517186156341008, 0.1468377871704953, 0.25311847776174545, 0.14279902460319654, 0.11957796849310398, 0.11596510878631047, 0.09888883187834706, 0.09966812256191458, 0.19094655316855225, 0.09409519910280194, 0.05572091914447291, 0.0579152505046555, 0.10843546675252062, 0.1359128983957427, 0.14542358448462828, 0.07912333748702492, 0.13196337675409658, 0.11129507116441216, 0.09706175420433283, 0.11290327379746096, 0.15025457739830017, 0.13122860475310258, 0.25186329654284884, 0.09325547130512339, 0.07187099235930614, 0.19155134500137397, 0.1457789061324937, 0.13008387546454156, 0.08639636436211211, 0.08728857005813292, 0.09509176348469087, 0.21963110539530004, 0.1121106973982283, 0.0985500393435359, 0.1541922925306218, 0.15401664695569448, 0.19469288071351393, 0.1424113911177431, 0.06824440588908535, 0.08893285039812326, 0.0788256913157446, 0.07663453210677419, 0.09067606114383255, 0.11932803690433502, 0.16341833317918436, 0.09341810936374323, 0.08665745785193783, 0.11021926746304546, 0.12438650189765862, 0.12974505578832968, 0.11850548961332866, 0.15514746627637319, 0.0872261244803667, 0.14529767552656786, 0.18938428057091578, 0.07968278282455035, 0.1697454143847738, 0.08336546378476278, 0.14422172254749707, 0.10554998980036803, 0.0874212168689285, 0.150000126766307, 0.1631220169365406, 0.08988340332039765, 0.09680701858763184, 0.14210567037974084, 0.10441830195486546, 0.20243704159344944, 0.08982933086476155, 0.13558023981750011, 0.130682071936982, 0.20872731905962738], [0.06496786884963512, 0.05786005846623864, 0.04395273008516856, 0.026012181071564555, 0.04621284541540912, 0.02057271357625723, 0.035392949756767066, 0.006514979850700391, 0.011859700532763131, 0.06391400218542133, 0.04427796209763203, 0.013851108362099953, 0.03594936204275914, 0.09056275936641864, 0.06003463427935328, 0.05904877718005862, 0.03445776904534016, 0.04902917964916144, 0.03337744969342436, 0.05457682428615434, 0.012278585644838, 0.07030839406486068, 0.052953276583658795, 0.08036374021321535, 0.005079652673365282, 0.04627592542341777, 0.03152395325845905, 0.024230889244271175, 0.019113856500812938, 0.05351157519700272, 0.018071065224441032, 0.06330911535769701, 0.03774463338777423, 0.052333604477878125, 0.02930970350280404, 0.010599868804482477, 0.02695486298762262, 0.03237464618203895, 0.011775904850635146, 0.04228463316602366, 0.009533505221562726, 0.025251137890986035, 0.06582021061331034, 0.022784225443111997, 0.02060475230350026, 0.01871018753653126, 0.017023917753249407, 0.029784993534641604, 0.050332228120948584, 0.0447680611562516, 0.03255276840978435, 0.010543910869663315, 0.03314990297492061, 0.01421643076797149, 0.009924495759020959, 0.018237482723114744, 0.055449318539883406, 0.029326354752161672, 0.023938944463485053, 0.044463195372372866, 0.03761698738006609, 0.04402571331177439, 0.03605281488437738, 0.04553385577829821, 0.04094858753627964, 0.010970342139314328, 0.03607546777597495, 0.060167240378047736, 0.041846207941749265, 0.049922535462038856, 0.03728811163455248, 0.02512184643585767, 0.03239130760942187, 0.09887290666145937, 0.02905856751437698, 0.026902727749464766, 0.034525123823966296, 0.03100294353706496, 0.07661294790783099, 0.02919743988396866, 0.0578420026493924, 0.04899694584310055, 0.056698759352522235, 0.008028727440562631, 0.08105260932019778, 0.033359322630401166, 0.04631507350131869, 0.024383905676326582, 0.04600051823737366, 0.02978513263432043, 0.03848684552524771, 0.022528955480083823, 0.06375875337315456, 0.0477603157716138, 0.023557114148778573, 0.02664568172102528, 0.024255964505885328, 0.08913788332470826, 0.051251463259437254, 0.05875624716281891, 0.012012062178525542, 0.020312970371118615, 0.04844034695997834, 0.01046909814301346, 0.03681955945545009, 0.039816339899386675, 0.02599550437714372, 0.024305061603497182, 0.0406287668405899, 0.02496377831058843, 0.009086650047850395, 0.03257465794948595, 0.022419648577592204, 0.04116008011624217, 0.04415068928418415, 0.023981101844193678, 0.007267339903462146, 0.06598491820373706, 0.05132995279771941, 0.04675627054114427, 0.009825646777504256, 0.03131545641060386, 0.01366305916703173, 0.0607794350279229, 0.020006369233929684, 0.02643750887364149, 0.05361269727083189, 0.005707821733916977, 0.05455693981743284, 0.04169139678456953, 0.030336313415318727, 0.03022394801623055, 0.10931220863546644, 0.019176807587168047, 0.061673988455108235, 0.04101629854579057, 0.022654287683378373, 0.03606646361627749, 0.06238694555525269, 0.039328446079577715, 0.021060514097501124, 0.044189895037561655, 0.035524504126182625, 0.03309104684740305, 0.009971988121313708, 0.028239149966144135, 0.012693750688673129, 0.040095960787896595, 0.026822482501821857, 0.09688889062298195, 0.03851097083783575, 0.0399470596707293, 0.018146258778870106, 0.0293263411814613, 0.03079839237034321, 0.018257048280377473, 0.040347880484270196, 0.025135286518239548, 0.019245505865131105, 0.012769600725732744, 0.07726425331618104, 0.023773029080725143, 0.010485803675172585, 0.030263238586485386, 0.09161489576633487, 0.002713815225953502, 0.027750652250168577, 0.044368064762758355, 0.01685662324806409, 0.027715069873790656, 0.011322214284778705, 0.07480017375200987, 0.010294903784857264, 0.027394675816010152, 0.009049021040222474, 0.035067700780928135, 0.07626706468207495, 0.036919718009552786, 0.037751975136676004, 0.015030877199023962, 0.03786161282498922, 0.047581898381135294, 0.007121521879785827, 0.02271409545625959, 0.01779679797722825, 0.03413144459149667, 0.057566117096160135, 0.04416115229417171, 0.06667151421840702, 0.10151955964309828, 0.028032203570806553, 0.006296903360635042, 0.008060264051891863, 0.004458866921985256, 0.022357867964144264, 0.047539435659668276, 0.049456738135112185, 0.03145402683211224, 0.043605153914541006, 0.002584277165754299, 0.03740885015577078, 0.04268901628841247, 0.039481435370232375, 0.019371786321114217, 0.03231416157047663, 0.016916110413149, 0.04757447520803128, 0.01999503091376807, 0.09177259409001895, 0.04030135673071657, 0.046387418905006986, 0.017264348155419742, 0.03808390089709844, 0.09104519776467766, 0.059799338690936565, 0.013754035445994564, 0.08365888268287693, 0.03932095844564693, 0.02803501609845885, 0.03184273579557027, 0.05334672172154699, 0.0007139465420290694, 0.03563376862023558, 0.032300960671688826, 0.010726102611183055, 0.042339658963360956, 0.04707070027611085, 0.035819707571395805, 0.02330832928419113, 0.00826812646950462, 0.018409169046208262, 0.02559708897024393, 0.031150216170187508, 0.08233485051563807, 0.044205104400004656, 0.02368881949223578, 0.04566094199461596, 0.02817674510047904, 0.022958949906751513, 0.07971185126474925, 0.04715791916740792, 0.03824625736368554, 0.018949313455128243, 0.04872452760381358, 0.02812717981370432, 0.0325147908047906, 0.00709773413836956, 0.032104684239519496, 0.02772943106746035, 0.039245854797107835, 0.02506866116475846, 0.011701124354398676, 0.03700690297409892, 0.04353433521464467, 0.04707337370408433, 0.016637505630829504, 0.07665460317262582, 0.04100283980369568, 0.014411308569833636, 0.0160516890298043, 0.0013163922870132539, 0.024851876011650478, 0.012782515791643943, 0.08320089190133981, 0.0691261485751186, 0.06264274647193295, 0.02167278847524098, 0.027367668425930396, 0.050404220686427186, 0.15833184468959058, 0.016584530705586076, 0.05347314975889666, 0.015678552445024252, 0.055481626984796355, 0.008592002260099565, 0.04099317407235503, 0.021936250052281787, 0.03184100553127272, 0.022262299699442725, 0.08395241014659405, 0.024558253553030745, 0.01569376011112971, 0.06844841422779219, 0.03714641655928322, 0.024367488521550382, 0.02129033730099244, 0.017853179148265293, 0.06755924158330474, 0.033042361959815025, 0.016957875939884355, 0.028344748674758842, 0.012161104939877987, 0.018132352203662907, 0.037228312343358994, 0.07484608343137161, 0.05391987346644912, 0.06040751641350133, 0.05278364282899669, 0.044682857513959916, 0.047160433139652014, 0.01478947649177696, 0.03621154797396489, 0.033788339966642, 0.08559858359928642, 0.04646096870835338, 0.0697276359423995, 0.051799824727433066, 0.06529122471277203, 0.057787394151091576, 0.049346903671643565, 0.04056659946218133, 0.06442933596138443, 0.06196085949029241, 0.014715638311047639, 0.07060884258576802, 0.04157340972285185, 0.0406553721986711, 0.05284421904278653, 0.030485390951590877, 0.013217929168604314, 0.0562630143415715, 0.03690002353063651, 0.045311618596315384, 0.029450180607714822, 0.03417477583778756, 0.058326524150158675, 0.03551389862384115, 0.04427213687449694, 0.050510255353791375, 0.013924340102156358, 0.03441090602427721, 0.024990770433630263, 0.025689290004915426, 0.019722918015239493, 0.044869654811918736, 0.026326436083763838, 0.013115998789934176, 0.03595131961628795, 0.06991246209612914, 0.04619352413075311, 0.06104992622775691, 0.07850804193211453, 0.02461274839671595, 0.04191312167261328, 0.039056811548237286, 0.016822664266718284, 0.0277909538376012, 0.045924349288855276, 0.020942645779411708, 0.010024230228736997, 0.05006758250030024, 0.022735784828130687, 0.2486439464347703, 0.1089561338137303, 0.1480040531605482, 0.103218577403043, 0.1546890480177743, 0.13126547634601593, 0.13464975117572717, 0.06522389368287154, 0.09584698653114693, 0.08387636672705412, 0.19881439741168702, 0.0819434579461813, 0.17729281368000166, 0.29247388882296427, 0.17133341703031743, 0.22808042700801576, 0.16834843291768006, 0.16164412695382321, 0.13410742527672223, 0.15417327997939928, 0.14168199311409677, 0.12276466749608517, 0.06913165149411984, 0.18875373154878616, 0.1456457639911345, 0.1097353837851967, 0.1575348645980869, 0.10921255898262773, 0.09084067373935666, 0.08912207345877375, 0.11978402600756713, 0.12097454283918653, 0.11858049487429005, 0.15746918240828173, 0.14231512056929724, 0.1207771570022617, 0.14936041752142565, 0.12152959805514131, 0.10919953789561987, 0.0845661179295608, 0.1551020180008241, 0.14391138777136803, 0.11765494596745286, 0.1308798241828169, 0.12359953698303018, 0.10709408444485494, 0.0900600870539035, 0.12112740320818764, 0.08419472178710358, 0.07856959862900631, 0.1264655739068985, 0.10330084298870393, 0.1591211709060839, 0.09571158486817564, 0.14158640110066958, 0.04751360383150833, 0.18548376272831643, 0.19121218605765275, 0.15210338176361152, 0.10824929709945406, 0.15041665227285453, 0.12201407205845628, 0.13886994043631212, 0.3227521569601127, 0.0834176159862961, 0.15338639648897306, 0.11053180069263492, 0.16282741060214384, 0.14137043697493418, 0.17465770936438016, 0.10611692616449935, 0.15009238038744244, 0.1323509830981493, 0.19708337315491267, 0.11162139222558055, 0.08778586158795015, 0.12546237345252717, 0.10414855714355196, 0.20409762034458773, 0.11818651030106203, 0.09358836058527231, 0.12608676137668745, 0.143195207629885, 0.06977054649697882, 0.11952311572219644, 0.15871305923376763, 0.09293634271515266, 0.1653432556028877, 0.11406487146658556, 0.16028572698788984, 0.1485532729753426, 0.12264031916856766, 0.18748644526515687, 0.30962611415556496, 0.2278185396322182, 0.06975249068013259, 0.11553501257938997, 0.23257756712181227, 0.13247896837336676, 0.14765508260045732, 0.05476534167038543, 0.16132792963513307, 0.12407039957387106, 0.1351331938058138, 0.09921209953193154, 0.19639656000903674, 0.14622068671243532, 0.08529236753072057, 0.09092525991478137, 0.06681416263537747, 0.12445913228605475, 0.16272690599518164, 0.20325420131640776, 0.16740712842770986, 0.205896864512137, 0.20834710874727794, 0.09629412075238568, 0.12855434896690504, 0.19750369845756463, 0.10057305078953505, 0.2131081854126283, 0.12168278412095138, 0.12919678592256137, 0.1456181611865759, 0.1441250177366393, 0.2223813028207847, 0.12323504154171262, 0.13423273712396622, 0.13014262302645616, 0.16906742219414028, 0.15809286465602262, 0.18553098876561436, 0.15878896016095365, 0.13345729373395443, 0.15181452940617288, 0.11139963341078588, 0.10142915842256375, 0.09274632576853037, 0.13360220167253697, 0.10239863568650824, 0.12259022971349103, 0.13163495223437036, 0.10826488304883242, 0.17619461832301958, 0.17841991462877818, 0.13002309229757103, 0.10594949086329766, 0.172291617042252, 0.14953554740973882, 0.15482915192842484, 0.12572792491742543, 0.1604356967977115, 0.14015940124435083, 0.12839243694075517, 0.08251848923308508, 0.141401541020189, 0.11025234604520456, 0.12004656477698258, 0.16421163561088697, 0.11589466328067438, 0.16325283848813602, 0.11421497698341097, 0.15125643435333455, 0.2394271610038621, 0.17540700201477322, 0.18816831867609704, 0.09241909547043697, 0.1666417544973748, 0.24314281876598084, 0.07798221121941294, 0.17572220867233618, 0.1609121369464057, 0.11028291404779468, 0.08374775041426931, 0.05526033296648945, 0.07989892336939063], [0.0575006723936115, 0.057926799170672894, 0.05578487106998052, 0.06794743825282369, 0.055381220765411854, 0.053926950586693626, 0.08280261220144373, 0.07141433150640555, 0.04002127443839397, 0.0036815316915245993, 0.017018918646499515, 0.06119944141911609, 0.0266484331805259, 0.008544143488896745, 0.031850803576942, 0.035210854706487486, 0.038287912628480365, 0.06036654646907534, 0.008267866929859986, 0.022583007579669356, 0.04739346920645662, 0.04686080225344215, 0.026564237162736908, 0.006395227749765451, 0.03143300920990961, 0.034128394576587846, 0.02414231837194945, 0.09629161017281668, 0.05025132639067514, 0.09356391975390059, 0.04966831553195204, 0.04977313222895775, 0.0054351647351203215, 0.03506050491705537, 0.08219850568899087, 0.04616984665127737, 0.02515796655123787, 0.061197561877114434, 0.022355255604322468, 0.05430256721696683, 0.038030869992715974, 0.04320832627958485, 0.008763846342584916, 0.011772887066139706, 0.028612335744713033, 0.06908471722687994, 0.05990029791636126, 0.030685358614261662, 0.023492566808792095, 0.017243542575410435, 0.044505437569958825, 0.018355564779735038, 0.0051417666171411315, 0.03143890567922166, 0.03503345851121204, 0.013533303763584366, 0.15674613549240998, 0.015010034299588628, 0.06087883362280471, 0.050405917023973804, 0.09775098293487515, 0.012167109126624252, 0.07532521736408983, 0.05603075859003833, 0.01849142784651901, 0.023216450553653494, 0.05276372782619936, 0.012373417699044304, 0.026478473729054843, 0.01618646304788334, 0.065909743309021, 0.059354022943547795, 0.03948647349274584, 0.03074876092640417, 0.013914901680046958, 0.01625797215716115, 0.03001595667696425, 0.008694707016859735, 0.043105473941458125, 0.017049232198457633, 0.03131418755011899, 0.03055955482912915, 0.020021810994616578, 0.0363002053595015, 0.05944350814180715, 0.04315506128062095, 0.05466003303549119, 0.041129071065889936, 0.03853919110926134, 0.01660132105462253, 0.017173241258465817, 0.10018030115004097, 0.025765777864892567, 0.001709961363563447, 0.032812199488814385, 0.014423133738871132, 0.019224515384329215, 0.04833107228790011, 0.02533041113721473, 0.023663623790655817, 0.022648508261357034, 0.040368552053613324, 0.03930574229785374, 0.04204277614397662, 0.05011635220476559, 0.052249384711363485, 0.04346238675394228, 0.049577435944229364, 0.023108970606699586, 0.046658374901328764, 0.057138483971357346, 0.05920912857566561, 0.01388407583414976, 0.07499834668955632, 0.012636356804120754, 0.04271557414904237, 0.03130737505853176, 0.034602588774370294, 0.03267407690041831, 0.045232246962508986, 0.04243765977610435, 0.051544166303106716, 0.025141152453475764, 0.037380365255687914, 0.06429148478699581, 0.04951178768117513, 0.03441364052040236, 0.04915845753358943, 0.05282709960426603, 0.01770243580852236, 0.008668412936718335, 0.06128290122640984, 0.06785874694053616, 0.03602615863616977, 0.012263109957400178, 0.12444427236914635, 0.04768689488992095, 0.04914463238258447, 0.019666947357888733, 0.0039212945848703384, 0.04504263713689787, 0.017319087271711657, 0.04848863829725555, 0.04167407039286835, 0.07111438510141202, 0.030067532123731713, 0.05860670483005898, 0.04536193536062326, 0.056624001756842644, 0.007521203602664173, 0.04872467688151768, 0.0441621599186744, 0.039661030018968244, 0.03076200932264328, 0.05344454950786062, 0.03707642906478473, 0.016924919494028603, 0.02641926645966513, 0.04267201220084514, 0.02229199748087142, 0.009913961502856441, 0.044150981054242165, 0.050163188084427796, 0.056090272896523984, 0.06278900469520263, 0.04976332739793828, 0.045132627843746116, 0.04389655077829957, 0.015231937303074768, 0.0229499440507165, 0.034723819233477116, 0.055631267705133984, 0.034047984784202914, 0.07500978000462055, 0.058921728283166885, 0.04942523714687143, 0.010491470290747072, 0.023204416735097766, 0.0728062918143613, 0.037556709721684456, 0.04359334401254143, 0.024685670555170094, 0.02992138246606503, 0.011796446650155952, 0.03536451235413551, 0.04017416534147092, 0.03174284526279994, 0.012742382141628435, 0.026426813465410044, 0.04028095318270581, 0.029037393829120055, 0.02496595980067338, 0.02441159329776253, 0.025614210105101978, 0.007761601774421121, 0.05099244608676859, 0.03335474591170039, 0.05539384151675871, 0.003279449651017785, 0.014223574045380312, 0.03488149720111063, 0.03951652241604669, 0.06571252710585083, 0.029090719896235635, 0.025769046707344905, 0.04248314876375454, 0.0650459953716823, 0.015085360168346336, 0.0503301110916904, 0.05364615583260145, 0.08491004697446312, 0.03667713834771088, 0.05569636296214802, 0.05190942509632025, 0.0511034408451191, 0.010563964972139468, 0.03610296880028077, 0.051818623540124724, 0.015320396217118417, 0.061930264346301556, 0.02692193368316761, 0.05656705231272748, 0.02500587123047028, 0.01668753401775445, 0.027940723479592373, 0.04211822923805032, 0.030702264314251285, 0.037163715809583664, 0.008301752120522516, 0.052053284698299, 0.03803516172670892, 0.04051181115210056, 0.011450264020822942, 0.020200654165819287, 0.019530022383800576, 0.0598855194236551, 0.0666043528222612, 0.055048372197364054, 0.04325847341013806, 0.07899816134678465, 0.00650436374624925, 0.030600999748068194, 0.02171164139040879, 0.020922157414523617, 0.01026999476432268, 0.011003374920359679, 0.006737638148479164, 0.011702418659946747, 0.016337396377431493, 0.035993293792541535, 0.025013631974746073, 0.059993691476328034, 0.027619839180260897, 0.0800640991489802, 0.05809538119605609, 0.015034320764243603, 0.012430903185824198, 0.01924142617333148, 0.027189227286726236, 0.035815446371478696, 0.0360793082841805, 0.021448383373873572, 0.01569010959272938, 0.03533644136041403, 0.1271038582282407, 0.03972563673076885, 0.013853321234429521, 0.028300206243459667, 0.058931526328836165, 0.04148883033277733, 0.0476135723958058, 0.01383991168612348, 0.02457590394520334, 0.0435868843591639, 0.04379004792177251, 0.04507849771263344, 0.058702174707182815, 0.02422176973362054, 0.062071318205978186, 0.041152141256523986, 0.07362403507743563, 0.04948952155453818, 0.04616308165714145, 0.0021733217955833034, 0.018417928933299015, 0.037427160423249006, 0.023586844160620655, 0.018727600441447327, 0.03296208448175873, 0.03700283854933722, 0.07133946195244789, 0.06366850821567432, 0.05725889001041651, 0.04208545260397451, 0.018823316287515417, 0.02105450736624854, 0.060275168158113956, 0.04845691678513374, 0.012278434670796352, 0.05028640325846417, 0.0469235837060426, 0.040122209915093014, 0.030717154765235524, 0.022306806507653425, 0.03348506874005709, 0.021353732827784758, 0.0071896357694640756, 0.02922552784106561, 0.014409391708405954, 0.002550159576847883, 0.036599442695400546, 0.06582337258649723, 0.022975027794018388, 0.03748761789341058, 0.040866885134684186, 0.01917646831965872, 0.03765627116497074, 0.08510494937321969, 0.0696815023464816, 0.0232315106383924, 0.0141535840063755, 0.05009222349950245, 0.0472271568807108, 0.08246726662452732, 0.014404501167259045, 0.026136385210390602, 0.03921259640316878, 0.019032028570239033, 0.01400570832525513, 0.018497334493856345, 0.010266444329837603, 0.019168263134945716, 0.026506997644901276, 0.04050678660028747, 0.04795207655323403, 0.01665705083204167, 0.030701850407889912, 0.019019272111888443, 0.036616952291556766, 0.025027804874948094, 0.06537354458123446, 0.04084013728424907, 0.030820471899850026, 0.04559884586238435, 0.020068480633199215, 0.055271369338567765, 0.023138807487807105, 0.05042230025199907, 0.0076396529163633075, 0.029924619078103985, 0.02650641749746033, 0.02516812930947968, 0.15568401105701923, 0.1024509168096951, 0.2223326518599476, 0.1504621005484036, 0.12485933224005358, 0.18640528113714286, 0.1689637013311897, 0.18528086718704018, 0.13745301003967011, 0.13053029722401074, 0.12430449415530477, 0.11479087679513864, 0.08715491901550974, 0.16810167687279837, 0.1306912593011345, 0.07663698161819152, 0.12477698523019042, 0.0820177575307233, 0.07750378296311412, 0.11824620781200272, 0.10073090517627341, 0.11255473749978201, 0.14300329078521046, 0.1208742010806288, 0.10968126383210931, 0.14664482538189205, 0.11183209091957126, 0.1312204623328788, 0.18821563970829758, 0.16631597626422132, 0.09216765074857644, 0.23314156542931283, 0.1928420000310455, 0.11475114178444658, 0.15821440384856292, 0.10311097531978573, 0.11460174194404057, 0.17802844063511916, 0.16677336314959185, 0.14844145040426934, 0.18306877517274447, 0.12160393835178443, 0.08326938322612218, 0.1032938744340624, 0.13106528137411388, 0.18296650637473377, 0.13517652505210467, 0.18205612951091357, 0.13068798876234464, 0.09053174353071622, 0.14025347333933624, 0.1424067635089159, 0.05535696653117027, 0.11500019127769129, 0.06954895731593881, 0.10273138925965343, 0.19102239981293678, 0.09602192642965487, 0.1574619627956833, 0.1682154671954257, 0.19297288943614277, 0.11340432441128151, 0.13307185870196137, 0.14647641299026354, 0.05954260139593056, 0.07947852342788662, 0.12350832830582346, 0.15203494472163065, 0.07732093813163893, 0.14023997049246514, 0.09387139789760113, 0.14682959046747002, 0.12224913015961647, 0.17567587830126286, 0.09866355825215578, 0.17158625274896622, 0.07958790327289275, 0.16106593369373254, 0.2018508959029402, 0.1028107710714851, 0.24883485904761724, 0.09386987119380917, 0.1869658324867487, 0.12791143703673566, 0.1354486040238823, 0.09487846600157873, 0.11633929370769433, 0.08175762756062405, 0.13784375121550901, 0.09054970435265984, 0.13414884305426053, 0.14087761699088983, 0.14808550450418675, 0.1140643557799714, 0.11111906596592494, 0.112755258168493, 0.16635081225207873, 0.08603216069085257, 0.07516667087163244, 0.11441709899476596, 0.15546829120389052, 0.10522183669464928, 0.11496460890131337, 0.2197854449706418, 0.1303841272102935, 0.13126787835998194, 0.16653329745999404, 0.11416600032576493, 0.10780344530940056, 0.14522599508719786, 0.12529656663537025, 0.11832483644996371, 0.09391726007951157, 0.14987892684127602, 0.127874918282032, 0.12293595687619277, 0.23965892142483167, 0.12985149079135486, 0.0708915474159377, 0.16031894806240285, 0.14217127114534378, 0.11976035870611668, 0.13341175046350273, 0.11152810723121677, 0.20856907112257822, 0.1867398667548384, 0.12066206389239856, 0.10223254388464348, 0.13871108181774616, 0.1277466615928071, 0.14040971281273024, 0.1562460416129657, 0.27928273379802704, 0.039636127783783844, 0.09062036020415169, 0.19394718429871968, 0.0747668712532946, 0.09433906458850418, 0.14725313202611037, 0.13208403385111264, 0.08718451671302319, 0.1499425055725234, 0.14738780765661172, 0.16657481023243495, 0.11310128388660294, 0.11466958187520504, 0.14167432566838606, 0.14942111926419394, 0.13872101557041916, 0.04617624184382813, 0.3096271183873926, 0.07829618972859212, 0.07915931341371366, 0.10184930052076067, 0.07769001368433237, 0.10292999645961182, 0.11146282537707261, 0.0801832363275545, 0.1239574777760676, 0.09432803160910096, 0.06787334222878728, 0.08820026327988931, 0.16633312962949276, 0.2098560892045498, 0.1794627279575382, 0.1342706536608083, 0.13130557776561805, 0.14475258120468684, 0.12326534491564546, 0.16329736395605973, 0.110793925555689, 0.12757625430822372, 0.113945869995015, 0.12624475147042954, 0.12625297531485558, 0.12250111092414175], [0.04770513391122222, 0.04485238270301904, 0.040853026056928296, 0.05110374618587749, 0.03164106501000268, 0.06005439321909632, 0.0188763404065477, 0.03847602967705045, 0.051070657425693104, 0.01606688991055957, 0.02381837896869651, 0.03670888700123344, 0.01501075693938349, 0.0949953572292413, 0.0572628594402756, 0.031035648924963813, 0.042427546211651394, 0.030520461034029722, 0.04406809800171426, 0.00528253082718168, 0.08609884711248533, 0.04879593662917614, 0.015278837643563747, 0.025556743278035095, 0.10288027341344527, 0.03136019900973354, 0.04168115769113813, 0.0037484216736629605, 0.061703491157719066, 0.03598915472892778, 0.03370817105418869, 0.051062928911830695, 0.044773119634815624, 0.03380431268098099, 0.010765933464946491, 0.01922495473575379, 0.06262646163148539, 0.012155266994211291, 0.02358540227370603, 0.05961434968880244, 0.01606461003289691, 0.02527385015439774, 0.029597938393375704, 0.04660627019724675, 0.02118845866061747, 0.06735018494405917, 0.013224162360919374, 0.044509926079107184, 0.013717303800928806, 0.03626203437202743, 0.04169797518157533, 0.04708429133253438, 0.021635509761316434, 0.03926910479952182, 0.0635807668524129, 0.08365389545048986, 0.025006202016291872, 0.014780056729380573, 0.04893052405012505, 0.007061415551496404, 0.03986378985324076, 0.028462067379483154, 0.011557239307356732, 0.04212433605321816, 0.02978038628186498, 0.014564769442326255, 0.03384791534127934, 0.04169658079211201, 0.016961277096665332, 0.04810412268021277, 0.06695751672876732, 0.014932041788207633, 0.03912811540067196, 0.021224451550681676, 0.023133323228518878, 0.022088194399007728, 0.05732936265745333, 0.035561392682471445, 0.040569130397800884, 0.03321283031255007, 0.019014747979651605, 0.03821160797295826, 0.043522067301507504, 0.0818050978705287, 0.06207018505249705, 0.037418702484241555, 0.0360258940075125, 0.07316447688000542, 0.023530098277011087, 0.026593588891306093, 0.04695597018248268, 0.03419877222872206, 0.03593717894649931, 0.058233157731592655, 0.05457040195220283, 0.02251904547613646, 0.019414369482547045, 0.008694596754919206, 0.026742780082193867, 0.03449733781495264, 0.04647333840174334, 0.022300475775929432, 0.035259848327508996, 0.029213249749903168, 0.03841408621519804, 0.04636972949707082, 0.009778987316946899, 0.005276758614594915, 0.04988245439848729, 0.037223487959376404, 0.025104011142892495, 0.046298985436026535, 0.03378204655434404, 0.029781946912407875, 0.10761658355061497, 0.050201840831765106, 0.027157639785270606, 0.03249634822298374, 0.007646924267256898, 0.02467314140605075, 0.03550198354891368, 0.08711845454360757, 0.021681293911699737, 0.0128255238856322, 0.037337899141545804, 0.027403137147692696, 0.011184877948835492, 0.007192207417184753, 0.01711237327461796, 0.022872148314490914, 0.039952175824769905, 0.017273974870996814, 0.020041893934831023, 0.011503009092328804, 0.06584761664271355, 0.018852934341079423, 0.014113322282875223, 0.04863311875877636, 0.05297590911920581, 0.009678316468905126, 0.060453032542552264, 0.04003440748367991, 0.0453575452390526, 0.059735149278172424, 0.058967522611575465, 0.036882524112505574, 0.0146905817091465, 0.031940553403858624, 0.011069444723294249, 0.031098874818001474, 0.042376269320292134, 0.05445144458540848, 0.014949631112228547, 0.06636204796710185, 0.0460120431546654, 0.024319633143022656, 0.04515925695055297, 0.02414890525064298, 0.02673491755766528, 0.02351524175277778, 0.02131043211556971, 0.01777996013074049, 0.013603979971126785, 0.01188105742247509, 0.029764020017215183, 0.03656264574133924, 0.026467554404267242, 0.018233135009982755, 0.08077553633068289, 0.02690944863882448, 0.02943053701892495, 0.07745935249009303, 0.04395428053768618, 0.012018678743126137, 0.02523595736628132, 0.025901488261297345, 0.056428787231977494, 0.023975544642390947, 0.03563010792380997, 0.013899111321994236, 0.03540422022342682, 0.029808223181005036, 0.05021888902410865, 0.07149105346096413, 0.04398998844304255, 0.01436514952885253, 0.02610197669959494, 0.013499430447284664, 0.009946407351110662, 0.03610540474099772, 0.028453538194298744, 0.029375551933688775, 0.037643996466483386, 0.07340525503137282, 0.05064759423424091, 0.005301824970436948, 0.033747977311057706, 0.03231811403696026, 0.05442301396812711, 0.07210110394018036, 0.026631028757297566, 0.0067766377968447545, 0.02085478906519711, 0.052035144064575434, 0.023883981430636983, 0.03494347119703889, 0.006756662149980132, 0.03849957144952246, 0.026046587886022668, 0.03633749425145132, 0.06721101741173438, 0.027801041956990957, 0.01785151843380715, 0.0473866533221943, 0.0218527054281107, 0.044459134340286255, 0.01247124548535794, 0.030764255273555006, 0.006899233383592218, 0.020860945074153796, 0.08485705338950668, 0.0478528916968831, 0.03321299994630473, 0.03151395843763437, 0.008722968848555215, 0.05747121718845197, 0.019565189157479575, 0.11803846753069333, 0.010710035750110234, 0.013408057225335921, 0.07495159562677145, 0.04217148066631385, 0.04519885964691639, 0.04687775884355817, 0.017879528359376957, 0.02908487431704998, 0.03409981128892728, 0.03130865070436682, 0.05091437045484781, 0.024864513726372803, 0.03519127218584929, 0.023908164418701614, 0.004852168295266373, 0.06416771321424417, 0.04708436257871134, 0.017278627924887196, 0.0365853597010885, 0.013045206383269812, 0.018193739266800027, 0.04647661911855851, 0.011456464982724615, 0.034434427440698655, 0.022456511688817824, 0.10600386187434196, 0.048461771703192165, 0.016909555764868855, 0.042014739077006064, 0.053991994953581264, 0.01955663791990706, 0.03922205178865364, 0.05254047962703875, 0.0398521733337215, 0.03603794818211879, 0.0431024714240006, 0.0008692490009707399, 0.0173372380834605, 0.005904252532803054, 0.012908071063325872, 0.05380100770188229, 0.06904700425054346, 0.015956816263496876, 0.04751403130857008, 0.06348826895867075, 0.023328235805300728, 0.032061855109142404, 0.01055204650453691, 0.025223063504589454, 0.03131313242816499, 0.03031188276197229, 0.09794847055205277, 0.03480046994185873, 0.021830093248614242, 0.00834783143363893, 0.07413567762289729, 0.03780053110261049, 0.047795311215200594, 0.03532220569572278, 0.08525375210280929, 0.055541507700192075, 0.006143034943046847, 0.005126957166274744, 0.035989945222224505, 0.010720417335895556, 0.02012233595762934, 0.06546496360429696, 0.05082588270306587, 0.03269141686281987, 0.013285965026755418, 0.04247449744226677, 0.03380847888599549, 0.037488689978740046, 0.0435818632000259, 0.003029709748391594, 0.05451144404443247, 0.04326544535745468, 0.04607342003977724, 0.048178561364433596, 0.026943388960457275, 0.05504103384113737, 0.04205356824344822, 0.02865539218432137, 0.017565763588728647, 0.00808781257364899, 0.10700721839176756, 0.027351403941533396, 0.04711899161338806, 0.03148333615224276, 0.030869747112904276, 0.040734991497759304, 0.02827320054971746, 0.04737476538866758, 0.04105905303731561, 0.05186600564047694, 0.004167863608537508, 0.008305845383022512, 0.04276597573022757, 0.049273509931351454, 0.015083955600857735, 0.05110291837315474, 0.020203772034229975, 0.018303385436800972, 0.035533240264547725, 0.015984263005001203, 0.023429693753964136, 0.044022385097507916, 0.04729692724400333, 0.044684988113918474, 0.021655782691336105, 0.011889142167222286, 0.019091032279123153, 0.021623280863942843, 0.0594590940911855, 0.03823253060025828, 0.022249845189175436, 0.04719507235235401, 0.025467281828501394, 0.021040478654737984, 0.021573720666180764, 0.017582933917375546, 0.029647427344960824, 0.05550257336082203, 0.08437416037278515, 0.15435176183070454, 0.08702624841992344, 0.09673748231892075, 0.14860811217554978, 0.0968492098950914, 0.12034697937113897, 0.12945072086794035, 0.1166013167904956, 0.19316197000443935, 0.09841898030468396, 0.19484582250671728, 0.09916209828640733, 0.1027059577671545, 0.18124522588082723, 0.11174172362578766, 0.11682374056960855, 0.18852818650858744, 0.13337966932782105, 0.13453321957162448, 0.10524168384394475, 0.14143283505524906, 0.15242987924388476, 0.11727782977478844, 0.16676938693438256, 0.09491349876459156, 0.1363332915518965, 0.1396600401827267, 0.1684302913823298, 0.19712435667003902, 0.15634870396128722, 0.06864254309662751, 0.12413906731775828, 0.14737503762756074, 0.10170477256178856, 0.16019202130181448, 0.07225258009774344, 0.13990526273846626, 0.08674051732357059, 0.07869358733296394, 0.1761307953191655, 0.04910012048536113, 0.11610514484345913, 0.09087675144629818, 0.13001374208501407, 0.12815777238990578, 0.17719300117875847, 0.12191202039165155, 0.1464119657341923, 0.11035000080508844, 0.13788382549371037, 0.08409267690564905, 0.2487225750727313, 0.06950037420860358, 0.08612917762781892, 0.17771647737494536, 0.1534484281603779, 0.26523784601262634, 0.17661351870213235, 0.11638441628643445, 0.11032382970941917, 0.12009892053902149, 0.1330399132732834, 0.08120007533580065, 0.1276359518191644, 0.1192648381526981, 0.11090146657079458, 0.16948778820889338, 0.1609183523271765, 0.12654420254485949, 0.05974090325513056, 0.13570161616163595, 0.11075151033167328, 0.13117991308016436, 0.15256588480302266, 0.11685348754482609, 0.07583963511777775, 0.09617750772408076, 0.13028127487216676, 0.18780918366142682, 0.08555812255612441, 0.14737929882747786, 0.16609980857798032, 0.13542070266391548, 0.22472836902098997, 0.16067751310765743, 0.1568325808537858, 0.11518631343330656, 0.1683361107217414, 0.1229840921504157, 0.06356117754642453, 0.10049727199865238, 0.13488917904240744, 0.15009691300136702, 0.11453515051731042, 0.11075512692332268, 0.151567583371486, 0.11262863674866301, 0.08613728612129178, 0.08799871123794999, 0.1407986083733184, 0.11662573048046657, 0.1034612622378128, 0.13001721618430956, 0.16915595744337353, 0.10862551762589387, 0.06034806317516735, 0.07342324978006737, 0.10539278002189738, 0.13724917812006815, 0.24839527692113603, 0.1281767985118287, 0.12611962961299078, 0.17370248133582727, 0.06116084634725537, 0.15622462704777718, 0.16539497354200908, 0.07478882186114788, 0.14445417507418565, 0.09192310672785554, 0.0817520839295217, 0.06745163271469728, 0.11637153769178049, 0.13106961042753287, 0.09836047701537609, 0.11712711357644626, 0.1263085337621825, 0.06666353464658771, 0.12023242908929076, 0.15376333626253263, 0.10669265634247235, 0.13194862540279115, 0.10190885553934745, 0.1755601473684822, 0.05548495180638773, 0.1384049811001335, 0.12156162490802151, 0.09673601668328047, 0.18405619290258202, 0.20707208716443606, 0.10666748947863068, 0.13562460243701935, 0.10296962969005108, 0.2144070914281266, 0.11138545202889613, 0.18379619185413631, 0.1765098249805825, 0.14151127370340483, 0.1274989555988993, 0.10772834505353655, 0.13237380901617662, 0.12810290604829788, 0.09933528756456715, 0.1413318554737738, 0.18194833743785108, 0.14302097340779646, 0.11261208727955818, 0.14576623109834536, 0.11900798550673894, 0.14320678343730314, 0.09567788203379937, 0.12248211194361959, 0.13731263471501215, 0.11360662962709155, 0.12580003961920738, 0.13532011663275106, 0.1770081003861768, 0.08187247639788048, 0.07088764583958046, 0.1844271479972771, 0.0470363901528929, 0.10235003222312246, 0.15198819365884575, 0.13495434554559843, 0.0828469137528113, 0.109061313526971, 0.134163268708757], [0.016477283156876053, 0.029684702666210275, 0.07281205257666962, 0.04173857193174107, 0.029000023512967994, 0.04105067991518548, 0.0576156365818211, 0.034387438890657256, 0.03396727304373469, 0.08143391885927745, 0.05466113904757159, 0.026485566116337265, 0.020171492427055324, 0.021999294437201958, 0.015375866454892924, 0.074805927728968, 0.04884410583014999, 0.02040848265668111, 0.06046865920403174, 0.015690864462937628, 0.04118634281413896, 0.035928378347307444, 0.06697472437684025, 0.051570523995906115, 0.023058697947167923, 0.04934575016211186, 0.012699798980195607, 0.06622584563280855, 0.05625848172764693, 0.03540506499952503, 0.03412143619997161, 0.022185596404597163, 0.04538911408079522, 0.08032042932297502, 0.04256692069715687, 0.026970482863751904, 0.012291210637028729, 0.024244609222348248, 0.03753910852330072, 0.00963548055317785, 0.02876205449657781, 0.017864123918116093, 0.026516858455059782, 0.02795001771301031, 0.008854137301178915, 0.04033526651827352, 0.022014230689299957, 0.02948083681985736, 0.01963944802992046, 0.03458103171682783, 0.035811063035258224, 0.04832319110365851, 0.017297637083434632, 0.03158213085095797, 0.0675029299621071, 0.04828550526872277, 0.031401012891105244, 0.003005259799205565, 0.013970225184623684, 0.06227196779634271, 0.01776729357827987, 0.07479178027382918, 0.11748120029057775, 0.019858937145077755, 0.02934297886011856, 0.04353971939001765, 0.03280839290735977, 0.05226568651518651, 0.05165438074618578, 0.03684753206159387, 0.030064319260418415, 0.028028597157182436, 0.03146765860063689, 0.04984135892508285, 0.04278376013306635, 0.033266587249402485, 0.07119249126740865, 0.01371158629522792, 0.01802162207396967, 0.01855933223851025, 0.033267208108944554, 0.040651317951934676, 0.02707167448742049, 0.015002494079193898, 0.03671184880658984, 0.10276294792337076, 0.024454208689608743, 0.03336178231984377, 0.06387266583208527, 0.0288060371364866, 0.06113559127386127, 0.04079578145008002, 0.02670784909943385, 0.03283516789919563, 0.07190485804208688, 0.03540764682527099, 0.054530212323048284, 0.037943505216389894, 0.03223826064329062, 0.03093602302085076, 0.03327837340267641, 0.07609572101916585, 0.012659399853354054, 0.008521146240777202, 0.01661479676009289, 0.026972615160048008, 0.0320660755969584, 0.10298110371721642, 0.030107121249394755, 0.07056709232607059, 0.016443529432373385, 0.03344443127779024, 0.02224758906023843, 0.017070855413164412, 0.004428674234077334, 0.0070010848825664395, 0.02191534947736987, 0.032656591052987745, 0.03242972965485283, 0.05802038950579507, 0.029612207984817878, 0.04339730506762862, 0.023355243195380484, 0.06936854163983039, 0.028181498238284673, 0.028377123276836107, 0.068176314899964, 0.042001962262604914, 0.021710116382954375, 0.009133606367478413, 0.013840602095504957, 0.0316933155991137, 0.03799224438677941, 0.05387392646766134, 0.03337068809196353, 0.034967878101659675, 0.015432897323210324, 0.06291248449789626, 0.025389482699600712, 0.05852840867425714, 0.019576780231935636, 0.06089752047721829, 0.03110596550894635, 0.025729879969730973, 0.0314290974555271, 0.07588865927287511, 0.029671084468386004, 0.036384940812630315, 0.04783703772617238, 0.04154318438044616, 0.07117397404674973, 0.018387137014152746, 0.05428283881129963, 0.03530867910012603, 0.09687762694167239, 0.04586205977414336, 0.04064560468707766, 0.017710717328424965, 0.07660146709531546, 0.03593220528481262, 0.00813908946500825, 0.021008779195004275, 0.07027306953178984, 0.03164264938927122, 0.0811860975144165, 0.01739221977602158, 0.032084029633551836, 0.05933311727962323, 0.01343811717483082, 0.04008912794025881, 0.03934434415506465, 0.017004550667479634, 0.00599131578513022, 0.03173123213595577, 0.033892674903784475, 0.010790130871880268, 0.02723848044739238, 0.014341773997460092, 0.06602793053856917, 0.029559909898255552, 0.040393657849303315, 0.05319300300574728, 0.09407793038657733, 0.0190665100235492, 0.057665305345186164, 0.08431039165173258, 0.020169538246201615, 0.030178713479212353, 0.018661875843203495, 0.04160468679453645, 0.053028085069464784, 0.04438180509688599, 0.026358943000169735, 0.041618291421660354, 0.04391553958079644, 0.010120583049553846, 0.04834927059710026, 0.02704498091978686, 0.01982159397032644, 0.017798626629103507, 0.019554953456723263, 0.02685601739878101, 0.008126928421136524, 0.04695200414529868, 0.038916822988539934, 0.03704412401254688, 0.04077353907216873, 0.02989150656919394, 0.06405033344136817, 0.036109207929777246, 0.04774141178599425, 0.039050993110452376, 0.047414106849048815, 0.0294448201810675, 0.04215573186853102, 0.019443225880552615, 0.05319456024361508, 0.052005566723112545, 0.01488169957883656, 0.023479618664298738, 0.04452918968828661, 0.02235505374015442, 0.040550409616636376, 0.06075000696416412, 0.023063837849934186, 0.029437583605093614, 0.0237176266964525, 0.04332907497882843, 0.06432609007294689, 0.03734275405960424, 0.024215537389474254, 0.009795614817578877, 0.020474115652697425, 0.023275233738656555, 0.004770071495191327, 0.04659471135320408, 0.04451499134302139, 0.01213245719139065, 0.03322362580469676, 0.046752572525292635, 0.03774998702907136, 0.03486546002594488, 0.05452564238969769, 0.03677496952669961, 0.028883006756326983, 0.03575422554942114, 0.009861775374572192, 0.0013438088125050335, 0.04050666446398411, 0.01644755314503397, 0.048865727348519225, 0.15727547423115798, 0.008139013977987426, 0.017554389645478556, 0.04842223007498043, 0.01390868884378246, 0.01561480068734714, 0.002564681286457926, 0.05605481265644942, 0.027070013772962347, 0.024976711188043867, 0.0677985337429813, 0.0627320348950369, 0.03894238679536751, 0.0113786573721362, 0.03298244731766837, 0.0833491450175643, 0.010925975278951228, 0.06452044964368854, 0.08362077615622963, 0.023915404387350594, 0.0317116428299674, 0.0665871791009392, 0.031068374668913226, 0.04615513261939798, 0.012352308474614151, 0.024919502204284072, 0.02195814298465848, 0.030689321258770566, 0.018340423270793896, 0.00728676381653973, 0.026065261169735874, 0.0792128091145839, 0.09481499583593436, 0.032707511713462215, 0.03110535822010466, 0.014563375052862933, 0.028656043577939272, 0.02376479675461139, 0.010111522062548568, 0.017015442850866487, 0.021404682325997522, 0.03845814010128379, 0.04921784291842154, 0.034096289692180495, 0.036731852018939595, 0.039467410051396916, 0.02086411213635334, 0.016728629491158893, 0.060216474879000864, 0.042692673592162986, 0.04577465767839125, 0.004505570911403213, 0.07826659203107868, 0.012940203089133968, 0.05179348721035889, 0.022474613306777816, 0.04390675933765514, 0.05076453974470496, 0.06606205406465701, 0.040856632470552406, 0.0314337182790041, 0.06729180379105465, 0.010502388767365898, 0.06094531648393188, 0.06110196986368724, 0.08912710818861212, 0.020501377493409172, 0.04052527667954564, 0.03383867369432535, 0.032637788847620995, 0.032097478197621446, 0.05283881451136299, 0.06784058934343712, 0.04224615344511611, 0.050837563683411906, 0.028922036090599637, 0.02158597161594246, 0.04856850865430065, 0.05006755535889949, 0.024209493338795643, 0.04859874078205653, 0.013989657579389001, 0.030768384159143482, 0.015640171111694405, 0.013509596598201563, 0.016051911250022904, 0.048824251895504336, 0.08230262010225228, 0.01624291716143489, 0.025941423439819897, 0.07091910272304501, 0.011417296548773135, 0.040198104056928835, 0.021631648897060325, 0.03809181261541588, 0.02138292510062456, 0.08135293570480176, 0.008337359941963638, 0.036701976122068505, 0.03498967264645866, 0.06459570596260683, 0.08668675699404307, 0.09082278755626508, 0.16302604494350298, 0.05423111069415297, 0.1861174872943333, 0.14846689546746866, 0.21958947048655578, 0.09434272189225469, 0.14139334431716374, 0.1640665376824992, 0.1488133690186909, 0.03960951564035245, 0.06874211132526398, 0.15803577271955355, 0.1102994228047984, 0.15064109808632306, 0.12561562737183912, 0.13640255640660012, 0.1857991050928831, 0.11523268451648098, 0.1028961172061307, 0.10252722485789231, 0.09463210350700788, 0.07673121656158141, 0.12939041267548287, 0.10778967783387218, 0.06810871245605604, 0.13711286043482168, 0.15886776521801949, 0.2626519219151565, 0.2531222232750484, 0.10291783711207764, 0.1909704376012087, 0.19617319985159806, 0.14224012887903623, 0.116093460470438, 0.17925215139985085, 0.06802342738956213, 0.11196521949023008, 0.08416164320494447, 0.13805021585098334, 0.17828327124672277, 0.09334830168102469, 0.11836572497018746, 0.09264390769281558, 0.14221543020435742, 0.2220150160470179, 0.15580438316932746, 0.17638082190283708, 0.14337238669395447, 0.17478398473135062, 0.11572923644312791, 0.16975323110818863, 0.1548608937965972, 0.19335570532296384, 0.12860603976462567, 0.0929562102204987, 0.12982668355107307, 0.055131323103393824, 0.13800260983407497, 0.13984651517655167, 0.1694648265838623, 0.23367473110556602, 0.19971041647451265, 0.10062515549361706, 0.09522496669420175, 0.12570922449231148, 0.12145448422857694, 0.07853404339402914, 0.11768850630947522, 0.09203790806766067, 0.11933654573346887, 0.1306670220302684, 0.10694632665919405, 0.1526518009070839, 0.223751997841256, 0.17221792813922676, 0.08774938354534761, 0.11222006367253405, 0.07656074820884637, 0.07056025269308261, 0.081722113037748, 0.10606163913117987, 0.1075865923027907, 0.11798844592911856, 0.1731887353318078, 0.10915824903973512, 0.12137509563139506, 0.09581014207963433, 0.1418070878301348, 0.17913693615368434, 0.16246637568942138, 0.1079903342095869, 0.1285912748426199, 0.13160487956234387, 0.09379047581127711, 0.13441429952425615, 0.11952475777694158, 0.16853479934590204, 0.06606325507164001, 0.13206268713942595, 0.11292359592126948, 0.20378128731889383, 0.1866660150034087, 0.12436473449426037, 0.14944169244595937, 0.14652082989258425, 0.1960666834243706, 0.09073795032288347, 0.20215338681425365, 0.05899740529379674, 0.1357475665530988, 0.09231795304055725, 0.04959911513807518, 0.09434896441442625, 0.0645921640098095, 0.1420179900846311, 0.12946874275803566, 0.14320252223738603, 0.13835561089217663, 0.07793655938335828, 0.1199573917048318, 0.1324761320969888, 0.140716980610575, 0.12552481224494322, 0.15519813927156584, 0.07710555754601955, 0.23378204820411547, 0.09335947036743164, 0.14570889488926955, 0.15482156590691634, 0.08586995689464466, 0.20954408523227486, 0.2335449137857982, 0.14122943739805902, 0.09803372169179575, 0.14341157887663158, 0.14661836251616478, 0.15441422776452132, 0.1725373145725046, 0.19219790744994367, 0.11848385791693415, 0.08496154778237854, 0.12308679521083832, 0.09425708398755107, 0.0892134178429842, 0.15253917766468866, 0.15630048726286205, 0.07785493162061487, 0.16158588150782244, 0.21921867824026517, 0.0713732937084777, 0.15611013104873045, 0.15351815441889421, 0.12527061945625714, 0.08329626678356103, 0.1356821014944996, 0.1068751686917884, 0.1139124860720975, 0.11117281951010227, 0.22822693628924234, 0.08779153414070606, 0.2709977940789291, 0.11377410564039435, 0.16500932137881005, 0.19181674718856812, 0.15160579846373626, 0.14539644308388233, 0.10118797315018517, 0.15949021253202642, 0.15812272019684315, 0.1348901018500328, 0.06915019585617951, 0.11261210085025855, 0.09078330360352993, 0.11911914311349392], [0.032028484756925275, 0.019352127465286424, 0.018098271086013744, 0.027518204812492644, 0.011937271504263793, 0.018865017353424003, 0.02991224599203893, 0.05816918545003448, 0.06563438701310328, 0.0553458555202399, 0.04429534277213471, 0.019477729386250888, 0.02588166655706508, 0.042436224674539905, 0.024564182252756188, 0.06109295891863959, 0.029218701778778007, 0.10696510172316007, 0.016619312410641993, 0.013035414274781942, 0.07831883244216442, 0.0464730093122593, 0.03128969922129597, 0.022350577105368887, 0.05305405260462846, 0.020904948070113148, 0.01307911447448922, 0.028536190544920306, 0.06524296730224576, 0.024120498382087265, 0.034920920085694106, 0.025001433611448323, 0.03092227250869785, 0.07497891344662223, 0.027251228424055234, 0.022342153093112365, 0.034155200102499554, 0.054384649598172734, 0.028575501471225704, 0.044570258020290306, 0.06202905225966658, 0.014244709563042437, 0.028969380871525834, 0.020203337771818042, 0.01763165442805205, 0.06923079224569456, 0.010960812963146185, 0.013534842341739153, 0.052005271560379436, 0.06457300896623305, 0.03709643566980958, 0.08665078785270452, 0.018948831695265005, 0.05658650591171213, 0.014598814936886941, 0.04266241771568145, 0.02431670017540455, 0.0346852716590677, 0.04309613729960152, 0.030859806574881077, 0.022063047891216617, 0.06748824646430356, 0.02734205881798906, 0.017377397178539207, 0.032277832805578194, 0.019037253289882625, 0.0499288390523621, 0.028574843292257616, 0.013605858664959669, 0.060213502895619185, 0.07642675789871387, 0.06684658982391868, 0.04190700128674507, 0.023077617199825387, 0.024008735182828138, 0.012435914166936917, 0.0629814915092928, 0.03058413815285478, 0.012856627930887043, 0.010048202022777071, 0.016059746633150747, 0.01541660909008767, 0.05911226770175355, 0.1087461882936103, 0.11679341005427496, 0.034423353749194315, 0.027017668188948716, 0.026437315491161177, 0.05799569761646645, 0.014778372266196778, 0.056305731513670514, 0.029570125242961303, 0.03242898665900741, 0.08113962465098926, 0.03937079684276666, 0.022980103235957876, 0.05511665317629065, 0.10599071186568056, 0.04959776146071298, 0.011549032426306179, 0.016118994614641582, 0.04684866665463362, 0.036090836594147344, 0.052954304564212046, 0.028167301589357, 0.04513684154621192, 0.01551816881900387, 0.036629915703088045, 0.02401040098629892, 0.028840679741863693, 0.060743303038179874, 0.08498896059713193, 0.0628974549472332, 0.053816539368459156, 0.047347362751939466, 0.052167315900857957, 0.04062488901295832, 0.017205541221691028, 0.024590570479631424, 0.11117668715970856, 0.059611906962735314, 0.018543235691530362, 0.027297027841476456, 0.04520868822666151, 0.07614790036209992, 0.06157507162008967, 0.06680964359215327, 0.03886113901223455, 0.017541658632191162, 0.006286236366057503, 0.06019149121961423, 0.027155185184840645, 0.00940097460988909, 0.07067068426736764, 0.050306844125900946, 0.008609531364137573, 0.0036001261489998016, 0.02927142394972699, 0.06813493783452682, 0.04061236325651407, 0.039754678029567, 0.015479667045708214, 0.04341015652088182, 0.05121642371107425, 0.04051930557138153, 0.06461959039526326, 0.0502429600538952, 0.04168696255822267, 0.03477820720789688, 0.011789622284205896, 0.02442675007374159, 0.021450771817139218, 0.06759850840483393, 0.039525458722242286, 0.007698945850799126, 0.04824671681438174, 0.052411747963300774, 0.07813091895409993, 0.03426368088860597, 0.02219742157363466, 0.021307120864678706, 0.07310690996902329, 0.03651107368724687, 0.016133511871365563, 0.010520308029039629, 0.02062913037038275, 0.05316433150853429, 0.02664116776681372, 0.003092988227893199, 0.010879672897447432, 0.07868986217571156, 0.04994621294151459, 0.04396576813555189, 0.03326136592243399, 0.03200016270524689, 0.023290711122431924, 0.0674702992130603, 0.030087569262832403, 0.027577829380918826, 0.013374147437778967, 0.037019778176077774, 0.016229122544505765, 0.0692471924370953, 0.029677153964127814, 0.08194565639964171, 0.05091085225077612, 0.03161094144784978, 0.039595890657177994, 0.014966112727831517, 0.055292023944535425, 0.021017642558685372, 0.02235864658307816, 0.049132398396198235, 0.04691144471455898, 0.014773904113098979, 0.008019428966300828, 0.045451725899641, 0.039865767782820125, 0.03187604847231081, 0.019331971582557474, 0.011452726254771863, 0.030091955991727964, 0.058079008146056106, 0.017365834941821437, 0.07467944880149194, 0.009243938706016966, 0.02228935289063624, 0.025278978182801178, 0.03861197756071176, 0.03411866777709552, 0.045606414920517375, 0.015269277085150992, 0.02267898296538208, 0.034929527302405665, 0.04676232307351061, 0.030675682704895735, 0.008381233168100672, 0.017629306696887528, 0.022996710380539298, 0.06353621424308845, 0.0068568711701248375, 0.03059955107580338, 0.030613868164696863, 0.02551709478055792, 0.05743015903447356, 0.06797597065035786, 0.04468475401933704, 0.059102795352893214, 0.04274940251239708, 0.05843511689454317, 0.06793738236384732, 0.028272917261347175, 0.040542474149593284, 0.02100564775589321, 0.013272641991664256, 0.06807626491146428, 0.041642518514501195, 0.03716077436027782, 0.07582243425505501, 0.02615909747380231, 0.007621730262014482, 0.015410093457571097, 0.025290660859484757, 0.05195880548230239, 0.05364262745050447, 0.04551827661427004, 0.0004673435916109676, 0.04463122099904077, 0.04304663138464093, 0.0277503655691232, 0.058933514436440806, 0.02911758649029902, 0.06239253668380635, 0.03207430283405951, 0.030138147263122455, 0.07712886522391013, 0.03480754706210323, 0.03869917270328317, 0.022984586656093597, 0.07977401864315782, 0.004054296778381935, 0.019760505462597524, 0.010624583594367971, 0.019450511650315354, 0.04735113201396806, 0.03370274277403951, 0.07893947485302176, 0.03179332487551229, 0.007821250091572958, 0.07210222352296114, 0.028426737757399678, 0.017042887896033268, 0.056537366405661614, 0.0519029281235167, 0.050455772384468994, 0.016938454571313093, 0.05007281061261892, 0.02025979697438223, 0.06161622476897069, 0.041079215705394745, 0.007208412529767624, 0.06398914315338645, 0.01835656222621245, 0.007070300543481218, 0.013931587704324296, 0.07079120565737997, 0.020645530561783483, 0.011277011130005121, 0.02137877925166062, 0.025930159758510332, 0.018517605727538466, 0.03128251014277339, 0.014806516202432769, 0.026719533472454975, 0.06124543930803027, 0.09230380558541842, 0.022967658903715864, 0.02564560592041484, 0.010147458125304962, 0.02398152762491788, 0.10796494342918907, 0.02516720480551677, 0.008588105772754975, 0.03149495945711221, 0.028605553787201643, 0.048063057740884166, 0.0466391791456512, 0.030957993984754597, 0.03611505011628781, 0.11101499905011483, 0.05688388066898499, 0.021270758173029338, 0.02630604101744081, 0.02625776325086398, 0.10979385314775364, 0.05111887073144317, 0.038727074063249996, 0.027653158642351627, 0.03262107992278678, 0.020045929521854435, 0.05691244699327009, 0.033450358281178136, 0.02870157327769058, 0.03671017961044397, 0.07730301802179643, 0.06624149943568877, 0.05548390007710882, 0.014333282131701708, 0.05539382794605834, 0.006183511677331158, 0.02397055401732879, 0.04121422042538013, 0.033200755781893215, 0.03240027105701821, 0.02943887621430414, 0.01759557332843542, 0.009994548562514995, 0.035136823143277846, 0.01981546849544559, 0.056141084991395473, 0.07003870353634868, 0.025480157030480247, 0.009307130672303694, 0.03789770410263112, 0.039275632306401215, 0.044317069463431835, 0.013896923894727868, 0.025431154927771007, 0.06282980500587396, 0.0350133467332593, 0.05852455459535122, 0.04275952625487532, 0.08417138696781226, 0.10327573719301394, 0.11921727284789085, 0.18434891290962696, 0.10147278143891267, 0.08364130862589393, 0.16026291464056286, 0.13287862549935067, 0.18620404122131212, 0.1360291043030364, 0.18286392545061453, 0.11427068470844201, 0.09932910611054727, 0.1652277825134141, 0.07686732390097209, 0.10327068889247519, 0.19750914030841418, 0.19039271931563104, 0.1016263814110841, 0.08344913393791233, 0.18406179760183605, 0.1812098334942545, 0.0800770523824862, 0.17065627979380743, 0.09828104092074291, 0.08730404744190828, 0.14394767582416534, 0.09414127841591835, 0.10073691021118845, 0.15747718912150177, 0.2879552255783762, 0.07766687564019646, 0.09242135499204908, 0.2828520451273237, 0.17626391031912395, 0.11452509462833405, 0.07132226108972516, 0.14846502271081718, 0.12046246603131294, 0.08660936328981604, 0.10492276559982981, 0.12586557253130845, 0.1036461019622428, 0.10406460879104477, 0.07163428541805063, 0.16395198740065098, 0.09212000401956694, 0.09439542370715312, 0.15166363678872585, 0.1074634517676064, 0.12596260303897516, 0.13714876850800856, 0.11355875219617571, 0.2187945395708084, 0.16802578951631272, 0.10392198073012487, 0.12482596188783646, 0.13378680390971048, 0.06522697423185621, 0.15715267296348298, 0.12433114701083728, 0.3029291635113103, 0.16343889279024942, 0.12270532282335417, 0.1525571181305817, 0.09558555377381188, 0.13909342273005418, 0.07917554397135973, 0.114842703299863, 0.19369296436863287, 0.146737024720226, 0.1277708988636732, 0.10129912397158997, 0.16042049761329377, 0.122742357264672, 0.0893779354436057, 0.2557525507041386, 0.10837340115436486, 0.09261090374950852, 0.14770825260451861, 0.13695883298558847, 0.11791063153317996, 0.13850396578865393, 0.28446443432143753, 0.1743777593863862, 0.07799049613199063, 0.13727718804563793, 0.05591064432103719, 0.13457836929176534, 0.11161708352821213, 0.19181819925350801, 0.13466953725687095, 0.13368951555873665, 0.18035696925861494, 0.10739152027027947, 0.1744417588093451, 0.09869128997836794, 0.14157511027795927, 0.18179805550192082, 0.10597596729972533, 0.07639961649796792, 0.1807415357657841, 0.086901465829994, 0.1318837981671095, 0.07263594559792962, 0.09994567052594253, 0.10659408556031329, 0.12161662695663315, 0.06461902721119778, 0.11307624594441482, 0.16219608805009297, 0.24265934899449348, 0.09734507650136948, 0.17221669320549282, 0.09481009681309972, 0.1746624591095107, 0.12478865603251116, 0.10761645462896142, 0.13794208451041154, 0.1346230711787939, 0.18468904894377502, 0.1926518745188202, 0.047537841102374453, 0.08904296306094953, 0.19551180462752069, 0.16241674763815744, 0.14449855126440525, 0.14619449526071548, 0.19551873925541127, 0.06507784580545765, 0.16484891570040158, 0.15778098282005104, 0.09584108327648469, 0.14797968018267835, 0.13884378969669342, 0.07229773660323449, 0.10006364740963493, 0.09209336473473481, 0.2187823395111731, 0.14683039113879204, 0.1622763451720987, 0.09296781995466777, 0.13898067735135555, 0.08498731854238681, 0.12289212351398808, 0.11411120183765888, 0.18724739737808704, 0.08522469723331076, 0.16025380870061262, 0.09963701173130955, 0.10347855809543814, 0.2091176395437547, 0.10604726097413472, 0.15377624199858733, 0.09282785853637116, 0.13298782892525196, 0.14303295633622579, 0.23870783245989255, 0.08804190677723714, 0.12451683490404061, 0.09909123208905969, 0.1433656420558691, 0.17414373265845434, 0.17834933341613837, 0.09006341187549488, 0.05751210570867572, 0.11796788631805352, 0.16838865647358553, 0.08101880470556871, 0.13146835831659182, 0.14954622755093233, 0.07965244552386658, 0.12654693025563443, 0.07634204958698579, 0.13819696940481663, 0.0893797403467553], [0.026367920018466454, 0.06014476051287992, 0.10822702758014202, 0.022902356693521142, 0.05258617217519453, 0.056147724456552944, 0.052735103826437674, 0.01226312352810055, 0.013364506303332746, 0.030398942197539976, 0.04354009936962809, 0.06298542701240097, 0.01801092836207577, 0.019809205617223467, 0.0013007736831371272, 0.025873614042731266, 0.034725485036947897, 0.06302594233836446, 0.03683804274935808, 0.05459341786003538, 0.057307357766798565, 0.02304848429879972, 0.02509099684123482, 0.08032587117382459, 0.033574330021760294, 0.017617624020203948, 0.02370320613096867, 0.06290922074445657, 0.04044673625113709, 0.06458654573985509, 0.040393396613321135, 0.056021784964416704, 0.029558345875037566, 0.03478572198322841, 0.02849926466920546, 0.018979896724756275, 0.037279477276440175, 0.03078931357179369, 0.023763692438868538, 0.016258155361616185, 0.014850753292973553, 0.05411843316895621, 0.041058601811528206, 0.026906032215005586, 0.020669135098744715, 0.02651687541843525, 0.006833437963255814, 0.06590143125504255, 0.055753634710397036, 0.0147795410427664, 0.02891700475343636, 0.07030313541846615, 0.025911683249952536, 0.04728782130405307, 0.08984469968293395, 0.03578589617141655, 0.017889735222394978, 0.03930641065484711, 0.10427036775009972, 0.029096528155995265, 0.01402157501849745, 0.02707916042501373, 0.038986824053738794, 0.039000150481505055, 0.03533081291243434, 0.037603759339877536, 0.024967589981055686, 0.045781368389725685, 0.012197867119019585, 0.04109589748882821, 0.04319814486163003, 0.029818343530808176, 0.018606115531708513, 0.03125356383887785, 0.04251433762588671, 0.023872895864769816, 0.018505478610417674, 0.04008887688230191, 0.022227679146453738, 0.0425623880832323, 0.02345171900066946, 0.0800528015409197, 0.022606306775872196, 0.014217111847496458, 0.034727965082441054, 0.05727980245969125, 0.012175249002341713, 0.018180597739826356, 0.03626104031822511, 0.024764272051730325, 0.016906817876068608, 0.057466535296823294, 0.02570593955793551, 0.0272172575683466, 0.057316355141145844, 0.040577384776302745, 0.04229894007689186, 0.0036165920734804657, 0.05327705992385745, 0.020671280965741192, 0.013002892091338123, 0.011043902120686002, 0.06195325989808355, 0.022440084356016347, 0.017436027693163072, 0.022047039553789154, 0.019262428528496196, 0.04224886079984052, 0.04294862378654735, 0.03519278531894088, 0.023628886190376112, 0.02904051509020584, 0.03952681239960449, 0.13163987839860575, 0.03726792521774769, 0.002006005874136463, 0.06625791998314005, 0.048153377537216456, 0.05003872440595712, 0.05313498486897775, 0.0059366665747282756, 0.04112352743478758, 0.014039018457489354, 0.026276202439995747, 0.04835397284477949, 0.014289292706442731, 0.030957101711205075, 0.0343366573298616, 0.018695753400347064, 0.014627347334421106, 0.06007362290152481, 0.02483987951252077, 0.01777469469899578, 0.0527580858075193, 0.023797279922291636, 0.014328199904412031, 0.03809475067204662, 0.03884233341419271, 0.028107950131275823, 0.11236963314669472, 0.02653463776888592, 0.057920332731945176, 0.044589341817689795, 0.12090074537055832, 0.03352859676150339, 0.0968434898448842, 0.003721277304326317, 0.03240872899602566, 0.01349357808274882, 0.028548210792775666, 0.007689128297248057, 0.02574541333264538, 0.028865900888506855, 0.02975513120847089, 0.0380162475630641, 0.030785490026963607, 0.05516993174595492, 0.04874587431550026, 0.007671980020989264, 0.0386313870549202, 0.07806183730385133, 0.07372868553336177, 0.007961746704365526, 0.04005057018782411, 0.007839433133735188, 0.02162789999108229, 0.04625615969832454, 0.0509273813638304, 0.07828295151037828, 0.014667233319154807, 0.07525260054639407, 0.013858765629785401, 0.01126761341999684, 0.04370012167575104, 0.046551763479198725, 0.027263382682576776, 0.01853308650398893, 0.06816575689507381, 0.05231557919510773, 0.04126683742340122, 0.04048709551404629, 0.013087283187944974, 0.07716114992009741, 0.03322126789550696, 0.038627078357551775, 0.021897977284554924, 0.01490847796334752, 0.05119793363181608, 0.03499133166457925, 0.024918055228356804, 0.014825525360980203, 0.0336217189074627, 0.011307155048208577, 0.0860737141753946, 0.028039731916838458, 0.0294408541438835, 0.0290518296616418, 0.11510879759277616, 0.03870979177632502, 0.0588408944063953, 0.07170547731220722, 0.03354511908920748, 0.055014550619359524, 0.07449827316616263, 0.01925605538833354, 0.036592148443950076, 0.04254156045083489, 0.017118712488029684, 0.0180699032332216, 0.05814827300075974, 0.051572525674211125, 0.05387613849182214, 0.08331849559077195, 0.012281870602497032, 0.024148832308128476, 0.02832841972953507, 0.01278026305538203, 0.03734105093670743, 0.01486397285147437, 0.01943954822075154, 0.004177899141463318, 0.07323341603790011, 0.016242739045992494, 0.0707229586052043, 0.09673318040690251, 0.04443439156083124, 0.019667271358360137, 0.049863777722099, 0.009984709804744592, 0.034230999249432764, 0.042408408131450415, 0.026173222876553024, 0.0199548039651875, 0.03185297488900168, 0.019029355142265558, 0.05734449398836919, 0.06298494525253773, 0.01947151230914252, 0.007615028032367783, 0.006122081781670983, 0.05737674475780555, 0.03169367182999849, 0.057590422220528126, 0.06594657418983323, 0.06527578804109778, 0.013641241721675863, 0.038433719625962634, 0.043176672620964904, 0.05030172457918525, 0.026105047070554326, 0.023918349229331528, 0.05012433516925999, 0.0242188791744411, 0.062356927166027684, 0.057704558596014977, 0.05085142954651799, 0.013679673945132111, 0.024951445936624492, 0.14319531619548798, 0.039803990562047274, 0.0373521110575114, 0.012719413731247187, 0.018468637551580156, 0.013792708549382431, 0.03371289705059358, 0.03790000094366925, 0.029416287783533335, 0.04590939437704427, 0.03200098712529455, 0.05128426703491381, 0.06253962271979877, 0.021675967411803346, 0.05605648863794548, 0.01996924149404679, 0.00578203862200358, 0.047634033619293144, 0.02737760217860341, 0.0346787950423147, 0.03785606240853667, 0.015130509888487203, 0.002807905344525352, 0.03499079901458962, 0.02418708471980478, 0.02010258549957403, 0.014861136575096419, 0.04369516158476472, 0.03647901290761573, 0.0283250660702054, 0.06425616025392498, 0.03540308367727058, 0.006182623220541115, 0.03370289205174361, 0.03513886553368398, 0.07648018574608223, 0.013815855075206076, 0.05600348487496376, 0.041727698408067226, 0.06775484287313052, 0.030526720519576753, 0.018002582381346395, 0.02618329063989222, 0.07540865681533303, 0.01950634490432484, 0.033831966375666, 0.03259983838402799, 0.03980199566909245, 0.12507475353777409, 0.04017525099750076, 0.04130373955039041, 0.06708433492375271, 0.02898821361096842, 0.017392414854839444, 0.009133112733252347, 0.018736836999388676, 0.022828986701954688, 0.043642585298844745, 0.02973358432895371, 0.02810402650253049, 0.03539864605824862, 0.04626826137038214, 0.012589170630755169, 0.07671328966638871, 0.06656538455614022, 0.07006663203771625, 0.07260311128837721, 0.10216268870447363, 0.02438250619785062, 0.005591480543703905, 0.04539474252877491, 0.07276579684444837, 0.05639598684917603, 0.08419006703687565, 0.04082910769752093, 0.032035480452967544, 0.010081566437812788, 0.02643668445359383, 0.12680839693972043, 0.039161255050982745, 0.01940205067928348, 0.021895151186202253, 0.01791994529776275, 0.0505312288712178, 0.014707543388275164, 0.019826437014022043, 0.008244242885016968, 0.04436373570933938, 0.025355615320482423, 0.03256323141977191, 0.03851231433717268, 0.09223197586834431, 0.020528149092569947, 0.03600261007834758, 0.14948119675474508, 0.16243198753467628, 0.26286270203334944, 0.08582640173179762, 0.09573315549641848, 0.10687002539634705, 0.1777600800352437, 0.07574590229030166, 0.15370875490563257, 0.09908987501902239, 0.08843101268368107, 0.10424997098743916, 0.13978456492934907, 0.10584576321499688, 0.12195320746728353, 0.14164330304733344, 0.15348616827811512, 0.16425502113997936, 0.11566449063164846, 0.07827615258949143, 0.15315596599664005, 0.12783609250826494, 0.13091548798339708, 0.1892684410725321, 0.1197590423481805, 0.0774325028594051, 0.13059360454125063, 0.14726523709084305, 0.11052398396922009, 0.15750445265855106, 0.09596626620207514, 0.15452119202486106, 0.11410392794225897, 0.17138855478593282, 0.1593662170427186, 0.14631774436150277, 0.13953877240419388, 0.1230350908424173, 0.09950731654784509, 0.08024545798876456, 0.18600000574120454, 0.11796552501618862, 0.0866671201906034, 0.08022882709545748, 0.061068945564329624, 0.1987316704222134, 0.1433430875518492, 0.14679680365536893, 0.2000716006649392, 0.12449288261788231, 0.1099865028102483, 0.17726018971630506, 0.07081315626523324, 0.1505388700004135, 0.31222514754959513, 0.07607522926160268, 0.0969511733523437, 0.1662755220064095, 0.19454034604132175, 0.1243025264037507, 0.1164219935557672, 0.10294079873710871, 0.14959289718951496, 0.13850563498479979, 0.19589147211185523, 0.13853762112557888, 0.10667223922376122, 0.14729289417820318, 0.16134524584880897, 0.12072872317263059, 0.16086816787719727, 0.1328035659555878, 0.10434082682643618, 0.10463958579514708, 0.1213159409484693, 0.09847345988133124, 0.08754063224686043, 0.1734359934926033, 0.13069016007440432, 0.16569443818713936, 0.08946540539285966, 0.2048754928899663, 0.37303019048912184, 0.08427556244922535, 0.1628107593527862, 0.13467873819172382, 0.0838851605408958, 0.10939866078219243, 0.1539041187082018, 0.13899067895753042, 0.10697476406182561, 0.13519268775624887, 0.08399112056940794, 0.1481734426426036, 0.1280557614352022, 0.11787234858742782, 0.15083898603916168, 0.08517641946673393, 0.08838000042097909, 0.13633097096213273, 0.05132171538259302, 0.08594184767987047, 0.08558421901294164, 0.09646929135279995, 0.14118021646780626, 0.08572226017713547, 0.11020315225635256, 0.20323368241744383, 0.08011467036392007, 0.11489484193069593, 0.15270222962966987, 0.1830927681710039, 0.11560114260230746, 0.18058661265032633, 0.15139229063476833, 0.1973882932215929, 0.10480212885886431, 0.21519716403314046, 0.10558323123093162, 0.20533597389502184, 0.1470116414129734, 0.12870296170668943, 0.0752513859687107, 0.09922459136162486, 0.10051560601485626, 0.20937014956559452, 0.0957119580624359, 0.10651457482682807, 0.10380341352096625, 0.1228871973497527, 0.14115744483258041, 0.11900763266852923, 0.15325732555772575, 0.10833988152444363, 0.05413962042491351, 0.117350948708398, 0.06993441270398242, 0.10841353650071792, 0.11082835442253522, 0.20248509544347013, 0.1281523983925581, 0.15749612024852208, 0.09295179974287748, 0.22125606105795928, 0.17807607379342827, 0.15391907362001284, 0.1529422410364662, 0.14166072782661232, 0.11081185923623187, 0.2232203927955457, 0.13836474397352763, 0.11238944636923925, 0.19060085314725125, 0.12617156468331814, 0.14049389186714376, 0.11436253120856625, 0.1786972861737013, 0.09266381591026272, 0.056918794688369544, 0.13205729957137788, 0.31810332355754717, 0.14613443134086473, 0.0683485067316464, 0.09079891669430903, 0.07043353627835001, 0.12272210977971554, 0.1456558063094105, 0.0995560557182346, 0.1086395565154297, 0.10752000766141073, 0.12333028071693011, 0.12739386409521103, 0.13152371320341313, 0.11991004353123051, 0.09345640588019576, 0.19373625490282262], [0.05207310470619372, 0.044493668380060365, 0.043047890067100525, 0.02529755816794932, 0.01695698536267238, 0.09247472177126578, 0.03407849511131644, 0.034925113432109356, 0.022399686077343564, 0.11848665348121099, 0.03655790278155889, 0.015967153744505982, 0.04919210608516421, 0.036508033850363324, 0.020755047810130885, 0.019017341679760387, 0.07001015078276396, 0.01545773509756795, 0.08040480515254395, 0.008394445941251303, 0.07658516189881734, 0.06902624107897282, 0.044903737625905445, 0.01018165544207607, 0.02316041204280087, 0.024380224623850415, 0.06638137264443295, 0.05948346706905535, 0.05147573943915112, 0.029889050272426436, 0.037859339732676744, 0.056050486995705535, 0.03468926144497735, 0.007193579754259969, 0.038439782336354256, 0.07858179868864161, 0.03285293194598385, 0.038745126487421136, 0.030015932928238596, 0.03022283861147506, 0.04035393640931163, 0.02469734814284103, 0.022000792303255627, 0.027067630418709347, 0.0290722637437284, 0.04341580193223698, 0.006468291976489127, 0.048494544944592884, 0.04094388528860041, 0.007556814816780388, 0.009533702844886907, 0.01017271913588047, 0.03280006389000586, 0.020771224084975462, 0.020503090794331262, 0.014608311034472925, 0.039093645821724615, 0.02960828605241009, 0.016028059047779868, 0.04186714753242476, 0.0264482721353748, 0.01492298164937113, 0.020905741956084967, 0.010554931974703712, 0.021839855671195046, 0.005165601856008704, 0.05456782351913197, 0.03212618022891028, 0.02946556978193777, 0.031808951536991766, 0.016767937024789195, 0.059761903913957734, 0.009869824496230908, 0.05911317015332835, 0.034388310808156214, 0.011643577799467104, 0.04515313995735986, 0.02120829393555011, 0.05495262072820749, 0.0278207500066076, 0.034279209162507734, 0.028105275006964803, 0.08681299843426261, 0.043387245785977156, 0.0690610431400793, 0.05890548415482044, 0.03080333549795406, 0.030554235114582946, 0.004483905288257769, 0.01030185367978577, 0.06690563594124146, 0.04936746328270861, 0.018468386493623257, 0.03730257460847497, 0.058300149493983815, 0.06615456552909953, 0.03595768427476287, 0.059677887707948685, 0.004200963394915951, 0.06731967122427054, 0.06093321820454938, 0.04255463921331933, 0.02496876723931304, 0.04458019855831351, 0.07267483243984835, 0.03893456667927759, 0.04699231591075659, 0.045055213783468516, 0.016591774066910148, 0.03609943702550871, 0.043040409218519926, 0.043736667571855445, 0.021983610100245903, 0.028928404141749655, 0.046193303606872044, 0.02082786649199469, 0.05146146984770894, 0.03184530744329095, 0.008165979807797288, 0.04810714555372085, 0.04174339970839875, 0.05518547019788197, 0.006312546137321208, 0.012772967107594013, 0.0006277789029159717, 0.04056376997115357, 0.04146777539114867, 0.026491501601412892, 0.05509049565132175, 0.01941106840968132, 0.02489387902564236, 0.03709606247554932, 0.012181740886132632, 0.006334599373596055, 0.01909525615961424, 0.06065605700548206, 0.05436795763671398, 0.04189581563696265, 0.0329909663248275, 0.016531642293557525, 0.018402583863852278, 0.06750316066401345, 0.014618085331416555, 0.031324104339416535, 0.02949855676186936, 0.06921985426119395, 0.013648953272162803, 0.05392553584117975, 0.047908046415873935, 0.04422100926084178, 0.009913219355179794, 0.06230132122124944, 0.038577993134302754, 0.03067817971376436, 0.027674094840352024, 0.03731451343212809, 0.009013340276266848, 0.04551421218950834, 0.035804386250674725, 0.029161782868738686, 0.0611230248053159, 0.038449397177568505, 0.04060962876038892, 0.08045058591025216, 0.052132110111415386, 0.026067613989913037, 0.0417239461094141, 0.04939781754676785, 0.028099090160269822, 0.04046696677271809, 0.02946420931922538, 0.07691771869680711, 0.0021313334125027594, 0.013654306065291166, 0.05443902400189212, 0.017746686469763517, 0.06258670626474278, 0.02141008007207087, 0.035631766941930564, 0.06783520177538906, 0.015786522633529136, 0.02048814945322062, 0.06809095519461802, 0.047751895152032375, 0.004609916450655354, 0.07575367151626519, 0.01467568108013698, 0.02723335750800158, 0.020275852809261, 0.05225424302209701, 0.05214924651331135, 0.0422362671898944, 0.04230952522318278, 0.04413440105106149, 0.06802512372710875, 0.015115010452323725, 0.045169346766280274, 0.02840682614727744, 0.07293345606220619, 0.023322368173726966, 0.04239974323926227, 0.060717579775622914, 0.019894141238182783, 0.01953729458286294, 0.010870921492044414, 0.060587674246302674, 0.032907686329313686, 0.03675017246444311, 0.041741991748235056, 0.08097880506621939, 0.060554914575602324, 0.03740393077688558, 0.09978002655719008, 0.009336825061057295, 0.02227550059823053, 0.019059297196300964, 0.021510184343372072, 0.02889296765040074, 0.06633628399244376, 0.029944629075803926, 0.021895402244159153, 0.028109490405768156, 0.030574058515152762, 0.028078795177862048, 0.018871709405045425, 0.06328061688691378, 0.03719720829810415, 0.0029208241737381157, 0.09133742244115897, 0.03200958416398082, 0.031523081340960095, 0.030353836582175324, 0.01871848601980933, 0.0764417942347271, 0.03135907603427768, 0.0439539684115776, 0.02880646800622344, 0.021911585304353918, 0.02342639098476086, 0.031957472674548626, 0.01562070903102202, 0.05567638010584882, 0.04528658065412726, 0.07564474628972155, 0.027269080680395876, 0.027865304312269603, 0.022126860717045407, 0.03399805478485567, 0.04478716870237674, 0.027418977547703043, 0.027372358799246804, 0.01876464675712798, 0.03870142883222018, 0.04324167627575142, 0.0326870369192745, 0.05313220287540129, 0.018476954694571238, 0.032832175559763394, 0.058303270755069594, 0.041135113420231004, 0.05634410266897508, 0.045859267602541616, 0.05546855500766209, 0.059079711591558795, 0.03754799393936992, 0.01923888166701155, 0.02173772597286318, 0.024874230347839848, 0.02123316563665867, 0.03946252120658755, 0.08078650824193444, 0.05317931016907096, 0.048834837041795254, 0.03464114652680499, 0.015758911347282783, 0.016769584168546965, 0.04015768372586795, 0.04556243567328368, 0.05491645820438862, 0.027630548159192716, 0.04936788397442017, 0.03912495342748506, 0.05257490510120988, 0.02015314144747598, 0.009049350977875292, 0.032125555976693115, 0.016119805463988866, 0.05938370206526347, 0.035428233577736785, 0.03137536087472524, 0.017356820604098693, 0.025788291656811322, 0.10754584627492086, 0.01375853582950575, 0.02025884872169367, 0.005417264133159603, 0.016669885321919407, 0.018214685642825704, 0.03983239743060299, 0.01911171063381646, 0.010353371451076652, 0.019035799528605173, 0.021117514431742684, 0.005511887961932058, 0.04833080765924283, 0.03441142510356648, 0.02354577413227941, 0.029714771945561682, 0.07510683086833783, 0.03888708958402276, 0.052737485484353135, 0.06234765837767294, 0.029666796127068143, 0.014199483507711972, 0.007589449806671057, 0.02734983991831541, 0.0202107880863228, 0.01912812439591757, 0.015492957850385989, 0.05721804220229387, 0.036941485412951024, 0.03323789878881403, 0.01213559796035822, 0.06936986478311674, 0.07348633996610131, 0.04333559909303274, 0.039105655891554694, 0.02952249887000237, 0.03829690661015255, 0.030583395157009363, 0.0404842320962676, 0.034524323152644296, 0.023670041035594683, 0.07191696989216975, 0.02021350392273494, 0.06296694371849298, 0.039364422006266456, 0.11409114434250764, 0.03934509732893535, 0.025926127564162016, 0.0065852332461093155, 0.05367940404851522, 0.031940051287944825, 0.02636828812371407, 0.03199852065050176, 0.0530688921654863, 0.0613741913278188, 0.03635589612115707, 0.04098045832610556, 0.03766327364636319, 0.011070261509822947, 0.02708790504506656, 0.24338823131152562, 0.11585540324449539, 0.13440338868115628, 0.09077190421521664, 0.10645364238215343, 0.18784971934344086, 0.16683753899165563, 0.13362847454845905, 0.12796741617577417, 0.15936335362493992, 0.10638195515743323, 0.05767480483544724, 0.15330845995673112, 0.09198593907058239, 0.11639516428112984, 0.11204372599188771, 0.16492616012692451, 0.17459852754005364, 0.1683389741395201, 0.15283529034682683, 0.12512700073421001, 0.16687883463289055, 0.2579278254083225, 0.15846158058515616, 0.08643140391047512, 0.09988073472465787, 0.15029136756701128, 0.19571395378027642, 0.12421620317867824, 0.17360283168298857, 0.11298667253660304, 0.19352848748011248, 0.15195035854620592, 0.1326506920158863, 0.11842299332576138, 0.16351202529455933, 0.15080510000033037, 0.08452781462775809, 0.0953510452860168, 0.12884263135492802, 0.0759181823315365, 0.1256612113543919, 0.1349383456898587, 0.12817221161510262, 0.16287893855146, 0.07484229042061738, 0.13600711976843222, 0.08174775487610272, 0.1224375729049955, 0.13975280949047633, 0.157768864184618, 0.11765770081962858, 0.1978262604347297, 0.14360615557857923, 0.09874076875192778, 0.09270595972027097, 0.09926748834550381, 0.11815942318311759, 0.10224588388311011, 0.12267846640731607, 0.17520550425563539, 0.06133071080382381, 0.06437763159296342, 0.12048934958875179, 0.16647160505609854, 0.1820960816528116, 0.12291087822190352, 0.12583353210772785, 0.08518224129719393, 0.09488975003893886, 0.15668176966054098, 0.1257140420909439, 0.14462546445429325, 0.20866733656397887, 0.11882989720574447, 0.0700613326792206, 0.10755415832889931, 0.1422016423727785, 0.16468017761196407, 0.16539443071399415, 0.150432787835598, 0.08768573696059839, 0.1757007533950465, 0.27082484907337595, 0.13947410801691668, 0.08592638386679546, 0.08206900049533163, 0.26787406312567846, 0.14506444946995803, 0.10849399718322925, 0.14579314179718494, 0.18400907543088707, 0.13165640751166002, 0.14432404562830925, 0.15583683071391924, 0.154619321759258, 0.12184278267834868, 0.178888008796743, 0.19275634177029133, 0.18909897016627447, 0.11649801661925656, 0.15218673300530228, 0.13180734084120818, 0.1632244892950569, 0.08947873182062592, 0.12370730191469193, 0.19282722153833934, 0.10923780048532145, 0.07502444314637355, 0.08710365569485085, 0.14822176790663175, 0.15302819785262856, 0.11276701718036618, 0.08173630799033813, 0.12470766609268528, 0.13956925219723157, 0.1801170121346201, 0.1848847113017525, 0.11888548279447214, 0.09182333493871347, 0.10319201275706291, 0.0902512100126062, 0.15556214616766997, 0.12439810484647751, 0.14576146778251442, 0.08003832160362176, 0.11453573405742645, 0.06993902674210922, 0.1403499881603888, 0.14543883795184748, 0.14405074529349804, 0.0924175755519952, 0.1477672037269388, 0.08858778141438961, 0.16903999580868653, 0.1302314568310976, 0.13013211930436747, 0.0893664817724909, 0.06419583849076714, 0.08382709829935006, 0.1426488919449704, 0.12469993079347269, 0.18947002025587217, 0.18361815783594335, 0.10468374485416071, 0.14178799385471003, 0.10552472115627357, 0.1652065986501319, 0.18036614305206708, 0.2163861880877188, 0.16940635043595517, 0.11940464350794043, 0.07255295397979872, 0.10025633099888052, 0.10456800713602986, 0.07274943057979856, 0.1757487936743668, 0.12068186354424272, 0.14080014186246054, 0.16174332877354963, 0.1809107759701354, 0.20704381939555916, 0.19077886002404348, 0.14740109337227686, 0.10872807819396257, 0.11577577037470681, 0.25143712226833614, 0.08240275151495423, 0.12756619841924735, 0.18412069444145474, 0.13243665492960385, 0.2616891350064959, 0.13182391066636356, 0.056671763836805306, 0.16865656924034866, 0.06688732228108815], [0.07305591127702168, 0.08232984971255064, 0.06278403781886611, 0.03970993882311242, 0.048662353440054824, 0.044397455507091114, 0.029558142314531972, 0.04125062382913061, 0.02591623621992767, 0.060618187966091294, 0.03007785603404045, 0.06832903956196137, 0.05293684246550713, 0.04168462161240833, 0.03455714728417141, 0.038654314753200324, 0.03329799663541572, 0.003349458349735609, 0.06169105361082724, 0.05436482619760292, 0.03305438560034547, 0.06579314385141645, 0.0482197246913399, 0.016923508141189814, 0.06279048390154328, 0.03770168890644397, 0.056358226375388246, 0.006097198206199599, 0.008638099384760218, 0.05731969353343759, 0.015068035472982695, 0.024855672415079813, 0.03451155312359333, 0.03237468350146498, 0.008311120144623731, 0.033730966438140185, 0.02668707405350038, 0.01783019886352122, 0.04023524367117456, 0.0636720365977713, 0.03631190669589809, 0.018392080141763602, 0.05287664283865264, 0.07326937160853829, 0.11338666893009629, 0.016893133521080017, 0.008590305922552943, 0.018569479729714136, 0.019989896100014448, 0.03974899869146092, 0.05605038521545274, 0.03795064679746117, 0.02784445971649672, 0.024629472588588084, 0.02455465562109436, 0.010832743719220161, 0.014587252700169171, 0.051424791637275896, 0.029789875594100783, 0.018578382109158804, 0.03035092566694532, 0.06717653426208667, 0.04612789961642452, 0.03528108986626778, 0.044252544175833464, 0.06439158227294683, 0.028173895253400718, 0.005010029043270541, 0.05320656692077007, 0.04497435615797128, 0.004865641456230411, 0.06679998803883791, 0.04013884420107518, 0.02119079282108162, 0.057662238366901875, 0.03583744108410818, 0.042560369441551824, 0.030986872435148274, 0.034755204870764694, 0.0419170266416456, 0.03992850513064435, 0.057660569170756, 0.02033032729689564, 0.06641939774687801, 0.039237434177526405, 0.07011136106614556, 0.030686780145125728, 0.03133565979078412, 0.04911572000543986, 0.040692586451768875, 0.020342574853982245, 0.03692851521606956, 0.032205009034701755, 0.01894925069063902, 0.04478213736521346, 0.014673184071268355, 0.029523703269660473, 0.034449304320982525, 0.02548577869310975, 0.040814875425504785, 0.004539703343263162, 0.050719685187297206, 0.05552827626732843, 0.038225657040519376, 0.02600075114917542, 0.05887485508407865, 0.001843813740249191, 0.01933701309774603, 0.02815418890012162, 0.09357696119695902, 0.03743742326540606, 0.015335288364440203, 0.03499340798173632, 0.08082169706800155, 0.0177759873082063, 0.029345214633005004, 0.0416981414226549, 0.03175704360806516, 0.011656347828518068, 0.02491199251796518, 0.02293641915145729, 0.034325064559067996, 0.024103925164256777, 0.018335449609107206, 0.048737073716308386, 0.1098555251955986, 0.03781194745429924, 0.050164724966245036, 0.04661410727671214, 0.025101297002817904, 0.055683277414313385, 0.03771187032439879, 0.02049669051276786, 0.023221325827762485, 0.07998610154858657, 0.0381950211844274, 0.016823366550462585, 0.044787321372755935, 0.054500000551342964, 0.028558171686849425, 0.013430229205239032, 0.03770332756851401, 0.0962936050657715, 0.06743549715195384, 0.02413824716183756, 0.04632000984357936, 0.031735242277915986, 0.027739790600857565, 0.031298068950751, 0.04815744535465326, 0.0181144829839468, 0.039840268436819315, 0.014638782345822879, 0.02714133119609739, 0.0195872652943113, 0.04223412980458566, 0.029275196604430676, 0.015939547547272274, 0.09662002112184252, 0.0511388366243669, 0.07512796044881855, 0.02594892125177596, 0.06808439376098768, 0.01857531343453697, 0.02026753227359482, 0.003933050628152809, 0.03928872803226113, 0.021920039850686277, 0.0296106914590512, 0.0243973254026579, 0.036165668828678985, 0.11214590658034597, 0.03962010417931846, 0.018002673983573914, 0.04585959329935057, 0.08136063029191323, 0.032403348213327784, 0.032542749840234, 0.03604267417852368, 0.00855743429357452, 0.012634801262590502, 0.01045001604195152, 0.03015807583662016, 0.013818038261628576, 0.022447519403483187, 0.07775693080787148, 0.025422269511701803, 0.07532014870750052, 0.014735531261456864, 0.025558073206671646, 0.06741489004343748, 0.027821152038606148, 0.00396264620524432, 0.042020075754927735, 0.019037468724751046, 0.017619096441194415, 0.05619441105851105, 0.025936895914907967, 0.02184675128332206, 0.03490161576441356, 0.03783509228378534, 0.017757290275767446, 0.04591830014916403, 0.05181113929886903, 0.02392974352863218, 0.05754783057740756, 0.04110010440594383, 0.034374841888036044, 0.016480404417961836, 0.04509654674412949, 0.014830816237788116, 0.028240445968029753, 0.03091531413208161, 0.022016139069039906, 0.09706270415335894, 0.041509847954979966, 0.020547073434240053, 0.015369294843237315, 0.04082259036866682, 0.05819596044187035, 0.034413474279322794, 0.04297338013670274, 0.02044276224582323, 0.04805023342903171, 0.050978166317301135, 0.017024109439392174, 0.03497584071010351, 0.034942151446427615, 0.023168332242806042, 0.024654549546539783, 0.018560153265882815, 0.012036538632985736, 0.06138208269008568, 0.04371080860229475, 0.026904145887653743, 0.05739119755370276, 0.03500839003494807, 0.01927159384026059, 0.089934028818139, 0.06511603375630719, 0.028703384966190373, 0.02958305472774165, 0.08960416580417327, 0.059110883490315506, 0.025335266055273156, 0.014026692020706832, 0.0268996980906065, 0.016574291612154672, 0.022108754010072777, 0.024136276017608385, 0.06230852726314749, 0.0316978855324643, 0.0517365513369441, 0.02239446305403752, 0.015039060331348861, 0.0448167562218649, 0.017210011071126376, 0.03175778999658568, 0.0437101300672761, 0.05181317490392497, 0.06710342889917748, 0.025690058445824043, 0.01632539478928915, 0.029501437143023525, 0.03719579015991517, 0.029046777968427966, 0.022414349219096557, 0.03285575804433652, 0.05285636142694524, 0.0051469485042616725, 0.020928706973791122, 0.025201621798000166, 0.031076065863349607, 0.04339044168591499, 0.010956446590301181, 0.05457113816269806, 0.014611196504639727, 0.0334802443560745, 0.05803577868001802, 0.020428304360913377, 0.05421991825902036, 0.024214127732973014, 0.0771333978378347, 0.060495298488863876, 0.018977532030216286, 0.015973272434036647, 0.08371431220855031, 0.027131156563492756, 0.0035069832229055464, 0.039771909426365576, 0.017720841070903198, 0.019090399545218264, 0.05499452705095921, 0.016797331161797047, 0.01975748428542699, 0.027862038862492357, 0.027334354052852308, 0.024971338887033716, 0.03692238125950098, 0.053672306572220156, 0.02942061683695231, 0.03910589677148631, 0.004577804356813431, 0.02305419586731919, 0.05645764532632061, 0.04543836215244872, 0.05487021943554282, 0.008877895356688117, 0.023056016037506715, 0.0400941524920719, 0.05342801360945616, 0.02728652920840042, 0.07156226571117129, 0.0617779739467161, 0.027195598730551343, 0.0743790070659348, 0.015279977582395077, 0.058143625035881996, 0.09263399429619312, 0.029368257682238306, 0.013444562409339207, 0.03132464038208127, 0.010277466283046773, 0.011598032832677876, 0.050602627718555074, 0.016421592395220484, 0.012690416537225246, 0.08074496832809278, 0.05968529052500214, 0.010852193077360945, 0.023683650751731226, 0.04743628137345825, 0.06118004210293293, 0.060475593831922324, 0.020562503320564116, 0.037772141197430234, 0.03388683610994901, 0.07039832709623234, 0.018476615427061915, 0.01129945706842201, 0.03303636710292526, 0.04479623053755079, 0.038101529236882925, 0.06218062341213226, 0.04430460477513926, 0.06459111906588078, 0.02456524076738528, 0.021152399613388946, 0.052933256407933574, 0.022180960314082246, 0.03823386731424502, 0.04949223569461277, 0.15487398952245712, 0.20999783516994544, 0.17835417815617152, 0.12092100642621517, 0.15501830035022326, 0.12918598364506448, 0.10489285577620779, 0.08642126659729651, 0.14456807396241597, 0.12981953179197653, 0.16861285801444734, 0.1394806219530957, 0.08289155457168818, 0.12219042330980301, 0.18824397533067636, 0.14956559294036456, 0.09607156805161919, 0.152530166719641, 0.16024610054280075, 0.14725781391773904, 0.16666151343711785, 0.16623757832816669, 0.17838745351348603, 0.16374396213463374, 0.11224502697587013, 0.1354077019329582, 0.16512404807976314, 0.08568867269371237, 0.10827972260969025, 0.16226581430860929, 0.1412822138518095, 0.15210001622991903, 0.0865462798891323, 0.23870389695678437, 0.12424527161887713, 0.1153974463897092, 0.08906233523573194, 0.07306600109274898, 0.18489434649901731, 0.14725699967571668, 0.07253973611763545, 0.0957735011886273, 0.10820773004421166, 0.1780683384942157, 0.2426182840551649, 0.10612599817769867, 0.19355391897261143, 0.08763851770865065, 0.08675108889916114, 0.09501110602702413, 0.14012316747435502, 0.09234189854136535, 0.16485062560864858, 0.08232685058776822, 0.10288532171398401, 0.09337729548237153, 0.11595795702721391, 0.2235114843185459, 0.13309461676648685, 0.13007791792707785, 0.12913214867668493, 0.2048503735235759, 0.16435986837106092, 0.0994062487568174, 0.13946790620684624, 0.15194647732589925, 0.1319895682058164, 0.17031881718763284, 0.16382789691644056, 0.12815303621547564, 0.057408540908779414, 0.1826220005750656, 0.13354664322521004, 0.11690411982791764, 0.14251281853233064, 0.13814290373453073, 0.141698047252638, 0.0987077783793211, 0.1074794651940465, 0.11232869034366948, 0.10541667123990399, 0.1786228644528559, 0.07595594280532428, 0.1548718317810978, 0.1752972286194563, 0.1840624354247536, 0.130117693649871, 0.169239770088877, 0.14767067533518585, 0.1690862990383591, 0.08910713211766311, 0.14605688835893357, 0.11382143345794507, 0.0893099530200873, 0.15478682491396153, 0.09899851706411157, 0.1628835525895868, 0.1261817291378975, 0.08143678227705614, 0.07503876702061721, 0.124733016160982, 0.0952747440231698, 0.20802363753318787, 0.09132756332733802, 0.20190914134894097, 0.16006011409418924, 0.1686046477407217, 0.18018912683640206, 0.09164116864225694, 0.11457403057387897, 0.1317255909421614, 0.1419217059654849, 0.1586665524435895, 0.15772280522755214, 0.10533305536955595, 0.10004738292523793, 0.12600085884332657, 0.10303005323346172, 0.09784398972988129, 0.07001169784260647, 0.06170364722077336, 0.11260714754462242, 0.060309739517314095, 0.12012830110532896, 0.10852261100496564, 0.19477438633995398, 0.11618679974760328, 0.06732787471264601, 0.14882259709494455, 0.07553408401353018, 0.11383368101503168, 0.10510700142809323, 0.059289012503411086, 0.1366415771522692, 0.18199947183685644, 0.13377058692276478, 0.18224715068936348, 0.08749984550688948, 0.1023587446127619, 0.13416834415069648, 0.08087228863899197, 0.13062875265521662, 0.2410119745348181, 0.189847950690559, 0.09385859394179923, 0.15545200636344297, 0.07912557665258646, 0.08685325591691903, 0.09840633919728653, 0.1985804656786578, 0.08392952994576522, 0.09382829056786639, 0.15472872874566487, 0.0869622625676649, 0.09695656770574194, 0.10836375238639967, 0.16586263344756194, 0.128440314371671, 0.14128348949764455, 0.08715588253523622, 0.1993324996105262, 0.16100285707839898, 0.13638096542230674, 0.09201859696102993, 0.09139876879219498, 0.09135838238788502, 0.10591807469193425, 0.1046032773862992, 0.16104191355407238, 0.09528057263897997, 0.11946862936019897, 0.21889011801353522, 0.1585323517876012, 0.10882115284247057, 0.13427085722131388, 0.15197269591901982], [0.03987636649981141, 0.010083253445502902, 0.04981656525550144, 0.032857512057359727, 0.03376590759892549, 0.03635215400052922, 0.045519718501184664, 0.03280613677842276, 0.00948573720441865, 0.058920357642429214, 0.020549677312374115, 0.05447827046737075, 0.012907672424002417, 0.04439919934208904, 0.032906522641756704, 0.010075893036888113, 0.03499188127794436, 0.04333261353895068, 0.04247565095179847, 0.025820727327040265, 0.02867811292942081, 0.005033661145716906, 0.017462195396157246, 0.033693928604147265, 0.045130772050470114, 0.02575919607521168, 0.017198835599369237, 0.0686935078618782, 0.006790623251747872, 0.051249224093875716, 0.04864263181973781, 0.029595278536102602, 0.04578076110088399, 0.025810318599854196, 0.008608093718066812, 0.021903502255944268, 0.0550096957013011, 0.01185293129778334, 0.03136953904426523, 0.04110941390639969, 0.021113226090424826, 0.04882768867537379, 0.02972038003749081, 0.09152025370193378, 0.011212897204261805, 0.04169574958671417, 0.012872082414105535, 0.03574072948790022, 0.029570247379264662, 0.036692734475114515, 0.040772466986839256, 0.016154007021603838, 0.019059417636266777, 0.03245571754606707, 0.03397747142506497, 0.044792953213410716, 0.0244521730845528, 0.065747281669506, 0.022452262363263538, 0.09756131204111235, 0.010078418883495033, 0.06635920490537371, 0.07619689737579652, 0.008725897575329458, 0.0659995542040893, 0.019485768329884325, 0.020800385823739425, 0.08530810954315321, 0.09374118702752249, 0.013164386818451541, 0.05196483426594308, 0.08466994735811438, 0.029474573941635232, 0.04551969814513411, 0.04707669513300061, 0.046296145766973495, 0.016746861727109978, 0.03838796940233026, 0.015587174134062869, 0.03184702413688813, 0.0847014110269291, 0.14067402934389456, 0.07809756895793335, 0.04319705920560019, 0.035852650446551185, 0.013697023237390178, 0.07201651097940547, 0.03858354355075529, 0.03815023108784642, 0.014019098365679383, 0.08340553127761398, 0.052212811673858335, 0.08616465143859386, 0.06907712442002126, 0.02089856475192521, 0.016766030341386795, 0.020540976797097495, 0.024002290796488523, 0.01888164485405598, 0.003904564879901175, 0.07145720134888377, 0.030107063573918173, 0.04497405081721289, 0.02744129965347903, 0.011136029364674218, 0.034330397844314575, 0.030094246047415903, 0.02033072423988155, 0.019682202521445494, 0.009364678075404038, 0.07406129661415305, 0.06183653151882546, 0.0910296186006495, 0.04204659290345652, 0.040054695680737495, 0.0365482574062688, 0.07550063223711082, 0.028286252170801163, 0.028257536568811963, 0.0025565624029176043, 0.06268404889851809, 0.020402443695015142, 0.02084454657909061, 0.02267559029028884, 0.055923909680651765, 0.04401031056685107, 0.00997029517644218, 0.0429136113795851, 0.0677130383306316, 0.051564814123724184, 0.019033005660665885, 0.052789417162005386, 0.10551507917365857, 0.019048622144120078, 0.04936909855210355, 0.02921555337629148, 0.03756168677604624, 0.09654072751956326, 0.10269602401448147, 0.03488203663645046, 0.032164279970207384, 0.05789812428078481, 0.05385693595079439, 0.010324679597813104, 0.03257088190210717, 0.033533377040709765, 0.04437865669439946, 0.005988510042828108, 0.05658814796645727, 0.022651393731523837, 0.01958201004059187, 0.03244568540581635, 0.03819157761920776, 0.024409452519778694, 0.02658782134364758, 0.0678297531391893, 0.048760571384004185, 0.006534117082732597, 0.034290235356560776, 0.03911739115470222, 0.007316277545344616, 0.03508174306313906, 0.020338875141793063, 0.054916488738464456, 0.051280368851231675, 0.04504267445632389, 0.03523611995790686, 0.0333727610164455, 0.01935255154967308, 0.02129429316015116, 0.02182161495355623, 0.036238590987133126, 0.023054886276700666, 0.025997701134266596, 0.025020773555817347, 0.011766809088710164, 0.006961486851131278, 0.021402870637497733, 0.08439288115394966, 0.034880292801452537, 0.049445416778326035, 0.020729109112705504, 0.03472055548003741, 0.04463318196524467, 0.04715850270752396, 0.05690869130194187, 0.004357126533120338, 0.040838580046381266, 0.004143694615257638, 0.026343280715601783, 0.02955118054524064, 0.01384760033605354, 0.036984850585992844, 0.06842151031430278, 0.021000341612047384, 0.038302762367363484, 0.013291914082531418, 0.02445851738697716, 0.014510853049744452, 0.07202183069395167, 0.035288428222494464, 0.026354585109012466, 0.02768311426708741, 0.037416551528232436, 0.032801241148263216, 0.026479299845440046, 0.057118894665368965, 0.04720345565250941, 0.045710335951298475, 0.05461895791813731, 0.026496309022020017, 0.043764860701880286, 0.04873573360964656, 0.020162223638700585, 0.01869373645500413, 0.05886703836066382, 0.024190299279455627, 0.016975380447027937, 0.05905202736279794, 0.07187891764832394, 0.009176527948251792, 0.06892005034855433, 0.01003601129299828, 0.010073861672676035, 0.015436663192563822, 0.007716605572828225, 0.05353495412107025, 0.024822476785629988, 0.018351614009588957, 0.010875502451589065, 0.02547020122541913, 0.04846382087894848, 0.05376560174460922, 0.09896617808512279, 0.09554873646370002, 0.06152910765792642, 0.03036586700805596, 0.01690487556957773, 0.03246597360287394, 0.024989452379356538, 0.062204534986189434, 0.035023344946759086, 0.07950898286487375, 0.04899964980514986, 0.09606909139880113, 0.0437609387694725, 0.022196212084963918, 0.08325860809002604, 0.032100361971450705, 0.028388814435207417, 0.042088468692132404, 0.06943626622004168, 0.03016091211299811, 0.019532139413058758, 0.018044882254408937, 0.03752798394166997, 0.02323081683633583, 0.06461292039602995, 0.08451971970498562, 0.04680760510798011, 0.07677246470536504, 0.03357695255960737, 0.010226478617239212, 0.034310869606477876, 0.046848710759409835, 0.04476505185344389, 0.0350296621077827, 0.034538314544728825, 0.04963476536795497, 0.01717760763131082, 0.06985179428011179, 0.027194090686472397, 0.03202402678185275, 0.017009249522483776, 0.10572191700339317, 0.03088977068130459, 0.03314446790942124, 0.07462585810571909, 0.016914185070033585, 0.03632957574778369, 0.020313075544046502, 0.019106523233598897, 0.04926395955096398, 0.05020828691444226, 0.04437126066269619, 0.039097316696175506, 0.013497250653537256, 0.03850745941911425, 0.03680492006242275, 0.0565374749712646, 0.0323364175190883, 0.03830368517498885, 0.06380222711179938, 0.02684993263600128, 0.06013308971055916, 0.017706154180424552, 0.019188096713540808, 0.0526115392068667, 0.017390682894204344, 0.038573497839804204, 0.0854795617716653, 0.02772561939699309, 0.0328624450069453, 0.009175886732659169, 0.015638909036559717, 0.0187543465955449, 0.03945965100345867, 0.030172986643654958, 0.06632640452257224, 0.03501971139173422, 0.052371242815362554, 0.03165231851328697, 0.009902553632855415, 0.05328568749661956, 0.02527133618215365, 0.024688735837116838, 0.012685723619402518, 0.029966959663267647, 0.015126450552738138, 0.03790465908657227, 0.05192223583747234, 0.02001610960412238, 0.013706635534098106, 0.03629085514694452, 0.048402430423136265, 0.004788419930264354, 0.022092626929017048, 0.01794204518332013, 0.025131973571010997, 0.03871468062113438, 0.020700914286343113, 0.06568746880761214, 0.024065818637609482, 0.04020767818604197, 0.017738706897944212, 0.10282069803880793, 0.034088839377675734, 0.03338529355823994, 0.07776552784655776, 0.04277671015422259, 0.04040348303637334, 0.02213277414973293, 0.047124141694179604, 0.04760656991441335, 0.031465663707682064, 0.030330878349819353, 0.036637450834470134, 0.055905239789613655, 0.023398793269214884, 0.02761942188122443, 0.009182516867960138, 0.0395526103010135, 0.11657471821776458, 0.09320057782211474, 0.09466104302555323, 0.09574128434594188, 0.23595754003950528, 0.17677482004676545, 0.11222194321453571, 0.0776741291795458, 0.07890643019761358, 0.13824057206511497, 0.09978088151131358, 0.10033121412353856, 0.17269172200134822, 0.05514506683019655, 0.08552796845989567, 0.13827794577394212, 0.12269578262099198, 0.19413399856005395, 0.0839248209127358, 0.16692603352878774, 0.11157350800931454, 0.13809457847050258, 0.08420608046331576, 0.14444668404757977, 0.06861415319144726, 0.1282380973654134, 0.14514731216643537, 0.10346719941922597, 0.13823394956333296, 0.12322110443242959, 0.1402821210878236, 0.14134995878807136, 0.14828204895768846, 0.12273991453860487, 0.16695510196898664, 0.06496134812810592, 0.2108829841017723, 0.16411934127765043, 0.09024462822292532, 0.1333562462989773, 0.10463768589709486, 0.10087098873087338, 0.1435052438506058, 0.2185933810791799, 0.11618268782539026, 0.15628169184284552, 0.07018315007111856, 0.15185365373534815, 0.08745513683451073, 0.10098588506558112, 0.1304123949791704, 0.09856544208845922, 0.12424183823168278, 0.12465070986321994, 0.2297187905226435, 0.1939089149236679, 0.12009632853525025, 0.24974743436489785, 0.14482903853058815, 0.28214308459843906, 0.1109143587361489, 0.1465621662459203, 0.16823696318481648, 0.12241030936794621, 0.15394903772643634, 0.10729909701538937, 0.14203454633908613, 0.10889991718743529, 0.21881337570292608, 0.20345522410103253, 0.10258844228727476, 0.1545713221920388, 0.1306918699826513, 0.12869574209409101, 0.21632723696529865, 0.17843781438257011, 0.13437776719885214, 0.12360674302492823, 0.13675007490175112, 0.09188062365033797, 0.1741610217307295, 0.2632858636123793, 0.16325009720666067, 0.18986794033220836, 0.12010600444461618, 0.14180524221488408, 0.05725828611424991, 0.1338015552610159, 0.09527603323970522, 0.14970074354537896, 0.19562653132847377, 0.09993139414915017, 0.1772108737911497, 0.1545788539307458, 0.17288851072745665, 0.05744003850434508, 0.18028542452624866, 0.14273198534335407, 0.1479784452489444, 0.07896760012954473, 0.14409369656017848, 0.13444055882947786, 0.07182438378887517, 0.13769747263618878, 0.05966652903173651, 0.15564764158001967, 0.09228560727621828, 0.1747932806611061, 0.09120064335209982, 0.10533743870577641, 0.099867421867592, 0.17916399613022804, 0.12017388508788177, 0.10302617201315505, 0.1019401563597577, 0.15161159315279552, 0.12961555059467042, 0.10935126511113984, 0.1583254121776138, 0.08714234576161418, 0.14456636405416898, 0.09364641604146787, 0.07178156822919846, 0.13290772108095034, 0.18093763238617352, 0.1355625707656145, 0.17362252276922974, 0.17158034949430398, 0.13583973875003202, 0.0949878254905343, 0.1038225685645427, 0.2134745671812977, 0.25660188655768124, 0.09320221987685987, 0.1574857658041375, 0.09754666247005973, 0.07120121722774846, 0.1604894639125892, 0.1803903260401317, 0.07975598318236214, 0.1623348891735077, 0.08132616749831609, 0.07556458416261844, 0.14301089037741932, 0.20001540439469473, 0.16643208717661245, 0.16461896018258163, 0.10394095935459648, 0.10807985333459717, 0.05893913270639522, 0.08716114118163075, 0.07484947610646486, 0.10568742028304509, 0.12174458509044987, 0.05966859856354339, 0.11355545451598507, 0.14781718461641244, 0.08827199800206081, 0.1562037688813039, 0.15986481814512185, 0.09221026953309774, 0.0731960626851235, 0.1780900787562132, 0.07313438385192837, 0.10629289065088544, 0.12354799546301365, 0.15882603531437262, 0.24714989374790872, 0.10343313017593962, 0.08739816024899483, 0.06394665329051868, 0.1042394604800003, 0.27677503121750696, 0.06683017606181757, 0.0700445660789098, 0.08061093052050897], [0.018714285888043896, 0.035033872417573414, 0.015401993445785982, 0.041852494568697045, 0.029404430384082452, 0.05275677623493331, 0.04451691498979926, 0.026932690159550736, 0.04737989172073347, 0.05288366228342056, 0.07478812975542885, 0.006479044636112771, 0.02168032360662307, 0.025923528775040592, 0.031174480582454374, 0.040656671593231816, 0.08118303732148238, 0.04834527741851551, 0.017093184304290583, 0.018895100203475783, 0.03204632004989045, 0.06639165923531566, 0.06088178525013583, 0.01563870208337903, 0.03670390655419656, 0.015031416634363788, 0.034441467241517136, 0.014461703365668654, 0.030082646491272107, 0.03580619454649942, 0.03980978185843144, 0.02857918252370187, 0.018774361682257483, 0.01027906168850937, 0.07734423902417932, 0.023077040445059538, 0.024780969102201716, 0.03747899032064846, 0.005046588934159705, 0.08620241869773183, 0.06520602785583053, 0.017048368762646402, 0.03729631173025284, 0.05185492177094732, 0.026373667210074406, 0.01040503425922777, 0.020921461916129504, 0.017028421529435685, 0.06283950127129044, 0.03280604178352015, 0.0326441127939948, 0.01369826665281185, 0.006642669115015971, 0.08302039480102913, 0.07213764983628478, 0.004148641135543585, 0.0663981663861445, 0.02186681895649859, 0.03127611155754753, 0.02596959621379418, 0.06673870275595359, 0.051199256775102446, 0.05066811652587993, 0.06004956204976354, 0.028412530930446725, 0.015415752439626625, 0.03308839377548013, 0.05927596427500248, 0.0019530135614331812, 0.03681313372882349, 0.033341382164508104, 0.014765729462461812, 0.046904272599411864, 0.06085407387997423, 0.037127512573663674, 0.02928035007789731, 0.06736956390419177, 0.06076335374798093, 0.026547601180417196, 0.018823848937505057, 0.03464788437954017, 0.0193017869522529, 0.06196113768965006, 0.028386298766625778, 0.014312025325905, 0.031149839583252157, 0.02877849879275475, 0.025256734108552337, 0.011174963704044265, 0.03378710164023297, 0.09695527170385633, 0.03305688939456429, 0.02122322509863547, 0.021060834705297436, 0.020497330032022934, 0.02115285423185144, 0.04103583696165255, 0.017435557807662656, 0.05245991377159953, 0.03304805147594639, 0.12612201805625642, 0.09106473957321473, 0.04746923442663891, 0.03961904566468937, 0.038346242891358476, 0.059120980091392994, 0.027531130904597894, 0.07230147533118725, 0.03557842730411461, 0.05047004197591117, 0.03687405599547284, 0.05532663940851178, 0.02402911667845079, 0.03807368894506778, 0.049000084067561796, 0.04038891488952296, 0.03249714889430574, 0.031884323206863234, 0.04583972240132945, 0.03921534446999431, 0.03277571126818657, 0.06336619372346572, 0.02564542950130999, 0.027019179625702754, 0.0356069970210748, 0.01490325663637902, 0.04125784004905394, 0.05746647422867162, 0.05585905530356935, 0.03299393491553409, 0.00884984980802983, 0.022361431969329715, 0.031082820679460253, 0.04291222716814705, 0.05120563500427774, 0.005593409279494413, 0.01588582792984588, 0.030128769909164736, 0.043002316262573004, 0.021721717635435716, 0.00986481860413083, 0.039974849072418044, 0.02242214558646083, 0.026581695868766735, 0.031679568479635885, 0.061076205889029164, 0.015059211125065173, 0.020096919732168317, 0.0455591108516923, 0.04092349870396512, 0.032580296575490914, 0.02022770226800016, 0.03468063726489033, 0.05528020386451057, 0.08629046540175166, 0.0241185713426343, 0.024599064041727355, 0.06142881339682, 0.0413955690871392, 0.03375585170994912, 0.025375776292224015, 0.06058955378830433, 0.023619837925902436, 0.010256171309655266, 0.042488305629896264, 0.05122019297310284, 0.05264860757493547, 0.025786597015602247, 0.04516679886728525, 0.01870062867445605, 0.021051296199272786, 0.03703733187701021, 0.03579398091616375, 0.03980160890413182, 0.03488483220072729, 0.04987551637792161, 0.05492414600614991, 0.029349838849157095, 0.03180965382073607, 0.04572571834017124, 0.039695849043450186, 0.03383402233677251, 0.013678509409406354, 0.049470933087702305, 0.027126128619004573, 0.06379069201648235, 0.03358344953241093, 0.021464193239808083, 0.07864147584353175, 0.023575388793168322, 0.016334946866014173, 0.06027488995875631, 0.054295300106917105, 0.07131277517016445, 0.03090611319722874, 0.05950325315019914, 0.07756701564150197, 0.0393544102220663, 0.04716789023950696, 0.009689878705622894, 0.02683561045809516, 0.058004661064062796, 0.03871804276215179, 0.04006781515532306, 0.02108629503553467, 0.04561930030052151, 0.054365715078477345, 0.06799769734165498, 0.01340165694377252, 0.01837990722352905, 0.02843425253273121, 0.04575603867747954, 0.030755383428186178, 0.07566792504595858, 0.03137540837217655, 0.023142763346965824, 0.03341409736978156, 0.009712981126670326, 0.0027435303948420498, 0.05832352502537625, 0.009897110085668308, 0.006320220368382121, 0.033014148473739624, 0.019081968747611557, 0.035160690612558804, 0.06995218353612082, 0.040489701088517904, 0.06447177832680089, 0.02383059768804482, 0.03729717007705143, 0.07239734554397208, 0.0045375587485198465, 0.017592248506844044, 0.03351205747042384, 0.028199053635554652, 0.023098025836848786, 0.020012248739866272, 0.03113602121759738, 0.031138609828693525, 0.009071052224109215, 0.058492636308074, 0.04104428472263472, 0.03774207191807883, 0.11761730084461824, 0.022715001300509487, 0.031873544678092, 0.05945141986012459, 0.0260980564635247, 0.04788324935361743, 0.046020901429333856, 0.027456624366875206, 0.028331242435212647, 0.029276180480207716, 0.03772492194548249, 0.016889620406020964, 0.03232454994161214, 0.026075732661411166, 0.04485618928447366, 0.0400514828174242, 0.004696743063894766, 0.03999702359682747, 0.04826947148623211, 0.04348922620660492, 0.044154892808624675, 0.016282314600955163, 0.03550060951550092, 0.05805487944079297, 0.017238455259108117, 0.047231689494635375, 0.0252771851540144, 0.008071015439262348, 0.03749911566930158, 0.021854939504659603, 0.015392253075593283, 0.030844804165618758, 0.0672022643099938, 0.05799727860305991, 0.05301300123600023, 0.04274102599759187, 0.02334565549556698, 0.03538607619702816, 0.03523972637153097, 0.010773112365443791, 0.05107664210455758, 0.031985326537064145, 0.0185035329112517, 0.053204107231327465, 0.04781795392877289, 0.023675457441381047, 0.04761969956702419, 0.08579091435032231, 0.02284384492252554, 0.049714924102383, 0.043268807498472076, 0.028304881349738156, 0.014163763727992773, 0.03440723514982632, 0.03690188271658761, 0.016447135845997503, 0.032538563279168944, 0.025758890734453286, 0.0489059509044247, 0.043488225367452414, 0.06079290394804307, 0.04084728904334562, 0.010483751106741173, 0.04190187495467918, 0.05908130614885262, 0.05483673373237252, 0.009842847640226995, 0.030408692745757953, 0.015951564402452538, 0.006470672786235809, 0.035797013967697106, 0.02393656110923205, 0.013169329946062394, 0.02934158786333033, 0.026309147011488676, 0.04457570326381496, 0.032177284093839784, 0.028069421216579418, 0.021302671371293918, 0.012980152686525668, 0.015494401433638163, 0.032932171265461614, 0.06604663774903331, 0.01872960551242743, 0.04937116129856024, 0.050062734367591996, 0.052140788574303897, 0.03230809886008501, 0.07123516433473144, 0.025653308989214044, 0.05734423614506211, 0.03085062260340367, 0.0447154509435807, 0.04720771685242653, 0.03631454958979573, 0.020696556395185844, 0.028522205938185965, 0.0671347975730896, 0.0566250263447208, 0.025738868862390518, 0.060708433123571534, 0.06373674169714962, 0.029849355973835503, 0.018614760067846094, 0.03947487732927714, 0.02866368388224925, 0.023406920422400748, 0.04023453460208007, 0.03687129096527185, 0.1280372781412942, 0.13496267795562744, 0.13111250741141184, 0.14707211245383534, 0.11216720579458134, 0.18658605643681117, 0.10421715024858713, 0.08600532463086502, 0.08915991535676376, 0.227726476000888, 0.1610205668423857, 0.09211386327764817, 0.16199498384126595, 0.08821253797837666, 0.08011494177792754, 0.08392485483948674, 0.14548670181206294, 0.12927742302417755, 0.09254693146795034, 0.11823858107839312, 0.1440470540629966, 0.1359874965356929, 0.1063416637480259, 0.15566293575934, 0.09294249702777181, 0.14026852324604988, 0.12994491149272236, 0.06932595678206001, 0.12535672555012362, 0.1809265044118677, 0.11234310242746558, 0.2554379818694932, 0.12643905675836972, 0.1655027927564723, 0.14563253255827086, 0.09366972371935844, 0.05375198354678495, 0.12317822101925101, 0.06314436705516917, 0.16156424981142792, 0.12671325275940554, 0.07553780238543238, 0.15373938397637435, 0.1963913624307939, 0.11324681607740265, 0.11650777395282473, 0.1504117396793195, 0.08670087730778114, 0.13712869744215692, 0.15997893416455813, 0.10205815359950066, 0.17408953128116472, 0.10732255397098404, 0.18859894414033207, 0.12679752680872167, 0.09876429356102433, 0.18301190036748136, 0.10271553189626761, 0.08766443774636302, 0.1514747597809349, 0.12155809652592454, 0.12538860312529973, 0.11202445559735809, 0.1423643957823515, 0.09599847625941038, 0.13862078237746442, 0.06993228210402386, 0.28098542243242264, 0.13913311702864511, 0.22447695822588035, 0.14883920763220104, 0.08857575098850898, 0.15837128114487442, 0.20243268539862974, 0.10443825088441372, 0.17581188386040075, 0.11703827977180481, 0.16166685787694796, 0.12483637061502252, 0.14708723021405085, 0.14443419900323662, 0.0887678646083389, 0.12583469918795995, 0.10179318567471844, 0.09767998103052378, 0.11237972974777222, 0.1018198656716517, 0.11137034783938102, 0.05872590307678495, 0.11125296128115483, 0.15755360573530197, 0.0842158445822341, 0.17209086567163467, 0.09666240920445748, 0.10168556323541061, 0.11245054166231837, 0.08570372938577618, 0.08345783954220158, 0.1407760131571974, 0.19607995556933538, 0.20835067784147604, 0.15219213414405072, 0.14363640466971056, 0.19710763756717953, 0.1294767087591546, 0.26239999543343273, 0.11064429501337664, 0.1288714012397187, 0.1264852514224393, 0.15563736855983734, 0.17637213665459836, 0.0932938763871789, 0.15985226524727686, 0.11980603768357209, 0.14965173974633217, 0.08653745214853968, 0.15179763388420853, 0.12153178293790136, 0.11802670173346996, 0.06184421253523656, 0.162322675543172, 0.15711995400488377, 0.0919999915308186, 0.0981910400358694, 0.17191440585468495, 0.1122747603803873, 0.08366924391261168, 0.11226034151124102, 0.10265944419162613, 0.07694416120648384, 0.12785013818315097, 0.0925306873396039, 0.12819380259939603, 0.12092272990516253, 0.1551790860082422, 0.12612260159637245, 0.07950093543955258, 0.10245105930204902, 0.08949538306998354, 0.15617520255701883, 0.09023571227278028, 0.11761371817971979, 0.09512305073440075, 0.16258921766919748, 0.07507591681288821, 0.09015589619853667, 0.06793810839631728, 0.09031197960887637, 0.1602636067462819, 0.15393852043364728, 0.10621737648866006, 0.23610673631940568, 0.14133915651057447, 0.18862958678177424, 0.17853872611054353, 0.12265927743698869, 0.2119877612484353, 0.1513734816440514, 0.1497497744858265, 0.11135493152375732, 0.10853049558188234, 0.17255103455058166, 0.11637094058096409, 0.07049048572246518, 0.16365386625485762, 0.0908277476472514, 0.1623997978333916, 0.12144961234714303, 0.2344652515436922, 0.08375003029193197, 0.1381327664213521, 0.16995242184826306, 0.09900525491684675, 0.16507986187934875, 0.14359688679022448, 0.11286969309938805], [0.04229137101875884, 0.03876264286892755, 0.05011513423440712, 0.016553430053006326, 0.03303451130964926, 0.031455149807568104, 0.04407801139833672, 0.024269575918359414, 0.031327714145715745, 0.07004181122673409, 0.033573190082928965, 0.026441919351262704, 0.023532547788428407, 0.046042020831789286, 0.012821777524160487, 0.022994713791246926, 0.08891923220029899, 0.005941977383502359, 0.019185299452926432, 0.03232968645170331, 0.05420279542782477, 0.02092454755412681, 0.03357641651694264, 0.048124190353389294, 0.03349335704530988, 0.011696961542059268, 0.02790857957942145, 0.013124985986256173, 0.01686674359786723, 0.03507473718907152, 0.007157830288633704, 0.06509432742106062, 0.018875485452424203, 0.08800909960908548, 0.07778126985899039, 0.026294392267508165, 0.02769924813349332, 0.05066334642469883, 0.030107911742691482, 0.037899390262152464, 0.006896397531298655, 0.041766907554119825, 0.04519984352269343, 0.025701449352449605, 0.02078781765885651, 0.02530158866596009, 0.0012802058024265403, 0.031295354810676405, 0.04848660269219961, 0.02942170588565724, 0.020419225562363863, 0.11473985096173626, 0.0223868176607149, 0.038730816183877845, 0.04967733665502497, 0.0466449534786599, 0.02568459793526147, 0.01620294466348631, 0.056456101659153185, 0.04576093770031418, 0.043504863046109676, 0.023253515529047166, 0.01731915003620088, 0.012097590669457401, 0.02622303243593446, 0.02226586370462818, 0.026108470279723406, 0.04037160885387233, 0.002848354937408918, 0.013959261755059873, 0.04911752490858946, 0.02002858107776514, 0.018864469436396445, 0.03926835162565112, 0.014321163496268647, 0.05310444400778838, 0.036289067207170386, 0.016975253221711943, 0.00677371839992702, 0.06382271208401237, 0.05633879991780434, 0.014032671610558671, 0.04678481311670371, 0.029616849164345434, 0.0502928120217153, 0.04450817206608398, 0.01791531259992293, 0.0344576977991632, 0.024503346499321715, 0.025569735527304665, 0.0348447681005512, 0.027961893772174205, 0.024182830305237855, 0.04274956536080156, 0.004541709262412041, 0.013497408412929093, 0.018687191984749267, 0.03652883434135999, 0.04387400984498007, 0.04515005262302501, 0.032539441982018094, 0.029693710218582834, 0.030670556372829845, 0.07040113623120955, 0.05663394229486585, 0.047018853415335925, 0.00398554209719545, 0.02993657486513257, 0.023635043895670345, 0.0409652761050633, 0.04655924093510423, 0.04709433025813528, 0.022230381412165504, 0.03248272663248437, 0.032347243545310836, 0.042632894657020054, 0.04654711551432099, 0.05426032841205597, 0.06074202739234481, 0.03379904046388609, 0.061956937557884624, 0.020325815039021627, 0.017292775380026017, 0.0075027016490431765, 0.04397532869396465, 0.07360238981034074, 0.04687501756208284, 0.07883468190474169, 0.08515721692570619, 0.040429206298930306, 0.03337152947538665, 0.02805690054914781, 0.03383091125371201, 0.06290778225021702, 0.020858712693942443, 0.05335097613611391, 0.029458879426653897, 0.010332889023369976, 0.06183153071573802, 0.04658500490976231, 0.031971986538597515, 0.05837303772568703, 0.045474355042512925, 0.034603528545371125, 0.016248934070712755, 0.09592583230031387, 0.06055833439209631, 0.02767844424982156, 0.09767737545605217, 0.06040174886584282, 0.045355373926992924, 0.028793077117630413, 0.04655049801138895, 0.016607317607849836, 0.11297561241579906, 0.031227480952761004, 0.04479482597006219, 0.0441117074473628, 0.011103342636488378, 0.06985740576471601, 0.012856426914887769, 0.027852953278592656, 0.01978691913453596, 0.0673510195421321, 0.028106840726520334, 0.036261915628399165, 0.037086566377963336, 0.04756722506135702, 0.0419311842748097, 0.024187454521389942, 0.019127522196088518, 0.026995770167559385, 0.10334852364446435, 0.01986311183177999, 0.03180825264592256, 0.00995804846752435, 0.018625794743586863, 0.037384483963251114, 0.0699611809104681, 0.03911249891721776, 0.026741059995921593, 0.025504019410748566, 0.03980765804382307, 0.03268075029232672, 0.013968463538081517, 0.06420214208109037, 0.01234813463608069, 0.021091762331447432, 0.042815352723534615, 0.04611485478069101, 0.03263830114156008, 0.0672140708193183, 0.06922383047640324, 0.01210830219289554, 0.030113211101187125, 0.024060183404279605, 0.04707988764026335, 0.009710007446951099, 0.020259722335530177, 0.03879659676126071, 0.025417719934401766, 0.029137437032269578, 0.03386398644319602, 0.0151492120099387, 0.07301973857517753, 0.01175879389380238, 0.01672146076868687, 0.03376324774165239, 0.04034723248332739, 0.05043230525084904, 0.04401823246319379, 0.033558092678764036, 0.06542450256113495, 0.0519295334815979, 0.03873912484518119, 0.033941634598055055, 0.058771934892450056, 0.03184495460508125, 0.04585444661123412, 0.025677400375051156, 0.04343832250950592, 0.023340956640562842, 0.030747644736298492, 0.05766744273049491, 0.05791249565247979, 0.041460854333958456, 0.04267888915325914, 0.1007054533277239, 0.04128584658194866, 0.06605077681264707, 0.03883830630885703, 0.05451656359114817, 0.07352899267737355, 0.03487896626549108, 0.04664577450603247, 0.044171354068177085, 0.039420916831919124, 0.02216085701781724, 0.016236652586875216, 0.019225419532241564, 0.04449479474819132, 0.06609590617673737, 0.007990487751417925, 0.06364999099501542, 0.015571496582456996, 0.01631715228515012, 0.04278943607849734, 0.02143231057561934, 0.032321279402822256, 0.05006253419976149, 0.008948443490745766, 0.06281992553600244, 0.0552880680853767, 0.04053423673446689, 0.004361052282287606, 0.04702108918822237, 0.06513838469982147, 0.05527697743049689, 0.05616034520789981, 0.03212406998500228, 0.0661036754027009, 0.03405518064807568, 0.015335125516035726, 0.025203017883801034, 0.0029620693489310463, 0.019252564325662594, 0.043499417802585025, 0.03270765420581613, 0.06309138025556292, 0.03602452336677483, 0.06449243293276855, 0.017807875061407685, 0.041251641631658585, 0.04264223808422685, 0.05653970056612577, 0.04393712377973965, 0.02506099032637264, 0.02802451916172036, 0.03826515117127981, 0.07152916677296162, 0.08427690594856228, 0.026966040155717304, 0.012145025356273566, 0.05978755932301283, 0.009108480215737862, 0.03073105794776763, 0.01817712533686842, 0.019054345587002378, 0.050810079622481547, 0.015148299380338617, 0.03038862846525652, 0.03948656509497336, 0.027429213248459355, 0.042228575995458026, 0.05206582402544362, 0.03688794221462948, 0.04215576918795705, 0.046747151030493636, 0.05990734789520502, 0.05568038685513394, 0.059893139371914525, 0.02687338619892086, 0.024286729283630848, 0.03614718892744609, 0.057204953261784146, 0.03128105807783348, 0.015111697505095174, 0.00937172890241657, 0.02319451860551323, 0.025874358734914234, 0.05484172096475959, 0.06288034229406289, 0.054364561568945646, 0.027587925981996313, 0.009450092911720276, 0.05418535368517041, 0.061441691991473944, 0.01272337552758732, 0.04605592740699649, 0.042019834874996116, 0.031069334795964614, 0.04592912956806166, 0.025597906604941403, 0.027355741476640105, 0.03152311866038612, 0.012699091607438666, 0.04122762827734862, 0.0232133360779179, 0.06355819877769266, 0.0037143537026297834, 0.03819447157106229, 0.010517422558872827, 0.04056252146671925, 0.048980440478771925, 0.004947991858768676, 0.022632318415812085, 0.0432006215144481, 0.054449263095323525, 0.016033670532384088, 0.019222947968436137, 0.08648619561323098, 0.031512828676828315, 0.025374963746539185, 0.02922888319673283, 0.011054741717608911, 0.016483785218692253, 0.0431269224333976, 0.03322704562119075, 0.06022576402340617, 0.03551439056172967, 0.03503053402528167, 0.03490854360695396, 0.08580886838691575, 0.0732615820265242, 0.09511457583201782, 0.05542160038437162, 0.07464759836771659, 0.12718079052865505, 0.15708271600306034, 0.12940299271472863, 0.09584837752793517, 0.10869234653988055, 0.10167290177196264, 0.10304235507334981, 0.2199051385479314, 0.10047625776912485, 0.08085077229355063, 0.11826161055692605, 0.12837307155132294, 0.0626154625788331, 0.0856912172000323, 0.12466065718659333, 0.14062562265566417, 0.10324919290308442, 0.14325590937265328, 0.14943569419639452, 0.10754078440368176, 0.14225162326225213, 0.1457135360687971, 0.13527724679027284, 0.10754408208387238, 0.16508870997599193, 0.05692956982446568, 0.11775976605713367, 0.14969352393278054, 0.10894928061004196, 0.2658657623188836, 0.1089877128334982, 0.1369781033801181, 0.18111273513308593, 0.12211172681834016, 0.1300753802061081, 0.11619456218821661, 0.2106918679284198, 0.1345333145665271, 0.10084599828613655, 0.14522443445665495, 0.12114116389836584, 0.12231649511626788, 0.19711636352751935, 0.12044981813856534, 0.09683296576674495, 0.09831616867865835, 0.2395401235137667, 0.08693273272365332, 0.09513036534190178, 0.12758469528385571, 0.14144700286643846, 0.15493526123464108, 0.10490101855248213, 0.14692876514579567, 0.09695668984204531, 0.11477689897375447, 0.07268412836960383, 0.11338210238942079, 0.08286728337407112, 0.18855241020875319, 0.16102421736078604, 0.042396455737096925, 0.1473925438310419, 0.06009661166795662, 0.09127213380166463, 0.15532839085374558, 0.13143082175936016, 0.11202955818069832, 0.12106481513806752, 0.05729905928352049, 0.18160080537199974, 0.09839206282049417, 0.10982341013316597, 0.09183166734874249, 0.14632313192955085, 0.1268097132976566, 0.17007307894527912, 0.08272032625973225, 0.07701212327395167, 0.09745701442339591, 0.11286524190966572, 0.11055122036486864, 0.14314392395317554, 0.10992236089493547, 0.107524492777884, 0.15897300599941186, 0.1412289488528456, 0.14798506775072642, 0.18798206081347807, 0.1500977272433894, 0.08649856530662094, 0.052069362585565875, 0.19751911477318831, 0.14647296603236878, 0.10803497502846376, 0.0666695668229035, 0.11009029152670077, 0.11826132557221822, 0.16250453649887017, 0.12777624571962015, 0.08814886425222669, 0.1528152192809752, 0.25760885966675623, 0.07208317704498768, 0.0998224892786571, 0.1000323873013258, 0.11298251990228891, 0.19879894038396223, 0.06490088387259416, 0.1535406546401126, 0.10259089179869209, 0.1110517145799739, 0.14448926890535013, 0.14970216846891812, 0.10749112921101706, 0.1515630100454603, 0.1489506366529635, 0.15477493698043482, 0.1174484406198774, 0.12839599246425287, 0.16003700319145406, 0.08977505484861986, 0.11132884185229029, 0.22020954292799744, 0.08597954030015639, 0.13297116410519394, 0.12763272199247563, 0.19951578548976354, 0.09996971780700342, 0.1287547339286123, 0.2149233887238162, 0.1363021603652409, 0.0991833500031914, 0.13371660267668112, 0.18814106870974812, 0.1587286383977958, 0.10544008748339755, 0.10121815438781466, 0.14365775138139725, 0.08111533988267183, 0.18315066077879497, 0.13284700576748165, 0.09221725844378982, 0.13803368673792907, 0.16147597240550177, 0.13932451818670544, 0.07949985656887293, 0.17303534570549214, 0.1858626159706286, 0.13740843028894492, 0.08015070057341031, 0.13844580176685536, 0.16904520695762976, 0.047183988482824395, 0.09778043814003468, 0.19185444659420423, 0.08793726310666118, 0.1637576006885086, 0.13997398476515496, 0.21514535109911645, 0.11605012922414712, 0.11197165200220686, 0.10377866734883615, 0.1293541110519852, 0.15682514410998138, 0.1691910241331373, 0.09395553623991353, 0.18794916543577397, 0.13399185719234602, 0.1319438756576606, 0.1084702213161758]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.04094699976433601, 0.05360101289781077, 0.03852198685386351, 0.03224693910617914, 0.03556740789541176, 0.06965204035597188, 0.0247857968788594, 0.02641995178003396, 0.034481965604105165, 0.008397739380598068, 0.03944764771897878, 0.06213859495307718, 0.03463175899482199, 0.03029190329834819, 0.033211249325956614, 0.07395649688052279, 0.0362667196563312, 0.014335134532302618, 0.024401961493172815, 0.06212667987814971, 0.03758648044562765, 0.04096920821549637, 0.004581153775299234, 0.03392297488504222, 0.07050385964768273, 0.011590104150984968, 0.036671632036034546, 0.001113649522137296, 0.03927827180762376, 0.025417423075331107, 0.07462581060826778, 0.056379328814468214, 0.015268215177846807, 0.027552391103069698, 0.00792451888056738, 0.012337606317097587, 0.01110576415833618, 0.052325390811477385, 0.052939936585192165, 0.10594643745571375, 0.03331854946113058, 0.03036754298955202, 0.017115262137459855, 0.024992846750787327, 0.07142462488263845, 0.04980870781998549, 0.08828018791973591, 0.019714695867151022, 0.06764550374022552, 0.06309249983834368, 0.05077700104032244, 0.05802045735929694, 0.03164342970454267, 0.0835859469537224, 0.06184812089694398, 0.051049103760825734, 0.041613843624613116, 0.045754277879106145, 0.018981140140177946, 0.06320092294897352, 0.018139770287754278, 0.030795518774539232, 0.034637835275913985, 0.037578164998974116, 0.02978788409382105, 0.06974725238978863, 0.0763616728197251, 0.018305407471156547, 0.029267586834196533, 0.012946219150243061, 0.01689610380812415, 0.03239643054881266, 0.037988441197999885, 0.023060796316713095, 0.021677122617672597, 0.04163169248827866, 0.03216511456828032, 0.11174253108245985, 0.05582353060266801, 0.046182514900075536, 0.019479047440524613, 0.027998877323365638, 0.007563727392282869, 0.01886726330433573, 0.013734569972647088, 0.013718792337125965, 0.02219781682028302, 0.06085507132645164, 0.025009347026103308, 0.0023767754319123924, 0.023365811378295933, 0.07023004362625734, 0.044228527428848405, 0.029396257429782833, 0.06277238058724574, 0.06986446252890996, 0.08016132643180233, 0.04549920638757093, 0.03311404239918504, 0.09711429317082677, 0.0063407914297256085, 0.019279715904433812, 0.015231418223785502, 0.028631958977452347, 0.07418827087219272, 0.0498917876476688, 0.05629623541608453, 0.036431111727974246, 0.059068488622350354, 0.03057492703997663, 0.051242336963436434, 0.08976227803421871, 0.03634512437773602, 0.018366950597347956, 0.06115647658173527, 0.09292957093566656, 0.0416582808829844, 0.018294981780595014, 0.0686295966484717, 0.04967187784079995, 0.022505764849483967, 0.00441940374938505, 0.03037367355344551, 0.02108754523630653, 0.03380936437419482, 0.02991692109831742, 0.028242138912901282, 0.042322088299053054, 0.037371184676885605, 0.006454227641890091, 0.04518003708549908, 0.02214235845687134, 0.012814626613232707, 0.019788081125755395, 0.02271847370346742, 0.00832441943098924, 0.031040096722011055, 0.08915646839886904, 0.031472771362002404, 0.05160569246592266, 0.03964971544753228, 0.06636676378548145, 0.011138359284294503, 0.021613627006965022, 0.05798674773957048, 0.08198154411677804, 0.01987742552799838, 0.010677073367073067, 0.055348104863826714, 0.03350636795429247, 0.043154711835086346, 0.08902513116065945, 0.018426256254315376, 0.07546970461096082, 0.035033282092107196, 0.04678060619958809, 0.02065000041121883, 0.028238853107073476, 0.022999824856274893, 0.07061888490404401, 0.02741985964322729, 0.12211935355194978, 0.054750851555062194, 0.050439653785101006, 0.020038138243502805, 0.06277187168598175, 0.022811468624110733, 0.03645596307303224, 0.03947404951655439, 0.04240751585790089, 0.0404303123110107, 0.0121144972176158, 0.05751912176076855, 0.02445296527418707, 0.07053853957248585, 0.04226879615868841, 0.06393161016915526, 0.034203861241361926, 0.02971007309055754, 0.03315076810706939, 0.005109330522827804, 0.10041124054363795, 0.014643233535545213, 0.02776945784821042, 0.018519680348357985, 0.047405021265149117, 0.032435144364301643, 0.029594006282942634, 0.0030373273641868892, 0.04544036043807864, 0.045581756957939694, 0.03573610866442323, 0.018961632258391807, 0.054931901661413055, 0.03189368699012058, 0.07589425040142876, 0.03181758928777916, 0.02423936245031655, 0.04691368727279561, 0.011299585990075554, 0.0262408083570855, 0.05401750108493226, 0.010044633776747754, 0.011401286515008126, 0.04108863377145358, 0.04726033385044762, 0.04557222693360277, 0.01815372096773769, 0.019192310416006615, 0.025257529690861702, 0.02331730121347521, 0.019764003310618655, 0.03485150595328637, 0.06022841030997889, 0.03616346698254347, 0.03778855495953134, 0.07732888377670731, 0.008503529775355543, 0.06957877214465823, 0.05445414176210761, 0.012879914404558284, 0.014286902566839541, 0.014141090480344636, 0.02324592272218849, 0.027114155868600522, 0.02967357129922935, 0.0840815082192421, 0.03759203425475529, 0.029011056492371217, 0.014391834614798427, 0.02074054751678237, 0.026589336173076714, 0.08406761182206017, 0.00584810460817867, 0.05152512661048344, 0.09269151370972395, 0.007947273552417755, 0.039586632046848536, 0.044189501487250836, 0.020463343909276382, 0.03536290761881641, 0.018550845461764505, 0.07629180406885487, 0.08166942479354994, 0.03999474032648972, 0.03176625472094331, 0.014485991526661175, 0.025075802745829736, 0.005754691540330116, 0.025862657398517643, 0.01632101654208132, 0.06819499496902738, 0.07244125354502882, 0.010268877726048231, 0.05118553340435028, 0.037587986793369055, 0.05251968592139227, 0.033603310252406766, 0.02641097136906215, 0.031340867547052245, 0.03628256005634155, 0.03259310392396791, 0.06742894928902388, 0.038364166393876076, 0.04762371988700969, 0.02305921702645719, 0.06711203272321395, 0.11090559206370797, 0.016076828752245222, 0.022143043777240173, 0.05660413425149662, 0.013730006824646677, 0.05840898651097502, 0.02370367940914418, 0.012931973307526537, 0.013289339042135646, 0.012247103316310261, 0.06973409559577703, 0.0308907715204571, 0.025339405118886913, 0.04463071549045188, 0.022643809406352893, 0.06491046478705746, 0.06210933652307306, 0.035711766220629215, 0.02778200226436768, 0.05357671455879297, 0.005410539427040411, 0.03431840134518487, 0.044671597225325446, 0.01612257049418986, 0.05290937536795225, 0.030142025090754032, 0.0816767733278019, 0.06608458821262632, 0.0233141171879002, 0.02998326825244086, 0.05523378528388483, 0.03526734274678996, 0.029794747475534678, 0.03561487141996622, 0.03394368038113628, 0.04318546304213149, 0.05421034073723214, 0.03618947522980826, 0.08063358680478164, 0.06509133508162838, 0.0370908547192812, 0.013336715205306453, 0.03171985649636813, 0.00927561950603766, 0.033667811791279485, 0.02538187801837921, 0.016180145886859724, 0.04892696852662733, 0.039228067001593966, 0.04548030240195138, 0.14318182691931725, 0.018477768936593617, 0.055845454069120545, 0.04651648983625429, 0.04756716060053025, 0.09479326914463725, 0.03797324540625725, 0.033071077561804225, 0.017422019337703074, 0.02073092249754284, 0.07303328891949994, 0.06387281510978937, 0.08112557219075305, 0.049821569451263974, 0.06481954109455858, 0.06227793890450682, 0.017023707407393625, 0.01621980795503727, 0.019796325326231972, 0.05367552622088364, 0.07501177489757538, 0.05599650953497205, 0.02792771426694734, 0.02585968711147351, 0.05191438518730657, 0.05427144281566143, 0.019102604693866203, 0.0494445278974516, 0.05271582664655788, 0.0430456916136401, 0.03909252963161894, 0.019718668689685206, 0.03187518334016204, 0.052317591051438024, 0.05663637823558279, 0.1731515380420855, 0.19550807268491813, 0.09161677530833653, 0.10591740294226579, 0.16922919851328644, 0.31104351952672005, 0.1158267283546073, 0.14416041012321199, 0.11780209307159696, 0.12538890168070793, 0.10917455423623323, 0.11130908969789743, 0.11482483068747179, 0.11114362214824983, 0.19735406791525228, 0.11237618779497487, 0.07511835239295449, 0.16970873278166565, 0.07792075630277395, 0.1269541462617261, 0.09453938848205976, 0.14973487385681697, 0.11038183766816344, 0.13558154260473593, 0.17934127018920012, 0.11877542441444737, 0.11508019055638995, 0.07438558885561568, 0.13327982968517713, 0.1275765664343323, 0.1626381536147424, 0.09847211638199431, 0.09175583427505833, 0.10309564721371446, 0.10501404213053839, 0.07532707655004092, 0.11258415877819061, 0.11930001340806484, 0.17221011141581194, 0.20280775241553783, 0.16987886865224155, 0.06380462912576539, 0.1780949913497482, 0.15519341666783604, 0.177546979327287, 0.09336724637874536, 0.19778435411197798, 0.16291640725518974, 0.11907731821494442, 0.07442542564656053, 0.21504069385784014, 0.17320032470992633, 0.10487163120082446, 0.09986542018928699, 0.16027850737529142, 0.08965747151523829, 0.21990440573011125, 0.1193847760025944, 0.13168551666396006, 0.2557479366660118, 0.13174138723739556, 0.09347368138177053, 0.0732132364064455, 0.1624201267425503, 0.13866077523146356, 0.12135274468788079, 0.18382888367133482, 0.11941009892949037, 0.28358318018061773, 0.08449238152908427, 0.1275079801146473, 0.14285199104675225, 0.09420792412545, 0.14947408570774964, 0.09791664725967816, 0.17678540519305638, 0.11042589494692427, 0.1984011424439294, 0.09589544750217881, 0.13342192848878248, 0.19867153864886078, 0.07020206084208828, 0.0829496303839343, 0.10225395166448184, 0.12769252806901932, 0.12619475701025554, 0.10813030919858388, 0.10166173308555569, 0.18111026526561805, 0.09740216165248837, 0.12025058668638978, 0.17745136017245905, 0.22168771789542266, 0.17733685060271195, 0.19074880092271737, 0.1033083882981113, 0.1345289040889059, 0.10630684811621904, 0.08329023460724524, 0.12405832165053912, 0.059390297425644736, 0.12413460255733558, 0.09942973285381283, 0.11221203660326344, 0.09452093232955251, 0.13207393725003513, 0.152357370991792, 0.17106456788522856, 0.12520941559757504, 0.17416757637900965, 0.13907792499022825, 0.12983173185161181, 0.09185865268643413, 0.16444741295916693, 0.2239383506987776, 0.14327322558632918, 0.09643860121390649, 0.18526813787009033, 0.19082657460655483, 0.1495620645582676, 0.07175044382789306, 0.1443235163709947, 0.15352868528238364, 0.0877268493973783, 0.13075284313942703, 0.17193929451916898, 0.08557077044887201, 0.24312951947961534, 0.1370304184300559, 0.14155921898782253, 0.19981717717434677, 0.07617789160992418, 0.11865780715431486, 0.07135091562356267, 0.10949217647846256, 0.1216679649161441, 0.11245395469346217, 0.20021559936659677, 0.14113856798836164, 0.19301110452839307, 0.13752729605351174, 0.2101359577583415, 0.09199477359652519, 0.08290155617786304, 0.09049601866198437, 0.17536603207034723, 0.20306710207036563, 0.09427861390369278, 0.11257657275668212, 0.1063415619677731, 0.10502702929079533, 0.16389637467052254, 0.13232172466814518, 0.19392415482018674, 0.14075504642512116, 0.09805347384618861, 0.10850092502576963, 0.13021365207220825, 0.12371016533247062, 0.2232475070548909, 0.13410848379135132, 0.1988729007009949, 0.1607145204075745, 0.15211630107036658, 0.10625384096056223, 0.1943010538816452, 0.14021757883684977, 0.08490708856178181, 0.20954328456095286, 0.18720960297754832, 0.1185020562261343, 0.17355034021394594, 0.1196319255977869, 0.14178578183054924, 0.15657460183969565, 0.20917158307773726], [0.011377611580038709, 0.018814965217773403, 0.05276926127927644, 0.0050458438178923514, 0.06118588428944349, 0.05221662504066314, 0.02147697175054678, 0.05662607807399971, 0.019750563228236775, 0.04563762413870011, 0.012289575367633785, 0.004972464496469391, 0.02536762030129986, 0.021118879983467714, 0.05049234202929905, 0.05776435110185828, 0.0631423993036151, 0.012318926248034196, 0.01420801184472761, 0.026493710232898593, 0.06138251016714743, 0.04321100310023342, 0.014916644132296954, 0.024255659165126935, 0.06633473014725105, 0.017830390549663986, 0.05564149322786501, 0.01006883372818785, 0.04496636640812669, 0.04594468159068908, 0.04628992360085249, 0.01182745145966432, 0.028649380364056145, 0.02029145572201482, 0.08294486706810338, 0.05630296648346952, 0.01134173828177154, 0.03950419682743294, 0.08147617123488869, 0.030515640042722225, 0.02519358624704182, 0.03576245617919734, 0.018053788026528697, 0.022592054147805487, 0.03151433163189462, 0.030687940440007618, 0.028750631359538863, 0.03935621173254081, 0.017797468030559163, 0.09887452836015395, 0.02190187037922442, 0.045256036400262795, 0.058363171826515875, 0.08439087947564465, 0.030357293718095337, 0.010268254321999848, 0.09348060922431094, 0.015514879620500972, 0.024674389910485064, 0.02566614347909178, 0.09550144935825042, 0.02441564415182386, 0.030799057334661484, 0.03629146243578621, 0.014794389085311974, 0.02492214340184416, 0.02513691160960921, 0.02643212130559342, 0.06206888226526124, 0.032248072259660275, 0.04039485885628632, 0.03529974618660552, 0.02845335329350616, 0.022678412995966415, 0.01623217934476478, 0.0359521474290107, 0.02502974378876388, 0.020448502652080994, 0.018191377964935133, 0.038148317619093826, 0.027235159018476094, 0.04995466409517186, 0.028573418368718455, 0.07935514540544578, 0.013475474768451281, 0.01333981441400413, 0.04526452487334609, 0.016343520155974796, 0.073930088297597, 0.04556910567251699, 0.015710265475458333, 0.0195441918913275, 0.025378775417006443, 0.03628079925796815, 0.026875672861933708, 0.01968720502087048, 0.029816385957279375, 0.058578593124236376, 0.015390415942030293, 0.05031395178022129, 0.03656133616875325, 0.05923862449292626, 0.01879562866607947, 0.026548215254609073, 0.004540716056778494, 0.019999181851744652, 0.06627253562744174, 0.00919695694132575, 0.01891646727121302, 0.0651362608852131, 0.04364470911345311, 0.04712881680045809, 0.05442091729491949, 0.05840172618627548, 0.03301695082336664, 0.02681043341622821, 0.046030044688710144, 0.008667217018747968, 0.05655667072694216, 0.029404036833771637, 0.061864765360951424, 0.021559927745589187, 0.06764441808419568, 0.04243247916123696, 0.07342819630035333, 0.03456565272063017, 0.06240486566509519, 0.015939269347914627, 0.017030689532735517, 0.004504182035036917, 0.05270984875304358, 0.030907565262168646, 0.09897997270205192, 0.035832297788666825, 0.05618770034717662, 0.007866583016168858, 0.024307645125580684, 0.09703713016850607, 0.0838591047961797, 0.03347639027716858, 0.022007134909342443, 0.07676196776862655, 0.03166724628369723, 0.07133586571684905, 0.024652703931289058, 0.032127581403723786, 0.07437446088130985, 0.0951812554683004, 0.021742991404607892, 0.03956045077315398, 0.02011922657090638, 0.017557929901938354, 0.024628839854683195, 0.04597542940505913, 0.00815654986737562, 0.056055443694016764, 0.055333648675254414, 0.014282081575532044, 0.036100865341722965, 0.03217151315350618, 0.01046465543497886, 0.02543879862475608, 0.021810760089595402, 0.007277746086141893, 0.05170782555692962, 0.034902925336999555, 0.0651427883920925, 0.037346360473228354, 0.04048642376437783, 0.048398145474493504, 0.10982165272746768, 0.025186933211183975, 0.02120614467587854, 0.048027923197618554, 0.05762498000902789, 0.020915085383291756, 0.03643528811101403, 0.009930407495370932, 0.04399421571620873, 0.012887559797880905, 0.01635944198018738, 0.03614240525556462, 0.02924410273720111, 0.05874534310506923, 0.04354766503508602, 0.03328406631148287, 0.05309830665854471, 0.0461308241023549, 0.012289722100831568, 0.043695639951952865, 0.06363696312265736, 0.08339980444205658, 0.042303703392722776, 0.03266262322930353, 0.021799477748572826, 0.033362094445952346, 0.03863648624558534, 0.03522984350898436, 0.04032061016187072, 0.02496674350861992, 0.02493855037859508, 0.00821023725438863, 0.07165427505970001, 0.06391249583767993, 0.0061699486104771495, 0.06715043101991926, 0.016869637549721768, 0.030069957886423384, 0.012768904379169856, 0.03432834527588316, 0.06114073456930263, 0.035331684829933305, 0.04445734300783702, 0.026783753419294953, 0.031547776622963805, 0.02000843537306147, 0.062052102094250064, 0.0888831816347582, 0.026670222636312246, 0.013531248650646635, 0.036243568041494915, 0.0385532673182232, 0.040913483527089865, 0.03287819041205304, 0.0923284635479961, 0.08061456746820893, 0.025160665424274545, 0.05382968598444547, 0.028741365963859216, 0.05409053520166448, 0.018948378773140054, 0.024590237997472286, 0.010609883981357728, 0.026499155476423245, 0.0909180131607822, 0.036463342141360044, 0.046425915589290004, 0.017508513892867734, 0.021402207369517003, 0.02873451615284596, 0.02295244105958513, 0.02273053296708635, 0.04657173276479755, 0.030366616789251566, 0.07198445019977433, 0.04615767712571791, 0.04208283685147762, 0.03245762422946947, 0.015745576437828795, 0.048937621526420116, 0.04220390785485506, 0.08784697045172964, 0.017783359591183916, 0.07326937160853829, 0.1114515820518136, 0.028986683514501368, 0.027965288143604994, 0.06106516612427575, 0.03796491299622825, 0.04115702331598316, 0.05199563975578972, 0.010854832578583487, 0.02312038865472589, 0.015116491355001926, 0.019189740464623486, 0.036406189136739285, 0.010793615149201026, 0.02763282973319292, 0.0046904534683562815, 0.061352478207222054, 0.023423045807118927, 0.03028069729251521, 0.008099391773742224, 0.012441040499002805, 0.03987042253304805, 0.058332773457680426, 0.020649856222527366, 0.013044609272453402, 0.037940455201481066, 0.014006608232323612, 0.053809842227825096, 0.014334620542025991, 0.010824915969611278, 0.03508551911051784, 0.023188868105145435, 0.0424472203345171, 0.1264390160462686, 0.020085610249744992, 0.04152302171236702, 0.014476242674780744, 0.06617266884339706, 0.030251537250088792, 0.05115240393206477, 0.07688917951392275, 0.025860314756365757, 0.04146741237491369, 0.05075061959879739, 0.02909718972763845, 0.02618577068538538, 0.004129288468642959, 0.07811664257730756, 0.01646972258043076, 0.026160015192415034, 0.032937528299433846, 0.04368605225213936, 0.03295034243326102, 0.013892469312330442, 0.05262771887438638, 0.04715308460540005, 0.05751286566789661, 0.034963559226265976, 0.04160152482134955, 0.02881039333130632, 0.12311483227780887, 0.05054780887439847, 0.05615722394681402, 0.10575917536126715, 0.030264297101114477, 0.025408040632360747, 0.03780814765819481, 0.023271956414516484, 0.062283428252807686, 0.01008966560142913, 0.08445975078003747, 0.004930578953852611, 0.013243725373675781, 0.022705037013760636, 0.011179101919489247, 0.08102004642465285, 0.055935960462582965, 0.02489592820139868, 0.03464277840352484, 0.060359367568578036, 0.045098931794720035, 0.039897061817880185, 0.043111387374145646, 0.05918851468179907, 0.060628942746136866, 0.020797705610415766, 0.02998546331322619, 0.06059329251625708, 0.06703686461384807, 0.04976137660975967, 0.033275927283934185, 0.0752637285206999, 0.06001143516706569, 0.05713486737970795, 0.022466565881456648, 0.022752631156306182, 0.06500291518334832, 0.008136523754468985, 0.06069384462067059, 0.07772001171750681, 0.07336276516850505, 0.12283288740686008, 0.11345798296055623, 0.14877395970480783, 0.15167012358350412, 0.108258864443217, 0.10083467353667531, 0.09310212917625904, 0.07304001320153475, 0.18901579534368856, 0.15924960401441368, 0.1909032626343625, 0.11917471513152122, 0.17426075280777045, 0.17793340502040728, 0.12770043978733675, 0.11071446231965508, 0.13313493531729492, 0.09355819970369339, 0.12127275897988252, 0.11694031288581234, 0.1907623851937907, 0.11509639397263527, 0.16661617372717175, 0.08530457437570606, 0.10591532662510872, 0.11302994950009243, 0.16311149964375155, 0.09831654865826879, 0.12901772053114005, 0.12023694813251495, 0.10903122728424412, 0.08537516237369605, 0.18939268083444663, 0.12587163863437517, 0.0915500685306532, 0.2240279580333403, 0.173269372433424, 0.06977524195930787, 0.14396580627986363, 0.1625665138874735, 0.2278346616242613, 0.11444033203380448, 0.11568905359932355, 0.17593787424266338, 0.08081446388470274, 0.13475685114307062, 0.16777496226131916, 0.17273328905659063, 0.0927240698199187, 0.17085281067660876, 0.1819484324327537, 0.12800877967051097, 0.1815628209816558, 0.12766115260975702, 0.21104903519153595, 0.09200203392122473, 0.1515946433480297, 0.13137406909040042, 0.21903503952281816, 0.1057665306808693, 0.14710751841110842, 0.10448220638292176, 0.20199133908110006, 0.07822799017386776, 0.07715681408132825, 0.1149666987891708, 0.15706639045051166, 0.12673062325588294, 0.17025663623852388, 0.09268605828817401, 0.0848738607019186, 0.21674993714051588, 0.15060445719531604, 0.16089830840272562, 0.1640316474118403, 0.13371844829193183, 0.16759175780628408, 0.1241012593465192, 0.1750182964439903, 0.21717911053981098, 0.0789484450859683, 0.13605568930506706, 0.09730403870344162, 0.08356555019106184, 0.12428987851100308, 0.1498797410832984, 0.1128131439909339, 0.13130981182413443, 0.06405892369470426, 0.21655956735568388, 0.1161440113293273, 0.12822060473263264, 0.09603194160653011, 0.1209478492715529, 0.05991181944097791, 0.11449913387852055, 0.07093139099223272, 0.12495085304336888, 0.08248422321464334, 0.1606004179588386, 0.12262874336114951, 0.10592440542365823, 0.12812330281095846, 0.12378586269915104, 0.13449770504874842, 0.11183065242533173, 0.11213406614427056, 0.14980734139680862, 0.30526991933584213, 0.09202428308448621, 0.10790939176721231, 0.07350309978106193, 0.16834390030375548, 0.14362702731575283, 0.2694465544606958, 0.1516662152217967, 0.11261778018836464, 0.07183635993195431, 0.2844112643173763, 0.1372341282133545, 0.1190499732536929, 0.09048607812396117, 0.16176988663417952, 0.11815832395638738, 0.16036925464868546, 0.10506106460733072, 0.10684084160519497, 0.11493976094893046, 0.12157941609621048, 0.0684202414538179, 0.2044936812349728, 0.15272650761263712, 0.14030341351670877, 0.20485126918980054, 0.09464743839842932, 0.2627777765904154, 0.21188226262373583, 0.12688485426562174, 0.1548886051667588, 0.13441210107079574, 0.11898509173520974, 0.16932740967188561, 0.08625104251716818, 0.13636352707232746, 0.1702890566417149, 0.14450275818152086, 0.11710929524685655, 0.09436760377138853, 0.08814718827073063, 0.13449177465268544, 0.14573048587356294, 0.1443508341908455, 0.07347144612244197, 0.13036193911518368, 0.17750102893582412, 0.12941216650818074, 0.12440151109227113, 0.12967190971331938, 0.11339141867522683, 0.10459921974688768, 0.11285911473844733, 0.06132872948156936, 0.16453862163637364, 0.14658332296780177, 0.14175777190497943, 0.08970726920025689, 0.10997430275061301, 0.18213988787361554, 0.1789651039455618, 0.10092314771775689, 0.15192027230347904, 0.17317653527217253, 0.13038852411721433, 0.17943298098232063], [0.032882393936493566, 0.01608876757589834, 0.03200928560857262, 0.06073526239820889, 0.043772826702999215, 0.05427307129970618, 0.0193886869320912, 0.05139505823275872, 0.03080869253192629, 0.06933101865329913, 0.06680760798709733, 0.03525710704603365, 0.03977005024041448, 0.03321829591212528, 0.04809777159243822, 0.06330112221517734, 0.036834446513759236, 0.03005598685038941, 0.04005548278135913, 0.07285052551222698, 0.0467400874809495, 0.04644264826284988, 0.038304258537079604, 0.04529004796807255, 0.006210119579918683, 0.030585522364292825, 0.032530933152884245, 0.0688835180231503, 0.0249784007402403, 0.052302941480385404, 0.029042513375835757, 0.06657736748456955, 0.020370676381779567, 0.03898633550852537, 0.06348566338419914, 0.07203619528029646, 0.02241770287842623, 0.059101899686668596, 0.028837972387139286, 0.05466507455067975, 0.03709342636700187, 0.011027493447597538, 0.04842959896528295, 0.0648235444511686, 0.008949754759669304, 0.03836415960852589, 0.06592435216797249, 0.031595609949103425, 0.08236499782651663, 0.03719923372513481, 0.029886509158781598, 0.013723455569041627, 0.0026938552702111857, 0.0721798072169934, 0.014812059833535125, 0.0820140391588211, 0.0152104345283338, 0.01025305428941335, 0.06426123569586448, 0.061469098020877154, 0.019792286346533468, 0.02183805755339563, 0.03314565195302878, 0.015466311780203666, 0.01266596298332193, 0.03731071024334856, 0.05822864547371864, 0.061853562747793536, 0.019538290333002806, 0.08120074030011892, 0.05187793089342969, 0.030295343470892737, 0.01961072564258107, 0.0240088793715196, 0.06021253937589271, 0.04600168192493064, 0.021500233627323593, 0.08336158934980631, 0.015968975611031055, 0.009621726648349847, 0.0481135441389467, 0.04919495593224253, 0.04817318058173571, 0.03924391757962959, 0.037118030046778064, 0.04946708918682166, 0.05932031332382134, 0.04773012435595904, 0.021179636009037495, 0.052265805258814774, 0.0420566420070827, 0.030062985939106772, 0.05144927318074873, 0.025726996195901717, 0.03955513445128288, 0.03405154709305082, 0.07488776583756719, 0.01613372391355889, 0.01814082371337073, 0.048210476259035726, 0.019224466190540364, 0.05937351046928337, 0.007593576147753213, 0.00996956490312836, 0.04084979623023953, 0.010120901112843837, 0.020078426260235052, 0.02906123754967536, 0.09449214208871126, 0.01369601730922503, 0.011319508626391845, 0.007252630960595394, 0.03213903507483857, 0.0310844525561801, 0.009941952768713236, 0.06717919411935977, 0.01738792464935354, 0.0658321799710393, 0.05270030515800629, 0.06820880994200706, 0.013712290275309767, 0.022822345540459667, 0.003928221579241965, 0.0871220575645566, 0.042869683022477796, 0.018414173241970793, 0.020413205260410905, 0.03918165520631841, 0.04497330103601728, 0.0679770088089364, 0.027836215516020144, 0.021505275142512152, 0.032286463771015406, 0.05439892258229, 0.01355213056584554, 0.02083329307580633, 0.016527560905420353, 0.010971506675040084, 0.03126305654378874, 0.0231380797589996, 0.03676993140418615, 0.032031141221523285, 0.020078685799879686, 0.07489066318209682, 0.03254001873678394, 0.025402103450947573, 0.014774136511342866, 0.014986339856737425, 0.05421105319900172, 0.017013548041826913, 0.009451835050380655, 0.04057243147066661, 0.017100068042054772, 0.03349526033603719, 0.029319162280963998, 0.029875985080642358, 0.03187284917969789, 0.004925399187154004, 0.027344800099464397, 0.031318326613732746, 0.03280424027304564, 0.0335134281111615, 0.051006149101470194, 0.01766571349331311, 0.027528194544304694, 0.03247698283355151, 0.03980843496641942, 0.051435098584209166, 0.026811195071786642, 0.04396232117765716, 0.010540867640104677, 0.059862137106912475, 0.011943931325471826, 0.06518489827534982, 0.0034433326093546513, 0.049193836349461756, 0.038833013735711575, 0.06961145717650652, 0.06967649475804397, 0.014858334225469401, 0.05340968637860247, 0.024139877342219864, 0.010363200878990548, 0.029405678888516765, 0.02819929281914873, 0.050006049552134106, 0.021425104533721293, 0.008829084940121641, 0.03919357028124588, 0.05004257848486304, 0.048797795815127235, 0.03733027919328638, 0.06993642795298781, 0.02169705628018294, 0.047676425094583204, 0.009356552618555725, 0.014587866774361049, 0.03314855947558369, 0.06342380134654896, 0.018725646260593618, 0.009112957698692168, 0.046382984678660116, 0.01797118317335844, 0.03540887497365475, 0.053849017447126765, 0.03586366646257894, 0.06927489023655653, 0.022188778733834624, 0.008721470982501549, 0.05131817342979567, 0.03610633094129818, 0.052647817081638744, 0.0388678904356701, 0.04584394967449563, 0.08820481624986444, 0.047012553217687776, 0.02287867073235767, 0.03305549839777606, 0.07422199406261955, 0.057188824484390874, 0.022903515292065482, 0.025717488223952905, 0.0541876165994576, 0.03554254637232848, 0.07522909609334809, 0.07669196331075259, 0.031104934135718004, 0.0724254029669932, 0.020581636311752454, 0.028752636430518966, 0.01420714586441006, 0.07365296102528061, 0.011246198854808296, 0.05768093879201582, 0.042265237242515595, 0.07059196063450404, 0.03902686779786434, 0.03821416265730347, 0.0793484550501619, 0.037592068181506226, 0.030222000620727028, 0.015306873014196754, 0.03685841915596809, 0.12930533795484475, 0.08532135454671723, 0.009195656698596264, 0.03650944520320211, 0.027528678000505482, 0.0378044394643179, 0.05998941670571055, 0.06049607201878514, 0.029211482166179588, 0.03399834994758878, 0.021392124339139888, 0.03282981086522341, 0.07605073414742947, 0.061722252650984695, 0.018177128729543517, 0.04050703087289419, 0.06532965693622828, 0.06280275860003062, 0.02824421183738325, 0.01230454639465149, 0.007245084803019251, 0.07349298282393388, 0.04809961381501385, 0.022730855271220207, 0.05872859686080899, 0.02537901290426297, 0.025631860497274568, 0.011832545561316823, 0.030088729557714293, 0.060172797579850466, 0.049910786628190956, 0.033367851815585575, 0.012487659247459044, 0.028012247855908105, 0.04232361839552011, 0.03337268637759345, 0.02209163287521473, 0.034445840399712324, 0.04869428190535732, 0.017380099444250976, 0.022742670262232423, 0.04121331458113023, 0.024953445918591957, 0.03814768658152648, 0.036982909975839515, 0.02043985472326832, 0.010247161212776388, 0.012028854223899543, 0.040548614891512055, 0.06137607086982046, 0.06032221777630704, 0.06914125276463372, 0.032363145013472865, 0.0541632707629885, 0.07741028762289456, 0.010901423337470208, 0.139310893203531, 0.04316622657435281, 0.06187129965318101, 0.009779997485955911, 0.028173462687326328, 0.032035609374621084, 0.02364509130295898, 0.017822901219395653, 0.07245048162128244, 0.038583285707448206, 0.05430954594963363, 0.012826320316110338, 0.020346303403909718, 0.02894448202901653, 0.05902939143457583, 0.026475902081334164, 0.026212878159380386, 0.03652346034401229, 0.01875251964000719, 0.0033318406120607896, 0.040831357041107755, 0.04947509590004172, 0.026351725083908865, 0.04741810002763357, 0.02895204090912427, 0.026548369621325816, 0.032381384034774134, 0.06302041227796248, 0.0622806598299316, 0.025838186033070087, 0.03054716477968863, 0.0364110033426966, 0.02260528558066913, 0.010589793407624322, 0.0032139602075663526, 0.019368047593161464, 0.005578310178991939, 0.020063495097149695, 0.060406770024980815, 0.05290149079103555, 0.0073037424590438604, 0.038484589396310706, 0.01191148123637374, 0.03867299482226372, 0.012337573238515427, 0.017301777843385935, 0.04327200339840991, 0.07060918185327734, 0.022577411362103054, 0.02477397340615945, 0.09939120563545398, 0.013846041401848197, 0.023390661027016382, 0.09991239516862802, 0.14022777043282986, 0.08767173878316369, 0.2412184120288917, 0.11777261751038687, 0.10720218185867582, 0.09051376913807221, 0.15159446692892484, 0.16705795430711337, 0.12179448455572128, 0.14271883533469268, 0.07097509543278388, 0.1544186653835433, 0.22641444711812905, 0.14445220732263156, 0.0944427786661046, 0.18912734650075436, 0.11156677015657936, 0.12953123583325318, 0.25973373278975487, 0.13337675162724086, 0.0880245566368103, 0.13438337189810617, 0.07609505605484758, 0.06576100843293325, 0.1081299427896738, 0.07503437011369637, 0.1268804437880005, 0.1394572396363531, 0.19581261277198792, 0.2009206786751747, 0.13525395946843283, 0.09431400629026548, 0.10450543942196028, 0.16119831587587083, 0.17247571716351168, 0.15237873127417906, 0.14776146332068102, 0.13286158069968224, 0.1868465053183692, 0.1314616815320083, 0.1414179615676403, 0.1567503016974245, 0.1770502645522356, 0.0842531436522092, 0.11673612812800066, 0.13258610905281135, 0.22617587420557225, 0.21816902527851717, 0.1621008760162762, 0.11251963688326733, 0.11702645969177995, 0.05160009115934372, 0.09013973349439246, 0.09291072801819869, 0.18919883695031914, 0.12428105755576066, 0.11296350735106639, 0.14161268754729203, 0.14680402326796735, 0.11980257715497698, 0.1306672798735755, 0.10660066734999418, 0.09995928193841662, 0.123605752363801, 0.10857317543455533, 0.10691059500511203, 0.20147900442991937, 0.1696137243083545, 0.09897850028106145, 0.1794264263340405, 0.13825659906225546, 0.10871718092156307, 0.0922950321276273, 0.10985145398548671, 0.11218558730823652, 0.09586786505367074, 0.1540138242500169, 0.09817001223564148, 0.13577953912317753, 0.1959911353353943, 0.16855056849973543, 0.15745405107736588, 0.1360998483640807, 0.1341407142047371, 0.15207054066870893, 0.1192408451544387, 0.10974089348954813, 0.14391726388462953, 0.1433800405689648, 0.10283185315451451, 0.10866426876080887, 0.1958692433046443, 0.08513227397842066, 0.14045308477112226, 0.10764624231628009, 0.16472897785050528, 0.11566679765071188, 0.09995907159256083, 0.14248991119010107, 0.06521408885185208, 0.21723469612853868, 0.15947162067251547, 0.1160120769803013, 0.15501952171325684, 0.08408310956188611, 0.13938838190266065, 0.20946837429489407, 0.30905742038573536, 0.12227354384958744, 0.0892734614067844, 0.11952124296554498, 0.10896164351808173, 0.11811234642352376, 0.0949682497552463, 0.15441912678735598, 0.20110906713775226, 0.18591757730713912, 0.11124310216733388, 0.11066872905939817, 0.12931261185024465, 0.12680972686835698, 0.10119173901953868, 0.26559581394706455, 0.1401304006576538, 0.13555091353399412, 0.09839118072496993, 0.09054061198340994, 0.07240981701761484, 0.14361858634012087, 0.17843736654945783, 0.07907557540706225, 0.1638025197067431, 0.08578216803393193, 0.11405132790761334, 0.09655385717217412, 0.0840893385133573, 0.15698953957429954, 0.114208137350423, 0.08667963916169745, 0.05956389382481575, 0.05998860924903836, 0.09484254435769149, 0.2298516748206956, 0.11555097172302858, 0.15672677010297775, 0.1237279972327607, 0.11260735110512801, 0.11693269972290311, 0.0916417386116726, 0.16921610278742655, 0.1607797954763685, 0.1216295598340886, 0.10342344748122351, 0.10542745316135031, 0.1154807840606996, 0.09612287886972938, 0.08510711389992918, 0.17210625484585762, 0.09629614278674126, 0.09338410797395877, 0.12906774213271482, 0.1935988244201456, 0.0588138344298516, 0.12549567595124245, 0.09140560842518296, 0.1300804963601487, 0.12922582722135953, 0.09504871722310781, 0.08957785221615008, 0.10572400010590043, 0.11444943797375474, 0.10006273817270994, 0.2400766004409109, 0.0949513338772314, 0.1595611601535763], [0.023973519215360284, 0.03258263412863016, 0.053272391602929146, 0.07324157202882425, 0.02395221491211227, 0.059626257978379726, 0.036177756930036206, 0.038017665701253076, 0.03445756209215947, 0.01055750616693071, 0.021003695271377052, 0.04738165930445705, 0.05941598676145077, 0.052297889787171564, 0.0176114476551967, 0.04910643764638475, 0.02717747675654079, 0.0482907130249909, 0.05622176619778786, 0.04340582746746285, 0.050032142616276226, 0.02402270112984947, 0.030221023530300175, 0.03582656756043434, 0.03559284617326089, 0.03378756304404565, 0.0202991723615144, 0.045956416853836606, 0.03999095410108566, 0.05979396469358887, 0.01630506757646799, 0.01243865629658103, 0.017541874067059586, 0.01738872192800045, 0.03358094234551702, 0.03015060516606484, 0.026777587232312987, 0.03021753586030432, 0.011398881956535791, 0.030909868888556957, 0.03894775400736502, 0.036382694861718586, 0.014187983187314655, 0.007482028383362506, 0.018208215811422894, 0.03980039432644844, 0.02803110095140125, 0.011781875110630478, 0.041482849046587944, 0.0330569809967918, 0.05798169265368155, 0.09784880732851368, 0.034725464680897336, 0.009408218819381935, 0.020229612344077656, 0.013841455353290906, 0.05473142849015338, 0.0372895569141422, 0.028867305455995456, 0.0501214208613549, 0.051008384874356646, 0.04360004115317549, 0.06807953545025416, 0.04545906086319259, 0.008892769692465663, 0.017187032482719848, 0.03699378349951335, 0.04125747364014387, 0.020448599343321154, 0.01619987259618938, 0.014445052116311021, 0.03873553539493254, 0.053900141668106825, 0.02850224683061242, 0.013693401556728142, 0.08006097788789443, 0.05589275474527052, 0.025708093906619718, 0.004888439384688224, 0.006396583971633975, 0.026104967342689633, 0.08021913761539118, 0.02672741635303412, 0.03201783175713249, 0.054111722457621775, 0.00906939320598862, 0.015728141480524625, 0.026636516409260885, 0.03279443544202617, 0.01282042554313583, 0.05468751370374646, 0.04404235438310674, 0.12111470103263855, 0.02837001731885331, 0.030595737708998576, 0.044311346020549536, 0.030640358171824898, 0.04875078351636018, 0.0018545460438222758, 0.03522611835173198, 0.03865423672167318, 0.026813227284167494, 0.054421690824840746, 0.04927687546504395, 0.05704051708536489, 0.013607727180767273, 0.015528966007488114, 0.03232432263238089, 0.024494958110153675, 0.021888070673282658, 0.0326287507611726, 0.08125262108764478, 0.04670526845646756, 0.04678595644821014, 0.049562582812671147, 0.017547974096877233, 0.008601469519947256, 0.013424231803842952, 0.016103630885481834, 0.04163883746202503, 0.031323117070964406, 0.04345991010112422, 0.04249756084755063, 0.059299828351608345, 0.050133183265903165, 0.02322689151125295, 0.03942410255383168, 0.038548487039016824, 0.02223712605025087, 0.09246979560703039, 0.022689071084771837, 0.06337780345763479, 0.04993781607065882, 0.025907642573916485, 0.025028213692296828, 0.04854044444592936, 0.03991086322015949, 0.045010691708219905, 0.020870885612176995, 0.038023840369922776, 0.032914047595113516, 0.024456793908029795, 0.010631518222258558, 0.008474166172423532, 0.02305389561557344, 0.060626900355730734, 0.04419501797695245, 0.028047017686601197, 0.06260956610952105, 0.018401080908785974, 0.012948802672326565, 0.022595604582290565, 0.03540757557909403, 0.050764339576874457, 0.09833174784268651, 0.016197324697194353, 0.04649342982364552, 0.005404841429221311, 0.039850147906690836, 0.056565674886639626, 0.016511591583756462, 0.018175968434661627, 0.05616792444405811, 0.04552874980228288, 0.04531615460291505, 0.0313115209074957, 0.038976089629743776, 0.09245019951569182, 0.08901726693979331, 0.007341121256883655, 0.06176203515912805, 0.0395569800665336, 0.07124285213649273, 0.05121200984077794, 0.04458970144124968, 0.03936840161415083, 0.06488043961248227, 0.08898283807294709, 0.018512655814577426, 0.02915690080927951, 0.02190614345350436, 0.020077418635732362, 0.06707662676594087, 0.016693131931658303, 0.022395591118506024, 0.022951511466609578, 0.028293705877981017, 0.04982851764985493, 0.04680694353633693, 0.031996284877615314, 0.03101590694859624, 0.011405626594621156, 0.010405847653081375, 0.050171008200517724, 0.0326673051209322, 0.028011158807203174, 0.023739187146670053, 0.014477789734623261, 0.022467629485098378, 0.021739853180146644, 0.07831368914672307, 0.011416751176251896, 0.01318448078486004, 0.01112447985048805, 0.053182404288755994, 0.03262025211006403, 0.029838621549840485, 0.035796718804963996, 0.03731059828507049, 0.06349559713687215, 0.029719708287822347, 0.009232424814919276, 0.03378362754093749, 0.01327969112233924, 0.017403547918157916, 0.05091547307425311, 0.035192239098250866, 0.07322338729032449, 0.054159467574208975, 0.028713413713765994, 0.0198730710295162, 0.051688049653811116, 0.010676396528391965, 0.03814342877428446, 0.012132944040266531, 0.025813487358391285, 0.021523476844387393, 0.014610835184742297, 0.02987054662246789, 0.028095368395692537, 0.02414118521846831, 0.033864729439041445, 0.03664243467418211, 0.03904054706384029, 0.025840148695611527, 0.06168495358100959, 0.028648186142423322, 0.010931085495810424, 0.03078113722481898, 0.028126589488238096, 0.11006555213992085, 0.11093784283314433, 0.05128812111381974, 0.007943705306388438, 0.10162199807486363, 0.01369912245510412, 0.03111257104735289, 0.03195587133190461, 0.038048864741410525, 0.002441382991881775, 0.024616470161293234, 0.011220991278865507, 0.06782358525586979, 0.03301951568573713, 0.0118554749559345, 0.0846901134188686, 0.03638214524835348, 0.07549696136265993, 0.02713077319120722, 0.03007756426398243, 0.07078584523073264, 0.06526280766619103, 0.04053439958287137, 0.025147313551445092, 0.054152604192495346, 0.04023791370647294, 0.03170596009918621, 0.019326438129480396, 0.043145490544182916, 0.027783703690926944, 0.011626516884591962, 0.06723162452025072, 0.03128026419186166, 0.022472340214465345, 0.011008234079261976, 0.010218937548675706, 0.030518561135977507, 0.024220628098451664, 0.03707168610500438, 0.02577408991887101, 0.021411469372521554, 0.02965621437345232, 0.04189043824693986, 0.05793651579213994, 0.03032625074099217, 0.0434794485169862, 0.014875414648226329, 0.016364454657637646, 0.055207712575793266, 0.04988020505490048, 0.03564382450921195, 0.04777340471212353, 0.032052392938307354, 0.041076759408627234, 0.04368938046640583, 0.018953254047249044, 0.054154510875897746, 0.019169638864696026, 0.018040181703067253, 0.0418720465552594, 0.04681464830147369, 0.07119657604822091, 0.029622728670282022, 0.050135968652154715, 0.10213771861578737, 0.0902194817151342, 0.017100712650322487, 0.00875738584103861, 0.06195393164775201, 0.024756216144721423, 0.07956426311284304, 0.011771166979867433, 0.10155943036079407, 0.02466176067745047, 0.035906312388501, 0.03993971113647733, 0.0236121738728668, 0.01736777724831232, 0.05428421623738749, 0.05324220018727439, 0.029618094276104654, 0.01153299949198429, 0.017537867317774465, 0.03151610939364348, 0.06112620034920318, 0.07143843985561814, 0.036420971022120545, 0.005019679083488882, 0.019287507182785442, 0.0359345767647028, 0.08717404691768543, 0.00420569532850225, 0.01673890760035387, 0.0565898884087801, 0.04231607308611274, 0.07889528865260736, 0.047027382600520334, 0.08873465031917606, 0.055151981102036576, 0.00980070891923138, 0.01436183658162398, 0.055571349670312235, 0.051290621515363455, 0.04062593395688704, 0.0842218224757484, 0.0014182907533332972, 0.06215621650751148, 0.019412520474621227, 0.03998161067387887, 0.04456938949546643, 0.06553189429853644, 0.030788082030734847, 0.1109402652031609, 0.16176187992095947, 0.24210286885499954, 0.22500590341431753, 0.10607601050287485, 0.10090984164604119, 0.07385032650615488, 0.13308203672724112, 0.14149390320692742, 0.15333993041089602, 0.10714381427637168, 0.09809492555047784, 0.11151604966393538, 0.17875488022608416, 0.18590925846781048, 0.12033540356372084, 0.08218479928161417, 0.17670521592455252, 0.25448092179639, 0.0938866717208709, 0.08013924011694533, 0.08942674925284726, 0.08442811069211789, 0.21205242563571247, 0.16493522535477365, 0.07194122751908642, 0.11165312730840274, 0.16930777286844595, 0.14427012923572743, 0.13273725951356546, 0.1264106532824891, 0.08531382280801024, 0.09033155534416437, 0.08411673775741033, 0.1357346743877445, 0.09037749895027705, 0.1266098575932639, 0.1518565442945276, 0.07239401393703052, 0.11165498649435383, 0.14604453902159417, 0.08987686224281788, 0.08889579560075488, 0.08468262239226274, 0.12843621602015837, 0.0981619240982192, 0.12639914532857283, 0.10447210978184428, 0.13064034203333513, 0.2061465246868985, 0.08396123110183648, 0.2127622411187206, 0.1687563003173896, 0.11641592745270048, 0.0831391927120941, 0.12175154685974121, 0.15737862512469292, 0.10361680282013756, 0.10888632613101176, 0.140536544578416, 0.1617421752640179, 0.12939233971493586, 0.19897772079067572, 0.13625257302607807, 0.29130607577306883, 0.12901451784585202, 0.14579399675130844, 0.08492344125573124, 0.16173076230500424, 0.058769200396324904, 0.11181541252881289, 0.14926353629146302, 0.14328949685607636, 0.12304647666003023, 0.12735254131257534, 0.2367518331323351, 0.09902592309351478, 0.12942968628236226, 0.14225527378065245, 0.20642671893749917, 0.1172027023775237, 0.20224931809519017, 0.07868152976568256, 0.21487035442675861, 0.19799657272441046, 0.20136938031230653, 0.12684060021170548, 0.09485329913773707, 0.16190640787993157, 0.11438127234578133, 0.12424259819090366, 0.07751337744827781, 0.11800307514412062, 0.07292979875845568, 0.1410992672400815, 0.13182935251721314, 0.1178696480180536, 0.17305487394332886, 0.059968809597194195, 0.060140953931425295, 0.057082470905567916, 0.11981062458029815, 0.12473165909094469, 0.124439020508102, 0.09399704222700425, 0.1111413761973381, 0.092596803791821, 0.178089671635202, 0.11064995399543218, 0.25556907483509606, 0.09974849503487349, 0.1772091503122023, 0.18793718250734465, 0.13715682950403008, 0.14720876940659114, 0.1103226151317358, 0.06155918711530311, 0.10390653727310044, 0.14685754611023835, 0.11580614160214152, 0.15175175134624752, 0.11220526482377734, 0.10078279953449965, 0.12659292135919842, 0.08652300613799266, 0.17725164017507009, 0.15610620911632264, 0.16820918396115303, 0.1874309546713318, 0.2714619663144861, 0.09431709362460033, 0.09551685888852392, 0.13189848166491303, 0.07059733463185174, 0.13906207441219262, 0.08377299870231322, 0.13346747175923415, 0.1619780340365001, 0.10388328387801136, 0.11871651400412832, 0.19604784729225294, 0.11401039867528848, 0.11275718520794596, 0.11898794158228806, 0.12952370409454617, 0.16972313129476138, 0.21303090027400426, 0.1291791440120765, 0.14380671695939132, 0.16097644849547318, 0.0870969517688666, 0.09875163209757634, 0.13650984636374883, 0.18619146118206636, 0.17583553759115084, 0.055366292995001586, 0.21354220355195658, 0.12950786708721093, 0.1493032577314547, 0.1729944029024669, 0.10139156758253064, 0.1718745215662888, 0.11901979201606341, 0.11655977687665395, 0.12780027942998068, 0.1233515188630138, 0.1435005348175764, 0.1167803414698158, 0.1811507466648306, 0.05944403061377151, 0.18846380710601807, 0.11881169889654432, 0.1463890719626631, 0.12279018041278635, 0.29306828549930025, 0.07070899435452052], [0.007934981042386165, 0.06374727934598923, 0.018798442890069315, 0.04666394567383187, 0.014861716722537364, 0.04970708363024252, 0.02908373437821865, 0.057280358858406544, 0.028658001151468073, 0.027397238982043097, 0.018113288762313978, 0.035894706047007015, 0.02150847782780017, 0.02887810773349234, 0.019124372097264444, 0.01959982158483139, 0.08935477025806904, 0.06547426631940262, 0.05088830113943134, 0.10907026340386697, 0.04337180232895272, 0.026594854359115874, 0.049744023076657734, 0.05475213737892253, 0.015921266117532338, 0.022280514972018342, 0.044729910524828095, 0.06201118643262556, 0.027053208156887974, 0.04526222124695778, 0.008330170015272285, 0.057778267855090756, 0.03361396325219955, 0.06850942131131887, 0.002864840581813561, 0.026295357483572195, 0.0434665936710579, 0.06598374433815479, 0.033927677132721455, 0.050434001588395665, 0.03986008505203894, 0.021236305557457463, 0.06626491567918233, 0.017957224011687294, 0.04671646089160016, 0.06554555999381201, 0.06819561243589435, 0.024535023906667317, 0.02904794504866004, 0.009196684679149516, 0.028072496676551442, 0.0018750971731995897, 0.04988702433183789, 0.012744058123124498, 0.02631403415996049, 0.028549710355166878, 0.03728583175688982, 0.010762413564537252, 0.011634000277678882, 0.054506585733698945, 0.0724358456209302, 0.042142066173255444, 0.057249811211866994, 0.029424379313630716, 0.04025230882689357, 0.06778290029615164, 0.04711770239685263, 0.023958498146384954, 0.047851320888314924, 0.017940632134143795, 0.030651102773845196, 0.043325020732092004, 0.009826008097401686, 0.026174729224294424, 0.03745558425518019, 0.020558024989441037, 0.02773409090670092, 0.03481065135981355, 0.017647713655605912, 0.05548861589548843, 0.05291661194392613, 0.021983567691807235, 0.02492199751681515, 0.015266393311321735, 0.011405051536192852, 0.015935092964874845, 0.1001079353903021, 0.0422027848793992, 0.043237862908946614, 0.036502103454300334, 0.023318724440676824, 0.017663319961034825, 0.0374427735140281, 0.03345608511673553, 0.03696791095925229, 0.0010324241094557302, 0.03366321132385305, 0.07610241137444973, 0.07085019749190126, 0.04644064658454486, 0.014615701977163553, 0.08047875189887625, 0.05256944289430976, 0.03042771208233067, 0.0642108680414302, 0.07962458487600088, 0.03756253833749464, 0.030449381098151207, 0.030591160990297794, 0.02552473169219281, 0.019063794187137058, 0.020825493315766965, 0.04485320033771651, 0.0323880268926067, 0.05086768385288971, 0.04981607671028801, 0.09887461656970636, 0.046567084799919806, 0.02137336284587426, 0.008591398363932967, 0.03903145130191531, 0.03792172763496637, 0.024838408787867854, 0.0576387814113072, 0.05931893589773348, 0.0027539389099859235, 0.016843585197680762, 0.01328302442561835, 0.023665430390142968, 0.052577741377587826, 0.015669582212077718, 0.027003191644325852, 0.07995868873383317, 0.059541936431612284, 0.059867565387061665, 0.05439531956134098, 0.041946553092982085, 0.044858581120414395, 0.04203176352062395, 0.04046381837023156, 0.01648108464931803, 0.011541142760376846, 0.026368939517331973, 0.0702529102563858, 0.04567471964816962, 0.023133087437599897, 0.054295378138444254, 0.05904636838074241, 0.06557178537228278, 0.06683184525796346, 0.03407139763502138, 0.04082471079060009, 0.05990057611571891, 0.054858813261879344, 0.021352581014590602, 0.04884491328682218, 0.032169857528060675, 0.026316987483629158, 0.05727349886936801, 0.0232129832397082, 0.09122119617781468, 0.011585540154815784, 0.011346855283980923, 0.03696406027302146, 0.07011917778956038, 0.014662580265264426, 0.038022021896072795, 0.010173865011893213, 0.04150346972580467, 0.018513388632397567, 0.017341843639899577, 0.018110041972249746, 0.04302457221118467, 0.01370263726650072, 0.027696259186736176, 0.01416921999771148, 0.01680679672530719, 0.030176426816199507, 0.05012797211695995, 0.0021381136736766037, 0.00367679085216618, 0.06817207405609743, 0.04478300249736224, 0.05114186289055007, 0.01853492363755192, 0.07738402831767287, 0.06372646867696728, 0.012802951570068086, 0.013371212773823311, 0.036736530517893176, 0.03906731527032597, 0.022141035313584974, 0.04500527360609599, 0.030923327630651847, 0.025358054653874466, 0.05969480358596359, 0.05219346324780157, 0.04332791807662163, 0.02829554131520646, 0.052488619195563455, 0.023772296262905, 0.02816428041218647, 0.08213519837175097, 0.04436397998194609, 0.028784212057611773, 0.013937795451576156, 0.08119103046400206, 0.0713716855804835, 0.02359411466334547, 0.1000030135203685, 0.011587179665054594, 0.035933521642748795, 0.01799651458194213, 0.04668529238551855, 0.03101520466485194, 0.0085956493858248, 0.04714287265336939, 0.013690527112755393, 0.04616304773039051, 0.035821074819458384, 0.018791571026667953, 0.05200394841709307, 0.02969435482685055, 0.04108092900631683, 0.008552369877829083, 0.06655469084424631, 0.03145057987421751, 0.006825418103419776, 0.026974650765103952, 0.015082233818247914, 0.05464704926790936, 0.010528630261043352, 0.01878308255358466, 0.014246025920978614, 0.042213081648307185, 0.08211134786584548, 0.03351771305980427, 0.06435230866606746, 0.01115866529289633, 0.04097623783828957, 0.028164266841486096, 0.07136994174548558, 0.02513513045518526, 0.03705578802951744, 0.04309541465980666, 0.0182173488927739, 0.06132585249309029, 0.0072783126628824645, 0.033848790651453395, 0.04311113292351365, 0.041623417753726244, 0.0238070118107966, 0.057715537292616706, 0.022330377117863724, 0.016441651586709276, 0.042149611482662816, 0.03969215102759855, 0.08102031105331012, 0.12153273288692747, 0.026294356644419686, 0.04576862889475056, 0.06119866788919483, 0.016728665114247372, 0.04036713730809944, 0.06179114431142807, 0.07719378066914422, 0.03420227686209338, 0.04331524304247328, 0.05450499117640512, 0.04299808220405664, 0.025339167631630386, 0.01849465597687023, 0.040845609669174464, 0.03713344975507685, 0.009871829567211015, 0.06859801084335361, 0.05058294341766408, 0.041299379962895594, 0.04152880961607609, 0.028706424803073918, 0.03698234000642385, 0.03727885302422302, 0.021583896995122944, 0.030869282316416502, 0.06358897034078836, 0.020963836428044096, 0.021136672867994224, 0.005329077057207802, 0.01011568317855043, 0.013343123968557587, 0.015524731948971748, 0.05085309534998877, 0.04534341474728925, 0.018775018164888024, 0.016646738796095763, 0.049378238418804746, 0.01789544679091445, 0.08579530447189297, 0.045455223747662137, 0.04022428872329848, 0.03445940092206001, 0.009392311414038497, 0.07161728811583348, 0.03457373746537736, 0.011748247763275035, 0.013628449640236795, 0.030241362617484162, 0.03120221570134163, 0.06389574959341969, 0.029619485272892883, 0.005375268328602293, 0.04193775588646531, 0.0047692691275317755, 0.03149782966024109, 0.08093921254788126, 0.007648122729733586, 0.016284558855529343, 0.01568639461350228, 0.0640036298760346, 0.039980555551924875, 0.0035709169127845337, 0.016602974983730485, 0.020125827020300285, 0.019420167564281395, 0.020401420803474526, 0.04536600657073515, 0.02805352653376758, 0.03451708657667041, 0.02055279178810971, 0.028736643360129425, 0.012890752305143645, 0.03801744517737201, 0.008448738920768457, 0.031751388018684726, 0.06850289380443947, 0.02983070643884795, 0.024784790950694253, 0.07614794107420103, 0.00590576948265412, 0.006064054315044943, 0.01908337331510016, 0.02973546047828027, 0.027065226708405783, 0.038366222354982576, 0.01410735711189253, 0.013229913793371191, 0.09215298082147326, 0.023414682863014083, 0.03712075436487794, 0.011035813983263714, 0.10890297738036939, 0.02086215965183718, 0.1512162515095302, 0.17039827363831656, 0.2412394466144698, 0.18705824895628861, 0.14221752009221486, 0.1330700945109129, 0.09977627425853695, 0.14551195688545704, 0.12912304273673467, 0.11532382534018584, 0.10772273356893233, 0.20930372098726885, 0.11812575427549225, 0.11971488328916685, 0.15609677747956344, 0.11651401647499629, 0.20129859553916113, 0.2284085394016334, 0.07339775721941676, 0.17730547514344963, 0.14326420107058116, 0.10663102500672851, 0.20217609059597763, 0.16335522942245007, 0.06537832146776573, 0.14581254789871828, 0.17518440181655542, 0.10822891390749387, 0.16492294387093612, 0.1148397855992828, 0.16628457366355828, 0.21709337085485458, 0.16630380334598677, 0.1465501154639891, 0.11058983579277992, 0.12376448884606361, 0.12176466972700187, 0.16010341819907936, 0.07450132657374654, 0.19267459187124455, 0.14327751392764704, 0.08342894073575735, 0.1325064083295209, 0.09051889207746301, 0.11117640896035091, 0.13106956971543177, 0.16946132534316607, 0.14742925257555076, 0.0989464462867805, 0.12949528704796517, 0.09524499704795224, 0.08691379481128284, 0.10274683950202805, 0.11446835553007466, 0.13496235225881847, 0.11174593732825347, 0.06754067686519452, 0.06305972659694296, 0.14639983352805885, 0.12813570643109934, 0.13730609363743237, 0.19298966282180377, 0.11729241827768938, 0.11568499595991202, 0.10119062622210809, 0.11987737885543279, 0.09223219299955027, 0.09036602492311172, 0.165630968021495, 0.058767483702727726, 0.17429724442107336, 0.12478792321469102, 0.07683098156537328, 0.11341495026967355, 0.1679328302187579, 0.15862706170550414, 0.14533823834998266, 0.09901415051094123, 0.08589208392160279, 0.09168967032538992, 0.12132772031639304, 0.13597643641488893, 0.23747688851186208, 0.08869945470775877, 0.13175611144730023, 0.13136014555181774, 0.27534484224660055, 0.11044576923762049, 0.16425397619605064, 0.18411453334348543, 0.10218847982053246, 0.09517718425818852, 0.1279504256589072, 0.16989952325820923, 0.10656557351882968, 0.05858081193374736, 0.0637916691069092, 0.1442559478538377, 0.19226349464484624, 0.10069007093885116, 0.18437541648745537, 0.19002978450485639, 0.16504608440612042, 0.13509856137846196, 0.1963897475174495, 0.14680060345147336, 0.11195611355027982, 0.11120287182607821, 0.1425242450620447, 0.12326590131436076, 0.10140010355306522, 0.09406490929956947, 0.14067994616925716, 0.10176056849637202, 0.10537840865020241, 0.10964977980724402, 0.10213166608342103, 0.24695002447281564, 0.09526559737111841, 0.13346055070204393, 0.07801642295505319, 0.16671604051121644, 0.0992062912721719, 0.10429554139929158, 0.17470284551382065, 0.054545835591852665, 0.1123412296708141, 0.13816080348832266, 0.07429362021918808, 0.14394941287381308, 0.09945280304444687, 0.12224264336483819, 0.15641336834856442, 0.1028906957113317, 0.11413742043077946, 0.10255609652293579, 0.127948525760855, 0.1259980904204505, 0.16336870512792043, 0.15545873743082794, 0.06425814157617943, 0.10394475915070091, 0.13492063592587197, 0.08243456123662846, 0.14928055394973072, 0.14474883569138391, 0.1320250691579921, 0.11384223055626665, 0.14925239474645682, 0.23804835070456776, 0.14366873007799896, 0.11713155119546823, 0.09572165432785239, 0.13163188525608607, 0.164107209071517, 0.10703678216253008, 0.11833937067006316, 0.10230586637875863, 0.18588717893830367, 0.19303641388458864, 0.1358134387327092, 0.1704874059983662, 0.09090826261256423, 0.10792097435998065, 0.18160465945090565, 0.09861452052635805, 0.0889475881787283, 0.1512246246316603, 0.2442061917058059, 0.1040018917992711, 0.20194160246423312, 0.1267689469137362, 0.1921909185392516, 0.07941369619220495, 0.203174052760005, 0.09973396081477404], [0.03268537111580372, 0.04740284995308944, 0.05495397440556969, 0.008487667322957089, 0.018097009010879055, 0.010967227663578731, 0.0037949776576299754, 0.03235536900215915, 0.08333585251654897, 0.12785420939326286, 0.031723418805216036, 0.003474130677724523, 0.012720731785520911, 0.04340949494923864, 0.020849082585690275, 0.05036467566554036, 0.0858020151832274, 0.011062585582424487, 0.030897587404719422, 0.036899266964090724, 0.021380165159436207, 0.09970688726752996, 0.033845404761710336, 0.026369999728298614, 0.044431748666933606, 0.03774619401831712, 0.04234917202432241, 0.07746854663959571, 0.03803857136517763, 0.05913845915347338, 0.04076179702367101, 0.040045413321682384, 0.0378545933802213, 0.02084876537056906, 0.022977684258616397, 0.023644612935770835, 0.03752787537606699, 0.034781884867697954, 0.0798077689749854, 0.019507914016555463, 0.02914310958502548, 0.003869779358085777, 0.08295108923422438, 0.06063567381352186, 0.02888779042820845, 0.025623524694570472, 0.02967021594356213, 0.022513584965573888, 0.03883665068341153, 0.02960626401805452, 0.0558152049779892, 0.007515133258753589, 0.0273149784853948, 0.02068844111636281, 0.013004056627063878, 0.05935630960656064, 0.03725967423192092, 0.022770261192428212, 0.03205765837005206, 0.038747016207448075, 0.0518337446930153, 0.007943770615383983, 0.04282622963988355, 0.02359300695492753, 0.011329384703588272, 0.012223542035956467, 0.04927505699119397, 0.06772845464625529, 0.06963032045002494, 0.0023272538258294973, 0.014662115468776651, 0.03553781019789832, 0.024425601653222526, 0.0036583139195239967, 0.03512725919219, 0.01499458066453891, 0.04111408222732799, 0.04202848280380879, 0.016882573819852302, 0.030996134438152825, 0.03316995707739677, 0.05307708547583648, 0.011809418543374963, 0.019580181388716613, 0.022923796703772883, 0.020477929019502232, 0.04752484715676733, 0.03125525678374937, 0.06112431402185133, 0.06699077173003129, 0.015022443008742161, 0.052269588091543744, 0.022335937712341547, 0.0570607917117221, 0.030819681406553303, 0.010407061382595981, 0.0016141675919893064, 0.11858003347047738, 0.021983652508684566, 0.0433321012450116, 0.015522017808897155, 0.036408604721405675, 0.017279683046841195, 0.024744913447648287, 0.03416202277211206, 0.010473813113224293, 0.020047615681375777, 0.03983315399714878, 0.0066257434830601725, 0.03447672052841101, 0.012541975127533078, 0.035493949694292884, 0.06636096231107201, 0.008368373233159738, 0.03303796844556928, 0.02062207360618881, 0.03314107862700309, 0.05934984316783292, 0.025449393949072276, 0.04714815844116466, 0.009643685737890857, 0.08825835944818598, 0.07742210770291941, 0.01817930513061583, 0.029233425988682678, 0.027889521227085164, 0.10694004342492137, 0.10069284614707742, 0.024954365333542228, 0.043174949142017534, 0.05719109757670334, 0.021085636856566583, 0.057510389015078545, 0.01838725745411856, 0.013680759601161947, 0.06621399841138295, 0.040653133033109565, 0.09993005743516342, 0.07090431744498865, 0.032806099458996735, 0.02589708796170141, 0.017282168181346994, 0.0674671440252236, 0.05955655886126416, 0.0629616172185966, 0.003918312847547765, 0.04094199217589838, 0.02100257059958364, 0.01066338477124061, 0.04460544345368232, 0.04343138448894024, 0.07542077545076609, 0.0013337169823768947, 0.023399972223809788, 0.0894083541684917, 0.08551183968250241, 0.014137951407714613, 0.06103550735861063, 0.02070738242140838, 0.005139680546043175, 0.08699010285948004, 0.021308974961617162, 0.009631980160650398, 0.05900494381785393, 0.013692308267179345, 0.05111822273050036, 0.03524332939248, 0.015141049233664359, 0.03161402878218463, 0.04244806171794023, 0.030644039224301065, 0.019454760975869637, 0.041505915844546895, 0.02002990252471396, 0.019853495294228196, 0.03126736863383225, 0.00703143617803497, 0.0952397994697094, 0.011909804406708904, 0.05026975879445672, 0.04727504788232701, 0.042219202034175396, 0.014620921607794506, 0.06403147695319993, 0.052748596495283503, 0.0752313556149602, 0.032002554541187625, 0.029843191483191082, 0.15551892348698207, 0.05365378595888615, 0.0332764226144978, 0.061219485343566964, 0.019419061552200998, 0.04397714716781463, 0.026481041984100426, 0.03977399252887283, 0.012186994443514516, 0.010059089965320058, 0.05570729076862335, 0.0051907254632429355, 0.014576789690181613, 0.04565362738711493, 0.01675093632989696, 0.11571972338216645, 0.019564118768487657, 0.09122386960578815, 0.056591581353651624, 0.015330558975360222, 0.025919818884826133, 0.018799058660598736, 0.018597834011805908, 0.023307572717645338, 0.055953673619244776, 0.0070524792453008035, 0.01255483930331788, 0.006174677575472742, 0.053705134096422365, 0.02283043198154441, 0.012165072673399533, 0.07139011459158999, 0.04839327359305961, 0.009997192304581404, 0.01938245289160737, 0.0316565695351788, 0.033080705973718844, 0.050585498102009296, 0.07547555358282157, 0.008043064885506672, 0.035828874579497745, 0.016947984595650008, 0.03283422473551972, 0.058516968573842726, 0.014837906928732991, 0.04357625850077186, 0.018536865944042802, 0.02079967505830739, 0.0441242060624063, 0.0046070916245558435, 0.016181184045438255, 0.025008174856858592, 0.057887851260602474, 0.01343264733441174, 0.021314661085073437, 0.04080418849896107, 0.011889723162832004, 0.052994076894330125, 0.028391255464937006, 0.02711044597838606, 0.02896402044487851, 0.023691457297120775, 0.03413904757638063, 0.006016017428399729, 0.05023580150944846, 0.03470365995807307, 0.022085780510678887, 0.07194353453814983, 0.0366417323904378, 0.011815686510609729, 0.03546108485066465, 0.02829223345699055, 0.03285723725067718, 0.050995078802640946, 0.04992819783676948, 0.03665032603644899, 0.033174757712653706, 0.06233074249965804, 0.04006569812606488, 0.02380467425765736, 0.036851677910557816, 0.04504085258979883, 0.01622493259076561, 0.03371691397790398, 0.013174983839105283, 0.039906530774065425, 0.01829410986309605, 0.027115942112037113, 0.013598687397981328, 0.018394677234547477, 0.01913356115775449, 0.07028880475887231, 0.03684775597815003, 0.049208652161593945, 0.0597758274525404, 0.034797165476317914, 0.038116623248372755, 0.023541726670893173, 0.009067352511920035, 0.03627857366310699, 0.04587663131366883, 0.014522786784384931, 0.04694443169449057, 0.07123807524996144, 0.042595408989914825, 0.04150311688759497, 0.010009128583728202, 0.015107544870781047, 0.036924762917416434, 0.03250690283519881, 0.0033561656683949487, 0.02638806402683258, 0.03169995845694627, 0.035535618529788086, 0.028831421131534234, 0.06504070958388702, 0.033811281235622506, 0.012581816159321793, 0.035556510623012266, 0.04140240532745208, 0.04710659817127245, 0.018721032222466807, 0.03601597382553986, 0.041947004318769486, 0.03574100090190768, 0.01345112469113831, 0.02904317155480385, 0.030724805247570788, 0.0509732164043401, 0.04888529969113214, 0.03669850541544812, 0.08129551807152373, 0.039633420429059436, 0.03371766036642449, 0.028276347255866443, 0.03147469500878027, 0.009055330567727131, 0.03642120511670198, 0.07842034128095422, 0.09045101143419743, 0.043187237411205254, 0.028134475761492337, 0.030850069597363472, 0.0883190001228026, 0.03743822732940316, 0.027153339569589922, 0.049631162347005944, 0.03734406702486532, 0.04268566771809544, 0.036312968603202274, 0.04145412665924855, 0.04248734550284488, 0.029269072825887373, 0.05745801289698907, 0.0549411670570927, 0.021739692028079714, 0.05476490740797349, 0.038377991544881036, 0.013814003522773939, 0.02377547011045473, 0.024011573155543635, 0.032102828446243487, 0.028977475794298307, 0.056890645663120916, 0.12468329311481544, 0.22876922147614615, 0.13355089085442678, 0.09841224245194878, 0.08013223763555288, 0.10374928678252868, 0.09045691468885966, 0.08911895219768796, 0.21674217469990253, 0.1786123335893665, 0.13298256349350723, 0.056518906860479286, 0.24436993577650615, 0.14531234545367105, 0.13473866640457086, 0.14528850173311575, 0.15920800981777056, 0.12649433022098883, 0.09185497502663306, 0.15886406041681767, 0.08468896669468709, 0.1776151449552604, 0.24654322915843555, 0.11155468544789723, 0.13869257138243743, 0.10012666295681681, 0.14435531252196857, 0.2570800094732216, 0.09330462438187428, 0.11987893948597567, 0.140422984957695, 0.11522637414080755, 0.11768391941274915, 0.11319777835160494, 0.07826412894896098, 0.09247162086623055, 0.14038536697626114, 0.10732280502894095, 0.14930716609316214, 0.07489104316170726, 0.05670509347692132, 0.11863726111395018, 0.18472764401563577, 0.20708573928901128, 0.1398850152535098, 0.08016583190432616, 0.1493571334119354, 0.1157855141375746, 0.13661902264824935, 0.14010813113834175, 0.15248498985809938, 0.06917518630091633, 0.07728743207241807, 0.1193028496844428, 0.08719965482928924, 0.14626675924020155, 0.14423082848744734, 0.1138684084372861, 0.1370891931333712, 0.09691394892122064, 0.16732605706368173, 0.07626961597374507, 0.1475485661732299, 0.14983840472996235, 0.13526774730001176, 0.14918949455022812, 0.24553332477808, 0.13568769262305327, 0.1274177756692682, 0.14999017944293364, 0.11691465069140707, 0.11199706313865525, 0.10452137820954834, 0.1227278501859733, 0.14412490917103632, 0.13429525734058448, 0.1407240102333682, 0.1770813414560897, 0.1842512445790427, 0.12724744980888708, 0.13200315247688973, 0.21522547251411847, 0.10078748142612831, 0.1541930524898427, 0.16926875710487366, 0.11159251377518688, 0.10238596743771008, 0.10629911960235663, 0.14679058827459812, 0.14096772644136632, 0.1054524639621377, 0.13660531624087266, 0.15388347767293453, 0.14304932260087558, 0.07035549118050508, 0.08901718551559107, 0.06557810931865658, 0.22902340069413185, 0.08512629608490638, 0.12447686919144221, 0.0868894150480628, 0.1640305888972112, 0.10680131015500852, 0.0814126060743417, 0.1334074485514845, 0.10427705132003341, 0.10237264100994382, 0.10493114550731011, 0.09057275418724332, 0.1423646536256586, 0.12192971658493791, 0.11946457172078745, 0.11845282172518116, 0.07901232237262384, 0.1576071557189737, 0.12158413869994027, 0.09255993219890765, 0.17335389075534685, 0.05879298983407872, 0.10662262474319764, 0.14177310679640087, 0.10135475705776896, 0.16369623398142202, 0.08069215116224118, 0.0757525587188346, 0.12658937940640108, 0.10784050010676895, 0.17678217536636762, 0.15701949011002267, 0.11978576305721488, 0.11944038873272282, 0.1530202997050115, 0.10617818430598293, 0.08686173760465213, 0.07739920036068984, 0.15104701130517892, 0.09345392922737769, 0.14500049075910024, 0.18547528104058333, 0.11789020762911864, 0.12822140540395463, 0.11283162728484188, 0.15146874796066964, 0.13252812145011766, 0.1763727744775159, 0.1344371118715831, 0.1601995394698211, 0.13544530634369167, 0.09561724135918276, 0.09252917420651231, 0.13081995025277138, 0.30422231554985046, 0.11656384808676583, 0.14494987204670906, 0.19360617973974772, 0.2145960634308202, 0.09848779732627527, 0.10310233078364815, 0.1151215811925275, 0.08756921892719609, 0.20987002631383284, 0.17111868783831596, 0.11394357654665198, 0.15784032749278204, 0.08511607734752552, 0.202486072533897, 0.20455054246953555, 0.08179903855281216, 0.08952441079808132, 0.08834644686430693, 0.09651117053415094, 0.0903781774852957, 0.12548844276794366, 0.16193939825253828, 0.09117287769913673, 0.1625860964081117], [0.01719524445278304, 0.04563195158594421, 0.02784378796682826, 0.0755407065153122, 0.02795108131665204, 0.052103394509426186, 0.017263416866106645, 0.03179536387324333, 0.023817064307097877, 0.020431931130588055, 0.06741027600531067, 0.030895823213670934, 0.04461748066491314, 0.012464001275865095, 0.00985804682464472, 0.008703188704592841, 0.014814787544310093, 0.07015864817159516, 0.029076202639511654, 0.030293165373482873, 0.01897831234548773, 0.04686765206445541, 0.038254498171487024, 0.0063447417757873025, 0.12912294774183206, 0.047563995234668255, 0.04850117762440017, 0.02539828329879258, 0.03775763072605644, 0.049577605577984026, 0.024910457332485487, 0.02304735453799367, 0.03133038757368922, 0.014740923918517572, 0.02272405126132071, 0.016353720233642628, 0.05762375186064413, 0.062340628754879744, 0.07189642385180507, 0.05303614606548633, 0.013284363684111407, 0.02917036633672459, 0.0209822840988636, 0.015718046575784683, 0.009270108105348689, 0.097359868564776, 0.042075505280601125, 0.04622255185885089, 0.04942180036700197, 0.026144325766446333, 0.05418130961645927, 0.051807566811995845, 0.027015384918610965, 0.04569589672610164, 0.043185727670788765, 0.04054272520755019, 0.02655817784502038, 0.017387995895530497, 0.050734239763447216, 0.10555955714413098, 0.03777275187894702, 0.00502369601079928, 0.037596912921539376, 0.006986419620391513, 0.01015497968598668, 0.029854302494121448, 0.020333998171346526, 0.032043151291353364, 0.0346356198590781, 0.02189159227002944, 0.060223097380782874, 0.03585638917450394, 0.04069490025618246, 0.05860120191105774, 0.03294408634038908, 0.05104075099474617, 0.044080287883324284, 0.021631665860435793, 0.018488281140370027, 0.03463395744828241, 0.05175440698595984, 0.020228126352386813, 0.032071212107049565, 0.009148553645770465, 0.048565336503088474, 0.04893910751811095, 0.003863575851677784, 0.026863079251987592, 0.046264512464404106, 0.03484628123364278, 0.048381280486605, 0.029902454731719832, 0.025297439424321055, 0.05130819896502154, 0.05883126599448068, 0.04969841534537928, 0.07072109941925321, 0.031145537671233927, 0.057082769460976124, 0.03471777009378586, 0.04582206013479403, 0.02870024674172912, 0.023243641148188283, 0.010811561552275504, 0.021176587690466216, 0.01587232169029968, 0.022296272251488905, 0.01618513311924679, 0.07057704643479415, 0.05274475259440286, 0.03158782036708934, 0.006399256551438677, 0.022796179533803036, 0.09227955474385194, 0.027800334584234015, 0.048287717292883565, 0.016513388005218337, 0.021051803404199224, 0.014896908941279565, 0.019064543968332664, 0.023790436896628568, 0.03160451911389828, 0.07080036588013172, 0.011390307818406394, 0.00617364577816001, 0.016177665841366564, 0.025035837033231343, 0.028500116230653863, 0.0371759464032948, 0.05066959233954549, 0.05669503080259476, 0.015748022556571022, 0.06847623416355678, 0.03432915612523045, 0.024757383224953498, 0.033877804808850796, 0.03601351074342217, 0.02902472558032189, 0.06168825126120022, 0.02261201155904148, 0.007951849422949766, 0.03634546703792044, 0.021826227295345495, 0.016280821823914136, 0.013150542159564793, 0.09035894101751701, 0.012089147149319095, 0.013057436128812177, 0.04662264324724674, 0.06640043269310679, 0.05304238858765789, 0.01582965880100216, 0.040462481656244824, 0.060616498413894854, 0.012059779305543219, 0.03204617077218635, 0.07452100408928734, 0.032391694374382496, 0.04073322391403573, 0.0425666051783732, 0.04850936075672507, 0.06917765616838421, 0.04925876875807132, 0.015804651392889873, 0.05750718632979052, 0.017280356492847204, 0.05404549743980169, 0.02905444541413869, 0.046669977850147655, 0.04018097783305815, 0.021492861344345977, 0.036427668162754605, 0.059691919812134335, 0.04318416025489569, 0.07433967239090375, 0.04408351092466286, 0.055183797609061, 0.020681179095325724, 0.016542627775509442, 0.06486177311411925, 0.07390671276620456, 0.020198148675262928, 0.016759451944381, 0.03042993089184165, 0.018118457502818534, 0.05653042159974575, 0.02077048278546759, 0.02808207759101476, 0.031200064745332514, 0.04141373007691332, 0.010347840542505895, 0.041613728273659945, 0.035806354002228806, 0.006256631035025099, 0.049200798118753095, 0.048452082223125865, 0.041357153827058415, 0.02540043934381434, 0.022794829249115925, 0.021009001415222883, 0.05546218017116189, 0.033340147230774164, 0.019220096425020268, 0.0540263661449509, 0.008423363407408553, 0.04154790019882577, 0.029418567661195993, 0.04585239065012761, 0.01967599562236241, 0.03503666798185025, 0.03477177808859518, 0.031879010277667215, 0.012470178489041115, 0.022758570034056902, 0.05548477538728288, 0.06557863179062094, 0.01159199302284313, 0.04201551599960242, 0.035294979478099515, 0.020820105747718896, 0.029727765891168798, 0.059474876815719266, 0.03131505607494286, 0.050080946247492514, 0.05398059556526797, 0.014520802069455385, 0.013249452209233173, 0.017989013377310972, 0.06622670058693204, 0.0410594567656517, 0.04309050885162183, 0.07241041412843124, 0.01914255174675158, 0.0226376567900713, 0.03019586345180869, 0.023932834255642126, 0.058238043183726926, 0.0403644469167505, 0.04434502849887524, 0.0169926440742399, 0.029103717234517847, 0.025935345462390354, 0.028670584583388906, 0.034945842676929066, 0.007831752117324089, 0.027870803838595748, 0.05436866331313338, 0.06279517936387233, 0.046669323063854656, 0.022848726981984716, 0.08557701975639377, 0.019938822769160782, 0.06811673273997647, 0.009422333195938595, 0.041595696205539365, 0.0314916007087699, 0.05193974204095347, 0.0938103161752224, 0.031016962070550238, 0.032456999977252314, 0.034635555398251326, 0.03244529864085572, 0.019226483135883297, 0.09180401704673256, 0.042424031400254796, 0.01873503379257662, 0.012692124749134694, 0.062450334296694825, 0.041959597928715606, 0.026742956501298716, 0.005970901635009795, 0.04391983810013958, 0.02966523210385016, 0.06537053188575165, 0.0166935102149312, 0.08248024699943406, 0.03351730593879308, 0.06904087029397488, 0.02028241254655378, 0.036932959620441706, 0.011266560842549162, 0.021385461125256758, 0.04629199991800955, 0.007737751268515629, 0.03871762885579041, 0.042784615087189844, 0.030107318024550165, 0.003776600384818656, 0.03423754371968763, 0.03091146344585078, 0.031099421038691486, 0.009105580326701914, 0.010427732951939106, 0.02973838835688574, 0.09485029322760445, 0.004050555930007249, 0.02417509161335017, 0.03853370854631066, 0.05475564201229385, 0.053569596726447344, 0.05684715835377574, 0.0295524053009493, 0.012883675184899142, 0.023279053890811544, 0.03547400415741971, 0.08374449344617979, 0.018324218158211027, 0.03890706565497177, 0.01647084894856172, 0.03254311624914408, 0.02547917315470321, 0.02667791043807353, 0.02862481739638107, 0.013016985263675451, 0.05087947679151382, 0.010364660577449416, 0.02484186253111277, 0.03254966071939894, 0.021442227364916886, 0.04130659618281892, 0.02357288499894951, 0.04960027204028197, 0.0044710996361183265, 0.03826937844444599, 0.050771033324833424, 0.003095042280619964, 0.03637962109808411, 0.017249259232942547, 0.086552854893463, 0.07155938872269221, 0.025189784754599844, 0.04103478862504874, 0.08940671889909677, 0.055756080829139264, 0.02949333543490086, 0.0451349959309612, 0.02346429055822747, 0.05344099398436291, 0.06019871761756284, 0.021880806955908026, 0.04399878564955933, 0.036644826510122845, 0.02334163517558149, 0.027106680109032562, 0.014718927509550537, 0.06353039919797863, 0.01151777316616582, 0.036737629744623385, 0.035477006674877236, 0.062025408526616435, 0.02827924460039607, 0.05102846272555845, 0.09213583424155201, 0.13778101386768477, 0.11894598097673484, 0.14551786014011928, 0.09343651123344898, 0.19742247781583241, 0.1592009123414755, 0.10168278124183416, 0.17122274796877587, 0.09919960770223822, 0.1286835963172572, 0.06284912289785487, 0.08937525523028203, 0.10794095043092966, 0.10382560161607605, 0.11414067739886896, 0.1483149714767933, 0.16061078597392353, 0.11471368665141718, 0.13860434825931275, 0.06780251674354076, 0.16451416723430157, 0.12268594386322157, 0.12063480035534926, 0.21320677655083792, 0.18041159132761614, 0.14417489006050996, 0.09922282038522617, 0.17436579002865724, 0.2378650919667312, 0.08586825377174787, 0.09009049899343934, 0.09910533883209739, 0.08260652915175472, 0.1310675341103758, 0.08200637849846057, 0.13242611049541406, 0.16211617019559654, 0.18642449724887097, 0.18992929346859455, 0.09641836729965039, 0.09691665627594505, 0.1634360293724707, 0.08191450485693556, 0.12045623707984175, 0.20444813796452113, 0.1427958897714104, 0.12249317206442356, 0.15916543853070053, 0.12257212639919349, 0.09482485494975533, 0.17649507362927708, 0.2235027854996068, 0.12973582771207604, 0.14422730010535034, 0.2385073932153838, 0.12813312799802848, 0.11631584353744984, 0.15399101190268993, 0.20678384548851422, 0.15550167512680801, 0.11396727098950318, 0.13089547120034695, 0.13948576524853706, 0.12402420490980148, 0.0878182209229895, 0.09227260654526097, 0.10907895543745585, 0.16171279469771044, 0.11805252677627973, 0.1425218837601798, 0.13938520635877336, 0.18186869099736214, 0.1256576558308942, 0.11770092350031648, 0.09141923340835742, 0.14036562160721847, 0.11426292226782866, 0.07440619596413203, 0.10876309060092483, 0.13570722086089, 0.18324410862156323, 0.11120475815343005, 0.13910798409155437, 0.14451877160796098, 0.09289979681904827, 0.07188710756599903, 0.1471216862222978, 0.07219366968742438, 0.13765154938612664, 0.12458362989127636, 0.12102892063558102, 0.10769974480250052, 0.1785275438534362, 0.13281877871070588, 0.14265483591173375, 0.1385129088801997, 0.1100969004577824, 0.16220071565892014, 0.1602292185915368, 0.16611711122095585, 0.23010403556483133, 0.0810395475210888, 0.1308697954352413, 0.08411946546818529, 0.13103558868169785, 0.08126908913254738, 0.1497545378016574, 0.1607049394931112, 0.1461728092815195, 0.11083169960017715, 0.1583678341869797, 0.0895173472485372, 0.20333369847919258, 0.2128264983849866, 0.07556459094796862, 0.1095596296446664, 0.10057858084993702, 0.12274577708116599, 0.10547032978917871, 0.10549491311290435, 0.10461920260318688, 0.12358824616031987, 0.18637970036693982, 0.106760903394648, 0.090137351836477, 0.09704177813338381, 0.13628922748778546, 0.19590927687074455, 0.10991752972560269, 0.1679856473846095, 0.05886335391551256, 0.13632719830742904, 0.13413447168256554, 0.11930936362062182, 0.1004181412447776, 0.06209088715591601, 0.12820126648460115, 0.1873134324061019, 0.08354974711047751, 0.08773127344569989, 0.08165426632123333, 0.11393003298767976, 0.12184886235211577, 0.1258507804679019, 0.13663057131426676, 0.08546483756176063, 0.17698307601468904, 0.15948828549257346, 0.10248624134276595, 0.1539462557328599, 0.11785455739923886, 0.16507433860429696, 0.1356330027005502, 0.08212098984846047, 0.09739729655640465, 0.1587530385170664, 0.076768970250019, 0.14043294585176877, 0.0837132129818201, 0.1101425387231367, 0.2514004813773291, 0.2186303205255951, 0.1772497674184186, 0.15134012486253465, 0.10815316904336214, 0.0904619697747486, 0.15181047176676138, 0.1391165472034897, 0.11033776681870222, 0.17058328299650125, 0.09639062878808805, 0.08317898200558764, 0.11253856801028762, 0.3054990198995386, 0.10463237975324903], [0.07519862987101078, 0.039108034156795056, 0.02145669373151447, 0.02059751233485128, 0.025774875323155096, 0.059909600631466935, 0.05993424502334424, 0.024016185497332896, 0.021738901534782987, 0.0022046732940777603, 0.06151386097605739, 0.05638279612841351, 0.03870039406631674, 0.034151939741734944, 0.0584570403609957, 0.037749922568244595, 0.01912267236704273, 0.07504015801740543, 0.038341622067881484, 0.03000983629109604, 0.017778706537293534, 0.03978237582902823, 0.029618185878332173, 0.05749928818217345, 0.0026326658303982443, 0.03459930466488004, 0.042006701829710176, 0.05491690603750093, 0.04273967571290476, 0.042991039010563066, 0.024523919681087136, 0.031101049522736242, 0.0448489391377994, 0.036778959312609265, 0.017764167228181447, 0.05991717308227505, 0.04126720043963619, 0.028957482759973834, 0.009023920333545123, 0.056024953722953796, 0.02433740227882351, 0.02561700397304126, 0.035041658606912406, 0.04219114121847919, 0.09768189449927636, 0.02162264134468777, 0.03914274461567402, 0.07410331828785793, 0.037072089833340476, 0.01596261604156877, 0.012080864781247718, 0.03185144818520971, 0.012608561465250594, 0.06391033131097044, 0.01608432486786374, 0.027637481090745757, 0.02046002756937274, 0.020939115700977187, 0.050493722848062, 0.019953238245631968, 0.011790769856556185, 0.03316643548064998, 0.07382362615317106, 0.0350443218568606, 0.030846754953797375, 0.010532709104674203, 0.020957746576251726, 0.022863697160833647, 0.07222224279705967, 0.07031930490796055, 0.07767695867057357, 0.07436619632478271, 0.04071442170866898, 0.07290249450930528, 0.018887984067467705, 0.0484562823548913, 0.037534463951098065, 0.006476700721707727, 0.007860863814130425, 0.029612391189272915, 0.0057652601473299515, 0.09534932859241962, 0.01675910928419658, 0.07149272265711001, 0.017259274409817796, 0.06566799485257693, 0.044051192301724634, 0.0434472689937268, 0.013526001878614937, 0.05742067311491285, 0.07603009989751236, 0.03912119773615684, 0.03937290708667465, 0.03819872598562922, 0.02414203847625426, 0.013528782175853848, 0.06298314713473831, 0.04723798290693334, 0.010282870814470308, 0.041273643129638264, 0.022250360875789608, 0.013133583024942448, 0.009932287037372589, 0.09463788462536675, 0.0199262630859656, 0.030670135681118284, 0.07352967121239219, 0.027341884095221758, 0.030433910499726022, 0.02315642056055367, 0.09600496305418865, 0.034588224188025506, 0.013600497390143573, 0.0325228755495378, 0.06068270307566438, 0.0339362402446568, 0.01599303985546742, 0.06720725832773106, 0.07240021574710097, 0.03171798373971667, 0.06206749126847301, 0.0334686006951545, 0.03181771142408252, 0.08712727549885001, 0.02070336040508534, 0.007407782233453223, 0.02701851466138448, 0.018764913082122803, 0.05086239806509443, 0.0985956233260887, 0.01987329833874745, 0.05430997681937047, 0.0615158151569111, 0.02509074917595301, 0.04040856187098792, 0.013942668181178825, 0.0361735907250217, 0.01818460618544902, 0.026255344273522496, 0.08805931798581566, 0.018897570070943663, 0.031152221241167614, 0.02827854062031422, 0.029085288223411356, 0.02141759654373995, 0.0764265882649592, 0.0168146745168737, 0.023407122286568795, 0.053431796442185125, 0.02998258632474712, 0.028471373487263918, 0.06862121674099139, 0.06661955200667892, 0.02004959700363023, 0.004522507993637451, 0.017704376418675696, 0.06548876661275115, 0.02502983878366649, 0.007088792319076934, 0.025488195974113684, 0.03289963211864233, 0.03989631882203477, 0.043783903787178655, 0.02797824307344854, 0.008493078639730811, 0.04746497661939689, 0.04628624254837632, 0.023586815322882364, 0.04458629858813115, 0.026255907457587973, 0.03927210731697934, 0.004772007016332022, 0.030091552263391868, 0.06389723558511053, 0.05177283599706633, 0.005017612096188324, 0.04527748149952718, 0.05040097389636295, 0.010178177950105496, 0.017162500049120614, 0.009477219893597066, 0.021550034705017294, 0.07533323086266007, 0.046087296080908606, 0.035355107858777046, 0.03110732597165874, 0.00770549032105399, 0.010266343397753579, 0.010832432441280355, 0.015294352346765143, 0.051099227142653296, 0.046042448308851035, 0.041512914933264256, 0.03955130072842751, 0.06034205135490213, 0.02794180065393448, 0.016380213633445755, 0.04110475915617176, 0.021846518885078173, 0.029524022181119238, 0.0387601560380842, 0.023933434759133627, 0.02142704344753708, 0.025288421693923216, 0.05731547983097179, 0.0038266839027138694, 0.055652556741344075, 0.026096400838079195, 0.018511051079258323, 0.0465164864435792, 0.05096717404999903, 0.04796507728419133, 0.03379004308953881, 0.05036637878843716, 0.014740783122501202, 0.07857077249458858, 0.03800088892291699, 0.00965171365533024, 0.04812835316572871, 0.05385029309296182, 0.016563652183062265, 0.010959437233395875, 0.014577478403225541, 0.06461226900241204, 0.043793420240815194, 0.027281655630628978, 0.01771578937768936, 0.05157756379672459, 0.014885757218248077, 0.07555449434689113, 0.03527966155005353, 0.05840250650154693, 0.04862196703574487, 0.02097936809462096, 0.03945393773860165, 0.010747498516658587, 0.01961625231030796, 0.056547775132847686, 0.05663295163373862, 0.024726781295612454, 0.10434364274676357, 0.029241795718137707, 0.016247302193992903, 0.07767370170248405, 0.03430519026837178, 0.0657465352809855, 0.02071992853390319, 0.1094295476962413, 0.013286930242819446, 0.06755496681268726, 0.028263063236538852, 0.0215856493118086, 0.03850483688126717, 0.021151461538725665, 0.029446550445365052, 0.026352403618927513, 0.0730431480333209, 0.05164920352399349, 0.02258759956540806, 0.07938095687755517, 0.031130111177584956, 0.008930367317848971, 0.04083060725991215, 0.0518139178997704, 0.03086438329358186, 0.014309226368953074, 0.05275253199839166, 0.05629429480593119, 0.022310160166983093, 0.029541297682694027, 0.06351900659501553, 0.04098647353904588, 0.10497863617326532, 0.01535864862879472, 0.05603770678862929, 0.03303317798833762, 0.02881825415949736, 0.04144554319126265, 0.029297829139977694, 0.024389746166499596, 0.0781925299337932, 0.02014575050478535, 0.01519067898126585, 0.04874909057148865, 0.055538606962987354, 0.10782779793121985, 0.003568900391525988, 0.04921770042606762, 0.05393770197406411, 0.05095552360372884, 0.01576642781895186, 0.022873753049810017, 0.02695533965847322, 0.08605145822678294, 0.03361016684877021, 0.04403927044144698, 0.0406185243544834, 0.04611345699855259, 0.030377832973109822, 0.0372052150113242, 0.055728922465017865, 0.041149796918034554, 0.040035985077598264, 0.015444098240030664, 0.035733577728803666, 0.053506815273846896, 0.05966626440307923, 0.06765594639416252, 0.017018053514350737, 0.030818985908159187, 0.03631934343970247, 0.016519783197769096, 0.03943172589476619, 0.036196667701005936, 0.018596877277429615, 0.05647263755755765, 0.006459815801853048, 0.04065153169046555, 0.03010460388447557, 0.013172147562727332, 0.11434549997959818, 0.020999403537384102, 0.02667834809316056, 0.008741986488790383, 0.049173219062920125, 0.005722407268227211, 0.019549910245197158, 0.050981274007686546, 0.024991404863872697, 0.010869156452827156, 0.01418805867433548, 0.04962921155882733, 0.04626371518575719, 0.0665052934948887, 0.04386989453009196, 0.017518510410029973, 0.0031938212882128675, 0.05966815073043108, 0.035566647936190875, 0.05507745760093842, 0.07268880347588233, 0.04879977374470659, 0.05454821385709303, 0.04138607298955321, 0.01277055321926517, 0.009154216020501085, 0.013454055962418872, 0.04007883117135082, 0.018626089906319976, 0.048037127525146515, 0.011250421887130609, 0.049532259082687755, 0.15270183607935905, 0.2079408834023135, 0.16903577532087052, 0.12279016684208598, 0.06346025224775076, 0.1404726265796593, 0.19494254088827542, 0.1242602536720889, 0.10745344337608133, 0.13050977832504682, 0.10918406729719468, 0.13016266695090703, 0.1949448071952377, 0.10017615530107703, 0.09976867466632809, 0.11424621673566954, 0.1266472041606903, 0.29344286397099495, 0.13828299407448086, 0.09419716934540442, 0.05732418543526104, 0.15733047627976962, 0.05967686312007053, 0.12189530128879206, 0.10713529866188765, 0.08309836526002203, 0.16688220016658306, 0.09735049799616848, 0.1609900463372469, 0.11197197769901582, 0.1716946962156466, 0.10324626163180385, 0.17116372899285384, 0.09046199691614934, 0.1371784204883235, 0.13930785336664744, 0.12305535189807415, 0.14920482944164956, 0.1320986087833132, 0.17506687955132552, 0.10478082285927874, 0.14728632595922264, 0.1543588593069996, 0.12339742854237556, 0.17084901088050433, 0.1332449936973197, 0.14724135265818664, 0.17553603223391942, 0.20914155111781188, 0.1233273765870503, 0.08475565990167004, 0.1019106333010963, 0.0939321064257196, 0.24821497659598077, 0.09170536484037127, 0.08904792315193585, 0.24605897228632653, 0.1447130904666015, 0.1092190525627562, 0.12752608342894486, 0.098770977130958, 0.10478363877960614, 0.1630256785345929, 0.17347338077213081, 0.09675821156374045, 0.07669674019728388, 0.09878029341676406, 0.10577907679336411, 0.15314137749373913, 0.25634933582374025, 0.15421589197857039, 0.2032704454447542, 0.12964446975716523, 0.18884620230112756, 0.0898167033280645, 0.1466664842196873, 0.13731997646391392, 0.08216033809419189, 0.12251229318124907, 0.20955001562833786, 0.11585990871701922, 0.22428514994680882, 0.11253806589437382, 0.23941065903220857, 0.18620044498571328, 0.11956734263471194, 0.08601224568805524, 0.18418767941849573, 0.10199766898793833, 0.10558612857546125, 0.17172140335398062, 0.1548979010965143, 0.08283163992954151, 0.07857950524027858, 0.14656816449548515, 0.14799596502312592, 0.20864178293517657, 0.11788712708013398, 0.10564491684947695, 0.0533193564042449, 0.13001656479069165, 0.13755515670137747, 0.10224459466657468, 0.23284971394709178, 0.11825923568436078, 0.08837356112365212, 0.11047614046505519, 0.16563740053347178, 0.132612694054842, 0.2173635092164789, 0.20015843957662582, 0.1137709165258067, 0.09260073929492917, 0.09912577630685908, 0.1256953959486314, 0.10472658755523817, 0.11559585002916199, 0.20195093910608972, 0.18342747592500278, 0.12688972614705563, 0.17871433097336972, 0.14269751576440676, 0.24134592232959612, 0.12336228042840958, 0.14362461173108645, 0.12963885148721083, 0.11920348501631192, 0.15055428631603718, 0.1148780956864357, 0.2909468864755971, 0.17074025528771536, 0.14136762783995696, 0.13805964748774255, 0.0990038774907589, 0.13578510311033043, 0.07457687466272286, 0.09581052205924477, 0.11457617474453789, 0.06376777788890259, 0.12696059234440327, 0.08707445833299841, 0.13351513205894402, 0.09458449070474931, 0.14404322712549142, 0.24059367126652173, 0.13228523305484227, 0.1551448471312012, 0.13841453487319605, 0.19403495958873204, 0.17142356719289506, 0.10115077586046287, 0.14083903548972948, 0.1384914264615093, 0.0599293460005096, 0.09642057932381119, 0.09878813049622945, 0.1851348600217274, 0.0949521277632032, 0.15084437360720976, 0.09154295748365776, 0.1210385151207447, 0.11226372740098409, 0.11639325081237725, 0.21740856394171715, 0.10923845187893935, 0.1309390195778438, 0.10908261952655655, 0.09525959912155356, 0.11388671531208924, 0.13125920668244362, 0.09542322784130063, 0.08772769078080143, 0.1385249053793294, 0.14138161923204148, 0.14008077260638985, 0.10424359275826386], [0.028285174996459057, 0.007576628039324922, 0.0896051971774016, 0.038984120091689486, 0.0625498957399811, 0.024369227267535667, 0.08523857327444212, 0.03325964244348662, 0.04551281440736992, 0.0383465855515429, 0.039319245144724846, 0.040487380498754125, 0.07836283543812377, 0.030911446482475315, 0.02002402301877737, 0.07094426958688668, 0.038146295584738255, 0.03883794329262205, 0.012097313318268528, 0.011717220901378562, 0.05219713072957737, 0.02311399006950004, 0.01593386990550373, 0.03417419908302171, 0.049044361870203695, 0.054153330224965296, 0.01204594736918807, 0.05812004594398396, 0.05914151934640748, 0.021671721478924155, 0.04227714553209288, 0.02057537004085524, 0.018240349533568536, 0.025970841325553398, 0.03983645507001451, 0.033248460186379294, 0.057170232624879906, 0.06178589923573392, 0.00967257606264736, 0.080979408962386, 0.016022630767630677, 0.029003070135201727, 0.06606267831687417, 0.015810554647552114, 0.03539593531084912, 0.045090697772268734, 0.017556206422990987, 0.03294595909704055, 0.03733194160408207, 0.026489963023258106, 0.022628126765734384, 0.06609609616654259, 0.06302909074085099, 0.04277225896450026, 0.05547018349170685, 0.010791213135235012, 0.020023673573242765, 0.03521623209651027, 0.027288388394351517, 0.03902529359662107, 0.031871023920497725, 0.05975061309124742, 0.04648790654859372, 0.03784673933738044, 0.06790493481925555, 0.05177716165781021, 0.05474666499399713, 0.027352623608229414, 0.021402485568874648, 0.014758820279634424, 0.03007931149165545, 0.021989460768444196, 0.043029053934982846, 0.039289029980344434, 0.07261766586452723, 0.005962076014839113, 0.025036785285919905, 0.035149094449090104, 0.02615704320903335, 0.025526818187375153, 0.08466611363525901, 0.05087857433993902, 0.06139240999306951, 0.014034640210281526, 0.03606547974050045, 0.03407315504071968, 0.027563634428328702, 0.030773116940898553, 0.020184418519160578, 0.02425215792443071, 0.015207898503701602, 0.01695010671392083, 0.026786358993766562, 0.052129691134073904, 0.02079138166404196, 0.008009851444512606, 0.05976552729095731, 0.06150861590036324, 0.04177863942459226, 0.013478911548320736, 0.009963682004516678, 0.0729689502290317, 0.022652041732466648, 0.008043264205168401, 0.05779006079371486, 0.021916411384674053, 0.019698100596932427, 0.043412684063826285, 0.0381044537228133, 0.06372747969414506, 0.04070208594202995, 0.030794562040162936, 0.052686693745532205, 0.027493263561544672, 0.03098028725279229, 0.026247763341026645, 0.02648283331654966, 0.01933678239583969, 0.02002855732903949, 0.040413678025028536, 0.06977082469633647, 0.03564358702195542, 0.03119263139420322, 0.057477649700428755, 0.035089685315532346, 0.0198118994012475, 0.08934199344366789, 0.023841065787045018, 0.019650369051045606, 0.016083218855783343, 0.03898941945018513, 0.029468439985066652, 0.02025280467101506, 0.039276402443647385, 0.06989693042955228, 0.01103892591449299, 0.01293582484192614, 0.022814589885196516, 0.03492220930222954, 0.013409149666715945, 0.028976173007062504, 0.015751903776877692, 0.02923127163999847, 0.034580068197101355, 0.015299594029784203, 0.05248824939397829, 0.05137105505647404, 0.029447045775928667, 0.010557598617327, 0.03750665419335876, 0.013775965697797281, 0.06177946672375713, 0.10585304389574698, 0.02405397650519652, 0.09536047013742582, 0.019697971675278883, 0.00909463725318866, 0.05319253481658442, 0.05902194790542126, 0.023479253951726214, 0.041776651316987615, 0.03052213362285069, 0.04699516236515982, 0.03496644300009523, 0.021024159887539487, 0.03621753265282937, 0.015565788406612617, 0.04197989630379847, 0.04227508617831128, 0.03143306688538619, 0.0520081519415336, 0.025389974637489234, 0.031575966360313554, 0.021290113384436284, 0.018561995488458445, 0.012428793790084975, 0.05168888425188405, 0.08258696698716708, 0.036473370888935666, 0.07928863540291786, 0.05819997058383056, 0.04142163161720548, 0.032806004464094124, 0.06977161179695811, 0.004457852936216763, 0.021692917216569185, 0.09383299281554562, 0.046534796711057425, 0.04207400232553482, 0.03477710798116667, 0.03894938927675996, 0.04468069637992552, 0.025538641660075103, 0.008725646517372556, 0.0799602357936757, 0.05302413260298116, 0.031486328491675, 0.031137408821710517, 0.020322037295305302, 0.02723916746409876, 0.011183735465497842, 0.026475279525454556, 0.04001961202759828, 0.024517590645700693, 0.03398390732971685, 0.04823594507096069, 0.05631349056160875, 0.0042581104623552945, 0.019928001831950884, 0.023512308785159673, 0.01706368669069239, 0.00900281874263393, 0.00806493406915771, 0.09498713338481528, 0.02337880532390305, 0.0778790128284267, 0.0478377298318914, 0.06436349770852498, 0.0884012792791639, 0.018378936918452382, 0.02205546017337058, 0.03380927277196731, 0.015441889608544963, 0.04436930987451758, 0.02889231625678284, 0.017805885257465497, 0.03711302245834044, 0.03666632928486381, 0.061121776300881586, 0.01283095046944384, 0.06970511536513056, 0.010187734267674387, 0.02219722988749189, 0.056707549773688824, 0.042253922671079636, 0.009831477937820767, 0.05035459263516324, 0.02426494491685714, 0.060448845981487205, 0.0691350848813142, 0.029728088195302656, 0.04243758513725229, 0.013553774316928216, 0.05858102906495333, 0.03096223822129624, 0.020725840270253162, 0.02861071065334337, 0.040446264669299126, 0.019620437175035477, 0.04673755993800504, 0.0825835471706731, 0.01305467025044241, 0.04421199153044394, 0.054883226951850314, 0.019458051870710084, 0.01703658091303493, 0.03700066723727754, 0.022528829951105372, 0.02499674154179437, 0.01883227634243667, 0.013949123593712491, 0.06664853223732539, 0.05482061513300453, 0.03285502861919148, 0.03522676635267479, 0.022392425752644027, 0.006767522951122373, 0.01542040379717946, 0.03285155451989599, 0.03452670141788466, 0.05567228853968637, 0.04164604011124798, 0.07675038517585822, 0.08040129712649755, 0.05980867533279317, 0.011942837187754256, 0.026190260890871286, 0.052869073780519624, 0.02656914636359683, 0.035699189574058564, 0.07493772637099028, 0.043328162349228344, 0.060953743888863494, 0.022582184855959246, 0.07748841414494173, 0.024174005957320333, 0.02027870435267687, 0.03460024104320577, 0.08357388938644103, 0.008597502634594483, 0.08692452244992767, 0.007897251950842994, 0.04980553227609821, 0.024863925097244124, 0.021544282424396703, 0.05597993292446647, 0.03931277192064694, 0.014678771807146924, 0.0560897131051336, 0.029817692137190273, 0.052540493197739124, 0.0605785750917026, 0.043244190247995515, 0.1160924562386104, 0.06036324878888471, 0.012875181622803211, 0.01091790325673563, 0.04034764638968876, 0.053194288829607625, 0.03480890073946544, 0.03350221531997834, 0.03992734822843756, 0.03911616300631847, 0.0406728953655277, 0.04990288169522371, 0.06411824801138469, 0.005814262250039194, 0.034440619072743824, 0.04319268265472991, 0.010968776419758797, 0.018665987765416503, 0.04444376552211387, 0.02228053702440645, 0.023560021671333482, 0.04084530093574098, 0.0077401219002370325, 0.04555695650300809, 0.04255588771775365, 0.03396935953891703, 0.01882246133339192, 0.058345441706478596, 0.04883068101480603, 0.010599437934745635, 0.018463646926517998, 0.026062021165021827, 0.036871762547109804, 0.04279462008603981, 0.03053655588467206, 0.011333156510123184, 0.0377799375647945, 0.04251165062721286, 0.023860331092561995, 0.006930782293368663, 0.04960099807275193, 0.021869784154530083, 0.06055158296866076, 0.00721425301994064, 0.025264469407764927, 0.0441579937136599, 0.045749097264238765, 0.02717715105973184, 0.02331409343917455, 0.13495068145649775, 0.16394959895738534, 0.12367442010768823, 0.14005498827568122, 0.215312962819423, 0.13654753219868454, 0.2391312654529299, 0.12557539024523326, 0.0853979272235717, 0.07004186550953559, 0.22955393365451268, 0.18149256546582493, 0.1567380473549877, 0.16198789993567125, 0.07851154995816094, 0.20113789130534443, 0.1350691401000534, 0.1497687327542475, 0.11292816924729518, 0.1416553131171635, 0.2303987368941307, 0.09612264816782304, 0.08385603103254523, 0.15682145287947996, 0.08883636950382165, 0.18066756187805108, 0.16286365794284002, 0.11380459221878222, 0.14761449263564178, 0.07247417606413364, 0.08502521472317831, 0.16287033472742352, 0.10635454234267984, 0.10347745208335773, 0.10640161231692348, 0.07314131169446877, 0.059872294776141644, 0.17170753409819944, 0.10369742635105338, 0.22498315892049245, 0.11404076990272317, 0.2754035219550133, 0.1707204013530697, 0.10259044396557979, 0.07925068493932486, 0.12741002679935523, 0.1302762401423284, 0.09824421682528087, 0.0933911172407014, 0.09286486583628825, 0.07875652824129377, 0.1463640747325761, 0.10798635120902743, 0.133852499670216, 0.10733115100967032, 0.15094592315810068, 0.10635032185486384, 0.156414589711598, 0.097267703153193, 0.1167118637157338, 0.100236409210733, 0.08741362406206982, 0.12434559980673449, 0.2386917376092502, 0.2263135082487549, 0.1186725449349199, 0.13922869547137193, 0.1492455279720681, 0.0967540250026754, 0.07544354030064174, 0.1677930112928152, 0.15976777406675474, 0.08655982344810452, 0.16874011047184467, 0.2331354043313435, 0.09153683709778956, 0.07867211169962372, 0.09132502560636827, 0.07581511964755398, 0.14978492259979248, 0.1219736992248467, 0.10607862964804683, 0.16724947760147707, 0.1030902528603162, 0.08993088720100266, 0.12701577081211976, 0.10811329154031617, 0.10280517994293145, 0.10242008417844772, 0.12671523408166, 0.07347299996763468, 0.1216871403157711, 0.12355425155588559, 0.1114506796002388, 0.1658075364040477, 0.1189721045749528, 0.1709630861878395, 0.20638713320451124, 0.09233899441148553, 0.09058021807244845, 0.07376620851989303, 0.22308592072554997, 0.07919401369456734, 0.13337228686681815, 0.14626176522246429, 0.09144098724105529, 0.16850176826119423, 0.15779042802751064, 0.192484602066023, 0.14134013360100134, 0.08970864662634474, 0.15943297131785325, 0.13446760523532117, 0.22181183552103384, 0.09924992785922118, 0.12887753519628728, 0.16900560765394143, 0.05668442190757819, 0.12004296854138374, 0.08187694794365338, 0.1350132423852171, 0.08633238529520375, 0.13846394579325402, 0.17284889785306795, 0.11660979847822871, 0.13580849899777345, 0.1795848235487938, 0.13159354802753243, 0.155959441991789, 0.06298998676772628, 0.141050928405353, 0.14990689605474472, 0.10809983619089637, 0.17347226797470025, 0.20880501131926263, 0.1879638625042779, 0.15244273069713796, 0.12289983167179994, 0.12732246864054883, 0.13583711960486003, 0.12495466641017369, 0.1132817877722638, 0.1263592881815774, 0.15169778067086423, 0.09119852632284164, 0.09069725857781512, 0.13057311278368744, 0.11501039644437176, 0.10917806904762983, 0.10625496054334299, 0.12936245703271457, 0.10605296066829137, 0.20448135903903417, 0.07669304218143225, 0.1619923918374947, 0.08908461832574435, 0.0936534320935607, 0.12832231713192804, 0.0834722380552973, 0.10965549307210104, 0.14013052279395716, 0.14636423758098058, 0.139967145132167, 0.18273047118314675, 0.1152887586504221, 0.0882921437067645, 0.12136088710810457, 0.2870600478989737, 0.1427446332361017, 0.13966580773038523, 0.12976398691534996, 0.140040535479784, 0.15074325831873076, 0.08413670704300914, 0.1744746541870492, 0.18627843580075673], [0.020472324320248196, 0.007370877561957708, 0.018712034848119532, 0.00797849549313209, 0.01574544751617525, 0.010300404159352183, 0.005875628108956984, 0.01530389763813998, 0.0469104778021574, 0.021035890061674372, 0.06439553813210555, 0.02199692974266197, 0.010870028370326119, 0.03002143923991493, 0.023100153044132248, 0.021100920857861638, 0.002418942566561912, 0.05550058864589248, 0.01985332226779844, 0.017576148567189063, 0.03615303450663175, 0.028665716094630103, 0.08505657661174025, 0.025523813973580087, 0.10437310473727328, 0.03320856232728277, 0.024259691359475255, 0.03412305111331599, 0.010631060211120971, 0.06119289355618613, 0.05911090384636607, 0.059000282282275815, 0.02624963440134057, 0.01290882593353412, 0.07978398632258177, 0.008161057884405767, 0.044191652443259954, 0.02535012597218156, 0.022907868094210113, 0.006263927830981889, 0.10640194479908262, 0.039455450871693235, 0.01947143767029047, 0.026695459049993327, 0.03414116460563881, 0.050999472316886695, 0.06142808736435004, 0.010024686543537038, 0.009141138954354184, 0.04320590051689318, 0.0033736127121041393, 0.03408860189041921, 0.01413476059678942, 0.0614586350108896, 0.00973389866495771, 0.035185033056352816, 0.02250945268731032, 0.03437676214213882, 0.030147158208170106, 0.08640813015933548, 0.016937562297763567, 0.04881052173940199, 0.016104558782119836, 0.03352081735751458, 0.04261957162192889, 0.02997155673801899, 0.03394098998978734, 0.018172787801761712, 0.009216217157830085, 0.05484456063381263, 0.0457481744566134, 0.039193716166274886, 0.029101210047623942, 0.02552686059581382, 0.03811059446473207, 0.04793950329933848, 0.04920088293563042, 0.04045506526849099, 0.05401703289576939, 0.0177867064651634, 0.03230462136811443, 0.06078653928956815, 0.040412829856255224, 0.05925492290407419, 0.012985946527416152, 0.039544315210410526, 0.03344094021511929, 0.13463255709835462, 0.007586655938731772, 0.02983485228781189, 0.009503301931545138, 0.04161351453512907, 0.025806780039731945, 0.02960919528933508, 0.015642717314351882, 0.03345442949129002, 0.06068713390933616, 0.03625053320346134, 0.024377001582511833, 0.08292595629713365, 0.03212447032066328, 0.007452810665459505, 0.013609152952475207, 0.047688024650726996, 0.0391523424935128, 0.03214968807463135, 0.010897022189705499, 0.027996488880099993, 0.06377181517226355, 0.03484136864010777, 0.04714871483987995, 0.03150010275255356, 0.033556331880390644, 0.008377562293649783, 0.03412105282768607, 0.04542297976357596, 0.04901525271790368, 0.046633571053722074, 0.12127460459513323, 0.0646043030012931, 0.057631147892347405, 0.041874733553933244, 0.05669785350827234, 0.044175320105361085, 0.06572236586362123, 0.01461530164150255, 0.06210035950477634, 0.05120309049795781, 0.027345549880660007, 0.007816999917849898, 0.02375801818977509, 0.04875309732077377, 0.03154408199978726, 0.020336054132453034, 0.005955456057563424, 0.07580044293510062, 0.06943376921117306, 0.022709922465894903, 0.02144524345307478, 0.053683115635067225, 0.01977155201270112, 0.067413017286786, 0.03787822675492082, 0.0205965488151248, 0.020665068977645466, 0.03649550470124398, 0.038525725581816266, 0.06370280816086701, 0.032349414857370515, 0.023946021583729556, 0.04089405367683087, 0.018628931271710565, 0.02323531382717192, 0.02820442763290235, 0.039797785359301736, 0.04326531982847622, 0.041950430920613666, 0.03349296349499907, 0.03527632655043687, 0.020572776340746453, 0.034182178654841015, 0.05176015417756779, 0.09864019629146371, 0.02908898623926299, 0.037367520587784905, 0.014322240670610751, 0.02357953803480736, 0.02370394064512636, 0.05478864595560091, 0.0452184319895293, 0.029100942026291574, 0.05607973524768438, 0.04579495944614921, 0.025515130421678935, 0.047956256328948905, 0.024088239130963172, 0.014108362191888903, 0.021399349040750946, 0.04971331258171371, 0.015411416600857462, 0.03133853677926319, 0.0032827905878158553, 0.03691401153004595, 0.0403076162162636, 0.10136117599904537, 0.03755372077492731, 0.056346158630081584, 0.01985622470134071, 0.01220484754802393, 0.030826005352927104, 0.009773688806620027, 0.03916453916047301, 0.004289542748925409, 0.06898499293518917, 0.032414717067565234, 0.053809560635792356, 0.02800580346956849, 0.035364627705088685, 0.044696122873574495, 0.010642322196092988, 0.10318446066230536, 0.030920627061277628, 0.043025644296514134, 0.060237862302788665, 0.031270510250968594, 0.016575591006715382, 0.003876086341084114, 0.03786301399980273, 0.005322673382969307, 0.02793319513356047, 0.038540724598403485, 0.005221944859450949, 0.0012874320943540493, 0.027727220739637102, 0.016764345878203, 0.00614638945054529, 0.02232883175435875, 0.043054526139582903, 0.05342039026852165, 0.03552966099232435, 0.018105207410241877, 0.04796434785904629, 0.01139752912734236, 0.020337412898827876, 0.04648027642230902, 0.06184772056128297, 0.04490495898893901, 0.06299578824213573, 0.05516783168007221, 0.03644509633470859, 0.011793378823702889, 0.028962782118469477, 0.02645017542610211, 0.035887896948094876, 0.039913187202598364, 0.05209526226722768, 0.021767413576266596, 0.037512218180511675, 0.06898476223328284, 0.05920871466930423, 0.04558189605761852, 0.012124157011775034, 0.03768907494044729, 0.004613863404041955, 0.024150460792173232, 0.05701498381261315, 0.044196707529148886, 0.029554817492940595, 0.028507054251219546, 0.051474931982478926, 0.003481478999934292, 0.07284432370215654, 0.02801392723007926, 0.044142994697072675, 0.039059264452329705, 0.030526449105569294, 0.02410193027130195, 0.00819755797939641, 0.044384678692689965, 0.011437876515888741, 0.05571383184620312, 0.11108059981571776, 0.022706051423613514, 0.04478865469406758, 0.008212196524254978, 0.01135559905586498, 0.02587200591473707, 0.02401764434762299, 0.00045035312775455944, 0.044171113188245466, 0.02592481459890093, 0.03824776031875184, 0.10591012904686586, 0.019782629096880555, 0.05337691313720175, 0.06143682011004005, 0.03551740325721247, 0.015304577869496174, 0.03161296008953026, 0.02730234246701002, 0.025414822589872137, 0.03828881847273026, 0.015469980958317007, 0.014008068778951253, 0.03149031149223447, 0.016263958532363176, 0.08021763805299997, 0.04532152181491256, 0.045982099404292445, 0.01900652583156313, 0.03612197456615312, 0.0353406211361289, 0.02430924816456224, 0.08397115128380911, 0.047823317748095305, 0.025823639938607812, 0.06524554573531662, 0.017119048362863914, 0.026780749205499887, 0.015387472796386905, 0.037388992828450034, 0.02474908304533788, 0.042396418417670896, 0.03211267738203917, 0.032886807806789875, 0.030072902728404318, 0.06700182506548506, 0.04332481717158641, 0.048984460798757415, 0.025433634973264167, 0.05005394055375031, 0.04404270722131644, 0.043367357924580574, 0.004522432506616626, 0.03002814995124936, 0.03269988497985261, 0.03428960431899343, 0.04867981214608465, 0.0509392794753824, 0.016516288742423058, 0.01732818642631173, 0.06532449328473636, 0.049153860458838086, 0.01625039631367794, 0.07047925596790654, 0.05852914149207728, 0.03672736690246633, 0.04263992427981325, 0.04358415664838893, 0.02918799128383398, 0.06686562273119177, 0.04469404655641743, 0.014352678055209773, 0.04356637563822525, 0.027490420499816537, 0.059713001895163736, 0.020186803569751124, 0.0409397733663874, 0.056888321680682044, 0.03189185155289514, 0.014807143847325017, 0.030924674522663866, 0.036715054884552956, 0.03501280051256929, 0.02957759252084153, 0.005316963934871767, 0.050752760376781225, 0.016052208109093562, 0.031423333300543685, 0.024276680180004666, 0.042809720882879834, 0.04926115720133696, 0.11612826931689467, 0.13473893781857832, 0.11962649731763772, 0.07799313563321318, 0.1447290496102401, 0.06519848933177334, 0.10308076015540532, 0.09665834477969579, 0.19078859021621092, 0.14899646490812302, 0.12132838528071131, 0.06430942525288888, 0.12531998966421398, 0.08567869822893824, 0.14769492617675237, 0.06652685733778135, 0.09192799896534, 0.21722563090068953, 0.16869915409811906, 0.16296642885676452, 0.17718304028468473, 0.10518858169338532, 0.10692278149404696, 0.10378545269902263, 0.17391680340681756, 0.0920054605230689, 0.10752841471029179, 0.14436179931674684, 0.10050031183553593, 0.06569996742265564, 0.14173744299582072, 0.1498093091483627, 0.1217899519417967, 0.1132298798433372, 0.12007808951394898, 0.09486271041844573, 0.11390141238059316, 0.14529787908707345, 0.09854917760406222, 0.1144530206386532, 0.23718796830092156, 0.13223814272454806, 0.1411247665860823, 0.15668223106435367, 0.13997353693204267, 0.10050462053290435, 0.06269502759511981, 0.05135352849694235, 0.15140499281031744, 0.13186437849487576, 0.08626029773482255, 0.10441991008285965, 0.10441659883196865, 0.1357064609016691, 0.09853268920310906, 0.1127667525517089, 0.1346606755895274, 0.16489266763840402, 0.15516536603016512, 0.10578132952962603, 0.1049589179456234, 0.09368002388094153, 0.13142672340784753, 0.08859918758805309, 0.1271830704063177, 0.0628328380574073, 0.13666828429060324, 0.12674109983657086, 0.09956039155700377, 0.13326811817075523, 0.10505106300115585, 0.06728763758604016, 0.09982550875949008, 0.08850288311285631, 0.11500599953745093, 0.16095682526273386, 0.10003976976232869, 0.10058060966964279, 0.110013562786792, 0.08555859753063746, 0.07900012231298856, 0.10865341898586069, 0.11418396793305874, 0.09220907531146492, 0.12507452283586773, 0.21845368428954057, 0.11005921462284667, 0.16410357212381704, 0.15383535596941197, 0.09193591068365745, 0.08313820205096688, 0.11316010608736958, 0.11411876071776662, 0.1959383860230446, 0.11274549404957465, 0.08464647683181933, 0.16379174457064696, 0.10182517181549754, 0.1928794008812734, 0.19961143178599222, 0.08055889366992883, 0.07872672698327474, 0.10069513281009027, 0.1196993448372398, 0.11399525377367224, 0.11311589274555445, 0.15668388668979916, 0.08113957036818777, 0.1277751736342907, 0.1129601350320237, 0.1972340622118541, 0.12432259746960231, 0.10774665871368987, 0.10566895734518766, 0.15271596317844732, 0.1714526763451951, 0.11452098270612103, 0.15348320986543382, 0.20730296548988136, 0.15665979869663715, 0.16861222019152983, 0.06643015931227378, 0.23562283228550637, 0.11131833134485142, 0.11309589631855488, 0.10267587152442761, 0.111636435346944, 0.12694033128874643, 0.20798232832125255, 0.10914919738258634, 0.16553285185779842, 0.09466377073632819, 0.2088937908411026, 0.07902678195387125, 0.11405592837503978, 0.15232786828918116, 0.09395962780607597, 0.11953675427607127, 0.1320813332817384, 0.13982435422284262, 0.17086301584328922, 0.19733434968761035, 0.12832044437527657, 0.12692834836031708, 0.11106384000075714, 0.10889864832695041, 0.17771809228828975, 0.18337236531078815, 0.14066367489950998, 0.09424002561718225, 0.12849395935024532, 0.16296664598797048, 0.09298080711492471, 0.07829644757189921, 0.18257493738617214, 0.09920859150588512, 0.09565187378653459, 0.12119698018899985, 0.10159913144473519, 0.10273499906595264, 0.12519716125513825, 0.09708659537136555, 0.18022042087146214, 0.2978655823639461, 0.10337577361081328, 0.14739721215197019, 0.11567012247230325, 0.06984176553253617, 0.13281202050192015, 0.15580221185726778, 0.1234899400068181, 0.12401018637631621, 0.09886836726218462, 0.11005563195794821, 0.16805546863802842, 0.10509675554931164], [0.018324228336236308, 0.04157481768301555, 0.04255674606455224, 0.013778541586361825, 0.05945861233132226, 0.03346918084259544, 0.07724482685859714, 0.025979965925216675, 0.012761086807586253, 0.017449725618852035, 0.06765497608908586, 0.025782320548647215, 0.03631687696490969, 0.03174894868529268, 0.00548121945134231, 0.012148502000075365, 0.06970519678933279, 0.035191825191889486, 0.052712732526872835, 0.011448372604458459, 0.027185646318165318, 0.049448799275393994, 0.033465845842978785, 0.05029297487011977, 0.03564643008368356, 0.030526744268302406, 0.03738204123718398, 0.033534391450562646, 0.06323669531515666, 0.043116754586143155, 0.034561452588864734, 0.007415150275586971, 0.030942652307982956, 0.061047469930989404, 0.009249209226774318, 0.013786873996390827, 0.0357123735094709, 0.03920832163255129, 0.046698523818382194, 0.02146193032552089, 0.019269690549533283, 0.06744465058935539, 0.012736326216586998, 0.051223107281007936, 0.05226698251707213, 0.07263401177312646, 0.028344516276514957, 0.035519469396344254, 0.05069599752979619, 0.04040901648945042, 0.05260803796617048, 0.05035042303747364, 0.052268597430416515, 0.024649044931200997, 0.042197780683636665, 0.05089062512187021, 0.07350721170327493, 0.011984087876044214, 0.04357497267691152, 0.04519999958574772, 0.02527115467403616, 0.09378900339028665, 0.06396519086722817, 0.013669959020002611, 0.07010634669235774, 0.032128219226641316, 0.03647293323384864, 0.027116583327629736, 0.0032819286362999783, 0.06143268783177648, 0.061682816195700846, 0.07190669008663722, 0.01801093854010105, 0.04611287685111165, 0.031667168252170086, 0.04290687691952501, 0.09544272893773657, 0.026237536121958067, 0.020853147010451982, 0.0687745860112565, 0.018515965369130884, 0.10338861827871629, 0.01737213005045695, 0.027347558344315206, 0.03490001442176955, 0.02536314875552697, 0.016603567005534257, 0.03738904371857643, 0.07513470508690391, 0.01988144075897123, 0.010760052262672355, 0.028346809724877988, 0.022339547518640757, 0.03336219622620514, 0.03501576231792569, 0.06114709244242736, 0.040166229874427826, 0.03277857129329017, 0.005198411568666675, 0.035383521512682946, 0.022492180578410625, 0.03156480445925679, 0.03705238517639892, 0.08635194745979138, 0.036295214734439335, 0.013946188081588064, 0.03604946631406035, 0.05787770037672349, 0.027308361072625433, 0.020804677557732378, 0.027991625480353832, 0.020046803135690943, 0.009903147350996733, 0.03294758418841021, 0.035353570976959806, 0.029676770591842275, 0.05456576755802546, 0.02011638690185334, 0.01542401360347867, 0.012536555329071624, 0.017597848117085438, 0.0738866145589522, 0.0352031669047262, 0.022040919167920947, 0.04770053005112069, 0.017141132981383374, 0.046647613335933, 0.013038583881487804, 0.09276039179946695, 0.04125808432166066, 0.02995725321982588, 0.10335235736731972, 0.049294520768203905, 0.005286021465768239, 0.038867361178355556, 0.0024459855797301444, 0.045661956404468844, 0.09539937733539514, 0.01033810356498829, 0.05473551666364074, 0.018571549261521016, 0.014233515431572284, 0.046348006198448796, 0.034506433576877625, 0.03889692494911807, 0.013951433157282216, 0.01057792074113552, 0.014690042273806674, 0.0062933745544536835, 0.01593964423851243, 0.03983431429203067, 0.013320076678480421, 0.0039388834848068655, 0.08008366131356784, 0.0703108978590795, 0.030671889694141488, 0.028629543392785957, 0.05457304823877556, 0.04573034934167351, 0.016792525437527468, 0.008189277307662581, 0.03388814228985991, 0.02178983067694519, 0.09290583578071424, 0.02989242259146912, 0.055027690449995656, 0.02682127301315112, 0.05851884811584439, 0.009691781148181429, 0.025045258491965275, 0.0037457300100608593, 0.004585707593443138, 0.03310554714075156, 0.003247482594036098, 0.04076209557907922, 0.056039582937955856, 0.03380902171401041, 0.024860091374388764, 0.051813330966979265, 0.0579994363444192, 0.08510440654520478, 0.03661332552188209, 0.04138015277151551, 0.03676571770172034, 0.028696867637336254, 0.024913466635293195, 0.03116451290303043, 0.03888834487380726, 0.02583654228198741, 0.041639000310429504, 0.07118314105485167, 0.004013968897717339, 0.09347901466701712, 0.024953780097088644, 0.008364173949563077, 0.008604791797032314, 0.023991139073457037, 0.021141000225075653, 0.03811567669202175, 0.036611412053129504, 0.03561254743752735, 0.040025189585451565, 0.03718355617352894, 0.0818476691575987, 0.03413179064435618, 0.12088756822049618, 0.08893519812928778, 0.04608578294781702, 0.01213074813131243, 0.028847736506057636, 0.03494233125820756, 0.03892268892377615, 0.026973090134561062, 0.0714626567704337, 0.07559017850352184, 0.0361000918118017, 0.03354245244658419, 0.04507069455991898, 0.007273064194513219, 0.053778280171432664, 0.03329980153856533, 0.01668000058270991, 0.021379169409296343, 0.05202089482918382, 0.06180664883660419, 0.015425733689750944, 0.050805472369704924, 0.0430912280987416, 0.020600492799920694, 0.0679559131552066, 0.05019927936206971, 0.061685849247234206, 0.07278602397335426, 0.016751721734181046, 0.011875472231102841, 0.013033692492172122, 0.03765934492860522, 0.07055717214409794, 0.06058111959802253, 0.047403464027281315, 0.05217503423669508, 0.01905765853423093, 0.061547224542924335, 0.04659582754330976, 0.04374817552577172, 0.06919062975794077, 0.018326742308480398, 0.019357126572036316, 0.02718150386187647, 0.07744365797511168, 0.11335507633962802, 0.009344509470143487, 0.09273132335926805, 0.03702166450342961, 0.020644375355914235, 0.028046089789963195, 0.036968036488230736, 0.025077271774145107, 0.07713350640343768, 0.05219083731727941, 0.04729560410071697, 0.0583845456796033, 0.03351893103016274, 0.06969241997493164, 0.054558595442878347, 0.0775168447622231, 0.0320143678358623, 0.03463502274826169, 0.055143879393913915, 0.048979765336428366, 0.05611901903258903, 0.04475511470809579, 0.06614932045340538, 0.06870606075972319, 0.01271980643338923, 0.05987946689128876, 0.02711020170577935, 0.0748393184372357, 0.020999296668118665, 0.05647753658039229, 0.035471798918609104, 0.035101060955119986, 0.016645919465060745, 0.056920728513172696, 0.02202627807855606, 0.05724320228078535, 0.043631545534091334, 0.03504669672942587, 0.021876837526048933, 0.03589810211477535, 0.006079574107258979, 0.06448053821389164, 0.024279964289494922, 0.024542711708428602, 0.009137867567395526, 0.05168113538197108, 0.010869195468590727, 0.03286934910076005, 0.05780855765832322, 0.006133665222608085, 0.040230381967765946, 0.03929935049797807, 0.031044517377657548, 0.10268744733184576, 0.020210382661649158, 0.03434194311765688, 0.05845152387129409, 0.03596720412107451, 0.03692787400047694, 0.05262049586911287, 0.01966183290018567, 0.0032455782430978225, 0.010279761427747352, 0.013853713936571563, 0.02230237058496901, 0.015135242670242275, 0.10932046640664339, 0.126077248315726, 0.0750139190682343, 0.030262967172477926, 0.06007968221924134, 0.008043778195445026, 0.08063735945948533, 0.019403855582433086, 0.08631638543946402, 0.01752918885488595, 0.007356468870836709, 0.007375960637416158, 0.04133531178480812, 0.016140470247981802, 0.02322429950748171, 0.013892181783116289, 0.04041517758741975, 0.018526185802849274, 0.06553304780806814, 0.024133974087557623, 0.047854879804487736, 0.05448350536503962, 0.03912831556850246, 0.0331555823130267, 0.0271377112117729, 0.02215971707898591, 0.02638543809631041, 0.019130562032972063, 0.05621210385912231, 0.031216736350740706, 0.027929461494620358, 0.01562682941689023, 0.0163061668031982, 0.04384616616048983, 0.0771040308422276, 0.017703071935102344, 0.10618278477340937, 0.10006708758217947, 0.07344682887196541, 0.12891353826437676, 0.1636576253388609, 0.14726765267550945, 0.12270270367818219, 0.14347114068056854, 0.14100911707750388, 0.09541965196175234, 0.20554994312780245, 0.07420250653688397, 0.07795815036765166, 0.11454794768776212, 0.1788625501628433, 0.09186160431376525, 0.2330457562846797, 0.11059318097042185, 0.1144684369542769, 0.16833214807723249, 0.12135159117834908, 0.09036332435373749, 0.09359483380935021, 0.12352127475397927, 0.08801262120583228, 0.16385989662792, 0.07257374429277011, 0.2031126589115177, 0.1620015792016472, 0.17441026121377945, 0.1612253894231149, 0.08510863381837096, 0.11692463872688157, 0.12687011648501667, 0.10160956731332199, 0.11136268039367028, 0.08500744389103991, 0.1793781282114131, 0.09342862665653229, 0.1302434126181262, 0.09986119970147099, 0.12700924330524035, 0.1451798411352294, 0.14219743545566285, 0.19182422464447363, 0.11366077672157969, 0.12496655434370041, 0.2426848347697939, 0.09755994818572487, 0.15084707417658397, 0.13322955024029526, 0.17747622169554234, 0.16144002362021379, 0.18976712359913758, 0.23202814374651226, 0.12224691813545567, 0.12574539040880545, 0.0890864028728434, 0.24731133079954556, 0.10039783947701965, 0.13854751416615077, 0.15113452875188418, 0.09964718297123909, 0.11142754155610289, 0.14298012559967382, 0.0667643513796585, 0.09820159125540938, 0.13669986331037112, 0.1382644022149699, 0.16438018370951923, 0.12894629793507711, 0.09692608112735407, 0.135421666183642, 0.1949456485786608, 0.1960019376128912, 0.13524034805595875, 0.24809750861355237, 0.14272187517157622, 0.07236377841659955, 0.1494449765554496, 0.13397257322711603, 0.21480973410819257, 0.21673840204519884, 0.12631082721054554, 0.17556724484477723, 0.11509830744138785, 0.12836727686226368, 0.12723073070602758, 0.15618738904595375, 0.17603247559496335, 0.09461512656084128, 0.12970376014709473, 0.07981122271823031, 0.12651721042181763, 0.1483249595122678, 0.13964741943137987, 0.1734943882163082, 0.1364582369902304, 0.10450511372515134, 0.09748178773692676, 0.06678801189575877, 0.222818523645401, 0.08710201364010572, 0.15477938817015716, 0.07888390962034464, 0.09426135197281837, 0.12024327207888875, 0.09088546383593764, 0.13984101904290064, 0.19290168397128582, 0.1661064446504627, 0.13899796642363071, 0.16721665007727488, 0.07565080560743809, 0.1123025803161519, 0.1377499641052314, 0.12532889204365866, 0.10650772162313972, 0.07075611182621547, 0.13978262431919575, 0.07743083366325923, 0.11582018727702753, 0.1189928406051227, 0.10747139741267477, 0.2471644143973078, 0.15681279477264198, 0.16198841562228544, 0.1739271714219025, 0.11797871573695115, 0.07483284521315779, 0.14144460085247243, 0.14493707487625734, 0.15829398243555, 0.11493574402162007, 0.08609204140624829, 0.0798596226211105, 0.1558249427803925, 0.11495059036782809, 0.0456584653417979, 0.1077254612797073, 0.1970131176390818, 0.17378043143876962, 0.12277975811489991, 0.1896879928452628, 0.20296020566352777, 0.13084196192877634, 0.16467284943376267, 0.16527252511254378, 0.15516974936638558, 0.1934417707047292, 0.08848731073417834, 0.1402439602783748, 0.11439264459269387, 0.1520923894963094, 0.10607069078832865, 0.07768571177231413, 0.10744867327490024, 0.11635603995195457, 0.11498516851237842, 0.1249313655176333, 0.11363634267555815, 0.1545887469713177, 0.11873445447002139, 0.13157653036926473, 0.11974153614469937, 0.07751620015395538, 0.11109803816569702, 0.10558378084429673, 0.12512580651257718, 0.13750371017626353, 0.13732005788811616, 0.15029851932610783, 0.10137217505169765, 0.10864213494850056, 0.13063734290855272, 0.13520245866051742], [0.0674397787079215, 0.0683316383510828, 0.010586143737392766, 0.05132259747811726, 0.06496590788343123, 0.02755142079799303, 0.0320148190616497, 0.039669786513383896, 0.03456826847312706, 0.04187687433191708, 0.050880365672388246, 0.018596103747508357, 0.011922934059319752, 0.04494194932548063, 0.009626505231218678, 0.012638007340553616, 0.024810202087142637, 0.022414585010015538, 0.012948098692244716, 0.003368095162191561, 0.027960796241781542, 0.06285197274493319, 0.013438950924734985, 0.05985339757587228, 0.02159775437654129, 0.0892040744157774, 0.028238154216004268, 0.049338367701108964, 0.031667168252170086, 0.015605214683871185, 0.009861428473543907, 0.0861521799649511, 0.008161911990360489, 0.09331205434032849, 0.021200171871376888, 0.03701936766239149, 0.040417454072407315, 0.03367023416129606, 0.011312714794517627, 0.011904225152518069, 0.027457506462399448, 0.02355351112782955, 0.06423438606517655, 0.04920633157183017, 0.015622812489579831, 0.05586286527769906, 0.01848760769436402, 0.08174197375774384, 0.050089424542550526, 0.007456208429565387, 0.04213121300563216, 0.07943556537585598, 0.039725327997335365, 0.04207052822623934, 0.06332917285284825, 0.028574103689087287, 0.007892225702692355, 0.06987798573183161, 0.10676570063722984, 0.019349279314545647, 0.013320037662716848, 0.03092503414622375, 0.05174742825329304, 0.029611485345023017, 0.04226284879924996, 0.0348851782535868, 0.030588558808501278, 0.03237494134477206, 0.05495929751279099, 0.01203264553831624, 0.020706164451049905, 0.014340267649718692, 0.026084441658375517, 0.04432467584099088, 0.03183237456583551, 0.009921752781208073, 0.03001475227730615, 0.09358471685222217, 0.04475107403205974, 0.02816126771670367, 0.039390966296195984, 0.04008402196424348, 0.01687484869866499, 0.043284220421420674, 0.04316560571481075, 0.010405663600457566, 0.14388160008404935, 0.07718797240938459, 0.03528616191553218, 0.02710842733670558, 0.05813381341951234, 0.006028997379222086, 0.07442175477210965, 0.037024775586490116, 0.01544409993636821, 0.0035406279577208416, 0.029140924702265432, 0.06002132820763758, 0.0739946441192712, 0.03925975119428975, 0.04436035660494651, 0.053741578212273974, 0.040738472382404974, 0.06154124664941004, 0.0564337032181876, 0.024598315956869295, 0.02896280925987022, 0.025846689773191298, 0.041060002986341715, 0.08854531190757241, 0.07726483685629708, 0.0213559211032199, 0.05449435513998781, 0.01833892540474023, 0.03977940723832164, 0.059868216780679565, 0.05001931491174868, 0.021220836655369828, 0.024148325103202035, 0.02762667372423623, 0.02379120873021228, 0.024644150997378995, 0.004992510965426585, 0.02345119313603001, 0.04408313773040261, 0.026670748500951698, 0.04317885750372495, 0.011086456444380539, 0.06004061217286757, 0.04233311788578119, 0.04425465441974146, 0.02287898794747889, 0.000439952431666565, 0.053910618248794756, 0.06990957832229988, 0.04621970879712275, 0.006912502559966275, 0.04203978380454438, 0.043811398026134284, 0.039733053118522675, 0.04718104024816837, 0.08220597635954618, 0.022975570622033308, 0.05774811375886202, 0.06447223294526339, 0.026686069821672778, 0.04629750283701079, 0.06023599633148738, 0.027093535189383795, 0.035143069058124504, 0.013493704459896045, 0.027807666155110513, 0.03628975931288941, 0.036185044396136484, 0.023748201484392797, 0.013464961716506098, 0.03891690441274217, 0.04023155244067311, 0.05539538857660123, 0.029963977501860688, 0.06234347860195807, 0.049816385443721495, 0.027173756688301052, 0.02640375175646373, 0.05522571071716292, 0.01988339833250003, 0.02221236630742039, 0.005743010135899697, 0.0558835809518184, 0.08289275557867118, 0.030283767663474594, 0.029087907368583337, 0.06875771763069288, 0.054359788075089455, 0.03861958393827081, 0.027886705306757773, 0.05107396528390901, 0.006165480033294963, 0.06956332190228359, 0.017131082181419646, 0.10194591033671584, 0.05700229520776442, 0.011413909810861307, 0.02059988211840391, 0.026904551312327385, 0.038853346037545373, 0.06034538974719388, 0.051660355247024975, 0.0238289013504982, 0.01821076201408037, 0.08858874493411609, 0.031493972188660076, 0.09918885292219264, 0.03486101222889764, 0.03541627100535801, 0.030138825798141103, 0.06984973831900529, 0.03802077339163848, 0.04988984703751547, 0.03553068558020251, 0.02682430436834693, 0.03652904468721577, 0.042072417946266275, 0.029832250106015375, 0.02409159448663039, 0.039780798235109875, 0.0561990556307137, 0.049737777161811075, 0.05145445718829121, 0.04356954778943743, 0.07520923537335225, 0.029786164007548774, 0.0503720309851425, 0.06621250563434192, 0.008853762410581112, 0.07438659308744328, 0.048907725273498466, 0.02510271853368197, 0.0776754862495831, 0.04172579511733992, 0.061891879620296616, 0.014669089112430811, 0.002246115668510486, 0.10061620561672108, 0.011643772030116191, 0.01563963506902967, 0.07589822661663805, 0.010146521746979227, 0.025792573212778995, 0.053923432382621934, 0.05721683440996068, 0.08662894581045423, 0.02616646806044238, 0.02478708270271974, 0.06584083129252706, 0.034249950732503615, 0.02348138964069741, 0.03543350240215659, 0.03302976495719381, 0.01219394349027425, 0.05509154738060065, 0.008416010632312723, 0.04488863682906542, 0.03645987822008984, 0.04134564587314214, 0.036162690059947114, 0.02392862903486405, 0.03779205620022757, 0.006691064352967909, 0.04043319608483996, 0.03408983003880296, 0.01973113846699042, 0.015297495660239031, 0.07864172011613846, 0.11000469433409826, 0.02201647324753659, 0.051422749246869764, 0.11199983156153134, 0.03900977210806949, 0.04528038902208209, 0.03514346260843532, 0.03978129356567349, 0.007944835067194487, 0.07149408651249749, 0.06604435108602047, 0.02126147920664932, 0.007215158864190536, 0.01628097958330597, 0.02045464509033731, 0.02327131010991122, 0.027224551819797074, 0.052150946243533065, 0.02481056340704007, 0.00431007394633655, 0.012321803236513265, 0.023579819626840096, 0.0322413852970515, 0.01709792047872075, 0.02584402821958065, 0.04621461978448289, 0.03177783052836146, 0.011550865319025303, 0.04953599441796541, 0.01769897188725216, 0.023591140983626246, 0.07098664409880127, 0.07032619882375002, 0.025142423010298183, 0.026125187686245357, 0.036552745915417156, 0.03821679537317582, 0.046916262313191376, 0.01553370218191828, 0.03417050785252026, 0.052272804347532134, 0.011471121339127421, 0.011174751661850937, 0.027344588057271073, 0.0051249482785351574, 0.05254147707351616, 0.044298043341508934, 0.011423578086708273, 0.05283725048814501, 0.024796003741877418, 0.03506002315719213, 0.01714316349742668, 0.032438177415835004, 0.09722114208021335, 0.04064174721549664, 0.05448944254645279, 0.023880744818598032, 0.06538077097918306, 0.006456701750201839, 0.030232260070208992, 0.04720000530193959, 0.06050824493701969, 0.064102831695761, 0.08055045269429684, 0.04879549218873892, 0.009287614308829819, 0.028025923729208962, 0.026827573210799267, 0.03690200485289097, 0.0790275554837925, 0.05310948213030185, 0.01885989441403321, 0.02773345647645848, 0.033118744646864276, 0.03150984990809645, 0.004437762786567743, 0.04262111868177142, 0.017467869645250694, 0.010844638438097067, 0.06050219919000353, 0.07289393818272011, 0.02078586517434035, 0.05265945734988366, 0.03995344807792987, 0.04352159232699445, 0.047783307930720706, 0.051105863215135675, 0.013863446673245301, 0.03069795561688287, 0.019908739919109002, 0.015867337850587707, 0.021028438050832068, 0.00961203801645232, 0.05060280074498483, 0.03428678839866604, 0.020670912860493575, 0.03393853030034474, 0.05213563170816217, 0.128704983741045, 0.10373102061982666, 0.14797687104770116, 0.20420356680239948, 0.21610804301287445, 0.13202186647270406, 0.08800323028117418, 0.11094635844762836, 0.12939257041684218, 0.12897953258029052, 0.16574416123330593, 0.1774499352489199, 0.08593473663287503, 0.10247334917741162, 0.18983565563602106, 0.07336282623665673, 0.1301991721349103, 0.05343335707272802, 0.16231100474085125, 0.04716081311926246, 0.12863776806209767, 0.1205737322036709, 0.13683212335620606, 0.15765336395374366, 0.1654660025877612, 0.24482295289635658, 0.10497113836130925, 0.1224149369767734, 0.09569990049515452, 0.11149461474269629, 0.12284831729318414, 0.15164607630244323, 0.10414298637104885, 0.14955901115068368, 0.11988139578274318, 0.12828564909952028, 0.13831454595284803, 0.1494041694594281, 0.15185460368437426, 0.1437228907431875, 0.17533118251178945, 0.09174749507967915, 0.301967733672687, 0.20809717715850898, 0.11111928309713091, 0.145315982401371, 0.16146899706551007, 0.29182412368910654, 0.13039302958973817, 0.07018771661179406, 0.18719574729246752, 0.10922952914344412, 0.09643763769418001, 0.18005447834730148, 0.14020824219499314, 0.23948046671492712, 0.10054409770028931, 0.11217992154083081, 0.18167140015533992, 0.07246477156877518, 0.0897798588765519, 0.10200524822409664, 0.10094820601599556, 0.07901005606566157, 0.16568279452621937, 0.06204522174916097, 0.08585969065981251, 0.10843023524752685, 0.14538925061268465, 0.11117763710873467, 0.08484040892549924, 0.14014604767518385, 0.0649620605898755, 0.24314984838877404, 0.14018910750746727, 0.09182942818318095, 0.08231699147394725, 0.13243208160357817, 0.17106498857694014, 0.10818508054528918, 0.15684294886887074, 0.13217440114489623, 0.12599217359508785, 0.15710882603057794, 0.11154908753399338, 0.11178466132176773, 0.21967328313205922, 0.17736887745559216, 0.17358924741191523, 0.11378296730773789, 0.09858231046902281, 0.09095503403139965, 0.1828707650836025, 0.09199447504111699, 0.10293486155569553, 0.16808320714959077, 0.08661519190562622, 0.14454234391450882, 0.14494400950414793, 0.11162581627390214, 0.1771280382360731, 0.11282779356198651, 0.12207021404589925, 0.19504768667476519, 0.14912491158715316, 0.1730616321521146, 0.12987788580358028, 0.05778891406953335, 0.12842120682554586, 0.08932316409690039, 0.10897362644651107, 0.11889701788978917, 0.1542713011481932, 0.125465277582407, 0.1274429221770593, 0.1512255338685853, 0.13564957252570561, 0.12936722034854548, 0.13728615827858448, 0.14714072591492108, 0.13734900419201168, 0.16099854159568036, 0.07002079021185637, 0.15903631331665175, 0.19442381443721907, 0.05949458147266081, 0.14929842656212194, 0.08695141957806689, 0.1253445390611887, 0.1451798818473305, 0.09276959951967001, 0.2928491729710783, 0.09868813479053122, 0.1755576775010143, 0.10711783317050763, 0.21061397210827895, 0.0798546082473227, 0.11776571002389703, 0.16815958305128983, 0.13440013171306678, 0.1048183933432613, 0.20884949607508524, 0.1034845495596528, 0.11712251310901982, 0.13036758452653885, 0.07723713905683585, 0.10591154039970466, 0.1421326082199812, 0.16844120222542966, 0.08440814140651907, 0.10572213413459913, 0.1859124611530985, 0.10313304127859217, 0.19354460947215557, 0.12876553620610917, 0.08647869780127491, 0.14107021237058298, 0.1182573629277093, 0.1900903641113213, 0.14679228461214475, 0.13915499299764633, 0.1293105219623872, 0.11370590608567, 0.10870494693517685, 0.14780996500381402, 0.0732977275869676, 0.07952244499964373, 0.16577913292816707, 0.1621263889329774, 0.1916182485542127, 0.0839958092463868, 0.12207155754523617, 0.1541032823068755, 0.07484569666641099, 0.13028652673321112, 0.1138528971267598], [0.04632717856605138, 0.028541730783347572, 0.02706184421133782, 0.030584528310490505, 0.008592770701008183, 0.026815610638420497, 0.03872569663716214, 0.0076892886011462125, 0.0400255220676107, 0.02652418493692364, 0.004070759734271893, 0.01576544394317482, 0.04770486928256495, 0.024812972206356268, 0.02549373112352831, 0.03957144304045609, 0.027854834516931857, 0.0804297820265804, 0.03760063468611666, 0.03006524546071887, 0.027312607005504624, 0.01119090333980109, 0.050609684482749016, 0.047035053438906155, 0.04037930004830871, 0.053110649210533926, 0.02002709678241185, 0.029172822633492093, 0.020718167735529796, 0.0893213524084006, 0.0329822301864624, 0.028486796588237797, 0.014877816662192345, 0.031255579087883234, 0.03694162790530494, 0.07780748166676078, 0.03916544161204781, 0.0061308917107193595, 0.027528920576774647, 0.006841409901556159, 0.0355184923059174, 0.03737417023096766, 0.03200529582266297, 0.0193242261053196, 0.056797347098056755, 0.039694610717041154, 0.018143376701378396, 0.028689793909766843, 0.02456644855971847, 0.04012591132361974, 0.009857068886049092, 0.04085856629535556, 0.013898639740156276, 0.023058777675032616, 0.03100918945191162, 0.047280255638595135, 0.022438572919262306, 0.005112305474800191, 0.004686443750480456, 0.06534166700605835, 0.014791403531229921, 0.007911933752309, 0.057977614658219476, 0.02982842656118529, 0.058781346173158715, 0.015533549511539084, 0.03435662661546043, 0.02069858182221651, 0.08408724184014968, 0.05260936110945685, 0.0675707088251199, 0.05553929228335619, 0.032126078448657475, 0.061772281037909646, 0.036806270347109864, 0.021191700361669064, 0.05392010077568037, 0.011183067108504474, 0.02961205192176359, 0.02562636266728597, 0.014109737073470439, 0.012005753499189658, 0.012502263865566679, 0.008343079992170845, 0.0727341974686299, 0.02832690829278103, 0.021031466013352786, 0.07119293231517076, 0.04095665531765137, 0.04372155320431505, 0.025215221336111426, 0.06579039578459092, 0.02663641462900809, 0.037165327330252955, 0.10340786831719534, 0.03318897641396948, 0.02096419774794153, 0.023115340354187146, 0.06167288922837802, 0.03813694876485637, 0.04972319544426032, 0.03529451807428684, 0.06325099883334977, 0.01813869141707463, 0.063685743005148, 0.02129586736139442, 0.016825178238962377, 0.06472976412624121, 0.04078180702137096, 0.0023634897162472563, 0.050468851146953445, 0.05349094433976071, 0.03159965741048966, 0.06657323520630598, 0.02373398787208966, 0.04225159190329058, 0.03994071197562984, 0.029610447186444486, 0.013472408638335764, 0.0243740567405309, 0.03845529364688056, 0.036576277509863885, 0.058177388938409944, 0.043231674669576545, 0.0683173348328897, 0.05211507548977222, 0.07016072448875223, 0.01011696900241077, 0.03818007645064166, 0.08958836950893913, 0.022013901599815915, 0.04311425418459943, 0.025717327071885978, 0.03998398893911924, 0.04610446301688041, 0.03435331875724452, 0.015526262045438801, 0.04440292449934142, 0.025111865185733353, 0.04947109254343169, 0.01294366192139153, 0.03579477480213557, 0.06330000263239656, 0.07871594506182841, 0.07841960167778389, 0.05396944723491158, 0.0459420115553907, 0.05579642991402319, 0.049526213335671594, 0.0393776534391301, 0.09028930296855313, 0.024364976245643835, 0.040137833183897395, 0.058029916137456894, 0.03811141209942954, 0.04981637526569622, 0.07191021846873419, 0.005450863490945527, 0.07085749852870192, 0.02342742744700185, 0.029331240204295943, 0.02952933171764016, 0.03558375041133591, 0.01210682129021734, 0.03621837742892759, 0.02132861176505685, 0.01722298635702048, 0.030566201079636812, 0.05128643834697349, 0.022470223185207163, 0.058676275025521, 0.043704691609101634, 0.013584152329713106, 0.0648853929181184, 0.02921301904799683, 0.01238758466206491, 0.07209805053259645, 0.04228936594777873, 0.023045714179586087, 0.009203617610702557, 0.029581341426819563, 0.07488653768918344, 0.026691297933991467, 0.019313327136582563, 0.03825794512938176, 0.07329750367041145, 0.04819690555866275, 0.06082923271294151, 0.032768070963876586, 0.006719573001776422, 0.03011944005265832, 0.0233584238282804, 0.026805756613612175, 0.041695379785129, 0.0066754834926021946, 0.03396382947851505, 0.09104031909789358, 0.026879481139725873, 0.019043640000745654, 0.004827398374410612, 0.03894291944535715, 0.0584300821647048, 0.019696933516700352, 0.05466968519613147, 0.019772473123988936, 0.017361619543018084, 0.02307807860363807, 0.05279877755258765, 0.07210869674703904, 0.02513970887022359, 0.03157962705673916, 0.06017756089568138, 0.07966465236885206, 0.03513301656182323, 0.034776928169386725, 0.038511900430811305, 0.01406100214392479, 0.0205947914094265, 0.020820071820967963, 0.004091036905135427, 0.04540306815345373, 0.026219283529956425, 0.023138429204534208, 0.010295740079267748, 0.04788405002493944, 0.031083197266395603, 0.03762733843177557, 0.06420114463461296, 0.03218331627015557, 0.04834258702716657, 0.020500598874475275, 0.051073463167995214, 0.021964828250929713, 0.04742639172556145, 0.031667799289737425, 0.053767545747437646, 0.09680489477302347, 0.017848410743421743, 0.05832197796553373, 0.027479945615466152, 0.028893303525234972, 0.12117860546069485, 0.027009125433063934, 0.07213811124009745, 0.042072533297219446, 0.04006817817155804, 0.03184125319655452, 0.025911238809515322, 0.008989497403880315, 0.011003488574975302, 0.04077838720487697, 0.02261292588497911, 0.03867215683151569, 0.03714885589267526, 0.016346371699390665, 0.019858065227578794, 0.0523700146669788, 0.013595784116270286, 0.024955545984474675, 0.03708960282217179, 0.037506399742726765, 0.05333973281085491, 0.05020313344097563, 0.06562256014772824, 0.010604733052397413, 0.011349090208698596, 0.04562925440924508, 0.047498313044863086, 0.04437144386715122, 0.03668905342263835, 0.04584602599165269, 0.08313354051538877, 0.05326057830825448, 0.03548515248777611, 0.0030675272615293837, 0.008983883374769772, 0.02052416778834803, 0.019242854489545737, 0.012508502146894378, 0.05742162984928914, 0.026424453859882693, 0.028708314523100853, 0.08591520160968814, 0.0473380566441587, 0.06914851308933326, 0.07925253055457558, 0.028483268206140826, 0.028601200985057012, 0.04053298823003258, 0.05102895466344697, 0.0337956715375185, 0.04380059235596231, 0.058326300233602524, 0.011163302231580019, 0.09735722227820329, 0.01925158384256065, 0.04541521393028753, 0.01006199833604374, 0.017991618951782584, 0.049222348390945365, 0.03160220191680959, 0.03884612303227186, 0.0668150515162519, 0.029297571296670606, 0.006518579903058708, 0.08698066443737064, 0.05021529957386, 0.044100698216685226, 0.003839235528305705, 0.07274582077349935, 0.02592736928324614, 0.06106014496513775, 0.047801519810621224, 0.09122368640133313, 0.02058664390019008, 0.0453309873784227, 0.02327384952721851, 0.04057094547897577, 0.03287256535674844, 0.011515466995271189, 0.07577462467764105, 0.03933042061648198, 0.07903155205505234, 0.00969439181166568, 0.044255370274186134, 0.021820142532565763, 0.11470128303127629, 0.0029610519704874605, 0.013015733366566045, 0.03604751891855683, 0.04755004116200975, 0.0970250251037734, 0.03470052851896201, 0.05458692088723183, 0.03793944079162819, 0.02334607788361609, 0.03772506443783641, 0.0268630758593125, 0.11553030354636055, 0.028252905567309687, 0.04425951951582517, 0.014201418180683894, 0.0305255432613194, 0.019981697700651627, 0.008209551934019794, 0.0228932151304824, 0.015688450574608784, 0.02826506152216877, 0.02363595143625779, 0.055749349761754274, 0.040872815530747175, 0.02612110460177064, 0.23677807886685642, 0.08115403673478536, 0.0838119126856327, 0.11129464368735041, 0.11865752216960702, 0.15546621488673346, 0.08328428385513169, 0.16114167177251407, 0.11613892231668745, 0.16637309534209116, 0.08902793351028647, 0.0722064600725259, 0.11582390564892973, 0.08016625938138791, 0.10549351533076592, 0.14050800539553165, 0.1127254365544234, 0.11703408642538957, 0.12744449637830257, 0.18956292527062552, 0.13880292831787042, 0.053366473875939846, 0.11151178846401827, 0.1166783712272133, 0.11910175904631615, 0.1857913697936705, 0.07954728616667645, 0.12199864217213222, 0.10090492226715599, 0.1289901448679822, 0.10010826787246124, 0.08703631109425, 0.16167409106024674, 0.09832148839320455, 0.11636743934026786, 0.15401108296854155, 0.15025484881230763, 0.05990923422255686, 0.085995099108134, 0.09595744524683271, 0.06417255116892712, 0.10797514181051936, 0.0987970396610243, 0.07088602414088589, 0.11061270920825855, 0.1393494882753917, 0.1534819613609995, 0.11150299465017659, 0.08892160028751407, 0.11379605624824762, 0.11099268203335148, 0.11817907355725765, 0.08006033327962671, 0.11652434377798013, 0.11300158673631293, 0.14463489609105246, 0.11729691017951284, 0.13838600926101208, 0.11980028370661394, 0.19183635685060704, 0.23584531034742082, 0.12880843318998814, 0.14365781923489912, 0.13398967230958597, 0.08274476709110395, 0.15631346085241862, 0.1017568094123687, 0.1315123409565006, 0.13239622781319277, 0.1386247585926737, 0.09791880500103746, 0.1556535041225808, 0.13022100739181042, 0.09895556579743113, 0.12434652261435986, 0.10707024750964982, 0.1332150295908962, 0.08810421664799963, 0.09589892838682447, 0.09340135633413281, 0.11878679666135993, 0.0658026026295764, 0.06618118445788111, 0.08169826253184251, 0.12851598459695066, 0.12063481392604963, 0.0989644138940743, 0.15599434583314828, 0.156006233766675, 0.1604851891419717, 0.19357365077095373, 0.16738097768809113, 0.10424973350018263, 0.11402413222406592, 0.19143794822905744, 0.10312197437243802, 0.11928174724536282, 0.10996784988258566, 0.1855607493115323, 0.07725469954311848, 0.16531641275754996, 0.14397996052035264, 0.24690022000244685, 0.07061659824103117, 0.11449536122381687, 0.09792520358626332, 0.18028272395687445, 0.14928362092801503, 0.132571832676019, 0.1398712545633316, 0.1462971033262355, 0.1344895897699254, 0.10481487174651452, 0.1323183998465538, 0.09119534399360418, 0.08530291196491037, 0.09917750103133065, 0.12634942228240625, 0.16374639129000051, 0.07581760308572225, 0.11701086695705142, 0.065904321814222, 0.07310972588935069, 0.1144056317529508, 0.09388575569859572, 0.10899202831621681, 0.15406474151781627, 0.12679808320743696, 0.0722954227988209, 0.22364592924714088, 0.12900381056325777, 0.1301748262984412, 0.1106642914403762, 0.21567063219845295, 0.15151981450617313, 0.08991549802677971, 0.07504798152617045, 0.18465076599802288, 0.13361353320734842, 0.08672189153730869, 0.1128606821543404, 0.11179077492228576, 0.12709553938891205, 0.11330653394439391, 0.16444651729294232, 0.09638258814811707, 0.1330950374581984, 0.11857433377632073, 0.12124249631805079, 0.13106331362255982, 0.17741135374775954, 0.15728846139141492, 0.1024025236921651, 0.14634754561952182, 0.1488540946905102, 0.13423067437750952, 0.10971692084733929, 0.12950636073946953, 0.14881878372813973, 0.12662904656359128, 0.08866275274860007, 0.1039434631488153, 0.18951696130846227, 0.09247009416243859, 0.15034152487558977, 0.10698254685848951, 0.1468720260475363, 0.08849814693842616, 0.12337961021278586, 0.08821726058210645, 0.13044233194419316, 0.12098858851407256, 0.12176749243267945, 0.17437533023101942, 0.10991884608353887, 0.11175593214907817], [0.007200664508023432, 0.029303566153560365, 0.03993689860882504, 0.05449675376127873, 0.04486258447702442, 0.05144081863441637, 0.023197555049721683, 0.0453190892668707, 0.031824629088597636, 0.017816875828430057, 0.0148636064425643, 0.04410367698541709, 0.0037105509379346457, 0.016753596187170063, 0.0325733755183007, 0.03443402371236256, 0.04954154822709305, 0.03934587764420679, 0.034345949866942, 0.005240597363029207, 0.042761907912790775, 0.058315993286669254, 0.020179027558437417, 0.03283486934378743, 0.03294655620785696, 0.0173144715372473, 0.00825570588598826, 0.014474317331665328, 0.017273286157952886, 0.04531329118513635, 0.044957389389829974, 0.01798710160489593, 0.011132243139270161, 0.048089730952467234, 0.08285846241882869, 0.024881414337349788, 0.07280030713549682, 0.052559465036860535, 0.043688271061650345, 0.04627127406586494, 0.056145295301186185, 0.013781663695616382, 0.07654601042824132, 0.03743175410532525, 0.024967920766877275, 0.06265235452779702, 0.07833388234887805, 0.014471516678375857, 0.030126194868768965, 0.017135189014620016, 0.022304206022194455, 0.040816561585026126, 0.03131820447742939, 0.026905586078230823, 0.06413888904665198, 0.022998087806627154, 0.003307945153210312, 0.047488939083580456, 0.02814760202142809, 0.022974296672535793, 0.018659855505185466, 0.026940722317833985, 0.050585321682904444, 0.022756459790148904, 0.0720871329041464, 0.022367857695956315, 0.05155958940408059, 0.037693587198321304, 0.0224859685903149, 0.02903100542191948, 0.029437970370054245, 0.0234668859546738, 0.10189003297793013, 0.02582376546758626, 0.08008185641041823, 0.03910927926855428, 0.015202237825308527, 0.027299694484099746, 0.041784026992640326, 0.03920343278774193, 0.02772457106038928, 0.03271105366625956, 0.049735066414411576, 0.0366175901144743, 0.03745154697181923, 0.04636523759524737, 0.023878639663702676, 0.016860574018210173, 0.010389603524734932, 0.09091141101505075, 0.03986950990344797, 0.04957832821777888, 0.037009600150798044, 0.02959559066221118, 0.017949083287801062, 0.07417624044631209, 0.04206769873521157, 0.01990375777573458, 0.05470639733331544, 0.05920747973557029, 0.017896713955061774, 0.019173484461914216, 0.009506173831011568, 0.02672881752784763, 0.05036526259833148, 0.06546697206795216, 0.03716099827683397, 0.02761084519858871, 0.003882660497246044, 0.07922424242964812, 0.024528856023347805, 0.014376235094719698, 0.027838480126644884, 0.022163505000727515, 0.03985963382625154, 0.053589389592941315, 0.05479298857972026, 0.008084826171398163, 0.02256418501825205, 0.05724387403045382, 0.022542197090972747, 0.02192282014792519, 0.04218849493190646, 0.03812959683792932, 0.040904900059103966, 0.034582833227302344, 0.041951021246079884, 0.007674754381046763, 0.062061852642468045, 0.010210735756637794, 0.024311336356082132, 0.026759568734892776, 0.06999149106975112, 0.030293894798627923, 0.029772070835211446, 0.023934350781408802, 0.04356633831879922, 0.05971956332879407, 0.06913061333554131, 0.07719181970294033, 0.02557280589826405, 0.06039807799139193, 0.02724668732844293, 0.05806258759860482, 0.022866635217464397, 0.0311930419078895, 0.01251230194299881, 0.015948673843273094, 0.05801502907914775, 0.021279263609488095, 0.00933135352430067, 0.031107716129294465, 0.06891651518110718, 0.0870265741167324, 0.04788269634757723, 0.05478489365694778, 0.09312701784074306, 0.02707976771385542, 0.03561389772221446, 0.015385695034638047, 0.012874867800357086, 0.056377428916416, 0.04828638057889683, 0.006852828373666853, 0.03202752802254898, 0.07398750593087502, 0.013750440058564501, 0.010798925533890724, 0.02164922295404332, 0.019716127576040368, 0.04532825627497264, 0.02042975303317819, 0.0321279240639082, 0.03748520909409438, 0.01776104257442057, 0.04085368084322129, 0.010142928904055484, 0.07270429443035807, 0.024917091708630323, 0.022021753946319222, 0.05244342537064638, 0.08326342568865844, 0.02616216614842415, 0.040923756547272205, 0.03451059299654194, 0.05798444750585726, 0.027062967186793685, 0.04558459323431764, 0.027629520178639462, 0.02688845306900995, 0.044867300295404026, 0.030149946987096752, 0.057274971290358474, 0.013446821930951305, 0.053809709913496456, 0.021503275160544684, 0.053854669643832107, 0.057878195707287104, 0.04082349621291671, 0.03508643174011793, 0.036973726004362106, 0.02807451192555683, 0.030443189466106038, 0.043934816760676246, 0.05115923677970256, 0.019421811315364072, 0.012993171229027212, 0.0038661585255925146, 0.02449712433320071, 0.030516854620405605, 0.0570590343060238, 0.04223190760239959, 0.06468877382576466, 0.033785330663834295, 0.013148008679438914, 0.049291921979082484, 0.018003230382289206, 0.05965469538101128, 0.04798165050202182, 0.034096276121480126, 0.03758069932726877, 0.04239684250205755, 0.035764668203358135, 0.051122497501117845, 0.03268020407163671, 0.034680057117449384, 0.07312104385346174, 0.010570681620655316, 0.023188126805637563, 0.0440950901247561, 0.05781031506402152, 0.027508790139108896, 0.0521681471062558, 0.028691771839346205, 0.004429211548995227, 0.003336259995454124, 0.015943425374903848, 0.00731802053217377, 0.042060502871338806, 0.043431153787033897, 0.02115600263433797, 0.02267189057809966, 0.04871808152113642, 0.006773105597988303, 0.050322691311261485, 0.056062385107257535, 0.06982894122068371, 0.01582510583102703, 0.06820333416440658, 0.03885996514665229, 0.027878169336223176, 0.009241266974381037, 0.0028919429667959256, 0.02906035884682621, 0.008828266457255398, 0.04788608902267047, 0.01919178115869207, 0.03598115819373301, 0.052952774467745, 0.00482067366829142, 0.031019533718270913, 0.014757539544786726, 0.032890773843973875, 0.03357051665495549, 0.038948720919766595, 0.03761264814862183, 0.10274148586073092, 0.05154406452285392, 0.03532791217522962, 0.04498455114662647, 0.02406184920775039, 0.029530485227171863, 0.046674432432545085, 0.026896585311208452, 0.03036789582776172, 0.03302195841180427, 0.039667408248143535, 0.053819854012025256, 0.008759877760894597, 0.018747958188344325, 0.04134513357920306, 0.010556224583914238, 0.06968043704650231, 0.018680371011474302, 0.016031324497557113, 0.09266125783324242, 0.053753961476364305, 0.06694530988378183, 0.013950987020507455, 0.04565057058685592, 0.08558889411922012, 0.06533389099474464, 0.04276033371154751, 0.015905427413859537, 0.03194573062605091, 0.01930185141307967, 0.03597647290942924, 0.00716109573841095, 0.04118372706164207, 0.01948969535130475, 0.030975866597145796, 0.006963103460813207, 0.047703630956155915, 0.013407635685455586, 0.10809986333229712, 0.011642818688414991, 0.030879066791385412, 0.016745452070608735, 0.040500367659011056, 0.02378035386625145, 0.057339778169989586, 0.05414425142641578, 0.020832948719284365, 0.047835127650094886, 0.01712074639674808, 0.03262375335076025, 0.03950015954407198, 0.02453784491600735, 0.02252361032047442, 0.09598160787884678, 0.08429809659719467, 0.0270028405024537, 0.03620586524318371, 0.016707649188382283, 0.057994184483374865, 0.03258728887885809, 0.012650327840154725, 0.06881221756339073, 0.03829088800453714, 0.05226072981687529, 0.05105964480234044, 0.022297995730436275, 0.04534952834780727, 0.06738978424774748, 0.07132646800684077, 0.026601324190518687, 0.02024747647478112, 0.05277268788112061, 0.07130590839577572, 0.022779161875535334, 0.030408346692898443, 0.020524574909359217, 0.016620180935465863, 0.048417884058185985, 0.05302750152934875, 0.027045143768191338, 0.03250821580045989, 0.01860367619831647, 0.06987940387002059, 0.05159410648047924, 0.10929840044783694, 0.04391598062855857, 0.08406166106994663, 0.15800332517496177, 0.0884508259062256, 0.14752789799656185, 0.19007401141737187, 0.18623521312006883, 0.08748922643384763, 0.14414613374641963, 0.07728228199162654, 0.11331293252961976, 0.10789541394582816, 0.11540516811822142, 0.10889641594673906, 0.08444009362054722, 0.13428114381219658, 0.11182886787823268, 0.13562904005604132, 0.22785306349396706, 0.14205437313233102, 0.1062595270840185, 0.20355446663286003, 0.1341838011784213, 0.107750010676682, 0.17621030605265073, 0.08828970098069736, 0.07453515154442616, 0.11508143906082426, 0.12909436784684658, 0.1379481234720775, 0.11146516632288694, 0.17720232424991472, 0.15941417589783669, 0.06947773149503128, 0.14934048216257775, 0.19519610942474433, 0.25426034363252775, 0.11384655960968562, 0.10799608140119485, 0.08143438704844032, 0.1512031015008688, 0.08777503895440272, 0.1858257172363145, 0.19756035613162176, 0.09845349059573241, 0.10229926423302718, 0.15709437323468073, 0.1466872338205576, 0.13872151768633298, 0.07508476490953139, 0.14993014266448362, 0.14312553565417016, 0.11661581029849392, 0.13016030564904213, 0.13332419230469636, 0.1870058931942497, 0.11379498416291815, 0.09738922198968274, 0.10075743589550257, 0.055132805702409575, 0.08107223933828728, 0.13610693226967538, 0.10139637839581285, 0.15735963971487113, 0.12573992141655513, 0.2179812474974564, 0.09326718960489545, 0.15976843903107302, 0.14949174118893488, 0.13484705558844975, 0.14376212363796576, 0.10056562083108084, 0.15436705601002487, 0.29695156855242594, 0.09082434140145779, 0.15082389542034694, 0.13688694898571285, 0.09007616154849529, 0.099097101416971, 0.06179118502352919, 0.12305731964962822, 0.10262777696230582, 0.12735465834183352, 0.15084503857152803, 0.1711472270212003, 0.08930362228836332, 0.15408447331615857, 0.158453424594232, 0.09439978668732302, 0.15977739569331917, 0.11153874666030918, 0.16202504294259207, 0.19204725910510334, 0.08645433839410543, 0.11781944999737398, 0.14014865324965545, 0.1325189205152648, 0.09580400133771555, 0.09343839756080083, 0.09698902882103409, 0.11694443837872573, 0.14161449245044164, 0.1637924773884671, 0.07369868750018732, 0.12137387426836149, 0.1432126188384635, 0.10774715404425349, 0.14231450988778047, 0.07140654870974165, 0.12391820416918822, 0.13873625546693802, 0.13982776046863624, 0.08696228292371545, 0.10137106903961726, 0.0896720193060381, 0.160422397511346, 0.3190460258296558, 0.23596834231700214, 0.18216744996607304, 0.08971462451985904, 0.10174101311713457, 0.12347475439310074, 0.1349561640194484, 0.14974663965404034, 0.12003616962049689, 0.12329993663089615, 0.08057825905936104, 0.278382914939097, 0.08653080929070711, 0.20683997390525682, 0.1036970599421433, 0.11225672491959163, 0.13423887108053478, 0.13405760723565305, 0.20737274603119918, 0.1566255326781954, 0.1321248680885349, 0.10766802329037871, 0.13772118064974034, 0.15848057956567832, 0.15584379248321056, 0.14959718553083284, 0.12711799889802933, 0.08456564974039793, 0.135445754176804, 0.12716122157871723, 0.11747756334287779, 0.09439411413456712, 0.1221543795296124, 0.15757550884570393, 0.09882300041083779, 0.1390872209199837, 0.19769154409212725, 0.10956547861652714, 0.16634693103177206, 0.1528161285179002, 0.13494621669607504, 0.15472296119800635, 0.11085821674870593, 0.15836653139974388, 0.1182740820305688, 0.12726137334746973, 0.10893912294081279, 0.13889135500150068, 0.10893708733575684, 0.15270259603857994, 0.09639835730195045, 0.11493098070578915, 0.1241978013089725, 0.1414639933833054, 0.08451158407011203, 0.14019338227808475, 0.07514879825924124, 0.2239097843744925, 0.17093320350561822, 0.11214080399700574, 0.10755694032247577], [0.042377036064863205, 0.02922163305005857, 0.055913137937230725, 0.014719894421952111, 0.025630055594124963, 0.01842630884077932, 0.008587178724285747, 0.03650114671992404, 0.019212571471663456, 0.011911208974197507, 0.010583357502972441, 0.00815648031753621, 0.01145538526387619, 0.05848437175154686, 0.02990436480779733, 0.017541412663246905, 0.012738167590993856, 0.02837403254982616, 0.03507038438692689, 0.11090270828987871, 0.03743307724861162, 0.006156399538407901, 0.021191557869315147, 0.037956261674740484, 0.03451578039675951, 0.029801997622208934, 0.04271114670804568, 0.01604905292125685, 0.027479664023433412, 0.014145619701594114, 0.031523023665483506, 0.05019577133602329, 0.07068638556769916, 0.016311713826975653, 0.028764531149395874, 0.01996807102113962, 0.029467293260885135, 0.026292329521051476, 0.06178463716059923, 0.03367317221792681, 0.034883390313812664, 0.025528952180008804, 0.07186249710087265, 0.06274076085537672, 0.041368749990527115, 0.06712712334202868, 0.025461960417617644, 0.03286819559122835, 0.04221217580405729, 0.03924834841330137, 0.02561062404752842, 0.09094090014696121, 0.01607126137241721, 0.020751975742833953, 0.052308145843978436, 0.03797927758257304, 0.06990655205611672, 0.0181734968708562, 0.1033802790833371, 0.03835534543863364, 0.019961139785924127, 0.022830231813713908, 0.03355132429195302, 0.02426065657553928, 0.02400866224031363, 0.037945004778781107, 0.040871075088424344, 0.07873630111238786, 0.01885423034296504, 0.0028736867700769964, 0.05239052678059254, 0.03568462481988328, 0.01869622158950993, 0.010507004501830255, 0.07871658288474594, 0.036216871081186194, 0.08273146780473845, 0.02735311215344284, 0.06458056106099061, 0.03280195700270789, 0.02592873653130872, 0.04087228288075753, 0.015002899503867542, 0.05811164568045309, 0.021046169867206897, 0.01635442760639957, 0.03766220834638391, 0.03927401400038174, 0.013227303129886942, 0.027538384443947246, 0.017653063904227953, 0.00803509888438774, 0.03764243922861559, 0.05208314023911953, 0.051903053652495146, 0.033340204906250746, 0.03319807896124465, 0.012427412971322025, 0.04711124613615019, 0.0320765148582203, 0.0234741411903607, 0.015276785075132335, 0.035771124464060576, 0.03769081877544522, 0.038709170916782956, 0.012038700615188904, 0.0416323269185211, 0.025711405157510723, 0.00772495664257024, 0.024666222045198083, 0.019578010076656938, 0.02020050149544009, 0.0048149544662529865, 0.05218995861443026, 0.028718187207622186, 0.01948192951801632, 0.06140796201569693, 0.011742491241810578, 0.05551358937684979, 0.0524896505687918, 0.058009770432753224, 0.04898014870871391, 0.06163918639400175, 0.01390042937626796, 0.030484559746193032, 0.016439906055373803, 0.043890739125864844, 0.02710718392128391, 0.028782990694578205, 0.019974742716710483, 0.04564441627423678, 0.027298227152121917, 0.04170592761199389, 0.035835663322359324, 0.0422577055038086, 0.0016991885599314369, 0.021707229216450026, 0.02485795907809266, 0.01115257544110396, 0.032427778866674216, 0.031783170598958216, 0.0320917785034648, 0.03654884094638484, 0.00591892797300326, 0.05144874392343419, 0.02709148940630257, 0.04709634550714067, 0.0411134749384863, 0.05487553575741393, 0.006607784357454095, 0.03405358948345695, 0.05146379383014781, 0.03519043419510126, 0.015915931135948216, 0.029797899270696298, 0.06188283474849803, 0.015052602193983538, 0.022751523447888236, 0.02595230714151902, 0.030692880174943378, 0.0172644448466599, 0.06919714369411979, 0.06724672870976584, 0.047702541907450983, 0.053659112458782535, 0.03933872588511024, 0.04940247568967087, 0.030807851148503165, 0.031101073271461895, 0.01677213715655463, 0.048525679523923566, 0.08846725323902709, 0.04274410654657653, 0.010614321600379688, 0.02603968888122056, 0.059493706162486754, 0.027666176336684396, 0.03472186505262341, 0.03875550128785627, 0.030044343189469407, 0.008216026006266475, 0.0842660493882639, 0.03924897945086871, 0.01773530404482569, 0.015316691415916597, 0.01866598267640386, 0.03370321435587747, 0.01848195380132113, 0.0401968657305198, 0.020912910678556988, 0.04551204087744866, 0.05259071835981948, 0.049100469930895736, 0.047791219649038146, 0.02236136411582785, 0.06222044663237674, 0.0217925634767328, 0.025436922475429516, 0.011913683082509254, 0.015614817650722606, 0.11826393114668982, 0.02055871539882251, 0.04137054471565144, 0.047799582593142986, 0.021822008503867046, 0.051260704906391244, 0.02011709936362292, 0.04390337344791208, 0.0603525075795395, 0.004946992715953716, 0.05488251449008073, 0.019196076285360113, 0.04662737263632672, 0.016614622037325586, 0.020380893422822868, 0.08206276475851025, 0.06531377243144171, 0.026274809746869972, 0.045572104797299416, 0.040161514056048224, 0.05202871494527374, 0.04007983201050332, 0.059621501447899, 0.01251175148146493, 0.03246990232063191, 0.056876369286328554, 0.009861332630472524, 0.08860127747591053, 0.044276754305298836, 0.024246451444923878, 0.049884822485702376, 0.08784595264920167, 0.02587074214326484, 0.0251542125562472, 0.0531041352743549, 0.03624114567147834, 0.05486192773761494, 0.02365204119788749, 0.03536575746589473, 0.03630938593830381, 0.06800781429878303, 0.049468293586479764, 0.039850168262741396, 0.0575432436806815, 0.020562394754961133, 0.042631585084434064, 0.042058613151311874, 0.039304351301065514, 0.02286821281138275, 0.09862539744270699, 0.011601355109762932, 0.030391919360096966, 0.09510639269969293, 0.03273627142022763, 0.03293633747047611, 0.038785027739192755, 0.007045016632348831, 0.043290635970021994, 0.032493610334183486, 0.00885337479745171, 0.06374866355742727, 0.028725243971816132, 0.057382261247507164, 0.05133332511676209, 0.027213836055515066, 0.03511339332908392, 0.07112843756164823, 0.01994417641045792, 0.040841311149831326, 0.02563303436285683, 0.05400403216481209, 0.09176204287047897, 0.026910461352339814, 0.03647302483607616, 0.0305560162690069, 0.06887424923479557, 0.009285989217460155, 0.024811494696353163, 0.04789394645818642, 0.04663982375391892, 0.012492587108031979, 0.02805966218667371, 0.06233072214360748, 0.037063689569809606, 0.07104476740849869, 0.005695357045624405, 0.013241661779050316, 0.030812129311795746, 0.045089805498719215, 0.06069154438695737, 0.034676803542034965, 0.015104749306504215, 0.021040307324645773, 0.013727180726294006, 0.03764299562733088, 0.02739840097326253, 0.014656210517776864, 0.017583687091246247, 0.029065308759787252, 0.03430773138201662, 0.07148393562861852, 0.010313844241734062, 0.015464347421324678, 0.03889934731913464, 0.03008231400911297, 0.0406613975896367, 0.03312377937670265, 0.01769397278050227, 0.021453501224251728, 0.02246735298207828, 0.023787171446851323, 0.019027012500113676, 0.034201371017843485, 0.09324483187603098, 0.009178267542405852, 0.035655919395919354, 0.036228395998477936, 0.03334520910201328, 0.07404022810182401, 0.006437705314186002, 0.035951689417873106, 0.07301668516759362, 0.028501530976167748, 0.016477237355762293, 0.05619280632319195, 0.055384772896234474, 0.05005819496831723, 0.029091622347810438, 0.016771707983155335, 0.05516838129343731, 0.031465945299714804, 0.019038578129506538, 0.07044232330684151, 0.05001429035993559, 0.015513972079913532, 0.0166899699584714, 0.0742634864790099, 0.01694075480502631, 0.017982304362314086, 0.021238632932571427, 0.06772027829928057, 0.035077895769583325, 0.07517260126769543, 0.05592606742201107, 0.050074120185204914, 0.0038155385409481823, 0.017406255272882323, 0.040997801681182215, 0.03113848769239017, 0.04798063948484404, 0.03569102001243404, 0.010595612693578005, 0.11258227245083877, 0.21922557215605462, 0.11479265455688749, 0.16849403296198162, 0.10043066700122186, 0.13429947782840046, 0.08601441021476473, 0.1120937272374119, 0.08499480278364249, 0.08483394248677151, 0.1164167688361236, 0.11276789927589041, 0.14976345375180244, 0.15265100023576192, 0.1118644977520619, 0.17119986776794704, 0.0820991885183113, 0.10673040324555975, 0.11711606702634267, 0.18016171402164868, 0.15360571257770061, 0.06281270592340402, 0.09432000453983035, 0.09208333598715918, 0.21778307455990994, 0.09014532462294612, 0.19350845712636197, 0.16552266026181833, 0.06512751456882272, 0.14012836505259785, 0.0868979510185974, 0.1721378338656255, 0.16460728938026087, 0.10194637174052851, 0.08789522107690573, 0.10993331923548665, 0.09665328290845666, 0.12276972936732428, 0.1311178949794599, 0.16733881352203234, 0.1815378237515688, 0.10404594907803194, 0.17578653379210404, 0.08093518204987049, 0.10504157708159514, 0.1491784615708249, 0.12571219647569315, 0.09375818432973963, 0.1422897840717009, 0.25698376606617657, 0.13054971689624445, 0.1474579410361392, 0.10713116638362408, 0.050004566953118355, 0.07362603675574064, 0.21558398327657155, 0.17519785038062505, 0.12423676278974329, 0.17090847768953868, 0.1204459233475583, 0.09439272992312908, 0.1200599047754492, 0.10297517332115344, 0.1443413347005844, 0.11530403925904206, 0.1796055460082633, 0.10943140009684221, 0.18685595052582876, 0.11086132443909134, 0.09839633759111166, 0.15320100715117796, 0.13645050169101783, 0.1205467807927302, 0.14583955359246048, 0.11808443149285656, 0.13394270411559514, 0.267274156744991, 0.1121030163818172, 0.21199536084064416, 0.1574336543147053, 0.08698190615645476, 0.13169173204473086, 0.15341036234583172, 0.09756703209131956, 0.12114250739770276, 0.09480871938701187, 0.15195582753845624, 0.14151234578873428, 0.11863536121589796, 0.1275231521576643, 0.09458335755126816, 0.05511895001732877, 0.11050868300454957, 0.11950604378112725, 0.16730552459401743, 0.17178785907370703, 0.08864684788776295, 0.07547906839421817, 0.06307565859918084, 0.1382830754986831, 0.17199437799198286, 0.08116333944989101, 0.14189218969217368, 0.14163307073925221, 0.1369877385773829, 0.09099167492240667, 0.11026029169027295, 0.0915582516629781, 0.09032949938305787, 0.16345972381532192, 0.15134453534015588, 0.13143078104725905, 0.12683068002973283, 0.2521597892045975, 0.11182177718728781, 0.10147137687142406, 0.10109778906085662, 0.11375637552035706, 0.21540229873997824, 0.09380313048937491, 0.22526082902082376, 0.08666898616190467, 0.09440752198653561, 0.10208591925246374, 0.1802655163088015, 0.13387808044041904, 0.12395587643342358, 0.1344213562884501, 0.18645941466093063, 0.10990302264690399, 0.13104211618857725, 0.08838734895523105, 0.12387997550623757, 0.1187581896249737, 0.10723628502871309, 0.09016455430537462, 0.06580158482704844, 0.24927001712577684, 0.05915675924292632, 0.1045746635645628, 0.08943768723734788, 0.07860841083207301, 0.12388122401067189, 0.06902645142482859, 0.15602969750761986, 0.12182542575257164, 0.09231172408908606, 0.11789879788245473, 0.1272125459675278, 0.15267141056912287, 0.08222863264381886, 0.1069395752357585, 0.12224290120814528, 0.20240586969469274, 0.16738728806376457, 0.11926360321896416, 0.1723287193370717, 0.1205824174519096, 0.07017936384571449, 0.08929503203502723, 0.15301318865801605, 0.11884113374565329, 0.12242598352687699, 0.18408329359122685, 0.13534477459532873, 0.13442138342985085, 0.14806067012250423, 0.1439589530761753, 0.15137010253965855, 0.11912740767002106, 0.1345971647117819, 0.13297649739044054, 0.08698876614549331, 0.21098654211631843, 0.1471398709607976, 0.1551850571164063], [0.05172573548874684, 0.006123282788653991, 0.07592797359185559, 0.051333274226635695, 0.06069805153778621, 0.017969354521483183, 0.033766545421843014, 0.033790436639849625, 0.040818468268428526, 0.031917289830744267, 0.017416703015831963, 0.02034669865055808, 0.04668793867209128, 0.017162213368075233, 0.054945109345551045, 0.031214727887085507, 0.0971134789288044, 0.028922616238040582, 0.031924957276454995, 0.01921954850799271, 0.023034640488081744, 0.04767673722069178, 0.03721552874360766, 0.05418853262173278, 0.09684446014996086, 0.06552336511335202, 0.03031155027981315, 0.018521244371575967, 0.011623823100567927, 0.01939093627567802, 0.049932733843369145, 0.04854684303115521, 0.012083640837642764, 0.05951358723853316, 0.06054533366113901, 0.026447895548439453, 0.009058266079851558, 0.031215586233884096, 0.018219045230320523, 0.020363283742751394, 0.02160120981612376, 0.045608304640544314, 0.018363040539302995, 0.07877346447535924, 0.06707919162831136, 0.03901550233630197, 0.02026962555412735, 0.048269776826990504, 0.022751889856798307, 0.04307197466758745, 0.08859219189201083, 0.01602388436107763, 0.05288483275632773, 0.04631983003179942, 0.033409069425293376, 0.018859645052413856, 0.02077324272665594, 0.04116782220080495, 0.02682455542630383, 0.029756016696670225, 0.08399079487259899, 0.044692021129386764, 0.03396551224536129, 0.014861755738300937, 0.009831994472603713, 0.05958918961031096, 0.01459371913889689, 0.06521656550467014, 0.02483859538499798, 0.017296963637428622, 0.03350747057369777, 0.0716858065820166, 0.04062195095632758, 0.03053014033607074, 0.04148810090763228, 0.01973790006845125, 0.045001541663493426, 0.04100882448256016, 0.0726347445909466, 0.0041340678996805635, 0.05386405039046492, 0.045103925812457285, 0.0828046885186008, 0.052603386608617644, 0.03517846144469721, 0.016143978274028217, 0.04861155491588371, 0.017135960848203728, 0.03385035128199628, 0.06937160183276449, 0.010475946257689168, 0.02393466460385493, 0.021257977965953093, 0.010942603627751981, 0.021206580634628023, 0.036475484525518756, 0.0217404774323638, 0.019327793503180146, 0.02423891461720424, 0.02866660836817963, 0.020900181361607144, 0.10258294615362372, 0.10366205432053123, 0.04422677680850029, 0.046231623872050216, 0.009330540130447065, 0.0361212281776326, 0.04880822829103895, 0.014760031464642711, 0.010220358231371003, 0.09771068474011761, 0.06760409953338758, 0.0382483370735177, 0.04676606519413846, 0.044202878805143495, 0.03917524305039218, 0.03558469696768692, 0.004299144867608058, 0.013652691151946783, 0.050312197767198086, 0.02452081368703927, 0.05274013177092586, 0.012324395240284503, 0.015216597322640675, 0.043502820655703545, 0.02828606727000858, 0.025319569843954275, 0.04239388069670115, 0.016421224289972867, 0.03172687594113605, 0.038752142539513965, 0.012680235119270427, 0.02209611120633781, 0.0443415849336556, 0.011983456838476871, 0.021038178421024765, 0.027729437852810537, 0.058745913074484894, 0.06443542242050171, 0.02903468647439565, 0.02123967109114996, 0.02379303059673735, 0.040115641696112495, 0.012342791172808834, 0.025268080910401683, 0.04054063192701765, 0.03412215205441628, 0.015847309193174754, 0.005800445156637579, 0.08065744409603731, 0.027876824140548706, 0.05763661688459771, 0.05763594513492925, 0.08362121041864157, 0.022860207794500247, 0.015222909394651651, 0.03744407290858882, 0.05933421650635345, 0.03824874758720398, 0.00921550893690437, 0.041229043022862503, 0.033248049672693014, 0.02456434510116066, 0.021288491685741713, 0.045330088319522996, 0.04531171698389309, 0.04654373301725302, 0.03805965005553194, 0.04195775570613997, 0.030946689591343914, 0.05505476738991482, 0.032568137227956734, 0.05106171772682241, 0.021539446166051284, 0.10418933709817273, 0.035931448718266826, 0.11853113823703357, 0.035469502077570984, 0.01946447420466159, 0.045879942564559836, 0.004021728369739971, 0.01576605292835406, 0.025174164878470556, 0.03224199937124338, 0.022382483518283283, 0.02653894476991679, 0.03241319375644837, 0.010028516873717308, 0.03050309732290251, 0.013397980980308992, 0.02930030579279576, 0.02135282359085977, 0.021546906658581326, 0.010662062476123018, 0.04195919420037951, 0.07194311384643827, 0.05862351892782109, 0.02771677978203765, 0.018138606600197296, 0.03935926514012473, 0.056949104847652574, 0.054483888737325153, 0.0251242162194103, 0.03075303230434656, 0.04316391955528941, 0.04109634192926543, 0.010176330638517226, 0.0415545091299074, 0.06726222644959177, 0.036133767504777224, 0.018568059895187616, 0.07039861208094017, 0.0290936002773898, 0.009484879705788834, 0.014781133903722678, 0.09410775878599711, 0.03968912476141538, 0.04329113130058561, 0.06056729783969266, 0.02491883045461561, 0.01641708692269666, 0.011378666701992708, 0.014345472013311726, 0.1046939907329423, 0.015082006509016668, 0.03482686495408416, 0.03796970345345991, 0.038277025534106154, 0.06827612061585699, 0.04335191107488104, 0.007022666112918938, 0.06006897493664708, 0.0356271800452045, 0.02204128388049347, 0.054961926835988245, 0.059625396238906045, 0.041196734577949555, 0.0057803015723558405, 0.0318228411488235, 0.06905659195035696, 0.01365803970423128, 0.008260172342748513, 0.008239138605339187, 0.02686205636044698, 0.012489224118845803, 0.03436962056106754, 0.012131793923409922, 0.06386643688061408, 0.008244802676407354, 0.013090171202618097, 0.032196795368301015, 0.0016338362017579908, 0.016920980598245348, 0.04283628213618483, 0.03046217148325273, 0.04543126128347857, 0.040928150061517954, 0.028627721526260887, 0.049272522662899325, 0.008779833475793046, 0.015126067180452602, 0.03204419284260698, 0.02549571244578276, 0.010176591026330633, 0.037811109463551214, 0.06356853965137686, 0.04506854699658496, 0.04911181164373245, 0.04753223301044532, 0.029083832765796354, 0.035664957482367754, 0.06874935807926313, 0.03780412055285914, 0.02149678666942886, 0.010538876139824944, 0.050663750153034925, 0.0291359713966293, 0.019024391658604145, 0.06208756911967482, 0.006307470271297331, 0.02110773165311132, 0.03477072975199137, 0.03308540143604789, 0.023713460491437997, 0.04205812799877354, 0.03177666684080448, 0.032943492622247765, 0.04853172866361482, 0.041969453649861474, 0.0282934616053743, 0.01814551917569978, 0.03843435066352997, 0.044704350110675604, 0.040383629101727686, 0.0517116016043084, 0.022392032202333212, 0.01924236424799476, 0.028106543867449676, 0.05275461510089891, 0.04962584602513483, 0.08122065530291625, 0.0286009567124503, 0.0089870826673827, 0.014079309866896697, 0.03857569968593972, 0.05914021655917168, 0.09200529088931424, 0.0601845294503229, 0.05198320560157299, 0.02277031717156725, 0.12217835895717144, 0.02916620352438518, 0.004209916664487017, 0.02165066823363304, 0.027268894083265747, 0.01472900714725256, 0.003177902432590989, 0.00871843793096819, 0.05083982999037419, 0.02271548645304782, 0.04044017481750675, 0.012226832082628139, 0.021441117960161397, 0.01698270014354161, 0.0241471376669194, 0.0216553060204855, 0.01672613587496536, 0.061102736608258316, 0.027460936456918716, 0.026071902331230894, 0.008525238655108427, 0.056545993978423734, 0.015049521644998873, 0.009504815912805498, 0.03343618029196348, 0.04433589202484914, 0.03376838764441865, 0.005438741038752986, 0.012217749043234756, 0.06772863785071032, 0.04163687988849623, 0.03032304805570415, 0.053775939225618324, 0.04457047175882118, 0.004936535219063184, 0.024392770736345222, 0.026865452428215315, 0.010107160778716207, 0.05800948544804539, 0.0321309876495174, 0.08588541392236948, 0.04938357848940151, 0.151585849534188, 0.13988292536565236, 0.19566538424364158, 0.09592827502638102, 0.13301840371319226, 0.06143597194126674, 0.11454646848142147, 0.0914046788322074, 0.10582686601472752, 0.12447343580424786, 0.08333927233304296, 0.09744576431278672, 0.09751804186297314, 0.06626765696065766, 0.09996333279247795, 0.09411306492984295, 0.14651551017803804, 0.08097308501601219, 0.13030423649719783, 0.14208967052400112, 0.1650591937026807, 0.11631549069924013, 0.10557544164891754, 0.11668811499008111, 0.10450316632964782, 0.2152897569217852, 0.13758231167282375, 0.12589170970022678, 0.15794814670724527, 0.1230281155024256, 0.12094805283205849, 0.12103608596537795, 0.10155142364757401, 0.10489847404616219, 0.15248220786452293, 0.16269953389252934, 0.10063219190176044, 0.1518202426710299, 0.0659358940486397, 0.10463423893920012, 0.10337720531970263, 0.14288074736084255, 0.19994248902159079, 0.12791918590664864, 0.15381266575838837, 0.1138041986684714, 0.08563422025846583, 0.12251799287540571, 0.06071576808712312, 0.14413507362561567, 0.18831826134451798, 0.13791442742305143, 0.103544192787792, 0.2408108567552907, 0.1983088752520936, 0.20608671861035482, 0.12677920636321816, 0.21655200847557612, 0.14621645265391894, 0.28079117142728394, 0.14747077891869204, 0.13159882702997752, 0.13422625032918795, 0.1511822161929948, 0.09052556207669632, 0.1636099921805518, 0.10230082486357008, 0.14069215979959282, 0.15738412125834397, 0.0596124158639993, 0.16492869784789427, 0.16114389736737522, 0.08719264556254659, 0.10975590946951083, 0.1498044372669288, 0.07289415531392608, 0.08656637131103448, 0.22250181064009666, 0.1622373972620283, 0.14751396088727883, 0.16673099542302744, 0.19324590478624615, 0.16396143260811055, 0.16000640126211302, 0.0797724783686655, 0.08967685047537088, 0.09193139842578343, 0.07541678566485643, 0.08980567713401147, 0.2167766307081495, 0.12881972401269845, 0.13795512595346995, 0.12702817443226064, 0.0690482866817287, 0.07026686093636922, 0.08604767878672906, 0.10100514867476054, 0.097949861548841, 0.10460453946143389, 0.11672234029642173, 0.1239077683006014, 0.20308642674769672, 0.299116773796933, 0.11797372171921389, 0.09478928614407778, 0.10360874182411603, 0.12646747380495071, 0.08896539972296783, 0.13437700723963125, 0.07248501226838146, 0.13140999073428766, 0.16129207584474767, 0.11736312162663255, 0.09797924211514847, 0.23877967574766704, 0.1434613290641989, 0.1692107016486781, 0.12645520589181355, 0.09968516057623283, 0.15812468794839724, 0.1080928947776556, 0.14385179882603033, 0.18557893405003206, 0.22486688515969686, 0.1431717574596405, 0.10081745910325221, 0.10927529633045197, 0.10036718326487712, 0.08830985347075121, 0.13502207691115992, 0.1516617097492729, 0.14113380467253073, 0.15331840728010449, 0.09025719469147069, 0.19032909987228258, 0.16735462338796683, 0.07724697102925607, 0.15515013970434666, 0.09799533018044063, 0.10080965595053774, 0.12057405790047986, 0.15101285385234015, 0.08914987982383796, 0.09234194603881665, 0.07162591229592051, 0.13206721975335053, 0.11378435151917593, 0.11710333770939282, 0.08896518259176187, 0.15167648824197905, 0.10994422329323632, 0.16358371930462973, 0.13725373787539347, 0.16094166679041727, 0.13755998787071022, 0.10828696257833924, 0.05880136974155903, 0.13519749178418092, 0.11489454337528773, 0.10995128005743027, 0.14049868232437543, 0.1301022366221462, 0.10214336402714252, 0.13596548485968793, 0.12313707465572016, 0.14558043463953904, 0.09855100286326238, 0.1500556580722332, 0.07706464866974524, 0.11254075967839786, 0.10616945156029292, 0.11015815859926598, 0.1695141289383173, 0.13500872334199293, 0.2799663985414164, 0.14147712982126645], [0.013549113629518874, 0.06587671900966338, 0.03673070529475808, 0.03448302751140935, 0.014707992917725017, 0.019646408102874244, 0.055525443383625576, 0.03873471436755998, 0.04592665630791869, 0.011081219002205347, 0.012304299577538456, 0.05307002531896744, 0.05243095728967871, 0.05576014525390097, 0.015392022373686944, 0.04092999228409358, 0.044210288407547135, 0.02586518324512456, 0.03695006548826184, 0.0444248208243932, 0.02321339544973203, 0.022646711839895164, 0.0501878867591066, 0.09486896651131765, 0.02753011988742011, 0.08006474375724792, 0.06052429907556091, 0.03069898020476103, 0.03432957003159182, 0.07770379473056112, 0.005192540968502206, 0.05926024940397058, 0.028116779568205987, 0.03307808343587177, 0.05991620956254857, 0.02211234685299652, 0.062409527200673304, 0.03948281618899532, 0.03285158844664693, 0.030586726763950925, 0.05823911526905639, 0.010640445198597652, 0.059936518115656715, 0.04614886634850076, 0.027371890610083938, 0.018934292386152914, 0.0638306780851313, 0.05561236032683935, 0.030805747689945356, 0.022369543855477656, 0.02034645268161382, 0.01712450378441385, 0.038072470974709303, 0.04182362290365355, 0.05482158883075629, 0.03779316560498305, 0.011601741026554788, 0.07797552086412907, 0.05501979569505368, 0.048611639732761044, 0.04518567571150405, 0.056758154915379624, 0.0033142606178963824, 0.01807417461116399, 0.016833878754238998, 0.0343003116015877, 0.06040182350469487, 0.026868451552997743, 0.014394660713151097, 0.013997202888796372, 0.04008878867274948, 0.008816713550394135, 0.023170829251674668, 0.0619587085342833, 0.03409205902633922, 0.03160486177408269, 0.034366373771003315, 0.021432098533426012, 0.02641738352498838, 0.06562337438975062, 0.04708046100235411, 0.006725425366312265, 0.05232022037463529, 0.027306096462000693, 0.0308191792906395, 0.03185123105400375, 0.03775188014177339, 0.0598374248615333, 0.012184934241564145, 0.06964982833181109, 0.031241055045809065, 0.04124095470511487, 0.0526949311606586, 0.05998508765229157, 0.027711461763828993, 0.04790112875135882, 0.03792081839804139, 0.027325007232970426, 0.021780611082379307, 0.013429347957883562, 0.035669561342469285, 0.04936260836465018, 0.018460430670529604, 0.04744099719183786, 0.030563955128725086, 0.0011082017341063225, 0.04714342565940959, 0.042337168739842515, 0.06566451396793127, 0.06711189701621022, 0.07124177326581307, 0.014834646567968386, 0.026872013861845647, 0.012463388898010765, 0.02521162510051259, 0.04905876038329942, 0.06498303410730191, 0.050007019857210774, 0.016125072592071125, 0.050146777715001783, 0.09831094395901475, 0.0720663493765252, 0.07820515068514006, 0.020242156760234917, 0.02477805649063417, 0.004978235012718609, 0.06489539452429328, 0.029790275929761783, 0.013305238813960125, 0.04401884314471057, 0.025200683723336885, 0.035000647950385294, 0.04416332360623138, 0.03673117009124585, 0.01940526014992169, 0.02560052744645093, 0.02815908283394362, 0.016193981215889965, 0.03183141104610903, 0.01730409843314971, 0.09770695279751505, 0.018537291724767004, 0.03316103434190154, 0.042785381831760914, 0.060125971878213544, 0.03165933795805488, 0.00875032229149448, 0.03101345743717892, 0.021879682284114615, 0.028611436685813323, 0.036224280683589835, 0.007979043410159647, 0.06806095716144357, 0.07267672555255038, 0.0076890824961342984, 0.04790944419801235, 0.07473728712648153, 0.014432880894414015, 0.01970149327202567, 0.011710424524998026, 0.055320705619773695, 0.008980087819509208, 0.05987032702458756, 0.01431783358566463, 0.05284080940431782, 0.015093472054494279, 0.049963227207107205, 0.057789579033851624, 0.05875768565705844, 0.06507631231631551, 0.038620930830282826, 0.026083674913804446, 0.04109229786055429, 0.021396526335073367, 0.013749592737959964, 0.03830378016989146, 0.031847414294523854, 0.06876737996935844, 0.029242481038506542, 0.04422232901145305, 0.05008663237094879, 0.06777851695993117, 0.010213192053405302, 0.014456707651593854, 0.04749991778018219, 0.033311896425272734, 0.048494568693318536, 0.07820540852844715, 0.019437421013468077, 0.06589417093034301, 0.02992157924122044, 0.04110662852014814, 0.017135353559362035, 0.020456385532660142, 0.014903964009135962, 0.05235319039119141, 0.049268088436552455, 0.03557659525956426, 0.021590919832565954, 0.062130954648767195, 0.014202638695548688, 0.06665424550218241, 0.029761092138609717, 0.03154221263581088, 0.03540114645979234, 0.044624768131013424, 0.005615990500830646, 0.04824159048231585, 0.050632323803646226, 0.01823709426181657, 0.03928147449291178, 0.019522673849548613, 0.09214963564383132, 0.01989424301843558, 0.031282214980040274, 0.12886282455708298, 0.07992782217583486, 0.009344835166952439, 0.006585386764657284, 0.05362966403897319, 0.040872347341584306, 0.023032068840361068, 0.025117130617478063, 0.055825304971741777, 0.031062373026673282, 0.014089486195838876, 0.04137208838281887, 0.029901701557849134, 0.05962957601462092, 0.046110193245112896, 0.008905862873819257, 0.009442472963460853, 0.04101498558052948, 0.07062191795557737, 0.0397216469448592, 0.022205243386062126, 0.016485113450991254, 0.020230501224952083, 0.005468158076317715, 0.05451098603329488, 0.010982457382072295, 0.029857959797871963, 0.026842316080416952, 0.004319327467653368, 0.034136815196169276, 0.035119856375136545, 0.10644911655357905, 0.01853799231217376, 0.026468500960618258, 0.005345269023174686, 0.030265365793768848, 0.04956779396161437, 0.047682955994137695, 0.05805697611400059, 0.020380016416311264, 0.03465374692210129, 0.02902474932904754, 0.07365172609154667, 0.061521521636417935, 0.0413517391176096, 0.03741539801870074, 0.009412346008632864, 0.06022842388067927, 0.0339735935974334, 0.04473205130281193, 0.004384760719923568, 0.014467816966186677, 0.023432820104062557, 0.031080476340970824, 0.016234691620671322, 0.02137960706438337, 0.09470188404832568, 0.014317889564803668, 0.045920831084783585, 0.011675913385780794, 0.006919699272007814, 0.013922324853150972, 0.0033229074864980896, 0.037206202279776335, 0.06008527334779501, 0.042501272434102635, 0.0710484789950507, 0.07620828997875963, 0.03976333952908005, 0.023199984205088446, 0.022637704287522604, 0.05937960371375084, 0.02615979466853397, 0.03165277652442455, 0.021023047090108906, 0.01082160132604518, 0.006583246834842222, 0.029315990129751817, 0.04323789344302245, 0.024686647645596946, 0.03788899849834187, 0.05234817262472851, 0.05291425742741142, 0.03859711764380336, 0.06739078847957508, 0.05072704389957445, 0.03473931018795286, 0.03560804875035371, 0.00615329312027565, 0.0400242701705013, 0.024290047319872037, 0.031500197747456174, 0.013428911999134081, 0.019953168695792556, 0.0314444085982229, 0.07449267525225878, 0.04899221645402057, 0.030764557221638303, 0.04015823333923306, 0.009170092043599911, 0.02405863973711218, 0.030548606666603258, 0.027508523814114075, 0.05822178548468011, 0.016367141656311493, 0.06923837826720305, 0.020389007005308355, 0.025434430555573533, 0.032984065623687844, 0.02306341376554753, 0.02289458746755762, 0.05009301399279918, 0.04929505002551845, 0.05614643863269261, 0.026405475235411098, 0.023089377908036113, 0.03329954708793333, 0.05622479585664613, 0.032500663705702336, 0.03511013636099441, 0.03292549787355321, 0.017965447856113315, 0.03204664235402431, 0.05652523080685309, 0.018508535410676683, 0.026657701968880634, 0.06404865067452192, 0.03173033307705607, 0.08062641468963452, 0.025276540545746684, 0.02784291435299175, 0.03920002654194832, 0.032281110129718266, 0.02216962369025818, 0.061086641757615974, 0.020190084286566292, 0.04854054622618215, 0.14321606579635823, 0.1504066778080804, 0.14469458003129276, 0.10528374622975077, 0.12265919601278645, 0.07026059127279691, 0.10903752408921719, 0.1309594977647066, 0.07098359747656754, 0.06176056952348777, 0.1345313061028719, 0.23058302700519562, 0.14268773128943785, 0.12070695576923234, 0.1175645651029689, 0.21034130959638528, 0.08889850295547928, 0.09213728630649191, 0.10680724733642169, 0.15379458958549158, 0.0867129552311131, 0.08422386486615453, 0.08314403745212726, 0.30898815553103176, 0.14107634632715157, 0.17984063125082425, 0.11975406190114361, 0.09344778848545891, 0.14860192393617971, 0.11694373270230633, 0.12875329543437275, 0.16090015401797636, 0.09478271113974707, 0.10741700604557991, 0.12546887381800584, 0.08627148677728005, 0.1367166909788336, 0.11382833415908472, 0.14371643108980997, 0.22342361403363092, 0.16849311015435628, 0.09944725941334452, 0.1094527468085289, 0.14452969602176122, 0.18420928397348948, 0.0755547589755484, 0.16137778838830336, 0.1289857208196606, 0.06120052028979574, 0.11666718897010599, 0.0821470795199275, 0.1818199043295213, 0.09740032282258783, 0.14537160870219978, 0.17907737434974738, 0.1565241324050086, 0.08390107897243329, 0.12389744099761758, 0.2044619122253997, 0.10923897435090371, 0.11126270504402262, 0.1304870881140232, 0.0881193954763668, 0.1686800601226943, 0.11183107990239348, 0.06993038220597164, 0.13658296529735836, 0.09239291758941752, 0.10072665076170649, 0.08302571451557533, 0.18442546523043088, 0.12334359357399599, 0.14505136731479848, 0.14689880103937217, 0.15907693042286805, 0.15375508527670587, 0.11404353832559926, 0.12296066912157194, 0.10483901402247803, 0.2191868820892913, 0.1266204020274537, 0.13869688686515602, 0.17081041580864362, 0.18398164904543332, 0.10048623223389898, 0.16414581771407807, 0.16279788075813226, 0.1712286647941385, 0.1152858002377408, 0.13344688500676835, 0.10701486548142773, 0.09060565635029759, 0.17524310866636889, 0.07709926074104649, 0.08184745881174292, 0.12569291251046316, 0.11494919258568968, 0.3688249561403479, 0.10024582727679185, 0.09193320332893304, 0.12989085939313683, 0.12834960781037807, 0.09679149370640516, 0.14058181643486023, 0.14980511580194744, 0.12474977597594261, 0.22284951912505285, 0.12131203258676188, 0.11623314368937697, 0.18720944012914384, 0.11624235819493021, 0.07487860561481544, 0.12393980872418199, 0.12350566844855036, 0.13010850628571852, 0.07584342134318181, 0.11224658082106284, 0.20788322149642877, 0.07118525129875966, 0.1672675402036735, 0.2485407276877335, 0.35943449288606644, 0.171408937977893, 0.22536121149148258, 0.1422307922371796, 0.07581181518201317, 0.07216628401407174, 0.08969924213098628, 0.13700071216693946, 0.07675792369991541, 0.13014738634228706, 0.07989611423441342, 0.13076074128704412, 0.12800248286553792, 0.13363052372421536, 0.1826191507279873, 0.10645402236176388, 0.1764330148164715, 0.07894313894212246, 0.07314395119569131, 0.21322037439261163, 0.15091104645814213, 0.16493381400193485, 0.13431227499885218, 0.22674226095633848, 0.1100935892068914, 0.11438899407429354, 0.08404935244470835, 0.148849684212889, 0.13963631859847478, 0.16316859158022062, 0.14286333615226404, 0.10380352887191943, 0.17190763407519885, 0.070815693986203, 0.08807522284665278, 0.1488221221204315, 0.07227773339088474, 0.14371132850646973, 0.14942190636481556, 0.16612329946032592, 0.13299389502831868, 0.16832760189260754, 0.0831358814612031, 0.10102712642401457, 0.10899503422634942, 0.12299817853740283, 0.16865234875253268, 0.1664213120405163, 0.1378459089568683, 0.05826586311949151, 0.15870558177786215, 0.15631783061793872, 0.12194989621639252, 0.1714054231664964, 0.14524873958102294], [0.012593851674215069, 0.08517481133873973, 0.034800744748541286, 0.04753876051732472, 0.032930882048926184, 0.015321000113285013, 0.023093092887263213, 0.06499280501157045, 0.05246196634003094, 0.036489045047866445, 0.0396455865619438, 0.01049775691769485, 0.008293620726492788, 0.026845652776371156, 0.01988066383637488, 0.008628053673809128, 0.04621592257171869, 0.01908798056787678, 0.04331717347460134, 0.03805993164756468, 0.041896344894277196, 0.012219860135311527, 0.03567802945950201, 0.04249181365594268, 0.028496550529130867, 0.0544547965484006, 0.03572776607636895, 0.024584589193442037, 0.05645081587135792, 0.011026322974690368, 0.02767557404669268, 0.023188739183491895, 0.009687090774865022, 0.021711337745987942, 0.0788828239643148, 0.03009287201400314, 0.05290048995188304, 0.03126681902046714, 0.08551482523658446, 0.009299628619503762, 0.02695372304879129, 0.038423466961830854, 0.026260440071512545, 0.02254178996996156, 0.059173681906291416, 0.06725034530141524, 0.030849034831460034, 0.013499067431049687, 0.03932653261082513, 0.03585531708917447, 0.01707859240871455, 0.030377527632351433, 0.041401211105819256, 0.0037546722534378724, 0.06058626289346388, 0.09245122410356998, 0.029473593458533287, 0.07291693373450212, 0.016110402664967945, 0.005822365654499403, 0.04023188153015716, 0.0523725252465478, 0.024910143510039364, 0.018655285571834872, 0.0298608537497265, 0.041033289062657526, 0.05673033158693995, 0.03470983123406768, 0.021829999950049177, 0.03102277372298496, 0.01624759566038847, 0.015046098435829793, 0.033855677781892676, 0.031189462635666132, 0.0815135178023151, 0.04063742834010294, 0.10861029130007539, 0.01650818024895021, 0.10293816602123634, 0.03867253341845103, 0.03311465308070183, 0.03017930719735367, 0.051646757405251265, 0.03381831764376589, 0.026479995343834162, 0.0492533065511712, 0.052663630340248346, 0.005540305856681828, 0.05715826326715095, 0.07581106200814247, 0.004440164800533759, 0.045669043702738624, 0.041280469191925864, 0.0038656678599571542, 0.020687816864145652, 0.0488783413145159, 0.0717860126335706, 0.04359017864667943, 0.028267712897754142, 0.0175265781914017, 0.061843757916774066, 0.03204424373273339, 0.048296979295888116, 0.04921504396146961, 0.04104864091745444, 0.008589896257035434, 0.0352152142939823, 0.037350998260080814, 0.014287922065705061, 0.0445942578038999, 0.03473600232973695, 0.025530170150367276, 0.07386475894600153, 0.05789997668138572, 0.023829851299524307, 0.05699549628687756, 0.019500056581039513, 0.007631845522804984, 0.05292593501508236, 0.010588796809315681, 0.03844294770221625, 0.02444741316139698, 0.022557911962004643, 0.053514370761279545, 0.05710479470768145, 0.024221411806398203, 0.039039994057800086, 0.025741579609790018, 0.0127828380957778, 0.04023641753675682, 0.07751989816980702, 0.01623581798880228, 0.018610938219353557, 0.022820177621075084, 0.009926010588450091, 0.03000372269057802, 0.06051637378654309, 0.025243796142084256, 0.012472530461049505, 0.07294109636651618, 0.0472721437524472, 0.07449097891471215, 0.015777204651385546, 0.030252616120768443, 0.014852127326386315, 0.03493212948420218, 0.031999976108116765, 0.07043353627835001, 0.017664473470566527, 0.027294457890093327, 0.06085144794945206, 0.07762644852378539, 0.049004175633724244, 0.01858264670175101, 0.053266569772469144, 0.16238811346037046, 0.10783807773675237, 0.01932888594456017, 0.023341891322551028, 0.01113885291852057, 0.024311746869768416, 0.06529382350189344, 0.05914306640625, 0.014829007941963417, 0.010113810421898961, 0.013434006100786584, 0.0727555306096162, 0.015465982690719622, 0.029688875656574965, 0.04111998548199024, 0.050721011723258665, 0.04379046522080898, 0.017645835809941803, 0.003602188895456493, 0.0265490057479058, 0.027210770773568323, 0.024983881606853435, 0.05739245962883745, 0.021298023406416178, 0.025395637012219856, 0.03245744102501443, 0.013959598478062876, 0.0182094677085323, 0.03371831515271749, 0.06100856951837029, 0.0778900050957288, 0.01300080559615578, 0.021629309647583535, 0.022442538956446306, 0.050010812867965014, 0.022287110332399607, 0.024204031131895523, 0.04380260081961751, 0.065841265554939, 0.04892920090683869, 0.0649566323097263, 0.030773412103631666, 0.05085248466847198, 0.09917247987219266, 0.01574402259263609, 0.03540551622531243, 0.03573088055210454, 0.0483605953465615, 0.04780978775982346, 0.06213040503540209, 0.04078626499644347, 0.02510804164090327, 0.010352101742423006, 0.023750240482123833, 0.06424039788544178, 0.0838927465624043, 0.05776879550623042, 0.012288623722270131, 0.0426353814878634, 0.048219992712672265, 0.03959994829658951, 0.02077593990335507, 0.027721626218408346, 0.0454475088045001, 0.03993429642702852, 0.09761683656168835, 0.08891416354370968, 0.06258143404764788, 0.03156493677358542, 0.06744062687669482, 0.03643816849216819, 0.02751583163626492, 0.016064126576696123, 0.011570715012827089, 0.025999565409230332, 0.053012505905436616, 0.04162415396422148, 0.014646100345999002, 0.08383289298840932, 0.030582842150969163, 0.021197162568569183, 0.020290337835571597, 0.03443288038085614, 0.030323597669069256, 0.028109707536974123, 0.029353061890495673, 0.028267831641382406, 0.06720540592713015, 0.0441690402637635, 0.022419546797339405, 0.019779657113498876, 0.013199861477395254, 0.0111382481741852, 0.038043460209986994, 0.03619564650580287, 0.01306893814554704, 0.02661873709543475, 0.14981852365391596, 0.008483890427409537, 0.05852874794176646, 0.040519183435078175, 0.01491517001496894, 0.04504753276705742, 0.013917762553319335, 0.06879392425928797, 0.03543006222961204, 0.040538810060492585, 0.028612400205539804, 0.040269455406814814, 0.017726250691339374, 0.026796779595315456, 0.05757598299533129, 0.06239952559449843, 0.017125409628663744, 0.03392028110101819, 0.04030147886701992, 0.099210260702031, 0.06764282352690186, 0.004587945486751518, 0.039140715795968256, 0.020590316470978514, 0.056382806306438785, 0.04199320916086435, 0.04927230892436845, 0.02436397031747869, 0.013067553934108998, 0.00849004474002868, 0.06141016046915736, 0.029549932040806328, 0.019247434600921612, 0.015396363301468747, 0.03265679122081824, 0.04296986532530614, 0.015576414265004652, 0.020290724600532224, 0.03617857795740877, 0.05142328868220959, 0.07744718635720865, 0.010016345651820302, 0.04546398363475289, 0.042161597803767235, 0.030134713875928094, 0.03489995674629297, 0.03166075609624386, 0.05562255870816963, 0.021220997807436755, 0.022598510408507924, 0.09251647203096322, 0.04376243833186371, 0.06480242844138827, 0.030995316803455353, 0.02717780923869993, 0.024804855231195688, 0.01235642294133348, 0.05975606172744717, 0.021812529369656528, 0.05637859599664807, 0.03210772746907813, 0.0705768768010395, 0.013281230548662799, 0.07287684588560037, 0.009971226465755274, 0.04012799781880208, 0.03745826107582875, 0.05100327889834132, 0.012130922005910958, 0.010586666209357125, 0.04657441297812121, 0.03503123291635087, 0.019501937819378715, 0.03428291057103446, 0.10765365191868373, 0.06939761008002929, 0.023193955421447754, 0.06063836081219571, 0.06004470373903002, 0.08214375469833612, 0.03456897075687136, 0.040187556230063946, 0.06475856793778283, 0.010598200456505375, 0.022187129893739308, 0.098953923742686, 0.06939917749592237, 0.0253577611874789, 0.05371363953288112, 0.047718945491526804, 0.020193700878215686, 0.01849001819001777, 0.03526795682098184, 0.025713496741705706, 0.06220968506698098, 0.0438424138618367, 0.011159260707375194, 0.009085889240460736, 0.02492265569578324, 0.048737874387630394, 0.09653572671647583, 0.2724645153752395, 0.10245216531412941, 0.142634941264987, 0.11896210296877793, 0.10698894544371537, 0.1032528637775353, 0.15548522743795598, 0.16192421263882092, 0.15856380867106573, 0.12822015689952032, 0.1590970829129219, 0.05627691413142851, 0.12095483818224498, 0.09293154547257082, 0.1046166852382677, 0.14376529918185302, 0.15960770765585558, 0.08691971842199564, 0.11380443615572793, 0.0863844221457839, 0.14812290535441466, 0.21211685932108335, 0.1491088710193123, 0.17186069302260876, 0.12171402387320995, 0.14926262705453805, 0.08158071991056204, 0.1818749878023352, 0.10311417121972356, 0.17670377743031296, 0.12376903503068856, 0.24757690940584454, 0.18056826506342205, 0.2009679725659745, 0.08444727930639472, 0.13621183378355844, 0.2668444812297821, 0.13266842892127378, 0.14252189733088017, 0.08154377367879663, 0.11505881670330252, 0.127017345013363, 0.1235353204288653, 0.15227115633232252, 0.20403017396373407, 0.09801170323044062, 0.1185577775218657, 0.08363216875919274, 0.05925307050347328, 0.1351802705654076, 0.13927375019661017, 0.12462560406752995, 0.13441822145666393, 0.14003936839955194, 0.15144616631524904, 0.14573097441877636, 0.1526133008301258, 0.09024830588272639, 0.11944805617843356, 0.11816042741494519, 0.20504653799746717, 0.13679161481559277, 0.07255056553653308, 0.17839624732732773, 0.11811145075729915, 0.18880011620266096, 0.14052100612648896, 0.1447434209819351, 0.11978148828659739, 0.0970611706642168, 0.08003111556172371, 0.10745308375252144, 0.09876024949231318, 0.1309338898531028, 0.10381044314375945, 0.21521142683923244, 0.10057511353599173, 0.18023905344307423, 0.2330009186906474, 0.09437336453369685, 0.1133436905220151, 0.10199294638420854, 0.1417553834617138, 0.11892316862940788, 0.14063951905284608, 0.16718131197350367, 0.131956224995, 0.16750510888440268, 0.1514560186437198, 0.14736737018185003, 0.11114934898380723, 0.1068333505785891, 0.10937379247375897, 0.081833962750222, 0.2451405887092863, 0.1508809330740145, 0.09932632411697082, 0.21755033704851354, 0.09147674603653805, 0.12595283213470662, 0.10881189762481622, 0.11576572805643082, 0.18130906245538167, 0.14811793847807816, 0.15066484681197576, 0.1167073446725096, 0.09675576883767333, 0.10690402678613152, 0.10944665356406144, 0.11116190188165222, 0.14853568534765924, 0.15895511981632027, 0.1217397539211171, 0.09030134017978396, 0.13063636581812585, 0.10696530528366566, 0.07092252932488918, 0.1989938970655203, 0.1419012684907232, 0.11973100528120995, 0.12646969939981187, 0.14510402163224562, 0.15066696384123393, 0.10183903428592853, 0.11779390993927207, 0.1280054005661181, 0.1003475600321378, 0.09339501203170844, 0.14536103712660925, 0.18759589296366486, 0.12044508196413517, 0.12880228566271917, 0.15805334677653654, 0.11733469100935118, 0.14960737712681293, 0.15808385371097497, 0.1398723537900618, 0.11607827485672065, 0.15601197417293275, 0.15644458095942224, 0.2182133878980364, 0.0808707212230989, 0.1511389392295054, 0.10357163952929632, 0.12154812206115041, 0.17117279422070297, 0.14040045759507588, 0.16316452037010873, 0.1372487031455551, 0.27000721437590464, 0.1468276091452156, 0.10844708327203989, 0.2452984159546239, 0.2570364203836237, 0.23689896666577884, 0.11486957328660147, 0.1937828024051019, 0.0809484338387847, 0.08530994158770357, 0.09300176706165075, 0.19575937491442474, 0.15600613877177238, 0.10824319706963641, 0.0679647001836981, 0.07852738018014602, 0.12821304585252488, 0.11915799602866173, 0.11775213932352406, 0.09104724694043398, 0.17002240595008644, 0.09196252961243902, 0.06479919182934932, 0.12315056393189089, 0.1442380752414465, 0.12646606245211192], [0.013679854605080826, 0.06325427615748984, 0.016278287495619485, 0.059371848058487685, 0.03614893276244402, 0.014893743575417569, 0.02212438576056489, 0.06985463055648974, 0.03710896481892892, 0.07922822543020759, 0.03607150173879095, 0.008249590589132692, 0.0500788970717362, 0.04488644855363028, 0.015960700876478637, 0.0657263013667294, 0.03206519689410925, 0.03123176929407886, 0.015242256124370863, 0.004787000943906605, 0.03830444174153464, 0.034428127243050506, 0.060786912483828406, 0.037733905749129396, 0.011242904567292758, 0.022258189473567263, 0.03897386742755771, 0.02453723593082811, 0.019800220117239014, 0.060784849737371714, 0.06121888144740036, 0.03691992496273347, 0.06524627855313675, 0.03306323369698865, 0.023445471389485256, 0.04038896577964936, 0.007538312014990619, 0.003070208535064012, 0.03031635091507009, 0.014899811374821832, 0.02744324704898255, 0.014684803983462709, 0.023233800694080334, 0.016805383676130856, 0.029823982156813145, 0.0320355483064694, 0.02131139563529619, 0.03738445342917528, 0.07869679001825196, 0.036092349727238925, 0.05133654137275048, 0.026381775703547255, 0.04720424275313105, 0.014996456813865473, 0.08077326323837042, 0.06286206934601068, 0.007802841436517025, 0.04882506613752671, 0.03951960975038154, 0.03729167055072529, 0.06115647658173527, 0.028491946669029336, 0.028504228152866875, 0.07708772564572947, 0.04696212788777692, 0.0349017955761935, 0.027092527564881102, 0.02317211337919746, 0.04855339089408517, 0.01580224428991122, 0.01129648762954665, 0.04256393514307482, 0.07713554879384381, 0.07720612322113343, 0.03857511614582368, 0.015184114154960428, 0.03190733911469579, 0.12268168266330447, 0.02712981645683093, 0.009509139877211834, 0.033944331774754186, 0.02412589612816061, 0.037604336094643386, 0.03777683665975928, 0.015596263110637665, 0.02815808029845357, 0.027396492593522583, 0.023093622144577757, 0.021151412344936813, 0.011448611788052534, 0.03390421339177659, 0.03894729260355234, 0.02635191846638918, 0.016564946488610337, 0.01827948064809399, 0.07141503039747477, 0.014850151093144501, 0.02274796792439052, 0.01840768475085497, 0.055993147393954654, 0.045343475815440924, 0.07180375632430826, 0.06646310897277934, 0.06809501961937972, 0.026671915581183772, 0.024730757510821735, 0.025923447350838354, 0.039834690878966024, 0.018736054987779686, 0.07743109150656632, 0.0171704389088388, 0.014862259550552284, 0.041335003051374636, 0.019171287704791342, 0.027289392626179115, 0.06220199726521969, 0.026557562074490955, 0.06895700336566993, 0.03368639347276517, 0.04671241682288902, 0.08972372367445912, 0.014647009582923991, 0.01263153666098203, 0.0280067279735314, 0.02235188158894224, 0.014250848608623658, 0.010194973388154591, 0.07128966426742928, 0.025809516232194643, 0.03872030906911407, 0.07142446881958417, 0.0197447023820132, 0.021629793103784323, 0.03258730923490865, 0.03436888095789722, 0.024641857549015964, 0.04250819349129285, 0.049451530378844054, 0.03900696297309228, 0.003062682521496234, 0.003739860258065164, 0.025296053516545465, 0.07210444911782231, 0.01724958323341395, 0.048001083744955916, 0.018367552797177007, 0.007212956169886249, 0.01085694706333535, 0.04793860084776368, 0.010190740177806999, 0.015409380995801516, 0.045825612265616655, 0.011690859815904071, 0.05216673236074192, 0.03431886614167264, 0.007740402644100998, 0.024701171687671115, 0.03856570486511503, 0.07892329857817718, 0.03962850444284933, 0.027706827369651625, 0.012025303789414465, 0.006180553688734237, 0.05588866996445826, 0.03548131537224565, 0.017631510239360586, 0.010985915366161083, 0.023814390879124403, 0.048376445924597125, 0.02845603011415473, 0.0740698529407382, 0.04277979409588235, 0.039008940902671645, 0.018479638300569992, 0.058699643771563254, 0.06727524075124945, 0.01684322557412088, 0.022205750590988567, 0.03193567134439945, 0.034746078574763875, 0.04913789792252438, 0.02259397609824581, 0.06672786655170576, 0.028832072525152137, 0.014444275193714669, 0.04213639362049954, 0.05175362667068839, 0.05755308922380209, 0.04645406800721373, 0.019079258000212054, 0.02331556416382747, 0.02384775105331625, 0.17723261405314716, 0.05073908111080527, 0.03807431658996003, 0.03914746043405362, 0.07000282938991274, 0.030907700969172374, 0.0478941059139158, 0.04032661519678576, 0.04513572535610624, 0.027751044104141847, 0.042302936648151705, 0.03633922790842397, 0.03346873979483332, 0.02739671990275383, 0.022080218219863515, 0.026584191181297814, 0.03665792223598276, 0.03108750596376402, 0.01236319387265082, 0.04075463169387408, 0.006547268363647163, 0.048217319284698794, 0.02972727395328028, 0.02318250005399542, 0.013536157003337783, 0.026131321642813937, 0.05275668802538088, 0.05531695671379566, 0.03366470749356917, 0.043291762338152955, 0.08908229095063039, 0.02491982790109302, 0.056031158925699334, 0.012164617206768265, 0.03408382500388792, 0.027280230707089816, 0.048374915828130076, 0.009570429400940026, 0.02936035274927105, 0.059064525977841446, 0.017604993090831807, 0.03545138179989798, 0.02549412128116403, 0.052720596747738976, 0.03564830623301012, 0.023467566186029996, 0.04233896007229175, 0.10066517548901693, 0.05824093374290636, 0.04361852444708347, 0.02988952524693949, 0.013494647623571967, 0.05079576253358807, 0.031833928411028216, 0.06178235049758639, 0.043278948204325776, 0.175416162237525, 0.04270437492855957, 0.03257695139784898, 0.01938339605528329, 0.044871266332588026, 0.027152488008141518, 0.020223671769989387, 0.06092800027025597, 0.0321495625456529, 0.04290368441226227, 0.02539690926537982, 0.012338705543827797, 0.022952503824074353, 0.019207380678770796, 0.02524985885247588, 0.01270439605494695, 0.029686599171587398, 0.01047989193882261, 0.06845716054418258, 0.03544092218258551, 0.005593681117586259, 0.02341913914174906, 0.021062622645071576, 0.04613748053088784, 0.02993657486513257, 0.007397320919803211, 0.028872255368956497, 0.041253310827804465, 0.08289138493793351, 0.04668445100209542, 0.05605694664908307, 0.033652677067688534, 0.02144564887774842, 0.016314863925799727, 0.051684789293046506, 0.06364594692630426, 0.031370502563991716, 0.05039543705061078, 0.030487226388816322, 0.02959724628765668, 0.03984253813645669, 0.014658654940181544, 0.05288894807121583, 0.04604425660467573, 0.035668102492179186, 0.09260073929492917, 0.07971033813165766, 0.007400231835033212, 0.029937460353331904, 0.009695447781788451, 0.019413261774129102, 0.03301661155585732, 0.009954481917832578, 0.04205289988645485, 0.06511421528245721, 0.04119483807257243, 0.03395803478945579, 0.03362718450703791, 0.04656815349257418, 0.03565037237214191, 0.015932197316682765, 0.037625031412712166, 0.011493367957882583, 0.018074859931532825, 0.027738031498821716, 0.07468345894345216, 0.056795755933438025, 0.036506181449762413, 0.02261607937647828, 0.08638643739478928, 0.04061787635354059, 0.0411513812973031, 0.07015100786728518, 0.05009452712589076, 0.04668828811762588, 0.0460154086883579, 0.016900147876835296, 0.09019042006028549, 0.011455908584009324, 0.03866592788004449, 0.02709777094423771, 0.06063938540007387, 0.032340210529842546, 0.06394858711532184, 0.02427988625796778, 0.08749218484652893, 0.07524069225681679, 0.022650871259559478, 0.016586959860952835, 0.027223500090518167, 0.04861918504216841, 0.031237652192690542, 0.008057530403935483, 0.031054780219814608, 0.034734010829457214, 0.02597763855010271, 0.03716908302158117, 0.005333076597058347, 0.03835588826664856, 0.03953436788703714, 0.02502284987297441, 0.010511215659789741, 0.02448764519899019, 0.052435859705188444, 0.09746529255062342, 0.12281540834477969, 0.09572721152965512, 0.08926920020686728, 0.18526224818612846, 0.10450757680726902, 0.13359642055417809, 0.1390295047312975, 0.09317205899528094, 0.14096183675740445, 0.14610122383705207, 0.059654166123696735, 0.14234516609992298, 0.08133796722229038, 0.08428791857191495, 0.13904599313225063, 0.21320756365145954, 0.14174823170261724, 0.08989018867058413, 0.12044683258448328, 0.17089619620570115, 0.08970163735960211, 0.09150600446654217, 0.13061442199562276, 0.11389986532075064, 0.13098699200366223, 0.15638238643961294, 0.09834202086286885, 0.11549449046807629, 0.10705200848834855, 0.08815404825976916, 0.0843775055504271, 0.22824531101754733, 0.12776773689048632, 0.18250659533909389, 0.08565907499619893, 0.12278023308941297, 0.08509132439004523, 0.07384447074894394, 0.08625934778579644, 0.08896290949944939, 0.09825657294797045, 0.12173908895679883, 0.12024614906736783, 0.0904987667288099, 0.12413598676877362, 0.16149951757064887, 0.08622555674186774, 0.0976798656795706, 0.10664817837199994, 0.11881426375891481, 0.09775425347366504, 0.15227615035005979, 0.09732921235263348, 0.14038319566420146, 0.23622203298977443, 0.07413921279034444, 0.17943786643445492, 0.13394497042255743, 0.07343196216970682, 0.1227684672921896, 0.09490960397358451, 0.09682274702936411, 0.1799215261957475, 0.12697998487523623, 0.09920302073338202, 0.18002862616309098, 0.12335176313562052, 0.13781845543001378, 0.05664246130202498, 0.09624193462410144, 0.20672910128320965, 0.2109874649239438, 0.2235864760088069, 0.12808972889823572, 0.18272135167249612, 0.1304506914956229, 0.17985492119831697, 0.123580646568111, 0.16089577068175587, 0.1354857606015035, 0.12059008489762034, 0.13779743441513606, 0.09539840024496828, 0.13535481691360474, 0.12104103927101408, 0.12756531632372312, 0.11306118246700082, 0.07452562491276435, 0.12681495158800057, 0.15787989965506963, 0.12454313492136342, 0.07980253068464142, 0.09241482748516969, 0.07013299954789025, 0.15689387970737048, 0.1194904510463987, 0.13839560374617577, 0.14539577811956406, 0.08538539468177728, 0.13204522164804594, 0.2603219955095223, 0.15083928459456988, 0.17264019405203207, 0.14642485789954662, 0.09472760052553245, 0.1390105193214757, 0.10787450149655342, 0.08657771641654627, 0.08833324935819421, 0.2316348919911044, 0.1320953925273248, 0.09257084304200751, 0.07242205778935126, 0.12384243894900594, 0.09600173322749989, 0.11710120710943427, 0.16876612550445966, 0.11462098519716944, 0.08914253807493619, 0.2029778068619115, 0.06815302079277379, 0.08568307477980852, 0.10711188920374427, 0.10785223876259156, 0.10477573384663888, 0.1170588122414691, 0.16049786417612008, 0.09812976153833525, 0.15040504932403564, 0.2892203948327473, 0.2527430307652269, 0.11168429242180926, 0.15691046310322626, 0.14748694162283624, 0.12103888152965478, 0.10892150138637849, 0.18336946118090833, 0.14028373600116797, 0.13593660640929425, 0.07539589357163225, 0.18944845641297953, 0.17068779096007347, 0.10423939941184861, 0.1071638853422233, 0.14550139888056687, 0.08699511723326785, 0.15768308378756046, 0.18079790845513344, 0.15198856006775582, 0.15743754910571234, 0.18295562267303467, 0.17458703315683774, 0.15489331419978822, 0.12033426362488951, 0.3862141801842621, 0.16967644808547838, 0.09682573258344616, 0.1061638400756887, 0.12332851652588163, 0.1499371858579772, 0.07425543226833854, 0.10553105867334775, 0.21073179292891706, 0.09071274274694067, 0.16138616151043347, 0.07632213458418846, 0.1078705456373947, 0.10553798651588814, 0.09585411793419293, 0.14554808208984987, 0.10088717857641832, 0.10328050050884485, 0.1124874200405819, 0.09275209331618887, 0.17983373733503477], [0.023809900673638498, 0.03807815709816558, 0.03313257997589452, 0.023570447361895015, 0.03478787633191262, 0.04468426208144852, 0.026131582878796116, 0.05639011412858963, 0.026229322455557327, 0.040903967073453326, 0.031299504052315436, 0.0396588926336595, 0.0350750968126314, 0.057076201241995604, 0.06543846681181874, 0.03448819794825145, 0.009529033675789833, 0.016263917820262055, 0.026836280511426072, 0.04013944470456668, 0.020228898185970526, 0.020470728066616824, 0.04738116058121834, 0.06339575749422822, 0.012420564856646317, 0.030411647765764167, 0.047970285040459464, 0.013471496008735682, 0.014167955378070474, 0.08757075241633824, 0.022771245068205253, 0.05666314644206848, 0.029983889111982923, 0.07053342341844525, 0.031496777930962186, 0.04812167298847011, 0.010023176803120544, 0.032255593820341995, 0.015029097740937556, 0.054065161384642124, 0.04041150671296886, 0.025185808539390564, 0.012545479760904397, 0.0403029953927866, 0.018764967364924293, 0.08384402774806533, 0.0334859203015055, 0.048344887260879786, 0.06426393626523869, 0.011482960927034063, 0.03185327683708497, 0.027767773385026624, 0.020160025185240165, 0.03660388031442251, 0.057068974844047, 0.06842383768941675, 0.03446494455316237, 0.031004850220467364, 0.04916878144389816, 0.018518966190250855, 0.041431348238672526, 0.024338289463360394, 0.03211430925875902, 0.028229988047054837, 0.04299581589709435, 0.03547174124313252, 0.04705816094896623, 0.02845798938402108, 0.04230010715712394, 0.03561039648151823, 0.03804143139028123, 0.009761442097702196, 0.03337639796414545, 0.018079624943701283, 0.03511365117239101, 0.06619054824113846, 0.05565105378627777, 0.03317799771736775, 0.04007958434522152, 0.025854526852656688, 0.008044567840572978, 0.0070412490666577855, 0.02621930218966944, 0.03659472009167075, 0.027992773900872896, 0.011136310956706958, 0.07297951501927205, 0.035294772524918826, 0.06421065091022424, 0.010607147788895028, 0.03815453978521483, 0.013341078185476363, 0.010527292698887842, 0.0313236225795533, 0.05597156658768654, 0.04068653391940253, 0.033643883253846846, 0.027414633227246146, 0.010105134503516768, 0.0460485415533185, 0.03314914980104991, 0.01940587761678866, 0.027952470617102723, 0.07036020699888468, 0.021960621333814094, 0.03317921908040132, 0.009797090631244438, 0.06306481560958282, 0.06413473641233784, 0.026926939575267688, 0.033272673708519766, 0.020751572014497857, 0.06407600242112364, 0.03858572504084025, 0.02900751114689878, 0.08692211365061146, 0.04715996155781405, 0.05484069637688143, 0.035714276800198216, 0.029384725727140903, 0.014716615401474493, 0.02724971529096365, 0.012461301554659647, 0.031888740469834635, 0.035384834477944035, 0.02315849857404828, 0.04188520334927099, 0.028470186050981283, 0.02961356166218008, 0.05818400465484176, 0.01015113408876849, 0.03562869657097118, 0.040732623410544226, 0.025235115982858197, 0.04119936050847173, 0.04292071903390544, 0.02315721444652549, 0.027758714942527667, 0.016148778909285153, 0.039835539047739336, 0.04226096247189811, 0.026871367557240382, 0.022116032994485328, 0.04078584091205682, 0.04442613718232938, 0.09349391529602663, 0.025145474721544554, 0.05381597279171858, 0.06822797177093369, 0.05261419567146471, 0.013676891103386879, 0.03560989436560443, 0.0998829806755696, 0.0377345537500722, 0.05763449985533953, 0.07544364886624472, 0.022795984454985176, 0.01808865454846195, 0.03489144452448402, 0.040956604427524974, 0.02913902819688831, 0.05793982704303094, 0.05631066785593118, 0.03573811373540333, 0.02990220028108784, 0.035065678746572564, 0.041731959607984336, 0.05111647550282734, 0.029253117074923854, 0.014258147949086768, 0.02046363059032176, 0.047637249875281534, 0.016393518008823906, 0.013367994821497371, 0.036525054901306114, 0.06903451242085014, 0.02904809432636414, 0.014004647266119719, 0.016943261991920214, 0.01752660872547754, 0.09288325413529362, 0.1003912848287395, 0.025989063383479203, 0.041783182216542106, 0.029934047322188104, 0.03146118537655898, 0.033252612820693424, 0.11398356940065112, 0.039356900445584736, 0.02620406398948814, 0.0396109473492418, 0.019049612805247307, 0.022735922231471965, 0.022430459336776818, 0.014656529429235628, 0.029656852196369852, 0.04112595319747925, 0.0254449885604637, 0.033576915240181346, 0.019826520134561827, 0.011394497772146548, 0.04142557390566383, 0.03652175382844039, 0.013919504691979714, 0.05073238057749612, 0.07197900156357459, 0.05359413594539676, 0.06773251907101699, 0.0462389113381505, 0.027587042190134525, 0.09245644882321358, 0.037337566659386666, 0.023841669683211615, 0.028998004871287515, 0.010254141641780734, 0.04871531988361052, 0.06437037805361406, 0.036433279647358825, 0.07669353751199585, 0.035738252835082154, 0.04348297689908317, 0.04144662884729249, 0.038444179243275096, 0.05202561743291361, 0.04520069169146674, 0.02383112864169691, 0.07656968451504197, 0.04969053755381277, 0.014451923979712384, 0.009764194405371589, 0.12252910727901117, 0.03962947814060109, 0.013663915817492774, 0.07365300173738173, 0.027897858726126806, 0.02571903189112033, 0.05013733929289239, 0.059109567132379325, 0.03556402200566871, 0.05029223865962454, 0.08465212902852468, 0.03631924505212477, 0.029770771440650736, 0.030938313076538698, 0.023930169309356382, 0.03751666597755892, 0.06161764290715967, 0.012383700049083148, 0.043323772227657695, 0.0374604493512639, 0.03764060039871505, 0.01294370602616774, 0.02173658603403185, 0.02445999998599291, 0.0352572868578136, 0.055636295649622164, 0.07698359766176768, 0.014734771302235978, 0.00851207083490278, 0.02457594296096691, 0.036424804744975905, 0.00949509589866336, 0.032701130091611824, 0.037890586270285506, 0.09766982336129461, 0.0314136845325785, 0.04868462295936687, 0.014942207939124532, 0.04639451638130205, 0.028667256369122436, 0.06253020465373993, 0.062478540997420035, 0.057232881763151715, 0.012990122910455933, 0.04865761387294956, 0.058612770933125696, 0.057406579942575524, 0.028056571459663764, 0.010808078971292292, 0.06768331849681479, 0.042491118157548566, 0.08657173173768179, 0.018926621547767093, 0.008453005209698208, 0.114999634878976, 0.004660634398793003, 0.057474508083292415, 0.06835464068821498, 0.027823348795729022, 0.0298913776475404, 0.033056709582784345, 0.05188804106520755, 0.02956966383914862, 0.07845458694334541, 0.017133139838863696, 0.012588974703768534, 0.04008731964443411, 0.038879316965384145, 0.017078186984040906, 0.02729722631296941, 0.07673193580870118, 0.015078941227069922, 0.009707904836562063, 0.02342979553421693, 0.03857752833781498, 0.08648570028266736, 0.05114592392263668, 0.05636927971084203, 0.01974835290041353, 0.027752862577991824, 0.02016473252193204, 0.048176983770515235, 0.09045842782195125, 0.06498548361871924, 0.04970258833574397, 0.04811520994241748, 0.0229519270693085, 0.0445756829077644, 0.025312633519726138, 0.05312612998698439, 0.03450406548966255, 0.027118983645258204, 0.025430065879066075, 0.03307441256142088, 0.0019620005457129863, 0.0470487394902323, 0.018014200597203205, 0.018721127217369418, 0.05063753495258944, 0.038771840411105325, 0.07491184026002884, 0.009364869761546808, 0.046267094290150065, 0.01831620805231588, 0.04159297528011458, 0.06928234733641148, 0.006757956031443817, 0.04260650643014482, 0.0447057071807129, 0.035833417371447594, 0.039668215704815726, 0.018087760578574877, 0.030527446552046707, 0.03817475673609546, 0.030194811722529784, 0.04168743074738553, 0.0254347715194204, 0.007466609523232494, 0.022517084509932568, 0.05427154120323913, 0.040736976212688854, 0.035466170470629416, 0.1474559868552855, 0.09878762838031564, 0.10334652875150953, 0.1159473175981215, 0.13361396746976034, 0.1753785985388926, 0.08659950417599507, 0.18264984765223094, 0.1799194227371897, 0.11722635610827378, 0.15323984649564537, 0.16934054610984667, 0.09292735212615558, 0.1661892802055393, 0.10255384378667388, 0.10992851520755462, 0.09604609584701912, 0.1760297750255891, 0.1026094633021525, 0.08987510483711958, 0.11728605361921446, 0.09230941707002265, 0.10509313217231206, 0.16409549755709513, 0.1415807149772133, 0.1396819840052298, 0.19625237131757395, 0.12203411598290716, 0.1009404571460826, 0.23955228286130087, 0.14902617117123945, 0.13418081562433923, 0.19561946099357946, 0.12866161178265298, 0.14168089388736657, 0.12238820269703865, 0.07417381129094533, 0.09531813633761235, 0.07429409519370113, 0.11648089039538588, 0.1596404401851552, 0.10905152905200209, 0.1676800080708095, 0.1397175799523081, 0.10639520016099725, 0.15161961343671593, 0.10020719149283, 0.17944995792848722, 0.2289325584258352, 0.12381395404892308, 0.12126495582716805, 0.1115067605195301, 0.07973321833248649, 0.1263076245252575, 0.15689469394939287, 0.12541600236935274, 0.12826453308973992, 0.20181240939668246, 0.16184126851814135, 0.12865707916872843, 0.17626948787697724, 0.1293027459510735, 0.11340366623231343, 0.13186688907444477, 0.13979950627045973, 0.14319843745657376, 0.1649687314139945, 0.12548076175153255, 0.0838881189535771, 0.08834508979426962, 0.20089061957384857, 0.09174273176384823, 0.09153150381254298, 0.26083765498229433, 0.10414262674748898, 0.2500717469624111, 0.12263217674834387, 0.09370808808931283, 0.14333067036100797, 0.14043325797787734, 0.12208906374871731, 0.13197800596909864, 0.10765283089131117, 0.14709177639867577, 0.06708456562565905, 0.10335477295198611, 0.13758537865110806, 0.09839332489562885, 0.13311930187046528, 0.2034625115671328, 0.19697601534426212, 0.11215273942798376, 0.10972040851733514, 0.11621573248079844, 0.13173115492931434, 0.1376928857394627, 0.14070927245276316, 0.07962972138609205, 0.08403312867241246, 0.14912671649030276, 0.14618739778442041, 0.0929454622258033, 0.07148995423423392, 0.2171745914965868, 0.09605767165443727, 0.19393038377165794, 0.23443393036723137, 0.11424677313438483, 0.29992002355200903, 0.058253154158592224, 0.1151862862919058, 0.10314180116568293, 0.17703868874481746, 0.11798106346811567, 0.13968844365860733, 0.15227606892585754, 0.12457635599587645, 0.1337388450545924, 0.10870892993573632, 0.0512026426648455, 0.1303858371185405, 0.15314270742237568, 0.07683795690536499, 0.2107609970761197, 0.16746637810553822, 0.09499039713825498, 0.10746576557201998, 0.1140433211943933, 0.08481938112527132, 0.16750134980039938, 0.13987851488803113, 0.21926000102290086, 0.10618123092821666, 0.15342063536601408, 0.09802170483661549, 0.10887021092431885, 0.17707038990088872, 0.1063671155965754, 0.1023989613833172, 0.1220822376864297, 0.15026456543377467, 0.12255611297275339, 0.1274117095662015, 0.14734630845487118, 0.09667823264109236, 0.1485585926898888, 0.10481782337384564, 0.13826704850154264, 0.19445817545056343, 0.15826761456472532, 0.13003929571381637, 0.11444181124014513, 0.18263173076723302, 0.10330675981406655, 0.17526419753474848, 0.19524340331554413, 0.1113948565242546, 0.09305398033133574, 0.10563386351402317, 0.10856830355312143, 0.12224219553172588, 0.20350040096257413, 0.09531953411975078, 0.13913439267448016, 0.14322169763701303, 0.16339625364967755, 0.13033076721642697, 0.1751532977713006, 0.08422063503946577, 0.09691796584853105, 0.12107894223715578, 0.11629717025373663, 0.12261829392186233, 0.09875514690897294, 0.20385961740144662, 0.10850867389568261], [0.06341757918042795, 0.045908206940761635, 0.01982788398994931, 0.06263707391917706, 0.03686042422694819, 0.04524223839065858, 0.01589829770715109, 0.054790963152689595, 0.033661487844905684, 0.05626975219430668, 0.02151430644361036, 0.03524802824748414, 0.03826300700062087, 0.007433966051654092, 0.011463869496115615, 0.056812223978340626, 0.04420892455215965, 0.025698446834992086, 0.04238971109901156, 0.019790077715047767, 0.08790386561304331, 0.01204317809814321, 0.03988590670217361, 0.03271282124998314, 0.03475613446374025, 0.06622928580535309, 0.04203044716268778, 0.043626310636422465, 0.041561121453664134, 0.11979405475514275, 0.06801556316869599, 0.013711718609556556, 0.06438541438962732, 0.08671893312462739, 0.023531630069815686, 0.08913079263376338, 0.008818529479737793, 0.05752716240073953, 0.05771874676325491, 0.029785210665847574, 0.007726756456707205, 0.0591924162581563, 0.05159710221258657, 0.05313119864357369, 0.005878735375258007, 0.06281273306480475, 0.01531935466586479, 0.06322458346507379, 0.022347547446510622, 0.022902173489066105, 0.028178071636440497, 0.06775398791900702, 0.029739368839987686, 0.03264996515853064, 0.03767333971336484, 0.03048444100256477, 0.03353281385664429, 0.017801154172047973, 0.049552177478160174, 0.07279381355536835, 0.054070267360657454, 0.00845865486189723, 0.06904122313218457, 0.0202418141000505, 0.034291463504944525, 0.021059576022837843, 0.04706249678773539, 0.0393638486441757, 0.026372267731598446, 0.023584674544898526, 0.017311155197343657, 0.042968979837106805, 0.021178621599184613, 0.019105669975812947, 0.04964629028524671, 0.053598824622375627, 0.02197124040685594, 0.09797195464904819, 0.03812565115679588, 0.04305246339312621, 0.04833493654483131, 0.032705533783882856, 0.022862935505275215, 0.03289514021681888, 0.02967415823202048, 0.028080077609047294, 0.05724673066288233, 0.02473280668657805, 0.018401952826284936, 0.021056140939305936, 0.03128903764965279, 0.02363351549554084, 0.03886076581797429, 0.057133578163172515, 0.025081510921674113, 0.012562768833179559, 0.03672669854547296, 0.029940547687666755, 0.013698977418243885, 0.04559519873665912, 0.014941098534369042, 0.023600660829937885, 0.03443417638274176, 0.035449129063636065, 0.04634672376726355, 0.017623941181227565, 0.022120626676561575, 0.02313894828382347, 0.03496960836595722, 0.032208357605018785, 0.031081653599228178, 0.04448815528303385, 0.019642587950719253, 0.023547965800389647, 0.055905687622725964, 0.04780456643285496, 0.046169286859886985, 0.03750844891848309, 0.019832426781899164, 0.017582221455605965, 0.02991130282836301, 0.014371639716305902, 0.04334892891347408, 0.05828711483627558, 0.045399248001298735, 0.012653366828869497, 0.012261544237844646, 0.050171439070254564, 0.03916436952671834, 0.03858525685167738, 0.0712034021105085, 0.01333537170596953, 0.04104215751535126, 0.06259771210274526, 0.034169863244252544, 0.0063058892847038805, 0.08978830663753407, 0.054026474710553885, 0.03882005710953048, 0.025684329913929105, 0.022345684867884432, 0.008649535244330764, 0.04934378919590797, 0.04362936404400638, 0.07807703648826905, 0.030534069053828716, 0.020085187861695886, 0.026040204567834735, 0.025356668746098876, 0.047208873754633326, 0.049525690863707235, 0.04189429911119597, 0.028679171444049904, 0.03788506978058389, 0.055196872978870354, 0.04331364169982927, 0.06200056057423353, 0.05071271663265569, 0.03039155973653708, 0.048769941952611716, 0.020429958290021335, 0.060303714126348495, 0.06329189413892371, 0.03967804089188576, 0.014076185213135821, 0.017061656174649085, 0.07028761053723948, 0.006044324637124581, 0.0517020105118198, 0.06164124235510826, 0.027691349985876253, 0.02453543950936624, 0.03268138472256916, 0.06008265420262303, 0.028152214363217354, 0.03474950517660805, 0.044746219114001305, 0.029904201959392855, 0.06037493994725602, 0.02978218100698931, 0.036383237689733505, 0.01348324484258358, 0.010069632703172309, 0.027761893879090036, 0.036612965898322206, 0.06510860379785299, 0.10804954317531415, 0.04299230108569775, 0.01881626800500921, 0.01647634168953768, 0.012580309811580394, 0.11614409275352955, 0.05745526483016355, 0.0775106700935534, 0.04904594285679715, 0.023637834370934536, 0.01483320807372885, 0.019987107321087803, 0.08072245453617402, 0.09893292986920901, 0.019490085508940474, 0.06776770111173391, 0.05273553130349942, 0.03437038391296353, 0.022858589488480772, 0.1003796411678195, 0.014830558394481028, 0.0455617707089654, 0.06121261178382805, 0.07834412144230944, 0.010091790264206273, 0.06681689034615244, 0.02961573636691485, 0.051179759071341584, 0.025150156613173227, 0.027099031323034848, 0.02341127661722047, 0.09747541629310165, 0.02717623843013176, 0.05779122108859675, 0.04699812077784112, 0.06297356622027499, 0.06443102551358086, 0.0584774235529559, 0.05591993346544249, 0.01932809714760099, 0.05297418224758335, 0.006776011424205665, 0.0776421023266656, 0.05051679303869605, 0.04225753926272903, 0.029552286557321037, 0.03508168199498739, 0.021274764922314456, 0.024915831329833184, 0.04582255546535764, 0.016544217243790627, 0.05665142474962132, 0.046246867161244154, 0.06183628724621875, 0.01932103529439441, 0.0009505805937806144, 0.02910767987902675, 0.025987482396885753, 0.06487820044692073, 0.06922582536935806, 0.034353691951504776, 0.050852301464016945, 0.01646522050058203, 0.014710917403655393, 0.01122175547893026, 0.02789786042246435, 0.051265349478593895, 0.06263670751026698, 0.03330853767693043, 0.05504812453208225, 0.045742620647485764, 0.06728383778993573, 0.049057664549244304, 0.03476006657417331, 0.022620508513812507, 0.08399895764887333, 0.05896852684340306, 0.05144199249999864, 0.022332629854125634, 0.0036341449262441267, 0.0280874532847, 0.005149705900943705, 0.024039113195613027, 0.023270531490977322, 0.01251410345347332, 0.014303212852350302, 0.06416204066148826, 0.0303195094955819, 0.013754099058652563, 0.03038551059684583, 0.0329168635154409, 0.03509685403800436, 0.05379273296732988, 0.02037413351769958, 0.024339239412386502, 0.01655565564786749, 0.04621823298345719, 0.01727203426084348, 0.04007063786100064, 0.03998742911166378, 0.013831024573716735, 0.0345824532476919, 0.057887959826205454, 0.007493212336807379, 0.014948479299034392, 0.036776262135910134, 0.01965982443653047, 0.026080738553511243, 0.002994933768474896, 0.02914750649194632, 0.07478624342807702, 0.02200722142255732, 0.010596455773338675, 0.054924963640847375, 0.07165384079728808, 0.030143609470022575, 0.01631900468575103, 0.04166896102417793, 0.028121681983715723, 0.032992262326713116, 0.040610368363559246, 0.03100754739716649, 0.055548371081905704, 0.053174753806420734, 0.04020002091835652, 0.022550113898302828, 0.013344367383979261, 0.04570386611989566, 0.013697719583953065, 0.03212759158174906, 0.00795186638632523, 0.052678798990590234, 0.06313929839857987, 0.05088143775771771, 0.033044400957546065, 0.026632133073040416, 0.03217644610309175, 0.0385976469011179, 0.08540092634835414, 0.0247778902495546, 0.0356308984171067, 0.047328767499753406, 0.02446603385864624, 0.015636953159368465, 0.042920997233263085, 0.018015730693670254, 0.043615929050637145, 0.05450004465611918, 0.04588555744183915, 0.056243530208511014, 0.015388012231726731, 0.0036251479759812355, 0.0015203663809058654, 0.026531572486939173, 0.053519778685378175, 0.01323837342871619, 0.0821757951219167, 0.05078640214300581, 0.06570967047342233, 0.06605187603937727, 0.033882686868309975, 0.03184625060696687, 0.019392130497310842, 0.01826553505712322, 0.02600061035315905, 0.05187076895630785, 0.09344084707221814, 0.22739138826727867, 0.10110536829701491, 0.15939666969435556, 0.237155018640416, 0.1580271010420152, 0.08880452585539647, 0.12216921230512005, 0.0950136301772935, 0.16010702800537857, 0.14772764513535158, 0.11704239169401781, 0.15965517796576023, 0.10284804978540965, 0.1406780055591038, 0.23428761107581003, 0.14558963557439192, 0.09830319508910179, 0.14334464818239212, 0.09206534123846463, 0.1424783489533833, 0.10860184353909322, 0.16785553150943347, 0.21407227510852472, 0.07352367974817753, 0.1699779483356646, 0.12127398034291607, 0.12083525317055838, 0.11632854571299893, 0.21477902361324855, 0.17442657319562777, 0.10310328751802444, 0.11357013801378862, 0.14318402537277766, 0.15826092420944146, 0.1682656245040042, 0.1369306059288127, 0.16079793950276716, 0.16431978052215918, 0.16670332476496696, 0.06502017711422273, 0.1670714842953852, 0.11910608809973512, 0.08237397484481335, 0.07347194823835577, 0.25215900210397585, 0.1258096612457718, 0.17383750980453833, 0.11545506758349282, 0.08747551324112074, 0.1604220446731363, 0.1961039892796959, 0.22082904540002346, 0.20758225050355705, 0.10051832694028105, 0.12365232700748102, 0.12401265624378409, 0.07326627748885325, 0.22783221889819416, 0.20415108890405723, 0.15220920608511992, 0.17533408664166927, 0.09681359359196254, 0.10791785988424506, 0.0719385812325137, 0.07499475723930768, 0.11109506618231535, 0.1276824450386422, 0.1352551808314664, 0.15304403485996382, 0.0800530593842268, 0.1286027149430343, 0.10481179798288004, 0.12397885162915502, 0.10261742930327143, 0.11960084869393281, 0.07694330625236034, 0.2136950639209577, 0.11391590588859149, 0.15297582851988928, 0.1468902107860361, 0.19775875977107457, 0.17390103425298417, 0.09489531402609178, 0.14237677226109163, 0.1580151452549866, 0.11287014771785055, 0.15116332577807562, 0.10921912041625806, 0.0926052854795541, 0.09966692834028176, 0.09239478356071881, 0.18271550270063536, 0.11197427793272904, 0.07162604800292424, 0.1241562342537301, 0.15686186642519065, 0.15656185895204544, 0.08639337202267987, 0.1126702648720571, 0.09409935852246624, 0.09599280370665447, 0.13037605264357158, 0.12281270777540547, 0.11097596293049199, 0.13993237699781144, 0.09185363831264631, 0.0643740760694657, 0.1270109803548881, 0.14347637897091253, 0.0987146044416087, 0.05270569272605436, 0.12950374159429753, 0.07638599830014364, 0.18547380183424267, 0.09206865248935563, 0.08243701074804578, 0.12138971127569675, 0.0945716935342976, 0.07280616967805795, 0.24432580385889324, 0.07373094505497388, 0.09524974000773259, 0.13479117144431385, 0.17448510362633637, 0.08169428631663322, 0.17967728073043482, 0.1676256981279169, 0.1089119069012148, 0.15641897304781846, 0.10958251663084541, 0.20967882871627808, 0.117815120943955, 0.1499970733587231, 0.09578844931508813, 0.10187011118978262, 0.09554260929248162, 0.09436168694602591, 0.14219700119325093, 0.0750559950247407, 0.11008793701018606, 0.13495610973664693, 0.1598114310098546, 0.13306820818356105, 0.16294439003935882, 0.13092220548008168, 0.10609624441713095, 0.10231968135173831, 0.21544432719903334, 0.17662605802927697, 0.12843241622405394, 0.0722501916544778, 0.08562064277274267, 0.1642534469387361, 0.10206572605030877, 0.07085217202880553, 0.09536614269018173, 0.12162721210292407, 0.15418142239962304, 0.18299482842641218, 0.07995479394282613, 0.11955096279936177, 0.12219271675816604, 0.09274692966469697, 0.11223431969327585, 0.10851817338594369, 0.2093291524797678, 0.15085190534591675, 0.11479120249194757, 0.11795058367507798, 0.13299692129450186, 0.15134475247136184, 0.09450437607509748, 0.10044659221810953, 0.1128989854561431, 0.13121660825397286], [0.01960236778748887, 0.04188928134473307, 0.007114043999795935, 0.038294830292995484, 0.011325459378505391, 0.018196310914520706, 0.023032472568697164, 0.06538131380719797, 0.02348765930426972, 0.0396933825686574, 0.029039127486092702, 0.04054798046126962, 0.11724732284035001, 0.023383190356461064, 0.047984636056103876, 0.036272558450166664, 0.010142040871349829, 0.015831545128354003, 0.025801402649709156, 0.024288802208112817, 0.06321531467671905, 0.009575809335469134, 0.023176869909678186, 0.04965587119971003, 0.042374827433377504, 0.020537682509581958, 0.007402570236341229, 0.06407528995935406, 0.029515720305166075, 0.014643818771998798, 0.07588903246713535, 0.025620210051004375, 0.030539541438754116, 0.03377859281109912, 0.011992064055188425, 0.05608590991635408, 0.04656305769458413, 0.02700993458607367, 0.09057101035224539, 0.014970209383006607, 0.058306975556271415, 0.029992146883159876, 0.041918980822499306, 0.018837976036593318, 0.05102064600214362, 0.060959111100861, 0.06759210303425789, 0.010772377851286104, 0.04529219213873148, 0.008787540785436119, 0.016456506414605037, 0.023797161178663373, 0.011694490826422614, 0.07675923327250139, 0.028822610354317085, 0.04746272388313498, 0.06699800491333008, 0.010264642819363092, 0.06085706621940647, 0.014901231209348356, 0.009862068840967757, 0.02611787138240678, 0.038647498868938, 0.058295996859669685, 0.06369067595473357, 0.02889045367815665, 0.018734031257086566, 0.012555962278773742, 0.024673395856682743, 0.06752821217690196, 0.04004817156653319, 0.012651962261380894, 0.04385844425165227, 0.030993206559547355, 0.013821519994443017, 0.041115286626986096, 0.06595627724059991, 0.056033876458449025, 0.002939108360026564, 0.059657945563750606, 0.016052750937108482, 0.015491814518879567, 0.042502880562096834, 0.029388026800006628, 0.05799187746431146, 0.027743877078007375, 0.01645156498333173, 0.03417930505903704, 0.023727443401834795, 0.011641722854359873, 0.05081124331003853, 0.009057120203838816, 0.01765051091622029, 0.020721382295180644, 0.009601521571832044, 0.03627163224986621, 0.012139915987583143, 0.0731788007542491, 0.032963041216135025, 0.04671058477833867, 0.01665680655943496, 0.015725335738222514, 0.046418550091662576, 0.030770029606563703, 0.03857839686263885, 0.012176359255265976, 0.02268781409864979, 0.005205445008219353, 0.005845123294940484, 0.054075658321380615, 0.03363816998898983, 0.019253712746181657, 0.02455461660533079, 0.02060063529227461, 0.044036400238318105, 0.026970023156276772, 0.031389318340058835, 0.05119152147588985, 0.04337245711524572, 0.08395199624023267, 0.010186051500828137, 0.02968566957861185, 0.038897555986685414, 0.06318160505699259, 0.045513845780598264, 0.012234267978263753, 0.03673821667741452, 0.014179420923548085, 0.022840720268764665, 0.02096602979249188, 0.048613414101834805, 0.024226336274296045, 0.00586635507975838, 0.054112903108554225, 0.011849403763855142, 0.048322919689651044, 0.0387639185147626, 0.09168711903371982, 0.057846338488161564, 0.03563522407785058, 0.03848502365872264, 0.04666660553110497, 0.016630613411377584, 0.041417655401996205, 0.025123761600947807, 0.017819174365805726, 0.022655702428892255, 0.013942527385162455, 0.006931480336269098, 0.016146492246272307, 0.04039440763049892, 0.06349519680121116, 0.030644174931304793, 0.012294968024694493, 0.00748149912604796, 0.03331340955836432, 0.01898883981630206, 0.09462418500334024, 0.03325230408725994, 0.022205733627613102, 0.04170904887307968, 0.0392984310830278, 0.022527091205120087, 0.02539975063077041, 0.018429760887686695, 0.08858267204569918, 0.013149856839195957, 0.029649184750659124, 0.020911992959944264, 0.01933457885336663, 0.01550532245476331, 0.057948987265782695, 0.08199398166366986, 0.10614376222448689, 0.06665078497358731, 0.03894693637266755, 0.01289087868229087, 0.134519703154053, 0.060957469046115875, 0.05688580770843795, 0.018316438754222224, 0.024450763428051556, 0.0016146676935022697, 0.05421602346801332, 0.0484495546801814, 0.05493151489645243, 0.03769425216263958, 0.04629693965294531, 0.037468201613851955, 0.04178652400150895, 0.03590571527768459, 0.01587461174598762, 0.01872346137783357, 0.01986256561108998, 0.08450200315564871, 0.024563686922192574, 0.050793017859437635, 0.030448750060583864, 0.009789111907593906, 0.054672877703394206, 0.05502382280038936, 0.029374639304088693, 0.04045367766437786, 0.034917161001690795, 0.025577275747699395, 0.016286166983523538, 0.11795537413230964, 0.0497286271170846, 0.025825494035546268, 0.05504504737577268, 0.020745740006012574, 0.017269220036853637, 0.03857547916205866, 0.012846569497404354, 0.07292340017322983, 0.04556762646617634, 0.020063520542212894, 0.03987969471407788, 0.03748875443956681, 0.027957493472578268, 0.04981509961986116, 0.03907922016722815, 0.035824158761118136, 0.031405189274145026, 0.0014891430619172752, 0.04726006243644016, 0.03607655343200479, 0.010351121259321059, 0.05151429719158581, 0.025079100426020365, 0.032804043497890234, 0.07505923842212983, 0.004739892802068165, 0.061588160560599396, 0.025638464339343563, 0.016040033494521464, 0.05042469887328999, 0.05471494687455041, 0.05038619879633188, 0.04491650086960622, 0.0483763611077198, 0.00885081332775631, 0.02778401242436043, 0.04518602515703865, 0.03534801038248198, 0.03197627827259047, 0.024082347750663757, 0.03500234768060701, 0.04111218572195087, 0.009919953815239881, 0.04873722977936268, 0.051665373013487885, 0.06889334999557052, 0.06278710479715041, 0.017070446595815674, 0.08868227420108658, 0.019962520604687076, 0.03379641114068883, 0.06098138740552323, 0.03310288728347846, 0.017293189286387393, 0.027361695621428744, 0.030654783826321363, 0.04006505351779716, 0.025624116716374244, 0.03478110455242651, 0.005026811758788037, 0.042788621836474965, 0.07653662628893342, 0.041699369571038654, 0.05334671154352171, 0.0546327694984419, 0.02590289622146104, 0.03737820412165352, 0.01700424193404615, 0.034630615663315566, 0.055106366585407934, 0.05541358010045119, 0.05815032896186624, 0.07149576249399356, 0.07963322941213846, 0.012463325285352767, 0.026807111987311925, 0.07656935881823301, 0.03163413716746228, 0.03485246608033776, 0.030185956840536425, 0.011180290203940655, 0.04050460171752742, 0.030472858409796442, 0.033452597446739674, 0.02291090114574347, 0.010973305641008275, 0.017655077456895794, 0.0375543246710939, 0.015368377124624593, 0.016875115023659806, 0.021774762110518556, 0.019040447493482913, 0.0711348293615239, 0.0039577874704264104, 0.051940596995076964, 0.01801552204415202, 0.026402771273361783, 0.03178856834503157, 0.05127338672588978, 0.04981755591662867, 0.050048902431236844, 0.055178203087832244, 0.06868452405823128, 0.025247175246477127, 0.006484138313680887, 0.09393188250916344, 0.02797557643082525, 0.06169026651020561, 0.03841928718611598, 0.040252454711922576, 0.030314009969255755, 0.015777767835451022, 0.03445650018485529, 0.02675263749967728, 0.015665064865191067, 0.011116351849133415, 0.027862356077613573, 0.012314012806330408, 0.016370851546525955, 0.04541021312720009, 0.06962154020688363, 0.025386895784842115, 0.02371551305986941, 0.013808653274151896, 0.011538911228334265, 0.03547398719404425, 0.021684918985036866, 0.030036329690899168, 0.052157171802329164, 0.00656113719534395, 0.059222278584327014, 0.020892834523692727, 0.07629721877830369, 0.004329116183466145, 0.06499057941670928, 0.02944655723071524, 0.0484400653679456, 0.028405370689662438, 0.052376783053789816, 0.0137747892877087, 0.033069971549723826, 0.03112790933144944, 0.017224119510501623, 0.038523194646196704, 0.021049828867294958, 0.1144125120980399, 0.1394297182559967, 0.08557780685701541, 0.16695640475622245, 0.16513157981847013, 0.11515111103653908, 0.10274089553526469, 0.1325408371963671, 0.15421674693269388, 0.19574140730713094, 0.13197203486093453, 0.2266354188323021, 0.20489726029336452, 0.21027208545378276, 0.09175231946366173, 0.13801407707589014, 0.1365322380193642, 0.10333111922123603, 0.17162463068962097, 0.09578173181840352, 0.12399926196251597, 0.09925667249730655, 0.11943105209086623, 0.24271393035139355, 0.14447013421782426, 0.08479948647852455, 0.06737045278506619, 0.1557015986847026, 0.08278959111443587, 0.07091878381158624, 0.27635116396205767, 0.17601389730615274, 0.14384025016001292, 0.10015274584293365, 0.08238063127334629, 0.16008641411151203, 0.11340552541826453, 0.08971189002373389, 0.18050509345318588, 0.07791825929390532, 0.15391591164682591, 0.15691815769033773, 0.20018691090600832, 0.11123489867895842, 0.23113584305558885, 0.17767486960760184, 0.14284701059971536, 0.11163211986422539, 0.09785002869154726, 0.09602890855499677, 0.08235163747199944, 0.11105835065245628, 0.08779819735458919, 0.21259167098573276, 0.1092130271717906, 0.14842219358044012, 0.11318855706070151, 0.08859308755823544, 0.19822629754032406, 0.06576965296907084, 0.1148027375872646, 0.08869845047593117, 0.11556528881192207, 0.1782217009791306, 0.22675697159554276, 0.11979125919086592, 0.06321966408618859, 0.07464005305830922, 0.14066162572375365, 0.10073721555194684, 0.1643804144114256, 0.07652374090892927, 0.11751967322613512, 0.14426966783191475, 0.18394001413668903, 0.09804896837366478, 0.21373699738511018, 0.16472645370023592, 0.13225828164390155, 0.15835833469671862, 0.10244161409458943, 0.14560665323265962, 0.18405005894601345, 0.21403281151184014, 0.09964427884135928, 0.0797427517494985, 0.13798956839101656, 0.10504161779369627, 0.09209432825446129, 0.10065939437065806, 0.07141819915601186, 0.14055144520742552, 0.07923521434089967, 0.07230771785335881, 0.1241436270730836, 0.12653733577047074, 0.10447362970028605, 0.1504858357033559, 0.14825350977480412, 0.17932550103536674, 0.15417288642908844, 0.08511204684951476, 0.11373144614377192, 0.099755863925176, 0.21203285668577465, 0.1316447774214404, 0.09696549044123717, 0.14679286815226078, 0.07636834281895842, 0.1237573642283678, 0.1267459038645029, 0.052474977249013524, 0.10069196405155317, 0.16191178187727928, 0.09130057798964636, 0.16030559449323586, 0.09365059581718274, 0.16319334453770093, 0.07931212628526346, 0.12433554391775813, 0.07259415462613106, 0.09514052979648113, 0.05780245762850557, 0.1787021444844348, 0.10502474941313267, 0.09495596148605857, 0.15210914931127004, 0.07765522519392626, 0.08219707398010151, 0.0898717800155282, 0.17974775337747165, 0.1373509990849665, 0.09264711716345378, 0.1434649388704981, 0.09872937614896468, 0.1257443047527756, 0.10295795210238014, 0.13985818597887242, 0.11272022540548018, 0.14490690720932825, 0.10703383732054915, 0.15703611421797956, 0.20314864840890678, 0.13998081082744257, 0.13834110381347792, 0.0923782205209136, 0.13093486694352968, 0.07136369922331401, 0.09160992210464818, 0.09800010706697192, 0.14851139379399164, 0.12894126320523874, 0.135785632367645, 0.10866396342005048, 0.07723554449954204, 0.08716209791600704, 0.12144429263259683, 0.181888734921813, 0.06806017684617213, 0.1262860878237656, 0.11383985568370138, 0.18350846586482866, 0.13058897693242344, 0.12501501531473228, 0.0876396983595831, 0.19169448874890804, 0.11566189862787724, 0.15585721390587942, 0.09974648657121829, 0.07686183455267123, 0.055660916292773824, 0.16321516622390064, 0.16871355261121476, 0.2286502064338752, 0.09517200025064604, 0.14232875912317208], [0.05734914195324693, 0.03786169085651636, 0.026468511138643538, 0.06456332627151694, 0.035177888082606454, 0.0609832601621747, 0.028599959265972887, 0.02996204367705754, 0.018431928807071278, 0.031458444095083644, 0.037526155289794715, 0.10007613923932825, 0.03716639941558242, 0.02090361644513905, 0.018242403798337494, 0.018723990635148118, 0.04097848718187638, 0.02620099361852876, 0.041030147445521185, 0.030189254520727054, 0.04199786051841719, 0.009658219109821533, 0.015587469296795982, 0.035835663322359324, 0.009604352759197354, 0.039309833864016194, 0.0388579024001956, 0.04657128493168524, 0.0658270570316485, 0.09212771896272898, 0.0066810716525651515, 0.014549721231950181, 0.0625823297138725, 0.03138210212013551, 0.04949326028249093, 0.03246676070349557, 0.03806909865566662, 0.023263038768033897, 0.02409030866277005, 0.02960891369730234, 0.051536271548164744, 0.032919469089912515, 0.030424913125378743, 0.012740161635779908, 0.033239615482411215, 0.05611481890082359, 0.05430857903723206, 0.04030473244243434, 0.050251920108816454, 0.07782507607979433, 0.017672035743349364, 0.020829893615362898, 0.057812011401568136, 0.06533801648765802, 0.03467150079086423, 0.01472883072814771, 0.02182227822153696, 0.028097398911735842, 0.06948368903249502, 0.07826177443244628, 0.008661989754598056, 0.023673026589676738, 0.031582741532474756, 0.06056252095316138, 0.06591679328786475, 0.06226725197796311, 0.007608766850483204, 0.021580517890730073, 0.023332727707124183, 0.0368084111250937, 0.04833045482103314, 0.05856308859906026, 0.02673663425126246, 0.030529536439904144, 0.07746568322181702, 0.01641419805985476, 0.013483167659225208, 0.04035449959337711, 0.036689518219126124, 0.05194909903886063, 0.029304851977420703, 0.06696806794830731, 0.029530773604554788, 0.010070468997582793, 0.02313340126004602, 0.012729935264880103, 0.0508780315119241, 0.02918915157871587, 0.030028207626725947, 0.026813703955018094, 0.012273165846376546, 0.042399410757103136, 0.013585049692275268, 0.01384650110932333, 0.02079630782827735, 0.014978361981255668, 0.04941818377535258, 0.03015108692592808, 0.05943127415542092, 0.021174219603251134, 0.015062083024531603, 0.03373221833524959, 0.049172791585858376, 0.04379973740183881, 0.022179501463792155, 0.0283818967706923, 0.06106080314410584, 0.05773589334317616, 0.001165018227766268, 0.04045789136684366, 0.07600745718394007, 0.019088804987924438, 0.04656139189111335, 0.08679613005369902, 0.0073549565859138966, 0.0163421376408743, 0.029759636680994715, 0.08000788252268519, 0.04352109021108065, 0.03423108745898519, 0.05712117454303162, 0.014924423536285758, 0.02258604402387781, 0.04776571012501206, 0.01908181607723236, 0.04793957115284034, 0.04939215177936213, 0.008362698135897517, 0.0560134016642613, 0.03587234492546745, 0.04567925565476928, 0.05847679251538856, 0.02084353725825037, 0.007111949447010244, 0.032251346191125255, 0.02173380404045539, 0.00428255765499281, 0.1016957616167409, 0.017873798131144474, 0.029815140845520154, 0.035506600979715586, 0.024381481609972458, 0.07129089241581303, 0.015255843788119299, 0.043955902236380746, 0.04495480417140892, 0.08069456674690757, 0.024540511558630636, 0.03588059591129422, 0.026537005856101, 0.06339051241853408, 0.03290700100894485, 0.015622459651370133, 0.021027002949267626, 0.02388996271682637, 0.03358591600720372, 0.03550200729763933, 0.01190739730373025, 0.018655032817540423, 0.011222811449053032, 0.05524549001295652, 0.028948315751871893, 0.01569537672081164, 0.020641567917274575, 0.021424682145672183, 0.0453878214715847, 0.05235328199341893, 0.031122759250657897, 0.07162773755512067, 0.018380797800741026, 0.017661040083372166, 0.04622210741841367, 0.04830624129889267, 0.08159484022430011, 0.006735538082596446, 0.06214092911354133, 0.02981280329238091, 0.049930593065385304, 0.024705161473580768, 0.040843143194381676, 0.025838577887043357, 0.02699513064830431, 0.05383561298783336, 0.017469330191878334, 0.05151250585913658, 0.04601438070780464, 0.018972929866452302, 0.02912224463320204, 0.060251779056021144, 0.02951503498479724, 0.014689046523666807, 0.03756754592593227, 0.016991563507222703, 0.03874407475814223, 0.05152759647795132, 0.01597120799124241, 0.024609094485640526, 0.07877343733395849, 0.044411650459681234, 0.028453039471060038, 0.021689695871568153, 0.07242110784032516, 0.03497393402670111, 0.03402726911008358, 0.05220397036256535, 0.041524755369339666, 0.011030277137511542, 0.04867785117988076, 0.05952531910900559, 0.013923854949618024, 0.02663682005368173, 0.05140534482364144, 0.04174416306029473, 0.05799518871520247, 0.06628063055021421, 0.024352109525352716, 0.026606533643124358, 0.049363103695213795, 0.03915759774723223, 0.014796984481758304, 0.049920493071632724, 0.0553172383058284, 0.0349988396545606, 0.021030762033270936, 0.019755650544539094, 0.033776713269097466, 0.025617500999942422, 0.06938724206494433, 0.021162279083260467, 0.0375503586339099, 0.027697268507576416, 0.027929476761658276, 0.03105143504217267, 0.04733272335891213, 0.05512373708188534, 0.07705681837563004, 0.02013167768849858, 0.07220929634890386, 0.04208075374897037, 0.058565551681177955, 0.03236825777483838, 0.03658515953325799, 0.016954932794240967, 0.021714806756270782, 0.0569698748045734, 0.06130783738834517, 0.003512350858987442, 0.06927521593336548, 0.015421167149075439, 0.04173761519736477, 0.10586266552231141, 0.003959456666572285, 0.03582254384777375, 0.011669355344825556, 0.022962839608745914, 0.06435492781123944, 0.06177274922707251, 0.043271430036319156, 0.05411388019898108, 0.005832338847020375, 0.01731958769128791, 0.013651190741386796, 0.04413267757211413, 0.028459787501820495, 0.04823798067601664, 0.04952390970928328, 0.03045607145343508, 0.018625586094068627, 0.014697674096428921, 0.05116098061470049, 0.08859708412949528, 0.025393703187416707, 0.026384347351267934, 0.013126718795060046, 0.017377203796058893, 0.04434599880395191, 0.00862399857890393, 0.040416985883244445, 0.04843605861866048, 0.03616991985057082, 0.047845431204353056, 0.033255062332110744, 0.024115602751927714, 0.046620607642190795, 0.04169792089877384, 0.04975573459107961, 0.015885407238134315, 0.030486965152834142, 0.027860825981146524, 0.016390656287382756, 0.02927625851173486, 0.010091579070181718, 0.020533716472397958, 0.07526051226471152, 0.02713343474481787, 0.05989795697054692, 0.052034302681152306, 0.0345134258802448, 0.033507881087384055, 0.008914019712912185, 0.04280452669731208, 0.030524437249239002, 0.04414291666554553, 0.035627641449017186, 0.09632624938551869, 0.012120022189005144, 0.007989969520297433, 0.06764557837907757, 0.028939046963517154, 0.026401059668777243, 0.04756476876458951, 0.0437734882746424, 0.029905399573700767, 0.028360623001520122, 0.06461305610303368, 0.04719768471217581, 0.057627985919160504, 0.026100845242451345, 0.03542077308520675, 0.06324821683977332, 0.011404082927453731, 0.04447419103235006, 0.07438296292509351, 0.00827261497865298, 0.027173329211239303, 0.042378026725990434, 0.07603199301021439, 0.022815980881984745, 0.005213510245084763, 0.025307174705501114, 0.038912280196590085, 0.04487111705488392, 0.022798959831041948, 0.03371440000565989, 0.02165358423787568, 0.0282706441690347, 0.05871408299676009, 0.028200785596189753, 0.027487217814528515, 0.006017199775669724, 0.0661021690549595, 0.006552100381148713, 0.01997851367507662, 0.06365187732236725, 0.030566126440784762, 0.040249645576945374, 0.02676693083984511, 0.08064337806510073, 0.012400509057832616, 0.02259581153547125, 0.031036782078444958, 0.028714499369795834, 0.18189376965165138, 0.10100508082125868, 0.06628464069217443, 0.1434828657656908, 0.14822920465043612, 0.10492212099156209, 0.10882386698254518, 0.09302496617393834, 0.1975021513977221, 0.09724046675754444, 0.12875440823180334, 0.20220692322722503, 0.14710057021251746, 0.09812193802957024, 0.08507922611066274, 0.13175730566893304, 0.09626274529312338, 0.14167127226080212, 0.13556793119226182, 0.09372696493353162, 0.1495913772710732, 0.1793035300714629, 0.11140757227050406, 0.10536763351410627, 0.08362316459949527, 0.10721343196928501, 0.1323087510785886, 0.2008385487965175, 0.12022166752389499, 0.1683163789233991, 0.08322138365890298, 0.16784486493894032, 0.11007325351238251, 0.0998361414032323, 0.15196867899170943, 0.21500086385224546, 0.11119387445173093, 0.0943146034010819, 0.14788397960364819, 0.12730718803192886, 0.12094626149960927, 0.17864825523325376, 0.12158055603504181, 0.11080978291907481, 0.11709269828030042, 0.1991090580288853, 0.09673596240047898, 0.23066379981381552, 0.07569380437156983, 0.15853491664997169, 0.11033615190535784, 0.09555981015520436, 0.18621079943009786, 0.09826897656811134, 0.09127208630421332, 0.09603584318288735, 0.1568009475512164, 0.08819838373788766, 0.207842332976205, 0.17678977495857648, 0.12132012072418417, 0.15793566166290215, 0.07069706570889268, 0.20702047779091767, 0.1124594643978136, 0.14547565526195935, 0.06821685736732823, 0.11425168572791985, 0.18194768604423317, 0.17222649125116213, 0.14665481341736658, 0.24190671795180865, 0.12933294075940335, 0.11168132722377777, 0.17742329596408776, 0.08170996726091419, 0.12896791606077126, 0.08323583645480019, 0.11698679253458977, 0.23269571363925934, 0.1440686314765896, 0.12740896828472614, 0.12287450874490397, 0.08467312290200166, 0.11127573970173087, 0.10491392428853683, 0.13379881397954055, 0.0948587002764855, 0.13154560274311475, 0.17764251705791267, 0.07775619799005133, 0.09909366124442645, 0.12957091656114372, 0.12608255445957184, 0.17742885995124066, 0.07398943975567818, 0.14607691871268408, 0.11823174144540514, 0.0794798940686243, 0.15702001936733723, 0.0676216125222189, 0.12234569926347051, 0.15767787263861724, 0.10543942251907927, 0.08749803381838969, 0.13289879156010492, 0.11907615113471236, 0.16614964018974984, 0.17457682799015725, 0.11853135536823954, 0.12360780153955732, 0.07892584308449711, 0.19684071546154364, 0.12982521791543278, 0.13981891237199306, 0.057586737775376866, 0.13045708329549857, 0.21353991010359355, 0.13886566566569464, 0.1370922601116555, 0.20900963033948625, 0.1815537286124059, 0.07472356714840446, 0.1788571761654956, 0.0920492396024721, 0.19270680871392998, 0.1643311527690717, 0.09300808422267437, 0.17576939399753297, 0.19103622835661682, 0.0905124731361866, 0.12338347786239215, 0.1532413392726864, 0.12082907850188868, 0.1202801979546036, 0.08048749821526663, 0.12159784510731697, 0.15461940318346024, 0.08760569696979863, 0.10963836684823036, 0.11399411383484091, 0.14084489803229058, 0.12288821515228067, 0.0924772187801344, 0.11632152966090611, 0.14260072952934674, 0.21758206534598554, 0.1557238410626139, 0.13678207461323055, 0.17359975113400392, 0.16346208511718682, 0.1912527217396668, 0.10472711681255273, 0.09608410059341363, 0.11425795539149217, 0.09431978740862437, 0.11150532202529055, 0.16400502169770853, 0.07284215917544705, 0.062395610447440825, 0.2275435836719615, 0.1130742985489113, 0.08896685178790774, 0.08984473360968487, 0.1351488951061453, 0.05842289647885731, 0.07979854089873177, 0.09061002611581769, 0.09665126765945128, 0.1072859809334789, 0.057615243031510284, 0.12711995307888302, 0.08568362439317362, 0.16931875156504766, 0.12234727346471377, 0.1933771606002535], [0.03692800631480558, 0.014414346710379635, 0.018615301199523464, 0.026455697004816363, 0.03515565588272043, 0.014747517582561289, 0.01513752933325512, 0.006472928915172815, 0.013527174047859651, 0.024072665055947642, 0.03401326753997377, 0.014318542654759117, 0.04344002902507782, 0.011397099953943064, 0.06203764929835286, 0.06983814894088677, 0.03128491894208959, 0.03783715163756694, 0.026870678844196454, 0.009235258546790906, 0.041287542919495275, 0.04980657043467675, 0.038626464283359904, 0.046151180152914355, 0.04113544590239014, 0.015241234929167798, 0.05654205508264048, 0.033847477686192305, 0.013519859440358621, 0.011429695079901388, 0.010356282366306653, 0.04109107989019581, 0.03364086038033877, 0.018560706271923015, 0.03308592051533716, 0.023911528256056563, 0.007886479359253176, 0.01899149119188743, 0.024293060015354837, 0.05678078066557646, 0.027389603766745756, 0.01945152266749314, 0.03756771895236202, 0.0144337680789509, 0.02691389134685908, 0.06612983971301999, 0.03236208310616868, 0.05476725853181311, 0.04889570502564311, 0.026831615583172867, 0.019497413687141876, 0.027351378496470194, 0.014868698847879256, 0.04577808767291052, 0.033310010097920895, 0.067649778510843, 0.0247343876731715, 0.03152991758127298, 0.008875683332527322, 0.010199221017371331, 0.017773712519556284, 0.034447692800313234, 0.027356023068672845, 0.029373879344867806, 0.03581733948418072, 0.009496271460583168, 0.009638082734974367, 0.056520684622228146, 0.013364050836701478, 0.058601561534617624, 0.05978203604796103, 0.04991200120587434, 0.027040592494553754, 0.0149652933967965, 0.05037590202742389, 0.04284475025321756, 0.008091865124047866, 0.03971598457012858, 0.03919431666976639, 0.05812909081578255, 0.06317262125334569, 0.0558484871206539, 0.003587344245586012, 0.026186522162918533, 0.026434304492015923, 0.04024275844650609, 0.09554526236440454, 0.0347087659340884, 0.05725780435438667, 0.013366491018262292, 0.03405368108568447, 0.0560745512401419, 0.032648886287850995, 0.06797751092485019, 0.08514934591948986, 0.03255730441638401, 0.007430018674183104, 0.0676765331466283, 0.07571677278195109, 0.058143584323780875, 0.03545550050746117, 0.03868682675861886, 0.022294969464253103, 0.03731928014063409, 0.02789984004838126, 0.048148234241775105, 0.057238941080868244, 0.03393020128299083, 0.05583483499607869, 0.0317417121093188, 0.03409732785075903, 0.015461841930768319, 0.024571566410096626, 0.04181538888120225, 0.016545615025929043, 0.037865996161209683, 0.04222459299489856, 0.034508957727147, 0.036128217088324685, 0.022285904236403958, 0.01628242995190833, 0.04563601940338101, 0.03665072976478508, 0.023734359370012368, 0.06947193002062184, 0.08028881637645618, 0.07320196593978576, 0.011867969330134136, 0.05571115163287946, 0.06171075826776879, 0.026264687700729285, 0.03242173311965806, 0.053981671043272526, 0.027322857973298857, 0.05888293643615075, 0.023811423984755362, 0.029545701374965053, 0.040138372619237216, 0.03611497547743576, 0.01878920124311532, 0.08349268231540918, 0.006655088002194783, 0.043656709005257914, 0.03260168739195381, 0.030058578854160647, 0.07849540082471711, 0.01587073052568095, 0.027400521395195807, 0.031025341978030543, 0.039396822053406916, 0.02552843649339463, 0.04163856944069266, 0.020945573658017174, 0.04068591645253556, 0.037940475557531626, 0.03808224866432803, 0.03543364489451051, 0.045698451410446844, 0.04309126541816762, 0.02951467196856226, 0.05158856963472707, 0.0273310682470245, 0.02596051402256957, 0.026237994133095657, 0.046228085311927965, 0.04639900489045041, 0.07948176003992558, 0.014818064868450165, 0.02179518262190478, 0.02489480692228036, 0.07598516052322728, 0.07760390759046588, 0.015746629863445247, 0.06648784157420908, 0.07751525020492928, 0.024650252723534192, 0.033979965041258504, 0.03613630861842206, 0.06506575431142535, 0.0305106324542846, 0.007060519037103015, 0.013596400734968483, 0.008445962016204638, 0.07929106455828462, 0.005186703446919897, 0.03390833888468998, 0.03506005369126797, 0.02642212139575609, 0.04067340426679168, 0.06586297867553574, 0.016830209576125656, 0.03513822092541626, 0.053601548940475495, 0.023525932071996585, 0.011810396481970591, 0.02229000598059169, 0.07185655991945948, 0.08108557933675391, 0.03286422955404435, 0.01850196549535862, 0.032532483605401855, 0.06789071951061487, 0.014411456151200193, 0.023552976781502366, 0.07726027031562158, 0.03366094162421567, 0.01743492846643286, 0.052379310596734285, 0.01745344907976687, 0.03461584395595959, 0.09732793670679842, 0.06919943714248282, 0.04468771582469344, 0.017288388651130453, 0.01007876154367945, 0.04502766526171139, 0.04559094771476729, 0.023821306847301976, 0.06636377144604921, 0.02297802352612572, 0.013070017016226692, 0.036922930872866085, 0.009089869696513882, 0.05934084579348564, 0.039171321117984395, 0.032375602916415246, 0.04374021631000297, 0.03788240992331079, 0.036963388523353, 0.029764610342681408, 0.043826108665338585, 0.02772013344136732, 0.0033751095179468393, 0.007563697706375803, 0.0375708436061229, 0.037542898141379864, 0.010070132274579788, 0.08380119861768824, 0.028220039027343904, 0.031185011445943798, 0.03479537075119359, 0.037541588568793874, 0.005096149556006172, 0.018315790753279413, 0.01956076341282044, 0.02262731082737446, 0.01580806103135858, 0.061336614058486054, 0.028717746159860065, 0.012807637702540627, 0.02313254969859762, 0.05242670626778688, 0.019977300793730786, 0.027605321923536912, 0.022561699883746247, 0.021872206524546658, 0.012434032928597714, 0.054159406506057294, 0.05164721880906394, 0.04416767301570092, 0.041803327921245775, 0.011626578800912415, 0.04814801032521895, 0.03028762513505561, 0.03281047261719193, 0.02790447274622108, 0.02604145646494414, 0.05019152709948165, 0.030081940814852715, 0.02864641516602465, 0.04695985818813954, 0.08725338123206582, 0.025076170851077353, 0.010604323386879904, 0.0951125266562615, 0.08821862443749394, 0.014472230836482984, 0.04975099163129926, 0.03393370930903724, 0.02268485738230603, 0.049211288270141394, 0.03190445873354163, 0.09191814663686923, 0.036602248437702656, 0.03736321867576667, 0.02351128589361906, 0.05873772994215999, 0.059915585310331414, 0.004002053398705486, 0.04727532608168466, 0.02350936733585383, 0.049628658552787135, 0.05380996097145336, 0.05995237547904253, 0.04350512767476695, 0.07321646623313427, 0.03271500952541828, 0.05287267680146864, 0.06833248651985611, 0.055724898752357276, 0.05371642831180777, 0.05539673546861325, 0.04216692769633872, 0.024058115568810275, 0.01409393993006753, 0.08585133789373295, 0.04140643582546285, 0.05028070695698261, 0.003966306901669928, 0.0309798801317811, 0.02466685138642788, 0.05531493467944009, 0.028398283391392658, 0.03152774966188839, 0.041753452204700024, 0.02254786285837846, 0.055258066659527164, 0.0521552956530026, 0.01190520987646388, 0.03890502665724073, 0.03348192373024566, 0.04380863978128348, 0.024908640554973056, 0.04267637857369014, 0.05735334208501237, 0.04257767886987754, 0.04941910319030285, 0.014994017480473434, 0.040706350534622154, 0.038900660284395726, 0.026171234768948386, 0.010954926671859409, 0.018306016456335783, 0.07945120560803584, 0.04604832102943744, 0.02402375285912837, 0.009812791931575962, 0.021172755663948398, 0.01290000497829169, 0.02546573816133397, 0.01465364226273128, 0.035685462810631306, 0.05045877829460161, 0.03853336249345115, 0.019215328020176718, 0.03119251604325005, 0.06631777355713503, 0.09918283431657723, 0.055268770549446344, 0.06845555920153856, 0.027662832855380008, 0.01362040136674685, 0.10984650067985058, 0.1332151788686003, 0.08800462806331259, 0.17881273212177412, 0.09753781437341656, 0.10178215948066541, 0.16842822863587312, 0.1239989905485085, 0.09197974404586212, 0.1775358784943819, 0.08764519449323416, 0.07108722334461552, 0.13975842776043074, 0.13681000311459812, 0.14516323059797287, 0.12627837966595376, 0.09702518795217786, 0.14780661304082188, 0.14990239058222088, 0.12139151617884636, 0.14448681260858262, 0.28115394338965416, 0.097077333368361, 0.15798937449497835, 0.1394890493580273, 0.0911024593349014, 0.13113949953445367, 0.11891907027789525, 0.1521366842623268, 0.0755679632670113, 0.09301401461873736, 0.17978657915123872, 0.08869524779064314, 0.06821883868958269, 0.14238790023539746, 0.07118795865348407, 0.06382554836039032, 0.08651387305664164, 0.10524297984583036, 0.1538074274680444, 0.13318349128322943, 0.13101398412670406, 0.15737133765859262, 0.11230681437466826, 0.07982024044862815, 0.19867894825126442, 0.11522087800715651, 0.11973412654229573, 0.15761989860662393, 0.13419496986482823, 0.08507587414767061, 0.1082135858014226, 0.08079606880034719, 0.13310180923768453, 0.09452693736446754, 0.15966596667255673, 0.07616457196750812, 0.07441753428429365, 0.1471147108823061, 0.0989999080608998, 0.09174416347273759, 0.12462606547134263, 0.06976268906146288, 0.13430471611874445, 0.15211100849722112, 0.0891931839287281, 0.05337903016645994, 0.09309830223875386, 0.10168567858636379, 0.13347451495272772, 0.13287288509309292, 0.18555605384920323, 0.13329555812690938, 0.062168952609811506, 0.10955198255500623, 0.12013940193823405, 0.11158280393907002, 0.14320792337613447, 0.18319471127220563, 0.09997417578207594, 0.10791785988424506, 0.15951446337359293, 0.16644001246563025, 0.1791501540158476, 0.13570411317050457, 0.12416695510702473, 0.14693913316088064, 0.1434174007070916, 0.1253965962678194, 0.12717275667403424, 0.1517585909792355, 0.12674707094473497, 0.13053244139466966, 0.10833595280668565, 0.1911182768110718, 0.13157255415405544, 0.12732478923031262, 0.15557459049991199, 0.2053160656775747, 0.15546219795942307, 0.13013057224452496, 0.12075468392244407, 0.17151881993881293, 0.11206052651894943, 0.11770218557545117, 0.10728150260235582, 0.21154726988502912, 0.15829813506986412, 0.14375685820622103, 0.09739424993417092, 0.19689768526170934, 0.10756507595734936, 0.08579847323043005, 0.27636487036943436, 0.09609842446765729, 0.14722974970936775, 0.13604606767850264, 0.10924773423799447, 0.19411305896937847, 0.1362235452979803, 0.0870319413287299, 0.1277887171932629, 0.12987439813358442, 0.1360907017120293, 0.1340087798557111, 0.16011047496327332, 0.16759905884308474, 0.17790487940822328, 0.06069554095821721, 0.18539254048040935, 0.18922061792441777, 0.12232881731220654, 0.1461772604712418, 0.09812516785625901, 0.23508516113672936, 0.20359935850969382, 0.11032019954706941, 0.06320219859480858, 0.11315828082816941, 0.12554879167250224, 0.11574771973703589, 0.1171307098120451, 0.204548411869577, 0.09794174627001796, 0.06563384418508836, 0.11818268336355686, 0.08595248710896287, 0.06725079313452755, 0.07910667266696692, 0.1470674712743078, 0.11891174209969384, 0.13541085033544473, 0.17113524409277098, 0.1320186366460153, 0.1386167790208544, 0.14695875639361994, 0.1480845816965614, 0.16311949278627122, 0.16334833550666059, 0.10506560400660549, 0.08483510956700359, 0.11337914397673947, 0.0885377326714141, 0.09118126439196722, 0.15132918687803404, 0.10135296572531972, 0.1646332229886736, 0.11360667712454285, 0.08896067711923804, 0.13709675201347896, 0.20686369548950875, 0.1656496820173093, 0.09843694791197777, 0.1321882161178759, 0.14790908539933817, 0.12808751687407494], [0.01890791264096541, 0.09178866179926054, 0.004950813292193094, 0.013303145533427596, 0.0710499310599906, 0.004040005982720426, 0.03757342203919377, 0.02915651404431888, 0.09683106586869274, 0.030234048009983132, 0.012703227278377329, 0.016989271755197217, 0.035570895565407615, 0.04386598616838455, 0.018056054333490983, 0.016869047224255543, 0.0384526609310082, 0.03336383828095027, 0.014263867999293973, 0.034220115547733646, 0.0033445523295085877, 0.010321555792221, 0.025163969889815365, 0.027292620756530335, 0.020376045290114622, 0.049408881060246906, 0.021584361791610718, 0.024059850922120467, 0.02255261599618409, 0.0357268330907183, 0.05781819964093821, 0.03286116596843515, 0.03692965515490089, 0.03366616295118417, 0.013720064590285932, 0.04015503743929522, 0.022367440396919847, 0.030989613716623614, 0.04009434248187712, 0.03834403765254787, 0.01666360378398427, 0.045716978809131045, 0.01892274372013552, 0.02534157643094659, 0.022076560916113, 0.019460835560624088, 0.054439424337553124, 0.043664305204791684, 0.0372683221607336, 0.023849286238795946, 0.011773947277106345, 0.04219436086714268, 0.021950589193563377, 0.04900942749476858, 0.04405051376670599, 0.016186966860134686, 0.05120358582852142, 0.026745256735011935, 0.05480808259121009, 0.02021503571553954, 0.016841003371934806, 0.06523630408836262, 0.02021632662841252, 0.03549669436844332, 0.06709525933755295, 0.04186717128115041, 0.047200354747474194, 0.04582721360826066, 0.020332198357209563, 0.006888110498299024, 0.021535768506250212, 0.025705730908417275, 0.059809123165905476, 0.041106750656451495, 0.015257463790476322, 0.025485495404739465, 0.029173134759600674, 0.028223029670438597, 0.044132161885499954, 0.015985426692558185, 0.03140121305893574, 0.016082691294806342, 0.02739667919065271, 0.037973133447979174, 0.04508913714172585, 0.07342699529337031, 0.03466500381806067, 0.050759026647678444, 0.019690721528604627, 0.015926568868703077, 0.035258962839309654, 0.02461027683291052, 0.023267903864117603, 0.012899476569145918, 0.05514381493308714, 0.030243615353746072, 0.02488309540785849, 0.021557101647236517, 0.011148690828122199, 0.041402293369174004, 0.040987922211310694, 0.027370268911389366, 0.01708073657937348, 0.042404740649674616, 0.042317114637366364, 0.04615657450631261, 0.052136391667383056, 0.047156151583684344, 0.00462482004825558, 0.01750759787059256, 0.008017892932652362, 0.04152040256719504, 0.021521673637575338, 0.033878215322537084, 0.006543489347677678, 0.02311843617020973, 0.09102186973073653, 0.0350264017470181, 0.04660395300015807, 0.016614923985408883, 0.025621173570730855, 0.02963200763666204, 0.029392491560429335, 0.022096048441848586, 0.014189028979412146, 0.05231112461271031, 0.027210082060524395, 0.005721847476836826, 0.011624749300868382, 0.04481136526114174, 0.03532989689015916, 0.029120890955839838, 0.018413604968892675, 0.04206924918772919, 0.03569128464109131, 0.06502663676760026, 0.037661339821560044, 0.021677010659394518, 0.055341936980507205, 0.08265329378523997, 0.010009611191760217, 0.07578531838953495, 0.037996916100382805, 0.054231432998286824, 0.014491435073848282, 0.04559995526713984, 0.05020578990557364, 0.08756998567176716, 0.08745396975427866, 0.058104487136006355, 0.021631815138139894, 0.040637041575142314, 0.02283847771052803, 0.043982012263898335, 0.02450295803802354, 0.024660859922213212, 0.07022343469517571, 0.012947078345210424, 0.05063035944476724, 0.0557238809498293, 0.01489443059212395, 0.04062629018777183, 0.006137620233598032, 0.02205343813901501, 0.04553088040224143, 0.03846768369632108, 0.02374241697335882, 0.010846806357481649, 0.043575535860977004, 0.047781584451773336, 0.024760306014546325, 0.03262086618425591, 0.012210575231750096, 0.04554558086342045, 0.044953738871429644, 0.07886924647859164, 0.013430867028156561, 0.06615278098200049, 0.010161133150437048, 0.007314119803985315, 0.01437580761765795, 0.030023841253880943, 0.05198187567293644, 0.0249813625455967, 0.07091236487030983, 0.01675855288548129, 0.011212794575840235, 0.011414742712596697, 0.070143469343228, 0.040746217859642844, 0.05543685045891574, 0.039324612356722355, 0.0227602290521775, 0.012080679880455136, 0.020891357013689618, 0.027931303717195988, 0.07084945788873093, 0.03760310455358454, 0.011986264277116528, 0.01132499288568007, 0.04016537831297942, 0.018353912546964626, 0.01631723201301481, 0.028564149580363716, 0.02229284734598228, 0.12841960548290185, 0.03159822570160031, 0.04769600082987121, 0.01828159937368972, 0.023180952994152904, 0.03778748965955206, 0.07471952307969332, 0.05347412684932351, 0.02221271405661745, 0.03515050919460399, 0.007458007395533579, 0.028183530450665524, 0.06315422616899014, 0.047146180511585305, 0.060334709606000354, 0.010295450005547276, 0.017229951518986906, 0.017118712488029684, 0.0736528185329267, 0.04380069413621511, 0.01202392636332661, 0.05957496751632009, 0.026186296550024833, 0.04764353310955422, 0.03947411737005625, 0.04722939943894744, 0.018076980353466103, 0.05580538996894445, 0.03414609755522438, 0.0029023432122942594, 0.03831606165372899, 0.017001524401296462, 0.026352150864633064, 0.036035308680896244, 0.038110750527786355, 0.11372791097632476, 0.03840191668963858, 0.07010538995798145, 0.032208191363939216, 0.016454238411305205, 0.08015529425548655, 0.0461335348497544, 0.014611016692859786, 0.005501652261175747, 0.012255469653090196, 0.03177984917004194, 0.015696974670780555, 0.0721807096685682, 0.025178599104817425, 0.018400597452585186, 0.05934856752199786, 0.016834280786237547, 0.03682592072124992, 0.009191907792618232, 0.07285156367080552, 0.018110791753445352, 0.06921551163707461, 0.021590526282255138, 0.012886032245920172, 0.05344613727980426, 0.050517403720212836, 0.07460313396794455, 0.0444720129349402, 0.05506824988073536, 0.004819839070218482, 0.016031790990382433, 0.05230577436408826, 0.03967501801837768, 0.03260640660300851, 0.029849718990070478, 0.0731424516333001, 0.02463800516644759, 0.010906383428456528, 0.03466791473329067, 0.06446535938552447, 0.03570080448740295, 0.01525704309876476, 0.018180221152891005, 0.019487639390198246, 0.016731340238558393, 0.06654123549482652, 0.03492700315213629, 0.1246226185134479, 0.004325106465590319, 0.003303110591202442, 0.05064547720498272, 0.05643428675830364, 0.036615642718970776, 0.01859747608458357, 0.009186814539134502, 0.056371301745197604, 0.04075101849489978, 0.020626372125531946, 0.048431654926389456, 0.02607260800765029, 0.02507364161179534, 0.0384799210753824, 0.07740407902747393, 0.04609825781413487, 0.010294862224587371, 0.08427737413772515, 0.03643438905211432, 0.016246342066941515, 0.03253021051308938, 0.033111033096377335, 0.05293515630598579, 0.07743635693831102, 0.04345020705035754, 0.0027205498980557813, 0.04032841670726027, 0.054260280914604664, 0.008567842172591813, 0.03648491616227797, 0.05984398629516363, 0.08371623924800328, 0.009499798146342593, 0.05869808992637055, 0.01955129106396011, 0.06738379278353282, 0.020894542735602175, 0.043778607821358104, 0.014877127949148417, 0.03033070871606469, 0.03417567489668727, 0.028631097237978662, 0.02999003663925188, 0.02992985736844795, 0.00781568355991372, 0.023639725787299018, 0.04931367241910525, 0.045205285373542986, 0.016391667304560542, 0.03161743502797825, 0.009494229070177036, 0.07388782235128538, 0.02243612171150744, 0.029057671848152365, 0.05366024221958859, 0.061337455441909175, 0.08593845500477723, 0.07237398358328001, 0.026435001686747586, 0.05026525332193289, 0.039460746837513785, 0.03786051020558391, 0.01641853729129902, 0.043558586056211164, 0.09356178915394203, 0.20322248658963613, 0.0693512661382556, 0.04399472461747272, 0.16070150610591682, 0.14434156540249074, 0.11767433849828583, 0.13022281229496002, 0.18546457375798905, 0.09055167210421391, 0.11273214726575784, 0.11107002824012722, 0.12194027458982808, 0.12381122633814812, 0.10009849696819272, 0.11364443081298045, 0.07900059728750161, 0.0848271707072854, 0.0872416900736945, 0.09164329245686531, 0.13796269840427808, 0.07934310140886477, 0.11732943914830685, 0.12350200435944966, 0.07542996960026876, 0.12560266735298292, 0.0810857353998082, 0.08974553178995848, 0.08242528566292354, 0.17857932964605944, 0.11911602185240813, 0.08961308853966848, 0.11639961547085217, 0.16148476621934346, 0.09140792901494674, 0.15609261127454893, 0.1181178018450737, 0.2118676741208349, 0.15910166980964796, 0.1362201390521867, 0.08040454052388668, 0.14344944113067218, 0.1195255448775632, 0.14878569836063044, 0.1357733780252082, 0.10702664484935147, 0.14883144519158772, 0.09876009342925889, 0.1668096376316888, 0.11045351132218327, 0.18373557153557027, 0.1292573112462248, 0.13280090609831469, 0.14964509010314941, 0.11531478725373745, 0.11836196588618414, 0.15171470333422932, 0.11542639269360475, 0.11571628999497209, 0.1117859844650541, 0.09918324143758842, 0.14214075064020498, 0.09255581349134445, 0.09763269392507416, 0.1629601591931922, 0.13183134741016797, 0.14308603134538445, 0.08815991758768048, 0.10997523912893874, 0.10385607462376356, 0.15430662568126405, 0.0941201149086867, 0.19647518864699773, 0.07011900137045554, 0.1455169373324939, 0.08999645403985466, 0.09584216893251453, 0.12145072514457361, 0.13098197084452423, 0.15510641490774496, 0.0917529369305287, 0.16711980955941336, 0.09453499157513891, 0.1115160903760365, 0.1423465231699603, 0.24035056574004038, 0.06444461657000439, 0.12853041025144712, 0.1498680974223784, 0.10811622959694692, 0.21873106940516404, 0.15207880522523606, 0.2666607882295336, 0.10787539716277804, 0.09119427190827471, 0.11537833884358406, 0.18105799092778138, 0.08701680321246386, 0.06769560676600252, 0.16731214709579945, 0.09009341669401952, 0.13460206373461656, 0.10476221742906741, 0.17417088762990066, 0.07902362676603453, 0.135575177946261, 0.19390782926763805, 0.10900340056312935, 0.0818365208272423, 0.17592393713338034, 0.12487872477088656, 0.17437876361821378, 0.08531892539135047, 0.16512322026704038, 0.0659628047474793, 0.1082539993471333, 0.11028729059866496, 0.08813910691865853, 0.1306225372744458, 0.11720446656857218, 0.15009419886129244, 0.16705878211983613, 0.21407892475170748, 0.1613972894847393, 0.08454295274402414, 0.1079632742330432, 0.1188366554145302, 0.11990367887275559, 0.06126135773956776, 0.10747430832790476, 0.11214075649955443, 0.1237173578036683, 0.1254386654389756, 0.11685141122766904, 0.11603811915431704, 0.15557311129357132, 0.1165547285761152, 0.08814110181161336, 0.07927047102046864, 0.1586208598954337, 0.1408767756074667, 0.16787332269762242, 0.13532604702881404, 0.14454748720995017, 0.06316494023693459, 0.21590146981179714, 0.0836126608774066, 0.10872423768575702, 0.13776806741952896, 0.12185362566794668, 0.12947646448654787, 0.15732951276004314, 0.17489408382347651, 0.0752023821696639, 0.18528024293482304, 0.14155589416623116, 0.10348778617169176, 0.07490472242768322, 0.1502753541405712, 0.21144384757748672, 0.1178150259490524, 0.16528233672891343, 0.037357770039566925, 0.10298833011516503, 0.15018083421247347, 0.11971537183438029, 0.16596112959086895, 0.11649782662945134, 0.200027129479817, 0.1658170630357095, 0.18134296206491335, 0.1029826711331095, 0.160560262256435, 0.12972236557730607, 0.10655656257378203, 0.09839512979877846], [0.01683624175244144, 0.055068382195064, 0.06745369546115398, 0.023290068210501755, 0.04252423066645861, 0.025303081443001117, 0.05480773653835058, 0.0899302629487855, 0.05488900128485901, 0.022428540779011588, 0.037299758688147576, 0.03253554379833596, 0.009734483053242522, 0.024217391486412713, 0.02672663264508758, 0.033947507318641455, 0.042604128164904456, 0.04355593298428825, 0.028761274181306362, 0.03354172980678933, 0.06678731300468956, 0.0403578210222934, 0.008161509958361941, 0.04607651415946228, 0.014670978832457746, 0.04124166716688445, 0.053660065800483735, 0.047407392745039294, 0.05083862219804099, 0.01584554330578872, 0.016667607140594294, 0.011021858214267662, 0.03911357778789742, 0.05214519905192511, 0.05467897094786167, 0.025075777300766537, 0.05699014264558043, 0.023046759123514806, 0.025446306614737426, 0.00556015724682116, 0.060869035577135425, 0.022558846643992832, 0.042992311263723035, 0.023137682816013694, 0.050769275919135125, 0.05227665164108787, 0.009512072844829942, 0.013058643072976597, 0.0681794225903494, 0.06509164042238678, 0.05954929853656462, 0.01822894166356751, 0.05351250818265336, 0.027017605424459492, 0.029628034814127853, 0.016919932261641537, 0.059632371578897746, 0.033121716630245955, 0.043581825880599875, 0.060570425886128626, 0.033449459222278426, 0.015447764025468911, 0.031793833776776276, 0.02716878641928945, 0.0232443620916456, 0.025963197628568326, 0.023533433276627744, 0.012192256482584136, 0.054002698843500445, 0.038230576419404576, 0.012434950647210436, 0.0299431871888893, 0.04094971729708569, 0.030746267310210636, 0.023428170442847267, 0.0477908905595541, 0.031482352276465723, 0.009953584555270416, 0.03570711825575147, 0.04238672215225441, 0.027165276696905494, 0.062181444439504824, 0.0051630437789884, 0.0309967994024711, 0.013364939717575908, 0.04399707913398743, 0.03139501464154039, 0.05634671842147197, 0.03244324267974921, 0.030489909994815077, 0.045828211054738076, 0.05209642256210957, 0.05999304686806031, 0.00898063404019922, 0.0036967440225583103, 0.04735114558466843, 0.043207430613360236, 0.11597223340400628, 0.051242520167891464, 0.0450145084676998, 0.02748541291137891, 0.020575069789109484, 0.00522897405815976, 0.0482679719238409, 0.025991672350625907, 0.05416532333141991, 0.02347167980458055, 0.028962663374841213, 0.06437188440135547, 0.020742096272962432, 0.024195620690339377, 0.03359846551237362, 0.006803436537406274, 0.010098359331355562, 0.03590831406680601, 0.01169592168714319, 0.028968464849250655, 0.031128984809454, 0.05695134401321411, 0.025040456160370792, 0.06533501057752542, 0.03901405366403716, 0.04748508839734963, 0.05131676207695689, 0.03986263634370906, 0.03146901906334928, 0.019183742215058634, 0.06779414362141065, 0.03760827499042664, 0.03423851741743939, 0.06592623849532434, 0.023778333528233424, 0.03352450519534094, 0.036706766579300165, 0.08386828537498202, 0.03226458440933909, 0.022714288838739907, 0.04649924486875534, 0.036837530455418994, 0.04434804119435804, 0.04041472975430744, 0.0337868370115757, 0.055627413626228056, 0.040070407159094296, 0.02433503758428352, 0.03136038899953876, 0.08435539887951952, 0.1002320937280144, 0.00934609554574958, 0.010465738546502377, 0.024757997299145375, 0.02063311676361731, 0.07075455119567257, 0.0009599252932405632, 0.0648184215117778, 0.04606242098712495, 0.03045043282743011, 0.029428355528839996, 0.022609168497313346, 0.04908262106723019, 0.004190081813638764, 0.07105673676622765, 0.010809195161397969, 0.05282970178606255, 0.051843580058110614, 0.09958933786089931, 0.048078375668930154, 0.0792428750012602, 0.028891284883554493, 0.062407138757407665, 0.024725403869524598, 0.05427131728668298, 0.0704679787158966, 0.031556621326931884, 0.043647765913712125, 0.030595235593084778, 0.046895295581115146, 0.011005262095880295, 0.014351536420040896, 0.03997057430180056, 0.053323671886963506, 0.036920912231185606, 0.023482029159952487, 0.04881851488192167, 0.03482935857027769, 0.010950858006253839, 0.0546898512568857, 0.030732360735003437, 0.013765150697768798, 0.045193967409431934, 0.01797533580767257, 0.02162499586120248, 0.010733747156336904, 0.05872257146984339, 0.06901184935122728, 0.026044821998636638, 0.021909140881949236, 0.033883473968931606, 0.02686953720902758, 0.04399986791291407, 0.02001385686786047, 0.02162201369979552, 0.03714855394459196, 0.06669096103204147, 0.04367739075262632, 0.030985786779118434, 0.08783481788954564, 0.05591071217453905, 0.03407248668372631, 0.05644718570900815, 0.03224390605464578, 0.06701777742377349, 0.06928576036755528, 0.04630416265821882, 0.01785375759936869, 0.048766535706818104, 0.02496665869174259, 0.07168851393674101, 0.08106718425239835, 0.04616632166185549, 0.022027000718350922, 0.036542157376451154, 0.016321632312610745, 0.037462101584034305, 0.06471230542021138, 0.04619328325082149, 0.027361505631623522, 0.03231205471924373, 0.07128768973052502, 0.021225230169615576, 0.05781826749444008, 0.022619314292179685, 0.0337040014564991, 0.017387012019753456, 0.0985773978754878, 0.024129926626171385, 0.019472620017560463, 0.05612348718568683, 0.04486638766580394, 0.008516630590228098, 0.02505705482326448, 0.06399074449603047, 0.051191789497222216, 0.01909971413468676, 0.05204646881403668, 0.08950398010866982, 0.02123307403443115, 0.042229115430797846, 0.010417939995282462, 0.09500636306724378, 0.03634525669206466, 0.02251227878566299, 0.02146132642935429, 0.013161863516350942, 0.014766097567709429, 0.012452962359280458, 0.020543824947838272, 0.017373599078772322, 0.02871883860124009, 0.009522585896775126, 0.04712422990373202, 0.03660525095516017, 0.02242907173266368, 0.051747855730354786, 0.023354342440143228, 0.02352010684886149, 0.04632023376013551, 0.0882284292685134, 0.017841566021421125, 0.03364093841186591, 0.023611865139433315, 0.0497759718980108, 0.029790550736444335, 0.019008934630879333, 0.022363606674064482, 0.03005730320832559, 0.03788686450570822, 0.028343588379876952, 0.018857305802937065, 0.03754082860957299, 0.03190247401861208, 0.03413161761792643, 0.03403076695810471, 0.037066736192043336, 0.05343837144651583, 0.017749863709988337, 0.02639460001539971, 0.035772023522960286, 0.02851839257138116, 0.0185604619993163, 0.030522065769348825, 0.03394604507567627, 0.01009784110023507, 0.010117565265058406, 0.018120756040194204, 0.02296093462168106, 0.07937452436557837, 0.019455970464540378, 0.06582164232219968, 0.017745256457211714, 0.03422042767384222, 0.03507342761648553, 0.016728763501825075, 0.016304141376167536, 0.07318762170949153, 0.016021699478317584, 0.05060538935608097, 0.014419398403593471, 0.05827980022877455, 0.028834610246121883, 0.04181806570185082, 0.03661233825342996, 0.033787295022713285, 0.0636854919471911, 0.008511256592880403, 0.11493233777582645, 0.036465940930481465, 0.041089671930032115, 0.060771977928067954, 0.018653097296399728, 0.03730163144479905, 0.00914041801089687, 0.03954819982339229, 0.052648923093719144, 0.058710690321666856, 0.03612301951008184, 0.040651239920407534, 0.09601996546345097, 0.04862700176558324, 0.02091499717373933, 0.04325907052095447, 0.023908680105315785, 0.008447836469193655, 0.004670958733186126, 0.017205580237454603, 0.03194205296624984, 0.014669307939974325, 0.015963104586782198, 0.008401118484990937, 0.019735135038250258, 0.022493978696210042, 0.07713267180536475, 0.013818344450555742, 0.056271309432174475, 0.005406246844878686, 0.021033957933208773, 0.009523540934813874, 0.054341474414936135, 0.035731464092220576, 0.027498905580224733, 0.03536523838660546, 0.03402719786390662, 0.1750690508633852, 0.13795056619814464, 0.20982361451855727, 0.11070719520960536, 0.21306759544781276, 0.12765504579458917, 0.15979252702423505, 0.15452486968466214, 0.22410866298845836, 0.09538730619741337, 0.10137852613947221, 0.1376661378890276, 0.11085644577230726, 0.07587788413677897, 0.11494460568896361, 0.06475976894476584, 0.11047440341540746, 0.19697549965764793, 0.1402778870293072, 0.11515679715999536, 0.1432156858167478, 0.09255907724478415, 0.1292094609567097, 0.11683249367134911, 0.10242574316050325, 0.1288050947976964, 0.15515901494239057, 0.14968030607061727, 0.18615829439035483, 0.13491025434008666, 0.20110184752515384, 0.14913540173854145, 0.16252478398382664, 0.21605176531842776, 0.08151490879910332, 0.14992843275623663, 0.21130130094076904, 0.1434087697416544, 0.11265250761061907, 0.09248591081372329, 0.09521826276821749, 0.18820577380912645, 0.16725382022559643, 0.09318455082497426, 0.07517670640455824, 0.1969058005405324, 0.13054242943014416, 0.09758060957704272, 0.25457507531557766, 0.13333960862032004, 0.12396323175302573, 0.13073030220610754, 0.16242566358830246, 0.10097696233008589, 0.14458148181438446, 0.09721291823578732, 0.2070425437497241, 0.1323469526001385, 0.19063621839242323, 0.12877955473959446, 0.17967474300946507, 0.13088352898401873, 0.0909605844478522, 0.10005492823464529, 0.10912926880908863, 0.1360222375286477, 0.14659614727965423, 0.09308933200580732, 0.18301807503615106, 0.14286936154322966, 0.08669158816337585, 0.09715873042919806, 0.13035302316503866, 0.2015396383191858, 0.0964855829785977, 0.10160717208470617, 0.0898449168141399, 0.10788325459829398, 0.11697979005319731, 0.09001039793448788, 0.11186569875904492, 0.12857680847602232, 0.09880775372896876, 0.14400554129055568, 0.16530581404055866, 0.1311156829552991, 0.056206634866872, 0.11889016468610082, 0.09155391582420894, 0.06842383090406656, 0.1312100671763931, 0.13059033400246076, 0.12378796615770885, 0.10675896956984486, 0.08228755662483828, 0.08416374666350228, 0.1368961770619665, 0.19551128894090652, 0.14490764002714837, 0.09696062534515347, 0.11870086698659829, 0.12199349887669086, 0.1128639934052314, 0.11608723151896681, 0.11805590588067259, 0.10457863977977208, 0.15968478923397406, 0.11407449309315, 0.1195320723844426, 0.07993763379220452, 0.09349058368908507, 0.11545566469430923, 0.09547766670584679, 0.17931624581771238, 0.1947160323283502, 0.1499781422317028, 0.094742284023336, 0.08008392594222512, 0.1881013744111572, 0.1466453139271055, 0.12981611197548254, 0.1081003247361098, 0.1790087337472609, 0.09323807366724525, 0.0873827642894217, 0.10761220699974469, 0.1804580031228917, 0.13061541265675, 0.12740287504025868, 0.06783155125698873, 0.1564528862280505, 0.2915518954396248, 0.21137215356741632, 0.09727806438292776, 0.1561276643936123, 0.12483349362654345, 0.09030626634401934, 0.1307426651141473, 0.09927736781537533, 0.2346063054033688, 0.08815330865659884, 0.1649361074502979, 0.1471097304352692, 0.1282796101378543, 0.09281497315636703, 0.14539512672594615, 0.14277971349656582, 0.16043053993156978, 0.13259308439280304, 0.11729859294635908, 0.1484222071511405, 0.12578488114689076, 0.15376679679112776, 0.07934033298598868, 0.19116059025483473, 0.08356833896998848, 0.11240090682570424, 0.1302038404558386, 0.10510314056383711, 0.12187672299998147, 0.0738730099318283, 0.17404625431767531, 0.08788637298026256, 0.17420246664966854, 0.18044656302247727, 0.20211194189531462, 0.11193291443799223, 0.18156386592558452, 0.12419526358800274, 0.13085459625082357, 0.19857547166092054, 0.17739318257996015, 0.17410543614200183, 0.15740088107330458, 0.2275030615606478, 0.10852839890867472], [0.024833631901336566, 0.024354313067825775, 0.03832673840224743, 0.035774174478969405, 0.03777756608490433, 0.037450800583298714, 0.019733667706272433, 0.03278886127684798, 0.01485480584337243, 0.035062143579125404, 0.052884432420666726, 0.03046012230749641, 0.018071672513282726, 0.021273222951484577, 0.026000618834846785, 0.04312051706282156, 0.007018446049187332, 0.037432300326015265, 0.017706566390448382, 0.030025507057351724, 0.0102217025788767, 0.017350133641489913, 0.005597617044778807, 0.027618293816755925, 0.009230239932159228, 0.043820283442203484, 0.026735109243808047, 0.03758673828893474, 0.0868053309885519, 0.03400846351204174, 0.03068208129012159, 0.0328486911021173, 0.006995560759345868, 0.02116644019926233, 0.040594297261642556, 0.041619509392018826, 0.020746562729722688, 0.015925042164911116, 0.03293461399152875, 0.02858516720256635, 0.04721451238063829, 0.0416962347392525, 0.036739617852228026, 0.10721807314881257, 0.04151499803577151, 0.04466541577130556, 0.00604360963084868, 0.043587586642908197, 0.05582246191001364, 0.021679685783705542, 0.045715421571263244, 0.004726761877204159, 0.04406415571325591, 0.033218397692378075, 0.01349399792629161, 0.02352545370480844, 0.024529283500409553, 0.03241020480969122, 0.030554927220301967, 0.01947182273891355, 0.020711921820683137, 0.021202648524194956, 0.016694592478285943, 0.05622546760631459, 0.03897710743227175, 0.025889233918860555, 0.04322882482249822, 0.018015023320913315, 0.05244472476520708, 0.06587468340460743, 0.03287162897842271, 0.038109664871756516, 0.043839221354573965, 0.023477091121354272, 0.02898331798080887, 0.03802929239879761, 0.0321525243510093, 0.04395053841705833, 0.02791815879754722, 0.02350139115670962, 0.03252245485782623, 0.014863647154665418, 0.007475134467573038, 0.023063515545800328, 0.0727546824408429, 0.03884535628770079, 0.013810017129539378, 0.04480008122378162, 0.029027846841407672, 0.023645691806450486, 0.07595590887857334, 0.012636022625624068, 0.053060943127742836, 0.00915903870814613, 0.030545129174632684, 0.014012183245670582, 0.04312585034806814, 0.116761464625597, 0.04765767717201795, 0.10658143766756568, 0.031834861396678855, 0.021895476883011203, 0.10308676519032035, 0.03879978587584836, 0.045266886175210984, 0.010647152517256992, 0.004278002140511359, 0.022699976838859062, 0.012825232115574181, 0.02325913210266403, 0.04757633100130728, 0.04154323527057256, 0.05670978215390018, 0.0258025358031903, 0.03720735239663294, 0.029147404711693525, 0.01957387101304318, 0.029709160460957458, 0.07888392997639519, 0.04715336619743279, 0.049103180678295236, 0.03201919221984489, 0.009851526103115507, 0.02826145850121975, 0.0371890014170536, 0.03495144059083291, 0.014520562885861312, 0.0685670425051025, 0.049436901163841994, 0.04755747112046395, 0.051717040062482865, 0.043854227156511376, 0.022723929125017354, 0.015759303201256052, 0.008729498899940933, 0.01866189280657896, 0.04765686292999557, 0.04641720998500075, 0.024054841637345295, 0.018802529367219125, 0.019319050579464862, 0.02493012127732592, 0.05733192751982382, 0.017351487318852117, 0.034979382662900856, 0.04738920461386442, 0.02334356730404709, 0.04126968727047954, 0.02994429659364479, 0.017399252791489874, 0.03993710216933063, 0.037842993824077506, 0.05531771667301655, 0.025543644159500088, 0.016763051572654928, 0.019954741200698272, 0.028904594347945282, 0.008206961626586105, 0.014189118037133344, 0.04027782174359475, 0.08597042757485594, 0.04454300466126629, 0.019458664248564413, 0.04414788354188204, 0.03348017989524773, 0.030477886354284625, 0.01353282539639622, 0.00876012203350131, 0.03028506027268512, 0.0058614000777847, 0.055258215937231264, 0.056237151979335716, 0.02889325942045876, 0.024691000447741578, 0.039615381575588665, 0.06187739968299866, 0.057322787653122625, 0.025623046327382326, 0.05787725932896137, 0.033119138197175095, 0.028561197953032594, 0.04156164392562849, 0.03841685803074922, 0.02934720952595983, 0.02490960237836199, 0.028752751781472137, 0.06800488981285266, 0.010085650370456278, 0.015251387509384325, 0.03316786379686423, 0.05194799641945532, 0.043740219702678065, 0.010580683226830192, 0.016643936446468745, 0.022844806745914475, 0.03346607654488512, 0.010682006316658641, 0.021123538126370738, 0.040374574051903825, 0.027288318844512105, 0.04993742930569819, 0.03562110037143741, 0.046769766602665186, 0.035496344922908714, 0.038535021511571746, 0.03078059439680406, 0.06120683066546917, 0.036034355339195044, 0.03478526057941573, 0.0644873371347785, 0.031734251616788764, 0.03516549464049084, 0.038950644566544464, 0.038160772129361115, 0.004563973268627056, 0.016996448959356973, 0.0580430661461183, 0.0609228162627135, 0.028646764611559253, 0.03793334415448563, 0.04518018975587828, 0.0021582214228276697, 0.02865471025662763, 0.07051014288195542, 0.04559833696112037, 0.017824036069214344, 0.014906985186306494, 0.039444903044828346, 0.0066549921591233996, 0.0244084703403392, 0.04246074014476367, 0.0605538764170238, 0.030817140292908465, 0.030747760087251663, 0.012324781157076359, 0.02833814822536494, 0.055607580047632964, 0.03157847015453236, 0.028289173264056444, 0.04203728340300066, 0.046422064903059175, 0.005910986568778753, 0.037695989212287326, 0.038058893488986154, 0.02386675512285105, 0.04902038922799485, 0.046043045419667444, 0.03215283986979297, 0.053557159179555516, 0.005629461965457137, 0.05943825628076281, 0.020123789718906795, 0.02360668622090348, 0.03935519393001284, 0.01076240508284952, 0.01914760852897806, 0.022065422763781886, 0.04383898725999253, 0.04937632834272725, 0.01933528283344848, 0.06443346145429782, 0.0408010095623987, 0.021544497859265124, 0.020552104771403328, 0.035875004782740555, 0.03589980184499707, 0.07479496260306664, 0.0319277664114322, 0.04186804998399956, 0.024438103660941124, 0.05717400527958359, 0.052241975108959844, 0.01605792137395058, 0.0901847475075296, 0.008087401211793934, 0.017210141689117466, 0.0383770585592304, 0.013824939810937005, 0.01960656452657921, 0.021663272021604434, 0.04305502486282161, 0.020080770598724484, 0.043249279260635376, 0.04495831219745534, 0.06202416680753231, 0.049478139129600356, 0.05215156031772494, 0.05145136306860617, 0.012526995618827641, 0.04781328560784459, 0.02190338520865355, 0.026154128901128258, 0.03513871964865497, 0.026476047966363173, 0.036324306923363886, 0.018859926644446592, 0.021649401069485714, 0.02287750195578805, 0.015488158911466599, 0.02316090228435184, 0.02096905266599996, 0.016854923517842377, 0.033350491497133455, 0.047792990625436814, 0.053272106618221314, 0.028023140039294958, 0.051078158630324264, 0.02328306233643421, 0.046831275802105665, 0.03666076869038599, 0.029605660121887922, 0.05097992033032434, 0.025554862039695894, 0.010366974381863006, 0.06057471422744649, 0.06147915390985353, 0.10422245639243297, 0.02617897854984871, 0.04441085318103433, 0.04192275347720299, 0.01262564443251384, 0.08108467009982892, 0.05117669887840748, 0.05763401809547629, 0.05767679972840207, 0.047924826586885114, 0.01574154763615557, 0.03694383653679064, 0.0619257249470268, 0.031648980120995214, 0.05736724526754447, 0.008233952053290392, 0.023718761546271186, 0.02720667581473078, 0.007085248245857656, 0.04587037522079689, 0.006752214777017278, 0.04417567294357078, 0.03262290178931185, 0.017694222142121623, 0.040900462440082004, 0.028910850440817218, 0.007084069715347141, 0.04476130973281605, 0.041021808250142, 0.05508353727470551, 0.04460673945556794, 0.019497491718669022, 0.0385620034565883, 0.0890514108219317, 0.01818957645446062, 0.04541250657556312, 0.11050544639251061, 0.11703415427889143, 0.13416007959416934, 0.1164912176983697, 0.14339124996747288, 0.14571481171463216, 0.121185160108975, 0.0828905367691602, 0.08945622481405735, 0.1532609217933246, 0.11418171519679682, 0.17320142393665655, 0.1550772786140442, 0.10810267925262451, 0.1110220422436084, 0.19268116009022507, 0.08804634439625911, 0.09779214965445654, 0.22770565854651587, 0.09042573600475277, 0.11248001722352845, 0.05348697151722653, 0.14606375513332231, 0.10540719210569348, 0.17533445305057935, 0.09621432503419262, 0.16922750217573984, 0.15226623016808713, 0.164117034258587, 0.14697778251554283, 0.14461302012205124, 0.09060387180319854, 0.09045953383403164, 0.09908413461276463, 0.12745369731315545, 0.0950553532955902, 0.12008312424378735, 0.06485814973711967, 0.08910001428531748, 0.08070637325623206, 0.1305228876216071, 0.14961048481719835, 0.14512489336941922, 0.1448085874851261, 0.10106925666332245, 0.11198985031140701, 0.10362558306327888, 0.2328314749257905, 0.15097812643008574, 0.09225268475711346, 0.12396262107150895, 0.08479120835129704, 0.10421111807227135, 0.12403591642422335, 0.12841142235057695, 0.10584759525954723, 0.1340152123676879, 0.14277302314128193, 0.11361950822174549, 0.0807339082072888, 0.12343587433653218, 0.06959091792149202, 0.0684573505339878, 0.1371276117861271, 0.23908724210092, 0.11625435469405991, 0.11440430182431426, 0.14186183203543934, 0.10267754750592367, 0.13216032832860947, 0.13390113706035273, 0.249599568013634, 0.13718251883983612, 0.11427867785096169, 0.10119918254869324, 0.08182672278157302, 0.1361322280551706, 0.1299902376319681, 0.18073966300913266, 0.14060867285089834, 0.07142626693738358, 0.1143321328397308, 0.11793117757354464, 0.13474709380950245, 0.14388165436685085, 0.08854176995477506, 0.1422932988830975, 0.1285603472164699, 0.13792577252856322, 0.1732766598995243, 0.1387033872306347, 0.20342474430799484, 0.12436292959111077, 0.11746731746409621, 0.08416480517813138, 0.20369762395109448, 0.1623087791459901, 0.2325098221855504, 0.12580978338207516, 0.2094750510794776, 0.11269977436001812, 0.12416327744722366, 0.13876486250332423, 0.07021772821566888, 0.14599831721612386, 0.09259526351732866, 0.15632373387260096, 0.14385470295591013, 0.16863108346504824, 0.09789536161614315, 0.12542635681373732, 0.1259597667625972, 0.11873115678983075, 0.11417281281735216, 0.17742883280983993, 0.13479292206466198, 0.12056432770831244, 0.14588490687310696, 0.12612360582820006, 0.16746849513479642, 0.12122266952480588, 0.09338141418993473, 0.08275649896157639, 0.15226096473634243, 0.1702564326780183, 0.12909238652459212, 0.1101937477609941, 0.15886475252253668, 0.1440316377473729, 0.13766243308782578, 0.14319131283887795, 0.11731118655630521, 0.12525214973304952, 0.10974200628697872, 0.08578271764729704, 0.14048315744314874, 0.08129960963768618, 0.10967131650873593, 0.17599929523255142, 0.1674460627670799, 0.20902942999133042, 0.10318977359150137, 0.12838075256773404, 0.1346135852592332, 0.10914503117757184, 0.1369038037955761, 0.14927321220082895, 0.10825532927576985, 0.14923742626394543, 0.0953925648438079, 0.09321583128933396, 0.13546022054340157, 0.10717120673507452, 0.09194032794662885, 0.12323553008692605, 0.05383359434615288, 0.08882081069584404, 0.09655458320464406, 0.06617749322737966, 0.1295266489365271, 0.1526406593620777, 0.14022996888629027, 0.054940135683864355, 0.1002180819798793, 0.11620317958295345, 0.07540905036564384, 0.08197757468691894, 0.08910489973745175, 0.141147714640413, 0.13869471555309637, 0.09336005390754767, 0.14197233824857644, 0.07983764487185649, 0.15906691524599278, 0.1320516134479216, 0.18564990881298268], [0.030591144026922326, 0.08370780505772148, 0.009865485264786651, 0.005893546522461942, 0.012471019024295467, 0.026862812926992774, 0.045221095239477496, 0.07129911626023905, 0.02387108756894512, 0.025605012562924197, 0.017446383833885193, 0.04119120112487248, 0.005248889485041478, 0.04806463533480253, 0.03160216799005866, 0.03788500531975712, 0.07559887053711073, 0.022597687684797814, 0.021456502045371702, 0.02965434840215104, 0.013954600219481757, 0.03755192265712789, 0.04606257026482906, 0.016956871708056757, 0.00871246088562267, 0.04599007558343666, 0.062336306486810954, 0.044031548712934764, 0.05903203093579837, 0.040380446772490225, 0.06256830439503704, 0.038318083688084564, 0.0639228027846132, 0.034665149703089676, 0.00801687004111175, 0.05134858876200659, 0.024238933276917254, 0.027558984767113413, 0.02880414741645966, 0.05763869320175477, 0.11550238861569337, 0.0169180679866778, 0.005500104353164456, 0.003016789169383368, 0.02595013243678425, 0.029062214640102217, 0.04714791416855795, 0.04065446635442121, 0.016630754207393954, 0.02447642562245684, 0.07647593133151531, 0.026767857040145566, 0.024289587612396905, 0.023388325170214688, 0.025900317788390175, 0.044490184102739604, 0.06129561018730913, 0.05118072598374315, 0.02129628974944353, 0.027418115808229362, 0.034302560945174525, 0.018957208210070218, 0.05226450586425407, 0.025958724386457886, 0.01291385302985353, 0.05303979997656175, 0.06194377397852285, 0.03887780722496765, 0.039080417781536064, 0.09061837888189725, 0.01277145227816488, 0.0063825149721066865, 0.056177793735904355, 0.014926991791331341, 0.03470050137756126, 0.041337978427431414, 0.06894846060978514, 0.028845504125846282, 0.030042277050337622, 0.05743315815925598, 0.11313779585595642, 0.02093048982455262, 0.06260237363832337, 0.033064153111938915, 0.07680236774363688, 0.03359804142798696, 0.015755014859938195, 0.007893905925032283, 0.06245651575071471, 0.03846635376768453, 0.018637726781889796, 0.008116359390052301, 0.023219581992764558, 0.06434759963303804, 0.08390164215649877, 0.04866462992504239, 0.009879114488804979, 0.06311047423098769, 0.02997895616239735, 0.03017779067158699, 0.03491437900811434, 0.01281711005140096, 0.03652970625885895, 0.020650197186374238, 0.022726870574323193, 0.027590616373345256, 0.017936435395053456, 0.05344721954315901, 0.05976288778973477, 0.02630213774474604, 0.03542027775464313, 0.005527431502871747, 0.05719924678227731, 0.030368988269141743, 0.027501042965533476, 0.010267036351641374, 0.022675983840599656, 0.005181455402635038, 0.06585804572595017, 0.032864636675055535, 0.03778685862198472, 0.005616403134938861, 0.0486907297745347, 0.020526011707261205, 0.039898391746516736, 0.013174936341653978, 0.04660989696692143, 0.03697577178744333, 0.04506002798942583, 0.027389890447791134, 0.039520912537617345, 0.05467623645173652, 0.011650732951238751, 0.0917552507349423, 0.06643539760261774, 0.008848461355747921, 0.079422103241086, 0.021793087645034705, 0.02304745971092156, 0.025998296548745463, 0.05090325605124235, 0.04099089419469237, 0.0325795026895191, 0.0376164275886757, 0.02872306926708136, 0.03837475832551718, 0.022126601177400777, 0.04508657567203045, 0.01776043528557888, 0.03895827130015407, 0.04368973669729062, 0.06650859796042953, 0.03286296408623457, 0.046996726388377805, 0.03563905780070594, 0.03471016710890191, 0.03523418274042862, 0.11177518218755722, 0.03243306804714458, 0.08994951977261476, 0.029173640268189565, 0.04648266486557467, 0.10345561004110745, 0.06488556255187307, 0.034463183754788976, 0.0029831552487199326, 0.01820361364765891, 0.0300650792196393, 0.05780854408762284, 0.022022771748847196, 0.028821426310709546, 0.0808332660900695, 0.08777004493666546, 0.01639407271120165, 0.08440183103084564, 0.05092619392754776, 0.017282531197581972, 0.07913826525743518, 0.02738598038974617, 0.086212976702622, 0.055240601168147156, 0.017912332134853517, 0.011904155602678657, 0.025552125847233192, 0.013276010918031846, 0.05352279477353607, 0.049716186177517684, 0.01936303830838629, 0.03205473388412169, 0.05414075357839465, 0.0688950191917164, 0.017706500233284066, 0.08118788206151553, 0.010979367503231125, 0.026237176498398185, 0.02313861240898924, 0.027617074150059904, 0.05043119923876865, 0.012369175158840204, 0.05024714661496026, 0.022332304157316685, 0.06907684622066361, 0.0066676018842762065, 0.030248605978808234, 0.02886443186019148, 0.018729161071990217, 0.04330293780991009, 0.055068901274353266, 0.05633237758385284, 0.038910797597574334, 0.01833232325900878, 0.03353952796065381, 0.0849937985518149, 0.02511589738008167, 0.05179504444822669, 0.10958771420908825, 0.04875200827206884, 0.024773669761738608, 0.043477019361619434, 0.0190184409064906, 0.06093627839748349, 0.05998867031719003, 0.0541283296022032, 0.025786568177863955, 0.03559906155403171, 0.07714394905737468, 0.03681439580395818, 0.0403232293070427, 0.05268821366397398, 0.03541211497836879, 0.03450023515948227, 0.024342672799580863, 0.03665546593921525, 0.016411200631409883, 0.05814954186124461, 0.007442941373613263, 0.05430148834628718, 0.10739234129765204, 0.008895823948218353, 0.0468720727201019, 0.042414413166365454, 0.01667132381615894, 0.0846831448642271, 0.017625099779771905, 0.034368280454405715, 0.05166202783584595, 0.045067712398512025, 0.0743617858471615, 0.04891982016020587, 0.01377490972767451, 0.03327245996998889, 0.03231827010001455, 0.04492719458150012, 0.0040322944322334865, 0.06554949549692017, 0.04974171266491924, 0.055062780888485055, 0.029136541366044964, 0.007789948422993932, 0.03306278247120125, 0.05472900612013681, 0.02592388670226293, 0.03194355592131615, 0.06601070931979588, 0.03849650786391326, 0.03491706261411309, 0.006406789138314447, 0.0962052530209933, 0.016875272783051645, 0.04966396272980741, 0.030094079806336334, 0.022455890829275762, 0.07476724444755486, 0.057124356872269084, 0.026557567163503597, 0.01183028519153595, 0.052345126002494774, 0.011938385998031922, 0.011461037460581532, 0.042926218560231585, 0.06491302964942795, 0.027291487603049194, 0.006659781768186284, 0.0399126681233091, 0.05004633078351617, 0.03339120020557727, 0.030270699079015424, 0.030208423135003874, 0.016635039156036716, 0.01859062457723277, 0.039120641337441545, 0.0413223212318761, 0.030754189206553356, 0.016287203445764523, 0.04888236163450139, 0.01811362463714821, 0.027876162568905523, 0.03849859096642051, 0.055998887800212414, 0.006940433605840164, 0.06640139621283327, 0.007157647932347442, 0.03117973244349871, 0.032116582351071496, 0.08824688542102065, 0.012890728556417992, 0.0653093619538205, 0.08334565734756844, 0.052921412579183064, 0.013520761891933424, 0.04718324887965407, 0.05160408094525337, 0.054837595471846204, 0.01526304304466716, 0.03008048196456262, 0.0270353728639228, 0.03669157078755753, 0.01904127700254321, 0.06240378000906535, 0.03140764217823744, 0.026889138389378786, 0.09661419250603233, 0.04397594955350671, 0.028806695315454687, 0.013414004584774375, 0.00752862253492432, 0.06462946986513478, 0.01683924426989896, 0.05382792857874717, 0.020686564967036247, 0.06275646894105844, 0.05920676727380071, 0.009860427634391402, 0.02010952860915235, 0.024890021554061344, 0.05008241527580789, 0.03700815487120833, 0.006724938941520772, 0.06399472071123974, 0.05715007334947586, 0.07080734122012343, 0.06122910018478121, 0.02704557972694082, 0.028661366685160568, 0.06516285267259393, 0.015493853516610605, 0.06236359037991081, 0.08570750882583004, 0.0781350444470133, 0.07207925511257988, 0.06103274572108473, 0.06212853906410081, 0.11041006472493921, 0.12123178903545652, 0.12577057762869767, 0.09171130880713463, 0.07771677510546786, 0.12048511553023543, 0.12144308484026364, 0.17164400964975357, 0.12206963050578322, 0.1411669578935419, 0.17210067728800432, 0.11173485006604876, 0.15676262389336312, 0.16976403338568552, 0.12324832725737776, 0.10857714486441442, 0.1866100901471717, 0.15887786181909697, 0.08830582975809063, 0.08708173901374851, 0.08572044848863568, 0.09506745157497269, 0.09393685617085014, 0.1415539128439767, 0.21324701367744378, 0.17722071254892008, 0.09913345732327018, 0.13737833047551767, 0.0671151607696499, 0.10356982784079653, 0.14128806282367024, 0.0908823629309024, 0.1308046153613499, 0.15607695068631852, 0.11824345295982701, 0.07089101815862314, 0.13421870501978056, 0.1103497768885323, 0.12515117015157426, 0.21809906831809453, 0.19289468148989336, 0.15623105955975397, 0.1362897160329989, 0.10278543457388878, 0.1371916654918875, 0.08463689591735601, 0.18462845576660974, 0.1639127680765731, 0.16527716629207134, 0.1148803484226976, 0.17737754913313047, 0.18754915547158035, 0.07730172201991081, 0.08440816854791981, 0.13943069534642355, 0.1096101872889059, 0.15445265998797758, 0.11249582708946296, 0.16085748773600372, 0.11024225622947727, 0.15592200042945997, 0.1441203901278121, 0.12812083294349058, 0.1214186032967908, 0.08734174006219421, 0.12287657149136066, 0.17732043005526066, 0.19853338891906397, 0.14768620021641254, 0.14707991560654982, 0.15657842877720082, 0.12994130168642315, 0.1020150055576648, 0.11724091746977397, 0.10975297819823027, 0.08054914990706102, 0.19526613423866884, 0.09626691149813787, 0.15517840747322353, 0.15281390292303904, 0.1446784037564482, 0.12861126448426927, 0.12249557407838957, 0.06526057528597967, 0.10781590321234294, 0.08872048929333687, 0.19348526479942457, 0.10292131799672331, 0.1444522344640323, 0.12514766891087803, 0.11739459208079747, 0.1472021740462099, 0.12313206706728254, 0.1770539829241378, 0.1868397199681827, 0.0926155313583357, 0.1398913934826851, 0.1469094268977642, 0.07547083776444197, 0.09839652758091688, 0.13923805925462926, 0.08599613726671253, 0.14564515330961772, 0.07003740074911288, 0.15577181348843233, 0.10348020015018326, 0.1018777039966413, 0.09716525793607746, 0.17451871825116022, 0.08364844681429011, 0.11657679453492165, 0.10785280873200723, 0.12482931385082857, 0.18604563043585845, 0.07849843387625047, 0.0647887559607625, 0.09696996198701006, 0.08996680884488992, 0.21577402736459458, 0.11745086977524416, 0.10766117008669035, 0.11489698610135488, 0.09006512178374187, 0.10999315923878125, 0.10655283063117947, 0.24018698451774462, 0.1409968084522656, 0.21845263934561185, 0.1630790928112609, 0.13715518744928495, 0.276863376476935, 0.23723115026950836, 0.1310792863368988, 0.17321598529815674, 0.2533409558236599, 0.11278824854109969, 0.17828218559069292, 0.08334136900625058, 0.06026228956346001, 0.20449195775602544, 0.1625822423292058, 0.09901520902557032, 0.06768940495593206, 0.1060048525354692, 0.10704859545720474, 0.2122495129172291, 0.0792852020157235, 0.09597430684204612, 0.056893543007650545, 0.12130701142762389, 0.16971747231270584, 0.11861267100487437, 0.1102489669408117, 0.13181380049458571, 0.13140833510884217, 0.06726167683622666, 0.10218261727797133, 0.11581606178411416, 0.11612670868635178, 0.18521150733743394, 0.1839361329163824, 0.12943632235484465, 0.22646194456943444, 0.14842994245035307, 0.11382599999862057, 0.09917207275118146, 0.1292334268135684, 0.09209182446024247, 0.09525030319179807, 0.14171539060771465, 0.11358805133828095, 0.24435272812843323, 0.2274799913700138, 0.18405558222106524, 0.1949784896735634, 0.13151422728385243], [0.05649441174630608, 0.025138752135847296, 0.04058525917519416, 0.06982233907495226, 0.012718466326727398, 0.03469727833622268, 0.012988977882611965, 0.009724994589175497, 0.013472831874553646, 0.016236045298033526, 0.012346685115647103, 0.025767345280785645, 0.07573127986064979, 0.011233928397164812, 0.03533456181841237, 0.041210807394236326, 0.03139959475291627, 0.03350910584309271, 0.014676517374547464, 0.01852577698550054, 0.0375729029599045, 0.030219327192753553, 0.015943535636844378, 0.029345058569950715, 0.061140877061656544, 0.02274348620059235, 0.002686230232939124, 0.02510825707577169, 0.018475696012111645, 0.049185083247721195, 0.050023460760712624, 0.03676535129281027, 0.0882956992302622, 0.023891460582880036, 0.024856993862028633, 0.042995378242007325, 0.02383362565056554, 0.009251292329281569, 0.02148047468758055, 0.002922750577064497, 0.04415097426889198, 0.006090066803153604, 0.05126295085730297, 0.04298132238909602, 0.04083958767088396, 0.02223613708546119, 0.008239743349674557, 0.026814139913767576, 0.027553839775334512, 0.011581869280364896, 0.03534360329753586, 0.02240399138203689, 0.046359164706830464, 0.037519780453294516, 0.04877908181931291, 0.0889806260487863, 0.007529124650838119, 0.044323423943881474, 0.04893228824117354, 0.03294546376647694, 0.02236795099452138, 0.03740019883428301, 0.055865749051528316, 0.04002310309026923, 0.047479042650333474, 0.06677581183612347, 0.041174756828695536, 0.0466187993463661, 0.07313812257988112, 0.06044337020388671, 0.035200110104467185, 0.03952361989234175, 0.01669451275042125, 0.05092720155205045, 0.02720822117823575, 0.00911648353628282, 0.021311399027971283, 0.02333010347293956, 0.06250245257147721, 0.06987037935427257, 0.017250455150912915, 0.015411112956436617, 0.05019778997770377, 0.03373490872659853, 0.07451843244156667, 0.003970835698835019, 0.06473256647586823, 0.10328612556414944, 0.03370909386181405, 0.056976246248398504, 0.053202370181679726, 0.056185366186712465, 0.07997954011495624, 0.020494217252624885, 0.09604032151401043, 0.032736139105898995, 0.02875401046393173, 0.03548984455743006, 0.04900536985535707, 0.01808359267722283, 0.040095943824521134, 0.01467259883481477, 0.038829851762524674, 0.060243385577840466, 0.05380423413589597, 0.08119353425822087, 0.036545645046447, 0.034344239958695004, 0.053171724147562466, 0.036294166397835524, 0.026075990504718254, 0.046932801604270935, 0.021981555835476944, 0.03360819570454104, 0.00631881707314668, 0.11016414327813046, 0.03703026493479099, 0.08865670021623373, 0.030748862706656967, 0.04436347108068211, 0.029441390186548233, 0.04547152215881007, 0.03550130162121994, 0.019738951797730157, 0.07546087008501802, 0.027099002485296557, 0.00830037469443466, 0.08114931413105556, 0.04040554917550512, 0.018746991275942752, 0.010320818733556994, 0.012761877300882978, 0.016023636695795825, 0.07317490596324205, 0.007851493245522891, 0.028660535479762723, 0.006853039567691407, 0.02213457566020744, 0.08528220307614122, 0.014673998313290732, 0.012948085121544344, 0.11071520870817558, 0.022171793305980306, 0.06181943243635552, 0.03589428874797054, 0.05314075920198645, 0.05832188975598131, 0.033750389503049, 0.03329099076134818, 0.04087679174595645, 0.016981059785134027, 0.054057063069194555, 0.04258887469768524, 0.03523575694167188, 0.020068456884473562, 0.017510337455730354, 0.018427345303020308, 0.06650320360703127, 0.017039983766153455, 0.029832959175109863, 0.08281440514006785, 0.03412044553884438, 0.0197126721364579, 0.008419758690121983, 0.08321237271385533, 0.04958927298762968, 0.023442960809916258, 0.034037511596190076, 0.055083323536174636, 0.007742877600581518, 0.07356629853269883, 0.023233111981036406, 0.024143482059506432, 0.017018156990941082, 0.03223595701690231, 0.06031455033059631, 0.026273993808510046, 0.03000052339796509, 0.023092047943334495, 0.018630854918488433, 0.014917668720175113, 0.05872253075774227, 0.03310320280226214, 0.03163862567661064, 0.03270815632172993, 0.04976989222424371, 0.02416404167057148, 0.04434433978583131, 0.056460444283272536, 0.04742738577936377, 0.1143104468605348, 0.02758073859981128, 0.05037641432136297, 0.03495014798162239, 0.032689516964767656, 0.04095822273354445, 0.024792125914245844, 0.02609248908369669, 0.012536218606068619, 0.05329863055210028, 0.02124568460775273, 0.04039513027029378, 0.02684518289087074, 0.011151313365969275, 0.021519305550360253, 0.04858993000483938, 0.019908317531059896, 0.02774242840574256, 0.05933085097266095, 0.033335882638181956, 0.05165854016585009, 0.014421293212633048, 0.01597087211640818, 0.046111689414829016, 0.019676112669653127, 0.017276495628591095, 0.038260241970419884, 0.031523471498595815, 0.024214085324534347, 0.038880097280655584, 0.030020414652036767, 0.049970277185950956, 0.009854568484505373, 0.005213872837235353, 0.013651351893453725, 0.03890250589964645, 0.022096068797899143, 0.017971030502979244, 0.03902473380523069, 0.01774852190698896, 0.017989603702777197, 0.025966307015291283, 0.0621019337060196, 0.03380337630265525, 0.02259817623001124, 0.030233433935791254, 0.04209370019712618, 0.023120492131316235, 0.06016637185322387, 0.07905563326286418, 0.02864914626947471, 0.051683540788612196, 0.028560590664190904, 0.12968523614108562, 0.053743108308741024, 0.0621547983693225, 0.019732285191171935, 0.0262165354631309, 0.05983066665274756, 0.025410676740908196, 0.019037266860582998, 0.03234728425741196, 0.05383889709732362, 0.03137887907879693, 0.0987884494076882, 0.07034883475197212, 0.013565699569880962, 0.06797546174909387, 0.026171550287732055, 0.056019355809049945, 0.0960423978311675, 0.02081511851533183, 0.04943573408360992, 0.08332662444029536, 0.03707875643989869, 0.018960738288504735, 0.015027647372335196, 0.016348068036937287, 0.07478271504598004, 0.07502357462154967, 0.036590194263096364, 0.021370682632550597, 0.02424740817930017, 0.03884591607909117, 0.012562921503558755, 0.05552849679120949, 0.022178546425753405, 0.028665576994951283, 0.02507734641299716, 0.03129188749673111, 0.09324163597609315, 0.02515285718254745, 0.041260228492319584, 0.024608081772125194, 0.05189810034685901, 0.07245922115232263, 0.020027108656774675, 0.03518259033028569, 0.0442848051232951, 0.0734383946816836, 0.04796443267592362, 0.022635168262890408, 0.04061274662879961, 0.046350381071014066, 0.049232132865914276, 0.07384227908083371, 0.006713545066304505, 0.018756205781495998, 0.06244039375867162, 0.05011509691498109, 0.04953484090843371, 0.04919368028640747, 0.04207553242200187, 0.031559315110955916, 0.057868418017668385, 0.03483318550778287, 0.044341612075056346, 0.05015612792755876, 0.022683615663221905, 0.010525267271857177, 0.02390617291842188, 0.03248521685600281, 0.01086399789034788, 0.019348965492099524, 0.033064580589000664, 0.0014335997756071655, 0.017468327656388283, 0.10680696913706404, 0.0673803458256381, 0.05122999441144722, 0.028067034469651322, 0.028021464057798897, 0.016798944378803884, 0.03302888286166957, 0.030196100939065218, 0.005975027552007565, 0.028886616562626193, 0.023397722880222967, 0.07145260766680751, 0.06275289306151015, 0.05251883775261896, 0.010758397485395628, 0.04585522014115538, 0.06357141663985592, 0.02107567765883037, 0.030561851670167277, 0.023840755357273986, 0.058523407871169705, 0.010435730335302651, 0.04138786092932735, 0.01843117902587567, 0.03819482440927199, 0.02286561232592378, 0.06057957253818001, 0.03419118620721357, 0.020645284592839222, 0.013890024041756988, 0.0028436573546579374, 0.012521584302053919, 0.008388438361829944, 0.04578397735687239, 0.06415722984820604, 0.1748690865933895, 0.13330098640705856, 0.09101657037224088, 0.1502923175160374, 0.18825922879789556, 0.10303820243903569, 0.13179495079176767, 0.13755434245935508, 0.06094634785716023, 0.11435691293861185, 0.08711660214300666, 0.14535361395350524, 0.16328025130288942, 0.17557337880134583, 0.23640426035438264, 0.07884273611541305, 0.08639596402645111, 0.07757335315857615, 0.12931405034448418, 0.11703656986355782, 0.07893975305237941, 0.10699934738555125, 0.11071611794510058, 0.17122734843620233, 0.08729113492050342, 0.11027690222752945, 0.11317075908716236, 0.15951288917234965, 0.11374279803463391, 0.22650660574436188, 0.16002968858395303, 0.18634360230394773, 0.1786033090736185, 0.06810989989233868, 0.11135856847145728, 0.12947084621659347, 0.14336148942155497, 0.14215647908193724, 0.08756638265081815, 0.10867924402867045, 0.09772306800420795, 0.060919674645577154, 0.11157567932137422, 0.16695252353591578, 0.1110734548419714, 0.11549527756869793, 0.09235711129648344, 0.08557679583983761, 0.1804413247321333, 0.14107726913477692, 0.10907943719731909, 0.09309199864843062, 0.1680481540305274, 0.12745011464825698, 0.15711740271321364, 0.231964822858572, 0.1526197197714022, 0.14352435139673098, 0.08482120638447148, 0.096441858181996, 0.11689609954399721, 0.16024642623960972, 0.12428607871489865, 0.21442885883152485, 0.08147242572158575, 0.11755338284586157, 0.14157205687037536, 0.19353061808007105, 0.17329013560499462, 0.2696108142180102, 0.09005889961762087, 0.06824761535972357, 0.15348377983484948, 0.1511543555451291, 0.08623071360800948, 0.08370352350175381, 0.10220378757055316, 0.16914143679397448, 0.22882876970938273, 0.14779040962457657, 0.10928999339895588, 0.16739552547889097, 0.12158807420304843, 0.1294774008648736, 0.1455362755805254, 0.09229442823146071, 0.1342385589544262, 0.19746860462640012, 0.09357854896890265, 0.18924172036349773, 0.0882025295868516, 0.16789365160678113, 0.18629358070237295, 0.13016075348215445, 0.18606344876544817, 0.18490175610142096, 0.06947111577859946, 0.0920871968514153, 0.1596065405756235, 0.16763479049716676, 0.10571511808250632, 0.14009747813854898, 0.09711634234658309, 0.10199561981218201, 0.18628717533179692, 0.19801486602851323, 0.14919515353228363, 0.11121805743979556, 0.11394501504089151, 0.07258284344737019, 0.1533707766128438, 0.14055809485060827, 0.0690734942576715, 0.16765111604971544, 0.10668772339288678, 0.21555863320827484, 0.09550458419003657, 0.18983165227941104, 0.0867452806394015, 0.23738930321165494, 0.149429234543017, 0.09111645072698593, 0.08086903845625264, 0.1897711676678487, 0.22279469349554606, 0.13167882630867617, 0.0839701538373317, 0.2038172496748822, 0.1639298807297434, 0.13280492302562508, 0.1197268119347947, 0.1498849115201405, 0.09620577549295765, 0.12378945893474988, 0.08246007415332965, 0.11101300415716, 0.08690725373370306, 0.06972826697996684, 0.2610038417790617, 0.10666951151298625, 0.14096498515989098, 0.24342343370829309, 0.20556062326899596, 0.1600295528769493, 0.21121344422655447, 0.13668528837817057, 0.12532630003988743, 0.09588775970041752, 0.10102210526487657, 0.11304961344493286, 0.09694676966007267, 0.10345662784363542, 0.11573733815125056, 0.1346328692244632, 0.15600232540496758, 0.06123450132352965, 0.1159663980028459, 0.179852302053145, 0.09977592820567743, 0.08823288045823574, 0.17946244297283037, 0.09019377202327762, 0.08263314808053629, 0.14013354906014033, 0.138532532112939, 0.19308609621865408, 0.0924972491338849, 0.10632436110505036, 0.17419182722057613, 0.13866670562752656, 0.19938098772295884, 0.1793712071542229, 0.10737724389348711, 0.055246043018996716, 0.09896372178835527, 0.16220813883202417], [0.0234963292854705, 0.05270571308210492, 0.04281867075977581, 0.046130712144076824, 0.0668151532965047, 0.07272906774388892, 0.027301709733105133, 0.03510845359414816, 0.025221426538856964, 0.02653793036006391, 0.02395693412316697, 0.029694867120789628, 0.04001831941838775, 0.03237824241763779, 0.04715354261653764, 0.058439181319304874, 0.04003300970154149, 0.028583243555788482, 0.04609783712242331, 0.026579565268808177, 0.021842893811741045, 0.044516341627708504, 0.045776469366891046, 0.045285919082484076, 0.005160116748551705, 0.020823374590171233, 0.008789360107454871, 0.019823772067736303, 0.007224406448325941, 0.02520675152274115, 0.0701688261968749, 0.017227776814252138, 0.012819982799036162, 0.04862018248864582, 0.009767783007451465, 0.03919619960444314, 0.05504682853019663, 0.030227042135915587, 0.0407409693912736, 0.014401593644704138, 0.026817223855427334, 0.019135707024750963, 0.0014846159610897303, 0.034006736640419276, 0.03951933155102389, 0.015351673288803016, 0.03332643064537218, 0.09163751133850642, 0.07006760912814311, 0.01430355551253472, 0.03845511722777571, 0.01806752666431878, 0.004894352393291358, 0.05281754922387855, 0.03742401541343757, 0.019371131534821222, 0.027723281843853847, 0.05140430327238781, 0.026849471232188598, 0.0074674246134236455, 0.013786614456746196, 0.03531742202384131, 0.03592484996521047, 0.017807159206963012, 0.052206094177173715, 0.020736208285338113, 0.05638699626017894, 0.0766522486561111, 0.016128450000126447, 0.020839628896542957, 0.04358195819492851, 0.03175455338454672, 0.05143985850736499, 0.05811637506953307, 0.049899054757718525, 0.023471798548208814, 0.010426743138980652, 0.013502428723898317, 0.036199598972286494, 0.0252782148309052, 0.02898007458341973, 0.034917120289589675, 0.024027625597747307, 0.04926251766404935, 0.034605730391506634, 0.09187401471925633, 0.03153284206720335, 0.038320668906505616, 0.028252635849639773, 0.035996360770825825, 0.011904554242002112, 0.07578381882714373, 0.04206491334896002, 0.03320912551134825, 0.05099586590326258, 0.05170637349198971, 0.02072336701011019, 0.08247293917728321, 0.02611108772855784, 0.03667807472603662, 0.01888661681940513, 0.01595273657169725, 0.05603910457076771, 0.016281013510056903, 0.008301661366463771, 0.013728017868873264, 0.04529546946287155, 0.006964772656959082, 0.0404514961742929, 0.02513015509716102, 0.04957512213981577, 0.02342876755366368, 0.02335093280167452, 0.030399987141468694, 0.053080993837543895, 0.0370054576945092, 0.013828818486737353, 0.02332467688912792, 0.06434869885976825, 0.030714298132807016, 0.020507184056831256, 0.06273802635925156, 0.01740365139474826, 0.022239405927913528, 0.026761412653805952, 0.01795538348544921, 0.039621518924832344, 0.019148448216063634, 0.06092670426837035, 0.07215758519513266, 0.01740254707900541, 0.03668903985193797, 0.052800809764968495, 0.03933253086038998, 0.01746775090162243, 0.02798393428591745, 0.032044932445777316, 0.014349192081551467, 0.026571885948734622, 0.029806971283895627, 0.0608808488718101, 0.045695852621325424, 0.008916958617711706, 0.004107975259622825, 0.020531212678179145, 0.02006541535125247, 0.03159849372293268, 0.02342384308576584, 0.05212325522942202, 0.07247293434504952, 0.030193943197705915, 0.014664978886555349, 0.03908359332542334, 0.0571622530530606, 0.06791331472673587, 0.03025902827669467, 0.03413791103022439, 0.032647630998066494, 0.047502296045422554, 0.027133692588124956, 0.038412505228604586, 0.00757495969134782, 0.03459607483819127, 0.09691381321421691, 0.0331425815820694, 0.040098691891346655, 0.023086589129109467, 0.019320821555863534, 0.08215803107512848, 0.025773570839581744, 0.07228584866970778, 0.0741227651014924, 0.12015446541564805, 0.04999287240207195, 0.006144823730989758, 0.03307537268847227, 0.013264083968741553, 0.013485338971284884, 0.09169417579791375, 0.025449665363079736, 0.005149300052185676, 0.04088839130210025, 0.03150568709575704, 0.027238702667610984, 0.020758596548278416, 0.004814668209291995, 0.03198389482817479, 0.05122002333934818, 0.05030529706605843, 0.023709977910454785, 0.028893055859953165, 0.05939391401729413, 0.044381418331925354, 0.03513135415102754, 0.016013850524489368, 0.01956625106478376, 0.0725577851491315, 0.04243024678102561, 0.014867104290585433, 0.0506878585022475, 0.018725686972694736, 0.023258752123053585, 0.07216642650642566, 0.06781979224511556, 0.010914675126384412, 0.07072318930711065, 0.0582285640495164, 0.06326997745782137, 0.07901703819100346, 0.04853527061641216, 0.0017700013226463593, 0.05494833917223981, 0.06792978955698864, 0.05338011242981468, 0.030479748932910816, 0.01965641649439931, 0.011501634210747267, 0.018757606956309507, 0.028557944377618175, 0.023439581705523387, 0.09229296259582043, 0.019849685320098485, 0.02765229351020285, 0.09601078488464866, 0.031817182166767974, 0.018142053558092033, 0.023772696598566005, 0.004946304426994175, 0.051966584886291196, 0.0617004648915359, 0.02571830925132547, 0.04469914235440748, 0.008123360175107206, 0.026390788344932452, 0.009954492095857859, 0.006363003697645451, 0.0681788661916341, 0.03524675599432417, 0.018219610110723546, 0.02531763432281358, 0.009913488224680935, 0.01665729340831084, 0.039036791372512064, 0.022822830692998, 0.04802044913438814, 0.0619185935439808, 0.03545581602624484, 0.0646202282181808, 0.04478764706956489, 0.027381617409576262, 0.0809954223888261, 0.008440350531600416, 0.030873441736080816, 0.040884788281151226, 0.007687265718621867, 0.0018744315727547342, 0.02975323809576886, 0.0151422078322087, 0.011490737786516547, 0.04344538266637495, 0.03832034660237176, 0.060690513013729026, 0.02468432705583317, 0.04612866296832051, 0.02291573740408889, 0.018809637021539465, 0.04016155476814934, 0.03975990953456078, 0.08914002749536719, 0.02023167848320944, 0.0033322820839072976, 0.0036226827734416084, 0.018417255487293005, 0.02906150557100773, 0.022242856278483356, 0.07275019732436963, 0.029287732538900206, 0.016903206373431852, 0.02487453568859824, 0.06159816895212446, 0.039879684536052604, 0.033441842666694095, 0.02601698849217168, 0.06501261823411499, 0.017527434841862748, 0.05114386456885508, 0.09945126276995454, 0.02527104101942054, 0.023069500224664807, 0.008556752365880778, 0.04610734339803457, 0.018631136510521173, 0.018164192459412982, 0.06797150588993515, 0.045207751848335774, 0.014995020015963485, 0.04051874917266624, 0.01776552769089384, 0.035044033479477675, 0.014356681411819798, 0.05271478509530425, 0.010112468618899584, 0.015325943240895867, 0.03968568458887083, 0.03821890222440873, 0.04160603368654847, 0.006824060185213706, 0.050304883159697056, 0.05757140288395541, 0.01379016658756882, 0.05197451017530901, 0.01327903039886483, 0.02325506428522723, 0.05792675167322159, 0.04934580783758845, 0.03455216344445944, 0.017238931929958717, 0.02424020553007722, 0.058497494618807516, 0.02095406552377556, 0.02215527437095131, 0.057112217880785465, 0.023635069340733544, 0.0348558112579797, 0.062464400327631404, 0.019107658083417585, 0.024747800614152635, 0.01818219568979527, 0.07357893964009625, 0.03683524379240615, 0.033643900217222314, 0.036549845178212435, 0.014025232322247965, 0.04733059275895357, 0.06267029499369008, 0.03249410905742219, 0.02831399577137615, 0.07003871710704905, 0.024201284761407545, 0.05062370980158448, 0.014577963555763875, 0.04809887421184352, 0.0586183417056288, 0.018929970118084123, 0.029026561017547334, 0.0559679194619613, 0.05006105838609593, 0.10962117277085781, 0.02233599029880549, 0.051830165420791934, 0.025267422731433595, 0.015319266456312366, 0.09767854253628425, 0.12238854196454797, 0.14345443514840944, 0.17429036407598428, 0.09687417319842748, 0.11959840596786567, 0.10175858038876738, 0.07387213462165423, 0.15659399437052862, 0.1613190679677895, 0.08628161730510847, 0.16725842069302285, 0.17666782864502498, 0.1627462442432131, 0.16564430801996163, 0.09346522005008799, 0.1585209116871868, 0.14017321621733053, 0.12788505559521063, 0.1181906900767769, 0.18066688334303244, 0.13442013492541655, 0.0911640567438943, 0.08520838525146246, 0.08110083280397312, 0.11505127139389515, 0.1123739622001137, 0.12834952638617583, 0.060825819681797705, 0.1782920786312648, 0.1543314600629466, 0.13341643235513143, 0.24497157920684132, 0.0558316187400903, 0.1632443703711033, 0.0995557096653751, 0.11377976462244987, 0.10880933276244573, 0.13247124664485455, 0.08808182499238423, 0.10440265493733542, 0.12064031005970069, 0.08647702860512904, 0.11553129420748778, 0.15139706752129964, 0.17372380090611322, 0.10149879647152764, 0.21659472904035024, 0.16770321396844728, 0.13393853791058064, 0.10964295374495642, 0.09301271183150155, 0.13846353867224284, 0.1742612684943846, 0.04875160115105765, 0.1935621699584382, 0.13715313827352865, 0.12351306448025362, 0.09488516314221279, 0.10241222674293177, 0.12001829700810568, 0.1431576439312526, 0.12898748501070909, 0.14518273169440882, 0.1150496836219515, 0.07102194827582155, 0.10487674056951489, 0.13091736074004853, 0.17814848705061845, 0.14218364762408392, 0.10630986759705202, 0.13344579935073853, 0.09758300480565854, 0.14518385806253978, 0.19500503396349295, 0.11322486546954938, 0.05401752483365791, 0.12416616800640311, 0.16561376037342207, 0.07164492484714303, 0.12837121236537183, 0.12176939233073167, 0.10453589885894742, 0.15261381651673997, 0.1150818190404347, 0.19298409883465084, 0.0982606645141329, 0.16963370037930353, 0.15496799376394066, 0.1307678251926388, 0.09289979003369808, 0.11339667732162134, 0.14920157247356006, 0.10626982724560158, 0.10966494506491081, 0.07396058166133505, 0.14532872528902122, 0.21975942993802683, 0.13135726856333868, 0.14338070553328308, 0.1319247002580336, 0.10005001564111028, 0.12526067213288375, 0.12536554650536605, 0.09414435217955283, 0.14336125871964864, 0.12702240688460215, 0.1713512625013079, 0.12470598332583904, 0.07514847256243229, 0.27573244859065327, 0.17869221073176178, 0.10700704197266273, 0.07315636838653258, 0.1069958054327539, 0.09577147236892156, 0.06085214005517108, 0.1478705174688782, 0.13362010142632894, 0.11118147761694022, 0.07754722956035819, 0.1632476816219943, 0.12524038393582615, 0.1166522747703961, 0.16371106675692967, 0.13150969466992787, 0.08659890027982847, 0.13481615510370049, 0.11875554333840098, 0.11910843583089964, 0.08302383497357368, 0.10189243499189615, 0.11177667496459824, 0.10304429568350315, 0.13839694724551269, 0.16620842846376555, 0.1537591836282185, 0.09106865472027234, 0.15831706619688443, 0.06522924732416868, 0.18802455067634583, 0.1586993256849902, 0.19493096508085728, 0.13065932744315692, 0.07724943411137376, 0.11681740305253438, 0.1786794135613101, 0.14651399025959627, 0.12316967147801604, 0.3064688907137939, 0.09944999390946967, 0.16648114525846072, 0.16869140522820608, 0.08256303505705935, 0.11828822270035744, 0.08526969767574753, 0.12861924405608857, 0.17436934555215494, 0.14825219341686793, 0.1261714289763144, 0.11424384186310427, 0.14096388593316078, 0.04069437439154301, 0.15437807541872772, 0.1833768165005105, 0.09980049117335252, 0.10649189818650484, 0.078514026610979, 0.18271448489810738, 0.11759015944387231, 0.11888637846069676, 0.17609684142683232, 0.1644594773117985, 0.2019816767424345, 0.13033706402140005, 0.1256203499755689], [0.06477567380560295, 0.07881727069616318, 0.03869741190490978, 0.018968705985961214, 0.04050821491650172, 0.05362636296610747, 0.02860904824254768, 0.02734499517828226, 0.03456346444519503, 0.021755853035886372, 0.04858091227444155, 0.0594378084476505, 0.03620311378368309, 0.03582189923950604, 0.06926593357431036, 0.022737157165205905, 0.03509279639859285, 0.00296826013280744, 0.00896746282731848, 0.053832966701260636, 0.021860252433855618, 0.037712504754641225, 0.06753238516726665, 0.07270735462329217, 0.03593111623610769, 0.012109800058949207, 0.05621467889951808, 0.02534467394330672, 0.032916368184877295, 0.010367511272696512, 0.02496616166484143, 0.02667822765319475, 0.02240758083228554, 0.017209590379414812, 0.02594811549144132, 0.011144354989353036, 0.007989520839016353, 0.04333981279549854, 0.022153294745034406, 0.015551084552758505, 0.019422773138753006, 0.034642476455441544, 0.046118030324578285, 0.03731342438342316, 0.0221326638877924, 0.05262122190158282, 0.0467447083044265, 0.039950282712067874, 0.05496049173442381, 0.03152510676799076, 0.0248236014574234, 0.009054888671796237, 0.0674647827233587, 0.07155744132718869, 0.03188666415267757, 0.015491862016330873, 0.004184759978670627, 0.02422803091550512, 0.03868066905332463, 0.010977525280655494, 0.029672302438744476, 0.004744208708871156, 0.04742260889283248, 0.015803959287170852, 0.05069204506331256, 0.022272777976468205, 0.02070724162539201, 0.06579130502151591, 0.03464467830157705, 0.045071563084742854, 0.012129028045040156, 0.024332223360293677, 0.015200139455763357, 0.018698453969721283, 0.049342784964080365, 0.0428886582542743, 0.03742905353595104, 0.028050271262015616, 0.0332226554996201, 0.02807450683654419, 0.019947034739223973, 0.02608575971264924, 0.0262855153331267, 0.040189649510596476, 0.013841520662286451, 0.03533784932057772, 0.020040453744253943, 0.039224993237959485, 0.07130880574030535, 0.0208301192282566, 0.07674503153456108, 0.04172137785436852, 0.033647740725427866, 0.0076142468689275634, 0.03755784626784069, 0.028748348089201108, 0.06336124720317976, 0.048609173257968256, 0.07160879964275019, 0.007182766450569034, 0.011683160987948733, 0.020083854540384243, 0.03925432291414056, 0.043486132086919885, 0.008771511243789323, 0.060711126907595565, 0.030342298094183207, 0.029254385935408727, 0.0657929674323116, 0.006948165936462049, 0.029256333330912248, 0.024822305455537777, 0.034037006087601185, 0.013415211528938795, 0.029795029067567418, 0.019890315997015153, 0.022608028558482016, 0.012825559508720679, 0.022079783957451582, 0.026763580573190535, 0.04961220747126, 0.07109298410692386, 0.038499534130096436, 0.01152025830067162, 0.0876083229003208, 0.08715983160904475, 0.015428870217874646, 0.024736871111339757, 0.02448677158515368, 0.007568263398882533, 0.012688520031848123, 0.042482992700700245, 0.029779307411185334, 0.010635524123374904, 0.04001862136647105, 0.06941164218421493, 0.022146884285445725, 0.03397521190345287, 0.053493064761693986, 0.006834106744333569, 0.03527956994782601, 0.011312953129942929, 0.017467247089371085, 0.038257795851677656, 0.09254029539546796, 0.03933163858684046, 0.032936534245631525, 0.007643702074087092, 0.03015387909752982, 0.041795752077762566, 0.06261125566171748, 0.04641302003126059, 0.017244270304217935, 0.05088822650057929, 0.04072843684947916, 0.04169758502393961, 0.0041211990589675096, 0.02364045351610652, 0.04400577116757631, 0.051354281670813046, 0.012853260700857001, 0.06879182758608035, 0.032971851993352175, 0.007703198569028505, 0.03933737899309822, 0.04587041593289801, 0.032249269873968194, 0.020167444965669086, 0.05594764822827918, 0.01733815749841077, 0.047254176145153384, 0.03708318727357047, 0.01999454915390483, 0.02729680562125785, 0.08805504321519818, 0.04000029752829245, 0.00960172598050641, 0.025987942104360888, 0.0566573110409081, 0.08686332537659577, 0.029257018651281084, 0.08509226755372115, 0.07145822593676192, 0.016752135640542423, 0.03180729591154626, 0.02816485716695232, 0.009019695604885263, 0.026321262254246643, 0.028182977444625328, 0.11834162340632506, 0.08867073910576956, 0.028750739925141846, 0.025749867915042808, 0.01350579595392836, 0.023557762149721384, 0.07873138851885285, 0.03206471174157091, 0.07236930169165134, 0.05654332733580044, 0.052095482791108746, 0.046355334376650195, 0.007182535748662693, 0.0345008729823998, 0.024895387069721307, 0.10814137610473804, 0.016155606667910303, 0.05011671861367566, 0.013979791680217853, 0.02531146304681897, 0.05344780647595014, 0.04634084765400205, 0.02102142708775188, 0.029131554133657898, 0.019069795829377005, 0.020147078737084354, 0.023305206326767802, 0.03090001316741109, 0.022591457036989074, 0.04321828378098352, 0.05369637081665652, 0.03862332945157375, 0.008522281090595892, 0.029509253866438354, 0.028913157459880625, 0.014936418339077915, 0.023369142985237495, 0.059022470377385616, 0.016744324006140232, 0.02848035729091082, 0.05220696609467268, 0.015251328137570193, 0.03156400378793478, 0.03938321403360792, 0.04210433962621859, 0.02040216719199504, 0.08733719387756926, 0.05978022435946124, 0.027649275725707412, 0.015024183451064994, 0.01042918671321656, 0.053725527466407845, 0.018814225614603077, 0.08062811102718115, 0.04371856765023299, 0.057787597711597166, 0.02104673644394747, 0.002210709499195218, 0.018665563681029847, 0.03573617651792509, 0.06834274596933808, 0.054988586476870945, 0.04763195390946098, 0.06914322730153799, 0.04628616451684918, 0.046495702915958, 0.012140020312342261, 0.03388212707691959, 0.017949035790349756, 0.05577143607661128, 0.058682639683995924, 0.08415101056120225, 0.019452669391674653, 0.004659442297582115, 0.02661040977441839, 0.032645948231220245, 0.06730220573289053, 0.05224125246916499, 0.043759578306760104, 0.007143497932702303, 0.04774151017357196, 0.017198940772297125, 0.052774899905281406, 0.07755983674100467, 0.026248962651672106, 0.05683150115822043, 0.04559923602002008, 0.01772241018313382, 0.030317707985107387, 0.026286024234390686, 0.04350476126585688, 0.021777810429089835, 0.02806902936260615, 0.0331959958587374, 0.06470427156559058, 0.03980682005307504, 0.09903049641954047, 0.016183046624064445, 0.014377870364114642, 0.007310166489332914, 0.03933416612978492, 0.01873962577831532, 0.019903099596766487, 0.047274175964828045, 0.04702707386708685, 0.021949298280690397, 0.03608777640121324, 0.06654203616614852, 0.008895396471156605, 0.03147558049697961, 0.017511979510475482, 0.0400437000207603, 0.0582400652180825, 0.021125658548304012, 0.05315244357500758, 0.04894649676446404, 0.03222118530954633, 0.05364933137648872, 0.07543220198048012, 0.029848490841686726, 0.019383640327890004, 0.021168087343020097, 0.04531215463898011, 0.03139866855261581, 0.03697670477309397, 0.0377057906506317, 0.03999850958851831, 0.11135734710842371, 0.0033417137206665105, 0.025169069080480506, 0.023982033133506775, 0.08847527352294751, 0.004177371156401932, 0.051469656372708936, 0.05118214412193213, 0.041297795583627055, 0.02558052762677627, 0.02557716887843396, 0.0689238840714097, 0.061397526147110124, 0.034903169609606266, 0.029655705472188335, 0.031779577756034474, 0.02732424727374954, 0.08153954640563045, 0.010108840152887362, 0.012479343800805509, 0.01348995216124292, 0.036144040524959564, 0.012220016198365815, 0.028012588819754974, 0.023203558388299177, 0.044484050146171024, 0.04142176393153412, 0.03398252311827881, 0.0063312554682072785, 0.06324630337102072, 0.08182036490844828, 0.03620058284806354, 0.017969690396317413, 0.00859150184052331, 0.03600774998111384, 0.0030878814037090963, 0.1699355806091002, 0.22052766728614057, 0.29943997359701563, 0.2617904809968812, 0.12878336810639926, 0.15610857041818754, 0.11402688707624163, 0.12566104850598744, 0.0831804069291268, 0.13313931865351541, 0.17684564553201199, 0.2024369194571461, 0.15682560551379407, 0.15582944825291634, 0.16142928919621877, 0.08275987806596927, 0.11107281023370368, 0.09413787217012473, 0.07233168371021748, 0.22294900592948708, 0.12171364389359951, 0.18565752197589191, 0.12005998619965144, 0.17889506556093693, 0.0980011180841497, 0.1317289700465543, 0.1355025339871645, 0.17150862834283284, 0.2537621632218361, 0.10841521926756416, 0.0704917749390006, 0.06818681862205267, 0.25526731674160275, 0.18210874311625957, 0.1377722607659442, 0.08047569170594215, 0.19111166787999018, 0.12042020687035151, 0.1072486275807023, 0.06464244345469133, 0.12368998570101601, 0.10813785450799124, 0.1991030733500208, 0.12265372702053615, 0.11904332361051015, 0.10496727071170296, 0.10047724164490189, 0.12369614679898534, 0.10901267613683428, 0.10569742867457015, 0.15977284950869425, 0.12087661666529519, 0.19733855660472596, 0.11599168021764074, 0.10339213987546307, 0.09684154244938067, 0.08561839003648077, 0.15785326037023747, 0.10485590954444238, 0.08812582798834358, 0.1439532126699175, 0.11541649965303284, 0.11564536951482296, 0.08619844926787273, 0.10844917994524751, 0.08520020211913756, 0.184924717726452, 0.1767882007573332, 0.09272903669625521, 0.08882999805999653, 0.15044610069266387, 0.11196980638695614, 0.07048924400338105, 0.11533111280628613, 0.0825825904362968, 0.17516951475824627, 0.1527549246592181, 0.17586498601096018, 0.15164641556995256, 0.1070436964343701, 0.10671204208795514, 0.11349381639489106, 0.11850075343889849, 0.1163946350238153, 0.10684462104524885, 0.08390376597110714, 0.11721039696463517, 0.09648304525762796, 0.27096470871141976, 0.14013105205127172, 0.09497458727232047, 0.12899896582322462, 0.12218791273023401, 0.10688426784638848, 0.14791823205138954, 0.15332174567239626, 0.12038766433085714, 0.13167793064245156, 0.1443597094288894, 0.14523345897240297, 0.12941672626350606, 0.12842903711966105, 0.1385523724768843, 0.11190764579389777, 0.09348999336361885, 0.17324517587465899, 0.08998590282031468, 0.10736925075096743, 0.1547793745994568, 0.14808140615267412, 0.14729440052594456, 0.1647703413452421, 0.21347844840160438, 0.18277786006884916, 0.1027479183727077, 0.077828156628779, 0.15520250903708593, 0.11911676824092865, 0.09726205774183784, 0.06954717955418996, 0.07708712853491306, 0.08491162796105657, 0.12098192530018942, 0.09416847409946577, 0.17590139620006084, 0.12400334674332823, 0.050521267977144034, 0.1099714393328343, 0.0857753080448934, 0.07085390907845326, 0.14646958692797593, 0.15539600008300372, 0.10876804390656096, 0.10960040281393699, 0.11222356491323028, 0.10795206483453512, 0.15469439487372125, 0.1256163330482585, 0.12145945110491344, 0.09674260525831155, 0.12103525815265519, 0.17555284633168153, 0.11717617165829454, 0.10130901022681169, 0.1646548682557685, 0.09820450217063938, 0.1132841422887785, 0.15534737626356737, 0.11814009850578648, 0.08336628481213536, 0.1086033566721848, 0.10808580408671073, 0.13317568813051495, 0.0821264927674617, 0.12643050721713475, 0.09582101221063308, 0.05873884952494076, 0.14055429505450384, 0.12257574977619307, 0.11569467186927795, 0.1593993566930294, 0.1502180586435965, 0.11550218505518776, 0.04870512489495533, 0.23513482990009443, 0.18392123228737287, 0.19768570869096688, 0.1649653794510024, 0.10430263887558665, 0.22648964236889566, 0.16174119817359106, 0.10189917962998152, 0.1036416372018201, 0.11141705140471458, 0.16072654404810496, 0.14956530795565673], [0.01169478429281818, 0.011621092845286642, 0.08461411749677998, 0.012219629433405186, 0.03883226056184087, 0.07593788698847805, 0.023549078597820232, 0.01459681665125702, 0.06624114659747907, 0.01372081776415663, 0.03252288233488798, 0.032123072538524866, 0.02031270574246134, 0.01442464517562517, 0.008024408565168934, 0.03193478924887521, 0.020490732975304127, 0.04753915746031063, 0.06040994556886809, 0.06663053748863083, 0.030487446912697384, 0.04650408960878849, 0.06919864325651101, 0.009249377164191433, 0.029339888133108616, 0.05578153946303895, 0.025150383922404478, 0.06061718373426369, 0.04178586921521595, 0.021599041896739175, 0.03830882507775511, 0.005429839083392705, 0.06412119285336562, 0.017993853028331484, 0.040917883826685805, 0.03163532121106982, 0.014527767231421811, 0.006566293637401291, 0.03316406060808471, 0.049918830660837035, 0.033381680359265635, 0.07496430458767073, 0.03156819034899984, 0.03980727806421263, 0.03172376825075064, 0.03290620373029794, 0.013746429916604288, 0.04867983928748539, 0.042932949627616575, 0.021084590216300318, 0.03367170997496162, 0.04674067780641573, 0.03422528598457575, 0.06323539252792086, 0.046595281322619746, 0.05179624884788479, 0.0047768593898841315, 0.020626684251640524, 0.03780662434707795, 0.04189365789560335, 0.05181181104853749, 0.02454947161355189, 0.04305208341351577, 0.04514802719599434, 0.058544598519802094, 0.03132255049422383, 0.016783913131803274, 0.021639214562518255, 0.03884028423843639, 0.005052947231368827, 0.056386490751590045, 0.028917103141014065, 0.028219747257285883, 0.02598887000099889, 0.03457742530320372, 0.060964987214122496, 0.05841011966445616, 0.0466304430072861, 0.008041616213241858, 0.02916283459801759, 0.029263861676944152, 0.03978737323944058, 0.022887018409424593, 0.016714531229808927, 0.023793536105326245, 0.008306390755543751, 0.04977067593219025, 0.08391259371169976, 0.03708976906325136, 0.06176806055009365, 0.02503292272532625, 0.019590145675465465, 0.0490795540889459, 0.03712236249287214, 0.025325939591441835, 0.008805885827834052, 0.012903331496220614, 0.023810233155797635, 0.06018917062985046, 0.05879895415689264, 0.06254509849739925, 0.0715278164882745, 0.037661523026015074, 0.015137939846941402, 0.03414434014952608, 0.028633736739201204, 0.08732333140713827, 0.08258140978536435, 0.010321475216187537, 0.026201974101630703, 0.026944310071745088, 0.0315820155000048, 0.020674171524920633, 0.034915142360010316, 0.04012182654280748, 0.04924957121589354, 0.03828346822410822, 0.051220447423734834, 0.05084142454766801, 0.019569803195606385, 0.014967334090865083, 0.035450011159160306, 0.04635891704154866, 0.024546698101663163, 0.03410370607993432, 0.024733802436717918, 0.01753952124688242, 0.03160203567573002, 0.0011933280870185367, 0.049218680909169574, 0.037367744504341056, 0.05248259719727295, 0.03470366335074816, 0.031213221539344107, 0.014014262107333966, 0.06460537508662258, 0.03266256555382695, 0.07072850902165685, 0.021729435971272842, 0.010704442077050251, 0.028233618209404603, 0.042155199218541384, 0.04444032874224441, 0.06487879077238695, 0.03256000159308314, 0.06725210949246373, 0.015309278420837862, 0.038331203162670135, 0.06498502221490655, 0.06705784491662468, 0.01616445985356612, 0.08682584988751582, 0.03392126497679523, 0.022947255355705107, 0.022829997719132473, 0.005828989428534571, 0.0330688825010189, 0.04906659407008972, 0.008880208312932934, 0.044768200255930424, 0.03361336614138313, 0.04623576972101416, 0.021640213705333214, 0.007521102670580149, 0.05000371539166995, 0.011344272610066193, 0.024472842957558374, 0.024131587340629528, 0.07535362762532063, 0.034786973880337815, 0.02109409309923649, 0.020793702253805738, 0.05234475280823452, 0.04016838422311204, 0.023376343938122903, 0.042936484795063734, 0.00436611457761111, 0.03070154506713152, 0.0639642680596028, 0.03743384738585778, 0.0462656218691596, 0.010094378027133644, 0.019219114245580773, 0.01529035747184285, 0.06185867211648396, 0.0513732840440103, 0.027037518730919276, 0.02624433843552002, 0.06258255363042865, 0.0513381902128458, 0.022515474685600827, 0.024781247301559364, 0.02354193023139877, 0.03894554198320423, 0.0513186110848827, 0.00925322445774717, 0.028941357375255654, 0.015941749393407787, 0.027460122214896337, 0.024697370195229138, 0.013655090621406478, 0.014107319792466504, 0.0494564802918051, 0.02805599131222282, 0.03180851388190474, 0.013669848758062082, 0.039103501542870484, 0.03107453915955765, 0.023368120093696883, 0.03636863900880728, 0.0495520180224308, 0.07385110682142632, 0.03027942164668015, 0.04103319746043001, 0.08607337490788528, 0.08952051600707428, 0.06591410628919091, 0.03383115552631872, 0.04074293375015259, 0.054055434585149796, 0.022248559365315095, 0.051026919058391025, 0.03929039044305682, 0.0765846733536039, 0.05868548953107425, 0.005433256355380374, 0.04051236076546567, 0.0066138148374323335, 0.0953177088605506, 0.08199098253888742, 0.04993948865947979, 0.05136478878557682, 0.02893750668902482, 0.04995992952691657, 0.026267106678070765, 0.026632631796279123, 0.049911217497927804, 0.03473435688231673, 0.03332198963367513, 0.0627932862511703, 0.03224600612052849, 0.058386778059814654, 0.04046988108062318, 0.05072258931717702, 0.04069061191486461, 0.011759466491639614, 0.07477345304297549, 0.036420482476907115, 0.016135705235813345, 0.01070589414199016, 0.02618044418548899, 0.053399901903633556, 0.028831254890454665, 0.05522668780758977, 0.058852002024650574, 0.037244145958019156, 0.019812968093901873, 0.021297528075852563, 0.01783828021559332, 0.060584980462278636, 0.028127247667206184, 0.01699184679559299, 0.03143390826880932, 0.02068156416394881, 0.053389968150960546, 0.037636478298476765, 0.03479765062885625, 0.023803946528849856, 0.030617165844887495, 0.02350845979526639, 0.025399089059127227, 0.004160194042404848, 0.025699686857738664, 0.08732885468219008, 0.03221510224310415, 0.017228060102622424, 0.04149197194991367, 0.010873032584121185, 0.019642772851511836, 0.062213715564991744, 0.062016920053533146, 0.004205926878577364, 0.03010469548670309, 0.028344470475401198, 0.01715084451383778, 0.03682089277676173, 0.03241043211892247, 0.02551134758894997, 0.01774416401583169, 0.023896530935806886, 0.03248723549768329, 0.025220999061795216, 0.04020917774843318, 0.01515022133077894, 0.027416809628318464, 0.05176565709656902, 0.013054174071710025, 0.013778892728233976, 0.027270210441201925, 0.03577474784106016, 0.02870191933055009, 0.03161264796342168, 0.025259436374264102, 0.014032440060483558, 0.06561094362820898, 0.02975173174802746, 0.03706330619752407, 0.02149340247602335, 0.0076510701162208405, 0.01916901291614132, 0.03353318365822945, 0.004533302637615374, 0.03510164110256093, 0.05916339531540871, 0.0358886908340667, 0.050394792442343066, 0.0034858551267201877, 0.014490127197599836, 0.06554033527416842, 0.05629103783784168, 0.0564978145994246, 0.03980343755600708, 0.024981616996228695, 0.024435823783278465, 0.0680620971002749, 0.03660722888473954, 0.015723317096542035, 0.04225312878510781, 0.00666960610708754, 0.02782952685707382, 0.04799579795716064, 0.0070019754597784156, 0.058040243440440724, 0.014785176276096275, 0.03447703265451959, 0.03796160853068743, 0.02336106332950294, 0.02839709086609738, 0.02847376193052956, 0.03314755524375609, 0.02784852753393352, 0.059530170634388924, 0.040957713832280467, 0.0024607926981324063, 0.04986358433961868, 0.06972200410174471, 0.02844128045918686, 0.03420367803690689, 0.025893512082153132, 0.04490058243806873, 0.03746650188363024, 0.03993302756654365, 0.06771623423056942, 0.12089170728410993, 0.17314609619123594, 0.1183609345129558, 0.15720961562224797, 0.13378978946379252, 0.14309549012354442, 0.06107478096549, 0.13012749169554028, 0.07064840796270541, 0.11531828849443368, 0.09390570462814399, 0.14504546406013624, 0.07849638470049415, 0.1871451421507767, 0.09026248047926597, 0.058626687686358175, 0.15936293293322834, 0.16889937621142181, 0.08463033448372569, 0.08682745801551, 0.13508751482835837, 0.18919396506888525, 0.15800257878644125, 0.14281723648309708, 0.09123258199542761, 0.11687935329973698, 0.13835126826805727, 0.12625430524349213, 0.12178890699786799, 0.08080451656132936, 0.23010604402848653, 0.11943737603724003, 0.09885324950196914, 0.1137500312179327, 0.2621916037585054, 0.1227564165102584, 0.2281589742217745, 0.0948279762108411, 0.23345076026661055, 0.12897394145173685, 0.11630202856447015, 0.15501494838723115, 0.1170331636177642, 0.1799490475761039, 0.129997402961765, 0.1826634726354054, 0.17074412293732166, 0.1476913435118539, 0.07347992781017508, 0.0994486707661833, 0.22767728221203598, 0.15235362547848905, 0.18867918769163744, 0.17872397974133492, 0.14945370251578943, 0.09743175256465163, 0.09705136583319732, 0.10201731936207839, 0.1696961120303188, 0.11343322321772575, 0.11436307403658118, 0.15583075104015215, 0.1802114506385156, 0.17052123775439604, 0.10880073572375945, 0.09009303671440907, 0.10278608596750669, 0.13786958982901915, 0.12432436166065079, 0.1519342636955636, 0.06674765263284956, 0.06799476607037441, 0.09917750781668083, 0.09464660380035639, 0.17127511730151518, 0.13509184388177736, 0.15296670900923864, 0.18345872924796172, 0.15066965083990777, 0.0776905972244484, 0.10146747529506683, 0.06685002321111304, 0.1704389585980347, 0.1099432801295604, 0.09344204129385096, 0.10549289786389895, 0.12628603354096413, 0.17039739154279232, 0.20590704253741673, 0.11164436063596181, 0.09343940857797861, 0.1719338662390198, 0.20720754989555903, 0.1482939233205148, 0.16646023280918598, 0.08738813828676939, 0.1467359797762973, 0.11469791749758379, 0.19668776009763989, 0.1221826472984893, 0.08911885041743517, 0.17941060289740562, 0.14110246992536954, 0.12497276972447123, 0.11042008668716465, 0.2189750298857689, 0.20141522213816643, 0.07753852395606892, 0.14938846815909657, 0.11269287365887846, 0.1937651333532163, 0.07943477827523436, 0.137732702174357, 0.18401989127908433, 0.12322905686284814, 0.19019232078322343, 0.21641851349600724, 0.18915116307990892, 0.1736679846154792, 0.07998486661485263, 0.1012914768819298, 0.19800436230642454, 0.09184421346123729, 0.1839151797550065, 0.09829113073647022, 0.21062029605465277, 0.11560681515506335, 0.14540959309254373, 0.13075776930366242, 0.1130561273811119, 0.09982719152633633, 0.17549177818000317, 0.1805638274444001, 0.07886975537985563, 0.09354595214660678, 0.1134651279343026, 0.15916172015879834, 0.08871484388198171, 0.11369517844702516, 0.15614872612059116, 0.17731274903884955, 0.14761409908533096, 0.11570892110466957, 0.13461347669363022, 0.12990440295210906, 0.13727075553366117, 0.11571133668933596, 0.13809756402458462, 0.17756064502256258, 0.14787272949303898, 0.1686311513185501, 0.09729761976216521, 0.13106564778302396, 0.09678907812173877, 0.07882511456097875, 0.2910846290843827, 0.12975614305053437, 0.07769831216761044, 0.11129115601735455, 0.10399257551346507, 0.12964527042848722, 0.11508640593716077, 0.05524451970787985, 0.08761691315365688, 0.20205882617405482, 0.21708786115050316, 0.09809934281344924, 0.18951211656842912, 0.21982796197491034, 0.12027832519795213, 0.0792502099648118, 0.09896143512534243, 0.11840422504714557, 0.14174601967845643, 0.10722031909972429], [0.035457895736077, 0.04067903610744646, 0.01681684922160847, 0.03141402719276292, 0.01354714757430234, 0.06136838985340936, 0.040087166974054914, 0.05062272931848254, 0.06957231927663088, 0.05439416605180927, 0.06556646565773658, 0.02032443761293377, 0.03663779688732965, 0.03207363108439105, 0.029456599548991238, 0.029615013727119992, 0.050937532247709374, 0.025699710606464317, 0.04120299406349659, 0.009822709569042283, 0.005922208689818425, 0.024711332749575377, 0.018010076800627366, 0.03703815968973296, 0.005307229925944869, 0.021166480911363448, 0.06888287341488258, 0.0687386847234198, 0.06305039674043655, 0.03539458163348692, 0.04120071418583393, 0.04469925770536065, 0.055835703520902565, 0.06446194635438067, 0.014358968074832643, 0.043413549195975065, 0.022627192083746195, 0.024907520972192287, 0.05237475084140897, 0.055804199139986715, 0.010246436028475208, 0.01994683457139347, 0.06473195579435144, 0.021120165807328055, 0.06401268153318337, 0.005495703629484134, 0.04090807221031614, 0.00877080047835729, 0.0440588427840599, 0.04202128015458584, 0.011831137601153126, 0.04040453476565225, 0.06661510760230677, 0.044899361075035164, 0.03213596470387919, 0.041360743277307065, 0.0222436874838812, 0.010326764396657901, 0.09434250476104872, 0.04423648325194206, 0.04981162212789059, 0.04543839268652456, 0.07918631232210568, 0.04681081797129341, 0.03622892864846757, 0.04376661471490349, 0.02624174134273614, 0.024380038026720285, 0.01139440871442535, 0.02484418820988919, 0.0323878267247762, 0.0620762307995132, 0.07046457925545317, 0.07918666516031538, 0.035232903701918464, 0.013153146037698855, 0.035728302119033675, 0.019091760007930652, 0.03251724370888301, 0.04760570138958948, 0.04072325623461178, 0.1153875533491373, 0.031054712366312742, 0.012114432756789029, 0.03432911880580442, 0.09261715305703026, 0.057485432497092655, 0.03245238254645041, 0.017306938102202754, 0.02917025437844651, 0.026347005872854164, 0.03574804070272616, 0.05343375401571393, 0.005272863399503487, 0.03701808862388134, 0.02878133167645761, 0.015658505127898285, 0.01755325649199741, 0.0098056562876861, 0.02716099174826273, 0.03596887670989547, 0.05313071009836026, 0.04937740382073181, 0.019172782178169916, 0.0226285457611084, 0.029103947936424186, 0.06666090871606555, 0.015839205788714544, 0.025884450246979083, 0.033467430222247324, 0.10699867563588278, 0.030793656195913042, 0.04049050175983991, 0.08300590807838099, 0.03210541705733963, 0.04249166777091367, 0.08258986433169671, 0.036786012684128115, 0.030587015141333853, 0.017288125718810728, 0.02098741043092949, 0.023389166553637812, 0.022043124406731555, 0.0630639267287084, 0.038065834902226925, 0.07149110095841543, 0.004557050515099296, 0.02253963053226471, 0.014163126753244017, 0.012705757365828114, 0.026321503134178262, 0.09205418612275805, 0.0443638273115669, 0.013656406131173884, 0.011055829918145068, 0.015333449534539665, 0.03952028489272509, 0.0732412531173655, 0.04524738847145012, 0.014644680511472481, 0.006806227012670466, 0.019345737361748303, 0.06794578262737819, 0.04206095409712621, 0.0062746601345549735, 0.02313823582205389, 0.05356609209307602, 0.03662793438083359, 0.015685760183259845, 0.030575096673731293, 0.04794243796329413, 0.03423246827774814, 0.06117010835025992, 0.016246026548157846, 0.0432940964986171, 0.025992718990892172, 0.01493408078593867, 0.01839144740785871, 0.019667486793228557, 0.03594573527308447, 0.0507667280201401, 0.03362938974584852, 0.030679719988256693, 0.041822503320872784, 0.0355972091534308, 0.07253177011651651, 0.04802837781608105, 0.05747008403497083, 0.03550971545545118, 0.03396042662539652, 0.02636955868053649, 0.05836473245705877, 0.018203988538256714, 0.037511322514287064, 0.06106530183127948, 0.027570899842040877, 0.01981823013297149, 0.03117959334381989, 0.026191636620621597, 0.0640581976622343, 0.04482914627130542, 0.031289295492959876, 0.04623213955866439, 0.09369186431701694, 0.05693001765757799, 0.021977978259591118, 0.016644974605047276, 0.024820751610345075, 0.036568386147597005, 0.06838260990168367, 0.04679329141176172, 0.022649588828374232, 0.018935110020850385, 0.03796997147479227, 0.04570889067170875, 0.07077624396021877, 0.021111638318481188, 0.0234532813275499, 0.032527564226516655, 0.0385725953882294, 0.008231544102142965, 0.03584645202915583, 0.0733388400237475, 0.032981823065451214, 0.053381103090941906, 0.015439324746174472, 0.05025256471708417, 0.02170280347179089, 0.02779417857527733, 0.014694043934079153, 0.010945478919893503, 0.01689800200983882, 0.0175935241526791, 0.022962593639801656, 0.02259309739539666, 0.040848958239491494, 0.046899597493133376, 0.03919322762106146, 0.030299438429730277, 0.03919681028595992, 0.03488745813124946, 0.007750909758864769, 0.084585191548935, 0.008744196816613632, 0.05990884745759623, 0.09729102440178394, 0.08873665878283125, 0.04192037860463772, 0.030936260508107286, 0.04725850519857236, 0.02778869601232665, 0.04037808207795024, 0.0475944953837565, 0.02779845504223236, 0.021966969028913548, 0.028497208708098958, 0.012921281291970184, 0.06632597704551049, 0.060727961361408234, 0.03522451361641288, 0.03230018035641738, 0.023542861520711864, 0.03142103985218065, 0.0071331943784441266, 0.06436400660978896, 0.03890162380412221, 0.013227831539032715, 0.04838700732216239, 0.055264563632330725, 0.023017005362947072, 0.04003371537796088, 0.024313833364950757, 0.030474649742245674, 0.024415447376668453, 0.0427055691501924, 0.06803745270839759, 0.031183179401393448, 0.060299968613045554, 0.006487673057043659, 0.03488156844728759, 0.027826826287699596, 0.04769918315910867, 0.035244594860289774, 0.08246250330869641, 0.10967213075075831, 0.007458086275229496, 0.03428210650703736, 0.020616728446579406, 0.044445458466985395, 0.01817795823860381, 0.0056734382441001275, 0.027395790309778283, 0.04145702061110309, 0.022761438540848236, 0.02527362114882895, 0.014221574063412845, 0.03986520799142974, 0.022422457712569406, 0.03197620363373842, 0.01370746928400227, 0.024702540632071238, 0.03495207841375044, 0.03535234961392624, 0.047044037242553065, 0.03096282176141228, 0.031307890745145936, 0.02222760790027678, 0.032770035322755575, 0.033988419587590864, 0.02627432289799409, 0.011906782381369599, 0.02569658256002835, 0.043227725595768006, 0.026495148727138127, 0.003324629693192297, 0.07629803980567626, 0.023042491138247505, 0.018375595133485537, 0.002515942328110603, 0.06249774353844779, 0.03939603156011019, 0.024978660279884934, 0.0030897439823352863, 0.08124511649033853, 0.04893153167462774, 0.031864869607878585, 0.08108531470809664, 0.03344212086605174, 0.015337491906913263, 0.037586242958371124, 0.024331495631486177, 0.04205552242430193, 0.010847033666712897, 0.04467933591721313, 0.009430009123337055, 0.03189525440601366, 0.03378010255151561, 0.11218347706432853, 0.06999334347035203, 0.002060327479349715, 0.0817371222323605, 0.0364549316998039, 0.0554784921530102, 0.04534563355680023, 0.04573120429579701, 0.007846291426436176, 0.06567967244024787, 0.028322104264848998, 0.045611375011503696, 0.039111796633473465, 0.05149062989013536, 0.0536509462898331, 0.007776964655412095, 0.05845733891640391, 0.019411334734676138, 0.0067039747539508554, 0.040407703524189334, 0.03068089046116386, 0.015804064460098743, 0.046930908491568904, 0.04013714786352856, 0.02945667758051838, 0.037034746658589156, 0.07831303096775498, 0.04905634479863303, 0.028094053734093904, 0.03194701305723616, 0.041963784489780664, 0.005190080006806446, 0.014037694466034216, 0.03283675567113927, 0.04088451347446867, 0.060254025006932874, 0.10966403582798583, 0.11560598734234061, 0.14317790498690947, 0.1803654238049473, 0.21306272356637887, 0.15436576679348946, 0.1073773524590901, 0.14703878281371935, 0.10004055007760014, 0.15424785097794874, 0.10163325497082301, 0.11144692730158567, 0.06395170837640762, 0.1685077529400587, 0.10777761348124061, 0.14022209788007395, 0.10767346514122826, 0.13639896017100128, 0.16055886447429657, 0.0884164445368307, 0.15448756382933684, 0.13914641631501062, 0.12554875096040113, 0.07784490965838943, 0.10281433338033301, 0.19896130024322442, 0.12444681009011609, 0.15604077119912418, 0.1353428339851754, 0.15732324309647083, 0.11061891780367919, 0.16191734586443218, 0.16045645996928215, 0.08274601559553828, 0.10591830539384059, 0.19869403887007916, 0.07168156573815004, 0.11452297759907586, 0.15890171911035264, 0.16666850234780992, 0.1302176961409194, 0.17424738566790307, 0.10393353618149247, 0.14598436653614044, 0.10577433383358376, 0.17744017791535172, 0.08591657225042582, 0.12089655202414308, 0.19214627093502454, 0.187687006645969, 0.14892388880252838, 0.16656072384544782, 0.17983756427253994, 0.09757932036050729, 0.1256745242114578, 0.14257839215653284, 0.23962711170315742, 0.180894314710583, 0.2072669081389904, 0.13443705758878163, 0.16822932288050652, 0.09243845407451902, 0.11292535332696778, 0.10575531449701105, 0.14929740875959396, 0.13312102534941264, 0.07318604072289807, 0.10930828670305864, 0.05432687573400991, 0.13539828386689934, 0.12294989398547582, 0.12740512777652058, 0.10853850908045258, 0.10122532650296177, 0.1324440645320075, 0.1305691229977778, 0.08552895233567272, 0.12978185952774116, 0.1694637137864317, 0.11892472925995078, 0.22791508159467153, 0.08032206459236996, 0.09263214189559221, 0.1449827809951135, 0.2120041682251862, 0.10372895108801977, 0.1417275635259492, 0.20366556995681354, 0.06858289986848831, 0.12715264489608152, 0.13776330410369805, 0.20597948293600762, 0.11525301342563969, 0.15801658374922617, 0.11533761317176477, 0.1330699316625084, 0.0971086545448218, 0.06555788218975067, 0.18055054172873497, 0.262890956231526, 0.15139283346278326, 0.12252000133906092, 0.13046035383428845, 0.09436146981481995, 0.12115571168916565, 0.11362591359232153, 0.12986538718853677, 0.10057476069778204, 0.11954993142613343, 0.23897064264331544, 0.1610711719840765, 0.16584766496505055, 0.1429950940821852, 0.10903529849435602, 0.09674106498381921, 0.10421672955687557, 0.11754826669182096, 0.20111796951719693, 0.09577126202306577, 0.1077636085184557, 0.1033980499154755, 0.06510498042085341, 0.26236441305705477, 0.07954853467111077, 0.18940992919462069, 0.06990852659302098, 0.22315971819417818, 0.12098104320466518, 0.14369876203792437, 0.11308850707220179, 0.21148880730782235, 0.09214859748525278, 0.134751952120236, 0.09989836306444236, 0.12216667458415031, 0.1411978312368904, 0.16722050415618078, 0.12477843729513032, 0.14149269541459425, 0.1208731968488012, 0.15702006007943833, 0.14706000738910266, 0.08155454202954258, 0.16890434308775834, 0.11495599150657654, 0.12009658637855734, 0.20267957715051516, 0.09091167564370803, 0.12258614493267876, 0.13248468163822377, 0.1456271857023239, 0.13685758199010575, 0.11054796339677912, 0.10249743038522345, 0.17330312276525156, 0.0835876568619694, 0.1318544718836035, 0.09487688501498528, 0.08888075926474162, 0.09404788485595159, 0.15397859471184866, 0.09395099684063878, 0.13334894526217664, 0.12346581130155496, 0.17823980429342814, 0.1565567156566041, 0.14667047400559696, 0.12230179804776396, 0.06589910387992859, 0.03896847307415945, 0.07970577159098216, 0.10238503784473453, 0.09703407676092216, 0.15825569948979787, 0.10031010489910841], [0.06304713977234704, 0.027568779420107603, 0.028208783827722073, 0.06165002938359976, 0.04132922871836594, 0.022014234081975052, 0.0301256248993533, 0.10242125125867979, 0.03827727319938796, 0.04891214592914496, 0.050826785154640675, 0.02864773491663592, 0.012818261864595115, 0.0691090834193996, 0.020141419755028825, 0.04021376125248415, 0.011817417623076056, 0.010433414834551513, 0.012440570613502391, 0.036891297570296695, 0.004243966399891568, 0.05746893731078931, 0.007005556852423719, 0.027327432995662093, 0.026123389568445936, 0.06576938834041357, 0.03981971221842936, 0.030420319443302493, 0.010871695021965673, 0.027761820936575532, 0.058694093355110714, 0.03800598132823195, 0.033101099343704324, 0.014000206254422665, 0.03327930299565196, 0.044184727993394644, 0.049769732768514326, 0.029484958920095648, 0.03429961610319359, 0.034709732846489975, 0.0340074762435896, 0.04733360206176128, 0.10701626326356616, 0.03927979511874063, 0.07560368135039296, 0.03327093326619693, 0.04201741250497954, 0.012027675269304641, 0.01452903778824423, 0.009280644906019526, 0.04368030506053141, 0.018924538445259844, 0.05376060094152178, 0.023201731432761465, 0.02363364102451929, 0.011299015172491116, 0.031569062266498804, 0.04046086674290044, 0.07866314146667719, 0.03948861087805458, 0.14602279875959667, 0.051184060983359814, 0.018715666706806848, 0.03801267168351582, 0.023252367108528103, 0.053236788870500665, 0.05348629976755806, 0.05768488786582436, 0.04180881726954665, 0.027420614513435533, 0.027263699897697995, 0.04828773086358394, 0.05542556302888053, 0.062354660859065394, 0.02900446791734014, 0.0184552602336875, 0.010962410064946328, 0.0632555993007762, 0.0315897982966687, 0.022512255036937337, 0.01658819309834923, 0.003139631573243865, 0.051743604708462954, 0.06601708754897118, 0.0519231077549713, 0.06721173665885415, 0.02961539031405534, 0.03203492405425225, 0.051258906788591824, 0.035317354170339446, 0.028677380111600672, 0.0760745100144829, 0.10559076296963862, 0.02752417592065675, 0.019115250890276263, 0.04195931972935796, 0.01870360235417528, 0.03281148363436971, 0.04076069440426571, 0.020816467103681395, 0.0369964230007359, 0.044112725249890766, 0.03658111546454685, 0.023488166509196162, 0.09704317591552224, 0.03949665830337575, 0.06164780378873859, 0.01779583445750177, 0.022892721496256332, 0.13058823054390295, 0.06756022545908179, 0.03652579111180135, 0.007319272429283176, 0.022382307099178433, 0.0554646330752543, 0.03030995572251933, 0.06523131685597555, 0.06470161849366766, 0.044563143580619774, 0.02030854462645948, 0.003152775644723858, 0.028538918255695274, 0.013301319426058658, 0.02863275964877435, 0.014023895608261228, 0.011415223624291164, 0.06616786481546504, 0.012801747170409985, 0.060358716174960136, 0.04897638962471059, 0.036345541676772494, 0.03718591408271875, 0.019290779417912875, 0.031016877253672907, 0.05057998161230769, 0.02793033341211932, 0.029015256624136652, 0.020264943662498678, 0.09214170356946332, 0.06732495701206581, 0.010753303383743125, 0.024374204321897457, 0.05787615331688097, 0.00604559773845332, 0.08055032377264329, 0.07217239761458975, 0.02188193502037653, 0.03538347401523164, 0.024638347826632004, 0.040420931564377885, 0.01357084116898477, 0.04071332248193877, 0.044596578393663676, 0.042281776533595154, 0.015657947032845447, 0.05789462982543877, 0.05173880746588111, 0.08200052952659981, 0.028789742118013755, 0.08158420758055789, 0.05750580890370267, 0.02371527217993779, 0.05470667213999799, 0.03468173309894545, 0.05288582681013005, 0.004426093680584537, 0.015850986852975826, 0.024025003059900234, 0.04858697498483317, 0.025296796512390887, 0.04067183345822351, 0.03129996206345303, 0.012545662965359432, 0.05552901587049876, 0.026074789497735243, 0.025794239016249776, 0.06367949369762625, 0.020492088349003876, 0.025067066607464637, 0.024229533870571425, 0.04979531353871737, 0.032565297558903694, 0.01593234489804932, 0.034846559433000426, 0.05670870667589562, 0.042489075767142434, 0.0032582206227484024, 0.008119435698193098, 0.029715029788868766, 0.015458737633058002, 0.054000829479524066, 0.03432211293173688, 0.025491432586152638, 0.05809205637446471, 0.03264123919819083, 0.056133210592504056, 0.03606185297082577, 0.062051715329289436, 0.05100797096799527, 0.1111217529645988, 0.014700515461819512, 0.054570700507611036, 0.0327576215245894, 0.024863519672570483, 0.023038369038009217, 0.037423811852931976, 0.05433866188728383, 0.03148832338462983, 0.018078513842608248, 0.04135667885254536, 0.028596658193107163, 0.02759745091732059, 0.019349550728553107, 0.028447397452379976, 0.07512173828269754, 0.005431753400314067, 0.03810392107282366, 0.020737485627510717, 0.11371247430465051, 0.027973330479913523, 0.05504549181620989, 0.031201825543705906, 0.05366206408611365, 0.04790215673191207, 0.03346747771969863, 0.007769795084771301, 0.05092607857659459, 0.020333046525982872, 0.02910461290074246, 0.045598218217492104, 0.02362228574098221, 0.045791654980608394, 0.0247424215277923, 0.02897908052961741, 0.0517402154260448, 0.06915042655808584, 0.022235210885160735, 0.04069446599377053, 0.057516427976744514, 0.015569591595392143, 0.038026886992156506, 0.08462672467742648, 0.012127174796270472, 0.018027021516380564, 0.02767107535951904, 0.040919736227286715, 0.023494073156533495, 0.06477177222924572, 0.012060451903380454, 0.02291200546148632, 0.02720662492460438, 0.031859309013400755, 0.02382908625129078, 0.004834381772005665, 0.03104154539427587, 0.011783280526287854, 0.07618505693972111, 0.0636864961790187, 0.057098742175315104, 0.031144200957247188, 0.023869360697322657, 0.04526235016861132, 0.043998850110386095, 0.054252498117940764, 0.032552819299910746, 0.04445344821682998, 0.05806024665279048, 0.02047293839444007, 0.015071801342336195, 0.032360335878495655, 0.0586038346269301, 0.03827104764059186, 0.07683497135128294, 0.022241419480581368, 0.007069636003247329, 0.005886644124984741, 0.08336045619632516, 0.0366453523747623, 0.023699319821649363, 0.046806672122329473, 0.040047231795532365, 0.05171291796224458, 0.033701202499547174, 0.03738597674029214, 0.03155126768563475, 0.05435224276568208, 0.025301200204661915, 0.017824794332097684, 0.014045761399237173, 0.02538665660124804, 0.06064726997699056, 0.02748129590015326, 0.050717496911862066, 0.06497362282659326, 0.034976797444479804, 0.045883396307804754, 0.08092964520411831, 0.019470547093078494, 0.025069407553278973, 0.030974370427429676, 0.06385685596615076, 0.04755812929943204, 0.021539415631975447, 0.027814200447340096, 0.014749302129660333, 0.030179955198296478, 0.04369069682434201, 0.023075428924390247, 0.0650659714426313, 0.042217739791210206, 0.03416232132752027, 0.03317147021048835, 0.019307897160095826, 0.03338551747479609, 0.06307193344192845, 0.06025833370430129, 0.02671220529425357, 0.0421195489886616, 0.007258641932691846, 0.018157378271488205, 0.0025582167561099467, 0.014065404988027044, 0.03884503059089184, 0.03680324408092669, 0.029770866435553347, 0.03480974551556366, 0.08664238080382347, 0.07508604734071664, 0.02150059494722102, 0.05129972406263862, 0.04273987588073526, 0.018283294014898793, 0.013419099534595651, 0.10650420002639294, 0.015565298165061643, 0.016533202924100415, 0.06753136057938848, 0.03447544827525105, 0.011597969220019877, 0.04453723032825759, 0.05313246750405856, 0.02610368830417948, 0.05197623026158128, 0.02801836484910122, 0.04701262107118964, 0.026651038754997507, 0.057315513757722716, 0.009351119249393898, 0.038142801129392216, 0.06859197866703783, 0.02801648700343711, 0.013157004357448645, 0.20383679148341927, 0.09546317998319864, 0.06734196109963314, 0.15162361679332598, 0.18840451671608857, 0.12644075309591635, 0.0717798922477024, 0.12664662062057427, 0.12955349178186484, 0.15730903457318032, 0.11449926958552428, 0.12396572876189436, 0.1725123037717172, 0.08996321260929108, 0.15007756118263516, 0.18423832527228765, 0.13569784350693226, 0.16283955637897762, 0.11984691263309546, 0.14056565373071603, 0.09643060128603663, 0.18432620912790298, 0.1071592645187463, 0.19291369404111589, 0.0967322847406779, 0.11880960900868688, 0.09398359366293464, 0.07808625777917248, 0.1058724092851792, 0.12032177858054638, 0.15984356642833777, 0.10804437273847205, 0.08277252595871687, 0.12363845775169985, 0.08457216367657695, 0.15563443728855678, 0.14757209776767663, 0.1076037660241127, 0.17267152879919323, 0.11220042008374419, 0.05431008538497346, 0.0796297960249441, 0.20342793342258247, 0.13547178278011934, 0.1446682528725692, 0.10438203425811869, 0.1515685333205121, 0.11187967658042908, 0.12055150339645998, 0.1437502492751394, 0.11117136744516236, 0.09838835801929235, 0.1777837880487953, 0.17882999405264854, 0.11119466155235257, 0.1408833031143461, 0.19012692357812608, 0.11009861715137959, 0.171409847214818, 0.1333983154701335, 0.2162118045879262, 0.14382754798446382, 0.09558847147439208, 0.10760916037751095, 0.21762665866741113, 0.18437610859317438, 0.12011516466736794, 0.09066479746252298, 0.08823613742632525, 0.11252766395253794, 0.09875015967658587, 0.1176446865179709, 0.1155487596988678, 0.12958455511501857, 0.16738267402563775, 0.17464261874556541, 0.12209039367735386, 0.18364999469901833, 0.17453340174896376, 0.1703648625739983, 0.18369167031986372, 0.17163489013910294, 0.137254959238427, 0.14709530478077276, 0.10772148506449801, 0.18737398487116608, 0.10235805929239307, 0.15870096773973533, 0.11337200578834329, 0.10033404361456633, 0.23534683138132095, 0.155906936952046, 0.20899205628250325, 0.10339007712900639, 0.09488989253129278, 0.16878319744552883, 0.17604516419981206, 0.09209079308701412, 0.09682687930762768, 0.060163270948188644, 0.13978810688214643, 0.08440115928117718, 0.15247969728495392, 0.11812014957623822, 0.17324685864150524, 0.15888890836920055, 0.13337649378393376, 0.2231010249150651, 0.08185262246323483, 0.2236402974064861, 0.13243695348501205, 0.1037034856687699, 0.09942458955837147, 0.08671888562717608, 0.09422825981995889, 0.12954387015530042, 0.1916995913322483, 0.10853138446275677, 0.16278980619141034, 0.09665865012045417, 0.12489552529794828, 0.09071603364178113, 0.0964717340788671, 0.10222377721220255, 0.2074357005102294, 0.1350092797407082, 0.13609660496669157, 0.07536447740026883, 0.11266953205423695, 0.1094126318182264, 0.10333932270961148, 0.06159384668405567, 0.15968926756509713, 0.10016193320708615, 0.16336774160819395, 0.12624401865260942, 0.15506126518760407, 0.08340201646621738, 0.19819646914090427, 0.12080560119024344, 0.13296585796134813, 0.07695702623043742, 0.08701702034366982, 0.06104667604501758, 0.13561971698488506, 0.10559237788298301, 0.11901912705174514, 0.09809125467602696, 0.12052025007350103, 0.15723758483571665, 0.15963186350251946, 0.12313096784055233, 0.0682341396542532, 0.13943943487746374, 0.15140402929059096, 0.1509559519056763, 0.19416434264608792, 0.3611433154770306, 0.10287941167397158, 0.13232274247067316, 0.15416087635925838, 0.14481100306979247, 0.18632032855280808, 0.07508876148079123, 0.14249242176967009, 0.09248145283865077, 0.09632888210139104, 0.14693038005914005, 0.2270641443984849, 0.11727295789335455, 0.11336154956370592, 0.11936665911759649, 0.16019062351967606, 0.19403685948678426, 0.10763681746487107, 0.14305369236639567], [0.04671819115589772, 0.01966092875227332, 0.04951570961358292, 0.08158519824168511, 0.012410430936142802, 0.009341065056755074, 0.0368524378697787, 0.033623662910291126, 0.049582935470555506, 0.030442202197653905, 0.02693690386201654, 0.03226462172876511, 0.014138973451086452, 0.05423401143135769, 0.029959539882838726, 0.044638559355267456, 0.027580450222428356, 0.03023825153442366, 0.04997827032847064, 0.01547903600814087, 0.022312587626012306, 0.043951484973409345, 0.0414113789530737, 0.021801228368920938, 0.02234466197634382, 0.021628658253965632, 0.024970799451693892, 0.026085098141006062, 0.02974529584337558, 0.051294268641088686, 0.11318187349076782, 0.0612402485151376, 0.02457549173517951, 0.03110834377418671, 0.029799100277679305, 0.02341591440407293, 0.05040100782311388, 0.06683943806482212, 0.05287759618035384, 0.009442117580744838, 0.04134796985558101, 0.05295728672561901, 0.02265013674540179, 0.020175684077133025, 0.05435953362445746, 0.025894747015887072, 0.04816799657419324, 0.03005590881886227, 0.02612047695687839, 0.031217347032257488, 0.019703442363866737, 0.04210360680839845, 0.039459698500909975, 0.01389163641059505, 0.02745898057972746, 0.039592728683991094, 0.02974373860550778, 0.01032468383865697, 0.01893433988360422, 0.06119639479688235, 0.05942384419696672, 0.02846144651994109, 0.025606866659862653, 0.07072117405810527, 0.021141115576028824, 0.04052650822060449, 0.023031471729544655, 0.02152519523432212, 0.03965817338653973, 0.03998175995158298, 0.04998568671622446, 0.04605809871905616, 0.038995526265352964, 0.010246778688659626, 0.06104899663478136, 0.07702437083103827, 0.03469245734491518, 0.0072712321499628675, 0.023165892909414003, 0.03509040456265211, 0.0367964621234153, 0.01724526096534516, 0.01810050007355, 0.018293816396700482, 0.013564127064975244, 0.011524310002901723, 0.08091331286621944, 0.016455252821158086, 0.02095366518811456, 0.06829201190599374, 0.12216195198042051, 0.02466264277297471, 0.028194940017004098, 0.027505024269755398, 0.010853949634890472, 0.05931913945823908, 0.030847097613981793, 0.05223811085202864, 0.018412763585469553, 0.07074974716774055, 0.014959128906152077, 0.0747778160231454, 0.056989138413752825, 0.06449270434677601, 0.08047400215374571, 0.01865441195799836, 0.037902589554765394, 0.04558321920090488, 0.0650314882929836, 0.016854192396359782, 0.020597977131339054, 0.02540420860584293, 0.04944931835468326, 0.03958437252523644, 0.008963000611402094, 0.056850703699248176, 0.035983081840510876, 0.013700238645209797, 0.015437725099868007, 0.024975486432335207, 0.016151886599670564, 0.00643345047553469, 0.0414232770646257, 0.03217269041176353, 0.010720430906595928, 0.05228058375152094, 0.04217118889625583, 0.03237938914181931, 0.018543086413826262, 0.026930284752909626, 0.006701589703360307, 0.015854522020422986, 0.06294796509402138, 0.02359445223451725, 0.01301032120162355, 0.04991768054398043, 0.03272201879216092, 0.022535951176126088, 0.01858177817692714, 0.0447495846476938, 0.03310058026441506, 0.07093684641378266, 0.03988546904708658, 0.009526156687310763, 0.027226743487907306, 0.1295135396399668, 0.030658868607133627, 0.04216293451775398, 0.019467262983588234, 0.0691967433584588, 0.04838592505880764, 0.053158072022987266, 0.03753809072077274, 0.03210147476888128, 0.019352985812085013, 0.09402225658829723, 0.011165225030189114, 0.005980049983398723, 0.10613620334437915, 0.03573037843619074, 0.03432804672047496, 0.03639032838067838, 0.034215854347816536, 0.0056881052026126, 0.06878062497292246, 0.04823224026975887, 0.016551236688558544, 0.015743388162393655, 0.012020599845397686, 0.04732416703232697, 0.04837542472939406, 0.029364552881036485, 0.06396508908697537, 0.013916292676835187, 0.03879228127854211, 0.04015797210325088, 0.03622737819594996, 0.023685564220483814, 0.044660333544015884, 0.11222718829022986, 0.028540214257580892, 0.045034582926226516, 0.031236715814364806, 0.01719921048996704, 0.014780993107706308, 0.008928680310158857, 0.02864340925589204, 0.06449636165052652, 0.01297598987418626, 0.09555238698210035, 0.01923762637722705, 0.024896542275590555, 0.040387164269174845, 0.009552044494609748, 0.038176381827465126, 0.014323092232059156, 0.07642335165292025, 0.01682292211002537, 0.01922892077293779, 0.025709830956267457, 0.030084088378186737, 0.013488387289856161, 0.06260314716824464, 0.007773225927459342, 0.014931828049676759, 0.06455690054489033, 0.038584351007427485, 0.1169096159615687, 0.06559387168713979, 0.014220842941930252, 0.014066555953052427, 0.010196153190918267, 0.03430979412847331, 0.03325659582125289, 0.014393150972734605, 0.051543681150568385, 0.025376895875004784, 0.07440502209854977, 0.011141767226425665, 0.015139676896589143, 0.023721806472167373, 0.01764900965749153, 0.07514096117977585, 0.02264637596506093, 0.05332311548824821, 0.01665355298402054, 0.029059083200991154, 0.020207677003262297, 0.004266662124012197, 0.031281583942472935, 0.015454539197630115, 0.00825995097069868, 0.03253046157104628, 0.012812238169967063, 0.039393283493284664, 0.04419443443683641, 0.024741125525906682, 0.04926848877221346, 0.04403356735461524, 0.07049616506057126, 0.046668909157493284, 0.03361969008775694, 0.033535249797361236, 0.06098499721182244, 0.04009315165291939, 0.04763131947921855, 0.031203596520104578, 0.01824970992415079, 0.06673381730381932, 0.015191576343828013, 0.02845549746416509, 0.040288837759622505, 0.022929012941728746, 0.05472913504179035, 0.027419218427634666, 0.06488837168685027, 0.036275031710309644, 0.007644045582440282, 0.025281132531485388, 0.09550421099577631, 0.016496339812874794, 0.011542688123881817, 0.04405732286561813, 0.031421925340379984, 0.0172375850379467, 0.021043644020599977, 0.0362258039947067, 0.0071177025757996094, 0.08135596875633512, 0.06589065611894641, 0.028477588868034736, 0.012920042965561152, 0.03719540339495454, 0.0434487244513418, 0.006188232584723404, 0.024977089471316764, 0.05581537800441895, 0.09894418676516839, 0.03435450619352715, 0.04810231438438807, 0.0425751377562327, 0.05404523281114442, 0.035170424197401316, 0.04765586887619325, 0.027617379490818297, 0.0241236179468355, 0.05010318523272872, 0.07738372976226465, 0.014876023633405566, 0.06291466259530612, 0.010001492520262088, 0.026069932883339267, 0.06687366337116275, 0.04134455682443721, 0.045394681460623226, 0.006132073209820581, 0.03157884334879262, 0.0239114604025547, 0.015623523255011864, 0.08818296063691378, 0.014608558699754732, 0.033135636776153526, 0.019355966277154427, 0.03246030444279313, 0.010553032076651496, 0.02147541451267898, 0.03354424038635833, 0.020286035923553363, 0.04431441639150892, 0.0443476103246212, 0.03527874892045345, 0.04277370763676507, 0.02513154948662434, 0.049048426294965405, 0.02537087896572692, 0.035899235268256495, 0.004231896110078586, 0.006723860494925508, 0.017078711152342812, 0.035278311265366416, 0.0023139091624346164, 0.014887674079675759, 0.0690412095614842, 0.045460438289280446, 0.01905393337697855, 0.025573742276589786, 0.01918642921373248, 0.037620010253574164, 0.04112107113802007, 0.06612988042512111, 0.03494201234674879, 0.021110798631395613, 0.02348775090649724, 0.031833925018353124, 0.05326374367411647, 0.026524106905396496, 0.02556421055591532, 0.0901169686445168, 0.042919314466416836, 0.010497406623991472, 0.018948889370741587, 0.0125510759784707, 0.0204287962988019, 0.05268091941252351, 0.033773473264383416, 0.033288025563316684, 0.015262919212026256, 0.020303114649972746, 0.03558753663673997, 0.010332805902830191, 0.014807725691103509, 0.029814791399985552, 0.18919557998222963, 0.12845349152173313, 0.17435895039566926, 0.2566838264465332, 0.06876024856631245, 0.0797380834285702, 0.12256938511771814, 0.11946495170039789, 0.08809576210166727, 0.15308438055217266, 0.11529977805912495, 0.14761484547385148, 0.09722431083875042, 0.18379157781600952, 0.10164132275219474, 0.12355628716094152, 0.19383289186017855, 0.08912137456770454, 0.18861267768910953, 0.14659134325172218, 0.13179922556238516, 0.12573860505861895, 0.07348513895911829, 0.13580353212143692, 0.1179417355784348, 0.1318867972918919, 0.15455434524587222, 0.09254970667617661, 0.127604535647801, 0.17866511004311697, 0.22606318310967513, 0.25667435409767286, 0.11583572572895459, 0.09231198193239314, 0.13981463760137558, 0.16186911559530667, 0.08813599922827312, 0.11540444887110166, 0.18479796738496848, 0.14394619661782468, 0.11036193623606648, 0.181645860097238, 0.1453693016831364, 0.12937171225036892, 0.10702132513480526, 0.13101802819541522, 0.34369902153100285, 0.11432175125394549, 0.10926537614847932, 0.13927205385906355, 0.09296117031148501, 0.15395586378872395, 0.11588991353554384, 0.0889579358377627, 0.10488484227763754, 0.12320996288742338, 0.0866871437590037, 0.07414679881185293, 0.09514846865619932, 0.1648801283112594, 0.13578724728098937, 0.09333264787814446, 0.11369255930185318, 0.17855878360569477, 0.08806383702903986, 0.0903387206739613, 0.10723634609686476, 0.1308570389768907, 0.25982677351151195, 0.12557266253445828, 0.1542286348662206, 0.12229246140590735, 0.1546337338430541, 0.08650498424789735, 0.14348678769809858, 0.13233084417879581, 0.15322736145130225, 0.1100614605737584, 0.11990509022559438, 0.13534746159400257, 0.0962924515562398, 0.1006411417786564, 0.0896436565422586, 0.21832326985895634, 0.10877577920577355, 0.09984037546174866, 0.15324672684073448, 0.07222912992749896, 0.1469295658171177, 0.16124410341892922, 0.17997403123549052, 0.11809261462518147, 0.14405998694045202, 0.1299555916339159, 0.08372090756893158, 0.17185777532202856, 0.14983954466879368, 0.1880695375480822, 0.10784115828573704, 0.10045630883957658, 0.06778461698974882, 0.12376462455306735, 0.08939269358026129, 0.14394977928272315, 0.15160977467894554, 0.09286335270319666, 0.115701877911176, 0.10936255593385015, 0.09236787286187921, 0.10828489983188254, 0.12233036437204906, 0.14729592044438633, 0.1456378387021167, 0.13566239683755807, 0.08517267395343099, 0.06903225968458823, 0.20052471277969225, 0.14463324046560697, 0.10125865614307777, 0.12204934230872563, 0.13863744719752244, 0.12022856143968445, 0.1167744110737528, 0.10597667297614471, 0.12791206128895283, 0.1000364992235388, 0.11061095180256025, 0.15422039745109423, 0.07568112933742148, 0.13259746772902353, 0.10076561902782746, 0.14554569364658423, 0.1301838643848896, 0.10553312141980443, 0.07521600715283837, 0.10813791557614293, 0.11997710993247372, 0.15556055839572633, 0.0909423047144498, 0.08717445403869663, 0.04885957982125027, 0.11402806772717408, 0.09395856929144689, 0.09893632932965245, 0.10053069663367101, 0.16563813335129193, 0.23192736772554262, 0.16655248643032142, 0.11986032048506395, 0.18986502263162816, 0.2200532898839031, 0.17500415577420167, 0.11990870003189359, 0.16683219213570866, 0.08502825456006186, 0.28865748218127657, 0.15305300509291037, 0.10227008044187512, 0.24848975613713264, 0.11614102577524525, 0.11533472261258534, 0.11498097516596317, 0.08982424863747188, 0.08250662165560893, 0.18506906926631927, 0.1534828705979245, 0.1423038433172873, 0.11689448463065283, 0.06704480347356626, 0.07771830859461001, 0.11872632562049798, 0.10147213004529476, 0.12452775931784085, 0.09750441009444849, 0.0942488330017243, 0.08742404635995626], [0.005774530632022236, 0.04925951514659183, 0.006638061438154961, 0.035417645038770776, 0.060254920673157485, 0.017487764291997467, 0.00885098974686116, 0.022997380433870212, 0.03029009500252349, 0.013662174527001168, 0.047630966641008854, 0.04388628454346742, 0.054017290739076476, 0.03466261537479503, 0.0066658771330756796, 0.02468864423488932, 0.050100365919726234, 0.007931367843411863, 0.02975819818675518, 0.016105975223971263, 0.02680194324680737, 0.029864606048379625, 0.018647709728351662, 0.03350267672379102, 0.019343150446989706, 0.04370367380657366, 0.04957115610263177, 0.024470303540251086, 0.03307063312136701, 0.037243165474917204, 0.04495013245780553, 0.04021822262023177, 0.012551294806014215, 0.03118246015427368, 0.04975548353312271, 0.0576945027070386, 0.047544385572629314, 0.03531369686658893, 0.03216771335740175, 0.014776358713528939, 0.04268074155386005, 0.017907504358195832, 0.03540424397215247, 0.030627978300409656, 0.042752520380807776, 0.09194284531154803, 0.013179457929384495, 0.05105372119162764, 0.04827857742618237, 0.009794239935997342, 0.019216749551040784, 0.04843822314536997, 0.03160231387508767, 0.06323865628136055, 0.010842608770222535, 0.01279528412435736, 0.023438994772732258, 0.02582592999429575, 0.04361930136967983, 0.030409347532050948, 0.0392647961021534, 0.03014026429238064, 0.03765314990388496, 0.04151013972503798, 0.014702975151262112, 0.025379850895011, 0.054251527812864096, 0.09554246001477752, 0.011345902790448495, 0.05060550470703414, 0.025261192083624855, 0.12831326547477925, 0.04445642020021166, 0.07007909672600882, 0.040989252139947245, 0.02147950098982879, 0.0542622724148844, 0.03652613037931068, 0.0192421691691769, 0.08271867063428674, 0.02698965826337891, 0.0042481092802648035, 0.05295773455873132, 0.017471143576715673, 0.06915377173572779, 0.023067990484248315, 0.03936805895396641, 0.0135558659011232, 0.027420321047039967, 0.07854863868228026, 0.015496090985834599, 0.025231592689773867, 0.04612657308046307, 0.056380319475595436, 0.00902006879914552, 0.0418892134912312, 0.043569659747715504, 0.0480009921427284, 0.07152521769915308, 0.04849730997479387, 0.03800351146076407, 0.07330181915313005, 0.021206563671252558, 0.04401416803843208, 0.021933283157912747, 0.02286540706908064, 0.03963952385155218, 0.04527200911460178, 0.033943001846117635, 0.0346493737639061, 0.00814104703853705, 0.035437695748571835, 0.029593253109071935, 0.05045757389494351, 0.06255929344998938, 0.036329640208610466, 0.03331560461914965, 0.025155561144596765, 0.02081195654214493, 0.014269303064793348, 0.028880109411797354, 0.04792934563010931, 0.03560933118153896, 0.027783556109560386, 0.047519954919282875, 0.02012670911582453, 0.048979239471788914, 0.030290664971939156, 0.0066642168427019245, 0.00684214780838894, 0.020957420879442776, 0.03688302283574428, 0.04540082898789218, 0.04115663655102253, 0.03991327880482588, 0.02753614358204816, 0.02469401653589947, 0.026040971312405806, 0.05357658902981451, 0.00658171546612201, 0.037306774740240405, 0.03470730029844812, 0.0594569838472775, 0.041520996285336356, 0.011322556944963123, 0.036806735143597634, 0.02867382119542786, 0.058939872309565544, 0.019459302071481943, 0.016705133519800644, 0.03847484563344291, 0.04828405659645796, 0.022788881889677474, 0.008435913760747229, 0.057352012156375816, 0.08469387928822211, 0.03952420682513288, 0.02027372899465263, 0.04091259464621544, 0.052524836002183814, 0.023232650577223728, 0.040250185012285195, 0.02178294863551855, 0.0607300851760166, 0.00788693652222199, 0.0570894055334585, 0.0581540134070175, 0.08437179907092027, 0.03282448775800211, 0.018205771389018213, 0.013530343654565513, 0.023110191969733154, 0.03351151464240892, 0.031984614075294564, 0.02539176257726337, 0.03754848926993353, 0.0658894618973136, 0.03417580042566572, 0.07193512748926878, 0.06588883764509644, 0.01781968665974481, 0.05602033968482699, 0.045574296465409656, 0.04161513623382364, 0.01558552190129246, 0.09784214411463056, 0.05249669376228537, 0.03731971779572112, 0.02625804653923426, 0.07463089962090765, 0.026755828310602477, 0.037841626576014926, 0.06589225746159043, 0.01312030918364014, 0.05231123996366348, 0.04551873801808272, 0.05248067694317017, 0.01175438511251871, 0.020660938395719444, 0.03450744120138032, 0.02431417432879763, 0.028159871630902802, 0.057406803859131675, 0.015842554359031574, 0.03215782370950494, 0.06462763103523425, 0.021623821995620216, 0.02624887953113232, 0.03934053418093494, 0.023777600710413287, 0.03693420812487602, 0.02372858503700367, 0.09610058899436678, 0.03980132731209908, 0.01634622411802411, 0.03745816268825105, 0.02812918827735952, 0.017751941723482947, 0.035148531265024624, 0.03615769264953477, 0.05697345746947186, 0.037381359309490235, 0.013936142370636975, 0.04052717997027295, 0.01883342137028064, 0.01940608796264444, 0.023175614619893686, 0.012571622018835374, 0.024015257600694895, 0.06277781565274511, 0.03790729180244463, 0.044311118711318286, 0.06739127702478852, 0.04104992674131479, 0.0562580949626863, 0.024206360203347037, 0.029515068911548172, 0.04572862586272614, 0.024281321359532218, 0.05627944167437298, 0.04524718151826944, 0.057483600452542305, 0.06856254381792885, 0.07446793586547885, 0.04618959541299513, 0.031205109653196166, 0.015091740093859178, 0.07504144723394088, 0.11226076898830277, 0.05581758663590465, 0.03815292826454554, 0.05875606395836387, 0.023346683476120234, 0.034866966373686276, 0.015035092597827315, 0.09989041741937399, 0.047836902019168646, 0.006605206348467618, 0.039352415329111476, 0.03474768331008298, 0.04987232047798378, 0.06381630671343633, 0.0201467055428241, 0.05196928206299033, 0.02871402439528278, 0.024966580660215447, 0.036262835043349435, 0.07447806639330727, 0.05481031497142144, 0.04162043559231928, 0.02301674921597753, 0.018915675081578747, 0.008227148891559668, 0.022850596345961094, 0.04695381922647357, 0.043331704302025695, 0.04895958570497377, 0.04492314372743879, 0.06176825053989887, 0.01622768065759114, 0.023599173141909496, 0.017656948517209718, 0.03130728006362915, 0.04129649618906634, 0.027096301915922334, 0.033763373270630836, 0.06843305898032018, 0.0324828080566866, 0.08079925791493484, 0.07642773498914071, 0.014943164673500826, 0.05341154895722866, 0.025493614076237594, 0.047267913086605925, 0.0138580379009779, 0.005139925242734275, 0.04667726870892303, 0.008314581521387612, 0.013298887726185578, 0.02402599372102746, 0.06060454262686627, 0.07391880426023688, 0.07514233860586371, 0.03410505297194634, 0.05774282118571656, 0.03327886534056493, 0.029690300580114126, 0.011945731987777566, 0.040576713026634285, 0.013029146307547177, 0.014052995430704738, 0.032264180681002994, 0.017972677646737014, 0.051489276212773154, 0.04779398128656404, 0.035849698819220066, 0.014259367615782788, 0.049120296724140644, 0.0029425311451112585, 0.02703257729964597, 0.04121555374669177, 0.03860961965152195, 0.0102658183812829, 0.01309734840677785, 0.04355812125972339, 0.02550177006716175, 0.008884239659112479, 0.014153511912029768, 0.0013865292712580413, 0.047467985922204595, 0.0455010791442224, 0.0065821577861372915, 0.030150930862873793, 0.03171139516468559, 0.03557275135868362, 0.04715618211776018, 0.028147123654239943, 0.030384170490184, 0.04153319973764675, 0.04763135340596948, 0.02149093769756811, 0.020792993184711252, 0.004148352334076273, 0.052604004075484614, 0.025729903718456626, 0.02587899991444179, 0.004638519246197704, 0.025437168444373777, 0.042062874351228983, 0.04155290778726339, 0.03062301142407315, 0.03517061757988163, 0.09724788314529828, 0.13529942131468228, 0.1627606563270092, 0.18702999475811208, 0.12049960903823376, 0.1381437179765531, 0.1117459237575531, 0.11251077521592379, 0.15147015931350843, 0.22690808134419577, 0.20536173108432973, 0.10828310849943332, 0.12138999626040459, 0.1793604998716286, 0.15053082257509232, 0.10871679415660244, 0.1406400211687599, 0.11289675307593175, 0.09788323619535991, 0.12904834960188183, 0.21041185009692395, 0.09614195927445378, 0.10159332997032575, 0.0854814141722662, 0.14139234008533613, 0.12577946643744195, 0.1291659940034151, 0.09058507638318197, 0.17700162716209888, 0.142568865524871, 0.220450436430318, 0.10013659670948982, 0.09998398061309542, 0.15088480072362082, 0.08530661676611219, 0.11745899862476758, 0.14060133110199655, 0.14381845561521395, 0.10427300046597208, 0.1407536757843835, 0.13109832602952207, 0.11947396264544555, 0.13912983291915484, 0.0995224682348115, 0.12612340226769447, 0.1816475157226835, 0.0940770957885044, 0.13421974996370928, 0.11378666532358953, 0.08194848589066948, 0.08995529410562345, 0.08470679180962698, 0.1017785971718175, 0.14615395957870142, 0.11912685127130576, 0.14012164755591325, 0.08426476695707866, 0.15056696135018552, 0.1070395370147058, 0.09464671236595937, 0.07531897484191827, 0.1186825872531959, 0.11762521256293569, 0.1893471104225942, 0.10263392448957477, 0.15005778867219174, 0.1366452548120703, 0.1481761024998767, 0.1616451990391527, 0.12089341719235693, 0.06350607371756009, 0.2395229430070945, 0.21104172058403492, 0.1324626835329192, 0.10106749925762415, 0.1895341689565352, 0.143840616568923, 0.13151356231953415, 0.1554380828248603, 0.20149462430604867, 0.17386767747146742, 0.08659199279333864, 0.13026060669549874, 0.11290302273950406, 0.1628621108829975, 0.253233584442309, 0.1439920248729842, 0.19035331000174793, 0.08546380618853228, 0.14008371744837078, 0.0811749966815114, 0.14726810050862177, 0.2584064911518778, 0.23789065916623386, 0.11795736902526446, 0.08275419194251299, 0.1057106058246323, 0.1493100837937423, 0.16433259126331123, 0.17236652730831079, 0.10699875027473484, 0.15507893423948968, 0.13167759137494223, 0.14692058201347077, 0.1459102298000029, 0.13318421053034918, 0.1103396802874548, 0.15560095837073668, 0.08834976490054812, 0.13657639707837785, 0.18368617418621266, 0.07032644309635673, 0.16733961419335433, 0.14527498531554425, 0.12808583410722868, 0.08854654684130635, 0.07926951428609234, 0.1762906310281583, 0.12353659607470036, 0.10036896781197616, 0.09282923596245901, 0.07296250414635454, 0.1434488304491554, 0.0669435253366828, 0.1122873132782323, 0.10998581748987947, 0.13405463525227138, 0.12552357731120928, 0.115667639034135, 0.11915889169488635, 0.09985333548060485, 0.11682621043707643, 0.11484777874180249, 0.1470838782510587, 0.18907683635396616, 0.19394293666950294, 0.15758268774620124, 0.12049181945621967, 0.15702740182834013, 0.12231061900300638, 0.13520344932164463, 0.13847583372678074, 0.16519734343247755, 0.09678357520273753, 0.113849884431277, 0.08788234926760197, 0.0726810817473701, 0.18599909650427954, 0.12920009717345238, 0.06241446015025888, 0.09770650496440274, 0.19598162227443286, 0.11622117433164801, 0.11930682589965207, 0.13294485051717075, 0.1285240455929722, 0.20927454398146697, 0.11438439360686711, 0.12957835330494813, 0.15214883003916058, 0.20092198146241053, 0.18771159675504479, 0.09111764494861875, 0.09807192999869585, 0.08921468670346908, 0.13762895417000565, 0.09692777067955051, 0.15327990720314638, 0.11793537091995988, 0.16042170540562697, 0.06463185830840043, 0.1466444996850831, 0.127370685338974, 0.11053119001111814, 0.12982904485293797, 0.0845804757305554], [0.011468680309397834, 0.06388863854642425, 0.009790220464180623, 0.019796313451869146, 0.04153148304404957, 0.003847654875633972, 0.01008311434582408, 0.10127138546002762, 0.05298046887453113, 0.030855063615100722, 0.012285898556001484, 0.08679259488625185, 0.07985750559185233, 0.013740037268559848, 0.05317540180736354, 0.06626102767352547, 0.02267609240620264, 0.05803043860942125, 0.08185065471168075, 0.03827375499531627, 0.034157785320920606, 0.016138059752328054, 0.0364227521765445, 0.020189363343108977, 0.00714657932985574, 0.022093760082498193, 0.041537345586610694, 0.04163004704085844, 0.024170078935899904, 0.059377289909337244, 0.062195646177445135, 0.03714462522683399, 0.013579361024312675, 0.007577868062071502, 0.031596576861504994, 0.008910709310189953, 0.02240898709611169, 0.029341360554099083, 0.022243595881653682, 0.024039735751492635, 0.08664252329617739, 0.055708081261920075, 0.06446135602891445, 0.02141448206800435, 0.06667969056538173, 0.03371926849441869, 0.024594606066654836, 0.07821955598358597, 0.03456374942990286, 0.009312642921161438, 0.04137400185157146, 0.011791668067287122, 0.029876402379678826, 0.026527124689891934, 0.01565665951264756, 0.0076593762330178705, 0.039738104811736515, 0.05247727748272674, 0.08527364674955606, 0.07491468332175698, 0.02237560656586928, 0.004317887701160673, 0.05170836499226945, 0.06798617581703834, 0.014348528813570738, 0.023069094799991165, 0.12634351902774402, 0.02671048351164375, 0.04211675342438476, 0.030435949497457062, 0.04407934811232345, 0.05559649278542825, 0.007167498564480671, 0.014919302293232508, 0.0024995656733933303, 0.029147126512335877, 0.054892879112490585, 0.050392617737608295, 0.011661452108195849, 0.02244807410586093, 0.0213076263732676, 0.06737477505313498, 0.026603056151153784, 0.02663523397807564, 0.03581831996728267, 0.013204416143707931, 0.04209994950464793, 0.0478963654355279, 0.0135003032129524, 0.024077296057449918, 0.031884248568011184, 0.008704735764435359, 0.055642812978476286, 0.03451476598690663, 0.021667265200189183, 0.013168413075618446, 0.05562390560018165, 0.039812526532581875, 0.027026655385270715, 0.04141410666384867, 0.029060464019754102, 0.025220320526776568, 0.060544030873903205, 0.050537956545927694, 0.032491588299827914, 0.0570900094296251, 0.02877886520166482, 0.03805757713104997, 0.02687124033192439, 0.039929444901645184, 0.039639215118118694, 0.08372161324535098, 0.006828500772826374, 0.022617227796997343, 0.013840309477278163, 0.03627060426931296, 0.027527032553085258, 0.019474699727392623, 0.015498811911259378, 0.07278273986386401, 0.013350058596448174, 0.029468419629016092, 0.0059944735174732545, 0.02994406928441354, 0.03751722237627421, 0.051022464475993595, 0.02235808170267514, 0.03669441384928567, 0.0616082384118012, 0.06776700900601489, 0.018173556242670332, 0.013783732379254485, 0.028580288535782268, 0.04029597934069378, 0.013932200082178627, 0.0295536605907338, 0.058039815963378975, 0.0272180361872805, 0.04570762859657407, 0.03300228428893855, 0.06589396736983742, 0.007758106470906309, 0.07790678526673998, 0.028468041880322353, 0.06569319564316954, 0.04492486720638616, 0.026328661678625003, 0.028130967735445926, 0.04314951764951859, 0.03077051815177713, 0.04976429431033986, 0.07324074421610151, 0.04410781265635576, 0.024088061015520777, 0.049626263324171305, 0.05299031441765172, 0.017237488346706544, 0.024837508032630597, 0.027644846588373184, 0.016434918822986738, 0.008524593198671937, 0.008254655853046902, 0.014955318932022368, 0.029281354309724908, 0.007757682386519653, 0.03467366531757372, 0.029600842523255518, 0.015731009987315962, 0.02789545671216079, 0.008008768332989087, 0.032515459161783965, 0.020420435051034604, 0.0755907009754862, 0.04244342053841267, 0.056238251206065924, 0.03891069242464645, 0.007205225959686297, 0.0420335989578494, 0.024943152542359064, 0.009890524055143552, 0.027834585335637842, 0.04236874436693532, 0.010050974686497023, 0.0443180906586349, 0.05592609117073672, 0.042531616520136595, 0.03541458823851176, 0.03589757964281099, 0.03782408644578286, 0.011347980803943105, 0.02967132195564253, 0.06000781857541629, 0.01428611546621791, 0.03455690640423979, 0.026626655599102378, 0.02757265215872654, 0.022621166692780595, 0.04157893978325384, 0.04450496598812086, 0.0371397024552737, 0.014497940528339573, 0.021075528381126266, 0.07557068419243608, 0.05077667873618858, 0.01296176269118275, 0.04518290050327778, 0.022034373001328537, 0.05039047356694937, 0.014303034736907907, 0.012840268451587429, 0.02258863772398659, 0.042912261094897985, 0.022030535885798078, 0.005582692242959248, 0.041726999516998015, 0.06386573798954487, 0.06565939781389066, 0.058013977349868844, 0.051004639361053705, 0.05755031401557582, 0.019345296313986182, 0.03373008434261594, 0.01869985514453479, 0.010944796992199761, 0.052608027788145204, 0.056984517590275834, 0.00939800262650741, 0.03440271610660212, 0.05240728320287807, 0.07491967733949423, 0.057252389644937854, 0.018355747984190072, 0.06394256172435624, 0.05131261622799294, 0.02542713121511042, 0.036018833850643465, 0.05121329905731337, 0.02105657520171787, 0.007858598355336912, 0.03170919671122517, 0.042831705417484045, 0.030376788029181104, 0.057167477772704194, 0.022147757899282233, 0.05881048925220966, 0.05027746355959347, 0.0073190603870898485, 0.026508173206821084, 0.054172509017267396, 0.034027482848614454, 0.049487204357449494, 0.07660938559898309, 0.02906492878017681, 0.05167278600856662, 0.010500261560082436, 0.07512933108955622, 0.0621012823124017, 0.06456107353525502, 0.02413134815703545, 0.023313606590298668, 0.0013766843642640325, 0.03463352657854557, 0.05030962611947741, 0.03214996627398899, 0.005921597584217254, 0.033154642542025874, 0.02677901215585215, 0.035476609731891325, 0.06864964057292257, 0.02592649058039699, 0.04446655072804008, 0.03255754529631563, 0.06068170562918697, 0.03903332066589168, 0.03473894377904279, 0.02260009987678911, 0.044804288140897236, 0.031216349585780075, 0.024321402423083782, 0.03058337140828371, 0.10570530646613666, 0.01781412776160453, 0.01864753839825945, 0.041827612689563205, 0.02621078148617276, 0.021100315265357494, 0.15049893142921583, 0.08376188429870776, 0.011823801789432764, 0.03259600466117263, 0.004459370734236602, 0.00945747028371053, 0.06714530808052846, 0.04512350494042039, 0.038412427197077444, 0.027464410556214194, 0.018697629549673626, 0.04736606656972851, 0.02744898066989013, 0.04305666691756674, 0.04094392600070153, 0.046808918073241196, 0.025855247796114002, 0.017783444408061247, 0.06148299441805907, 0.05653423157387546, 0.026450460410809944, 0.02651585083055709, 0.05066478491893836, 0.04340572229453495, 0.037123997762267075, 0.044632666278630495, 0.04830495886770742, 0.04843132244423032, 0.059421143627592495, 0.026700700733012388, 0.021334808486114656, 0.02284837923278766, 0.03201591150302972, 0.020446752031732882, 0.005336920073854604, 0.011437710274809172, 0.026344269680391465, 0.07265682412045342, 0.025202593799414377, 0.12248606101742812, 0.05226982897147536, 0.0677301509838019, 0.07135529895978314, 0.023157677546675717, 0.016918978919940333, 0.016833819382424866, 0.0382188682976578, 0.01870190940930375, 0.022238941131425754, 0.016680402614708458, 0.045310773820217164, 0.03454876059134092, 0.04336506108354245, 0.034151308704167604, 0.024783610299761807, 0.006724821894230055, 0.036555548265044174, 0.021608858602121472, 0.0739744712731668, 0.04624062463907259, 0.03962148499808141, 0.08420729504099914, 0.028783058548080068, 0.05085936501356108, 0.029182892093168836, 0.04701989496658955, 0.16782084479928017, 0.15195822955242225, 0.13773241718964918, 0.1077118498672332, 0.1327206218349082, 0.07758764989141907, 0.06313334086111613, 0.22956164181232452, 0.14462946781090327, 0.09108046122959682, 0.09794975298323802, 0.19565515193556035, 0.1856017056852579, 0.11636772432497569, 0.1493348367512226, 0.17415825330785342, 0.11670102072613579, 0.14860024116933346, 0.14665501697787217, 0.19294532734368527, 0.08308791582073484, 0.15426471935851233, 0.13479626045695373, 0.0954430749905961, 0.06378370310579028, 0.097524440448199, 0.14580382193837846, 0.09684761533779757, 0.14314139980290616, 0.13001702619450434, 0.1966361507241215, 0.12006715152944837, 0.09230761895222322, 0.06892573647201061, 0.14920785570783274, 0.0860046868079475, 0.14013696887663432, 0.10348809829780034, 0.11375388529683862, 0.13281227834522724, 0.3113407992890903, 0.11175122990139894, 0.18115458717303617, 0.1108277098142675, 0.16944087429770402, 0.10026060576949801, 0.14317911277924264, 0.16056490343596252, 0.13611408402877195, 0.07864647664661918, 0.08885678662253277, 0.08348301319139344, 0.2164048749421324, 0.11423336528241634, 0.09134523237922362, 0.13363228791526385, 0.14543159119784832, 0.09809569229504891, 0.1382384414651564, 0.14097038629863942, 0.18634273377912386, 0.09481666503208024, 0.15219412903700555, 0.13353407675666468, 0.12103642523288727, 0.12425449969513075, 0.16732847264834813, 0.08756056760570832, 0.13542828868542398, 0.10443389468959399, 0.17578744302902902, 0.2122516163757869, 0.07357703974204403, 0.12649903925401823, 0.1406970452517271, 0.14143465352909906, 0.18973676594240324, 0.11285492817738227, 0.07040136693311588, 0.1017164976469108, 0.11176621873996087, 0.15463040902146272, 0.11063692612307412, 0.07952425668814353, 0.13027470665318625, 0.08930605144373008, 0.1157561471419675, 0.08063397356974226, 0.12729838064738683, 0.06469009696905102, 0.10777934374553816, 0.13255412291203225, 0.2112563412104334, 0.14014292641409806, 0.13918845834476606, 0.10906074355755534, 0.1753761286714247, 0.1434689557978085, 0.2136531033154045, 0.15318101750952856, 0.1339206245860883, 0.09434912726283073, 0.16515744557338102, 0.10530174097844533, 0.11510328788842474, 0.12142544292977878, 0.06059654948434659, 0.10117333036448274, 0.17400134887014115, 0.08092193704630647, 0.20460181257554463, 0.2240162193775177, 0.1687534504703113, 0.11712826708597796, 0.10638098485235657, 0.0784910921273487, 0.10963882146669285, 0.17548071805919918, 0.11706160780574594, 0.1550473959318229, 0.09594341992799725, 0.06441777372466666, 0.09425933672381298, 0.09173646210027592, 0.08784661761351995, 0.10602997190185956, 0.09190668618040425, 0.12240526106740747, 0.13903595081397466, 0.2393689698406628, 0.12226550999496665, 0.06376925709524325, 0.18860929858471664, 0.11589557251759938, 0.11052439109023128, 0.12961282288389547, 0.2566260966871466, 0.11887875172708716, 0.16906443664005824, 0.15132497996091843, 0.1431644699935402, 0.1176550816744566, 0.11249719094485044, 0.11992262357047626, 0.14474424879465783, 0.08164246659725904, 0.12264301973794188, 0.1288971991411277, 0.12913406214543752, 0.17596610129943915, 0.11091121033366237, 0.1846244659807001, 0.17709903764937604, 0.09043318631925754, 0.07130494487604924, 0.13380231522023678, 0.14534408732184342, 0.14811451866158418, 0.20774902084044047, 0.08460769855550357, 0.15804291090794972, 0.141920036769339, 0.08708166437489645, 0.14416545842375073, 0.09941824525594711, 0.09478991718164512, 0.12869587780109473, 0.10436790715903044, 0.16370057660554135, 0.10417402256280184, 0.13591135133590015, 0.21590255546782697, 0.17658940356756958, 0.10526106280407735, 0.11816296513591494, 0.10287601899887834], [0.075434671847948, 0.03767552798879998, 0.04025711964017578, 0.007095765538646707, 0.013485528961090105, 0.059499263364289484, 0.05698501970618963, 0.060085917956062725, 0.04922405490651727, 0.02119894202665559, 0.03093667441446866, 0.07459229097834655, 0.09989843770329442, 0.013164302849742984, 0.041783389169722795, 0.04339466217373099, 0.019481374815638577, 0.039738179450588565, 0.0437380416052682, 0.061600767741245885, 0.02872778508546097, 0.015278467841978585, 0.01620428985916078, 0.01560200860590807, 0.028813460309590613, 0.017474819540179203, 0.024013917494033064, 0.0348969779775611, 0.006932954029512725, 0.034346200924898894, 0.04550119449517556, 0.05489795455443008, 0.05522617890632578, 0.057832964562944005, 0.06816885780010905, 0.00994688317379249, 0.00997230364009738, 0.028235981207607046, 0.023111077457932488, 0.05119114149627941, 0.02878583375630634, 0.0005021006467619113, 0.02002981092248644, 0.04315066098102501, 0.0485776722697275, 0.02980066430089729, 0.04706542127366577, 0.004746986461603748, 0.05381794393594776, 0.013016249053180218, 0.04874556218939168, 0.04607425803052528, 0.02321819099597633, 0.041003715113869736, 0.02623524097725749, 0.08936004926051412, 0.03695899840178234, 0.04312147040452276, 0.047347640951297114, 0.049553419197244306, 0.053202834978167496, 0.04550426486613495, 0.006441664141935429, 0.05877139206443514, 0.07047686073929071, 0.023646134550550153, 0.05901341872023685, 0.01916886872744986, 0.044984181345041306, 0.0814534742385149, 0.011435398166733128, 0.006637557625903615, 0.0661086897764887, 0.007818710674265665, 0.011055715415360672, 0.05224687073911939, 0.022502699567537223, 0.01593699286292706, 0.06648881187928574, 0.026206325207437788, 0.018323710953284587, 0.012856710203258055, 0.02532222630855228, 0.04629576578736305, 0.03297507503469076, 0.020196024860654558, 0.03800483121137534, 0.035509796879653416, 0.05064384193558778, 0.048152424195515256, 0.10400910462651934, 0.040782997850328684, 0.04279008407944015, 0.05763472377189568, 0.04825021466240287, 0.02216882641161127, 0.017011212185025215, 0.06723787382777248, 0.04038777495069163, 0.03261665926714029, 0.024899158028087447, 0.03394443016233189, 0.00606877013342455, 0.041725469420530965, 0.0410828017629683, 0.05946480735604252, 0.04613177065870591, 0.01949053503839033, 0.0860324931730117, 0.07921572681516409, 0.01600389471942825, 0.03018455227304782, 0.030064129270613194, 0.029187156685761044, 0.009005236023637866, 0.05229318414681724, 0.019572651346347163, 0.021115455077961087, 0.01384141294485224, 0.026999118737876415, 0.03792912705934473, 0.011892916518263519, 0.04536429326981306, 0.07341454417577811, 0.05151810377304043, 0.06937787828168698, 0.016433024013947164, 0.010052753296414656, 0.027282093285716007, 0.043620285245456865, 0.06275505758821964, 0.021127263283623115, 0.017805737676098943, 0.036435427210692845, 0.025048919188390886, 0.04593409983707326, 0.0389988239455436, 0.009583850823608893, 0.039765639762793265, 0.042071780123348744, 0.0048146902616801, 0.02127784547129912, 0.04765767717201795, 0.06024654755102737, 0.03590282132583005, 0.050982675182500055, 0.0553918907285801, 0.05918355459081275, 0.029536744712718895, 0.020254925092948333, 0.019784581581396714, 0.052868568271930726, 0.04736091648893697, 0.080964745820633, 0.018679400706397634, 0.003094593175254496, 0.08032090429748807, 0.040299124350505214, 0.023840626435620443, 0.02869449955012117, 0.029928992236299173, 0.02463727574130254, 0.03036649465294821, 0.015175861472796117, 0.03623513724388821, 0.027227803698873947, 0.03335400970120515, 0.025051901349797845, 0.037859899524067125, 0.01321000896859914, 0.05465091013216546, 0.034961645757513385, 0.0216137389652431, 0.017280129183615957, 0.01691486021237714, 0.06041616094963891, 0.04504585339288626, 0.04753316938877106, 0.005932847270742059, 0.031172316055744886, 0.044958549684711864, 0.047239367118371386, 0.06903209005083356, 0.05692902021110058, 0.07059738212930304, 0.014735351449676921, 0.044817753668342314, 0.010083910776302218, 0.031064469699880908, 0.039450348288353, 0.024181917675637772, 0.0076049874104293326, 0.08601335170013563, 0.04432826868391462, 0.010016592468933334, 0.03771902886884553, 0.024203523926969086, 0.05331247266648071, 0.012698717565009636, 0.018866616999730468, 0.025884348466726284, 0.046129948792180846, 0.016922648098053675, 0.029034873071525778, 0.014118859128627394, 0.032176313788763115, 0.01632812589273921, 0.05503671835841877, 0.011153056352798427, 0.013650283200799354, 0.08272763408188309, 0.015512759198567696, 0.011481161112897098, 0.045307238652770004, 0.03248439582863024, 0.06868959271482059, 0.04533735882224781, 0.05461085621001465, 0.01202996023597994, 0.03709323976987174, 0.011867234815976449, 0.04705369279586843, 0.020435047302661196, 0.008167033233413739, 0.020603963506541083, 0.029870811251125166, 0.0021979456193678614, 0.017861798239339675, 0.05539054722924318, 0.013080284099227615, 0.03145686650116529, 0.05928314317549978, 0.058875967881509235, 0.03155822606225099, 0.03366634276296411, 0.03495090115549309, 0.00897442374844104, 0.042117058765143156, 0.04753725077690823, 0.02930431254208088, 0.05135148271386113, 0.03734400934938874, 0.041072908722396405, 0.04078732351107257, 0.017561342933082154, 0.03764714826164501, 0.03559398611209222, 0.022018415554027473, 0.05864734907767602, 0.06763865732188735, 0.037851200705128055, 0.047949162245328934, 0.014970779352422272, 0.013846835287820016, 0.05576904424067054, 0.0224799431993493, 0.03845553452681218, 0.02089192359043019, 0.041716865596494505, 0.0779217808906521, 0.05410902528092265, 0.04498996585607529, 0.05980651080608368, 0.08677799959800073, 0.026804204464757016, 0.03917448648384639, 0.03564394325284021, 0.10723996268851416, 0.014044929345670556, 0.028179718780198267, 0.0287234526393669, 0.06780589584793363, 0.023569996136107614, 0.01470518039007272, 0.021273501150842224, 0.04207373769687755, 0.013751263630443385, 0.016681316940646087, 0.03275043244606682, 0.04701422919918384, 0.033221559665564976, 0.01681564312561282, 0.07972333207726479, 0.04058265360072255, 0.019888141292280385, 0.033979744517377446, 0.01840338623151183, 0.028574049406285797, 0.06469518598169088, 0.06847921971763883, 0.03991171817428299, 0.024667838654880012, 0.021546865946480205, 0.028013503145692602, 0.014536109819476093, 0.03808007735226836, 0.06608714628964663, 0.01711675152182579, 0.06630801622356687, 0.010006450066742088, 0.05064743138583643, 0.047170763835310936, 0.03976652185831751, 0.02911338975120868, 0.011335601780696638, 0.024100322143307755, 0.10448750574141741, 0.014473684597760439, 0.02288504726519542, 0.03192202261249934, 0.07241040055773088, 0.027086955096040453, 0.05489823614646282, 0.016919816910688366, 0.07169337224747453, 0.028482277545013597, 0.05045890382358006, 0.036639605183154345, 0.021915598838989223, 0.028865914459207227, 0.011820691554541034, 0.031910423056355545, 0.025046686808179532, 0.03634188437302198, 0.07613933046481439, 0.004515484732110053, 0.03682457043656281, 0.01811279003907527, 0.046850508877209256, 0.02582619971196566, 0.04219802495624338, 0.054115186378891976, 0.05117013065942696, 0.020768693149355904, 0.02403363911435008, 0.04468312892796738, 0.007108384169571633, 0.04505873198754021, 0.01949415502271482, 0.043858023559940715, 0.08896183062876974, 0.025969904947227666, 0.042905021126249006, 0.05631884420290589, 0.010331995053482907, 0.055969144217669964, 0.009062164263533694, 0.03056950554517763, 0.037584265028791766, 0.048496343062392304, 0.024902713551585163, 0.00717197689560375, 0.1271191252661603, 0.10685846315962927, 0.06837805693170854, 0.11469307275755064, 0.13575857239110128, 0.106108871953828, 0.15810160418706282, 0.10515519098511764, 0.13428967978273118, 0.08960259838828019, 0.12216978227453572, 0.12964630180171557, 0.17014897987246513, 0.10745598109705107, 0.10944733209908009, 0.1397269165941647, 0.0902724549440401, 0.15158788513924393, 0.08233655363853488, 0.11731365642377309, 0.11487219243177346, 0.11935838099036898, 0.10930663786296334, 0.10992183163762093, 0.11784436580325876, 0.10705395588385207, 0.03861867130867072, 0.14764057552175863, 0.0950957125584994, 0.08411827124655247, 0.14559057195271763, 0.13471521623432636, 0.08153880680246012, 0.1135435462264078, 0.12777524148779257, 0.06866592541337013, 0.15826618964118616, 0.1593106043125902, 0.12588368941630634, 0.17127401807478496, 0.12925486852015766, 0.12460992990859918, 0.1136923421706472, 0.12329710035451821, 0.12296222975211483, 0.12455123662948608, 0.15023882181516715, 0.06352065543511085, 0.12445436897022383, 0.14266654742615564, 0.13010537145393236, 0.10255496336945466, 0.17595436264361652, 0.10646197479218245, 0.17185457263674053, 0.19786305060344084, 0.1129382454923221, 0.11187865199255091, 0.19523873499461583, 0.2474267360355173, 0.11461947884942804, 0.15639306658080646, 0.09676906812403883, 0.1174391582608223, 0.14870879320161684, 0.10682692485196249, 0.1448791551270655, 0.1801613476127386, 0.11522307646061693, 0.1350911653467587, 0.1254416238516569, 0.07813835569790431, 0.16092695615121297, 0.21809057305966104, 0.1324694010296038, 0.12278944759496621, 0.09099611254142863, 0.10197434773934738, 0.16478570337806428, 0.10513679590076208, 0.12698359468153544, 0.07902324678642408, 0.1595688411699874, 0.15605670320136206, 0.08214193622448615, 0.11099131817796401, 0.09200725864086833, 0.16971743160060473, 0.09229980901415859, 0.08454736322164536, 0.1166325972548553, 0.1429528213505234, 0.07177437575800077, 0.07582258353275911, 0.09971580321767501, 0.1778502980513232, 0.15130212690149034, 0.10774831433913537, 0.10352571627923421, 0.16696667777640478, 0.08583691902458668, 0.14632490969129971, 0.08489216079137155, 0.12773352515484604, 0.13482015846031054, 0.18639997499329702, 0.18466847576200962, 0.09745216289801256, 0.20475955839668, 0.11964830543313708, 0.10339522720979792, 0.12114357948303223, 0.11092387858246054, 0.12479415216616221, 0.10899943113327026, 0.1054991539567709, 0.05516606748902372, 0.08317733995084252, 0.18581529493842805, 0.10934416763484478, 0.15563004038163594, 0.1442596526550395, 0.17411101369985513, 0.10176942337836538, 0.20931330190173217, 0.15349870760525974, 0.10455331685287611, 0.1033346951007843, 0.15986059765730584, 0.10618410791669573, 0.1843212829636676, 0.1785816095237221, 0.07760288978793792, 0.19973743573895522, 0.13559208703892572, 0.10148416725652558, 0.14875116092818125, 0.07755894786013023, 0.13180231968207018, 0.14005882878388676, 0.18625514847891672, 0.09076852511082377, 0.09973223055047648, 0.07314387655683927, 0.14293779858521052, 0.130942846515349, 0.16280989082796232, 0.13858438575906412, 0.11858145839401654, 0.176961498601096, 0.13251877123756067, 0.1858507144664015, 0.20100506129009382, 0.19354011757033213, 0.06289650499820709, 0.14749490762395517, 0.16256134345063142, 0.15802366765482084, 0.07720456259059054, 0.10751770742769752, 0.23290079406329564, 0.09088946719254766, 0.18257041834294796, 0.17030439153313637, 0.13881928101181984, 0.1196406108460256, 0.12643080577254295, 0.08054328736449991, 0.08048873993435077, 0.11156680408333029, 0.12725016394896166, 0.13084318329180988, 0.09875649719366006, 0.1394373042775052, 0.08967961889824697, 0.11395387670823506], [0.00858336450931217, 0.03916340261431677, 0.013913689646869898, 0.03601699841341802, 0.06908351621989693, 0.08448444945471627, 0.03464905485244734, 0.018449119491768733, 0.05214545350255711, 0.007542228858385767, 0.011659663320252938, 0.039324385047491105, 0.053189277848494906, 0.058133182381944995, 0.011053965643181332, 0.08373458683490753, 0.022176560014486313, 0.03774966472493751, 0.06687060317822865, 0.019050623822425092, 0.05909956552620445, 0.0348515432727124, 0.05877218595040696, 0.03484021852325116, 0.020060797920450568, 0.01747365585262222, 0.030281087450150932, 0.0339673137558358, 0.04368152981624007, 0.01987630594521761, 0.022773999920380966, 0.020581631222739816, 0.009362970711663365, 0.09054933794374977, 0.11588744366807596, 0.05037173582240939, 0.035778235511056015, 0.02450185202594314, 0.023818797964070524, 0.0313147846609354, 0.021859139636425034, 0.034562748590750356, 0.009553221752867103, 0.030015227251819203, 0.015495454859254616, 0.14572570898703166, 0.0572771697438189, 0.08334249537438154, 0.08958687673189811, 0.07439857601587262, 0.06803595993135657, 0.033354610204696655, 0.06623876493956361, 0.03502456630979266, 0.09693866116659981, 0.02776990907399782, 0.02961578725704125, 0.0415420105148639, 0.044548460082816224, 0.016908709292433093, 0.04898714779743126, 0.06153782004756587, 0.004681152449588158, 0.030414351727813482, 0.023962479450606873, 0.039703234897128174, 0.03677575662732124, 0.020063315285369754, 0.026585168271724666, 0.03120792218084846, 0.034296494842107804, 0.02509677456691861, 0.040762007369526794, 0.0713334840589336, 0.02852064530764307, 0.029228632138775926, 0.055782709935946126, 0.04758434110720243, 0.014576833794957824, 0.08544623213154928, 0.0893780847213098, 0.018960772215255668, 0.03020658091242824, 0.016737830426011766, 0.010372933615664286, 0.03183808783069253, 0.025243132874103527, 0.035034306679985354, 0.040559423954359124, 0.029161382533077682, 0.04833821726164647, 0.01978700395141329, 0.007483717087390167, 0.05265553202480078, 0.05098678710471306, 0.02004269290981548, 0.029219566910926784, 0.038432728964835405, 0.08285511045583657, 0.013481716442454075, 0.05252144332709057, 0.042310621057237895, 0.03942280655194606, 0.020692534378862808, 0.04483252537569829, 0.05605825622166906, 0.02918904979846307, 0.03779829193704894, 0.061058041506579945, 0.024037829068090235, 0.03647962358913251, 0.007869356528057583, 0.03877753331991179, 0.07697282252567154, 0.017285827181435058, 0.038670745478676896, 0.0680900120309421, 0.01327786925581417, 0.046869212694998295, 0.04433682161782469, 0.08265881706029177, 0.01873505923763982, 0.03503112435074789, 0.018043791509366462, 0.02909171734271305, 0.0012844647759006225, 0.07124247894223247, 0.04950415416221533, 0.02497508270399911, 0.027812276800562228, 0.01883889375520604, 0.009184336189978888, 0.07810269868267433, 0.030744665967566625, 0.03208253685651081, 0.06992948653974704, 0.0819238211427416, 0.02196276550447302, 0.03960705595090985, 0.01616775753375675, 0.02602043714640396, 0.04521846591628023, 0.015050127237503017, 0.024262130692867295, 0.012892447794521493, 0.019255846738815308, 0.025990121898108294, 0.01803663296491972, 0.05100552824192813, 0.07474431674927473, 0.020013934899387614, 0.03310996101104787, 0.005464766673477632, 0.016820009498457824, 0.06225235813430377, 0.06672285896326814, 0.015085519624075719, 0.024187417201963917, 0.10475540493748017, 0.05017782408478005, 0.03668235967467938, 0.023448918347379992, 0.028755041837160076, 0.008578255140621747, 0.05930778756737709, 0.06482366658747196, 0.02081118810123631, 0.027860233959342753, 0.03305835163752947, 0.06785493357373135, 0.022674016089045575, 0.015917949777628695, 0.019973903029624904, 0.04610719412033047, 0.06954525930008718, 0.030966814939997027, 0.04069115813555462, 0.07472989788012845, 0.011959003284573555, 0.05501360067033342, 0.019088565804330365, 0.10709750426134892, 0.047385784797370434, 0.02707035473680922, 0.06917498952576093, 0.022178543033078313, 0.03501436792846237, 0.05690075922757387, 0.06262876186519861, 0.008465140808506735, 0.02463206459235932, 0.03800452247794185, 0.04460668856544154, 0.026488865492865443, 0.04851633948939187, 0.04890523165730493, 0.008156528663156288, 0.013507526218225914, 0.05969765343304191, 0.04350210480125887, 0.020754727202334573, 0.010928502821895694, 0.039013989203210385, 0.03662433135988457, 0.05576115966375385, 0.02476049091533891, 0.0566794007484402, 0.033709019222962, 0.044789133061255725, 0.007443795479567987, 0.04873472598514386, 0.08835846371948719, 0.0015177437370376928, 0.04729811128761087, 0.07244692609778472, 0.07795255245374781, 0.02867373977122562, 0.0442804896405765, 0.025525011587888002, 0.046738313111875734, 0.01525589298190815, 0.05939881982547896, 0.017199147725477815, 0.09061893528061253, 0.008062794987511421, 0.08499656018934079, 0.02845333463379315, 0.019619865509282266, 0.011777868361345359, 0.041019684435533624, 0.041693184724343677, 0.035439025677208386, 0.061634348439318795, 0.027265613366450583, 0.006998327909968793, 0.019819342930402075, 0.02797114729349102, 0.03543635564191001, 0.01176590918164168, 0.04004372716216104, 0.06518744278166975, 0.017754420072638562, 0.03482306855065482, 0.055336047296545336, 0.028946395497769117, 0.018177686824596355, 0.03924560034647584, 0.03885387868753501, 0.018267328085909997, 0.00980062410235405, 0.06539964103805167, 0.03532692490677748, 0.06095788973782744, 0.053230257970946174, 0.007983747354176427, 0.037505069814090214, 0.0649118082863944, 0.023759387134175216, 0.0307185729034245, 0.021639409641336118, 0.02643756315644298, 0.008077022170514932, 0.06566840197358813, 0.02532960198420499, 0.012409300327167978, 0.048469588426606994, 0.04315192984150989, 0.004751005509336079, 0.01953828185131507, 0.04974037255825741, 0.03280472542558398, 0.07764515573424952, 0.03863058977627328, 0.031983677696968825, 0.06449549312570266, 0.0912223903994475, 0.05803383806986468, 0.008131439830841762, 0.04377687416438546, 0.0430613555945456, 0.04935052704864314, 0.058597972084368975, 0.021947496770215884, 0.02153606027630823, 0.033075009672237296, 0.028423753899655173, 0.01552565475659711, 0.02415458967776171, 0.027317884311612164, 0.051146907798413715, 0.009165192172596497, 0.04395334755203553, 0.07515987195074558, 0.0462017581532044, 0.02348481454620404, 0.030517020861485174, 0.047316136570381265, 0.01826361649935799, 0.04413657575579626, 0.07146228357617344, 0.02732205221296421, 0.023778423434123397, 0.01990067892308746, 0.13219673851771013, 0.06479939538985491, 0.012694936428618218, 0.025247729948854873, 0.050070177896746566, 0.06261738283293587, 0.010146280867047608, 0.020346630797056214, 0.019217782620606676, 0.036238194044147215, 0.06232574848192079, 0.01945546834862658, 0.021771544158192616, 0.033716242228235514, 0.012132081452624073, 0.014243428828194737, 0.024952899697901945, 0.06349558356617178, 0.02566628766778324, 0.09255067698125329, 0.054669454494225125, 0.02135364631456988, 0.04907732170873454, 0.025140604536448206, 0.020503243464710455, 0.012378464303245502, 0.021119337994605303, 0.020495589589700103, 0.06478199096662657, 0.05871991839792047, 0.014490303616704685, 0.020491947552987506, 0.0503937203570136, 0.0377352085363652, 0.04559588744970305, 0.03005350680489625, 0.017854904323550205, 0.0634388444679124, 0.005853129159991762, 0.024812785609226142, 0.03314044080408556, 0.006821339259788926, 0.008750699726598603, 0.029589843470603228, 0.04518602515703865, 0.0510976665121104, 0.022303893896085874, 0.04138475663161703, 0.0592273065288152, 0.11068410466292075, 0.2241058267120804, 0.13294145784207753, 0.16240514468933853, 0.10880060001675572, 0.21151984349957534, 0.1583752573600837, 0.17548139659421785, 0.1419754730803626, 0.07176205356206213, 0.0997961824759841, 0.14169525168836117, 0.11919063356305871, 0.1266042393233095, 0.0926900345033833, 0.22810854549918855, 0.11378908090825592, 0.06729922017880849, 0.16129880691213266, 0.10049519568149533, 0.11194875823067767, 0.17438294339392865, 0.1485520787537098, 0.1072686104370015, 0.08914440404623747, 0.0999305731217776, 0.15114527674657957, 0.134903862540211, 0.19240636697837285, 0.07766512501984835, 0.08842846817736115, 0.10581203323921987, 0.17771095409989357, 0.1459247368787016, 0.14732854440808296, 0.1764367331883737, 0.12011615532849516, 0.13689001596399716, 0.21170121591006005, 0.10163145685302359, 0.07925148561064686, 0.20504333531217916, 0.10832912674439804, 0.18007427799914563, 0.150542819074222, 0.24794559819357737, 0.11238267458975315, 0.17649952481899941, 0.1935003147061382, 0.17028232557432993, 0.1567175555974245, 0.12600057385861874, 0.1449608371726104, 0.13460171089640685, 0.253219905176333, 0.11258274064000164, 0.13763758513544286, 0.16294517713998044, 0.11403782506074224, 0.09149565002215759, 0.12821432149835996, 0.11432290476347719, 0.09343477418380124, 0.1398169853325401, 0.15285395005983965, 0.08118094743362494, 0.10711412836930581, 0.0999263594193118, 0.08310192078351974, 0.09521415763135467, 0.1479497296469552, 0.09407024258481604, 0.09838825623903956, 0.2206010983458587, 0.09654601330735854, 0.21809188941759722, 0.15253995119460992, 0.12423152449939932, 0.11954109690019063, 0.11324455655579056, 0.15514598707003252, 0.13710223457642964, 0.2497725673019886, 0.08189598763627665, 0.09265654201486281, 0.056267122871109417, 0.14636649031724247, 0.06296365960900273, 0.07410041415797812, 0.14573554774480207, 0.18447486257978848, 0.08718383139265434, 0.10388515663466283, 0.11509836172418934, 0.14502257028860704, 0.14494084753096104, 0.14615927929324762, 0.1207855436950922, 0.19243844811405453, 0.19043372997215816, 0.10416830251259462, 0.07827853424740688, 0.10757222093109574, 0.09563944302499294, 0.14227746187576226, 0.11084215582481452, 0.08781624638608523, 0.13939765069101537, 0.12506171209471567, 0.07950797863304615, 0.08993328921496868, 0.17754779356930936, 0.10856506694108248, 0.1433050488787038, 0.15293403076274054, 0.09643004488732133, 0.15594862614359173, 0.21765405791146414, 0.07728048387382712, 0.09933515185756342, 0.1483329797961882, 0.06336485022412879, 0.07754438649863005, 0.24266559151666506, 0.09384021242814404, 0.11334616038948298, 0.1411446069500276, 0.19988888475511754, 0.06675363731171403, 0.15484455467334815, 0.09248345451695578, 0.1537817381322384, 0.1560576802917889, 0.1081336068787745, 0.089252671093813, 0.17614235755588326, 0.21561012044548988, 0.09231763412909848, 0.11115009537232773, 0.09128446278295346, 0.0905738262725728, 0.10123205078499657, 0.15417832827993802, 0.11467932563807283, 0.11351690694157567, 0.05746481181787593, 0.09638767716075693, 0.1448829820645707, 0.10496410873851605, 0.15291127269821508, 0.10879910723971468, 0.0964166573914034, 0.08462711822773729, 0.11325135547667742, 0.1558029989578894, 0.16562019288539886, 0.15189105458557606, 0.08215828891843557, 0.13324411160179547, 0.1950476188212633, 0.09502726194581815, 0.1478309045944895, 0.11603136094553129, 0.09149731921830348, 0.15236772543617658, 0.1598939544388226, 0.06609151605516672, 0.1006000293418765, 0.09146143828651734, 0.10725959949195385, 0.13711717591754027, 0.10845347507191555, 0.18429365301770823, 0.17264592088758945, 0.1816345557038273, 0.1241906224084752], [0.020246065121942332, 0.034900886339268515, 0.06160424862589155, 0.028485636293355907, 0.06900168489664793, 0.051686322782188654, 0.01001776209367173, 0.033885377259658914, 0.012937052990309894, 0.01749499747529626, 0.025023779465949962, 0.00999441709635513, 0.04353464055540306, 0.021060799082208956, 0.02941159571387938, 0.05629326682537794, 0.017601900667484318, 0.017922883354393498, 0.017061679923374738, 0.06060393873069968, 0.029486787571970905, 0.07432264794728585, 0.018006806261837482, 0.02079346646288676, 0.060565974696406295, 0.03952028489272509, 0.0190210244285741, 0.027080704092181156, 0.05028850671702197, 0.030401842934744697, 0.029234728775918484, 0.048836974427103996, 0.017851886539054767, 0.033824526239186525, 0.04208131354036076, 0.022881946360160197, 0.09019889496266842, 0.043141382014645, 0.010288703671124364, 0.018364472248192345, 0.0221835200874401, 0.015436698815652301, 0.08623518515378237, 0.021024543259825026, 0.01985344779677689, 0.03735946976978864, 0.01698358223906585, 0.014763366464259369, 0.051663313659706285, 0.04418627166056207, 0.017843835721058503, 0.005645773947305445, 0.0055817694353338864, 0.014001358915785593, 0.03681623124118362, 0.030991364336971725, 0.022903528862765858, 0.010453442643795694, 0.05423756356218031, 0.08846202173403331, 0.03223447781056166, 0.03802263597026467, 0.011544627885866379, 0.04224198045475142, 0.031253669011805735, 0.0665212187117764, 0.0571595931957875, 0.05356895551085472, 0.017762677843815515, 0.0173923877134387, 0.01462839906370001, 0.05033466745434063, 0.0014740846735159202, 0.04981099448299833, 0.07174006902745791, 0.01625628599763981, 0.07583432218858174, 0.04694434009226305, 0.04834779817610979, 0.046540710143744946, 0.029772271003041948, 0.015749859690134014, 0.011903376135575985, 0.06520801596343517, 0.045070792947496684, 0.05802652346236365, 0.043300325450088294, 0.01978834405807512, 0.029942858099405254, 0.018854915663333874, 0.011659056031411248, 0.040935485025069544, 0.04012188421828406, 0.03947324545255729, 0.05122283586700048, 0.030017059296369553, 0.11498978255050522, 0.024418166605755687, 0.02842417968037937, 0.009880816763533013, 0.024868042108469775, 0.016478506216247166, 0.034551186354032586, 0.007101541992077338, 0.02870616695976683, 0.025027664078931724, 0.00908910295194281, 0.06959069400493588, 0.07316653962646212, 0.05925737241549151, 0.023147647102762545, 0.008991102987368191, 0.015720404484974485, 0.03136477233575923, 0.044354765476392846, 0.02079038761023964, 0.03307363224614944, 0.043800287015203915, 0.019450360676273704, 0.019872129562177827, 0.016267151039625918, 0.025267829852444783, 0.046473623386451175, 0.042688497209123204, 0.03675159738798227, 0.018336614993001734, 0.020499555626884103, 0.03959096110026751, 0.026781614337648665, 0.024463604703279476, 0.040110668034425805, 0.022339272711958204, 0.006821471150033176, 0.02946657401376537, 0.027732701606250236, 0.01826656303767647, 0.04305203930873956, 0.04578281366931541, 0.035956961634968004, 0.01980103605559894, 0.047483293672225306, 0.078240224160254, 0.04632840332176004, 0.021868432173505425, 0.023022871298183287, 0.021273536773930703, 0.02120639743017299, 0.03203573151092444, 0.023262992966920137, 0.012579398878317858, 0.02674851879211409, 0.10974020138382912, 0.016596523812040687, 0.031883298618985076, 0.019377538601734808, 0.016526402306876013, 0.03767974508394088, 0.02029006981423923, 0.03547360382175871, 0.021681290519024645, 0.08954730456961052, 0.054049823100545576, 0.043102142334516556, 0.05135683296248317, 0.015170534972899725, 0.004958614324485617, 0.02665858406440488, 0.06974462645926646, 0.05676320321591837, 0.015423479257151484, 0.04852830884712083, 0.028616451059601138, 0.05226610381422298, 0.02293534197711519, 0.04007129603996873, 0.06399335685585227, 0.03461492793368442, 0.043108992145529816, 0.01664638426154852, 0.01606128690764308, 0.06958951335400343, 0.049250256536262374, 0.011551132492188896, 0.06717649354998555, 0.023017736484429667, 0.057859264580266814, 0.01866558234074286, 0.0420652254750686, 0.0773127210725631, 0.058906461245247295, 0.03128042704026614, 0.02094082730556173, 0.0358474223342325, 0.022981098986097744, 0.021838832779654434, 0.05616751732304692, 0.022546275086434822, 0.052041715676231046, 0.03010049196226256, 0.01747610536403954, 0.04472194791638425, 0.019079863592716198, 0.011666592010962111, 0.06237938667514494, 0.023718074529564807, 0.07576682831027678, 0.04667480562680534, 0.040674157440662384, 0.016583010787144303, 0.030981488259775296, 0.03724611370957323, 0.07817517300801617, 0.06324891573084251, 0.06740405383918967, 0.012027497153862246, 0.07340432543839727, 0.049500171161655865, 0.021466495169858848, 0.010070490201802125, 0.04720767614032541, 0.034078013351453204, 0.02913940478382366, 0.036770857604486604, 0.020398145175672004, 0.028822084489677633, 0.1099947402253747, 0.04456683820379632, 0.041302413014428954, 0.02236463126194264, 0.04624581882464034, 0.013071510641436492, 0.03811306772487504, 0.03989436124850597, 0.03314121433400682, 0.02962645043485931, 0.02246419100889138, 0.042915738586868556, 0.06438545510172844, 0.06982707524938242, 0.015668420220858285, 0.041445061431399415, 0.018470474685143148, 0.06868389980601412, 0.030200962642473832, 0.013474543479138186, 0.015588483706648861, 0.02227070165931114, 0.03620244203401463, 0.04860248629535947, 0.030902428752077476, 0.03910699939089162, 0.02742026506790093, 0.03356214353282537, 0.03624430085931506, 0.029263831142868315, 0.03913347582731928, 0.016103495178478103, 0.03109761274286679, 0.019271620981661335, 0.03980658595849361, 0.137188299958195, 0.06834586723042385, 0.048215259930917194, 0.03721692313307098, 0.04937569051980972, 0.038997673828686984, 0.007896293520129152, 0.01943858470102506, 0.05165116109752229, 0.01057610396362309, 0.006577596758558814, 0.03545599244534969, 0.013029098810095872, 0.020589463213192563, 0.040567376384777684, 0.061146169634802, 0.015772744979975478, 0.007017982949037105, 0.02656154677138797, 0.03144212193521006, 0.03907074187217014, 0.046512740930276256, 0.06470628002924578, 0.09157476041998182, 0.09174679618860994, 0.03927719972229429, 0.03953548068446772, 0.010773340522843813, 0.029698439607662813, 0.08034847996064595, 0.05188675524134721, 0.051323007991803546, 0.011285695530075048, 0.033517424682421346, 0.044291234242596796, 0.027066283526697328, 0.06269504116582018, 0.03167708504146763, 0.020937280263751745, 0.04671871702053717, 0.011215764014715595, 0.028513985486435037, 0.034958975722215006, 0.0738593985193542, 0.018916580925828645, 0.0286860008990126, 0.039179219265601466, 0.049074892553367784, 0.01877154745826764, 0.028067791036197116, 0.030432112381926606, 0.07195904584867613, 0.04512154397421649, 0.07730179665876286, 0.022759187500923872, 0.022774629261610762, 0.04754280458603587, 0.04173099948093295, 0.030600592627057006, 0.04381680255755782, 0.014610567163409931, 0.05238027072378567, 0.04513823254300015, 0.02603474405727216, 0.06952894731823887, 0.039371285387980084, 0.008870243178015309, 0.025697778477998715, 0.0713651105761528, 0.01456066600180098, 0.0457289990569864, 0.012033564105097736, 0.008629148659695472, 0.051665803883224726, 0.011000162057046379, 0.02023979545837002, 0.05144971762118595, 0.017904601924653565, 0.03608300969270723, 0.02138838221851204, 0.026721128029748797, 0.026632263691031506, 0.02537566263760839, 0.07229066626834017, 0.01870106972221817, 0.032413200541798554, 0.02923981100320816, 0.038546132522502115, 0.020288000282432352, 0.01892567329507853, 0.02139535077315356, 0.07873798387923411, 0.14598850559975418, 0.20166024113340036, 0.17418912665120193, 0.1000688789146287, 0.20044950395822525, 0.1878243014216423, 0.0994775899286781, 0.18531332830233233, 0.1756288693951709, 0.11589874806148664, 0.14953366108238697, 0.07825260063899414, 0.09495843135352645, 0.11246517766267061, 0.11040237692317792, 0.12641263460474356, 0.20886659515755518, 0.10396157324846302, 0.09924515775804009, 0.17843956500291824, 0.14394139258989266, 0.16261360421776772, 0.08727940305003098, 0.07878195294844252, 0.15499130822718143, 0.10872135391192776, 0.12678253118480953, 0.13826843271298067, 0.07687967323831149, 0.13722947346312658, 0.20783864174570355, 0.13337117406938756, 0.1072953175753355, 0.13619822237108434, 0.19734485340969904, 0.14054464628653868, 0.18370738519089563, 0.14149973860808782, 0.08604034382317748, 0.18605550990572997, 0.11632338884685721, 0.11982719440545354, 0.10790043510496616, 0.08005017561039754, 0.14806246145495347, 0.11449565977922507, 0.11459414235183171, 0.06583901960402727, 0.1809881425329617, 0.1483100453125579, 0.20458609770451272, 0.1343179882637092, 0.048203531453119855, 0.09972205252519675, 0.10279669825519834, 0.14253283531538077, 0.13915888778865337, 0.06385911548776285, 0.11712946130761079, 0.16316129054341996, 0.1080640773954136, 0.17290712972836836, 0.14977113476821355, 0.09955256126288857, 0.16889154591730662, 0.2236787432006427, 0.1602979406182255, 0.15089789644948073, 0.12272056271987301, 0.07975390007985489, 0.08090519080204622, 0.10754744761756488, 0.13607289695313998, 0.12302070590002195, 0.20656889916530677, 0.06470673464770828, 0.1202554449971233, 0.08841097554458038, 0.1557812722665923, 0.21370041077690466, 0.09867677611431905, 0.09281406391944204, 0.10507420104529176, 0.12356246182961123, 0.14515846728214196, 0.13122776336967945, 0.1244295888713428, 0.16598086138921125, 0.15838330478540488, 0.12985472061804362, 0.10551104189029761, 0.16823317695941242, 0.13938432426324912, 0.15008084529212543, 0.17123819142580032, 0.11133572219737939, 0.15303306973406247, 0.05511169308530433, 0.15908865550799028, 0.16263888643256255, 0.15305757841893605, 0.11305835297597305, 0.10484638969813075, 0.1768366074455636, 0.13982334999101503, 0.12474134857101099, 0.17346426126148018, 0.18274161272815295, 0.2422777951828071, 0.16997572274080344, 0.10963250430566923, 0.13973708104874405, 0.08974790666252375, 0.15838561180446828, 0.14232174307107925, 0.09200696687081031, 0.1070824543546353, 0.08151559411947217, 0.21535615835871014, 0.11526696410562311, 0.1271246349705117, 0.1730291846075228, 0.13591838095869335, 0.103055315092206, 0.1584754226995366, 0.11155212058552674, 0.09148404707333871, 0.25486453835453304, 0.12293670326471329, 0.1493077767746789, 0.18293475093586103, 0.14966889311160358, 0.11193269730678626, 0.17280999065509864, 0.13661515499864305, 0.17130630277097225, 0.14455366187861987, 0.0758005040032523, 0.0791969924632992, 0.13686322740146092, 0.12564533363495553, 0.11601903874959264, 0.19942178124827997, 0.10619787539222411, 0.13685268296727113, 0.20409109283770832, 0.09904232328491551, 0.19939694686659745, 0.15205531434289046, 0.11491400375962257, 0.12821600426520618, 0.15293868551296846, 0.090712681678789, 0.09316718711384706, 0.13214658120913164, 0.09197495358863048, 0.11350191810301372, 0.20729651940720423, 0.15144259722105094, 0.0940496286909495, 0.16123516032738344, 0.10193604443754468, 0.205138588058097, 0.18516334492181027, 0.12230361652161394, 0.060657434431569915, 0.10635130573064089, 0.15195271984807082, 0.16437429402555737, 0.07699659839272499, 0.10847535782626697, 0.15395944645362242, 0.23331654603992188, 0.08688750157931022, 0.09661292364554745, 0.21219684502908162], [0.057463447962488444, 0.03603502030351332, 0.026654127785669904, 0.06899532023817301, 0.011832292807022375, 0.020389780535229614, 0.049110983831009695, 0.018424531079030464, 0.017591578453513126, 0.02434859301761857, 0.006110170523502997, 0.044277147855609655, 0.0075943886934380445, 0.05766374471464327, 0.0682807821514351, 0.10721076532666172, 0.06001296865620783, 0.026182315245802914, 0.031211423421544687, 0.0749096485919186, 0.027757809098277773, 0.05244344911937203, 0.02129364007019571, 0.016719443823343942, 0.029930403589137962, 0.015167814047474946, 0.043532248719462326, 0.005454218846612743, 0.025010804180055857, 0.032458967728806395, 0.0368756844795176, 0.021175179730302522, 0.05430189546729837, 0.040328087617776225, 0.03955683418150459, 0.027073839014129977, 0.025222218728491237, 0.05202778874497328, 0.06764941888728312, 0.014865336706861854, 0.05308816595269101, 0.016186780263004557, 0.028960247790174823, 0.03554403575669442, 0.05068978554170046, 0.028353578111689006, 0.026890785533136556, 0.012744102227900709, 0.011847472483558314, 0.024661482478092824, 0.040097182150930166, 0.03460209005113159, 0.010189355118200183, 0.017143195727840066, 0.0248205378718142, 0.013480319508484431, 0.03817942166434867, 0.04019652985568557, 0.034475757008684535, 0.018329371631677662, 0.008344625355675817, 0.02116840286180377, 0.015072393364139965, 0.05492224610809769, 0.04259736995611872, 0.08032581689102308, 0.03892004263720342, 0.06371323724410363, 0.010571499255352786, 0.028528431496982063, 0.11151041782328061, 0.02913561516574451, 0.06889784189739398, 0.030224904750606844, 0.06907972999449287, 0.019413531491799012, 0.03370812016406229, 0.03147923780073013, 0.033322223728256564, 0.02969500282779336, 0.016164529403405528, 0.013307851173781922, 0.029466950600700717, 0.052080565198723755, 0.017528618885470287, 0.06973940173962287, 0.03981026701096978, 0.12129747122526169, 0.031702787947974036, 0.05438146726893527, 0.03512725579951491, 0.011229774066513138, 0.041545277660978694, 0.07003875781915017, 0.09712486474641732, 0.004755303604594831, 0.0310904779471457, 0.017129947331600955, 0.023953809469406093, 0.01752119740870382, 0.036880895628460815, 0.028281022362144928, 0.009683408026051308, 0.012233311243887459, 0.03196036662640316, 0.027247906995138953, 0.011643301296447004, 0.025356651782723408, 0.058347219468227456, 0.043804649995373826, 0.0288088971615902, 0.10145005051578794, 0.03915866983256169, 0.05781610296773059, 0.08302685445440666, 0.038222810586116145, 0.01595112674736551, 0.08150979943041291, 0.02417853517856981, 0.024426979079310383, 0.025041755554931502, 0.01795898481006069, 0.027423827376748835, 0.06801446394196578, 0.03494676209187933, 0.01630490642440106, 0.007163082149678043, 0.08690509599234376, 0.03550977652360286, 0.020615213617150272, 0.012720535010365503, 0.041498692839273384, 0.008503400005533226, 0.012699259544855781, 0.013492948741519024, 0.023002350702881813, 0.0020068294460153474, 0.026362607089270438, 0.03189052501693368, 0.03027836313205106, 0.07378391828387976, 0.016236985069034354, 0.03138925727190716, 0.0081709178463955, 0.07190515659749508, 0.04289595929107495, 0.0134824814906876, 0.061900795570441654, 0.03474124062008091, 0.10678210082863059, 0.029916792176663876, 0.03281140899551766, 0.01297244368054505, 0.03370126696037395, 0.0607352556128587, 0.014851645566523075, 0.019576410430350473, 0.041157186164387634, 0.07245523815176316, 0.02488444738888315, 0.07108919109616961, 0.049836202058941126, 0.04444763995707035, 0.0302173458704991, 0.02150388414572392, 0.017159575563190237, 0.014303718360939195, 0.037397230243576426, 0.02914565409134541, 0.04075549682602286, 0.029672906334911073, 0.03156583922516022, 0.03747182159817644, 0.026454280562964932, 0.02073823710504387, 0.08999761433473655, 0.047067290637642145, 0.04243131886635508, 0.029819649710719074, 0.009218323160894215, 0.0035761776796009925, 0.02438701845572463, 0.02695808093994856, 0.020299435293834125, 0.06278563916151013, 0.06186042952218226, 0.05539951067683952, 0.046060823037156036, 0.032295162589954476, 0.04531466182587402, 0.03981010076989021, 0.054668032963361056, 0.03244261164218187, 0.0395570275639849, 0.05515542805993131, 0.048386827510382445, 0.008584149913596255, 0.06795693774308477, 0.07042694770331893, 0.01008938146489007, 0.02098995154457433, 0.017299791432118843, 0.0480939175135323, 0.0345939510235829, 0.033813896988119395, 0.02005301682012422, 0.0025375803857709146, 0.0363922757761819, 0.06547901606453316, 0.0653409952563899, 0.022255032589393, 0.02164102964369314, 0.04324036670316543, 0.045661131984421184, 0.006759148556739092, 0.018141741431983452, 0.060172587233994684, 0.0318074282258749, 0.033360238652676344, 0.03966881620830723, 0.076791165130479, 0.024146016387801086, 0.03587525923337255, 0.018922538463292376, 0.02543698693625629, 0.01177941118034401, 0.02559490578382143, 0.036729436434273205, 0.0675310959507312, 0.058073417017502446, 0.02111235586926341, 0.07657763694546052, 0.041652282633419545, 0.03940169393484082, 0.017279739025980234, 0.0196800159423479, 0.02421798350821648, 0.036302790577922545, 0.020205183387068764, 0.007273713043624801, 0.05585579155012965, 0.024445526834045137, 0.0069551726586983675, 0.0065292214525730485, 0.02449731432300593, 0.05439797941861408, 0.0515208280911403, 0.004954310292045453, 0.06561365098293338, 0.07577823448394026, 0.05660528436835323, 0.012803644523955882, 0.08590882338051285, 0.03965970009033169, 0.008719891692245645, 0.021377294956307327, 0.024713617716250674, 0.08537822256663016, 0.02086331316136888, 0.0035745377452777965, 0.053087802936456034, 0.05085631160597716, 0.015098533925733395, 0.04115190037659236, 0.03214532509446144, 0.036132895587278266, 0.02470282731311662, 0.018699330976232886, 0.021682988552908813, 0.09757901501974889, 0.06148638030780213, 0.03853037015401891, 0.04028388445398637, 0.05889291090092488, 0.013510272588713892, 0.02879592017935855, 0.05529071097927434, 0.06645430158823729, 0.028159444153841053, 0.028165578110409633, 0.06294221790241343, 0.043452968687883446, 0.023544293229601214, 0.00942722034441041, 0.046378720086067915, 0.034771520245288096, 0.027067666041797826, 0.07603646455598728, 0.025645151301952343, 0.03491028404927679, 0.022349313333896653, 0.024751987175217698, 0.048647931178233454, 0.06874136493674346, 0.02364877235543515, 0.05653362428503377, 0.009104990849404462, 0.02369374904914626, 0.035287196681435616, 0.02057791793985026, 0.12683504979525292, 0.02011729953145342, 0.026355706388130784, 0.03696531895548105, 0.03591346414759755, 0.023010430358616368, 0.026193519555298344, 0.04946231230029038, 0.016217948769086173, 0.05927822379661458, 0.020326870160975626, 0.026913217900853072, 0.002321503241546452, 0.06404413163129773, 0.026908396909545575, 0.017172596650198102, 0.06356030223625046, 0.05597661488822528, 0.019732772040047815, 0.014085474357541119, 0.0077304807657908115, 0.05359095022348421, 0.04518724312739713, 0.08849363468055214, 0.013028870652695852, 0.011670591974897044, 0.03834464833406465, 0.030812831595540047, 0.03525007403056536, 0.014810972481167741, 0.022234322004286305, 0.04955174660842333, 0.020785527603168572, 0.08362712045865399, 0.01088114786294422, 0.029474635009786913, 0.061532649610723765, 0.020589658292010427, 0.029809525968240838, 0.020188776410317848, 0.01515627047047019, 0.031214605750782148, 0.023608389343800287, 0.05046615057757922, 0.05519795863490019, 0.034295843448489904, 0.032063334315483055, 0.004176747752353549, 0.08780034152524811, 0.012372162409259804, 0.015283166696982724, 0.0609239697722452, 0.10812918283045292, 0.07806598993816546, 0.08881497529468366, 0.07062186367277588, 0.09391546874706234, 0.1171804599996124, 0.0976297694391438, 0.09196756434227739, 0.13676238352698938, 0.1679431710924421, 0.1831273598862546, 0.13724797032773495, 0.10737376300884144, 0.14625165505068644, 0.13666098325380258, 0.16144089214503765, 0.133066932537726, 0.1344478598662785, 0.11525248416832515, 0.1606445498764515, 0.09978485094117266, 0.17872532324067184, 0.11671906975763184, 0.18207166796284063, 0.1320797319390944, 0.0907025443656104, 0.17272620515099593, 0.10194933693856001, 0.10717179027519055, 0.11032634028898818, 0.18165545458240168, 0.09362407866865396, 0.18329722434282303, 0.19403122764612946, 0.12255337169127804, 0.13010853342711926, 0.10597359242716006, 0.11108328681439161, 0.1324574045304741, 0.07332856700356517, 0.1004432945379189, 0.08980370259710721, 0.10765117526586566, 0.1787775975785085, 0.16441648533301695, 0.1226084144519908, 0.08173768541642598, 0.069109280194555, 0.15857789505805286, 0.06220914223896606, 0.10996304585465363, 0.0988993491711361, 0.15329810551234654, 0.12483069806226663, 0.11922055695738111, 0.09478760337723152, 0.10371663567743131, 0.09799568301865033, 0.06439363144870315, 0.07197600243879215, 0.08798413630574942, 0.07304462723966156, 0.12839874731642859, 0.09321984143129416, 0.16544112749397755, 0.181301069312862, 0.10626610887369939, 0.09946421600346055, 0.11951818955796105, 0.1374717918889863, 0.1266690937003919, 0.0945620583370328, 0.12816636264324188, 0.122189622638481, 0.13982302429420607, 0.11449129001370498, 0.1768748089671135, 0.16571757623127528, 0.11356293875724077, 0.17385806941560336, 0.10744264788393464, 0.14334035984107427, 0.1624319739639759, 0.27271182781883646, 0.09010795769946915, 0.11262433483664479, 0.21337282764060156, 0.21569611797375338, 0.08657114819756576, 0.17999456370515482, 0.08577729615249804, 0.12186229734548501, 0.09694360768688576, 0.21134337011192525, 0.16861934480922564, 0.1723138458494629, 0.12200382617967469, 0.1040863897651434, 0.2100056383226599, 0.09909853312586035, 0.23778459057211876, 0.13027286103793553, 0.12093820050358772, 0.08244864083826542, 0.11525204990591321, 0.18635748513042927, 0.09510109334119729, 0.1954383057143007, 0.13258285208472184, 0.171711266040802, 0.24127687460609845, 0.09516669410680022, 0.10872904171368905, 0.11175083635108811, 0.15217791205005987, 0.16870667226612568, 0.08095222006418876, 0.2905266561678478, 0.15984699981553213, 0.1432631289852517, 0.08537343889474869, 0.09924908647579805, 0.1299617120197841, 0.09895615612289735, 0.22372143662401608, 0.13391233288816043, 0.06710412779024669, 0.10356652337525572, 0.16608817848776067, 0.0938724631975804, 0.08320332784205675, 0.15170440317264625, 0.07792117020913533, 0.13957679750663893, 0.1180296465754509, 0.09592405453856502, 0.08087129797786474, 0.14890664044235433, 0.0797199597582221, 0.1363955946373088, 0.26906293790255276, 0.1207982458706413, 0.13621559286756174, 0.09996808253760849, 0.13499203138053417, 0.16569118121904985, 0.05978756610836301, 0.16732957187507833, 0.09235930296459369, 0.18709282710083894, 0.11540036409028939, 0.13831613372479165, 0.12819358546819004, 0.09262590615877084, 0.1205325722694397, 0.0900563279699002, 0.0998724837388311, 0.2269103340804577, 0.16949483140238694, 0.09909499795841319, 0.14295667542942933, 0.09971274981009108, 0.21153008937835693, 0.15403804795018264, 0.0682389640382358, 0.17508739845028945, 0.1149716249534062, 0.16258886483098778, 0.1972082100276436, 0.10272528922983579, 0.13631362760705606, 0.06636137621743338, 0.20428319967218808, 0.0715434295790536, 0.15796702355146408, 0.149141060720597], [0.04386044932263238, 0.04495043440588883, 0.02249950197126184, 0.052639067372573276, 0.005646405833041561, 0.022619080197598253, 0.08490079175680876, 0.021125656851966466, 0.04146789752745202, 0.024510589860645787, 0.027095552134726728, 0.04947374561535461, 0.021817022967817526, 0.03120564908853599, 0.03444446636629956, 0.02996792657566922, 0.08809255263102905, 0.045179809776267836, 0.030197101778217723, 0.03263439956520285, 0.02715415720428739, 0.01697877312212118, 0.05511905858293176, 0.010305798512750437, 0.03984068234318069, 0.0448339265505118, 0.035867971767272265, 0.032840670818196874, 0.04032622503915003, 0.05413823960615056, 0.05383556888305715, 0.04924855002069047, 0.05171389505267143, 0.039006379432976246, 0.04260041657835245, 0.06655560008117131, 0.01956883119419217, 0.02395404695666262, 0.04386991488614252, 0.04490306926891208, 0.05598180228844285, 0.03291961497494152, 0.007251372278135802, 0.025148950517177582, 0.049276227464101145, 0.04403722805104085, 0.03333048489210861, 0.06380592512765101, 0.051666268679712496, 0.045444479145641835, 0.006090733887893813, 0.03990425768175295, 0.030569071282765696, 0.007661243052487927, 0.017206743925011585, 0.02818644306223307, 0.0656750855435218, 0.05794509926012584, 0.0397841976955533, 0.02305462334438094, 0.06494583003222942, 0.05919323728552886, 0.05244821582787803, 0.016311606957710216, 0.027863112644159367, 0.022794055719194666, 0.04504112061113119, 0.02037599609632577, 0.026914703892543912, 0.04629520938864776, 0.019873912412939326, 0.06014179531484842, 0.04623593596209373, 0.041558298747986555, 0.024974963960370848, 0.02067916893533298, 0.03222718695178628, 0.031018468418291638, 0.041824803554586, 0.020905831861974936, 0.03542123788169452, 0.025798389954226356, 0.07371771362211023, 0.014696388272568583, 0.07182886211999825, 0.032106102377708466, 0.04620209742071373, 0.0105293215185936, 0.020058384032121727, 0.02307061811110803, 0.06756525340356997, 0.026525195954101424, 0.08074679358729295, 0.021168606422309364, 0.01922407603290464, 0.011848228201935334, 0.022031994736088172, 0.010971437125200672, 0.021308832469263246, 0.029589392244815826, 0.01265381381381303, 0.04392293221982462, 0.044481454749724696, 0.03653131438685315, 0.03495695708053453, 0.025628628974248256, 0.05326310585119894, 0.02354042897267001, 0.008200725889764726, 0.05682435957714915, 0.028824713812874894, 0.05377937261281269, 0.068757866908397, 0.07314322516322136, 0.06870690214314631, 0.04783113786418523, 0.029128449835947583, 0.0547253963138376, 0.040388826679970534, 0.025005146894337874, 0.03605148156306573, 0.05503229431009718, 0.023875175742432475, 0.06802001435841833, 0.03008231400911297, 0.04342011741495558, 0.019887282945481793, 0.02782751160806843, 0.03258863577087011, 0.019791349968207732, 0.06323497862155948, 0.04161237459629774, 0.07974540482142142, 0.03504696135808315, 0.050188646718327484, 0.027111049874552658, 0.03822750604844519, 0.05303277713911874, 0.03457154918994222, 0.022910390548141937, 0.025370385331500853, 0.02987080446577498, 0.008320408440860254, 0.008965586677991917, 0.011187248580556895, 0.05806620419025421, 0.04851998322244201, 0.014184861078060098, 0.04485083903585162, 0.019839475064405372, 0.006655615987256169, 0.01625034711988909, 0.03501319406288011, 0.083689267481012, 0.04807200422510505, 0.0453834517060646, 0.05376538461340325, 0.07194888139409678, 0.021491175184824636, 0.040614500641822815, 0.04119547589548996, 0.08353701779352767, 0.012704256107099354, 0.05157744166042123, 0.04050337356914367, 0.04449241987562605, 0.02316645100446684, 0.061798560699181895, 0.06329163629561663, 0.016857610516516224, 0.020948114771662012, 0.018613243542079414, 0.01956218494368451, 0.019448482830609595, 0.023710805723177533, 0.09967550502291747, 0.010291445800768477, 0.0702506507347737, 0.018968068163043687, 0.024168099309982996, 0.10161648837051221, 0.051329342116202624, 0.0572868592238852, 0.022187526836725216, 0.03460201880495463, 0.022974752987335836, 0.027596550162083337, 0.018644534184464386, 0.012671925609798303, 0.06416255634810243, 0.017286163056269288, 0.0540510139295033, 0.039834202333752594, 0.039190065647874556, 0.040204712988010476, 0.07684611968163933, 0.07288609431790453, 0.06300739797630481, 0.012727104925683566, 0.011080351325550249, 0.03586224153903978, 0.056418948474207094, 0.03519151306578091, 0.030560389427202087, 0.029284685916666473, 0.01849934465384909, 0.04491342032062156, 0.012260519649966486, 0.019996786623128822, 0.022652693126084547, 0.0014496972767769226, 0.05459349928423762, 0.03410189099875944, 0.08312655839004687, 0.05851389481020825, 0.034526921941765716, 0.02429092093370855, 0.026209076666938405, 0.029634650530559675, 0.067302076811237, 0.01752973168290087, 0.025206264673865268, 0.037424609131578884, 0.01982290523924998, 0.025835059682971666, 0.027247443894988725, 0.030466456431895494, 0.02034384710714221, 0.017683964388977205, 0.009155064189274396, 0.005881982589406627, 0.05096214949818594, 0.04151245352945157, 0.0750170878267714, 0.01984944104749177, 0.0345662396534213, 0.06538796345038073, 0.010157596286652344, 0.030282105252678906, 0.014963544472785932, 0.05364236621452229, 0.04026726713137967, 0.030396418047270606, 0.05048887471535376, 0.02849484740623406, 0.03856172864990575, 0.016381796316376755, 0.04416947452617543, 0.05253977055794426, 0.06588511248784405, 0.024472546098487716, 0.060667687095701694, 0.03555337239855102, 0.05683443242950099, 0.007095373260589051, 0.027029868248584013, 0.033761629435632906, 0.018782332772389054, 0.013961581496654876, 0.03054925806022116, 0.03433147332231913, 0.041262752642588954, 0.021732250195262686, 0.021799794963694046, 0.025547991872632077, 0.06538173449890954, 0.06993186141231231, 0.04084996586399419, 0.05888222397438117, 0.041792345831968954, 0.03233016821156655, 0.09919605896409069, 0.04536229498418314, 0.059106052320982726, 0.02565198245325259, 0.0530453978904656, 0.0220822589139321, 0.0359089179629726, 0.09077769211892571, 0.02268541038834623, 0.04106506146490574, 0.031210721137800386, 0.07276973913290671, 0.028234130503343682, 0.028366073334057416, 0.05035904721756067, 0.05801267456263304, 0.03317768219858408, 0.04599385841616562, 0.0019012951982274118, 0.023880463226565292, 0.0929064057501299, 0.054263313966138024, 0.054515922375555546, 0.01755204700332667, 0.03684890270233154, 0.025173728919721076, 0.026874443017212406, 0.02300445076876453, 0.08273081641112055, 0.009369296354374715, 0.022017655594806586, 0.0449022550268897, 0.006728469868124063, 0.0453547869942018, 0.04911545537678259, 0.013546752327653979, 0.05330396383734686, 0.08574566284992866, 0.026567251554557254, 0.03991744840251548, 0.027678863245195577, 0.04428974146555577, 0.0183588709416134, 0.043430044382278404, 0.014876943048355835, 0.014539156441709824, 0.03530836018866726, 0.04010329914412328, 0.018945518748036454, 0.038323773204215934, 0.03593082107337458, 0.06498420797288418, 0.02286599060919668, 0.05515199128006186, 0.030817140292908465, 0.01853039102362735, 0.0333900840154716, 0.03134002277095403, 0.03875939607886331, 0.01864240358450583, 0.03169489997838225, 0.07094959608678307, 0.0279838850921286, 0.02392621005752257, 0.03232042784137385, 0.028007333566035544, 0.0056804640501338455, 0.01720779395795294, 0.004217805058163191, 0.05616902706346341, 0.02739285903849772, 0.024545441115541116, 0.013991822954267263, 0.00890876870003662, 0.01377460777959121, 0.0598178966236966, 0.030718742537179163, 0.05042819332863603, 0.0160805539094976, 0.04069748886727861, 0.07544164040258952, 0.12574339551585062, 0.16247697440641268, 0.09804701419281107, 0.1292958113231829, 0.14123524565781864, 0.10275874779160533, 0.16758935579231807, 0.11195372510701418, 0.12450908603412764, 0.11381615445549999, 0.12246392720511981, 0.08145344031176396, 0.13256088112081799, 0.0728965573278921, 0.08681089497570481, 0.10787862020411662, 0.1954214780458382, 0.119144506752491, 0.1082302031240293, 0.20082846576614038, 0.12956799886056355, 0.12727037072181702, 0.10774547127740723, 0.10290223759199892, 0.08392395238791193, 0.18785860815218516, 0.06573804002255201, 0.12300903509770121, 0.06596981401422194, 0.06578255870512553, 0.16368404749248708, 0.11630680545100144, 0.12066443876496383, 0.14389264663415297, 0.0928485742104905, 0.11961105386061327, 0.1034045299249036, 0.119960309405412, 0.16598229988345078, 0.13915719145110675, 0.126506489568523, 0.16534082644752093, 0.10957455741507666, 0.11685648666960852, 0.11530660412141255, 0.1171999339546476, 0.11362054638032403, 0.09363602767033236, 0.1202080018286194, 0.17252489738166332, 0.07445017181869064, 0.06994139482932431, 0.07677460209067379, 0.07519195987177746, 0.1345880859132324, 0.10203687474131584, 0.16917629992323263, 0.2078391710030181, 0.11760816776326724, 0.07937452436557837, 0.1961057534707444, 0.12896684397544178, 0.14987307786941528, 0.14670035668781825, 0.1038507820506181, 0.08575383919690337, 0.11190921320979084, 0.10259509871580771, 0.1554749272763729, 0.1819458675703832, 0.0778997420732464, 0.12264718594295637, 0.06427228903131825, 0.1310011191027505, 0.12160962447524071, 0.13290198067469255, 0.11431630940309592, 0.08249600258256708, 0.11437188142112323, 0.08574471968625273, 0.09279218116509062, 0.09372367403869118, 0.17209553399256297, 0.1302326646234308, 0.11763807758688927, 0.11469654685684613, 0.14020270534924098, 0.16663069437657083, 0.07474506992314543, 0.13970947824418545, 0.16111733950674534, 0.11485113070479461, 0.10956343622612101, 0.11701989147279944, 0.1037608150924955, 0.17784474763487065, 0.18009405050958904, 0.13132260899458612, 0.06819531388048615, 0.08006544264831714, 0.1328867543488741, 0.11000174270676714, 0.18391957666192735, 0.11558047442563943, 0.13507585759673799, 0.09682969522795506, 0.15572947290326866, 0.09078091516026429, 0.10598061526460306, 0.1376458089798689, 0.1000031695834228, 0.13801920680063112, 0.11700059393686907, 0.07721464562096766, 0.15060064382851124, 0.22253856009670667, 0.11983590679509298, 0.15630303855453218, 0.14309901850564138, 0.12058917566069535, 0.13642007618078164, 0.14017115347087383, 0.0753777427598834, 0.13151140457817487, 0.12232325332505362, 0.12911150764141763, 0.12340320966073445, 0.09042228226150785, 0.13947212669466222, 0.13303757911281927, 0.1181941098932709, 0.13785021086888655, 0.2145335567849023, 0.0932473831677011, 0.20328305262540067, 0.10263429768383503, 0.11489227706832544, 0.10747842703546796, 0.15333277865179948, 0.08892646538359777, 0.11160657980612346, 0.13108851441315242, 0.10978295587535415, 0.15223074278661183, 0.17595858313143253, 0.15202418315623487, 0.13512506495629037, 0.07757601980119944, 0.11271913974945034, 0.11266071109899453, 0.11840202659368515, 0.16680076239364489, 0.14825348263340338, 0.15524803873683723, 0.1174152602574655, 0.1372239501880748, 0.09821835785572018, 0.17516827982451233, 0.09548540879040956, 0.10696514243526117, 0.10130624180393559, 0.09288382410470929, 0.12878038255231722, 0.1311583492372717, 0.13824103346892766, 0.10840381987925087, 0.10217059363744088, 0.1330084428191185, 0.10803523965712104, 0.07586847285607032, 0.10260347183793783, 0.13753319930817398, 0.17969048502189772, 0.07189723130847726, 0.10908140494887318, 0.21756290351705893], [0.02754417574033141, 0.016585073533600996, 0.06092367800218718, 0.053504721993314366, 0.014920544012316635, 0.037312420151595554, 0.01999013528360852, 0.06669851312679903, 0.06266103977603571, 0.04124190465414098, 0.08862380483852965, 0.04036010429263115, 0.016522042719381194, 0.003174230709971328, 0.013780712898421501, 0.05772546425993953, 0.1490788526300873, 0.0515385039283761, 0.020031863490917852, 0.03870763064229062, 0.01744332703362618, 0.01351084340629833, 0.06897502525576524, 0.008954295007112836, 0.03492023476532527, 0.025860185834712217, 0.019530327724558965, 0.0022837332258599675, 0.00505049220685448, 0.02936431878645505, 0.04702240554615855, 0.03664216665284974, 0.033538951205887964, 0.06587631867400237, 0.0342934346491737, 0.05673036551369088, 0.04127653029614261, 0.03018789066533957, 0.009389900070215975, 0.021985033327447515, 0.03248319821432233, 0.0031010195380076766, 0.044132887917969904, 0.07141406009239809, 0.021463758977396146, 0.03447355855522411, 0.05132742525477495, 0.04069681033225996, 0.01390216897042202, 0.034720128002975664, 0.03628311984773193, 0.05571839838687863, 0.021826958416828086, 0.031327022039996724, 0.03490700672513672, 0.045024476147123745, 0.0201717061655862, 0.018427099334076047, 0.005607809913012066, 0.006724209092291338, 0.07895075210503169, 0.036575700755098035, 0.034984749874898365, 0.04452065371775201, 0.011921474360860884, 0.05378275510988065, 0.040339032387627025, 0.014605279679277113, 0.038859859973724396, 0.0748516677745751, 0.0303891407591956, 0.05310016245182071, 0.05817663576453924, 0.04018415676962052, 0.025584810879081488, 0.014727461783747588, 0.08576169663241931, 0.07029139676264354, 0.07523158631686654, 0.016545389413035343, 0.02714434728425528, 0.024046363342287283, 0.014735405732478415, 0.018367966703538383, 0.015677863731980324, 0.06881837866136006, 0.031377817171492746, 0.013730081463498729, 0.047037455452872176, 0.03643584790240441, 0.007511020488371807, 0.03740501643291541, 0.031029525146420513, 0.017126086467344846, 0.08406472804823092, 0.037221764480429034, 0.05028166029868381, 0.0708363689482212, 0.006374643117721591, 0.010494873143865593, 0.042740581557154655, 0.01855533566725041, 0.05891997766281877, 0.04932387080043554, 0.07091285341552325, 0.04976118661995445, 0.047827826613294225, 0.02185339923016727, 0.035120775790086815, 0.02468477319260793, 0.03235778458682554, 0.00837707459660513, 0.013443882177983011, 0.02571095393172332, 0.02180004771798849, 0.031104493087955883, 0.05495372334761279, 0.05649028964606779, 0.08918514328875712, 0.04534759113032903, 0.04792788677981921, 0.04005925204338772, 0.046887994544314485, 0.039843650933887274, 0.009081912177082683, 0.025262639059552124, 0.08135594840028457, 0.006782481679692864, 0.02216814618025507, 0.013702249653371317, 0.019286106007971933, 0.07395058684051037, 0.030769038945436478, 0.03876724333635398, 0.04169659097013729, 0.015093005561668957, 0.012580671131477823, 0.041939479365412674, 0.025866377466757382, 0.028208605712279677, 0.05279599555901118, 0.03423286522073405, 0.013582993731168764, 0.003955277739026184, 0.0424945142253169, 0.020524780166202357, 0.04948890069499612, 0.034408778816993744, 0.009308440244889684, 0.036758284350591044, 0.018142374165888344, 0.028225279014025415, 0.026655432269243256, 0.03716765470536692, 0.04004701466432639, 0.023388717024187957, 0.038323701958038976, 0.06075831901814256, 0.044872701434152465, 0.03891391885866012, 0.07989448575036866, 0.05003096196534378, 0.14184812562806265, 0.019588286489514366, 0.07284716676388468, 0.037866895220109394, 0.08704774440931422, 0.02674332121387124, 0.040322269179991314, 0.05076869237901909, 0.08901376569909708, 0.018419720265748243, 0.055295016283967664, 0.020101825540353144, 0.0158882265511368, 0.04467865398951939, 0.014270783967471548, 0.005820978050386267, 0.058672258098210604, 0.042722712337438545, 0.011783350076127266, 0.02743314196621733, 0.01273253235766398, 0.07399754146380083, 0.016490424683849727, 0.04646876846839275, 0.019459666784054468, 0.06573626904615334, 0.00947185352976833, 0.03379894207630839, 0.03446068335324526, 0.04736265353858471, 0.0618054885417223, 0.09488116657095295, 0.02637027283864362, 0.02908565802499652, 0.030192002587552582, 0.04170916083135775, 0.07914643481905971, 0.025256469479895065, 0.033303835429251194, 0.024321897753647397, 0.02307175296092672, 0.02259474284281688, 0.02466518897563219, 0.07332978836659874, 0.028574938287160227, 0.04246308109057801, 0.017569459908242737, 0.03589657541098339, 0.006697880661314619, 0.0066569378582893735, 0.030694362773959125, 0.04590401020167129, 0.04472953054521765, 0.029390109902513877, 0.04617162441302623, 0.026997505520869578, 0.041628493195665736, 0.04355638760275074, 0.01732866988251252, 0.10283933739577021, 0.05774596958820309, 0.043819672760686705, 0.027310688447739397, 0.0504476876397218, 0.02387562018286969, 0.046266008634120226, 0.023833042110449502, 0.011695860618991511, 0.04189435000132237, 0.005132930394860783, 0.08398245567721979, 0.015146932132276041, 0.024710333606760417, 0.03154216513835958, 0.03511131701192685, 0.043184658978134394, 0.047531221993267536, 0.0383782595662134, 0.008223730771403228, 0.02635260039408292, 0.07129595428705215, 0.10126403014042548, 0.021266617413078035, 0.051976494890238555, 0.03848789046917643, 0.03578242885747126, 0.029590678068676164, 0.06508566252887249, 0.07290510686912707, 0.053217688109725714, 0.03563923421981079, 0.0354985094496182, 0.006051711338971342, 0.06389201765081712, 0.019172505675149814, 0.057584288263959546, 0.028057431502799903, 0.07062157868806805, 0.011409653699956834, 0.05745588229703052, 0.03250679426959582, 0.05376533033060176, 0.05352526803367904, 0.03466585537950907, 0.03607706233326878, 0.02500489753271852, 0.030416512861847878, 0.023039646380181824, 0.02101700134309275, 0.014157211624218949, 0.05075820901298097, 0.018418588808604648, 0.005315301524076078, 0.020264507703749195, 0.030699556959526877, 0.02887372100459678, 0.026610884748931442, 0.039047461335680315, 0.0296287133491465, 0.014903356720294272, 0.015221813560596533, 0.04462706497205155, 0.016398103209212422, 0.047920171836657185, 0.027070558297314813, 0.04320580891466566, 0.02923714096790978, 0.01802023616619408, 0.014638334512710571, 0.052002313147698126, 0.02465221199340054, 0.015596921289605754, 0.03772621794736811, 0.003224196968533631, 0.07087998517921992, 0.03980489979897227, 0.0655296483476247, 0.016678209250260676, 0.00799614588530468, 0.00782404056683715, 0.035734341080699644, 0.13612563269478933, 0.018679297229807292, 0.0368789957304086, 0.022212549511875426, 0.03512835502624512, 0.025071529671549797, 0.06505775438355547, 0.03372454071151359, 0.00804922089446336, 0.032023673943643055, 0.037480323641960106, 0.031098918922777687, 0.03603314754686185, 0.0520845074871821, 0.07260258881641285, 0.037129782273301055, 0.029925056733191013, 0.03864415029862097, 0.05852870044431516, 0.034087068401277065, 0.06634115587387766, 0.01857944232012544, 0.041819846856274774, 0.05812364896493299, 0.025334585823916962, 0.026728603789316754, 0.018868153881547705, 0.011963088065385818, 0.011771641106211712, 0.03770091198384762, 0.036310125541474135, 0.010467295784370174, 0.03518540285793798, 0.06835365002708775, 0.052070108974086385, 0.09311606628554207, 0.034011900291911194, 0.0622382378205657, 0.03430260165727564, 0.059746412959481986, 0.041850961079554896, 0.07367820931332451, 0.04838993859344295, 0.06327640318444797, 0.040292020088859966, 0.02690654281260712, 0.05674462831978287, 0.044466353952884674, 0.03839793029640402, 0.10912692107792411, 0.176288581852402, 0.20029658930642263, 0.18620372909520352, 0.10124108887144498, 0.15579659358731338, 0.09468370609517608, 0.18510724364646844, 0.1806936447641679, 0.08464994414576463, 0.20474100724927016, 0.19895478630704538, 0.13459791110030242, 0.12470567119973046, 0.15259409828909806, 0.10078712180256844, 0.21570013490106377, 0.1215256896934339, 0.11763482061879975, 0.14955218508839607, 0.18114314707262175, 0.0964428624138236, 0.17522515462977545, 0.1298512193773474, 0.13051509803959302, 0.11058389182601656, 0.16462772685502255, 0.08396057292286839, 0.16814708443624632, 0.12341017143002578, 0.12009187734552793, 0.1882337158811944, 0.07456768729857036, 0.10105240185345922, 0.1418985136385475, 0.13905826104538782, 0.1213215592184237, 0.11177021531122071, 0.14868754148483276, 0.15038249482001576, 0.11686504978154387, 0.2252909695463521, 0.14340020662971906, 0.1162355864154441, 0.13709915402744496, 0.19293007387646607, 0.12617491664631025, 0.11390833343778338, 0.12531408640955174, 0.13360422370689257, 0.1768619032310588, 0.15843572840094566, 0.12837978904800756, 0.12386211646454674, 0.17656166505600723, 0.09091350090290819, 0.14365814493170806, 0.08267649289752756, 0.09713254576282841, 0.08136669639497995, 0.2011597401329449, 0.1252414153090545, 0.10676589741238526, 0.10944165954632418, 0.08497785297887665, 0.1708852717919009, 0.18923862624381269, 0.17857861039893969, 0.09751581626811198, 0.20640884632510798, 0.16308323187487467, 0.08175169716456107, 0.16715100859957083, 0.15272828537438596, 0.2347193221960749, 0.16236815096012183, 0.21455189080110618, 0.14366915076971054, 0.23395453180585588, 0.09271716233342886, 0.09000539713140045, 0.14159963253353322, 0.11108649628502981, 0.09431201818266086, 0.08338390636656966, 0.18154192210308143, 0.14377192168363503, 0.062313358432480266, 0.12095327755170208, 0.11935365838663918, 0.08308729156851768, 0.17066971478717669, 0.11031606726880584, 0.08638088019298655, 0.1615436766296625, 0.16343566296356066, 0.1310017704963684, 0.12111483673964228, 0.09592142182269267, 0.1128342260739633, 0.13617884341095174, 0.08370325887309653, 0.14340214723987238, 0.09823971135275704, 0.13893940885152134, 0.09138445848865168, 0.09402168661888156, 0.06871895971042769, 0.1569445798439639, 0.0895538456471903, 0.08070673287979194, 0.09926054014691285, 0.10716618557593652, 0.06978559640369245, 0.13270532765558787, 0.1342630269271987, 0.16005087244723523, 0.16094933423612798, 0.1062189574752535, 0.1364663794104542, 0.13161588540034636, 0.10291767426367317, 0.1624570797596659, 0.15451633371412754, 0.17298028937407903, 0.15607498293476446, 0.2021090513361352, 0.15529233350285462, 0.0918868322457586, 0.24081541651061603, 0.09679171762296132, 0.12883773233209336, 0.10461546387523413, 0.1673446489231927, 0.12942284664937428, 0.16907008205141338, 0.0515425683531378, 0.08626016202781882, 0.14202664819146904, 0.0616380600258708, 0.15591281306530747, 0.14881407469511032, 0.08705083852899925, 0.08462865171687943, 0.23705329267042025, 0.09951480078910079, 0.14949772586779936, 0.15273676706211908, 0.13181073351630143, 0.12461234549326555, 0.145435363852552, 0.10779153701982327, 0.11862747663898127, 0.09808324117745672, 0.11320786816733223, 0.10990100061254841, 0.15323192120662757, 0.12362989463976451, 0.15624898645494664, 0.20852455922535487, 0.1562782313142504, 0.21198833121785096, 0.29560956199254307, 0.12274675417159285, 0.14148842064397676, 0.1300713497080973, 0.17032989087913716, 0.11480975363935743, 0.18934021650680474, 0.12118422373064927, 0.14612755099577562, 0.10642864515206643, 0.11214682260262114, 0.1533334707575185, 0.1263071359800441, 0.15521164211843694], [0.016314431359725337, 0.014522042092201965, 0.049391069516007385, 0.044770110332007916, 0.03417013126558491, 0.045678030899060626, 0.020903502790523425, 0.032928673417440484, 0.0478000779237066, 0.017430797884506837, 0.08327515077378068, 0.0457712208985218, 0.04227385802992752, 0.04509862645396164, 0.02655212870532913, 0.010677686593096172, 0.05784437752195767, 0.01839471116129841, 0.017503653885796666, 0.0015150033037311264, 0.00525486737855577, 0.07310861987727028, 0.008277454629673489, 0.028591375797986984, 0.026189071758251106, 0.06263668715421643, 0.025754000193306377, 0.02826899872161448, 0.032667308513607295, 0.047243404401732345, 0.04685034602880478, 0.019213126174041202, 0.04902023316494056, 0.033536203139062436, 0.013117892750804978, 0.04147878801450133, 0.04426079176898513, 0.02715522759327931, 0.016127632365428975, 0.05872824402259929, 0.03230358999488609, 0.09658309524612767, 0.03890025994873472, 0.004533365402104599, 0.011061914680924798, 0.014042438273983342, 0.03743039024993777, 0.02291085195195462, 0.023465718874441724, 0.00780055222899786, 0.0426902071173702, 0.09492672341210501, 0.0032876111550389654, 0.001495857271947898, 0.05808229225554636, 0.057836757573698244, 0.05696657033903258, 0.01358251621214939, 0.08157686583165612, 0.010212685696647635, 0.024022129464096258, 0.019801565312913487, 0.022949730312185626, 0.04328221535044057, 0.04380618687719107, 0.031846457560147555, 0.0833177152755005, 0.019649090012535453, 0.017159461908574616, 0.04997067752161196, 0.02398480155638286, 0.05469071299635938, 0.0610565555148891, 0.019612510189680115, 0.09297901578247547, 0.03872795955144933, 0.016486636762108122, 0.021267531739015664, 0.017533355059900453, 0.020681112938161408, 0.05268629001719611, 0.04317552589678338, 0.02648596984467336, 0.039553254909281216, 0.0673707513404744, 0.009905759710818529, 0.05723246107144015, 0.039725294070584435, 0.04229522170498967, 0.07018086340810571, 0.01255541860259005, 0.06018452266497271, 0.025423207586365085, 0.03286956623196602, 0.05433298933452793, 0.027860237352017845, 0.02350123000464269, 0.010035933261471135, 0.051459362996476035, 0.022360132574769, 0.002102228925130995, 0.0288949455799801, 0.06865791870015008, 0.0736693815727319, 0.02407838001714221, 0.007261086355096528, 0.004850074590649456, 0.0532000733406416, 0.021478006516450217, 0.007151405410175877, 0.07796466430383069, 0.03405744695503797, 0.0341151156462729, 0.04708227947620409, 0.049405274646622796, 0.05299717101401516, 0.14060358383825847, 0.01784329628571868, 0.03878173345167722, 0.015802398656627963, 0.05974380738501038, 0.020779369897874336, 0.0029373942109357032, 0.06536876769470316, 0.036631225275674036, 0.0370882423594594, 0.055397963616997004, 0.03699905571660825, 0.02810647092493517, 0.02199748274870217, 0.01719056086481682, 0.030670522446078912, 0.03866158864860024, 0.028178624642480696, 0.03131703400452222, 0.012762447270298643, 0.03304092346557549, 0.01814618074734296, 0.017019205327544893, 0.03958451501759035, 0.05601857888645359, 0.0442270719712334, 0.017035581770219972, 0.06234573133821998, 0.008128517041248935, 0.03459674319518464, 0.02535669249482453, 0.005602729806144322, 0.012192700923021351, 0.01966559368052653, 0.05412060448101588, 0.032278697937726974, 0.025813758772398745, 0.029516663468841995, 0.007996972001689886, 0.036728167573788335, 0.02853975285376821, 0.031951633880713155, 0.03330766236675637, 0.030186346998172145, 0.06519755295344762, 0.012807903179366673, 0.07666313235781022, 0.05056080621268068, 0.08829232012586934, 0.0234108338731208, 0.1310355615402971, 0.02336410995173667, 0.046818590589932034, 0.09671504316585404, 0.10713991948536464, 0.046974484010466507, 0.02337688167712518, 0.07293856543089662, 0.038369869480707815, 0.01308798631985805, 0.04248945913942797, 0.01547198772563466, 0.04084001514794571, 0.06597064861229487, 0.01940775546245277, 0.05688677801351462, 0.058784881340605874, 0.006132628336282713, 0.034022471867501736, 0.01366420165036938, 0.041300099210015366, 0.059408326101090224, 0.025301057712308, 0.02311710115256054, 0.03565307294151612, 0.040714604913124015, 0.05286387959495187, 0.04327488038688898, 0.03431168384850025, 0.03860746869551284, 0.018648612179926465, 0.04271581842164908, 0.05987262725830078, 0.025266815442591906, 0.05291089189371892, 0.06376776431820222, 0.010413172438607683, 0.03998613989512835, 0.03997107641771436, 0.09580616586442504, 0.07286478831831898, 0.05136452754959464, 0.011555197765119374, 0.015404994266905954, 0.02813175313973001, 0.008911888264784855, 0.02486758240099464, 0.05870184222502368, 0.003162849133202274, 0.024974772274228077, 0.01667996495962143, 0.06979670402194772, 0.03871384941573654, 0.02067605615593493, 0.01016775904489415, 0.053288293071091175, 0.05298475721584899, 0.019641906023025513, 0.021719580250126973, 0.013201266044883855, 0.01609699990201209, 0.035650385942842276, 0.028427589318848083, 0.031397752530340634, 0.045423620979168584, 0.004128268969777439, 0.03386734179886324, 0.027939990661772232, 0.04490749331723366, 0.035527795021023066, 0.03608427516051701, 0.07708732531006847, 0.06566251907497644, 0.02904132933222822, 0.04047169616179807, 0.04888692817517689, 0.036618088837713, 0.010937335651500948, 0.03555541478895715, 0.023336927838889614, 0.03849244343915156, 0.0625084304649915, 0.04693204503772514, 0.024833642079361846, 0.025212932976761034, 0.09725279573883329, 0.03018829778635076, 0.034082800416009765, 0.016196115208523612, 0.02689467353879341, 0.01940835596594427, 0.05413477907755545, 0.01063156487154109, 0.06831737554499082, 0.03399840083771518, 0.020239498599299362, 0.020239332358219793, 0.043343710979180675, 0.036701504540230544, 0.07643576205841132, 0.11057839569236551, 0.05719718403582062, 0.007260577453832541, 0.002529190936391907, 0.009551874012686312, 0.01932819383884115, 0.005578465817961842, 0.06720486309911523, 0.02671274812226849, 0.03919131415230887, 0.03194090624206832, 0.07382625208369323, 0.03543664401929293, 0.013908257974045617, 0.053496063886476417, 0.003648070161164339, 0.009881715822432722, 0.06980599316635303, 0.05559073541579502, 0.01839417002962104, 0.07650162066732134, 0.03394060322482671, 0.025372441292607358, 0.02547374487455402, 0.04527937121955412, 0.027416421167020286, 0.014224934508092701, 0.026692524386037673, 0.019853500383240835, 0.03210698786590781, 0.023748493254450814, 0.031246184770550047, 0.022411533298769167, 0.07268132601997682, 0.0076201993173786575, 0.019216293236240745, 0.07177018919693572, 0.0606627609314663, 0.07306253377880369, 0.03725332314414637, 0.06836772962872471, 0.026849221870569245, 0.03730919711025698, 0.05041439871170691, 0.02614052257766681, 0.019175040003444468, 0.031127671844192913, 0.030858195054211786, 0.028216341011492268, 0.02728198472011302, 0.044976547826081514, 0.028750760281192403, 0.06593081860670022, 0.025622413593477437, 0.02022028588024633, 0.02842878014780581, 0.04252249700948596, 0.021045944254313196, 0.05379171177212681, 0.028741773084870408, 0.05074910307303071, 0.003663549665361643, 0.02917975726138268, 0.035763324704021215, 0.0013205218087283096, 0.032877420274806876, 0.04295177897438407, 0.021282897164512957, 0.023091416905767152, 0.03459251931469355, 0.06144481325255973, 0.016720044326835444, 0.057254934151257784, 0.027913566811808517, 0.0372483901945608, 0.04583414823615125, 0.010492335422895849, 0.030320846209568635, 0.0381764937857432, 0.09513829741626978, 0.046263386096273146, 0.08465044626167842, 0.008885219294045652, 0.03672889021358319, 0.05785826034843922, 0.017817338928580284, 0.1124127269057291, 0.1576284481478589, 0.12440593514059271, 0.13406915590167046, 0.21281186916998454, 0.11984893466745104, 0.12093244652662959, 0.0710216225790126, 0.15419242823762552, 0.11046319401689939, 0.13282894316528523, 0.14624842522399767, 0.1381572208234242, 0.12037540998842035, 0.17247885199529783, 0.05943721812218428, 0.12915373966097832, 0.09929363229977232, 0.1689284582223211, 0.15828457794019155, 0.12062488017337662, 0.13979821705392428, 0.14837519824504852, 0.11659822267081056, 0.10568884520658425, 0.10064304167670862, 0.05106965997921569, 0.1711672573749508, 0.12375612929463387, 0.15539799497595855, 0.14499093698603766, 0.17231417154627188, 0.11368668318859168, 0.06251884597752776, 0.09141183059130396, 0.08393173518457583, 0.15721424323107513, 0.12745113245078496, 0.12088100000151566, 0.12903633953205176, 0.0856835904664227, 0.12534140422940254, 0.1415853832981416, 0.10339963090206895, 0.13139842849756989, 0.08119496596711022, 0.11833025115941252, 0.07232960060771022, 0.13920543529093266, 0.11542876756617002, 0.12312157691589423, 0.1718740737331765, 0.14394421529557022, 0.112826137936541, 0.1695930968437876, 0.16116946456687792, 0.10534961840936116, 0.1203947075243507, 0.09991447827113525, 0.08778050794665303, 0.12431723704295498, 0.1485595562096153, 0.07496562094560691, 0.11134804439331804, 0.12488388163702828, 0.09122295358351298, 0.15944859119398253, 0.08236198513103382, 0.10871846335274832, 0.16686449040259632, 0.10158872950289931, 0.14626705779560975, 0.15758318986211503, 0.06735432400767292, 0.23610472785575048, 0.12529149119343075, 0.07911424511777503, 0.07050580025783607, 0.06829893974853413, 0.07474719373775379, 0.2355582628931318, 0.14335131139627524, 0.13326902740768024, 0.17399573060018675, 0.13009641479168618, 0.05589570976527674, 0.0901856974565557, 0.11824182447578226, 0.1344322535608496, 0.1970624742763383, 0.19810660396303448, 0.13363203007195676, 0.12324114835688046, 0.1429578425096614, 0.19714212071682724, 0.10651439840772323, 0.16142448516828672, 0.09304006357810327, 0.17456527932413987, 0.2215305149023022, 0.11207257051553045, 0.1556449138692447, 0.2683431479547705, 0.1313683965376445, 0.14661597407289914, 0.14552095425980432, 0.0366088539761092, 0.25747089992676464, 0.10945609198617083, 0.14081383469913686, 0.12057065165468625, 0.12021782701568944, 0.12902895707104886, 0.10282573955399649, 0.12973969536168234, 0.08767565393022128, 0.16659342923334666, 0.1837763786315918, 0.18631693587771483, 0.13416830343859537, 0.16298419290355273, 0.100791762982096, 0.07886513455637864, 0.1365947989480836, 0.0865116338910801, 0.13908686808177403, 0.2555203288793564, 0.12063374184072018, 0.16280629459236348, 0.16946374092783245, 0.1392867916396686, 0.118236830458045, 0.1077800765633583, 0.20853061175772122, 0.20641265969191278, 0.1218128457133259, 0.13659868016839027, 0.14362239970692567, 0.052149595958845954, 0.06329196877777576, 0.11399146754826818, 0.16610143706202507, 0.12708551064133644, 0.15069540802921566, 0.1374912794147219, 0.10941327642649412, 0.15114769233124598, 0.0731382379308343, 0.1549975371786526, 0.07835253527654068, 0.22941885090300015, 0.07241397643727915, 0.17805597558617592, 0.1011009578193937, 0.06461427746606724, 0.12680922475244316, 0.07290732567863804, 0.1567529615546976, 0.10917992144823074, 0.06465249255831752, 0.16045986621507577, 0.06806884173836027, 0.20819226705602237, 0.106862419018788, 0.17442004568874836, 0.1074252434607063, 0.22805789964539663, 0.10103294146912438, 0.18105347188455717, 0.1570770163089037, 0.16361848743898527, 0.1577157484633582, 0.10096717785511698, 0.1653873332376991, 0.1412704209131854, 0.10810064364756856], [0.010295027617498167, 0.00874855725227722, 0.04499866467501436, 0.012297658416043435, 0.05062242058504905, 0.07620781500424657, 0.04080604089956198, 0.0615317810858999, 0.0188553787634841, 0.01769677173745419, 0.05280565789767674, 0.04977784126198717, 0.04114914552441665, 0.021303261696760143, 0.034896431756871085, 0.02866776187771133, 0.03360467410779425, 0.0356763297292803, 0.02531749352679721, 0.029251285030373504, 0.014386436868725079, 0.032064552285841534, 0.020949364972433875, 0.014855891499402267, 0.051742929566119394, 0.09434413324509348, 0.026567623052479963, 0.022334982674302797, 0.06777356365429503, 0.02720389042847923, 0.021819569170475006, 0.04350597584354026, 0.021752263585637723, 0.027371128954525505, 0.0613863913874541, 0.01604067301377654, 0.03459214951310839, 0.04538122611120343, 0.10063795266406876, 0.019403183832764626, 0.042968511647943936, 0.018573693432179943, 0.03720386472663709, 0.07286476796226841, 0.012118375893416149, 0.016422369317816835, 0.036603347664432864, 0.05755123682320118, 0.012062663927541246, 0.02885476952152593, 0.018781503263328756, 0.01000748059180166, 0.030092943260180097, 0.0565957611293665, 0.01816080487333238, 0.003184411915883954, 0.0847148731616991, 0.007663126835333449, 0.012051634340813118, 0.023856229348374263, 0.043322591576725245, 0.05085033710513796, 0.06336381885090045, 0.04953289690560528, 0.015498601565403598, 0.06270564666816167, 0.0030717203959024376, 0.036280083403523476, 0.05510761508984225, 0.06107129329549415, 0.11186641800616469, 0.0023701611997759236, 0.11692933418921062, 0.08019977222595896, 0.12185392422335488, 0.05719755044473069, 0.021273908271853412, 0.03493434150836297, 0.01733017453391637, 0.009002987528219819, 0.04315874572577221, 0.11049629295510904, 0.005599210753903857, 0.05791949134852205, 0.03696836557771478, 0.010955165855453482, 0.017731470321970325, 0.06651192956737109, 0.04400490942810263, 0.02757515595294535, 0.033142744430473874, 0.005336639329990638, 0.033492614049464464, 0.08250927472753183, 0.007559437354627464, 0.09769627265632153, 0.030818188629512275, 0.04681818007624575, 0.02360019094443747, 0.011708259998288537, 0.011491172897097255, 0.0571962408721447, 0.031778760121337006, 0.0401066036096641, 0.01850653542870922, 0.08543854432978801, 0.06979563193661825, 0.013971569532129382, 0.013541860938338297, 0.022397879477856413, 0.06947062044803586, 0.0344185938260385, 0.01528173329175583, 0.031954870492752106, 0.04118389330272164, 0.01222320192027837, 0.015138923722718443, 0.06293268448540143, 0.043587718957236836, 0.04937944621113794, 0.03652892255091241, 0.09597613888659648, 0.0288047309565757, 0.05882444671754326, 0.057647622722600184, 0.03774856889088239, 0.02647881469290171, 0.014633006316476634, 0.018558716467980827, 0.029413651674985886, 0.026320953520813158, 0.02478158487273114, 0.03136858230988894, 0.029151089156844785, 0.09046582385365452, 0.015686342027038336, 0.06435629166662693, 0.08182886695223195, 0.02813368526819561, 0.027102617380608405, 0.037313471880874464, 0.04027504314269338, 0.035479846343930276, 0.049550141873104234, 0.0456485214110996, 0.03766297169827989, 0.05845294200948306, 0.018111840090049163, 0.027695682431970323, 0.0322108105091112, 0.07269265076943807, 0.025632425377677594, 0.07290663357291903, 0.03100373063768659, 0.05845406159226384, 0.08365235517599753, 0.036106704135558436, 0.07039861886629037, 0.02880697351481233, 0.030742386089903966, 0.060655772020774226, 0.048813473366733105, 0.10894491762987205, 0.014832317496516874, 0.04193292810980763, 0.05631913258028882, 0.02975243403177176, 0.011216274612317128, 0.035309567981000455, 0.019931939031396593, 0.006505509622261992, 0.06128587999514171, 0.044915184511670043, 0.0638649712449738, 0.017527524747752717, 0.022677434209202017, 0.03915942639910749, 0.05408665058868272, 0.07267268148383924, 0.02350909761818392, 0.03307749989575573, 0.006199462763366422, 0.05498127526204501, 0.033386508135923317, 0.030744014573948722, 0.0407058755601091, 0.06264700767185007, 0.09015018293367964, 0.03913861233741045, 0.015731736019785916, 0.03479343692639044, 0.04746412166527339, 0.05737987280424152, 0.02837716568527477, 0.025325995570580875, 0.04005537421575614, 0.04520957710753594, 0.01435139901669962, 0.02427353517019323, 0.05870005767792463, 0.023853377804958394, 0.06344660690852574, 0.014749154548293777, 0.012434647002789592, 0.08211094074483428, 0.027215769880318215, 0.04291358423818435, 0.02081988861651293, 0.02058952088866915, 0.0292901956210179, 0.06091862291629825, 0.09853832104376384, 0.053444518973784785, 0.04726752971432038, 0.12123733945190907, 0.018564667220094373, 0.05541886928092156, 0.05031177029013634, 0.0430266146015908, 0.05034934416679399, 0.06613940027143274, 0.04188612276422126, 0.023077793618930236, 0.033021201845258474, 0.03673825738951564, 0.030986468706812178, 0.026453678363135884, 0.0039721999783068895, 0.05511585250496864, 0.0422479651336159, 0.04248461100671973, 0.007774499028788081, 0.0477148301766387, 0.01883626273567123, 0.010785036770227765, 0.010721273986356599, 0.05296033674052783, 0.03430685607184257, 0.012812027824111283, 0.04528182412364653, 0.07392594923398324, 0.032757146550076346, 0.028385596482881477, 0.03709488860996706, 0.0237415467521974, 0.01762988175531583, 0.05980604261692081, 0.03859234754262226, 0.04856418638623186, 0.05476729245856404, 0.08242683272276606, 0.05908060725778341, 0.030338389732475792, 0.03742269227015121, 0.010839384880715182, 0.024752183950373104, 0.04991356522909232, 0.03106752989281501, 0.028127066159088696, 0.040683660323598554, 0.04361175945294755, 0.03428133297711611, 0.02512412461718278, 0.02866387726472957, 0.02397936479454594, 0.013729184100936567, 0.017085613549820015, 0.041398887123380385, 0.03395638255668538, 0.031042203573243957, 0.03478754384975348, 0.02327848901040852, 0.04856185222576771, 0.026782236893528273, 0.030455487913319042, 0.028018604032695293, 0.0383392539806664, 0.0023171771567181815, 0.028915077713983398, 0.04100109936137285, 0.022701647731342485, 0.06853911400373493, 0.10970358084887266, 0.04918666762698974, 0.05854200651603086, 0.021901057833539586, 0.009011670231952198, 0.04799082429547395, 0.08192616887390614, 0.04580105269061668, 0.06880305055528879, 0.004863565139073346, 0.09759320318698883, 0.02425164054147899, 0.01197848656946527, 0.04807397876200931, 0.017070638281958442, 0.023517172184905837, 0.0650886209415538, 0.025673539510795047, 0.02292650405849729, 0.008272581051902046, 0.06575393809803895, 0.027896788337134888, 0.0725396139813321, 0.07174052364592041, 0.04464690533599683, 0.058361210860311985, 0.015823803043791225, 0.025517247450937117, 0.006471058278943279, 0.0054000590295929995, 0.011920782255141862, 0.018505843322990195, 0.016948987131140063, 0.03163892762469394, 0.01988360358934317, 0.03738893176029835, 0.06634064018726349, 0.042139840578394275, 0.030669725167432, 0.014771096674459321, 0.04207218724435993, 0.04247320144038115, 0.05583148642576166, 0.035538736398198774, 0.04365348596391933, 0.034935250745287964, 0.12985360782061303, 0.04140882766140359, 0.12130106746086053, 0.0551485070027411, 0.035821339448115656, 0.03801885313753571, 0.01805257853785796, 0.01940992338183735, 0.05916867431785379, 0.02005648922308215, 0.03685282463473933, 0.010084404410528285, 0.03189115944717612, 0.0355961065340255, 0.013330650798577284, 0.022062969859689474, 0.030495212745985815, 0.017129491016800915, 0.03837527061945625, 0.03290545055642724, 0.02163738082163036, 0.04325838180791054, 0.06461397212530885, 0.035222321948302646, 0.15767855117363588, 0.11817451380193233, 0.15978423532630714, 0.10486502905509301, 0.128087082611663, 0.2427784726023674, 0.15719179729265825, 0.12853269012910978, 0.13026881696922438, 0.11858662883085863, 0.19792668361748966, 0.13909753465226718, 0.11470390217644827, 0.10416612441518477, 0.11958828222538744, 0.09108916004853589, 0.15436863021126815, 0.09356478149337427, 0.09147693602634327, 0.15882196410426072, 0.08355081919580698, 0.08311359837119069, 0.07923129240849189, 0.13312695574547562, 0.11200362457228558, 0.12232178768941335, 0.10891638523233788, 0.09741857541458947, 0.2408522202500275, 0.09525767886745078, 0.09852337970265321, 0.08889230114540883, 0.1076636603102088, 0.05928990138428552, 0.15060775487550668, 0.12231007617499147, 0.17449328675866127, 0.14076469519308635, 0.20387393449034008, 0.14033530466258526, 0.18707203678786755, 0.12054091825016908, 0.13282061075525625, 0.1253702962504966, 0.12261875532567501, 0.12720040019069398, 0.08717224879988603, 0.11590855967785631, 0.12782896789056913, 0.07929177023470402, 0.13759827081646236, 0.07418638454484087, 0.14231068295027527, 0.1721356896949666, 0.0793934351365481, 0.13963783851691655, 0.10177607980689832, 0.10705033250685249, 0.13762940200311796, 0.09388398472219706, 0.16080963744648866, 0.11781938214387212, 0.15943586187703268, 0.13482994293527945, 0.1605540875877653, 0.11230581692819085, 0.07212773643966232, 0.17904971726238728, 0.09892855331833873, 0.2527405880391598, 0.178383450156876, 0.16100584263248102, 0.1685086078941822, 0.1078145664983562, 0.32670978030988146, 0.1600226725318602, 0.16617519381855214, 0.11399775078254086, 0.09442842765046017, 0.09532446706933634, 0.12225492484867573, 0.14771239166813238, 0.08622314115720135, 0.12467462143727712, 0.14681919531098434, 0.05737998815519469, 0.20345354133418628, 0.13555995162044251, 0.1368429120630026, 0.07901112136564084, 0.10069881725524153, 0.17330712612186158, 0.09726285841315985, 0.21605723431067808, 0.1215390432626009, 0.1557955757847854, 0.12478386557527951, 0.1819859282778842, 0.08266290862645422, 0.12896379056785787, 0.08225391485861369, 0.11763604198183332, 0.11574440848614488, 0.1238577738404274, 0.08586436576609101, 0.12715537260685647, 0.18945813232234546, 0.1479330783975976, 0.18995330003755434, 0.2527738091136728, 0.21822044466223034, 0.20995567100388662, 0.10920244881084987, 0.14434833718197687, 0.10981946784470763, 0.04566189533631716, 0.16647007156695637, 0.14633051439055375, 0.2001129234475749, 0.08876776961343628, 0.10292248507695538, 0.14633663477642195, 0.1811327247747353, 0.09905828242855412, 0.10183670691081456, 0.08525758582566466, 0.18612662037568434, 0.12543832617146627, 0.19109169180904115, 0.14129753517253058, 0.14908346666821412, 0.09791896106409174, 0.12109471139098917, 0.19436695320265635, 0.11654384487441607, 0.0951339683628508, 0.16043170701180184, 0.08808439664010491, 0.1433647871017456, 0.10338456063930478, 0.17141128570905753, 0.06158073738749538, 0.1361546739935875, 0.13837205858102866, 0.1436706164053508, 0.36579451018146103, 0.19925175394330705, 0.12995048905057566, 0.1535457707941532, 0.13873124787850039, 0.09802849018680197, 0.16927863657474518, 0.15820651927164622, 0.15715142445904867, 0.19468677389834607, 0.11950360105506011, 0.12918937632015773, 0.1256577915378979, 0.059274790409420214, 0.09472102552120175, 0.17668575554021768, 0.1274336398180042, 0.21835248757685932, 0.054935491111661704, 0.11426550070089952, 0.1792908278959138, 0.07661651700202908, 0.11588850218270506, 0.08238382717328412, 0.1250955167093447, 0.12355303019285202, 0.1343869138509035, 0.12939248899263994, 0.11828940335128989, 0.11012832341449601, 0.09252236850027527], [0.050358572243047614, 0.035655566557709656, 0.004787006032919245, 0.059286529065242836, 0.020626348376806294, 0.03236624252583299, 0.06407599563577346, 0.035235916397401264, 0.07593688275665045, 0.029004786828798906, 0.027415634066398655, 0.062166727014950345, 0.03225797887093254, 0.016546839781637703, 0.05085000801565392, 0.032035012263804674, 0.07145736419728824, 0.03319645047719989, 0.024349615909159184, 0.02913650743929403, 0.03196654808042305, 0.017022441939583847, 0.0863174507394433, 0.0307227899985654, 0.00840881307210241, 0.037921544430511336, 0.030129061679222753, 0.03762815606647304, 0.027637306367978454, 0.02381359360047749, 0.04557119216769934, 0.03717737811218415, 0.01800533214450947, 0.016668241570836732, 0.1243318933993578, 0.033281369134783745, 0.04167410771229437, 0.06424972774194819, 0.07228660184357848, 0.04051959394876446, 0.028469677149717296, 0.04100803738193853, 0.030879080362085785, 0.017317200944359814, 0.0423511329905263, 0.030004655676228658, 0.05882513203791209, 0.034508733810590844, 0.02706861259814884, 0.025131644481526952, 0.05581047558890922, 0.04869358640696321, 0.08183424773492984, 0.026957563556996838, 0.09012705167489392, 0.04509059599201594, 0.0217381924656885, 0.0030407603272968636, 0.0025233750431133167, 0.008612091985664197, 0.02105316556324916, 0.0416174161114863, 0.11351408423589808, 0.044624486538980684, 0.04048026945175869, 0.048138073179870844, 0.10656934617353336, 0.02613128093071282, 0.039818867442331145, 0.06920117419213057, 0.059921834617853165, 0.005070479728081929, 0.017551215797928826, 0.0420211478402572, 0.018156981328502297, 0.0074327277252450585, 0.02641848105538104, 0.029860714650047675, 0.02451348550883787, 0.011689866610270525, 0.008217372898278492, 0.046987016552260945, 0.020899380690285137, 0.04549838536019836, 0.022033865796402097, 0.07603035774081945, 0.046230704457099946, 0.026278217689001133, 0.028786003390061002, 0.012977684515395334, 0.02383351029961237, 0.00676331264133166, 0.04426762122394783, 0.020661216595077088, 0.03797773052273052, 0.050776105374097824, 0.056965905374714305, 0.045438925336514197, 0.043008043098130395, 0.05423552456444927, 0.02094257453323475, 0.024679193938417093, 0.03848684552524771, 0.029725669217961173, 0.02760493685491383, 0.052410811584975035, 0.023064195777156522, 0.044284381038908444, 0.08436391449400357, 0.021862708730623126, 0.013483354256355336, 0.10094567508037601, 0.01877198172067957, 0.04074797187266605, 0.05768490143652473, 0.044910641719720194, 0.013819810934364796, 0.053652228721018345, 0.014288039112995778, 0.030435423632817607, 0.05972541230065482, 0.03323699633723923, 0.0360324215143919, 0.03563164480562721, 0.06396477696086679, 0.03442920272105506, 0.07034968292074543, 0.021109965729660222, 0.05049087978633387, 0.008590133744291961, 0.037237648985215595, 0.02992814067485077, 0.042808394346918376, 0.036843033374420235, 0.13791647659880774, 0.015409798294837986, 0.009441267715633979, 0.021407175942191055, 0.02322230631086443, 0.03934173858059304, 0.028976478347820894, 0.03717182430305651, 0.007319523487240076, 0.03890325228816696, 0.017125328204461505, 0.0321459459540035, 0.015674791664683392, 0.070191462125097, 0.015777918809492673, 0.016006608859502842, 0.033972429909876416, 0.02268461310969932, 0.05243360357625144, 0.039874877115445476, 0.028163293143734336, 0.037054427566805055, 0.08125482632645539, 0.055096996016800404, 0.0176050728186965, 0.027749831222796013, 0.012468759502683367, 0.1319121066480875, 0.015844630676188638, 0.07282862240182501, 0.04398605293993439, 0.00890735989170415, 0.05757800502968686, 0.06667277629354171, 0.03003446032692279, 0.06946238981825964, 0.012851325179716306, 0.04391295775505049, 0.05211174727550574, 0.007894160375664276, 0.09210335277020931, 0.07432647488479104, 0.0464425363045718, 0.013981146205748831, 0.04005361341738275, 0.053296449062015326, 0.013845407819774534, 0.002727685117861256, 0.02100800905775811, 0.02787249339079218, 0.030686993883656602, 0.0436407498616193, 0.001980365308034899, 0.06968809092151267, 0.027347224165818522, 0.01322325736483825, 0.06183377666664975, 0.03316953299301011, 0.008480661448889544, 0.008924759225919843, 0.01659851531232042, 0.05007349254031267, 0.018851054799077765, 0.055160812235304287, 0.007728370521882815, 0.04125930568469422, 0.02060823149180838, 0.021756891194464903, 0.015871034170101796, 0.012048733603608395, 0.008149451542911785, 0.036303709992872815, 0.004375415596379233, 0.03538320938657437, 0.01504523160734347, 0.00962705654092133, 0.039096359961799214, 0.07012105054621186, 0.06497479669217553, 0.03897032208208527, 0.027905897669760243, 0.0272805903306497, 0.04405300399022443, 0.011305254301987588, 0.01741955116657274, 0.03345443627664021, 0.018341432591634135, 0.0661787756585649, 0.07316115205841404, 0.04085188951077206, 0.02800675681126969, 0.04609696181224925, 0.06818983810288565, 0.03128433879464865, 0.030356130030538355, 0.03568296580176268, 0.023447810638962046, 0.010708034919973995, 0.025324468866788914, 0.04823424194806388, 0.03932991850056818, 0.05285085511526891, 0.031204241128372293, 0.027389147451945713, 0.06126449257135391, 0.02265340049884149, 0.021621786390564272, 0.026900229044258595, 0.05998488409178598, 0.020892664889938066, 0.029096589224146943, 0.05685220665431448, 0.0348007379631911, 0.007437565679928022, 0.014133217777790768, 0.048843071064246554, 0.015814537648111582, 0.03858966054394841, 0.052214589435607195, 0.009687106041902942, 0.05430389714560338, 0.04175434787092464, 0.018949805393016765, 0.04101797452728663, 0.08425346256366797, 0.03192810907161661, 0.010565065047038453, 0.09206136502325535, 0.06678723158048731, 0.019490251750020043, 0.03976783821625369, 0.01961662550456822, 0.030658865214458535, 0.0391870834864676, 0.03716195161853518, 0.058479384519159794, 0.0348696669430605, 0.045414610034120936, 0.049747805909386704, 0.014743722875469496, 0.061115995182522705, 0.02729053426134799, 0.03785278169172151, 0.016106563853099942, 0.03023804797391806, 0.023886476743168066, 0.022482175579560653, 0.046198772599122355, 0.042144519077347856, 0.04115902499428817, 0.1075021079076188, 0.0071829640738932145, 0.010696282693451005, 0.028198697404669862, 0.08672111122203724, 0.04946667867313538, 0.038161939209593196, 0.03000951398696218, 0.041080786513962915, 0.024265251953953078, 0.02647761538225625, 0.04468862845429352, 0.034878057028566084, 0.019153795072010586, 0.027553777010845285, 0.090108643019838, 0.06516889841961009, 0.0278795128355601, 0.013229795049742928, 0.028826545857425247, 0.01728061433615429, 0.051540220621973276, 0.02645020935285304, 0.03305986477062106, 0.031055126272674118, 0.052471950982830355, 0.07085713211979185, 0.038268197793513536, 0.057931718549558094, 0.018603718606755137, 0.006288601060597492, 0.028039443539455533, 0.03849278949201107, 0.05439669359475374, 0.01573108971518065, 0.02293969986827246, 0.012667969750639583, 0.040242704163704596, 0.02855310303026012, 0.0275594173331878, 0.08023967687040567, 0.026223380185131515, 0.07149158271827868, 0.04395727287711842, 0.017088281888780848, 0.047600252753389735, 0.03980901850653546, 0.03812703876090901, 0.05444994841569236, 0.06509437491851193, 0.03393044216292245, 0.039502802437969615, 0.023408111251358475, 0.028698818425514867, 0.062055698329848905, 0.05999400360243661, 0.015530959204105394, 0.03202854243240186, 0.014233846217393875, 0.0360942190912153, 0.01744071806647948, 0.0677821606929813, 0.016981088622872318, 0.015975211347852434, 0.02539410861209035, 0.06661254952528647, 0.0727661225412573, 0.11802349904818193, 0.13850288013262407, 0.16915207622306688, 0.10143337212502956, 0.11170941857354981, 0.1004071489774755, 0.10340965286429439, 0.3390335775911808, 0.1688867283186742, 0.1265653864081417, 0.08994078702692475, 0.10504670002098594, 0.1252103384052004, 0.12888981668012484, 0.1472170203924179, 0.17988411177481922, 0.08596687205135822, 0.18284321656184538, 0.10975816899112292, 0.0691697308793664, 0.10443467500486545, 0.08869669307023287, 0.11535108887723514, 0.10765690888677325, 0.1488934632922922, 0.10707228311470576, 0.10300840118101665, 0.1483390594699553, 0.09744829524840627, 0.10426018293946981, 0.09915010857262782, 0.12193291927022593, 0.10225356489952121, 0.09092065944735493, 0.09297948397163834, 0.1729887439204114, 0.12783401619110787, 0.1780485524130719, 0.16435635355966433, 0.1957964500678437, 0.08986958156206779, 0.09380816521921329, 0.10631767753511667, 0.07359384026910577, 0.11284755928707974, 0.11093188529568059, 0.13756617611008032, 0.10705964200730834, 0.20923596248030663, 0.12540566149566854, 0.2898926873292242, 0.19127562908189638, 0.24485172278114728, 0.16284141556492873, 0.18592475620763643, 0.13018178806773253, 0.1824630605322974, 0.13769774405019625, 0.12351326804075922, 0.07670826850725071, 0.10417918621429376, 0.07302986231765576, 0.08550839950995785, 0.16056715617222445, 0.13446456539843762, 0.08702715087149825, 0.12159267467047487, 0.15310633794537612, 0.12039773379053388, 0.1048827523897801, 0.11683511281652109, 0.10172930838806288, 0.08847357718540089, 0.15321790267314228, 0.1440031257058893, 0.1402557125048978, 0.23249307594129018, 0.10602915765983717, 0.1348798016884497, 0.17275429650076798, 0.1379406324454716, 0.07455404874469553, 0.12726814512695583, 0.15359591453203134, 0.09523695640798126, 0.14058497840804712, 0.1682956971760307, 0.20630619754748686, 0.08232822122850589, 0.13118649486984524, 0.11268668541950838, 0.12303849708821092, 0.13962692767381668, 0.1184679666267974, 0.12533087336591311, 0.28561080566474367, 0.14404239931276866, 0.1533378405230386, 0.17444113455712795, 0.13911015540361404, 0.08999112075460808, 0.16925575637391635, 0.0665645431727171, 0.10868459088461739, 0.1944432748215539, 0.10207697616091796, 0.1278002115764788, 0.15143701966319764, 0.1538473931806428, 0.19207498404596532, 0.08899184223264456, 0.08040616900793143, 0.19947695971599647, 0.1484467022653137, 0.12499514780938625, 0.11479627793388707, 0.11510545920048441, 0.15323804159249577, 0.08621362131088972, 0.12954695070428507, 0.19925031544906752, 0.1557210726397378, 0.1095016420419727, 0.10035449466002838, 0.13188674300909042, 0.15742437195565018, 0.15333428499954088, 0.13700476980635098, 0.13793227289404186, 0.17901279138667242, 0.08910148670630795, 0.07413221709430218, 0.11375588018979345, 0.07834584492125682, 0.1277208094085966, 0.18474090258990014, 0.12990793133420603, 0.12792242930403777, 0.11654330204640116, 0.09204834393624749, 0.1943078799439328, 0.10999324744833366, 0.08579735364764929, 0.059108746105006764, 0.17614754156342574, 0.07116236431258065, 0.15168072230049542, 0.09681458425308977, 0.12542960021112645, 0.17890835127660207, 0.11977482507271425, 0.17513233103922435, 0.11889000183769635, 0.16931510104664735, 0.14570356160402298, 0.16520212031900883, 0.12231245104755674, 0.13568349927663803, 0.15227810453091348, 0.12378278215016637, 0.15332901956779615, 0.14892118823315414, 0.15246295104069368, 0.18420009660933698, 0.15418995837015764, 0.12063098698854446, 0.11456652597657271, 0.12556032676781925, 0.1314348251159702, 0.12068106287292071, 0.09749958571046591, 0.10203528018402201, 0.08492937165179423, 0.06869913970253297, 0.19269226092313016, 0.19676560163497925, 0.17854969123644487], [0.007928434875793755, 0.02647852461918124, 0.016111276278804456, 0.03356783983430692, 0.020786126410322528, 0.060432907193899155, 0.019867693639493415, 0.03590850744928632, 0.06797137018293142, 0.040056917882923565, 0.03848427048485194, 0.04201267293787428, 0.07265552133321762, 0.005947738145810685, 0.03329193053234901, 0.008498590888588555, 0.03883324443761792, 0.019578227207862904, 0.03855476688061442, 0.09832645526954106, 0.03666164060788495, 0.00730029889382422, 0.03376232832670212, 0.007692080772747951, 0.05242567828723362, 0.0020636154055994537, 0.044676106090524366, 0.05748242658696004, 0.08213037398776837, 0.020488670228847435, 0.03877420510564532, 0.05173231727842774, 0.017090789075674753, 0.05859696785254138, 0.0729600682056376, 0.012848957940669996, 0.017910069220566323, 0.016561757374022688, 0.043234334526849647, 0.039542985281773975, 0.03518008653606687, 0.005098180072049477, 0.042985237536153624, 0.036933855286666324, 0.04392829943182213, 0.08452736679464579, 0.02007602254993149, 0.033102263031261306, 0.07576924389494316, 0.037290910591504405, 0.01728531828017107, 0.027617942674883773, 0.05708366512720074, 0.0021608802198898047, 0.006463443419696497, 0.08301575362150158, 0.01125487731769681, 0.04511772042938641, 0.016213265181119953, 0.019449675355904868, 0.030058477073907852, 0.09475394804030657, 0.027158438760255064, 0.013397832550773663, 0.032547523334090195, 0.054052628842847686, 0.024467443515147482, 0.010807391106417137, 0.02349180176055857, 0.026706078123035173, 0.04611061393682446, 0.021962271870246956, 0.05173394576247249, 0.023844721394457986, 0.026900681966383542, 0.07828538066574506, 0.04047904808872512, 0.034323212158467085, 0.018610466637515595, 0.034844557754695415, 0.024860744464344213, 0.0874432014035327, 0.023863750909055983, 0.03807440140683736, 0.0020028288459538347, 0.088549735955894, 0.0171473958596055, 0.049596343322524, 0.04936333439712014, 0.018947508551978638, 0.009121966099233499, 0.08812643188451018, 0.03710094114233341, 0.03845741067613874, 0.027204289067802683, 0.041336987766304185, 0.04293033726779478, 0.018843270306076323, 0.013879436350959753, 0.07235149014741182, 0.03151553603155272, 0.05057067211185183, 0.04762179624023182, 0.009885041492192872, 0.02341104591531413, 0.08532227056899241, 0.019680219502853494, 0.04141076827155692, 0.060043936994458945, 0.05572802001344306, 0.03525947513324874, 0.06650542920189244, 0.023343752204839672, 0.028682655721370662, 0.0026090089190152605, 0.025949788080262284, 0.009162778284267654, 0.08083153582577195, 0.06660638164196696, 0.07488668018153735, 0.02831266075372696, 0.07254314236342907, 0.026313299645802805, 0.03676766170454877, 0.050550943706184626, 0.014897796125816447, 0.002514770582950275, 0.03761379148012825, 0.026709847385063767, 0.04869408513020192, 0.022274504848090664, 0.014760491172117847, 0.02732928030725036, 0.03700510824897459, 0.055137148326528926, 0.04364195086860231, 0.010742417985706456, 0.00786130062104868, 0.023941899483491267, 0.04858119386647429, 0.04490715404972434, 0.04258735817191856, 0.01708638368706618, 0.051151196139731576, 0.03219321270340255, 0.06598783590431724, 0.045685847622475455, 0.028872879621173655, 0.019102792987333875, 0.008771796228497155, 0.059285721608570645, 0.04428363125771284, 0.06444027394588504, 0.024008996418810317, 0.03540760611316987, 0.01491604871781809, 0.010973999443064843, 0.047641049671385965, 0.01373694314887481, 0.027562484311472093, 0.13315195297556265, 0.04745146020182541, 0.017247155774384737, 0.043896055447735956, 0.009400430933705397, 0.0711599283718637, 0.024617187712075453, 0.010620641305909624, 0.07710168989641325, 0.0614055667870811, 0.03040946627567921, 0.022989217657595873, 0.028079132749033824, 0.03994984505698085, 0.05006838317162224, 0.04550409862505538, 0.05043084979323404, 0.05439276148432067, 0.08192793306495462, 0.01970451614553375, 0.029031711098338877, 0.00964101230991738, 0.04325074150360056, 0.007934858906082809, 0.030863307815577303, 0.03718452647860561, 0.038595557013260465, 0.029758371213184934, 0.05496525505025472, 0.01952604786492884, 0.00874149370273309, 0.009573664316641433, 0.04646534186654857, 0.032284831894295554, 0.014700221995423948, 0.010129988393081086, 0.010061829550457852, 0.02517244139952319, 0.09037211138222899, 0.036595758250249286, 0.013840807352348097, 0.04827908632744636, 0.029319199600390027, 0.019660818490332792, 0.038708044548652, 0.032703627100480456, 0.040103987857167206, 0.031290072415556223, 0.044914512762001584, 0.04811385287238019, 0.01977080732051815, 0.048991062944488864, 0.054859318770468235, 0.005138679706890668, 0.024432590563914607, 0.058846689095454555, 0.019744824518316557, 0.048215131009263654, 0.0302609722795231, 0.06957860929625374, 0.01909045043534466, 0.060986951392676146, 0.020185734877096753, 0.013266721773626549, 0.026791142665648034, 0.038270308037421534, 0.027134596736037304, 0.021471602842211723, 0.05032096443963902, 0.01987361046485603, 0.04118905695421355, 0.08227959062371935, 0.012613530037924647, 0.05154013580509594, 0.027961635928867117, 0.029351789637335708, 0.02735730041084545, 0.06836606043257884, 0.015842098044231534, 0.055550766310521534, 0.03267884021624923, 0.06157351777489696, 0.017557351450834955, 0.032329170765089135, 0.054379109359745464, 0.02368440562193947, 0.003960909155596579, 0.019011703053755418, 0.029351484296577315, 0.016303618904203176, 0.018285595944949558, 0.030293511426342384, 0.049537965562194586, 0.013613735608357404, 0.025080070731097033, 0.05493376763271434, 0.048151355502860885, 0.03611275666792478, 0.009160395778183426, 0.0987735894907798, 0.037117097061127424, 0.0802419703187687, 0.02149556700273284, 0.01559186281104173, 0.018241033157599822, 0.03317339385726622, 0.024535804221938764, 0.054229017413620434, 0.08317459866936718, 0.016954188102058003, 0.013028905427615558, 0.032330873887985945, 0.028909859779689993, 0.04223437746986747, 0.012753695864895625, 0.012230212883358555, 0.012423347698391547, 0.06449828868997948, 0.021163313849163905, 0.019365849139701043, 0.015099395665207078, 0.028894049913755486, 0.02898028153660042, 0.04124803861070957, 0.029197684156575372, 0.031910799643290896, 0.0034114431598157224, 0.012749711167998612, 0.031713807356676886, 0.00916536180635116, 0.03587070626339742, 0.012078269384801388, 0.023262175332222666, 0.03078693530655333, 0.04310206091031432, 0.04517592177061098, 0.017962343558402996, 0.05095558806455561, 0.04655141064098903, 0.07537570036947727, 0.05137965548783541, 0.023513933876529336, 0.043163441188101254, 0.031050485093146563, 0.02251745431151773, 0.039376170840114355, 0.004738281281398875, 0.0392159483661609, 0.02463570493273437, 0.028250737647925104, 0.06574654206633568, 0.042726610521120686, 0.05718417651951313, 0.0026827588901921573, 0.0286867031827569, 0.04102499736472964, 0.023811810749715993, 0.02123414272708552, 0.023497667695794786, 0.04908500272514565, 0.0311006186529994, 0.057235032719160826, 0.054515097955507894, 0.031111478605972867, 0.03713495271014316, 0.09338328016123601, 0.062455457236085615, 0.04929157931889806, 0.01945056762945439, 0.07062206044793129, 0.07123305409082345, 0.016048932481291037, 0.04438910274101155, 0.031031431829822913, 0.053285602679742236, 0.06841626523860864, 0.05645960629252451, 0.023654970772830502, 0.02143783724334623, 0.024001425664339746, 0.06200691166200808, 0.039581319117652516, 0.027981077653488944, 0.06393220049462148, 0.07379568408110312, 0.029992000998130867, 0.037341624298798184, 0.04498696673129286, 0.01949916430748999, 0.04346782521211675, 0.052843313198536634, 0.03495762883020299, 0.09302027749695949, 0.15788610146514007, 0.12256658955344132, 0.150685596412846, 0.10679804640156881, 0.17844489828816482, 0.09202593192458153, 0.09759380029780523, 0.13328658789396286, 0.09230685899300234, 0.15298250530447277, 0.09552525915205479, 0.17949221708944865, 0.1098304736827101, 0.17110107306923183, 0.16082293673285417, 0.09236318418490035, 0.09891680787716593, 0.2034370529332331, 0.1147359697414296, 0.07799762074968644, 0.09662008897534438, 0.1546037154538291, 0.10579965676047973, 0.16445190486099037, 0.12866739290101187, 0.07669861295393535, 0.08106691962374107, 0.2416194805077144, 0.13052501822156565, 0.15071746041732176, 0.10749351765428271, 0.18285187466868333, 0.14682550568665775, 0.1443469122584377, 0.14340316504240036, 0.17232759296894073, 0.10727832027311836, 0.11006160306611232, 0.17702723507370266, 0.15189414870526108, 0.16130890351321014, 0.10118814956929002, 0.14671090112200805, 0.125732566096953, 0.1907187146799905, 0.08010769502392837, 0.0987847853185875, 0.17795610880213125, 0.15061635869954312, 0.09847777536404984, 0.09734366514853068, 0.1580293673489775, 0.08426963883851256, 0.09846445572163377, 0.21742814646235534, 0.11048855087054626, 0.1216574204819543, 0.11690392983811242, 0.10254675309572901, 0.09409170464745589, 0.24154842432056153, 0.12178706138261727, 0.0917117769962975, 0.08397518856717007, 0.16708979117018835, 0.13767981715500355, 0.06220815157783883, 0.10008239533220019, 0.12643649189599923, 0.22282252700201102, 0.09542230503367526, 0.14702331221529416, 0.2778919812824045, 0.06874190776475839, 0.13229117702160562, 0.13030175305902958, 0.0986937191337347, 0.14886454412979738, 0.15280037293476717, 0.08648778338517461, 0.12976005141224178, 0.1490678060799837, 0.15686960172440323, 0.07465333198862416, 0.24273485637136868, 0.06927178254617111, 0.10355028603225946, 0.12475862407258578, 0.11066974686192614, 0.1128047572981034, 0.11360526577170406, 0.21546158912990773, 0.12127410247921944, 0.123923035338521, 0.12292778731456824, 0.14963381285113947, 0.07925926840731076, 0.10705351483608995, 0.1641458041433777, 0.15234027190932206, 0.21106792560645513, 0.08645019933049168, 0.09469128533133439, 0.07449975237250328, 0.15799945752535546, 0.11403908713587693, 0.21136866589742048, 0.33464554590838297, 0.17293017277760164, 0.15408071423215525, 0.14455324118690832, 0.10217002366802522, 0.11195307371339627, 0.0817105575863804, 0.09262911562940904, 0.11247651598283223, 0.12576839274593762, 0.10784098186663219, 0.23514251091650554, 0.05915879484798227, 0.12551665625401906, 0.19452042425317423, 0.18244999194783823, 0.08617239352315664, 0.07700366194226912, 0.15813957500670636, 0.1800716859953744, 0.13344790280929633, 0.15784882275121553, 0.15421780544732297, 0.09840395075402089, 0.07749318424612284, 0.0967596432726298, 0.21549786361200468, 0.0993754229109202, 0.29043092844741686, 0.06292866077274084, 0.14273693864899023, 0.22534746437200479, 0.09596268353717667, 0.1322329044342041, 0.09978435561060905, 0.13594484382442065, 0.147614682625447, 0.11742178776434489, 0.18930635760937417, 0.1092193036207131, 0.15656639156597002, 0.2261901098702635, 0.1761832596468074, 0.11180591982390199, 0.12558141563619885, 0.26997803737010273, 0.12983382173946925, 0.06730030583483831, 0.11349119724971907, 0.1842060134346996, 0.2205588798969984, 0.11802318692207336, 0.3438070443059717, 0.10673658469957964, 0.06202067913753646, 0.20789155390645775, 0.2241031261427062, 0.1562264726630279, 0.08721862666841064, 0.11709706804582051, 0.1494519111833402, 0.1542566040796893, 0.08617373702249356, 0.13636861608496734, 0.14351437693195684, 0.08006667079670088, 0.15188346856406756, 0.09585737490228244], [0.03483945517135518, 0.047506319758083136, 0.07471598791224615, 0.019563967794446007, 0.010094908132616962, 0.00919191797064351, 0.07237478425460202, 0.07729473989456892, 0.046969897113740444, 0.030709504282900264, 0.06863548633243356, 0.011774259403214922, 0.029846641833760908, 0.020816178726298467, 0.046349777174847465, 0.02840234442347927, 0.059278366288968494, 0.01433581645999636, 0.004606862194902662, 0.05894464919609683, 0.02948039916477033, 0.07664103925760303, 0.05080361657642892, 0.024021001399627755, 0.00963355096921857, 0.007921944688340383, 0.04350963653996587, 0.012074048896985394, 0.07891261165163346, 0.01884851877444557, 0.06578947976231575, 0.03178629864539419, 0.035426252255482335, 0.01795336484376873, 0.04199935668813331, 0.010559360263869166, 0.022520187111305337, 0.03740234639761703, 0.07743909821978637, 0.06145322708679097, 0.028350911469065716, 0.07835965989423649, 0.05072041800511735, 0.01462469935151083, 0.03494588678170528, 0.04330822020503027, 0.07017672434449196, 0.04003582222919379, 0.006102214700409344, 0.022940502235932008, 0.04091741903019803, 0.019422216740037714, 0.014280342829546757, 0.02116739354096353, 0.029694161444370235, 0.07311613804527692, 0.08063438069075346, 0.010986582026816905, 0.03939619780118976, 0.035916945032243214, 0.011766099171446902, 0.04699846004535045, 0.06546367438776152, 0.046304413716175725, 0.028744904523981468, 0.025434254136468683, 0.017284999368712306, 0.03982371557503939, 0.04045728747067707, 0.024105984518038373, 0.05012649969596948, 0.03704049385019711, 0.028816886911434785, 0.028660345489957502, 0.03721256693825126, 0.01895930997229048, 0.035077990764485936, 0.07327872860644545, 0.07479519330497299, 0.06972950869905097, 0.01390503323636949, 0.0561638125218451, 0.08385584104274, 0.07189803197979927, 0.061880222388676236, 0.03382906224578619, 0.0779577771733914, 0.02884975854041321, 0.03458046853276236, 0.045674064861876626, 0.11852040381303855, 0.0957825460604259, 0.04092865896278194, 0.03255906182208231, 0.029558216953384023, 0.04917416901194623, 0.03171187013919864, 0.04904599374692355, 0.003091658723341035, 0.004018608804991735, 0.002461440274990829, 0.054430538921483924, 0.025134591019845436, 0.013854570587032607, 0.020177656917699745, 0.041282304629151306, 0.09987958121512618, 0.06612047592976264, 0.03104244445317558, 0.03290957944201572, 0.03813009895384312, 0.054572308635605235, 0.017381062963977456, 0.039293033336954455, 0.023509447063718523, 0.01606239631239857, 0.05102006585470267, 0.04129608228270497, 0.014191931412954415, 0.03697561572438904, 0.045706257955836396, 0.02673477676164891, 0.014129975228570402, 0.01706794449793441, 0.048652426472732, 0.025025716683428203, 0.04786891190867339, 0.018330876283081513, 0.04460951466379421, 0.017645518594820584, 0.04243470475609813, 0.009125469036267271, 0.0765733825308936, 0.038444029965570996, 0.029067656490951777, 0.016542899189516902, 0.009688039875722356, 0.024477114335500767, 0.05628922954201698, 0.032668977709753175, 0.010890079928295953, 0.037042173224368265, 0.02421437030924218, 0.07055597113711493, 0.03943499304088099, 0.032915282528847456, 0.028473996025110995, 0.053426144245479784, 0.033707865713430304, 0.03534253460488149, 0.060745060443878174, 0.0234793116272028, 0.03574894315430096, 0.010210325242951512, 0.038335128487753015, 0.036333290727010796, 0.010989330941811204, 0.023345165254016007, 0.08324193648461785, 0.009806356026924081, 0.03812916936086757, 0.012199165665411522, 0.037109633175922294, 0.022374626082767333, 0.012060504489844399, 0.009786839663450207, 0.03588231599756649, 0.06644233901585851, 0.055624322899218114, 0.014221091455380832, 0.03889517432876995, 0.03518872428685427, 0.0351125485529857, 0.031224145953144346, 0.03384168978248324, 0.03660687604652984, 0.040234436214502366, 0.0021360693748907317, 0.08686143226389374, 0.026003483948963027, 0.0396018108752157, 0.07574454522026436, 0.06568332974399839, 0.03811631451493927, 0.06560217695576803, 0.035522465128451586, 0.07130721118301153, 0.025415777627910887, 0.032666188930826526, 0.00853190865434174, 0.015617460544620241, 0.006936830160806754, 0.016925871139392257, 0.017046606267935464, 0.03947125734495265, 0.058141175524464676, 0.031047737026321034, 0.00898696986093585, 0.05119142648098724, 0.08912707426186119, 0.011356682167388499, 0.012354680802673101, 0.009658482890310032, 0.029838258533605506, 0.054184498731046915, 0.029015541608844484, 0.0340563239795821, 0.044080304846699746, 0.028918327896722724, 0.06709365799490895, 0.021469937038740942, 0.05226913347308125, 0.02208231489307114, 0.004019007868399578, 0.07458065410277673, 0.021717023869444217, 0.0490117820112833, 0.05074010909135852, 0.035804501601627896, 0.02269956123616014, 0.05819596044187035, 0.006942426378373057, 0.051798905312482796, 0.03431293235293456, 0.008129471231118908, 0.018932604530294026, 0.025344923304926072, 0.05296376334237201, 0.011725081729569604, 0.04598881350830197, 0.03204357198306492, 0.013005987059191933, 0.09690554865768977, 0.01224524328219039, 0.012619001574681273, 0.024934652194912945, 0.009269576303527823, 0.03209256560408643, 0.045216844217585664, 0.04153580870479345, 0.030376788029181104, 0.044240252513970645, 0.014558167296594806, 0.01984846904607756, 0.020802202601251856, 0.01182704433865313, 0.009770296979695559, 0.03750611815069403, 0.009005184285342693, 0.03644316250990544, 0.02662778875258352, 0.03402577633304255, 0.06380538229963609, 0.03227337822318077, 0.06172894300626857, 0.008243781481204289, 0.03797439213043877, 0.04117887892893382, 0.03453974286094308, 0.058932503419263024, 0.0053844001377001405, 0.004420614934393338, 0.006658725373979125, 0.01928941556252539, 0.07384068452353988, 0.020597892314461724, 0.10491325253886835, 0.0239347290646817, 0.013054100281026746, 0.02001497645064124, 0.013171236629464796, 0.03054495614820293, 0.041184989136776755, 0.05443363304116896, 0.03547420432525022, 0.04039643305752959, 0.04728960245847702, 0.01935967616736889, 0.045967154670506716, 0.04591646810461368, 0.04552473287497248, 0.009042531700937875, 0.04473816151065486, 0.037582358345389366, 0.05214921258656042, 0.02823823394386896, 0.02245086627746267, 0.014774160260068519, 0.0371881973530565, 0.0820489769269313, 0.030792685890836374, 0.05467649090236851, 0.04000593954697251, 0.02665205655752548, 0.014990758816046374, 0.00491290438886998, 0.030172443815640042, 0.04163285956851073, 0.03853953376944576, 0.016056942587186183, 0.015220003568434289, 0.03673047459285174, 0.02107962333996381, 0.03888639069295355, 0.05322209519467183, 0.042508553114852736, 0.05355159179972751, 0.014419025209333216, 0.0345829044734793, 0.016864511217655878, 0.028102823799209933, 0.009529575655635978, 0.007313347970401602, 0.02609059427465711, 0.03623695232506309, 0.057701953021543365, 0.008655913473506058, 0.03320006706884929, 0.028159098100981543, 0.024787832483915345, 0.05826601239719561, 0.06775419147951262, 0.05100085652832474, 0.06973120503659759, 0.01694993708016617, 0.027094149263575673, 0.08274435318474259, 0.012712563072065157, 0.026229792341057743, 0.021882337052375078, 0.07330339335437332, 0.02226851847288864, 0.03832995126556073, 0.028404997495402182, 0.027323567042393342, 0.026234957688887204, 0.022916817971106087, 0.04598079322438155, 0.026078947221062014, 0.03369775214897735, 0.023923153257263557, 0.04768596190427031, 0.04874078869553549, 0.021750394221661345, 0.04869418351777962, 0.03912939443918211, 0.04187755625961082, 0.008141573751345277, 0.03554083985675659, 0.08621239316250597, 0.006899587918139462, 0.015627348496179496, 0.12101374859256403, 0.13048813305795193, 0.15979031500007423, 0.19337914192250796, 0.11103801495794739, 0.15990491956472397, 0.14178732889039175, 0.11579278803297452, 0.14849958728466714, 0.06523076045726027, 0.18993003985711507, 0.09020175838044711, 0.13988363104207174, 0.09241415573550121, 0.12384967213230473, 0.07231055412973676, 0.12810277034129414, 0.05472065335405724, 0.12901575277958596, 0.11321031767874956, 0.09480644629469939, 0.1156328980411802, 0.11610986744718892, 0.12068079145891325, 0.07711151508348328, 0.08915629197976419, 0.12225149146148137, 0.1283912155777216, 0.11995185485907964, 0.05896642338484526, 0.15608647731798037, 0.14610692353120872, 0.05041416800980057, 0.15082177839108876, 0.13924061054629938, 0.13668930530548096, 0.12480769572513443, 0.11919919667499405, 0.1596049799450806, 0.10673691718173878, 0.09404923514063869, 0.14629643836191722, 0.09725586950246777, 0.04553653259894677, 0.11351018265954085, 0.09441423269787005, 0.1363765685153859, 0.09467725322714873, 0.13877810750688824, 0.13747755943664483, 0.100316530625735, 0.08835356469665255, 0.11906449390309197, 0.17176278041941778, 0.11862242833844253, 0.14137186189847334, 0.19347999936767987, 0.08581044258815901, 0.07274513545313052, 0.22592496552637645, 0.09976377564349345, 0.08259908562260014, 0.1376304333763463, 0.11743849329650402, 0.0797028946025031, 0.1119947289781911, 0.09549780562520027, 0.06741571785616023, 0.14767687714525632, 0.0637224449643067, 0.09596598121736731, 0.19928553141653538, 0.14744134406958306, 0.08756327496043273, 0.11136133689433336, 0.13089537620544434, 0.10329014249145985, 0.16460655656244072, 0.1769418753683567, 0.15758169708507402, 0.09426312294921704, 0.18459262911762508, 0.1424175115036113, 0.11109594827783958, 0.15235388332179614, 0.0939731170822467, 0.14319200494459697, 0.2130614072084427, 0.15819015300699643, 0.11864194300557886, 0.23088264092803001, 0.1408937525536333, 0.11437108074980122, 0.15435689155544552, 0.12660316723798, 0.11631745845079422, 0.08279446978121996, 0.17484902909823827, 0.1251680249614375, 0.15475202963820525, 0.13648900176797593, 0.1990900319069624, 0.06220115588179656, 0.11576487310230732, 0.18483796023896762, 0.14164483653647558, 0.1504595899688346, 0.12276193978531019, 0.10249232101653304, 0.10813100130430289, 0.15241778774985246, 0.1208169191543545, 0.1434913067413228, 0.17587946594825812, 0.14510076466415608, 0.09957542789301702, 0.11740733496844769, 0.11025186428534132, 0.06507585091250283, 0.1505407698984657, 0.1426076234451362, 0.13001200503536633, 0.1373662661228861, 0.0716730569090162, 0.1961931623518467, 0.09774965979158878, 0.0970682409991111, 0.08972617997122662, 0.15012455651802675, 0.11382266160632883, 0.08437876762556178, 0.09664010575839452, 0.19585275490369114, 0.21003287471830845, 0.17725231871008873, 0.07130628159003598, 0.10641487089118787, 0.14857396829341138, 0.22724265339119093, 0.07169924157538585, 0.0936449436204774, 0.08956785739532538, 0.09552164934575558, 0.18532484982694897, 0.1476141805095332, 0.08571719152054616, 0.14578453797314847, 0.1742806610252176, 0.07089990696736745, 0.11172404778855187, 0.1777067200413772, 0.09795760363340378, 0.09274699751819883, 0.09584096114018134, 0.09008951511766229, 0.11416032777300902, 0.15048926909055027, 0.06311284910355296, 0.12595216717038835, 0.07842611561396293, 0.09025870782456227, 0.10155837184616498, 0.07414067842598472, 0.16227680657591137, 0.0969679874501058, 0.11678260777677808, 0.10793993262840168, 0.18278133416814463, 0.1075733405138765, 0.14589368711624826, 0.11501771105187279, 0.09333388959722859, 0.11469702183135919, 0.12018770006086145, 0.08383007028273173, 0.08937223574944905], [0.04539768397808075, 0.022717754456347654, 0.03102560660668782, 0.06034890455859048, 0.05645733320021203, 0.11029486983482327, 0.035176653148872514, 0.0055879576747039595, 0.03270819703383105, 0.030409435741603374, 0.04739115200936794, 0.03804046108520456, 0.03468658123165369, 0.04466110368126205, 0.07607858800994498, 0.07175625208765268, 0.06815783160605601, 0.028739554275359427, 0.02198829877722476, 0.05817674433014222, 0.055358252355030606, 0.011414970021827944, 0.019869887003941194, 0.03063755582219788, 0.056576334671782594, 0.02673101089229541, 0.03413686269362058, 0.04000407357567123, 0.0512067613724087, 0.042885211296379566, 0.016727633741019026, 0.048674495824213536, 0.029340485243925025, 0.009833869773761501, 0.01151442714035511, 0.012678442090483648, 0.07133756883974586, 0.010977675406528371, 0.047120793123862574, 0.059043097841952524, 0.02338338882795402, 0.04252582522375243, 0.03197476853217397, 0.012862953573598393, 0.026606750774330327, 0.0463255093699055, 0.017931293795949647, 0.03243609431332775, 0.021716467470728924, 0.016805549917210425, 0.05959471967071295, 0.02490586195407169, 0.016651983871789913, 0.008450431017471212, 0.0354528236868126, 0.05539902891697628, 0.024099579147462333, 0.052222894704235454, 0.014150452567264438, 0.08575477557522909, 0.06648459139146976, 0.02438337472267449, 0.007052915204050285, 0.026865695004484484, 0.011523068283817597, 0.04083417974678533, 0.05684259859845042, 0.08222458178975753, 0.03482938910435353, 0.061902763321995735, 0.050618668286395926, 0.023036608239635825, 0.007664826565555164, 0.03079470792519195, 0.08819218871316739, 0.03971744681309376, 0.02685224304773978, 0.03705841056736452, 0.028200006977255856, 0.04313890875450202, 0.021312890108674765, 0.02738988705511604, 0.021830670003380095, 0.0214136033651552, 0.03101571017344083, 0.06220469104924372, 0.030504980257579258, 0.015542375555794154, 0.006650783121585846, 0.044392027226941924, 0.07680202847612755, 0.026225448020600846, 0.07525120954960585, 0.03732141413326774, 0.0251886516011187, 0.04563787519665701, 0.029890278420810188, 0.02125057514889964, 0.1010554281196424, 0.01561066840908357, 0.036282329354435205, 0.08490859490952321, 0.06310553449605193, 0.006230213546327182, 0.009762625293140965, 0.01958573010883161, 0.041994237141417604, 0.020214094248201166, 0.02087882956090782, 0.05974194819905928, 0.025421836945627416, 0.03167321739186134, 0.11425475270620414, 0.038458296164338074, 0.0204850485481854, 0.041195876231150966, 0.04216229669483645, 0.016625400566096817, 0.06386679650417396, 0.04143757719014372, 0.027002068668869988, 0.05319240589493087, 0.020008649111592343, 0.06731600713516984, 0.016555845637672713, 0.03510358849806445, 0.04561710863241127, 0.018033075745084455, 0.04266537952103785, 0.05048976359622819, 0.02066158300398716, 0.018792814442089627, 0.04507883698014276, 0.08728091618312256, 0.04508332548929112, 0.044480162140514166, 0.0042675772981186, 0.04041766781093819, 0.0666727287960904, 0.05909016103084598, 0.020069377995761375, 0.02725964565096157, 0.02644129509904555, 0.01953203763280596, 0.02990992200960006, 0.012730773255628134, 0.07132533485335962, 0.013480083717565452, 0.06065592129847833, 0.029608672817370722, 0.015353695323158587, 0.03336137519883258, 0.046531617774495056, 0.01276773220992514, 0.01920603887577142, 0.07320680389446871, 0.004676540531883282, 0.06830460551593985, 0.034521456342190504, 0.02273947436229459, 0.03175953043890851, 0.11613696813583374, 0.03318769398278423, 0.037728945658143075, 0.04996731877326965, 0.008395060863611954, 0.04615358555955546, 0.03572517067992261, 0.05922972211348159, 0.017726342293566892, 0.07052344895367112, 0.04229615129796522, 0.06355625138218914, 0.010543530890052872, 0.043205310191426954, 0.02784656996040472, 0.02647964420196201, 0.0046182878764479286, 0.02449522613148604, 0.02034926351292857, 0.036001466746841154, 0.06298516238374369, 0.06877558345773391, 0.02830858445460243, 0.026314448066321865, 0.05313786185745682, 0.05109715082549623, 0.015210483722122652, 0.040760399241532595, 0.03750057112691658, 0.0373717885730522, 0.05433348127241645, 0.02190770408404725, 0.07057152994509254, 0.016097669955343008, 0.04439386944951756, 0.04457432244505201, 0.03268546271803124, 0.007849464425817132, 0.03512234999133008, 0.03396684217399784, 0.04277581788067307, 0.03747457305767706, 0.03212674341297575, 0.03634257987141609, 0.07107742529894624, 0.038485630947564325, 0.08143373565482241, 0.01698130405774074, 0.05696931162050792, 0.05573896139061876, 0.052107353761259995, 0.021880725531705787, 0.02941580941634519, 0.0579885458573699, 0.030033164325037172, 0.02173804149164685, 0.018903758310313736, 0.013205739286994296, 0.019352096931210587, 0.0038963669046227422, 0.04206507280468941, 0.04107348886983735, 0.011603745249366122, 0.08338886645755597, 0.03221978413473282, 0.04799919402492898, 0.06287289876490831, 0.02903736668771931, 0.059715709249888144, 0.033899280442191024, 0.02542942127079836, 0.018466746135215675, 0.058018672812197886, 0.0351267061861498, 0.024668659682252576, 0.031148502869265418, 0.010870628873817623, 0.07008573958384139, 0.04519680029313479, 0.023574734006875327, 0.02410843742213079, 0.03188539868486779, 0.0408932869322598, 0.023392233531922102, 0.03191885385396225, 0.012446776664416705, 0.06820927134581975, 0.035048844292759895, 0.011009384196118584, 0.022383355435782244, 0.08153086115739175, 0.06764027223523174, 0.02011260067644928, 0.0729256732655423, 0.030322630756667683, 0.027211042187575783, 0.06402277813426085, 0.02122948119150741, 0.024549936410039663, 0.03966057540050574, 0.04652915808505245, 0.04513091115014894, 0.04103390992219959, 0.025544975784474185, 0.03434756817296147, 0.06292447421167578, 0.0391599217296711, 0.043313801155558655, 0.020260473813063333, 0.0325648938305676, 0.048527565851275406, 0.07743199395814113, 0.03294239339551755, 0.08618439002228634, 0.04952939905758415, 0.04239483743107744, 0.060480458928006034, 0.049953086501253505, 0.019107949853475605, 0.01487772845263992, 0.03174814122862049, 0.02336564174454127, 0.050089913087763956, 0.019121515464835932, 0.01492808762538646, 0.034003706981561015, 0.054627042662884505, 0.044651387059795, 0.031632162630558014, 0.07764314048524414, 0.022193277421008264, 0.04617917650778379, 0.05274943448603153, 0.012167427189914244, 0.058891777747443745, 0.025429131197077886, 0.04242847580462694, 0.006967144560933645, 0.03088046796619892, 0.021975817125556723, 0.01615015633537301, 0.042378572946680446, 0.010281244026763099, 0.02602353805143918, 0.018562422965520194, 0.038073882327548096, 0.009272505030302065, 0.04600880993530154, 0.025533369442980205, 0.023147234892738715, 0.025755011210484163, 0.045811861753463745, 0.055509874397622685, 0.04756185106400933, 0.022916046137522374, 0.019420866455350603, 0.0257975655341787, 0.04637092371870365, 0.014497536800003477, 0.03873518594939794, 0.03492929320782423, 0.03604654861348016, 0.053613820246287754, 0.06173256638326815, 0.023819656310869113, 0.042624799734247584, 0.036661508293556314, 0.06662519741803408, 0.022335406758689454, 0.018298810414437736, 0.08832315954246692, 0.02579816773400775, 0.06669163278170995, 0.024529371709961976, 0.0805207057190793, 0.05114336584561637, 0.04377345434789147, 0.10087383857795171, 0.03643608199698584, 0.045653518821511946, 0.02457357317741428, 0.08309346623718739, 0.03899719546149884, 0.10568105562457017, 0.018165171246177385, 0.07365334779024124, 0.03753882014591779, 0.02771176371191229, 0.05446439442623939, 0.029621300354067768, 0.02673241206710892, 0.14628190414181777, 0.10763034424079315, 0.146513325295278, 0.21602290043873446, 0.1550467038261039, 0.13171890058687755, 0.10180554858275823, 0.1963854320347309, 0.10123859186257635, 0.2012153257216726, 0.1457886498953615, 0.1272168614502464, 0.17689858483416693, 0.11225430254957505, 0.10679280132587467, 0.11838495465261595, 0.1656378890786852, 0.14136935131890432, 0.11230287208620991, 0.17658416527722562, 0.24692782280700548, 0.09330144205263682, 0.15595458368105547, 0.12699932312326773, 0.09407214248286826, 0.11230230211679425, 0.11613828449376992, 0.1289969573595694, 0.13583789313478128, 0.10367077349552087, 0.07064540883792297, 0.20076438491897924, 0.18461460008152894, 0.09752899341817413, 0.07212069324616875, 0.11441621689924172, 0.17252823577395507, 0.06481260646666799, 0.1485210968447583, 0.09880225080996752, 0.10279067286423274, 0.14973414103899682, 0.17575453408062458, 0.0766628948705537, 0.09140125223036323, 0.14999359925942762, 0.15748900920152664, 0.053264510418687544, 0.16018120545361722, 0.10353125991033656, 0.10514114531023161, 0.18700602890125342, 0.11078746590231146, 0.11152174935809203, 0.11233308046524014, 0.15058510537658418, 0.12689530370490892, 0.10897846440119402, 0.23587668580668314, 0.12088842317461967, 0.16524132607238634, 0.11484735805009093, 0.11228772718459368, 0.250506335071155, 0.0671489518135786, 0.1282435663576637, 0.09661377181432076, 0.259532560727426, 0.09609653814030544, 0.13401762795235428, 0.13112512816275868, 0.11665896512567997, 0.13126335931675776, 0.1356876790523529, 0.13378133491746017, 0.1769350493060691, 0.13208411527531488, 0.10711416908140693, 0.09365880609090839, 0.1497784358050142, 0.17750263027846813, 0.1290626259786742, 0.05889301946652787, 0.1415137435708727, 0.09927856882235833, 0.16960590758493968, 0.09662424160965852, 0.15657564678362437, 0.06519927643239498, 0.13902875834277698, 0.1539108497755868, 0.11225125592734132, 0.10714392962732486, 0.12027669671390738, 0.07800958332206522, 0.11356181238910981, 0.15456638245710305, 0.12691158854535647, 0.18519310546772821, 0.1144736616739205, 0.1517666655459574, 0.21648581059915678, 0.12258774627532278, 0.053162238228001764, 0.09632874639438731, 0.2110429826591696, 0.08535178684230361, 0.18508091648774488, 0.10033309366554022, 0.1224163890417133, 0.19352262493755135, 0.12315630433814866, 0.15336648827152594, 0.09686911811253854, 0.15667001743401798, 0.0962954710370728, 0.11022439718778644, 0.11037521516638142, 0.1323407779314688, 0.1355566539402519, 0.10244086770606892, 0.14991161865847452, 0.13832040849540914, 0.10370381136557885, 0.09032569958695344, 0.12241661974361964, 0.07736699708870479, 0.0698814055483256, 0.12300892653209822, 0.14586372300982475, 0.1944965941033193, 0.09634696505963802, 0.12974555790424347, 0.23667955558214868, 0.04806039449093597, 0.10196744703820773, 0.1057579539982336, 0.16545000273202146, 0.0984543523352061, 0.1372961327433586, 0.20219822440828594, 0.13696180496897015, 0.22341434524527617, 0.07056934506233249, 0.13848127557763032, 0.11184499665562596, 0.11268682112651211, 0.14974057355097362, 0.1366782316139766, 0.0734769015439919, 0.08368328958749771, 0.09509178384074143, 0.06520690316600458, 0.08168391151619808, 0.153294156438538, 0.18807887418993882, 0.10614330082067422, 0.18223028230879987, 0.12972719674663885, 0.09426402540079185, 0.12138847634196281, 0.2636322150272982, 0.201857328414917, 0.14494367023663862, 0.09688912132488829, 0.05255566184808101, 0.17212590521999768, 0.11203392116086823, 0.1914766790079219, 0.12317596828298909, 0.25058355235627716, 0.12490391199077878, 0.09146964856024299, 0.15862590819597244, 0.11787423491477966, 0.12981016800871917], [0.007890997554308601, 0.0050220866105519235, 0.03763735360865082, 0.017925254834283675, 0.04190490800621254, 0.029672499213899885, 0.014379984000697732, 0.02017077657261065, 0.020347182106758867, 0.0034466928419923143, 0.05130700135071363, 0.02954236976802349, 0.016243627926866924, 0.03431210114753672, 0.04770076075302703, 0.04267614108643361, 0.022567306279337833, 0.02926077094993421, 0.010460691094132406, 0.028883200138807297, 0.05707103080515351, 0.0457024886938078, 0.004834071342234633, 0.06388209068349429, 0.0086481484883864, 0.03546605511967625, 0.05909032387925046, 0.03866532737655299, 0.07235729162182127, 0.07880577631294727, 0.023394423503694788, 0.03597957042178937, 0.05216960934922099, 0.05419770302250981, 0.03662869094737938, 0.03455034836328455, 0.041695478172706704, 0.04991009791514703, 0.042384014797530005, 0.020315414793523293, 0.0262713831450258, 0.01325725536194763, 0.012813175396461571, 0.006146730414392161, 0.04682550825444715, 0.020762778020330837, 0.032206600199320486, 0.045390779884266, 0.06686553452163935, 0.029513684700110128, 0.06382129394582339, 0.05240933916398457, 0.049373414034822156, 0.015987173920231204, 0.05362281762063503, 0.08687260773565088, 0.010199014912359416, 0.03102719777130655, 0.017948577779212167, 0.019772342505997846, 0.043349885647850375, 0.04438316555959838, 0.013739306995246028, 0.025486794799300175, 0.06274387533111231, 0.04476264305412769, 0.02215335242051099, 0.05457691249570676, 0.0698521878304226, 0.03446396407006042, 0.07292499473052365, 0.0170943310284721, 0.017154250759631395, 0.026171972675781165, 0.024178737042737857, 0.05185517282890422, 0.018305331135966947, 0.027945627591439655, 0.05829102319798299, 0.030903032648244073, 0.047853098650063784, 0.05117039528808423, 0.06334454167102065, 0.04749403488157051, 0.009906397533736058, 0.07043642005217926, 0.022630072464900355, 0.009492511528411081, 0.05901534575968981, 0.03562725129138146, 0.04069920216820069, 0.007868286987234439, 0.09226851497909852, 0.02577211198929165, 0.047822761349380016, 0.026248155194999914, 0.062185793848974366, 0.01876110310799309, 0.08569995673107249, 0.03423452423885465, 0.025455093643228923, 0.05440310575067997, 0.03424139101324337, 0.0385388111296509, 0.05089732226250427, 0.02638601145840117, 0.02333891933916935, 0.02958516836432474, 0.03902703064626881, 0.0682466925520982, 0.05054266557895711, 0.015604000106187803, 0.020408614971009747, 0.038588208479008505, 0.05650977038645318, 0.06415051235152142, 0.07257493851440293, 0.05638957130057471, 0.02281984853159104, 0.011611216768090214, 0.030721117409744432, 0.06907414565128939, 0.047522557101079395, 0.07324746849813632, 0.009972076330866133, 0.02737450975525592, 0.05058441244597946, 0.016573692805000713, 0.053200270115797005, 0.03673056619507926, 0.04283063333215458, 0.03663193095209343, 0.018896133273041675, 0.005518206395208836, 0.05561677419713565, 0.05511142506397196, 0.017630702782688395, 0.014286028953003032, 0.05702475471688168, 0.07216587010771036, 0.024061699930046285, 0.015538738608094198, 0.0738538820296526, 0.018227905201326524, 0.04138039365144713, 0.0657523503260953, 0.029210847735937153, 0.033377412373998334, 0.04878763136054788, 0.0412561538895326, 0.04550069237926176, 0.013396628999284335, 0.06289634893515281, 0.0572894647983568, 0.018213432049378753, 0.035843259521893094, 0.06819296614932162, 0.02407598478852638, 0.05296048601823194, 0.01328849681054375, 0.017969770124182105, 0.03891694851751838, 0.054092530094619305, 0.10063943187040941, 0.051573122785027535, 0.04652239309091653, 0.03981008380651474, 0.057030542620590756, 0.03982562904379197, 0.07652093855930225, 0.04040728283247777, 0.01767198315688542, 0.0064452247544457865, 0.029729197600058148, 0.01878494513221085, 0.08042626042983361, 0.013037293816783597, 0.03784163336136511, 0.052579254510679414, 0.06468933700983014, 0.056699285217161687, 0.05608428143230932, 0.0511812077436064, 0.014461403113922902, 0.05612598080188036, 0.01809457815917475, 0.053720509699944935, 0.01978679869457015, 0.05785707291215658, 0.0302834623227162, 0.035189786194158454, 0.048376242364091535, 0.0073780954782185805, 0.015937081072479486, 0.007482213284155088, 0.02302792977674731, 0.01007218229850488, 0.036602530029735396, 0.03948485518672636, 0.02404661100756909, 0.028657668669308935, 0.02997264578672392, 0.08135544628437076, 0.03238539417673435, 0.08484786602535418, 0.04199597079839025, 0.002352133160457015, 0.03971999131941369, 0.0062220431365338814, 0.06030154959963901, 0.0277711236516812, 0.01964935294485518, 0.016755523226623024, 0.06872576541666474, 0.01823750477550285, 0.08247282382633005, 0.016376337502151728, 0.021585888495402675, 0.04963105717407806, 0.0420571950131229, 0.0701258477887937, 0.029558240702109675, 0.024560950729729872, 0.013736291755256909, 0.06366044721965279, 0.057170130844627104, 0.05186076395745788, 0.029509820443178927, 0.0469958748269294, 0.026493759426687444, 0.06403518853975193, 0.03891537092360003, 0.008192100013340158, 0.035989928258849044, 0.02818951173685491, 0.06861589702644519, 0.0239650019045387, 0.07346486433276109, 0.022406980328794037, 0.01628435529502375, 0.08631768144134964, 0.04728233874110239, 0.02004007206830595, 0.044199995031314235, 0.019366531067394784, 0.011762574182025023, 0.030461014581045935, 0.03765636955254844, 0.032376831064799, 0.03829124762809702, 0.025292518349098306, 0.05065023034278836, 0.024391103236536895, 0.019121011652584587, 0.02086294335978372, 0.03049128402822784, 0.005021374572866729, 0.011461883084848523, 0.05037972217957888, 0.04267259913363627, 0.0722787036959614, 0.10218089379902397, 0.029069834588361636, 0.03017560239615185, 0.043512021590556414, 0.03885816363617778, 0.018948550103232265, 0.03200243240488427, 0.05984644937728133, 0.028931918953146254, 0.04763327366007226, 0.027015103326578225, 0.05532999476417899, 0.05326797773263284, 0.05338718615738409, 0.04554308046187673, 0.040176587711487494, 0.012179366013567363, 0.06063403854412692, 0.008180703169533184, 0.04274161971573319, 0.03234683981697474, 0.005544933041424623, 0.021687987659658705, 0.04268910449796489, 0.07484002411365509, 0.05938623300088303, 0.0025413572813184665, 0.02809321743968342, 0.0122153673853193, 0.04741459878693734, 0.006739555009906846, 0.01658272580243647, 0.05227374751120806, 0.06032154602663858, 0.02421043989514666, 0.02716277290268668, 0.039854032519672594, 0.06606039165386132, 0.04417928274986999, 0.05343044276482292, 0.05452529972951327, 0.0244066874895777, 0.024681146422933255, 0.031020195289914097, 0.0242096663652254, 0.022225443373567293, 0.04857808956876397, 0.014307248439373714, 0.006692820486413049, 0.008981550062474395, 0.024049028288573027, 0.016420681461957947, 0.03154892673982041, 0.057475064482007704, 0.008432665274345448, 0.03355749896062272, 0.027785946249163578, 0.05891642213932105, 0.04936839287568416, 0.01669826844174947, 0.02420400738316987, 0.03895591678363936, 0.03807771944307855, 0.02255717575150941, 0.025296145118772984, 0.03788407911945667, 0.04329576908743807, 0.06972966476210526, 0.038528517753418, 0.012324514832081539, 0.045971422655774016, 0.06648577204240219, 0.030008190843675817, 0.024873684127149836, 0.023204857782859887, 0.03350192694259541, 0.022609509461160218, 0.02085095873501684, 0.0846790736541152, 0.020068986141788106, 0.08400638082197734, 0.06354247712131057, 0.0433694037076618, 0.047486357257834504, 0.04499395903466003, 0.026684602489694953, 0.018331524284024323, 0.00508219887602276, 0.023556713813117573, 0.020218713375340615, 0.07131221877144915, 0.09740943554788828, 0.16983215830155782, 0.10982031601348094, 0.1259839768920626, 0.20093496862266744, 0.13847412381853375, 0.18094874678977899, 0.15112209799034254, 0.0771726578740137, 0.09158515557646751, 0.15146398464483873, 0.06163456557052476, 0.15664400240140303, 0.16905528998800687, 0.17286872464631284, 0.15645498968660831, 0.1162427653159414, 0.08518803598625319, 0.1325852812400886, 0.12199643014797143, 0.12974238236035618, 0.12095425464212894, 0.15272240926112446, 0.15801557951739856, 0.08204986580780574, 0.0761503702295678, 0.19377600348421506, 0.10724060729678188, 0.22123423937175954, 0.1030563193240336, 0.10098682822925703, 0.10580691708517925, 0.10396407025733165, 0.14431730099022388, 0.1250638019825731, 0.11527113031063761, 0.12633792789919035, 0.17003455172692025, 0.11158485311482634, 0.15309628205639975, 0.12002912642700331, 0.1188794845449073, 0.14378851865019115, 0.07482779012726885, 0.19958851087306226, 0.12478505979691233, 0.11736825135137353, 0.12411687922264848, 0.18555510390017713, 0.15302031327571186, 0.16835391548063072, 0.13727566812719616, 0.15765663449253353, 0.08404539658554963, 0.16055910874690327, 0.23065525027258055, 0.10308835974761418, 0.14107754054878438, 0.19159291205661638, 0.14134583329515799, 0.19984852549220833, 0.20662899022655828, 0.12269559263118676, 0.07632410233574254, 0.13265407112027916, 0.15644386171230248, 0.09838137589395046, 0.20239356106945447, 0.10793965442904405, 0.17335694416293077, 0.15143155067094735, 0.19324871392122336, 0.12076520121523313, 0.08414253565881934, 0.08913492491202694, 0.1823492023561682, 0.14236184449068137, 0.10515259219599621, 0.1354672908782959, 0.14721797034144402, 0.0983100686488407, 0.1174061678882156, 0.16454079294843332, 0.21661725640296936, 0.21804668541465486, 0.24699290788599423, 0.07867595899317946, 0.09891163065497365, 0.2000325306185654, 0.12565355747938156, 0.14551335466759546, 0.11568186112812587, 0.13789791188069753, 0.13283583708107471, 0.10125528382403509, 0.0711055573608194, 0.11072624168757882, 0.1555420072483165, 0.2256979277091367, 0.12975570878812245, 0.07892343428518091, 0.10690125836325542, 0.16519202371793135, 0.10203234212739126, 0.07917063137782471, 0.13832802165831837, 0.17050956695207528, 0.1212066018155643, 0.14000701584986278, 0.1777772062591144, 0.15277705847152642, 0.11349496311907258, 0.1419478159930025, 0.09191341046243906, 0.13480361577655586, 0.14813395190451825, 0.2315748009298529, 0.16763591686529772, 0.08961565340203898, 0.0790632532111236, 0.1725958450032132, 0.13538482173212937, 0.15963976165013655, 0.23147065937519073, 0.06699115170964173, 0.1313315520861319, 0.13752839528024197, 0.11383861396461725, 0.0969845572752612, 0.18071075741733822, 0.16316738378788742, 0.1484545325594289, 0.10696516957666193, 0.1144957004913262, 0.12277784464614731, 0.09437624152217593, 0.10892449372581073, 0.09332029175545488, 0.14049845162246907, 0.1739545435245548, 0.09253317077777215, 0.07114557057086911, 0.17590275327009813, 0.15372643752821855, 0.13867620511778764, 0.19565649543489727, 0.14759998555694306, 0.17534035630524158, 0.0894664435514382, 0.1402925026736089, 0.11336429763053145, 0.2047264187463692, 0.21938325012368814, 0.12210321798920631, 0.1826266281838928, 0.11886649738465037, 0.1419384250683444, 0.10669055288391453, 0.15570458423878464, 0.05828511315797057, 0.12152883809592042, 0.10664692986756563, 0.281609050397362, 0.1751752280231033, 0.16652567072638444, 0.176542408232178, 0.13808400689491204, 0.2525013637329851, 0.11242316955966608, 0.14830388421458857, 0.11964564557586398, 0.1455110612192324, 0.08920496329665184, 0.07004077306815557, 0.09775603802076407, 0.17804106138646603], [0.017583407195551053, 0.048264141593660624, 0.009376621139901025, 0.011484988050402274, 0.08124569324510438, 0.03879055779959474, 0.006835985862250839, 0.0006651073937453994, 0.03243258289460625, 0.026859771393771683, 0.04846790226708565, 0.01852276937903038, 0.014036266997988735, 0.06097139258469854, 0.01643193157256714, 0.03732809431052633, 0.05147215677425265, 0.047674949280917645, 0.07134981639683247, 0.02056342952086457, 0.023669354018888304, 0.05154310778847762, 0.021528988245076368, 0.058483856064932685, 0.04162069682830146, 0.04630695143714547, 0.06496304446565253, 0.013620958613630916, 0.03056476597807237, 0.023263500171846578, 0.027068665184612786, 0.04233993037736841, 0.01910020607257528, 0.013705542244549309, 0.025973131381241337, 0.06547140290162393, 0.04588802391663194, 0.06838200600551707, 0.02550431796615677, 0.005157027293794921, 0.03441330464556813, 0.01440890655586762, 0.027613301495356218, 0.028507956702794348, 0.03370512103927987, 0.027384261999811445, 0.021473423012399247, 0.032316037719803195, 0.05516363154830677, 0.020012028215985214, 0.023760053794831038, 0.018795857671648264, 0.021321911231747696, 0.061330459745866914, 0.05442634218239358, 0.06066435548876013, 0.030423912286226238, 0.051115701972906075, 0.02948507766372391, 0.04113764774852565, 0.039846928258027346, 0.019239987679091946, 0.041707020053373914, 0.05237956165469118, 0.02652100769669882, 0.04879835560651762, 0.04367050701486213, 0.019576434179076126, 0.011354102037980087, 0.07196903388415064, 0.042555728262024264, 0.060648233496717045, 0.027118622325360775, 0.022167235246992538, 0.06405836729598896, 0.009799324707793338, 0.0630249652479376, 0.05583497748843261, 0.154191898980311, 0.1614116065736328, 0.27482554582612856, 0.06593427913529532, 0.41566566697188784, 0.5146169172866004, 0.37405713966914583, 0.06170907550092254, 0.0763275900057384, 0.022562500555068254, 0.02371902617492846, 0.018332063719364147, 0.011701062438078225, 0.03022932879892843, 0.03488370243992124, 0.010077271311144744, 0.023814772555072392, 0.044059131161442826, 0.05004588634307895, 0.05758970297340836, 0.02800564910285175, 0.053452020178415945, 0.04975988044004355, 0.03092734795063734, 0.014216025343297847, 0.03624282504564949, 0.08713199131722961, 0.0357512332099889, 0.017446556860314946, 0.020041607253785645, 0.030122876832527772, 0.031318024665649445, 0.030834310621555363, 0.0704170750187976, 0.033123647062374015, 0.03598127693736127, 0.013776662044360169, 0.04678169185561793, 0.05301668907382658, 0.02793287791843925, 0.042796306245561154, 0.043298032001725266, 0.07978917033012424, 0.0521056981358145, 0.01242525692630027, 0.01596889757950391, 0.0465110615561051, 0.04219595203176141, 0.022506031174478785, 0.03459158632904291, 0.02535278074044202, 0.03262740047648549, 0.0223215527699462, 0.01499786477402917, 0.037992295276905806, 0.042689599828528504, 0.03186992808644261, 0.049464388617447445, 0.04647954360448888, 0.04790457570925355, 0.08021298330277205, 0.008385003278298038, 0.02678732929884323, 0.010869424474159521, 0.03965970009033169, 0.08222674631646701, 0.04484359906720264, 0.07387487590312958, 0.05319116756852184, 0.05432448050539408, 0.04399135908378022, 0.023518932983279228, 0.03529519321663039, 0.031735204958489964, 0.07029992594782795, 0.04207141710711377, 0.0326232274861208, 0.05245464833985482, 0.04113332887313195, 0.026825661438384225, 0.02331281270432685, 0.06243726571223565, 0.04723482771909662, 0.03217511956713029, 0.027141522882240157, 0.05171021739287036, 0.014591486758685537, 0.022970695347924317, 0.047835443168878555, 0.010521130752749741, 0.007475221828956689, 0.050629948931080956, 0.02717063542721527, 0.014321577402630022, 0.00827430877169328, 0.018333785501973968, 0.036700103365417035, 0.028397109525810395, 0.048366264506642304, 0.013661264441907406, 0.04378335078113845, 0.01885067142679223, 0.0533975202457181, 0.03159951491813574, 0.0022676523700023866, 0.026642652062167014, 0.05243754925738488, 0.03566999560488122, 0.020494895787643533, 0.008737998399218279, 0.036971948242613246, 0.07714719245476381, 0.02781800363611962, 0.0173082714235144, 0.04942957977099078, 0.015413484436326792, 0.04680484686312931, 0.005614456587604114, 0.07029509477849517, 0.03009739105722734, 0.043237058844949515, 0.037516635443483076, 0.008913640581470515, 0.045633373116808276, 0.07038844084101063, 0.04936124790193779, 0.012903216145267444, 0.0219336088547217, 0.004406450515879052, 0.04931341457579817, 0.015757233669449176, 0.024878026751269187, 0.03623850956293089, 0.059154784706022055, 0.04209501655506236, 0.012010418427442866, 0.03350486499922616, 0.02107753005943128, 0.04168511015762176, 0.01012870850640216, 0.025800250836515, 0.053135490377566645, 0.061200649211449284, 0.01403344514047993, 0.08824610510574919, 0.024242141051217914, 0.02721478770087872, 0.012239509661282812, 0.046287799786244116, 0.03104841216866459, 0.005895383231940546, 0.08376585372856685, 0.0038990589923092295, 0.05600772571883031, 0.01656405421506081, 0.022822939258600985, 0.03868627714525376, 0.0020961187172880663, 0.01529264752753079, 0.04645514687789338, 0.010666727404376226, 0.05831946060061455, 0.03973221852044974, 0.006726030110647636, 0.014520201565963882, 0.0026526124274823815, 0.053767491464636157, 0.02822279727219471, 0.021282488347164223, 0.05563784949481487, 0.013058341124893298, 0.007070824287698737, 0.05040823761373758, 0.013727495396908904, 0.0383833825056042, 0.04210257204249501, 0.2658590855343001, 0.3173107946557658, 0.4780635301555906, 0.5243488465036664, 0.7244423095669065, 0.7916028914707047, 0.40004858640687807, 0.29608779347368647, 0.04886435331510646, 0.06666025053709745, 0.02293131317544196, 0.02938811161688396, 0.025081682251766324, 0.05464911540704114, 0.027073440374806523, 0.03129945655486413, 0.062462676848684034, 0.07396445609629154, 0.034712738756622584, 0.028234664849670868, 0.03072216913902334, 0.07473210990428925, 0.035843262914568186, 0.07088515561606203, 0.038375070451625755, 0.06888133314039026, 0.030326528940349817, 0.014444241266963738, 0.053533671689885, 0.012470648374541529, 0.052836185188165734, 0.07064066587814263, 0.022432438962693726, 0.01711902461413826, 0.0982594635071499, 0.010904104398962642, 0.03165816069979753, 0.01924662714424942, 0.035852745441453795, 0.03759072807484439, 0.03683688584715128, 0.05437484476715326, 0.013139479494254504, 0.049139529799244235, 0.03969161159225872, 0.019583864137530327, 0.051807699126324484, 0.03929631066109453, 0.024125899520835707, 0.00387461731276874, 0.04965134537113564, 0.0426645992057664, 0.06602164051894631, 0.010533170508486884, 0.027581484988331795, 0.05582209210842848, 0.011917777193178023, 0.07418350077101163, 0.019615056392337595, 0.006430604445215846, 0.024396428040095737, 0.02640515293127724, 0.04245586487065468, 0.045490460071180544, 0.042648331328694306, 0.014046448415943553, 0.010764047985763421, 0.049602246577186246, 0.024092203471809626, 0.03145200479775667, 0.052324512108628235, 0.025073717946984937, 0.02222281913938267, 0.06800738682172128, 0.04874783188902906, 0.02044613626120346, 0.03076826880819031, 0.051883671299687455, 0.037198008969426155, 0.04596587223932147, 0.02906601443620665, 0.07983680348843336, 0.03774542388107095, 0.04913660192063876, 0.02303307137585112, 0.0336162974126637, 0.038256330216037374, 0.0260027443457927, 0.024616593993934135, 0.03263459973303335, 0.06276636198163033, 0.049949625972658396, 0.003828108826253031, 0.008305251664881195, 0.014005124785139092, 0.047685558175934215, 0.06853558562163796, 0.013644691224076917, 0.16665077901312284, 0.10919710195490293, 0.0960920937359333, 0.11551479223583426, 0.14903963330600942, 0.10065161835934434, 0.13413182539599283, 0.07899048033037356, 0.1350747990821089, 0.07751822218831096, 0.1703382097184658, 0.130895036937935, 0.1101757665829999, 0.18368924116449697, 0.1190674387450729, 0.13784730673900672, 0.13240990707916872, 0.16688837483525276, 0.15743875689804554, 0.12284212905381407, 0.16852988675236702, 0.14805684318499907, 0.16578336698668344, 0.19515729722167763, 0.17044545896351337, 0.09005844499915838, 0.1742963351841484, 0.12177944821970803, 0.11626620191548552, 0.09042220083730561, 0.1900573330266135, 0.10740628519228526, 0.11832350652132716, 0.11646474126194205, 0.12905376431133064, 0.11268457517560039, 0.14980640501848289, 0.13006875770432608, 0.11075142212212086, 0.04983168640839202, 0.07619704665350062, 0.09782132666025843, 0.15321130731276103, 0.09557685495487281, 0.13222162718219416, 0.07207635098270007, 0.1903754166726555, 0.17949327560407774, 0.14120662505073206, 0.05857667965548379, 0.09243219119629689, 0.09780318941920996, 0.05157799466646143, 0.13760789244302682, 0.23099858899201664, 0.11343055657510247, 0.22033995735858167, 0.16629609518817492, 0.13616795970925263, 0.11885846353002957, 0.10204610960291964, 0.1338137960327523, 0.11974065404917512, 0.10853758627282721, 0.1382709297218493, 0.10690728375422102, 0.1848586555570364, 0.0976581322029233, 0.17500127878572258, 0.18514236461903366, 0.1277485614908593, 0.16059864019708975, 0.1173123400658369, 0.10464174353650638, 0.07608481696141617, 0.12658680097333022, 0.16984733034457478, 0.09519186775599207, 0.4090172994349684, 0.5164898367864745, 0.856876331780638, 0.9715270910944257, 1.093605420419148, 1.2372471583741051, 0.6570597110050065, 0.4600414772118841, 0.21654468029737473, 0.12223869429102965, 0.09207906800189189, 0.10874971667570726, 0.08678660342203719, 0.10284085731421198, 0.13588676122682436, 0.13951699143009527, 0.07492505133684192, 0.15034765883215837, 0.11134120476033006, 0.12476828641125134, 0.1339840811810323, 0.14987033658793994, 0.08349742527518954, 0.19078194057302816, 0.1568367877709014, 0.16600307662572178, 0.1296500608857189, 0.07848884617643696, 0.15353960969618388, 0.09884292898433548, 0.10572148952633142, 0.06958873303873198, 0.11056331864425115, 0.09413140573139701, 0.17190618201025895, 0.20430147940559046, 0.0965175691193768, 0.12472735717892647, 0.11603855341672897, 0.07702434368963752, 0.08265248632856778, 0.14178601253245557, 0.10505991109779902, 0.11166171077638865, 0.14361573649304255, 0.07674652431160212, 0.1491305569985083, 0.09820757593427386, 0.10285813281578676, 0.08714596235326358, 0.08567820289837462, 0.11105228454938956, 0.11170566627489668, 0.0636176180892757, 0.07959697528609208, 0.10829100664705038, 0.12378880754113197, 0.1942091259573187, 0.1337270385452679, 0.11956319000039782, 0.18242810240813664, 0.0592552689569337, 0.1191160354231085, 0.18413657216089113, 0.18864740511136396, 0.14859519286879472, 0.12856323777564935, 0.18909298548741, 0.14315697896693433, 0.07518062833696604, 0.13232403168720858, 0.12341198990387575, 0.13136146190975392, 0.23114091849752835, 0.1430366068546261, 0.09949763385312897, 0.09031553513237409, 0.14449277014604636, 0.08847495461148874, 0.09225907655698912, 0.14362652519983904, 0.11895322773073401, 0.13922879046627454, 0.1401580034622124, 0.10400862965200629, 0.15139134068574223, 0.11529254487582616, 0.09527752601674624, 0.20185298579079763, 0.08331901806273631, 0.055629547618861706, 0.10200718204889979, 0.09922856079148394, 0.13460005527096136, 0.10087764515940632, 0.15836558145071777, 0.21676962822675705, 0.1041894524491259], [0.04006209849779095, 0.06714239037994828, 0.027630785646449243, 0.05980391880231244, 0.04524064722603985, 0.030178096012345383, 0.016111330561605946, 0.013187926046417227, 0.013528430185812925, 0.05665666303996529, 0.0613969358216439, 0.013603605928697755, 0.0723824720563633, 0.03493763240320342, 0.03440093155950308, 0.01700930550162281, 0.022860390998955284, 0.055012759286910295, 0.06246045803917306, 0.06350660297487463, 0.06536617569093194, 0.03519132986132588, 0.026487418516938175, 0.02912505037550415, 0.02341894575926874, 0.018453065172902176, 0.027565729405198778, 0.04428441835833447, 0.009155132042776262, 0.029335426765361, 0.05574859658788357, 0.06666004019124167, 0.019320806288825612, 0.030137244811547653, 0.04855984715478761, 0.015746068375717317, 0.014599637660597051, 0.045437876999910386, 0.07320636963205678, 0.0731637372768351, 0.03502801666036248, 0.02589281997643411, 0.037306119953947406, 0.033390657377562354, 0.01588565999242876, 0.05782571780894484, 0.10715384980929749, 0.04082966409623623, 0.1077320905668395, 0.10251008506332125, 0.008637693960086575, 0.02872376815815057, 0.020055242414985384, 0.016935430001467466, 0.02887721885261791, 0.055994121091706414, 0.0308105449325272, 0.06700715156538145, 0.015531088125758936, 0.05400899904114859, 0.028381542236145054, 0.04771559352853468, 0.047589684570474286, 0.032691291333841424, 0.029401373583823442, 0.026414805091917515, 0.05075637357575553, 0.03209095408341714, 0.01817157831309097, 0.050295139396829266, 0.04419727749856455, 0.017688206929181303, 0.06855811976960727, 0.041003545480115075, 0.04247196650664721, 0.22831112891435623, 1.09343193258558, 2.266027948686055, 7.5758267641067505, 4.536041557788849, 7.485388142721994, 11.604040554591588, 11.584710666111537, 10.03076776436397, 9.235727088791982, 6.696326392037528, 2.828387566975185, 0.8925107653651918, 0.11460404896310397, 0.037618178209023814, 0.029897311436278478, 0.027803915552794933, 0.02120495554325836, 0.03213424461760691, 0.2625794272337641, 0.3526818480874811, 0.31713535264134407, 0.5028550827077457, 0.9063735072101865, 0.691290771322591, 1.5829598818506514, 1.926464923790523, 1.4250963756016322, 0.2922445439866611, 0.03834534043978367, 0.02073543475541685, 0.04300758169431772, 0.08312805795243808, 0.00807769307201462, 0.04525538839931999, 0.050120759289711714, 0.007374344027734229, 0.05631217759634767, 0.02799755078740418, 0.04659376818952816, 0.020817042162109698, 0.02320058979759259, 0.03418114049626248, 0.040273048249738555, 0.06405346827315432, 0.058944812044501305, 0.058035697255815775, 0.03689071063750556, 0.009215083156180168, 0.030282369881336178, 0.06559479449476514, 0.03404947756124394, 0.0790298217907548, 0.031877453039799414, 0.042361728314842494, 0.02304504412625517, 0.038232143835297654, 0.02651801535726658, 0.03473727119022182, 0.03596117873010891, 0.01428636652417481, 0.0045941523858346045, 0.04425025751282062, 0.048383461976689954, 0.004316140473487654, 0.016113863193563054, 0.08978184698415653, 0.041440572922251055, 0.009090092764901263, 0.04702501790598035, 0.04916231161249535, 0.02084711822681129, 0.03647794421496136, 0.01649345434270799, 0.0050707829484183875, 0.03248574611331735, 0.051993444695004394, 0.017595744658527628, 0.04067803526829396, 0.03239995214555945, 0.02313646484565522, 0.08548782632819243, 0.05442424211651087, 0.024873975897207856, 0.010247920323828501, 0.046145063159721236, 0.0686901423281857, 0.11936562774436814, 0.04034794155242188, 0.06444374804518052, 0.05221824334668262, 0.026555635035037994, 0.05953687456037317, 0.020051888755655715, 0.045534649664270024, 0.047230980425540886, 0.033566302952489684, 0.057628169123615534, 0.058345346711575985, 0.03283661657146045, 0.04012083588168025, 0.015917383200888122, 0.03633226613913264, 0.05224430926942399, 0.06416641721235854, 0.009652818819241864, 0.029286497605166266, 0.0430426280280309, 0.02113720721432141, 0.026547485829464028, 0.06307834559785468, 0.04300494897844536, 0.022892153223178217, 0.07285923790186644, 0.0173867881031973, 0.06344782148620912, 0.02257652078489108, 0.012921410213623728, 0.018123251352725283, 0.08658321933554751, 0.03770654043182731, 0.012911108355703098, 0.018539820964049016, 0.058727144795869074, 0.036640969038541825, 0.02641222665884665, 0.03604751891855683, 0.027318025107628534, 0.026995452952438166, 0.05159376382029482, 0.06514794525823422, 0.010924718292829181, 0.06963858500655208, 0.019987614526014243, 0.03594930436728256, 0.059205165931156704, 0.013324082579596766, 0.03488235554790922, 0.05248445299054895, 0.06701697675245148, 0.04258570254647306, 0.009394070516074342, 0.03462157757686717, 0.06276121868618897, 0.0628812447456377, 0.0761626720694559, 0.04060962197503873, 0.019940586960209266, 0.01695891749113798, 0.0419638659139829, 0.06636911151664597, 0.019586758089384863, 0.023518737904461365, 0.06135796755552292, 0.02644504909403622, 0.01938538077021284, 0.05089632481602686, 0.04075680300593376, 0.02486995896989746, 0.02613659216357129, 0.05801400449126959, 0.01756346844402807, 0.08005795162171125, 0.032194213542555056, 0.03479299248595323, 0.026569127703883817, 0.04218845761248043, 0.03601502048383866, 0.05820061519209828, 0.05474897201306053, 0.02202129932785673, 0.03744572853403432, 0.017408808260889988, 0.04405718037326421, 0.047335725876369646, 0.12587181505348, 0.5788441651633808, 1.8509327939578464, 4.5411063602992465, 11.647722142083303, 8.251404455729894, 11.979949389185224, 16.324057817459106, 16.14976920400347, 15.325526986803327, 13.276660425322396, 9.002403974533081, 4.9366968359266, 1.467668096934046, 0.2801143191754818, 0.07516253859336887, 0.03527535285268511, 0.06151220535061189, 0.08611800215606179, 0.01566580786103649, 0.13509928062558174, 0.43008915015629356, 0.4600090703793934, 0.8338698148727417, 1.0869836785963602, 1.5400650692837579, 2.165081696850913, 2.4316306625093733, 1.9891051054000854, 0.3386994126651968, 0.056439681111701896, 0.026128687230604034, 0.025545773063121096, 0.014587902397449528, 0.02160003934321659, 0.05634441479508366, 0.05012204172089696, 0.04983828176877328, 0.047017509915999005, 0.009446640016644128, 0.00804563144421471, 0.0514490865836186, 0.024050107159252678, 0.03956327687150665, 0.03332369614924703, 0.06861813619200673, 0.05583113698022706, 0.03505067294463515, 0.03713655066011207, 0.028442337277478406, 0.08786928746849298, 0.11414438220007078, 0.08142599357025963, 0.09142886182027203, 0.019399891241586635, 0.0198890115134418, 0.0389406870651458, 0.004869572718494705, 0.038889715514544926, 0.041940385209662576, 0.013378195747333978, 0.051143935815032036, 0.032944781838783195, 0.004383803137378501, 0.039376849375133, 0.03798201886404838, 0.029244533606937954, 0.03259162471762725, 0.03902937837743333, 0.031585652447704754, 0.06929044904453413, 0.017358572920784354, 0.01836106939507382, 0.06504300303225007, 0.060970883683434556, 0.023795995794768845, 0.07633518959794726, 0.07952268248690025, 0.018346256975616728, 0.03433132065193994, 0.01243168774193951, 0.06422821818185703, 0.02640049478837422, 0.02279204216652683, 0.04138149966352752, 0.008221665480440217, 0.013538166315161755, 0.011142430494406393, 0.026962845952117016, 0.08542794561279671, 0.0314743794899966, 0.016123108233192136, 0.006133876840717026, 0.10580160415598325, 0.015207791634436165, 0.03739361704460212, 0.06295058423919336, 0.011072813649661839, 0.013665401809183615, 0.05840507136391742, 0.0469862362369895, 0.054932237536247285, 0.12560958841017314, 0.19187159995947564, 0.14472550765744277, 0.16088031365403108, 0.09512427209743432, 0.13801120008741105, 0.09189168377114193, 0.13047465735248157, 0.15691325866750308, 0.10843288831944976, 0.22087355729724678, 0.06342865965728249, 0.20556636367525372, 0.12653622297304018, 0.17994876259139606, 0.12702619311000618, 0.12818082900983946, 0.12338520134133951, 0.17287913337349892, 0.1155542286911181, 0.1368156892380544, 0.15804938413202763, 0.11440074630081654, 0.1258862271372761, 0.1761813461780548, 0.08993545374167816, 0.19242121332458087, 0.10940523578652314, 0.12778299035770552, 0.15507157891988754, 0.14929856226912566, 0.2005191080804382, 0.14040828788919107, 0.14353229025644915, 0.2005622221955231, 0.13770332160804952, 0.08977404383144208, 0.1579426098614931, 0.181958013347217, 0.128325044842703, 0.06505253644926207, 0.14163269075964177, 0.21312669584793703, 0.12559664196201734, 0.13774704640465124, 0.19287857306855066, 0.20054931645946844, 0.18468511344066688, 0.18842963608247892, 0.18088671511837415, 0.08477758336812258, 0.09469327343893902, 0.11159790812858514, 0.10511169689042227, 0.09153623998697315, 0.15445683976369246, 0.16677068972161838, 0.17612352142376558, 0.05827163066715002, 0.19624835439026356, 0.11259825195052794, 0.1299173358295645, 0.171291266434959, 0.10821600817143917, 0.131143950724176, 0.07316033103104148, 0.14862333850136825, 0.13307052877332481, 0.16161995753645897, 0.12585379316338471, 0.16076842322945595, 0.21243528223463468, 0.1228880930159773, 0.16047112989638532, 0.29873836838773316, 0.9044550444398607, 2.9897640390055518, 5.846357601029532, 11.78713687828609, 9.328675746917725, 15.008282661437988, 19.13783505984715, 19.557924883706228, 18.606735604149954, 15.611745868410383, 11.16194144317082, 6.04810506105423, 1.9062022396496363, 0.5155949305210794, 0.17916809448174068, 0.15671708062291145, 0.18048518523573875, 0.14752409820045742, 0.14154844385172638, 0.3889862128666469, 0.8581712480102266, 0.526212212230478, 1.3415683891092027, 1.7405511055673872, 2.288488434893744, 3.5238232101712907, 3.221057627882276, 2.5774303589548384, 0.4994871605719839, 0.16781388302998884, 0.18777362842644962, 0.16654604034764425, 0.19626599630074842, 0.09027240744658879, 0.13047757505306176, 0.11753014980682305, 0.16779649896281107, 0.15850613319448062, 0.07864017305629593, 0.1746372990310192, 0.17870176450482436, 0.12414886536342756, 0.21950681135058403, 0.1094965258879321, 0.19726216713232653, 0.14828377243663582, 0.19715277371662004, 0.19480340049735137, 0.12964350623743875, 0.13926296148981365, 0.2654082940093109, 0.1657124465065343, 0.22003055896077836, 0.11310714642916407, 0.07590087968856096, 0.07307804508933, 0.0782350537234119, 0.12207694511328425, 0.1414669110838856, 0.09759091652397599, 0.11594643550259726, 0.09028040737445865, 0.19108728133141994, 0.11920999895249094, 0.08087042266769068, 0.12323493297610964, 0.12748937468443597, 0.15397665410169534, 0.1886851859412023, 0.09758715065462248, 0.10923276575548307, 0.10892539617738553, 0.14790437636630877, 0.13093922313834938, 0.15484717381852015, 0.17116625314312323, 0.13997545040079526, 0.12414151004382543, 0.13409700297883578, 0.18838840829474585, 0.16220272412257536, 0.15140108444861003, 0.11300885384636265, 0.1268580521323851, 0.14152135673378194, 0.09429910566125597, 0.15366454156381743, 0.12627388776413032, 0.2508324390011174, 0.14621000657124178, 0.11201667958604437, 0.061753831670752594, 0.21133719544325555, 0.08046864172709839, 0.11364378620471273, 0.1669636107981205, 0.10837056487798691, 0.1673013312476022, 0.17490035348704883, 0.13771727228803293, 0.11470847550247397], [0.11404142129634108, 0.023264249953042184, 0.07458122407219239, 0.0020814004445648088, 0.09520860042955194, 0.03711818950250745, 0.006563703754051987, 0.07826349112604346, 0.06442067106919629, 0.061072107537516525, 0.058074048055069785, 0.015211118152365088, 0.05248006286897829, 0.025167265873668448, 0.02212191589309701, 0.0505611997629915, 0.04731008743069001, 0.05491413422194975, 0.04036482011101075, 0.1072248856403998, 0.029752410283046107, 0.04309380653181246, 0.05383600314546909, 0.01444981203946684, 0.0459584253174918, 0.03538708382153085, 0.014981461189953344, 0.007089023869152048, 0.04386059520766139, 0.0606035723217896, 0.010058128990099897, 0.0538247496421848, 0.11320716249091284, 0.05327170628256031, 0.02407309422934694, 0.05138642726732152, 0.011339874006807804, 0.07185746915638447, 0.0583468462739672, 0.02476085053889879, 0.03888845683208533, 0.03629304002970457, 0.12710266400660786, 0.04354868283761399, 0.03372233208002789, 0.056434235868177245, 0.034662435563015084, 0.02721672152568187, 0.017998587506424104, 0.040611789894423315, 0.020453703622998934, 0.06723676781569209, 0.029743280594370196, 0.0589980295460139, 0.02971264473827822, 0.017425071048949446, 0.06555599586239882, 0.0851629301905632, 0.054532777185418775, 0.05694071815482207, 0.03256396763026714, 0.010733664883965892, 0.012764493901548641, 0.06419667308884007, 0.0635009982756206, 0.0834510609773653, 0.07547032207782779, 0.06367912728871618, 0.1386860710169588, 0.11830986796745233, 0.18303389847278595, 0.8499539175203868, 1.3169750230652946, 2.8429377462182726, 6.674419156142643, 11.607314024652753, 18.008049283708843, 34.983217579977854, 41.65689631870815, 39.872053486960276, 39.908093793051584, 38.43621172223772, 44.352321420397075, 41.36489479882376, 38.15357289995466, 36.5103690964835, 30.689877033233643, 19.214206184659684, 9.036900912012372, 4.380979912621634, 4.9643667340278625, 2.547226973942348, 3.1919967872755866, 4.110186031886509, 3.1337975902216773, 5.32532000541687, 7.038232479776655, 8.221179791859218, 13.028366548674446, 12.531373194285802, 18.405522721154348, 20.226522241319927, 11.467830674988882, 6.527067840099335, 3.1269023716449738, 0.4343973589794976, 0.011426809609734585, 0.026300074998289347, 0.053856942736144574, 0.06349546142986842, 0.07301686837204865, 0.06586761306971312, 0.027723892525370632, 0.028118506439828446, 0.029744742837335383, 0.005647151373393301, 0.011759008480502027, 0.010390446604495602, 0.0083437805795776, 0.05627979790525777, 0.0057503446753669, 0.05968565693391221, 0.11397767971668925, 0.08774017582514457, 0.010141343676618167, 0.08487222543252365, 0.016687220195308328, 0.04106147540733218, 0.01767210359685123, 0.0460912146206413, 0.027397518877738287, 0.02197308771844421, 0.024544011102989316, 0.017683969477989843, 0.062442721133785586, 0.006931931986140886, 0.043021919139261754, 0.007735289034566709, 0.08681819601250546, 0.015460685028561523, 0.02973120267103825, 0.06541028046714407, 0.027765666533793722, 0.10532669071108103, 0.011144644214904733, 0.020382659310208898, 0.022912281964506422, 0.027006390936938778, 0.012661647500603326, 0.025687364661800008, 0.025317198364064097, 0.019386554635795097, 0.05685510399884411, 0.07794326330934252, 0.007810425761687968, 0.05764034204185009, 0.033206221381468434, 0.0072214522764885, 0.05376082146540284, 0.03558119233431561, 0.0485353995380657, 0.0619896836578846, 0.029212873162967817, 0.05372792948037386, 0.032028464400874715, 0.017341689273182834, 0.009837918931485286, 0.016963193958093013, 0.018257329872410213, 0.012207917918983315, 0.029735518153756857, 0.08789736524756465, 0.016325983418417827, 0.03772523067891598, 0.14661328707422527, 0.027271877941010252, 0.14498192604099, 0.042998387544815025, 0.028819858894816468, 0.01853140882615532, 0.019482066921357597, 0.020649973269818083, 0.04263381746464542, 0.0430863596099828, 0.045413144398480654, 0.04879133276907461, 0.04353354811402304, 0.024532967945560813, 0.016899784860600318, 0.01994811530624117, 0.031821874236421924, 0.0456920494325459, 0.057929343676992824, 0.022159148805907795, 0.02631996455602348, 0.009247549360484948, 0.02373317871907992, 0.03644520150763648, 0.058429342561534474, 0.04803045413323811, 0.03828977859978165, 0.0313285894558898, 0.0341492018529347, 0.058077678217419555, 0.08762139148477997, 0.023629043949767947, 0.04728471361366766, 0.018641312839463353, 0.029109657808606113, 0.05078098064820681, 0.022905978374183178, 0.022618627275473306, 0.019219750372160758, 0.006268537628264832, 0.05897139026118176, 0.03373893243925912, 0.035552171391568015, 0.027175522575687085, 0.005250662157777697, 0.025937610073015094, 0.046439258980431726, 0.0371153498334544, 0.07520959499691214, 0.05647743819281459, 0.017847201254751, 0.07580695687127964, 0.03675949214292424, 0.00934074360078999, 0.030773021945995942, 0.029793644856129373, 0.04410923757989492, 0.025236043879496198, 0.03932515179206218, 0.0325986814818212, 0.02415133949502238, 0.022899398280839835, 0.04724258676703487, 0.03103744365008814, 0.06878049605126892, 0.038428969880832095, 0.09164044260978699, 0.05184226370017443, 0.04649521437074457, 0.04551857177700315, 0.06783724416579519, 0.13124887937945978, 0.42290441425783293, 1.5582175637994493, 3.0866581882749284, 4.561116737978799, 9.621936627796718, 16.47473818915231, 25.012933015823364, 44.96374205180577, 51.32412651606968, 52.61730786732265, 51.097375529153005, 48.13300650460379, 56.47547926221575, 52.608803272247314, 48.281496456691194, 45.45797783987862, 38.56190116064889, 25.415330989020212, 13.596125568662371, 7.08894955260413, 6.517358601093292, 3.833236481462206, 4.380660729748862, 5.571786071572985, 4.425158730575016, 6.474294969013759, 8.824165310178484, 10.563013672828674, 15.832160098212105, 16.475149869918823, 23.453569650650024, 24.69727635383606, 15.127868107386998, 8.464305077280317, 4.694861309868949, 0.6896962683115686, 0.05172105698979326, 0.03516739793121815, 0.03587436695982303, 0.027886839317423955, 0.08973559803728547, 0.0021306597544545574, 0.04290923482871481, 0.05256493742178593, 0.02446306187526456, 0.0955817811191082, 0.034047092510653396, 0.03922786683376346, 0.037990181640322716, 0.026487133532230343, 0.06245452764311007, 0.01644965660359178, 0.15535617007740907, 0.006166519888211042, 0.059503422783953805, 0.015032943338155746, 0.021164745558053255, 0.06227341986128262, 0.05731216858008078, 0.040525510774127076, 0.06127779185771942, 0.0742458581392254, 0.030844047599072968, 0.032749943900853395, 0.07832670344838075, 0.013215195520647934, 0.03072252876258322, 0.058758221699723175, 0.05248825278665338, 0.028320796388600553, 0.03911811379449708, 0.024187854857050946, 0.08347954587744814, 0.022747482771852186, 0.06798852354820285, 0.028238574907715832, 0.051805493887513876, 0.02907096774184278, 0.03153618385217019, 0.017099326742546897, 0.015224181647811617, 0.041650542191096714, 0.04987656471452542, 0.01196178951899388, 0.010572812220613872, 0.09787248141531434, 0.021962243032508662, 0.03208231293995466, 0.029216007994753972, 0.03472275393349784, 0.07624614544745002, 0.04753706078710301, 0.020240204275718758, 0.03890845665176, 0.001231555371694932, 0.05557291030085512, 0.05738691599773509, 0.033658329264393876, 0.045053151037011824, 0.009545994506749724, 0.024170514894649386, 0.024773603604574288, 0.02255381869950465, 0.01862620186459805, 0.07982271031609603, 0.026830200837658982, 0.23114762242351258, 0.10799817128905229, 0.28634861750262125, 0.05366935155221394, 0.26369559019804, 0.09823833392666918, 0.15813809580036572, 0.12287111606981073, 0.1952536084822246, 0.10898211491959435, 0.10383366939744779, 0.08312944216387612, 0.13234666761543068, 0.09306370373815298, 0.07175566854753665, 0.1752323199595724, 0.1606751246643918, 0.1550901843500989, 0.12227289245596953, 0.17258627765945025, 0.12381560967436858, 0.08870351913252048, 0.13287238297717913, 0.1187880587364946, 0.16879600818668092, 0.14533909330410616, 0.10857651382684708, 0.12589070546839917, 0.24223149195313454, 0.1499919436339821, 0.09466590812163693, 0.09022906941494771, 0.14228355512022972, 0.10887882153370551, 0.09915733497057642, 0.16195344392742428, 0.13114247151783534, 0.13566635948206696, 0.1419214074100767, 0.17276758221643312, 0.09704376624098845, 0.11645568960479327, 0.1940305083990097, 0.10701721321259226, 0.1788772065192461, 0.15168647627745355, 0.18140747717448644, 0.15189482724027975, 0.09635550103017262, 0.19747441288615974, 0.13512541779450007, 0.14666518143245152, 0.15076548712594168, 0.12275888637772628, 0.11126949039420911, 0.16880128718912601, 0.12504480300205095, 0.12779597751796246, 0.17932417110673018, 0.1410392304616315, 0.14293942706925528, 0.11916054732033185, 0.19338553372238362, 0.19503631442785263, 0.15302941921566213, 0.10314278504145996, 0.16637940571776458, 0.1841977760195732, 0.33530652044074877, 0.2482266202569008, 0.6449037290045193, 1.94890239409038, 4.328480192593165, 6.665221478257861, 12.596615042005267, 20.584804364613124, 29.207916600363596, 50.44840335845947, 59.27036435263497, 62.11695793696812, 60.53042016710554, 56.040859018053325, 63.70650427682059, 59.989808627537315, 58.60975742340088, 53.547522272382466, 45.737677574157715, 30.811296803610666, 17.25238404955183, 9.393856797899518, 8.002947296415057, 5.011997069631304, 6.350060309682574, 7.100220833505903, 6.243374628680093, 9.215720619474139, 11.746406538145882, 14.428293943405151, 20.59432860783168, 21.719328812190465, 28.245335749217443, 29.715652738298687, 18.677942480359757, 10.901840840067182, 6.260059859071459, 1.1501069771392005, 0.14952171886605875, 0.1305200784866299, 0.1917554619056838, 0.17664314354104654, 0.22186595547412122, 0.1495069268026522, 0.10604287085256406, 0.09297375035073076, 0.1118111377581954, 0.1572162245533296, 0.13381235753851278, 0.07950641800250326, 0.08749436972928898, 0.09499429871461221, 0.2037384853299175, 0.12053065880068711, 0.24984462772096905, 0.1692266607923167, 0.12362139938133103, 0.22933484826769146, 0.1295166609010526, 0.08005990580256496, 0.1577510322843279, 0.1326809682484184, 0.19756658508309297, 0.2062433244926589, 0.17476680422467844, 0.11703353002667427, 0.16829355300537177, 0.12360735370644502, 0.13007463381758758, 0.10181041367884193, 0.30267560854554176, 0.14461045525968075, 0.13513909706047603, 0.20517080490078243, 0.23844578223569052, 0.13600901966648443, 0.2304460714970316, 0.08578039705753326, 0.09098668769001961, 0.10956239806754248, 0.16265546982841833, 0.15738081000745296, 0.237876545637846, 0.09662559189434562, 0.20015796460211277, 0.14181394103382314, 0.11499037966132164, 0.1268298522170101, 0.08113391817148242, 0.13651826019798005, 0.14866140431591443, 0.12638280620532377, 0.1276300757059029, 0.09480680591825928, 0.08826840855181217, 0.17710690865559237, 0.17042911984026432, 0.15395944645362242, 0.1807231746081795, 0.15140370359378202, 0.10674988398594515, 0.14150252060166427, 0.11362393227006708, 0.153567158217941, 0.06596175980355058, 0.1037058469706348, 0.2567199787923268, 0.08276655485055276], [0.025910475457619344, 0.02092047464767737, 0.04086524986528924, 0.045175748744181225, 0.02573517763188907, 0.04878071030335767, 0.011395607176902038, 0.049275270729724846, 0.018134209693276455, 0.012328652199357748, 0.06568655957068716, 0.06827090946691376, 0.0627758614718914, 0.06191860032933099, 0.053941393204565556, 0.018020896041499715, 0.01994071588186281, 0.034750285491879494, 0.027261274135006324, 0.040858427195676734, 0.05043696000107697, 0.0451478982743408, 0.0762596550796713, 0.054834867761071236, 0.023220155354855315, 0.030511321167328527, 0.04013630987278052, 0.03574559458398393, 0.05061031552031636, 0.06910025567880698, 0.07201431252594505, 0.042750474597726545, 0.015350665664300323, 0.01768515182525984, 0.029207136149385145, 0.04132014313446624, 0.019806617006127323, 0.034417253719376664, 0.050478767936250994, 0.01660212002960699, 0.03612192706870181, 0.025812944530376365, 0.06692302679376942, 0.09286200920385973, 0.040404449948774915, 0.018150772733081664, 0.036193855173353634, 0.012654804474940258, 0.020166065843243684, 0.05575805536604353, 0.06308715298239674, 0.01679454916822059, 0.047374246309378316, 0.013751663117935615, 0.03787908170904432, 0.013458135654218495, 0.022467162992273058, 0.05035753408446908, 0.035776583278285604, 0.025632781608562385, 0.04042879917791911, 0.017910822394437025, 0.022259448156026856, 0.10139597127480166, 0.025507841259241104, 0.0041237944554138395, 0.011735442111135592, 0.0679486392598067, 0.8340426513126918, 2.690094747713634, 7.211889241422925, 10.923726797103882, 22.682173694883073, 25.084122521536692, 34.2582425389971, 50.613332748413086, 59.89212390354702, 64.59954234531948, 59.996465001787456, 63.02458722250802, 65.78336947304862, 67.32506356920514, 74.1099100112915, 63.364222117832725, 61.62619277409145, 68.43346800122941, 58.16948481968471, 49.775904587336946, 43.121045044490266, 39.921194621494834, 33.56048706599644, 32.9109069279262, 30.520139489855083, 31.061188765934535, 36.44584812436785, 29.751772948673793, 38.30067668642317, 37.32263435636248, 40.16802937643868, 46.74013934816633, 48.4552709034511, 51.30087436948504, 46.673718043736045, 31.805882794516428, 27.399239710399083, 14.635602133614675, 4.324649129595075, 0.9847184632505689, 0.05482978892645665, 0.018612836421068226, 0.040527980641594956, 0.05210476515016385, 0.07191486643361193, 0.04789336970342057, 0.034819842116641145, 0.017777235812640617, 0.017041288249726807, 0.048837079600031884, 0.014654303834374462, 0.05182316633207457, 0.09390347224793263, 0.030248107255569527, 0.04936871857249311, 0.04959224836368646, 0.09253021915044103, 0.0651283763082964, 0.04196624757189836, 0.055771483574062586, 0.03108333975874952, 0.06902299768158368, 0.02381808719863849, 0.04282163256513221, 0.047624625731259584, 0.05244714713522366, 0.053368607868573496, 0.020901124525283064, 0.02390798121424658, 0.04531873303598591, 0.0491033978095012, 0.03684723350618567, 0.046544615112777264, 0.049075343779155185, 0.02566855906375817, 0.017436626500317028, 0.02334354694799653, 0.05318759847432375, 0.02392023046767073, 0.008751960953564515, 0.008740167166771633, 0.08263877992119108, 0.0433560501384948, 0.0358181062287518, 0.016356414017666663, 0.020938903658783863, 0.017708685116044114, 0.024428453196638396, 0.03847593128947275, 0.03489445721996682, 0.04071088993389692, 0.04972952278330922, 0.019861315410318117, 0.05653901185308184, 0.03790583973750472, 0.011000546277500689, 0.005435706290882081, 0.07325035905731575, 0.052242948806711605, 0.034406495546655994, 0.02783148443060262, 0.054716392154140134, 0.048001344980938096, 0.05745763970272882, 0.02795027894899249, 0.048890310672244856, 0.03448010981082916, 0.06651967843728405, 0.02252743047262941, 0.04955107485875487, 0.05050997036908354, 0.027000860876536796, 0.05049869990242379, 0.031939674701009474, 0.03072417081732835, 0.055811272867556126, 0.01248881614966584, 0.04398919455707073, 0.03727431362494826, 0.00876384210174105, 0.03958480678764837, 0.0515671686402389, 0.039053218705313544, 0.04819809638762048, 0.06868583363081728, 0.017339546798861454, 0.011352648276702633, 0.023985120467841625, 0.015608296929193395, 0.042448590975254774, 0.07306863380862133, 0.032158203689115386, 0.02280257811902889, 0.03398169869823115, 0.0171464934080307, 0.060224074471209726, 0.05421166048784341, 0.060340287163853645, 0.04000777837687305, 0.013305703610447901, 0.03518677010600056, 0.04452135939417141, 0.06970429433775799, 0.021998108697256873, 0.02245488659744816, 0.11495960131287575, 0.015012453276930111, 0.015387047015662705, 0.07901791350117751, 0.09979490004479885, 0.047568185188408406, 0.04185702378994652, 0.06071213113942316, 0.022288893183161105, 0.011434352374635637, 0.024507709479491626, 0.03479877360431211, 0.11670720896550588, 0.024172162038407156, 0.012403630318918397, 0.03929599514231086, 0.01741193630732596, 0.05533843913248607, 0.09604355812604938, 0.07786147948354483, 0.050807385838457515, 0.03370407270267606, 0.03071676121492471, 0.011332734970242848, 0.025445936813152263, 0.05353973100760153, 0.02928147983870336, 0.023499823740816543, 0.016211121010461023, 0.07497798385364668, 0.14459304405110224, 1.7604789733886719, 5.274080514907837, 11.23517198222024, 16.587870495659963, 31.02274785723005, 33.9370551109314, 45.431192534310476, 62.280080795288086, 72.57799203055245, 75.22665922982353, 71.6057653427124, 73.57876886640275, 76.63731030055455, 79.56958906991142, 84.70487063271659, 74.80057484763009, 71.93990421295166, 81.08673518044608, 71.36712946210588, 62.41211741311209, 55.67301443644932, 48.843147141592844, 41.556682450430735, 39.54381711142403, 35.47808565412249, 37.51098959786551, 41.99677092688424, 35.4914505141122, 45.30934197562081, 44.18501227242606, 47.03512511934553, 54.87479843412127, 55.97233588354928, 58.83756801060268, 55.60409525462559, 39.81827442986624, 34.83362633841378, 19.32227499144418, 6.58353237594877, 1.9520397228854043, 0.02381155121007136, 0.03760616135384355, 0.006081437958138329, 0.0026311183464713395, 0.046652000064828565, 0.020933877410633222, 0.017903529839324098, 0.03580824711493083, 0.012925953853742352, 0.05375105734648449, 0.04110202466004661, 0.039332842986498556, 0.10234269047422068, 0.03427737372528229, 0.04721508235005396, 0.037936078650610786, 0.028691758268645833, 0.024451638738225614, 0.040734170470386744, 0.07534170576504298, 0.017486385169572065, 0.029018683225980828, 0.04346233925649098, 0.03343610565311142, 0.0545279426234109, 0.025310562291581715, 0.04917239125019737, 0.0514956273005477, 0.030633121595851014, 0.05744174162724188, 0.009916394050898296, 0.02716227078677288, 0.03880288678088358, 0.05798572315169232, 0.013456444405684513, 0.010321342053690126, 0.04652159920494471, 0.010126911236771514, 0.03358032148597496, 0.0021312008861319293, 0.012984430001649474, 0.02609475708699652, 0.023542038797001754, 0.04349991313314863, 0.012511828664823301, 0.02375558394539569, 0.0271158725621977, 0.015065382401059781, 0.010937089682556689, 0.02510216213496668, 0.052199899152453454, 0.050990284952734194, 0.025256333772891333, 0.0393403034790286, 0.014460895908996463, 0.03979623490678413, 0.04684262430029256, 0.01826792010771377, 0.005251845777300852, 0.013292105768674185, 0.028656674615506614, 0.06728587339499167, 0.04472743047933493, 0.027667748841590116, 0.04209668914388333, 0.05826262650745256, 0.02653068021338965, 0.026773410849273205, 0.13081449483122143, 0.11981986622725214, 0.16300415540380137, 0.16496099611478193, 0.13449835644236632, 0.12476680720491068, 0.123442890388625, 0.1706944541739566, 0.08616193729851927, 0.09570120328239032, 0.22759047044175013, 0.08111728727817535, 0.12906369806400367, 0.1203966752759048, 0.12782233181808675, 0.10888671968132257, 0.1401678557906832, 0.10165513772517443, 0.08765967443053212, 0.19801394322088786, 0.10499090408640248, 0.08019853050687484, 0.22309989854693413, 0.1589158462094409, 0.06835073911185775, 0.11171557967151914, 0.21049433281379087, 0.13825145576681408, 0.19572734806154454, 0.14480735255139215, 0.15212048084608146, 0.14179053157567978, 0.08805496857634612, 0.09596835608993258, 0.12700245795505388, 0.16421726745154175, 0.1472554254744734, 0.26023698864238604, 0.1468260349439723, 0.1075558275250452, 0.26546341819422586, 0.19356089431260312, 0.19005835082914146, 0.21118981763720512, 0.17452255875936576, 0.13764291842068943, 0.11218131253761904, 0.09236189496836492, 0.1326867357960769, 0.13648296280630998, 0.20080508344939776, 0.10250060592911073, 0.19883408849792822, 0.19437858329287597, 0.09594702294894628, 0.1911606445376362, 0.17871336745364325, 0.15389058871992997, 0.08675929238753659, 0.227753074573619, 0.15090415254235268, 0.10997110685067517, 0.13321614238832677, 0.171664474265916, 0.1173280549368688, 0.13033330493739673, 0.14683895425072738, 0.33267071044870783, 2.1053380455289568, 5.454217774527414, 13.408882907458715, 21.193475246429443, 37.592234883989605, 42.755319663456504, 55.293813024248394, 70.62290096282959, 81.77389117649624, 86.19489097595215, 82.32136753627232, 85.26667417798723, 89.4515186037336, 91.48482554299491, 96.9002445765904, 88.2412257875715, 83.8749361038208, 90.61188861301967, 83.1499332700457, 74.14481081281389, 64.3281318119594, 58.466332708086284, 47.48650789260864, 48.48917463847569, 44.53278350830078, 46.169883319309776, 49.134839466639924, 44.15567002977644, 54.14589418683733, 55.13036707469395, 56.52471072333199, 66.66360201154436, 68.1459515435355, 68.16435037340436, 65.57650770459855, 47.51460640771048, 40.409458432878765, 22.71049976348877, 8.115411707333156, 2.232325494289398, 0.18244209380022117, 0.18397490440734796, 0.14087393933108874, 0.11400574392506055, 0.11682559975555964, 0.07234028753425394, 0.10724954360297748, 0.11672113250408854, 0.11701481603085995, 0.1572143653673785, 0.16809808063719953, 0.1884255377309663, 0.21315362011747702, 0.11453135072120599, 0.1961312121046441, 0.18156761143888744, 0.18338812089392117, 0.11134504526853561, 0.10888735071888991, 0.206535650949393, 0.10676761410598244, 0.14642287657729217, 0.16728366219571658, 0.14925574670944894, 0.1285415789378541, 0.16903793306222983, 0.10855356577251639, 0.1516653059848717, 0.09421662972973925, 0.17900273549769605, 0.07178836036473513, 0.18956219245280537, 0.08623216567294938, 0.16621058620512486, 0.06285148419971977, 0.11569977445261818, 0.16489646743450845, 0.19786283347223485, 0.07971894874104432, 0.10701671109667846, 0.16933240368962288, 0.16474347135850362, 0.11351144473467555, 0.20810598454305104, 0.13686632152114594, 0.0602959788271359, 0.1332820009972368, 0.061053122127694745, 0.1271793113223144, 0.10349784206066813, 0.12544914201966353, 0.12993111009044306, 0.1145219055137464, 0.16742436321718351, 0.23968131308044704, 0.06507429706731013, 0.08039108517446689, 0.18500793326113904, 0.1465593028281416, 0.1281618300293173, 0.10055493390453712, 0.25235393164413317, 0.16031206771731377, 0.13927616578127655, 0.1381775497325829, 0.11055970205260174, 0.16141987113015993, 0.11736462797437396], [0.017477258873571242, 0.014089562531028475, 0.03605243829744203, 0.04133449075743556, 0.005960947526286223, 0.02979857102036476, 0.042330980500472445, 0.05027344663228307, 0.05239555811775582, 0.025087945129988447, 0.05791761859187058, 0.023056304414889643, 0.007356954023375043, 0.03814378161249416, 0.042227507302803655, 0.01222583293981318, 0.008880786764036332, 0.026594403133328472, 0.011230981010677559, 0.02891938980402691, 0.018721003384728516, 0.05150551016309431, 0.04221692215651274, 0.02284973460648741, 0.016515586458678757, 0.012611362966708839, 0.018383800318198543, 0.04984051414898463, 0.045397524522351365, 0.014751115514497672, 0.05324036814272404, 0.055698710693312545, 0.019253604180578674, 0.02404149654986603, 0.04680629553539412, 0.018893812683277895, 0.05354454182088375, 0.06646758051855223, 0.009159240572314178, 0.0464087961507695, 0.026153589465788434, 0.0764016385323235, 0.032257520859794955, 0.017143769089930823, 0.05055441441280501, 0.043995789917452, 0.04313780613509672, 0.04020285040938428, 0.032630345318466425, 0.022479293502068946, 0.016878456808626652, 0.02920330242652978, 0.08379917658333268, 0.06034661789557763, 0.09797830573682274, 0.04939624334552458, 0.031283195463142226, 0.043244709327284775, 0.0320258588264031, 0.034100014849432876, 0.04226118978112936, 0.08666619738297802, 0.024596394006428973, 0.121618513283985, 0.09276245454592363, 0.6712491810321808, 1.9411714375019073, 6.1784020236560275, 14.37077328136989, 32.65256248201643, 43.73460572106497, 50.35577344894409, 54.17078610828945, 64.97140298570905, 68.65297549111503, 62.85421739305769, 68.5257956641061, 63.17830916813442, 65.834883417402, 63.75764996664864, 54.26446519579206, 58.023656027657644, 62.86379895891462, 62.42496463230678, 65.20439692905971, 68.50916862487793, 64.78547613961356, 70.50209958212716, 73.17375142233712, 67.1821460723877, 69.07846927642822, 62.06012167249407, 54.61601277760097, 58.529498781476704, 61.82871886662075, 61.57361575535366, 59.52693353380476, 60.64863681793213, 62.092361313956125, 67.43697820390973, 64.94174112592424, 62.07455308096749, 64.82238497052873, 59.22219249180385, 65.57084492274693, 52.08158438546317, 35.48853921890259, 12.84308067389897, 4.968410151345389, 1.26835489485945, 0.029255210355456387, 0.01918572692998818, 0.08372497199369328, 0.030789819080382586, 0.08966209912406546, 0.03764753841928073, 0.010652819981000252, 0.019417198973574808, 0.013069889790910696, 0.02286925266629883, 0.03833455851833735, 0.038414282990353446, 0.05171656169529472, 0.01666881832560258, 0.017549292151150957, 0.01890281853931291, 0.02857417832793934, 0.025159511914742843, 0.044529678233500035, 0.008208246602277671, 0.07135551609098911, 0.04476583556139043, 0.02843165204727224, 0.03923248426456537, 0.031344792872135124, 0.1032169692750488, 0.014693892960037504, 0.03479673460658107, 0.01378182739218963, 0.01424671633036009, 0.005812927232390004, 0.01924175356647798, 0.015653506021148393, 0.018368546850979328, 0.048952922491090636, 0.02254786285837846, 0.04149107628368905, 0.044224669957267385, 0.09642161748238973, 0.009833047898220164, 0.03862594520407064, 0.0386129614364888, 0.043259345327637026, 0.050902625013675006, 0.01624718345036464, 0.05877273556377206, 0.0398248622992209, 0.019388054198186313, 0.05930470023304224, 0.020724652833970528, 0.00703440434465717, 0.021297310944646597, 0.0186199780021395, 0.06097408636872258, 0.05048095960436123, 0.027753205238176242, 0.051179942275796614, 0.06277307947831494, 0.06347775845123188, 0.021862427138590386, 0.036028370660330565, 0.028781871111797433, 0.0429649663024715, 0.052693204289036136, 0.041091805922665765, 0.04250574397987553, 0.010303473682142794, 0.025099062926269004, 0.06337930980537619, 0.016796995286962817, 0.036677226557263305, 0.03250562379668866, 0.01513118842350585, 0.012009324289725294, 0.06331797023969037, 0.07461020430283886, 0.025780351100755588, 0.019052104725103294, 0.028333759800131832, 0.062197328944291384, 0.02677872377846922, 0.009802608817283596, 0.0669638542458415, 0.006898486146902931, 0.03610482798623187, 0.03360266225146396, 0.016029975909207548, 0.01992420542852155, 0.03334855427965522, 0.012675658400569643, 0.005336976052993643, 0.029646314547530243, 0.038459592166223695, 0.003939608245023659, 0.043147169918354066, 0.018392677252580012, 0.06213855424097606, 0.05586903316101857, 0.06069964609508004, 0.006776572911933596, 0.044843073202563186, 0.05914947856217623, 0.03494528967088886, 0.04321129487029143, 0.047027738831405125, 0.013549905819153147, 0.021492276107892394, 0.061904446088841984, 0.03211008198559284, 0.0446129344802882, 0.07707730334784303, 0.01887772122531065, 0.04111042831625257, 0.031245197502097914, 0.02163834773403193, 0.03006260935217142, 0.03639748692512512, 0.019245054639343704, 0.03611589489238603, 0.0463500112694289, 0.0432413878983685, 0.048025473686201234, 0.03229360535208668, 0.03080296908904399, 0.03661656552659614, 0.032631112063037496, 0.0033742386606588426, 0.10877242045743124, 0.04987826783742223, 0.12810206466487475, 0.16641314247889177, 1.0891012506825584, 3.97931193453925, 10.316726088523865, 20.891440527779714, 40.87908022744315, 53.83259296417236, 59.26652199881417, 63.85784299033028, 76.51354203905377, 80.19057737077985, 73.00223514011928, 78.90240219661167, 72.86721079690116, 75.83652346474784, 72.69276237487793, 62.27176380157471, 67.03572668348039, 72.15942559923444, 73.47476128169468, 74.92783110482353, 76.14583642142159, 73.76534884316581, 82.46996865953717, 79.83023684365409, 78.6284625189645, 77.1245596749442, 72.11750711713518, 64.18008654458183, 68.44781603131975, 71.6877749306815, 69.97908088139125, 68.89523833138603, 68.77948829105922, 70.65087441035679, 77.34731892177037, 73.29938874925885, 69.80183928353446, 73.5341614314488, 69.12112426757812, 76.12902178083147, 59.71343013218471, 43.340080056871685, 18.409321648733957, 8.273931384086609, 2.7510834293706075, 0.20418736338615417, 0.07659470210117952, 0.06811870049153056, 0.035445950127073696, 0.053350850607135465, 0.04434583256287234, 0.07245785729693514, 0.05407409429816263, 0.0530148231025253, 0.013322938399921571, 0.021493697638756463, 0.024617676257288883, 0.11828773415514401, 0.022191944099696617, 0.03150104930890458, 0.033846975570278506, 0.012240896417227174, 0.05210220368046846, 0.01642425055615604, 0.03688455632488642, 0.0239312396983483, 0.03841803189633148, 0.06675007500286613, 0.029598973159279143, 0.06804837033684764, 0.023819486677114452, 0.03731813341645258, 0.0648901155218482, 0.03259737869458539, 0.00452897824912465, 0.02195401070639491, 0.046301909921956916, 0.020091206467311298, 0.03680461472166436, 0.07145435150180544, 0.018279723224363158, 0.01920879033527204, 0.03146773663216403, 0.08161115899149861, 0.03159722486244781, 0.0339286610084985, 0.0052123066935954344, 0.01089090434834361, 0.08759222126432828, 0.015826573163004856, 0.02355800472599055, 0.01621162991172501, 0.055836636506553204, 0.05257419603211539, 0.02187601649867637, 0.04891491774469614, 0.044635977529521496, 0.05881716603679316, 0.009755459963344038, 0.015831238091258065, 0.08710949788136141, 0.005315427901223302, 0.013703058806381055, 0.06726247750754867, 0.021577225299552083, 0.027950083870174627, 0.01869407232983836, 0.05885025818965264, 0.018248659891209433, 0.025556212324383, 0.025345042048554336, 0.09019257101629462, 0.13449116397116864, 0.15273910122258322, 0.050395219919404814, 0.10502169600554875, 0.13394273125699588, 0.053956225980073214, 0.18697594265852654, 0.22501354371862753, 0.1327540600406272, 0.18402173689433507, 0.13807253965309688, 0.10029159446379968, 0.11660074682107993, 0.23325395796980175, 0.19218086265027523, 0.11852003740412848, 0.08600537212831633, 0.12528105532484396, 0.09957339228796107, 0.10491592596684184, 0.14513999755893434, 0.1660878663616521, 0.08551051653921604, 0.12764630626354898, 0.07798427396586963, 0.1791279794914382, 0.13478359899350575, 0.14755943630422863, 0.09968257535781179, 0.12250970117747784, 0.17407486135406153, 0.10813211410173348, 0.16147376038134098, 0.15282060684902327, 0.14460846036672592, 0.11476298900587217, 0.11071165997002806, 0.0654366279819182, 0.12282550494585719, 0.0747973442609821, 0.1893757310296808, 0.0862032397251044, 0.10189653334340878, 0.14951505565217563, 0.14590854703315667, 0.14235370207045758, 0.1398074044180768, 0.23355604176010403, 0.1592321385230337, 0.11973635213715689, 0.12972171418368816, 0.17358231278402464, 0.13588488847017288, 0.23055284576756613, 0.10808849787073475, 0.16958407232803957, 0.24461124997053826, 0.11678499622004372, 0.10549426171928644, 0.11993482363011156, 0.1445140354335308, 0.16291842928954534, 0.31745138711162973, 0.43437993420021875, 1.1980621410267693, 4.476423842566354, 13.157991273062569, 25.67665794917515, 45.749725750514436, 60.845312527247835, 68.11737360273088, 72.65306036812919, 86.40273938860211, 92.72391169411796, 83.67651639665876, 88.27176312037876, 84.20210593087333, 87.34594345092773, 84.81980773380825, 74.20795604160854, 77.8736936024257, 82.77273641313825, 82.95288930620465, 85.90666580200195, 87.868072782244, 86.96554347446987, 93.90747479030064, 93.51251138959611, 89.07055582318986, 87.45407131740025, 81.22985417502267, 77.37510476793561, 78.94928864070347, 82.00518975939069, 81.87258338928223, 79.98533453260148, 78.63780089787075, 80.5454774584089, 85.39917632511684, 84.26404217311314, 79.77654116494315, 84.17987169538225, 77.39337853022984, 86.58693613324846, 66.75285162244523, 50.58661345073155, 23.491842065538677, 10.641857487814766, 3.070624134370259, 0.35200125032237595, 0.22677037944751127, 0.12814876144485815, 0.11922405819807734, 0.1845747565052339, 0.1074500914130892, 0.10315028285341603, 0.1711333306240184, 0.09019190605197634, 0.07150701260460274, 0.1744744913386447, 0.09231086913496256, 0.19722260854073934, 0.12853100736226353, 0.1512433657688754, 0.15095414700252668, 0.08172163127788476, 0.10833004955202341, 0.12850545373346123, 0.10748502239584923, 0.11413657904735633, 0.08034037825252328, 0.18080854788422585, 0.1913545291338648, 0.12584698067179748, 0.18045626607324394, 0.10743095672556333, 0.0785771846505148, 0.12369113921054772, 0.09940604519631181, 0.09979634532438857, 0.13927593507937022, 0.14517267580543244, 0.1292528464858021, 0.15014227985271386, 0.054789521265774965, 0.10792934069676058, 0.1626009563250201, 0.19051944251571382, 0.17347727556313786, 0.10796959139406681, 0.10827015526592731, 0.06174034917993205, 0.14311174782259123, 0.11254455947450229, 0.1473963571978467, 0.0900336377588766, 0.114623115797128, 0.14954982378653117, 0.12942351161369256, 0.18026717193424702, 0.08248071518859693, 0.16467975692025252, 0.12615073365824564, 0.10921029267566544, 0.09479851422033139, 0.13001528914485658, 0.15283150412142277, 0.1692622024565935, 0.085417258686253, 0.12171854291643415, 0.11261241976171732, 0.15318103108022893, 0.12888288205223425, 0.12192321621945926, 0.09911750496498176], [0.05780030667249646, 0.06426494728241648, 0.016562532600281493, 0.021314555912145546, 0.016314271903995956, 0.0071845085892294136, 0.03705379313656262, 0.06439925650400774, 0.025509848026558757, 0.07332633462335382, 0.012627702938126666, 0.03361327114648052, 0.011830093505393182, 0.004821165182095553, 0.03538468859291502, 0.02801521814295224, 0.02528772789186665, 0.054839654825627804, 0.01032838100633983, 0.019138894443001066, 0.039548844431660006, 0.05943850055336952, 0.039618916743035824, 0.08414687828293868, 0.027550811812813793, 0.05805005505681038, 0.0576661399432591, 0.07193384505808353, 0.026873018093673245, 0.00625060309955318, 0.017007091781124473, 0.024389646082584347, 0.04960528641406979, 0.01729148785982813, 0.04472932019936187, 0.017565975630921975, 0.03773702022486499, 0.0791722937886204, 0.02238753521149712, 0.030161638145468066, 0.020328135628785406, 0.016618386210341538, 0.05765717649566276, 0.02336252048345549, 0.025965070385219793, 0.010300468620178955, 0.012352708810275155, 0.012134543686572994, 0.013539424997621348, 0.08180347617183413, 0.04756311313914401, 0.031064554516758238, 0.03759853122755885, 0.023659903722416078, 0.02116510348527559, 0.029611729617629732, 0.0406624527115907, 0.09575913660228252, 0.09590630406247717, 0.14600325695105962, 0.05793983382838113, 0.09812696597405843, 0.5693488546780178, 1.8948816699641091, 6.008042616503579, 13.268624833651952, 27.581847054617747, 36.31425619125366, 45.264876978737966, 61.02605601719448, 62.322784423828125, 60.98971693856375, 61.655361311776296, 58.674410411289756, 61.8349027633667, 58.45399965558733, 53.04686287471226, 48.258049760546, 52.525907788957866, 44.539533683231895, 48.610031604766846, 48.008380140577046, 37.24981376102993, 38.71939945220947, 49.169768060956685, 47.545036043439595, 40.2761607170105, 59.03610583714077, 46.66879524503435, 56.93425144468035, 56.931333201272146, 61.89921528952462, 60.03028883252825, 56.371777398245676, 59.948237555367605, 54.89530256816319, 60.46223749433245, 66.56762654440743, 58.08078064237322, 54.616478306906565, 50.989747932979036, 53.448374952588765, 60.24331365312849, 61.92118549346924, 63.6799760546003, 63.41743837084089, 59.916004862104145, 41.0087822505406, 33.08646706172398, 18.828567266464233, 6.283305057457515, 1.106437331863812, 0.08831300865858793, 0.0049765161986994955, 0.011082589642943015, 0.01867692405357957, 0.04512631407539759, 0.026962092778246318, 0.026039439519601207, 0.015620554664305277, 0.04469321874369468, 0.044743097852915525, 0.03985429036297968, 0.039698013570159674, 0.03714706116755094, 0.033220100815274885, 0.05885975089456354, 0.022532058081456592, 0.02874527432556663, 0.0432067452929914, 0.01091448768108551, 0.08097144974661724, 0.051189879421144724, 0.02487343646186803, 0.024327880736174326, 0.010934138903394341, 0.033592697964715104, 0.03495436168408819, 0.05562200570212943, 0.010966354897910995, 0.007555669788936419, 0.0339318229816854, 0.05762853553252561, 0.04259427244375859, 0.004990846434208963, 0.029184876808098385, 0.026743670659405843, 0.022501366246225576, 0.05815872922539711, 0.02479900456299739, 0.06934901340199368, 0.052547153018947156, 0.022535698421831642, 0.04574353327708585, 0.012958677053185446, 0.019588705484888384, 0.05964286851563624, 0.03719633298793009, 0.03186407572190676, 0.057622354078505716, 0.011513000520478402, 0.02502988967379289, 0.057400479912757874, 0.00681599197975759, 0.016333549083875756, 0.04165184158565743, 0.038189620045678954, 0.007574311690405011, 0.07815305276640824, 0.05611513441960726, 0.010670282927873944, 0.06434637148465429, 0.04589564386489136, 0.030408862379512618, 0.023508892361340777, 0.010006997983769646, 0.03541943637122001, 0.08723101671785116, 0.03080503862085087, 0.017404704820364714, 0.048548970238438675, 0.022839760141713277, 0.02713148226030171, 0.04766658294413771, 0.014939493799049939, 0.04712394831169929, 0.010723890587022262, 0.03256590824042048, 0.015947739161284905, 0.052582752358700545, 0.03692991299820798, 0.06884457689843007, 0.06976654992571898, 0.056171561391758065, 0.039058402712856016, 0.0048062717625206065, 0.06205493158527783, 0.017202185866023813, 0.05438711607296552, 0.012611979585407036, 0.02262823872401246, 0.05683179632095354, 0.058584313174443584, 0.0544690559618175, 0.007938774901309183, 0.054535264016262124, 0.029084663971194198, 0.032206115046782155, 0.014783473153199469, 0.026036832248792052, 0.03951318063107984, 0.031017599893467765, 0.057780093114290915, 0.03112372277038438, 0.03653496151257839, 0.02992319076188973, 0.060643931584698815, 0.016213087065677558, 0.00789922648774726, 0.013918207841925323, 0.007304766198753246, 0.02979742768885834, 0.07198419914181743, 0.08262532457177128, 0.030670264602771828, 0.03850235344309892, 0.0448608338566763, 0.034478691672640185, 0.04861181954454098, 0.0658620490825602, 0.10101963539740869, 0.01438388557705496, 0.041161732349012575, 0.1063775582505124, 0.08598779128598315, 0.03600834709193025, 0.0964073139641966, 0.276954707290445, 0.9868331040654863, 3.028881311416626, 11.57139183793749, 22.52164772578648, 39.49614552089146, 47.44904667990548, 55.872674397059846, 71.82823276519775, 70.27604688916887, 72.63842051369804, 70.72059263501848, 66.92461109161377, 69.15332221984863, 66.38312407902309, 61.95974799564907, 58.251327650887625, 61.32856668744768, 55.51764576775687, 58.42701980045864, 58.87909739358084, 48.003474712371826, 51.45261607851301, 58.603142738342285, 57.59608473096575, 51.00850806917463, 69.39551557813371, 59.30529294695173, 68.80566910334996, 66.38847419193813, 71.5920912878854, 68.039658001491, 64.78776904514858, 69.10402475084577, 63.96153095790318, 69.21310452052525, 73.57210554395402, 65.63084956577846, 63.37877859388079, 58.96874305180141, 63.21664932795933, 67.7307619367327, 69.84140927450997, 71.49116175515312, 71.67725535801479, 68.13744694846017, 50.68169954844883, 41.849069595336914, 26.11577888897487, 10.019275443894522, 2.059684906687055, 0.3761183390659945, 0.03285750527200954, 0.028947810243283, 0.02101957129447588, 0.030435284533138787, 0.014135305121141886, 0.023754879965313842, 0.027352856006473303, 0.02703036697182272, 0.039400526854608736, 0.029853681634579386, 0.024939737814877714, 0.02241977071389556, 0.017729511052103977, 0.015015449009037443, 0.031504781251507144, 0.018016449940790023, 0.01450622035190463, 0.08918601859893117, 0.02508615719021431, 0.04869723692536354, 0.03276512272922056, 0.005877553452072399, 0.056718385977936644, 0.039899592753499746, 0.011817983351647854, 0.028822189662605524, 0.013768137100019624, 0.044248961510935, 0.05548491109428661, 0.06410336773842573, 0.05218619953042694, 0.026350826025009155, 0.016035036084109118, 0.05118940783930676, 0.053040770281638415, 0.02199159815375294, 0.03486097490947161, 0.023766545678621957, 0.05855044749166284, 0.033036282286047935, 0.030096851621887515, 0.004658104735426605, 0.014979863239984428, 0.014820699280660068, 0.025535683247393796, 0.02298780800109463, 0.018459195736795664, 0.06132843092616115, 0.020247529061245065, 0.044274019809173684, 0.01737478142604232, 0.031219687978071824, 0.015662506788170764, 0.02860254787706903, 0.025528048032096455, 0.033064662013202906, 0.051001402749014754, 0.012277895235456526, 0.044217209464737346, 0.047056176234036684, 0.03955124305295093, 0.02631549640292568, 0.04728557196046625, 0.12292596884071827, 0.198817125122462, 0.06905809829809836, 0.10059066555861916, 0.1007206185853907, 0.07487292627670936, 0.11280133069625922, 0.13431585766375065, 0.09244103250758988, 0.13864221051335335, 0.10650409824614014, 0.11072863013084445, 0.12023036634283406, 0.0951683090201446, 0.26455236279538696, 0.1377351177590234, 0.156985590500491, 0.1442261194544179, 0.09751965677631752, 0.10748867969959974, 0.15151024716241018, 0.11317303217947483, 0.1448559628001281, 0.29345450763191494, 0.09883418266794511, 0.20694202557206154, 0.1938497738114425, 0.16426777759832994, 0.16625394459281648, 0.28467163177473204, 0.15226009621151856, 0.08535369352570601, 0.14111841549830778, 0.1584733192409788, 0.0927251690466489, 0.11592150612601212, 0.11949247308075428, 0.1803989162934678, 0.09741204112235989, 0.1246841616396393, 0.12805160880088806, 0.06115482095628977, 0.13131575579089777, 0.0945454885118774, 0.10155138293547289, 0.1555402566279684, 0.16533535745527062, 0.1394437775015831, 0.08283268487347023, 0.2549473467682089, 0.2034543284348079, 0.11499460014913764, 0.1276571356824466, 0.09410617101405348, 0.2317029626241752, 0.0683084460241454, 0.16003401763737202, 0.32516931582774433, 0.1956588431660618, 0.18529550997274263, 0.20642882239605698, 0.436939856835774, 1.3388589173555374, 4.15758490562439, 13.290073922702245, 25.498004129954747, 44.537692410605295, 53.48000315257481, 64.7086638041905, 82.22059086390904, 79.04798780168805, 80.78718444279262, 80.94875090462821, 77.64821066175188, 78.237320627485, 79.44036647251674, 72.28473636082241, 69.29506547110421, 71.16393634251186, 61.44228785378592, 69.5553171975272, 66.39992482321603, 55.853233337402344, 57.18552957262312, 66.36416939326695, 68.8277643748692, 60.24242428370884, 79.19012015206474, 68.58784307752336, 77.20260184151786, 75.74605791909354, 82.11651379721505, 79.37678350721086, 75.51829596928188, 78.43735231672014, 75.39328398023332, 78.50990540640694, 86.12042713165283, 76.0466091973441, 74.65357875823975, 68.12077127184186, 71.27236992972237, 77.15433965410504, 79.89114475250244, 80.30496556418282, 82.60257502964565, 77.61877809252057, 58.80610656738281, 49.869090352739605, 31.568841525486537, 12.00504628249577, 2.873928666114807, 0.6525247629199709, 0.13406579036797794, 0.1291985229722091, 0.14555251970887184, 0.11330588933612619, 0.19472992872553213, 0.22001597045787744, 0.10502598434686661, 0.15507106323327335, 0.12875903584063053, 0.15521750466099807, 0.13541755426142896, 0.1524647559438433, 0.13502708449959755, 0.10322291324181215, 0.08674685484064476, 0.10136215987482242, 0.13718402518757752, 0.13843824288674764, 0.17349282758576529, 0.15383215328412397, 0.15229924768209457, 0.06628113266612802, 0.09899153493876968, 0.13045164144464902, 0.14748269399361952, 0.12416320959372179, 0.12516426587743418, 0.10210767987051181, 0.11932202508406979, 0.20447850919195584, 0.24694809743336268, 0.19229596933083876, 0.1910604927688837, 0.23104703639234814, 0.07335253286042384, 0.19957606654082025, 0.09397881677640335, 0.1813998640115772, 0.17959893707718166, 0.08811179588415793, 0.08677232025989465, 0.10837739094027452, 0.08773562964051962, 0.16030791508299963, 0.2057304470134633, 0.06443639272557837, 0.13934514565127237, 0.17338460125029087, 0.0974758437701634, 0.13817677620266164, 0.11952952109277248, 0.1602456255682877, 0.07116146864635603, 0.14952387660741806, 0.07443348664258208, 0.12770042621663638, 0.11910767587167875, 0.05133841412940195, 0.1642211758132492, 0.20018745373402322, 0.08336951463882412, 0.09918725836489882, 0.12481114268302917], [0.05314244536150779, 0.011509735070701157, 0.09993866804455008, 0.02037757369024413, 0.06582774235201733, 0.023029139265418053, 0.034741868264973164, 0.028128170474831547, 0.020214927149936557, 0.06586232049656765, 0.025349235394969583, 0.02960348202447806, 0.02947140857577324, 0.03455085387187345, 0.03491428740588682, 0.020661308197304606, 0.014970044838264585, 0.062059342062899044, 0.040687775638486655, 0.08282591987933431, 0.06344083257551704, 0.00273114161765469, 0.07020092090325696, 0.026684432855940292, 0.05338573409244418, 0.02953299580674086, 0.053657765566770516, 0.04011903437120574, 0.023409804196230004, 0.04948719757209931, 0.015541557921096683, 0.04519603694123881, 0.005650975766392159, 0.035726656671613455, 0.03039509829665933, 0.00132930332412278, 0.03170927135007722, 0.05953086952545813, 0.0253663955455912, 0.029229395490671908, 0.03247823812333601, 0.011819682233700795, 0.03219371481931635, 0.07779589228864227, 0.0469011411603008, 0.03139434289187193, 0.022206374843205725, 0.029415748348193507, 0.05508151184767485, 0.0883218567552311, 0.022014356218278408, 0.027489762320848446, 0.01983975156742547, 0.13716004576001847, 0.03261082386597991, 0.11893736358199801, 0.0856193264148065, 0.05668706480147583, 0.9913244630609239, 1.203047473515783, 1.406086864215987, 8.643534728458949, 15.243656362806048, 26.081524269921438, 38.46464722497122, 54.21627943856375, 61.44224616459438, 60.778985023498535, 62.7945671081543, 55.68038647515433, 57.42504440035139, 65.26560361044747, 46.90234851837158, 48.54380832399641, 35.06527233123779, 33.21715572902134, 44.99462679454258, 37.645607471466064, 28.95499174935477, 21.00526418004717, 25.94314742088318, 27.757040670939855, 20.02036397797721, 20.63262186731611, 36.62937436785017, 25.946185520717076, 28.451627765383037, 39.861759730747764, 30.05798700877598, 32.55284888403756, 34.604255880628315, 38.21259437288557, 45.67576217651367, 52.00622769764492, 41.28225987298148, 40.58277082443237, 40.675598757607595, 32.0927391733442, 42.443724223545615, 42.130961486271445, 40.46301514761788, 44.15645170211792, 42.467521803719656, 44.87561804907662, 53.98294503348214, 59.78020926884243, 58.92098113468715, 62.828967639378135, 52.13645083563668, 49.93996197836739, 34.08083071027483, 15.166585206985474, 9.097018463271004, 1.9860937127045222, 0.7213155116353716, 0.14793070352503232, 0.018693673690514903, 0.013780304929241538, 0.06599974419389452, 0.01705040776037744, 0.11428040132990905, 0.0660559336787888, 0.023175640064956884, 0.007757687475532293, 0.05379575923351305, 0.02603104943409562, 0.15186470028545174, 0.023206040130129883, 0.05092523380049637, 0.03310834609770349, 0.0020066104064296398, 0.08399006205477885, 0.04494808328204921, 0.03828527991260801, 0.029828653870416538, 0.042475362574415546, 0.03367158444598317, 0.02165837130243225, 0.03676177880593708, 0.054484601199094734, 0.01368467983723219, 0.01993194581674678, 0.06870171813560383, 0.0388938444001334, 0.03885545967412846, 0.04465845739468932, 0.01297439362055489, 0.004056626698002219, 0.06453404070011207, 0.05415356771222182, 0.04574798785948327, 0.04500393010675907, 0.017895506162728583, 0.09836342185735703, 0.028822043777576516, 0.04820331771458898, 0.0488663889201624, 0.06765235694391386, 0.01980595543448414, 0.08053843583911657, 0.014179800054989755, 0.06064794851200921, 0.0544073567725718, 0.030440957085894685, 0.0488981172176344, 0.052730357473982234, 0.025726987714213983, 0.046376942324319055, 0.008725248726217874, 0.04989017951967461, 0.0077798806596547365, 0.04262139688112906, 0.013728596319976662, 0.07762034849396773, 0.03432242166517036, 0.01893979191247906, 0.013649981252716055, 0.016447902590568577, 0.017947166426373378, 0.03404199331998825, 0.014056046293782336, 0.028689135730798756, 0.050892952496984174, 0.02674091580723013, 0.025325897183003168, 0.034339469857513905, 0.03584437910467386, 0.018928304314613342, 0.05785293384854283, 0.03579876119537013, 0.025937328480982354, 0.0543580578107919, 0.0685171837519322, 0.05087288821648274, 0.05888551486922162, 0.026126124064571092, 0.05137885142383831, 0.014037873429645385, 0.04306872109217303, 0.041548456597541056, 0.018490616997171725, 0.01895559499306338, 0.042328673481409035, 0.04744496322902186, 0.02510753782865192, 0.04784353130630084, 0.03508064044373376, 0.018004187116665498, 0.04587178657363568, 0.05267055818278875, 0.044603781042886634, 0.05375931511766144, 0.03187715448439121, 0.0324176992289722, 0.005722821174588586, 0.0486053361424378, 0.043194840396089215, 0.03717988869175315, 0.029439480110470737, 0.06455595059586422, 0.008018442546017468, 0.03935764683410525, 0.02120288261877639, 0.054222415267888985, 0.006126546118009303, 0.04232056838061128, 0.013711915384711964, 0.012602853289406215, 0.08480596648795263, 0.1780687320445265, 0.022366190196147988, 0.08070108746843678, 0.15831037584160054, 0.22812683880329132, 1.7095432494367873, 2.4522629039628163, 3.8937605023384094, 15.441040788378034, 24.629222222736903, 40.320827211652485, 52.10718502317156, 64.98311070033482, 70.67432458060128, 72.4949541091919, 74.03193037850517, 63.82250445229666, 66.55800328935895, 73.31442465100969, 56.9778687613351, 56.94158526829311, 43.750061988830566, 44.76236241204398, 55.386752128601074, 50.59981155395508, 37.35268531526838, 32.953589711870464, 39.80318641662598, 38.99725096566336, 31.178328445979528, 30.923187119620188, 45.45289175851004, 36.66323641368321, 39.42082357406616, 52.741013595036094, 39.734051840645925, 40.77517339161464, 41.37905175345284, 49.05810008730207, 55.179945945739746, 59.9288729258946, 47.83205917903355, 48.58845397404262, 50.327091285160606, 39.903104986463276, 54.6761668069022, 52.13631534576416, 52.073753765651155, 51.35257938929966, 51.84301103864397, 55.26042693001883, 62.4280982698713, 67.8611170904977, 65.87202848706926, 74.55786732264927, 61.49959659576416, 58.74421201433454, 43.82236494336809, 22.169123922075542, 13.46502869469779, 3.7504504323005676, 1.9469495160239083, 0.1986406110227108, 0.03082152023645384, 0.049212994785713296, 0.001126044024463876, 0.01921668678655156, 0.043056867085397243, 0.06643098033964634, 0.026460840300257717, 0.042016035078891685, 0.09406064131430217, 0.020871733780950308, 0.08770580124109983, 0.025457561814359257, 0.016238827291609984, 0.0010950962543055148, 0.03894812720162528, 0.009388417471200228, 0.031232403724321296, 0.024773922516033053, 0.03282199753448367, 0.02868337496849043, 0.005128033492448074, 0.015428899055612939, 0.049801043766949854, 0.04105900214718921, 0.03486320389700787, 0.07482912684125559, 0.030823389600430216, 0.0405035567735987, 0.07043425552546978, 0.029972815420478582, 0.04743189125188759, 0.016860814898141792, 0.02732604030253632, 0.06281025641198669, 0.06690919146473918, 0.05241886918832149, 0.006796487490646541, 0.045855070863451274, 0.009347111651940005, 0.04043137761098998, 0.047708886209875345, 0.031672739024673185, 0.03509213821962476, 0.06084568040179355, 0.028135195008612106, 0.009733474580571055, 0.02888190752959677, 0.044348275288939476, 0.012348902228820537, 0.09965791739523411, 0.019275437741141235, 0.01347045785015715, 0.031380829866975546, 0.04308954533189535, 0.006692665695611919, 0.01563297864049673, 0.0211098011849182, 0.007902949948662093, 0.032329506639923365, 0.02812692875574742, 0.067338717702244, 0.11388208770326205, 0.18050309856023106, 0.08490224382174866, 0.2572023629077843, 0.08212666918656655, 0.1337475845856326, 0.0906681019280638, 0.1415304626737322, 0.09885438944080047, 0.1417956477297204, 0.1250160195465599, 0.2042842446161168, 0.13520950185401098, 0.13208402028041227, 0.13855058114443505, 0.12276549530880791, 0.11144029122910329, 0.17850758135318756, 0.1943884627627475, 0.1679460752223219, 0.04607453622988292, 0.20687072511230195, 0.09372207948139735, 0.13204697226839407, 0.08111932966858149, 0.18580354271190508, 0.11715950683823653, 0.1646579216633524, 0.18527181552989141, 0.13486108769263538, 0.12121082230338029, 0.14460627548396587, 0.09603603995804276, 0.09889151209167071, 0.10350308713636228, 0.12814581660287722, 0.1634028082979577, 0.10358834506145545, 0.11476393895489828, 0.12588164024055004, 0.1178687930639301, 0.1286588026476758, 0.09355218788342816, 0.18456786258944444, 0.1559982949069568, 0.09151456079312734, 0.22696146847946302, 0.1935873164662293, 0.18475159630179405, 0.13280539800013813, 0.16998401443873132, 0.21004738179700716, 0.27280511281320025, 0.1257902822856392, 0.29058012472731726, 0.24420244619250298, 0.5610316438334328, 2.725142764193671, 2.567060172557831, 4.84888767344611, 18.519130979265483, 27.4139438356672, 46.56963750294277, 62.617068426949636, 74.11884539467948, 79.84027699061802, 82.75183623177665, 83.47828429085868, 73.99322196415493, 76.50140353611538, 82.40436376844133, 62.33877222878592, 67.67646871294293, 54.13464157921927, 51.59893471854073, 63.08089542388916, 55.80832365580967, 45.8817206791469, 36.56452335630144, 41.19279486792428, 41.74544416155134, 33.25606564113072, 33.18372794560024, 51.69950294494629, 40.80074276242937, 44.0861359323774, 59.07038824898856, 46.897943360464915, 50.68120275224958, 50.64531878062657, 56.592097827366416, 63.304856709071565, 68.43845680781773, 54.707909652165, 59.10644939967564, 59.31334590911865, 49.210508823394775, 58.69054412841797, 59.30391025543213, 56.42086294719151, 58.46005153656006, 58.755051204136436, 62.14388220650809, 70.45614419664655, 77.71280111585344, 76.36462129865373, 84.71690491267613, 68.90940570831299, 67.384519304548, 49.93537616729736, 27.29105278423854, 16.460268565586635, 4.683111037526812, 2.070468293769019, 0.37158482947519844, 0.1438483925802367, 0.19571974846933568, 0.1959457684840475, 0.078651891356068, 0.1260896519358669, 0.2618591215993677, 0.10059783767376627, 0.10825272370129824, 0.1951923096286399, 0.11366760956921748, 0.22496885540229933, 0.15952985254781588, 0.14651198179594108, 0.10798009511615549, 0.12142739711063248, 0.1298067346215248, 0.16081296226808003, 0.19676922501197883, 0.16612073459795543, 0.055465053766965866, 0.10222048631736211, 0.1492782197892666, 0.18495563178190164, 0.18570420518517494, 0.1984766905329057, 0.1305637490004301, 0.17349684451307568, 0.11437596620193549, 0.18398310111037322, 0.10673519370279141, 0.10782460203128201, 0.07851462372179542, 0.0964015464165381, 0.2455017321876117, 0.18274841164903982, 0.2088678843740906, 0.08172351081988641, 0.21765519785029547, 0.09263885939227683, 0.15014424760426792, 0.13627271194543156, 0.1563314013183117, 0.1528576820024422, 0.18708529536213192, 0.09292087211672749, 0.155364136078528, 0.12454085504370076, 0.10651121607848577, 0.1124497206349458, 0.16173931184623921, 0.1712615466011422, 0.125441881694964, 0.17014602145978383, 0.12945428996213845, 0.13112781516143254, 0.17094676063529082, 0.1278797494513648, 0.07478859794459172, 0.14222005781318459, 0.11795473630939211], [0.03749984509444662, 0.0418946858761566, 0.01907226739318243, 0.04828071141881602, 0.052308742954794846, 0.03679054869072778, 0.056345877038048844, 0.010480076839615191, 0.0027207778434136082, 0.013316691636906137, 0.028877975419163704, 0.07446576455341918, 0.04061245485874159, 0.026997507217207124, 0.03431028267368674, 0.04379856353625655, 0.02970427500882319, 0.035680489148944616, 0.02754341747744807, 0.016360782086849213, 0.02040520872521613, 0.03554050737459745, 0.0476763267070055, 0.05198704271710344, 0.06975553730236632, 0.040299483974065096, 0.03323210749242987, 0.0031228935986291617, 0.01791773327360196, 0.05530791184199708, 0.07485444298280136, 0.018123743290613805, 0.015555606988657798, 0.058672203815409114, 0.014029833637843174, 0.014228309371641703, 0.018866681460557238, 0.019131871605558053, 0.02304187197504299, 0.04752998027418341, 0.02026978161718164, 0.027571725958426083, 0.049892469575362544, 0.054287425708025694, 0.10523381283772842, 0.026817005027883818, 0.04682885682476418, 0.09924220613070897, 0.03493903357801693, 0.050473736599087715, 0.04450141724997333, 0.05582379183865019, 0.12320788657026631, 0.20506890251168183, 0.2979973538645676, 0.7176153244716781, 4.346734847341265, 6.399760339941297, 12.503403220857892, 19.238830600466045, 31.977701323372976, 41.36336966923305, 57.37949548448835, 61.454169273376465, 63.771768706185476, 63.75275843484061, 62.4790563583374, 55.69675643103463, 50.18166896275112, 45.042649269104004, 35.16022293908255, 33.062068462371826, 27.941695996693202, 18.961024250302994, 24.013392959322246, 15.427635976246425, 15.5512444291796, 13.793152162006923, 21.449627535683767, 12.40329270703452, 12.992876887321472, 14.723882470812116, 16.139202730996267, 13.104457139968872, 16.90578705923898, 19.320053304944718, 15.43058374949864, 17.800496169498988, 20.83276125362941, 24.661404541560582, 27.684194019862584, 36.65177536010742, 26.297356162752422, 24.582782200404576, 28.425936801092966, 21.927055631365093, 26.670469215938024, 15.89027656827654, 19.284598384584697, 27.896921804973058, 24.913137776511057, 33.30944517680577, 30.55597482408796, 29.784029960632324, 35.3851500238691, 47.318597725459504, 52.5342560495649, 49.57860006604876, 62.729240145002095, 63.82073266165597, 54.46977751595633, 49.79250035967146, 37.86484745570591, 26.937696933746338, 15.730068479265485, 5.690552932875497, 1.676593697496823, 0.5149745866656303, 0.1787469820784671, 0.013984341257517892, 0.08090598468801805, 0.01309731787270201, 0.06474881060421467, 0.030451019760221243, 0.036705565572317154, 0.09861018468758889, 0.013096646123033549, 0.06818001970116581, 0.05723311925040824, 0.03636732943622129, 0.047226624230721166, 0.017071705278275267, 0.06590544139700276, 0.050847589038312435, 0.0256995681141104, 0.010823258647828229, 0.0653469595792038, 0.02624755129883332, 0.03481161148686494, 0.02460560342296958, 0.020342875105727996, 0.025055355093042766, 0.011195564875379205, 0.012227296879115914, 0.017643625482118556, 0.062060882337391376, 0.018032220790960958, 0.040323185202266486, 0.07386116271040269, 0.019578637721549188, 0.044972768386027644, 0.030811488096203123, 0.04259998570861561, 0.01716994188193764, 0.01685041295630591, 0.05619192422766771, 0.020013397160385336, 0.018375652808962122, 0.037638252667550526, 0.013399617946041482, 0.0030145900797963676, 0.021606205530198555, 0.02921015563021813, 0.016203166883704916, 0.030466911050357988, 0.02332001196087471, 0.04742692776822618, 0.07290666749966995, 0.039397252923143763, 0.009781156932669026, 0.062298498515571864, 0.0570492430457047, 0.043821056972124746, 0.061299688182771206, 0.019100991476859366, 0.03598538885957428, 0.020152895478531718, 0.041617097200027535, 0.07197127983506237, 0.035891391403440914, 0.03419823957873242, 0.03744334687611886, 0.024953206734997884, 0.05288534505026681, 0.04571572691202164, 0.0035497073923969375, 0.0036109602328256835, 0.0306600865774921, 0.05420843744650483, 0.04598898653473173, 0.04320592087294374, 0.023404089235035435, 0.040567410311528614, 0.04948963690549135, 0.04843831474759749, 0.022587630099483898, 0.02620200633204409, 0.05021685002637761, 0.02089648843476815, 0.0663007762549179, 0.018021515204704235, 0.09470224367188555, 0.02904830127954483, 0.016037984318765144, 0.035342799233538766, 0.053412583723132095, 0.030224480666220188, 0.00610346532526559, 0.0605230505711266, 0.03690348745190671, 0.0231490245288504, 0.03380811586976051, 0.05026941274159721, 0.06766001081892423, 0.06392337953937904, 0.02452518854157201, 0.06755814914192472, 0.07361906141574893, 0.0462216935120523, 0.039895267092755864, 0.08268682020051138, 0.057894229489777765, 0.048050185931580405, 0.015485061399106468, 0.033564935704427104, 0.04189772232036505, 0.04624325396226985, 0.09334463759192399, 0.04979771216000829, 0.2618003604667527, 0.36500407116753714, 1.3476438288177763, 5.403188032763345, 10.392841867038182, 16.97170635632106, 25.989328622817993, 45.84912320545742, 53.852694102696006, 69.71754373822893, 73.04865605490548, 71.67548356737409, 70.73303685869489, 69.43992151532854, 61.68497453417097, 57.09912177494594, 54.48664426803589, 44.445851121629985, 43.166270869118826, 36.858508586883545, 31.595383644104004, 33.201233931950156, 25.499949625560216, 27.964772701263428, 26.14059611729213, 33.32579428809029, 18.03890449660165, 26.30600666999817, 22.897623436791555, 28.530203206198557, 21.363379546574183, 30.57797976902553, 27.408845594951085, 26.259029899324688, 30.40731464113508, 32.374012674604145, 34.2493314743042, 34.32820047651018, 40.81402424403599, 35.67400400979178, 33.80970852715628, 38.70648275102888, 36.64478199822562, 38.87813452311924, 24.130614280700684, 27.0432904447828, 35.099096161978586, 33.88871649333409, 44.76794181551252, 39.067879404340474, 38.58550419126238, 41.93343114852905, 56.48069388525826, 60.35770879473005, 57.93959672110421, 69.96049445016044, 70.92468902042934, 61.92309624808175, 58.43881089346749, 46.25742367335728, 34.5737498147147, 21.29095847266061, 9.273934364318848, 2.7194411158561707, 1.2316357280526842, 0.14949782086270197, 0.01311035592308534, 0.043451357167214155, 0.06836319022944995, 0.06462481511490685, 0.037227623630315065, 0.05268405085163457, 0.02920911068628941, 0.06439268149967704, 0.05504002282395959, 0.02986234313409243, 0.0506409717324589, 0.06658236828765698, 0.029456263674157004, 0.06590255762317351, 0.028978636089180197, 0.017890902302627052, 0.01279079815971532, 0.018176078696602156, 0.021944589247660976, 0.0383798168040812, 0.06955022617642369, 0.02687433614794697, 0.010944754583761096, 0.02060757840185293, 0.024346285998555164, 0.07473058320049729, 0.06923743510352713, 0.04407270525449088, 0.06339400008852993, 0.06649120710790157, 0.01658505996290062, 0.0696365154747452, 0.04353521052481873, 0.02420787333643862, 0.013449936406686902, 0.012036214632514333, 0.049767429142126014, 0.025215730237375413, 0.01704190402025623, 0.012169216826025928, 0.05970817751118115, 0.03775848228750484, 0.020584029844030738, 0.012165301678968328, 0.07251709340406315, 0.039333012620253224, 0.025760587071999907, 0.05801428947597742, 0.04413130014602627, 0.06190233584493399, 0.032879768005971394, 0.0729500191020114, 0.03530338652698057, 0.026707533580650176, 0.022982303385755846, 0.0965219863823482, 0.02042255038395524, 0.1151397523603269, 0.10212302154728345, 0.22332553858203547, 0.167113974158253, 0.13005757544721874, 0.1705580007817064, 0.13179181595998152, 0.14214920518653734, 0.17285376973450184, 0.08941843719886881, 0.09149357370500054, 0.17108238621481828, 0.1493968955640282, 0.1065104900460158, 0.13719576384340013, 0.22582087825451577, 0.11888879404536315, 0.11012117844074965, 0.13792619322027477, 0.20968265565378325, 0.1008767019957304, 0.07880782548870359, 0.09554470596568924, 0.13177095779350825, 0.12426403989749295, 0.1518969985523394, 0.11785704083740711, 0.1447939175580229, 0.051145221638892374, 0.27837691668953213, 0.1779274610536439, 0.08389472788465874, 0.08002823178789445, 0.12692517281642982, 0.13539304557655538, 0.09449385878230844, 0.13806285017303058, 0.14426353387534618, 0.16178604933832372, 0.07729461097291537, 0.10991028975695372, 0.13960064122719423, 0.12192119418510369, 0.13300500943192414, 0.24878706304090364, 0.16839272768369742, 0.178593103906938, 0.13229888517941746, 0.1213182479675327, 0.14706760698131152, 0.10411867446133069, 0.17018259449728898, 0.24993910693696567, 0.5879175354327474, 0.6122527867555618, 2.2916466082845415, 7.507293207304818, 14.449844649859838, 22.480999026979717, 32.76481410435268, 54.5690290587289, 63.54800891876221, 79.11475999014718, 85.22224739619664, 80.16697434016636, 82.45428657531738, 77.87816129411969, 72.04865046909877, 69.15762315477643, 64.06211308070591, 51.648638657161165, 51.8800379889352, 44.510507583618164, 33.760233879089355, 37.70648758752005, 27.74181021962847, 27.294660636356898, 26.052883795329503, 34.727746214185444, 19.985202619007655, 22.57765368052891, 23.741951159068517, 26.511522224971227, 22.50323847361973, 28.248043809618267, 32.464367049080984, 25.43402511732919, 29.66181114741734, 32.71432154519217, 37.478930609566824, 44.01368011747088, 50.41553143092564, 40.80121176583426, 38.228276457105366, 45.095344407217844, 35.8244811466762, 42.098273686000276, 30.810588087354386, 32.295143672398154, 41.135305472782676, 37.93010146277291, 47.350687980651855, 44.233444690704346, 44.63589130129133, 51.69546604156494, 65.48873111179897, 70.99911117553711, 66.78610570090157, 78.26069436754499, 78.64848722730363, 72.43468543461391, 67.20259462084088, 53.034630571092876, 38.42534473964146, 24.489160435540335, 11.278608645711627, 3.7466046043804715, 1.4501358377082008, 0.41142387315630913, 0.1468456174646105, 0.17841601983777114, 0.08943108509161643, 0.14510114464376653, 0.13839472165065153, 0.10423243764255728, 0.20999220332929067, 0.1348626483231783, 0.2398813994867461, 0.1622640501175608, 0.09294267344687666, 0.1898083785282714, 0.0957176306151918, 0.18670988907771452, 0.15368803244616303, 0.09098848580781903, 0.08086812243397747, 0.1375610056732382, 0.1436076212142195, 0.1484871565231255, 0.1515238450041839, 0.1384984560843025, 0.09894887544214725, 0.09730988088995218, 0.11533215775021485, 0.1758592456047024, 0.16620807562555584, 0.13614494380142006, 0.1608580034226179, 0.1454642830150468, 0.06749132022793804, 0.20016580846692833, 0.08089574559458665, 0.1544095730142934, 0.08590492858950581, 0.07342567215008394, 0.12134236310209547, 0.06838945632002183, 0.11172999854066543, 0.1643568013927766, 0.15063799039593764, 0.1309088519109147, 0.08618558424391917, 0.16701424308121204, 0.16780785763902323, 0.06440301558801106, 0.10761579644999333, 0.10973938714180674, 0.16573269399149076, 0.20645197401089327, 0.10330178615237985, 0.15412291911031517, 0.1559892568205084, 0.04866840936509626, 0.08867454568722419, 0.17633511578398092, 0.109024964406022], [0.02978507156616875, 0.01649393101355859, 0.08820044648434434, 0.016120670596137643, 0.014298186604199665, 0.05573192837515047, 0.04784456267952919, 0.0319435287799154, 0.02865600965118834, 0.006845911133236119, 0.05932818433003766, 0.05043843581474253, 0.03518742149961846, 0.034336681078587256, 0.03383361521576132, 0.07498400924461228, 0.046484863319035084, 0.07128867360630206, 0.08440225850790739, 0.14141447389764444, 0.07538676049028124, 0.05117846306945596, 0.027208009136042426, 0.047371233613895516, 0.0347154427186719, 0.03466001319299851, 0.004243306948670319, 0.03168678469955921, 0.036487789758081944, 0.03586760875103729, 0.03728494966136558, 0.034133911066289456, 0.04399710288271308, 0.028988457883575132, 0.02098565811424383, 0.03331153340903776, 0.042374715475099425, 0.015542300916942102, 0.04143746183919055, 0.04543402631367956, 0.09424333686807326, 0.03106068686715194, 0.028393389457570653, 0.029179156757891178, 0.035945796341236146, 0.04274751279237015, 0.02278834754335029, 0.054624854387449365, 0.09935121956680502, 0.3235322008175509, 0.3435416285480772, 0.9788249794925962, 2.5072833001613617, 4.538321001189096, 6.753220413412366, 13.534554975373403, 22.16740597997393, 27.996406112398418, 42.288762024470735, 47.63746445519583, 66.62989630017961, 61.47067124502999, 64.48632839747837, 56.07669087818691, 53.10345247813633, 43.909874030521934, 41.87473971503121, 38.74177612577166, 37.5602696963719, 29.87177528653826, 39.71388122013637, 40.14710487638201, 24.214458193097794, 12.132154021944318, 11.962754334722247, 11.866746732166835, 28.85268647330148, 25.0018766948155, 12.968038814408438, 26.640845571245464, 22.670940194811138, 28.39391950198582, 26.794326066970825, 31.62850570678711, 21.367911509105138, 29.8708233833313, 19.483360290527344, 22.515719175338745, 20.375628846032278, 20.907049655914307, 11.649080514907837, 23.395260368074688, 36.470590659550254, 17.272368805749075, 16.211330243519374, 9.794119937079293, 8.118284787450518, 8.088695015226092, 17.055093424660818, 20.385906968797954, 27.34099817276001, 19.48609266962324, 20.223352125712804, 19.93900752067566, 23.773447343281337, 28.23943672861372, 30.11824526105608, 36.192627974918906, 52.465854508536204, 55.86235284805298, 52.29327515193394, 54.26136629922049, 54.16980293818882, 50.39193534851074, 44.599434103284565, 36.136562960488455, 19.28056148120335, 14.372526832989283, 3.6656819752284457, 2.4079340483461107, 1.1336278042622974, 0.116164448804089, 0.09555456507951021, 0.007290517811530403, 0.024707202167649354, 0.04581260474930916, 0.048701135109045675, 0.007183808849991432, 0.04108609265780874, 0.01663528342864343, 0.04941354598850012, 0.051565546941544325, 0.031383761138256104, 0.026722580094688704, 0.07754372153431177, 0.011046361810128604, 0.011993230287251728, 0.0392094208592815, 0.03337770075138126, 0.024233861227652857, 0.05335237731092742, 0.058081980129437785, 0.037172302670244656, 0.05708895091499601, 0.07092893469546523, 0.02191512725715126, 0.03327671777723091, 0.013023837619195027, 0.03978624347863453, 0.012606809148564935, 0.00794898346066475, 0.041220998990216424, 0.03137505214129176, 0.04053496276693685, 0.06645950595183031, 0.00578541899864961, 0.04122532465096031, 0.03390866797417402, 0.01986883527466229, 0.009284917980299463, 0.047247370438916345, 0.019192154352952327, 0.024061538777979355, 0.0360359838232398, 0.01781408704950341, 0.05315209073679788, 0.06888032212321248, 0.03480547074494617, 0.024015559548778192, 0.06395415110247475, 0.018146645543830733, 0.025676925400538102, 0.05987627099135092, 0.015113499015569687, 0.02269759518094361, 0.06741204698170934, 0.03306446863072259, 0.0670206815536533, 0.02665432625716286, 0.01090665060162012, 0.027444751700386405, 0.025257000433547155, 0.029625140862273316, 0.07104347819196326, 0.02329356436218534, 0.025235402663903575, 0.058931526328836165, 0.04513634282297321, 0.057964478220258436, 0.028268247244081328, 0.018977204637069787, 0.03783261223829218, 0.04540704097598791, 0.11399020547313349, 0.02673650872228401, 0.04807473532855511, 0.04258095280134252, 0.025180169913385595, 0.07296407156224761, 0.022373877997909273, 0.025668565849108354, 0.03695151076785155, 0.036629674823156426, 0.035283980425447226, 0.029306399037263224, 0.022353610156902244, 0.01707952030535255, 0.038217256776988506, 0.039449262632323165, 0.06468557792582683, 0.02235132858290204, 0.06711265019008092, 0.011479374869460506, 0.02708021385063018, 0.025057402572461536, 0.04473397834226489, 0.07200622438852276, 0.027823358973754302, 0.1081024824774691, 0.021657601165186082, 0.04809617024979421, 0.07027327987764563, 0.04372826052297439, 0.05118951301223465, 0.1324890378330435, 0.5394457078405789, 0.6116225091474397, 1.1858360256467546, 3.413577445915767, 5.495850946222033, 8.788857170513698, 17.828111784798757, 26.803355251039775, 35.49410125187465, 55.08260863167899, 57.8947183064052, 74.94918291909354, 70.65596049172538, 70.89049693516323, 63.927929469517295, 63.552344594682964, 53.77774041039603, 53.02876629148211, 47.16683169773647, 46.955790587833945, 39.7060922895159, 45.923177106039866, 44.62353045599801, 34.21347529547555, 23.083729199000768, 23.809162821088517, 21.575839826038905, 34.07903460093907, 28.34127300126212, 26.568624258041382, 26.891699859074183, 25.74610345704215, 29.420510632651194, 27.805045775004796, 32.17886209487915, 22.147634880883352, 35.4690842628479, 15.41598732130868, 24.725724015917095, 21.426569938659668, 29.024296556200298, 22.41060161590576, 37.15995618275234, 36.04290124348232, 19.801264694758824, 22.272183077675955, 17.832254648208618, 18.03672971044268, 15.593715293066841, 23.952599695750646, 33.01393829073225, 31.841492312295095, 24.86118609564645, 30.00203663962228, 29.634386607578822, 33.954623631068635, 37.906824997493196, 37.854508536202566, 44.55460780007498, 60.315248353140696, 61.894170897347585, 58.303439140319824, 62.23190198625837, 59.563168389456614, 57.25967379978725, 53.54732077462332, 44.30168642316546, 26.17850375175476, 19.650834458214895, 6.327614154134478, 3.532966388123376, 1.4993796753031867, 0.24074772585715565, 0.044945362356624434, 0.006662087514996529, 0.060454979938055785, 0.04270745547754424, 0.02922475091846926, 0.07439852851842131, 0.05991534782307489, 0.04326388133423669, 0.010783097856411976, 0.07774259336292744, 0.03103052598557302, 0.03714969388342329, 0.019169850906889354, 0.019701215072668025, 0.039481079139347584, 0.03466026425095541, 0.04763139072539551, 0.04811890795826912, 0.06888877666954484, 0.026879786480484263, 0.03670260715963585, 0.022475201935906495, 0.029641985494111265, 0.009379044358086373, 0.01602379615152521, 0.047647322727633376, 0.022439997842801467, 0.06033125586275544, 0.04500396403351, 0.017784139906455363, 0.050755416841379235, 0.0639891702947872, 0.05072560540533491, 0.023612206103280187, 0.07674123852380685, 0.012221996672451496, 0.0064882328484340435, 0.0809762877013002, 0.04871011891269258, 0.043210365277315886, 0.0415230318903923, 0.0750780813395977, 0.00622174542929445, 0.048831770063510964, 0.007372017500789038, 0.021491924966020242, 0.041300845598535876, 0.04448970573555146, 0.02615561828549419, 0.037166450305708816, 0.014703707969082254, 0.0212007944272565, 0.029081539317433323, 0.04123203536229474, 0.13396113312670163, 0.2011824981974704, 0.11315897971923862, 0.08870989057634558, 0.11438109592667647, 0.1775109762591975, 0.16809077960039887, 0.11227079773587839, 0.06295462830790452, 0.06031311183635678, 0.2501193529793194, 0.15855019725859165, 0.0740120688985501, 0.11151184274681977, 0.10409916657954454, 0.1511134805956057, 0.1775205707443612, 0.1845752586211477, 0.2450265134019511, 0.20556736790708133, 0.1348204705864191, 0.08673445122050387, 0.10022781217204672, 0.118315350530403, 0.1249803150338786, 0.18384615917290958, 0.1687485785888774, 0.0893738642334938, 0.20574481838515826, 0.1511242285903011, 0.14093894298587525, 0.13126582918422564, 0.14345758355089597, 0.13569514293755802, 0.09753391958240952, 0.12606567250830786, 0.15267736810658658, 0.1592337262949773, 0.14714671059378556, 0.12283238529094628, 0.1970124798161643, 0.0847175330189722, 0.15638002513774804, 0.09893583399908883, 0.21996114482837065, 0.17429789581469127, 0.1065451835415193, 0.1253768644694771, 0.2255777320159333, 0.7621272759778159, 1.0049355498382022, 2.06351358124188, 4.49223837682179, 8.1837055512837, 12.458796654428754, 23.504343611853464, 32.33624226706368, 44.6325353213719, 65.36407348087856, 68.10569368089948, 86.13123158046177, 81.25201198032924, 80.03870364597866, 76.0512922831944, 74.85593809400285, 62.480369567871094, 62.45406368800572, 56.125307423727854, 54.90827138083321, 44.26509026118687, 55.778175422123496, 51.67196028573172, 35.95363078798567, 23.63253092765808, 23.8043338230678, 20.83253022602626, 40.066175733293804, 33.27726806913103, 23.91587151799883, 40.99147776194981, 31.596498829977854, 38.456271171569824, 37.011094502040315, 43.764535086495535, 30.775006362370082, 47.13079139164516, 31.627824783325195, 38.236499650137766, 32.930222920009065, 34.65451914923531, 24.21690395900181, 38.92954771859305, 48.05177164077759, 28.999008587428502, 27.838787964412145, 19.615303107670375, 17.03525284358433, 18.385056802204677, 29.452458449772426, 31.527569225856237, 35.1347473689488, 29.8056458064488, 31.757895060947963, 32.27518149784633, 39.394097328186035, 42.14799846921648, 44.485271726335796, 52.33491570608956, 67.59978144509452, 72.43148231506348, 68.2719293321882, 71.67682456970215, 70.08639580862862, 66.56925242287772, 62.755017961774556, 51.74416249138968, 31.502065862928117, 23.79710943358285, 8.664987291608538, 4.700166693755558, 2.349737239735467, 0.40258400035755976, 0.23590336580361637, 0.09809462699506964, 0.16361771390906402, 0.16978912561067513, 0.157804704404303, 0.14701261850340025, 0.18192973200763973, 0.16393199775900158, 0.14097751091633523, 0.18493237160146236, 0.11602199716227395, 0.14593179364289555, 0.1457039958664349, 0.07277592737227678, 0.0918346732588751, 0.11103609470384461, 0.09736260984625135, 0.1932464747556618, 0.17129531050367014, 0.11652468304548945, 0.1248413510620594, 0.1906045036656516, 0.17726451876972402, 0.09316940592335803, 0.12146535435957567, 0.1425163062023265, 0.07790565889860902, 0.2205109346125807, 0.10724714837436165, 0.10160195415041276, 0.0828030328931553, 0.15714299705411705, 0.14140975129391464, 0.15307450108230114, 0.13212526163884572, 0.1243507159607751, 0.1528869132910456, 0.13179586002869265, 0.12640992046466895, 0.09937359765172005, 0.10959344782999583, 0.07581779307552747, 0.11704885134739534, 0.11065775714814663, 0.20066165471715586, 0.13865962172193186, 0.09282386196511132, 0.10258995542036635, 0.16328908582883223, 0.14823451079428196, 0.17018053175083228, 0.11509929810251508, 0.12853039668074676, 0.17741410859993526], [0.038275376694010835, 0.047986600414982865, 0.017964414786547422, 0.033952358844024796, 0.02324218738691083, 0.04477956571749278, 0.03899887822834509, 0.013724157004617155, 0.03607727946447475, 0.023583224176296165, 0.018839261860453656, 0.0618619155138731, 0.052399775212896724, 0.02082003789421703, 0.016979385499975512, 0.00533183996698686, 0.03138178999402693, 0.01618032230596457, 0.004544482774300767, 0.0211722281029714, 0.05353531713730522, 0.012569923984951206, 0.007071873472471322, 0.0782081973073738, 0.01358032793671425, 0.037626452943576236, 0.07518209397260632, 0.06462326805506434, 0.058002679741808345, 0.022189131572044322, 0.04933803861162492, 0.09490236400493554, 0.08344498808894839, 0.010773727287804442, 0.05841328842299325, 0.09773908143064805, 0.02493276077854846, 0.04133583425677248, 0.038262487921331606, 0.054116567197654925, 0.042568172594266276, 0.0593517091391342, 0.026769702655396292, 0.04736922854291541, 0.010891072285760726, 0.05440513796306082, 0.046623077509658675, 0.29969510276402744, 2.2252164014748166, 5.3731392451695035, 7.647258588245936, 11.416576419557844, 16.18341932977949, 17.41579873221261, 30.944799491337367, 45.32429797308785, 46.12564761298043, 58.55540861402239, 63.02680369785854, 61.86093766348702, 57.24906390053885, 50.05162647792271, 43.36288057054792, 38.74071652548653, 45.18872472218105, 26.960896968841553, 24.661771059036255, 18.416417496544973, 22.268241712025233, 9.437968305179051, 19.677256720406668, 38.70599290302822, 11.799448217664446, 14.030083128384181, 17.256728410720825, 16.839351858411515, 40.950208936418804, 39.34809330531529, 25.267942326409475, 34.70721776144845, 51.398621627262656, 47.35844911847796, 50.023163182394846, 39.51137944630214, 36.218523911067415, 25.81633584839957, 34.532977785382954, 36.604947975703645, 32.57409994942801, 31.70557859965733, 25.203621115003312, 19.12302323750087, 43.81145627158028, 32.550309317452566, 35.00227648871285, 40.125304903302876, 38.958546025412424, 26.05399203300476, 24.035222462245397, 19.604896443230764, 25.846953085490636, 42.366984844207764, 23.353918586458477, 24.435838222503662, 18.729838575635636, 30.639304569789342, 20.72588406290327, 22.922956568854197, 25.54148769378662, 34.47544322695051, 35.86852925164359, 43.664335114615305, 46.60707439695086, 52.904733998434885, 54.89128303527832, 55.261622020176475, 59.49870300292969, 48.29592786516462, 30.583632128579275, 21.099426167351858, 10.459465537752424, 6.928149563925607, 2.0719684532710483, 0.5054290103060859, 0.06716427991964988, 0.07555205840617418, 0.045954639092087746, 0.09916629163282258, 0.03899923445922988, 0.018260676746389697, 0.01117369908440326, 0.00843236078175583, 0.025719757923590283, 0.03551214121814285, 0.03273592197469302, 0.07258662967277424, 0.050840294786861966, 0.06965315315340247, 0.02175674700577344, 0.02282178744540683, 0.06496223022363015, 0.080541434963899, 0.03218524670228362, 0.046310978542481146, 0.023034053555290614, 0.03358389058017305, 0.0620705582467573, 0.030878232193312476, 0.03601261507719755, 0.008547700708732009, 0.021977605065330863, 0.11896934972277709, 0.0479760390174176, 0.14262641886515276, 0.034133571798780134, 0.0036463348078541458, 0.04531416649531041, 0.015355508707995926, 0.008984165814971285, 0.01764718609462891, 0.002329410082893446, 0.015605940716341138, 0.02068205101282469, 0.07727113366127014, 0.017461901929761683, 0.037080822579030476, 0.07498453171657664, 0.05223984790167638, 0.06396713826273169, 0.03913419507443905, 0.033949430965419324, 0.06849333324602672, 0.07314191559063536, 0.04456677035029445, 0.022228778373183947, 0.11575120740703174, 0.06691277412963764, 0.008120729155572397, 0.02419797351051654, 0.0661250628264887, 0.014872931210058076, 0.02821889060682484, 0.08400437914367233, 0.06371694204530545, 0.013254190080000885, 0.021397237100505402, 0.008762583419281458, 0.019012919327776347, 0.04048016767150589, 0.026640974384333407, 0.04789183621427842, 0.004259401375228273, 0.03148103252585445, 0.023460433086646453, 0.011364422555613731, 0.05726067455751555, 0.04640610236674547, 0.0695504229515791, 0.028308275721168945, 0.04771841284153717, 0.04209141353411334, 0.038546621067715545, 0.008136400769996856, 0.01903012188683663, 0.06127593945711851, 0.053899955070976696, 0.07035380841365882, 0.016420074173116257, 0.03986553708091378, 0.07308796527130262, 0.027015369651573043, 0.024287356928523098, 0.018814770138955543, 0.04308288551068731, 0.08298226791833128, 0.04285335068457893, 0.029666029382497072, 0.03497863966705544, 0.043509460120861015, 0.005453409693603004, 0.03739642957225442, 0.03129288155053343, 0.047338945525033135, 0.45170651589121136, 2.9543301803725104, 6.727947643824986, 9.578552075794764, 14.58647836957659, 21.3531048979078, 22.5484573500497, 38.17783600943429, 53.40459087916783, 57.58583613804409, 72.46448625837053, 73.10761151994977, 70.24161856515067, 66.90468365805489, 57.17181035450527, 51.59231308528355, 51.855128696986604, 52.73028905051095, 39.64515311377389, 32.88042518070766, 29.28696972983224, 32.64375911440168, 22.1033661706107, 30.75399500983102, 48.308990478515625, 21.999679940087454, 23.196003402982438, 22.124853474753245, 19.01386877468654, 49.384901659829275, 38.530189582279746, 27.73943567276001, 38.652540411267964, 38.81703206471035, 41.72368935176304, 35.16498245511736, 30.150439739227295, 25.63472557067871, 26.413417134966167, 27.493090765816824, 28.227576153618948, 27.72832724026271, 24.41184435571943, 18.22602469580514, 14.246187738009862, 38.69314220973423, 30.865996497017996, 28.966178349086217, 25.858798027038574, 24.051550728934153, 18.094507455825806, 18.666094064712524, 21.247438430786133, 20.386535780770437, 44.71973521368844, 25.4388975415911, 22.95389516013009, 25.44619836126055, 37.23969370978219, 33.04015384401594, 29.74109009334019, 31.18139954975673, 42.540161745888845, 43.82950421742031, 50.702419076647075, 53.708845547267366, 59.690973554338726, 60.787739753723145, 60.99700559888567, 67.54825360434396, 58.29508740561349, 39.810395172664094, 28.363396065575735, 14.912692819322858, 9.356419035366603, 2.773810986961637, 0.5343436130455562, 0.03421707231817501, 0.03400612935157759, 0.009530577342957258, 0.047991706390998194, 0.011360918770411184, 0.03571127428274069, 0.020653220059882318, 0.021793900190719535, 0.020479873022330657, 0.027246975705825856, 0.008704494036334966, 0.058389275068683286, 0.027181215484493544, 0.031687069684267044, 0.043603315084640465, 0.04186413822961705, 0.02748415253258177, 0.10658890155277082, 0.03029560131419982, 0.010523677803575993, 0.03806625220126339, 0.09443568118980952, 0.03760238530646477, 0.022018593669469868, 0.01872260303103498, 0.013081147535038846, 0.06334278426532235, 0.0632775906207306, 0.039030545457665405, 0.056731050834059715, 0.031988247630319426, 0.05501829952533756, 0.08587712222444159, 0.00721983312230025, 0.04474318606246795, 0.01662404858507216, 0.04357059612604124, 0.043599087811474285, 0.05955991082425628, 0.08013712308768715, 0.06137965353471892, 0.01616848017355161, 0.019615176832303405, 0.060460482857057025, 0.026493457478604147, 0.02382580383813807, 0.04895704459132893, 0.012510573375038803, 0.04145302064716816, 0.024722659195374166, 0.019529762844155942, 0.0506834921294025, 0.2876534132020814, 0.0890892662906221, 0.1513405048421451, 0.17132824659347534, 0.14237077401152679, 0.21325043349393777, 0.1682197962488447, 0.17564291507005692, 0.12576936983636447, 0.18329830999885285, 0.13648664046611103, 0.10638325794466905, 0.16590877382883004, 0.0804828502503889, 0.1348882969468832, 0.055763490431542904, 0.14112069537597044, 0.063023160344788, 0.13660729756312712, 0.09573617497725145, 0.22237162691141876, 0.12891784017639502, 0.17282330351216452, 0.18832026980817318, 0.15981551579066686, 0.10976183308022362, 0.11440579460135528, 0.1352692943598543, 0.15563725999423436, 0.15007099296365464, 0.18867711137448037, 0.19323094987443515, 0.24578625549163136, 0.09583340904542378, 0.14200143383017608, 0.12628572141485556, 0.13231587569628442, 0.1205859322633062, 0.17133989025439533, 0.14279575406440667, 0.13373604949031556, 0.15859188645013741, 0.12848878891340323, 0.09029714004801852, 0.11303441426051514, 0.17027963857565606, 0.20990003113235745, 0.7514252045324871, 4.3666687948363165, 8.863097803933279, 13.341084122657776, 18.171450069972447, 26.89147925376892, 28.650217703410558, 46.080685819898335, 61.106495312282014, 67.22546114240373, 80.45506749834333, 83.91588878631592, 78.97631018502372, 73.07988125937325, 67.44247422899518, 60.70313153948103, 57.34314945765904, 62.474435806274414, 41.83817829404558, 38.36846678597586, 32.32643835885184, 35.223083291734966, 20.664300441741943, 32.91735485621861, 51.90914051873343, 18.657976831708634, 21.370569195066178, 26.823932341166906, 25.945560182843888, 51.22900915145874, 52.80137607029506, 37.6484249659947, 50.60000262941633, 68.5042701448713, 62.61964620862688, 65.72761017935616, 55.451571873256135, 52.2459579195295, 39.577682631356375, 52.196688243321006, 51.0592542375837, 49.81355340140206, 45.77098376410348, 37.49245180402483, 31.454540184565953, 59.845890590122764, 45.377674034663606, 50.54223530633109, 56.45888696398054, 52.91126877920968, 40.03463091169085, 37.6781667300633, 27.85174982888358, 36.96245016370501, 56.79138605935233, 33.77642665590559, 38.1215694972447, 29.582657269069127, 45.843658447265625, 34.487675530569895, 34.55345065253121, 38.457059792109895, 49.77216993059431, 51.28462948117937, 59.48243032182966, 63.88414192199707, 69.93971238817487, 69.0494327545166, 71.09692096710205, 77.79401166098458, 67.15129607064384, 46.1491151537214, 35.59746960231236, 18.50777414866856, 12.182010820933751, 3.988918253353664, 1.063218233840806, 0.15906534104474954, 0.1605490664286273, 0.09628108609467745, 0.14734590133386, 0.10957124616418566, 0.10841160267591476, 0.08863257829632078, 0.1572950838931969, 0.12544021249881812, 0.1563428957015276, 0.16408880720181124, 0.19902676530182362, 0.15652622229286603, 0.1878128477505275, 0.280485423547881, 0.2257388840828623, 0.17049733975103923, 0.16318164659397943, 0.1594330934541566, 0.08102071138897113, 0.16078921354242734, 0.21647564614457743, 0.19604928578649247, 0.11290387769362756, 0.14994779814566883, 0.1098587889490383, 0.12303100606160504, 0.24188288780195372, 0.19377615276191915, 0.28709791015301434, 0.0531175397336483, 0.15474520357591764, 0.14952238383037703, 0.09828663883464676, 0.1288096002702202, 0.11866776804838862, 0.14996781492871897, 0.08725779849503722, 0.11558901039617402, 0.1521190966346434, 0.14310028058077606, 0.20361178927123547, 0.16547635703214578, 0.17301948155675614, 0.1283108363194125, 0.12085639632173947, 0.1660983700837408, 0.15262923283236368, 0.12550569112811769, 0.11657367327383586, 0.1720449695629733, 0.22390755877963134], [0.03516910444679005, 0.013263655643511032, 0.03489032494170325, 0.024666937899642756, 0.08623623688306127, 0.043315165010946136, 0.0482453767077199, 0.04159866140357085, 0.02810207232167678, 0.038549667689949274, 0.029371857310512235, 0.03480092456032123, 0.04269286358196821, 0.036948358972689936, 0.0804767162938203, 0.012331129700344588, 0.028827621335429803, 0.012017900124192238, 0.05044841706486685, 0.06065841830734696, 0.08062265560563121, 0.012587051905159439, 0.021040919702500105, 0.016558590311823145, 0.027907534635492733, 0.05768495571932622, 0.07318845630756446, 0.039977111986705234, 0.051562727628541846, 0.0051819392829202116, 0.027101236561845456, 0.04193249724007078, 0.02909051294305495, 0.004267825811569179, 0.027480015165305564, 0.039020747411996126, 0.08908671499895197, 0.05386853550693818, 0.028984213647033488, 0.065905122485544, 0.06502578181347676, 0.025495505492602075, 0.003800034015772066, 0.06205633615276643, 0.021379735986036912, 0.04230679411973272, 1.4060775275741304, 5.151881677763803, 11.91110576902117, 20.152925184794835, 27.92106853212629, 33.293443475450786, 46.317883423396516, 49.577946935381206, 50.720665046146934, 55.68948514120919, 62.50431306021554, 59.89498656136649, 56.53808600561959, 49.44485419137137, 34.579850333077566, 44.86398676463536, 36.97937250137329, 25.018951892852783, 23.726157903671265, 11.674032364572797, 13.548211659703936, 6.226686792714255, 8.881287319319588, 15.105995178222656, 9.627040079661779, 9.262310028076172, 25.23674144063677, 34.293730463300435, 34.9646554674421, 50.99778699874878, 36.78257867268154, 37.37252242224557, 52.8531470979963, 31.959340708596365, 38.81787627083914, 30.975100585392543, 30.470077719007218, 29.513571330479213, 20.349324703216553, 20.037251574652537, 16.584234850747244, 23.70765311377389, 19.46570144380842, 27.23719903400966, 33.58117880140032, 36.87005649294172, 21.809999329703196, 26.64386108943394, 29.7134918485369, 39.414309637887136, 47.45423003605434, 34.76288325445992, 52.69399513517107, 45.11705405371529, 70.48368685586112, 48.74742875780378, 38.211861337934224, 53.088611125946045, 41.28271497998919, 35.29606716973441, 17.63991114071437, 33.08250658852713, 40.44920212881905, 26.505199364253453, 22.64965612547738, 32.508446420942036, 27.846257277897426, 31.745329243796213, 45.030257156917024, 50.686598028455464, 48.37535619735718, 53.65865523474557, 54.8277382850647, 47.21104655947004, 41.53371865408761, 31.023734501429967, 11.999219349452428, 6.486086496285029, 0.7465898554239954, 0.17155902992401803, 0.06803862657397985, 0.011190899947125996, 0.07519035852913346, 0.016392011661082506, 0.006248160373486046, 0.015837796132213304, 0.011461817775852978, 0.024386563837262135, 0.04617343610152602, 0.032078095844813755, 0.03349271922239235, 0.026871564332395792, 0.023017285258642266, 0.04322742364768471, 0.05418687021093709, 0.036590496211179664, 0.031542870814778974, 0.03476803936064243, 0.03310015278735331, 0.031343429016747644, 0.03130522410252264, 0.04188570885785988, 0.006811349103892488, 0.049257625426564894, 0.06168886872806719, 0.024058615988386527, 0.025440208281257322, 0.007834041324843253, 0.005587257087297205, 0.026681951114109585, 0.0045225809361519554, 0.034310621941196065, 0.06869493957076754, 0.04694867253835712, 0.023476729801456844, 0.042655327024736574, 0.01308546047325113, 0.03699345101735421, 0.07439110534531729, 0.019540495571813414, 0.07749609516135283, 0.10320098299000945, 0.0636952832075102, 0.018710587872192264, 0.011430316787612225, 0.03338690507890923, 0.050222590432635376, 0.03545504588899868, 0.09329998998769692, 0.044574671890586615, 0.03422356250562838, 0.021720920356788805, 0.033094928067709715, 0.02307934746412294, 0.08958847128919192, 0.01219076116103679, 0.05440879526681133, 0.024047225081760968, 0.03199300076812506, 0.0368040413595736, 0.01992893821027662, 0.04538404542420592, 0.0625235957226583, 0.03404624434188008, 0.04403741464817098, 0.05433860421180725, 0.026970879806737815, 0.036249291484377215, 0.020989227208441923, 0.08518798848880188, 0.016921864390107136, 0.09224458304899079, 0.05043779120647481, 0.017913212534040213, 0.00868104216975293, 0.0696888780221343, 0.04067998266379748, 0.024502628948539495, 0.01300690817047975, 0.04149609405015196, 0.07649858761578798, 0.044112894883645434, 0.029387304160211767, 0.0449822271641876, 0.0331747611053288, 0.04692539539454239, 0.009218849025533667, 0.02724025651280369, 0.01396259421017021, 0.03103858358891947, 0.022063648394708122, 0.07078860686825854, 0.0025588475816350964, 0.013220552554620164, 0.03721816145948001, 0.07478808225797755, 1.8283624393599374, 6.538138926029205, 13.86637054170881, 23.874826771872385, 34.130235876355854, 42.11450120380947, 56.53152690614973, 60.60612773895264, 61.28894111088344, 67.15383911132812, 71.34404754638672, 68.00720296587262, 64.0995569229126, 57.86080067498343, 41.21963923318045, 55.90993411200387, 45.127493722098215, 34.07852390834263, 36.889104979378835, 22.337146997451782, 22.783412422452653, 15.358221735273089, 17.470804146357946, 17.505152566092356, 14.702204091208321, 18.892389944621495, 25.173333917345317, 25.308078595570155, 28.915406124932424, 38.06293364933559, 30.65605320249285, 31.137247221810476, 34.72384827477591, 26.787991046905518, 29.286434718540736, 22.66904159954616, 21.88345742225647, 19.028206382478984, 14.422158684049334, 12.627335633550372, 12.959283215659005, 16.420568295887538, 14.07211104461125, 17.799346242632183, 20.162353890282766, 25.084042617252894, 21.51866831098284, 22.761346680777415, 30.93526656287057, 34.460250990731375, 46.874868392944336, 42.556601183755056, 52.06419651848929, 34.257394858769004, 66.06427819388253, 54.376345089503694, 36.63044786453247, 51.85960681097848, 42.99660628182547, 44.94349152701241, 23.93264968054635, 34.10569483893258, 46.7923515864781, 36.56300170081002, 35.222669873918804, 43.23182017462594, 35.97303015845162, 39.18789563860212, 52.26773704801287, 56.345270020621165, 54.27381747109549, 59.995811871119905, 63.0302916935512, 57.02839953558785, 51.34214319501604, 38.73273999350411, 17.17522951534816, 9.615377528326851, 1.813001275062561, 0.24838661881429808, 0.07601293296154056, 0.011909772176295519, 0.05889030532645328, 0.005188444313327116, 0.018912151788494418, 0.03675896627828479, 0.02994431016434516, 0.03193710983863898, 0.12181062011846475, 0.07404132732855422, 0.08416411307241235, 0.06560768666011946, 0.0588631842817579, 0.09249251974480492, 0.06395245476492814, 0.06127798863287483, 0.030088342792753662, 0.05982582191271441, 0.027328250630359565, 0.026651001435571482, 0.024095185633216585, 0.05113199699137892, 0.03583823497008, 0.0898545112993036, 0.027996478702074716, 0.03624000233997192, 0.05060908058658242, 0.024168084042945077, 0.011282121346864318, 0.04761314152606896, 0.004394185995416982, 0.05844059267214366, 0.06473582344395773, 0.06387342579130616, 0.007943278677495462, 0.014863813395744987, 0.056548687762447765, 0.015265518001147678, 0.0054740876242119286, 0.006075535127560475, 0.07998025257672582, 0.09931741495217596, 0.0385907190585775, 0.06657768639602832, 0.020157645223662257, 0.01392178117696728, 0.06806766108742782, 0.014339031019647206, 0.03689666138961911, 0.0612865381741098, 0.1314742887126548, 0.07345416383551699, 0.1880679904882397, 0.15669593747173036, 0.18654328158923558, 0.11528350678937775, 0.13737868331372738, 0.10527155295546566, 0.11365587091339485, 0.09467542796794857, 0.08831792125212294, 0.13379780974771294, 0.13208301604858466, 0.1090354545574103, 0.2714855521917343, 0.10764599125832319, 0.10499473102390766, 0.0791203383622425, 0.12977447706673825, 0.1257229716117893, 0.1363059330199446, 0.13743771586034978, 0.19818770246846334, 0.11283360860709633, 0.13448874838650227, 0.10719393087284905, 0.19001279398798943, 0.08225876638399703, 0.2336110845208168, 0.12021345725016934, 0.1916182078421116, 0.1390367243438959, 0.10960534254887275, 0.09314897523394652, 0.12050522730818816, 0.11354446224868298, 0.20992318274719374, 0.1347302525703396, 0.07582628154861075, 0.15799381211400032, 0.1068658320499318, 0.18815317377448082, 0.10501958576164075, 0.1638153168771948, 0.15946187690964767, 0.3348203908119883, 2.845621270792825, 8.924187234469823, 17.444864783968242, 29.577432223728724, 42.44045509610857, 49.79179859161377, 66.80114160265241, 69.69806793757847, 70.59301676068986, 75.5980473927089, 81.0399807521275, 77.78224836077008, 71.695529120309, 67.94810853685651, 50.64710446766445, 62.259027753557476, 51.83648668016706, 37.80799382073538, 38.942443575177876, 20.884890113558086, 24.694448437009537, 14.046121307781764, 16.25040864944458, 20.9684248311179, 20.592475175857544, 18.58451352800642, 33.758027826036724, 47.056806973048616, 48.70907122748238, 68.02364935193742, 46.20528439113072, 48.40727622168404, 64.9373151234218, 42.28404767172677, 49.24371426446097, 38.93262229646955, 37.93778964451381, 35.38359710148403, 26.21684217453003, 25.547084467751638, 21.56087688037327, 29.737060138157435, 25.208467483520508, 34.77423313685826, 41.292539732796804, 46.22864076069423, 28.593068769999913, 34.80550003051758, 40.27549368994576, 51.370179176330566, 61.85877677372524, 49.309423378535676, 68.52917943681989, 60.43187386648995, 84.50895922524589, 55.41440595899309, 52.569580691201345, 66.69986465999058, 54.57342726843697, 47.816258975437705, 29.14093770299639, 45.423660687037874, 53.91952535084316, 41.06596939904349, 36.67052507400513, 46.34890365600586, 42.300494057791575, 46.649573053632466, 61.8797881262643, 65.59355163574219, 62.54803112574986, 69.17407648903983, 71.74777957371303, 66.41874749319894, 60.06072889055525, 44.536636284419465, 21.127703598567418, 11.457624639783587, 2.5415780884878973, 0.3450098969042301, 0.32587121959243504, 0.12551253076110566, 0.16821390656488283, 0.10995879822543689, 0.08970760168241602, 0.1684522216341325, 0.12490278562264782, 0.07932317962071725, 0.2516978425639016, 0.16085205945585454, 0.24200445413589478, 0.13147719284253462, 0.16804727193500313, 0.1744221355766058, 0.18137975223362446, 0.12100936525634357, 0.055788989777543714, 0.12488103178994996, 0.13358248344489507, 0.18644217987145695, 0.10497127406831298, 0.0994149882878576, 0.07617639204753296, 0.2004448084958962, 0.1374645179935864, 0.10430097646479096, 0.11783489345439843, 0.10568826845181839, 0.10293310414999723, 0.11837455949613027, 0.06920867878943682, 0.16262017243674823, 0.17215810849198274, 0.18276454721178326, 0.26081548045788494, 0.07675118584718023, 0.2472743642117296, 0.07333200717610971, 0.08349286551986422, 0.11052705773285457, 0.1505831919078316, 0.22557585925928184, 0.13206333853304386, 0.18280303371804102, 0.11381214431353978, 0.10572438008551087, 0.14955844118126801, 0.13053244139466966, 0.1849124633840152, 0.1357603230114494], [0.028970975428819656, 0.021249609932835613, 0.05290112777480057, 0.06608314971838679, 0.02658086975238153, 0.04638433835602232, 0.0577178510970303, 0.026638757271159972, 0.027334123350945965, 0.02429919397192342, 0.036653993518224785, 0.036136342545173, 0.02201268702213253, 0.007767354055041713, 0.044774839721087895, 0.028684691326426606, 0.03460987624047058, 0.03797661093994975, 0.020780967847843255, 0.03726541803085378, 0.05060762512896742, 0.046983983500727584, 0.029079418895500045, 0.02409349608102015, 0.0403007392638496, 0.04361641081050038, 0.055573012081107924, 0.07654159316526991, 0.028753810296101228, 0.03466360264324716, 0.04921186163223215, 0.06943575053342751, 0.020414871063881686, 0.01696807941022728, 0.007390434637532702, 0.005932660249527544, 0.0907404880438532, 0.027281294310731546, 0.021250531044123427, 0.07118943785982472, 0.04926233106691923, 0.04448931897059083, 0.08835625169532639, 0.03767832355307681, 0.4044675592865263, 3.178328594991139, 9.098657369613647, 20.922069924218313, 25.29731583595276, 38.00611475535801, 51.628728594098774, 60.35804925646101, 65.93015711648124, 59.22798728942871, 58.90301309313093, 53.78568914958409, 53.42320162909371, 43.39583240236555, 40.50268588747297, 38.98301758084978, 30.05722270693098, 22.214823961257935, 17.308695725032262, 16.976922716413224, 10.7717045545578, 13.63302137170519, 10.463260122707911, 15.016950539180211, 18.062050683157786, 33.93146875926426, 31.436422756740026, 31.54212917600359, 44.63658264705113, 47.26064280101231, 35.83283635548183, 32.07901300702776, 33.91355977739607, 24.447509459086827, 23.888622420174734, 17.012448855808803, 10.189790316990443, 7.447055799620492, 5.449758768081665, 4.551311526979719, 4.264156809874943, 5.406384204115186, 5.477071268217904, 6.276937901973724, 12.066834006990705, 7.005571169512613, 5.9624389835766385, 2.982267366988318, 4.452869015080588, 9.268419231687274, 12.223216244152614, 15.55542550768171, 16.175496646336146, 18.723805802209036, 21.759572778429302, 38.213490690503804, 27.63486875806536, 41.08662639345442, 39.42153576442173, 33.45219244275774, 41.52847971235003, 44.74853549684797, 46.4597031048366, 52.9695120538984, 40.35953910010201, 18.896579708371842, 18.68502790587289, 17.85429607118879, 19.115105765206472, 22.625721318381174, 31.202310153416224, 34.231095927102224, 42.22604063579014, 44.164164202553884, 49.69361359732491, 52.65425838742937, 52.11954934256417, 46.72400563103812, 44.55365937096732, 32.01637847082955, 15.384461607251849, 2.3778351034436906, 0.2888546644576958, 0.042864142784050534, 0.022029146585347395, 0.06315205485693046, 0.06352547981909343, 0.024376460450834463, 0.005790009712135153, 0.02472657264609422, 0.018771888422114507, 0.07979046633200985, 0.07284287842256681, 0.03537298725651843, 0.07030543565217938, 0.020857245361964618, 0.04491695209539362, 0.05208600704957332, 0.05106062528544238, 0.01731818142746176, 0.020016786442803483, 0.016796415139521872, 0.05180125304364732, 0.05301327265000769, 0.05157183017581701, 0.02685059590398201, 0.07940482095416103, 0.05320048046165279, 0.019994879939726422, 0.03727131450016584, 0.04847214989630239, 0.01927354632477675, 0.014688496910301703, 0.07333449739962816, 0.017683577624016573, 0.02980409768809165, 0.08438862673938274, 0.03344458394816943, 0.028219333350924507, 0.014392185756670577, 0.0120010012095528, 0.08081783620374543, 0.050194485512162955, 0.021927542751654983, 0.028693695486124073, 0.0517516623118094, 0.05279256895716701, 0.02511098139387156, 0.05595566172684942, 0.034751075985176225, 0.06369191088846751, 0.0315575169931565, 0.05843834672123194, 0.009253288918573941, 0.02897291603897299, 0.08088724355080298, 0.014141404302790761, 0.026610526821709106, 0.033048346638679504, 0.012849739104110216, 0.018757713825574944, 0.031528431589582136, 0.061796050119612894, 0.034199498261192014, 0.025358948623761535, 0.024397103182439293, 0.019722259836271405, 0.03379930169986827, 0.016535954383601035, 0.060645946833704195, 0.04453211078154189, 0.060377287678420544, 0.024158628657460213, 0.02892654834847365, 0.016201255111289874, 0.02579707189995263, 0.046665509697049856, 0.026659364379676323, 0.076387430009033, 0.041497423978788514, 0.009494080640641707, 0.04482712423694985, 0.053393126731472354, 0.03526432665863207, 0.015145198475303394, 0.040781240444630384, 0.08716945323560919, 0.03407878348869937, 0.06770255496459347, 0.010668154872421707, 0.03759130822228534, 0.034496425185352564, 0.07404115769479956, 0.04885304892169578, 0.02686536930767553, 0.10133699979633093, 0.6182013675570488, 4.0465796164103915, 11.87496384552547, 24.185781240463257, 31.637107576642716, 47.92317090715681, 61.196974754333496, 69.36241436004639, 78.59682042258126, 69.9691241128104, 69.93457072121757, 63.66964408329555, 63.15054416656494, 52.840084484645296, 49.77378191266741, 49.37703282492501, 39.330288546425955, 35.244827679225374, 31.14155510493687, 25.655115059443883, 20.74683461870466, 19.011188507080078, 19.43507204736982, 18.135837078094482, 18.399010522024973, 22.63268515041896, 32.676551137651714, 35.84642355782645, 34.11246933255877, 32.79574401038033, 29.178657736097062, 28.94256489617484, 21.91118941988264, 18.82552742958069, 14.950126239231654, 10.84803399017879, 6.783237499850137, 5.061990227018084, 3.611073694058827, 3.1837766340800693, 2.5832735768386295, 3.2458216590540747, 3.6704493079866682, 4.780850912843432, 7.050649779183524, 5.521409460476466, 4.603371339184897, 3.5733692944049835, 3.827846416405269, 7.500126140458243, 8.039776223046438, 13.967203668185643, 14.358223966189794, 19.07380219868251, 26.117076465061732, 37.419092723301475, 34.24004520688738, 31.1419963155474, 36.70853519439697, 40.02954135622297, 40.18390948431832, 43.17448363985334, 41.9937276159014, 56.02052511487688, 45.895172391619, 26.19678619929722, 25.391653265271867, 24.341797828674316, 29.540012700217112, 28.665243182863506, 37.037438596997944, 43.099005358559744, 49.44276973179409, 51.94110223225185, 56.13362094334194, 59.91038376944405, 59.836691175188335, 55.99083546229771, 57.12106418609619, 42.48379101072039, 20.86159975188119, 3.9175150905336653, 0.3868169364120279, 0.05214267490165574, 0.04997459945401975, 0.0569661089352199, 0.03574423751394663, 0.03850338142365217, 0.035770323792738576, 0.025241046378921186, 0.04924568321023669, 0.0873967692522066, 0.12045296654105186, 0.033863514861358066, 0.025610520570938076, 0.029043385293334723, 0.04965100271095123, 0.07672609362219061, 0.05906333854155881, 0.029283976847571985, 0.013565751308176135, 0.04461978768397655, 0.057292558918041844, 0.03611247507589204, 0.023854227670069252, 0.032199882702635865, 0.09856320292289768, 0.02508825047074684, 0.02450899699968951, 0.06339047849178314, 0.05450064855228577, 0.010879578750713595, 0.009947811070430492, 0.05766079308731215, 0.009915550122968853, 0.02826945503641452, 0.024249971345333115, 0.019472253608650396, 0.03728569604988609, 0.018085177056491375, 0.015480806984539543, 0.04364251744534288, 0.03919537179172039, 0.05852629164499896, 0.03866565985871213, 0.03225371427834034, 0.048421829739319425, 0.011869527416170707, 0.01766500951323126, 0.03542334134025233, 0.08576044134263482, 0.04213597971413817, 0.13712142354675702, 0.21900507541639463, 0.1609637327492237, 0.2673918961414269, 0.16082589514553547, 0.12977568485907146, 0.10075381930385317, 0.20448302823518003, 0.10427383506404501, 0.16422840899654798, 0.14999437278934888, 0.12364176900259086, 0.08634778804012708, 0.11932517348655633, 0.1409793836729867, 0.10058023647538253, 0.17529232959662164, 0.11995535609977585, 0.2600430633340563, 0.14291608546461376, 0.10193462629935571, 0.0956928301602602, 0.1435813619089978, 0.13385187541799887, 0.12653132395020553, 0.09066541492938995, 0.17591453263802187, 0.13797861683581555, 0.14525556564331055, 0.09646554583949701, 0.15693284118814127, 0.14015100098081998, 0.0321518729573914, 0.13582209683954716, 0.17313601316085883, 0.09848109340029103, 0.1665546984544822, 0.09221390648079769, 0.09717418067157269, 0.1622326746582985, 0.17744971811771393, 0.10105092943246875, 0.19654429065329687, 0.2917800731956959, 1.1929387130907603, 5.802497097424098, 16.61816464151655, 30.82193102155413, 40.061485699244905, 58.2297500201634, 71.34324850354875, 79.03040885925293, 86.29379163469586, 78.38030065808977, 80.13654817853654, 74.02878284454346, 71.93429701668876, 60.83679403577532, 58.842758314950125, 55.77262381144932, 45.44259452819824, 35.28947332927159, 31.851775646209717, 28.317873205457413, 18.948679038456508, 22.250070435660227, 18.567005804606847, 23.576629195894512, 27.761433669498988, 46.869782311575754, 42.60487379346575, 43.69822495324271, 60.02220112936837, 62.25934737069266, 46.190206800188335, 41.952806200299946, 42.46801165172032, 30.815486567361013, 30.359809807368688, 20.409409250531876, 12.732419320515223, 9.479459473064967, 7.4670900617327005, 6.029945075511932, 5.787277068410601, 6.682808671678815, 7.403402873447963, 7.992315684046064, 15.333011933735438, 9.214786086763654, 7.863659364836557, 4.536556158746992, 6.312769762107304, 13.046312877110072, 15.687274524143763, 22.236920969826834, 21.25323322841099, 26.33865451812744, 31.176879746573313, 49.86766597202846, 37.55150801794869, 53.62256976536342, 54.66578272410801, 46.382230690547395, 56.42922510419573, 58.91224724905831, 57.82483332497733, 65.81706128801618, 49.74693059921265, 29.189861706324987, 29.35942554473877, 29.48805407115391, 34.12008455821446, 34.42727484021868, 46.6028915813991, 48.930572850363596, 58.82745838165283, 59.81441525050572, 65.34265913282121, 67.51318604605538, 67.65196241651262, 65.00922897883824, 66.50929641723633, 47.92887885229928, 24.51252027920314, 5.017440114702497, 0.8232320685471807, 0.09109796064772777, 0.1526427763913359, 0.11455436662903853, 0.10158191701131207, 0.16666903160512447, 0.18937263690999576, 0.0648212374321052, 0.11798404902219772, 0.1547784110797303, 0.21704659265066895, 0.17048034923417227, 0.15274761005171708, 0.11767397208937577, 0.1840538451714175, 0.21026696929974215, 0.10873535887471267, 0.14647056401840278, 0.08851298649928399, 0.08186085309301104, 0.18104751434709343, 0.09560837290648903, 0.16733949205705098, 0.10588688243712698, 0.18019390372293337, 0.14537160870219978, 0.16152070143393107, 0.20656256164823258, 0.10557319569800581, 0.15058708669883863, 0.1331602582441909, 0.17983926061008657, 0.11253524997404643, 0.15185973340911524, 0.14582822205764906, 0.1433489636651107, 0.12333908810147218, 0.13984637946954795, 0.08458031288215093, 0.14895382576755115, 0.11137224773743323, 0.19326750934123993, 0.10112153100115912, 0.23584305761115892, 0.1988653146794864, 0.08595936066870179, 0.13060182838567666, 0.11985645283545766, 0.18756826301770552, 0.17039429742310727], [0.0161619594520224, 0.03453198381300483, 0.032263135737074275, 0.032548327398087294, 0.021720284230208824, 0.04150964439447437, 0.020208255454365696, 0.059440074754612784, 0.0902914267831615, 0.022001484408974648, 0.021244049338357787, 0.048240090919924636, 0.06580000384045498, 0.04069363818104778, 0.011646637992401208, 0.029390713798680475, 0.028349160848717605, 0.031131933044110025, 0.02622201632974403, 0.049462549787546904, 0.02592339476437441, 0.015823502792045474, 0.01626121555455029, 0.03418648395953434, 0.08490931415664298, 0.061112290381320884, 0.08855005486735276, 0.01829689016033496, 0.06702238467655011, 0.04963656009307929, 0.02303502894937992, 0.02463078046483653, 0.030383329106760875, 0.03237026623849358, 0.002803008654154837, 0.023655360930466225, 0.08724355604499578, 0.01599270398063319, 0.03179294828857694, 0.10776122007519007, 0.00815718260128051, 0.04083842737600207, 0.036812709644436836, 0.665305594248431, 2.7033562532493045, 17.93400580542428, 29.518994399479457, 38.40916933332171, 56.555369649614605, 61.3414625440325, 60.84624358585903, 67.95018604823521, 55.088069915771484, 50.621872084481375, 52.76341111319405, 47.33762536730085, 39.338522161756245, 38.6555837222508, 27.29065499986921, 25.018402985164098, 14.334910154342651, 13.291248168264117, 9.461614762033735, 16.138469696044922, 23.37002103669303, 24.591081823621476, 30.454294885907853, 36.15181425639561, 32.71087176459176, 31.033079828534806, 27.263327734810964, 26.746088198253087, 26.31249976158142, 12.871501411710467, 7.516924279076712, 5.8913441470691135, 3.85302495104926, 1.9066755856786455, 1.8000732830592563, 0.5170691428439957, 0.2538617993039744, 0.11764434725046158, 0.16304725594818592, 0.09944096939372164, 0.11207783594727516, 0.02762250921555928, 0.11455638866339411, 0.1447283575045211, 0.20890607232494013, 0.515654478754316, 0.2820674686559609, 1.041135121669088, 1.1014952084847858, 1.6611922553607394, 4.224676276956286, 5.398727289267948, 10.551566515650068, 15.74703598022461, 17.733023950031825, 15.495738744735718, 17.39675371987479, 28.957876988819667, 25.35522907120841, 23.20426654815674, 33.977476256234304, 54.191853046417236, 52.54823235103062, 44.08243949072701, 36.05683238165719, 40.2691638810294, 54.51512145996094, 48.731652872903005, 29.178011553628103, 20.150904996054514, 14.839648144585745, 17.41261645725795, 25.113238947732107, 30.076090540204728, 43.367487226213726, 49.946962288447786, 48.28792354038784, 46.52076039995466, 57.92931686128889, 54.510170868464876, 47.99164540427071, 24.532532828194753, 6.884747641427176, 1.2480574697256088, 0.3837994911840984, 0.03440373730180519, 0.04564618046528526, 0.013402892725675233, 0.04830852796190551, 0.0577329620718956, 0.09452549887022801, 0.07136316318064928, 0.021717108686321547, 0.012257916620001197, 0.04100765061697789, 0.03376555476071579, 0.020098034225936447, 0.030698583261775117, 0.0035288409562781453, 0.0502461729172085, 0.006866900341784847, 0.044708652022693834, 0.02040508489257523, 0.015053206090150135, 0.03279855075691428, 0.0336847717740706, 0.030407261036868607, 0.018436312143291746, 0.021492386369832923, 0.06845685520342418, 0.07836303899862937, 0.026472789301936115, 0.03316703598414149, 0.09594801361007349, 0.05244092496910265, 0.030912654274808507, 0.017048499380637492, 0.018306465985785638, 0.027074064627023678, 0.05812686522092138, 0.058071523904800415, 0.028775557343448912, 0.02372491585889033, 0.07821927099887814, 0.018584426159837415, 0.008644565823487937, 0.03883477792676006, 0.02675826594765697, 0.05575499856578452, 0.028571952733078172, 0.035416634021592994, 0.008826732968113251, 0.060964186542800496, 0.025101973841499006, 0.024449387698301246, 0.04070106813950198, 0.039796038131628714, 0.028839387132653167, 0.031869113844420226, 0.09794717455016715, 0.09559110419026443, 0.017461869699348296, 0.02171692039285387, 0.0612932149586933, 0.030713812980268682, 0.04786368040367961, 0.01655231725557574, 0.03669116027387125, 0.03767337364011577, 0.009704367972777357, 0.048832160221146684, 0.065950604687844, 0.04482977052352258, 0.02149309034991477, 0.01406721243568297, 0.030257929049964463, 0.05402466641472919, 0.01590127308320786, 0.08680850653243916, 0.040239280954535515, 0.04103934498769896, 0.08814794144460134, 0.04331451701000333, 0.029748115156378065, 0.045978394603090625, 0.03178108071110078, 0.058858828086938174, 0.023752486433035562, 0.012541936959938278, 0.01787601354798036, 0.018707839805366736, 0.04920504914064493, 0.02252757635765842, 0.027168099402583072, 0.10535795760474034, 0.7560889657054628, 3.278512933424541, 19.411807741437638, 35.5370272227696, 46.958809580121724, 67.84954833984375, 71.79189368656704, 70.31761101314, 76.25680610111782, 63.19134398869106, 58.54751546042306, 62.0143677847726, 55.813607760838096, 49.84091540745327, 45.62597138541085, 37.26181329999651, 35.29947873524257, 26.060306208474294, 23.66584059170314, 20.743727036884852, 25.74939169202532, 22.95050617626735, 27.143731866564067, 30.078769070761545, 24.264116968427384, 28.680075849805558, 28.997205529894146, 26.282995973314556, 21.234525203704834, 17.525074788502284, 10.765461598123823, 6.233757453305381, 4.545839820589338, 3.1419046180588857, 2.0437635438782826, 1.0073908695152827, 0.44661842605897356, 0.06199154284383569, 0.03672225753377591, 0.11569625964122159, 0.05578543764672109, 0.14709797820874623, 0.0949302450088518, 0.08898011714752231, 0.19898080133966037, 0.291670666209289, 0.49912189160074505, 0.16328520460852555, 0.5179809310606548, 0.5860372334718704, 0.9617805055209568, 3.006282946893147, 3.303768332515444, 7.179161923272269, 10.156075051852635, 11.232830439295087, 12.15938401222229, 14.199532321521215, 22.8787225995745, 22.832762002944946, 21.864916154316493, 32.984272956848145, 50.507952894483296, 48.680020809173584, 44.620469774518696, 33.75076001031058, 35.55974088396345, 50.42092323303223, 49.65330014910017, 39.000395025525776, 28.14233044215611, 25.93967158453805, 29.866946288517543, 34.20741646630423, 34.98329401016235, 49.992976733616416, 58.02195719310215, 56.68636056355068, 53.69610949925014, 64.81520748138428, 63.19471386500767, 57.15231718335833, 34.07395894186837, 11.17161680970873, 2.9856259524822235, 0.47006941054548534, 0.01000338139212025, 0.022838355574224676, 0.06553338029022727, 0.02324002794921398, 0.019494007441348264, 0.03077002282121352, 0.04345748094575746, 0.03268752885716302, 0.04399843281134963, 0.08872122889650719, 0.02445270403820489, 0.030720615293830633, 0.04351613351276942, 0.05888774046408279, 0.019303993887401054, 0.0223768262325653, 0.025918675553319708, 0.009996058302931488, 0.024623065521674495, 0.07639502281589167, 0.016476574087781564, 0.02923000617218869, 0.02266166844804372, 0.02059161925821432, 0.03861328713329775, 0.04959815501102379, 0.03888976301199623, 0.045878836552479436, 0.009673709216128503, 0.05370700006772365, 0.01259322911833546, 0.02580040689956929, 0.008262075633475823, 0.03841056801112635, 0.07134592160582542, 0.033510317028101, 0.03131707471662334, 0.03246912879071065, 0.06294983785067286, 0.038791538282696686, 0.03864832668166075, 0.03670223396537559, 0.04956936816285763, 0.033633352390357425, 0.022785445109808018, 0.09301844545240913, 0.024733252823352814, 0.07737733796238899, 0.09874795443777527, 0.14240316727331706, 0.1757843896214451, 0.07809247994529349, 0.17268611730209418, 0.11527361374880586, 0.12798583161618027, 0.2059226217014449, 0.12915481174630777, 0.13281431395028317, 0.17288111469575337, 0.11401964032224246, 0.16058953425713948, 0.15948238223791122, 0.1221338470599481, 0.08075687661767006, 0.17495360491531237, 0.1290096188230174, 0.17806687285857542, 0.13336529795612606, 0.15840349798755987, 0.13041433558932372, 0.13456034740167006, 0.23323449758546694, 0.12811582535505295, 0.17989358412367956, 0.09910334393914257, 0.20192191137799195, 0.14204545718218597, 0.11483156175485679, 0.10847590065428189, 0.10260298329272441, 0.092878646882517, 0.1439085786363908, 0.13776958733797073, 0.10144694961075272, 0.1963552643678018, 0.1073605315759778, 0.2820607104471752, 0.12942523509263992, 0.15176566131412983, 0.36804569938353127, 1.4869144984654017, 6.272348182541983, 26.42087255205427, 45.761231967381065, 60.49132265363421, 81.49317005702427, 84.02223096575055, 80.80201884678432, 86.17843764168876, 73.68839754377092, 68.2560179574149, 69.53994083404541, 62.858768463134766, 55.4559006009783, 54.203498227255686, 41.79766682216099, 40.094680718013215, 24.184360333851405, 22.806544712611608, 17.23159156526838, 25.66755407197135, 32.55623613085066, 33.890457017081125, 40.98293495178223, 49.67904322487967, 44.32519565309797, 41.66060318265642, 36.11350883756365, 35.877909319741384, 31.580962657928467, 16.07860401698521, 9.995534317834036, 7.541140488215855, 5.227508042539869, 2.7803155864988054, 2.5310237748282294, 1.0441889635154178, 0.8608716002532414, 0.24040764410580906, 0.5719638743570873, 0.3487817645072937, 0.35824716516903465, 0.17726487160793372, 0.29207808577588623, 0.3097500689327717, 0.5134917433772768, 0.9107443583863122, 0.5971832296677998, 1.323270090988704, 1.4457292684486933, 2.2181157767772675, 5.812624965395246, 6.551022623266492, 13.52605038029807, 19.477080856050762, 22.491822583334788, 20.65550923347473, 24.06156655720302, 36.44461481911795, 32.55441222872053, 31.521621567862375, 44.169285024915425, 62.769095012119834, 61.50974791390555, 57.083509172712056, 49.134669235774446, 52.92167370659964, 67.32316671098981, 58.71936525617327, 41.365558351789204, 31.152314390454972, 28.055952174322947, 29.627007620675222, 37.82226889474051, 43.875188623155864, 59.3587315423148, 65.23834582737514, 63.598584856305806, 62.183598109654014, 75.37618446350098, 70.72521318708147, 63.90084539140974, 39.400639057159424, 13.607775960649763, 3.736145828451429, 0.5855822893125671, 0.12033814484519617, 0.13704124784895352, 0.15606134438088962, 0.1722649506160191, 0.18061942660382815, 0.11936104084764208, 0.17248626159770147, 0.18386380108339445, 0.22728120775095054, 0.2483504664685045, 0.10189368349633046, 0.09824035596102476, 0.19436419835048063, 0.13859225676528045, 0.12087633168058735, 0.09905266415859972, 0.1033846013514059, 0.11495413232062544, 0.07672471619610276, 0.0917017346780215, 0.07135749062789337, 0.11161095635699374, 0.11228373739868402, 0.1142484966133322, 0.12096319773367473, 0.11833247675427369, 0.12916015860225472, 0.1254079006612301, 0.11442647634872369, 0.12755158277494566, 0.09839477696056877, 0.05623688056532826, 0.16462446988693305, 0.12156617109264646, 0.15363083194409097, 0.19013773942632334, 0.09267087945980684, 0.1694757102855614, 0.17269394759620937, 0.12482897458331925, 0.12435512643839632, 0.10468010790646076, 0.08263699537409203, 0.16692764844213212, 0.1376057347016675, 0.20314543215291841, 0.06908618286252022], [0.04392990755981632, 0.012480062199756503, 0.041590139003736634, 0.004614371881221554, 0.012081643400181617, 0.03978346148505807, 0.038156375222440274, 0.0439877051727048, 0.0687120250825371, 0.04750650974788836, 0.004679157980717719, 0.024003953207284212, 0.020162193104624748, 0.038527669584644694, 0.042672314148928435, 0.0226266865751573, 0.014493823517113924, 0.055980482537831576, 0.08469606417098216, 0.05730002958859716, 0.02458108795274581, 0.06007734127342701, 0.005341163462227476, 0.021341972119574035, 0.04399682129068034, 0.030644310638308525, 0.020577921332525353, 0.028508991468697786, 0.026209802699408362, 0.012182321033573576, 0.012765032488719692, 0.02552207692393235, 0.041598668188921044, 0.021029598345713954, 0.021769109913813214, 0.04351933280538235, 0.012168250761793127, 0.019994216671745692, 0.03333854928080525, 0.011091053519131882, 0.05160368060959237, 0.07864750801984753, 1.043453648686409, 4.614106740270342, 17.390340532575333, 35.71097537449428, 48.001115798950195, 63.07649026598249, 63.831432887486045, 59.62491703033447, 60.67592239379883, 54.41510214124407, 57.51209838049752, 41.31750808443342, 32.98749344689505, 38.95315769740513, 25.78844404220581, 25.902743646076747, 14.98353317805699, 14.85295741898673, 13.096416337149483, 21.129449333463395, 24.400873150144303, 27.150997945240565, 38.962628092084614, 39.8772611618042, 41.608415263039724, 31.504021780831472, 22.3745630468641, 14.96801437650408, 12.104205761637006, 10.206710917609078, 3.737521137510027, 2.1086586330618178, 0.6697617237057004, 0.693020438509328, 0.3035413920879364, 0.11345887184143066, 0.0031956412463581985, 0.06965258996933699, 0.15493340204868997, 0.01345495247681226, 0.026164164434054067, 0.12637448736599513, 0.015012762010363596, 0.10750919181321349, 0.13704960740038327, 0.05539155485374587, 0.10841426931853805, 0.04002763909686889, 0.029348542847271477, 0.08137297962925263, 0.08304372962032046, 0.054287334105798175, 0.027928092550220232, 0.15875719115138054, 0.19883501130555356, 1.137170734150069, 1.355615258216858, 3.302986443042755, 5.122547251837594, 3.334000378847122, 5.191064740930285, 10.55873531954629, 10.889736209596906, 12.130012239728655, 20.566164084843226, 28.839615174702235, 44.03598383494786, 59.691557203020366, 57.89324181420462, 43.05513790675572, 26.212956394468033, 20.33699859891619, 11.112832444054739, 12.86946906362261, 14.30141202041081, 21.360963310514176, 30.819311550685338, 37.37992920194353, 45.13285078321184, 41.10630716596331, 46.83875165666853, 49.442123549325125, 49.43529347011021, 51.424104145595, 39.813132762908936, 17.262467622756958, 4.271652179104941, 0.7390067651867867, 0.06169344883944307, 0.028663761913776398, 0.06365916478846755, 0.041179903516811986, 0.01552314417702811, 0.04720238017450486, 0.08645148176167693, 0.0727442940697074, 0.034859034299318276, 0.03089234232902527, 0.03729997242667845, 0.04721678886562586, 0.02712793182581663, 0.0298982545999544, 0.029120429552027156, 0.045887063789580546, 0.06605224244828735, 0.04630813208807792, 0.011742515838705003, 0.0391015371839915, 0.07660347555897065, 0.023962620246623243, 0.08261374197900295, 0.027094162834276046, 0.008208546854023422, 0.04536047311765807, 0.04196739090340478, 0.03790153782548649, 0.06610716985804693, 0.04205888456531933, 0.0854185139760375, 0.032719206264508624, 0.010976880672387779, 0.03461915859952569, 0.017945638026243875, 0.037396439750279696, 0.052138841178800376, 0.008891494046630604, 0.04853854115520205, 0.06604841551078217, 0.05643357429653406, 0.04622104551110949, 0.007271842831479651, 0.022386654812310423, 0.032220388030899424, 0.08635628329856054, 0.006335934391245246, 0.02208447772344308, 0.013048079979073788, 0.053223808495593924, 0.007064843001509351, 0.018429927128766264, 0.025252408447808454, 0.03964125411584973, 0.038076386121766906, 0.0816167840468032, 0.09322773957891123, 0.015038563304447701, 0.04267646339056747, 0.016030605250437344, 0.030297009274363518, 0.04264017873044525, 0.042928498437894244, 0.10395579213010413, 0.0007285416712485519, 0.04338288280580725, 0.025920531346595714, 0.012987792142666876, 0.03165798767336777, 0.06321660389325448, 0.018474201538733075, 0.011914423533848353, 0.06960590676005397, 0.01579393902128296, 0.01044323408444013, 0.023805680185822502, 0.021630619220169525, 0.05830445819135223, 0.033480753257338486, 0.006712417001836002, 0.021731407115502015, 0.037424185047192235, 0.028997217770665884, 0.041321761440485716, 0.08087210543453693, 0.07051650754043035, 0.028079894404592257, 0.127816591411829, 1.2611257284879684, 5.4747353707041055, 20.93915207045419, 42.30173431124006, 57.341714654650005, 72.00475869859967, 71.07659748622349, 68.50246361323765, 68.096987588065, 63.63782828194754, 66.98706150054932, 49.680610043661936, 42.57625068937029, 48.61303670065743, 36.40489544187273, 37.96076386315482, 25.301816531590053, 26.006690434047155, 17.91072586604527, 25.965108939579554, 23.73947933741978, 30.8928929737636, 36.10195745740618, 33.05461999348232, 28.303092650004796, 26.891630377088273, 18.641189983912877, 12.18873928274427, 9.500216347830635, 6.583707383700779, 2.4400312517370497, 0.9487575186150414, 0.4653196654149464, 0.39747533734355656, 0.22113123775592872, 0.020571907815922583, 0.06474439334124327, 0.037945829198828766, 0.19221743568778038, 0.092601424615298, 0.03463503292628697, 0.14095380290278367, 0.03274840023368597, 0.03870391905573862, 0.10614849161356688, 0.027455185872635672, 0.09123471938073635, 0.05972777360251971, 0.06021051734153714, 0.035783002219562016, 0.01598667010797986, 0.0651803385200245, 0.028027806663885713, 0.16824346355029515, 0.1390688597623791, 0.7659739181399345, 1.491013609937259, 2.823355551276888, 3.8733006630625044, 2.642498935971941, 4.241660279887063, 7.342395952769688, 10.051429101399012, 11.803370475769043, 18.86330304827009, 32.493632861546104, 46.09741013390677, 60.107358251299175, 61.80966690608433, 50.43175547463553, 29.82691424233573, 28.53579650606428, 17.39720708983285, 17.126579965863908, 21.070638043539866, 33.61306408473423, 40.77408252443586, 44.64962094170706, 52.548895903996055, 49.91454199382237, 53.6305046081543, 56.137817655290874, 57.22833047594343, 60.52921118055071, 49.92823689324515, 25.71394545691354, 7.960611053875514, 1.625913211277553, 0.07544018155229942, 0.030270919602896487, 0.012706022842654159, 0.03686311801097222, 0.00989955450807299, 0.023382730648985932, 0.04212031912590776, 0.04245250951498747, 0.05182353613365974, 0.027162433635177355, 0.009868328326514788, 0.044016532732972076, 0.022736514253275733, 0.008673256828582712, 0.0038453207151698215, 0.03495698422193527, 0.004452500991257173, 0.051876882556825876, 0.018570466998166273, 0.04233239524598632, 0.06091604448322739, 0.054311764759144614, 0.025676155263291936, 0.023561336332932115, 0.04294602499742593, 0.022149908855291348, 0.11639068595000676, 0.0329498979928238, 0.035964188032916615, 0.034302930746759684, 0.029154386837035418, 0.031200471866343702, 0.024820514123088548, 0.05086983820157392, 0.02606094568701727, 0.04297389243064182, 0.11624113683189664, 0.013360581826418638, 0.02760862130006509, 0.05087375334863152, 0.007868288683571985, 0.04672732762992382, 0.03986985934898257, 0.02468120409840984, 0.017522846248799136, 0.06444051143314157, 0.16461468541196414, 0.12156735174357891, 0.1197388084339244, 0.10862461517431907, 0.12502842316670076, 0.1515200859201806, 0.08925564986254488, 0.18885137273796967, 0.11398048885166645, 0.17245950017656597, 0.17671844735741615, 0.14226653746196202, 0.12156585896653788, 0.12323144530611378, 0.10679776820221118, 0.16169222151594503, 0.14943897830588476, 0.17891221892620834, 0.1583935370934861, 0.15659308513360365, 0.23241821995803288, 0.20223060409937585, 0.11812545572008405, 0.14469832554459572, 0.1354040785559586, 0.10333924128540925, 0.12035429397864, 0.13208087187792572, 0.19339837160493645, 0.10729112422892026, 0.09140035656413861, 0.1620459146797657, 0.1484149739678417, 0.07854975826506104, 0.07610256743750402, 0.11904210224747658, 0.10578795203140803, 0.15868996190173285, 0.12098561653069087, 0.14612186487231935, 0.15023681335151196, 0.44503985505018917, 2.227309763431549, 8.62051968915122, 29.91330119541713, 53.236326353890554, 68.31477192470005, 84.24426065172467, 79.1781553540911, 76.86631597791398, 77.84576184409005, 71.4776336124965, 74.01348985944475, 58.05256748199463, 46.739989961896626, 53.02699102674212, 38.92056022371565, 40.20508411952427, 27.316969564982823, 26.930550711495535, 24.370016200201853, 29.182982989719935, 34.51228952407837, 37.54409429005214, 53.17927816935948, 49.905655247824534, 51.66656848362514, 39.780048915318076, 27.71445516177586, 19.092046431132726, 15.428733791623797, 12.798958744321551, 4.323157872472491, 2.756018170288631, 1.0482526826007026, 0.9660915370498384, 0.6359539606741497, 0.2758023648389748, 0.1691231434898717, 0.16884726472198963, 0.2845742484288556, 0.2607161429311548, 0.24422937046204293, 0.3260881065257958, 0.1803919816655772, 0.23602395504713058, 0.2681500368884632, 0.15336571474160465, 0.2868304316486631, 0.14407233627779142, 0.3331972264817783, 0.20183606312743255, 0.19194394536316395, 0.24519943126610347, 0.15023802114384516, 0.46782812795468737, 0.3694646789559296, 1.7908807077578135, 2.1184545074190413, 4.394168896334512, 6.212811674390521, 4.795082994869777, 7.219089312212808, 13.569316812923976, 13.071739809853689, 15.011522259031024, 24.775467906679424, 36.90507541384016, 52.566829204559326, 66.93253898620605, 65.3453619820731, 54.76471812384469, 37.22146511077881, 31.936536720820836, 20.805718864713395, 22.59587185723441, 25.314293759209768, 35.66844892501831, 45.56864179883684, 49.739304951259065, 58.98487676892962, 57.1292005266462, 63.61796338217599, 64.23439366476876, 66.0858176095145, 68.7919533593314, 56.02838352748326, 31.909060069492885, 9.37761104106903, 1.5899043892111098, 0.10241701041481324, 0.20829806423613004, 0.1601107870893819, 0.19374156104666845, 0.15819936751254968, 0.14322561956942081, 0.12585699584867271, 0.17209017356591566, 0.19140892050095967, 0.11713810584374837, 0.16567280649074487, 0.1481901074626616, 0.1240489442965814, 0.12915808228509768, 0.180521907550948, 0.12070825855646815, 0.13001062082392828, 0.1815312962446894, 0.11914209116782461, 0.15269928478768893, 0.19387604668736458, 0.21495860469128403, 0.15357299361910137, 0.09681383786456925, 0.08443957793393306, 0.1274769167814936, 0.1662493712667908, 0.07246554509869643, 0.18228170169251307, 0.11356000748596021, 0.20904594553368433, 0.09023951206888471, 0.12081197941941874, 0.09904347000909702, 0.21020713608179772, 0.16943513389144624, 0.18395145423710346, 0.10681440588086843, 0.09909412943358932, 0.0854375943807619, 0.1645460855215788, 0.1515969503670931, 0.1272677651473454, 0.12924474477767944, 0.08928828061159168, 0.1363199379827295], [0.004970191828241306, 0.052203610739005465, 0.0047158658770578244, 0.05854689196816512, 0.09260728037250893, 0.03168035897293261, 0.01735215906852058, 0.04412375144394381, 0.047428010031580925, 0.05742062561746154, 0.060500496067106724, 0.028325027054441825, 0.0579500864925129, 0.024502342267494117, 0.03703219536691904, 0.02047841756471566, 0.0762715090864471, 0.016520064789801836, 0.017379548134548322, 0.0422637308947742, 0.03967180854773947, 0.022262411657720804, 0.07134626765868493, 0.015579372677685959, 0.007965107997214156, 0.009225417244514185, 0.02425332330832524, 0.04357403629858579, 0.029918814211019447, 0.019967794518119523, 0.03933079381074224, 0.058745051335011206, 0.037062339285122495, 0.04043256504727261, 0.040552876091429164, 0.01029099796765617, 0.016579285629891923, 0.02185462398587593, 0.0077381380334762585, 0.032713777984359434, 0.05548510108409183, 0.9447854288986751, 6.063089719840458, 18.884317874908447, 37.54268033163888, 58.6362578528268, 68.5014283316476, 66.99616364070347, 64.45192786625454, 53.222975390298025, 49.56807701928275, 51.207789352961946, 41.7885160446167, 32.00932257516043, 25.43062744821821, 15.84655329159328, 14.754456281661987, 12.031152401651655, 13.964249815259661, 20.153015511376516, 28.71061839376177, 36.8375597681318, 45.22221156529018, 36.31725433894566, 22.760155064719065, 28.917349883488246, 16.471007006508962, 6.093740829399653, 6.358058989048004, 2.9430437002863203, 0.46918042110545294, 0.570355692080089, 0.11587274659957204, 0.0436349789212857, 0.07828319578298501, 0.003718888012891901, 0.0659248000010848, 0.11557586038751261, 0.10585079794483525, 0.06386616546660662, 0.041139679960906506, 0.04842458459149514, 0.058623437503618855, 0.05762880016118288, 0.03130921728110739, 0.0377886737031596, 0.0508237588884575, 0.041381808396961005, 0.025719184561499527, 0.023996450306315507, 0.022007095893578868, 0.06129438203892537, 0.02662221628374287, 0.03822947719267436, 0.015291426164497222, 0.06708744261413813, 0.15033582518143312, 0.05203233492959823, 0.06463151225554091, 0.03934492430250559, 0.09833126608282328, 0.572459584900311, 0.7046610053096498, 0.5450644120573997, 0.5798852550131934, 2.4295045137405396, 3.729338765144348, 5.916571753365653, 10.48527809551784, 16.449709040778025, 24.810307911464147, 30.393122945513042, 34.86559847423008, 25.635013920920237, 34.71687923158918, 54.046441146305625, 19.697581938334874, 10.184604355267115, 18.72936957223075, 17.098627362932476, 28.777988127299718, 33.12362950188773, 38.30445303235735, 45.09727600642613, 53.633624349321636, 51.107526847294395, 56.33479561124529, 51.92910269328526, 31.96712269101824, 17.73486695970808, 2.2499578510011946, 0.283660071768931, 0.11762557897184577, 0.05542405668113913, 0.018071769204522883, 0.025407250139064023, 0.07978641547794853, 0.027525353178914105, 0.07762781237917286, 0.014310941366212708, 0.01678180797690792, 0.06461262862597193, 0.009449026763572224, 0.03271670925563999, 0.020028464030474424, 0.03930191536034856, 0.010953025077469647, 0.05580968848828759, 0.01492543624980109, 0.03539002527083669, 0.05917943588324955, 0.0034398786540675375, 0.03176237689331174, 0.02820572872380061, 0.03127173161400216, 0.043701760337821076, 0.0262685706173735, 0.03456371211047683, 0.03565944777801633, 0.027602580642061572, 0.07530290034732648, 0.032955370377749205, 0.02088566410488316, 0.04812072982479419, 0.045927378947713544, 0.04717820057911532, 0.03699825504528625, 0.05297799561438816, 0.02258150462460305, 0.047501793929508755, 0.04527028224297932, 0.033645009621977806, 0.022765240033290217, 0.04790776821651629, 0.03688265642683421, 0.03015558222042663, 0.03520234587735363, 0.037936580766524584, 0.003984496305097959, 0.008522343855085117, 0.024532610018338476, 0.00897893006913364, 0.02690251401093389, 0.022028761516724314, 0.03539653242166553, 0.1067957936653069, 0.03962717451421278, 0.02122570514412863, 0.059456407092511654, 0.048397992804114304, 0.00177418915596458, 0.05083786223882011, 0.07569933443197183, 0.03585316952584045, 0.003745192695142967, 0.06739837450108357, 0.06230195904416697, 0.05821713073445218, 0.01997444755397737, 0.030415515415370464, 0.03666762528674943, 0.05012346325176103, 0.04357134929991194, 0.04066569610897984, 0.028360042854079177, 0.029916524155331508, 0.061536259417022975, 0.044673822820186615, 0.016434092706601535, 0.0036618032858573963, 0.04428585345989891, 0.04522182127194745, 0.03799577276887638, 0.01921035266215248, 0.07555216697177716, 0.04817256311486874, 0.22178461269608565, 0.8788528868130275, 7.51918591771807, 22.2293370110648, 43.27768523352486, 64.58303342546735, 77.4061632156372, 75.16770376477922, 74.1833802631923, 59.38150773729597, 60.25058841705322, 60.87275096348354, 50.21612855366298, 42.75703239440918, 34.558529785701204, 28.911214624132427, 20.505009514944895, 21.107013600213186, 20.585646833692277, 24.230831623077393, 30.688754899161204, 31.14528281348092, 34.40633644376482, 24.245577437537058, 21.557477474212646, 20.144123554229736, 13.038697651454381, 6.044545412063599, 4.601629078388214, 2.310553525175367, 0.6763259257589067, 0.4426877541201455, 0.08435117839170353, 0.04349790466949344, 0.017676580231636763, 0.05730332048343761, 0.10213469913495438, 0.06963684795690434, 0.12429796664842538, 0.2300961102758135, 0.05542979708739689, 0.1134718522163374, 0.12720414570399693, 0.10944238557879414, 0.036310183216950724, 0.0526233898209674, 0.03342541194121752, 0.10976921554122653, 0.06040222384035587, 0.16318468643086298, 0.08181839037154402, 0.13944474102130958, 0.11227156448044948, 0.03161134517618588, 0.32981152672852787, 0.08303791457521063, 0.17972162977925368, 0.12298140515174184, 0.0442591022167887, 0.024906735567908202, 0.06302447670272418, 0.5658041877405984, 0.281407362648419, 0.4334986257765974, 0.560279012790748, 1.8060395057712282, 3.899491463388715, 6.352871290275028, 11.331593871116638, 19.386999198368617, 24.25818841797965, 32.860473428453716, 34.4587710244315, 28.18309552328927, 36.32810395104544, 54.849843978881836, 28.700797115053447, 16.230835574013845, 26.945091554096766, 27.0198871748788, 37.089890548161094, 43.16498892647879, 47.28157424926758, 53.54524326324463, 62.62671252659389, 58.096931729997905, 64.01940945216587, 62.4340181350708, 44.73851272038051, 26.313620158604213, 5.428805606705802, 0.5984790144222123, 0.10265799891203642, 0.010724151823004442, 0.019208310271746347, 0.020103815344295332, 0.09185394365340471, 0.05277498811483383, 0.010086263596479381, 0.019878200754257183, 0.054333555911268504, 0.03791317130838122, 0.015546816567491208, 0.030576501241219894, 0.09083378660891737, 0.010598808593515838, 0.023623678434107984, 0.05414203940225499, 0.035590596829674075, 0.046353933201836686, 0.045310926490596364, 0.06607049504028899, 0.04124238980667932, 0.018571535690820644, 0.02366531334285225, 0.019469972034650188, 0.058646616259855885, 0.042473269293883016, 0.011820077480349158, 0.07124725582876376, 0.056778643280267715, 0.03597418963909149, 0.011088973809299725, 0.04582612116688064, 0.02892928962994899, 0.021974556746759584, 0.019018596969544888, 0.023275761299633553, 0.03423909756488033, 0.0298131595232657, 0.022812642489692996, 0.013524766096712222, 0.06379899049976043, 0.028656138572841883, 0.032260499628526826, 0.007068217016889581, 0.12101134657859802, 0.13244121468492917, 0.09255869047982351, 0.12292263044842652, 0.1532834084438426, 0.2041077305163656, 0.1020453767850995, 0.14676746380116257, 0.16803313126521452, 0.21142761701984064, 0.09027437519814287, 0.06998438002275569, 0.16913583209472044, 0.1451252190662282, 0.10506889490144593, 0.16062716580927372, 0.1293939139161791, 0.13879576298807347, 0.14963301217981748, 0.17912294476159982, 0.1368539857545069, 0.1532381772994995, 0.15869241819850036, 0.14393919413643225, 0.1805930994451046, 0.10491190903953143, 0.12551972323230334, 0.14298243261873722, 0.1031758568382689, 0.13764135779014655, 0.1580906526318618, 0.12398119936031954, 0.18455592037311622, 0.14268211301948341, 0.13842330154563698, 0.10160878699805055, 0.11322816314974002, 0.12017615139484406, 0.11422366223164968, 0.10927283324833427, 0.52857335124697, 1.7717970460653305, 11.208469186510358, 31.32976790836879, 55.20777348109654, 76.93298394339425, 86.80638108934674, 82.87303365979875, 83.06400489807129, 68.39693437303815, 64.18766702924455, 65.76337950570243, 54.4523549079895, 45.68330097198486, 38.38305105481829, 28.31430356843131, 24.91996611867632, 22.41264091219221, 22.720948117119924, 29.72767312186105, 41.66534880229405, 50.77413838250296, 58.1808624948774, 47.15587786265782, 31.537084783826554, 35.59079238346645, 20.933927025113785, 7.767227922167097, 8.42159971169063, 4.091824548585074, 0.8689992555550167, 0.7404930282916341, 0.30628340638109613, 0.1127958684893591, 0.160517582403762, 0.13963722783539975, 0.12665422021278314, 0.25957036869866507, 0.48122273491961615, 0.2772560311215264, 0.22937319906694548, 0.14505102804728917, 0.2857613318732807, 0.21417355324540818, 0.12365015569542136, 0.12399911268481187, 0.20728294870683125, 0.45230856644255774, 0.13744131209594862, 0.12361814241324152, 0.1281218778874193, 0.13031517448169844, 0.17041651265961782, 0.179583412195955, 0.247824276132243, 0.23330300248094968, 0.41384209053856985, 0.2116865459829569, 0.17910314510975564, 0.15526501568300383, 0.29594861237066133, 1.110865831375122, 1.1570040413311549, 0.87062399408647, 0.8569519477231162, 3.4687895689691817, 4.713888951710292, 7.62937913622175, 14.159495064190455, 22.924471276147024, 33.28412594114031, 42.614114897591726, 45.613079002925325, 36.749859605516704, 45.28338003158569, 65.24457141331264, 30.050083432878765, 19.56783822604588, 30.77441576548985, 28.34980365208217, 42.99992404665266, 46.43771205629621, 52.524980204445974, 61.58552496773856, 71.11077567509243, 67.74426228659493, 73.86493042537144, 70.67235129220145, 54.35728965486799, 30.938674654279435, 6.711476070540292, 0.783214515873364, 0.2631013292287077, 0.10696610595498766, 0.0997121391285743, 0.20803468408329145, 0.1624775579465287, 0.15610725406025136, 0.1849837095609733, 0.08550666246031012, 0.11439563014677592, 0.12906633077987603, 0.1411856176065547, 0.12178125312285763, 0.14617929607629776, 0.05814866655107055, 0.118956647547228, 0.16776752551751478, 0.08191832500909056, 0.12732827690030846, 0.06808264992598977, 0.18066613695451192, 0.15162411890923977, 0.11169520326490913, 0.11006191519222089, 0.1610378830560616, 0.10819135020886149, 0.10558591144425528, 0.06747933729950871, 0.17284201750797884, 0.12172299410615649, 0.19246770654405865, 0.1181156983865159, 0.1500832744474922, 0.13950325788131782, 0.10026634617575578, 0.0928479228168726, 0.10016039293259382, 0.07479711355907576, 0.11513971164822578, 0.1502516868391207, 0.15427853433149202, 0.13563457690179348, 0.11319821939936706, 0.1360148007848433, 0.07215708986456905], [0.045001131149807146, 0.03452957501368863, 0.0332115580593901, 0.036121889749275785, 0.015566986020920532, 0.016578359429591467, 0.019278525075476085, 0.0290055433953447, 0.008621618617326021, 0.055720091331750154, 0.023508634518033693, 0.04362986955259528, 0.041932130831160715, 0.02795968683702605, 0.039732401724904776, 0.027216765630458082, 0.05480443885815995, 0.01909081175524209, 0.03188878457461085, 0.01328406173602811, 0.03537615940773061, 0.03943594977525728, 0.01056893015213843, 0.11300803281899009, 0.07251158369971172, 0.02472735126502812, 0.017325261940381358, 0.0464852568693459, 0.03441643947735429, 0.029868812965495244, 0.05192775232717395, 0.03271540646840419, 0.024262346127735715, 0.07275958824902773, 0.08666479960083961, 0.03912561160645314, 0.03385248527462993, 0.0393413077108562, 0.038178393683795414, 0.1249626866940941, 0.6684492198484284, 7.011766791343689, 18.180844034467423, 37.49955286298479, 55.620486055101665, 67.52557468414307, 63.60698522840227, 63.733762059892925, 54.71609810420445, 46.50307723454067, 39.60275173187256, 28.65534199987139, 31.011154787881033, 20.029822213309153, 17.780914408820017, 20.37406897544861, 35.47756453922817, 37.93067816325596, 28.95802116394043, 40.6954983983721, 34.86664070401873, 34.29240335736956, 24.250059025628225, 23.37091040611267, 12.617946011679512, 8.198356696537562, 2.1599780278546468, 1.464355543255806, 0.19189195601003511, 0.016780841064506342, 0.02827386381769819, 0.04196035788793649, 0.04472667391278914, 0.05062544345855713, 0.062496352541659556, 0.05303446329864008, 0.05117973871529102, 0.08058813852923256, 0.08682000091565506, 0.09113783136542354, 0.0642557463475636, 0.05901488435587712, 0.016911296207191687, 0.017611766566655467, 0.06917513201811484, 0.04779155213119728, 0.024922514899766872, 0.08756109686302287, 0.08260013735187904, 0.2922026105225086, 0.06223652112696852, 0.057353131739156585, 0.08918590324797801, 0.08555921499750443, 0.11320796316223485, 0.07500053835766655, 0.15029143542051315, 0.03468885771664126, 0.04057731353012579, 0.10779110275741134, 0.06026961774166141, 0.0877216789605362, 0.05771310135189976, 0.027655523336891617, 0.16638254054955073, 0.10397457397942032, 0.0881241587921977, 1.139282877956118, 3.88039607661111, 9.068351932934352, 15.041257074901036, 18.206208433423722, 30.099971498761857, 33.20162650517055, 35.5693849836077, 34.67181321552822, 28.672962631498063, 31.337789603642054, 17.29012840134757, 14.99747473852975, 17.4165369783129, 14.748171636036464, 25.845344577516826, 35.492881843021934, 30.754429272242955, 41.61016968318394, 56.23430381502424, 56.327381883348735, 62.122912543160574, 52.43599115099226, 35.03008665357317, 12.262710673468453, 1.2750543696539742, 0.10546575646315302, 0.08923369246934142, 0.08554661460220814, 0.03952513302543333, 0.04711864556052855, 0.036685609857418706, 0.03586387002308454, 0.021919157755162035, 0.046136737535042424, 0.08533012800450836, 0.05291740922257304, 0.031115923010345017, 0.013887086833295013, 0.027711203920521905, 0.005485548928845674, 0.04995964454220874, 0.059957077726721764, 0.04297016388071435, 0.06913960392453841, 0.02755454714809145, 0.015612727762865168, 0.024325509256284152, 0.03721789683082274, 0.013312589044549634, 0.007613212951192898, 0.03376255563593336, 0.027074549779562012, 0.013229493949828404, 0.06832284453724112, 0.057587931997009685, 0.03206104765247021, 0.04676608894286411, 0.04707995888644031, 0.04098460078239441, 0.025676643808505366, 0.13069587333926133, 0.054930853324809244, 0.02592951345390507, 0.046807272625820975, 0.0394768552588565, 0.04412792443430849, 0.030541526153683662, 0.027135053050837347, 0.045495043575231514, 0.03476093849167228, 0.08380201285971062, 0.021007067590419735, 0.051581824996641705, 0.008551549698625292, 0.01311956618779472, 0.04463320571397032, 0.019993468586887633, 0.009116891505462783, 0.056759430561214685, 0.06705212486641747, 0.028936044446059635, 0.0319042212462851, 0.037749016723994694, 0.03922070828931672, 0.11718482976513249, 0.00767820727612291, 0.03011689893901348, 0.04023972539497273, 0.07323826077793326, 0.01649422787262925, 0.03288494183548859, 0.047647974121251276, 0.014168504143266805, 0.05709516629576683, 0.03381100982161505, 0.06879161045487438, 0.012732962379232049, 0.023036167191873704, 0.03515894677756088, 0.031851977442524264, 0.058796090739113946, 0.028124255327773944, 0.041566210466303995, 0.032835286642823897, 0.0330011070306812, 0.0592469365469047, 0.017274853573845964, 0.10164567216166429, 0.9857061931065151, 7.666469488825117, 20.961283820016043, 42.79749870300293, 64.86306667327881, 77.05070032392229, 72.63405704498291, 71.17195456368583, 62.88073866707938, 56.36594091142927, 47.415893350328716, 36.830587250845774, 39.64426374435425, 26.401408910751343, 30.264820984431676, 26.170016527175903, 31.948564052581787, 42.62826837812151, 31.826084681919642, 37.92369522367205, 30.511575835091726, 29.328617232186453, 19.632612807410105, 17.506966045924596, 7.540126051221575, 5.504539234297616, 2.0635500592844824, 1.0716884136199951, 0.3040820759321962, 0.13499528834862368, 0.027695846976712346, 0.20959470394466603, 0.08029180871588842, 0.29636322440845625, 0.1482456794806889, 0.6193930921810014, 0.39911370085818426, 0.3689388685992786, 0.42886868278895107, 0.5182039790919849, 0.3367381750472954, 0.09786433220974036, 0.17916578746267728, 0.21335718062307152, 0.08599313135657992, 0.11747060157358646, 0.09490375500172377, 0.04706538734691484, 0.3065163881650993, 0.8130648998277528, 0.7340467284832681, 0.272679719541754, 0.5807885751128197, 0.6925825934324945, 0.35745175927877426, 0.6983613233481134, 0.052803371234663894, 0.11589386260935239, 0.16560998771871838, 0.47187371658427374, 0.09649958794138261, 0.06930379582835094, 0.0677375877276063, 0.12815238482185773, 0.18957163766026497, 0.09478343717221703, 0.09126127045601606, 0.8973232614142554, 3.2828707567283084, 6.729843633515494, 12.92806669643947, 17.273822716304235, 23.032258680888585, 27.778514078685216, 34.06026751654488, 38.97203942707607, 29.94582223892212, 36.90234824589321, 23.81796097755432, 21.303948129926408, 27.60954257420131, 23.429002557482036, 35.041804790496826, 43.16172674724034, 40.24486950465611, 52.21594864981515, 63.2248204095023, 63.460343497140066, 69.28603281293596, 65.25780078342983, 47.22618668419974, 19.766275303704397, 2.8835634291172028, 0.12075735735041754, 0.2047295942902565, 0.049386754033288786, 0.04112047402720366, 0.07945054064371757, 0.01829073584771582, 0.034843153187206814, 0.02616443924073662, 0.0352411682584456, 0.03910828860742705, 0.008331382048449345, 0.03356272028759122, 0.03077222127467394, 0.014356834082198995, 0.024566382402554154, 0.050574027467519045, 0.03009108068155391, 0.009079609398863145, 0.016993446441899453, 0.0278785086037325, 0.04327421202989561, 0.014023105114964502, 0.035057594001825364, 0.03211996145546436, 0.03688745706209114, 0.008965990406328013, 0.03852783582572426, 0.01916671946777829, 0.07792653063578264, 0.041080491351229806, 0.026100217597559094, 0.013246807618997991, 0.019911415043420026, 0.05409121373668313, 0.04670120742438095, 0.07794406398066453, 0.022891946269997528, 0.11698334557669503, 0.06657504010945559, 0.02259389467404357, 0.03935580121885453, 0.07108974070953471, 0.009602450316638818, 0.1297604042504515, 0.17933367059699126, 0.23778423773390905, 0.0699043468173061, 0.13856138342193194, 0.10956585859613759, 0.09063741178917033, 0.11181493076894965, 0.07755035760679416, 0.12367549219301768, 0.1578735349965947, 0.09796548142497029, 0.128860205411911, 0.1607765792203801, 0.142220763489604, 0.10959208397460835, 0.18412771049354756, 0.09242590117667403, 0.14233911356755666, 0.11707763480288641, 0.17554657666810922, 0.1420278695545026, 0.10487751409943614, 0.2572494532380785, 0.11865526943334512, 0.07779297458806209, 0.10267844995749847, 0.11038613958018166, 0.10880307666957378, 0.1255440962101732, 0.11762122277702604, 0.07682312412985734, 0.07636535047952618, 0.1701875478029251, 0.17374879813620023, 0.14829762812171662, 0.09789516484098774, 0.13935195814285958, 0.13537522724696568, 0.32668234035372734, 2.0120943060943057, 12.069973724228994, 29.5792943409511, 52.231099196842735, 77.86020714896065, 84.20785209110805, 80.61767618996757, 79.92610113961356, 68.34341934749058, 59.64474718911307, 51.31456232070923, 39.56648908342634, 43.81541674477713, 31.389452934265137, 29.74071489061628, 29.973972865513392, 48.70834861482893, 50.76017945153372, 41.76382909502302, 53.62202433177403, 47.3050730569022, 44.704445702689036, 31.99507529394967, 29.253479412623815, 14.617401327405657, 10.237827556473867, 2.58340494121824, 1.9362141149384635, 0.3966057540050575, 0.26164014477814945, 0.2059326504490205, 0.19841351892266954, 0.30674491875938004, 0.3802609039204461, 0.26799245391573223, 0.5279400880847658, 0.38116829523018425, 0.5513016687972205, 0.4839643420917647, 0.3280800682093416, 0.21586269832083158, 0.2713444711906569, 0.21148960797914437, 0.2254047870103802, 0.28351749799081255, 0.17975102391626152, 0.6141850373574665, 0.3098380070711885, 0.4873120167425701, 0.9832467479365212, 0.4596151400889669, 0.25033431287322727, 0.47667025348969866, 0.4676210933497974, 0.20885354014379637, 0.4134167305060795, 0.14067172232483113, 0.17897914962044784, 0.22522627801767417, 0.479293307023389, 0.20209504637335027, 0.25388337671756744, 0.12954708641128881, 0.16500081254967622, 0.4567902630993298, 0.24156739615968295, 0.22148719722671167, 1.515101820230484, 5.33193382195064, 11.409420643533979, 19.03070252282279, 23.57658576965332, 39.1106664112636, 42.31919166019985, 45.03563158852713, 44.95651592527117, 39.40369973863874, 43.90685851233346, 28.44927406311035, 26.10110776765006, 27.913331712995255, 25.876990147999354, 37.222250257219585, 49.43608556474958, 46.62084920065743, 58.85738427298409, 71.8281910760062, 73.45719623565674, 77.76913016183036, 74.80933652605329, 53.74352748053414, 24.397536277770996, 4.503054116453443, 0.20255746798855917, 0.35213736444711685, 0.17067397598709377, 0.17117686543081487, 0.15564910721565994, 0.081256522664002, 0.1647738425859383, 0.11610572838357516, 0.09058533422648907, 0.17212085691945894, 0.1679747094001089, 0.15090582173849854, 0.12899794802069664, 0.07781556980418307, 0.1464620687599693, 0.2035855163953134, 0.09763249036456857, 0.09509214346430131, 0.10403385079864945, 0.13390812597104482, 0.17952610312827996, 0.10772246894027505, 0.11646554193326406, 0.1072048485012991, 0.15005713727857384, 0.11850014275738172, 0.1262445750513247, 0.1303288537476744, 0.1335913044001375, 0.1916599784578596, 0.08279031036155564, 0.12631023009972914, 0.11774676532617637, 0.18118019508463995, 0.11023954208940268, 0.24573506680982454, 0.08695250523409673, 0.25338250930820194, 0.09805707008178745, 0.09132632839360408, 0.15858014779431479, 0.15824970124023302, 0.14778836044882024], [0.014324320380442908, 0.04595725823725973, 0.037302713708153794, 0.021196914903287376, 0.027547205399189676, 0.013921810014705573, 0.06257065212620155, 0.037836496851273944, 0.008744571707211435, 0.022530575482440845, 0.07120874218110528, 0.04221780425203698, 0.07420842336224658, 0.026700858492404222, 0.0209404405406011, 0.0822704778984189, 0.021869397389569452, 0.05844748658793313, 0.018883146112784743, 0.0663940476785813, 0.04949550623340266, 0.024145941748949032, 0.044338972573833804, 0.0459898007767541, 0.015445343351789882, 0.016626552379290973, 0.016585344947608452, 0.025682212884670923, 0.027662006738994802, 0.007479472850848521, 0.040965696796774864, 0.02502849867700466, 0.060446600030575476, 0.015065468914274658, 0.045791861933789084, 0.03720522518934948, 0.04177536888580237, 0.022595294152519534, 0.07840370360229697, 1.1953333445957728, 9.08480613572257, 24.716654879706248, 40.053811413901194, 57.80436045782906, 67.95584883008684, 68.80859429495675, 62.57370471954346, 48.544739382607595, 47.44694137573242, 33.034890583583284, 32.59879732131958, 27.890776123319352, 20.078424862452916, 25.793217454637798, 20.835031577519008, 37.5927004132952, 42.03493390764509, 29.585936818804058, 43.65377385275704, 31.72472436087472, 28.0454933983939, 16.466070311410085, 11.180216073989868, 2.227495627743857, 1.5994698873588016, 0.8585104069539479, 0.21288534094180378, 0.0862415973097086, 0.09986338458423104, 0.04441998965506043, 0.04102327388578227, 0.10805064240204436, 0.025654584635049105, 0.14178481831082276, 0.16086230533463614, 0.2895131691225937, 0.13185715888227734, 0.1254781290356602, 0.07849810139409133, 0.7637982634561402, 0.8397630272167069, 0.09780486540070601, 0.08125220039593321, 0.040791231872779984, 0.09827613511255809, 0.022817008862537996, 0.02668529629175152, 0.04252817974026714, 0.4288237637707165, 0.8979217293007034, 0.68943033686706, 0.9130484461784363, 0.7662378954035896, 0.7073247166616576, 1.7386307971818107, 0.7217153587511608, 0.4734135568141937, 0.13748616326068128, 0.23557777756026813, 0.18630738210465225, 0.07512278322662626, 0.18204798709068978, 0.0806973623111844, 0.08470817602106503, 0.010125926512825702, 0.09378311370632478, 0.10482232884636947, 0.07050900972847428, 0.09602177715195076, 0.8721111799989427, 1.0578722464186805, 6.129455872944423, 12.199251038687569, 19.339232070105417, 30.22797121320452, 35.953182629176546, 45.911736897059846, 24.75804008756365, 24.056942531040736, 19.275263479777745, 14.386112298284258, 23.913554293768748, 23.555614369256155, 36.61268132073538, 26.21464306967599, 36.51704978942871, 38.623469148363384, 41.755685806274414, 55.82857070650373, 52.48552485874721, 54.80341958999634, 43.96114131382534, 23.044025455202373, 9.76540129525321, 1.6513334129537856, 0.22486155187445028, 0.025197455592985665, 0.06077086513063737, 0.03674108348786831, 0.042358454383377514, 0.06962970976850816, 0.021894009551033378, 0.08354313817939588, 0.04438493314332195, 0.03555267350748181, 0.007361294102988073, 0.08730794223291533, 0.05456621878381286, 0.053622393536248376, 0.03214939630457333, 0.03881074421639953, 0.024950205913877914, 0.07439773463244949, 0.07812526675739459, 0.008209890353360345, 0.0246529600782586, 0.029282860657466308, 0.041203061916998455, 0.004765211912204644, 0.030072281868862252, 0.07474924291351012, 0.0035531513817009647, 0.017220031337014267, 0.03465560271537729, 0.09113896451890469, 0.05986170284450054, 0.024561551233221377, 0.03790014682869826, 0.01650804284560893, 0.020146982045844197, 0.058371049618082385, 0.013976602565630205, 0.03325850250465529, 0.01249233605007508, 0.015757423659254397, 0.052165259939751456, 0.05367291046838675, 0.008010464670535709, 0.009609071122083281, 0.04083834595179983, 0.011307761488881494, 0.025749226699450185, 0.06715651747903653, 0.004540336925336825, 0.02049396449833044, 0.04097962033535753, 0.024841460499114225, 0.047774921237890206, 0.05209037342241832, 0.020480327640793154, 0.0393341288103589, 0.07380880694836378, 0.020221975432442765, 0.029249215498566628, 0.003649097293548818, 0.03152039773496134, 0.03135107610640781, 0.015538611382778202, 0.07236099642302309, 0.04800936865753361, 0.010622993277918016, 0.01002877895786826, 0.013351268085118915, 0.05680354551545211, 0.035585416214806695, 0.016304271994158626, 0.012802423160922314, 0.022166482073121836, 0.028679215548826114, 0.10817219516528503, 0.07425484872822251, 0.016307922512558953, 0.03034706480268921, 0.022453638093013848, 0.10626221408269235, 1.3086922275168555, 9.327524083001272, 27.43238261767796, 45.72655003411429, 64.27554784502301, 77.39739458901542, 77.17285660334996, 69.75764874049595, 57.558411598205566, 53.98679086140224, 41.62454898016793, 39.33187620980399, 32.19677802494594, 26.001234361103602, 32.24840661457607, 22.706419433866227, 39.493123054504395, 48.21757302965437, 33.139106614249094, 43.853847231183735, 29.404700006757462, 22.34814599582127, 12.228813886642456, 7.653729098183768, 2.2306327394076755, 1.6161035490887505, 0.664544440805912, 0.040670065874499936, 0.19047069655997412, 0.1647020671516657, 0.46503886048282894, 0.3025549107364246, 0.41600140609911507, 0.3772806152701378, 0.568094433418342, 0.5161919870546886, 0.6861474758812359, 0.575756559414523, 0.5826055833271572, 1.356522323829787, 1.7616027359451567, 1.2009960178818022, 0.11175514504845653, 0.26419444914375034, 0.045683655954365215, 0.07243144871400935, 0.04989758912207825, 0.03909272301409926, 0.08531195005135876, 0.26901120639273096, 0.17308059042053564, 1.8282252124377658, 2.0305320024490356, 3.1327071573053087, 2.38948940379279, 2.9853184946945737, 1.7293396443128586, 2.13291848557336, 2.205139798777444, 0.9637337092842374, 0.32958999861563953, 0.39772870231951984, 0.5721006670168468, 0.46485055344445364, 0.19388558688972676, 0.15136748339448655, 0.035858282287205966, 0.2575578066919531, 0.11480646952986717, 0.16568396160645144, 0.7698198546256337, 1.0088231755154473, 3.2974072567054202, 8.25105617727552, 14.689037254878453, 24.195234264646256, 31.711609636034282, 38.8195994240897, 30.458658354622976, 27.97757649421692, 26.833041429519653, 20.251263039452688, 29.14101413318089, 34.009538718632285, 48.88362387248448, 36.990635531289236, 45.41275201525007, 48.826082365853445, 50.75456183297293, 63.22361142294747, 58.19069766998291, 63.294642857142854, 55.79601839610508, 32.37477697644915, 14.135505540030342, 2.738289407321385, 0.4290056111557143, 0.054242245453808985, 0.04982683488300868, 0.004302081651985645, 0.016829612465309243, 0.05027690376820309, 0.057974391616880894, 0.03031467493357403, 0.026204058900475502, 0.0377677917879607, 0.02172434186962034, 0.05189772715259876, 0.01592802262998053, 0.020346500179065124, 0.04987528228334018, 0.018818944825657775, 0.028969367300825458, 0.097136169139828, 0.0825380106855716, 0.03315918194130063, 0.02871056047401258, 0.007011259515171072, 0.017176113157932247, 0.04207050447751369, 0.04930760970871363, 0.036084848522607765, 0.004402584562610302, 0.05192625955013292, 0.039988301029162746, 0.035240272592220984, 0.013177569057526333, 0.03509504574217966, 0.020252979393782358, 0.04172968990834696, 0.04446253040805459, 0.06616066555891718, 0.05282648553007415, 0.05740001850894519, 0.03055357015026467, 0.028766437832798277, 0.05730734419609819, 0.18167822621762753, 0.12297098285385541, 0.15297970974019595, 0.12861388362944126, 0.09130746512008564, 0.11685089554105486, 0.15921489016285964, 0.19370501515056404, 0.15656712438379014, 0.07680327698056187, 0.1290813535451889, 0.15089774717177662, 0.10593912284821272, 0.11256291384675673, 0.10350377245673112, 0.2559451732252325, 0.10036898816802672, 0.1997326181403228, 0.1143076920083591, 0.11417995100574833, 0.12693528298820766, 0.12977644481829234, 0.14240673636751516, 0.12289675112281527, 0.09818447181688887, 0.08342377029891525, 0.11604504021150724, 0.17711932584643364, 0.11978994283292975, 0.07415498872952801, 0.12485528817134244, 0.07741862681827374, 0.1503938263548272, 0.1405157542654446, 0.193370592381273, 0.1969962628292186, 0.1845263633877039, 0.08230246403919798, 0.42226110877735273, 2.109390582357134, 14.741935627801077, 35.149585247039795, 55.840962818690706, 74.73351778302873, 85.89659786224365, 84.54907117571149, 78.71282754625592, 62.05792604173933, 61.33830806187221, 45.63698428017752, 43.1459994997297, 39.11679472242083, 32.05497223990304, 39.282696860177175, 30.227939946310862, 49.93710626874651, 54.64783205304827, 41.30583511080061, 55.39520113808768, 41.3213643346514, 34.597453594207764, 20.056390387671335, 13.375811219215393, 2.7317604890891483, 2.618588447570801, 1.2937091972146715, 0.49974266971860615, 0.29688672774604385, 0.17222942252244267, 0.40038429839270456, 0.3176232193197523, 0.3092194545481886, 0.3535688290638583, 0.8035033100417682, 0.41887169065220015, 0.5167746043631009, 0.47715114482811516, 0.6418872337256158, 0.6772426537105015, 2.9477500191756656, 2.574624155248914, 0.17986470567328589, 0.5175378205520766, 0.3318354066993509, 0.33800955968243734, 0.14473143805350575, 0.22520793043076992, 0.26763394315327915, 1.8610532794679915, 3.343839462314333, 2.230434932879039, 2.402962177991867, 2.6613691576889584, 2.7532564784799303, 3.6956882051059177, 2.0493314393929074, 1.9168473141533988, 1.8924137566770827, 0.9952085060732705, 0.24227244832686015, 0.4843606065426554, 0.6829295914087976, 0.5397608195032392, 0.19368266420704977, 0.18048895789044245, 0.2534211315214634, 0.31032258964010645, 0.21585443376430444, 0.33206567434327944, 1.483218925339835, 1.8590031266212463, 8.187574829374041, 14.390972563198634, 25.14795388494219, 38.49253729411534, 47.38289982931954, 61.14024271283831, 34.88408415658133, 34.43413618632725, 29.604933193751744, 23.61225782121931, 33.76751906531197, 34.97978516987392, 51.45173018319266, 37.88666827338082, 51.21058600289481, 54.87750128337315, 58.753592082432334, 73.63310377938407, 67.6823399407523, 74.32262911115373, 65.92156914302281, 39.48716497421265, 19.132465839385986, 3.9786401305879866, 0.7815582390342439, 0.1351204237767628, 0.14927798908736023, 0.1370813085564545, 0.07939595250146729, 0.10813523536281926, 0.09037010970392398, 0.1334596686065197, 0.08039128873497248, 0.12298776981021677, 0.09099613968282938, 0.15805635947201932, 0.19300714188388415, 0.17965784748750074, 0.12244834804109164, 0.09870251973292657, 0.12068801107151167, 0.1523534490593842, 0.19948084093630314, 0.1458665050034012, 0.11754164419003896, 0.09499197812484843, 0.08138525432773999, 0.10189731365868024, 0.13294163426118238, 0.12151914861585413, 0.13382733959172452, 0.156758362693446, 0.09026465857667582, 0.3076641165784427, 0.16743630543351173, 0.11631638636546475, 0.0932137006893754, 0.1830555573105812, 0.15780361874827317, 0.1938596804227148, 0.12199732581419603, 0.10499319753476552, 0.10668927723807947, 0.06027094088494778, 0.17956928509686673], [0.028399231644081216, 0.05721187431897436, 0.030850887232060944, 0.038120426437152286, 0.04273445099326117, 0.01894129826022046, 0.05739646977079766, 0.014880934530603034, 0.019429465190374424, 0.005712071059471262, 0.047734965703317096, 0.05031663877889514, 0.05541144950049264, 0.02693356546972479, 0.02013542489813907, 0.04970546532422304, 0.03636822510244591, 0.030095721861081462, 0.0860007173780884, 0.009191399739523019, 0.03369579118277345, 0.03511886910668441, 0.042351523148162026, 0.06588070201022284, 0.014004036584602935, 0.006438368158082345, 0.02985460783487984, 0.04900375154933759, 0.03462794902069228, 0.014502418859462653, 0.02419831447436341, 0.05010892563898649, 0.03676154471135565, 0.019302938765447055, 0.021487473776297908, 0.0662532855889627, 0.12366144651813166, 0.23874279058405332, 1.752842794571604, 5.936301163264683, 18.28931062562125, 33.25403676714216, 64.43874713352749, 61.96724510192871, 68.16492707388741, 57.15371029717581, 51.089749881199424, 42.895937306540354, 33.14367505482265, 35.07438489368984, 26.841302837644303, 29.111539874758037, 25.74740971837725, 24.263310977390834, 34.90416445050921, 38.61167458125523, 30.862126350402832, 36.86986541748047, 28.47633729662214, 18.69614154951913, 7.716407060623169, 4.502959447247641, 1.078496128320694, 0.27075300578560146, 0.04053520703954356, 0.044354053014623265, 0.04267050924577883, 0.20843696035444736, 0.4241387780223574, 0.33548489372645107, 0.3057620200727667, 0.7337249400360244, 0.6688727342656681, 0.5219832562974521, 0.6676766127347946, 1.2323802709579468, 0.6965419809733118, 0.6821052527853421, 1.8451881536415644, 1.2307558038405009, 0.9460270937000002, 0.23129567876458168, 0.17337362255368913, 0.07643286471388169, 0.045566337249640904, 0.0943939241447619, 0.17981954238244466, 0.015540009164916617, 0.44313238454716547, 0.1703627591154405, 2.9342325159481595, 1.1448480593306678, 2.4974908999034335, 1.8669746645859309, 1.6692128649779727, 2.6669919873986925, 0.6781559618456023, 1.2221103991780962, 0.5629262221711022, 0.8098950013518333, 0.18769555618720396, 0.22511081849890097, 0.030968395926590477, 0.29619711903589113, 0.2624459186834948, 0.13888268332396234, 0.04926634120887943, 0.07208718718694788, 0.05896788902048554, 0.09474035019853286, 0.22723888073648724, 0.48646525932209833, 0.7768975176981517, 3.2770299272877828, 6.581949923719678, 18.63763424328395, 30.868643760681152, 40.0911614554269, 38.88137238366263, 36.11739982877459, 29.70606075014387, 15.25478390284947, 13.763914142336164, 21.311506032943726, 24.51492783001491, 24.855156796319143, 24.02648683956691, 45.40050234113421, 40.436118670872276, 48.90168571472168, 51.109250000544954, 55.84685141699654, 55.88397216796875, 40.066676003592356, 22.83934542110988, 7.92945533139365, 1.2684333877904075, 0.049282568373850415, 0.06538999227008649, 0.04526690313858645, 0.055108408975814066, 0.04910045296752027, 0.04033827921375632, 0.03866944608411618, 0.006515709275845438, 0.04788954955126558, 0.027619145378204327, 0.0444210583477148, 0.0357819572756333, 0.046214653711233816, 0.076657921208867, 0.0439006016323609, 0.017280705938381807, 0.035782798659056425, 0.03254864291687097, 0.028228585175903778, 0.021396611151950698, 0.013730154406013233, 0.00909654563292861, 0.01475050313664334, 0.029276797947074686, 0.013296523031645587, 0.0651277317000287, 0.04270233932350363, 0.026489277702889273, 0.08790606406650373, 0.06508651748299599, 0.04022444139367767, 0.02346071976769183, 0.03205376697172012, 0.047751501601721556, 0.04476810526102781, 0.07114869861730508, 0.04378645847152386, 0.04357877925836614, 0.04422146387930427, 0.03817134370495166, 0.058432640241725106, 0.06390490981617145, 0.009261860512197018, 0.006497888401749411, 0.0670264083892107, 0.026240440251837884, 0.08168233052960464, 0.022964761559186236, 0.07127859736127512, 0.019531813716249805, 0.03609321146671261, 0.02512557668212269, 0.06196514104626008, 0.058136229004178724, 0.03969613742083311, 0.08528007926153285, 0.02973864959286792, 0.015475846893553222, 0.02220403389739139, 0.014097493757227702, 0.053066588539097986, 0.031457545036183934, 0.014930089303691472, 0.018581264186650515, 0.04697109133537326, 0.027722225025562302, 0.03770318507616009, 0.03051391656377486, 0.050354663881340196, 0.009127498704141803, 0.03757430074204292, 0.03545064898207784, 0.06587608797209603, 0.03382234814177666, 0.02167609124444425, 0.0729475085224424, 0.28686628543904846, 1.316992610692978, 6.907563354287829, 22.631085327693395, 41.07411616189139, 73.53063869476318, 72.22769859858921, 75.7125050680978, 66.31107125963483, 59.86346953255789, 47.5436464037214, 42.9494697025844, 40.911827087402344, 35.19783353805542, 37.056396756853374, 33.23611388887678, 31.120793887547084, 34.479681628090994, 40.39288003104073, 35.59038591384888, 28.75688123703003, 24.448647226606095, 16.327571868896484, 7.45642978804452, 3.229568519762584, 0.8092375823429653, 0.17849102509873255, 0.2458487349961485, 0.3258625072027956, 0.30090704773153576, 0.7031922212668827, 1.127992598073823, 0.9994580894708633, 1.3599144560950143, 1.9915037538324083, 2.062965759209224, 2.0378664774554114, 2.380210735968181, 2.6030933133193424, 3.550655198948724, 3.423476891858237, 4.606195781912122, 2.9473765535014014, 1.3318564359630858, 0.861232092337949, 0.16189415353749478, 0.21418552260313714, 0.15240357922656195, 0.08601284279887166, 0.32027626410126686, 0.10677543082939726, 0.16860493272542953, 0.6016580324087824, 3.709045248372214, 4.084965808050973, 6.417741843632289, 4.5825923170362195, 6.793235957622528, 6.190300813743046, 6.261611044406891, 4.118301962103162, 2.991186899798257, 2.4654045530727933, 2.2098919323512485, 0.8712086741413388, 1.7020636222192218, 0.8458068743348122, 0.6519077303154128, 0.4993680641055107, 0.2898251052413668, 0.3340253106185368, 0.15924843693418161, 0.015914411217506443, 0.2245409305074385, 0.2503904955727713, 0.6881801496659006, 2.4879870670182362, 6.214666843414307, 16.90922294344221, 27.386418546949113, 30.185677528381348, 35.164770535060335, 33.367865630558555, 34.40013517652239, 23.77328406061445, 20.21815139906747, 34.75522286551339, 31.74028832571847, 41.19482374191284, 36.15165097372872, 55.82034751347133, 52.51365116664341, 59.36342852456229, 58.069587094443186, 63.360115732465474, 64.88623891557965, 51.62913506371634, 29.089953558785574, 9.386146034513201, 1.76328387430736, 0.06736383028328419, 0.03654893933396254, 0.04870356087173734, 0.05953925621828862, 0.028846179268189838, 0.06438490548836333, 0.030122520601642982, 0.024821462375777106, 0.016189825188900744, 0.020385297115093896, 0.02196727436967194, 0.04668991660167064, 0.02197877553823803, 0.018785087624564767, 0.04807249616299357, 0.023793203623167107, 0.03758363738389952, 0.021230290344517146, 0.01070566852909646, 0.07656505012086459, 0.013851467985659838, 0.03696035886449473, 0.014381880506074854, 0.02619194026504244, 0.02382496415105249, 0.05540842662698456, 0.04699463650052037, 0.019524124218150973, 0.028414276461782198, 0.05583601564701114, 0.01629440948766257, 0.056954845253910334, 0.011375707441142626, 0.008078347858307617, 0.0511308502671974, 0.021848310217527405, 0.036443752835371664, 0.04695428063028625, 0.09126939930553947, 0.0875079675710627, 0.12106440801705633, 0.12955357320606709, 0.11714358840669904, 0.116958456912211, 0.08228335649307285, 0.07263026625982352, 0.11733755442712988, 0.13040714311812604, 0.19205745070108346, 0.10912536044738122, 0.11864281153040272, 0.16712649991469725, 0.23813612599458012, 0.12441681884229183, 0.09395932246531759, 0.1431964968464204, 0.08624581779752459, 0.10581381100096873, 0.15886167197355203, 0.0861267823992031, 0.14396416422511848, 0.16543896975261824, 0.18980201386979648, 0.07020327541977167, 0.1517811454832554, 0.17715536962662423, 0.1111460920157177, 0.08493959717452526, 0.14569115798388207, 0.15738767678184168, 0.22197363898158073, 0.12392048404685088, 0.11587535217404366, 0.09574260748922825, 0.1662610149277108, 0.1986929260726486, 0.6006355615598815, 3.438334963151387, 10.743276000022888, 29.441344806126185, 49.918801239558626, 84.32852145603725, 80.38854544503349, 84.338394846235, 72.81450176239014, 66.46370233808244, 56.460589272635325, 43.37213209697178, 45.28256361825125, 38.45371770858765, 39.41555336543492, 40.527515275137766, 36.11342545918056, 49.70724943705967, 47.92646087918963, 42.190010751996724, 48.12218468529837, 35.322237559727256, 23.74654218128749, 11.122999395642962, 5.72749433347157, 1.6370292433670588, 0.5400069920080048, 0.29379331373742645, 0.26670578867197037, 0.21066594789070742, 0.6136523059436253, 1.086043609040124, 0.7649041669709342, 1.0212263613939285, 1.8896086386271884, 2.2922421991825104, 1.9359463921615054, 1.924227386713028, 3.1931944830077033, 3.2712105938366483, 2.673813815627779, 5.6375095163072855, 4.4234907286507745, 4.3728548628943305, 1.3004360305411475, 2.779430776834488, 0.9610231518745422, 0.3567956159157412, 0.35904037260583466, 0.53347595674651, 0.3898133470543793, 1.449954098888806, 3.6252158837659016, 11.051970567022051, 5.476493699210031, 7.752386569976807, 7.374899625778198, 7.465907999447413, 10.003569909504481, 6.959420365946634, 5.4014574970517835, 3.343815795012883, 3.093561657837459, 1.489691932286535, 0.6811619805438178, 1.1295409607035773, 0.9155436094318117, 0.8593087441154889, 0.4201820231974125, 0.21559895175908292, 0.47795138188770836, 0.33539190728749546, 0.28398386867983, 0.4598035014101437, 0.8126175552606583, 1.419708481856755, 4.217683349336896, 8.625381691115242, 23.212960481643677, 39.42800453730992, 50.35742017201015, 51.355393409729004, 46.69915887287685, 42.540008885519846, 26.944422789982386, 21.006228242601665, 32.85896219526018, 35.109709535326274, 37.63674851826259, 36.63562079838344, 60.839455195835654, 57.224474225725444, 65.80627768380302, 66.22700500488281, 73.02111339569092, 79.00693089621407, 62.82875919342041, 37.20867347717285, 12.611292243003845, 3.209664970636368, 0.1437847459954875, 0.121869829084192, 0.12718302969421658, 0.17816254629620484, 0.09912381534065519, 0.14003544646714414, 0.1011018127735172, 0.0766830745020083, 0.1385063813733203, 0.09819602048290627, 0.1509607152215072, 0.16060420418424265, 0.13481525943747588, 0.10705458692141942, 0.07351359671780042, 0.10129346498953444, 0.06235081356550966, 0.14342324967895234, 0.0597829045727849, 0.1534122893852847, 0.11934280182634081, 0.12603429704904556, 0.32889251889927046, 0.15132158728582518, 0.1365239598921367, 0.12454944529703685, 0.2474290430545807, 0.1065062220607485, 0.16171728659953388, 0.18238349551601069, 0.1708142834582499, 0.1639086968664612, 0.10955373996070453, 0.12204265195344176, 0.12448271816330296, 0.0943678684000458, 0.2052846359355109, 0.18310371972620487, 0.17509373596736363], [0.020406458925987993, 0.018231548934376667, 0.016670411186558858, 0.031540214350180965, 0.06355539642806564, 0.11061076859810523, 0.05106585339776107, 0.009358634872894202, 0.03481585911608168, 0.03237575219411935, 0.052357478732509274, 0.03497347601556352, 0.05828645665730749, 0.012180685764178634, 0.023103459206010615, 0.04910160308437688, 0.04618616881115096, 0.07892312215907232, 0.0026704241837640958, 0.035570881994707246, 0.07121702030833278, 0.019691269445632185, 0.05243257559569819, 0.036766067147254944, 0.03239523632717984, 0.008128220182178276, 0.05822254544390099, 0.014893780894843596, 0.023410552281088064, 0.05085154150479606, 0.02182020020804235, 0.025274321736235703, 0.03679639087723834, 0.03822269523516297, 0.053574723058513234, 0.05822031306368964, 0.2568754718772003, 1.9693843807492937, 8.861413734299795, 24.18512637274606, 45.07372161320278, 60.46600341796875, 64.45569378989083, 63.99183900015694, 61.19860758100237, 55.93959597178868, 43.350894927978516, 43.60095017296927, 29.24963011060442, 26.121372188840592, 22.137662478855678, 17.860455649239675, 28.18079219545637, 30.981583254677908, 35.7521538734436, 41.69587571280343, 29.784950596945627, 20.99631142616272, 13.423461965152196, 3.0254562837736945, 1.4499168608869826, 0.3557057801101889, 0.1764550536338772, 0.04030994698405266, 0.10100288915314845, 0.18486396170088223, 0.342589263937303, 0.5294043666550091, 0.8178733246667045, 1.9127934745379855, 1.6396988715444292, 1.8115479073354175, 1.3507264405488968, 1.9340347690241677, 1.6704708146197456, 2.4151560493877957, 2.5429397182805196, 1.305222145148686, 4.397901381765093, 1.3370194903441837, 0.5259315701467651, 0.25367894768714905, 0.0936927328418408, 0.024147254714210118, 0.016868568857067397, 0.045314916276506016, 0.10557493274765355, 0.0827162346935698, 0.1564076008009059, 0.37200579260076794, 1.7899129539728165, 4.628730961254664, 6.810345896652766, 3.8995709334100996, 5.5492691312517435, 2.5924384679113115, 4.452079960278102, 4.398828097752162, 2.5936806755406514, 1.3370750759329115, 1.254347760762487, 0.9478991989578519, 1.7415239619357246, 0.8548008831483977, 0.3576491315449987, 0.7645059483391898, 0.8963195181318692, 0.2057980562427214, 0.10431396362504788, 0.17572817978050026, 0.06437486317008734, 0.07314126419701747, 0.14015051243560656, 0.32796623717461315, 0.9380902967282704, 3.2228348468031203, 11.595091274806432, 31.105619021824428, 38.9042979649135, 50.104762826647075, 28.888368947165354, 34.37024055208479, 34.355625016348704, 25.132402079445974, 28.860876662390574, 11.570532866886683, 24.33255672454834, 40.482991218566895, 25.881256341934204, 35.899733611515586, 41.54063905988421, 41.76350947788784, 49.36238949639456, 52.39975282124111, 48.01720782688686, 25.08298475401742, 8.927464178630284, 1.3486060457570213, 0.03705001708918384, 0.08219689077564649, 0.07378435254629169, 0.07150453595178467, 0.06446333735116891, 0.03808324611080544, 0.09893480941121068, 0.08243823211107935, 0.04711125631417547, 0.015281775700194495, 0.006365909947947199, 0.027188333316839168, 0.04889021907001734, 0.02498350671625563, 0.049515122680791786, 0.017121657330010618, 0.04555033739390118, 0.012945291253605058, 0.04263068941820945, 0.06895873362996749, 0.023608667543157935, 0.017137494337345873, 0.04649530258029699, 0.04875995052446212, 0.0858645693265966, 0.0618825497637902, 0.08063778693654708, 0.046379968590502224, 0.05300561538232224, 0.014679658991683806, 0.013597857040752257, 0.05949716669108186, 0.05060892791620322, 0.015850735795018927, 0.04039092335317816, 0.01657972837399159, 0.05824873689562082, 0.027065252153468982, 0.010034696631399649, 0.021885561790051203, 0.019993868922548633, 0.005995852639898658, 0.07258942523705107, 0.07782229408621788, 0.039646404196641276, 0.036163178605160544, 0.026135430172351853, 0.0397910780406424, 0.024372703063168695, 0.005403878757663603, 0.029081780197364942, 0.02028148464991578, 0.01459465890989772, 0.017304553051612208, 0.04536778433248401, 0.08082681322204215, 0.0039673989189655656, 0.06912211807710783, 0.03310374563027706, 0.01625765154936484, 0.03390097338706255, 0.037474430565323145, 0.016056990084637488, 0.01640998775006405, 0.02442497740100537, 0.012284850219397672, 0.040238459927162955, 0.038108301016369035, 0.021032887544216852, 0.008078067962612425, 0.08143161184021405, 0.018066245929471085, 0.008313797813441073, 0.011428136145696044, 0.18867617499615463, 2.298883374248232, 10.57094417299543, 27.2665308543614, 53.40649815968105, 70.58834757123674, 75.16871125357491, 71.73275756835938, 70.8241138458252, 61.60231876373291, 52.003514426095144, 50.16928727286202, 33.04970414297921, 27.78058637891497, 24.14172966139657, 25.806194952556066, 34.24627774102347, 30.38884632928031, 32.84528466633388, 34.10238054820469, 29.280917848859513, 18.40068851198469, 9.506632140704564, 2.9549301138945987, 1.1496530643531253, 0.1910863856651953, 0.1877370418182441, 0.17415338142641953, 0.7600377138171877, 1.0285896062850952, 1.4114666155406406, 2.4895960092544556, 2.897189063685281, 3.504457929304668, 4.333651389394488, 3.3275528848171234, 5.036340517657144, 5.410746370043073, 4.257670666490283, 5.26638799054282, 6.021055723939623, 6.324589082172938, 8.491492509841919, 2.5094778452600752, 2.101924308708736, 0.6946479997464589, 0.1931277039859976, 0.07096175543431725, 0.06027858118925776, 0.03365911636501551, 0.004055026203526982, 0.2179492749273777, 0.2390337735414505, 0.5476207520280565, 4.924656910555703, 8.561718821525574, 8.445954884801592, 4.547339328697749, 9.55421166760581, 8.159546664782933, 6.621541193553379, 6.640398170266833, 6.257797351905277, 5.547408751079014, 5.349299107279096, 4.194386907986232, 3.6023220036711012, 2.3686187522751943, 2.7261737031596045, 2.0368852615356445, 1.3717544036252158, 1.48602371769292, 0.322000150169645, 0.4829990310328347, 0.17926178659711564, 0.07920318748801947, 0.1444925937269415, 0.14579158116664204, 0.638195623244558, 2.8039207884243558, 9.83722482408796, 25.63278702327183, 36.466063908168245, 46.481162616184776, 28.647021532058716, 26.976045778819493, 24.68191041265215, 26.637797049113683, 32.74962534223284, 19.048764365059988, 35.15756525312151, 56.18436711175101, 34.16258668899536, 44.39208596093314, 50.50606298446655, 52.16475779669625, 57.8508334841047, 59.66297231401716, 57.82960673740932, 30.762614250183105, 10.677222950117928, 2.0250353259699683, 0.05522304068186453, 0.04538014045517359, 0.010571830041174377, 0.02015577755602343, 0.02315948244982532, 0.00529108164066981, 0.062409099723611555, 0.03077187522181443, 0.07203864479171378, 0.032673710491508245, 0.07185738773218223, 0.01647706941834518, 0.031089606029646735, 0.018453814954097782, 0.06406353094748088, 0.03364999006901469, 0.04417244311688202, 0.013577371220370489, 0.018498820485547185, 0.006067395675927401, 0.06735800845282418, 0.04224392785025494, 0.027144350676930377, 0.011736102834610003, 0.015346626684601818, 0.04059139313176274, 0.027857962563367825, 0.05103949909763677, 0.013133616103524608, 0.040002574013280015, 0.03189782266105924, 0.055369553355766196, 0.006780353624240628, 0.03166067467204162, 0.03064431742365871, 0.05338900123855897, 0.03598547028377652, 0.03929087220292006, 0.11588479738150324, 0.044440813894782744, 0.09036713093519211, 0.10422156072620835, 0.17435148651046412, 0.24934389601860726, 0.11436547605054719, 0.10181517699467284, 0.13336068391799927, 0.07635768303381545, 0.1192618797400168, 0.13323383858161314, 0.12527052446135453, 0.23994941583701543, 0.0801677725144795, 0.13638100613440785, 0.1279994701700551, 0.16204324125179223, 0.11617754452994891, 0.1303559137242181, 0.1299453457551343, 0.04924500806789313, 0.16217060227479252, 0.12087764803852354, 0.06778553979737417, 0.17537977918982506, 0.18140308026756558, 0.0906219615467957, 0.10088004038802215, 0.10594192519783974, 0.09024109305547816, 0.13310118498546736, 0.1605840924062899, 0.15009071119129658, 0.1072875347786716, 0.12071045700992857, 0.5544986543910844, 4.19688652242933, 14.62141912324088, 38.03844819750105, 65.96858065468925, 82.66230174473354, 82.61908394949776, 80.54752022879464, 78.24504007611955, 72.96707725524902, 58.47188431876046, 55.97444813592093, 41.04287706102644, 35.50187976019723, 32.85980987548828, 31.622168949672155, 41.21947247641427, 43.30393900190081, 44.82020616531372, 52.98797689165388, 39.8495899609157, 26.108511073248728, 15.783116238457815, 3.7485327294894626, 1.6101573024477278, 0.5740050162587846, 0.31312008095639093, 0.174196006996291, 0.6552983426621982, 0.9831660836935043, 0.9940846349511827, 1.8550817370414734, 3.178228497505188, 5.211013887609754, 6.165371979985919, 4.721692647252764, 5.865406087466648, 4.998132807867868, 9.427881257874624, 8.181576796940394, 7.890451618603297, 7.034730153424399, 12.79013887473515, 5.071026359285627, 4.376834443637303, 1.8328954875469208, 1.4480466012443816, 0.147915300780109, 0.1510383260569402, 0.11461596403803144, 0.2630841758634363, 0.38150788843631744, 0.6201510429382324, 1.8139821652855193, 7.626629386629377, 13.843339000429426, 15.836037193025861, 12.840936286108834, 16.75315076964242, 10.841025863374982, 13.06272452218192, 10.436249869210378, 6.573257727282388, 5.959860767636981, 6.091206473963601, 4.773876658507755, 4.512951825346265, 3.586520714419229, 4.527401907103402, 2.6596594665731703, 2.3931504530566077, 1.0623479719672884, 0.2284582895892007, 0.6067866172109331, 0.11660390879426684, 0.1631894497466939, 0.24658252990671567, 0.7007678427866527, 1.33731153181621, 4.201981289046151, 14.066894684519086, 37.71909161976406, 50.445189816611155, 64.63835498264858, 41.79990414210728, 47.47578682218279, 45.19511011668614, 36.79837192807879, 40.682706764766145, 19.201346806117467, 34.87453385761806, 54.373920168195454, 39.272663661411826, 50.672045026506694, 59.245663506644114, 61.344165393284385, 68.86678545815604, 69.79146562303815, 69.06223133632115, 38.93313298906599, 14.931034326553345, 4.062777604375567, 0.19904834271541663, 0.12450048221009118, 0.12316147477499076, 0.12843363758708748, 0.1439835974680526, 0.08744754402765206, 0.21357106843164989, 0.10839990473219327, 0.1318003519305161, 0.06825280615261622, 0.12982292446706975, 0.12355266378394195, 0.13340978271194867, 0.10566795311336007, 0.13520275721592562, 0.07550390956125089, 0.1402154075247901, 0.08199373060571295, 0.15409956393497332, 0.1333971076778003, 0.13235443005604403, 0.10879796051553317, 0.11988021513181073, 0.08766041403370244, 0.11729905435017177, 0.17706773004361562, 0.12583096724535736, 0.19534896979374544, 0.14223806613257953, 0.14316314006490366, 0.1308890658297709, 0.14551464388413088, 0.12414763042969362, 0.18047268662069524, 0.0816063413928662, 0.13831959425338677, 0.12747136636504106, 0.08634141659630196], [0.0409204452963812, 0.024388658814132214, 0.052401420660316944, 0.01791322780107813, 0.038935526806328974, 0.020846935022356253, 0.04097398849470275, 0.03620860652465906, 0.07120931893587112, 0.0678097770682403, 0.009105257174399282, 0.05316326281587992, 0.053137081542185376, 0.0339175669609436, 0.016202003196147934, 0.02401102184584098, 0.09620202997965471, 0.033620796099837334, 0.03317483913685594, 0.0350059676649315, 0.05419221706688404, 0.05203352915123105, 0.02556909091903695, 0.05158067148711, 0.009451833354043109, 0.18282524895455154, 0.00592076510656625, 0.003769305709283799, 0.03241515811532736, 0.05681839186166014, 0.02556036156602204, 0.06185558478214911, 0.02062002951944513, 0.10557217789547783, 0.07622935170573847, 0.07661447461162295, 2.4103811170373644, 11.52073860168457, 33.332923139844624, 53.55769443511963, 58.699722698756624, 67.24811226981026, 64.38120910099575, 63.23317214420864, 44.11441510064261, 41.97824355534145, 33.20309257507324, 25.793413741247996, 23.49285650253296, 27.64907956123352, 21.427641698292323, 26.352662086486816, 29.85853202002389, 30.841597897665842, 32.23791136060442, 19.62981789452689, 8.009060842650277, 2.5087880194187164, 0.9325391203165054, 0.14257471449673176, 0.19648662874741213, 0.05861152242869139, 0.1448112473423992, 0.3041408099234104, 0.9503572327750069, 1.4963351700987135, 1.7661801874637604, 3.0431025368826727, 2.3827162129538397, 1.5528928552355086, 3.4213236016886572, 2.756619406597955, 3.755493087427957, 4.512568805898939, 4.270635136536189, 3.3732729000704627, 7.480393256459918, 7.933541740689959, 6.175023462091174, 3.341530054807663, 0.5426898109061378, 1.1749807681356157, 0.2024672906845808, 0.2591934289251055, 0.687008618244103, 0.15944738340164932, 0.0017209205522833923, 0.08528704103082418, 0.2455734669097832, 0.35521628494773594, 2.901510626077652, 3.8369407398360114, 6.621347946780069, 1.5934619754552841, 8.118535791124616, 6.998585624354226, 7.680256451879229, 5.235786821160998, 5.280280913625445, 3.7930133598191396, 5.0851055809429715, 1.6681984279836928, 4.299067599432809, 1.064454687493188, 1.4006815999746323, 1.6122347052608217, 0.9816499650478363, 1.4559738444430488, 0.45082148909568787, 0.19486697922859872, 0.24302611074277333, 0.10718337965330907, 0.09442677881036486, 0.061092782499534745, 0.036597234063914845, 0.24971896303551538, 1.3542034711156572, 5.309253598962512, 17.840517793382915, 25.39579439163208, 42.27192653928484, 54.609394618443076, 66.69804423195976, 72.29144137246269, 63.16696970803397, 45.93730279377529, 27.669067791530065, 21.807240894862584, 23.78953242301941, 26.627082926886423, 26.195445196969168, 42.22766651426043, 43.41262967245919, 47.380349840436665, 50.591421604156494, 52.76215696334839, 27.629878214427404, 8.40931703363146, 0.7073663515704018, 0.025169632264545987, 0.04002068072025265, 0.02206889516673982, 0.017517414575974857, 0.056528301177812476, 0.02153679309412837, 0.1088638666218945, 0.009033866808749735, 0.027995610177250843, 0.06516374155346837, 0.025086881526346718, 0.014038998101438795, 0.02118396675879402, 0.08971924534333603, 0.018209021571757536, 0.03069582162424922, 0.016526195353695323, 0.0636954799826656, 0.06005778589418956, 0.027231332080970918, 0.03035130225388067, 0.03723984743867602, 0.01809259514058275, 0.0283358327246138, 0.020490356388368776, 0.022873027017340064, 0.09310605789401702, 0.03380687075800129, 0.041425441591335196, 0.019950167874672582, 0.04354391273643289, 0.02377869824080595, 0.055384833964386156, 0.044127110192286115, 0.027726014643641453, 0.01928222648400281, 0.04202710198504584, 0.008152309023509068, 0.03255956054532102, 0.09003386846078293, 0.024711605859920382, 0.03898725153080054, 0.030534615274518728, 0.06549473772091524, 0.030292307026684284, 0.018640127099518265, 0.04033621646729963, 0.05260465546910252, 0.02042406521338437, 0.07714131634150233, 0.05477491579949856, 0.041701130369412046, 0.0006168345041390109, 0.016239057993516326, 0.019943684472569397, 0.08666531528745379, 0.013122864716154124, 0.02475762240854757, 0.060067190389548025, 0.01398188411258161, 0.03071118365707142, 0.021867840151701654, 0.06895566665168319, 0.018369362789339254, 0.02750208621312465, 0.047448552679270506, 0.025438720593228936, 0.04060108939717923, 0.06044611827071224, 0.029115004664553062, 0.02562264259904623, 0.014022964318948132, 0.11341571022889443, 3.0318362499986375, 13.15029788017273, 37.51173652921404, 60.774739674159456, 71.85414954594204, 77.67035457066127, 71.44793006352016, 71.19534914834159, 54.31661490031651, 55.585870129721506, 45.474712576184956, 37.45515734808785, 33.60641465868269, 34.49844871248518, 25.416025808879308, 30.64158010482788, 34.57658120564052, 31.57720020839146, 29.711028712136404, 17.470184019633702, 8.441056404794965, 2.9412523678370883, 0.8183601328304836, 0.04249231577185648, 0.2521216555365494, 0.3399601850126471, 0.639000474342278, 1.2726883994681495, 1.6653427183628082, 2.5595645861966267, 3.51108238526753, 4.536216999803271, 4.983791725976126, 4.27410272189549, 5.883929116385324, 7.082023935658591, 10.366714903286525, 6.056219254221235, 8.688002330916268, 10.228833981922694, 8.971910067967006, 7.841123751231602, 8.576356938907079, 4.81591499703271, 1.265003583260945, 0.9098045059612819, 0.14586727853332246, 0.3386736554758889, 0.8375438920089177, 0.12025805057159492, 0.12435740631605897, 0.10255832890314714, 0.42663003291402546, 1.4339861614363534, 5.7542852844510755, 8.889955197061811, 8.60975432395935, 8.651656304086957, 9.358821375029427, 8.534764153616768, 7.81598516872951, 8.891154629843575, 9.185553278241839, 8.505359377179827, 7.235365467412131, 6.37459396464484, 8.208845002310616, 4.670554339885712, 4.455177554062434, 4.33235685314451, 3.097053561891828, 3.307316473552159, 2.7546634886945998, 1.1449694356748035, 1.1570566956486021, 0.6550552099943161, 0.21795958865966114, 0.320539372840098, 0.048343703217272244, 0.406655454742057, 1.4923923930951526, 5.83705700295312, 16.364432062421525, 24.365095138549805, 32.37403004510062, 44.19955832617623, 51.353541714804514, 59.8755316053118, 60.398279326302664, 42.01305055618286, 33.6725754056658, 29.05126598903111, 33.61046893256051, 36.92269604546683, 36.86411230904715, 49.95845808301653, 52.79686321531023, 59.38953985486712, 59.80498654501778, 60.9273499080113, 32.581642218998496, 10.781325204031807, 0.9159699465547289, 0.019241560183997666, 0.04757748111816389, 0.010754922537931373, 0.054012778481202464, 0.04261042496987751, 0.010742254289133208, 0.059198448434472084, 0.025274686448808228, 0.010466272892829562, 0.06838073035968201, 0.02555942179502121, 0.0506593430680888, 0.06321104669145175, 0.04716626854081239, 0.05302188665206943, 0.03334981296211481, 0.04968351810904486, 0.03460804080324514, 0.03864024532958865, 0.036712530734283585, 0.00908720983924078, 0.01353897970901536, 0.04900318157992192, 0.021417052019387484, 0.05636872331212674, 0.02486132800446025, 0.04598155996895262, 0.021987338650173376, 0.05468556291556784, 0.025121965179485933, 0.01338914645436619, 0.016386800512139286, 0.07554312209997859, 0.06115895323455334, 0.01918486688685204, 0.03370919903474195, 0.0575736149081162, 0.07618093144680772, 0.13349016197025776, 0.21874075888523034, 0.0791026082422052, 0.16266912195299352, 0.0821877441235951, 0.1945229484034436, 0.0889255493613226, 0.12569839507341385, 0.15877331314342363, 0.1271595659532717, 0.17269362189940043, 0.23335774668625422, 0.23132908982889994, 0.10399003100714513, 0.104056466370821, 0.16288338974118233, 0.10111529526433774, 0.11612210821892534, 0.09045380699847426, 0.15704581726874622, 0.15417053869792394, 0.0686034866209541, 0.13208241893776826, 0.12649723435086863, 0.2923280309353556, 0.11785254893558365, 0.11286535726061889, 0.09902551597250359, 0.1459038108587265, 0.15996160438018187, 0.11246108609650816, 0.12613510021141597, 0.19517465414745466, 0.19565198996237346, 0.24894383177161217, 4.4184437308992655, 18.42103804860796, 47.86557034083775, 73.55108029501778, 82.91900294167655, 89.54628508431571, 82.02945981706891, 79.47480174473354, 59.18836171286446, 55.78611373901367, 44.804002966199604, 38.192764214106965, 34.406002930232454, 41.00479398454939, 34.67408527646746, 39.27717999049595, 42.545133181980674, 43.24970136369978, 42.13614484242031, 25.36279218537467, 10.57151392527989, 3.4693389109202792, 1.4656398743391037, 0.3334829711488315, 0.7083858368652207, 0.35236402228474617, 0.5296544475214822, 0.8705354045544351, 2.1108232140541077, 3.55987155011722, 4.363607679094587, 9.053710341453552, 9.03758704662323, 7.384764330727713, 10.280823877879552, 12.936640773500715, 10.971358435494558, 12.894935948508126, 13.435228739465986, 12.492391194616046, 16.536542415618896, 16.187256472451345, 16.242574555533274, 8.299806475639343, 2.977358030421393, 3.688743914876665, 0.4328353170837675, 0.8595345062868935, 1.119422429374286, 0.5296932597245488, 0.3665536008775234, 0.2036308968173606, 0.3991896424974714, 1.2840346992015839, 10.941673994064331, 13.688291685921804, 19.785290786198207, 11.74173561164311, 16.98737801824297, 18.634434597832815, 16.576402493885585, 18.18887962613787, 14.066632390022278, 12.231641803468976, 13.784890753882271, 8.649811557361058, 12.25710608278002, 7.9181002378463745, 5.722057368074145, 5.773519200938089, 3.1309727132320404, 4.777219176292419, 2.94641335947173, 0.6255113067371505, 1.1320969206946236, 0.39670577006680624, 0.3264567410307271, 0.3410048032445567, 0.14914448053709098, 0.6392950128231729, 2.2668578241552626, 6.7278642654418945, 23.09581732749939, 33.04016079221453, 53.35425465447562, 65.1334627696446, 76.62644331795829, 78.64781325204032, 72.71186992100307, 57.02789579119001, 37.68491690499442, 32.35136154719761, 35.89086076191494, 39.5250882421221, 40.08402565547398, 57.88452877317156, 61.45004204341343, 68.40395205361503, 67.03984696524483, 73.98964364188058, 43.79961306708199, 14.524984206472125, 1.6105183916432517, 0.15769347894404614, 0.14970846527389117, 0.11378422938287258, 0.19214324466884136, 0.11708724285875048, 0.05639833118766546, 0.24737394601106644, 0.09342211272035326, 0.09463975059666804, 0.21770745861743176, 0.2086722491575139, 0.09987941836672169, 0.14547006413340569, 0.18084574517394814, 0.15825298534972326, 0.144486025507961, 0.11838686812136855, 0.13100696807461126, 0.07986487448215485, 0.07868211330579859, 0.09001491697771208, 0.0989368518016168, 0.12683443911373615, 0.11210927247468915, 0.10144784527697734, 0.08855491996343647, 0.16767932953579084, 0.0987764054111072, 0.0948250652956111, 0.12371719495526382, 0.08108243771961757, 0.13140061338032993, 0.2830766402184963, 0.19563882638301167, 0.10370783507823944, 0.10284066053905658, 0.21676082084221499], [0.0406722405792347, 0.025111066210748892, 0.023706388460206132, 0.03747695132291742, 0.022400780215061138, 0.07106270787439176, 0.05612327005448086, 0.057941224825169356, 0.09310634966407504, 0.017588457192427347, 0.02813378704844841, 0.0763760849035212, 0.026369901340720907, 0.06730423455259629, 0.012600790542949523, 0.021196095572252358, 0.027210528197299157, 0.0637606464858566, 0.029490699326353412, 0.033196735461907725, 0.025509140653801814, 0.029637768398970366, 0.026760328694113662, 0.036813062482646534, 0.013998430189011353, 0.03839971484350307, 0.05872504133731127, 0.015926504407876303, 0.010127037613918739, 0.02871356638414519, 0.014677207783928939, 0.019834905131054775, 0.01972369833051094, 0.04818617452734283, 0.14507225262267248, 1.2406794599124362, 10.109105229377747, 30.92589691707066, 55.90694291251046, 68.75299480983189, 75.86935370309013, 67.80721296582902, 58.59761197226388, 50.45402445111956, 40.50344671521868, 30.867903777531215, 27.625988960266113, 19.22825370516096, 17.727828434535436, 14.327762195042201, 26.25668488230024, 34.54967083249773, 36.87432616097586, 18.45692549433027, 10.907812816756111, 4.534963284220014, 2.293261847325734, 0.4431410969368049, 0.19318086041935853, 0.0908743833590831, 0.11064599813627345, 0.28925432158367975, 0.635196715593338, 0.9927549234458378, 1.5738268004996436, 2.2207940902028764, 4.505159854888916, 2.9129282534122467, 3.7022090894835333, 3.6446801764624457, 4.685503823416574, 4.1028482999120435, 8.54455155985696, 6.95926924262728, 3.6464380707059587, 5.96000885111945, 6.111714516367231, 6.000551155635288, 6.388579819883619, 1.388926659311567, 0.8667174779943058, 0.12672655204577105, 0.14995287358760834, 0.37562865391373634, 0.5599742691431726, 0.23393515284572328, 0.08747961837798357, 0.27896906062960625, 0.8643076473048755, 0.9196587886129106, 5.460881965500968, 7.493093694959368, 4.969100628580366, 3.645566940307617, 6.352490442139762, 6.616450335298266, 3.8323636140142168, 4.888178867953164, 9.846844605037145, 5.5418567061424255, 6.157709419727325, 5.711609448705401, 4.847765973636082, 2.51565739938191, 2.5074333378246854, 2.5986924980367934, 1.9668298321110862, 3.8035437890461514, 2.2276938685349057, 1.0356293256793703, 0.8922697497265679, 0.8104896151593753, 0.3469896992402417, 0.15381095585014137, 0.08764094686401741, 0.05234925828075834, 0.0910203769536955, 1.0799804372446877, 3.230216005018779, 15.328804799488612, 28.006437574114116, 44.05722795213972, 66.65126201084682, 82.40038245064872, 75.82877622331891, 55.863336018153596, 43.92475012370518, 33.046382904052734, 16.394165141241892, 13.18933459690639, 24.79607973779951, 36.752708366939, 34.66259643009731, 49.61854178564889, 51.30807270322527, 55.24891029085432, 39.1945971761431, 19.723245109830582, 2.7204101724284033, 0.023428248474374413, 0.08535896574280091, 0.04267513346193092, 0.029268499463796616, 0.03433575148561171, 0.025983353511297276, 0.06676191543894154, 0.01644850818307272, 0.002216270729799622, 0.0239826489040362, 0.020088236180267165, 0.04122398454429848, 0.03855910611205867, 0.04620807870690312, 0.06388952742729868, 0.01159499554030065, 0.06299807490514857, 0.018433129814054285, 0.05092445687790002, 0.008996370963619223, 0.0976456335878798, 0.0066274682342606995, 0.022771832000996386, 0.06442773461874042, 0.0705508685537747, 0.04489880806899496, 0.047109434447650395, 0.04731294406311853, 0.0784413894372327, 0.02045242119181369, 0.03496256177978856, 0.02200304334317999, 0.0037277742771298756, 0.02760831087029406, 0.04667832383087703, 0.002385259876194011, 0.01669347459184272, 0.045163324767989774, 0.050641748655055246, 0.025968990621290038, 0.008166947568367635, 0.015232683691595281, 0.0786434028829847, 0.020402967863317047, 0.035185562313667366, 0.00416246840697048, 0.10183180110262972, 0.03824957539992673, 0.02036046442974891, 0.04874170471781066, 0.058286843422268114, 0.020614916758079613, 0.04201404357861195, 0.01912943396850356, 0.02409632726838546, 0.027508664610130445, 0.03808871849573084, 0.024584529821627905, 0.028891301846929958, 0.059590153130037446, 0.010650316186781441, 0.04489134757646492, 0.02743659570946225, 0.07839170710316726, 0.06659618326063667, 0.03353910387626716, 0.0649103969335556, 0.026306670358670608, 0.04533252765291503, 0.06386433342205626, 0.07310021961373941, 0.05520592802869422, 1.971987132515226, 12.447385106767927, 35.68369674682617, 66.4874095916748, 77.22389807019914, 84.02663612365723, 77.6388166972569, 68.0894696371896, 60.3432218006679, 49.23905897140503, 39.74570049558367, 36.4182950428554, 29.04198840686253, 26.412046602794103, 22.08574206488473, 31.56745535986764, 32.61068916320801, 32.24211502075195, 18.52157153402056, 9.848571232386998, 4.3194796698434015, 1.4221032219273704, 0.3510179987975529, 0.17234433921320097, 0.2990103252232075, 0.3504416782941137, 0.911513979945864, 1.8462438455649783, 3.573800734111241, 4.814737277371543, 4.55106486592974, 7.380555459431239, 6.319468259811401, 6.235880996499743, 5.786247866494315, 7.768931099346705, 7.459727576800755, 12.600530351911273, 13.809558595929827, 5.761906155518123, 7.052023785454886, 9.059512087277003, 7.9657761710030695, 7.440963097981044, 3.025361397436687, 1.2013254059212548, 0.5925021522811481, 0.045284080252583535, 0.43556416779756546, 0.6466187941176551, 0.41275062624897274, 0.11698284346078124, 0.22266502545348235, 1.1679191184895379, 3.0454154184886386, 5.219630088124957, 7.476808854511805, 7.364849056516375, 6.306133798190525, 10.077788829803467, 9.363466245787484, 8.000336510794503, 10.265217355319432, 9.762703657150269, 9.157995854105268, 7.895711404936654, 7.013073921203613, 6.204932851450784, 6.815505802631378, 6.196289726666041, 6.150987471852984, 5.602519256728036, 5.817449620791844, 3.892112042222704, 4.0627849868365695, 2.1709878827844347, 0.9712487288883754, 0.9816433425460542, 0.6983734284128461, 0.3527246500764574, 0.035556419020784755, 0.11413820753140108, 0.6427305170467922, 3.8817201427051, 12.549572263445173, 29.138820239475795, 46.18968915939331, 70.57896055494035, 86.7995023727417, 84.32130922589982, 57.48686599731445, 42.07566772188459, 35.27317632947649, 22.982283762523107, 20.45170988355364, 30.58331945964268, 47.667848927634104, 44.72004093442644, 56.1411771093096, 60.32820674351284, 64.66222204480852, 46.39806910923549, 23.89000337464469, 4.46783630337034, 0.1095934681860464, 0.04830523028171488, 0.039712513863508186, 0.04233650038284915, 0.03518312976562551, 0.009178422757291367, 0.035829190098281415, 0.03123662421213729, 0.04793013273073094, 0.002916069975721517, 0.03331020348040121, 0.06493139759238277, 0.047706022792096646, 0.034247708174266984, 0.028304606543055603, 0.030096739663609436, 0.037423655789877684, 0.006602573208510876, 0.07180835000638451, 0.04221791960299015, 0.020555631457162753, 0.02993569616228342, 0.02842260547913611, 0.07977937906980515, 0.03271628177857824, 0.019632788208712424, 0.01631666543627424, 0.06725428758987359, 0.018464622320607305, 0.007003663315637303, 0.07610746646033865, 0.024147066420742443, 0.021914353727230003, 0.05524427204259804, 0.04496948088386229, 0.016071064597261802, 0.0773350652307272, 0.0956315788041268, 0.10076920169272593, 0.11771328640835625, 0.13033310137689114, 0.08326432814023324, 0.18099088381443704, 0.19882036851985113, 0.12587378280503408, 0.12808119292770112, 0.11452763234930378, 0.12149242790681974, 0.14992518935884747, 0.15571483011756623, 0.134781861943858, 0.1471335877265249, 0.12073088091398988, 0.14567168402884687, 0.24648213386535645, 0.13729917258024216, 0.10917276968913418, 0.10506568543080773, 0.09815365954169206, 0.17906142877680914, 0.13260301814547606, 0.10725864275757756, 0.14471919728176935, 0.19279060778873308, 0.20149359293282032, 0.0722459711666618, 0.1728269811719656, 0.08044682682624885, 0.1322420917983566, 0.18455579823681287, 0.1439776127891881, 0.26410002421055523, 3.073374752487455, 17.814133746283396, 45.0164406640189, 77.13828931535993, 87.71036257062639, 98.26890073503766, 85.04429708208356, 75.70647403172084, 65.7238998413086, 54.24089690617153, 42.62275150844029, 38.68310553686959, 28.10905725615365, 26.52510247911726, 23.326037202562603, 37.650478158678325, 47.817238671439036, 49.06564235687256, 24.95015604155404, 13.42365390913827, 5.906324897493635, 2.613106970276151, 0.7522232159972191, 0.40864304666008266, 0.24103121778794698, 0.4233048584844385, 0.6920872628688812, 1.5827756460223878, 3.97265773160117, 6.893226180757795, 7.470875092915126, 11.732491901942662, 12.123178686414446, 11.438537069729396, 13.567709173474993, 13.168592487062726, 12.289898106030055, 19.577626500810894, 19.6955634866442, 15.301065853663854, 16.253608294895717, 19.124880143574305, 17.837083646229335, 17.147756338119507, 6.579478536333356, 4.809583016804286, 2.0124734171799252, 0.2636470342321055, 1.2540781923702784, 1.647133769733565, 1.0153786923204149, 0.39131299086979454, 0.4029115427817617, 1.7320423849991389, 3.165062746831349, 15.112952062061854, 18.081538643155778, 15.502275262560163, 14.545219097818647, 17.244268553597585, 17.28574582508632, 12.760133947644915, 15.600534949983869, 20.49552001271929, 17.919138397489274, 16.052339826311382, 15.91016057559422, 12.993864400046212, 8.152300562177386, 10.547533086368016, 10.273448365075247, 6.809175559452601, 10.080292786870684, 5.2393560239246915, 4.2195276618003845, 2.693401438849313, 2.2395894016538347, 0.6796395650931767, 0.6830443452511514, 0.29542253060000284, 0.20753020686762674, 0.16160159637885435, 1.9533831136567252, 4.106102228164673, 18.999338354383195, 33.23762512207031, 50.147518566676546, 71.26831912994385, 86.59664971487862, 81.0472138268607, 63.185139247349326, 54.983624594552175, 45.89661414282662, 26.477727924074443, 24.211154324667795, 38.00692769459316, 51.83897066116333, 48.56631701333182, 66.69457708086286, 69.84871183122907, 74.93272958483014, 57.66324601854597, 32.79713017599923, 6.800801243100848, 0.3935467552925859, 0.13100010130022252, 0.16107179623629364, 0.15942724448229584, 0.10216690919228963, 0.08553648407437972, 0.2113908404218299, 0.09784270729869604, 0.19861397173787865, 0.10643900638180119, 0.1835387692387615, 0.24277247435280255, 0.10642717951642615, 0.07574193286044256, 0.10362985104854618, 0.17381179332733154, 0.18158745180283273, 0.06071516419095652, 0.12418291425066334, 0.11268783214368991, 0.2670976019331387, 0.08494851991002049, 0.09319563808717898, 0.10984592392508473, 0.14696457822407993, 0.14001472400767462, 0.12813475648207323, 0.11135515544031348, 0.1082606218489153, 0.086991629563272, 0.12155382175530706, 0.1396317859845502, 0.10192827521158115, 0.1438858884253672, 0.08873614988156728, 0.12154889559107167, 0.18367125998650277], [0.02554593251885048, 0.0325671533521797, 0.025668962792094265, 0.033029866737446616, 0.02136705755921347, 0.0395460352966828, 0.02818603254854679, 0.014054596773348749, 0.024456893991945044, 0.03794533047559006, 0.022214742876323204, 0.017320108466914723, 0.03181063091116292, 0.015825375548696945, 0.026992034832281724, 0.012036331679805048, 0.04526373438004937, 0.012722588426965688, 0.013486249056378645, 0.04611317201384476, 0.03417760193614023, 0.06449623951422316, 0.050345181354454586, 0.043859105823295455, 0.05170357792771288, 0.02015236282854208, 0.036401049233973026, 0.02001839117812259, 0.027032477215730717, 0.021350818519879664, 0.027682371271241988, 0.022619019129446576, 0.023129063724939312, 0.07936520807977233, 1.4883227029017039, 11.752262132508413, 42.804224559238975, 57.96009390694754, 71.14928259168352, 70.90441417694092, 61.11477061680385, 55.40162474768502, 50.57231058393206, 35.32683726719448, 39.21168279647827, 21.38169847215925, 22.984646150044032, 21.899452175412858, 31.24397155216762, 34.39781447819301, 38.46109669549124, 35.14933163779122, 22.917166982378276, 9.183520061629158, 3.3700971390519823, 0.40824729789580616, 0.062219442400549135, 0.03787489175530417, 0.060551230130451064, 0.21013473639530794, 0.33491603710821694, 1.3477629252842493, 1.768548111830439, 3.293961601597922, 3.0386157376425604, 3.296244953359876, 3.4957967826298306, 2.9045005227838243, 4.096698709896632, 2.798880304609026, 4.821505257061549, 5.700276502541133, 14.573316744395665, 6.088859719889505, 4.956632520471301, 7.988056438309806, 7.256813253675189, 5.312382025378091, 5.267584817750113, 3.6917003733771185, 0.6303716802171299, 0.638099054140704, 0.052453786600381136, 0.8751887434295246, 0.027006397722288966, 0.12623958103358746, 1.9494172121797289, 5.994307330676487, 7.897541386740548, 10.027961560658046, 3.5503718427249362, 6.8490230441093445, 4.192450097629002, 8.537097011293683, 6.09338994537081, 5.526813856192997, 6.722492439406259, 5.628656642777579, 6.5723740032741, 9.137572492871966, 4.124253528458731, 5.4802131567682535, 6.8359178730419705, 6.775183234895978, 4.340016807828631, 5.090498685836792, 5.902388742991856, 4.542584155287061, 3.890969063554491, 4.4302617481776645, 3.0251182104860033, 1.7872963058097022, 0.7419343452368463, 0.7382014255438532, 0.08427581350718226, 0.1183452739247254, 0.0630481643602252, 0.026712629378640225, 0.21109110436269216, 1.5579833877938134, 5.117817265646798, 15.945580754961286, 28.525322096688406, 27.15246401514326, 31.298045907701763, 56.953883579799104, 67.67446068355015, 50.35145166942051, 38.31664712088448, 26.090119191578456, 43.48526961462838, 28.73273798397609, 26.998740332467214, 41.513992718287874, 45.663408279418945, 47.144719055720735, 48.300680433000835, 31.716542857033865, 13.25826506955283, 2.5820244210106984, 0.04221662699377962, 0.03031481403325285, 0.008221858014751757, 0.05671374140573399, 0.013640450380210365, 0.04877978749573231, 0.0151995406486094, 0.021687952036570226, 0.045838256765689166, 0.05047907327700939, 0.02069579134695232, 0.07657486173723425, 0.04060505882703832, 0.02925825019233993, 0.02304433675349823, 0.008922783840846802, 0.011716426167237972, 0.027942424906151633, 0.033625983500054905, 0.012883233288968248, 0.032254715117492845, 0.01575885876081884, 0.027572994818910956, 0.05795262421348265, 0.017399549650560533, 0.05345838483689087, 0.0414030499357198, 0.013976633099706044, 0.02238912637611585, 0.018739683453791907, 0.053758772289646525, 0.03289998495685203, 0.045340955057846646, 0.017222051675032293, 0.049052131096167226, 0.03203995878409062, 0.020870824544025317, 0.07112448170248951, 0.008148415080670799, 0.07655700269554343, 0.06778437950249229, 0.036907161719032695, 0.009066270248565291, 0.0025271018967032433, 0.018376163406563655, 0.04325104345168386, 0.060082382788615565, 0.038955791254660914, 0.07086846365460328, 0.04563340704355921, 0.028794753099126474, 0.05375121340953878, 0.03132978367752262, 0.02943056755300079, 0.014003982301801443, 0.031857683922031095, 0.04689226592225688, 0.07505608323429312, 0.04095856539372887, 0.06745328834014279, 0.01298429853548961, 0.01912748996567513, 0.04858721586476479, 0.0829828582437975, 0.052281340318066735, 0.01571751053311995, 0.022899279537211572, 0.009949716057495346, 0.06115479381488902, 0.04271952661552599, 1.4733598658016749, 14.427260398864746, 48.29069587162563, 67.66148144858224, 80.21480573926652, 79.72174767085484, 72.12939548492432, 64.34197262355259, 62.26713630131313, 48.9798321042742, 48.32003116607666, 32.361321789877756, 28.133605241775513, 23.67566360746111, 28.388086489268712, 22.76679059437343, 32.92953157424927, 28.750421149390085, 18.639776025499614, 6.164097419806889, 3.100520278726305, 0.46601611375808716, 0.0867430754005909, 0.19152348435350827, 0.2771808494414602, 0.6214632753814969, 2.086753351347787, 4.85439716066633, 5.319281586578914, 6.038417535168784, 6.163869432040623, 8.092290707996913, 6.289299615791865, 7.812999180385044, 7.398643357413156, 8.619689379419599, 9.715531468391418, 10.71015133176531, 9.079149433544703, 9.87869427885328, 9.210477335112435, 9.978337526321411, 8.866012573242188, 10.583828738757543, 7.772624935422625, 6.285517190183912, 2.1645942372935156, 1.0249812113387244, 0.3244333496051175, 0.9545259347983769, 0.14836013476763452, 0.09541376906314067, 1.619233821119581, 4.4594884770257135, 7.185298919677734, 7.3866941928863525, 4.1358479005949835, 2.6316938357693807, 4.3858449544225415, 6.778304278850555, 8.789617129734584, 8.00915811743055, 6.773807057312556, 8.078548039708819, 7.28242735351835, 5.413037104266031, 7.598732369286673, 6.3464802503585815, 9.26193048272814, 6.485517178262983, 7.686367392539978, 9.169071282659258, 7.180853809629168, 6.920718899794987, 6.494534202984401, 7.198897847107478, 4.8199770876339505, 4.049308955669403, 3.215957432985306, 1.490807118160384, 0.7037847180451665, 0.38673154956528116, 0.37361074505107744, 0.07879056355782918, 0.2920337367270674, 1.5124130845069885, 6.443512712206159, 18.83064477784293, 38.03931672232491, 34.403081212724956, 33.739483083997456, 46.541059562138145, 58.706455503191265, 44.00838211604527, 35.72992658615112, 29.843086174556188, 52.68646328789847, 34.6504614012582, 34.80059460231236, 49.00326490402222, 56.01810366766793, 56.043773787362234, 56.867764132363455, 38.69843673706055, 16.396112373897008, 3.0491235852241516, 0.034526436789227385, 0.04629120263936264, 0.0529308849280434, 0.05007138568907976, 0.02362451981753111, 0.10210744916860547, 0.06383322259145123, 0.02281841173368905, 0.01483269069077713, 0.048442372387009006, 0.05183438930128302, 0.029489851157580103, 0.03644269432074257, 0.013301290588320365, 0.08961681369692087, 0.07611723057925701, 0.04025232918294413, 0.0474404238297471, 0.06588209300701107, 0.08196754593934331, 0.037797864459987195, 0.03212662466934749, 0.03410934470593929, 0.03714581944846681, 0.07097126170992851, 0.02605669466512544, 0.002899317582237667, 0.031143946506615196, 0.058214803359338214, 0.031926100607961416, 0.029258603030549626, 0.02590849922437753, 0.02304756488384945, 0.05201194495228784, 0.06888858667973961, 0.04566840587982109, 0.08523212040641479, 0.11958364104585988, 0.09303903220487492, 0.22111945838800498, 0.09017066112054245, 0.18709316636834825, 0.1324209129171712, 0.12731389195791312, 0.08179517090320587, 0.11846196837723255, 0.10628761843379055, 0.10909135227224656, 0.11669666453131608, 0.09518815616944007, 0.0783165797059025, 0.11814212054014206, 0.11075615829655103, 0.14691177462892874, 0.09521980304270983, 0.11948271574718611, 0.11195647317383971, 0.22418677593980516, 0.07849564509732382, 0.17023812580321515, 0.07819833819355283, 0.10749955661594868, 0.16229628053094658, 0.1311910953372717, 0.11525116781038897, 0.08911886398813554, 0.1408046201935836, 0.14389654142516, 0.18629834401820386, 0.23014244064688683, 3.1926811848367964, 21.510426010404313, 59.815228189740864, 79.4678396497454, 91.8021080834525, 87.4877700805664, 77.9864559173584, 70.7362538746425, 63.89760753086635, 48.59157024111067, 50.02832569394793, 30.6473297391619, 32.20522008623396, 30.144790853772843, 43.02623687471662, 48.34222371237618, 51.5769818850926, 43.71000909805298, 28.39760204723903, 11.006172384534564, 4.341736921242305, 0.9189254279647554, 0.21279892272182874, 0.2890184356697968, 0.1806507342095886, 0.41377225571445053, 1.3661742401974541, 4.929998338222504, 6.574119738170078, 8.836055415017263, 8.774727140154157, 10.710219076701573, 12.63001503263201, 12.139974219458443, 12.823406849588666, 12.746842043740408, 15.601874215262276, 16.035582508359635, 26.524501459939138, 14.432508025850568, 16.35997826712472, 18.001017706734793, 19.784067903246196, 13.701424649783544, 13.67530723980495, 8.045669163976397, 1.6525817002568925, 1.506352192589215, 0.402612173131534, 1.7320187176976884, 0.26275527636919704, 0.29806539735623766, 2.1673611402511597, 6.078211605548859, 9.507805517741613, 13.304005929401942, 11.74145942074912, 18.108848537717545, 14.119239807128906, 18.620301961898804, 18.13889081137521, 14.696329389299665, 18.886697632925852, 15.522421564374651, 18.57093153681074, 17.84759627069746, 11.912503225462777, 11.952926107815333, 19.668201480592998, 18.513242380959646, 13.073817321232386, 17.72588641302926, 14.271751029150826, 11.18435980592455, 11.334322776113238, 10.74654425893511, 7.791378991944449, 5.99815446138382, 3.4041530830519537, 2.2802526482513974, 0.6850036286881992, 0.40495064907840317, 0.3910666826580252, 0.09973703457840852, 0.4452005592840058, 2.0194179245403836, 6.8465160472052435, 21.346132380621775, 35.884923526218955, 36.874510288238525, 41.85552794592721, 65.7457241330828, 75.9858819416591, 59.80966963086809, 49.28251995359148, 38.646280084337505, 55.79056058611189, 39.76690639768328, 41.1020062310355, 57.48062651497977, 62.358713558741975, 65.1423773084368, 68.03995677403041, 50.87288270677839, 23.162290743419103, 4.609710701874324, 0.10975934285670519, 0.13990724406072072, 0.09056836406567267, 0.11314856420670237, 0.14164225810340472, 0.19349143946809427, 0.13887255958148412, 0.16712453216314316, 0.1538720511432205, 0.1536671742796898, 0.16052225072469029, 0.1299036701342889, 0.13526206117655548, 0.16098455020359584, 0.2233090637517827, 0.130936115447964, 0.14362526312470436, 0.10563136650515453, 0.1506177293402808, 0.18303091291870388, 0.16478853965444223, 0.1491825327809368, 0.09023772752178566, 0.10829786663608891, 0.15097761074347155, 0.08134393833045449, 0.264064686106784, 0.1071006798052362, 0.13549194884087357, 0.12599579697208746, 0.14210421831480094, 0.1559675165585109, 0.1046900280884334, 0.1022648692929319, 0.21771143483264105, 0.1104928052851132], [0.1431718524545431, 0.021455993144107715, 0.08699198918683188, 0.02672472256901009, 0.03315901230754597, 0.08059413677879743, 0.017505226390702382, 0.04019004984625748, 0.037403940954910855, 0.12804664192455156, 0.010170536797626742, 0.027229038632607887, 0.062261945834117274, 0.07075598968991212, 0.06927558234227554, 0.06386184998388801, 0.044624377973377705, 0.010496126737312546, 0.06437173512365137, 0.01800432282366923, 0.029446424916386604, 0.04729732757966433, 0.0072348245053685135, 0.08828427948589836, 0.007673434630435492, 0.03574576421773859, 0.024442836442696195, 0.051137106360069344, 0.07788959797471762, 0.00923771145088332, 0.03188519512436219, 0.06895057085369315, 0.033483938979251046, 2.1078244149684906, 10.978264076369149, 34.66310017449515, 63.12172998700823, 71.58933980124337, 66.1081213269915, 59.69836643763951, 53.81959635870797, 45.722756317683626, 36.90567990711757, 31.128940650394984, 28.012289694377355, 24.366286754608154, 26.494217736380442, 34.532651220049175, 44.59761367525373, 42.56892728805542, 37.31389004843575, 16.196278708321707, 4.145379960536957, 1.0631808872733797, 0.060643938370049, 0.15680138181362832, 0.1815314862344946, 0.40118157703961643, 0.4666155587349619, 1.3326653582709176, 1.966650481734957, 3.8031295027051653, 4.749261796474457, 5.214213533060891, 5.71989951814924, 5.206398980958121, 6.202051520347595, 5.552243394511087, 5.068710003580366, 6.431412424360003, 7.507373111588614, 6.068798967770167, 4.913403000150408, 17.372245686394827, 2.8920871317386627, 4.829348470483508, 5.011956683226994, 8.320239390645709, 4.27568473986217, 1.8907107966286796, 0.424233040107148, 0.27398334816098213, 0.40061331753219875, 0.08524565718003682, 0.3687254286238125, 1.5339242730821883, 11.273181234087263, 17.65950506074088, 20.42682491030012, 21.626728432519094, 7.988916277885437, 2.177350912775312, 5.823411175182887, 3.040422486407416, 7.845580152102879, 6.703064407621111, 5.127486552510943, 9.31447536604745, 4.775400051048823, 3.294517457485199, 7.0871412839208325, 4.6109166485922675, 3.710344127246312, 4.854173081261771, 6.070875610624041, 3.4995097262518744, 4.974327410970416, 5.808220676013401, 2.9812427248273576, 6.616955382483346, 2.2369532116821835, 0.9552410564252308, 4.688480692250388, 1.7601562078510011, 1.735401839017868, 0.38010619793619427, 0.3499181206737246, 0.20310995834214346, 0.028473768715879748, 0.21698741082634243, 0.8413884714245796, 3.3471765518188477, 11.728466289384023, 29.93237747464861, 55.108504567827495, 72.05389635903495, 86.08000251225063, 57.668290410723, 36.687947681971956, 23.071769612176077, 17.414112057004655, 22.93932478768485, 26.342625413622173, 31.05210052217756, 42.904726777757915, 52.215100969587056, 44.58531188964844, 36.285994393484934, 27.33680146081107, 5.572237270218985, 0.27069280615874697, 0.01221107310682003, 0.02908739846731935, 0.05343263104025807, 0.027882983542180488, 0.034152563993952105, 0.060743567666837146, 0.026992637032110776, 0.03456462474007692, 0.02974308721188988, 0.028389396278985908, 0.03416553419083357, 0.04488616017624736, 0.02215279432545815, 0.04521954478695989, 0.07578802574425936, 0.09962806863976376, 0.0802311273291707, 0.053638647842620096, 0.07012696737157446, 0.09371234928922993, 0.08988298262868609, 0.0023141913905939354, 0.10494010895490646, 0.06519132400197641, 0.0036487228270354016, 0.019860860791855624, 0.02448257484606334, 0.10117753728159837, 0.0356782364126827, 0.08265463728457689, 0.015350343360166465, 0.023388035096494213, 0.023185534801866328, 0.06891370604612998, 0.024957038761515702, 0.08486613897340638, 0.02548154633093093, 0.018332910191799914, 0.049930976437670846, 0.012312605694335486, 0.03700821254668491, 0.033502829394170215, 0.04838520920436297, 0.08009345935923712, 0.08548121061176062, 0.03460950983156051, 0.010301225186724747, 0.02976821336363043, 0.042927321179636886, 0.04750966154304998, 0.007404594815203122, 0.047964690519230704, 0.03929940478077956, 0.036170252332729955, 0.06631959203098502, 0.04206183958532555, 0.029878251387604644, 0.029299182817339897, 0.059139931574463844, 0.012515549581231815, 0.09219283796846867, 0.07330095741365637, 0.0799402054399252, 0.08076802494802646, 0.04631832707673311, 0.04074526112526655, 0.01890341904280441, 0.04290295159444213, 2.706655127661569, 13.562263522829328, 38.400206157139365, 71.23226492745536, 78.1833748136248, 77.36433506011963, 70.00660269601005, 62.66624777657645, 57.329444135938374, 46.490553106580464, 41.61832339423043, 39.93349640710013, 24.64925561632429, 27.313677855900355, 32.05093881062099, 32.12888717651367, 37.174220834459575, 29.505744184766495, 13.689270513398306, 4.262560895511082, 1.1658370473555155, 0.15538301292274678, 0.1398456466517278, 0.23157906212977, 0.6508631120835031, 1.8214132636785507, 3.0661156220095496, 5.835959187575749, 5.088073330266135, 7.386091436658587, 7.915921977588108, 7.859918628420148, 8.743709513119288, 8.545545152255468, 9.53002759388515, 10.083490695272173, 8.552515063967023, 8.038151213100978, 8.212331260953631, 5.399952777794429, 7.4396620477948865, 7.736859083175659, 8.566153509276253, 7.871805259159633, 8.81739776475089, 5.587864637374878, 3.4650955157620564, 2.125282632453101, 1.0086091927119663, 1.1464065185614993, 0.12618499967668736, 0.33812860186610905, 1.3093605573688234, 10.466101935931615, 15.749222925731114, 19.198795080184937, 16.41238158089774, 6.540912125791822, 2.7469303607940674, 4.377838458333697, 6.011775970458984, 6.158755557877677, 7.361070105007716, 7.0283699461391995, 6.90413441828319, 6.419673877102988, 4.5501168710844855, 7.503782629966736, 5.832832932472229, 6.915132982390268, 9.224533540861946, 9.208657775606428, 11.024987237794058, 10.289531707763672, 9.315072042601448, 7.702291795185634, 6.988746975149427, 6.7442138109888345, 4.8252082126481195, 5.9122499738420755, 3.790924991880144, 2.1772805622645786, 1.9993906106267656, 0.34281087347439354, 0.4137439743748733, 0.06428936775773764, 0.2466616199484893, 1.1671810895204544, 4.188886974539075, 10.966177684920174, 25.517113413129533, 48.81014667238508, 68.7520637512207, 86.11171409061977, 67.35900551932198, 46.89902033124651, 31.347041130065918, 25.70434478351048, 29.032316514423915, 31.08594172341483, 38.23244537625994, 50.47018943514143, 59.14371953691755, 53.16360650743757, 44.88828808920724, 31.532964502062114, 6.688059772763934, 0.3251088990696839, 0.010007224444832121, 0.05748929336134877, 0.03263110527768731, 0.07024790945329837, 0.027890435553022792, 0.053617976273276975, 0.04112795487578426, 0.03059204647849713, 0.00889295628959579, 0.05276896272386823, 0.02732416076053466, 0.024227274348959327, 0.017317816714889238, 0.0614433204755187, 0.04351919370570353, 0.02726930459695203, 0.030314098178808178, 0.013309010620495039, 0.023124758420245986, 0.015662058955058455, 0.05025190993079117, 0.03350762324407697, 0.06562022598726408, 0.029172625858336687, 0.06297365442982741, 0.034811387570308785, 0.05774433431880815, 0.01374734509071069, 0.0602977362328342, 0.019638635484235625, 0.028531332234186784, 0.08381260479135172, 0.02815875204812203, 0.06037838690515075, 0.022420976809891205, 0.143016481505973, 0.11750266913856779, 0.15431235251682146, 0.15250151897115366, 0.1134721507717456, 0.11946668875004564, 0.13536475066627773, 0.14834067438329968, 0.1179242158042533, 0.24546256714633533, 0.09688148102057831, 0.11148945787655455, 0.12133990680532795, 0.22247614844569139, 0.18629282074315207, 0.19463759368019445, 0.14765611397368567, 0.08402738826615469, 0.20011354769979203, 0.11465632330094065, 0.10647684827979122, 0.11764479508357388, 0.09132918502603259, 0.1803508624434471, 0.10342836686010871, 0.14659960780824932, 0.20880079083144665, 0.13608973819230283, 0.21891443670860358, 0.14303577904190334, 0.11188181396573782, 0.06974702168788229, 0.1841548111821924, 4.1016093492507935, 19.889666625431605, 52.187968254089355, 81.09997844696045, 89.04314517974854, 83.26377255575997, 75.51254980904716, 68.76346574510846, 58.61272430419922, 47.38498081479754, 43.04974610464913, 36.715285369328086, 32.60495342527117, 37.742378507341655, 48.27024384907314, 60.60275786263602, 56.16474192483084, 46.209755556924, 19.978426388331822, 5.226600868361337, 1.37125825881958, 0.2072507454348462, 0.2506950492305415, 0.38697533362678116, 0.6824897921511105, 1.837463059595653, 4.696815056460244, 6.809752259935651, 7.903120790209089, 11.69217584814344, 11.457348448889595, 13.514122928891863, 14.705567019326345, 14.758267368589129, 15.021840333938599, 17.377310923167638, 13.578284331730433, 15.943518877029419, 15.846066917691912, 12.726479479244777, 34.59597362790789, 12.249243327549525, 12.639443738119942, 12.88591023853847, 18.86926633971078, 10.77218050616128, 9.470650894301277, 6.768802183015006, 2.5264021371092116, 1.9821662434509821, 0.24645214261753218, 0.6469574102333614, 1.906325135912214, 10.153228027479988, 12.379073023796082, 16.732102939060756, 20.21256157330104, 11.60856556892395, 10.780714631080627, 15.955410718917847, 11.641340221677508, 16.65265723637172, 17.4832535811833, 16.27389008658273, 20.80704770769392, 15.932797806603567, 10.731640372957502, 14.5114369562694, 12.587303587368556, 10.382679258074079, 14.528941205569676, 16.0375714302063, 13.539421319961548, 16.856286355427333, 14.003585304532733, 13.643777183123998, 15.8638299873897, 11.23949202469417, 6.779458114079066, 8.236935700689044, 4.444425216742924, 4.743531703948975, 1.5946481632334846, 0.7150880257998193, 0.642868449645383, 0.16567386500537395, 0.5590686148830822, 1.4604015839951379, 3.846336007118225, 14.922708647591726, 36.22652128764561, 60.982747895377024, 79.54583317892892, 89.11305795397077, 64.80422932761056, 47.977773325783865, 34.35503441946847, 29.37407582146781, 34.18537678037371, 39.06520782198225, 44.25258002962385, 59.402470452444895, 67.63470309121269, 63.2326649257115, 56.5916531426566, 41.634630816323416, 9.724538939339773, 0.6292860241872924, 0.06342490735862936, 0.199011606829507, 0.20659389639539377, 0.1823073231748172, 0.08535212610981294, 0.1277572060269969, 0.16504551443670476, 0.11843770396496568, 0.12051643670669623, 0.12228066846728325, 0.10983263820941959, 0.12976123206317425, 0.0916552007464426, 0.09874547099960701, 0.22233833798340388, 0.13402297480830125, 0.1537524661315339, 0.07376548248742308, 0.16058211108403547, 0.14095924475363322, 0.226689484502588, 0.11237970260637146, 0.1916306521743536, 0.1295884091939245, 0.11797467166824, 0.1001136147284082, 0.15649267552154406, 0.190366337874106, 0.07345943605261189, 0.11715236864984035, 0.1063843300299985, 0.12197739045534815, 0.18746443358915194, 0.16078607871064118, 0.11681762018374034], [0.11489537118801049, 0.0676800547433751, 0.051858619786798954, 0.042124071424560885, 0.027321373677945564, 0.06521095402006592, 0.0294996424178992, 0.11399495521826403, 0.0298310830257833, 0.08633249386080674, 0.04499124828726053, 0.039381487161985466, 0.041231516283005476, 0.014637613569253256, 0.09024722701204674, 0.0801541203899043, 0.08972026314586401, 0.060431204071002345, 0.09814131020435266, 0.045692449768206904, 0.07823309275720801, 0.0532266820913979, 0.08085658733866044, 0.061407704172389846, 0.02536373908099319, 0.04492420224206788, 0.004339502858264106, 0.04647699570549386, 0.07139966157930237, 0.03682017352964197, 0.029235278389283588, 0.06103396029876811, 0.5758892808641706, 7.337563480649676, 21.200089931488037, 60.4791841506958, 70.68721348898751, 70.69064589909145, 62.02592263902937, 45.34401001249041, 33.28567886352539, 28.57616901397705, 29.690170219966344, 21.215339490345546, 17.946300642830984, 35.61097690037319, 38.907334327697754, 38.888709681374685, 45.57139675957816, 19.264118569237844, 9.879015633038112, 3.2701455652713776, 0.7740940824151039, 0.037076483347586224, 0.12474696684096541, 0.1012250618743045, 0.2248766017811639, 0.09146695477621895, 1.837376207113266, 2.2454013526439667, 7.531180245535714, 6.387534550258091, 7.197486928531101, 8.25344635759081, 7.117920935153961, 8.471582446779523, 5.06252132994788, 8.301788449287415, 7.449549334389823, 9.256126999855042, 6.496789761951991, 8.178760170936584, 3.3930479075227464, 4.338778725692204, 10.702467492648534, 9.906479256493704, 6.28211213861193, 8.43621437890189, 5.844480284622737, 4.701063445636204, 3.864993223122188, 1.4078819964613234, 0.34342891031077927, 0.014213346826311733, 0.4504963079733508, 5.96504716362272, 29.062315361840383, 42.96389763695853, 45.047075271606445, 31.786323615482875, 18.1201845237187, 2.7088596607957567, 1.8976763657161166, 4.227997515882764, 4.160293400287628, 5.952531720910754, 3.42335290993963, 3.8970135620662143, 2.7870219009263173, 1.459960699081421, 6.070638937609536, 4.733273991516658, 7.92138934135437, 3.57511676635061, 7.374890940529959, 10.274848427091326, 5.756346728120532, 7.185291971479144, 7.076788902282715, 8.859252844538007, 5.64956898348672, 4.587363123893738, 4.591160314423697, 2.197838327714375, 1.7770594379731586, 1.8713418245315552, 0.8104404892240251, 0.0820256353222898, 0.17664986103773117, 0.06680226791650057, 0.3297384077949183, 0.8561610473053796, 6.092444556100028, 11.74212384223938, 26.472601890563965, 37.68058817727225, 36.50865983963013, 15.444923094340734, 17.94196149281093, 24.785973582948955, 23.528716155460902, 17.300969328199113, 29.6847471509661, 28.90741743360247, 43.786546979631694, 44.67640277317592, 51.70743431363787, 53.184197493961875, 40.81224203109741, 16.61683406148638, 1.5760433844157626, 0.07899614609777927, 0.06517056083040577, 0.18762460856565408, 0.01236201576622469, 0.024716935752491866, 0.0292715189446296, 0.011457795759529939, 0.036070748564920256, 0.028739106442247118, 0.024376991404486553, 0.040059486137969155, 0.045109259097703865, 0.02143158115047429, 0.023223632846825888, 0.1337046604603529, 0.04777081610102739, 0.014870049132566367, 0.13983911914484842, 0.07033381198665925, 0.22182399486856802, 0.05499692567225013, 0.021336927211710384, 0.061003148023571284, 0.033938286027738025, 0.061299701753471575, 0.052847486188901324, 0.1108023529606206, 0.08382401096501521, 0.07453551116798605, 0.05195580975019506, 0.02194868929551116, 0.042710590309330394, 0.015719642829416052, 0.13500052663896764, 0.059305270202457905, 0.059131605949785025, 0.027117979413430606, 0.031392317464841266, 0.12120804030980382, 0.027047131875795976, 0.04661536935184683, 0.04528367991692253, 0.06370244853730712, 0.015063453665269273, 0.11873992346227169, 0.054790508534227095, 0.008232986837226366, 0.02733627430695508, 0.013140931559194411, 0.05525716760062745, 0.018373220260920267, 0.058433739468455315, 0.018637988017871976, 0.09485233561801058, 0.02988185440855367, 0.028254537444029535, 0.02448747556523553, 0.04394986327471478, 0.02914268889331392, 0.05941785951810224, 0.06259411586714642, 0.03937378239684871, 0.02438831445761025, 0.04955594674018877, 0.013743155136970537, 0.023545178717800548, 0.06488533184996673, 0.753843394773347, 8.538089735167366, 26.51329575266157, 68.38595621926444, 79.46827738625663, 80.67202499934605, 70.91163335527692, 56.14811141150338, 45.11624806267874, 37.44357122693743, 40.053564752851216, 28.940379687717982, 19.6631692477635, 33.2850535256522, 39.22090653010777, 34.867641244615825, 40.70211655752999, 22.082933255604335, 12.141138911247253, 4.080931075981685, 0.7325565570167133, 0.04943020063053284, 0.2972747954939093, 0.41923356694834574, 1.6006042893443788, 2.5936808926718573, 4.224225078310285, 4.192986411707742, 7.390153527259827, 8.174572144235883, 9.372122832706996, 8.414994580405098, 9.989559735570635, 8.044031994683401, 9.130117075783865, 10.882031525884356, 8.661838020597186, 8.804493222917829, 8.94936490058899, 6.468006415026529, 5.135074419634683, 7.733384983880179, 5.835294766085489, 5.464159343923841, 6.903606789452689, 4.988800508635385, 4.463780292442866, 1.673699664218085, 1.5109905494110925, 0.8323961996606418, 0.26754700924668995, 0.07078350428491831, 0.5250750418220247, 5.755737892218998, 28.170772893088206, 39.294050216674805, 41.03185721806118, 30.476275512150355, 16.32577575956072, 2.882430221353258, 2.7948106144155775, 3.8485833150999884, 3.801689488547189, 4.426620892116001, 2.46454319357872, 4.185068939413343, 4.139866130692618, 4.115117950098855, 8.245082463536944, 6.5122125915118625, 11.08789883341108, 6.893206204686846, 9.866045083318438, 8.22532786641802, 10.40462861742292, 12.382461139133998, 10.234722580228533, 9.105393648147583, 7.6194267102650235, 8.774742773600988, 10.509607212884085, 5.76776522397995, 4.297155542033059, 4.826120597975595, 2.9645587972232272, 0.6138481040086065, 0.4960742922765868, 0.102132283550288, 0.4021097043795245, 0.7992915074740137, 5.6000179052352905, 13.739847319466726, 34.3852208682469, 48.0422282900129, 51.075433118002756, 24.71795071874346, 22.045664855412074, 26.67482921055385, 25.170408725738525, 23.44424169404166, 35.222346782684326, 37.54320839473179, 47.2759496825082, 50.97035551071167, 56.533048561641145, 59.03623785291399, 45.96971614020211, 18.93777905191694, 2.022961288690567, 0.10365407474871192, 0.023403588815459182, 0.04765366703005774, 0.029102105713848556, 0.07273333572915622, 0.004842061940247991, 0.030531256526176418, 0.030169861989894083, 0.0299590004474989, 0.013258578505233994, 0.021999857621267438, 0.048111494963190386, 0.05672849275703941, 0.018065323121845722, 0.12666293260242256, 0.03604630434087344, 0.030231846163847616, 0.06078450368451221, 0.06030617720846619, 0.08019109376307045, 0.05940528626420668, 0.005657503273271556, 0.03536031900772026, 0.041348309123090336, 0.07170293959123747, 0.01637171158966209, 0.07103360550744192, 0.06283359801662819, 0.09001440129109792, 0.09123968625707285, 0.03851837365488921, 0.02677891037559935, 0.011533259031628924, 0.037610585402165136, 0.06085954287222453, 0.2873074417667729, 0.10459975578955241, 0.13190047655786785, 0.2202358836574214, 0.15457643834607943, 0.14939240366220474, 0.08820315383906875, 0.16275209321507386, 0.14484104860041822, 0.20895641962332384, 0.12353808885174138, 0.16239605232008866, 0.11606352350541524, 0.0878179766503828, 0.14875316939183644, 0.15340952096240862, 0.2434960369552885, 0.17595736176839896, 0.22656661538141115, 0.07290210774434464, 0.17245667747088841, 0.09108580808554377, 0.12457980295377118, 0.15801954216190747, 0.14774724122669014, 0.18438140116631985, 0.11872640704470021, 0.13637935050896235, 0.16256229339965753, 0.08677299200956311, 0.07785803252565009, 0.180479227698275, 1.514321233545031, 14.631229979651314, 35.919414384024485, 81.68930380684989, 88.50962775094169, 87.13907473427909, 78.67508493150983, 61.00434289659773, 45.754450525556294, 40.69348342078072, 39.50807210377285, 29.704118728637695, 25.41917507989066, 47.97314235142299, 50.44523845400129, 51.71068607057844, 57.75692163194929, 27.090239422661917, 12.479529210499354, 4.048605016299656, 1.1458859464951923, 0.14752754515835217, 0.30544392285602434, 0.47346143424510956, 1.74333798459598, 2.7570065515381947, 5.279457552092416, 6.713601350784302, 16.37572114808219, 16.029501097542898, 16.72478822299412, 19.23038853917803, 17.263845103127615, 19.55135362488883, 13.832364320755005, 17.1319283417293, 18.700136763708933, 18.083287852151052, 14.798674617494855, 17.879570143563406, 11.6173654624394, 15.753225088119507, 19.404638937541417, 18.974944966179983, 14.208190645490374, 19.331232956477574, 15.164523329053607, 16.02777620724269, 13.270786591938563, 6.06910685982023, 1.698242221559797, 0.1946498615933316, 1.1166743082659585, 7.1407084209578375, 25.67837241717747, 39.316447734832764, 41.60334307806832, 27.57001427241734, 19.144378525870188, 5.063851041453225, 6.014402823788779, 9.520122068268911, 10.553332226616995, 12.006640025547572, 9.790060452052526, 12.094059654644557, 9.162121347018651, 8.289153150149755, 15.787603037697927, 13.48658982345036, 17.700013058526174, 11.291104112352643, 14.367733444486346, 19.279553992407664, 15.156402621950422, 15.637521948133196, 15.921939509255544, 16.705741473606654, 13.826764941215515, 14.043175271579198, 15.292854819978986, 6.80483032975878, 6.181417107582092, 4.338532064642225, 2.9994915170328955, 0.9433478031839643, 0.648700159575258, 0.20385135284491948, 0.5514195710420609, 1.3936732560396194, 7.4003005027771, 13.611427239009313, 30.740637098039898, 44.523003918784006, 45.427110467638286, 23.895763431276592, 28.35295292309352, 36.455679825374055, 34.956894329616, 27.744657244001115, 42.932279859270366, 43.18492678233555, 55.70388180868966, 59.172415597098215, 67.19508361816406, 68.44779518672398, 55.218018599918906, 26.23358038493565, 3.0509683319500516, 0.2321568482688495, 0.19251361622342042, 0.277670046048505, 0.13886680560452597, 0.1775455136916467, 0.1263729945889541, 0.07655538099684886, 0.12451737773205553, 0.1024912828579545, 0.19634789547749928, 0.08673557758863483, 0.12153194578630583, 0.12036459414022309, 0.1461928260645696, 0.278078659836735, 0.17498768094394887, 0.1282639495496239, 0.2362541684082576, 0.17930346221796103, 0.22072045265563897, 0.1563634281711919, 0.108094801461058, 0.21904107848448412, 0.11143124635730471, 0.1615972944668361, 0.14116144818919046, 0.17975984487150395, 0.20091519611222403, 0.22652806102165154, 0.1937098598905972, 0.11130321358463593, 0.10979220430765833, 0.12911933793553285, 0.15617854094931058, 0.22661248434867176], [0.02905509002240641, 0.06559303030371666, 0.05868036659168346, 0.06527105186666761, 0.033163059768932204, 0.04544845536085112, 0.0955286179003971, 0.1524765081703663, 0.08914471617234604, 0.05066885952172535, 0.049427815579942296, 0.10126288341624395, 0.020569909530292665, 0.019370030611753464, 0.03351694970790829, 0.186608027400715, 0.15176513205681527, 0.05307170808581369, 0.050886316424501796, 0.02991491263466222, 0.03795165102928877, 0.030948107729532888, 0.034546524818454466, 0.12396461596446377, 0.05747116290565048, 0.05084849488256233, 0.010442452072831137, 0.018361966757635986, 0.04278603661805391, 0.02285932739531355, 0.03419124727536525, 0.16298314795962401, 3.923517031329019, 21.039687292916433, 56.44681446892874, 73.86040714808873, 66.12342820848737, 53.84703132084438, 48.726969787052695, 36.95125314167568, 32.0262588092259, 27.85174114363534, 22.473416805267334, 47.35221311024257, 73.04183987208775, 42.668078081948416, 48.72799117224557, 41.58850172587803, 23.978420938764298, 11.792528680392675, 2.285732388496399, 0.16832780545311316, 0.10413654707372189, 0.05010719198201384, 0.15898858516344003, 0.5527341919285911, 1.3152460072721754, 2.456319566283907, 3.077662225280489, 2.8539476011480605, 5.203328745705741, 4.76266313450677, 7.127007876123701, 7.184659685407366, 6.647597806794303, 4.970777750015259, 8.864128742899213, 9.039911219051906, 6.16601425409317, 8.325110077857971, 6.686289719172886, 3.432976599250521, 2.4667527207306454, 4.131559559277125, 5.406801096030644, 8.293139679091317, 8.988728182656423, 5.582808954375131, 3.127833430256162, 2.0595958828926086, 2.9455980317933217, 3.34151029586792, 1.8668380890573775, 1.302455567887851, 4.268253207206726, 20.736784049442836, 53.27258552823748, 55.619885035923545, 66.52971717289516, 50.894185883658274, 36.2541994367327, 10.857984679085867, 3.72551942723138, 5.210971329893384, 6.4549329451152255, 8.050978456224714, 7.787385514804295, 6.5503265006201605, 6.018867909908295, 4.243587970733643, 6.104970855372293, 4.735015383788517, 4.346395688397544, 8.735661762101309, 8.265582254954747, 11.527827501296997, 10.978738290922982, 12.428268875394549, 6.400570673601968, 4.717971018382481, 8.040991289275032, 6.559932819434574, 7.645538909094674, 7.067376698766436, 1.718000944171633, 5.07332273891994, 1.1821484863758087, 0.4136443654341357, 0.5541279028568948, 0.0812043161796672, 0.36156140161412104, 0.02966589367549334, 0.11065633222460747, 1.0276989340782166, 7.178746768406459, 18.727365016937256, 32.231407846723286, 40.84011125564575, 36.07388326099941, 28.59829728943961, 19.07177332469395, 21.574120146887644, 15.812422003064837, 24.38856267929077, 39.35935286113194, 44.563855852399556, 52.144389152526855, 55.29619973046439, 55.513838154929026, 37.26640605926514, 6.194610868181501, 0.2587014910365854, 0.0419543291042958, 0.025393910140597394, 0.03746152143659336, 0.011999599186570516, 0.04260518328685846, 0.017748455749824643, 0.04777695005759597, 0.09692351626498358, 0.04924847198916333, 0.04504772614953773, 0.10090874241931097, 0.12553718872368336, 0.028588817720966678, 0.1365569502647434, 0.023882490349933505, 0.06782585156283208, 0.13129936238484724, 0.27158084564975327, 0.33212229130523546, 0.13985981446291718, 0.038286060227879455, 0.00850696231438113, 0.04084703120003853, 0.08690413925796747, 0.03510764613747597, 0.13888148910232953, 0.12725038108016762, 0.03200580133125186, 0.06912156167839255, 0.15089036471077374, 0.027689799533358643, 0.12839052347200258, 0.04773934903953757, 0.0898059621187193, 0.04423604220417993, 0.050733656223331175, 0.03153359524107405, 0.03897287676643048, 0.026991312192486863, 0.03528570390439459, 0.11466921546629497, 0.045827535912394524, 0.05453998661999192, 0.08143195110772337, 0.07214497801448617, 0.02942688650052462, 0.046971165974225314, 0.07825901279492037, 0.05933524787958179, 0.056802846624382904, 0.0443880238703319, 0.01659701744626675, 0.036465737369975874, 0.0456935557802873, 0.03821527206205896, 0.06540713206465755, 0.023599756682025533, 0.03436456547517862, 0.03941775146605713, 0.055629266026828966, 0.044965060228215795, 0.013126798522924739, 0.08273662467088018, 0.03679556645719068, 0.06728273177785532, 0.22632406625364507, 4.678557796137674, 23.183362892695836, 61.287620953151155, 82.34830570220947, 75.64785902840751, 64.13835566384452, 61.2021233694894, 46.63804599217006, 41.491793223789756, 37.22388308388846, 24.555239541190012, 35.53250741958618, 44.99574545451573, 31.05287872041975, 38.09524972098214, 33.368484020233154, 26.37697730745588, 13.508129239082336, 3.154559459005083, 0.3458917752972671, 0.24471810566527502, 0.08711365730102573, 0.6601357545171465, 1.708027022225516, 3.563560826437814, 4.937771201133728, 5.849505569253649, 5.97064437185015, 8.856928672109332, 8.477841905185155, 8.690712996891566, 15.818831716264997, 12.615587098257881, 13.369444932256426, 9.224472744124276, 11.66325397150857, 12.793863109179906, 9.701791405677795, 6.963343058313642, 6.330468560968127, 6.25814780167171, 3.5094373992511203, 4.826370298862457, 7.848278658730643, 5.537724265030452, 3.8740758214678084, 2.878990645919527, 2.6970373008932387, 3.240757725068501, 3.724855440003531, 1.8074345737695694, 1.6957281678915024, 4.9404067397117615, 20.863651207515172, 52.611891746520996, 58.21769489560808, 66.57159396580288, 51.83620875222342, 35.749169622148784, 11.283473253250122, 4.672746496541159, 4.62622309582574, 6.710998381887164, 6.719220272132328, 5.759188541344233, 6.061485554490771, 5.61925573008401, 5.32636353799275, 6.037842571735382, 5.3645113195691785, 10.043978026935033, 9.45772203377315, 10.919510109083992, 11.372630800519671, 11.070769786834717, 14.772118602480207, 13.379040394510541, 9.156211035592214, 7.252987836088453, 11.04719889163971, 10.911513601030622, 8.22973562989916, 5.4348101530756265, 6.002748089177268, 6.011254855564662, 1.7896238437720706, 1.5925170204469135, 0.7130409670727593, 0.7675473051411765, 0.09474295577300446, 0.3356960266828537, 1.882791804415839, 7.571175813674927, 20.177250828061783, 28.070383582796367, 32.54998970031738, 33.315121855054585, 30.85081468309675, 27.910409995487758, 26.732707704816544, 23.662029504776, 29.18310805729457, 47.14672013691494, 53.10775688716343, 60.91380092075893, 61.46254880087716, 62.51291493007115, 44.07640845435006, 8.297337259565081, 0.2969815326588494, 0.02288878768948572, 0.10087795050016471, 0.0421459507862372, 0.07970343064516783, 0.025113491973440562, 0.08238652095730815, 0.04151301671351705, 0.009492200250471277, 0.011840176535770297, 0.019208825958360518, 0.019600440748035908, 0.10581881180405617, 0.02889023654695068, 0.04542819769786937, 0.053838188028229136, 0.02987333879406963, 0.028341233863362243, 0.19442481866904668, 0.17834252092455113, 0.06402648293546268, 0.03971037308552435, 0.020091832415866, 0.030200823542795012, 0.054130148076053174, 0.03949038524712835, 0.024992237765608088, 0.0219149576233966, 0.030286298599094152, 0.026515547186136246, 0.16451328513877733, 0.052282534539699554, 0.0326014906167984, 0.07575928300086941, 0.01877981880014496, 0.21376006757574423, 0.2997714786657265, 0.16642120347491332, 0.10931758263281413, 0.1069740176733051, 0.21896425474967274, 0.16910390023674282, 0.2115266288497618, 0.20193223868097576, 0.16460321817014897, 0.08838654149855886, 0.1603225442980017, 0.17306798323988914, 0.09910476207733154, 0.18126535122948034, 0.276300382401262, 0.26258119142481257, 0.1508394203015736, 0.15164775906928948, 0.1313083190470934, 0.15357801477823937, 0.1639155229287488, 0.14241250391517365, 0.16785063248659882, 0.24219460678952082, 0.16108780966273376, 0.08351439543600593, 0.13141373624759062, 0.22270936093160085, 0.152633575456483, 0.15098819588976248, 0.4384888708591461, 8.176348277500697, 32.193085057394846, 76.34865433829171, 90.76225457872663, 83.75881086077008, 70.05681732722691, 64.17601490020752, 49.85720198495047, 45.548158509390696, 38.19256271634783, 31.27123280933925, 58.75712871551514, 85.91813727787563, 53.55067328044346, 61.17165551866804, 52.88092252186367, 31.71655327933175, 14.414394072123937, 2.903005357299532, 0.4782531942640032, 0.29552705213427544, 0.12476659007370472, 0.5094512573310307, 2.1622110051768164, 5.122501654284341, 7.026902573449271, 10.40087832723345, 10.234539321490697, 14.778344188417707, 16.851316656385148, 16.94298597744533, 19.54153755732945, 18.848756994519913, 14.30337575503758, 16.8158461025783, 19.775969777788433, 16.211338928767614, 16.06987360545567, 14.56332002367292, 10.43708712714059, 10.49270224571228, 8.583993877683367, 11.259211880820137, 19.81705447605678, 16.7581239427839, 10.048047065734863, 9.587234718458992, 4.818647376128605, 4.976476141384669, 5.911153895514352, 2.9925237766333987, 2.456279831273215, 6.9839114631925305, 23.070588418415614, 49.573941298893516, 54.63545731135777, 66.83554908207485, 49.66550465992519, 36.049568040030344, 16.31959707396371, 9.567467093467712, 11.592146107128688, 11.83574821267809, 12.464876328195844, 11.040362732751028, 10.49935861996242, 11.918839114052908, 9.91300014087132, 12.606229611805507, 10.96981246130807, 11.44883690561567, 18.4916022164481, 21.13225293159485, 24.36903303010123, 19.2381739956992, 22.59886826787676, 17.583363226481847, 16.20030345235552, 17.655386516026088, 13.857128569058009, 20.10324730191912, 14.289513230323792, 7.996039049965995, 12.818220887865339, 5.409282471452441, 1.5566155697618211, 1.2756219506263733, 0.7612384493861879, 0.6705382391810417, 0.15902347543409892, 0.3947296046784946, 2.1096101020063673, 9.666713425091334, 24.637792825698853, 41.47486393792288, 54.581653935568674, 49.98606675011771, 41.9117180279323, 31.131073747362407, 32.25922843388149, 26.494872604097637, 32.884361335209434, 52.34111697333199, 57.334245341164724, 68.09839112418038, 68.29722077505929, 71.21175384521484, 52.64563567297799, 11.822222675595965, 0.6615579639162336, 0.1276671780007226, 0.23833021415131433, 0.243913471698761, 0.20487788133323193, 0.17693180590867996, 0.13290644543511526, 0.18005584898803914, 0.19490470577563557, 0.15220943678702625, 0.1313262459422861, 0.1549255039010729, 0.28263442537614275, 0.14038730758641446, 0.12768486062330858, 0.1518724084432636, 0.1686727183737925, 0.16587121013019765, 0.4065522902778217, 0.5787242544548852, 0.24618270993232727, 0.1513206780489002, 0.09644436876156501, 0.17072392973516667, 0.13000116204576834, 0.200987894354122, 0.21025396856878484, 0.209043896357928, 0.09959030138062579, 0.1930139950875725, 0.324859116758619, 0.24931900735412324, 0.3378843835421971, 0.26723423174449373, 0.13123438587146147], [0.13293250117983135, 0.09145345871469804, 0.020478936644004922, 0.08355568429189068, 0.02893778488838247, 0.05397237850619214, 0.08972712992025272, 0.025929657642596533, 0.04210684002776231, 0.075157958481993, 0.041451612687004466, 0.03770897976521935, 0.06530406938067504, 0.020741843518667986, 0.0772537292380418, 0.17359873333147594, 0.13046297297946044, 0.1306343980665718, 0.11252779965954167, 0.046814325997339826, 0.05782846587577036, 0.06785795305456434, 0.05475273109706385, 0.11071287454771143, 0.07250163637633834, 0.11025171500763722, 0.08272961540413754, 0.05503081849643162, 0.10158509255519935, 0.10159419849514961, 0.02722808698724423, 0.843519885625158, 12.206042902810232, 52.26116752624512, 65.86751215798515, 65.3655812399728, 57.55674403054373, 50.31050246102469, 40.16520145961216, 27.70344226700919, 24.238587549754552, 23.13387782233102, 53.61894627979824, 80.94304643358502, 87.13822705405099, 78.2835053035191, 63.13352108001709, 34.85952227456229, 12.45978329862867, 1.7490791508129664, 0.4083384115781103, 0.16045118096683705, 0.13861436343618802, 0.3326299169233867, 0.7004510483571461, 1.6450125064168657, 1.9883644708565302, 3.8699390377317155, 3.7446056944983344, 4.95010164805821, 5.276664810521262, 6.4755109037671765, 8.949012279510498, 7.967083300862994, 7.901261278561183, 10.163164819989886, 7.965525167328971, 9.830121159553528, 8.85719530923026, 6.314990145819528, 7.317226103373936, 5.970470232622964, 6.792606711387634, 7.236416816711426, 9.467592818396431, 9.677487475531441, 9.316669259752546, 6.066023596695491, 8.515799045562744, 6.80297429221017, 9.831493428775243, 7.329154423304966, 7.181098299367087, 9.236704179218837, 21.250358411243983, 33.67598349707467, 67.12483733040946, 56.4151862689427, 64.30873244149345, 58.244195325034006, 50.97297150748116, 17.72962280682155, 11.517827306474958, 11.046188797269549, 13.902768680027553, 18.304810319628032, 15.617992298943655, 18.68052547318595, 16.537195546286448, 15.008565800530569, 16.53017439161028, 9.297625984464373, 17.914005415780203, 7.306854179927281, 8.200980510030474, 5.674236391271863, 11.866365449769155, 13.683632918766566, 14.262872099876404, 7.0159817423139295, 5.854631168501718, 12.147282855851309, 11.330372725214277, 8.26366194656917, 4.630094110965729, 5.800932449953897, 7.46598356110709, 1.8960300769124712, 1.519256083028657, 0.5055109230535371, 0.5336960735065597, 0.06870673250939165, 0.1361285639660699, 0.1829725724778005, 3.1539147964545657, 10.194102542740957, 29.930359022957937, 42.03197397504534, 36.94087600708008, 24.73919309888567, 24.34616129738944, 16.79304732595171, 21.658071756362915, 23.185125998088292, 25.759004524775914, 34.84572662625994, 46.07796907424927, 53.270917960575645, 56.74788686207363, 43.21725675037929, 20.960536888667516, 2.136999683720725, 0.07124387672437088, 0.021148886498329893, 0.07483074175459997, 0.06433434105877366, 0.11714360197739941, 0.0292172497138381, 0.08324161757315908, 0.08252785980169262, 0.05246232257091573, 0.15876244301242487, 0.14351984592420713, 0.04767894585217748, 0.037557849660515785, 0.10378446882324559, 0.06242224294692278, 0.02431724130708192, 0.16070932282933167, 0.2279001266828605, 0.20854214685303823, 0.296099382851805, 0.086722739706082, 0.050618230631308894, 0.026451493480375836, 0.07607850658574275, 0.10210781557751553, 0.05892750261617558, 0.04839939737160291, 0.01965260143125696, 0.027942331607586572, 0.05377230227791837, 0.029926457908004522, 0.03472105420327612, 0.11508731517408576, 0.045513587937291176, 0.04595333969752703, 0.05160012847876974, 0.07481449084090334, 0.01573709983910833, 0.018568578974476883, 0.029086814927203313, 0.05270847811230591, 0.010099143887470876, 0.08579970816416399, 0.07413583368595157, 0.06193776894360781, 0.05629162137795772, 0.0618694947500314, 0.06815355005008833, 0.02215827688840883, 0.11403049688254084, 0.05982149964464562, 0.06739447971007653, 0.050774571884955676, 0.020991003273853233, 0.07634246349334717, 0.10474578331091575, 0.02701483021623322, 0.020575817873967544, 0.05672027909063867, 0.04322446184232831, 0.018039101136050055, 0.05921955765890224, 0.03694342602310436, 0.02267286936486406, 0.034815614843474965, 0.829205293740545, 13.979081613676888, 57.11437654495239, 75.08195604596818, 75.48643847874233, 67.04482187543596, 59.1208530153547, 48.006601401737754, 36.30497339793614, 30.542026315416607, 23.406108243124827, 44.18573835917881, 69.34886537279401, 75.97552912575858, 67.3207209450858, 56.01601920809065, 35.7397826058524, 14.13589985030038, 2.989756005150931, 0.3237665668129921, 0.20053455153746264, 0.1590580264372485, 0.5087546461394855, 2.5804011481148854, 4.229920864105225, 6.363670527935028, 10.026613610131399, 9.411123071398054, 11.473734038216726, 11.16246690068926, 10.837789739881243, 10.232399276324681, 11.456946321896144, 10.823882920401436, 12.600237659045629, 9.710640805108206, 9.636797956057958, 9.31658501284463, 11.279722963060651, 9.931557042258126, 4.438970446586609, 6.322790367262704, 8.753249389784676, 7.684495721544538, 9.208954811096191, 8.789306197847639, 7.366290807723999, 7.80532055241721, 7.781570741108485, 9.433820230620247, 9.571112292153494, 6.835913530417851, 11.477534702845983, 20.85332097326006, 38.06710951668875, 71.24800259726388, 62.45038114275251, 70.04758317129952, 62.05650860922677, 53.835233279636924, 20.504314695085796, 13.194914868899755, 11.839742558343069, 16.25041559764317, 18.84360316821507, 18.69472759110587, 18.2366623878479, 17.17507665497916, 14.43923475061144, 11.444522074290685, 6.392038285732269, 7.033218051706042, 5.870994176183428, 8.662747366087777, 10.61759350981031, 12.46022972038814, 16.84865549632481, 15.472474438803536, 11.861915128571646, 11.982121569769722, 14.111012271472386, 11.652255841663905, 11.415225863456726, 8.3409788949149, 10.015398349080767, 7.931611010006495, 5.27921827350344, 4.239263585635594, 1.6344920652253287, 1.2463010954005378, 0.19334919138678483, 0.19279242626258306, 0.2342199475637504, 3.115471499306815, 9.908674887248448, 28.287313291004725, 41.80316284724644, 39.40767410823277, 30.463817392076763, 27.875434500830515, 24.078964846474783, 25.499508414949688, 27.505816391536168, 35.19483539036342, 41.55674498421805, 51.79344606399536, 59.32584571838379, 64.54515184674943, 50.02710281099592, 25.974155494144984, 2.9763357767036984, 0.033093377615192106, 0.020588389431525553, 0.06262503670794622, 0.03360451804473996, 0.04104626943756427, 0.009889459603333046, 0.05103144488696541, 0.04135999349611146, 0.0668309156649879, 0.0885418988764286, 0.05184392611097012, 0.07615844479628972, 0.05224207688921264, 0.09809702900903565, 0.015833378869241903, 0.13942716696432658, 0.031296681346637864, 0.2160598263144493, 0.09546166685010705, 0.02550800410764558, 0.01332396044329341, 0.060729420211698325, 0.020805281453898976, 0.04581972936700497, 0.023630865816293017, 0.06504087921764169, 0.02729625770423029, 0.03285419741379363, 0.019740403862670064, 0.05134991190529295, 0.04550499768395509, 0.05563430414934244, 0.13839071829404148, 0.021352852428598062, 0.2906180684055601, 0.22002135802592548, 0.19446909986436367, 0.1049731264689139, 0.10676887618111712, 0.11705601667719227, 0.1805240245802062, 0.2120212944490569, 0.19140000455081463, 0.2318993577999728, 0.1666545109557254, 0.2393563219479152, 0.16930450232965605, 0.15794484902705463, 0.1965322805834668, 0.3280549352722508, 0.2473515272140503, 0.26644713112286156, 0.20545897872320243, 0.15139951024736675, 0.1762505838913577, 0.2068136196051325, 0.1197118434522833, 0.3130661781345095, 0.20417893598122255, 0.25157076652560917, 0.14281959778496198, 0.22854666199002946, 0.30824000281947, 0.14431544180427278, 0.10843113091375146, 2.2510912758963446, 20.375295332499913, 69.60153661455426, 85.02524512154716, 82.55305521828788, 74.53466728755406, 64.33360699244908, 51.92113658360073, 39.18863909585135, 33.456962381090435, 29.852938720158168, 65.99772834777832, 89.47487149919782, 89.32946654728481, 82.5244425364903, 69.7330243246896, 41.06528500148228, 14.733700275421143, 2.6214817208903174, 0.5483096550617899, 0.2742770181170532, 0.2551223002374172, 0.49560556028570446, 2.92414351446288, 4.92618898834501, 5.94817042350769, 13.79417702129909, 16.063458681106567, 17.379939079284668, 19.27663401194981, 18.658418042319163, 18.48607666151864, 20.560485669544764, 18.14134005137852, 19.53159121104649, 15.784630945750646, 21.151483808244976, 15.595355067934308, 14.740561621529714, 17.662730761936732, 11.25815054348537, 12.940840091024127, 12.301002195903234, 16.403677225112915, 13.977480053901672, 14.34829499040331, 10.32340591294425, 12.069606338228498, 9.54018064907619, 13.122122934886388, 10.448002747126989, 9.980649539402553, 11.607195905276708, 25.007150377546036, 39.61130496433803, 69.78484398978097, 60.51958097730364, 69.28782544817243, 63.106701033455984, 54.01893670218331, 22.37499383517674, 18.273121322904313, 18.177293504987443, 21.14694663456508, 22.890769038881572, 18.812841756003245, 24.185062101909093, 21.740387065070017, 21.11825578553336, 23.126002039228165, 17.769816398620605, 26.955416577202932, 14.975528853280203, 18.299585274287633, 13.120167885507856, 20.80098714147295, 28.59720468521118, 22.888106141771587, 21.93334722518921, 17.367018904004777, 23.257058961050852, 22.7402206829616, 16.319185393197195, 11.201197896684919, 15.065271786281041, 16.333257232393535, 6.791054223264966, 6.86803982939039, 1.8805395024163383, 1.6225659166063582, 0.2475228708769594, 0.2979555289660181, 0.309886345905917, 3.9117189901215688, 11.918343186378479, 35.33056150163923, 49.03021349225725, 47.66844647271292, 37.036914008004324, 35.254006249564036, 25.23885543005807, 32.01815720966884, 32.91354029519217, 37.0665202822004, 44.93179423468453, 59.70440442221505, 67.22234834943498, 73.68067809513637, 57.96095895767212, 35.13569927215576, 4.606952701296125, 0.059339427655296664, 0.12555915968758719, 0.18969118195985044, 0.22491960733064584, 0.17924338472740992, 0.13400257804564067, 0.12342865472393376, 0.21380352095833846, 0.1542359223323209, 0.34734090896589415, 0.2010038806391614, 0.13550998430166925, 0.19111963388110909, 0.20443038748843329, 0.1292266414633819, 0.25374118291905945, 0.256017342209816, 0.4069613383284637, 0.45745919006211416, 0.3743546094213213, 0.22762386793536799, 0.08221418663327183, 0.16635955178311893, 0.24329377923692974, 0.1711906532623938, 0.22996878996491432, 0.21376004043434346, 0.24589137413672038, 0.14681889675557613, 0.11399834789335728, 0.053222220723650286, 0.26823026686906815, 0.2760162933596543, 0.18377711144941195], [0.12263504016612257, 0.07561183055596692, 0.019405572276030267, 0.04625008680990764, 0.0424779477928366, 0.030671489358480488, 0.022897009837574193, 0.09498936576502663, 0.04591715681765761, 0.049746421697948656, 0.02074802327635033, 0.0211086697277746, 0.035658616572618484, 0.045252484269440174, 0.04280611786193081, 0.22393617938671792, 0.08291421085596085, 0.0737173268571496, 0.10776768651391778, 0.06965953816792794, 0.025866565760225058, 0.056821967741208415, 0.12335360875087124, 0.0851502822978156, 0.057089880507971556, 0.03555863104494555, 0.04715063848665782, 0.06397038844547101, 0.07426561029361826, 0.02792683556409819, 0.10369826773447649, 8.32642502444131, 41.38980756487165, 60.53317165374756, 65.73368290492466, 63.301076889038086, 52.31133352007185, 33.79850108282906, 23.163685594286235, 24.076830012457712, 35.541494914463584, 57.58947352000645, 50.36371176583426, 55.7783282824925, 63.82200418199812, 60.05794266292027, 38.66798278263637, 10.864333595548358, 2.761747177158083, 0.2504537621779101, 0.039344289872263155, 0.10827008741242544, 0.24424945509859494, 1.6553868183067866, 1.618285826274327, 2.5892846371446336, 5.794889688491821, 6.165063653673444, 6.256979201521192, 4.84483904497964, 7.4638895477567395, 6.394958700452532, 7.092186110360282, 17.575164352144512, 9.899102006639753, 15.727223191942487, 7.92462112222399, 8.612055046217781, 13.390197464397975, 11.020265936851501, 7.419904845101493, 12.860463329723903, 15.986186027526855, 15.69767597743443, 15.844126633235387, 19.84454502378191, 20.20489076205662, 16.9332081249782, 18.761089835848125, 20.925922700337, 22.91902562550136, 18.284365245274135, 16.779901334217616, 27.060396909713745, 39.41746759414673, 42.49965027400425, 59.42792170388358, 49.63180242265974, 58.76817635127476, 53.69076633453369, 59.00188595908028, 30.749826090676443, 23.91057004247393, 24.992750235966273, 30.288538660321915, 33.29002496174404, 36.60223470415388, 35.57621506282261, 31.75160346712385, 32.7345929145813, 25.75119127546038, 19.341747317995342, 16.47359347343445, 11.49501289640154, 8.656864847455706, 12.330565043858119, 10.950232437678746, 16.48361451285226, 13.652186240468707, 11.020102654184614, 8.059525609016418, 13.146056004932948, 9.1466338123594, 9.455617598124913, 6.354528435638972, 7.210453569889069, 8.69209395136152, 4.603717880589621, 4.337923228740692, 2.1430524332182745, 0.9466923837150846, 0.14598416297563485, 0.031057280621358326, 0.13705523924103805, 0.28434058810983387, 1.3722577137606484, 4.5675442559378485, 17.116122926984513, 34.1774662562779, 37.759040287562776, 34.786725997924805, 26.308424643107823, 15.626625435692922, 20.68776798248291, 26.45022174290248, 34.15872001647949, 41.207076890128, 53.77510009493147, 49.62687962395804, 57.78030579430716, 41.83710479736328, 9.636140482766287, 1.0583388613803046, 0.031443085454936535, 0.11365727548088346, 0.03874219521614058, 0.06516378905091967, 0.02922456432133913, 0.111563228203782, 0.067072847325887, 0.12078212387859821, 0.09651340969971248, 0.08818167142037835, 0.050218057818710804, 0.060540400711553435, 0.00651067921093532, 0.019627836599413837, 0.02924253192863294, 0.1684167885354587, 0.17289839019732817, 0.19158700880195412, 0.22934879894767488, 0.05760150269738265, 0.07755149754562549, 0.04968546211187329, 0.0360861377391432, 0.022246852849743197, 0.173436454896416, 0.13788344551409992, 0.07411711969013725, 0.044953576023025174, 0.06110414117574692, 0.06486844989870276, 0.11633807234466076, 0.07557933551392385, 0.10482914812330689, 0.07303041871637106, 0.07475553971848317, 0.034202154725790024, 0.0378781351526933, 0.04918112399588738, 0.044204317299383025, 0.07455058821610042, 0.024024307561506118, 0.06656680947967938, 0.042710027125264914, 0.03799899581021496, 0.0610567590753947, 0.03177661934335317, 0.012340910782638406, 0.010368912447510021, 0.08266626058944634, 0.08024988203708615, 0.04705480559329901, 0.020118232517104064, 0.012267078539090497, 0.016552344396976486, 0.026921199169009924, 0.04236516848738704, 0.10431648098996707, 0.09115774636822087, 0.04441113477306707, 0.03383259062788316, 0.017191727945048894, 0.046815862879157066, 0.01535546121054462, 0.08478149172982999, 8.503700494766235, 44.07998330252511, 68.0227460861206, 73.98223686218262, 71.91792706080845, 63.256698744637625, 45.669348989214214, 35.085974488939556, 29.551723888942174, 34.2022921698434, 45.983553477696006, 51.97468287604195, 62.306268555777415, 73.11787400926862, 69.06473268781389, 45.6183248928615, 15.297431945800781, 3.4184450932911465, 0.16291796788573265, 0.0607373658567667, 0.1592218926442521, 0.7754649945667812, 3.8816484894071306, 4.837314145905631, 6.328210830688477, 7.781316263335092, 8.555094582693917, 9.830125502177648, 11.445571252277919, 13.00807694026402, 9.900599343436104, 13.224685294287545, 11.201936142785208, 13.227134534290858, 12.624981931277684, 9.986487763268606, 8.079443488802228, 6.6592742545264105, 12.544635568346296, 8.694013391222272, 9.50862627370017, 12.33178618976048, 16.432937826429093, 15.271796567099434, 19.312533617019653, 20.18901412827628, 18.860997983387538, 19.49745123726981, 20.06315098490034, 22.912122590201243, 21.020133325031825, 18.168206998280116, 30.033991404942103, 42.75107431411743, 50.280177048274446, 67.80901254926408, 57.646184716905864, 65.38277803148542, 60.79585524967739, 63.40034580230713, 36.16735737664359, 27.398385081972393, 27.7089296068464, 30.536234991891043, 35.34407227379935, 36.48825992856707, 37.39268262045724, 32.80833067212786, 32.5526682308742, 25.658149685178483, 18.475920132228307, 15.233214957373482, 9.262405565806798, 7.527565445218768, 8.338515758514404, 8.164516363825117, 15.298283100128174, 16.41811384473528, 13.634031466075353, 14.28006454876491, 18.704983132226126, 10.88092155115945, 8.921745811189924, 10.211841293743678, 10.906516977718898, 8.252956509590149, 8.035877415112086, 7.93326381274632, 4.7288914152554105, 3.177019728081567, 0.5078154993908746, 0.03121163376740047, 0.1019870431295463, 0.33326526997344835, 1.5777628464358193, 6.47822504384177, 19.31573326247079, 38.387602124895366, 40.384094033922466, 34.18149273736136, 21.475233384541102, 20.44291867528643, 26.72991452898298, 31.442971433912003, 38.43583999361311, 49.06575352805001, 58.73754174368722, 56.890060901641846, 64.840012550354, 50.0593980380467, 11.671193156923566, 1.5131540447473526, 0.06079297858689513, 0.11470106590007033, 0.08362879644015006, 0.0898198178038001, 0.02451312418894044, 0.03628847688170416, 0.01877306737670941, 0.036949329277766604, 0.11058672131704432, 0.04936429452417152, 0.10017821804753371, 0.036798015968608, 0.05448245702843581, 0.11769088118204049, 0.06472624252949442, 0.09319586878908531, 0.20080787901367458, 0.1575617752969265, 0.018684465970311846, 0.0843729797218527, 0.09020762092300824, 0.07313228717872075, 0.018374095571094325, 0.01878839378644313, 0.18410970217415265, 0.05969082058540412, 0.043097786139696836, 0.05738331976213625, 0.05106646068660276, 0.025970982121569768, 0.05085296982101031, 0.10479423749659743, 0.02625352579967252, 0.275472135416099, 0.20758583316845552, 0.1193168003644262, 0.11932932612087045, 0.15345875546336174, 0.13171366229653358, 0.16511505070541585, 0.14702380076050758, 0.14782664339457238, 0.08762196823954582, 0.10902282702071325, 0.13809890752392157, 0.21381904583956513, 0.1572015274848257, 0.19747059951935494, 0.40268336502569063, 0.20916847538735184, 0.14016041904687881, 0.15738041645714215, 0.23463605237858637, 0.13964515312441758, 0.07757150754332542, 0.20288787383053983, 0.3085491433739662, 0.13866807626826422, 0.18119405076972075, 0.11178466132176773, 0.07501070959759609, 0.2682054867701871, 0.14290362756167138, 0.36158884157027515, 12.452117698533193, 56.7520557812282, 79.91378893171037, 84.15340600694928, 81.52430493491036, 67.66787379128593, 49.46056406838553, 33.342261518750874, 34.04239674976894, 46.854576178959434, 70.14068208421979, 60.57699394226074, 60.472173418317524, 70.16454914637974, 66.27917207990373, 44.46408666883196, 13.658721021243505, 3.771730593272618, 0.5345279031566211, 0.11407400454793658, 0.3135607758803027, 0.6178073287010193, 3.6227816258158003, 4.95874433858054, 10.277328933988299, 17.53970422063555, 15.901185240064349, 16.94442425455366, 17.630732570375713, 17.6741327558245, 16.621305227279663, 18.100194556372507, 26.060212407793315, 17.580398082733154, 24.197216238294327, 17.79308591570173, 16.83611920901707, 20.66604617663792, 20.45592396599906, 13.655709845679146, 17.056217295782908, 20.661062581198557, 19.925873688289098, 20.32575293949672, 27.349292584827968, 25.906577314649308, 22.32190786089216, 23.134718554360525, 23.261512756347656, 27.30269796507699, 23.36470913887024, 22.781588520322526, 33.72332852227347, 48.43776839120047, 51.50872278213501, 69.62589005061558, 59.07983085087368, 69.5348755972726, 61.86783722468785, 64.78361402239118, 41.685387407030376, 31.68873269217355, 32.08502319880894, 36.10042190551758, 38.28544623511178, 41.118153844560894, 41.22250189099993, 38.53113106318882, 37.03858157566616, 32.78410577774048, 25.742017916270665, 23.522758075169154, 18.149926287787302, 15.829326970236641, 19.983493362154277, 20.9603180204119, 26.434141874313354, 22.167306968144008, 22.320268086024694, 17.04722806385585, 17.922937325068883, 20.22954818180629, 20.786489725112915, 16.225160632814678, 13.195536732673645, 14.850944178444998, 11.41153723852975, 10.25323952947344, 5.983237113271441, 2.8260056376457214, 0.30744264274835587, 0.14398207754961082, 0.500204507793699, 0.48746905688728603, 1.7669324385268348, 6.527195513248444, 21.28261194910322, 42.36887475422451, 49.78598642349243, 45.344291414533345, 37.049410343170166, 25.83936391557966, 30.91097913469587, 36.16533892495291, 44.35775491169521, 54.65030213764736, 68.39188998086112, 63.68274143763951, 73.51601273672921, 56.960727555411204, 17.915638242449077, 2.2150872307164327, 0.10467623347150427, 0.2798302029924733, 0.20001492942018168, 0.12769039746906075, 0.1526619517909629, 0.2642074498747076, 0.13979842061442987, 0.15829665586352348, 0.241440048707383, 0.266935622053487, 0.17463923964117253, 0.169041067894016, 0.1172679095928158, 0.23284542560577393, 0.16505155339837074, 0.223820475595338, 0.4767308873789651, 0.350145619894777, 0.3535535755966391, 0.1602761596441269, 0.2325707817716258, 0.1731777973473072, 0.1639507253255163, 0.1478914570595537, 0.3255743198096752, 0.25388655226145473, 0.20109380009983266, 0.17790018394589424, 0.10444211853402001, 0.18830673981990131, 0.2019044051745108, 0.1832565122417041, 0.23237240527357372], [0.07249367716056959, 0.028597204413797175, 0.05389384147045868, 0.04877404369679945, 0.08741048923028366, 0.08590794807033879, 0.07550027939890112, 0.07347413990646601, 0.11052927654236555, 0.041720509329544644, 0.035536062970225296, 0.011920644851800586, 0.03297526163182088, 0.10003563069871493, 0.05693777331284114, 0.09869591080184494, 0.10046833248010703, 0.13250875606068543, 0.043640827893146446, 0.01913240595188524, 0.04670279519632459, 0.03481467507247414, 0.12647689187100955, 0.07541757955082826, 0.09457972060356822, 0.06458686465131384, 0.053066137313310585, 0.06919280107000045, 0.07278386623199497, 0.07453517190047673, 0.5467150434851646, 18.95877650805882, 47.59617131096976, 56.04146351133074, 50.354376861027305, 44.47308111190796, 34.27621405465262, 28.61737530572074, 21.52560782432556, 24.558340174811228, 44.37507677078247, 56.48801728657314, 56.840332644326345, 35.01812880379813, 32.60551275525774, 27.266723666872295, 15.355385133198329, 3.256088925259454, 0.329947830843074, 0.06242385107491698, 0.15037423026348862, 0.12710879796317645, 0.7491252422332764, 2.7802024611404965, 4.9683801872389655, 3.0110643931797574, 4.86786059822355, 9.181544167654854, 7.744274548121861, 10.2345176083701, 11.26289963722229, 9.12113652910505, 11.045665076800756, 4.141717825617109, 11.993569595473152, 9.55268132686615, 8.114029884338379, 6.45954350914274, 8.43684492792402, 23.79575800895691, 21.04667718069894, 20.053223746163503, 22.84936646052769, 34.51031276157924, 32.28168501172747, 34.49596473148891, 34.839369024549214, 36.28564350945609, 37.818516867501394, 38.13841193062918, 36.032788140433176, 34.317774704524446, 30.421850272587367, 41.99324819019863, 46.63184125082833, 35.61581632069179, 49.07727364131382, 43.62190246582031, 49.60278327124459, 47.65434857777187, 54.67679214477539, 41.26154381888253, 43.8578702381679, 44.941719736371724, 46.123132365090505, 49.06565277917044, 52.04259456907, 50.44105216435024, 48.50054883956909, 45.473809310368125, 43.29236677714756, 31.88101713997977, 25.480951513562882, 15.915512425558907, 13.68951804297311, 14.629763909748622, 6.5455821837697705, 13.743183323315211, 17.105186462402344, 9.540217995643616, 16.350454023906163, 21.736136504581996, 9.75616887637547, 8.06122965472085, 8.873115369251796, 11.507032411439077, 3.5970027233873094, 5.809632463114602, 4.985460596425193, 3.964221315724509, 2.5372091914926256, 0.7645025828054973, 0.617304832807609, 0.1607092549758298, 0.09710467154426233, 0.07529855772320714, 1.547385430761746, 8.035506555012294, 25.215858629771642, 39.1441775730678, 44.278746945517405, 42.182861055646626, 37.003764152526855, 24.785878045218332, 18.573425940104894, 28.893079825810023, 34.42646884918213, 38.50399487359183, 50.000258445739746, 50.163304873875205, 49.53272111075265, 35.81216893877302, 3.3100957529885426, 0.06587752646633557, 0.08507379104516335, 0.04551193570452077, 0.057047641703060696, 0.0960344589714493, 0.07753590481089694, 0.07898059407515184, 0.022019697985212718, 0.16509067772754601, 0.033787617326847146, 0.059675607830286026, 0.020812797925568054, 0.08685394123728786, 0.04040473493348275, 0.08028064681483166, 0.11272175210927214, 0.0905960618651339, 0.23924341372081212, 0.13822531859789575, 0.026610531910721744, 0.04927753025133695, 0.08028121678424732, 0.03453042996781213, 0.050429923592933586, 0.08460338985813515, 0.05260562916685428, 0.04714523395523429, 0.0370812636267926, 0.057327449188700745, 0.04434788173862866, 0.04567654151469469, 0.0129216493972178, 0.07210679684898683, 0.035499059062983306, 0.0915389202002968, 0.013280304348362344, 0.010198028492076057, 0.06430934382868664, 0.06358695509178297, 0.046660329082182476, 0.051045850185411315, 0.03179573706750359, 0.05505080474540591, 0.016108224567558085, 0.021180867550096343, 0.021073616608711224, 0.0306294642921005, 0.06411108268158776, 0.0007023429570836015, 0.0720910005537527, 0.0766920583056552, 0.02013260728147413, 0.03488897126434105, 0.07225217976208244, 0.03138607154999461, 0.017135217852358307, 0.06974537284778697, 0.07774157556039946, 0.05200013165761318, 0.07215881334351641, 0.021131517698190043, 0.027098334128303186, 0.05761676973530224, 0.6673467361501285, 22.48085137775966, 55.483533586774556, 68.74007810865129, 63.74649115971157, 59.17347172328404, 44.39548363004412, 37.48372834069388, 24.323635237557546, 26.927599464144024, 49.53794615609305, 65.34884997776577, 55.294612067086355, 48.45336709703718, 45.94099576132638, 37.70717545918056, 20.251353366034373, 4.576969053064074, 0.34560529781239374, 0.03805307505120124, 0.5180303826928139, 0.6924010174615043, 2.9957334101200104, 6.110735688890729, 8.086424691336495, 9.271109921591622, 11.129436033112661, 10.130070550101143, 10.344776834760394, 10.062794617244176, 10.351797120911733, 11.932995200157166, 11.020648087774005, 13.901314769472394, 12.770449416978018, 7.448734658105033, 8.916948080062866, 11.070160950933184, 2.875485496861594, 13.156392318861824, 16.989895003182546, 19.195652757372173, 23.87972698892866, 32.84807784216744, 31.387941701071604, 34.02088165283203, 35.32465900693621, 36.46874243872506, 37.20159673690796, 39.871469838278635, 38.26470933641706, 39.20942463193621, 34.254782336098806, 47.33977583476475, 50.10832725252424, 45.01109055110386, 57.37403072629656, 51.23622138159615, 57.252499784742085, 55.85555403573172, 59.387094088963096, 48.884600094386506, 46.748435497283936, 47.252252851213726, 46.143368993486675, 48.848538943699424, 52.494960512433735, 53.22109937667847, 49.259601320539204, 47.682367188589915, 44.424686908721924, 33.30159023829869, 21.332435744149343, 15.939615726470947, 11.419171571731567, 9.554059675761632, 10.920213614191328, 14.359837685312543, 11.073846101760864, 15.948002202170235, 18.927876131875173, 16.372502395084926, 12.675758498055593, 14.537385872432164, 11.848221097673688, 11.153700011117117, 6.629724868706294, 11.15521992955889, 11.626537953104291, 4.934864682810647, 4.561022068772997, 3.9282552685056413, 1.2744421682187488, 0.14080926137311117, 0.21176066914839403, 0.22481558791228703, 1.9192689784935542, 8.082660504749843, 25.60128562791007, 35.765824454171316, 38.200285639081685, 36.22746276855469, 28.310652290071758, 26.794961827141897, 24.84067848750523, 33.648016997746055, 41.384561674935476, 46.26468106678554, 57.12847443989345, 57.1550304549081, 57.81869806562151, 38.98657158442906, 4.6802761725017, 0.035602813852684836, 0.04383482105497803, 0.00844932924623468, 0.011054790911397763, 0.03568573083196368, 0.05630939560277121, 0.033893387365554056, 0.010885774623602629, 0.08451397929872785, 0.023392839124426246, 0.04052262021494763, 0.0311837052660329, 0.05101847129740885, 0.07175983475255114, 0.062439348814742904, 0.08250931543963295, 0.0735227908673031, 0.06752799504569598, 0.05545104541150587, 0.015404054495905126, 0.02199831904311265, 0.021766831732488105, 0.02310040919110179, 0.029428667654948573, 0.05841358019305127, 0.04824250311191593, 0.07453005574643612, 0.03490413652200784, 0.04731126808162246, 0.018908803218177388, 0.01912449762624289, 0.10214995938752379, 0.02858700942514198, 0.16823428975684301, 0.16401851097387926, 0.11473759822547436, 0.1798158918640443, 0.25205206498503685, 0.2672311919076102, 0.20494477131537028, 0.16808377711900643, 0.15851792613310473, 0.2230229933879205, 0.10937127510883979, 0.08673565222748689, 0.1536284570715257, 0.16653654085738318, 0.23456651610987528, 0.2850176032100405, 0.20522055508834974, 0.29154492009963306, 0.13185935733573778, 0.16467024385929108, 0.11883795820176601, 0.11454295367002487, 0.19743002312523977, 0.18134889246097632, 0.3410674455974783, 0.12205174432269164, 0.16031455115548202, 0.11917533938373838, 0.1798232200422457, 0.2059286470924105, 1.6090718635490961, 29.958158765520366, 69.01878425053188, 82.02559661865234, 73.31739153180803, 64.84286825997489, 49.602276052747456, 42.1651987348284, 35.15849978583199, 37.91236965996878, 57.20773254122053, 63.23114327022007, 65.1537584577288, 45.23938403810774, 44.84471246174404, 36.51316227231707, 20.24522852897644, 4.471140606062753, 0.552226973431451, 0.13688237565968717, 0.5206525134188789, 0.3684865842972483, 3.429082133940288, 8.256881373269216, 14.20512648991176, 13.076110226767403, 18.39236457007272, 19.608191626412527, 18.969131061008998, 20.800648416791642, 20.96253796986171, 20.471298592431204, 20.142523731504166, 12.081651040485927, 25.66446212359837, 19.35183436529977, 15.133044515337263, 17.756371634347097, 16.92242452076503, 32.651957988739014, 25.65992668696812, 24.494025911603654, 26.348058904920304, 38.42693240301949, 36.498598848070415, 39.87612165723528, 39.47565875734602, 43.582134451184956, 42.68294027873448, 43.49246447426932, 42.33179221834455, 42.43333319255284, 39.680165086473735, 53.041394642421174, 57.75081763948713, 47.57635504858834, 61.75198296138218, 56.444184575762065, 61.32999801635742, 61.01818370819092, 65.51346669878278, 53.99989168984549, 50.39403370448521, 51.00420366014753, 48.924576554979595, 52.25642190660749, 56.751253264290945, 55.742468629564556, 51.64007152829851, 50.78539099012102, 49.6776396887643, 36.93828432900565, 29.000504187175206, 20.440738677978516, 19.69793282236372, 23.112605912344797, 16.4538380077907, 25.307208333696636, 29.7879695892334, 18.511331626347133, 25.4020026070731, 31.13366195133754, 22.72453338759286, 17.318207808903285, 16.056197813579015, 21.99905981336321, 9.361704877444676, 14.543973633221217, 12.373664719717842, 10.75828150340489, 6.85395930494581, 4.153957511697497, 1.4249020431722914, 0.30681244656443596, 0.24745029477136476, 0.34681021315710886, 1.9570202784878867, 9.335248742784772, 30.301973002297537, 48.27351297651018, 57.36475140707833, 54.81724303109305, 49.21052966799055, 36.07499844687325, 29.10310823576791, 38.81936318533761, 46.25613130841936, 50.94868407930647, 66.11827264513288, 65.10562133789062, 67.02786827087402, 48.610323429107666, 6.696709411484854, 0.3822338123406683, 0.2098148071340152, 0.13875040970742702, 0.19330094754695892, 0.16529087269944803, 0.16153055376240186, 0.2027759969766651, 0.09968940820544958, 0.3012141255395753, 0.19070584965603693, 0.19611639289983682, 0.21826131961175374, 0.2521276537861143, 0.11714703536459378, 0.2436324224940368, 0.19325620494782925, 0.27529536347304073, 0.43160882432545933, 0.23438388162425586, 0.13450367615691253, 0.136070169242365, 0.2591746470757893, 0.196558377040284, 0.1603613565010684, 0.37023478906069485, 0.14868241176009178, 0.1644000376441649, 0.15716412663459778, 0.1566575188189745, 0.1066423768975905, 0.1899649572691747, 0.22076337678091867, 0.19884943696005003], [0.08183480413364512, 0.03161091430644904, 0.03405450889840722, 0.07587906478771142, 0.029351443584476198, 0.06132846485291209, 0.07739104436976568, 0.02029321652038821, 0.11556242539414338, 0.015712989793558205, 0.05474450046728764, 0.046041383008871756, 0.019620092818513513, 0.046529127550976615, 0.19770368986896106, 0.037523278301315646, 0.07181950512209109, 0.02280828799121082, 0.010887111337589366, 0.036645108102155585, 0.034092734168682776, 0.05390976329467126, 0.05208944382944277, 0.13333522528409958, 0.09633017810327665, 0.023001712879964283, 0.01802399694653494, 0.0625960836187005, 0.04253953502380422, 0.07333278070603098, 5.8367742981229505, 28.723561150687082, 42.93372161047799, 50.23828635896955, 42.011046000889365, 30.758907386234828, 25.5106828553336, 22.727809463228496, 29.92776734488351, 37.659594195229666, 32.12449591500418, 43.492110116141184, 42.68538951873779, 32.31267050334385, 29.115255423954554, 19.479861872536794, 7.57379789011819, 1.1260891173567091, 0.22550208893205437, 0.01899944701498108, 0.414758139955146, 0.5977124869823456, 2.509591839143208, 6.54518700497491, 3.19428665297372, 6.833163346563067, 6.320787983281272, 6.793288937636784, 7.917091880525861, 7.680026292800903, 11.476350034986224, 7.630638497216361, 10.06408611365727, 12.68840856211526, 12.782301306724548, 9.923156670161656, 11.188840525490896, 11.416598132678441, 13.007193650518145, 29.20239278248378, 30.695129871368408, 35.18075486591884, 42.98907790865217, 48.26889589854649, 45.69021095548357, 45.63284662791661, 49.17246396200997, 49.88797208241054, 48.602461542402, 50.938862800598145, 46.615544251033235, 50.33768728801182, 46.709331035614014, 48.9029780796596, 38.352718693869456, 31.63580478940691, 44.14807217461722, 39.810603618621826, 46.9682799748012, 43.700100966862266, 42.99009929384504, 46.76491315024239, 54.023630210331504, 55.309755665915354, 59.07884420667376, 52.92311198370797, 59.137994221278596, 58.89394569396973, 55.78766666139875, 58.09266553606306, 54.79325784955706, 49.58392586026873, 43.42610222952706, 33.69321155548096, 25.527428013937815, 16.001256670270646, 16.190190349306377, 17.230419056756155, 12.91100105217525, 15.329732384000506, 15.618824345724923, 19.543939896992274, 7.187214016914368, 7.718347345079694, 9.224764568465096, 8.527911492756434, 7.029376566410065, 10.019925100462777, 11.372822744505745, 3.481028820787157, 5.996656256062644, 2.725538811513356, 0.862013656113829, 0.199464135404144, 0.07481345268232481, 0.08416626402842146, 0.13332534581422806, 1.5211756314550127, 12.739563805716378, 25.924270902361187, 39.49678822926113, 30.5166688646589, 27.355712720326014, 26.804046596799576, 20.926089457103185, 22.850530283791677, 22.649538006101334, 31.232791900634766, 45.49555022375924, 51.01306956154959, 52.97677639552525, 40.77752883093697, 10.987394877842494, 0.43810430435197695, 0.04330813538815294, 0.0494641104180898, 0.02634401522975947, 0.06591456769300358, 0.08491882721760444, 0.10060560689972979, 0.06247014751923936, 0.03521143485392843, 0.0470824728586844, 0.024759669887966344, 0.06515308855367558, 0.02790039305442146, 0.019958140661141703, 0.03268373923908387, 0.03219511938680496, 0.0861150776701314, 0.06693921663931438, 0.0312000715306827, 0.12542539329401084, 0.08408295349883181, 0.005912079010158777, 0.03368057164230517, 0.027879227850852267, 0.04262989213956254, 0.12729626361812862, 0.06912175166819777, 0.05867529793509415, 0.04044818153072681, 0.033204460583095036, 0.05153970154268401, 0.09414119699171611, 0.07668515760451555, 0.05149579014895218, 0.022934419169489826, 0.01253171737438866, 0.023709611501544714, 0.02852355283019798, 0.1062329760087388, 0.040769552678934166, 0.02398901356251112, 0.04420291951724461, 0.04671590788555997, 0.04760904995990651, 0.03317170769774488, 0.021420962077432444, 0.054512180254927704, 0.14495896441595896, 0.05894032692802804, 0.023813547799363732, 0.07113038495715175, 0.03581468641225781, 0.015010661944480879, 0.07659257150122098, 0.028694750608078072, 0.023081398336216807, 0.014766631914036614, 0.016499852927933847, 0.005411848999626402, 0.04279258108830877, 0.009439350854206299, 0.02027977304533124, 0.06880949663796596, 6.205716260841914, 33.36565957750593, 56.672627449035645, 63.154483795166016, 54.17708465031215, 40.60654061181204, 34.892835412706646, 28.050909519195557, 33.62059245790754, 40.201682976314, 35.725003787449424, 48.84664903368269, 55.4252382005964, 34.414375509534565, 29.292160034179688, 19.98267000062125, 7.600016917501177, 1.2739479775939668, 0.16520638151892594, 0.14796439957405838, 0.5760741680860519, 3.008020647934505, 5.800244144030979, 9.55049090726035, 11.361049890518188, 7.530980484826224, 11.218407716069903, 12.39765076977866, 13.881720849445887, 14.572437797273908, 15.219568695340838, 15.126667806080409, 14.243628195353917, 12.17178133555821, 10.120099016598292, 9.469214354242597, 6.937551779406411, 10.234746898923602, 13.810996873038155, 26.329597541264125, 27.86075643130711, 34.60317543574742, 40.415701389312744, 44.807233878544395, 44.689771107264924, 45.76279878616333, 47.70601190839495, 49.82969754082816, 50.695988518851145, 50.504822731018066, 48.46333428791591, 55.27755423954555, 52.254903725215364, 54.098854882376536, 44.195121901375906, 38.755835805620464, 50.09486164365496, 46.64292015348162, 52.79540409360613, 52.0668055670602, 49.686317988804404, 51.899176801954, 57.974872725350515, 56.50261892591204, 58.50358894893101, 55.01168142046247, 61.577333041599815, 60.43445859636579, 59.097458430698936, 58.86281776428223, 55.15622132165091, 51.31368684768677, 42.2150034223284, 31.881493091583252, 22.72011433328901, 14.534757716315132, 12.724931768008641, 10.151920897620064, 9.899973137038094, 13.928505676133291, 18.496500696454728, 17.60997830118452, 13.118669680186681, 16.462999207632883, 15.578250340053014, 13.195543680872236, 13.781985538346426, 12.93264729636056, 12.131485257829938, 7.320624641009739, 9.273665990148272, 5.538541112627302, 3.327263666050775, 0.7400919326714107, 0.4470225072332791, 0.1623886970004865, 0.22918475632156643, 1.5858230824981416, 13.364251153809683, 26.987303597586497, 40.404803139822825, 36.31912340436663, 37.50535808290754, 26.938982350485666, 21.194447994232178, 27.417543002537318, 29.47452245439802, 35.51998676572527, 50.44013500213623, 56.65773745945522, 59.71354825156075, 49.349907057625906, 13.786023310252599, 0.6188156860215324, 0.0386378602789981, 0.06073047872632742, 0.03374311560764909, 0.051313403328614574, 0.09244586367692266, 0.056509967161608596, 0.061018991816256724, 0.027524754371760145, 0.07031543047300406, 0.021906686281519275, 0.03491636711571898, 0.038082163847450695, 0.05870055300848825, 0.03806330057393227, 0.08819622599652835, 0.036154350864567926, 0.0202871979147728, 0.07248054072260857, 0.030419440740453343, 0.06619290275765316, 0.021273424815652624, 0.048463569820991585, 0.0317604871732848, 0.006825850669494165, 0.028096520208886692, 0.03728317189961672, 0.08077269326895475, 0.05584687559998461, 0.050144932099751065, 0.055073220149746964, 0.03983748983591795, 0.02272129471280745, 0.2512127443083695, 0.12640636494117125, 0.15143070928752422, 0.11670757537441594, 0.207018306478858, 0.1624783586178507, 0.1391377853495734, 0.13730259239673615, 0.21490531255091938, 0.16125197442514555, 0.15422132025871957, 0.1404159010521003, 0.21776195855012961, 0.15177461797637598, 0.41084828547069, 0.371623125991651, 0.15201335373733724, 0.16698931370462688, 0.13814960766051496, 0.13148697731750353, 0.1091573533735105, 0.18790088088384696, 0.20281095510082586, 0.18974375485309533, 0.18985051555292948, 0.0907456652660455, 0.1579395564539092, 0.13410540324236664, 0.19277801417878696, 0.3502609437065465, 10.195865648133413, 44.4513749395098, 68.57933848244804, 74.37619277409145, 63.324339457920615, 49.19956193651472, 42.54720721926008, 34.915542125701904, 44.08602128710066, 51.10487263543265, 45.87103087561471, 53.569148540496826, 51.75705139977591, 43.16615969794137, 39.569612298692974, 24.703456776482717, 9.500389184270587, 1.5162013726575034, 0.3411062849419457, 0.2555446747158255, 0.5346275663801602, 2.7517843289034705, 5.859212636947632, 15.702032497950963, 16.90771344729832, 15.632708583559308, 14.635506595884051, 21.368780033929006, 18.796815735953196, 13.526043432099478, 19.5801591191973, 15.816118444715228, 23.533079624176025, 21.86623283794948, 23.424310786383494, 16.74385929107666, 19.813693284988403, 17.595995051520212, 21.007998296192714, 35.33837475095476, 33.7777989251273, 37.9554762840271, 48.561856269836426, 52.24075371878487, 48.737183638981406, 49.84318746839251, 53.135250908987864, 53.30133717400687, 53.358823095049175, 53.0193167413984, 51.718947478703086, 56.504974365234375, 55.396580355507986, 59.98978083474295, 50.13866308757237, 44.01933247702462, 54.646706444876536, 50.52058124542236, 58.40402126312256, 56.786772455487935, 55.324350357055664, 60.78081239972796, 59.96637235369001, 58.42936134338379, 59.75500120435442, 55.49158654894148, 64.07053429739815, 62.15048994336809, 60.8767739704677, 62.582688740321565, 57.327102593013215, 54.22036150523594, 47.160213538578574, 36.67026799065726, 31.44721678325108, 20.800763062068395, 26.00347341809954, 26.521220173154557, 24.49529048374721, 26.030597448349, 28.87503014292036, 32.65710660389492, 13.304682510239736, 17.642780746732438, 18.799098219190324, 18.842946563448223, 17.77747678756714, 21.79214940752302, 21.05035104070391, 13.01627060345241, 15.526397671018328, 7.564150316374643, 3.426202539886747, 0.5812183863350323, 0.5401905764426503, 0.3743206283875874, 0.2876147909888199, 1.9837024467332023, 15.617525032588414, 32.05771330424717, 49.68921538761684, 41.371749196733745, 40.46361269269671, 36.76326962879726, 32.14986726215908, 33.327579975128174, 33.176209994724815, 43.237486430576865, 59.8093569619315, 65.49062102181571, 68.44240338461739, 60.974034854343955, 19.944258621760778, 1.5249605540718352, 0.19094956586403505, 0.13977187632450036, 0.14351641253701278, 0.24906832937683376, 0.12459615564772061, 0.1432223490306309, 0.16553093838904584, 0.20075222557144506, 0.17588516564241477, 0.17042503505945206, 0.15729065984487534, 0.08414121251553297, 0.16569564597947256, 0.1836190263607672, 0.19799949042499065, 0.1938810542758022, 0.3194714401449476, 0.15186426602303982, 0.32307418967996326, 0.16198167098420008, 0.15151243204517023, 0.12404838789786611, 0.20015200706464903, 0.10492811245577675, 0.1297477563577039, 0.1270868812820741, 0.18209556596619741, 0.13717200154704706, 0.12720840690391405, 0.09406057346080031, 0.1797856834850141, 0.22053608112037182], [0.027646999240719845, 0.019542195302035128, 0.07487730282757964, 0.01050803841956492, 0.05563676383878503, 0.04272856470197439, 0.07185748272708484, 0.0652100583538413, 0.06400417270404951, 0.0194992847474558, 0.02417060819321445, 0.013749282308188933, 0.09343105581189905, 0.10732427066458122, 0.0800799632977162, 0.0862702586288963, 0.23076872846909932, 0.012751234479115477, 0.029374839471919195, 0.016827478472675596, 0.01836424833163619, 0.02675042038650385, 0.04709594856415476, 0.15631715208292007, 0.04593895814780678, 0.037147366508309326, 0.0978485019877553, 0.048499264155647585, 0.03854957948039685, 0.7702202445694378, 15.2408492905753, 32.02355595997402, 33.255283968789236, 49.28691816329956, 41.30049194608416, 34.04778855187552, 30.426008769444056, 27.376548630850657, 16.69958015850612, 19.99769721712385, 32.66644498280117, 21.940397909709386, 21.836468492235454, 49.71662950515747, 34.55995416641235, 14.741551739828926, 2.1267773636749814, 0.19094389331127914, 0.21709508076310158, 0.13382881879806519, 0.3754416768039976, 3.2830524955477034, 4.423113788877215, 4.934253241334643, 9.027032732963562, 7.327376552990504, 10.822602714811053, 8.309277738843646, 9.97537933077131, 15.877498831067767, 11.022038596017019, 15.822854723249163, 9.681676370756966, 21.33861095564706, 12.581919601985387, 13.699986372675214, 16.754556042807444, 36.878581932612825, 22.548406975609915, 40.90122413635254, 45.97773436137608, 49.378471102033345, 51.57051311220442, 54.37942661557879, 56.27519743783133, 55.702679770333425, 56.655580043792725, 56.859902245657786, 56.52909503664289, 59.3907071522304, 55.83450099400112, 60.8437283379691, 55.95427404131208, 55.09540721348354, 37.46284900392805, 29.987261295318604, 40.15761750085013, 41.38618060520717, 39.51723330361502, 41.730620179857524, 35.10176774433681, 41.27774006979806, 58.07783113207136, 59.61012431553432, 58.162078039986746, 59.13244955880301, 57.98037917273385, 59.430416107177734, 57.78989083426339, 59.68911838531494, 58.83835315704346, 55.33029801504952, 49.153912271772114, 45.59400967189244, 36.81559303828648, 30.43580572945731, 33.551600319998606, 25.795826503208705, 10.148986152240209, 16.07708583559309, 18.2411596093859, 12.03794687134879, 11.422253097806658, 22.19148669924055, 14.678470781871251, 7.143519401550293, 7.103130391665867, 9.504882063184466, 15.407043252672468, 3.986679196357727, 4.4094288774899075, 5.736093163490295, 2.6126731421266283, 1.0093294169221605, 1.1419630369969775, 0.03405954362824559, 0.30727572313376833, 0.174119305397783, 3.9274536200932095, 10.717177697590419, 22.894788571766444, 34.53611142294747, 28.12926435470581, 37.80430780138288, 25.719036749431066, 18.64273074695042, 23.94910822595869, 38.0311074256897, 44.00185080936977, 45.60711744853428, 49.671226501464844, 49.73218652180263, 24.203348023550852, 6.135494726044791, 0.37117819700922283, 0.05494149275390165, 0.06268178937690598, 0.015236276534519025, 0.08636896511805908, 0.14246336690017156, 0.022545827253322517, 0.044352346499051364, 0.04865406174212694, 0.05556276959500142, 0.024064621023301567, 0.030186893218862157, 0.027678244081991057, 0.052945978939533234, 0.05045733301501189, 0.041832416717495234, 0.09435353774045195, 0.07602543836193425, 0.02822800163578774, 0.05315072688141039, 0.022588837891817093, 0.033774243401629586, 0.07167146913707256, 0.045137961128992696, 0.03158398664423397, 0.0601873928681016, 0.03380294204024332, 0.026336483491052474, 0.061075269510703425, 0.026066682700599943, 0.060787231395287175, 0.08204559782253844, 0.04329085310122796, 0.0061637247480185965, 0.06352793611586094, 0.08658047126872198, 0.054734424222260714, 0.0395818314115916, 0.03558828981061067, 0.05243053659796715, 0.05476870720407792, 0.04428468977234193, 0.027944677642413547, 0.007465725731370705, 0.06572997224118028, 0.021172921905027967, 0.09440259582230023, 0.03814839904329606, 0.11985187950943198, 0.032263525894709995, 0.015208699175023606, 0.0382016436862094, 0.013779443189767855, 0.021396443214533583, 0.03766554334600057, 0.04152607511995094, 0.006981593964155763, 0.05280511506966182, 0.051701606783483706, 0.060211385866361, 0.020477805186861327, 0.7754277565649578, 18.000692878450664, 38.80245474406651, 48.87862811769758, 59.59021077837263, 54.215056555611746, 42.602862289973665, 40.44910832813808, 31.439295836857386, 22.96140616280692, 31.90649618421282, 44.19570207595825, 33.84536668232509, 25.984862668173655, 44.0524753843035, 33.44917345046997, 14.492581282343183, 2.0907559479985918, 0.24444473747696194, 0.247969672616039, 0.7949120796152523, 2.7284613975456784, 7.63208372252328, 7.903136423655918, 10.643267972128731, 9.917236804962158, 12.498463920184545, 17.119140182222637, 13.428872874804906, 13.00705121244703, 14.30690370287214, 13.471501810210091, 15.465359483446393, 12.685263633728027, 11.044603739465986, 8.124822173799787, 9.512658834457397, 14.774470567703247, 27.435853242874146, 28.655331577573502, 37.71987329210554, 45.4624594279698, 50.0671626499721, 54.127391133989605, 56.43022911889212, 55.35301167624337, 55.91640288489205, 57.87409257888794, 58.949906485421316, 56.33179746355329, 59.69508688790457, 55.96132298878261, 62.94312654222761, 60.03463840484619, 59.73237092154366, 41.36731277193342, 35.105474608285085, 47.65494612285069, 47.49415438515799, 47.32149165017264, 48.97129276820591, 41.833550793784006, 47.13186141422817, 60.149770055498394, 60.32857499803816, 58.2641783441816, 59.65568365369524, 61.008824484688894, 61.37037399836949, 61.924861090523855, 62.79395566667829, 61.042988777160645, 56.0919908114842, 50.26817056110927, 45.54634502955845, 37.75667095184326, 30.574595996311732, 27.17847112246922, 17.20804933139256, 12.228558540344238, 16.15600347518921, 17.12757703236171, 16.333948578153336, 15.777800866535731, 21.538156270980835, 16.625039884022303, 16.00728075844901, 10.881762283188955, 7.9901895352772305, 11.88162977354867, 7.940731389181955, 10.341721364430018, 7.681468912533351, 6.19690420797893, 2.752902554614203, 2.2351592736584798, 0.2693320991737502, 0.06244217830577067, 0.32560941364083973, 4.241414487361908, 11.596418380737305, 25.723740679877146, 30.696707112448557, 25.965338230133057, 35.63223491396223, 21.683983325958252, 20.338120732988628, 25.44315505027771, 42.05371488843645, 48.09256451470511, 54.27438027518136, 56.76122392926897, 59.717237745012554, 30.573963710239955, 8.715734328542437, 0.4075791308922427, 0.029370968429637805, 0.027087922008442025, 0.07613307437194244, 0.021633145066776445, 0.06192018810127463, 0.0401327577419579, 0.05478808616421052, 0.04791329149156809, 0.031268284656107426, 0.026094882615974972, 0.06146100309810468, 0.028569964625473534, 0.04994736984372139, 0.042359448437179835, 0.06644242722541094, 0.012314161235865737, 0.038320183753967285, 0.014364523580297828, 0.046675589334751875, 0.054211738519370556, 0.01949541879418705, 0.037240963628781695, 0.0678229338622519, 0.020706612284162214, 0.025496625075382844, 0.05358919281778591, 0.0343257668428123, 0.013644242542795837, 0.03942027222365141, 0.04132459771686366, 0.05725342780351639, 0.2548275717667171, 0.14349566293614252, 0.20147120127720491, 0.3107371745365006, 0.15344764105975628, 0.1092776372762663, 0.1291422995605639, 0.24447592294641904, 0.2299564949103764, 0.14067067738090241, 0.09807694437248365, 0.06906735351575272, 0.18527800376926148, 0.2188205003206219, 0.3084274141916207, 0.24387061542698316, 0.42883654737046784, 0.10398335422256164, 0.11847775110176631, 0.11661089770495892, 0.13946905971637794, 0.14399795526904718, 0.18695416168442794, 0.24273200652429036, 0.13515790605119296, 0.13780975661107472, 0.18879229947924614, 0.15033916357372487, 0.18045171988861902, 1.7023618519306183, 25.03124325616019, 51.76806776864188, 61.48492200034005, 71.7926857812064, 63.648834228515625, 53.757423877716064, 47.58585671016148, 43.191249643053325, 29.269182341439382, 31.503233160291398, 43.82139914376395, 33.05321993146624, 32.494654246738975, 62.187767028808594, 42.842481340680806, 17.440767083849224, 2.34870108962059, 0.44967006945184296, 0.31876410810010775, 0.5642645103590829, 2.759328986917223, 10.204191327095032, 13.191575390951973, 14.478803873062134, 17.334841796330043, 17.367922169821604, 25.89176549230303, 18.217146635055542, 22.64900646890913, 27.45469502040318, 22.897039788109915, 29.548670155661448, 20.024677072252544, 31.93621710368565, 22.782425778252737, 21.482390029089792, 23.242837735584803, 43.66374451773507, 29.185859543936594, 45.55033329554966, 49.72962263652256, 53.25728906903948, 55.99128362110683, 59.669621740068706, 58.91244179861886, 57.65589482443673, 59.4901567186628, 60.431269373212544, 59.1937118257795, 60.9623201915196, 57.88376447132656, 64.13409641810826, 61.01491110665457, 62.85018048967634, 47.55330439976284, 40.884850706372944, 51.701490129743306, 51.50929600851876, 50.66262674331665, 53.48512397493635, 48.09198086602347, 52.72974361692156, 60.79003265925816, 61.91835757664272, 58.923614501953125, 62.867300851004465, 61.91466113499233, 62.57685225350516, 61.91774613516671, 63.834719385419575, 62.26246016366141, 57.87775427954537, 51.821850299835205, 48.55766303198678, 40.58865942273821, 34.67349467958723, 40.26189953940255, 32.25247825895037, 16.616340739386423, 27.983534574508667, 29.777088710239955, 19.829884324754985, 23.931294781821116, 36.943161964416504, 26.13376603807722, 16.649725096566335, 16.31271140916007, 18.746870347431727, 24.667343514306204, 10.256954210145132, 11.600651570728846, 14.034661991255623, 7.005468249320984, 2.604089294161115, 2.5198213245187486, 0.24549201556614467, 0.680075076009546, 0.4288194482879979, 5.0349960412297925, 14.275474395070757, 29.654459953308105, 42.52853046144758, 36.95142684664045, 52.297061920166016, 37.27455629621233, 28.715992825371877, 34.26232460566929, 48.58125911440168, 56.9730293410165, 61.51175594329834, 65.3282138279506, 67.45456409454346, 43.088579586574006, 13.519035305295672, 0.7691027788179261, 0.17130022309720516, 0.18591316682951792, 0.1894444123442684, 0.21349379686372622, 0.20855066925287247, 0.1307126060128212, 0.17341529817453452, 0.17727384184088024, 0.15175048927111284, 0.11868526068116937, 0.18445046246051788, 0.16450649978859083, 0.16441649890371732, 0.13853292566324982, 0.13230507341878756, 0.18652156846863882, 0.15847874752112798, 0.19892973479415688, 0.2023050393909216, 0.1141789603446211, 0.07757224036114556, 0.19006030500999518, 0.07825342166636672, 0.12600266374647617, 0.20809523654835566, 0.13316526583262853, 0.07512886290039335, 0.12157953823251383, 0.17207129672169685, 0.2359591413821493, 0.2479417169732707], [0.023957309013764774, 0.03245887951925397, 0.01038478422976498, 0.06061743479222059, 0.02467014397760587, 0.0598116201747741, 0.03852337785065174, 0.10657250136137009, 0.036556131805160215, 0.03370072413235903, 0.06947439988808972, 0.0567069085580962, 0.014976665643709046, 0.04427683912217617, 0.12939434817859105, 0.1154679326074464, 0.1037863212238465, 0.062487015899802954, 0.04566306241654924, 0.07939922304025718, 0.07511881379676716, 0.011974519684112497, 0.0345830571438585, 0.049870223804776154, 0.028992461240185157, 0.007954959657841494, 0.008476092363707721, 0.027261559119714156, 0.055501772689500024, 1.8146956584283283, 26.032370976039342, 34.145188399723594, 38.40466342653547, 45.401058197021484, 36.112536089760916, 31.63253218787057, 17.868734427860804, 18.09767930848258, 21.884520496640885, 26.279867546898977, 14.414923003741674, 17.533511638641357, 38.12401526314871, 29.036598341805593, 20.41012838908604, 3.6320325008460452, 0.2601151780358383, 0.10790120184953723, 0.4423901486609663, 0.7510972278458732, 1.8451607951096125, 4.546768273626055, 5.015049934387207, 8.60597276687622, 12.963167258671351, 5.269967181341989, 6.814294644764491, 10.426551052502223, 13.218511819839478, 13.263538752283369, 13.819534472056798, 19.087097576686315, 18.162712710244314, 11.212446161678859, 17.204695088522776, 32.79308979851859, 33.67245033809117, 38.83419758932931, 47.79183605739048, 52.80140733718872, 53.936996596200125, 60.584525789533345, 57.106094292231965, 58.59507587977818, 59.020625250680105, 59.97289671216692, 61.536130223955425, 61.36422484261649, 60.9390298298427, 57.22736815043858, 58.8756719316755, 60.23086942945208, 64.16075665610177, 58.502400806971956, 42.08911943435669, 30.226508617401123, 38.16796261923653, 38.82484878812517, 40.37567976542881, 39.4096473966326, 28.44962321008955, 42.64104611533028, 54.061946051461355, 58.33506734030587, 57.263801029750276, 60.77047348022461, 55.55754232406616, 55.00287110464913, 56.97002077102661, 58.57550975254604, 55.42086083548409, 57.752012729644775, 57.7981070790972, 54.238576207842144, 46.18089621407645, 43.85384028298514, 33.24351372037615, 26.775018760136195, 26.705053874424525, 23.363665172031947, 21.825997556958878, 22.27055719920567, 16.295280115944998, 16.456794466291154, 14.369320239339556, 16.67343929835728, 14.903720957892281, 7.471200789724078, 5.530100354126521, 9.228213480540685, 12.025386265345983, 5.3141655411039075, 5.806904426642826, 3.248612880706787, 0.6643152045352119, 0.3436340450176171, 0.1267027218959161, 0.06266507705939667, 0.6022603000913347, 7.045027817998614, 13.091620343072073, 29.6964305468968, 53.9532345363072, 36.63366835457938, 31.77778775351388, 25.17490073612758, 25.86005391393389, 32.337635380881174, 40.55071183613369, 38.866121087755474, 40.56883273805891, 51.33681045259748, 36.510775566101074, 15.687918969563075, 3.141383068902152, 0.03084897037063326, 0.003001491173303553, 0.03416976824934993, 0.018346450358097042, 0.06409692165574857, 0.06394155749252864, 0.07678746711462736, 0.019532017276755402, 0.011250787447871906, 0.062397931037204604, 0.021335303816678267, 0.028582317355488027, 0.03684382386771696, 0.05005570813747389, 0.05059130296909383, 0.159215012299163, 0.0022658165086925563, 0.014694303473723786, 0.042001331225037575, 0.04807907116732427, 0.037779401522129774, 0.031442654585199695, 0.04900991264730692, 0.05330564321151801, 0.016294713132083416, 0.0401941549831203, 0.015844452560746243, 0.036573196960879226, 0.022341345636440173, 0.03339403987463031, 0.025265631398984363, 0.0425592227173703, 0.06722480524331331, 0.011895070018778955, 0.03143808125917401, 0.03498216126380222, 0.043311331288090775, 0.02688356931321323, 0.030998943573130027, 0.01874959345773927, 0.04577057629025408, 0.05399221208478723, 0.08555729474340167, 0.024088081371571337, 0.04313167217852814, 0.06333726777562074, 0.13486666525048868, 0.0475331965301718, 0.0163205754943192, 0.02847330391939197, 0.051237811134862046, 0.014108143364345389, 0.042233848212552924, 0.0694900740470205, 0.03456365782767534, 0.04484836577570864, 0.014756350412166544, 0.024878674752211997, 0.007586677991119879, 0.1156911299164806, 2.7509283976895467, 29.83351503099714, 43.72384296144758, 49.073844705309185, 57.70607124056135, 44.83410256249564, 40.58738442829677, 25.056098699569702, 29.238843032291957, 25.599380084446498, 25.550291061401367, 19.24960204533168, 18.331873553139822, 36.087067467825754, 29.64146682194301, 19.7922910962786, 4.586330447878156, 0.428434637508222, 0.22949959657021932, 1.0652753348861421, 2.061750041587012, 5.368238593850817, 7.631019779614039, 15.246543339320592, 10.556688206536428, 9.70012470654079, 11.313591957092285, 15.786319358008248, 13.80681926863534, 13.008305362292699, 15.31829217502049, 13.060798134122576, 14.671355826514107, 7.265927987439292, 6.641090818813868, 12.914803453854152, 26.79016235896519, 31.936821596963064, 39.40552364076887, 47.173977919987266, 55.22061027799334, 55.07507331030709, 60.858597482953755, 56.90719515936715, 60.11637006487165, 59.651132583618164, 60.4775721686227, 59.8540894644601, 60.33083316258022, 59.35503510066441, 56.22577142715454, 58.07490594046456, 61.44627611977713, 67.17626789637974, 61.831984519958496, 46.18937996455601, 36.63732310703823, 45.48168509347098, 45.620058468409944, 47.564338139125276, 46.949307918548584, 36.232521057128906, 46.94858877999442, 56.41068731035505, 56.307374545506065, 57.279031481061665, 62.609522683279856, 58.41438797542027, 57.611419405256, 59.792590958731516, 60.97368049621582, 58.82275445120675, 58.54423591068813, 58.27183525902884, 54.35326664788382, 46.55687713623047, 42.311718872615266, 35.18089730398995, 27.250617742538452, 24.03830225127084, 18.088023049490793, 15.2237480367933, 15.59791374206543, 13.285871131079537, 17.700577599661692, 17.833998646054948, 14.008868541036334, 12.10936393056597, 9.505496978759766, 10.915328162057058, 11.812327572277614, 10.600718072482518, 11.732751590864998, 6.842218586376735, 6.709369029317584, 3.5085454242570058, 1.388565787247249, 0.49791073373385836, 0.06227144532437835, 0.7316413489835603, 6.917134063584464, 13.264383826936994, 26.675869703292847, 42.98709767205374, 39.54992110388619, 33.51892294202532, 28.22025622640337, 25.716415541512625, 35.234005859919954, 46.81965800694057, 45.812669481549946, 46.21264600753784, 58.8992680140904, 44.553624629974365, 20.08715179988316, 4.48220648084368, 0.033963632703359635, 0.03737218551603811, 0.02669033780694008, 0.0277451951322811, 0.025332502721409713, 0.09750826417335443, 0.04696461811129536, 0.027966149883078675, 0.0737807359546423, 0.07806956581771374, 0.057561177361224375, 0.05019291131091969, 0.017886539322457144, 0.023202333632590513, 0.0660307803856475, 0.027702788389953117, 0.03980957151257566, 0.043570955749601126, 0.027856576655592238, 0.011286801542155445, 0.013752525705578071, 0.03182558582297393, 0.09344577323645353, 0.06002636972282614, 0.020695168791072707, 0.08967630086200577, 0.014483782895175474, 0.03535268548876047, 0.03172859602740832, 0.03291696190301861, 0.02240015087383134, 0.15547103248536587, 0.22583508677780628, 0.1128131439909339, 0.18861783455525125, 0.06881860257791621, 0.15807010659149714, 0.09968853289527552, 0.1439485443489892, 0.12987817078828812, 0.118873106315732, 0.16779662109911442, 0.17405389462198528, 0.09773517985429082, 0.19512497181338923, 0.33499917121870176, 0.252376703279359, 0.1860063432582787, 0.17317763449890272, 0.22497676712061676, 0.19734056506838116, 0.13353820224957808, 0.15839786614690507, 0.15473118504243238, 0.10944113028900963, 0.10899240151047707, 0.2182966848569257, 0.09591232945344277, 0.14403053852064268, 0.27591524592467714, 5.378187111445835, 38.00068473815918, 58.43819945199149, 68.12988036019462, 66.71697112492153, 55.33318846566336, 48.51232951028006, 31.517442226409912, 32.34719262804304, 35.67523036684309, 40.926935945238384, 25.542380537305558, 30.797594955989293, 51.86257716587612, 36.69786623546055, 24.57727575302124, 5.10832906620843, 0.5198454367262977, 0.46770550310611725, 1.0100395445312773, 1.550966467176165, 6.877309594835554, 12.415611863136292, 19.20876748221261, 18.889900752476283, 22.255259002958024, 15.888539518628802, 20.91223301206316, 23.098909275872366, 27.29836228915623, 28.778922660010203, 23.43772602081299, 28.354547534670147, 31.327412469046457, 19.32244348526001, 22.91337674004691, 38.5689640045166, 40.705406529562815, 42.708339418683735, 51.38440213884626, 56.659696851457866, 57.81528302601406, 63.33172539302281, 59.21071406773159, 61.75360189165388, 60.11220809391567, 63.10293510981968, 61.677560806274414, 62.618360791887554, 61.08608150482178, 56.47349902561733, 58.38232203892299, 61.179805755615234, 66.863098689488, 67.24880014147077, 51.879416125161306, 42.49089206968035, 50.32868242263794, 47.93089035579136, 51.883369650159565, 50.83150618416922, 41.005318573543, 51.39077711105347, 56.96107496534075, 57.46135221208845, 58.4824664252145, 64.44581345149449, 59.849468912397114, 60.05036217825753, 61.72317573002407, 62.535698073250906, 58.248781136104036, 58.85909352983747, 58.21994611195156, 55.78406402042934, 46.6330189704895, 46.48395579201834, 37.958568232400076, 32.58928871154785, 34.593329838344026, 28.45380081449236, 29.185303688049316, 34.757046767643516, 29.88471630641392, 30.8929728780474, 26.515750203813823, 28.857364348002843, 23.750259467533656, 15.052735498973302, 14.141181349754333, 17.12311281476702, 19.884750774928502, 15.902382067271642, 15.121039765221731, 10.176070230347769, 5.429735362529755, 0.7411886623927525, 0.4038236838366304, 0.17973003004278454, 0.7957736019577298, 9.324145521436419, 17.6852377142225, 36.549570832933696, 62.19998891013009, 50.09458024161202, 44.33367592947823, 36.38881383623396, 35.826183455330984, 42.33946997778756, 53.412622996738975, 51.544512953077046, 55.56326069150652, 66.50222315107072, 53.75999471119472, 29.748055662427628, 6.574880565915789, 0.17417213613433496, 0.1834192792219775, 0.06417802016117743, 0.2070738242140838, 0.1078509631167565, 0.23703323517526897, 0.15185917701039994, 0.08982091703053031, 0.1032561818137765, 0.1380693641092096, 0.19437631698591368, 0.12889638489910535, 0.06832261383533478, 0.14871586353651114, 0.20264632893460138, 0.23981639583195957, 0.10984428865568978, 0.1528731526008674, 0.08932931162416935, 0.10157608839550189, 0.06946068669536284, 0.13988858434770787, 0.14021889519478592, 0.18617234006524086, 0.10649634937622718, 0.21111629158258438, 0.10303685893969876, 0.15985075889953546, 0.13076163695326873, 0.1786281977381025, 0.1870120678629194], [0.033451983372547796, 0.05639961361885071, 0.04147493054292031, 0.030792434832879474, 0.011506865715741046, 0.07207582172538553, 0.06432357949337789, 0.05524021440318652, 0.030033819111330167, 0.018833711444001113, 0.04131437558680773, 0.046468028865222416, 0.01706925067784531, 0.056729351103838, 0.04776745396000998, 0.07941189128905535, 0.04297078474025641, 0.030636643192597797, 0.031944977452180216, 0.03263559039416058, 0.008598543337679334, 0.010218404050517296, 0.07448042769517217, 0.015369532330493842, 0.038460732105055025, 0.0304741340556315, 0.07200380880385637, 0.050830038730055094, 0.11837525160184928, 9.207947322300502, 27.17494317463466, 40.80192395618984, 44.66477843693325, 42.62975876671927, 35.41600349971226, 25.75701560292925, 24.160541909081594, 13.424142020089285, 19.253703219549998, 19.83407756260463, 20.220029149736675, 44.639375822884695, 38.3085663659232, 19.644471645355225, 6.891220756939479, 0.767971470952034, 0.18965881583946093, 0.02613297726825944, 0.4388556054660252, 2.646106570959091, 6.943125103201185, 7.132961179528918, 10.560769404683795, 8.105943049703326, 5.66456059047154, 13.940560800688607, 21.605593749455043, 15.272029331752233, 9.038089922496251, 9.524267537253243, 10.711721624646868, 17.3317620073046, 12.520908338682991, 19.535645484924316, 29.16524771281651, 36.31258167539324, 46.75586659567696, 55.81810324532645, 60.649720736912315, 59.201459067208425, 61.71981280190604, 58.59162262507847, 59.88573156084333, 58.715050424848286, 57.59805801936558, 57.03172424861363, 59.312018803187776, 60.4240015574864, 60.1127986907959, 60.66499982561384, 59.7494843346732, 58.719851630074636, 62.681714466639924, 59.057026863098145, 46.686342920575825, 29.18782935823713, 34.003476415361675, 40.13661657060896, 40.80681896209717, 36.29407862254551, 27.786139726638794, 42.47685323442732, 50.98502663203648, 59.62290205274309, 59.31544426509312, 58.815472739083425, 53.34128931590489, 52.43894413539341, 56.499572140829905, 56.114339692252024, 60.2534510748727, 54.0557621547154, 53.089931283678325, 54.258934429713655, 54.60266181400844, 50.90995829445975, 49.28764772415161, 36.21567167554583, 36.33061225073678, 42.04434871673584, 33.36408233642578, 28.754991327013286, 15.885025467191424, 18.870046275002615, 14.526883670261928, 16.45224165916443, 9.030302728925433, 5.60006263426372, 10.249206968716212, 8.913731932640076, 12.521588393620082, 3.4915227719715665, 5.290919474193028, 4.25075330053057, 3.602469870022365, 1.604009775178773, 0.5364737244588988, 0.33461001781480654, 0.026019164893243994, 0.6919806514467511, 5.134855551379068, 13.934783373560224, 20.552123512540543, 36.36639894757952, 27.572618109839304, 26.391801289149694, 55.106069224221365, 82.60700798034668, 55.51127774374825, 34.628171580178396, 35.100645610264365, 47.91990177971976, 45.5082619530814, 30.672635078430176, 5.573796272277832, 0.4705400424344199, 0.07932522201112338, 0.010761360138920801, 0.024356282515717403, 0.021653730122904693, 0.039505828704152784, 0.04168010935453432, 0.018121246281745176, 0.02326247388763087, 0.08388543874025345, 0.03475492327873196, 0.029390825756958554, 0.030520786730838672, 0.06685251343463149, 0.04330898355692625, 0.052290391975215504, 0.040688840938465934, 0.01243049097580037, 0.009809553623199463, 0.06856460656438555, 0.03250416833907366, 0.031110148677336316, 0.03510217035987547, 0.05197174853778311, 0.01672166772186756, 0.002642946272057348, 0.07241257865514074, 0.12637040258518287, 0.06342091757271971, 0.12139929219016007, 0.041093919559248855, 0.034678825576390536, 0.028156495919185023, 0.04803712073979633, 0.0428118989802897, 0.017393793977264847, 0.03180958257455911, 0.08257248704986912, 0.031019720315401043, 0.053718945676726956, 0.03574204923851149, 0.03654668999037572, 0.03695795006517853, 0.11537099709468228, 0.025487661627786498, 0.01955327408255211, 0.06107068261397736, 0.08078095782548189, 0.023133318139506236, 0.02947209050346698, 0.027728306395666938, 0.032479839465980015, 0.039018895011395216, 0.03346265672839113, 0.03651636965306742, 0.01744132874799626, 0.011367516675298768, 0.042509916970240216, 0.044723172672092915, 0.2667819745838642, 9.960514528410775, 36.36363703863961, 53.46143061774117, 56.333683899470735, 53.49719646998814, 45.489606039864675, 34.965114048549104, 26.38626183782305, 19.941746847970144, 27.2453544821058, 25.212476594107493, 23.93776876585824, 37.726446287972585, 35.49580703462873, 20.72246902329581, 8.252087116241455, 1.1105769383055824, 0.20005013181694917, 0.40146990013974054, 2.339950919151306, 7.967963116509574, 9.704648852348328, 7.251976004668644, 12.135740160942078, 12.279375059264046, 17.712424278259277, 12.323272040912084, 15.896682807377406, 22.261017322540283, 12.008002740996224, 10.59929803439549, 10.230653541428701, 10.987835219928197, 11.121084298406329, 17.983577728271484, 27.48073513167245, 35.99212033408028, 45.47608831950596, 54.991566385541645, 61.56149809701102, 59.12505667550223, 61.662399836948936, 59.31818185533796, 61.19524465288435, 63.02740819113595, 59.16195855821882, 58.097206183842246, 60.286545344761436, 61.26427500588553, 61.414884158543174, 60.96878201620919, 59.315527643476216, 60.29900346483503, 63.21916457584926, 61.80445575714111, 51.6381572995867, 35.2050735609872, 41.834662505558555, 48.27476365225655, 47.59396873201643, 44.41159997667585, 34.8936379296439, 47.20673867634365, 55.17259475163051, 59.62265191759382, 59.512661933898926, 59.85303333827427, 56.44935056141445, 55.353300026484895, 59.19943019321987, 59.331897599356516, 60.6528057370867, 55.77757787704468, 52.95454910823277, 55.749878883361816, 53.05440861838204, 51.747587953295024, 45.12225478036063, 35.78524466923305, 36.039604323250906, 27.684883628572734, 20.479184797831945, 20.91879211153303, 11.69025467123304, 14.1333281482969, 17.058492830821447, 13.50165091242109, 11.285674963678632, 10.775710191045489, 13.33999238695417, 9.227023601531982, 12.640823824065071, 12.729897992951528, 9.199787531580244, 10.58065254347665, 6.862087394509997, 3.9266706449644904, 0.9347027242183685, 0.14600973017513752, 0.1138575654476881, 1.072710884468896, 5.735955502305712, 13.058644192559377, 22.167095048086985, 35.3248153414045, 34.05841929571969, 22.172198499952042, 42.98615619114467, 75.44283853258405, 59.22320692879813, 39.942369256700786, 40.886410576956614, 54.04831368582589, 53.36569138935634, 37.0961890901838, 9.213758621897016, 0.6384547150560788, 0.09495876383568559, 0.034477066581270525, 0.04495740296053035, 0.015607004319982869, 0.06043055946273463, 0.03970137910385217, 0.035257524345070124, 0.013673923360849065, 0.01705757817918701, 0.03967024791719658, 0.07837196851947478, 0.00851467640937439, 0.07956415454724006, 0.016974437283352017, 0.01619724666566721, 0.030255472753196955, 0.03091088669108493, 0.016619899343433123, 0.033983615559658835, 0.08997781468289238, 0.05209634792325752, 0.04317830789035984, 0.050574383698403835, 0.04806297292400684, 0.024136260750570467, 0.04362776270136237, 0.08510023355484009, 0.019582566439307163, 0.0412782944871911, 0.04634294771988477, 0.10680996826184647, 0.19887459703854152, 0.16372257471084595, 0.12425447255373001, 0.1427887108709131, 0.1153011079877615, 0.20464507596833365, 0.17088599103902066, 0.15795027730720385, 0.10242695773818664, 0.15870566320206436, 0.133376575208136, 0.13442092202603817, 0.1378310490399599, 0.19595719501376152, 0.20215075409838132, 0.18845980374940804, 0.13332174957862922, 0.09291603416204453, 0.10676352932517018, 0.101487166381308, 0.10812575622860875, 0.16622320695647172, 0.120053784389581, 0.1838541387447289, 0.1080543879153473, 0.16239297177110398, 0.19500800594687462, 0.9255117774009705, 16.228431497301372, 49.11959511893136, 67.59019293103898, 69.11601039341518, 63.94800281524658, 55.891076701028005, 42.90550150190081, 38.14622170584542, 24.72066225324358, 32.679493699754985, 33.55379595075335, 33.94756426130022, 58.45074789864676, 48.74253722599575, 24.37725796018328, 9.313612052372523, 1.2135236199413026, 0.5102731532284192, 0.4285491742193699, 2.175456008740834, 8.184026905468532, 16.950236422674998, 15.958523511886597, 17.010902881622314, 19.11465413229806, 17.37732481956482, 21.96953865459987, 28.041454757962907, 22.34484907558986, 18.556496654238018, 23.43720143181937, 22.126581839152745, 28.78577879496983, 22.842300142560685, 26.047934940883092, 34.470256396702354, 41.12592193058559, 49.445931162152974, 61.01856585911342, 63.43758814675467, 62.611322266714915, 64.42523983546666, 60.001078605651855, 61.46719714573452, 63.508619580950054, 60.11231231689453, 58.66641303471157, 60.20437594822475, 62.820393562316895, 62.09659971509661, 62.63976124354771, 61.19863537379673, 60.21795967647007, 62.688155446733745, 64.05338614327567, 56.03401156834194, 41.100713866097585, 45.83477864946638, 51.46570995875767, 50.99928086144583, 48.62576232637678, 41.1884001323155, 48.434395040784565, 55.45203740256173, 60.22770799909319, 61.16315787179129, 63.83137035369873, 58.661375590733115, 56.88358518055507, 61.17992387499128, 60.24146543230329, 63.4255816595895, 55.696162360055105, 53.847858156476704, 54.37986782618931, 54.630301748003276, 53.05537789208548, 50.53923715863909, 39.049039363861084, 44.47121204648699, 46.985487188611714, 39.906662464141846, 37.41387115206037, 22.888785328183854, 28.092828001294816, 22.87931145940508, 23.52574232646397, 17.9528215272086, 14.467488731656756, 16.927008594785416, 16.700915949685232, 18.54568178313119, 10.54478941644941, 12.442048890250069, 11.625739778791155, 6.993537323815482, 3.6517117534364973, 1.0508699821574348, 0.6787408590316772, 0.233407768287829, 1.2552924986396516, 7.642010961260114, 17.949389117104666, 26.122320617948258, 45.8547442981175, 40.65797812598092, 36.94367265701294, 65.49632549285889, 89.17133944375175, 66.05797617776054, 48.20053257261004, 48.02715069907052, 62.03280135563442, 63.71322318485805, 46.6769072668893, 16.503046887261526, 0.9028446908508028, 0.20808845119816916, 0.22855260595679283, 0.13923132818724426, 0.10044322668441705, 0.09641886263021401, 0.12055664669190135, 0.08588487109435455, 0.1539314365280526, 0.29295999131032396, 0.11915000288614205, 0.15300797750907286, 0.12000559483255659, 0.16085480073732988, 0.2274001142276185, 0.1541146816951888, 0.15810711389141424, 0.08225368415670735, 0.11781015406761851, 0.13165528114352906, 0.1567733718880585, 0.10620895586907864, 0.16568761212485178, 0.15371176760111535, 0.16922055397714886, 0.09971864627940313, 0.2117738462984562, 0.243497584015131, 0.08111040014773607, 0.13372817848409924, 0.16670293121465615], [0.013290551075312709, 0.07635626489562647, 0.022109732796837176, 0.04471948144159146, 0.020460928324609995, 0.03636994518871818, 0.013667366168062602, 0.026954401583809937, 0.026278404286131263, 0.026529073781733, 0.05467264360881277, 0.023617909190111926, 0.03704744544146316, 0.032408209916736395, 0.03474667907825538, 0.06611782964318991, 0.014200649739775275, 0.04876353318936058, 0.023889603093266487, 0.018761740930910622, 0.11539821991963045, 0.012753327759648008, 0.03716466236593468, 0.06218835871134486, 0.04951582157186099, 0.06851781478949956, 0.020753801002034118, 0.053818727643894296, 1.9780720174312592, 19.783954995019094, 29.89658730370658, 39.446705613817485, 46.54872342518398, 40.177697794778005, 28.45132725579398, 31.92448159626552, 27.369953053338186, 20.29600075313023, 23.505554335457937, 20.899019275392803, 38.53070374897548, 40.88976655687605, 25.927901336124965, 9.184396403176443, 2.1628782493727545, 0.11646052077412605, 0.04672160418704152, 0.692148493868964, 1.6843233512980598, 7.865961824144636, 4.086977745805468, 3.9748668244906833, 17.367967333112443, 8.454568914004735, 11.10142958164215, 9.946609445980616, 16.075751781463623, 21.436121974672588, 10.8125547511237, 16.35740395954677, 17.950330598013743, 21.800207580838883, 22.675515583583287, 27.924533946173533, 36.43742690767561, 50.689384256090435, 56.56437798908779, 59.57004015786307, 60.04518577030727, 58.664411953517366, 57.688273429870605, 61.113672801426475, 59.8864472252982, 62.4045786176409, 58.70776176452637, 55.09224925722395, 60.91323116847447, 61.63594804491316, 63.418015071323936, 61.49029295785086, 63.18881484440395, 59.54581873757498, 63.35627337864467, 56.320583071027485, 49.64271804264614, 32.13496685028076, 29.8536057472229, 38.94545909336635, 49.64359698976789, 36.13501698630196, 30.235193865639822, 40.75693784441267, 49.30844715663365, 58.45566027505057, 60.030010904584614, 56.66249697549002, 53.338902609688894, 50.01279994419643, 53.90732084001814, 55.89759758540562, 57.35349185126168, 58.03710774012974, 56.05135774612427, 53.87869773592268, 53.011288097926546, 53.79834876741682, 52.5205020904541, 48.11527817589896, 45.79445825304304, 35.02488245282854, 32.64717762810843, 33.294190406799316, 22.996841975620814, 17.673203434262955, 22.195817164012364, 9.463672297341482, 8.450113381658282, 9.274481534957886, 12.80541101523808, 11.564812762396675, 9.084245068686348, 16.932912826538086, 5.161047654492514, 7.762986046927316, 5.910025681768145, 5.391201955931527, 1.2918716158185686, 0.1942696648516825, 0.1962717231363058, 0.017833443957247903, 1.3918339375938689, 5.351648032665253, 21.283174753189087, 40.390489850725444, 52.333831787109375, 52.09490755626133, 66.240081514631, 58.87950733729771, 32.07078981399536, 27.60631513595581, 40.74145378385271, 48.74947847638811, 53.73283420290266, 36.62677574157715, 15.260424103055682, 2.6190107677664076, 0.053796648114387474, 0.01161469765273588, 0.05587511283478566, 0.05376659919108663, 0.07412001024931669, 0.006830193293613515, 0.06301737244107894, 0.036264236218162944, 0.002207123441621661, 0.01781048742122948, 0.05077962018549442, 0.0710599801636168, 0.05780577566474676, 0.04829676555735724, 0.061746272790644846, 0.009159301640465856, 0.07979879874203887, 0.018389572954869697, 0.06891711229192359, 0.028053061737279807, 0.043279898153351884, 0.044880877781127176, 0.04859836758779628, 0.06657183742416756, 0.07171767058649234, 0.04252245290470975, 0.04036126798018813, 0.011852759119522358, 0.05874207935162953, 0.004623949827094163, 0.027797181092734848, 0.044484294418777735, 0.08199575264006853, 0.0791218379246337, 0.07493161277047225, 0.015717288312901343, 0.040786085184663534, 0.029113752767443657, 0.05082896325205054, 0.061383249770317755, 0.04382345898609076, 0.01699144815626953, 0.010156763384916952, 0.05606678540685347, 0.020765208872035146, 0.03391913098416158, 0.011322228703647852, 0.0479203652191375, 0.11904350002961499, 0.060110555562589846, 0.07299057514007602, 0.06661151815205812, 0.015453012493838156, 0.03478632587939501, 0.04416504708517875, 0.05710262339562178, 0.05542720847630075, 0.06097813043743372, 1.7148850028003966, 23.578470468521118, 40.57915081296648, 53.57265738078526, 55.82877567836216, 49.89097717830113, 34.30209609440395, 35.906640120915, 34.93492412567139, 20.326616253171647, 31.30392755780901, 20.691537380218506, 28.552322796412877, 40.528988293239046, 27.695406675338745, 9.272908636501857, 2.183951701436724, 0.11374560716961112, 0.3474786515746798, 1.8069143274000712, 5.359692743846348, 7.1200575062206815, 8.950155258178711, 9.635502985545568, 13.196921161242894, 10.14545386178153, 14.110969713756017, 12.427101578031268, 15.544843401227679, 17.51852090018136, 15.206156935010638, 10.864312750952584, 15.192851134708949, 19.89462763922555, 22.68495123726981, 29.57056392942156, 38.49598012651716, 51.28871154785156, 56.920278617313926, 62.14871120452881, 61.37204156603132, 61.20674392155239, 58.32638904026577, 60.54845074244908, 59.79308428083147, 60.77258573259626, 59.30771092006138, 54.88362264633179, 59.80748789651053, 62.57556683676583, 64.06555243900844, 61.340059007917134, 63.147535596575054, 61.179548672267366, 64.25318159375871, 59.83546829223633, 56.73300034659249, 37.065957478114534, 36.12248591014317, 46.38610431126186, 52.74037088666643, 44.5289237839835, 38.99413122449602, 47.18833984647478, 53.169491631644114, 59.14501190185547, 61.53349685668945, 58.29751927512032, 56.53734949656895, 51.97179937362671, 55.6679596219744, 57.786260400499614, 61.06099155970982, 58.6480906350272, 56.20106363296509, 54.87675435202462, 52.30182491030012, 55.00886740003313, 52.284249441964285, 47.96335581370762, 43.12158005578177, 37.92541490282331, 29.379589217049734, 27.684260027749197, 20.685596670423234, 13.422517878668648, 11.984835709844317, 10.382784349577767, 12.934881142207555, 13.116352455956594, 18.431418657302856, 13.031730345317296, 16.16261121204921, 21.144287211554392, 13.100013766969953, 12.075007694108145, 9.012185301099505, 7.8150688750403265, 3.484478167125157, 0.9277660335813249, 0.11049963813275099, 0.08401326116706644, 1.6055217683315277, 6.396295794418879, 18.781435898372106, 37.66108805792672, 40.42658574240548, 44.511522020612446, 72.04678835187639, 72.75048800877163, 40.389788082667756, 32.10729564939226, 44.069957051958355, 56.57621771948678, 61.6412147794451, 45.26871585845947, 20.233447858265468, 3.578277111053467, 0.13315050091062272, 0.04234157243211355, 0.056171747988888195, 0.054746115380632024, 0.030040085382227386, 0.045161642001143525, 0.021794337845806564, 0.04066146883581366, 0.032704203855246305, 0.0308428262360394, 0.020505338441580534, 0.04757603923124926, 0.05449242810053485, 0.04117262962141207, 0.006087162249189402, 0.06749034313751118, 0.06161279138177633, 0.02545454233352627, 0.09373681726200239, 0.06366338527628354, 0.01839284858267222, 0.0038438631371328874, 0.038133888571922264, 0.03379021950864366, 0.04171344917267561, 0.02843537211551198, 0.013702958722465804, 0.03970436805060931, 0.04749920192573752, 0.023187032667919993, 0.1756128966808319, 0.1577974305089031, 0.1594450492411852, 0.20909095954682144, 0.1077897185459733, 0.1418036680136408, 0.10630984045565128, 0.12780783831008843, 0.12217514270118304, 0.13499998381095274, 0.15655420507703507, 0.09087241560752903, 0.09893604434494462, 0.10014712078762905, 0.1431223058274814, 0.28307316611920086, 0.1302745845168829, 0.13139167028878415, 0.24169848912528583, 0.12704500210072311, 0.16842248822961534, 0.15791127511433192, 0.10744323820940085, 0.12203691154718399, 0.15693385899066925, 0.2516422026923725, 0.1445510291627475, 0.16401009713964804, 3.119366181748254, 32.409667355673655, 53.841976506369456, 67.64556312561035, 67.03312110900879, 60.754221643720356, 42.74112796783447, 47.84941577911377, 40.510158675057546, 32.2193284034729, 35.3014554977417, 32.79078647068569, 54.778041294642854, 52.01454816545759, 32.58593967982701, 11.341034735952105, 2.8503794840403964, 0.4057098211986678, 0.2911813610366413, 1.7375540435314178, 5.341847598552704, 11.11612067903791, 16.314141001020158, 17.06662917137146, 24.887903656278336, 21.188441276550293, 19.690187317984446, 19.88602924346924, 29.58488416671753, 33.91680458613804, 23.513593401227677, 22.74430274963379, 27.33914474078587, 29.515169416155132, 27.014519691467285, 32.27130092893328, 41.42560120991298, 56.203495502471924, 60.43040084838867, 63.54488917759487, 62.03889492579869, 60.35206685747419, 58.16967936924526, 61.44881221226284, 60.128418241228374, 63.43482971191406, 59.435946873256135, 56.24619913101196, 61.799536432538716, 64.93748188018799, 68.31885746547154, 65.78093760354179, 65.0296983718872, 62.908288274492534, 65.07511874607631, 62.06199768611363, 60.88762705666678, 42.520970821380615, 40.769899708884104, 48.679232188633506, 58.37685380663191, 50.79192229679653, 44.22801119940621, 50.02555683680943, 53.855473382132395, 59.7073643548148, 63.883467946733745, 61.715136664254324, 58.62942777361189, 55.11823551995413, 57.68303448813302, 60.01707335880825, 61.55425112588065, 60.6278269631522, 57.97635269165039, 55.22581100463867, 53.19405003956386, 55.71287625176566, 53.453846658979145, 50.439384596688406, 47.53095204489571, 39.7444498198373, 38.3172516141619, 38.19718674251011, 31.462169306618826, 24.52329867226737, 33.42908273424421, 19.184823989868164, 18.26416335787092, 15.49458360671997, 25.30357095173427, 20.84398433140346, 19.96686805997576, 35.73374114717756, 12.952597311564855, 15.31700849533081, 13.355267133031573, 13.754429851259504, 4.510671079158783, 0.45415377457227024, 0.48676880874804085, 0.11793142184615135, 1.8320912335600172, 7.412726487432208, 25.707633018493652, 48.84473480497088, 64.017470904759, 63.331037521362305, 73.94729437146867, 62.658604758126394, 42.01316867555891, 39.085458346775596, 53.35068328039986, 62.33445739746094, 68.75641332353864, 53.67710270200457, 28.736092226845876, 6.292234361171722, 0.3137354850769043, 0.11850162196372237, 0.1807346689913954, 0.1346116717904806, 0.19801103909100803, 0.08344671835324594, 0.15899207283343586, 0.14256054668554238, 0.15468541107007436, 0.07316814096910612, 0.2052285618015698, 0.11586407492203371, 0.29191903716751505, 0.1307370468441929, 0.14920358093721525, 0.17761308220880373, 0.18807149172893592, 0.1538176326347249, 0.17349749590669358, 0.12996856522347244, 0.1068716538803918, 0.13750631575073513, 0.1785613348973649, 0.23504713603428432, 0.2000284186963524, 0.1106211162571396, 0.09438462821500641, 0.09104692124362503, 0.15125855138259275, 0.19903406633862428], [0.06200830265879631, 0.04515390670193093, 0.071672358017947, 0.020424190742362822, 0.06201812784586634, 0.05508239733587418, 0.029802710083978515, 0.04090092723656978, 0.019385993148067167, 0.022615560297189013, 0.040070332520242245, 0.06007801302309547, 0.023091108172333667, 0.028338977734425237, 0.029037902730384042, 0.07844472104417426, 0.09934426458286387, 0.05608232046610542, 0.033937386968838315, 0.0544866300188005, 0.013471914155940925, 0.005861509491556457, 0.03712630817400558, 0.02350440215585487, 0.03206373465114406, 0.05620067393673318, 0.007022190714321498, 0.16146101749369077, 7.3845802034650525, 20.221743617738994, 33.164658614567344, 42.96351548603603, 43.570857524871826, 35.278033120291575, 32.937247548784526, 27.30569611276899, 22.7965566771371, 18.564909185682023, 25.433814934321813, 48.425904342106406, 62.2271146774292, 31.965180669512065, 11.636536410876683, 5.826662063598633, 0.2820258880300181, 0.13912819086440972, 0.6442469071064676, 1.2004101978881019, 5.761262144361224, 9.277510949543544, 6.633700975349971, 6.891033589839935, 11.519984722137451, 9.6026588508061, 24.600298609052384, 9.756593585014343, 10.879782046590533, 30.911628791264125, 14.744648899350848, 16.34088809149606, 23.155066353934153, 29.44096612930298, 32.75497892924717, 43.47867577416556, 51.44230842590332, 56.64133276258196, 60.5638062613351, 59.31563186645508, 59.572465079171316, 58.09059844698225, 59.5059152330671, 59.236721175057546, 55.619621004377095, 59.10344777788435, 58.987781115940635, 55.60411957332066, 58.35673877171108, 59.58526366097586, 58.983862331935335, 60.64643423897879, 57.76418249947684, 60.656238147190635, 59.636742864336284, 58.20040430341448, 49.89819288253784, 37.32087646211897, 26.68887846810477, 37.161384037562776, 52.229667867933, 37.348262786865234, 33.2297180720738, 42.21292243685041, 46.100005286080496, 54.91628612790789, 61.346103940691265, 55.496377331869944, 51.99975545065743, 49.71428448813302, 50.87541879926409, 54.82075187138149, 55.50852278300694, 57.827018533434185, 54.19252702168056, 52.153651101248606, 50.27225610188076, 50.197872161865234, 54.55331570761544, 52.77950661523001, 52.80982507978167, 51.012086391448975, 38.50062499727522, 39.891199248177664, 32.09400027138846, 26.38671347073146, 23.72376251220703, 8.64796073096139, 10.18477371760777, 11.304708685193743, 14.386872257505145, 5.371687071663993, 11.481629797390529, 14.54688927105495, 16.18308581624712, 14.224955780165535, 9.454580579485212, 4.9060031686510355, 1.927834804568972, 0.20246590647314275, 0.0685147342405149, 0.08702255718942199, 0.10452955455652305, 0.9497123530932835, 6.417245047433036, 19.678658519472393, 35.07657010214669, 27.22366394315447, 18.55812774385725, 17.570896421160015, 22.02309536933899, 25.111932686397008, 38.613797255924766, 41.026983056749614, 50.2835191317967, 43.81098031997681, 22.792801175798687, 8.264110105378286, 0.18484893893556936, 0.051281308622232506, 0.009087384562008083, 0.013644726847165396, 0.15197192238909857, 0.013126696742671942, 0.025869714162711586, 0.07275599201342889, 0.024723524327522943, 0.031515447822000296, 0.03299261177224772, 0.015612081458259906, 0.03209559865561979, 0.05700460222682782, 0.03408350948510425, 0.028076874923759272, 0.0462146638892591, 0.07030232117644378, 0.023089176043868065, 0.07934955427689211, 0.04729845734047038, 0.07116998426084008, 0.05777400665517364, 0.08306124939450196, 0.008112919217507755, 0.06645473585064922, 0.017827354105455533, 0.12361688033810683, 0.02739658928476274, 0.07849782998008387, 0.015112330239000065, 0.028817314388496534, 0.03056854202545115, 0.021276050746174793, 0.03028539614751935, 0.020772411521258097, 0.03351490392482706, 0.07849361627761807, 0.04361651259075318, 0.09463681932538748, 0.029137956111558845, 0.03243402138884578, 0.07489468010940722, 0.035024630770619423, 0.025020875336070145, 0.03139582209821258, 0.09632936386125428, 0.08042131390954767, 0.008704560193499284, 0.06861300646726574, 0.023649528921980943, 0.041263597418687174, 0.004975156160071492, 0.013802449767743903, 0.012293129194793957, 0.06211936527064868, 0.028897052431213002, 0.18465129525533744, 7.511980635779245, 26.513842923300608, 44.520961148398264, 53.487941469464985, 55.2167192867824, 43.234467438289094, 38.06235000065395, 37.05180747168404, 30.591747624533518, 22.24420268195016, 29.69743456159319, 47.72727687018258, 57.90156923021589, 33.86492238725935, 13.454562970570155, 4.667014232703617, 0.7716679126024246, 0.2004025357642344, 1.230127208999225, 3.9440993326050893, 7.312762754304068, 9.90204804284232, 11.355836136000496, 13.700888769967214, 13.046179124287196, 14.018843548638479, 16.284543412072317, 18.422962699617656, 17.655949320111954, 20.874954189573014, 14.219966973577227, 13.318458182471138, 23.642781257629395, 29.01493385859898, 32.5518205506461, 42.16466719763619, 51.18776117052351, 58.30059037889753, 60.992524010794504, 60.88001877920968, 60.40258026123047, 57.92470325742449, 58.809101240975515, 60.08807005201067, 56.84140961510794, 59.71140820639474, 59.749831744602744, 57.8080221584865, 60.940412521362305, 62.84281539916992, 60.897271156311035, 61.04376002720424, 60.31558881487165, 62.72705146244594, 60.099367822919575, 60.963675090244834, 54.73041834150042, 43.59198352268764, 33.31150531768799, 42.11624867575509, 54.7030667577471, 44.98179694584438, 41.50968483516148, 48.66714232308524, 50.59931823185512, 55.88482679639544, 61.49689374651228, 55.45325681141445, 54.13617018290928, 52.616581780569895, 52.733658926827566, 57.18403918402535, 58.98093714032854, 60.27495574951172, 55.043719564165386, 53.16403382165091, 52.18021406446184, 52.407253401620046, 54.379065309252056, 53.43915121895926, 53.99420458929879, 49.24337380273001, 42.88738407407488, 37.085269996098106, 30.524311883108957, 21.594909157071793, 19.96386817523411, 14.533963016101293, 13.685076407023839, 16.32672766276768, 16.25501009396144, 13.614301187651497, 20.315559932163783, 18.33778820719038, 19.64666380201067, 13.71662209715162, 11.994000383785792, 7.668729390416827, 4.6989238347326, 3.9080538153648376, 0.636145144701004, 0.17322993597814015, 0.1187810291137014, 1.283378420131547, 7.229659693581717, 22.093240908214025, 39.382830824170796, 37.85830920083182, 30.186969893319265, 28.432167598179408, 26.580882617405482, 32.47876371656145, 43.371961866106304, 48.957788944244385, 57.53830003738403, 50.99393769672939, 28.71875647136143, 10.469726290021624, 0.24710565326469286, 0.1309332520301853, 0.03207799067188587, 0.06791077022041593, 0.04386894118839076, 0.01696958575796868, 0.07237297935145241, 0.023729370441287756, 0.03304181234644992, 0.06770381025437798, 0.011063544861307102, 0.018472433955009495, 0.01568017923273146, 0.04056863167456218, 0.03904200252145529, 0.03152325776006494, 0.013169235799328556, 0.024402370310521553, 0.00246289000746661, 0.02654601171213601, 0.01619339089042374, 0.058313754121107716, 0.06804075038858823, 0.03748904960229993, 0.047967292701027224, 0.08008689792560679, 0.02163254625962249, 0.058178366028836796, 0.03449393156915903, 0.029205887644950832, 0.19607444586498396, 0.15643881341176374, 0.13103793641286238, 0.12757071746247156, 0.14973821224910872, 0.16090502589941025, 0.08978051705551998, 0.19063900038599968, 0.08632350327180964, 0.19332465556051048, 0.10002436701740537, 0.16223067976534367, 0.17771216189222677, 0.15579136886766978, 0.09800233266183309, 0.1664289387741259, 0.19453061584915432, 0.16440372887466634, 0.1199919834200825, 0.18042379138725145, 0.17406108709318296, 0.18168075036789688, 0.08706685195543937, 0.10644490963646344, 0.12665557728282043, 0.151295165132199, 0.09031570476612874, 0.5753941131489617, 12.648189783096313, 35.449518135615754, 58.92374651772635, 65.93959971836635, 63.41401290893555, 54.1757401738848, 48.59651735850743, 44.5958696774074, 37.2861076763698, 30.267172949654714, 38.67989894321987, 64.14214938027519, 74.10865933554513, 39.64034148624965, 15.00849631854466, 6.39613424880164, 0.833714348929269, 0.5291366438780511, 0.8843991777726582, 4.082772782870701, 9.653603042875018, 17.86441264833723, 18.176341601780482, 17.42964996610369, 23.611345870154246, 19.89867149080549, 35.12249769483294, 17.59993989127023, 21.849642276763916, 43.24397952216012, 22.22825309208461, 24.419501270566666, 29.243262086595806, 34.16572380065918, 37.47013766424996, 47.239680085863384, 55.5499027797154, 60.1815858568464, 63.58394500187465, 62.356809752328054, 61.09694153921944, 59.043665477207725, 61.61919593811035, 59.82294069017683, 56.11737952913557, 59.06403759547642, 61.04330144609724, 59.158901350838796, 64.10398987361363, 65.27993079594204, 64.6486383165632, 64.27189309256417, 60.50449643816267, 64.19768633161272, 60.95776217324393, 63.012108257838655, 58.09526416233608, 50.08070468902588, 37.67093365533011, 46.33320767538888, 57.71151862825666, 49.89420461654663, 47.05130399976458, 51.17240912573678, 51.05008608954293, 56.60085950578962, 63.57294600350516, 58.64201096126011, 56.866193839481895, 54.615515981401714, 54.20362676892962, 60.04001631055559, 59.538120133536204, 62.873165130615234, 56.24756792613438, 53.264119148254395, 53.554105690547395, 57.14746734074184, 54.25804853439331, 54.9497833933149, 56.035772936684744, 53.92723090308053, 42.92183671678816, 45.46116358893258, 36.07795490537371, 31.519314765930176, 30.453012943267822, 16.60940817424229, 17.922136545181274, 21.70002497945513, 20.685655730111257, 12.035368221146719, 22.11836906841823, 24.20142684664045, 26.348475796835764, 22.263614211763652, 17.174835205078125, 11.422068102019173, 6.825583730425153, 2.9298058620521, 0.45242313029510633, 0.18048460169562272, 0.47866976048265186, 1.4816206225327082, 8.32341124330248, 24.164462430136545, 44.12780775342669, 37.39927298682076, 28.249850341251918, 28.056664364678518, 33.40897117342268, 36.870119026729036, 51.05645758765084, 55.511778014046804, 65.79958656855992, 60.518392835344585, 37.77393027714321, 14.982197386877877, 0.596433258482388, 0.21130282085921082, 0.11986686156264373, 0.11283704877964087, 0.21016718393989972, 0.1336850779397147, 0.20004622345524176, 0.12733138459069387, 0.059802853502333164, 0.15621755671288284, 0.1443045309611729, 0.1258474692170109, 0.134789393682565, 0.14526815925325665, 0.1427653149834701, 0.13930523422147545, 0.12442965672484466, 0.40973141682999475, 0.09881787747144699, 0.12031983797039304, 0.11545167490839958, 0.1245444512792996, 0.2172173120613609, 0.22723681799003057, 0.09568252321332693, 0.16505715809762478, 0.11978148828659739, 0.1739495223654168, 0.15519151676978382, 0.16041132381984166], [0.03258732280560902, 0.03521671385637351, 0.01591968343460134, 0.014188639669945198, 0.01594711999808039, 0.0357594163423138, 0.02184666137743209, 0.0326527980422335, 0.04844800762033888, 0.05330327512430293, 0.01770931954628655, 0.024937161078144397, 0.04369501230706062, 0.036448848633361716, 0.010249103519267269, 0.08386895712465048, 0.02186222866709743, 0.04513415115486298, 0.026098816422745585, 0.010518911095069987, 0.013558513035864701, 0.0554002740287355, 0.03192984612126436, 0.08426124536033187, 0.030786809777574878, 0.1035131158839379, 0.07752496682639633, 1.1838194195713316, 13.011224474225726, 26.465408767972672, 44.02051714488438, 45.0448066847665, 43.91691950389317, 38.08769702911377, 27.834196942193167, 19.890976360866002, 15.50754199709211, 18.619523763656616, 38.24235003335135, 51.58479860850743, 34.640185015542166, 18.878985132489884, 10.5676429101399, 1.0605034423725945, 0.1368421521037817, 0.15109995060733386, 1.7666554876736231, 3.892139835017068, 9.69600442477635, 6.197560812745776, 7.2848996094294955, 10.524577975273132, 9.658349531037466, 8.888040968350001, 9.855157256126404, 17.892113379069738, 15.887804746627808, 12.47139286994934, 25.10198286601475, 22.595399379730225, 36.45651708330427, 41.298244203839985, 46.82552228655134, 52.77284329278128, 55.54193319593157, 60.23774119785854, 58.1865530695234, 57.66872814723423, 58.06746441977364, 57.4055130141122, 59.096645491463796, 58.07658045632498, 55.95209230695452, 57.705713408333914, 60.33141681126186, 55.78885480335781, 54.022647040230886, 55.88439948218209, 56.78445870535714, 56.2676169531686, 58.12515183857509, 57.202754156930105, 60.533442633492605, 55.04004396711077, 52.336062158857075, 44.82611213411604, 33.13627174922398, 27.126132079533168, 55.05603872026716, 43.75808368410383, 33.39386231558663, 44.764478138514924, 46.407449177333284, 51.99608332770211, 61.73814214978899, 55.751060077122276, 52.74263252530779, 49.454637254987446, 48.909752573285786, 50.61834239959717, 54.060334069388254, 55.64818157468523, 59.28299617767334, 57.23735966001238, 49.39805459976196, 52.38382060187203, 54.1880384853908, 50.25398928778512, 52.56042991365705, 51.73971217019217, 51.75914280755179, 51.74948828560965, 47.1702641078404, 32.89777135848999, 24.192769391196116, 27.47481005532401, 20.085687467030116, 15.275896004268102, 21.063005447387695, 18.782459020614624, 22.260249546595983, 17.722507851464407, 13.5872449023383, 11.44002832685198, 8.917012350899832, 7.885722500937326, 5.1937254667282104, 4.924614787101746, 0.35149267475519863, 0.24538499702300343, 0.03764508551518832, 0.37675841471978594, 1.9325897608484541, 10.783083966800145, 19.156668152127946, 34.22585003716605, 35.81826250893729, 30.27390227999006, 24.061745473316737, 20.54040711266654, 25.064851692744664, 33.383054392678396, 46.050645283290315, 49.901239667619976, 36.82561581475394, 17.922306776046753, 1.3237726411649158, 0.037318672851792405, 0.040481260112885914, 0.06872491724789143, 0.008245264080220034, 0.016510283707508018, 0.06460738355027777, 0.026008812145196965, 0.03553623938933015, 0.06374457199126482, 0.04987221869773098, 0.017892530786671808, 0.029887676239013672, 0.05801733609821115, 0.005089339184840875, 0.014910175997231687, 0.024218146356620958, 0.05562325081388865, 0.07209819302495037, 0.05649046267249754, 0.03841283092541354, 0.05269083280914596, 0.0060328459450309825, 0.0865789038528289, 0.04707483255437442, 0.07507935020008258, 0.04106989263423851, 0.04098641586356929, 0.04325020546093583, 0.07572627905756235, 0.04527462486709867, 0.0677617300035698, 0.031816673265503984, 0.047416970266827514, 0.02236067201010883, 0.05458217792745147, 0.019428488099947572, 0.009832145446645362, 0.028946551560823406, 0.03933707704501493, 0.01645544111462576, 0.012907135533168912, 0.046837297800396166, 0.02389885322190821, 0.03542207247976746, 0.04823025894750442, 0.09771124792418309, 0.052512710581400564, 0.016694226069375873, 0.02313267013856343, 0.06578538141080312, 0.04523235892078706, 0.0597069493627974, 0.04702456668019295, 0.05714116418468101, 0.05523807362520269, 0.04191846174321004, 1.3483634016343524, 15.687912021364484, 33.705902440207346, 52.06162568501064, 57.32431983947754, 50.18254096167428, 45.3418630191258, 35.75832734789167, 27.439179692949565, 22.336552926472255, 23.99315980502537, 31.296277591160365, 48.94729021617344, 41.304160594940186, 21.18719581195286, 7.906012109347752, 1.1722170135804584, 0.06297427189669438, 0.2730434957359518, 3.7731019939695085, 8.402333225522723, 11.02109364100865, 12.731824381010872, 13.414037602288381, 12.819955331938607, 10.300158108983721, 13.777046237673078, 12.460535441126142, 17.841563497270855, 14.553653342383248, 13.507127829960414, 19.2218040398189, 22.95106029510498, 32.43525757108416, 36.75096436909267, 46.40741443634033, 53.173031738826204, 58.01670435496739, 60.59118216378348, 59.697859219142366, 59.155899729047505, 58.62746838160923, 58.10624231610979, 61.10305595397949, 58.86610426221575, 56.86701372691563, 58.539719581604004, 61.59991468702044, 58.24672099522182, 58.079901695251465, 57.71192857197353, 59.900294985089985, 58.392535890851704, 57.91159895488194, 59.308211190359934, 60.10561425345284, 57.01042454583304, 55.861929007938926, 51.23704474312918, 39.410835538591655, 33.68047203336443, 58.62597451891218, 48.318645000457764, 42.62011119297573, 50.325385502406526, 49.74161522729056, 53.79156385149275, 63.1803171975272, 59.49973828451974, 54.89218282699585, 51.960390431540354, 50.840566635131836, 52.324632372174946, 56.1679276738848, 57.915781770433696, 60.95944363730294, 57.5112750189645, 50.61979457310268, 53.10413687569754, 54.16197231837681, 51.281613962990896, 52.70057160513741, 55.53458547592163, 53.3664904321943, 49.71142530441284, 43.99920701980591, 32.39534364427839, 24.446390799113683, 21.990664652415685, 12.223439455032349, 10.42944758278983, 13.549477100372314, 14.207697323390416, 20.88732545716422, 22.44883234160287, 16.113669838224137, 15.326614379882812, 11.2093403169087, 9.947885308946882, 8.474097694669451, 5.312575272151402, 1.2235931881836482, 0.6198595442942211, 0.1836643796414137, 0.3789765185543469, 2.2715756509985243, 10.977339097431727, 20.48345446586609, 31.62504550388881, 36.1876391683306, 28.824871097292217, 24.62847008023943, 24.642934492656163, 31.933093888419016, 38.23898015703474, 51.74447863442557, 57.09235075541905, 42.096508843558176, 22.10723979132516, 1.6569994517735072, 0.07997928905699934, 0.08627821105931487, 0.048873225160475285, 0.05223403964191675, 0.028033262085435644, 0.010584631452469953, 0.06751951335796288, 0.04015325289219618, 0.0674559956948672, 0.018051265572596873, 0.027654144214466214, 0.022262828956757272, 0.014774055087140628, 0.021923978746469532, 0.07875289129359381, 0.0494151609018445, 0.07425361379448857, 0.01941849327912288, 0.022760181554726193, 0.05631196725049189, 0.042203032544681, 0.02251536611999784, 0.04849213953795178, 0.03158626652189663, 0.028188300551846623, 0.04945197821195636, 0.09338976017066411, 0.029702127445489168, 0.013171815080568194, 0.20349756468619618, 0.17184770586235182, 0.13296143391302653, 0.10516277022127594, 0.16369229847831385, 0.10739669070712157, 0.09245924438749041, 0.09573051599519593, 0.21840982378593513, 0.15200612055403845, 0.119695531470435, 0.19982515674616608, 0.10462045110762119, 0.13697952830365726, 0.09553842951676675, 0.1519207472779921, 0.22234126925468445, 0.08752855432352849, 0.16198412728096756, 0.2064437230250665, 0.16278649494051933, 0.15606278287512915, 0.15098116626696928, 0.14084845355578832, 0.16076513911996568, 0.1623557744813817, 0.1325410000447716, 2.9371414227145056, 20.48566746711731, 44.007075854710166, 65.11930928911481, 66.78805119650704, 61.256409645080566, 54.89263793400356, 41.026743343898225, 32.7028465952192, 26.717725651604788, 30.772428580692836, 51.870685713631765, 64.06871386936733, 46.328541960035054, 25.680462087903702, 11.610709956714086, 1.2708079346588679, 0.4701459492955889, 0.29948749818972176, 4.902935538973127, 10.847851599965777, 18.6025493144989, 17.480109521320887, 17.78320210320609, 22.930611746651785, 17.558028357369558, 19.615938867841447, 16.56917289325169, 27.104684727532522, 23.903031247002737, 17.882476227624075, 29.27149609157017, 26.900510174887522, 42.54314947128296, 43.67089073998587, 51.33197103227888, 56.40498283931187, 58.16597250529698, 62.32159628186907, 60.49754823957171, 58.546785899571006, 59.20005553109305, 57.926784242902485, 62.22803183964321, 60.381687028067454, 59.008980069841655, 60.80849402291434, 64.57129791804722, 61.248398372105186, 60.19389806474958, 60.54958329881941, 62.60342911311558, 62.00265312194824, 61.168667793273926, 60.786093030657085, 61.76568480900356, 58.02181822913033, 59.691522462027415, 54.87906115395682, 44.918995652879985, 38.972755091530935, 58.64511680603027, 54.98303052357265, 46.93425464630127, 52.475022656576975, 50.09855113710676, 54.053361552102224, 65.41585840497697, 61.12907695770264, 57.333088466099326, 53.0824168069022, 52.348051275525776, 53.91091653278896, 57.84575435093471, 60.65634931836809, 64.55972916739327, 59.78813716343471, 49.77302803312029, 53.12264687674386, 54.73782859529768, 52.4334203175136, 54.15677853993007, 55.63080413000924, 54.92943211964199, 57.29765960148403, 51.56417982918875, 37.79836014338902, 28.537557874407085, 32.68208537782942, 29.739182812826975, 23.457710777010234, 31.711588791438512, 24.6277266229902, 30.237292221614293, 29.359696524483816, 23.00900479725429, 26.555226394108363, 18.952186141695293, 14.812258345740181, 11.113425646509443, 10.014244079589844, 1.5749980062246323, 0.6443703461970601, 0.3018672562071255, 0.6017150293503488, 2.8196534642151425, 13.590899654797145, 24.579546076910837, 43.32893167223249, 48.526833874838694, 40.568374156951904, 33.340781552451, 29.6466258593968, 36.6115939276559, 46.40449619293213, 60.0832827431815, 63.05778571537563, 50.61330148151943, 27.360361065183366, 3.301904478243419, 0.11664763359086854, 0.11353664552526814, 0.12348756513425282, 0.12957227363118104, 0.10393483218337808, 0.09631355399531977, 0.11172102152236871, 0.11196329245077712, 0.1587844682591302, 0.1131752102768847, 0.08503865650189774, 0.1178868149540254, 0.1090276310486453, 0.12209464130657059, 0.16699624833251747, 0.10155257715710572, 0.17472663495157445, 0.18639058406863893, 0.0987850431618946, 0.18374272329466684, 0.11815878536020007, 0.16484987922012806, 0.24168554267713002, 0.12892679683864117, 0.14585533631699427, 0.1503351873585156, 0.18780739232897758, 0.10014152287372521, 0.1682674294071538], [0.05358301814911621, 0.03267052476959569, 0.08554946444928646, 0.07845394233507769, 0.034707744738885334, 0.01673656326186444, 0.05029466442231621, 0.012023559106247765, 0.037430977182728906, 0.047386741531746726, 0.052695389171796184, 0.027651820232027342, 0.014291750699547785, 0.09791203322155134, 0.023654136174757565, 0.034153686969407966, 0.028967430083347217, 0.020883343515119383, 0.011551836472270744, 0.020917137951723168, 0.043240037613681385, 0.013195615544516062, 0.06399537889020783, 0.06127376135970865, 0.06506249734333583, 0.023837532315935408, 0.019633690660287226, 2.6628093889781406, 13.74451390334538, 40.45786305836269, 47.80110495431082, 42.172699315207346, 39.015125206538606, 31.76162624359131, 24.90860755102975, 23.490179709025792, 19.84847249303545, 27.255189657211304, 46.11133779798235, 41.505779947553364, 35.12678473336356, 18.442846706935338, 2.4810857687677657, 0.442495620144265, 0.02665012951807252, 0.5855588391423225, 2.8816270530223846, 7.427920460700989, 6.108342468738556, 8.811523931367056, 14.721261262893677, 12.22072184085846, 9.231934240886144, 18.961357763835363, 17.631776537214005, 30.75460992540632, 24.64963776724679, 24.096917254584177, 29.928476061139786, 31.00702060971941, 40.72810282026018, 44.914142336164204, 54.9643919808524, 57.824875014168875, 57.95853751046317, 56.61767067228045, 58.160309723445344, 57.88091223580496, 57.40296997342791, 58.02093928200858, 57.840345178331646, 57.568941593170166, 58.13166230065482, 55.881908552987234, 55.02818686621529, 55.72015796388899, 51.57278864724295, 54.41598456246512, 52.856343269348145, 55.235837255205425, 57.628307001931326, 59.140453883579795, 58.46228190830776, 61.35616493225098, 54.61139222553798, 52.78448499952044, 39.59290613446917, 23.795898709978374, 39.281136989593506, 34.08344670704433, 36.814509119306294, 42.86802291870117, 48.662862232753206, 50.36262437275478, 59.90138585226876, 57.654348850250244, 51.561876501355854, 51.08345133917672, 49.50461564745222, 47.03766816002982, 47.807702268872944, 54.076832566942485, 53.4445777620588, 55.40199300221035, 54.869649818965364, 52.321106161390034, 53.620315074920654, 54.455926282065256, 52.43141576222011, 54.871675218854634, 57.19202961240496, 52.35742439542498, 53.444334575108115, 47.22785425186157, 41.78544841493879, 40.87670046942574, 22.797312293733867, 16.259090423583984, 13.850672824042183, 18.921268395015172, 22.790697608675274, 20.80441086632865, 19.45853958811079, 9.969899807657514, 10.257513540131704, 8.352571095739092, 6.670830411570413, 5.696221794400897, 1.9738729170390537, 0.2935340047946998, 0.07063703571579286, 0.02714874079850103, 0.17677131880606922, 4.053293747561319, 16.491396495274135, 34.508186612810405, 46.141757011413574, 46.849681173052105, 24.30525377818516, 25.520116771970475, 27.60344900403704, 35.10839979989188, 45.33710697719029, 50.26165315083095, 43.65890162331717, 22.347359112330846, 3.632333878959928, 0.007273532383676086, 0.06940681780023233, 0.08525854256004095, 0.02794158521906606, 0.05905547432069268, 0.04980887406106506, 0.02488557545335165, 0.04270474812281983, 0.034513001795858145, 0.02455035031640104, 0.03575418822999511, 0.05245524884334632, 0.03135565621778369, 0.020671089279598424, 0.039483270807457824, 0.039285868007157526, 0.030698454340121577, 0.047525342487330945, 0.014452003707577075, 0.012260403450844544, 0.010695515100711157, 0.07717360103768961, 0.04186337487772107, 0.03256530773692897, 0.03535431736548032, 0.06473795404391629, 0.013457123788871934, 0.05437710428876536, 0.031230900769254992, 0.0708662448450923, 0.07318888378462621, 0.03152636545045035, 0.014043790255008, 0.0458592234977654, 0.017967831210366318, 0.08568225375243596, 0.0038388780251677546, 0.0062508664559572935, 0.02147618804260024, 0.15084822768611567, 0.057337403297424316, 0.0507350506127945, 0.07207350113562175, 0.0667148454646979, 0.013428040081635118, 0.0628102496266365, 0.029469702060201337, 0.025792386615648866, 0.017290548088827302, 0.0689709201189024, 0.02659203334977584, 0.039532210145677836, 0.05914866432015385, 0.014652939978986979, 0.036961973777839115, 0.03475057386926242, 3.701231130531856, 17.88366958073207, 46.113144329616, 55.91333178111485, 51.0900764465332, 47.66077218736921, 40.17444256373814, 28.15959324155535, 27.394985675811768, 17.417395080838883, 25.742947237832205, 42.789560386112754, 46.57071794782366, 37.03197731290545, 17.044872624533518, 2.7032542015825, 0.47312357808862415, 0.26543695532849854, 1.7507606148719788, 5.691444039344788, 10.641661201204572, 12.017449685505458, 11.117490342685155, 15.02132443019322, 14.765078340257917, 7.17393514088222, 9.376838053975787, 8.569690142359052, 8.81261306149619, 8.841993519238063, 21.43879008293152, 25.64568635395595, 28.258558171136038, 38.079109055655344, 43.70609031404768, 56.88826131820679, 58.52247415270124, 59.75646727425711, 57.35849108014788, 58.86056654793875, 57.157330308641704, 57.310364382607595, 58.65949262891497, 60.015259878976, 57.67160817555019, 59.75090871538435, 58.466179847717285, 58.872017179216655, 57.24351576396397, 55.72570262636457, 57.75731767926897, 55.33859763826643, 55.84567369733538, 58.83779035295759, 60.772314752851216, 60.58536652156285, 59.62248516082764, 57.57614687510899, 56.57598842893328, 45.54682445526123, 28.596996239253453, 46.601988315582275, 41.1563515663147, 43.546837602342876, 51.688462257385254, 51.30065550122942, 51.31772027696882, 59.77297619410923, 57.80523245675223, 55.11632129124233, 53.48737866537911, 51.77299404144287, 50.15921238490513, 49.515475681849885, 58.054620674678254, 54.92557239532471, 57.9426018169948, 55.750650133405415, 52.145132609776084, 52.802508626665386, 52.96187250954764, 53.379223006112234, 56.05846227918352, 59.00553376334054, 55.53340080806187, 51.681329931531636, 46.50702033724104, 37.20736721583775, 30.761644976479666, 19.91010648863656, 12.328702058110919, 11.162776095526558, 12.915061405726842, 17.665133101599558, 14.924233777182442, 14.202366318021502, 14.255051902362279, 16.323250089372905, 12.349418112209865, 7.36088684626988, 6.503054431506565, 4.705749137060983, 1.614745393395424, 0.25599370204976624, 0.19048721210232802, 0.46876488626003265, 3.940656065940857, 17.453157458986553, 34.568837438310894, 46.7181031363351, 41.77315705163138, 22.806831325803483, 24.250281367983135, 31.523577485765728, 40.417167459215435, 51.9509790965489, 56.72290461403983, 50.9424272264753, 27.546067305973597, 4.712870606354304, 0.039000245476407666, 0.02633121297029512, 0.026956988498568535, 0.029753462012325014, 0.03704043956739562, 0.021298681585384265, 0.024746664067996398, 0.031241933748658215, 0.04197457319657717, 0.02711869866055037, 0.03450691194406577, 0.030132179547633444, 0.026461157515378933, 0.03435044176876545, 0.029364790368293012, 0.0358793541922101, 0.02266113749439163, 0.01673190511896142, 0.014681428271744932, 0.020240117762503878, 0.03896237982969199, 0.03384141158312559, 0.01492280014125364, 0.06179909674184663, 0.10309053105967385, 0.01287260658240744, 0.035195302683860064, 0.042836383916437626, 0.04404360967289124, 0.19302797290895665, 0.17401912648762974, 0.18750072164194925, 0.20901579143745558, 0.10365079063922167, 0.13616011584443705, 0.21440787852874824, 0.05962768968726907, 0.07822032272815704, 0.16010891433273042, 0.2203895446977445, 0.16830677086753504, 0.12941344215401582, 0.22460682982844965, 0.21003356682402746, 0.16158461943268776, 0.10116982233843633, 0.09315274788865022, 0.10518043248781137, 0.06594161409884691, 0.20393336058727332, 0.09650291276297399, 0.16657622158527374, 0.1393169050237962, 0.18174784391054086, 0.1398520791637046, 0.16039832308888435, 5.091347234589713, 21.924538646425518, 56.722981044224326, 63.4270407812936, 58.65405913761684, 53.91335882459368, 47.57666424342564, 37.98295293535505, 36.610548223767964, 30.48885522569929, 39.390536376408164, 59.653689520699636, 53.85927404676165, 45.138117517743794, 22.28494691848755, 3.2068939421858107, 0.7882950603961945, 0.26038490927645136, 2.20121146099908, 8.98640661580222, 15.508589438029698, 17.04244944027492, 21.00029100690569, 27.05425296510969, 22.75994314466204, 22.637856347220286, 31.79501233782087, 28.965262923921856, 41.19322913033621, 31.32964631489345, 29.046278919492448, 35.10685382570539, 33.34624283654349, 45.10138586589268, 47.82319327763149, 58.60130146571568, 59.627105712890625, 60.97203377314976, 59.07707241603306, 59.37960393088204, 58.79772703988211, 58.8498454775129, 60.457818440028596, 60.89659718104771, 60.05097361973354, 63.14779962812151, 61.305345807756694, 59.810142108372276, 61.62710298810686, 56.292710372379844, 60.00744315556118, 56.29732050214495, 59.72985567365374, 60.824037143162315, 62.00441796439034, 61.10349369049072, 61.74042810712542, 59.15127917698452, 58.465707370213096, 50.73195934295654, 35.79578856059483, 50.17351177760533, 42.73942565917969, 49.02177143096924, 50.50990186418806, 50.92054387501308, 53.03013161250523, 63.062753677368164, 61.13744258880615, 57.12672001974923, 55.39852237701416, 52.82976988383702, 50.9178340775626, 51.117226532527376, 59.03060286385672, 58.62781579153878, 60.211546489170615, 55.862700257982524, 52.24128178187779, 54.10086291176932, 53.19475875582014, 54.92081635338919, 58.287249837602886, 62.385957445417134, 56.829448291233604, 57.17156021935599, 52.036639962877544, 45.110908372061594, 43.001240730285645, 29.645211900983536, 24.81816806112017, 19.433713674545288, 25.851425988333567, 34.889086859566824, 31.451778275626047, 28.577473538262502, 22.069465909685405, 19.475406340190343, 17.456827844892228, 16.95528950010027, 10.75176669870104, 4.801298592771802, 1.701507874897548, 0.2575699117566858, 0.3238527136189597, 0.5540298681174005, 4.995562408651624, 19.848953655787877, 42.29783637183053, 59.36590903145926, 59.30798189980643, 34.766927106039866, 35.92164128167288, 37.81419161387852, 48.355751855032786, 57.64406551633562, 65.20389665876115, 59.72370651790074, 33.33689750943865, 6.283768849713462, 0.1467073591692107, 0.2006851320288011, 0.14622122954045022, 0.11337498455707516, 0.15385419210152967, 0.16345833960388387, 0.16922524943947792, 0.11658398700611931, 0.09106549274708543, 0.1095288512962205, 0.12064443555261407, 0.16059607533471926, 0.12831874803772994, 0.13538015341120108, 0.11638050792472703, 0.2442587103162493, 0.21407737769186497, 0.11761987927768912, 0.10119623092136212, 0.09820471930184535, 0.10793286229350738, 0.15100164445383207, 0.1498811524361372, 0.11272483944360699, 0.1620460096746683, 0.15341391786932945, 0.15499445662966796, 0.14797620608338288, 0.09477322522018637], [0.014585868488731129, 0.005678851681295782, 0.050950570298092704, 0.08335554360279016, 0.042330190007175715, 0.006053042115776667, 0.04926524876749941, 0.026499416712405424, 0.00545583588037906, 0.02834766298266394, 0.0235528834829373, 0.03488399420997926, 0.057648260545517714, 0.016361297773463384, 0.014096741431525775, 0.050759532156267335, 0.041977891232818365, 0.06313359191907303, 0.0280508564984692, 0.02349209353061659, 0.03310698902766619, 0.0581986949379955, 0.0511189521556454, 0.02422458735028548, 0.07129674138767378, 0.05369130555274231, 0.20526236641619885, 5.073750053133283, 30.469143186296733, 42.67343514306204, 44.658969742911204, 39.60960612978254, 31.61374773297991, 31.791941234043666, 25.089712347303117, 15.793420416968209, 28.139170748846873, 36.141100134168354, 31.19467408316476, 28.79697581699916, 15.452713762010847, 8.327846799577985, 0.5678758365767342, 0.10373832165662732, 0.1525283618164914, 0.6551874971815518, 4.829345864909036, 8.917658533368792, 9.730257306780134, 11.505694883210317, 8.728884662900652, 9.741372687476021, 3.083867618015834, 8.304007530212402, 10.643959317888532, 12.578822442463466, 17.352964435304912, 32.046797684260774, 35.34804664339338, 42.11234378814697, 51.729647704533164, 52.88033192498343, 57.513734681265696, 55.617022378104075, 56.08448675700596, 58.09575401033674, 57.160384041922434, 55.041979040418354, 57.01594836371285, 56.19932310921805, 55.47869764055525, 56.66972310202462, 54.284722668784006, 53.11783872331892, 51.96076563426426, 51.08035591670445, 48.010016441345215, 46.85382924761091, 47.41347885131836, 51.94002526147025, 54.73506668635777, 57.71257822854178, 59.1440669468471, 58.98338290623256, 54.065871783665244, 55.89918177468436, 47.68313149043492, 28.66522581236703, 36.5262839453561, 26.345545394080027, 43.58284664154053, 45.216958727155415, 52.65487330300467, 47.59785277502877, 55.54374667576381, 58.763291767665315, 57.201183864048545, 52.71696240561349, 53.858638286590576, 50.589465686253135, 45.36781106676374, 47.40059341703142, 54.98914841243199, 54.66700908115932, 54.3157776423863, 53.29603917258126, 52.112170355660574, 51.54468665804182, 50.99497992651803, 52.991273811885286, 54.358116490500315, 53.49137387956892, 55.79266241618565, 54.036751883370535, 48.091695989881245, 41.97033650534493, 30.58387531552996, 17.77636854989188, 15.660859210150582, 18.40956657273429, 16.977183273860387, 17.67550676209586, 11.546412195478167, 12.813112224851336, 12.176007577351161, 11.370057361466543, 6.218753252710615, 6.086027026176453, 3.251632524388177, 2.4241928330489566, 0.3857648271535124, 0.15016292088798114, 0.18744438966470106, 0.7229517581207412, 4.4163983549390515, 17.357562405722483, 29.993024826049805, 29.49193811416626, 29.01991397993905, 22.713991233280726, 21.089106355394634, 30.92498322895595, 39.6446076801845, 50.533685547964915, 45.23945699419294, 27.90109940937587, 6.412973642349243, 0.03360659096922193, 0.012547692633233964, 0.04821748552577836, 0.012371890995252346, 0.051393175298081975, 0.02695870858484081, 0.007306379415760083, 0.03861459670588374, 0.0381346722798688, 0.07247608274753604, 0.021209274418652058, 0.07239997825984444, 0.021800415823236108, 0.0511835147626698, 0.08622649990554367, 0.02170586705740009, 0.014833898483110326, 0.010930260227593993, 0.0710969806781837, 0.051461537701210806, 0.03485327692968505, 0.06915698120636599, 0.0195473793095776, 0.03825986538348453, 0.04899908662108438, 0.04631541616150311, 0.07941356048520122, 0.03717019921168685, 0.05742538893329246, 0.026139070512726903, 0.002698613072945071, 0.10403213410505227, 0.011557791465228158, 0.03464904806709715, 0.03282362601852842, 0.041217297581689696, 0.025647921421165978, 0.014862544535260116, 0.021823009343019555, 0.08480612255100693, 0.006752462442299085, 0.059588368582938395, 0.04081735886367304, 0.013171060210359948, 0.031044670048036745, 0.05913967373115676, 0.015141461443688189, 0.024786353277574693, 0.030137516225555112, 0.03632617289466517, 0.006489469054421144, 0.017906800378113985, 0.04759134019591978, 0.031670886624072275, 0.04720211215317249, 0.3004889344530446, 5.659017665045602, 34.541183607918875, 52.035424028124126, 54.58236265182495, 46.591909953526084, 37.45514692578997, 37.2350766318185, 29.483780929020472, 21.666588510785783, 31.178043569837296, 31.04221670968192, 37.77312428610665, 31.324779101780482, 20.792223726000103, 8.945427877562386, 0.7821260914206505, 0.12159294608448233, 0.20388169693095343, 2.0787831161703383, 5.236458625112261, 11.937715632574898, 10.158247232437134, 12.808595027242388, 17.36807155609131, 12.88255078451974, 8.524571146283831, 6.085889799254281, 11.573737723486763, 9.893517392022268, 16.07080466406686, 27.92606602396284, 32.25049107415335, 40.21100745882307, 47.34761340277535, 54.52764558792114, 58.21169165202549, 57.58923380715506, 57.39415965761457, 59.0288519178118, 57.235726833343506, 56.72170604978289, 58.812436376299175, 56.31344032287598, 57.47072185788836, 59.395445823669434, 55.331253392355784, 55.6538200378418, 54.76660108566284, 54.2227794783456, 51.15534087589809, 49.073698793138774, 49.93805469785418, 52.24967867987496, 57.24414457593645, 59.943874086652485, 58.86686161586216, 60.70734214782715, 55.51913963045393, 58.2940799168178, 52.84012617383684, 34.03101560047695, 38.90672288622175, 34.351525579180034, 49.148270334516255, 50.899049622671946, 54.90515858786446, 49.15215785162789, 55.81026220321655, 60.47076988220215, 57.47220877238682, 56.85026509421212, 54.831389563424246, 51.66030468259539, 46.95819813864571, 49.612941537584575, 57.383886745997835, 56.03451183864048, 56.56639296667916, 52.899887629917686, 52.501999037606375, 51.36258479527065, 50.38008519581386, 54.98282902581351, 56.63965129852295, 55.6219972882952, 56.384888648986816, 55.69827113832746, 47.49655498777117, 39.69837978907994, 29.355499812534877, 22.045954942703247, 14.592530250549316, 16.383247784205846, 9.377002205167498, 13.227232677595955, 13.789224692753383, 13.15513643196651, 14.698903696877615, 13.181884390967232, 9.394603729248047, 8.863618050302778, 7.424155405589512, 2.0413514333111897, 1.1000943865094865, 0.44511984075818745, 0.1284766567072698, 1.145593796457563, 4.696382096835545, 18.257546935762676, 32.98966128485543, 34.68744666235787, 28.02345197541373, 25.28015204838344, 27.375853810991558, 37.89969614573887, 44.34088468551636, 56.725141933986116, 50.66125099999564, 33.90667411259243, 8.053753393036978, 0.0733988835875477, 0.022526980943179557, 0.053671159848038635, 0.021525113810119883, 0.019525038544088602, 0.02913625298866204, 0.008401406014205089, 0.03017441156719412, 0.039767549838870764, 0.0035141633956560065, 0.04185310525021382, 0.018639960858438696, 0.056422487034329345, 0.030889034470809356, 0.036421306896954775, 0.002865679844814752, 0.055677007750741074, 0.012510083133487828, 0.02112071881336825, 0.057223192283085415, 0.0659725960077984, 0.06394310455237116, 0.023179277012656842, 0.024888299771451523, 0.037946836823331456, 0.06674538632588727, 0.036560776377362866, 0.056287007339830906, 0.04058336266981704, 0.10177470916616065, 0.15527634721781525, 0.17631494972322667, 0.2231740624244724, 0.10324176972998039, 0.12524469941854477, 0.13398066136453832, 0.17212454814996037, 0.14339758748454706, 0.11137756745197944, 0.17698840929993562, 0.08740802614816598, 0.13336934202483722, 0.13084281688289984, 0.14271608048251697, 0.1113694521731564, 0.2207881704505001, 0.11999560679708209, 0.12889623562140123, 0.1007525504433683, 0.1365595965513161, 0.14847578427621297, 0.15516654668109758, 0.1173670164176396, 0.23424195923975535, 0.10421119271112339, 0.46490689899240223, 8.374894789287023, 41.6724568094526, 62.20001670292446, 65.15361949375698, 56.28475815909249, 47.60085439682007, 44.690757751464844, 38.04931170599801, 23.964435952050344, 40.78235782895769, 50.27138410295759, 42.511031423296245, 38.76336417879377, 21.55385398864746, 10.713702729770116, 0.9989721498319081, 0.4138522414224488, 0.17698395811021328, 3.1002386595521654, 9.970690165247236, 20.909648282187327, 25.281373194285802, 19.691085372652324, 22.995556558881486, 19.20875358581543, 9.57136069025312, 14.771790300096784, 16.36862530027117, 19.324998685291835, 22.417362213134766, 36.58958203451974, 39.11657238006592, 45.06702354976109, 54.51259231567383, 55.11514357158116, 60.49428258623396, 58.4467248916626, 59.14146137237549, 59.900809151785715, 58.98073564256941, 55.23422179903303, 59.932812554495676, 57.68784958975655, 58.73551286969866, 61.57898671286446, 59.15799808502197, 58.35069383893694, 57.2638635635376, 56.00440876824515, 52.44865076882498, 51.572896344321116, 52.68116876057216, 55.10706629071917, 59.696108273097444, 60.386919021606445, 61.15979494367327, 60.76073905399868, 57.10345050266811, 58.76477173396519, 55.732529231480186, 39.62372139522007, 46.46021727153233, 38.67659854888916, 53.180066789899556, 52.01079266411917, 56.680617877415244, 49.18401186806815, 54.931384563446045, 62.83696501595633, 60.18028654370989, 57.77819006783621, 57.64773416519165, 54.23612696783883, 49.05235045296805, 51.83181749071394, 59.23924337114607, 58.07384634017944, 58.31568186623709, 53.793929713112966, 52.98209524154663, 53.05973788670131, 50.97158186776297, 55.46534667696272, 58.99791158948626, 58.693858419145855, 59.576501982552664, 58.18615007400513, 51.16527679988316, 46.03111042295183, 32.43648392813546, 21.873269626072474, 21.376584597996303, 26.68650392123631, 24.510911771229335, 26.638498817171367, 18.132732970373972, 21.896000657762798, 20.87343774523054, 25.144316502979823, 16.099799496786936, 15.36188691002982, 9.074942299297877, 3.0564174566950117, 1.782574679170336, 0.5725490972399712, 0.3629615721958024, 1.1718905568122864, 6.034847463880267, 20.78213667869568, 39.47680868421282, 42.416473388671875, 41.780709743499756, 33.06399311338152, 31.797423362731934, 41.73354537146432, 51.398885658809114, 63.45945412772042, 57.94265045438494, 42.525111947740825, 11.719827072960989, 0.3141060194798878, 0.050443053245544434, 0.1407375130802393, 0.10149193648248911, 0.11675832979381084, 0.08973645299140896, 0.1694012207112142, 0.1714118963905743, 0.13302794391555445, 0.2096562742122582, 0.1694238159273352, 0.09927890808986765, 0.1275314845676933, 0.1206839262906994, 0.28256858033793314, 0.12525704875588417, 0.08680579239236456, 0.13412924696292194, 0.1436415072530508, 0.19681921947215283, 0.12363923128162112, 0.13569747709802218, 0.09471290345702853, 0.08914095030299254, 0.1643096703503813, 0.1417276178087507, 0.2170341754598277, 0.1588833715234484, 0.15547480514006956], [0.06668199758444514, 0.01194925358452435, 0.03621809583689485, 0.015700598047780137, 0.034912723382668834, 0.014434468666357654, 0.01509280369750091, 0.016421946929767728, 0.03937370775799666, 0.03885385493880936, 0.02853397173540933, 0.047957525189433775, 0.033243595090295584, 0.09204187071216957, 0.037124184359397204, 0.03695106632741434, 0.05406150068821652, 0.007124087590325091, 0.08229751751891204, 0.023833432268085222, 0.045154958431209834, 0.03243016391726477, 0.02678434374476118, 0.0014203629356675915, 0.03538684633427432, 0.08622768055647612, 0.3551836609840393, 10.775274191583906, 34.91348893301827, 44.553760119846885, 50.070007937295095, 40.341793400900706, 29.960479463849747, 25.768992560250418, 38.37948662894112, 24.0664997782026, 18.173689126968384, 40.86979396002633, 33.256680556706016, 27.83189708845956, 16.96245309284755, 2.82776700598853, 0.3745618068746158, 0.04211762873455882, 0.6666222778814179, 2.112043491431645, 4.057117862360818, 9.935011165482656, 8.496711475508553, 11.43453664439065, 15.417321375438146, 11.704843282699585, 5.346445568970271, 2.8377053184168677, 11.35598291669573, 8.034941145351954, 17.515098912375315, 38.46996259689331, 40.763872146606445, 45.82510328292847, 51.4552320752825, 54.62901980536324, 57.86510508401053, 56.322750908987864, 56.99305057525635, 54.049477509089876, 55.78023556300572, 55.26080213274275, 55.64414814540318, 55.29671042306082, 57.67156301225935, 55.30919286182949, 51.02952984401158, 49.21048450469971, 48.33207239423479, 47.89426987511771, 47.308873721531455, 44.532724448612754, 49.316413266318186, 49.858706269945415, 55.09741871697562, 58.968402590070454, 59.210575103759766, 57.968285833086284, 60.29281956808907, 52.58569008963448, 56.226382868630544, 33.51169681549072, 43.42257949284145, 29.925213881901332, 46.537040029253276, 51.33945771626064, 47.743636403764995, 52.7247930254255, 50.89734731401716, 53.857272965567454, 54.24636166436331, 53.63164758682251, 56.12583548682076, 52.66809919902256, 44.61302477972848, 43.33365992137364, 47.08870962687901, 51.7358524458749, 53.493625095912385, 54.79055847440447, 52.51474550792149, 52.14706073488508, 49.42805344717843, 53.649643421173096, 55.40382385253906, 51.27975879396711, 50.26149681636265, 55.58885438101632, 53.164054666246685, 50.03163651057652, 38.57554394858224, 33.01893751961844, 24.18341190474374, 17.979236841201782, 9.807864342417036, 6.90869243655886, 12.070642488343374, 11.040428740637642, 20.543578965323313, 10.797599622181483, 4.461090036800929, 5.432176785809653, 7.97899946144649, 1.2734709403344562, 1.1517907210758753, 0.17677306942641735, 0.04279755814267056, 0.12537548025803907, 2.437710770538875, 9.94235975401742, 28.00058545385088, 35.789483070373535, 30.828854901450022, 26.15789713178362, 20.47173980304173, 26.845808744430542, 48.806196621486116, 48.88939435141427, 47.40340048926217, 39.838403361184255, 13.39310267993382, 0.8085061758756638, 0.021544345188885927, 0.059172385904405794, 0.05253817600065044, 0.05830980504729918, 0.04818202867837889, 0.034265370440802405, 0.016322846890294125, 0.016237005425084914, 0.04537186911329627, 0.04473865005586829, 0.02339307152267013, 0.020288300534178103, 0.012681215602372373, 0.020941840019077063, 0.04236038142283048, 0.08072033072156565, 0.01639427966438234, 0.03170732056189861, 0.02725302484551711, 0.029404162362750088, 0.05015778016032917, 0.030080950153725486, 0.0292381350217121, 0.041919669535543234, 0.012910388260414558, 0.04399493835600359, 0.028950137618396963, 0.060743336964930804, 0.025198003510013223, 0.0634696703138096, 0.06008564654205527, 0.037201282900891135, 0.030866317118385007, 0.07726878593010561, 0.05202921706118754, 0.02371149443622146, 0.05677485705486365, 0.04841673394132938, 0.01806768442371062, 0.08459350360291344, 0.07393053613070931, 0.020030922023579478, 0.04304480951811586, 0.029969802724995782, 0.03423630200060351, 0.016247341209756475, 0.02902068490428584, 0.014610762242227793, 0.038942285015114715, 0.015010010550862976, 0.07135273409741265, 0.03134343580209783, 0.039744764632944546, 0.008734680362977087, 0.3967407824737685, 13.14585016454969, 41.90737887791225, 51.85038307734898, 58.044458934238975, 47.60999475206648, 37.24579422814505, 35.383687428065706, 38.95430415017264, 20.538112470081874, 25.413541827883037, 42.02443517957415, 31.364644391196116, 26.27535469191415, 14.486275792121887, 3.3121745671544756, 0.23591880926064082, 0.24195831375462667, 1.9046449746404375, 4.157716052872794, 10.688783884048462, 10.364977853638784, 13.581547379493713, 11.576476182256426, 14.192566752433777, 18.189187083925518, 9.496980224336896, 8.779015047209603, 12.8864244052342, 14.442334515707833, 21.078616312571935, 34.82730695179531, 38.06409052440098, 45.332628863198416, 54.698526109967915, 57.52542502539498, 59.438580240522114, 57.547614097595215, 57.24007987976074, 55.49734313147408, 56.836542401994976, 55.12581947871617, 58.22520589828491, 56.944923877716064, 58.53145817347935, 57.39658110482352, 54.59914255142212, 53.61063276018415, 51.37333713259016, 50.66281434467861, 48.76005710874285, 46.543599128723145, 50.505858012608115, 50.0339572089059, 57.6931163242885, 60.854650906154085, 60.991613796779085, 57.05772788184029, 58.139833382197786, 55.264606271471294, 59.0722017288208, 39.0878450529916, 44.522152764456614, 36.19561570031302, 51.46953494208199, 54.36043718882969, 51.90642377308437, 52.85600280761719, 50.530176707676475, 53.25513512747628, 55.90361819948469, 57.574256965092246, 58.492263385227744, 55.06634637287685, 46.49906117575509, 46.08174889428275, 49.40616314751761, 53.24807923180716, 55.61304106031145, 56.16587448120117, 52.37336008889334, 51.41687454496111, 51.46985455921718, 54.20806666782924, 55.89301177433559, 54.129673617226736, 52.29036733082363, 57.74465111323765, 54.098785400390625, 50.196611063820974, 39.58590929848807, 31.25249351773943, 23.27796609061105, 20.52584195137024, 12.828756962503705, 8.062040856906346, 16.695586681365967, 16.691405602863856, 15.520417009081159, 15.911798613412039, 9.047200747898646, 9.215621607644216, 11.050266521317617, 5.6806643434933255, 1.6776800049202782, 0.8145470374396869, 0.20179681666195393, 0.23063736408948898, 2.8885876280920844, 11.275478482246399, 26.823062079293386, 33.02741084780012, 36.42068869726998, 30.04357644489833, 21.481210572378977, 31.241185324532644, 51.46695368630545, 53.68935237612043, 54.22266135896955, 46.49445104598999, 15.764001744134085, 1.0942445461239134, 0.05946739257446357, 0.044711403482194455, 0.004888926657648491, 0.037995063699781895, 0.05080309410446456, 0.03525187893371497, 0.06633530690201692, 0.02788565188114132, 0.03782379806839994, 0.026712805797745074, 0.03206777871985521, 0.03469251502039177, 0.013983627099410763, 0.05268307715388281, 0.04104147219498243, 0.05434851082307952, 0.045290872388120205, 0.023382001223840883, 0.06487233790435962, 0.059370728475706916, 0.009426728406521891, 0.004380157283906425, 0.020662534649350812, 0.020474848470517566, 0.025102855937023247, 0.050416023803076575, 0.005852613897461976, 0.045861455877976756, 0.19788272811898164, 0.1832232368843896, 0.14643940569034644, 0.11628744006156921, 0.12671599404088088, 0.13503264848675045, 0.2079485101359231, 0.12236676099044935, 0.19272214360535145, 0.18898546482835496, 0.15060795843601227, 0.12517498673072883, 0.15342117819402898, 0.20320489896195276, 0.11694039431001459, 0.10317345482430287, 0.12404521235397883, 0.16796895542315074, 0.08322241503213133, 0.059527273289859295, 0.12629085113959654, 0.12597389386168548, 0.13548878686768667, 0.11844314581581525, 0.09802059203918491, 0.21795573458075523, 0.7520180270075798, 16.867360046931676, 50.26252862385341, 62.43819400242397, 67.61020374298096, 53.33786385399954, 42.30778966631208, 37.73658718381609, 51.05463368552071, 34.29078790119716, 26.859220504760742, 53.95017385482788, 45.16622298104422, 36.17154714039394, 19.961814982550486, 3.8872005343437195, 0.6679497637919017, 0.2976517624088696, 2.447221551622663, 5.962503254413605, 15.852573905672346, 20.851372003555298, 16.558710643223353, 26.580380610057286, 31.344914981297084, 20.549233061926707, 12.481708339282445, 9.339329072407313, 14.110984478678022, 13.048979248319354, 20.03073069027492, 41.98561559404646, 45.09069258826119, 48.93974447250366, 54.43224334716797, 57.906478132520405, 60.54947212764195, 58.01066289629255, 58.60109996795654, 56.61982808794294, 57.098565919058665, 57.50102990014212, 59.36249051775251, 60.638874598911826, 61.03571401323591, 60.40308747972761, 55.581263474055696, 55.67939635685512, 53.825425897325786, 52.57749816349575, 51.10157224110195, 49.37076554979597, 53.04485831941877, 54.14252431052071, 60.58235795157296, 62.79055799756731, 60.53474889482771, 58.11479207447597, 60.64472498212542, 55.265620708465576, 59.41017600468227, 46.67439201899937, 48.312412466321675, 41.70761469432286, 54.94558320726667, 54.95737777437483, 52.88003315244402, 51.93892397199358, 51.0525665964399, 53.36884934561593, 55.73602417537144, 57.18941361563546, 59.83286271776472, 56.91363613946097, 48.6418057169233, 47.44425937107631, 50.80075693130493, 56.215623583112446, 57.06690297807966, 58.10148280007498, 54.52846547535488, 52.5729992049081, 51.720962456294465, 55.68005643572126, 58.82097571236746, 55.797460147312705, 54.693380968911306, 60.204619135175435, 57.95470210484096, 54.311622619628906, 41.69853687286377, 36.005148206438335, 29.116471358707972, 21.163361753736222, 16.17865286554609, 13.882884672709874, 22.59069197518485, 20.459062814712524, 35.456111976078574, 17.88807647568839, 12.73592642375401, 14.653217554092407, 19.839881045477732, 6.3008622867720465, 2.843350512640817, 0.927852886063712, 0.21935347600706986, 0.41403425165585106, 3.0620183561529433, 13.368100455829076, 34.027555397578645, 48.484474182128906, 43.02009119306292, 37.18939570018223, 30.03781291416713, 38.01249667576381, 59.85277625492641, 61.32605838775635, 61.365364347185405, 53.37119436264038, 20.76108363696507, 1.6019719988107681, 0.13561761352632726, 0.07810497856033699, 0.06275159705962453, 0.12116294487246446, 0.20272741386932985, 0.1558952254376241, 0.21382475910442217, 0.10403594068650689, 0.1486275318477835, 0.13839616014489106, 0.11103815745030131, 0.08993966744414397, 0.12064121929662568, 0.15757660807243415, 0.11987070207084928, 0.2059358259929078, 0.17890148450221333, 0.09920177901429789, 0.18552689041410172, 0.07284505651997668, 0.07819019577332906, 0.08117604162544012, 0.07087307769273009, 0.13193352121327603, 0.07005068646477801, 0.1170939060726336, 0.07759256248495408, 0.07457268810165779], [0.03298871358856559, 0.014615880092605948, 0.046081657454903634, 0.0391109247159745, 0.04052437762064593, 0.027307275416595594, 0.017335126143214957, 0.05437759622665388, 0.04172929296536105, 0.029232062133295194, 0.04354765824973583, 0.043765627446451356, 0.08769039849617652, 0.025708502723968456, 0.006219976149233324, 0.05880848078855446, 0.043302608720426045, 0.028481073145355498, 0.04764479518468891, 0.06031955113368375, 0.09895806280629975, 0.03230720997921058, 0.031780887328620465, 0.033544040218527825, 0.015489219122433236, 0.012424105113106114, 1.5735895846571242, 12.617992912020002, 33.815569332667756, 52.32905142647879, 48.388710635049, 41.422283445085796, 27.868752070835658, 30.80930267061506, 74.9142404283796, 69.84879520961216, 28.799227033342632, 34.43777009419033, 30.842817306518555, 20.782683849334717, 6.29222480739866, 0.8176222124270031, 0.03435195490185704, 0.2877052532775061, 1.4683070055076053, 3.419083459036691, 4.364546120166779, 6.609811765807016, 9.489369341305324, 7.293779407228742, 14.8550557749612, 19.768021038600377, 15.736587626593453, 7.0629658954484125, 19.395439522606985, 23.089857510157994, 33.37255219050816, 39.848985467638286, 44.993883337293354, 51.54264388765608, 59.44884967803955, 58.242204666137695, 54.43426527295794, 55.57917554037911, 53.91928563799177, 55.65918057305472, 51.78886720112392, 54.254348618643625, 56.96740130015782, 54.996847016470774, 53.80225712912423, 51.0518022945949, 48.64960854394095, 45.28804922103882, 43.830282415662495, 44.9011526788984, 43.99887350627354, 43.46469252450125, 48.094113962990896, 50.13891669682094, 54.83297722680228, 57.46973173958914, 60.894123622349326, 53.99016768591744, 57.99093001229422, 52.212887968335835, 58.52521869114467, 33.00722633089338, 34.61299671445574, 38.70295306614467, 47.26218530109951, 54.3672707421439, 49.978732926504954, 56.545346873147146, 51.41152095794678, 53.20996488843645, 51.03893423080444, 56.43614550999233, 56.63713952473232, 56.201421465192524, 47.32108518055507, 43.98944827488491, 45.90067189080374, 50.39522532054356, 50.930733408246724, 54.69732754571097, 52.45825317927769, 51.38449246542794, 50.08082628250122, 51.771479334150044, 53.52171318871634, 56.45252241407122, 51.79911926814488, 51.13374934877668, 50.9856276512146, 56.37903479167393, 49.555796078273225, 40.90280832563128, 31.719391618456157, 40.01854235785348, 18.068760905947002, 9.774593761989049, 14.451520034245082, 13.904655984469823, 10.933264936719622, 11.401733330317906, 10.403847813606262, 8.713781016213552, 7.630547302109854, 2.416943039212908, 1.4541927171604974, 0.8015775733760425, 0.25856722252709524, 0.1538206860423088, 0.19100999619279588, 3.0691571959427426, 16.430624076298304, 39.048500878470286, 35.00667469842093, 25.658910512924194, 20.41074504171099, 30.09681006840297, 38.1847494670323, 43.71105827604021, 51.162744181496755, 42.109369959150044, 19.126811742782593, 1.2367116042545863, 0.08009991222726447, 0.005405670514197222, 0.04792287919138159, 0.048637156042137315, 0.021481563736285483, 0.024088147528735653, 0.09953681925045592, 0.0027601354190015365, 0.02366322515133236, 0.025189593068457077, 0.0271320641040802, 0.051796788283224614, 0.020438260165974498, 0.016024895378255417, 0.03694146166422537, 0.004764937529606479, 0.019433653447777033, 0.09468293935060501, 0.07038495995636497, 0.05453177634626627, 0.019492886162229946, 0.007101260400044599, 0.04370878656793918, 0.021830583490165215, 0.04797916706385357, 0.07572103398186819, 0.027202409525801028, 0.09774190413632564, 0.0598588122853211, 0.05749006010591984, 0.042956538897539885, 0.043710024894348214, 0.028555142027991157, 0.06174828125430005, 0.05159554497471877, 0.024012375523203185, 0.008280966896563768, 0.027053672953375747, 0.018563657899254134, 0.036698440954621346, 0.025834499891581278, 0.022282564147774662, 0.04748141073754855, 0.07723437063395977, 0.03406085320083158, 0.03266580555854099, 0.025622544211468527, 0.05027337877878121, 0.09572999352323157, 0.026893655736265436, 0.03652128563927753, 0.05473432583468301, 0.0253383822273463, 0.04776251422507422, 2.057293640715735, 15.407460144587926, 40.77671936580113, 58.77591664450509, 57.6295542035784, 45.212199211120605, 31.509392738342285, 32.70936747959682, 74.7406118937901, 54.197262219020296, 23.675279719488962, 38.28832973752703, 31.943088872092112, 18.505328382764542, 7.00852849653789, 0.9612084733588355, 0.050324618350714445, 0.5341652940426553, 2.39228019118309, 7.265113311154502, 9.839548996516637, 12.020800454275948, 16.299480301993235, 15.25526680265154, 11.142568128449575, 13.215817655835833, 16.862032515662058, 14.243071470941816, 18.55342207636152, 21.009203808648245, 32.53007616315569, 37.871597630637034, 43.78335428237915, 52.2146806035723, 58.36046300615583, 59.086396898542134, 55.063219683510916, 57.046815735953196, 55.61713702338082, 55.03376626968384, 52.82634789603097, 56.801874365125386, 58.20214482716152, 57.48220375605992, 57.048073359898154, 55.538292339869905, 49.68318435123989, 47.70402124949864, 46.967539991651265, 46.44372572217669, 45.45532362801688, 46.70866053444998, 49.71821369443621, 50.59283556256975, 56.40986047472273, 60.9009884425572, 61.941376958574565, 55.438933100019185, 57.3468702180045, 52.800097601754324, 60.63412203107561, 39.746416160038535, 36.311626298086985, 41.50047847202846, 51.43628086362566, 54.63774674279349, 51.60855449948992, 55.52618857792446, 50.46304668698992, 53.38289860316685, 50.1625405720302, 57.05107150759016, 59.11887277875628, 57.53956113542829, 49.51872396469116, 45.77914789744786, 48.298880849565776, 52.47183690752302, 53.59309203284127, 56.85970074789864, 53.40971517562866, 50.66454097202846, 51.18606233596802, 51.615144865853445, 54.33349902289254, 56.73713799885341, 53.22478539603097, 53.55613456453596, 54.701930727277485, 55.32612214769636, 49.99298020771572, 41.44007430757795, 29.70313903263637, 29.061028208051408, 20.470562083380564, 13.131526453154427, 14.840558358601161, 11.176476206098284, 9.91438717501504, 15.507500307900564, 15.878393411636353, 16.48151441982814, 10.943869624819074, 9.081953031676155, 5.200197279453278, 1.6523065950189317, 0.2507021059947354, 0.3780182371182101, 0.2929995906140123, 3.5580118213381087, 17.481224707194738, 40.00345434461321, 35.50725071770804, 30.670592308044434, 23.30305256162371, 32.65853793280465, 45.05506222588675, 48.82693352018084, 55.59075471333095, 48.4999999318804, 22.417249304907664, 1.6934833569186074, 0.1515039232160364, 0.01591553249662476, 0.015730585902929306, 0.05504866736009717, 0.026526464814586297, 0.08883472066372633, 0.10154161881655455, 0.06275585825954165, 0.04936093916850431, 0.06266579630651645, 0.04793413269466587, 0.054341399776084084, 0.0757446266444666, 0.025774234107562473, 0.030808224342763424, 0.02915880749268191, 0.04324954388929265, 0.04306133184581995, 0.01961861191583531, 0.04344414773264101, 0.039270974163498194, 0.04410650986911995, 0.054857968485781124, 0.04059002588370016, 0.04663060585569058, 0.029125691591096774, 0.05754220552210297, 0.020803493514124836, 0.1551252103277615, 0.1038511823862791, 0.15530472355229513, 0.12914354806499823, 0.11989861700151648, 0.21208020485937595, 0.22853195135082516, 0.11101746213223253, 0.14154464405562195, 0.14208994193800858, 0.188023356454713, 0.11391064045684678, 0.1953257503254073, 0.07206516872559275, 0.13978262431919575, 0.13251125306955405, 0.07907925985221352, 0.15322476944753102, 0.08628209906497172, 0.11866010060267788, 0.26559912519795553, 0.09491472691297531, 0.18657346282686504, 0.17796514688857965, 0.09826486464589834, 0.11387220823339053, 2.6300408158983504, 20.143614598682948, 47.42196260179792, 69.26011603219169, 66.13099479675293, 55.25698062351772, 38.267721380506245, 44.25949348722185, 82.92675713130406, 79.10791601453508, 40.932553563799175, 45.04378877367292, 41.105893748147146, 25.69309217589242, 8.064629060881478, 1.5159996577671595, 0.11045716862593379, 0.8048209707651819, 4.807279688971383, 11.690361499786377, 14.86928915977478, 16.938080549240112, 21.212495940072195, 14.171340005738394, 25.163425786154612, 33.57976484298706, 28.164166893277848, 10.352720362799507, 23.76804859297616, 26.845803533281597, 39.06057684762137, 43.09273113523211, 47.39637238638741, 52.01406526565552, 62.325091225760325, 61.470824105399, 57.25385120936802, 57.044508934020996, 55.30054930278233, 55.79603576660156, 52.469276496342246, 57.31248010907854, 61.78773839133126, 58.6372583934239, 58.11256865092686, 57.015472412109375, 53.05740329197475, 50.48786565235683, 47.97804083142962, 49.72675650460379, 47.687244824000764, 48.58842618124825, 52.168391704559326, 54.615293639046804, 57.76786157063076, 62.100129399980815, 62.89745603288923, 55.25876631055559, 58.664808000837056, 54.511577878679546, 58.881828035627095, 44.51818881716047, 42.9467043195452, 46.965584073747905, 51.41963297980172, 54.13204642704555, 51.56313065120152, 55.00886392593384, 52.8317084312439, 52.713147844587056, 50.68883882250105, 58.546417645045686, 61.59326526096889, 60.38962881905692, 52.76249047688076, 47.119500568934846, 50.78044387272426, 53.61202934810093, 55.32741798673357, 59.38797651018415, 55.65884358542306, 52.15429728371756, 50.14975241252354, 53.231876032693044, 54.713746138981406, 60.324670110430034, 57.02094759259905, 55.07352038792202, 55.38528258459908, 59.655127797807964, 54.48338903699602, 44.497455392565044, 34.881815569741384, 42.76763187135969, 22.667667593274796, 17.28169502530779, 24.388583523886545, 21.956185953957693, 18.229471002306255, 19.513680492128643, 21.760364873068674, 15.841611385345459, 16.372907127652848, 12.01700326374599, 4.886582953589303, 2.102793267795018, 0.5695992069584983, 0.6766856036015919, 0.530146521117006, 4.1623900192124506, 20.81839759009225, 48.49927731922695, 45.731219223567415, 36.242175579071045, 30.880684988839285, 40.02422251020159, 49.80704641342163, 55.99362863813128, 64.25655147007534, 57.87717757906233, 28.611544030053274, 3.1143196182591573, 0.2768982803182942, 0.1239809143756117, 0.15573921666613647, 0.20331630084131444, 0.11456652597657271, 0.15608075048242295, 0.12964365551514284, 0.18575153978807585, 0.07948047760874033, 0.13550258826996597, 0.08718985678361994, 0.13167327589222363, 0.16467427435730184, 0.0508589002170733, 0.0798714223450848, 0.07315256180507795, 0.15781277897102491, 0.20646061854703085, 0.16843006068042346, 0.14125736589942658, 0.09069166066391127, 0.12204764597117901, 0.1218057753784316, 0.09003186678247792, 0.18156325524406774, 0.22399228066205978, 0.11903016003114836, 0.21096030995249748], [0.05171876014875514, 0.05249801351289664, 0.06254826047058616, 0.0774217141526086, 0.03999141550489834, 0.009740774769202938, 0.019736361490296464, 0.04312847288591521, 0.022918655104669075, 0.06702684265162263, 0.0478705098586423, 0.023050587757357528, 0.005922384684838886, 0.014431858002873403, 0.05064793689442532, 0.05773043113627604, 0.04349723291982498, 0.01965312220688377, 0.03670095831954053, 0.022315910751266137, 0.05466753424012235, 0.051483664728168926, 0.022198530978390148, 0.005654171242245606, 0.0591398026528103, 0.03357778037233012, 2.6014303054128374, 17.05256254332406, 39.0262006350926, 56.25642340523856, 56.94147409711565, 46.48484516143799, 39.453959533146445, 24.623686245509557, 25.65658286639622, 28.513039418629237, 35.512263842991416, 33.754838602883474, 24.27972435951233, 12.480497615677969, 3.2175620325974057, 0.45297665202191895, 0.27480570546218325, 0.6597705941115106, 1.5934655581201826, 4.6803443517003736, 11.807475992611476, 6.024274042674473, 14.293373823165894, 11.752150961330958, 5.346256230558668, 14.2376457963671, 13.28103518486023, 26.180734123502457, 26.439723014831543, 31.612858363560267, 37.01853949683053, 45.458922794886995, 50.6479035105024, 55.26196943010603, 53.32618045806885, 54.868475573403494, 54.05646392277309, 54.64491728373936, 53.60430295126778, 53.28904233660017, 53.23235545839582, 53.92143957955496, 55.3779730796814, 52.36987556729998, 49.77059268951416, 48.64992468697684, 46.70028795514788, 43.53241661616734, 42.922083377838135, 44.477604389190674, 45.472944259643555, 46.519263063158306, 48.24994816098894, 54.16919149671282, 56.80499758039202, 60.04412964412144, 58.42025225503104, 58.271918637411936, 57.89478778839111, 53.66166727883475, 57.45409829275948, 42.68971129826137, 18.069751024246216, 50.970341614314485, 53.72846378598894, 50.81980889184134, 56.17342717306954, 54.68499449321202, 53.83782843181065, 53.50117083958217, 54.67998831612723, 52.57136985233852, 56.175445624760215, 55.01210526057652, 52.35506200790405, 43.03306000573294, 42.50550413131714, 46.21507092884609, 51.716314111437114, 52.99428933007376, 54.87665360314505, 52.055111748831614, 50.90036283220564, 52.01710162843977, 52.49343538284302, 53.233873639787944, 50.984637532915386, 49.06410333088466, 52.15464121954781, 51.8685039792742, 53.723912715911865, 49.63593660082136, 40.073047501700266, 36.14853123256138, 27.560106141226633, 16.031147820608957, 17.598769119807653, 15.03597296987261, 7.806844813483102, 16.768481969833374, 9.789943201201302, 14.131453003202166, 9.67694638456617, 7.767413786479405, 3.9984468391963413, 1.190275815980775, 0.26126784618411747, 0.1303830144128629, 0.4729123094252178, 1.468430227466992, 8.16341507434845, 21.235777616500854, 43.17165572302682, 30.53336191177368, 25.1744612625667, 24.376801116125925, 23.47867522920881, 40.91358150754656, 45.99240895680019, 48.85450744628906, 26.9292322908129, 8.575472780636378, 0.34684080151574953, 0.053319773703281365, 0.04979763412848115, 0.02754416216963104, 0.06441997217812709, 0.011515355885161884, 0.02940311741882137, 0.050856644088136296, 0.14175398567957537, 0.008563787925855389, 0.020428670769823448, 0.020813038805499673, 0.09646517264523677, 0.01782550340119217, 0.056532603089830706, 0.04133706919050642, 0.01763379350969834, 0.021962071702416455, 0.02525056792157037, 0.09571681637316942, 0.01814190936940057, 0.08858621399849653, 0.07688952556678227, 0.03066056494468025, 0.048395960591733456, 0.018593036769224063, 0.04978135607338377, 0.04894786401252661, 0.06383422003792864, 0.01920610503293574, 0.021698304784617255, 0.04084190486797264, 0.02778722019866109, 0.05193899225975786, 0.046203987140740664, 0.03361826177154269, 0.0623559636463012, 0.03296112435470734, 0.04506789899564215, 0.04893418813922575, 0.030639815343809978, 0.02109266139034714, 0.041154831647872925, 0.1015726617936577, 0.04810161888599396, 0.03471790919346469, 0.06310607732406684, 0.02027749316766858, 0.04091609588691166, 0.022675086478037492, 0.09015003365597554, 0.01888688314439995, 0.03595950614128794, 0.14983398068164075, 2.9956430835383276, 20.269918952669414, 45.770143032073975, 62.898366246904644, 62.4397087097168, 52.348141602107454, 42.04210444859096, 27.99603090967451, 40.97727564402989, 38.354483536311555, 28.381511756352015, 33.08270461218697, 22.309397629329137, 12.17564366544996, 2.7497608831950595, 0.7788318853293146, 0.2934366485902241, 1.3687578844172614, 5.308326882975442, 9.088680624961853, 8.98389310496194, 12.599706990378243, 15.021136828831263, 11.457350185939244, 10.86497630391802, 17.986066920416697, 13.578889693532672, 16.61605760029384, 19.72032686642238, 27.641266311917985, 33.631289209638325, 43.4414438520159, 52.40357780456543, 54.29645470210484, 55.43124491827828, 56.238371985299246, 53.76770373753139, 54.52090930938721, 54.36907727377755, 55.3576773915972, 54.5870144707816, 56.30030822753906, 57.512911319732666, 55.692028181893484, 52.27220821380615, 51.926799365452354, 48.811119420187815, 46.718481813158306, 45.27152987888881, 46.5758352960859, 47.48535796574184, 47.962594985961914, 50.84354393822806, 55.414586612156455, 58.07476697649275, 62.06451988220215, 59.40850148882185, 57.18210411071777, 56.976041385105674, 54.21963889258248, 56.126235008239746, 45.82468639101301, 23.18657990864345, 52.31500564302717, 52.00449759619576, 50.59846012932913, 55.70124844142369, 56.61529438836234, 54.30833612169538, 55.579283237457275, 53.988354206085205, 53.3159943989345, 56.99521146501814, 57.494112968444824, 53.34330776759556, 46.03992421286446, 43.13498660496303, 46.766080447605674, 53.58271142414638, 54.551040172576904, 56.69067539487566, 51.74850164140974, 51.124754905700684, 50.84382881437029, 52.57566383906773, 55.883082798549104, 52.764373438698904, 50.7024746622358, 53.8890505518232, 55.07280124936785, 55.8701730455671, 48.58484091077532, 39.6844938141959, 37.361221177237375, 28.70619933945792, 17.97754842894418, 12.444038680621556, 15.182401044028145, 11.205613476889473, 15.085289546421595, 16.344395194734844, 14.2054990870612, 10.457401054246084, 9.049527525901794, 5.493752590247563, 2.9255826600960324, 1.0535203942230769, 0.12354180722364358, 0.34495596694094793, 1.3926627274070467, 8.88482221535274, 25.626243557248795, 43.298206738063264, 31.19476440974644, 25.400102274758474, 29.295853001730784, 30.52921036311558, 45.043729713984895, 51.6117194039481, 55.197601318359375, 32.78330326080322, 10.160124114581517, 0.3761599196919373, 0.04902256732540471, 0.04281934590211936, 0.03401058054129992, 0.06301249377429485, 0.019780269491353204, 0.033084285245942216, 0.03135983260082347, 0.07143908446388585, 0.0130882738490722, 0.01872568018734455, 0.011726664412500603, 0.042299842528466663, 0.04809213296643325, 0.050448854719953876, 0.01799229409412614, 0.01375184377788433, 0.0915059433983905, 0.02879041386768222, 0.007146888911457998, 0.03174858566905771, 0.05165179892043982, 0.0945970911000456, 0.050278559393648586, 0.023996019436578666, 0.032816406405930004, 0.0033210427874499665, 0.02544544487526374, 0.17176541313529015, 0.10576176057968821, 0.0773162358839597, 0.14467157769416059, 0.14686563424766064, 0.12715413767312253, 0.07737680191972426, 0.14229709867920193, 0.25081295147538185, 0.14175535632031305, 0.1848663772855486, 0.15559969629560197, 0.1653686056711844, 0.11779777758887836, 0.1554996259510517, 0.2370390977178301, 0.14958387267376694, 0.10350940429738589, 0.17795450745948724, 0.2595595664211682, 0.13828173199934618, 0.1368703655898571, 0.17072182627660887, 0.10506681858428887, 0.10410818430994238, 0.17582337824361666, 4.5002409645489285, 25.452780042375835, 54.48273590632847, 69.07553018842424, 70.49877834320068, 60.611331939697266, 51.99052824292864, 34.621952942439485, 35.20904098238264, 37.329287256513325, 47.806048597608296, 44.028736863817485, 31.611486094338552, 15.534530537469045, 4.0928203122956415, 0.8538816581879343, 1.1116101571491785, 2.4798233679362705, 6.536744509424482, 10.83128535747528, 20.694674491882324, 22.385251113346644, 26.69661181313651, 22.271031413759502, 14.187813316072736, 23.37040318761553, 16.306881870542252, 29.71343626294817, 30.24509504863194, 37.09993764332363, 42.30867903573172, 47.16789129802159, 52.91862692151751, 56.70107684816633, 55.3563676561628, 56.91904878616333, 55.40129818235125, 55.230942249298096, 54.51470456804548, 55.6270694732666, 56.138932841164724, 58.2196820804051, 60.13382393973214, 56.32649598802839, 53.750076157706125, 54.149413449423655, 52.15598917007446, 48.129178047180176, 46.38080630983625, 49.26548991884504, 51.36986303329468, 50.07208544867379, 53.34747668675014, 59.054053034101216, 60.48929377964565, 62.45793383462088, 60.84901591709682, 58.47238458905901, 59.471327100481304, 53.781151975904194, 56.5847292627607, 47.562691416059224, 36.47858108792986, 55.38955920083182, 51.19071762902396, 52.41470187050955, 57.7658257484436, 59.14402525765555, 55.68234586715698, 57.34066547666277, 55.75608362470354, 53.9957331929888, 58.75101430075509, 60.266916683741975, 55.11017213548933, 48.842924799237935, 46.6000462940761, 50.815924848829, 56.61706617900303, 57.056949683598106, 59.121589524405344, 53.52219956261771, 51.01869412830898, 53.233300413404194, 52.45974704197475, 57.307192529950825, 54.80341958999634, 53.42338228225708, 55.93795272282192, 56.62589733941214, 58.37055179050991, 53.61252267020089, 42.63743652616228, 38.09493705204555, 32.481921672821045, 21.46973041125706, 24.997853687831334, 26.855631760188512, 19.141406433922903, 34.99865995134626, 18.73115873336792, 22.60542389324733, 22.15250383104597, 18.00425556727818, 9.252345442771912, 3.4011479871613637, 1.299971369760377, 0.3662082536944321, 0.6348306866628783, 2.15447918006352, 10.092525090490069, 28.10090354510716, 54.266636507851736, 42.56677334649222, 37.57359286717006, 33.828416551862446, 36.1476731300354, 52.75276299885341, 58.71118722643171, 63.37409550803048, 42.90659236907959, 12.571742228099279, 0.7487817949482373, 0.13811471738985606, 0.17703999153205327, 0.10492370197815554, 0.11822328689907279, 0.169357441631811, 0.10392761935612985, 0.12870324669139727, 0.17549461445638112, 0.1009737460740975, 0.08878576436213084, 0.09025298777435507, 0.14486592369420187, 0.09550847219569342, 0.1172727814742497, 0.15390223238084996, 0.14323062715785845, 0.14144096390477248, 0.08823718237025396, 0.15307589886443956, 0.086245505671416, 0.13892727664538793, 0.2054683289357594, 0.07533122239900486, 0.15308344417384692, 0.12576027746711457, 0.11023469056401934, 0.1549966008003269], [0.031044877001217434, 0.013531952630728483, 0.018962717914421643, 0.057470036537519524, 0.035896799327539544, 0.0094702114750232, 0.04363215621560812, 0.0218326241842338, 0.032610830651330094, 0.0283150491969926, 0.021508835755022507, 0.015672645797686915, 0.053014415981514115, 0.04218508529343775, 0.03714387883831348, 0.04574214567297271, 0.03328506715063538, 0.10922876239887305, 0.03231532186535852, 0.022867354464584162, 0.06523752545139619, 0.024354475916230252, 0.041964174647416384, 0.04407687824485557, 0.05636308468612177, 0.10629656831068651, 3.0951323849814276, 20.019815070288523, 46.493023191179546, 52.57348905290876, 45.94065877369472, 37.29428570611136, 26.892754248210363, 20.248622723988124, 14.071100950241089, 15.361985921859741, 24.571043218885148, 30.23658003125872, 21.820866312299454, 4.505043472562518, 0.629234672657081, 0.08283550079379763, 0.38776615262031555, 1.1916436340127672, 4.1675125786236356, 8.708232879638672, 5.517297863960266, 12.354003054755074, 14.07001529421125, 18.066400255475724, 9.084823506219045, 14.586153541292463, 25.830836738858903, 29.5140438079834, 25.969413348606654, 25.529201541628154, 42.19278655733381, 48.26912171500069, 53.55962603432791, 55.43773453576224, 56.08681092943464, 53.38273532049996, 53.10140970775059, 52.84115103312901, 53.56175913129534, 55.30719872883388, 56.255648681095664, 50.74507754189627, 51.47115734645298, 51.43558604376656, 49.13613530567714, 45.53517232622419, 43.74919693810599, 41.964819635663716, 42.229712758745464, 43.384704862322124, 47.787653241838726, 47.40479360307966, 52.30673033850533, 52.402768339429585, 57.63479661941528, 55.66730301720755, 55.33488382611956, 52.68768964494978, 47.46775470461164, 52.49446371623448, 53.91312953404018, 48.35334777832031, 18.458040680204117, 46.63108389718192, 48.42254836218697, 52.86554615838187, 56.35397958755493, 54.89591400963919, 52.331524985177175, 51.128777912684846, 53.912823813302175, 56.3467777797154, 53.539521421704976, 54.60606295721871, 51.42196757452828, 43.93039900915963, 40.49968773978097, 41.896070684705464, 47.6960586139134, 51.31794956752232, 51.76747369766235, 53.58398641858782, 51.135792119162424, 50.46962663105556, 52.585523332868306, 52.81843389783587, 54.13885218756539, 51.720225947243826, 50.628698689596995, 51.54986654009138, 55.570997510637554, 52.82089008603777, 48.20995085580008, 41.39950030190604, 39.55117525373186, 30.303112506866455, 18.50230939047677, 8.703046917915344, 8.747541444642202, 14.504948207310267, 23.367149693625315, 22.410943814686366, 4.829778824533735, 8.55572165761675, 7.419713769640241, 2.2063442255769457, 0.33080742614609854, 0.20570127000766142, 0.07248972130141088, 0.5915109483259064, 3.5673905866486684, 18.661612476621354, 34.02642631530762, 40.1019172668457, 28.214336361203873, 23.032111031668528, 23.188028608049663, 29.823589529309952, 35.19305317742484, 43.244389465876985, 35.65447609765189, 13.008994971002851, 1.059544590967042, 0.021783868050468818, 0.040396222711673806, 0.06199101358652115, 0.03644884524068662, 0.06645918704037156, 0.046332623809576035, 0.042822236461298804, 0.05019960166620357, 0.013769030221737921, 0.032274301030806134, 0.05840203831238406, 0.021242173189031224, 0.02655411002758358, 0.00608326364142288, 0.037235199473798275, 0.038577022829226086, 0.019417843581842523, 0.019802323575796824, 0.015914940474820987, 0.055437345789479356, 0.041384017028446705, 0.029235268211258308, 0.059704710197235854, 0.017943293687754443, 0.011060079243699355, 0.02554704531628106, 0.046159186866134405, 0.032069661654531956, 0.030111898135926043, 0.025842949348901, 0.016137386306322048, 0.030929906027657644, 0.034755544138274024, 0.025137415421860557, 0.026211451539503675, 0.0323198035891567, 0.030936267293457474, 0.02139961197307067, 0.03169887280091643, 0.04034286271780729, 0.0017193024583061092, 0.036233332340738604, 0.021803018005032624, 0.0473355460645897, 0.026775517700506107, 0.026114395586773753, 0.03460838346342955, 0.06398414235029902, 0.039717507881245444, 0.06676849722862244, 0.02261851022818259, 0.03638924611732364, 0.12352934932070118, 4.059798564229693, 24.004633017948695, 53.32765347617013, 60.12216486249651, 53.62597438267299, 43.37730155672346, 33.39538049697876, 21.341635159083776, 15.239914757864815, 21.719268015452794, 29.543431213923864, 28.02894105230059, 20.74990224838257, 4.899735024997166, 0.9629506255899156, 0.10417841946972267, 1.1336512544325419, 1.9526118636131287, 6.954105428286961, 9.552927119391304, 12.102975930486407, 13.172530378614153, 13.195016486304146, 9.729981984410967, 8.261087638991219, 10.93307386125837, 15.385361398969378, 22.054280621664866, 25.27441109929766, 31.449818883623394, 41.4325772012983, 50.157235622406006, 53.35268088749477, 56.31485080718994, 54.905314922332764, 54.746176855904714, 53.081270354134695, 53.89418874468122, 54.886759757995605, 56.55377503803798, 57.37509727478027, 52.764991828373496, 54.04737220491682, 53.325218132564, 51.36016682216099, 47.586068630218506, 45.4244110924857, 43.13302721296038, 43.46848276683262, 46.038923672267366, 49.26915161950247, 50.03209161758423, 53.85482372556414, 55.51894508089338, 58.48827511923653, 56.52602045876639, 56.262381485530305, 56.36180673326765, 49.62186649867466, 51.82951763698033, 54.12058537346976, 49.681416034698486, 23.040203945977346, 49.79710006713867, 48.81291900362287, 51.83729267120361, 56.74678904669625, 56.802617822374614, 53.63485765457153, 54.2793412889753, 54.631792136601035, 55.839222294943674, 52.992114543914795, 56.80621004104614, 52.44296366827828, 47.13211154937744, 41.65398849759783, 43.683824811662944, 49.25424425942557, 53.364541462489534, 54.620911257607595, 54.80873843601772, 49.81918491636004, 51.6148738861084, 51.40901960645403, 53.5023763520377, 55.93900884900774, 53.82554401670183, 52.02128096989223, 53.90898493358067, 56.283649921417236, 54.47777141843523, 48.25795943396432, 40.27171734401158, 36.35905817576817, 25.971268517630442, 18.069396666118077, 13.552120889936175, 11.575182948793683, 17.14673147882734, 16.057519708360942, 17.25138177190508, 12.398750322205679, 9.19628129686628, 6.345118837697165, 4.47276257617133, 2.443931362458638, 0.5810894646814891, 0.10508404658841235, 0.4217876541827406, 4.79132445369448, 18.343398877552577, 37.056997776031494, 36.28194011960711, 30.042419569832937, 25.466860566820415, 27.333791153771536, 35.92265224456787, 40.81453146253313, 49.80427408218384, 42.387068612234934, 16.03758532660348, 1.4139745895351683, 0.042281121747302156, 0.02308909292332828, 0.0478247291009341, 0.05114005120205028, 0.06091718442205872, 0.03314524483201759, 0.046276464858757596, 0.008126640891922372, 0.01707355598253863, 0.030894757913691655, 0.05199391966951745, 0.0374444325321487, 0.046005912590771914, 0.027333497402391264, 0.05560341723529356, 0.07459044536309582, 0.019862591056153178, 0.056629901618829796, 0.025679449550807476, 0.01826925003635032, 0.012127226534565645, 0.02175395653050925, 0.027748725210715617, 0.016698651814035008, 0.06693125742354564, 0.009433110876541053, 0.03946047542350633, 0.06500044531588044, 0.15206941430057797, 0.10193835824195828, 0.14047388865479402, 0.10555762331932783, 0.11638943744557244, 0.09893360161887747, 0.05439470209447401, 0.15421495560024465, 0.12032038079840796, 0.11972633696028165, 0.13342724820332869, 0.11962291465273925, 0.058754184416362217, 0.11507489798324448, 0.10791553929448128, 0.08081272683505501, 0.20396401679941586, 0.10962715744972229, 0.10721345911068575, 0.1730522412274565, 0.11192053795925208, 0.17714363097080163, 0.14010267571679183, 0.18272800131567887, 0.3569470377905028, 4.8820449113845825, 29.950081484658376, 62.271624837602886, 67.07919461386544, 59.94968972887312, 50.92805140359061, 38.532805579049246, 29.497256960187638, 21.457583223070415, 25.266029834747314, 34.03893307277134, 38.692895548684255, 25.491740328924998, 6.254858698163714, 0.8783041962555477, 0.5439559029681342, 1.3503557975803102, 1.7464290644441332, 12.439109802246094, 16.262293543134415, 15.137175219399587, 18.199345350265503, 25.729940210069927, 29.93105731691633, 16.53876062801906, 19.20727709361485, 31.871737820761545, 32.83222900118147, 28.363088607788086, 31.757422583443777, 45.25810595921108, 52.43643583570208, 57.07989263534546, 56.400914669036865, 56.880583558763774, 55.40047482081822, 53.90299906049456, 52.281049796513145, 55.88673407690865, 58.47697734832764, 59.52473790305001, 54.45213603973389, 55.658061913081575, 55.1551512990679, 53.61856412887573, 49.94459990092686, 48.0398450578962, 46.388404164995464, 45.137339319501606, 47.99767296654837, 51.103250231061665, 51.54390498570034, 56.48526232583182, 57.193922996520996, 60.62287984575544, 58.583111081804546, 57.61507068361555, 59.11922713688442, 55.97494493212019, 54.47768109185355, 53.08471666063581, 52.60253599711827, 31.4991580418178, 47.66305814470564, 48.269920757838655, 52.96108388900757, 58.52860246385847, 59.2339905330113, 55.23172392163958, 55.555648939950125, 58.36134542737688, 58.08518927437918, 54.2569055557251, 58.490026065281455, 56.08536570412772, 48.40730401447841, 43.53557457242693, 45.81391668319702, 52.18431350163051, 56.20819248471941, 56.873680523463655, 59.006492614746094, 51.49014329910278, 52.285809312547954, 52.7730586869376, 54.667981828962056, 58.30919919695173, 58.09661558696202, 54.12311451775687, 55.5837196622576, 59.772746903555735, 56.49709163393293, 51.36402307237898, 48.42219400405884, 45.20982640130179, 35.84390483583723, 21.922537565231323, 14.16530202116285, 21.706445114953176, 21.597589424678258, 34.1002266066415, 36.6072130884443, 19.176661593573435, 16.027527809143066, 17.546692371368408, 7.2445796472685675, 1.5217384355408805, 0.5513508490153721, 0.2777513616851398, 0.8723659291863441, 5.082888671330043, 22.997719185692922, 43.74102585656302, 52.46489218303135, 40.052432196480886, 32.36827346256801, 35.079526560647146, 41.781849248068674, 48.0053403036935, 57.39123099190848, 50.93649346487862, 20.073568071637833, 1.9553318662302834, 0.1907698626496962, 0.1276811422514064, 0.1339256050331252, 0.20702686959079333, 0.21409457176923752, 0.1349608459110771, 0.1390125277851309, 0.14006013157112257, 0.06967217248997518, 0.08350281962858778, 0.07368811592459679, 0.19709281836237225, 0.11101319414696523, 0.06794112109180007, 0.12231327886027948, 0.11589968443981238, 0.12262345078800406, 0.1080382727086544, 0.0605977504913296, 0.14983487634786538, 0.10799159628472157, 0.13224213251045772, 0.1512473826961858, 0.08063296933791467, 0.16725145892373153, 0.08338419135127749, 0.11515286165688719], [0.018271044761474644, 0.04694497112983039, 0.05521157683272447, 0.028428630870101706, 0.025263400715110556, 0.02348054995361183, 0.016514919798022935, 0.05296092028064387, 0.07325822327818189, 0.031036551376538615, 0.02133253539380218, 0.029980411620012352, 0.048452981282025576, 0.03838568273931742, 0.008348837361804076, 0.06176479679665395, 0.058042190835944245, 0.02259589635234858, 0.06281512150807039, 0.061411408973591666, 0.04051189936165299, 0.05288976231323821, 0.030481190819825445, 0.03610579150595835, 0.011123614718339272, 0.3969990329018661, 3.090897023677826, 26.567377056394303, 46.86034665788923, 54.285775320870535, 51.61857032775879, 42.830200399671284, 35.787270069122314, 27.838725430624827, 26.49758587564741, 33.09332840783255, 35.946717330387656, 27.956132616315568, 10.045118400028773, 2.3580290462289537, 0.30461418309382027, 0.033811111601867845, 0.47388880274125506, 3.17019898550851, 4.192555623395102, 9.207202996526446, 10.21119511127472, 9.864527770451136, 6.414217804159437, 2.7884243513856615, 11.18565651348659, 24.30633074896676, 15.534353358404976, 19.947725772857666, 26.940288611820765, 39.36054795128958, 45.552118982587544, 54.87516668864659, 55.52202660696847, 54.93750940050398, 51.808662618909565, 53.061572211129324, 52.36083248683384, 53.441711630140034, 53.979161739349365, 53.74485806056431, 50.725709438323975, 53.028814928872244, 46.521569865090505, 46.45508255277361, 47.59409727369036, 43.73414019175938, 40.10317836488996, 41.13915824890137, 41.71015773500715, 43.25448519842965, 44.599048478262766, 47.25286429268973, 53.50701774869646, 52.393259729657856, 55.40100635801043, 57.05361107417515, 54.49631616047451, 48.10217734745571, 43.08937515531267, 53.98089184079851, 49.554760796683176, 53.18326990944998, 27.19139998299735, 42.976338386535645, 47.59374291556222, 52.09174960000174, 56.015244483947754, 54.262853213718955, 47.741114207676475, 49.45675645555769, 49.16907671519688, 56.3632276398795, 54.059364795684814, 53.07216821398054, 51.68232004983084, 43.959140232631135, 38.87503562654768, 39.727381569998606, 45.785550662449424, 50.34640032904488, 49.97894484656197, 54.67360986982073, 51.40381193161011, 50.54252365657261, 50.72508757455008, 51.28928477423531, 52.01776170730591, 52.87564883913313, 50.39946372168404, 50.78708635057722, 51.03214236668178, 53.50513826097761, 52.37932511738369, 53.41379376820156, 47.860970633370535, 42.07439620154244, 26.829626389912196, 29.636874062674387, 10.533335311072213, 12.037476999419075, 14.97057478768485, 5.868509760924748, 8.939455900873456, 7.067297228745051, 1.9650152666228158, 3.467117658683232, 3.9032447934150696, 0.4654801796589579, 0.0878605479374528, 0.17185659467109612, 1.3940947077104022, 10.660895551953997, 27.909734283174785, 38.38756390980312, 34.11524166379656, 30.5172837802342, 28.00891634396144, 29.16998985835484, 42.0084091595241, 48.06303119659424, 42.984922885894775, 22.644582203456334, 2.9429344832897186, 0.07160301173904113, 0.04670000981007304, 0.04665885326851692, 0.023549285551000918, 0.01565478845233364, 0.03130390095923628, 0.05564560854275312, 0.010564541726905321, 0.039179762093616385, 0.08140407010380711, 0.01777964800463191, 0.023112831470955695, 0.039171467003013404, 0.08541620017162391, 0.023445527368624295, 0.02319515303575567, 0.0476205002383462, 0.03514185108776603, 0.03584626203935061, 0.06838078464248351, 0.09540113474109344, 0.013525788988252836, 0.01393776067665645, 0.10217390488833189, 0.05935003994298833, 0.04839082068896719, 0.04228331680808749, 0.018292852876974002, 0.007329824496991932, 0.03554784573082413, 0.03419266541355422, 0.05121482915378042, 0.027557142544537783, 0.03970463267926659, 0.04168331543249743, 0.04457885505897658, 0.014626952087772744, 0.01629036372261388, 0.029071578423359563, 0.017578396214438335, 0.041277697376374684, 0.06305261554994754, 0.018230894148083668, 0.0733397967581238, 0.03730143466964364, 0.0036588775276738617, 0.02739063005096146, 0.04725734151101538, 0.029036430309393575, 0.003742197811204408, 0.02398116121600781, 0.011234460198985679, 0.4550090543925762, 4.533743875367301, 30.410378796713694, 54.06749071393694, 59.926962171282085, 56.3854410307748, 45.98866040366036, 36.569602489471436, 28.880859681538173, 26.94960962023054, 32.96430730819702, 33.734601974487305, 28.985464811325073, 12.534305334091187, 2.8382557460239957, 0.22804924153855868, 0.2799777165055275, 0.6347986598099981, 4.970566264220646, 12.295498354094368, 12.996266739709036, 10.999756591660635, 13.46200362273625, 11.873495170048304, 10.97852029119219, 10.114428418023245, 9.901782274246216, 14.235449297087532, 22.7039041859763, 29.907596724373953, 39.116183280944824, 48.06178746904646, 54.345123359135215, 54.873860427311485, 55.066033703940256, 53.39613839558193, 54.042532784598215, 52.78226157597133, 54.12046377999442, 55.97053630011422, 54.770453861781526, 52.85316446849278, 54.134526933942524, 49.274265493665425, 48.707626002175466, 49.397953850882395, 45.26017999649048, 42.928764070783345, 42.81156880514962, 45.15568951198033, 44.47958809988839, 46.86477960859026, 50.323207242148264, 55.410994393484934, 54.88070787702288, 57.92837190628052, 55.91883475439889, 53.647267137254985, 50.57002810069493, 48.62460197721209, 54.36782659803118, 49.25148235048567, 53.05531883239746, 32.678232601710725, 46.897119998931885, 46.478598730904714, 51.10845790590559, 56.559819970812114, 56.966129779815674, 49.78226218904768, 51.22095966339111, 52.06032984597342, 57.3175870350429, 53.52324179240635, 53.960554463522776, 53.577389104025706, 45.29689080374581, 40.69087437220982, 41.036467347826274, 47.149718284606934, 52.39279767445156, 51.975276947021484, 56.005228655678884, 52.68515007836478, 49.830906527382986, 50.759821619306294, 51.00888327189854, 53.64405706950596, 54.00965738296509, 53.85882936205183, 53.98587717328753, 53.9244898387364, 55.17574575969151, 55.78892775944301, 50.38630730765206, 42.97530310494559, 34.76856688090733, 22.261911903108867, 15.729899985449654, 14.739022595541817, 17.609441552843364, 13.786071947642736, 12.083719866616384, 8.245802470615931, 9.506688594818115, 8.043505668640137, 4.9704859256744385, 1.9007789535181863, 0.9488215723208019, 0.3768328907234328, 0.4304229351026671, 1.2536305763891764, 12.471961753708975, 30.249896253858292, 37.19429070608956, 30.885381971086773, 29.862756524767192, 30.085216999053955, 34.19488191604614, 46.060285908835276, 52.954340662275044, 50.41540288925171, 26.910506895610265, 3.8258301360266547, 0.062290010042488575, 0.03359827891524349, 0.05370302385251437, 0.04177357416067805, 0.0457370804090585, 0.05657700981412615, 0.02194990387319454, 0.04088717672441687, 0.04458689230627247, 0.046473121270537376, 0.05305839522874781, 0.019003733659961393, 0.043070675273026736, 0.049228909824575694, 0.01701425202190876, 0.02201774380435901, 0.03458199184387922, 0.016653785382264426, 0.07505676176931177, 0.020532437433887805, 0.0538489495936249, 0.08431100233324937, 0.07968553767672606, 0.03811467246019414, 0.04365779466128775, 0.054615541494318416, 0.06922248019171612, 0.09302449798477547, 0.09986260426895958, 0.09108492599001952, 0.15106953866779804, 0.12448438735944883, 0.2525198741682938, 0.15512128839535372, 0.16429136347557816, 0.10801200661808252, 0.0998717305649604, 0.10827522392251662, 0.12316633308572428, 0.13235878625086375, 0.10581050653542791, 0.11604776792228222, 0.17427304786230835, 0.19624417461454868, 0.15017168756042207, 0.09432072378695011, 0.1398210972547531, 0.19486430580062525, 0.13205729957137788, 0.09705496206879616, 0.15828567716692174, 0.10523415210523776, 0.6939176246523857, 6.706882008484431, 37.96169492176601, 62.46076175144741, 66.63110528673444, 63.36633437020438, 54.284309250967844, 47.518330642155235, 38.93496036529541, 37.66741091864449, 44.40671191896711, 46.52575962884085, 34.079246520996094, 13.595631378037588, 3.1162227732794623, 0.46385918664080755, 0.4223366432956287, 1.46954465338162, 8.59170811516898, 14.784069504056658, 23.723135437284196, 22.91109946795872, 20.352741479873657, 15.699586732046944, 10.64406875201634, 19.490438767841884, 31.516396522521973, 18.97709195954459, 24.416793210165842, 29.778033665248326, 39.791659355163574, 48.570517199380056, 57.49879952839443, 55.15619352885655, 55.66678885051182, 52.21514960697719, 55.20839534487043, 53.233230931418284, 55.41955804824829, 57.85051734106881, 57.97713088989258, 53.28264651979719, 57.30077934265137, 51.390106609889436, 52.10934591293335, 51.94552476065499, 48.118957247052876, 45.26567602157593, 45.05077518735613, 46.07199362346104, 47.03165449414934, 49.828763008117676, 51.99323456627982, 57.06367553983416, 58.0018630027771, 59.56915773664202, 59.97150707244873, 54.8687778200422, 52.236494473048616, 47.453573431287495, 54.025408949170796, 50.11155816486904, 56.567077364240376, 39.59296172005789, 49.71735211781093, 48.32305710656302, 53.02027906690325, 60.681029319763184, 57.685838086264475, 51.51265893663679, 52.9198637008667, 53.693830490112305, 60.194738796779085, 55.606971808842246, 55.900852816445486, 56.24259301594326, 48.67122786385672, 42.27358021054949, 43.43123000008719, 49.47965771811349, 55.18829768044608, 54.243662289210725, 58.21588488987514, 55.01449196679251, 50.91412026541573, 50.5985678264073, 52.46692453111921, 54.96729980196272, 58.929909569876536, 56.335031849997385, 56.64298643384661, 55.48451328277588, 57.051658630371094, 57.122061252593994, 55.64176491328648, 56.1569356237139, 46.885603359767366, 28.078872544424875, 38.079091685158865, 15.982260295322963, 21.43986357961382, 24.107785974230083, 13.787670033318655, 16.450754744665964, 16.899665696280344, 11.01158937386104, 8.636102761541094, 6.106533331530435, 0.5189358741044998, 0.36486944981983727, 0.4989542120269367, 2.2686207124165128, 13.037029215267726, 34.587729590279714, 48.56900944028582, 46.15963472638811, 41.07285853794643, 38.132558073316304, 40.6816680090768, 54.503250462668284, 60.25695991516113, 59.47935921805245, 32.823411737169536, 5.47882091147559, 0.19168688915669918, 0.12577820436230727, 0.11653043702244759, 0.12745388730296067, 0.16141373717359134, 0.19048428083104746, 0.1534023827740124, 0.18325143679976463, 0.14879071951976844, 0.25504804136497633, 0.21019174690757478, 0.13398773169943265, 0.13281929439732007, 0.12952423335186072, 0.11601998869861875, 0.1157888796712671, 0.10651391664785997, 0.07429740644459214, 0.1104972700455359, 0.12272053557847228, 0.18999663128384522, 0.18095188162156514, 0.09858722984790802, 0.15541566402784415, 0.1558145476239068, 0.12666514462658338, 0.12705397233366966], [0.03201081570503967, 0.05213779962754675, 0.03391427267342806, 0.008180419881162899, 0.00962065625935793, 0.06542471969234091, 0.030748838957931315, 0.03748985366629703, 0.03276927536353469, 0.03344897406974009, 0.06708104402891227, 0.03875817471582975, 0.015475492359005978, 0.03816854474799974, 0.06094404762344701, 0.049102844803461006, 0.06435769623411552, 0.021935971852924143, 0.045515511584069045, 0.025589726865291595, 0.02265673889113324, 0.027590224519371986, 0.024255569259236966, 0.024174184072762728, 0.014087502329078103, 0.1228635029069015, 5.946822472981044, 36.68546717507498, 48.936350277491975, 52.084363664899556, 41.9902674130031, 34.71708767754691, 29.208746910095215, 26.268557616642543, 18.311480590275355, 32.26392194202968, 39.398200239454, 16.77031282016209, 7.3694444213594705, 0.47820754242794855, 0.0708423943391868, 0.182792299294046, 0.837554640003613, 4.08704766205379, 10.528459412711006, 7.5363505738122125, 9.404076729501996, 14.953086171831403, 10.860396572521754, 7.558041112763541, 6.387439446789878, 8.529288973127093, 21.26437292780195, 35.170638288770405, 44.77998651776995, 47.35159819466727, 51.48392813546317, 53.500166824885774, 55.079408986227854, 51.87689740317208, 54.78313432421003, 54.874145303453716, 51.48392813546317, 53.48736129488264, 53.42198569434029, 52.69860873903547, 49.63361937659127, 48.96387209211077, 44.384675707135884, 45.35839278357369, 44.36469963618687, 43.7168322290693, 39.948243958609446, 40.64882387433733, 42.651117529187886, 44.07527242388044, 43.372476032802034, 43.85957254682268, 48.382283551352366, 51.1937609400068, 53.059095178331646, 56.95391137259347, 57.032217570713584, 58.348630223955425, 51.563693455287385, 51.62460831233433, 48.07658018384661, 50.21886614390782, 27.48203444480896, 42.80952950886318, 50.75942209788731, 50.522109849112375, 55.44047212600708, 51.283448287418906, 44.53988109316145, 43.45960644313267, 52.18415021896362, 53.20941250664847, 53.26269824164254, 51.59078795569283, 48.80428239277431, 40.59737941196987, 38.48328924179077, 42.01762247085571, 42.88223198481968, 47.03854015895298, 49.146175452641074, 51.49278014046805, 53.29449667249407, 50.715162072862896, 49.60181747164045, 50.27819333757673, 50.96267080307007, 52.40937260219029, 54.01789099829537, 55.55944613048008, 53.883564949035645, 52.435438769204275, 51.556800842285156, 46.52057974679129, 40.474587372371126, 38.892482553209575, 34.07991007396153, 24.302241734095983, 18.904380798339844, 28.5352806023189, 12.289264951433454, 18.13727014405387, 10.51678991317749, 6.39454311132431, 4.693507279668536, 1.736650994845799, 2.890125785555158, 2.2795854040554593, 0.1056695408853037, 0.04540011313344751, 0.35826388427189415, 3.5578572239194597, 15.244773285729543, 43.29062277930123, 47.93844304765974, 32.302974292210166, 29.067804438727244, 24.603880405426025, 39.74746881212507, 48.20146363122122, 48.182908466884065, 29.590929099491664, 5.405314181532178, 0.09941270162484475, 0.014772667483027493, 0.055120398689593585, 0.029716407214956622, 0.06381895300000906, 0.09553551860153675, 0.05573763485465731, 0.039015882315912416, 0.06793367077729531, 0.026172686833888292, 0.03128189606858151, 0.05436772354213255, 0.12453242763876915, 0.00922146053718669, 0.04051778904561486, 0.041796858089842966, 0.061830757185816765, 0.01983666423309062, 0.08875826333782502, 0.01487746721665774, 0.06927541270852089, 0.021091238163145523, 0.042776065545954874, 0.05990993989897626, 0.058369088651878495, 0.07393220532685518, 0.028235621584047164, 0.03734264549400125, 0.020830076819817935, 0.02346485374229295, 0.053202122516397915, 0.014053234614298811, 0.021994710933150988, 0.040339195236031494, 0.028552471992692778, 0.029181884468666146, 0.08814926458788769, 0.02172976336441934, 0.03589101142383047, 0.051991124105240615, 0.11084771981196744, 0.03790141908185823, 0.09005678937371288, 0.04090686781065805, 0.04445648466103843, 0.04325444969747748, 0.058674504049122334, 0.017636241324778115, 0.05486140187297549, 0.02352054280761097, 0.012831790156529417, 0.011168379369857056, 0.4210652858018875, 7.982041035379682, 41.45808056422642, 54.69099773679461, 58.01937941142491, 47.04004791804722, 41.97019059317452, 36.960348333631245, 29.067486558641704, 20.699590342385427, 31.049835409436906, 39.45965705599104, 18.53550614629473, 7.722521475383213, 0.5967992874128478, 0.2759594049836908, 0.5036482087203434, 2.822447725704738, 6.302126424653189, 7.928132568086896, 10.248906459127154, 10.533443876675197, 17.267183712550572, 14.286832094192505, 15.163515840257917, 11.268571972846985, 9.36557241848537, 19.860088144029888, 31.13291154588972, 42.37415191105434, 45.74903787885393, 51.162872723170686, 54.39192989894322, 55.72080414635794, 52.463822160448345, 54.45199360166277, 52.966301986149375, 50.86408281326294, 54.71411439350673, 56.213084016527446, 54.84307990755354, 51.24628584725516, 52.557066985539024, 47.58600957053048, 47.23347534452166, 47.36881930487496, 46.46926382609776, 41.1807154246739, 43.07174062728882, 43.66778836931501, 46.549755232674734, 45.335397720336914, 46.887267453329905, 52.696392263684956, 54.3803368295942, 54.69867549623762, 58.61749076843262, 56.17546994345528, 56.31553520475115, 52.981240613119944, 51.752906799316406, 48.43803242274693, 51.56494065693447, 32.07077244349888, 45.87101697921753, 50.34687280654907, 51.538245677948, 57.25638730185372, 53.73291410718645, 46.85009806496756, 45.30506188528878, 52.85822623116629, 53.21682970864432, 56.01161057608468, 52.74391794204712, 51.60561888558524, 43.76686273302351, 40.521897656576975, 44.152845587049214, 45.85907302583967, 50.42756918498448, 52.90496676308768, 52.345529079437256, 54.46043913705008, 51.08332974570138, 49.41517496109009, 50.12516621180943, 50.890517234802246, 53.86479091644287, 55.042416776929585, 55.86068875449044, 54.60728931427002, 55.25552150181362, 53.46914311817714, 48.46868787493025, 43.03222969600132, 37.75474282673427, 29.9747371673584, 20.799903222492762, 15.180113349642072, 13.212490337235586, 11.65321295601981, 11.017338139670235, 12.872921449797493, 14.231622576713562, 7.739030395235334, 5.9734362448964795, 4.650266902787345, 1.6372871952397483, 0.28657874943954603, 0.014891623153484293, 0.5687833364520753, 4.405333348682948, 16.21549916267395, 41.18596131461007, 49.416578497205464, 35.5167350087847, 33.414123262677876, 29.012302228382655, 44.83764614377703, 53.29888098580496, 52.70983007975987, 33.97385277066912, 6.889682599476405, 0.037712409759738615, 0.019565243440281068, 0.010829824322302426, 0.020324917676459466, 0.03835207489984376, 0.04782579440091338, 0.026693070606727685, 0.013035187813719469, 0.012626166056309427, 0.030483820143022707, 0.08278056659868785, 0.041001486126333475, 0.03529407363384962, 0.012268658677515174, 0.04783288848453334, 0.036201909384025, 0.03135266727102654, 0.05560928317052977, 0.030291160302502767, 0.05090779545051711, 0.030792621430009604, 0.012445815689196544, 0.036508634353854826, 0.04801384698865669, 0.01726794778369367, 0.01800944237038493, 0.043374109348016124, 0.14558521152607032, 0.16590599183525356, 0.07008165480302912, 0.13769887041832718, 0.08718351248119559, 0.16091248978461536, 0.12241697258182935, 0.11898308327155453, 0.17370047287217208, 0.16149144300392695, 0.19664429314434528, 0.1143543209348406, 0.18038639053702354, 0.11599641639207091, 0.14552275916295393, 0.20906153826841287, 0.2023979986884764, 0.10250279081187078, 0.16551823621349676, 0.15175095067492553, 0.09407116539244141, 0.1579930250133787, 0.1641235210533653, 0.14540542688752922, 0.10319244701947484, 0.9684527303491319, 11.556527904101781, 49.43942070007324, 62.7339996610369, 64.30491093226841, 53.71295540673392, 48.273565087999614, 38.73575203759329, 37.630033084324424, 28.19124228613717, 43.134868485586985, 49.75187076841082, 20.864667381559098, 9.411053589412145, 0.900391976748194, 0.3944490983017853, 0.4910849428602627, 4.723388007708958, 8.015797121184212, 16.744323083332606, 18.816760540008545, 19.977708986827306, 27.19441376413618, 16.579230410712107, 19.206014258520945, 11.751863479614258, 12.242389798164368, 26.621163061686925, 37.61328445162092, 45.45920419692993, 49.67292881011963, 53.54906129837036, 55.83307661328997, 57.25093991415841, 52.81982006345476, 54.01604625156948, 55.27735274178641, 52.25154774529593, 55.58984449931553, 57.33569751467024, 57.62775809424264, 54.080761773245676, 53.86833449772426, 49.93514340264456, 48.7920674596514, 48.89641898018973, 47.81276750564575, 44.159019061497276, 45.36587599345616, 46.36643048695156, 49.25303874697004, 46.46542842047555, 48.13640069961548, 53.46444961002895, 57.64251954214913, 57.48824521473476, 61.409422874450684, 59.02334894452776, 57.72519268308367, 51.53579991204398, 51.89710623877389, 49.574618748256135, 51.7300819669451, 38.566299370356965, 48.3610394341605, 49.85923433303833, 53.74542086465018, 60.36467783791678, 57.135540757860454, 48.23306056431362, 45.49901737485613, 55.99395867756435, 56.160534790584016, 59.49749401637486, 56.36375570297241, 54.118851797921316, 45.25651134763445, 42.292347294943674, 46.36720521109444, 47.155405385153635, 52.20593629564558, 54.245798860277446, 54.73438923699515, 56.529129777635845, 52.270776884896414, 50.270119530814036, 51.145265987941194, 53.78787783214024, 55.2509217943464, 57.8411476952689, 59.63825757162911, 57.16336134501866, 57.04446724482945, 55.32065391540527, 49.026791504451204, 45.661334242139546, 41.04372821535383, 39.00434160232544, 27.27446743420192, 23.866002559661865, 40.43868950435093, 21.667971202305385, 27.084599222455704, 21.955100297927856, 13.473719154085432, 15.831479174750191, 14.534599644797188, 6.096362905842917, 3.950768734727587, 0.45338271451847895, 0.4713884826217379, 0.746489377958434, 4.812908164092472, 19.842173951012747, 53.16242183957781, 58.07497194835118, 40.46883078983852, 39.04177849633353, 34.58456815992083, 51.852814946855815, 59.892360142299104, 61.1515474319458, 39.99464750289917, 10.9038645029068, 0.2945542229073388, 0.14361721569938318, 0.10150436045868055, 0.12639343206371578, 0.20187707378395967, 0.23572515536631855, 0.15858432757002966, 0.14282267833394663, 0.2239639043275799, 0.10128336160310678, 0.24523544790489332, 0.12680305008377346, 0.16987025125750474, 0.17058185807296208, 0.11821176537445613, 0.1990330485360963, 0.19894812309316226, 0.08074699036244835, 0.19930786878934928, 0.13737245436225617, 0.13318358627813204, 0.08950879770730223, 0.11826716097337858, 0.15937145533306257, 0.14743336449776376, 0.16178382374346256, 0.17550158979637281], [0.08744352710034166, 0.06831411179155111, 0.027546711764963608, 0.062380309482770305, 0.013516668629433428, 0.05468641108434115, 0.035698443185538054, 0.02845370613171586, 0.03907971549779177, 0.02116293556589101, 0.004862526556410427, 0.0235675686770784, 0.03593192369277988, 0.07735042726354939, 0.02791391795368067, 0.01714727033062705, 0.04241546489564436, 0.03376546994383846, 0.00813746776631368, 0.03101790862690125, 0.05548859553943787, 0.03782688540273479, 0.054726434472416124, 0.01960595554139997, 0.038109481667301486, 0.6922547795942852, 7.72648194858006, 34.51918561117989, 49.25212505885533, 50.74211413519723, 45.04712043489729, 29.884976863861084, 14.752681016921997, 21.4320399080004, 24.846209253583634, 35.98418549128941, 26.771683624812535, 12.890177300998143, 2.4881685887064253, 0.21055070550314017, 0.23049831869346754, 0.5300016403198242, 1.0696193703583308, 5.783103806631906, 10.030819875853402, 9.13868681022099, 8.256257772445679, 9.00851925781795, 15.153387103761945, 19.139519998005458, 13.85006833076477, 12.349276542663574, 25.433373723711284, 35.419814586639404, 44.38461664744786, 48.89474793842861, 52.8729043006897, 54.44791153499058, 52.71266841888428, 53.674674306597026, 51.78999975749424, 49.93743978227888, 52.156829902103965, 53.76602922167097, 53.31624105998448, 49.694895539964946, 48.772727148873464, 45.51782962254116, 44.21993391854422, 43.22996847970145, 45.650303976876394, 43.88263361794608, 42.16318375723702, 39.973966189793174, 39.94040986469814, 40.096702643803184, 43.130716936928884, 43.2190146446228, 46.647968019757954, 50.0794609614781, 52.27490758895874, 52.614712715148926, 55.63987152917044, 54.94300889968872, 48.78402839388166, 49.48428521837507, 50.23445095334734, 48.58848524093628, 30.075729233878, 47.71776826041085, 49.91744286673409, 52.09218038831438, 53.31577900477818, 49.842996392931255, 42.2007109778268, 40.28344937733242, 43.127725737435476, 50.087107454027446, 52.1740961756025, 49.61571734292166, 43.52819211142403, 38.15121398653303, 39.094015053340364, 40.72940213339669, 43.97111892700195, 43.34286281040737, 48.48384884425572, 51.511738300323486, 54.03902047021048, 52.22738191059658, 50.18931892939976, 49.19201619284493, 47.74329941613333, 47.095508439200266, 48.44578313827515, 48.39019407544817, 53.564798968178884, 55.04941708700997, 53.50748675210135, 54.64001880373274, 53.55929252079555, 43.317039830344065, 35.28832687650408, 26.467785051890782, 34.42078174863543, 15.607768024717059, 7.652140566280909, 9.208011593137469, 4.919618163790021, 13.40890027795519, 6.663465321063995, 2.26091559444155, 0.9879768426929201, 1.5003670794623238, 0.6160912322146552, 0.10227607190608978, 0.09022733236529998, 2.7086399240153174, 17.13958351952689, 37.268368925367085, 33.12779842104231, 27.402055467878068, 25.26562336512974, 21.90877492087228, 26.69155526161194, 46.35980537959507, 51.91665499550955, 34.66692863191877, 10.332642674446106, 0.9625600065503801, 0.028963124778653895, 0.01666016361143972, 0.03924691331173692, 0.0390035906540496, 0.0964900002415691, 0.026151854112478237, 0.02726197981142572, 0.02024937467649579, 0.03366918243201716, 0.03708428650030068, 0.017017744780917252, 0.09106889220752887, 0.01231324436542179, 0.0739344512777669, 0.01682551920280925, 0.020175137856443013, 0.04015358876703041, 0.0400630280907665, 0.025563630408474376, 0.041242213387574465, 0.028355907183140516, 0.01826184382662177, 0.047797855721520524, 0.011817532125860453, 0.04799760625298534, 0.013168824437473501, 0.05376643295000706, 0.02120400559423225, 0.017326483303414922, 0.04986792357106294, 0.02621678143207516, 0.020164605296616043, 0.00980879196764103, 0.024832006809966903, 0.051362963526376655, 0.042441069414573054, 0.011415517938855504, 0.03607235669291445, 0.027305965844009603, 0.12469773234001227, 0.09954110080642359, 0.07455566365803991, 0.03191909134121878, 0.07937342513884817, 0.013182489284580308, 0.015350952345345701, 0.11113578506878444, 0.04157724683838231, 0.046979589986481836, 0.031426077974694114, 0.06313340192926781, 0.8344615516918046, 10.669124824660164, 41.15435743331909, 56.89426108769008, 57.13352925436837, 49.274769238063264, 34.8620514188494, 23.108117376055034, 26.591718333108084, 23.392651319503784, 38.78296504701887, 28.511703627450125, 12.232581547328405, 2.7436757811478207, 0.2649852138544832, 0.31816406601241654, 2.0781063182013373, 3.3291501019682204, 6.029200315475464, 8.609106404440743, 15.396989209311348, 11.702918631689888, 13.36699048110417, 17.54799689565386, 14.659437928880964, 13.35397129399436, 15.289530106953212, 29.770633833748953, 36.014340673174175, 44.882774693625315, 50.782305989946636, 53.153027875082834, 52.43035616193499, 53.32079560416085, 53.663946287972585, 53.380630016326904, 51.39100987570626, 53.83289173671177, 54.75975363595145, 55.316116741725374, 51.85849857330322, 51.02806030000959, 48.374136788504465, 46.94501393181937, 45.67167316164289, 47.20763846806118, 44.84769671303885, 45.522592612675254, 42.0544444492885, 42.032192843300955, 41.41320562362671, 44.97822904586792, 44.928410461970735, 47.99686697551182, 52.38056537083217, 54.078263895852224, 54.012707642146516, 57.50555665152413, 56.5190166745867, 48.76840884344918, 47.657739298684255, 50.13499443871634, 50.23421818869454, 34.44321400778634, 48.11586529867989, 49.240007400512695, 53.28586006164551, 54.89327022007534, 52.497625146593364, 44.403571333204, 41.29153571810041, 45.681174823216026, 51.94891200746809, 53.52555554253714, 52.6693811416626, 45.99711288724627, 40.101781776973176, 42.007307870047434, 42.72354902539934, 45.30359928948538, 44.78912687301636, 51.38338075365339, 52.75851263318743, 55.01095533370972, 53.12059020996094, 50.67527593885149, 48.77897357940674, 49.07255234037127, 48.426606110164094, 50.443852288382395, 50.352886472429546, 55.50281136376517, 54.82526125226702, 54.367666789463584, 55.59182126181466, 52.96218170438494, 44.15957144328526, 33.996316296713694, 25.936419827597483, 20.480167967932566, 14.648022038596016, 12.623445510864258, 11.640042645590645, 11.683110186031886, 16.60764159475054, 8.772031239100865, 8.684001037052699, 5.419514562402453, 2.7239235724721635, 0.9021395029766219, 0.323920838534832, 0.06523347459733486, 2.332318974392755, 15.595487083707537, 41.90708705357143, 39.43718310764858, 32.72115509850638, 30.57881007875715, 27.154831613813126, 33.32673576899937, 52.54001610619681, 57.38448429107666, 40.525653157915386, 12.884936622210912, 0.9541694053581783, 0.07068308110215835, 0.04963437860299434, 0.062423545734158585, 0.032915543764829636, 0.014193101885861583, 0.030772811600140164, 0.05801744466381414, 0.036797310292188606, 0.0024931384624713765, 0.03769225387700966, 0.04123555017369134, 0.032099140608417134, 0.015057167038321495, 0.0681043698319367, 0.03277252893894911, 0.04238897149584123, 0.004815053701999464, 0.03151143428736499, 0.02282824200977172, 0.04648047319746443, 0.04700972372666001, 0.01636318918982787, 0.00692507454160867, 0.022045366964968185, 0.019979273634297506, 0.014896495034918189, 0.24093679285475186, 0.1092065946598138, 0.1243602561631373, 0.10880905456308808, 0.17684218500341686, 0.19283620534198626, 0.16634910234383174, 0.1078287750216467, 0.10812647547572851, 0.1011435833892652, 0.07901318411209754, 0.09349264643554177, 0.1885746254452637, 0.29535022590841564, 0.21283299875046524, 0.19818041500236305, 0.1636266162885087, 0.0929399389507515, 0.10265507442610604, 0.1378532371350697, 0.1761377299470561, 0.19120290369859763, 0.2214596215635538, 0.12595356495252677, 0.1254147267235177, 1.456065690943173, 13.835403289113726, 46.644563402448384, 64.25452954428536, 62.7837279183524, 55.875474521092, 39.88950041362217, 24.927709886005946, 31.70299734388079, 35.81071676526751, 48.472492013658794, 33.11764015470232, 15.312886476516724, 3.045251701559339, 0.32978237686412676, 0.49541372486523216, 2.4003878704139163, 4.523573883942195, 13.292825409344264, 20.442453145980835, 15.771356412342616, 15.086925847189766, 21.274248055049352, 27.166660921914236, 27.4281998021262, 18.359669821602957, 17.1975644997188, 29.400614465985978, 37.67460230418614, 46.33485439845494, 50.20909002849034, 53.998154640197754, 53.78852054050991, 53.54551076889038, 53.91817740031651, 54.205127579825266, 53.51387562070574, 56.566914081573486, 58.81185967581612, 58.3699403490339, 53.42883314405169, 53.20427083969116, 52.22184419631958, 49.426243441445486, 47.9269437789917, 50.78306334359305, 48.11222096851894, 48.77188294274466, 43.29520511627197, 44.46626492909023, 43.91372333254133, 46.727622168404714, 47.00073848451887, 48.94451093673706, 54.23592547007969, 56.22657741819109, 56.50704492841448, 59.80854402269636, 55.438512734004426, 49.22241803577968, 48.91611017499651, 52.25499405179705, 50.2643803187779, 37.799402373177664, 50.14099073410034, 49.534016949789866, 55.7588837487357, 57.718911511557444, 54.06211280822754, 47.06339039121355, 45.528967584882466, 47.68582739148821, 53.34051806586129, 56.3702974319458, 54.25139910834176, 48.867740290505544, 42.09899282455444, 44.314366885593955, 46.0920843396868, 48.493246282849995, 47.092263630458284, 52.6616130556379, 55.431627069200786, 56.69973931993757, 53.63555594852993, 50.29719318662371, 48.810243947165354, 50.33626638139997, 49.43066249574934, 52.132108211517334, 50.975691727229524, 57.02886159079415, 59.04577078138079, 59.09017671857561, 58.85342379978725, 57.257592814309255, 48.63130351475307, 41.07596785681588, 33.348170961652485, 41.36201129640852, 20.128068004335674, 14.040191888809204, 17.19887249810355, 12.946391701698303, 24.138490063803538, 15.26210035596575, 14.34435362475259, 8.26223235470908, 4.624587229319981, 1.5106283745595386, 0.6429591562066759, 0.11723230007503714, 3.7730607390403748, 19.222215720585414, 42.478145599365234, 41.67216151101248, 38.53573077065604, 35.32204648426601, 31.883782523018972, 38.725420066288535, 59.01080744607108, 63.29120349884033, 49.74259492329189, 17.227342741830007, 2.1825811692646573, 0.1552257285054241, 0.1850289949881179, 0.22577015097652162, 0.13769034801849298, 0.1615787297487259, 0.10790122899093799, 0.1484041716903448, 0.1252500462744917, 0.11530988823090281, 0.1910791253404958, 0.14096482231148652, 0.1506010645202228, 0.07729100795196635, 0.11221846911524024, 0.09291142012391772, 0.1523190744753395, 0.16469116987926619, 0.09371294640004635, 0.22987173231584684, 0.14318996933954103, 0.1300130771206958, 0.06523901144308702, 0.12848659045994282, 0.1393921545573643, 0.1400598601571151, 0.04933130754423993], [0.05428913900894778, 0.02854781724246485, 0.0844040091282555, 0.04845615343323775, 0.022793399236564125, 0.021801316578473364, 0.02836622261176152, 0.05353898122640593, 0.015178848723215716, 0.04365378112665244, 0.031042474987251416, 0.02514654171786138, 0.051115372883422036, 0.031050447773720537, 0.01025056915490755, 0.01692629013476627, 0.028388629534414837, 0.04359970188566616, 0.05137563856052501, 0.012972511534046913, 0.05133490949603064, 0.0338717319204339, 0.06481468278382506, 0.032355793086545806, 0.14567089692822524, 2.612921540226255, 14.733919143676758, 43.063847473689485, 53.586279324122835, 48.76902028492519, 38.90013599395752, 26.16242388316563, 20.799953596932546, 15.73439199583871, 32.01117079598563, 27.46356439590454, 24.951566525868007, 7.049263613564627, 0.7271048809800829, 0.06797991293881621, 0.22215986970279897, 1.954727590084076, 2.681027565683637, 4.2071268643651685, 4.137270978518894, 12.162953649248395, 10.535887905529567, 17.67589933531625, 18.635989257267543, 17.717154264450073, 22.2266480582101, 19.394261802945817, 34.89623655591692, 39.240368434361045, 49.8350441796439, 50.90410096304757, 51.81358889171055, 51.31975957325527, 54.0263261113848, 48.79979385648455, 52.44026429312569, 55.21793869563511, 50.77736234664917, 50.535168988364084, 47.945359979357036, 45.988604818071636, 43.42812762941633, 41.555549894060405, 43.054957253592356, 43.040703024183, 45.30976928983416, 45.58207961491176, 43.45111921855381, 38.575516155787874, 40.28875780105591, 40.40893384388515, 43.465098994118826, 41.40744209289551, 43.1041122845241, 41.91458068575178, 45.57450260434832, 52.296193395342144, 54.801324708121165, 54.65141384942191, 50.45183229446411, 49.08477769579206, 48.34988757542202, 42.75885629653931, 22.648606947490148, 37.208444186619346, 51.14321974345616, 53.301712376730784, 53.61441258021763, 49.97274357931954, 43.04465307508196, 40.13836751665388, 38.44384431838989, 38.74522590637207, 43.218149593898225, 40.188748904636924, 40.34904037203108, 39.656086104256765, 42.293521540505544, 41.219479424612864, 42.25508063180106, 44.59827375411987, 44.25467143739973, 47.74046802520752, 52.883809498378206, 52.45304897853306, 51.34854596001761, 48.327066217150005, 50.37479414258684, 47.69607598440987, 46.285237312316895, 47.851048605782644, 48.54046624047415, 48.864627497536794, 52.724421296800884, 47.74241699491228, 43.38104663576399, 40.04329184123448, 29.833726951054164, 26.27829725401742, 18.56350564956665, 14.703552041734968, 11.618726440838405, 7.8708359854561945, 14.667576006480626, 21.374861444745743, 6.413965497698102, 6.356279381683894, 7.717243450028556, 1.528448115502085, 0.8819850587419101, 0.20309136648263248, 0.15504029845552786, 0.4960533933980124, 5.569347253867558, 16.68575324331011, 29.36865622656686, 31.303482873099192, 19.821878262928553, 14.872033698218209, 20.701447248458862, 34.201298577444895, 44.33033037185669, 38.59958471570696, 13.734040362494332, 1.771532905953271, 0.20059780457190104, 0.15087315706270082, 0.024129972427285144, 0.07431092964751379, 0.017692276442955648, 0.024023430554994514, 0.029648580854492526, 0.030958662341747965, 0.00468205617341612, 0.017638103903404305, 0.048684955441526005, 0.028849473555705378, 0.02810351251225386, 0.02967237029224634, 0.02685066036480878, 0.02684562054595777, 0.013292125276555973, 0.012043554685078561, 0.01363512727298907, 0.05339921658326473, 0.018974081679646457, 0.02159176121598908, 0.030870707239955664, 0.02697763462284846, 0.07380112593195268, 0.07584224747759954, 0.06084305447127138, 0.020488224092072675, 0.06540076062083244, 0.050506028080625195, 0.02977985023920025, 0.019314855536712066, 0.005151568479569895, 0.0008293338074249082, 0.03604208046038236, 0.036587900814733336, 0.021611060448256985, 0.03295189967112882, 0.042575371850814135, 0.051083488522895744, 0.012647514464333653, 0.03201489370050175, 0.04188569528715951, 0.02768912099833999, 0.03640920861757227, 0.014395505489249314, 0.040981001154120476, 0.043202606229377646, 0.02854187666837658, 0.019954987169642533, 0.10579917500061647, 3.3373630898339406, 16.851403508867534, 48.97723347800118, 59.86209378923689, 55.1980425289699, 44.353085722242085, 27.60156430516924, 21.01413529259818, 17.560760736465454, 30.583580017089844, 29.23275293622698, 23.81117606163025, 7.399867977414813, 0.9819630682468414, 0.053397625418646, 0.26582836146865574, 2.006482550076076, 6.461781697613852, 9.373799085617065, 8.356527226311819, 18.218671764646256, 10.515012042863027, 9.920279247420174, 13.231144513402667, 19.46727694783892, 17.003840037754603, 20.762660878045217, 35.65888820375715, 38.71500471660069, 51.65006651197161, 51.80544907706124, 52.92669725418091, 51.73812798091343, 53.336870261601035, 49.95777021135603, 52.82363115038191, 56.03576946258545, 53.38896090643746, 53.527077198028564, 51.21953180858067, 47.6764577456883, 45.07168926511492, 44.27741289138794, 45.159299101148335, 45.1431063243321, 48.23953628540039, 48.660169805799214, 44.951968329293386, 40.634163175310405, 41.369296482631135, 42.42619044440133, 43.69682836532593, 43.31751578194754, 44.418162550245015, 44.74685403278896, 48.29516356331961, 54.4787163734436, 55.94279909133911, 54.02998086384365, 51.38469743728638, 50.251303809029714, 48.57428312301636, 43.55186462402344, 25.84859459740775, 40.56648077283587, 51.30492169516427, 54.26773084912981, 54.31973116738455, 52.28363452638899, 45.745351859501426, 42.25957611628941, 39.57618876865932, 40.82312985828945, 45.39118480682373, 43.00859887259347, 41.97485283442906, 42.287289006369456, 43.00249835423061, 43.58672373635428, 45.248420170375276, 47.19090025765555, 46.27352612359183, 51.04141821180071, 53.7048260143825, 53.67985418864659, 51.155952317374094, 50.06678397314889, 51.821711335863384, 48.729947090148926, 48.39745494297573, 49.58387722287859, 50.37392561776297, 53.997855867658345, 54.32580041885376, 49.37010547092983, 45.84549624579293, 41.68224682126726, 32.41682052612305, 28.08581379481724, 16.88054599080767, 12.697305730410985, 8.425998789923531, 8.183647360120501, 13.392168147223336, 12.988619378634862, 11.233485307012286, 10.147928289004735, 7.396431224686759, 3.947027564048767, 1.1635554326432092, 0.41429928743413513, 0.28761633804866243, 0.9100324394447463, 7.359754289899554, 20.565512691225322, 31.641651698521205, 30.92360748563494, 20.021133490971156, 17.028627736227854, 25.21548863819667, 39.72710711615426, 51.14424112864903, 44.973559856414795, 18.40877100399562, 2.3566858725888387, 0.2226704673043319, 0.07666928667042937, 0.06939290783235005, 0.017693604675254652, 0.03867161061082568, 0.014296279920797263, 0.04521449648642114, 0.06392891638513122, 0.03395288470866425, 0.027380341763741205, 0.06975160858460835, 0.10387208805020366, 0.03287169343924948, 0.021666471314217364, 0.04205946471276028, 0.05197598259629948, 0.053219221598867855, 0.008012097395424331, 0.07521895878016949, 0.04080609518236347, 0.036668636303927214, 0.02282731750580881, 0.012693340174986847, 0.02422969332630081, 0.1345685983874968, 0.014812236252639974, 0.1776233280875853, 0.1542640815355948, 0.295924293675593, 0.15703791912112916, 0.07909844203719071, 0.13942206438098634, 0.05074209380628807, 0.16145694628357887, 0.11281420929091317, 0.14021688673113072, 0.08676056124802146, 0.12692665202277048, 0.14226306336266653, 0.12331079319119453, 0.12432927425418581, 0.12929047803793633, 0.13486157623784883, 0.1834463934813227, 0.09569513039397341, 0.136544492361801, 0.19733833947352, 0.19726857250290258, 0.12155127046363694, 0.21723228054387228, 0.2999066428414413, 4.634462356567383, 23.578658069883073, 58.1205347606114, 67.32315281459263, 61.70858451298305, 51.51299592426845, 36.003845419202534, 30.57649632862636, 25.117854288646154, 44.094275747026714, 35.61364153453282, 29.666066919054302, 8.868636386735098, 1.2494841303144182, 0.16561433034283773, 0.46561262969459805, 3.0586022308894565, 8.944663575717382, 14.810627256120954, 13.239719458988734, 31.127405098506383, 20.075296436037334, 26.641253777912684, 25.37239806992667, 25.277652433940343, 27.712778908865793, 24.3500713961465, 37.87787880216326, 41.13526030949184, 51.673405511038645, 52.80577775410244, 52.04707963126046, 51.10009574890137, 53.69593926838466, 51.129017625536235, 54.764485359191895, 58.769621576581685, 54.525161606924875, 55.590490681784495, 52.184330872126985, 51.062481675829204, 47.7913635798863, 46.36807026181902, 47.635786465236116, 47.030223165239605, 50.53320264816284, 51.02115379061018, 47.5499484198434, 43.78939226695469, 42.90744004930769, 43.89227771759033, 46.77331352233887, 45.0969946043832, 47.408861773354666, 45.74095712389265, 49.80151564734322, 55.163635049547466, 57.86308315822056, 54.930328437260215, 50.02905525479998, 48.95217827388218, 48.48173311778477, 45.65723133087158, 27.357639108385357, 42.85064547402518, 51.18646533148629, 57.02934101649693, 56.002442428043906, 54.474693366459434, 47.643742152622764, 45.167960030691965, 41.075234821864534, 42.894471236637656, 47.45107207979475, 44.910258293151855, 44.477889265332905, 43.86745180402483, 45.42427560261318, 45.3388648714338, 47.15592997414725, 50.772231101989746, 47.31260143007551, 53.55797583716256, 56.30200358799526, 54.31190749577114, 51.69328430720738, 49.51668119430542, 51.22567401613508, 49.341767242976594, 49.585148743220735, 52.08341523579189, 52.871247155325754, 55.49382734298706, 57.189048835209434, 53.853010245731895, 49.0416293825422, 45.608861446380615, 38.55879531587873, 36.43890339987618, 23.944994892392838, 21.13788444655282, 18.318020582199097, 12.339691502707344, 28.071246896471294, 33.68147952216012, 15.023339407784597, 11.357867615563528, 15.466080359050206, 5.2531169312340875, 1.3726015410252979, 0.4556717116917883, 0.446471916777747, 1.1024865210056305, 7.029109060764313, 22.572612762451172, 40.27744960784912, 42.60528026308332, 29.295543806893484, 23.529749700001307, 32.052356243133545, 47.7729161126273, 58.18250574384417, 53.58472292763846, 23.880737951823644, 3.655917150633676, 0.40546652568238123, 0.21486939090703214, 0.11751078441739082, 0.1366568984729903, 0.17349190477813992, 0.15255011564918927, 0.1549993556525026, 0.14637239357190474, 0.0969498162823064, 0.11534561988498483, 0.11672782285937242, 0.14443430756883963, 0.07596831928406443, 0.1034865105258567, 0.16234423938606465, 0.13691175622599466, 0.15404734387993813, 0.09444980150354759, 0.15806648321449757, 0.10871264830763851, 0.10888296738266945, 0.12155739084950515, 0.06856756497706686, 0.11660591725792203, 0.2585041730531624, 0.14571209757455758], [0.057034824176558425, 0.03837089406858597, 0.04223610773416502, 0.05147512536495924, 0.03232123529804604, 0.05605985077896288, 0.04152728630495923, 0.110274920905275, 0.09913659215505634, 0.0699697100956525, 0.09453370235860348, 0.0699828736750143, 0.05107685584308846, 0.025737959625465528, 0.008041559385934045, 0.06995962027992521, 0.04318081168457866, 0.06565793217825037, 0.05558973118396742, 0.0817722635609763, 0.05563363239967397, 0.03542287993643965, 0.03609183064794966, 0.06668471850986991, 0.007141997522142316, 5.37909254857472, 21.130404710769653, 45.79042134966169, 53.539510999407085, 49.43495648247855, 42.62501662118094, 32.653121812003, 23.609252725328716, 32.55050039291382, 54.130351066589355, 42.42697211674282, 13.45227701323373, 3.2586345715182166, 0.15753204189240932, 0.11647194730384008, 0.7230790512902396, 2.5317913336413245, 5.95802731173379, 5.755677529743739, 7.059447501386915, 14.01972336428506, 11.247312222208295, 4.840604552200862, 15.259145634514944, 20.67285020010812, 22.357449633734568, 27.355935062680924, 40.77688264846802, 45.09908948625837, 52.356924125126426, 53.9741381917681, 52.93856477737427, 52.83404650006975, 47.629227365766255, 51.607574803488596, 54.90942825589861, 51.02357176371983, 52.29093360900879, 49.53087636402675, 45.71379314150129, 41.62394796098982, 41.28667197908674, 40.39548907961164, 42.58143057141985, 45.9741838318961, 45.99804741995675, 46.92380108152117, 43.57403979982649, 39.83152117047991, 38.620724609919954, 38.940400804792134, 41.713478973933626, 48.26002304894583, 49.818403244018555, 48.9861410685948, 46.47913721629551, 48.73566893168858, 52.4164319719587, 51.023252146584646, 47.90904521942139, 46.91531038284302, 47.52415670667376, 41.32056181771414, 25.806342601776123, 34.83098602294922, 52.1176038469587, 53.70209884643555, 51.19963911601475, 47.940788064684185, 42.70870072501046, 39.16444199425833, 39.542326722826274, 37.19067069462368, 36.43245547158377, 37.04144770758492, 38.18185206821987, 39.01015724454607, 41.31737606866019, 39.944776807512554, 39.315068517412456, 41.68114900588989, 43.3788822719029, 46.40408277511597, 52.13406065532139, 51.156466484069824, 51.26503903525216, 50.81110279900687, 48.27777917044503, 47.333956718444824, 46.615770067487446, 44.71019533702305, 46.802020004817415, 50.93009417397635, 47.388649463653564, 43.60220084871565, 34.354648794446675, 26.137142862592423, 20.57754349708557, 21.788201093673706, 14.107536435127258, 16.345380101885112, 13.347710967063904, 6.127021397863116, 9.13115930557251, 10.358726211956569, 9.302003349576678, 9.383608204977852, 3.8806935463632857, 2.802288830280304, 1.775360494852066, 0.5570581427642277, 0.060198819397815635, 0.3504966939134257, 3.054052463599614, 14.614425761359078, 23.854218414851598, 34.38809047426496, 27.44550255366734, 23.101108380726405, 30.42586980547224, 40.34224155970982, 45.9701121875218, 42.5152941431318, 20.953050204685756, 7.091431362288339, 0.27252153945820673, 0.010850449242363018, 0.06683271378278732, 0.08475972432643175, 0.03631243256053754, 0.04390500193195684, 0.05732143736843552, 0.06809249546911035, 0.042998146664883406, 0.015080707114455956, 0.02117992947543306, 0.04452967144814985, 0.09541783348790236, 0.0066148881950149575, 0.012982972847696925, 0.032980662770569324, 0.03344009204634598, 0.030225040457610573, 0.04725312780854957, 0.013230411668441125, 0.03442347249282258, 0.09662164282053709, 0.023438796301239302, 0.015527023700997233, 0.03661921520584396, 0.04332109879968422, 0.07620512800557272, 0.026985890697687864, 0.025881812442094088, 0.06420100892760924, 0.024506564451647655, 0.025044215244374106, 0.049105033078896146, 0.07516656230602946, 0.023455001413822174, 0.047225440187113624, 0.07545318906860692, 0.028309765105534877, 0.0569394017968859, 0.053352926924292526, 0.02766174211033753, 0.07037167424069983, 0.09495310485363007, 0.02022120699153415, 0.11729648948780128, 0.03660459616886718, 0.06696221897644655, 0.008852312041978751, 0.01721227907442621, 0.06691236022327628, 0.036633114995700974, 6.530269656862531, 26.525557586124965, 52.44236264910017, 58.60353183746338, 54.49792814254761, 46.061717237745015, 34.97770765849522, 24.81261123929705, 28.650705814361572, 45.202388354710166, 35.00613273893084, 15.634435210909162, 3.515332511493138, 0.28567990767104284, 0.013844883651472628, 0.7742792953337941, 3.229680125202451, 7.266525098255702, 9.055667996406555, 12.420672757284981, 11.43362729890006, 9.380046384675161, 8.352325303213936, 15.020653929029192, 19.742535046168737, 17.884657961981638, 27.957673379353114, 39.6909556388855, 45.77182102203369, 52.61316326686314, 53.699291774204795, 52.64223452976772, 51.77580458777291, 48.54203653335571, 52.13991798673357, 56.14204910823277, 54.70559242793492, 53.96343796593802, 51.61070496695382, 47.07223197392055, 43.51383365903582, 42.89219570159912, 42.58438702992031, 44.490260532924104, 46.67769241333008, 49.1155686378479, 49.00224699292864, 46.387049266270225, 41.67827592577253, 41.07205254690987, 40.04964596884591, 43.664335114615305, 48.50579125540597, 50.98288311277117, 49.22707680293492, 46.75690535136631, 50.4812023299081, 55.101980209350586, 51.82922581263951, 46.813005106789724, 46.02708394186837, 46.320805140904014, 43.3592084475926, 31.20957796914237, 37.45964241027832, 52.81293092455183, 55.306747095925466, 53.79210581098284, 50.35341453552246, 43.61864723478045, 40.54843977519444, 42.85787854875837, 39.283513273511616, 39.50380938393729, 39.46682064873831, 40.70351314544678, 42.16310385295323, 42.96771567208426, 42.03796679633004, 40.891632148197715, 44.91916935784476, 45.49537304469517, 47.73693486622402, 52.32822111674717, 53.391271182468955, 53.03194161823818, 50.66480500357491, 50.41831071036202, 48.77063226699829, 47.78062513896397, 47.76399115153721, 50.52773094177246, 52.37797021865845, 52.27003690174648, 46.05112470899309, 35.95597927910941, 27.025492634092057, 23.885148320879253, 22.14032711301531, 17.92251001085554, 14.512945583888463, 12.808596764292036, 9.093896985054016, 11.814424191202436, 9.29043894154685, 11.375438741275243, 15.114520617893763, 7.0545342564582825, 5.7567188910075595, 4.0978112901960095, 0.9239347534520286, 0.05184010935149022, 0.3976115328924996, 3.0784621366432736, 16.864912543978008, 27.169033731733048, 36.83800097874233, 26.91569893700736, 23.66342782974243, 34.471003328050884, 47.0818760735648, 50.707626751491, 51.28298623221261, 25.992371933800833, 8.180961012840271, 0.2579342579202992, 0.015783112995060425, 0.05367295118048787, 0.03276236109169466, 0.04492074849882296, 0.028424666529255252, 0.07286562291639191, 0.059901200367936065, 0.05010855923007641, 0.03071936678939632, 0.0263054947967508, 0.04765743289941123, 0.028825880893106972, 0.0859979557405625, 0.030292215424456766, 0.05951153127742665, 0.08143631408789329, 0.03582334791177085, 0.10592822557581322, 0.033349090322319946, 0.004364468706106501, 0.06693976625267949, 0.01992849207350186, 0.08466600506965603, 0.03959110359262143, 0.0641694977613432, 0.13296123035252094, 0.15355398106787885, 0.08646242653152772, 0.18216024392417499, 0.12340464815497398, 0.10250475177807467, 0.11666189639696053, 0.28414299871240345, 0.2391910579587732, 0.19533873748566422, 0.18906669904078754, 0.22688484830515726, 0.14531234545367105, 0.1747260106993573, 0.12473837658762932, 0.18039557790117605, 0.2831385226121971, 0.17616027088037559, 0.22844773158431053, 0.18399357769106114, 0.25928204559854096, 0.14419372619262763, 0.2344985269010067, 0.16874081614826406, 0.13526006628360066, 8.685239553451538, 31.605434213365825, 59.36078820909773, 65.97784260341099, 62.21524715423584, 52.41100195475987, 43.51819017955235, 34.169586999075754, 43.45061894825527, 64.07593304770333, 50.04869086401803, 17.61611703463963, 4.204460493155888, 0.5516783371567726, 0.45580280465739115, 1.1613639273813792, 5.144051492214203, 9.134095788002014, 16.428339856011526, 18.504150663103374, 26.074252980096, 23.08364929471697, 13.445818662643433, 22.162198305130005, 26.69695748601641, 24.427648033414567, 33.37627989905221, 47.144969190870015, 46.29477718898228, 53.685134819575715, 53.40077631814139, 52.29352528708321, 52.50631386893136, 50.12517663410732, 53.40574428013393, 58.59404754638672, 57.09004395348685, 56.75527279717581, 54.352926186152864, 50.13912514277867, 46.17068931034633, 45.35990054266793, 45.11496959413801, 46.65198407854353, 49.60728570393154, 50.373585156032014, 50.30748694283621, 49.08372504370553, 43.5346018246242, 42.67290013177054, 41.69131074632917, 45.96305629185268, 51.920059612819124, 53.60269444329398, 51.88064595631191, 49.73701204572405, 51.27885900224958, 55.796747956957134, 52.37549665996006, 48.025434494018555, 46.43562759671892, 48.003797803606304, 45.99296481268746, 31.44955137797764, 40.65419830594744, 54.059211935315815, 57.336732796260286, 56.444340910230366, 52.568972723824636, 47.82738651548113, 43.03792027064732, 44.06317908423287, 40.684558459690635, 40.65356254577637, 41.56580890927996, 43.14058337892805, 43.27940838677542, 45.62772927965437, 44.40466914858137, 43.20254046576363, 47.3109894480024, 48.23770890917097, 51.59302527563912, 55.26689917700631, 55.5751872743879, 55.049087047576904, 51.70866067068917, 48.644004821777344, 47.72309405463082, 47.958453859601704, 47.88860361916678, 50.60188906533377, 57.02297299248831, 55.073586395808626, 50.49500492640904, 39.59579311098371, 30.947130611964635, 25.292238439832413, 27.252811636243546, 20.52827034677778, 19.973088434764318, 16.540016514914377, 9.832123109272548, 17.042206253324235, 17.8251987525395, 17.882068020956858, 18.418182338987076, 11.134739245687213, 8.868579064096723, 4.072074294090271, 1.3968465200492313, 0.1601415654378278, 0.59737571648189, 4.124134974820273, 18.850615637642996, 32.7724849155971, 46.67324556623186, 39.19265168053763, 33.776725428445, 42.33673586164202, 51.78748798370361, 57.79671743937901, 57.15486369814192, 35.39750392096383, 10.43043075289045, 0.8116520270705223, 0.1355611051299742, 0.18079030886292458, 0.20054813580853598, 0.14298251404293946, 0.1044871054057564, 0.1380578561552933, 0.16415100172162056, 0.12228699241365705, 0.08822946064174175, 0.11244864854961634, 0.16195469243185862, 0.17132200407130377, 0.13401156184928759, 0.10692607917423759, 0.1730136868676969, 0.10544219094195537, 0.0815253107409392, 0.13225753525538103, 0.14079563638993672, 0.12326598273856298, 0.17123618296214513, 0.14237522520124912, 0.17163852708680288, 0.141657877979534, 0.188049262921725], [0.038888969126024416, 0.11081717895077807, 0.04118436827723469, 0.011577114446221717, 0.056217376076217206, 0.024210511141323617, 0.025906953860872557, 0.05980372202715703, 0.024863604489447813, 0.042215344562594376, 0.008448647318540939, 0.03582871512376836, 0.019513515323134403, 0.03916738561487623, 0.020016223258738006, 0.0448669610278947, 0.03995271526010973, 0.07962079186524663, 0.06637453979679517, 0.041269242830042324, 0.07874092872121505, 0.06659997627139091, 0.09450780946229186, 0.02199276862666011, 0.28250992777092115, 8.690716470990862, 22.763245276042394, 46.333687101091655, 50.45071363449097, 45.18704325812203, 36.10997915267944, 20.897520201546804, 22.299965449741908, 31.097138745444163, 34.78430107661656, 25.919679880142212, 9.92597850731441, 0.9833009221724102, 0.06825322684432779, 0.06471858865448407, 0.24214336382491247, 2.081736751965114, 7.035912215709686, 7.89114556993757, 9.116157276289803, 7.933394091469901, 4.412859984806605, 8.968131984983172, 12.299157449177333, 34.85573203223092, 24.27979905264718, 30.53024217060634, 48.46333081381661, 54.82853732790266, 56.10051277705601, 54.15186268942696, 54.75046042033604, 51.25587436131069, 52.23018898282732, 53.729846477508545, 50.13294472013201, 49.57283306121826, 46.07193456377302, 42.585748876844136, 40.83838810239519, 41.55984388078962, 40.86195291791643, 42.711949007851736, 46.55494901112148, 50.221273694719585, 51.545409270695274, 48.91709681919643, 43.49030358450753, 39.02661405290876, 36.42460748127529, 42.63871152060372, 51.42805419649397, 51.36685446330479, 52.21569504056658, 51.30814218521118, 53.37347337177822, 52.053645678928916, 54.09781960078648, 51.57030814034598, 49.916511808122905, 50.121313435690745, 48.00782775878906, 38.87892314365932, 24.71977809497288, 35.94027287619454, 55.05741098948887, 51.314979212624685, 50.731240204402376, 43.53652647563389, 40.74311440331595, 38.0822948047093, 39.616220814841135, 38.366222517830984, 39.77320146560669, 38.448252950395855, 38.97079569952828, 37.12150485174996, 38.831710134233745, 39.9824777330671, 38.819919041224885, 37.48122698920113, 39.19457285744803, 43.60696036475045, 49.8401962688991, 48.703894819532124, 50.85871185575213, 50.16011217662266, 48.026806763240266, 46.88420329775129, 49.39294072559902, 48.938733509608674, 48.43294286727905, 42.03273132869175, 42.864569664001465, 46.40291895185198, 45.15637738364083, 44.554809297834126, 42.037167753492085, 31.33419738497053, 22.476925645555767, 14.320188658578054, 13.783856340817042, 13.560546449252538, 11.050408959388733, 7.06387654372624, 11.277665427752904, 13.827764613287789, 5.5867646506854465, 4.630622608321054, 2.158093546118055, 0.5941167399287224, 0.12615882179566792, 0.1436009851417371, 0.6585655159183911, 7.16703644820622, 24.34356267111642, 32.92407029015677, 27.501923663275583, 14.298601474080767, 21.998964275632584, 25.89964474950518, 41.428505556924, 42.86904082979475, 33.34879629952567, 11.124299577304296, 0.3528094398123877, 0.08535976641412292, 0.07414777590227978, 0.04125214714024748, 0.019405713072046638, 0.048078450307782204, 0.04137018169941647, 0.04040392408413546, 0.013912305435431855, 0.06656571025294916, 0.019129847874864936, 0.018185724071892242, 0.04412834173334496, 0.038130115917218585, 0.01537925234463598, 0.01502177634808634, 0.013123785827441939, 0.03296312264033726, 0.045100071733551364, 0.009349583215745432, 0.038020559653107605, 0.04017084051987954, 0.04755118788619127, 0.014157071676371353, 0.019667422332401787, 0.026486314201195325, 0.05477886826598218, 0.025022512301802635, 0.02545449653241251, 0.039772995082395415, 0.03087444936058351, 0.038624357432127, 0.03869844667081322, 0.007624797240298773, 0.12261013793093817, 0.04726752632164529, 0.00401731619578121, 0.014839152040492212, 0.03392475264679108, 0.020417583507618735, 0.058131234986441474, 0.023653518707890595, 0.006536497044310505, 0.03830140869000128, 0.04369334650358983, 0.13489092966275557, 0.07805051933974028, 0.046511828300676177, 0.011720389659915651, 0.035469742957502604, 0.40557549840637613, 10.555855291230337, 27.78084519931248, 52.599061897822786, 57.02417155674526, 49.986407211848665, 41.51690748759678, 24.89743137359619, 26.277270657675608, 33.36150108064924, 37.98467261450631, 29.619649478367396, 10.223997167178563, 1.199186554976872, 0.12574819954378263, 0.13821471988090447, 1.9803581918988908, 4.737012122358594, 9.261438029153005, 13.95943558216095, 11.070390241486685, 9.920201080186025, 8.674256188528878, 8.996855837958199, 11.332465870039803, 22.4034640789032, 23.700691018785747, 32.46257093974522, 45.89367505482265, 56.37301417759487, 54.624322823115754, 55.00217628479004, 53.98920883451189, 52.35125092097691, 51.11152900968279, 55.55167804445539, 52.515033858163015, 52.27147170475551, 48.28366082055228, 45.956754275730674, 43.107367515563965, 43.75723252977644, 43.34775086811611, 45.18628590447562, 47.65335151127407, 51.22029958452497, 52.841533184051514, 51.338047231946675, 45.3145044871739, 39.54357739857265, 38.09995365142822, 43.16253968647548, 52.62286990029471, 53.76511205945696, 53.68145227432251, 55.02867671421596, 54.021695137023926, 52.83027015413557, 55.13683932168143, 52.175687313079834, 48.01553678512573, 49.46471561704363, 48.73891026633126, 42.22329609734671, 27.97916763169425, 38.89942380360195, 54.996280738285606, 52.8921160697937, 51.321958678109304, 46.57377862930298, 43.608270100184846, 40.748669488089426, 41.9233249936785, 41.12667233603341, 41.38766404560634, 42.103616850716726, 40.11908279146467, 39.058832849775044, 40.69647809437343, 41.1558130809239, 42.0653600692749, 39.592339856284006, 43.18057026181902, 46.87379142216274, 51.98093972887312, 51.96185997554234, 52.04931000300816, 50.45293705804007, 48.24575144904, 47.67364025115967, 48.88227244785854, 49.99503340039934, 51.65325920922415, 48.77661466598511, 48.501083850860596, 50.91280010768345, 51.13070256369454, 47.464016573769705, 42.797870431627544, 33.90886974334717, 24.255073887961252, 19.590692588261195, 11.441724555832998, 5.431216631616865, 7.364840371268136, 6.753339401313236, 8.907645310674395, 12.177432826587133, 9.369186350277491, 7.375869768006461, 4.282398436750684, 1.044342258146831, 0.23155344064746583, 0.14334755231227192, 1.190696724823543, 8.373349683625356, 24.21662081990923, 38.196846280779155, 34.554954937526155, 19.012065717152186, 25.93592303139823, 32.3340014730181, 46.69118928909302, 48.14572518212454, 39.90826402391706, 14.21195570060185, 0.5006116830876896, 0.06913730369082519, 0.15225567216319696, 0.02587460300752095, 0.060012378330741606, 0.025219368881412914, 0.06776466806020055, 0.05045438478035586, 0.04145088665453451, 0.02255560494294124, 0.02573994094771998, 0.04372582118958235, 0.007425019567433212, 0.009569378519829894, 0.01438771081822259, 0.05583591725943344, 0.04391707646261368, 0.004188194214033761, 0.00382158810472382, 0.08867236758981432, 0.01748848014644214, 0.018454140650906732, 0.011432895220683088, 0.05333679136154907, 0.038388278135763745, 0.01877045671322516, 0.19963048504931585, 0.14046366991741316, 0.12679454125463963, 0.1151780081646783, 0.10953079869172402, 0.22918576055339404, 0.13002363512558596, 0.17073885750557694, 0.2554178972329412, 0.0786063548709665, 0.1180862228253058, 0.15115181782415935, 0.1218012020524059, 0.1249726340174675, 0.0799136475792953, 0.08068183742995773, 0.0739982132134693, 0.15049481950700283, 0.11616759720657553, 0.17628183721431664, 0.17993986021195138, 0.10351470365588154, 0.15464026134993347, 0.10953207433755908, 0.5680790713855198, 13.606348974364144, 35.26508515221732, 61.09614249638149, 63.28044073922293, 56.304734230041504, 46.311640466962544, 30.90579230444772, 32.17888988767351, 42.615563596997944, 44.59390681130545, 31.337904248918804, 11.992672409330096, 1.4450748349939073, 0.25777548072593554, 0.2853707399751459, 1.768078999859946, 4.944437563419342, 15.419141803468976, 19.203533751623972, 18.02002797807966, 13.936000176838466, 15.005746568952288, 20.30335021018982, 17.542452233178274, 38.647624560764854, 27.862420524869645, 32.2438451222011, 53.54927321842739, 59.44980158124651, 57.290443897247314, 56.675809723990305, 54.27288293838501, 52.916351386478965, 52.709055355616975, 55.056049142565044, 55.39664288929531, 54.89609118870327, 50.6341495513916, 46.49753604616438, 46.39210408074515, 45.775031089782715, 44.97872584206717, 47.38645035879952, 50.51044382367815, 53.4827754838126, 55.14125837598528, 52.36633198601859, 46.59624562944685, 41.727132184164866, 39.81234066826956, 45.67522716522217, 55.7883232661656, 55.30999885286604, 56.838470527103965, 55.517548492976594, 56.2648480960301, 54.87256458827427, 58.23156349999564, 52.279489925929475, 49.335791792188374, 48.56757116317749, 49.25953878675188, 43.865096364702495, 31.58095223563058, 41.36414091927664, 55.85740573065621, 56.26394830431257, 54.512484618595664, 48.968072278159006, 44.87487806592669, 42.745178767613, 43.423260416303364, 42.08046892711094, 43.455861364092144, 43.105557509831016, 42.57760558809553, 41.32202788761684, 42.79034553255354, 44.25384112766811, 44.5902555329459, 42.41690417698452, 45.045289584568565, 49.64637279510498, 53.84945624215262, 53.316880294254844, 54.39276368277413, 52.541496072496685, 49.35196025030953, 47.61095012937273, 49.64327389853341, 51.159339564187185, 52.55979067938668, 49.27118396759033, 50.64095878601074, 53.87717955453055, 54.11127131325858, 51.549845695495605, 48.145836353302, 39.170146465301514, 28.194858823503765, 20.0209094115666, 17.272674526487076, 22.008881092071533, 19.496409007481166, 15.940039566584996, 24.233958312443324, 24.971137864249094, 15.089057207107544, 12.630696824618749, 6.3001813633101325, 1.3637002472366606, 0.49993173671620234, 0.38542949514729635, 1.2132446063416344, 9.194869944027491, 31.587282044546946, 42.80464145115444, 39.13579109736851, 24.62593572480338, 34.79599142074585, 37.04762118203299, 53.47259637287685, 56.040799958365305, 46.66279894965035, 18.308074235916138, 1.0894877442291804, 0.16514764752771172, 0.1719361732580832, 0.12736010019268307, 0.12697029539516994, 0.08735832345804997, 0.08589592442980834, 0.14513973971562727, 0.13611773454717227, 0.14319129926817759, 0.09478627344859497, 0.12639989171709332, 0.11461044076297965, 0.18396465852856636, 0.11903271132281848, 0.10928451083600521, 0.12261959670909814, 0.157989252358675, 0.1500405945948192, 0.22790145661149705, 0.07025122748953955, 0.08631757287574665, 0.10848341882228851, 0.11774744386119501, 0.14049936085939407, 0.055984692847622294], [0.017809783441147635, 0.009314169624953397, 0.031164726641561304, 0.028604016905384402, 0.03301393812788384, 0.03686645979593907, 0.057449924759566784, 0.01863230698342834, 0.02688417999473001, 0.005490540402076606, 0.024098605449710573, 0.08838769500809056, 0.047682640475354025, 0.03748793001951916, 0.18769916599350317, 0.02663105250602322, 0.08279502617993525, 0.058702581828194, 0.03174727948914681, 0.03794901831341641, 0.08741736957537276, 0.0468132335559598, 0.049010519936148605, 0.0696284816201244, 0.5219711512327194, 9.92286137172154, 30.4614862714495, 51.01335096359253, 48.04977750778198, 40.697843415396555, 25.63227459362575, 12.593607340540204, 21.325932230268204, 35.88394383021763, 25.36939123698643, 16.392702545438492, 3.83470732825143, 0.2634994935776506, 0.13914404144244535, 0.29431605711579323, 2.8708469229085103, 5.838876128196716, 8.220779401915413, 7.342347315379551, 12.596004469054085, 10.815105608531407, 6.263709834643772, 6.326465095792498, 17.758412667683192, 28.896899597985403, 27.879936933517456, 45.84581586292812, 44.48408358437674, 50.58135713849749, 51.51697029386248, 58.081642218998496, 48.470400605882915, 48.969423702784944, 49.92522137505667, 49.64387839181082, 45.45756789616176, 49.035917963300435, 44.021330084119526, 41.339686734335764, 39.136267048971995, 41.56344652175903, 42.39554194041661, 46.0946169580732, 50.92885739462716, 55.33435228892735, 50.41538551875523, 48.24473353794643, 41.155493463788716, 35.218890053885325, 39.488047395433696, 48.80986179624285, 49.81998743329729, 53.82228531156267, 52.983067989349365, 54.86707551138741, 53.04625143323626, 53.247738770076204, 53.98713479723249, 51.568213258470806, 45.61797053473336, 50.727859905787874, 39.341926779065815, 40.251828125544954, 29.35254682813372, 39.30630683898926, 54.58688940320696, 48.51417078290667, 50.86231797082083, 38.749978474208284, 38.580491065979004, 37.454073429107666, 40.21899788720267, 41.56457560403006, 44.933586869921, 46.83911296299526, 46.44127648217337, 43.21010357992989, 40.08118731634957, 37.96971314293997, 36.528500420706614, 35.32979719979422, 38.799939496176584, 40.523301192692344, 45.62605823789324, 50.266902514866416, 51.13710185459682, 51.21747861589704, 50.57290118081229, 47.39698730196272, 45.646058627537315, 44.88082224982125, 50.421777861458914, 46.039302349090576, 49.20454032080514, 50.34747035162789, 49.8486522265843, 46.263378279549734, 47.72451843534197, 40.86400611060006, 34.74177115304129, 32.89225101470947, 22.61264828273228, 9.612536583627973, 9.299713918140956, 2.9032856736864363, 6.906540666307722, 11.301388314792089, 4.998251795768738, 6.302429974079132, 6.159881600311824, 0.44875331435884747, 0.21167345025709697, 0.07996507374835865, 0.31347661039658953, 5.301951042243412, 17.867442062922887, 30.24178770610264, 27.639907939093455, 19.29249153818403, 21.562058074133738, 30.127229281834193, 40.03449542181832, 42.10708052771432, 36.31895317350115, 13.775752135685511, 0.7170718450631414, 0.06649469477789742, 0.008835139168825532, 0.009171268453688493, 0.023263422140319432, 0.0606428323579686, 0.04798289222110595, 0.02676145506224462, 0.03923680653263416, 0.016308587476877228, 0.025029333275077597, 0.02982470140393291, 0.029183702942516123, 0.052405071178717275, 0.061068477375166755, 0.050184758712670634, 0.03523276799491473, 0.04017877937959773, 0.0482472833911223, 0.016300587549007366, 0.026355636838291372, 0.03847579897514411, 0.029368953180632422, 0.02193044518519725, 0.02160436670029802, 0.01984724259403135, 0.023808105948514173, 0.03840518044307828, 0.013815436928000833, 0.07875087604458843, 0.05128987512684294, 0.059888552475188456, 0.008920492088821317, 0.036771922904465876, 0.11262468767485448, 0.03791421625230994, 0.02262361959687301, 0.052202559009726555, 0.02482316380233637, 0.026208835787006786, 0.10806053544261626, 0.025388310530356, 0.01267577799236668, 0.09020987365927015, 0.027083616703748703, 0.04420758783817291, 0.08168999797531537, 0.030649504823876277, 0.046779642679861615, 0.06754139611231429, 0.7602852976747921, 11.908737301826477, 35.934808118002756, 57.47859069279262, 53.001008238111226, 46.47345706394741, 32.14725473948887, 19.90428216116769, 20.01532653399876, 36.37189497266497, 28.159643615995133, 15.79094512122018, 5.1958833166531155, 0.36851681981767925, 0.08432221173175744, 0.641365576003279, 2.159791946411133, 6.166484126022883, 10.842415503093175, 9.003896968705313, 9.939209614481245, 14.354171429361616, 8.02449105467115, 8.23719538961138, 14.748932463782173, 18.125628437314713, 28.84895702770778, 41.28231198447091, 46.873093128204346, 52.639382294246126, 54.83023616245815, 56.904912676130024, 52.72198595319475, 50.67983743122646, 51.0195973941258, 52.84418739591326, 48.940578256334575, 49.30053315843855, 46.35928079060146, 43.89197547095162, 40.10925456455776, 43.070458684648784, 45.10971328190395, 47.7287220954895, 52.57580280303955, 55.88666806902204, 53.469674655369346, 51.12549141475132, 43.941519601004465, 37.457905360630576, 40.72988850729806, 50.99090133394514, 52.67086110796247, 55.400523458208355, 55.755812644958496, 56.20736217498779, 54.80502462387085, 54.78691414424351, 54.89501074382237, 52.475262369428364, 46.82540764127459, 49.76553092684065, 41.44042519160679, 42.72594615391323, 32.101966381073, 40.277949878147666, 56.948380606515066, 50.774235657283235, 51.41893815994263, 41.33757100786482, 40.75878259113857, 38.96076250076294, 41.788939884730745, 43.59434243610927, 46.88861192975725, 48.289858613695415, 47.89746257237026, 44.56046513148716, 42.19893571308681, 39.67831686564854, 37.61352069037301, 37.74006475721087, 41.00800405229841, 43.29322140557425, 47.68444469996861, 51.9028628213065, 53.077129227774485, 53.77870273590088, 52.046742643628804, 48.5071565764291, 46.96757125854492, 45.03057677405221, 50.01424169540405, 47.11318465641567, 50.91318225860596, 51.531974928719656, 50.18339211600167, 49.5372930254255, 52.32271466936384, 45.047068323407856, 38.11933217729841, 32.2781205858503, 18.765416826520646, 8.971917016165596, 11.18780698095049, 11.285291075706482, 12.727948154721942, 11.071981378964015, 11.005122338022504, 7.577812211854117, 4.357525834015437, 2.9212780339377264, 0.1238866387201207, 0.17628805259508745, 0.4611646426575524, 4.505442125456674, 18.851701293672832, 32.554450443812776, 27.851254769733973, 22.596252271107264, 26.150808232171194, 32.83081504276821, 46.96036945070539, 48.096184526171, 42.47610630307879, 17.022739137922013, 0.9990341407912118, 0.1016211634767907, 0.024531030728082572, 0.039126982247190814, 0.04467248271352478, 0.03780994577599423, 0.025113118779180304, 0.04036279468398009, 0.009976631845347583, 0.0263833091926894, 0.022112489345350435, 0.0031004510528873652, 0.020762482857597724, 0.017206888113703047, 0.054722380225679705, 0.058412413112819195, 0.012231297691219618, 0.04223408569980945, 0.03683145756700209, 0.017940713558346033, 0.016851836183507527, 0.019541090986292278, 0.030269379328404154, 0.07078444066324405, 0.04791419394314289, 0.014648599051205176, 0.119278151009764, 0.08548847093646016, 0.05834417284599372, 0.14029129488127573, 0.17486183983939035, 0.2611149043909141, 0.0910129469952413, 0.10768175683915615, 0.24431562583361352, 0.08475035375782422, 0.08158069955451147, 0.12928506332848752, 0.11273980114076819, 0.15456749525453362, 0.27790875466806547, 0.09582791291177273, 0.14199365781886236, 0.2036167968596731, 0.11081287025340966, 0.10753530184073107, 0.12454894318112306, 0.07821943384728261, 0.14696666811193737, 0.14659637798156055, 1.3031609186104365, 15.125865289143153, 43.83225570406233, 64.28163446698869, 59.335607937404085, 50.785665443965364, 38.054790360586985, 22.314994403294154, 31.54813241958618, 46.45782361711775, 36.05595690863473, 19.95491021020072, 5.642290311200278, 0.47883326028074535, 0.36031859687396456, 0.5441496382866586, 5.543692767620087, 12.236115574836731, 16.833916630063737, 15.677425452641078, 24.330025843211583, 27.963152033942087, 15.116177763257708, 10.791638936315264, 26.699722869055613, 33.949683461870464, 31.938642024993896, 50.00786672319685, 48.429788385118755, 56.99533305849348, 58.055280753544395, 61.60557052067348, 53.74831131526402, 52.900050912584575, 51.148681027548655, 54.97410556248256, 49.067268235342844, 53.759421484810964, 47.855620520455496, 46.49362768445696, 42.92947278703962, 45.538622106824604, 47.866689000810894, 50.73550639833723, 54.46336085455758, 57.86816923958914, 53.906674657549175, 53.524822507585796, 45.11907597950527, 38.784410272325786, 43.73238229751587, 54.368476254599436, 54.54297678811209, 58.9218635559082, 56.428714411599294, 57.51777853284563, 56.39467518670218, 55.66893931797573, 56.02270337513515, 53.22446230479649, 46.49949891226632, 50.15423400061471, 42.540213857378276, 45.35641949517386, 36.72312988553728, 43.77368586403983, 58.193421363830566, 52.86815868105207, 53.803063120160786, 43.65284974234444, 42.18891641071865, 41.54193489892142, 43.819724627903526, 45.37311601638794, 48.953036376408164, 51.63196645464216, 50.82847676958357, 47.285010133470806, 45.053745542253765, 42.56847218104771, 39.032704148973735, 40.1675568989345, 43.431396756853374, 45.43021283830915, 50.10633659362793, 54.80723762512207, 55.547853061131065, 55.3257087298802, 53.90264817646572, 49.379131180899485, 46.37734958103725, 45.04875673566546, 51.57583543232509, 48.36205039705549, 51.902088097163606, 53.25643444061279, 52.321953841618125, 51.338818481990266, 53.36901610238211, 48.16425950186593, 41.90993234089443, 36.70425162996565, 26.551856517791748, 12.515797938619341, 17.54813759667533, 12.748923897743225, 15.546570028577532, 21.135053055627004, 14.7165173803057, 15.361193827220372, 12.89054034437452, 3.528978990656989, 0.2733916656247207, 0.37731239785041126, 0.7777827616248811, 6.763301815305438, 21.731746980122157, 38.76164102554321, 38.83348887307303, 31.775581700461252, 31.186589854104177, 40.52143212727138, 52.42117411749703, 55.40554700578962, 48.70940126691546, 23.918338128498622, 2.2344262387071336, 0.23280066943594388, 0.14813363977840968, 0.14093644597700664, 0.13159106458936418, 0.12588265804307802, 0.12341954878398351, 0.13856436897601399, 0.04291954177564808, 0.16444635444453784, 0.1227192192205361, 0.09595688206276723, 0.08305459296596901, 0.11670764322791781, 0.227734808410917, 0.1675261841820819, 0.10299680501754795, 0.15673856304160186, 0.13324607935334953, 0.13686522229441575, 0.05665589629539421, 0.09734663713191237, 0.09059686932180609, 0.1268338691443205, 0.07434830335634095, 0.0819996881431767], [0.04856630341549005, 0.018602610898337195, 0.03953406593895384, 0.029321828923587288, 0.057374946640006134, 0.030980897934309075, 0.05338485199691994, 0.08898291949714933, 0.03607894866062062, 0.09772367190037455, 0.07540057546326093, 0.022458969681922878, 0.0337080658812608, 0.04457041747601969, 0.026752182881214788, 0.02521827644003289, 0.08620390468942267, 0.06647834886929818, 0.005453870249246913, 0.0999482421736632, 0.039845510119838376, 0.019788496728454317, 0.02471015040230538, 0.015969089265646677, 1.0857061871460505, 12.584766626358032, 37.35076413835798, 49.689680916922434, 51.67408990859985, 44.716090883527485, 22.410422699792043, 13.887440953935895, 33.30260814939226, 32.83711705889021, 25.907763719558716, 10.9589524269104, 1.2756620113338744, 0.10116605646908283, 0.013780118332111409, 0.8639520949551037, 1.8828048322881972, 3.5653860313551764, 8.446191992078509, 14.876364162990026, 6.860382914543152, 10.738087432725088, 6.760625890323094, 7.847056644303458, 11.939259001186915, 18.12758435521807, 27.417544739586965, 29.11489585467747, 34.87109102521624, 46.32037435259138, 48.63764374596732, 50.04152379717146, 45.21203940255301, 49.149350779397146, 49.58577755519322, 48.56478146144322, 47.963744912828716, 49.225600310734336, 41.962221009390696, 39.31677082606724, 38.667340074266704, 43.390124457223074, 45.16076169695173, 49.47647544315883, 52.660786220005576, 53.281038011823384, 52.18403557368687, 47.63657855987549, 39.8843309538705, 37.54430621010916, 45.7584422656468, 52.31458527701241, 52.27489716666085, 54.46187046595982, 48.24505662918091, 48.971793038504465, 49.38299090521676, 52.05246795926775, 50.39597225189209, 51.17753342219761, 48.78408397947039, 51.79005881718227, 37.84346090044294, 40.589930943080354, 31.982599803379603, 50.12284203938076, 53.405216217041016, 48.82571063722883, 47.55579532895769, 40.3309576851981, 37.16853025981358, 40.54607391357422, 44.58889021192278, 47.564980847494944, 50.60608925138201, 51.47644492558071, 52.419162614004954, 50.70350299562727, 47.703531401497976, 45.453437192099436, 37.691698346819194, 36.83813646861485, 37.52594559533255, 39.85283129555838, 40.824661936078755, 45.071849073682515, 49.87240811756679, 49.62365913391113, 52.961740493774414, 48.45902293069022, 46.360896246773855, 46.851817744118826, 45.66762236186436, 49.58564901351929, 50.8913197517395, 48.41921322686331, 53.183846609933035, 52.09984425136021, 49.60050426210676, 46.16143430982317, 37.82094178880964, 34.91489941733224, 15.51251517023359, 9.309296352522713, 8.187665155955724, 5.5125861167907715, 8.108645030430385, 7.411073684692383, 10.181797283036367, 5.185340293816157, 0.4988329442484038, 3.174687087535858, 0.4420146202402455, 0.12937661127320357, 0.18099057168832847, 1.4531958677939005, 10.33895684991564, 30.33708224977766, 45.119121142796104, 22.197550739560807, 16.396501473018102, 25.91094946861267, 35.07779993329729, 43.72919307436262, 40.8263955116272, 19.595012630735123, 3.1046596680368697, 0.030977291520684958, 0.049561157889131985, 0.06532695636685405, 0.09835136429007564, 0.04325601711337056, 0.03155220406396048, 0.03815774925585304, 0.06683536006936006, 0.019304127898067236, 0.029062441949333464, 0.08190090022981167, 0.1138247854209372, 0.01530578566182937, 0.052182355629546304, 0.058656509300427775, 0.03180651220359972, 0.02463762857951224, 0.03870809883145349, 0.034751486498862505, 0.07141539002103464, 0.03028865311560886, 0.04574536192896111, 0.01779807871207595, 0.06082849989512137, 0.04559964653370636, 0.033614736782120805, 0.039229315506028276, 0.006771786271461419, 0.025132401048072746, 0.061691684648394585, 0.0029762702387025847, 0.15452569749738487, 0.0593641602567264, 0.06316164255674396, 0.0758832920608776, 0.08291137457958289, 0.015442493504711559, 0.015537315380892583, 0.03222436085343361, 0.020836638253448263, 0.03688206610136798, 0.06955431774258614, 0.028333001537248492, 0.028970480098256042, 0.039623184728303125, 0.07160832466823713, 0.05587804749874132, 0.020936698419973254, 0.02899673261812755, 1.8176094506468092, 16.040468829018728, 44.44875546864101, 56.482076576777864, 57.95754391806466, 48.08039127077375, 26.134783949170792, 13.523707100323268, 28.35240922655378, 36.000183718545095, 27.432632752827235, 11.757150190217153, 1.402345476405961, 0.1528544250343527, 0.1721983320478882, 0.5794964815889085, 3.0715894997119904, 6.420673983437674, 7.819601706096104, 10.847863759313311, 12.107909151485988, 12.823439853531973, 9.693734969411578, 8.786852615220205, 13.102634106363569, 18.744061538151332, 25.968056712831768, 30.857012476239884, 38.05878904887608, 48.04347549165998, 55.03193541935512, 53.55868107931954, 49.71472569874355, 50.422712394169395, 50.54754720415388, 50.41680295126778, 50.65117263793945, 50.799155371529714, 44.970214298793245, 41.60272816249302, 40.422493253435405, 45.742162636348176, 46.3058317729405, 51.009984561375205, 54.68442474092756, 54.73995474406651, 54.625736781529014, 50.50094563620431, 42.01578119822911, 39.524403844560894, 46.612716334206716, 54.84865583692278, 53.41923768179757, 56.49080351420811, 48.396148681640625, 49.96243940080915, 48.42827020372663, 51.233726978302, 50.3633782523019, 51.551558426448274, 48.77606923239571, 50.66882801055908, 39.7230806350708, 43.249948024749756, 34.527850014822825, 51.60777282714844, 55.19445031029837, 50.553237778799875, 50.224334376198904, 41.46362522670201, 39.332494599478586, 42.17960582460676, 46.12189211164202, 50.84102521623884, 53.53678730555943, 54.41543912887573, 53.82642296382359, 52.429908003125874, 49.3532144001552, 46.935057163238525, 39.558568137032644, 37.95892606462751, 40.01872648511614, 41.68336548124041, 44.14143317086356, 47.526248114449636, 52.17318248748779, 50.746668679373606, 55.18591097423008, 50.06718349456787, 46.037912709372385, 46.84312554768154, 46.00723641259329, 48.31419120516096, 51.16072572980608, 48.53879867281233, 51.93818398884365, 48.807412556239534, 50.26888622556414, 47.952787603650776, 40.67505332401821, 33.335890020642964, 19.13758318764823, 7.208107250077384, 7.7245112657547, 14.00064708505358, 16.456709350858414, 12.649431773594447, 12.75368515082768, 9.785747357777186, 4.720590489251273, 2.5243430818830217, 0.7486509733966419, 0.1324623306947095, 0.23417293865765842, 2.0686804354190826, 11.62011000088283, 29.787504059927805, 42.060732569013325, 25.39924590928214, 21.95469730240958, 30.41079568862915, 39.890719822474885, 50.40311847414289, 46.68519994190761, 25.18762288774763, 3.6190586941582814, 0.017817634091313397, 0.03707733151635953, 0.03061412600800395, 0.07620545370238167, 0.036040570719965866, 0.03904715599492192, 0.04899012317348804, 0.05987845587411097, 0.08143649729234831, 0.08766097043241773, 0.0662298354187182, 0.04504917821447764, 0.030533957095550637, 0.021912482666916082, 0.014713490747713616, 0.025570461559774618, 0.03232038373659764, 0.009721588343381882, 0.04790681826749018, 0.09440216834523849, 0.03631280914747289, 0.034147658185767274, 0.04466761422476598, 0.05133333868746247, 0.019448655857039348, 0.09427823392408234, 0.2639405684811728, 0.10482414732021944, 0.16534729967159884, 0.2102862668356725, 0.16853146095361027, 0.22037304272609098, 0.24579032670174325, 0.09681288113019296, 0.24413719826510974, 0.25987082400492256, 0.16064638192100184, 0.0920412057478513, 0.12488043467913355, 0.10177998816860573, 0.12335170885281903, 0.1875182549868311, 0.26274257419364794, 0.09721551702490874, 0.1282652523368597, 0.13965651180062974, 0.14917774232370512, 0.15945426374673843, 0.1570721308567694, 2.8812707407133917, 21.05249629701887, 51.27220262799944, 62.13654490879604, 63.87554700034005, 54.84590435028076, 33.332075459616526, 23.449520587921143, 46.24191876820156, 44.51538174492972, 33.20732402801514, 13.41598744051797, 2.0408984976155415, 0.3404407506542546, 0.34958837979606217, 1.4247222585337502, 4.743940344878605, 9.134627325194222, 16.334851843970164, 21.083214282989502, 15.515461206436157, 21.82549728666033, 16.49252210344587, 14.834214653287615, 16.156291825430735, 22.31140913282122, 30.336967604500906, 33.82129117420742, 42.404459953308105, 52.54659257616316, 54.57765177318028, 55.27537250518799, 51.16269901820591, 51.27245971134731, 51.67041431154524, 53.631317547389436, 52.471711839948384, 54.42462117331368, 46.69259282520839, 43.36968980516706, 42.78817422049386, 48.91268123899187, 48.727536065237864, 54.100320952279226, 56.33857890537807, 55.85552971703665, 56.5180196080889, 51.91857964651925, 43.9621696472168, 42.97770370755877, 49.00053078787667, 57.335436957223074, 56.10738107136318, 57.14992700304304, 48.82935496738979, 48.571913787296836, 48.76318727220808, 51.58515991483416, 48.86613178253174, 51.05502278464181, 49.09338651384626, 51.49150514602661, 42.36456339699881, 46.58373539788382, 37.95731060845511, 52.27656126022339, 57.279761041913716, 51.91872903278896, 52.319167613983154, 43.72025769097464, 41.188327176230295, 44.30953093937465, 46.69949933460781, 52.47932011740548, 54.73199210848127, 56.04934971673148, 56.239622661045615, 54.96685859135219, 51.81284196036202, 50.16692835944039, 41.4929118837629, 41.5278126852853, 42.57464565549578, 43.46694721494402, 44.59384080341884, 49.96977322442191, 53.96290990284511, 53.157443455287385, 57.54097161974226, 52.03556646619524, 45.99495547158377, 47.92549507958548, 45.90717887878418, 50.11614050183977, 51.857522351401194, 51.053726945604595, 54.45597839355469, 51.667332785470144, 50.7936350277492, 51.50120483125959, 40.08521032333374, 39.88205541883196, 19.541280473981583, 12.962148479052953, 14.732625041689191, 11.635169352803912, 18.693690572466167, 16.86531901359558, 22.51919674873352, 13.057367461068289, 9.44565040724618, 5.337983965873718, 1.738694416625159, 0.3754974795239312, 0.3475206664630345, 2.0944054893084934, 13.727900760514395, 36.6560936655317, 55.09522308622088, 33.174393040793284, 26.28318010057722, 34.86610916682652, 45.72559118270874, 56.57433475766863, 53.85349661963326, 32.71320983341762, 5.607703047139304, 0.17270176431962422, 0.1163847962660449, 0.1257412377744913, 0.20637871937028, 0.11531796279762473, 0.10665883137179272, 0.10220293261642967, 0.22841423909579003, 0.19018151850572654, 0.18279497272201947, 0.2537052205630711, 0.2012742225612913, 0.06404881352292639, 0.16465889875377926, 0.11627040883260113, 0.19888261732246193, 0.15010733529925346, 0.1465788853487798, 0.14276021240012987, 0.22303265572658607, 0.12040724685149533, 0.13589684425720147, 0.1440736933478287, 0.13874914763229235, 0.159398542451007], [0.047139632648655345, 0.02749059522258384, 0.02758865031812872, 0.035583753804011006, 0.0398589010084314, 0.04270839864122016, 0.04391512567443507, 0.024998152894633155, 0.062041218392550945, 0.07369891820209366, 0.029558423906564713, 0.01753852210406746, 0.01893376143250082, 0.07428233618182795, 0.026782481166134988, 0.03362985793501139, 0.028742360017661537, 0.024910158777077283, 0.02927576657384634, 0.06945116006370101, 0.05393768161801355, 0.026679299738524214, 0.026932337321341038, 0.05159744487277099, 1.0987717317683356, 20.196811744144984, 40.11676904133388, 49.28537566321236, 41.879005908966064, 31.796283858163015, 18.945567982537405, 24.930508272988455, 27.48263372693743, 30.904423509325298, 25.32812762260437, 5.065905102661677, 0.5719324446150235, 0.1350186706653663, 0.03910482807883194, 0.49529039434024263, 1.354292277778898, 4.345661350658961, 6.612007396561759, 6.0881601231438776, 9.127548847879682, 9.547506655965533, 4.965269999844687, 7.462223717144557, 15.473476716450282, 8.987499220030648, 20.230329854147776, 28.885945762906754, 40.52632018498012, 41.67462464741298, 44.97696794782366, 44.29279620306832, 49.47466196332659, 50.63819687707083, 52.135214056287495, 49.69947787693569, 48.28826747621809, 43.125474521092, 40.934346199035645, 37.26294238226754, 41.17220040730068, 42.268911021096365, 45.486955302102224, 51.388862882341655, 51.48608555112566, 49.47514486312866, 50.940030097961426, 44.07981654575893, 35.386817591530935, 39.06072275979178, 50.1690788269043, 49.74037497384207, 50.99404191970825, 50.696707657405305, 49.964711461748394, 50.441896370479036, 52.08965471812657, 52.59140498297555, 51.607967376708984, 53.85762732369559, 49.59992756162371, 49.59573432377407, 38.22228363582066, 44.65780939374651, 43.28329242978777, 49.78268950326102, 52.925029686519075, 48.71256617137364, 43.68384565625872, 37.549830027988975, 41.14576945986067, 42.39745964322771, 46.86880956377302, 49.52704095840454, 50.53663853236607, 49.49539886202131, 50.625707490103586, 50.60884421212332, 51.93362249646868, 47.81112773077828, 46.47736195155552, 39.409567492348806, 37.19644117355347, 37.594208172389436, 38.63200153623308, 41.9633709362575, 46.99855327606201, 47.941062518528526, 48.99669885635376, 49.25682898930141, 47.96471766063145, 48.030621324266704, 46.90339422225952, 49.293987955365864, 49.59521320887974, 47.10317577634539, 48.86499227796282, 49.571815150124685, 48.15105445044381, 47.40353945323399, 46.54717745099749, 36.67733083452497, 23.47473907470703, 10.187942096165248, 10.108323557036263, 23.132489919662476, 17.613018138068064, 12.185306004115514, 6.643873572349548, 6.778023745332446, 4.5952649627413065, 2.6833910388605933, 0.34234946966171265, 0.16034200468233653, 0.09917561470397881, 0.7553907260298729, 5.291921751839774, 23.251882553100586, 32.61508389881679, 35.34942238671439, 20.78620137487139, 31.367941311427526, 33.748974323272705, 41.647193159375874, 38.81878995895386, 22.7477525302342, 5.107515258448465, 0.13266857819897787, 0.0345939985210342, 0.028944644877421002, 0.03763911101434912, 0.020260254985519817, 0.03170560047562633, 0.031473823091281314, 0.028901415411382914, 0.014066639921760984, 0.056731427420995066, 0.0341692355993603, 0.03158293152227998, 0.057126731744834354, 0.048398376176399846, 0.00878762305780713, 0.02512360384155597, 0.02931973903572985, 0.004120411110177104, 0.015192999571029629, 0.03482232894748449, 0.03648554380717022, 0.014855726954660245, 0.07584893104753324, 0.025416145733158504, 0.012868521801595176, 0.04376823302092297, 0.05034323735162616, 0.031437324692628214, 0.0033941625692282935, 0.05910946535212653, 0.02994778087096555, 0.004475875674480838, 0.018259426545617834, 0.009046860754356852, 0.03946466876992157, 0.06100585537829569, 0.03696495254657098, 0.051398433944476504, 0.02539811366503792, 0.05006872243913157, 0.04342065006494522, 0.03419706571315016, 0.0604447340592742, 0.02633919593478952, 0.029389774027679647, 0.046327175173376284, 0.05227069410362414, 0.07507028497223343, 0.051470850594341755, 1.9102154757295335, 25.056446109499248, 46.37044307163784, 53.78024523598807, 47.05289166314261, 38.89994144439697, 24.137070894241333, 27.233836105891637, 35.466103485652376, 34.26863704408918, 26.30602056639535, 5.963761746883392, 0.8113637853946004, 0.08165125362575054, 0.2805445103773049, 1.014202492577689, 3.7499518990516663, 7.818278074264526, 11.064382655279976, 8.8350088426045, 9.80677694933755, 11.494068809917994, 8.583692499569484, 10.93953047479902, 12.943084359169006, 13.44079772063664, 20.19840461867196, 32.27086666652134, 44.008910179138184, 48.469671045030864, 49.108814988817485, 49.2810504095895, 51.72036838531494, 53.055054800851, 53.82785429273333, 50.48393644605364, 50.72905847004482, 46.94729988915579, 41.86013807569231, 39.96382529394967, 41.66188165119716, 44.731474195207866, 47.54473032270159, 53.45769943509783, 52.89810541697911, 51.58502095086234, 53.14443642752511, 46.679745606013704, 37.92955255508423, 41.81159796033587, 51.345499174935476, 52.89810194287981, 52.290568828582764, 50.90860686983381, 49.3668189729963, 50.159566743033274, 52.02040549686977, 53.196502753666465, 50.54311077935355, 53.355599130902974, 49.99796554020473, 50.53189638682774, 39.321019649505615, 45.61093200956072, 44.33110857009888, 52.19697659356253, 52.566561698913574, 51.51826613289969, 44.37786994661604, 39.42630917685372, 43.43462419509888, 44.7502794946943, 48.58617843900408, 51.784486361912315, 52.09404250553676, 50.57446452549526, 51.34842784064156, 51.07159423828125, 54.15211282457624, 50.394089290073936, 47.46604892185756, 41.375452586582725, 38.88474225997925, 39.55725492749895, 41.389567852020264, 43.39705875941685, 48.822976521083284, 51.11697292327881, 50.80625990458897, 50.33239623478481, 46.925864696502686, 49.33845295224871, 47.395184244428364, 48.785108838762554, 48.58664396830967, 47.5168263571603, 49.137309551239014, 50.54052952357701, 49.198363372257774, 48.77628810065133, 45.231237275259836, 35.46614170074463, 25.551303761346, 10.821382437433515, 11.992770552635193, 20.48918672970363, 12.971718754087176, 11.809147902897426, 9.952242697988238, 9.260401010513306, 4.633203429835183, 3.375609883240291, 1.1649321530546461, 0.3550016778920378, 0.12109404642667089, 0.7150489964655468, 6.314030425889151, 25.486412797655376, 38.993137632097515, 34.687106200626914, 24.04622319766453, 33.528626101357595, 37.8396498135158, 46.20705965587071, 45.20028305053711, 26.739287648882183, 6.464365124702454, 0.20955281119261468, 0.035293442596282275, 0.027489913294890096, 0.07517653677080359, 0.052736243765269, 0.05433847189747861, 0.05082080726112638, 0.0720990344083735, 0.03603726286174996, 0.005493658270487296, 0.015816710656508803, 0.018255446937733462, 0.06806680613330432, 0.06598758484636034, 0.03849544934928417, 0.041831222495862415, 0.025287705839478543, 0.03575967079294579, 0.035355029827249904, 0.06482742567147527, 0.07245176405246768, 0.034343449465398274, 0.028131137369200587, 0.018227895023301244, 0.06424752928848777, 0.10153682835932289, 0.11011285281607083, 0.08518677391111851, 0.07363808753767184, 0.11973613500595093, 0.19557562763137476, 0.10195372027478047, 0.10890176280268601, 0.14411334693431854, 0.1485830470919609, 0.13463752397469111, 0.15021728511367524, 0.12186734564602375, 0.21189919885780129, 0.16029785919402326, 0.15107009506651334, 0.163045003211924, 0.16830716441784585, 0.13916029914149217, 0.16202717354255064, 0.1933143011161259, 0.13370820241315023, 0.16408047479178223, 0.1640250656221594, 2.932205379009247, 31.068380151476177, 53.11613294056484, 62.05809279850551, 51.75546721049717, 41.93617916107178, 27.45810832296099, 36.17779704502651, 38.95653452192034, 41.74571861539568, 30.243913854871476, 7.607513155255999, 0.859574729842799, 0.24917293233530863, 0.3236512430012226, 1.5171558814389365, 5.383348320211683, 12.793586918285914, 18.70850760596139, 17.379824434007915, 24.60838804926191, 20.005725860595703, 11.738549862589155, 13.572849103382655, 21.151968445096696, 13.268709080559866, 26.094263792037964, 38.91339315686907, 49.46576132093157, 49.85908842086792, 51.796631813049316, 48.62053380693708, 52.50308295658657, 51.21000930241176, 55.72628280094692, 54.23838513238089, 53.88857460021973, 48.2009459904262, 44.78741066796439, 42.31246927806309, 44.15411710739136, 47.292462076459614, 49.043154512132915, 55.67438670567104, 53.8338749068124, 52.45872565678188, 55.03785875865391, 48.86158766065325, 39.19550739015852, 44.13132701601301, 54.02261577333723, 54.019937242780415, 53.94201666968209, 50.32883528300694, 49.84408031191145, 50.49659258978707, 52.65887199129377, 53.990428243364605, 54.20626361029488, 54.390175478799, 51.64286470413208, 50.323926380702424, 43.08140557152884, 48.94054004124233, 47.89464160374233, 52.35823733466012, 57.886394364493235, 54.774928501674104, 47.86736645017351, 41.18366493497576, 46.9386875970023, 45.968246596200125, 51.1395754132952, 53.61822019304548, 52.327613149370464, 51.49606663840157, 51.84242044176374, 53.20368024281093, 55.780874797276084, 51.49271413258144, 51.23869841439383, 42.9343261037554, 40.997932638440815, 41.8869685445513, 43.492092745644705, 46.10770389011928, 51.924735750470845, 53.39949437550136, 51.22856099264962, 52.15555143356323, 48.61496482576643, 48.22864498410906, 48.71742296218872, 50.10041672842843, 49.39009196417672, 49.13526330675398, 49.75077642713274, 50.41020911080496, 49.91464621680123, 48.93867097582136, 48.505978856767925, 39.53295360292707, 29.900926453726633, 14.46773191860744, 18.73744511604309, 33.49481616701399, 28.794048888342722, 19.145794221333094, 16.702227422169276, 13.890800407954625, 10.150263752256121, 7.371085064751761, 1.075637053166117, 0.5851323391710008, 0.1844985977347408, 1.1848488386188234, 6.61600261075156, 29.626417023794993, 42.96475921358381, 46.208935669490266, 30.99153307506016, 40.23460006713867, 44.76927934374128, 52.430147715977256, 52.68583447592599, 35.36036579949515, 8.815428818975176, 0.5548846051096916, 0.15064462646842003, 0.11144437600991555, 0.1751538405993155, 0.10690479353070259, 0.1796289418957063, 0.08666313040469374, 0.21491122937628201, 0.1540576983243227, 0.11201446756188359, 0.07089842776102678, 0.13188883289694786, 0.09316720746989761, 0.19720176394496644, 0.08403917441942862, 0.15939434910459177, 0.05228413248966847, 0.1600846770618643, 0.11609480396977492, 0.1205523990626846, 0.18410732730158738, 0.09688127746007272, 0.13656791539064475, 0.05877826562417405, 0.11245218371706349], [0.012767310670044805, 0.012301966265243078, 0.022543052045096244, 0.030517115856387785, 0.03210461299334254, 0.042493170725979974, 0.03863126152594175, 0.005500201468489, 0.017672471702098846, 0.005664884462021291, 0.08765125381095068, 0.031838620480682166, 0.04588413251829999, 0.0505845922577594, 0.06542657209294182, 0.03957717326868858, 0.029785644928259507, 0.019040503472621952, 0.10116904880851507, 0.06394169319953237, 0.008536198691997145, 0.021124618693387935, 0.05276812134044511, 0.06860438228717872, 4.18234611409051, 28.484822784151348, 49.15678187779018, 49.30831861495972, 41.485748291015625, 24.81804473059518, 17.464740106037684, 17.032497882843018, 23.60630147797721, 28.11608362197876, 17.306692906788417, 3.2467540204524994, 0.37053630288158146, 0.035140524551804574, 0.11534990822630269, 0.99972722360066, 3.8612893990107944, 6.8486031123570035, 7.327358313969203, 5.087596075875418, 7.802538667406354, 9.365114705903189, 8.56788534777505, 10.930223362786428, 8.999191301209585, 19.13469273703439, 30.039518696921213, 39.400743280138286, 44.69184514454433, 47.47919838769095, 50.69912563051496, 52.85067353929792, 52.509398869105745, 53.42064816611153, 49.92605168478829, 48.97204664775303, 46.99673979622977, 45.018681458064485, 39.07513679776873, 37.50303738457816, 39.277815750667024, 43.08723858424595, 47.2610319001334, 50.067787987845286, 52.09336505617414, 51.32644721439907, 50.0936005456107, 42.590866225106375, 35.21454048156738, 42.072367327553884, 52.43427494594029, 53.60996225902012, 53.2624967438834, 50.345184394291465, 53.73484570639474, 52.211411476135254, 52.37625748770577, 50.94276074000767, 50.16782815115792, 48.139687197549, 51.956207615988596, 48.985717228480745, 47.045804500579834, 38.59830624716622, 35.07272774832589, 52.729139123644146, 47.67362288066319, 46.139613492148264, 39.88052681514195, 37.62637485776629, 39.033510140010286, 43.204138551439556, 44.558057580675396, 48.359316280909944, 50.976292746407644, 52.074729987553184, 48.55002696173531, 49.97393519537789, 51.11233500071934, 50.61497252328055, 47.71584708350045, 44.80698374339512, 40.78677340916225, 36.89453499657767, 37.99402836390904, 38.765452112470356, 41.7855144228254, 46.81100402559553, 48.07971382141113, 48.57059710366385, 48.45919663565499, 46.82884699957711, 49.5748028755188, 47.29994876044137, 50.08982767377581, 49.72119794573103, 53.132242338997976, 51.966358934129985, 51.78767558506557, 47.31862899235317, 45.73452656609671, 37.00543519428798, 29.41839143208095, 9.603926028524127, 8.727608799934387, 17.90621301106044, 12.703284655298505, 9.233006869043622, 10.03780802658626, 9.613031642777578, 2.746480247804097, 1.3624184131622314, 0.7611565366387367, 0.17269378474780492, 0.030426860520882264, 0.2666304441434996, 2.8714336114270345, 14.77426906994411, 33.70226853234427, 29.27417462212699, 20.77322040285383, 20.104977403368267, 31.183841841561453, 41.15413509096418, 39.98110546384539, 32.10345329557146, 9.861759781837463, 0.5050728608454976, 0.03738778503611684, 0.006580781632302595, 0.06645846100790159, 0.021122751025749103, 0.004360740156179028, 0.04374688970191138, 0.024316968196736913, 0.06556023670626537, 0.01873023315731968, 0.030591276341250966, 0.0425995887656297, 0.02073350771596389, 0.009825556871614285, 0.058228781180722375, 0.03816878902060645, 0.07340169272252492, 0.02082427534540849, 0.04239770084885614, 0.05127849270190511, 0.045996894860374074, 0.026007668813690543, 0.047824325372598, 0.03697495076007076, 0.030816220877958194, 0.01638737048155495, 0.024898130047534193, 0.006744029948354832, 0.010936635912262967, 0.02253459919510143, 0.052793233921485286, 0.04729347010808332, 0.0543039887478309, 0.06444933917373419, 0.0588043960077422, 0.01010098441370896, 0.01978058331379933, 0.049532313365489244, 0.08191562443971634, 0.0706509728250759, 0.08868026573743139, 0.04003363395375865, 0.022677259486434714, 0.02669925375708512, 0.04396004469266959, 0.07395414236400809, 0.05559010777090277, 0.0465110615561051, 0.02864930572520409, 5.0608133758817395, 33.17274284362793, 54.01927021571568, 53.77502366474697, 45.79245717184884, 28.0414617061615, 16.562608582632883, 19.841720581054688, 27.15459884916033, 29.297544888087682, 20.438407557351248, 3.7261421595300948, 0.47427898751837866, 0.0199985796519156, 0.1755577860666173, 0.7782690812434468, 5.060176312923431, 12.746532848903112, 10.367834431784493, 8.353389246123177, 8.931105903216771, 6.103809203420367, 8.62393125465938, 9.265966517584664, 10.260939870561872, 19.195345299584524, 33.761880602155415, 44.05968761444092, 48.213883536202566, 48.37421669278826, 51.64765896115984, 52.299462522779194, 53.99780028206961, 55.2988817351205, 52.49210827691214, 50.166153635297505, 48.92101212910244, 47.05323907307216, 41.28465352739607, 40.382756505693706, 43.20937749317714, 45.64106634684971, 48.43494394847325, 52.24464470999581, 53.163627352033345, 52.13185807636806, 51.59006881713867, 43.77597529547555, 36.185245513916016, 43.089865003313335, 52.88674858638218, 55.16716820853097, 51.88472802298409, 50.724733216421946, 52.86547667639596, 52.81452553612845, 53.789878913334434, 53.32646533421108, 52.69629846300398, 50.189708028520855, 53.68074703216553, 49.65764624731881, 47.469290256500244, 42.14632395335606, 38.787067958286826, 53.730367592402864, 50.86542728969029, 48.50244917188372, 41.90711832046509, 39.126251220703125, 41.308086327144075, 45.37133380344936, 47.047690936497276, 49.63262925829206, 53.15528951372419, 52.79114484786987, 49.85901199068342, 50.30383913857596, 52.013266222817556, 51.52753850391933, 50.373981203351704, 47.30016762869698, 42.04604755129133, 37.72134631020682, 40.254127979278564, 40.81764078140259, 43.98010989597866, 48.3630405153547, 50.98115995952061, 50.20546654292515, 49.72738879067557, 47.86205802645002, 48.10453973497663, 48.66865703037807, 49.17427396774292, 49.75507041386196, 52.016841070992605, 52.00480331693377, 51.595387663160054, 49.169302531651084, 46.44637993403843, 37.784585339682444, 28.191422939300537, 12.97513118812016, 12.896858862468175, 14.597121272768293, 15.016947065080915, 16.949531180518015, 10.906527400016785, 11.602603146008082, 6.290229371615818, 2.4545746999127522, 1.875886163541249, 0.523540195609842, 0.10200494966868844, 0.3790768603129046, 3.379324563911983, 16.351612636021205, 34.213878290993826, 35.307747091565815, 24.516192402158463, 24.576916183744157, 36.2497421673366, 46.350390570504324, 46.21755838394165, 37.43130070822579, 12.241244213921682, 0.5859814307519368, 0.02219487537097718, 0.060895980202725956, 0.028387358977592418, 0.01761613802851311, 0.006548935015286718, 0.010946249905308443, 0.03453072513054524, 0.03899614033954484, 0.027826349616848996, 0.0459340285908963, 0.03747651706050549, 0.004140564872484122, 0.04386282419519765, 0.04218604202781405, 0.07495082888220038, 0.0474177302260484, 0.07265662055994783, 0.057481863402894566, 0.018678598338738084, 0.08532573109758751, 0.05759599977838142, 0.03594844262780888, 0.019230827456340194, 0.06610294258488075, 0.15681446396878787, 0.1466003677674702, 0.1312469251986061, 0.05614038270765117, 0.19000709429383278, 0.1254566873290709, 0.12459855766168662, 0.11310895811766386, 0.13511688182396547, 0.14071596280804702, 0.08856245848749365, 0.10441137411232505, 0.11046615242958069, 0.09996038116514683, 0.15633207985333034, 0.1211157324058669, 0.12549571666334355, 0.14663323600377354, 0.21856724391026155, 0.1745715896998133, 0.13629768203411782, 0.1233692014855998, 0.17729749557163033, 0.17989188778613294, 7.261343479156494, 39.688020024980815, 61.88191427503313, 58.992241859436035, 52.680373191833496, 34.5204883984157, 25.9373265675136, 25.76599267550877, 35.60338599341256, 38.20005634852818, 22.47370341845921, 4.279305619852884, 0.5965078973344394, 0.1184029494013105, 0.943984431879861, 2.4606396087578366, 10.41287612915039, 20.628095115934098, 14.644678218024117, 17.994187627519878, 18.973319087709697, 19.734834705080303, 14.94969197681972, 16.001110758100236, 13.12177118233272, 23.496334075927734, 39.125281946999685, 47.55088642665318, 51.60065787179129, 50.46966137204851, 54.99527324948992, 53.28152438572475, 54.62315205165318, 56.49315895353045, 54.504563672201975, 52.19478791100638, 51.14722190584455, 49.37515681130545, 43.36441612243652, 42.92753076553345, 45.49093314579555, 47.07928786958967, 51.21416779926845, 52.10893596921648, 55.18142591203962, 54.80384690420968, 54.08880778721401, 46.827808243887766, 38.779977321624756, 46.43481813158308, 56.836653573172434, 57.205960750579834, 51.98737723486764, 51.268596512930735, 53.93175070626395, 53.7788382257734, 55.88066829953875, 55.272006102970664, 54.66470922742571, 51.976941040584016, 54.863639627184185, 51.55523749760219, 49.5013986315046, 44.30074494225638, 41.28203753062657, 55.24128811700003, 52.51905686514718, 50.70662273679461, 43.188960211617605, 40.64794145311628, 42.161071504865376, 46.66477918624878, 48.61291858128139, 51.18989079339163, 55.21808460780552, 55.55887290409633, 51.723543712071006, 51.06793253762381, 54.11639560971941, 53.14515904017857, 52.34462233952114, 50.07140799931118, 44.438527720315115, 40.12386315209525, 41.9099497113909, 42.814671175820486, 46.70129196984427, 51.25130592073713, 52.68721716744559, 52.857458455221995, 51.58523981911795, 48.280092920575825, 50.531653199877056, 48.32467256273542, 51.70197997774397, 51.615693773542134, 55.02213498524257, 53.784837995256694, 53.665068422045024, 50.37818833759853, 48.68611785343715, 41.41157974515642, 33.392847878592356, 13.139082619122096, 13.828115497316633, 26.18505416597639, 22.55973427636283, 20.012972831726074, 19.29170118059431, 16.884502989905222, 11.110551697867256, 5.956139138766697, 2.895371675491333, 0.4791446807129042, 0.23488949877875193, 0.5234029686876706, 4.293488195964268, 19.240284511021205, 41.97347709110805, 41.574226651872905, 31.53951665333339, 31.293696335383824, 43.0951178414481, 52.34700904573713, 52.65522766113281, 45.996324266706196, 16.540207590375626, 1.014631218143872, 0.12934956486736024, 0.09124263788440398, 0.11922207687582288, 0.06639009181942258, 0.08538340657417264, 0.0979860546067357, 0.11473033790077482, 0.1968487086040633, 0.07938807470990078, 0.1256877692150218, 0.22871686571410724, 0.1350254017327513, 0.09987120809299604, 0.14288514426776341, 0.08710897540939705, 0.15484175910907133, 0.11741323822310992, 0.20822822941201075, 0.10368132471506085, 0.135507500863501, 0.16868691332638264, 0.15996670696352208, 0.13265374542347022, 0.10314059337334973], [0.024407494946249893, 0.01702147502718227, 0.018562981060573032, 0.06497463384377104, 0.0205949186347425, 0.05779166892170906, 0.04912683780172041, 0.05895365335579429, 0.018360065163246224, 0.05192823408703719, 0.00571561258818422, 0.04541748362992491, 0.06424087285995483, 0.10887710484010832, 0.017607362874384438, 0.048900556551026444, 0.04565489285492471, 0.04284136436347451, 0.045257719167109044, 0.06319039208548409, 0.05618558671059353, 0.017778404589210237, 0.022078167347769653, 0.14010803614343914, 4.301085616861071, 24.282250029700144, 49.94434976577759, 52.93078279495239, 42.78480781827654, 36.34649583271572, 27.445750951766968, 27.387245382581437, 33.823962756565635, 29.98500313077654, 12.160563468933105, 1.6488501919167382, 0.05704696995339223, 0.1019914128950664, 0.37293742118137224, 0.5008340254426003, 1.3764513858727045, 8.495094282286507, 9.90758228302002, 4.875108003616333, 2.974787848336356, 5.737892312662942, 5.620962381362915, 9.234067337853567, 17.2760009765625, 28.30847576686314, 38.048495292663574, 46.49671963282994, 49.09631517955235, 49.31561074938093, 49.935501234872, 50.99765498297555, 50.398574352264404, 50.6831065586635, 49.03213119506836, 46.737988880702424, 42.7245843069894, 39.26493379047939, 37.36455283846174, 36.286140305655344, 37.45546654292515, 43.755641392299104, 47.9275552204677, 50.61512885774885, 47.75755017144339, 50.49950735909598, 48.981447560446604, 39.94860873903547, 35.6876676423209, 42.59112330845424, 50.57595491409302, 51.86263969966343, 43.85081434249878, 48.40528208868844, 53.630973611559185, 47.7444041797093, 50.127983706338064, 45.281041962759836, 45.06371968133109, 43.269653115953716, 45.492684091840474, 48.932507923671174, 49.64477123532976, 23.532372644969396, 32.7925443649292, 54.566743101392476, 45.74625859941755, 46.321083068847656, 40.10447072982788, 41.33115782056536, 38.103118555886404, 39.91934640066964, 40.18571254185268, 43.179482868739534, 46.6274847303118, 51.17025865827288, 50.18490334919521, 51.85338817323957, 47.1531263760158, 49.587438174656455, 50.39882101331438, 46.34684698922293, 44.811531339372905, 38.485231263296946, 35.93232066290719, 36.8159612928118, 39.194826466696604, 42.2938620022365, 47.55773040226528, 49.18056903566633, 49.53045947211129, 47.9945011138916, 49.22202546255929, 48.04500756944929, 50.88914496558053, 49.82439259120396, 49.452361719948904, 49.27341086523873, 53.51627969741821, 50.36597687857491, 49.2174049104963, 42.12128611973354, 33.4264042036874, 18.8279002393995, 20.08031824656895, 19.61982638495309, 8.042046546936035, 12.234307306153433, 8.029498968805585, 8.777832984924316, 4.3663261617933, 1.132775455713272, 1.977785621370588, 0.8682248028261321, 0.16021734422871045, 0.043492191404636414, 1.424776975597654, 9.355723346982684, 33.568852697099956, 33.07335581098284, 28.36930203437805, 24.43377113342285, 34.6324725151062, 41.22740731920515, 44.383741174425396, 37.47171490533011, 14.574925252369471, 1.9414821522576469, 0.017659603285470178, 0.07945351941244942, 0.06681821348943881, 0.07903596253267356, 0.015263782647837485, 0.02932316224489893, 0.014806524684120501, 0.06640688556113414, 0.009695639467931219, 0.054573859088122845, 0.09249572921544313, 0.026337983053443686, 0.022414797052208866, 0.014068382060421365, 0.027465621741222482, 0.017716747808403203, 0.08095123618841171, 0.030951083105589663, 0.007634615642018616, 0.0755677122090544, 0.014814044548464673, 0.06571185535618237, 0.03194344735571316, 0.023360031956274594, 0.018512920443234698, 0.026321391175900186, 0.025464645719953945, 0.021305022495133535, 0.04049555006037865, 0.011674467258022299, 0.020071739297626272, 0.02772892895154655, 0.016019299160689116, 0.08266108336725406, 0.051475654622273784, 0.03436520329809614, 0.025848508247041276, 0.10545142580355917, 0.0597939986203398, 0.012731121852993965, 0.03306719294882246, 0.029013061563351324, 0.020737220998853445, 0.06624179120574679, 0.021521251249526228, 0.013649563105510814, 0.03504635746191655, 0.275144918688706, 5.562547138759068, 29.640789372580393, 55.430758544376914, 57.719168594905305, 47.59055716650826, 38.43103184018816, 31.23541831970215, 32.63105085917881, 35.5327262878418, 29.666271890912736, 13.170189704213824, 1.9397865746702467, 0.05838275434715407, 0.022687546077317426, 0.6581448242068291, 2.366210550069809, 6.099721057074411, 8.050925476210457, 12.358404738562447, 10.658430678503853, 9.25940133844103, 8.140001382146563, 7.091848688466208, 8.138345105307442, 16.42258848462786, 30.60960102081299, 39.63014153071812, 47.55316196169172, 51.542779377528596, 50.166719913482666, 51.55270487921578, 52.51383876800537, 52.658059052058626, 51.78209270749773, 51.277556215013774, 48.31635904312134, 45.32162986482893, 42.33195202691214, 39.77552911213466, 38.54440212249756, 40.036208152770996, 45.110446316855295, 50.74209329060146, 52.80581596919468, 49.24676104954311, 52.94136142730713, 50.61292280469622, 41.74522181919643, 36.38824755804879, 45.85337550299508, 53.536724771772114, 52.98518024172102, 47.51246983664376, 49.20067017418997, 53.846339975084575, 50.32600041798183, 51.65227951322283, 47.05214820589338, 46.5077360016959, 45.13917016983032, 48.218580518450054, 50.211223125457764, 49.75082853862217, 26.495836666652135, 33.8381336075919, 56.92217200142996, 47.73085866655622, 49.18260138375418, 42.159046104976106, 41.730776514325825, 39.29467208044869, 40.569548402513774, 42.33847985948835, 45.64566952841622, 47.8952009337289, 52.086455072675435, 51.173927307128906, 52.26687199728829, 48.14434596470424, 50.84208481652396, 51.58245011738369, 48.9723801612854, 46.397957938058035, 40.31972244807652, 37.417129857199534, 38.06378827776228, 41.02036837169102, 44.77767276763916, 48.30665240968977, 50.79725503921509, 50.5650497164045, 48.52985634122576, 49.70130525316511, 48.83737318856375, 53.70911305291312, 52.11977168491909, 53.2601934160505, 52.58893142427717, 55.56264925003052, 51.85764047077724, 48.23921319416591, 42.16019950594221, 30.21611758640834, 19.79160496166774, 14.946316889354161, 8.016415510858808, 9.208076732499258, 9.14725307055882, 11.910161682537623, 10.89691196169172, 8.612207038061959, 4.66908175604684, 2.4836374947002957, 0.1820113461996828, 0.056409113109111786, 0.062413761259189675, 1.8611071280070712, 11.17578399181366, 33.929978370666504, 33.90702847072056, 27.86688995361328, 27.728910888944352, 40.013449328286306, 47.99514382226126, 48.78800971167428, 42.51427623203823, 17.338814428874425, 2.1118589299065724, 0.0728301830323679, 0.029953375392194306, 0.040223657685731135, 0.05735948961228132, 0.030738742356853824, 0.0763189997524023, 0.012000259910044926, 0.021699127508327365, 0.02798417177317398, 0.06626486139638083, 0.044368159757660966, 0.026915494385840635, 0.008377552963793278, 0.06320927571505308, 0.05477895647553461, 0.021159941530121223, 0.03635320572980812, 0.0381907023090337, 0.026448070271206752, 0.0015043120303224506, 0.02327731005581362, 0.08415372470127684, 0.02399358179952417, 0.032337007844554524, 0.09646245850516216, 0.10626403934189252, 0.12367425725928374, 0.1308619108583246, 0.09622991098357098, 0.12931457960179873, 0.12102351949683257, 0.17630743155522005, 0.12425634531038147, 0.1973373488123928, 0.12618461969707692, 0.13878965617290565, 0.08991499591086592, 0.17192300967872143, 0.17252910429877893, 0.12819061348480837, 0.1576751313571419, 0.1488959603011608, 0.1698296477219888, 0.17009563344929898, 0.1609317058963435, 0.08595771861395665, 0.18591243401169777, 0.48824524666581837, 7.879676699638367, 36.02816411427089, 61.9219081061227, 64.39212472098214, 54.821460587637766, 46.28405959265572, 37.927131107875276, 39.18933391571045, 44.32048824855259, 38.394751821245464, 15.18878470148359, 2.4456280257020677, 0.1996239846838372, 0.2189067964042936, 0.766354929123606, 2.7839282155036926, 9.667603663035802, 16.18208006450108, 20.826956033706665, 16.528701373508998, 11.036767039980207, 15.231842688151769, 15.002423592976161, 14.881617001124791, 23.047668048313685, 35.36690752846854, 43.76118605477469, 50.66939776284354, 53.935631275177, 52.825868470328196, 52.871924604688374, 55.283574853624614, 56.14899730682373, 54.70150341306414, 54.009466307503835, 50.38883645193917, 46.79039566857474, 43.76352412360055, 40.770816871098106, 39.71645205361502, 41.077791758946006, 47.995633670261924, 52.884632859911235, 54.08494806289673, 48.87636300495693, 54.09204912185669, 52.188037736075266, 44.88202428817749, 39.30713367462158, 47.45651599339077, 54.14278139386858, 54.74123321260725, 48.5171411378043, 50.93141780580793, 56.67567770821707, 52.29267760685512, 53.60119710649763, 48.59695856911795, 48.26840952464512, 47.28473220552717, 50.44028786250523, 53.18418707166399, 50.19453007834298, 29.50821426936558, 37.790046623774934, 57.609783104487825, 50.05328014918736, 50.63487563814436, 45.00727946417672, 45.15439714704241, 42.211491107940674, 42.78048256465367, 44.13306406566075, 45.46111842564174, 49.44148778915405, 54.63590547016689, 54.084763935634065, 54.23126670292446, 48.90781055177961, 52.73497213636126, 53.87785700389317, 52.22602353777204, 48.74702228818621, 42.07334354945591, 40.16060870034354, 40.489123003823416, 42.87423113414219, 46.39130156380789, 51.2248888696943, 52.40293857029506, 52.90992430278233, 48.85718597684588, 49.89074788774763, 50.59357554571969, 55.512191431862966, 53.12019068854195, 54.95514740262713, 53.37158693586077, 57.152073996407644, 53.03212921960013, 51.266915048871724, 44.833477224622456, 38.82934774671282, 21.825509446007864, 26.941164084843226, 27.773424523217336, 18.11540068898882, 22.373491287231445, 17.270841939108713, 20.11342293875558, 10.411653246198382, 7.299767885889326, 4.883204392024449, 1.263666489294597, 0.45934768872601645, 0.1835259042148079, 2.2008594913142066, 12.859460183552333, 41.603374344961985, 44.06514889853341, 39.877987248556956, 35.82600280216762, 44.84459434236799, 52.51453011376517, 56.79693419592721, 50.03862987245832, 23.1546060357775, 3.2248639379228865, 0.20474703264023575, 0.17249371191220625, 0.1490870900452137, 0.13503631257585116, 0.10597107506224088, 0.14113111767385686, 0.08594001563532011, 0.16215879576546804, 0.1066849956821118, 0.11268823926470109, 0.1838043342743601, 0.14466978636171135, 0.1276514224175896, 0.12163848935493402, 0.09958449990621634, 0.08211663365364075, 0.15614867183778966, 0.0828276297875813, 0.0828979667276144, 0.1369538525385516, 0.11327686160802841, 0.14658153163535254, 0.1407778723431485, 0.15574735908636025], [0.017880498664453626, 0.01421717376381691, 0.009357690012880733, 0.04284270786281143, 0.07897376122751407, 0.028841371847582713, 0.020318614086136222, 0.01552539352061493, 0.061303956168038506, 0.015701575138206993, 0.027900615274640064, 0.02338107841621552, 0.038431867225361724, 0.03520985726001007, 0.03350190319386976, 0.040338771151644845, 0.03633970966828721, 0.017219673409791927, 0.01286779237645013, 0.06864045320877007, 0.0422691998870245, 0.1057376115183745, 0.030940484388598373, 0.12045042882008211, 3.916510207312448, 28.473384312220983, 48.702967235020225, 51.28058910369873, 43.637056486947195, 28.413108689444407, 15.621723481587, 21.98668680872236, 35.738194942474365, 26.12845414025443, 9.414294924054827, 0.6992494985461235, 0.0743480319423335, 0.08747435294623886, 0.14596128277480602, 1.302063103233065, 5.171012239796775, 7.245153307914734, 8.847387058394295, 6.255823194980621, 7.93175779070173, 2.045879921742848, 7.001554676464625, 8.696273292813983, 19.613885675157817, 33.168605191367014, 42.75496530532837, 43.86929307665144, 46.54990461894444, 50.48691374914986, 50.31137445994786, 45.94341720853533, 48.03682606560843, 47.83024917330061, 46.1479617527553, 42.15769815444946, 40.16961356571743, 38.63469396318708, 36.699394839150564, 36.856552668980186, 41.23056527546474, 46.57481043679373, 50.48062910352434, 50.46808760506766, 50.36619227273123, 49.91484771456037, 48.354945863996235, 38.991661139896934, 34.51092072895595, 41.575720514569966, 49.60970715114048, 49.450923442840576, 42.32994052342006, 51.30716943740845, 49.72366108213152, 47.47007540294102, 44.02757651465279, 39.99218784059797, 38.99481562205723, 42.427288259778706, 45.26835107803345, 51.050621100834434, 47.094685077667236, 18.87640561376299, 33.0175860949925, 53.37518262863159, 46.247369629996165, 47.95110961369106, 46.55452169690813, 48.268892424447195, 42.784675802503315, 40.62180927821568, 38.03085381644112, 37.57959611075265, 40.737545422145296, 44.98202623639788, 47.47701317923409, 50.66360991341727, 50.30160876682827, 48.884478500911165, 49.40322405951363, 50.22709281103951, 46.68353584834507, 41.8224892616272, 36.537050179072786, 38.75137506212507, 36.38001046861921, 41.95518248421805, 48.05094827924456, 48.60979536601475, 50.138103757585796, 48.91460936410086, 47.798603602818076, 51.25061804907662, 50.97618504932949, 47.505657127925325, 48.09376655306135, 50.17648213250296, 52.10612194878714, 51.45920297077724, 48.05389778954642, 43.69429227284023, 31.532189777919225, 25.53559388433184, 20.480697768075125, 4.319560876914433, 13.530290518488203, 14.131615417344229, 12.436165503093175, 11.485174247196742, 6.245688378810883, 0.9961411931685039, 1.4652585919414247, 0.5450695146407399, 0.09232950849192482, 0.1186899154313973, 0.5216576137713024, 6.447324667658124, 21.66381617954799, 31.781209741319927, 30.773383957999094, 28.96618356023516, 21.019693851470947, 29.98053891318185, 43.24459443773542, 39.104684012276785, 22.992238794054302, 3.1674459789480482, 0.08963705439652715, 0.016678772434326153, 0.0071006840693631345, 0.05795978954327958, 0.03111257783270308, 0.003756654847945486, 0.0176509333042694, 0.008937024594550686, 0.042628928619836054, 0.0696057439116495, 0.04028418640206967, 0.008640891556361956, 0.03514414453612907, 0.01870669308118522, 0.055097392959786315, 0.008212389906735292, 0.011509925908675151, 0.02480242437949138, 0.05156712453546269, 0.03110967031014817, 0.027850317170045207, 0.02598586748354137, 0.0399438943048673, 0.0540194383024105, 0.09192159359476396, 0.022571326599323323, 0.02342166838103107, 0.04533991689926811, 0.04579125464494739, 0.03428631342415299, 0.033592569043061564, 0.040009345792766125, 0.04861928003707102, 0.022078235201271515, 0.012286938410917563, 0.03910808165424636, 0.028611049920852696, 0.008321449143945106, 0.021737944800406694, 0.008050273471911038, 0.0402967732266656, 0.027967215183057954, 0.0398661816891815, 0.04110437917656132, 0.021034539776987264, 0.028547935986093113, 0.056367973530931134, 0.17933874603893074, 5.219912792955126, 32.583254201071604, 54.72982079642159, 56.34700359616961, 47.853494371686665, 33.23229237965175, 19.77086980002267, 21.92426245553153, 32.34343017850603, 27.737147978373937, 9.733797413962227, 0.9164655485323497, 0.055994175374507904, 0.22496373924825872, 0.6111396093453679, 3.871025128023965, 7.76203327519553, 10.79659821305956, 12.663204840251378, 9.542789697647095, 6.177321144512721, 6.456847608089447, 5.900146646159036, 10.040055768830435, 23.69689209120614, 36.71347883769444, 43.68834114074707, 47.67965391704014, 46.53645290647234, 51.866464682987754, 51.74860239028931, 49.5027813230242, 50.2982771056039, 50.04418495723179, 48.5536504473005, 45.85062401635306, 42.07648760931832, 40.15246193749564, 38.548452922276084, 38.42258283070156, 42.163367884499685, 47.86362484523228, 51.4030441556658, 51.43751764297485, 50.825575896671836, 52.82868596485683, 50.45741517203194, 40.074937411717, 35.95808458328247, 44.5779641696385, 51.86276476723807, 50.984474250248496, 44.19010877609253, 52.41657441002982, 51.152231557028635, 50.189357144492014, 45.49045024599348, 42.791627475193565, 40.3895275252206, 43.16526338032314, 47.6892215864999, 51.747827666146414, 48.04685926437378, 22.578459671565465, 36.66392081124442, 55.0449389730181, 49.57297897338867, 50.40594639096941, 50.00732476370675, 50.004621914454866, 45.2813754762922, 43.1013434273856, 39.61513689586094, 39.77592168535505, 42.62952947616577, 46.45851148877825, 49.29637813568115, 52.92863580158779, 51.2569374356951, 49.7594894681658, 50.72681072780064, 51.076503140585764, 50.39325550624302, 43.35778406688145, 38.052758012499126, 41.66701289585659, 38.24299274172102, 43.1267078263419, 50.470700127737864, 51.15898173195975, 51.37946891784668, 49.096534047807964, 47.90779801777431, 52.06139292035784, 51.98655039923531, 50.29267685753958, 49.427546228681294, 51.05377210889544, 53.48935890197754, 52.60891791752407, 48.93344940458025, 46.32291391917637, 33.95806993756975, 25.111828463418142, 12.64539052758898, 10.609458906309944, 14.139915909085955, 15.800554479871478, 12.613150017602102, 11.176899177687508, 10.116824678012303, 4.595377436705998, 2.981498505387987, 1.2339594662189484, 0.11833519089434828, 0.04723219500322427, 0.859654634126595, 7.28672959123339, 25.31102810587202, 35.809299332754954, 36.090378284454346, 35.22176660810198, 28.04581822667803, 36.455971649714876, 49.66446590423584, 45.08646808351789, 27.24580785206386, 3.8310946992465427, 0.14044996351003647, 0.07797870997871671, 0.023530495219997, 0.011593602847174873, 0.015345664861212884, 0.04113538822691355, 0.011134403425135782, 0.007719393503586096, 0.06794968420373541, 0.0272160786137517, 0.06552135664969683, 0.037780616099813154, 0.061796592947627814, 0.04611834245068686, 0.07319136043744427, 0.028317471567009176, 0.03545424182500158, 0.08302586379327945, 0.06027461175939866, 0.03871572895773819, 0.03721880267507263, 0.03772858603458319, 0.08011948117720229, 0.03654267306306532, 0.1561516709625721, 0.0647008517490966, 0.1390243750065565, 0.08863289042242936, 0.19824316592088767, 0.07235313220215694, 0.12657057041568415, 0.13295821765703814, 0.2684092101241861, 0.12451652277793203, 0.09717539524925606, 0.14731463444020065, 0.10675470836992774, 0.11064320935734681, 0.08780779862510306, 0.11187903197216136, 0.08436612651816436, 0.14655578801674501, 0.1134554927370378, 0.17983816138335637, 0.09001609762864453, 0.1428633090108633, 0.1830950751900673, 0.3847712076136044, 7.063614249229431, 39.955959933144705, 61.38226931435721, 61.232570375714985, 55.59943996156965, 39.47447061538696, 21.937255586896622, 30.496550355638774, 45.29304844992501, 33.62679025105068, 11.070511834962026, 1.0613303865705217, 0.16360721018697533, 0.4218668256487165, 1.2379982152155466, 4.956209983144488, 9.248880897249494, 17.51263403892517, 17.062276124954224, 15.492519991738455, 21.97854004587446, 7.768394351005554, 12.86990680013384, 12.39798515183585, 25.416274206978933, 38.637344700949534, 47.852361815316335, 49.328614303043906, 49.06909213747297, 52.98106690815517, 55.57975571496146, 50.70769623347691, 52.64722681045532, 53.08521693093436, 50.60358789988926, 46.47526706968035, 45.131273542131694, 42.58971282414028, 40.24067974090576, 41.070829663957866, 45.410104751586914, 50.7424441746303, 54.5534268787929, 51.86849355697632, 51.38924503326416, 54.1293157849993, 52.973882470812114, 41.88930661337716, 38.07469000135149, 45.92772470201765, 54.70971270969936, 52.68441356931414, 46.10094329289028, 53.558257239205496, 53.78089141845703, 51.314558846609934, 46.591249874659944, 44.10296099526541, 41.55999674115862, 46.68258741923741, 48.87290627615792, 53.64615889957973, 48.619387354169575, 26.11732312611171, 39.76907423564366, 54.86360836029053, 51.730550970349995, 51.877581800733296, 52.073034627096995, 51.99131338936942, 48.07941157477242, 44.73391301291329, 43.153906549726216, 40.73210845674787, 45.221384729657856, 47.8941969190325, 51.29408597946167, 55.35505444662911, 52.02117674691336, 49.87260266712734, 52.08461727414812, 52.83089549200875, 54.061046259743826, 46.509393147059846, 40.37866401672363, 42.203559739249094, 40.30532578059605, 46.206243242536274, 52.836471421378, 52.439281123025076, 54.880089487348286, 50.84878287996565, 50.03055606569563, 54.6847756249564, 54.51085179192679, 52.880988529750276, 51.63956083570208, 53.65270757675171, 56.48251778738839, 55.4242376599993, 51.043499197278706, 47.5513345854623, 34.82303728376116, 28.921977383749827, 24.25396912438529, 9.79743596485683, 20.5211467061724, 22.772990124566213, 20.011277471269878, 18.98157181058611, 16.048596484320505, 9.099642276763916, 4.028339726584298, 1.3208101029906953, 0.13853869321090834, 0.43327981180378367, 0.9593996618475232, 8.388859799930028, 29.015953506742203, 42.34064769744873, 42.32393033163888, 40.01011419296265, 31.635544231959752, 44.041188035692485, 56.282447883060996, 52.04271616254534, 33.00821644919259, 6.65863892861775, 0.2806946023234299, 0.19213561793523176, 0.13582155401153223, 0.12105857261589595, 0.11519411658602101, 0.10495401213743857, 0.07397018293184893, 0.034654092974960804, 0.08700829438333, 0.13835638442209788, 0.2066122711236988, 0.14449788630008698, 0.11061477195471525, 0.13643955013581685, 0.10236384041075196, 0.07507248342569385, 0.12037676705845765, 0.07605243048497609, 0.1537568766091551, 0.1016369326306241, 0.15603584503488882, 0.10440412735832588, 0.242049834557942, 0.1535069178789854], [0.020766152035711066, 0.016760534207735742, 0.0321614606572049, 0.06590084771492652, 0.020758515124076178, 0.044562702532857656, 0.02632443779813392, 0.0664234689569899, 0.03022565453180245, 0.06435882938759667, 0.0689821702295116, 0.05398107393245612, 0.1307686801467623, 0.08749453936304365, 0.02680087964316564, 0.03077935267771993, 0.047505943171147785, 0.0331049262812095, 0.017385159619152546, 0.00945336090600384, 0.009441014961339533, 0.017052138024674993, 0.04236785887873598, 0.10013267477708203, 4.973851025104523, 32.79508740561349, 47.08851160321917, 48.291376795087544, 43.546615259987966, 28.96485471725464, 24.086941378457205, 38.67483023234776, 36.69439213616507, 19.08305025100708, 4.662854433059692, 0.2737963981926441, 0.06789103163672344, 0.10095583274960518, 0.7284291099224771, 2.9437448169503893, 9.52088463306427, 7.291245920317514, 13.776466931615557, 9.340311373983111, 6.889351691518511, 12.239767721721105, 6.18332655940737, 10.121343612670898, 21.815672533852712, 33.79984903335571, 42.84484372820173, 47.987000533512656, 49.429811341421946, 51.41813564300537, 46.409019470214844, 46.73756851468767, 41.26452807017735, 39.981247901916504, 38.25233459472656, 38.11810234614781, 37.4442903654916, 36.39691196169172, 38.22974252700806, 39.946545124053955, 44.45856979915074, 46.49587542670113, 51.60274927956717, 50.038390159606934, 48.809232984270366, 49.48222507749285, 49.36946276256016, 41.44243669509888, 35.135615893772666, 37.73734106336321, 48.503397600991384, 50.37087188448225, 53.747553961617605, 48.4586546761649, 47.803373541150776, 43.087568623679026, 38.22229058401925, 34.55011551720755, 38.13681731905256, 41.72192450932094, 48.94446924754551, 46.3650095803397, 48.628340108054026, 19.422641720090592, 36.427880082811626, 54.70380674089704, 47.594753878457205, 50.71047551291329, 49.2972640310015, 50.92643594741821, 48.666284220559255, 48.39436994280134, 44.9920003754752, 38.03044387272426, 34.323031016758506, 40.229868343898225, 44.97121483939034, 50.54644244057791, 48.39913640703474, 47.997495787484304, 47.196351119450156, 50.078609807150706, 48.63711220877511, 46.679130690438406, 39.60300186702183, 39.448574679238455, 36.463545186179026, 37.82337018421718, 40.67175987788609, 46.527819769723074, 47.709180286952424, 48.61987372807094, 47.74376147133963, 51.18613876615252, 47.62547186442784, 46.02869592394148, 45.440162658691406, 48.88165405818394, 49.20179925646101, 52.72591863359724, 49.567357880728586, 49.57032128742763, 37.05848816462925, 34.824961934770855, 14.773556879588536, 13.049616745540074, 8.916885546275548, 10.175886103085109, 10.377250109400068, 6.575349135058267, 8.22773107460567, 6.21620282956532, 2.2318300008773804, 0.9663386323622295, 0.053242573381534646, 0.05858159903436899, 0.4754878655076027, 3.7676368015153066, 17.416663782937185, 29.589674949645996, 27.75686001777649, 21.69694345338004, 21.72419081415449, 32.18990625653948, 39.93685586111886, 43.522543225969585, 28.279633794512065, 6.244943184512002, 0.2559137706245695, 0.009143091438870345, 0.043706957916063924, 0.01279987271742097, 0.059111324538077624, 0.006983850517177156, 0.05092104723943131, 0.013360027124040892, 0.08490054748420205, 0.04259682034275361, 0.031159695304398025, 0.04235136029975755, 0.01728942511337144, 0.023536741134843657, 0.06175556193505015, 0.03837778798437544, 0.03144871051024113, 0.01888373643825097, 0.05726937337645462, 0.03416274201923183, 0.05929028136389596, 0.062194804794022014, 0.13674604440374033, 0.059650522390646596, 0.048290058238697905, 0.036167555156030824, 0.03235774048204933, 0.04664434618981821, 0.02750869684054383, 0.013030276916522001, 0.05328429649983134, 0.03527692366125328, 0.050153349326657395, 0.014483022935954588, 0.04534406953358224, 0.05590393700237785, 0.054618761142981906, 0.049729682239038606, 0.06564957262682063, 0.046792962322277684, 0.02585666423796543, 0.08093434066644736, 0.05911557895264455, 0.023513029728616987, 0.01564126185673688, 0.006149147271311709, 0.015865957031824758, 0.2300579494663647, 7.270674909864153, 38.700458662850515, 53.64886522293091, 53.52775812149048, 49.80342640195574, 35.054478304726736, 26.36241388320923, 35.90393032346453, 39.56303930282593, 22.623150484902517, 5.662813552788325, 0.3459232321807316, 0.1793716956994363, 0.09296186241720404, 2.5333889850548337, 7.2141725931848795, 11.009784579277039, 7.7915118762425015, 9.945524658475604, 11.251633133207049, 10.125932029315404, 6.247185715607234, 8.175081099782672, 13.287642053195409, 24.488274540219987, 36.595626967293875, 44.66706092017037, 49.503496987479075, 49.14954880305699, 53.15547711508614, 49.17254386629377, 49.11675330570766, 44.87513862337385, 43.14801100322178, 40.97548648289272, 40.603865555354524, 39.60718468257359, 38.505467891693115, 38.8712523324149, 42.16370487213135, 47.40836150305611, 49.1686042376927, 52.03593472072056, 50.57093136651175, 49.88460568019322, 50.842769214085166, 50.994635990687776, 43.291880403246196, 36.80235324587141, 39.42829288755144, 49.73574052538191, 51.08790166037423, 54.69421475274222, 50.193397521972656, 50.112909589494976, 45.083699226379395, 40.834889684404644, 36.498102051871165, 39.14752313068935, 43.498095989227295, 50.76097502027239, 49.557150976998464, 48.642580441066194, 21.64188071659633, 37.011490549360005, 55.16628231321062, 50.14527429853167, 53.35031849997384, 51.36681972231184, 52.118903160095215, 51.6157146181379, 49.90926831109183, 45.438557624816895, 39.380600452423096, 36.55793298993792, 41.91051598957607, 47.36539731706892, 53.63477080208914, 50.64740671430315, 49.436241899217876, 49.38976539884295, 52.041795526232036, 50.08598531995501, 48.886014052799766, 41.8257132257734, 41.5723888533456, 38.57539108821324, 40.522113050733296, 43.26083237784249, 48.04058156694685, 51.16741337094988, 49.93159982136318, 49.157532283238, 51.28124918256487, 48.915161745888845, 48.19074256079537, 47.50324262891497, 52.648282936641145, 52.068261214665, 54.42213371821812, 52.36461578096662, 51.60354832240513, 38.225983551570344, 29.327616691589355, 15.720943757465907, 13.194669076374598, 14.268099750791277, 15.71371589388166, 13.613498670714241, 10.85162273475102, 10.5515022448131, 8.565801756722585, 3.2025391587189267, 2.78226129923548, 0.452432032674551, 0.047490123127188, 0.4907737938421113, 5.014983926500593, 19.54370539528983, 32.729159423283164, 30.51053360530308, 23.45429573740278, 24.38357560975211, 35.33482422147478, 45.82226146970476, 47.587103911808555, 32.52838775089809, 7.253801209586007, 0.3009346233946936, 0.041035850532352924, 0.02383975112544639, 0.007556165967668805, 0.04807505084733878, 0.029037967191210816, 0.07598441413470677, 0.030816410867763416, 0.05160763307607599, 0.03983480962259429, 0.012724949728830584, 0.044044949779553075, 0.041876775944339376, 0.036541261710226536, 0.01724805144060935, 0.0541945953321244, 0.04192068733807121, 0.019732203766969696, 0.02827649822990809, 0.03540753486699291, 0.038550488717321835, 0.04124549749706473, 0.022811858781746457, 0.025162017405299202, 0.08823205264551298, 0.062289969330387454, 0.10098431086433785, 0.12915672521506036, 0.1165283199931894, 0.16545183477657183, 0.16435473864631994, 0.17164923436939716, 0.1397729076977287, 0.09632667007723025, 0.1775140839495829, 0.1250065064855984, 0.2723807841539383, 0.12439684277134282, 0.12748609057494573, 0.18475369976035186, 0.11069945991039276, 0.1751060038805008, 0.1411212517746857, 0.17252774722874165, 0.09507851169577666, 0.08625506622982876, 0.11565429903566837, 0.32428806168692453, 9.529225945472717, 44.11025660378592, 60.96186855861119, 59.510355131966726, 54.43685000283377, 37.69336938858032, 34.01586505344936, 51.24914503097534, 47.092805589948384, 24.835437808717998, 6.985628971031733, 0.6283689705388886, 0.3188347028834479, 0.3074437012629849, 2.8214875715119496, 8.703916311264038, 18.8427346433912, 18.570125545774186, 24.142832687922887, 16.36598151070731, 17.366445677621023, 20.248106820242747, 10.395615066800799, 13.514412147658211, 25.01860100882394, 36.2727233341762, 44.56031574521746, 49.868183612823486, 51.07538448061262, 56.237625053950715, 52.1273695400783, 51.64301756450108, 46.498442786080496, 44.11831304005214, 42.238905225481304, 41.70518282481602, 41.579121657780235, 40.045751503535676, 41.68088844844273, 45.542874404362266, 48.95968580245972, 51.486696992601665, 54.78882837295532, 52.91967609950474, 49.64662640435355, 53.40346874509539, 53.39058331080845, 46.06254754747663, 38.910078866141184, 40.993110588618684, 51.439483983176096, 54.09883403778076, 55.48671586172921, 54.34018666403634, 50.862661906651084, 47.46721274512154, 41.668673515319824, 37.97181844711304, 40.545754296439036, 46.94204010282244, 52.19334268569946, 50.69054807935442, 50.69351148605347, 25.92772936820984, 39.54874685832432, 54.92236927577427, 51.434877327510286, 55.212109157017295, 54.33899504797799, 55.24965374810355, 51.84493221555437, 52.61369480405535, 49.125494139535085, 42.04432092394148, 38.109337193625315, 44.35947806494576, 49.37340586526053, 55.41360344205584, 52.1450457572937, 50.74576541355678, 49.64268330165318, 52.055156912122456, 52.534301212855745, 51.87709890093122, 44.85619783401489, 43.06487233298165, 40.10501616341727, 41.99984550476074, 44.498629638126914, 50.36452470506941, 52.465778078351704, 51.773289339882986, 50.88361767360142, 55.192970343998496, 51.8044867515564, 50.207099369594026, 49.751766545431956, 54.915136201041086, 54.755508286612375, 56.55484506062099, 53.2615761075701, 54.108415603637695, 42.671541758946006, 35.50069856643677, 18.531085354941233, 19.745840651648386, 18.40942587171282, 18.671485866819108, 18.523310320717947, 16.85582603727068, 18.84294308934893, 12.151411822863988, 7.9262582915169855, 2.6759786137512753, 0.6978803777268955, 0.34263708708541735, 0.781996029828276, 5.69583660364151, 22.534020730427333, 38.5662750516619, 37.570292472839355, 31.71342658996582, 30.54918990816389, 42.28608349391392, 52.665528365543906, 54.69725806372506, 39.39283275604248, 9.845816271645681, 0.49297778414828436, 0.08048190030136279, 0.13481407878654345, 0.13151239523930208, 0.16072055936924048, 0.1687945696924414, 0.13206910608070238, 0.0883741243077176, 0.17879511735269002, 0.11130526276039225, 0.0804416835308075, 0.11185092705168895, 0.09438008203038148, 0.1085780066038881, 0.11484412822340216, 0.10292148084512778, 0.12269571476749011, 0.11652910709381104, 0.1315756482737405, 0.09283593310309307, 0.16404510954661028, 0.18074083008936473, 0.23007122161132948, 0.10867066056068454], [0.019921073989410485, 0.07449887027697903, 0.055595295171120336, 0.01645523076876998, 0.046261370847267766, 0.06054346090448754, 0.04264424315520695, 0.03590624453499913, 0.03641548506649477, 0.04101859538682869, 0.023060414640765105, 0.06207639364791768, 0.031093256548047066, 0.04200575866603425, 0.03394643523331199, 0.031859085096844604, 0.02244051861842828, 0.010369248322344251, 0.03552834802706327, 0.040014377129929404, 0.053188545030674765, 0.026024750932785015, 0.04964591709098645, 0.4880420118570328, 6.0330556971686224, 32.39605583463396, 47.08892502103533, 43.46825000217983, 32.44207375390189, 16.335433755602153, 13.769384111676898, 25.175202982766287, 30.772161075047084, 15.566011088235037, 2.9971795039517537, 0.22419787677271025, 0.013173734486502196, 0.37855433406574385, 0.6629959153277534, 8.095536385263715, 8.132436530930654, 7.097562279020037, 8.5808550289699, 8.680503487586975, 2.2229224102837697, 3.1901036202907562, 6.100696410451617, 10.829052380153112, 22.0496027469635, 39.20018005371094, 44.72466843468802, 51.05227477209908, 45.96322652271816, 51.003606115068706, 50.15528665270124, 47.29082924979073, 44.53134870529175, 41.95986557006836, 37.89863307135445, 36.26719604219709, 36.15315873282296, 37.019783224378315, 37.49177088056292, 42.19875158582415, 47.07169696262905, 49.82687657220023, 50.399911880493164, 50.07136978421892, 49.38413388388497, 48.57084723881313, 48.97471128191267, 45.29155111312866, 35.9172500201634, 34.76732315335955, 42.830259459359304, 50.22706849234444, 47.769782475062776, 47.31171553475516, 44.28026860100882, 36.75679043361119, 36.628144536699565, 37.03825848443167, 41.074713706970215, 47.57372168132237, 49.604700974055696, 47.01937355313982, 49.30158928462437, 28.75331333705357, 24.954180785587855, 43.098637104034424, 48.07602085386004, 49.38351549421038, 47.871299130576, 51.2245831489563, 47.004497459956575, 48.18482269559588, 47.37572928837368, 47.26168850490025, 39.063550676618306, 36.95081887926374, 40.707463196345735, 48.65783173697335, 51.16029494149344, 48.71268081665039, 48.57292822429112, 49.730713503701345, 49.8409640448434, 46.77249016080584, 41.29405096599034, 34.83199003764561, 34.97965662819998, 35.74980885641915, 37.70372567858015, 42.712258202689036, 45.87145471572876, 49.355823448726106, 49.19146033695766, 50.20813465118408, 46.48872920445034, 42.219988754817415, 44.63806956154959, 47.89377655301775, 49.53099448340279, 51.23690230505807, 49.33690350396292, 48.73754147120884, 40.730583327157156, 29.68150929042271, 17.727828434535436, 19.238438027245657, 18.1990396295275, 20.554246187210083, 15.226756606783185, 6.616362614291055, 7.304912158421107, 3.0195787591593604, 2.545791519539697, 2.977153492825372, 0.16122445304478916, 0.027844919423971857, 0.15396940734769615, 2.029540147100176, 13.17659420626504, 26.044290610722133, 26.183513402938843, 27.008301053728374, 22.404475041798182, 30.05114303316389, 46.39299692426409, 48.8044422013419, 34.84018543788365, 9.94234846319471, 0.5556373990007809, 0.05841919846300568, 0.037213035127414126, 0.015353815763124397, 0.007132945864993546, 0.054322149737605026, 0.054415838460304906, 0.06164080130734614, 0.06555811289165701, 0.02769197423809341, 0.06644193189484732, 0.025308212864079645, 0.12211163182343755, 0.005811910278030804, 0.024068849992805293, 0.06722063903829881, 0.051955334775682004, 0.016761244973167777, 0.031120601509298598, 0.0662443899948682, 0.05262992411319699, 0.027615528786554933, 0.028274162373106395, 0.02979954132544143, 0.0447225789539516, 0.0671703867348177, 0.021983096109969274, 0.033432024264974256, 0.007157846403840397, 0.018774008844047785, 0.04567394272557326, 0.015133464908493417, 0.027415201500324265, 0.041970183075006516, 0.008932583582853633, 0.03309277371902551, 0.015390278538689017, 0.051000452799988646, 0.027071967953816056, 0.025379708402657082, 0.04227134066500834, 0.06528699065425567, 0.04379428198028888, 0.010173996478053076, 0.025162553447963934, 0.030361062980123928, 0.034716016080762656, 0.5768089943698474, 7.947028194155012, 39.95946182523455, 53.30409908294678, 50.32731710161482, 38.268183435712544, 22.002568653651647, 16.902283430099487, 29.896344116755895, 34.07304872785296, 18.257427079336985, 3.7509046707834517, 0.2686676505420889, 0.05028973825808082, 0.2865033234868731, 1.6674560563904899, 6.394056303160531, 9.379074505397252, 10.859937991414752, 8.287557670048304, 12.901250123977661, 6.805746189185551, 6.20272592987333, 9.54185516493661, 13.279038446290151, 21.35873814991542, 38.32228905814034, 46.755432333265034, 49.4492176600865, 47.85357775006975, 51.654940673283164, 52.17926563535418, 48.59687866483416, 45.86377000808716, 43.35951764242989, 39.49951539720808, 38.50099325180054, 37.90426458631243, 37.45532063075474, 39.57103667940412, 43.632144110543386, 49.37912423270089, 52.38328559058053, 50.473392554691856, 49.98009129932949, 49.41883666174752, 50.32320376804897, 52.05644927706037, 45.96988984516689, 37.33113200323922, 35.06782579421997, 44.01889474051339, 51.39948320388794, 50.53378282274519, 49.88898999350411, 46.68432446888515, 38.562064443315776, 37.010271140507285, 38.4475998197283, 42.53490890775408, 48.41226502827236, 51.85056025641305, 47.86187389918736, 50.9980023929051, 29.231474467686244, 28.31590165410723, 47.93060895374843, 47.965047700064524, 51.60786662782942, 49.45548146111624, 53.00280434744698, 48.45494433811733, 50.1210424559457, 49.81746523720877, 49.1544577053615, 40.13705778121948, 38.74245704923357, 42.18889556612287, 51.06830079214913, 51.94719927651541, 49.22456155504499, 48.23068428039551, 50.95400292532784, 51.59160089492798, 50.08228887830462, 43.45545489447457, 37.610182080950054, 36.60546561649868, 38.425733838762554, 39.105952058519634, 45.80797597340175, 48.597226074763704, 51.49675103596279, 50.129689489092144, 52.87662158693586, 49.01009498323713, 45.14047990526472, 45.72437177385603, 50.378594807216096, 50.364847796303884, 53.13527175358364, 52.24589885984148, 52.50108882359096, 44.63102061407906, 29.85915388379778, 20.254903895514353, 11.969371625355311, 12.066715019089834, 16.394005332674297, 15.862629686083112, 11.022457224982125, 12.040343999862671, 7.058680159705026, 5.662486553192139, 5.315542587212153, 0.6334310589092118, 0.07960970460304193, 0.22815870280776704, 2.562496943133218, 15.334252187183925, 29.344914231981548, 30.577962398529053, 30.63502447945731, 24.648781401770457, 34.15336990356445, 48.80240985325405, 53.962611130305696, 40.372097969055176, 11.927203008106776, 0.7533205971121788, 0.04017108818516135, 0.05288498203403183, 0.041673052590340376, 0.016059468433793102, 0.013644904962607791, 0.05021850225914802, 0.01460440267276551, 0.04975666418405516, 0.049597320412950854, 0.023309426814583794, 0.022141539125836322, 0.0919143400554146, 0.02062140355285789, 0.018091533233278563, 0.026865467695253234, 0.016078942388828312, 0.012386750912160745, 0.04091633337416819, 0.019559560709499886, 0.008498400898783334, 0.01660839478219194, 0.04523669815223132, 0.032826774421014955, 0.12994938982384546, 0.21156803305659974, 0.12563678409372056, 0.14299297705292702, 0.09226589583392654, 0.12118331449372427, 0.19304444773920945, 0.11966275822903429, 0.1108615415702973, 0.13586261895086083, 0.09998927997159106, 0.15622282214462757, 0.11109645717910357, 0.1648675754134144, 0.06953417882323265, 0.12984275126031466, 0.15054542464869364, 0.12187339817839009, 0.13140464387834072, 0.07274389373404638, 0.15599214737968786, 0.15400365979543754, 0.18036260109926971, 0.8597480548279626, 12.545787232262747, 46.12280232565743, 60.52610533578055, 55.785033294132774, 43.21329280308315, 25.506854397909983, 20.852336066109793, 34.152230398995535, 39.84510489872524, 20.5264481816973, 4.511507034301758, 0.32868268873010364, 0.15051589480468205, 0.5014796108007431, 1.8399198991911752, 12.710893801280431, 14.582385880606514, 17.39358013016837, 18.850657326834543, 18.727418865476334, 10.47339059625353, 8.58220558507102, 12.361083269119263, 15.81585441316877, 28.096208299909318, 45.12680932453701, 47.54769720349993, 52.3929887499128, 46.922553879874094, 54.352398123059956, 53.48329659870693, 52.9437689781189, 49.656847204480854, 47.04915005820138, 42.00656788689749, 41.35570580618722, 39.20332063947405, 40.643776008060996, 40.03821618216378, 46.62646334511893, 50.79049791608538, 55.82596860613142, 51.84231274468558, 51.1538713318961, 49.127345834459575, 51.69356223515102, 53.206744398389546, 49.69417987551008, 38.872357095990864, 38.22711958203997, 46.081516129629954, 53.71639823913574, 52.40594366618565, 51.87628248759678, 47.38014486857823, 40.46567630767822, 38.85099833352225, 40.82641635622297, 45.54672718048096, 51.15793602807181, 53.4333564213344, 50.14415911265782, 51.970962115696494, 32.0074257169451, 32.90879814965384, 51.530946595328196, 46.91663748877389, 52.40319912774222, 47.981108461107524, 53.76077290943691, 48.77392223903111, 52.204869747161865, 52.25650181089129, 51.78962802886963, 42.88976035799299, 39.722121783665244, 45.47928449085781, 53.199188232421875, 54.258204868861604, 50.972846439906526, 49.32048143659319, 52.370799677712576, 53.40639393670218, 53.03549909591675, 45.40531396865845, 38.86853906086513, 38.619609424046104, 40.48910215922764, 41.53233596256801, 48.219473361968994, 49.91853025981358, 53.07367597307478, 52.82391255242484, 55.84524638312203, 50.897076334272114, 45.59174108505249, 49.32532780511038, 52.83122205734253, 53.65783882141113, 55.19641317640032, 53.778407437460764, 54.01081425803048, 46.8569837297712, 36.87881817136492, 22.440187045506068, 25.521148579461233, 24.622336557933263, 32.3184757232666, 32.352393354688374, 16.320891175951274, 17.47569046701704, 10.473593831062317, 7.1772346666881015, 6.1384516188076566, 0.8244751989841461, 0.16967240401676723, 0.38987102253096445, 2.6595231081758226, 17.13660274233137, 35.56705733707973, 37.02553980691092, 38.278053351810996, 31.793327399662562, 40.020008427756174, 55.89694445473807, 61.920469829014365, 48.144526617867605, 16.064674615859985, 1.3071331168924059, 0.1849538811615535, 0.18137331972164766, 0.2174599968961307, 0.1425057617681367, 0.14679616583245142, 0.16412364318966866, 0.15187529900244304, 0.2049943043717316, 0.1533938603741782, 0.17882139022861207, 0.18096552017543996, 0.288150209401335, 0.12005512788891792, 0.11285031413925545, 0.16903551747756346, 0.15966300825987542, 0.07132426276803017, 0.12568329088389874, 0.24397388845682144, 0.1320938454674823, 0.10710682733250515, 0.10766610982162611, 0.1325240773814065], [0.022898614572893296, 0.047921220173260996, 0.021730633585580757, 0.01730354203443442, 0.007356648682616651, 0.01424336776004306, 0.03197729268244334, 0.03680122543924621, 0.07763482843126569, 0.04205306952020951, 0.0372650584072939, 0.017370569419914057, 0.05547692134444203, 0.01156208319922111, 0.02876451418602041, 0.023967034116919552, 0.04698801739141345, 0.03833070783210652, 0.05828663307641234, 0.03777498086648328, 0.009048119436816444, 0.022806937706523707, 0.05326143326237798, 1.280847104532378, 7.719525064740862, 35.08849321092878, 47.95698431559971, 37.06266055788313, 25.327953917639597, 17.181083372661046, 19.32746008464268, 36.078086921146934, 32.44994258880615, 11.41445027078901, 1.5644007005861826, 0.16366196796298027, 0.015037506486156156, 0.24141418295247213, 3.1692314488547186, 6.613153849329267, 8.93178595815386, 5.652237960270472, 3.862280820097242, 11.35020809514182, 7.778174809047154, 3.7814181191580634, 11.31599429675511, 16.29878200803484, 23.98305712427412, 35.966481481279644, 49.09046132223946, 51.9318402835301, 47.32691471917288, 47.996175629752024, 49.5170042855399, 47.56889615740095, 47.844722270965576, 46.52146911621094, 47.77632767813546, 44.419541767665315, 39.164348193577354, 34.4743002482823, 35.69583177566528, 40.23806027003697, 46.21022456032889, 45.71377924510411, 48.16392598833357, 49.09872620446341, 49.85266828536987, 48.62518909999302, 48.95233460835048, 47.39061580385481, 42.187901973724365, 33.870157854897634, 37.42816012246268, 39.186353138514924, 43.39830248696463, 38.712833404541016, 36.66511590140206, 34.11468233380999, 35.96978882380894, 34.51062890461513, 42.079576083592, 45.732754775456016, 49.54495688847133, 44.11120155879429, 50.7876422064645, 31.432757581983292, 26.99853883470808, 46.37035274505615, 44.46852656773159, 49.37374632699149, 48.26811422620501, 49.71133150373186, 45.445665631975444, 48.85014745167324, 46.42088351930891, 47.48650441850935, 44.4162483215332, 35.000164236341206, 38.765688351222444, 47.01511778150286, 47.95239850452968, 46.60076890672956, 49.21283646992275, 48.177214418138774, 49.474797453199116, 50.423407214028494, 45.779557841164724, 42.11650575910296, 34.16160351889474, 35.119648933410645, 33.452956744602744, 35.89970234462193, 36.64887796129499, 41.06484031677246, 42.49164594922747, 41.580685002463206, 40.39258125850132, 41.28871127537319, 43.86325856617519, 46.4613150869097, 47.43724169049944, 49.64601148877825, 48.6680907521929, 50.35988678250994, 46.74530185971941, 34.32477848870413, 22.79566730771746, 10.806147643498011, 9.788337298801967, 13.165520514760699, 8.26722810949598, 9.19774215562003, 6.7552653551101685, 8.378102251461574, 3.5262948146888187, 4.18181631394795, 0.8888715377875737, 0.10635603511972086, 0.045427125612539906, 1.2346116197960717, 9.17813607624599, 26.77651957103184, 34.82237720489502, 26.041936908449443, 21.233317954199656, 30.651707104274205, 40.40264572416033, 47.156065464019775, 31.32090895516532, 9.273868356432233, 1.2376140015465873, 0.051423373499086926, 0.08439863513090781, 0.035694365190075975, 0.024742443580180407, 0.08570426542844091, 0.04558029132229941, 0.03996430463822825, 0.0486064896519695, 0.0332707500617419, 0.03218268183991313, 0.021894805133342743, 0.047410765064081976, 0.03620997377272163, 0.06932012816624981, 0.02014205588160881, 0.03084114007651806, 0.023856380322415913, 0.0473160687168794, 0.05649836082011461, 0.06741871698094265, 0.039334335763539584, 0.02212055373404707, 0.05512000174660768, 0.01911698454724891, 0.06146018207073212, 0.013470431556925178, 0.039882151010845385, 0.014438149718833821, 0.0390900428007756, 0.030254634762448922, 0.005648343474604189, 0.025468711841053197, 0.04080779830526028, 0.029063741343894174, 0.04891263447435839, 0.040317573717662265, 0.040903047658503056, 0.06447632451142583, 0.023223464909408773, 0.020240368820460777, 0.05131120148247906, 0.013399280374869704, 0.0405319738201797, 0.013733316379200135, 0.07641942972051245, 0.006421843709956322, 1.3481145692723138, 11.922983714512416, 41.71891246523176, 53.413609640938894, 41.76490953990391, 29.9280035836356, 20.500720739364624, 20.06322741508484, 34.977645124707905, 36.44779014587402, 12.566214936120168, 1.9801058854375566, 0.03973841354517, 0.26504397498709814, 0.5737777341689382, 5.422223491328103, 10.787540367671422, 9.248807072639465, 8.733922975403921, 6.084084136145456, 12.824535931859698, 8.178139175687518, 6.031833682741437, 13.561903085027422, 16.442627089364187, 22.605934585843766, 37.8686238016401, 50.0283465385437, 52.18759652546474, 48.077389648982454, 49.24620171955654, 50.55797645023891, 50.22596720286778, 48.83563266481672, 48.671405042920796, 47.87255675452096, 45.07966579709734, 40.51362930025373, 36.81232738494873, 38.640276840754915, 42.37467302594866, 48.290150438036235, 48.75251831327166, 50.826107433864046, 50.90286765779768, 50.754273482731406, 49.385287284851074, 51.21359804698399, 48.603444712502615, 43.119492122105186, 36.151588439941406, 39.58105945587158, 42.59436116899763, 45.658749512263704, 42.02989993776594, 38.238219329289024, 35.432651383536204, 38.22483709880284, 36.76974534988403, 44.68335097176688, 48.09040362494332, 49.79990019117083, 46.11781004496983, 51.50521394184658, 32.5028600692749, 29.92229563849313, 48.70517328807286, 44.57321160180228, 49.85722630364554, 47.809098856789724, 52.32104710170201, 44.491059575762065, 48.167052677699495, 48.88362039838518, 49.44751187733242, 45.873980385916575, 38.28629738943917, 39.88791969844273, 49.608928952898296, 49.134533745901926, 47.17389106750488, 48.91299738202776, 49.31499235970633, 50.43411438805716, 52.55576072420393, 46.94403770991734, 43.18900190080915, 36.89962107794625, 38.08938544137137, 35.171725681849885, 37.90539714268276, 40.233272961207796, 44.701228686741416, 44.81102759497506, 45.06409140995571, 43.457483768463135, 42.69989388329642, 47.01740026473999, 49.359346185411724, 49.41520275388445, 49.56746557780674, 51.3603127343314, 52.50657442637852, 47.71360281535557, 36.80160978862217, 21.715479510171072, 11.324376429830279, 14.576198509761266, 13.231900129999433, 10.195190804345266, 13.736469626426697, 10.618312648364476, 9.917505179132734, 5.835349048886981, 4.002558001450129, 0.7423667620335306, 0.08990899766130106, 0.04419693483838013, 1.3937407838446754, 10.676320552825928, 29.124948160988943, 35.85104758398873, 31.280206407819474, 25.88781370435442, 35.40323271070208, 47.4154486656189, 52.026533808027, 37.96721179144723, 13.714725238936287, 1.5632255864994866, 0.0820595281464713, 0.08386075363627501, 0.033622051389621835, 0.03646144224330783, 0.06983545515686274, 0.03952689043113163, 0.03862218272739223, 0.011802835057356527, 0.04896844397964222, 0.03668803222743528, 0.010065102633754057, 0.05084582145458885, 0.029505267473203794, 0.05219246580132416, 0.02584307487787945, 0.05138272925146988, 0.008810823018263494, 0.04744329403287598, 0.03161059878766537, 0.06052350518958909, 0.053809601347893476, 0.0669921695121697, 0.15245635568031243, 0.21801807837826864, 0.12955176830291748, 0.08093624734984976, 0.07688873168081045, 0.13583926377551897, 0.0790818314999342, 0.0694656196449484, 0.09349588304758072, 0.17873183717685087, 0.12732117942401341, 0.09155468935413019, 0.14572099995400223, 0.12191789650491305, 0.06953792433653559, 0.20407079106995038, 0.13324833208961145, 0.14508282419826302, 0.13416127381580217, 0.1430009701954467, 0.13023197251771176, 0.06351055204868317, 0.10511341358401946, 0.12420036617134299, 1.6690147327525275, 15.90524993624006, 50.854577677590505, 59.98746708461216, 48.41812583378383, 33.466919149671284, 24.529805660247803, 28.83496856689453, 47.59708152498518, 41.616065229688374, 14.8731176171984, 2.4729153386184146, 0.42321697462882313, 0.3214333291564669, 0.6126969829201698, 5.211331333432879, 13.56798015322004, 15.686826365334646, 14.684084926332746, 9.84192441190992, 17.474378994532994, 13.729714240346636, 9.674151471682958, 17.571752786636353, 19.206778560365947, 27.900376796722412, 39.98733799798148, 51.024228368486675, 53.34518378121512, 48.36462817873274, 49.520679882594514, 51.51044593538557, 51.89799908229283, 51.509910924094065, 51.21268088476998, 50.528325012751985, 49.49995688029698, 42.26134443283081, 39.66578926358904, 39.75233602523804, 44.539387771061485, 50.044615745544434, 51.404461588178364, 52.5745347567967, 52.335968358176096, 51.38089329855782, 50.85534197943551, 53.13778005327497, 50.73517983300345, 45.416622161865234, 38.88874094826834, 40.289765289851594, 44.4388473374503, 46.344929286411826, 42.35532924107143, 39.31244209834507, 38.55709648132324, 39.794216292245046, 37.13365725108555, 46.511887550354004, 49.94167470932007, 52.206978525434224, 47.8696072442191, 51.252584389277864, 34.742184570857454, 34.9153163092477, 48.36147369657244, 44.73502819878714, 50.59073025839669, 49.654436179569785, 52.429265294756206, 45.817512375967844, 48.45963784626552, 49.627202715192524, 52.223091397966655, 48.63737971442086, 39.59119687761579, 42.53397784914289, 51.119276251111714, 52.111322675432476, 47.0733436856951, 50.18797792707171, 49.85473190035139, 51.993783473968506, 56.1945983341762, 50.70822777066912, 45.63178702763149, 38.66995259693691, 39.45863219669887, 36.94110529763358, 40.792238167354036, 41.093279293605256, 45.45813070024763, 45.74692562648228, 47.038644381931846, 44.97426857267107, 43.86120884759085, 48.20590353012085, 51.13386399405343, 51.64556407928467, 53.80363287244524, 52.638645785195486, 55.90483066013881, 49.74290064402989, 41.07587405613491, 28.19397987638201, 15.890156711850848, 16.827425275530132, 20.4329115322658, 18.872738701956614, 18.444616760526383, 17.898986884525844, 19.937034232275828, 12.389942611966815, 7.31512861592429, 2.3807759284973145, 0.2685464641877583, 0.29846844715731485, 1.6699770582573754, 11.757835456303187, 35.04774897439139, 44.25816985539028, 36.98401737213135, 31.517421381814138, 40.67906590870449, 51.088936941964285, 58.758052825927734, 44.53980813707624, 18.490355014801025, 2.3369419148990085, 0.1978082928274359, 0.18449672497808933, 0.1446455626615456, 0.13987396870340618, 0.15504130268735544, 0.15974774371300424, 0.107255202585033, 0.23616397753357887, 0.14174439119441168, 0.1707157873149429, 0.08892370374607188, 0.10515739622392825, 0.11864567494818143, 0.1350760068744421, 0.09209472859012229, 0.13463198712893895, 0.08109817294670002, 0.14462634654981749, 0.09409910746450935, 0.13522673664348467, 0.10145131937627282, 0.13301065484327929, 0.1731946114450693], [0.005061781333227242, 0.023176854642640268, 0.03316447790712118, 0.011102696331883115, 0.05403079358594758, 0.04263979196548462, 0.03145595047889011, 0.03371511586010456, 0.030676520695643764, 0.021844736034316675, 0.033519070129841566, 0.05431499797850847, 0.03485880020473685, 0.06759706991059439, 0.08076588077736752, 0.11662845819124154, 0.03767405556780951, 0.02140658052771219, 0.027321314306131432, 0.04339723042877657, 0.034592397178390195, 0.03863057281289782, 0.026420185874615396, 0.4938698677080018, 11.161664383752004, 38.58872468130929, 44.60204315185547, 37.64561094556536, 23.056683335985454, 16.10628390312195, 24.390025275094168, 32.149811676570344, 26.67714296068464, 8.374630757740565, 0.9666389248200825, 0.03020479975800429, 0.08684615165527378, 0.378292799528156, 4.07270918573652, 6.450312393052237, 4.287880565438952, 8.370586906160627, 5.276264854839869, 10.405207054955618, 5.0671223402023315, 5.588687130383082, 11.00044880594526, 13.150069458144051, 21.571151529039653, 42.69108704158238, 52.413357394082205, 51.82547378540039, 51.80151292255947, 47.76357078552246, 47.592679841177805, 46.70982435771397, 49.50634574890137, 47.22509929112026, 48.524269989558626, 47.116860253470286, 47.199130398886545, 42.62831701551165, 37.226033551352366, 34.89501019886562, 36.27325487136841, 40.952637331826345, 42.243470191955566, 45.893748010907856, 50.614729336329866, 50.15174307141985, 48.3362968989781, 48.564993381500244, 47.15464455740792, 39.18167005266462, 35.451665128980366, 34.976238114493235, 32.491562298366, 34.68622030530657, 34.784506048474995, 33.413907868521555, 35.83429547718593, 34.030894007001606, 42.00049863542829, 43.06055055345808, 48.185197898319785, 44.89686911446707, 51.960512025015696, 34.3496287209647, 37.24398422241211, 54.2986399105617, 46.456604208265034, 49.80273853029524, 45.57761887141636, 47.75702558244978, 45.632210867745535, 48.665297576359336, 49.34649896621704, 51.10933337892805, 47.6562419618879, 40.643494606018066, 34.455123220171245, 47.087900161743164, 49.425951617104666, 50.16790805544172, 45.02213471276419, 49.007687432425364, 47.141092096056255, 50.04629373550415, 46.7816652570452, 42.70154408046177, 35.24619994844709, 36.398037569863455, 36.934320381709504, 39.811374868665425, 36.75940990447998, 36.948616300310405, 34.72423389979771, 36.68616546903338, 37.14095980780465, 39.243797370365684, 40.81849888392857, 44.526578766959055, 45.25369732720511, 45.76141956874302, 48.2530574798584, 46.48922252655029, 46.08095332554409, 35.28765984943935, 29.00341374533517, 11.01032567024231, 15.702866281781878, 12.711479187011719, 6.9540663446698865, 12.659910525594439, 11.509104711668831, 4.847865419728415, 4.303177458899362, 5.413570812770298, 0.21746763720044068, 0.07378136699220963, 0.055376359062003236, 0.5785447412303516, 6.702423436301095, 24.0035525730678, 33.14701019014631, 30.278460298265728, 19.338264533451625, 26.506677593503678, 35.83225965499878, 47.12566014698574, 32.706008025578086, 9.987494383539472, 2.1347452104091644, 0.0560938284200217, 0.026201517786830664, 0.05689245056627052, 0.046472127216735055, 0.014342386375314422, 0.04027891418497477, 0.02088004074591611, 0.04333677635129009, 0.04389739555439778, 0.07878132191087518, 0.0639121090727193, 0.016724592207797935, 0.04013693073232259, 0.002363293365176235, 0.03600670164451003, 0.0136463697500793, 0.032956547636006556, 0.05690260823549969, 0.09116844008011477, 0.05673129510666643, 0.07657004413860184, 0.010036451492591627, 0.038309649497802765, 0.02236016989419503, 0.008729265653528273, 0.040434458159974644, 0.01372955390252173, 0.07672597148588725, 0.03871807668890272, 0.021901305498821393, 0.014807995408773422, 0.10261773464402982, 0.049415561237505505, 0.01905726837659521, 0.05122447792174561, 0.04198738393772926, 0.08800195463533912, 0.06602459214627743, 0.055676166367317946, 0.03089541948533484, 0.02712379445854042, 0.045825907428349764, 0.06602162016289574, 0.008877101470716298, 0.03907760186120868, 0.0515592874559973, 0.8773538672498294, 14.45757452079228, 45.8414489201137, 51.0167555809021, 43.52500636237008, 27.560172149113246, 18.07198313304356, 24.826971428734915, 33.93763181141445, 28.781048808779033, 9.584979159491402, 1.296364603298051, 0.058532697015575, 0.05732021600540195, 1.1407427596194404, 4.453186895166125, 7.595867105892726, 12.348739794322423, 9.75779562337058, 10.106332898139954, 14.550469330378942, 9.60601396220071, 9.112926363945007, 10.715768081801277, 20.928064482552664, 25.184767178126744, 43.5732616015843, 52.01476008551461, 53.5804671560015, 51.468381541115896, 49.56277206965855, 47.41496923991612, 49.30082498277937, 51.27876172746931, 49.75980908530099, 49.90930652618408, 50.55771936689104, 47.25168309892927, 41.958420344761436, 38.42346525192261, 37.768027782440186, 38.923909255436485, 41.87046309879848, 43.982062339782715, 49.11131634031023, 52.23001527786255, 51.72495767048427, 49.79161099025181, 49.82323224203927, 48.54685510907854, 40.72560146876744, 37.537833963121685, 37.01198387145996, 35.094298430851524, 36.22218908582415, 36.089930125645225, 34.949543135506765, 37.00770378112793, 36.8457030568804, 43.404343945639475, 45.39263350622994, 50.00734560830252, 46.0599593435015, 52.98502390725272, 36.48320858819144, 39.35549661091396, 54.02960218702044, 48.000275066920686, 52.14190517153059, 47.44343253544399, 49.81546415601458, 48.1127142906189, 49.75022751944405, 49.067612171173096, 51.4459353855678, 50.17315394537789, 42.04364694867815, 36.22571529660906, 48.46658257075718, 50.9469678742545, 49.850861753736226, 45.45595938818795, 48.90857137952532, 47.86582742418562, 52.105559144701274, 47.638947895595, 45.011882645743235, 37.471430029187886, 38.484741415296284, 38.02636180605207, 40.46164982659476, 38.21481432233538, 37.7704770224435, 35.309143679482595, 38.128458636147634, 38.884481702532085, 41.81750045503889, 42.7530962399074, 47.20133992603847, 47.53393629619053, 48.75249399457659, 50.6223897252764, 50.0133627482823, 49.558241844177246, 37.85829530443464, 28.626894337790354, 11.827763863972255, 11.17349282332829, 14.573301110948835, 14.913316420146398, 14.122343914849417, 11.897952829088483, 9.550348469189235, 7.532489112445286, 4.172738492488861, 1.069979265332222, 0.3278110697865486, 0.0926446472959859, 0.6238087266683578, 7.9431823662349155, 28.15168445450919, 38.50817768914359, 31.73873540333339, 25.732524939945765, 33.07256371634347, 39.62000410897391, 53.20699800763811, 39.44591351917812, 14.586066688810076, 2.7505427726677487, 0.0631687061062881, 0.02737523748406342, 0.04017861992386835, 0.08677622183625187, 0.045535966022206206, 0.0025790424801276197, 0.022399155123691474, 0.06974901658083711, 0.05200245224737695, 0.04219206063342946, 0.02255125722980925, 0.030858938050057207, 0.022446041893480078, 0.02407800343020686, 0.05551323653864009, 0.0390346675579037, 0.03803842548014862, 0.022052937719438757, 0.043967644284878454, 0.025826267565467527, 0.021422146121039987, 0.0346695567880358, 0.017794222936832478, 0.07978723650532109, 0.09154126793146133, 0.14895629563501903, 0.10888667896922145, 0.1010174165878977, 0.18347837962210178, 0.11471831426024437, 0.0523817126107003, 0.1280614747000592, 0.17780683109802858, 0.1330746542662382, 0.1815378644636699, 0.1451929775731904, 0.16111895442008972, 0.14503850229084492, 0.2014445619923728, 0.13701770268380642, 0.162971504298704, 0.113141018897295, 0.16760076875133173, 0.14096976204642228, 0.1385826894215175, 0.1194877911891256, 1.3677482243095125, 19.317611013139995, 53.34108086994716, 56.86951855250767, 50.488734177180696, 32.715071950639995, 23.318324702126638, 32.47961139678955, 43.30615200315203, 34.4556999206543, 10.921357461384364, 1.6464749936546599, 0.09122559987008572, 0.25134741993887083, 1.2503904359681266, 8.115456002099172, 13.370401178087507, 13.637880768094744, 18.898427929197037, 12.389510955129351, 21.067379338400706, 12.86976523058755, 12.797096627099172, 16.60618942124503, 18.24254403795515, 26.02511531966073, 45.423122201647075, 54.523660796029226, 53.33072110584804, 52.870545387268066, 50.21735838481358, 48.54209559304373, 48.951907294137136, 53.58244044440133, 51.80177000590733, 52.45877776827131, 51.840888363974436, 52.352491174425396, 46.32889631816319, 41.18813957486834, 39.20053441183907, 40.020807470594136, 44.52871881212507, 45.101424080984934, 49.977249486105784, 55.373717308044434, 54.88901792253767, 49.913444178445, 52.45042950766427, 51.76079995291573, 43.95356430326189, 38.40605654035296, 39.370678424835205, 35.45906148638044, 38.061960901532856, 36.4650216783796, 36.48775618416922, 38.601491996220176, 38.76799167905535, 45.184781619480674, 47.63108948298863, 51.661030769348145, 49.21803024836949, 53.90107093538557, 38.99551739011492, 40.84386675698416, 52.320935930524556, 49.49550655909947, 52.707519803728374, 50.16719586508614, 52.47486284800938, 49.93976048060826, 52.13509941101074, 51.50521741594587, 53.55865676062447, 52.689958231789724, 45.424720287323, 38.58810976573399, 50.45663349969046, 54.56795903614589, 51.42728989464896, 45.111175877707346, 49.54279599870954, 48.65569864000593, 51.9078585760934, 49.51437439237322, 45.744264466421946, 40.26434530530657, 40.46375165666853, 40.02022729601179, 43.67800916944231, 40.47969082423619, 39.864497320992605, 39.04418952124459, 40.046505383082796, 39.74047892434256, 44.47513083049229, 44.20672539302281, 49.09885127203805, 50.028607095990864, 51.31695597512381, 53.899782044546946, 51.51123455592564, 52.37216847283499, 38.46294491631644, 33.884314809526714, 15.26508287021092, 22.23338607379368, 24.07222161974226, 14.81981451170785, 25.520856755120413, 15.93825387954712, 13.655289479664393, 11.483164480754308, 7.528694527489798, 1.2361213330711638, 0.4202503652444908, 0.31159956540380207, 1.0437646891389574, 8.56904309136527, 30.187855788639613, 44.071954659053254, 40.03003815242222, 27.405592100960867, 37.10703522818429, 47.070543561662944, 60.94518593379429, 47.379345825740266, 23.23401526042393, 3.635245825563158, 0.18638777493366174, 0.1021322292674865, 0.11337037730429854, 0.12435212731361389, 0.10100436157413892, 0.11290201850767646, 0.1423019298485347, 0.147726640903524, 0.11166267429611512, 0.142835136236889, 0.13923040537961892, 0.15784549792962416, 0.1358982284686395, 0.18360990685011658, 0.20403238598789486, 0.1073719309642911, 0.14665517982627663, 0.13624704975102628, 0.1716498179095132, 0.13639340975454875, 0.1472206844815186, 0.14607048620070728, 0.1500738835228341], [0.01926677454529064, 0.020215274899133613, 0.049314540943929126, 0.04008249526045152, 0.022059955467869128, 0.03980705414765647, 0.048615266502435715, 0.07584794038640601, 0.04000208207539149, 0.018136604921892285, 0.08229495265654155, 0.04982771697853293, 0.0171731242111751, 0.06645607256463595, 0.03607315057888627, 0.06518976337143353, 0.05022700769560678, 0.05563238389523966, 0.04101389992449965, 0.021671053121930788, 0.0954991966219885, 0.02626911174905087, 0.04177034094131418, 1.1481010104928697, 18.43791696003505, 44.277048110961914, 44.39061294283186, 29.78371034349714, 20.091185229165212, 21.478174209594727, 46.153461251940044, 49.12704358782087, 30.476136548178538, 5.976127369063241, 0.7201507655637605, 0.022093067976779172, 0.15444328263401985, 1.5735680886677332, 8.312539049557277, 9.525284579821996, 12.383688364710126, 6.038763208048684, 7.845380391393389, 12.222807168960571, 10.72596195765904, 7.523455585752215, 16.983539138521465, 35.164308479854036, 36.931721755436485, 49.18185097830636, 49.112990856170654, 50.13997629710606, 49.91056415012905, 49.12695326123919, 46.015470027923584, 48.07015310014997, 44.89601101194109, 48.58803708212716, 48.62152739933559, 48.10941389628819, 46.04995046343122, 46.02845968518938, 44.394941670554026, 38.823907307216096, 36.40972096579415, 32.07623372759138, 35.34321069717407, 36.473029477255686, 42.60851117542812, 47.302939959934776, 49.61928524289812, 48.05570779527937, 46.64599125725882, 40.172208717891145, 34.895809241703574, 33.76651505061558, 35.78152390888759, 33.48035001754761, 33.72918585368565, 36.03090170451573, 37.642737865448, 34.35873086111886, 38.84909800120762, 39.952607427324565, 42.916524818965364, 43.55151373999459, 50.112694195338655, 37.37660101481846, 29.773298467908585, 51.71173177446638, 44.42098004477364, 46.7138022014073, 41.86713491167341, 43.343905040196006, 43.142560141427175, 47.324062483651296, 47.69006926672799, 48.364325932094026, 47.22950097492763, 43.42699159894671, 33.33446911403111, 43.26155846459525, 46.19328485216413, 49.731588976723806, 48.46533189501081, 48.26232637677874, 49.34592921393258, 49.64179393223354, 46.75181232179914, 46.32508870533535, 44.54253530502319, 43.38277326311384, 45.57272039140974, 48.380549975803916, 46.78296109608242, 45.77338089261736, 43.40265205928257, 39.846480642046245, 37.05510786601475, 39.61750970567976, 40.513938495091026, 44.46864816120693, 45.918289048331125, 47.77289874213082, 47.37869964327131, 52.526171820504324, 49.00787155968802, 37.66361720221383, 26.54111807686942, 20.188640662602015, 15.855071783065796, 9.339177080563136, 13.94076316697257, 13.362489785466876, 11.260357465062823, 10.249384147780281, 5.023747776235853, 1.8438725556646074, 0.6185898152845246, 0.41039537691644257, 0.08838057039039475, 0.3604715115257672, 4.002865893500192, 20.816863775253296, 43.54270689828055, 38.92165456499372, 22.37054177692958, 26.41041898727417, 36.15624025889805, 42.81808621542794, 38.745924200330464, 23.781279700142996, 2.651719629764557, 0.028659239477877105, 0.02931814787111112, 0.05994073860347271, 0.01989883670051183, 0.023782489555222646, 0.045491155569574664, 0.027189946533846, 0.07731831898646695, 0.039406121375837495, 0.03899157379886933, 0.03369246975385717, 0.019175989952470576, 0.03445929574913212, 0.02800530644266733, 0.01123464001076562, 0.022538215786750828, 0.043614711080278666, 0.04099716046558959, 0.09000969904341868, 0.02845329901070467, 0.02179749812265592, 0.06317754741758108, 0.0232617071430598, 0.027521468565932343, 0.02021968368041728, 0.03312414578561272, 0.06358697544783354, 0.04686630517244339, 0.021582405914419463, 0.0682044266057866, 0.0580935695075563, 0.06259720320148127, 0.05456716534016388, 0.060012697242200375, 0.05807527620345354, 0.013884432065034551, 0.01775046930249248, 0.027135645072641115, 0.017407008446753025, 0.04576075788853424, 0.02212636877915689, 0.03644756959485156, 0.022523501754871438, 0.055224506317504814, 0.04332655422123415, 0.03512400561677558, 1.753698508654322, 23.71919928278242, 49.90117365973336, 49.82487896510533, 36.62075512749808, 22.167001247406006, 24.336550201688492, 37.72019638334002, 46.434213638305664, 30.456170899527415, 6.803020758288247, 0.743069018636431, 0.0987803205581648, 0.46153734837259563, 1.329148592693465, 4.281475629125323, 10.989725129944937, 10.952611327171326, 13.109076823507037, 13.053517290524074, 14.811226538249425, 12.976609417370387, 9.958110451698303, 13.469605820519583, 27.392871686390468, 35.84566967827933, 49.03918709073748, 49.36467892783028, 49.66402816772461, 51.48251417704991, 50.658558573041645, 46.69618156978062, 48.292877605983186, 46.91190923963274, 51.380219323294504, 50.13947255270821, 51.246900762830464, 50.06203487941197, 49.22941139766148, 46.179899147578645, 38.98355259214129, 37.76873302459717, 34.94725022997175, 37.659840856279644, 38.99152912412371, 46.42007405417306, 48.70230368205479, 50.96405349458967, 50.35519674846104, 47.66844647271292, 42.153428486415315, 36.18772602081299, 34.93646315165928, 36.92620141165597, 34.99270534515381, 35.538246631622314, 36.866860321589876, 38.72044168199812, 36.35596970149449, 41.13668816430228, 42.12267575945173, 44.494849818093435, 47.22077751159668, 52.03007391520909, 38.80583504268101, 32.30436740602766, 52.256216934749055, 47.29571730749947, 47.7095832824707, 44.29031917027065, 45.20766551154, 45.09123454775129, 49.647310801914756, 49.30692550114223, 49.842489174434114, 50.43262052536011, 45.310599599565776, 35.1445061138698, 44.8979252406529, 48.373897075653076, 52.08839362008231, 48.71457420076643, 47.421698570251465, 49.280789852142334, 51.099466936928884, 49.79094743728638, 48.09238386154175, 45.588211400168284, 44.733909538814, 46.34120852606637, 50.013915130070274, 47.719755445207866, 47.76757642201015, 43.85772085189819, 39.926624638693674, 38.75122914995466, 40.25163357598441, 42.27598428726196, 46.761564118521555, 47.67319209235055, 49.990791525159565, 48.718472140175955, 53.67887796674456, 48.934814725603374, 37.66042103086199, 29.115432603018625, 21.146015575953893, 9.912102086203438, 11.437526106834412, 11.84800830909184, 15.08272566114153, 12.224061318806239, 9.404850585120064, 7.273351269108908, 4.632003128528595, 0.9010109092508043, 0.2687136280749525, 0.0759053308782833, 0.4527719515774931, 4.56148282119206, 21.959220579692296, 38.13681731905256, 39.07962185995919, 22.89973395211356, 28.71698120662144, 42.29129811695644, 46.79041651317051, 45.167049816676546, 26.60847565105983, 3.8947341186659674, 0.025859732912587266, 0.02978699521294662, 0.08158895732568842, 0.010709958566751863, 0.0123480421856844, 0.04854544524901679, 0.05235451353447778, 0.017508093201156174, 0.0573622105377061, 0.022922370083896176, 0.05506276392510959, 0.02876242429816297, 0.0686932025211198, 0.027224826626479626, 0.02154298302983599, 0.03731228444459183, 0.03728078006367598, 0.049381905900580544, 0.058304302128297944, 0.06881228541689259, 0.0057780653753850076, 0.02205380963693772, 0.031937754446906705, 0.07748151344380208, 0.06216831478689398, 0.13700437625604017, 0.10201545339077711, 0.12268142481999737, 0.10391740740409919, 0.25870081250156673, 0.18549892120063305, 0.10195821217660393, 0.09449739394975559, 0.17998902685940266, 0.36439800368888037, 0.07514396030455828, 0.12986728708658898, 0.13921830031488622, 0.15852141380310059, 0.17143240171883786, 0.12201365136674472, 0.07176262353147779, 0.1504268031567335, 0.12402349923338209, 0.1305711178907326, 0.13371749834290572, 3.0564204965318953, 29.003396374838694, 57.31372731072562, 56.44845076969692, 41.37913165773664, 28.01956966945103, 30.888762269701274, 56.32178510938372, 57.4540114402771, 36.4517263003758, 8.065158861024038, 1.2379398069211414, 0.21701170238001005, 0.9231023809739521, 1.9341439860207694, 16.466271809169225, 23.530566113335745, 20.498172487531388, 16.0588207585471, 18.54566614968436, 21.933564356395177, 19.649913821901592, 14.343201960836138, 22.79294535091945, 39.8741831098284, 37.662432534354075, 51.264931338174, 49.98168591090611, 50.30179636819022, 51.5132669040135, 50.377503940037315, 47.510475703648154, 49.2183255468096, 46.59980310712542, 51.635009765625, 51.14942795889718, 52.66491344996861, 52.56035695757185, 50.117436340876985, 48.18655627114432, 42.49960511071341, 40.02773829868862, 35.73592982973371, 39.42614936828613, 41.00612456457955, 47.58706569671631, 50.43297488348824, 53.06847872052874, 52.077544007982524, 48.645703656332834, 44.12575108664376, 38.63180698667254, 36.58965499060494, 38.65153987067086, 36.70263964789254, 37.182589939662385, 38.723592690059114, 40.84334911618914, 38.33246469497681, 43.601933343069895, 44.37156445639474, 45.85869434901646, 49.5349097933088, 52.990158626011436, 41.72400549479893, 34.77253777640206, 53.552417278289795, 49.827501910073416, 49.74170902797154, 46.34746190479824, 46.880208083561485, 48.26505701882498, 50.18306902476719, 52.75137683323452, 51.838588510240825, 51.202387128557476, 47.28653178896223, 37.38659599849156, 48.26363263811384, 50.42032221385411, 53.84864330291748, 51.00470045634678, 48.22622353690011, 49.77607829230172, 51.687114306858604, 51.29660470145089, 50.90739788327898, 47.84572628566197, 46.38574300493513, 48.87723500388009, 51.32585661751883, 51.177800927843364, 50.365122250148225, 46.837351594652446, 44.04943902151925, 41.26021671295166, 42.87520735604422, 44.42520802361624, 50.088615213121685, 50.64443983350481, 52.70613363810948, 51.54417596544538, 57.261622769492014, 51.77165303911482, 39.74296290533883, 29.917101860046387, 26.095474515642437, 22.76930931636265, 19.09494730404445, 22.38052633830479, 21.269663981028966, 22.34624740055629, 20.356429236275808, 11.408349752426147, 5.419294825622013, 1.8641942994935172, 0.7801411865012986, 0.2728105139519487, 0.8096156620553562, 5.299378037452698, 25.428240742002213, 50.86965526853289, 49.79808323723929, 31.37823506764003, 35.45459726878575, 47.25177342551095, 53.623573780059814, 52.26944977896554, 34.69667387008667, 5.430600847516741, 0.1606035663613251, 0.1538306197949818, 0.27972133883408135, 0.09449687826314143, 0.054003760750804625, 0.1367578644837652, 0.17423127724656037, 0.1895857783300536, 0.15575609861740045, 0.1102344123646617, 0.1288153813885791, 0.09935547398137194, 0.16599090370748723, 0.09496645842279706, 0.11124994180032186, 0.11461491909410272, 0.09378278800951582, 0.1782220131052392, 0.1813728447471346, 0.22173571746264184, 0.10789761239928858, 0.11463687648730618, 0.09512991750878946], [0.05895896628499031, 0.018659516237676144, 0.01786767435260117, 0.020467666177345172, 0.033661467488855124, 0.010160463097106134, 0.04724188109061547, 0.0048197224470121515, 0.04572959616780281, 0.019757855783349702, 0.02632671089044639, 0.04291675978207162, 0.0527778142131865, 0.015434890519827604, 0.05898665729910135, 0.03517306709129896, 0.03977178729006222, 0.07328274553375584, 0.030516871583781073, 0.0255253389810345, 0.04169063682534865, 0.04047478688880801, 0.01304672799804913, 1.052023383123534, 20.166861534118652, 40.403156416756765, 44.222998074122835, 33.8620354107448, 20.43547715459551, 18.973336458206177, 42.76559257507324, 47.88882596152169, 24.425603525979177, 4.797892238412585, 0.4395934173039028, 0.10030484625271388, 0.155377381082092, 0.7458233822669301, 1.1567534719194685, 7.758593048368182, 12.877649698938642, 9.112858619008746, 14.738642181668963, 12.409216914858137, 12.138531599725995, 10.559515254838125, 14.048455902508326, 37.77697358812605, 38.013580594744, 50.05917569569179, 51.70048611504691, 52.10744558061872, 49.53974573952811, 51.896411418914795, 48.04321493421282, 49.26654951913016, 46.393420764378135, 46.879839829036165, 46.948606150490896, 47.70813805716378, 48.9924396106175, 48.81306838989258, 46.39886120387486, 46.73315988268171, 42.9545453616551, 42.78547484534127, 36.783071994781494, 34.231293950762065, 33.521611894880024, 37.98678486687796, 42.55560411725725, 44.018196446555, 42.3444379397801, 39.047041756766184, 34.526581968579976, 33.91412952968052, 32.53983838217599, 34.58984184265137, 38.49146032333374, 41.32340015683855, 42.18920128686087, 36.595234394073486, 36.98055369513375, 38.047157764434814, 41.67833498546055, 43.50822646277291, 50.76069361822945, 37.192605767931255, 33.26167631149292, 53.817894050053184, 46.472658021109446, 46.13696275438581, 41.46584517615182, 37.54501840046474, 35.91864660808018, 42.11113132749285, 46.207761423928396, 50.41037239347185, 48.27723721095494, 44.266302721840994, 34.074473108564106, 37.23251274653843, 44.63963985443115, 49.63479709625244, 48.83557707922799, 49.410481452941895, 45.99832534790039, 48.99747358049665, 48.46592249189104, 45.92694650377546, 46.23373031616211, 48.150839056287495, 49.931777000427246, 50.04060663495745, 48.04862410681588, 49.20029149736677, 46.41220869336809, 47.850680351257324, 45.199129649571006, 43.8747752053397, 43.316678524017334, 46.13467332295009, 47.47540119716099, 50.748655864170615, 51.72076095853533, 48.21014540536063, 44.610485213143484, 37.05063322612217, 30.247158663613455, 19.45405626296997, 12.8671327318464, 11.428022708211627, 14.41667742388589, 14.144205553191048, 11.353687405586243, 5.896999112197331, 8.099073018346514, 3.608153279338564, 1.9338078669139316, 0.43531614967754906, 0.12310955327536378, 0.1564465622816767, 2.8696021097046986, 18.475869757788523, 50.13772855486189, 59.005318369184224, 44.190466608319966, 27.23415572302682, 33.394543239048545, 45.87158325740269, 40.4662321635655, 22.979120595114573, 3.3593476244381497, 0.030770596183304275, 0.021867678999634724, 0.026257400234629, 0.05360455485060811, 0.027383985496791344, 0.05236425729734557, 0.04917412829984512, 0.037073840453688583, 0.030139022573296512, 0.033330773269491534, 0.07820905904684748, 0.030614431348762343, 0.004411612471033419, 0.04293097509071231, 0.02197027179811682, 0.041088233435792584, 0.03456081137327211, 0.004850001224050564, 0.04044801868232233, 0.028826338904244558, 0.04056457742782576, 0.03417307610756584, 0.04058611073664256, 0.03852915557633553, 0.012145661482853549, 0.01836232638119587, 0.011871864969309951, 0.006144365295767784, 0.07072225292878491, 0.087176577853305, 0.003998880823408919, 0.047071351669728756, 0.08033888547548226, 0.016351196083373258, 0.028097836566822867, 0.022799034469894, 0.005637311767454126, 0.029009319442723478, 0.06537173289273467, 0.0329526121328984, 0.015436038940346666, 0.06528267517153706, 0.016378653002902865, 0.08628800231963396, 0.02563902921974659, 0.025081943487748504, 1.7069214986903327, 26.53006522996085, 46.947216510772705, 49.31215054648263, 37.48847048623221, 25.98196700641087, 21.900193895612443, 43.43646199362618, 50.39033031463623, 26.59605748312814, 5.68190199136734, 0.40907120225684984, 0.10644381040973322, 0.1623146009764501, 2.473226487636566, 5.407280087471008, 6.177223001207624, 10.830175382750374, 10.544634819030762, 13.451884440013341, 13.643495781081063, 12.80318672316415, 11.43970697266715, 15.715527636664254, 32.90715142658779, 40.630939211164204, 49.27358109610421, 52.48963124411446, 50.937448842184885, 51.18593379429409, 51.82199968610491, 49.89643498829433, 48.39845895767212, 46.66831929343087, 47.052749225071494, 47.95720318385533, 48.11831453868321, 50.337468419756206, 50.5220890045166, 49.03867639814104, 47.83605439322335, 45.57991177695138, 42.376889501299175, 37.481949601854595, 35.346795967647004, 36.70621102196829, 40.32620164326259, 45.356270108904155, 46.21603325435093, 44.596158027648926, 40.83032471793038, 36.48551539012364, 35.70099776131766, 34.589008058820454, 36.05374738148281, 40.44384854180472, 43.118036474500386, 44.445715631757466, 38.79988043648856, 39.056275912693565, 38.97128554752895, 43.38466664722988, 45.07767513820103, 51.443479197365896, 39.75234644753592, 34.92586714880807, 52.986549036843435, 49.118743964603965, 48.91000270843506, 43.500402791159495, 38.63022627149309, 39.357772145952495, 44.84234660012381, 48.142699241638184, 51.793543338775635, 50.61199869428362, 45.292899063655305, 34.99799987248012, 38.5359148979187, 48.32044458389282, 51.83000748498099, 50.28849056788853, 50.20614399228777, 46.49621588843209, 48.79404769624983, 49.829815660204204, 48.63371801376343, 48.358993189675466, 50.091880866459434, 52.617165429251536, 51.949544293539866, 50.90717554092407, 52.01722322191511, 48.37222950799124, 48.99811628886631, 46.09582247052874, 45.57072625841413, 45.52059153148106, 48.5800918170384, 49.02545745032174, 51.96451071330479, 52.43035616193499, 51.8935661315918, 46.03218044553484, 40.629799706595286, 28.851170028959, 24.593159335000173, 11.728763324873787, 10.852618932723999, 8.934008513178144, 9.730221697262355, 11.435241886547633, 12.230847103255135, 10.532703025000435, 5.871460574013846, 2.029013386794499, 0.6590860337018967, 0.08963233857814755, 0.13072381541132927, 3.2865259434495653, 18.610025576182775, 50.74737739562988, 57.869621413094656, 37.699535914829795, 29.048273052488053, 38.699722153799875, 50.401506492069785, 46.854440689086914, 26.71331180844988, 4.6639279297419955, 0.05572366721129843, 0.08517128974199295, 0.018827229738235474, 0.012092198012396693, 0.037869161527071676, 0.03161546727642417, 0.01774104105840836, 0.10314506491912262, 0.08212776162794658, 0.022476070460730364, 0.031860099506697485, 0.049353193691266437, 0.032339403073170354, 0.05419978951769216, 0.0384919684646385, 0.1084092753008008, 0.05758066488695996, 0.035373703110963106, 0.046221964926059754, 0.05172726219253881, 0.027494101552292705, 0.027201020225350345, 0.06154465289520366, 0.11387009120413236, 0.18130710827452795, 0.10967370495200157, 0.12004598123686654, 0.1277206465601921, 0.1014665864141924, 0.17751280830374785, 0.04928145896909492, 0.11962104189608778, 0.2238947887505804, 0.09326166632984366, 0.12220680314515318, 0.10678386501967907, 0.08170508180877992, 0.1639437906976257, 0.1627858571176018, 0.13562058550970896, 0.08320906146296433, 0.19468769670597144, 0.1037212565009083, 0.15256226142602308, 0.09592513340924468, 0.18212155385741166, 2.5569904957498824, 32.81088066101074, 54.00572122846331, 55.960510049547466, 42.75790091923305, 28.919887713023595, 27.78130725451878, 49.80751541682652, 54.21690130233765, 28.649137258529663, 6.27418554680688, 0.6637920811772346, 0.17958859620349749, 0.3508518391421863, 3.75681802204677, 5.204838676112039, 14.3029762336186, 20.927995000566753, 15.177384444645472, 23.170604263033184, 18.870159183229717, 20.830074037824357, 17.900416476385935, 19.642993416104996, 36.867169516427175, 41.73685271399361, 52.82896041870117, 54.17559078761509, 53.49462563650948, 50.868932655879426, 52.13618680409023, 49.82275629043579, 49.5053973197937, 46.720882415771484, 47.159459659031455, 47.56007194519043, 47.25886058807373, 52.20521368299212, 52.692153862544465, 51.52832017626081, 50.71841730390276, 47.36773191179548, 47.077335425785606, 40.20269741330828, 38.172260080065044, 38.303709575108115, 40.67348303113665, 46.89597007206508, 47.810359954833984, 45.44458171299526, 42.45558827263968, 36.7523262160165, 36.39152363368443, 36.3979229245867, 38.55656841823033, 42.92145456586565, 45.34622996194022, 46.922098772866384, 41.444663592747276, 41.10764816829136, 42.146174567086355, 44.79174634388515, 48.239848954336985, 52.264141355242046, 42.72424731935774, 38.280460902622764, 53.29135956083025, 50.91297728674752, 50.50815439224243, 46.221633502415244, 41.62139449800764, 39.421313422066824, 46.29659761701311, 51.043127468654085, 53.989604881831575, 51.756634507860454, 47.1069347517831, 36.88062122889927, 41.240591526031494, 49.63945238930838, 54.99429702758789, 52.72508484976632, 51.349588189806255, 45.67715529033116, 49.483868326459614, 51.05258049283709, 49.584023135049, 50.82424184254238, 53.124335289001465, 55.12004205158779, 53.03460277829851, 53.283542837415425, 52.497496604919434, 50.239290373665945, 52.0324467250279, 50.492034571511404, 47.14353091376168, 48.81969002314976, 51.51639706747872, 53.18738671711513, 55.66568408693586, 53.98594318117414, 51.69537918908255, 47.696371282849995, 40.43254034859793, 33.62652274540493, 23.929648058755056, 17.708085128239222, 16.34246185847691, 23.486948796680995, 24.464110442570277, 19.911984239305767, 13.989674142428807, 15.441917998450142, 11.45450576714107, 3.642169488327844, 1.6546855930771147, 0.31794560487781254, 0.32626601840768543, 3.7158410208565846, 21.91285698754447, 54.22037540163313, 66.04872117723737, 53.83816194534302, 36.72735786437988, 44.95712736674717, 56.132682936532156, 52.228768076215474, 32.923424107687815, 6.10653246300561, 0.14641850681177207, 0.167543907516769, 0.09368622569101197, 0.168752093400274, 0.21221711965543882, 0.10861894262156316, 0.07058479530470711, 0.09755698298769337, 0.18033898808062077, 0.10860411663140569, 0.20752009669584887, 0.0735134067279952, 0.15227724957678998, 0.24615860836846487, 0.17745385718132767, 0.20800526280488285, 0.16654439829289913, 0.17282229928033693, 0.12712216510304383, 0.15630392065005644, 0.2424897423812321, 0.11363434778260333, 0.16949065162667207], [0.07178570050746202, 0.028323169564828277, 0.03256166400387883, 0.0024972319370135665, 0.06238097444708858, 0.13126607345683233, 0.03064285857336862, 0.044571174042565484, 0.05503434009317841, 0.04022414283826947, 0.04700625641271472, 0.025729477937732424, 0.038162610959261656, 0.05871172848024538, 0.008607631466085357, 0.04470041460756745, 0.010032751780402447, 0.05514650871711118, 0.024783932603895664, 0.010541872720101049, 0.02108385061312999, 0.021279093975733434, 0.024465555491458093, 1.642505509512765, 26.46253047670637, 45.17157309395926, 40.72407633917672, 30.09060185296195, 12.974229659352984, 44.9345874105181, 53.047047001974924, 44.63400486537388, 21.220031261444092, 3.056213353361402, 0.2697765396109649, 0.028554616163351705, 0.4136294105223247, 2.6638579155717577, 4.248075204236167, 4.1344691174370904, 7.301727277891977, 11.544891408511571, 12.596299767494202, 15.575599602290563, 16.502482346126012, 12.460662245750427, 20.390395505087717, 32.26923731395176, 45.423869132995605, 50.6680463382176, 49.47232389450073, 49.329326493399485, 49.31598595210484, 50.78368173326765, 49.69764007840838, 50.10449532100132, 49.415814195360454, 47.58098949704851, 45.81600114277431, 48.16125440597534, 49.69291182926723, 46.77825369153704, 48.866103989737375, 47.3216028213501, 46.19212102890015, 45.71650988715035, 45.74981607709612, 38.209016050611226, 32.41403429848807, 31.058562346867152, 34.00556434903826, 34.77938175201416, 34.77229111535208, 33.704870632716585, 34.86318397521973, 34.00358411243984, 37.054486002240864, 38.42410101209368, 44.34156560897827, 47.6757663999285, 44.98989854540144, 38.014032227652415, 35.706327029636924, 34.78694486618042, 41.067810671670095, 40.173184939793174, 49.522472517830984, 39.13776438576834, 30.501987321036204, 50.019595282418386, 45.87780884334019, 48.79082373210362, 43.39729152406965, 41.36421734946114, 33.6917211668832, 34.702364444732666, 35.90089743477957, 42.95947858265468, 39.845375878470286, 37.393856866019114, 33.21186467579433, 33.26161725180489, 35.310797350747244, 45.30418988636562, 45.78094400678362, 50.387658732278005, 48.022168840680806, 48.88395391191755, 46.98398290361677, 49.23352125712803, 48.674323286329, 48.22797448294503, 47.918022292000906, 46.628217765263145, 45.4307860646929, 50.091908659253804, 48.12550245012556, 48.209836210523335, 48.2299234526498, 47.7921313558306, 46.20767804554531, 49.76792458125523, 48.40048088346209, 48.60869060243879, 50.4266311781747, 46.47019835880825, 43.663991178785054, 41.76662574495588, 30.942228657858713, 25.164023331233434, 13.748692376273018, 11.515270369393484, 8.02462567601885, 8.018945523670741, 10.163407138415746, 8.809889367648534, 5.793686347348349, 5.180936872959137, 1.6078614656414305, 0.3911430314183235, 0.11713976146919386, 0.12612101382442883, 1.4923415843929564, 11.744458436965942, 31.510660784585134, 52.29220860345023, 52.030132974897114, 27.02159469468253, 30.667507307870046, 45.3414044380188, 44.92722579411098, 20.70452356338501, 4.47717251096453, 0.030679669098130295, 0.006072898170844252, 0.04398975434846111, 0.035697883394147666, 0.023197212389537265, 0.041024963437978706, 0.02189437935261854, 0.06821216869034938, 0.04846329162163394, 0.06053765264472791, 0.007038712617941201, 0.011999279426942979, 0.062151066426719935, 0.022249339680586542, 0.027633170697039793, 0.012863174097479453, 0.0432458017686648, 0.03779925545677543, 0.031285736576787064, 0.033023800634379895, 0.04302055528387427, 0.07150086507733379, 0.014712411877033966, 0.06572841839598757, 0.03959550049954227, 0.0231210366556687, 0.02510792459361255, 0.036003353074193, 0.058458377074982436, 0.013427580374159982, 0.03340763432372894, 0.060592824327094216, 0.04432765460972275, 0.008650637015567293, 0.04668061388656497, 0.04208155442029238, 0.05624773034027644, 0.0603582344150969, 0.058188822253474166, 0.032513684792710204, 0.007566581480205059, 0.050171344075351954, 0.0359880419314972, 0.03139479072498424, 0.09322284055607659, 0.0477275832423142, 2.6546435185841153, 31.86265652520316, 51.475989818573, 45.319072927747456, 34.63132953643799, 16.330375467027935, 35.90774141039167, 51.3969783782959, 49.369681630815776, 25.078624759401592, 3.963493057659694, 0.28636547231248444, 0.02408739265852741, 0.6654662170580455, 4.220526899610247, 5.926868115152631, 7.343590174402509, 9.767431906291417, 11.747009294373647, 10.540519748415266, 14.24269539969308, 14.981674534933907, 13.54734400340489, 21.551116398402623, 33.03064176014492, 45.44794116701399, 52.54549823488508, 51.71960408346993, 52.36420931134905, 52.78163971219744, 52.27094711576189, 50.93160193307059, 50.37637485776629, 49.43718685422625, 46.973584924425396, 45.31312526975359, 47.11936507906233, 49.680745533534456, 48.475229603903635, 50.47187089920044, 49.09689882823399, 48.15835353306362, 47.20190273012434, 46.5318740436009, 39.23738765716553, 33.82915653501238, 33.073463508060996, 36.18819849831717, 37.52988174983433, 36.810187339782715, 36.63214669908796, 36.027486664908274, 36.281912326812744, 37.24140991483416, 39.378095626831055, 46.108082566942485, 48.667680808476035, 46.07995973314558, 39.059326171875, 37.51570395060948, 37.25168282645089, 42.309884548187256, 42.6529483795166, 50.90967689241682, 40.8469934463501, 32.62572506495884, 51.77870198658535, 47.84449298041207, 50.53156982149397, 45.18897485733032, 42.94465112686157, 34.92757640566145, 37.0011168888637, 39.424342836652485, 45.876645020076204, 43.21819475718907, 39.531487533024375, 35.31985780170986, 34.85568686894008, 36.871612889426096, 47.33153527123587, 48.75598199026925, 51.85116127559117, 48.19133315767561, 49.51124422890799, 48.79209525244576, 50.41780696596418, 50.049555914742605, 52.045662198747905, 48.206508023398264, 47.935087067740305, 46.44751596450806, 52.37683418818882, 49.94193526676723, 49.478191648210796, 50.45009524481637, 49.74133382524763, 47.71110493796212, 51.43561036246163, 51.05478654588972, 52.66266918182373, 50.217507771083284, 46.62354162761143, 44.07626254217965, 40.740668637411936, 31.473668575286865, 25.119280406406947, 16.05772989136832, 10.55351722240448, 8.333532163075038, 12.991720880780901, 10.833586948258535, 16.368258782795497, 9.30012125628335, 6.264142794268472, 3.654223527227129, 0.6577107246432985, 0.22477013963673795, 0.10806683224758931, 2.1112852692604065, 13.90949627331325, 37.98904650551932, 56.76146016802107, 55.42094073976789, 29.352567672729492, 36.105872767312185, 49.60630253383091, 52.16113083703177, 24.45834343773978, 5.935466510908944, 0.09325437207839318, 0.087927614338696, 0.03658846060612372, 0.060817819753927846, 0.05884501989930868, 0.03438331000506878, 0.038661910952734094, 0.011000704885061299, 0.05701870218451534, 0.05251685643036451, 0.039333290819610865, 0.05021320290065237, 0.07506743512515511, 0.05617873011423009, 0.04145009955391288, 0.12970324446048054, 0.03094753436744213, 0.08205079540078129, 0.028085948633296148, 0.035995485460651774, 0.024585562891193798, 0.042117917111941745, 0.03587281989998051, 0.1424155437520572, 0.2059688027948141, 0.0994874354717987, 0.1334996207484177, 0.1504940731184823, 0.20243873793099607, 0.08817700988480023, 0.08578566927462816, 0.13650968351534434, 0.1538120550768716, 0.15003732405602932, 0.13949401623436383, 0.11236197248633419, 0.22280427441000938, 0.09917119065565722, 0.10510147815304142, 0.18345780644033635, 0.12435129950089113, 0.08319370621549231, 0.1492336400385414, 0.11156624089926481, 0.20040081228528703, 0.13145769174609864, 3.7960922803197588, 37.662192821502686, 58.37751388549805, 51.96805429458618, 39.884348324366975, 19.853933777127946, 51.73095743996756, 58.1887834412711, 50.60020065307617, 26.407969747270855, 4.2828366075243265, 0.5384118918861661, 0.2177090056772743, 1.4085331729480197, 5.78718934740339, 9.489494408879962, 12.369538358279637, 17.586760895592825, 20.422885281699045, 21.86976773398263, 22.147426434925624, 23.638358729226248, 18.152881009238108, 24.21582351412092, 36.879690170288086, 50.3753638948713, 55.622716426849365, 53.83930492401123, 53.296053068978445, 54.31793853214809, 54.28166198730469, 53.051549434661865, 50.99567127227783, 50.20092242104666, 47.04140976497105, 45.044407163347515, 47.87846619742257, 49.432691369737896, 49.18418557303292, 52.61873919623238, 49.841050897325786, 51.6520745413644, 50.30269268580845, 50.65414299283709, 43.123959813799175, 35.417730127062114, 34.640185015542166, 37.64581591742379, 38.938368456704275, 39.313730989183696, 38.425879750932964, 37.95272479738508, 38.58140475409371, 39.7950952393668, 41.51899889537266, 48.841653278895784, 50.72248200007847, 48.59221294948033, 41.545756408146445, 38.70343596594674, 38.8029237474714, 45.040008953639436, 44.39493819645473, 52.13831990105765, 42.766742501940044, 36.074890749795095, 51.38878992625645, 50.05972807747977, 52.441459383283345, 48.47362804412842, 45.072432722364155, 37.31453275680542, 38.56923845836094, 40.039713518960134, 47.16115154538836, 44.70167337145124, 40.63268320901053, 37.02157933371407, 36.23524475097656, 39.03370816367013, 50.06248651232038, 52.32837397711617, 53.18829345703125, 49.6920884677342, 48.50249433517456, 48.917159352983745, 51.84501906803676, 51.74533673695156, 52.560996191842214, 50.44950117383684, 48.07756682804653, 47.12948860440935, 53.579977308000835, 52.52855852672032, 51.70801796231951, 53.55918134961809, 51.371009486062185, 50.47476134981428, 53.361334868839805, 54.8118269102914, 51.55556753703526, 51.392354352133616, 47.50525760650635, 45.27669933864048, 43.359778199877056, 34.584224224090576, 28.901231799806865, 21.356177738734655, 18.37283492088318, 17.94041551862444, 20.13334342411586, 16.842947551182338, 22.35657068661281, 17.67771281514849, 9.945954578263418, 5.274908653327397, 0.6736441925168037, 0.3311473721904414, 0.4097420834004879, 2.2944202423095703, 14.72767618724278, 39.22710084915161, 60.06138896942139, 60.43801607404436, 36.52783686774117, 42.96312638691494, 55.31276076180594, 59.73897865840367, 30.277480602264404, 7.624813301222665, 0.4607200122305325, 0.15949147460716112, 0.10275656969419547, 0.13813012013477938, 0.10723724176308938, 0.10335219451891524, 0.0866121927808438, 0.09817725220429045, 0.09397995671523468, 0.2436035711850439, 0.14635566089834484, 0.14917603241545813, 0.2673248297401837, 0.14693133000816616, 0.10001667921564408, 0.26527399835841997, 0.08367936086973973, 0.1612776094781501, 0.1491541021636554, 0.11420253265116896, 0.07485309948346444, 0.08198866873447384, 0.12294458784162998], [0.02285303907202823, 0.03185098338872194, 0.027678196584539752, 0.02269930000017796, 0.016139284508036714, 0.061815191592488966, 0.05274133277790887, 0.00989247823599726, 0.03180005594289728, 0.018379744375124574, 0.04201315130506243, 0.018449329837624515, 0.08864425588399172, 0.04986885994938867, 0.040781630602266104, 0.016910595619784932, 0.04750367347151041, 0.014562017982825637, 0.03328059560486248, 0.036210733731942515, 0.05115982371249369, 0.06656133370207888, 0.08186693276677813, 3.531204802649362, 25.925241913114274, 40.82328271865845, 37.835995061056956, 24.905583347593033, 28.650742292404175, 42.828588417598176, 37.4101573399135, 29.679042679922922, 14.98866789681571, 2.8082443049975803, 0.10551261609154088, 0.031164207562272037, 0.3936805081154619, 3.168797186442784, 5.703383650098528, 4.483617399420057, 7.321040664400373, 9.21420851775578, 6.64696204662323, 11.898057920592171, 11.448441726820809, 14.45810432093484, 23.140558515276226, 37.117693764822825, 47.2010828426906, 48.73931326184954, 48.60886778150286, 46.68796532494681, 44.16229861123221, 45.67015845435006, 45.952974455697195, 48.52612863268171, 49.645406995500835, 49.66362517220633, 49.30904122761318, 49.2828882081168, 46.890269075121196, 48.68620818001883, 47.83285474777222, 49.71321446555001, 47.72446979795183, 50.06368507657732, 45.240804944719585, 45.73805625098092, 33.72812972749983, 31.337949412209646, 31.254379953656876, 31.129962035587855, 33.86365781511579, 35.65865543910435, 37.38671064376831, 40.455139364515034, 42.565484455653596, 46.16941431590489, 49.99254594530378, 46.27656248637608, 44.49525628771101, 40.06114523751395, 36.53380537033081, 34.900287355695454, 39.25604009628296, 41.030217443193706, 48.21607221875872, 40.86585085732596, 34.25636999947684, 49.61050271987915, 44.225579329899375, 49.535104342869346, 47.160008566720144, 44.982728004455566, 38.878513199942454, 34.547829559871126, 33.27408232007708, 34.83662796020508, 35.07439531598772, 34.311215605054585, 33.63881063461304, 35.29148135866438, 32.839145932878765, 39.321224621364046, 44.8293673651559, 46.354799202510286, 47.66141836983817, 46.7012676511492, 46.80765151977539, 46.616548265729634, 45.156624044690815, 48.36959266662598, 49.39895439147949, 46.71324634552002, 47.6685402733939, 45.629174504961284, 47.32934658867972, 50.51498794555664, 50.45719977787563, 48.42908661706107, 50.38490377153669, 50.550510610852925, 47.52384403773716, 45.84063598087856, 46.76071643829346, 47.84233209065029, 45.470182350703645, 42.48089708600725, 34.28195674078805, 33.74970735822405, 14.74132592337472, 16.761363540376934, 2.135776149375098, 6.578205278941563, 7.19621627671378, 16.057201828275407, 9.29297763960702, 3.5954519723142897, 2.605746005262647, 0.8041352704167366, 0.17308996777449334, 0.04630869866481849, 1.3114456683397293, 7.043882668018341, 24.207395349230083, 34.229313714163645, 49.20245238712856, 37.90030063901629, 31.764801570347377, 48.44279541288103, 46.858960492270334, 20.920298133577617, 3.0848201726164137, 0.14161823796374456, 0.02764692629820534, 0.023496066353150775, 0.026149560664115206, 0.007758021654028977, 0.03762808142762099, 0.055140978656709194, 0.03102116220231567, 0.03451895933332188, 0.06952251480626208, 0.08570408900933606, 0.045054280797817876, 0.040866264275142124, 0.01712197115245674, 0.007564587435419006, 0.03079313033127359, 0.054717158898711205, 0.07057879705514226, 0.05042709070923073, 0.03416950022801757, 0.03305145093638982, 0.01590938157668071, 0.021576439895267998, 0.05375228888754334, 0.02773895939545972, 0.06598081306687423, 0.01986195832224829, 0.030511205816375356, 0.02814691330838416, 0.043059638900948424, 0.025329121920679296, 0.046547125692346265, 0.018350867621068443, 0.0177388884060617, 0.044457376934587955, 0.05487749333094273, 0.04465257449607764, 0.014539868903479405, 0.0460550181700715, 0.05897565146109887, 0.014219930312330169, 0.026448180533147285, 0.060994021727570465, 0.02358809096871742, 0.04948242407824312, 0.021546192500474196, 4.668798616954258, 32.09790515899658, 47.48006343841553, 40.961280890873496, 28.120844875063213, 23.2308121408735, 46.135642596653526, 46.69752952030727, 36.137229987553184, 18.391159057617188, 2.88658915247236, 0.1468338788087879, 0.017216211184859276, 0.19405699840613774, 1.994524700301034, 5.787167200020381, 8.269739014761788, 5.9980228798730035, 9.959818840026855, 13.58431363105774, 15.975169658660889, 17.228549991335186, 15.571698188781738, 23.166115726743424, 39.129965032849995, 49.822158745356965, 50.749805791037424, 49.804399149758474, 48.7444931438991, 46.88077783584595, 48.44817679268973, 48.852614062173025, 50.60200023651123, 51.38181740897042, 51.8673540524074, 50.20337860924857, 49.509267466408865, 47.04877485547747, 48.43568740572248, 48.052171162196565, 49.142902851104736, 48.86548212596348, 50.96953214917864, 48.932584353855674, 46.46813474382673, 34.791930198669434, 33.2679192679269, 32.10166760853359, 32.619628020695274, 34.41435466493879, 35.52079275676182, 39.13927214486258, 42.3999262537275, 43.326121125902446, 47.73106363841465, 51.42686605453491, 47.83038118907383, 47.99793004989624, 41.37932620729719, 37.99055773871285, 36.52481092725481, 41.06650441033499, 43.18739686693464, 50.12828247887747, 43.57070813860212, 36.12229483468192, 50.45470537458147, 46.27097266060965, 51.82245479311262, 48.62053728103638, 46.62171425138201, 40.653962067195344, 37.28373834065029, 34.57767902101789, 36.5230530330113, 35.663779735565186, 36.437541552952354, 35.44207314082554, 36.24445111410958, 35.00521557671683, 41.696063314165386, 46.81858451025826, 48.10958065305437, 48.81329420634678, 47.922688007354736, 45.42365721293858, 46.796016761234824, 46.48974364144461, 49.11072574343, 48.59228937966483, 47.141015665871755, 47.059266635349815, 46.658101967402864, 48.63521882465908, 51.35350349971226, 51.81566292898995, 50.85601248059954, 52.2083021572658, 51.64982679912022, 48.29716464451381, 47.752314703805105, 45.693334170750205, 48.39176436832973, 45.84635434831892, 43.40320444107056, 35.00380856650216, 29.78096580505371, 15.881645168576922, 12.67347948891776, 5.401064055306571, 11.004725422177996, 11.412730591637747, 14.41131775719779, 12.100105455943517, 11.281076993261065, 4.162918516567775, 0.6817153937050274, 0.28467250029955593, 0.03130878980404564, 1.2966062703302927, 9.255019630704608, 28.419801541737147, 40.50315489087786, 53.424108369009836, 39.805493218558176, 36.003074169158936, 52.255977221897666, 52.638169833592, 26.386388642447336, 4.067357770034245, 0.21047943218478135, 0.030818208985562836, 0.04654996536139931, 0.02366487229509013, 0.008029080278772329, 0.028251333062403967, 0.12669086110379013, 0.06858465727418661, 0.03791274722399456, 0.04671087994107178, 0.0563579515687057, 0.0345245708179261, 0.02208780593770955, 0.04387745001752462, 0.050038951715188365, 0.046632600748645406, 0.03136860605861459, 0.10369824737842594, 0.04572556906246713, 0.06694896040218216, 0.07445223456514732, 0.03349054791033268, 0.014713997952640057, 0.1881356540002993, 0.09591301477381162, 0.23635711574128696, 0.08106521650084428, 0.11891805247536727, 0.09917634073644876, 0.15304468625358172, 0.07929157345954861, 0.20920857680695398, 0.0925688888611538, 0.12887643596955708, 0.11884272151759692, 0.17774405303810323, 0.09170499164611101, 0.10585944926632301, 0.11546916754118033, 0.20367238244840077, 0.14043827913701534, 0.06875756835298878, 0.10833856516650744, 0.10037275403738022, 0.13309889153710433, 0.230386848960604, 6.241254993847438, 40.35615880148751, 53.451477323259624, 48.55328219277518, 33.624737058367046, 38.684741837637766, 50.46731982912336, 44.74030188151768, 39.325025285993306, 19.92594838142395, 4.207270170961108, 0.29313312630568233, 0.09523836776082005, 0.7678395637444088, 6.4588877729007175, 11.669857365744454, 10.956940054893494, 14.297173619270325, 18.213648217064993, 19.610237870897564, 16.506795440401348, 15.216789415904454, 17.72508042199271, 27.03119363103594, 43.23317507335118, 52.36063098907471, 52.092423575265066, 52.244436264038086, 50.94920866830008, 49.192714486803325, 50.858222007751465, 51.62995842524937, 52.8438469341823, 53.56606701442173, 54.98144286019461, 51.445046016148154, 51.26753691264561, 49.483680725097656, 49.47551311765398, 48.21506125586373, 50.03668785095215, 49.62277323859078, 53.59285579408918, 49.5042473929269, 49.61289290019444, 37.3957120350429, 35.26949725832258, 35.3659382547651, 34.54436240877424, 36.22459316253662, 37.79401751926967, 41.140381131853374, 45.196916648319785, 45.814844267708914, 49.78558690207345, 52.867620195661274, 50.034968171800884, 48.129629680088584, 44.56870569501604, 39.56249386923653, 38.248725005558555, 41.95350449425833, 45.05833830152239, 51.5181063243321, 45.77625397273472, 38.599734101976665, 50.781413146427695, 48.02967984335763, 53.535731179373606, 51.799324240003315, 47.95749153409685, 42.811499323163716, 38.078851972307476, 35.706646646772114, 39.12907566343035, 37.95196049554007, 37.9224271774292, 37.11783272879464, 38.331526688167024, 36.42725474493844, 43.2565974508013, 48.14780964170183, 49.580868652888704, 48.921019077301025, 47.23070648738316, 46.818990979875835, 46.655034337724956, 46.23471696036202, 49.82130759102957, 48.58881875446865, 46.97414078031267, 48.17568581444876, 46.09924793243408, 49.241706235068186, 51.83741773877825, 53.012573514665874, 53.4666417666844, 53.56123454230172, 54.64146402903965, 49.44094235556466, 46.712263175419395, 46.89305877685547, 48.85820736203875, 47.448230266571045, 45.67462962014334, 38.11193929399763, 38.0688465663365, 17.958077839442662, 22.72398795400347, 9.405343907220022, 14.126875877380371, 18.54489142554147, 22.046870367867605, 19.60412171908787, 12.917942302567617, 8.322015523910522, 1.7666063074554716, 0.5048108377626964, 0.20304571464657784, 1.779615615095411, 9.51475805895669, 32.22896555491856, 45.611519132341655, 58.701174872262136, 47.84788370132446, 44.8561144556318, 57.01664318357195, 60.42605822426932, 31.877178260258265, 6.201102222715106, 0.5301681799548013, 0.07884376070329122, 0.18985603882798127, 0.12603063295994485, 0.09029899923396961, 0.100601284631661, 0.20591571421495505, 0.1360317234482084, 0.09786359939192023, 0.11557269841432571, 0.11243754771671124, 0.149440769638334, 0.07400035059877805, 0.08607543086899178, 0.19041684802089417, 0.1196894110845668, 0.11919500332857881, 0.26460645560707363, 0.15030915875520023, 0.11521516474229948, 0.17331917690379278, 0.16729066467710904, 0.06875865400901862], [0.019197658968291113, 0.03189022646152547, 0.02571859593237085, 0.04767488142741578, 0.04016811620177967, 0.04105829647076981, 0.015331622579001954, 0.018025990143152218, 0.04150373774713703, 0.04638282183025565, 0.07382089844239609, 0.0718057919293642, 0.05503536807373166, 0.02822102459945849, 0.03275688870676926, 0.017117382559393133, 0.010389406749579524, 0.0488329066096672, 0.09407791003052678, 0.024563049099275043, 0.030971574863152843, 0.03631715516426733, 0.08534136454441718, 4.013233908585139, 26.17963457107544, 41.3624837739127, 37.39772353853498, 24.502605199813843, 21.7594598702022, 31.192193576267787, 31.942769254956925, 33.68230635779244, 18.69097556386675, 2.2098224503653388, 0.23432870315653936, 1.4612663090229034, 15.84922661100115, 14.564499480383736, 5.586870610713959, 5.84678144114358, 5.724601277283259, 9.278959648949758, 10.04985533441816, 20.064822026661464, 18.38054915836879, 18.219804321016582, 28.356383596147808, 40.41590288707188, 52.17503070831299, 47.6557833807809, 44.32645675114223, 43.905719007764546, 42.6749324798584, 42.816015652247835, 43.766963481903076, 43.88649681636265, 44.3487674168178, 47.01052154813494, 46.74676098142351, 47.13035018103463, 49.0062699999128, 48.7575557572501, 47.83790608814785, 47.66275937216622, 48.04860326222011, 47.942125592912944, 47.321564606257844, 46.201622690473286, 37.31179516656058, 31.50836787905012, 32.153209345681326, 34.88047456741333, 41.43236180714199, 41.851230485098704, 47.069661140441895, 45.66701439448765, 49.90230969020298, 46.69681732995169, 45.413398197719026, 44.42687906537737, 46.462940965379985, 38.74663986478533, 35.880181380680625, 33.498561246054514, 37.63173886707851, 40.77211618423462, 49.45247983932495, 41.362275327954976, 34.46311017445156, 50.23866850989205, 42.85488040106637, 45.63386801310948, 45.97314855030605, 45.714241300310405, 39.21225254876273, 36.46850272587368, 34.700578757694785, 33.81754609516689, 33.72964096069336, 34.54194790976388, 36.04175131661551, 41.22792148590088, 31.73591790880476, 37.85256651469639, 42.33079515184675, 48.631227084568565, 48.324502331869944, 49.36906671524048, 48.083069801330566, 49.63155576160976, 48.215391295296804, 49.79337583269392, 48.146798678806846, 50.443619523729595, 48.036513396671836, 49.320269516536165, 47.18956272942679, 45.74842643737793, 44.5546738079616, 47.4076805795942, 45.47201320103237, 46.938451358250205, 47.139601707458496, 48.05420698438372, 45.792085443224224, 48.810671261378694, 48.62956646510533, 47.47793728964669, 43.12134034293038, 33.91881956372942, 23.10429412978036, 10.504911967686244, 1.2894428947142191, 11.731859615870885, 9.230371764728002, 17.0310891355787, 6.726150665964399, 8.377433487347194, 2.776904672384262, 1.031910736645971, 0.11469862317400319, 0.018500603336308683, 0.6968989446759224, 7.485026836395264, 22.601103850773402, 37.13906989778791, 34.14790514537266, 24.798654045377457, 31.882775034223283, 41.715271609170095, 44.180843353271484, 30.924948487962993, 4.956476620265415, 0.009605430781708231, 0.03909622086212039, 0.04525955121165939, 0.04604124730186803, 0.10788377707025834, 0.05361116038901465, 0.010851504364317017, 0.04204943935785975, 0.0716096003140722, 0.040231705111052306, 0.028030371526256204, 0.05118862413136022, 0.04344238014891744, 0.04464072388197694, 0.03343151875638536, 0.06330465738262449, 0.024464069499767253, 0.024744204378553798, 0.04528385294335229, 0.041794951406440566, 0.020502201913456832, 0.030342274345457554, 0.006895668530237994, 0.04403837138254728, 0.032598596664943864, 0.009755692361587924, 0.0173191653032388, 0.02160193245591862, 0.03987273294478655, 0.028664199568863426, 0.021328187680670192, 0.03475197843675103, 0.10922807707850422, 0.015781275861497437, 0.03855079405808023, 0.021244885632768273, 0.018860070833138058, 0.056130632159433196, 0.06472496688365936, 0.03103506877752287, 0.051471206825226545, 0.0707442985315408, 0.03196484495752624, 0.03315314297963466, 0.07979600996311222, 0.011942608182185462, 4.81283347095762, 30.637782914297922, 46.58623327527727, 43.111449582236155, 28.30697843006679, 27.611873694828578, 33.50760085242135, 36.90099334716797, 36.698873724256245, 18.81608830179487, 2.4768267401627133, 0.23197595083287784, 0.9053478336759976, 13.077472073691231, 10.692956277302333, 7.054077412400927, 11.892871958868843, 9.607923848288399, 9.621442437171936, 10.722368001937866, 16.336493355887278, 13.435657790728978, 15.140605892453875, 25.542283262525284, 42.423015117645264, 52.313011510031565, 50.01096561976841, 47.058839321136475, 46.05478640965053, 45.01439094543457, 43.85319062641689, 46.55206550870623, 46.06047003609793, 46.532871110098704, 49.35332557133266, 49.77368811198643, 49.63310520989554, 51.3557825088501, 50.021266324179514, 48.098658084869385, 48.026403767721995, 47.818204471043174, 50.02645662852696, 47.841623374394004, 47.97115516662598, 39.373697417122976, 32.76551239831107, 33.00149406705584, 35.904149191720144, 42.1889511517116, 43.54868582316807, 48.40256186894008, 47.99344846180507, 50.909385068076, 48.917743001665386, 48.97183820179531, 48.2867944581168, 48.95787579672677, 40.83576168332781, 37.38487631934029, 36.837320055280415, 39.171529156821116, 43.163380418504985, 51.57834720611572, 44.60066046033587, 37.54204109736851, 52.0518148286002, 43.8615597316197, 48.97304024015154, 47.91643462862287, 47.56836462020874, 41.4929917880467, 37.405005250658306, 35.57604135785784, 35.00037963049752, 34.801296370370046, 36.614748409816194, 37.70634167534964, 42.326056480407715, 33.805303369249614, 39.955890451158794, 44.62076507295881, 51.159690448216026, 49.221330642700195, 48.742311409541536, 48.963121686662944, 49.132028920309885, 47.934124742235454, 50.768524238041465, 49.08506952013288, 49.737307344164165, 48.80390024185181, 48.63038287843977, 47.46715715953282, 46.676017897469656, 45.923854555402485, 47.136822428022114, 46.48406001499721, 47.06101758139474, 47.15686103275844, 47.87217460359846, 46.245139258248464, 47.15113571711949, 47.873404434749055, 46.94777236665998, 42.921482358660015, 33.007160323006765, 22.762712001800537, 13.056136761392866, 7.706475479262216, 9.691178900854927, 12.727026649883815, 8.729310240064349, 9.550212110791888, 9.966027055467878, 3.639957355601447, 1.9151589018957955, 0.5274425862090928, 0.16633106688303606, 1.04289225595338, 7.618782264845712, 23.621490240097046, 40.89067677089146, 42.26857055936541, 33.61484282357352, 38.287124225071494, 46.204603467668804, 49.864966596875874, 35.689435958862305, 7.060903583254133, 0.1489872368318694, 0.03623640949704817, 0.03314348064096911, 0.03839057158412678, 0.04068282572552562, 0.039349307638726065, 0.03771516461191433, 0.03868606001404779, 0.020557171731655086, 0.11809102685323783, 0.046965127012559345, 0.031736497567700486, 0.029736668270613466, 0.04605719626748136, 0.005917050551423537, 0.04183245064424617, 0.015427114508513893, 0.00387313386558422, 0.09488617415939059, 0.03924861304195864, 0.05787175640996013, 0.041837543049561124, 0.024287002393975854, 0.1744927167892456, 0.1140538113457816, 0.10129069656665836, 0.09841086502586092, 0.12119315325149468, 0.14659276817526135, 0.10992627604199307, 0.0804626095507826, 0.09363182753856693, 0.17541171104780265, 0.22613953186997346, 0.22767110754336628, 0.1574128640017339, 0.12281132356396743, 0.10102405944573027, 0.134278429672122, 0.1120799733325839, 0.15801728942564555, 0.17502835233296665, 0.10093033340360437, 0.26261256688407486, 0.10633297171443701, 0.18755132678364003, 6.805680615561349, 37.82063259397234, 53.96917370387486, 49.40467970711844, 35.477491583142964, 31.22473199026925, 38.4608222416469, 40.443984031677246, 42.64445768083845, 21.942037684576853, 3.2112289667129517, 0.5292325615882874, 2.18784008707319, 18.24343514442444, 23.124122551509313, 12.654873081615992, 16.278390782220022, 16.72370604106358, 15.674766029630389, 13.043970465660095, 29.542229175567627, 25.039673158100673, 22.582571268081665, 32.427750042506624, 45.1990601675851, 55.71664217540196, 52.861283438546316, 48.7426483971732, 48.50545079367501, 47.71808787754604, 45.16243621281215, 48.563193798065186, 48.44325399398804, 48.35342420850481, 51.508041858673096, 52.26039975030081, 52.26611811774117, 53.26322283063616, 51.61977236611502, 49.71652528217861, 48.33844041824341, 48.34140729904175, 50.14144584110805, 49.503128732953755, 50.365653787340435, 40.496679169791086, 34.998962197984966, 35.61585453578404, 39.194569383348735, 46.169247559138704, 45.70736953190395, 51.39588056291853, 50.10977595193045, 53.33700227737427, 50.8306793485369, 50.20022760118757, 49.65839317866734, 50.83665132522583, 42.36351074491228, 39.14265244347708, 38.16070869990757, 39.75283282143729, 45.3764511517116, 52.61614056995937, 46.24959305354527, 39.57807520457676, 54.00467899867466, 46.69570561817714, 49.45453303200858, 49.4305374281747, 50.49000917162214, 42.84981516429356, 39.13371011189052, 38.03404998779297, 37.08668742861067, 36.292546544756206, 38.8621814591544, 41.05458130155291, 43.7211401121957, 36.039896147591726, 41.257923807416645, 47.13691970280239, 53.82644380841936, 50.34371485028948, 49.344452721732004, 48.48930318014962, 51.68479013442993, 49.50159318106515, 52.355756827763145, 49.05217327390398, 53.371857915605815, 48.16764327457973, 50.183826378413606, 47.46246712548392, 47.532223565237864, 45.221989222935264, 46.681145668029785, 45.37107672010149, 46.86604765483311, 46.98483405794416, 48.28466483524868, 46.836312838963096, 48.4541209765843, 48.59414454868862, 49.045461314065115, 46.18018749782017, 37.12489904676165, 26.83964048113142, 17.32865616253444, 7.070086061954498, 24.21780722481864, 21.93170918737139, 28.790463617869786, 16.593741723469325, 18.128696066992624, 6.294155103819711, 2.9573832622596194, 0.8283335119485855, 0.2551860011049679, 1.2572257263319833, 9.64012701170785, 29.045804704938615, 48.00995390755789, 44.000523703438894, 35.93344974517822, 43.60134274618966, 53.040967328207834, 57.35134833199637, 42.431821959359304, 9.707191024507795, 0.45626165717840195, 0.1634894979319402, 0.10329489223659039, 0.2869978940912655, 0.23161985565509113, 0.1234684440174273, 0.20410428355847085, 0.1999814369316612, 0.12921391214643205, 0.16503597423434258, 0.11101362162402698, 0.11940328643790313, 0.1275305346186672, 0.21430548759443419, 0.14267549051770143, 0.21029052803558962, 0.11662845819124154, 0.11420118915183203, 0.16729831855211938, 0.11474081448146276, 0.11401039867528848, 0.10259730395461832, 0.08237623436642544], [0.027957591860155975, 0.03786798766148942, 0.05438424586983664, 0.059228120770837576, 0.04404534672253898, 0.04906746938026377, 0.062039399918700965, 0.07216123571353299, 0.04507611266204289, 0.04375418734603694, 0.022549116451825415, 0.017055883537977934, 0.01882386250820543, 0.10207314922341279, 0.018803323253190944, 0.026271149050444365, 0.030575032212904522, 0.051221984305552075, 0.03157797482396875, 0.02998042179803763, 0.05758738238364458, 0.0209146867439683, 0.0797772416844964, 3.6078162917069028, 27.183607578277588, 43.39197615214756, 38.6804131099156, 22.492194311959402, 18.343977315085276, 28.958095857075282, 30.609010423932755, 31.203845705304825, 13.151167273521423, 1.8341565855911799, 0.312165870730366, 2.0030796698161533, 7.104498318263462, 6.375219302518027, 8.410148211887904, 7.88779045854296, 5.185444516795022, 7.372211541448321, 17.624076196125575, 16.70628343309675, 12.765246084758214, 17.320915869304113, 22.050730092184885, 48.043690885816304, 48.824230670928955, 48.06866618565151, 44.42560407093593, 40.0953095299857, 36.326057706560405, 35.842827865055625, 34.707995959690635, 36.414459637233186, 39.34845461164202, 39.95735304696219, 42.546328272138325, 44.09599542617798, 44.6306106703622, 46.54903609412057, 48.3037028993879, 46.353239331926616, 45.831558159419465, 46.98416008268084, 47.57275588171822, 45.69900737489973, 37.79063722065517, 32.68243973595755, 35.90459387642996, 41.42286014556885, 48.4286801474435, 46.420021942683626, 48.947113037109375, 47.873988083430696, 46.130754538944785, 42.574489321027485, 46.4972859110151, 48.02491685322353, 42.22009645189558, 36.88154533931187, 34.073166847229004, 34.27964299065726, 39.87826517650059, 40.856602805001394, 48.40509101322719, 40.315782819475444, 35.597226415361675, 51.652720723833355, 42.536812714168, 44.417047364371165, 42.665205001831055, 42.64911297389439, 38.95773656027657, 33.90743146623884, 34.28278705051967, 33.82449081965855, 35.202784129551475, 34.64051505497524, 33.53639766148159, 33.30711753027779, 31.957197189331055, 36.201094354902, 44.96530539648873, 49.19278744288853, 47.61812761851719, 46.0030813898359, 47.65805196762085, 48.26384803227016, 49.287751947130474, 46.697678906576975, 44.44196707861764, 44.50427852358137, 45.2197380065918, 45.58770765577044, 46.874430656433105, 44.36910826819283, 45.99432665961129, 46.956794602530344, 45.73659712927682, 47.81808982576643, 44.79580756596157, 46.76746661322457, 45.33703054700579, 49.45263269969395, 48.37854194641113, 49.79264974594116, 41.070339815957205, 39.07627630233765, 24.635093450546265, 12.202039003372192, 7.52266001701355, 8.87926365647997, 10.654526659420558, 5.429559051990509, 11.585762449673243, 12.330480796950203, 3.054759008543832, 1.072331121989659, 0.3329604449016707, 0.064726154319942, 0.4362074461366449, 6.271962123257773, 23.33940553665161, 34.64618131092617, 21.40024495124817, 19.700164931161062, 32.6305262701852, 38.135069847106934, 44.165571212768555, 25.732874086924962, 8.144387432507106, 0.36496903161917416, 0.06809208156274897, 0.0023095610252182397, 0.0403489322135491, 0.025646839157811234, 0.04838581310052957, 0.014886746183037758, 0.028978812508285046, 0.018069146666675806, 0.07326061850679771, 0.021860515366175344, 0.06483483527387891, 0.011714785808830388, 0.02808557035002325, 0.018883051117882133, 0.08443982899188995, 0.061621693761221, 0.03845685088474836, 0.019822253845632076, 0.03859080048277974, 0.050985874475112984, 0.012232308708397406, 0.05921923874744347, 0.027149356569030454, 0.030097106072519506, 0.07511456616755043, 0.09529602966670479, 0.009300486966302353, 0.02424565246993942, 0.031137497031262944, 0.02457406002629016, 0.013666125297147249, 0.016517540639532462, 0.052634348161518574, 0.051339564246258566, 0.06929141256426062, 0.10782756044396333, 0.01757573296449014, 0.029825027100741863, 0.017259381279083233, 0.028256966599396298, 0.010765326176104801, 0.037606113856392245, 0.018842162597658377, 0.025063594204506705, 0.08288801940424101, 5.027451600347247, 32.330510003226145, 48.242447580610005, 43.00339467184884, 29.820681708199636, 21.993933779852732, 34.992093903677805, 35.03681598390852, 35.30532911845616, 15.072732414518084, 2.0569698980876376, 0.310883710959128, 2.696299923317773, 10.350443959236145, 11.541171516690936, 8.957237209592547, 4.995856838566916, 9.41068707193647, 11.432508638926915, 10.105775305203029, 9.821747711726598, 6.878319689205714, 15.514033351625715, 27.813376665115356, 46.93140588487898, 52.40028783253261, 49.60204676219395, 46.56973130362374, 42.16865198952811, 39.47432470321655, 38.078122411455425, 38.593247958592, 39.54688821520124, 43.11301987511771, 43.83817209516253, 45.78765596662249, 46.013225759778706, 47.301706654684885, 46.26122433798653, 50.60913951056344, 46.58518409729004, 47.108755179813926, 47.83387613296509, 49.1615309715271, 47.42825419562203, 39.18509898866926, 33.97808074951172, 36.78225210734776, 43.27763312203543, 49.096825872148784, 49.291219098227366, 50.49095065253121, 47.863854135785786, 45.83723136356899, 44.51519066946847, 48.29051521846226, 49.477614947727744, 44.73085233143398, 38.24818304606846, 36.48905202320644, 35.98148611613682, 40.7156412260873, 43.111585072108674, 49.8346655028207, 42.00248234612601, 38.39810085296631, 52.13423088618687, 44.10695273535592, 46.134193897247314, 44.062762192317415, 44.2555364881243, 41.412146023341585, 35.71526936122349, 35.564486503601074, 35.777021476200645, 35.655417578560964, 35.314195019858225, 34.40613147190639, 35.38924598693848, 34.5976550919669, 37.772047315325054, 45.802476474217, 50.69306680134365, 50.364601135253906, 48.11192914417812, 47.65236486707415, 51.010825293404714, 51.225976262773784, 48.64053419658116, 46.09387697492327, 47.413458006722585, 47.82967594691685, 46.29608345031738, 45.71868119921003, 45.133417061397004, 45.86903326851981, 47.18815919331142, 46.17559126445225, 46.274700369153706, 46.37974670955113, 46.600494452885215, 45.27080379213606, 48.10330295562744, 50.015846729278564, 48.87881571905953, 43.53960452760969, 36.60194635391235, 25.482924801962717, 12.200821331569127, 10.65900651046208, 7.609826905386789, 11.056757875851222, 9.520136833190918, 12.089655365262713, 8.873962180955068, 5.024823009967804, 1.7455038683755058, 0.2666674650141171, 0.04446195365328874, 0.4712229200771877, 7.09750452211925, 26.04459806850978, 40.45563963481358, 26.56631224496024, 22.530652591160365, 36.42079986844744, 43.866426944732666, 51.15965918132237, 30.95024687903268, 9.486360771315438, 0.5635682791471481, 0.02869205343137894, 0.0842258936858603, 0.022129359422251582, 0.05011072036411081, 0.028300928883254528, 0.07640659862330981, 0.06265311448701791, 0.037471512864742956, 0.029979577021939412, 0.03179739269294909, 0.04023790352844766, 0.026777641515114477, 0.001959154939478529, 0.06408617366105318, 0.02947424485215119, 0.02321340223508222, 0.030889512837997506, 0.04638963771451797, 0.08776619085775954, 0.06682491063007287, 0.03261823346838355, 0.030712693397487913, 0.13098122445600374, 0.1563641745597124, 0.1474971060774156, 0.14333242098135607, 0.11140502776418414, 0.14561487707708562, 0.13154580630362034, 0.16194949485361576, 0.09339282036359821, 0.11247999008212771, 0.1406697817146778, 0.08712918896760259, 0.18127869122794696, 0.17911086683826788, 0.12278401931481701, 0.09719455029283251, 0.12379291946334497, 0.08984514751604625, 0.15070063274885925, 0.11380725886140551, 0.157226863982422, 0.16052101579095635, 0.2041766561035599, 6.401338449546269, 39.78757381439209, 55.049979891095845, 50.20762743268694, 33.69593177522932, 28.94209589276995, 36.99761847087315, 38.997827666146414, 37.1350017275129, 17.033630439213344, 2.506399141890662, 0.5577442230922836, 2.565820570502962, 9.09059919629778, 8.867053065981183, 17.336931467056274, 18.64657657487052, 11.966526338032313, 14.9266482761928, 26.88906822885786, 25.16849970817566, 20.97052492414202, 22.008292232240947, 24.81507784979684, 52.1747145652771, 53.66822290420532, 53.75713552747454, 48.59552724020821, 43.77791731698172, 39.90778807231358, 40.770115103040425, 38.054533277239116, 41.30487278529576, 44.11630848475865, 45.27628592082432, 47.200363704136436, 48.722245012010845, 49.216637134552, 51.50415434156145, 53.49095698765346, 48.063319546835764, 47.229879651750835, 49.93349667957851, 49.867659023829866, 50.014853136880056, 40.871812411717, 36.07152782167707, 38.354476588112966, 45.311207566942485, 52.255445684705464, 50.727227619716096, 50.39686162131173, 50.450960295540945, 47.034503255571636, 44.773670605250764, 49.18813909803118, 51.59445660454886, 46.53146757398333, 40.14161927359444, 37.51611736842564, 37.64489528111049, 43.64887537275042, 46.35528210231236, 50.95655638831002, 45.184399468558176, 41.38260923113142, 52.92342117854527, 45.990783078329905, 48.851550987788606, 46.113116536821636, 45.83553947721209, 44.60408244814192, 36.99200085231236, 38.20994016102382, 39.12371512821743, 38.28052691050938, 36.98601497922625, 37.15320948192051, 35.542019503457205, 36.10574769973755, 39.695214884621755, 48.72636181967599, 52.66479185649327, 52.23320797511509, 50.420648779187886, 48.44288921356201, 52.05804736273629, 52.654810769217356, 51.20063965661185, 48.85303095408848, 48.601144858769004, 48.24893372399466, 46.64176675251552, 49.3992531640189, 44.79174634388515, 47.25516414642334, 48.85873195103237, 45.895822048187256, 47.34762382507324, 45.30992562430245, 48.075058528355186, 44.23545619419643, 50.494754791259766, 50.46412713187081, 52.65223298754011, 46.42017480305263, 45.15841320582798, 29.690858091626847, 18.779660633632115, 12.79664933681488, 13.469552840505328, 15.233565841402326, 15.235282046454293, 22.494436843054636, 17.090423277446202, 11.065319793564932, 2.8172061783926825, 1.1247488749878747, 0.22275088727474213, 0.849575837807996, 8.180562359946114, 29.066310576030187, 42.78930330276489, 32.399488244737896, 29.917887006487163, 45.5845809664045, 47.89395373208182, 59.108624185834614, 36.52135419845581, 12.676704321588788, 0.7244377498115812, 0.16254690422543458, 0.15489140073103563, 0.1704418762986149, 0.14146947594625608, 0.10950316196041447, 0.10200829484633037, 0.11781254251088415, 0.09824501749660287, 0.08555343387914555, 0.1138393399970872, 0.11858300545385905, 0.160879255139402, 0.15969280951789447, 0.20970413807247365, 0.24429993810398237, 0.19074372548077786, 0.09693675448319741, 0.15631526575556823, 0.16627845327769006, 0.17892492110175745, 0.12557258111025604, 0.148304264194199], [0.04314701385529978, 0.047753259007419856, 0.05312298158449786, 0.060316077034388266, 0.053997945705694814, 0.05329567213941898, 0.038940469933939834, 0.08146148095173494, 0.0863708718014615, 0.054030963219702244, 0.03150930708008153, 0.021853753764714514, 0.01602065283805132, 0.03925208714125412, 0.029003202449530363, 0.054706343050513945, 0.06556156663490192, 0.019024227113862122, 0.006341424163630498, 0.05092493863776326, 0.03099643299356103, 0.03084666674424495, 0.038128562072025876, 3.766286245414189, 22.688275950295584, 42.341311250414165, 39.883542333330425, 27.607803787503922, 23.95914489882333, 19.243435519082205, 29.55181768962315, 25.822012526648386, 10.691934023584638, 1.7323907720191138, 0.048822715013687096, 0.0823926684845771, 0.40485975252730505, 0.5147591925093106, 4.470306822231837, 14.691146033150808, 10.237869245665413, 11.449946880340576, 7.990828769547599, 6.728691535336631, 9.45067482335227, 12.170402986662728, 32.057459694998606, 45.854574067252024, 47.945530210222515, 44.94850812639509, 40.892121996198384, 36.60142523901803, 35.34484004974365, 34.92106941768101, 32.54556369781494, 31.649353776659282, 32.81528581891741, 32.694894381931846, 34.4503150667463, 36.7835305758885, 39.36218077795846, 43.335681847163606, 45.712472983769004, 48.372802734375, 48.40715115410941, 46.325311047690256, 48.06836741311209, 44.51978342873709, 34.08139698845999, 30.99005310876029, 41.94056347438267, 46.63664245605469, 46.99466575895037, 47.19133799416678, 48.32134437561035, 47.04320934840611, 49.84723826817104, 50.09072399139404, 48.84738901683262, 42.02257653645107, 39.6080254146031, 33.98400756290981, 34.79837812696184, 34.319883482796804, 37.52436488015311, 41.19782536370413, 49.757783685411724, 43.73397690909249, 35.67882605961391, 47.24645110539028, 41.59040553229195, 40.79309974397932, 38.450618812016074, 38.96220077787127, 34.39201620646885, 33.911259923662456, 35.120222159794395, 37.491895948137554, 38.773220198495046, 40.07344702311924, 39.818121569497244, 35.902624062129426, 32.385108947753906, 33.00972768238613, 37.74586302893502, 45.157874720437185, 47.98606252670288, 47.189319542476106, 47.68645620346069, 42.91728564671108, 42.68471554347447, 39.59490721566336, 40.01197631018502, 42.350597517830984, 47.437717642102925, 46.94835601534162, 45.60860436303275, 46.12106875010899, 46.326638153621126, 44.985333578927175, 46.03616176332746, 45.096372740609304, 45.22067601340157, 44.71425308500017, 47.52232238224575, 47.847018650599885, 47.34769330705915, 47.98762934548514, 44.92154911586216, 35.490432603018625, 29.981633254459926, 15.439678941454206, 15.820386375699725, 4.613325067928859, 8.54792925289699, 6.545809737273625, 6.05696531704494, 5.082010158470698, 0.9471064529248646, 1.6965470782348087, 0.3788805194199085, 0.05461350588926247, 0.31680984582219807, 4.003205052443913, 16.30994428907122, 33.313172885349815, 33.87866939817156, 32.954757009233745, 42.86571959086827, 40.93060111999512, 39.82179021835327, 23.829680851527623, 9.061770251819066, 0.07263832047049489, 0.036804601150963984, 0.05174901941791177, 0.027357419154473712, 0.04791147301771811, 0.0802035177392619, 0.022043965790154676, 0.029899757555020706, 0.023942045368520275, 0.02573597151786089, 0.006426132475358567, 0.019896071670310836, 0.08331247698515654, 0.00989222208902772, 0.0268269302988691, 0.026575565304873244, 0.013288177050916212, 0.016234640730544925, 0.01994337573913591, 0.0463075417626117, 0.043528954431946786, 0.005506232372551624, 0.04105911071279219, 0.0261022481136024, 0.02789133970093514, 0.016321376165641204, 0.0480529475691063, 0.02611369839204209, 0.026899942363213216, 0.0708156872008528, 0.005214500058043216, 0.04253414406308106, 0.038264604950589795, 0.05436742498672434, 0.02085290613052036, 0.02860676497220993, 0.04205925775957959, 0.04582036040457232, 0.017203943271722113, 0.07284009642899036, 0.010993097659333475, 0.024067260524524108, 0.050883056063737185, 0.007872281013987958, 0.02709677180142275, 0.025468550688986267, 4.6352987459727695, 27.570858478546143, 47.63435861042568, 46.30262170519148, 31.56051410947527, 29.88651588984898, 24.94616256441389, 31.35779694148472, 27.57981296948024, 11.538587655339922, 1.8126206440585, 0.1597876280014004, 0.15812668284135206, 0.4383586735597679, 1.0922344539846693, 3.119847127369472, 7.776553273200989, 7.027913102081843, 11.331049306052071, 9.485576493399483, 12.952718036515371, 10.709063070161001, 17.765336547579082, 32.56883321489607, 48.50440856388637, 49.42911999566214, 46.92833478110177, 43.46412624631609, 39.06536415645054, 36.29538140978132, 36.76720230919974, 33.82594994136265, 34.08507258551461, 34.131427492414204, 36.14563730784825, 37.0272490637643, 37.797755650111604, 42.43512582778931, 46.54150077274868, 47.29380655288696, 49.2778959274292, 49.658664158412385, 47.80918918337141, 48.962069034576416, 46.3842317717416, 36.459153924669536, 32.35023941312517, 42.31823280879429, 47.914120878492085, 48.05232402256557, 48.04178013120379, 47.42102459498814, 47.5580986567906, 49.2814290864127, 50.087149143218994, 50.63591091973441, 45.57007312774658, 40.81274924959455, 36.640005111694336, 35.80485943385533, 36.3378210067749, 40.44600943156651, 43.960040024348665, 50.12468678610665, 45.08359500340053, 39.092319692884175, 48.70164360318865, 42.974785464150564, 43.05032280513218, 41.50347661972046, 41.36586059842791, 36.51427050999233, 36.63486344473702, 37.731264863695415, 38.440682888031006, 40.712333883558, 41.05431727000645, 40.81481981277466, 35.57262979234968, 34.115074907030376, 34.81349393299648, 39.56633274895804, 47.163757119859966, 49.91708156040737, 49.64187731061663, 48.793453625270296, 46.40028558458601, 45.0990686416626, 44.482259682246614, 42.36143323353359, 44.581177711486816, 49.15886981146676, 48.004826136997764, 46.993720803942, 45.86460379191807, 46.870425019945415, 45.887220178331646, 47.076967171260286, 45.70242588860648, 45.43010861533028, 46.61328608649117, 46.210151604243684, 47.94216728210449, 48.1999454498291, 50.87923683438982, 47.06030191693987, 39.97980615070888, 28.872216122491018, 17.251036099025182, 16.418902465275355, 11.925734332629613, 12.450787118503026, 8.658464670181274, 12.127119183540344, 7.582086222512381, 3.6522936650684903, 1.1400775781699588, 0.4736307965857642, 0.07262931631079741, 0.3731407102729593, 4.515598654747009, 19.82154996054513, 36.755529335566926, 38.13113021850586, 36.50144066129412, 47.476620606013704, 44.034139088221956, 47.815779549734934, 27.622561761311122, 11.520223566464015, 0.23722610196896962, 0.018048001819157174, 0.03951281761484487, 0.02221536373586527, 0.05531167092600039, 0.005918328317680529, 0.0465568999892899, 0.009875970327162316, 0.019552313955500722, 0.04927794076502323, 0.08000312599220447, 0.018298455879890492, 0.027300644433125854, 0.018618693874616708, 0.009675034055752414, 0.055438746964292865, 0.04908609516652567, 0.07259030733257532, 0.014556345430069735, 0.02879474970645138, 0.025274250490058745, 0.05614705609955958, 0.03989515852715288, 0.14801622607878276, 0.17760339272873743, 0.17736095216657433, 0.20726442470082215, 0.11035081504711083, 0.13864411041140556, 0.21943115469600472, 0.14878765254148416, 0.1609312037804297, 0.11937653858746801, 0.11347453242966107, 0.1496424302458763, 0.0751596073220883, 0.10355679996843849, 0.18827075032251223, 0.19687427580356598, 0.20002748231802667, 0.1159256316189255, 0.11459920422307082, 0.1711927160088505, 0.1497033898319517, 0.15929341023521765, 0.14352500279034885, 5.906314475195749, 33.6076340675354, 55.738386562892366, 52.69063220705305, 38.07072605405535, 33.27646555219378, 27.709299598421367, 38.97691706248692, 33.493579387664795, 14.219516209193639, 2.346522177968706, 0.24319674872926303, 0.20167375755097183, 0.48614558790411266, 1.2937756393636977, 10.094018953187124, 27.135480880737305, 18.59844466618129, 25.705030918121338, 18.80700526918684, 14.78989383152553, 16.779468808855327, 17.539245639528545, 34.3109689440046, 49.650913442884175, 52.440851415906636, 49.55392353875296, 46.14180217470442, 40.4532425062997, 39.028323309762136, 39.71782432283674, 37.04994535446167, 35.44511645180838, 36.643656390053884, 36.928317138126914, 39.04138592311314, 39.64280114855085, 43.56261001314436, 48.99333940233503, 49.252628803253174, 50.336387974875315, 50.74055079051426, 49.55730731146676, 51.56507962090628, 48.405580861227854, 37.219300746917725, 34.3121987751552, 45.51595360892159, 50.9212178502764, 47.48098407472883, 47.61015803473336, 49.277162892477854, 47.4555640901838, 51.053855487278526, 54.05824613571167, 52.94870567321777, 47.187030111040386, 42.733505793980186, 38.93526608603341, 37.72748851776123, 37.47006818226406, 41.678689343588694, 46.59107269559588, 53.82759026118687, 47.10638236999512, 41.92637177876064, 50.389253343854634, 45.738559995378765, 44.88210766656058, 43.63786595208304, 43.725527899605886, 38.23152821404593, 39.152310439518516, 40.064779145377024, 41.728528772081646, 43.000264508383616, 43.799727712358745, 43.87781851632254, 37.96046161651611, 35.116226945604595, 38.31313828059605, 40.74939904894148, 48.31379515784127, 53.3787123135158, 51.753445284707205, 50.897340365818565, 47.287316935403005, 46.97277545928955, 44.55318341936384, 44.091173376355854, 45.6073363167899, 51.836969579969136, 48.45983239582607, 46.30456372669765, 46.062564917973106, 47.08138622556414, 44.828707286289756, 47.73743513652256, 47.604658535548616, 45.6783573286874, 45.964602266039165, 47.09306614739554, 49.363900729588096, 49.38175412586757, 52.34819718769619, 49.871998173849924, 40.85053355353219, 33.29783821105957, 19.348370688302175, 22.17846577508109, 13.310701387269155, 17.258550575801305, 18.60548492840358, 16.38598711150033, 12.11545489515577, 6.664872765541077, 4.970599268163953, 0.5805167811257499, 0.2629575883703572, 0.8044149896928242, 5.083996909005301, 23.635661091123307, 43.95829255240304, 44.7378283228193, 44.185258933476035, 54.993494510650635, 51.63351590292794, 55.228496483394075, 35.29129375730242, 13.806972997529165, 0.591213370008128, 0.09118290644671236, 0.1199373070682798, 0.11306849707450185, 0.2052869429545743, 0.23528904733913286, 0.0664322084880301, 0.08863168263009616, 0.11146653017827443, 0.10857063771358558, 0.1456373365862029, 0.09823082254401275, 0.1788830283497061, 0.11616435380918638, 0.1706030419362443, 0.06708991926695619, 0.26357755224619595, 0.1430300793477467, 0.15295419682349476, 0.09542957892907517, 0.26911352947354317, 0.18843116957162107, 0.09296311770698854], [0.001962513899863032, 0.03600700359259333, 0.03548331026520048, 0.031371435549642356, 0.02704840412895594, 0.006286157486361584, 0.017496882106310556, 0.01061450141215963, 0.017260872359786714, 0.01834229942012046, 0.05243622950677361, 0.03820545705301421, 0.0518533238209784, 0.02254549477116338, 0.04617142763787082, 0.07968388883663075, 0.02940016918416534, 0.0788731344842485, 0.0353613571662988, 0.032467612264943976, 0.061379449974213324, 0.05326998619628804, 0.03913417471838849, 3.851133303982871, 21.403329951422556, 39.62762975692749, 43.18909570149013, 34.46730688640049, 18.013390711375646, 17.487372125898087, 30.640722002301896, 22.386644227164133, 9.454649192946297, 1.3729363573448998, 0.13871732433991774, 0.3817258881671088, 5.758696956293924, 24.62744000979832, 20.082340172358922, 2.5206902836050307, 6.985580333641597, 5.36279033763068, 6.485659182071686, 8.145730171884809, 5.498126915522984, 17.221183163779124, 35.38771390914917, 44.44149807521275, 46.36135482788086, 42.915833473205566, 39.06137241636004, 35.79952669143677, 34.00966726030622, 36.16306338991438, 41.31300565174648, 41.52206999914986, 39.108456884111675, 32.14734854016985, 33.61359562192644, 31.351418495178223, 32.812614236559185, 38.930944306509836, 44.37794637680054, 45.49613734654018, 46.76336022785732, 47.03470127923148, 46.879933629717144, 40.184309005737305, 33.639554091862266, 35.71176746913365, 44.893648624420166, 47.57341596058437, 48.34957490648542, 46.74309580666678, 47.82318980353219, 48.600839138031006, 47.084985392434255, 44.76244926452637, 44.08822734015328, 40.54557364327567, 35.256601401737754, 33.84478303364345, 35.154893670763286, 34.451583112989155, 38.01925032479422, 42.47610282897949, 48.03798988887242, 43.090962818690706, 35.87913220269339, 48.275847571236746, 41.471289089747835, 38.227407932281494, 33.81882803780692, 35.398865767887656, 31.74270977292742, 34.9637313570295, 36.800831590379985, 41.046382427215576, 43.61393288203648, 47.128675665174214, 45.63994768687657, 46.75067629132952, 41.9788932119097, 35.930639198848176, 31.768421581813268, 36.12689454214913, 40.738823890686035, 41.72024999346052, 38.88269601549421, 38.87512942722866, 35.8214829989842, 34.089588914598735, 37.04945550646101, 43.32529429027012, 46.6352458681379, 47.44068799700056, 45.681372846875874, 46.432257720402305, 46.88101060049874, 48.359969411577495, 46.56974867412022, 46.90315798350743, 47.26210192271641, 46.617104121616904, 46.165707451956614, 45.427152156829834, 48.784657205854145, 50.6964054107666, 47.119458879743306, 37.234684058598106, 25.514815296445573, 13.30734714439937, 13.3713287625994, 9.497232096535818, 10.355790598051888, 5.679052361420222, 12.818878361157008, 7.695872528212411, 4.120782903262547, 0.986841789313725, 0.3058150000870228, 0.05134959638650928, 0.1228145533906562, 4.27840495961053, 16.358114412852697, 28.37893397467477, 23.958733218056814, 22.440848861421856, 49.030703340257915, 41.551836081913535, 42.62019804545811, 24.34026575088501, 5.4637424520083835, 0.4757502142872129, 0.03407564187156303, 0.028197096062025855, 0.042661990238619704, 0.01049338375949966, 0.049945598867322714, 0.03440794421892081, 0.030195707388754402, 0.03196549974381924, 0.04510591392006193, 0.02849882362144334, 0.061458512874586244, 0.04062495347378509, 0.02934425789862871, 0.00891545057363276, 0.08362812469048159, 0.03237175223018442, 0.01710160492387201, 0.02363776312475758, 0.03320628923497029, 0.03507799754983612, 0.033513526498739205, 0.05664377087461097, 0.01487873777348016, 0.04499516004164304, 0.024442480211811404, 0.06678368284233979, 0.026105749354298626, 0.04739135217719844, 0.028512872689004456, 0.038149773076708825, 0.02627625672279724, 0.032540113731686554, 0.031599240111453195, 0.03230612771585584, 0.03767350595444441, 0.01624890523297446, 0.02082622274091201, 0.04481308874008911, 0.03480208146252802, 0.028771180792578628, 0.0891830941130008, 0.06812988953398806, 0.047566916327923536, 0.07309469633868762, 0.010802771979277688, 4.947679332324436, 26.266094480242046, 45.3580766405378, 48.815166745867046, 39.83412674495152, 22.92750416483198, 21.675449201038905, 34.68460832323347, 27.1176153251103, 11.658111436026436, 1.364110842347145, 0.2129027657210827, 0.07316616643220186, 2.488302992922919, 11.884058168956212, 20.558100700378418, 8.23942402430943, 11.117593697139196, 10.884076901844569, 11.55861931187766, 14.062446968896047, 9.872591154915945, 18.60863593646458, 38.0868285042899, 47.40998043332781, 48.93967499051775, 45.23586130142212, 41.11718804495675, 37.967580045972554, 34.90179511478969, 37.03850514548165, 41.12880890710013, 43.391736439296174, 38.58711617333548, 33.61200795854841, 34.88752351488386, 34.474348885672434, 33.82971239089966, 41.13189390727452, 46.386003562382285, 48.120909690856934, 48.42932285581316, 48.74733148302351, 48.218212263924734, 42.32329109736851, 35.027800696236746, 35.80955989020211, 46.36841072354998, 48.4046949659075, 47.77967323575701, 47.20013093948364, 48.16311304909842, 49.920072759900776, 49.66476467677525, 46.23746844700405, 46.86219140461513, 43.34404747826712, 38.58668538502285, 35.51915645599365, 37.19000366755894, 35.800013065338135, 39.34861789430891, 44.274484225681846, 50.717493193490164, 44.81140974589756, 38.533020973205566, 49.69796664374215, 43.00438131604876, 40.723183495657786, 35.91438736234392, 37.99122129167829, 34.63884401321411, 35.84615952627999, 39.12538616997855, 43.1717460496085, 45.83242668424334, 48.53636680330549, 47.0199294090271, 48.34431859425136, 42.971502440316335, 35.771612303597585, 33.33946139471871, 39.22465508324759, 44.27185780661446, 45.2258871623448, 42.780722277505056, 42.06823662349156, 38.076329776218955, 35.43104634966169, 38.32030187334333, 44.736258029937744, 48.28998368127005, 47.59802647999355, 45.64675692149571, 46.91138117653983, 47.45090879712786, 48.73267425809588, 47.788271631513325, 48.686513900756836, 48.42196471350533, 47.01808813640049, 45.81197813579014, 45.994847774505615, 49.815307821546284, 53.20835290636335, 48.467972210475374, 41.57938568932669, 30.304748807634624, 16.61079260281154, 15.44773190362113, 13.897341268403189, 14.308077079909188, 12.81004285812378, 8.725320237023489, 8.307505079678126, 4.0473630258015225, 1.882285020181111, 0.32375237186040196, 0.0763567534408399, 0.3173281651522432, 4.421851822308131, 19.50564316340855, 32.606277057102744, 29.53134482247489, 28.006541797092982, 55.496874128069194, 45.84348474230085, 48.93642323357718, 29.711313588278635, 8.147977045604161, 0.5367043720824378, 0.04676330694928765, 0.02578118400249098, 0.024701661929222088, 0.04057084709139807, 0.06367862517280237, 0.0256159064426486, 0.01932391058653593, 0.02004165475123695, 0.0018273026507813483, 0.03733783128804394, 0.008460191743714469, 0.03905089133019958, 0.0470737876104457, 0.06643096676894597, 0.03709069526355181, 0.10056526799287115, 0.021138447237067988, 0.014454821324242013, 0.029583037764366184, 0.007209873924564038, 0.03026486707053014, 0.034300817110176594, 0.11705267828490053, 0.15447601516331944, 0.08302835401679788, 0.27158915091838154, 0.06695145062570061, 0.1749062431710107, 0.11111790567104306, 0.11382636640753065, 0.17659356977258409, 0.09528255396123443, 0.10406230855733156, 0.2379823156765529, 0.17709276798580373, 0.14397635071405343, 0.11203251659337964, 0.21873537131718226, 0.07754894625395536, 0.1288962084800005, 0.14766952182565415, 0.18134978812720093, 0.17880704599831784, 0.20563281939498015, 0.12731146280254635, 6.252108080046518, 32.03995023454939, 51.439859185900005, 54.778016975947786, 45.369124276297434, 30.013462952205114, 27.45028117724827, 40.17016247340611, 29.490590163639613, 12.919885192598615, 2.1306427334036147, 0.3536727534873145, 1.2422801511628287, 9.816632100514003, 31.447310583932058, 24.774846042905533, 5.501725648130689, 14.666905505316597, 16.87373501913888, 18.458075421197073, 15.58681399481637, 10.921490345682416, 21.4806547164917, 39.243474279131206, 50.426273345947266, 50.798262528010774, 47.12210266930716, 43.389276776994976, 39.770377022879465, 38.17691189902169, 39.32122809546334, 46.54994283403669, 47.00323288781302, 43.054964201790945, 36.32133640561785, 37.02345882143293, 34.670736244746614, 35.63836669921875, 43.730065073285786, 48.885791710444856, 48.064101219177246, 50.08008629935128, 50.30433940887451, 50.389802251543315, 44.600118500845774, 36.449961457933696, 39.42800453730992, 49.403046880449565, 50.590118816920686, 47.86856154033116, 47.856753076825825, 49.888573101588655, 51.77078104019165, 50.17159060069493, 48.91912916728428, 48.45920010975429, 46.59229210444859, 39.73542063576834, 38.49661936078753, 38.56862701688494, 37.67284093584333, 40.983157294137136, 46.01384762355259, 52.66877317428589, 47.203726632254465, 41.703369344983784, 51.428877558027, 45.332507269723074, 41.48882981709072, 38.056735856192454, 39.997138432094026, 36.991674286978586, 37.933648518153596, 41.47064985547747, 44.8420478275844, 48.74720641544887, 50.8747170312064, 49.14535209110805, 51.53892312731062, 46.71453523635864, 37.67711060387747, 35.49738427570888, 40.41983904157366, 45.76401819501604, 46.25707278932844, 44.061202321733745, 42.64115033830915, 38.823948996407644, 36.640029430389404, 40.24517175129482, 47.40367841720581, 51.28255544389997, 49.19016449792044, 45.87750659670149, 47.800250325884136, 48.57206317356655, 50.24066611698696, 50.06164925439017, 51.12429632459368, 49.51261649812971, 46.48557819638933, 46.13947105407715, 44.96980088097708, 51.99722283227103, 53.70561810902187, 50.99066162109375, 40.53318847928728, 30.163974830082484, 16.335432018552506, 19.112434182848247, 15.472660303115845, 18.81667021342686, 11.97590901170458, 21.68642909186227, 17.438053812299454, 7.311841249465942, 3.2947956025600433, 1.9036244579723902, 0.1776939093002251, 0.34637285662548883, 5.521283958639417, 21.235815831593104, 37.70508405140468, 34.73426015036446, 32.78366109303066, 59.64774881090437, 51.455499580928254, 56.71664081301008, 36.3609550339835, 9.687771677970886, 0.937631715621267, 0.19582775767360414, 0.12821130880287715, 0.1410367198820625, 0.0866633000384484, 0.2208644106451954, 0.0920762452962143, 0.11265026844505753, 0.12959029552127632, 0.08963843860796519, 0.10310906185103313, 0.1343667342194489, 0.19115947745740414, 0.19099163503519126, 0.15612193755805492, 0.10324343892612628, 0.17773300648799964, 0.060264501587620804, 0.09796481646065201, 0.1192064027168921, 0.10523736157587596, 0.1323025764099189, 0.12002790506396975], [0.008815035024391753, 0.019435851901237453, 0.018951089520539557, 0.0340832380710968, 0.009736064039835972, 0.012734201553809856, 0.024989828966291885, 0.009475035859005792, 0.026665766357577274, 0.04799244599416852, 0.02248448259862406, 0.03298505628481507, 0.033868715832276006, 0.0419256101096315, 0.03193454836894359, 0.0661362586542964, 0.0230027832689562, 0.0547322698735765, 0.03686862771532365, 0.03375213673072202, 0.01498629235928612, 0.055385576960231574, 0.03751320544896381, 2.0422342887946536, 20.201463563101633, 38.141177313668386, 45.33557142530169, 34.21542773927961, 30.165169920240128, 19.522780895233154, 27.434347220829554, 21.299605505807058, 7.079191676207951, 1.194738187960216, 0.19752541157816136, 4.249292007514408, 21.954747676849365, 12.284157156944275, 2.5453600798334395, 3.7860686353274753, 7.068397215434483, 9.703511084829058, 6.869977942534855, 21.22159113202776, 17.768159253256663, 20.518357004438126, 38.70964070728847, 47.97163111822945, 45.49343449728829, 44.03255142484392, 37.57275908333914, 36.48351430892944, 35.635240009852815, 46.33869327817644, 45.75810180391584, 47.948882716042654, 43.19878496442522, 40.30258124215262, 32.345601490565706, 32.46849080494472, 30.738417148590088, 35.69465058190482, 41.10247870853969, 43.5505097252982, 46.1783184323992, 46.80932256153652, 40.21101788112095, 33.863529273441856, 31.212756769997732, 38.05215351922171, 45.64659711292812, 46.477045808519634, 47.01505524771554, 47.08898755482265, 46.72638191495623, 42.83370229176113, 42.62039606911795, 41.07266051428658, 39.56885494504656, 34.48203706741333, 33.66142354692732, 32.19420371736799, 33.44564029148647, 35.301639625004356, 41.1478956086295, 41.297691822052, 47.50926324299404, 43.45760188783918, 31.895747320992605, 48.61768157141549, 42.06846243994576, 38.88260568891253, 32.583021436418804, 33.13867582593645, 32.02464682715279, 35.510926314762656, 35.125728607177734, 42.411019052777974, 46.462725571223665, 47.99877773012434, 44.62293985911778, 47.791898591177805, 46.89683859688895, 45.16205753598894, 38.75704479217529, 33.21422011511666, 31.239503860473633, 32.322293758392334, 32.29231922967093, 31.502906594957622, 32.76916020257132, 34.91559771129063, 41.57811416898455, 43.67622695650373, 48.458911759512766, 47.355867862701416, 44.679994991847444, 46.43868480409895, 47.219874245779856, 46.664619377681184, 44.05395882470267, 44.759735992976594, 47.64933197838919, 48.21645436968122, 45.17567253112793, 48.062461444309776, 47.056841714041575, 51.17740140642439, 47.97789491925921, 41.007621901375906, 31.254960128239222, 22.007965666907175, 18.683895349502563, 18.682427542550222, 12.656637055533272, 10.331923535891942, 7.13144907781056, 7.20506089925766, 3.0527042959417616, 0.7201722072703498, 0.675924015896661, 0.02335638822322445, 0.2866571338049003, 2.3722127079963684, 15.502445493425641, 27.577002423150198, 33.92090402330671, 33.710213797433035, 52.91207824434553, 42.20558166503906, 43.66666623524257, 27.51865839958191, 5.35905350957598, 0.22197412752679416, 0.03062256019828575, 0.018940193944477608, 0.09665529137211186, 0.05755189500216927, 0.030953647967960154, 0.014490142464637756, 0.0042409129923076504, 0.02730485813559166, 0.009463807800784707, 0.004804349387995899, 0.04024453281557985, 0.010907765095388251, 0.04633746515693409, 0.024709806045783416, 0.04339263674670032, 0.017247147292697003, 0.006216842589700329, 0.010734714068738478, 0.04594712431675621, 0.02193819235877267, 0.06526839879474469, 0.03088510236037629, 0.04449284056733761, 0.009939536335878074, 0.08694880721824509, 0.04314697653587375, 0.041949345264583826, 0.02124740639036255, 0.03563679827909384, 0.027094614060063447, 0.0338491367043129, 0.048774698483092446, 0.035810842511377165, 0.04207577669460859, 0.05241521866992116, 0.03638635555814419, 0.04347458342090249, 0.014632407509322678, 0.023355473897286823, 0.037641543562390974, 0.04524024010502866, 0.004186492363390113, 0.0481545106906976, 0.06347292728189911, 0.033095525178526125, 2.9396551506859914, 24.86417555809021, 44.25878824506487, 50.23761933190482, 40.027484689440044, 32.592241695949006, 23.659826925822667, 32.394548075539724, 26.098342384610856, 8.63760791506086, 1.8007746168545313, 0.1422351620026997, 5.342282295227051, 22.334440674100602, 19.202354294913157, 7.275182119437626, 6.219372510910034, 7.793499061039515, 11.469463501657758, 13.754557524408613, 8.48039015701839, 8.01237860747746, 20.27578149523054, 37.21635471071516, 47.784933022090364, 46.7794383593968, 46.91602952139718, 40.84670509610857, 38.10263218198504, 37.69802120753697, 47.302186080387656, 47.27768325805664, 50.24169097627912, 45.36182519367763, 40.95850508553641, 33.68307065963745, 34.996964590890066, 34.06313017436436, 36.38874435424805, 43.237444741385325, 46.01521989277431, 47.93889468056815, 47.726821763174875, 43.56752586364746, 36.30318076269967, 32.655070781707764, 39.9903952053615, 48.82810776574271, 48.013858795166016, 46.74309580666678, 49.72317123413086, 49.38183403015137, 44.707110336848665, 44.16914258684431, 42.554318700517925, 41.27267830712454, 36.49521507535662, 35.03432158061436, 34.04249055044991, 34.8804224559239, 37.20711360658918, 43.61632653645107, 43.60291998726981, 48.67975677762713, 45.92829098020281, 34.829113483428955, 50.285165854862754, 43.61226184027535, 40.60121829169137, 34.505758217402864, 35.999641759055, 33.904023374829976, 36.389119556971956, 37.7843838419233, 45.22762073789324, 48.097904205322266, 48.70243222372872, 45.84228965214321, 51.44277048110962, 48.48262248720442, 46.4182779448373, 39.5091803414481, 34.470843519483296, 33.99050760269165, 34.180228165217805, 34.723209040505544, 32.94730159214565, 33.82782595498221, 36.68784345899309, 44.00988292694092, 46.49546548298427, 50.080367701394216, 47.43640095846993, 45.49511248724801, 47.038831983293804, 48.194383416857036, 48.63191843032837, 47.169673510960166, 47.40473106929234, 49.13707331248692, 48.2974078314645, 46.19772475106375, 47.27039112363543, 48.13395840781075, 51.09966148648943, 50.547088623046875, 43.23970290592739, 31.547138827187673, 19.575602837971278, 14.530634828976222, 14.37913283279964, 16.53316385405404, 9.825967873845782, 12.15349280834198, 7.803842323166983, 6.118848145008087, 3.1921583328928267, 0.5219528579286167, 0.0792849984552179, 0.17096084702227796, 2.9797857744353156, 16.50522862161909, 32.39158466884068, 35.60375772203718, 33.640669277736116, 55.52379839760916, 45.792755944388254, 48.79504476274763, 32.18841586794172, 6.533782405512674, 0.5048111091767038, 0.0312560981671725, 0.048369192385247776, 0.015554324557472552, 0.012975786313680666, 0.017576674431828514, 0.014660375026453818, 0.021878488062481796, 0.015670213249645064, 0.017177928239107132, 0.03491360887086817, 0.025849227494161044, 0.022493793795417463, 0.02553603608560349, 0.04469000927305647, 0.04878508685422795, 0.004112987512988704, 0.020144883676299026, 0.01097573564454381, 0.04826010770297476, 0.04866780886160476, 0.010012154849911374, 0.028503783712429658, 0.11078752697046314, 0.1278853677213192, 0.12326712267739431, 0.140671098072614, 0.11091861993606601, 0.10135644660996539, 0.10493786300399474, 0.17483411489852838, 0.09564308675804309, 0.177896682705198, 0.12963441386818886, 0.15584339893289975, 0.12760908183242592, 0.09967324550130538, 0.10820355026849679, 0.09055144818765776, 0.09565180593303271, 0.10199451380010162, 0.10215498054666178, 0.11561478115618229, 0.11314545651631695, 0.16980652324855328, 0.12427769202206816, 4.108486328806196, 28.327166421072825, 50.37823002679007, 57.897619179316926, 45.030774797712056, 40.164534432547434, 28.084783724376134, 35.9018771307809, 29.946079322269984, 9.84162129674639, 2.131113256726946, 0.481564499437809, 7.145576068333217, 28.064210108348302, 14.86601482118879, 4.6225822397640774, 6.236166741166796, 9.984140140669686, 15.444676433290754, 15.82676134790693, 28.869351727621897, 23.96059533527919, 23.958524772099086, 42.427124977111816, 51.39470979145595, 49.1209465435573, 48.50585378919329, 43.193480014801025, 40.77944653374808, 40.35349416732788, 51.112303733825684, 50.067562171391074, 52.60154587881905, 47.470169203622, 44.03967332839966, 36.055682454790386, 36.442575522831504, 34.71636853899275, 39.2252630506243, 45.54295430864607, 47.09228447505406, 49.791211468832834, 50.937897000994, 44.22936609813145, 38.411781855991904, 34.10065739495413, 43.077156748090474, 49.477006980351035, 47.810804639543804, 46.98310048239571, 51.830476488385884, 51.11946732657296, 46.25906344822475, 46.98312827519008, 44.91103301729475, 42.994629519326345, 37.5880902835301, 37.51881326947893, 36.34885127203805, 36.57902077266148, 39.33067764554705, 46.122597353799, 45.189732210976736, 51.153930391584126, 48.38322155816214, 38.64707217897688, 52.29849672317505, 47.340825012751985, 41.67019864491054, 36.909866196768625, 37.780478954315186, 35.45157480239868, 39.35543407712664, 39.2624637058803, 47.89185190200806, 51.46131174904959, 50.81706782749721, 47.224324566977366, 52.87194892338344, 50.5904940196446, 49.295273372105186, 42.76595040730068, 37.556031295231406, 35.43775136130196, 35.25996085575649, 36.92754241398403, 33.92699759347098, 34.87683718545096, 39.54305280957903, 47.197337763650076, 48.04085602079119, 51.705707686288015, 48.19473777498518, 44.024689538138254, 48.35184349332537, 50.05948141642979, 50.00517429624285, 47.8864357812064, 49.23313215800694, 50.68900557926723, 49.70184373855591, 45.91494001661028, 48.608881677900044, 47.96565914154053, 54.299925327301025, 51.707500321524485, 44.495218072618755, 35.06871863773891, 26.31754067965916, 25.234200137002126, 27.949616943086895, 20.486937250409806, 18.209250007356914, 16.750887393951416, 11.403287989752632, 10.726543869291033, 2.4044410586357117, 2.0654480031558444, 0.18796804227999278, 0.5716369290437017, 3.12152989421572, 19.50861178125654, 36.90743432726179, 47.009034633636475, 44.174086230141775, 60.92007514408657, 51.419382844652446, 56.295618193490164, 39.29934126990182, 10.734807882990156, 0.7875201191220964, 0.1132808785353388, 0.1244981616203274, 0.18705727186586174, 0.10405309405177832, 0.16942458945725644, 0.19341365221355641, 0.05198615722890411, 0.12442296636956078, 0.06783845195812838, 0.12283541155712945, 0.08195686579814979, 0.15106812731495925, 0.09841168605323349, 0.12484143248626164, 0.08392881069864545, 0.07224151997693948, 0.12269944671009268, 0.10814626834222249, 0.19012387017054216, 0.14798884040543012, 0.15682792610355786, 0.0762349631903427], [0.031027306336909533, 0.007211869665687638, 0.017046004068106413, 0.009026784599492592, 0.09439832105168275, 0.009879236625108336, 0.05126153611178909, 0.026629547854619365, 0.02591294702142477, 0.02534235844255558, 0.037281519666846306, 0.07286408942724977, 0.044106621827398024, 0.023745461899255003, 0.046619878217045746, 0.08275282130177532, 0.021202670576583062, 0.039818192299987586, 0.053221267381949086, 0.01858458391922925, 0.013674634974449873, 0.06883207149803638, 0.02742228370958141, 0.9700001158884594, 15.699525935309273, 38.4070258140564, 44.069658279418945, 36.04082373210362, 23.141229016440256, 23.160871573856898, 22.919737815856934, 21.201934678213938, 8.773551157542638, 1.0264105860676085, 0.4427646728498595, 2.2684339795793806, 1.7134301151548113, 0.5436518649969782, 3.972178740160806, 7.075134796755655, 8.422144276755196, 12.722662312643868, 13.846692374774388, 7.217710094792502, 7.324054445539202, 16.303921937942505, 38.4924886567252, 46.86902148383004, 46.1200612613133, 41.10720695768084, 38.04146024159023, 34.228636264801025, 40.76044321060181, 44.08359636579241, 50.767343044281006, 48.339354106358115, 48.038417203085764, 43.1499148096357, 38.704325335366384, 34.55703592300415, 32.48127896445138, 33.14681216648647, 35.69053030014038, 38.60494525091988, 38.2460812159947, 36.9661466053554, 33.719020639147075, 30.46519660949707, 32.8873108455113, 40.874577794756206, 47.69754205431257, 45.671204158238, 47.57245363507952, 46.56793172018868, 43.518718242645264, 41.60404484612601, 39.851375647953574, 35.61246381487165, 33.027997970581055, 33.78642511367798, 31.938503061022075, 34.86380583899361, 38.1655307497297, 37.24540512902396, 42.279604298727854, 43.177016258239746, 47.59382976804461, 43.04033824375698, 33.35770041601998, 48.83971473148891, 41.56925868988037, 41.11205332619803, 32.99523721422468, 34.80567026138306, 34.307741505759104, 34.02388327462332, 36.91263157980782, 41.27112538473946, 44.531251430511475, 46.18859829221453, 47.25462566103254, 47.681988511766704, 46.04855040141514, 48.83333281108311, 46.08220747538975, 42.396021366119385, 37.32477787562779, 36.22892189025879, 35.18518781661987, 32.673952511378694, 32.42622143881661, 38.478790283203125, 44.46721683229719, 46.90777506147112, 45.893008027757915, 47.08881037575858, 47.97039433888027, 48.35467488425118, 45.80455051149641, 41.263864517211914, 42.703673703329905, 45.767381123134065, 44.892060961042134, 49.1820524760655, 46.11176858629499, 45.86966902869088, 47.908211435590474, 49.81019394738333, 49.50634227480207, 45.62288638523647, 34.03287424360003, 21.247122287750244, 16.278128487723215, 11.228095241955348, 18.356468439102173, 17.031222888401576, 8.210945095334734, 4.878884783812931, 3.2673489153385162, 3.172902920416423, 0.1767168188733714, 0.03658070834353566, 0.06457596059356417, 3.055987536907196, 13.54079532623291, 26.259274823325022, 27.437006643840245, 39.997155802590505, 52.631912980760845, 43.51077645165579, 43.97996398380825, 24.568053756441387, 7.749297227178301, 0.4354332648217678, 0.09733153294239726, 0.031519620812364986, 0.09576320102704422, 0.015017677996573704, 0.01485517734129514, 0.03215264309463756, 0.030235737562179565, 0.021298651051308428, 0.06871345000607626, 0.013658790333595659, 0.027095182333141565, 0.018529834624912058, 0.012935180233658423, 0.00974444140280996, 0.07554530019738845, 0.05236316146329045, 0.04155065165832639, 0.019924015438716327, 0.08736010800514903, 0.015245675940864852, 0.014756793156266212, 0.018785007896700075, 0.01978744669551296, 0.01755465766681092, 0.012536154145241847, 0.023298042693308423, 0.03233082639053464, 0.027396716510078738, 0.03500082776216524, 0.06646403856575489, 0.039507701460804255, 0.024158413222591792, 0.006853961951232382, 0.02557094331963786, 0.002042561736223953, 0.02278604052428688, 0.03159556584432721, 0.030083267350814173, 0.046799058959420235, 0.040695446476872475, 0.04185503568234188, 0.07046820941780295, 0.015417911877323474, 0.11146818580371992, 0.028814708814024925, 1.2233657432453973, 19.71104407310486, 45.31645345687866, 49.09778124945504, 43.370026792798726, 27.210417202540807, 23.39629738671439, 28.861979688916886, 23.542657715933665, 9.0597448519298, 1.0782215659107481, 0.5113367161580494, 3.2830101549625397, 4.305419555732182, 1.9196693684373582, 5.562440744468144, 8.533290266990662, 11.732951351574489, 14.267120923314776, 17.88793751171657, 11.942826901163373, 12.025790997913905, 23.344601052148, 38.772869314466206, 49.19441679545811, 47.70971529824393, 44.49069479533604, 40.30496447426932, 37.30020209721157, 42.075351578848704, 47.49728454862322, 50.59276955468314, 50.26432820728847, 47.71868542262486, 45.4795172555106, 39.8205360685076, 34.647685595921104, 32.555753231048584, 33.866513524736675, 39.02336229596819, 40.842077595846995, 40.73670816421509, 39.7660413469587, 36.28294760840279, 32.356225286211284, 35.24576916013445, 43.41775744301932, 50.59092828205654, 47.067208426339285, 48.15797138214111, 48.746230193546836, 44.46010535103934, 43.68527003696987, 41.69691446849278, 38.34341158185686, 34.835227898189, 35.399181910923545, 33.94620936257498, 36.02526671545846, 39.108825138636995, 39.91436801637922, 44.50276729038784, 45.64755596433367, 49.91787018094744, 44.51183121544974, 35.65997907093593, 51.59026684079851, 43.696105752672466, 42.40718017305647, 35.07897070475987, 35.85726274762835, 35.511843476976665, 36.97437327248709, 38.27619123458862, 43.03550577163696, 45.97212369101388, 47.63688428061349, 46.995357104710166, 48.67417042595999, 48.22302736554827, 50.73169878550938, 47.57115084784371, 43.38421848842076, 38.05740288325718, 37.63991689682007, 36.874656200408936, 33.742741789136616, 34.800445216042654, 41.26610878535679, 46.02749735968453, 49.111139161246165, 47.202541964394705, 46.14859403882708, 47.88918726784842, 49.1531514440264, 48.47013310023716, 43.54679938725063, 45.49085324151175, 45.53602000645229, 47.0577449798584, 50.88839108603341, 46.22011532102312, 46.38272053854806, 48.04828017098563, 51.65280062811715, 49.05848223822457, 45.43871395928519, 33.4755870274135, 23.776139770235332, 14.180609771183558, 10.666643449238368, 12.989333306040082, 12.972360593932015, 12.310909458569117, 8.73296672957284, 7.922176224844796, 3.288558291537421, 0.3946717120707035, 0.02074578241445124, 0.24161904624530248, 3.03120504958289, 15.9589056628091, 32.35027762821743, 34.5612986428397, 44.20407118116106, 56.872575759887695, 49.01636920656477, 50.52753986631121, 30.957021372658865, 10.958427837916783, 0.5457199854510171, 0.05651080175968153, 0.11226314386086804, 0.09378677101007529, 0.054738766846380064, 0.06122315621801785, 0.03291983549882259, 0.030802076815494468, 0.02875955748770918, 0.008368155253784997, 0.03418880794197321, 0.0060129496019466645, 0.012275791776898717, 0.044780980463006666, 0.015731232207534567, 0.019441751763224602, 0.027583507022687366, 0.03418723034805485, 0.061039856768080165, 0.04795435982357178, 0.026102787548942224, 0.04451555452708687, 0.055771106987127235, 0.12356768654925482, 0.1186630047325577, 0.09317110904625484, 0.13379182506884846, 0.13003502094319888, 0.06411870941519737, 0.22888164115803583, 0.16538780821221216, 0.16347786784172058, 0.12830282960619244, 0.14668872659759863, 0.10237229495708432, 0.12345894452716623, 0.11937325447797775, 0.12511588633060455, 0.1326423596058573, 0.1568296631532056, 0.06806353559451443, 0.14687160535582475, 0.1356956043413707, 0.13204271106847695, 0.22385417164436408, 0.13959591862346443, 1.958674384014947, 23.93796852656773, 51.36457545416695, 54.07539081573486, 48.36881794248308, 33.55465405327933, 32.46139669418335, 33.24628605161394, 29.947475910186768, 11.174469913755145, 1.74910802926336, 0.7647654744131225, 2.9539684397833685, 2.7585336353097643, 1.3677738457918167, 12.395682692527771, 15.70606940133231, 15.940439088003975, 20.81084316117423, 18.599671023232595, 12.878606813294546, 12.437242473874774, 19.572931255613053, 43.19188887732369, 51.41675295148577, 49.4731958934239, 46.40326983588082, 41.87668521063668, 38.77970634187971, 44.63244846888951, 48.82707248415266, 53.073047161102295, 51.34091683796474, 51.07598549979073, 47.54573086329869, 42.88010931015015, 36.893065452575684, 36.029244559151785, 36.60389184951782, 40.79339156832014, 42.6630927494594, 41.29093469892229, 40.95660475322178, 36.97463730403355, 34.29301479884556, 36.78325612204415, 44.876684597560335, 51.1191338130406, 45.65465702329363, 49.617690631321494, 50.84330769947597, 46.99866444723946, 45.12802178519112, 43.68666315078735, 39.030046463012695, 36.650604588644846, 37.780270508357454, 34.567586762564524, 37.39136593682425, 41.75028705596924, 41.3325856753758, 46.295082909720286, 47.96787214279175, 51.156278882707866, 45.00942645754133, 40.11022731236049, 50.99694626671927, 45.280301979609895, 45.366216455187114, 37.14157819747925, 38.10695743560791, 38.788739000047954, 38.33689764567784, 40.12846980776106, 44.763741629464285, 47.04809045791626, 49.230821881975444, 48.16347435542515, 49.28220728465489, 48.457421370915, 53.26319851194109, 50.2330196244376, 47.31317465645926, 42.322703974587576, 40.64341122763497, 40.321476868220735, 37.106614862169536, 36.18313673564366, 42.71932452065604, 48.66984517233712, 50.52739742824009, 46.79296997615269, 48.6339681489127, 49.847293853759766, 51.34760447910854, 49.81718730926514, 45.17586708068848, 45.97400665283203, 49.823134967258994, 49.76854991912842, 53.12027406692505, 45.780666078839985, 46.483229705265586, 48.16676780155727, 52.48350293295724, 51.02354049682617, 49.54924740110125, 38.012239592415945, 26.078854424612864, 23.360031264168875, 17.592689446040563, 28.3663056237357, 23.350955179759435, 12.674311535699026, 12.506350125585284, 11.810108491352626, 6.280452387673514, 1.000348544546536, 0.12374627696616308, 0.3558174398328577, 3.682821009840284, 17.44722890853882, 35.723461287362234, 40.26630817140852, 49.67592348371233, 62.116283961704795, 54.0470734323774, 57.65377214976719, 37.02575520106724, 13.986328584807259, 1.0120768866368701, 0.14119371931467736, 0.2155552405331816, 0.19177014540348733, 0.12975199041622026, 0.12360770654465471, 0.09990554196493966, 0.11390369225825582, 0.09181119594722986, 0.1707695544298206, 0.11903457050876957, 0.14722527137824468, 0.11271005416555063, 0.1379049957862922, 0.1052514479628631, 0.20357179641723633, 0.1638385092041322, 0.11947157420217991, 0.08926232664712838, 0.1285154689103365, 0.12470016149537903, 0.0716017157371555, 0.17094294726848602], [0.09302296449563333, 0.03277573501691222, 0.02159343719748514, 0.00940419256221503, 0.050907510465809276, 0.006060717195006353, 0.027577936250184263, 0.04979276563972235, 0.029372030336941992, 0.02673709735141269, 0.00877177672061537, 0.017966984737930552, 0.00894829082036657, 0.002117272258536624, 0.06121107829468591, 0.04321475539888654, 0.05656154939372625, 0.02002045392457928, 0.07042920043958084, 0.010741963367243963, 0.026207536392446076, 0.05708390939980745, 0.026373215984287005, 0.8564433178731373, 13.383685265268598, 36.43794454847063, 45.214033535548616, 36.61588444028582, 24.499235323497228, 15.335542815072195, 25.21902527127947, 23.62403675488063, 9.228338548115321, 0.9838689374072211, 0.054949679278901646, 0.031970826243715625, 0.831179287816797, 4.601936101913452, 2.9390135279723575, 6.574887079851968, 10.84808783871787, 12.481745685849871, 22.738026789256505, 9.044697659356252, 8.065571410315377, 26.01374285561698, 35.171117714473176, 47.26042740685599, 44.14988218035017, 40.672065598624094, 36.5618691444397, 35.385170868464876, 40.97819628034319, 46.99705941336495, 47.93597296306065, 45.10260874884469, 47.43465348652431, 45.13375057492937, 39.74307060241699, 39.31350517272949, 38.02152238573347, 36.52164602279663, 33.01435170854841, 34.20941754749843, 31.972031593322754, 32.283130237034385, 32.61625467027937, 33.19425099236624, 35.693483284541536, 41.876792907714844, 46.86603723253523, 47.02795805249895, 46.54451629093715, 45.48991870880127, 42.177997316632954, 39.24338047845023, 34.426215239933555, 33.83170304979597, 33.0042142868042, 32.095171042851035, 34.52282299314226, 38.05871261869158, 41.7671468598502, 44.95669657843453, 44.45545700618199, 48.62493896484375, 47.74328899383545, 42.855575220925466, 33.24543489728655, 49.64465659005301, 41.467568329402376, 41.653033120291575, 34.864288738795686, 35.34530210494995, 34.85920960562569, 33.018239225660054, 35.09477438245501, 39.23625857489449, 43.58783892222813, 47.564011573791504, 47.392019339970176, 50.17382444654192, 45.85015501294817, 43.99657712663923, 47.16754041399275, 48.400453090667725, 45.460920401981895, 45.594127791268484, 46.45144864491054, 43.05920607703072, 34.10419750213623, 42.046770163944785, 48.14590930938721, 46.17016472135271, 44.57299968174526, 45.833941391536165, 48.174084254673545, 47.03024748393467, 41.541316509246826, 41.44700166157314, 37.442101682935444, 42.531782218388145, 42.05149146488735, 46.421425478799, 48.290553433554514, 46.84867715835571, 47.347523076193674, 46.45646524429321, 46.40523965018136, 46.2768543107169, 34.992305823734824, 27.094029664993286, 19.140798466546194, 12.353859748159136, 10.7718391759055, 5.286803535052708, 18.704276153019496, 8.047818762915474, 4.53735042469842, 4.686189523765019, 0.6297114927853856, 0.0798555581963488, 0.11754787314151015, 2.1290324883801595, 11.993631260735647, 32.28264733723232, 38.94920069830758, 38.578920773097444, 50.16547271183559, 38.495177609579905, 38.18931095940726, 20.84305500984192, 6.5141511389187405, 0.3353026935032436, 0.02388506369399173, 0.02982056912566934, 0.04044564041708197, 0.07695187614964587, 0.028422763238527944, 0.02984807014997516, 0.03312063097421612, 0.019541900139302015, 0.03980314239327397, 0.018836020159402063, 0.07300732816968646, 0.045958008018455336, 0.025300959324730293, 0.017033627589366267, 0.04259384157402175, 0.06943395920097828, 0.0037727865939294653, 0.0260898478861366, 0.0371520517926131, 0.11429516625191484, 0.054854490993810553, 0.02460020567689623, 0.047263417792107375, 0.032617995981127024, 0.029415504075586796, 0.030131463693188767, 0.012736015786815966, 0.008800327777862549, 0.024790550016665032, 0.03401289773838861, 0.04000550189188548, 0.027939517383596728, 0.007155524965907846, 0.015430812524365527, 0.025579570892399976, 0.014982609610472406, 0.08001924119889736, 0.036539168429694006, 0.036009700769292455, 0.042657050503683944, 0.05618018896452018, 0.05462539382278919, 0.0072624807445598495, 0.018091674029294933, 0.0172904242561864, 1.058201743023736, 18.321341821125575, 43.113224846976145, 49.664830684661865, 42.38513353892735, 28.50551278250558, 19.447481530053274, 23.862085512706212, 26.377243076051982, 10.463021278381348, 1.3194321883576257, 0.07951135773743902, 0.005936707710913781, 0.6541872822812625, 4.155764477593558, 7.548694917133876, 11.419875945363726, 8.785483820097786, 9.501930815832955, 13.193962965692792, 7.982548253876822, 9.773421253476824, 25.73523473739624, 39.07329205104283, 47.317499910082134, 46.49388476780483, 43.37983070101057, 37.78684350422451, 36.865908418382915, 42.590341636112754, 48.17500836508614, 50.12102508544922, 46.62236738204956, 49.783040387289866, 46.781363010406494, 43.02836997168404, 40.75872353145054, 39.47576992852347, 37.66527782167707, 33.770875045231406, 35.80751017161778, 33.754248006003245, 34.294974190848215, 33.79422099249703, 34.49266086305891, 36.61933422088623, 45.08121524538313, 48.1077115876334, 47.15457507542202, 47.660268442971365, 47.89916140692574, 44.29366472789219, 41.49927295957293, 36.65792104176113, 35.44702025822231, 34.185140541621614, 33.83449969972883, 36.28012316567557, 39.859046459198, 43.67154039655413, 46.56382186072213, 46.865606444222585, 51.3062036378043, 49.279428005218506, 43.56570890971592, 35.65811347961426, 50.95999574661255, 44.14034577778408, 42.8024388722011, 35.5490163394383, 36.72510664803641, 35.354772499629426, 35.36998905454363, 36.76880734307425, 40.70791482925415, 46.62253761291504, 48.721525873456685, 48.71352154867989, 50.286444323403494, 45.867438656943186, 44.641425541469026, 48.568391050611226, 50.25633430480957, 47.01386710575649, 48.233300277165, 47.583400521959575, 43.74078614371163, 35.049941131046836, 43.39040238516671, 49.496441091809956, 47.21620559692383, 45.65561934879848, 46.658616134098594, 48.64129849842617, 48.61800466264997, 44.07947260992867, 43.71557460512434, 39.79983043670654, 44.92446041107178, 44.67790705817086, 48.25641693387713, 48.76710953031267, 48.248586314065115, 47.55841132572719, 49.17840467180525, 48.36715384892055, 47.4189783505031, 34.82412815093994, 26.18894863128662, 16.451654536383494, 8.135116798537117, 12.626834494726998, 13.036627088274274, 8.91567655972072, 9.404353788920812, 9.255129064832415, 3.3897034355572293, 0.8779194940413747, 0.13042873410241945, 0.10454766465617077, 2.443790444305965, 14.809404373168945, 34.52882623672485, 41.64922898156302, 42.471190452575684, 57.114043031420024, 43.49069268362862, 45.07550730024065, 25.612647669655935, 8.550920452390399, 0.6162825248071125, 0.04213909079719867, 0.0724323783069849, 0.014662536160488213, 0.006019452936016023, 0.04015592971284475, 0.02938126859122089, 0.023202935832419565, 0.022447885812393258, 0.021605348879737512, 0.029841875125254904, 0.07161375973373652, 0.009594792200784599, 0.005665125341952911, 0.030021737795323133, 0.05100003210827708, 0.01165962515265814, 0.024008596083149314, 0.016763248347810338, 0.004242452842715595, 0.06371703025485788, 0.04944985779002309, 0.03527389060971992, 0.21379760413297585, 0.18874425919992582, 0.13725383287029608, 0.1198505088686943, 0.12095019700271742, 0.10753486079296895, 0.08533820935658046, 0.11502795693065439, 0.18604914524725505, 0.08060193993151188, 0.08402090147137642, 0.06347072882843868, 0.08325875058237996, 0.1521449081067528, 0.21377990793968948, 0.12467525926019464, 0.19295702528740677, 0.13296437875500747, 0.16840175219944545, 0.07839412268783365, 0.11644695007375308, 0.109812858913626, 0.1541663317808083, 1.805012149470193, 23.26032635143825, 49.5248453276498, 56.835958753313335, 47.74972997392927, 35.420071669987266, 25.741816418511526, 34.7771965435573, 31.497823987688335, 12.36055086340223, 1.5838481656142642, 0.15758156137807028, 0.23258891222732408, 2.136512875556946, 9.644520878791809, 8.889812758990697, 14.78269897188459, 17.22998305729457, 18.58605429104396, 29.515860761914933, 14.75395427431379, 13.191081200327192, 29.611565249306814, 38.89641523361206, 51.70365101950509, 48.189151423318044, 45.2161214692252, 40.38479232788086, 38.509087903159006, 46.21560246603829, 51.79461336135864, 49.695263794490266, 46.60236004420689, 51.27541616984776, 50.40250008446829, 44.98293992451259, 43.81134857450213, 42.7375670160566, 39.56429692677089, 35.74074493135725, 38.56300592422485, 34.99679436002459, 36.23546709333147, 36.63243852342878, 36.65892505645752, 38.77227871758597, 47.30513211659023, 49.606844493321006, 47.26477003097534, 48.616858209882466, 51.35551152910505, 46.7397780418396, 44.18639496394566, 37.543159757341655, 37.648428440093994, 36.42867565155029, 34.91717495237078, 37.868675913129536, 41.86505045209612, 46.087776456560405, 49.776651518685476, 48.69330923897879, 53.63117858341762, 50.11667203903198, 43.82972655977522, 40.46351541791643, 53.17781209945679, 45.78457791464669, 44.98840120860508, 38.682226589747835, 38.430614948272705, 38.71496997560774, 35.36760582242693, 38.553917680467876, 42.98453378677368, 47.677228995731895, 50.61071675164359, 51.62760993412563, 51.001403536115376, 47.16370848246983, 44.91926315852574, 50.52984666824341, 51.54474571772984, 49.32107898167202, 51.07458543777466, 50.40589427947998, 46.244923864092144, 38.37362582342965, 45.52521555764334, 52.39254753930228, 45.88337435041155, 46.15375655038016, 46.17156825746809, 50.09884990964617, 49.85876185553414, 45.53419610432216, 44.87383931023734, 41.82768651417324, 47.04986572265625, 45.81333998271397, 51.009188992636545, 51.200764724186485, 49.404770033700125, 48.302070072719026, 47.21644530977522, 49.36699962615967, 48.89540801729475, 37.7138283593314, 30.68441574914115, 23.864387103489467, 19.684739930289133, 21.91522979736328, 12.803792084966387, 29.175221851893834, 17.32968102182661, 13.769968628883362, 10.511177505765643, 1.4037895074912479, 0.22970310279301234, 0.24204237067273685, 3.257524162530899, 16.8502014705113, 41.781084946223665, 49.876886231558665, 48.12991108213152, 58.94435487474714, 50.35670450755528, 51.67588949203491, 33.697317940848215, 11.677403109414236, 0.8544296973517963, 0.09260346700570413, 0.12213666976562568, 0.10581277962774038, 0.17432874201663903, 0.15341534279286861, 0.1246158874460629, 0.13250391132065228, 0.12462036577718598, 0.10420677544815199, 0.07144752543951784, 0.16248080134391785, 0.16989642913852418, 0.08317816776356526, 0.1347466188349894, 0.1325809114745685, 0.13175440153905324, 0.07269617915153503, 0.1022506607696414, 0.14205426456672804, 0.17603681821908268, 0.13617413437792233, 0.10780608481062309], [0.03716638584488204, 0.033049154095351696, 0.0072924287357766715, 0.05643581685477069, 0.021515124078307832, 0.014725100481882691, 0.06663329912615673, 0.06335666709180389, 0.03079274356631296, 0.08506526864532914, 0.02799566785272743, 0.05496693103175078, 0.005878600092338664, 0.008041061510864114, 0.05333295424601861, 0.03453729674220085, 0.013843035491715585, 0.006822852816964898, 0.037345108576118946, 0.05090787348204425, 0.017978711519390345, 0.02819298074713775, 0.013607443892396986, 0.17274460702070168, 7.044321707316807, 34.70426477704729, 46.42244338989258, 42.58082260404314, 24.962496042251587, 22.584652253559657, 33.26126636777605, 23.33242780821664, 9.769884620394025, 0.8742082874689783, 0.09506342786231212, 0.15809431672096252, 0.9907502595867429, 1.572842219046184, 3.5069110776696886, 7.708717141832624, 8.895542417253766, 8.77481312411172, 16.2261802809579, 11.179970281464712, 13.662924681391035, 28.87250794683184, 38.72100101198469, 46.70400871549334, 44.17055654525757, 42.056633131844656, 39.629040241241455, 36.26016446522304, 41.303816659109934, 44.3803574017116, 48.357200554439, 47.05881152834211, 49.03223194394793, 46.53427464621407, 45.86667088099888, 42.0865729195731, 41.35642841884068, 43.224931035723, 46.12221867697579, 37.884754044669016, 35.97311006273542, 36.786466189793174, 36.99582583563668, 37.34660564150129, 40.13407005582537, 43.68396724973406, 47.77836002622332, 45.48272384916033, 50.50222757884434, 42.017125674656455, 41.65556921277727, 36.05671426228115, 33.96616806302752, 32.17252881186349, 32.57452726364136, 32.789435046059744, 35.9131749016898, 41.113095555986675, 47.44328314917428, 46.058423791612896, 49.129103728703086, 46.20741401399885, 47.88152340480259, 43.108027594430105, 30.990869522094727, 51.39189229692732, 45.49967050552368, 42.0564420563834, 35.58131504058838, 33.51480613436018, 32.497169494628906, 33.03224331992013, 33.85526786531721, 35.924472672598704, 38.744534560612266, 44.71548639025007, 45.54731777736119, 47.30545173372541, 50.339938504355295, 48.82277502332415, 45.82429034369332, 48.93693740027291, 49.060518060411724, 48.49053995949881, 48.6087566103254, 46.68212536403111, 36.111205509730745, 41.75005429131644, 48.49069281986782, 46.819574628557476, 47.018956661224365, 48.591782161167686, 45.58570657457624, 42.94859422956194, 39.18649557658604, 35.57726771490914, 35.9458383832659, 37.321953432900564, 43.02196025848389, 43.799856254032676, 46.306272983551025, 49.460320881434846, 48.052042620522634, 50.7014011655535, 48.797983850751606, 47.1165406363351, 40.012806619916645, 29.296752793448313, 17.246419021061488, 8.31249041216714, 8.970119169780187, 13.081310084887914, 7.855122634342738, 6.416937155382974, 8.606310623032705, 2.4884756122316634, 0.5229899851339204, 0.03965295884492142, 0.21880211202161653, 2.147051990032196, 15.48346127782549, 32.14296075275966, 34.27669695445469, 36.33364861352103, 43.658606324877056, 42.69030884334019, 40.310561248234336, 25.426203182765416, 7.438362734658377, 0.5868231398718697, 0.02808375866152346, 0.026299505028873682, 0.01642801981818463, 0.03249022105176534, 0.0028564258994135472, 0.03746737040845411, 0.04653161438181996, 0.05960465342338596, 0.02689454800981496, 0.05193572850631816, 0.07678860705345869, 0.023039490317127535, 0.023760737418862324, 0.011180735492546643, 0.0385474454877632, 0.036111562446291955, 0.026248843908043842, 0.01846049682769392, 0.08110553505165236, 0.06165624476437058, 0.09547124097922019, 0.07903161990855422, 0.026897060285721506, 0.052867051746164045, 0.020853942592761347, 0.04468208398403866, 0.05022947756307466, 0.0681143103699599, 0.09472003486007452, 0.037540357027735026, 0.06912219271595989, 0.014018373181378203, 0.03497937587755067, 0.010204762103967369, 0.01734158070757985, 0.021332515037751625, 0.010301122558303177, 0.048617285144116194, 0.04061527417174407, 0.09473349020949431, 0.0395164647405701, 0.06716894145522799, 0.05503069975280336, 0.039471203062151156, 0.021619767748883793, 0.3642846611993653, 9.767580424036298, 40.35449470792498, 52.18667241505214, 46.896612780434744, 29.18847554070609, 24.66836837359837, 33.704280035836355, 28.21680818285261, 10.558478236198425, 1.5108815495456969, 0.09031242744198867, 0.3451452782111508, 1.7924703253167016, 4.5100787452289035, 6.427451516900744, 9.585019980158124, 14.53176999092102, 12.866231203079224, 10.23894100529807, 11.816515598978315, 13.449373534747533, 24.199080092566355, 39.60338054384504, 49.927427428109304, 45.97259964261736, 44.457565784454346, 41.89551135471889, 37.51563794272286, 43.510832037244526, 46.646210125514436, 49.12338188716343, 48.39958109174456, 48.365260464804514, 47.331795828683035, 47.16894742420742, 44.39290584836687, 43.119836057935444, 44.158883571624756, 45.47757175990513, 40.48628119059971, 37.20827048165457, 38.28732919692993, 37.22725990840367, 38.28402532849993, 40.37511696134295, 45.880497796194895, 48.421624251774375, 45.4926632472447, 50.273360865456716, 43.96241283416748, 44.6173917225429, 38.66140978676932, 34.82475001471383, 33.99427005222866, 34.24867486953735, 34.31241069521223, 36.53678614752633, 43.07048647744315, 48.38731404713222, 47.199283259255544, 49.42195292881557, 47.43705061503819, 47.535662923540386, 42.85797234943935, 34.10140780040196, 51.064979553222656, 45.608913557870046, 43.46529354367937, 38.29584074020386, 36.53319392885481, 34.49616970334734, 35.08195148195539, 34.67953266416277, 37.356298378535676, 41.51742860249111, 47.32447590146746, 46.43929624557495, 48.63186631883894, 49.50836072649275, 49.095179149082725, 46.00816052300589, 49.149434157780235, 50.12133775438581, 49.06628506524222, 51.095694065093994, 48.18970033100673, 37.98108039583479, 44.61401489802769, 51.278824261256624, 47.71415867124285, 47.3345125743321, 51.20233154296875, 47.32317658833095, 44.87757396697998, 41.029324599674766, 37.302960532052175, 37.43335042681013, 38.82729107992989, 45.28298051016671, 45.719164099012104, 48.4702581678118, 51.70457860401699, 49.346724782671245, 49.85934203011649, 49.275123596191406, 48.00088650839669, 39.086451939174104, 29.765620708465576, 16.517566885266984, 10.844050935336522, 8.401541999408177, 14.014573012079511, 9.106789367539541, 10.773648313113622, 6.103376678058079, 2.845492511987686, 1.6399237109082085, 0.013829614917215492, 0.09994146360882691, 2.603736238820212, 15.720525128500801, 33.61918197359358, 37.00953810555594, 38.47975260870797, 48.00045919418335, 49.99918842315674, 45.42361552374703, 32.41117858886719, 9.633916190692357, 0.6721455529332161, 0.041965826880186796, 0.028715571455125297, 0.019004878687805364, 0.04475494846701622, 0.018970536334174018, 0.03541476805029171, 0.0777362354898027, 0.05591241529743586, 0.02977845924241202, 0.03736762576071279, 0.04845008733017104, 0.0404830751940608, 0.03250922342496259, 0.035413509367832115, 0.024078011911894594, 0.021000409465549246, 0.028160573914647102, 0.022124979478706206, 0.07965395865695817, 0.033307468984276056, 0.06783140876463481, 0.021665977679991295, 0.06647557366107192, 0.10615738042231117, 0.13316705716507776, 0.17585400731435843, 0.12936257916901792, 0.13852789093341145, 0.22628013789653778, 0.12371437224958624, 0.18009704963437148, 0.13566432387701102, 0.07485900273812668, 0.10802529233374766, 0.12465054701481547, 0.06205928099474736, 0.08576584926673345, 0.12187167469944273, 0.09392454076026167, 0.11056084199143307, 0.1278732762272869, 0.11785580590367317, 0.1801977442311389, 0.1671477109193802, 0.10013158912105219, 0.6618316578013557, 13.378749438694545, 46.683810302189414, 56.75467872619629, 51.6307817867824, 35.2999199458531, 31.649728979383195, 42.605238573891775, 31.964454582759313, 11.42165902682713, 2.1181915615286147, 0.3204596314047064, 0.8547247243779046, 2.3805225363799503, 4.745232275554112, 11.046822820390974, 14.669835908072335, 17.1123674256461, 21.800949301038468, 28.39243953568595, 18.107580491474696, 18.85747872080122, 32.79228033338274, 41.72721208844866, 51.00281054633004, 49.13759790148054, 46.51043537684849, 44.239618165152415, 40.190774304526194, 45.72050857543945, 49.82658127376011, 51.062902041843955, 48.48837906973702, 48.84758356639317, 49.16711732319423, 50.12399891444615, 46.253560474940706, 46.533812591007774, 46.701615061078755, 50.8869389125279, 43.36924164635794, 39.64283241544451, 40.60250718252999, 39.58933823449271, 40.571744033268516, 42.89716713769095, 47.74122885295323, 48.279999119894846, 44.969547271728516, 54.035244124276296, 45.09293685640608, 46.53543152127947, 40.56434767586844, 37.56565455027989, 34.33912999289376, 36.319984980991904, 35.9952574457441, 38.37104109355381, 45.88358974456787, 50.26279960359846, 49.40126814161028, 51.63865409578596, 48.714028767177034, 47.75642803737095, 43.631327697208945, 39.413871901375906, 53.39430059705462, 49.84083202907017, 46.32492194856916, 39.8948644229344, 37.99115875789097, 36.77703053610665, 37.01696572984968, 36.57545634678432, 39.229334694998606, 43.05298049109322, 49.1048058782305, 49.47692012786865, 50.207478046417236, 51.631841387067524, 50.60901096888951, 46.22167866570609, 49.65424510410854, 51.134892327444895, 49.88381358555385, 51.031492710113525, 51.23593997955322, 39.87972429820469, 46.69170345578875, 53.301764488220215, 49.04513822283064, 49.83224058151245, 52.45838866915022, 49.552971635546, 46.20174428394863, 42.84430176871163, 39.90470307213919, 39.981067248753135, 41.669239793504985, 47.08754580361502, 48.420588970184326, 50.16629259926932, 53.118102754865376, 50.4893456186567, 51.837730407714844, 49.847867080143516, 49.990979126521516, 42.34141199929373, 33.64256266185215, 23.46518530164446, 14.49374076298305, 14.904669386999947, 26.224082197461808, 21.21239866529192, 17.734100920813425, 17.278062854494365, 3.9930133478982106, 2.3016546198299954, 0.0736993592498558, 0.31359654824648586, 3.360347730772836, 19.811046021325247, 39.98058087485177, 45.144985812050955, 45.55367885317121, 51.011864049094065, 53.70127895900181, 53.491662229810444, 39.13566950389317, 13.482692752565656, 1.0956322316612517, 0.21142988332680293, 0.12115016127271311, 0.12593501380511693, 0.14943680699382508, 0.10130246236388173, 0.2046759764530829, 0.16906394809484482, 0.19639635644853115, 0.2102575105215822, 0.12153862257088933, 0.24250534868666104, 0.10528785815196377, 0.07828667666763067, 0.14885751450700418, 0.1082516855427197, 0.12156672749136176, 0.12292970078332083, 0.15303152267421993, 0.2705104159457343, 0.15550812120948518, 0.14213505094604834, 0.18496309566710675], [0.04358634153114898, 0.028311373233529072, 0.007602837302588991, 0.025501542757930498, 0.03185861351500664, 0.05045282754248806, 0.05333730026281305, 0.00770116041946624, 0.03991314309782215, 0.018915681866928935, 0.03599620131509645, 0.0662261713296175, 0.07478412639881883, 0.03590046002396515, 0.03237653590206589, 0.05558955476486257, 0.03418446871052895, 0.015416873718744941, 0.014099465749625648, 0.02223819643924279, 0.0038246733186367366, 0.05496211682579347, 0.012223665020428598, 0.22763416809695108, 7.340530361448016, 32.30223083496094, 45.39670515060425, 45.967930453164236, 34.30641092572893, 19.74576769556318, 22.16279411315918, 26.13533459390913, 10.679859791483198, 1.5328056131090437, 0.02080997691622802, 0.09678355484668698, 0.4980683709893908, 4.980813120092664, 8.72372909954616, 11.759535159383502, 8.095112545149666, 6.905529703412737, 4.622848008360181, 5.877864641802652, 8.952090331486293, 21.52769923210144, 37.941579886845176, 44.87117467607771, 43.24456664494106, 41.90412017277309, 38.2987311908177, 38.88658700670515, 40.29533427102225, 46.28264563424246, 48.26238891056606, 45.45302030018398, 45.52997159957886, 45.716787815093994, 49.104972634996685, 42.964453492845806, 45.32896368844168, 48.25420045852661, 46.98450749261038, 43.938764640263145, 45.27143260410854, 42.140018463134766, 42.88968045370919, 42.903767926352366, 45.105172634124756, 46.9756554876055, 46.88042000361851, 46.35722759791783, 46.93072843551636, 43.902974469321116, 40.38295800345284, 35.990800176348, 31.94734811782837, 33.058594363076345, 31.03806516102382, 31.22182069505964, 34.260500703539165, 42.33335208892822, 44.363091128213064, 49.49381467274257, 47.392189570835654, 48.45247425351824, 45.79793930053711, 44.85775423049927, 32.8533411026001, 48.28076689583914, 41.30643960407802, 43.996639660426546, 41.66489022118704, 35.161803654261995, 35.8036504473005, 34.29219838551113, 32.755041463034495, 31.130722863333567, 35.39631230490548, 39.088529450552805, 40.857676301683696, 42.32835633414132, 46.40288421085903, 47.457773617335725, 49.657951968056814, 48.71102714538574, 46.54324129649571, 46.74790048599243, 48.123112269810264, 43.93340063095093, 36.11710105623518, 41.28755440030779, 46.23225382396153, 47.08611100060599, 46.96779360089983, 44.649648734501426, 41.93774945395333, 37.30971418108259, 34.314978054591585, 33.454853602818076, 32.458332538604736, 34.40274422509329, 37.42818444115775, 45.038098199026926, 44.10893644605364, 49.35101529530117, 46.98952061789376, 52.75305134909493, 51.161861760275706, 52.673956530434744, 40.49889217104231, 32.95339168821062, 16.68012867655073, 11.550931998661586, 10.912818993840899, 13.475213885307312, 4.223150713103158, 6.501252242497035, 6.1932433758463175, 2.7053410496030534, 1.6795391908713748, 0.21208005558167184, 0.07414810838443892, 1.922464064189366, 10.669705867767334, 28.12021085194179, 35.22286442347935, 44.53847060884748, 44.83069794518607, 36.82592500959124, 42.6335003716605, 25.467706509998866, 6.593793562480381, 0.5008388023291315, 0.031555817262934785, 0.018284819022353207, 0.022878538418029035, 0.030935934811298336, 0.0804454968976123, 0.032569266988762786, 0.08014818999384131, 0.05049101888601269, 0.06230640344853912, 0.027573697102655257, 0.048508858640811274, 0.030819043583635772, 0.039285342142518075, 0.030085957742163112, 0.0407628589309752, 0.02934423414990306, 0.04651501062991364, 0.06682663410902023, 0.011155109769398612, 0.06092386120664222, 0.05349264406998243, 0.05075770350439208, 0.04877649320821677, 0.02796914052617337, 0.0225660170628024, 0.02884285444659846, 0.021746487556291477, 0.025559686423678483, 0.020108425989747047, 0.04022425140387245, 0.03199753677472472, 0.026812082256323526, 0.04171034487496529, 0.0894115229270288, 0.08461411749677998, 0.03494617176641311, 0.01970958140944796, 0.06651665895645108, 0.07079060176121336, 0.026729838723050695, 0.04780181497335434, 0.05757884641310998, 0.03249511668192489, 0.09295049017029149, 0.028855861962905953, 0.28223471396735733, 9.875439047813416, 39.04878922871181, 49.94230004719326, 49.88942078181675, 37.292764050619944, 23.27270630427769, 28.590087992804392, 27.322399582181657, 11.207467777388436, 1.8128108509949274, 0.047001832364393134, 0.052725251497966905, 1.0262565314769745, 2.967391708067485, 6.512334619249616, 8.574378439358302, 11.73852206979479, 10.168275220053536, 8.429354769842965, 10.915630408695765, 14.059643370764595, 20.290662799562725, 40.61588593891689, 46.57310117994036, 45.86719199589321, 42.88142946788243, 40.141542843409944, 40.12795564106533, 41.98932940619332, 47.01120247159685, 50.61226967402867, 45.64031246730259, 46.70020110266549, 44.855940750667024, 49.98444781984602, 45.22876719066075, 46.35525778361729, 48.74725505283901, 48.92536170142037, 44.750519207545686, 45.95702872957502, 44.66823863983154, 45.39315114702497, 43.591778550829204, 47.613722460610525, 49.71706029347011, 46.54011113303048, 46.134478773389546, 48.62625912257603, 45.832228660583496, 42.91485030310494, 39.02454696382795, 33.075040749141145, 34.31058331898281, 33.41053104400635, 33.84555428368704, 36.57979549680437, 43.46275397709438, 47.3335085596357, 50.582795415605815, 48.04250274385725, 48.90141820907593, 45.88738693509783, 43.33587292262486, 35.787853717803955, 49.482572487422395, 44.30922869273594, 45.12382159914289, 42.13621779850551, 36.71307931627546, 36.066889899117605, 34.288001673562185, 33.78976372310093, 32.953075545174734, 37.86276994432722, 42.430870056152344, 44.25889594214303, 44.42165749413626, 48.22026545660836, 49.014427185058594, 49.752409253801616, 47.69080924987793, 46.26107842581612, 47.115734645298545, 50.53981385912214, 45.72282927376883, 38.54673324312483, 43.87072440556118, 48.89530379431588, 48.694674560001914, 48.42974669592721, 47.182218483516145, 42.76253189359392, 39.71058429990496, 36.20035089765276, 35.38488599232265, 34.4004339490618, 36.456280844552175, 39.97974361692156, 45.59554869788033, 45.96574871880667, 50.58384459359305, 49.495787961142405, 54.187135219573975, 52.63573448998587, 52.36864226205008, 43.2479122025626, 34.95263508387974, 17.512429067066737, 12.306049193654742, 11.48983301435198, 13.284603084836688, 8.610702753067017, 8.155953577586583, 6.113155833312443, 5.525411622864859, 1.793254820363862, 0.1693434366690261, 0.11031490018857376, 2.275512456893921, 13.493491121700831, 31.499898024967738, 41.06085205078125, 46.79187216077532, 50.02011987141201, 41.01480286461966, 49.27403620311192, 30.419199534824916, 8.365747485842023, 0.8439746126532555, 0.06169109432292836, 0.04783476124118481, 0.01844673783385328, 0.08569445381207125, 0.007605626929684409, 0.03622944772775684, 0.054575765771525245, 0.04937118843996099, 0.017697216177891408, 0.018913547874295285, 0.042129272395478826, 0.02860505845663803, 0.02644784465831305, 0.01201385775181864, 0.024766526484329785, 0.022972632565402558, 0.018979696556925774, 0.015343047412378448, 0.043197082954325845, 0.05764180089214018, 0.012485443830623158, 0.03430800958137427, 0.11907028859215123, 0.10242482713822808, 0.06234704769615616, 0.09676261525601149, 0.13803851790726185, 0.23355444041746004, 0.12715701466160162, 0.10137970679040466, 0.08218650918986116, 0.20252801956874983, 0.13169954876814569, 0.16186133958399296, 0.17501455093068735, 0.2057883803333555, 0.10535571165382862, 0.13824009709060192, 0.1607853594635214, 0.21746761005903992, 0.11332593326057706, 0.12611855752766132, 0.17776180351419107, 0.16180223918386868, 0.14120558010680334, 0.5055656401174409, 12.198630043438502, 45.61141838346209, 56.94176592145647, 55.93394013813564, 44.008576665605815, 29.4154314994812, 31.769352640424454, 33.997525283268516, 13.32137816292899, 2.0986860139029364, 0.22356967548174517, 0.2587904876896313, 1.5928558536938258, 9.546958616801671, 15.283007485525948, 20.617575543267385, 15.352642331804548, 13.169968230383736, 11.673554675919668, 10.06355631351471, 13.01775404385158, 24.42169863837106, 44.23800618307931, 49.09782641274588, 47.51053476333618, 45.59149442400251, 42.4395865712847, 42.21213034221104, 43.9224328994751, 49.307151317596436, 50.09386805125645, 45.788013798849924, 47.04977887017386, 45.68606635502407, 50.79105724607195, 46.690473624638145, 47.151861803872244, 50.67024891717093, 49.78813689095633, 46.907323428562705, 50.06171178817749, 46.09020832606724, 47.98667744227818, 47.62753200531006, 49.526606695992605, 49.867530482155935, 46.978191580091206, 46.89110285895211, 49.50380618231637, 47.82883521488735, 44.33796991620745, 40.58786385399954, 35.88741445541382, 37.557042258126394, 35.49013730457851, 34.79699196134295, 37.76095799037388, 46.82267352512905, 48.01881286076137, 53.13791901724679, 50.848317350660054, 50.457998820713584, 45.23744549070086, 45.187133584703716, 40.07861648287092, 52.24135821206229, 45.5897330556597, 47.7506228174482, 45.90691137313843, 38.584618295942036, 38.6367541040693, 37.385609354291645, 35.670245034354075, 34.58250454493931, 39.99794094903128, 43.212577138628276, 46.837737219674246, 46.22783824375698, 50.12638214656285, 51.048849310193745, 52.89054230281285, 48.71400097438267, 46.926875659397666, 46.81779588971819, 51.385319301060264, 47.72036688668387, 39.30715799331665, 46.0329794883728, 48.96280901772635, 49.37383317947388, 50.13685655593872, 48.94530997957502, 45.41520472935268, 41.600390093667166, 38.06335054125105, 36.36617660522461, 34.605232102530344, 38.367243903023855, 41.34105205535889, 48.70788655962263, 49.03966304234096, 55.10759782791138, 51.045444692884175, 56.683588232312886, 53.253425870622905, 54.07596404211861, 43.885419845581055, 37.223664215632844, 22.35977554321289, 17.33972290584019, 19.090146098818096, 25.673597267695836, 14.642956801823207, 17.394764798028127, 10.064595069204058, 9.413888454437256, 3.7874052950314114, 0.38228502816387583, 0.4453328193298408, 2.4894870093890598, 15.28980803489685, 36.03252758298601, 46.88636071341378, 53.68431840624128, 53.461100578308105, 48.736266476767405, 57.53570141111101, 38.67975303104946, 11.858055404254369, 1.102235300200326, 0.14987535774707794, 0.11221770915601935, 0.09696449299475976, 0.16369627469352313, 0.18073232126023087, 0.0694011113207255, 0.18965280401919568, 0.13590506810162747, 0.20387377164193562, 0.10411647600787026, 0.16435840273542063, 0.150111392938665, 0.12039800520454134, 0.13449683652392455, 0.10015535141740527, 0.07167294834341321, 0.09358849629227604, 0.156155525041478, 0.20290288302515233, 0.23982619387762888, 0.12370559200644493, 0.0851634865892785], [0.03378952061757445, 0.02402736266542758, 0.032598148831831555, 0.05738703813403845, 0.015523480051862342, 0.03658994659781456, 0.010183473915926047, 0.014982212667486497, 0.035881813881652694, 0.033994913167719326, 0.018773150497249196, 0.07285904791206121, 0.06403904261865787, 0.06243742856064013, 0.03917466629562633, 0.04598970917452659, 0.07293844329459326, 0.02631234291142651, 0.003425953843231712, 0.023066950629332235, 0.01435678658474769, 0.08244705985167197, 0.1428693886846304, 0.1423940613333668, 4.343417951038905, 27.519676310675486, 43.86166742869786, 45.26736443383353, 27.58847737312317, 19.575337069375173, 22.534995215279714, 25.928170578820364, 11.22037318774632, 1.8215823003223963, 0.20837450799133095, 0.37435824636902126, 2.370690618242536, 2.918684401682445, 2.960947471005576, 4.974693059921265, 18.589566605431692, 13.5695686851229, 6.504135744912284, 19.054046733038767, 15.73851922580174, 17.588982582092285, 35.42184346062796, 45.3915148462568, 44.29382106236049, 42.21714694159371, 39.039683614458355, 37.26553406034197, 40.03347751072475, 44.64594187055315, 47.33922345297677, 45.68662221091134, 46.822034290858674, 47.014085974012104, 46.715292590005056, 44.64473983219692, 49.30000509534563, 46.436110496520996, 47.878250803266255, 46.917572021484375, 46.37056813921247, 45.908717904772075, 46.27707665307181, 47.4464966910226, 45.924264499119346, 45.73811183656965, 48.4883964402335, 46.29307835442679, 48.0375417300633, 44.371307373046875, 40.92378493717739, 33.934713568006245, 30.509335041046143, 31.689458778926305, 31.581838130950928, 32.23311710357666, 32.685875620160786, 35.845082555498394, 40.31737395695278, 42.66376672472273, 45.33027342387608, 46.03563717433384, 49.26689345496041, 43.371260098048616, 29.40137529373169, 47.48256131580898, 43.93310533251081, 41.75087765284947, 41.78564991269793, 40.86712237766811, 37.812454564230784, 34.57456622804914, 32.09158229827881, 34.03967653002058, 32.529256275721956, 34.6289393561227, 39.14480985913958, 42.028642313820974, 42.885073798043386, 43.45307513645717, 45.32266862051827, 49.953736782073975, 46.12519598007202, 46.95828151702881, 46.94777236665998, 43.35966008050101, 37.584998335157124, 41.7562381880624, 50.1733068057469, 48.004589898245676, 43.46767677579607, 39.16800989423479, 36.136847836630686, 33.99704238346645, 37.017862047467915, 37.155672618321006, 36.99924782344273, 34.23986107962472, 34.216921601976665, 37.61699826376778, 41.62608105795724, 45.60717303412301, 44.36971970966884, 48.73754147120884, 50.79661580494472, 52.22911548614502, 46.87378794806344, 39.35544449942452, 18.400261197771343, 16.891795124326432, 6.8874044588633945, 7.996508921895709, 4.131059288978577, 9.190199886049543, 5.745593088013785, 1.9398504112448012, 1.2657937237194605, 0.25980568464313236, 0.06396019006414072, 2.6235787740775516, 12.108796783855983, 28.956388337271555, 26.64410080228533, 33.73125294276646, 41.22391584941319, 39.222153731754844, 41.85057388033186, 30.788371222359793, 11.446757657187325, 0.5844869166612625, 0.05898796687168734, 0.03632130440590637, 0.02184189636526363, 0.012914768203959932, 0.09953067172318697, 0.05878675409725734, 0.04089386368702565, 0.04076581055830632, 0.09083992056548595, 0.03053047621090497, 0.03452252164216978, 0.054792025059993775, 0.03956291724794677, 0.027499755445335592, 0.0236072290489184, 0.049515940315489254, 0.05450668751395174, 0.03306457719632557, 0.0698242321876543, 0.08959311925406967, 0.02335459689077522, 0.027555463170366626, 0.04826580400445631, 0.030681677561785494, 0.10631193034350872, 0.02916762505524925, 0.02787816763988563, 0.011327907193585165, 0.031207874683397155, 0.012677141847754163, 0.02052252403726535, 0.05298361727701766, 0.02262417769192585, 0.01030960085336119, 0.046379524150065014, 0.017120525872867023, 0.01552180915937892, 0.02197804780943053, 0.1711280516215733, 0.07491931771593434, 0.027317365232322897, 0.02034324829998825, 0.01020777564761894, 0.05983429681509733, 0.03661433653905988, 0.26851546870810644, 6.070601156779698, 34.209896973201204, 49.81817742756435, 49.832268374306814, 33.54367937360491, 22.337383236203873, 28.37914068358285, 29.66174861363002, 12.919450930186681, 1.868257692881993, 0.18019858561456203, 0.03591016307473183, 0.5758622480290276, 3.901638891015734, 7.632414630481175, 9.806596296174185, 11.633026702063423, 14.823609965188162, 9.042131168501717, 15.71377842766898, 17.51714689391, 23.450526339667185, 39.10225909096854, 47.74784006391253, 45.58809675489153, 43.196745668138774, 40.56849922452654, 39.452295439583914, 42.79949631009783, 46.553066049303325, 48.494635922568186, 46.56620509283883, 46.14453976494925, 47.21465267453875, 45.41305773598807, 47.150291510990684, 48.98956305640084, 47.88984039851597, 46.94070257459368, 48.023495946611675, 48.0187920161656, 47.609914847782676, 47.41134575435093, 49.54858384813581, 47.102289881025044, 46.15344040734427, 48.041133948734824, 47.055862018040244, 48.25811229433332, 46.5780656678336, 42.54927430834089, 35.37780230385916, 32.310117040361675, 33.4220198903765, 33.164995602199006, 33.883123193468364, 34.557032448904856, 39.0767730985369, 43.53487975256783, 44.00114556721279, 46.38816097804478, 48.13053642000471, 49.12576164518084, 44.222039222717285, 32.43198496954781, 48.68701764515468, 45.21808433532715, 43.869487626211985, 43.56339863368443, 42.31356014524187, 39.433173997061594, 37.37412050792149, 33.24806131635393, 35.37836510794503, 35.31739466530936, 36.93435512270246, 40.71878181185041, 44.5175530569894, 45.01973411015102, 45.76824269975935, 47.15910530090332, 51.30610983712332, 47.45720386505127, 48.171555110386436, 48.000952516283306, 45.505152634211946, 39.33941500527518, 43.65804352079119, 50.12812614440918, 48.75230291911534, 45.28069455283028, 42.17122629710606, 38.832662037440706, 36.44492053985596, 37.51948724474226, 38.620571749550955, 37.455890383039204, 35.82280315671648, 36.079212529318674, 40.9345303262983, 44.14610583441598, 48.1928756577628, 46.0526567867824, 50.12784126826695, 51.85394055502755, 53.594238485608784, 45.73168475287301, 39.41593204225813, 21.46129356111799, 14.985612426485334, 10.622603160994393, 14.34875704560961, 12.827433330672127, 5.459183130945478, 3.4011310509272983, 5.296072431973048, 1.2018959181649345, 0.0698188514049564, 0.02292669065562742, 2.6702522124562944, 13.698386549949646, 35.12741354533604, 32.1651428767613, 39.251739161355154, 45.443410941532676, 44.6231552532741, 47.88839864730835, 36.21224273954119, 13.828805106026785, 0.9994930475950241, 0.04623118621696319, 0.03075567859091929, 0.047087249745215685, 0.05056709962497864, 0.07158095256558486, 0.05176430681188192, 0.019327252371502773, 0.059589997066983154, 0.035332692454435995, 0.021900470900748457, 0.01608535454475454, 0.08278005091207367, 0.019276073867721216, 0.03975061021213021, 0.032024108206054995, 0.0831580220588616, 0.05958202428051403, 0.04691569234377571, 0.04239901042144213, 0.032374252631728134, 0.019954965117254427, 0.022215874333466803, 0.09027341167841639, 0.12075070770723478, 0.13675094342657498, 0.1444687092942851, 0.0715092924822654, 0.10760300606489182, 0.16831800740744385, 0.06977543194911309, 0.11200683404292379, 0.08243079536727496, 0.10998130523200546, 0.13442842662334442, 0.11817797433052744, 0.12530840028609547, 0.11428314261138439, 0.1798524513308491, 0.2227097816233124, 0.13496292222823414, 0.09606863678033863, 0.09633866657635995, 0.15288467412548407, 0.0860528356528708, 0.24048130586743355, 0.5310574408088411, 8.959286059652056, 42.0601350239345, 57.083585602896555, 54.73103673117501, 38.64036021913801, 28.15511339051383, 33.94666446958269, 34.848683084760395, 15.192547151020594, 2.5467321319239478, 0.44183372280427385, 0.5988550313881466, 4.13502801316125, 6.813509498323713, 9.086688229015895, 14.103390966142927, 26.09763193130493, 26.431534562792095, 13.034330708639962, 25.452906847000122, 20.88431167602539, 20.058269875390188, 40.58863510404314, 49.94878966467721, 48.9215784072876, 46.648225103105815, 42.886557238442556, 41.348639488220215, 45.1886100769043, 48.53336518151419, 49.25362586975098, 46.67986025129046, 47.78233092171805, 47.47929913657052, 47.6581666128976, 47.227649280003135, 50.11657476425171, 49.50476850782122, 48.764580386025564, 48.44487987245832, 48.37652696881975, 47.04135070528303, 47.92679786682129, 50.13320875167847, 47.01250178473336, 45.640736307416645, 48.53794404438564, 48.543401854378835, 50.57967914853777, 49.769043241228374, 44.58648613521031, 37.92609930038452, 34.53160204206194, 35.88148416791643, 35.01887573514666, 35.43822383880615, 36.152109554835725, 40.55899061475481, 45.03829274858747, 47.04427242279053, 47.96316473824637, 49.63003063201904, 50.146139349256245, 44.07016897201538, 35.5998215675354, 49.6820205279759, 48.16999871390206, 45.27332598822457, 46.7783648627145, 45.14965500150408, 42.30753605706351, 38.58733851569039, 35.26790264674595, 37.23771694728306, 36.404537609645296, 37.85190296173096, 41.78953742980957, 46.80733190264021, 47.571619851248606, 48.991703101566856, 49.34356682641165, 54.48043952669416, 47.53746598107474, 48.24500104359218, 48.97341891697475, 47.037796701703755, 41.60514266150338, 46.652890818459646, 52.712168148585725, 50.83925689969744, 46.56158801487514, 43.241877692086355, 40.626377718789236, 37.31466129847935, 40.6257905960083, 42.3831706728254, 41.38622229439871, 38.359382016318186, 37.64329719543457, 41.356056690216064, 44.98160934448242, 51.196821621486116, 47.95157166889736, 52.85206665311541, 54.42604555402483, 56.55582823072161, 49.62668854849679, 44.63711071014404, 24.729922464915685, 22.52802096094404, 12.08203319140843, 16.76083026613508, 14.067376715796334, 15.26438283920288, 10.647994484220233, 6.629463008471897, 3.2631092114107947, 0.5835647604295185, 0.3006610923579761, 3.7612192715917314, 16.26721113068717, 39.31666660308838, 38.811807019369944, 43.809246744428364, 52.61684581211635, 51.33865867342268, 54.50106178011213, 42.490270205906455, 16.499051673071726, 1.273672329527991, 0.12328537526939597, 0.12537809940321104, 0.0913687843297209, 0.1353824468595641, 0.14773574684347424, 0.10615389275231532, 0.12071593957287924, 0.18485910339014872, 0.1534309083861964, 0.13003875288580144, 0.125611366171922, 0.10597958389137473, 0.14242665815566266, 0.13956482814890997, 0.10669895993279559, 0.14348210580646992, 0.15370442585221358, 0.11092241294682026, 0.12905134872666427, 0.1512837114610842, 0.08667074356760297, 0.0888664150344474], [0.0575380732438394, 0.03871548807780657, 0.01799471816048026, 0.05222269453640495, 0.08535708620079926, 0.0072948926660631385, 0.01929874541903181, 0.03316044740911041, 0.016441420884802938, 0.029791052852358137, 0.023875759282548512, 0.054008347647530694, 0.03591337254537003, 0.07294232451489993, 0.02213530338901494, 0.00922066071403346, 0.04113234839003001, 0.038638545599366934, 0.04413823816659195, 0.04534376419282385, 0.030105798106108392, 0.04222576007513063, 0.04991291383547442, 0.12082987917321068, 7.365206888743809, 27.57020013672965, 40.41817842211042, 41.98210327965872, 29.353509153638566, 18.331663370132446, 22.360234124319895, 20.313527584075928, 13.30717430795942, 2.7424850336142947, 0.11499432873513017, 0.07687956467270851, 0.6065845766237804, 2.5358529899801527, 7.257571475846427, 6.386129711355482, 8.721072282109942, 10.853326780455452, 6.369334612573896, 11.216897351401192, 20.08664458138602, 23.420718567711965, 40.405452796391074, 45.08335529054914, 44.71037599018642, 41.1993157523019, 38.7955447605678, 37.70289536884853, 39.85244567053658, 45.70383984701974, 48.59588507243565, 46.967376708984375, 45.18171746390206, 47.330534730638774, 47.27289594922747, 45.51297630582537, 44.16197551999773, 46.1970716203962, 46.60864816393171, 46.47257464272635, 45.41022287096296, 46.003901277269634, 45.97363492420742, 47.776633398873464, 46.19686317443848, 46.902306829180034, 45.60362250464303, 45.76645353862217, 45.56045682089669, 43.819460596357075, 37.03275898524693, 31.633456298283168, 31.800789764949254, 31.242130279541016, 31.913625035967144, 33.98112753459385, 32.84504495348249, 31.612413678850444, 34.362159797123496, 39.377505029950825, 40.74348613194057, 41.995784282684326, 47.0346109526498, 45.148765632084434, 28.145222629819596, 45.120118209293906, 47.102265562329976, 43.55777754102434, 43.30900771277291, 43.616211891174316, 42.49313633782523, 38.730342864990234, 33.304359095437185, 32.175599915640696, 33.29288761956351, 32.634792464120046, 32.65538692474365, 34.96332836151123, 38.01982355117798, 42.377626010349815, 42.632440771375386, 47.75115435464041, 47.646608284541536, 46.10621697562081, 47.68490328107561, 44.749351910182405, 40.42087779726301, 43.3160080228533, 45.37561389378139, 42.33283792223249, 40.612880843026296, 39.287532806396484, 37.9113586970738, 40.04781511851719, 44.82201617104666, 46.28228432791573, 44.9843156678336, 38.980172293526785, 31.80706398827689, 36.07513393674578, 36.19424343109131, 40.63395472935268, 42.67481436048235, 45.670585768563406, 46.58611863000052, 50.65918391091483, 47.86851985113961, 39.080358369009836, 23.74539920261928, 11.978801199368068, 16.430976697376796, 14.396595392908369, 12.325840268816266, 1.939262637070247, 2.338887627635683, 6.190139268125806, 1.434877593602453, 0.051949258494590006, 0.07050451104130064, 2.005852218185152, 11.99140088898795, 27.544453586850846, 40.03017364229475, 33.259880202157156, 46.263055188315256, 40.999165943690706, 44.5361499105181, 24.53259536198207, 9.723089371408735, 0.5698904884713036, 0.013478649464169783, 0.05633060321477907, 0.054460570881409306, 0.01947630785538682, 0.04526478610932827, 0.015091132805017489, 0.02492681341911001, 0.04585011416514005, 0.035714422685227225, 0.03297341940924525, 0.03836708070178117, 0.04212754891653146, 0.0313646875188819, 0.0950096200353333, 0.009529339016548224, 0.01902104478462466, 0.06759705633989402, 0.037731398562235494, 0.0353743578972561, 0.043850447716457505, 0.03493284194597176, 0.027116311913622276, 0.035474723404539485, 0.03966135571577719, 0.012948006241848426, 0.01155431566959513, 0.05426025716587901, 0.02949027524196676, 0.04637352929317525, 0.05377237352409533, 0.03132660134828516, 0.10060531512967177, 0.0463125086389482, 0.007842425473167427, 0.02313321635925344, 0.12616742561970437, 0.03133939851873687, 0.03577247814142278, 0.0680620971002749, 0.004480860362361584, 0.04416651611349412, 0.0477515830259238, 0.009449849487282336, 0.07818959866251264, 0.035649805795401335, 0.18257860147527286, 8.48098075389862, 33.3573807988848, 47.142756189618794, 46.809068952287944, 33.59416151046753, 26.063300882066997, 26.206885405949183, 24.776581355503627, 15.2745133127485, 2.8790099705968584, 0.216456674305456, 0.10149706620723009, 0.43581351584621836, 2.7696820199489594, 5.333739050797053, 6.413635892527444, 10.081777964319501, 12.12124274458204, 13.319779208728246, 13.50252638544355, 16.948200600487844, 28.23742696217128, 40.2119802066258, 47.92682565961565, 46.33189793995449, 44.46968691689627, 40.568117073604036, 40.659048148563926, 41.2717159816197, 47.200037138802664, 49.43083272661482, 48.04464626312256, 45.20007807867867, 46.87175212587629, 50.195933614458355, 47.119618688310894, 46.459518977573936, 47.52740151541573, 48.47184930528913, 48.34268924168178, 47.03684132439749, 47.520554065704346, 47.23456621170044, 48.266311168670654, 48.04918343680245, 47.880547182900564, 46.96636574608939, 46.98554972239903, 47.93543100357056, 44.88955613545009, 39.854346002851216, 33.66398048400879, 32.25933960505894, 32.96235139029366, 33.80387898853847, 35.97340536117554, 33.94185284205845, 32.71948058264596, 37.09608139310564, 42.612294469560894, 42.36691536222185, 44.65701035090855, 48.843438965933665, 47.19810206549508, 29.923542840140207, 46.80278083256313, 47.57296085357666, 47.105600697653635, 45.09126928874424, 45.65819713047573, 45.414409160614014, 40.70264114652361, 34.759680134909495, 34.27254887989589, 35.23564216068813, 34.14158923285348, 34.709941455296104, 37.35596833910261, 41.02687535967146, 44.8356728553772, 43.90193918773106, 49.416484696524485, 48.434745924813406, 46.38311311176845, 50.00585521970476, 45.93963391440255, 42.10024350030081, 44.510337352752686, 47.47768020629883, 43.738121509552, 41.69593824659075, 40.64304992130825, 39.882583481924875, 40.319461890629356, 45.16281836373465, 47.81209005628313, 46.70201458249773, 39.58275829042707, 35.393995080675396, 37.94777767998831, 39.78169911248343, 42.85884782246181, 45.04014444351196, 47.781042030879426, 48.84414073399135, 52.100587708609446, 51.2688501221793, 41.10321521759033, 26.278646400996617, 13.130554573876516, 9.313162156513759, 15.878106798444476, 10.887526682444982, 6.199293085506984, 7.114822038582393, 2.56482241834913, 1.4309471930776323, 0.07809256815484591, 0.07812542960579906, 2.682150568280901, 13.857616680009023, 31.865578242710658, 43.343199798039024, 35.48044456754412, 49.11130244391305, 46.84693316050938, 52.35280384336199, 30.585032190595353, 12.69438488142831, 0.8164478582995278, 0.06260645841913563, 0.07430170157126018, 0.055080141206937175, 0.01779224500725312, 0.04769748003621187, 0.05550279727737818, 0.04662900451304657, 0.019423064908811023, 0.08421175980142184, 0.08732865112168448, 0.09047260241849081, 0.05147978011518717, 0.032681079381810765, 0.09301803154604775, 0.0101525225410504, 0.024994437915406058, 0.014059600120942508, 0.02464179478452674, 0.05385460518300533, 0.03399079446015613, 0.018709541231926, 0.027730436995625496, 0.07891421299427748, 0.1614399557667119, 0.12223296745547227, 0.23953075973050936, 0.33924183355910437, 0.11611848484192576, 0.11928067516003336, 0.16318250154810293, 0.09882047626056842, 0.1778527679187911, 0.13709464855492115, 0.06554547856960978, 0.07430472105209317, 0.2279075634266649, 0.11256646258490426, 0.10306318609842233, 0.14599174899714334, 0.09671788622758218, 0.13017626479268074, 0.17680901821170533, 0.1571143628763301, 0.18508835323154926, 0.08302806224673986, 0.38149453486715046, 10.694517016410828, 39.052298069000244, 54.17896066393171, 52.71614946637835, 38.629611355917795, 27.25270915031433, 30.889099257332937, 29.889923981257848, 17.55086476462228, 4.060199388435908, 0.3036942524569375, 0.26630762432302746, 1.355407246521541, 6.933914831706455, 15.905576501573835, 13.650826130594526, 18.749885865620204, 18.508432490485056, 11.542357053075518, 17.60690893445696, 24.214058671678814, 27.198763336454117, 44.91432646342686, 51.107134274074006, 48.31183923993792, 46.11615637370518, 43.23027767453875, 42.07500416891915, 43.8700921194894, 50.492309025355745, 51.748188972473145, 48.152947834559846, 45.5213280405317, 47.893366609300884, 50.8007048198155, 48.35845123018537, 48.976250307900564, 50.08137171609061, 50.67268773487636, 50.21822690963745, 48.244643211364746, 48.82508877345494, 48.39021839414324, 49.85669476645333, 49.72854566574097, 49.8001503263201, 47.286886147090364, 48.43143858228411, 50.35174001966204, 47.7935140473502, 41.210012504032676, 35.68427692140852, 34.98811953408377, 34.70650904519217, 34.67143106460571, 37.39629915782383, 36.149906975882395, 34.87919609887259, 38.642145906175884, 43.6531207220895, 44.23566116605486, 45.58461570739746, 50.856054169791086, 47.07005371366228, 33.96532385689871, 47.026571886880056, 50.2161910874503, 48.58662659781319, 47.54557452883039, 47.50077254431588, 47.51260880061558, 43.65001140322004, 36.4601857321603, 36.29219913482666, 37.532560280391145, 36.149597781045095, 36.62692860194615, 38.69303103855678, 41.441509110586985, 46.78989887237549, 46.60361419405256, 51.912361008780344, 49.944971629551475, 46.19966329847063, 51.4899765423366, 48.12019750050136, 44.70991046088082, 47.8259517124721, 48.46324396133423, 46.69468075888497, 44.214861733572825, 42.537924425942556, 42.33846943719046, 43.69968407494681, 49.69686188016619, 50.276883602142334, 49.48081111907959, 43.77680560520717, 35.8852778843471, 39.493835244859966, 41.99200793675014, 46.01600156511579, 47.354280199323384, 50.20021023069109, 51.58426707131522, 54.358467374529155, 53.385156767708914, 43.70877579280308, 30.284842218671525, 16.042561973844254, 22.568490743637085, 23.116540329796926, 22.927347830363683, 12.123126574925013, 11.209198747362409, 11.334057007517133, 3.218407324382237, 0.3735013109232698, 0.33184175778712544, 2.810041282858167, 16.077865770884923, 36.033892904009136, 53.37516873223441, 42.61279821395874, 54.41931274959019, 52.50600119999477, 59.15466294969831, 35.79257154464722, 15.686584915433611, 1.2606379432337624, 0.1076228464288371, 0.17037499988717691, 0.19035822259528296, 0.06921834112810236, 0.1428005038095372, 0.10723385587334633, 0.07887615396508149, 0.10763858165591955, 0.17592643414224896, 0.2257719694503716, 0.1210694427468947, 0.16188725962170533, 0.1702620102358716, 0.14222419687679835, 0.11230599334729569, 0.2050192201776164, 0.17631812526711396, 0.15432927518018655, 0.10940019427133457, 0.16044039226004056, 0.1663717518427542, 0.11158756046955075], [0.0318615481789623, 0.05521455899413143, 0.04400525887363723, 0.06564879231154919, 0.04417211402739797, 0.017984443443960378, 0.06082899522568498, 0.02613446834896292, 0.026500816190881387, 0.02390298041115914, 0.08023993471371275, 0.025731192934992056, 0.048474348349762816, 0.019183241795482378, 0.031342777623129744, 0.04815976933709212, 0.028942541418863193, 0.009530935270179595, 0.030145122603114163, 0.033139059985322614, 0.014455140235700777, 0.06555893391902957, 0.027761135616206696, 0.0723342824993389, 3.931677690574101, 25.63419577053615, 41.353947911943706, 42.17560018811907, 26.430980443954468, 17.46792585509164, 23.396938358034404, 28.97293199811663, 15.129261221204485, 3.0783563937459673, 0.35849738174251145, 0.11727373142327581, 0.2805430718830654, 2.957647728068488, 4.954525913511004, 6.88449272939137, 4.887197869164603, 11.270348106111799, 16.285714183534893, 15.021532876150948, 17.13663748332432, 40.088413442884175, 39.43171487535749, 46.76497220993042, 43.14878920146397, 42.82815762928554, 38.44135686329433, 37.69906343732561, 41.68982383183071, 46.580344676971436, 46.93896205084664, 45.707157611846924, 48.2817257472447, 45.980002948216026, 41.10465349469866, 40.68307849339077, 39.915622166224885, 40.33669689723423, 41.77854537963867, 43.0268691607884, 41.02336999348232, 43.631852286202566, 42.68881498064314, 44.254358768463135, 42.41905811854771, 42.940579482487266, 45.98911551066807, 46.1718670300075, 43.85193647657122, 40.96997308731079, 33.30670063836234, 31.482374668121338, 31.67858832223075, 30.430806500571116, 31.146811417170934, 31.132862908499582, 31.152415139334543, 33.191843441554475, 33.009630407605854, 33.68125023160662, 38.86045830590384, 41.689924580710276, 44.96950210843767, 45.44153492791312, 26.389501435416086, 43.86047581263951, 43.73971264702933, 44.98204013279506, 46.80666487557547, 46.93640858786446, 44.250019618443076, 40.75258479799543, 34.48074122837612, 32.47204828262329, 33.72463478360857, 35.962753772735596, 33.403256280081614, 35.395273549216135, 35.679204736437114, 40.46864318847656, 42.00006784711565, 47.858861855098176, 46.93070759092058, 45.28169856752668, 45.236448424203054, 48.82984481539045, 44.81841353007725, 46.24287414550781, 43.161108357565745, 43.384131635938374, 39.225877966199604, 42.05027553013393, 42.94496379579817, 42.908902645111084, 46.685818331582205, 46.71196092878069, 46.06304086957659, 45.76345886502947, 36.06353391919817, 34.78769874572754, 35.754280022212434, 38.54182434082031, 39.02991097314017, 44.16927807671683, 47.47054788044521, 48.42035967963082, 48.77609355109078, 43.67422934940883, 23.337850877216884, 16.130427156175884, 8.558246459279742, 13.878024407795497, 11.451705643108912, 4.9330698762621195, 3.2611094330038344, 1.9846812742097037, 0.6308745560901505, 0.0535049051977694, 0.1366347103778805, 2.338800775153296, 13.857122489384242, 39.42262315750122, 30.08038452693394, 33.113672733306885, 42.883677210126606, 44.68405621392386, 45.32904359272548, 31.112254551478795, 9.539032459259033, 0.10362465347030334, 0.08451369431402002, 0.03625508278076138, 0.025939913699403405, 0.05662448012403079, 0.04223158869094082, 0.009539940278045833, 0.028779421600380113, 0.07158397204641785, 0.0804381687194109, 0.061800881288945675, 0.03265424332182322, 0.025886526564136147, 0.037785423520420275, 0.06304491417748587, 0.05610503442585468, 0.013636528447802578, 0.030084224085190465, 0.03552805964968034, 0.013578497588501444, 0.07052567454853229, 0.02702640093463872, 0.019692831772512624, 0.03347929779972349, 0.019345857801714113, 0.04218611327399101, 0.0308625546417066, 0.03580810801525201, 0.0635496424511075, 0.06289945662553821, 0.018827701320073435, 0.04633174849940198, 0.08782231248915195, 0.029805729564811503, 0.05883604288101196, 0.004565131443087012, 0.022633512637444904, 0.08483101121549096, 0.0391929053169276, 0.022046400034534078, 0.038161094433494976, 0.049528181087225676, 0.021850568042801957, 0.030607469579471008, 0.03164771465318544, 0.03667440724426082, 0.07199038059583732, 6.230157852172852, 29.82120282309396, 47.04727404458182, 47.591835635049, 31.888305800301687, 18.519191776003154, 24.480502980096, 30.909276826041086, 17.379186936787196, 3.5457606273038045, 0.25557550734707285, 0.10338630447430269, 0.37227077409625053, 2.9685911408492496, 4.985767619950431, 7.039648175239563, 7.518646563802447, 9.373097317559377, 7.469797253608704, 14.928913388933454, 19.117216280528478, 33.99036863871983, 41.87002536228725, 49.1310179574149, 45.82577378409249, 43.49142919267927, 39.758346217019216, 39.39532368523734, 44.592468534197124, 47.73847041811262, 47.44602421351841, 46.12924330575125, 48.79912682941982, 48.25169563293457, 43.96786369596209, 43.89400781903948, 43.2127925327846, 43.483775751931326, 43.695101737976074, 46.084594181605745, 43.8553341456822, 45.84553446088518, 45.79738344464983, 47.385296957833425, 45.50860241481236, 46.29942553383963, 47.83816317149571, 46.88456807817732, 46.37521300997053, 42.57613256999424, 34.97980254037039, 34.08422490528652, 32.03046594347273, 33.02692099979946, 32.696669646671836, 33.68578740528652, 33.142254148210796, 35.609017508370535, 34.081890310559956, 35.49012688228062, 41.08159589767456, 44.65302555901663, 46.62474366596767, 48.58122089930943, 28.6661342893328, 45.25243622916085, 44.68875319617135, 46.9125519480024, 48.094173022678916, 47.95887769971575, 46.50087118148804, 42.759464263916016, 36.24634102412632, 33.75752755573818, 36.54304647445679, 36.90870237350464, 34.274873052324565, 36.45570761816842, 36.262909003666465, 41.67959260940552, 44.76146262032645, 50.371886321476524, 48.04467058181763, 45.608166626521516, 46.615631103515625, 49.99674265725272, 46.5005133492606, 47.088396957942415, 45.64981760297503, 45.03992557525635, 41.626491001674104, 43.80395221710205, 43.484022412981304, 45.75219930921282, 49.28539650780814, 48.762652260916575, 49.30293723515102, 47.67721162523542, 37.486990519932334, 37.409747396196636, 37.91419356209891, 40.106464862823486, 42.776966776166645, 46.87238788604736, 49.01164790562221, 50.25717503683907, 49.87505538122994, 44.37969732284546, 24.1029691355569, 14.073941026415143, 8.985956719943456, 17.882069758006505, 13.78664083140237, 5.913327378886087, 2.79262866292681, 1.8069859806980406, 1.1705397835799625, 0.13772584897066864, 0.12487879262438842, 2.7507027983665466, 14.130615745271955, 38.32867792674473, 39.20475891658238, 38.54849461146763, 48.22969763619559, 49.21781832831246, 52.030028751918245, 35.47288492747715, 11.502963372639247, 0.18090483200337204, 0.010137597315146454, 0.03577124999303903, 0.03503775363788009, 0.03600772623238819, 0.03904668441308396, 0.01424009382857808, 0.028218819360647882, 0.042641725790287764, 0.06770313850470952, 0.004911732219625264, 0.02545908173280103, 0.04327808985752719, 0.0574124628411872, 0.0373880530574492, 0.037868187829319916, 0.035956015078616996, 0.04823733606774892, 0.046570270521832366, 0.050456841077123366, 0.01767723841060485, 0.06535783649555274, 0.04507953926388707, 0.06843603774905205, 0.09341355639376811, 0.1366442370095423, 0.1756369439618928, 0.12893160086657318, 0.08217513015759842, 0.11699545064142772, 0.0959678404033184, 0.11404100060462952, 0.15285304082291468, 0.16792729337300571, 0.08257834280708007, 0.20483324729970523, 0.09295015768813235, 0.14324949043137686, 0.2096695327865226, 0.07302484794386796, 0.07932028227618762, 0.1272059098950454, 0.11046381148376636, 0.14250482538981096, 0.16487564998013632, 0.14139624844704354, 0.2219598511500018, 7.364746570587158, 34.8563608442034, 54.87234919411795, 52.12908921922956, 38.17325019836426, 27.33745632852827, 32.660886423928396, 37.30425289699009, 20.157517944063457, 4.3402183055877686, 0.8019271003348487, 0.25472622577633175, 1.0642650233847755, 4.3862731371607095, 11.985800640923635, 19.169834988457815, 12.321790337562561, 22.15138864517212, 23.65182086399623, 22.411690746034893, 21.882055623190745, 43.08177382605416, 43.33314575467791, 50.97445147378104, 48.27082402365548, 46.93053388595581, 42.231533186776296, 42.25471237727574, 46.13474975313459, 49.52132606506348, 48.07884529658726, 46.43335553577968, 49.13721922465733, 50.618467467171804, 45.73179244995117, 45.635768345424104, 45.52178314753941, 46.239702292851035, 46.24035194941929, 48.39915725163051, 45.36268329620361, 47.723948683057515, 47.57950953074864, 50.24871907915388, 47.21485069819859, 47.3527307510376, 49.10491704940796, 49.30227368218558, 48.03258071626936, 44.813383034297395, 36.20718445096697, 36.03122826984951, 34.70764854976109, 33.725930622645784, 34.30204745701381, 35.07660484313965, 34.51397793633597, 37.004045554569785, 35.51606798171997, 38.783937794821604, 42.375749996730256, 47.10864748273577, 48.60689449310303, 48.854014124189106, 31.76587506702968, 46.48825325284685, 46.22078234808785, 47.78245251519339, 50.430275508335654, 50.86925574711391, 48.81940514700753, 44.53289120537894, 37.83877086639404, 35.63692842211042, 37.165174279894146, 39.05398300715855, 35.99185282843453, 38.40003592627389, 37.57492692129952, 44.46198831285749, 46.62892648151943, 53.070757729666575, 49.40256398064749, 45.77017082486834, 45.57245635986328, 52.69534655979702, 47.60176461083548, 50.79760939734322, 47.721127714429585, 47.77748455320086, 43.93842417853219, 46.83071606499808, 46.8907276562282, 48.662500926426475, 50.784758704049246, 51.01056126185826, 51.27324138368879, 49.92607600348336, 40.97683790751866, 38.36357525416783, 40.16645213535854, 43.211871896471294, 44.09657907485962, 48.73059674671718, 51.703261920383994, 52.81103754043579, 54.062185764312744, 47.399155139923096, 29.511570249285015, 21.83591784749712, 12.075010299682617, 22.379298244203838, 22.28429205077035, 12.479058470044817, 10.050556233951024, 7.255378884928567, 2.9770755427224294, 0.4011100051658494, 0.25494607112237383, 3.7137639437403, 18.030231407710485, 46.749404770987375, 42.66702195576259, 44.51751831599644, 52.871427808489116, 55.79689039502825, 59.097493171691895, 43.33535875592913, 15.074306181498937, 0.8945352967296327, 0.18991323933005333, 0.0710495850071311, 0.08315880915948323, 0.18024188971945218, 0.14736404536025866, 0.08514491508581809, 0.13131066677825792, 0.07635994934077774, 0.14796563450779232, 0.10354199433433157, 0.060402468112962585, 0.19238246897501604, 0.1393103368048157, 0.14780885220638343, 0.12951890006661415, 0.12097064804817949, 0.150904600375465, 0.15446400509348937, 0.07476189759160791, 0.1884908535118614, 0.14240544715097972, 0.16537910939327308], [0.006584048778417387, 0.07765887571232659, 0.006462702120188624, 0.026903701447216526, 0.025006397095109736, 0.05063111601131303, 0.014588053371491176, 0.04638308645891292, 0.019235455065167377, 0.02610564587770828, 0.019799887635079876, 0.0202621972920107, 0.01801102844599102, 0.0402088690149997, 0.03158604599801557, 0.03035066443096314, 0.021762523035119687, 0.0703607430415494, 0.06229693788502898, 0.006522713453575436, 0.04948493465781212, 0.08703440441084759, 0.01959533816469567, 0.025202855035396557, 2.73073302422251, 19.15952386174883, 40.97297123500279, 43.207491057259695, 31.3342182295663, 28.06407461847578, 23.372914961406163, 25.350919451032365, 17.797878435679845, 4.781779365880149, 0.35775316453405787, 0.02270925071622644, 0.18113364758236067, 1.518769274864878, 2.8280627386910573, 4.024087429046631, 6.6141470074653625, 7.243744994912829, 10.328914097377233, 13.883843524115425, 22.076622554234095, 32.99742937088013, 41.34260845184326, 45.599974700382774, 44.21132857458932, 38.85100180762154, 38.219236850738525, 40.281149523598806, 41.504921845027376, 48.312634808676584, 46.169747829437256, 46.04202951703753, 46.36697244644165, 41.98521607262747, 39.85067387989589, 37.723958832877024, 36.824344294411794, 35.880869252341135, 36.22150468826294, 35.70548629760742, 37.29268067223685, 35.89822237832205, 38.17422642026629, 39.5379250390189, 40.253443581717356, 39.297892570495605, 40.83818313053676, 39.36736413410732, 37.80961969920567, 31.508117743900844, 30.503255367279053, 30.815083571842738, 31.298726831163677, 31.946844373430523, 32.10738597597395, 32.04091950825283, 32.88988515308925, 32.13692624228341, 33.23328249795096, 36.6163603918893, 37.95907197679792, 42.14696666172573, 45.40613038199288, 46.96617814472744, 26.938254526683263, 43.07068450110299, 43.47086252485003, 42.995459829057964, 46.835069111415315, 48.31222833905901, 45.09571960994175, 42.600871631077354, 35.09913090297154, 34.45937899180821, 36.428025994982036, 34.12129354476929, 32.31334795270647, 32.54614734649658, 34.68862090791975, 37.6765582220895, 43.30946976797921, 45.71092700958252, 48.14196968078613, 46.35060943875994, 45.22500821522304, 47.179876940590994, 47.590234075273784, 45.329814842769075, 47.90931619916643, 46.88271985735212, 44.65892457962036, 42.11492851802281, 46.9665116582598, 46.23042297363281, 48.20618840626308, 43.273425987788606, 47.22649587903704, 44.95416396004813, 39.57938494001116, 35.90152277265276, 35.195540632520405, 37.644106660570415, 39.92750358581543, 43.011531012398855, 43.41669436863491, 47.57234941210066, 48.31689405441284, 41.3808513368879, 26.939659799848283, 13.946435502597264, 8.121777125767299, 16.761471237455094, 6.262402270521436, 3.7035222990172247, 3.3107406326702664, 0.8480167271835464, 1.1246496460267474, 0.14138364126639708, 0.053503934892692735, 2.5684908500739505, 11.70194501536233, 30.90260308129447, 38.54611832754952, 35.482216358184814, 46.541087354932515, 47.08884164265224, 42.35069479261126, 30.63473265511649, 9.405923213277545, 0.7505494058132172, 0.02859353693202138, 0.02268437562244279, 0.06679040712437459, 0.049050010674233945, 0.043176581018737385, 0.02339683230301099, 0.08494911702083689, 0.024089397729507515, 0.04279627910416041, 0.031846959676061354, 0.026075622399470637, 0.021337941621563265, 0.03259976713785103, 0.08889089657792024, 0.04310660370226417, 0.012979760832552398, 0.030050507680113827, 0.010973160604148038, 0.05305188807791897, 0.02730911085382104, 0.010578493255057504, 0.009987764060497284, 0.03408483602106571, 0.05991336650082043, 0.019693915732204914, 0.013524076535499521, 0.03275352317307677, 0.037399510121239085, 0.009064797827574824, 0.004497843669793967, 0.03506752436182328, 0.02341555817318814, 0.01961730743226196, 0.043030831696731706, 0.043185130559972355, 0.01901621531162943, 0.04132731185693826, 0.052197341075433154, 0.014040468826091715, 0.028870837230767523, 0.04161025756703956, 0.03155990543642214, 0.013092173729091883, 0.06529883787568126, 0.007764782407321036, 0.07718250341713428, 3.3629674187728336, 23.625693900244578, 47.44292879104614, 45.942718914576936, 35.70114714758736, 29.654869897024973, 29.95566783632551, 32.05555241448538, 20.764689752033778, 5.765296007905688, 0.3571769525962216, 0.03056226557652865, 0.45781599091632025, 1.9692067674228122, 6.3879892230033875, 6.90470677614212, 7.755947521754673, 6.239936138902392, 6.261447761740003, 14.05369484424591, 22.309361151286534, 34.11358799253191, 43.168344906398225, 48.5541125025068, 46.40310655321394, 43.160062653677805, 40.76056480407715, 42.586252621241975, 43.737774099622456, 49.904067584446494, 46.29029212679182, 46.71054002216884, 48.08326087679182, 43.5233804838998, 42.23884269169399, 41.13939101355416, 39.15684413909912, 39.72004427228655, 38.49779708044869, 38.722769328526084, 39.76834120069231, 38.69092920848301, 40.44484908240182, 42.86704669679914, 42.58590521131243, 42.80757359095982, 42.07493816103254, 42.78091335296631, 40.5960453578404, 34.32952410834176, 31.762526035308838, 33.45798029218401, 32.86785241535732, 33.295382022857666, 32.99335077830723, 33.86837216785976, 33.175362314496724, 33.95406430108206, 34.81133304323469, 37.98857750211443, 39.25428915023804, 43.96693958554949, 47.06141015461513, 47.88457018988473, 29.156499930790492, 43.64316395350865, 44.44602482659476, 44.668144839150564, 48.121920653751914, 50.981027943747385, 46.869671140398296, 43.52342912128994, 35.83078663689749, 36.036491530282156, 38.095548493521555, 35.781475271497456, 34.5809759412493, 33.58062641961234, 36.76910611561367, 38.46367795126778, 44.253226212092805, 47.34083890914917, 50.2132693699428, 46.27167442866734, 45.259172507694785, 48.12660026550293, 48.84114258629935, 47.84360013689314, 50.62243488856724, 48.15014771052769, 46.376390729631694, 44.730171407972065, 48.14604479925973, 47.880290099552695, 49.696636063711985, 46.747817107609336, 49.1382406098502, 46.69310699190412, 41.31940146854946, 37.394860880715505, 37.413238865988596, 40.38857562201363, 41.292188848767964, 45.79582357406616, 46.405795506068635, 50.94952481133597, 51.21745082310268, 43.92563949312483, 24.04368363107954, 18.091776813779557, 8.6882472549166, 15.561955077307564, 12.337087665285383, 6.502835128988538, 5.904213947909219, 2.3184781627995625, 0.7335208367024149, 0.10788003834230558, 0.08943723261888538, 2.8292854045118605, 14.330106343541827, 37.9935941014971, 41.41879892349243, 37.86390944889614, 50.53888974870954, 51.31183167866298, 49.06840079171317, 35.50240782329014, 11.909093397004263, 0.5664508044719696, 0.03044234129733273, 0.03035527846908995, 0.0527981465150203, 0.0565567046536931, 0.03984140159030046, 0.05551957066303917, 0.05298254858436329, 0.023635067644395998, 0.08895630056836776, 0.03938465592052255, 0.04373640972854836, 0.02919749416677015, 0.05192964204720088, 0.035288055028234205, 0.025148010746176754, 0.0493603386650128, 0.01615976099856198, 0.027217350866911665, 0.019966557888048034, 0.06586658848183495, 0.044445292225905826, 0.03975942098934736, 0.13000208485339368, 0.1461570265569857, 0.11324830885444369, 0.0993784898892045, 0.09024227370641061, 0.10511305396045957, 0.23860013538173266, 0.09964615159801074, 0.08734986212636743, 0.10247259600354092, 0.12006138398178987, 0.14754624558346613, 0.15437579554106506, 0.10632305831781455, 0.10442968098712818, 0.16756311005779675, 0.11367377745253698, 0.09481740463525057, 0.08333153703383037, 0.09019610618374177, 0.1278630303485053, 0.1780466525150197, 0.12574724959475653, 0.20930868786360535, 4.491979990686689, 28.224671806607926, 52.76366124834333, 52.87223032542637, 42.2070894241333, 37.2624386378697, 33.43897002083914, 33.31216887065342, 23.713246413639613, 6.274716215474265, 0.6938305550387928, 0.16311073968453066, 1.0404397589819772, 5.298915547983987, 8.933217287063599, 10.207748804773603, 13.94856686251504, 19.823260954448156, 21.31809639930725, 18.826644352504186, 24.372258731297084, 37.47393485477993, 43.76874222074236, 50.658266748700825, 47.80748687471662, 44.627018451690674, 42.73666722433907, 45.29285042626517, 45.32465927941458, 51.9628917830331, 46.15412827900478, 47.361287457602366, 50.0769978250776, 45.74855497905186, 44.23356281008039, 43.47346115112305, 40.973784174237935, 41.62650489807129, 39.48807518822806, 39.946965490068706, 41.18933466502598, 39.70115906851632, 42.44265072686331, 43.89561980111258, 44.15998138700213, 43.471407958439414, 43.86986630303519, 44.66286073412214, 41.7314053262983, 35.12754903520857, 34.213801860809326, 34.645382268088206, 34.482103075299946, 36.23287541525704, 35.45492730821882, 34.763890743255615, 35.14708389554705, 36.05131551197597, 36.61987270627703, 39.69389125279018, 41.54935210091727, 46.46376085281372, 49.0258708681379, 49.03331238882882, 31.52884074619838, 46.4912930897304, 46.79343897955758, 45.10891771316528, 49.860196658543174, 52.419350215366904, 48.73882688794817, 46.52312626157488, 37.835703236716135, 38.39970588684082, 39.03912081037249, 36.220952306474956, 35.940081800733296, 34.933138438633506, 37.42293160302298, 39.61141960961478, 46.71645641326904, 50.44134051459176, 50.64052104949951, 48.18346432277134, 46.257006781441824, 48.64281667981829, 49.88572781426566, 48.547490869249614, 51.7282372202192, 49.5731839452471, 49.09559604099819, 47.05689035143171, 49.81502989360264, 49.606372015816824, 50.73909861700875, 45.16733469281878, 49.96577453613281, 50.816786425454275, 43.90910278047834, 39.875551904950825, 39.32824925013951, 43.00831052235195, 44.42851536614554, 48.754505498068674, 49.213183879852295, 51.3658504486084, 53.71938943862915, 45.09955848966326, 31.963912623269216, 17.36859961918422, 13.508586083139692, 23.75074063028608, 13.030886139188494, 11.178759557860237, 15.024223566055298, 5.132634733404432, 2.207905181816646, 0.4188754361655031, 0.22251553061817372, 3.8779598644801547, 15.1881228855678, 39.52213525772095, 49.88437638963972, 47.39437477929251, 54.91111666815621, 58.179194927215576, 55.57981130055019, 41.86532490594046, 15.2520706312997, 0.8506253414920398, 0.09300314448773861, 0.10870733537844249, 0.14771361303116592, 0.12487298436462879, 0.11831125217889037, 0.10603054865662541, 0.14257491805723735, 0.12404085615915911, 0.1480201208697898, 0.0841989287042192, 0.11674788035452366, 0.10504425729491881, 0.12779396905430726, 0.24637875226991518, 0.14038953318127564, 0.12800192646682262, 0.16062298603355885, 0.09552729475711073, 0.08691591184054102, 0.12130787995244775, 0.1346314578716244, 0.11764647785042014], [0.03708909052823271, 0.02233536943926343, 0.04142806752185736, 0.05478607091520514, 0.01667891662301762, 0.03135058756119438, 0.04400821728631854, 0.0609853161232812, 0.011923571034068508, 0.027493132943553582, 0.03958878978820784, 0.039780455574925454, 0.024891329430309788, 0.004067221174149641, 0.032913993312312026, 0.030085387772747448, 0.027079694771340916, 0.008011937091526176, 0.027562026300334504, 0.025902270272906338, 0.024216799464608942, 0.0474016625168068, 0.03662152901025755, 0.023476056355450834, 2.0337739884853363, 17.27735413823809, 38.68006917408535, 43.47564288548061, 29.32928078515189, 17.78221719605582, 18.817453622817993, 23.191007648195537, 21.19309483255659, 6.515171221324375, 0.6552852062242371, 0.07704119171415057, 0.28272534906864166, 1.7680755257606506, 5.038575666291373, 3.963034042290279, 7.619820152010236, 3.7620760713304793, 1.0170922917979104, 14.035569599696569, 20.315749270575388, 31.84401798248291, 41.937342984335764, 46.46141236168997, 42.492406776973176, 41.113105978284565, 40.97944695608956, 41.10651213782174, 47.29543590545654, 47.8280222756522, 45.76602969850813, 48.63320732116699, 43.97193881443569, 39.26324190412249, 37.37545108795166, 34.67495380129133, 32.09889875139509, 32.500605378832134, 32.08660043988909, 31.128971917288645, 32.30660472597395, 32.79604625701904, 32.02464682715279, 33.19027662277222, 31.597019944872173, 31.76053885051182, 32.263956683022634, 33.279602663857595, 30.266210624149867, 32.25771025248936, 33.27947759628296, 31.508777822766984, 31.653178759983607, 32.64559343882969, 35.89661734444754, 37.88963862827846, 38.835389205387656, 41.74525656018938, 40.658919606889995, 39.78793512071882, 42.41674089431763, 42.66734504699707, 45.82886920656477, 44.797065189906526, 24.189118112836564, 39.38022872379848, 48.35641540799822, 44.80516331536429, 44.68153749193464, 45.1258087839399, 43.68273047038487, 39.08246367318289, 33.8661869594029, 32.33463723318917, 32.88307244437081, 31.686846256256104, 33.91966724395752, 34.04906702041626, 31.913955075400217, 32.279461588178364, 40.05897045135498, 43.70227575302124, 46.24645594188145, 45.803035804203574, 46.207907336098806, 45.3871340070452, 46.1384322983878, 47.109029633658274, 48.487903118133545, 46.40965870448521, 47.25800595964704, 48.030374663216726, 45.65758916309902, 46.22368669509888, 44.344483852386475, 46.51028946467808, 45.90006739752633, 46.9550575528826, 41.493818623679026, 37.78595413480486, 34.582730361393516, 38.420675550188335, 40.31451824733189, 44.95737402779715, 44.756616251809255, 49.029813970838276, 47.00243384497506, 45.9714948790414, 19.93238936151777, 17.641222613198416, 8.816785454750061, 16.14132366861616, 17.848772253308976, 4.211235421044486, 3.3827267927782874, 1.4875692576169968, 0.29598585037248476, 0.08280094979064805, 0.1896892413496971, 2.6173870606081824, 13.322770408221654, 28.731904200145177, 26.022801569529943, 36.25716284343174, 48.10161106927054, 46.90137577056885, 42.53097970145089, 25.182491643088206, 8.166766711643763, 0.2965715889419828, 0.06487554058964763, 0.014625167540673698, 0.0016459423267016454, 0.024473168654367328, 0.005505565287811416, 0.039786535248692544, 0.054307595161455016, 0.04859196900257042, 0.011657995820444609, 0.02813386168730046, 0.0348814157769084, 0.04172181211678045, 0.006890340758088444, 0.047845488879829645, 0.022072031694863523, 0.03346521141273635, 0.03816789335438183, 0.02833011606708169, 0.039062894614679475, 0.018346202692815235, 0.03438410728371569, 0.03548654009188924, 0.009314129761021053, 0.039989366329142025, 0.026125506597704122, 0.03718918801418372, 0.051472848879971674, 0.050210967127765925, 0.05140181304886937, 0.13532478495367936, 0.03623560882572617, 0.05134654976427555, 0.042844797750668864, 0.028993482435388223, 0.033671869430691004, 0.03280236751639417, 0.04658820420237524, 0.05076258895652635, 0.02284237589421017, 0.0503193189922188, 0.013887574530339666, 0.028408790506156426, 0.04618769890761801, 0.05732898946319308, 0.014619086170569062, 0.013545045812082077, 2.5781377724238803, 20.733719893864222, 44.45922640391758, 49.2626758984157, 35.168564251491, 25.989802837371826, 19.257100888660975, 27.19687863758632, 23.15946282659258, 7.180734821728297, 0.7980536967515945, 0.048928247565137487, 0.31859070169074194, 1.7472402666296278, 5.721995268549238, 5.262374971594129, 6.2191775270870755, 9.5728953736169, 6.198468855449131, 16.323085069656372, 22.64621503012521, 33.413831438337056, 43.95664930343628, 47.951766218457905, 44.43575538907732, 42.77735587528774, 41.787241050175254, 41.92442280905587, 48.208265917641775, 49.06143522262573, 45.62405368259975, 48.757368155888145, 45.51345573152815, 41.30626242501395, 39.0419556753976, 36.39372968673706, 33.090785367148264, 34.246513979775564, 34.183580671037944, 34.363813468388145, 34.38141325541905, 34.61311830793108, 33.65810578210013, 34.99953542436872, 33.91062068939209, 35.1113840511867, 34.71729959760393, 33.95036785943167, 31.72188949584961, 32.33486999784197, 33.491442816598074, 32.88579266411917, 32.87419612067086, 33.60135637010847, 35.42577614103045, 39.779861313956125, 39.64958259037563, 41.75807251249041, 41.047709533146445, 41.29432889393398, 44.178751945495605, 44.78345366886684, 47.76404326302664, 47.213158811841694, 26.035652262823923, 39.652757917131694, 48.97175482341221, 45.42265319824219, 47.052030086517334, 47.38911499295916, 46.03188167299543, 41.747539043426514, 34.79013408933367, 33.56043495450701, 34.493883746010916, 34.190810271671836, 34.50947897774832, 35.49824932643345, 34.46502092906407, 34.31853553227016, 42.211602279118125, 45.97636209215437, 47.79857928412301, 48.367247649601524, 47.46403741836548, 46.494909627096995, 47.75175884791783, 47.283533641270225, 49.53056716918945, 47.2302895954677, 48.5039256640843, 49.02283450535366, 46.54436343056815, 46.98377445765904, 44.74347373417446, 46.64619970321655, 47.75635160718645, 49.72770840781075, 42.16438579559326, 38.83579567500523, 37.46308176858084, 39.87543031147548, 43.33371550696236, 47.389764649527415, 48.75084032331194, 51.28878797803606, 50.09217963899885, 43.893403325762065, 25.7207008429936, 18.20282292366028, 10.517364008086068, 12.451539261000496, 10.69493043422699, 5.724660336971283, 5.092919698783329, 3.773355168955667, 0.9256528041192463, 0.12443690347884383, 0.12053072665418897, 3.1640370190143585, 14.404961892536708, 32.16023744855608, 34.76564168930054, 41.39982339314052, 52.89059094020298, 51.72966854912894, 46.758896010262625, 31.947681631360734, 10.591952051435198, 0.6392635287983077, 0.013143565123235541, 0.024857212689572146, 0.036322101684553285, 0.018533079718638743, 0.05340232088097504, 0.026929261861369014, 0.02368302989218916, 0.06036511476018599, 0.036542422005108426, 0.048440238394375355, 0.07150531626705613, 0.03140179320637669, 0.04368378594517708, 0.05157593531267984, 0.02788189279713801, 0.06075270074818816, 0.05143152949001108, 0.061249571586293836, 0.05163436057046056, 0.04029522277414799, 0.06718631195170538, 0.008659839646757712, 0.11094741017690726, 0.08076958557856934, 0.09715265075543097, 0.16151847583906992, 0.08799146448395082, 0.11246154071497065, 0.13568662053772382, 0.21481282822787762, 0.10364631230809859, 0.10324235327009644, 0.12555348713483128, 0.08579972852021456, 0.1467960165547473, 0.04990445589646697, 0.1296982911548444, 0.0982915378574814, 0.1284648094858442, 0.17756525906068937, 0.1497685970472438, 0.11939916094498974, 0.06601718254387379, 0.13807065332574503, 0.12064269850296633, 0.11675923903073583, 3.261252739599773, 24.582530328205653, 50.87958424431937, 55.47274303436279, 39.88598115103585, 27.044786044529506, 28.43961606706892, 32.3483738218035, 27.96676857130868, 8.923788581575666, 1.0809630645172936, 0.1474046760371753, 1.3021671090807234, 4.127723719392504, 11.834261298179626, 13.421428748539515, 18.237157446997507, 13.533107144492012, 4.358140749590738, 17.717942884990148, 22.183895792279923, 33.54556233542306, 46.10300343377249, 50.878663608006065, 45.938449246542795, 46.022769110543386, 44.85477692740304, 45.43806082861764, 51.81638554164341, 49.38700001580374, 46.786431721278596, 49.70866686957223, 47.98963737487793, 42.442275524139404, 41.46591813223702, 38.93447746549334, 34.52858304977417, 35.7696077483041, 34.785732405526296, 35.995142800467356, 36.19443103245327, 36.760375704084126, 35.73905304500035, 36.68189927509853, 34.39058835165841, 35.30340794154576, 36.38251876831055, 35.36373567581177, 32.71926518848964, 36.074598925454275, 36.470062596457346, 34.56983797890799, 35.007372992379324, 35.51424755368914, 38.35212114879063, 41.976447446005686, 43.57301146643502, 44.79902458190918, 43.899962425231934, 44.8089987209865, 46.62812396458217, 47.70648438589913, 49.0041230065482, 46.41702379499163, 29.06939036505563, 41.19926711491176, 49.670069626399446, 47.766152041299, 48.80680111476353, 49.778836727142334, 47.941079889025005, 43.26903820037842, 37.92458806719099, 36.419302531651084, 36.754209177834646, 36.516393184661865, 36.96275241034371, 37.953662804194856, 35.73778847285679, 35.72882529667446, 43.84394952229091, 47.91691058022635, 51.153492655072895, 50.489060742514475, 48.522418294634136, 47.87987668173653, 48.71170459474836, 48.73541879653931, 50.43488563810076, 46.65244960784912, 48.45117494038173, 50.04411547524588, 47.15771566118513, 47.0163927759443, 45.29488277435303, 47.44374867847988, 47.15262957981655, 52.71440199443272, 44.700207301548545, 41.84511259623936, 38.64011355808803, 42.16104023797171, 44.93683515276228, 50.79430552891323, 50.3912023135594, 55.30245310919625, 51.38842167173113, 48.38805055618286, 23.64657497406006, 21.594681603567942, 13.19430777004787, 24.522992951529368, 29.08911108970642, 13.078785283224923, 6.189687200954982, 5.259057641029358, 1.5434920511075427, 0.3175772689282894, 0.5311104208230972, 3.576538541487285, 18.04306820460728, 36.96660171236311, 37.39902979987008, 46.603318895612446, 57.47078439167568, 57.747569356645855, 56.82393489565168, 38.18746968678066, 13.594442367553711, 0.9521118700504303, 0.15361168368586472, 0.10643493517168931, 0.1607952117919922, 0.13875510516975606, 0.13176501382674488, 0.18017014142658028, 0.18281520663627557, 0.12286879548004695, 0.1621334592678717, 0.1028432050453765, 0.12028946674295835, 0.2050277968602521, 0.13696810177394322, 0.11739548774702208, 0.14918787963688374, 0.14531731233000755, 0.11525359696575574, 0.12932968379131385, 0.1212100623441594, 0.18386859154062613, 0.10651006256895405, 0.11599999905696937], [0.04537564176799996, 0.033480719330587556, 0.019049069977232387, 0.050920131217156134, 0.023992569086008837, 0.0484932319793318, 0.045807970355131795, 0.024744950767074312, 0.015087872444252883, 0.015569874883762427, 0.008815470983141234, 0.03577726859865444, 0.012538172786922326, 0.03929130646533199, 0.08929721691778728, 0.024107519703518068, 0.03266854005466614, 0.06179533765784331, 0.04634604862491999, 0.07910296108041491, 0.07333414456141846, 0.04949533320697291, 0.03063270090413945, 0.04305067206067698, 1.1071174953665053, 13.171482069151741, 34.5260261126927, 43.381678921835764, 29.05260525430952, 21.38328787258693, 24.653870957238333, 31.03682143347604, 26.733593600136892, 9.739349024636404, 0.8989668903606278, 0.13539322199566023, 0.2598791835563523, 0.8853141143918037, 3.5627965245928084, 4.332454996449607, 2.448560816901071, 5.168716294424875, 7.22979257787977, 12.344078421592712, 22.708196435655864, 31.07759346280779, 41.74452005113874, 44.615241255079, 42.17443636485508, 42.57061570031302, 42.050199099949424, 46.687902791159495, 47.8237178666251, 44.70435190200806, 45.138982568468364, 47.34435817173549, 41.38555874143328, 37.73545115334647, 36.806181703295024, 32.46356800624302, 33.45541640690395, 32.431592396327424, 32.65835380554199, 32.99173184803554, 31.370032719203405, 32.79982607705252, 30.3474246433803, 31.63229247501918, 31.028341157095774, 32.34582035882132, 29.928684507097515, 33.41068043027605, 30.611529145921978, 44.42932135718209, 40.565483706338064, 30.83576488494873, 32.29118319920131, 34.10438510349819, 41.81997748783657, 43.19641562870571, 45.2002899987357, 42.48183856691633, 42.17563492911202, 47.96505812236241, 41.825497831617085, 46.99691697529384, 47.998277459825786, 47.90604359763009, 25.19570016860962, 41.587740898132324, 49.60446126120431, 44.76142093113491, 45.57141760417393, 41.08570575714111, 41.47072628566197, 33.92528486251831, 33.04084866387503, 32.58073200498308, 35.71114213126046, 34.192012310028076, 34.24036482402256, 34.088866301945274, 32.358292375292095, 33.29109845842634, 33.885860783713206, 39.11934123720442, 43.394988196236746, 42.60177837099348, 41.1027774810791, 42.825149059295654, 45.50098718915667, 47.9177200453622, 46.632831369127544, 47.38735709871565, 45.550875255039756, 44.56623213631766, 48.24323967524937, 45.69952154159546, 43.93467215129307, 46.78086274010794, 46.77519995825631, 47.313855579921174, 44.25203807013375, 41.26217610495431, 35.074989386967246, 39.15368965693882, 39.51077842712402, 45.44059344700405, 45.36940220424107, 49.37536178316389, 47.923285552433555, 36.69814763750349, 24.01103925704956, 19.854072741099767, 12.447844556399755, 12.406023349080767, 8.676631603922162, 2.57661720258849, 3.4999227098056247, 1.75717217368739, 1.0323832141501563, 0.03646923182532191, 0.13400143810680934, 3.104395853621619, 13.764298898833138, 35.657647950308665, 30.56408337184361, 34.32992362976074, 43.12464073726109, 44.74175752912249, 43.10873283658709, 24.989906685692922, 6.606139208589282, 0.5920130642397063, 0.019120458646544387, 0.012247993893522238, 0.033492111933550665, 0.031043027993291616, 0.007852268471781696, 0.01609137823938259, 0.017343009023794105, 0.04034172956432615, 0.018049182470089624, 0.04518989280664495, 0.07777588229094233, 0.09805540088564157, 0.07077365195644753, 0.022024971898645163, 0.0442552345671824, 0.032293798734566996, 0.029238935693034103, 0.013857914068336998, 0.07624474087996141, 0.04875063763133117, 0.04105857467012746, 0.05313212484387415, 0.0297805796643453, 0.027885455105985914, 0.022578520766858543, 0.013818342754218196, 0.03582080679812601, 0.031192549970000982, 0.039290624537638257, 0.014865626780582326, 0.0463321895471641, 0.004454345334254737, 0.043064480248306475, 0.027626548195257783, 0.030165237773741995, 0.03226114084411945, 0.08213920172836099, 0.014494632670123662, 0.031003303160624843, 0.009708197454788854, 0.05707535985857248, 0.10443117376416922, 0.021374940439792614, 0.021414149585845213, 0.014445160681914006, 0.04085950267368129, 1.5541358228240694, 15.835295472826276, 41.33830056871687, 48.306676728384836, 34.012745312282014, 21.903596775872366, 27.265433038984025, 35.98476913997105, 29.016587529863628, 10.343341163226537, 1.1057919093540736, 0.12617445524249757, 0.1860424548919712, 1.2683844247034617, 4.052104737077441, 4.24904100384031, 5.333656540938786, 7.548309292112078, 10.85110683100564, 15.961309739521571, 22.513115337916783, 33.313638414655415, 43.43708733149937, 47.07668229511806, 43.735748699733186, 44.46431943348476, 43.941880907331196, 48.525763852255686, 48.8759217943464, 45.503762994493755, 45.68009785243443, 47.92935132980347, 44.373436995915, 39.201705183301655, 37.831044469560894, 33.781679494040354, 34.01053925922939, 34.52882276262556, 33.62998989650181, 33.43461350032261, 33.52521106175014, 32.87750693729946, 31.1881879397801, 32.125889028821675, 32.897260665893555, 33.96987840107509, 31.441248280661448, 34.514127322605674, 32.05540997641427, 44.50683546066284, 39.70533493586949, 31.891397748674663, 34.24140010561262, 34.40583964756557, 43.42401429585048, 45.79922124317714, 45.7599013873509, 44.594400133405415, 43.26032863344465, 49.148690700531006, 43.678335734776084, 48.953081539699006, 48.44917385918753, 47.97107873644148, 27.047431571143015, 42.073833397456575, 49.78725446973528, 45.099624497549875, 46.27125753675188, 43.65547268731253, 44.590686321258545, 36.601244585854666, 35.15829133987427, 33.883425440107075, 36.853158473968506, 35.609462193080354, 35.013497829437256, 35.773866994040354, 33.69223880767822, 34.21263803754534, 37.01593392235892, 42.37686518260411, 45.540689195905415, 45.15627316066197, 45.389096873147146, 45.49549811226981, 47.85181985582624, 49.358241421835764, 48.294593811035156, 47.81533486502511, 48.3286121913365, 48.009863580976216, 50.92540066582816, 47.89900507245745, 46.19027280807495, 46.918617725372314, 46.72934879575457, 50.784578050885884, 47.1013970375061, 42.04935141972133, 37.6166786466326, 41.09474188940865, 42.698552880968364, 47.18897213254656, 49.47396714346749, 51.009272371019634, 50.18811341694423, 40.45763724190848, 26.69173765182495, 21.75063739504133, 9.35854171003614, 5.481726561273847, 7.129342036587851, 8.818509476525442, 5.068639653069632, 4.577792414597102, 1.2649120624576295, 0.16344083340040275, 0.24691191794616835, 3.843744329043797, 15.792916672570364, 37.23130028588431, 30.8769086429051, 39.33372443062918, 49.003931931086946, 49.47856337683541, 50.23234912327358, 30.233793803623744, 10.155381100518362, 0.48552877243076054, 0.026336865167000463, 0.04447388908426676, 0.03479504166170955, 0.04378412091838462, 0.01490957210106509, 0.02631761003950877, 0.01811436763299363, 0.050357188031609566, 0.014472090040466614, 0.027956548612564802, 0.015129164692812731, 0.03510368349296706, 0.008279918559959956, 0.023274567078000734, 0.0693788757281644, 0.029158739639180045, 0.054481032104896646, 0.025848157105169127, 0.09433979062097413, 0.06094117742031813, 0.0681988490479333, 0.03685140310387526, 0.14335398482424871, 0.13694661935525282, 0.07701521060828652, 0.08888244881693806, 0.15666718115764006, 0.07416447464908872, 0.1661078017205, 0.11492325897727694, 0.10846224852970668, 0.08010343382401125, 0.17098535570715154, 0.15375433888818535, 0.13005714118480682, 0.10029858337449175, 0.1482772585004568, 0.07128835469484329, 0.09977887983300857, 0.15777365464184964, 0.16587904042431287, 0.17505458449678762, 0.12550512115870202, 0.1432815987084593, 0.0977671659950699, 0.08389401542288916, 1.9562075563839503, 19.12729811668396, 47.129832540239605, 56.28253126144409, 39.100542885916575, 30.31223896571568, 34.07848916734968, 40.68937356131417, 33.274130957467214, 12.984933359282357, 1.4857887817280633, 0.5199244182024683, 0.4158603793808392, 3.2020725437573025, 9.201598405838013, 13.808377402169363, 12.892513632774353, 11.32481677191598, 14.289244856153216, 13.286305393491473, 26.61009110723223, 35.64282396861485, 45.00710923331124, 49.04168496813093, 47.07229798180716, 46.65428045817784, 46.48412602288382, 50.28992189679827, 50.047693797520225, 45.46839318956648, 46.85770981652396, 49.719815254211426, 47.51987314224243, 41.45962653841291, 42.24126761300223, 35.86920322690691, 37.519601890019004, 36.23482091086251, 35.96255227497646, 35.56264870507376, 35.85529293332781, 36.22856405803135, 33.88285568782261, 34.40594734464373, 35.13171100616455, 35.6556989806039, 33.55485207693917, 36.91298941203526, 34.0951509475708, 45.81549392427717, 42.205077920641216, 33.95163590567452, 35.44630459376744, 37.42250081471035, 46.65471819468907, 47.72477551868984, 49.373110566820415, 46.945722648075645, 47.41372203826904, 50.49766608646938, 45.09050498689924, 50.97384350640433, 48.890943799700054, 48.44061367852347, 30.686837196350098, 44.25040176936558, 51.18897015707833, 47.175343241010395, 48.548401083265034, 45.51978554044451, 46.66654750279018, 37.22188547679356, 35.91794831412179, 35.56296484810965, 39.27080154418945, 36.80473647798811, 37.47396959577288, 38.17412567138672, 36.0893360546657, 35.77547550201416, 38.307423387254985, 44.8129175049918, 48.55335167476109, 47.0628136907305, 46.57988609586443, 46.46853426524571, 49.5697272164481, 52.209035192217144, 51.004068170275005, 50.541926111493794, 50.68090745380947, 48.89203119277954, 53.68392235892159, 49.21634183611189, 46.59127419335501, 47.15923384257725, 48.344912665230886, 52.312959398542134, 48.66688176563808, 43.97779961994716, 39.46089036124093, 43.59961264474051, 44.51432909284319, 50.86989845548357, 50.29310417175293, 53.989580563136506, 52.61597033909389, 40.04144014630999, 26.558278390339442, 23.072454009737285, 16.971049751554215, 22.106008223124913, 17.14920677457537, 11.160297325679235, 13.915092178753444, 9.818287508828298, 1.708034296120916, 0.7733210953218597, 0.6426307995404515, 4.299523574965341, 18.855748619352067, 43.77087879180908, 42.280240058898926, 45.73472458975655, 53.02556664603097, 55.54003633771624, 58.45283235822405, 38.22069249834333, 12.373478855405535, 1.0096021337168557, 0.2016620731779507, 0.12018620728382043, 0.12970755994319916, 0.08310211077332497, 0.0659969418442675, 0.13263366078691824, 0.12509441748261452, 0.19130790020738328, 0.13339663270328725, 0.17994873544999532, 0.20409106569630758, 0.14882163357521805, 0.1279499778257949, 0.16242290873612675, 0.12323372518377644, 0.0774216598698071, 0.14922487336610044, 0.07370202589247908, 0.301718711320843, 0.1615324808018548, 0.186194066756538, 0.14182021069739545], [0.011368610813016338, 0.053814741250659735, 0.046361475118568966, 0.0349805667065084, 0.048357982986739705, 0.05583230745313423, 0.030833886537168707, 0.02595153191526021, 0.010089944648955549, 0.023752413490521054, 0.057161696654345305, 0.06886613395597253, 0.09322545291589839, 0.017953872048695172, 0.015993280735399042, 0.013534551419849907, 0.021999993328271166, 0.08394599120531764, 0.03813142888247967, 0.03345171195854034, 0.0689618888178042, 0.054633308933781724, 0.01723524578846991, 0.030710389771099602, 0.6436779690640313, 10.97327092715672, 32.11055088043213, 47.485437870025635, 37.26452309744698, 26.320804595947266, 16.258289643696376, 27.365263019289287, 27.14935122217451, 10.513539893286568, 2.7380318897111073, 0.10910646324711186, 0.16213860256331308, 0.8305534071155957, 2.5865207740238736, 1.622552671602794, 4.848550685814448, 10.597650442804609, 12.67036235332489, 19.243444204330444, 21.219529254095896, 30.450553280966624, 38.8073844909668, 43.73263938086373, 44.08808142798287, 45.95672648293631, 48.58648763384138, 46.74120937074934, 41.34527656010219, 44.43811777659825, 44.706835883004324, 46.14693341936384, 41.293422154017854, 40.98115621294294, 36.11069481713431, 32.0459361076355, 31.588404178619385, 32.12760523387364, 32.09490353720528, 34.61561965942383, 33.095124517168315, 35.979287011282786, 36.018193449292866, 35.362901891980854, 33.2285646711077, 32.08361618859427, 32.52431958062308, 30.581554617200577, 30.058723517826625, 34.64646618706839, 34.35506221226284, 31.83404036930629, 34.010817187173025, 40.97385018212454, 45.945498194013325, 45.38982990809849, 48.36233874729702, 45.26102420261928, 48.14916454042707, 34.80030972617013, 40.09467029571533, 46.78277349472046, 43.76396186011178, 39.81906999860491, 22.419521365846904, 43.52406488146101, 48.79359606334141, 41.20107364654541, 42.64056321552822, 36.729640347617014, 35.00591387067522, 32.13544280188424, 31.75301742553711, 33.17730781010219, 33.49435063770839, 32.86814423969814, 33.503431933266775, 31.676208564213344, 32.56139516830444, 32.33756242479597, 31.263878141130718, 32.06969199861799, 34.905227524893625, 36.49820627485003, 38.80425780160086, 39.076967648097444, 41.0130866595677, 43.85150916235787, 44.273601804460796, 42.48476723262242, 41.924506187438965, 42.14961739948818, 42.28944294793265, 45.21001747676304, 47.02696793419974, 46.51466335569109, 47.36112070083618, 47.708888462611604, 46.6560765675136, 43.5816376549857, 38.95434583936419, 36.47137233189174, 41.00602728979928, 44.435852663857595, 48.93112175805228, 48.86517293112618, 47.033335958208355, 35.465769972120015, 26.09668002809797, 20.67167248044695, 10.974528551101685, 2.029152567897524, 1.6386757493019104, 4.994698226451874, 1.2454095546688353, 3.2660780463899886, 1.33560140643801, 0.1147982185440404, 0.22099197522870132, 3.2214345676558356, 14.453731298446655, 34.00159692764282, 27.837935073035105, 37.10093123572213, 40.70730338777815, 40.31393807274954, 45.10231692450387, 24.01661171231951, 5.4221479296684265, 0.7615545381392751, 0.009775366484453636, 0.06215047610125371, 0.00996098737232387, 0.025230639348072664, 0.0256443964317441, 0.017310351133346558, 0.07932614481874875, 0.04819965362548828, 0.03791589562648109, 0.038219947168337445, 0.01976742482345019, 0.03247041800724609, 0.04491459757887891, 0.12755483974303516, 0.12620489432343415, 0.06668448780796357, 0.02554464839132769, 0.02940926494609032, 0.021302778240559355, 0.03404278042060988, 0.010661070118658245, 0.04662048550588744, 0.04626535724050232, 0.03843243719477739, 0.010066006781666406, 0.03223858294742448, 0.06916319658713681, 0.052370364112513404, 0.019228645966255238, 0.04085552306579692, 0.02930331848827856, 0.034405861116413555, 0.005879994481801987, 0.04230075176539166, 0.03686197128679071, 0.03251390192391617, 0.039250061714223454, 0.03575885655092342, 0.04795512996081795, 0.03362522014815893, 0.050659689120948315, 0.0488850180990994, 0.07647727483085223, 0.06465424996401582, 0.020708373082535605, 0.0908217222562858, 0.8730305678078106, 13.702659692083087, 36.231558731624055, 51.75416094916207, 40.91423116411482, 28.447625602994645, 22.518270901271276, 29.681099346705846, 32.76453965050833, 11.338675822530474, 2.488040481294904, 0.10412434701408659, 0.12059832231274673, 0.5652571256671632, 4.388678516660418, 5.304608728204455, 5.664023842130389, 9.577608857836042, 10.686918292726789, 15.347154991967336, 25.78289590563093, 31.926903043474468, 41.619587966373985, 45.60269144603184, 47.281820910317556, 46.506672927311485, 49.81686421803066, 48.88149772371565, 44.08316557747977, 45.89857700892857, 45.79135588237217, 47.443839005061555, 44.00495318004063, 42.88209996904646, 37.10376262664795, 34.22295958655221, 32.84404788698469, 33.70635059901646, 34.152206080300466, 35.51348672594343, 34.439138889312744, 38.18473209653582, 36.70056561061314, 35.857373918805806, 34.21461132594517, 32.47038071496146, 32.84074401855469, 32.632603781563894, 31.81195204598563, 36.99623230525425, 36.16357408251081, 33.616204670497346, 34.60198729378836, 42.67996992383684, 46.71554272515433, 47.991183349064414, 48.68759087153843, 45.507615770612446, 48.59382840565273, 39.02306352342878, 42.064307417188374, 46.95572805404663, 44.75554970332554, 41.39961494718279, 25.79220301764352, 42.74601949964251, 50.98902532032558, 44.012460708618164, 45.13679388591221, 39.81799650192261, 37.389364855630056, 33.329191957201274, 34.343441350119456, 34.62042433874947, 36.95562355858939, 35.07294314248221, 34.980122157505576, 34.126872948237825, 33.94290896824428, 32.555437088012695, 33.671686036246165, 33.27886268070766, 37.38953856059483, 39.474435874394004, 42.43823167255947, 41.94141115461077, 44.300939491816926, 46.05438688823155, 47.376695087977815, 45.81298909868513, 46.69663667678833, 44.468248639787944, 44.57658495221819, 47.94562748500279, 47.84673377445766, 48.15270117350987, 47.69428334917341, 47.356097153254915, 49.15304722104754, 44.898706912994385, 40.26855591365269, 38.96419491086687, 43.56106751305716, 45.63997547967093, 52.70295136315482, 50.97360379355294, 49.03676911762783, 36.38561071668352, 28.325835841042654, 19.581712041582378, 9.499814220837184, 5.4558979357991895, 9.833826286452156, 9.82508545262473, 7.912422691072736, 4.248618466513498, 0.29730494959013803, 0.044343335554003716, 0.24176099577120372, 3.6568073885781422, 17.500170707702637, 40.427124227796284, 35.01068728310721, 40.45381573268345, 45.74171447753906, 45.297658579690115, 53.71753774370466, 29.628741196223668, 9.044096640178136, 1.0068873422486442, 0.03585515424077, 0.11368508863129786, 0.019158390450424383, 0.03966013774541872, 0.07505728424127613, 0.06510286339159523, 0.02254206477664411, 0.03178465998332415, 0.05111737795440214, 0.007083542154370142, 0.05021048876057778, 0.03298574160518391, 0.023841425410604904, 0.01665020441370351, 0.041772820986807346, 0.07271179224231414, 0.027827981493568847, 0.02330613083073071, 0.019513856286981275, 0.02143517229706049, 0.06653974950313568, 0.04171218370486583, 0.12178049316363675, 0.12388883717358112, 0.18567512317427567, 0.16076002296592506, 0.14181007338421686, 0.12133829189198357, 0.10569159327340977, 0.1288974976965359, 0.07770683456744466, 0.1876157468983105, 0.13520418213946478, 0.13613794132002763, 0.19740712935371058, 0.09091794530728034, 0.08921395388564893, 0.1157357639500073, 0.2282602930707591, 0.1880316345819405, 0.11425442700939518, 0.13714650220104627, 0.19465067583535398, 0.1195111870765686, 0.10355102563542978, 0.15974551811814308, 1.225746478353228, 16.054363489151, 42.58740602220808, 57.119507789611816, 47.68172100612095, 36.66625540597098, 25.27212166786194, 34.725053787231445, 37.93362767355782, 14.114871995789663, 4.3673332163265774, 0.2605706921645573, 0.7092582157679966, 2.249573745897838, 8.103528550692968, 7.395009449550083, 12.856403844697134, 19.739993742534093, 19.197976929800852, 26.480448143822805, 24.4206668308803, 35.366768564496724, 42.27675553730556, 48.48950467790876, 49.30246475764683, 51.112098761967246, 51.21395935331072, 49.49016686848232, 44.18816328048706, 46.13142851420811, 45.47091538565499, 49.48375020708357, 46.25695466995239, 46.36638184956142, 39.731401102883474, 36.673359939030235, 34.03979812349592, 35.77482237134661, 35.62816326958792, 39.31859820229666, 35.871152196611675, 39.729987144470215, 39.7107823235648, 39.37603896004813, 36.93329899651663, 35.08499479293823, 34.037501743861604, 33.84841694150652, 33.92760903494698, 38.172055108206614, 37.613941056387766, 35.53942435128348, 37.682954038892476, 44.35033770969936, 48.53757231576102, 50.09814466748919, 50.20029360907418, 48.227911949157715, 49.85526691164289, 40.03728859765189, 42.6607894216265, 48.26141963686262, 43.388554164341514, 44.189556394304546, 31.233743803841726, 44.37231138774327, 52.8848934173584, 45.5516881942749, 46.41325092315674, 41.30231237411499, 38.5020945412772, 34.630467959812705, 35.376311915261404, 36.687106949942454, 38.28705126898629, 35.71927499771118, 36.668739386967246, 35.55876118796212, 35.015432902744834, 35.00459023884365, 34.34991707120623, 35.18879393168858, 38.81092459814889, 40.62606157575335, 44.38721179962158, 42.562156268528526, 46.39777381079537, 48.99295725141253, 50.21258497238159, 46.784732886723106, 47.22451564243862, 46.76636184964861, 46.511356013161794, 50.72580671310425, 51.29735858099801, 50.131364004952566, 48.249093532562256, 48.31252016339983, 50.44670452390398, 47.80647938592093, 43.041029589516775, 40.733661379132954, 45.16666071755545, 48.565465859004426, 53.63479512078421, 51.82089492252895, 50.96862540926252, 38.96687344142369, 28.267059292112076, 22.103046553475515, 15.864563022341047, 10.313925964491707, 12.394702996526446, 12.745063304901123, 9.829382044928414, 11.702920368739537, 2.729103454521724, 0.44050482554095133, 0.5179680117538997, 5.087279498577118, 18.87711606706892, 45.60243088858468, 38.276159967694966, 46.96335717609951, 51.154889242989675, 54.3645053591047, 60.31618635995047, 35.101719106946675, 12.710253698485237, 1.2740984495197023, 0.11185964622667857, 0.20744366651134832, 0.13586557736354216, 0.12146333232522011, 0.12757974197821959, 0.15876481788499014, 0.2351380597267832, 0.10739485866257123, 0.132859789367233, 0.14526916348508426, 0.11870921296732766, 0.12383257304983479, 0.13596711334373268, 0.28908238080995424, 0.1309773703770978, 0.2145876767379897, 0.0898513493261167, 0.1203709723693984, 0.12921347788402013, 0.17807675232844694, 0.15349496209195682, 0.09146709048322268], [0.03742875498054283, 0.0660536741571767, 0.01264827951256718, 0.01955809168118451, 0.03876087189252887, 0.008467402874625154, 0.02359094251213329, 0.12688489497772285, 0.03232259576075843, 0.03581743447908333, 0.08410379809460469, 0.020744635690269724, 0.02205911578078355, 0.01203773879179997, 0.026083142263814807, 0.04884947982749768, 0.02386314870922693, 0.07704640964844398, 0.014068762040031808, 0.06293873701776777, 0.028998639301529953, 0.0291993262113205, 0.057468984808240614, 0.019155974865757992, 0.5006615146994591, 7.896981188229152, 31.42909935542515, 42.38182619639805, 39.59806169782366, 21.616545847484044, 24.016401529312134, 34.59956932067871, 28.525692088263376, 16.179509231022426, 2.8894044756889343, 0.17369879010532582, 0.2457258387335709, 0.633406685931342, 2.902170922074999, 3.733816010611398, 2.385246225765773, 4.030333859579904, 8.393270168985639, 12.498847808156695, 23.93164219175066, 26.577102797372, 36.009574208940776, 42.50831815174648, 44.28179373059954, 45.22231926236834, 45.278339113507954, 43.51618562425886, 43.80146128790719, 47.44989088603428, 44.37873152324131, 45.226057393210276, 42.067309038979666, 39.216616017477854, 36.42896400179182, 33.78784949438912, 30.5663971219744, 33.151686327798025, 32.89803539003645, 36.83943578175136, 39.89743873051235, 42.91722658702305, 42.85192394256592, 44.94226516996111, 41.20355762754168, 38.55856602532523, 31.395223413194927, 32.83338935034615, 33.09524611064366, 32.25817925589425, 29.657072475978307, 32.000560896737234, 33.45030600684029, 43.01634611402239, 45.12452336720058, 45.623772280556814, 49.283791473933626, 48.1130165372576, 46.22493042264666, 44.79674557277134, 43.7174506187439, 46.95248671940395, 42.371042592184885, 41.99776451928275, 27.2211434841156, 38.885162625994, 43.79280730656215, 37.810106073107036, 39.824486119406565, 31.7544070652553, 33.38427380153111, 31.80124487195696, 33.54078197479248, 31.919249602726527, 33.22840486254011, 33.051399503435405, 33.49376351492745, 31.95157262257167, 34.17601408277239, 34.206061567579, 33.946108613695415, 33.88522154944283, 33.08377810886928, 33.11153268814087, 32.54772458757673, 33.89284372329712, 36.217530318668906, 36.669750349862234, 38.19244459697178, 39.601685183388845, 39.048559938158306, 39.68537623541695, 40.25468730926514, 40.84277588980538, 42.67288276127407, 45.68643460954939, 48.81111594608852, 44.9029974256243, 49.09362622669765, 47.60123307364327, 42.44175440924508, 36.53537218911307, 40.30845594406128, 45.05311325618199, 51.040452412196565, 48.34571170806885, 43.44238880702427, 31.774626323154994, 24.507413353238785, 22.96700988497053, 4.464967131614685, 2.1453540240015303, 7.946516633033752, 12.222418938364301, 7.554604360035487, 3.2592631663594926, 0.23256288362400873, 0.11704856636268751, 0.18167996326727526, 3.1597428151539395, 16.913329328809464, 37.13092660903931, 45.973374366760254, 44.136079583849224, 48.192684582301546, 44.55402415139334, 45.93689979825701, 25.282700300216675, 7.703917673655918, 0.2582575934273856, 0.05763682044510331, 0.10040078431900058, 0.009503448664742922, 0.031212814418332915, 0.031586198668394766, 0.0363944878003427, 0.0044451872319249165, 0.07961226268006222, 0.01855787169188261, 0.02369672612154058, 0.03290283141125526, 0.012182474552121545, 0.02071457149993096, 0.011031726657945131, 0.012375108099409511, 0.042319923772343566, 0.05259534936132176, 0.07287674410534756, 0.028863861890775815, 0.03287894697859883, 0.04113573767244816, 0.042430277315101454, 0.03192730500761952, 0.03375800945130842, 0.05112775954018746, 0.008845775205242847, 0.02172405518857496, 0.056000109163245985, 0.018592042715421746, 0.06888248664992196, 0.03699686744117311, 0.03786269169566887, 0.022776435861097913, 0.06262082979083061, 0.01719996196750019, 0.025457448159743632, 0.06891874756131854, 0.0786457641848496, 0.002135292028209993, 0.05522987352950232, 0.07192866105054106, 0.047187896844531806, 0.0810157987954361, 0.03567692684009671, 0.01695865286248071, 0.023854166601917574, 0.7068280290280069, 10.356313449995858, 35.95526361465454, 49.43727370670864, 44.98396825790405, 27.877838577542985, 23.517062289374216, 37.219001974378315, 33.30922630855015, 17.927794115883962, 3.00705332841192, 0.07837017718702555, 0.1340026594698429, 0.6958304420113564, 2.4100321871893744, 3.5756057458264485, 7.587947028023856, 9.073849695069448, 10.012952583176748, 12.09222446169172, 23.75722677367074, 29.624607018062047, 39.12970100130354, 45.91520752225603, 45.932960169655935, 47.99710668836321, 46.06617798124041, 45.19786507742745, 45.64238650458199, 47.76627016067505, 44.96572923660278, 48.13288491112845, 44.61724233627319, 42.127727099827354, 38.62533473968506, 34.701798166547505, 33.378096852983745, 34.40092727116176, 33.450743743351524, 38.29923493521554, 40.33982706069946, 45.30980750492641, 44.520558152879985, 45.45765127454485, 42.706407819475444, 39.042077268872944, 33.81983552660261, 33.69875274385725, 34.11393540246146, 33.11391939435686, 32.22093343734741, 33.48908390317644, 34.62362745829991, 44.21044267926897, 47.887561389378135, 48.299499239240376, 49.872196197509766, 47.955889974321636, 46.32497753415789, 44.1777583530971, 43.23007270268032, 45.957588059561594, 40.97298860549927, 43.98140573501587, 30.991508756365093, 40.647635732378276, 47.445947783333914, 39.50919771194458, 42.29303864070347, 34.14255850655692, 35.01699277332851, 33.190471172332764, 36.338293484279085, 33.12437295913696, 33.730964592524934, 34.62740380423409, 35.04265941892351, 33.878742354256765, 35.58264214651925, 35.80455371311733, 35.35553332737514, 35.01028776168823, 34.45913927895682, 34.66546951021467, 34.990447180611746, 35.536301136016846, 37.7381956917899, 39.64968681335449, 40.82488775253296, 41.50000946862357, 42.793249879564556, 42.2617370060512, 42.28672967638288, 43.75066648210798, 46.138473987579346, 48.025733266557964, 49.639626094273154, 45.59705993107387, 50.351503780909944, 49.007517201559885, 43.87528242383684, 39.338282448904856, 41.910255432128906, 47.325869015284944, 52.09542172295706, 50.45731789725167, 46.3451828956604, 36.202230385371614, 28.04447375025068, 19.129651818956646, 6.511301508971623, 7.635803614343915, 10.142057929720197, 11.106835280145917, 7.339971899986267, 5.522807351180485, 1.0553593869720186, 0.07910260145685502, 0.3142821400293282, 3.7899240170206343, 18.807581969669886, 38.77861547470093, 41.82136017935616, 45.634132044655935, 52.09775979178292, 48.38242598942348, 53.34336335318429, 30.420867102486746, 9.065240877015249, 0.3193660500858511, 0.012771945912390947, 0.09213738808674471, 0.06446400231548718, 0.05118384385215385, 0.04595122266826885, 0.02679409090030406, 0.0632815600505897, 0.010451485918435668, 0.005803185589944145, 0.02178324549458921, 0.02215262469170349, 0.02772563636036856, 0.04255507008305617, 0.053248839652431865, 0.03205028608707445, 0.024649263758744513, 0.0636752460684095, 0.05321585267250027, 0.022668430049504553, 0.045417863609535356, 0.03958943100380046, 0.0409625653576638, 0.08852444695574896, 0.1388793449316706, 0.11379946927939143, 0.13727231616420404, 0.11385187932423182, 0.10862581618130207, 0.10529104048120123, 0.18297470307775907, 0.11050024202891759, 0.11881059966981411, 0.11148136973913227, 0.15376276629311697, 0.11023548444999115, 0.12101108873529093, 0.14830461703240871, 0.15523668006062508, 0.08900965377688408, 0.1152474901505879, 0.24619676917791367, 0.14676491250949247, 0.21185921957450254, 0.1448496524244547, 0.08688423104052033, 0.15760848564761026, 0.8027505704334804, 12.288947939872742, 42.250689370291575, 54.704220158713206, 50.94065890993391, 33.110945565359934, 33.61607265472412, 45.30347422191075, 36.93377842221941, 20.639759404318674, 4.1940008487020215, 0.28798022280846325, 0.45807557127305437, 2.3103917624269212, 5.984276303223201, 10.29855307510921, 8.63943268571581, 12.83858779498509, 14.916660240718297, 18.10680750438145, 30.15966694695609, 31.209935801369802, 41.289110796792166, 48.81437465122768, 47.20940678460257, 47.96415833064488, 46.118699414389475, 46.02791772569929, 48.38169642857143, 51.1986003603254, 45.88024418694632, 48.29845700945173, 47.416793142046245, 43.11021975108555, 40.52334983008248, 36.92518697466169, 34.97252777644566, 37.52777991976057, 35.3601712499346, 40.80209418705532, 43.948797839028494, 47.81690515790667, 48.000403608594624, 49.128315108163015, 45.1132811818804, 42.58221919195992, 35.336182594299316, 36.509180954524446, 36.21599129268101, 34.85879966190883, 33.946581091199604, 35.6895922933306, 36.23472711018154, 45.89513765062605, 49.225034032549175, 48.30210828781128, 51.87697383335659, 49.046197823115754, 46.972084113529746, 42.77713005883353, 43.540344510759624, 46.52340071541922, 42.71778896876744, 44.154381138937815, 33.84145484651838, 43.2500661441258, 47.552967412131174, 41.45682988848005, 44.70672123772757, 35.02503183909825, 35.78327832903181, 35.50785173688616, 37.777289731161936, 34.984315395355225, 35.56346164430891, 36.454137325286865, 37.556510720934185, 36.208681787763325, 37.975289072309224, 36.864682061331614, 37.375051566532676, 36.70692321232387, 36.641530241285054, 36.85312025887625, 36.56536756243025, 37.291770458221436, 38.830459458487375, 39.78935950142996, 40.89268480028425, 43.87597376959664, 42.899095262799946, 44.392037323543, 44.39092908586775, 45.82270268031529, 48.82951477595738, 50.18510137285505, 50.962924412318635, 45.11322907039097, 52.822609765189036, 51.67148086002895, 46.70661081586565, 41.55473000662667, 44.326157978602815, 49.87797015053885, 54.74308490753174, 51.1861491884504, 46.48090205873762, 35.99454525538853, 27.388244186128887, 27.921909264155797, 8.650088616779872, 5.394060271126883, 12.899354134287153, 20.788622822080338, 13.449652331215994, 5.7184126036507745, 1.5342786312103271, 0.2766963211553437, 0.46580712497234344, 4.283273475510733, 21.214439698628016, 45.50838007245745, 57.15167447498867, 55.354040009634836, 59.07008252825056, 55.75315843309675, 60.10843522208077, 36.44902345112392, 11.263762950897217, 0.5723005905747414, 0.10384667691375528, 0.22187322936952114, 0.19959754895951065, 0.09761685691773891, 0.09928092333887305, 0.13292347666408333, 0.18972200102039746, 0.16242109026227677, 0.04811267222144774, 0.09620056434401444, 0.11330714462591068, 0.11744207596140248, 0.1420879741864545, 0.13958495349756309, 0.11729575666998114, 0.12845644993441446, 0.15187619466866764, 0.20779783464968204, 0.061492283562464375, 0.13304391662989343, 0.11113518117261784, 0.1254776676318475], [0.027844217140227556, 0.02752210129983723, 0.0362146556643503, 0.05373662829931293, 0.1465262853141342, 0.0377386249601841, 0.10704919935337134, 0.055295226629823446, 0.03712996547775609, 0.01330756364456777, 0.05408745126000472, 0.031111739841955047, 0.07493230487619128, 0.01630533390146281, 0.04916710206972701, 0.04603463837078639, 0.024891205597668886, 0.03573398145713976, 0.03230978162693126, 0.05291687317990831, 0.06476723282997097, 0.02616720087826252, 0.020176345648776208, 0.043180211181087155, 0.34809250863535063, 7.605443460600717, 27.432538952146256, 47.777380330221995, 37.5659567969186, 30.260353292737687, 19.663502761295863, 24.358885186059133, 31.613344737461635, 16.195394550051006, 5.0734356471470425, 0.32105959206819534, 0.07820014309670244, 0.0467377295717597, 2.5903611736638203, 3.901478213923318, 8.037084664617266, 10.651751722608294, 7.767345173018319, 10.073427966662816, 18.924699068069458, 26.448705298560007, 36.26815489360264, 42.80272374834333, 44.720402240753174, 44.69341196332659, 46.70562417166573, 44.77229833602905, 44.058242389133994, 44.07651267732893, 45.74328824451992, 45.7593594278608, 44.97297968183245, 40.9894871030535, 38.19869450160435, 34.826813629695344, 30.786978108542307, 32.665277685437886, 33.169987882886616, 39.548031193869456, 40.79538222721645, 46.539656026022776, 44.30461161477225, 45.27574743543352, 46.42120313644409, 43.805946350097656, 39.07320172446114, 34.15414810180664, 33.05837549482073, 32.75372130530221, 30.515161105564662, 31.97497762952532, 30.40819011415754, 38.1493101801191, 44.53299542835781, 45.31282649721418, 46.61744805744716, 47.3959242275783, 48.41064262390137, 52.4636241367885, 48.523078373500276, 50.74898590360369, 45.5261744090489, 48.32183769771031, 31.391221250806534, 40.15023503984724, 48.23201833452497, 36.485289573669434, 38.71997267859322, 32.202208042144775, 35.08368853160313, 32.30358573368618, 34.078416211264475, 32.681053570338655, 33.86279623849051, 33.457539081573486, 33.54204307283674, 31.088022708892822, 33.38732058661324, 33.73377513885498, 33.14507859093802, 36.16027021408081, 32.83283349445888, 32.37551695959908, 32.968118395124165, 33.317470346178325, 32.06685365949358, 32.620239462171284, 34.21554238455636, 33.74473592213222, 32.561586243765696, 35.00405522755214, 40.0222144808088, 38.88560731070382, 41.77159023284912, 43.37705142157418, 45.922371115003315, 45.77583360671997, 48.39638144629342, 48.49968726294381, 45.63698080607823, 39.50677626473563, 40.08566543034145, 44.95834330150059, 50.76254531315395, 51.10268742697579, 41.61487708772932, 32.33950792040144, 24.787113087517874, 11.69121960231236, 5.423097661563328, 11.230953557150704, 12.128325564520699, 9.100979804992676, 7.350926603589739, 4.70579560313906, 0.1057391246514661, 0.17505275245223725, 0.2637474574148655, 4.231464666979654, 17.042744738715037, 40.743058817727224, 38.73902463912964, 46.71548366546631, 41.477208954947336, 49.16333750316075, 51.807161808013916, 27.684270450047084, 8.222868204116821, 0.09788111238075153, 0.029082065182072774, 0.0414464727842382, 0.06845657021871634, 0.05736168806574174, 0.018228290269949605, 0.046563122155410905, 0.01463255678702678, 0.025847164747704352, 0.019467870272429924, 0.037835319593016586, 0.06122994835355452, 0.07420347684196063, 0.03392276793186154, 0.046247111433850865, 0.03991454766531076, 0.03011968432526503, 0.030719136087489978, 0.011637353088839777, 0.06033445854804345, 0.038206196656184535, 0.02945486589201859, 0.032698646653443575, 0.05700658354908228, 0.029783775564283133, 0.03761584744123476, 0.03136353740202529, 0.051029260004205365, 0.06522360191281353, 0.061184880057615895, 0.039853306487202644, 0.022241763837103332, 0.02713605049731476, 0.02054495470864432, 0.006003094728969569, 0.06749307763363634, 0.026320597289928367, 0.02805904302346919, 0.05569126037880778, 0.05341672617942095, 0.041498787834175994, 0.011648760958840805, 0.05424132264618363, 0.03081080616850938, 0.032147482835820744, 0.0016124831288055117, 0.011327199820828224, 0.43107495297278675, 8.78156851019178, 32.48463841847011, 53.708564145224436, 42.31875392368862, 33.070607798440115, 25.467192343303136, 27.540776252746582, 33.92458656855992, 18.990135465349468, 4.846215656825474, 0.671080795781953, 0.023452556991417493, 0.5509590900370053, 2.200295167309897, 4.975435648645673, 6.096970438957214, 6.894491621426173, 9.790697949273245, 7.916302391460963, 25.57905834061759, 31.317427907671245, 37.44186544418335, 46.38427693503243, 46.702643394470215, 44.36143398284912, 46.345710958753315, 45.50433274677822, 46.67527791431972, 45.1991400718689, 45.91721555164882, 47.44247368403843, 45.882787227630615, 42.75349923542568, 40.27595574515206, 35.53922285352434, 32.36081109728132, 34.23904466629028, 34.40278591428484, 40.88728952407837, 44.39581714357649, 47.34799555369786, 45.14923810958862, 47.81569617135184, 48.92431947163173, 45.21063586643764, 40.52075120380947, 35.560394014631, 34.20384161812918, 35.57810149874006, 32.36771413258144, 33.921334811619346, 33.70309884207589, 39.64300264630999, 46.393830708095, 46.58615337099348, 46.90714277539934, 48.02690403802054, 49.481029987335205, 53.6138254574367, 48.68765687942505, 50.138256617954795, 46.74207442147391, 48.11844655445644, 32.89172295161656, 42.1540572983878, 49.40258482524327, 38.780036381312776, 40.17867749077933, 34.257836069379536, 36.13120589937483, 33.98580019814627, 35.625849519457134, 33.30075645446777, 34.876034668513704, 35.446457454136436, 35.29902015413557, 32.72996194022042, 34.1212032181876, 35.88586848122733, 35.08422006879534, 36.57812098094395, 35.22809294291905, 34.12323556627546, 34.75094624928066, 34.57160976954869, 33.40838405064174, 34.29738868985857, 34.964662415640696, 35.76970154898507, 35.93110472815377, 36.5893805367606, 40.60903154100691, 40.43551417759487, 43.863039697919575, 44.112181254795615, 48.241016251700266, 47.58411618641445, 49.88125317437308, 50.652398994990754, 47.53369658333914, 41.290893009730745, 42.132969515664236, 47.602018220084055, 52.41087688718523, 51.7044917515346, 41.945635659354075, 32.53746904645647, 27.189185244696482, 16.372535399028234, 7.540319732257298, 8.096701077052526, 11.868409957204547, 5.725844570568629, 6.037760496139526, 7.247037138257708, 1.1640329041651316, 0.1190726634647165, 0.268002414809806, 4.975355310099466, 18.41774981362479, 42.94598865509033, 46.639692715236116, 51.232837608882356, 48.192153045109336, 53.898802348545615, 54.92494705745152, 32.26762880597796, 9.306022882461548, 0.22510643516268047, 0.06271885774497475, 0.04162577905559114, 0.04377442126029304, 0.05035182421228715, 0.013719222358694034, 0.05020722500713808, 0.048095138876565864, 0.04867476384554591, 0.03177310113928147, 0.020678990819890584, 0.05750567998204913, 0.040639009326696396, 0.009192657573813838, 0.04486484060596142, 0.05467155116743275, 0.009239575725847056, 0.018950466964659945, 0.03573402216924088, 0.019852219648393135, 0.013963023383569504, 0.06722756688083921, 0.03016947183225836, 0.1953985028501068, 0.10382051938878638, 0.1298531192753996, 0.11771468419049468, 0.2033053764275142, 0.1403017986033644, 0.28144891613296097, 0.15323424179639134, 0.1257743774248021, 0.08203478197434119, 0.0785449610224792, 0.10321698963109936, 0.1613111426787717, 0.133081887449537, 0.17235770635306835, 0.14447533179606709, 0.1731876361050776, 0.20210701573107923, 0.10715228239340441, 0.1333704548222678, 0.1156718052391495, 0.13965280699942792, 0.16004894540778228, 0.09440501819231681, 0.6666031703352928, 11.494147845676967, 37.8493321282523, 62.70961843218122, 49.105778626033235, 42.05344043459211, 29.886408192770823, 33.591927664620535, 38.30052730015346, 21.32035803794861, 6.205130440848214, 0.9869905241898128, 0.16176882811955043, 0.6607502358300346, 6.116824916430882, 11.284630128315516, 14.451489635876246, 18.16202483858381, 12.56270088468279, 12.260663560458593, 26.24983048439026, 31.217054230826243, 40.39581217084612, 47.05615036828177, 47.78731972830636, 45.07472562789917, 48.48747927801949, 47.67659323556082, 46.912701334272114, 46.86424807139805, 47.9056510244097, 48.22194692066738, 48.179726191929404, 45.282907554081504, 42.93899876730782, 37.25265557425362, 34.042459283556255, 35.49963896615164, 36.33869647979736, 43.13690778187343, 46.05187164034162, 50.2810594694955, 46.84872579574585, 47.95724834714617, 51.53625849315098, 47.069574287959504, 43.96554299763271, 37.37619454520089, 37.30658401761736, 37.20183644975935, 34.37181084496634, 35.396885531289236, 34.91045951843262, 40.7998811858041, 49.41374363218035, 48.87125955309187, 49.8098361151559, 50.108323778424946, 52.591422353472026, 53.14886590412685, 51.10361153738839, 50.62113210133144, 48.8059847014291, 47.280233246939524, 35.438727583204, 45.49725948061262, 52.44745915276663, 41.794703415461946, 42.215316091264995, 36.0449857030596, 38.439637184143066, 35.513309546879356, 37.637530190604075, 35.77099738802229, 36.8126574243818, 37.07321834564209, 36.87574011938912, 33.99954373495919, 36.95765243257795, 37.90555347715105, 36.632629598890034, 38.872416155678884, 36.25548832757132, 36.233667509896414, 36.024415561131065, 37.124690600803916, 35.387168475559776, 34.63897950308663, 36.57386520930699, 37.20654385430472, 37.54653310775757, 38.12026671000889, 44.2134165082659, 41.994314738682334, 47.4172864641462, 47.279100690569194, 49.22915778841291, 47.87089613505772, 50.28227193014962, 52.44229664121355, 52.481487955365864, 43.45619487762451, 45.43731737136841, 50.00578226361956, 55.8332051549639, 54.23448371887207, 44.128731863839285, 36.13981124332973, 29.184730461665563, 15.745437894548688, 10.632870861462184, 18.542966774531774, 22.52773608480181, 16.984902722494944, 14.954065867832728, 9.454422507967267, 1.3858450246708733, 0.4041904998677117, 0.9211792498826981, 6.085871994495392, 22.799610410417827, 49.46101222719465, 49.99255289350237, 55.4383807182312, 52.02126359939575, 60.73283508845738, 62.659772055489675, 37.06793424061367, 11.223519853183202, 0.4337982396994318, 0.19987863887633595, 0.17587444478912012, 0.1778659179274525, 0.14177313393780164, 0.10117345928613629, 0.1404208814991372, 0.12009712920657226, 0.10215367775942598, 0.19083968390311512, 0.1845598965883255, 0.13381976714091642, 0.11440746379750115, 0.11969680711627007, 0.16690886659281595, 0.10135641268321446, 0.11951343981283051, 0.17777982540428638, 0.12610607248331818, 0.20618782032813343, 0.09357875931475844, 0.11782913947744028, 0.09681939506637198], [0.03129430986674769, 0.020964435235198055, 0.048922184854745865, 0.056889610897217474, 0.01860872789153031, 0.016013636785958494, 0.05118738580495119, 0.02388927061110735, 0.043787181111318726, 0.035132673901638815, 0.026127974768834453, 0.008911501499824226, 0.04477470401408417, 0.07594670794372048, 0.019842346963871802, 0.030313450177865367, 0.0704273208975792, 0.012111154584480184, 0.06888525507279805, 0.05706223699131182, 0.039780028097863705, 0.06992173088448388, 0.0338692213408649, 0.05141647279794727, 0.2506666050425598, 6.827586982931409, 26.325703075953893, 42.124513557979036, 44.473744664873394, 39.93354157039097, 29.268734182630265, 31.448696749550955, 28.867461817605154, 22.48795591081892, 6.549174402441297, 0.8627237294401441, 0.1332422795572451, 0.37411215528845787, 0.9450432722057615, 2.122944780758449, 4.182409082140241, 5.118842559201377, 9.74889498097556, 5.289800379957471, 16.901644195829117, 22.989388295582362, 31.71804714202881, 40.18720293045044, 46.066004276275635, 45.94334077835083, 44.20374461582729, 43.80042948041643, 46.06175545283726, 46.95819813864571, 45.608045033046174, 46.249332496098106, 43.632984842572895, 42.35510342461722, 39.93642507280622, 37.251519543784006, 32.27294765199934, 32.80408532278878, 34.099611691066194, 39.42952619280134, 41.2876238822937, 46.01331956045968, 48.40835666656494, 46.626880237034385, 45.45821755273001, 45.13497345788138, 41.83018786566598, 38.651862961905344, 34.35786928449358, 33.39994198935372, 31.33773054395403, 32.99604320526123, 33.010589259011404, 33.86029141289847, 38.00521843773978, 45.79505927222115, 43.78814853940691, 47.40779522487095, 46.88915041514805, 45.81345810209002, 43.09880386080061, 47.711136204855784, 44.18558897290911, 49.75206879207066, 31.706210885729107, 37.37950536182949, 48.250952175685335, 39.52149254935128, 39.742865630558555, 35.377479212624685, 35.87165594100952, 32.9726243019104, 36.52216713769095, 34.16182586124965, 34.678577286856516, 32.53379692350115, 32.14896747044155, 32.02409097126552, 32.00432334627424, 32.443366118839805, 33.80433756964547, 34.0830854007176, 34.048591068812776, 33.51633126395089, 32.54787744794573, 33.40597997392927, 33.332749434879844, 31.740969249180385, 32.97571972438267, 32.166122572762625, 32.21537140437535, 33.14497784205845, 35.34355115890503, 37.782733644757954, 41.04425975254604, 43.05812215805054, 43.52508626665388, 47.33398103713989, 49.21059567587716, 50.980736119406565, 46.952910559517996, 43.97113282339913, 41.42832142966134, 43.55398382459368, 45.74726608821324, 47.20986883980887, 36.52053083692278, 30.91975818361555, 25.85265408243452, 14.32770834650312, 4.124078520706721, 8.502807651247297, 6.318090779440744, 4.944570447717394, 2.356820059674127, 9.511824182101659, 1.7442486328738076, 0.14704263689262526, 0.3380891111280237, 4.3221912043435236, 17.74963014466422, 35.97398553575788, 34.97824614388602, 40.28787885393415, 38.201383454459055, 44.65879256384713, 44.32961470740182, 24.55285804612296, 5.474945553711482, 0.2546686317239489, 0.06401158909180335, 0.024957839432837706, 0.002296874964875834, 0.023206620277570825, 0.06369326795850482, 0.08737183987562146, 0.037362187302538326, 0.0429869542297508, 0.00917037109112633, 0.009463960471163903, 0.05826941864298923, 0.06327465934945004, 0.057892132816570144, 0.04126249819195696, 0.032452063634991646, 0.04188488783048732, 0.04781786911189556, 0.030250366777181625, 0.008352365743901049, 0.03281752938138587, 0.0477329538469868, 0.018999650575486676, 0.04921820254198142, 0.02936945529654622, 0.04212477710098028, 0.034619277343153954, 0.014956497886617268, 0.0693270152966891, 0.033765819389373064, 0.027269102732783983, 0.030713195513401712, 0.047374392194407325, 0.03384855316419687, 0.04210915722485099, 0.03714294585266283, 0.08213306777179241, 0.02380814666061529, 0.03523401649934905, 0.023713155150679604, 0.020434309395828416, 0.011960295045615306, 0.03759289260155388, 0.07545166915016514, 0.07528487845723118, 0.035928232462278435, 0.016705255656104003, 0.3012638757271426, 8.306707773889814, 30.490564482552664, 48.33556733812605, 48.10005119868687, 43.609701429094585, 29.388691357203893, 31.435693195887975, 30.81066451753889, 23.127495901925222, 7.250542070184435, 0.7241340375372342, 0.21519389349435056, 0.27743595146707123, 1.2596383797270911, 3.116060793399811, 7.313669494220188, 8.778024060385567, 7.365027104105268, 10.176106708390371, 19.48071128981454, 28.727686643600464, 33.042662143707275, 40.86876910073416, 45.41553824288504, 47.66249534061977, 46.035449572971885, 45.687119007110596, 47.62721586227417, 47.78971338272095, 45.98662110737392, 47.26364442280361, 46.30566154207502, 44.88056516647339, 41.8264080456325, 36.72875792639596, 33.46668291091919, 34.318160329546245, 35.356752736227854, 41.278580801827566, 42.67795842034476, 48.73506791251046, 48.924652985164094, 47.40472412109375, 46.16535309382847, 46.290410246167866, 44.40388052804129, 40.693212441035676, 35.24301419939314, 35.34313774108887, 32.605009010859895, 33.99194935389927, 33.18346391405378, 36.16349417822701, 41.07620062146868, 47.11659969602312, 45.98136132104056, 49.07033239092146, 48.83313826152256, 48.01723909378052, 46.07467562811715, 49.243634360177175, 45.957063470567974, 51.15088708060128, 33.5346953528268, 39.404766287122456, 49.47765316282, 41.89651536941528, 40.5788311958313, 37.095595019204275, 36.93130138942173, 35.71415070125035, 36.90590919767107, 36.19815526689802, 36.70211853299822, 35.399209703717915, 34.61585589817592, 33.567112173352925, 33.849750995635986, 33.40247460774013, 34.706651483263286, 36.119008336748394, 34.06236239842006, 35.56072405406407, 34.19667107718331, 35.44700983592442, 34.77035256794521, 32.71585014888218, 34.331358432769775, 34.0370431627546, 33.16421045575823, 34.19344016483852, 37.08676038469587, 39.456492151532856, 43.34089994430542, 44.714614391326904, 46.840995924813406, 48.426307337624685, 48.1389923776899, 52.57553877149309, 49.86203793116978, 43.83328403745379, 42.425554684230256, 46.50163548333304, 49.16414696829659, 50.9883965083531, 42.209166935511995, 31.87449278150286, 22.02650693484715, 11.009793264525277, 8.05249229499272, 9.937827791486468, 14.104235172271729, 5.510182474340711, 5.672021218708583, 3.7744312712124417, 0.721049363059657, 0.19865142687090806, 0.22834415999906404, 5.407301800591605, 19.905451195580618, 44.268269062042236, 35.86770241601126, 46.681746687207905, 42.84703241075788, 50.73310579572405, 52.549507345472065, 30.381967612675258, 6.952923366001674, 0.31381647501673016, 0.035606315093381066, 0.03824668484074729, 0.00880773738026619, 0.12543377998684133, 0.029300492389925888, 0.01299346554359155, 0.05774983723780938, 0.018162899850202457, 0.05977115234626191, 0.03313420167458909, 0.043600777363670726, 0.013552461351667131, 0.015256123683814491, 0.018931747879832983, 0.04283420581902776, 0.08129152150026389, 0.007417987400133694, 0.1135719089901873, 0.02827962118733142, 0.017463603356320943, 0.020878785456131612, 0.03306254159126963, 0.2691091868494238, 0.09941551754517214, 0.23260153297867092, 0.17459987103939056, 0.12034288101962634, 0.17937348703188555, 0.1905577661735671, 0.0796970184892416, 0.12727034358041628, 0.09843104465731553, 0.1068825511527913, 0.13035040401986667, 0.11513576257441725, 0.10203265425349985, 0.1404592322983912, 0.17191622432853493, 0.13768979161977768, 0.15290948136576585, 0.13743348180183343, 0.09390613889055592, 0.19318312672632082, 0.13775575879429067, 0.18971457784729345, 0.2334432149572032, 0.5138980501464435, 9.833161864961896, 35.573592117854524, 53.62353209086827, 55.61432300295149, 49.660842418670654, 39.75321497235979, 42.784846033368794, 38.10212843758719, 28.705396822520665, 9.356067282812935, 1.352741526705878, 0.4507632707910878, 0.6884248022522245, 3.1157622379916052, 6.507791365895953, 10.771984219551086, 10.416270324162074, 19.55070744241987, 10.904009546552386, 19.909003462110245, 27.391905886786326, 34.26253999982561, 42.51877171652657, 45.87160757609776, 48.51735653196062, 46.976416315351216, 47.74909768785749, 48.24078001294817, 47.25295809337071, 45.586179052080425, 47.36650208064488, 47.738824776240754, 47.40970597948347, 45.34959636415754, 41.07970598765782, 35.040543692452566, 36.38529109954834, 36.3442828314645, 43.74352025985718, 45.17280292510986, 50.10901859828404, 50.942326477595735, 49.02212231499808, 47.58894518443516, 48.42059939248221, 46.48359101159232, 42.4727155821664, 37.56219434738159, 38.03709329877581, 34.44006299972534, 36.612855025700156, 35.87865972518921, 37.54646362577166, 42.39384657996041, 50.26270580291748, 46.905641964503694, 51.89844029290335, 52.42946679251534, 48.58464636121477, 48.47634826387678, 51.063193866184776, 47.90576219558716, 52.387402398245676, 37.07347542898995, 41.8243340083531, 51.1848464012146, 44.53292942047119, 42.749490124838694, 39.287824630737305, 38.8840126991272, 37.280166966574534, 40.12229980741228, 38.229989188058035, 38.395130498068674, 36.384756088256836, 35.15774590628487, 35.821955476488384, 35.05123002188546, 35.813707964760916, 37.19485698427473, 37.72878088269915, 36.1575152533395, 38.71221848896572, 35.91460623059954, 37.87872648239136, 37.38442121233259, 34.58056599753243, 35.321164063044954, 35.10547808238438, 36.12573071888515, 36.81497812271118, 38.2671412059239, 41.63114629473005, 44.86396939413888, 48.71477917262486, 48.841886043548584, 49.68808283124651, 48.47549016135079, 53.240606444222585, 51.19662707192557, 47.370504243033274, 45.27944040298462, 49.5628102847508, 49.86400427137102, 51.2424886567252, 42.02080127171108, 35.406925678253174, 27.505663531167166, 18.543310710362025, 8.898854970932007, 18.88611398424421, 15.37776701790946, 10.152144977024623, 11.075558832713536, 13.75905908857073, 2.8251983438219344, 0.2871989847293922, 0.9553731807640621, 5.739190323012216, 23.728813852582658, 46.341027872903005, 46.66008220400129, 48.88971744264875, 47.728148869105745, 56.39653730392456, 59.25783675057547, 34.279392855507986, 8.551424196788243, 0.5270185289638383, 0.147547914779612, 0.19380382341997965, 0.10044270421245269, 0.18639352891061986, 0.20520171895623207, 0.12364860863557883, 0.11218822680945907, 0.09219262762261288, 0.14712613741202013, 0.14033527752118452, 0.19311392972511904, 0.12918378519160406, 0.14487806947103568, 0.12118582507329327, 0.11373138507562024, 0.22521048172244004, 0.09166366207812514, 0.14202876522072724, 0.17484153807163239, 0.12356343892003809, 0.14933111837932042, 0.17888114202235425], [0.02195445853950722, 0.05414422767769013, 0.08854301167385918, 0.049987695179879665, 0.056243513245135546, 0.07993420719036035, 0.03670920252001711, 0.017005286877974868, 0.03385181352496147, 0.04986630526504346, 0.002327504883786397, 0.06591532086687428, 0.016389495992500867, 0.06926529575139284, 0.03360195318236947, 0.04169619402715138, 0.030143877491354942, 0.04170175122895411, 0.011928407292413925, 0.034061884574059925, 0.005737755730349038, 0.01545445607709033, 0.051014366160546026, 0.07156410454107182, 0.07958324852266482, 3.705892937523978, 21.897025517054967, 44.70373698643276, 46.165099484579905, 42.46907820020403, 25.07951933997018, 20.279649904796056, 33.090031487601145, 23.30276768548148, 9.674008165087018, 1.4766551575490405, 0.05995343399367162, 0.45279266046626226, 0.8265836515596935, 2.119905812399728, 4.681647138936179, 5.979809480054038, 3.8360882827213834, 7.594226462500436, 19.075193575450353, 23.9877211025783, 26.25692285810198, 36.310973167419434, 44.55615724836077, 42.57121671949114, 45.727807658059255, 49.12812055860247, 46.749342237200054, 47.12444421223232, 48.44711719240461, 46.45350183759417, 44.621807302747456, 42.59646994726998, 40.575113909585134, 37.467424392700195, 32.327689034598215, 32.46574626650129, 32.95361055646624, 33.710290227617534, 37.341377122061594, 44.14440699986049, 42.699369294302805, 47.8242633002145, 44.15281432015555, 47.45222200666155, 44.08930778503418, 42.37966183253697, 38.541157313755576, 33.23563098907471, 32.52190855571202, 32.47816617148263, 31.113988127027238, 32.582938058035715, 34.02949741908482, 38.298703398023335, 39.179967744009836, 42.78418248040335, 41.863570485796245, 45.4991910798209, 40.32662548337664, 45.54470872879028, 43.0908968108041, 50.54735960279192, 35.05889735903059, 35.74739783150809, 48.256062575748985, 39.57518127986363, 41.74348824364798, 37.66062947681972, 38.49995797021048, 39.03832524163382, 41.54105247770037, 41.57994154521397, 41.86616563796997, 37.834209374019075, 32.72000517163958, 32.367853096553254, 32.47870465687343, 32.431936332157676, 33.853555134364534, 36.68126351492745, 41.99755259922573, 40.92658853530884, 40.254471915108816, 36.554868834359304, 31.798205035073416, 33.45676435743059, 31.57737738745553, 35.250240325927734, 34.39002207347325, 32.7538046836853, 34.94999129431588, 36.91866609028408, 39.87296717507498, 39.31237261635916, 42.859424522944856, 47.73331832885742, 49.07386554990496, 50.089000838143484, 49.84044292994908, 45.10939366476876, 44.68312168121338, 38.65479857581002, 46.61075694220406, 43.74328749520438, 40.13475792748587, 26.306032725742885, 19.407650981630596, 10.487511941364833, 8.341058799198695, 4.111441484519413, 12.792509078979492, 2.4104065213884627, 3.8659572856766835, 2.6388695878641943, 0.5483664348721504, 0.24245033306734903, 0.2301845641008445, 5.201623397214072, 19.48021101951599, 33.19381672995431, 42.048277923039024, 40.84035096849714, 33.689678396497456, 42.10698325293404, 39.68329177583967, 26.509156363351003, 3.595836511680058, 0.11436171696654387, 0.05772824625351599, 0.034004796030265946, 0.020405775301956704, 0.026184951354350363, 0.05011040145265205, 0.03735460467370493, 0.05544668582401105, 0.04141808966440814, 0.019306171984810914, 0.033238190558872054, 0.036162208300083876, 0.0322449476058994, 0.05573002169174807, 0.11190980353525706, 0.047601240021841865, 0.01523174052791936, 0.062417561055294106, 0.03874727065808006, 0.02298590979937996, 0.06312679299818617, 0.02396861171083791, 0.08257009860660348, 0.056881705964250226, 0.0420610592700541, 0.05853350447224719, 0.07679993858827011, 0.05650437603305493, 0.04516836967585342, 0.051270282428179464, 0.019846411388633505, 0.020803274686581323, 0.023810618224420717, 0.018393362572948848, 0.09428069700620004, 0.026738781814596484, 0.023504597234672735, 0.031236186557050263, 0.007329026370176247, 0.023145704796271663, 0.012346546864137053, 0.01886825226912541, 0.028834881660129343, 0.021571299992501736, 0.0034135122675382134, 0.043794621247798204, 0.019748810911551118, 0.12912871528949055, 5.128758072853088, 26.30260031563895, 50.84399904523577, 50.79342310769217, 46.90203237533569, 31.278451987675258, 28.315007073538645, 34.329711709703716, 27.9802793434688, 11.464172448430743, 1.6354358260120665, 0.1365264161889042, 0.15773899507309708, 0.2976149858108589, 2.9292589085442677, 7.331498571804591, 9.096992407526288, 5.750942766666412, 6.849063864776066, 16.55625966617039, 24.51308308328901, 29.829936708722794, 37.81833621433803, 43.78430618558611, 43.14108712332589, 47.50107479095459, 49.722361768995015, 49.64755398886544, 48.487156186785015, 49.30805458341326, 45.915200574057444, 46.38563878195626, 44.432062421526226, 42.51245927810669, 39.00092656271798, 34.66852671759469, 33.52878243582589, 34.80753237860543, 36.51614999771118, 40.76300014768328, 44.74612099783761, 46.939875738961355, 48.46975094931466, 46.61615916660854, 48.76496948514666, 45.13962875093733, 44.68031808308193, 39.68028320584978, 34.00742299216134, 34.096936634608674, 33.8934725352696, 33.37898622240339, 32.55109793799264, 35.93936613627842, 39.99843774523054, 41.25715255737305, 44.507679666791645, 43.664171831948416, 48.164016314915244, 43.965529101235525, 46.7981915473938, 44.879258905138286, 50.53217431477138, 36.33441986356463, 38.114277362823486, 49.36299051557268, 41.536365917750764, 43.98669331414359, 39.85128879547119, 39.731418473379954, 40.93560382298061, 44.22993237631661, 42.865469455718994, 42.34625141961234, 38.48935154506138, 34.788466521671836, 34.04946306773594, 34.17440210069929, 33.95740638460432, 35.94870798928397, 38.623899936676025, 42.90332324164254, 41.706016608646934, 40.54981551851545, 37.303561551230295, 33.923804896218435, 34.3047468321664, 33.02814040865217, 34.54907676151821, 35.78586653300694, 35.53042296000889, 37.424873624529155, 39.232798371996196, 40.85377141407558, 42.22583218983242, 46.255353110177175, 49.44331169128418, 50.38255875451224, 49.87152222224644, 51.56397138323103, 46.80497298921858, 46.75381340299334, 42.24579783848354, 47.82121304103306, 47.56067991256714, 42.22105530330113, 31.12073482785906, 16.906205688204082, 9.333488242966787, 15.144575050898961, 8.260972125189644, 13.648191026278905, 7.8809890406472345, 4.065137820584433, 2.9628145822456906, 0.40649969024317606, 0.15447032903986319, 0.48002151080540245, 5.144837941442217, 23.132104294640676, 38.18892880848476, 45.5117951120649, 44.76529107775007, 41.55881207329886, 49.36388335909162, 46.30056503840855, 29.463954244341167, 5.0596538952418735, 0.18469781561621598, 0.04717688422117915, 0.04483763813706381, 0.05185157659330538, 0.03540762646922043, 0.04874582342537386, 0.02686926070600748, 0.022183640527405908, 0.03173927616860185, 0.00985729873978666, 0.035952564728047164, 0.06752641405910254, 0.05102127703971096, 0.009135671658441424, 0.0979604534804821, 0.03935581139687981, 0.014825805256675397, 0.01722614324119474, 0.01251635279706014, 0.02465627302548715, 0.01985287613102368, 0.037193795266960344, 0.056323169863649776, 0.16979973789836678, 0.1579742838761636, 0.177632013335824, 0.1502673745687519, 0.11914948719952788, 0.18627882935106754, 0.0868866534105369, 0.08453272722129311, 0.14433174021542072, 0.14372029873941625, 0.10227643831499986, 0.17859163827129773, 0.12755528757614748, 0.11577568895050458, 0.0904914860480598, 0.1677432611052479, 0.12675372058791773, 0.08849330898374319, 0.1231134616370712, 0.14421288802155427, 0.102628184083317, 0.10160483792424202, 0.15147383697330952, 0.16304365971258708, 0.28317155369690483, 5.942916716848101, 30.302740778241837, 58.75865731920515, 56.71472658429827, 55.968149593898225, 36.44829389027187, 29.679786137172155, 41.95425489970616, 31.610746111188615, 13.147578528949193, 2.1755393871239255, 0.34934356436133385, 0.9612860977649689, 2.039200531584876, 7.737022365842547, 14.084340742656163, 13.375406486647469, 8.679381353514534, 11.521456003189087, 24.168372528893606, 31.283840315682546, 29.78795916693551, 37.962726729256765, 45.47704717091152, 43.83867931365967, 49.24948821749006, 51.81298439843314, 50.50545154299055, 50.269285746983115, 51.74060501371111, 48.42963899884905, 49.26642097745623, 47.48351321901594, 45.07634455817086, 41.91276373182024, 36.90317160742623, 35.57879284449986, 37.37101466315133, 36.94474615369524, 42.35485328946795, 47.04728446687971, 46.77042654582432, 49.52965348107474, 46.58504513331822, 49.30183941977364, 46.9101756640843, 45.58090189525059, 41.78543451854161, 35.29566764831543, 35.66369635718209, 34.98947095870972, 34.53934580939156, 33.927133083343506, 38.30850730623518, 40.37880645479475, 42.33117730276925, 45.36810289110456, 44.81839268548148, 48.78903109686715, 44.85489157267979, 48.78611980165754, 48.0137927872794, 52.03428452355521, 38.57244157791138, 40.1160637991769, 50.59899861471993, 45.223097460610525, 47.22152096884591, 42.89371388299124, 42.154946667807444, 43.11316926138741, 46.22814049039568, 45.5293983731951, 45.83762393678938, 41.12797859736851, 36.2847124508449, 35.86202573776245, 35.28619030543736, 35.241228512355256, 37.36852025985718, 40.681588104793, 46.145616735730854, 44.975960459027974, 44.98224857875279, 40.47083534513201, 35.647065843854634, 36.097357749938965, 34.401906967163086, 37.43278762272426, 39.18193755831037, 36.23378562927246, 39.31128522327968, 41.354118142809185, 44.13743100847517, 44.56625645501273, 48.98153788702828, 51.78401735850743, 51.29308543886457, 50.887849126543315, 53.80732931409563, 47.7957444190979, 49.56914356776646, 43.93064914430891, 52.2519576890128, 49.167204175676616, 44.45170497894287, 30.36135230745588, 24.219341039657593, 16.806241955075944, 15.96320138658796, 11.2757842029844, 22.76100274494716, 11.382728270121984, 9.04989230632782, 7.171901055744716, 0.9065767420189721, 0.5378159752913884, 0.5408649316855839, 6.552311079842704, 25.842157091413224, 44.7954740524292, 51.414581639426096, 50.76053033556257, 47.81839902060372, 56.01930570602417, 52.848915645054404, 35.58799573353359, 6.354821997029441, 0.36887937464884346, 0.17520101235381194, 0.15615391012813362, 0.18094638548791409, 0.2324547522834369, 0.24032448285392352, 0.12724792478340013, 0.14162000215479306, 0.12531654270631926, 0.08903528882988862, 0.10467673558741808, 0.07244406268000603, 0.11122821510902473, 0.12169471276657921, 0.3304440570729119, 0.14383826883775847, 0.10776709618845157, 0.11425524125141756, 0.1543060014290469, 0.08798736613243818, 0.08806287350931338, 0.12699769463922295, 0.14885709381529263], [0.024676532384806445, 0.008933118777349591, 0.013734293469626988, 0.024469635183257715, 0.022751596390402744, 0.04106524127668568, 0.07762458933783428, 0.0406564273206251, 0.05488787152405296, 0.04187040789318936, 0.019118083773979118, 0.04632297843428595, 0.0668436246258872, 0.050680679601750205, 0.00758216403690832, 0.03665189684501716, 0.04516211697565658, 0.04162738039823515, 0.01146759295703045, 0.016213188845930353, 0.0902755151369742, 0.013402474578469992, 0.10035633348992892, 0.041683902365288565, 0.047325493568288426, 1.7325790247746875, 15.681425877979823, 45.11424698148455, 45.978734901973176, 43.750975676945274, 25.955713238034928, 24.14880813871111, 30.759647369384766, 26.59693816729954, 12.653235043798174, 2.149508829627718, 0.2553436112190996, 0.02882989103506718, 0.2816087247005531, 1.5005306878260203, 7.495046138763428, 8.911278350012642, 2.6174218016011372, 4.279764635222299, 10.00326418876648, 14.946144921439034, 25.453575611114502, 34.30369070598057, 40.480118138449534, 45.02149200439453, 49.56140674863543, 45.410893372126985, 44.52632515771048, 46.03963933672224, 45.90993383952549, 46.4697710445949, 46.1806252343314, 45.4294068472726, 42.253854274749756, 39.06736523764474, 33.71574108941214, 32.46634381158011, 31.8912935256958, 31.64892646244594, 34.872991357530864, 39.92579780306135, 42.79719645636422, 46.10597726276943, 46.11146633965628, 44.07644666944231, 44.48525435583932, 43.79470763887678, 41.50780534744263, 36.835690702710835, 32.71288326808384, 31.907017299107142, 32.18903425761631, 32.23543432780674, 32.752804143088206, 33.40323543548584, 35.28469296864101, 38.67981209073748, 36.32193047659737, 37.00477164132254, 37.07153688158308, 41.725217955453054, 41.07529388155256, 48.276038646698, 37.884615080697195, 34.42630556651524, 48.563801765441895, 41.44645275388445, 42.81274652481079, 42.14181457247053, 45.11800595692226, 41.844824245997835, 41.63722596849714, 42.93100833892822, 43.996570178440635, 43.24118634632656, 38.87843329565865, 31.50642933164324, 34.066771030426025, 33.82889250346592, 37.85548823220389, 45.05561808177403, 46.26821769986834, 46.62840189252581, 45.92630379540579, 42.63745737075806, 37.910820211683, 34.18094382967268, 33.62560558319092, 34.012675830296104, 34.253708839416504, 33.810809816632954, 35.722328730991904, 35.303654602595735, 37.9993576322283, 42.06721871239798, 40.277658053806846, 46.75126688820975, 49.54949753625052, 48.79037209919521, 50.81227357046944, 49.84885719844273, 44.732116903577534, 44.268824917929514, 44.605579784938264, 45.269000734601704, 43.189811365945, 30.821764264787944, 14.38666033744812, 3.9038714340754916, 9.868601151875087, 10.631069540977478, 17.530683721814835, 4.976963383810861, 3.559189106736864, 2.1513498851231168, 0.3438888484878199, 0.1008830734395555, 0.3431532351034028, 6.839107530457633, 21.92841747828892, 38.00587851660592, 38.01636682237898, 33.32245567866734, 35.35095793860299, 41.19395521708897, 42.92667613710676, 22.950787578310283, 2.5458811947277615, 0.016126122625012482, 0.02858572020860655, 0.025253502585526024, 0.03364990525213735, 0.04352473733680589, 0.05017577830169882, 0.016714748361014893, 0.04383599831323538, 0.04840689179088388, 0.04490078939124942, 0.05142433362613831, 0.0305304117500782, 0.04238425228478653, 0.0773921978792974, 0.057049975863524845, 0.020167209174750105, 0.0056963231098572055, 0.03160306365628328, 0.04939396007518683, 0.03137403094608869, 0.05145582104367869, 0.013402187897424613, 0.03770357523379581, 0.062149926487888606, 0.04866204131394625, 0.021310761205053756, 0.03485735831782222, 0.06350386169339929, 0.011670226414155747, 0.06662044767290354, 0.010968743341176637, 0.03639162777523909, 0.014987651125660964, 0.02483375064496483, 0.02917573694139719, 0.025582110309707265, 0.04843270665566836, 0.04290506523102522, 0.02716389757448009, 0.04702039708250335, 0.013889502417961401, 0.04504150737609182, 0.08105522846536976, 0.0042722710641101, 0.024146983300202658, 0.1157524830528668, 0.06753925194165536, 0.14227458488728317, 2.6400171262877326, 20.829153401511057, 50.59840106964111, 52.58532878330776, 50.22188861029488, 30.081388541630336, 25.35858678817749, 37.84339141845703, 28.969169548579625, 13.795395561626979, 2.2840448447636197, 0.17478209840399878, 0.10813038383743592, 1.211851709655353, 1.644416698387691, 5.674107415335519, 8.415475743157522, 6.984875960009439, 8.147925802639552, 9.899888890130178, 17.423752682549612, 25.14990632874625, 35.59898778370449, 42.162759917122976, 46.65701110022408, 50.36830105100359, 47.33371353149414, 46.92493711199079, 47.364098003932405, 47.89802190235683, 47.29187147957938, 46.802603653499055, 47.41186686924526, 43.56261348724365, 41.203773021698, 35.118328775678364, 33.38257149287632, 33.33407654081072, 33.57409858703613, 36.5547194480896, 42.817224638802664, 43.232855456215994, 48.41834122794015, 46.3233551297869, 46.566333634512766, 47.32212741034371, 45.506566592625205, 44.05306945528303, 37.95044926234654, 33.674628598349436, 33.864661829812185, 33.412320205143516, 34.53193555559431, 33.922991956983296, 34.98317241668701, 37.25814117704119, 40.345642702920095, 39.3139637538365, 39.82230091094971, 40.150061334882466, 44.41957303455898, 42.95180777141026, 50.22390011378697, 39.09740924835205, 36.08027212960379, 50.24349750791277, 43.64074945449829, 44.49942173276629, 43.88974509920393, 45.60104819706508, 43.75119801930019, 44.42227240971157, 44.66786343710763, 45.75659057072231, 45.33862863268171, 40.13552917752947, 33.65964133398873, 34.84271110807146, 35.32160527365548, 39.46149832861764, 45.26672519956316, 48.53676979882376, 48.339131764003206, 47.366106033325195, 43.299530369894846, 38.80435160228184, 35.49538319451468, 34.707328932625906, 34.77507039478847, 36.259334155491416, 34.78690665108817, 36.69256475993565, 38.01737083707537, 40.22495249339512, 44.50909015110561, 42.892258235386436, 48.33079045159476, 50.31731169564383, 47.95862061636788, 51.71058879579817, 51.263024057660786, 46.183981214250835, 47.94051013674055, 47.28493022918701, 49.230196544102256, 42.72508110318865, 31.230565002986364, 15.335019963128225, 10.534528664180211, 14.138600093977791, 9.916825992720467, 9.670174496514456, 8.355683888707842, 5.812635387693133, 2.649059555360249, 0.7272509559988976, 0.07470595916467053, 0.5111848871622766, 6.707097836903163, 25.873384032930645, 38.977153301239014, 41.78827633176531, 39.763480935777935, 39.06966161727905, 46.78405891145979, 48.837453092847554, 28.622402327401296, 3.377749494143895, 0.019977986114099622, 0.0027988577161782552, 0.027674313667895536, 0.03987661077241812, 0.022533798523779427, 0.014288929690207754, 0.07504211898360934, 0.0324286914962743, 0.05267943681350776, 0.02407790334629161, 0.015048600533711059, 0.024373466415064673, 0.03856068031330194, 0.056633806587862115, 0.05541510680424316, 0.036000761070421765, 0.03415184135415724, 0.02421349669540567, 0.01033448103615748, 0.04370387058172907, 0.01599044445902109, 0.03987363878903644, 0.041241741805736504, 0.09367979317903519, 0.0980267734932048, 0.10225026721933059, 0.08888853527605534, 0.13574625019516262, 0.14264066810054438, 0.16827625036239624, 0.07000698202422687, 0.08371782023459673, 0.11542993464640208, 0.08065225330314466, 0.15136839263141155, 0.08029117767832109, 0.2712666296533176, 0.1134412299309458, 0.1647301177893366, 0.1410756813628333, 0.10395785487656083, 0.162488048097917, 0.13580537773668766, 0.20852230648909295, 0.15940383502415248, 0.4388495800750596, 0.14508329917277607, 0.30152359179088045, 3.346925765275955, 24.419727087020874, 57.88108594076974, 58.81470843723842, 54.439101219177246, 35.71050984518868, 32.921888555799214, 41.6365624155317, 34.33251183373587, 16.463680131094797, 3.033751347235271, 0.5443953222462109, 0.24832291794674738, 2.3533168647970473, 4.516849330493382, 14.865083762577601, 20.264707803726196, 7.3278394767216275, 7.130864994866507, 11.202884571892874, 18.019576345171245, 26.86856583186558, 35.8774333681379, 42.38330616269793, 46.88781983511788, 52.21196385792324, 49.88119411468506, 48.89334092821394, 49.02080563136509, 48.57406425476074, 47.74168743406023, 48.07975203650338, 50.43394415719168, 47.20889261790684, 43.696585178375244, 37.36717230933053, 35.8216358593532, 35.952901227133616, 34.257679734911235, 37.95110934121268, 43.75751393181937, 45.29935394014631, 49.75558805465698, 48.03844152178083, 46.53050872257778, 48.54869638170515, 47.0214649609157, 45.82358857563564, 40.384538718632285, 35.84851496560233, 34.83075673239571, 36.56001744951521, 35.55269193649292, 35.50671223231724, 36.53280135563442, 38.916863782065256, 41.06939138684954, 40.74750566482544, 40.99135616847447, 40.805599553244456, 44.87575701304844, 45.04508808680943, 50.716499601091655, 41.89140496935163, 37.73694501604353, 51.426490851810996, 46.11129263469151, 45.546160902295796, 46.79405736923218, 47.98563868658883, 47.581239632197786, 47.710726261138916, 48.73013816561018, 47.81923280443464, 47.526512145996094, 42.468070711408345, 35.39095524379185, 36.5589474269322, 38.09213692801339, 41.258976459503174, 48.114649363926475, 50.67172193527222, 51.946000712258474, 50.77771323067801, 45.67340326309204, 41.27704872403826, 37.804273060389924, 37.47343111038208, 36.278330530439106, 38.116754395621165, 37.355679988861084, 39.196591309138704, 38.61653137207031, 42.01286990301949, 46.530522618974956, 45.69616208757673, 50.111374037606375, 50.563733032771516, 48.64508874075753, 51.160326208387104, 53.6222814151219, 48.76275300979614, 48.85363892146519, 50.14507280077253, 50.224713053022114, 47.79026229040963, 34.08050067084176, 19.343652861458914, 8.989450795309883, 17.25116811479841, 17.20603609085083, 23.73354731287275, 11.033103602273123, 7.3021789108003885, 3.5065297952720096, 1.1227996881519045, 0.3451629472630364, 0.726670401436942, 8.597237144197736, 28.642003195626394, 46.99378681182861, 48.15912478310721, 43.44890969140189, 46.692394801548545, 56.442947796412874, 57.054316316332134, 31.59993471418108, 4.272067768233163, 0.1469625969018255, 0.09379091007368905, 0.12237560908709254, 0.1445201151072979, 0.14982019285006182, 0.1878515649586916, 0.19113657011517457, 0.08362772435482059, 0.16680425006364072, 0.10891227331012487, 0.11896655415850026, 0.13431292639247008, 0.1345407377396311, 0.21921050867864064, 0.16800087371042796, 0.11277034878730774, 0.1291344285543476, 0.10599592979997396, 0.2161321717181376, 0.13583318410175188, 0.09043875709176064, 0.17783060696508202, 0.1146226136812142], [0.02606179385579058, 0.06620407822941031, 0.03238337214237877, 0.003516503069217184, 0.014097640490425485, 0.025827896049512283, 0.027897488924541643, 0.05426163459196687, 0.03541271887453539, 0.030274234246462584, 0.03703979156645281, 0.02031617984175682, 0.014973924362233706, 0.06819055735000543, 0.060850742273032665, 0.0184105312052582, 0.014282899210229516, 0.026251688666109527, 0.01218060264363885, 0.03372437447043402, 0.00410567969083786, 0.1504074784794024, 0.01188832029168095, 0.041003433521836996, 0.024410926637106707, 0.6828338908297675, 12.313447288104467, 37.0932743208749, 46.79001004355294, 40.02675860268729, 29.631527423858643, 23.76039515222822, 25.474786724363053, 31.81794834136963, 17.936677387782506, 4.242943091051919, 0.2801475945327963, 0.025987445077459728, 0.7058089779956, 1.535408364874976, 2.535790890455246, 5.567002671105521, 7.306418180465698, 4.6946298480033875, 4.361170164176396, 10.522689802306038, 17.680773496627808, 25.820544719696045, 37.62105253764561, 44.17259931564331, 46.87190498624529, 44.87951946258545, 42.94974415642874, 41.71372216088431, 44.47522810527256, 47.29678038188389, 47.23852321079799, 45.407728467668804, 43.83904409408569, 40.99967663628714, 35.74593523570469, 31.380930968693324, 32.59518078395298, 31.47213649749756, 32.513365745544434, 36.75617551803589, 41.31502410343715, 42.87949439457485, 47.04857683181763, 45.32275547300066, 46.245816707611084, 45.437056813921245, 41.29084437234061, 42.61000503812517, 36.98569883619036, 33.03723907470703, 33.3948906489781, 33.20636517660958, 32.85309444155012, 32.629244327545166, 32.38371583393642, 33.80392762592861, 31.129684107644216, 35.474250248500276, 35.10019397735596, 42.205925600869314, 44.06356470925467, 49.488978726523264, 39.25066219057356, 32.052776609148296, 52.62692417417254, 42.09350374766758, 47.47546025684902, 44.074838161468506, 45.10153177806309, 44.91651167188372, 48.67256191798619, 45.54009165082659, 47.390879835401265, 44.08377007075718, 42.268695626940044, 33.217277322496685, 31.975495270320348, 33.86037826538086, 39.05498007365635, 43.89901747022356, 49.36847611836025, 45.97739389964512, 48.32564183643886, 44.58976568494524, 43.28798941203526, 36.43516526903425, 33.651654379708425, 33.95520033155169, 34.19303022112165, 33.657442229134695, 35.08466822760445, 35.29228040150234, 37.3532828603472, 39.581542355673655, 41.60725491387503, 44.51134484154837, 46.932225772312705, 43.21445662634713, 46.629332951136995, 54.60724415097918, 51.58637932368687, 48.127392360142295, 48.020692348480225, 42.17751094273159, 35.55489798954555, 26.764408860887798, 10.666550517082214, 11.003361838204519, 18.3529509135655, 8.208866715431213, 6.968808685030256, 9.153555086680822, 4.428492563111441, 2.4263163762433186, 0.616363134767328, 0.35214490975652424, 0.7957733305437225, 6.1714768409729, 24.795164312635148, 39.61014461517334, 33.11081007548741, 33.10222905022757, 44.134075028555735, 46.26083871296474, 45.585459913526265, 19.282182148524694, 2.3034101256302426, 0.10409082738416535, 0.026218615172963058, 0.029317052037056004, 0.08664181761975799, 0.04246895041848932, 0.029741496047271148, 0.06916283017822675, 0.050991265435836146, 0.020756549068859646, 0.023621990578249097, 0.04358821428780045, 0.057382376598460336, 0.020076807954215577, 0.03924281496022429, 0.04742849857679435, 0.0030163629645747797, 0.05187124053814581, 0.033552756000842364, 0.04934375187648194, 0.03511451630453978, 0.02594644799163299, 0.024793476198932955, 0.010350217959577484, 0.03781561154339995, 0.06189124858272927, 0.04558208604742374, 0.02220350124740175, 0.0517346955436681, 0.03150835373838033, 0.008209707148905312, 0.02305567846633494, 0.033231086297226806, 0.09347851255110332, 0.012190086018693234, 0.03839711944705673, 0.03349910084424274, 0.02654374540517373, 0.07698748566742454, 0.0385891143232584, 0.020536825859120915, 0.023429105124835457, 0.06486264163894312, 0.018775818836210028, 0.008985762068602656, 0.04800516174041799, 0.0461430241619902, 0.014804823257561241, 0.01226254168432206, 0.8109652953488486, 15.437167167663574, 42.89448165893555, 52.96200105122158, 44.66593183789934, 34.50149202346802, 27.981868743896484, 31.81105920246669, 34.96137939180647, 18.49422342436654, 5.129532362733569, 0.4040792744074549, 0.07958795755569424, 0.27064023326550213, 1.7902677463633674, 3.7916119950158254, 5.035636144024985, 7.595782858984811, 6.145132311752864, 6.062265489782606, 13.56343082019261, 21.06381491252354, 28.80627598081316, 38.81194945744106, 46.254640919821604, 48.504478045872276, 47.097075257982524, 45.34194639750889, 44.811701570238384, 47.47189583097185, 48.62579011917114, 47.46516302653721, 47.83031518118722, 45.00549725123814, 43.59794160297939, 37.55898427963257, 32.320570605141775, 33.24299955368042, 33.13909271785191, 34.93184954779488, 38.571420192718506, 42.88438245228359, 43.63975238800049, 47.9927327973502, 45.64975159508841, 46.49010842187064, 47.09080798285348, 44.06905378614153, 43.63199125017439, 38.99325227737427, 33.8680351802281, 34.30882542473929, 34.87614236559187, 34.099966049194336, 34.20679112843105, 34.89220660073416, 35.64515161514282, 33.47124440329415, 37.75241865430559, 37.38134316035679, 42.90861776896885, 45.435281549181255, 50.47372259412493, 40.01338332039969, 33.85786649159023, 51.51302024296352, 46.17668213163103, 48.5780942099435, 45.34386410032, 47.02921567644392, 47.08799396242414, 49.60280758993966, 47.30270719528198, 48.57627725601196, 46.18552024023873, 43.96182918548584, 33.68624251229422, 33.46476868220738, 35.41857780729021, 42.623717308044434, 46.54122979300362, 51.27214356831142, 48.144175733838765, 48.31327404294695, 47.115821497780935, 43.903342723846436, 38.68130942753383, 35.24357352937971, 35.36098766326904, 36.0034875869751, 35.04201323645455, 36.05501542772566, 36.40689304896763, 40.61048024041312, 42.04106221880232, 44.33221680777413, 47.89087568010603, 48.65547282355172, 45.823720591408865, 49.0200309072222, 55.25673048836844, 52.78124713897705, 50.7129282270159, 50.00847469057356, 44.40723998206002, 37.91814013889858, 25.6874589238848, 14.066246765000479, 8.971309917313711, 13.09681064741952, 13.599733420780726, 10.25198711667742, 8.541272010122027, 5.5046078477587015, 2.432379548038755, 0.8893404869096619, 0.1564619243144989, 0.8899536111525127, 7.7597507919584, 28.038513932909282, 42.56533506938389, 40.92327077048165, 37.30831411906651, 48.33699171883719, 51.27084425517491, 49.91895062582833, 23.475366149629863, 3.002402812242508, 0.188389833218285, 0.017711473894970756, 0.04225137477208461, 0.04717141183625374, 0.016458864323794842, 0.08045467069106442, 0.056546971068850586, 0.03562588065064379, 0.053724010940641165, 0.08207873068749905, 0.019433039373585155, 0.03945460270291992, 0.04551417487008231, 0.041606271173805, 0.04126311226614884, 0.042101381213537285, 0.06160118164760726, 0.03137338633782097, 0.049773678449647765, 0.02158412430435419, 0.03385468712076545, 0.01607559551484883, 0.03010646646310176, 0.09086518920958042, 0.16158099605568818, 0.10926017857023648, 0.09146199468523264, 0.14002640838069574, 0.07635137944349221, 0.10991919892174856, 0.12403040671987192, 0.1599301610674177, 0.19398904990937027, 0.10926656358476196, 0.06534594177667584, 0.15647830414984906, 0.22874189008559498, 0.15259603889925138, 0.20571233012846538, 0.07887799279498202, 0.13495940741683754, 0.10823886123086725, 0.1148312089166471, 0.07537993442799364, 0.24197069023336681, 0.19970477106315748, 0.14225483951824053, 0.12690280830221518, 1.2239674138171333, 18.73566116605486, 48.16383566175188, 60.06551619938442, 49.66739804404122, 40.24877439226423, 32.733526366097585, 36.971170152936665, 41.16921615600586, 22.61078790255955, 6.276088050433567, 0.6043464967182705, 0.2783146814576217, 1.3036908273186003, 4.992997220584324, 8.917879138674055, 11.094653350966317, 14.15066042968205, 6.789875200816563, 7.449614473751613, 11.535176958356585, 20.918905019760132, 29.36883340563093, 41.0532020841326, 47.51360239301409, 51.12455340794155, 49.309482438223704, 47.62761190959385, 46.00310918263027, 50.23036541257586, 51.00560024806431, 48.78690147399902, 49.06380108424595, 48.81398555210659, 46.02550670078823, 40.26720101492745, 33.976010186331614, 36.32640511648995, 34.484482833317344, 36.189866065979004, 40.35828147615705, 45.267242840358186, 44.72994906561715, 50.803960050855366, 47.12732771464756, 47.46070228304182, 48.59640966142927, 46.16847283499581, 46.30334084374564, 41.61466864177159, 35.505343437194824, 36.66094698224749, 35.98243107114519, 36.18342161178589, 35.76203073774065, 37.0004255431039, 37.557386193956646, 34.608028752463206, 38.17216280528477, 38.62579332079206, 45.37620101656233, 49.208271503448486, 51.75523444584438, 43.358954838344026, 36.377860001155305, 50.10237264633179, 46.4054411479405, 50.48917538779122, 47.550549439021516, 49.23934037344796, 50.56740515572684, 51.40978043419974, 49.72163915634155, 50.28215728487287, 48.98449781962803, 46.01185001645769, 36.57927090781075, 35.87280934197562, 37.60839639391218, 43.72042792184012, 47.81282309123448, 53.09914459500994, 49.6533522605896, 49.899697167532786, 49.1289439201355, 46.10062714985439, 41.48904868534633, 36.45722579956055, 38.93047530310494, 36.87063666752407, 36.712884766714915, 39.125205516815186, 38.96491057532174, 42.32481970105852, 44.03699132374355, 45.324857303074424, 50.59591361454555, 47.09771796635219, 49.132567405700684, 52.402156897953574, 54.18306704929897, 58.279558181762695, 51.93313264846802, 52.47381714412144, 47.310996396201, 41.07968166896275, 30.402874742235454, 14.5988461630685, 18.009972197668894, 30.457928793770925, 14.527999724660601, 16.460237298692974, 23.72437742778233, 9.42289331981114, 6.678339242935181, 1.2803820094891956, 0.7160217442682811, 1.2486412269728524, 9.23575575011117, 30.983476638793945, 50.82616996765137, 42.58250406810215, 43.175265312194824, 56.17971529279436, 57.33100400652204, 56.933483668736045, 27.3339718069349, 4.462632536888123, 0.2569627043391977, 0.11071340380502598, 0.15171167706804617, 0.12216488325170108, 0.09778553393802472, 0.11657968509410109, 0.23518387441124233, 0.17305984081966536, 0.14392353354820184, 0.11474949972970144, 0.12058310955762863, 0.1641207662011896, 0.11919473191457135, 0.20834784156509809, 0.17835854792169162, 0.09512520847576005, 0.11747164651751518, 0.14229808934032917, 0.29699548333883286, 0.0863609244780881, 0.10216833411582879, 0.18030484419848236, 0.09953443080719028], [0.057701410193528445, 0.024530377638127123, 0.04139811698613422, 0.0249860054214618, 0.11410594997661454, 0.01664413322162415, 0.039940969818936925, 0.028812669816293886, 0.017755848388852816, 0.04013654736003705, 0.11788000246243817, 0.046315097250044346, 0.038253419300807376, 0.11189190378146512, 0.03695904589923365, 0.03536740969866514, 0.051899650799376626, 0.0427342304693801, 0.03985703842980521, 0.006541886308696121, 0.041416379756161144, 0.01219660249937858, 0.030778473974870782, 0.04588327756417649, 0.0130218427262402, 0.27189563161560465, 8.922569172722952, 33.76050138473511, 47.17021894454956, 40.06608540671212, 28.06984336035592, 25.064328840800695, 32.3249305997576, 33.34360599517822, 17.920413391930715, 6.7600765483719965, 0.5109502768942288, 0.006898858492994415, 0.16837072957839283, 0.591186662869794, 3.4810429343155453, 4.112561881542206, 7.203048961503165, 8.31848497050149, 2.2994361902986253, 8.214693648474556, 12.380595547812325, 19.62249275616237, 31.813925334385463, 42.32441323144095, 46.53657449994768, 43.31821755000523, 39.65694073268345, 41.96899550301688, 39.9931640625, 44.75085966927664, 45.78148944037301, 46.59863928386143, 43.75834424155099, 42.748427050454275, 38.00648300988333, 31.06754289354597, 31.827599389212473, 31.83876861844744, 32.001349517277305, 35.759230613708496, 39.83648565837315, 43.75428996767317, 46.11934559685843, 44.72996643611363, 42.52876670019967, 45.50722319739205, 44.06090702329363, 44.20273017883301, 39.78814704077584, 39.49870593207223, 33.46533496039254, 32.11137424196516, 32.7883163860866, 32.061600821358816, 31.3072418485369, 33.152200494493755, 33.12466825757708, 34.71661867414202, 38.949989318847656, 44.895653179713655, 45.665722029549734, 51.36862277984619, 39.242831570761545, 31.077454498835973, 40.142289774758474, 41.94655629566738, 47.3967684337071, 43.87817634854998, 45.45965582983834, 41.08562585285732, 42.43697057451521, 45.075517722538535, 46.302051952907014, 46.91099207741873, 40.69024556023734, 31.4778687613351, 32.70773465292794, 34.070627280644004, 38.85162714549473, 43.81476361410958, 47.34777668544224, 49.032117298671174, 48.69457033702305, 48.18696621486119, 46.04308564322335, 43.02373204912458, 36.149726322719026, 33.77878556932722, 34.10968310492379, 34.743813923427034, 33.37815591267177, 33.218444619859966, 36.43306343896048, 40.8351537159511, 41.207525048937114, 46.3816922051566, 45.48315116337368, 38.119721276419504, 46.162639822278706, 48.08229855128697, 48.20881135123116, 55.47948626109532, 47.46214056015015, 41.28414978299822, 28.918843746185303, 21.686118159975322, 11.343188677515302, 8.276298114231654, 9.027349744524274, 11.581770709582738, 4.462393258299146, 5.544034097875867, 5.327655034405844, 0.7448640423161643, 0.9402312104191098, 0.06607671720641, 0.7472256698778698, 8.48039015701839, 28.599778992789133, 42.93438516344343, 35.32250159127371, 34.232391766139436, 45.207978180476594, 46.41941050120762, 42.458648954119, 16.436542204448156, 0.6601918829338891, 0.2755836051489626, 0.04333680349269083, 0.107022261513131, 0.02096372107709093, 0.0065682287344575995, 0.019435098727366755, 0.011669005051122179, 0.05278149865833776, 0.07827479551945414, 0.03186789248138666, 0.08322629625243799, 0.03304082168532269, 0.03237208131966846, 0.03784788606156196, 0.051075067903314314, 0.07039474443133388, 0.01582272078043648, 0.036748204712889025, 0.08954479399004153, 0.017709562122555714, 0.0374859995873911, 0.0884169941501958, 0.0340763068358813, 0.007792040855357689, 0.036229417193681, 0.0695845600483673, 0.03218722123918789, 0.03657781099900603, 0.03586319827341607, 0.03845086620588388, 0.057942249413047514, 0.057265302166342735, 0.034307945120547495, 0.07016189156898431, 0.03608710804421987, 0.024133304034226706, 0.05545553392065423, 0.013520170718298426, 0.0737947884148785, 0.0899366954607623, 0.06712648551911116, 0.0203277861832508, 0.024053993468571986, 0.02342432993464172, 0.007504837338014373, 0.033762117980846336, 0.02916727900238974, 0.018677468577932035, 0.48897659885031836, 11.577973519052778, 38.021630082811626, 51.95284468787057, 44.99566207613264, 31.627838679722377, 27.313353027616227, 33.57029444830758, 39.24934203284127, 21.66232579095023, 7.216211889471326, 0.8336007350257465, 0.16025465008403572, 0.31678590710674015, 1.6480420295681273, 4.246656468936375, 5.039270920412881, 6.230454019137791, 6.30996355840138, 4.365327792508261, 9.72891456740243, 14.835314205714635, 22.88092691557748, 33.518943786621094, 44.507471220833914, 49.746284416743684, 44.95301750728062, 41.57879509244646, 44.453706060137065, 43.36746638161795, 48.54203305925642, 47.11996957233974, 47.68244014467512, 46.8652868270874, 44.53049060276577, 40.02168641771589, 33.84307377679007, 34.0223650932312, 32.65317044939314, 33.016189507075715, 36.61291755948748, 42.57967962537493, 44.503733089991975, 47.298131806509836, 46.23878165653774, 44.2439329964774, 48.37777764456612, 45.98450190680367, 46.29050752094814, 43.13253041676113, 40.38326372419085, 34.200558594294954, 33.531440121786936, 33.918993268694194, 33.15356234141758, 33.15453856331961, 33.86284487588065, 34.173273018428254, 36.4524176461356, 39.50062016078404, 46.12186779294695, 46.71732146399361, 52.40645088468279, 41.41335153579712, 33.64651618685041, 42.83807965687343, 43.023141452244346, 48.95732341493879, 46.184874057769775, 46.454432896205354, 43.18833139964512, 45.530218260628835, 45.926279476710725, 48.227088587624685, 47.45950371878487, 43.607901845659526, 34.22935192925589, 35.04207924434117, 35.00165809903826, 41.27933120727539, 45.374661990574424, 49.66059228352138, 49.209779262542725, 49.72328935350691, 50.892455782209126, 47.071221011025564, 44.72190999984741, 37.188429900578086, 35.46734026500157, 36.21412222726004, 36.270155974796836, 35.689797265189036, 34.83217069080898, 39.715983050210134, 41.051680428641184, 43.57066297531128, 47.47265665871756, 45.544427326747346, 43.07325186048235, 50.46929659162249, 48.913831165858674, 52.043244225638254, 53.94533096040998, 52.11455706187657, 42.54395546231951, 35.19649600982666, 22.067023617880686, 9.845776319503784, 10.346995047160558, 14.019410695348467, 11.443395597594124, 7.454396571431841, 12.064195428575788, 3.8914550031934465, 1.5539937104497636, 0.15719607206327574, 0.11555502936244011, 0.8789521157741547, 9.642930609839302, 29.349378449576243, 44.35758120673043, 35.524954727717805, 35.429941586085725, 50.56280892235892, 52.443363189697266, 49.47437708718436, 21.494222811290197, 1.6665167467934745, 0.244766715914011, 0.07291791082492896, 0.050264622284365554, 0.007632599544844457, 0.02584965666756034, 0.026176871698615805, 0.03632621360676629, 0.07791258674114943, 0.03601622149082167, 0.05260136457426207, 0.03629853277068053, 0.01751016273296305, 0.021380015881732106, 0.02555411565117538, 0.005907485328082527, 0.056953820666032176, 0.05882712693086692, 0.04706702261630978, 0.030209542717784643, 0.05125762435740658, 0.022362154609124576, 0.03003059606999159, 0.02742027015691357, 0.11276917492172547, 0.1433744765818119, 0.11594564840197563, 0.10107815225741693, 0.11268510443291493, 0.10798482450523547, 0.12540218739637307, 0.1253480538725853, 0.10003049418862377, 0.12583826828215802, 0.2192614395171404, 0.13726692859615597, 0.09467017610690423, 0.13779899504567894, 0.10080096391694886, 0.12978727423718997, 0.14048979351563112, 0.11559164311204638, 0.18635926289217813, 0.09021657079990421, 0.07469637146485703, 0.06228549099926438, 0.2545582747885159, 0.1552751122840813, 0.11742276485477175, 0.6911678750600133, 12.639283061027527, 43.93164273670742, 59.3891716003418, 51.638546398707796, 38.3269374029977, 36.40552077974592, 42.91168539864676, 43.67575795309884, 24.5617413180215, 9.216317296028137, 1.387743728501456, 0.558846435376576, 0.7799084218485015, 4.0860892449106485, 7.473763806479318, 10.812848312514168, 14.880176986966815, 13.998408896582466, 5.014066764286586, 10.32420756135668, 14.755404710769653, 23.421908446720668, 33.56772361482893, 45.903246198381694, 50.82741022109985, 46.95892422539847, 44.46058130264282, 46.675218854631694, 45.27126237324306, 49.69917563029698, 49.883764948163716, 49.198870590754915, 48.93902880804879, 48.164179597582134, 42.380912508283345, 36.034511293683735, 35.16552788870675, 35.577246870313374, 35.907348837171284, 38.09231758117676, 43.73056534358433, 46.482586996895925, 49.22368260792324, 46.74283872331892, 44.29869869777134, 49.822328976222444, 47.26853248051235, 48.81275224685669, 44.29072216578892, 43.469952310834614, 37.17380741664341, 36.39119012015206, 35.78410516466413, 34.98958560398647, 34.90677349908011, 34.912276472364155, 36.405576365334646, 38.524005685533794, 42.723385742732454, 48.400067465645925, 48.70738281522478, 55.38231570380074, 44.66271134785244, 37.75486094611031, 46.53330189841134, 44.54249708993094, 49.018543992723735, 47.79070350102016, 46.52131278174264, 43.7288248198373, 46.47758776800973, 46.592719418661936, 50.49344852992466, 50.44353267124721, 46.74359607696533, 35.15697465624128, 35.96199989318848, 36.98113734381539, 43.44678701673235, 48.06771428244454, 50.30522877829415, 52.519022124154226, 51.611653396061485, 53.49671009608677, 49.71288095201765, 47.940041133335654, 39.71327325275966, 38.59754194532122, 37.750268186841694, 40.10644054412842, 37.36340291159493, 37.59205770492554, 40.546661036355154, 44.68385124206543, 43.4057822227478, 50.23944670813424, 45.740755626133506, 44.93387522016253, 51.89031784875052, 50.23518051419939, 52.91554192134312, 55.97584472383772, 52.36795786448887, 46.212322916303364, 34.224203314099995, 24.675474643707275, 16.631673676627024, 15.963917051042829, 15.003596101488386, 17.90400000980922, 16.07309409550258, 12.251348631722585, 10.466860158102852, 5.013238625867026, 2.065030025584357, 0.4062065359737192, 1.1811808411564146, 11.973453692027501, 35.32226882662092, 54.45687123707363, 44.63224002293178, 45.78359127044678, 57.755399976457866, 59.53241566249302, 55.279426779065815, 26.709438187735422, 2.963424938065665, 0.32874280693275587, 0.18863049601869925, 0.24152150005102158, 0.10573007299431733, 0.20747601906103746, 0.06454113139105694, 0.12227946067495005, 0.25494441549692837, 0.11751476063260011, 0.128494529319661, 0.19436547399631568, 0.10427448645766292, 0.13411608338356018, 0.13315291649528913, 0.08295676178698029, 0.14197721013001033, 0.12633011117577553, 0.13489911279508046, 0.14210613178355352, 0.09466872404196433, 0.1473706950034414, 0.2986469832914216, 0.11094651451068265], [0.0270123807048159, 0.04721848859584757, 0.012245520633379263, 0.04212002396317465, 0.0644631337906633, 0.04782381307865892, 0.02615350634524865, 0.01626282537888203, 0.031035760883241892, 0.04267396638169885, 0.07595105735319001, 0.023475459244634424, 0.037440924506102286, 0.020732941139223318, 0.018177023556615626, 0.015996988929275955, 0.005775413151630866, 0.025478964505184973, 0.06195988918521574, 0.03415754783366408, 0.036889611410775354, 0.015174265219164746, 0.06678969466260501, 0.056254471585686715, 0.04501122096553445, 0.0204168472971235, 3.8267724854605536, 23.808867522648402, 41.40847737448556, 43.21691281454903, 35.765018463134766, 26.965038095201763, 22.86095779282706, 31.36726038796561, 26.114220755440847, 8.837463293756757, 1.750391926084246, 0.014831745830763663, 0.18701365563486302, 1.1049582340887614, 2.856487601995468, 3.387404884610857, 3.3846553521496907, 1.8270913532802036, 3.330415108374187, 4.214541460786547, 7.9343598910740445, 17.660705362047466, 25.461225577763148, 39.84415299551827, 43.421457358769004, 44.06426995141165, 40.099739006587434, 38.338645117623464, 39.595442226954866, 43.06319086892264, 43.58056763240269, 46.80675867625645, 45.02322210584368, 43.50544718333653, 37.95082793916975, 33.68506826673235, 33.02577454703194, 32.99731819970267, 32.223285402570454, 39.22735445840018, 41.672217096601216, 43.33085284914289, 45.77730662482125, 44.17159877504621, 42.901561873299734, 45.37188271113804, 45.15000588553292, 45.19315072468349, 43.38582699639456, 44.31820229121617, 42.5693268094744, 33.797816685267854, 32.101104804447715, 32.423379625592915, 32.417383330208914, 31.614748273577007, 34.85032980782645, 38.20176560538155, 41.46784973144531, 45.116678850991384, 43.581550802503315, 48.80929551805769, 38.42561224528721, 25.09838891029358, 38.90072659083775, 40.972950390407014, 45.166004112788606, 43.417093890053884, 48.00582667759487, 48.317668778555735, 45.27654995237078, 42.82836954934256, 46.44000496183123, 46.393653529030935, 41.34528003420149, 33.771055698394775, 32.217316899980815, 33.69729362215315, 37.45045689174107, 42.29725619724819, 45.50700085503714, 45.57063940593174, 47.72067608152117, 47.234475885118755, 45.86536461966378, 42.743556363242014, 40.64949437550136, 32.565307004111155, 33.65845319202968, 33.718155588422505, 35.658401829855784, 33.59158372879028, 37.15150022506714, 40.13015474591936, 44.33399207251412, 46.781637464250835, 49.781480516706196, 43.53246177945818, 42.443133626665386, 46.849733284541536, 47.60341828210013, 48.35868746893746, 45.612721170697895, 36.13596541540963, 26.73076742036002, 14.478049993515015, 6.800300972802298, 6.351875526564462, 13.019623109272548, 14.003183177539281, 6.479550412722996, 11.240978939192635, 2.4446563635553633, 1.4324172799076353, 0.21786893638116972, 0.10897954327187367, 1.5710278706891196, 10.180994766099111, 29.320699759892054, 39.15679202760969, 35.05163301740374, 34.14276695251465, 42.93311364310128, 49.06071260997227, 38.46000582831246, 13.709380337170192, 0.6210082226565906, 0.06074159312993288, 0.057693274558654854, 0.012207487049246473, 0.07572381597544466, 0.05642863795427339, 0.07680098353219883, 0.057198195052998405, 0.03985269919836095, 0.01744439572628055, 0.01605384168215096, 0.006737317116598466, 0.005761230497487954, 0.03521864428850157, 0.04356171070997204, 0.006338547175151429, 0.06921587804598467, 0.026523942360654473, 0.08992216802601304, 0.022971752166215862, 0.02117253514006734, 0.0007977513949819175, 0.04978665882455451, 0.0575475116659488, 0.017750689826373543, 0.03153797518461943, 0.02579935347395284, 0.042132692211972814, 0.042213939995105774, 0.023218820337206125, 0.0356408355624548, 0.012720652905824994, 0.05711518307881696, 0.011340834133859192, 0.039275744264679294, 0.03987140980150018, 0.05627992004156113, 0.020935639905344163, 0.03131284065810697, 0.015023671157125915, 0.013219072500110736, 0.043643240085137744, 0.03576044771554215, 0.004735209638186331, 0.01825808304628091, 0.004537636355962604, 0.02994997932442597, 0.021759605334539498, 0.09453322738409042, 0.1236768899751561, 5.807363876274653, 28.61541591371809, 47.96308135986328, 48.182463782174246, 39.5516095161438, 31.61798960821969, 29.333706787654332, 36.90990093776158, 27.438629048211233, 11.234398995126996, 1.717754717384066, 0.016598396568692157, 0.3082583504063742, 0.5205404194337981, 3.5380735312189375, 7.084388060229165, 6.71926326411111, 5.66114033971514, 4.364031519208636, 5.202732069151742, 10.018299221992493, 19.955587659563335, 28.263677256447927, 42.74263572692871, 45.003256457192556, 44.81103801727295, 43.19578334263393, 41.13055290494646, 41.18191398893084, 45.71991450445992, 46.75711727142334, 47.690461839948384, 48.54661192212786, 45.02630363191877, 39.950557708740234, 34.308154923575266, 34.50518151691982, 34.19379104886736, 32.4298449243818, 40.11799539838518, 43.20849854605538, 45.49690859658377, 47.57996463775635, 44.736473424094065, 42.920301164899556, 45.907613141196116, 46.467544146946494, 47.172734192439485, 44.16543224879673, 45.96035691670009, 43.77405411856515, 35.46494313648769, 33.86832700456892, 32.1682174546378, 32.86660868780953, 33.242190088544575, 34.70132221494402, 39.48140491758074, 42.0716620853969, 45.96386228288923, 46.04046617235456, 50.09501797812325, 40.71067673819405, 28.981436593191965, 41.61443240301949, 41.87504196166992, 46.24522958483015, 44.03137023108346, 46.056262901851106, 48.56663315636771, 44.78881072998047, 42.406877926417756, 47.496329171316965, 48.85800586427961, 43.24763427461897, 36.115058285849436, 34.29251452854702, 34.53256089346749, 38.8132244518825, 45.15473066057478, 47.338733604976106, 47.537695271628245, 48.84384543555123, 49.79045411518642, 48.54487834657942, 45.056875705718994, 42.90869419915335, 34.030761991228374, 34.059412888118196, 35.1961555480957, 36.66757903780256, 36.076964787074495, 39.12464966092791, 42.393123967306956, 46.261578696114675, 50.14414521626064, 48.98896551132202, 44.87234544754028, 45.85721090861729, 48.70371764046805, 48.80783292225429, 52.46164737428938, 47.539581707545686, 40.367963790893555, 28.992756945746287, 16.195766278675624, 7.742309076445443, 8.757392253194537, 10.594084279877798, 13.293311783245631, 10.789211409432546, 9.077167459896632, 4.529091187885829, 1.0143926995141166, 0.38254854402371813, 0.03141570317425898, 1.7655823166881288, 11.334718823432922, 32.61602537972586, 44.07191644396101, 43.82494967324393, 37.683912890298025, 50.032293115343364, 52.706835406167166, 45.00407634462629, 16.1947466305324, 0.6113902873226574, 0.11330949235707521, 0.04241370070459587, 0.06450377125293016, 0.08995171144072499, 0.06243372375943831, 0.05619165620633534, 0.05472527417753424, 0.021940964174323847, 0.055857253793094835, 0.022947835503146052, 0.03099334905190127, 0.03430549221645508, 0.02958767894389374, 0.021925079669537287, 0.02052688871377281, 0.002411463626361053, 0.04348448324682457, 0.03908790880814195, 0.0433195517398417, 0.06067259290388652, 0.025020288403279016, 0.08419208907123123, 0.027547717693128755, 0.06854750748191561, 0.11801143469555037, 0.09143311623483896, 0.1039844738053424, 0.16345876029559545, 0.2340096559907709, 0.10167383815028838, 0.12261320490922246, 0.14532770748649324, 0.06790228174733264, 0.13868351972528867, 0.13020713813602924, 0.22427718394568988, 0.11279970221221447, 0.07688513544521161, 0.1055050300700324, 0.1122685857117176, 0.154181856662035, 0.0786838164286954, 0.16622493043541908, 0.12198751419782639, 0.1313446070998907, 0.13325427605637483, 0.08707183918782643, 0.2758873174233096, 0.2980811936514718, 7.454130802835737, 31.019138268062047, 53.29626151493618, 55.69992133549282, 46.310997758592876, 36.36552347455706, 33.94368369238717, 42.71359920501709, 33.94755383900234, 12.408033984048025, 2.398538563932691, 0.28493764464344296, 0.7397430028234209, 2.289767554828099, 8.066406062671117, 10.689942496163503, 11.879478437559944, 9.422676188605172, 6.320764533111027, 6.978322505950928, 11.293212022100176, 20.30916064126151, 30.242138590131486, 45.550249917166575, 48.252376556396484, 48.3213860648019, 45.282883235386436, 43.64170830590384, 44.492098331451416, 48.309188502175466, 48.34725073405674, 50.94045393807547, 49.31291484832764, 47.54645695005144, 41.321576254708425, 37.46801846367972, 36.90567990711757, 36.169414043426514, 34.593149185180664, 43.180702277592246, 44.68326759338379, 47.406419481549946, 48.80324363708496, 44.57593876974923, 45.76775632585798, 46.80436502184187, 48.379177706582205, 49.32215595245361, 47.0930209841047, 47.894620759146555, 47.15215015411377, 37.21578843252999, 35.8607611656189, 33.61254644393921, 35.83785990306309, 34.08721957887922, 37.28561782836914, 40.78718335287911, 44.21570941380092, 48.34778227124895, 47.55671943937029, 50.65829106739589, 43.364176409585134, 32.41202279499599, 42.65351118360247, 43.87182222093855, 45.64966821670532, 45.11573042188372, 46.1535758972168, 46.962342739105225, 46.35771744591849, 43.838925974709646, 48.447891916547505, 50.698816435677664, 46.719364234379356, 39.94198015757969, 35.73177480697632, 37.77399281093052, 40.703263010297505, 46.407734053475515, 49.993080956595286, 49.3159373147147, 50.19975164958409, 50.81059210641043, 49.95666544778006, 47.30044903073992, 44.85904312133789, 35.85947574887957, 36.00034352711269, 37.62219551631382, 39.087473324366975, 37.412165369306294, 40.80563082013811, 46.07627371379307, 49.216789994921, 51.58893626076834, 50.5154777935573, 46.51643167223249, 48.143539973667686, 48.88700417109898, 49.41078717367989, 53.2582757132394, 49.6419016293117, 41.56240429197039, 30.216642175401958, 19.803369998931885, 11.719313774790082, 11.514471326555524, 19.940173080989293, 23.818839924676077, 14.492366756711688, 24.272506918225968, 7.568269729614258, 2.237929867846625, 0.838199465402535, 0.30180806081209866, 2.3735521904059818, 13.756483043943133, 36.34242071424212, 49.51403740474156, 46.604336806706016, 46.47322082519531, 54.68587344033377, 60.547610010419575, 51.228783335004536, 21.507118667875016, 1.3596416307347161, 0.19776273598628386, 0.1586751291262252, 0.19388224849743502, 0.3037131428718567, 0.11904215653027807, 0.16046639372195515, 0.2749082999570029, 0.12491888047329017, 0.11391857931656496, 0.09125509578734636, 0.07444735589836325, 0.07378828804939985, 0.1706706647362028, 0.08285992126911879, 0.150331563981516, 0.1241378595254251, 0.11225599210177149, 0.26686749713761465, 0.10697634504841906, 0.13469969135309967, 0.11424887659294264, 0.19167607330850192, 0.13327723768140587], [0.03506805361913783, 0.03306527608739478, 0.04395660452012505, 0.03462147579661437, 0.027031686722433994, 0.05312605874080743, 0.04250852258077689, 0.05973060309354748, 0.007609844024825309, 0.009480158798396587, 0.015506676132125514, 0.026513628628371016, 0.03561890870332718, 0.04053402638861111, 0.0064353800594939715, 0.07575413292007786, 0.030523124283977916, 0.011716139486192592, 0.013365917656171535, 0.06249428979520287, 0.07780512715024607, 0.011753324053383299, 0.014567744818383029, 0.025538504256733825, 0.06340998637356929, 0.034286974995796166, 2.290159693786076, 14.855550834110804, 37.3901812689645, 48.79601056235177, 35.49696738379342, 26.519785370145524, 28.948311056409562, 32.88130065373012, 27.84461055483137, 11.720935310636248, 2.784845377717699, 0.29343393445014954, 0.014626936820734824, 0.27260917904121534, 2.6676186280591145, 4.078565214361463, 5.979716982160296, 3.3806338650839667, 3.522430964878627, 2.630589072193418, 5.210395932197571, 12.403535893985204, 21.29280843053545, 37.82884883880615, 45.35296971457345, 43.31288480758667, 39.42258146830967, 38.224253450121196, 37.29396956307547, 39.823593275887625, 41.23860434123448, 44.01645244870867, 45.75056995664324, 41.41731548309326, 37.87951510293143, 33.58761978149414, 33.62041180474417, 35.70348521641323, 35.85659572056362, 42.61819001606533, 42.704444953373496, 45.361404827662874, 45.16917943954468, 44.99075664792742, 44.140220710209434, 44.52327489852905, 45.80761119297573, 45.90803003311157, 46.77033969334194, 44.88169077464512, 43.22782496043614, 40.0415860584804, 33.127305098942344, 32.93337392807007, 34.1265081678118, 33.925083364759175, 31.762984616415842, 37.16434397016253, 39.912155015128, 44.97495297023228, 45.87251084191458, 48.064521585192, 39.06796973092215, 27.4489540713174, 47.21847765786307, 46.514607770102366, 46.07549898965018, 45.96314661843436, 47.55158472061157, 47.83631842476981, 47.46877956390381, 45.544965812138145, 48.52216815948486, 44.80868257795061, 39.880961077553884, 33.4720573425293, 32.6068502834865, 33.24503884996687, 35.14525304521833, 41.306005341666086, 44.002146107809885, 45.82811532701765, 48.48573180607387, 46.30279541015625, 47.57568107332502, 44.811951705387656, 42.56706517083304, 36.5296607698713, 32.91762931006295, 32.26893506731306, 32.7757887840271, 33.4370071547372, 33.76460429600307, 40.753178868974956, 43.882008280072895, 45.018768310546875, 48.64683273860386, 49.55110951832363, 47.97177703039986, 49.518220220293315, 47.035993644169395, 43.0350923538208, 37.20549815041678, 30.052859238215856, 22.322401182992117, 13.981966853141785, 6.381123534270695, 9.7355683360781, 12.058262535503932, 8.39955915723528, 8.111981902803693, 9.157907264573232, 3.301358176129205, 0.8274436539837292, 0.1310864652373961, 0.17646908573806286, 1.5690500225339616, 13.006337285041809, 26.68700245448521, 37.16899231501988, 26.03867472921099, 32.16749136788504, 45.71710395812988, 51.656563077654155, 36.05715894699097, 10.971675447055272, 0.35890816684280125, 0.022076618591589586, 0.020436032874775783, 0.02098601943414126, 0.05171179498678871, 0.05348565855196544, 0.03591496370998876, 0.018013852848006145, 0.06904269555317503, 0.026268848816731145, 0.019522083524082388, 0.04341495715613876, 0.02155067422427237, 0.05263059925554054, 0.05980912995125566, 0.06664212686674935, 0.04597517495442714, 0.029563763977161477, 0.11867011577955314, 0.04672968214643853, 0.048868044545607905, 0.04466373300445931, 0.018949203193187714, 0.044168473687022924, 0.030949766747653484, 0.07154228964022227, 0.004613728969291384, 0.03112562606111169, 0.06214504103575434, 0.034552774125976224, 0.018661171863121644, 0.03414018412253686, 0.030126581633729593, 0.03879105991550854, 0.0629518191729273, 0.054324806202203035, 0.07281788797783, 0.022263943450525403, 0.043576953999165974, 0.041223787769143067, 0.035836280789226294, 0.03533987135493329, 0.045841517126453776, 0.03969793893130762, 0.010865249787457287, 0.0498442494842623, 0.01846032719393926, 0.050587214795606475, 0.02309921327313142, 0.05572259173329387, 2.9651813123907362, 19.763449123927526, 42.5108368737357, 52.781834261757986, 39.321884700230186, 29.219891820635112, 31.82944761003767, 35.463984285082134, 32.35630519049508, 13.521967445101057, 2.7883902617863248, 0.19585335201450757, 0.06785968331886189, 0.6298157700470516, 3.04536634683609, 7.175641357898712, 5.592127791472843, 7.328340615545001, 4.173612662724086, 4.323670302118574, 8.124909894806997, 14.053027817181178, 26.292356933866227, 40.07143551962716, 47.606527600969585, 45.28538806097848, 41.91523034232003, 40.30322047642299, 40.17222956248692, 41.25386953353882, 43.74868971960885, 45.979669434683665, 48.021943024226594, 43.4844844681876, 39.379964692252024, 35.19184766496931, 35.726052965436665, 36.31626769474575, 37.32829366411482, 44.191640853881836, 43.72334269114903, 46.98582765034267, 47.8293320110866, 44.52906969615391, 46.08343383244106, 44.34117998395647, 46.98513977868216, 47.17580877031599, 49.36210809435163, 46.532742568424766, 45.692955493927, 40.1540287562779, 34.733270032065256, 33.57737118857247, 34.927145617348806, 34.123975549425396, 34.13484600612095, 38.63998849051339, 43.27301604407174, 47.04812519890921, 46.743630817958284, 49.184713636125835, 40.1783960887364, 31.516372203826904, 49.342719146183555, 44.05442087990897, 46.279904569898335, 46.05462312698364, 48.28622817993164, 47.558446066720144, 48.22045305797032, 45.17760760443551, 49.11874049050467, 45.91549587249756, 42.881683077131, 34.74754510607038, 34.3123585837228, 34.17753226416451, 37.28037541253226, 43.608294418879915, 47.17861236844744, 47.36134304319109, 50.141404151916504, 46.18164314542498, 49.514214583805625, 46.84277466365269, 45.962225982121055, 37.67858362197876, 34.54384824207851, 34.69574628557478, 35.688845361982075, 33.9504269191197, 37.24726029804775, 41.574337823050364, 45.6630539212908, 48.294548647744314, 50.9930031640189, 50.132725851876394, 48.77504437310355, 49.97725296020508, 48.63100126811436, 44.138438497270855, 40.71411262239729, 32.53730576378958, 22.23607850074768, 12.514835613114492, 9.132873773574829, 8.924174206597463, 7.479985918317523, 6.869927133832659, 8.730606079101562, 4.634086719581059, 3.534557742731912, 0.4699761526925223, 0.12920372055045196, 0.061288404145411084, 2.216293611696788, 14.185671533857073, 29.21224880218506, 43.992668764931814, 30.005729607173375, 39.185557569776265, 52.118732929229736, 57.01937729971749, 43.91642270769392, 13.62761219910213, 0.7131657632333892, 0.06916783098131418, 0.05447381588497332, 0.04899426223710179, 0.023219312275094644, 0.03452698979526758, 0.0364683836565486, 0.047401967857565196, 0.055979491876704354, 0.0095850645531235, 0.024490189705310122, 0.06133153183119638, 0.044535126869699786, 0.039474141118781905, 0.04856724657916597, 0.0479494811567877, 0.01601781147266073, 0.046288488499288044, 0.07095021355365004, 0.05246792048481958, 0.021326776327831403, 0.004348856463496174, 0.07633842620998621, 0.01396824895138187, 0.11495363020471164, 0.1673781821238143, 0.10961890646389552, 0.08330655337444373, 0.10736677409814936, 0.14559348965329783, 0.16107068343886308, 0.2084910124540329, 0.11894275115004607, 0.1114690068310925, 0.13031757649566444, 0.2266058889882905, 0.18410419246980123, 0.17002146957176073, 0.11476509246443, 0.15142597311309405, 0.13303958757647447, 0.1478032475071294, 0.08991437165864877, 0.1529457558478628, 0.1303640425737415, 0.1560380977711507, 0.07833484586860452, 0.08471956862402813, 0.10168020959411349, 0.19378147247646535, 3.599824343408857, 22.564460788454326, 49.1254837172372, 59.96352359226772, 45.7236248425075, 36.27142749513899, 38.62210035324097, 43.01020738056728, 37.130641732897075, 15.793510743549891, 3.849955584321703, 0.5929862463048526, 0.4254712036677769, 1.5667206389563424, 7.124169971261706, 11.684368678501674, 13.762363825525556, 12.380067484719412, 7.587610040392194, 3.8037704740251814, 7.066056106771741, 14.768621921539307, 26.95231420653207, 42.298472132001606, 49.7843918119158, 48.59500959941319, 44.56182697841099, 42.19433947971889, 41.793616022382466, 42.654890401022776, 46.08049474443708, 48.332999978746685, 51.59098250525338, 45.8399133682251, 41.59886148997715, 37.37474584579468, 38.24268354688372, 38.22622673852103, 40.28088896615164, 46.59970235824585, 45.62365763528006, 48.48120158059256, 47.185195786612375, 46.81354359218052, 45.920046942574636, 46.12672110966274, 47.460966314588276, 46.71949972425188, 50.18557732445853, 49.1120320047651, 47.41820362636021, 43.091796602521626, 37.14856808526175, 35.61889089856829, 37.77368361609322, 36.37885011945452, 35.19972692217146, 40.36169304166521, 45.51869119916643, 49.21989583969116, 49.14445229939052, 50.819214820861816, 43.17033209119524, 35.077820777893066, 46.22929389136178, 45.496269362313406, 45.69628715515137, 46.68504013334002, 50.18830449240548, 49.263415881565635, 48.144835812704905, 48.353392941611155, 53.003217765263145, 48.769819327763145, 44.75349998474121, 36.72838272367205, 35.77277960096087, 36.02207749230521, 39.244023186819895, 45.68390546526228, 50.067391940525596, 50.071567807878765, 51.59425163269043, 47.28428404671805, 51.937753200531006, 49.13307809829712, 47.91346427372524, 39.97324357713972, 36.335326603480745, 36.192610604422434, 37.190257276807515, 37.950626441410606, 38.16718094689505, 44.45691612788609, 48.78140892301287, 49.8414261000497, 52.394732747759136, 53.102563108716694, 49.199548040117534, 51.93605089187622, 50.27917998177664, 45.522095816476, 41.24801915032523, 33.82742643356323, 26.836176804133824, 17.92898746899196, 10.572611740657262, 16.20045804977417, 22.44492745399475, 14.845020839146205, 17.12344980239868, 18.393752472741262, 7.546684282166617, 2.5736876683575765, 0.532588215810912, 0.34728936744587763, 2.5283393817288533, 17.348184074674332, 34.01455184391567, 48.50646523066929, 36.47980049678257, 44.270985807691304, 59.5174492427281, 64.89280496324811, 49.34123223168509, 16.093403679983957, 0.8864564416663987, 0.1002567991880434, 0.0962626910103219, 0.12704783837710107, 0.14554212455238613, 0.13755625592810766, 0.1294194675449814, 0.19969935635370867, 0.12997900109205926, 0.15871520340442657, 0.12343746210847582, 0.12345642037689686, 0.1494654276009117, 0.13676832749375276, 0.14853770738201483, 0.1728448130722557, 0.09842832373189074, 0.08893817689801965, 0.29818142684442656, 0.1608316491224936, 0.18602142030639307, 0.15273136592337064, 0.16892359991158756, 0.1418599592787879], [0.033551958722195456, 0.007344851503148675, 0.022494299304006354, 0.034297543178711615, 0.02213300485163927, 0.023019858602700487, 0.039041228991534026, 0.023174086219764183, 0.0295950783682721, 0.028754319197365215, 0.028368677212191478, 0.03778640739619732, 0.01453610133778836, 0.07425230422190257, 0.038533243749822886, 0.013015244821352618, 0.022239292273297906, 0.03273050726524421, 0.0180871973945094, 0.0220574075688741, 0.01091310940682888, 0.04369246440806559, 0.0755468811839819, 0.048089737737817426, 0.038722602517477105, 0.03756160195916891, 0.843329515840326, 12.702053955623082, 35.928526946476524, 47.42705910546439, 41.80111312866211, 41.228303636823384, 24.633201803479874, 28.885336058480398, 30.18446854182652, 16.901734522410802, 4.765987847532545, 0.453317005187273, 0.052978233101644685, 0.4914609598261969, 2.2495348794119696, 6.3555867331368585, 3.5729745498725345, 4.814055051122393, 3.250751623085567, 3.5478333617959703, 3.337387625660215, 7.66017963205065, 22.334409407206945, 35.68302277156285, 43.05116353716169, 44.342760699135916, 40.64276851926531, 37.344267572675435, 35.904871804373606, 35.07638250078474, 37.5614196232387, 39.76753520965576, 40.610855443137034, 37.60979993002755, 34.76624270847866, 32.31545673097883, 31.965646198817662, 34.84089068004063, 40.18521921975272, 42.94603729248047, 44.64348915645054, 46.097271169934956, 44.578224727085654, 47.741329601832796, 47.86607755933489, 46.542039258139475, 45.89239658628191, 47.56896563938686, 44.75554970332554, 45.873671191079275, 44.245482444763184, 45.28908450262887, 37.95897817611694, 31.541389192853654, 31.68896198272705, 30.92572668620518, 32.954534666878835, 37.58977174758911, 42.154390811920166, 45.845458030700684, 43.778563499450684, 48.01084675107683, 39.641852719443186, 30.979241711752756, 46.869056224823, 47.29082577569144, 49.433163847242085, 46.55032498495919, 48.89769744873047, 47.30677536555699, 46.57550873075213, 46.080692768096924, 48.133687428065706, 43.78479255948748, 37.75947107587542, 30.76340981892177, 32.513185092381065, 32.373324802943635, 33.72009066173008, 37.81454249790737, 43.61283506665911, 42.241118226732524, 46.33603211811611, 47.48766476767403, 48.779303618839805, 46.67260980606079, 42.49344553266253, 37.98389441626412, 34.041628973824636, 33.93621785300118, 33.49559783935547, 33.225785391671316, 33.721455982753206, 36.85121645246233, 41.32137475694929, 45.88301999228341, 45.944886752537315, 50.101872376033235, 49.34957006999424, 51.31574698856899, 49.270662852696006, 44.853644371032715, 36.31717096056257, 25.655604907444545, 13.858101316860743, 6.90800586768559, 5.319990302835192, 4.201518365315028, 5.530637102467673, 8.732132077217102, 6.88529611485345, 2.2459229018007005, 4.137624033859797, 0.5779260258589471, 0.1537528596818447, 0.12962157598563603, 3.612882614135742, 16.51819917133876, 34.45673172814505, 36.126984868730815, 43.09224476133074, 29.33441550391061, 35.99614681516375, 50.36653273446219, 30.423413617270334, 7.2912337609699795, 0.283101990286793, 0.052441023356680355, 0.10766555342291083, 0.0351332811904805, 0.03917902588312115, 0.047601918556860516, 0.018076500289940407, 0.020515940551246916, 0.01989513698832265, 0.035658297661159716, 0.040802414129887304, 0.06129916571080685, 0.03958965152768152, 0.010500577078866107, 0.024477226293778846, 0.03152677596413663, 0.041776708992464204, 0.024739956749337058, 0.03032481563942773, 0.04834301111155322, 0.0456028899310955, 0.04078996301229511, 0.02207773647803281, 0.027351524381499206, 0.006169079661568893, 0.028441650260772024, 0.06758816753114973, 0.0508253161263253, 0.015027603267558982, 0.01631668070331216, 0.025149218538509946, 0.014868077988337194, 0.03188796354723828, 0.02376627256827695, 0.035074828791299036, 0.06242799013853073, 0.04372401628643274, 0.015684319992682764, 0.05544191233015486, 0.013775550095098359, 0.041072182689926455, 0.03526367187233908, 0.01215488022925066, 0.046235009761793275, 0.037199525495192835, 0.05014213653547423, 0.03157930135993021, 0.03342661973355072, 0.030197210343820707, 0.018654413654335907, 1.132174870797566, 14.715704441070557, 41.73372255052839, 53.436344146728516, 45.513417516435894, 43.64887189865112, 29.389396599360875, 33.71834666388375, 35.14925520760672, 18.655748197010585, 6.0149469545909335, 0.3219312381531511, 0.036103993388158936, 0.11480815229671341, 2.5119461928095137, 7.155881115368434, 7.2511144280433655, 7.712099177496774, 4.779592854636056, 5.340725898742676, 6.174985246998923, 11.33061156954084, 21.768112114497594, 38.82558182307652, 45.48710468837193, 47.557553223201204, 42.05474322182791, 39.54108646937779, 38.762123925345286, 37.30341216496059, 39.788873127528596, 41.937478474208284, 43.502528939928325, 40.84450946535383, 35.712253843035015, 33.51867280687605, 34.874551228114534, 36.85795273099627, 41.47557265417916, 44.20575959341866, 46.13913059234619, 47.44575323377337, 44.191408089229036, 48.84803172520229, 47.65659284591675, 48.48216043199812, 47.21722003391811, 46.743540491376606, 44.11512381689889, 47.54685994556972, 47.561499800000874, 45.90880823135376, 39.77074180330549, 33.51976019995553, 33.91566855566842, 32.94098220552717, 34.4794453893389, 39.51707696914673, 42.48812321254185, 46.83376979827881, 45.4933511189052, 48.53195817129952, 40.291908809116904, 32.938216822487966, 46.0240649495806, 47.71535376140049, 49.68536261149815, 49.20123645237514, 50.59238392966134, 48.33954170772007, 46.810990129198345, 45.963275160108296, 49.079111439841135, 45.10619749341692, 39.69750779015677, 32.279597078050884, 35.14398499897548, 34.563205923352925, 35.196061747414724, 40.245612961905344, 45.81558772495815, 45.84249809810093, 47.973830223083496, 48.400272437504356, 49.67662525177002, 48.47624404089791, 45.91969953264509, 41.02145576477051, 35.53202451978411, 35.94195086615426, 34.883830547332764, 36.09758356639317, 35.844689982278005, 39.35408265250069, 45.074857643672395, 47.6960586139134, 48.96388946260725, 51.48105158124651, 50.25288105010986, 52.959280831473215, 51.442381381988525, 46.81523200443813, 38.95077793938773, 29.75610167639596, 16.642478125435964, 9.908645357404437, 8.654815128871373, 6.244067711489541, 7.015408081667764, 8.057904073170253, 6.514274035181318, 4.9769351567540845, 3.694402354104178, 1.2693635778767722, 0.1447490392518895, 0.268660268081086, 3.6954715081623624, 16.989052534103394, 33.5722017288208, 39.883396421160015, 42.428031717027935, 34.71415901184082, 44.08064685549055, 56.048286642347065, 35.62348018373762, 9.32252311706543, 0.3299255206116608, 0.03800351146076407, 0.05958471806453807, 0.020924186234229376, 0.0554516832344234, 0.042157784436962435, 0.012398569295848054, 0.07253665556865078, 0.027167926376153315, 0.015218956928168024, 0.06483128653573138, 0.02449105823013399, 0.04463730067280786, 0.027950328142781342, 0.05493681425494807, 0.07725206004189593, 0.03620849795905607, 0.006960511032957584, 0.052247515347387107, 0.06004134499068771, 0.022318546859813587, 0.0500852244107851, 0.015971233436305608, 0.020531925139948726, 0.11217297334223986, 0.10190908624125378, 0.11293289863637515, 0.27317266166210175, 0.1270331141671964, 0.16196356766990253, 0.20213468638913973, 0.13259559497237206, 0.18181922579450266, 0.07437449480806078, 0.16597024910151958, 0.10223164143306868, 0.1269621801163469, 0.20273354782589845, 0.13303059020212718, 0.12442690187266894, 0.11600976996123791, 0.07277549310986485, 0.07201390540493385, 0.18448923395148345, 0.09867260312395436, 0.15784910773592337, 0.18016191758215427, 0.14476252852806024, 0.10511969003294196, 0.12662406611655438, 1.7619768530130386, 17.577307871409825, 46.078455448150635, 58.878979274204795, 52.18871865953718, 50.87339687347412, 34.109912395477295, 41.56546497344971, 39.85809108189174, 22.518086774008616, 6.88195663690567, 0.930437507373946, 0.10269913849021707, 2.1711496455328803, 6.042714561734881, 12.52213556425912, 11.648413487843104, 12.145670005253383, 8.181674940245491, 7.6623561552592685, 6.854722738265991, 9.431350146021162, 25.6375378540584, 41.25163221359253, 48.95342547552926, 49.481485094342915, 45.293906552451, 41.82533802304949, 40.98909452983311, 39.634921891348704, 41.6885974747794, 43.31843294416155, 45.11928789956229, 41.19377108982631, 38.1945811680385, 35.699125221797395, 36.05142668315342, 39.02963999339512, 44.13549940926688, 46.69471549987793, 48.345649174281526, 48.52791779381888, 45.57034758159092, 51.26811708722796, 50.07943664278303, 49.35737637111119, 48.66838952473232, 47.70010246549334, 45.58576216016497, 47.59703288759504, 48.50335243770054, 48.728477546146934, 42.98824412482125, 34.15514516830444, 35.42548779078892, 33.40898854391915, 36.30550146102905, 40.716957909720286, 45.4093473979405, 49.726263182503835, 46.80046360833304, 50.293170179639546, 42.510826451437815, 35.63274213245937, 46.719930512564524, 49.11804567064558, 51.010165214538574, 51.11692081178938, 51.909897872379844, 50.372258050101145, 49.70473418916975, 48.23608997889927, 52.07708542687552, 48.070517880576, 41.02738952636719, 34.13924421582903, 36.03731141771589, 37.06403282710484, 36.85090378352574, 41.44244711739676, 49.249731404440745, 47.37338774544852, 50.30873761858259, 49.30599791663033, 51.56124768938337, 51.629920210157124, 46.6349436214992, 42.31398745945522, 36.79718378611973, 37.04429646900722, 37.15491526467459, 37.72031797681536, 37.92021417617798, 40.26259783336094, 45.62123271397182, 50.24722521645682, 50.20042909894671, 52.607302461351665, 52.7064254624503, 55.450029373168945, 53.17113488061087, 47.70945821489607, 40.482612541743684, 29.65303209849766, 16.46575764247349, 10.376305154391698, 7.991996935435703, 8.478996174676077, 8.94592033113752, 18.76646774155753, 14.672180925096784, 8.53129700251988, 10.02342004435403, 1.2943879493645258, 0.5942412103925432, 0.3922267332673073, 5.50494874375207, 21.254723617008754, 43.02897793906075, 48.380678517477854, 54.853015831538606, 39.89034114565168, 50.86307185036795, 62.42574283054897, 42.40302862439837, 11.049559542110988, 0.5710710851209504, 0.08554278087935277, 0.20429083997649805, 0.1901658714881965, 0.1302286476961204, 0.11627699062228203, 0.054630001075565815, 0.1590211819857359, 0.07531416402863604, 0.18953429109283856, 0.162164943292737, 0.10211332528186695, 0.12549655804676668, 0.17984729446470737, 0.08359806558915547, 0.11302291309194905, 0.1369368213095835, 0.10175210716468946, 0.10843913084162132, 0.11675660631486348, 0.16122198317732128, 0.1447142032640321, 0.11482229296650205, 0.11650184355676174], [0.0358153920886772, 0.03562640990795834, 0.01788044098897704, 0.041839100287428925, 0.029972126707434654, 0.020731331314891577, 0.047825506023530445, 0.04267965929050531, 0.012454034444609923, 0.005662743684037456, 0.04222096283254879, 0.013911188397157406, 0.01566291051650686, 0.03664110474554556, 0.10477253794670105, 0.013401273571486984, 0.017084811182160462, 0.02918578265234828, 0.033103796520403454, 0.03302648084770356, 0.008282753988169134, 0.03916408454201051, 0.02131710890015321, 0.021550049972055212, 0.03481528575399092, 0.0484728521800467, 0.49051790471587864, 6.8259862916810174, 29.17195619855608, 43.8726282119751, 47.9024270602635, 32.73652451378958, 25.563449212482997, 22.510138034820557, 31.09770154953003, 23.92729435648237, 7.408073799950736, 1.177390273128237, 0.0995798044438873, 0.12344537382679326, 1.812520438006946, 4.845998525619507, 4.012429654598236, 7.083371886185237, 2.667510496718543, 3.839723059109279, 5.7893146276474, 8.272612963403974, 16.375488383429392, 34.13840000970023, 43.33899961199079, 45.53768062591553, 42.16784599849156, 40.449931689671104, 35.480430671146934, 35.907237665993826, 34.199763025556294, 35.54511145183018, 35.64518983023507, 35.322727407727925, 34.23838458742414, 32.93406874792916, 32.01278625215803, 38.15382650920323, 43.208460330963135, 45.149790491376606, 47.322200366428916, 43.25526687077114, 45.917858260018484, 44.817604064941406, 44.482099873679026, 46.30374731336321, 46.06047698429653, 48.73660693849836, 46.13474975313459, 46.01006085532052, 46.20508636747088, 45.04025214059012, 41.56710474831717, 35.24307325908116, 32.34100873129708, 33.22949225561959, 32.48476696014404, 36.42818580354963, 40.07634442193167, 43.03617279870169, 43.84121193204607, 46.70954295567104, 41.211881569453645, 30.316915103367396, 49.165960448128835, 46.05520677566528, 45.58745404652187, 43.629288400922505, 44.68119355610439, 46.25209787913731, 47.8256425176348, 47.0515958241054, 45.350301606314524, 43.614453996930806, 34.56557525907244, 32.76241002764021, 33.8861734526498, 34.1669362613133, 35.88217551367623, 37.714286940438406, 43.560720103127615, 40.876061235155376, 47.83683953966413, 46.69265535899571, 46.88552345548357, 45.90525075367519, 44.17078236171177, 40.86394010271345, 35.06369856425694, 33.747334548405235, 33.73661347797939, 33.34053141730172, 32.981709071568076, 35.93698985236031, 37.480004106249126, 41.33309636797224, 42.37002468109131, 43.894817284175325, 46.51723766326904, 48.05071898869106, 49.163688387189595, 43.94655704498291, 33.530693190438406, 22.922567469733103, 10.819306663104467, 4.67238084759031, 6.9328760760171075, 4.543558640139444, 4.441427937575749, 3.2244296755109514, 3.2453604723726, 2.07426917552948, 1.7101166929517473, 0.7470033275229591, 0.06885630198355232, 0.29319677289043156, 3.756566149847848, 15.334537063326154, 33.7682694707598, 42.37360995156424, 29.397557258605957, 30.91186155591692, 39.80021953582764, 48.57590900148664, 29.529517446245464, 4.825195184775761, 0.043744406263743124, 0.0247950096880751, 0.060946395354611535, 0.04830589185335806, 0.06740771114294018, 0.09027822927704879, 0.04453913701166, 0.04831954397793327, 0.044536395730184655, 0.04201623863939728, 0.05467547309984054, 0.03561656775751284, 0.05441226936610682, 0.07855262168283973, 0.05061702623165079, 0.03064233610140426, 0.05161532087783728, 0.019770897226408124, 0.03635908862841981, 0.01751642900386027, 0.05566076701506972, 0.06311564466782979, 0.059255472517439296, 0.03314396918618253, 0.04081099759787321, 0.03249618537457926, 0.01681659646731402, 0.07278877204017979, 0.02368491282686591, 0.013914764276705682, 0.030571144207247665, 0.06983352811740977, 0.01551960052789322, 0.018480930909780518, 0.08788284459816557, 0.02995184190305216, 0.022159174250970994, 0.040910657428737195, 0.042204925657383034, 0.016940973632569824, 0.01599341644240277, 0.06053831760904618, 0.05699597126139062, 0.04432792263105512, 0.01829290546343795, 0.017891144878896217, 0.02915473628257002, 0.03151387022808194, 0.05627217795699835, 0.025275751748787503, 0.5729062237909862, 9.340754321643285, 34.827199254717144, 50.50357552937099, 51.88902200971331, 37.909802300589426, 28.146244015012467, 31.68015514101301, 34.887742383139475, 26.258427143096924, 7.709799323763166, 1.2374420336314609, 0.10990672066275563, 0.290573420801333, 1.3536342616592134, 3.8375621693474904, 5.081413916179112, 7.939609255109515, 6.313192733696528, 4.895499229431152, 4.56809880903789, 9.601614883967809, 19.48053584780012, 37.28145933151245, 45.498951366969514, 46.572823251996724, 43.97118146078927, 41.590374265398296, 37.70706081390381, 38.666860648563926, 35.5013621194022, 37.36506005695888, 38.21334477833339, 38.002831731523784, 35.63163389478411, 34.371755259377615, 33.69945451191494, 39.88008213043213, 44.133199555533274, 47.272798674447195, 47.80644464492798, 43.903717926570344, 47.10671935762678, 46.52623210634504, 46.28639071328299, 48.08505003792899, 47.26978663035801, 49.88512332098824, 46.12746456691197, 47.08060802732195, 49.724428858075825, 47.404470511845176, 42.758126735687256, 37.07628597532, 34.35274498803275, 34.82872091020857, 33.84893805640084, 38.05238628387451, 42.5033779825483, 43.780689648219514, 46.55768312726702, 48.94874586377825, 41.801641191755024, 32.10535710198538, 50.06592239652361, 47.13952875137329, 48.31539671761649, 46.804010663713726, 47.17804956436157, 46.68568284170968, 50.302446024758474, 48.680065972464426, 47.61659206662859, 45.072054045540945, 35.79270703451974, 33.6232397215707, 34.22704512732369, 35.166983536311555, 38.32146222250802, 39.637391975947786, 46.17431974411011, 42.273851190294536, 50.91880335126604, 47.49507849557059, 48.08487980706351, 47.46637896129063, 45.932452951158794, 42.46707364491054, 36.45001704352242, 34.696052006312776, 35.82350492477417, 35.417542525700156, 35.041676248822895, 36.73560537610735, 40.04261091777256, 44.695003100803916, 45.316866874694824, 46.95727055413382, 47.326838288988384, 49.46838426589966, 51.586247307913645, 45.31627280371529, 34.927461760384695, 25.926699297768728, 14.719133377075195, 5.4391888209751675, 5.687948661191123, 6.784292323248727, 7.915463396481105, 6.270781798022134, 6.701035099370139, 5.586866268089839, 2.2625099888869693, 1.0125010524477278, 0.23155173073921884, 0.2707797943481377, 4.496860665934427, 18.131492716925486, 39.97703034537179, 44.625528063092915, 36.6016024180821, 33.47245338984898, 45.025799887520925, 54.600330693381174, 35.48877893175398, 6.159261473587581, 0.1226706225425005, 0.013451264638985907, 0.04485218253518854, 0.04337938156511102, 0.01679000976894583, 0.03891045833006501, 0.047562590667179654, 0.0755175616858261, 0.07407729646989278, 0.031106850997145687, 0.06724170755062785, 0.07214070324386869, 0.09404449218085834, 0.0794474600947329, 0.07007776001202208, 0.032068989904863496, 0.06104265911770718, 0.04147246406812753, 0.048797161384884796, 0.04330209303381188, 0.05203667076836739, 0.013625889018710171, 0.04387894957991583, 0.06733702815004758, 0.19493701761322363, 0.11067079859120504, 0.10259473230689764, 0.14400968035416944, 0.09259537208293166, 0.09808788914233446, 0.16602379908519133, 0.1234972681850195, 0.09539817632841212, 0.07738866949720041, 0.16655978746712208, 0.09661934258682386, 0.09133813490292855, 0.17622896576566355, 0.13671685382723808, 0.1405514044953244, 0.11696007182555539, 0.1199507692030498, 0.12350467778742313, 0.14570483724985803, 0.09804225087698017, 0.21256119119269506, 0.12602130988878862, 0.12467631777482373, 0.13204888573714665, 0.12369917306516852, 0.8371538700801986, 10.53516355582646, 39.84278072629656, 55.82696567262922, 59.903782980782644, 42.0717385155814, 34.264419487544465, 33.354976722172324, 40.82512051718575, 30.707466397966655, 10.27589760507856, 1.6714737436601093, 0.44936103746294975, 0.5292396726352828, 4.990228363445826, 12.996839966092791, 12.338272333145142, 14.411955254418508, 8.931693025997706, 9.924051250730242, 9.878270438739232, 10.742080909865242, 19.69679852894374, 39.617256096431184, 47.73770611626761, 49.602745056152344, 46.69384697505406, 45.01881347383772, 40.08672850472586, 40.67942721503121, 37.68031372342791, 38.82716948645455, 40.78912884848458, 39.0730801309858, 39.107643944876536, 35.918083803994314, 34.9821788242885, 42.238512652260916, 46.599664143153596, 48.87520612989153, 50.299326283591135, 45.56665113994053, 48.34701449530465, 46.678762435913086, 48.04675504139492, 51.75155537469046, 48.7476441519601, 51.830681460244314, 46.78768934522356, 46.729140349796836, 49.34281642096383, 50.38517822538103, 44.7282259123666, 39.47531482151577, 36.118907587868826, 37.686966623578755, 36.118726934705464, 39.80356856754848, 45.052355902535574, 46.31016397476196, 47.83957712990897, 48.72576080049787, 44.63050644738333, 34.472695214407786, 50.87960161481585, 49.22359922954014, 49.70762116568429, 48.081895555768696, 48.557336466653005, 50.29710980824062, 51.21262877328055, 49.54897294725691, 48.64947305406843, 48.28730862481253, 38.11211994716099, 35.76757192611694, 37.26344265256609, 37.360995360783164, 38.99190085274832, 41.805379322596956, 47.952287333352224, 44.74776424680437, 53.77052470615932, 48.090219497680664, 48.81571217945644, 50.35134049824306, 48.61700759615217, 44.98599713189261, 38.4439138003758, 36.01986796515328, 36.34557172230312, 36.516476563044954, 37.02106169291905, 39.691938808986116, 41.86117683138166, 46.01194381713867, 47.13261876787458, 49.01436812537057, 49.41677304676601, 51.374344621385845, 54.90909126826695, 48.02796711240496, 38.578861713409424, 26.864897183009557, 15.338669504438128, 8.383284739085607, 11.467252237456185, 9.428999049322945, 10.354170799255371, 8.629211885588509, 8.609049950327192, 9.349304948534284, 5.929636972291129, 3.2794728704861233, 0.5384605292763028, 0.6179560092943055, 5.110386601516178, 21.17778968811035, 42.21583373206002, 52.11851406097412, 40.780936922345845, 41.484983989170615, 52.58739587238857, 61.995864731924875, 39.813886642456055, 7.540406584739685, 0.15814028068312577, 0.0928632780643446, 0.16733547512974056, 0.2531343011983803, 0.1565477725650583, 0.15832820774189063, 0.15226969069668225, 0.2807919585279056, 0.18596621469727584, 0.18282556108066014, 0.18588708394340106, 0.1568350371505533, 0.2088799894388233, 0.23637519191418374, 0.12816724473876612, 0.07035922990845782, 0.17161068000963756, 0.14101134267236504, 0.18388256936201028, 0.09636065789631434, 0.11270280741155148, 0.08759515932095902, 0.13916131694402012, 0.1490590801196439], [0.018476591678336263, 0.03065853951764958, 0.032304716363017044, 0.0060884472248809674, 0.021078658123899783, 0.06196364826921906, 0.04055726960567491, 0.05258500509496246, 0.004293926509230265, 0.02782638693627502, 0.019630091032013297, 0.0411431472748518, 0.029528846565101827, 0.03407058000032391, 0.03794327451448355, 0.04005545224728329, 0.014599454456142016, 0.043512364250740836, 0.03443206613883376, 0.0343806365770953, 0.0972934535571507, 0.07707290644092218, 0.009368947757008885, 0.008198855677619576, 0.012117590489132064, 0.03664975267435823, 0.13746484369039536, 3.7237115928104947, 23.291688782828196, 45.33288247244698, 49.692262172698975, 44.46365588051932, 33.74126877103533, 29.664979525974818, 30.676647663116455, 24.57192737715585, 10.85606871332441, 1.8148742488452365, 0.13424371582056793, 0.060050152375229766, 0.44140345017824856, 3.1182724918637956, 4.817886548382895, 6.371262737682887, 5.196504311902182, 3.602120940174375, 2.2219207840306416, 7.285590520926884, 14.70278947693961, 30.875998428889684, 43.41560002735683, 46.07244873046875, 45.42314999444144, 42.5240592956543, 40.305700983319966, 35.64160803386143, 34.624621050698416, 34.34516102927071, 33.249864373888286, 34.0959221976144, 32.51787860052926, 34.231627464294434, 36.800918442862375, 41.23575210571289, 41.39401469911848, 44.72403267451695, 44.0968986919948, 45.78547075816563, 45.742256437029155, 43.440384251730784, 44.147116797310964, 42.27309731074742, 45.09381232942854, 44.77582802091326, 46.86378254209246, 45.333813531058176, 46.21266337803432, 45.20120716094971, 43.81010832105364, 39.77755103792463, 34.632545471191406, 34.00924342019217, 32.940916197640554, 36.80541740145002, 37.88789463043213, 44.46687637056623, 44.01461117608206, 49.698890754154746, 43.05306734357561, 30.341612475258962, 49.050794056483674, 42.81354556764875, 44.558537006378174, 42.167192867824006, 43.23710775375366, 42.67510618482317, 44.0458676474435, 44.26631314413888, 43.783187525612966, 38.50690616880144, 32.159692014966694, 31.184609617505753, 32.74947943006243, 35.13306243079049, 36.63086823054722, 39.54080506733486, 41.85034458977835, 44.213593687329976, 47.44842481613159, 47.70411157608032, 48.94049140385219, 48.39168446404593, 44.86478233337402, 40.91303607395717, 37.66933209555489, 36.32695402417864, 35.254287651606965, 35.163363524845664, 33.646158354622976, 35.4870731489999, 34.15982478005545, 37.69003772735596, 39.20948716572353, 41.74060474123274, 44.117302077157156, 45.6428416115897, 45.16484376362392, 44.522048541477744, 30.93509633200509, 21.422718899590627, 9.673004150390625, 4.028848247868674, 4.241248599120548, 4.550089078290122, 8.400755984442574, 4.477528606142316, 7.675308465957642, 4.848439514636993, 1.4812923201492854, 0.9336548490183694, 0.2962072699197701, 0.5204914563468525, 4.939793995448521, 16.47014716693333, 30.15133258274623, 34.5379318509783, 28.647723300116404, 37.853726863861084, 44.530712945120676, 46.34269891466413, 22.3298305443355, 2.2788808132920946, 0.022499915877623216, 0.01073647486711187, 0.017550611901762228, 0.055781227336930375, 0.04512255159871919, 0.03614126531673329, 0.06502059780593429, 0.038392390057976754, 0.05026191492964115, 0.02427565728846405, 0.030934954328196387, 0.038265446334012916, 0.02827468145239566, 0.04117861769295164, 0.058466716270361624, 0.024038271812189902, 0.03110156860202551, 0.03604885223986847, 0.06545119612876858, 0.06980846981917109, 0.05988614367587226, 0.0944895568702902, 0.03237288199099047, 0.009008016320876777, 0.018279236375487277, 0.043471394306314845, 0.03636244059141193, 0.022170619440398047, 0.024168599729559252, 0.041180368313299756, 0.03303058598456638, 0.06402229637439762, 0.03759125054680875, 0.056385669724217484, 0.035410194724266014, 0.06769540320549693, 0.011476900761148759, 0.009424933681397565, 0.028991667354213338, 0.05144335296271103, 0.015376387230519737, 0.011367727869323321, 0.029414018083895956, 0.025935204666373984, 0.019721727186281766, 0.03004489280283451, 0.024020609545654485, 0.03737312189436384, 0.048186262736895254, 0.05334852662469659, 0.19064366870692798, 5.022219172545841, 28.590657745088848, 50.16731398446219, 54.50318445478167, 44.760475976126536, 36.575449398585725, 30.86757026399885, 35.9380772454398, 30.725691522870743, 11.481553367206029, 2.392802608864648, 0.1477648424250739, 0.22843340092471667, 0.5451617954032761, 2.4491229695933203, 6.353321186133793, 8.294745581490652, 7.227283409663609, 4.587803900241852, 4.897651868207114, 8.249083757400513, 15.907690490995135, 34.064471176692415, 45.378292424338206, 48.4923986026219, 48.36179678780692, 44.27738162449428, 42.43902724129813, 37.97416346413748, 36.584892000470845, 36.329031535557334, 34.74872282573155, 35.839860984257285, 34.053298473358154, 35.439957414354595, 36.770235197884695, 42.77610172544207, 43.91463007245745, 47.42850085667202, 44.87690346581595, 46.32583563668387, 47.604693276541575, 45.18415975570679, 44.90842396872384, 44.89770984649658, 47.36179467609951, 48.03419269834246, 48.20979104723249, 45.41916520254952, 47.241875716618125, 47.43885367257254, 45.88032756532942, 40.50283874784197, 35.93689605167934, 34.22836528505598, 33.90347099304199, 38.59361273901803, 39.96806369509016, 46.31869636263166, 46.89912108012608, 50.58742291586739, 44.05816943304879, 32.43570225579398, 49.99943855830601, 45.394721439906526, 45.980861050742014, 43.91113860266549, 45.986690589359824, 45.473989963531494, 47.01521158218384, 46.37447302682059, 45.002474784851074, 40.97329085213797, 32.33901112420218, 32.5878712790353, 34.872605732509065, 36.936328411102295, 38.764635699135916, 42.030803203582764, 44.01156439099993, 45.22690159933907, 48.51166248321533, 48.453054428100586, 49.76455470493862, 49.78568765095302, 46.38235228402274, 44.14445216315133, 37.70479570116316, 38.03312240328108, 35.87831578935896, 36.419288635253906, 34.63760723386492, 35.90159920283726, 35.5825309753418, 38.90536451339722, 41.75797871180943, 44.63839612688337, 46.63812242235456, 48.6194429397583, 48.57049288068499, 45.47866610118321, 34.87768486567906, 23.888608523777553, 13.78684493473598, 7.204094665391104, 3.990319618156978, 6.3693102938788275, 8.327701755932399, 6.8596212182726175, 8.18922676358904, 3.8392466732433865, 2.87814622265952, 0.7992582321166992, 0.07637919937925679, 0.6588594572884696, 4.419463813304901, 19.126915965761455, 36.03613369805472, 41.03553281511579, 30.962718895503453, 40.12395000457764, 48.982621806008474, 54.136660030909944, 26.99985899244036, 3.200419306755066, 0.04095407009923032, 0.038053648413292, 0.018120700061055164, 0.08318527202521052, 0.03896976229069488, 0.04289094491728714, 0.025674806674942374, 0.038519754473652155, 0.031414013622062545, 0.015280062399272407, 0.08080425193267209, 0.007605479348317853, 0.014558995109317558, 0.04123213714254754, 0.02958391307454024, 0.03500509914010763, 0.05648436603535499, 0.032362876992140494, 0.07039488013833761, 0.018423114637179033, 0.01088643619524581, 0.05500576359086803, 0.03686504505042519, 0.02698510529340378, 0.09071777069142886, 0.10044065503669636, 0.09675805550068617, 0.14779197025511945, 0.1451967502278941, 0.18240353944046156, 0.12505111337772437, 0.11839028793786253, 0.04833129281178117, 0.13296623794095858, 0.19437924825719424, 0.08944456758243696, 0.07058310575251069, 0.1248468743371112, 0.0961745764528002, 0.13925487335239137, 0.08970443970922913, 0.09972889215818473, 0.07058074445064579, 0.11892216439758029, 0.14854844180600985, 0.09303705766797066, 0.0807497248585735, 0.1022186746288623, 0.13202707762164728, 0.15857705367462976, 0.34168662237269537, 5.557017241205488, 31.8962128502982, 56.9766389301845, 61.91411917550223, 54.864883354731965, 45.128317083631245, 39.61301074709211, 41.48324693952288, 32.691979612622944, 13.96738953249795, 3.3117409561361586, 0.2980990526931626, 0.6490335102592195, 3.3859587907791138, 6.97095524413245, 13.616094691412789, 15.278228861945015, 12.185103637831551, 9.491495490074158, 4.850975172860282, 10.495511054992676, 19.186378649302892, 35.46260854176113, 48.53707899366106, 50.469053404671804, 50.1775278363909, 47.39205060686384, 46.30678367614746, 40.14237315314156, 38.066925389426096, 38.18332161222185, 36.32928514480591, 38.47732073920113, 35.196798256465364, 36.949860027858186, 38.98018618992397, 45.269403730119976, 44.643732343401226, 49.99233749934605, 45.54719270978655, 47.8944296836853, 50.412783418382915, 47.90708235331944, 46.7404659135001, 46.16775369644165, 49.297795568193706, 48.671616962977815, 49.6037004334586, 46.149792603084016, 48.29691103526524, 49.57727296011788, 48.52945681980678, 44.75254808153425, 38.63338075365339, 37.058953693934846, 35.64944560187203, 40.019459520067485, 41.56479794638497, 48.08764866420201, 48.05963352748326, 53.13438933236258, 45.68032019478934, 35.142115933554514, 50.39386347361973, 48.07601043156215, 48.116810253688264, 46.099619661058696, 47.83195495605469, 47.24026026044573, 47.54698153904506, 48.21643352508545, 47.10619476863316, 43.07619094848633, 34.82383285249983, 34.22710418701172, 35.8477715083531, 39.02092000416347, 40.51140240260533, 44.21821771349226, 45.608031136649, 48.26210403442383, 50.18349633898054, 49.49463108607701, 51.09059061322893, 52.17424556187221, 48.89622443062918, 45.50302301134382, 40.87218761444092, 40.55770172391619, 38.006931168692454, 38.553222860608784, 36.71364212036133, 39.09833335876465, 37.52857548849923, 40.330617223467144, 43.49188082558768, 47.099649565560476, 47.807796069553916, 50.547894614083425, 50.047839709690635, 48.694539070129395, 36.95274005617414, 26.46119121142796, 12.890323213168553, 6.490030033247812, 8.903161117008754, 10.455287064824786, 14.27665558883122, 11.820350136075701, 17.647903306143625, 11.316579682486397, 5.026226546083178, 1.8527818833078658, 0.5030143484473228, 0.9640995753662926, 6.47076050724302, 21.818159988948278, 40.07143551962716, 47.26760837009975, 39.55701868874686, 51.30369186401367, 57.09887163979666, 58.9034230368478, 31.412590435573033, 4.340946563652583, 0.10955382817025695, 0.10010675473936967, 0.07964080186294657, 0.1716821976006031, 0.20062430814972945, 0.1906510375972305, 0.13988528666751726, 0.15533182424093994, 0.13082332935716423, 0.049365366609500985, 0.1388811498348202, 0.08089077193289995, 0.14508468338421412, 0.13718521940921033, 0.09146543485777718, 0.11222266924700566, 0.10800281925393002, 0.117953786360366, 0.22781009865658625, 0.11993255732314927, 0.11760751636964933, 0.15553193778863975, 0.09423975420317479, 0.14922791320298398], [0.02149119893355029, 0.06491907539644412, 0.04333533785705056, 0.02875307747828109, 0.053614047555519004, 0.01795807896581079, 0.053794144320168664, 0.08866548045937504, 0.020130340974511843, 0.04968063094254051, 0.010164891386271586, 0.02166562993079424, 0.04744420666247606, 0.03401247026132686, 0.03745542140677571, 0.04326460736670664, 0.08103911325867687, 0.03409051875184689, 0.10310659198356525, 0.008004329017629581, 0.1421685977173703, 0.05387592136061617, 0.019278684531205466, 0.03349828999489546, 0.01725513704254159, 0.062195612250694206, 0.015559844439849257, 1.6197014131716319, 13.042190858295985, 37.963539668491904, 47.79700551714216, 41.768359320504324, 30.72667121887207, 33.449235984257285, 28.934296539851598, 28.01664968899318, 12.438263859067645, 4.438038085188184, 0.19141958707145282, 0.24202502731766018, 0.6461932169539588, 0.8591032294290406, 2.66809001990727, 6.2174330949783325, 6.077243634632655, 1.6892544009855814, 4.119941302708217, 3.7153655035155158, 8.526203972952706, 22.861183609281266, 40.84273420061384, 46.88472441264561, 46.340965339115684, 44.53274529320853, 41.886562074933735, 42.199700014931814, 40.490255560193745, 37.475560733250205, 36.95028386797224, 36.45884820393154, 37.14388847351074, 37.74190255573818, 39.806907176971436, 41.92276218959263, 44.17122704642159, 45.26464768818447, 44.66799545288086, 45.67122847693307, 44.4003404208592, 41.52365071432931, 40.86649009159633, 39.685678482055664, 41.47304698399135, 44.90088169915335, 48.90723385129656, 47.092822960444856, 45.79761273520333, 48.02049779891968, 46.70889329910278, 43.112839221954346, 39.3109586579459, 34.82094587598528, 34.388503892081125, 34.03717517852783, 39.74588809694563, 44.41068628856114, 46.005832876477925, 45.72355536052159, 45.075312750680105, 32.83005768912179, 49.555066517421174, 45.18569878169468, 43.64397341864449, 39.23263508932931, 38.83103963306972, 37.93031338282994, 40.1589480808803, 38.02079977308001, 35.578042439052034, 31.75513662610735, 32.056799616132466, 30.84109762736729, 32.98859821047102, 32.62246983391898, 35.10752780096871, 41.15648010798863, 44.59699528557913, 46.36743450164795, 48.10911512374878, 43.33051586151123, 48.782374722617014, 46.644768374306814, 43.96075221470424, 42.58730527332851, 39.377942766462056, 35.10076372964041, 35.2692540713719, 33.84173624856131, 34.41985763822283, 33.34804589407784, 34.75162369864327, 34.763067381722585, 37.71402290889195, 39.30044255937849, 41.023852893284385, 44.87729603903634, 46.95269863946097, 41.50047499792916, 31.957301412309917, 18.748077596936906, 9.696371810776846, 3.7424361194883073, 1.458443711910929, 5.7574606112071445, 7.666906356811523, 4.694107864584241, 5.065627174718039, 2.849572624479021, 1.6408593292747224, 0.23410264242972645, 0.0509563989139029, 0.7333180904388428, 5.12892439535686, 21.813810416630336, 35.23149061203003, 37.9312652860369, 41.51904058456421, 49.34526913506644, 51.65934583118984, 43.111369677952354, 19.91858329091753, 1.4097169722829546, 0.0740954540669918, 0.02387118086751018, 0.040182507929525206, 0.0530795858773802, 0.005174756565663431, 0.014987812277727892, 0.05106516807739224, 0.017163589097825543, 0.025390853340338384, 0.03843080531805754, 0.04442038320537124, 0.1281368327992303, 0.05093734904325434, 0.027907658468133638, 0.031611511417265446, 0.060395737045577595, 0.03686129614444716, 0.021772273583337665, 0.046787330481622896, 0.004693977609609387, 0.037532591194446595, 0.012505545430550618, 0.015088773199490138, 0.06722019799053669, 0.029436413132186447, 0.08172516644533191, 0.026930652858157243, 0.0351963883398899, 0.016059873858466744, 0.04391080340636628, 0.0406063242948481, 0.03405984557632889, 0.022533454167257463, 0.02035619135546897, 0.03545907638700945, 0.0075216081791690415, 0.02210552418338401, 0.017881231482273767, 0.042981220608843226, 0.03089461542133774, 0.03291562858170696, 0.025435027666389942, 0.11560787366969244, 0.014008138328790665, 0.0520997711324266, 0.02979608079684632, 0.02471966346326683, 0.04726733972451516, 0.062404254983578406, 0.03171951722885881, 0.03117066721564957, 2.2054394398416792, 17.70613615853446, 44.26986367361886, 53.286930084228516, 46.99451289858137, 37.48794937133789, 39.36550201688494, 34.31619051524571, 31.61318145479475, 14.993066106523786, 3.7240802815982272, 0.34444543719291687, 0.047862883125032694, 0.4632346087268421, 2.0883681561265672, 5.009641196046557, 5.561747661658695, 5.974105009010859, 6.4626041906220575, 6.475821835654123, 7.706174101148333, 13.794115356036595, 27.919748374394008, 43.88412400654384, 49.088415077754426, 47.95067535127912, 46.75388288497925, 43.78103010995047, 43.74971110480172, 42.07627221516201, 39.37322841371809, 37.62042025157383, 37.83390365328108, 38.55510582242693, 39.21677582604544, 41.58094208581107, 44.338928767613, 45.806947640010286, 47.40318856920515, 46.16466869626726, 46.353020463671, 45.88057770047869, 44.59305565697806, 43.34416559764317, 41.298970290592735, 44.018505641392295, 46.31461429595947, 49.76203945704869, 48.044076510838096, 46.735845361437114, 50.740759236471995, 47.13272646495274, 44.85595464706421, 39.46938453401838, 37.01907103402274, 35.200279303959434, 35.61122356142317, 42.17621162959507, 46.15387119565691, 47.00284726279122, 47.816286768232075, 45.46067721503121, 34.60225827353341, 51.210533891405376, 46.58493396214077, 44.96349539075579, 41.46565062659127, 40.88857841491699, 40.778491156441824, 42.479184355054585, 40.89157656260899, 38.95604814801897, 34.265621525900706, 34.013113566807334, 32.73437752042498, 34.79167658942086, 33.916481494903564, 35.494049140385215, 43.05082654953003, 47.201857566833496, 46.8688964162554, 49.80451032093593, 45.81727613721575, 49.92110456739153, 49.30178036008562, 45.37672560555594, 44.38720137732369, 39.714252948760986, 36.62735939025879, 37.07437869480678, 35.55088540485927, 36.190956933157786, 35.868348598480225, 36.917418888636995, 36.914778573172434, 39.669576031821116, 42.117464610508506, 44.390859603881836, 47.56293460300991, 47.58344568525042, 44.13598925726754, 33.666283811841694, 20.472651754106792, 12.634020669119698, 4.957421141011374, 4.798868026052203, 6.784934597355979, 7.4403950827462335, 7.755278757640293, 8.363194022859846, 5.093559801578522, 1.621485254594258, 0.4454664635871138, 0.07215065735259227, 0.5499223970941135, 6.084256972585406, 23.29096964427403, 37.2546775000436, 43.76365613937378, 41.37867655072893, 52.34636633736746, 56.20247411727905, 48.74310350418091, 23.350738048553467, 1.8747996389865875, 0.10482762141951493, 0.05104166701702135, 0.02145216959927763, 0.06417188620460884, 0.025355067403454865, 0.043212217677916796, 0.006778085196856409, 0.03327825126637306, 0.03511326780010547, 0.036774355452507734, 0.037261577522648234, 0.0833850395200508, 0.025295135797932744, 0.039315821935555766, 0.0428483464888164, 0.03742627493504967, 0.008585003171382206, 0.06652583953525339, 0.009547696781477757, 0.032593270165047476, 0.05759956208722932, 0.0021750454865728636, 0.014615469578919666, 0.02655158587731421, 0.1045888720878533, 0.1465083991310426, 0.14177617377468518, 0.14906026077057632, 0.14685222639569215, 0.14082498981484345, 0.09469045073326145, 0.10917141940444708, 0.11597958872360842, 0.13958793905164513, 0.0974503376388124, 0.03736792770879609, 0.0926106051941003, 0.14394520595669746, 0.1522494432117258, 0.11577479328427996, 0.12439686991274357, 0.06614718306809664, 0.3101349611367498, 0.1347381371472563, 0.14200877557907784, 0.1488570123910904, 0.06625272240489721, 0.10923702695540019, 0.1643814593553543, 0.17855859361588955, 0.13449581872139657, 2.7367629749434332, 20.435942683901104, 50.62408855983189, 59.36961242130825, 52.449116298130576, 40.60864244188581, 43.68830292565482, 38.745736598968506, 37.52408695220947, 17.64119134630476, 5.569950878620148, 0.616877518594265, 0.6177736733640943, 1.1317654699087143, 6.522815542561667, 9.02221415724073, 11.537273577281407, 14.681203160967145, 8.455666729382106, 10.678162693977356, 7.289649571691241, 10.891052893229894, 26.05107205254691, 44.190817492348806, 50.16270732879639, 51.35162401199341, 49.000742707933696, 46.105098315647666, 46.74311317716326, 46.013534954616, 42.449974128178184, 40.4533189364842, 40.60187489645821, 42.817433084760395, 41.55572359902518, 44.66188451222011, 46.60499341147286, 49.091562611716135, 48.05159446171352, 44.89451020104544, 48.441134793417795, 47.90443161555699, 46.46767963681902, 44.46664013181414, 44.4002605165754, 45.05434308733259, 47.86627210889544, 53.01207324436733, 48.75455066135952, 46.13809878485543, 51.40774461201259, 51.11357872826712, 46.672408308301655, 42.66840812138149, 38.199427536555696, 37.66890130724226, 37.06494651521955, 44.63620744432722, 48.8155836377825, 49.470371450696675, 48.15995856693813, 48.82101712908064, 37.28531558173043, 50.41088656016758, 50.01170212881905, 47.36599138804844, 42.90395900181362, 42.757053239004954, 42.74645723615374, 43.271299839019775, 41.648356982639854, 39.58159099306379, 35.39116021565029, 35.97828994478498, 33.443767751966206, 37.242625849587576, 35.24305588858468, 36.93557105745588, 45.7050974709647, 49.168951647622244, 49.19157150813511, 52.26544761657715, 44.716681480407715, 51.088704177311485, 52.67040252685547, 47.04333789008004, 47.545439038957866, 42.90548413140433, 38.84439754486084, 38.46401841299874, 36.66100604193551, 38.36030960083008, 37.21948834827968, 38.31041806084769, 39.304423877171104, 41.01098482949393, 44.11094100134713, 46.22071286610195, 50.37062522343227, 50.434197766440256, 46.29458263942173, 35.48885883603777, 21.725830589021953, 12.88743189402989, 6.691213386399405, 6.669762994561877, 11.254882284573146, 16.29934307507106, 12.866813114711217, 11.306126117706299, 9.457058480807714, 5.0386017220360895, 1.9855526217392512, 0.37896881039653507, 1.0439782376800264, 7.773930328232901, 28.218630347933086, 44.42322431291853, 49.086313247680664, 52.11239269801548, 61.353607995169504, 62.94691331045968, 55.56890262876238, 28.199896267482213, 2.495469625507082, 0.35284960908549173, 0.14320907688566617, 0.13210973675761903, 0.15222565377397196, 0.13341686661754334, 0.06697813062263386, 0.145095594227314, 0.14345672859677247, 0.10743430868855544, 0.1102500661675419, 0.16518379987350532, 0.22457785638315336, 0.12384556021009173, 0.1439872479864529, 0.14077262048210415, 0.11071967346859829, 0.13697807623871736, 0.2218793226139886, 0.1503311704312052, 0.1400656955582755, 0.10617814359388181, 0.12033087094979626, 0.12183210253715515, 0.1567846762814692], [0.058654711182628355, 0.018421016267633865, 0.027068855174418007, 0.028279522799753716, 0.03392809443175793, 0.03169301025835531, 0.010857680729324264, 0.05588614920686398, 0.009013076495778347, 0.0737102497369051, 0.041419623153550286, 0.026290305790358355, 0.04303044153909598, 0.032725133267896514, 0.04041385105145829, 0.06662499385752849, 0.01846507185005716, 0.02094511903955468, 0.014492390111887028, 0.06860406337571995, 0.0517624578039561, 0.020863711800692335, 0.05150683330638068, 0.0577153405174613, 0.015869653351338844, 0.04290535021573305, 0.15179425477981567, 0.6864033650074686, 9.747190066746303, 30.259602887289866, 46.78599745886666, 43.608954497746055, 30.676154341016495, 23.483533757073538, 34.03887748718262, 26.271500178745814, 17.100112540381296, 5.23809232030596, 0.6712846819843564, 0.1285777177129473, 0.06222382573676961, 0.770399486379964, 4.3308256438800266, 2.9507974556514194, 4.333698723997388, 5.470136966024127, 4.896143240588052, 6.071226494652884, 8.25767867905753, 18.93072315624782, 31.41349717548915, 46.54592677525112, 48.862699372427805, 46.16551637649536, 46.71913841792515, 42.7647761617388, 43.40903745378767, 42.06188249588013, 41.90065996987479, 42.50309658050537, 41.93656131199428, 42.504524435315815, 42.70213120324271, 42.39352348872593, 45.6224799156189, 45.535999161856516, 44.7081595148359, 45.56225987843105, 42.92678036008562, 40.606380803244456, 38.09345013754708, 39.16862480981009, 40.21319614137922, 45.60834033148629, 45.92733907699585, 48.706243310655864, 44.64993013654436, 45.24793379647391, 45.9360590662275, 45.33551236561367, 41.771319253104075, 35.60252441678728, 33.31872797012329, 33.84441130501883, 38.786630221775596, 43.43143149784633, 45.284804412296836, 47.82373871122088, 43.03512362071446, 29.86792598451887, 47.61361128943307, 44.39186014447893, 42.272322586604524, 38.65348536627633, 33.6123241015843, 32.985242230551584, 32.69333103724888, 32.352445466177805, 31.395952974046978, 30.985317911420548, 32.15132290976388, 32.6831727709089, 33.7386770929609, 35.827555724552695, 38.74254042761666, 43.60079731260027, 42.18194736753191, 45.69479329245431, 46.17396886008126, 44.30083874293736, 47.4399619102478, 48.090872628348215, 46.38695199148995, 43.50648593902588, 41.988777024405344, 40.668018272944856, 39.76714611053467, 40.000647272382466, 37.783067158290315, 36.45061111450195, 35.18157475335257, 37.532028743198936, 38.502817153930664, 41.33608756746565, 43.29169627598354, 46.721483434949604, 47.04879570007324, 43.508900438036235, 29.670694419315883, 18.93563379560198, 10.91248721735818, 6.222381515162332, 3.291726670094899, 4.364626024450574, 3.3380672463348935, 5.170617929526737, 7.949770995548793, 2.8535717470305304, 1.4716799216611045, 0.5016346424818039, 0.09098529669323138, 0.9269601511103767, 6.909229184900012, 20.450318506785802, 31.33538552692958, 28.00233813694545, 33.8946259362357, 46.446227073669434, 48.80817338398525, 38.77816384179251, 15.812161445617676, 1.2279596967356545, 0.027666162765984024, 0.013779389755135136, 0.019032598539654697, 0.014778910005199057, 0.06560182411755834, 0.04332308012193867, 0.015751423713352, 0.06181381416640111, 0.027774384012445807, 0.03472390744302954, 0.030720248884920563, 0.04796709253319672, 0.003957046595002923, 0.045839752935405285, 0.07377412023821048, 0.013334197840387267, 0.04357668597783361, 0.04622592078521848, 0.11488914223653929, 0.03471278625407389, 0.04684741815019931, 0.031888757433210096, 0.06905132651861225, 0.04750216033841882, 0.020603242563083768, 0.01553338157412197, 0.011335873194704098, 0.02964882512709924, 0.023579804359802177, 0.022204466463465775, 0.009222598779680473, 0.023709066977192248, 0.04258550237864256, 0.04394029253827674, 0.05727097471909864, 0.01472401143317776, 0.07362170770232167, 0.022429426267210926, 0.02314785405594323, 0.07508370639490229, 0.04044259040217314, 0.05647690215014985, 0.0866864448679345, 0.027016704669222236, 0.022209918492340615, 0.020332018545429622, 0.05553796235471964, 0.04452364266450916, 0.026500285237229297, 0.02114306975688253, 0.07586748898029327, 1.2135985302073615, 11.457702807017736, 34.33811902999878, 52.49676356996809, 47.810849802834646, 34.143044880458284, 25.86386673791068, 35.132075786590576, 33.49866546903338, 19.08299466541835, 6.181513948099954, 0.5920279377273151, 0.1312840546348265, 0.11522790762994971, 1.3299082262175423, 3.050563382250922, 3.9993379456656317, 8.125421455928258, 5.695783189364842, 6.96251665694373, 9.75016302721841, 12.872356040137154, 22.33758125986372, 34.16652284349714, 47.102039745875764, 50.3162590435573, 47.64011171885899, 48.859055042266846, 45.45998239517212, 45.097616468157085, 44.59470238004412, 43.60376419339861, 44.24898433685303, 42.095702852521626, 43.18304034641811, 44.91769981384277, 44.34939622879028, 47.361492429460796, 45.83103009632656, 45.21387372698103, 47.16762726647513, 44.42564228602818, 42.55630241121565, 39.982508999960764, 41.08708150046212, 42.630356311798096, 46.2851539339338, 48.13898195539202, 49.543584619249614, 46.49168913705008, 47.73783813204084, 46.94039337975638, 46.383655071258545, 42.18828412464687, 38.119019508361816, 34.436283179691856, 34.568135670253206, 39.941340923309326, 46.21619653701782, 47.09134299414498, 49.4338378225054, 44.04541254043579, 32.43841552734375, 48.894511699676514, 47.012738023485454, 43.21696492603847, 39.959267275674, 36.15178646360125, 34.948952538626536, 34.18842703955514, 34.075748103005544, 33.21916028431484, 33.50340414047241, 33.872242314474924, 33.69453518731253, 35.25231783730643, 37.15165655953543, 40.43372849055699, 44.57287114007132, 44.79557132720947, 46.880527700696675, 48.291720730917795, 43.734873226710725, 47.16186720984322, 49.90608603613717, 47.55034794126238, 44.74930674689156, 42.920068400246755, 41.88142040797642, 40.06468187059675, 40.685475621904644, 37.85566888536726, 37.24482842854091, 36.90183755329677, 39.47454009737287, 40.37810468673706, 43.225601536887034, 45.208391598292756, 48.104591846466064, 48.74339532852173, 43.83338131223406, 31.9198853628976, 19.526539870670863, 8.52331873348781, 5.254693303789411, 6.137599161693028, 7.897968700953892, 6.951106412070138, 8.63741683959961, 10.089216010911123, 3.3071243124348775, 1.465496459177562, 0.492322102189064, 0.09425057683672224, 1.127726395215307, 7.339322243418012, 23.51539124761309, 34.19596583502633, 34.03073419843401, 42.23854391915457, 53.90939487729754, 55.88912425722395, 46.91200998851231, 19.650712864739553, 1.4492629702602113, 0.037126413346933465, 0.03013480208548052, 0.042493581239666255, 0.02449444920888969, 0.06247463942106281, 0.008852510513471705, 0.013059973849781921, 0.030526903724031787, 0.04332301905378699, 0.014513190602883697, 0.0453246125419225, 0.0496259138786367, 0.024527904377984147, 0.0341813304860677, 0.09827793323035751, 0.01249661251703011, 0.044674983115068505, 0.03698121363829289, 0.1423046982714108, 0.048764981861625395, 0.06415503818009581, 0.0246808461711875, 0.07750772525157247, 0.030912586421306645, 0.13280771858990192, 0.08556849057120935, 0.2252618468233517, 0.12931734802467482, 0.07508068691406931, 0.18051835202745029, 0.16655815898307733, 0.11909002039049353, 0.10713349375873804, 0.16880250855215959, 0.15711748413741589, 0.08613149143223252, 0.15187985875776835, 0.08816185819783381, 0.06853123621216842, 0.12468479946255684, 0.10951648160283055, 0.14497328150485242, 0.15186468671475137, 0.18795958773366042, 0.13191753492823668, 0.13319125372384275, 0.1409701013139316, 0.08914356944816453, 0.22101136775953428, 0.16404164901801518, 0.24879854385341915, 1.2843229408775056, 13.817020961216517, 39.67229625156948, 59.8365661076137, 55.43464953558785, 40.02426072529384, 31.960633073534282, 45.311825956617085, 37.5496563230242, 22.857280458722794, 7.066519899027688, 1.1670160698039191, 0.3433691720877375, 0.9183498131377357, 3.2262715995311737, 11.777564866202217, 10.491370797157288, 11.49294320174626, 13.902296202523367, 11.31185143334525, 11.246890119143895, 10.06863718373435, 21.965156078338623, 34.66491712842669, 48.99947813579014, 51.81181362697056, 50.33191333498274, 52.42628451756069, 47.43238489968436, 47.25352437155587, 47.745317867824006, 46.171908719199045, 47.31537028721401, 45.42859738213675, 45.61412818091256, 47.27308702468872, 46.178940296173096, 49.93307283946446, 46.62697751181466, 45.70290878840855, 48.8560152053833, 45.97030326298305, 44.51919283185686, 41.88810804912022, 43.32055561883109, 44.48605687277657, 50.25948183877127, 51.060991287231445, 52.34163808822632, 46.73149926321847, 48.39579432351248, 47.933447292872835, 48.873889446258545, 44.45184046881539, 39.33769532612392, 36.26985372815813, 36.33000775745937, 42.62039606911795, 48.19903870991298, 49.10052578789847, 51.83321060453142, 44.98531968252999, 35.10219158445086, 50.6840306690761, 49.412986278533936, 45.99687664849417, 42.899418354034424, 37.20881244114467, 35.79330805369786, 35.150665691920686, 35.262142590114046, 34.435633523123606, 35.23348127092634, 36.0984069279262, 36.15178993770054, 36.94771303449358, 38.334924357278005, 42.320397172655376, 46.61230986458914, 46.72488457815987, 49.20852511269705, 52.21515308107649, 45.849936144692556, 47.44482912336077, 51.622853892190115, 50.64221640995571, 47.651788166591096, 45.50351980754307, 44.60915463311331, 43.81348514556885, 42.80162593296596, 40.147410597120015, 40.102903911045615, 38.44681119918823, 42.26317180906023, 42.718466418130056, 45.279694012233186, 49.026263441358296, 51.68923350742885, 52.41696350915091, 46.66369179316929, 35.03470025743757, 21.665909324373516, 13.474641527448382, 9.584895781108312, 7.920405302728925, 12.104051164218358, 13.30957577909742, 12.463324274335589, 16.94279142788478, 10.712491137640816, 3.6543242761066983, 1.6863563507795334, 0.34729476858462605, 1.6811571440526416, 8.70794974054609, 27.48981990133013, 41.06872088568551, 38.691266196114675, 44.3202520098005, 58.47230815887451, 61.11449268886021, 54.03587293624878, 22.24166832651411, 2.0661749584334235, 0.14102063860212052, 0.11293426249176264, 0.1353441503431116, 0.12847189339143888, 0.09614773360746247, 0.09262414875307254, 0.1105449642719967, 0.12807519467813627, 0.12424776862774577, 0.13679977080651692, 0.08662601453917367, 0.1304736938327551, 0.08775745811206953, 0.17769834691924707, 0.1993183046579361, 0.07235495746135712, 0.11769318820110389, 0.10014091897755861, 0.2735510399299008, 0.1764926037618092, 0.14939966398690427, 0.15002467616328172, 0.2667364313134125, 0.13267222871737822], [0.015812783635088375, 0.04968518051984055, 0.05511780668582235, 0.028086386288383176, 0.07229389609502894, 0.04176316882616707, 0.04263685051617878, 0.03175656524087701, 0.0329305224253663, 0.040733854951603074, 0.04477913824043103, 0.08708636662257568, 0.02102063489811761, 0.013872324455795544, 0.02732975867443851, 0.018008275290152857, 0.026157206057437828, 0.07973855840308325, 0.02941386541351676, 0.021805009505312358, 0.09528193649436746, 0.050993524957448244, 0.03285178182912724, 0.08890907453106982, 0.040365016886166165, 0.029949775763920376, 0.013900112161146743, 0.12343387944357735, 5.959813867296491, 24.509758370263235, 42.69613490785871, 45.7719669342041, 39.664917264665874, 36.30080795288086, 25.24972936085292, 23.59539454323905, 20.88119888305664, 8.614967209952217, 1.276644530040877, 0.08699436405939714, 0.14078577049076557, 0.46770257183483666, 0.923263275197574, 3.170097802366529, 5.528996459075382, 3.6913025890077864, 5.9451014910425455, 7.677597897393363, 10.718880874770027, 15.632894447871617, 26.651319980621338, 37.94320576531546, 44.634758744921, 48.52609736578805, 49.411374296460835, 47.587611130305696, 44.59843008858817, 43.75666625159127, 44.23836748940604, 44.74673591341291, 44.22503737040928, 42.824068614414756, 42.713293484279085, 43.93991109303066, 44.89303370884487, 44.24765375682286, 45.30784811292376, 43.9105931690761, 42.96244893755232, 40.93085820334298, 34.763161182403564, 34.62803609030587, 37.82308183397566, 43.5028520311628, 43.87151997429984, 47.151458808353965, 45.505409717559814, 44.64915541240147, 48.63948154449463, 46.510595185416086, 41.53455243791853, 36.45244196483067, 35.15854842322213, 35.41534342084612, 39.72712101255144, 42.0066373688834, 47.2023161479405, 47.332904066358296, 45.78332723890032, 29.517087118966238, 47.43626894269671, 44.11246960503714, 42.996557644435335, 38.510203089032856, 33.398910181862966, 33.66750322069441, 32.86369391850063, 33.499144894736155, 33.40972852706909, 32.57553127833775, 34.064464228493826, 34.21033818381173, 34.53649009977068, 37.525236879076274, 39.2793721471514, 42.80615963254656, 44.53898477554321, 45.268535205296104, 45.581231934683665, 46.839099066598074, 48.39402253287179, 48.01101003374372, 44.07049206324986, 43.90177937916347, 43.75344576154436, 42.593826157706125, 45.63447945458548, 42.53303289413452, 42.618863991328645, 43.32355029242379, 40.94977814810616, 41.166999680655344, 42.872476713997976, 44.470308780670166, 42.90068292617798, 45.70651142937796, 47.03856447764805, 41.61557885578701, 25.976868765694753, 15.375566176005773, 6.7645286066191535, 1.0016387381723948, 4.305656663009098, 6.484224813325064, 5.512497092996325, 7.591732059206281, 6.729761557919638, 2.907566849674497, 0.5668681306498391, 0.08057219974164452, 0.24619847908616066, 0.7526735461183957, 8.084993362426758, 25.38521749632699, 40.3121280670166, 38.46902806418282, 28.51665074484689, 37.70062678200858, 51.320596831185476, 32.20446620668684, 10.305956380707876, 1.0041130568299974, 0.07720361942691462, 0.03520749256547008, 0.010365563877192991, 0.0222340488939413, 0.03626383927517703, 0.016254760990185396, 0.018765047092788985, 0.033874066080898046, 0.020953979010560682, 0.037651833545948775, 0.0468208670749196, 0.009003286083628024, 0.025568431043731313, 0.03083531485338296, 0.08504230702029807, 0.021460727622200335, 0.046808765402862, 0.015331588652251022, 0.03876771152551685, 0.06968872195908002, 0.027365290160690035, 0.015207442188901561, 0.07639382859425885, 0.04713846896109836, 0.03694325299667461, 0.034981889849794764, 0.03316945835415806, 0.01606646243349782, 0.0884231213214142, 0.04491936768006001, 0.00935137624453221, 0.06077986250498465, 0.01473407750017941, 0.047211262197898965, 0.06235179065593651, 0.09267766480999333, 0.08745290445429937, 0.012279560190758534, 0.03397694216775043, 0.043822573497891426, 0.07737720225538526, 0.06853155512362719, 0.026865890083302344, 0.03289875341579318, 0.05429475727890219, 0.007362428104637989, 0.08748448347406727, 0.05823374127170869, 0.09451551083475351, 0.035718914587050676, 0.025062289720933353, 0.2963395028242043, 7.4806546824319025, 29.231074946267263, 47.91268260138375, 51.582807949611116, 41.38507236753191, 39.36947291237967, 33.19959415708269, 27.978116716657365, 23.040044137409755, 8.863489508628845, 1.6273180501801627, 0.13528196939400264, 0.21798154605286463, 1.1187609391553062, 2.763558268547058, 5.746146772589002, 7.950072373662676, 7.007728150912693, 8.370914340019226, 10.170207687786647, 12.720628227506365, 18.27049490383693, 29.969536440713064, 40.62026677812849, 48.082586901528494, 50.198157038007466, 50.944046156747, 49.03545938219343, 46.48086036954607, 45.57808092662266, 47.067184107644216, 46.3628625869751, 45.70012603487287, 45.658947535923545, 43.57157666342599, 44.853095463344026, 46.63321699414934, 43.782843589782715, 47.06593690599714, 45.44994224820818, 45.010030950818745, 40.89363670349121, 36.871456554957796, 37.73480149677822, 40.13599818093436, 44.84069640295846, 46.462520599365234, 49.206048079899375, 47.06961250305176, 45.38810328074864, 49.47869886670794, 48.25439848218645, 43.15230846405029, 38.765459060668945, 36.85588564191546, 36.44195018495832, 40.54302018029349, 43.686551979609895, 47.84981182643345, 49.26102222715105, 45.630932399204795, 32.709360531398225, 50.29764829363142, 47.069001061575754, 44.910901001521516, 38.16004514694214, 34.53759486334664, 36.072806290217805, 35.48794862202236, 35.38254792349679, 35.13425752094814, 33.78659187044416, 35.62617608479091, 35.165670326777864, 35.60470267704555, 37.973847321101594, 41.56752164023263, 45.13437243870327, 45.54587255205427, 47.309526852199006, 47.13476923533848, 47.15841742924282, 48.76067202431815, 50.700876576559885, 47.01395743233817, 46.46034581320626, 44.29109736851284, 45.14613226481846, 46.55389288493565, 44.47754880360195, 44.873967851911274, 45.21171283721924, 43.62928145272391, 42.93860271998814, 43.13737678527832, 45.669505323682515, 45.42709657124111, 48.77762910297939, 49.03816223144531, 44.05055768149239, 29.19029596873692, 16.632719380514963, 7.468782816614423, 4.822488861424582, 6.3869843397821695, 9.474782466888428, 6.542862832546234, 7.215204834938049, 7.419373307909284, 2.6203537242753163, 1.352682358452252, 0.4590602070093155, 0.16797964913504465, 1.1212650047881263, 8.361521244049072, 26.50084284373692, 39.00978204182216, 37.447872161865234, 31.15149450302124, 43.19251421519688, 57.12791510990688, 38.441943986075266, 13.165039352008275, 1.1956698979650224, 0.05158339919788497, 0.030353972289179052, 0.05018504709005356, 0.03160422055849007, 0.02669302310927638, 0.028068710451147387, 0.008998569417079645, 0.043245493035231314, 0.04193272454930203, 0.04340888766039695, 0.04002948131944452, 0.026581941837710992, 0.04621191242975848, 0.006442524185071566, 0.05339537946773427, 0.005117929681936013, 0.05095551342570356, 0.04210854993600931, 0.07368220588458435, 0.04503523092716932, 0.044231126217969825, 0.029953456816396544, 0.017751169889899235, 0.0592627531981894, 0.11462479856397424, 0.09203547891229391, 0.12493999648307051, 0.12058556585439614, 0.14721535119627202, 0.14617025798984937, 0.08279923988240105, 0.1628156719463212, 0.08335286338946649, 0.1469970257686717, 0.1341726460627147, 0.17310246638953686, 0.13465475876416477, 0.07001827284693718, 0.09294697535889489, 0.13548976395811352, 0.15286795502262457, 0.1703730049942221, 0.12060247494706086, 0.09745742154440709, 0.16655373493475573, 0.15180359142167227, 0.10756057727017573, 0.17491039580532483, 0.13281888727630886, 0.11097664146551064, 0.07707925752869674, 0.5689559557608196, 8.426581570080348, 32.75698695863996, 53.03028794697353, 57.76002747671944, 49.2592191696167, 46.82583148138863, 36.46619939804077, 34.91407258169991, 28.093468972614833, 11.251316121646337, 2.066179083926337, 0.3493075748639447, 0.5535737297364643, 2.3148392609187534, 3.8714767609323775, 10.156400748661586, 12.55772510596684, 10.668377893311636, 12.276607939175197, 14.07714762006487, 16.49277571269444, 18.03900350843157, 31.77556085586548, 40.25792169570923, 48.507618631635395, 50.14312383106777, 52.51929310389927, 50.62758002962385, 49.168583393096924, 48.30331727436611, 49.121120248522075, 48.10482113701956, 48.213900906699045, 48.830900941576274, 46.57947962624686, 47.518931661333355, 47.82558345794678, 44.61848258972168, 48.0881141935076, 48.092064244406565, 46.963440554482595, 43.880736759730745, 38.69174909591675, 37.585793903895784, 42.08122280665806, 47.030671324048726, 47.738241127559114, 50.26466519492013, 48.71014125006539, 48.26685660226004, 51.270878996167866, 50.36953783035278, 45.29576519557408, 40.38518142700195, 39.26198775427682, 39.55838748386928, 44.32582099097115, 45.03160858154297, 50.57054574148995, 52.22342491149902, 48.37622472218105, 36.49219260896955, 51.30485916137695, 48.54523270470755, 46.844855649130686, 40.35743727002825, 36.38450942720686, 37.939026423863, 36.29706634793963, 36.37060260772705, 38.03004782540457, 35.078890800476074, 37.760909352983745, 37.19916139330183, 36.706624439784456, 41.710220268794465, 44.4447672026498, 48.46050637108939, 47.67760419845581, 49.30282258987427, 48.72322818211147, 47.85966089793614, 50.38437918254307, 51.891815185546875, 48.3630405153547, 48.862629890441895, 47.38720771244594, 46.88147612980434, 48.86524588721139, 46.39713110242571, 47.133230209350586, 48.41474206107003, 45.6565260887146, 45.981743471963064, 46.73616845267159, 50.142706939152305, 46.7518435886928, 50.23006664003645, 50.46300152369908, 46.11908156531197, 28.944664989198955, 17.712127242769512, 10.16244741848537, 4.769927476133619, 10.994706988334656, 15.597029583794729, 11.798347796712603, 16.76122283935547, 14.960069111415319, 7.058009658540998, 2.4166056173188344, 1.2068588861397334, 0.5982261651328632, 1.4490432334797723, 10.517264996256147, 32.60030508041382, 49.353103228977744, 48.75000306538173, 40.08453982216971, 51.557860442570274, 64.15239797319684, 45.39029891150338, 17.425816297531128, 1.583101559962545, 0.09805299208632537, 0.08600919906582151, 0.13067612797021866, 0.10609509769294943, 0.0811914104436125, 0.08445268044514315, 0.13376981339284352, 0.17019194470984594, 0.09907555793012891, 0.1769463944115809, 0.15919800821159566, 0.07140146648245198, 0.18271980461265358, 0.07700700033456087, 0.11885706574789115, 0.14206141632582459, 0.1152978917317731, 0.11015084399176495, 0.1489913080419813, 0.18509456861232007, 0.09719092691583292, 0.08215233138097183, 0.14287047434066022, 0.1355709167463439], [0.03852027016026633, 0.04691182469416942, 0.0342140121252409, 0.03507768542372754, 0.014216440945996769, 0.06347480682390076, 0.04038097263712968, 0.01952510470125292, 0.0532056950032711, 0.041122882826519866, 0.05760258835341249, 0.006998812214338354, 0.04639511688479355, 0.04929937907893743, 0.007418748207523355, 0.015559971665165253, 0.07546387599515063, 0.013251945825426706, 0.024795213248580694, 0.034850898664444685, 0.04078243127358811, 0.03958555317616888, 0.021640329056286385, 0.01785242427805705, 0.024942569002243023, 0.03882077296397515, 0.02270665023076747, 0.04986460553482175, 2.4387710222176144, 16.84597522871835, 40.013011591775076, 47.33770874568394, 38.2227144241333, 20.48993018695286, 22.288815328053065, 30.968152386801584, 23.383326836994716, 13.081475104604449, 2.1004971052919115, 0.42027813089745386, 0.041676682752690146, 1.1852500970874513, 1.8415357896259852, 3.4989219520773207, 6.985095262527466, 4.385174453258514, 8.027951257569448, 9.969707863671438, 6.828329137393406, 13.027498892375402, 21.38205804143633, 36.03671039853777, 40.91323062351772, 44.9179117338998, 48.93830966949463, 48.47966602870396, 48.47850220543997, 47.81578997203282, 45.642775603703086, 47.56240653991699, 47.90538004466465, 46.358658926827566, 46.043158599308555, 43.2602904183524, 42.2251477922712, 44.76111173629761, 46.181399958474294, 43.74293313707624, 43.15431996754238, 41.414831502096995, 36.205423082624165, 34.42038222721645, 36.33291210447039, 40.205584389822825, 43.12918485913958, 44.955327783312114, 46.61260863712856, 47.083012104034424, 45.57749032974243, 43.56839438847133, 38.76770680291312, 35.388592856270925, 35.03027425493513, 34.597512653895784, 38.426369598933626, 44.151629652295796, 44.8666444505964, 46.991379261016846, 46.12840257372175, 29.825052125113352, 44.740965434483115, 45.941853863852366, 42.53820930208479, 39.98801892144339, 34.60977622440883, 34.85618713923863, 34.90917410169329, 34.02016598837716, 34.541920116969514, 33.56993661608015, 33.87499727521624, 35.90477800369263, 37.876176493508474, 41.41546031406948, 40.760450158800396, 41.483979974474224, 43.46235792977469, 44.91462871006557, 46.03763825552804, 47.54893050874983, 45.57121958051409, 49.12899603162493, 47.82698351996285, 46.505575111934114, 44.95721421922956, 47.330545152936665, 45.01891769681658, 47.45901387078421, 45.93179634639195, 44.40676055635725, 44.378863539014546, 43.835299015045166, 43.93876116616385, 44.58112212589809, 47.502099650246755, 47.62185532706124, 48.12707274300711, 36.03871495383126, 23.011122260774883, 12.299490094184875, 4.143926918506622, 5.149632632732391, 3.4635588782174245, 6.9104703068733215, 5.266196915081569, 8.063799619674683, 5.999427284513201, 0.7217168243868011, 1.6787702207054411, 0.2604383778359209, 0.19394148460456304, 1.6485757380723953, 9.845983896936689, 25.41782191821507, 35.93700722285679, 30.443344524928502, 39.62753248214722, 47.75648709705898, 49.96188007082258, 39.46977015904018, 9.95464677470071, 0.38664613557713373, 0.0358285963801401, 0.055822780821472406, 0.012584237681169595, 0.0435622840720628, 0.04585916921496391, 0.0726121086627245, 0.0348156996603523, 0.02884944641430463, 0.04834152511986239, 0.0802581330229129, 0.057013178909463544, 0.026500809405531203, 0.02843685301819018, 0.03967439715883561, 0.01886276631349964, 0.03543446592188307, 0.011405194876715541, 0.02835101494565606, 0.03498419008350798, 0.039143036385732036, 0.03888914215245417, 0.014434670530525702, 0.060559969661491256, 0.02655451205958213, 0.06108518969267607, 0.06813771304275308, 0.02831251486869795, 0.060305580097649775, 0.010136782224955303, 0.057762939749019485, 0.058196096148874076, 0.013606569430391704, 0.045917628399495564, 0.06435726197170359, 0.058894919364580085, 0.014470322456743036, 0.08465222402342729, 0.03453521703236869, 0.056906282502625666, 0.052897585822003226, 0.016813358158937523, 0.0127786337231685, 0.04394619579293898, 0.05891698532338653, 0.07364350224712066, 0.01853923572759543, 0.0203300965949893, 0.042291167458253245, 0.026223877212032676, 0.044677955098450184, 0.009215679418827807, 0.04712665905909879, 3.663723451750619, 19.90772499356951, 45.42567219052996, 55.25404500961304, 43.39435591016497, 27.10644609587533, 25.369387762887136, 33.67843273707798, 24.37340865816389, 14.563273991857256, 2.6815339156559537, 0.2055298720619508, 0.09646899958274194, 0.9103195954646383, 2.173845112323761, 5.0658920747893195, 6.822202563285828, 6.24929883650371, 7.318475042070661, 6.868824541568756, 6.930469393730164, 14.061000875064305, 26.21324474470956, 38.24225623267037, 42.72950710569109, 47.01996067592076, 51.04086235591343, 49.81043018613543, 49.90941422326224, 47.898744515010286, 48.00968292781285, 48.48940045492989, 48.43010105405535, 46.443586758204866, 47.382107734680176, 43.894303117479595, 42.51193816321236, 44.03766529900687, 47.99377155303955, 46.600511823381694, 45.27077252524239, 42.38057204655239, 37.08956398282732, 35.86470774241856, 37.888026646205354, 41.92498561314174, 45.83615091868809, 47.48789753232683, 47.37038959775652, 48.275124958583284, 47.763351917266846, 45.79522950308663, 41.60867582048689, 37.16644927433559, 36.43469973972866, 35.99999264308384, 39.2422513961792, 46.35538632529122, 47.947812693459646, 48.19087110246931, 47.95635550362723, 31.84698486328125, 46.63757004056658, 46.6061190196446, 45.00444459915161, 40.592487880161826, 36.37458045142037, 35.89190993990217, 35.26931660515921, 35.4157429422651, 35.64899744306292, 35.679069246564595, 34.577696391514365, 36.89094625200544, 39.61129106794085, 42.05140808650425, 43.34264741625105, 44.06563874653408, 46.54069825581142, 47.141821656908306, 48.55818067278181, 48.511474881853374, 47.12416975838797, 49.43481057030814, 48.26821844918387, 48.25708743504116, 47.66935668672834, 48.17217002596174, 48.086206912994385, 47.74433469772339, 47.998996598379954, 46.92274495533535, 46.46330574580601, 46.18745878764561, 46.51245730263846, 47.19626079286848, 50.61107458387102, 49.1478464944022, 49.92168474197388, 40.610796383449006, 26.90233060291835, 13.700257352420262, 4.4412108063697815, 6.543488170419421, 7.909582614898682, 9.253583090645925, 8.296000599861145, 7.632775936807905, 5.209151336124965, 3.689495188849313, 1.019105640905244, 0.14139418570058687, 0.19786701324794972, 1.765227849994387, 9.66915224279676, 30.130133628845215, 41.11596516200474, 36.692578656332834, 41.80944749287197, 50.41163349151611, 56.979741300855366, 43.32713903699602, 12.433300239699227, 0.40247073929224697, 0.041690881097955365, 0.01807736372575164, 0.04862446743728859, 0.025208934709163647, 0.03987734019756317, 0.019500689314944402, 0.0795045384605016, 0.028999657104057924, 0.020436753818233098, 0.06551270532820906, 0.05405886797234416, 0.010445571637579372, 0.038251634753708325, 0.026370164273040633, 0.072190853767097, 0.0007777505150962887, 0.027325156510674527, 0.006263059730242405, 0.04575454590043851, 0.03063518094963261, 0.02383696743553238, 0.01551487113881324, 0.029635332458253418, 0.015703291831804172, 0.21869818759816034, 0.1826344041952065, 0.1640333437493869, 0.14680749736726284, 0.07823847353990589, 0.20083519683352538, 0.10034874068307024, 0.13332655360656126, 0.13924369109528406, 0.10300848260521889, 0.1467634333031518, 0.11694825174553053, 0.17283960192331246, 0.14201277893568787, 0.1313452042107071, 0.13052739309413092, 0.20621865295938083, 0.08497152903250285, 0.10246952902525663, 0.11138359284294502, 0.1963882547404085, 0.1400980209665639, 0.09161770490131207, 0.13442769380552427, 0.08302429637738637, 0.15819601554955753, 0.07839159853756428, 0.16615903111440794, 4.084702210766928, 22.97736791202, 50.226238182612825, 60.80932085854666, 48.80552959442139, 30.69785703931536, 31.85683046068464, 40.81956890651158, 31.754080499921525, 16.704516853604996, 3.6222961204392568, 0.7431367635726929, 0.37713608731116566, 3.959130023206983, 6.132486590317317, 11.45095350061144, 15.716734886169434, 12.711447051593236, 15.437518051692418, 16.362502200262888, 11.83636920792716, 15.784775120871407, 27.42721836907523, 42.25863463538033, 47.13632215772356, 48.611754758017405, 51.353962080819265, 49.470499992370605, 50.81112364360264, 50.53259468078613, 49.19277007239205, 50.0610100201198, 50.066252435956685, 47.98333535875593, 48.94186019897461, 45.92978484289986, 42.603060313633506, 44.55502816608974, 49.26426356179373, 48.862768854413716, 46.78462866374424, 45.267645835876465, 39.344719954899375, 37.98888322285244, 39.49277564457485, 43.113867555345806, 47.64995036806379, 50.316835744040354, 49.476346901484895, 50.04426138741629, 50.080544880458284, 46.961658341544016, 43.65851252419608, 38.95986270904541, 38.34784453255789, 37.34561552320208, 40.54653944287981, 47.888238838740754, 48.929620947156636, 50.57839373179844, 49.11986262457711, 36.44892617634365, 48.832738740103586, 49.75215564455305, 46.06797061647688, 43.008032594408306, 36.97015571594238, 37.881957394736155, 38.06397935322353, 37.63463626589094, 38.58761991773333, 36.66944462912423, 36.9975837298802, 40.391226359776084, 41.77382755279541, 44.4021886416844, 45.65331254686628, 46.30234030314854, 48.100662640162874, 48.15397964205061, 49.33762264251709, 49.504723344530376, 46.342125688280376, 51.2285019329616, 51.03511619567871, 50.643491404397146, 49.639601775578086, 50.6220840045384, 49.77896874291556, 51.27722617558071, 51.44694287436349, 49.53854717527117, 48.69868714468819, 48.81572607585362, 47.47245168685913, 47.967295442308696, 52.93405539648873, 51.61315768105643, 50.73988723754883, 41.13350241524832, 26.41956455366952, 16.854439871651785, 7.505296468734741, 9.530104024069649, 11.998290027890887, 12.647313441549029, 14.762431076594762, 13.278287172317505, 13.907387495040894, 5.668625720909663, 2.785421209675925, 0.9371697689805711, 0.7069182470440865, 2.4787707158497403, 12.91508572442191, 32.939432757241384, 47.8773649079459, 42.69447776249477, 49.598277364458355, 60.441816738673616, 65.07494504111153, 50.78727395193917, 15.792987891605922, 0.5754213631153107, 0.09588545268135411, 0.09806439147463866, 0.1761890814772674, 0.14228759918894085, 0.09972032904624939, 0.1328483356961182, 0.25722111761569977, 0.09852567315101624, 0.09397653011339051, 0.12509643951697008, 0.13100240831928595, 0.113249157023217, 0.09195150341838598, 0.15464038348623685, 0.22556706544544014, 0.12599799542554788, 0.12224664672144822, 0.11237919370510749, 0.1409496638391699, 0.17230186292103358, 0.11219584675771849, 0.05351848607616765, 0.08886165171861649, 0.16057618068797247], [0.024058902669431906, 0.04663760494440794, 0.04397929812382374, 0.01963665585831872, 0.08782506734132767, 0.05090697103046945, 0.02013465984990554, 0.05721308211130755, 0.05472764565742441, 0.07753167075238057, 0.03923158520566566, 0.018965479551947544, 0.03931457343112145, 0.07844071090221405, 0.027426153055525253, 0.00984624625250165, 0.05117169128996985, 0.05245807833437409, 0.03889282999028053, 0.02140487910115293, 0.036451834187443764, 0.046662276477686, 0.007963659324949341, 0.04770039773679205, 0.030790928485138074, 0.01733259860027049, 0.009191770389276956, 0.06582044131521668, 1.0412584521940775, 11.490720646721975, 32.9817716053554, 45.97188050406319, 44.65791709082467, 34.901419912065776, 26.717550209590367, 27.460547140666417, 25.135438442230225, 16.089123589651926, 5.768962485449655, 0.7657936992389816, 0.05697207325803382, 0.18665670550295285, 2.3545484329972948, 3.54859744650977, 4.660256675311497, 5.904433250427246, 6.102640603269849, 5.928182627473559, 4.923337621348245, 8.382575154304504, 16.595369338989258, 23.63742593356541, 37.73330415998186, 45.6283164024353, 46.399886063167024, 45.283063888549805, 46.864345346178325, 47.13623183114188, 45.825367314474924, 44.33028868266514, 40.77769558770316, 43.180538994925364, 44.43343816484724, 42.6291230065482, 44.95219414574759, 45.577278409685405, 43.61183105196272, 45.544958863939556, 42.178556646619526, 42.88327074050903, 38.9119861466544, 33.94259977340698, 32.852027893066406, 35.34965167726789, 40.10776417595999, 45.060339382716585, 45.71983807427542, 44.635064465659006, 43.91814933504377, 38.623014041355674, 33.474020208631245, 33.223700932094026, 33.08880513054984, 33.37099231992449, 36.43345601218087, 41.561494077954976, 44.14865582329886, 44.29808725629534, 46.310063225882395, 34.6413905279977, 47.51948404312134, 47.06241764341082, 43.28373711449759, 37.480553013937815, 34.47966773169381, 39.16001599175589, 40.26221568243844, 41.23091615949358, 42.45345517567226, 40.22844048908779, 39.2942864554269, 39.85883106504168, 41.49710512161255, 43.17038767678397, 41.45352949414934, 41.89385768345424, 43.82916028159005, 44.6267683165414, 46.00733021327427, 47.08385978426252, 48.27723026275635, 46.88959857395717, 45.859521184648784, 49.386145387377056, 43.13866567611694, 49.68745749337332, 48.019886357443674, 49.962922300611226, 49.83054869515555, 47.490169593266074, 45.28143106188093, 46.04613937650408, 46.523723806653706, 47.71655927385603, 47.63793345860073, 50.67260088239397, 44.988154547555105, 29.66091135569981, 21.079238176345825, 9.641755495752607, 2.9328005356448035, 5.6937881878444125, 6.490066077028002, 9.31216595854078, 6.404380892004285, 2.636937988655908, 3.8710472754069736, 2.6759367074285234, 0.9653829293591636, 0.265851295952286, 0.16608380872224057, 1.8646637371608188, 10.529338359832764, 20.70144898550851, 30.053491524287633, 34.55197416033064, 34.56435585021973, 50.78876086643764, 50.27512570789882, 30.8594617162432, 6.345882271017347, 0.2944820267813546, 0.026380937712799226, 0.022888126117842536, 0.018751025166628615, 0.008380680162060474, 0.019257634678589444, 0.03577211173251271, 0.0770043201212372, 0.043513256524290354, 0.037625011056661606, 0.0686765309157116, 0.0320329902294491, 0.09356461185961962, 0.05405077983492187, 0.07170525339565106, 0.05610199798164623, 0.036147579085081816, 0.04466417744489653, 0.07637821550347976, 0.015896708238869905, 0.028896088911486522, 0.012741483082728726, 0.027865930260824304, 0.05233070034799831, 0.0011357333985090787, 0.06985418272337743, 0.020872098493522832, 0.03099209376211677, 0.04495839022898248, 0.05262199203882899, 0.06129894179425069, 0.05177463411486574, 0.04441377427428961, 0.02983486925118736, 0.03478625124054296, 0.040675039536186626, 0.034591331878410916, 0.03663111671007105, 0.01842745895763593, 0.03998694735180054, 0.030389944823192697, 0.022288942376949956, 0.04361098253035119, 0.019472343514540365, 0.06915198718862874, 0.019319713847445588, 0.017039697085108076, 0.030767844723803655, 0.06750960674669061, 0.03306886214496834, 0.009757540521344968, 0.015989840562854494, 0.04984763537400535, 1.6500364882605416, 13.493549312864031, 39.30848857334682, 52.271739210401265, 46.25896617344448, 33.301795210157124, 28.448495864868164, 31.805983543395996, 30.821729523794993, 18.080209800175258, 6.038676355566297, 0.8136947974562645, 0.0608354616644127, 0.36323228052684237, 1.1652444962944304, 3.0673686861991882, 5.305523719106402, 8.040051545415606, 7.168022223881312, 6.849700927734375, 7.237136823790414, 9.655428682054792, 18.403912476130895, 28.774771111352102, 42.95084197180611, 47.52978474753243, 48.5573399407523, 45.88135937282017, 47.244099140167236, 46.42730018070766, 46.10232251031058, 44.64969389779227, 42.686226776668, 43.95260892595564, 46.03072132383074, 43.37755169187273, 45.97546230043684, 45.4274891444615, 45.59499284199306, 46.58513198580061, 45.343363830021445, 44.390335014888215, 41.24045603615897, 35.471095766339985, 35.137081963675364, 39.605732509068076, 44.14521646499634, 47.21478121621268, 47.93565682002476, 45.91619764055525, 47.122714110783164, 41.244263648986816, 35.597657203674316, 34.50372239521572, 34.54725285938808, 35.36922822679792, 38.0514725957598, 42.935580253601074, 46.16934483391898, 46.612191745213096, 49.24101488930838, 35.343547684805735, 49.228515080043245, 47.965485436575754, 44.18436261585781, 40.705389159066335, 36.49271719796317, 40.12361996514456, 41.03526183537075, 41.93850680759975, 43.46001638684954, 40.93196644101824, 40.30255344935826, 41.3135267666408, 42.93810592378889, 45.04648814882551, 44.19702918188912, 43.02856452124459, 45.62254244940621, 46.5249536378043, 48.79001774106707, 49.492133208683555, 49.15237324578421, 47.33951180321829, 47.91430500575474, 49.191755635397776, 44.79560954230172, 51.947775976998464, 49.59847886221749, 51.754636900765554, 50.442222935812815, 48.24947568348476, 46.836792264665874, 47.02705478668213, 48.9341789654323, 48.6081416947501, 50.209534713200156, 52.392175810677664, 47.74539777210781, 33.13630996431623, 22.772429057529994, 10.254859328269958, 4.361366885049002, 7.091955517019544, 10.023868203163147, 8.028222237314496, 6.7445772886276245, 8.72926333972386, 5.70981377363205, 3.5654809176921844, 0.9950963578053883, 0.22075945484851087, 0.17509965279272624, 2.5242253967693875, 11.53318108831133, 23.958556038992747, 35.87733956745693, 35.317693437848774, 39.24099724633353, 57.06901870455061, 56.38166121074131, 37.0430075781686, 8.529885649681091, 0.2952280081808567, 0.01953780178778938, 0.045237519179603884, 0.05389009934983083, 0.019313803807433163, 0.06552258479808058, 0.05322139969627772, 0.06218779552727938, 0.023745629836672118, 0.05651746836623975, 0.024243169031771164, 0.028911481478384564, 0.05519980764282601, 0.062150333608899794, 0.04388189102922167, 0.01883989798703364, 0.024544472506801997, 0.06774005759507418, 0.044767881344471655, 0.009247709664383104, 0.033575527636068206, 0.030223177878984382, 0.04000512191227504, 0.016479697045204893, 0.03474816846262131, 0.10342585628053971, 0.14972184598445892, 0.21727079419153078, 0.09814143912600619, 0.11589002210114684, 0.11855561978050641, 0.13321344181895256, 0.18045698532036372, 0.1807136344058173, 0.15641739884657518, 0.1494704894721508, 0.1051951227709651, 0.13853782468608447, 0.13840796665421554, 0.12371813133358955, 0.07106648052909545, 0.06790043613208191, 0.19127984956971236, 0.17530792233135017, 0.19051796330937318, 0.14140572079590388, 0.1399432878409113, 0.14456678474588053, 0.30208175469722065, 0.09048082626291684, 0.07926848291286401, 0.09928748477250338, 0.1873161465461765, 1.9650521789278304, 15.271157332829066, 43.19063820157732, 58.71944863455636, 54.80933598109654, 44.25796488353184, 36.45893505641392, 37.71591281890869, 34.88240964072091, 21.564231123243058, 7.608082039015634, 1.3191741279193332, 0.43947144384895054, 1.1139170676469803, 5.403294427054269, 9.302763308797564, 13.566118904522487, 11.976133959633962, 12.094037941523961, 13.832027333123342, 9.304219824927193, 11.775377920695714, 21.86192842892238, 28.8315326826913, 44.17234570639474, 50.87737124306815, 51.79269565854754, 47.851785114833284, 48.335966859545024, 47.11765929630825, 45.501345021384104, 45.05071612766811, 42.288855825151714, 43.453050817762104, 46.856629371643066, 44.040837151663645, 46.135454995291575, 46.63005208969116, 45.40353522981916, 48.06633506502424, 46.65954719270979, 46.59579399653843, 43.37918451854161, 37.816005093710764, 36.62989895684378, 41.676090717315674, 46.319693429129465, 49.54178850991385, 49.53108480998448, 49.40630211148943, 48.14298759187971, 41.61500562940325, 37.00116205215454, 37.15877498899187, 36.03173548834664, 36.94741426195417, 40.63246086665562, 45.10140323638916, 48.84892109462193, 48.71025936944144, 51.94503838675362, 38.257781982421875, 51.05199337005615, 51.09592335564749, 46.84274687085833, 41.30004726137434, 37.40331336430141, 42.21751867021833, 43.34744167327881, 45.16304418018886, 46.57890292576381, 44.13322734832764, 43.167007378169465, 43.08397987910679, 43.92408309664045, 47.50995111465454, 45.62615203857422, 45.94871868406023, 47.74656506947109, 48.26016896111624, 51.19319813592093, 51.151835509708945, 51.16603067943028, 47.27897909709385, 46.98161704199654, 50.72752291815621, 46.78202656337193, 53.26398018428257, 50.99791554042271, 51.41278553009033, 51.47086204801287, 50.43383298601423, 47.81354570388794, 50.43189443860735, 52.34666163580758, 52.801205839429585, 52.94989381517683, 54.617565699986045, 48.51742948804583, 33.802937507629395, 25.02340395109994, 12.487788881574359, 6.495444416999817, 12.495633397783552, 12.727248992238726, 17.240030152457102, 13.369697672980172, 13.036183272089277, 12.150823831558228, 5.917218804359436, 3.3447390369006564, 0.8130196279713086, 0.7034027299710682, 3.017704265458243, 14.12256452015468, 28.51257562637329, 42.280222688402446, 45.7839595249721, 45.95790767669678, 60.55730969565255, 63.64734731401716, 41.98424332482474, 10.99748626777104, 0.42177839896508623, 0.08657203707844019, 0.07546234250600849, 0.17737893334456853, 0.10079633630812168, 0.10930302805666413, 0.1213814060070685, 0.17755818872579507, 0.08191169572195836, 0.13150267861783504, 0.16362889616617135, 0.08704412103231464, 0.1545397431722709, 0.1605412768466132, 0.20416715661329882, 0.15672732650169305, 0.15053280389734677, 0.1623714214989117, 0.15469690545329026, 0.06865573381739003, 0.1820240348045315, 0.1431183296122721, 0.11820290370711259, 0.08967586659959384, 0.07982108183205128], [0.023785152805170844, 0.021376068504261117, 0.026096631539985538, 0.014857241784089377, 0.07655177797589983, 0.06078710925898381, 0.0026177607485026655, 0.025688144977071455, 0.03876782348379493, 0.013863098924048245, 0.026428241781624298, 0.11376782919147185, 0.021316326888544217, 0.007121644016089184, 0.10615727185670819, 0.021122895214440565, 0.07240039216620581, 0.06226373038121632, 0.02963882012824927, 0.03651661392567413, 0.026628278994134495, 0.024750234858532037, 0.03683989854263408, 0.029320902723286833, 0.030911551655403206, 0.02664739841462246, 0.020403234188311865, 0.051152261439710855, 0.2534704745880195, 5.925830662250519, 25.460888590131486, 45.368936674935476, 45.02826302392142, 34.8789563860212, 24.22405539240156, 22.54857199532645, 25.755645070757183, 21.232079437800817, 7.249363047736032, 1.6886008360556193, 0.06706247252545186, 0.12489017844200134, 0.734070667198726, 0.2606638957347189, 3.2819889869008745, 3.5938695200851987, 5.052774744374411, 2.828876329319818, 4.171992429665156, 5.629939453942435, 11.160534432956151, 23.081587416785105, 35.21993228367397, 47.939235142299104, 49.410457134246826, 47.09142984662737, 46.61024972370693, 46.00398465565273, 47.82612541743687, 45.662584917885916, 46.49832466670445, 44.41004705429077, 43.51506349018642, 44.68254845482962, 43.177770137786865, 45.284974643162315, 42.31432097298758, 43.38977357319423, 44.41682154791695, 44.45532499040876, 41.42046301705496, 36.550255230494905, 34.88530009133475, 33.14911896841866, 34.4704578944615, 36.822801794324604, 37.38914251327515, 37.22309793744768, 35.96537324360439, 33.42950310025896, 32.356725556509836, 31.922331128801616, 32.51564475468227, 35.37765986578805, 35.365559577941895, 39.19322490692139, 44.02839640208653, 43.64239270346505, 46.10828406470162, 35.84721565246582, 46.31042800630842, 45.140021324157715, 41.30045025689261, 37.02229847226824, 35.049965449741904, 40.18980155672346, 42.777470520564485, 45.62053094591413, 44.803683349064414, 45.03945309775216, 43.606599058423726, 42.94013132367815, 42.40629775183541, 44.267855644226074, 44.9744005884443, 43.433807781764436, 41.62830100740705, 43.87471267155239, 42.71079560688564, 44.89670235770089, 44.9598753792899, 48.60565423965454, 42.6727021081107, 41.360027585710796, 45.26410225459507, 47.34982640402657, 46.95866714205061, 48.836459500449045, 48.64522075653076, 49.06721612385341, 48.78129080363682, 49.4519795690264, 49.17577477863857, 52.42062520980835, 49.746645723070415, 47.8570032119751, 42.48184551511492, 30.97310992649623, 17.85714830671038, 7.65490334374564, 2.2423361114093234, 5.697075120040348, 8.400982669421605, 6.661261439323425, 6.001946006502424, 7.828989590917315, 3.600525677204132, 0.9313210142510278, 0.6318229309150151, 0.08747645640479666, 0.1769653255386012, 3.573944692100797, 11.263304369790212, 26.66125069345747, 35.78556081226894, 36.44397211074829, 39.333786964416504, 45.390312807900564, 44.81170851843697, 19.788420949663433, 3.6694105522973195, 0.08453931579632418, 0.019915974798745344, 0.03307344564901931, 0.01694356563634106, 0.02838720121820058, 0.029885857765163695, 0.06848238169082574, 0.014588889665901661, 0.041544229324374876, 0.04034467440630708, 0.04749607387930155, 0.037464612163603306, 0.0364057820157281, 0.038589087181857655, 0.029590593251798834, 0.03114728829158204, 0.02962234869067158, 0.016787280361833315, 0.045412265695631504, 0.004963034131963338, 0.04692062868603638, 0.018634434190711806, 0.07416118375424828, 0.0615043682711465, 0.02032283627028976, 0.016791980913175002, 0.011926285174143101, 0.01834466411466045, 0.060508726696882925, 0.12367807062608854, 0.07090767619333097, 0.032360115354614596, 0.08000728541186877, 0.05505343746127827, 0.02726123172656766, 0.02345406842817153, 0.10073832156402723, 0.040043937508016825, 0.02264484077958124, 0.01939321615334068, 0.03606091998517513, 0.0827619204563754, 0.019960758109976138, 0.06165129824408463, 0.06231532618403435, 0.04248448208506618, 0.06466730497777462, 0.031601465706314356, 0.028453889336170893, 0.020723750382395725, 0.02236675507655101, 0.0368614250661007, 0.05951248801180294, 0.48924991275582996, 8.646998405456543, 29.06834466116769, 50.80672543389456, 51.98793656485421, 40.76913888113839, 27.216191155569895, 28.933831010546, 28.923438242503575, 23.608026368277415, 8.337318931307111, 1.4271992913314273, 0.053936338118676624, 0.4538841518972601, 1.421263901250703, 2.5455444242273058, 4.722410048757281, 9.001327872276306, 6.6051199947084696, 5.015606224536896, 5.3749401313917975, 7.5960138865879605, 15.508024896894183, 27.218774148396083, 38.06968035016741, 48.40297181265694, 51.6799750328064, 47.81993804659162, 47.62991523742676, 46.52485636302403, 47.398272718702046, 45.02607781546456, 46.18484973907471, 44.40598930631365, 43.13770682471139, 44.8380560874939, 42.67032235009329, 44.93122100830078, 43.12343522480556, 45.40571001597813, 46.79569367000035, 46.183536529541016, 42.66876942770821, 37.33044760567801, 35.65091861997332, 35.295886516571045, 37.08406448364258, 38.533799171447754, 40.22833626610892, 41.27159438814436, 38.05520030430385, 34.63274349485125, 33.791490350450786, 32.98999827248709, 35.20611926487514, 36.93254859106881, 36.152710574013845, 41.28536571775164, 45.991741929735454, 47.551963397434776, 47.135620389665874, 37.91376624788557, 48.62877089636666, 46.95874009813581, 43.3497554234096, 39.45855229241507, 35.92385080882481, 41.112803731645855, 45.43812336240496, 47.68002217156546, 46.436777523585725, 46.55306257520403, 45.95702872957502, 45.74922548021589, 45.83419847488403, 45.74948256356375, 46.70801435198103, 44.65853548049927, 43.97535732814244, 45.50590303965977, 45.52902317047119, 47.55447864532471, 47.37141098294939, 48.111203057425364, 44.66449703489031, 43.89066226141793, 45.72548001153128, 47.68244014467512, 48.27070243018014, 48.40598038264683, 49.67798709869385, 48.89853818075997, 49.5817927633013, 50.879386220659526, 51.08582067489624, 54.35816165379116, 50.561700684683665, 49.026492731911794, 45.963264737810405, 30.787474904741558, 18.412027972085134, 9.858986582074847, 4.803935868399484, 8.095537253788539, 10.67405022893633, 9.081471000398908, 7.324809193611145, 7.797599366733006, 5.801600345543452, 2.5402042993477414, 0.8897085785865784, 0.2026700098067522, 0.19453361497393676, 3.453135277543749, 14.912369728088379, 29.265489373888286, 35.77579859324864, 41.959955896650044, 43.03892428534371, 51.187361649104524, 51.69476774760655, 24.865841388702393, 4.564836629799434, 0.022686967626214027, 0.010136229218915105, 0.010181026949015046, 0.030908803588577678, 0.06436295488051005, 0.04483395029923745, 0.014902133660923158, 0.04127282549494079, 0.027448512480727265, 0.021141789022034833, 0.048998927165355, 0.04768309509381652, 0.10252010702554669, 0.04622110318658607, 0.0455562508265887, 0.018014158188764538, 0.025614196534401605, 0.01521504347744797, 0.025762313943622366, 0.08135655229645115, 0.060119946487247944, 0.015990999161398838, 0.05733030582112925, 0.03138135912429009, 0.00995999586302787, 0.09344535933009215, 0.1686446541654212, 0.09491315949708223, 0.10684544207262141, 0.2860190123319626, 0.1268709171563387, 0.09370144523148026, 0.19031888113490172, 0.11635722060288702, 0.12645535516951764, 0.11834550462663174, 0.28810583321111544, 0.09666068572551012, 0.13602482953241893, 0.10919197223016194, 0.08691239702914443, 0.17731603314833982, 0.11847623118332454, 0.09809942423765149, 0.11139592182423387, 0.12167829221912793, 0.19930481538176537, 0.13589472722794327, 0.09524956358862774, 0.12435348438365118, 0.091191625621702, 0.1133803314130221, 0.14137505101306097, 0.6215255920376096, 9.02317908832005, 32.68345069885254, 57.71151515415737, 58.07531935828072, 47.332904066358296, 33.07088920048305, 33.303091049194336, 35.29712329592024, 28.403193610055105, 10.615953734942845, 2.6688443337168013, 0.18039234807448729, 1.339263215661049, 3.153171122074127, 7.7907432317733765, 10.804460099765233, 14.419231755392891, 14.237442561558314, 7.682927165712629, 7.874424730028425, 8.025465539523534, 15.851601157869611, 27.652018649237498, 39.29900080817086, 48.54762288502285, 52.67453670501709, 47.41941608701433, 47.980962548937114, 46.43347365515572, 47.96119492394583, 46.2358113016401, 46.79973752158028, 44.15707356589181, 45.04369149889265, 45.866424219948904, 44.3480031149728, 45.85401473726545, 41.99358517783028, 46.33530255726406, 48.51279156548636, 48.98677682876587, 45.74646357127598, 39.17500673021589, 37.92473745346069, 36.298480306352886, 37.681776319231304, 39.15689277648926, 40.322463512420654, 41.64531019755772, 39.04482180731637, 35.96247584479195, 35.10632576261248, 34.49523169653756, 36.87026146480015, 38.43274457114083, 37.81242677143642, 42.44887631280081, 49.08373199190412, 48.34277956826346, 49.75285741261074, 39.92784752164568, 50.33941044126238, 49.402317319597515, 44.78687913077218, 40.43619162695748, 38.6400579724993, 42.51985216140747, 46.90221997669765, 48.97433607918875, 49.293946266174316, 49.24923808234078, 47.84341948372977, 46.992209570748464, 48.329373019082205, 47.449258599962505, 48.80948659351894, 47.3364372253418, 45.49576561791556, 47.68855108533587, 47.27044670922415, 49.21445887429373, 49.57244396209717, 50.37287296567644, 46.15176241738455, 45.134747641427175, 48.10225030354091, 48.18137986319405, 47.775646754673545, 49.65226139341082, 50.19540902546474, 50.097533226013184, 52.695739133017405, 51.823788847242085, 50.37910549981253, 55.19679185322353, 51.40076167242867, 50.1743803024292, 46.595394475119456, 34.11884430476597, 20.7834255695343, 10.02309695311955, 6.592387855052948, 12.6178982428142, 17.594214575631277, 16.319016899381364, 13.852434192384992, 16.320870331355504, 11.134491716112409, 6.778813234397343, 1.3473553700106484, 0.7549133630735534, 0.4421851225197315, 5.094671947615487, 15.564977543694631, 36.560423919132774, 47.23673057556152, 45.91760812486921, 51.41825376238142, 57.710226263318745, 58.076917443956646, 29.515405654907227, 6.210714621203286, 0.2499639413186482, 0.06362470199487039, 0.14740661664732865, 0.1603685761136668, 0.10134784278592893, 0.14814984319465502, 0.12923785086188996, 0.14454941424940312, 0.1130405142903328, 0.1214845704713038, 0.1228856910020113, 0.12248614244163036, 0.21500579001648085, 0.18943579494953156, 0.14245061044182095, 0.04737660761124321, 0.1273766564471381, 0.1253767694745745, 0.15422232449054718, 0.10435382755739347, 0.13417693440403256, 0.06473583022930793, 0.22000576529119695, 0.12639694687511238, 0.07658335021031754], [0.02808988413640431, 0.028448070898385983, 0.03609749980803047, 0.013724059465208223, 0.07013520478670086, 0.023186500017930354, 0.027192436757364442, 0.0702997020312718, 0.024997314903885126, 0.017553052931491817, 0.04997822283101933, 0.03926848054730466, 0.056091382301279476, 0.035348410718142986, 0.06309629284909793, 0.03600836744798081, 0.06904866666133914, 0.028092260705307126, 0.08532524255237409, 0.015956415927835872, 0.020549577228458862, 0.05760707346988576, 0.04123894624145968, 0.019673493524481143, 0.07352763560733624, 0.06116151809692383, 0.0015389978923069844, 0.04195925187585609, 0.09038222155400685, 2.41332454766546, 22.11403512954712, 42.749636037009104, 43.1593782561166, 35.461885929107666, 26.28802125794547, 23.576382534844534, 29.92206982203892, 26.005429336002894, 12.068612745829991, 2.4426244497299194, 0.20112839181508335, 0.19575949705072812, 0.8030384864125932, 0.8009339964815548, 2.1951376497745514, 8.901947787829808, 4.147168253149305, 4.908754221030644, 6.5915970632008145, 6.031303882598877, 13.860903177942548, 23.807903460093907, 35.6833667073931, 42.32616417748587, 45.98649951389858, 48.02896070480347, 48.16083056586129, 47.85311916896275, 49.39384399141584, 49.50173561913626, 48.46338987350464, 45.36513253620693, 43.90820646286011, 42.479483127593994, 44.23912831715175, 43.19737448011126, 42.72179113115583, 45.16836650030953, 47.259412969861714, 46.04366929190499, 40.493368353162495, 39.736587933131624, 35.26422357559204, 33.37779113224575, 33.345117228371755, 32.07513243811471, 32.052304131644114, 32.65607132230486, 33.51410436630249, 32.985645226069856, 33.28194768088204, 33.55670377186367, 35.303810937064036, 35.72890172685896, 36.8508551461356, 40.88108130863735, 44.00698552812849, 44.500158241816926, 45.82362331662859, 34.974977016448975, 46.22083098547799, 46.299241406576975, 41.77136441639492, 37.08479404449463, 35.233474322727744, 38.205635751996724, 42.789261613573345, 44.406465257917134, 46.01946871621268, 45.20617164884295, 44.2187179837908, 47.142422676086426, 46.1322796685355, 45.41752542768206, 44.08477061135428, 42.86565358298165, 40.214905398232595, 40.636049611227854, 41.098476546151296, 43.20742852347237, 44.83291442053658, 46.922407967703684, 46.85595539637974, 44.575782435280935, 47.735395840236116, 48.84693043572562, 47.402566705431255, 45.968281337193076, 45.02522666113717, 46.58133479527065, 48.10150684629168, 47.760367665972026, 50.277442932128906, 46.835531166621614, 47.35744857788086, 45.42637743268694, 41.12092270169939, 26.516504083360942, 12.434009824480329, 6.627731604235513, 4.679309938635145, 5.162993584360395, 8.82825345652444, 5.472427265984671, 4.160859678472791, 4.758569777011871, 2.977692195347377, 3.031679481267929, 0.46167164402348654, 0.06037116050720215, 0.43547606681074413, 3.55570610506194, 11.93612015247345, 30.872555596487864, 30.908324922834122, 32.97080039978027, 34.20088168552944, 48.30969224657331, 41.4641706602914, 18.2775490624564, 3.1718315950461795, 0.07180729827710561, 0.015582166545625244, 0.03634663751082761, 0.017503640315096294, 0.010157424956560135, 0.07882921969784157, 0.010331961126731974, 0.00936101483447211, 0.01636251913649695, 0.04746649653783866, 0.024795589835516045, 0.09170959211353745, 0.07692955913288252, 0.030696018399404626, 0.03601227920236332, 0.0752588159271649, 0.07604842712836606, 0.038961385775889666, 0.026225278386846185, 0.011425559408962727, 0.03378810587206057, 0.044089811122311015, 0.02795409061945975, 0.02104137771363769, 0.06565671081521682, 0.04252923486222114, 0.019328938531024114, 0.05588482945625271, 0.029026069079658816, 0.014668220587606941, 0.029122896026819944, 0.08709915022232703, 0.027014616477702345, 0.02653267341000693, 0.019610040322212235, 0.019264516720016087, 0.012228856661490031, 0.08165612550718443, 0.048974079212972095, 0.0420383181689041, 0.025975538484219993, 0.06425322898264442, 0.0523295536238168, 0.023411263046520095, 0.017154488246887922, 0.053421916972313604, 0.012215161280307387, 0.05942437345428126, 0.028490280865558555, 0.013549732792723392, 0.00678053852503321, 0.009928019900274063, 0.04774630741615381, 0.13682068325579166, 3.8674394232886176, 26.748725039618357, 48.723189967019216, 48.6574878011431, 41.515701975141255, 30.61592388153076, 26.39343932696751, 32.827302728380474, 28.929239988327026, 12.17675711427416, 3.077127213988985, 0.14399210629718645, 0.2567040467900889, 0.7449769505432674, 2.528517863580159, 4.049880879265921, 5.607309605394091, 5.800436522279467, 5.908328149999891, 5.075977385044098, 8.488427485738482, 16.70782593318394, 24.916653564998082, 36.67743158340454, 45.031716278621126, 47.63546337400164, 48.488108089991975, 50.26164967673165, 49.381695066179546, 50.7149293082101, 48.88999189649309, 48.224646295819966, 45.65133925846645, 44.50907972880772, 44.8753331729344, 44.237592765263145, 43.63679245540074, 43.6979991367885, 45.46274083001273, 48.31297179630825, 47.32473645891462, 43.92606333323887, 41.321069036211284, 37.246551581791465, 35.45275947025844, 34.60156692777361, 33.863341672079905, 34.55291216714041, 34.12971823556082, 34.32819700241089, 33.97587469645909, 34.60693441118513, 34.34075239726475, 37.0184109551566, 36.44302020754133, 38.5711214201791, 41.79214300428118, 46.19047777993338, 44.63195514678955, 48.597809723445344, 39.12535490308489, 48.43195622307913, 47.640382698604036, 43.842295851026265, 37.812068939208984, 36.97522095271519, 39.836120877947124, 43.74492032187325, 46.32634285518101, 48.10898658207485, 46.80822474615914, 46.07362297603062, 48.227585383823936, 47.95262084688459, 46.57733958108084, 45.64110803604126, 43.153031076703755, 42.829126902988975, 43.3040189061846, 44.87908520017351, 46.31675781522478, 46.175705909729004, 48.67204080309187, 44.66328804833548, 45.967416286468506, 48.24972929273333, 49.21436159951346, 49.86598103387015, 47.33618014199393, 48.09852259499686, 48.89746815817696, 49.39204788208008, 48.198267459869385, 49.15502050944737, 48.2860232080732, 49.60520124435425, 45.92919077192034, 42.70424345561436, 28.378451074872697, 15.239669833864484, 7.486742172922407, 8.179727707590375, 10.04893730367933, 8.848815781729561, 7.3255040134702405, 7.836289542061942, 8.422244157109942, 4.247527599334717, 2.1073102482727597, 0.5986378458993775, 0.034805715017552884, 0.5462520654712404, 4.078691150460925, 13.797211647033691, 34.49785116740635, 35.11897495814732, 35.682334899902344, 41.31012909752982, 54.26869317463466, 47.34178386415754, 21.880841425486974, 4.16598744903292, 0.06168802734464407, 0.02815342215555055, 0.051206140512866635, 0.013912484399043024, 0.027000346886260167, 0.021451341786554882, 0.017136183068422333, 0.015463913158912743, 0.01487403382946338, 0.0757218346531902, 0.04238698338823659, 0.035158671970878325, 0.03349355382046529, 0.05817552975245884, 0.016441632926996266, 0.03614655449720366, 0.027238560175257068, 0.010924180553826903, 0.0502085210090237, 0.03365339970748339, 0.02494393116129296, 0.0739368125796318, 0.01991831574455968, 0.0557276977093092, 0.03742636314460209, 0.14042351421500954, 0.08572348154016904, 0.17100708239844867, 0.08880166243761778, 0.11653681525162288, 0.14273434664521897, 0.14118533262184688, 0.20083540039403097, 0.15526295293654713, 0.118929831843291, 0.11689303256571293, 0.11606075508253914, 0.17345495176102432, 0.066489985744868, 0.10916301235556602, 0.18246354907751083, 0.1792879101953336, 0.1280887382371085, 0.15347794443368912, 0.1037346643528768, 0.11386200306671006, 0.17391510706927094, 0.1383677702397108, 0.08387328617806945, 0.08727268555334636, 0.09274996271623032, 0.15163929095225676, 0.13701010309159756, 0.17058412437992437, 4.242015940802438, 28.58642976624625, 55.212932518550325, 54.24890470504761, 47.35093116760254, 37.93950932366507, 33.82240983418056, 40.29620279584612, 34.78679895401001, 15.801838159561157, 3.561240562370845, 0.6368539695228849, 0.612281393791948, 1.9359155595302582, 6.406377196311951, 11.133631876536779, 15.817667893001012, 13.31227341720036, 12.889718719891139, 12.237759692328316, 10.241186141967773, 16.445835420063563, 27.10736152103969, 39.255195890154155, 47.432735783713206, 49.379634925297324, 49.43738487788609, 51.54850121906826, 50.291599886757986, 51.60117203848702, 50.94237164088658, 50.65957995823452, 47.049723284585134, 44.793907233646934, 44.6250764301845, 45.70183529172625, 44.41829456601824, 44.47946998051235, 46.99416548865182, 50.593540804726736, 49.12673439298357, 43.893035071236746, 42.4367482321603, 38.162529127938406, 37.05390582765852, 36.86217376164028, 35.38579968043736, 35.35082592282976, 35.380609376089915, 37.15230969020298, 36.6408041545323, 35.93514510563442, 36.188059534345356, 39.160335608891074, 38.426901136125835, 41.36287634713309, 43.85590737206595, 47.746787411826, 47.41447244371687, 49.655732018607004, 41.55550820486886, 50.41183498927525, 49.18855946404593, 45.61983960015433, 39.86931937081473, 39.222018241882324, 42.7291944367545, 47.33241074425833, 47.66066101619175, 50.0693860735212, 48.218941824776785, 47.762681416102815, 50.913112776620046, 49.746680464063374, 48.136619567871094, 47.589942250932964, 45.77152919769287, 44.517969948904856, 45.3898229598999, 45.78163535254342, 47.98777525765555, 48.7540990284511, 48.96668611254011, 46.798455578940256, 45.69381707055228, 48.752566950661794, 49.43398720877511, 51.77940028054373, 48.41812930788313, 48.66040257045201, 50.52272476468767, 50.73538133076259, 49.86954893384661, 50.78078433445522, 48.760456630161826, 48.615079471043174, 45.34020587376186, 44.19413873127529, 29.18272590637207, 15.636894873210363, 10.224196927888052, 10.669556481497628, 10.994990995952062, 19.72958881514413, 14.349473578589302, 12.499024987220764, 14.51001865523202, 9.267992785998754, 8.080914769853864, 1.626254867230143, 0.16912198998034, 0.9902967810630798, 4.862723273890359, 16.998543773378643, 39.648960726601736, 41.24122381210327, 43.30472762244088, 47.37673677716936, 61.539395877293174, 53.5716290473938, 25.426371676581248, 4.849645461354937, 0.26089242632899967, 0.1300088430621794, 0.19875950392867836, 0.14961695804127625, 0.11007531625883919, 0.21849058302385466, 0.1052743960171938, 0.10122145206800529, 0.06082718353718519, 0.14166805600481375, 0.14969957646514687, 0.3072756145681654, 0.1595908799873931, 0.1598031935947282, 0.15419218396501883, 0.15332253277301788, 0.2293037170810359, 0.10335163812019996, 0.09201297869107553, 0.10435341365103211, 0.07238710645054068, 0.18864247894712857, 0.11474869905837945, 0.12287894636392593, 0.12499719698514257], [0.06851064945970263, 0.02303596193503056, 0.027941678517631123, 0.03715695760079792, 0.06653227883258037, 0.05672091352088111, 0.006960424519742706, 0.012212978093884885, 0.027068585456748093, 0.03450893397842135, 0.03676894074305892, 0.04125856947419899, 0.030907880780952315, 0.05167812268648829, 0.02932160161435604, 0.05167603279863085, 0.039141557179391384, 0.06168967618473938, 0.026407198714358465, 0.028956332643117224, 0.020504061099407927, 0.03521107183769345, 0.02421782914149974, 0.02724102495371231, 0.0190928897687367, 0.07337234608296837, 0.0454350101894566, 0.03172095572309835, 0.047990043980202506, 0.9174769456897462, 11.96639345373426, 33.4482284954616, 43.81487825938633, 39.926239013671875, 29.090862035751343, 25.43075598989214, 29.838931151798793, 29.901016780308314, 14.165067519460406, 3.9053214362689426, 0.4415278120764664, 0.12795869021543435, 0.5994475824492318, 1.1972544129405702, 3.1312860335622514, 3.8149401375225613, 3.0479200269494737, 3.949272700718471, 3.6782807963235036, 5.146168955734797, 9.755906581878662, 19.944208247320994, 31.390154702322825, 41.905065127781455, 49.57550811767578, 49.81713172367641, 47.415823868342805, 45.411880016326904, 46.50406387874058, 47.04863589150565, 48.12495354243687, 47.543312890189036, 45.728624071393696, 43.36596209662301, 43.21982410975865, 44.4130973134722, 43.273443358285085, 46.01658868789673, 46.870049817221506, 46.63249090739659, 43.53902782712664, 40.357218401772634, 35.959804262433735, 35.457015241895405, 36.33780363627842, 32.76106555121285, 34.73334298815046, 32.651325702667236, 34.70544597080776, 35.00501755305699, 38.63466617039272, 40.29303094318935, 41.3822375025068, 44.19546236310686, 44.93267665590559, 43.36579186575753, 44.142082827431814, 46.10977097920009, 45.846753869737896, 32.492305755615234, 44.65118081229073, 47.12287391935076, 41.07447052001953, 36.631993838718955, 35.94162777491978, 37.00811719894409, 40.08130196162632, 43.15709229878017, 45.342078413282124, 47.66447557721819, 46.34944214139666, 49.01393386295864, 46.119067668914795, 45.54198850904192, 43.13374982561384, 40.8452216557094, 37.099051748003276, 37.325573444366455, 38.125641141619, 42.875134399959016, 45.20886060169765, 48.50312314714704, 46.31023693084717, 46.08375344957624, 49.563119479588096, 48.81767504555838, 44.6655079977853, 43.222916058131624, 42.38887514386858, 43.37916714804513, 43.62463310786656, 47.60360588346209, 49.320140974862234, 52.369007042476106, 50.084025927952354, 44.40563494818551, 36.36000313077654, 21.793207270758494, 13.042830092566353, 6.314772146088736, 3.877364924975804, 13.502334441457476, 9.11617204121181, 4.599555475371225, 7.131464276994977, 7.819666845457895, 2.4240942554814473, 0.7983672884958131, 0.725985949592931, 0.13814036601356097, 0.39141916802951265, 5.626625597476959, 18.42553527014596, 35.608941078186035, 42.2950119291033, 27.255608286176408, 39.918641158512656, 44.557029247283936, 36.86580766950335, 15.118413346154348, 1.985613852739334, 0.02956066985747644, 0.014248840144968458, 0.03503304121217557, 0.038168280119342465, 0.015080693543755581, 0.013882990178119923, 0.060720945309315405, 0.019248216612530605, 0.10492846529398646, 0.10771708815757718, 0.046670018562248776, 0.026939144723915627, 0.02828706641282354, 0.0685904316071953, 0.06266051051872117, 0.0013890883024682157, 0.008947478274681737, 0.022970395096178566, 0.03362825319969228, 0.025992345796631913, 0.041354646640164514, 0.03834960163970079, 0.040435224904545715, 0.08434334131223814, 0.00044216567506997047, 0.04638280486688018, 0.022892862292272703, 0.04352448967152408, 0.058546003087290695, 0.0208464600478432, 0.05273648125252553, 0.008956063439005187, 0.039614448589938026, 0.03745304314153535, 0.022226569741698246, 0.008969037876730519, 0.030258980779243366, 0.011823337841113763, 0.03241279002811227, 0.026213846768119504, 0.012561710318550467, 0.07568180108708994, 0.06333934409277779, 0.03333164179431541, 0.07007836390818868, 0.01945424698559301, 0.021391708736440966, 0.01798261479208512, 0.05601623115528907, 0.011816616103585278, 0.018218283574762087, 0.008764418008338128, 0.07081810957086937, 0.024824456411546895, 1.6530184596776962, 15.914690801075526, 40.80365753173828, 49.33261299133301, 45.17947319575718, 33.554848602839876, 28.868637800216675, 34.59566443307059, 32.8966839654105, 15.844375031335012, 4.507599541119166, 0.5172700977751187, 0.08539809685732637, 0.5354270434805325, 1.6181531591074807, 3.362691227878843, 6.605201201779502, 5.414184425558362, 6.528524790491376, 4.6231628486088345, 5.868124570165362, 10.758742690086365, 23.089011566979543, 35.054718017578125, 42.35577392578125, 51.34762879780361, 51.60072387967791, 48.66120856148856, 48.25099733897618, 48.170387813023154, 48.18169948032924, 49.26445116315569, 47.041861397879465, 46.404708112989155, 44.766170024871826, 44.49701418195452, 45.917309352329795, 43.709112780434744, 47.391984598977224, 49.453376156943186, 49.386016845703125, 45.566748414720806, 41.225371497017996, 36.914229665483745, 36.942630427224294, 37.68695967538016, 34.759586334228516, 35.22314235142299, 33.799310547964915, 35.772751808166504, 36.14049564089094, 38.97598252977644, 41.56074367250715, 42.43368755068098, 45.97286714826311, 44.66964912414551, 44.168385233197895, 46.8306222643171, 46.622138091496055, 48.16352299281529, 35.273933683122905, 46.950628076280864, 47.72672101429531, 42.318184171404155, 38.46475144795009, 38.21972669873919, 39.461248193468364, 43.12562738146101, 45.57423162460327, 48.70111901419503, 49.242967333112446, 48.229079246520996, 49.93689782278878, 48.52222721917288, 46.820199966430664, 44.21366316931588, 42.69985566820417, 40.33479309082031, 39.320984908512656, 40.656991481781006, 44.970207350594656, 47.399446964263916, 49.8656370980399, 46.8081031526838, 47.13474491664341, 50.281841141836985, 50.334525857652935, 47.214187145233154, 44.48764453615461, 44.30514662606375, 45.25254045213972, 47.25830473218645, 49.9066036769322, 51.846092564719065, 51.56932149614607, 50.848359039851594, 45.8596636227199, 38.38017102650234, 23.963756765638077, 14.88722767148699, 6.473138962473188, 4.632780458245959, 10.321948528289795, 10.692503775869097, 8.088197350502014, 6.476151875087193, 5.76836667742048, 3.294931960957391, 1.481234563248498, 0.37942109469856533, 0.20445972734263965, 0.5149417998535293, 5.979873316628592, 18.8229044846126, 40.64349808011736, 44.34079088483538, 33.25564527511597, 44.35571908950806, 49.0483899797712, 43.30558919906616, 18.78201607295445, 2.730306361402784, 0.019265928072854877, 0.01835310848296753, 0.051060540468565056, 0.04289909073018602, 0.021478143919791495, 0.06339616461523942, 0.028492971256907498, 0.017279679654166102, 0.03760073646636946, 0.051500780774014335, 0.0866860920297248, 0.07626720038907868, 0.04908541323883193, 0.04207462318507688, 0.05333653012556689, 0.10983468059982572, 0.048373117710330656, 0.03708524662735207, 0.049275626960609636, 0.06294727977365255, 0.027012557123920748, 0.028835919818707874, 0.009459015647215503, 0.008977089542895555, 0.012931833359678941, 0.15822045638092927, 0.08678959576146943, 0.07830283258642469, 0.13063091039657593, 0.15663537143596581, 0.11604839217449937, 0.08111905146922384, 0.15573852456041745, 0.17862917482852936, 0.11945343017578125, 0.10866564618689672, 0.0768903601648552, 0.08354982174932957, 0.09754426045609371, 0.15754099855465548, 0.12977949822587626, 0.16556858351188047, 0.15058347689253943, 0.12732682483536856, 0.20811199636331626, 0.11865099466272763, 0.09881776890584401, 0.06368327313768012, 0.15397140224065098, 0.06693294697574206, 0.19243888237646647, 0.09778296229030405, 0.10865779553673097, 0.07213315114911113, 2.0577585186277116, 17.076070036206925, 44.75709220341274, 55.560922622680664, 51.33089058739798, 38.82799979618618, 35.28468949454171, 40.156137534550254, 38.282614844185964, 18.503773723329815, 6.0144267082214355, 0.8214394333107131, 0.36343174268092426, 1.9153002543108804, 3.2492786049842834, 7.651150447981698, 12.142602375575475, 12.426068033490862, 10.461234722818647, 8.31513854435512, 8.225440774645124, 13.875053184373037, 24.301050118037633, 37.28627790723528, 43.31465312412807, 52.61622742244175, 53.39799009050642, 51.28756162098476, 49.252079895564485, 50.37578078678676, 49.17447199140276, 51.15983288628714, 48.411257539476665, 49.02956730978829, 45.23999547958374, 45.085234778267996, 46.4448687008449, 44.202469621385845, 48.595787797655376, 50.49824626105172, 50.429299286433626, 47.76501948492867, 44.12698439189366, 40.103779384068076, 38.643615450177876, 40.191486494881765, 35.50227580751692, 37.80587462016514, 35.47397926875523, 38.26899637494768, 39.165380001068115, 41.654294218335835, 44.15758078438895, 43.9270465033395, 48.888338225228445, 48.10655123846871, 46.198791299547466, 48.3462849344526, 49.0423971584865, 49.763845988682334, 39.06894942692348, 49.24121986116682, 50.764831270490376, 44.28922135489327, 40.439815112522666, 40.556881836482454, 39.88875348227364, 44.303715297154014, 47.047631876809255, 49.43093694959368, 49.31999158859253, 48.599491187504356, 51.960390431540354, 50.089421204158235, 49.267723764692036, 46.35926342010498, 44.80156067439488, 40.17675631386893, 40.984314169202534, 40.73376907621111, 46.02116060256958, 49.59002637863159, 51.77705526351929, 46.458431584494456, 47.55704253060477, 52.236949580056326, 51.320072242191856, 50.31936488832746, 46.776457582201274, 46.20450619288853, 46.29200138364519, 48.768061433519634, 50.838120869227815, 51.98394135066441, 54.30574791772025, 52.803870473589214, 46.704863343920024, 39.74992847442627, 26.430379424776348, 17.808616876602173, 9.426346574510847, 7.654822570937021, 19.90040680340358, 15.254212413515363, 13.355265395981924, 15.148667539869036, 18.674414532525198, 11.154008337429591, 3.426797262259892, 1.5956706340823854, 0.6214096982564244, 0.8644517681428364, 7.772278394017901, 23.39313769340515, 44.895295347486226, 51.723425592694966, 39.22677080971854, 51.111157281058176, 56.73641538619995, 48.56947149549212, 22.400389501026698, 3.2800289435046057, 0.08042035717517138, 0.081267474219203, 0.20441706106066704, 0.10575919571731772, 0.1558898650109768, 0.1445356264178242, 0.12367002320076738, 0.08664794479097639, 0.11097177636942693, 0.2511785461434296, 0.11294114962220192, 0.15657305477985314, 0.20288074921284402, 0.14372781690742287, 0.2221819899444069, 0.1415432191320828, 0.10502137709408998, 0.12219064044100897, 0.13988824508019856, 0.08195125431354557, 0.12354863328593117, 0.21047190044607433, 0.13821082508989743, 0.12184504898531096, 0.10136759494032178], [0.03235693641805223, 0.04099041582750423, 0.03942663009677615, 0.03139118770403521, 0.04455222934484482, 0.008818278421780892, 0.01514978876470455, 0.015892606494682174, 0.01884563160794122, 0.020852258129577552, 0.03406877170449921, 0.028154472188491906, 0.05815733822860888, 0.06756765541753598, 0.010115889283562345, 0.01643716816657356, 0.036870680283755064, 0.0686615217210991, 0.03513238213158079, 0.047901481589568515, 0.021342379240585223, 0.02629049408382603, 0.07313422100352389, 0.030144332109817436, 0.011147701863332518, 0.031946829852781126, 0.003944815577207399, 0.010564428072289696, 0.05688787724024483, 0.41549342764275415, 6.745746323040553, 29.07948088645935, 39.269283362797324, 44.53625760759626, 25.940382037843975, 23.770801816667827, 23.334281240190776, 28.31227990559169, 21.575996160507202, 6.29997422013964, 0.9964037047965186, 0.10323396657726594, 0.5512332724673408, 1.6240003939185823, 1.6668309356485094, 5.271519235202244, 2.6784691086837222, 5.359124294349125, 2.7515572096620287, 4.3312312449727735, 10.674851877348763, 17.919167927333287, 31.971371514456614, 40.97345413480486, 45.32095241546631, 51.84943464824131, 48.4066230910165, 43.59333494731358, 45.66068458557129, 44.301422391619, 43.560341426304404, 47.1452888080052, 46.00476285389492, 44.33583334514073, 44.749678475516184, 45.42736060278756, 45.42542552947998, 44.86446271623884, 47.59640754972185, 46.214904172079905, 43.27970715931484, 40.09675475529262, 35.084636960710796, 33.81965487343924, 33.79438080106463, 31.72207362311227, 31.995096138545446, 34.698744433266775, 35.995726449149, 42.017744064331055, 45.66728884833199, 44.92670120511736, 44.935098103114534, 44.99806615284511, 46.86942795344761, 44.93180465698242, 46.81393616540091, 46.034205845424104, 44.9473443031311, 32.08719103676932, 45.48919262204851, 45.896277155194966, 42.468362535749165, 38.80677999768938, 35.04562282562256, 34.92671830313546, 35.56482349123274, 38.07023273195539, 42.99880886077881, 45.87356349400112, 46.926969460078645, 45.358781882694785, 45.996751580919536, 42.35231024878365, 38.89347614560808, 36.14753416606358, 35.70429120744978, 35.8784304346357, 39.512546743665425, 43.845752579825266, 44.15078544616699, 46.50057935714722, 45.208134514944895, 45.72903054101126, 47.904626165117534, 47.09380265644619, 44.267108712877544, 39.66785287857056, 40.44904579435076, 44.56984519958496, 45.239623750959126, 47.870215211595806, 46.567316804613384, 48.93840347017561, 54.632865633283345, 46.155382428850444, 31.388167517525808, 19.61994276727949, 10.506918260029384, 3.929553278854915, 6.19909462758473, 7.10595657144274, 6.885869341237204, 5.38768356187003, 5.460095516272953, 4.5326391117913385, 1.2988887535674232, 1.0897615466799055, 0.15082576817699841, 0.04165010453600969, 1.1755650682108743, 6.717835409300668, 16.034929377692087, 23.353206396102905, 45.07705327442714, 34.94056258882795, 37.138520990099224, 47.89603124346052, 31.751474925449916, 9.19446347440992, 1.3529802624668394, 0.02310415300806718, 0.020490336032318215, 0.037791767822844644, 0.10295547544956207, 0.0794165867513844, 0.09571072991405215, 0.026602567605940357, 0.046951152583850284, 0.019086669298953245, 0.0414921076569174, 0.06280366105160543, 0.055865243542939425, 0.015614327409171631, 0.053236978860305886, 0.01366028395880546, 0.06094412226229906, 0.030736021431429044, 0.049653784704527686, 0.05843402445316315, 0.01850572118668684, 0.03535174571775964, 0.04557593173480459, 0.021229272541989173, 0.03026274325592177, 0.08680555490510804, 0.08216471464506217, 0.06858694393719945, 0.01874340691470674, 0.04092499826635633, 0.02022273199898856, 0.022657699018184627, 0.03593667343791042, 0.013495963981508144, 0.05094766616821289, 0.030035488307476044, 0.030436237874839987, 0.02570499469792204, 0.019869391673377583, 0.015618098367537771, 0.053604286829275746, 0.006938751687162689, 0.03574488551488944, 0.03603502708886351, 0.05294780759140849, 0.021726379171013832, 0.042930795278932364, 0.03738315403461456, 0.057283052642430575, 0.030898116662033966, 0.01254142975501184, 0.023888955092323676, 0.03400879938687597, 0.027381792132343565, 0.031018885717328106, 0.514349140226841, 9.591651167188372, 34.508426325661794, 46.34959152766636, 48.14665624073574, 30.515213217054093, 26.22557258605957, 31.945166383470806, 30.678117207118444, 22.385707957404, 7.178261263029916, 1.048001678926604, 0.11358424475682632, 0.27135736335601124, 1.5665171870163508, 3.3491613481725966, 6.567648359707423, 5.689925857952662, 6.820218852588108, 4.88565536907741, 6.686393942151751, 11.238663452012197, 20.71103228841509, 31.373433862413677, 43.920105252947124, 46.64396933146885, 53.43690695081438, 49.62821020398821, 46.56548942838396, 46.73397977011544, 46.91934381212507, 46.063937187194824, 48.981669902801514, 46.358075278145925, 45.37320981706892, 44.64948197773525, 44.626271520342144, 44.708440916878835, 45.71475199290684, 48.71243762969971, 47.10617044993809, 45.01650319780622, 41.31039660317557, 37.55070202691214, 35.53171532494681, 34.190699100494385, 32.669700213841026, 34.784856932503835, 35.713344710213796, 38.45866482598441, 42.602049350738525, 47.80537462234497, 47.71372093473162, 46.99920988082886, 46.909939425332205, 47.8155745778765, 46.45546122959682, 49.65938677106585, 48.15372950690133, 46.81359222957066, 35.2889278956822, 47.26655224391392, 46.95204898289272, 42.84233890260969, 40.20747777393886, 37.307848589760916, 37.49148947851998, 37.37284551348005, 40.794510228293284, 46.21202761786324, 48.02108144760132, 48.38899898529053, 47.934691020420615, 47.537403447287424, 45.16517032895769, 42.32615722928728, 39.62081010001046, 37.077286515917095, 37.35973426273891, 40.57307461329869, 45.82835156576974, 46.63262987136841, 49.20103842871529, 46.41469267436436, 45.84702832358224, 49.71385717391968, 49.063307762145996, 46.72274800709316, 42.504986490522114, 42.2188527243478, 47.382253646850586, 46.82271521432059, 48.37552990232195, 50.336704117911204, 50.33766644341605, 55.358135972704204, 45.645186628614155, 34.59707491738455, 21.911724431174143, 12.911563856261116, 5.433313250541687, 3.352722082819257, 6.581961214542389, 8.800544909068517, 5.759252377918788, 6.860213986464909, 6.672975667885371, 3.427765016044889, 1.5081174692937305, 0.30440796273095266, 0.12679944027747425, 0.7757996480379785, 7.959268314497812, 19.459694726126536, 29.231596061161586, 49.91174186979021, 35.29050166266305, 43.483963353293284, 53.0576742717198, 37.96605839048113, 12.033116136278425, 1.663213095494679, 0.008217382228134998, 0.008775369563539113, 0.04909963872549789, 0.027831491215952804, 0.08021516140018191, 0.015434508843879615, 0.027248972295118228, 0.05867144385618823, 0.01965607892322753, 0.06109826506248542, 0.03199328575283289, 0.07381098504577364, 0.022372753326115862, 0.01729055487417749, 0.014095822016575506, 0.03637935646942683, 0.04915721242183021, 0.04540244050856147, 0.0261767987561013, 0.03257482758324061, 0.022814082680270076, 0.024051487978015627, 0.09074952613030161, 0.011303979504321302, 0.042618977903787575, 0.14925018272229604, 0.17858014388808183, 0.09851898279573236, 0.12838570587337017, 0.10048628651670047, 0.05917926624949489, 0.19486455007323197, 0.1026446521282196, 0.08927600591310433, 0.09876434784382582, 0.17826378372098717, 0.1748534802879606, 0.16552816996616976, 0.13952323395226682, 0.22456507278340204, 0.11762396405850138, 0.10959892360759632, 0.14850079507700034, 0.19407857581973076, 0.10987778114421026, 0.11162789259105921, 0.08985273353755474, 0.25086647431765285, 0.10597486128764493, 0.1864396557211876, 0.14211747688906534, 0.14220215805939265, 0.07551783988518374, 0.1754631440022162, 0.8295451040778841, 11.423383917127337, 39.00369889395577, 51.63430104936872, 55.762191091264995, 36.43313292094639, 34.16969469615391, 32.82676771708897, 38.00540256500244, 28.26917849268232, 8.901747158595494, 1.6614269741943903, 0.41110637305038317, 1.042772616658892, 5.840788185596466, 7.057481595448085, 12.17844465800694, 11.377780284200396, 11.418852823121206, 8.346153565815516, 9.073368532317025, 13.513619184494019, 22.927036898476736, 35.617525577545166, 45.468622480119976, 49.78283541543143, 55.19498879568917, 52.04571778433663, 46.42040409360613, 49.87771654129028, 48.66747236251831, 47.77218655177525, 50.291308062417166, 47.800507409232004, 44.50611979620797, 44.6219288962228, 44.45554733276367, 45.79844651903425, 47.12958240509033, 50.21987015860421, 48.53246191569737, 45.87489407403128, 43.616673946380615, 38.272248131888254, 37.43061978476388, 36.69081033979143, 34.29482133047921, 35.508199146815706, 37.79384381430489, 40.064744404384065, 45.848400592803955, 49.287178720746724, 49.211255754743306, 48.68390485218593, 48.373473235539024, 49.40657309123448, 49.375393050057546, 51.50677033833095, 49.33167845862252, 46.01674154826573, 37.02695376532418, 49.81540509632656, 48.576107025146484, 46.775446619306294, 41.95082943780081, 39.66018206732613, 38.39728791373116, 39.56050321034023, 42.615685190473286, 47.27804456438337, 50.85017946788243, 49.88585288184029, 49.6543528011867, 49.366301332201274, 46.560792446136475, 43.12282378332955, 40.406783376421245, 39.81702722821917, 39.24021209989275, 43.85217271532331, 47.4037617955889, 47.75650446755545, 49.94427680969238, 45.621236188071116, 45.754485266549246, 51.12736742837088, 51.10720028196062, 49.743327958243235, 43.69893019539969, 44.13658332824707, 49.33502401624407, 47.748465401785715, 50.49675587245396, 51.387098039899556, 51.1115984916687, 57.02508871895926, 50.62035737718855, 38.243263721466064, 23.547043766294205, 15.62263890675136, 4.910808282239096, 13.058414033481053, 15.50410611288888, 15.115373509270803, 13.95919586930956, 13.335011397089277, 9.12049034663609, 6.050871746880667, 4.04036488703319, 1.005893424153328, 0.26357111973421915, 1.8522360154560633, 9.062205382755824, 22.137756279536656, 31.08590350832258, 53.00188371113369, 45.78623158591134, 50.15153809956142, 60.8294289452689, 44.10939850125994, 14.727420840944562, 1.8621235191822052, 0.09144870218421731, 0.10682986290859324, 0.2812996655702591, 0.20974295027554035, 0.20764306081192835, 0.16258410151515687, 0.17537382165236132, 0.14907676274222986, 0.20855058782867023, 0.22549723062132085, 0.09875877028597252, 0.15309351363352366, 0.10351409297436476, 0.10537093797964708, 0.09316193525280271, 0.2071849275380373, 0.110192689246365, 0.13567925164742128, 0.15177961199411324, 0.13744057927812847, 0.1627484562673739, 0.1055255625396967, 0.14090690256229468, 0.10119224792080266, 0.14718595705926418], [0.011107875250412949, 0.020351446699351072, 0.028203067170189958, 0.032035443133541515, 0.039148539304733276, 0.05270952984158482, 0.01762437035462686, 0.07946989246244941, 0.10009254621607916, 0.025252001326797262, 0.01556193602404424, 0.054745857537324936, 0.07872207223304681, 0.013161385149162794, 0.04186655381428344, 0.04449635537873421, 0.06332264534596886, 0.03920625549341951, 0.02755177702887782, 0.06447746445025716, 0.021277665659519177, 0.016174095050830926, 0.03466477311615433, 0.05683834757655859, 0.06464412622153759, 0.025810852946181382, 0.04062182203467403, 0.03659028247264879, 0.03344587655737996, 0.05753974922533546, 4.046400700296674, 19.458447524479457, 44.518619605473106, 42.72601563589913, 41.65955400466919, 26.94715690612793, 20.044439486094884, 35.79313434873308, 22.575781141008648, 10.852516446794782, 2.009551916803632, 0.17763160621481283, 0.13851658654000076, 0.7369304480297225, 2.1620670471872603, 3.868407828467233, 3.255875268152782, 5.294904266084943, 2.2031387175832475, 3.620157378060477, 6.215967893600464, 17.698659896850586, 27.766365153448923, 42.87215709686279, 52.26369667053223, 53.64184406825474, 48.26654045922415, 44.21525778089251, 43.29298169272286, 42.894075189317974, 44.686738218579976, 46.86401183264596, 45.57919263839722, 43.69584172112601, 42.890448229653494, 46.390710966927664, 45.770949023110525, 47.626816340855186, 46.6948162487575, 47.06455421447754, 42.68760599408831, 38.8552680015564, 35.205195154462544, 33.59455060958862, 33.589509691510884, 37.06062820979527, 32.6074651990618, 35.295629433223176, 42.42850766863142, 44.59668261664254, 47.6372594833374, 46.99611445835659, 47.99363953726632, 49.49981444222586, 47.80165386199951, 45.783125741141184, 46.91681466783796, 43.58842257090977, 44.61103412083217, 30.967485359736852, 42.487706320626394, 46.95124299185616, 42.35655559812273, 41.80416686194283, 35.08121844700405, 33.100842884608674, 31.921754428318568, 34.060861587524414, 36.03556047167097, 38.45511082240513, 41.625625950949534, 40.66078519821167, 40.570354393550325, 39.75044958932059, 37.22279221670968, 33.46605409894671, 32.9218225479126, 37.88612631389073, 42.43263489859444, 45.16545173100063, 46.44124174118042, 48.781019823891775, 45.00651863643101, 48.547945976257324, 48.66060406821114, 45.21409606933594, 41.90371370315552, 38.52534668786185, 40.30461706433977, 45.130752427237375, 45.94160720280239, 49.16108281271798, 48.2283045223781, 44.21152312414986, 43.94319759096418, 49.242981229509624, 34.31373085294451, 20.28133658000401, 12.292708652360098, 6.955541968345642, 2.106125580413001, 3.097697355917522, 6.780921578407288, 5.035910163606916, 4.704777257783072, 4.270603435380118, 2.7063218312604085, 0.4623190207140786, 0.2256427492414202, 0.37778376255716595, 1.7207942285708018, 9.603728004864283, 22.302934067589895, 33.62306949070522, 34.75073780332293, 46.56428739002773, 37.51137522288731, 40.544493198394775, 28.507597242082866, 8.296248997960772, 0.29837019528661457, 0.04183360754645296, 0.02141778144453253, 0.038633419267301045, 0.03618015215865203, 0.024005132161879113, 0.013892917993611522, 0.08124532683619431, 0.02223138394765556, 0.03525394168017166, 0.028179829042138796, 0.03868345783225127, 0.03142240031489304, 0.03285194807020681, 0.1008886442120586, 0.0347345672281725, 0.06639613756643874, 0.05740159271018846, 0.039664622861891985, 0.04230860920090761, 0.04067026943500553, 0.015621543629094958, 0.11101758426853589, 0.04523272193702204, 0.07030011593763318, 0.04783944652548858, 0.03131876426881977, 0.0244212963485292, 0.019286772668627754, 0.0324004780101989, 0.044905389858675857, 0.02900332458583372, 0.0017065638114997584, 0.025572724474061812, 0.028542117548308203, 0.05721719403352056, 0.03467692228566323, 0.027484327255349075, 0.04301376993368779, 0.0487842590415052, 0.028762261449758495, 0.05350126146471926, 0.02431056961151106, 0.0179191938202296, 0.04038893524557352, 0.02459893172739872, 0.0172814879499908, 0.03827240131795406, 0.03281062528757112, 0.054708463472447226, 0.014299389307520219, 0.034787275828421116, 0.0155213426665536, 0.05328966371182885, 0.01931913030732955, 0.16138354236526148, 5.672240521226611, 25.17888900211879, 48.78375046593802, 48.4145370892116, 42.43856866019112, 30.54171712057931, 21.551715680531093, 39.064422675541465, 27.22599332673209, 11.22779299531664, 1.9748033242566245, 0.11536381819418498, 0.13851992493229254, 0.8737620828407151, 2.2261300895895277, 4.667543164321354, 4.74272050176348, 5.834025417055402, 5.152382382324763, 7.004066450255258, 8.586473516055516, 18.71037667138236, 31.334652491978236, 43.74268300192696, 51.234699726104736, 53.611911228724885, 51.190116609845845, 46.59331348964146, 44.947601386478965, 44.44183506284441, 47.57802956444876, 48.282966000693186, 46.99999155317034, 44.92796925136021, 44.59278467723301, 47.00888524736677, 46.92198412758963, 48.51244068145752, 48.612484318869456, 48.07219239643642, 43.62147862570626, 39.870920930589946, 36.95774275915963, 34.99124622344971, 34.13438395091465, 37.504691055842805, 33.62743295942034, 37.14892244338989, 44.20374114172799, 47.06494678769793, 49.639309951237266, 48.922877720424104, 50.04409463065011, 47.96164655685425, 48.52041026524135, 45.96863916942051, 47.80747645241873, 45.397698743002756, 47.58640561785017, 34.721211433410645, 44.745999404362266, 49.0138817514692, 43.80358048847744, 42.859441893441335, 35.957282066345215, 33.516536235809326, 34.892904894692556, 36.06323862075806, 38.50836876460484, 40.49416044780186, 43.970646449497764, 42.24178525379726, 42.270463943481445, 41.607960156032014, 39.174117360796245, 35.50625712530953, 35.827489716666086, 38.21590518951416, 44.961407457079204, 46.50825016839163, 49.704782826559885, 49.57070343835013, 46.24198477608817, 47.60081270762852, 49.09496375492641, 45.80337974003383, 44.05866970334734, 40.50060142789568, 42.328853130340576, 46.83553811482021, 48.10624204363142, 49.03081451143537, 49.703282015664236, 46.00912979670933, 48.85449007579258, 51.11655950546265, 36.51181084769112, 21.47769478389195, 14.50231397151947, 7.070698806217738, 5.39808588368552, 7.343629258019583, 9.131242683955602, 7.0845339723995755, 7.697057196072169, 7.192750428404127, 2.498551151582173, 0.9743299292666572, 0.24838957722697938, 0.19104674564940588, 2.132421689374106, 9.555467554501124, 22.128688880375453, 34.26222733088902, 38.542366300310405, 51.59302180153983, 40.976295948028564, 48.05186196735927, 33.85410751615252, 10.440258979797363, 0.5947215046201433, 0.031001423618623188, 0.04814854636788368, 0.06488860238875661, 0.005278560549153813, 0.06067646733884301, 0.03861921074401055, 0.02241164695338479, 0.08400138680424009, 0.0342706935480237, 0.025430210067757537, 0.014127607989524091, 0.0875687168112823, 0.012399465810241444, 0.017418947270406143, 0.018108500001419867, 0.05281021426032696, 0.0533224199898541, 0.06036829708942345, 0.024071033179227794, 0.03707546893773334, 0.007322180800006858, 0.07017365736620766, 0.07160646548228604, 0.01938104153876858, 0.02592483495495149, 0.13430350832641125, 0.1211823509739978, 0.09466653915920428, 0.11574269857789789, 0.13439924961754254, 0.10521064765219178, 0.14996316017849104, 0.18647325677531107, 0.17497880570590496, 0.138645508193544, 0.11345430530075516, 0.12433718597250325, 0.1425900493881532, 0.11426001813794885, 0.09987636495913778, 0.17925893675003732, 0.12865861265787057, 0.15446259374065058, 0.10248954580830676, 0.08553048582481486, 0.05521339869924954, 0.09967125060835055, 0.06457220150956086, 0.15422840416431427, 0.12870372166591032, 0.12309758391763483, 0.11068924117301192, 0.07469536044767924, 0.06289288162120751, 0.3062804208270141, 6.6902541007314404, 27.49506058011736, 55.35665948050362, 56.394035952431814, 52.70641156605312, 37.297172682625906, 29.09768169266837, 46.74107388087681, 30.018628937857493, 14.747174569538661, 2.6294178664684296, 0.45879726111888885, 0.7645760274359158, 1.951293008668082, 6.814304632799966, 11.03543906552451, 12.337757297924586, 12.0286579983575, 6.85311553307942, 7.483744893755231, 8.182572994913373, 20.571614946637833, 32.229365076337544, 44.724209853581016, 52.37005969456264, 56.63260929925101, 52.76300464357649, 48.57906000954764, 47.97688743046352, 47.241455350603374, 49.68205526896885, 50.59110198702131, 47.85276828493391, 44.96534708568028, 44.302113737378804, 47.70233283724104, 46.815593310764854, 49.893016474587576, 50.24976478304182, 50.291110038757324, 45.99181488582066, 41.60030671528408, 38.016474519457134, 36.91253777912685, 35.71230248042515, 39.74803161621094, 36.16987609863281, 38.60420874186924, 46.24952009746006, 48.55612400599888, 51.17288160324097, 49.220635822841096, 50.51822928019932, 50.783952713012695, 50.10916798455374, 47.35700041907174, 49.223199708121165, 44.97260447910854, 46.83034781047276, 37.5688715662275, 45.39144883837019, 50.666034834725515, 45.4185676574707, 46.09138604572841, 37.297704219818115, 34.79885755266462, 35.04001562935965, 37.29092277799334, 40.23627805709839, 41.5291919027056, 44.82624762398856, 43.86244910103934, 44.0903673853193, 43.00436394555228, 39.618732588631765, 36.79909454073225, 36.469538007463726, 40.748787607465474, 47.19583347865513, 48.784949030194966, 51.17502164840698, 49.24762610026768, 45.99553912026541, 49.15086548668997, 50.30501338413784, 48.170141151973176, 44.801404339926584, 41.64193337304251, 43.72613934108189, 49.26122372491019, 50.376089981624055, 50.37543337685721, 51.70676381247384, 46.66502237319946, 50.6449852670942, 54.07062782560076, 39.27819790158953, 23.489686386925833, 17.282172713960918, 11.325959750584193, 7.4822006566183905, 10.658020734786987, 14.897601331983294, 13.241973280906677, 12.437875628471375, 12.246861832482473, 7.555518916675022, 2.7464958812509264, 1.1855021864175797, 0.8243675561887878, 2.652879544666835, 12.555391379765101, 28.63774221284049, 42.92247595105852, 43.831130095890586, 57.322669642312185, 50.847097941807334, 55.24172237941197, 39.26806395394461, 12.704067196164813, 0.634742042848042, 0.16451618926865713, 0.08790805217410837, 0.1222859610404287, 0.11518794191735131, 0.1405742982668536, 0.07216874031083924, 0.13841321851525987, 0.1527228842356375, 0.1174353448940175, 0.09269658915166344, 0.09762689245066472, 0.12446792609989643, 0.12313930025058133, 0.13688629759209497, 0.15778806672564574, 0.16121040736990316, 0.13502651453018188, 0.20199805657778466, 0.09940301893012864, 0.13391051441431046, 0.11976392780031477, 0.20268097493265355, 0.1502622448440109, 0.1447495413678033, 0.16983711160719395], [0.1308774221688509, 0.05056736764631101, 0.039553533108638864, 0.022553667725462998, 0.07494414531226669, 0.017039033817127347, 0.10285578508462224, 0.06521896073328597, 0.04731865393530045, 0.07565143664500543, 0.040116768064243455, 0.09158765937068633, 0.030901811285210506, 0.05973377185208457, 0.03108102934701102, 0.020977011881768703, 0.01889570918865502, 0.029446832037397792, 0.028374958750126616, 0.014452224231458135, 0.030060624637241875, 0.03896033065393567, 0.020984647097066045, 0.03419306914189032, 0.041616493303860934, 0.0215073582450194, 0.09028924190040145, 0.02827972127124667, 0.02642198059973972, 0.04504901536607316, 2.47867865221841, 17.41313930920192, 39.632146086011616, 50.96216705867222, 39.96496132441929, 24.890163557870046, 34.19802597590855, 19.901181527546473, 26.348743302481516, 14.488553932734899, 3.3951510403837477, 0.38530198484659195, 0.11470479784267289, 0.7404414053474153, 1.2925528649772917, 4.216929904052189, 4.0355576021330695, 3.771551242896489, 5.262135693005153, 6.2629676801817755, 8.491828628948756, 14.853066853114537, 31.3605796950204, 46.72090326036726, 45.815782274518696, 45.68630954197475, 44.8681035723005, 45.484367098127095, 42.7822265625, 41.64379896436419, 45.68198776245117, 45.15422344207764, 46.033281735011506, 44.4667513029916, 47.87815352848598, 44.8102250780378, 45.86905411311558, 47.326813970293315, 44.64586891446795, 42.42057977403913, 40.45930480957031, 36.21522699083601, 33.552861418042866, 34.312243938446045, 34.06076431274414, 35.860160146440776, 33.065403597695486, 37.062375681740896, 42.41815137863159, 44.86486571175711, 46.87825911385672, 47.75786631447928, 45.94777372905186, 45.11546639033726, 47.40128476279122, 46.478616101401194, 46.75411912373134, 44.39951358522688, 45.30963032586234, 31.36699983051845, 42.062532152448384, 48.62712417330061, 41.35214485440935, 45.65403168542044, 39.46074444907052, 38.71827384403774, 33.54185547147478, 33.35056114196777, 32.3344635282244, 32.67673526491438, 34.58154569353376, 34.87179626737322, 33.99581255231585, 34.48342670713152, 33.67653587886265, 34.45183672223772, 36.63686452593122, 42.925067629132954, 44.670941489083425, 45.94396264212472, 48.72336367198399, 48.00225877761841, 46.26576151166643, 46.946014472416465, 47.595636299678254, 44.915445123400005, 40.73340776988438, 37.625214508601594, 41.25537381853376, 44.68394504274641, 46.29378359658377, 49.56747252600533, 51.57240302222115, 46.7948112487793, 40.61657381057739, 35.01602349962507, 32.16103301729475, 18.594647475651332, 10.272738780294146, 6.684853179114206, 2.900969535112381, 4.138123869895935, 6.457882021154676, 2.9090088180133273, 6.350378624030522, 6.849905465330396, 1.7010238894394465, 0.7498515461172376, 0.1689242377345051, 0.3053118527999946, 2.8644895383289883, 13.484967419079371, 27.77279223714556, 32.32223817280361, 28.112220423562185, 34.199815137045725, 44.77770750863211, 44.49265766143799, 25.10892759050642, 5.3839232836450845, 0.23141602373548917, 0.07147719099053315, 0.04278716637885996, 0.024541356334728853, 0.06791896692344121, 0.04589495175917234, 0.058755975748811445, 0.03166298847645521, 0.05545312851401312, 0.07904253753700427, 0.04148107807018927, 0.03353564674034715, 0.05386110894115908, 0.025771548805226172, 0.026137453903044974, 0.015215367477919375, 0.0450308238422232, 0.013310773963374751, 0.05306735189099397, 0.06610712236059563, 0.01687152896608625, 0.042049164551177194, 0.01392699487041682, 0.06913553271442652, 0.029975098690816333, 0.04531711133729134, 0.010541100038348563, 0.021658742800354958, 0.055830556832786114, 0.07416854585920062, 0.030018965979771953, 0.07991531677544117, 0.030870289940919195, 0.09738966982279505, 0.02905694242300732, 0.03319409256801009, 0.015174400926168476, 0.04316957175199475, 0.026565083635172675, 0.03390886814200452, 0.011770083868343915, 0.03297266284269946, 0.042381042814148326, 0.016290543534393822, 0.03586851120261209, 0.013223317584821155, 0.060820418543049266, 0.052164018220667324, 0.022736378546272005, 0.0434710143267044, 0.03315556874232633, 0.0456967211461493, 0.05392597349626677, 0.02392063249966928, 0.06787285368357386, 0.053656360999281914, 3.1420357653072903, 20.13807167325701, 46.56831734521048, 53.20229755129133, 47.69526999337332, 28.530149357659475, 32.02716554914202, 27.52818785394941, 27.90163963181632, 15.827450956617083, 3.4906918108463287, 0.2820116659360272, 0.05082023389903562, 0.7493876995784896, 2.461482729230608, 5.318383097648621, 6.2112326962607245, 4.5214225479534695, 5.058951692921775, 5.961200467177799, 10.179421867643084, 17.1539089679718, 30.518454551696777, 46.97209106172834, 48.127117906297954, 50.133250440870015, 48.952428409031455, 47.36452531814575, 45.19011436189924, 44.79955611910139, 46.388157503945486, 47.12198454993111, 46.681711946214946, 45.45036956242153, 48.31384032113211, 46.43728126798357, 47.41725172315325, 48.664356095450266, 46.04962042399815, 43.91726343972342, 43.64080156598772, 38.19428586959839, 35.686813013894216, 35.821691444941926, 35.72310692923409, 38.25373465674264, 35.70331845964704, 40.05994667325701, 42.7265749658857, 48.732757636478965, 49.12995488303048, 49.78212669917515, 48.738375255039756, 47.9765157018389, 49.48676919937134, 47.56012405667986, 47.688558033534456, 44.456106662750244, 45.554905210222515, 33.948613439287456, 44.66912800925118, 49.440289224897114, 44.361531257629395, 46.87024784088135, 39.49172646658761, 39.648140839168, 34.22717366899763, 35.10640566689627, 33.23103128160749, 35.09525033405849, 37.27753012520926, 37.16216570990426, 34.77132878984724, 36.86435202189854, 36.137198720659526, 36.53292294910976, 37.27343416213989, 43.87242324011666, 46.003234250204905, 47.145973205566406, 50.382999965122764, 48.371357509068076, 47.169631821768625, 47.540224415915354, 49.18230955941336, 48.12857355390276, 43.62778064182827, 39.36886147090367, 43.777552536555696, 45.608715534210205, 48.975875105176655, 50.622841358184814, 51.10742957251412, 48.427078587668284, 44.09718704223633, 40.11265918186733, 33.61479418618338, 20.9859881401062, 11.375458717346191, 6.808552392891475, 4.786627905709403, 5.543593321527753, 7.109777646405356, 9.104376605578832, 5.8904165625572205, 5.163355759211949, 1.5074981025287082, 0.9528973421880177, 0.14963450495685848, 0.5016566812992096, 3.0922834064279283, 15.395035028457642, 30.708953312465123, 35.02213791438511, 34.224116461617605, 40.27732106617519, 49.575949328286306, 48.30691991533552, 29.78252567563738, 6.914503736155374, 0.2742111459374428, 0.0542879753213908, 0.0406803253239819, 0.02397915275235261, 0.018612006912007928, 0.034376002182917934, 0.06213726502444063, 0.05107801953064544, 0.04193840728008321, 0.05324907374701329, 0.06585643081260578, 0.05296534772164055, 0.0306556184243943, 0.04052792975146856, 0.0475952994477536, 0.05525299800293786, 0.05820997219000544, 0.05340709776750632, 0.038178756700030396, 0.042725375587386746, 0.016703635653746978, 0.058790662458964756, 0.06494834739714861, 0.028896384074219635, 0.023701750673353672, 0.07022628454225403, 0.19268516344683512, 0.12684046450470174, 0.11114386642085654, 0.2631156327469008, 0.15581192847873482, 0.15003406708793982, 0.23417122874941143, 0.1523342193769557, 0.11372788383492402, 0.10946466188345637, 0.09152735117822886, 0.20880288071930408, 0.07816213156495776, 0.10661875709359135, 0.10665471266422953, 0.1915175403867449, 0.15107175069195883, 0.09311874649886574, 0.12805634497531823, 0.19060449009495123, 0.16071084274777345, 0.17932417110673018, 0.10368512451116528, 0.20070297749979155, 0.13965229131281376, 0.09604968529726778, 0.22654558079583303, 0.11753856364105429, 0.19322994564260754, 0.1788221908999341, 3.531932843582971, 23.315314395087107, 50.43067850385393, 61.58346830095564, 53.07356480189732, 36.255672454833984, 43.42193678447178, 30.829389912741526, 34.90402896063668, 19.39223119190761, 4.718532519681113, 0.639752671122551, 0.40824789500662256, 2.767253407410213, 3.57128244638443, 10.969861098698207, 9.411476561001368, 9.835064802850995, 11.05722861630576, 10.87969606263297, 13.713914905275617, 19.13182486806597, 33.59546429770333, 49.62949562072754, 50.640052046094624, 51.384791237967356, 50.33889627456665, 51.0634891646249, 47.02017954417637, 45.95918961933681, 49.91864490509033, 49.318504674094065, 47.25842979976109, 44.9618695122855, 47.72635623386928, 45.87883717673165, 49.7727883202689, 50.3413211958749, 49.040135519845144, 45.68810565131051, 44.780420780181885, 40.20204428264073, 37.0181017603193, 38.18140043531145, 37.979353768484934, 39.81793049403599, 37.51155240195138, 42.847487517765586, 43.799296924046104, 50.42454324449812, 50.689710821424214, 51.079282420022146, 50.603494099208284, 48.177377700805664, 50.49923985345023, 48.59540217263358, 49.34678036825997, 46.122319425855366, 46.42645597457886, 38.212872300829204, 46.74722303662981, 50.66465561730521, 45.07952683312552, 48.40187399727957, 41.04152911049979, 41.40996081488473, 36.476364612579346, 37.027054514203755, 35.75490536008562, 35.582332951681956, 37.83572408131191, 38.12274374280657, 35.92521265574864, 38.6590439251491, 36.90660054343087, 37.888130869184224, 40.5217274257115, 46.19188479014805, 48.71567896434239, 49.47938673836844, 53.01948002406529, 49.98636899675642, 46.86774301528931, 47.69780261175973, 50.39246341160366, 50.62012808663504, 44.60052497046334, 41.644775186266216, 45.0198244367327, 47.617401531764436, 51.052483218056814, 51.263458320072715, 52.102463722229004, 50.46938691820417, 47.4187525340489, 43.875643730163574, 37.87578739438738, 24.55798407963344, 13.071770208222524, 9.868741852896553, 6.599800714424678, 8.800114120755877, 13.9247328042984, 13.19110986164638, 12.900873184204102, 12.100151487759181, 5.063554005963462, 2.0069545933178494, 0.6576689811689513, 0.8824128615004676, 3.855471585478101, 17.489027534212383, 37.97229092461722, 42.2223094531468, 40.28299427032471, 46.274776799338206, 55.40887519291469, 56.76846047810146, 33.71019295283726, 8.470997929573059, 0.39193575030991007, 0.21779725594179972, 0.18053790740668774, 0.08401797698544604, 0.12749016178505762, 0.1051093695153083, 0.1942878903022834, 0.1799342690833977, 0.08747931303722517, 0.22290032782724925, 0.19487088759030613, 0.11189381046486752, 0.09577418650899615, 0.13562179330204213, 0.12452740647963115, 0.08142853129122939, 0.1336852815002203, 0.12182932054357869, 0.12542396837047168, 0.14801446188773426, 0.09318600967526436, 0.1139808145484754, 0.10120152349450759, 0.18934548193854944, 0.15143681610269205, 0.1821460761129856], [0.022302407904395034, 0.061265225389174054, 0.030385035622332777, 0.02681726117485336, 0.05153365918834295, 0.03692773150812302, 0.0412585626888488, 0.03430109530953424, 0.01612921165568488, 0.05059514347729938, 0.029282867442816496, 0.0403847283284579, 0.06506270090384142, 0.04814900777169636, 0.019841712533629367, 0.019451468384691646, 0.04135556605511478, 0.04361632599362305, 0.027647581084498336, 0.01590769541715937, 0.008677785201663417, 0.004106617341416755, 0.01983414517183389, 0.03161088716504829, 0.07846103981137276, 0.047969165457678695, 0.04769190926370876, 0.030647903481232266, 0.041446540637740066, 0.05935975656445537, 1.0060344508716037, 9.666098509516035, 33.95241757801601, 50.8060097694397, 43.523641041346956, 33.08467790058681, 24.66962947164263, 40.41106694085257, 47.30054977961949, 23.490813732147217, 7.008938874517169, 0.27574607357382774, 0.14848388598433562, 0.31355502190334456, 2.3208978729588643, 1.8866426263536726, 3.2032611199787686, 3.44194672363145, 3.3079539707728793, 3.8941730516297475, 6.4146629231316705, 17.37352589198521, 26.783250638416835, 30.943076338086808, 34.40730571746826, 46.40233530317034, 48.1011837550572, 44.51380450384957, 42.38181577410017, 42.21766458238874, 44.45173624583653, 48.287510122571675, 46.471035616738455, 46.34290388652256, 44.29632936205183, 43.095190797533306, 47.66749109540667, 45.017132009778706, 43.42250306265694, 42.055174010140554, 37.37289762496948, 33.66375814165388, 33.7303010395595, 34.819045543670654, 36.52457816260201, 36.49012899398804, 37.45090157645089, 37.415920870644705, 42.50677565165928, 41.355980260031565, 44.91795342309134, 42.80336645671299, 45.09143951960972, 43.14985574994768, 45.9943961415972, 43.71243749346052, 47.86346503666469, 44.208320004599436, 52.690017291477744, 31.069863591875347, 37.80191762106759, 49.951291016169954, 43.285602705819265, 45.78276096071516, 43.96868358339582, 43.422325883592876, 42.166994844164165, 38.45741415023804, 35.69975403376988, 32.43545906884329, 32.04714856828962, 34.09449781690325, 34.50546986716134, 34.38633952822004, 34.12159579140799, 36.45282758985247, 38.24420172827584, 44.85257087435041, 46.00088575908116, 48.11757802963257, 43.88293933868408, 45.54465661730085, 49.10739755630493, 48.13507011958531, 47.884149823869976, 44.80848455429077, 40.94922924041748, 35.32065337044852, 38.14421367645264, 41.405097075871055, 47.936414173671174, 44.28423949650356, 48.6393495287214, 50.952582018715994, 49.989186491285054, 39.22217110225132, 26.174220187323435, 17.103895834514073, 10.249821884291512, 3.2548154507364546, 5.6194155386516025, 7.5202542032514295, 8.201155952044896, 8.44570996080126, 4.049641600676945, 3.8790502973965237, 0.5093463286757469, 0.8291997026119913, 0.24365720259291784, 0.433553152850696, 3.3826247411114827, 13.031155381883893, 22.875239815030778, 33.73129463195801, 29.54698521750314, 41.571440424237935, 50.14391245160784, 37.18553250176566, 19.44875305039542, 3.9766373123441423, 0.061539346751357825, 0.008288394310511649, 0.05590790643223694, 0.016407897862206613, 0.048495762914951356, 0.04575908529971327, 0.04551020544022322, 0.04254234076610633, 0.0647459811131869, 0.06458155172211782, 0.040083842152463536, 0.033869852378432236, 0.010774687414855828, 0.027429276012948582, 0.035666490971509895, 0.05636833315449102, 0.045710410590150526, 0.043407859679843695, 0.03451300518853324, 0.010023483840216483, 0.043077297774808745, 0.09640158712863922, 0.04952628458184855, 0.05058883310162595, 0.021705945088927234, 0.0537907652157758, 0.03204796210463558, 0.03503371296184404, 0.02735062362626195, 0.008554275713062711, 0.056692228452967744, 0.015083115913772156, 0.02732726845092007, 0.041625446573432, 0.13572084584406444, 0.025722852043275322, 0.04590216797909566, 0.015930494193785956, 0.05783669650554657, 0.02248846390284598, 0.0376132147253624, 0.02199662440190358, 0.03971070896035858, 0.043686883457537205, 0.05909515504858323, 0.014262980814757091, 0.009031352836505642, 0.012797588598914444, 0.024271716696343253, 0.023764180984081965, 0.041228951420634985, 0.02317860526298838, 0.02923634708193796, 0.0283594796700137, 0.0904328538370984, 0.03637368730934603, 1.3550305238791873, 13.045066543987819, 39.51376962661743, 58.73521409715925, 46.45075729915074, 35.34808485848563, 29.031111001968384, 33.559840883527485, 44.3576854297093, 23.728193725858414, 6.839728959969111, 0.4684306670512472, 0.052186674504939995, 0.37437512832028524, 1.807938426733017, 4.685076943465641, 6.019409869398389, 4.984300681522914, 4.537189747606005, 3.912847638130188, 6.459814054625375, 17.09654811450413, 32.36084583827427, 37.112718854631694, 39.20268487930298, 48.23930352074759, 50.458172525678364, 48.02521562576294, 44.424096311841694, 44.42814711162022, 45.21778208868844, 50.64250476019723, 47.591331890651155, 46.29892873764038, 45.50463151931763, 44.90807655879429, 48.527170862470356, 46.49463169915335, 47.24344948359898, 43.24269757952009, 38.57627350943429, 35.810285976954866, 34.80794927052089, 36.54445001057216, 36.71570920944214, 37.810439586639404, 39.51292194638933, 38.319308280944824, 43.70170600073678, 42.90164177758353, 46.65707015991211, 45.33330283846174, 47.244258948734824, 45.4323285647801, 48.16304356711251, 45.81175231933594, 49.585621220724924, 44.85771948950631, 51.09013898032052, 34.41171087537493, 39.52946560723441, 50.95373889378139, 45.70084169932774, 45.644036701747346, 44.856166567121235, 43.88726111820766, 41.52894524165562, 39.42527389526367, 36.488079275403706, 34.060409954616, 34.37343324933733, 36.145352431706016, 35.84836557933262, 35.35567923954555, 35.025271551949636, 37.971543993268696, 40.27242258616856, 46.04386036736624, 49.14237131391253, 49.30219030380249, 46.38121277945382, 46.662024225507466, 48.33473355429513, 49.52662754058838, 49.345481055123464, 47.16699845450265, 42.489311354500906, 36.92575325284685, 40.48639236177717, 44.9509608404977, 48.834614753723145, 48.44877086366926, 50.643567834581646, 51.74433272225516, 49.13911608287266, 41.82715845108032, 29.83284452983311, 19.58590701648167, 10.638560567583356, 5.52348393201828, 5.9700120857783725, 5.28308060339519, 5.2973834701946805, 4.824398747512272, 5.081221103668213, 3.101397923060826, 1.247668479170118, 0.7944086609142167, 0.21669281806264604, 0.3694877220051629, 4.172623412949698, 14.000331810542516, 26.431336539132253, 34.25012009484427, 33.6417601449149, 46.58342967714582, 56.23891741888863, 45.69813190187727, 24.001115492412023, 4.555949449539185, 0.10468757179166589, 0.009417213649222893, 0.011678060949114817, 0.019692383939400315, 0.026187483986307467, 0.023486497313050286, 0.020210525154003074, 0.0222023714865957, 0.030275269012366022, 0.02864395547658205, 0.007478935960015016, 0.014127375591280205, 0.05635733410183873, 0.05843185314110347, 0.01786363876557776, 0.05781701220465558, 0.026358276339513913, 0.03465423207463963, 0.04406387751389827, 0.007146037350009594, 0.0530399255055402, 0.030463226605206728, 0.028440415327038084, 0.019505059080464498, 0.0444871239098055, 0.04065288197515266, 0.10603038580822093, 0.12350915611854621, 0.15681602459933075, 0.068536169161754, 0.13954630414290087, 0.1206485339041267, 0.10922393122954027, 0.11584286391735077, 0.14176182954439095, 0.10736830758729152, 0.10685839530612741, 0.18314755308840955, 0.1440707349351474, 0.15317073091864586, 0.06247154530137777, 0.11576544307172298, 0.17606857365795545, 0.1909435133316687, 0.07519138311701161, 0.10194727419210331, 0.13507382199168205, 0.12055220907287938, 0.0797917487631951, 0.08032809676868574, 0.19289670352424892, 0.14671681794737065, 0.10812445344137293, 0.19579714217356273, 0.1853617892733642, 0.1765077215220247, 1.640227803162166, 14.634818724223546, 44.84701926367623, 63.786894934517996, 55.9564140864781, 44.69475643975394, 34.498778751918245, 49.438805784497944, 53.60077326638358, 28.740660667419434, 8.984687805175781, 0.6249063249145235, 0.4136725110667092, 1.2078859167439597, 6.927640608378819, 6.33213916846684, 10.407403554235186, 12.212230273655482, 7.526436362947736, 9.257802384240286, 9.404951333999634, 20.16994653429304, 33.700600964682444, 40.897875104631694, 41.6892123903547, 50.1650766645159, 51.65108789716448, 49.703007561819895, 45.32200854165213, 46.901639802115305, 46.983034474509104, 53.5202089037214, 49.2050336429051, 47.11219106401716, 46.21532801219395, 46.00645126615252, 50.117658683231895, 48.32954672404698, 49.88425827026367, 45.084703241075786, 39.911352498190745, 36.81438752583095, 35.60121815545218, 38.28925037384033, 38.242218017578125, 40.17584262575422, 40.64837571552822, 39.747197832380024, 44.26635830742972, 45.06331321171352, 48.02971805844988, 47.08929327556065, 48.02920389175415, 47.20594310760498, 50.37281390598842, 48.04012993403843, 51.195595264434814, 47.22295577185494, 50.55755608422415, 36.68371622903006, 40.64693396432059, 52.307435580662315, 47.64175149372646, 47.24423810413906, 47.52763775416783, 46.087109429495676, 45.062295300619944, 41.22776862553188, 40.129744802202495, 35.375627517700195, 36.11484636579241, 38.245792865753174, 37.759005546569824, 37.324913365500315, 36.33681699207851, 39.238766874585835, 42.15195894241333, 48.253627232142854, 50.86591018949236, 51.04328727722168, 47.33931377955845, 47.196083613804404, 49.21397597449166, 49.70019006729126, 50.98902532032558, 48.065584659576416, 44.9525728225708, 39.163302489689414, 42.12962743214199, 45.87993846620832, 51.76507656914847, 49.294397899082725, 53.92749840872628, 53.91901813234602, 50.87293829236712, 44.44871377944946, 32.28168848582676, 21.708362817764282, 11.798523238727025, 6.365395852497645, 12.180357149669103, 13.506971495492117, 15.96537617274693, 16.423729726246425, 11.74954799243382, 13.35685305935996, 4.9729742492948255, 2.13155511873109, 0.7887580926929201, 0.990837003503527, 5.075434557029179, 18.054232222693308, 30.056333337511333, 44.46845013754708, 41.57941000802176, 54.33395412990025, 61.057051931108745, 49.260594912937705, 27.06078427178519, 5.367518152509417, 0.22098965463893755, 0.07384396863303014, 0.085855633020401, 0.06161480663078172, 0.12778198612587793, 0.16037773633641855, 0.14854180573352746, 0.15885000117123127, 0.11718753033450671, 0.12266794911452703, 0.11196151468902826, 0.13707296257572515, 0.14897917583584785, 0.19501141219266824, 0.16621160400765284, 0.17690997065177985, 0.16345642613513128, 0.17515743683491433, 0.09229602957410471, 0.10977674727993351, 0.1773406911109175, 0.14282837802810328, 0.0921424635286842, 0.2019452258412327, 0.11189976121698107, 0.13656617834099702], [0.0853326114426766, 0.031193995249590704, 0.10737877738262926, 0.018550268706998656, 0.032274317994181595, 0.027828322457415716, 0.049226219433226755, 0.05718273802527359, 0.022358319189931666, 0.04393752411540065, 0.02121872132244919, 0.00734007716112371, 0.036440539972058365, 0.019260581216907928, 0.04820350431171911, 0.0410479114923094, 0.03966510122908013, 0.027549931413627098, 0.03445302608555981, 0.037436100122119696, 0.012801203494226294, 0.038463446245129616, 0.041768909232424836, 0.035026506919945986, 0.002278286498039961, 0.025609560443886688, 0.030712442339531014, 0.04341676884463855, 0.023521565699151585, 0.050491622782179287, 0.2275443029190813, 6.015468069485255, 28.52815522466387, 47.7288749558585, 49.47602033615112, 35.8300119127546, 44.36348370143345, 63.38690798623221, 53.87492486408779, 30.964640072413854, 9.906087551798139, 1.203260913491249, 0.10821049168173756, 0.19392251276544162, 1.067241132259369, 7.169070099081312, 6.9391811319759915, 3.201200544834137, 2.7554327845573425, 2.144045808485576, 7.8523702791758945, 11.246098024504525, 19.69002056121826, 27.07511666842869, 45.77361018317086, 50.48383569717407, 47.587096963609966, 43.86997400011335, 44.061039039066856, 44.336604595184326, 44.89505216053554, 46.051760469164165, 46.83235583986555, 42.0313903263637, 45.34665380205427, 48.03658635275704, 45.75294624056135, 42.529364245278494, 42.90208993639265, 36.36705902644566, 34.36176027570452, 34.482193401881624, 37.34917994907924, 38.90894978387015, 40.94589410509382, 38.445939200265066, 36.45350156511579, 36.19288853236607, 38.0721504347665, 37.77420473098755, 39.314064502716064, 38.43241800580706, 40.106395380837576, 39.43761042186192, 43.59315082005092, 41.69130032403128, 46.19625520706177, 45.04332324436733, 46.25373417990548, 31.434578010014125, 41.01668235233852, 48.373414175851, 44.197272368839805, 47.85860129765102, 43.651077951703755, 45.18712316240583, 44.33473205566406, 46.592358112335205, 40.42436579295567, 32.74142299379621, 32.42514099393572, 35.43432937349592, 33.52317523956299, 35.19948026112148, 33.95970971243722, 34.72651638303484, 38.03058978489467, 43.54763664518084, 45.64380393709455, 46.72260209492275, 44.75223193849836, 46.86650276184082, 44.37287071772984, 49.061223302568706, 44.969793932778494, 43.89339985166277, 39.37233904429844, 38.002901213509695, 36.80157157352993, 40.597931793757844, 41.35454545702253, 44.58297382082258, 46.24438190460205, 50.17780576433454, 48.25318602153233, 39.79127720424107, 28.119590725217545, 17.416451862880162, 6.509915343352726, 2.75110753093447, 3.200425603560039, 3.617965438536235, 1.9391032627650668, 4.011707041944776, 2.6041353259767805, 1.6540516785212924, 0.5838424169591495, 0.7037792897650174, 0.35736762093646185, 0.8359395095280239, 5.632321383271899, 17.075500283922466, 22.788571459906443, 22.729560409273418, 35.6764497756958, 32.517482553209575, 45.93108763013567, 31.465368952069962, 13.827372908592224, 1.7935274285929543, 0.03418599880699601, 0.033571371609078984, 0.036095321710620604, 0.030097882995115857, 0.034386353234627416, 0.03659724424194012, 0.07585353151495967, 0.05517585535666772, 0.031385620324207206, 0.018943656169410263, 0.04783137195876666, 0.0666630325306739, 0.02351120955842946, 0.11966406101627008, 0.010236151133930045, 0.04386767232790589, 0.05043998287458505, 0.0037664817313530614, 0.05957044168774571, 0.015636846290103028, 0.03949573888842549, 0.08052675146609545, 0.03349896513723901, 0.1058380686278854, 0.04481800811897431, 0.012666696649310845, 0.030746267310210636, 0.05987777055374213, 0.052420918364077806, 0.019591034556339895, 0.06834497834954943, 0.03731661010533571, 0.05453151850295918, 0.06513552128204278, 0.062174265539007526, 0.007078847964294255, 0.01593619049526751, 0.015606536130820001, 0.029903944116085768, 0.03213394606219871, 0.051057466704930575, 0.03755892174584525, 0.03333522445921387, 0.08515886576580149, 0.009511380739110922, 0.011639195311415409, 0.031031282552118813, 0.027316695178991983, 0.006986273735362504, 0.01989757123270205, 0.03483448150966849, 0.03270635481125542, 0.02022192793499146, 0.011721654279556657, 0.017837389638381343, 0.020867903450770036, 0.32043881395033424, 7.61247764314924, 33.25430427278791, 53.86581924983433, 54.59505353655134, 37.516200746808735, 38.01441437857491, 59.78976304190499, 55.53167070661272, 32.686250822884695, 10.31132994379316, 1.216787644795009, 0.05334281335983958, 0.14249861000904016, 0.7319875104086739, 2.9524129118238176, 4.747742312295096, 4.551098304135459, 5.752794027328491, 1.9848905886922563, 8.639285905020577, 15.14424501146589, 23.877124888556345, 32.98539161682129, 46.26348945072719, 51.58441298348563, 49.82050507409232, 46.23538051332746, 44.397008759634836, 46.476885999952046, 48.1648223059518, 48.911173479897634, 47.49727760042463, 45.00308622632708, 45.93148715155465, 48.225716318402974, 48.64083991731916, 45.497683320726665, 44.146724224090576, 39.55207504544939, 36.148559025355745, 35.56299958910261, 38.2856616292681, 39.64173460006714, 42.286163398197715, 39.683434213910786, 38.17544930321829, 37.86907196044922, 39.645702021462576, 40.59500312805176, 41.43848317010062, 40.338319301605225, 42.52148151397705, 43.33159630639212, 46.11644472394671, 44.21748120444161, 48.381630420684814, 45.81883600779942, 47.958273206438335, 34.90894481113979, 41.347652844020296, 49.026621273585725, 46.217700822012766, 49.34157964161464, 45.287343978881836, 47.81807592936924, 46.569359574999126, 47.42471061434065, 41.19029004233224, 34.02419941765921, 33.88175439834595, 36.15290859767369, 34.56143760681152, 35.8431579044887, 35.479892185756135, 37.863350118909565, 40.149397781917024, 45.60845497676304, 47.061934743608745, 48.03263282775879, 45.566421849387034, 46.01317017418997, 46.114103181021555, 49.17902653557913, 47.003159931727815, 45.32955428532192, 41.07475887026106, 39.98965522221157, 38.34290088926043, 42.937612601688926, 44.76909869057791, 47.37138319015503, 48.521389961242676, 51.058917249952046, 50.45335047585623, 40.358694893973215, 30.844832284109934, 18.085108280181885, 7.16543619121824, 4.487931362220219, 3.761977928025382, 6.137496675763812, 6.843157027448926, 5.691363266536167, 6.895973324775696, 3.82674686397825, 1.8698840056146895, 1.258490189909935, 0.18213336036673614, 0.865697341305869, 5.527701488562992, 19.406049421855382, 26.369513205119542, 30.50750071661813, 40.632825647081646, 38.54417978014265, 50.60036393574306, 35.65237079347883, 17.290677309036255, 2.4309592928205217, 0.05543808539264968, 0.03697692868965013, 0.020007638094414557, 0.04377050272056034, 0.04834547419367092, 0.022994418628513813, 0.09149296980883394, 0.030530293006449938, 0.06258390391511576, 0.05479175364598632, 0.03490623998056565, 0.03716370223888329, 0.06507013086229563, 0.034742489124515226, 0.04585916582228882, 0.04392144622813378, 0.06121778900602034, 0.04397463998092072, 0.09393805717783314, 0.039761554981981, 0.021087172042046274, 0.028703941364905665, 0.02302458120643028, 0.02794351565119411, 0.018983492960355113, 0.04298128506966999, 0.12254284082778863, 0.12215395883790084, 0.1648755549852337, 0.07534354459494352, 0.0765203618045364, 0.16859046635883196, 0.2319226994046143, 0.3154062554240227, 0.16314744842903955, 0.1549062877893448, 0.16535169657851967, 0.05878553951957396, 0.14450137397008284, 0.07530482738677945, 0.12400767579674721, 0.11397280783525535, 0.13274405843445233, 0.16421857023877756, 0.08684226364961692, 0.10105914649154459, 0.1516736519656011, 0.05791685863264969, 0.24170636013150215, 0.09756747313908168, 0.1258110318865095, 0.10751377870993954, 0.10944523542587246, 0.11445524623351437, 0.10394604836723634, 0.11174206967864718, 0.5500123436961855, 9.185244083404541, 37.8358838898795, 62.44950566973005, 62.44828973497663, 45.928680079323904, 51.64429603304182, 70.07263837541852, 59.87804685320173, 35.66946336201259, 12.09755894115993, 1.9924502287592207, 0.2897139883467129, 1.0183821597269602, 2.6650080595697676, 11.673224636486598, 16.166337183543614, 10.22508977140699, 9.553141645022801, 4.815791232245309, 10.887214882033211, 18.9671699319567, 33.08373989377703, 39.82755722318377, 49.2740535736084, 54.18769107546125, 50.99536555153983, 47.457412311008994, 48.984834807259695, 48.897624492645264, 50.17711789267403, 50.31314972468785, 48.642993858882356, 46.00905336652483, 46.98279823575701, 50.53691298621041, 49.641033104487825, 47.80638211114066, 46.422182832445415, 41.188181264059885, 37.13002334322248, 37.25579616001674, 39.96975905554635, 41.57249655042376, 44.93584156036377, 41.52392864227295, 39.64232867104666, 39.54123932974679, 40.90669584274292, 42.08916459764753, 42.35358871732439, 41.48303154536656, 42.416456018175396, 45.31207261766706, 46.74703890936715, 46.35124519893101, 50.566262177058626, 47.52825961794172, 47.627424308231895, 38.7644168308803, 42.47099242891584, 48.72607694353376, 47.085815702165874, 51.115812574114116, 47.21306848526001, 49.79055486406599, 49.13144179752895, 50.49482774734497, 43.60683182307652, 35.931389604296, 36.08114760262625, 36.96073743275234, 36.251496587480815, 38.706684248788015, 37.582587310246055, 39.60707351139614, 41.72746569769723, 47.757810728890554, 48.302257674080984, 48.75761481693813, 45.627076148986816, 46.59503664289202, 46.55865240097046, 50.9180668422154, 48.452238014766145, 47.113987173352925, 42.24409205572945, 41.91462932314192, 40.23489536557879, 44.97369187218802, 45.18082114628383, 50.047634737832205, 49.98287057876587, 55.20970855440412, 52.590185574122835, 45.4207215990339, 34.47013480322701, 21.387781620025635, 8.01500850064414, 6.318807312420436, 7.521539619990757, 10.121854305267334, 8.361878207751683, 12.311070135661534, 10.73207984651838, 6.2576822723661145, 3.856442596231188, 2.287327651466642, 0.8031632825732231, 1.261429712176323, 8.52635509627206, 22.287069593157085, 33.15253400802612, 33.35047776358468, 49.39677613122122, 43.74544838496617, 58.810970306396484, 40.84690659386771, 19.45086877686637, 2.8407584003039767, 0.12105455568858556, 0.17175096033939294, 0.1964094793157918, 0.14574442298284598, 0.15881600656679698, 0.14425349155707018, 0.1779858557773488, 0.12438336706587247, 0.16731928528419562, 0.07919263626847949, 0.09742698246347052, 0.16565630451909133, 0.09492041982178177, 0.2300794454557555, 0.13140613665538176, 0.16867206698017462, 0.1533227634749242, 0.1472569725343159, 0.17567677396748746, 0.15788540935942105, 0.15780987484114511, 0.15293247013219766, 0.1261287084115403, 0.18469075885202202, 0.07728072136108365, 0.10574136381702763], [0.014526835942108716, 0.023948384581932, 0.023568630584382584, 0.024352019619462744, 0.061839401721954346, 0.01872163781497095, 0.01498978172561952, 0.006814993261027017, 0.07280692285192863, 0.024503261682444384, 0.058704685286751816, 0.03102376777678728, 0.06474294806165354, 0.015699515784425393, 0.04936361259647778, 0.058689974647547515, 0.021738947335896746, 0.015156005841812916, 0.06527652085891791, 0.09163849521428347, 0.028286766161077788, 0.015972544705229144, 0.054751523304730654, 0.027500381393890296, 0.011747540390518094, 0.021255024642284428, 0.06313385654773031, 0.022637804371437857, 0.051873564520584683, 0.07688575291207858, 0.09114411459969622, 5.337678245135716, 23.13776707649231, 41.792268071855815, 45.600568771362305, 46.60206821986607, 50.948322772979736, 65.4791009085519, 55.92168351582119, 32.95865147454398, 13.54118355682918, 1.9776510000228882, 0.13980131117360933, 0.1982795489685876, 0.22857849885310444, 1.2868048591273171, 2.3062823372227803, 2.818646626813071, 1.1805404126644135, 1.147236394030707, 8.413842047963824, 15.075560331344604, 22.628250462668284, 33.87730060304914, 46.67556973866054, 50.20160681860787, 49.78330441883632, 45.242590631757466, 43.572188104902, 44.74464103153774, 47.50500052315848, 46.65111207962036, 47.10127196993147, 44.9002355166844, 46.678272587912424, 46.52923025403704, 45.79570892878941, 41.4889166695731, 38.59077092579433, 34.4441693850926, 36.73197494234358, 36.79126044682094, 42.376674107142854, 42.99198920386178, 44.01480572564261, 40.33904538835798, 40.42424419948033, 36.54931722368513, 36.16299043382917, 35.07304041726248, 34.883934770311626, 33.92852619716099, 37.024876253945486, 36.36489118848528, 42.654313700539724, 43.533080169132774, 45.466881956372944, 44.96125112261091, 42.425005776541575, 29.28987407684326, 40.98208727155413, 48.47363151822771, 43.650699274880544, 48.63761942727225, 47.16501474380493, 47.373353004455566, 46.694111006600515, 47.22177457809448, 44.26002155031477, 36.94865451540266, 31.070433344159806, 33.351658957345144, 35.55596801212856, 37.7916134425572, 34.834171772003174, 34.179870332990376, 39.1640112059457, 44.04770197187151, 46.9427627154759, 47.952870982033865, 44.48803016117641, 46.523070675986155, 46.50744765145438, 47.43217645372663, 45.95164734976632, 44.68887478964669, 39.67465169089181, 37.30288062776838, 37.98334550857544, 38.82073892865862, 39.91136292048863, 44.435484409332275, 46.95286539622715, 47.836429595947266, 47.581472396850586, 39.54640531539917, 29.09444730622428, 18.63697416441781, 7.956263218607221, 4.475944416863578, 2.8559821205479756, 4.811591046197074, 4.217764122145517, 1.3796931547777993, 4.263360806873866, 2.013488288436617, 1.1262516400643756, 1.094788242663656, 0.16602658107876778, 1.2585586948054177, 6.617029207093375, 15.463523421968732, 30.511492456708634, 22.875328404562815, 28.762241772242955, 37.15858391353062, 38.28110013689314, 24.088749647140503, 8.069108043398176, 0.6426644548773766, 0.025275269988924265, 0.08712762155170951, 0.05776091092931373, 0.037034729695213695, 0.05103035583826048, 0.03275344853422471, 0.013463082174504442, 0.06935636193624564, 0.046582090601857216, 0.04300709654177938, 0.014208212860726883, 0.016446854253964763, 0.07035255312387433, 0.07775035580354077, 0.030041802075824568, 0.03449281198637826, 0.04519911749022348, 0.012720095658940929, 0.05635397535349641, 0.031694028060883284, 0.10742958608482565, 0.03962795143680913, 0.047822103170411925, 0.029391029317464148, 0.0361299643159977, 0.12582716744925293, 0.05205035003434334, 0.01226165280344763, 0.0408101494290999, 0.03638876775013549, 0.03285897769300001, 0.026865070752267326, 0.011434361704492142, 0.036326644476503134, 0.08822253958455153, 0.049087275817458115, 0.01448047673329711, 0.03296639657180224, 0.017701173733387674, 0.03347019185977323, 0.035416372785610814, 0.05359510285779834, 0.06822690647095442, 0.017068078508600593, 0.03093254892155528, 0.038617405840860944, 0.034803346930337806, 0.02211583961200501, 0.04125685278060181, 0.03532328795907753, 0.06486382907522575, 0.015935203226815377, 0.05596825533679553, 0.013220485549287071, 0.06937368493527174, 0.031131135765463114, 0.10765942625169243, 6.529203108378819, 28.059657301221574, 48.55004433223179, 50.70444100243704, 49.27754504340035, 56.67574371610369, 68.00436810084751, 59.613487243652344, 37.01907450812203, 14.224529334477015, 2.3847231566905975, 0.07511348051152059, 0.09183400829455682, 1.1838147512504031, 3.7120842167309354, 4.91538497379848, 9.668117829731532, 2.4839994524206435, 1.5451633099998747, 7.534935746874128, 18.674077544893535, 27.883949518203735, 38.09748009272984, 49.79300062997, 52.63368477140154, 50.18863453183855, 46.693047932216096, 45.74341678619385, 46.43377937589373, 48.67988879340035, 49.64105742318289, 46.70851462227957, 45.716051306043354, 49.20457853589739, 48.6341210092817, 47.09089830943516, 43.94660568237305, 40.77775812149048, 35.69980614525931, 37.56788492202759, 39.0003012248448, 43.265980992998394, 43.64468560900007, 44.396980966840474, 42.36519915716988, 41.090388842991416, 38.08111361094883, 37.70713724408831, 36.23389332635062, 36.73655033111572, 36.754810197012766, 39.01125505992344, 37.97771399361746, 44.568528515951975, 46.90833439145769, 47.40797240393502, 47.91499982561384, 43.03519310270037, 33.49413871765137, 42.243939195360454, 48.869206360408235, 43.59337663650513, 48.19920546667916, 48.629469190325054, 47.67120490755354, 47.309627601078574, 48.503606046949116, 44.99714551653181, 38.04732799530029, 33.36343962805611, 35.51177052089146, 36.53261375427246, 39.605902739933555, 36.154701232910156, 36.674673148563926, 40.481209005628315, 46.802030427115305, 48.54924528939383, 49.14880881990705, 44.67201151166643, 46.6869022505624, 47.18379919869559, 48.480329581669395, 47.66215487888881, 46.207031863076345, 41.81996359143938, 38.66803142002651, 39.04741695949009, 40.898844378335134, 41.767108644757954, 45.98358474458967, 49.62151908874512, 50.108056272779194, 49.02716670717512, 42.76159388678414, 31.69374234335763, 20.064905405044556, 7.178116653646741, 2.956382070268903, 3.1424276871340613, 5.85120700938361, 6.957568671022143, 6.847495308944157, 7.554741586957659, 4.111127512795584, 1.9704142340591975, 0.6302182227373123, 0.263855941593647, 1.4948516211339404, 8.82668924331665, 18.930764845439366, 33.12789569582258, 24.007521731512888, 36.16307381221226, 41.36516925266811, 46.008087566920686, 31.5532671383449, 10.408806221825735, 1.2468305698462894, 0.09436323400586843, 0.03654724299641592, 0.034803754051348994, 0.030377059443188564, 0.05992656400693314, 0.016540692254368747, 0.016339735626908283, 0.030546761051352535, 0.06229575723409653, 0.03898126345926097, 0.057201248460582325, 0.07095536363444158, 0.037343066185712814, 0.05634865224627512, 0.03145633385117565, 0.04407086303191526, 0.032746534262384684, 0.05877805527831827, 0.0066747650936512005, 0.02669005621490734, 0.01125749561470002, 0.03443506187094109, 0.032460633532277176, 0.04403998290321656, 0.016672014225540415, 0.021428163030317852, 0.18447087279387883, 0.06976392399519682, 0.19881046190857887, 0.14138685752238545, 0.17707404041928904, 0.13746529152350767, 0.12728597702724592, 0.1880461009485381, 0.20674081279763154, 0.09656067644911152, 0.16378867759236268, 0.11523857420044285, 0.21323789416679315, 0.10628994580890451, 0.11518981467400279, 0.1979839519730636, 0.25399297369377954, 0.15780075533049448, 0.15308333560824394, 0.1643619311175176, 0.15945112891495228, 0.15767766907811165, 0.1322581052247967, 0.12605096186910356, 0.18075526931456157, 0.0776072663388082, 0.11610931104847363, 0.07530744653195143, 0.15090773520725115, 0.16752953614507402, 0.17310763682637895, 7.886041249547686, 31.060365404401505, 54.74538128716605, 57.936859130859375, 56.71369130270821, 59.86068330492292, 69.98092910221645, 61.08378165108817, 38.93625967843192, 16.397441216877528, 3.2567594264234816, 0.33747188853366034, 0.3700038971645491, 2.1957914318357195, 4.976089213575635, 5.542650972093854, 8.359415071351187, 7.630837389401027, 2.8325721195765903, 11.58801019191742, 21.836162771497452, 30.745948995862687, 39.95653315952846, 51.44497306006295, 53.997022083827424, 53.27647304534912, 48.86025708062308, 48.412588119506836, 49.17780712672642, 51.41372701099941, 50.22191987718855, 47.74650253568377, 46.01854460580008, 47.528509753090994, 49.94200127465384, 49.00660351344517, 45.002071789332796, 42.24386971337454, 38.48490122386387, 39.72062792096819, 41.382108960832866, 46.292216777801514, 45.66900852748326, 47.30932535443987, 45.12309551239014, 43.72719199316842, 39.90321268354143, 38.49922146115984, 37.880765778677805, 37.67084332874843, 37.19043098177229, 40.842713356018066, 40.52643135615757, 46.30927113124302, 48.01247262954712, 49.21692201069423, 49.53236675262451, 43.84287255150931, 37.15712479182652, 43.604667459215435, 47.857506956372944, 43.93385921205793, 49.36509581974575, 49.884723799569265, 48.180712836129324, 48.19419928959438, 51.10872541155134, 47.10091413770403, 40.426627431597026, 34.850173473358154, 36.77607863289969, 38.534365449632915, 41.90978990282331, 38.44239214488438, 37.427308968135286, 42.70449359076363, 47.68794311795916, 50.31113474709647, 49.85509320667812, 44.824284757886616, 46.33056388582502, 47.695898805345806, 49.6279114314488, 50.30676085608346, 48.431494167872835, 43.90572943006243, 40.69889259338379, 41.09419298171997, 42.245638029915945, 43.501121929713655, 49.929963520595, 51.55680431638445, 51.730762890407014, 51.819904804229736, 44.70195824759347, 35.200282778058735, 22.650915486471995, 10.809546181133815, 7.017399174826486, 7.8706605434417725, 12.00978147983551, 10.98622236933027, 10.31057606424604, 12.119408420154027, 7.377188188689096, 3.449327230453491, 2.056032108409064, 0.5622227713465691, 2.099690245730536, 9.56921022278922, 21.642691918781825, 39.80613245282854, 32.17425891331264, 40.947551250457764, 49.93343414579119, 51.91281264168875, 35.67090163912092, 12.018161875861031, 1.4394805580377579, 0.18602193599300726, 0.11418837841067996, 0.09451164318514721, 0.13218398205935955, 0.16992943308183125, 0.07172446272202901, 0.16087674455983297, 0.16529171408287116, 0.09407227818987199, 0.1452494723988431, 0.10229848391775574, 0.20867205916770867, 0.19227042927273683, 0.2367535973233836, 0.093136184848845, 0.07377262746116944, 0.09343149007431098, 0.07001232209482364, 0.15820117241569928, 0.08954095348183598, 0.14498028398624488, 0.0982104664934533, 0.1605991558837039, 0.17475910963756697, 0.09744762349873781, 0.2253005233194147], [0.05036868920017566, 0.06231662218591996, 0.04823638951139791, 0.03439333535996931, 0.055173287101622136, 0.032744064394916804, 0.01352601544931531, 0.00643679777359856, 0.030867989707205976, 0.02039709683906819, 0.03621770567925913, 0.04100506539855685, 0.049677465576678514, 0.030981891988111392, 0.013160254540187972, 0.049984981039805074, 0.026703462370538285, 0.047668778004923036, 0.08177666046789714, 0.02106846822425723, 0.009661974801149751, 0.05235916149935552, 0.036856688891670535, 0.0446612258175654, 0.043126762977668216, 0.034040524291672876, 0.020142976992896626, 0.05592652204047356, 0.04733474878594279, 0.06177247781306505, 0.04279289999976754, 2.2559094173567633, 16.473193952015468, 33.8684138570513, 45.109039306640625, 36.65772649220058, 38.2629896572658, 51.75265319006783, 33.178422995976035, 33.864060810634065, 15.895218474524361, 3.522813984325954, 0.35633274646742, 0.09070137050002813, 0.29590969160199165, 3.0276423607553755, 4.745969653129578, 5.9480844395501276, 1.3203684581177575, 1.7470016394342696, 6.864745080471039, 14.071407539503914, 21.6941294329507, 32.562691007341655, 44.54937580653599, 49.070714541843955, 49.261796951293945, 46.352270058223176, 45.81779030391148, 47.3359751701355, 47.262928758348735, 45.30377994264875, 48.13343729291643, 47.07017183303833, 48.995708738054546, 45.67969833101545, 43.337252140045166, 41.23559577124459, 36.99089956283569, 37.290088994162424, 39.22377961022513, 42.216875961848665, 44.906947476523264, 42.93721655436924, 47.048462186540874, 43.28083276748657, 41.20099721636091, 37.93133476802281, 36.01784256526402, 33.30920198985508, 34.10993671417236, 34.10273143223354, 37.45092242104666, 39.70865617479597, 43.49604279654366, 43.70565257753645, 44.9267498425075, 43.571326528276714, 36.859477860586985, 27.41007021495274, 41.336059774671284, 50.06742320741926, 48.517384324754985, 48.56405537469046, 46.008834498269216, 46.74314096995762, 47.082994733537944, 46.071990149361746, 46.04293278285435, 35.918368680136545, 32.025609152657644, 35.28127792903355, 38.307593618120464, 42.26239013671875, 38.036155291966026, 34.87958172389439, 38.26638732637678, 43.040188857487266, 45.52389539991106, 46.603249413626536, 46.37879133224487, 43.876140526362825, 43.256097180502756, 48.782433782305034, 44.285837582179475, 45.20592846189226, 40.065025806427, 37.99438967023577, 37.56874302455357, 39.51990836007254, 40.13899632862636, 42.83084658214024, 43.59557921545846, 47.45857613427298, 47.430581842150005, 39.50347587040493, 26.88453105517796, 15.449673925127302, 4.550152480602264, 1.911955999476569, 1.3510242359978812, 3.744484535285405, 6.463615153517042, 3.88385454245976, 7.0246639507157465, 3.7185282366616383, 1.1215814735208238, 0.6374452177967344, 0.3060251288115978, 2.433542719909123, 9.08993477480752, 23.135279621396744, 29.810624190739222, 30.339218820844376, 34.26724393027169, 41.83391210011074, 28.58661563055856, 17.43738157408578, 3.593151250055858, 0.039481642323413065, 0.024145127506926656, 0.01792263568911169, 0.021174711541139653, 0.04033640306442976, 0.007663966522419027, 0.028154853864439895, 0.021243162153820907, 0.030512698593416383, 0.011010068668318647, 0.06835527851113252, 0.06255821457930974, 0.07233778374003512, 0.09374086133071355, 0.04835764032655528, 0.03871348639950156, 0.017011373337092142, 0.040117568735565455, 0.05269603717273899, 0.044483568386307785, 0.04623702161812356, 0.029731277309890305, 0.03031091924224581, 0.019910892571455667, 0.03622526116669178, 0.02191509502673788, 0.026228341972455382, 0.03612129942380956, 0.044000553233282905, 0.061327521689236164, 0.024108473045219268, 0.07861805960003819, 0.01587056428460138, 0.0656778064689466, 0.034541585083518705, 0.06684717336403471, 0.04221089676554714, 0.022056935987036144, 0.020839535597977892, 0.02594999672978052, 0.0108635619315984, 0.02455841640143522, 0.045229098560022454, 0.0389415895167206, 0.03603942399578435, 0.03195232937910727, 0.032660519770745716, 0.04183714271390012, 0.0333784335692014, 0.025688667449035814, 0.0343877679801413, 0.05225280113518238, 0.06174752129507916, 0.04043888560097132, 0.038058482975299866, 0.0400684495855655, 0.04425158404878207, 0.05675653660936015, 2.702157254729952, 19.818409374782018, 40.15320192064558, 52.050706590924946, 44.91707795006888, 43.53334420067923, 58.58012335641043, 45.27364213126046, 37.757084369659424, 17.153783900397165, 3.7616726415497914, 0.5532443416970116, 0.1665603167244366, 0.21870505437254906, 1.5861833031688417, 2.3182998980794634, 4.834327289036342, 2.2527753455298285, 3.7568241017205373, 10.206555451665606, 18.443147216524395, 24.505332367760793, 34.91208192280361, 47.51602036612374, 51.18756314686367, 51.717780181339805, 48.46430008752005, 46.997587476457866, 47.725129876817974, 49.782498427799766, 47.380495752607075, 49.54541894367763, 47.02882310322353, 49.554990087236675, 47.87397418703352, 45.984324727739605, 42.96589871815273, 38.169928959437776, 38.874399866376606, 40.52492707116263, 43.328872612544465, 45.785561084747314, 44.913131373269216, 48.67581020082746, 45.18556329182216, 42.814361980983186, 40.16520145961216, 37.45393793923514, 35.22755445752825, 35.97602483204433, 36.19645643234253, 37.93698017937796, 40.397573539188926, 45.04311827250889, 45.6050295148577, 47.7304139818464, 45.00917979649135, 37.335957527160645, 31.814105987548828, 43.271727153233115, 50.44937610626221, 47.93475702830723, 49.018526622227256, 46.86539452416556, 47.93555607114519, 48.318440028599326, 47.35494722638811, 47.02098553521292, 38.62371233531407, 33.87433024815151, 37.903121607644216, 40.42771135057722, 42.94768054144723, 38.49113375799996, 37.666035175323486, 40.6270933832441, 45.55074323926653, 47.440118244716096, 47.916417258126394, 46.817438057490754, 46.39332001549857, 44.538137095315115, 49.700263023376465, 47.07329504830496, 45.71602003914969, 42.20409822463989, 40.28534623554775, 40.28979655674526, 41.39465740748814, 43.41977936880929, 43.69844034739903, 45.382895605904714, 49.73047726494925, 49.06680270603725, 40.46143095833914, 29.836877959115164, 18.66513000215803, 6.749504864215851, 2.425346668277468, 3.2300857262951985, 5.092173635959625, 6.710392585822514, 7.462545939854213, 5.988274122987475, 4.095083687986646, 2.2703733955110823, 0.8949408978223801, 0.16686273978224822, 3.1636804895741597, 8.738465360232762, 21.54005139214652, 31.779399735586985, 34.165932246616904, 39.043387004307334, 48.01708623341152, 36.8884414264134, 20.68221984590803, 5.259562688214438, 0.10406631191394158, 0.04631256292174969, 0.05987655597605875, 0.03526109343926821, 0.03663946947615061, 0.05242526438087225, 0.020929334618683373, 0.02755047084896692, 0.02622587719400014, 0.026754698549796428, 0.03045418851875833, 0.0319538187634732, 0.01798194134607911, 0.08954630033778292, 0.010054598063496607, 0.0630266819415348, 0.09498344215431384, 0.05926418490707874, 0.05509554734453559, 0.064311976544559, 0.01812234550847539, 0.026288504279883843, 0.0596241138077208, 0.009699866741097398, 0.04917893232777715, 0.004361970849069101, 0.03652256807046277, 0.1458511022584779, 0.12525409034320287, 0.19575572439602443, 0.1601498028529542, 0.18474187968032701, 0.11923608183860779, 0.1519560446696622, 0.1034013136689152, 0.13568051372255596, 0.11744090888117041, 0.11060444465173142, 0.10749751422554255, 0.12175891575004373, 0.1536304655351809, 0.10199056472629309, 0.11291989112006766, 0.13480585494211741, 0.07778488645063979, 0.1271123941987753, 0.12886439875832625, 0.12116341984697751, 0.09371198966567006, 0.09134724084287882, 0.13685584494045802, 0.08512047425444637, 0.11100691091269255, 0.13308671861886978, 0.1125269311347178, 0.12240351044705935, 0.20318105524139746, 0.10265993273683957, 3.3490230355943953, 23.063878195626394, 46.74434648241316, 58.16961683545794, 49.46756437846592, 46.31073372704642, 56.784250259399414, 43.41229963302612, 44.143774713788716, 19.29975414276123, 5.52575295312064, 0.7472445602927889, 0.5145635030099324, 1.0400771498680115, 5.058658131531306, 10.503316487584796, 12.376596859523229, 4.88704457453319, 4.060597172805241, 12.714830824307032, 17.33473583630153, 26.545848063060216, 37.064088412693565, 47.447955812726704, 51.86776399612427, 53.39463063648769, 49.36925431660244, 49.54777785709926, 50.31415721348354, 50.77766111918858, 48.0343907220023, 49.76566641671317, 47.281098297664094, 52.57148102351597, 50.029600688389365, 48.54766110011509, 44.77504287447248, 40.18993009839739, 41.19479594911848, 43.216013022831504, 44.97128084727696, 48.2523626599993, 45.40833990914481, 50.782854897635325, 48.47606686183384, 45.06631135940552, 42.28288037436349, 40.43224157605852, 36.600362164633616, 37.26378658839634, 37.59650802612305, 39.95569937569754, 42.9982773235866, 48.262409755161826, 47.86992686135428, 48.63971430914742, 46.990059103284565, 38.447137764522004, 34.015938009534565, 43.29648011071341, 49.850396224430625, 50.17077766145979, 50.618304184504915, 47.69278948647635, 49.38751418249947, 50.340768814086914, 50.3935091154916, 49.039895806993755, 39.33397456577846, 35.21330370221819, 39.66692181995937, 41.78623008728027, 45.18382624217442, 40.71786117553711, 39.43725953783308, 43.14489473615374, 45.997008664267405, 50.52990920203072, 49.288182735443115, 47.406006063733784, 47.463665689740864, 44.87606968198504, 52.24892132622855, 48.824383531297954, 49.01281172888619, 44.38843468257359, 41.950815541403635, 41.392663274492534, 43.172051770346506, 44.43974018096924, 47.00848225184849, 47.17214706965855, 52.10310990469796, 51.45700734002249, 42.926224504198345, 31.662920134408132, 19.240486008780344, 6.445253670215607, 3.5989790516240254, 5.1563385128974915, 9.332704833575658, 13.667974284717015, 12.496964846338544, 14.694640977042061, 8.436117104121617, 3.6437378270285468, 1.7972012885979243, 0.6674054701413427, 3.990052112511226, 12.527989421572004, 30.52921383721488, 39.864806515829905, 40.97190816061837, 46.81295299530029, 53.34347799846104, 43.34842831747872, 24.12482122012547, 5.907821800027575, 0.21548985689878464, 0.10966727244002478, 0.14838131863091672, 0.09938638803682157, 0.13711531673158917, 0.11564090475440025, 0.10972724136497293, 0.11139834419425045, 0.14073091771985802, 0.12415571856711592, 0.1727033249501671, 0.10582039279064961, 0.12494550618742194, 0.12628987404916966, 0.17026739780391964, 0.11292722608361926, 0.22202421698187078, 0.18747967348567077, 0.11902541028601782, 0.20825537081275666, 0.12853742630353995, 0.10457152873277664, 0.22687325892703875, 0.11129441977079425, 0.12703737536711351, 0.16681388526090554, 0.10622064702744995], [0.0029760980604416026, 0.04079453294564571, 0.039644941953676086, 0.02181398991628417, 0.06769171197499547, 0.018180930221985494, 0.021735820985798324, 0.02311362705326506, 0.028041506285912225, 0.08115570593093123, 0.016133581421204975, 0.07212765501546008, 0.024196993027414595, 0.03704092471993395, 0.042649471267525635, 0.031344368787748475, 0.019088496254490953, 0.07453075463750533, 0.022850089141034653, 0.012028063730602818, 0.03801233920135668, 0.024483175349554846, 0.07461359019258193, 0.052282459900847504, 0.026795410650915334, 0.02157860272563994, 0.029590006319007704, 0.015248753097174423, 0.03506339547623481, 0.031768096943518946, 0.037793803427900584, 1.2308577469417026, 11.944477098328726, 31.18777104786464, 49.79379619870867, 44.71916198730469, 39.3105799811227, 26.926110812595912, 28.288650819233485, 43.339128153664724, 21.79226926394871, 5.0924511296408514, 0.9964926200253623, 0.04094939838562693, 0.3284664803317615, 1.5267160598720824, 3.311385078089578, 9.46821207659585, 3.449607329709189, 9.925745742661611, 5.656273126602173, 5.357321236814771, 14.569188645907811, 25.782419954027446, 36.55128356388637, 47.39208534785679, 49.882597650800435, 48.362491607666016, 47.436609404427664, 46.7137188230242, 48.852374349321636, 47.15654836382185, 46.96057094846453, 44.733120918273926, 48.646912642887656, 46.388174874441965, 43.94849559238979, 39.184081077575684, 35.565059729984824, 35.27246413912092, 39.617096287863596, 41.687093189784456, 44.92891073226929, 46.505071367536274, 47.482102734701975, 45.514817578451975, 42.90275348935808, 41.27972378049578, 37.76436955588204, 33.64069012233189, 35.47460460662842, 37.5329042162214, 41.8314802306039, 42.20856591633388, 45.34436437061855, 44.977391787937705, 47.662627356392996, 39.23239885057722, 38.49709531239101, 30.65356227329799, 38.217135020664756, 51.53899955749512, 44.46316950661795, 46.66709293637957, 43.572622367313926, 46.25639533996582, 43.2001885005406, 46.502052375248496, 38.840020179748535, 33.38917922973633, 32.069421018872944, 36.54200771876744, 44.05749198368618, 45.78208698545183, 40.33380992071969, 37.67916032246181, 35.54997866494315, 39.450120653424946, 44.207451479775564, 47.2951579775129, 46.865623814719065, 43.56940535136631, 44.93948936462402, 46.571211269923616, 46.987776620047434, 45.495915004185264, 41.284299169267925, 38.83016416004726, 40.18542071751186, 41.039128507886616, 42.44584689821516, 45.18201971054077, 45.367699895586284, 46.94948509761265, 44.254376138959614, 36.303701877593994, 24.060003212520055, 12.629581638744899, 4.888700417109898, 2.1813552464757646, 2.0334654450416565, 3.8497923016548157, 5.960175607885633, 6.006146626813071, 5.2475223285811285, 3.0706942677497864, 1.799615136214665, 0.3322237730026245, 0.6506876700690815, 3.375508482967104, 11.23051495211465, 21.800299644470215, 28.008169412612915, 26.424051352909633, 35.23313038689749, 31.764978749411448, 22.541667222976685, 12.610387240137372, 1.0852765930550439, 0.034515492019376585, 0.025746541397113885, 0.0319509112409183, 0.04358987669859614, 0.04653375855247889, 0.011065830676151174, 0.062065123181257925, 0.04242731211706996, 0.045003828326506276, 0.04178123142836349, 0.0450979954163943, 0.012985055950204176, 0.038283549648310454, 0.026402052026242018, 0.023695769387164285, 0.036712937855294774, 0.021036000323614905, 0.008344700842696642, 0.022655631182715297, 0.04488902020135096, 0.040744087259684286, 0.11793098758373942, 0.11649888514408044, 0.05008564170982156, 0.017048453579523733, 0.025384003529325128, 0.01897087220900825, 0.02576503826172224, 0.10566996836236545, 0.010861962285291935, 0.06542850591774498, 0.05924393742212227, 0.021862528918843185, 0.024000794626772404, 0.01966813818684646, 0.059354599698313644, 0.05644566918324147, 0.02151307829522661, 0.06229659861751965, 0.03113346653325217, 0.025227346756894673, 0.021466708908389722, 0.045191422903112004, 0.019891019977097, 0.021064843150920103, 0.012265422913644995, 0.07091231058750834, 0.04024217490639005, 0.005486241882733468, 0.03431621306974973, 0.03555109930623855, 0.013618336923952614, 0.050700692992125235, 0.05875478831252881, 0.04185657934950931, 0.019275532736043845, 0.028328138137502328, 0.01909258951699095, 1.4551683962345123, 15.105977807726179, 36.792017800467356, 53.839822564806255, 47.48030315126692, 43.36632340294974, 33.52156325748989, 29.762622560773575, 46.32056195395333, 21.83557391166687, 5.449259800570352, 0.9363592181886945, 0.14693768109594071, 0.4137117846735886, 1.831242901938302, 3.8759631259100775, 4.096320467335837, 2.6485592850617, 9.611168657030378, 9.30576319353921, 6.8570990221841, 18.608517817088536, 29.84218290873936, 39.994213240487234, 48.9600818497794, 52.251182964869905, 50.13891669682094, 49.738721302577424, 48.69105454853603, 50.15688473837716, 49.22037179129464, 45.63429880142212, 46.793119362422395, 50.5047219821385, 48.469646726335796, 44.89602838243757, 40.78525522777012, 36.63364403588431, 38.0804500579834, 40.864808627537315, 43.10628359658377, 46.497473512377056, 48.49799190248762, 48.680510657174246, 47.31881659371512, 45.05237674713135, 42.31705856323242, 39.40176466533116, 35.13394137791225, 36.27586391993931, 39.45639140265328, 43.77950498035976, 43.96082169669015, 46.97978619166783, 46.896880286080496, 48.619814668382915, 41.59680829729353, 38.77201816013881, 33.37237501144409, 40.70224857330322, 52.02327510288784, 47.433729376111714, 48.54060173034668, 45.54148823874337, 47.39994028636387, 45.368516308920725, 48.22542796816145, 41.757297788347515, 35.50099039077759, 34.56935855320522, 38.7219876561846, 45.10270602362496, 48.219904150281636, 41.40295703070504, 38.696692739214214, 37.17737531661987, 42.258005823407856, 47.19834177834647, 47.392328534807476, 47.701738766261506, 44.63003396987915, 47.12060185841152, 48.18915489741734, 48.546573707035606, 46.95385204042707, 43.75775711877005, 40.93844563620431, 41.45386300768171, 42.0213953426906, 43.67874220439366, 47.34932960782732, 46.396398067474365, 48.80626957757132, 48.10549858638218, 38.36787271499634, 26.296180180140905, 15.535633563995361, 5.1232885377747674, 2.607029902083533, 3.573226422071457, 5.936071872711182, 5.975481620856693, 6.84184034381594, 5.383115989821298, 2.7125296124390195, 1.855865797826222, 0.24638705753854342, 0.5694601887038776, 3.2611274548939297, 12.651062863213674, 26.591301441192627, 34.02681194032942, 30.969378743852886, 41.311730657305034, 41.02918563570295, 29.486490726470947, 15.032236576080322, 1.7986921114580972, 0.04565992758476308, 0.07206995239747421, 0.037199372824813635, 0.05218195868656039, 0.031640355940908194, 0.01963605365848967, 0.03158645311902676, 0.036719227874917645, 0.03822903275223715, 0.0633712759507554, 0.07178331206419639, 0.046836849967283864, 0.041560371672468524, 0.04555033060855099, 0.005349037437034505, 0.020849043569926704, 0.05526459416640656, 0.03940876426973513, 0.011484047431232674, 0.04368680203333497, 0.014796933591631907, 0.052510617300868034, 0.012710363770435964, 0.021969737451789633, 0.037231118085661104, 0.03272752510383725, 0.07247972648058619, 0.07727310141282422, 0.3066421885575567, 0.16169778550309793, 0.10858461553496973, 0.18091733061841556, 0.0962567131168076, 0.08618957402982882, 0.10167007906628506, 0.12939570524862834, 0.14771978769983563, 0.22148840501904488, 0.18440836614796094, 0.1494739092886448, 0.1626654171517917, 0.11288935704422848, 0.10914217454514333, 0.09520802367478609, 0.10029578781021492, 0.14071300439536572, 0.1426955751542534, 0.12403460006628718, 0.11895269847341947, 0.11649822017976216, 0.2248284122241395, 0.06539063009300403, 0.12966828633631977, 0.14824890930737766, 0.16860352137259074, 0.08656289721173899, 0.10618681527142014, 0.09324900486639567, 1.7904285320213862, 17.346346276147024, 43.11057758331299, 61.802433831351145, 55.237664631434846, 48.47643859045846, 37.180015632084434, 39.13960565839495, 51.883685793195454, 27.49513874735151, 7.325919168336051, 1.5040418079921176, 0.38983516874057905, 1.0900037565401621, 5.443859313215528, 9.539928776877266, 19.36529128892081, 8.618364879063197, 15.64030817576817, 8.138715096882411, 6.127386612551553, 18.50736246790205, 28.697213581630162, 41.12215600694929, 50.30653851372855, 53.968211378370015, 52.62423522131783, 51.77026687349592, 50.18544183458601, 52.96676056725638, 49.62369734900338, 47.237213475363596, 45.9063937323434, 52.920006138937815, 50.56086342675345, 47.485868658338276, 43.62805509567261, 39.896062987191335, 39.67411320550101, 43.17541469846453, 45.48844916479928, 48.22625132969448, 51.19013745444161, 50.9668744632176, 48.53783982140677, 46.688201563698904, 44.182455335344585, 43.0158805847168, 36.68935816628592, 38.226945877075195, 42.47207287379673, 46.72391530445644, 46.17142234529768, 48.36565998622349, 48.01482459477016, 50.095681531088694, 43.35539388656616, 39.37040049689156, 36.34544665472848, 42.74399757385254, 52.161891664777485, 49.80027886799404, 50.939213684626985, 47.534203801836284, 51.06883927753994, 46.8931873185294, 50.03366538456508, 42.73358569826399, 36.13548598970686, 36.010731084006174, 40.23050062997, 46.82146801267351, 49.40197338376726, 43.54054600851876, 40.145093372889924, 38.32987649100167, 43.04313836778913, 49.01435770307268, 49.27241379874093, 50.28035422733852, 46.212194374629426, 48.83099126815796, 50.09068577630179, 49.53278711863926, 49.16070066179548, 45.19335222244263, 42.44951902117048, 44.79467500959124, 43.13594545636858, 45.84523916244507, 50.16650104522705, 49.42602457318987, 50.88215855189732, 47.674991675785606, 39.790321826934814, 28.405590738568986, 16.166184323174612, 6.686875973428998, 5.369801070008959, 6.036932357719966, 11.475593549864632, 12.52425650187901, 12.477984973362513, 8.998530353818621, 6.273178926536015, 4.409875299249377, 0.9742114841938019, 1.2367855374302184, 4.756761942590986, 15.919601440429688, 30.816038949148997, 39.047229358128135, 38.98751653943743, 46.86715241840908, 47.81467131205967, 34.89807782854353, 16.958600316728862, 2.207216441631317, 0.15536273829638958, 0.11793102829584054, 0.23782315850257874, 0.1091118643858603, 0.09446240868419409, 0.07769377955368587, 0.11231066845357418, 0.11846378685108253, 0.1490028431372983, 0.1432657345597233, 0.1581658071705273, 0.1112190888130239, 0.0998324298166803, 0.10632719059607812, 0.0696079016530088, 0.07470834082258598, 0.08864357056362288, 0.060584437634263716, 0.08647364271538598, 0.09578344172665051, 0.09274638005133186, 0.2663756678146975, 0.22665048230971607, 0.08376144325094563, 0.06579589870359216, 0.09521790314465761, 0.16124221709157738], [0.007715363853744098, 0.016941696272364686, 0.03820226115307637, 0.021654111798852682, 0.021113774007452384, 0.05717464988785131, 0.02420011259216283, 0.010437881291311766, 0.007149408820883504, 0.012037077220156789, 0.05308981818546142, 0.054919613392225335, 0.02740799036941358, 0.017210087406315973, 0.04763002687000802, 0.05815999808588198, 0.007213603322660285, 0.020007963791223507, 0.023038134943427782, 0.03660951215507729, 0.012243513017892838, 0.038679481617041996, 0.033886171145630736, 0.05723012012562581, 0.04706707350643618, 0.03267143400652068, 0.03714010618360979, 0.055013953508543115, 0.09873158138777528, 0.02616295833805842, 0.05116035636248333, 0.26192192680069376, 5.19376585313252, 27.38333007267543, 44.47809076309204, 40.556642123631065, 35.08875029427664, 29.025498594556534, 35.01882014955793, 41.590315205710276, 22.97344044276646, 5.862892142363957, 2.0566222710268836, 0.10921283718198538, 0.26697166583367754, 0.9011354339974267, 1.3036419727972575, 1.819867832320077, 7.624537110328674, 10.526433144296918, 1.4226042521851403, 4.630319493157523, 8.276688950402395, 20.62357531275068, 31.969766480582102, 46.62827682495117, 50.37407152993338, 49.716709409441265, 48.60400751658848, 48.75568669182913, 47.661658082689556, 46.5061274937221, 47.64951263155256, 46.19567503247942, 49.82855108806065, 45.98746183940342, 44.28103985105242, 39.8514347076416, 36.84461566380092, 37.77495513643537, 38.67725167955671, 41.72210168838501, 44.05475786754063, 45.62777444294521, 47.26453031812395, 46.0452013696943, 43.227960450308665, 42.493761675698416, 39.770581994737896, 38.30293137686593, 39.38924748556954, 41.416280201503206, 42.90001589911324, 42.44643749509539, 43.73793043409075, 44.27479689461844, 44.038436549050466, 38.95904629571097, 49.98158516202654, 35.580686228615896, 38.85903739929199, 50.91592332295009, 43.90987055642264, 45.46294927597046, 41.07020780018398, 40.486531325748985, 38.98973996298653, 37.61213452475411, 33.60037667410714, 32.89948756354195, 32.400318554469514, 41.188087463378906, 45.87455013820103, 45.71640566417149, 42.97042546953474, 39.11115278516497, 34.83481100627354, 37.39047309330532, 42.563598019736155, 47.236379691532676, 47.75805391584124, 48.17982694080898, 46.08107839311872, 46.897404875074116, 45.48648977279663, 44.682287897382466, 42.48884929929461, 39.190289293016704, 42.00182574135916, 43.077611855098176, 43.94639376231602, 44.90270560128348, 47.54787785666329, 48.03207002367292, 44.766253403254915, 32.16154718399048, 20.956795283726283, 10.331702062061854, 2.9721649033682684, 1.9840557192053114, 2.6451618330819264, 3.2222789909158434, 3.7589098640850613, 6.279185209955488, 3.3203106905732835, 2.3319533254419054, 1.3391606211662292, 0.4144160768815449, 0.9298761146409171, 5.108311261449542, 11.865123459271022, 15.76148475919451, 20.26185383115496, 31.177873338971818, 33.575470856257844, 27.427199261529104, 18.21633890696934, 6.9699664286204746, 0.7802946982639176, 0.043314900382288864, 0.022067334536196928, 0.083356520693217, 0.05758873945368188, 0.05263016499312861, 0.057707286306789944, 0.04571934011099594, 0.05933185520448855, 0.01327945024240762, 0.03911758792985763, 0.03592939614983542, 0.02061174969588007, 0.10404203393097435, 0.01869236581426646, 0.05339481967634388, 0.030115616507828236, 0.02982621792969959, 0.017162630667111704, 0.021499509291191186, 0.044254338900957785, 0.051130955440125296, 0.02518099433343325, 0.055216316399829726, 0.01572199904226831, 0.0312226124640022, 0.058626334848148484, 0.05838894937187433, 0.007088385198065745, 0.06324238822396312, 0.02546272716218872, 0.06650847582412617, 0.014706277920465385, 0.0438403104032789, 0.047379318358642716, 0.0348032960402114, 0.03223920041429145, 0.005981043613116656, 0.009525919200054236, 0.04452052818877356, 0.00510303074926404, 0.06179637581642185, 0.04906442275803004, 0.026018667866342833, 0.032599706069699357, 0.012742340581358542, 0.04133402596094778, 0.04463340248912573, 0.04062765743583441, 0.027741673535534313, 0.04517670887123261, 0.05311384511047176, 0.08230510354042053, 0.05391675220536334, 0.017546140355989337, 0.07886883935758046, 0.048439661639609506, 0.02840813571986343, 0.08055299720061676, 0.4342454214181219, 7.221963260854993, 32.1207959992545, 50.9432749067034, 49.97183683940342, 41.65940114430019, 33.3780586378915, 41.467446735927034, 46.20302970068795, 26.60111924580165, 6.849897214344569, 2.123767925160272, 0.06595161570502178, 0.27319632896355217, 0.11637818733496325, 2.0334022598607198, 1.823067912033626, 10.170065249715533, 15.384921925408499, 2.412368518965585, 7.2611463240214755, 10.33964124747685, 23.562856129237584, 33.28807599203927, 47.42941801888602, 51.229363509586875, 51.80881200517927, 50.98405041013445, 50.45009177071707, 48.80468538829258, 47.122724533081055, 48.81982203892299, 46.355768476213726, 50.27061980111258, 47.939169134412495, 45.6237827028547, 41.725158895765034, 38.60089445114136, 39.450874532972065, 39.74772242137364, 43.28679084777832, 46.47103214263916, 46.357578481946675, 48.574922357286724, 48.08579349517822, 45.61769955498831, 43.14674643107823, 41.63685423987252, 39.136482443128315, 40.96740920203072, 43.78373990740095, 43.76871790204729, 44.84063386917114, 46.45290776661464, 46.29686859675816, 44.45428276062012, 40.2627854347229, 48.77691691262381, 37.36177008492606, 40.20916618619646, 51.956377846854075, 46.018172877175466, 46.577676568712505, 42.54016521998814, 44.398506096431184, 42.17321000780378, 40.35341773714338, 35.67713417325701, 34.76988703863961, 34.06639930180141, 42.56875705718994, 48.27463858468192, 46.98199571881975, 45.68378734588623, 40.76894433157784, 37.634021350315635, 39.7243903705052, 45.024375506809776, 49.719898632594514, 50.222472258976524, 47.8219495500837, 47.0736528805324, 47.379286766052246, 48.50852884565081, 46.46428196770804, 43.96536234446934, 40.351378440856934, 44.08691760471889, 45.649164472307476, 46.697539942605154, 46.82743304116385, 50.65782553809029, 49.84178393227713, 46.83827917916434, 34.97694683074951, 23.387513126645768, 10.073769296918597, 4.378688309873853, 2.5872210221631184, 4.612483033112117, 5.58227915423257, 6.506750438894544, 8.70720020362309, 5.1045470748628885, 3.454919010400772, 1.0030642045395715, 0.5746299741523606, 1.0409671706812722, 6.3324666023254395, 13.693069440977913, 18.3670939717974, 24.194527285439626, 34.97705800192696, 38.02068860190255, 33.91519955226353, 23.229163680757793, 8.926795414515905, 0.9161928317376545, 0.10461546387523413, 0.009306790556625595, 0.05697083153894969, 0.013598118276734437, 0.01134265769672181, 0.015510099341294594, 0.05604686361870595, 0.0555707627375211, 0.030175504008574144, 0.038232198118099144, 0.02908584462212665, 0.041525630679513724, 0.10473025164433888, 0.037969750950911214, 0.010874737403355539, 0.016380351036787033, 0.03822540258988738, 0.013035047017703099, 0.05227378822330918, 0.009065601891571922, 0.029223085114998475, 0.04071036746193256, 0.05262628716549703, 0.06494600645133428, 0.030470860124166523, 0.036040360374110084, 0.01139453933241644, 0.09453427911336933, 0.12382426778120653, 0.1189626729381936, 0.12462214353893485, 0.12335215668593134, 0.1251622981258801, 0.1470909621566534, 0.1447684589241232, 0.08261295487838131, 0.055698466420705826, 0.10911962682647364, 0.15608016694230692, 0.16458807326853275, 0.11739862257880823, 0.2050956639328173, 0.0832092785941703, 0.14717168068247183, 0.11713775300553866, 0.1386291826409953, 0.194491125111069, 0.10228204979960408, 0.1206204696957554, 0.08337186236998864, 0.16238370298274926, 0.12926808638232096, 0.19071819899337633, 0.13640210857348783, 0.13137986377945968, 0.1810179573616811, 0.08223133999854326, 0.16262223518320493, 0.6472400607807296, 8.587725060326711, 36.72209460394723, 57.1835423878261, 55.21827220916748, 46.25419970921108, 39.8615026473999, 46.74617385864258, 51.200337409973145, 30.362269469669886, 9.179050632885524, 2.6418356001377106, 0.29905822979552404, 0.6241568965571267, 1.205692674432482, 4.4182261654308865, 2.7634008484227315, 17.154185158865793, 15.266653163092476, 2.724929975611823, 6.282299305711474, 11.176243441445486, 24.378244604383195, 34.647584847041536, 49.36326149531773, 54.21074172428676, 53.20932912826538, 53.09966223580496, 52.75084529604231, 49.809672832489014, 47.477138246808735, 48.746702671051025, 45.20228065763201, 54.154780932835166, 50.170972211020334, 49.52778441565377, 44.71399252755301, 40.137693541390554, 40.67315993990217, 42.11514738627842, 44.83923380715506, 48.103751114436555, 47.64332526070731, 50.41057736533028, 48.72502429144723, 46.88061802727835, 45.879570211683, 43.77805628095354, 41.070023672921316, 43.51567840576172, 44.623735427856445, 45.80836507252285, 45.349495615277974, 48.538829939705984, 46.97497456414359, 46.587754930768696, 42.62760829925537, 48.58163431712559, 39.62180021830967, 42.218644278390066, 53.20882190976824, 49.30130440848214, 49.252184118543354, 44.07448727743966, 45.422771317618235, 43.320392336164204, 39.92408159800938, 35.90379135949271, 36.298205852508545, 36.16053424562727, 43.657894134521484, 49.19135611397879, 47.6590872492109, 48.434815406799316, 42.91187300000872, 39.23182562419346, 41.46350015912737, 46.54213653291975, 51.85596595491682, 51.61683675221035, 47.778537205287385, 46.39951433454241, 48.94150931494576, 49.894746576036724, 47.62243550164359, 45.166612080165315, 43.09063277925764, 46.03735685348511, 47.82627132960728, 48.935537338256836, 48.99400642939976, 52.07840558460781, 52.05922160829817, 48.60228783743722, 35.52833502633231, 23.263534682137625, 11.681822163718087, 4.792224245412009, 3.7004142829350064, 6.625956773757935, 9.52194423334939, 11.804968561444964, 18.698463984898158, 11.387977634157453, 5.4107038123267035, 2.501871087721416, 1.1354625629527229, 1.984098059790475, 7.513095821653094, 17.49751475879124, 25.530405317034038, 30.721171719687327, 43.369655064174104, 44.46258238383702, 40.56494869504656, 28.087434462138585, 10.46977492741176, 1.2840818166732788, 0.19689028923000607, 0.14577316572623594, 0.22221495317561285, 0.10669816604682378, 0.1476765921605485, 0.22851354948111943, 0.16451548359223775, 0.1352677337293114, 0.13496638275682926, 0.0822256945871881, 0.17571804246732167, 0.09000885087464537, 0.23523186040776117, 0.08278444781899452, 0.1118113888161523, 0.15668681796107972, 0.09874438534357718, 0.13901349130485738, 0.16612023248204164, 0.11176891252398491, 0.187477244330304, 0.117983004078269, 0.15184376069477626, 0.1496812967317445, 0.14603783509560994, 0.11331129047487463, 0.09974741616419383], [0.022591221246070096, 0.014569386873128158, 0.06619119963475636, 0.012780960250113691, 0.011924205464310944, 0.021559890426163162, 0.05450861116072961, 0.08410461233662707, 0.06799774483910628, 0.05672803474590182, 0.02568394654164357, 0.04093429080343672, 0.0431097046072994, 0.02346770528570882, 0.019697705350284065, 0.029144191848380224, 0.017407142457419207, 0.027771401851038848, 0.032510916369834116, 0.04960210747750742, 0.02211153430731169, 0.07144608015992812, 0.044403569107609134, 0.03701163575585399, 0.02125218158055629, 0.02611740319324391, 0.0332970534717398, 0.01292941183783114, 0.009351078537292778, 0.026903206116652915, 0.033405700498925786, 0.045495946026806316, 3.314837030002049, 15.858514615467616, 35.582478863852366, 39.58016661235264, 39.67024653298514, 30.250869001661027, 25.655281816210064, 44.722312995365684, 26.879139253071376, 7.966963444437299, 3.6599471058164323, 0.10320433495300156, 0.15266769219722065, 1.1593049807207925, 1.2898608722857066, 5.472199712480817, 11.855982235499791, 10.373525874955313, 0.9419507810047695, 2.8387564505849565, 7.087037060941968, 15.90182100023542, 25.978637082236155, 40.62195519038609, 47.10661513464791, 51.53803375789097, 51.18599285398211, 49.02761834008353, 47.5854571887425, 48.476636614118306, 45.96306324005127, 46.44550446101597, 47.10971055712019, 47.507203102111816, 44.86592878614153, 41.799900668007986, 39.29783698490688, 38.50358145577567, 38.656962939671104, 39.61811072485787, 42.770362513405935, 43.64955282211304, 45.30245631081717, 44.447404044015066, 43.942634786878315, 40.04011651447841, 37.547481536865234, 36.960046086992534, 38.733063084738596, 41.56206383023943, 46.113217285701204, 47.713418688092915, 47.30002866472517, 43.26607131958008, 47.035910265786306, 45.3269556590489, 47.394694396427695, 34.136940887996126, 37.96433523723057, 49.58799403054373, 42.38495635986328, 44.30247851780483, 36.497570514678955, 36.47471441541399, 32.41381195613316, 32.553679193769185, 31.572788102286204, 34.27074582236153, 39.25558846337454, 44.004126344408306, 46.908542837415425, 46.5208020891462, 44.157414027622764, 42.11299344471523, 36.81755937848772, 35.57637139729091, 40.05442632947649, 45.039425304957796, 45.091647965567454, 48.42378166743687, 46.590694018772666, 47.41840859821865, 48.017065388815745, 46.50248663766043, 43.74818597521101, 41.227900641305105, 41.24107789993286, 43.186010701315745, 45.213081632341655, 48.03186157771519, 48.15054375784737, 47.13779864992414, 38.89753041948591, 29.357261180877686, 18.29259886060442, 6.53901309626443, 2.084687347923006, 1.2567507518189294, 3.723953911236354, 3.398194351366588, 4.877405686037881, 2.991961623941149, 3.466915075268064, 2.1664576573031287, 0.7517218057598386, 0.2429875699537141, 1.8698147407599857, 4.936314685004098, 18.600984232766287, 29.44652816227504, 30.212303025381907, 34.3755316053118, 37.88293014253889, 23.165525129863195, 12.84171187877655, 4.187127777508326, 0.09781811040427003, 0.016311961492257457, 0.04227465530857444, 0.020981658150308898, 0.00808405942682709, 0.0214995279509042, 0.04655688641858952, 0.017286590533331037, 0.01160214645122843, 0.0485593484315489, 0.020386878101687347, 0.05415923008695245, 0.04445566702634096, 0.01821842267444091, 0.04474538790860346, 0.027328822296112776, 0.065655916929245, 0.09333552486662354, 0.02650386281311512, 0.023341090651229024, 0.02986642112955451, 0.06951144111475774, 0.048875732347369194, 0.013256644680430847, 0.03439587647361415, 0.030704018327274492, 0.03133457074207919, 0.023780403060040305, 0.04550732166639396, 0.05835285809423242, 0.057029043058199544, 0.03245964965650013, 0.025019886371280466, 0.011052634866376008, 0.06422615543540035, 0.0413663479765611, 0.05276092208389725, 0.07528749760240316, 0.053747861446546655, 0.012656346445770135, 0.07719391637614795, 0.045369521382131746, 0.02617867151275277, 0.07450815942138433, 0.023566396507833685, 0.03548477590084076, 0.06919626838394574, 0.018941315223595927, 0.011395312862337699, 0.02837825982299234, 0.0520343569639538, 0.028257414432508603, 0.014852283389440604, 0.037265075370669365, 0.033248592500707934, 0.04000400572216936, 0.02423106735971357, 0.049856724350580146, 0.013216321040610117, 0.13093501622123377, 4.175048334257943, 20.04096712384905, 40.54638658251081, 43.46586677006313, 46.330668108803884, 35.768412658146445, 32.51553705760411, 47.36620330810547, 30.168115956442698, 9.846861107008797, 3.1827322329793657, 0.19524480109768255, 0.11881179389144693, 0.877119528395789, 1.5920030708823885, 6.0194719689232965, 13.279279027666364, 6.898109895842416, 2.9109091503279547, 5.849810855729239, 8.092050126620702, 17.771798372268677, 28.48563919748579, 41.74185194287981, 49.564491748809814, 55.03250517163958, 51.2749992779323, 50.37162576402937, 49.644385610307964, 49.97991759436471, 46.46782554898943, 46.8170211655753, 49.53871393203735, 50.01747955594744, 46.52287265232631, 42.962712969098774, 41.09437710898263, 39.769432067871094, 40.192987305777415, 42.368659360068186, 44.607657296316965, 46.01731824874878, 48.06727654593331, 45.79765442439488, 46.07531486238752, 43.20477431161063, 40.136554036821636, 38.72180700302124, 40.770021302359446, 42.21005630493164, 45.96345581327166, 47.321832111903596, 49.688402448381694, 45.305944306509836, 48.76590401785714, 46.092699255262104, 47.653236865997314, 37.85339682442801, 40.53558908190046, 51.2809191431318, 44.47557551520211, 46.112421716962544, 38.86586747850691, 38.02124445778983, 34.394805908203125, 34.13538449151175, 32.83606440680367, 34.15631593976702, 40.50716052736555, 45.22878456115723, 48.555363178253174, 47.89036846160889, 45.829438958849224, 42.705664362226216, 38.76171050752912, 38.049891880580354, 43.457636628832134, 47.58273002079555, 47.62314421789986, 48.836518560137065, 46.5739141191755, 48.39149338858468, 49.25242730549404, 47.80315467289516, 46.151154450007844, 41.66750969205584, 43.88841799327305, 45.89275789260864, 47.19766432898385, 49.505553654261995, 50.417678424290244, 48.654750210898264, 40.83225284303938, 30.897576059613908, 21.211643048695155, 9.113126124654498, 4.050967403820582, 3.1606836446693967, 6.523567685059138, 7.505836691175189, 7.686304858752659, 7.33065436567579, 3.451619267463684, 1.7677609026432037, 0.5151051910860198, 0.3850447115089212, 2.050849403653826, 7.260202671800341, 20.93601495879037, 28.707333632877894, 30.394415310450963, 38.54148040499006, 42.4308248928615, 30.07621213368007, 16.430931534085953, 5.641404415879931, 0.15697784163057804, 0.01895376294851303, 0.006179745807977659, 0.02958106662013701, 0.02284838262546275, 0.04488127472411309, 0.06607405056378671, 0.05466129171795078, 0.03704326905842338, 0.04957635368087462, 0.02183040707106037, 0.03704934873219047, 0.06275583790349108, 0.011998858735231417, 0.017744180979207158, 0.029579397423991134, 0.07978323314871107, 0.06956004457814352, 0.05124504431816084, 0.020547090397615517, 0.06963900569826365, 0.08435558208397456, 0.04082580662465521, 0.035785414411553314, 0.049089857643204074, 0.0396310285931187, 0.03004328128216522, 0.011647928057105413, 0.09265179905508246, 0.13925488692309174, 0.18386974505015782, 0.09533148990677935, 0.11933155171573162, 0.08833945795361485, 0.1560283675789833, 0.14091636134045465, 0.09649139123835734, 0.17642655516309397, 0.18290636103068078, 0.20377385057508945, 0.1241962406784296, 0.2057380194642714, 0.10848612617701292, 0.12890260027987616, 0.12240881659090519, 0.15234238893858024, 0.08156180913959231, 0.16650281766695635, 0.1057582525536418, 0.21233538830918924, 0.1582759605454547, 0.11420825948672635, 0.22453312735472405, 0.08433584350028209, 0.18668797239661217, 0.09732907664562974, 0.09163839343403067, 0.11974324605294637, 0.21036319913608686, 0.27656587958335876, 4.71164207799094, 22.12615626198905, 46.90338379996163, 51.70657273701259, 52.969880308423726, 40.14854315349034, 36.96365220206124, 54.22187621252877, 35.967655726841514, 12.655065894126892, 4.998019465378352, 0.5600169354251453, 0.5615312627383641, 2.270314987216677, 4.552527461733137, 13.720611231667654, 20.088543176651, 12.97474730014801, 2.802243015595845, 4.520201402051108, 9.361147284507751, 18.207928112574987, 30.447701045445033, 43.50797980172293, 51.35529613494873, 56.35749190194266, 53.68036140714373, 53.040401050022666, 49.90956013543265, 50.39607994897025, 46.38851533617292, 47.32093926838466, 50.678124700273784, 52.616057191576274, 48.092543670109336, 45.9053167615618, 42.839820180620464, 42.43089784894671, 41.87658098765782, 43.1851213318961, 46.39021417072841, 47.454275199345176, 50.64020490646362, 47.6691551889692, 47.53155306407383, 44.75293370655605, 40.627148968832834, 41.889716557094026, 42.48169265474592, 43.74544491086687, 49.2822767666408, 50.452315194266184, 51.027334213256836, 47.079513686043875, 49.1403146471296, 47.3104579108102, 48.89134679521833, 39.42405448641096, 42.09745379856655, 52.842280115400044, 46.99601718357631, 48.22924600328718, 39.428185190473286, 38.92090763364519, 35.624359130859375, 35.75918197631836, 35.12231009347098, 36.80906867980957, 43.53668628420149, 47.36524445669991, 49.980157307216096, 49.91672372817993, 47.52332639694214, 44.68010268892561, 40.407144682747976, 38.18601403917585, 45.413491998400005, 48.57729516710554, 49.34274346487862, 51.13123410088675, 47.03855405535017, 49.57806505475725, 51.1262765611921, 49.46307584217617, 48.18024730682373, 45.25426707948957, 46.681830065590994, 47.00260060174124, 49.1207971572876, 52.05513606752668, 52.9891094480242, 50.35534266063145, 41.5179705619812, 31.933107784816197, 22.4212167263031, 8.389314906937734, 3.719246072428567, 5.539347972188677, 9.342529586383275, 14.28627450125558, 10.915895308767047, 10.123890995979309, 9.688862545149666, 5.070317208766937, 1.7498325960976737, 0.7672429957560131, 2.50442151086671, 7.73798816544669, 27.058896098818096, 39.47881323950631, 40.29113061087472, 45.696370533534456, 49.584763118198936, 36.30375051498413, 18.471695627485, 6.532280291829791, 0.266546332942588, 0.15817523880728654, 0.15573595969804696, 0.11907368126724448, 0.06969501876405307, 0.11599856056272984, 0.17984018341771194, 0.14828470881496156, 0.13348724426967756, 0.13211203020598206, 0.07860720303973981, 0.12856819108128548, 0.14240862269486698, 0.09866813157818147, 0.12495212868920394, 0.14914365272436822, 0.17440955553736004, 0.18313831144145556, 0.16627274001283304, 0.10674180263387305, 0.18164902207042488, 0.12949304788240365, 0.1724099942616054, 0.09614468698522874, 0.10079330325658832, 0.12733274166073116, 0.09495480119117669, 0.0945020147732326], [0.012443663885018654, 0.03745645956535425, 0.10291483120194503, 0.04544574461345162, 0.03578233386256865, 0.017442940268665552, 0.061026951032025475, 0.011719849376407052, 0.03761438859094467, 0.027600019172366177, 0.05636093033743756, 0.030198004229792526, 0.02427498553879559, 0.01543355719851596, 0.022855766782803193, 0.0310483578858631, 0.062425391349409304, 0.02980786355744515, 0.08038943633437157, 0.03663215147597449, 0.04816350806504488, 0.07257164761956249, 0.02608816003027771, 0.010750713924478208, 0.02690749615430832, 0.03672630838783724, 0.014807416957670023, 0.05583587654733232, 0.03990377252921462, 0.02087404080001371, 0.04990786214226058, 0.08339872557137694, 0.6030905012573514, 7.427167449678693, 23.463576793670654, 38.731902735573904, 40.49264921460833, 34.61812448501587, 28.855792318071636, 42.918095111846924, 29.615275587354386, 12.01781359740666, 4.645334550312587, 0.36638752264635904, 0.12172593894813742, 0.12061132304370403, 0.4216689376958779, 0.8965749187128884, 11.272428223064967, 3.524053369249616, 2.0507603798593794, 9.385779517037527, 2.730741926601955, 11.861092635563441, 21.95067082132612, 34.43977812358311, 43.83664001737322, 51.238041809626985, 51.0788585799081, 49.491653782980784, 47.2418201310294, 47.000425815582275, 48.25809144973755, 47.25015449523926, 47.42384556361607, 46.6583833694458, 44.55036245073591, 44.638441290174214, 41.25962264197213, 38.98520973750523, 37.73359598432268, 39.22763933454241, 41.01573044913155, 40.60671431677682, 41.09282071249825, 42.19416230065482, 41.7934318951198, 39.57459763118199, 36.61952529634748, 35.47267995561872, 37.41466324669974, 42.3559650012425, 44.770988600594656, 44.52121128354754, 45.82358162743704, 44.41455296107701, 47.51753854751587, 43.95251512527466, 48.926344871520996, 38.39566550936018, 38.67605658939907, 51.51017842973982, 42.54851000649588, 45.169811725616455, 35.31868355614798, 36.14247587748936, 33.734240668160574, 35.861539363861084, 37.030278478349956, 43.039709431784495, 43.663817473820274, 47.09595659800938, 46.99134799412319, 46.738478728703086, 46.866593088422505, 42.90561267307827, 38.92125851767403, 35.594457558223176, 37.500549929482595, 43.64103085654122, 45.509550843920024, 45.52011905397688, 48.028436115809846, 47.15490858895438, 46.95286539622715, 44.33600010190691, 45.04326071058001, 40.76364633015224, 44.419593879154746, 46.18084062848772, 47.924348626817974, 48.963990211486816, 48.71842697688511, 42.567061696733745, 35.16713639668056, 23.445935317448207, 14.199448074613299, 5.069295389311654, 2.4117019261632646, 1.6387352432523454, 4.6082737275532315, 4.994005577904837, 4.564243861607142, 6.0263181158474515, 2.5995514690876007, 2.6160629945141927, 0.45539258952651707, 0.9698074119431632, 2.607606819697789, 10.643192410469055, 19.97114815030779, 25.697768313544138, 26.18631178992135, 41.95542219706944, 40.16322122301374, 19.02993127277919, 9.202428715569631, 1.6695509382656641, 0.014802753725754363, 0.02136546469825719, 0.02782064483367971, 0.026654183764808943, 0.06353928800672293, 0.06294706264244658, 0.1080851119809917, 0.044091663522911925, 0.055371941799031835, 0.03369374539969223, 0.03825237435687866, 0.0906109149966921, 0.015877636315833246, 0.05547841751415815, 0.0592544682856117, 0.020105404812576513, 0.03333560783149941, 0.06499568200004952, 0.04593401841287102, 0.012076534879659968, 0.014467118075117469, 0.053144073845552545, 0.07615034308816705, 0.03926046026338424, 0.01776813665804054, 0.02615556739536779, 0.044926017323242765, 0.0430535253004304, 0.03197732660919428, 0.030022775953901664, 0.032855659656758816, 0.02164116535069687, 0.01748446491546929, 0.04955254388707025, 0.05802030808159283, 0.005556891372959528, 0.051574174514306445, 0.02127118395375354, 0.05471193078639252, 0.05618265883198806, 0.04358329830159034, 0.025770393599356924, 0.015488386220697845, 0.056083911630724154, 0.019163369201123714, 0.017485394508444836, 0.04140988617603268, 0.026927499366658073, 0.039075349124946764, 0.012007904455198773, 0.044769360550812314, 0.017588850742738162, 0.020884376584685276, 0.050379450765571425, 0.08061274899435894, 0.020244769120056714, 0.03322590568235942, 0.09706258201705557, 0.02634741977921554, 0.05910804042858737, 1.3352484596627099, 9.428061042513166, 29.35272400719779, 44.14574105398995, 46.2777784211295, 38.141733169555664, 33.00141763687134, 47.68410423823765, 34.10600403376988, 13.627541848591395, 5.244644037314823, 0.43453656722392353, 0.11548131331801414, 0.2664645287607397, 1.42428343636649, 3.392376537833895, 12.749852350779943, 8.605413436889648, 3.482700079679489, 5.215995745999472, 5.052479445934296, 15.137840509414673, 23.910929611751012, 36.93068994794573, 46.0365161214556, 51.559107644217356, 53.284856046949116, 51.92195994513375, 48.459286962236675, 48.682876518794465, 48.34249816622053, 47.59905481338501, 48.51944099153791, 49.566096782684326, 45.587346349443706, 46.28051948547363, 42.45207595825195, 40.958049978528706, 40.48680230549404, 41.70479025159563, 43.24841594696045, 42.71810163770403, 42.415643078940256, 43.12418910435268, 43.6638765335083, 40.07888398851667, 39.16601923533848, 37.31671449116298, 39.14329515184675, 43.24016843523298, 47.215955461774556, 46.34847981589181, 47.5006023134504, 45.54900966371809, 49.32525484902518, 46.47478069577898, 49.88521712166922, 38.787331989833284, 40.44126033782959, 52.28436061314174, 44.5202420098441, 46.170939445495605, 37.02199969972883, 37.12614972250802, 35.04073824201311, 36.97466162272862, 37.9299590247018, 43.45493377958025, 46.06116485595703, 48.67164822987148, 48.37429659707205, 46.88832010541643, 48.45207820619856, 44.64516019821167, 40.28542961393084, 37.716687543051584, 39.54919849123274, 44.17504160744803, 47.33457858221871, 48.37491498674665, 48.23929309844971, 46.05801384789603, 49.36135074070522, 46.44770703996931, 46.61676018578665, 43.296733719961985, 45.82100731985909, 47.07177339281355, 49.367176805223735, 48.8892171723502, 50.960051332201274, 43.89082554408482, 37.58589117867606, 23.67185252053397, 15.287006173815046, 6.401243346078055, 5.069683619907924, 5.925702120576586, 6.6733612929071695, 6.284725095544543, 7.381186008453369, 5.556754946708679, 3.3056690990924835, 2.25701396380152, 0.6203371786645481, 0.49713606387376785, 3.2234391229493276, 10.041496651513235, 21.123934200831822, 31.061987808772496, 30.685892241341726, 46.449075835091726, 46.43614523751395, 24.140581471579416, 11.634443266051155, 2.7128618231841495, 0.05696366620915277, 0.018303443112277558, 0.06212386395782232, 0.013921865993844611, 0.022076113083000694, 0.014539553384695734, 0.06627613186304059, 0.027360760939440558, 0.0640011192964656, 0.013645178072952797, 0.031534867494234016, 0.0034415366119771662, 0.043414332903921604, 0.037677801081112454, 0.057401382364332676, 0.028550137832228626, 0.058935590753597875, 0.04490408707144005, 0.025868146746818508, 0.05240412122969117, 0.04709535145333835, 0.014999635750427842, 0.07552207394370011, 0.02035823035320001, 0.037443397766245265, 0.03122259210795164, 0.05493243770407779, 0.09357272035309247, 0.0760470971997295, 0.1990773840142148, 0.18824713730386325, 0.17120904156139918, 0.14382207899221353, 0.10275840173874583, 0.19710290139274939, 0.05950481378074203, 0.1224901865103415, 0.1201637749161039, 0.1349475466247116, 0.20239676375474247, 0.08978772988276822, 0.1309395216937576, 0.14018220002097742, 0.17299048097005912, 0.09277714482907738, 0.06227307380842311, 0.187251943562712, 0.10691746177950076, 0.14785336410360678, 0.15062953584960528, 0.10096552222967148, 0.11067786214074918, 0.15502961831433432, 0.14635813076581272, 0.1570952417595046, 0.10910760318594319, 0.12334702696119036, 0.11034412469182696, 0.08124595108841147, 0.18949261547199317, 1.398758468883378, 10.7634996005467, 32.8053012575422, 53.377656187329976, 53.4516510282244, 45.13211080006191, 39.35581622804914, 52.5869094984872, 39.14797476359776, 17.872436080660137, 6.8256688458578925, 0.7934803164431027, 0.3885274146284376, 1.231737996850695, 2.1195147590977803, 4.381803708417075, 16.953578506197246, 9.369995815413338, 7.95750173500606, 14.104104025023323, 4.598219684192112, 14.73141084398542, 25.09539771080017, 37.17692368371146, 47.634396825517925, 52.979114464351106, 55.00059904370989, 52.88564729690552, 49.65794849395752, 49.418593474796836, 48.599835123334614, 47.419794763837544, 49.494749205453054, 51.08645990916661, 48.76960045950753, 49.54043361118862, 45.995730195726665, 43.100693770817344, 40.733320917402, 43.192580223083496, 44.06655590874808, 44.636349882398335, 43.91614130565098, 45.4533816065107, 44.518793310437886, 41.696747711726594, 40.049910000392366, 39.23150600705828, 41.593744141714915, 45.41857807976859, 49.36867414202009, 47.599238940647666, 47.6524795123509, 47.293841293879915, 49.92864683696202, 47.89106675556728, 51.27995681762695, 42.27730791909354, 45.05610792977469, 53.1643499646868, 47.0748861857823, 48.32561404364449, 39.03862748827253, 39.38468599319458, 37.78343193871634, 38.71159315109253, 41.04672288894653, 47.354238510131836, 47.56205218178885, 51.26972212110247, 49.75319440024239, 48.60512965066092, 51.28327110835484, 47.02036714553833, 42.90684597832816, 40.105228083474294, 39.76947375706264, 46.2461884362357, 48.77755267279488, 49.4878739629473, 48.58188097817557, 46.449607372283936, 50.951442514147075, 48.21333115441458, 49.4216958454677, 45.39294270106724, 48.7489469391959, 50.52814783368792, 51.63606589181082, 52.83480732781546, 50.92284720284598, 45.31879152570452, 37.99219056538173, 26.43831079346793, 16.72187692778451, 7.070782618863242, 5.130610636302403, 6.670552917889186, 11.868153742381505, 12.059607880456106, 11.823114650590078, 12.093107751437596, 6.776717918259757, 5.513869796480451, 1.3579242314611162, 1.4869171040398734, 4.117575875350407, 14.636917080198016, 29.136657612664358, 37.75595528738839, 37.2758868762425, 54.73970113481794, 50.53974437713623, 29.287810461861746, 13.667904802731105, 2.643947635378156, 0.1990889733923333, 0.13633718634290354, 0.10355979909322091, 0.0890589357752885, 0.16822382674685546, 0.10213099433375256, 0.17526787519454956, 0.1885446613388402, 0.13636930819068635, 0.173702508477228, 0.15268495412809507, 0.16956818103790283, 0.1541269767497267, 0.14038122791264737, 0.16381455691797392, 0.21076920734984533, 0.15097398736647197, 0.1367076936044863, 0.1388791820832661, 0.07058474102190562, 0.19537760397153242, 0.08714135510048696, 0.1466393428189414, 0.10594005244118826, 0.13022686993437155, 0.14522826139416012, 0.23098051281911985, 0.2261365463158914], [0.08949083688535861, 0.03708745186616268, 0.015515600563958287, 0.02722220408863255, 0.021343125629105737, 0.044669107001807005, 0.024448975488277416, 0.004846340527624956, 0.04225812280284507, 0.06241292666111674, 0.046044266782701015, 0.010136794947486902, 0.01953117928600737, 0.012271489016711712, 0.019304032903164625, 0.022121084687699164, 0.026380081062338183, 0.015176042980913605, 0.056876671234411855, 0.06454860206161227, 0.0024459054277810666, 0.038145583122968674, 0.03310271425704871, 0.0395364984869957, 0.028959246951022317, 0.03607674342181001, 0.05186349845358303, 0.04964349811364498, 0.06281076531325068, 0.020088550002713288, 0.07133191664304052, 0.0739172843417951, 0.07678969949483871, 2.381412991455623, 14.511429139545985, 29.06365462711879, 40.20154053824288, 35.47293356486729, 30.018701893942698, 35.56670992715018, 32.64995690754482, 13.701731239046369, 5.658690231187003, 0.9570243550198418, 0.09106173366308212, 0.22489930556288787, 1.3830570599862506, 3.079715200832912, 2.69232468519892, 5.984052223818643, 1.0045059557471956, 1.2254738701241357, 3.2323738549436842, 9.394887736865453, 17.180402449199132, 27.318114280700684, 39.50508785247803, 45.03328309740339, 50.6422233581543, 47.47825343268258, 48.872020380837576, 47.628473486219136, 48.53424412863595, 47.24429021562849, 49.5339092527117, 48.28418888364519, 46.380705560956685, 44.49421405792236, 44.8782514163426, 40.78756202970232, 40.00068201337542, 39.47553021567208, 39.59651572363717, 38.151748997824534, 39.05547339575631, 39.48549393245152, 40.29152318409511, 37.05783155986241, 36.15654945373535, 33.52464825766427, 35.19244521004813, 38.647534234183176, 40.48302943365914, 42.44464485985892, 43.96074179240635, 40.808639390128, 45.01158734730312, 43.94501107079642, 49.43801021575928, 39.25001948220389, 40.408423151288716, 49.322701386043, 43.367376055036274, 43.649087292807444, 35.23928301674979, 37.145906925201416, 37.09401082992554, 40.326622009277344, 44.62503474099295, 46.172874518803184, 46.59463364737374, 47.2489663532802, 45.9676490511213, 46.63769858224051, 46.693305015563965, 43.60864530290876, 41.77280964170183, 38.70560032980782, 36.592507226126536, 41.411204542432515, 43.72279725755964, 45.52729306902204, 48.18235955919538, 46.386917250497, 48.13397577830723, 45.34485421861921, 44.31481851850237, 41.83679560252598, 43.866322721753804, 45.42765590122768, 50.026300294058665, 49.89974580492292, 46.091698714665, 39.1922938483102, 28.51612615585327, 17.060830899647303, 9.53439540522439, 5.949059358664921, 5.1454102993011475, 4.935754920755114, 5.5991446035248895, 3.2363768858569006, 7.386763674872262, 5.209683741841998, 1.8275940120220184, 1.168286178793226, 0.2859888310943331, 0.8802860613380159, 4.711705480303083, 9.77566465309688, 15.05192950793675, 27.030137504850114, 32.45934697559902, 42.00161729540144, 25.887468031474523, 17.324209315436228, 4.996312814099448, 0.33870125828044756, 0.010966966427596552, 0.03555396272401724, 0.05455162349556174, 0.03249356962208237, 0.03299974656796881, 0.03820968771885548, 0.008253411589456456, 0.01662961087588753, 0.026290777372196317, 0.034490403187062056, 0.046388429922184775, 0.09671091088759047, 0.013622727045523269, 0.04093633997919304, 0.06436534332377569, 0.06860491832984345, 0.04162709541352732, 0.047284133466226716, 0.03571588492819241, 0.009637466964444943, 0.060071946920028756, 0.008772601140663028, 0.06874262022652797, 0.07230517334703888, 0.04272382174219404, 0.043855794572404454, 0.0739302375753011, 0.07448225973972253, 0.06066890845873526, 0.022444854457197443, 0.04267443796353681, 0.02660208584607712, 0.06169222069105931, 0.05285740637087396, 0.038697048888674805, 0.01769660888904972, 0.015269158341522728, 0.03607077909899609, 0.046739218956125636, 0.008323637419380248, 0.0362390557836209, 0.022143696867195622, 0.03569005310003247, 0.08610918120081935, 0.029727341806782142, 0.015226042530100261, 0.01886588757458542, 0.05685614215742264, 0.028180170005985668, 0.05187231940882547, 0.07981631173087017, 0.02492916115027453, 0.053591146998639615, 0.06214550243956702, 0.02239965384693018, 0.012171311802896006, 0.04996505585898246, 0.07157477789691516, 0.013446675197753524, 0.039315557306898494, 0.051669780098434, 4.1884792021342685, 18.72612476348877, 37.2346111025129, 46.38300541469029, 41.08627550942557, 32.65969828196934, 41.30562319074358, 39.17049387523106, 17.315768991197857, 6.317429397787366, 0.9880322111504418, 0.18615849795086042, 0.23630375574742044, 1.246586731501988, 2.2103116469723836, 6.844691710812705, 7.54117088658469, 7.053493329456874, 4.1949931383132935, 6.3715706297329495, 9.836110506738935, 19.517166750771658, 29.81493902206421, 41.96007054192679, 47.56776360103062, 51.34236901147025, 49.22523900440761, 48.901682240622385, 48.39892448697771, 48.46875735691616, 48.95026751926967, 50.579352583204, 50.13303852081299, 49.894663197653635, 45.260298115866526, 46.274929659707205, 44.021764346531455, 41.21602964401245, 41.43629796164376, 40.8814252444676, 41.68366772787911, 40.542297567640034, 41.959045682634624, 42.299010617392405, 39.068935530526296, 37.9150516646249, 35.78490768160139, 36.85088293892996, 40.97016068867275, 42.31439740317208, 43.9409533228193, 46.03296559197562, 43.4588178225926, 46.42513929094587, 46.28814513342721, 50.70273869378226, 41.02870968409947, 42.06041642597744, 50.199133259909495, 44.015702043260845, 44.61827414376395, 36.933163506644114, 37.842720917293, 38.810514654432026, 42.9223369870867, 44.78445420946394, 48.09511797768729, 47.42516919544765, 48.96648114068167, 47.449206488473074, 48.69896854673113, 47.802831581660676, 45.39917523520333, 43.62896530968802, 40.6420076915196, 39.13496426173619, 43.47931848253523, 46.82395199366978, 47.65810407911028, 48.80487993785313, 46.364231382097515, 49.65314034053257, 47.276939800807405, 45.89591237476894, 44.8475056375776, 45.155550548008506, 48.78989267349243, 50.56371913637434, 50.919578075408936, 47.23610871178763, 41.61174692426409, 29.314977918352398, 21.125485386167252, 10.63827655996595, 5.405369767120906, 6.59384263413293, 5.357862327780042, 9.842683502605983, 8.32394972869328, 4.2336898275784085, 6.337868826729911, 2.8957151770591736, 0.7776236044509071, 0.17881680333188602, 0.8853816421968597, 5.574466339179447, 13.434893488883972, 23.33361073902675, 29.936515126909526, 37.6453469140189, 46.08766181128365, 35.864780698503765, 20.18130510193961, 6.797992868082864, 0.4544242386307035, 0.035159442108124495, 0.031606534362903664, 0.02562542798529778, 0.017772984790748785, 0.023745884287304113, 0.031590687177543125, 0.07092098905039684, 0.01938448510398822, 0.021677785885653326, 0.022005803284368346, 0.050166014182780466, 0.030143249846462692, 0.06374113860407046, 0.08277336734214, 0.04088955498965723, 0.04087372137499707, 0.08400007723165409, 0.04451483188729201, 0.020656444797558442, 0.03027755906805396, 0.05970294600618737, 0.0078814225770267, 0.021596873977354596, 0.014789880220113056, 0.02526599950423198, 0.06799825374037027, 0.050379128461437564, 0.055675453905548365, 0.2631191611289978, 0.07617405110171863, 0.09658376699579613, 0.13784422619002207, 0.15742579687918934, 0.1316718781100852, 0.12243749148079328, 0.07304453224475894, 0.16868229928825582, 0.1170325665069478, 0.16006206827504293, 0.11429813823529653, 0.10867277080459253, 0.08853288114603076, 0.11905481799372605, 0.24681092479399272, 0.15731917188635894, 0.0767692755907774, 0.1738480678094285, 0.17483874250735554, 0.11172932679099695, 0.0782060870634658, 0.18163488140063627, 0.1011664228779929, 0.13772576754646643, 0.13818962765591486, 0.14259137931678975, 0.1709383332303592, 0.1387892219104937, 0.10852920636534691, 0.21050875846828732, 0.29862603013004574, 0.26951508649757927, 4.194014745099204, 21.193480457578385, 41.65391901561192, 54.29982805252075, 47.06564508165632, 40.16606651033674, 48.651783330099924, 44.31960930143084, 20.287096636635916, 8.571327311652047, 1.4670789114066531, 0.3597317455070359, 0.7222961304443223, 4.225450132574354, 10.369021705218724, 6.556536887373243, 9.783794045448303, 7.083259412220546, 3.874071478843689, 4.5800058501107355, 12.221503513199941, 18.58463512148176, 31.237290859222412, 43.07043089185442, 49.763317925589426, 53.2192268371582, 50.26344231196812, 49.59711354119437, 49.546030385153635, 50.951477255140034, 48.30575261797224, 51.37250682285854, 50.065936292920796, 50.68470811843872, 46.64581407819475, 48.61489186968122, 46.151807580675396, 44.12884998321533, 43.326822893960134, 43.1960334777832, 43.28187152317592, 41.53171409879412, 43.88091393879482, 43.96817289079939, 40.19293519428798, 39.020346777779714, 37.737817014966694, 37.332837785993306, 42.75551421301705, 43.17307315553938, 45.69100999832153, 46.82962172372, 44.4797340120588, 47.141786915915354, 48.170106410980225, 51.28246859141758, 43.34685455049787, 45.55810138157436, 52.0047025680542, 47.67566565104893, 46.90277235848563, 37.23141145706177, 40.05612863813128, 40.661817005702424, 45.418852533612935, 48.225004128047395, 50.25375999723162, 49.82927370071411, 50.32729278291975, 47.08176142828805, 49.158397333962576, 49.16704436710903, 47.954715728759766, 45.352358273097444, 41.92072984150478, 41.089454310280935, 46.372944423130576, 48.027053424290244, 49.14790555409023, 50.15165274483817, 46.54717397689819, 50.4855032648359, 48.621006284441265, 48.52441242762974, 46.67274529593331, 46.99862275804792, 50.06967789786202, 52.31718390328543, 51.567629609789165, 48.80129814147949, 42.32462167739868, 31.230672700064524, 20.21768413271223, 11.186081222125463, 9.066541058676583, 11.158357041222708, 10.155229108674185, 10.177538905824933, 12.573187453406197, 15.874139377049037, 12.984708411352974, 6.162898421287537, 1.9487271692071642, 0.8172724683369909, 1.715101699743952, 6.957497886248997, 14.919144221714564, 26.221954311643326, 37.28823382513863, 43.699819564819336, 53.57172284807478, 40.18276303155081, 23.270208426884242, 7.928471292768206, 0.5974140944225448, 0.07853860993470464, 0.10355585680476256, 0.13301473962409155, 0.10088883420186383, 0.09624084218272141, 0.1459843801068408, 0.11133192918662514, 0.11033013329974242, 0.08502886524157864, 0.11615870839783124, 0.1643292528710195, 0.14504720110978397, 0.13094001023897103, 0.2080952636897564, 0.1637378553194659, 0.12513506173023156, 0.15173733926245145, 0.17828899808228016, 0.06990308474217143, 0.10793086740055255, 0.1404575223901442, 0.06951650977134705, 0.18141053058207035, 0.08722246039126601, 0.15600240682916983, 0.0815800345901932, 0.1776961348950863, 0.1389179942863328], [0.02721029071004263, 0.04851061265383448, 0.05928323817040239, 0.01661681879444846, 0.06180646563214915, 0.024749417223834565, 0.03406437819025346, 0.05231863260269165, 0.03499147076425808, 0.033020865970424244, 0.053570424539170096, 0.024188935424068143, 0.032046662710074864, 0.020147170339311873, 0.10044599510729313, 0.01038656453602016, 0.09891233633139304, 0.023400757628093873, 0.033464855181851556, 0.06916010246745177, 0.018786760213385736, 0.013319998646953275, 0.04764496481844357, 0.05152827162029488, 0.04685411529083337, 0.025616238924807737, 0.038737306371331215, 0.04192202065938285, 0.03291338263079524, 0.06361939585102455, 0.05031991271036012, 0.03247952733987144, 0.023848848583708917, 0.3854926531868321, 7.2241732222693305, 18.10116730417524, 31.52043342590332, 37.69217777252197, 33.831063815525596, 30.713507856641495, 29.161669390542166, 19.3234474999564, 7.549436637333461, 3.104896341051374, 0.2639800049364567, 0.07022420143974678, 0.5870529189705849, 1.6545074369226183, 4.365194473947797, 6.933468844209399, 7.834046142441886, 4.053894332477024, 4.860613192830767, 4.90788917030607, 14.380129030772618, 21.74213801111494, 32.03074734551566, 40.89531469345093, 49.633136476789204, 48.107694217136924, 49.20314025878906, 45.15360505240304, 46.69498995372227, 48.418890135628835, 46.604611260550364, 48.27509369168963, 48.3817137990679, 46.89409405844552, 45.25849158423287, 43.793512548719136, 40.82298742021833, 40.94711698804583, 39.48776946749006, 37.020210538591655, 38.14875085013253, 36.71328428813389, 37.47893408366612, 36.71794305528913, 36.41750642231533, 35.6188040460859, 35.048603602818076, 35.03385257720947, 37.39022295815604, 34.97924321038382, 37.10282809393746, 37.34786673954555, 42.91908523014614, 42.275119236537385, 49.708573068891255, 40.52148771286011, 36.98233243397304, 49.35123416355678, 41.4983696937561, 44.75414269311087, 37.20266675949097, 38.28408438818795, 37.89559670857021, 41.26231159482683, 44.56902183805193, 47.433541774749756, 47.689784390585764, 49.53181784493582, 46.95463023866926, 48.11713681902204, 47.7905193737575, 45.751594815935405, 41.72912284306118, 39.262001650674, 37.46506200517927, 41.47214719227382, 43.88925525120327, 44.177063533238, 47.418498924800325, 45.57845960344587, 44.75188452856881, 47.73292922973633, 43.53419188090733, 43.95931393759591, 42.78678110667637, 48.54330457959856, 48.951049191611155, 45.59496504919869, 43.58375685555594, 35.553365911756245, 23.31212169783456, 12.16095517362867, 5.2598336679594855, 1.6333714510713304, 5.444581925868988, 6.480564849717276, 12.124264342444283, 6.368299330983843, 3.3941031651837483, 3.6201269796916415, 2.154199949332646, 1.1097330578735896, 0.10541110725275107, 1.7976341396570206, 5.157424603189741, 15.521553039550781, 8.524020501545497, 25.486324208123342, 24.810707432883127, 37.761955056871685, 19.875700746263774, 6.772010079451969, 1.0927294045686722, 0.03985975935522999, 0.03728188268308129, 0.01967763089175735, 0.06715274482433285, 0.04261447921661394, 0.08170120058847324, 0.012663904477709105, 0.030642658405538117, 0.028046868408897092, 0.06649253703653812, 0.01673964211451156, 0.04958516445809177, 0.032540829586131234, 0.021583304973319173, 0.025634070825097815, 0.03467778402513691, 0.1012971019372344, 0.02905808236183865, 0.0160460894195629, 0.05699530629707234, 0.012972961063496768, 0.04362491624695914, 0.03915840181122933, 0.031712365469762256, 0.026877645702500428, 0.06444703894002096, 0.05397861424301352, 0.09778535073356968, 0.01862287873934422, 0.02863203700897949, 0.040082644538155625, 0.045001317746937275, 0.018485882519079105, 0.04101090419239231, 0.08727202737437827, 0.023918707156553864, 0.006344559843585427, 0.05119312960388405, 0.009490066257837628, 0.01468291595977332, 0.04995314756940518, 0.02659768724281873, 0.015029752527230551, 0.06332121363707952, 0.011951380791807813, 0.05268625948312027, 0.025097872097311274, 0.009870361387064415, 0.04344631904470069, 0.016300796198525598, 0.009137539326080253, 0.034158979542553425, 0.012252289020190281, 0.029416152076529603, 0.06438021681138448, 0.032569015930805884, 0.03432926469083343, 0.07649106266243116, 0.03547181248930948, 0.09702598862349987, 0.05543984279834798, 0.02020526141859591, 0.6978977482233728, 10.203063981873647, 24.27147511073521, 40.34951979773385, 42.60674980708531, 38.53440713882446, 39.37504884174892, 34.123176506587434, 21.66800594329834, 9.943048494202749, 2.9775640879358565, 0.25997852108308245, 0.15438730349498136, 0.5140605185713086, 2.8805448710918427, 5.909647004944937, 7.083515627043588, 5.288600512913295, 4.8060073001044135, 4.822180100849696, 6.280238730566842, 14.880977766854421, 24.209253992353165, 35.681650502341135, 42.45099203927176, 51.5642215183803, 48.744524410792756, 50.950789383479524, 46.32473087310791, 47.88861404146467, 48.90353740964617, 47.71725409371512, 49.40331786019461, 50.782305989946636, 48.20842572620937, 48.1159382547651, 45.46419300351824, 43.00132410866873, 43.42027963910784, 41.252802985055105, 38.61112567356655, 40.53191001074654, 38.46847915649414, 39.20754167011806, 37.51134048189436, 38.86731965201241, 36.884765829358784, 37.16056415012905, 36.80256169182913, 39.805653027125764, 37.78905650547573, 38.98266669682094, 39.05152334485735, 45.87601968220302, 44.20619732992989, 50.71482855933053, 41.25668355396816, 40.170075620923726, 51.38802215031215, 44.13059745516096, 45.62891047341483, 38.30523123059954, 39.710247312273296, 42.10051795414516, 43.63964121682303, 46.31758117675781, 49.05855172021048, 49.33283533368792, 50.12798023223877, 48.90021964481899, 49.08572959899902, 49.53703941617693, 47.62116398130144, 42.91943958827427, 40.8303142956325, 39.9096953528268, 42.46949509211949, 45.053926195417134, 47.06084040233067, 47.71630219050816, 45.94880553654262, 46.85347836358206, 48.77555159160069, 46.502900055476594, 45.339257444654194, 44.36738511494228, 50.72396544047764, 51.36803218296596, 49.03677259172712, 44.832532269614084, 36.537890911102295, 25.368413278034755, 14.757310254233223, 6.405592484133584, 3.7067332352910722, 4.764520909105029, 7.734916193144662, 11.07063603401184, 9.188636541366577, 5.613935147012983, 3.951369753905705, 1.4279660901853015, 0.5541017385465759, 0.2288313481424536, 1.3486314501081194, 5.843600903238569, 15.263073103768484, 12.58903889996665, 30.035318510872976, 32.49337577819824, 44.171789850507466, 24.9627548626491, 8.715551938329424, 2.3150535694190433, 0.0057530202237623075, 0.07591751058186803, 0.031127851655972854, 0.021218120818957686, 0.015711815927975943, 0.06480462689484869, 0.049318021828574796, 0.03379988184730921, 0.011646134180149861, 0.03124277513208134, 0.042459851263889244, 0.07827297704560415, 0.026891760927225863, 0.03174371039494872, 0.01249464985448867, 0.012392517611650484, 0.006843180029786059, 0.030096620919981172, 0.0078449241783736, 0.03146714969937291, 0.028006627889616147, 0.00872634710477931, 0.10229283850640059, 0.017489565802471976, 0.05961391542639051, 0.05825228563376835, 0.010464595214995955, 0.020066953929407255, 0.05581518801461373, 0.042342610590692074, 0.14072137751749583, 0.20326329368565763, 0.07411616295576096, 0.11817656297768865, 0.23322288106594766, 0.13422534109226295, 0.09412449824490718, 0.13508803051497253, 0.10240278832082238, 0.15113355166145734, 0.1995284062411104, 0.09747222039316382, 0.08735877807651247, 0.18702103809586593, 0.11126350571534463, 0.15487674437463284, 0.12664875122053282, 0.16522399628801004, 0.09418452145265681, 0.0963666018630777, 0.0946292265185288, 0.1985344338629927, 0.10558913448559386, 0.12866645652268613, 0.14242621032255037, 0.09823044934975249, 0.1514828207769564, 0.12286426286612238, 0.18601832618670805, 0.1318189709314278, 0.07001219317317009, 0.17962690629065037, 0.83998618381364, 10.759826609066554, 29.251078810010636, 45.17748253686087, 50.442462648664204, 44.67906740733555, 43.23656232016427, 40.58096776689802, 27.583962781088694, 11.38299230166844, 3.9587869559015547, 0.7012038965310369, 0.3435471925352301, 1.629245089633124, 5.5969051122665405, 9.13283121585846, 14.62734419958932, 13.909621340887886, 11.128217492784772, 8.850702217647008, 6.728941670485905, 16.133133479527064, 25.321743965148926, 35.31631422042847, 43.54907839638846, 52.54395226069859, 49.378325189862935, 51.68635695321219, 47.844468661717, 48.037044933864046, 49.64045292990548, 46.338335445949006, 50.77643823623657, 52.183319909232004, 51.06553193501064, 49.63534600394112, 48.30280658176967, 43.43681287765503, 45.12672247205462, 43.43220969608852, 40.913491180964876, 42.86632061004639, 40.70928015027727, 40.94868728092739, 39.94132355281285, 40.2904566356114, 38.82212856837681, 38.13072722298758, 38.545753547123496, 41.440237590244834, 37.968507630484446, 39.394833837236675, 41.013573033469065, 47.51171943119594, 46.70763567515782, 51.23049259185791, 43.85396187646048, 42.143760068076, 51.73453228814261, 46.136844635009766, 47.98105634961809, 39.9046995980399, 41.24959291730608, 42.15167754037039, 43.95897694996425, 48.852485520499094, 50.45015777860369, 50.22576917920794, 51.94617094312395, 49.007663113730295, 50.219918795994346, 50.13031830106463, 48.83181462969099, 44.63394233158657, 42.755323137555806, 41.70327207020351, 46.02635438101632, 46.386319705418174, 47.63317741666521, 47.784196513039724, 46.56709098815918, 46.414776052747456, 50.4353928565979, 48.46219825744629, 48.27181414195469, 46.8147143636431, 52.62000376837594, 53.70959595271519, 49.24917554855347, 45.264088358197895, 37.779381138937815, 27.56829980441502, 13.996468612125941, 6.533852321760995, 3.493975268942969, 9.540839859417506, 13.196649312973022, 25.41433218547276, 16.406750065939768, 5.925724267959595, 9.933111701692853, 5.681976250239781, 2.216248882668359, 0.5471113079360553, 2.5251069494656155, 8.074625781604222, 22.731962748936244, 17.116289683750697, 36.030418804713655, 37.2999450138637, 50.09184265136719, 31.793984004429408, 9.318588699613299, 2.587605344397681, 0.1731696142149823, 0.21461209042796067, 0.1116107731525387, 0.12224196482981954, 0.12238001956471375, 0.20892568198697908, 0.15326807355242117, 0.09638767037540674, 0.0835723966094, 0.09351131293390479, 0.08699511723326785, 0.16377476762448037, 0.11379199182348591, 0.08902278342949492, 0.15115723253360816, 0.06824942704822336, 0.18546732861016477, 0.1407445427030325, 0.09512864186295442, 0.12884254993072577, 0.12385659318949495, 0.15556655664529118, 0.1303927038929292, 0.14593419565686158, 0.18591494459126676, 0.1722320280969143, 0.1483328848012856, 0.19852682070008346, 0.11847969171191965], [0.052260007177080424, 0.060809473773198466, 0.01920048167396869, 0.017755007005429695, 0.0120086058907743, 0.027187295158260634, 0.11552525524582181, 0.009992777586116322, 0.025015942386484573, 0.02467445606764938, 0.033445584787321944, 0.031086569585438286, 0.024075326609558294, 0.051184345968067646, 0.006917878253651517, 0.09500047338328191, 0.029476389022810117, 0.022125413741118143, 0.02940822678751179, 0.012614023672150714, 0.04637451995430248, 0.013870386390148528, 0.05608592687972954, 0.019807719625532627, 0.032580754586628506, 0.03845829955701317, 0.012533775880001485, 0.021241128245102506, 0.003463030480946015, 0.04518238142398851, 0.03286904376000166, 0.007806625117414764, 0.049963919312826226, 0.02899647138214537, 2.8581599465438297, 10.799349699701581, 24.836563416889735, 46.94021620069231, 30.72052206311907, 28.570999554225377, 31.00655508041382, 24.49630492074149, 11.52993106842041, 4.026143227304731, 0.44368186220526695, 0.4088091791740486, 0.5967068980847086, 1.1478984270777022, 3.3287030288151334, 6.956877759524754, 4.478905652250562, 3.2312282707009996, 4.784822242600577, 3.8068415778023854, 10.199348432677132, 18.122083118983678, 28.08944422858102, 34.928448404584614, 41.29551703589303, 42.69275113514492, 47.00866985321045, 48.66780240195138, 47.40984146935599, 45.36088718686785, 47.108411243983674, 45.839652810777935, 49.87755673272269, 48.981423241751536, 49.559416089739116, 45.6625988142831, 47.388760634831016, 42.03763675689697, 40.7850467818124, 37.80645479474749, 36.421088218688965, 36.96764741625105, 37.79803357805525, 39.69969994681222, 40.541686126164024, 38.33228751591274, 37.356117725372314, 35.222336360386436, 36.2134621483939, 33.98060294560024, 38.41511699131557, 37.26587799617222, 43.94767223085676, 43.8414238521031, 49.83108370644705, 38.14672892434256, 35.544916902269634, 52.02652338572911, 43.73503303527832, 44.34472703933716, 36.294353076389854, 35.54936374936785, 38.45580564226423, 44.04099696023123, 46.18143122536795, 47.7696122441973, 46.27329683303833, 47.8744466645377, 46.82220799582345, 47.16567134857178, 45.7492220061166, 45.617977482931956, 42.40405695778983, 40.4822929246085, 38.89056485039847, 41.05295194898333, 45.077317305973594, 44.90983097893851, 45.96428959710257, 44.25925030027117, 45.09509079796927, 46.63710103716169, 43.78643233435494, 45.49870818001883, 42.437422207423616, 47.19517339978899, 46.749634061540874, 47.12572268077305, 41.44147784369332, 32.4188563483102, 17.953917605536326, 13.259232606206622, 3.219147741794586, 2.9530554030622755, 4.8082081420081, 2.742022978407996, 5.79036510842187, 7.389064397130694, 4.412929901054927, 3.6937526975359236, 0.9588498856340135, 0.18159041021551403, 0.22077313411448682, 1.3298929184675217, 8.040040254592896, 19.663473231451853, 24.411592483520508, 23.662349121911184, 36.578339849199565, 31.201240130833217, 15.499699217932564, 3.3660493791103363, 0.8404041613851274, 0.0488781377540103, 0.07164269925228187, 0.028225419810041785, 0.018762651864173155, 0.00787271442823112, 0.051398749463260174, 0.07720610286508288, 0.0542683961934277, 0.04354910013665046, 0.009075770586995142, 0.06464644002595119, 0.0355482121397342, 0.003439268820719527, 0.04529304709285498, 0.048470005725643465, 0.038431975790964704, 0.047928307471530776, 0.04031917506030627, 0.03932410006278327, 0.05931766025189843, 0.03794843138062528, 0.010927850580109017, 0.14304451857294354, 0.052632163278758526, 0.0869937330218298, 0.05178737021716578, 0.03348789483840976, 0.016739533548908572, 0.013830396928824484, 0.005572252981697342, 0.0277389950185482, 0.02884824201464653, 0.025676075535427247, 0.03739560175953167, 0.021306598392714347, 0.019807348127609918, 0.022269200400582383, 0.005280792081196393, 0.03339138001735721, 0.016353793176157132, 0.05192610348707863, 0.02279140773628439, 0.0408151671955628, 0.0727048304730228, 0.04310368600168398, 0.05920431776238339, 0.012896239957106965, 0.021438290165471177, 0.03656510543078184, 0.016341080822582756, 0.04222084069624543, 0.03372543298506311, 0.018574675611619438, 0.023918308517230407, 0.06353065704128572, 0.01612349330181522, 0.03955509713185685, 0.011871500256737428, 0.03421889079202499, 0.05695090296545199, 0.008555196824350526, 0.032758177923304696, 0.04949973350656884, 4.031095990112849, 16.10129509653364, 32.077533040727886, 50.38570628847395, 36.74587133952549, 31.971833569662913, 34.25028337751116, 27.91988386426653, 12.875901358468191, 5.125115045479365, 0.6821509589041982, 0.11368029138871602, 0.24547152380858148, 1.1350480594805308, 3.9475656151771545, 5.110760935715266, 8.250214576721191, 6.3776563831738065, 4.142444346632276, 6.832152817930494, 12.854082277842931, 19.285447801862443, 29.586214746747697, 37.96563802446638, 43.63783121109009, 44.993859018598286, 46.41330303464617, 50.00912782124111, 48.02083478655134, 45.80994231360299, 46.2422696522304, 46.86603375843593, 49.87438835416521, 50.75809151785714, 51.103066103799, 47.10602453776768, 49.272789001464844, 44.407458850315635, 43.191096782684326, 40.17464753559658, 38.0912058694022, 38.63519075938633, 39.73646286555699, 42.385713713509695, 41.40132072993687, 40.91598211015974, 37.68222795213972, 35.793092659541536, 37.104641573769705, 36.854565484183176, 38.68952219826834, 38.3731290272304, 45.341154302869526, 46.22607340131487, 50.998752798352925, 41.3554139818464, 39.44947794505528, 53.49885014125279, 45.10422420501709, 47.35434620720999, 37.49481419154576, 37.75516319274902, 40.34907511302403, 45.72240195955549, 48.547501291547505, 49.69762965611049, 48.07993616376604, 48.29591744286673, 48.83493437085833, 49.34517533438546, 47.20007535389492, 47.513671875, 45.371990408216206, 42.675634247916086, 41.03979206085205, 42.528895241873606, 46.22791467394148, 47.505855151585166, 46.623691013881135, 44.97251762662615, 46.16893836430141, 48.7018381527492, 45.13346222468785, 47.02122177396502, 45.14741768155779, 49.62367303030831, 48.299652099609375, 49.357383319309776, 41.77376501900809, 32.201992647988455, 20.108390705926077, 14.771858045033046, 5.360191711357661, 4.5316906826836725, 6.7240622980254035, 7.647691982133048, 8.855529478618077, 6.860228751386915, 5.02167330469404, 3.840820005961827, 1.6210919214146478, 0.24288321126784596, 0.4274443563606058, 1.2042940237692423, 7.828561408179147, 18.247011729649135, 20.521342992782593, 27.38828066417149, 37.49335854394095, 37.46332148143223, 18.783348390034266, 4.54774102142879, 0.9086366114871842, 0.06000994239002466, 0.05019489602584924, 0.05265001214242407, 0.03056177024596504, 0.02303570069904838, 0.018868494845394577, 0.044218234052615504, 0.03389350271650723, 0.030656073042856793, 0.02265804846371923, 0.01882534341088363, 0.020504688744300177, 0.08421779197773763, 0.019837610789441636, 0.07922528737357684, 0.016500029347038696, 0.03988840031836714, 0.03055781438680632, 0.04425072570198348, 0.07183869409241847, 0.018690681351082664, 0.006687114006906215, 0.11052276260618653, 0.03936144323753459, 0.026939385603847246, 0.06134631710925272, 0.04905680620244571, 0.03292681762416448, 0.03741762700623699, 0.12611699689711842, 0.10810514233474221, 0.11517807601818017, 0.13292378879019193, 0.1119916212878057, 0.11127871847046272, 0.19628895792577947, 0.11998173754130091, 0.09733649303338357, 0.12557648947196348, 0.1667905165148633, 0.10637668972568852, 0.07666026215468134, 0.11791895037250859, 0.11351640482566186, 0.15785372177405016, 0.15817662301872457, 0.1265344452112913, 0.12131419032812119, 0.09610504018408911, 0.10542036247040544, 0.16440838362489427, 0.18782295792230538, 0.09386466683021613, 0.08329180202313832, 0.10150642999048744, 0.09868903724210602, 0.09490304932530437, 0.10042238887399435, 0.0995491821584957, 0.10825182803507362, 0.0651367630011269, 0.1255693377128669, 0.18446135973291738, 4.627227544784546, 18.19147651536124, 38.30020420891898, 58.65962464468819, 41.118497780391145, 40.32152550561087, 41.60755368641445, 34.28101178577968, 17.006527253559657, 6.130945827279772, 1.0930594440017427, 0.7937477135232517, 1.0055839036192213, 3.9382737023489813, 8.756775600569588, 12.380020584378924, 13.657367859567914, 8.609486818313599, 10.183662005833217, 6.522496359688895, 13.235045058386666, 20.532974277223857, 29.910528864179337, 38.50823327473232, 45.2813720021929, 46.22414527620588, 47.023921149117605, 50.970154012952534, 51.93210778917585, 44.97139549255371, 47.660157271793906, 45.921777044023784, 50.04901742935181, 52.30628565379551, 52.7579984664917, 50.4760537147522, 52.76563801084246, 45.19850778579712, 45.703308309827534, 42.15287263052804, 39.46342992782593, 40.212709767477854, 41.717585359300884, 44.05546658379691, 43.2329284123012, 42.20297261646816, 39.51353338786534, 38.187824044908794, 39.86881562641689, 37.54690831048148, 40.80906670434134, 40.340660844530376, 46.04330103737967, 48.12888969693865, 52.058137689317974, 43.82182993207659, 42.30975948061262, 54.571790967668804, 48.527487005506245, 48.65032073429653, 39.02717685699463, 39.59209666933332, 42.13464750562395, 47.43707840783255, 51.23332050868443, 50.87811817441668, 49.86235407420567, 50.28377621514456, 51.155987058367046, 51.06807497569493, 48.14755603245327, 49.092083726610454, 47.04063156672886, 44.224936621529714, 42.20551913125174, 45.59089340482439, 49.29290056228638, 49.63188232694353, 47.59361784798758, 43.8059845651899, 46.583526951926096, 49.35236324582781, 46.212135314941406, 49.89837006160191, 45.14232465199062, 52.73433985028948, 50.10385608673096, 52.6238773890904, 42.431564876011436, 34.58446741104126, 19.74546718597412, 18.32929403441293, 5.961458419050489, 6.398183533123561, 9.13920531954084, 11.047726954732623, 15.574428830827985, 13.59300148487091, 12.70408456666129, 6.100358554295131, 4.693434323583331, 0.6741587391921452, 0.7939461171627045, 2.1001811793872287, 11.868678331375122, 26.159298930849346, 35.67292703901018, 33.99223075594221, 47.78419998713902, 42.77034861700875, 23.84589794703892, 5.906893781253269, 1.2433228152138847, 0.12594638605202946, 0.18430368176528386, 0.09845007077923842, 0.08721767671938453, 0.07678084461284534, 0.14759455727679388, 0.16557224760098116, 0.09478386464927878, 0.13794846273958683, 0.0781020133623055, 0.1093343695891755, 0.12226846840764795, 0.16524313097553595, 0.08903575701905148, 0.17536688702447073, 0.10691821495337145, 0.14119499496051244, 0.10662514889346701, 0.11010425577738456, 0.16583877615630627, 0.2227782186652933, 0.06635926597352539, 0.20077791490725108, 0.16103402897715569, 0.1757241085703884, 0.14844377099403314, 0.13670556300452777, 0.15527440660766192, 0.1543534988803523], [0.016748666630259583, 0.06182931869157723, 0.10399142200393335, 0.006402601729080613, 0.0415879948330777, 0.039853343806628666, 0.04015503743929522, 0.011869913332962563, 0.04228353054661836, 0.026129920468000428, 0.07228529905634266, 0.037209048734179566, 0.05355974439797657, 0.047848158915128024, 0.004982643794002277, 0.052328199946454594, 0.026683084267590727, 0.03647569487137454, 0.05757594906858035, 0.07220485194453172, 0.02420204132795334, 0.01968314398878387, 0.03362340845965913, 0.036863050157470365, 0.005843225517310202, 0.039952155468719344, 0.02220591513573059, 0.009853314042889645, 0.05690906110352703, 0.0056920907476783866, 0.030831749151859964, 0.04602545439930899, 0.11831809181187834, 0.10105149940188442, 0.8239431732467243, 7.71168315410614, 24.58827648844038, 40.51974718911307, 39.97182614462716, 35.84591633932931, 34.196556431906565, 27.960555144718715, 15.331455537251063, 6.110635374273572, 2.502954138176782, 0.12549497027482304, 0.27091427998883383, 0.546328495655741, 4.652271023818424, 3.534562519618443, 4.872697412967682, 3.993279985019139, 0.7257405370473862, 3.1279142030647824, 6.919704028538295, 10.478638223239354, 20.52139163017273, 23.687241043363297, 31.464545590536936, 37.48700789042881, 47.43794693265642, 41.41226066861834, 42.490707942417686, 47.47684294836861, 49.40932805197579, 48.42118304116385, 47.237949984414236, 46.25506475993565, 48.57599932806832, 46.741119044167654, 47.48752580370222, 47.17984914779663, 45.19457163129534, 41.70314005443028, 39.961782523563926, 38.38937391553606, 40.40052652359009, 40.67756162370954, 41.59665543692452, 40.13451821463448, 40.32559714998518, 36.75889573778425, 36.51948513303484, 35.46497440338135, 42.23218631744385, 43.90001106262207, 46.73659924098423, 44.28210987363543, 53.28667994907924, 42.636734758104595, 32.7970745904105, 54.13818168640137, 42.91297428948538, 45.211306367601665, 35.799429416656494, 35.133944852011545, 36.436565331050325, 40.06189564296177, 43.54930421284267, 44.932193756103516, 44.23198209490095, 44.445698261260986, 44.292372362954275, 45.01150049482073, 42.57163708550589, 42.61606386729649, 40.9442195892334, 41.246938705444336, 40.29951013837542, 41.87055689947945, 44.73879064832415, 45.89881672177996, 47.086409773145405, 44.92008304595947, 45.90320450919015, 46.23500531060355, 47.44359234401158, 46.00294937406267, 44.7881749698094, 45.49471296582903, 49.02051380702427, 43.54260614940098, 37.02598449162075, 28.647818837847026, 16.0583986554827, 16.621619633265905, 15.537985529218401, 3.480570239680154, 2.315402933529445, 10.24452040876661, 6.466823484216418, 6.553928707327161, 3.8848824415888106, 2.0225437453814914, 0.7768190247671944, 0.5554183678967612, 0.5402244489107813, 2.9243708508355275, 9.480473910059247, 16.753779581614904, 22.70789245196751, 28.099017109189713, 30.845290865216935, 29.181291103363037, 12.003965837614876, 0.8320327763046537, 0.149616184511355, 0.032732447875397544, 0.0664293925677027, 0.08148223055260521, 0.043335388747176955, 0.02233388684024768, 0.06821341719478369, 0.07464680448174477, 0.08090563184980835, 0.03708160289430192, 0.03163494462413447, 0.0784710617735982, 0.04613467139591064, 0.07608810785625662, 0.055849172441022735, 0.040591878284301074, 0.03269365602838142, 0.05552284120182906, 0.05465999910874026, 0.020208033234147087, 0.02506317012012005, 0.0160704895388335, 0.03337905442874346, 0.05658810046900596, 0.01820834812575153, 0.022726853610947728, 0.00894517804096852, 0.029002344102731774, 0.008465692118209387, 0.02401597854415221, 0.010444208630360663, 0.044085295471761904, 0.07836120695407901, 0.017782954166510274, 0.026014058917228664, 0.029798984926726137, 0.038475320607955964, 0.0690739895882351, 0.0768745502989207, 0.05814192869833537, 0.031099566923720495, 0.05079317392249193, 0.008726094350484865, 0.023526620785040513, 0.07373849714973144, 0.03980736627376505, 0.026878275043730224, 0.06360327385898147, 0.039463444014212916, 0.004113992592985076, 0.026930630805769136, 0.03823828796989151, 0.011304925212503543, 0.028666353917547634, 0.06451393570750952, 0.04269591020420194, 0.041164823076022525, 0.01583283095221434, 0.044868192568953545, 0.009950589671331857, 0.022011803230270743, 0.03335153304838708, 0.03147811821794935, 0.08271625504962035, 1.6199504626648766, 9.628711121422903, 28.110453844070435, 47.11384473528181, 41.79380709784371, 37.397372654506135, 38.360504150390625, 29.041555881500244, 17.597574029650005, 6.829101690224238, 2.4947235626833777, 0.12585945214544023, 0.12329501046666078, 0.9239802424396787, 2.8712540439196994, 5.024807376520974, 6.202133595943451, 4.5836992519242425, 2.9402303312505995, 3.7745967251913886, 7.820868015289307, 14.266103880746023, 21.824015583310807, 29.91005986077445, 34.15955032621111, 40.53514787128994, 49.7581901550293, 46.1242162840707, 47.229664257594514, 49.71651833398001, 48.2003310748509, 47.84143577303205, 49.214743750435964, 48.001636913844514, 52.17672954286848, 49.214684690747944, 50.77189411435808, 48.41597189222063, 47.49678775242397, 43.26841286250523, 40.66508960723877, 40.66523551940918, 42.18945142201015, 42.34364931924002, 44.032544476645334, 41.13845648084368, 43.00721965517317, 38.65962757383074, 39.17696612221854, 37.17173685346331, 42.236306599208284, 44.94667032786778, 48.84329652786255, 46.08428498676845, 52.59209632873535, 41.08558068956648, 36.67963416235787, 55.38034936359951, 45.26642295292446, 47.825392382485525, 37.579835823604036, 37.778189522879465, 39.37292964117867, 41.94414874485561, 44.7561229297093, 46.152717794690815, 46.317574228559224, 46.8626708303179, 46.65828609466553, 46.330873080662315, 43.77228232792446, 44.60161236354283, 42.3887848172869, 43.06608826773507, 42.32928391865322, 43.77190712520054, 46.37747117451259, 48.44146135875157, 47.662446703229634, 46.052642890385215, 45.726727213178364, 48.42924989972796, 49.53527109963553, 47.9032747404916, 46.885269846235005, 47.953607491084504, 48.7617107800075, 45.158545221601216, 40.36420828955514, 30.01915352685111, 18.830408539090836, 17.077259915215627, 12.432136416435242, 4.880210586956569, 4.34147549527032, 3.6027949154376984, 4.369726002216339, 3.998314389160701, 3.754816940852574, 1.4797621965408325, 0.6687817020075661, 0.2620355949870178, 0.664691330066749, 2.9110442059380666, 11.59678750378745, 18.173211438315256, 25.340983527047293, 30.75602388381958, 39.44955090114048, 33.11559738431658, 14.379937086786542, 1.533865864787783, 0.2991740150111062, 0.04829365447429674, 0.04762919566461018, 0.030107423197478056, 0.03978051325040204, 0.015700255387595723, 0.06522362226886408, 0.10705715178378991, 0.009603111040113228, 0.05262238219646471, 0.04256461707076856, 0.04857575540829982, 0.031673454879117866, 0.06908274268997566, 0.009556455820399736, 0.07591675062264715, 0.029899000988474915, 0.0419844492737736, 0.019041897862085273, 0.025527257538799728, 0.03805132443085313, 0.053092983551323414, 0.09432056093854563, 0.03886022977530956, 0.0321370605379343, 0.020088392243321453, 0.053945712079959254, 0.03165803856349417, 0.03004443139902183, 0.028180784080177546, 0.06614581242735897, 0.09624502874378647, 0.1906408460012504, 0.08619705148573432, 0.09498975252998726, 0.19689913732664927, 0.09775177003549677, 0.14733803032764367, 0.12142348874892507, 0.13868783520800726, 0.18665817113859312, 0.1475996327187334, 0.15329461784235068, 0.09250901493110827, 0.17068946015621933, 0.16194216667541436, 0.13576024158724717, 0.18514107540249825, 0.17871224108551229, 0.12022480235568114, 0.07496669981628656, 0.12556029962641851, 0.0612449711188674, 0.09864494603659425, 0.15639260517699377, 0.20768831909767219, 0.10565244180283376, 0.12256232835352421, 0.24038658237883023, 0.10005439897733075, 0.17864816023835114, 0.09533028889979635, 0.1279812040073531, 0.13721382644559654, 1.7528452915804726, 11.46811294555664, 33.277010985783164, 53.92014026641846, 49.53745630809239, 47.39666421072823, 44.90805918829781, 37.91869599478585, 21.778647320611135, 9.644684161458697, 3.4711350202560425, 0.6072693541646004, 0.6196456157735416, 1.284688264131546, 9.09854359286172, 11.135585188865662, 11.603097336632864, 8.58034086227417, 2.800131631749017, 5.703938637460981, 10.146988545145307, 15.04422048160008, 26.82137714113508, 31.502559185028076, 37.67196546282087, 42.03648683003017, 50.90517445972988, 48.19331339427403, 47.56819091524397, 48.876178877694265, 48.38901635578701, 47.66037614004952, 48.08731862476894, 47.49634306771414, 52.031592096601216, 50.66102170944214, 51.9974764415196, 51.60778324944632, 50.14929730551583, 44.83869532176426, 43.30057259968349, 42.729184014456614, 44.86667224339077, 45.88497243608747, 46.15797758102417, 42.80722270693098, 45.20504951477051, 39.880936758858816, 39.05715833391462, 39.07505341938564, 44.679182052612305, 47.54429606028965, 49.56391504832676, 47.95379509244646, 54.75775950295584, 43.85550785064697, 39.775570801326204, 55.127042361668174, 47.12513555799212, 49.41338579995291, 39.357018266405376, 39.6936411176409, 41.12145076479231, 44.37940549850464, 46.03308718545096, 48.40615061351231, 48.53310809816633, 47.947135244097026, 47.94514805930001, 48.210788113730295, 45.810230663844514, 46.46705777304513, 44.24667753492083, 45.41805001667568, 43.917412825993125, 46.80141551154, 49.18401186806815, 49.58819900240217, 48.81567049026489, 45.239637647356304, 46.25228548049927, 49.608216762542725, 50.75708402906145, 50.07303735188076, 47.994084221976145, 50.02699163981846, 50.862654958452495, 48.45093175343105, 42.81746435165405, 34.25497341156006, 25.060034854071482, 22.755487612315587, 19.841291529791697, 7.896891730172293, 8.160013931138174, 19.320289543696813, 14.637224537985665, 16.472900390625, 11.908791150365557, 7.879049624715533, 2.3890262629304613, 0.8855406908052308, 1.308248085635049, 4.027978420257568, 14.38507788521903, 25.38445840563093, 36.38221304757254, 41.150671413966585, 47.754347051892964, 38.5984764780317, 16.4826226575034, 2.1564049167292456, 0.33252444544008797, 0.22536350493984564, 0.1556987352669239, 0.25437526032328606, 0.13900813087821007, 0.154816422611475, 0.14864435951624597, 0.1867143674088376, 0.2055416242884738, 0.12149065014507089, 0.1489032477672611, 0.17134268581867218, 0.1536776101482766, 0.1280102181647505, 0.09194227534213237, 0.22912439384630748, 0.09671856476260082, 0.08695792672889573, 0.18663096188434533, 0.12833119236997195, 0.22458069265953132, 0.25847163051366806, 0.20297397992440633, 0.13499910171542848, 0.15904942261321203, 0.08361570749964033, 0.10941069799342326, 0.15794208060417855, 0.09524934645742178, 0.10723233595490456], [0.058663097875458856, 0.033210526686161757, 0.009624186337792447, 0.02513416693545878, 0.049332535692623684, 0.03353102930954524, 0.0054870425540554735, 0.017449248948001435, 0.023336810791598897, 0.04047580808401108, 0.026479883385556083, 0.03672243056020566, 0.027520829046677266, 0.057093788869678974, 0.11413807182439736, 0.024156794916572313, 0.06069235184362956, 0.050147456250020435, 0.022094698157161474, 0.01938296857822154, 0.02965250617957541, 0.02466127722124968, 0.018638047389686108, 0.06623221029128347, 0.00584849900665826, 0.029957392319504703, 0.03252349301640477, 0.0998215868270823, 0.09952109759407383, 0.05115864645423634, 0.031249553696917634, 0.01852335631182151, 0.06578869266169411, 0.020292492184255804, 0.11437304850135531, 2.7887051020349776, 17.36647173336574, 35.68486751828875, 44.42010804585048, 37.11472340992519, 31.43077734538487, 36.69969013759068, 19.490820918764385, 14.412543245724269, 3.9463905010904585, 0.6410541555711201, 0.2361507596714156, 1.3955888961042677, 2.1818107877458846, 2.402145113263811, 6.794272541999817, 3.9441201772008623, 3.1841713786125183, 2.8872322951044356, 2.413556660924639, 4.189722061157227, 10.061386738504682, 18.042696475982666, 26.91618357385908, 34.08157416752407, 37.85939311981201, 46.9326947757176, 41.646574769701274, 47.05323559897286, 50.34821033477783, 46.60527828761509, 48.63379444394793, 47.712209701538086, 49.518157686506, 46.72987685884748, 48.8242688860212, 46.51471546718052, 48.29145669937134, 44.39851999282837, 41.97782666342599, 39.114991664886475, 41.71775906426566, 39.82416650227138, 42.41174513953072, 40.56779745646885, 41.14288943154471, 38.45665679659162, 38.00455488477434, 37.33855267933437, 49.001110962459016, 45.328675338200156, 50.015676498413086, 45.74672065462385, 56.726368291037424, 53.62759678704398, 30.42079414640154, 54.06858852931431, 42.769195216042654, 47.701815196446006, 38.424681186676025, 36.171832016536165, 35.83615412030901, 38.32127462114607, 38.27589593614851, 42.782674721309114, 38.14104529789516, 40.358350958142964, 39.90643664768764, 40.07907158987862, 39.56220899309431, 40.6045742716108, 39.78682688304356, 42.05073758534023, 42.73048332759312, 44.569181646619526, 44.80662938526699, 48.17391402380807, 46.64700222015381, 44.10912752151489, 46.27504083088466, 48.065747942243306, 47.54851361683437, 47.31785079411098, 45.30301911490304, 45.344426904405864, 42.70324638911656, 37.83623129980904, 29.976001739501953, 19.10570658956255, 8.187439339501516, 10.459908485412598, 28.46417621203831, 19.00862114770072, 9.087992753301348, 1.7642422914505005, 3.839041267122541, 1.4055702005113875, 1.297153115272522, 1.3435784812484468, 0.5860373963202749, 0.5218074885862214, 1.311520795736994, 4.6255799531936646, 14.026008878435407, 17.073064940316335, 30.115799495152064, 35.56625829424177, 31.48791238239833, 20.157175745282853, 6.237575488431113, 0.21041526991341794, 0.04863672177972538, 0.07775452200855527, 0.07873810601553746, 0.05864679267896073, 0.04377624312681811, 0.023590311474565948, 0.028487956883119683, 0.020251574826293757, 0.03820933148797069, 0.036732004689318795, 0.10168977693787642, 0.03215574399967279, 0.04284125240519643, 0.050746846944093704, 0.05428674038765686, 0.009499535214022865, 0.04742111611579146, 0.017827774797167097, 0.050309029008660994, 0.07988956637148346, 0.07962222357413598, 0.10879965006772961, 0.05696009032960449, 0.012964036631663995, 0.010121494830985154, 0.023664344734113132, 0.030070012169224874, 0.07991908264479466, 0.04618418070354632, 0.036064757100705586, 0.04341370186635426, 0.059494405053555965, 0.06332109828612634, 0.015108930778556635, 0.04286490274327142, 0.03252500954217144, 0.02911648726356881, 0.013147296217669333, 0.07043539546430111, 0.029315179280404533, 0.022985229568023766, 0.019098852395213077, 0.07794755843601056, 0.04590976757130452, 0.05938672833144665, 0.01651489096028464, 0.04675107974825161, 0.0461403134145907, 0.013905710075050592, 0.03841052729902523, 0.031397908593394926, 0.04800346540287137, 0.030638319174093858, 0.061443361187619824, 0.024147387028538754, 0.09216942172497511, 0.03629347089944141, 0.07659681913043771, 0.07902590664369719, 0.08312260931623833, 0.04931497520634106, 0.01423239754512906, 0.05396573564835957, 0.08739718315856797, 0.25717248022556305, 4.568182621683393, 22.676109654562815, 41.59814929962158, 48.88111209869385, 41.72959879466465, 36.16159732001168, 39.34853104182652, 22.241162845066615, 12.846881338528224, 5.273433463914054, 0.4248856008052826, 0.2971477194556168, 0.2490446620753833, 2.50858804157802, 4.344176607472556, 6.026730665138789, 6.59456307547433, 5.406714243548257, 5.259564859526498, 4.813878740583148, 6.714812074388776, 13.765427112579346, 21.594064950942993, 29.820323875972203, 36.85271378925869, 42.52597352436611, 47.9400862966265, 44.61851038251604, 49.59022440229143, 50.466027464185444, 48.73646797452654, 48.92246082850865, 47.69760806219918, 49.97973346710205, 50.25296095439366, 49.86179821831839, 49.471830572400776, 49.93649482727051, 46.727563108716694, 44.605444295065745, 42.40036399023873, 42.67732613427298, 41.57760695048741, 45.34563936505999, 42.95995453425816, 42.71109437942505, 41.00899764469692, 39.91105719975063, 39.81593288694109, 49.25162131445748, 47.36242348807198, 51.64034250804356, 48.699503558022634, 55.44613490785871, 51.743627480098176, 34.33282102857317, 54.93528250285557, 45.340716566358296, 49.48085280827114, 40.37386975969587, 37.50516700744629, 37.176218441554475, 39.759433610098704, 40.53475182397025, 43.71461575371878, 41.397818837847026, 42.90312869208199, 42.04040213993618, 42.368899072919575, 41.07813916887556, 41.22536107472011, 42.33341809681484, 43.06974302019392, 44.67804602214268, 46.02644123349871, 47.735687664576936, 51.123170716421946, 47.86944048745291, 45.09284652982439, 46.89905159814017, 49.288620471954346, 47.9825119972229, 48.765876225062776, 46.39923988069807, 47.49361937386649, 44.341610772269114, 40.91126080921718, 33.29922437667847, 23.979796682085308, 11.835143719400678, 15.852940423148018, 27.384403569357737, 14.907509463174001, 6.079245584351676, 2.483927147729056, 2.143560520240239, 1.79863326890128, 1.2958124386412757, 1.0415922914232527, 0.3227543282721724, 0.36028939272676197, 1.10199493595532, 5.522731355258396, 14.184294922011238, 19.545230524880544, 31.27003424508231, 41.901076861790244, 37.3841814994812, 24.877352816717966, 8.240827560424805, 0.7758572963731629, 0.04494277713820338, 0.06327937516782965, 0.021582662061389004, 0.03953662062329905, 0.014312055859980839, 0.019711985119751523, 0.05502788383247597, 0.040048972237855196, 0.04554780985095671, 0.053878082494650564, 0.03284882341644593, 0.05195753322914243, 0.04099416473348226, 0.09991598461887666, 0.10136646178684064, 0.03870298946276307, 0.014046143923353935, 0.07144542876631021, 0.04768141571964536, 0.04693466418289712, 0.04880581609904766, 0.0687545013747045, 0.04964873640398894, 0.036111392812537293, 0.022701125259378126, 0.06082826919321503, 0.03964242119608181, 0.04391760571992823, 0.057965360315782685, 0.0003430165478286134, 0.12840830108949117, 0.14200941340199538, 0.17636642338974134, 0.14109978292669567, 0.10471635524715696, 0.10937521739729814, 0.15400557326419012, 0.17554253259939806, 0.11216120754501649, 0.10463503282517195, 0.11116531491279602, 0.14701568548168453, 0.21312780864536762, 0.10038680649761643, 0.1894641848547118, 0.1272330241543906, 0.1710143970059497, 0.15328904028449739, 0.09472676592745952, 0.13886622206440993, 0.2163726445287466, 0.20353093503841332, 0.1715258224202054, 0.21727281622588634, 0.1030569232202002, 0.16311988633658203, 0.1353081472750221, 0.11500328539737634, 0.20259332177894457, 0.20450429352266447, 0.08863158763519355, 0.0755656019651464, 0.14530349735702786, 0.14646787701972894, 0.4541823816086565, 5.089739160878318, 25.094325951167516, 46.95925426483154, 54.798399516514365, 48.59639923913138, 42.14118576049805, 47.23677921295166, 29.788907596043178, 17.639801706586564, 5.944745830127171, 1.1362947182995933, 0.542514260326113, 2.230970812695367, 4.3607154914311, 6.193556044782911, 15.377822603498187, 12.679344637053353, 8.854053854942322, 6.18588045665196, 4.409979522228241, 6.013723637376513, 12.35562024797712, 23.026515994753154, 30.04151282991682, 40.57742765971592, 44.77354901177542, 48.34477717535836, 45.02108900887625, 49.96793195179531, 51.210252489362446, 48.909151554107666, 47.65104818344116, 49.290232454027446, 49.82606363296509, 51.015629972730366, 51.872547830854145, 50.81690454483032, 51.88701050622122, 48.68940087727138, 45.72961071559361, 44.3858916418893, 44.8657238142831, 43.100447109767366, 45.800645623888286, 45.03574970790318, 44.845462867191856, 42.75537524904524, 40.99554245812552, 41.30333375930786, 52.21449647630964, 49.66877726146153, 52.22765289034162, 49.33666379111153, 54.62011568886893, 54.06161601202828, 37.46178592954363, 55.45250293186733, 46.43455062593733, 52.29287910461426, 42.03974553516933, 39.88682188306536, 39.66939537865775, 41.406719480242046, 41.342782156808035, 45.32991559164864, 42.187095982687815, 44.20851455415998, 43.01423733575003, 44.90623181206839, 42.96060071672712, 41.619667870657786, 42.63025208881923, 45.17106587546212, 45.25603539603097, 47.34278440475464, 49.757252148219514, 52.50178711754935, 47.89783082689558, 42.41316604614258, 45.51897954940796, 50.03523915154593, 49.15720224380493, 49.84230157307216, 48.1824950490679, 49.59327118737357, 47.243994917188374, 43.49501098905291, 34.51565940039498, 24.333392245428904, 12.294068762234279, 14.203743798392159, 32.78456088474819, 26.281229393822805, 18.56275350706918, 12.295394131115504, 11.317014813423157, 8.732650586536952, 5.1203950473240445, 4.853474353040967, 1.988239186150687, 0.8933904181633676, 1.8960027183805193, 7.219436287879944, 19.844452960150583, 25.83586723463876, 42.0674341065543, 48.39658989225115, 47.04479701178414, 28.393007550920757, 9.428190452711922, 1.3015425311667579, 0.12349473046404974, 0.12863195980233805, 0.09622598226581301, 0.11152866362993206, 0.2087302774723087, 0.11163772456347942, 0.1099966469087771, 0.06991052827132599, 0.11548845150641032, 0.11874814730669771, 0.220205051026174, 0.12776510417461395, 0.12477893941104412, 0.15811539201864175, 0.22756666743329593, 0.14282632885234697, 0.08964516967535019, 0.10054172282772404, 0.11812720634043217, 0.2641424462199211, 0.14277452948902333, 0.23745286837220192, 0.1394814226244177, 0.1703165101685694, 0.06948061526886054, 0.10836000008774654, 0.11224863678216934, 0.2478295958467892, 0.1831368322351149, 0.10088767390698195], [0.056964650084929805, 0.03172456552939756, 0.03172515246218868, 0.01660164675143148, 0.050650973338633776, 0.014381227416119404, 0.016578201670199633, 0.011922848394273646, 0.03140646152730499, 0.03240663232281804, 0.03958426056695836, 0.03246329338955028, 0.07304277483906065, 0.03142232906871608, 0.037796710950455496, 0.017072580588449324, 0.057681976950594356, 0.0036656251343499336, 0.012271120911464095, 0.01510309537739626, 0.05486451634871108, 0.002413979294942692, 0.0268008999992162, 0.040821107769651074, 0.009520344186707266, 0.06363406577812773, 0.06542902838970933, 0.027653380862570236, 0.029503879869090657, 0.04614323111517089, 0.03935525839083961, 0.033949230797588825, 0.09334505828363554, 0.01028214902284422, 0.04714229589860354, 1.1947490445205142, 9.603456156594412, 29.107652357646398, 42.60383851187569, 38.854416847229004, 32.18460478101458, 25.931599514825002, 24.92743022101266, 15.02512162072318, 6.641590220587594, 1.3716606029442378, 0.3516770734318665, 0.2316983485860484, 1.555622085928917, 4.261485227516719, 2.090439804962703, 3.692912834031241, 3.7256870525223866, 5.874609410762787, 3.1672562062740326, 3.5951395205089023, 7.230681513037, 12.263544457299368, 18.171903439930507, 27.806437151772634, 35.68066038404192, 44.29710408619472, 40.65383005142212, 45.15552622931344, 51.38044513974871, 47.71270997183663, 49.697525433131624, 48.073738370622905, 49.33305420194353, 49.83651372364589, 47.6813770702907, 49.179370471409385, 48.0409255027771, 45.73268529347011, 44.693630831582205, 44.54305989401681, 41.659095423562185, 41.445504324776785, 41.66767297472273, 41.59082242420742, 40.35604068211147, 38.861517906188965, 39.561055592128206, 40.82379688535418, 47.31798280988421, 48.2879513331822, 51.025413036346436, 47.35147312709263, 47.51214327130999, 35.464338643210276, 33.06707116535732, 52.7825916154044, 44.229953220912385, 48.38742521830967, 39.79270158495222, 38.41207020623343, 35.90062298093523, 36.628418990543906, 34.66569880076817, 38.920574120112825, 34.21265540804182, 36.49783802032471, 37.35283817563738, 39.05323607581002, 36.659383637564524, 41.3731666292463, 39.598520278930664, 42.25832544054304, 45.471238476889475, 46.978438241141184, 45.56983688899449, 47.62537111554827, 44.34061023167202, 48.19384145736694, 44.576897621154785, 44.28385387148176, 48.38809224537441, 48.615767342703684, 45.95133468082973, 47.77724136625017, 39.82257536479405, 29.276967797960552, 21.8501911844526, 12.719387105533055, 5.995272261755807, 2.111870654991695, 4.289095197405134, 5.8097323434693475, 2.980687737464905, 2.3192730801446095, 1.3782446725027901, 0.8341363434280668, 1.285863378218242, 0.1299747670335429, 0.05288312963343092, 0.38992503391844885, 2.479492025715964, 9.114150983946663, 19.047284398760112, 24.628312008721487, 29.489930084773473, 28.490026984895977, 28.55632495880127, 15.965848650251116, 3.3136071988514493, 0.06962670385837555, 0.13357880578509398, 0.013179032996829067, 0.005220384652992445, 0.0235157336906663, 0.02849995338224939, 0.06442305272711174, 0.06655754069132463, 0.047147490084171295, 0.02290375447565956, 0.028383269107767513, 0.018817669179822718, 0.03634431692106383, 0.06638672628573009, 0.03796686717708196, 0.032112877549869676, 0.022346619549872618, 0.09850279973553759, 0.028481249564460347, 0.10792248070772205, 0.02745495517072933, 0.022307598697287694, 0.025858540387291993, 0.020546769789819206, 0.03697053688977446, 0.01914549828507006, 0.008507165026717951, 0.01334790509593274, 0.06973554766071693, 0.0625041149822729, 0.01616806796352778, 0.018351077966924225, 0.09955839666404895, 0.028521378125463213, 0.05609325845060604, 0.056344346941581795, 0.029221409133502414, 0.03306202590465546, 0.055817746091634035, 0.03574288383658443, 0.02518085014474179, 0.04038506081061704, 0.05973529177052634, 0.029903207905590534, 0.022133915784901807, 0.029865315117474114, 0.03832051623612642, 0.06787302331732852, 0.05874899362346955, 0.05988463054278067, 0.03531508447070207, 0.04251865650128041, 0.05236584506928921, 0.024139253090002706, 0.015207925645102347, 0.022389363863372376, 0.04120561320866857, 0.03389202690284167, 0.009951407306029328, 0.019548688882163594, 0.0386666776612401, 0.047541077714413404, 0.09770974157644169, 0.04564962742318, 0.00773910664221538, 0.056030076662344594, 1.4507305600813456, 13.40899407863617, 36.146714278629844, 47.875436782836914, 43.72870322636196, 36.39740875789097, 33.95304638998849, 29.6341712134225, 23.940918036869594, 7.82515071119581, 1.3412817759173257, 0.09862418286502361, 0.35162509764943806, 1.4352415055036545, 2.305130890437535, 3.546299546957016, 4.015224567481449, 4.08233938898359, 7.873477169445582, 4.800538199288504, 4.155337597642626, 9.97601682799203, 15.599755014692034, 23.73287681170872, 31.45640230178833, 37.708103043692454, 46.05121503557478, 45.02920797892979, 47.57788365227835, 53.2573481287275, 46.63168144226074, 49.56875794274466, 48.18117489133562, 50.17380707604544, 50.516995974949424, 50.12067072732108, 50.02640799113682, 51.09091370446341, 47.51150403703962, 46.237200941358296, 45.192174502781455, 42.826646396092, 42.79551499230521, 43.425181593213765, 42.845590659550254, 42.20719712121146, 40.9336131640843, 40.82536717823574, 42.56080136980329, 48.48694426672799, 50.60908045087542, 51.918867996760774, 47.469866956983296, 48.607252325330464, 40.008269446236746, 35.47699131284441, 54.85744183404105, 46.517814363752095, 49.819070271083284, 42.3576534135001, 39.049734183720176, 37.48945713043213, 38.53820085525513, 37.7043788092477, 40.70998191833496, 36.593261105673655, 38.77588483265468, 38.709300245557515, 40.227064745766775, 39.669635091509136, 42.62152862548828, 40.562885080065044, 44.51243570872715, 46.373708724975586, 49.43253156117031, 47.844378335135325, 50.68777574811663, 46.51612595149449, 47.85181985582624, 47.53092425210135, 46.22461427961077, 50.148453099387034, 50.582666873931885, 47.8125764301845, 49.272344316755024, 42.621247223445344, 33.28194073268345, 25.336607898984635, 16.756286144256592, 7.511202437537057, 2.228090350117002, 6.2802969217300415, 11.508289166859218, 5.9906213113239835, 3.2767092244965688, 0.27926235060606686, 0.8261099255510739, 0.19743409433535167, 0.15665986655013903, 0.13664034221853527, 0.44137964716979433, 2.8695984184741974, 10.248815264020648, 21.174180098942347, 25.140470675059728, 35.118714400700156, 36.493102822984966, 35.51457759312221, 18.74128746986389, 4.36502901996885, 0.12746614164539746, 0.03187589580193162, 0.029516890778073242, 0.02251267233597381, 0.018467095580750277, 0.028388992550649812, 0.03986156765105469, 0.03957251173311046, 0.043368541968188117, 0.04169120679476431, 0.001988638558291963, 0.031678184268197844, 0.022070450708270073, 0.06855421819325004, 0.05487289625619139, 0.037937089667788575, 0.014321667308519994, 0.016449836415371726, 0.05031209259427019, 0.040891095264149566, 0.0021604796721866088, 0.05957670456596783, 0.039690983947366476, 0.058903489261865616, 0.029205945320427418, 0.0670101371194635, 0.02046912333129772, 0.04163571959361434, 0.04866624144571168, 0.060480126445846896, 0.04566647884036813, 0.15728703646787576, 0.10572502469377858, 0.10141188970633916, 0.1256404346121209, 0.13758657287274087, 0.064891526874687, 0.14474266102271421, 0.17595225918505872, 0.13685348363859312, 0.07139621462140765, 0.10279358377946274, 0.14659827787961277, 0.21712982175605638, 0.09470348539096968, 0.12414233785654817, 0.07893295413149254, 0.19607520582420485, 0.09531937127134629, 0.1401288400271109, 0.14801615822528089, 0.14249609942947114, 0.12975687586835452, 0.10302033661199467, 0.09342661819287709, 0.11084164692355053, 0.18773621400552137, 0.1388751244438546, 0.1063765472333346, 0.08186379793499197, 0.11534195579588413, 0.1531350535473653, 0.11798357404768467, 0.18710413149424962, 0.0552976082877389, 0.2130840974194663, 2.148248165845871, 15.299408708299909, 39.65628065381731, 55.1029703276498, 48.574297019413535, 43.323254993983674, 37.34443432944161, 33.54223067419869, 21.577351059232438, 8.649485860552106, 2.0900092337812697, 0.5587507347975458, 1.1144032244171416, 3.5774778510843004, 8.174815331186567, 9.226146391459874, 10.118607759475708, 9.355517506599426, 8.215985144887652, 5.334286221436091, 5.317524995122637, 8.913787518228803, 14.878129005432129, 23.05876432146345, 31.79119082859584, 37.65912171772548, 47.01279360907418, 46.12166976928711, 50.94755847113473, 53.53124611718314, 47.65311874662127, 50.965547357286724, 47.65763507570539, 48.44477564947945, 50.33114903313773, 48.6800868170602, 52.338632992335725, 52.27097143445696, 49.93866613933018, 48.58775915418352, 47.72729424067906, 45.68307515553066, 44.922546182359966, 45.7904873575483, 44.75393077305385, 44.82143252236502, 42.16854429244995, 42.98486382620675, 42.63491433007376, 51.29359613146101, 51.41588790076119, 54.46093593324934, 48.35601241247994, 48.52239050183977, 44.444642135075156, 37.861189229147776, 54.84711333683559, 48.20466327667236, 51.96334341594151, 43.772167682647705, 41.64465011869158, 38.83600064686367, 39.49654156821114, 38.54392269679478, 42.41311393465315, 37.564143317086355, 39.97300386428833, 39.636054447719026, 42.122387409210205, 40.4161182812282, 45.03877912248884, 43.79437065124512, 46.73814868927002, 48.351840019226074, 51.099734442574636, 49.73572662898472, 51.18078865323748, 45.93310260772705, 48.022707326071604, 47.800642899104524, 48.12447411673409, 50.45167595999581, 51.688462257385254, 49.21934345790318, 51.41036408288138, 44.78210571834019, 35.791720390319824, 25.548772880009242, 19.525184971945627, 10.19750542300088, 2.9327684002263203, 6.807232669421604, 9.384975263050624, 9.167038066046578, 8.001801712172371, 4.418336033821106, 3.305611993585314, 3.5719581586974005, 0.4527300995375429, 0.3293125049344131, 0.9190515811954225, 3.9144218393734524, 13.235904029437474, 27.81882926395961, 33.663726874760215, 40.24962207249233, 43.523898124694824, 40.6488481930324, 21.593566417694092, 4.814975687435695, 0.34766625293663567, 0.24373650976589747, 0.09152978033359561, 0.11523049963372094, 0.10319068961377655, 0.0754657012543508, 0.14376664268118994, 0.12769514721419128, 0.1298016727502857, 0.09097220775272165, 0.0906430504151753, 0.24813667365482875, 0.08929965285850422, 0.21618798800877162, 0.18367766535707883, 0.11765866433935505, 0.1352516660200698, 0.23467760586312839, 0.09617460359420095, 0.21626083552837372, 0.09926356641309601, 0.12627052223043783, 0.17595586899135793, 0.2928057467298848, 0.1103908893253122, 0.1702761101935591, 0.15386750495859555, 0.07462959683367185, 0.30155165599925177, 0.18758263438940048, 0.15823588626725332], [0.04242495081520506, 0.023489779726203, 0.04368138053853597, 0.01437841319212956, 0.029755148171846355, 0.08770608622580767, 0.021913634480110238, 0.04105704118098531, 0.03503861537735377, 0.05594498837100608, 0.0796188987525446, 0.04012979254392641, 0.013759680009180946, 0.05530587962961622, 0.007982306315430572, 0.028744483832269907, 0.05204736787293639, 0.07731679228267499, 0.03455096583015152, 0.04075283357607467, 0.026641819160431623, 0.012420643736342234, 0.019435794225760868, 0.07099494258207933, 0.04991009791514703, 0.017088500716324364, 0.08991111469055925, 0.05101216431441052, 0.03450676605903676, 0.004431100420853389, 0.05479061370715499, 0.024141529574990273, 0.05857557364340339, 0.011131859766984624, 0.019097039010375738, 0.23935127364737646, 3.5679449226175035, 23.04054961885725, 36.791871888296946, 37.989703110286165, 29.241049085344585, 20.898871626172745, 17.093379735946655, 13.813072647367205, 12.412847348621913, 1.9173649549484253, 0.5537534058094025, 0.220200830538358, 1.4052286531244005, 1.6658474398510796, 2.702698345695223, 4.44801048721586, 3.8109657679285323, 8.147633109773908, 3.6977661507470265, 0.717155223446233, 4.316756410258157, 7.648926155907767, 15.960331780569893, 24.061092342649186, 28.22023364475795, 32.90858275549752, 37.13741275242397, 36.90512752532959, 50.823818002428325, 48.621906076158794, 46.95387635912214, 50.03529821123396, 50.58291700908116, 46.39849642344883, 49.4570552280971, 48.881143365587505, 48.603291852133616, 47.58751732962472, 46.13514927455357, 45.97421857288906, 45.251060485839844, 45.805342606135774, 42.34438930238996, 40.29581022262573, 41.280665261404856, 38.30068016052246, 38.2986547606332, 42.843860558101106, 49.22789321626936, 48.6312062399728, 49.725276538303916, 49.500974791390554, 44.0889846937997, 32.74625894001552, 34.104638712746755, 52.90279197692871, 45.60421657562256, 47.38180896214077, 44.41751984187535, 37.9197347504752, 36.09961244038173, 39.75946487699236, 35.033880370003835, 35.08535957336426, 36.30188839776175, 37.90824243000576, 42.10338756016323, 43.14728839056832, 42.59754344395229, 43.79725762775966, 44.67986645017351, 45.33447013582502, 45.912414346422466, 47.560864039829795, 47.318076610565186, 47.240486076899934, 46.16839293071202, 48.01418188640049, 46.278403759002686, 45.06659276144845, 48.89039489201137, 47.85765634264265, 47.305795669555664, 46.24482658931187, 40.79905782427107, 29.63496330806187, 15.531006063733782, 6.050939491816929, 2.03595290013722, 0.41359067974346025, 1.0631422379187174, 2.955563702753612, 0.2845213498388018, 0.4385822372777121, 0.5589884934680802, 0.24537313623087748, 0.07112633410309042, 0.22176459591303552, 0.2548805789223739, 0.4330375748021262, 3.5209859567029134, 14.283437899180822, 17.839651005608694, 26.489258459636144, 27.799318722316197, 29.900606836591447, 23.070511988231114, 9.989823767117091, 0.9004399627447128, 0.06576035025396518, 0.011452833972206073, 0.05124932587412851, 0.01756239466236106, 0.04115657887554594, 0.0033485514452747467, 0.021489987748542, 0.05156487858455096, 0.04438783727320177, 0.014984760566481521, 0.02948078592973096, 0.04280939179339579, 0.035142512659409215, 0.009612421388737857, 0.07853946488882814, 0.038067721229578765, 0.05133052955248526, 0.029453793806689124, 0.02066137774714402, 0.05082144169136882, 0.06509244109370879, 0.0789019518664905, 0.05888583378068038, 0.06154130771756172, 0.049878101596342664, 0.01743676051098321, 0.04858408781832882, 0.05937034849609647, 0.06690956465899944, 0.024879173475450704, 0.04168460125635777, 0.030837275819586854, 0.015937092946842313, 0.031646269373595715, 0.026414060399734547, 0.06512203879122223, 0.042078385661755285, 0.01966601437223809, 0.012407789738582713, 0.03781334184376257, 0.016487021830731204, 0.05458054265805653, 0.04568566781069551, 0.01793425899398114, 0.054176682007632086, 0.0040894690651579624, 0.08199487054454428, 0.08956605249217578, 0.04309683958334582, 0.022574712489066378, 0.034247318016631265, 0.02997671699683581, 0.02153426385484636, 0.013762221122825784, 0.03557147571284856, 0.04774375273180859, 0.018024224255766188, 0.059228460038346906, 0.04737881624272891, 0.036201397090085914, 0.027220942013497864, 0.02534963912330568, 0.043243640634630404, 0.04500779775636537, 0.016615782332207476, 0.08636965043842793, 0.20772865121918066, 5.370452897889273, 27.105742590767996, 43.03841011864798, 42.81105463845389, 33.86900792803083, 24.648135219301494, 21.333212205341884, 15.164396524429321, 12.536966494151525, 2.3004402049950192, 0.7395775488444737, 0.11220755148679018, 0.9169624532972063, 2.0219218816076006, 1.4142811787979943, 3.044691937310355, 3.9862006391797746, 9.055080873625618, 5.745770267077854, 2.6376024101461684, 8.303298813956124, 11.346181614058358, 16.309883492333547, 25.596385410853795, 31.734330245426722, 36.817955425807405, 39.30826275689261, 43.95182030541556, 52.125566482543945, 50.97019917624337, 47.13660703386579, 50.415552275521414, 51.69551815305437, 47.8785217830113, 50.337322507585796, 50.59616027559553, 50.56231212615967, 49.2446939604623, 47.81024183545794, 48.315601689474924, 46.831740924290244, 47.70076949255807, 42.91114343915667, 42.6856118610927, 43.10713127681187, 40.70761605671474, 40.34890488215855, 43.845012596675325, 50.651078837258474, 51.28074196406773, 51.21533857073103, 49.75790875298636, 43.8140548978533, 34.65113190242222, 36.95691244942801, 52.46835238592965, 47.34451450620379, 48.560379777635845, 45.33777747835432, 40.94748176847185, 36.907892908368794, 40.192660740443635, 36.774008069719585, 37.17728499003819, 37.87959153311593, 38.764430727277485, 44.06484317779541, 44.91320085525513, 43.305394649505615, 45.82455090114048, 46.794019154139924, 47.43298591886248, 49.708468845912385, 49.7591107913426, 49.569661208561485, 48.487243039267405, 46.79494673865182, 48.354292733328684, 47.321112973349436, 47.98300879342215, 48.510113034929546, 49.472726890019004, 49.120692934308735, 48.140520981379915, 42.242320265088765, 32.369861125946045, 19.278926917484828, 10.391061391149249, 4.239682648863111, 1.4380357669932502, 1.0265162203993117, 2.6654329853398457, 0.9209607073238918, 0.41794272192886894, 0.21895964071154594, 0.1744706236890384, 0.031893659848719835, 0.16262095953736985, 0.16917307009654386, 0.9891441400562013, 5.1801899416106085, 16.049725566591533, 19.490558624267578, 29.553933416094097, 31.73290933881487, 36.20488807133266, 26.645042283194407, 12.396238548415047, 1.5060522258281708, 0.13217221626213618, 0.03983876208907791, 0.044665124001247544, 0.06295371907097952, 0.02028633956797421, 0.0505581361773823, 0.02006950691741492, 0.034014295520527024, 0.051926076345677884, 0.03177508585421102, 0.030009653086641004, 0.03953644081151911, 0.041076070695583305, 0.024138057172032337, 0.06680879542337996, 0.01178201166580298, 0.015618283268330353, 0.0386286254173943, 0.07687430602631398, 0.028768073102193217, 0.031055791236992394, 0.0569449250719377, 0.01751762831450573, 0.06108998014990773, 0.05423480531732951, 0.02566530548834375, 0.055587851641965766, 0.048691201356372664, 0.03767955848681075, 0.09100569345589195, 0.04356104913832886, 0.1332919890327113, 0.12294631132057735, 0.0967122068894761, 0.07855657075664826, 0.1801383995584079, 0.1722563739333834, 0.12583099438675813, 0.1489940493234566, 0.0898934727800744, 0.3207973247127873, 0.18711103898073944, 0.11620376312306949, 0.0807852733082005, 0.12817013529794558, 0.12073078591908727, 0.16703952529600688, 0.22155266228531087, 0.1813608482480049, 0.10986438686294214, 0.09853674005717039, 0.12851434254220553, 0.11393373778888158, 0.12468028041933264, 0.14955750480294228, 0.18744799947100027, 0.10730225898857627, 0.1575197468378714, 0.158637280442885, 0.17879521234759263, 0.18531102128326893, 0.16950009683413164, 0.14104677577103886, 0.21477989213807241, 0.09669381180512053, 0.23569166287779808, 0.5126095392874309, 7.459257704871042, 32.05818578175136, 47.92539780480521, 48.32442242758614, 40.689696652548655, 30.623733656747, 25.910225118909562, 19.294416189193726, 16.150616884231567, 3.0329837884221758, 1.347385116985866, 0.48766089230775833, 3.3254901383604323, 5.971393474510737, 6.498644930975778, 12.660261409623281, 11.368415849549429, 15.235896962029592, 9.29354999746595, 2.705896471227918, 6.401381875787463, 9.916563698223658, 19.49923345020839, 26.68506043297904, 32.88572318213326, 38.275291442871094, 39.714096614292686, 46.145505564553396, 55.72757863998413, 48.873441287449424, 46.77691963740757, 50.20338208334786, 50.55506168093, 46.26014736720494, 49.963648387363975, 50.746435914720806, 52.54974358422415, 50.666163376399446, 48.565267835344585, 49.28861352375576, 47.27016530718122, 49.67653839928763, 45.54612616130284, 43.616760798863, 45.958515644073486, 42.04907349177769, 42.39780705315726, 45.60513373783657, 53.85294771194458, 52.351007734026226, 51.571412903921946, 50.252273082733154, 43.650716645377024, 37.42152806690761, 40.60498768942696, 52.78284175055367, 50.418870040348594, 50.79650463376726, 47.63315657206944, 41.896560532706125, 39.4500789642334, 42.22205236979893, 38.37552962984358, 39.06563861029488, 39.60184499195644, 40.998523235321045, 46.48311505998884, 46.1132937158857, 45.304193360464915, 47.301560742514475, 47.39865486962454, 49.34920181546892, 50.88692849023001, 50.632436820438926, 49.62082426888602, 48.708689076559885, 46.61365781511579, 48.644699641636436, 48.44384459086827, 47.39417328153338, 49.98889119284493, 50.289918422698975, 48.83496911185128, 49.90190322058541, 43.61009400231497, 35.01671484538487, 21.74614712170192, 10.627076063837324, 4.530402660369873, 3.134166713271822, 2.596844494342804, 8.500588570322309, 4.688790321350098, 0.6146144143172673, 1.5979738533496857, 0.6310938586081777, 0.33687507627265795, 0.5895582873906408, 0.8252478603805814, 1.1186257749795914, 7.806294168744769, 20.137538399015153, 26.88230242047991, 37.174168722970144, 40.028540815625874, 46.829642568315776, 33.52471079145159, 13.280848452023097, 1.8624073096684046, 0.27912458085588043, 0.10928544721433095, 0.11619773773210389, 0.1439618029232536, 0.10954461366470371, 0.14604381977447442, 0.09355241179998432, 0.08999209105968475, 0.18508132360875607, 0.1013303297970976, 0.17703327403536864, 0.13825001727257455, 0.17375130871576921, 0.14604434903178895, 0.15739184298685618, 0.06854336841830186, 0.13150943682662078, 0.08058305630194289, 0.19283054635993072, 0.15049761507127965, 0.1170308023158993, 0.17780339771083423, 0.14753665109830244, 0.16112890174346312, 0.10217512625136546, 0.1723746968699353, 0.15914601885846683, 0.09459093678742647, 0.09984344244003296, 0.21084536612033844, 0.10046183211462838], [0.0107281636613022, 0.03844520722382835, 0.02839163544454745, 0.048409765386687856, 0.007441896429684545, 0.006636536854784936, 0.04061451760519828, 0.02461333024049444, 0.03975788410753012, 0.03170774803896036, 0.046909154658871036, 0.04232965396451099, 0.020897847201142992, 0.04376912868714758, 0.0372920641010361, 0.048851864878088236, 0.023572204767593315, 0.020854672017906393, 0.049691779272896905, 0.046673981206757684, 0.06555489663566862, 0.05943533858018262, 0.022447210670049702, 0.0035917682939075996, 0.03439586629558887, 0.04462561969246183, 0.01198240595736674, 0.00774119483373527, 0.023983373240168606, 0.029067798983305693, 0.015945440623909235, 0.0786669480481318, 0.034831648625965626, 0.01784730133866625, 0.09308165777474642, 0.04762219996856792, 0.7172439758266721, 14.014254263469152, 34.399221488407676, 36.501968724387034, 31.66314595086234, 26.2597108227866, 32.975424425942556, 35.99728979383196, 13.174593125070844, 3.15555630837168, 0.6946126073598862, 0.09780802058854274, 0.6663709485105106, 0.5708993343370301, 1.3425076987062181, 0.9368865213223866, 1.6062448152473994, 5.570931877408709, 3.9693369269371033, 2.122776286942618, 5.480818084308079, 6.960636734962463, 8.459411808422633, 13.296461922781807, 19.291687284197124, 22.79024771281651, 29.94144139971052, 32.051591941288535, 44.72743034362793, 50.145409788404194, 47.25899607794625, 49.88750655310494, 49.1949587549482, 53.8509327343532, 47.85898692267281, 49.9022228377206, 50.742395537240164, 49.476732526506694, 49.639775480542866, 47.61468826021467, 47.46289791379656, 47.13661050796509, 45.61881474086216, 40.965595722198486, 40.383225509098594, 39.58792427607945, 39.3549998147147, 40.20375006539481, 45.211890016283306, 47.13510969706944, 48.664380414145334, 49.17787660871233, 48.70423528126308, 42.09789848327637, 33.33034535816738, 52.52324315479824, 48.55614137649536, 45.973495960235596, 46.443673610687256, 40.85424389157976, 38.73608207702637, 35.651860100882395, 35.14843879427229, 36.7275767326355, 40.82180970055716, 45.840761048453196, 44.76543351582119, 45.48386682782854, 46.26842267172677, 44.737123080662315, 44.04027087347848, 46.96112333025251, 48.751674107142854, 48.10736070360456, 45.20246478489467, 47.30310671670096, 46.95182316643851, 48.21526275362287, 47.86863449641636, 47.34829085213797, 46.35396889277867, 46.663650103977744, 45.15873629706246, 41.28870432717459, 31.550612926483154, 19.729385580335343, 9.515492830957685, 3.2640144314084734, 1.1006965999092375, 0.4469071291387081, 0.7872698754072189, 0.34103910997509956, 0.8580114937254361, 0.24421908387116023, 0.03358452840309058, 0.0893609109999878, 0.02992944685476167, 0.04174775590321847, 0.21254753906811985, 1.3146189323493411, 6.941292950085231, 16.03872309412275, 21.12851827485221, 25.429095370428904, 34.64163024084908, 29.854898112160818, 20.762745993477957, 5.412128193037851, 0.47411076511655537, 0.03925697259338839, 0.017282836538340365, 0.04227635843147125, 0.011702234607322939, 0.03711931247796331, 0.062364859240395684, 0.026911852349128042, 0.08560533502272197, 0.0328618445034538, 0.053746796146567376, 0.05966200998851231, 0.07446179512356009, 0.012623440041872007, 0.04298904072493315, 0.026223878908370222, 0.012315305415540934, 0.07167748095733778, 0.0547153539955616, 0.020266382156738212, 0.07468033768236637, 0.020376817123698335, 0.048559762337910276, 0.02600969254438366, 0.04222533259806888, 0.027369028888642788, 0.040183929460389275, 0.03569267563787954, 0.016675744471805434, 0.016960165995572294, 0.04483980605644839, 0.038928683780665906, 0.08376640334193196, 0.025062096338453035, 0.023710639482097964, 0.011417021742090583, 0.023189319330932837, 0.024684235453605652, 0.007152737883318747, 0.0524158497074885, 0.01871085419718708, 0.012637813109904528, 0.04052774654701352, 0.0119035059053983, 0.030300564797861234, 0.04489053672711764, 0.033918696721749644, 0.08007309652332749, 0.0367338061997933, 0.024181334135521735, 0.005914389421897275, 0.023170674884957925, 0.010744397611623364, 0.023062407837382386, 0.02797704206646553, 0.06954406507845436, 0.03570883494934865, 0.043745366390794516, 0.026510565042761818, 0.056273012555071285, 0.031128489478890384, 0.024501826580879942, 0.03222309538562383, 0.04106557036616972, 0.04503372457942792, 0.009432059147262147, 0.04238609790003725, 0.1047940000093409, 1.5585555285215378, 18.576384135654994, 39.19126204081944, 42.11790582111904, 35.212852069309776, 28.450594220842632, 26.81018533025469, 23.605163710457937, 14.930002519062587, 3.724542336804526, 0.4770412764378956, 0.08759414830378123, 0.239963882203613, 1.5344628670385905, 0.9167155751160213, 1.0094013959169388, 3.120206262384142, 5.716949573584965, 6.918995746544429, 2.3764597943850925, 6.139248490333557, 9.800950016294207, 10.541946734700884, 15.70807569367545, 22.51680483136858, 27.330819061824254, 33.080588885716026, 37.287851674216135, 48.30994585582188, 51.204026903424946, 49.95624508176531, 49.3751220703125, 51.010988576071604, 53.20766850880214, 49.80871050698416, 51.07630511692592, 51.90772656032017, 51.27467271259853, 50.524482658931184, 50.161411489759175, 48.96986491339547, 50.471565178462434, 46.64895813805716, 42.40318495886666, 43.287961619240896, 42.79470205307007, 41.47804273877825, 41.99618033000401, 48.71141971860613, 48.94552537373134, 50.38839176722935, 51.77579069137573, 47.588972977229524, 42.88028996331351, 35.684770243508474, 53.525798729487825, 48.492798124040874, 48.76992702484131, 48.13572325025286, 42.929861886160715, 40.241798400878906, 38.600050245012554, 37.67932707922799, 38.10629735674177, 42.15242099761963, 47.48280102866036, 45.53942114966256, 47.19450637272426, 48.39167404174805, 47.05434036254883, 45.61874873297555, 50.07413516725813, 50.22014113834926, 49.92441538402012, 46.149723121098106, 48.01975086757115, 47.358848639896934, 48.83064733232771, 49.88751002720424, 49.497761249542236, 49.34433112825666, 49.08251953125, 47.09614072527204, 44.27009296417236, 35.805877344948904, 22.809895481382096, 12.461661049297877, 4.902701905795506, 1.6859020037310464, 0.8098166712692806, 0.5365118309855461, 0.8772721173507827, 0.2613886797002384, 0.11867767465966088, 0.06667927665902035, 0.047918312650706084, 0.09108543489128351, 0.031245624979159663, 0.4905542199100767, 0.8264304654938834, 6.33075213432312, 20.366787263325282, 23.028369426727295, 27.649889026369365, 41.09653799874442, 37.461806774139404, 24.592012882232666, 7.444227882793971, 0.4929413603884833, 0.030476349472467388, 0.012295118998736143, 0.05608091250594173, 0.027380959230608175, 0.018644452760262147, 0.025103164670456733, 0.022342019082446183, 0.017903923389634917, 0.03712728526443243, 0.06006166032914605, 0.009008731327152677, 0.027083575991647582, 0.0348852800338396, 0.021572253334202936, 0.02519837500793593, 0.009817351686901279, 0.030256992671638727, 0.08539502309369189, 0.04162741771766117, 0.030275438646120683, 0.015440948141206588, 0.015171566346128072, 0.0051808243650676945, 0.01881502289324999, 0.02433517838029989, 0.026613849946962934, 0.030374253700886453, 0.046303945527012856, 0.05266457350392427, 0.040823129804006646, 0.07458251328872782, 0.09938094618597201, 0.11450579709240369, 0.14414806078587258, 0.1490869950503111, 0.12952648608812264, 0.11200599944485085, 0.10165745152958802, 0.08567233357046332, 0.09205799948956285, 0.07790209658976112, 0.14902545192411967, 0.130961913349373, 0.07118050155362912, 0.19425027232084954, 0.10017257942152874, 0.17428543791174889, 0.1293668539396354, 0.10550800205341407, 0.11185590071337563, 0.11672448446708066, 0.21228874581200735, 0.16631041227706841, 0.07561759131827525, 0.17178795406860964, 0.16301434699978146, 0.10632121270256382, 0.09344049423400845, 0.16916177927383355, 0.20307698154023715, 0.09214044149432864, 0.10964859237096139, 0.08990329796714441, 0.15985686571470328, 0.11470661631652287, 0.106620236299932, 0.18753301990883692, 2.079398900270462, 20.667262111391338, 46.35920436041695, 47.68111998694283, 42.02280582700457, 35.24184342793056, 42.68812363488333, 44.056758948734824, 18.146611997059413, 4.4382504395076205, 1.3616239300795963, 0.3734192896102156, 1.9614975239549364, 1.9775828208242143, 3.5510944553783963, 3.758585035800934, 4.883894434997013, 14.390121408871241, 10.289856536047798, 6.215508009706225, 8.495366999081202, 9.419797028814044, 10.081135255949837, 17.848079170499528, 21.936017070497783, 26.71919172150748, 33.92094223839896, 38.60580335344587, 51.7021814755031, 52.56825358527047, 49.259111472538535, 48.86341156278338, 48.76105070114136, 52.33481843130929, 48.887084075382774, 49.95590114593506, 52.02412278311593, 52.62571171351841, 51.19564042772566, 51.517981256757466, 50.29194382258824, 52.09781190327236, 49.17565665926252, 44.93359729221889, 43.38606323514666, 43.78214529582432, 43.13494838987078, 42.67141669137137, 48.75220217023577, 50.376089981624055, 53.11480236053467, 51.716734477451865, 49.26979085377285, 45.1075940813337, 40.05900519234793, 51.654489040374756, 51.79534639630999, 49.3150965826852, 50.47138799939837, 46.158797468457905, 42.94298703329903, 39.11530433382307, 39.683604444776265, 40.446228299822124, 44.67973096030099, 49.65053129196167, 47.92251430238996, 48.79336329868862, 49.93766907283238, 48.50282784870693, 47.41196414402553, 52.253670419965474, 51.40423577172415, 49.54628052030291, 45.44564478737967, 46.98824562345232, 47.26632990155901, 49.666675431387766, 48.504290444510325, 49.8862315586635, 48.331217765808105, 49.54776396070208, 47.70960065296718, 45.49551200866699, 35.44591549464634, 22.77831244468689, 12.563975010599409, 6.886042611939566, 3.505912274122238, 2.642622483628137, 1.302503771015576, 4.468327888420649, 3.149006111281259, 0.5329636899488313, 0.21350446343421936, 0.38629755856735365, 0.20374216298971856, 0.11482469498046807, 0.7509688490203449, 2.249819104160581, 10.952887518065316, 25.678606918879918, 30.947974818093435, 35.59461389269148, 48.37612049920218, 45.17731925419399, 27.178088971546718, 8.338877064841133, 0.7131451900516237, 0.14549089515847818, 0.13047210606081144, 0.1994103140064648, 0.07766515216124908, 0.051058888235794644, 0.12778981641999312, 0.17346629686653614, 0.1792224994195359, 0.15065996135984147, 0.23639769213540213, 0.10825161090386765, 0.16049139095204218, 0.10665796284696885, 0.1343367701130254, 0.1422687087740217, 0.0761951467554484, 0.27807499574763433, 0.16251966782978602, 0.11223980225622654, 0.1417542706642832, 0.08162711813513722, 0.1354692450591496, 0.08281694286103759, 0.1616102002028908, 0.0831696182223303, 0.1514312792569399, 0.19418187599096978, 0.1299554423562118, 0.09187999261277062, 0.08973156753927469, 0.19859736120062216], [0.030109747179916928, 0.03650325017848185, 0.009715038784114378, 0.061983203648456504, 0.018348913440214734, 0.01668443650539432, 0.021800090126427155, 0.010330704140609928, 0.04321119309003864, 0.006586349012130606, 0.03224355660911117, 0.030759851581283977, 0.034942263404705694, 0.03155998346794929, 0.03201832030234592, 0.05557034543848463, 0.035127829161605666, 0.029893172372664725, 0.024679880955123475, 0.002448370206236307, 0.06355694348790816, 0.04637128334226353, 0.015088902121143681, 0.016645076385300075, 0.017493051776130284, 0.1059039883049471, 0.03946591727435589, 0.06904766921486173, 0.06045787049723523, 0.06013644167355128, 0.005339593925912465, 0.01668985460751823, 0.040204485678779225, 0.04024684661999345, 0.04261362426249044, 0.05074995124180402, 0.21145752684346267, 8.39094078540802, 29.691222872052872, 37.94178138460432, 37.298888887677876, 26.529882839747838, 29.55228669302804, 23.837375981467112, 13.84153767994472, 6.731998877865927, 1.5268766283988953, 0.3777597967003073, 0.2854231228785855, 1.5183537943022591, 0.49698048936469214, 0.6814723696027483, 1.5501268208026886, 4.939164314951215, 5.102707539285932, 1.7311117606503623, 4.8851954851831705, 3.882133560521262, 3.0501723289489746, 5.433546015194484, 10.955003244536263, 15.003547464098249, 19.7680401461465, 25.04506322315761, 27.375025238309586, 41.68833344323294, 44.72262219020298, 47.905588490622385, 48.767377035958425, 49.500887938908164, 50.42647136960711, 50.32108456747872, 49.41041891915457, 50.42654085159302, 50.09569195338658, 49.85516963686262, 49.53125851494925, 48.011989729745046, 46.22162308011736, 43.613724436078755, 40.69671433312552, 40.26788541248867, 39.01814072472708, 41.031554971422466, 44.00078773498535, 47.35845954077584, 49.06459665298462, 49.412333147866384, 49.77387571334839, 44.91257899148123, 33.554952825818745, 46.991368838718955, 49.60471487045288, 48.39581169400896, 44.57300662994385, 40.71060725620815, 36.17548329489571, 35.50967911311558, 34.91968672616141, 38.00646563938686, 43.261822496141704, 46.65520109449114, 45.92463275364467, 47.903656891414094, 48.47747039794922, 47.677590302058626, 50.46470383235386, 49.62450334003994, 47.19554165431431, 47.57770994731358, 45.97309991291591, 46.49732412610735, 47.62031977517264, 46.781790324619834, 47.23995106560843, 46.934935569763184, 47.62262657710484, 42.39721645627703, 41.86631155014038, 30.74063014984131, 22.852824926376343, 11.698089633669172, 4.161074638366699, 0.7899973147681781, 0.27344062871166636, 0.6415010658758027, 0.5746019099439893, 0.8328736711825643, 0.0758541693378772, 0.03996642506016152, 0.027251123251127343, 0.06885939610323735, 0.08507279359868594, 0.15849721724433558, 0.7842082168374742, 2.7410786747932434, 11.896333030291967, 17.098976509911672, 22.69994718687875, 27.761308601924352, 34.20695093699864, 20.9358777318682, 12.68143778187888, 1.880601167678833, 0.10492136781769139, 0.014771826099604368, 0.05622366609584008, 0.03314241534098983, 0.02343413476566119, 0.0106892819083961, 0.018857058137655258, 0.029316488852990524, 0.034690723687942536, 0.04458502972764628, 0.06472975734089102, 0.02896941140560167, 0.08925639625106539, 0.05428379215300083, 0.015721468088616217, 0.030342684859143834, 0.04276020818256906, 0.0145666048795517, 0.018950414378196, 0.021372792876458595, 0.047671654993402104, 0.018907883803227117, 0.04356009918930275, 0.0310420814369406, 0.10255006434662, 0.04283422617507832, 0.07374551320182425, 0.04007581169051783, 0.09483510761388711, 0.049290500448218415, 0.043483628292701075, 0.011441342981665261, 0.010109421996665853, 0.05584268564624446, 0.035018836081560166, 0.03834699606522918, 0.023559127701446414, 0.015948415999966006, 0.053399413358420134, 0.09687582882387297, 0.030982916575989554, 0.06891541595437697, 0.007028474372678569, 0.03256205416151455, 0.06329086276569537, 0.019234832509287765, 0.013516558367492897, 0.033064061509711404, 0.06626437963651759, 0.0041198084862636665, 0.036692921072244644, 0.047101865389517376, 0.010439888906798192, 0.030667492787220647, 0.022336952122194425, 0.053748088755777905, 0.027699833369946907, 0.02661480159232659, 0.012212503119371831, 0.01760827041497188, 0.015061348510373915, 0.0589543522468635, 0.045219463362757645, 0.019874300874237503, 0.06550074954118047, 0.018128394648166637, 0.009133918493586992, 0.05638795638723033, 0.30497467517852783, 10.750964181763784, 34.81485577992031, 42.78739602225167, 40.55641630717686, 26.937842845916748, 31.655124255589076, 30.474847657339915, 13.367636663573128, 7.790277702467782, 1.919303068092891, 0.1993467217045171, 0.19678892966892036, 0.5488104681883539, 0.3638337068259716, 0.7265741580298969, 1.0196671422038759, 4.662807966981616, 9.501899548939296, 3.1975761907441274, 1.4740069167954581, 4.096641387258257, 4.553474153791155, 7.113839737006596, 13.710631881441389, 16.84974636350359, 22.765124763761246, 28.582354647772654, 33.41137525013515, 46.302319458552766, 47.02426161084856, 50.31017242159162, 50.40405648095267, 52.64960309437343, 51.40775156021118, 50.380036558423726, 49.57837077549526, 51.72380774361746, 50.980701378413606, 50.902176312037874, 50.79149498258318, 50.22783626828875, 49.62010513033186, 45.44710043498448, 42.723979813711985, 41.28913164138794, 40.43380839484078, 42.35654517582485, 46.21457065854754, 48.874924727848594, 51.32162863867623, 51.86095823560442, 51.80596324375698, 45.781249727521626, 36.332908630371094, 48.286436625889365, 51.174973011016846, 51.22589635848999, 46.86871228899275, 42.166119371141704, 37.463505608694895, 36.534708636147634, 36.259942122868125, 39.889083521706716, 45.300608089991975, 48.34195968082973, 47.91368661608015, 50.38461889539446, 50.12189361027309, 49.55682093756539, 50.860004220690044, 50.58401135035923, 49.09845175061907, 48.35656132016863, 46.78454875946045, 46.77354628699166, 47.51229265757969, 47.167950357709614, 49.21233967372349, 48.58303090504238, 48.910033975328716, 45.524284499032156, 45.29516070229666, 34.31027065004621, 25.926640238080704, 12.917805075645447, 6.821239369256156, 1.5172986452068602, 0.6326218109045709, 0.43269583742533413, 0.517819059746606, 0.5673520075423377, 0.07755953818559647, 0.05131427524611354, 0.0794764199693288, 0.005519915031202669, 0.14150900739644254, 0.09018910370234932, 0.04357430092724306, 1.8725458170686449, 12.703579953738622, 21.462040492466517, 25.462674277169363, 30.91032600402832, 40.813770634787424, 28.439546585083008, 15.030978952135358, 2.8390324243477414, 0.09467407768326146, 0.061607817720089636, 0.0652650332610522, 0.01699645913738225, 0.03137659241578408, 0.03362390718289784, 0.03819058695808053, 0.008994114834682217, 0.005603331581888986, 0.05409726287637438, 0.05688601126894355, 0.05346508197752493, 0.009657067296627377, 0.1025428379486714, 0.05221145460382104, 0.042849011453134675, 0.044323373053755076, 0.0145016164918031, 0.003969715267885476, 0.038686555344611406, 0.013262070416073714, 0.03574357594230345, 0.019796932615073662, 0.0258969166316092, 0.04282490988927228, 0.027709521153675656, 0.02916363866201469, 0.05014096266989197, 0.02837669410343681, 0.039746243839285204, 0.126408794096538, 0.030334461014717817, 0.0939754308866603, 0.09949218521692924, 0.07558730830039297, 0.15543914133948938, 0.10198341975254671, 0.12502064715538705, 0.07519891485571861, 0.17942128303859914, 0.16347161174884864, 0.14926516477550777, 0.13491353844957693, 0.08797723560460977, 0.16716535282986505, 0.13383978392396653, 0.0857585414445826, 0.0970755759626627, 0.15241432722125733, 0.1515364521848304, 0.1617897269981248, 0.12418902106583118, 0.10031571638371263, 0.09580640335168157, 0.10969986926232066, 0.13775407602744444, 0.07746303693524428, 0.20672884343990258, 0.21335994904594763, 0.1316497442977769, 0.11625603746090617, 0.12257254709090505, 0.11669747877333846, 0.10570505540817976, 0.24260626041463443, 0.15133556510720933, 0.13694489587630543, 0.1347123799579484, 0.5623310655355453, 12.406428950173513, 39.15655926295689, 49.292615686144146, 48.49129383904593, 35.237719672066824, 39.435807364327566, 33.61663893290928, 19.52726248332432, 9.469096234866551, 2.4748914497239247, 0.7141197834696088, 0.6009801487837518, 3.545296400785446, 1.3588761346680778, 2.964615902730397, 7.428971375737872, 11.962088176182338, 12.211970584733145, 6.220839883599963, 8.652968645095825, 9.574448296001979, 3.627490767410823, 8.161793538502284, 14.223397646631513, 17.441415003367833, 22.198408842086792, 28.500352008002146, 35.34427377155849, 48.150693144117085, 46.65067434310913, 51.17724854605538, 50.75132049833025, 51.19021041052682, 51.23546402794974, 50.598870073046, 49.96955435616629, 52.306459358760286, 52.40765987123762, 53.27089711597988, 53.44268090384347, 51.93280608313424, 51.11560412815639, 48.04683147157942, 44.21822813579014, 42.47877788543701, 42.432329177856445, 44.41196823120117, 47.17214012145996, 50.42511299678257, 52.663058280944824, 53.69977119990757, 52.01548269816807, 46.63868522644043, 40.07650075639997, 48.60422985894339, 50.675442695617676, 51.61593696049282, 49.37878377096993, 43.7955379486084, 39.82741478511265, 39.4310930115836, 38.09815754209246, 41.76402017048427, 47.332754680088584, 50.52668176378523, 48.79759475163051, 52.83051334108625, 51.0386632510594, 51.477744238717214, 51.642329692840576, 51.27467271259853, 48.00665698732649, 48.46273674283709, 46.11118841171265, 47.18613031932286, 48.21622855322701, 46.77908052716936, 49.825427872794016, 48.27702876499721, 50.047857080187114, 47.18937512806484, 45.990935938698904, 33.71503932135445, 26.427938870021276, 13.598718115261622, 6.809715347630637, 2.3765740053994313, 2.2687440429415022, 1.303871589047568, 2.5121403081076483, 2.4144334367343356, 0.3364259403731142, 0.27102984807321, 0.3032272575157029, 0.1601814225848232, 0.5001626557537487, 0.3928800810660635, 1.7204171802316393, 3.9184856670243398, 16.09964142526899, 25.75318193435669, 33.32633972167969, 40.32100439071655, 48.19504696982247, 36.57564742224557, 16.942737579345703, 3.735639044216701, 0.24630802177957126, 0.15526918188801833, 0.1309856077922242, 0.12203096758042063, 0.1654541553663356, 0.11727274076214858, 0.1994154980140073, 0.15309548138507775, 0.10311293628598962, 0.17182128370872565, 0.17236005408423288, 0.2127169964036771, 0.09841413556465081, 0.2082210640822138, 0.10141334855662924, 0.15832747492407048, 0.1048364695161581, 0.10985355744404451, 0.0842327129627977, 0.13313688949814864, 0.15543405232684954, 0.12836167216300964, 0.23582736988152775, 0.12969712407461234, 0.19382384020302976, 0.10964605464999165, 0.15125286525913648, 0.1948564619358097, 0.15339514959071363, 0.11338124064994709, 0.14068715221115521, 0.06711720994540624], [0.04421094997919031, 0.03186709520273975, 0.05666979269257613, 0.038839412320937426, 0.060478233333144865, 0.02285254543780216, 0.017447245573358874, 0.04504878805684192, 0.01856823461795492, 0.04650401157726135, 0.045668334633644135, 0.04188671987503767, 0.012585485337435134, 0.034648108296096325, 0.03815416319827948, 0.02163145042556737, 0.03417227204356875, 0.041399358705218346, 0.02611138967664114, 0.048305840963231664, 0.06755911944700138, 0.03805336682125926, 0.05995352898857423, 0.024765166021617394, 0.000680719424313533, 0.03131389917273607, 0.08243574867291109, 0.031199521917317594, 0.013012056554933744, 0.04771787001352225, 0.11809991566198212, 0.020825025126604096, 0.02298754676511245, 0.02066947266991649, 0.00903185410425067, 0.033226085494139364, 0.09176909963467292, 3.450163619858878, 18.25689033099583, 39.49203566142491, 39.4928103855678, 32.19626733234951, 23.825805493763514, 20.61792642729623, 22.724060910088674, 10.138047950608389, 2.0351321441786627, 0.4228746401412146, 0.10235281421669892, 0.7845859708530563, 0.11227978832487549, 0.2663382669644696, 1.369743442961148, 4.205872280257089, 10.297268526894705, 2.5330611169338226, 0.20160219924790518, 1.5999568040881837, 2.1376491231577734, 1.4532818517514636, 3.88258649621691, 6.909190535545349, 8.490721259798322, 14.206072313444954, 16.287157671792166, 23.85212353297642, 37.1894964490618, 42.59957579204014, 48.22129031590053, 48.31022030966622, 49.779250144958496, 51.43200077329363, 51.0358943939209, 50.665958404541016, 50.933682918548584, 48.89123909814017, 52.41019596372332, 49.36724281311035, 46.70232377733503, 45.48289408002581, 41.192829608917236, 40.665155615125386, 42.618943895612446, 41.69393021719796, 43.583617891584126, 45.26290021623884, 49.53048379080636, 48.572813579014365, 50.88958270209176, 45.67640141078404, 32.01679188864571, 47.51132338387625, 45.98233754294259, 47.462818009512766, 43.28275394439697, 42.4698702948434, 36.62850931712559, 36.945159571511404, 35.213453088487896, 39.69726112910679, 45.97242941175188, 48.221248626708984, 49.487384114946636, 49.50486578260149, 47.75613273893084, 49.611937522888184, 47.43982294627598, 48.324940068381174, 48.3038592338562, 47.68565368652344, 45.69433123724801, 47.42446395329067, 46.09418964385986, 47.101542949676514, 46.94769593647548, 46.892162459237234, 44.49438081468855, 38.36106695447649, 30.744357858385357, 23.303472927638463, 11.389270867620196, 3.8131435939243863, 1.1472826429775782, 0.4389635739581925, 0.30282214496816906, 0.16391419300011226, 0.5315176503998893, 0.27296342860375133, 0.037333339386220486, 0.06288849828498703, 0.07528749081705298, 0.06207995595676558, 0.019661488543663706, 0.2081436568072864, 0.985098985689027, 7.279855651514871, 17.078875371388026, 24.184511457170757, 30.05027798243931, 30.12870577403477, 32.17172976902553, 20.276545797075542, 7.705656460353306, 0.8472458028367588, 0.016738497086667588, 0.029844239819794893, 0.03402098587581089, 0.053297385440341065, 0.09264563795711313, 0.042575151326933076, 0.06990858766117267, 0.014639944337042314, 0.05217409785836935, 0.037601028236427476, 0.02758681488090328, 0.07085840098027672, 0.03508325280355556, 0.016577898025778786, 0.010318708489648998, 0.005776402964589319, 0.031214968767017126, 0.039006976543792655, 0.04793465855930533, 0.07143364939838648, 0.05879879130848816, 0.030297569065753902, 0.019142689150092856, 0.015630391725738133, 0.05935791773455484, 0.01780762061077569, 0.025758264785898582, 0.03433301020413637, 0.04989469177754862, 0.025709591772673384, 0.03823924470426781, 0.022964266228622625, 0.06542134737329823, 0.04703265481761523, 0.05298598197155765, 0.029878865461796522, 0.058535139741642137, 0.016966747785253183, 0.13137231847005232, 0.044342697731086185, 0.004248800113730664, 0.015429099223443439, 0.01057895296253264, 0.03798367448949388, 0.03858114153678928, 0.026871732269812907, 0.0659342927059957, 0.050778168120554516, 0.004041544560875211, 0.03846219774069531, 0.016197134707389132, 0.019127695222518275, 0.04018864867144397, 0.028748219167547565, 0.014796412816005093, 0.025921795118067945, 0.04008270221363221, 0.03988150979525276, 0.01266481286646532, 0.009618664759078195, 0.014592168686379279, 0.017092414167044417, 0.08533374459615775, 0.036108010315469334, 0.025710300841767873, 0.017104071398664798, 0.03245875059760042, 0.04494188825732895, 0.037958958851439614, 4.852417358330317, 22.499514239174978, 44.8833201272147, 44.48383692332676, 33.74241174970354, 26.644172021320887, 21.947148084640503, 21.541321175439016, 10.566344465528216, 2.420650554554803, 0.526722633412906, 0.0839636263304523, 0.3699824283165591, 0.3202473856508732, 0.4883758510862078, 0.4204645923205784, 1.2928117939404078, 2.078865626028606, 4.530155999319894, 1.2290515410048621, 0.999447015779359, 2.53973160471235, 2.781460302216666, 6.544025353022984, 7.079901695251465, 11.171267662729536, 16.57659009524754, 20.184054851531982, 28.313436780657085, 40.44177450452532, 43.817949363163535, 48.88859183447701, 48.389474936894004, 50.600805146353586, 51.357005391802105, 51.09431484767369, 51.27783414295742, 51.60532358714512, 50.39572559084211, 54.07139560154506, 50.94026286261422, 49.10446194240025, 46.68311200823103, 43.65859242847988, 43.00115040370396, 44.85944611685616, 43.16401617867606, 45.13030079432896, 48.733685220990864, 50.57040677751814, 51.331623622349326, 51.34942838123867, 45.42972299030849, 36.20190034593855, 46.28083215441023, 48.69465718950544, 49.64471217564174, 45.444859640938894, 45.43983261925833, 38.322163990565706, 38.158488750457764, 38.12637070247105, 41.95877817698887, 48.05827168055943, 50.69613095692226, 50.945654664720806, 50.77592059544155, 48.764340673174175, 50.06105865750994, 48.895112718854634, 48.48891060692923, 47.96162918635777, 47.738327980041504, 47.14869689941406, 48.56693887710571, 47.84919343675886, 47.66964503696987, 49.192971570151194, 46.681291580200195, 47.823078632354736, 40.33661699295044, 36.31496838160923, 25.792890889304026, 14.87629120690482, 5.803856338773455, 2.0195258387497494, 0.7134827747941017, 0.46579024302107946, 0.38303803918617113, 0.23010498551385744, 0.3797939904034138, 0.03012735516365085, 0.05500800275642957, 0.10962511505931616, 0.05281599877136094, 0.018279438239655325, 0.1321903331471341, 1.0667165432657515, 7.473949670791626, 19.39696638924735, 27.44293519428798, 31.32533495766776, 34.424947193690706, 39.10234246935163, 24.88298433167594, 9.293906092643738, 1.148674345442227, 0.04776949974309121, 0.0048323198737177464, 0.05193974882630365, 0.03802976058796048, 0.03756625670939684, 0.06812253421438591, 0.05452921148389578, 0.028166046299572502, 0.058601602246718745, 0.03128518696342196, 0.023407419145639454, 0.011043515355725373, 0.035982186174286265, 0.05119209144530552, 0.03756000740187509, 0.01397058820085866, 0.06261673822466816, 0.03592271936525192, 0.022117549520252005, 0.051098850555717945, 0.039609318865197043, 0.0339339332255934, 0.02768678344520075, 0.06737474791173424, 0.04203675075301102, 0.08800591727984802, 0.02288551375802074, 0.02014253255245941, 0.047760258096137216, 0.07816829944827727, 0.011448799233351434, 0.09606309314923626, 0.16054476451660904, 0.18070549198559352, 0.135398853836315, 0.151521483702319, 0.2445333270089967, 0.15881406595664366, 0.17097023794693605, 0.09606214998556034, 0.08044804140393223, 0.09923914593777486, 0.17088588247341768, 0.15575485011296614, 0.07823573904378073, 0.1080960567508425, 0.1402633392385074, 0.1108584338799119, 0.09770617926759378, 0.15217304016862596, 0.09105389658361673, 0.146891662850976, 0.18325588798948697, 0.14783484009759768, 0.1354634232286896, 0.12581002765468188, 0.10118807493043797, 0.08944383476461683, 0.15730444767645427, 0.08498593433094875, 0.08898317055510623, 0.15629355263497147, 0.1782468067748206, 0.08542334514537028, 0.10436874175710337, 0.12169189006090164, 0.15169611147471837, 0.09256099071353674, 0.2158185121204172, 5.870783993176051, 25.087263107299805, 50.203951835632324, 51.25890030179705, 40.708561011723106, 32.81258296966553, 30.135341303689138, 30.420384202684673, 13.740561246871948, 2.602429977485112, 0.957865195614951, 0.2932278226528849, 2.0583397788660864, 1.5521763222558158, 1.3322496605770928, 5.105135500431061, 12.100428547177996, 16.601756470543997, 5.0289376463208875, 1.7959697203976768, 3.6521820596286227, 4.4912912505013605, 2.1279040575027466, 7.6381790297372, 9.17594391959054, 11.60635951587132, 17.252264193126134, 22.16120818683079, 33.1384847504752, 40.756823199135916, 42.77533047539847, 49.86956630434309, 50.052529743739534, 49.695656367710654, 51.03324713025774, 51.217933722904746, 49.96584749221802, 52.313730648585725, 49.94582625797817, 54.86733954293387, 52.38458490371704, 50.06825699125017, 50.040603160858154, 45.58949681690761, 43.9537136895316, 46.84196172441755, 44.87706674848284, 46.63661813735962, 48.7818466595241, 54.49822691508702, 52.01227610451834, 52.35196311133248, 47.537472929273335, 39.759416239602224, 46.56109816687447, 50.05718156269619, 50.60498448780605, 48.263017722538535, 46.49752909796578, 41.09487043108259, 39.074070249285015, 39.02344914845058, 43.492728505815776, 50.086978912353516, 52.44746610096523, 52.40246956689017, 51.12806224822998, 50.416771684374126, 50.052008628845215, 47.46710852214268, 48.400803974696565, 48.53387587411063, 48.5086087499346, 46.94888755253383, 48.02888427461897, 47.542951583862305, 48.34957838058472, 48.920779364449636, 47.16430255344936, 48.920709882463726, 41.52321992601667, 35.54944017955235, 28.088999543871196, 13.903328010014125, 4.975636712142399, 2.2640181822436194, 1.1503813224179404, 1.0208742831434523, 0.9763142913579941, 2.1669933199882507, 0.951425735439573, 0.12515560777059623, 0.26761277286069735, 0.2181334157607385, 0.3981844335794449, 0.2228059164647545, 0.8071393892168999, 2.0153160989284515, 9.692057847976685, 22.76645186969212, 34.81049925940377, 39.099712576184956, 42.77430214200701, 47.04233040128435, 29.305959156581334, 10.892535465104238, 1.383242707167353, 0.11502039805054665, 0.12806127113955362, 0.15579835777836187, 0.13390322694821016, 0.18004064980362142, 0.22242782318166324, 0.2116408941469022, 0.12737957414771828, 0.16582862527242728, 0.13351385641310895, 0.16270378152174608, 0.21794709004461765, 0.13080403182123387, 0.10800300924373524, 0.10237950778433255, 0.07256183600319283, 0.22878648340702057, 0.16988306199865683, 0.09434648776160819, 0.16234037173645838, 0.20284095991935047, 0.0626045720917838, 0.08869184833019972, 0.15132236081574643, 0.14551734445350512, 0.12079261402998652, 0.1462289784103632, 0.09607385471463203, 0.12343097531369754, 0.11836744844913483, 0.10056845710745879, 0.12863476893731526], [0.07442100159823895, 0.05646342983735459, 0.05221820602725659, 0.015170529883887087, 0.028533391587968384, 0.02140122010106487, 0.02489171958794551, 0.047856620246810574, 0.06399377076221363, 0.02106498903594911, 0.06876028249306337, 0.06248061052922692, 0.013657713159253555, 0.033323909887777906, 0.0025333658351363347, 0.07937233269746814, 0.034780592258487425, 0.06575153608407293, 0.03926245515633907, 0.015154450300282665, 0.060798345798892636, 0.019317456022171036, 0.029303430446556637, 0.008809541435247021, 0.025157191324979067, 0.09720637715820755, 0.10980443150869437, 0.04314118863216468, 0.03561890870332718, 0.026067669969052076, 0.0035006616089958698, 0.03428223203601582, 0.030073201283812523, 0.03910312156326004, 0.02493681332894734, 0.02482140130762543, 0.06114739778318575, 0.7599834310156959, 10.649234737668719, 29.99380997249058, 40.083139760153635, 34.81435203552246, 23.947567462921143, 27.497464656829834, 20.958945751190186, 14.656078474862234, 6.50525266783578, 0.8551578468510083, 0.16267001761921815, 0.008439966311146106, 0.16784318217209407, 0.07493798421429736, 0.24981064668723515, 1.672785541840962, 3.9878920912742615, 5.644007384777069, 0.8729470265763146, 0.35382262830223354, 0.9051252741898809, 0.9447743552071708, 2.1530925801822116, 1.1914400735071726, 3.9477080532482693, 6.029369677816119, 10.585161055837359, 12.656432952199664, 26.350209372384207, 34.46788011278425, 38.474965299878804, 43.906608377184185, 47.63745403289795, 49.289006096976145, 50.266336236681255, 50.04915986742292, 50.96282018933977, 50.28350176130022, 50.12809835161482, 48.75333820070539, 46.657744135175435, 41.94390555790493, 43.12972681862967, 44.78847026824951, 44.17680644989014, 44.02759735924857, 44.49607270104544, 45.976994378226145, 49.71003566469465, 50.427694252559114, 52.28033760615757, 47.354829107012065, 32.87517581667219, 51.64625195094517, 49.98622308458601, 47.24760798045567, 46.17643894468035, 41.54012836728777, 37.049142837524414, 36.36501973015921, 36.30209336962019, 37.93110547746931, 44.76609706878662, 47.83626978737967, 49.69480521338326, 48.93229947771345, 46.85281828471592, 48.96557787486485, 50.65341690608433, 50.94161081314087, 47.4784688268389, 46.426709583827424, 47.93158170155117, 47.146160806928364, 47.700286592756, 47.85122231074742, 44.9396595954895, 43.343845980507986, 38.53327110835484, 28.57570001057216, 21.593884297779628, 11.393938320023672, 6.076028568404062, 1.7850950296436037, 0.8264840969017574, 0.20611337146588735, 0.20651298787977013, 0.2561519092747143, 0.24317329855901854, 0.12642241907971247, 0.0411490708855646, 0.07836381931390081, 0.0684528789882149, 0.03640219256547945, 0.04657048765303833, 0.4847048137869154, 2.658658708844866, 10.070328201566424, 15.937058789389473, 24.371826205934795, 31.614803859165736, 33.89121437072754, 27.482268946511404, 15.544614110674177, 3.5582137533596585, 0.11520031839609146, 0.020242901452417885, 0.012841703553151871, 0.06845396464424473, 0.0407152664847672, 0.05440660020602601, 0.03144204051100782, 0.012542002268933823, 0.05489604447835258, 0.020975447858550718, 0.03518077185643571, 0.05629526171833277, 0.014834638086280652, 0.027353351337036917, 0.032759015914052725, 0.0878400629652398, 0.010026471090636082, 0.026873309863731265, 0.08017362148634025, 0.007331574269171272, 0.02647800893256707, 0.03654579432415111, 0.0648913708116327, 0.034628783618765216, 0.008354191851269985, 0.03166107840037771, 0.020946437093828405, 0.0474731054689203, 0.0292735782984112, 0.03818448353558779, 0.04400168299408896, 0.018597844189831188, 0.022924772097862194, 0.07132074795663357, 0.01245709294120648, 0.07088345249316522, 0.013355012750253081, 0.03706006280013493, 0.007447906553612224, 0.062366073818079064, 0.04360318277031183, 0.03063436670761023, 0.027029311849868724, 0.047128090767988136, 0.047393228326525004, 0.02995921757870487, 0.00027468155115327263, 0.0269244476554117, 0.06347401293792895, 0.0054436447265158805, 0.013292591769381292, 0.008828141776445721, 0.03214682126417756, 0.02465943499867405, 0.10056295418845755, 0.05731184288327183, 0.03061903520886387, 0.02288733053553317, 0.03778273652174643, 0.10979385314775364, 0.028510799764522483, 0.0697433983108827, 0.017434263502114584, 0.0065285022054532805, 0.02704697072372905, 0.03961537818291357, 0.02569264536058264, 0.061852178536355495, 0.027377096670014516, 0.02018999946968896, 1.2164592338459832, 13.62685397693089, 36.84015144620623, 46.02942548479353, 39.00826038633074, 25.0909195968083, 27.45063032422747, 21.804235798971995, 14.368474296161107, 5.8933704154832025, 1.0467698935951506, 0.11592781650168554, 0.11938580737582274, 0.25812818322862896, 0.07251899330211536, 0.17885695903428964, 0.3991898867700781, 0.9616083204746246, 3.699134945869446, 1.5092047538076128, 0.4496604613959789, 0.9952498695680073, 1.5812999137810297, 1.6529958780322755, 1.3909332773515155, 5.226277342864445, 7.047568253108433, 12.363810437066213, 16.725615058626445, 29.467160837990896, 34.823693888528005, 42.423883642469136, 45.55333144324166, 48.23627063206264, 48.995715686253135, 52.371553557259695, 49.397585596357075, 50.098238468170166, 50.10345309121268, 51.62100567136492, 49.852334771837505, 48.6637932913644, 44.34332002912249, 44.4419983455113, 45.48126820155552, 45.249399866376606, 45.19617666516985, 45.117571694510325, 47.374954564230784, 51.440175328935894, 51.58276973451887, 52.46870674405779, 47.23511511938912, 35.7607626914978, 51.49081727436611, 50.047551359449116, 49.87414864131382, 47.88985082081386, 44.5897205216544, 39.17519433157784, 37.472534792763845, 37.79702608925955, 39.508839879717144, 47.06492246900286, 49.60383244923183, 51.00085115432739, 51.456315994262695, 48.03228541782924, 49.104882308415, 52.54080472673689, 48.99932527542114, 48.755200317927766, 47.466340746198384, 48.521372590746196, 46.85342625209263, 49.33618089130947, 49.986184869493755, 46.95859071186611, 44.91753305707659, 39.66776602608817, 31.238131591251918, 24.097249031066895, 14.616796834128243, 5.708551372800555, 3.1135963542120795, 1.8195317132132394, 0.7708224036863872, 0.23923752403685025, 0.0778477391494172, 0.09663140015410525, 0.0733368858428938, 0.05301071796566248, 0.10112347161131245, 0.08611872140318155, 0.0453957501532776, 0.0978488480406148, 0.4928572763289724, 3.2195770101887837, 10.94578298500606, 19.435085943767003, 29.528839996882848, 35.25514228003365, 40.13336133956909, 33.581835406167166, 18.156424590519496, 4.412769223962512, 0.1568899034921612, 0.01771495138694133, 0.05111287248187831, 0.029097355968718017, 0.02330078567112131, 0.07732224770422493, 0.034955718754125495, 0.04781726521572896, 0.036630828332688124, 0.05733576802802937, 0.020962706667238047, 0.033152471229966195, 0.05848289933055639, 0.03824339733858194, 0.06288946859006371, 0.045070799732846875, 0.031006600840815475, 0.015982195169531872, 0.048459101667893786, 0.0201215522496828, 0.0020351551024110188, 0.04909106204286218, 0.05135070579126477, 0.03298823522137744, 0.032322025791342766, 0.016393638448789716, 0.04554758593440056, 0.0073354631229969, 0.015417338515232717, 0.047179947806788344, 0.019987248117104173, 0.039216786356908936, 0.031267290602305105, 0.20081250662250177, 0.1215081156364509, 0.15984258933791093, 0.1382436797555004, 0.14658674278429576, 0.16671751971755708, 0.14152149244078568, 0.18911118379661015, 0.09864300542644092, 0.13243323511310987, 0.17573668860963412, 0.09825367560344082, 0.06999705505690404, 0.07753430346825294, 0.09983580892107316, 0.22031364377055848, 0.11648083611258439, 0.12390342567648206, 0.11363387959344046, 0.12536492225314888, 0.15166549597467693, 0.19393313862383366, 0.11726463905402593, 0.11292565866772618, 0.09615016276282923, 0.2151692355317729, 0.24123996230108397, 0.13216742580490454, 0.1217858400195837, 0.09491491690278053, 0.07952066045254469, 0.10096871134425912, 0.09197289762752396, 0.13247253586138996, 0.1479617261460849, 0.0947373646444508, 0.1429024197693382, 1.4527249102081572, 16.472433124269756, 42.18617187227522, 52.1966986656189, 46.921869482312886, 33.51600817271641, 34.84221083777291, 30.54460757119315, 21.304781913757324, 8.234095624514989, 1.6797960570880344, 0.4609408346670014, 0.5152968636580876, 0.6820394620299339, 1.2662006275994437, 0.8555462402956826, 4.771034845284053, 10.866781098502022, 13.127221175602504, 3.3931477878774916, 0.9522637533290046, 3.0255387936319624, 2.5141900266919817, 3.535792133637837, 2.237027470554624, 6.17535046168736, 8.86361631325313, 13.51983174255916, 18.85357209614345, 30.492145197732107, 38.37902109963553, 43.21679469517299, 44.86812789099557, 48.97178956440517, 49.93999671936035, 51.41031197139195, 49.69976970127651, 50.503648485456196, 51.92247411182949, 52.975897448403494, 52.7381648336138, 50.78278888974871, 46.072007519858225, 46.823066098349436, 48.9300274167742, 47.82792847497122, 48.391079970768516, 47.359751905713765, 49.49564552307129, 54.21860361099243, 53.4913113457816, 54.01980175290789, 47.938335350581575, 40.911948680877686, 51.42694248471941, 52.275209835597444, 51.07063538687569, 50.01083707809448, 45.94028009687151, 42.218814509255544, 40.16141469138009, 39.13713557379586, 41.42833880015782, 48.23604481560843, 51.07424150194441, 51.99052129473005, 52.82344702311924, 48.03864301953997, 48.523328508649556, 52.256970814296174, 49.281811237335205, 49.7618761743818, 46.52839994430542, 49.50448363167899, 48.490053585597444, 50.753509180886404, 49.863312925611226, 49.50604697636196, 46.69348566872733, 41.41748571395874, 31.354295049394878, 25.036110469273158, 14.543921521731786, 8.228122779301234, 2.7596809566020966, 2.410631903580257, 0.9201718696526119, 1.3322377183607645, 1.2864224910736084, 0.8945963648813111, 0.29489145481160706, 0.2903896192354815, 0.25701967413936344, 0.1940407949898924, 0.12957965609218391, 0.1764536965638399, 0.7747926477875028, 3.747061014175415, 13.811722959790911, 24.55073016030448, 35.30320644378662, 42.1699651990618, 47.3796272277832, 40.998960971832275, 21.907142094203405, 4.971838218825204, 0.33079656958580017, 0.0805725050824029, 0.175974718694176, 0.1269838118127414, 0.15350564223315033, 0.18665720761886664, 0.12904464480068, 0.09501583541610412, 0.13103899492749146, 0.15664709652108805, 0.07624098858130829, 0.0854565662198833, 0.12724089516060694, 0.07222205959260464, 0.17274232714303903, 0.2556559816002846, 0.10063038699861084, 0.09957941767892667, 0.16433530540338584, 0.09114555987928595, 0.17733625349189552, 0.18279817540730747, 0.11598484058465276, 0.11968364353690829, 0.11729391105473042, 0.12394227859164987, 0.08721671998500824, 0.13229000994137355, 0.13785814972860472, 0.12077115875269685, 0.14152541437319346, 0.10828574800065585, 0.1640852109662124], [0.037800670202289305, 0.0180364175300513, 0.05982106538223369, 0.042029107056025944, 0.051940651277878454, 0.06255721034748213, 0.042984413116105964, 0.022824766214138696, 0.04112431453540921, 0.0823764582829816, 0.012306906000178839, 0.04431105085781642, 0.014300871906535966, 0.056453150031822066, 0.037751954780625444, 0.04394323398758258, 0.01930627546140126, 0.03244426726762738, 0.018954107305034995, 0.02834928977037115, 0.05059499419959528, 0.005943662694854928, 0.03082860753472362, 0.010887208028829523, 0.017221401977751936, 0.030940830441457883, 0.07042151942316975, 0.05168222103800092, 0.03568167997790234, 0.06780261173844337, 0.07490236112581831, 0.036569936600114615, 0.04430535455633487, 0.07036788801529578, 0.0923157681577972, 0.01077142620592245, 0.03307129469301019, 0.18977906581546578, 3.068819774048669, 18.949127197265625, 39.416255133492605, 41.68135745184762, 35.97579206739153, 26.35913607052394, 29.528183392116002, 21.210206508636475, 11.330146040235247, 2.763470547539847, 0.42774112043636187, 0.22452577203512192, 0.2765500290053231, 0.08535657729953527, 0.09295432389314685, 0.12397668031709534, 0.33926965349486893, 2.964788956301553, 1.2219430995838982, 0.14642113952764443, 0.12159342105899539, 1.355033455150468, 0.8425673853073801, 0.23967452773026057, 1.7563946268388202, 1.7299806156328745, 4.3563776441982816, 5.968220319066729, 14.332127400806971, 22.201172488076345, 30.22123146057129, 35.85828413282122, 42.945741994040354, 48.540004185267854, 50.996661390577046, 51.24116155079433, 52.49911553519112, 51.74098369053432, 50.721912247794016, 47.487376417432515, 45.775545256478445, 45.46461336953299, 46.28499412536621, 46.898586068834575, 47.68196766717093, 46.06515659604754, 44.76742417471749, 47.07630014419556, 47.767861298152376, 49.82235676901681, 49.75356265476772, 46.75530726569039, 30.938650335584367, 46.78506987435477, 49.820984499795095, 47.80298444202968, 46.52555465698242, 40.42316028050014, 37.75978027071272, 37.89502348218645, 36.83550657544817, 38.11937734058925, 43.21317120960781, 46.273001534598215, 48.92277349744524, 49.37494836534773, 46.06229393822806, 48.40419469560896, 44.01541716711861, 46.928300040108816, 51.02360303061349, 49.41949674061367, 48.030520575387136, 45.64017697743007, 45.97507667541504, 43.22511516298567, 39.366975034986226, 34.510844298771445, 29.766676834651403, 19.496980496815272, 11.330028789384023, 4.144959594522204, 1.9798909255436488, 1.4864643854754311, 1.4717367014714648, 0.755035825073719, 0.32843703191195217, 0.13438422685222967, 0.014609642659447022, 0.1089411246191178, 0.0432644784450531, 0.050584504048206975, 0.08726346426244293, 0.09405097219028644, 0.12765501865318843, 1.302034659045083, 5.101006967680795, 14.849723032542638, 14.463801843779427, 23.191520077841624, 28.114756516047887, 33.23727076394217, 25.402806861060007, 9.457904423986163, 0.6338296575205666, 0.06020318237798555, 0.03274198468508465, 0.05724363654319729, 0.0038404721583771917, 0.057354929856956005, 0.05560497108048626, 0.043947349302470684, 0.028404890626136745, 0.036887406171964746, 0.042244867621255774, 0.061982158704527786, 0.02568831800350121, 0.015299673757648893, 0.060048693524939675, 0.06173647474497557, 0.023599892389029264, 0.010857244770574783, 0.02260288017402802, 0.05071019248238631, 0.0188168244037245, 0.007317977275566331, 0.010630245969098593, 0.02222001170074301, 0.04356610422421779, 0.009255791864623981, 0.05369110538491181, 0.039493574361715994, 0.024457597972026894, 0.06871107513351099, 0.03918041009455919, 0.026415398810058832, 0.042502934844898324, 0.04868809027331216, 0.07831470016390085, 0.038902906235307455, 0.061814974461283, 0.001558389574971183, 0.04044228166873966, 0.04479129758796521, 0.04527016689202615, 0.03246406691947153, 0.01729558451500322, 0.0450033126398921, 0.06044120567717722, 0.039401222353002856, 0.044023450397487195, 0.03845882881432772, 0.014804601037342633, 0.04434618200840695, 0.018272659674819027, 0.009669900090167565, 0.07548242714256048, 0.04852318251505494, 0.018586339628590003, 0.01816767843307129, 0.059958461938159804, 0.03535719774663448, 0.016561167048556463, 0.09425812214612961, 0.008978442372088986, 0.01249119102223111, 0.03653402852692774, 0.009457931687523211, 0.006910187483299524, 0.0536911087775869, 0.03793234331533313, 0.03864035728786673, 0.0930094209366611, 0.026383909696180905, 0.030256768755082573, 0.2007672619074583, 4.4215565238680155, 24.698063237326487, 45.22167655399868, 46.9891106741769, 37.169711453574045, 25.839874608176096, 30.716999326433452, 20.63780869756426, 10.851884160723005, 3.019388335091727, 0.3892168604901859, 0.1944815306259053, 0.10465805551835469, 0.254898193691458, 0.03392891885180559, 0.050108297994094234, 0.09106544524963413, 1.1865625466619218, 0.43226124931659016, 0.3800956942141056, 0.27728944218584467, 0.4887997454830578, 1.383497184940747, 0.21037264434354647, 2.025546018566404, 2.953434079885483, 6.25433932031904, 10.282745923314776, 18.448889902659825, 23.775120122092112, 31.958489554268972, 36.88669742856707, 43.932625906808035, 47.583862577165874, 51.64624847684588, 51.80451454435076, 53.03356749670846, 52.14871440614973, 51.34697914123535, 49.41645690373012, 46.51974943705967, 46.5002041544233, 48.42887469700405, 48.75912257603237, 49.0841315133231, 47.66298518862043, 47.095567498888286, 49.858053139277864, 49.804982798440115, 52.18014805657523, 50.69719403130667, 47.090860094342915, 34.3872184753418, 48.097827775137766, 50.84179646628243, 50.995699065072195, 47.73000751222883, 42.09253447396414, 39.95624133518764, 39.29503686087472, 38.54884549549648, 40.19284834180559, 44.4026437486921, 48.60933678490775, 49.00303561346871, 52.68139805112566, 48.27420779636928, 49.27024596078055, 46.73781517573765, 48.328549657549175, 50.12263011932373, 49.74195916312081, 48.550947598048616, 48.13208586829049, 47.045703751700266, 45.77626439503261, 41.004748821258545, 35.34403058460781, 30.19197259630476, 22.831577335085186, 14.087311966078621, 5.697380406515939, 1.843734460217612, 2.0658766201564243, 1.6668843499251773, 0.7188143229910305, 0.5496737818632806, 0.11160746868699789, 0.25688331574201584, 0.16713602654635906, 0.04219907329284719, 0.09007719292172364, 0.061914807318576744, 0.07025715110025235, 0.17230013944208622, 1.4519108853169849, 6.748974629810878, 17.00094611304147, 20.464312178747996, 28.15013153212411, 33.04254402433123, 38.4174793788365, 30.336887700217112, 11.399634105818611, 1.2178269433123725, 0.020134686991306286, 0.04381188317867262, 0.024731524255392805, 0.0176231710439814, 0.04815815103107265, 0.07126271964183875, 0.019168929795601537, 0.0375982055307499, 0.007072047771154237, 0.04946443611489875, 0.015446924338383334, 0.018617545454097644, 0.056626118786100826, 0.018000845331698656, 0.011877750412427952, 0.027446609189999954, 0.048752076125570705, 0.047196975643081326, 0.011078794935851224, 0.017463839147239923, 0.037697841612888236, 0.0698392413822668, 0.059885505852954726, 0.032314405843083344, 0.023664302325674465, 0.06206465499209506, 0.045056730309235196, 0.018408519348927906, 0.012711403625352042, 0.06289514792816979, 0.03457001909347517, 0.03391945668097053, 0.07413705504898514, 0.1690855933619397, 0.11920698625700814, 0.13797632338745253, 0.03973752466429557, 0.1534474374992507, 0.09231743735394307, 0.16333857817309244, 0.1654690017125436, 0.1335904901581151, 0.1442757746470826, 0.09074210974254779, 0.14705755109233515, 0.11179298694644656, 0.25771777810794966, 0.1781829430588654, 0.09660857423607792, 0.162208315251129, 0.09607084880449943, 0.12084275776786463, 0.16172023144151482, 0.1354790431048189, 0.09925510508141347, 0.12937381570892675, 0.09795873000153474, 0.08338384529841797, 0.12388700512903077, 0.10861190621341978, 0.14151294289955071, 0.11066172657800571, 0.17874679208866187, 0.1577984347407307, 0.1239598390779325, 0.14264749416283198, 0.19339767949921743, 0.22512352067445004, 0.14698109376643384, 0.14545932970941067, 0.3082246950694493, 5.984802629266467, 29.8575245312282, 51.43668385914394, 52.66833891187395, 46.17841918127877, 35.92322547095162, 39.20321294239589, 29.177684988294327, 14.546841502189636, 3.8448425786835805, 0.698277836399419, 0.7029888778924942, 1.159482702612877, 0.46792247146368027, 0.11803895607590675, 0.277238877756255, 0.7006781133157867, 8.644494448389326, 2.9014370185988287, 0.5619866411600793, 0.6314792122159685, 2.128412578787122, 3.6423527470656802, 0.7128166162541935, 3.260353599275861, 2.926573864051274, 5.90273745570864, 10.70086419582367, 19.624603271484375, 24.05466525895255, 32.791425704956055, 37.449320861271445, 44.12516743796212, 49.445674078805105, 51.770690713609966, 52.0197627885001, 55.78329277038574, 54.86441782542637, 55.044782638549805, 52.072947774614605, 49.356671128954204, 49.160137857709614, 50.7304550579616, 50.99113062449864, 52.02309097562517, 49.61426864351545, 47.575107846941265, 51.18519033704485, 51.35322904586792, 53.68979358673096, 51.50169120516096, 46.343154021671836, 38.45374550138201, 48.693045207432334, 51.89426442555019, 53.88077524730137, 49.99441501072475, 44.416745117732454, 42.37674706322806, 40.97541700090681, 39.96027476446969, 41.29982491901943, 46.78161314555577, 50.27407652991158, 52.11449105398995, 53.28829540525164, 49.40841088976179, 53.062155859810964, 46.20464515686035, 48.18755333764212, 52.026676246098106, 50.49978528703962, 49.84175961358206, 48.19770812988281, 48.073293685913086, 46.05732250213623, 43.08255549839565, 37.175318649836946, 33.10957677023751, 22.329257317951747, 13.733417630195618, 5.920038904462542, 4.405745029449463, 4.3472755040441236, 4.517305740288325, 1.8248694496495383, 1.635091673050608, 0.7562384605407715, 0.5931062655789512, 0.39381252388869015, 0.15513283706137113, 0.18213729586984428, 0.26655664667487144, 0.28136108656014713, 0.5132644070046288, 1.6180475247757775, 7.705563528197152, 19.59944905553545, 22.46681775365557, 35.3414215360369, 39.15597908837454, 45.62683991023472, 35.71443905149187, 13.504499673843384, 1.4090961941650935, 0.11185302372489657, 0.10331091923373086, 0.21545560445104325, 0.1347893393997635, 0.16293795752738202, 0.13595745100506715, 0.17359899117478303, 0.10235098217214857, 0.1108438725184117, 0.11968960107437202, 0.2639044704181807, 0.09717516454734973, 0.10544445724891764, 0.36741601888622555, 0.10083481602902923, 0.09105728247335979, 0.09864759232316699, 0.10664189513772726, 0.13609032173241886, 0.07387083861976862, 0.13953556971890585, 0.09461611043661833, 0.07757941926164286, 0.23239498691899435, 0.130209458725793, 0.16472418739327363, 0.15223815238901547, 0.1197625028767756, 0.1500863821378776, 0.15670479913907392, 0.09926820759262357, 0.17069001655493463, 0.13524304862533296], [0.03437330161354371, 0.01892060294215168, 0.012201518485588687, 0.03489440632984042, 0.06479403496320758, 0.02287352234790368, 0.023804033042064736, 0.07196735111730439, 0.06178965831973723, 0.014360187741528665, 0.05609225761145353, 0.02588772587478161, 0.077817713974842, 0.027915392071008682, 0.012548333848826587, 0.009584050991439393, 0.059486581544790945, 0.08745017674352441, 0.03252720121028168, 0.01869361601503832, 0.02254092992682542, 0.0609021345153451, 0.0040831633544127855, 0.035664696246385574, 0.04348268173635006, 0.028885656435574805, 0.01193115281473313, 0.028654102967785935, 0.030433924070426395, 0.07291675731539726, 0.05592835408502391, 0.016342229243101816, 0.05122652370482683, 0.019032739335671067, 0.07687567666705165, 0.015462025135223354, 0.013360557229524212, 0.024530148632558327, 1.3836544964994704, 11.715919579778399, 31.336757796151296, 47.84535108293806, 37.31670754296439, 30.560848985399517, 21.32234522274562, 31.066844599587576, 18.04472882407052, 7.359344346182687, 1.2935615479946136, 0.22937887161970139, 0.18694570713809558, 0.01600957745020943, 0.1652888778064932, 0.22043400231216634, 0.06180974295628922, 0.2432819184448038, 0.3418297932616302, 0.7433317473956517, 0.1869297751358577, 0.12252566032111645, 1.780557747398104, 0.388666568590062, 0.9361062603337424, 0.12563800545675413, 1.7383567775998796, 2.984538342271532, 6.595271357468196, 12.72960182598659, 21.181237731661113, 26.005415439605713, 33.681090423039024, 37.834348337990896, 45.40174259458269, 49.672532762799946, 50.568989345005576, 50.31253828321184, 49.335896015167236, 48.522505147116526, 47.243428639003206, 46.244263785226, 48.284199305943076, 48.48650305611746, 49.21046713420323, 49.047656944819856, 48.26534536906651, 49.32413271495274, 48.05284513745989, 50.92279161725725, 51.974290302821565, 49.45994915281023, 32.98614549636841, 49.137660435267854, 51.75513022286551, 48.02568115506853, 46.647478171757285, 40.940769808632986, 36.7302691595895, 38.410729203905376, 38.97556216376168, 39.95151308604649, 40.225779329027446, 46.67222418103899, 46.6026622908456, 47.395312786102295, 45.96479681559971, 47.33995648792812, 44.88523783002581, 43.823514870234895, 51.53219032287598, 48.072838578905376, 45.87201057161604, 44.0996675491333, 40.90318700245449, 33.23783356802804, 29.392901965550013, 24.981082473482402, 15.544054780687604, 10.495080266680036, 4.449400561196463, 1.6798889892441886, 1.0874109928097044, 1.356970591204507, 0.6276892955814088, 0.8941573798656464, 0.19758485124579497, 0.07617919439715998, 0.09222892924611058, 0.037249323180211444, 0.0642401332567845, 0.05147292012614863, 0.15829472882407053, 0.16888158502323286, 0.5444686583110264, 4.729879796504974, 13.454740149634224, 15.93587759562901, 14.723844255719866, 19.191204173224314, 31.415515627179825, 29.18782241003854, 19.770645720618113, 3.8067360520362854, 0.30706923135689324, 0.049717434681952, 0.026056399502392327, 0.05586114179875169, 0.026971322550837482, 0.06770772540143558, 0.1124461515407477, 0.032933535120849095, 0.019685364494632398, 0.08193675402019705, 0.062135840100901465, 0.02705107755692942, 0.02193498967348465, 0.08192077452050787, 0.038519981782883406, 0.03283903215612684, 0.05579516105353832, 0.11293336004018784, 0.04345211034108486, 0.019846502990861024, 0.04515311620863421, 0.019491725867348056, 0.029346164582031112, 0.08475179225206375, 0.014693029524226273, 0.02850051995898996, 0.04096892662346363, 0.040805674490651915, 0.10682015985782657, 0.031476907032941065, 0.03212270952228989, 0.013008514602136399, 0.01576138291108821, 0.029034533804016452, 0.035491822487009425, 0.01730982187603201, 0.019574612312551056, 0.04498501933578934, 0.022268102870189717, 0.06456907346312489, 0.08553917785840374, 0.061167217791080475, 0.042839169302689176, 0.01610483698147748, 0.02615904319100082, 0.03008269059604832, 0.043381759830351384, 0.025287218990602663, 0.02815285388247243, 0.014550474405820881, 0.05134531143786652, 0.07199930333133255, 0.028745830724281923, 0.03120988653972745, 0.0196418364731861, 0.04615134300131883, 0.04521655923287783, 0.017873491094048535, 0.010391076793894172, 0.06405737663486175, 0.031000086904636452, 0.10343564754085881, 0.032412980017917495, 0.021211272704281976, 0.10757893842778035, 0.02114933093876711, 0.059659105858632495, 0.011764815892092884, 0.060010790558797975, 0.026063668308779597, 0.03894952837643879, 0.048808794867779524, 1.8334869529519762, 14.764979328427996, 37.91361338751656, 53.4464989389692, 41.19482374191284, 32.21708760942732, 27.477323566164287, 34.80673680986677, 20.530459029333933, 7.5922410147530695, 1.759795987180301, 0.24636170747024672, 0.07934530664767538, 0.05098866664671472, 0.08232473355851003, 0.14768525026738644, 0.04269663623667189, 0.08789163841200726, 0.42186012172273224, 0.17029702264283383, 0.39342369618160383, 0.7786809791411672, 1.6599125925983702, 0.7397856691053936, 0.8178862439734595, 1.0141204169818332, 1.9218786784580775, 5.117277911731175, 9.089503986494881, 15.070236274174281, 23.23181094442095, 29.59141547339303, 34.72040891647339, 40.38804408482143, 47.78862598964146, 49.98419768469674, 50.52636562074934, 52.14732824053083, 49.51831749507359, 49.71251964569092, 49.185630798339844, 48.897419520786826, 48.66644055502755, 50.74154438291277, 50.9969219480242, 50.94053036825997, 49.659650802612305, 50.068962233407156, 49.42712238856724, 51.716314111437114, 52.65551948547363, 49.392103467668804, 36.06686905452183, 49.52448402132307, 53.221029894692556, 51.49860273088728, 48.68262985774449, 43.8988333429609, 38.61299821308681, 40.11312471117292, 40.30077471051897, 40.8870324407305, 43.274933746882844, 49.0668409211295, 49.50760684694563, 51.31399951662336, 48.4587276322501, 50.09096717834473, 45.01097590582711, 45.66666003635952, 50.90660926273891, 48.82801396506173, 46.434668745313374, 44.1460919380188, 41.81707314082554, 37.73664276940482, 30.930044991629465, 27.912018503461564, 19.637400116239274, 14.235647320747375, 7.568618008068629, 1.810776874423027, 1.0228375835078103, 2.8149154441697255, 1.5848845328603471, 0.48254870091165813, 0.7235196105071476, 0.024650125498218194, 0.13321288542023726, 0.1692496631294489, 0.13403250143996306, 0.11112284540597882, 0.06702503096312284, 0.1471163122249501, 0.7218692504933902, 4.471808935914721, 11.799655795097351, 19.333897590637207, 17.49730804988316, 22.91648953301566, 36.65452337265015, 34.96936982018607, 23.093182223183767, 4.787955445902688, 0.343617705894368, 0.03880052887169378, 0.024890226810904484, 0.07299479562789202, 0.027255409896107655, 0.04075695228363786, 0.01616784235063408, 0.04734972405380436, 0.05393808873902474, 0.025374795809122067, 0.051433995964803865, 0.035522275138646364, 0.03231692999335272, 0.05302142185558166, 0.015016336193574327, 0.053607723609145196, 0.045641620709959946, 0.027988059778830836, 0.03332618637276547, 0.029206413509590284, 0.039692961876945834, 0.029732468138848032, 0.02968116071341293, 0.04061015462502837, 0.036925455023135455, 0.032325096162302155, 0.024672340734728744, 0.05668954823964408, 0.07545023065592561, 0.0589727269751685, 0.03912210018773164, 0.014655038348532148, 0.034414502259876044, 0.04990509711205959, 0.09945320338010788, 0.09152881002851895, 0.08993088041565248, 0.18077775596507958, 0.13874521212918417, 0.1473450463797365, 0.1497465989419392, 0.1763489307569606, 0.13325230830482074, 0.18888335887874874, 0.15013591519423894, 0.08451851869800261, 0.23307384763445171, 0.07750239875167608, 0.18858584841447218, 0.06306880539549248, 0.21170854408826145, 0.19446971054588044, 0.13383476276482853, 0.1455524382846696, 0.08899007804159607, 0.18449143240494387, 0.16708371149642126, 0.11328382337731974, 0.09921967198273965, 0.13164700301630156, 0.16644351370632648, 0.19190005771815777, 0.11681881440537316, 0.18179064589951718, 0.18333144964916365, 0.11484106124511786, 0.21305475756525993, 0.14058858821434633, 0.12430711330047675, 0.1209500612957137, 0.12161004516695227, 0.10769347513892821, 2.2000419923237393, 16.761726583753312, 42.51112174987793, 60.33425167628697, 46.60128654752459, 39.51316860743931, 30.24219070162092, 40.89438363483974, 24.720353058406285, 9.140165039471217, 2.39185591680663, 0.5105815338236945, 0.6641318915145737, 0.28278715003814014, 0.6292248474700111, 0.5893312767148018, 0.16969833762517997, 1.9860693940094538, 1.4556592213256019, 1.6705513702971595, 0.6133256863270486, 1.0487875853266035, 3.1306174865790775, 1.835765962089811, 2.34335749064173, 0.7898784897157124, 2.8914537600108554, 5.804919847420283, 9.701264211109706, 16.893379313605173, 24.02102381842477, 28.839378935950144, 37.64690678460257, 41.762220587049214, 47.65227454049246, 52.07938528060913, 51.44705751964024, 53.19187872750418, 53.50487075533186, 52.319372585841585, 50.98471048900059, 50.639280796051025, 50.36094985689436, 53.08129814692906, 53.265883990696494, 53.30011429105486, 52.612197467258994, 52.32683147702898, 51.85114737919399, 54.56831686837332, 53.94867999213082, 49.824927602495464, 40.747467449733186, 50.06095443453108, 55.04284061704363, 54.06217186791556, 49.72481795719692, 44.95429597582136, 40.16081019810268, 41.613748005458284, 42.24623210089547, 42.711674554007395, 44.10161999293736, 50.945303780691965, 50.63719286237444, 52.442463397979736, 50.13933706283569, 51.14899369648525, 46.284198556627544, 46.50888245446341, 51.228929247174946, 50.59111588341849, 47.38321944645473, 46.97757319041661, 43.88322768892561, 37.33027042661394, 31.817729473114014, 27.811509336744034, 18.52839640208653, 12.61954583440508, 5.405352830886841, 3.104368495089667, 1.804010414651462, 3.48721011195864, 2.662920125893184, 1.8913148556436812, 0.9380717320101601, 0.593869264636721, 0.45542190223932266, 0.2358331781412874, 0.3135392798909119, 0.4528859997434275, 0.6289612501859665, 0.3925087595624583, 0.9687498744044984, 5.634343309061868, 14.917115347726003, 22.823786667415074, 24.503334760665894, 32.07766505650112, 44.49682310649327, 42.844982692173545, 27.412788697651454, 5.947904654911586, 0.506880695266383, 0.11417916390512671, 0.12158103100955486, 0.2640561637069498, 0.1149473741118397, 0.16745955204325064, 0.13814611999051912, 0.17134371719190053, 0.1769862515585763, 0.18883652639176163, 0.18910928389855794, 0.19345810982797826, 0.11298726964741945, 0.17082473289753708, 0.12702966720930167, 0.1557514574378729, 0.1483241588409458, 0.26005443558096886, 0.09183767238365752, 0.14845656816448483, 0.16913556068071298, 0.11568201040582997, 0.13844219196055615, 0.20095047993319376, 0.0807670953550509, 0.08854785641389233, 0.18116834786321434, 0.08593327099723475, 0.1937049472970622, 0.11270822212100029, 0.14896164249096597, 0.14141059267733777, 0.11418748274445534, 0.14947469638926641], [0.09783834431852613, 0.0102509584643745, 0.02338129554742149, 0.09290737605520658, 0.041260211528944116, 0.015866864572412202, 0.044534865633717606, 0.03663368496511664, 0.025306782851527845, 0.025312731907303845, 0.0343683856273336, 0.041856983077845404, 0.02908632977466498, 0.04203749714153154, 0.007009900324711842, 0.023091903754643033, 0.0777732835018209, 0.04446746675031526, 0.03515941835939884, 0.07463994449270622, 0.026816499519294927, 0.04176784732512065, 0.00661271349028019, 0.04042402568406292, 0.04214071249589324, 0.015965006181171963, 0.02443777457145708, 0.008712773859900023, 0.037720172200351954, 0.012663348927162588, 0.08181817324033805, 0.03659467937956963, 0.09384375438094139, 0.005717921303585172, 0.02746944358971502, 0.038824016361364296, 0.071195924654603, 0.030156773049384356, 0.03787625900336674, 3.4158503753798346, 20.39241221972874, 45.0197480065482, 43.93206657682146, 31.212871415274485, 22.331815992082866, 25.706856557301112, 22.37821432522365, 7.974518741880145, 5.207583214555468, 0.8466686680912971, 0.20744355794574532, 0.06676839544836964, 0.07895398871707064, 0.07054818155510084, 0.06495756190270185, 0.04358643652605159, 0.2177354549723012, 0.1501433112259422, 0.5464230562959398, 0.553743417773928, 0.9823570528200695, 1.0049617141485214, 0.11359147794012513, 1.1007309066397803, 1.0128902601344245, 2.376262204987662, 3.057641859565462, 3.818963578769139, 11.44947006021227, 17.64881178310939, 23.929234640938894, 29.175336497170584, 34.74474498203823, 42.92012398583548, 47.05405896050589, 48.05641303743635, 49.33063275473458, 50.101076807294575, 49.71153647559029, 50.92931944983346, 51.60198150362287, 50.29349674497332, 50.34613629749843, 49.68984767368862, 49.063495363507954, 49.073552880968364, 50.37187589917864, 52.840831415993826, 51.20405469621931, 46.68478304999215, 32.618523257119314, 48.05942855562483, 52.542670318058555, 48.419789927346365, 47.44446781703404, 42.04503311429705, 39.81927844456264, 40.39294951302664, 39.60274130957467, 40.88515990121024, 42.70991665976388, 46.890216963631765, 47.28654568535941, 48.82715238843645, 50.42054108210972, 48.42670338494437, 49.36772918701172, 50.87313631602696, 48.648559365953716, 44.73926312582833, 42.86356217520577, 36.48208992821829, 32.468664509909495, 26.71375823020935, 18.528387716838292, 13.54720069680895, 8.593094280787877, 6.98680408511843, 3.8019522173064093, 1.0142113949571336, 1.3239210503441947, 2.077446456466402, 1.091767730457442, 0.3143673911690712, 0.9662992230483464, 0.09837135393172503, 0.061968784779310226, 0.02725200534665159, 0.07600112645221607, 0.17138387289430412, 0.08285284414887428, 0.2404845899769238, 2.109578617981502, 8.614348820277623, 23.66664137159075, 35.13641146251133, 23.34662124088832, 24.178162540708268, 30.474385602133616, 24.270980051585607, 12.259858437946864, 1.6370383628777094, 0.10709326341748238, 0.030771254362272363, 0.008126567949407866, 0.041160724724509885, 0.028116179064714482, 0.02623909505616341, 0.05813168960490397, 0.013684869827037411, 0.035162281777177534, 0.02036145848355123, 0.038220730876283984, 0.021415674593299627, 0.02001042178432856, 0.11889199673065118, 0.036549936780439954, 0.01456176522853119, 0.014640639835436429, 0.0545726750445153, 0.021305957177121724, 0.004616051679477096, 0.002563869588941868, 0.029966959663267647, 0.008939134838458682, 0.08868594507553748, 0.015374390641227365, 0.017133623295064484, 0.05072628054767847, 0.05039124031152044, 0.049687287371073446, 0.018368478997477462, 0.038470811742757044, 0.05537752274956022, 0.02861538575962186, 0.010751640972947436, 0.03538182856781142, 0.007412992534227669, 0.043871662113815546, 0.037402556743472815, 0.04432173099900995, 0.03308700277869191, 0.02739963760333402, 0.022226135479286313, 0.04792869084381631, 0.02643460813643677, 0.01945915788279048, 0.010396075052475291, 0.04959603798176561, 0.025855919545782462, 0.010403434612921305, 0.0315253374698971, 0.06437693270189421, 0.03861499364886965, 0.010615166376477905, 0.03180627810901829, 0.005506708195233452, 0.024214207460837703, 0.04480188612693122, 0.0565110188908875, 0.020601140800863504, 0.05399516031944326, 0.03191728304539408, 0.023282785833414112, 0.04888836666941643, 0.04811445676854678, 0.03406401178134339, 0.06303348086242165, 0.07181596995464393, 0.04399125391085233, 0.016075597211186374, 0.027665443518864255, 0.012720551125572195, 0.03188164299353957, 0.12176198272832803, 4.896979195731027, 26.704687356948853, 51.40967621122088, 48.000532150268555, 33.50161497933524, 21.167143310819352, 32.662984779902864, 24.2066901070731, 11.977016380855016, 5.482467412948608, 0.8387768172792026, 0.29191477596759796, 0.050388577061572244, 0.25601869927985327, 0.053596086733575375, 0.0780395135017378, 0.04223460817177381, 0.16551425999828748, 0.1833936713103737, 0.5337731008018766, 0.2663598172366619, 1.681669465133122, 1.109062990971974, 0.1108594856091908, 0.6135480286819595, 1.8548311676297868, 3.007433308022363, 3.037858383996146, 8.100098746163503, 14.097530160631452, 21.01956183569772, 26.36927001816886, 31.674263068607875, 36.5926114491054, 45.465672969818115, 48.19703068052019, 50.113458497183665, 49.29445001057216, 50.87410906382969, 50.182009424482075, 52.16747106824602, 53.15173898424421, 52.58207355226789, 51.63120215279715, 51.833134174346924, 51.08755772454398, 52.08384949820382, 51.65926592690604, 54.30387190410069, 52.147953578404014, 47.44305385862078, 35.20672375815255, 48.66685744694301, 53.87260069165911, 50.1016708782741, 48.93292828968593, 45.15959439958845, 40.91466195242745, 42.114883354731965, 41.63192796707153, 43.623354639325825, 43.12645769119263, 48.8095908164978, 48.29938806806292, 49.76796627044678, 51.49175875527518, 49.33499622344971, 49.635776792253765, 50.82080943243844, 49.59659590039934, 46.13561480385916, 44.51827219554356, 38.55104112625122, 33.99853277206421, 28.388682297297887, 20.531318868909562, 17.829072373253958, 13.366612672805786, 9.849394593920026, 4.5349519933973035, 2.967742374965123, 2.4227751834051947, 3.1013002140181403, 2.238075780017035, 0.8285043399248804, 0.729261536683355, 0.4366312048264912, 0.9653177899973733, 0.2798912168613502, 0.1271843867642539, 0.1339350366698844, 0.08372329601219722, 0.2590457797050476, 2.279497900179454, 10.660141672406878, 23.592735120228358, 36.61389030729021, 27.36329320498875, 26.33843912397112, 38.49059179850987, 28.68410406793867, 14.732982873916626, 1.8627438630376543, 0.15070876159838267, 0.046617354066776376, 0.06786823286009686, 0.04019277755703245, 0.05030096801263945, 0.0023538169875142296, 0.05073151205267225, 0.04963832089145269, 0.019289753133697168, 0.044115999181355746, 0.03126334831384676, 0.050334236584603786, 0.041703355964273214, 0.03917551785707474, 0.02914410024615271, 0.08439163264951535, 0.07195279654115438, 0.02141054656489619, 0.024645748947347914, 0.046208109240978956, 0.06728429240839821, 0.04584305400827101, 0.043329495670539994, 0.04271589306050113, 0.03598685449521456, 0.02626481662238283, 0.025805904729557887, 0.034995843922453265, 0.029318219117288078, 0.014361594005354812, 0.032206020051879544, 0.018579983451802815, 0.007780259791096407, 0.027470001684767858, 0.1658297652112586, 0.11320210061967373, 0.08885574167860405, 0.10787151594247137, 0.11487698288900511, 0.09845661864216838, 0.14575470957372869, 0.07370408185358558, 0.13933738321065903, 0.1129316704879914, 0.10299880669585296, 0.08233548155320541, 0.14687552728823253, 0.13692972383328847, 0.06811702451003449, 0.11161844738359962, 0.147622105798551, 0.12822943925857544, 0.07666962593793869, 0.15500263976199286, 0.13263338937291078, 0.0805513212191207, 0.15555703001362936, 0.1700640001467296, 0.05951052026024886, 0.10658617384199585, 0.1285816260746547, 0.1180296465754509, 0.10873758446957384, 0.13677435288471834, 0.23813957295247487, 0.12592731921800546, 0.20899629034101963, 0.10336293572826044, 0.11651070522410528, 0.09393166537795748, 0.1079146232722061, 0.14141512529126235, 0.302061208656856, 6.213813083512442, 31.473984718322754, 56.543630668095176, 55.538386140550884, 42.20737777437483, 29.17371756689889, 36.64578601292202, 30.92150912966047, 12.711491346359253, 6.42603234733854, 1.3419972232409885, 0.3010914464082037, 0.14368220578346932, 0.600180617400578, 0.21234663841979845, 0.2369277094091688, 0.30496878549456596, 0.4503741445285933, 0.7613451693739209, 1.0667800541434969, 2.7830145273889815, 2.312391540833882, 2.8382359870842526, 0.6286749084080968, 3.2204609513282776, 2.2352437376976013, 4.77870956489018, 5.955498601709094, 6.074667155742645, 14.084293842315674, 21.20847988128662, 25.354926824569702, 31.804291657039098, 39.13904632840838, 45.472430092947825, 50.84323821749006, 52.05799525124686, 52.46758460998535, 53.343585695539204, 53.63931492396763, 55.949927943093435, 54.88310500553676, 53.22441019330706, 54.341590200151714, 52.50004659380232, 53.11297845840454, 54.191286768232075, 53.85579994746617, 55.270369802202495, 52.61379902703421, 47.52239533833095, 40.64286579404558, 49.5670382635934, 56.03283384868077, 52.87922716140747, 51.59989356994629, 46.596961293901714, 42.91167150224958, 44.75573035648891, 43.2726651600429, 45.059877327510286, 47.020353249141145, 50.42379283905029, 50.68806757245745, 51.565982886723106, 54.3657351902553, 48.44160032272339, 49.07286500930786, 51.623513971056255, 49.22039610998971, 47.766832964760916, 46.01642887932913, 38.98020356042044, 35.273273604256765, 29.311177253723145, 20.012066091809952, 15.763572692871094, 11.067627464021955, 9.232214774404254, 5.286010571888514, 3.034164982182639, 3.1872665839535848, 3.5834689353193556, 2.64565862928118, 0.4805310091802052, 1.9970416852406092, 0.4251832334058625, 1.1936049801962716, 0.5324402408940452, 0.22923426223652704, 0.6083754205277988, 0.47217694031340735, 0.6028539368084499, 3.0256191321781705, 11.088847262518746, 28.22107263973781, 39.00421306065151, 33.103295598711284, 33.877661909375874, 44.53052534375872, 36.084159646715435, 16.388269594737462, 2.794973679951259, 0.1907705683261156, 0.10063854977488518, 0.15296824249838079, 0.11292374519897358, 0.16631529772920267, 0.08992671421063797, 0.1235804972904069, 0.20264973518039497, 0.10094397874282938, 0.09652341130588736, 0.1099633104833109, 0.1318043688578265, 0.08911358498569046, 0.20602313987910748, 0.15688302314707211, 0.12490038360868182, 0.08948314908359732, 0.16498640046588012, 0.07150182859706027, 0.060312881134450436, 0.17699466539280756, 0.16164920239576272, 0.12513093623731816, 0.12395196807171617, 0.16627671622804233, 0.15231224841305188, 0.14306145480700902, 0.11804150736757688, 0.13440914265811443, 0.11685716520462718, 0.12601295033735888, 0.12348618092281477, 0.11881069466471672, 0.13829077008579457], [0.06438422695334468, 0.034614883828908205, 0.024323941840391074, 0.02027962207128959, 0.037257387568908076, 0.031129286757537296, 0.06754583373133626, 0.12855158054402896, 0.04941067239269614, 0.10370947034763438, 0.011790578170413417, 0.11630600477967944, 0.04113407526165247, 0.03504373153139438, 0.04602094214143498, 0.09994019474834204, 0.04167552585048335, 0.06200923225177186, 0.046453114665512524, 0.03025707070316587, 0.04782318204109158, 0.016393287306917564, 0.049386095854320695, 0.03656534291803837, 0.00992309203970113, 0.07813140749931335, 0.030106242546545606, 0.028126750640305023, 0.012709088972769678, 0.04016086266243032, 0.035375212851379595, 0.03578101411195738, 0.03735929674335888, 0.025642606795632412, 0.033674960157700946, 0.04489304730668664, 0.04016431640567524, 0.06989713399005787, 0.031056381562458615, 0.45789155257599695, 9.959652083260671, 32.33003405162266, 40.619651862553184, 36.51419060570853, 25.950889451163157, 22.792801175798687, 25.09257674217224, 17.640444414956228, 8.009678363800049, 2.8129973070962087, 0.44538756353514536, 0.030360367481729815, 0.19052963411169394, 0.022144558606669307, 0.06397773697972298, 0.058350150739508014, 0.10102997627109289, 0.08576825128069945, 0.5890307128429413, 0.6483409702777863, 2.139771580696106, 0.38837582990527153, 0.30829433990376337, 0.38816238992980545, 0.08995043579488993, 0.7866210330809865, 0.9643116039889199, 2.0559556782245636, 5.941341647080012, 10.812042321477618, 16.670286553246633, 20.755915914263042, 24.58126401901245, 34.167485169001985, 40.66977964128767, 42.67704125813076, 46.26394803183419, 50.100406306130544, 52.136370931352886, 50.84707014901297, 49.787713050842285, 50.49946914400373, 50.168818269457134, 52.90402528217861, 51.632560525621685, 51.44390651157924, 52.92152432032994, 51.87900965554373, 51.77944196973528, 50.08753476824079, 31.71693890435355, 47.86344766616821, 50.61005319867815, 47.94386959075928, 48.049874782562256, 44.79643290383475, 42.511556012289866, 41.75073174067906, 41.53991297313145, 43.581693240574424, 43.298550673893516, 45.040189606802805, 46.463333538600374, 47.957957063402446, 49.34604038511004, 51.62756129673549, 47.04923691068377, 46.93956307002476, 44.78012548174177, 41.66658558164324, 32.11170080729893, 28.25261398724147, 22.598465272358485, 17.99940746171134, 11.330093928745814, 8.687925032206945, 6.200696621622358, 2.788367028747286, 2.616523095539638, 1.7090716404574258, 0.8690441474318504, 2.8972730934619904, 0.6945743379848344, 1.3770571819373538, 0.4182437743459429, 0.13373208684580667, 0.456802531012467, 0.16250168665179185, 0.08015860550637756, 0.06003949937543698, 0.2979000248014927, 1.1914762258529663, 3.9886186122894287, 10.042248794010707, 27.226387637002126, 23.689619064331055, 24.413894074303762, 30.47622687476022, 27.132882254464285, 18.272528988974436, 5.370726917471204, 0.3011110967823437, 0.07586786217455353, 0.018560260135148252, 0.049919895960816314, 0.05647899882335748, 0.05516667477786541, 0.08946186344006232, 0.06979726042066302, 0.017480670208377496, 0.012012403142372412, 0.0442066887792732, 0.0628495571602668, 0.026560420403257012, 0.02835749156240906, 0.009935814571300787, 0.05921089955206428, 0.06435928400605917, 0.01496673358737358, 0.06835451176656143, 0.030723821371793747, 0.0550080875733069, 0.033006514954779825, 0.02165543663847659, 0.03541178249620965, 0.07083302377057926, 0.026591821307582513, 0.054679330571421554, 0.03441782029611724, 0.07925637784813132, 0.022896305857492343, 0.060802159165697436, 0.05323661245139582, 0.06953464701239552, 0.02529485590223755, 0.0218958297212209, 0.05671057264719691, 0.03003652985872967, 0.01765972202909844, 0.028395979765004346, 0.014702598564326763, 0.015828888663755994, 0.031891037310872755, 0.05061934342873948, 0.06615782928253923, 0.022356280192200626, 0.05682313821411558, 0.11579860986343452, 0.0340178714000753, 0.032224805293870826, 0.0690784068512065, 0.05989681703171559, 0.006288908097693431, 0.04012682395321982, 0.018220212310552597, 0.07917160846825157, 0.03137024811335972, 0.0630561439320445, 0.0158490682952106, 0.03157538282019751, 0.05373585816206677, 0.02457507952515568, 0.024303097244618193, 0.0682475542915719, 0.037567688418286185, 0.03364682809582778, 0.05209582545129316, 0.05426408749605928, 0.027115122781002095, 0.02909417703215565, 0.08216267904000622, 0.06342496164143085, 0.058052572421729565, 0.046812721262020726, 0.014263365883380175, 0.7560572102665901, 12.608658007213048, 37.27446944372994, 48.21524885722569, 40.33322627203805, 27.15680663926261, 25.222794669015066, 30.310227462223597, 16.70258525439671, 8.975784557206289, 3.1040996866566792, 0.5560665045465741, 0.032869742651070864, 0.04487434348889759, 0.012843359178597373, 0.12852483269359383, 0.03913477522187999, 0.4807083510926792, 0.1384592910430261, 0.3060438835195133, 1.4831009145293916, 3.79421409538814, 0.38437377608248163, 0.6778850906661579, 1.1360809526273181, 1.8626617874417986, 3.0502335599490573, 2.765714381422315, 4.9361826692308695, 6.302604113306318, 14.542933140482221, 16.876052243368967, 24.498898335865565, 27.974858011518204, 36.788474219185964, 41.94588232040405, 47.12773418426514, 49.51519080570766, 52.64034809385027, 52.909903458186555, 53.952623094831196, 51.49661207199097, 52.83385195050921, 52.358365876334055, 54.40684420721871, 52.15996353966849, 54.477448327200754, 53.71779135295323, 52.88293749945504, 51.72335263660976, 48.49465329306466, 35.16067804609026, 48.19329949787685, 52.39157479149954, 50.23342261995588, 48.599928924015586, 45.895530223846436, 44.04945291791643, 44.07346589224679, 44.446014404296875, 45.03803219114031, 45.09739759990147, 46.39732912608555, 48.13153348650251, 49.75874253681728, 49.74861206327166, 52.231109619140625, 47.08743463243757, 47.76477629797799, 46.00072247641427, 41.81736843926566, 34.965200901031494, 28.87844865662711, 25.925233227866038, 19.163140399115427, 14.121806297983442, 11.19140180519649, 7.280267766543797, 4.426495390278952, 4.434467579637255, 3.886001535824367, 3.709534662110465, 3.493867354733603, 2.9922862350940704, 1.4714934059551783, 1.316069368805204, 1.3217065291745322, 0.8556237018534115, 0.2558610348829201, 0.20195986862693513, 0.07910935288029057, 0.242524049111775, 0.9386295420782906, 5.903012343815394, 11.979428274290902, 30.49495574406215, 33.44663735798427, 27.117464201790945, 35.41438109534127, 33.39277492250715, 23.292499985013688, 6.570357288633074, 0.37680868059396744, 0.03280735814145633, 0.024254982326445833, 0.02805705152318946, 0.025224495213478804, 0.029287691826799085, 0.08699522579887084, 0.03869033478466528, 0.02720878945131387, 0.04354725791407483, 0.037075699639639685, 0.08328856541109936, 0.006816128959014479, 0.049763592026595554, 0.03983610223180481, 0.07704618573188782, 0.021900828827970793, 0.022183799983135292, 0.03566706094092556, 0.003882183402311057, 0.024611294635438492, 0.02206034053649221, 0.05863549507090023, 0.02678090357221663, 0.013048949352066432, 0.04528440934206758, 0.03860688176272171, 0.030879864070032324, 0.01838456536643207, 0.05470754066482186, 0.037584807856806686, 0.05765911710581609, 0.040890304770852835, 0.03446689873401608, 0.0037840091390535235, 0.1303233304726226, 0.10034602654299565, 0.15690181856708868, 0.13345954647021635, 0.08005478964852435, 0.09022292867302895, 0.1711646518004792, 0.2877490594983101, 0.128986317930477, 0.1256048793771437, 0.16229804472199508, 0.21238146083695547, 0.09617602173238993, 0.14290666739855493, 0.16006429386990412, 0.12534354840006146, 0.10111529526433774, 0.31278103057827267, 0.13504510638969286, 0.14224015602043696, 0.10746348569435732, 0.13192081903772696, 0.12153799831867218, 0.12162167525717191, 0.08656255794422966, 0.17213564898286546, 0.1341082938015461, 0.10409352795353957, 0.1200274300894567, 0.06100979766675404, 0.14220993407070637, 0.11529637181333133, 0.21492640141929897, 0.13226776756346226, 0.17359722698373453, 0.10568925911294562, 0.11117915024182626, 0.19193665789706366, 0.15260449344558374, 1.3326230176857539, 15.753179924828665, 43.11708804539272, 55.543284620557515, 46.68602677753994, 35.7423916544233, 31.631361416407994, 37.69809068952288, 25.637987749917166, 10.456366641180855, 3.952758959361485, 0.8914694583841732, 0.24244726608906472, 0.3806530428784234, 0.19366027255143436, 0.2743545610989843, 0.22529035886483534, 0.6065707345093999, 0.35927167162299156, 0.59927214043481, 1.788326810513224, 3.338342785835266, 1.5547697373798914, 0.9362581436123166, 3.3522063962050845, 1.4671509989670344, 1.9493129892008645, 3.334754909787859, 4.202894977160862, 9.367616057395935, 13.656727756772723, 20.353175742285593, 25.252268927437918, 28.370926175798687, 38.22319732393537, 43.83133854184832, 48.92327029364449, 50.94042614528111, 53.40497650418963, 54.17441306795393, 53.76579645701817, 51.281405517033164, 53.06729752676827, 52.680981159210205, 56.56094905308315, 54.57732173374721, 55.2287848336356, 55.415694849831716, 53.493718896593364, 51.94109875815255, 50.88885314123971, 39.2545462335859, 49.53547607149397, 52.773850781576975, 52.32849209649222, 50.24821533475603, 48.66118424279349, 47.04113531112671, 46.013385568346294, 46.47590977805001, 46.40786954334804, 46.462451117379324, 47.901787825993125, 48.464414732796804, 51.587918349674766, 51.72351244517735, 52.42638874053955, 47.47192014966692, 47.47623150689261, 45.74755791255406, 42.38110358374459, 35.813339710235596, 30.542992115020752, 25.622456789016724, 20.04627902167184, 14.51805077280317, 10.932369487626211, 7.419409785951887, 4.705273619719914, 5.704314708709717, 3.4834302919251576, 3.810811604772295, 5.8174517921039035, 5.640155042920794, 3.4247418982642035, 0.8509700915643147, 1.4944310379879815, 1.5682826808520725, 0.6942895161254066, 0.41407482804996626, 0.2227602374872991, 0.5566478733505521, 1.6032649065767015, 5.556021477494921, 14.23091733455658, 37.393446922302246, 34.20633602142334, 32.03255387714931, 40.73821939740862, 42.30520493643624, 28.949176107134136, 8.414289338248116, 0.5842820533684322, 0.24757742509245872, 0.14646907124136174, 0.21755044561411652, 0.09378312049167496, 0.09946131187358073, 0.2629841598016875, 0.15898775735071727, 0.0997893496283463, 0.11364149954169989, 0.18504754613552774, 0.13899669077779564, 0.1511246357113123, 0.14744171047849314, 0.05766799234386001, 0.24579480503286633, 0.19826787816626684, 0.11997645853885583, 0.1156731623091868, 0.11978139329169478, 0.12125176510640553, 0.08597114682197571, 0.08092395908066205, 0.0970257714922939, 0.12067275760429245, 0.14819519647530147, 0.14760402962565422, 0.1302268292222704, 0.10199030009763581, 0.12106467943106379, 0.12822159539375985, 0.16217202719833168, 0.205215506787811, 0.17772886742438587, 0.06540231446602515], [0.03370753662394626, 0.06412933527358941, 0.09868755803576537, 0.016971767248053635, 0.049371595560972176, 0.04623931845916169, 0.03982925242079156, 0.0449018546912287, 0.025635215852941786, 0.022651610862729803, 0.020438331412151456, 0.041737052013299296, 0.03617052035406232, 0.09627017525157758, 0.020652794279158115, 0.05214095820805856, 0.03582125123856323, 0.019513259176164865, 0.06032352056354284, 0.037585554245327196, 0.06879685553056852, 0.0385789227272783, 0.04080457187124661, 0.026087400071056824, 0.03250189185408609, 0.02696378911579294, 0.020901299248050367, 0.003895247745926359, 0.018142828784350837, 0.014652295370719262, 0.029421811058585132, 0.09356764491115298, 0.0631107185035944, 0.0055520657167237785, 0.06660623236426286, 0.044771267234214714, 0.07836820265012127, 0.014160664519295096, 0.03150454376425062, 0.07235600919063602, 2.668390963758741, 21.33841814313616, 41.05109330586025, 40.63243654796055, 25.6954128742218, 16.830098594938004, 23.504882097244263, 28.319643259048462, 21.039887053625925, 8.37537247794015, 3.060066346611295, 0.5357281501804079, 0.15072036454720156, 0.03868634839143072, 0.0670106460207275, 0.11726523616484233, 0.22639251686632633, 0.2429848558136395, 1.163222570504461, 0.7933824988348144, 2.668920112507684, 0.7849151960441044, 0.15637599463973725, 0.41379901713558603, 2.5814186249460493, 3.537007199866431, 0.3938029972570283, 3.2141828196389333, 1.38430469589574, 5.283329001494816, 6.375506349972316, 14.377169966697693, 16.322567428861344, 22.379452841622488, 31.47458573750087, 36.432844570704866, 39.271857670375276, 45.38925668171474, 46.04065029961722, 50.13639102663313, 49.67101458140782, 50.62588119506836, 51.65216834204537, 51.99050045013428, 49.349531854902, 53.142445768628804, 51.62088407788958, 52.594104358128135, 51.17296845572335, 50.84342929295131, 34.47001320975167, 47.51109756742205, 50.77523272378104, 49.62380157198225, 47.99927452632359, 47.73768179757254, 45.236156599862234, 45.70267602375576, 44.648147923605784, 45.37865720476423, 44.68607813971383, 47.96637480599539, 48.024010113307405, 47.656325340270996, 51.994082246507915, 48.509015219552175, 47.96645123617989, 47.14685910088675, 36.84238876615252, 32.00452136993408, 26.003591537475586, 18.18906201635088, 13.425068736076355, 9.174966829163687, 4.3921478390693665, 3.289418999637876, 2.627063947064536, 3.2681145199707577, 2.428717847381319, 5.588126063346863, 3.3694672414234708, 4.2708761521748135, 2.4573405172143663, 2.088189022881644, 2.126956496919904, 1.7786430844238825, 0.6880905830434391, 0.48633199504443575, 0.09311525882886988, 0.21089973034603254, 0.42049254796334673, 3.810213625431061, 5.614560919148581, 20.40853030341012, 20.728560856410436, 14.612577540533882, 30.248781067984446, 36.087400981358115, 27.736951691763743, 10.312109010560171, 1.0499381635870253, 0.05208151514774986, 0.05006274454561727, 0.05713602088923965, 0.02714252032871757, 0.008054290399221438, 0.044738982538027425, 0.07632043824664184, 0.0313149339386395, 0.06231606578720467, 0.015527956686647875, 0.04196134176371353, 0.08646752911486796, 0.0635088285697358, 0.06109023120786462, 0.039417402020522525, 0.040913839757974656, 0.028204329245324646, 0.026970728832696165, 0.033937760163098574, 0.03640193472217236, 0.006757588350280587, 0.01919338759034872, 0.03796186637399452, 0.039390745772314925, 0.04971318366006017, 0.027485964221081564, 0.05409318148823721, 0.024338258929284554, 0.06620204940970455, 0.019615473691374063, 0.07849593008203165, 0.09332702960819006, 0.06525188325239079, 0.032820470830691714, 0.04612524654450161, 0.06506072636693716, 0.103570899926126, 0.04273014229589275, 0.006817715458704957, 0.02365738126848425, 0.06339000351727009, 0.015059484235410179, 0.034545293277395625, 0.08694734836795501, 0.00957958453467914, 0.047791575879922936, 0.02793928498535284, 0.031383411692721505, 0.043127658643892834, 0.034950812945940664, 0.013005303435160645, 0.011624326912819274, 0.017404913469882946, 0.03788389930767672, 0.03918781630428774, 0.1098384125424283, 0.09361586160957813, 0.048376615558351786, 0.023697282520255873, 0.04821211492110576, 0.02155447910938944, 0.04777745217350977, 0.04782234065766845, 0.035692753669406684, 0.015449825075588055, 0.06897170043417386, 0.09279493601726634, 0.04145558890221374, 0.09676355163433722, 0.015954909580094472, 0.029110563652856008, 0.021928640282047645, 0.007575668760442308, 0.012072171051321285, 0.0893079988392336, 3.891059390136174, 25.147311176572526, 46.52594028200422, 45.020345551627024, 27.974772896085465, 21.58086337362017, 28.37511420249939, 35.028992312295095, 20.089790378298076, 8.61851600238255, 3.051038899591991, 0.5907672196626663, 0.0709242799452373, 0.07715488704187529, 0.17695696598717145, 0.19647256950182573, 0.3762197121977806, 1.0500909153904234, 0.4449827495430197, 3.4312899240425656, 2.8181357170854295, 1.9734801266874586, 0.8560570957405227, 1.6431305216891425, 6.373964718409947, 7.697440215519496, 2.2716227684702193, 6.3301059518541605, 3.4388517354215895, 5.753648655755179, 10.7839629139219, 17.144737345831736, 21.29230294908796, 26.84265078817095, 34.7595967565264, 37.309735025678364, 41.83513150896345, 47.60998780386788, 49.78794581549508, 49.33552428654262, 50.66079936708723, 50.908471379961284, 53.00918626785278, 53.17883348464966, 51.43084042412894, 53.90991946629116, 52.076696327754426, 53.90953731536865, 51.566747188568115, 50.437925474984304, 37.28934553691319, 48.199879441942485, 51.27053853443691, 51.44776276179722, 50.070007937295095, 49.11857373373849, 45.804126671382356, 48.13439267022269, 47.417755467551096, 46.56396082469395, 46.91421604156494, 49.17793219430106, 49.46392004830496, 48.94557053702218, 52.64979764393398, 51.72728531701224, 47.5458733013698, 47.797985213143484, 38.087905475071494, 33.98411178588867, 28.247529642922537, 22.644625629697526, 18.88726043701172, 10.515180536678859, 6.787905386516026, 5.436573258468083, 4.053744077682495, 4.752402816499982, 4.315682479313441, 7.956163338252476, 6.137353803430285, 2.802775638444083, 4.485605887004307, 3.3179448289530615, 3.1909899498735155, 1.8310824419770921, 0.6545573824218341, 0.5444992195282663, 0.06710378852273736, 0.15479873998888902, 0.33758498675056864, 3.869483930724008, 7.332081351961408, 20.127545152391704, 28.46321736063276, 18.460034813199723, 32.19497496741158, 40.42611673900059, 33.93622827529907, 12.59537044593266, 1.2564944284302848, 0.09973270552498953, 0.04114894535658615, 0.06756768255893673, 0.06801599064575774, 0.02445019345863589, 0.016508943600846187, 0.08229961419211966, 0.0663265809416771, 0.02793299326939242, 0.027931929665750692, 0.039762613496610096, 0.04869908932596445, 0.014192597225441464, 0.042165882752410004, 0.010562216048128903, 0.05585898405739239, 0.02195819726745997, 0.0062470204346547166, 0.06068513223103114, 0.032986857795289586, 0.0436532009792115, 0.01876107935926744, 0.03580219458256449, 0.021132184358845865, 0.03415872848459652, 0.040848289882498126, 0.040936848880457025, 0.06848968951297657, 0.023173231265640686, 0.01730265824257263, 0.022548724597852145, 0.008123956437754844, 0.004695764701214752, 0.005601536008595888, 0.035915832234812636, 0.12042612369571414, 0.11388036422431469, 0.2002304457128048, 0.10149604161935193, 0.1846585012972355, 0.12505605311266013, 0.07349225679146391, 0.09601961941059146, 0.09275953005999327, 0.06603721289762429, 0.16108871889965876, 0.07135453900056225, 0.1461114018623318, 0.21085068583488464, 0.072811957581767, 0.09386421221175364, 0.10645010721470628, 0.1267376664493765, 0.17238658480346203, 0.06261388837758984, 0.209438098062362, 0.16398740692862443, 0.1268197556159326, 0.1146725131464856, 0.16612272949091025, 0.08608799733753715, 0.1848738683121545, 0.06545081614915814, 0.10860415734350681, 0.037114630586334636, 0.13343906828335353, 0.25529939787728445, 0.15539613579000744, 0.193888287459101, 0.2063154120530401, 0.16081155091524124, 0.19942863445196832, 0.17443291071270192, 0.10381705207484108, 0.2485919435109411, 5.0621461272239685, 28.810783624649048, 54.26432623182024, 53.57745163781302, 35.64948729106358, 25.709642784936086, 33.818056787763325, 36.72144147327968, 25.02353422982352, 10.78984977517809, 4.126229422433036, 0.917251563497952, 0.39630909849490437, 0.20011248918516295, 0.2621939107775688, 0.31937677093914574, 0.6469066558139664, 0.6525410477604184, 2.5511652997561862, 5.9257121086120605, 10.248308045523506, 2.2356829941272736, 0.37260496616363525, 2.0729242648397173, 8.04067862033844, 5.861687932695661, 1.9439346492290497, 6.429059590612139, 3.3908844121864865, 7.070844718388148, 8.449957047189985, 18.312026023864746, 21.654818262372697, 26.330082178115845, 35.96269818714687, 37.06850746699742, 41.32011365890503, 49.228740896497456, 49.102169036865234, 50.32700095857893, 50.14810916355678, 51.52638510295323, 54.55330875941685, 54.34904561723982, 51.79733010700771, 55.59756394795009, 53.610736983163015, 55.4989446912493, 53.08575889042446, 50.39438458851406, 41.37207228796822, 49.40518692561558, 52.27426488058907, 54.82250281742641, 51.77268484660557, 52.01523951121739, 47.89497511727469, 51.2621624810355, 48.60258660997663, 49.447946139744346, 48.4286766733442, 51.08202001026699, 50.26821572440011, 51.38682358605521, 55.59041772569929, 51.46250336510794, 50.24400820050921, 49.120109285627095, 39.49421044758388, 35.202186584472656, 28.615242208753312, 22.198130914143153, 16.89329593522208, 11.87002454485212, 6.020459915910449, 5.268696963787079, 4.684337828840528, 7.145398889269147, 7.732358387538365, 8.74035005910056, 9.287077750478472, 10.352492809295654, 8.83692741394043, 6.258278948920114, 8.188987919262477, 7.148338411535535, 1.9549073747226169, 1.3446293962853295, 0.5294082750167165, 0.4559371545910835, 0.7790905971612249, 4.758778657232012, 9.107106379100255, 27.492618288312638, 28.064086777823313, 23.195147037506104, 40.77252265385219, 49.03014401027134, 42.820191519601, 17.037941796439036, 1.961111681801932, 0.1559210369097335, 0.16420430743268558, 0.14688409040016787, 0.09725890255400113, 0.27591074045215336, 0.10324611913944994, 0.12717692287904875, 0.13175404870084353, 0.12193395064345428, 0.0781128088544522, 0.1527198851108551, 0.1568816253649337, 0.07900557773453848, 0.2305797157543046, 0.1756912674754858, 0.14536343914057526, 0.15418180237923348, 0.1221581928964172, 0.16689746720450266, 0.08631191389369113, 0.2034043882574354, 0.07715425600430795, 0.19052219736788953, 0.12519835547677108, 0.10671033217970814, 0.10991054081491061, 0.16284708811768464, 0.11922156118920871, 0.09592834966523306, 0.06202815659344196, 0.1535097812967641, 0.3622586099164826, 0.158879354596138, 0.09625954260783535, 0.11389480344951153], [0.05528103167723332, 0.011638616012143237, 0.07471589291734354, 0.026029125787317753, 0.035402530671230385, 0.04532402900180646, 0.03198458693389382, 0.07423377343054328, 0.01577574240842036, 0.07245844083705119, 0.0244561645668, 0.016005753905379345, 0.038524358333753686, 0.021809262223541737, 0.02453082038222679, 0.0821459260103958, 0.029756454351757253, 0.08088708748774869, 0.022231801246692027, 0.03324420237913728, 0.05922302497284753, 0.023739548466567482, 0.052928527018853595, 0.01066393862544958, 0.02148985373787582, 0.01132102684849607, 0.03063562878274492, 0.06558321190199681, 0.007710907575009125, 0.038966376400951824, 0.028754091888133968, 0.05769457056054047, 0.043170928822032044, 0.04772908280470541, 0.009421712336396533, 0.015608809223132474, 0.02438045193308166, 0.0596276286191174, 0.021958656974935105, 0.02826602164922016, 0.5235990924494607, 8.289731587682452, 28.707349266324723, 45.18271105630057, 30.45800174985613, 21.788263627461024, 16.417278323854717, 18.266940900257655, 29.077769892556326, 15.5834093775068, 7.719776936939784, 2.0812173741204396, 0.3270266018807888, 0.07183023276073591, 0.3474277885896819, 0.1857843944536788, 0.4772244808929307, 1.2464052098137992, 0.22572669759392738, 2.870563566684723, 2.16937546644892, 1.683726349047252, 1.001978331378528, 0.37962384096213747, 4.636769592761993, 12.183392643928528, 2.9683197268417905, 3.9223831721714566, 1.1020212088312422, 2.33629356111799, 2.5529414330210005, 5.827968759196145, 11.644831691469465, 15.256913525717598, 18.80858772141593, 28.374330793108257, 31.857942172459193, 37.493285587855745, 42.427156244005474, 48.50875466210501, 51.536758763449534, 52.25790187290737, 52.185060432979036, 52.95633132117135, 53.175220421382356, 51.82519585745675, 52.62450967516218, 51.498258795057026, 51.80362170083182, 50.31659255708967, 36.73735979625157, 49.11134760720389, 53.164766856602256, 50.99771056856428, 49.67103542600359, 46.63638537270682, 45.02333327702114, 46.99178573063442, 47.323624747140066, 46.91145065852574, 48.303869656154085, 48.4873229435512, 48.9029780796596, 48.413908277239116, 50.90530300140381, 45.869880948747905, 44.11714921678816, 39.270082405635286, 32.28163290023804, 23.524524654660905, 17.033091953822545, 14.153166992323738, 10.197686076164246, 2.3654588418347493, 2.1905479303428104, 1.9549950957298279, 1.7780688809497016, 1.763516964656966, 3.1896178977830068, 10.73391764504569, 4.6446497184889655, 1.8822083728654044, 4.716608302933829, 2.1929858795234134, 2.551033283982958, 0.4504591513957296, 0.21794315454150948, 0.2298603600689343, 0.14899589493870735, 0.3629115777356284, 2.663275135414941, 6.178501469748361, 15.494392531258718, 26.207978010177612, 16.09841159411839, 30.07479817526681, 31.40517670767648, 31.22257457460676, 14.685896669115339, 3.6209590264729092, 0.06980978617710726, 0.07173270692250558, 0.029514980701995746, 0.02412689187830048, 0.03970441554806062, 0.022984878426151614, 0.013896850952213364, 0.04338987510917442, 0.01939672926839973, 0.02869121204795582, 0.05876915968422379, 0.011921852644133781, 0.05017608364245721, 0.0523653972361769, 0.11839864748929228, 0.022699293214827776, 0.1067374125123024, 0.03839952824637294, 0.06535240143005337, 0.055202151981315443, 0.04615860671869346, 0.027633135073951313, 0.04170174105092883, 0.054402288115982494, 0.023980677759807025, 0.0622655488550663, 0.02322276432200202, 0.01939010337394263, 0.10052759572863579, 0.04163012846506067, 0.04433591916624989, 0.036206411463873725, 0.022205190799598182, 0.01185868273023516, 0.04243309662810393, 0.053193444053509405, 0.04462691569434745, 0.0191058684473059, 0.039181068273527284, 0.0745065648640905, 0.015270167662362968, 0.0328161078505218, 0.03859051210539682, 0.01854288624599576, 0.024555948230304887, 0.05628310576347368, 0.023440480764423097, 0.017833545737500702, 0.0006645441036588246, 0.03423169135515179, 0.0361139508895576, 0.011413081149969782, 0.018918998206832578, 0.05414043805961098, 0.040420409092413526, 0.03518684474485261, 0.07721689157187939, 0.07054128085396119, 0.03737732202612928, 0.07366956477718693, 0.042120125743427446, 0.031202439617897784, 0.03684906215806093, 0.014869928692600556, 0.01790845430722194, 0.036265678105077574, 0.02480282132247729, 0.018391751052279557, 0.019608070874320607, 0.008536623624552573, 0.04176813909517867, 0.017102661742163554, 0.07055812209312405, 0.01367848735701825, 0.03270877039592181, 0.06429864333144256, 0.6670752135770661, 10.317727497645787, 34.42207063947405, 51.03538717542376, 34.14515365873064, 18.659467220306396, 17.713226795196533, 21.970740692956106, 38.588860171181814, 19.513023887361797, 9.304477776799883, 2.544139151062284, 0.18503560391919954, 0.04141772664817316, 0.31328781481300083, 0.14654858197484696, 0.4805786151971136, 0.42648045665451456, 1.339295785341944, 2.8410163521766663, 3.113355338573456, 2.9043396285602023, 2.4840856535094122, 3.9377326113837103, 9.755736351013184, 10.835383926119123, 4.7940429363931925, 5.004577696323395, 3.1254899331501553, 3.1752055968557085, 3.8273874010358537, 8.662928019251142, 14.83619315283639, 18.76140250478472, 22.209697927747452, 31.37763057436262, 33.96579286030361, 39.95385462897164, 44.09391096660069, 49.668329102652415, 52.60963010787964, 52.56650263922555, 53.85156849452427, 54.44085563932146, 54.80974245071411, 53.530335903167725, 53.16691732406616, 52.929764883858816, 52.279128619602744, 50.635344641549246, 39.74419273648943, 49.27808700289045, 53.97073357445853, 51.81512791769845, 53.06693969454084, 49.154905864170615, 46.603384903499055, 47.969894068581716, 48.56911366326468, 48.590934480939595, 50.411925315856934, 50.826201234545024, 50.1235785484314, 49.78871011734009, 51.07095847811018, 48.12467908859253, 45.608621733529226, 41.592826979500906, 35.23866810117449, 24.960482801709855, 20.155586344855173, 16.519882372447423, 12.199019142559596, 4.235902394567217, 5.076591866356986, 4.3690628835133145, 3.2537185038839067, 5.1306193215506415, 5.844484192984445, 6.11925287757601, 7.040874532290867, 3.3021007648536136, 3.604636622326715, 2.2014870004994527, 2.3682322587285722, 1.926465358052935, 0.10578899018998657, 0.17411560059658118, 0.03535453788936138, 0.32631498149463106, 2.111829834324973, 8.852293355124337, 15.53489705494472, 28.353696380342754, 19.745831966400146, 26.442641258239746, 36.74654531478882, 38.2277067048209, 19.781510966164724, 4.727842237268176, 0.1731854240809168, 0.009021217219664581, 0.04867550005604114, 0.06065907648631504, 0.04511394777468272, 0.02401454683526286, 0.030265542212873697, 0.03054096975496837, 0.009191443844299232, 0.026831118556271707, 0.05292477472020047, 0.03624823296974812, 0.07499088958970138, 0.004621219995897263, 0.04425855938877378, 0.03014316502958536, 0.06725675745734147, 0.01786667520978621, 0.05070809920185378, 0.06328172289899417, 0.07664161601236888, 0.010448862532419818, 0.019214218615421226, 0.012948362472733217, 0.03037658446867551, 0.07715210504829884, 0.03593168281284826, 0.07905012355851275, 0.06407864870769636, 0.04022893329550113, 0.011472649739256926, 0.028417304424302917, 0.05842534599027463, 0.027520589863083193, 0.03663841435419662, 0.03298166700239692, 0.10560704102473599, 0.060043923423758576, 0.14548861528081553, 0.09358664389167513, 0.08339339907148055, 0.1610064126018967, 0.11982643444623266, 0.20419100033385412, 0.08236084519220249, 0.14290080485599382, 0.0905488697545869, 0.09220350453896181, 0.10115395818970033, 0.10134991231773581, 0.1189639757254294, 0.22130163146981172, 0.10103330787803445, 0.24564031617982046, 0.09286135102489165, 0.06722939214003937, 0.17405531954552445, 0.0913267151585647, 0.08771757382367339, 0.14884412022573607, 0.12866273815078394, 0.10519801333014454, 0.08444096893072128, 0.12097748768116746, 0.09870643487998418, 0.09018892728324447, 0.04784908850810357, 0.08331134383167539, 0.11388435401022434, 0.15998463385871478, 0.12174717709422112, 0.2014210575393268, 0.16269482485949993, 0.12143182115895407, 0.07109981695456163, 0.1281523441097566, 1.1473231379474913, 13.150149362427847, 38.912548950740266, 58.56646319798061, 40.58773531232561, 29.598127433231898, 25.706285067967006, 29.286191531590053, 39.052711486816406, 21.329642568315776, 9.983328069959368, 3.1713845218930925, 0.7842826928411211, 0.1677084115466901, 0.7340416258999279, 0.41568694583007265, 1.7512836839471544, 3.262065678834915, 2.4861774955477034, 9.302001612527029, 8.04494481427329, 8.059998086520604, 3.1088937265532355, 4.693023945604052, 14.398553047861371, 21.121750729424612, 8.071861267089844, 7.991444553647723, 2.755093191351209, 4.108709973948343, 3.86570280790329, 9.001644015312195, 16.311179331370763, 18.944900955472672, 21.05736003603254, 32.19958857127598, 33.63808454786028, 40.298221247536794, 44.77627617972237, 50.777358872549875, 53.42253460202898, 54.98365933554513, 54.51479489462716, 56.01867689405169, 56.306644984654014, 54.87652506147112, 53.61446121760777, 53.80844797406878, 53.44869109562465, 52.19236298969814, 43.343331813812256, 50.838575976235525, 54.3092428616115, 54.29220240456717, 54.07027694157192, 50.93324865613665, 48.37337596075875, 50.5863424709865, 51.10745736530849, 50.64711488996233, 52.25153037479946, 53.132301398685996, 52.27560240881783, 51.90304694856916, 51.310699122292654, 48.64049250738961, 46.53191920689174, 43.08005067280361, 34.653080872126985, 25.886729785374232, 18.668268850871495, 18.397700786590576, 12.197887454714094, 3.379070954663413, 4.259522795677185, 4.017262560980661, 6.366167536803654, 6.6611628617559155, 10.209113257271902, 20.340538706098283, 13.226436240332466, 6.513927493776594, 8.963572229657855, 8.99511010306222, 7.5308458634785245, 2.088917063815253, 1.518508608852114, 1.0253746530839374, 0.3764536982136113, 0.702609658241272, 3.2610933652945926, 8.767924853733607, 21.512001514434814, 32.72411503110613, 23.71305012702942, 39.48590040206909, 42.9573107446943, 46.455454281398225, 25.570301873343332, 6.616475522518158, 0.30230865680745667, 0.11712924417640481, 0.1348976878715413, 0.0933846915140748, 0.11692097463778087, 0.12106438087565558, 0.14977972502154963, 0.15998163473393234, 0.16032045441014425, 0.1619806531816721, 0.10918216061379228, 0.11246353560792548, 0.16558927882994923, 0.15447354529585156, 0.1708673448967082, 0.10925416674997125, 0.19136355364961283, 0.11955469474196434, 0.19865353032946587, 0.15932631918362208, 0.16408464099679673, 0.15163490761603626, 0.09735980749662433, 0.22638353306267942, 0.126336204420243, 0.178130641579628, 0.12785511863018784, 0.1327486996139799, 0.22988025471568108, 0.09612615619386945, 0.2298209507550512, 0.10823267977684736, 0.17331055950905594, 0.13503697754016944, 0.14724325255623885, 0.13692228708948406], [0.03835268558136054, 0.03257394888039146, 0.04671407923368471, 0.05106248786406858, 0.01891311870089599, 0.01903804887219199, 0.013656888739205897, 0.0260007867722639, 0.022100513202271292, 0.034224027302116156, 0.056671163333313804, 0.04129306958722217, 0.04773052129894495, 0.06054567971399852, 0.05794123161051955, 0.07227796409279108, 0.04037961217441729, 0.0482803721513067, 0.06306137543703828, 0.06676944039229836, 0.010206821457748967, 0.01668570875855429, 0.07330975122749805, 0.048480197321623564, 0.043202073579388, 0.06733879912644625, 0.010671936856981899, 0.01496563944965601, 0.12081539923591272, 0.05705206575138228, 0.031368782477719445, 0.01067458653622972, 0.05814273615500756, 0.030002094206533263, 0.06778111574905259, 0.0528728464352233, 0.03331907193309494, 0.019442623680723563, 0.03281736992565649, 0.04396537119256599, 0.04939565980540855, 2.1537858801228658, 17.030946697507584, 34.83569342749459, 43.19489049911499, 40.71677030835833, 26.65005193437849, 27.41636007172721, 19.167710576738628, 17.213470663343156, 11.177721670695714, 5.6418421523911615, 2.1953087491648535, 0.3744575296129499, 0.22018238795655115, 0.37596976703831125, 0.5799823126622609, 0.6439303840909685, 0.6177871354988643, 1.4932609179190226, 0.7069183556096894, 1.4393021847520555, 2.2944297960826328, 4.659253963402339, 8.049721700804573, 11.819042137690953, 2.034642730440412, 5.4736805473055155, 2.7887632931981767, 0.8902964070439339, 1.8623551981789725, 2.783218413591385, 6.097558430262974, 8.301078864506312, 11.940190928322927, 16.46302352632795, 22.437270539147512, 27.60746853692191, 32.721606731414795, 40.14981467383248, 46.82646724155971, 50.7231559753418, 53.65964535304478, 52.467671462467735, 53.00664670126778, 53.217204911368235, 52.81077350888933, 53.248082705906455, 49.37513596670968, 50.632780756269185, 40.840927668980186, 49.500144481658936, 50.40835394178118, 51.89098140171596, 51.188768659319194, 50.48524270738874, 48.23397772652762, 47.66058806010655, 47.833855288369314, 49.10125534875052, 49.52062777110508, 51.53043590273176, 48.463285650525776, 50.289480686187744, 48.195585455213276, 43.93371329988752, 43.00266858509609, 33.141517639160156, 24.38920017651149, 14.755180631365095, 11.806097643715994, 7.346435461725507, 5.481484242847987, 0.6736449524760246, 2.8343145975044797, 2.5106097502367835, 4.086191730839865, 5.623711696692875, 4.526523394244058, 4.424240265573774, 7.155003036771502, 1.75157387980393, 2.043346651962825, 1.0426225789955683, 1.8565577949796404, 1.7711169911282403, 0.18021671607026032, 0.22497227521879332, 0.2044010612049273, 1.6032404793160302, 4.95897319487163, 10.949323092188154, 24.435197251183645, 21.485323905944824, 25.555941683905466, 33.200969900403706, 31.23817675454276, 23.40494963100978, 7.549162183489118, 0.7070562882082803, 0.03734040293576462, 0.016260669333860278, 0.039893363802028556, 0.047259526393775425, 0.044858279172331095, 0.07182895032955067, 0.02836177820738937, 0.02440177319970514, 0.053821384108492305, 0.029123041911848953, 0.03077128150367311, 0.04349748397778187, 0.07205904833972454, 0.03334718703159264, 0.016817434458062053, 0.016365418177364126, 0.05006645613216928, 0.06845782550850085, 0.024831058557278345, 0.04608948774901884, 0.15563926845788956, 0.026138247789016793, 0.046162423478173356, 0.041687359501208575, 0.03935572997267757, 0.029422421740101914, 0.03520849679729768, 0.046539003628173044, 0.02678423687549574, 0.015514874531488334, 0.05283762028973017, 0.010086423052208764, 0.006638402402001832, 0.019339486357889006, 0.08552046386258942, 0.034325383470526764, 0.024001522355579903, 0.027326589915901423, 0.02665370370128325, 0.059493651879685264, 0.04876591484727604, 0.011088794845688556, 0.0375505113042891, 0.023663128460092202, 0.04015138013554471, 0.03581078822857567, 0.05211084482393094, 0.03230641609323876, 0.03591288060748151, 0.03413179064435618, 0.0488918916588383, 0.0417117969399052, 0.011502728348464837, 0.0011587264057847538, 0.060031200892158916, 0.054856957468603335, 0.004160301335754671, 0.03837641395096268, 0.10348850541881152, 0.030704944527574947, 0.0426366367776479, 0.06477415388716118, 0.01976694306358695, 0.034482549144221206, 0.045530924507017644, 0.02903988744531359, 0.09298308020723717, 0.07233384145157677, 0.05999600528074162, 0.036341311010931215, 0.04705564697672214, 0.03336038453770535, 0.053642335680446455, 0.029380216861941984, 0.09469566188220467, 0.05409556653882776, 0.10168678459844419, 2.9016658748899187, 20.2019099848611, 41.821999413626536, 45.840750626155305, 39.700248854500906, 26.126013585499354, 28.214874846594675, 25.238898856299265, 23.968702145985194, 13.645781738417488, 6.203145861625671, 2.4916292258671353, 0.4094287087874753, 0.043255827123565335, 0.040718757547438145, 0.2707359067031315, 0.658907063305378, 0.911580964922905, 1.8155767768621445, 1.6916527237210954, 3.1211140879562924, 4.84806170633861, 5.623105032103402, 5.137842408248356, 5.9862717390060425, 6.629068698201861, 6.443440624645778, 3.6272825385843004, 3.263549553496497, 3.5781509578227997, 4.623634023325784, 8.467713168689183, 11.491898366383143, 13.871250782694135, 20.419581413269043, 25.570505108152116, 30.57386643545968, 35.84770550046648, 41.93405301230294, 48.6208256312779, 52.50255489349365, 55.07497603552682, 54.704682213919504, 55.718827383858816, 55.47278124945504, 55.35000658035278, 55.1218763760158, 51.414810929979595, 52.04847969327654, 40.91606896264212, 47.57437481198992, 52.69876854760306, 53.81491674695696, 53.029895373753135, 52.171810218266074, 50.38908658708845, 47.424863474709646, 48.89409480776106, 50.59209210532052, 50.72011613845825, 50.99251331601824, 50.479215145111084, 50.12155662264143, 50.27026196888515, 45.266589709690635, 44.21881178447178, 34.674286774226594, 26.316778114863805, 17.758713177272252, 14.321660808154515, 10.981908406530108, 9.666537983076912, 2.366772702762059, 4.58645464692797, 5.128856216158185, 5.819324765886579, 5.275266919817243, 4.2297519360269815, 4.630912695612226, 4.319728067943028, 3.412634227957044, 2.395013221672603, 2.5341050837721144, 1.7189555615186691, 1.5148235665900367, 0.2576465590723923, 0.11028383007006985, 0.2762264763670308, 1.274214289018086, 6.3569885322025845, 12.313342196600777, 23.832713740212576, 27.511680671146937, 24.0568938936506, 36.12443487984793, 35.83538287026541, 28.741963454655238, 9.776607871055603, 0.9274828944887433, 0.05767720684941326, 0.04223874045003738, 0.05849613754877022, 0.03690220502072147, 0.044802961604935784, 0.0811877463545118, 0.04534572855170284, 0.03221977734938264, 0.01586007752588817, 0.0696498215464609, 0.02177989692427218, 0.06499981427831308, 0.014423489969755923, 0.020324795540156107, 0.01830614368165178, 0.027089413089145507, 0.039136600481080155, 0.0734610916780574, 0.030375447922519276, 0.025260601758158634, 0.08054730429181031, 0.029394886789045165, 0.0326678581269724, 0.06499365996569395, 0.01482837351172098, 0.01291083439718932, 0.009928041104493397, 0.0741356233400958, 0.09451582296086208, 0.09174539162112133, 0.006742041416665805, 0.05161839124879666, 0.03932948084548116, 0.055519658872591596, 0.08896358124911785, 0.06279761530458927, 0.07883492617734841, 0.11345632733511073, 0.1341539184962, 0.1371452808380127, 0.14809033567351954, 0.09081457728253943, 0.08270334252821547, 0.1673456531550203, 0.16734411966587814, 0.2676502822765282, 0.2991155795753002, 0.13671966296221527, 0.16793584291424068, 0.15014185916100228, 0.13223770846213612, 0.16519662418535777, 0.09636888174074036, 0.17123144678771496, 0.14255700473274502, 0.19026292913726398, 0.15088509927902902, 0.1312796984400068, 0.16614879880632671, 0.1563774874167783, 0.10794935747981071, 0.16136930670057023, 0.14246112773461, 0.09565319692982094, 0.23849452819143022, 0.13647040990846498, 0.15920008452875273, 0.2314041629433632, 0.15702031792274543, 0.29558613896369934, 0.19618902328823293, 0.15029383743447916, 0.17599652680967534, 0.14115801480199608, 0.15984473350856984, 0.13297009201986448, 0.2540616957204682, 3.951034937586103, 24.75545883178711, 49.39701236997332, 54.35552828652518, 51.18632984161377, 36.69852631432669, 35.64245918818882, 29.262932436806814, 24.79030578477042, 16.392629589353287, 7.20584647996085, 3.3210102873189107, 0.5932514720729419, 0.5240419858268329, 0.9231559038162231, 1.741166455405099, 3.776358093534197, 2.2294925834451402, 5.462673732212611, 4.539673294339861, 7.560854264668055, 11.572160482406616, 12.72094350201743, 17.907939638410294, 22.21989962032863, 8.63143357208797, 12.485369171415057, 7.424217939376831, 2.848492396729333, 4.600778358323233, 4.190430777413504, 9.752846768924169, 11.596735392298017, 14.10217763696398, 20.494594165257045, 26.86955073901585, 31.632632936750138, 36.61680160249983, 44.05637332371303, 49.35018845966884, 53.229485852377756, 56.55962194715227, 55.56771101270403, 56.642399311065674, 55.35204587663923, 56.77381753921509, 56.453522954668315, 51.2753084727696, 51.632536206926616, 47.191661085401265, 50.59273828778948, 52.43868705204555, 55.43844672611782, 55.36454221180507, 55.782917567661826, 52.601643153599326, 50.11180830001831, 50.71152469090053, 51.068415437425884, 54.32783276694161, 52.30427762440273, 54.32374375207083, 51.33603572845459, 50.51534925188337, 47.64716761452811, 45.03197683606829, 35.212066922869, 27.636763879231044, 17.318291187286377, 14.207053746495928, 10.347648177828107, 7.708146521023341, 2.4734586008957455, 4.99926666702543, 5.943049601146153, 10.08162076132638, 13.048386914389473, 12.468175854001727, 13.532510467938014, 14.67867922782898, 5.508815850530352, 6.979562325137002, 6.829732239246368, 5.798550954886845, 5.064562797546387, 0.7026711606553623, 0.47716134999479565, 0.41907457262277603, 2.2486791653292517, 6.526637486049107, 15.629640953881399, 32.63405595506941, 30.612168380192347, 35.66367203848702, 43.046612467084614, 44.36955990110125, 35.56248194830758, 13.474169049944196, 1.3784552897725786, 0.11651255083935601, 0.11854042059608869, 0.18270505326134817, 0.16049832557993277, 0.21143005974590778, 0.22245994502944605, 0.10915477494043963, 0.24397467555744307, 0.11974586519811835, 0.1030736423230597, 0.1902779247611761, 0.1814159724329199, 0.1886185266609703, 0.11039599190865244, 0.043268078073327026, 0.09406820019440991, 0.11203084739723376, 0.23454664860452923, 0.12524569007967198, 0.17769556492567062, 0.281223506799766, 0.1653469196919884, 0.16957769409886428, 0.14139143084841116, 0.09729447135967867, 0.10843637598944561, 0.1772258287029607, 0.14769643252449377, 0.19311739025371416, 0.11309502779373101, 0.10284496923642499, 0.08746393064835242, 0.08054167245115552, 0.18811115888612612, 0.19958272975470337, 0.12413195627076284], [0.017485087471348897, 0.040731724351644516, 0.017011112101109963, 0.021649833635560105, 0.04551412397995591, 0.0683550817359771, 0.014042284755435373, 0.03179562171655042, 0.002976521720743871, 0.031056276389530728, 0.04501657121415649, 0.0876966342329979, 0.05337853144322123, 0.01775242687602128, 0.05921543895133904, 0.017766825389117002, 0.045709586170102866, 0.02486608792761607, 0.02183789131231606, 0.03362650936469436, 0.05848363893372672, 0.029959068301000764, 0.08602648813809667, 0.055442285524415116, 0.03531657046239291, 0.061629388348332474, 0.04164201979126249, 0.012657676374406686, 0.06442280166915484, 0.06889414388154234, 0.07692723854311875, 0.04294373833441308, 0.037938867429537435, 0.013328455737791955, 0.08691246488264628, 0.025600429058873227, 0.005923039471131882, 0.026326632858919244, 0.09599827269890479, 0.08929870969482831, 0.02058715619412916, 0.39863527938723564, 5.8232075061116895, 25.64231821468898, 41.92559358051845, 36.31559371948242, 24.218944992337907, 29.411491870880127, 27.32103599820818, 27.513278756822857, 16.82726894106184, 9.354569946016584, 6.581179976463318, 1.7841549600873674, 0.5791258386203221, 0.15967731177806854, 0.04289080581760832, 0.12327868491411209, 0.7554870780025209, 0.9308639530624662, 1.4086238252265113, 2.0777875695909773, 2.3102569239480153, 3.6878284897123064, 4.0144303015300205, 4.0406258787427625, 6.319176001208169, 3.3069892568247656, 3.2178178131580353, 3.2281037526471272, 2.099051011460168, 1.2052081461463655, 1.938602775335312, 3.976594320365361, 5.449877755982535, 9.300690140042986, 12.823664801461355, 18.77278365407671, 24.662462404796056, 30.96928494317191, 35.912827491760254, 47.02445616040911, 51.53580338614327, 53.005733013153076, 53.357339654650005, 55.41267933164324, 51.41024596350533, 49.98955127171108, 48.68582255499703, 53.42118665150234, 48.306075709206716, 48.60565076555525, 49.56592655181885, 49.637107372283936, 53.064601625714985, 49.21546983718872, 49.46459402356829, 47.96003804888044, 50.34176588058472, 52.357834339141846, 51.59956005641392, 48.70782402583531, 46.40117495400565, 50.187230995723176, 41.51261697496687, 39.51680598940168, 31.895931448255265, 23.734342881611415, 15.356376988547188, 9.967553053583417, 6.494928078992026, 5.31837180682591, 5.3397257924079895, 2.0410181369100298, 4.675527078764779, 7.030749704156603, 3.3018260938780646, 4.675780253750937, 3.3511452760015215, 1.1755054656948363, 3.6251498758792877, 2.530419932944434, 0.6729752655540193, 1.2808417848178317, 0.3309788240918091, 1.1348753316061837, 0.0668459248596004, 0.18703603371977806, 0.9141553810664585, 3.498224526643753, 6.405849567481449, 25.49674650600978, 26.809712852750504, 14.993001835686819, 30.039216450282506, 31.84734616960798, 29.053388663700648, 12.751777001789637, 2.5088264516421726, 0.038512439866151126, 0.059646722594542165, 0.045657447539269924, 0.02833590397079076, 0.013072436841736947, 0.06313985479729516, 0.055372311600617, 0.014076940083344067, 0.019811264971005063, 0.04263458760189159, 0.05353131717337029, 0.04063978624929275, 0.04972377898437636, 0.060115495297525606, 0.033243079403681416, 0.053485451598784754, 0.04072686604091099, 0.0307460332156292, 0.04118483307372246, 0.032593938522040844, 0.026474546707634414, 0.0415002398991159, 0.043265665881335735, 0.018560443339603286, 0.07733880395867995, 0.008127003908157349, 0.05892154507871185, 0.029087998970810856, 0.04283824649506381, 0.04203719858612333, 0.06377839017659426, 0.02363218387056674, 0.009671532815056188, 0.04596390788044248, 0.027851993151541268, 0.027093652236674513, 0.01111032985084291, 0.06661380481507097, 0.045376686711928675, 0.028688508085906506, 0.03538725684796061, 0.04511157290211745, 0.0029368371760938317, 0.1063287580119712, 0.051761942117341926, 0.03902787542236703, 0.017272851895540953, 0.015031384403950401, 0.009798166957417769, 0.04926154396629759, 0.04559160589373537, 0.031698686203786304, 0.012902078750942434, 0.03057791937940887, 0.03521348742235984, 0.03887611428009612, 0.031039048385407244, 0.011636404836151217, 0.04729541071823665, 0.03820051731807845, 0.028189169076670493, 0.06269527865307671, 0.05532849180911269, 0.018857804526175772, 0.06085587199777365, 0.05123524287981646, 0.06282924860715866, 0.07177006027528218, 0.04762699381847467, 0.0435331138516111, 0.007742992103365915, 0.02724428870715201, 0.03972793696448207, 0.048406433779746294, 0.07803520480436937, 0.03562598243089659, 0.0060307611461861855, 0.08247622328677348, 0.4428385788840907, 7.6419579812458585, 30.445724282945903, 48.58579976218087, 42.59562226704189, 28.492726360048565, 26.341935804912023, 29.4235782623291, 26.958267075674875, 20.793926034654888, 13.092076318604605, 6.865276183400836, 1.7994782349893024, 0.36330610513687134, 0.09623011454407658, 0.042169601124312193, 0.3219074894274984, 0.9110257604292461, 1.0676790859018053, 2.757939781461443, 1.6129103090081895, 2.966177727494921, 3.8258192794663564, 8.02045328276498, 7.869107621056693, 5.1070749163627625, 6.763756488050733, 5.212058288710458, 5.979846826621464, 4.086904789720263, 3.3225121838705878, 4.781828437532697, 6.392778268882206, 8.806723594665527, 11.655547550746373, 16.638748679842266, 22.428206614085607, 26.27365412030901, 33.717408657073975, 39.40120186124529, 48.431803362710134, 53.49737364905221, 56.10008546284267, 55.309335299900596, 55.602785519191194, 54.44627176012312, 53.12647533416748, 51.56145960944039, 53.88783114297049, 47.03655297415597, 47.716239656720845, 52.02210085732596, 52.62801851545061, 54.90005513599941, 51.0587227003915, 50.098707471575054, 49.047389439174104, 51.61413390295846, 52.10958562578474, 53.07646220070975, 52.02711050851004, 49.27529730115618, 49.71230772563389, 45.363027232033865, 41.06396484375, 34.80195297513689, 26.13693789073399, 19.47821341242109, 11.16299409525735, 9.57188093662262, 7.427261250359671, 6.080518407481057, 3.2300214554582323, 4.943648508616856, 6.69384241104126, 5.714271911552974, 5.179905499730792, 3.341824918985367, 3.558610669204167, 2.3822237593787055, 2.7124429770878384, 2.418044545820781, 0.6317295102136475, 0.44579753439341274, 0.2516229322978428, 0.1132050251056041, 0.10688016270952565, 0.7858541799443108, 4.7781341671943665, 9.061346411705017, 22.514678682599747, 32.29948282241821, 21.25562514577593, 30.078883716038295, 37.36086681910923, 34.52744007110596, 16.568931443350657, 3.5530479848384857, 0.10703615112496273, 0.009717102378739842, 0.03876099742150732, 0.034774234385362694, 0.04306769650429487, 0.019865062619958605, 0.026287213367010866, 0.11064985221517937, 0.018751852979351367, 0.04051664232143334, 0.03928724543324538, 0.027320413550894176, 0.04361127090773412, 0.01391919850305255, 0.06276272503393036, 0.08561488201043435, 0.035341303063822646, 0.07234574974115406, 0.049714900353657346, 0.020662236093942608, 0.06070619395800999, 0.014832476952246256, 0.027928854205778668, 0.050458228681236506, 0.027737003518268466, 0.030493516408439194, 0.029934946381087815, 0.03145540086552501, 0.03191638059381928, 0.06646462889122111, 0.04174135731799262, 0.02890347476516451, 0.04491718958265015, 0.09457789534436804, 0.011581283195742538, 0.03251891629770398, 0.021852557846744145, 0.16762757088456834, 0.1581075888659273, 0.17214996607175895, 0.09801860393158027, 0.11348481902054378, 0.10748985356518201, 0.14028114399739675, 0.2500206397048065, 0.14132641362292425, 0.1331854590347835, 0.10667638507272516, 0.12360727228224277, 0.161380977502891, 0.09039206709712744, 0.18733830749988556, 0.1171657493604081, 0.11595066956111363, 0.11063647150461163, 0.13393895860229219, 0.06558634673378297, 0.18043961482388632, 0.2274047282657453, 0.18912985708032334, 0.10815665671335799, 0.13189299910196237, 0.19198339538914816, 0.23419666024191038, 0.1106768511235714, 0.1404156024966921, 0.19734830036759377, 0.2918202153273991, 0.14085827874285833, 0.10741617144750697, 0.14168427299175942, 0.1534545621169465, 0.1202505324035883, 0.10393304763627903, 0.22113695102078573, 0.15103813606713498, 0.12785472507987702, 0.1639221590012312, 0.6263091010706765, 9.090925761631556, 35.29556342533657, 55.51846218109131, 49.317820276532856, 35.60362223216465, 38.261999538966585, 38.04862036023821, 36.55168308530535, 23.06396504810878, 13.325891017913818, 8.846636652946472, 2.3187252581119537, 0.8466861471533775, 0.356149324881179, 0.5930695161223412, 0.6743219132934297, 3.3626462817192078, 4.419251893247877, 5.894471704959869, 7.59756246634892, 8.636441486222402, 11.772759318351746, 12.101779971803937, 13.835675137383596, 15.315646648406982, 10.384747215679713, 8.595880508422852, 6.715092173644474, 5.3889685443469455, 4.015849471092224, 4.462488796029772, 5.9101607373782565, 8.795471855572291, 12.422221337045942, 15.106801169259207, 22.26942116873605, 25.971108709062847, 33.09657669067383, 40.15811082295009, 51.5476187978472, 54.59310456684658, 56.95986597878592, 55.74548414775303, 58.117039816720144, 55.45205477305821, 52.34936448505947, 50.864068916865754, 55.96600260053362, 51.67888763972691, 49.275589125497, 52.90919821602957, 53.12656218664986, 55.775236334119526, 52.312153407505576, 52.26868895121983, 51.7515275818961, 53.016718115125386, 53.84720849990845, 51.9264554296221, 53.09589283806937, 51.07814986365182, 50.78916038785662, 45.41040699822562, 42.21787997654506, 34.56680161612374, 27.027191468647548, 17.41626078741891, 12.373120154653277, 8.272673760141645, 7.7459586177553446, 9.47044244834355, 4.407206322465624, 10.66268731866564, 14.594269037246704, 8.032206160681588, 11.258942638124738, 9.599936894008092, 8.713148730141775, 10.148674351828438, 7.116751900741032, 6.410090574196406, 4.967531638486045, 2.106592846768243, 2.0996088215282986, 0.32997220382094383, 0.3973181614918368, 1.4026365407875605, 4.634051110063281, 10.095550162451607, 31.829419817243302, 35.012313161577495, 23.624411957604543, 39.26523603711809, 43.16192477090018, 40.98447745186942, 20.22331738471985, 4.637941667011805, 0.2721113514687334, 0.1348903054105384, 0.07111617643386126, 0.1543781975550311, 0.1354853127683912, 0.13234966674021312, 0.15198910289577075, 0.17669651710561343, 0.08439683701310839, 0.08786898891308478, 0.10940442832985095, 0.19244310286428246, 0.1390374843031168, 0.09371106685804469, 0.18350776018840925, 0.14155251506183827, 0.1271608415991068, 0.14672847517899104, 0.1245229145778077, 0.13314271132860864, 0.1574497220239469, 0.11752250950251307, 0.1454633873488222, 0.19531578943133354, 0.14963769407144614, 0.08672064981822457, 0.13182521345359938, 0.20830753658499035, 0.144777402015669, 0.18776172692222254, 0.24741270393133163, 0.14750376929129871, 0.1860100616301809, 0.209016279982669, 0.1041647062769958, 0.06352548660444361, 0.09345293856625046], [0.035179044984813244, 0.0430594998012696, 0.02806685126519629, 0.049343650096229145, 0.04386732627504638, 0.06436023395508528, 0.017121385916003158, 0.021955779986456037, 0.024468164458604794, 0.03283074385087405, 0.013863199007963496, 0.004118193148834897, 0.013307838451250322, 0.050370300720844946, 0.04575052218777793, 0.031241557161722864, 0.04136447861258473, 0.019140758717964803, 0.08717896629657064, 0.047966434354228635, 0.02933985081368259, 0.031027238483407667, 0.029924259454544102, 0.06591607404074498, 0.07721719691263777, 0.01764609874226153, 0.020708449417725205, 0.015614023764750786, 0.0560728922220213, 0.026768109794440012, 0.036298003513365984, 0.014145707062977766, 0.027436719542103152, 0.01595286718968834, 0.024914840668705956, 0.012716415454633534, 0.018591579615271518, 0.08429068020944085, 0.024154389509931207, 0.04690061529566135, 0.026374557787286382, 0.10331802349537611, 1.198879857148443, 8.951429384095327, 28.175134624753678, 37.65176704951695, 39.45736067635672, 36.91827351706368, 17.582856007984706, 20.398418937410625, 19.483488832201274, 16.87631974901472, 14.383483273642403, 6.460969626903534, 1.920266262122563, 0.6591383623225349, 0.31680517750126974, 0.29885922904525486, 0.40535169041582514, 0.33852766188127653, 1.1349913882357734, 1.552234947681427, 2.011111787387303, 1.6003247329166956, 4.21442768403462, 3.064456956727164, 3.6717208283288136, 6.141174878392901, 3.1221804193087985, 8.360902854374476, 3.890167849404471, 2.7200225932257514, 4.17684531211853, 2.253148159810475, 3.280061947447913, 4.76939593894141, 7.275318912097386, 11.428993718964712, 16.14593379838126, 21.943950176239014, 29.272684233529226, 36.02123328617641, 46.713593755449565, 50.09164115360805, 49.5856351171221, 52.95459427152361, 52.966301986149375, 48.284053393772666, 46.51817567007882, 57.64937046595982, 48.289472988673616, 44.89204706464495, 51.49646615982056, 47.830193587711875, 52.79459115437099, 53.26423379353115, 53.32617350987026, 50.21253286089216, 52.455178601401194, 51.015164443424766, 52.75940547670637, 44.7658052444458, 49.75814846583775, 45.10364055633545, 33.10024186543056, 32.41076864515032, 23.082341296332224, 16.55826595851353, 10.646702119282313, 5.791037346635546, 4.084028669766017, 3.5165625597749437, 4.486041017941066, 2.2508524315697804, 2.690373544182096, 4.086324180875506, 5.820376115185874, 2.3831126945359364, 0.9104533482875142, 2.4942319776330675, 0.4352307899722031, 1.7477110070841653, 1.3804775412593568, 0.5599210719977106, 0.21620545350015163, 0.1292772466050727, 0.2498194676424776, 1.0125163601977485, 2.786423053060259, 8.704968963350568, 15.925837448665074, 30.020293031420024, 14.114331773349218, 21.956885984965734, 34.18406704493931, 31.2200836454119, 16.663499900272914, 5.41899779013225, 0.37584567655410084, 0.05933798237570694, 0.054383170391832075, 0.03691800810130579, 0.03745692775451711, 0.007262981164136103, 0.03603485745510884, 0.06193158070423773, 0.06294242146291903, 0.018700160485293185, 0.010871878226420708, 0.05246134887316397, 0.04469643499968307, 0.015204594038160784, 0.034508533642760346, 0.05123926319980195, 0.019393826834857464, 0.027833699847438505, 0.03289506897064192, 0.04365213228655713, 0.02115207222024245, 0.06796190461942128, 0.010746316169388592, 0.017346659542194436, 0.06131093150803021, 0.05760038311460188, 0.04687698192096182, 0.05206483675699149, 0.008446396278616573, 0.019720633048564196, 0.032696773896792104, 0.01935159311895924, 0.04996764447007861, 0.040287287307104895, 0.016307072647448097, 0.049147387234760184, 0.08970461612833397, 0.02137062495707401, 0.05470312340185046, 0.02387777792422899, 0.10113900327788931, 0.01863199146464467, 0.015410217290212, 0.06643999807004418, 0.039158469664731195, 0.025878474049802338, 0.01806625271482127, 0.07734496505664927, 0.032527241922382794, 0.041668950846152644, 0.032284536731562445, 0.06096823061151164, 0.044481447964374504, 0.014974512991362383, 0.03763993882707187, 0.025202157840664898, 0.06156730917947633, 0.020847362499418, 0.0170695305735405, 0.02241560790155615, 0.04652387568993228, 0.05122554661439998, 0.04141752648034266, 0.03571178318400468, 0.01527132626090731, 0.04088540914069329, 0.042052567404295714, 0.012303331816968108, 0.017239215218329003, 0.02202065471958901, 0.05377017507063491, 0.03042285716427224, 0.06351529500846352, 0.02470190789816635, 0.031189069085355316, 0.015895147608327012, 0.061034299566277435, 0.03327113004135234, 0.030649260551269566, 0.21552695919360432, 1.4198894607169288, 11.921993596213204, 34.516117981501985, 42.60500233513968, 43.09871006011963, 40.71035017286028, 21.5842992578234, 24.327494961874827, 21.986634697232926, 19.224611112049647, 13.310198511396136, 5.549053737095424, 2.712871376957212, 0.49596643235002247, 0.17501199963901723, 0.1900428802307163, 0.5054671711155346, 0.5693165021283286, 1.1554784774780273, 2.4987252908093587, 3.0445620928491866, 3.921699208872659, 5.623323031834193, 6.623818465641566, 6.367723499025617, 7.574653387069702, 6.6003318173544745, 6.022941291332245, 7.9451252562659125, 5.077733976500375, 5.150372181619916, 4.155417936188834, 5.234642105443137, 6.767044288771493, 11.621383258274623, 15.865568774087087, 19.50366292681013, 24.15628787449428, 33.047859396253315, 38.75774308613369, 48.43301234926496, 52.944092069353374, 51.87839821406773, 55.33014168058123, 53.572594846997944, 50.11038391930716, 49.13342898232596, 58.516609873090474, 48.77052804401943, 43.58231857844761, 52.89478417805263, 48.54951626913888, 52.921256814684185, 54.60524306978498, 54.6624128477914, 50.880741119384766, 53.168803759983604, 52.97204119818551, 53.28761795588902, 46.787477425166536, 51.22762993403843, 47.29135036468506, 37.23029627118792, 33.94987801143101, 26.571090868541173, 18.37813639640808, 12.483477524348668, 9.120250633784703, 5.986442838396345, 7.27073918070112, 3.089408806392125, 2.6590376027992795, 6.048958820956094, 6.854487368038722, 8.0355977501188, 6.031586153166635, 3.3202622703143527, 3.5280542288507735, 2.1228203645774295, 2.6606070271560123, 1.0755756050348282, 0.5406659852181162, 0.213578749448061, 0.17873221715646131, 0.09048376431954758, 1.0231379845312663, 2.879240563937596, 8.966113533292498, 16.585832936423166, 30.799078396388463, 20.952767065593175, 21.345670325415476, 37.933613777160645, 36.39095040730068, 22.056255647114344, 6.760160361017499, 0.7318183651992253, 0.049550532030739954, 0.00809485067812992, 0.057777962514332364, 0.030462755023368766, 0.05657716926985553, 0.03375834532614265, 0.005441055267250964, 0.04793877387419343, 0.04302460274526051, 0.02959812499050583, 0.03278738207050732, 0.03453615341069443, 0.029434414846556525, 0.027601208304986358, 0.019366941581081067, 0.0224608661873, 0.04453081477965627, 0.03739300297041025, 0.04485688139019268, 0.012108119836609279, 0.018159351112054925, 0.03856353016038026, 0.025135403565530266, 0.05978062469512224, 0.04804727162367531, 0.008515521185472608, 0.04321413453934448, 0.056646006647497416, 0.03962327633053064, 0.06238672163869653, 0.059175344317087104, 0.06187393915440355, 0.019645878845559697, 0.03533363901078701, 0.040567305138600726, 0.027528296324557493, 0.04148066755650299, 0.1294352366988148, 0.1496584979551179, 0.2682654692658356, 0.15298232888536795, 0.13413196110299655, 0.13293847228799546, 0.12504765284912928, 0.12110349163413048, 0.14723094393100056, 0.16758558313761437, 0.16040485059576376, 0.1219036608402218, 0.1280077075851815, 0.15309200728578226, 0.15286503732204437, 0.15019912751657621, 0.15512930867927416, 0.07175351080617734, 0.1819842183696372, 0.12909890046077116, 0.13799849791186197, 0.1453959545386689, 0.17414647393992969, 0.15028446008052143, 0.0971104119505201, 0.07116493596030132, 0.07757893071642943, 0.09753450990787574, 0.14333540653543814, 0.18046538558389458, 0.1062707229118262, 0.12774031050503254, 0.15648401741470608, 0.13494765519031457, 0.1400024425238371, 0.17033417922045502, 0.10819912622017519, 0.18705709544675692, 0.2484441857252802, 0.15785366749124868, 0.11352663713374309, 0.177031686263425, 2.188920097691672, 15.022849559783936, 41.42731046676636, 50.767589705330984, 51.4271821975708, 47.79876341138567, 27.438076666423253, 30.64935861315046, 29.12982405935015, 23.711047308785574, 17.25863916533334, 8.563686030251638, 3.1622532861573354, 0.8606151682989938, 0.5473053146685872, 1.0392551996878214, 1.7956550972802299, 2.1119887743677412, 4.208723212991442, 6.044947973319462, 8.789636237280709, 8.839666741234915, 9.760516711643763, 11.050893596240453, 13.731953297342573, 13.397787502833776, 9.345622403281075, 14.820512805666242, 8.630051749093191, 7.554725953510829, 8.263702767235891, 4.596393610749926, 5.927374465124948, 6.896599096911294, 11.301146864891052, 16.688509941101074, 19.686756644930156, 25.731428861618042, 34.10609436035156, 38.98890617915562, 48.72955799102783, 52.81261478151594, 52.9124048096793, 55.11956262588501, 55.10788270405361, 51.58032396861485, 51.30361543382917, 58.67860017504011, 54.25184726715088, 46.45492969240461, 53.93254974910191, 49.88590151923043, 54.743810994284495, 56.370530196598594, 56.241571630750386, 52.48758847372872, 54.19254091807774, 54.83699328558785, 55.7319073677063, 50.55784790856497, 49.04230335780552, 47.46625736781529, 38.17080443246024, 33.44870444706508, 25.711051532200404, 17.87737624985831, 13.239063722746712, 8.301271677017212, 7.723156367029462, 6.833340091364724, 9.12818808215005, 6.192096488816397, 9.196807622909546, 11.153527174677167, 15.70781339917864, 10.338015369006566, 7.596344794545855, 10.245602590697152, 5.4856301460947305, 5.899095731122153, 4.8378161532538275, 2.0779914557933807, 0.8091500241841588, 0.49164503280605587, 0.6134129730718476, 1.4207194447517395, 3.9683906691414967, 11.5747469493321, 21.387076377868652, 38.65216173444475, 21.541538306644984, 29.27172190802438, 44.718012060437886, 43.4431392124721, 26.84158945083618, 9.398580704416547, 0.9052028985960143, 0.14033347261803492, 0.12910697502749308, 0.09222461376339197, 0.09469188922750098, 0.18427280842193536, 0.13347421639731952, 0.14493821481508867, 0.11818980798125267, 0.16550417696791037, 0.14195063869868005, 0.1368136807743992, 0.12936320342123508, 0.1287064900887864, 0.09139739136610713, 0.08946989729468312, 0.16611636483243533, 0.14638054956282887, 0.1637184220765318, 0.14692834445408412, 0.09005004473562751, 0.0780708889610001, 0.12061977759003639, 0.1355784349143505, 0.12993086581783636, 0.10119505027042967, 0.1372750574456794, 0.16961843334138393, 0.18058950320950576, 0.07693014945834875, 0.10840396915695497, 0.2254536279610225, 0.22867604504738534, 0.13527291773685388, 0.14579998143017292, 0.09288292165313448, 0.13797922751733235, 0.10211488591240984], [0.013650301012343593, 0.026652636704966426, 0.021250330876292925, 0.04361488749938352, 0.011329042043403854, 0.062344129995575974, 0.023015599099120924, 0.041269022306161265, 0.033070534733789306, 0.05131628710244383, 0.040257017859922986, 0.008767373028344341, 0.04437879579407828, 0.061641154145555835, 0.036637620468224795, 0.06545326566057545, 0.03669397958687373, 0.032785577167357714, 0.025111049247373427, 0.08505456814808504, 0.10619698651134968, 0.03588418536154287, 0.04122345528698393, 0.08030172211251088, 0.03173830586352518, 0.018487188698990003, 0.03629013929249985, 0.00664354909011828, 0.08515010587871075, 0.03288932517170906, 0.03789300864030208, 0.04960837035572954, 0.04047053586691618, 0.03628563381997602, 0.02046620563071753, 0.0170903904363513, 0.02632847847416997, 0.057531233610851426, 0.09694763139954635, 0.05294050316193274, 0.03377568528854421, 0.07723103224166802, 0.18032596020826272, 3.2626775545733313, 13.793168663978577, 33.45596184049334, 43.29422194617135, 30.882623536246165, 21.874928508486065, 14.709018536976405, 19.280387776238577, 17.574677978243145, 17.049701622554235, 12.69953349658421, 7.541315061705453, 2.318363734654018, 0.7622181453875133, 0.3756629063614777, 0.514853698866708, 0.4348602012864181, 1.0675614007881709, 1.1557299154145377, 1.5744768913303102, 4.649716692311423, 9.070632679121834, 8.836968234607152, 3.3335311583110263, 6.283884363515036, 5.187200673988887, 5.958689996174403, 7.226575127669743, 4.026276545865195, 3.184861855847495, 2.2456840574741364, 2.462224015167781, 3.0102201870509555, 4.671115406921931, 6.11056068113872, 8.14038005896977, 15.08722983087812, 22.765565974371775, 28.415634359632218, 35.847604751586914, 43.0483147757394, 47.945978369031636, 49.66469866888863, 51.55952801023211, 47.134154319763184, 51.3371057510376, 48.13848863329206, 41.294297627040315, 41.33576447623116, 49.17426354544503, 48.18333230699812, 48.924284730638774, 50.67351804460798, 52.084301131112234, 53.01465450014387, 52.85301160812378, 48.97172703061785, 47.46407215935843, 44.161120891571045, 48.009877477373394, 30.354994705745153, 30.0233085496085, 22.53696502958025, 14.912585122244698, 8.232816287449428, 6.5452456304005215, 2.172308691910335, 2.7373616056782857, 3.5919264129229953, 0.845346990440573, 0.8360884072525161, 5.702858626842499, 4.69667956658772, 5.977437538760049, 5.37978823695864, 2.2714592686721256, 1.1605930030345917, 1.2382963363613402, 1.3654649811131614, 0.6492860338517598, 0.03765311258445893, 0.08854946454188653, 0.2183769555496318, 0.5124094528811318, 2.4898648176874434, 9.41194122178214, 13.200635841914586, 23.604526213237218, 23.999953406197683, 17.839574575424194, 30.442267554146902, 31.075814723968506, 23.721523455211095, 6.564865606171744, 1.703913688659668, 0.017553032575441257, 0.03749341597514493, 0.07713361496904067, 0.14030147290655545, 0.04101234607930694, 0.02772269830373781, 0.056375216892255206, 0.010909894847178032, 0.013107354253796595, 0.03543734969571233, 0.1000374084604638, 0.05755663796194962, 0.06589622010609933, 0.05044541454740933, 0.05235776371721711, 0.04393102035724691, 0.05299327622300812, 0.05708397725330932, 0.029032046973173107, 0.014657869535897459, 0.0251005692740104, 0.023678711016795466, 0.06141397383596216, 0.029136629575597386, 0.05423296648742897, 0.06550939407731805, 0.03168318167861019, 0.02793577695930643, 0.06958810200116464, 0.04881735797971487, 0.03743586942021336, 0.057581065222620964, 0.03730880355994616, 0.008971232089347072, 0.03583176853135228, 0.0466910904672529, 0.020210185886493752, 0.021088198326261978, 0.020975561513166343, 0.05321043796305146, 0.06757177412509918, 0.013159123931213148, 0.06390359345823526, 0.06672471814921924, 0.05537607068462031, 0.04881353443488479, 0.04348131448828748, 0.004958463774528354, 0.04092816702489342, 0.01830925646104983, 0.09184223892433302, 0.044978776813617775, 0.013680489035323262, 0.01246619294397533, 0.056019617045032125, 0.07169823055820805, 0.04310082258390529, 0.09523466295961823, 0.08638075127133302, 0.014322339058188456, 0.023284480474623184, 0.06881852115371398, 0.04628655806715999, 0.021399917313829064, 0.04900837915816477, 0.021186329756996462, 0.019235626395259584, 0.02408385070573006, 0.04015258453520281, 0.014574185812047549, 0.005184928229677358, 0.046094118750521114, 0.07873567007482052, 0.03224417068330305, 0.036646845151803324, 0.04290744010359049, 0.01711600004429264, 0.06819301364677292, 0.01917476180408682, 0.034700358885207346, 0.17985467692571028, 4.248943729060037, 17.085012367793492, 40.04352460588728, 47.73455858230591, 34.11002704075405, 22.988194942474365, 19.557191848754883, 23.974807875497, 21.754149709429058, 22.6876471383231, 13.902638401303973, 6.540866093976157, 2.4663256236485074, 0.6557909048029354, 0.2558843493461609, 0.17437473312020302, 0.2348107344337872, 0.4363893206630434, 0.2771611176431179, 1.818158575466701, 2.4303341720785414, 5.46429135969707, 6.665631421974727, 4.390098120485034, 6.9265879562922885, 4.922036136899676, 5.347401814801352, 7.2222594278199335, 6.4640311769076755, 6.228972315788269, 4.105128611837115, 3.8142379352024625, 5.456420353480747, 7.733891333852496, 8.37657538482121, 11.68107783794403, 17.759086642946514, 24.850597040993826, 30.111786910465785, 38.60476459775652, 45.609761238098145, 49.69213015692574, 52.78488104684012, 53.32717752456665, 50.41019174030849, 54.371047088078086, 52.97178758893694, 43.472137519291465, 39.733252797807964, 50.95360687800816, 50.43964862823486, 50.209138665880474, 53.34049374716622, 54.95766265051705, 53.47589329310826, 54.142090048108784, 49.370376450674875, 49.524661200387136, 47.70580346243722, 49.722875935690745, 34.85228225163051, 31.60976641518729, 26.559273719787598, 19.03954063143049, 12.930079936981201, 9.71692545073373, 5.511012784072331, 4.12736588716507, 7.525024141584124, 4.951039220605578, 3.6427372864314487, 7.320053151675633, 6.276207038334437, 6.2400082264627725, 4.438076300280435, 2.8887274605887274, 3.4223100287573676, 0.6537427604198456, 1.0511526869876044, 0.5834333417671067, 0.2709538792925221, 0.18916550731020315, 0.10312385391443968, 0.3684301573250975, 1.9068008703844888, 8.671340550695147, 17.070937054497854, 22.40968097959246, 30.35967779159546, 19.116180998938425, 28.748086554663523, 36.03696053368704, 28.663224731172832, 8.924671871321541, 2.198500143630164, 0.014182382728904486, 0.04178876316707049, 0.057281817708696635, 0.08016329418335642, 0.0037262870131858756, 0.04740287709449019, 0.030285745593053953, 0.05452805458168898, 0.047825136221945286, 0.02914355741813779, 0.041290480976126025, 0.02496978673817856, 0.05302110294412289, 0.02981960560594286, 0.0367999226520104, 0.055763476860842535, 0.04762650188058615, 0.011168816176775311, 0.022780525730922818, 0.05177120412034648, 0.03464966892663922, 0.07082676767770733, 0.051930608959602456, 0.007359123639097171, 0.05306489559422646, 0.020703937159851193, 0.03747015240203057, 0.07191057809229408, 0.088712889701128, 0.028689268045127392, 0.030387681908905506, 0.008858059233586704, 0.03410779425342168, 0.027117984502443244, 0.005452656519732305, 0.032663088025791306, 0.034111044436161, 0.02336026944353112, 0.13333211759371416, 0.1245814992913178, 0.12169222932841096, 0.16572691287313188, 0.12734733016363212, 0.17405964859894343, 0.10339929841990982, 0.08335760634924684, 0.15432425402104855, 0.08618785733623163, 0.13369380390005453, 0.07213865406811237, 0.14413223734923772, 0.18713949673942157, 0.206887064235551, 0.11198082579565899, 0.10619197213756186, 0.23659446729081018, 0.11090084910392761, 0.1797033907579524, 0.2528716267219612, 0.08263488513018404, 0.155357405011143, 0.14837044849991798, 0.1885886032666479, 0.09450004023632833, 0.11990534806890146, 0.10607997993273394, 0.18395435836698326, 0.130128645205072, 0.10544318838843278, 0.14920896850526333, 0.06939894679401602, 0.16593804582953453, 0.11878827586770058, 0.14198200058724197, 0.11739372355597359, 0.07858112693897315, 0.118272779243333, 0.1616735618029322, 0.09887312379266534, 0.24567340154732975, 0.2916613295674324, 4.967003575393131, 21.25367965017046, 46.27525622504098, 54.67600005013602, 41.951055254255024, 32.24961560113089, 24.53840058190482, 30.84755597795759, 26.93943050929478, 24.23932753290449, 16.46695099558149, 9.501391461917333, 3.537442547934396, 1.3768270228590285, 0.8688087772045816, 0.9361795421157564, 0.8003355828779084, 3.3372849225997925, 4.510443959917341, 5.288729923112052, 10.632305451801844, 15.687957184655325, 19.85703614779881, 11.1041385105678, 13.242055790764944, 12.04102839742388, 13.676814998899188, 13.557678580284119, 8.326219184058052, 8.8289760691779, 5.2302369475364685, 5.144226934228625, 6.5121874042919705, 8.787635156086512, 9.438762136868068, 11.060427393232073, 17.83706627573286, 25.647204535348074, 30.888011864253453, 39.08969327381679, 46.302319458552766, 49.63046836853027, 52.9116335596357, 54.47005891799927, 54.049932616097585, 56.86952550070626, 55.81784963607788, 49.692689486912315, 42.74735702787127, 49.83788251876831, 49.9268924168178, 51.36675024032593, 53.11119624546596, 57.18609932490757, 55.03623635428292, 56.20061547415597, 49.17033086504255, 51.57720422744751, 46.604044982365195, 49.62037263597761, 36.17456613268171, 31.788734640393937, 24.372526236942836, 18.563849585396902, 10.375153490475245, 9.922581706728254, 4.1792932493346076, 6.285267489297049, 7.799306018011911, 4.042141454560416, 10.3618529013225, 11.31107757772718, 12.633878231048584, 13.84953158242362, 10.656735318047659, 7.916437881333487, 5.353944846561976, 5.160810112953186, 4.054172694683075, 2.65154983316149, 1.015411479132516, 0.4763636642268726, 0.3774201220699719, 1.113878526857921, 3.2311600915023257, 11.88863616330283, 17.38618724686759, 29.855172566005162, 32.280705315726145, 25.42653148514884, 39.016539164951865, 40.992898668561665, 34.941688196999685, 11.33963554246085, 2.9081205342497145, 0.11154137937618153, 0.13522421249321528, 0.16468732937106065, 0.23763124165790422, 0.15382082174931253, 0.1314863802066871, 0.17737951688468456, 0.2085285625819649, 0.18084825575351715, 0.08474522403308324, 0.19480293909353869, 0.11097779497504234, 0.13464975117572717, 0.11106725981725113, 0.18474126899881022, 0.19092998334339686, 0.12231649511626788, 0.1516053234892232, 0.11633933441979544, 0.15845623372920922, 0.10909435818237917, 0.10585502521800143, 0.20847912452050618, 0.10131996856736285, 0.1554741266050509, 0.1369638405740261, 0.14452193358114787, 0.13340301093246254, 0.13086936117282935, 0.13613107454563889, 0.07588365168443748, 0.11976756474801473, 0.0850947577772396, 0.11882267759314605, 0.12937802262604237, 0.15490746844027722, 0.1304535549134016, 0.14830076295350278], [0.05455622735566326, 0.013516681351965027, 0.025003406452015042, 0.03179485497197934, 0.09157704029764448, 0.011712019930460622, 0.04373360398624625, 0.10043680095779044, 0.07740303408354521, 0.021253402943589857, 0.05130121683967965, 0.010623179875048143, 0.02942536658208285, 0.025264861261738197, 0.088743817327278, 0.03510821610689163, 0.027269306293289577, 0.05791759823582002, 0.028456311706187468, 0.07057028822600842, 0.017706505322296704, 0.02200458531400987, 0.014516630775428243, 0.044617178716829846, 0.07496290680553232, 0.03309193912095257, 0.10272220868085112, 0.07907653892678873, 0.036541539909584184, 0.038265958627952, 0.0678161010146141, 0.01281076150813273, 0.020351539997916137, 0.022538071598059366, 0.007320435268671385, 0.02137417539155909, 0.055366499948182275, 0.05632648789989097, 0.02054870191828481, 0.024057374269302403, 0.03127615905499884, 0.06478562791432653, 0.04249483313677566, 0.28216783755591934, 5.801796632153647, 22.79843442780631, 35.65225614820208, 40.02353811264038, 30.076292037963867, 20.691936901637487, 16.938869169780187, 22.99544538770403, 18.199552059173584, 16.93722070966448, 13.791799000331334, 9.483254058020455, 3.932291737624577, 1.5623498963458198, 0.4141875191458634, 0.30391393495457514, 0.07547967907573495, 0.2959325989442212, 1.0127471706696918, 1.5771200295005525, 3.185676097869873, 4.953846727098737, 4.402975303786142, 8.41194258417402, 4.603808641433716, 2.7640763436044966, 7.6376127515520364, 7.114832026617868, 4.85014008624213, 4.618228759084429, 2.595980312143053, 2.7162484186036244, 3.9590609754834856, 3.27396142908505, 4.515008926391602, 7.405794790812901, 12.915633763585772, 19.92189758164542, 26.881190708705358, 36.3478889465332, 38.517224243709016, 44.6540504183088, 40.29520572934832, 50.75633709771292, 46.02477713993618, 41.49257837023054, 30.836404119219097, 40.55112177985055, 52.25417763846261, 49.408098220825195, 48.672356946127756, 49.79330635070801, 48.195668833596365, 54.98353426797049, 48.717082500457764, 51.38359267371041, 42.461449078151155, 40.395961557115825, 26.822518382753643, 23.669787168502808, 21.12446747507368, 12.792175565447126, 7.590783630098615, 5.389267751148768, 2.7403087275368825, 4.9321275268282205, 2.1483575999736786, 8.665761147226606, 7.241495081356593, 1.953697519642966, 6.262037924357823, 4.894568170819964, 5.700674286910465, 3.502966889313289, 2.202392871890749, 1.1486822707312447, 0.7567084410360881, 0.9742850916726249, 0.19698764543448175, 0.266010154570852, 0.21574229906712258, 0.6838809517877442, 2.067062807934625, 5.9404613971710205, 10.994744334902082, 13.2110390322549, 39.54311881746565, 19.285616295678274, 19.80595472880772, 30.456108365740093, 27.417935575757706, 12.781569140298025, 2.1375855037144254, 0.19966807588934898, 0.05169661955109664, 0.05924992888633694, 0.02834748656355909, 0.121085754728743, 0.0218414841552398, 0.013733406285090106, 0.031135922830019678, 0.005396153212391904, 0.024877265095710754, 0.054424594954720566, 0.04828606166743806, 0.052274917984115224, 0.0774271356474076, 0.011775624106771179, 0.028407099257622446, 0.038692180399916, 0.036413486780864854, 0.016986281112102524, 0.027371147614238516, 0.01787108399106988, 0.011824452334881892, 0.05258144957146474, 0.013431989155443651, 0.05288798115881426, 0.01640041870996356, 0.034993000860725126, 0.028604960069060326, 0.09224441341523613, 0.031568801030516624, 0.02786603882642729, 0.016277819306456616, 0.03480589482933283, 0.044803314443145476, 0.008190324796097619, 0.00625952668321718, 0.013552772629606937, 0.04181775696841734, 0.04362137768683689, 0.06468928272702865, 0.025718110779832517, 0.05234929220750928, 0.05269384889730385, 0.02262200298719108, 0.029856843607766286, 0.007609888977770294, 0.07977395757500615, 0.023971514144380177, 0.025514852222321287, 0.013458656429845308, 0.038933701547128816, 0.05209692467802337, 0.044760308893663545, 0.060609394152249606, 0.06199225530560527, 0.026784321692373072, 0.03579956865204232, 0.029668387291686873, 0.03343299457005092, 0.053650081157684326, 0.04361690953373909, 0.06601233780384064, 0.041832552424498966, 0.05113636336422392, 0.008235667050550026, 0.10275624399738652, 0.028991378976830413, 0.022087351319247057, 0.023394637242225663, 0.027963525648894053, 0.05536039652568953, 0.03841608789350305, 0.0054677263584120995, 0.07318751992923872, 0.030095229923192943, 0.04411896437938724, 0.11625298405332224, 0.06894073888127293, 0.025352472007008534, 0.0559300164958196, 0.1240879057773522, 0.04990397074392863, 0.5354853432093347, 7.450517739568438, 26.496521064213344, 40.53736087254116, 47.23115464619228, 34.57456275394985, 24.38055314336504, 21.89829008919852, 23.119898046766007, 21.694270133972168, 22.716805253710064, 16.728646210261754, 9.732441646712166, 3.5613195981298174, 1.1324200119291032, 0.3372379025178296, 0.10055498140198843, 0.02962235886869686, 0.16682246194354125, 0.7407722047397068, 1.8615225000040871, 3.927501388958522, 5.066195624215262, 4.979047409125736, 4.9792810423033576, 5.526385673454829, 4.432037881442478, 8.756516780172076, 8.075192928314209, 8.002196890967232, 6.379112030778613, 4.418441125324794, 4.677559861115046, 4.1163899047034125, 5.94566125529153, 8.718584827014379, 10.398409979684011, 15.667816093989781, 21.757425785064697, 28.233190298080444, 37.88714075088501, 40.88391964776175, 47.11871542249407, 48.09338787623814, 52.604050704411094, 50.89391837801252, 47.437783649989534, 36.33677530288696, 38.83924892970494, 49.38652753829956, 50.17820528575352, 49.4322293145316, 50.37992886134556, 50.95532308306013, 53.775662899017334, 49.942932333265034, 51.15620592662266, 44.003466265542166, 41.75854846409389, 32.641702447618755, 25.90240839549473, 24.87667884145464, 16.201378686087473, 11.157619663647242, 7.202195201601301, 6.576093460832324, 6.0810282315526685, 2.845746772629874, 6.920789684568133, 11.668717861175537, 5.3181577154568265, 5.621519974299839, 5.850607292992728, 4.484005195753915, 3.904056429862976, 3.337915688753128, 0.9568150405372892, 1.44615994819573, 0.3599088431469032, 0.347477023090635, 0.1409490667283535, 0.1594876205282552, 0.37837210670113564, 2.6337541937828064, 6.7667346596717834, 18.473516055515834, 13.59580682005201, 35.54560824802944, 24.42132690974644, 21.24412066595895, 34.405311584472656, 31.513672828674316, 17.492407832826885, 2.9151401690074374, 0.2808086233479636, 0.050540039648434947, 0.07126729975321464, 0.0407970944153411, 0.08000376381512199, 0.03964887745678425, 0.04757632760863219, 0.052022516527878385, 0.03443558095023036, 0.030577430834195445, 0.05149921675079635, 0.03751224532191243, 0.007179575639643839, 0.02833301680428641, 0.039181818054722886, 0.04424084623211196, 0.05935779559825148, 0.06065108334379537, 0.031725888672683916, 0.03986218511792166, 0.021213167513321553, 0.03859787081767406, 0.0491312143525907, 0.04785472034875836, 0.049793830939701626, 0.012527311137611312, 0.025818350758137446, 0.02659916814549693, 0.051153981525983126, 0.02261329907923937, 0.007638719082543892, 0.0307448288159711, 0.028166916520733918, 0.04027976913909827, 0.008993137744255364, 0.03126393524663789, 0.018937722380672182, 0.027817674546635578, 0.01830994856676885, 0.18785586687070982, 0.07202742860785552, 0.11024150984095675, 0.1312277362282787, 0.11795571339981896, 0.12644230015575886, 0.09155398367771081, 0.18983665986784867, 0.12083157551075731, 0.13924966220344814, 0.12672397361270019, 0.08988438719617468, 0.18311473913490772, 0.13700702254261288, 0.20678738744131156, 0.10673389091555562, 0.07377042900770903, 0.16770229116082191, 0.10768867111099617, 0.16106720933956759, 0.12879115768841334, 0.1354967121567045, 0.13449942852769578, 0.09095219775502171, 0.1442158735756363, 0.15228638265814098, 0.20099720385457787, 0.13845422917178699, 0.22992905495422228, 0.10366661407585655, 0.1416129996734006, 0.13758558221161366, 0.09436232476894345, 0.07188545872590371, 0.08513380068221263, 0.1428015080413648, 0.1400266390826021, 0.18274689173059805, 0.18607689732951777, 0.09417890996805259, 0.11569910948829991, 0.3490137420594692, 0.17280214679028305, 0.8343403381960732, 8.900915111814227, 30.502699511391775, 47.82445437567574, 54.172582217625205, 42.499952520642964, 30.623775345938547, 25.811150755201066, 32.92294468198504, 26.795177221298218, 24.413161039352417, 17.76080458504813, 12.604641948427473, 5.2163205742836, 2.04638540319034, 0.9031052482979638, 0.5561303954039301, 0.5597534467067037, 1.169828896011625, 3.020665066582816, 6.209762283733912, 10.438027739524841, 10.662213104111807, 14.226736256054469, 19.118310621806554, 13.731899448803492, 7.736014008522034, 18.5872928074428, 18.537561076028005, 10.726187774113246, 11.384900450706482, 6.364282837935856, 5.277555482728141, 5.9494132825306485, 7.042075702122279, 8.320618935993739, 10.591749685151235, 14.371523686817714, 21.61346779550825, 29.419933932168142, 37.685267789023264, 40.88430527278355, 47.322054454258506, 47.31840664999825, 57.08146292822701, 55.320038999829976, 50.52388858795166, 40.7645982333592, 41.574911049434114, 49.28385400772095, 52.196782044001985, 51.82844761439732, 52.42295980453491, 51.84664494650704, 55.53714936120169, 51.29499619347708, 52.69440507888794, 44.302422932216096, 39.46056032180786, 30.926053251538956, 26.62039875984192, 24.53667916570391, 16.183038915906632, 10.885456987789699, 8.059414437838964, 5.2870506303650995, 10.685433983802795, 5.961233471121107, 14.25429368019104, 13.193761467933655, 7.472948261669703, 13.325033783912659, 11.7713531766619, 12.729085053716387, 8.413040399551392, 8.996411153248378, 5.19702455827168, 2.271722648824964, 2.43972162263734, 0.9783075558287757, 0.4475146622530052, 0.5216865465044975, 1.0823468416929245, 3.179087902818407, 7.704274637358529, 17.13970685005188, 19.723901714597428, 47.78880316870553, 25.675874539784022, 27.18151443345206, 40.39661816188267, 38.0672276360648, 21.670349223273142, 4.1756250347409924, 0.6036870692457471, 0.1384165161954505, 0.17797459209603922, 0.10945452457027775, 0.229827274701425, 0.10508576328200953, 0.15191575326025486, 0.09083544901971306, 0.15696010472519056, 0.15251312191997254, 0.15134743947003568, 0.19183377841753618, 0.17306066863238811, 0.18634136313838617, 0.08266478138310568, 0.18436762690544128, 0.14919043092855386, 0.07357107541923012, 0.1038077629304358, 0.08980530393975121, 0.1763353193444865, 0.1481638074453388, 0.23629094500626835, 0.07389726755874497, 0.1728138718754053, 0.04613090552655714, 0.08557244643036808, 0.13348294235765934, 0.17802279522376402, 0.07808646133967809, 0.15395776368677616, 0.09416547497468335, 0.21211567867015088, 0.2162202184221574, 0.10123516526073217, 0.09266397875866719, 0.11152810723121677, 0.12109819906098501, 0.19080522789486817], [0.05083723459392786, 0.03810053179040551, 0.06795528211763927, 0.019846548791974783, 0.045325766051454205, 0.05303953195522938, 0.05254117851810796, 0.03225471172481775, 0.03834675518529756, 0.07406810232039009, 0.03603486084778394, 0.010360026183272046, 0.017938615188800862, 0.06925656979105302, 0.04776660579123667, 0.05650761264509388, 0.03785549922447119, 0.005932919789172176, 0.05186215495424611, 0.05163932744679706, 0.011096543715601521, 0.03264467937073537, 0.011458235110954514, 0.02966439750577722, 0.02826380792872182, 0.10064532833972148, 0.031844550876745155, 0.12166609215949263, 0.020242343357365047, 0.06236049626022577, 0.07269524955855948, 0.049422010712857754, 0.03212600720248052, 0.021685205666082244, 0.009879980469122529, 0.07761876750737429, 0.059842418879270554, 0.03520193536366735, 0.012402576045133173, 0.0323024805901306, 0.034191997056560855, 0.04532138950058392, 0.009888088114426603, 0.051105381455272436, 0.94158002947058, 8.352100355284554, 23.20703193119594, 34.66084895815168, 35.901123251233784, 25.167995963777813, 20.232581070491246, 28.41978417124067, 22.631957326616558, 20.0906172139304, 16.13474546160017, 12.41026782989502, 11.424257653100149, 5.065126035894666, 2.1486639721052985, 0.5286724716424942, 0.3310944193175861, 0.10785319549696785, 0.520837834903172, 0.693615486579282, 1.1749556894813264, 2.941007443836757, 1.4028832018375397, 3.52060814840453, 3.9720263140542165, 4.878074884414673, 3.8926930853298733, 4.853863452162061, 6.581715856279645, 5.116164897169385, 3.7033646617616927, 5.552854835987091, 3.237310115780149, 2.686971966709409, 3.3438563985483984, 5.526463406426566, 7.040622660091945, 13.4131977387837, 17.768972192491802, 26.885766097477504, 33.263197966984336, 40.555092675345286, 38.65493059158325, 42.55704934256417, 37.277995654514854, 43.92406225204468, 27.09554089818682, 37.83383069719587, 55.6392948286874, 43.44698851449149, 46.01387194224766, 44.38118771144322, 47.399738788604736, 51.78451762880598, 47.35424893242972, 38.36803947176252, 35.22108221054077, 26.37637628827776, 19.478930813925608, 19.296797684260778, 10.636754035949707, 8.470998798097883, 3.5022827088832855, 3.5741492296968187, 6.7963539617402215, 3.1622504634516577, 0.8781273428882871, 8.350623863083975, 12.448797328131539, 4.826286486216953, 4.614842815058572, 4.49096815926688, 2.4309447450297217, 3.214464221681867, 2.2185046587671553, 1.3490024187735148, 0.3202865778335503, 0.46953097943748745, 0.1459299615983452, 0.4860678549323763, 0.633803764624255, 2.5640739670821597, 4.3704898697989325, 10.92944690159389, 11.2810492004667, 30.558399745396205, 32.68554210662842, 23.076756681714738, 27.748560394559586, 30.68957131249564, 23.264502218791417, 4.197118418557303, 0.29447027455483166, 0.07664019108882972, 0.09422559996268579, 0.06738894964967455, 0.032351864368787835, 0.06395059557897703, 0.07818423823586532, 0.03858826615448509, 0.0437812167885048, 0.06307775527238846, 0.030890025131936585, 0.04190034146553703, 0.0526359902162637, 0.023877479368820786, 0.03476704191416502, 0.02945800750915493, 0.07088447708104338, 0.03368690237402916, 0.006588256119617394, 0.03518667850377304, 0.04264676391280123, 0.028000081723023738, 0.043749440993581495, 0.0845962380990386, 0.022946215500789027, 0.035174726109419546, 0.0233859604756747, 0.026015186981697167, 0.08843703128929649, 0.04828297094042812, 0.05708492720233543, 0.05051039784614529, 0.008230738341808319, 0.06768413273883717, 0.07580963029925313, 0.037115580535360744, 0.02276334522425064, 0.02112718694843352, 0.06748632621020079, 0.031895064416208437, 0.017801327198477726, 0.032593918165990284, 0.05385603349921959, 0.07492332785789456, 0.014611143918175782, 0.013251838107992495, 0.02285683377912002, 0.023507969553715417, 0.03264927983816181, 0.02114485091130648, 0.014190176551762437, 0.03832762389044676, 0.005629947966164244, 0.0395625508390367, 0.049619786707418304, 0.05116276516179953, 0.026978396278406893, 0.015476946120283433, 0.02261915653278785, 0.011657383442590279, 0.025716645144192234, 0.03599771784086313, 0.0324761312721031, 0.036417530849575996, 0.021873687427224855, 0.02638667811905699, 0.008871121032695686, 0.034879051082368405, 0.03209432640245982, 0.03289222251623869, 0.06079987928803478, 0.014101329176420612, 0.04268495186365076, 0.016836552182212472, 0.07223309935735804, 0.005430378942816917, 0.022690784385693923, 0.0263249246470098, 0.045081629151744504, 0.03346645991717066, 0.014507650364456432, 0.05444272541041885, 0.01984079820769174, 0.04047980804794601, 1.4354128220251627, 11.344092811856951, 28.552277633122035, 38.610632351466585, 40.22739131110055, 27.407761675970896, 23.98129575593131, 30.975569588797434, 25.597137553351267, 23.189565896987915, 19.10374024936131, 17.302239111491613, 10.250594002859932, 5.323380155222757, 1.5925303740160806, 0.4817220281277384, 0.06313190915222679, 0.06986345151173216, 0.4505481209073748, 0.769985091473375, 1.5093824756996972, 1.9630287332194192, 3.040416189602443, 3.1738535208361487, 4.3148209026881625, 5.446054075445447, 3.490213905061994, 6.377709363188062, 6.151991052286966, 6.410116195678711, 3.3293361834117343, 6.250855232988085, 4.738517710140773, 5.81096955708095, 6.013236829212733, 7.4227171284811835, 8.984586187771388, 14.073591879435948, 20.610160078321183, 27.68368332726615, 34.823530605861116, 43.88983195168631, 43.76139102663313, 46.07026699611119, 44.676600796835764, 48.36935295377459, 32.304482051304404, 38.018232413700645, 51.60529579435076, 46.39080824170794, 49.54905979973929, 47.69510671070644, 49.671476636614116, 52.18550164358956, 47.20001629420689, 40.279683453696116, 35.96227434703282, 32.1905072757176, 21.81603557722909, 22.213330098560878, 14.93332028388977, 12.415838548115321, 5.71815595456532, 5.011022584778922, 7.062033099787576, 5.178937528814588, 3.4588658043316434, 9.543727704456874, 10.641034994806562, 4.950905902045114, 4.666748464107513, 5.478939030851636, 3.424882165023259, 2.3380253996167863, 1.7179447071892875, 0.524181275495461, 0.6681794886078153, 0.4524258444351809, 0.09911074675619602, 0.21020653897098132, 0.5844262284891946, 2.1863397104399542, 5.090818302971976, 14.350257856505257, 12.704875792775836, 24.62385126522609, 38.665255614689414, 23.35456476892744, 26.757387706211635, 36.6414155960083, 27.394230059215, 5.967655777931213, 0.2695423907467297, 0.07838412108165876, 0.05204553243571094, 0.03588702503059592, 0.03425592523334282, 0.10609628512923207, 0.06351880981986012, 0.023804319723110114, 0.04284032281222088, 0.038241144602320025, 0.006026297233932252, 0.06230509387595313, 0.02315938236591007, 0.0915554425280009, 0.03841816081798502, 0.020022250346041152, 0.07391714863479137, 0.06836322415620089, 0.04153086218450751, 0.015466549267460192, 0.0391243766727192, 0.05521658442116209, 0.02032226460453655, 0.02708052088772612, 0.026966806900288378, 0.0374584408876087, 0.007030512522240835, 0.02305443674725081, 0.042567687441727946, 0.08415676453816039, 0.06365982975278582, 0.020241712319797704, 0.0397397197250809, 0.1156094071588346, 0.05816510066922222, 0.04871104172031794, 0.017003208864480257, 0.033821605145931244, 0.036143725006175895, 0.04554668687550085, 0.14894625331674302, 0.1235700071390186, 0.10355686782194035, 0.13035062115107263, 0.18199382642550127, 0.1425524042653186, 0.12296708806284837, 0.13282120786607265, 0.09203655099762337, 0.16622183631573403, 0.0804060333009277, 0.11841638439467975, 0.14299079217016697, 0.18137379469616072, 0.15291956439614296, 0.16889777486877783, 0.14933627524546214, 0.07557733383561883, 0.11849551514855453, 0.10692505458635942, 0.13423617051116057, 0.1852051562496594, 0.13393435813486576, 0.08293605968356133, 0.1121937840112618, 0.11240116466901132, 0.11897902563214302, 0.25284747087529724, 0.12319812923669815, 0.13696879387966224, 0.1739091631025076, 0.09678447086896215, 0.14794975678835595, 0.12072155784283366, 0.12345648823039872, 0.1147813501634768, 0.13502914724605425, 0.1842936258763075, 0.13919974916747638, 0.13507855816611222, 0.16694132770810807, 0.14100902208260127, 0.10624146448182208, 0.1321538279631308, 1.8953980079718997, 13.249208092689514, 33.32058661324637, 45.43465273720877, 47.36095394407, 34.33042737415859, 30.015484877995082, 40.883117130824495, 33.62445913042341, 30.19191701071603, 23.65050765446254, 17.0697888646807, 13.761930431638445, 6.785611612456186, 2.692230233124324, 0.9742394941193717, 0.9704286243234361, 0.7271395676902362, 1.971740688596453, 2.566221611840384, 5.821725368499756, 6.407953568867274, 6.529779374599457, 10.69397418839591, 10.806049500192914, 13.31561028957367, 9.236382825034005, 14.563473752566747, 17.22262144088745, 12.033506972449166, 10.22545542035784, 12.176908237593514, 7.677650877407618, 6.2333292705672125, 6.8071423428399225, 9.495620114462715, 8.640212621007647, 15.764444691794258, 19.517383881977626, 29.10629745892116, 35.16169595718384, 45.39098678316389, 45.555381161826, 51.46198572431292, 48.92154714039394, 53.12513085774013, 33.860072544642854, 43.250177315303254, 53.12916081292288, 47.68971143450056, 51.64080803734915, 49.390630449567524, 51.91687386376517, 52.78048283713204, 49.20230647495815, 40.964508329119, 35.74180105754307, 32.037657329014365, 24.77838441303798, 22.737681116376603, 13.741386345454625, 12.390395981924874, 6.363754774842944, 5.696675164358957, 10.665922573634557, 7.286813838141305, 5.885378684316363, 19.378838539123535, 23.632888759885514, 12.300304770469666, 12.08414718082973, 9.766760536602565, 9.144428627831594, 9.58130703653608, 5.775386963571821, 5.87805962562561, 2.2614460459777286, 1.707246869802475, 0.2835610056562083, 0.8363952679293496, 1.0178136016641344, 3.3571830434458594, 5.784060486725398, 14.952556371688843, 17.35557869502476, 38.43244232450213, 40.96826730455671, 29.664142268044607, 36.8581577028547, 42.1762672151838, 33.74401330947876, 7.671185578618731, 0.7986713807497705, 0.09320971768881593, 0.22011020540126733, 0.13181096421820776, 0.1073220247136695, 0.2525275009019034, 0.19992376145507607, 0.1438839342445135, 0.09476460104009934, 0.12681932135352067, 0.0990663298538753, 0.13477123608546598, 0.10039298116628613, 0.14859627852482454, 0.12596839772803442, 0.11036069451698235, 0.16182133315929345, 0.13472661562263966, 0.1254585872271231, 0.1190781324569668, 0.27335239201784134, 0.09538928751966783, 0.10003833805343934, 0.14156172956739152, 0.12344559095799923, 0.07068312181425945, 0.08968168164470366, 0.1525423260671752, 0.25778926855751444, 0.28151796385645866, 0.16163648664951324, 0.09995827770658902, 0.06417265294917993, 0.25236291544778006, 0.1361029696251665, 0.16426891753716127, 0.09170781435178858, 0.07707883683698517, 0.22096574306488037, 0.12770304536180838], [0.04659243826089161, 0.0676713694951364, 0.028683293544288193, 0.03816757783559816, 0.042750159078942876, 0.05979588494769164, 0.013023997923093182, 0.05048656430361526, 0.04394167335703969, 0.005637912695030016, 0.07356188126972743, 0.0434880319849721, 0.06826339129890714, 0.09476836012410265, 0.01614608851793621, 0.01716601655685476, 0.05845728463360241, 0.024580504412629774, 0.023841008111568432, 0.014289357167269503, 0.028896831907331944, 0.043883519513266425, 0.06125939677336386, 0.03594611186001982, 0.02760903011741383, 0.0667507399671844, 0.05218977540997522, 0.014780255200873529, 0.0236612726668162, 0.016900156358523027, 0.032076769308852296, 0.008764679244320308, 0.06198828587574618, 0.07863623755318777, 0.04912623390555382, 0.022306153417697976, 0.03042218541460378, 0.0489404374467475, 0.02948169855933104, 0.013150096870958805, 0.04583243154255407, 0.08042066930127995, 0.0305601824740214, 0.06874637931053128, 0.14770452066191606, 1.84134275998388, 8.93036070891789, 30.286440304347447, 37.13926444734846, 36.41793721062796, 30.931066376822336, 20.707987240382604, 11.974328296525137, 19.966696092060634, 19.380730186189922, 18.04265304974147, 17.740741661616735, 11.489634990692139, 6.232982729162488, 2.592907254184995, 0.595852866768837, 0.2039765561265605, 0.414026353508234, 0.4544330324445452, 1.7646633088588715, 2.1035688604627336, 1.7081914991140366, 1.2583271243742533, 3.057530254125595, 4.101020923682621, 5.969379365444183, 4.32400381565094, 4.90276791368212, 4.178811652319772, 3.5234284656388417, 4.123464907918658, 3.157207808324269, 3.5199306990419115, 4.68884460415159, 1.733070284128189, 3.6911753501210893, 5.930053864206586, 10.861990315573555, 18.195798294884817, 28.455556971686228, 34.52088444573538, 33.21054104396275, 33.00587838036673, 37.73925529207502, 39.736820697784424, 20.82097363471985, 25.26431884084429, 46.068814822605674, 39.830162797655376, 46.43527671269008, 42.077109473092214, 46.07625634329659, 41.10155807222639, 38.48335524967739, 32.84162643977574, 25.453080551964895, 14.112064923558917, 16.609950133732386, 8.351784212248665, 5.621972475733076, 4.004659831523895, 3.3939700637544905, 2.599330863782338, 4.190931916236877, 3.9271175009863715, 2.86861937386649, 4.505030878952571, 9.558796610151019, 3.6186774117606024, 2.4390639322144643, 4.137693081583295, 2.3896730967930386, 2.4485742790358405, 1.1992317182677132, 0.16925895905920438, 0.6610862463712692, 0.15134895938847745, 0.22865311056375504, 0.719963327050209, 2.6385677754879, 4.7363767964499335, 13.156861322266714, 15.33264889035906, 20.300715105874197, 34.378324781145366, 15.395795856203351, 24.653045858655656, 32.77292265210833, 25.072689260755265, 9.097319841384888, 0.4275439381599426, 0.16433616035750934, 0.013103607892324882, 0.04571107894714389, 0.1106022936957223, 0.033706949691155126, 0.02391682082920202, 0.05507407510387046, 0.02316066649343286, 0.009455951213437532, 0.05090072511562279, 0.015279821519340788, 0.03791590580450637, 0.07038607275379555, 0.08034573867917061, 0.028964298644236157, 0.026429539479847466, 0.039538367850972075, 0.019853005052677224, 0.06815684094492878, 0.004642785959211844, 0.07277421746402979, 0.05677062638902238, 0.07288339374853031, 0.026482831620212113, 0.04269842417644603, 0.04460328571232302, 0.1085398525797895, 0.030164796725979874, 0.09811951565955367, 0.07727154078228132, 0.028959277485098158, 0.05449617361383779, 0.05361390167048999, 0.07752460720283644, 0.01598136735680912, 0.0970170930294054, 0.008911368337326815, 0.042409548070281744, 0.025929364176200967, 0.01596671269674386, 0.03511982584106071, 0.025546611053869128, 0.018571021700544015, 0.03122143859841994, 0.023821759769426923, 0.0027737368654925376, 0.045030576176941395, 0.010158738769989992, 0.04388626758009195, 0.02092683082446456, 0.036756493018141816, 0.05004834942519665, 0.054649254506719966, 0.04944243461691907, 0.029286297437335764, 0.04232978967151471, 0.03051543648221663, 0.04765724290960601, 0.03570719289460352, 0.0661689369007945, 0.019263147775615965, 0.02668118097686342, 0.058513562328049114, 0.05888905682201896, 0.010383738437667489, 0.026801458094269037, 0.011913081730848976, 0.008388418005779386, 0.021197255867134248, 0.042450558726808856, 0.019479430812810148, 0.045492132660001516, 0.01251337572466582, 0.03855115707431521, 0.07075361481734685, 0.03307090453537447, 0.03719207178801298, 0.10180016101471015, 0.039817350916564465, 0.029454350205404416, 0.07776096809123244, 0.05056920986888664, 0.05480920556666596, 0.02164213904844863, 0.11448252334126405, 2.5382857280118123, 11.5675607749394, 35.367696149008616, 41.694586821964805, 37.56329911095755, 33.11151531764439, 25.79199457168579, 18.349711315972463, 24.904051269803727, 24.668208565030778, 18.851369517190115, 21.159250157220022, 13.236149821962629, 6.626613812787192, 2.3352878093719482, 0.485505647957325, 0.17591329770428793, 0.17141429840454034, 0.2275901718863419, 0.404486069721835, 0.9587231895753315, 2.1008171566895077, 0.75182336888143, 4.770103786672864, 4.980404913425446, 4.580605132239206, 4.898308038711548, 4.868077295167105, 5.532492271491459, 3.850683408124106, 5.74973247732435, 6.04302636214665, 3.721013520445142, 3.797066765172141, 3.323039378438677, 5.6892653448241095, 7.244582687105451, 12.534536361694336, 21.15845285143171, 29.78978306906564, 38.55875710078648, 37.5051565851484, 40.840576784951345, 41.650580406188965, 45.95330449513027, 24.582252400262014, 28.117587906973704, 42.70942333766392, 43.92814084461757, 50.30428729738508, 44.88222926003592, 50.48645864214216, 43.85630341938564, 39.0519506590707, 33.899569579533164, 29.04332767214094, 18.976880039487565, 21.389080933162145, 12.651800240789141, 7.551039934158325, 5.380997223513467, 6.733943504946573, 4.730533795697348, 5.362046880381448, 6.040494612285069, 5.804866433143616, 8.701323764664785, 6.835137503487723, 6.0258356503077914, 5.566960547651563, 4.98317550761359, 2.5828195554869513, 2.3809211892741065, 0.9876876239265714, 0.26205980511648314, 0.19486913696995803, 0.16528632651482308, 0.09195590711065701, 0.675024495593139, 2.4365632321153368, 6.31015637091228, 15.691669259752546, 17.812551294054302, 19.364978619984218, 35.673125062670024, 22.277708632605417, 26.22249800818307, 37.445541041237966, 29.862839903150284, 12.342333555221558, 0.9299493964229311, 0.23487606378538267, 0.022181002722520913, 0.03504359243171556, 0.09189855054553066, 0.05440533813089132, 0.014272894211379545, 0.019816951094461337, 0.02810385517243828, 0.009659406546104168, 0.01791634058047618, 0.06253909346248422, 0.029497810373348848, 0.06870040856301785, 0.029419083347810165, 0.029319779747830968, 0.025847091805189848, 0.014253211606826102, 0.06930810452571937, 0.05678478402218648, 0.0565121215102928, 0.01822595950216055, 0.06539614658270564, 0.048044408205896616, 0.051806016359478235, 0.014878252620941826, 0.03767599278528776, 0.005982612301262894, 0.031091153089489256, 0.03876492953194039, 0.013889252208173275, 0.011592910741455853, 0.05533940604488764, 0.04666072941784348, 0.07725302356162242, 0.005523760204336473, 0.047085156464683156, 0.0072091877560264295, 0.032715745735913515, 0.05317861127800175, 0.04688888681786401, 0.1733558585069009, 0.1887286664651973, 0.08722260966897011, 0.14760170903589043, 0.1335719118693045, 0.10220783842461449, 0.09903785173914262, 0.11178089545241424, 0.16318598921809876, 0.0671600458611335, 0.22512878610619477, 0.17924472822674684, 0.18699491449764796, 0.19335257049117768, 0.1233499175203698, 0.11316158529371023, 0.08404617690082107, 0.15536330826580524, 0.12513226616595471, 0.2004676479846239, 0.1190028829233987, 0.11287592205085925, 0.15655261730509146, 0.1301259853477989, 0.12199926642434937, 0.19052160025707313, 0.17426069852496895, 0.10119855829647609, 0.18506535089441709, 0.09342165131654058, 0.05944642584238734, 0.10539995892239468, 0.20786066699240888, 0.222459470054933, 0.17229237700147287, 0.10497549455612898, 0.11034198730651822, 0.10058422626129218, 0.1672129724174738, 0.076139025124056, 0.14179852471819945, 0.1949693158801113, 0.07219922688922711, 0.12940003430204733, 0.3190481700003147, 3.2763392329216003, 14.943839856556483, 38.94366645812988, 47.74461609976632, 46.361049107142854, 42.23598003387451, 31.514510086604528, 21.667905194418772, 30.644543511526926, 28.07618359157017, 26.323432752064296, 23.610746588025773, 14.63439314705985, 8.498047266687665, 3.9990209341049194, 1.0485794650656837, 0.42700518135513577, 0.8924296125769615, 1.295027726462909, 4.056637568133218, 5.201624265738896, 6.519749649933406, 5.290190781865801, 8.950398445129395, 10.28495979309082, 14.406229938779559, 10.269632066999163, 12.259975688798086, 11.721207158906118, 9.529509084565298, 11.682383230754308, 7.13691383600235, 7.97882228238242, 9.230734808104378, 3.194858576570238, 4.870281611170087, 7.871910350663321, 13.128589102200099, 21.863307646342687, 30.68642725263323, 38.91600567953927, 38.90618440083095, 43.81742477416992, 46.199545179094585, 50.25086259841919, 29.305174010140554, 32.53739261627197, 47.84706033979143, 45.546442304338726, 54.72344582421439, 49.45884091513497, 51.01005751746041, 45.192108494894846, 41.34664535522461, 36.23071105139596, 28.47190955707005, 21.27108141354152, 20.92132125582014, 11.311119266918727, 9.091106414794922, 6.915339257035937, 8.027003696986608, 6.124917830739703, 9.739766785076686, 8.783187440463475, 9.146639023508344, 13.24407684803009, 21.58335951396397, 11.778038212231227, 10.46727010181972, 12.017808386257716, 7.752009630203247, 5.405207787241254, 2.80232726250376, 0.9585983391319002, 1.991759100130626, 0.8503246147717748, 0.713678030031068, 0.9470264400754655, 3.683570546763284, 7.241538941860199, 17.388374192374094, 20.94971333231245, 29.316315446581157, 43.26510551997593, 22.98464093889509, 34.378255299159456, 42.436626638684956, 35.277070794786724, 15.357796158109393, 1.735000797680446, 0.2315430183495794, 0.15997938199767045, 0.1316609808376857, 0.20644741425556795, 0.26717620342969894, 0.09502703802926199, 0.19123583978840283, 0.13522565098745482, 0.0940941134467721, 0.16557475818055017, 0.08398561086505651, 0.13670951207833631, 0.1973222717642784, 0.12795171487544263, 0.0819344198597329, 0.1031509478177343, 0.17166082374751568, 0.09205291047692299, 0.20384733591760906, 0.1143947344805513, 0.10030648152210883, 0.17149626543479307, 0.10587962211242744, 0.16585484386554786, 0.09710394551179238, 0.19642608985304832, 0.15952890259878977, 0.12915371251957758, 0.1788797170988151, 0.12280138981129442, 0.07079301056052957, 0.16011196774031433, 0.12002482451498508, 0.18256180094821112, 0.06576471323413507, 0.12743287985878332, 0.13122936471232347, 0.15000900200435094, 0.11691881689642157, 0.11062630705003228], [0.047521451088998995, 0.008362390250632805, 0.01539798330382577, 0.0409909281214433, 0.10236179802034583, 0.05800459999591112, 0.07265686483255454, 0.018061380833387375, 0.014195690496957727, 0.0319606007209846, 0.014492668311244674, 0.04316228089321937, 0.053754483948328664, 0.04233545204624534, 0.019794618810660074, 0.01893175296884562, 0.08035244260515485, 0.03447579432811056, 0.02439609046892396, 0.03121950477361679, 0.01632850247967456, 0.03906575803245817, 0.004615343034466994, 0.00588657075838585, 0.03738382239160793, 0.0204369794311268, 0.03387182691533651, 0.04622267399515424, 0.006480464046554906, 0.012082925831366862, 0.01514339866116643, 0.019876243180728385, 0.02463829015115542, 0.025744587216260176, 0.011841937334143689, 0.05388803321069904, 0.06375566603881971, 0.023483089370919124, 0.0586640274684344, 0.043602887607578716, 0.02666109973298652, 0.02273194771260023, 0.018558707986293093, 0.0280749037795301, 0.005833855796871441, 0.01639912779709058, 3.6993681447846547, 14.403118014335632, 29.619350705827983, 41.47955397197178, 36.992042541503906, 30.069736412593297, 22.544495139803203, 17.220425810132706, 21.468335560389928, 22.54368567466736, 18.877692767551967, 15.833198853901454, 10.58292634146554, 6.776208528450557, 4.190719561917441, 1.065344165478434, 0.46887231192418505, 0.1931750385888985, 0.08435673559350626, 0.47907704434224535, 1.2867581759180342, 0.9729157537221909, 2.557118386030197, 3.9920375602585927, 0.9502057837588447, 4.261331932885306, 2.844083547592163, 4.795243237699781, 1.8425573919500624, 4.046042433806828, 4.60632996899741, 3.2262249163218906, 2.087653794458934, 2.2278677906308855, 2.3837545343807767, 2.387778627020972, 5.1314109819275995, 10.20283121722085, 14.24440552507128, 24.750541244234356, 23.871234553200857, 28.487525633403234, 31.418062141963414, 34.35827228001186, 24.777979680470057, 14.453298773084368, 27.686066559382848, 39.97083602632795, 44.15211950029646, 41.825334548950195, 35.71886852809361, 31.471500737326487, 28.18855333328247, 22.545348031180247, 16.04987668991089, 12.851887515613011, 7.313827565738133, 3.7127542836325507, 2.631138848406928, 2.1635882684162686, 4.44892417533057, 4.348971733025142, 5.526603238923209, 5.6850786209106445, 3.9880045652389526, 7.622516053063529, 3.3947048357554843, 3.6967729926109314, 3.675187110900879, 3.6979255250522067, 1.4468882062605448, 0.9067025152700288, 0.6276318643774305, 0.10157280428601162, 0.11473664827644825, 0.1715188877923148, 0.74430172677551, 2.492091063942228, 6.184592868600573, 9.676013588905334, 11.828811304909841, 15.15130090713501, 32.559810979025706, 25.346646308898926, 20.735349246433803, 35.970306464603965, 27.53479037966047, 15.583907910755702, 3.8410896829196384, 0.2309357566492898, 0.07037843244948558, 0.051110412792435715, 0.05197142284097416, 0.03184415054108415, 0.011980933536376272, 0.025466503209567497, 0.034756986025188646, 0.039874575167362175, 0.031379720462220054, 0.0530515725591353, 0.03292529431304761, 0.033176158887467215, 0.043646737933158875, 0.011329825751350393, 0.022425280418246984, 0.04750602459535003, 0.033771773534161706, 0.05120327030973775, 0.0618273780814239, 0.02481696199226592, 0.04249927754114781, 0.017390801637832607, 0.038403731770813465, 0.03467218271855797, 0.025566125721005455, 0.03704861252169524, 0.017243491685284034, 0.08012473303824663, 0.08658499031194619, 0.02407453102724893, 0.02723826331618641, 0.050797017823372564, 0.07498183793255261, 0.016182239167392254, 0.0085869132474597, 0.02320877292991749, 0.10071740911475249, 0.05407579402838435, 0.05244956611256514, 0.01726691810680287, 0.04592556386653866, 0.02654252404214016, 0.012224158654654664, 0.03063108938347016, 0.10940491008971419, 0.032192829331117015, 0.035425441406135044, 0.04985886512856398, 0.1160302074359996, 0.06178380934787648, 0.02705160851058151, 0.01038034661074302, 0.052323114326489825, 0.08343350049108267, 0.03897164522537163, 0.03991520245160375, 0.039436760624604564, 0.03753377863072923, 0.0348311600807522, 0.0667655523866415, 0.004264889451275978, 0.0346395350061357, 0.04712214680122478, 0.030813530486609255, 0.031334638595581055, 0.07626430982989924, 0.04159358596163137, 0.0340771075072033, 0.04703360476664134, 0.017870642943307757, 0.005957688013690391, 0.03229027035247002, 0.035366313864610026, 0.05996110822473254, 0.019888918214876736, 0.06039675484810557, 0.029846261854150465, 0.08633461089006492, 0.04465206898748875, 0.03834674839994737, 0.026701905132670487, 0.0556573166644999, 0.04843830117689712, 0.0517586919346026, 0.028385106241330504, 0.1292049012013844, 4.6125399214880805, 17.25879202570234, 34.587997095925466, 46.06246764319283, 41.02558994293213, 32.5266090120588, 23.7298196043287, 19.987031732286724, 21.349128791264125, 24.69924964223589, 19.342082568577357, 17.18514633178711, 12.841897743088857, 6.97614598274231, 3.80186710187367, 1.0576983243227005, 0.22648345412952559, 0.26335227862000465, 0.14288367863212312, 0.36798723680632456, 0.7558292767831257, 1.9312172744955336, 3.8960638301713124, 2.03794573034559, 3.68535840511322, 4.7278279066085815, 4.999535475458417, 5.093082547187805, 4.981408928121839, 5.888059386185237, 5.105538930211749, 6.949229529925755, 3.638498451028551, 3.497689949614661, 4.330624580383301, 3.6809337053980147, 6.956443497112819, 12.537022948265076, 20.079164845602854, 31.209386893681117, 29.539880684443883, 34.04101405824934, 37.0863539150783, 41.43560314178467, 27.727582045963832, 17.685017108917236, 28.077425582068308, 43.48662798745291, 48.11825200489589, 46.93702697753906, 41.37676927021572, 35.211403369903564, 30.900053092411586, 25.870854888643535, 20.454648971557617, 15.697319882256643, 12.224112561770848, 7.474214570862906, 5.939035713672638, 4.537855037621089, 6.8668686236654, 6.1807770047869, 5.599709144660404, 7.555499809128897, 6.291117872510638, 6.183464220591953, 4.4824752892766675, 3.979111739567348, 2.3729007967880795, 3.2646024227142334, 1.735708536846297, 0.5824834470238004, 0.8779839277267456, 0.15565024715449127, 0.4411734810897282, 0.04886821417936257, 0.8902816964047295, 2.6312962685312544, 7.259407537324088, 9.654841559273855, 16.07179651941572, 14.912326301847186, 29.988345214298793, 31.54425185067313, 20.4411746774401, 35.404653617313926, 31.80401372909546, 19.66583561897278, 4.850940866129739, 0.36575200674789293, 0.04415140513862882, 0.10223084754709687, 0.04609449194478137, 0.06529369458023991, 0.01691083310704146, 0.006591214956383088, 0.03394464390086276, 0.022727057171453322, 0.040391483144568543, 0.01734675792977214, 0.08367633460355656, 0.05647285808143871, 0.09278740427855935, 0.040049694877650054, 0.014067190383294863, 0.05238063374002065, 0.014589342588026608, 0.046335918097091575, 0.015909054183534214, 0.026729236523221647, 0.014711504336446524, 0.015111046111477273, 0.040342472560171566, 0.022049438175080077, 0.09988597301500184, 0.024495490760143315, 0.021769532301862324, 0.014316586777567863, 0.041980713938495944, 0.059987795007015975, 0.09847571940294333, 0.039585081594330926, 0.056683136083717854, 0.027110976932038153, 0.03803124997232642, 0.05964628154678004, 0.052949215551572185, 0.009558563519801413, 0.04094501165673137, 0.007243089910064424, 0.12330588059765951, 0.20446652626352652, 0.0782948937267065, 0.13079717861754553, 0.18815020179109915, 0.1295214242168835, 0.11114058909671647, 0.10005355080855743, 0.23767971619963646, 0.18682650210601942, 0.0981697951044355, 0.1351189309997218, 0.13971103887472833, 0.12802346316831453, 0.19893893572900975, 0.12771539469914778, 0.1260428058781794, 0.1655526515096426, 0.15809430315026216, 0.1332437859049865, 0.11840526999107429, 0.18781755678355694, 0.10209961887449026, 0.0937480605872614, 0.15839462274951593, 0.13527617470494338, 0.18085790452148232, 0.12978225307805197, 0.11982826649078301, 0.07936925893383366, 0.13734144531190395, 0.13416134166930402, 0.09571077062615327, 0.11688635578112942, 0.07134867645800114, 0.15776119673890726, 0.2201088619019304, 0.16851166130176612, 0.1414173101740224, 0.11952260003558227, 0.15305987186729908, 0.13905532977410726, 0.10063325041638953, 0.11973199594233717, 0.08951267892760889, 0.2910054847598076, 5.643614377294268, 19.88509123665946, 38.43954338346209, 54.73194694519043, 48.21724993841988, 39.256679330553325, 32.00776270457676, 27.384549481528147, 30.78255558013916, 31.868249825068883, 28.027068512780325, 21.491532121385845, 14.629015241350446, 9.13566608088357, 5.466508703572409, 2.074782256569181, 1.0182662116629737, 1.076785460114479, 0.7049458814518792, 1.3839788905211856, 4.218423332486834, 4.031310081481934, 6.834538655621665, 10.178535972322736, 5.277865546090262, 12.034480588776724, 9.794099961008344, 11.748346822602407, 7.706259216581072, 11.123366781643458, 11.01818755694798, 8.132500801767621, 5.724575221538544, 5.992542922496796, 4.439339135374341, 3.6052973525864735, 6.916135260037013, 12.996915527752467, 18.29791944367545, 30.999610355922155, 28.61792768750872, 37.47689478737967, 42.07924951825823, 44.846449511391775, 32.550316265651155, 21.51470783778599, 35.160844802856445, 44.48374659674508, 49.49606588908604, 46.77872616904122, 43.46894134793963, 37.93839413779122, 35.7320944241115, 25.9639207976205, 21.692051921572002, 16.012418951307023, 13.09569980416979, 7.145384558609553, 7.135254085063934, 5.482380560466221, 8.290337818009512, 10.109561204910278, 10.604640330587115, 11.718240278107778, 10.881609422819954, 13.450947301728384, 11.314635055405752, 9.17740477834429, 9.110869697162084, 10.083374312945775, 5.355944190706525, 3.8814956290381293, 2.1534871075834547, 0.9168541048254285, 0.8527797716004508, 0.4960936169539179, 1.3160073778459003, 3.735035853726523, 8.513234291757856, 13.6498281955719, 17.070012944085256, 23.25129543031965, 41.59324387141636, 33.564711570739746, 27.49283194541931, 44.680880887167795, 36.61180932181222, 22.87380674907139, 5.901941452707563, 0.5049959963985852, 0.14418491880808557, 0.22808702236839704, 0.19534811483962194, 0.24353064224123955, 0.1371239884091275, 0.08944759384862014, 0.26777355851871626, 0.1728722530284098, 0.07938253107879843, 0.10579820469553981, 0.10940876416862011, 0.11080613240067448, 0.14986712033195154, 0.13481743074953556, 0.1148863738136632, 0.1333072424999305, 0.1852431134986026, 0.2499381841293403, 0.1851455673043217, 0.0951921527406999, 0.1249998432717153, 0.1433373335748911, 0.1408455494259085, 0.11385573340313775, 0.17747989935534342, 0.121380551052945, 0.13347771763801575, 0.137174145717706, 0.10412947673882757, 0.14405390726668493, 0.33832600127373424, 0.2777684064848082, 0.19159036076494626, 0.09678649290331773, 0.12355748138257436, 0.12238030454942159, 0.22147729061543941, 0.10106990127159016, 0.11478615419140883, 0.09196021580802542], [0.021144396292843988, 0.07884799476180758, 0.010335807572118938, 0.035261303785123994, 0.026485479603122388, 0.1465948037803173, 0.015672944353095124, 0.056261263721223385, 0.016399119315402846, 0.014857519983447023, 0.03397148674620049, 0.01676382849525128, 0.007601050210983625, 0.028727279576872076, 0.0566199576881315, 0.012880122205907745, 0.03878922787095819, 0.06964921086494412, 0.039803729326065095, 0.0587632292881608, 0.008811281029401081, 0.01977057831494936, 0.016018361086025834, 0.03365057700180581, 0.06550512609205075, 0.07623333470629794, 0.02059372780578477, 0.032229293803019185, 0.02347780019044876, 0.044232340795653205, 0.00942716860611524, 0.0271043272888554, 0.00859092254125114, 0.02086726393151496, 0.02217265504545399, 0.019655800723869885, 0.0353543275435056, 0.06097075476178101, 0.02582171289915485, 0.017450614499726465, 0.039494514132716825, 0.05459990126213857, 0.09085170671875988, 0.025059209171948687, 0.04121213732287288, 0.055424643613930256, 0.11482594348490238, 4.191995424883706, 17.49436375073024, 33.35125248772757, 39.025293895176475, 46.10714108603341, 31.45784752709525, 24.013278314045497, 23.503026928220475, 16.80521535873413, 16.39905493600028, 23.01739648410252, 13.729397228785924, 10.673232078552246, 6.7865374599184305, 3.4089599336896623, 1.4511709021670478, 0.4437639106597219, 0.2019766148711954, 0.2563634222107274, 0.34125382559640066, 0.6085713814411844, 4.87273519379752, 1.591953022139413, 3.6323501638003757, 2.0647985637187958, 3.4727198609283993, 3.768224358558655, 3.6686427763530185, 3.657659411430359, 5.924082321780069, 4.485978049891336, 2.679434908287866, 1.8507595232554843, 3.0734379376683916, 1.2210137780223573, 1.8155008895056588, 5.553632165704455, 6.96817900453295, 10.343955210277013, 15.290395157677786, 20.9621992451804, 23.535271780831472, 28.499335833958217, 27.002695594515117, 16.822775193623134, 16.419196026665823, 27.393602984292166, 37.58445290156773, 25.99962064198085, 25.970775195530482, 23.045802456992014, 16.46983970914568, 13.308357238769531, 11.332498873983111, 5.236624947616032, 4.316015124320984, 4.358981481620243, 1.0298983646290643, 2.280775717326573, 4.191341859953744, 4.334605463913508, 2.775011722530637, 7.299422213009425, 8.087518164089747, 5.354394308158329, 2.4390828226293837, 5.371714864458356, 2.074228354862758, 2.090743354388646, 0.5779626124671527, 0.516289153269359, 0.5210006290248462, 0.13588193005749158, 0.33952850103378296, 0.918186856167657, 1.8508950131280082, 5.467028081417084, 9.62485921382904, 15.984136308942523, 17.440167801720754, 28.04378240449088, 42.08691685540335, 17.58714304651533, 28.086711849485123, 34.11201075145176, 21.229552030563354, 5.73567453452519, 0.4002339893153736, 0.08477381749876908, 0.05822143943182059, 0.050999007520398924, 0.06707069636987788, 0.05168742200891886, 0.019649841490068605, 0.14840159325727395, 0.008246534637042453, 0.02184310246125928, 0.03391372645273805, 0.02320475091359445, 0.026931287288399677, 0.05900518809046064, 0.04065794723906687, 0.0555411955740835, 0.06467301824263164, 0.017389542955373014, 0.07202609867921897, 0.027258604099707942, 0.0063924105571849, 0.048601329393152676, 0.033076142825718434, 0.059538313054612706, 0.03419993252360395, 0.019872382316472273, 0.029968683142215014, 0.07136171790105955, 0.042114249630165954, 0.14234503039291926, 0.0331296758460147, 0.0179013466529016, 0.03955371292041881, 0.02714500037421073, 0.0199242291772472, 0.024943707244736806, 0.06188497891915696, 0.03411788406914898, 0.05293919698202184, 0.01666476407886616, 0.014934152032115629, 0.028582449669816663, 0.02516599022783339, 0.09624236210116319, 0.018043840703155314, 0.03165283080722604, 0.06354658225817339, 0.027456364827230573, 0.012654147992309715, 0.04935787558289511, 0.03500268016276615, 0.04762164356985262, 0.02069246313268585, 0.04074386673580323, 0.0070050203856746, 0.0627098942973784, 0.020862246165052056, 0.03475470954020109, 0.03713018600163715, 0.012273209102983986, 0.022335123470319167, 0.05661884489070092, 0.02434628430221762, 0.04379552369937301, 0.03960208907457335, 0.016394761424245577, 0.018955883370446305, 0.016365826994712864, 0.07271937147847243, 0.01796622647504721, 0.04238442870389138, 0.013000496862722295, 0.009341408565108265, 0.03930737417457359, 0.03872489596584013, 0.029410981639687504, 0.005694158159063331, 0.04260597038748009, 0.03201337378205998, 0.07350141022886549, 0.032561796318207464, 0.033108658223812065, 0.07596333883702755, 0.03354655758344701, 0.03475031602595534, 0.0872858694887587, 0.05753135574715478, 0.007120293731402073, 0.34638308893357006, 5.849113430295672, 21.74564858845302, 38.01991735185896, 43.49990946905953, 49.19491706575666, 34.08226203918457, 24.269269057682582, 24.897827420915874, 21.715000084468297, 24.44206554549081, 24.241794143404277, 21.152486085891724, 13.272600940295629, 8.479406118392944, 3.7711356537682668, 1.2742168945925576, 0.3832141325942108, 0.11185911696936403, 0.18643607305628912, 0.3684308630015169, 0.9813524952956608, 1.444777473807335, 1.6571273420538222, 1.5066219781126295, 2.8804245804037367, 2.732502209288733, 5.153439377035413, 5.229753613471985, 4.60095032623836, 6.650239425046103, 6.576734866414752, 4.385228736060006, 3.8882479752813066, 4.418147998196738, 3.216097265481949, 3.6104820115225653, 6.325864510876792, 11.383972866194588, 13.393919961793081, 21.61510409627642, 24.18754608290536, 28.568670170647756, 32.86202982493809, 31.982853412628174, 19.103114911488124, 17.532516309193202, 33.12922280175345, 42.47922257014683, 32.198622771671836, 31.268818310328893, 27.216856445584977, 20.86057836668832, 17.165095567703247, 12.81177817072187, 7.980030400412423, 6.750193170138767, 5.259784162044525, 3.613261942352567, 6.372760508741651, 9.7050735609872, 5.452972744192396, 7.103845621858325, 7.395087616784232, 1.9690167776175906, 5.7337676882743835, 4.378767779895237, 3.752243067537035, 2.4953328328473225, 1.4697291063410896, 1.295822860939162, 0.7456556484103203, 0.1467838300658124, 0.12656647206417151, 0.13259830911244663, 0.6938218155077526, 2.1411366845880235, 5.570599232401166, 10.35002967289516, 20.19952154159546, 15.72089512007577, 24.341346195765905, 43.994649001530235, 22.537871769496373, 29.26781702041626, 41.08015414646694, 24.529512098857335, 8.347593579973493, 0.8586975740534919, 0.18131039238401822, 0.051200637593865395, 0.030481706506439617, 0.044676438572683504, 0.02502531125875456, 0.024252917883651595, 0.06922412224646125, 0.0038694863157745984, 0.017146052360268574, 0.0336716692628605, 0.07527904984142099, 0.02656372486879783, 0.02854557807690331, 0.025095632931749736, 0.015732560439833572, 0.027045974973589182, 0.05713897251657077, 0.025322394245969396, 0.048340602312237024, 0.023890278235610043, 0.08851135801523924, 0.01787876840015607, 0.06684504954942636, 0.0275528423288571, 0.06529361994138785, 0.038895082726542435, 0.04439670233322041, 0.019919058740405098, 0.019837656590555395, 0.01173222839965352, 0.006066649711491274, 0.05599061306566, 0.014977756388751524, 0.025588101773921932, 0.039440109194921594, 0.010845585842616856, 0.11175996264708893, 0.03859508203874741, 0.051484282195035896, 0.059202675707638264, 0.028778983945293084, 0.11980872468224593, 0.22492727477635654, 0.09948586127055542, 0.08693641716880457, 0.16868177003094129, 0.22779020400983946, 0.09587856555091483, 0.15432058993194783, 0.14286894085151808, 0.1657027977385691, 0.10952199130718197, 0.09349260572344065, 0.15903255423264845, 0.10768780937152249, 0.08759503039930548, 0.10496086534112692, 0.09724943699049098, 0.10292653593101672, 0.09288593434861728, 0.13187490935836518, 0.12106714929853167, 0.09380771738610097, 0.11969394369849137, 0.1218053682574204, 0.17534288045551094, 0.1428018201674734, 0.13333826512098312, 0.08460505905428103, 0.11347327713987657, 0.15536706734980854, 0.07438937508101974, 0.13661208802035876, 0.14754347716059002, 0.11105906989957605, 0.05475599824317864, 0.12041958261813436, 0.13622711439217838, 0.13442841305264405, 0.1207959388515779, 0.1172166530575071, 0.12130264166210379, 0.1877563800662756, 0.19813398963638715, 0.11053251993975469, 0.3447613902390003, 0.09761724368269954, 0.4859772026538849, 5.845403960772923, 24.807764870779856, 43.45915828432356, 49.8288185937064, 58.299881662641255, 41.5733094896589, 33.7052458354405, 33.53310074125017, 27.81260715212141, 28.577919960021973, 34.03165136064802, 19.97513815334865, 15.084619045257568, 9.617104155676705, 4.696541036878314, 2.1467341099466597, 0.8788167887500354, 0.8258131614753178, 0.8345189286129815, 1.6927813717297144, 2.454993111746652, 8.233237521989004, 5.513911051409585, 8.885404995509557, 6.410505294799805, 7.850045238222394, 9.64047702721187, 10.997718163899012, 8.409165041787283, 14.701069797788348, 10.07762815271105, 6.0490352511405945, 6.562239621366773, 7.941348910331726, 2.939345738717488, 3.0512126045567647, 8.123609713145665, 10.762993250574384, 13.444841572216578, 21.784897225243704, 26.738108192171367, 31.05818714414324, 33.489136014665874, 35.74809612546648, 26.26609969139099, 25.05262460027422, 35.79159532274519, 44.4060275214059, 34.062018462589805, 34.13533932822091, 31.269221305847168, 22.228319099971227, 18.546623264040264, 15.57219672203064, 8.547562735421316, 7.445207578795297, 6.833119051797049, 3.8698925716536383, 6.406375024999891, 10.68467663015638, 8.993875929287501, 8.06352777140481, 16.05772989136832, 14.745982953480311, 13.018961293356758, 7.793781331607273, 9.208201800073896, 5.423967923436846, 5.7109211427824835, 3.0670178021703447, 2.315709739923477, 1.5636942642075675, 0.38866447870220455, 0.6347204925758498, 1.5795044558388847, 2.8623748975140706, 7.479418771607535, 13.796446476663862, 22.908059631075176, 24.677918672561646, 38.90819590432303, 49.95112425940377, 25.544866255351476, 37.464464460100444, 45.05888720921108, 30.019264698028564, 9.621009911809649, 1.1120245520557677, 0.20073595430169786, 0.2524556576141289, 0.18665414064058236, 0.18227046515260423, 0.18066231001700672, 0.1037000794229763, 0.16914993205240794, 0.14289767002420767, 0.14144625647791795, 0.14449825270899705, 0.2622964238481862, 0.11348566718931709, 0.0949455052614212, 0.11203720527035849, 0.11008809307324034, 0.16189302716936382, 0.10732725621866328, 0.22407514335853712, 0.08545843897653477, 0.11821480521133967, 0.18201593309640884, 0.14586609788239002, 0.1362111959606409, 0.0940612248544182, 0.13210687333984034, 0.1353825961372682, 0.12840075578008378, 0.1204877889582089, 0.19512053419436726, 0.11799487844109535, 0.06986789591610432, 0.12794414242463453, 0.11525580898991653, 0.06532155522810561, 0.1053438237203019, 0.16162154530840261, 0.27822807324784143, 0.0919854301693184, 0.09815146787358181, 0.18564395127551897, 0.11110479637448277], [0.06585547407822949, 0.10535649196910006, 0.011725022357755473, 0.02807383847955082, 0.030650020510490452, 0.05050895595923066, 0.037460344178336005, 0.074815970047244, 0.05871886666864157, 0.02463372700315501, 0.04683431224631412, 0.02928789538730468, 0.03911814432857292, 0.04940609906667045, 0.036598913438085995, 0.004270926716604403, 0.015518893155136278, 0.0379216122840132, 0.027480059270081774, 0.002480453674382131, 0.0393118864324476, 0.07212810963392258, 0.047079093754291534, 0.016378958343661258, 0.058279528814767084, 0.01671902652430747, 0.052253632340580225, 0.039757283604038615, 0.025259416018213545, 0.004339991827561919, 0.022226389929918305, 0.010357701352664402, 0.03170925099402666, 0.018388719697083746, 0.007116707673828516, 0.07441069465130568, 0.058935156491185935, 0.05641595274209976, 0.02375619293057493, 0.0436627411815737, 0.03423274647710579, 0.025606953173077533, 0.05269287859222718, 0.05164993634181363, 0.06925268857074635, 0.03794859083635466, 0.08128159453294106, 0.5588382929563522, 5.637805249009814, 18.50802080971854, 32.361936705453054, 40.23931441988264, 38.35825988224575, 26.014012098312378, 20.620966264179774, 19.388560806001934, 11.220960310527257, 29.222229889460973, 22.44551110267639, 19.517369985580444, 13.706501177379064, 8.892761400767736, 4.747212077890124, 2.020691833325795, 0.581026876611369, 0.44941529312304085, 0.0788683101002659, 1.3328349377427782, 1.9718351406710488, 0.27553040800350054, 0.8473444889698709, 2.196643020425524, 2.08605049763407, 4.7842824544225415, 3.028045573404857, 3.2314106609140123, 1.8341943664210183, 7.69915555204664, 3.9898154394967213, 2.574632840497153, 1.4555838767971312, 2.690600663423538, 1.8394443818501063, 0.8336994754416602, 6.117952695914677, 7.113224387168884, 10.73239164693015, 12.892218334334236, 17.489854369844707, 17.539389814649308, 19.675359862191335, 12.654724563871111, 10.182296684810094, 18.177284819739207, 25.11238431930542, 23.07031570162092, 20.75826093128749, 12.32444715499878, 8.497064096587044, 8.453749026571002, 4.539324147360666, 3.772696827139173, 2.301239464964185, 2.3400549249989644, 3.194986032588141, 7.9624627488000055, 7.336029665810721, 3.6226066180637906, 5.523366681167057, 4.091338174683707, 0.8712973722389766, 3.989116277013506, 3.8873012832232883, 2.359817555972508, 0.7868336588144302, 0.7742608934640884, 0.39547865305628094, 0.07028809908245291, 0.16668356582522392, 0.5378936539803232, 0.9531723388603756, 2.941862723657063, 4.599706164428166, 11.133548498153687, 14.90532078061785, 17.92650522504534, 12.310621976852417, 21.536248990467616, 25.981623070580618, 21.10599742616926, 30.10958433151245, 24.7327173777989, 13.89761051109859, 2.053153165749141, 0.10808931211275713, 0.050588751677423716, 0.004007073285590325, 0.060941903452788077, 0.05881170382989304, 0.027441538837073103, 0.011627521964588335, 0.038412301668098996, 0.03922745632007718, 0.032648021155702214, 0.05783052183687687, 0.022906032656984668, 0.08078580935086523, 0.07069232953446251, 0.0228346524693604, 0.01939227638233985, 0.013651083872121359, 0.053523632764284096, 0.019443527828635912, 0.053873244539967606, 0.07491706497967243, 0.04670036604095783, 0.01144267715114568, 0.029825664923659394, 0.07263819833419152, 0.08545869003449168, 0.012942879909782537, 0.023932783365515724, 0.04500397760421038, 0.0033036784401961733, 0.027000748918258717, 0.0638216399986829, 0.05804996684725795, 0.0490062078461051, 0.02176914892957679, 0.015516204460124885, 0.04205660129498158, 0.019632917130365968, 0.06005930581263133, 0.03168584153588329, 0.033112234103360345, 0.02952779144314783, 0.050835986089493544, 0.015375756192952394, 0.05921192413994244, 0.02059091018911983, 0.06744800255234752, 0.00884714414964297, 0.01778750035113522, 0.02007134065830282, 0.0564623204325991, 0.0438692227804235, 0.012150773396050292, 0.03578463748895696, 0.05679976946807333, 0.07038428820669651, 0.02651293821898954, 0.00963909799299602, 0.05340790183150342, 0.058918756299785206, 0.04653451851169978, 0.020178167515301278, 0.016291778468127762, 0.05593914957717061, 0.0365813427737781, 0.014219517254137566, 0.06832263419138533, 0.00857855030335486, 0.08235675362604004, 0.053779107984155416, 0.038195292598434856, 0.030893237995249883, 0.03441573380093489, 0.026824731845408678, 0.007098455929995647, 0.03943524070616279, 0.013536470825783908, 0.04961648563455258, 0.05123027939615505, 0.06727059957172189, 0.04860233362498028, 0.09847719860928399, 0.02949363399030907, 0.009871014477019864, 0.025919074192643166, 0.06205541334514107, 0.01125018609621163, 0.022512551896007996, 0.011714129326199847, 0.9214433899947575, 7.865529298782349, 22.841641800744192, 38.62012011664254, 45.94212484359741, 41.94156401497977, 29.899349212646484, 23.648289442062378, 23.729275907788956, 15.011331183569771, 33.592827456338064, 21.267341545649938, 21.64500740596226, 16.523931435176305, 9.326193502971105, 5.490878641605377, 1.6382079401186533, 0.40680427104234695, 0.08184643422386476, 0.06903239539159195, 0.24370299013597624, 1.3964860822473253, 0.2680278734437057, 1.1767452848809106, 1.6085020026990344, 2.134648369891303, 3.6826190778187344, 3.3514394887856076, 3.9775188650403703, 5.497224952493395, 5.651096284389496, 4.363042703696659, 5.662597290107182, 2.803315209490912, 3.4833892541272298, 3.5485464206763675, 2.4345430433750153, 5.761477104255131, 8.206083961895533, 13.737155761037554, 16.791440555027553, 21.648194892065867, 23.15428294454302, 23.532678365707397, 17.26089906692505, 11.230967453547887, 23.155203580856323, 31.00601659502302, 26.630840165274485, 24.74572093146188, 15.479031801223755, 11.65075763634273, 10.57564810344151, 6.408889838627406, 4.551149112837655, 4.95329521383558, 4.153835918222155, 3.580401522772653, 8.771467566490173, 9.177580220358712, 5.435518000807081, 7.158943099634988, 7.473498906408038, 5.399237547601972, 2.2659354507923126, 1.509391269513539, 2.1948143414088657, 1.8944560928004128, 0.6438401117920876, 0.054099264554679394, 0.2572307256715638, 0.1322216136114938, 0.35678720208151, 1.351373274411474, 3.0222562040601457, 5.512685997145517, 12.38423466682434, 19.30782273837498, 21.881529297147477, 15.300640276500157, 28.217589855194092, 30.599025862557546, 23.036474500383648, 34.0861565044948, 29.46280779157366, 16.085750239236013, 2.938918858766556, 0.1472652099494423, 0.05692141383354153, 0.018709648101191436, 0.023366366080673676, 0.020341051542865377, 0.049626246360795837, 0.03317036759108305, 0.01825042747493301, 0.03823273416076388, 0.00642404767651377, 0.020427161029406955, 0.054636267346463034, 0.011994663692478622, 0.06240943220577069, 0.03232132350759847, 0.008152359913635467, 0.015254825985591327, 0.013108228715801877, 0.01597873124826167, 0.03211753908544779, 0.028791455418935845, 0.03726735185565693, 0.027631416684016585, 0.0473056294556175, 0.07287994679063559, 0.022381099306845238, 0.014291060290166309, 0.008707068228561963, 0.015689677026654993, 0.010145637955117439, 0.008902444753662815, 0.031236003352595226, 0.023659418569877744, 0.03896810666524938, 0.04093564108812383, 0.025477047643757293, 0.032651356155318875, 0.06921090438429799, 0.08820164749132735, 0.06958260586751358, 0.0268982171879283, 0.05041665144796882, 0.17090566855456146, 0.23437180370092392, 0.13517467943685396, 0.1328679724995579, 0.1509787778237036, 0.11839258138622556, 0.17672923606421265, 0.118229298719338, 0.14431137059416088, 0.07451497869832174, 0.18519467966897146, 0.15864223374852113, 0.2096738346985408, 0.2405421840293067, 0.0777687169611454, 0.11198767221399716, 0.13838539857949528, 0.14947472353066715, 0.08794075756200723, 0.10925453315888133, 0.10317903238215617, 0.13687561745090143, 0.12970483223242418, 0.1010603407131774, 0.09276466657008443, 0.15530753268727235, 0.17959247742380413, 0.16467611997255258, 0.094578621376838, 0.1410142332315445, 0.05926612551723208, 0.09299363142677716, 0.097510577977768, 0.10973008442670107, 0.06939452274569444, 0.1571150549820491, 0.12539078800805978, 0.16235323676041194, 0.16253163718751498, 0.22617136873304844, 0.24188731185027532, 0.1097234415688685, 0.11019517946988344, 0.2072498904807227, 0.23101517238787242, 0.09080030090574708, 0.18892674440784113, 1.0830051835094179, 8.58779627936227, 24.725232430866786, 43.541226931980674, 52.150552204677034, 50.58269466672625, 37.61308642796108, 31.805584021977015, 30.02874551500593, 19.48153465134757, 41.842451436179026, 29.33163969857352, 27.24834394454956, 19.284287452697754, 12.799142003059387, 6.4057614122118265, 3.4840406477451324, 1.1759465677397591, 0.8634743520191738, 0.8883428775838443, 2.6490287227290015, 4.209720279489245, 2.2728178586278642, 5.017888273511614, 8.592313476971217, 8.266519393239703, 12.110376630510602, 7.386319858687265, 10.3101270369121, 8.480369312422615, 16.55185624531337, 9.161159890038626, 7.194784079279218, 4.952442756720951, 6.179029967103686, 4.278475310121264, 2.6937492830412726, 8.02340453011649, 10.527000291006905, 13.762422016688756, 18.298122678484233, 22.336214201790945, 23.558947767530167, 23.45452502795628, 21.20183914048331, 16.003153528485978, 23.844727175576345, 31.14925023487636, 27.396993705204554, 24.40872287750244, 15.856122698102679, 12.73999980517796, 11.552568299429756, 6.1129226343972345, 6.103809203420367, 6.032626211643219, 5.1953904288155695, 8.379127979278564, 16.45501572745187, 17.314127479280742, 12.571914196014404, 12.88400035245078, 11.417768904141017, 7.484761067799159, 9.489131365503583, 8.529328056744166, 7.63397102696555, 4.517913707665034, 2.2197321014744893, 1.5687915278332574, 0.6549700945615768, 0.5696829110383987, 0.8782527361597333, 1.6389091653483254, 4.027302707944598, 7.359815086637225, 16.584714276450022, 21.63074275425502, 25.140941415514263, 19.797721113477433, 32.08460978099278, 34.44844600132534, 28.562260457447596, 40.74360772541591, 33.1530134337289, 18.375398806163243, 3.864672303199768, 0.21263378086899007, 0.1612092810017722, 0.21903273250375474, 0.1437459880752223, 0.1871503804411207, 0.22919232877237455, 0.18718453789395945, 0.20137535142047064, 0.19197762784148964, 0.07981657635952745, 0.14964427586112702, 0.21704815328121185, 0.20110469737223216, 0.2725451524768557, 0.09875253454915114, 0.06055152190050908, 0.08082929666021041, 0.10962442973894732, 0.10724387783557177, 0.16297108360699245, 0.24703942824687275, 0.1451579923076289, 0.12370262002306325, 0.12884799178157533, 0.14478285743721894, 0.1868572804544653, 0.08111411851963826, 0.10832620904381786, 0.12181516630308968, 0.19527602727924073, 0.177940271794796, 0.11513380839356355, 0.11253717022814921, 0.09167362297219889, 0.12214881554245949, 0.1405483917998416, 0.16463647995676312, 0.14437353797256947, 0.16854257535721573, 0.19913524948060513, 0.11601114060197558, 0.12947578595152923], [0.04225948326555746, 0.058350300017212114, 0.048679581444178305, 0.009476574437160577, 0.03728661546483636, 0.035988167460475645, 0.02114336152694055, 0.0043392301720034865, 0.051674010764275274, 0.0563675358758441, 0.0157143468635955, 0.06268054765782186, 0.045445598728422604, 0.0516158637058522, 0.03482550109869667, 0.03644951359767999, 0.03868961553754551, 0.01716066461189517, 0.04366276153762426, 0.02715593157336116, 0.005341967950308961, 0.032073573408914466, 0.04524434184921639, 0.036875525023788214, 0.018626778619363904, 0.004872422565573028, 0.033983523957431316, 0.05101690048884068, 0.11434326081403665, 0.013308772285069739, 0.024493285521332706, 0.03454698282959206, 0.03175272473267146, 0.033762827049940825, 0.050050293428025076, 0.032991010429603715, 0.02851210255175829, 0.009170528002349394, 0.03108228463679552, 0.0175133009574243, 0.06474870203861169, 0.04429975324975593, 0.04213092802092433, 0.01882481076089399, 0.05702048673161438, 0.02970195102638432, 0.02016238309442997, 0.06838605685957841, 0.837391085922718, 6.84961233820234, 17.642867599214824, 30.6965195110866, 38.61486380440848, 33.8562718800136, 28.149362019130162, 18.665166480200632, 26.286569084439957, 25.183938605444773, 24.576520136424474, 21.580352681023733, 16.44374748638698, 15.235309839248657, 9.349381378718785, 6.600870302745274, 3.1802087341036116, 0.8663206164325986, 0.37868084013462067, 0.35673674621752327, 0.5812981820532254, 0.36825699518833843, 0.11836565711668559, 0.8869212110127721, 1.247835887329919, 1.901354351214, 2.913921194417136, 3.333257790122713, 5.008704057761601, 2.7131295459611073, 2.923841702086585, 4.169266564505441, 2.811718838555472, 3.4532662076609473, 0.769234197480338, 1.0287694994892393, 2.175547638109752, 3.3113601080008914, 5.843514485018594, 6.288483202457428, 9.707276139940534, 12.872340406690325, 10.794374789510455, 10.279361282076154, 10.10806473663875, 12.846613832882472, 16.572177989142283, 17.360666513442993, 15.200283970151629, 7.7303842306137085, 6.002174428531101, 4.1872832434518, 3.262740956885474, 0.9922001532145909, 3.0043502620288303, 3.304249712399074, 1.864147616284234, 4.98525128194264, 12.55656909942627, 4.9516463194574625, 6.51556943995612, 6.990003296307155, 1.0800943225622177, 2.0716861827032904, 1.2535322159528732, 1.8036872148513794, 1.829566431897027, 0.5779569127729961, 0.11901019753089973, 0.4155621225280421, 0.2257174559469734, 1.363269133227212, 2.9087995035307745, 7.764801263809204, 11.056399175098964, 12.147467851638794, 9.78162968158722, 18.084531579698833, 18.562678813934326, 19.11852080481393, 29.064398084368023, 30.662594931466238, 29.253121580396378, 18.129012210028513, 4.935117857796805, 0.3809946988310133, 0.057483580096491745, 0.04781216263238873, 0.04204992451039808, 0.06604620348662138, 0.0405032073280641, 0.05114966943593962, 0.0376834498851427, 0.03427242720499635, 0.026508358107613664, 0.09181878196873836, 0.053041723623339615, 0.027846939761989882, 0.029859941120126417, 0.01017628314106592, 0.04346317724723901, 0.10455740163368837, 0.02041596859427435, 0.05065215738224132, 0.04386941955557891, 0.029613693976508718, 0.023169726632269363, 0.019976011577195356, 0.007981312261628253, 0.006226823839824647, 0.06030084392321961, 0.040207871568522284, 0.02142557441922171, 0.026706556490223323, 0.04681876700903688, 0.02646503534301051, 0.03899471541600568, 0.04032004697780524, 0.03602106283817973, 0.02354634240535753, 0.013146959494666328, 0.05895007747624602, 0.008852461319682854, 0.052095140130924325, 0.04449690838477441, 0.019711065704801252, 0.0064770722196304375, 0.0514732899277338, 0.029313778105591024, 0.024834527567561184, 0.03158746074352946, 0.05969785699354751, 0.054037100568945916, 0.011634992635143655, 0.03738714042784912, 0.03894520950104509, 0.0474949916159468, 0.04976006703717368, 0.02089875134905534, 0.05522158522424953, 0.02889090490394405, 0.056811396165617874, 0.02067544886709324, 0.04294091223606041, 0.00785461111393358, 0.06466370874217578, 0.04471591574006847, 0.016974042036703656, 0.10546344944408961, 0.015337563153090221, 0.058918756299785206, 0.007654456005963896, 0.08490701392292976, 0.030046612889106785, 0.025027957545327287, 0.05480361783078738, 0.041882631701550314, 0.05671001624848161, 0.013094365397202117, 0.07427464838006667, 0.04437404265627265, 0.02761279937944242, 0.05142928693177445, 0.04551943690915193, 0.019789088750258088, 0.02707765916628497, 0.016324572065579038, 0.02125840544301484, 0.02838468554961894, 0.037654188062463484, 0.011591846289645349, 0.008606476260216107, 0.03261262537645442, 0.02199043276985841, 0.015320528531447053, 0.06232199618326766, 1.3732653111219406, 8.83784544467926, 22.04265628542219, 34.99344880240304, 45.10369961602347, 36.557724543980186, 30.88031326021467, 21.124453578676494, 24.194249357495988, 31.673099245343888, 24.876845598220825, 25.733799934387207, 19.587428671973093, 17.61293649673462, 12.169297354561941, 6.806801012584141, 2.8943172863551547, 0.8812355761017118, 0.17916744308812277, 0.019735060399398208, 0.19620614951210363, 0.27822259068489075, 0.13472344007875237, 1.254067444375583, 1.5914953095572335, 1.315467806799071, 2.67480936220714, 3.097456123147692, 4.3692196522440225, 4.327608627932412, 4.885565476758139, 5.679456659725734, 5.727424851485661, 4.836332712854658, 2.598498599869864, 1.900794586965016, 3.7824872732162476, 5.759768715926579, 7.236481956073216, 10.000260829925537, 13.98582136631012, 14.834405728748866, 15.71805156980242, 14.41610506602696, 11.494613374982562, 17.537581545966013, 20.89200680596488, 20.470247677394322, 18.541695254189626, 10.921162043298994, 7.610473087855747, 6.090499494756971, 3.132391448531832, 2.39659806234496, 3.157487907579967, 5.674660665648324, 5.991572780268533, 9.446178470339094, 4.503373299326215, 5.290816554001399, 5.996590248176029, 4.6665269902774265, 2.4491247066429684, 4.9567562852587015, 1.7710901754243034, 0.8397977682096618, 0.8675516960876328, 0.5792888498732022, 0.2974346583443028, 0.21516342727201326, 0.3477284610271454, 1.6904852092266083, 3.3185071987765173, 8.746496609279088, 11.199082170213972, 17.60893954549517, 14.906587089811053, 20.768151691981725, 15.803672483989171, 24.834920167922974, 32.711392879486084, 31.85894271305629, 33.25076069150652, 21.743402583258494, 6.5230991159166605, 0.4157831078129155, 0.05694414475666625, 0.06903103832155466, 0.030598495953849385, 0.10296820476651192, 0.027273197691621523, 0.03949829696544579, 0.039020913653075695, 0.012365947876657759, 0.01943753636442125, 0.06844068571392979, 0.0338771534152329, 0.02701242650592966, 0.04148877265730074, 0.030084841552057436, 0.036800451909324954, 0.03916051544781242, 0.01811937352509371, 0.028619121094899516, 0.012794335023500025, 0.014111249358393252, 0.021060468296387365, 0.020302397099190524, 0.07582167429583413, 0.037771700149668117, 0.04139686169634972, 0.024452536100787774, 0.04601601936987468, 0.02425893479292946, 0.02319155171114419, 0.017668225769219652, 0.06708344604287829, 0.026825975260830352, 0.019830109584810476, 0.04040823617417898, 0.040344141756317446, 0.07232196030340024, 0.008274010216285075, 0.03485643890287195, 0.034332134893962314, 0.023194411736247793, 0.015061010939202138, 0.0771961487563593, 0.15832984979663575, 0.1250796661313091, 0.09529599573995386, 0.14892886924956525, 0.09917406764413629, 0.0664984742179513, 0.09000210623656, 0.13853531410651548, 0.13007280177303723, 0.16763769462704659, 0.12494831532239914, 0.1355152361627136, 0.1566580752176898, 0.19675775777016366, 0.10374257607119423, 0.1400441588567836, 0.0747739551588893, 0.12565476527171476, 0.21189443554197038, 0.1361520141363144, 0.20028793119958468, 0.12053827196359634, 0.17898186376052244, 0.0854405052959919, 0.24262170387165888, 0.12119056124772344, 0.12126157672277518, 0.18546964919992856, 0.2574574920747961, 0.09414412826299667, 0.1778261014925582, 0.10654090198555163, 0.14242329262197018, 0.07194288314453193, 0.15203042567840644, 0.17175172029861382, 0.1245455505060298, 0.10446599618132625, 0.17677582427859306, 0.11476289401096956, 0.19855138366775854, 0.16547612633023942, 0.11587016816650118, 0.09789388919515268, 0.13612085580825806, 0.1144734581134149, 0.08969792577305011, 0.1336389375584466, 1.8212481353964125, 9.956601824079241, 24.27724211556571, 41.39856229509626, 50.82133749553135, 44.66017525536673, 38.51575122560774, 29.327734810965403, 36.98930147715977, 36.38210882459368, 33.67512539454869, 31.029755115509033, 24.169833387647355, 21.359207153320312, 13.377175671713692, 8.230657134737287, 4.70297463451113, 1.7007754913398196, 0.8568684607744217, 0.7408714879836354, 1.6276396214962006, 1.5130497132028853, 2.0255038951124464, 2.636846576418195, 3.741838574409485, 4.788975528308323, 7.249287051813943, 8.054147703307015, 10.214607545307704, 10.316847681999207, 11.031125102724348, 8.81328877380916, 9.772902744156973, 9.117279410362244, 4.686932981014252, 2.9463673276560645, 3.9299723420824324, 6.563747380461011, 9.003448809896197, 9.76699069568089, 13.434161322457449, 15.294616188321795, 15.154983452388219, 14.089708226067678, 13.065326622554235, 18.77665901184082, 22.28211726461138, 22.283810888017925, 20.94520742552621, 11.58040452003479, 9.945011360304695, 8.116662383079529, 4.727346743856158, 3.8850057721138, 5.700620438371386, 11.221677712031774, 6.423836282321385, 13.388183355331421, 22.113675560270035, 14.777392285210745, 15.204798562186104, 14.896909986223493, 3.9625020708356584, 6.654443085193634, 5.763565906456538, 3.9998000008719305, 3.1408573942525044, 1.5022132375410624, 0.8077649985040937, 0.6234518172485488, 0.5894828342965671, 2.40581419638225, 3.778643616608211, 10.98498819555555, 15.068916116441999, 18.441780158451625, 15.92064540726798, 26.15523076057434, 27.014681237084524, 30.373317105429514, 39.54340716770717, 39.17552784511021, 38.97648280007498, 24.340507200786046, 7.5752396413258145, 0.589716793170997, 0.14819162738110336, 0.13557072675653867, 0.12979708585355962, 0.19129100468541893, 0.14241034617381437, 0.15609542040952615, 0.17839075119367667, 0.0833247448982937, 0.10183702582227332, 0.1800521034747362, 0.14623899358723844, 0.07610169212732996, 0.1409244087657758, 0.12257580405899457, 0.1442656780460051, 0.21821496209927968, 0.08171466950859342, 0.09897151137036936, 0.12592343799769878, 0.11078179334955555, 0.1160200158400195, 0.07798041310161352, 0.08197073505393096, 0.11569913662970066, 0.1428431836622102, 0.10127715979303632, 0.10732777190527745, 0.10630215943924018, 0.11971146347267286, 0.09456994291394949, 0.2652925359351294, 0.14081638599080698, 0.09671108052134514, 0.1453040266143424, 0.1294474367584501, 0.16068509912916593, 0.1247674043157271, 0.07677975895681552, 0.22275202721357346, 0.12943978288343974, 0.07411051075905561, 0.1726627214146512], [0.05986092931457928, 0.024943844648078084, 0.038294348533132246, 0.07016094840530838, 0.06514044744627816, 0.03376188049358981, 0.013182726771836835, 0.039720971802515645, 0.029042353920106376, 0.012431281469097095, 0.021702757670677135, 0.044962329124765735, 0.0475660817298506, 0.03177475676472698, 0.054555056882756095, 0.0480334193312696, 0.03477879074801292, 0.03302282354395304, 0.01314755660548274, 0.038614935973393064, 0.047632126935890744, 0.06319742849362747, 0.018122476126466478, 0.016976025055295656, 0.06288889862064805, 0.037976878961282115, 0.028474050307912484, 0.010805190956619169, 0.043115763925015926, 0.05317379367936935, 0.02394749570105757, 0.025334197362618785, 0.030023770007703985, 0.035298104131860394, 0.05560789556641664, 0.018811002573264495, 0.022408887012196437, 0.0651604642293283, 0.043051350595695634, 0.00430424660277952, 0.10526900166379553, 0.009623826714232564, 0.00400789685746921, 0.030145943630486727, 0.04835632396861911, 0.04413551724116717, 0.04646179312840104, 0.06023934829447951, 0.014990146438192044, 1.139247594135148, 7.235817100320544, 19.200087445122854, 27.277154650006974, 34.577269077301025, 36.28000157220023, 29.549073151179723, 21.491917746407644, 16.503297022410802, 11.185910122735159, 21.720105273383005, 20.757090159824916, 21.84471079281398, 20.44814545767648, 8.008895822933741, 5.3303874135017395, 2.748467649732317, 1.1351302436419894, 0.721633608852114, 0.19862933377070086, 0.12807993085256644, 0.22059516794979572, 0.21135806718042918, 0.8877826247896466, 0.6207619958690235, 2.0529497138091495, 1.1224706258092607, 4.512669554778507, 2.6707946062088013, 3.0312111292566573, 5.683364152908325, 2.7375570237636566, 3.062882104090282, 3.115659100668771, 2.0505204498767853, 1.5438698594059264, 2.1656123655182973, 3.1479864631380354, 5.5602933168411255, 4.7667651772499084, 7.283151703221457, 9.275520290647234, 6.708512663841248, 5.439861927713666, 7.895144258226667, 8.794071793556213, 7.93535087789808, 7.481947047369821, 3.4731319759573256, 1.8262100177151817, 0.9015479290059635, 1.4444579652377536, 1.4001450687646866, 2.5017067193984985, 3.653209090232849, 5.457425670964377, 8.640239545277186, 2.200662987572806, 1.3992960857493537, 4.935037953513009, 4.620691026960101, 4.69301004920687, 2.5570354419095174, 0.6788083868367332, 0.6347407400608063, 0.4480076857975551, 0.21385006846061774, 0.2799953312746116, 0.946295685001782, 1.4221172268901552, 3.8351897937910895, 6.67913133757455, 13.621443935803004, 28.64852581705366, 11.880392125674657, 17.369143315723964, 17.435604572296143, 21.036088126046316, 19.49428459576198, 23.71710787500654, 30.584285259246826, 18.800333261489868, 8.03659655366625, 0.9162306125674928, 0.00728317182178476, 0.047902360292417664, 0.011060692469722458, 0.025721707015431354, 0.03262419779119747, 0.01819777485382344, 0.013885368443360286, 0.02655078181331711, 0.021749931121511117, 0.025941752529303943, 0.011738087549539549, 0.038333951229495664, 0.04760737058573535, 0.05470649911356824, 0.03698376153728791, 0.03191706591418811, 0.04064069887889283, 0.02421421933520053, 0.01538074342533946, 0.09909841098955699, 0.04097431758418679, 0.04673922574147582, 0.0763065554201603, 0.022413989595536674, 0.010458321310579777, 0.023468947004792944, 0.06141883214669568, 0.025904928433841894, 0.021776309170361077, 0.027628741559705565, 0.018816586916467974, 0.06380879533077989, 0.017459018155932426, 0.040371527429670095, 0.06343250695083823, 0.04509639407375029, 0.07163104880601168, 0.015862394722976854, 0.009569183441012033, 0.03450179918270026, 0.05892218968697956, 0.05346009135246277, 0.019642231719834462, 0.031799367229853354, 0.020514417240130048, 0.049283484396125586, 0.016166466620883772, 0.0552609606113817, 0.05401112624843206, 0.003465171895056431, 0.018795223241405826, 0.02683137809591634, 0.008812894246407917, 0.024948351816939454, 0.07102723406361681, 0.04198046288053904, 0.042151908323700936, 0.06357632923339095, 0.03537511446380189, 0.056523320730775595, 0.052634911345584054, 0.04942617013252207, 0.02265937839235578, 0.0422910419292748, 0.03602942917495966, 0.011634236916766634, 0.007132017968355545, 0.041103568327214034, 0.01169042385715459, 0.05084952286311558, 0.05217876617929765, 0.043835893140307496, 0.01053201699895518, 0.020815622327583175, 0.023899769244183387, 0.05207816318475774, 0.06588372149105583, 0.07506491097488574, 0.04293090045186026, 0.0680951349703329, 0.005942828520866377, 0.02706907909097416, 0.04243189222844584, 0.026753509417176247, 0.03778107411095074, 0.028972702300442115, 0.015943713752286773, 0.04386950437245624, 0.07146357957805906, 0.021145356419895376, 0.021628866903483868, 0.030349035946918384, 1.8429883973939079, 9.861425399780273, 23.249831097466604, 33.017672947474885, 38.86597517558506, 38.816764559064595, 30.606828689575195, 27.52732801437378, 20.91065924508231, 12.86484590598515, 24.71233136313302, 23.814460822514125, 24.08658354622977, 20.395359992980957, 12.895266856466021, 6.9708709972245355, 4.082172632217407, 1.2369053938559122, 0.5745066436273711, 0.2889044146452631, 0.13242279924452305, 0.1271735437746559, 0.01046759179527206, 0.31793227845004624, 0.8641854567187173, 0.3489396188940321, 2.4065665560109273, 2.7444368260247365, 2.786250650882721, 2.464739045926503, 6.254919060638972, 4.497865549155644, 2.577864404235567, 4.473981116499219, 3.076594374009541, 2.9726931835923875, 2.4533374863011495, 4.32017970085144, 7.388285330363682, 6.489178444658007, 9.905331935201373, 9.646074669701711, 9.9847446339471, 7.496797953333173, 11.89374656336648, 12.225038409233093, 12.234014613287789, 10.925766961915151, 5.225853502750397, 3.182082359279905, 1.95893429006849, 3.42430003626006, 2.7245306713240485, 4.14420918907438, 4.801425397396088, 8.144905941826956, 6.922524128641401, 4.072163752147129, 2.7660689566816603, 2.769855724913733, 1.2651185542345047, 1.6994427399975913, 1.6646244483334678, 1.5827196261712482, 0.5657474622130394, 0.3321666946368558, 0.1327413578650781, 0.10013351616050516, 0.593768950019564, 1.4670259313923972, 4.073105667318616, 7.197299761431558, 18.616480452673777, 27.410540955407278, 15.099621943065099, 15.165596825735909, 15.892597266605922, 25.254883187157766, 22.704493045806885, 29.401142529078893, 34.36652673993792, 23.470127207892283, 9.656782712255206, 1.2396610059908457, 0.044235875963100364, 0.07327963105802025, 0.02151489507273904, 0.022118808202711598, 0.061641079506703784, 0.02079828406151916, 0.06407329506639924, 0.03141947243628757, 0.028134024535704936, 0.03144197944285614, 0.019413248203428726, 0.07296472295586552, 0.03702154915247645, 0.0292038452545447, 0.06344837109957423, 0.013969779896017696, 0.058216601477137635, 0.05300379690847226, 0.03428410479266729, 0.0213538871945015, 0.026540900647108043, 0.024420432912717973, 0.018790726250569736, 0.03142410343778985, 0.016254089240516936, 0.011652270681224763, 0.025255972452993904, 0.06629862529890877, 0.032232510059007576, 0.046699792678867064, 0.053148280762668164, 0.013383480686960476, 0.0457769952315305, 0.02386969487581934, 0.04965856159105897, 0.030632650014013052, 0.03673211664759687, 0.05097276857122779, 0.08197637367993593, 0.03177584242075682, 0.04853545721354229, 0.07723032656524863, 0.05409106445897903, 0.1542865681861128, 0.17650150614125387, 0.16434356995991298, 0.23378014830606325, 0.15314128249883652, 0.0958168867177197, 0.11612425238958426, 0.10173994781715529, 0.0938470656318324, 0.17116964581821645, 0.06912324444523879, 0.09349962177553348, 0.15511351238404, 0.1201210543513298, 0.17189384624361992, 0.17852841237826006, 0.16482151645634854, 0.09405338777495281, 0.11060434287147862, 0.20325048294450554, 0.19226411889706338, 0.1025278762515102, 0.0958167781521167, 0.09468212510858263, 0.19760182819196156, 0.1678052113524505, 0.21878172882965632, 0.12176462901490075, 0.1653716183666672, 0.1430231990026576, 0.13016600534319878, 0.10727445262351207, 0.11784446079816137, 0.21264978072472981, 0.21000481050993713, 0.09512320001210485, 0.130842531898192, 0.17206098298941339, 0.1140123935682433, 0.10604960870529924, 0.24736167809792928, 0.0698767372273973, 0.12371882343930857, 0.07419422162430626, 0.13995132169553212, 0.18229350820183754, 0.08888747676142625, 0.17187415515737875, 0.2184204360736268, 1.7183719128370285, 10.896251014300756, 25.633963005883352, 38.58019576753889, 47.68016808373587, 47.0079402923584, 38.86352593558175, 32.45392043249947, 29.197424820491246, 19.01338587488447, 32.16080720084054, 30.903971876416886, 31.45966795512608, 27.153695583343506, 12.83475933756147, 8.222264579364232, 4.18780609539577, 2.417986354657582, 1.2944562371288026, 1.0403035091502326, 0.4487965777516365, 0.63791552398886, 1.465625326548304, 2.8469075560569763, 3.1749235434191565, 7.344139950616019, 6.991448087351663, 10.324528915541512, 8.316470861434937, 7.650763085910252, 15.464143548692975, 6.667006731033325, 9.216772403035845, 9.147936599595205, 6.656103270394461, 4.117273194449289, 3.789230934211186, 5.321924073355539, 8.993015221187047, 6.999764212540217, 9.204761573246547, 10.854177934782845, 10.271252734320504, 7.603385056768145, 11.200360638754708, 10.916253140994481, 11.069997668266296, 11.567519085747854, 6.037986746856144, 3.6624593138694763, 2.9336021840572357, 3.627258219889232, 4.771638470036643, 8.42106122629983, 8.35366804259164, 15.952086005892072, 16.955862726484025, 11.334838679858617, 7.006179136889322, 12.349284359386989, 9.02579769066402, 9.116177252360753, 5.642830099378314, 2.8080690801143646, 2.0875241671289717, 1.5882140227726527, 0.8405404112168721, 0.5545434919851167, 1.3971912158387048, 2.202127754688263, 4.8570904561451504, 9.195516995021276, 19.0280795778547, 34.89007002966744, 19.19175829206194, 24.286806310926163, 25.819622346333094, 29.626177310943604, 29.14286756515503, 35.719174248831614, 40.27660887581961, 25.584365027291433, 11.278593012264796, 1.505623391696385, 0.18563943223229476, 0.33291007046188625, 0.09249342898172991, 0.09896699911249535, 0.26925767745290485, 0.16482755541801453, 0.14270964797054017, 0.147795010092003, 0.15808907843061856, 0.16602237416165216, 0.10081334039568901, 0.13644244069499628, 0.12289573332028729, 0.143124327861837, 0.09577777595924479, 0.0965301695146731, 0.15182644448110036, 0.13385368032114847, 0.18329190462827682, 0.14921878012163298, 0.10834076361996786, 0.0926770812698773, 0.11802159915012972, 0.07052995610449996, 0.109837856143713, 0.07744781060942582, 0.20261963536696775, 0.1404390119548355, 0.11894277829144682, 0.09686814102211169, 0.06622853941683259, 0.08144630212336779, 0.17750362093959535, 0.08376359420695476, 0.20598917241607392, 0.09921667285795722, 0.10860698683453457, 0.13206063796366962, 0.20201856190604822, 0.1466171411531312, 0.16314581994499477, 0.16665277390607766, 0.17450370905654772], [0.12042711435684136, 0.046807069065315385, 0.004744098871015012, 0.05744833020227296, 0.048781371875000853, 0.05042259880740728, 0.11537643894553185, 0.04139537909733398, 0.03188588044473103, 0.0061002130221043315, 0.05352897622755595, 0.019157566030376723, 0.022823180138532604, 0.05948047472962311, 0.032945229671895504, 0.02763423090800643, 0.09731800973947559, 0.051663500256836414, 0.06376124359667301, 0.06828055823487894, 0.014714691754696625, 0.028467794215040546, 0.06502441117273909, 0.015141186637005635, 0.007136760928135897, 0.03158111983378019, 0.034997767569231134, 0.037946426309645176, 0.03748632189152496, 0.03450892719307116, 0.04229583917185664, 0.024867916579491327, 0.01112419571394899, 0.02640284930488893, 0.06757702598614351, 0.05448108299502304, 0.010898768569209745, 0.01003346000132816, 0.021881326035197293, 0.015688911978421465, 0.056980887427926064, 0.05214245437777468, 0.03142401522823742, 0.026184993762789027, 0.030027841217815876, 0.016149993486968533, 0.0350544659553894, 0.0554159888997674, 0.041383772755839994, 0.01772603016745831, 1.0146310010126658, 6.4238302026476175, 15.33877546446664, 29.127277544566564, 39.56262241091047, 36.681388582502095, 31.011120046888077, 33.46848596845354, 21.4920653956277, 17.493767942701066, 16.55529907771519, 19.946403878075735, 23.192525829587662, 14.014534796987261, 9.291415163448878, 6.568298016275678, 3.960692499365125, 2.2344132108347754, 0.9415969657046455, 0.35828627592750956, 0.17203556506761483, 0.3015385467026915, 0.23505945823022298, 0.5023306565625327, 0.31021817667143686, 1.1013919625963484, 1.0699608091797148, 1.0343370693070548, 2.0200237206050327, 2.10702537213053, 4.01667891229902, 1.9429323715823037, 2.980912685394287, 2.613248756953648, 2.2308183865887776, 1.2679862060717173, 1.842493555375508, 4.283662140369415, 4.0801646028246195, 3.7407459701810564, 3.7975175295557295, 5.774175371442523, 2.1231892704963684, 5.334031743662698, 5.136112306799207, 4.0577128018651685, 2.9506619657788957, 1.287226636494909, 1.6209372154303958, 1.7098564612013953, 2.1219288238457272, 1.103384792804718, 3.1723181860787526, 4.805969085012164, 7.393695371491568, 5.467673829623631, 1.799882858991623, 2.2539795551981245, 1.4285252030406679, 1.1013444108622414, 1.1949173212051392, 3.7313211730548312, 2.220663811479296, 0.16604727639683656, 0.1777819831456457, 0.6590404361486435, 0.9120964344058717, 2.27342061485563, 5.0600486397743225, 6.79997136763164, 10.883874535560608, 13.164288078035627, 46.194855145045686, 28.310561963490077, 15.906078508922032, 24.759671177182877, 21.290142059326172, 26.84852201598031, 20.9231573172978, 19.233714989253453, 10.055149861744471, 1.6524144006626946, 0.05156449181959033, 0.021239423425868154, 0.041535326944930215, 0.02321438441452171, 0.03367174050903746, 0.028283668648717657, 0.09439270956707851, 0.040834597045821805, 0.06106632641915764, 0.05638983253655689, 0.0348183595176254, 0.015308080806529947, 0.03161329596436449, 0.014837121524448906, 0.021668026855747615, 0.024562370564256395, 0.0604539214234267, 0.043048768769949675, 0.026100638289270655, 0.0561261097235339, 0.02031002383280013, 0.06570150769714798, 0.04491872985714248, 0.03483442722686699, 0.0072983455611392856, 0.02130025578662753, 0.04953589263771262, 0.012601262124787484, 0.04740705008485487, 0.02345645347876208, 0.018468422116711736, 0.03854193239073668, 0.016321437233792882, 0.06725383297141109, 0.0036057914923211293, 0.05830399678753955, 0.030553814422871386, 0.08444145069058452, 0.009621909852804882, 0.05905059565390859, 0.05125000101647206, 0.01061635126825422, 0.05884034479303019, 0.04319527465850115, 0.06197681184858084, 0.058732016677302976, 0.02357303088397852, 0.03930709597521594, 0.029519696520375352, 0.018493071597601687, 0.020279713673517108, 0.043387191503175666, 0.03775507264903613, 0.02479894010217062, 0.10733098816126585, 0.09957186558416911, 0.033323051540979316, 0.007445116078348032, 0.029269737790205648, 0.018864228556464826, 0.04047189972230366, 0.022118041458140527, 0.03183118034420269, 0.04119272443598934, 0.0122803430505363, 0.026229787252045104, 0.043091889670384784, 0.06492506686065878, 0.0220158914037581, 0.04053747673918094, 0.034129850034202845, 0.05149521678686142, 0.02939941261761955, 0.04712397884577513, 0.028511342592537403, 0.04415024484374693, 0.03311402882848467, 0.012351784306312246, 0.026822061810110296, 0.05127530358731747, 0.016829261323437095, 0.06794331275991031, 0.051565265349511585, 0.042887345289013216, 0.030022368832890476, 0.04384380146594984, 0.014388813437627894, 0.030733632988163402, 0.020919931819662452, 0.02611676197765129, 0.024330242038039223, 0.0166875611591552, 0.06682244754795517, 0.04533075328384127, 1.4400650752442223, 8.459462182862417, 19.879551785332815, 34.842457498822895, 44.54678760256086, 40.72113725117275, 34.255630016326904, 33.00089999607631, 19.18362716266087, 20.04175227028983, 20.34769708769662, 24.987108298710414, 31.029136725834437, 16.89477242742266, 11.814983521189008, 6.425964168139866, 3.7265486291476657, 2.284075894526073, 0.8392823530094964, 0.2620114119989531, 0.2397822519498212, 0.14760373107024602, 0.21883218469364302, 0.232053385249206, 0.6079364897949355, 0.6879275175077575, 1.8454028964042664, 1.7715132555791309, 2.8010681186403548, 3.5072480653013502, 4.060812566961561, 3.802542814186641, 4.853381420884814, 3.9253973875726973, 3.067283353635243, 1.7830782064369746, 2.9873884064810614, 5.45864725112915, 6.072973532336099, 5.863873141152518, 7.498797297477722, 6.142820732934134, 2.6309731772967746, 8.430494274411883, 5.410793704645974, 6.411072875772204, 4.965781995228358, 3.1234688758850098, 2.9402103551796506, 2.427489319017955, 4.566409093993051, 2.440302231482097, 2.7757464945316315, 2.4235264573778426, 6.243052840232849, 5.000688876424517, 2.3171692958899905, 1.2939157975571496, 1.268135700907026, 0.8204209793891225, 0.5405363578881536, 0.2830630966595241, 0.31665622549397604, 0.2406643746154649, 0.03853233112022281, 0.3959652983716556, 0.7340164386800357, 2.87838528411729, 4.808529496192932, 10.38455353464399, 12.949351634298052, 18.994599682944163, 52.71955755778721, 24.049464532307216, 17.72455757004874, 25.859036002840313, 26.13295136179243, 32.877777917044504, 26.83292852129255, 24.79837611743382, 12.176318509238106, 2.364146717957088, 0.043493467050471475, 0.06326992317501988, 0.009473929846925395, 0.05696458223142794, 0.14409286874745572, 0.03970096519749079, 0.044638949512903175, 0.05579100841922419, 0.006895333927656923, 0.056249331682920456, 0.06150985083409718, 0.04691003675439528, 0.006838488808300878, 0.02327292163058051, 0.011972305115445383, 0.027323148047019328, 0.04741473788661616, 0.05931850163532155, 0.015572736605203577, 0.008186983011130775, 0.020788117910602262, 0.034837107440190654, 0.03018086782789656, 0.02419576487903084, 0.047633680781083446, 0.020127414792243923, 0.045491586439311504, 0.02448368933983147, 0.07534226216375828, 0.024392964118825536, 0.021844371321744153, 0.06711543218365737, 0.026168413759608353, 0.13918311148881912, 0.026547082101127932, 0.024365098381947194, 0.028056642705840722, 0.07553044028048005, 0.031856299710593054, 0.0464147231541574, 0.018679013941437006, 0.04647339268454483, 0.07569168734231166, 0.023881204526073167, 0.1557964850217104, 0.16520761645265988, 0.06157104790742908, 0.07379429986966507, 0.1519360143159117, 0.1317622454038688, 0.19357582208301338, 0.16309137429509843, 0.10581542591431312, 0.21031070766704424, 0.15202792866953782, 0.15915064646729402, 0.08284732087382249, 0.18078437846686157, 0.13891874067485332, 0.2050841831203018, 0.15596690587699413, 0.1013676899352244, 0.144981125369668, 0.19983049003141268, 0.15825200825929642, 0.06397527389760528, 0.10634789269949708, 0.24349804541894368, 0.08700829438333, 0.15006188702370438, 0.14241391526801245, 0.137438122981361, 0.11399807647934981, 0.21425580526036875, 0.10373368047709976, 0.06163943066660847, 0.09588651119598321, 0.10103467173342194, 0.17938614849533352, 0.22445528581738472, 0.1561232946280922, 0.10909211223146745, 0.19324290566146374, 0.09674159424113375, 0.12594367191195488, 0.21644935969795498, 0.13753484136291913, 0.17999746783503465, 0.08099433673279625, 0.1133771762251854, 0.07832298507647854, 0.20719266283724988, 0.14894609046833857, 0.15401324070990086, 1.7563806218760354, 9.12575968674251, 21.89799131665911, 39.16275010790144, 51.14609282357352, 48.15293393816267, 41.15909263065883, 44.91668537684849, 31.66608156476702, 27.70647168159485, 24.983180829456874, 27.778199672698975, 33.41292469842093, 19.468440771102905, 14.841871568134852, 10.067334396498543, 6.4940017972673685, 3.0193668391023363, 1.8511616502489363, 0.6211801905717168, 0.7756677408303533, 0.6563570744224957, 0.888702501143728, 1.1298137860638755, 1.3636914534228188, 2.8685299158096313, 4.567851713725498, 5.002278711114611, 7.213004861559186, 6.470888614654541, 7.478496398244586, 6.603615709713527, 8.256335071155004, 7.770606483731951, 7.634617209434509, 4.636980210031782, 4.051798147814615, 7.851296782493591, 7.05172153881618, 5.544413208961487, 5.965157900537763, 10.685715385845729, 2.958698643105371, 9.170216866901942, 7.659817457199097, 7.170449316501617, 5.028385698795319, 2.9128290244511197, 4.260113826819828, 3.421520756823676, 3.930220740182059, 5.482695400714874, 8.917205163410731, 10.35209936755044, 15.060639074870519, 13.826620766094752, 5.8736410055841715, 6.184182056358882, 5.200905995709555, 3.4010005550725118, 2.592399601425443, 6.203161060810089, 3.4132526176316396, 1.0575303733348846, 0.6839891374111176, 1.2012392048324858, 1.2064694613218307, 3.3979029612881795, 7.2286374398640225, 9.839311020714895, 14.977863448006765, 18.609516620635986, 55.472916739327566, 34.490711893354145, 23.720295361110143, 34.64691781997681, 32.101431369781494, 38.08404575075422, 32.569010393960134, 27.16582887513297, 13.50770366191864, 2.7935753549848283, 0.10037218406796455, 0.09959492898945298, 0.12810019190822328, 0.23297901558024542, 0.23473517277411052, 0.18817173849259103, 0.16091140412858554, 0.11547143384814262, 0.12847272120416164, 0.1705382689833641, 0.11873704647379262, 0.1351130006036588, 0.11018337296055895, 0.06624214404395648, 0.14099800267389842, 0.17448536146964344, 0.12277643329330853, 0.12859772092529706, 0.053499989211559296, 0.20591158872204168, 0.12005473433860711, 0.1422301544142621, 0.0839779366339956, 0.14253584801086358, 0.12002748437225819, 0.08059307147881814, 0.14764387320194924, 0.10760609339922667, 0.17493362884436334, 0.1523888957287584, 0.10130176347281251, 0.13708665541240148, 0.09086601702230317, 0.1891111023724079, 0.09121761351291623, 0.17864615177469595, 0.17253518397254602, 0.16845429795128958, 0.06806211745632545, 0.13910516138587678, 0.14489173516631126, 0.11409707473857061, 0.15333398644413265, 0.08080250809767417], [0.014284705809716667, 0.04974471518237676, 0.018941023453537906, 0.08031133016837494, 0.018721100075968673, 0.06597746110388211, 0.02492950889947159, 0.10141790831195456, 0.024126437259837985, 0.06231829138206584, 0.024488798708521893, 0.023814570690904344, 0.06622782016971282, 0.0675532908311912, 0.03632850366245423, 0.047911523907844505, 0.03390549921563693, 0.025328248306842785, 0.01519218532900725, 0.004834755814434695, 0.058237574994564056, 0.01352487042147134, 0.03484400135598012, 0.04599593812599778, 0.03485945838370493, 0.028159662981384566, 0.02734966349921056, 0.049929290278149505, 0.028472662703799348, 0.04794799855777195, 0.03815717250108719, 0.03301793130646859, 0.04179619651819978, 0.016655262892267535, 0.015899247656177198, 0.03205313254147768, 0.007547580803345356, 0.004962135497148016, 0.04141765200932111, 0.04454984090157917, 0.03391573830906834, 0.04613175369533045, 0.013004268669257206, 0.038722415920346975, 0.08916765065597636, 0.02747602029038327, 0.04766622332057782, 0.04190747965393322, 0.05916250643453427, 0.12165598198771477, 0.057369857627366266, 0.7736180765288216, 5.748255116598947, 14.342619180679321, 28.191688707896642, 37.71507208687918, 39.3717553956168, 36.735445567539756, 26.71975452559335, 24.70082688331604, 24.81427185876029, 27.779658794403076, 21.654998915536062, 28.11559898512704, 20.141538824353898, 17.60078409739903, 8.474775144032069, 6.182620882987976, 3.99753315108163, 1.1627910222326006, 0.8273989249552999, 0.3905176935451371, 0.12582237699202128, 0.2792885149163859, 0.04563407200787749, 0.5947907151920455, 1.405192066516195, 1.9960852222783225, 1.4244942707674844, 3.2260312352861678, 6.192404380866459, 2.3508936805384497, 3.0211694623742784, 2.0362510212830136, 1.8687566603933061, 0.7809179191078458, 1.2375105385269438, 1.4746109758104597, 2.591968378850392, 3.4356842253889357, 3.690426681722913, 0.8959947984133447, 1.6150366749082292, 2.128406281982149, 2.0406075417995453, 3.7179810660226003, 1.3832549750804901, 2.3396621346473694, 2.5229428027357375, 2.1803427636623383, 4.887482745306833, 3.0110157557896207, 3.1964681702000752, 1.3964655633483614, 5.129103745732989, 3.4397808398519243, 1.0666205712727137, 0.7271628550120762, 0.739932938345841, 0.15271187839763506, 0.32891029651675907, 0.18758762840713772, 0.296301613428763, 0.2198161283241851, 0.3085705579391548, 0.9519876710006169, 2.318970399243491, 4.43845671415329, 6.9262097137314935, 8.555145825658526, 12.897824662072317, 17.926609448024205, 35.57045848029, 47.610130241939, 19.285630192075455, 27.224405663354055, 34.308401584625244, 24.895927088601248, 18.938567672457012, 10.22268830026899, 2.6718956785542622, 0.17289007135799953, 0.02017325152909117, 0.06862363232565777, 0.04036694731829422, 0.11925171528543745, 0.007600090932101011, 0.02475496255127447, 0.02316794208517032, 0.06293480830000979, 0.032518733093248944, 0.057156227662095, 0.037357881997845004, 0.062435236892529895, 0.029373733459838798, 0.06436523475817271, 0.039664300557758124, 0.08511410281062126, 0.011835543837930475, 0.02318048819766513, 0.035181911795267036, 0.04108607230175819, 0.054622384519981484, 0.04583011773814048, 0.01722762923288558, 0.02424170169979334, 0.014560038356908729, 0.04102901768471513, 0.009644399895997984, 0.02298741614712136, 0.02791782801172563, 0.06833805729235921, 0.05003801533686263, 0.05357187660411, 0.06418941954949073, 0.02489272551611066, 0.02351339953020215, 0.06770132003085953, 0.03722766094974109, 0.0401086120733193, 0.02040423672380192, 0.03468862362205982, 0.06970473538552012, 0.011691833513655832, 0.10387642388897282, 0.010329723657507981, 0.040847105838890584, 0.010838319580735905, 0.03512243141553231, 0.01643177042050021, 0.027215685063440884, 0.057242272687809806, 0.029544323948877196, 0.022825398948043585, 0.02433132260505642, 0.024281297610806565, 0.038704302428024154, 0.03312522804896746, 0.07038137729146651, 0.03809905597673995, 0.022982247406616807, 0.02859362174889871, 0.03222484939864703, 0.03771444536479456, 0.040732453776789565, 0.0361438708912049, 0.022475045872852206, 0.05786168695028339, 0.024247852619737387, 0.11125123780220747, 0.03152808892939772, 0.03223317163065076, 0.07853111212274858, 0.016625018890148828, 0.038440701751304526, 0.035194423981010914, 0.03141656491373267, 0.02202442058894251, 0.009794102532656064, 0.038126333084489615, 0.02170553118256586, 0.013636332520815943, 0.02268469792657665, 0.01682715447220419, 0.038865210222346444, 0.020419992306934934, 0.035549158696085215, 0.030367230863443444, 0.028058851337326423, 0.024253269025523747, 0.08102510829589196, 0.03221445084948625, 0.0512670559941658, 0.01750799311724092, 0.044988931090171845, 0.049550833978823254, 0.06794772323753152, 1.2146464054073607, 7.4804644754954746, 19.288925375257218, 34.38901458467756, 42.8492488861084, 44.10890517915998, 42.6972952570234, 29.144792216164724, 24.90562503678458, 23.010705368859426, 28.75181426320757, 23.16120161328997, 22.981533357075282, 19.550403458731516, 20.411653518676758, 9.673160484858922, 6.5978560873440335, 3.9222350886889865, 1.3421467180762972, 0.6732239350676537, 0.286443829536438, 0.09337094439459698, 0.11116564739495516, 0.4960930198431015, 0.5145223566464016, 0.7108295943055833, 0.9728026283638818, 1.0759817489555903, 0.4186625661594527, 0.6645291330558913, 1.8750977601323808, 3.504104873963765, 2.787946228470121, 2.0164959899016788, 1.265857560294015, 3.023136453969138, 4.360185691288539, 4.965330362319946, 4.495046751839774, 4.271002522536686, 2.9523451668875555, 2.2885479288441792, 5.480908410889762, 3.692795148917607, 4.701974962438856, 2.5257531319345747, 4.10999539068767, 4.213962588991437, 1.8711642112050737, 4.597437143325806, 4.445317625999451, 4.701364389487675, 2.0678362292902808, 4.267605721950531, 2.7806669047900607, 1.2998130811112267, 0.8235219929899488, 0.8943253851362637, 0.9457654505968094, 0.16688515857926436, 0.2767702271895749, 0.19689343763249262, 0.27832464235169546, 0.49796957629067556, 1.0009657399994987, 2.5126970325197493, 4.954202388014112, 10.487040332385472, 10.787289363997322, 15.500241177422659, 17.9040173803057, 42.69580486842564, 46.94910989488874, 18.679863657270158, 32.724719524383545, 36.636899266924175, 30.822757857186453, 23.65858667237418, 12.531921233449664, 3.6000188929694037, 0.16988564043172769, 0.08806948244039502, 0.007152582668433232, 0.039195514284074306, 0.027356382692232728, 0.035461064494614086, 0.011528369338650788, 0.0730295976889985, 0.0058158097339661, 0.08059683734817163, 0.051048432011157274, 0.03986966935917735, 0.011915841672037328, 0.029908368164407353, 0.0631450048780867, 0.0720882864136781, 0.048709813571934185, 0.06656740659049579, 0.039228267169424465, 0.0391799011932952, 0.017269075848162174, 0.038706924965871234, 0.018721464788541198, 0.023162632548649396, 0.011069810284035546, 0.029757614646639143, 0.04572318401187658, 0.052717146397169144, 0.03966775430100305, 0.05181290348991752, 0.036435820761003664, 0.04403833745579634, 0.08494180919868605, 0.043969890235790184, 0.029621225715215718, 0.04849637698914323, 0.020176759555137584, 0.07628167354102645, 0.03182678682995694, 0.036882452866328616, 0.026488594078857983, 0.023735838576353023, 0.008878749462642839, 0.037061009356485944, 0.05352814841483321, 0.08559851574578456, 0.16602750388639315, 0.14648683528814996, 0.22534823790192604, 0.16647966605212006, 0.11908638344279357, 0.10299593649272408, 0.16815549827047757, 0.131771785606231, 0.14717592831168855, 0.11037737969309092, 0.29988058709672516, 0.15789007768034935, 0.14053814592106, 0.06262790691107512, 0.1828268367264952, 0.13636995958430426, 0.0992877222597599, 0.18638591574771063, 0.07759362778493337, 0.11394101168428149, 0.15823286000107015, 0.05677210220268794, 0.12919336610606738, 0.11378754063376359, 0.1197575902832406, 0.17180004556264195, 0.1892228570899793, 0.14141049768243516, 0.15888475573488645, 0.10315203347376414, 0.09838314687034913, 0.12666028631584986, 0.11167009068386895, 0.08870448265224695, 0.21388958634010383, 0.11537759245506354, 0.09850298972534281, 0.11301692162773438, 0.08688254827367407, 0.11985791847109795, 0.10875796766153403, 0.11021596978285483, 0.13728452979453973, 0.22664400908563817, 0.15781246684491634, 0.23371579604489462, 0.14657543839088508, 0.212597465674792, 0.17297400613980635, 0.12432125397026539, 1.3862869952406203, 7.656707269804818, 21.040618351527623, 38.32914693014962, 49.83624274390084, 50.27222830908639, 49.72893476486206, 39.036869594029014, 35.68576731000628, 34.252201080322266, 37.26493304116385, 32.42856298174177, 38.411493505750386, 27.46869216646467, 24.713205099105835, 13.741520966802325, 9.383860077176776, 6.108918734959193, 1.9383250645228793, 1.2910548767873218, 0.9756676746266228, 0.47552032662289484, 1.019879279392106, 1.675857948405402, 1.9846678120749337, 3.5216525495052338, 5.362510672637394, 4.351833522319794, 8.07153730733054, 12.413319826126099, 7.838872534888131, 9.069292545318604, 8.141311986105782, 5.548564757619586, 2.7915927299431393, 4.262790620326996, 3.967530829565866, 5.217774050576346, 6.183855491025107, 6.122436889580317, 2.2802103076662337, 4.358987995556422, 6.741944355624063, 4.30053106376103, 5.82544743163245, 4.608073532581329, 6.393443124634879, 6.084373354911804, 6.217333214623587, 11.593930057116918, 8.125648140907288, 9.047573345048086, 6.402512260845729, 9.629571829523359, 7.908605524471827, 5.991377362183162, 3.023137322493962, 3.6749586888722012, 2.5472148145948137, 1.3284719032900674, 0.5221831798553467, 0.7948203416807311, 0.5487820240003722, 0.6991702999387468, 1.419259128826005, 3.7548512475831166, 6.594491856438773, 11.248763527188983, 13.236911518233162, 20.161655596324376, 24.639026130948746, 43.24488973617554, 54.076797825949534, 27.798335552215576, 38.21938623700823, 45.143127168927876, 35.65638337816511, 27.560265949794225, 14.272659506116595, 3.6705591763768877, 0.3018535226583481, 0.1871655389134373, 0.1297964480306421, 0.12521598381655558, 0.1573088445833751, 0.16737824997731618, 0.07020835764706135, 0.16273601193513187, 0.19239188704107488, 0.18961332685181073, 0.1625544631055423, 0.11287472104387623, 0.12230075310383524, 0.15679790771433286, 0.09388087703181164, 0.1772055947887046, 0.10042209031858615, 0.19166562386921474, 0.15753690020314284, 0.11195942480117083, 0.16310303152671882, 0.15758693537541799, 0.11797860717134816, 0.08389074488409928, 0.13027693224804743, 0.09746155382267066, 0.12760114297270775, 0.12099196761846542, 0.12436833072985921, 0.12244825304618903, 0.13461441307195596, 0.08675473263221127, 0.1617426366678306, 0.15737574813621386, 0.1263454867792981, 0.17434228557561124, 0.13508006451385363, 0.13355851758803639, 0.11427569229687963, 0.1427681648305484, 0.15297767413514002, 0.12583891967577593, 0.0996086218261293, 0.26889270703707424, 0.11429926460342747], [0.027552754119304673, 0.055873983073979616, 0.027529690714020814, 0.038800064075206, 0.034018631359296184, 0.01820526079141668, 0.05431521171703935, 0.005980122925913227, 0.08060274738818407, 0.04268905360783849, 0.04198591151673879, 0.030159375231180872, 0.04025655645611031, 0.04897395707666874, 0.03782223404518195, 0.005285633004470063, 0.07256124567772661, 0.021974124180685197, 0.051271670032292604, 0.057826437056064606, 0.06959587801247835, 0.06046336663088628, 0.0637992008456162, 0.03676323426355209, 0.024719695693680217, 0.062211442472679276, 0.005179140750052673, 0.01620209988738809, 0.016996462530057346, 0.012608389286989612, 0.0274010777939111, 0.05524234500314508, 0.052515370438673666, 0.013487691791462047, 0.03497148112260869, 0.052620807995221446, 0.03180681415168302, 0.02603175171783992, 0.011418329618339027, 0.06155204214155674, 0.09641256582524095, 0.04965817143342324, 0.011989439821003802, 0.013569415397276836, 0.02281532609569175, 0.04138191017721381, 0.04470408548201833, 0.07129248018775668, 0.03358947831605162, 0.05476489383727312, 0.04487726118947778, 0.06229157745838165, 0.5852601208857128, 4.010032091821943, 14.865455491202217, 26.641116550990514, 34.97864219120571, 39.341923304966514, 41.49642767224993, 41.22592387880598, 25.72890666552952, 24.825665167399816, 30.502070699419292, 37.934916564396445, 30.5140563419887, 17.90212573323931, 17.230809892926896, 10.40501684801919, 8.35449400969914, 6.147803459848676, 3.391438965286527, 1.6093852924449104, 0.7521658933588437, 0.11044553853571415, 0.1526789694492306, 0.5753436301435743, 0.2966024215732302, 0.2850842624902725, 1.1474203041621616, 0.7628562940018517, 0.6880290806293488, 2.069932848215103, 3.117455210004534, 2.031813076564244, 2.0228386095591953, 0.7917986352528844, 1.558246225118637, 2.0856735578605106, 2.888940683432988, 1.7579157395022256, 2.6019959322043826, 1.534567198583058, 0.25413945583360537, 2.907306943620954, 0.8231714889407158, 1.4162182062864304, 0.4626432518873896, 2.8265282724584853, 2.385803601571492, 1.8558234572410583, 4.30102047749928, 1.2679602588926042, 1.6628193280526569, 1.1746269528354918, 3.794058629444667, 2.0452020381178175, 0.5981389326708657, 0.4422667095703738, 0.21650471458477633, 0.18653450134609426, 0.029110906313040426, 0.3208598313587052, 0.44440146216324394, 0.5470677188464573, 1.4223101479666573, 2.6432788712637763, 6.089110723563603, 10.651191524096898, 14.778059312275477, 24.393355199268886, 22.358002015522548, 16.262194531304495, 30.19803489957537, 40.142727511269705, 30.05736861910139, 32.882304668426514, 25.826940536499023, 18.30219953400748, 8.304572939872742, 3.2749695692743575, 0.2771650531462261, 0.015150830315958177, 0.12017509288021497, 0.032942373039466996, 0.1431315474744354, 0.011334578040987253, 0.03163417109421321, 0.09090208115854434, 0.015797126439533064, 0.02297104479345892, 0.01769369458114462, 0.024436712664152895, 0.05230385750266058, 0.09124186435448271, 0.029793980730963603, 0.06021689557071243, 0.09479094176952328, 0.06631287453430039, 0.01135947264265269, 0.0036464539755667958, 0.016871155771825994, 0.014244098881525653, 0.01090274817709412, 0.014867491055546063, 0.04669340427166649, 0.01494366509307708, 0.027508264274469445, 0.05296484899840184, 0.034895027189382484, 0.07805764395743608, 0.053347722560699494, 0.035509535643671236, 0.03507933087114777, 0.03590526405189719, 0.06576036382466555, 0.03476287231647542, 0.03950851909550173, 0.015311459910922816, 0.03708205072741423, 0.02682540868408978, 0.022061198883290802, 0.09001861499356371, 0.01372878546161311, 0.04269978803183351, 0.019973070127889514, 0.012440423032135835, 0.035909040099275966, 0.048814559022762945, 0.027638875480209078, 0.03769468642505152, 0.04202943614550999, 0.041787127897675545, 0.0724875974868025, 0.030835226643830538, 0.014996940270066261, 0.07226697182548897, 0.02214059935483549, 0.030693328008055687, 0.00840141364772405, 0.01499318627507559, 0.01582942470642073, 0.03613737391840134, 0.07762131879904441, 0.021616088392745172, 0.02702147646674088, 0.04859617591968604, 0.051483942927526574, 0.0631882818415761, 0.03645097923332027, 0.04150544426270893, 0.02015654938960714, 0.016404537417526757, 0.025553934143057892, 0.009377471853180655, 0.02408114165466811, 0.07448434962757997, 0.06117480381258896, 0.0460513031908444, 0.01718069157297058, 0.03290017494665725, 0.01856105062844498, 0.025216383327330862, 0.009306280807192837, 0.05112323371161308, 0.050785024716917954, 0.019182698967467462, 0.06711438045437847, 0.004356290662794241, 0.10865284223109484, 0.016882894427648613, 0.0040916747280529565, 0.04753446878333177, 0.00809215774227466, 0.08830778393894434, 0.06061514812920775, 0.022281422512605786, 0.016978069142039334, 0.07338290408785854, 1.0455357198204314, 6.099097890513284, 19.09564733505249, 32.673361914498464, 38.710783685956685, 44.334005968911306, 44.19495514460972, 44.878838539123535, 29.179404667445592, 30.648806231362478, 31.74247353417533, 35.75071907043457, 29.7048830304827, 22.298996176038468, 22.68335141454424, 13.886936341013227, 10.541872910090856, 6.301738628319331, 3.885392699922834, 1.6247366858380181, 0.7765870200736182, 0.1596571592880147, 0.1655847733574254, 0.17380979843437672, 0.1541787761130503, 0.23661932881389344, 0.4777702944619315, 1.0469888704163688, 0.8025762140750885, 2.1241611497742787, 2.179209338767188, 2.015312190566744, 2.248525219304221, 1.7729603265013014, 1.5518560537270136, 2.4057907462120056, 3.1820591262408664, 3.014393014567239, 3.118744317974363, 2.8682745695114136, 1.909390160015651, 3.847710881914411, 2.3723382098334174, 2.4343224380697523, 0.8348755123359817, 2.210436497415815, 2.3434747414929524, 2.4205400347709656, 2.3097238668373654, 3.1598809106009345, 2.71458215372903, 0.9447202895368848, 3.3105636707374027, 1.5452244324343545, 0.7900329785687583, 0.592820195215089, 0.2556850500404835, 0.17352845067424433, 0.1589993874409369, 0.14481036524687493, 0.23427393180983408, 0.5770602694579533, 1.566549648131643, 2.487457266875676, 7.780037794794355, 11.875799366406032, 15.56293477330889, 21.669105495725358, 18.324053355625697, 18.500490699495586, 31.82461166381836, 43.3988687651498, 30.602680615016393, 35.473777770996094, 32.47905554090227, 23.15171037401472, 11.712177106312343, 4.647226197378976, 0.3184142825858933, 0.02693579445726105, 0.019208079569840004, 0.03799069732693689, 0.05017124568777425, 0.048921509712402306, 0.009328918431752493, 0.046456018795392344, 0.04461086155580623, 0.023104997784165398, 0.03521950263530016, 0.05572786395038877, 0.04521159574921642, 0.09363504379455533, 0.00091826896823477, 0.0671609550980585, 0.0077020391223153895, 0.06542927944766623, 0.01916289083393557, 0.015915615617164543, 0.019810505011784177, 0.04043079407087394, 0.013873701033714627, 0.01727419878755297, 0.1000180769977825, 0.02529775324676718, 0.024581237230449915, 0.013444782933220267, 0.022581582656130195, 0.12965205577867372, 0.047480898443609476, 0.0022691790737943457, 0.03383681111569915, 0.01721477777963238, 0.047165226989558766, 0.02605587024507778, 0.09819647510136877, 0.03605643826137696, 0.02839847338119788, 0.017586789692619016, 0.025631719701258198, 0.07049566294465746, 0.039674705892269096, 0.043090206903538535, 0.008256157111775662, 0.031633791114602766, 0.05809484515339136, 0.16177550490413392, 0.08566565000052963, 0.15444173557417734, 0.0883150781903948, 0.11554346712572233, 0.142312637131129, 0.0831206212086337, 0.10809979547879525, 0.16853606142103672, 0.08649904028113399, 0.10620763272579227, 0.1325915101915598, 0.18825347482093743, 0.07816463535917656, 0.13497736145343098, 0.149237846955657, 0.1615274596427168, 0.1445171566946166, 0.17547040432691574, 0.18001624968435082, 0.1215011402964592, 0.1821895023541791, 0.1943859928952796, 0.14908782286303385, 0.12550315340714796, 0.08520789670624904, 0.11114194616675377, 0.10400413775018283, 0.21198512853256293, 0.12601920643023082, 0.147911080292293, 0.12450128288141318, 0.13603233412972518, 0.11105657967605762, 0.1314265334180423, 0.1135695001908711, 0.12640746416790144, 0.1452149621077946, 0.16234387297715458, 0.2623749167791435, 0.10677523405424186, 0.17065211358879293, 0.09024768841585942, 0.12678760662674904, 0.1482547311378377, 0.10333698176379714, 0.1687352793025119, 0.24931789455669268, 0.25146936625242233, 0.09843557048588991, 0.13263234442898206, 1.2153201635394777, 6.096044157232557, 21.020657914025442, 37.47354228155953, 45.26270914077759, 51.855180808476035, 52.2783191544669, 51.964128562382285, 33.98602948869978, 34.32474027361189, 37.78468608856201, 48.28542218889509, 40.4565429006304, 27.341665199824742, 25.17527767590114, 15.574725866317749, 13.599991372653417, 8.898278270448957, 5.089115994317191, 2.3689177419458116, 1.355948663183621, 0.5784769420112882, 0.5204462387732097, 1.1389263485159193, 0.9232246258429119, 1.1219041304928916, 2.8991480214255194, 3.8708805186407904, 4.2437356199537, 6.2328802432332715, 8.463633707591466, 6.3131193433489114, 6.267433200563703, 4.483143184866224, 5.584322793143136, 6.218756292547498, 6.567903271743229, 4.046518385410309, 5.584064841270447, 4.2448790328843256, 1.8604570371764046, 6.531738766602107, 4.486264663083213, 6.091400589261736, 3.518693268299103, 7.234791372503553, 5.521590547902243, 5.586999586650303, 11.919040611812047, 4.916321677821023, 6.484584816864558, 5.675343760422297, 7.307221565927778, 5.802365950175694, 3.225153808082853, 2.607458519084113, 0.778335306261267, 0.8471672013401985, 0.5273189299872943, 0.6167154301490102, 0.9042171772037233, 1.0337106457778384, 2.2248207884175435, 4.347260304859706, 9.00990629196167, 15.760675294058663, 20.59980205127171, 32.958099092756, 29.811503137860978, 23.16933274269104, 37.51936912536621, 49.23347609383719, 39.14368077686855, 43.50598914282662, 36.386263847351074, 26.991799082074845, 12.971487726484026, 4.852281868457794, 0.47047626014266697, 0.13081851175853185, 0.23151753257427896, 0.13426791237933294, 0.23904823990804808, 0.13640395418873855, 0.08279231882521085, 0.210381614576493, 0.1197074872574636, 0.12774345890751906, 0.1491420649524246, 0.12115002556570939, 0.15309812767165049, 0.21183974561946733, 0.0831405972795827, 0.19578526781073638, 0.19169575082404272, 0.18526471805359634, 0.10656467785260507, 0.0730657907468932, 0.10077984790716853, 0.09630776609161071, 0.1292488702705928, 0.05470826669729181, 0.1742543610078948, 0.08657393019114222, 0.07991190374429737, 0.10983209538140468, 0.10629143858594553, 0.1582852971873113, 0.10970223056418554, 0.11083827460450785, 0.1992226040789059, 0.12115647164838654, 0.1274836885609797, 0.19642315858176776, 0.22443866170942783, 0.14443022278802736, 0.08610960189253092, 0.25057095874633106, 0.08441793945218835, 0.15329615133149282, 0.1608626717435462, 0.1116374327934214, 0.0763215646147728, 0.11230557944093432], [0.019915265729650855, 0.012915926802504276, 0.06392869925392525, 0.05669287645391055, 0.056302159026797326, 0.09166130077626024, 0.03266447562990444, 0.06892463045993022, 0.030158164046172584, 0.014339704465653216, 0.01725707934903247, 0.03640692534723452, 0.05783033863242183, 0.06399811338633299, 0.020003672057230557, 0.06069311858820064, 0.04340031776311142, 0.04231289754222546, 0.03010409837588668, 0.019499347511945025, 0.028299619310668538, 0.02596593212469348, 0.08345707279763051, 0.11699812406940119, 0.01875801577365824, 0.06259298271366528, 0.04737814449306045, 0.02604657601165984, 0.06436351806457553, 0.03484720404126814, 0.028825426274644475, 0.03785440678309117, 0.025706504438338534, 0.020311182431344475, 0.007742529003215688, 0.06695871773575034, 0.007369234659043806, 0.06144041634563889, 0.033484871964901686, 0.030432383795934062, 0.01651187487212675, 0.04459310768704329, 0.008112450180176114, 0.03274558770603367, 0.06063804190073695, 0.050426571629941463, 0.027274985631395663, 0.007959913811646402, 0.017743193710755025, 0.03525712400940912, 0.03682597161137632, 0.0339464827307633, 0.08362434525042772, 0.3462908353124346, 3.583224662712642, 13.625443492616926, 24.32620780808585, 31.067223276410783, 36.47823020390102, 33.423604079655235, 22.714251790727886, 18.070958273751394, 11.452243259974889, 15.365324531282697, 23.673860549926758, 27.206328187670024, 17.46453513417925, 20.868077210017614, 17.483514138630458, 10.208718947001866, 7.03222793340683, 4.188244700431824, 2.574386179447174, 1.2417090960911341, 0.558499025447028, 0.21607171424797603, 0.1691160731549774, 0.14135534635611943, 0.2790283645902361, 0.6677293756178447, 0.25233892244952066, 0.4311325198837689, 1.6260453356163842, 1.3641957406486784, 0.7714492071952138, 0.8920479501996721, 0.2908605496798243, 1.3494269102811813, 1.1570224974836623, 2.1097614424569264, 0.9605895408562252, 2.429452185119901, 1.6406123425279344, 2.637155771255493, 1.7477365200008665, 1.214023238846234, 0.8355061156409127, 1.4940319508314133, 2.097399728638785, 0.8068854542715209, 1.499417130436216, 2.4419272414275577, 1.7411703637668063, 0.5759380268199104, 2.6951790920325687, 0.3824863630746092, 0.30676866748503273, 0.47100540889160974, 0.2878579779395035, 0.4203789069184235, 0.27570017746516634, 0.464079846228872, 0.9033952270235334, 3.1265508362225125, 3.920360812119075, 6.525448041302817, 8.888005358832222, 11.68039517743247, 18.370818206242152, 22.141145263399395, 20.22210839816502, 18.39609054156712, 24.7940491267613, 35.27073403767177, 31.043109553200857, 30.367042882101877, 17.791737965175084, 9.128646663257054, 3.164160349539348, 0.17202147868062767, 0.09976683583642755, 0.09479723178914615, 0.06905241895999227, 0.03718621603080204, 0.01437067280390433, 0.0269926743515368, 0.016558169620111585, 0.02906618406996131, 0.027869668988777057, 0.016934244261522378, 0.0078814225770267, 0.02175294720966901, 0.048150361449058564, 0.027957200006182705, 0.08724402423415865, 0.02460016157212002, 0.05173577102167266, 0.04016969379569803, 0.029277758074126074, 0.08871689984308821, 0.03757791054834213, 0.016791572095826268, 0.013876393121401114, 0.07158703902470213, 0.0059448683667661885, 0.043722655823720355, 0.032736770143466334, 0.00807736483069935, 0.02127244772522577, 0.03697788203135133, 0.03734341223857232, 0.05199541923190866, 0.04180718878550189, 0.07871040143072605, 0.07049404803131308, 0.004732384388002434, 0.04777224441724164, 0.04634190956130624, 0.05202922723921282, 0.06771676348788397, 0.023711231503901736, 0.0561567354016006, 0.06913277107690062, 0.09068142835583005, 0.05870080406644514, 0.019262693157153468, 0.1336845215409994, 0.02581459337047168, 0.012184762063303163, 0.009674263918506247, 0.041817343062055964, 0.03110401811344283, 0.05310705636761018, 0.01820274512283504, 0.05589394896690335, 0.04593494800584657, 0.020259564576138343, 0.06344056794685976, 0.05459190133426871, 0.04092389903962612, 0.056397852820477316, 0.028878345220748867, 0.03994898331750717, 0.07816132410828557, 0.01597196964680084, 0.01123231093931411, 0.022182176588103175, 0.0541307384015194, 0.0570492430457047, 0.04271965553717954, 0.04189732877005424, 0.04190585795523865, 0.03516201375584517, 0.023682982394737855, 0.04509316424706152, 0.06763276763792549, 0.011411024340694504, 0.04956861159631184, 0.010739697060281677, 0.03799303148740104, 0.013005999781723534, 0.026332169704671417, 0.006583135300648532, 0.01603187241458467, 0.07687835688037531, 0.0309511645297919, 0.022332137916237116, 0.021497889288834164, 0.04067162311236773, 0.024615411646664143, 0.047703797197235484, 0.021606768714264035, 0.043360179024083276, 0.0488179958026324, 0.03090355172753334, 0.05801032004611833, 0.017295733792707324, 0.080613223968872, 0.06871563488883631, 0.7179512264473098, 5.113577127456665, 18.027471235820226, 30.105675969805034, 38.38292598724365, 43.77369628633772, 38.338943890162874, 24.766819136483328, 21.53407073020935, 17.582267148154124, 23.048227378300258, 28.495691503797257, 24.3222872870309, 22.70669562476022, 22.419323342187063, 20.440354790006364, 15.501264299665179, 8.440090605190822, 4.876254890646253, 3.1487874601568495, 0.7957330527050155, 0.33070008190614836, 0.11287972184696368, 0.1380890959075519, 0.04697977997628706, 0.1508474541561944, 0.2263491041958332, 0.32309370434709955, 0.243696286209992, 0.6681733546512467, 0.6897229211671012, 1.1620430052280426, 1.1179080477782657, 0.916183603661401, 0.6296098753809929, 1.340938600046294, 1.4231212415865488, 1.270065563065665, 1.5588286795786448, 1.9947998055389948, 3.230366042682103, 1.4126993779625212, 1.8547955581120081, 1.5531511328050067, 1.3370241586651122, 1.8798299176352364, 1.4726998955011368, 1.5592924718345915, 0.7681575523955482, 1.1106445746762412, 1.2687951283795493, 0.04971592154886041, 0.4062243678740093, 0.6083224405135427, 0.3188958524593285, 0.03991130426792162, 0.14893507105963572, 0.2098906130662986, 0.647213625056403, 1.2596946167094367, 3.8578209451266696, 5.068708266530718, 8.270440782819476, 11.034195337976728, 15.8294746194567, 21.242272445133754, 26.854665960584367, 23.33050663130624, 17.980079310280935, 29.12661051750183, 39.088664940425325, 35.418640341077534, 36.14965336663382, 22.70522086960929, 12.287977797644478, 4.022359064647129, 0.2885694354772568, 0.06962573355329887, 0.06253327163202421, 0.03903749365625637, 0.08933933358639479, 0.02429017284885049, 0.04371300705575517, 0.047533878457865546, 0.019507388151916008, 0.06010583295886006, 0.015257843770086765, 0.013878509302490523, 0.04771792429632374, 0.06974232622555324, 0.025608663081324527, 0.09793844180447714, 0.01615962020254561, 0.02770775865896472, 0.03311871750546353, 0.03268430920849953, 0.02765366415094052, 0.021402310846107345, 0.024805282708257437, 0.009870574277426516, 0.07264333484428269, 0.021809362307456986, 0.024603009722860794, 0.04317202465608716, 0.02795734758754926, 0.01597158288184021, 0.02638558398133942, 0.020695969462394714, 0.03180118909637843, 0.07761818396725825, 0.023434759017878344, 0.04997054859995842, 0.05945610175175326, 0.02891187842137047, 0.10420547944626637, 0.02130971965380013, 0.05452754907310009, 0.0337217213985111, 0.02373011682980827, 0.08223535014050347, 0.02230439261932458, 0.04435916916866388, 0.024763791988204633, 0.2101851651178939, 0.09978316138897624, 0.15576789155602455, 0.1328912191092968, 0.13275430431323393, 0.1803699428481715, 0.17903583443590573, 0.13305630667933396, 0.151285231379526, 0.09012074129922049, 0.13124558169926914, 0.15278074970202787, 0.10742984392813273, 0.1497797928750515, 0.17496011885149138, 0.1395045199564525, 0.10563632659614086, 0.1740129246775593, 0.11942802582468305, 0.10560109027262245, 0.19707200090800012, 0.1153810801250594, 0.1906789389571973, 0.187262677986707, 0.07034793230039732, 0.1694862140076501, 0.18254415903772625, 0.08083709302757468, 0.17384581507316657, 0.12557330035737582, 0.09241750769849334, 0.10550139312233243, 0.1196993991200413, 0.18971360075686658, 0.12422186216073376, 0.18885650246271066, 0.12687835390014307, 0.20106203109025955, 0.26005484270198004, 0.1074120391692434, 0.11127760567303215, 0.19878204486199788, 0.0770807842324887, 0.11327122298202344, 0.13240815645882062, 0.13798214521791252, 0.11152896897069045, 0.16246153094938823, 0.11844465216355664, 0.194880997762084, 0.1548252978495189, 0.17230513345982346, 0.1809649094939232, 0.7970864857946123, 5.899235997881208, 19.208850860595703, 32.833806242261616, 42.66581644330706, 50.33751358304705, 44.21919740949358, 32.51255280630929, 29.21870367867606, 21.364991528647288, 26.0590329510825, 34.507227761404856, 36.23440054484776, 27.477863788604736, 29.39311041150774, 24.383247307368688, 15.2083386693682, 10.344624842916216, 6.014163979462214, 3.841835311480931, 1.6392806768417358, 1.3570154287985392, 0.426138773560524, 0.524167596229485, 0.73820240263428, 1.273044386080333, 1.0548762700387408, 1.8646120599337985, 1.994312128850392, 3.814430747713361, 3.9443047387259345, 5.085011780261993, 3.143397395099912, 2.535697958299092, 5.679182205881391, 4.668953214372907, 6.032546741621835, 3.9924275279045105, 6.748598558562143, 5.279448866844177, 7.600901944296701, 5.982935735157557, 4.647084627832685, 4.823119844709124, 5.387760426316943, 6.83238297700882, 4.492275723389216, 5.329648298876626, 6.587698689528874, 3.7518722074372426, 3.112626211983817, 6.4587331754820685, 2.1318382578236714, 2.147759186370032, 1.0449607563870293, 0.7515372442347663, 0.9269069539649146, 0.7449405810662678, 1.0442394465208054, 1.7886900710208076, 4.433481803962162, 5.708283867154803, 10.425496663366046, 13.28957278387887, 18.63241788319179, 27.306279761450632, 31.720569338117325, 28.505849770137242, 25.582334416253225, 34.74601302828108, 44.007187025887625, 40.040158203669954, 41.043509347098215, 25.79800476346697, 13.435773304530553, 4.512164507593427, 0.4008829402072089, 0.26020102628639763, 0.26015358311789377, 0.13358930950718267, 0.15880589639501913, 0.07797105610370636, 0.14382198399731091, 0.14801466544823988, 0.1132181276168142, 0.10112472690109696, 0.09838003239461354, 0.05352368704708559, 0.1118414072053773, 0.1739879681595734, 0.10100544723016874, 0.2347253475870405, 0.10160985908338002, 0.10265452481274094, 0.1432533445102828, 0.16576058178075723, 0.14351458049246243, 0.1127111262508801, 0.09721264682177987, 0.11845035185771328, 0.2374830496098314, 0.196835707873106, 0.1611098349094391, 0.10509939505053417, 0.1044081375002861, 0.14757630468479224, 0.10314043052494526, 0.12874834212873662, 0.11902929150632449, 0.14747239383203642, 0.19167122856846877, 0.14341255596705846, 0.1384725496172905, 0.11116848367133311, 0.14194145133452757, 0.11566941679588386, 0.2102627216705254, 0.1083867343674813, 0.14870246925524302, 0.15289542212017945, 0.16226322230483803, 0.12309211492538452, 0.09735057263502053], [0.05037658395511763, 0.03049158936898623, 0.0158783114581768, 0.01556956275765385, 0.03460480758388128, 0.0026152747658280922, 0.03911586105823517, 0.03303300156923277, 0.04408824709909303, 0.0380012858659029, 0.03139290439763239, 0.02996899526832359, 0.0290048411116004, 0.051306058187037706, 0.040244373359850476, 0.08253315916018826, 0.032812185918114016, 0.023074606200680137, 0.018994315593902553, 0.08758230108235564, 0.06335027529192822, 0.019136665455464805, 0.05410028914255755, 0.004714144094448004, 0.028202446310647895, 0.014983052354572075, 0.022086494668786014, 0.06615982417549406, 0.03226607379370502, 0.02102427014948002, 0.02084755588189832, 0.03297257124047194, 0.04398679593577981, 0.03731434040569833, 0.018836837794099535, 0.0264762600085565, 0.037838576561106105, 0.004132874950300902, 0.03560974169522524, 0.05740567749100072, 0.028278786589258482, 0.03883759045441236, 0.07592872676572629, 0.0706747690481799, 0.07668895740061998, 0.01596095023809799, 0.04667470045387745, 0.044921735767275095, 0.037169327294187884, 0.027967983623966575, 0.05696077564997332, 0.0493243932723999, 0.016429962124675512, 0.10309433085577828, 0.5233615509101323, 3.1470634383814673, 11.055350865636553, 23.613819428852626, 32.12441601072039, 40.27730022157942, 40.707702909197124, 43.57195881434849, 31.397839409964426, 24.699317387172155, 10.556656071117946, 12.524878365652901, 23.749337094170706, 20.883516107286724, 11.833665490150452, 15.72596035684858, 16.729806559426443, 10.527702059064593, 8.412216169493538, 5.53368866443634, 3.0177290184157233, 1.4906298305307115, 0.8872484277401651, 0.26671683522207396, 0.2287732655448573, 0.14736770944935934, 0.21312768650906427, 0.8524459866540772, 0.35240112457956585, 0.7162302987916129, 0.8557995238474437, 0.7086487827556474, 0.31180635573608534, 0.8002907452838761, 0.7560866315449987, 0.2963455282151699, 1.1096725868327277, 0.7222203516534397, 1.5450779774359293, 2.4879677423409055, 1.0545391738414764, 1.769588930266244, 1.3739478630678994, 0.8940269925764629, 0.6262834795883724, 1.885932173047747, 0.3861250478242125, 0.4929015710949898, 0.6394845140831811, 0.14520110642271383, 0.45840647923094885, 0.4432594877268587, 0.1595370585897139, 0.20358348079025745, 0.15993013392601693, 0.2668512122971671, 1.042458102107048, 2.1574104513440813, 3.249710044690541, 4.66011814560209, 5.168451828616006, 8.80717088494982, 17.382192032677786, 21.16314114843096, 16.498898812702723, 20.117638758250646, 17.00985196658543, 25.199370554515294, 30.145471777234757, 33.37411553519112, 30.71598141533988, 18.367879118238175, 8.478224924632482, 2.0559619750295366, 0.3056690879166126, 0.005084253140791718, 0.03543773306799786, 0.030231381367359842, 0.013082932930306664, 0.06115388457796403, 0.07188423057751996, 0.050533339115125794, 0.058156435777034075, 0.04244862150933061, 0.03294300746970943, 0.05830309433596475, 0.03876694817362087, 0.011408530724500971, 0.12113166440810476, 0.036457398174596686, 0.030654620977916887, 0.00921270573910858, 0.06203781893210752, 0.0234165318709399, 0.07265248828168426, 0.01530349051712879, 0.052745940030685494, 0.00931272264902613, 0.012453325375515436, 0.005784645044643964, 0.027336574558700834, 0.028984868433326483, 0.048700537998229265, 0.0975626962525504, 0.04862964465948088, 0.03887423473809447, 0.04068726334454758, 0.02904555999806949, 0.023626370521794473, 0.07664642004030091, 0.011630655948205717, 0.05624907383961337, 0.037618259633226056, 0.012587425099419696, 0.021155358026070253, 0.004819622787181288, 0.04254181829414197, 0.01569656076441918, 0.052828928256141286, 0.02470428277073162, 0.03763392022145646, 0.03215932666457125, 0.030064957083335946, 0.04485974480797138, 0.03472813132352062, 0.019304263605070964, 0.009807403515359121, 0.05146601263965879, 0.01964897126890719, 0.022919197932683995, 0.046779812313616276, 0.0848184379615954, 0.00813500044335212, 0.05195807944983244, 0.06403376361621277, 0.05367199105343648, 0.048785731462495666, 0.00903025530611298, 0.01771069527603686, 0.03507041831367782, 0.06473737050380025, 0.033344221833561144, 0.020723065062026893, 0.025002441235951016, 0.06631075750504221, 0.0840822613931128, 0.018302240408957005, 0.023215563369116614, 0.06327499183160917, 0.013168335892260075, 0.06845276363726173, 0.04970633724172201, 0.051990716984229426, 0.01401335880759039, 0.08538790526134626, 0.012276797705063862, 0.1104428990344916, 0.024906674499756525, 0.023262889490329793, 0.024794804431231957, 0.009997916640713811, 0.011984527227468789, 0.04585205477529338, 0.03437158152727144, 0.01914277227063264, 0.06875124440661498, 0.016112911548199396, 0.01721582781257374, 0.044859554818166156, 0.06745925266295671, 0.033665379243237634, 0.09188270675284521, 0.0479054544121027, 0.01993480244917529, 0.03839790994035346, 0.04529462129409824, 0.8027271745460374, 4.795611926487513, 15.423877000808716, 27.211249249322073, 37.46685116631644, 44.391724654606406, 41.57552249091012, 41.57865265437535, 30.753435679844447, 25.91463201386588, 17.00580985205514, 20.744317633765085, 23.1709395136152, 25.021547045026505, 21.7796721799033, 20.528749772480555, 19.626788479941233, 13.471313340323311, 10.998125502041407, 7.370351161275591, 3.5055540076323917, 1.5246854488338744, 0.8216149296079363, 0.16604019249124186, 0.021424520993605256, 0.1051645479830248, 0.0758745050323861, 0.22106560984892504, 0.2155636136553117, 0.558038055896759, 0.31265246176293915, 0.619365896497454, 0.6985873569335256, 0.6469883514302117, 0.5204093264681953, 0.9691437504121235, 0.5648970678448677, 0.7935774283749717, 1.7748361229896545, 1.4099588564464023, 1.789059954030173, 1.2571322513478143, 1.4943238837378365, 0.5011900663375854, 0.6766863635608128, 0.5487184588398252, 1.0591412697519575, 0.6629550403782299, 0.520771284188543, 0.5574630924633571, 0.6422674847500665, 0.32561858743429184, 0.21359211658792837, 0.17672957533172198, 0.12003607462559428, 0.3328086701886994, 0.999907876764025, 2.254435747861862, 4.044185093470982, 5.984823473862239, 7.808479377201625, 12.910833426884242, 19.971499034336635, 19.803015640803746, 18.820823499134608, 23.360752139772686, 19.761496680123464, 27.21163661139352, 31.76672622135707, 37.946450574057444, 35.25833150318691, 23.363312550953456, 11.759224227496556, 3.20639215196882, 0.28792830130883623, 0.020177585671522787, 0.018704423381547843, 0.03802734500329409, 0.04564870461555464, 0.025242104893550277, 0.03671081743336149, 0.05742181305374418, 0.07767020724713802, 0.04313829807298524, 0.03222922934219241, 0.048694868838148456, 0.06823189370334148, 0.010842901388449329, 0.025188895873725414, 0.023826171943385686, 0.02718916621857456, 0.06514832523784467, 0.03650460046316896, 0.04634608255167093, 0.0754010368670736, 0.008494791092484124, 0.029581365175545216, 0.04153652795191322, 0.06459049481366362, 0.009958333452232182, 0.04099564054714782, 0.03312925176162805, 0.04589705182505505, 0.039867019679929526, 0.07695574379925217, 0.044672380933271985, 0.02898898035553949, 0.053160104235368114, 0.08641683576362473, 0.014447798486799002, 0.020568033380966102, 0.022129517181643417, 0.04404364020696708, 0.05304609678153481, 0.020718742793958102, 0.024079777799280624, 0.02559099572577647, 0.0364259616471827, 0.0325366803444922, 0.01413026954313474, 0.04360182909294963, 0.09165080383952175, 0.2138496477689062, 0.12053563924772398, 0.1327989926295621, 0.1605755700064557, 0.1202273400766509, 0.1231963921870504, 0.11622364419911589, 0.07460103729473692, 0.1394475501562868, 0.1554847253220422, 0.07754911588771002, 0.13641422720892088, 0.15489624547106878, 0.10458803748978035, 0.1164005518491779, 0.18039738280432566, 0.10811924907777991, 0.0815201470894473, 0.18645013230187552, 0.14897750663970197, 0.10415293369442225, 0.1736580372921058, 0.16990153172186442, 0.10858629830181599, 0.09228134607630116, 0.1442945429256984, 0.1550379642950637, 0.1209555845707655, 0.21758699151022093, 0.18935818411409855, 0.2749259690088885, 0.09133589573736701, 0.14273247388856752, 0.15890209908996308, 0.23520797597510473, 0.09301075086529766, 0.10908594434814793, 0.0823314239137939, 0.14708587314401353, 0.10667377271290336, 0.07411216638450112, 0.1998715414000409, 0.19457428636295454, 0.17260805863354886, 0.07082686945796013, 0.09095519009445395, 0.12388237752020359, 0.15641024708747864, 0.07435024396649428, 0.17422313482633658, 0.13364218095583574, 0.14180886559188366, 0.08913653982537133, 0.18736202908413752, 0.8114176339336804, 5.055185335023062, 16.864196879523142, 31.451218945639475, 42.314786502293174, 53.54328039714268, 53.55800015585763, 54.218759945460725, 41.62110267366682, 35.770375524248394, 21.405336243765696, 20.98927984918867, 34.6945755141122, 31.703799860818044, 21.466263260160172, 23.892226798193796, 24.656813519341604, 15.23089599609375, 12.228679265294756, 8.356838158198766, 4.289483428001404, 1.9879890510014124, 1.5016671525580543, 0.5912144556641579, 0.5177572316357067, 0.44855377078056335, 0.6967272481748036, 1.3377368918487003, 1.3877481796911784, 1.6768239651407515, 2.657075822353363, 1.5892525613307953, 2.7096489327294484, 2.3366631184305464, 2.410337039402553, 2.9846099955695014, 4.228507339954376, 3.858506211212703, 5.907518684864044, 5.863500544003077, 3.4131655480180467, 4.768652481692178, 2.8863720212663924, 3.543747821024486, 3.6400274889809743, 4.226712533405848, 2.2719343517507826, 2.8940341472625732, 2.19661631328719, 1.7254120664937156, 1.5332420468330383, 1.2318752237728663, 0.7651662986193384, 0.5608227093304906, 0.4032509188566889, 0.6595834270119667, 1.586354836821556, 3.223284959793091, 4.886744064944131, 6.8602917194366455, 9.414940237998962, 15.700667176927839, 25.297934225627355, 29.24602746963501, 25.40550971031189, 29.086163316454204, 25.015109539031982, 33.40274906158447, 39.406899384089876, 42.11867012296404, 39.707502773829866, 26.047101157052175, 12.613760590553284, 3.4757071520601, 0.558766313961574, 0.13702949562243052, 0.17493729293346405, 0.16680241801909038, 0.11803709688995566, 0.1480230792824711, 0.17888135915356024, 0.13566737728459494, 0.214734213160617, 0.15857568303389208, 0.13238059436636312, 0.19209930274103368, 0.18107962262417587, 0.1106898450691785, 0.19279891305736133, 0.11623524714793478, 0.08544550609907933, 0.13896041629569872, 0.1214129850268364, 0.18091290657009396, 0.16594160135303224, 0.09486530920756714, 0.11205569534961667, 0.16806823866707937, 0.1816572052027498, 0.08024115607674633, 0.11410673707723618, 0.08629936099584613, 0.20543225801416806, 0.14284274939979824, 0.13639586605131626, 0.1579313733215843, 0.12626961299351283, 0.153520583574261, 0.11381287713135992, 0.10802504806114094, 0.2750370316207409, 0.12793152167328767, 0.12701129248099668, 0.13981493615678378, 0.11005913319864444, 0.08263353484549693, 0.1807727212352412, 0.18683817290834018, 0.12459101235227925, 0.145321003560509, 0.12132230560694422, 0.16771336485232624], [0.03538511606997677, 0.019964311937136308, 0.05030391624729548, 0.04904454507465873, 0.09298234738941703, 0.05775094324988978, 0.039545044635555575, 0.0247622517137123, 0.021049053641036153, 0.019670475739985704, 0.06290449135537658, 0.07362417078443936, 0.03643517954541104, 0.06937382064227547, 0.03763089056259819, 0.010149037415560867, 0.03195991540061576, 0.023204457447198883, 0.06508895342371293, 0.03167329203071339, 0.034381579740771225, 0.01575212090808366, 0.0922450308821031, 0.027012161877272383, 0.06478346338761704, 0.021044096942724924, 0.013605030852236917, 0.07499988017869846, 0.048450731938438754, 0.08932308945804834, 0.024826288456097245, 0.026955436349713376, 0.049916683097503016, 0.01977096338357244, 0.011346837472436684, 0.017199193526591574, 0.02279710573410349, 0.04453453993690865, 0.030132254186485494, 0.02769849156694753, 0.03525502055085131, 0.041217820053654056, 0.040820585297686715, 0.06522554930831705, 0.046428276891154904, 0.023237751464226415, 0.02041952751044716, 0.05209758624966655, 0.037563125270285776, 0.032652309497020075, 0.08699424870844398, 0.012808613096629935, 0.04696618213451334, 0.048327974775539975, 0.03815100461776767, 0.05171839373984507, 2.6114274603979926, 8.601060390472412, 20.954088960375103, 29.512383188520158, 38.26980584008353, 41.52344226837158, 38.415478297642295, 34.417338916233604, 23.445459365844727, 19.832776512418473, 26.391377449035645, 16.75258101735796, 20.65700309617179, 22.82208956990923, 20.139435257230485, 16.488396610532487, 14.78532886505127, 12.152383702141897, 8.747625691550118, 6.728304173265185, 3.519401116030557, 2.8102933721882954, 0.952067141022001, 0.4483811786132199, 0.2439206370285579, 0.18298047062541756, 0.14982654393783637, 0.17509636868323597, 0.09654722109969173, 0.6831582848514829, 0.8384602942637035, 0.3122905311839921, 0.22953376759375843, 0.19421774335205555, 0.05635120353794523, 0.33788897043892313, 0.7951961957982608, 0.898829174893243, 1.3051365954535348, 1.1230410294873374, 0.3812913271997656, 0.44948013392942293, 0.36884941054242, 0.10300407891294786, 0.22216651934598172, 0.2578151614538261, 0.24513464474252292, 0.22402292330350193, 0.18283134219901903, 0.402101317686694, 0.27890207565256525, 0.8763850278088025, 1.4596879822867257, 2.2971602209976743, 2.571265786886215, 5.197860947677067, 5.974735123770578, 11.183985471725464, 10.822137185505458, 16.113593408039637, 14.786987747464861, 20.546460730688914, 22.73863649368286, 19.432916368756974, 24.671583652496338, 30.167494092668804, 31.416363307407924, 25.94923230579921, 20.350525004523142, 7.991532274654933, 2.3672540826456885, 0.14981525311512606, 0.05055121512019208, 0.1431064416787454, 0.03185725983764444, 0.06381851195224694, 0.027459606528282166, 0.011221685080922075, 0.018172781016411524, 0.028372453259570257, 0.012811337414729809, 0.05589405753250633, 0.028203693118744662, 0.021076281554996967, 0.019460881361737847, 0.060382899163024764, 0.06873901042022876, 0.06358842072742325, 0.01692629013476627, 0.010142923815042844, 0.07832540066114493, 0.011998399027756282, 0.07717705478093453, 0.04886837363509195, 0.02194536617025733, 0.0640647251691137, 0.03696984817673053, 0.08251027895935945, 0.05108155809076769, 0.08303653036377259, 0.03257531612845404, 0.027812639816797206, 0.015887821126463156, 0.05965243585939918, 0.07343880858804498, 0.04415150013353143, 0.004470968169958464, 0.022834532029394592, 0.06524341513535806, 0.07703313071812902, 0.045748252488140545, 0.013252246925341231, 0.07597950832652194, 0.021277260234845535, 0.03583990416622587, 0.01919860722097967, 0.10005072810287986, 0.04024713160470128, 0.042887996682631116, 0.01859947437021349, 0.013204827505562986, 0.019565525032313805, 0.04663419530593923, 0.033515419611441236, 0.07206811356757369, 0.01442925921375198, 0.021034232739891325, 0.015765416801774075, 0.011560773626635117, 0.0533109222139631, 0.027220360169719373, 0.055907523059951406, 0.02587018235187445, 0.017905565444380045, 0.046786000552986345, 0.10866614151746035, 0.023734863182263713, 0.027609498306576694, 0.03179861744865775, 0.06340178288519382, 0.01380035309453628, 0.02045161203880395, 0.1427182246531759, 0.035009747104985375, 0.043164516666105816, 0.02444905012712947, 0.06640751659870148, 0.05814501603267022, 0.01346734761526542, 0.019112004100212028, 0.024464535992592573, 0.09529081851776157, 0.029824426597250358, 0.03758628027779715, 0.027748760833804096, 0.007398053737623351, 0.019171506532334855, 0.020206959452480078, 0.051995972237948856, 0.027229788413803493, 0.06441602988966874, 0.015331693825178912, 0.08999888319522142, 0.032710900995880365, 0.016150916294593896, 0.014921449856566531, 0.018301241266142045, 0.05619691824540496, 0.031383856133158715, 0.026646036255572523, 0.025447426197518195, 0.0034661911818797565, 0.09546551414366279, 0.028193589732316986, 0.021495409243341004, 0.2313372322491237, 3.6562041980879645, 12.18464766229902, 25.863488061087473, 36.29642711366926, 44.02655165536063, 47.57511132104056, 42.2868686403547, 39.780691623687744, 23.277747222355433, 21.809806517192296, 30.96740892955235, 16.5684745992933, 21.324942111968994, 24.519327776772634, 25.19722008705139, 21.341902664729528, 18.14473077229091, 15.410427025386266, 9.418801699365888, 7.203127997262137, 3.126547144992011, 2.512951293161937, 0.9842439229999269, 0.3541979395917484, 0.29226142593792503, 0.05625456997326442, 0.09799159145248787, 0.16069290228188038, 0.01930555621428149, 0.2221968091492142, 0.2539985648223332, 0.15444919945938246, 0.25433332685913357, 0.06292927145425763, 0.4045673853584698, 0.3364643725965704, 0.5690624043345451, 0.40865194903952734, 0.12389461829194001, 0.5897386148571968, 0.38897163793444633, 0.40025581100157326, 0.4225773060960429, 0.42141391709446907, 0.2087376056505101, 0.1830780982439007, 0.13400872557290963, 0.24497714319399425, 0.022180704167112708, 0.16883501037955284, 0.19699870555528573, 0.611767552793026, 1.0884783012526376, 3.3888110263007025, 4.500793346336909, 5.822640359401703, 6.914155891963413, 10.502430592264448, 10.377624443599156, 17.828961202076503, 16.274753400257655, 24.846610512052262, 25.14301371574402, 22.459167787006923, 26.76168516704014, 33.875344685145784, 36.01766538619995, 31.62047358921596, 25.128115040915354, 10.362671051706586, 3.541607992989676, 0.26751164400151795, 0.030656629441572086, 0.04948056149961693, 0.006927135167643428, 0.04954616905057004, 0.05322800184200917, 0.01815713569521904, 0.049543353130242655, 0.07377224069620882, 0.017205227399244905, 0.03772070485034159, 0.02512797699975116, 0.031931654417089055, 0.034363361075520515, 0.052994151533182175, 0.06315172237477132, 0.04035903899265187, 0.025166405830532312, 0.02842025605163404, 0.037695592269301414, 0.02646961884706148, 0.07867224062127726, 0.09130981963660036, 0.019696368636297326, 0.051909299567341805, 0.021777036899168576, 0.05212326201477221, 0.06882778315671853, 0.045812292623200586, 0.0041481343547015315, 0.060665963616754325, 0.05927609998200621, 0.014771359606779047, 0.024591652742986168, 0.0904501700507743, 0.010963890967624528, 0.01982990772064243, 0.037624257882790904, 0.043768711388111115, 0.012860273360274732, 0.022378273208492568, 0.021363284904509783, 0.03045196631657226, 0.013910698155606431, 0.0421368652023375, 0.025820927494870763, 0.041615414433181286, 0.017008928914687464, 0.025490178992705684, 0.09208208748272487, 0.13756887667945453, 0.16607264003583364, 0.12868198140391282, 0.2665434016713074, 0.19759146017687662, 0.1381761926625456, 0.1468336616775819, 0.055952326727232764, 0.20156646759382316, 0.22265286610594817, 0.13147274165281228, 0.1348293051123619, 0.13472619493092808, 0.18879605856324944, 0.1636692282876798, 0.11336233666432755, 0.10686662593590361, 0.12382269357996327, 0.1260716300457716, 0.11193948265697275, 0.09641037415713072, 0.30427735831056324, 0.17416537792554923, 0.11824628923620496, 0.12294978541987282, 0.15958136692643166, 0.1379353263016258, 0.1066004570041384, 0.1702962355422122, 0.14858688760016645, 0.20365290849336556, 0.13561806135943957, 0.07230458302157265, 0.04184653703123331, 0.08117838935660464, 0.06448260774569851, 0.1359436088906867, 0.2237343830721719, 0.09923968198043959, 0.14083609064774855, 0.10661424483571734, 0.20996857673994132, 0.15655014743762358, 0.2228760091321809, 0.1441493092903069, 0.12081088019268853, 0.1656595750578812, 0.14561334358794348, 0.10601626549448286, 0.1688383894839457, 0.12850183035646165, 0.19341735701475823, 0.12907735018857888, 0.11253374362630503, 0.3682338707149029, 3.975877787385668, 12.10124409198761, 27.41197054726737, 40.63022354670933, 50.16433320726667, 53.244344575064524, 51.065580572400776, 45.16948168618338, 33.976336751665386, 29.42928273337228, 39.08700432096209, 25.488158532551356, 31.170852184295654, 33.491564410073416, 29.316846983773367, 24.90144395828247, 20.53658734049116, 18.063565390450613, 12.838018911225454, 8.735344750540596, 4.943549062524523, 3.8621336051395962, 1.64261266376291, 0.687686556151935, 0.5951495787927082, 0.4791925038610186, 0.3934317028948239, 0.43743670731782913, 0.5262823456100055, 1.6425398162433078, 1.8845169118472507, 1.0770502516201563, 1.3656645246914454, 1.697446869952338, 1.0025087829147066, 1.9713009979043687, 2.672692332948957, 4.180493550641196, 3.2024803161621094, 2.8635862725121632, 1.9490116110869815, 2.796665132045746, 0.9232321168695177, 1.0150216200522013, 1.0731662086078098, 1.2764631169182914, 0.7309369210686002, 1.0087555391447884, 0.7960648291877338, 0.7813954449125698, 0.6511743696672576, 1.226018760885511, 2.1017868646553586, 3.340106108358928, 4.2488382032939365, 7.742269992828369, 10.05337199143001, 17.842838491712296, 18.136372089385986, 24.28303517614092, 23.80758384295872, 29.570622989109584, 32.95131765093122, 29.58542960030692, 33.68632241657802, 40.52608394622803, 41.54660756247384, 34.771985394614084, 27.505993570600236, 11.986839396612984, 3.954269758292607, 0.34723421611956184, 0.13358698891741888, 0.20771973526903562, 0.2137755924569709, 0.1737278721162251, 0.13887550442346505, 0.10467379074543715, 0.16411746852099895, 0.1921811747763838, 0.11756107743297305, 0.09101399193917002, 0.07052003592252731, 0.11271357576229743, 0.10141956393740006, 0.138196073738592, 0.19074076706809656, 0.18220124101000174, 0.16137609205075673, 0.1308656292302268, 0.17515739612281322, 0.12719415766852243, 0.179964952436941, 0.33610168205840246, 0.12757017463445663, 0.18648179274584564, 0.12991084903478622, 0.1768296185348715, 0.1222326960414648, 0.13007384671696595, 0.1491244366126401, 0.15352708393973963, 0.164476196414658, 0.20372192907546247, 0.18712669956896985, 0.1458231873278107, 0.07098667124020201, 0.11601435685796396, 0.24824684060045651, 0.10861713771841355, 0.08645688968577556, 0.15087749968682015, 0.12636924907565117, 0.11672007398945944, 0.1107193681278399, 0.13633276229458197, 0.13354863811816486, 0.1193945604775633, 0.1631234690014805, 0.055507557200534005], [0.016431456598054086, 0.10504003002175263, 0.013462366320059767, 0.03505118863124933, 0.02454998390749097, 0.01999138548438038, 0.028734166707311357, 0.01296870834526739, 0.021105536592325995, 0.028932153047727685, 0.00798984059864389, 0.04775425984657236, 0.039176637439855506, 0.01795652851329318, 0.0090138661409063, 0.017686619157237665, 0.05449080979451537, 0.008469359599985182, 0.08795786342982735, 0.026106653502210975, 0.055799001561743874, 0.06127479951828718, 0.036881065262215476, 0.03562750913468855, 0.073750961838024, 0.04524412132533533, 0.028443835143532072, 0.019198274738820534, 0.041757608231689246, 0.04102558090484568, 0.013320914669228452, 0.03969973704910704, 0.042177502664604356, 0.029861990295882736, 0.039933977515569756, 0.021039303092818176, 0.045193719744150124, 0.051380700431764126, 0.07981848304292985, 0.06632780909006085, 0.05469009213681732, 0.01846573511803789, 0.028146970983860747, 0.0602890509845955, 0.017092724596815448, 0.07400991794254098, 0.05786530354193278, 0.06775938905775547, 0.0853535035359008, 0.05356712007362928, 0.021009260954867517, 0.017781960112707954, 0.02461439723681126, 0.034972403930234056, 0.020046750549227, 0.015404180024883576, 0.12126461655965873, 1.205546653696469, 6.300777171339307, 13.504880956241063, 26.857995884759085, 38.39783682141985, 44.143010411943706, 36.22047635487148, 31.843298843928746, 25.44287712233407, 31.28283977508545, 34.65614850180489, 24.634271826062882, 22.83491247040885, 27.0424861907959, 26.711993387767247, 25.22356070790972, 24.883786848613195, 18.36493829318455, 16.31951195853097, 12.699195640427725, 6.750095461096082, 5.3774740525654385, 3.251291628394808, 1.5385323401008333, 1.3766614603144782, 0.5161428068365369, 0.47701798911605564, 0.18272688851824828, 0.2035933466894286, 0.16621963786227362, 0.22705187648534775, 0.17764732108584472, 0.24630251207521983, 0.1537039644484009, 0.14975512134177343, 0.17094203803156102, 0.10947922324495656, 0.16509055559124264, 0.07000662240066699, 0.7540746395077024, 0.11190577303724629, 0.5966444728629929, 0.13677820696362428, 0.13957287557423115, 0.27338078192302157, 0.3424547240138054, 0.3159695209137031, 0.7076687610575131, 0.8969521299004555, 1.9042041982923235, 3.1260210360799516, 4.547830045223236, 4.766680496079581, 5.3804053238459995, 11.854674237115042, 13.694199391773768, 15.854420389447894, 23.291296209607804, 13.698039140020098, 23.147077662604197, 18.01559329032898, 22.033244950430735, 27.799905845097133, 36.16148962293352, 30.203183514731272, 22.05597424507141, 14.868726355688912, 6.531960240432194, 2.5971968982900893, 0.16085579139845713, 0.0821502414931144, 0.09333148758326258, 0.05329118363027062, 0.051593963988125324, 0.06388126287077155, 0.035261921251990964, 0.0580036568322352, 0.017532084503078034, 0.05937135272792407, 0.0622786513662764, 0.050976368199501715, 0.04579144463475261, 0.050764828122087886, 0.03466958053676145, 0.056759087901030264, 0.02271510647343738, 0.06427712698600122, 0.05445760229070272, 0.056127996050885746, 0.05309560948184558, 0.02016858320816287, 0.021312089437352758, 0.019948284939995835, 0.014114966033957899, 0.029048243604068245, 0.039287364176873646, 0.06689153598355395, 0.017811264343825833, 0.03939540730789304, 0.023281196365132928, 0.0454686960604574, 0.04384373361244798, 0.01581563857117934, 0.03464396244713238, 0.014151751113656377, 0.04747669831184404, 0.012661208149178751, 0.04657940360318337, 0.03846132243052125, 0.04124777737472739, 0.08713066817394324, 0.06008189424340214, 0.01980878153283681, 0.04670405387878418, 0.05467332892918161, 0.04399643113304462, 0.026175480701827576, 0.06687240808137826, 0.019128166804356233, 0.05762426076190812, 0.05858383819993053, 0.03689351977248277, 0.02046397833951882, 0.005728383465403957, 0.025840618581111943, 0.023814114376104305, 0.027338009660265276, 0.019380530941167047, 0.046540560866040845, 0.017831223451399376, 0.007583732300970171, 0.019509986941037432, 0.08699019785438265, 0.06301138097686426, 0.023805951599829962, 0.04713569714554718, 0.009749345514657242, 0.006790871341114065, 0.0467974711874766, 0.06623622043324368, 0.029533732017236095, 0.0819049985813243, 0.04516714831281986, 0.029720692163599387, 0.030775827688298056, 0.05618345611063497, 0.011295374832116067, 0.024652508852471198, 0.06665354661111321, 0.06454901596797363, 0.012318713357672095, 0.052118359599262476, 0.022134543429794054, 0.03551977473710265, 0.048688521143049, 0.05211359967610665, 0.02585202475477542, 0.019052720495632718, 0.029265296778508594, 0.05345219659752079, 0.04841478654582586, 0.019670857415933694, 0.040745318800743134, 0.06284621876797505, 0.018715580193591968, 0.04505869127543909, 0.008141614463446396, 0.017409032177446142, 0.05486217540289674, 0.04205687949433923, 0.04091519682801195, 0.0719980683975986, 0.030115161889365742, 0.04944299101563437, 0.04420444282836147, 0.25241874530911446, 1.6749068051576614, 8.58196587221963, 18.277212074824742, 32.33948360170637, 43.03338657106672, 46.728351729256765, 39.25374024254935, 33.63013233457293, 27.90767240524292, 35.55913291658674, 29.43030411856515, 23.021805116108485, 21.356422662734985, 28.51070829800197, 29.216924939836773, 30.334855352129253, 26.993944338389806, 23.307216269629343, 16.32445386477879, 14.967246600559779, 8.874878474644252, 5.013014980724879, 4.067545805658613, 1.607950923698289, 1.484963140317372, 0.24933909199067525, 0.545025816985539, 0.17405951289193972, 0.16986934202057974, 0.015344492691968168, 0.13202638551592827, 0.1652353142521211, 0.1374047797705446, 0.05917453686041491, 0.19405911543539592, 0.16360104908900602, 0.27291128997291836, 0.1650400318737541, 0.24025934349213326, 0.15449360279100283, 0.05133611728836383, 0.1944951963211809, 0.17264537805957453, 0.10899818941418614, 0.1532693084861551, 0.12101251365883009, 0.3099465183913708, 0.48377907489027294, 0.8140742342386926, 1.5430878613676344, 2.8757299865995134, 4.837321528366633, 6.463892212935856, 6.334318731512342, 13.469680513654437, 15.272562605994088, 20.51787063053676, 22.749678918293544, 16.571000269481114, 23.72470920426505, 19.037994657244, 25.877226386751445, 28.88938512120928, 38.02285296576363, 36.05880914415632, 26.81246086529323, 18.899391991751536, 9.319250515529088, 3.5385755385671342, 0.22243083587714604, 0.10645443626812526, 0.045815997424402406, 0.04667975553976638, 0.07011765787111861, 0.041962926142982075, 0.05182828248611518, 0.02899117541632482, 0.022873076211128916, 0.029532809209610735, 0.08714537881314754, 0.04758601708869849, 0.024370314619903053, 0.025726339713271176, 0.02592333878523537, 0.02641502222312348, 0.046310995505856614, 0.03198975058538573, 0.009597530089584845, 0.036014436943722625, 0.07300598467034952, 0.06744851145361151, 0.05159767218200224, 0.00037226721178740263, 0.0603566262871027, 0.02375203011823552, 0.016664460434445312, 0.03579009969585708, 0.02389576588757336, 0.0067010689277334935, 0.06386032328009605, 0.026293649271662747, 0.04190273669415286, 0.019973214316580976, 0.03732603495674474, 0.048054023047110865, 0.057292294289384565, 0.00986375245598278, 0.04053690676976528, 0.030869078755910908, 0.017732725611754825, 0.023937546681346636, 0.05022939953154751, 0.034236186649650335, 0.01849604188464582, 0.06543394098324434, 0.015621443545179707, 0.02077394161772515, 0.0600096709760172, 0.01907533437146672, 0.15646923892199993, 0.15603355158652576, 0.14217769008662018, 0.10803914123347827, 0.11491848209074565, 0.20139056417558873, 0.09153130703738757, 0.19297124738139765, 0.17068960943392344, 0.1609014839466129, 0.12626468682927744, 0.14183819187538965, 0.16003298626414367, 0.1284243552280324, 0.17618522739836148, 0.05920029404972281, 0.09248227386602334, 0.1005459093887891, 0.21685338658945902, 0.09144115008945976, 0.19300378992089204, 0.08769531108971153, 0.24918180757335254, 0.16249073509659084, 0.20500735938549042, 0.12054714720164027, 0.15832548003111566, 0.07613680631454502, 0.17175334878265858, 0.15264440487538064, 0.11283755089555468, 0.10623927959906203, 0.1470298125807728, 0.09543997408556086, 0.1497286313346454, 0.16639110366148607, 0.121990011206695, 0.0843290106526443, 0.19521286923970493, 0.1390217151492834, 0.10384939105382987, 0.11556456956480231, 0.09729684623224394, 0.13969246058591775, 0.12238463360284056, 0.2017996393676315, 0.16656673566571303, 0.19425021803804807, 0.18087940051087312, 0.17470690315323217, 0.09111081210098096, 0.14106958811836584, 0.1650610664593322, 0.13730755927307264, 0.10230238549411297, 0.14860938782138483, 0.33170482942036217, 2.1514345662934438, 8.87907258101872, 20.52002283505031, 35.726900645664756, 49.37840509414673, 54.75759274618966, 49.000899042402, 42.87412691116333, 36.35682085582188, 40.21029526846749, 46.73318420137678, 35.06950725827898, 31.93397283554077, 39.640369279044016, 37.355183192661826, 34.504788943699424, 33.83370760508946, 25.546127353395732, 20.748959030423844, 17.11011447225298, 9.8774687903268, 7.177238140787397, 4.628351850169046, 2.6412575968674252, 1.8030589457069124, 0.8070487912212099, 0.7828005009463855, 0.3269467518797943, 0.6005578285881451, 0.4814461629305567, 0.7957560143300465, 0.8020799064210483, 0.9697470494679042, 0.7779885477253369, 0.6971931031772068, 1.0309247438396727, 0.5693693192941802, 1.6509451823575156, 1.048490658402443, 1.593235181910651, 0.656201391347817, 1.7537629966224944, 0.6432607514517648, 0.4890065629567419, 0.5231746552245957, 0.8519404509237835, 0.71246209527765, 1.0373911282845905, 1.219392567873001, 2.4021991789340973, 3.728068547589438, 6.263051492827279, 7.661187120846339, 9.18956412587847, 18.010330029896327, 21.846991539001465, 25.91932725906372, 33.86320618220738, 22.48475452831813, 32.547967774527415, 26.902328865868704, 31.242696557726177, 38.32918861934117, 45.05713973726545, 41.475749833243235, 30.244629519326345, 21.3189822946276, 10.705150365829468, 3.9056901250566756, 0.4049388968518802, 0.19102777381028446, 0.1612417692584651, 0.11015710008463689, 0.14197715584720882, 0.1340782211295196, 0.12140474761171, 0.1576889870422227, 0.1461319886147976, 0.0870151679430689, 0.17009996250271797, 0.08943778223225049, 0.09634865461183445, 0.12837989761361054, 0.12458755182368414, 0.13089253992906638, 0.11640231604022638, 0.12089102874909129, 0.2225976333554302, 0.12065449144159045, 0.2046899271330663, 0.16731739895684378, 0.171285444604499, 0.1379655889634575, 0.12073377147316933, 0.09292771853506565, 0.1970783927078758, 0.11488485389522143, 0.14853191269295557, 0.11502794335995402, 0.162001280646239, 0.14675349955047878, 0.13652357991252626, 0.08424247708171606, 0.1068065891574536, 0.12316560026790414, 0.14410630374082498, 0.05833522975444794, 0.14213834862623895, 0.10341107778783355, 0.1306635072188718, 0.17167689145675727, 0.1304353701749018, 0.07684656072940145, 0.10127741085099322, 0.1863259468227625, 0.09380776488355227, 0.12863988509135588, 0.08277234953961202, 0.09320796706846782], [0.02839024275142167, 0.07280834099011761, 0.030928504852844135, 0.01971925901515143, 0.03448033033471022, 0.04212667021368231, 0.014093198630559658, 0.05514156558950033, 0.013132735704337912, 0.03734298815418567, 0.06479104940912553, 0.0337270445057324, 0.016190115262621214, 0.042479684842484336, 0.07897297412689243, 0.04711813326658947, 0.07040556706488132, 0.04008678360176938, 0.025483911025470922, 0.07052074159894671, 0.0302833639351385, 0.07253799228263752, 0.013551654743163713, 0.04000656379918967, 0.08558572536068303, 0.01982425043492445, 0.10838184891534702, 0.019140324455552866, 0.014996567075806004, 0.026640367095491717, 0.051965142999376567, 0.049850434330957274, 0.0460276596381196, 0.02534324223441737, 0.01981330057606101, 0.011400951488342668, 0.0417272573603051, 0.06840705751840558, 0.014462291994797332, 0.010586218376244818, 0.034160740340926816, 0.026085137156769633, 0.0551709970459342, 0.022726834951234714, 0.05451725908954229, 0.02041517979731517, 0.05182659632659384, 0.04050860168146236, 0.03803265453981502, 0.03148139214941433, 0.033207042408840995, 0.03054450492241553, 0.025027742110458866, 0.02178370180938925, 0.07218745430665356, 0.013942801343676234, 0.05681799831134932, 0.07080356178006955, 0.5071432611771992, 2.3256519607135226, 9.207916055406843, 22.877463238579885, 31.629638263157435, 36.541868754795615, 39.99703768321446, 35.13109956468855, 35.4273499080113, 42.28427348818098, 24.31353255680629, 20.758104596819194, 19.752602985927037, 21.12327585901533, 13.989346708570208, 28.540116548538208, 25.86167631830488, 25.766878570829117, 16.67255687713623, 14.612162385668073, 9.538685917854309, 7.391004681587219, 6.315780069146838, 3.9607732721737454, 3.485125435250146, 1.9960124833243233, 1.4374592836414064, 1.20281959431512, 0.9566718425069536, 0.5159872866102627, 0.44234867660062654, 0.45472705523882595, 0.43953112778919085, 0.6058347140039716, 0.5825142253722463, 0.3600667789578438, 0.2804967686533928, 0.8237221336790493, 0.25361177272030283, 0.30943137460521286, 0.42720230934875353, 0.3623190266745431, 0.4636678397655487, 0.7984116918274334, 1.1406464619295937, 2.0522231927939822, 2.9516156060355048, 5.106670618057251, 6.506072989531925, 8.336438247135707, 11.061237726892744, 16.331450700759888, 18.64143317086356, 17.147113629749843, 15.220602239881243, 10.621378540992737, 19.35818154471261, 19.832354409354075, 23.849538803100586, 31.43103095463344, 27.1502423286438, 32.576385906764436, 22.89571268217904, 17.067155497414724, 11.504769904272896, 6.915538149220603, 1.871850780078343, 0.17069577053189278, 0.05706136168113776, 0.02178055001422763, 0.0775590699964336, 0.05219624184870294, 0.04586995452908533, 0.05357572389766574, 0.03140019186373268, 0.03168203156175358, 0.020938538946211338, 0.03682092670351267, 0.03194271114521793, 0.0590861373181854, 0.04168357666847961, 0.0236585873644799, 0.060580719262361526, 0.060343937682253976, 0.04571836641324418, 0.07884055801800319, 0.023364776612392495, 0.016909153732870306, 0.01955456329908754, 0.013070783760797764, 0.04744375204401357, 0.019070837380630628, 0.05150352884083986, 0.045106846905712566, 0.0762573548459581, 0.008606421977414616, 0.024837311257475188, 0.07738222341452326, 0.05840456924800362, 0.037757138788167915, 0.05579916780282344, 0.027976020871262466, 0.006906545870671315, 0.019129357633313963, 0.01409523593195315, 0.07657972683331796, 0.029543285790298666, 0.014583140777956163, 0.08518251271120139, 0.0382197198591062, 0.0310393706895411, 0.08641003005738769, 0.017813369498721192, 0.05162869819572993, 0.07420684237565313, 0.05045894453568118, 0.0559289647665407, 0.028735286290092126, 0.0029678814254501568, 0.032433770330888886, 0.005148485810163298, 0.0492721800027149, 0.08525046120796885, 0.005869762597805155, 0.01999702919939799, 0.016385937076328055, 0.040161442809871266, 0.03236850883279528, 0.04254604217463306, 0.025877756499020115, 0.05447354447096586, 0.03665454652426498, 0.037843662181070874, 0.05935680493712425, 0.03440980001219681, 0.010095111693122556, 0.007502403941803745, 0.06162576497133289, 0.031018227538360015, 0.03415242828694837, 0.00870387232862413, 0.020492999282266413, 0.026417654938995838, 0.017241803829425147, 0.06178488821855613, 0.026607212178143005, 0.028670394593583684, 0.05528654816693493, 0.03914224249976022, 0.03956705291888543, 0.06058024428784847, 0.0162058369190033, 0.08461524386491094, 0.01698961611171918, 0.00898444655883525, 0.01432449001419757, 0.07057944844876017, 0.028707866689988544, 0.025143942928739955, 0.01693372178955802, 0.04607235473979797, 0.01336595752010388, 0.02735390095040202, 0.026084882706137638, 0.0023553110368084162, 0.014344462692471487, 0.00630293511286644, 0.022146020849634494, 0.0987093865073153, 0.020814984504665648, 0.017566723715780035, 0.030209430759506564, 0.030033103256885494, 0.0575558440759778, 0.024089390944157327, 0.10329094994813204, 0.7934795564838818, 3.73432149205889, 12.30816752570016, 27.858915158680507, 39.9634222984314, 42.18328489576067, 43.76272855486189, 36.67944656099592, 39.78408234460013, 46.1614898954119, 24.457316841397965, 24.046610559735978, 25.541254929133824, 23.906826700483048, 18.70694773537772, 33.72708054951259, 29.803043706076487, 30.025274889809744, 24.55918264389038, 16.76626202038356, 12.800892949104309, 8.799513970102582, 7.033328788621085, 4.0908022948673795, 3.9511126705578397, 1.9798930968557085, 1.3017458745411463, 0.7763957817639623, 0.7695883927600724, 0.5988066654120172, 0.5900437927671841, 0.5101118790251868, 0.6355705069644111, 0.31208745922361103, 0.4080748142940657, 0.44924422087413923, 0.21413612525377954, 0.2475863274719034, 0.3972422741353512, 0.14664517822010176, 0.33663856610655785, 0.40494508509125027, 0.49817623091595514, 0.7330912968942097, 0.9030611706631524, 1.803908797247069, 2.95555089201246, 4.898506930896214, 7.6209874493735175, 9.639448693820409, 12.323474407196045, 14.379858919552394, 17.048850468226842, 21.44552288736616, 18.87072546141488, 14.71925323350089, 22.871807404926844, 20.10155541556222, 27.857909406934464, 33.35909005573818, 29.360742228371755, 37.44536733627319, 30.595416273389542, 22.121761526380265, 15.525977305003575, 8.496293715068273, 2.7736420588833943, 0.3230068790061133, 0.03412727499380708, 0.013849099050275981, 0.04777346578027521, 0.049913850213800154, 0.013489928412517267, 0.05716474327657904, 0.04199470533058047, 0.07903867667274815, 0.04450427388240184, 0.05346525500395468, 0.02568586340307125, 0.06084872702402728, 0.05370749539828726, 0.03685612231492996, 0.03864697639697364, 0.057612121770424504, 0.04263727120789034, 0.019727993457178985, 0.021624383483348147, 0.022950995779995407, 0.025321708925600563, 0.025546553378392543, 0.024424622866458127, 0.05430521011086447, 0.021755199945930923, 0.014985807206747788, 0.04615810460277966, 0.024414317615862404, 0.03252564397241388, 0.020061973482370377, 0.024847699628610696, 0.015011482971853443, 0.06516718851136309, 0.019244974911479012, 0.06603764037468604, 0.05471448886341282, 0.013838293380104005, 0.032060603212032995, 0.027122956467792392, 0.036754732219768424, 0.029219536376850944, 0.06907987248684679, 0.02162756411624806, 0.10962084028869867, 0.05047181634498494, 0.015792958538181016, 0.036319479146706204, 0.031058966780879667, 0.03395105605678899, 0.026732043961861303, 0.11157029175332614, 0.15090669026332243, 0.10980504897556134, 0.23205865068095072, 0.1571593361773661, 0.08124974409916572, 0.11561586681221213, 0.12854999277208531, 0.1833731931235109, 0.14090839533933572, 0.1520049941859075, 0.08718717657029629, 0.09990954532154969, 0.11272681398051125, 0.16113878121333464, 0.114480229892901, 0.14983714265482767, 0.14357657145176614, 0.06319619355989353, 0.17935790786785738, 0.11427263888929572, 0.11112357822379895, 0.09047749465597527, 0.08810546515243393, 0.11384558251925878, 0.09203849839312689, 0.131258202450616, 0.10985641407647304, 0.22302729529993875, 0.12339965413723673, 0.1214841226381915, 0.10469291864761285, 0.1320400783526046, 0.07164598336177212, 0.10463558243853704, 0.14934903170381272, 0.11533685321254389, 0.2550787925720215, 0.21851141404892716, 0.11423563158937863, 0.1016076538445694, 0.08788244426250458, 0.256604899253164, 0.06578775628336839, 0.1265313375209059, 0.10760867861764771, 0.12697469230209077, 0.10486380090670926, 0.09940120045627866, 0.11525061141167368, 0.07845471586499896, 0.11829317600599357, 0.12428431452385016, 0.0756373434726681, 0.0964257429753031, 0.16239895644996846, 0.15028849057853222, 0.21766982706529753, 0.9687173047236034, 4.353072472981044, 13.488621303013392, 31.378985473087855, 45.04527221407209, 49.08511815752302, 51.13241876874651, 46.560577051980154, 46.66946922029768, 53.83080727713448, 36.04359258924212, 31.728010858808243, 29.800386020115443, 32.20559876305716, 22.515649693352835, 39.5514566557748, 35.940988540649414, 36.11845595496041, 24.829790660313197, 20.80138839994158, 14.799709899084908, 12.044693572180611, 9.573697022029332, 6.18272510596684, 4.753267432962145, 2.9536514282226562, 2.359014387641634, 1.8742433488368988, 1.2149956609521593, 1.1329589315823145, 0.9786390066146851, 1.093324995466641, 1.2380551035915102, 1.0175997274262565, 1.2311934317861284, 1.3906689201082503, 0.8045104731406484, 1.3649799099990299, 0.9046932916556085, 0.8660360659871782, 0.8364555761218071, 0.6601596932326044, 1.2030219605990817, 1.777926117181778, 1.672818437218666, 2.716016956738063, 4.515736750194004, 6.734911910125187, 8.41935110092163, 11.368274280003138, 15.925536939076014, 21.64582208224705, 25.85713393347604, 26.374217135565623, 23.22633228983198, 19.12935652051653, 30.000264848981583, 27.807937962668284, 34.36571380070278, 40.48448855536324, 35.44053064073835, 42.27181189400809, 37.50132465362549, 25.665382759911672, 16.765025241034373, 9.374546016965594, 2.6311627328395844, 0.4672835628901209, 0.0914657809106367, 0.12573419458099774, 0.25616396005664555, 0.13978495847965988, 0.13663604030651705, 0.17002165956156595, 0.1345362729792084, 0.12896072358957358, 0.2941241402711187, 0.16475603782704898, 0.13807803578674793, 0.145449409527438, 0.08855779695191554, 0.0751642824283668, 0.1395665651985577, 0.21229331913803304, 0.09151720029434987, 0.19490611712847436, 0.1545975407851594, 0.09570471809378692, 0.17069966532289982, 0.09389725008181163, 0.16731761608804974, 0.09902166189359767, 0.17117219710988657, 0.18223937467804976, 0.17967054966304982, 0.16134825854429177, 0.09064840405647244, 0.16630008497408458, 0.16376077623239585, 0.12442878820002079, 0.1314690097102097, 0.08201015793851443, 0.16581342608800956, 0.11115373910537787, 0.08465003914066724, 0.18382231545235428, 0.15843328567487852, 0.0731838151280369, 0.18115409862782272, 0.1670156137219497, 0.17973172638033116, 0.18530553872031824, 0.09760063993079321, 0.21254519133695535, 0.22366948798298836, 0.12712671128766878, 0.14217717440000602, 0.12469271118087427], [0.05135136397023286, 0.030853984744421074, 0.014134898848299469, 0.018210538097524216, 0.06038329271333558, 0.04808521530191813, 0.03367268028003829, 0.04280344443395734, 0.05910003371536732, 0.050131459786955795, 0.02437948671701763, 0.0326076652854681, 0.06048541223364217, 0.03437635502112763, 0.048522928064422946, 0.014786733513964074, 0.0291416948395116, 0.07191135840756552, 0.05215055947857244, 0.020464963911633407, 0.03801345878413745, 0.03423371338950736, 0.03481501094730837, 0.054398756341210434, 0.01195888199643897, 0.03256330266594887, 0.0603630995111806, 0.005387283911529396, 0.019564878727708544, 0.022593009185844233, 0.053790609152721505, 0.030237203197819845, 0.049117585976741145, 0.012335737801289983, 0.04669137545196073, 0.004961467140154647, 0.034792402160487006, 0.00944710142045681, 0.02963201781468732, 0.037330384366214275, 0.027936927076163035, 0.08412078861147165, 0.07974421738513879, 0.012032948334568312, 0.029997588734009435, 0.054524136041956286, 0.034845602698624134, 0.018545995632718717, 0.07870084765766348, 0.08995497519416468, 0.062234166610453806, 0.0373621974805636, 0.025306891417130828, 0.07884629842426095, 0.03456424815314157, 0.012519171261893851, 0.08791925478726625, 0.04617150906207306, 0.0743764964863658, 0.40554816701582497, 1.3197456172534396, 6.842087873390742, 13.661055615970067, 25.679221834455216, 33.9106102670942, 44.34171846934727, 43.05934851510184, 43.71118334361485, 30.38206488745553, 21.41094865117754, 19.08693081992013, 27.373817988804408, 27.229024478367396, 20.168520416532242, 32.2561469078064, 23.991514819008962, 30.053164958953857, 22.289954832621984, 21.079776661736624, 18.110064472470963, 10.25001209122794, 11.853351473808289, 9.29541906288692, 8.977076053619385, 5.471590876579285, 5.362790771893092, 5.125333045210157, 4.541985741683415, 3.7597432136535645, 4.213800174849374, 3.1896737005029405, 2.7661208510398865, 2.022280365228653, 2.518568694591522, 2.0589080112321034, 2.229855192559106, 2.0343569857733588, 1.8097166227442878, 2.3369477774415697, 2.998501181602478, 3.467631825378963, 4.023533310209002, 5.927395743983133, 8.01049998828343, 10.159961700439453, 12.101937174797058, 12.967160735811506, 14.380846432277135, 14.691604614257812, 14.872844900403704, 15.272790159497942, 18.790699584143503, 13.596303616251264, 16.986752680369786, 24.424321583339147, 27.50537691797529, 29.62565619604928, 35.365483147757395, 32.7412805557251, 24.82089522906712, 15.375012057168142, 9.845366375786917, 5.264166304043361, 1.124947332910129, 0.16765933989414147, 0.10745072245065655, 0.03031452904854502, 0.023387661902233958, 0.0063966823592116785, 0.023073893738910556, 0.08154777025005647, 0.06769406649151019, 0.11429984814354352, 0.03447849150480969, 0.05970999598503113, 0.042988192556159835, 0.05363363007615719, 0.015362864027598074, 0.05065073585137725, 0.047243428150458, 0.014086785626464655, 0.04290985229558178, 0.04799292775403176, 0.0319491504425449, 0.06499466419752155, 0.058726812313709936, 0.05240393463256104, 0.045934920864445825, 0.0668740433507732, 0.027800928302375332, 0.004672314955054649, 0.06441767194441386, 0.09545929197754179, 0.061519160334553034, 0.037373559549450874, 0.07818855371858392, 0.008559239196724125, 0.025468028217021908, 0.04174214441861425, 0.006853455170390329, 0.007328828746852065, 0.02484115176568074, 0.03838264290243387, 0.011603590034480606, 0.04675357675712023, 0.05094071118427174, 0.05301277731944408, 0.016873740990247046, 0.039212966204753945, 0.03766496319855962, 0.028254791894661527, 0.02392662057120885, 0.07101674391222851, 0.07126236680362906, 0.04799261223524809, 0.03441958448716572, 0.027186740455882888, 0.04241073550656438, 0.034643392477716715, 0.04548845160752535, 0.02644599904306233, 0.041770330763288906, 0.023142888875944272, 0.0556124349656914, 0.013031905400566757, 0.03828584988202367, 0.05214399465226701, 0.025876078821186508, 0.02962069645790117, 0.006449941845078553, 0.014904964848288467, 0.031849005459142585, 0.058534332284969945, 0.0659504079126886, 0.008470571633162243, 0.015015321783721447, 0.020615851440067803, 0.049556146908019266, 0.03366061932008181, 0.06785429575081382, 0.03194816317409277, 0.015336463926360011, 0.036922500003129244, 0.04028620504375015, 0.03901804005727172, 0.040899878899965963, 0.04168512372832213, 0.05932146004800286, 0.04535784040178571, 0.07385868605758462, 0.0019143909240873264, 0.03729476806308542, 0.07924220325159174, 0.011071637239573258, 0.02365045342594385, 0.0843223813655121, 0.02042742056905159, 0.03710707849157708, 0.06973925246191875, 0.05227800192577498, 0.05148410577593105, 0.08190111736101763, 0.03197207135547485, 0.05298105241464717, 0.0670228460803628, 0.03374999934541328, 0.05095660247440849, 0.06828456837683916, 0.06187211389520338, 0.031556770604635985, 0.06840153424335377, 0.022080532042309642, 0.07155147021902458, 0.06357873124735695, 0.07384900336286851, 0.3565067228462015, 2.2425973202501024, 8.913549542427063, 17.630541494914464, 31.323167119707378, 41.59440769468035, 48.9819895199367, 46.15162345341274, 48.38567427226475, 34.34472329275948, 24.762080465044292, 21.10905463354928, 26.857572044645035, 24.616672039031982, 22.32479657445635, 33.81753914696829, 31.512307507651194, 31.093178272247314, 28.68641608101981, 24.84602686337062, 21.54207158088684, 14.99845096043178, 14.797597646713257, 11.934851237705775, 10.962124279567174, 7.892682858875819, 7.256508835724421, 5.393631219863892, 4.575948970658438, 3.4414486246449605, 3.6994771446500505, 2.6985593906470706, 2.9620995691844394, 2.3363587004797797, 1.9861267166478294, 1.9446388057300021, 2.2195857550416673, 2.212260616677148, 2.3616486234324316, 2.441542919192995, 2.491296146597181, 3.3859807210309163, 4.214661751474653, 5.081072585923331, 7.24198579788208, 11.83408498764038, 13.255464945520673, 16.210769176483154, 16.530657291412354, 20.045532090323313, 20.975209747041973, 20.85834973199027, 23.243713208607264, 16.475049121039255, 17.34587206159319, 26.002877610070364, 30.22388914653233, 31.92926890509469, 38.96740845271519, 35.115660667419434, 29.39985016414097, 17.634423800877162, 12.581003308296204, 6.358605291162219, 1.7551893315144946, 0.2100123693900449, 0.019699099739747386, 0.037540692902569256, 0.04303926249433841, 0.012845102165426527, 0.011193323165311344, 0.046549425926059484, 0.04578524961003235, 0.07099233022225754, 0.04199002683162689, 0.01275349230439003, 0.03692441686455693, 0.007539510477467307, 0.0630454027226993, 0.05103279856432762, 0.02935663777004395, 0.020122244355401823, 0.08642723770546061, 0.05742547714284488, 0.05505360709503293, 0.021863402532679693, 0.01691336913167366, 0.011794120123210763, 0.02247552084736526, 0.13121386697249754, 0.08305521043283598, 0.041180554910429885, 0.06286137724029166, 0.060232284744935374, 0.049426614572959285, 0.0242562545796058, 0.019696243107318878, 0.013924162834882736, 0.02032928235296692, 0.019663354514964988, 0.042956525326839516, 0.051652616555137296, 0.0502279474666076, 0.049462068027683666, 0.021327604140554155, 0.05574329383671284, 0.02728073112666607, 0.010607604951863843, 0.0961205582799656, 0.04021919631798353, 0.05816073090370212, 0.03455403620111091, 0.030771183116095405, 0.028985397690641027, 0.02589179029954331, 0.05523372421573315, 0.011287601365308677, 0.13578886219433375, 0.12394620052405766, 0.20666499329464777, 0.12290542280035359, 0.152548541447946, 0.1249679114137377, 0.12023565891597952, 0.18952126322048052, 0.12192001353417124, 0.14594018033572606, 0.1538221923900502, 0.0932540667376348, 0.3236195961279528, 0.14241942497236387, 0.18196702429226466, 0.1086967366614512, 0.13019923998841218, 0.17956293400909218, 0.15759452139692648, 0.17585364090544836, 0.1096561241096684, 0.13284450875861303, 0.17024715031896318, 0.1341100444218942, 0.09060007879244429, 0.12480519871626582, 0.08814978705985205, 0.1303611927266632, 0.15769851367388452, 0.09209304582327604, 0.11127332411706448, 0.14190688676067761, 0.13332128817481653, 0.12435816627527986, 0.14252265729010105, 0.14204062601285322, 0.15298021185610974, 0.0993075490530048, 0.1255651307957513, 0.15758992092950003, 0.10175813255565506, 0.16367920275245393, 0.1280070969036647, 0.13416423222848348, 0.1468140927276441, 0.16862190967159613, 0.16314326865332468, 0.14766131155192852, 0.17689707848642552, 0.17567024646060808, 0.1674901404018913, 0.17427300715020724, 0.07438465247728995, 0.15796141885221004, 0.13610068974750383, 0.14914070788238729, 0.19095078722706862, 0.08718313250158514, 0.13508819336337702, 0.642925500869751, 3.175136983394623, 9.382997632026672, 20.336708511625016, 36.114165442330496, 45.41052164350237, 56.158624035971506, 53.49073811939785, 55.4834988457816, 43.341212613242014, 32.44401230130877, 31.833116258893693, 39.60433939525059, 38.01638766697475, 31.719478470938547, 42.416490759168354, 35.56509794507708, 40.369669573647634, 33.22951657431466, 29.746134485517228, 25.384147473743983, 17.15055125100272, 17.946479558944702, 14.268481033188955, 12.194193618638174, 7.983593957764762, 7.510183657918658, 6.779473747525897, 6.675513497420719, 5.063244376863752, 5.692652591637202, 3.77316061939512, 3.735733279160091, 3.138542341334479, 3.492414964096887, 3.3615198050226485, 3.219633464302335, 2.8805715782301764, 2.5903965660503934, 3.772450166089194, 4.187712728977203, 4.374584964343479, 5.605767105306898, 7.924596803528922, 10.94224374634879, 14.013025300843374, 16.069769382476807, 18.590118987219675, 21.62933748109, 22.418975932257517, 24.146014962877544, 24.433548791067942, 28.34792763846261, 23.276223829814366, 26.24713979448591, 33.93721144539969, 37.435198647635325, 39.24407877240862, 45.90126943588257, 42.06717702320644, 34.54390035356794, 22.27284836769104, 13.355992351259504, 6.871886960097721, 1.6139586184706007, 0.2787152071084295, 0.20556945779493876, 0.10926661108221326, 0.10774686227419547, 0.11707426926919393, 0.12380454955356461, 0.19067816542727606, 0.1995137905968087, 0.23191892674991063, 0.11293499530958277, 0.22594057183180535, 0.09400511000837598, 0.16715444198676518, 0.12280813444937978, 0.1719890989895378, 0.1558427203978811, 0.14133446104824543, 0.19358803571334907, 0.10388102435639926, 0.12793403225285666, 0.11074380895921163, 0.13802015674965723, 0.0920238352513739, 0.1554950661957264, 0.1897148492613009, 0.1962075201528413, 0.1415323761424848, 0.18409208740506852, 0.15164238507194178, 0.1646786169814212, 0.11683925188013486, 0.1956237629055977, 0.20886032549398287, 0.15493201783725194, 0.1216038026447807, 0.11794126060392175, 0.09713355678000621, 0.1593869123607874, 0.09026048558631114, 0.08789226944957461, 0.23315806740096637, 0.14762724909399236, 0.07747717081968274, 0.1352680865675211, 0.14308467427534716, 0.1680365375110081, 0.11560984142124653, 0.16054225393704005, 0.11935782459165369, 0.21844996591763838, 0.15119540691375732, 0.1549970486334392], [0.04049098351970315, 0.027717460013393844, 0.01476801951814975, 0.016763655468821526, 0.042390654262687476, 0.03380928294999259, 0.026815067810405577, 0.046836134112839184, 0.008452376716637185, 0.0554105131221669, 0.02968600206077099, 0.034559298240180523, 0.048195785975881984, 0.026206813752651215, 0.019241275199289833, 0.052455041890165637, 0.07221498925771032, 0.03107796236872673, 0.0386311834944146, 0.02692793362907001, 0.04557305135365043, 0.0408911766883518, 0.024510710300611596, 0.028453351597168615, 0.018337912691224898, 0.03549383434333971, 0.050702399507697136, 0.016807096977052943, 0.02350091278952147, 0.052636329483773024, 0.015313693987471717, 0.04930470557883382, 0.012900060109261955, 0.025627210836059282, 0.026308258130614246, 0.047955825459212065, 0.0782540798453348, 0.07064482529780694, 0.012944948593420642, 0.034107441415211985, 0.023875394569975988, 0.028255439895604337, 0.03699874698317476, 0.014523165067657828, 0.009313117047505719, 0.09658652184797184, 0.010406305664218962, 0.0413239768573216, 0.040874403302690814, 0.06635919133467333, 0.0754063565816198, 0.02158911492941635, 0.006712674845143088, 0.09761840397758142, 0.03179786766746214, 0.01589208741539291, 0.019572961776118194, 0.06562591889607054, 0.027120159207178012, 0.017462614391531264, 0.09162972175649234, 0.6299139133521489, 3.5683064460754395, 11.86707764012473, 21.534836769104004, 31.345588956560405, 40.6765958241054, 45.330193519592285, 39.96175473076956, 37.01110145023891, 34.394573143550325, 31.85111209324428, 28.587923628943308, 15.590958595275879, 20.474373170307704, 15.598394904817853, 20.359536818095616, 19.428889887673513, 23.497616018567765, 23.800343820026942, 11.323699848992483, 14.381874765668597, 13.334459015301295, 13.0323600258146, 10.697464789663043, 10.517913784299578, 12.60027847971235, 11.159680673054286, 11.493086508342198, 8.86814306463514, 10.006172009876796, 7.865329538072858, 6.810434486184802, 5.697706971849714, 8.034364444868904, 9.570134333201818, 8.432900088174001, 7.763694763183594, 8.19639469896044, 9.215823105403356, 10.287114603178841, 10.182124716894966, 8.850248847688947, 13.774269563811165, 23.696320601872035, 19.07621843474252, 19.90276745387486, 22.24849840572902, 17.094477551324026, 17.91483572551182, 15.33878936086382, 17.540550163814, 19.7857962676457, 29.22231674194336, 30.973433017730713, 33.47590664454869, 32.54633494785854, 26.585881846291677, 20.29249017579215, 13.995310868535723, 8.131886754717145, 3.058077859027045, 0.622110977768898, 0.05988639473382916, 0.05011837763179626, 0.0218054403750492, 0.04696423813168492, 0.035675562984709225, 0.03165318025276065, 0.015172268629872372, 0.06698088547480957, 0.017423205077648163, 0.05905687888818128, 0.033110680258167643, 0.03506471522684608, 0.01452657809880163, 0.057160441364560804, 0.009246434018548046, 0.01218290881453348, 0.06091721834880965, 0.04329091077670455, 0.05137496341818145, 0.0007743895933214974, 0.09588664011763674, 0.011693238929313208, 0.05473365069233945, 0.01317679976844894, 0.022600800464195863, 0.03026680089533329, 0.050498896677579196, 0.04880985677508371, 0.04653768387756177, 0.016067995922639966, 0.0398778762402279, 0.038479215398963006, 0.06245583721569606, 0.02485607614341591, 0.0459415569369282, 0.08493311716509716, 0.03715178716395583, 0.059620850054281097, 0.04419454978778958, 0.039664582149790864, 0.021186974365264177, 0.06736280569540602, 0.033905173518827984, 0.02022959877337728, 0.03224385177184429, 0.04364206621955548, 0.009228274725111467, 0.028105068053784113, 0.01638539764098823, 0.06499971249806029, 0.013993033291106778, 0.021201079411964332, 0.02237883978523314, 0.02238058701290616, 0.03330010348664863, 0.05105761598263468, 0.04863248772120901, 0.035730361472815275, 0.04625391374741282, 0.05440648824774793, 0.009050140623003244, 0.022085229200976234, 0.0429233483571027, 0.04418597310515387, 0.046543923007058244, 0.06418789963104896, 0.03141239870871816, 0.05253722944429942, 0.012563828195977424, 0.037653760585401735, 0.03557347060580339, 0.06354536089513983, 0.012691304569930902, 0.028821646834590604, 0.03651558594512088, 0.022112747188657522, 0.029322768694588115, 0.01881494146904775, 0.04240969056263566, 0.05534484111038702, 0.028446981849681054, 0.06999690577919994, 0.027004280693030784, 0.03306833288765379, 0.012571126688271761, 0.017291509912216237, 0.00707245192357472, 0.0356392308271357, 0.05512997621138181, 0.04012829637421029, 0.021511346334591508, 0.014339841868994492, 0.06378380488604307, 0.09648457196141992, 0.01599474297836423, 0.011642300457294499, 0.01895738293283752, 0.03758612760741796, 0.04206638576995049, 0.012686035745511097, 0.01661065430380404, 0.02917668010507311, 0.02030393567734531, 0.054079831311745305, 0.03271196290318455, 0.012600291819710816, 0.07412695166255746, 0.01696882749508534, 0.028392987425572107, 0.026599166449159384, 0.0759960985077279, 0.03536639868148735, 0.09122277716440813, 0.13998621196619102, 1.2081678616149085, 5.705264440604618, 15.774523053850446, 25.97262167930603, 37.128119536808555, 47.44820594787598, 49.72883401598249, 42.987049034663606, 40.906202520642964, 38.042526790073936, 37.78302199499947, 31.96633059637887, 19.408026184354508, 27.42213749885559, 20.037534713745117, 25.293376207351685, 24.61594421522958, 26.761025088174, 27.365395035062516, 17.764353377478464, 25.427670989717754, 20.584342309406825, 17.611699717385427, 14.702025175094604, 14.400035619735718, 15.801386526652745, 12.540625589234487, 14.017996736935206, 12.464091181755066, 11.573349492890493, 8.921322839600698, 8.220560533659798, 8.437001262392316, 9.556290916034154, 10.129265427589417, 8.890326925686427, 8.826472980635506, 10.294516171727862, 11.290650742394583, 12.20288234097617, 13.167449508394514, 10.949853760855538, 18.220023189272197, 24.951029777526855, 24.53227574484689, 21.55283781460353, 28.4448550088065, 21.138019936425344, 18.976751497813634, 16.53746131488255, 20.11860282080514, 20.831830195018224, 30.234054361070903, 34.262824875967844, 36.60883896691458, 37.18738419669015, 32.87166002818516, 24.97593038422721, 17.88680148124695, 10.500988841056824, 4.4663103052548, 1.081667763846261, 0.058055659756064415, 0.08837509461279426, 0.025403136520513465, 0.030578105976538997, 0.046364240148769956, 0.03230236523917743, 0.00742227489328278, 0.035776155801223855, 0.0025544097505709423, 0.06878673178809029, 0.04219523278464164, 0.020128252782991955, 0.03910886196951781, 0.0803128636575171, 0.03974070020818284, 0.04890515701845288, 0.026820852321439555, 0.039638377127370665, 0.03881251519279821, 0.07196941386376109, 0.06529207288154534, 0.04051175008394888, 0.026669930866254226, 0.050834886862763336, 0.09875433266695056, 0.009889072838372417, 0.06561464164406061, 0.01988651111189808, 0.0632881825523717, 0.048448343495173116, 0.06924920768610068, 0.02900422703740852, 0.03179470569427524, 0.057564868591725826, 0.09203283262572118, 0.048863142130098174, 0.09329965072018759, 0.1040252334039126, 0.06586969617222037, 0.03652188953544412, 0.06858881669385092, 0.04474570682006223, 0.02257010353995221, 0.05740482932222741, 0.008816040952556899, 0.01850831488679562, 0.010998969531751104, 0.023234835459983776, 0.06068380908774478, 0.02070606267079711, 0.03358122054487467, 0.025620266030143415, 0.005192133847491017, 0.11467513229165759, 0.11759736548577036, 0.07317808150712933, 0.06985668651759624, 0.14049034991434642, 0.14970193776701177, 0.2071543120379959, 0.10491728982222931, 0.13156338036060333, 0.16272461254681858, 0.08887505957058497, 0.1665679977408477, 0.1559161650282996, 0.11107720714062452, 0.1413194247122322, 0.22284494579902717, 0.15946835013372557, 0.10876384377479553, 0.1577894916491849, 0.11560701871556894, 0.13236838073602744, 0.09993806414838348, 0.10894683109862463, 0.122200574193682, 0.15774702892771789, 0.09582489343093974, 0.13390633463859558, 0.0703603969886899, 0.13263338937291078, 0.1763694089438234, 0.08849483568753515, 0.13034238373594625, 0.054469469868178876, 0.11459952991987978, 0.15525816247931548, 0.13975496723183564, 0.14319412197385514, 0.1612911666078227, 0.1236655991524458, 0.19673867736543926, 0.1645651659263032, 0.12192717886396817, 0.13966495277626173, 0.11205389044646706, 0.10679029753165585, 0.1356481747435672, 0.20919614604541234, 0.10284324575747762, 0.12561150187892572, 0.11974100688738482, 0.1803028764469283, 0.09655626597149031, 0.089157995102661, 0.1772611668067319, 0.10150761742677007, 0.11127457262149879, 0.125932068963136, 0.1364483575203589, 0.08522095172000782, 0.16234936911080564, 0.25329891379390446, 1.151212283543178, 5.551539020878928, 17.03058191708156, 30.879955427987234, 40.78225360597883, 52.28656319209507, 56.692846706935335, 52.19680636269705, 49.97782618658883, 46.3775441305978, 45.97050476074219, 39.090662547520225, 25.689439160483225, 33.07242127827236, 25.6426100390298, 31.235720566340856, 30.897023677825928, 35.79904726573399, 34.82575055531093, 20.117489371980938, 26.087037665503367, 21.953462260110037, 21.15886800629752, 17.71458169392177, 15.965954610279628, 17.332620109830582, 16.497220822743007, 15.65867747579302, 13.36786334855216, 14.20036436830248, 11.474936945097786, 10.694469247545515, 9.10523818220411, 11.212627683367048, 13.649667518479482, 11.538301042148046, 9.902846217155457, 11.032900367464338, 13.177052787372045, 14.329836232321602, 14.65134675162179, 13.5092522416796, 20.521085909434728, 31.368771621159144, 28.444083758762904, 28.112192630767822, 32.320699146815706, 26.327184779303415, 26.1802008492606, 24.1091182913099, 28.155625820159912, 28.385599034173147, 38.128159863608225, 41.418013777051655, 44.27514430454799, 43.296518325805664, 36.750238282339915, 26.77412244251796, 18.855588810784475, 10.783438324928284, 4.615698746272495, 0.9961902648210526, 0.13666073898119585, 0.25604345223733355, 0.08494769209729773, 0.13115687003093107, 0.13974994607269764, 0.1249379473073142, 0.2678541684789317, 0.09576405598116772, 0.088159754739276, 0.24158528234277452, 0.23397543068443025, 0.1555116224501814, 0.07611179551375763, 0.17898919193872384, 0.10423844267747231, 0.11130816689027206, 0.1257426491273301, 0.11896701556231294, 0.14441100667629922, 0.14630304729299887, 0.20241091799523148, 0.11042639027748789, 0.13377700586404118, 0.11247205122240952, 0.17134685202368669, 0.11629392685634748, 0.15382828563451767, 0.10778070760092565, 0.10932364195053067, 0.08242803372974906, 0.07314465008676052, 0.11660745074706418, 0.12572010819401058, 0.15548959720347608, 0.18776062769549234, 0.18307143503001758, 0.1369279867836407, 0.2766419026468481, 0.17211974412202835, 0.17274447131369794, 0.11536179615982942, 0.1661746645612376, 0.0901939891544836, 0.09717278967478446, 0.11900798550673894, 0.07079433370381594, 0.23765048491103308, 0.058358571359089444, 0.13897348488015787, 0.18892404383846692, 0.15286289315138543, 0.06222451105713844, 0.09015569263803107], [0.021953873303053633, 0.03097854002511927, 0.02277859190611967, 0.04598713752680591, 0.03585817711427808, 0.041973772525255165, 0.03998373109581215, 0.07370369508862495, 0.09831565299204417, 0.050834530631878545, 0.0830853780997651, 0.027186073795227066, 0.03408699715510011, 0.021217369341424534, 0.04576909029856324, 0.0763804546690413, 0.008595218516087957, 0.020053464653236524, 0.007536007540433535, 0.01596598157526127, 0.005202299998407918, 0.058843472839466164, 0.051662886182644537, 0.03032999625429511, 0.019114263621824126, 0.01819283511888768, 0.03768523443224175, 0.046635426846998076, 0.0343720531091094, 0.0374423765710422, 0.01044304748731, 0.03118061793169805, 0.022180186784160987, 0.008010359497607818, 0.06324102436857564, 0.056123948589499505, 0.01691337252434875, 0.03527896944433451, 0.046087065379002264, 0.033376252079116445, 0.03058016872299569, 0.02047512327720012, 0.022544222518003414, 0.026934009910162007, 0.053850964842630286, 0.030227435686226403, 0.016423234449965612, 0.061472789251378605, 0.012377304856532385, 0.025536146347544024, 0.03241046265299831, 0.022433181958539144, 0.05323275837248989, 0.05315509664693049, 0.029492470302752087, 0.006622143430701856, 0.04126997904053756, 0.014908420287870934, 0.046982300733881335, 0.01928619421752436, 0.030726511763142686, 0.03296226090086358, 0.20669342391192913, 1.415465520960944, 7.479563815253122, 17.325638907296316, 27.160958187920706, 31.363536153520855, 37.394325869424, 38.174535615103586, 37.48585796356201, 40.49561609540667, 34.72402892793928, 27.122208084378922, 25.05576171193804, 15.329426663262502, 21.183617489678518, 18.79960891178676, 27.306284972599574, 19.437665462493896, 22.246189866747173, 23.025070769446238, 18.985016380037578, 21.54699090548924, 14.98705244064331, 19.330472128731863, 15.847234215055193, 20.34749558993748, 18.435525042670115, 14.775080272129603, 15.196042094911848, 16.494875805718557, 17.17687623841422, 13.697914940970284, 9.98330635683877, 17.031106506075176, 30.58934007372175, 15.618061780929565, 14.372305359159197, 14.819065843309675, 15.75651158605303, 14.975138017109462, 15.824075869151525, 21.20531497682844, 33.67764411653791, 23.378146954945155, 26.094222102846416, 15.884330647332327, 15.74886335645403, 25.058895349502563, 23.79487385068621, 23.19800274712699, 29.37859215055193, 31.282673018319265, 33.60842963627407, 28.82930404799325, 21.709398099354335, 15.137644222804479, 9.028024588312421, 2.9210389724799564, 1.7234938208545958, 0.2622316101832049, 0.04444154331992779, 0.01549800275824964, 0.03695125970989466, 0.015535868404965316, 0.021762935245143514, 0.0571419173585517, 0.058151998158012114, 0.004280949951083, 0.05085143293919308, 0.037623884688530645, 0.014437790095273937, 0.04672948197860803, 0.03491419919633439, 0.021736937175904, 0.04918496450409293, 0.04731493217072316, 0.06142265908420086, 0.0362698816295181, 0.04783627098160131, 0.03384890939508166, 0.0423420474066266, 0.04241496956508074, 0.08121622446924448, 0.030008004246545688, 0.015511525961171304, 0.043686696860407076, 0.04925775095554335, 0.02436085923441819, 0.026854919868388345, 0.06032195993299995, 0.014590094065559762, 0.053499497273670774, 0.03722167627087661, 0.11614239641598292, 0.0426579733113093, 0.02531881836642112, 0.026710821082815528, 0.05349081202543207, 0.05577455733769706, 0.021296734189880744, 0.04052150063216686, 0.04875161811443312, 0.012092521164699324, 0.03755946796653526, 0.053768424450286796, 0.027336703480354378, 0.02501547080464661, 0.02187545331461089, 0.030871368811598847, 0.023333589446597865, 0.014930392948112317, 0.014041291549801826, 0.030049781647643874, 0.0486059366459293, 0.01841910619155637, 0.08600901586136647, 0.03329804413286703, 0.04560131912252732, 0.028113831333549957, 0.03713817575148173, 0.007926043888021792, 0.06747432292572089, 0.03349227138928004, 0.046525314184171815, 0.018201762943395546, 0.02112043891767306, 0.026889866118186286, 0.03369825426489115, 0.022510755474546125, 0.06984118877777032, 0.06354715901293925, 0.04530137950288398, 0.024625642258407812, 0.05893529898353985, 0.050164161782179556, 0.03821617790630885, 0.03568055700244648, 0.04612297684486423, 0.01818718122584479, 0.008395194874278136, 0.038146767166576216, 0.01169042385715459, 0.05388148874044418, 0.03716697617034827, 0.06883144046046905, 0.033071413436638455, 0.015467768934156214, 0.07594414986670017, 0.011432948655315807, 0.037424965362463675, 0.04388798088101404, 0.028268866407285844, 0.059897997682648044, 0.009775296934614224, 0.042158958302544694, 0.01720448779607458, 0.0156125106316592, 0.01963011478073895, 0.03293021708460791, 0.049690184715603075, 0.015141040751976627, 0.05302377637209637, 0.02678427249858422, 0.004537191067356616, 0.025978228875568936, 0.07993053631590945, 0.007666802798796977, 0.012884217164745288, 0.020895175469507064, 0.01871012816471713, 0.07675668198083128, 0.054761887927140505, 0.028324606362730265, 0.018990982290623442, 0.052415568115455766, 0.05759125003325088, 0.2602844860936914, 2.2938103207520077, 10.298139657293047, 22.826089995247976, 33.323421478271484, 39.12047379357474, 44.40402296611241, 42.906588894980295, 44.045211042676655, 43.888977323259624, 38.21200030190604, 28.006314243589127, 26.405379806246074, 18.093185561043875, 21.055511815207346, 20.6049610887255, 29.14694615772792, 26.32670882769993, 22.16778986794608, 28.649819919041224, 26.709540673664637, 28.365279027393886, 22.126159736088344, 22.00820016860962, 22.02121935571943, 25.6914940902165, 25.646563564028057, 18.34728639466422, 21.384806053979055, 21.740034443991526, 22.896402290889196, 16.196563584463938, 15.475750514439174, 21.67674330302647, 32.07239137377058, 16.330521379198345, 20.14594919340951, 20.527002300534928, 22.293020725250244, 15.816266093935285, 18.25699281692505, 27.423356907708303, 39.3632264818464, 26.79070952960423, 26.91545922415597, 19.197153568267822, 18.396012374332972, 25.510589054652623, 24.458234003611974, 24.140605790274485, 28.958540541785105, 35.78073181424822, 36.604013442993164, 33.485449995313374, 26.999384777886526, 19.232137748173304, 12.39529185635703, 5.39159974030086, 2.578160571200507, 0.33729145250150133, 0.08251286417778049, 0.00624330757584955, 0.05451568149562393, 0.044578637927770615, 0.028949733890060867, 0.016501123484756266, 0.02005469280162028, 0.024332163988479545, 0.005951312329021415, 0.026897994967709695, 0.03747251031122037, 0.0295261493884027, 0.031841107311525514, 0.07486650733543293, 0.04289323836565018, 0.05208319112924593, 0.060394631033497195, 0.021731368099738444, 0.03953122966257589, 0.024242395501849905, 0.05613915795194251, 0.024205140536651015, 0.04342500286708985, 0.03445102779992989, 0.05138791325901236, 0.07430742840681757, 0.04387825408152171, 0.03034083585121802, 0.03356599761173129, 0.01086825060857726, 0.004207119403872639, 0.03652851203722613, 0.04865373604531799, 0.038396264492933235, 0.048378182974244864, 0.029971244611910412, 0.044809302514685054, 0.04737816484911101, 0.04622988682240248, 0.041001526838434596, 0.013754256818044399, 0.033521370363554785, 0.043389342459184785, 0.03598331254241722, 0.066861992568842, 0.0357369229064456, 0.029738771729171276, 0.021805318238745843, 0.024217113287055066, 0.05359542855460729, 0.017554454106305326, 0.02036547032184899, 0.06026332772203854, 0.05822497459926775, 0.08369333869112389, 0.13542207330465317, 0.07604824392391102, 0.15028052457741328, 0.10583057760127954, 0.11709932078208242, 0.09413646081728594, 0.16863440828663961, 0.17416573076375894, 0.15916036308876105, 0.12688348362488405, 0.1044468954205513, 0.16202724139605248, 0.09890892330024924, 0.06844947274242129, 0.17346447839268617, 0.086946948032294, 0.187245904601046, 0.0996030985510775, 0.13035205964531216, 0.10004918104303734, 0.17219896987080574, 0.15334960632026196, 0.1148240707282509, 0.10465285794011184, 0.13855641654559545, 0.08471648128969328, 0.13544621558061667, 0.11344914164926324, 0.18070859967597894, 0.1560804790684155, 0.09940041335565702, 0.0658697843817728, 0.09628141857683659, 0.12142806207495076, 0.09094583309654679, 0.16495514714292117, 0.12707987880068167, 0.1895960106381348, 0.117688207754067, 0.15986890292593411, 0.11104144155979156, 0.09435447411877768, 0.046833894947277646, 0.1834682287382228, 0.18225308108542645, 0.08044941883002009, 0.14389878059072153, 0.10401080096406595, 0.08193705257560525, 0.1198042734925236, 0.17893877678683826, 0.1300715668393033, 0.050960582082292864, 0.16409925664109842, 0.0830609779804945, 0.24743867825184548, 0.14068597156022275, 0.12146781065634318, 0.08539260072367531, 0.12238357508821146, 0.1794365636472191, 0.4268527552485466, 2.3674888014793396, 10.957677432468959, 24.276943343026296, 36.83359234673636, 45.5589143208095, 51.75024216515677, 49.690702302115305, 52.76537050519671, 52.095553738730295, 46.823371819087434, 37.77905109950474, 38.18998146057129, 25.360942227499827, 31.065361159188406, 28.65312726157052, 39.64947141919817, 32.388468401772634, 33.77176788875035, 35.59192493983677, 28.697604417800903, 34.77731466293335, 26.18280816078186, 30.388981819152832, 25.76673092160906, 31.144678320203507, 26.378547600337438, 23.17310561452593, 22.872300727026804, 24.620875699179514, 25.533568484442576, 21.386913095201763, 16.00059311730521, 24.455227170671733, 37.57158831187657, 21.55102607182094, 21.94709771020072, 21.86330590929304, 23.915854147502355, 21.663927350725444, 24.484473875590734, 31.480463913508824, 45.65386492865426, 34.64844989776611, 35.230827059064595, 24.37856422151838, 24.809187514441355, 36.362535749162944, 32.7039999961853, 32.29302099772862, 40.36271095275879, 42.357441493443076, 43.71777023587908, 38.76682785579136, 30.29497616631644, 21.2411607333592, 12.759407860892159, 5.6700765916279385, 2.2759289145469666, 0.3472886346280575, 0.1615515612065792, 0.1085543596584882, 0.095754278291549, 0.10831360186317138, 0.10366418492048979, 0.1529278289526701, 0.10572583893580095, 0.1430310428674732, 0.1672856163765703, 0.09945933055132627, 0.13282139785587788, 0.1735055297613144, 0.151228397286364, 0.11696544582290308, 0.1387857206697975, 0.1696434984249728, 0.1584767797695739, 0.11883167496749333, 0.12773077030267033, 0.20885324158838817, 0.12711238062807492, 0.16655543127230235, 0.195356121552842, 0.16197757263268742, 0.11877322596098695, 0.138072688930801, 0.19525936245918274, 0.11925394088029861, 0.10247512693916049, 0.13277366970266613, 0.11422928050160408, 0.09523167062018599, 0.1371612806937524, 0.1711488419345447, 0.12304982862302236, 0.12450899103922503, 0.17760165567908967, 0.1302560605108738, 0.11292982487274067, 0.10261267955814089, 0.15884100379688398, 0.19148874336055347, 0.16148933954536915, 0.05317385135484593, 0.17214574558394297, 0.11549260414072446, 0.09381133397775036, 0.10650348077927317, 0.17436177310134682, 0.14895362220704556, 0.11933651859206812, 0.09444370825908013, 0.10727347553308521, 0.21608243510127068], [0.08488786566470351, 0.07040581812283822, 0.044613399276775975, 0.03451900004542299, 0.05181124447179692, 0.029376081191003323, 0.09809732756444386, 0.08664128157709326, 0.08395226086888995, 0.005747396864795259, 0.02275620025050427, 0.08192333259752818, 0.04298682191542216, 0.03164852889520781, 0.07847484121365206, 0.05841037072241306, 0.029682985972613096, 0.03652667999267578, 0.04629643414435642, 0.05007704467113529, 0.02273721314434494, 0.031648383010178804, 0.06359754023807389, 0.02871868932353599, 0.036926581391266415, 0.03671240859798022, 0.055015188442277055, 0.010711020474056048, 0.0918723251670599, 0.09171806023057018, 0.026102083568860377, 0.05224001414275595, 0.0026555367013705628, 0.03646480777700033, 0.018308530428579876, 0.011568367281662566, 0.046288325650883574, 0.027974765581477965, 0.07079794351011515, 0.007937131150226508, 0.07291970894272838, 0.0296595391950437, 0.033635242110384364, 0.02991516369261912, 0.04039285039263112, 0.05842263185020004, 0.03478539967909455, 0.055918332122798474, 0.030044282121317725, 0.0091507071462859, 0.016617524470867853, 0.05072047907326903, 0.03083630551451019, 0.06326044404080935, 0.02946045362789716, 0.04082901270261832, 0.021683665391589915, 0.020483002765104175, 0.02409000162567411, 0.03437409210684044, 0.04790180728637746, 0.07727025835109608, 0.042798514877046855, 0.08253973416451897, 0.9772982214178357, 4.419568470546177, 10.709958519254412, 18.387056146349224, 27.58912876674107, 33.08418457848685, 37.25357273646763, 43.83269691467285, 43.82487671715872, 41.12500129427229, 34.26939787183489, 27.613013199397496, 33.47972467967442, 29.65821198054722, 23.182431834084646, 18.288386515208654, 30.479572432381765, 21.18290182522365, 19.743728399276733, 15.362065826143537, 14.109787651470729, 24.880147729601177, 22.093353816441127, 15.766763653073992, 19.20045222554888, 27.377938270568848, 16.817548411233084, 18.320728642599924, 17.154989412852697, 20.286815234592982, 16.69606610706874, 18.558534213474818, 47.98077147347586, 32.606106826237266, 13.351458651678902, 18.42748076575143, 14.537711569241115, 30.805533272879465, 28.600967134748185, 28.280003786087036, 32.006341797964915, 38.573956285204204, 28.023304326193674, 23.13163529123579, 25.3049692767007, 23.358914341245377, 29.22283090863909, 30.219720227377756, 34.86752659933907, 32.63189506530762, 27.72664056505476, 17.263586282730103, 10.816840921129499, 5.094227262905665, 2.117131526981081, 0.7222407619868005, 0.030808397369193177, 0.028389265660994818, 0.014733782337446297, 0.04301901840205703, 0.030533461764987026, 0.041688299272209406, 0.038421594205179384, 0.026198260818741152, 0.007431448686734906, 0.0415890499550317, 0.08129876825426306, 0.044182824702667337, 0.10131211791719709, 0.010211665349613343, 0.009581865260510572, 0.01951909457732524, 0.03240972983517817, 0.049603627395949194, 0.014197590395009943, 0.02249698799901775, 0.08108152848269258, 0.05123394009258066, 0.021423550688528588, 0.0346445052751473, 0.10599339207900421, 0.029036250497613634, 0.04138951316209776, 0.008084508956276944, 0.019599037876884853, 0.08634102304599114, 0.014828585553914309, 0.04115611747173326, 0.010340008552053144, 0.027669148320066075, 0.028034050882394825, 0.0112244967604056, 0.10091168047594172, 0.013934703028228666, 0.05835652218333312, 0.045865008008799384, 0.04870044639600175, 0.0485514672473073, 0.02339121572939413, 0.026645196568486944, 0.06186022596167667, 0.014255175965705087, 0.04466973464669926, 0.04543025705165096, 0.06472734175622463, 0.048615643089371066, 0.006348122576517718, 0.026989444524848034, 0.014906131928520543, 0.07091701962053776, 0.025860815175942013, 0.038672105941389284, 0.04073526969711695, 0.03812325932085514, 0.09084892472518341, 0.03481066493051393, 0.12667514623275825, 0.08794151752122811, 0.02268205164000392, 0.005284650825030569, 0.02436451823450625, 0.013788618679557527, 0.03267070797405072, 0.04530845662312848, 0.03290578982393656, 0.019663536023082476, 0.03936894444216575, 0.03694149559097631, 0.005796429077495954, 0.03878583858854004, 0.05379751663921135, 0.04005260579288006, 0.04709528020716139, 0.01705511679340686, 0.0341912201339645, 0.006876325193193874, 0.034965727145650556, 0.05603064323908516, 0.023867599898949265, 0.021605985006317496, 0.04165070503950119, 0.04057582414575985, 0.038620625489524434, 0.04430977860465646, 0.01387252377545727, 0.02066856512932905, 0.009322743763082793, 0.028815221107964004, 0.03641801600211433, 0.03279163309239915, 0.030323197333408252, 0.04090238269418478, 0.043070994184485505, 0.022069466832493032, 0.05563449753182275, 0.012565140313069736, 0.06315360191677298, 0.05389725110892739, 0.07605108020028897, 0.012951000277618212, 0.05141210303242717, 0.034063451989953, 0.03918003011494875, 0.04854777940948095, 0.008050374403995062, 0.021449854098526493, 0.05113586124831012, 0.026532661535644105, 0.0356620228184121, 0.024313137866556644, 0.035258928912558725, 0.019800946149708967, 0.010546164454094, 0.019923026473926644, 0.06257452656115804, 0.09352341121328728, 1.4703096066202437, 6.066096118518284, 15.1242915221623, 23.88513442448207, 32.81376068932669, 38.7593446459089, 43.67957946232387, 49.80654614312308, 48.64542572838919, 43.86983503614153, 38.28103065490723, 30.233224051339285, 35.286402225494385, 27.11703167642866, 29.204835074288503, 19.117808614458355, 32.128366061619346, 24.57118044580732, 18.73817467689514, 22.6075622013637, 19.500312158039637, 27.76326973097665, 25.127731152943202, 26.156090600149973, 25.335070610046387, 30.63516344342913, 20.799602712903702, 24.155610425131663, 25.058985676084244, 25.272566352571758, 21.167409079415457, 32.576660360608784, 53.90214443206787, 36.00686093739101, 19.68746188708714, 24.951516151428223, 21.210953439985, 29.026558194841655, 29.428855419158936, 32.05332204273769, 41.42888075964791, 39.008256912231445, 30.573925495147705, 22.37572339602879, 24.043245894568308, 26.92238484110151, 29.973809582846506, 32.785047258649556, 39.547763688223704, 36.562577860695974, 32.74091230119978, 20.90606995991298, 13.646336725779943, 7.1905990924154, 3.1018456476075307, 0.8580159449151584, 0.17942102519529207, 0.07343479166073458, 0.03016068141109177, 0.07714907199676548, 0.026735423066254174, 0.08704821259847709, 0.04988348916439073, 0.013630296103656292, 0.02751974847966007, 0.04570420538740499, 0.013062238460406661, 0.019718012207054665, 0.03106842895171472, 0.06051294718469892, 0.04658127975250993, 0.058631851337850094, 0.032943920099309514, 0.06808498408645391, 0.03513436684651034, 0.050827531543161185, 0.03220567739169512, 0.04895274946466088, 0.03632970806211233, 0.04252575397757547, 0.011972680006043186, 0.07187268191150256, 0.017784343466960957, 0.028793121222406626, 0.06046983985496419, 0.012815305996420128, 0.04013836583388703, 0.028420398543987955, 0.06368374811219317, 0.06071802082338503, 0.04115402419120073, 0.01865178093846355, 0.0971696005601968, 0.09152038262358733, 0.072501405674432, 0.032085546159318516, 0.03899635747075081, 0.04877708353368299, 0.058526379854551384, 0.03048073620136295, 0.04320887928562505, 0.0185222316400281, 0.1059416944959334, 0.04224803977246795, 0.054979999616209946, 0.05654385659311499, 0.01847635249474219, 0.003132655385083386, 0.033809761317180734, 0.04994253867438861, 0.038306412885763814, 0.06467672982918364, 0.16045625640877656, 0.1326746985848461, 0.16591729622866425, 0.12396237679890224, 0.18172667361795902, 0.1816339043102094, 0.13783388531633786, 0.2069783407662596, 0.13958529276507242, 0.16341165639460087, 0.0917038449219295, 0.14101060985454492, 0.07916970857019935, 0.13074419860328945, 0.12176549753972463, 0.16652088026915277, 0.18741359774555477, 0.11114204794700656, 0.13120681020830358, 0.12550425263387815, 0.07501863488661391, 0.1705704044018473, 0.27966252341866493, 0.11100320611149073, 0.09800280763634614, 0.08903697159673486, 0.11461365701896803, 0.07005724111305815, 0.1852701734751463, 0.20235476243708814, 0.10696375143847295, 0.19754078718168394, 0.056943717279604504, 0.15082228050700255, 0.09083952701517514, 0.11694605329207011, 0.2175571359694004, 0.11558187220777784, 0.12575041156794342, 0.10253357594566685, 0.21137716115585395, 0.11029230497245278, 0.17756844817527703, 0.14266493251281126, 0.1374252579574074, 0.11986051047486918, 0.2169798519462347, 0.19890715314873628, 0.06606567744165659, 0.15014974373791898, 0.11324854634170022, 0.16289599692182882, 0.10243959206023387, 0.1476313610162054, 0.16058554447122983, 0.08678448639277901, 0.11133815813809633, 0.0538200813212565, 0.12103574669786862, 0.16956078500619956, 0.14178431619490894, 0.14145643450319767, 0.15830250483538422, 0.1426365833197321, 1.6684062225478036, 6.792625818933759, 15.53594102178301, 26.358408246721538, 37.93738317489624, 45.13145419529506, 50.69970580509731, 57.477451188223704, 57.54337222235543, 53.505999837602886, 47.85789605549404, 38.03823627744402, 46.93544626235962, 40.64883082253592, 36.04535048348563, 28.131637164524623, 45.37907409667969, 31.261515753609793, 30.086422511509486, 25.915182658604213, 24.795426607131958, 37.98179953438895, 31.72584649494716, 29.419023718152726, 30.513253825051443, 40.59731340408325, 27.650701965604508, 29.124652862548828, 30.98159715107509, 33.590023858206614, 26.008116551807948, 29.88129779270717, 60.054225376674104, 43.19047491891043, 20.149795021329606, 27.991613592420304, 26.10449501446315, 39.68138796942574, 36.52915007727486, 39.11071157455444, 46.33278036117554, 50.47407347815377, 37.8614046233041, 31.87358604158674, 34.92855262756348, 32.81360782895769, 38.28199992861067, 41.59141649518694, 45.57925517218453, 44.10122741971697, 36.37466035570417, 24.316832951137, 14.371761662619454, 7.356919424874442, 2.9631936933313097, 0.8873810949070113, 0.19423359393009118, 0.1159043934728418, 0.152836606704763, 0.13006209449044295, 0.1381938617144312, 0.1776639044817005, 0.15433010299290928, 0.1512010387544121, 0.06771140306123666, 0.13454037133072103, 0.13926100730895996, 0.06750744221998112, 0.17760735537324632, 0.08084123209118843, 0.14674298225768975, 0.15309584779398783, 0.12982960125165327, 0.14057247979300364, 0.09883334128452198, 0.17411079656864914, 0.09715613164007664, 0.189158151990601, 0.08068003931215831, 0.10515474315200533, 0.17016687962625707, 0.12461519534034388, 0.10374764472778354, 0.11442376220864908, 0.15217343371893677, 0.18638981053871767, 0.07163252122700214, 0.14260554712797913, 0.1233787824000631, 0.1576424531106438, 0.1091698044911027, 0.1474926955997944, 0.23155167645641736, 0.14706722700170108, 0.15912338293024472, 0.11577505112758704, 0.13151262594120844, 0.17099744720118387, 0.18321737434182847, 0.13970571916018212, 0.13488609849342278, 0.10184589427496706, 0.14151260363204138, 0.07344739884138107, 0.13770048533167156, 0.10503130406141281, 0.049525670507656674, 0.1498606199664729, 0.2472786796944482, 0.1673154854880912, 0.10096176314566817, 0.1049773944541812], [0.036961040792188475, 0.030146971611039977, 0.04858054925820657, 0.019615402445197105, 0.033425642643123865, 0.019276124757847617, 0.06795397254505328, 0.03012497689841049, 0.025764787203765342, 0.05135002725624612, 0.03565335114087377, 0.05302871271435704, 0.08235519299549715, 0.06349319512290613, 0.040517928145293675, 0.03823020322514432, 0.005973926628939807, 0.03534594763602529, 0.0527296721536134, 0.02676995880236583, 0.016239027459440485, 0.038977080290871005, 0.01881934516131878, 0.07138793649418013, 0.015292613600779856, 0.04665023248110499, 0.016503157393474664, 0.10934669178511415, 0.06984428968280554, 0.02186486647198243, 0.02624266075768641, 0.021101602785555378, 0.02310540829785168, 0.0015841463401946904, 0.04046572844630905, 0.04035627056977578, 0.022660543776250312, 0.08473752944597177, 0.02637167401345713, 0.012238481680729558, 0.04479764189038958, 0.05335269622238619, 0.020321699724133526, 0.057981801219284534, 0.017037347657606006, 0.039653657735990624, 0.030901336310697452, 0.069582802642669, 0.027406414471832768, 0.03779795266953962, 0.0467315040129636, 0.017624699444110905, 0.021341319029618586, 0.038681629180376015, 0.024750638586868132, 0.017344155747975622, 0.020523781023387398, 0.01865086661252592, 0.048108607796686034, 0.03199665807187557, 0.03960514926750745, 0.0030752492020837963, 0.013021008128167262, 0.010683158129852797, 0.038467819403324804, 0.622739138347762, 1.2541339950902122, 7.110896306378501, 12.904047642435346, 20.77776105063302, 25.045045852661133, 32.02708217075893, 40.51363624845232, 41.97265025547573, 43.904318945748464, 36.65264735903059, 34.820581095559255, 37.16973924636841, 32.190639291490825, 33.960505281175884, 27.865508999143326, 22.727342196873256, 26.672543253217423, 21.246177332741873, 27.181479692459106, 21.69093499864851, 19.06368909563337, 16.48326189177377, 23.463823454720632, 25.438183614185878, 20.886753967830114, 22.98299421582903, 26.035002606255667, 26.256261042186193, 24.071625811713083, 15.023193495614187, 62.68989249638149, 54.56842456545149, 19.70134265082223, 26.69710339818682, 21.034670693533762, 37.058043479919434, 27.611144133976527, 11.955820901053292, 36.93988936288016, 41.54449878420149, 34.34128393445696, 30.562648568834575, 35.04619605200631, 34.02329962594168, 37.86466332844326, 35.40034573418753, 26.604704516274587, 20.103473118373326, 11.101883820125035, 6.738062049661364, 2.1247725912502835, 0.359283695263522, 0.11405651191515581, 0.029239773683782135, 0.022907820596758808, 0.05747165823621409, 0.023799478375752057, 0.05231496172824076, 0.026152705673926642, 0.04563341722158449, 0.044811942015907595, 0.012873391138522752, 0.024733257912365452, 0.047458089488957605, 0.03130832161488278, 0.0043382395108762595, 0.125050407701305, 0.009346904698759317, 0.015304513408669403, 0.041581236624291966, 0.05393674523968782, 0.037629122978874614, 0.013275653838978281, 0.018777828996202776, 0.08255695538329226, 0.07021170961005346, 0.007611428404093853, 0.058881918633622785, 0.025855146015861204, 0.04485633856217776, 0.04336469467463238, 0.06323186414582388, 0.051421707695616145, 0.03737455699592829, 0.07159668100731713, 0.0802845958886402, 0.016999543079042008, 0.08533515594899654, 0.0025108755799010396, 0.06552206232611622, 0.028744653466024568, 0.02472529191124652, 0.0515741982630321, 0.07554906606674194, 0.04250864810975535, 0.015555401731814657, 0.031656861305236816, 0.03593939097066011, 0.02859079904322113, 0.03866747833256211, 0.08321058816675629, 0.022707983552079116, 0.02281008441267269, 0.04830525403044053, 0.030459416631077017, 0.0390297956764698, 0.032821461491818936, 0.07098216576767818, 0.05046349072030612, 0.007294943556189537, 0.04982942010142973, 0.055993354347135336, 0.015757031805281128, 0.017927899424518858, 0.011525290486003672, 0.07811777573078871, 0.057020941350076876, 0.03729384864813515, 0.03315843555278011, 0.011530195446019726, 0.01571429766980665, 0.06988021811204297, 0.017890756417598044, 0.017025792206238424, 0.02504963504283556, 0.04491579519318683, 0.036628680769354105, 0.06649121389325176, 0.07262633075671536, 0.03898379100220544, 0.041763352030622106, 0.07156881357410125, 0.06621126391525779, 0.026239873675097312, 0.025609287333541682, 0.021998386896614517, 0.011088130729539054, 0.05011687806940504, 0.02589042135514319, 0.036950191017240286, 0.03517942496442369, 0.014544581329183919, 0.03379806337345924, 0.016615220844479542, 0.0243229240378631, 0.012239396854835962, 0.02323762932792306, 0.08923243717955691, 0.0022725683562124944, 0.04615610631714974, 0.07804203086665698, 0.052384301221796443, 0.053803236689418554, 0.02107190839680178, 0.014873935441885675, 0.02954860550484487, 0.043367734511515925, 0.0334626736917666, 0.01679852368709232, 0.03702278747888548, 0.012632745301483997, 0.019362768590716378, 0.05370456751968179, 0.019993622953604375, 0.029981392103114297, 0.03501814736851624, 0.029192744421639612, 0.025675858404221277, 0.054455902560481, 0.03792796337178775, 0.07986969208078724, 0.0947366589680314, 0.013120555152584399, 0.06314951035061053, 0.03385110106319189, 0.854365100818021, 2.312010475567409, 9.689823133604866, 17.39991167613438, 26.109817334583827, 30.83650139399937, 38.96592501231602, 46.96894352776663, 47.8922027860369, 47.7994304384504, 41.725725173950195, 39.747694628579275, 39.436186041150776, 34.55571576527187, 34.77786009652274, 31.73975678852626, 21.940427439553396, 22.90309340613229, 18.933300937925065, 23.464688505445206, 23.991690261023386, 21.465102910995483, 19.917912789753505, 22.642475162233623, 30.764056001390728, 22.594977276665823, 23.552122899464198, 27.390851497650146, 30.048700741359166, 23.587002856390818, 17.299145426068986, 67.95937851497105, 57.49318190983364, 17.15568596976144, 24.693154335021973, 19.76251459121704, 37.353665011269705, 27.263152292796544, 15.583577871322632, 40.15186439241682, 47.24582576751709, 36.027177470070974, 32.40889957972935, 38.803986821855815, 36.19892999104091, 41.23686729158674, 39.00000245230538, 32.07218292781285, 24.695963144302368, 14.819503579820905, 8.557073950767517, 3.1324327034609656, 0.7015605345368385, 0.19762370416096278, 0.021192582457193306, 0.017647119937464595, 0.04719370849696653, 0.08214232298944678, 0.03838582523167133, 0.04597898832123194, 0.052424171939492226, 0.046703765501401255, 0.010491859600214022, 0.04099100615297045, 0.07555946122322764, 0.025380458183852688, 0.05133969995326229, 0.04257943966825094, 0.030495725039924895, 0.012491563368322594, 0.03476184433592217, 0.04696913715451956, 0.0433541909525437, 0.04039330840376871, 0.018346353666856885, 0.04599328844674996, 0.03842470528823989, 0.04016653860786131, 0.06827080768666097, 0.04104085133544036, 0.055692705658397505, 0.037722960979278596, 0.023575709400964633, 0.026367448436628495, 0.03506353796858873, 0.06959798147103616, 0.04643996465685112, 0.026564886860017265, 0.04497751813115818, 0.0718097070764218, 0.036025039053389, 0.031580641466592035, 0.04753220247636948, 0.02936290743361626, 0.04911403723859361, 0.04906186128833464, 0.02875516397346343, 0.04667722121147173, 0.04785306811598795, 0.040581235462533574, 0.02593640567335699, 0.01882687859636332, 0.05121839824797852, 0.0232262638663607, 0.03804209635459951, 0.02089008815320475, 0.06656490279627697, 0.02164893288032285, 0.07903534506580659, 0.0304454184536423, 0.013184805633500218, 0.2080833079027278, 0.23434444516897202, 0.07550237607210875, 0.11946888720350606, 0.08945791436625378, 0.23799357935786247, 0.20627185010484286, 0.1342285166361502, 0.133051869060312, 0.17272805076624664, 0.18464068296764577, 0.21995296169604572, 0.08606207729982478, 0.1679511642349618, 0.07027792105717318, 0.12474764537598405, 0.13329512386449746, 0.16356558884893144, 0.17454659246972629, 0.07066602951713971, 0.12272341256695134, 0.10928126065326588, 0.18586273810693196, 0.13933019073946135, 0.13755489885807037, 0.10189462666000638, 0.10044173390737601, 0.16184753818171366, 0.11840634207640376, 0.15544265615088598, 0.10189058937664543, 0.12004940105336052, 0.07457799424550363, 0.06686427244650466, 0.1489595661738089, 0.11801906142915998, 0.08192650135606527, 0.14379440833415302, 0.09222877318305628, 0.12655755611402647, 0.10385562679065125, 0.10353850666433573, 0.1560154211308275, 0.11117412229733807, 0.09062686735498053, 0.16673495806753635, 0.09066762695355074, 0.19184629060328007, 0.11946773369397436, 0.1766228824853897, 0.13127717428973742, 0.14800706585603102, 0.11201563464211566, 0.1060506332931774, 0.1311888833131109, 0.10538099386862346, 0.10341411083936691, 0.09491634861166988, 0.14719781785139016, 0.11504136478262288, 0.213493389742715, 0.14554080819444998, 0.09304439263152224, 0.07020069020135061, 0.132698637300304, 0.8069553705198425, 2.5267419474465505, 9.593070336750575, 18.070833206176758, 28.519735745021276, 34.66931881223406, 42.724879605429514, 53.33023125784737, 54.24249846594674, 58.49378504071917, 50.61325979232788, 50.340588160923545, 48.322271960122244, 42.827653884887695, 44.407698563167024, 40.48782021658761, 32.700939314705984, 38.61388063430786, 30.416958740779332, 38.198836939675466, 33.79325519289289, 29.12670431818281, 26.386187144688197, 34.46082074301583, 39.09146506445748, 32.80940069471087, 33.499641690935405, 38.382585525512695, 39.45537349155971, 34.51121255329677, 22.452487094061716, 73.43246064867292, 66.34831360408238, 29.422060080936976, 36.159047331128804, 30.599164826529368, 44.997638838631765, 36.12381649017334, 20.34942024094718, 47.28122336523873, 55.05558361325945, 44.42790739876883, 40.04702302387783, 44.62757083347866, 44.725488322121755, 48.567036151885986, 45.367272581372944, 37.63369825908116, 27.470740147999354, 17.382737466267177, 9.280283280781337, 3.360046135527747, 0.6051360400659698, 0.20304077491164207, 0.09280943631061486, 0.09036622169826712, 0.22940992138215474, 0.19966468321425573, 0.2641386464238167, 0.11349548559103693, 0.13134764693677425, 0.16188287628548487, 0.08662816549518279, 0.1321218553930521, 0.1360102274588176, 0.10913924327386276, 0.11898978719753878, 0.14996090744222912, 0.08972400865916695, 0.14667318814567157, 0.2516211409653936, 0.15676669510347502, 0.16510853676923684, 0.11986331960984639, 0.10187393812728779, 0.16450754473251955, 0.188062725056495, 0.12977835828704493, 0.13655811734497547, 0.14068317599594593, 0.23330164541091236, 0.16446923464536667, 0.12436895498207637, 0.1097126460767218, 0.13216418240751537, 0.1823906201337065, 0.12156511257801737, 0.1127551088907889, 0.1905386857688427, 0.0897686630487442, 0.10581687119390283, 0.08231419590967042, 0.10352328712386744, 0.10312492599976913, 0.17074235874627317, 0.12115432747772761, 0.14847498360489095, 0.16939667452658924, 0.13341080051447662, 0.09478951006063394, 0.1492181694401162, 0.17771366823996815, 0.08680142941219465, 0.2149624451994896, 0.13471167428152903, 0.17715450110180037, 0.15800339302846364, 0.12030837072857789, 0.16803531614797457, 0.15424506898437226, 0.048441364762506316], [0.024899532918685248, 0.05099966909204211, 0.04989476641640067, 0.00944316337284233, 0.024557705636003187, 0.016245219091485654, 0.014588596199506094, 0.06394199175494057, 0.018293909695265547, 0.024228706057848673, 0.031791811742420704, 0.025779594534209797, 0.028834159020334482, 0.05087605018966964, 0.022943567517878752, 0.059567042227302275, 0.03226889989205769, 0.02426226300719593, 0.03255508221419794, 0.024057962898431078, 0.07041904955570187, 0.03820712285648499, 0.038153891784272025, 0.02967322863904493, 0.05361768789589405, 0.021061141742393374, 0.05017768498510122, 0.06889408959874085, 0.04463219130411744, 0.04239214364705341, 0.0655922024909939, 0.0337319638846176, 0.02248410601168871, 0.11296181101351976, 0.006727123400196433, 0.05555397917383483, 0.027418606049780334, 0.007647903054021299, 0.05744607746601105, 0.04402955381997994, 0.056321073190442154, 0.02497189528574901, 0.03863763975511704, 0.02381657576188445, 0.08850257777209793, 0.03361537121236324, 0.01816737139597535, 0.07015412912837096, 0.0276482019440404, 0.04357508124251451, 0.009989942157907146, 0.0246553688775748, 0.03188974470166223, 0.041704550185906034, 0.056919191631355455, 0.030658603978476355, 0.019214306824973652, 0.030318752929036106, 0.03949564050084778, 0.01380534965677985, 0.06689599395862647, 0.018971698325393454, 0.02249127982317337, 0.006726627645548433, 0.023686051069359695, 0.03298132434221251, 0.02817708776066346, 0.5167129391006061, 2.3845142764704566, 6.042219936847687, 10.83514073916844, 15.801308359418597, 24.69683861732483, 32.55829974583217, 37.02515765598842, 41.22637898581368, 46.42865507943289, 45.67024878093174, 43.58890894481114, 43.69368083136422, 38.82692629950387, 32.344357763017925, 37.78630154473441, 40.6676013810294, 40.3968300819397, 31.871675286974224, 25.11680337360927, 15.447860445295062, 31.17715767451695, 25.10582000868661, 24.78032990864345, 26.434801953179495, 28.637406962258474, 29.027379819325038, 24.90736903463091, 34.19720261437552, 47.64650058746338, 81.42805848802838, 33.917808600834434, 24.058351278305054, 27.664655685424805, 44.35998180934361, 31.12895107269287, 26.127067974635533, 31.5126861844744, 44.22952243259975, 42.64914424078805, 40.15218053545271, 37.36591468538557, 36.26886708395821, 30.438327925545828, 21.419807604381017, 12.141612257276263, 6.068524948188236, 1.772781518953187, 0.2704415853534426, 0.05970685436789479, 0.012782933090680411, 0.01775123435072601, 0.030278715970260755, 0.030015590268054178, 0.013813218118489852, 0.0176268860232085, 0.030545529510293688, 0.013289063387284321, 0.037093524754579575, 0.023075279646686146, 0.06275833491235971, 0.029050014580466917, 0.09163802023977041, 0.02839869899409158, 0.04706384028707232, 0.0204208642244339, 0.03565664203571422, 0.030273878015577793, 0.03130654385313392, 0.062148990109562874, 0.04215466656855174, 0.00991421764982598, 0.014523623078795416, 0.025553245430013964, 0.07414221870047705, 0.03343004633539489, 0.029904453017349755, 0.024735778669959733, 0.08582884445786476, 0.03721055168924587, 0.07678065462304012, 0.03146307509658592, 0.04269455313416464, 0.06542178163571016, 0.04472140848104443, 0.021837809888113822, 0.013710837362201085, 0.03996865404769778, 0.037403007969260216, 0.03876828149493251, 0.03092848788946867, 0.028952166438102722, 0.011413497600837477, 0.02167861200203853, 0.025577833842752234, 0.04534149110051138, 0.04248704694743667, 0.049881887821746726, 0.018384531439681138, 0.0729131678651486, 0.02879191343007343, 0.03241392657426851, 0.024440503978569592, 0.07941176915275198, 0.09263896795787982, 0.012324716696249587, 0.029686775590692247, 0.028503254455115114, 0.013761993813594537, 0.03084541145446045, 0.04778073289032493, 0.04539341260013836, 0.023210165623043264, 0.03211738980774369, 0.020053072799263254, 0.04030177063707795, 0.014763505563938191, 0.03128675777199013, 0.04371880853016462, 0.052392945757934024, 0.035220282950571606, 0.02499719107124422, 0.010024711140431464, 0.040687405836901495, 0.053208375216594765, 0.05888643767684698, 0.02671333505505962, 0.04665360140747257, 0.04530420560123665, 0.047280428665024896, 0.031213625267680203, 0.067934132181108, 0.05357703007757664, 0.06387749700141804, 0.026431812572159936, 0.0646294087969831, 0.05465933075174689, 0.06050844171217509, 0.013994872121007314, 0.029351711605808566, 0.05363304992871625, 0.01582216438172119, 0.06293673533946276, 0.02291822593126978, 0.03273440205625125, 0.030123789462127855, 0.018040415797648684, 0.058286734856665134, 0.047816545968609195, 0.04465788063992347, 0.025598457914644053, 0.012160663043947091, 0.02196818191025938, 0.1001439927411931, 0.011778532477494861, 0.0836932844083224, 0.016295540944806168, 0.020384935795196464, 0.03711972638432469, 0.039044407928096395, 0.033321758931768794, 0.0469636444135436, 0.051646981321807416, 0.02449638642636793, 0.02104316226073674, 0.025420325508873378, 0.078510315024427, 0.05888973535703761, 0.04725315494995032, 0.011537123288560127, 0.016445115507979478, 0.062367905862629414, 0.04057035515350955, 0.051082050028656206, 0.026140539541042278, 0.10998577677777835, 1.1341180865253722, 4.170339626925332, 8.825725180762154, 15.008874995367867, 21.47965591294425, 31.86205898012434, 38.80506379263741, 42.37938737869263, 47.00097472327096, 50.70602171761649, 48.71199989318848, 47.85811492374965, 45.621628761291504, 39.20234094347273, 34.20496375220162, 38.71259369168963, 40.73729528699602, 41.96802970341274, 33.48952511378697, 26.743260281426565, 17.560222251074656, 29.367961406707764, 27.956082241875784, 25.550584622791835, 27.587455987930298, 31.383182185036794, 34.79939603805542, 25.477484362465994, 26.9746960912432, 56.230353764125276, 81.86877577645438, 28.226243836539133, 24.610149417604717, 23.038378306797572, 46.189908027648926, 32.40279558726719, 22.10933641024998, 35.32334232330322, 49.11476264681135, 47.33137198856899, 43.51963540485927, 40.49977459226336, 41.7441656930106, 35.25743171146938, 26.035858971732004, 15.231422322137014, 8.27668981892722, 2.6276200200830186, 0.5956351384520531, 0.17523147857614926, 0.05546068739412086, 0.02585182458694492, 0.017482414043375423, 0.015148874438766922, 0.03334214212372899, 0.02457979364719774, 0.03868860112769263, 0.05812595598399639, 0.03429356017815215, 0.051360212066876035, 0.03985230225537505, 0.02991414928276624, 0.05585705362526434, 0.02475928821201835, 0.025634191265063624, 0.015449528216517397, 0.02012015786021948, 0.044750151224434376, 0.03165463910305074, 0.012587414073225642, 0.07151276658156089, 0.06827955400305134, 0.03426823725125619, 0.039953726277287514, 0.07153851020016841, 0.03809360055519002, 0.01224305755126157, 0.029005903018904582, 0.05196590295859745, 0.014519061627132552, 0.040821297759456296, 0.04328486502968839, 0.05132118612527847, 0.02200468539792512, 0.040204672275909355, 0.04226873169786163, 0.005287135111367596, 0.03054554308099406, 0.04061826990385141, 0.06345088167914323, 0.01139402958298368, 0.02397947505648647, 0.031320813444576094, 0.03774155962413975, 0.04150601762479969, 0.05688022675790957, 0.04355930869600602, 0.05638291487204177, 0.0066074701109235835, 0.027297496030639325, 0.05315446900203824, 0.011501214367204478, 0.023144807433709502, 0.01059747442403542, 0.056920742083873065, 0.05320847360417247, 0.04402327058570726, 0.03206054553655641, 0.027192446935389723, 0.09700029928769384, 0.14487574888127192, 0.09857583045959473, 0.14374449529818126, 0.1049176494457892, 0.07620211531008993, 0.08903612342796155, 0.13230056794626371, 0.15785598808101245, 0.09514412603207997, 0.15512359541441711, 0.09617035596498422, 0.11258745645838124, 0.09038043022155762, 0.1739169391138213, 0.1993705654250724, 0.1370645487414939, 0.11037423129060439, 0.15504507534205914, 0.1791924267475094, 0.1364038320524352, 0.07296549648578678, 0.1423878866646971, 0.09716391443674054, 0.19574124445872648, 0.1322438017066036, 0.14119591776813778, 0.18701554196221487, 0.10987865645438433, 0.10179936712873833, 0.1939399375447205, 0.0922831374087504, 0.074728316893535, 0.16132548690906592, 0.1262868477829865, 0.1156768263982875, 0.11420435112501894, 0.09192160038011414, 0.14524185923593386, 0.15068923336054596, 0.20540175107972963, 0.09015202176358018, 0.09506153474961009, 0.09603885587837015, 0.20571366005710193, 0.11377194111368485, 0.12649157536881311, 0.1710320253457342, 0.0674850641350661, 0.09572997316718102, 0.10098224811788116, 0.11815517555390086, 0.07329960712896925, 0.15413377567061357, 0.10241687470780951, 0.12974254520876066, 0.08266695948051554, 0.12667106145194598, 0.12520625362438814, 0.11275308685643332, 0.13850060025496141, 0.07718475615339619, 0.12109187511461121, 0.18659518951816217, 0.19235938521368162, 0.10579291212239436, 0.30685245298913544, 1.0934084824153354, 3.962845572403499, 8.569344469479152, 16.36955635888236, 22.605905055999756, 34.982428959437776, 42.56749595914568, 49.84056452342442, 54.15740040370396, 60.59656006949288, 58.83359364100865, 55.97042860303606, 55.30622598103115, 50.31129108156477, 45.75483962467739, 50.44534615107945, 50.46823351723807, 53.58915935243879, 44.24118150983538, 36.54487385068621, 24.628876549857004, 42.05907889774868, 37.06274741036551, 36.025687081473215, 36.63291447503226, 38.79410995755877, 44.28253371374947, 35.72545542035784, 42.86935349873134, 54.29550279889788, 90.23768642970494, 45.454687867845806, 33.655083315713064, 37.96110779898507, 55.763681479862754, 41.08265549795968, 34.05448661531721, 42.33113213947841, 58.67419501713344, 54.914500440870015, 51.600223609379356, 48.770034721919465, 47.259430340358186, 38.763023717062815, 29.191744668143137, 17.049338579177856, 9.49280869960785, 2.977087050676346, 0.7646600572126252, 0.34597032251102583, 0.1385722399822303, 0.07228196066405092, 0.16754333754735334, 0.16193346785647528, 0.12888712968145097, 0.05911953481180327, 0.08779655529984406, 0.12607739759343012, 0.15929887922746794, 0.19269356371036597, 0.13754864276519843, 0.14631709296788487, 0.15643738848822458, 0.09222110573734556, 0.2256038420434509, 0.12413624461208071, 0.1615226420440844, 0.11491627006658486, 0.08068953880241939, 0.17404647144888127, 0.1474287368889366, 0.2874975672789982, 0.17295963476811135, 0.09432749556643621, 0.20677878361727509, 0.13104651309549809, 0.11035783788455383, 0.14871443861297198, 0.1318568738975695, 0.06188381862427507, 0.13873499339180334, 0.13046146663171904, 0.1294146635170494, 0.11000499288950648, 0.13418917517576898, 0.0730058489633458, 0.06599426841629402, 0.0961927001231483, 0.20498394992734703, 0.23170141556433269, 0.13040502608886786, 0.0928197568282485, 0.12959499098360538, 0.13353375105985574, 0.1276139130017587, 0.21900654105203493, 0.12106751570744173, 0.104795350294028, 0.0837524730179991, 0.16881401650607586, 0.09709637306098427, 0.1345978703882013, 0.15059033009622777, 0.24563711349453243, 0.16046300104686193, 0.08813960903457232, 0.08606584995452847, 0.11821500877184526, 0.09471459979457514], [0.030963435835604156, 0.08454860494072948, 0.0022975403532784966, 0.024923590377771428, 0.08041489496827126, 0.06853305468601839, 0.030390368907579353, 0.03839760799227016, 0.05449894542938896, 0.07220480444708041, 0.03921678974958403, 0.04339724739215203, 0.04198027628340891, 0.01207791909109801, 0.03354015899822116, 0.028751167402203594, 0.0226192057265767, 0.024492186294602494, 0.029697153783802475, 0.0025434495016400304, 0.03982476730431829, 0.01791359081731311, 0.011519288843763726, 0.016412318517853106, 0.03193188511899539, 0.04766565335116216, 0.06182633313749518, 0.02179297399041908, 0.015366192241864545, 0.024851524869778326, 0.0583134080682482, 0.021618285149868046, 0.004492127860430628, 0.03406023573396461, 0.01736959063314966, 0.036134384971644194, 0.02560692772801433, 0.07056104657905442, 0.08618017631982054, 0.061236150163624964, 0.03854810366673129, 0.0054648570034519905, 0.03884406367849026, 0.11077224636184317, 0.007182599361320692, 0.04690529379461493, 0.024858356021078568, 0.04137696026425276, 0.033836631303919215, 0.019682051547403847, 0.009585264720954001, 0.06703898164310626, 0.0405242419136422, 0.05531023243176086, 0.02814477083406278, 0.06563320636217083, 0.028265889334891523, 0.049896961477185996, 0.10698931863797562, 0.043745210327740223, 0.010690946015529335, 0.02496589533984661, 0.04656750209895628, 0.04919031136003988, 0.027533290342294743, 0.04593857816819634, 0.02730670035816729, 0.06357702133910996, 0.13377070905906813, 0.411690428853035, 1.8016835280827113, 4.206315662179675, 7.766398480960301, 16.037986585072108, 22.60132966722761, 31.265778473445348, 37.90378168651036, 42.73765386853899, 45.7380736214774, 46.167381967817036, 47.44442612784249, 50.13122851508004, 45.69063826969692, 42.4410526411874, 37.25024454934256, 40.912626130240305, 36.83615970611572, 24.93723065512521, 38.06986447743007, 34.878334522247314, 38.63866138458252, 32.10958508082798, 33.59369945526123, 40.76117277145386, 31.864775725773402, 33.20986359460013, 31.047737053462438, 67.39116178240094, 48.19612046650478, 24.00818007332938, 42.198689052036826, 36.65525640760149, 27.26027921267918, 39.20935862404959, 36.10848181588309, 42.697600977761404, 38.190613746643066, 30.814371381487163, 27.737193141664775, 17.45466869218009, 12.486559918948583, 6.614586915288653, 1.95216218488557, 0.524568963263716, 0.02170604178016739, 0.0054965428924853245, 0.021501829880954962, 0.014167012214394552, 0.05973981759910073, 0.08386890284184899, 0.003743184231487768, 0.1067418297752738, 0.04809625845934663, 0.07099552612219538, 0.03878447134047747, 0.025914064907867993, 0.022896039532497525, 0.013863470421970954, 0.05573614886296647, 0.016893861249887517, 0.07169964191104684, 0.02232073343891118, 0.0465621179235833, 0.030746508190142255, 0.05241937469691038, 0.04676404655245798, 0.03464906503047262, 0.05320808005386165, 0.014189732111325222, 0.04750010437731232, 0.02067392216330128, 0.016520962152363997, 0.01527290215848812, 0.013321488031319209, 0.02521730613495622, 0.04713369546724217, 0.013890366701941406, 0.060268857782440524, 0.06299328444791691, 0.05028077481048448, 0.023587736434170177, 0.04502576875633427, 0.018508966280413524, 0.0610002778204424, 0.04750068113207817, 0.013085897280169385, 0.03689030012381928, 0.03874890592747501, 0.04030285968578287, 0.004464092489797622, 0.07239127265555517, 0.03996618078755481, 0.034954667024846585, 0.03590065001377037, 0.04762067665745105, 0.017458702637148753, 0.013045271692265357, 0.01994674975451614, 0.015697817750541226, 0.046947318860994916, 0.027592629926013093, 0.013591922403845404, 0.0020249155848952277, 0.03347391023167542, 0.02366381717313613, 0.03830563257049237, 0.012276007211767137, 0.09130832007420914, 0.013142738158681562, 0.022819392216791, 0.03182493103668094, 0.06491986928241593, 0.026596029921035682, 0.04712540716198938, 0.05805929670376437, 0.024261102712314044, 0.0378323001121836, 0.052805111676986725, 0.038910631356494765, 0.03887990729085036, 0.032681038669709644, 0.04353661509230733, 0.02686835146908249, 0.06051571560757501, 0.04290078706773264, 0.05347590121839728, 0.05094633963225143, 0.020862504008359144, 0.04166504926979542, 0.06741516145744494, 0.04263176489621401, 0.02519746237833585, 0.014420304247843367, 0.058855686469801834, 0.012033040784964604, 0.04107027939919915, 0.034918881087963066, 0.05158038650240217, 0.06292448099702597, 0.048122192067759376, 0.028642316814512014, 0.021455830295703242, 0.10318304930946656, 0.04211292987955468, 0.014678732791383351, 0.046474671723054986, 0.020736211678013206, 0.07956754722233329, 0.11913413873740605, 0.08221192032630954, 0.01939314660350127, 0.010771968185768595, 0.023621254367753863, 0.01187994547321328, 0.016305847891739438, 0.03933391846450312, 0.08896915880697114, 0.07554701010563544, 0.025160270177626183, 0.04358699631744197, 0.07467405444809369, 0.045044849161058664, 0.055966060276010206, 0.02913387811609677, 0.01477751731207328, 0.02606773951889149, 0.027124756281929355, 0.013018659548833966, 0.03629808833024331, 0.05205350182950497, 0.018521929691944803, 0.04524282193077462, 0.027438144465642314, 0.03531755433816995, 0.2330084911414555, 0.8175382912158966, 2.882062618221555, 6.81128694329943, 11.47859604018075, 20.97874638012477, 28.005402292524064, 36.792399951389854, 43.555446420397075, 49.49267169407436, 50.265227999006, 51.520698002406526, 51.45328310557774, 52.790057454790386, 49.733089787619456, 46.12406342370169, 41.21788133893694, 45.00174522399902, 40.04211412157331, 26.837783575057983, 41.18141719273159, 38.617108072553364, 41.22844607489449, 34.35699381147112, 33.439494609832764, 42.12041759490967, 33.26168325969151, 35.85062026977539, 30.585570675986155, 76.02048397064209, 50.33175352641514, 24.49832510948181, 41.21577256066458, 40.706511293138774, 31.35348211015974, 40.25289119992937, 39.500300543648855, 49.29640940257481, 42.27019643783569, 38.02330459867205, 32.32651131493704, 22.91439117704119, 15.50768096106393, 8.652494430541992, 2.7006095434938158, 0.7536659442952701, 0.08546780275979213, 0.010618848277122846, 0.07205779983529023, 0.036479504845504246, 0.031859234374548705, 0.058530776761472225, 0.04120434774085879, 0.038226603596870384, 0.017937795857765844, 0.0590543547379119, 0.03133706435827272, 0.03146967724231737, 0.028217874500634413, 0.02436299661972693, 0.04226195991837552, 0.018139848319281424, 0.03069839666464499, 0.06343561464122363, 0.021424176637083292, 0.06293260984654937, 0.022148144664242864, 0.03399699966290167, 0.04742528571348105, 0.07114339247345924, 0.041631071628736596, 0.02495662315881678, 0.042612267192453146, 0.03229308288012232, 0.033704235551080534, 0.02567794659574117, 0.025067137853641595, 0.02815400908834168, 0.018752039576481496, 0.012751954574404019, 0.027192954140316163, 0.043580658800367794, 0.06183368845709732, 0.08303099351802043, 0.023410886459584748, 0.01435513435197728, 0.0211143677255937, 0.02139117947912642, 0.09619538033647196, 0.00841196401909526, 0.011601822450757027, 0.06817318685352802, 0.015622254394526993, 0.019246007981044904, 0.06076963698225362, 0.026550413708069494, 0.049313339936946116, 0.035171771089413335, 0.006871854919674141, 0.014020220492966473, 0.010226787350672697, 0.007293392255503152, 0.08944403832512242, 0.07870058981435639, 0.016094974474981427, 0.022173839089061533, 0.012539694401701646, 0.01576198511091726, 0.10576446793441262, 0.1857002561113664, 0.13951157672064646, 0.07257364251251731, 0.19055587984621525, 0.15683131877865109, 0.12364033050835133, 0.17941760537879808, 0.17892497538455895, 0.10899129549839667, 0.08695988769509963, 0.13307673058339528, 0.12654456895376953, 0.1112609612090247, 0.10055432322302035, 0.08189169250960861, 0.10274071911615984, 0.2195614062781845, 0.1501355759267296, 0.10121096870196716, 0.09530091511883906, 0.20701882216547215, 0.17184561597449438, 0.28396402831588474, 0.09152786007949285, 0.17030699710760797, 0.1599119763289179, 0.16911714524030685, 0.11074115588728871, 0.08596652599849872, 0.11299897437649113, 0.1174027073596205, 0.1023876094924552, 0.12675643472799233, 0.07009918136256081, 0.1495640730219228, 0.21551048436335155, 0.25754130472029957, 0.13049980386027268, 0.12873649490731104, 0.11507223812597138, 0.11212016974708863, 0.2835789461221014, 0.1924205483602626, 0.11696673503943852, 0.10794610729707138, 0.21335540286132268, 0.18430619234485285, 0.15967001074126788, 0.11390471006078379, 0.16695394845945494, 0.19520171412399837, 0.0823398106066244, 0.1903632708958217, 0.1481121437890189, 0.11673531388597828, 0.13345011483345712, 0.09075897812311139, 0.14469653421214648, 0.14805085850613459, 0.12700500924672398, 0.11891679040023259, 0.12277655542961188, 0.14244941622018814, 0.10267978667148522, 0.09762371690677744, 0.11644271601523672, 0.11726263059037072, 0.2858751357666084, 0.8304273624505315, 3.108644894191197, 6.625244149139949, 11.732440658978053, 21.146871941430227, 29.892998559134348, 41.00964730126517, 48.30383838926043, 54.63454014914376, 59.60580948420933, 59.47277232578823, 61.110622542245046, 64.09929983956474, 59.03149223327637, 54.39598069872175, 49.77937521253313, 55.77660165514265, 49.8849252973284, 34.88422312055315, 51.01286111559187, 48.36690371377127, 49.51859542301723, 43.94075182506016, 43.673235757010325, 52.771415437970845, 42.76947661808559, 42.90418829236712, 39.479719979422434, 76.37388324737549, 60.54824229649135, 33.98459815979004, 52.5323418208531, 45.97055687223162, 39.0640926361084, 49.31996032169887, 46.75205898284912, 55.502568176814485, 50.24113164629255, 43.116028445107595, 36.40267896652222, 25.17447168486459, 16.824117933000835, 9.570189918790545, 3.001829368727548, 0.7810913526586124, 0.14151431354028837, 0.14277615797306809, 0.15150644736630575, 0.11558869827006545, 0.15740511513182096, 0.16198745210255894, 0.20237254005457672, 0.18806044517883233, 0.07581314511064972, 0.211618000375373, 0.11190371707613979, 0.16027849380459103, 0.11232137573616845, 0.15993039176932403, 0.17672508342989854, 0.08370475843548775, 0.20742018919970306, 0.16725660221917288, 0.12069234012493066, 0.15097112394869328, 0.15718860817807062, 0.10486940560596329, 0.15723938973886625, 0.11940909469766275, 0.11547598003276757, 0.10185056259589535, 0.1582178236650569, 0.1144278741308621, 0.0929876806746636, 0.11694584973156452, 0.1254835030330079, 0.13723130550767693, 0.0908146451360413, 0.1470232443617923, 0.18904461951128074, 0.15831684906567844, 0.13085740538580076, 0.1363285689481667, 0.1071707656873124, 0.09064864832907915, 0.06886378622480802, 0.07772034419966595, 0.1694998661322253, 0.12030387882675443, 0.07799379381218127, 0.12272924796811172, 0.14920039182262762, 0.14108283312192985, 0.11434674848403249, 0.13349753086056027, 0.14902188282992157, 0.1540122093366725, 0.12876567191311292, 0.15242833218404225, 0.07982432522944041, 0.09326227701136044, 0.2240485990686076, 0.17000248416193894, 0.17793284862169198, 0.107194765470922, 0.07842160335608891, 0.10228234835501228], [0.023431223850431185, 0.025202705757692456, 0.015893544569345455, 0.01375051130474146, 0.022716351585196595, 0.03937395881595356, 0.008014096529223025, 0.008786235453693994, 0.01905803003215364, 0.06559871642717294, 0.03306680279118674, 0.014368730497413447, 0.06160130378391061, 0.04241569899022579, 0.0730297944641539, 0.07815715111792088, 0.046384874398687055, 0.041519425476768186, 0.03376247760440622, 0.002517886967065611, 0.026494112264897143, 0.055868866919939, 0.05068798742390104, 0.06571258817400251, 0.03285690476851804, 0.059318182723862786, 0.09812972761158432, 0.006728527967685035, 0.056971306513462744, 0.0072873812834067, 0.05887423761721168, 0.03966067378808345, 0.014456054561638405, 0.02400856894174857, 0.00867818044831178, 0.05835351627320051, 0.060661641348685534, 0.033445588179997036, 0.04154597315937281, 0.017716936101870875, 0.06047197724027293, 0.0334291879885963, 0.036342267745307515, 0.055620251689106226, 0.052951872016170194, 0.07605795376002789, 0.07797336990811995, 0.045196902073387585, 0.022006805819858397, 0.08785794236298118, 0.025928122457116842, 0.020393546404583112, 0.04194308577903679, 0.035588744429073164, 0.0018161034302985562, 0.02248358862873699, 0.0803360559844545, 0.06635229741888386, 0.011250189488886722, 0.037938399240374565, 0.02509604174909847, 0.03520036455509918, 0.053379169266138754, 0.01883022377400526, 0.04072678122403366, 0.06421699521264859, 0.010681841771916618, 0.07259646843054465, 0.01167976322384285, 0.027702639112249017, 0.05662132493619408, 0.4732542910746166, 1.7368608521563667, 2.8344959020614624, 6.173522216933114, 11.240848660469055, 17.635252373559133, 24.597071170806885, 34.844350882938926, 38.88367918559483, 45.61031361988613, 40.65048449380057, 41.857723576681956, 49.63196917942592, 47.436286313193186, 51.11516291754586, 45.99654313496181, 44.96692085266113, 48.23533262525286, 45.942013672419954, 50.834938594273154, 48.69233301707676, 51.13882500784737, 47.17094155720302, 42.376444816589355, 42.96583618436541, 46.052635942186626, 42.23486484800066, 52.43317018236433, 43.29547609601702, 42.30798421587263, 40.267402512686594, 39.70413984571184, 40.419707025800435, 36.30133254187447, 29.618774005344935, 24.442623138427734, 17.50021587099348, 9.295746496745519, 6.107985505035945, 2.5858583067144667, 0.480980036514146, 0.026469968292596083, 0.03031441369759185, 0.04691611982083746, 0.04359765949526003, 0.009143950633837708, 0.010067185736261308, 0.049807842687836716, 0.025541874879438962, 0.0330720953643322, 0.0021687228124522206, 0.029085267867360796, 0.04665380836065326, 0.05365835589223674, 0.046291657257825136, 0.07847488192575318, 0.04268293322197028, 0.08066574257931539, 0.03788954132635679, 0.06083507489945207, 0.025913522079853073, 0.034165038860269954, 0.0534423544470753, 0.00727079703938216, 0.07637243438512087, 0.07124775794467755, 0.019660609840814556, 0.05896384495177439, 0.016801616110439812, 0.00871374670948301, 0.06371951369302613, 0.006885345468098032, 0.059650949867708344, 0.009055289855626012, 0.027797725617087314, 0.04316801790680204, 0.007574264192953706, 0.02261023040461753, 0.06982402862714869, 0.09288010573280708, 0.018133792394239987, 0.017339543406186358, 0.11442693775253636, 0.045222984959504435, 0.022172163107565472, 0.03229110495054296, 0.01785764899770064, 0.0291909938012915, 0.04026925523898431, 0.04114000905039055, 0.03714973120284932, 0.030955975343074118, 0.05916655050324542, 0.004607647599186748, 0.037051394515271695, 0.04836200669940029, 0.029110536511455263, 0.019973414484411478, 0.06366658796157156, 0.01481713357913707, 0.0054245660181290335, 0.04724889375003321, 0.031900112716747184, 0.020913724920579364, 0.02206489520280489, 0.008434724628127046, 0.04030218115076423, 0.01741472678259015, 0.015443881108824695, 0.08666057911302362, 0.02110733131745032, 0.044683305347072225, 0.05745081364044121, 0.043773664693747244, 0.0417286178230175, 0.012828755408658512, 0.01669738973890032, 0.05429483870310443, 0.028733250685036182, 0.031323673469679694, 0.019332183624750802, 0.021353780325236063, 0.025819595869896666, 0.03442882952679481, 0.021870642501328672, 0.06021971149103982, 0.0579813669568726, 0.013355722667516341, 0.018915330725056783, 0.07066514063626528, 0.054709226824343204, 0.05369510534884674, 0.07387467234262399, 0.03198722643511636, 0.00890763639472425, 0.04317714420280286, 0.020431656323905503, 0.03638030302577785, 0.03349937904360039, 0.03478990854429347, 0.020353560335934162, 0.035416389748986275, 0.06767461289252553, 0.04964002401434949, 0.05476566058184419, 0.053867833223193884, 0.006677557265252939, 0.04073822132444807, 0.021317281926582967, 0.04428251846028226, 0.01059271619721715, 0.028621546857591187, 0.07623532281390258, 0.030954570775585513, 0.045841323743973456, 0.03377485069047127, 0.021886033371889164, 0.006417078697787864, 0.052065057280872545, 0.04668300232983061, 0.01949733226293964, 0.07901679391839675, 0.046255701687186956, 0.028519634290465286, 0.01883438997901976, 0.05426286274035062, 0.023974572640976737, 0.03507207054644823, 0.052509256838155646, 0.022322468792221377, 0.01314522753403123, 0.06033645344099828, 0.04252542828076652, 0.016102343365283947, 0.005448792262801102, 0.15120748483708926, 0.7098576064620699, 2.724348498242242, 4.915054065840585, 9.345858642033168, 15.986069645200457, 22.461985281535558, 30.046779564448766, 41.37645660127912, 45.17724977220808, 51.318175383976524, 48.47138030188424, 49.453306674957275, 54.19990253448486, 50.98426233019148, 57.026346342904226, 50.74122823987688, 47.59893321990967, 52.7908947127206, 50.27009868621826, 55.04022114617484, 51.834430013384136, 55.84013598305838, 53.54966926574707, 46.16309492928641, 43.46480369567871, 44.299789564950125, 45.901224272591726, 57.48870726994106, 44.27670764923096, 46.99562808445522, 44.11286217825753, 42.56231607709612, 45.20538650240217, 40.953745569501606, 36.31759132657732, 28.59429165295192, 21.358456747872488, 11.62705819947379, 7.443312457629612, 3.5155337921210696, 0.9739959814718792, 0.11635019098009382, 0.05987598600664309, 0.010195389839022287, 0.06539583445659705, 0.031746600954128165, 0.013165077227833015, 0.03967794589698315, 0.00591952253931335, 0.03493327960105879, 0.11815311280744416, 0.07197613814579588, 0.05652136315724679, 0.00513711483550391, 0.07699480706027576, 0.07134394706892115, 0.04340790378461991, 0.055339053206677945, 0.010130448948724993, 0.037309957069477866, 0.011809517779121441, 0.040546033065766096, 0.014986777511824454, 0.04252832562529615, 0.02558524174881833, 0.026593402294175963, 0.039159049812172136, 0.014666174804525716, 0.013230553312626268, 0.00608664910708155, 0.0621703639626503, 0.043296104962272305, 0.0557456721019532, 0.047328150032886436, 0.02091203027937029, 0.05255836920280542, 0.01279461576736399, 0.020291723743347184, 0.07681918862674918, 0.05719304497220686, 0.046187491954437325, 0.012484654185495206, 0.026466392413047806, 0.053619302809238434, 0.011373800757740225, 0.03797145068113293, 0.03837525365608079, 0.015916964205514108, 0.047553891848240576, 0.03439143546191709, 0.042917048159454546, 0.01263373002542981, 0.033088268246501684, 0.014264108879225594, 0.03408967058307358, 0.08191542766456093, 0.017897959066820995, 0.011631828117450433, 0.047717120232326646, 0.03129901211442692, 0.030075986670064073, 0.09730051032134465, 0.0685833544869508, 0.03350378612854651, 0.011147747664446277, 0.11765383317002229, 0.08685188527618136, 0.07832066448671476, 0.04835470566259963, 0.11588234108473573, 0.08556697743811778, 0.1351867030773844, 0.10812210571020842, 0.14561837831778185, 0.1668733520699399, 0.08626701523150716, 0.09191297620002713, 0.15100503712892532, 0.21571118145116738, 0.19435734514679226, 0.20769183390906878, 0.11032378899731807, 0.14088782215757029, 0.07933839916118554, 0.0761178887582251, 0.15348178494189466, 0.1968421403850828, 0.1657713976289545, 0.1899144606930869, 0.13654114039880888, 0.1557338290980884, 0.12275261671415397, 0.11175914161971637, 0.1670293744121279, 0.06292430457792111, 0.1699550545641354, 0.1206856361989464, 0.09220412200582878, 0.09650051753435816, 0.21129361992435797, 0.14021411830825464, 0.10139333177357912, 0.09848424858812775, 0.11383556734238352, 0.21363304582025322, 0.1406064879681383, 0.07401217746415309, 0.07318940625659057, 0.11766563967934676, 0.13473975206060068, 0.12720372501228536, 0.16047920446310723, 0.1602548672152417, 0.13603886163660459, 0.2387775315770081, 0.08277541651789631, 0.07851924454527241, 0.09486680876995836, 0.13713751839739935, 0.1406327337026596, 0.08036023218716894, 0.14572296770555632, 0.17551442767892564, 0.16724054808063166, 0.12059594744018146, 0.15257155735577854, 0.08395283083830561, 0.17707166554672377, 0.09728488365986518, 0.10781493290726628, 0.1526897038732256, 0.11315300182572433, 0.2181706673332623, 0.1086558752826282, 0.0701897047193987, 0.31098340132406777, 0.7173777286495481, 2.659895488194057, 4.706321929182325, 9.486990451812744, 16.09326819011143, 24.808386734553746, 32.77175188064575, 44.11207703181675, 49.47350856236049, 55.685323170253206, 54.46516738619123, 57.041816507067, 62.14412539345877, 60.51650292532784, 65.07372910635812, 59.7694673538208, 57.756247656685964, 62.28317274366106, 58.95857783726284, 64.88064561571393, 61.82300744737898, 63.81953757149832, 60.51119450160435, 57.29232685906546, 55.161644390651155, 56.695084026881624, 53.183325495038716, 64.51792185647147, 54.15420075825283, 55.62958819525582, 51.812279156276155, 50.88466337748936, 52.47025271824428, 49.297736508505686, 41.40827587672642, 33.276851177215576, 23.87084719112941, 14.371403830392019, 8.976174524852208, 3.5025024456637244, 1.085849819438798, 0.1731704148863043, 0.22296930769724504, 0.10197622728134904, 0.23861796728202275, 0.10583945283932344, 0.173820397151368, 0.1332269310951233, 0.11942552881581442, 0.0982253806931632, 0.2801791328404631, 0.2135316455470664, 0.16802832723728248, 0.1554559554372515, 0.20342441861118588, 0.20988396342311585, 0.13502271473407745, 0.1588188021310738, 0.08349720814398356, 0.12272596385862146, 0.10942706425807305, 0.09459606651216745, 0.14646348011280808, 0.09246824176183768, 0.1165822906685727, 0.17477976424353464, 0.14204713994903223, 0.059862924207534106, 0.1130485413596034, 0.09404799342155457, 0.2878196271402495, 0.13151259879980767, 0.11623251943715981, 0.06797167552368981, 0.07940315175801516, 0.1428097997392927, 0.09650699754378625, 0.051796157245657275, 0.19360155213092053, 0.16526548191905022, 0.12353985304278986, 0.11294824031314679, 0.14954134209879807, 0.17908227337258203, 0.09551614642675434, 0.098597781067448, 0.1291865671851805, 0.17852052780134336, 0.10272711448903594, 0.09574667191398994, 0.12020051080201354, 0.11666530264275414, 0.2067057325371674, 0.12966755351849965, 0.1471863913216761, 0.2248903624713421, 0.13410731671111925, 0.12778888004166739, 0.14525780480887207, 0.16015330409365042, 0.12696408001439913, 0.1961015329829284, 0.1235711063657488, 0.12442935816943645, 0.1369917555046933], [0.018117872266364948, 0.036708317031817775, 0.04617422320214765, 0.009120413102209568, 0.027204701277826513, 0.07741892537368195, 0.030343434640339444, 0.07379483591232981, 0.00940361071843654, 0.0488581074002598, 0.025385640495057617, 0.016655079687812498, 0.03502782667055726, 0.04584510996937752, 0.040616465000701804, 0.017576258829129592, 0.022407253439139043, 0.007226326702428716, 0.055945347994565964, 0.028054707184700028, 0.06039355216281755, 0.01703411104556705, 0.05290174184899245, 0.01746115893391626, 0.03013857134750911, 0.08300500562680618, 0.0613444239965507, 0.013763590915394681, 0.03269558306783438, 0.017781569955072234, 0.03933200838842562, 0.03607479941898158, 0.0133354234442647, 0.05707192647137812, 0.08695661715630974, 0.011454020560319935, 0.054107722493686845, 0.013156726158091, 0.033565536207918606, 0.08839347612644945, 0.016619968893272535, 0.05351271852850914, 0.09530588199517556, 0.032527754216321876, 0.045888916190181456, 0.041040393324302774, 0.05779178427266223, 0.04083348424839122, 0.05706323443778923, 0.023103951143899133, 0.007951262490158635, 0.03563179747600641, 0.01068140157232327, 0.030855270568281412, 0.05887853952922991, 0.01027281238098762, 0.03945119306445122, 0.0582829350605607, 0.06342057151986019, 0.06074365587638957, 0.021765635814517736, 0.03228538829301085, 0.05828872974961996, 0.042670220868395906, 0.023607327436496104, 0.024966821540147066, 0.06791554032159702, 0.04208529314824513, 0.042077788550938876, 0.06559375633618661, 0.04952167732907193, 0.0590159021584051, 0.05893725994974375, 0.15124613419175148, 0.4620381072163582, 0.9068856111594609, 2.881218194961548, 6.2793819308280945, 9.502377237592425, 14.206835746765137, 18.703454528536113, 22.411529200417654, 27.7421715259552, 35.085467270442415, 39.26944317136492, 35.670613288879395, 40.112422943115234, 40.64458547319685, 36.51890843255179, 41.13542706625802, 48.1162474496024, 44.3916516985212, 43.43894944872175, 38.411938190460205, 41.07097905022757, 47.78884833199637, 44.216334751674104, 43.30326850073678, 44.4953396660941, 42.54486567633492, 41.95965712411063, 39.77977793557303, 38.54074042184012, 29.860265595572336, 26.266688551221574, 14.64525318145752, 8.861481479236058, 3.952011159488133, 1.1863246794257845, 0.45070570388010567, 0.11447709506111485, 0.0426457766443491, 0.013088840425812771, 0.0155538241378963, 0.0020092634783525553, 0.01884437631815672, 0.05766384649489607, 0.06772209677313056, 0.05091732208217893, 0.007454516332862633, 0.03930293994822672, 0.024880673037841916, 0.06284284644893237, 0.010004571372909206, 0.029958308341779878, 0.05195402181042092, 0.04932236106001905, 0.03522803521315966, 0.05282319463523371, 0.046909456606954336, 0.03320496269900884, 0.03577355022675224, 0.016220142133533955, 0.05350540052833302, 0.019656579342803786, 0.021734650512891154, 0.06598185122545276, 0.011047617948081876, 0.03619218258453267, 0.02289727616256901, 0.04143147716032607, 0.061491048628730435, 0.048432492917137485, 0.0076858687846522245, 0.025137043923937848, 0.014030024475817169, 0.038496575717415125, 0.05594006220677069, 0.013068283359254045, 0.07852980933551278, 0.01986337306776217, 0.030963802244514227, 0.030340968165546656, 0.024902079121342728, 0.08218300794916493, 0.019597504387742708, 0.08297295841787543, 0.008153647433833351, 0.06392287063811507, 0.009678285086660512, 0.0033609703324535595, 0.05632599596200245, 0.054842972861869, 0.03205834708309599, 0.04348400148696133, 0.013756033731624484, 0.04789384128525853, 0.06118514468627317, 0.036257162490593534, 0.03679934250456946, 0.050904945603438785, 0.07804413432521479, 0.010190132040796536, 0.03959183980311666, 0.051031594164669514, 0.020818448425935845, 0.03846839615809066, 0.03642516436853579, 0.038733584606753926, 0.008609980045418655, 0.0621257842119251, 0.04726830663691674, 0.018054408886070763, 0.08209872711449862, 0.019982187942202603, 0.018505215678097944, 0.07237706413226468, 0.07719283072011811, 0.01806847830968244, 0.015440820915890592, 0.05018815138776388, 0.09976708689438445, 0.0297286683427436, 0.012123739712738564, 0.05946718222860779, 0.04702979139983654, 0.05086355835997632, 0.031627687692110024, 0.04295404188867126, 0.0201319949036198, 0.0252146310106452, 0.05089315605748977, 0.052296325763953586, 0.018932653724082878, 0.026943643411089267, 0.06156270192669971, 0.012578659275147532, 0.03244391103674259, 0.02981985666389976, 0.02847908843042595, 0.025255896117804304, 0.05782119876572064, 0.03654981803681169, 0.07908416566039835, 0.06400231351809842, 0.06274967002017157, 0.01701636565849185, 0.06878451297857932, 0.031747157352843454, 0.024916472545425807, 0.04176429180162294, 0.019519248944041983, 0.02240530095462288, 0.02224361284502915, 0.05415291631860392, 0.02023062845026808, 0.031703530943819454, 0.024561196698674133, 0.027341125832338418, 0.05990144464054278, 0.021168341793652092, 0.026424078969284892, 0.01750471070408821, 0.007475947861426643, 0.02470752107910812, 0.1025503696873784, 0.01501818180882505, 0.0318331311323813, 0.033902761326836686, 0.02296098381546991, 0.023427610651456883, 0.005578944185149989, 0.018467017549223134, 0.0626626004065786, 0.04791414983836668, 0.045125906954386404, 0.0564490652510098, 0.04483279339703066, 0.15730243921279907, 0.3378340091024126, 0.7328025666730744, 1.7808094024658203, 4.847811571189335, 10.290776303836278, 12.750015633446829, 18.548923117773874, 24.83254735810416, 27.77761254991804, 34.14755426134382, 42.62776115962437, 46.0289043698992, 42.51377248764038, 46.9765795980181, 47.0887131009783, 43.28116280691964, 48.09766101837158, 54.15609066826956, 50.44071517671858, 49.81450530460903, 45.00170006070818, 48.300544943128315, 53.32802520479475, 50.87842736925398, 48.74445145470755, 50.03736530031477, 48.002752099718364, 46.879308291843955, 45.437167985098704, 44.745280265808105, 36.79850046975272, 29.66045277459281, 17.457805803843907, 11.41950421673911, 5.945679060050419, 1.6459875340972627, 0.8458219106708253, 0.20316810879324163, 0.016445373351286565, 0.06909087153949908, 0.0502959264974509, 0.02268222127375858, 0.011215911596082151, 0.010200214223004878, 0.055479862793747864, 0.03874435295749988, 0.025090630432324748, 0.04302317103637116, 0.12160347694797174, 0.03816255328378507, 0.04357960028573871, 0.03339261495109115, 0.04435161368123122, 0.030304391735366414, 0.02524192338543279, 0.0547272012169872, 0.09516094012984208, 0.0018963569475870046, 0.031175552667783837, 0.008095139903681619, 0.022831624506839683, 0.01050912746826985, 0.026115639002195427, 0.03988874297855156, 0.07146116399339267, 0.015198843453877738, 0.15201952840600694, 0.04787371254393032, 0.01630921851444457, 0.05085399440888848, 0.04253519579235997, 0.05586593904133354, 0.013028974977454968, 0.06427207868546247, 0.02679192298091948, 0.026480436391596283, 0.08421758841723204, 0.014791859846029962, 0.015301293760005916, 0.01771583517880312, 0.024398818179698925, 0.029260645420955758, 0.03940512392936008, 0.014026894733043653, 0.0237467935242291, 0.013451033088910793, 0.018511200356962423, 0.055641293060034513, 0.036331692777041874, 0.012794190834808563, 0.041948351210781505, 0.03688159112685493, 0.01302875021273004, 0.012421877821907401, 0.015087383899039455, 0.03360647561826876, 0.018588163191452622, 0.005317990643171859, 0.025947377584608536, 0.01197833813992994, 0.012577359032418047, 0.11139041211988245, 0.040341047636632404, 0.11990982640002455, 0.11832930121038641, 0.1190759747156075, 0.08759821951389313, 0.09306563756295613, 0.1592311750033072, 0.06498264734234128, 0.15899952314794064, 0.08343920018523932, 0.14179300144314766, 0.15372573185179914, 0.13033981887357576, 0.156160763331822, 0.1348192627940859, 0.09996833359556538, 0.1674228568694421, 0.16898569943649427, 0.12461067629711968, 0.13695016130805016, 0.10360070796949522, 0.2121413272938558, 0.1922055748956544, 0.1634063231093543, 0.12245855320777212, 0.12498372127967221, 0.14556706749967166, 0.12985847970204695, 0.2618769534996578, 0.17621922200279577, 0.07202990526067359, 0.1193779499403068, 0.13713599847895758, 0.10891290434769221, 0.13075212389230728, 0.1373964880726167, 0.12191515522343771, 0.17309143341013364, 0.1586675023926156, 0.13379995391837188, 0.1403153014502355, 0.08525892932500158, 0.15179631752627237, 0.1393294172095401, 0.1428621555013316, 0.11188632622361183, 0.10980891662516765, 0.12041206445012774, 0.08270323396261249, 0.13095299739922794, 0.13960934004613332, 0.11756628858191626, 0.17022849060595036, 0.15011692978441715, 0.1657283106552703, 0.21411758767707006, 0.14722980399216923, 0.09001041829053845, 0.09670757249529872, 0.15435933428151266, 0.229630173849208, 0.10022018543843712, 0.10403047847960677, 0.10337251664272376, 0.16973884616579327, 0.11973556503653526, 0.05622492817097476, 0.25487170368433, 0.16995813511312008, 0.1354840099811554, 0.17753392431352819, 0.17444877486143792, 0.09808935477797474, 0.24720580503344536, 0.4619836615664618, 0.7326854786702565, 1.961961533342089, 4.418462838445391, 10.230094211442129, 13.88782571043287, 19.31586527824402, 26.371317999703543, 30.175748552594865, 37.53002766200474, 46.14240666798183, 50.0254282951355, 46.716776030404226, 52.265624795641216, 53.156046867370605, 49.04850809914725, 53.249885763440815, 61.88298429761614, 57.10175166811262, 57.12442364011492, 50.978488377162385, 56.19673490524292, 59.255474363054546, 57.15824747085571, 54.47602047239031, 57.08027826036726, 53.92198153904506, 52.70680413927351, 50.16156087602888, 53.33877754211426, 42.44401952198574, 34.2043662071228, 20.318940230778285, 13.310289706502642, 6.560049636023385, 2.2290565839835574, 0.971699167575155, 0.22002861835062504, 0.11277129873633385, 0.133500177147133, 0.1446684700037752, 0.10463473426976375, 0.1719185584889991, 0.11222228926739522, 0.136664783049907, 0.15410563003804, 0.1370036977210215, 0.14997240182544502, 0.20375105179846287, 0.16952293632285936, 0.11702450551092625, 0.11250325704791717, 0.2530660948583058, 0.14082878961094789, 0.09098108299076557, 0.1772640845073121, 0.18448094225355557, 0.12567926038588795, 0.08386616156037364, 0.16569293183939798, 0.21013245651764528, 0.07837811604674373, 0.2314932138792106, 0.12829991190561227, 0.13787233111049446, 0.1194908581674099, 0.2586580647953919, 0.17803648806044034, 0.14978690392204694, 0.1284470861511571, 0.06946775703025715, 0.24951678674135888, 0.07535066242728915, 0.13395679050258227, 0.17460596428385802, 0.11314352269151381, 0.18511052775595868, 0.09352650533297233, 0.07961266980107341, 0.06716459883110863, 0.1847136119114501, 0.17035990926836217, 0.09828488142894846, 0.17834915699703352, 0.10864830283182007, 0.14070062791662558, 0.0739914889314345, 0.06524773061807666, 0.13748981377908162, 0.10833951511553355, 0.1277131691042866, 0.10648121125996113, 0.23349627639566148, 0.06611007398792676, 0.14307658613792487, 0.10957634874752589, 0.11031943958784853, 0.08417118340730667, 0.15894525391714914, 0.10424399987927505, 0.10273043252527714, 0.17443527201456682, 0.07369544410279819], [0.06184508106006043, 0.031924919957028966, 0.01835283197994743, 0.00452190706606156, 0.04898699851972716, 0.04871920110391719, 0.043630626119141064, 0.04266708603660975, 0.006015186223001885, 0.06367100522454296, 0.03379304221432124, 0.01367289453212704, 0.022971485841221044, 0.0390813066624105, 0.03252762868734343, 0.019945377417440926, 0.028014804236590862, 0.03893052939591663, 0.0789249949157238, 0.01278433681000024, 0.0076222154145528164, 0.04381422751716205, 0.03157036505373461, 0.03287921839260629, 0.03736485055248652, 0.04637532062562449, 0.051018308449004374, 0.026480495763410414, 0.052626290558172126, 0.0460151067402746, 0.045874096985374174, 0.005857487051149032, 0.05009386555424758, 0.037591443929289065, 0.006518207132882837, 0.027353164739906788, 0.012291076626362545, 0.056992246104138236, 0.04888183576986194, 0.0609877792053989, 0.028434389936072484, 0.024644079751202037, 0.04125328707907881, 0.04818520082959107, 0.044456308241933584, 0.03494394277887685, 0.018134604939924817, 0.021185885316559246, 0.012600680281008993, 0.03008398659793394, 0.038934895768761635, 0.050332024560442994, 0.03429091728425451, 0.05104825559205242, 0.029357055069080422, 0.059616208874753544, 0.03022527115951691, 0.09325813794774668, 0.024401540801461254, 0.06168065166899136, 0.04181875102221966, 0.0038832304666617085, 0.10236861051193305, 0.009777484361880591, 0.018472720636054873, 0.07666292879730463, 0.02443816133641771, 0.02978108517293419, 0.03243970751230206, 0.015410470044506448, 0.05364519909822515, 0.08534815667995385, 0.02494982423792992, 0.012272773992403277, 0.05351919514526214, 0.03158683988398739, 0.09528875577130488, 0.28574260430676596, 0.6423690478716577, 1.2302464140313012, 2.4014639726706912, 4.8175786563328336, 8.520219836916242, 8.534625189644949, 12.7755754504885, 12.717751673289708, 16.917863028390066, 17.136859825679235, 16.902868815830775, 20.317012105669292, 19.770736047199794, 23.23731391770499, 22.104695013591222, 26.323668990816387, 22.79404490334647, 21.482916355133057, 30.358180454799108, 29.60386664526803, 28.364441769463674, 25.623571974890574, 25.743907826287405, 21.568492106028966, 17.24430329459054, 11.267171910830907, 5.546433831964221, 3.159550436905452, 0.46751366768564495, 0.3088694933269705, 0.05221712376390185, 0.04490395475711141, 0.03599604185936706, 0.05312879662960768, 0.04571791858013187, 0.03184260008856654, 0.034879936570567746, 0.04578882548958063, 0.04606466693803668, 0.06685734460396425, 0.019672302695523416, 0.03702179342508316, 0.018848535737821033, 0.054406091304762025, 0.06089216683592115, 0.055348240570830445, 0.04962557461112738, 0.0100437202989789, 0.03911761846393347, 0.04108459309541753, 0.054995846801570485, 0.019620951165312102, 0.010989285140697445, 0.029195373744836876, 0.024437192727678587, 0.04085920751094818, 0.04487422474526933, 0.03821425086685589, 0.03657262699146356, 0.049318873390023193, 0.07009413306202207, 0.004752318050512778, 0.019583007487069284, 0.03854983053835375, 0.02577793212341411, 0.03732685259144221, 0.028485056145914962, 0.05592768233535545, 0.01666003977879882, 0.040828157748494825, 0.01402460043651185, 0.022252810387206928, 0.013798906118609011, 0.038948398615632734, 0.020303564179422598, 0.030946872795798948, 0.08181997135813747, 0.024085577577352524, 0.12017921837312834, 0.05660687892564705, 0.03429541936410325, 0.018235026426347237, 0.0830713188541787, 0.06768533374582018, 0.026845043791191917, 0.08678215901766505, 0.013171761645935476, 0.04540875766958509, 0.06702641517456089, 0.04258634376206568, 0.02712346876173147, 0.015469278674572706, 0.009985518957754331, 0.01856419224558132, 0.03125532802992633, 0.08566427935979196, 0.05559839607615556, 0.02139338811061212, 0.02832317635017846, 0.07974237855523825, 0.06031020092112677, 0.02563163997339351, 0.10354652016290597, 0.012784793972969055, 0.031217438634485006, 0.034970174942697795, 0.07008163444697857, 0.05237482887293611, 0.07216659614018031, 0.00406390949917425, 0.03596598615071603, 0.05165756307542324, 0.02536811393552593, 0.0335346187597939, 0.06315883342176676, 0.022470101048903804, 0.05597548173474414, 0.061302714448954375, 0.04432080479870949, 0.03242565844474094, 0.06130242267889636, 0.03429210811321225, 0.05903178666319166, 0.04911027476191521, 0.026448947277718356, 0.03294984371002231, 0.05130771381248321, 0.05111330674429025, 0.0223559154796281, 0.019540480304775492, 0.06575442664325237, 0.010101403409082974, 0.03353402164897748, 0.01572536627229835, 0.02193297442447926, 0.025463531226185814, 0.07778444540287767, 0.01612174098512956, 0.014241150646869625, 0.0047775341081433, 0.031147149191903215, 0.028626181251768554, 0.00852639555731522, 0.06525060082120554, 0.07416009809821844, 0.09074251007820879, 0.023511584449027265, 0.0375115566088685, 0.03962694041963134, 0.04619950880961759, 0.019998657683442746, 0.009197374240362217, 0.017711412826819078, 0.025438325346580574, 0.0345884277485311, 0.0406287125577884, 0.02521681589340525, 0.025211570817711096, 0.030081241923783506, 0.01803623093292117, 0.005115702814821686, 0.027031187999195287, 0.040895040945283005, 0.03142924334055611, 0.06540753918566874, 0.023042085713573864, 0.031207593091364418, 0.03959091021014111, 0.017017193471214602, 0.07305537523435694, 0.030851738793509345, 0.016749698003487926, 0.06561471628291266, 0.022151920711621642, 0.17637884058058262, 0.48661806540829794, 1.2772581428289413, 2.40975729908262, 3.6808485899652754, 7.207844955580575, 11.696768607412066, 12.848997933523995, 16.743458032608032, 17.136484622955322, 21.98332735470363, 23.305976016180857, 22.09083683150155, 26.05979551587786, 25.810928412846156, 28.662863424846105, 28.186121463775635, 30.357815674373082, 28.67010865892683, 27.90349653788975, 35.78490768160139, 35.35250391278948, 33.19770424706595, 31.118765013558523, 31.569595405033656, 26.098403181348527, 21.006044115339005, 14.36445563180106, 7.689793722970145, 4.3193628532545905, 0.8819578087755612, 0.45971100351640154, 0.08981477628861155, 0.06686132760452372, 0.06081925146281719, 0.027099333271118145, 0.0347398428379425, 0.056824664917907546, 0.059240483678877354, 0.0663510217730488, 0.05962579657456704, 0.026839454358975803, 0.03781922134969916, 0.04046941289146032, 0.030539236097995724, 0.026683723786845803, 0.07295312679239682, 0.04706132631482823, 0.014192554817002798, 0.028714010824582407, 0.034187976736575365, 0.010709547204896808, 0.03885730528937919, 0.06394845819366829, 0.017777748106579696, 0.03556817803265793, 0.052159312580313, 0.05181552942043968, 0.04555531444826296, 0.016491915764553205, 0.03422192384355834, 0.08162343368998595, 0.06772833250995193, 0.012570370121725967, 0.03240326339645045, 0.014504742841901523, 0.08637093965496336, 0.05259619753009506, 0.05916298140904733, 0.03828486939892173, 0.01400447593602751, 0.033090775433395586, 0.03300961585981505, 0.02748734164716942, 0.03190678950133068, 0.025754990854433606, 0.0046107166978929725, 0.015520204424059816, 0.006882308175720806, 0.055882644573492665, 0.021811099357104728, 0.03176808337281857, 0.0329347870179585, 0.03725083970597812, 0.05741864429520709, 0.11949695141187736, 0.02154006702559335, 0.038863547811550755, 0.04520576713340623, 0.0499972659163177, 0.03766661203865494, 0.04469409744654383, 0.036729120915489535, 0.062032051384449005, 0.04591989131378276, 0.013098543476579445, 0.033201207007680617, 0.05822713912597724, 0.021414261544123292, 0.025414215301030448, 0.18119531284485543, 0.08927401102014951, 0.19521411774413927, 0.19757965366755212, 0.20782627883766377, 0.11392716956990105, 0.08043999397861105, 0.1059905897293772, 0.10011579961116825, 0.09788135665335826, 0.16200375051370688, 0.10237819142639637, 0.16855261767549173, 0.12527844975037233, 0.16784419997462205, 0.0731426551938057, 0.12976995802351407, 0.11773865004735333, 0.13288961776665278, 0.14871027240795748, 0.11511096890483584, 0.08848874922841787, 0.13057970814406872, 0.11543775136981692, 0.10435268761856215, 0.15614799330277102, 0.15134173977587903, 0.099170091428927, 0.12130340162132468, 0.12792071939579078, 0.12686550244688988, 0.11387230322829314, 0.17733991758099624, 0.21436384160603794, 0.08124566610370364, 0.1543008852750063, 0.06675878060715539, 0.13905642900083745, 0.19611526653170586, 0.15493964457086154, 0.10477604597274746, 0.07986876927316189, 0.15062296763062477, 0.10049431358597108, 0.12890420162252017, 0.1845866444387606, 0.1562192937625306, 0.27667778357863426, 0.1225174500473908, 0.10217483448130743, 0.13998402708343097, 0.10479750125003712, 0.13219308799930982, 0.08723668248525687, 0.10968612892819302, 0.18244512006640434, 0.14071322152657167, 0.11688575867031302, 0.07165230052279574, 0.1273037546447345, 0.13767307251691818, 0.08195953922612326, 0.13132198474236897, 0.09208946994372777, 0.11112882329949311, 0.10728334821760654, 0.16206137170749052, 0.10486401803791523, 0.11582435348204204, 0.13542739301919937, 0.11742736532219819, 0.1310443960662399, 0.10598201304674149, 0.1318743529596499, 0.09838460572063923, 0.20367931707629136, 0.402169904006379, 0.8495770320296288, 1.3331009234700884, 2.6872572771140506, 4.434010735579899, 7.5605719941002985, 10.9312447479793, 13.978602187974111, 17.494766746248516, 18.402835505349294, 21.685008185250418, 23.788999148777553, 23.90157733644758, 29.304722377232142, 29.69507564817156, 30.473829746246338, 30.623500892094203, 33.24329137802124, 32.95755018506731, 32.211202485220774, 40.17618656158447, 40.022478512355256, 37.926616941179546, 34.77063396998814, 34.16271175657, 30.26259756088257, 24.813180991581508, 17.102153573717388, 8.956897616386414, 5.039100689547403, 1.3198219388723373, 0.4995037168264389, 0.19024129744086946, 0.18938133572893484, 0.12904535047709942, 0.07294693855302674, 0.1830554623156786, 0.11150138652218239, 0.142174880951643, 0.0926460043660232, 0.2179406439619405, 0.12325091926114899, 0.14574860275856086, 0.12826435667063507, 0.07891092888478722, 0.19506676707948956, 0.22497393084423883, 0.09765959783856358, 0.17221708675580366, 0.06330692368958678, 0.14540767962379114, 0.09123314517949309, 0.13588441349565983, 0.1292955670505762, 0.13343274433697971, 0.10816851072013378, 0.13199422295604432, 0.21745009028485843, 0.1314456138227667, 0.11498025591884341, 0.08626615349203348, 0.17911871070308344, 0.11011781969240733, 0.08019179265413966, 0.12552151456475258, 0.08851300006998436, 0.16187313252261706, 0.16814318964523928, 0.12303395090358597, 0.1830254439264536, 0.06575278458850724, 0.1071936119613903, 0.09438908619007894, 0.11344823919768844, 0.19008714785533293, 0.13147127601717198, 0.08672624773212842, 0.10612142485167299, 0.151957456022501, 0.11892934329807758, 0.2007546547268118, 0.15633955730923585, 0.17776895527328762, 0.1765675547399691, 0.130933496302792, 0.1653368773737124, 0.11080693307199649, 0.13198180576520308, 0.11774744386119501, 0.2179769727268389, 0.14076495303639344, 0.14846267497965268, 0.0959504224093897, 0.16207662517470972, 0.10706245114228555, 0.10021787163402353, 0.08572181912937335, 0.1442035785210984, 0.23514992051890918, 0.12236597388982773], [0.04231747765360134, 0.03555153017597539, 0.03247144598779934, 0.03799102641642094, 0.04192760500258633, 0.040606080022241385, 0.06644911758069481, 0.0395729459955224, 0.034344294241496494, 0.029764074300016676, 0.023399967134797146, 0.012598384288139641, 0.08906304769750152, 0.04116044652515224, 0.06259463833911078, 0.05243125584508691, 0.026209867160235132, 0.053863304001944404, 0.0404210231666054, 0.012593963632493146, 0.032194291574082205, 0.026462531548791697, 0.025952816042783003, 0.03287672477641276, 0.040957462774323564, 0.031320514889167886, 0.017107952618971467, 0.02822281762824527, 0.027587111739973937, 0.03276454258177962, 0.035788986898426495, 0.00475373406827982, 0.007305138544844729, 0.018214052908920815, 0.03609840565228036, 0.06445672842008726, 0.0796991762306009, 0.010021462654029685, 0.04112627210893801, 0.03864397727219122, 0.035885145488594256, 0.024762350101290003, 0.031166490832609788, 0.02513899471211646, 0.06203925742634705, 0.020629384821014743, 0.0022193464018138392, 0.03834847527156983, 0.07957093311207634, 0.026331574290192554, 0.0751983177449022, 0.013221024136458124, 0.03891198164118188, 0.061309845852000375, 0.005721007789751249, 0.017568194440432956, 0.010359759010108454, 0.018901580212903873, 0.05838484423501151, 0.05752340331673622, 0.05676892326612558, 0.040639738751841445, 0.029199797793158462, 0.010458881950138934, 0.038467300324035544, 0.04178796588842358, 0.02478536600912256, 0.018190433104921664, 0.0605667753677283, 0.0477983714081347, 0.024199047292183553, 0.06353212946227618, 0.0782310367961015, 0.07459349198532955, 0.028036486823111773, 0.03730872552841902, 0.016012269537895918, 0.03086690405117614, 0.03627077729574271, 0.06335683672555856, 0.038338738294052224, 0.14944884420505591, 0.3658310967896666, 1.3120910908494676, 1.6510180298771178, 1.910012892314366, 1.7718468776771, 2.4087984476770674, 3.2670321209090094, 3.068872536931719, 4.4393682309559415, 3.730374480996813, 5.312209623200553, 5.153696894645691, 6.427237859794071, 6.3627316526004245, 9.017367788723536, 10.923937848636083, 9.989070756094796, 9.323534948485237, 5.279323365007128, 4.49578195810318, 3.3106763618332997, 1.2046919167041779, 0.49275386759213036, 0.022536439721339514, 0.06388361738728625, 0.024814702470653822, 0.08773871018950428, 0.05193366575986147, 0.02466775044532759, 0.04847109816702349, 0.019656709960794876, 0.018851853774062226, 0.005973025449618165, 0.029252655671111176, 0.03179160478924002, 0.04487373620005591, 0.038580391755593677, 0.056220836604812315, 0.07862892294568674, 0.02603654726408422, 0.0849470067769289, 0.019568870209955742, 0.01735515140795282, 0.008107705524058213, 0.02605336475452142, 0.025114867703190873, 0.04319741204380989, 0.030420550145208836, 0.03250542702153325, 0.03938974154048732, 0.037351490197969336, 0.056029550797705135, 0.01197266558717404, 0.06799873550023351, 0.0682164231049163, 0.06421385359551225, 0.05988387058355978, 0.0034066384957571116, 0.01993301959841379, 0.017341658739106994, 0.020141440111079385, 0.035941100878907103, 0.07512493418263537, 0.028584983998111317, 0.027546910236456564, 0.03094444703310728, 0.039609715808182955, 0.024421275992478644, 0.03521227963002665, 0.029153983108699322, 0.04765465429850987, 0.04488446383870073, 0.029374951430197273, 0.12453633600047656, 0.034195922381643734, 0.019183988184002892, 0.024917388567700982, 0.01435317168943584, 0.014595951519108244, 0.02653626455659313, 0.053389649239501784, 0.00893895757118506, 0.03943701507523656, 0.040305899522666416, 0.014850715973547526, 0.010465434053912759, 0.013662071898579597, 0.019254964643291066, 0.02552966294544084, 0.14935606132660592, 0.03259791812992521, 0.08017077842461211, 0.03319150395691395, 0.03876780312774437, 0.051966469535338025, 0.07159892017287867, 0.015257585926779678, 0.07477120030671358, 0.029577127724353756, 0.07552598230540752, 0.030601417047104666, 0.03733591442661626, 0.033682627603411674, 0.009279426087492278, 0.03968991186203701, 0.042450368737003634, 0.03811867920947926, 0.04610796765025173, 0.02227700694597193, 0.0580896543604987, 0.02620491724727409, 0.04593938562486853, 0.012483860299523388, 0.017727736683030213, 0.03734683205506631, 0.07724129169114999, 0.0196680923857327, 0.02159635489806533, 0.017655448954818503, 0.007149189145171216, 0.054747747257351875, 0.023381387149649005, 0.06216413501117911, 0.013821553073025175, 0.04951385721298201, 0.03498284997684615, 0.028357657803488628, 0.021057872899941037, 0.019336270101900612, 0.05722855270973273, 0.031832316890358925, 0.03273313658844147, 0.04716412437015346, 0.07459250810955252, 0.03476898930966854, 0.025747779723522917, 0.0327842302753457, 0.025311856597129787, 0.027781249090496982, 0.008691429692719663, 0.02256907895207405, 0.05903066708041089, 0.032010452688804696, 0.03187729697674513, 0.04086706155378904, 0.08001673061932836, 0.04307743687448757, 0.0031420458856570932, 0.01507235604471394, 0.07354185770132712, 0.03546702203207782, 0.015351001539134553, 0.012565856167514409, 0.07551287979419742, 0.0031357060361187905, 0.004962277565417545, 0.0691690727003983, 0.012621542688326111, 0.06339333512421165, 0.028108029859140515, 0.044643719614084275, 0.07332935410418681, 0.081235237020467, 0.04213609845776643, 0.0394539105972009, 0.06118069349655083, 0.0470422119833529, 0.04604944061221821, 0.04586103518626519, 0.0388658344745636, 0.017968168781538094, 0.02937438146078161, 0.015930029397298182, 0.10416331528020756, 0.02674628301922764, 0.30271466502121513, 0.8253827531422887, 1.8477987221309116, 2.445700547524861, 3.2383727559021542, 2.981994215931211, 3.867979211466653, 5.180668498788561, 5.170213631221226, 6.06226418699537, 5.666158241885049, 6.801595074789865, 7.879681042262486, 8.182010190827505, 9.059881210327148, 11.414002980504717, 13.736758845193044, 12.572544745036534, 11.277722750391279, 6.830276370048523, 5.59446325472423, 4.078008055686951, 1.6834504838500703, 0.6031751281448773, 0.11593754669385296, 0.05510875842134867, 0.016350459872878025, 0.05997319293341466, 0.011792413607638861, 0.05099546217492648, 0.01491637441462704, 0.039365446594144614, 0.04971352292756949, 0.03788403162200536, 0.01517178347733404, 0.01462255178817681, 0.04115413275680371, 0.026473079375656586, 0.04710977032248463, 0.04555222372125302, 0.03948214443932686, 0.048339051859719415, 0.059121380427054, 0.009740433805356068, 0.01044057253082948, 0.015308815320687634, 0.04516609658354095, 0.04888319283989923, 0.023100907914340496, 0.05185184122196265, 0.0929568073313151, 0.012271981802769005, 0.016264426721526042, 0.016335048646266972, 0.08006760038967643, 0.02071641881151923, 0.1224835640085595, 0.08414127358368464, 0.03443594057379024, 0.042536050746483464, 0.010230873827822506, 0.017943722861153737, 0.02361373959242233, 0.015431462221645882, 0.06450155922876936, 0.03873473472361054, 0.032798879846398316, 0.02998022163020713, 0.05172431395788278, 0.02324639430402645, 0.10890134211097445, 0.02238832740113139, 0.03859848489186593, 0.017563295417598317, 0.048813103565147946, 0.038056610218648396, 0.04301805827500565, 0.037478081083723476, 0.04757613083347678, 0.04196591169706412, 0.004991070774849504, 0.0645654500861253, 0.023309114688475217, 0.03709615407777684, 0.041311641090682576, 0.02133957010560802, 0.025811977617974793, 0.017196426800053035, 0.05651938522766743, 0.008670265337319245, 0.03264910341905696, 0.02784646818015192, 0.021283450170553157, 0.020623978593253663, 0.010041364086126643, 0.1345749223338706, 0.1141275545316083, 0.1335383786686829, 0.24880277791193553, 0.21696159935423306, 0.1427583803555795, 0.08271209562995605, 0.1254382718886648, 0.14082045720091887, 0.10222022168870483, 0.15712371308888706, 0.12340900434979371, 0.15550406357007368, 0.16868174288954052, 0.14626423508993217, 0.2191514354199171, 0.19963640187467846, 0.1158481700611966, 0.14829038136771747, 0.10593950961317335, 0.14041638959731373, 0.1620452090033463, 0.06698847149631806, 0.11624428523438317, 0.10754754939781767, 0.0871892800288541, 0.17122004739940166, 0.12176578252443246, 0.18889299407601357, 0.09217933512159757, 0.11528512170272213, 0.12460709363222122, 0.13472401004816803, 0.07112953678837844, 0.07488611021212169, 0.25057668558188845, 0.21940402686595917, 0.05807534405695541, 0.1561862626778228, 0.17100177625460283, 0.1501661507146699, 0.09670645291251795, 0.09143659033413444, 0.0959418864388551, 0.16812005160110338, 0.08922825740384203, 0.09033402521163225, 0.11474956758320332, 0.1204089160476412, 0.0898431594084416, 0.1695793904364109, 0.20325661690107413, 0.11709229115928922, 0.18054752903325216, 0.11814144200512341, 0.12075433108423438, 0.2041948815541608, 0.06886215774076325, 0.07932784794164555, 0.22148304459239754, 0.11414725918854986, 0.10318068800760166, 0.14797620608338288, 0.2616099906819207, 0.14413936196693353, 0.14496504408972605, 0.14793275270078862, 0.11392421115721975, 0.17093365133873054, 0.10282349360308476, 0.1223253703543118, 0.20748592567230972, 0.12705440659608158, 0.2472463000033583, 0.09783373028039932, 0.14150619826146535, 0.08360189252666064, 0.13823118114045688, 0.14941148406692914, 0.17558350254382404, 0.21789295652082988, 0.42520472939525333, 0.7343110857265336, 1.604163721203804, 2.312383289848055, 3.078050455876759, 3.5943641449723924, 3.820706708090646, 4.521512874535151, 5.297579756804875, 6.083413200719016, 6.264132806232997, 7.332092642784119, 7.8454741920743665, 8.959606545312063, 9.911131943975176, 12.531340190342494, 14.228315234184265, 14.148055723735265, 12.450812305722918, 8.10537156036922, 7.186920889786311, 5.17251261643001, 2.3684161688600267, 0.8513587564229965, 0.18774667701550893, 0.1448183583893946, 0.09317643554615122, 0.11573127204818384, 0.10108436763818775, 0.16846611803131445, 0.16527632490864821, 0.13071097752877645, 0.16918889353317873, 0.11814326047897339, 0.09623089485934802, 0.1358770988881588, 0.1398463523281472, 0.10735388871814523, 0.10212004277855158, 0.1869894183639969, 0.12871741450258664, 0.12801928339259966, 0.13089339488318988, 0.1919738280453852, 0.1202528937054532, 0.1200987169785159, 0.14092028327286243, 0.12166275376720087, 0.08366370028150932, 0.11352443868028265, 0.24704265807356152, 0.08865321254623787, 0.11011033545115165, 0.08490434049495629, 0.1410387283457177, 0.19968526996672153, 0.2846176746700491, 0.13504978828132153, 0.07919729101870741, 0.12337681464850903, 0.17918589924063, 0.15114826230066164, 0.15496021775262697, 0.16404197471482412, 0.26537301018834114, 0.14712385753435747, 0.10268167299883706, 0.08660919365606137, 0.08561572339385748, 0.1286994061831917, 0.1894209621740239, 0.11041007151028939, 0.10297540402305977, 0.07723969713385616, 0.2414555735886097, 0.16272216982075147, 0.10783582500049047, 0.11145113421870129, 0.09905082532869917, 0.14119732912097657, 0.09562898001500539, 0.1313621268740722, 0.14460748327629908, 0.20838782084839685, 0.17296058471713746, 0.09775778864111219, 0.12132142351141997, 0.09211278440696852, 0.13487377629748412, 0.07167683634907007, 0.18698960835380213, 0.12370446563831397, 0.14853343261139734, 0.0876905545592308, 0.11102002020925283], [0.022713013192904846, 0.0026798594252405955, 0.028193867931674634, 0.05870612378099135, 0.03236038676862206, 0.06927899537341935, 0.03390667647389429, 0.02123790011475129, 0.035661588556000164, 0.035382700485310385, 0.046273078969014544, 0.053373411896505525, 0.08215565620256321, 0.02692248499287026, 0.03905465041420289, 0.0027227869431953877, 0.032210410173450194, 0.039299099440021176, 0.05547935389248388, 0.01894677064514586, 0.029416918821100677, 0.058333262002893856, 0.024222187032657008, 0.017729880853689144, 0.028217930479773452, 0.07019419662122216, 0.0155443857157869, 0.03019054712993758, 0.05268816277384758, 0.07047730857240302, 0.006884027413824307, 0.027793632354587317, 0.007571187036644135, 0.09321222148303475, 0.01629651803523302, 0.04114297764109714, 0.002231066185881251, 0.016259938212377683, 0.058774682959275584, 0.019187060251299824, 0.04330329743346997, 0.03907812433317304, 0.05269957912553634, 0.08755312407655375, 0.03417487083269017, 0.052620190528354475, 0.023972107862521495, 0.008431493953269507, 0.0708484197301524, 0.05595408413293106, 0.018824086424761584, 0.018970622847388898, 0.039269664590912204, 0.11313190617199455, 0.06317452793674809, 0.04690408260960664, 0.03494887572846242, 0.08016456982919148, 0.026541156794077585, 0.029531811763133322, 0.021696808614901135, 0.09124463956270899, 0.009175001244459833, 0.01534095752452101, 0.01938613733675863, 0.026200459272201573, 0.014571373284395252, 0.02552043995819986, 0.021711056153955202, 0.014217982068657875, 0.06402213352599315, 0.041407307742961814, 0.04959660455850618, 0.007252608060038516, 0.01619396934152714, 0.008940262902927185, 0.011753698943981102, 0.031912404378609996, 0.016255877180291072, 0.04202590437073793, 0.030618119186588695, 0.04823106640417661, 0.01128463277460209, 0.03983076216120805, 0.02110167233539479, 0.04168852658144065, 0.0753683518352253, 0.09239500069192477, 0.05201784481427499, 0.03849208042291658, 0.14622029316212448, 0.22133892375443662, 0.047917043790221214, 0.08327078779361077, 0.21771235764026642, 0.26673176299248424, 0.5041736119559833, 0.33586905311260906, 0.8327700995973178, 0.5910272342818124, 0.30887869426182335, 0.08884851528065545, 0.06044351948159082, 0.047600530952747376, 0.0020876743489809868, 0.059791141987911293, 0.04606817835675819, 0.03997822478413582, 0.021823655647624816, 0.019333174285878028, 0.029337313092712845, 0.04021963397307055, 0.03813096408599189, 0.025707608754081384, 0.050861281874988756, 0.015623333265206643, 0.05792003417653697, 0.03893586268116321, 0.037577262547399314, 0.02671531807365162, 0.03980254867513265, 0.038250440532075505, 0.013169198479902531, 0.054183976259082556, 0.03981612276818071, 0.0812825309112668, 0.008593136261749481, 0.038641744891979864, 0.03461399834070887, 0.031720650382339954, 0.045569373693849356, 0.03538756897406919, 0.03731198249650853, 0.018815508045788323, 0.09971397117312465, 0.0370065603139145, 0.01426155080220529, 0.03596727875992656, 0.06103900859930685, 0.003282928839325905, 0.02069201529957354, 0.05802920367568731, 0.016440839041024446, 0.040966500860771964, 0.04077777652336018, 0.012500694753336055, 0.038514947053045034, 0.029359779387180294, 0.008887812994154436, 0.017184828940246786, 0.009329345060645469, 0.06251575185784272, 0.007350581731381161, 0.06443106622568198, 0.013873318509597863, 0.08041867440832512, 0.042383512681616206, 0.03644978840436254, 0.022870687767863274, 0.05332700688658016, 0.07245808799884149, 0.03959968706060733, 0.014386112868253673, 0.031146772604967867, 0.016239449847489595, 0.021017857993553792, 0.03621582952993257, 0.005285897633127336, 0.03757404629141092, 0.02783576937924538, 0.0199557573068887, 0.025606544355728796, 0.04159220175019332, 0.012578207201191356, 0.032838095777801106, 0.05777064112148114, 0.02158311498351395, 0.07919219522071735, 0.03204336502988424, 0.08105733870927777, 0.08390076006097452, 0.04135414452425071, 0.1234089093548911, 0.03211705732558455, 0.03542843035289219, 0.0455242714711598, 0.05111215662743364, 0.05427585329328265, 0.03840144510780062, 0.08484912131513868, 0.0606671306969864, 0.023635057466370717, 0.013794011336618235, 0.032707141911877055, 0.01439628580452076, 0.015397457439186317, 0.10530939485345568, 0.05749681831470557, 0.024073121370747685, 0.00794421844849629, 0.010167427410903786, 0.01203604245425335, 0.02160253974476031, 0.00886324408929795, 0.020000937561105405, 0.038191849033215215, 0.017373992629083138, 0.016629990855497972, 0.05136008993057268, 0.02260991488583386, 0.030901309169296707, 0.03818367947159069, 0.038086055245782645, 0.03651051050318139, 0.03153307616178479, 0.0427476858187999, 0.017968017807496444, 0.01023942930623889, 0.03444521275482007, 0.05944105863038983, 0.015342127997428179, 0.038882400907043896, 0.055201388629419465, 0.09380597355110304, 0.049030872594032965, 0.042490734785263023, 0.09227652169231858, 0.017840687318571975, 0.03978615866175719, 0.06069149010415588, 0.08628019916691951, 0.009255165067900504, 0.014837738991315876, 0.04352286458015442, 0.0066663381128039744, 0.08325688461107866, 0.02002742587189589, 0.0751945043780974, 0.038135276176035404, 0.027225735863404613, 0.020877954250733768, 0.029639013510729586, 0.08368440238492829, 0.032000250914799314, 0.023495330142655542, 0.057342058047652245, 0.023520118723224317, 0.02173999397616301, 0.03580604526879532, 0.008742755777867777, 0.03527992278603571, 0.03615108371845313, 0.03235162688153131, 0.04157100431621075, 0.034488757739641836, 0.04643195455095597, 0.04089455918541976, 0.04854828831074493, 0.020179012291399494, 0.022012705681845546, 0.034443278930016925, 0.07592389559639351, 0.18097481610519545, 0.1639933373246874, 0.1564877222159079, 0.151995806821755, 0.37767658116562025, 0.3020046731191022, 0.28109605078186306, 0.24082844438297407, 0.388369370251894, 0.5414005400879043, 0.7234385120017188, 0.8521701214568955, 1.1199752454246794, 0.7918310963681766, 0.47464311655078617, 0.19681886663394316, 0.07187825268400566, 0.07088326250336, 0.029318992647209337, 0.03852047372077193, 0.046238131022879055, 0.054462643805891275, 0.005799208950650479, 0.008987898605742624, 0.041206016937004666, 0.02304877606885774, 0.014801890289943134, 0.03196783729695848, 0.03603765980473586, 0.05720460720892463, 0.03418263327330351, 0.06636882653193814, 0.03441921807825565, 0.030017459632030556, 0.013298227002711167, 0.0037146302056498826, 0.01967349013180605, 0.034842817312372584, 0.03545667437304344, 0.11281350361449377, 0.0375106982620699, 0.026536980411037803, 0.014848251195092286, 0.05292447277211717, 0.024112335605812923, 0.045497985024537356, 0.049487753970814605, 0.055840287024953535, 0.020140098308080008, 0.09569817023085696, 0.022335257480985353, 0.03405017645231315, 0.08011685524668012, 0.03346909602571811, 0.054579918405839374, 0.09400567319244146, 0.05070083209180406, 0.1181790464158569, 0.01414480121872787, 0.03203828280259456, 0.07839725073426962, 0.026574661156960895, 0.05298065207898617, 0.04197669361851045, 0.03071882056870631, 0.07014066699360098, 0.058408816877220354, 0.02306516608223319, 0.009727108225758587, 0.10919489671609231, 0.044382673621709855, 0.008138250626091446, 0.018047063744493892, 0.02048116732787873, 0.057482996556375704, 0.04523239963288818, 0.021973806965563978, 0.004751536887072558, 0.012152163544669747, 0.031192292126693895, 0.03499495164890375, 0.06565766076424293, 0.015757620434409807, 0.037819513119757175, 0.04610946721264294, 0.007934706235703613, 0.04719361010938883, 0.03228483867964574, 0.00653782400435635, 0.05796384039734091, 0.18972626222031458, 0.12521776157830442, 0.13618001049118383, 0.14801860095134803, 0.14729828174625123, 0.11030421326203005, 0.3145497813820839, 0.07673221400805882, 0.14189516167555535, 0.12233831680246762, 0.15327077412179538, 0.1728819967912776, 0.1713660138526133, 0.12458022364548274, 0.10147277465356247, 0.125534447442208, 0.16426229503537926, 0.06917437205889396, 0.08886825386434793, 0.06560668921364204, 0.15487720577844552, 0.09782880411616393, 0.16149588062294892, 0.09077700679855687, 0.07207966223359108, 0.1428178743060146, 0.06814460017319236, 0.06977967279297964, 0.12962191525314534, 0.20839848741889, 0.1082076554053596, 0.06932729349604674, 0.08600545355251857, 0.11692458444408008, 0.14589269645512104, 0.08618216442742518, 0.08548569572823388, 0.17886577998953207, 0.1272149479814938, 0.1422945066754307, 0.09896518063864537, 0.1670344498540674, 0.17788206706089632, 0.10203774326613971, 0.1342893133738211, 0.12568801348762854, 0.16372131263571127, 0.2302946224808693, 0.16770168047930512, 0.17854903984282697, 0.20176989239241394, 0.14965743944048882, 0.07283109905464308, 0.12731386481651238, 0.24787410774401256, 0.06362573336809874, 0.09723723693085567, 0.25112857882465633, 0.11616035045257636, 0.14547480030783586, 0.20460163615643978, 0.21410157425062998, 0.13983770779200963, 0.06411465177578585, 0.12438823894730636, 0.11308373018567051, 0.20241459565503256, 0.0759387080158506, 0.08696458994277886, 0.12354708622608866, 0.09927231272948639, 0.10155856862132039, 0.11205165128090552, 0.11131534579076938, 0.08860657004905598, 0.1521550997027329, 0.09035286134374992, 0.06560555606016091, 0.0810135460591742, 0.12836241855153016, 0.11456615956766264, 0.09220405415232692, 0.08411941797073398, 0.13272113752152237, 0.13812866806983948, 0.195758547101702, 0.19997887206929071, 0.2026749766830887, 0.3174956004534449, 0.20448613592556544, 0.46664715132543017, 0.45390928483435083, 0.3377289447401251, 0.2915366691138063, 0.47398097493818825, 0.6291217101471764, 0.9741379852805818, 0.9713460036686489, 1.1957838918481554, 0.9207015612295696, 0.5944602957793644, 0.3106225835425513, 0.20390383074326174, 0.29058194320116726, 0.1314773964030402, 0.11801784006612641, 0.12745767352836473, 0.17524628421025618, 0.05058997304045728, 0.10130561076636825, 0.11514379642903805, 0.14038837967174395, 0.1395460870116949, 0.08456976166261093, 0.13241452111729554, 0.12471974401601724, 0.16826077976397105, 0.14373616288815225, 0.16242322086223535, 0.10737541863428694, 0.11252657829650811, 0.1268965114972421, 0.09526136331260204, 0.12611663048820837, 0.2535849298749651, 0.17317083557801588, 0.08213877425129924, 0.12319038036678519, 0.17830246021705015, 0.1279767799590315, 0.08389096880065543, 0.11174005442964179, 0.10178538252200399, 0.10779981514705078, 0.17355099160756382, 0.17164953292480536, 0.09968370851129293, 0.06153975387236901, 0.12301020217793328, 0.07059000645365034, 0.11307646307562079, 0.1399945986590215, 0.1210575412426676, 0.19037758798471519, 0.12718562169798783, 0.12049181945621967, 0.13684273564389773, 0.1304644386151007, 0.07129836987171854, 0.06256272005183355, 0.10513881793511765, 0.1544478695307459, 0.16459751847599233, 0.0936082416613187, 0.08981428774339811, 0.340195853795324, 0.0799512927021299, 0.10780064974512372, 0.09189437076981578, 0.15946877082543714, 0.1358447734798704, 0.13080335328621523, 0.14151202009192534, 0.10862626401441437, 0.08921222362135138, 0.08816189212458474, 0.1035852102296693, 0.13653306583208696, 0.07600647330816303, 0.16971109408353055, 0.21236023626157216, 0.08928194309451751, 0.0820538488083652, 0.10963631767247405, 0.07292267414075987, 0.07481114566326141], [0.09092934469559363, 0.06377112985189472, 0.0317692233116499, 0.034440232307783196, 0.022644611774012446, 0.022165026615506837, 0.00980171315105898, 0.07881303663764681, 0.021825904991211634, 0.028330280611823713, 0.018020008856962835, 0.04331426934472152, 0.034291972406208515, 0.032327993506831784, 0.027858198354286805, 0.03951509749250753, 0.009700072846109313, 0.06534473398434264, 0.01824248691887728, 0.017444244752238904, 0.014885119395330548, 0.06096147918807609, 0.007223049378288644, 0.04905948980844446, 0.027035571335415755, 0.1154844481498003, 0.01757504085877112, 0.02941854391247034, 0.04150944083396878, 0.03816295361944607, 0.030453788183097328, 0.04712079990921276, 0.06271807064435311, 0.015154546991522824, 0.018270437472632954, 0.07066378356622798, 0.030570167116820812, 0.039964650691087754, 0.03384795944605555, 0.03700446364070688, 0.03578518031697188, 0.05952405024852071, 0.06451600523931639, 0.049264068116566966, 0.03145306670506086, 0.020493338549775735, 0.09690681073282446, 0.016212579860751117, 0.018666383012064865, 0.018309146199109297, 0.039218146819621325, 0.03037684570465769, 0.06845494173467159, 0.0026609128191401915, 0.07165211053299052, 0.014528737536498477, 0.03519118736897196, 0.043624902676258764, 0.026787412419383014, 0.0028848630900029093, 0.047238929463284354, 0.01806660894570606, 0.051925947424024343, 0.025975077080407312, 0.023549892839842608, 0.02119633136317134, 0.024326220021716187, 0.0587769356955375, 0.018403795048860565, 0.04207575633855803, 0.08296031731047801, 0.046801888450448, 0.02991029859653541, 0.032795046123542955, 0.03408571472391486, 0.07134050011102643, 0.01949959178455174, 0.021034478708835583, 0.012245538444923503, 0.0757845448596137, 0.026413729613912956, 0.056574465307806215, 0.050191306575600586, 0.03554227156564593, 0.027995092794299126, 0.01477656397037208, 0.028178992747728313, 0.021224568597972393, 0.0279435224365443, 0.019954237388446927, 0.014187163008110864, 0.02863342800576772, 0.06407216869826828, 0.012482750894767898, 0.009287493868864008, 0.04863389568137271, 0.03330196267259972, 0.01813784833731396, 0.03159994239519749, 0.023224677790754607, 0.007159347662569157, 0.029716166335025003, 0.015906794661922113, 0.034024887452168126, 0.02688281105032989, 0.039205034130385945, 0.024122440688578144, 0.0157917100337467, 0.024591393203341534, 0.028375304802986126, 0.05620592919045261, 0.02253659748073135, 0.014871870999091437, 0.041751620160149674, 0.02276989139084305, 0.041666952560522726, 0.05010818264314106, 0.061144731140562465, 0.019220403462116207, 0.018772086893607463, 0.018493258194731813, 0.03174239742968764, 0.036283713565873246, 0.018640993928004588, 0.04686593197818313, 0.006338829191268555, 0.07313855005694286, 0.023070263576560786, 0.035216350840138536, 0.045129072320248396, 0.01884832539196525, 0.02584294425988836, 0.01749709414850388, 0.0359124870571707, 0.020635157457685897, 0.04702378297224641, 0.02145313311900411, 0.017760314845613072, 0.03323332207011325, 0.007205218326167336, 0.033965396894408126, 0.025738276840586747, 0.06814692076295614, 0.04709534466798816, 0.04046998286087598, 0.03673348728833454, 0.03610806120559573, 0.01161792832759342, 0.02141387477916266, 0.05501776348267283, 0.0626236932086093, 0.02014777423547847, 0.018948144678558623, 0.0670337840648634, 0.0240156579363559, 0.030996365140059164, 0.07091346409704004, 0.03594413732311555, 0.03654053567775658, 0.04330169269815087, 0.0366062416162874, 0.027756928699091077, 0.025686133120741163, 0.04081819685442107, 0.006690826017542609, 0.056892348786017725, 0.015907390076400976, 0.03920714098161884, 0.028661071522427455, 0.02305664537873651, 0.02720120342980538, 0.034146650561264584, 0.019728322546663027, 0.021607070662347332, 0.011784728350383895, 0.063074572943151, 0.03272782705192055, 0.00985941237636975, 0.04518589623538511, 0.021370842088279978, 0.040085847223443646, 0.04131548499156322, 0.013228612702472933, 0.03815026501459735, 0.027331117440813353, 0.0776961747823017, 0.018721968600792543, 0.015741520494754826, 0.06505070440471172, 0.005769871640950441, 0.02496417864624943, 0.029089685130332197, 0.04564557996179376, 0.020570309865953665, 0.01595831921856318, 0.06036006645964725, 0.013842187322942274, 0.051505927462130785, 0.05798672738351992, 0.009341846220195293, 0.007203310794596161, 0.03451009766597833, 0.01980207421417747, 0.028387516736984253, 0.007585175884222346, 0.0291542443446815, 0.0231147381543581, 0.056949593392865996, 0.08621866961142846, 0.02004995832352766, 0.03335297154262662, 0.03461022229333009, 0.0013428734943902651, 0.016685930978772894, 0.07974655833095312, 0.03353956188740475, 0.003948414781396943, 0.05079862255869167, 0.029575607805911983, 0.08278599487883703, 0.023752605176663825, 0.035187594526048215, 0.0714763088950089, 0.02951264993420669, 0.04912840861028858, 0.019624937558546662, 0.019537608405309062, 0.03147351435784783, 0.024181983832802092, 0.0335198572304632, 0.07772050704807043, 0.05029656432036843, 0.028536428032176833, 0.048994116352072785, 0.008587719855963119, 0.011723436282149382, 0.02525091397442988, 0.009973915160766669, 0.06249604720090117, 0.035597911437175105, 0.06239745606269155, 0.05223470799891012, 0.010045711799258632, 0.0274781644610422, 0.05777181498706341, 0.038746938175920925, 0.04037892346137336, 0.02975212869101337, 0.059528433584741185, 0.025797377240711024, 0.043845239960189374, 0.00074045192221612, 0.026471651059442332, 0.024097670767722384, 0.0256621418188193, 0.02451575011946261, 0.0640303370143686, 0.03351712951968823, 0.0061834043839813346, 0.03849255200475454, 0.026683752624584094, 0.025192777094032084, 0.06333373260817357, 0.025855583670948232, 0.022017138211854866, 0.06720499202076878, 0.0207573005463928, 0.013421410794502922, 0.060934514206434996, 0.03984954061784914, 0.03677232663280197, 0.019960878549941947, 0.03706417472234794, 0.020297296212187836, 0.02547181783510106, 0.03591559135488101, 0.06247090747846024, 0.042201634762542586, 0.06454259024134704, 0.038626220010753186, 0.023367402542914664, 0.07132133828209979, 0.02610535071497517, 0.016899123288957135, 0.01768798810163779, 0.051983178460172245, 0.027915174939802716, 0.014515612972900271, 0.04012384518448796, 0.03357179569346564, 0.014519277062000973, 0.0542593072168529, 0.012070967499831957, 0.03084940802572029, 0.06271905452013016, 0.05522259624142732, 0.04740056668275169, 0.022597182176208923, 0.025760520914835588, 0.007627664050752563, 0.03719782915764621, 0.03904014333550419, 0.05033413819702608, 0.026499431979443346, 0.02526019124447235, 0.0403834730386734, 0.016365262114309838, 0.09259888689432826, 0.07506571164620773, 0.03284639426107917, 0.07650666896786008, 0.09450484426426035, 0.02645775975127305, 0.030945949988173585, 0.06953225178377968, 0.05397234118676611, 0.024195261066779494, 0.03825961093285254, 0.04422180653948869, 0.06455833225377969, 0.024986997778926576, 0.03488521218033774, 0.018349410467115895, 0.03332019490855081, 0.04124370616461549, 0.06624799301581723, 0.04868713014626077, 0.041312553720282655, 0.008720371755771339, 0.016798399854451418, 0.006884246665452207, 0.04780581832996436, 0.045601624463285716, 0.017920751058097397, 0.01652223610186151, 0.03748738379882915, 0.026434789644554257, 0.008746867700080787, 0.03960026381537318, 0.06560575283531632, 0.022251402427043234, 0.03233879578432866, 0.03320188893537436, 0.018163322238251567, 0.04672948537128312, 0.029800891610128537, 0.05304671424840178, 0.003380304339641173, 0.047517712361046245, 0.030726962988930087, 0.011924233453880464, 0.020484831416979432, 0.22903276447738918, 0.15753490531018802, 0.17687160628182547, 0.07417368915464197, 0.14543524171624864, 0.20420956505196436, 0.08660985183502946, 0.14362702731575283, 0.08957306175891842, 0.15705093342278684, 0.08329463151416608, 0.12452188320457935, 0.18857024210904325, 0.08390334527939558, 0.14462823287716933, 0.13167662785521575, 0.12852059863507748, 0.1416985357978514, 0.09017231674598795, 0.13697312293308123, 0.08364966817732368, 0.13764985304858002, 0.10272364038974047, 0.1431483615721975, 0.11816694135112421, 0.2804357005017144, 0.12066829284386975, 0.15283249478254998, 0.1170987779540675, 0.12086076608725957, 0.10289505869150162, 0.11581671317773205, 0.12130706571042538, 0.10937060335917131, 0.04772281653380819, 0.18965246475168637, 0.09523066638835839, 0.11669908011598246, 0.20301058010331222, 0.10711822672081844, 0.14327270989971502, 0.11046859515564782, 0.14105232618749142, 0.08515324749584709, 0.12157385210905756, 0.16617619805037975, 0.11648717362965856, 0.12622577963130815, 0.0853218702333314, 0.1373813838831016, 0.14951266720891, 0.10405962155865771, 0.18188535581742013, 0.13240477735442774, 0.1223609120185886, 0.137426370754838, 0.0924171277188829, 0.13893653186304228, 0.08610616171998636, 0.0656097222651754, 0.16719245351850986, 0.14420697119619164, 0.1821807085403374, 0.12044843392712729, 0.12383637284593922, 0.12257745968444006, 0.14887838624417782, 0.1061200609962855, 0.11338973590838057, 0.1288904273616416, 0.1872840111276933, 0.1013508690521121, 0.23752764293125697, 0.1124012732346143, 0.1332998193268265, 0.10469662344881467, 0.18632030141140732, 0.07698262057134084, 0.06469011732510158, 0.11662113001304013, 0.17153980024158955, 0.10713860991277865, 0.10628098914665834, 0.15981597719447954, 0.19942346401512623, 0.16690440183239325, 0.17447214360748017, 0.11731026374867984, 0.11362007819116116, 0.13762972769992693, 0.16023566467421396, 0.09370306693017483, 0.19398233241268567, 0.13219733562852654, 0.10309691607419934, 0.2107331228575536, 0.18197178760809557, 0.16822796581046923, 0.1199466979929379, 0.1127945657021233, 0.15678751255784715, 0.1039290985624705, 0.15273345581122807, 0.10534027498215437, 0.09707758442631789, 0.13916931008653982, 0.09853554583553757, 0.1580944659986666, 0.07225059199013881, 0.1847673247435263, 0.10280116980097123, 0.08432210995150463, 0.16915116698614188, 0.14607230467455729, 0.07128625123628549, 0.10938885595117297, 0.0928904398211411, 0.16507121734321117, 0.10332173508192811, 0.1634737287781068, 0.07711427672100918, 0.0699641936059509, 0.09273177119238035, 0.12697773213897431, 0.1126655897657786, 0.07617593742907047, 0.24143038636871747, 0.12230988618518625, 0.1012959009302514, 0.14437528859291757, 0.0780528127881033, 0.19130996295383998, 0.12115024269691535, 0.09311859722116164, 0.17303244157561234, 0.19247408477323397, 0.15793168544769287, 0.12363981482173715, 0.1536134071648121, 0.1037611204332539, 0.10635902067380291, 0.06497388066990034, 0.13698270384754452, 0.1382586346673114, 0.1571545728615352, 0.1343351144875799, 0.11936679482460022, 0.13452329938965185, 0.10991653227912528, 0.15614356925444944, 0.19618379856858933, 0.1263579446822405, 0.06970979047140904, 0.12801585000540527, 0.0742859256320766, 0.19097662584057876, 0.1070880319124886, 0.11440603887396199, 0.1642611279551472, 0.15848949551582336, 0.18124230818024703, 0.1248183080128261, 0.1086836816476924, 0.26645994186401367, 0.06414659720446382, 0.1287740043231419, 0.1376702090991395, 0.1509274805762938, 0.12590138560959271, 0.15660764649510384, 0.12560747138091496, 0.10616016241588763, 0.1306701840034553, 0.09445776071931634, 0.08216035845024244, 0.17878274087394985], [0.06227063786770616, 0.0123474764571126, 0.03537593888384955, 0.031037603105817522, 0.04430038767999836, 0.04910143684329731, 0.023975234212619916, 0.014129778453414994, 0.054002196727586646, 0.05549707383449588, 0.018828142367835556, 0.01596404266144548, 0.03944886229666216, 0.02789622515306941, 0.0768976408456053, 0.04711015369477017, 0.043537582004708905, 0.07875036714332444, 0.01671904348768294, 0.06997913494706154, 0.07762125773089272, 0.027657453769019673, 0.07212127678628479, 0.06433833763003349, 0.041114815045148134, 0.012927396588825753, 0.007866915498327996, 0.010349308722652495, 0.0373110936156341, 0.07786021740841013, 0.05772733023124082, 0.030994909682444165, 0.06716458526040826, 0.054330641603363414, 0.012266374559008648, 0.021573352560933148, 0.025709093049434677, 0.015799745584705045, 0.059446100145578384, 0.01685779372097126, 0.01610728140388216, 0.05553689705474036, 0.03319616888516715, 0.05397245653771928, 0.008968994620123079, 0.016089831179540073, 0.012816782658254462, 0.05784865907792534, 0.07994711971176521, 0.013956679081145142, 0.027187178110969917, 0.023436124569603374, 0.030306929456336156, 0.03331480734050274, 0.03353095467069319, 0.014938711787440946, 0.04325538268312812, 0.050347644436572275, 0.008214265207893081, 0.02989991701075009, 0.06179353275469371, 0.04688484614182796, 0.06610811302172286, 0.017738533871514455, 0.02214756451680192, 0.00818994312014963, 0.04409412321235452, 0.036594594562692304, 0.10565254358308655, 0.05580811767971941, 0.03023710141756705, 0.051174893975257874, 0.016246287784140025, 0.03329411880778415, 0.0228532273654959, 0.028554195471640145, 0.01300266308576933, 0.03680528986400791, 0.002214392035966739, 0.017717097253937806, 0.017900218588433096, 0.016239773847961, 0.0198856239273612, 0.03219508885272911, 0.07256889955273696, 0.05685934823538576, 0.07082731050572225, 0.049264139362743924, 0.019901443971320987, 0.015880219837916747, 0.05725500200475965, 0.04745744827336498, 0.028548187044050013, 0.038878098995025666, 0.043553856667131186, 0.00914484545189355, 0.042566544110221524, 0.04266508435830474, 0.012298939999059906, 0.0177466712027256, 0.02404424292035401, 0.05053186669413533, 0.01851945134278919, 0.0362019568814763, 0.07347047581736531, 0.02141722334947969, 0.044273066467472484, 0.07091601538871016, 0.010223966341332665, 0.020683141757867167, 0.04595249152875372, 0.05542074543024812, 0.04584101161786488, 0.023625142373410717, 0.006817993233978216, 0.06440802996179887, 0.041295454637812715, 0.010899618434320604, 0.03165934135072997, 0.06420274597725698, 0.023391365007098232, 0.02402072828928275, 0.039671208044247966, 0.03159902298024722, 0.037846603630376716, 0.04724558589181729, 0.043069942455206595, 0.013188545209621745, 0.01993827654847077, 0.038449057910059176, 0.01813890176293041, 0.01769848334203873, 0.03898001156215157, 0.03069694120702999, 0.04188681826261537, 0.019797894438462596, 0.044966797277863534, 0.00474630665433194, 0.09115578540201698, 0.0546056111343205, 0.058535227951194556, 0.004416501315842781, 0.013218713724719626, 0.03553229031552162, 0.015034193538927605, 0.060369375960103104, 0.046818312390574386, 0.007825794579860355, 0.022903830810849155, 0.05315684387460351, 0.011348253066119338, 0.0062640614175636855, 0.005521258530539593, 0.033112569978194575, 0.012632331395122622, 0.02492672181688249, 0.057165136826889854, 0.014458890838016356, 0.04291135864332318, 0.020243895506220203, 0.04157139447384647, 0.04591809658865843, 0.08627456054091454, 0.016387568953047906, 0.02314365901319044, 0.01946710861687149, 0.07953719635094915, 0.03519485824342285, 0.00910200783982873, 0.11795597124312605, 0.10609814431518316, 0.02855994605592319, 0.04922281997278333, 0.022072798439434597, 0.017060339816712906, 0.031280813805226765, 0.04619705929820027, 0.06095468705253942, 0.05029392142647079, 0.0464195441454649, 0.03892527074952211, 0.042288080123918395, 0.024053859457905804, 0.021953211731410453, 0.05941754060664347, 0.06775457824447326, 0.03830208383234484, 0.04232195598472442, 0.05368146340229681, 0.012774950126186013, 0.0027641266892065425, 0.08114001820130007, 0.052076341318232675, 0.05247445816972426, 0.050584442980055294, 0.10024589513029371, 0.029766452565257038, 0.08813663026584045, 0.04272094475371497, 0.019268745689519813, 0.05380707380494901, 0.034998948220163584, 0.042723387479782104, 0.01385959004983306, 0.028102720322619592, 0.0660689886925476, 0.053217375983617136, 0.006667577287381781, 0.04390493407845497, 0.016333601670339704, 0.028305298648774624, 0.018595233526346937, 0.039840733233307085, 0.033865078884576044, 0.05008550261014274, 0.07368766809148447, 0.03927641262167266, 0.05297251644411257, 0.08518604787864856, 0.020379186907250966, 0.06312631802367312, 0.010594760283960827, 0.04538489020030413, 0.08511230469282184, 0.0335786963946053, 0.03474911841164742, 0.05021099087649158, 0.015243070366393243, 0.07128728260951382, 0.039899606324200115, 0.04451597521879843, 0.011653884746400374, 0.01870439454380955, 0.01519879256375134, 0.04967302456498146, 0.023045283309849243, 0.05259047408721276, 0.0664224104423608, 0.027607389759006243, 0.058599810914269516, 0.040231029968708754, 0.021003506977909377, 0.03177019700940166, 0.031060975244534866, 0.054699516988226345, 0.016466748900711536, 0.036436065033610375, 0.040159152754183323, 0.03469417064583727, 0.043243589744504006, 0.015062418899365833, 0.04418195278516837, 0.04223284737340041, 0.06151863107723849, 0.034040239306965044, 0.009178276872262359, 0.011792744393460453, 0.019405156673331345, 0.0745926641726068, 0.03374964650720358, 0.01857042289339006, 0.037177093127476316, 0.15044159522014006, 0.015750887670687268, 0.06900873487549168, 0.02080573946503656, 0.014888337347656488, 0.035922112076410224, 0.043729573488235474, 0.024693455048171536, 0.013220620408122028, 0.034505049365439584, 0.05516857128324253, 0.013978229353337415, 0.013821325763793928, 0.022608243993350437, 0.03341075558481472, 0.02723636681080929, 0.02586557509909783, 0.023470399069732854, 0.0348117336231683, 0.029914050895188535, 0.0605438340987478, 0.05467375979891845, 0.0429267647809216, 0.07613895048520394, 0.01884619309566915, 0.0345717120383467, 0.031681797467172146, 0.029280750413558314, 0.04744198785296508, 0.06040337056453739, 0.027124496742284725, 0.016022662998044064, 0.044249405951372216, 0.041651671951902766, 0.05273528703089271, 0.02863432706466743, 0.011983045476621814, 0.04674873201708708, 0.023434609740174243, 0.024258397053927183, 0.02147741788732154, 0.024834812552269016, 0.06220972577908209, 0.018727510535557355, 0.028768653249634162, 0.011041693489200302, 0.0062122853788813305, 0.05153029365465045, 0.024127862183377147, 0.04182388413963573, 0.04491302337763565, 0.03125268852870379, 0.0401863280816802, 0.028803356923162937, 0.024414919815691452, 0.03174953222540872, 0.009097120691356915, 0.010134080807412309, 0.05932955497077533, 0.006326989179277527, 0.04483469329508288, 0.051447505597025156, 0.08468598114060504, 0.023368986922183206, 0.023976818591888462, 0.040414577083928246, 0.05357837357691356, 0.033920735719480684, 0.02503460888484759, 0.03349592869303056, 0.05269346891769341, 0.03977266599291137, 0.04508725420704909, 0.03733103915250727, 0.07859205813812357, 0.040294188008244546, 0.01835742566202368, 0.01692786263967199, 0.037776161517415724, 0.021672013248982172, 0.03861027443781495, 0.07549460684614522, 0.04992269152509315, 0.07168531803680317, 0.026219660116891776, 0.031135451248181716, 0.037380104019705734, 0.009294051061650472, 0.04925468397725906, 0.05745820288679429, 0.11739894827561718, 0.1286248487553426, 0.1993057517600911, 0.2180762831121683, 0.08627428912690707, 0.10147892218083143, 0.08645292025591646, 0.10119983394231115, 0.14915583921330317, 0.1516616011836699, 0.11992469988763332, 0.11172361352613994, 0.12285401698734079, 0.08366695724959884, 0.16032979105200085, 0.17047830005841597, 0.1937270811093705, 0.10067450534552336, 0.1516338355307068, 0.2039907103670495, 0.16894831215696676, 0.13207853771746159, 0.15421254001557827, 0.15239032065229757, 0.18690407222935132, 0.12217967531510762, 0.15082808876676218, 0.07465439050325326, 0.10259298847189971, 0.14132711929934366, 0.12545401390109742, 0.07119696959853172, 0.17207365802356175, 0.08369248373700039, 0.08063740695693664, 0.11718197991805417, 0.10632480215281248, 0.13408614641853742, 0.11473743537706987, 0.22443986950176104, 0.0961376845038363, 0.11023547087929078, 0.11736156099608966, 0.08499873150140047, 0.14307293561952455, 0.10825577032353197, 0.09987824450113944, 0.16262603497930936, 0.10284304898232222, 0.06637847529990332, 0.14010438562503882, 0.07550845574587584, 0.13114764195467743, 0.10749111564031669, 0.13581254306648458, 0.11499586222427231, 0.14443533894206795, 0.15560399820762022, 0.08441730162927083, 0.14541549634720596, 0.216818455606699, 0.22924881002732686, 0.0950859212981803, 0.11687619132655007, 0.1650326494127512, 0.07740923589361565, 0.07381368561514787, 0.17889364063739777, 0.1350940287645374, 0.11254783679864236, 0.16004809045365878, 0.12247972350035395, 0.10900647432676383, 0.1981961163026946, 0.07226440696311848, 0.138668578384178, 0.1079178870256458, 0.16020332569522516, 0.10232249048671552, 0.08901071229151317, 0.1593840896551098, 0.08853993112487452, 0.126903093286923, 0.11411547660827637, 0.08511256253612892, 0.1580230298319033, 0.41467003896832466, 0.1548390585396971, 0.1547989435493946, 0.15269564783998898, 0.09844753305826869, 0.08748986425676517, 0.1267529741993972, 0.10655711897249733, 0.09105523329760347, 0.10894444265535899, 0.1406578394983496, 0.15721850443099225, 0.13543629539864405, 0.11019570872719799, 0.09014679704393659, 0.11206670797296933, 0.10519624913909606, 0.12072170712053776, 0.1785809038473027, 0.08835701165454728, 0.23220258152910642, 0.16876817468021596, 0.2459593904869897, 0.17207337303885392, 0.07449987450880663, 0.10751593645129885, 0.12150051604424204, 0.15857345743903092, 0.12214071383433682, 0.16392684089285986, 0.1485495546034404, 0.08937839684741837, 0.091815748917205, 0.13444180733391217, 0.1256272710327591, 0.07779346313327551, 0.16852061796401227, 0.14091101448450769, 0.07511229986058814, 0.1791238539985248, 0.09370933659374714, 0.09186431845383984, 0.13716457837394305, 0.0966784158455474, 0.07407489445592676, 0.09369812719523907, 0.08190252192850624, 0.10471067590905087, 0.08725737780332565, 0.22753157360213144, 0.2008583213069609, 0.16194965770202024, 0.1519464094723974, 0.2007947290050132, 0.09377655227269445, 0.07107283161686999, 0.05311207413407309, 0.15479458735457488, 0.08829310722649097, 0.1546937706215041, 0.17121024935373239, 0.08739169381026711, 0.14404421778661863, 0.09691981146378176, 0.08267307986638375, 0.044273388771606345, 0.14187502275620187, 0.08167590480297804, 0.10606862125652176, 0.0777679637872747, 0.11897328522588525, 0.08233879280409642, 0.1550502186375005, 0.12405278480478696, 0.14226813880460604, 0.09967240411788225, 0.16848989389836788, 0.07813012506812811, 0.0993781370509948, 0.08043909152703625, 0.1975821778178215, 0.11904743553272315, 0.12171523166554314, 0.17290869035891124, 0.18905255837099894, 0.14850737686668122, 0.13045451843312808, 0.2072030987058367, 0.1607133261859417, 0.1767926655177559], [0.018028743298990384, 0.057528743387332985, 0.0861035357894642, 0.0025606132569789353, 0.0702850863869701, 0.015706251940823028, 0.03202052554115653, 0.03818992877911244, 0.018682337066690837, 0.031144228098647933, 0.05273916146584919, 0.05997465178370476, 0.062202458669032366, 0.01735346864110657, 0.03347717398511512, 0.08366129148219313, 0.04758266173303127, 0.06458273237305028, 0.024768841985080923, 0.023077688446002345, 0.037438193402652226, 0.01699945147681449, 0.09321678123836007, 0.010710034053772688, 0.01750060047821275, 0.050542916636914015, 0.036083932500332594, 0.029189952250037874, 0.01823636144399643, 0.033402368891984224, 0.027874227047764828, 0.06367408577352762, 0.02584035904146731, 0.017460443079471588, 0.03577032718541367, 0.031513463107070754, 0.06870581648711648, 0.07500442636332341, 0.018950144660526087, 0.04690944982160415, 0.030603751207568815, 0.017159960631813322, 0.03809743767072048, 0.06652212794870138, 0.06302611197211913, 0.024398953886702657, 0.04241620110613959, 0.021645350215424384, 0.06323790989284005, 0.022786963331912245, 0.14303230494260788, 0.04880052013322711, 0.02656599965744785, 0.06088889629713126, 0.03917301406285592, 0.1079842545358198, 0.018365941276507716, 0.04401392376582537, 0.03618706643049206, 0.057513496705463955, 0.05263396818190813, 0.025008285118799125, 0.08048803425793137, 0.046746170547391684, 0.040475723267133744, 0.05416167959836977, 0.058289917185902596, 0.02452831149899534, 0.04747254228485482, 0.05327619139903358, 0.035161952687693496, 0.06593180926782743, 0.04503603159849133, 0.027676193209897195, 0.018765408412686417, 0.011793710457693254, 0.09308566113135644, 0.023487493063190153, 0.06110667211136647, 0.04008284470598612, 0.027519468583964875, 0.026236055219279866, 0.03367559119526829, 0.04668239164831383, 0.02810235391370952, 0.008476915935586606, 0.02032640197181276, 0.01610215167914118, 0.011432557649511312, 0.05362590495496988, 0.014955427497625351, 0.05008902081421443, 0.023397402272426655, 0.006834671200652207, 0.0275758599330272, 0.01606204517052642, 0.07820600563926355, 0.03927869928468551, 0.023604345275089145, 0.06138429471424647, 0.07918633946350642, 0.03139251084732158, 0.04720337422830718, 0.0352667727773743, 0.05566242603319032, 0.061520402053637166, 0.057973964139819145, 0.023651008128321598, 0.010600124103283244, 0.06793672418487923, 0.03583537155230131, 0.024696398193814924, 0.04622773925906845, 0.09360276588371821, 0.03967045826305236, 0.05171879407550607, 0.018620447887639915, 0.04871928592079452, 0.010933670714231474, 0.015639322942921093, 0.08158641960471869, 0.02210692366185997, 0.05153907389779176, 0.014477849106437393, 0.008049952864114727, 0.017192708428150842, 0.06470598147383758, 0.02580701413431338, 0.043331103798534186, 0.019667993998154998, 0.05025965201535395, 0.025337612090100135, 0.09659243188798428, 0.029809675245944942, 0.023198165731238465, 0.05521194324163454, 0.02618985207352255, 0.05680427833327225, 0.011340833285690417, 0.048821055995566506, 0.015790166366579275, 0.007449961666549955, 0.01615167286113969, 0.015037252035524164, 0.016711219978917922, 0.07102937144892556, 0.02627213462255895, 0.0485408244255398, 0.0350430699597512, 0.014015047511618053, 0.022478416495557343, 0.020282877343041555, 0.07465137780777045, 0.04446661179619176, 0.014062365999312272, 0.07164778147957154, 0.016813653321670632, 0.04732943246407168, 0.01699777040630579, 0.021098657943574444, 0.03321091005844729, 0.05047282736216273, 0.04045768780633807, 0.06639336914356266, 0.025991171931049654, 0.04142374525378857, 0.018236604020265595, 0.061383717959480624, 0.01265307336247393, 0.015526379092729517, 0.030073364132217, 0.0414525490653302, 0.025875142442860773, 0.07940169290772506, 0.05228575418836304, 0.05410931705098067, 0.019241399031930735, 0.03850224148482084, 0.030318888636039834, 0.04123277835814016, 0.043117178670529804, 0.05214884617765035, 0.025895766514752592, 0.032239845022559166, 0.02751005221424358, 0.03867787688172289, 0.03181148925796151, 0.024445543797420602, 0.03259503435609596, 0.009414725970210773, 0.0329516045083957, 0.018672009763707007, 0.0028059789411989705, 0.025710078621549264, 0.003866974463952439, 0.04068181810102292, 0.026813227284167494, 0.052634667072977336, 0.013740898159864758, 0.07964230142533779, 0.027975472954234908, 0.04737763898447156, 0.031005918913121735, 0.04346226801031402, 0.03254776760669691, 0.031329291739634106, 0.030648280068167617, 0.05703565877463136, 0.025367152112136995, 0.019161258957215717, 0.04207734071782657, 0.06125538663140365, 0.04399125051817723, 0.0920262440506901, 0.025297882168420723, 0.0975645554385015, 0.020006881527868763, 0.030121445123638426, 0.01137356411865247, 0.03984111321291753, 0.038973300850817134, 0.028475573619029353, 0.023606942367873023, 0.03760615796116846, 0.041075975700680695, 0.06628364324569702, 0.04550403416422861, 0.058118946717253754, 0.0159703089323427, 0.06441074410187346, 0.02496979521986629, 0.051562028737472634, 0.0314792988688818, 0.04289531468280724, 0.023986019526741335, 0.01898184242392225, 0.02821753014411245, 0.023430782802669064, 0.0590214729309082, 0.03914509913218873, 0.027594507771677206, 0.05918663513979741, 0.033222363729562075, 0.009054498514160514, 0.06062378587999514, 0.030743200331926346, 0.0734885994877134, 0.0343097500236971, 0.04828651289322546, 0.03814487744654928, 0.04994608062718596, 0.029378920860056366, 0.07256469942097153, 0.03263991266222937, 0.030653715133666992, 0.01642143802850374, 0.1010035676881671, 0.03652289376727172, 0.048891952726989985, 0.05986091574387891, 0.03745184552722743, 0.10115034838340112, 0.01142106156995786, 0.0397838482500187, 0.051546015311032534, 0.06316512344138962, 0.0068058987713551945, 0.019955222960561514, 0.01713111610817058, 0.018716273995648538, 0.02422725229657122, 0.03176245153216379, 0.11855571477540902, 0.025502224685624242, 0.03680291838411774, 0.06089517953140395, 0.032795700909835954, 0.030639404830123698, 0.052669146829949956, 0.01643718682628657, 0.06948445577706609, 0.03523348045668431, 0.020938197982364466, 0.006953491588189665, 0.012113202912067729, 0.06586970295757055, 0.060851244388946464, 0.03417926434693592, 0.028646357490548065, 0.05847173064414944, 0.029079303544546877, 0.01622053568384477, 0.025767184128718715, 0.03275077510625124, 0.04104459345606821, 0.03251822758466005, 0.08237795106002263, 0.06995928779776607, 0.02170329710601696, 0.04244382765942386, 0.03923778023038592, 0.03516142682305404, 0.03207107300737074, 0.029588384620313133, 0.016585344947608452, 0.03618915971102459, 0.0499003745083298, 0.02861667497615729, 0.05078310785549028, 0.006422517155962331, 0.03937058310423579, 0.03573665149243815, 0.017543875745364597, 0.05683774368039199, 0.0376137168412762, 0.031393623644752164, 0.054228237098348994, 0.013507546574276472, 0.051829510634498935, 0.03654185203569276, 0.0072202614475307715, 0.03685107062171612, 0.02868668961205653, 0.023064535044665848, 0.0174122178993587, 0.007377456807132278, 0.036158785090914795, 0.030431498307734728, 0.049915780645928214, 0.049557907706392665, 0.04452491831034422, 0.08291007179234709, 0.020569933279018317, 0.01025083293539605, 0.037837409480874024, 0.0660859520680138, 0.036890605464577675, 0.04724271229601332, 0.07118293070899588, 0.06394435305680547, 0.08309373086584465, 0.04378272992159639, 0.04899698994787676, 0.0372412112940635, 0.013092018514206367, 0.03672467990379248, 0.030010314658284187, 0.012924015788095338, 0.046731622756591866, 0.00978027144446969, 0.03315175198284643, 0.05314784310758114, 0.11809237035257475, 0.1787256353667804, 0.1150858359677451, 0.11801271034138543, 0.17500597424805164, 0.11137260057564292, 0.06378571835479566, 0.09242504622255053, 0.0678233816953642, 0.20399935490318707, 0.1064321735341634, 0.16496259745742592, 0.18474912643432617, 0.06754298388425793, 0.12150104530155659, 0.1549263181430953, 0.18043608644178935, 0.15119124070874282, 0.07716756886137383, 0.12456552657697882, 0.1489556578121015, 0.1305480477000986, 0.14689139143696853, 0.12897744269243308, 0.15591096745005675, 0.20241436495312623, 0.1738344021141529, 0.08687886382852282, 0.13097806248281682, 0.13006514789802687, 0.10580380939479385, 0.11183289837624345, 0.16777603434664862, 0.0759938864835671, 0.1413233330739396, 0.08547200289155756, 0.11652541586330958, 0.23026965239218303, 0.06858923738556248, 0.22862710910184042, 0.05565799519951854, 0.10639283885913235, 0.14501669417534555, 0.13598107759441647, 0.15194446886224405, 0.10859563494367258, 0.0859707532716649, 0.15780371374317578, 0.15036813701902116, 0.11262109822460584, 0.20759686614785874, 0.12209375921104636, 0.13887857140174933, 0.1443539418812309, 0.07221326577876296, 0.18100634084216186, 0.07487203739583492, 0.17824473045766354, 0.09324268770537206, 0.08514897951057979, 0.14094196925205843, 0.1434166543185711, 0.16023356121565613, 0.20937331153878144, 0.09864066448062658, 0.17832608680639947, 0.15731771982141904, 0.1475924402475357, 0.16868962746645721, 0.125350917290364, 0.21324997209012508, 0.17889963888696261, 0.07079857454768249, 0.0681714905159814, 0.15484726881342276, 0.1531686003186873, 0.1195561196655035, 0.1916213562445981, 0.12799819452422007, 0.0849682924204639, 0.14047711848148278, 0.12559034515704426, 0.11891328915953636, 0.16519491427711078, 0.08104091137647629, 0.10090246597038847, 0.19017372892371245, 0.06898375800145523, 0.1863601721291031, 0.12460108181195599, 0.04920204323051231, 0.18556368058281286, 0.08742381565804992, 0.07646002647067819, 0.14753760104732855, 0.041848959401249886, 0.3100813568702766, 0.06818704932395901, 0.09833783430180379, 0.22449181814278873, 0.14175398567957537, 0.13687620099101747, 0.08878785424998828, 0.13758628788803304, 0.2209285864872592, 0.10825544462672301, 0.114882764007364, 0.09835215139069728, 0.08409197801457984, 0.27293550010238377, 0.08585790611271348, 0.1397597576890673, 0.09629930475992815, 0.18006883614829608, 0.07104201934167317, 0.12319589007113661, 0.1588380318135023, 0.13599273482603685, 0.06370049435645342, 0.07930601947009563, 0.12939147119011196, 0.2007865865847894, 0.1300236622669867, 0.17371196725538798, 0.11174620195691075, 0.10225147501166378, 0.15144991182855197, 0.058517633538161, 0.1448146535881928, 0.08296550810337067, 0.15634501273078577, 0.1243532265403441, 0.1449616921267339, 0.11102819655622755, 0.0955333337187767, 0.15978347536708626, 0.123505546312247, 0.19669649962868008, 0.09054945329470293, 0.08744406314300639, 0.18515426612326077, 0.10971207610730614, 0.0686928021854588, 0.09971069384898458, 0.06025382823177746, 0.16173804977110454, 0.0811901076563767, 0.11802279337176255, 0.17709721917552607, 0.11189049921397652, 0.10057961222316537, 0.07525055137063776, 0.16023475543728896, 0.2169901928199189, 0.06348655905042376, 0.10708309896290302, 0.14726909116974898, 0.0960833609902433, 0.07213719521782228, 0.1083927597584469, 0.15642893394189222, 0.10936645751020738, 0.13247052739773477, 0.17741908904697212, 0.12077917903661728, 0.15858622746808188, 0.1256266196391412, 0.16292131984872477, 0.1123738604198609, 0.12018007332725184, 0.09216596119638, 0.050844691693782806, 0.1250884463744504, 0.16698165982961655, 0.13152678018169744, 0.10158825452838625], [0.02000432345084846, 0.011140890219914061, 0.006130520636881036, 0.04014291541118707, 0.05967623208250318, 0.03065119098339762, 0.02602918346279434, 0.015086398326924868, 0.05762728702809129, 0.00815808929369918, 0.05461927004424589, 0.013558261129739029, 0.06783390577350344, 0.012101398099080792, 0.019976150676874176, 0.03507838770747185, 0.03842397586309484, 0.009448391485161014, 0.04750706614660365, 0.02323692025882857, 0.029658819947923933, 0.030886157482330288, 0.03109049830319626, 0.007233382618453885, 0.028563732281327248, 0.08053434427295413, 0.041595604603311846, 0.007046647236815521, 0.05771857712950025, 0.00926214040789221, 0.03450964304751583, 0.0423486224109573, 0.009797558820407306, 0.05560205677258117, 0.04596233367919922, 0.013340917881578207, 0.0700025986880064, 0.01503390007253204, 0.04348650188850505, 0.031018203789634363, 0.013397615419567695, 0.014285676114793335, 0.03158729450244989, 0.07561699420745883, 0.012558676418848336, 0.038908215771828375, 0.022477285038413744, 0.05155440539653812, 0.06824501657060214, 0.06748392419623477, 0.04612403875216842, 0.058066265258405886, 0.05310158398268478, 0.029163560630487542, 0.056238587080900154, 0.06974356794463736, 0.06259054677294833, 0.022939626925757954, 0.03728631351675306, 0.00483974559132808, 0.046580706390419176, 0.02175206341780722, 0.03825679501252515, 0.010078967648691364, 0.03448322767923985, 0.062269131519964764, 0.01631813446458961, 0.017335931903549602, 0.025143647766006843, 0.018715020402201583, 0.0349933672696352, 0.03140837160338249, 0.04469187863703285, 0.019375608169606755, 0.0423325072042644, 0.04017463692330888, 0.0459154028046344, 0.04077929983447705, 0.018077787810138295, 0.04716086740206395, 0.03990996755393488, 0.038439666985401084, 0.03789074233333979, 0.02414754478793059, 0.03933569622625198, 0.03309252266106861, 0.03624790048758898, 0.0429366510361433, 0.08024133928120136, 0.04663328606901424, 0.03551431253020253, 0.05505697262872543, 0.08812026400119066, 0.0073441178371597615, 0.009865106133344983, 0.013684339721554091, 0.024443481050963913, 0.03273871075361967, 0.027113509563995258, 0.049967393412121704, 0.012892069511248596, 0.014795369568413921, 0.07321871896939618, 0.0023397274198941886, 0.02313140806342874, 0.0162125645937132, 0.029337248631886075, 0.035059619428856034, 0.02032935359914388, 0.029016243892588785, 0.027146415119724612, 0.03320476931652852, 0.03632880221786244, 0.026485459247071828, 0.011360711817230498, 0.019040986928822737, 0.0045831406106507135, 0.0382258945277759, 0.016484931942873766, 0.02610315226151475, 0.03143659866015826, 0.06402769072779588, 0.04062687372788787, 0.0071757529429825285, 0.052821047071899684, 0.06609972632889237, 0.06299153382756881, 0.02714897319674492, 0.0025932071106840988, 0.1043732947270785, 0.0385537185440106, 0.015848118346184492, 0.041477756641272984, 0.07591903728565999, 0.01794498154361333, 0.02687315040800188, 0.018659865683210746, 0.009912436495402029, 0.007030992161682141, 0.05291477989937578, 0.014471962815150619, 0.006288926757406443, 0.05072801420465112, 0.07751839860741581, 0.017529041273519397, 0.02847578396488513, 0.011175359798861402, 0.03802339592948556, 0.0420256193860301, 0.02161070252103465, 0.039716832738901885, 0.03384245313437922, 0.07593168517840759, 0.039664456620812416, 0.04946642082982829, 0.029310962185263634, 0.05806355790368148, 0.09094961253660065, 0.06158700705106769, 0.025331657945311496, 0.03406728910548346, 0.05056131511394467, 0.02539215443123664, 0.036926245516432185, 0.005067665080007697, 0.019023643573746085, 0.02261218797814633, 0.08280793191598994, 0.03367668702932341, 0.055511034692504575, 0.0561159181275538, 0.049134702022586546, 0.0624400544911623, 0.009733466947052096, 0.0556372829180743, 0.024748161934050064, 0.02198588828157101, 0.0362515577913395, 0.027132718890373195, 0.045374050603381226, 0.03220814047381282, 0.02437985482226525, 0.0564338558885668, 0.053937807146992, 0.03358067771685975, 0.0345523839683405, 0.04719929284017001, 0.006038129188319934, 0.048341033181973865, 0.004198105490234281, 0.032333906939519305, 0.01229236669106675, 0.04366064450836607, 0.07208098537687745, 0.03964392415114811, 0.007178758004946368, 0.010162388440221548, 0.01310755018078323, 0.05477935341852052, 0.014130670726964516, 0.0327488853862243, 0.05065025069883891, 0.024102571486894573, 0.03165947027238352, 0.02882206752630217, 0.07053007145545312, 0.011971828444594783, 0.036263303232512305, 0.06226943686072316, 0.017848202093903507, 0.054519528789179664, 0.07040383680058376, 0.059751244128814766, 0.03981204138004354, 0.033607574844998975, 0.02337514971649008, 0.05128175984801991, 0.00552584881994075, 0.05392321525141597, 0.06044716999999114, 0.09249578349824462, 0.016385755568210567, 0.05018930828997067, 0.06618883154754128, 0.034997943988335986, 0.03557212710646646, 0.007663418605391468, 0.028340970931042517, 0.014865660707333257, 0.016945394288216318, 0.09434783126094512, 0.024758329781304513, 0.007909652178308793, 0.03352832195482083, 0.03132426040247083, 0.03429553132238133, 0.022864239988848567, 0.03927720311496939, 0.032231763670487065, 0.026750048888581138, 0.008869583302709674, 0.07589201123586722, 0.011344578798993357, 0.03985615972695606, 0.04431374464184046, 0.02051379807692553, 0.08066206491951432, 0.043437063827046325, 0.016442737242739116, 0.0059865745216874135, 0.029366656339594295, 0.04892550967633724, 0.045096743519284894, 0.0761964088305831, 0.044718120978879075, 0.004617704760416278, 0.01948524416158242, 0.05110684709091272, 0.061374537380678315, 0.03186293239040034, 0.034333766770682166, 0.030256955352212702, 0.027348521864041686, 0.024595528874280195, 0.05567675330010908, 0.034831797903669734, 0.043808822985738516, 0.07583939763052122, 0.0223991924431175, 0.052567746556763134, 0.010619443691601711, 0.006536948694182294, 0.041226495123867474, 0.023704917735553215, 0.09102797654590436, 0.028366422779592018, 0.038742259676967344, 0.061891947473798475, 0.011189017012449247, 0.05131918105429836, 0.010209837545906859, 0.034410444620464525, 0.027284558064171245, 0.015378361767424005, 0.003283209795232064, 0.03283765133736389, 0.03097287765038865, 0.03136466716283134, 0.03462925859327827, 0.056217287866664786, 0.011303091471615647, 0.021508445597386787, 0.026547782688534687, 0.019586230528407862, 0.01947223155626229, 0.02462872620006757, 0.050937868122543604, 0.04838973842561245, 0.0020452932637583998, 0.02756646561569401, 0.0698024919256568, 0.054624277632683516, 0.03640992107934185, 0.01583084962995989, 0.0409981104146157, 0.012114078222241784, 0.03931446825819356, 0.04389426072261163, 0.011322938620911112, 0.04736975101487977, 0.05806889118892806, 0.022671254451519678, 0.02132884755597583, 0.01125124715534704, 0.022763799842713133, 0.0410126208859895, 0.04769448769677963, 0.06481019766735178, 0.01664645890040057, 0.06405527996165411, 0.03052556361736996, 0.04714313388935157, 0.01575476210564375, 0.019512470379205685, 0.059294440783560276, 0.014557753390233432, 0.03691804202805672, 0.03498932320092406, 0.06530438829213381, 0.025852294472445334, 0.04027415086914386, 0.024862108319731693, 0.012830417819454201, 0.02313669554756156, 0.01577242267584162, 0.03974475784759436, 0.03089720063975879, 0.024944445151569586, 0.005033765894560409, 0.026996426650189927, 0.025496782834774682, 0.019711150521678582, 0.036131721721696, 0.044225253497383425, 0.01002511486876756, 0.022965908283367753, 0.02882532449439168, 0.014919061413300889, 0.02346466375248773, 0.03930756416437881, 0.03706366582108395, 0.02517609191792352, 0.10455375790063824, 0.10621770218546901, 0.10483340253787381, 0.10596715991518327, 0.1507936870413167, 0.09621894585766963, 0.1722594273409673, 0.15191434190741607, 0.1256729228688138, 0.08811613850827728, 0.10774954248751913, 0.0786547004910452, 0.1290251708456448, 0.10250686202198267, 0.15563404373824596, 0.0769262071698904, 0.09953255805053882, 0.13264339097908565, 0.13532317004033498, 0.08354394563606807, 0.13881446341318743, 0.16900505125522614, 0.14467114343174867, 0.06861434318125248, 0.14014338781791075, 0.16037034030471528, 0.08128434938511678, 0.11937049962580204, 0.1662977643843208, 0.1769773220377309, 0.11937624003205981, 0.11821282388908522, 0.12877301366201468, 0.10940898808517627, 0.13944465959710733, 0.14186358265578747, 0.11902524743761335, 0.10828690151018755, 0.1593725002769913, 0.08354412205517292, 0.10674991791269609, 0.09291230900479214, 0.2247585231172187, 0.12674131696777685, 0.17702391025211128, 0.07879234810492822, 0.1398683368627514, 0.19111495198948042, 0.1822529046663216, 0.12135156403694834, 0.13155644573271275, 0.1294085702725819, 0.10651422198861837, 0.09331054799258709, 0.12639104362045014, 0.15695941261947155, 0.12166753065373216, 0.10180601677192108, 0.07623273759548153, 0.21240009340856755, 0.1266613584011793, 0.12926594221166202, 0.11640942708722182, 0.12205491986657892, 0.05453771352767944, 0.1870577468403748, 0.0653712104207703, 0.14817289981458867, 0.07454419641622476, 0.08434022683650255, 0.1356409822723695, 0.12174700067511626, 0.0892040744157774, 0.09770148380526475, 0.09819511124598128, 0.0831691093210663, 0.13476869836449623, 0.12571421851004871, 0.12832239855613026, 0.16009855988834584, 0.05736975584711347, 0.14866596407123975, 0.17752830604357378, 0.12974372585969313, 0.10297420980142695, 0.10706781156893287, 0.09076271685106413, 0.09506584344697849, 0.1934190397816045, 0.08990804092692477, 0.07575419398822955, 0.17767910366611822, 0.15414531076593058, 0.15959808602929115, 0.16101607494056225, 0.07843952346593142, 0.07703422315950904, 0.0709298507177404, 0.15506307009075368, 0.16049542145005294, 0.0998972841937627, 0.10933371141020741, 0.08947636373341084, 0.110495017309274, 0.13831739579992636, 0.1599525934351342, 0.21207788426961216, 0.13066187873482704, 0.09633435109364134, 0.1385654274906431, 0.18308850697108678, 0.11066260867352996, 0.12027505465916224, 0.11461646615394525, 0.09856556422476258, 0.06645362983856883, 0.11616120540669986, 0.11524797869580132, 0.12422302924096584, 0.08517346105405263, 0.14781827027244226, 0.09412828447031123, 0.11776253448000976, 0.17460121453872748, 0.15981778209762915, 0.18024716872189725, 0.11232569800423724, 0.09953707030841283, 0.07767667368586574, 0.2488837135689599, 0.13054726059947694, 0.11409240641764232, 0.12690801945115837, 0.16851968158568653, 0.1478684140103204, 0.2211213582860572, 0.09324983946446862, 0.08845835085958242, 0.05505218556416886, 0.09428166052592651, 0.12466616689094476, 0.11301462139402117, 0.1060739748978189, 0.09799454986516919, 0.09057974988328558, 0.1046514737286738, 0.10076492013675825, 0.11287013414715018, 0.1393410472997597, 0.08073248328374964, 0.15547815710306168, 0.08999340741762094, 0.14751132817140647, 0.1595521763499294, 0.11450411432555743, 0.15234871288495405, 0.17806797208530561, 0.144302278224911, 0.1466443639780794, 0.11695743910968304, 0.08187759933727128, 0.1506271202649389, 0.21247953628855093, 0.11570379137992859, 0.10171060796294894, 0.13677699917129107, 0.08400788716971874, 0.24532490596175194, 0.1234477079872574, 0.1828030880008425, 0.26421662366815973, 0.13289649811174187, 0.17851516737469605, 0.09802413399198226, 0.13801894895732403, 0.07841842102685145], [0.05533539929560252, 0.04337853339633771, 0.0760415807100279, 0.06193720575954233, 0.04227383428120187, 0.017860344478062222, 0.04244901166696634, 0.0349334763762142, 0.016418776474893093, 0.030851022939064672, 0.11052358363355909, 0.053586994364325485, 0.06238982932908194, 0.018078525716971074, 0.033137937009866746, 0.007369628209354622, 0.07137435900845698, 0.12533145690602915, 0.0696034843900374, 0.04088381119072437, 0.03553228013749633, 0.06480159384331532, 0.045626862573304346, 0.04738698919702854, 0.020971980544605424, 0.06051244506878512, 0.044279207209391255, 0.03894022905400821, 0.05407668969460896, 0.06063273575689111, 0.008713686489500105, 0.028478694880115132, 0.05358811055443116, 0.03542602833892618, 0.043209618888795376, 0.07354188484272786, 0.015849717992490957, 0.04598091196800981, 0.035408698554549894, 0.06438006753368036, 0.04385733145422169, 0.04745204034926636, 0.02709573703551931, 0.0898977814774428, 0.0405113395702626, 0.01602694116133664, 0.010328465823217161, 0.06032604471381221, 0.06453824083187751, 0.014704157498532107, 0.04828814137727022, 0.031189642447446073, 0.029080032969691923, 0.024985693295353224, 0.03416227722274406, 0.009015186739686345, 0.024402714667043517, 0.02387709599653525, 0.018858579752434577, 0.0357197559704738, 0.028908336468573128, 0.04769590922764369, 0.06509570484714848, 0.014878724202779787, 0.033764509816787074, 0.06808034969227654, 0.021202811372599432, 0.05690386691795928, 0.0267696229275316, 0.032908341115606685, 0.02591922177400972, 0.04229178831779531, 0.044567523524165154, 0.03682935071576919, 0.008946110178450388, 0.022957460522385578, 0.045041276674185476, 0.0287640663529081, 0.017576462389635186, 0.05287775902875832, 0.040239633792745214, 0.06382189105663981, 0.05243401748261281, 0.023174946262900318, 0.012042105164644974, 0.04712634354031511, 0.032891072399382076, 0.01784059062733182, 0.05191659042611718, 0.03439824116815414, 0.04497502112228956, 0.030803834221192768, 0.007779884900498603, 0.04303412598424724, 0.032075412238815, 0.05804639096770968, 0.028031343527670418, 0.05271692248061299, 0.008127659542619117, 0.09308880274849278, 0.04432786834825363, 0.01521109270730189, 0.04089419277650969, 0.03150142928851502, 0.017771849940930094, 0.02158141864596733, 0.035341825535787005, 0.08815627385463033, 0.03869737119280866, 0.04255936181704913, 0.08817756628351552, 0.04008038162386843, 0.015690498054027557, 0.035279861717884026, 0.029395042852099453, 0.027046694220708947, 0.00878974178340286, 0.04139477859384247, 0.06712136257972036, 0.02693049340242786, 0.011524097112539624, 0.027412843591134464, 0.03533974243327975, 0.046218341549060175, 0.021034865473796214, 0.044158933484660726, 0.006832237380357193, 0.0026050948321686257, 0.014677216265616673, 0.04033288486035807, 0.0104960995959118, 0.0045191331300884485, 0.007851138710975647, 0.03286375457953129, 0.05542218731716275, 0.028734750247427394, 0.029250039918614284, 0.050939109841627736, 0.02679062867537141, 0.035214759675519805, 0.05263602075033954, 0.019815090212172697, 0.07557914552411862, 0.02006349679348724, 0.027745522525427595, 0.007603615073354116, 0.028367086047572748, 0.021449385909363627, 0.02132792305201292, 0.06661911774426699, 0.03649784564705832, 0.02683698618784547, 0.03518558945506811, 0.04710241161020739, 0.010853574744292667, 0.04937865571784122, 0.03229290306834238, 0.01989071972535125, 0.0368933060339519, 0.04544089648074337, 0.03152333918426718, 0.04029515152797103, 0.028135140725810612, 0.025775543680148463, 0.04788781250161784, 0.048204637465200255, 0.041533247235098054, 0.043211135414562056, 0.06517228430935315, 0.01286856081735875, 0.03962561049099479, 0.01470655103081039, 0.03892211556168539, 0.00833409364401762, 0.061899248510599136, 0.034431937217180214, 0.03199843583362443, 0.03723216302958982, 0.08327237556555442, 0.03400542367515819, 0.02488625738104539, 0.026964939232649546, 0.13022127880581788, 0.022234637523069978, 0.012969087476709058, 0.021114527181323086, 0.03159159302179303, 0.034059865932379446, 0.036478402226098945, 0.015257808146998286, 0.018587979986997585, 0.017747470177710056, 0.024914604877786975, 0.04073769206713353, 0.036180783196219375, 0.01011249321579401, 0.02853148490456598, 0.028509320558181832, 0.05637129495984741, 0.04004648540701185, 0.03396851476281881, 0.004955794587398746, 0.03835630217300994, 0.029425047670624087, 0.00801367498934269, 0.036041374783962965, 0.05157246799873454, 0.04897549056581088, 0.02274735045752355, 0.010151709147196795, 0.03716385490926249, 0.054610245528497865, 0.009620804688893259, 0.02034812866310988, 0.04168822802603245, 0.06175898853689432, 0.019268884789198637, 0.023974908515810966, 0.006161078461445868, 0.025411389202677777, 0.024493487385500754, 0.019712938461452723, 0.018879767008391873, 0.014155271014065614, 0.0425742861947843, 0.01551945973187685, 0.019102794683671424, 0.01520783913188747, 0.03323748488245266, 0.042362237216106484, 0.02401495904528669, 0.04210226670173662, 0.024771730847922818, 0.04709087651489036, 0.05212399822526744, 0.030590635125658343, 0.0645789597183466, 0.08359767203884465, 0.015739970042237213, 0.01766485853918961, 0.012094371868962688, 0.06899089618985142, 0.07857130175190312, 0.070234033412167, 0.028165437314393263, 0.04910213912704161, 0.01688959665729531, 0.06391782912292651, 0.03996548868183579, 0.03876902449077793, 0.0345596137589642, 0.02662466579516019, 0.03192552724587066, 0.01605175349063107, 0.02324076585604676, 0.016153784801385233, 0.051495729080800495, 0.0957887207290956, 0.05552986743194716, 0.026732524025387, 0.010583248089200683, 0.026414769468829036, 0.020625091390684247, 0.010676410947261112, 0.020642105656276857, 0.010732889657707086, 0.07642690717641797, 0.039742634032985995, 0.016152585490739772, 0.029845640994608402, 0.034013901970216205, 0.04368305991270712, 0.01531586529953139, 0.028343050640874674, 0.013954108281593238, 0.06547527733658041, 0.020717694457354288, 0.033712150662073066, 0.03591963203091707, 0.04155159482200231, 0.03479922143742442, 0.04525107630927648, 0.038573199284396, 0.032370252667793205, 0.0262839835403221, 0.03427714302337595, 0.03754349185952118, 0.03728917693453176, 0.05204162407400353, 0.014406511327251792, 0.03187316469848156, 0.11095563402133328, 0.03796349825071437, 0.039826558636767526, 0.040177174644278627, 0.02276724001525768, 0.03833961360422628, 0.010393824012550925, 0.033630231129271645, 0.018089831806719303, 0.0599219160420554, 0.035759996489754746, 0.01302565015586359, 0.047204456491661925, 0.027876301668584347, 0.032945192352469475, 0.040531420814139504, 0.011438707721286585, 0.03766109894162842, 0.03835644805803895, 0.06270247112427439, 0.008333644962736537, 0.03742874480251755, 0.019346332776227167, 0.01721175660246185, 0.04087873914145997, 0.037858403354351006, 0.03604298969730735, 0.06601147606436696, 0.04201772802376321, 0.050933623886001964, 0.05328737026346581, 0.02660155319608748, 0.006410828966181725, 0.05056943717811789, 0.07004523104322807, 0.07036172691732645, 0.02248331721472953, 0.03124609316832253, 0.020895265375397036, 0.00646418726371069, 0.047836596678410254, 0.04678766635645713, 0.03497452774484243, 0.03521258836346013, 0.03889397332178695, 0.03994352789595723, 0.016781914846173356, 0.03844979412055441, 0.009284024858581168, 0.0429109990197633, 0.027800519485026598, 0.041718192132455964, 0.11974461669368403, 0.020136598763721328, 0.05152813930596624, 0.01376465367086764, 0.032525060432297845, 0.026249977061524987, 0.04681336247761335, 0.03322851464950612, 0.03163642383047512, 0.1963837356971843, 0.12932150065898895, 0.17850733708058084, 0.07303408959082194, 0.1158751757549388, 0.0825354051111, 0.19209485155131134, 0.12047746165522508, 0.1402895985437291, 0.14340993682188646, 0.1700641494244337, 0.1988789125212601, 0.12281383414353643, 0.11284869922591106, 0.11250822392425366, 0.10812119647328343, 0.11029151108648096, 0.20833173314375536, 0.17492339653628214, 0.11147349194756576, 0.1445198572639908, 0.13041563837655953, 0.175400189523186, 0.1543910897203854, 0.0739148280450276, 0.1410010289400816, 0.17055827219571384, 0.1560968453330653, 0.12998740135559014, 0.1380169947764703, 0.11510999181440898, 0.13663840160838195, 0.16402521489986352, 0.11569894663989544, 0.14421197878462927, 0.14988203453166143, 0.08224864942686898, 0.14003171452454158, 0.13708721181111677, 0.11895381127085004, 0.08562670887580939, 0.12118225597909518, 0.08715070531304393, 0.18497769774070807, 0.17384132317134313, 0.11142641518797193, 0.06813316685812813, 0.10621217891041722, 0.13384374656847545, 0.07245278864034585, 0.1661157812923193, 0.0805463000599827, 0.09620036078350884, 0.1491966327386243, 0.10010823394571032, 0.1455224741782461, 0.1370607760867902, 0.0809042544237205, 0.11169550860566752, 0.11547634644167763, 0.2213425064193351, 0.29733043536543846, 0.11488154264433043, 0.0418163218668529, 0.14134902240974562, 0.14769457333854266, 0.11544248754424707, 0.13382317338671001, 0.10352177399077586, 0.10279582294502429, 0.14195095082478865, 0.10005866696259805, 0.1976357413721936, 0.14379614538380078, 0.07118554306881768, 0.1565415436135871, 0.10785510896572045, 0.07560387812554836, 0.13887304812669754, 0.117381876334548, 0.12819140058543, 0.13919974916747638, 0.12153140295829092, 0.1048450054866927, 0.11809481307864189, 0.10484719715480294, 0.09099104388483933, 0.17508153590772832, 0.10482981308762516, 0.11607121809252671, 0.16971847654453345, 0.10451219763074603, 0.06746196001768112, 0.11272375378757715, 0.14342685948525155, 0.13181871308812074, 0.10036801786295005, 0.12251858998622213, 0.0556295510115368, 0.1783563494682312, 0.24016407717551502, 0.13849118218890258, 0.15491481018917902, 0.11370699174169983, 0.10762304998934269, 0.15765565740210669, 0.1502920596727303, 0.12549368105828762, 0.09106600164834942, 0.10527638412479844, 0.25408669295055525, 0.0895007774233818, 0.10505978896149568, 0.07818817373897348, 0.10921806868697916, 0.2096987369337252, 0.12048875247793538, 0.14347229419010027, 0.14139863689030918, 0.09312561327325446, 0.12258154446525232, 0.14407025996063436, 0.10561892217291252, 0.12037592567503452, 0.2439688401562827, 0.13909581117331982, 0.2037863763315337, 0.1727341575814145, 0.09976202502314534, 0.16256386760090077, 0.07594477411891733, 0.08293389515685183, 0.13255203302417481, 0.1329531150736979, 0.17326070075588568, 0.11694283703608171, 0.09834523711885725, 0.12378446491701262, 0.11471512514565672, 0.13017032082591737, 0.19360309919076307, 0.14000407100788184, 0.11304360162466764, 0.0918165020910757, 0.21884044925017015, 0.16887306262339863, 0.13044423184224538, 0.124584308426295, 0.2867121494242123, 0.2863650380500725, 0.09933263449264423, 0.08555222608681236, 0.13642764863158974, 0.132169189995953, 0.08463387643652302, 0.13711226332400525, 0.12479901047689573, 0.22199759126773902, 0.13044257621679986, 0.12010938354900905, 0.28168121938194546, 0.06601303669490985, 0.12652733416429587, 0.06933975139898912, 0.1574060515101467, 0.13185857023511613, 0.1453908790967294, 0.21589256743235247, 0.2544877071465765, 0.10145708692393132, 0.11755701979356152, 0.1581528607223715, 0.08563766721636057, 0.09272363555750676, 0.14527076482772827, 0.10821470538420336], [0.038652482708649974, 0.02317003027669021, 0.02699707804380783, 0.01017136376218072, 0.06996321651552405, 0.004685037486654307, 0.04092631462429251, 0.0750407347721713, 0.032184167831603966, 0.06847579311579466, 0.07583721953311137, 0.05342324011559997, 0.09211370721459389, 0.012944480404257774, 0.026893299505380646, 0.07965366010154996, 0.01723264530301094, 0.04312216251024178, 0.016050145362636874, 0.020573168194719722, 0.017691625049337745, 0.03129655581765941, 0.06332937641335384, 0.029980109671929052, 0.05365329062832253, 0.03680332550512893, 0.024819547210686972, 0.017985121978979026, 0.04814980844301837, 0.03255780313962272, 0.019914292031899095, 0.019528003742120097, 0.006686069487061883, 0.02161516558511981, 0.0578120317576187, 0.021200550154649785, 0.05158219140555177, 0.0925542257194008, 0.017778891438086118, 0.02876107401347586, 0.04158847998561604, 0.07360275621925082, 0.051801568562431, 0.020053449386198605, 0.011558290188466864, 0.027351532863186936, 0.02426500428867127, 0.05540418239044292, 0.028281558404809663, 0.024663501119773303, 0.08937360639018671, 0.06293778706874166, 0.029938244061278443, 0.013427066383883357, 0.062265182446156225, 0.06455166903989655, 0.038627210671880415, 0.04437990180615868, 0.032549155210810046, 0.04461701586842537, 0.04079089939062085, 0.0168835780516799, 0.05561883694359234, 0.005279944760591856, 0.10394303567175354, 0.032633056065865924, 0.026043369933696728, 0.030652598943561316, 0.04654412317488875, 0.0746080329907792, 0.0485494078935257, 0.020766859408468008, 0.06087833150689091, 0.014746520136083876, 0.0036317874411387102, 0.01628409405904157, 0.03782731627247163, 0.0062258242729253, 0.026088485727086663, 0.03379022968666894, 0.013728099293075502, 0.010359752224758267, 0.03118177144122975, 0.03791841299140027, 0.06597376987338066, 0.04914062902597444, 0.03277892752417496, 0.03623508296108671, 0.036023183260113, 0.058404067132089815, 0.011876652033866515, 0.014995262592232652, 0.024400465323456695, 0.04008951809789453, 0.012868260565612997, 0.02689190341957978, 0.07607577887496778, 0.022948361367785504, 0.017495789664930532, 0.031494735540556054, 0.016685238873053874, 0.028574622768376554, 0.01986597864223378, 0.011809009726026228, 0.05485227557697466, 0.03197069053671189, 0.04620475049263664, 0.04836919917059796, 0.021876033462051834, 0.05062306858599186, 0.026341877844450728, 0.05074376639510904, 0.043431750897850306, 0.03640490670555404, 0.019858285751459853, 0.12729037393416676, 0.018222132564655373, 0.046911515960735936, 0.05069306965119072, 0.061150064425809045, 0.010635522427037358, 0.048412533809563944, 0.061692410680864535, 0.0521706576858248, 0.016982625504689555, 0.03392605543402689, 0.02432907495780715, 0.03725681759949241, 0.012639697740918823, 0.07611204657171454, 0.02995284952755485, 0.01572168861249728, 0.02760027362299817, 0.03489355816106711, 0.06614242653761591, 0.02409622718447021, 0.06488077209464141, 0.026527735371408716, 0.040718866113041124, 0.013237997689949614, 0.019890265106888752, 0.03698138327204755, 0.01596215463775609, 0.02552590216509998, 0.03326829376497439, 0.024893534669120396, 0.021077472383954694, 0.009043572404022728, 0.03404234955087304, 0.014244170127702611, 0.0045093859745455635, 0.05602784767480833, 0.0021127589404516455, 0.008805878194315093, 0.05164403308715139, 0.03743157768622041, 0.07328643676425729, 0.0312427445980055, 0.00835473383111613, 0.06142014171928167, 0.08894433799598898, 0.01798316270911268, 0.027493960756276335, 0.020364442341295735, 0.042771020638091226, 0.03866485918739012, 0.06439816406262772, 0.0360831250436604, 0.062062171553926807, 0.036327672457056384, 0.033404163617108545, 0.027698513619335632, 0.018442451188872968, 0.03924065721886499, 0.04347172000312379, 0.057113547809422016, 0.014807783366580094, 0.04025104675175888, 0.08456085928316627, 0.056641307792493274, 0.04358280975637691, 0.010900478477456739, 0.017323304366852556, 0.025347157381474972, 0.0290387780405581, 0.024668495137510554, 0.13596007015023912, 0.06805132196417876, 0.1266195877854313, 0.01990436845725136, 0.03131617565772363, 0.13381903432309628, 0.02429307358605521, 0.084922959495868, 0.02905206036354814, 0.06513980962336063, 0.034012612753680775, 0.05409418572006481, 0.03481490916705557, 0.021808839835492626, 0.024427796714007854, 0.029388946214956895, 0.051648911753935475, 0.022339586534404328, 0.02667822426051966, 0.05773457698523998, 0.035352322472525496, 0.009262699351113821, 0.0209305508927043, 0.024025416966261606, 0.05443756854427712, 0.03223814868501254, 0.04725147557577916, 0.0284081272381757, 0.07322805561125278, 0.028143001554001654, 0.037771004651274, 0.019991670469088212, 0.04544099826099617, 0.047086014811481745, 0.021344577694045644, 0.013896936617259468, 0.014874215337580867, 0.04572572512552142, 0.02208122584436621, 0.015365238900163343, 0.048809035747711144, 0.022445697536958114, 0.028054549425308193, 0.02552679104597441, 0.04412306612357497, 0.018106162448280623, 0.07163072989455291, 0.09215547783034188, 0.049018920199679475, 0.030468468288225786, 0.04416095891169139, 0.026479194672512155, 0.05070390924811363, 0.004234419836263571, 0.0699511928749936, 0.03451149884079184, 0.10834433271416596, 0.04512681619131139, 0.029958851169794798, 0.02102422095569117, 0.024718087565686022, 0.033458191967968426, 0.03762689399133835, 0.009709490912168153, 0.026127576129511, 0.08184494144682374, 0.028635663778654168, 0.015647222786875706, 0.007399157205197428, 0.028090756053903272, 0.02940763985472066, 0.03863586199336818, 0.04926366438823087, 0.03287473327613302, 0.015603039979136415, 0.027428203927619115, 0.007352572383492121, 0.029753207561693022, 0.049969113498393974, 0.01958892261609435, 0.03528984636068344, 0.06408502693687167, 0.0172194359225354, 0.03552524033667786, 0.028632145574582473, 0.037261652161500285, 0.04644590862361448, 0.04093315425728049, 0.050565593277237246, 0.02166789793409407, 0.01617212051392666, 0.006122222153602966, 0.0973426066339016, 0.0032780921568961014, 0.03815163565533502, 0.07187359114842755, 0.016742011898064187, 0.05610841692292264, 0.01576214117397155, 0.08988768487636532, 0.0521381762144821, 0.024112907271566134, 0.04420337074303201, 0.04795578135443585, 0.05710037744471005, 0.020532349224335382, 0.0291522867711527, 0.035390089731663465, 0.02639501222542354, 0.04636585845478943, 0.11747797046388898, 0.0528193812684289, 0.03926103701815009, 0.10668917545782668, 0.0356078010850719, 0.03869134919451816, 0.007365767345098513, 0.061217375099658966, 0.05769341026565858, 0.05824644344725779, 0.028889072859393697, 0.06344781470085893, 0.04462589789181948, 0.04353674740663596, 0.10203133789556366, 0.05500412492879799, 0.07399136679513113, 0.05619993772623794, 0.03735095076262951, 0.04060333874076605, 0.029720101838133166, 0.016089524142444134, 0.03487866431740778, 0.027440135965922048, 0.06179506624383586, 0.04148744612133928, 0.03504980102713619, 0.027307129531566585, 0.04331481895808663, 0.02478794613853097, 0.017556050359936695, 0.010776449909566768, 0.04917843699721353, 0.05064380122348666, 0.04307969639609967, 0.03068621356838516, 0.018263497755729725, 0.03377683201272573, 0.03577716003305145, 0.040033569492931874, 0.014935159656618322, 0.011334935120040817, 0.02770760768492307, 0.05786961902465139, 0.06242817334298577, 0.049139207495110374, 0.053534764131265025, 0.07259191546056952, 0.022264589755130664, 0.021166443591937423, 0.007979303797973054, 0.013316784935471202, 0.062255140127880235, 0.017443279536174874, 0.036143199141536436, 0.026993039064109325, 0.17660859253789696, 0.12013938836753368, 0.16483345867267676, 0.2310740149446896, 0.13290244207850524, 0.1007405471588884, 0.19353170373610087, 0.29626521681036266, 0.10386427811213902, 0.12784677264945848, 0.2550366962594645, 0.1593737080693245, 0.3153145717723029, 0.10911801869847945, 0.12571269859160694, 0.1922031185988869, 0.0628672262121524, 0.1114770339003631, 0.13215487290705952, 0.09039862853075777, 0.07632278597780637, 0.13520832120307855, 0.11289313648428236, 0.1165649201720953, 0.12212163342961244, 0.10797461255320481, 0.17709457288895333, 0.11765311392290251, 0.19319706383560384, 0.10813858732581139, 0.09510519847806011, 0.15755412142191613, 0.10486255918762513, 0.1160729822835752, 0.19602842762001924, 0.14074718898960523, 0.0925246619486383, 0.17683548107743263, 0.13599619535463198, 0.18066718189844064, 0.09273114015481301, 0.08260572169508253, 0.17200193687209062, 0.13815906643867493, 0.126026344618627, 0.123324418174369, 0.16410381639642374, 0.09164872752236468, 0.10546297446957656, 0.07076173688152007, 0.11884823122194835, 0.11278729859207358, 0.0700182049934353, 0.0871166360697576, 0.2042002419808081, 0.08598447324974196, 0.1655660593616111, 0.23696152759449823, 0.12660622064556393, 0.13217387188758167, 0.13824270266507352, 0.1587693640696151, 0.08592755094702755, 0.1315998855446066, 0.18762653560510703, 0.07207703630306891, 0.1635708407099758, 0.13575000927916595, 0.088221101090312, 0.1851979773491621, 0.12102396732994489, 0.16778307754014218, 0.19552306830883026, 0.17141741966562613, 0.10695432658706393, 0.18562131534729684, 0.16571532349501336, 0.0827246146010501, 0.08707719961447374, 0.09879495655851704, 0.09053708360131298, 0.11531537079385348, 0.11807128148419516, 0.06877550203353167, 0.12672724415149006, 0.09833849248077188, 0.11316989734768867, 0.230655521686588, 0.1529390247804778, 0.09242861531674862, 0.16711947029190405, 0.08411949939493622, 0.13229642888264997, 0.17990376214895928, 0.07229254581034184, 0.17493479592459543, 0.1856501530855894, 0.15134287971471036, 0.14795798063278198, 0.14497359363096102, 0.09638552620474782, 0.09281263899590288, 0.15458992762225016, 0.07940609659999609, 0.1310929927442755, 0.15045830075229916, 0.09093559400311538, 0.13789127580821514, 0.09577927552163601, 0.14729050573493752, 0.08649450766720942, 0.13967755995690823, 0.10376791935414076, 0.06978882623038121, 0.12270634062588215, 0.1672812466110502, 0.09729605913162231, 0.06938733705984694, 0.1293856765010527, 0.23354510377560342, 0.13306932098099164, 0.15006335265934467, 0.14469696847455843, 0.15048879411603722, 0.21559733684573854, 0.1289076078683138, 0.11821700366480009, 0.1525480393320322, 0.11580938499953065, 0.16315587583397115, 0.10608949977904558, 0.09529486258647271, 0.15003367353762898, 0.08667777997574636, 0.2036332988313266, 0.18727734791381018, 0.12768422280039105, 0.12634151056408882, 0.11707245079534394, 0.07757460844836064, 0.09665616668228592, 0.08877460924642426, 0.09386706205883197, 0.0857369504602892, 0.125715684145689, 0.09247778196419988, 0.07292076745735747, 0.08031761340264763, 0.06530888697930745, 0.11917153958763395, 0.17118215800396033, 0.16359267596687588, 0.1224230658262968, 0.14228333798902376, 0.1620059082550662, 0.08380003832280636, 0.12524942202227457, 0.1292712754969086, 0.064544917616461, 0.1617059414940221, 0.1709835643747023, 0.09293320788336651, 0.1378500751618828, 0.1361509963337864, 0.1444294356874057, 0.1579964312591723, 0.12630093416997365, 0.09716704248317651, 0.14396588770406588, 0.07979556212999991, 0.1141594863895859, 0.11336275057068892, 0.12251382667039122, 0.20672593931002275, 0.17196530955178396, 0.18559726806623594], [0.025086537169824754, 0.03695665067061782, 0.016715942582647716, 0.08009774770055499, 0.03984108267884169, 0.024924747279978225, 0.08734890539199114, 0.02161100786179304, 0.023930705352021114, 0.04725074275795903, 0.004517653923747795, 0.018664649355092218, 0.018479315996436135, 0.012693768500217369, 0.04617159387895039, 0.05449222114735416, 0.02482690761930176, 0.02530279815463083, 0.02151255582326225, 0.057625570334494114, 0.05684505489521793, 0.057864767499268055, 0.03563423341672335, 0.01505932308334325, 0.018952212495995418, 0.01256953806815935, 0.07210242029811655, 0.025913896970450878, 0.04052492384133594, 0.11190912500023842, 0.04546891658433846, 0.020966228263984834, 0.08244247974029609, 0.010543492722458072, 0.03403510279687388, 0.030839063759360994, 0.029587539844214916, 0.05497418796377523, 0.023404034952233945, 0.03536985242473228, 0.0285356918216816, 0.05663963181099721, 0.06153858679213694, 0.019783546815493276, 0.048017114134771485, 0.046081399611596546, 0.027962562129167572, 0.0380642403449331, 0.07683100870677403, 0.0344802896226091, 0.018295558535360863, 0.06154879195881741, 0.029378500168344805, 0.02765664631234748, 0.012945985055661626, 0.02249845702733312, 0.015633986264999424, 0.011800216760353317, 0.037934433203190565, 0.028217672636466365, 0.05154305350567613, 0.02069939436790134, 0.01408060671695109, 0.037794315721839666, 0.04776949295774102, 0.04434076729895813, 0.004076512014892484, 0.06406205174114023, 0.03317396382668188, 0.05378831570435848, 0.005348179090235914, 0.024885709464017833, 0.07930679300001689, 0.010247444501146674, 0.027725585470242158, 0.021211922401562333, 0.015765937577400888, 0.029607366637459824, 0.049503163501088104, 0.02593217500751572, 0.02637852552080793, 0.024157064634242227, 0.07655436319432088, 0.04273278179711529, 0.02036596056339996, 0.037444876972585917, 0.03928413435018488, 0.029966762888112237, 0.03381902671286038, 0.014143363572657108, 0.03311149789286511, 0.023559499199369123, 0.03240872560335057, 0.05247952004096337, 0.060595382404114516, 0.03241114458069205, 0.05165924923494458, 0.03183120748560343, 0.0361491939984262, 0.015804544523624436, 0.04310067669887628, 0.05955229087599686, 0.028367104707285762, 0.012012436220954572, 0.003953731103268052, 0.024794565247637883, 0.06372509125087943, 0.03400133889434593, 0.044709517154842615, 0.033560247027448246, 0.03564707129927618, 0.02813879294054849, 0.032403497491031885, 0.07587920728006534, 0.006314749679794269, 0.010904988190824432, 0.03971440697621022, 0.031505402111049206, 0.06008514442614146, 0.03348620867888842, 0.05709381601107972, 0.06475537882319518, 0.04294023370104177, 0.02704045848388757, 0.04320350528827735, 0.03851191060883658, 0.017580674395763447, 0.0694302883265274, 0.02030503999308816, 0.005713705904781818, 0.007329229082513068, 0.05750523214893682, 0.0684176901621478, 0.06189678542848144, 0.0856837872415781, 0.04475503328389355, 0.035662752243557146, 0.02971323167106935, 0.009123258708444024, 0.02311896882019937, 0.02500636825737144, 0.019818179242845093, 0.03408421516152365, 0.05296402797102928, 0.016335771286061833, 0.016437841612579565, 0.03389949757339699, 0.04954476109040635, 0.04326950638954129, 0.07157045562884637, 0.010504271702042647, 0.039401778751718144, 0.03623656216742737, 0.035141298081725836, 0.03145027453345912, 0.038183801607894044, 0.05263260771919574, 0.05480472384286778, 0.030321891153497354, 0.04516510931508882, 0.030401941322322403, 0.03957128019205161, 0.04353863373398781, 0.08293554399694715, 0.017062548448198607, 0.04952981974929571, 0.04774247030062335, 0.021595343880887543, 0.030679682668830668, 0.046667803145412884, 0.022658133280596564, 0.0521452058372753, 0.02396053884045354, 0.016870300817702497, 0.04846585648400443, 0.021885782313932265, 0.01752051887368517, 0.05639874170135174, 0.05853108210223062, 0.035962518836770735, 0.010102576426496463, 0.033705002295651605, 0.036322471486138444, 0.025050983631185124, 0.054572101682424545, 0.017093691509217024, 0.03569300812003868, 0.06023991826389517, 0.015363963254328285, 0.004647536552511156, 0.026203941853184785, 0.06329228090388433, 0.0439517597800919, 0.0392599276133946, 0.07972599193453789, 0.017966986434268098, 0.061884056111531596, 0.03197479906624981, 0.017963458052171127, 0.051909058687410185, 0.020274689121704017, 0.030638773792556355, 0.03938682383990713, 0.029990158775555234, 0.017148184656564678, 0.03156466196690287, 0.00858471479399928, 0.06306188433830227, 0.01898806119736816, 0.015908977848344615, 0.025577157004071132, 0.02637671383230814, 0.06549650869731392, 0.035756084735372236, 0.020851594861596823, 0.027679321256333163, 0.023971269871773462, 0.03664680104702711, 0.037911363012556515, 0.01712047159006553, 0.018579603472192372, 0.078433504860316, 0.011886094696819782, 0.027268266438373497, 0.04102329084915774, 0.008566055929155221, 0.024748309515416622, 0.05589480731370194, 0.0918889424896666, 0.04123708366283348, 0.013321888366980212, 0.023558615407507335, 0.029499625454523733, 0.027782970873106803, 0.024757963372394443, 0.028040597048987235, 0.07164550160190888, 0.07387961207755975, 0.047742894385010004, 0.05424423695408872, 0.04922080811645303, 0.03897945177076118, 0.034623117851359506, 0.047126445320567915, 0.03852325232167329, 0.053174621492092095, 0.0427788136127804, 0.07289477956614324, 0.047531072715563435, 0.032744145819119046, 0.019068001104252677, 0.021283545165455768, 0.06138163485697337, 0.04327182697930506, 0.041643885762563775, 0.025176490557246974, 0.028331634289185916, 0.04425127531534859, 0.02331259726945843, 0.08369955407189471, 0.01647999051160046, 0.03193637023546866, 0.02856179167117391, 0.04941043151276452, 0.01336014926034425, 0.02892219554632902, 0.01147177951809551, 0.06853644736111164, 0.024312369425648024, 0.015620025406990732, 0.03477606303723795, 0.011181520896830728, 0.023647518761988198, 0.041515418727483065, 0.03418149333447218, 0.07191816411380257, 0.05106430633791855, 0.010915051713319761, 0.01778341387398541, 0.027327965645651733, 0.008160319977572985, 0.028108942488740598, 0.06540159521890537, 0.006192948827187398, 0.05266261932307056, 0.03638298323910151, 0.026265043931614076, 0.028718733428312198, 0.05188929635499205, 0.022264923933627348, 0.022186132447261895, 0.03537938923441938, 0.014021251018026044, 0.02332723157347313, 0.05974486589963947, 0.03155298098655684, 0.051420058855520825, 0.01703842313561056, 0.07656508404761553, 0.08647757821849414, 0.025936258091990436, 0.016356929704280834, 0.037513792381754944, 0.03247768511729581, 0.022744475165382028, 0.042281813853021176, 0.03414872348574655, 0.06575273709105593, 0.012736312645886625, 0.038292720049087486, 0.030666759969400506, 0.06887961644679308, 0.017583105247467756, 0.025545080957402076, 0.03688295158956732, 0.023660497440557395, 0.040690513527286906, 0.013839529162006719, 0.06532898518655982, 0.041727674659341574, 0.023841944489894167, 0.03179449874109455, 0.03216909756883979, 0.006218325612800462, 0.04285215646294611, 0.05899013139839683, 0.022339413507974575, 0.02838412915090365, 0.039011034183204174, 0.028939457477203438, 0.04726067990330713, 0.08766935033989803, 0.02513229417880731, 0.046330639094646485, 0.04160191837166037, 0.04598437588928001, 0.014984316126044308, 0.06047037589762892, 0.06159374490380287, 0.024632956865908842, 0.013149694838960255, 0.04757247352972627, 0.07298193060393844, 0.05978878068604639, 0.022784617297085266, 0.04807083714487297, 0.023102936734046255, 0.05529266855280314, 0.0004902012099462029, 0.015384141189445342, 0.055728566234133074, 0.016528734771002616, 0.1234087057943855, 0.15740979702344962, 0.11987813881465367, 0.13212002334850176, 0.08720850292593241, 0.19233383158487932, 0.1181670499167272, 0.11838270191635404, 0.13293666738484586, 0.166160415325846, 0.11483293239559446, 0.13988167686121805, 0.08355849342686789, 0.14106876030564308, 0.1574513233665909, 0.12370551058224269, 0.10183929891458579, 0.07429757607834679, 0.1606104059943131, 0.14089091627725533, 0.32651118668062346, 0.10369748741920505, 0.11560661159455776, 0.12889025094253675, 0.09150977712124586, 0.06900617001312119, 0.16307996133608477, 0.08805023918726615, 0.14101924081998213, 0.1658076856817518, 0.11140947895390646, 0.17554288543760777, 0.15526574850082397, 0.13359012374920504, 0.10454442125878163, 0.09113783815077373, 0.16162117889949254, 0.11893033395920481, 0.14346500672399998, 0.11867809535137244, 0.2527245474713189, 0.15175236202776432, 0.09477454157812254, 0.0752062498192702, 0.1038008350878954, 0.1840061034475054, 0.11834502965211868, 0.12092084357781069, 0.13736214062997273, 0.09955789454813514, 0.1285781655460596, 0.1088924804436309, 0.2563474087842873, 0.09939412333603416, 0.11919080998216357, 0.10045997971402747, 0.11434521499489035, 0.11909772854830537, 0.11605200198079858, 0.14322912081011704, 0.23907852971128055, 0.112445398366877, 0.08277927738215242, 0.15796318304325851, 0.22727582018290246, 0.11539424370442118, 0.14788726371313843, 0.1323779480797904, 0.07069993591202156, 0.09687732838626419, 0.1675992352621896, 0.11709567026368209, 0.20438586202050957, 0.09897252917289734, 0.1682564914226532, 0.10223588906228542, 0.158158044729914, 0.10380550340882369, 0.14423849593315805, 0.11668612009712628, 0.10525190936667578, 0.12029416220528738, 0.12057168302791459, 0.22710598286773476, 0.06216545815446547, 0.054256952700338194, 0.13311163442475454, 0.11920594131307942, 0.08199935566101756, 0.07401438948831388, 0.07848524994083814, 0.16587373428046703, 0.13541777139263494, 0.09197639886822019, 0.11688189102070672, 0.1139189592961754, 0.08747681602835655, 0.15696823357471398, 0.18718653278691427, 0.136917700192758, 0.1285740536238466, 0.1097453311085701, 0.09781153539993934, 0.11368568574211427, 0.11833691437329565, 0.14418289677373, 0.1409036184528044, 0.06552095631403582, 0.14159375642027172, 0.0685583572568638, 0.09415619940097843, 0.1226352301559278, 0.11018051632813045, 0.1567830206560237, 0.081357129051217, 0.10645164748919861, 0.08869747338550431, 0.16808837758643286, 0.1243782780532326, 0.14198722530688557, 0.14409577287733555, 0.13241095202309744, 0.23681127279996872, 0.16431119026882307, 0.08971636835485697, 0.10434366988816432, 0.11846838731850896, 0.23972932621836662, 0.10134985124958412, 0.08573601408196346, 0.13479221638824257, 0.1539041729910033, 0.10960157667951924, 0.19595397875777312, 0.16914386594934122, 0.15501357774649346, 0.07315357282225575, 0.11776721637163844, 0.12339432085199015, 0.09712280878531081, 0.16900591978005, 0.13242024795285293, 0.1642359678766557, 0.11018165626696177, 0.09745550129030432, 0.0699936623818108, 0.11464938867305006, 0.129971605060356, 0.0817007798967617, 0.16627956607512065, 0.06978630886546203, 0.1469819758619581, 0.10311131458729506, 0.16445199985589298, 0.1557910567415612, 0.12012921034225396, 0.11633599602750369, 0.12321193063897745, 0.11918701018605914, 0.0984193534989442, 0.13845794754368917, 0.12989350567970956, 0.06263537758163043, 0.09229329507797956, 0.12597164112542356, 0.11038282832929067, 0.1065956869029573, 0.20584716860737118, 0.12020063293831688, 0.11859213853521006, 0.12488669077200548, 0.10363954052861248, 0.12777163168149336, 0.0751781313280974, 0.2553904029939856, 0.0712316698793854], [0.07911918485271079, 0.035163316543080976, 0.02841602199311767, 0.015932628186419606, 0.022110859164968133, 0.03261065083955016, 0.023201846783714633, 0.017691730222265636, 0.04137542677511062, 0.05228782711284501, 0.024746580947456614, 0.021601242046537142, 0.030799206612365584, 0.057905662804841995, 0.03442383550905755, 0.038592428966824494, 0.04214627309037106, 0.021252634502681236, 0.04833638182442103, 0.02433893916064075, 0.029165613198918954, 0.023012812016531825, 0.015307561727240682, 0.021781338811186806, 0.10290045983025006, 0.02915298566222191, 0.031524183960365396, 0.01813056765656386, 0.040986802628529925, 0.043206287281853814, 0.007872700009361973, 0.11054692523820059, 0.013016015806767558, 0.03358304241139974, 0.056373954817120514, 0.04361204443765538, 0.009849260644321995, 0.07382763629513127, 0.039613569887088876, 0.06964657814907176, 0.05214521601530058, 0.05055043141224554, 0.03903261498947229, 0.016767110908403993, 0.04428121906572154, 0.043123431370726654, 0.021662011642807295, 0.034542918404830356, 0.02375292917713523, 0.030740760998534303, 0.07912589556404523, 0.022894763886662464, 0.0262601873172181, 0.025285702464835982, 0.02556612911368055, 0.07212411306266274, 0.026241452965353216, 0.01881096016482583, 0.036875056834625344, 0.024773284693115523, 0.04361047362908721, 0.048210455902985165, 0.05383411681811724, 0.06394315204982247, 0.0336847717740706, 0.05689347176147359, 0.00691428710706532, 0.012991761572525969, 0.028781518273587738, 0.038702002194310935, 0.022498185613325665, 0.0731424041358488, 0.018255898163520863, 0.017704978618504744, 0.029631868536983217, 0.04993438946881464, 0.0465693002167557, 0.04316829610615969, 0.030664256175181696, 0.02525372650208218, 0.039108783937990665, 0.04534500930458307, 0.012923023430630565, 0.04312497503789408, 0.00896604044828564, 0.04099851753562689, 0.007157473209580141, 0.01319230005278119, 0.05849256845457213, 0.04938198393210769, 0.004126388155522623, 0.03198202546419842, 0.01320692672327693, 0.04039482492953539, 0.016080959334171245, 0.02622730381387685, 0.02490054563220058, 0.01742936108660485, 0.053901790508202145, 0.049845816900155375, 0.059127209042864184, 0.028507654754711047, 0.026970077439078262, 0.07620517550302403, 0.05307950445317796, 0.03997721715963312, 0.03833910809563739, 0.0172048270635839, 0.030873261924300874, 0.04671669837885669, 0.061268441645162444, 0.06913642838065114, 0.03203052714733141, 0.03600768891296216, 0.024387578247115016, 0.016821802527244602, 0.031885897408106496, 0.03214342858908432, 0.03229421942627855, 0.028652732327048267, 0.02832872507029346, 0.04204704073656883, 0.07945874413209301, 0.020664633018895984, 0.0398021720881973, 0.03288853467841234, 0.007021288262746696, 0.027620426113052026, 0.03929493662768176, 0.025930319214239717, 0.03759297402575612, 0.037720993227724514, 0.029431293585470746, 0.0109334315306374, 0.04349707346409559, 0.04235736872734768, 0.023339133077700223, 0.01877976451734347, 0.050006921469633064, 0.02144656659636114, 0.0368280886406345, 0.0770025695008891, 0.04712095257959195, 0.00528637769665303, 0.03542734808953745, 0.027015033776738813, 0.0479404430703393, 0.02969614615929978, 0.03401061786072595, 0.025941569324848906, 0.03905441631962146, 0.03398387340296592, 0.06538885233125516, 0.03305337119049259, 0.0514880480643894, 0.024699792565245713, 0.048061035706528595, 0.056703098583966494, 0.02879201860300132, 0.08513771582927022, 0.01876408526940005, 0.0029807572635555907, 0.02876123007653015, 0.004834392374115331, 0.05071403977594205, 0.011139204908561493, 0.034932010740573914, 0.044180578751755614, 0.0386225491363023, 0.013414972345344722, 0.046439913766724725, 0.01984580579612936, 0.011709852011076041, 0.0438596384732851, 0.04825285416362541, 0.06596811089132514, 0.04549106057467205, 0.026649028595004762, 0.04971245762759021, 0.01991745570142354, 0.01303139649930277, 0.04581477266869374, 0.023575044436646358, 0.06241354412798371, 0.030966156761028936, 0.026737775886431336, 0.03893485166398542, 0.016101447699059333, 0.03388281918263861, 0.05448479797425015, 0.04548438379008855, 0.017045423920665468, 0.011569394414047045, 0.01833985330137823, 0.04228906739237053, 0.03605263167992234, 0.017394945790459002, 0.031730268616229296, 0.015137140871956944, 0.01083614572416991, 0.04598998737388423, 0.021903541271707842, 0.03141613065132073, 0.02371276160036879, 0.05717531485216958, 0.01872240286320448, 0.006901314789761922, 0.04611114997948919, 0.0865322749263474, 0.03686349120523248, 0.04116234303052936, 0.01688331172668508, 0.025236719021839753, 0.012455994562645043, 0.042118402264480076, 0.04667389978255544, 0.03615984360554388, 0.03905910838927541, 0.04890612393085446, 0.05827202421746083, 0.03233701123722962, 0.0742082130163908, 0.04288083813818438, 0.030039498449436257, 0.07233500174645867, 0.03157852443733385, 0.12777152311589035, 0.06316653479422842, 0.025368972282324518, 0.0940210691520146, 0.039832054770418575, 0.006511523138864764, 0.02279589115642011, 0.024111935270151923, 0.05876085441559553, 0.025528461938457828, 0.014109028004375952, 0.018888365743415694, 0.04110141058585473, 0.03728338563814759, 0.03319593818326082, 0.028557170847696916, 0.010403215785377791, 0.023855389661288688, 0.01925848115102521, 0.01570571929083339, 0.032354578508862426, 0.0942812669756157, 0.016220065798344355, 0.032687084416725805, 0.049501687687422545, 0.03727274281638009, 0.05961081452135529, 0.0533961665683559, 0.02320262709898608, 0.05312552609081779, 0.03152009239420295, 0.08981357528162853, 0.008996169099451175, 0.02083839905182166, 0.04135749309456774, 0.0322245678066143, 0.027485859048153673, 0.031077310975108827, 0.07556687082563128, 0.026339250217591013, 0.04759410522612078, 0.03953298706827419, 0.036920389759221246, 0.030224762258252928, 0.044000739830413034, 0.02812025197116392, 0.004405581566970795, 0.01613177651805537, 0.02234800036863557, 0.050863320872719796, 0.10529515240341425, 0.032834933804614205, 0.031499247798430066, 0.0349168081634811, 0.03470526130071708, 0.04324804771957653, 0.03179219172203115, 0.016103976938341345, 0.047587112922753604, 0.04332254747194903, 0.08429937224302973, 0.02032755039233182, 0.021794151248676435, 0.036904115096798966, 0.023694761762661592, 0.042988399509340525, 0.03247437047372971, 0.05191039879407201, 0.03036170419571655, 0.038705859665891955, 0.02002362777212901, 0.006039314504180635, 0.0280523374011474, 0.04472230075459395, 0.03522296655657036, 0.030487901531159878, 0.04370358559702124, 0.04135647189936467, 0.11090183297970466, 0.055262114120913405, 0.01681425721783723, 0.03792982255773885, 0.033439562789031436, 0.008935670917188483, 0.03788302739017776, 0.07381851678448063, 0.03698606855635132, 0.022658075605119978, 0.025036020237686377, 0.017231272965935723, 0.031688514963856766, 0.05781752110591956, 0.0409046320377716, 0.0402449602926416, 0.03386100767446416, 0.04421485494822264, 0.07367349349494491, 0.06801046737070594, 0.08099504240921565, 0.03209073016686099, 0.035442808509937355, 0.041176439595541785, 0.05388219441686358, 0.050242661498486996, 0.025819997901895216, 0.04306374403781124, 0.014516734252018588, 0.013816814354088689, 0.04613570955448917, 0.05334495413782341, 0.08161298425069877, 0.020304838128920113, 0.06904492793338639, 0.0748384634831122, 0.03235074817868216, 0.01931232969010515, 0.038637181743979454, 0.020352167642808387, 0.0438293656334281, 0.01661524798588029, 0.027452702434467416, 0.06267583183944225, 0.060507926025560925, 0.024838381646467105, 0.05258369891505156, 0.06725762598216534, 0.14026874037725584, 0.07879819707678896, 0.0932722379054342, 0.11087499013436691, 0.13071845498468193, 0.12743216061166354, 0.1475806473089116, 0.10768776187407118, 0.11482982470520905, 0.1685270369052887, 0.1338063728596483, 0.12198762276342937, 0.06708492524921894, 0.16691117361187935, 0.13089229565645966, 0.0928928554058075, 0.20335410881255353, 0.06487994428191866, 0.1791190363998924, 0.10186257945107562, 0.15556331324790204, 0.16008935895349297, 0.10720896042351212, 0.07189325509326798, 0.1406094463808196, 0.1357511356472969, 0.07775667974991457, 0.10463117874626603, 0.15624129186783517, 0.17639162418033394, 0.19365972972341947, 0.1699214806514127, 0.22543948729123386, 0.1264558844268322, 0.11302312343780484, 0.10711078319166388, 0.11440510249563626, 0.14813939375536783, 0.1208689356488841, 0.15156207366713456, 0.13472924833851202, 0.13122177869081497, 0.1894662340304681, 0.19371158336954458, 0.11132630413132054, 0.15216943036232675, 0.20272631464259966, 0.13668238424829074, 0.09795505234173366, 0.10496547259390354, 0.15816964767873287, 0.16937420144677162, 0.10778393064226423, 0.14822577126324177, 0.16511612279074533, 0.12851297190146788, 0.10567534914506332, 0.07907968732927527, 0.08772322602037873, 0.12745054891066893, 0.1807953164513622, 0.11722411694271223, 0.16095351401184285, 0.12394039226429802, 0.16697498304503305, 0.12241533052708421, 0.09878199653966085, 0.1393372339329549, 0.074443162551948, 0.12409923731216363, 0.09275352502507822, 0.14213229609387262, 0.056907836347818375, 0.11236104967870883, 0.14591724585209573, 0.2458798119000026, 0.13834018100585255, 0.18468443490564823, 0.11817588444267, 0.15858105703123979, 0.12882550513105734, 0.14442366813974722, 0.09655673416065318, 0.1367862815303462, 0.09757407528481313, 0.1289252226373979, 0.12183956642236028, 0.08343787704195295, 0.1517074430095298, 0.13516314434153692, 0.17832094351095812, 0.10608464146831206, 0.13800076421882423, 0.11682633257337979, 0.10938827241105692, 0.14639296675367014, 0.09466261722679649, 0.0814555301996214, 0.11250860390386411, 0.16761144889252527, 0.18664534682674067, 0.1741598682211978, 0.16861268159534248, 0.19322869713817323, 0.19276532557393822, 0.12348770084125654, 0.10952977410384587, 0.07917764742991754, 0.13443823823971407, 0.09995161449270588, 0.20448065336261476, 0.16785422872219766, 0.07333204788821084, 0.11451065540313721, 0.10676598562193768, 0.08694797940552235, 0.19875003157981805, 0.16278752631374768, 0.09283398570758955, 0.1383652732308422, 0.13521513369466576, 0.09220540443701403, 0.15705083842788423, 0.06050172421549048, 0.09778518109981503, 0.12354575629745211, 0.13474562817386218, 0.2343340500124863, 0.12099066483122961, 0.153027085055198, 0.15289928976978573, 0.19037563380386147, 0.12847082130610943, 0.14082422985562257, 0.11568762867578439, 0.1181154405432088, 0.09527675927217517, 0.08202544533248458, 0.1108516553150756, 0.06416077858635358, 0.15909013471433095, 0.18344502284058503, 0.13166928610631398, 0.09534478240779468, 0.0915898781801973, 0.1137214648936476, 0.18660448544791766, 0.12037022598087788, 0.12550949092422212, 0.07293436529913119, 0.12254687132579939, 0.09656106321407215, 0.10982292158795254, 0.15272642618843488, 0.06892613680767161, 0.11794883305472986, 0.1078317402196782, 0.12472898566297122, 0.16359087106372627, 0.13599151346300328, 0.12024587765336037, 0.15930273330637387, 0.1805450048829828, 0.13877304563564913, 0.13523368484207562, 0.08438480658722775, 0.13913531548210553, 0.19470706209540367, 0.11028174018221241, 0.08029168657958508, 0.1695681403258017, 0.18873868164207253, 0.1228383971112115, 0.18290648316698416, 0.13893693898405346, 0.28002817236951416], [0.02767139087830271, 0.052917287086269686, 0.02215551694722048, 0.016782552669090883, 0.03118810217295374, 0.008789938558558268, 0.044988089706748724, 0.02722197847573885, 0.03828498814254999, 0.05741303959595306, 0.02745178641219224, 0.05360567443338888, 0.04182884083794696, 0.006972011777439288, 0.02048273304743426, 0.013466197498408812, 0.02371804738816406, 0.03484289534389973, 0.014871782789539014, 0.023540184700063298, 0.0731882323910083, 0.030522320219980817, 0.005765950556711427, 0.06094050567064967, 0.07131945195474795, 0.02823415255573179, 0.0645922115072608, 0.03526894408943398, 0.019095283301014985, 0.044082795070218186, 0.0015899437858024612, 0.003314740045295496, 0.024942166970244477, 0.041544846791241846, 0.03045550487669451, 0.04272049352792757, 0.019444399746134877, 0.02674589116525437, 0.026841825838865976, 0.029286134588931288, 0.0186883539759687, 0.02516794780136219, 0.06396102466221366, 0.03463979284944279, 0.023258867474006753, 0.042723126243799925, 0.0323237187362143, 0.04899619606190494, 0.016892225980492573, 0.044416291639208794, 0.05138433398678899, 0.04022400373859065, 0.029724390179451023, 0.028162199006016766, 0.048898463270493915, 0.020227732802075998, 0.03608878741839102, 0.0057945592894351906, 0.08555990031787328, 0.03502045778025474, 0.0028430169872340877, 0.0615148109250835, 0.027880822408146093, 0.031835234590939114, 0.04232935880177787, 0.007991643805455948, 0.01725832954980433, 0.08096264236207519, 0.03455367997022612, 0.016537908564454744, 0.04121300924037184, 0.09721470956823655, 0.005018630322800683, 0.029154810921422074, 0.025074006324367862, 0.04738015974206584, 0.016659741223390614, 0.05253053230366536, 0.03018736819337521, 0.053907985532922406, 0.06404124785746847, 0.05863231274166277, 0.02295777604116925, 0.08624671346374921, 0.030056377008025135, 0.009888429926442248, 0.04844245381121125, 0.024194065148809125, 0.0806722633008446, 0.0457261356392077, 0.05368560246591057, 0.03359539174873914, 0.04678534237401826, 0.03247974107840231, 0.04828874866611191, 0.06516867450305394, 0.023454343234854083, 0.013478623170937811, 0.03927755595317908, 0.05096854129806161, 0.035746693810714145, 0.03369472588279417, 0.05963906193418162, 0.07378250693104096, 0.026687839101733904, 0.013993785616808703, 0.02073853905312717, 0.04180184192955494, 0.06959230213293008, 0.04975279653444886, 0.0392485316177564, 0.01833160570822656, 0.0507028710895351, 0.007417588760810239, 0.05337841269959297, 0.00862873560150287, 0.05276093565459762, 0.08953324532402412, 0.02707678046343582, 0.02751446099552725, 0.0067801411579629135, 0.012479395539100682, 0.031544763927481005, 0.05142785183021, 0.05598436375813825, 0.03276822702693088, 0.04199215403891035, 0.06326912250369787, 0.017401120459128703, 0.05406017415225506, 0.0469203674500542, 0.040136764491243024, 0.01320360105351678, 0.06600857193448714, 0.03661214826362474, 0.0202107626412596, 0.011887196468056312, 0.035007161886564324, 0.07269100192934275, 0.006181640617017235, 0.033447963052562306, 0.04251485670517598, 0.023878856794908643, 0.04678804294339248, 0.020396682932706814, 0.10211994099829878, 0.011269351317813354, 0.007576732364084039, 0.0717678889632225, 0.04714647228164332, 0.022707171006394283, 0.02469165693037212, 0.019318987814975635, 0.06524117596979652, 0.029071792161890438, 0.09754212307078497, 0.024410034363557185, 0.011116857357722307, 0.022301532594220977, 0.04749444878793188, 0.03953805572486349, 0.0706729573596801, 0.02480020048096776, 0.05848230221973998, 0.021289212629199028, 0.014691054987322007, 0.05367093932415758, 0.03602572437375784, 0.02454754796677402, 0.029843425577772514, 0.03271839202248624, 0.020997218654624054, 0.009460351513033467, 0.0643237219857318, 0.0548815747190799, 0.01563294810642089, 0.022604605349312936, 0.042972701601684093, 0.07675358786114625, 0.02039081190845796, 0.018290467826383452, 0.03359403128602675, 0.021376803018418804, 0.0453657792615039, 0.04327136218281729, 0.008370091623094465, 0.020644446602091193, 0.054939351975917816, 0.022773725113698413, 0.031139088195881674, 0.018014137832713977, 0.0777227801403829, 0.0391631345929844, 0.06778205212737833, 0.018057650587122356, 0.05447791423648596, 0.03359927296904581, 0.06720204717878785, 0.057953160256147385, 0.07606773144964661, 0.06066680500017745, 0.06693070781018053, 0.008534666899192547, 0.014254198875278234, 0.04667449010802167, 0.026633415504225662, 0.05659135404442038, 0.026916137297770808, 0.019174593866669705, 0.013126400731770056, 0.03257451545713203, 0.012683042557910085, 0.034569595009088516, 0.03237780476255076, 0.031177744335894073, 0.07517847738095693, 0.01690226829876857, 0.03496051599670734, 0.02950322169012257, 0.05526508949697018, 0.03204644897154399, 0.0174702021093773, 0.06396282956536327, 0.04194941311808569, 0.043825301208666394, 0.0206138175313494, 0.02934279226298843, 0.08273621754986898, 0.03203356019886477, 0.0467590152152947, 0.024802515981718898, 0.01285627085183348, 0.04559602315670677, 0.02664082680296685, 0.03748519552339401, 0.07057933988315718, 0.008967307612432964, 0.0520033818403525, 0.043599596712738276, 0.023366556070478897, 0.026013717953381792, 0.09072339574673347, 0.052626063248940876, 0.01373766578866967, 0.03925884535003986, 0.031166840278144394, 0.048157099301793745, 0.06846800353378057, 0.016291520624820675, 0.03808553616649338, 0.011110669966521007, 0.01107772030601544, 0.035415473726711104, 0.013852743631494897, 0.056418561709246466, 0.02093535492063633, 0.03930608156536307, 0.016352833049105744, 0.030807250645011663, 0.021468690230644176, 0.07942864431866578, 0.017071886786392758, 0.011784616392105818, 0.014604260180411595, 0.11686545690255505, 0.04192485354308571, 0.03099819039925933, 0.029728084802627563, 0.06155225248741252, 0.0005287066409696958, 0.04225886579869049, 0.07086625841579267, 0.00990501671497311, 0.045654753755245886, 0.04840397748297878, 0.07784974082772221, 0.01619842222758702, 0.022009526745283177, 0.05835844922278609, 0.028918005592588867, 0.027275370700018745, 0.04093207538660083, 0.06832499549325023, 0.05921354583863701, 0.03065079064773662, 0.03545133090977158, 0.022332609498075078, 0.02665275544859469, 0.07667134263153587, 0.016603969037532806, 0.02978217082896403, 0.022899262573836104, 0.04926104185038379, 0.06019405608198472, 0.012686106991688055, 0.0877210343522685, 0.024470939666831067, 0.025897422140198093, 0.0626183259966118, 0.08719265234789678, 0.03391777391412428, 0.02047733190868582, 0.04012255596795252, 0.02439591913883175, 0.06211475801787206, 0.03107202857998865, 0.021273533381255608, 0.06150791700929403, 0.031814786938152144, 0.07921168274645295, 0.043247535425637446, 0.0399820008315146, 0.050337591940271, 0.016497718935300196, 0.03013936523348093, 0.03312156056719167, 0.02504533652349242, 0.025817969082189456, 0.01569063715370638, 0.04024514349709664, 0.04412502708977886, 0.010246345274416464, 0.007578782388009131, 0.04092161576928837, 0.04558008436911872, 0.013862163393891283, 0.05384005060685532, 0.012990922733609165, 0.03533531838495817, 0.008563653915189207, 0.013665035400273544, 0.12210126380835261, 0.05967147555202246, 0.026111194597823278, 0.012737089568482978, 0.020162852979930382, 0.038827826335494, 0.10128043033182621, 0.050732163446290154, 0.027620154699044566, 0.06780339205371481, 0.05301499952163015, 0.02694835074778114, 0.009675893250719776, 0.0234420854997422, 0.036887087260505984, 0.028917001360761266, 0.03413711714425257, 0.006156693004803466, 0.04890172702393361, 0.02314600165534232, 0.00825197309521692, 0.09559437472905431, 0.09951854630240373, 0.1177345516958407, 0.10531427352023975, 0.06666874579553093, 0.08966705921505179, 0.11407111398875713, 0.07775313779711723, 0.11941563577524253, 0.10496904168810163, 0.07083402800240687, 0.12705351092985698, 0.15288087432937963, 0.08120726102164813, 0.11310631183109113, 0.2120033675538642, 0.1286406721919775, 0.10260989756456443, 0.1184761497591223, 0.15636570804885455, 0.10817609674164227, 0.13282892959458487, 0.1019150505640677, 0.13582566593374523, 0.1233154750828232, 0.16722161695361137, 0.09626075040016856, 0.09239621526960816, 0.1126339157511081, 0.1159494753394808, 0.14603746868669987, 0.09192304565970387, 0.07505702639796905, 0.13975773565471172, 0.07757720723748207, 0.11769826364304338, 0.10511211758213383, 0.1594800887895482, 0.17882418579288892, 0.15929364093712398, 0.11773117259144783, 0.10589884500950575, 0.1658654697239399, 0.2535052698637758, 0.06055170510496412, 0.1567319133984191, 0.11565500471208777, 0.19622816118810857, 0.10617575515061617, 0.11269908225429909, 0.16651204574320996, 0.26883326736944063, 0.16143038842294896, 0.1352737998323781, 0.09550271821873528, 0.20093761490924017, 0.18924110968198093, 0.08098537328519992, 0.14599827650402272, 0.11227786128542253, 0.0518514680277024, 0.22516793757677078, 0.22749086150101253, 0.07460472852523838, 0.1455033394907202, 0.16624652141971247, 0.09372980120990958, 0.167531246053321, 0.08937448848571096, 0.06489477027207613, 0.11602908106786863, 0.1538746974297932, 0.09379199572971889, 0.13191634070660385, 0.13683058986706392, 0.1364749560930899, 0.11826269621295588, 0.1643091682344675, 0.08521472955388681, 0.11528182402253151, 0.2920204374407019, 0.13543207491082804, 0.11419725364872388, 0.1247782473053251, 0.18289315673921788, 0.13357658019023283, 0.11279751054410424, 0.07285772476877485, 0.14600759957517895, 0.139908601130758, 0.14092605082052095, 0.12761600288961614, 0.18914743113730634, 0.05846878580216851, 0.131029373300927, 0.1546146534383297, 0.055606348506574116, 0.07735360280743667, 0.14644190269921506, 0.12474456482699939, 0.07997761986085347, 0.06731860592429127, 0.1458989389772926, 0.14552081855280058, 0.1537189329309123, 0.1274990505938019, 0.16736917117876665, 0.11654659972659179, 0.11929710927818503, 0.13595890307000705, 0.11145040140088115, 0.10525999750409808, 0.16843122776065553, 0.06291901200477566, 0.1416914111801556, 0.09808197231697184, 0.1745854860969952, 0.24035919670547756, 0.1514953329627003, 0.1522329140986715, 0.12001983049724783, 0.08011929797274725, 0.18901188698198113, 0.1461136003157922, 0.1558687761425972, 0.12173617125621863, 0.12290766196591513, 0.07636645649160657, 0.1669263999376978, 0.2865192826305117, 0.16104975741888794, 0.1594419822629009, 0.12702400822724613, 0.22115742920764855, 0.148793650791049, 0.18361707217991352, 0.1103080062727843, 0.126656798645854, 0.1386147298450981, 0.1056368558534554, 0.1595364207667964, 0.19936652135636124, 0.05904883824821029, 0.09596933996570961, 0.11357467741306339, 0.11450614993061338, 0.2420002743601799, 0.15544356538781098, 0.1296041240649564, 0.16654021851718426, 0.14156243524381093, 0.057370807576392374, 0.12318953898336206, 0.2458612471818924, 0.11973906627723149, 0.24252779462507792, 0.17621500151497976, 0.0619597127661109, 0.11036733058946473, 0.18894296139478683, 0.12784671836665698, 0.16077029598610743, 0.10407450183161668, 0.08846295811235905, 0.1257584182811635, 0.10869313364050218, 0.12860922887921333, 0.11252134679151432, 0.08585013688674994, 0.07517244520464114, 0.09674778248050384, 0.17320165463856288, 0.08108037497316088, 0.19997203243630274, 0.1514784102993352, 0.08247888314404658], [0.0164242709122066, 0.014423941195543324, 0.07100577200097696, 0.07427045503365141, 0.045265861587332826, 0.05596995845969234, 0.0279997746859278, 0.03033765352198056, 0.0175238674440022, 0.11835542480860438, 0.05016714733626161, 0.032691203124289, 0.04636131566283958, 0.04799679879631315, 0.05831595935991832, 0.01812777548496212, 0.061478244672928534, 0.028581102777804648, 0.039189644956163, 0.012134876168732132, 0.05662726551028235, 0.03592412054006543, 0.04706406420362847, 0.03295494629336255, 0.026791161325361048, 0.01752167916856706, 0.020116636263472692, 0.02704090970967497, 0.05170313687995076, 0.06520857914750065, 0.04569081789148705, 0.030870310296969752, 0.005413938039315066, 0.011499462898687592, 0.020997936205406274, 0.012074817337894013, 0.06041436283183949, 0.03884902376947658, 0.026765697602448717, 0.060462633813066144, 0.06949329708835908, 0.04127253033220768, 0.08739828917064837, 0.05479104457689183, 0.027088726072439125, 0.04594699539510267, 0.02545644053524094, 0.028528641842837845, 0.03349549782329372, 0.022597205924934576, 0.0302567551843822, 0.024467065231874585, 0.048056377563625574, 0.010215311627169805, 0.047100403146552186, 0.009100680455698498, 0.02233107600893293, 0.024238351433138763, 0.005046666117518076, 0.01613625484917845, 0.05688092225630369, 0.051664043084851334, 0.02029795099848083, 0.029011046314345937, 0.01822467876731285, 0.0315979305388672, 0.007867617782072296, 0.029780705193323747, 0.020435705481629287, 0.02802508064944829, 0.017183941755709902, 0.02579086839354464, 0.01511246764234134, 0.015612010212082948, 0.04593973167772804, 0.03930377793897476, 0.017646694156740392, 0.03573345219982522, 0.06721859664789268, 0.016124317721862878, 0.011069201298856308, 0.04420866670885256, 0.030161594040691853, 0.015019233538103955, 0.0057242342237649214, 0.04260791439030852, 0.02516992064192891, 0.020983624205525433, 0.049456215663147826, 0.06840541546366044, 0.03727295655491097, 0.05729133076965809, 0.06360216784690108, 0.04820539063907095, 0.04314192823533501, 0.06896448760692563, 0.03690556716173887, 0.012456307536922395, 0.044145349213587384, 0.014926779749138015, 0.004194181013320173, 0.05467397353744932, 0.0283177853894553, 0.01896238712860005, 0.0368593691049942, 0.059836753111864836, 0.025127079637188996, 0.025547425295891504, 0.044522604505930624, 0.0919098210121904, 0.042792326637676785, 0.05305891091536198, 0.020530552802873508, 0.03895058349839278, 0.028409784559958746, 0.027184692976464118, 0.016261629460911666, 0.07274312020412513, 0.08407185266592673, 0.06354469593082156, 0.03577705825279866, 0.08946165309420653, 0.024740570823528936, 0.020537226194781915, 0.025814640867922987, 0.12974261306226254, 0.04173060593062213, 0.0074207286816090345, 0.02347304705264313, 0.01834772091491946, 0.012001348110581083, 0.012256255905543054, 0.03409385375146355, 0.03123361151665449, 0.03909354404147182, 0.021442458066823225, 0.03834930647696767, 0.03918199786650283, 0.030531734893364564, 0.00807894327278648, 0.002929890461798225, 0.02882406920460718, 0.046100218780338764, 0.003533443544126515, 0.03564154463154929, 0.02383558322409434, 0.03838477010971733, 0.013457851517679436, 0.017640941876119802, 0.04055284555735333, 0.0856228412262031, 0.038767759022968154, 0.05565307582063334, 0.01724354427174798, 0.13577815491173947, 0.022847291880420277, 0.044652048631438186, 0.04533911622794611, 0.05352731720943536, 0.04257882220138397, 0.03595970970179353, 0.042002399917691946, 0.019554746503542577, 0.07854752588484969, 0.021966331205996018, 0.04955456931410091, 0.0012592280441562512, 0.04498133149796298, 0.034898531822753806, 0.002044095013323905, 0.03033471546534981, 0.0487473094170647, 0.05345637298056057, 0.051530843268015554, 0.017442295660397837, 0.013991314053003277, 0.02546925127639302, 0.043345135902719836, 0.026325877988711, 0.06243005967033761, 0.05703051547919001, 0.02948032452591828, 0.05217073232467685, 0.054152583836444786, 0.01682088989764452, 0.022773599584719965, 0.03617602666573865, 0.08744518272578716, 0.062055359062339575, 0.03748351275654776, 0.04083548253402114, 0.03347090432154281, 0.019292516467560614, 0.039525513005043776, 0.02594667360452669, 0.058594158717564175, 0.05577775663030999, 0.02763586108838873, 0.04668532631226948, 0.022723822255751917, 0.046609720547816584, 0.09833975455590657, 0.028262669686228037, 0.040406488946505954, 0.04559070683483567, 0.04684398815568004, 0.008497387337099229, 0.06477268146617071, 0.08622981115643467, 0.05338049580210021, 0.029346731158771684, 0.016107032042262808, 0.05187937617301941, 0.013863972537884755, 0.028052861569449306, 0.03452658945960658, 0.006747177926756973, 0.038393048236944845, 0.06410489444221769, 0.03974930403221931, 0.03888819559610315, 0.04278902895748615, 0.01803118602505752, 0.011726603344348925, 0.040845870905156643, 0.036479396279901266, 0.05671992285975388, 0.05228083480947784, 0.00958672272307532, 0.058950179256498814, 0.03279282392135688, 0.0931387972086668, 0.014008244349887329, 0.06211108714342117, 0.05371676079396691, 0.0699379410860794, 0.07081371266394854, 0.02167016763373145, 0.012519389241268592, 0.04798258688034756, 0.008660524967126548, 0.018424760084599257, 0.017991639307833145, 0.044335810600646904, 0.008270290148045336, 0.025210293475538492, 0.009649787464046052, 0.05234101747295686, 0.061799795632915835, 0.06896121028278555, 0.05142021831125021, 0.041962865074830394, 0.03636030659877828, 0.04129900676863534, 0.037126674582915645, 0.03234434620078121, 0.02129400478276823, 0.04671866613041077, 0.023800402879714966, 0.03741548962092825, 0.011576126329600811, 0.031563111514385254, 0.05312098329886794, 0.050534462090581656, 0.06218181763376508, 0.048797945092831335, 0.0323791889739888, 0.06389089128268616, 0.03467347872044359, 0.059393567964434624, 0.02161538101998823, 0.003559488686732948, 0.056011498373533995, 0.007780316618404218, 0.04400847852230072, 0.03135745094290801, 0.02676423535948353, 0.042095281183719635, 0.04388221333335553, 0.017043985426425934, 0.08091684124831643, 0.02069661407066243, 0.031286727237914286, 0.05071148509159684, 0.021269859114129628, 0.0805547342502645, 0.04916837093021188, 0.020749017330152646, 0.0207706286704966, 0.022709428831668835, 0.039304273269538365, 0.051678183754639964, 0.04864745959639549, 0.007402342078941209, 0.03155070450156927, 0.07665533599044595, 0.04881742922589183, 0.013413890081989979, 0.03340742737054825, 0.0422916424327663, 0.035108273782368214, 0.045892712593610795, 0.016536454803177288, 0.07565446969653879, 0.024157035796503936, 0.06632267257996968, 0.023616645418639694, 0.03487941409860339, 0.017463160612221276, 0.08420365130794899, 0.03631585916238172, 0.05399642239457794, 0.03481586590143187, 0.02001420800973262, 0.040026590760265074, 0.013617428535196398, 0.026419755004878556, 0.016370781996686543, 0.0789443263784051, 0.017265321853171502, 0.02862954678546105, 0.0801114948200328, 0.01790708366648427, 0.05803621294242995, 0.008625180078005152, 0.04457602896062391, 0.027867803017475774, 0.05818713948662792, 0.03362088430938976, 0.032692943566611836, 0.0559385524663542, 0.042270794444318326, 0.07363430809761796, 0.021951547624277215, 0.05403549922630191, 0.03197865993050592, 0.031068045579429184, 0.04817975219339132, 0.012401877154063965, 0.033348805337612114, 0.008586230471597185, 0.022085244468014156, 0.020352635831971253, 0.015107984222205622, 0.047578061265604835, 0.03314187929832509, 0.057151973247528076, 0.07069890453879323, 0.028181647515988777, 0.027150535523625355, 0.031947477853723934, 0.019020376427631294, 0.1375770733824798, 0.18091768345662526, 0.18431616680962698, 0.2302160481257098, 0.12865436502865382, 0.1670197392148631, 0.13202852968658718, 0.15373547561466694, 0.10178910767925636, 0.1856389572577817, 0.13448408006557397, 0.1510712621467454, 0.10732511883335454, 0.12731782746102127, 0.12298909973885332, 0.14628657246274607, 0.13245209838662828, 0.11084339075854846, 0.11439565728817667, 0.10804243212831871, 0.21692760474979877, 0.12167504882173878, 0.08008948992937803, 0.09181783201971225, 0.1310995202511549, 0.26035155249493463, 0.05078412905069334, 0.09468573491488184, 0.16304025346679346, 0.16060007869132928, 0.15157155958669527, 0.10271007647471768, 0.09921526829046862, 0.12648845410772733, 0.09785558589334999, 0.12435062096587249, 0.10971924143710307, 0.1351499129086733, 0.11905713858348982, 0.13923541296805653, 0.1643546572221177, 0.12635850108095578, 0.2254362574645451, 0.14816041477024555, 0.09560229323272194, 0.09366790524550847, 0.09641881513276271, 0.13029168359935284, 0.1715430843510798, 0.14102822462362902, 0.10199454772685256, 0.14290419753108705, 0.13095390663615294, 0.11894310398825578, 0.15248522056000574, 0.16167941077479295, 0.11662027505891663, 0.14536490477621555, 0.09497349483094045, 0.14794858970812388, 0.2087209408304521, 0.11330316162535123, 0.2519482491271836, 0.1018912543409637, 0.08263420659516539, 0.10557215753942728, 0.06886746388460908, 0.0813444811584694, 0.07427350165588514, 0.08996447468442575, 0.11688498514039175, 0.1044064818748406, 0.14917611383966037, 0.11812499431627137, 0.15686376632324286, 0.15452051348984241, 0.08830718004277774, 0.1236891443175929, 0.128430272053395, 0.10938273556530476, 0.1511112685714449, 0.1372412664017507, 0.0584988109767437, 0.11783539557031222, 0.08208083414605685, 0.12740364857017994, 0.10242281867457287, 0.1169532864753689, 0.13552554989499704, 0.20557237549551896, 0.16605178186936037, 0.13569719211331435, 0.17526847230536596, 0.1910386575119836, 0.19022278700556072, 0.12324782514146396, 0.09895524688597236, 0.048680426220276525, 0.08650630739118371, 0.084823153779975, 0.06553027938519206, 0.20721747007753166, 0.11740851561938014, 0.09494655020534992, 0.13963960270796502, 0.16812256218067237, 0.22445774211415223, 0.14308052164103302, 0.1289333514869213, 0.26524935396654264, 0.11531393229961395, 0.28959524471844944, 0.11592856289020606, 0.14876640082470008, 0.10267836174794606, 0.12303977273404598, 0.10041522354419742, 0.1244770320398467, 0.2106466774961778, 0.209079044471894, 0.13643315833594116, 0.17189087426023825, 0.14496783965400287, 0.1852418514234679, 0.12673758502517427, 0.19931698829999991, 0.07527552145932402, 0.10953579270946127, 0.15748291595705918, 0.08872183279267379, 0.12490849888750485, 0.11566093510815076, 0.097562390911792, 0.23907603270241193, 0.09094819439841167, 0.13016789167055062, 0.09783731294529778, 0.11312346519636256, 0.09742001390882901, 0.13930462353995868, 0.10173335245677403, 0.07894828223756381, 0.1479062084108591, 0.10590050063495125, 0.10112007215086903, 0.21485493811113493, 0.11496614239045552, 0.15137638577393123, 0.11935551757259028, 0.11938617378473282, 0.18798423212553772, 0.14487889728375844, 0.1599081086793116, 0.07831974846443959, 0.20630874883915695, 0.11222032830119133, 0.1705052378986563, 0.11248057362224374, 0.19900612426655634, 0.09936661552637815, 0.07247623881059033, 0.20318486860820226, 0.07904784368085009, 0.17417725228837558, 0.12017644995025226, 0.08645266919795956, 0.07464260434997932, 0.12389193129326616, 0.1313326648835625, 0.07168605085462332, 0.10228091664612293, 0.27268208084361895, 0.0970844579860568, 0.1634599273758275, 0.11781938214387212, 0.04388668487912842], [0.022361262335575054, 0.03160536388999649, 0.027334113172920685, 0.037999701486634355, 0.019804462657443116, 0.012942697553496276, 0.015621077136269637, 0.03749642527795263, 0.06674459243991546, 0.007104968593921512, 0.03299304942733475, 0.045468428039125035, 0.006859274880428399, 0.008254172396846116, 0.039628887815134864, 0.02223599120043218, 0.012703521592941667, 0.06579110146101032, 0.05002305024702634, 0.014527916509125913, 0.04317045384751899, 0.05130200054762619, 0.01182370340185506, 0.029105766410274164, 0.06015799194574356, 0.02789728027502341, 0.04911271409530725, 0.008082518304165984, 0.1132163227136646, 0.029577042907476425, 0.05487169524920838, 0.04362128608460937, 0.027276247706530348, 0.01799905569558697, 0.06185546264584575, 0.05171158124825784, 0.02781635140334921, 0.06638889759778976, 0.04924976120569876, 0.03407673431294305, 0.03681530843355826, 0.03461636982059904, 0.021505500755405853, 0.018521018758682267, 0.017166350735351443, 0.024637294401015555, 0.03585145283224327, 0.041005391095365794, 0.013587442376384777, 0.014648889124925648, 0.059578923375478814, 0.029239739757031202, 0.019445570219042044, 0.04189233135964189, 0.06303162167647056, 0.02094577212951013, 0.00714794742608709, 0.02934937405266932, 0.024812982384381548, 0.012170196460959102, 0.03807246418935912, 0.05297020942504917, 0.024636636222047464, 0.014965763282296913, 0.060263266653886864, 0.009839946054853499, 0.008208427262226385, 0.11218632691140686, 0.018198750247912746, 0.008529353121827756, 0.04225226365295904, 0.019587450195103884, 0.024885987663375478, 0.017123319740806307, 0.018824853169332658, 0.04475309267374022, 0.04701966765735831, 0.043339806010148356, 0.044911187940410206, 0.036099871287920644, 0.027362487811063017, 0.04068221165133374, 0.020329053347398127, 0.024969778256490827, 0.05980153714439698, 0.025936699139752557, 0.015797409727903347, 0.024708035069384744, 0.01321836088650993, 0.07464631593653134, 0.02708442585675844, 0.03386057001937713, 0.02590312353069229, 0.00742758358163493, 0.04108276105086718, 0.021676500061792985, 0.003110333491349593, 0.04842285093452249, 0.010742361158398646, 0.03303262498229742, 0.008721047746283668, 0.05958988171602998, 0.019058789991374527, 0.029503537208906243, 0.017467109686029807, 0.004444680875167251, 0.031465497466602495, 0.04275708692148328, 0.036479932322565994, 0.029865142091044357, 0.04357858248321073, 0.035914872107761245, 0.03676040137984923, 0.015006911342165299, 0.0358228220471314, 0.017862240983439342, 0.0779574311205319, 0.015181308412658317, 0.02755020622030965, 0.01701449629451547, 0.02136166320581521, 0.021282189791756015, 0.02710608808722879, 0.05304244965580957, 0.017719867373151437, 0.042862239493323226, 0.023668980824628046, 0.026416944173563803, 0.056414500677159855, 0.009426218657089131, 0.012912959059966462, 0.034280522127768824, 0.042491508315184286, 0.02097684394435159, 0.0732473260057824, 0.029945137977067913, 0.08024015184491873, 0.025660749125693525, 0.07802666883383479, 0.08252199047378131, 0.0041780119479101685, 0.03272665997168847, 0.06179811965141978, 0.03653864595772965, 0.05397883815956967, 0.046278765092470815, 0.03789325969825898, 0.02713980958131807, 0.06261619539665324, 0.0034908253957317875, 0.033602987948272905, 0.07529628463089466, 0.019694061617233923, 0.0172079669843827, 0.045767784118652344, 0.020995914171050702, 0.052519804665020535, 0.018539083057216237, 0.046724321719791205, 0.03199886670336127, 0.03689428651705384, 0.03958371773894344, 0.04120717044653637, 0.12115660735539027, 0.016116838569619825, 0.04568885013993297, 0.053331057740641494, 0.017645944375544786, 0.05508054154259818, 0.018153096715520536, 0.08169276639819145, 0.018841149884143045, 0.01527972991711327, 0.0750257730750101, 0.024161926337650845, 0.039078792690166404, 0.11522371428353445, 0.042104468547872136, 0.03143534337037376, 0.018578322737344673, 0.03885909662182842, 0.03225249291530677, 0.03104746900498867, 0.02774463703722826, 0.0254624099470675, 0.02874765937615718, 0.017545965633222034, 0.05942483485809394, 0.04358134751341172, 0.009731502588173109, 0.03985788320590343, 0.0173972307571343, 0.02127603378279933, 0.05217732089970793, 0.06596818553017718, 0.03393094427883625, 0.027400987888021127, 0.004999073671310076, 0.026864108928878392, 0.025710984465799162, 0.025948056119627187, 0.029949694339718138, 0.04089151595586112, 0.005752379432254071, 0.020653698427070464, 0.08842019005013363, 0.03397209742771728, 0.033508159286741696, 0.03399270114355853, 0.04654923593625426, 0.04135167465678283, 0.025650538870000412, 0.06001747412873166, 0.042219517552959065, 0.025255919866529957, 0.022040503565222025, 0.05412121516253267, 0.012515903267610286, 0.02823045793255525, 0.014628940195377384, 0.01803747095566775, 0.028661417575286965, 0.08389880588012082, 0.07326307480356523, 0.020283715333789587, 0.04170123214966484, 0.036127508019230196, 0.04253557577197041, 0.004806244621119861, 0.01794304771881018, 0.04425983503460884, 0.04124306155634778, 0.041089878883212805, 0.012176894449761935, 0.02575144381262362, 0.05799279348658664, 0.034037280894283733, 0.02915696187743119, 0.041367253820810995, 0.020329314583380307, 0.05899038924170392, 0.00405644391763157, 0.010161364700512161, 0.034696151968091726, 0.027152425243652294, 0.04475947090291551, 0.03314232373876231, 0.03595236116754157, 0.022679673374763558, 0.011407035402953625, 0.04353139376533883, 0.04388342791103891, 0.03322106094232627, 0.02215389015951327, 0.04744525160640478, 0.03279820470405476, 0.04923790380624788, 0.04771072164710079, 0.025846314882593494, 0.01797942228482238, 0.030163158063909838, 0.006344059848093561, 0.06239730678498745, 0.03086217466209616, 0.010663495033181139, 0.06959021224507264, 0.019634866222207035, 0.03738929477653333, 0.03906763418178473, 0.0404780574275979, 0.06642657664737531, 0.01507171313278377, 0.03796253473098789, 0.019004751462489367, 0.032950318684535365, 0.05199863209522196, 0.002554463185203661, 0.0338806648339544, 0.019752573388229524, 0.027111719927883575, 0.011502439971081913, 0.03239759084369455, 0.01758388047372656, 0.05653043856312122, 0.00867136795672455, 0.021124326923329915, 0.017286704187946658, 0.045070290831582885, 0.0887044555108462, 0.027073262259364128, 0.016005172061600854, 0.007686001098980861, 0.040850681718438864, 0.024008706345089843, 0.026112385426781008, 0.03518348938918539, 0.040078098353530676, 0.002120478548541931, 0.05870490920330797, 0.013793908708196665, 0.01635518078027027, 0.03186592812250767, 0.02580556206937347, 0.022887661321354762, 0.06054793245026043, 0.01892998199244695, 0.05264229719926204, 0.003622896087888096, 0.038976167661270926, 0.07228142462138619, 0.027629201267180697, 0.01693891597512577, 0.07637303149593727, 0.04202992808339851, 0.022767737042158842, 0.083589061429458, 0.04387597420385905, 0.03910501467596207, 0.06315028388053179, 0.04360162553244403, 0.07930912716048104, 0.03600097480895264, 0.039176559408328364, 0.010015575514574136, 0.04930116023336138, 0.023303749172815254, 0.01254280039574951, 0.007247107685543597, 0.003215969095305939, 0.01947826542891562, 0.060874294223529954, 0.041405550337263515, 0.10356661837015833, 0.04743803199380636, 0.015398968875940357, 0.015708635295076028, 0.03672022532139506, 0.023555553518235683, 0.08776604158005544, 0.016590069247675792, 0.03840294127751674, 0.03498183556699327, 0.05453510116785765, 0.11917448442961488, 0.007738054912936474, 0.018372007379574434, 0.021162375774500624, 0.01371584749514503, 0.02042026541727994, 0.10727444583816187, 0.06809417145060641, 0.05004941472517593, 0.13907746358641557, 0.15496057059083665, 0.09385198501071759, 0.10587713867425919, 0.09134622982570104, 0.09115829598158598, 0.07307387888431549, 0.2099503105772393, 0.14819008032126085, 0.121451539386596, 0.15327852299170835, 0.1209166773727962, 0.1629354062357119, 0.08758895751088858, 0.23602737486362457, 0.07930901859487806, 0.0932687230940376, 0.13305651023983955, 0.18214338911431177, 0.04794947437143751, 0.1903481124235051, 0.09014313295483589, 0.08527525487755026, 0.16979638593537466, 0.13449032258774551, 0.08997749577143363, 0.0928021827712655, 0.06049546812261854, 0.18428336642682552, 0.15534448570438794, 0.1406875050493649, 0.08452546689659357, 0.14975276003990853, 0.13574642661426747, 0.19646658482296125, 0.11415344742791993, 0.1324446209307228, 0.15303347685507365, 0.09338861344648258, 0.1010409617530448, 0.13713439713631356, 0.1480344786707844, 0.09517330982323204, 0.0952144426160625, 0.08779155449675662, 0.12391386154506888, 0.11446892549949032, 0.25742790794798304, 0.1415181133363928, 0.08142205806715147, 0.12015803450984613, 0.0665156886513744, 0.1853691174515656, 0.08308862828250442, 0.24148244357534818, 0.13688384129532746, 0.14788541809788772, 0.11633477466447012, 0.09209053524370704, 0.10872296203992196, 0.08146275659757, 0.1304105765053204, 0.12867393397859164, 0.158426826021501, 0.15284877962299756, 0.1447552139205592, 0.1689813161002738, 0.26964259679828373, 0.14781331696680614, 0.08271441621971981, 0.13561146599905832, 0.09916388283350638, 0.14518536441028118, 0.17060070777578012, 0.2232639683144433, 0.20147764735988208, 0.1333708076604775, 0.15387171187571116, 0.1513187645801476, 0.10013970439987523, 0.13938454139445508, 0.16233890610081808, 0.12776215933263302, 0.24367405740278109, 0.18168176817042486, 0.12455640706632819, 0.13062347365277155, 0.050603737123310566, 0.1409670343356473, 0.15903539050902638, 0.08299290056207351, 0.1437717859766313, 0.09071367912526641, 0.09979932409312044, 0.16387163528374263, 0.09491502546838351, 0.11006223410367966, 0.1416801746402468, 0.13355774405811513, 0.17123641366405146, 0.07416509211595569, 0.1329764159662383, 0.126966549881867, 0.2949633795235838, 0.17993466263370855, 0.07090644804494721, 0.15859818325511046, 0.1324642984462636, 0.09826750414712088, 0.135891551684056, 0.13651664528463567, 0.15795274717467173, 0.2247688097081014, 0.07804797483342034, 0.12110621934490544, 0.06747654852058206, 0.1314003283956221, 0.14901064629001276, 0.12861624493130616, 0.08152567714984928, 0.24589555391243526, 0.11408566177955695, 0.16227382102182933, 0.11275150586983987, 0.08698690017419201, 0.0762828066945076, 0.12588508719844477, 0.09826343972235918, 0.12680903476263794, 0.08525401673146657, 0.0887998982465693, 0.0859469570485609, 0.10326852436576571, 0.214179877191782, 0.1832284073212317, 0.12729772925376892, 0.14151398784347943, 0.049577381661427875, 0.13277571887842246, 0.20784450428826468, 0.09463221885796104, 0.08111162151076964, 0.1865708301109927, 0.10621834679373673, 0.2380461793925081, 0.23130854378853524, 0.11683496353881699, 0.08526741779808487, 0.1519516206213406, 0.10444730932691268, 0.11966654445443835, 0.2001641664121832, 0.10316548203783375, 0.045908824407628605, 0.1528643180749246, 0.13199385654713425, 0.23007086877311977, 0.0888761995094163, 0.09049626971994128, 0.11067064931350094, 0.17385911435953208, 0.17307027668825217, 0.1929493849830968, 0.18010886971439632, 0.17340620580528462, 0.13314896742148058, 0.14741640112229756, 0.14366954432002135, 0.10045418502496821, 0.08374998279448066, 0.15418078457670553, 0.07956994245094912, 0.047299132482813935, 0.12786811936114514, 0.14353781353150094, 0.12120008787938527], [0.0520804939525468, 0.05912759580782481, 0.029796616839511052, 0.03170923403065119, 0.08151407420103039, 0.04468706103840044, 0.013101853879301675, 0.03338513410251055, 0.06364240497350693, 0.006185718612479312, 0.049529002114598236, 0.1212504216070686, 0.031250171163784604, 0.08558082633784839, 0.03487039976088064, 0.06268368248960801, 0.07783900640372719, 0.04542396024667791, 0.0437288576337908, 0.04089456257809486, 0.03543563639479024, 0.01698858643482838, 0.05335752060636878, 0.04544673188190375, 0.007985662519266563, 0.0267693973146379, 0.03170871834403702, 0.04256864756877933, 0.039766932372003794, 0.021375900566844002, 0.010645259404554963, 0.021352867695635984, 0.03800569973619921, 0.009200919585834657, 0.005259332563062864, 0.050595818619642935, 0.03179414251020976, 0.04561124948252525, 0.01699038964164044, 0.03798113337584904, 0.04543223837390542, 0.06657127424010209, 0.034396415908953974, 0.04118361849603908, 0.06899346105222191, 0.061472300706165175, 0.01362832835210221, 0.016111322079918215, 0.043165415725005526, 0.010545217897742987, 0.05801692219184978, 0.023047975397535732, 0.04872185078316501, 0.09263389930129051, 0.09996499520327363, 0.04993276437744498, 0.01970271802773433, 0.009999841135660452, 0.029526532760688236, 0.04624298594093748, 0.014281423396563955, 0.06160726810672453, 0.07037327558334384, 0.01610181580430695, 0.029211047903767655, 0.047163052284823995, 0.025081823047782694, 0.03654289358694639, 0.04081304677362953, 0.04240364820829459, 0.04830984431984169, 0.05055291145773871, 0.05260808885629688, 0.020054272109908716, 0.017184567704264606, 0.03130307653918862, 0.07942470881555762, 0.02041550719046167, 0.052819703572562764, 0.06981355204646077, 0.0025264329035832945, 0.12225404275315148, 0.023557148075529506, 0.013475035417026706, 0.10059186656560216, 0.0718807496928743, 0.00903459029671337, 0.03914240874083979, 0.026669747661799192, 0.0420335514603981, 0.054657366392867904, 0.058777661728007455, 0.04097479934405003, 0.03630297378237758, 0.03369146212935448, 0.02946499302717192, 0.038964452754173956, 0.037768256584448476, 0.06766121182590723, 0.007563401695473918, 0.045201000424900224, 0.0317455254761236, 0.03730288673458355, 0.04138774557837418, 0.021284395030566623, 0.06604611527706895, 0.002786853159445205, 0.011577952436969748, 0.048198873310216835, 0.021362804840984087, 0.04212177458352276, 0.020365282028381313, 0.07473182491958141, 0.0372373945345836, 0.08171376705701862, 0.011890346566880388, 0.04378374433144927, 0.05679524703217404, 0.01582249516754278, 0.022139164253271053, 0.023374479663159167, 0.04612517190564956, 0.021726582731519426, 0.055825698522052596, 0.04904744241918836, 0.03042913700586983, 0.01226116341006543, 0.034728267030524354, 0.06552468825663839, 0.03493504039943218, 0.038327946194580624, 0.0067542652250267565, 0.13297518103250436, 0.06924082777862038, 0.029967451601156166, 0.04260065745828407, 0.055065457709133625, 0.03148653544485569, 0.0021508593178753343, 0.014010221431297916, 0.014302664935322744, 0.013812299551708358, 0.016368110265050615, 0.013155689695850015, 0.027795810451997176, 0.021620414053489054, 0.017335484070437293, 0.01720893898579691, 0.014767096710524388, 0.05164833160649453, 0.024117029371804426, 0.028979619964957237, 0.026366552770403878, 0.042992735348109684, 0.05140891391783953, 0.06069558845566852, 0.02314712293446064, 0.048774281184055975, 0.02612046168984047, 0.07722463365644217, 0.025967876127521907, 0.04145406898377197, 0.01717319376101451, 0.031099305687738315, 0.01637267510938857, 0.03142257673399789, 0.03556304830791695, 0.025809400881241475, 0.039001982526055405, 0.028019084096220986, 0.030175117243613516, 0.05249264969357422, 0.07165042098079409, 0.02786802014868174, 0.0186885541437992, 0.050996052500392706, 0.03794719644689134, 0.022585407897297825, 0.010402360831254294, 0.021724740508943796, 0.09898144512304238, 0.06730310139911515, 0.0568045565326299, 0.047867639655513425, 0.016286801413765976, 0.01225938055930393, 0.00955122770808105, 0.03228886578498142, 0.018627898202144673, 0.047358829993754625, 0.04952775700283902, 0.022254750997360264, 0.028383258929742233, 0.06318741331675223, 0.04422093462198973, 0.03973067146060722, 0.055489107833376954, 0.031588403907205374, 0.0360414562081652, 0.017840677140546695, 0.028050741147516028, 0.03277055100936975, 0.019636752549558878, 0.036017391963728836, 0.06474034927253212, 0.024038295560915555, 0.05906279571354389, 0.05106328853539058, 0.058926070907286236, 0.02772526995145849, 0.06065522240740912, 0.01697843724728695, 0.05339499609544873, 0.024489573934780698, 0.035980255742158206, 0.06820750715477125, 0.037649343322430334, 0.046059007955981154, 0.006757593863377613, 0.0477512810778405, 0.026852202335638658, 0.025032430787437727, 0.022996228620676056, 0.04522761596100671, 0.01461650095214801, 0.009735477107044841, 0.0924112991030727, 0.03272011550143361, 0.022979344973074536, 0.04115478075774653, 0.03357637580484152, 0.07055987949882235, 0.025484574293451648, 0.05155040882527828, 0.026251644561333314, 0.018604483654988662, 0.02087953863000231, 0.03455581396285977, 0.026436762485120977, 0.054952128790318966, 0.04195830871218017, 0.008709109770799322, 0.03541939905179398, 0.019995514369968857, 0.049079683010599444, 0.029745458691780056, 0.03340103557067258, 0.04451281663828662, 0.006627084861975163, 0.011168392940557428, 0.053368957314108095, 0.07937655318528414, 0.09278737035180841, 0.020614616506333863, 0.057915386211659224, 0.024138048690344607, 0.012343562158223773, 0.04474151686632207, 0.06225263633366142, 0.017636224361402646, 0.05506529825340424, 0.013705516799486108, 0.016169995002980744, 0.044874102608965974, 0.06528633247528758, 0.06382183677383832, 0.021064715925604105, 0.020217653164373975, 0.04526285228452512, 0.005364938057027757, 0.021370984580633894, 0.02713565694700394, 0.028674221531088864, 0.0308306261764041, 0.05897686603878226, 0.037717519128429036, 0.01838897245137819, 0.06361136878175394, 0.02695027269822146, 0.05765326813395534, 0.016724868710818033, 0.030816858700875725, 0.01872514414467982, 0.04439673965264644, 0.017507994813578467, 0.047655102131622176, 0.039985234050878456, 0.020689737118248428, 0.0630484154181821, 0.004771002360420036, 0.041523333838475604, 0.04927391026701246, 0.025577469130179713, 0.014186145205582892, 0.021424380197588886, 0.03965823106201632, 0.020011018895144974, 0.050232856667467525, 0.05305444954761437, 0.019463868612157445, 0.05000150676018425, 0.022080742388165424, 0.029494821426591704, 0.05996916243540389, 0.05371795840827482, 0.049675538537225554, 0.08888546829777104, 0.042517455494297404, 0.020309179056701914, 0.07805807821984802, 0.01467901947242873, 0.0020911359377870603, 0.029561283931668316, 0.034803360501038175, 0.017286095202767422, 0.05634416712980185, 0.029836334886827638, 0.03561865086002009, 0.00974034729214119, 0.03429895453155041, 0.03868724066498024, 0.025974873519901718, 0.02542876818084291, 0.06244012913001435, 0.04814657522365451, 0.02795573776321752, 0.014597683479743344, 0.03292048689244049, 0.036198031556393416, 0.0798282471618482, 0.0370157985681934, 0.02774663532285818, 0.07031634649527924, 0.0165692059921899, 0.041918342999581776, 0.029751076961734464, 0.01865343317123396, 0.07343033368566207, 0.01241893382809524, 0.05282947786950639, 0.04338585818186402, 0.04207606507199151, 0.05418291774445346, 0.02657293767801353, 0.06835808086075953, 0.03878183862460511, 0.049195169670773406, 0.0371080725453794, 0.02033669195537056, 0.025384369938235198, 0.06974987153496061, 0.07730169487851006, 0.126554082014731, 0.22338934801518917, 0.06688585664544787, 0.2616234528166907, 0.15322822997612612, 0.16707240710301058, 0.08594878909311124, 0.1319415279264961, 0.18615249970129558, 0.1286278207387243, 0.08457721876246588, 0.21404341022883142, 0.06128366118563073, 0.1588711171810116, 0.14159108299229825, 0.09444168622472457, 0.18980529797928675, 0.12361187274966921, 0.16975632522787365, 0.09115002463970866, 0.18380164727568626, 0.1246441009321383, 0.10768513594354902, 0.15449539412345203, 0.11014340046261038, 0.10575650871864387, 0.14103083019810064, 0.10577277998839106, 0.12577306106686592, 0.09249013130153928, 0.10403826127627067, 0.11727424710988998, 0.08328520666275706, 0.2076039229120527, 0.1256625141416277, 0.1264911275357008, 0.10263002291321754, 0.11324541829526424, 0.1512862763234547, 0.1785268924598183, 0.1588754869465317, 0.1102823508637292, 0.07675527741334268, 0.13599588322852338, 0.14508632543895925, 0.1510942102010761, 0.07956028011228357, 0.11696875707379409, 0.09853526085082974, 0.1984813181417329, 0.20272683032921382, 0.11102317539708954, 0.1333026827446052, 0.2242598405906132, 0.2031758983752557, 0.19417928398719855, 0.14863236301711627, 0.14789244772068091, 0.09927409727658544, 0.12872182498020784, 0.15105298241334303, 0.15143917740455695, 0.13281449036938803, 0.12419453077018261, 0.14588954805263452, 0.15268347492175444, 0.08338607089327914, 0.1312617715448141, 0.15132090875080653, 0.1781904205147709, 0.0889980983255165, 0.15789885792349065, 0.22167255942310604, 0.09594357599105154, 0.09467221171196018, 0.17048915661871433, 0.13187904842197895, 0.11827560194901057, 0.19562161873493875, 0.16940421983599663, 0.08790459843086344, 0.1683545940156494, 0.1599592159369162, 0.10877266473003797, 0.21198857549045766, 0.1381225883960724, 0.070097586805267, 0.17635452188551426, 0.12765139527618885, 0.1422326107110296, 0.2094558078263487, 0.16124024934002332, 0.09974884108773299, 0.07214731896030051, 0.1270919567240136, 0.10148559218006474, 0.25655273348093033, 0.09520190328891788, 0.12708222653184617, 0.08594175947031804, 0.1190499732536929, 0.14523373038641044, 0.13751149975827762, 0.14556841099900858, 0.20435235596128873, 0.11435320813741003, 0.09999541392815964, 0.10000132396817207, 0.09013279208115169, 0.09407014080456325, 0.10965726404849972, 0.08082667751503841, 0.1748254160795893, 0.11808508288647447, 0.1476142212216343, 0.15363730516816887, 0.04933133129296558, 0.08488509724182741, 0.15740328308727058, 0.10373924446425267, 0.08830758716378893, 0.11873323310698781, 0.12558051996997424, 0.09517502651682921, 0.09540257323533297, 0.06633198208042554, 0.09003612119704485, 0.17153836174735002, 0.15362081676721573, 0.18553545352603706, 0.09282041500721659, 0.14503149980945246, 0.1480084636381694, 0.1511428068791117, 0.06381763664207288, 0.18521753272839955, 0.11502395357404437, 0.13577379871691975, 0.0668439706787467, 0.1474409912313734, 0.08086650752063308, 0.07633964757301978, 0.15080098807811737, 0.055694781975554566, 0.14560589327343873, 0.11144759905125413, 0.09781344208334174, 0.14545205581401074, 0.11589177272149495, 0.18608358768480165, 0.1251841876655817, 0.09374643888856683, 0.09728040532874209, 0.12976585967200144, 0.08728358961109604, 0.1238839788628476, 0.15864648137773785, 0.11435616655009133, 0.16005677570189747, 0.12981441563793591, 0.14934182566191467, 0.16289826322879108, 0.07197966652789287, 0.20246491581201553, 0.09718071496380226, 0.11626793896513325, 0.1175398121454886, 0.11163104777889592, 0.1503740945564849, 0.1044947864221675, 0.11135461261229855, 0.19010545473013604, 0.156430453860334, 0.12215693082128253, 0.15832258947193623, 0.1853461151144334], [0.024984948603170257, 0.0249977797003729, 0.024620044344503964, 0.015125487033011658, 0.020059673248657157, 0.010172524905231382, 0.012243204284459352, 0.0797760406775134, 0.0588973213785461, 0.02905857769240226, 0.026693577811654125, 0.03792353253811598, 0.034674805256405046, 0.03721006314403244, 0.02908997011504003, 0.017613038819815432, 0.04692963284573384, 0.06952733240489449, 0.031245401062603508, 0.05386348381372435, 0.0730110668976392, 0.01868498674593866, 0.027406331351292983, 0.017702060917924558, 0.03833732015586325, 0.05078219522589019, 0.006747115162267748, 0.01382660137356392, 0.02147284965030849, 0.01959627284668386, 0.043414709490856955, 0.017367604221882563, 0.025301400372492414, 0.06118952123714345, 0.03935408113258226, 0.060741152082170756, 0.026315011250387346, 0.059618074846054823, 0.020351595977055173, 0.05072985981990184, 0.04576697326930506, 0.0825819390426789, 0.07199063165379421, 0.01672752178274095, 0.025349576358816454, 0.05324405598055039, 0.053678959608078, 0.0377408335916698, 0.0554720630337085, 0.04827049946678536, 0.006914474128279835, 0.037750967512173314, 0.01948440447449684, 0.02835297421552241, 0.010590266685799828, 0.04388351612059133, 0.018746095609718134, 0.029322426034403697, 0.0284797669654446, 0.012386222503014972, 0.05417029020775642, 0.04257315643397825, 0.006459113518108747, 0.022767287512708987, 0.035942804001803906, 0.026103791780769825, 0.028662116466356174, 0.008543812703075153, 0.054419855387615304, 0.02811369562654623, 0.02356374343591077, 0.014833362440445592, 0.03843578915776951, 0.0675472179427743, 0.05725419454808746, 0.07056760801268475, 0.006489330802911094, 0.030545275059661696, 0.022485870202737193, 0.01489481735708458, 0.033514937851578, 0.045944895329219956, 0.022447217455399886, 0.021554501161777546, 0.03587446195472564, 0.02803329940486167, 0.023428535155419792, 0.025775533502123187, 0.006027302313928625, 0.020364342257380486, 0.08156176842749119, 0.0331834463535675, 0.027224324510565827, 0.012488767804045762, 0.03623998876927154, 0.03748980616884572, 0.023679866222664714, 0.021732704813725183, 0.053773978259414434, 0.10600819092776094, 0.04920076758467725, 0.0293491840628641, 0.025029954134619663, 0.05269350962979453, 0.07413157248603446, 0.026532164508742944, 0.011535798448936214, 0.036689090742064376, 0.0336811585750963, 0.01642843202820846, 0.02182128416773464, 0.03803143317678145, 0.0673381205914276, 0.028549079317599535, 0.031046888857547725, 0.017111477608393346, 0.019992603454738855, 0.06831502781382628, 0.009845643204503825, 0.06988571424569402, 0.046214711386710405, 0.05188125232234597, 0.032283281441777945, 0.06113962855722223, 0.05459997929366572, 0.015815991409389035, 0.003952127640202109, 0.03408896490665419, 0.030146360929523195, 0.035999729697193415, 0.009760546431477581, 0.06857099157891103, 0.012615245883353055, 0.040634534388248406, 0.0030677340026678784, 0.019940732845238278, 0.05707075260579586, 0.024219096305647066, 0.041996449165578396, 0.0296143555481519, 0.05484057763325317, 0.1016838194004127, 0.020783183264679143, 0.06408398199294295, 0.07841252455753939, 0.025908015768176744, 0.03676761420709746, 0.053190414394651137, 0.01205881408947919, 0.012571712772894119, 0.013258010232155877, 0.0037514131649264266, 0.03352429145681007, 0.03224290521549327, 0.010764180300092059, 0.045539124602718015, 0.02939493428649647, 0.05629977736888187, 0.01095760179617043, 0.004035136221708464, 0.02846777725166508, 0.010559043048747947, 0.03623295236112816, 0.020302658335172703, 0.022925386172054068, 0.03482413724330919, 0.0443919424100646, 0.07232652005872556, 0.025568761829552904, 0.03687405260279775, 0.05049918166228703, 0.06083554308861494, 0.027235445699521472, 0.027226663760042617, 0.012330905783788433, 0.056260948202439716, 0.031688827089965343, 0.03575874459264534, 0.02753048120731754, 0.010594491414459688, 0.01252886583097279, 0.03594732304502811, 0.013324782318834747, 0.015567895257845521, 0.03792188369802066, 0.04764674258019243, 0.05514813720115593, 0.09747622374977384, 0.02962024523211377, 0.04567193426191807, 0.03920627924214516, 0.04079549985804728, 0.019110952370933125, 0.026276616346357123, 0.058308115495102744, 0.03774724914027112, 0.11371258287025349, 0.018479005566665103, 0.019883064154003347, 0.04297054386032479, 0.008962267793581953, 0.0035438730514475276, 0.00594756766388725, 0.02148640338730599, 0.00763694301713258, 0.04319282853975892, 0.0301863198567714, 0.03976432340485709, 0.0341890148951539, 0.13851464592984744, 0.03557606600224972, 0.05753753041582448, 0.05012269650718995, 0.07562116041247334, 0.04794414447886603, 0.038632842512535195, 0.02426689231236066, 0.03358224852542792, 0.00804758392873087, 0.039722993836871216, 0.015181807135897023, 0.047968436032533646, 0.04805604847414153, 0.04401734018964427, 0.010807543776796331, 0.009039546995024596, 0.014801060780882835, 0.03824047285265156, 0.008407584075549883, 0.032588269361960034, 0.050211496385080476, 0.10102489404380322, 0.02649203934041517, 0.017937378558729376, 0.020530569766248976, 0.00938759050664625, 0.026280380519373075, 0.08324300178459712, 0.03364097912396703, 0.08339576715869562, 0.053189182853592296, 0.04695658086399947, 0.02042720513418317, 0.04137373722291418, 0.03597098695380347, 0.005836857890244573, 0.02728470055652516, 0.03526480502582022, 0.08306769547717911, 0.020432307717523406, 0.0223805412117924, 0.008186908372278725, 0.05451819546786802, 0.042034335168344636, 0.047211116312869957, 0.035276214592158794, 0.04804258294669645, 0.019512383865990808, 0.017512849731636897, 0.047032064492149014, 0.021514983282291462, 0.0033093155819057885, 0.027309097283120667, 0.01578614435025624, 0.024655988040779318, 0.013789457518474331, 0.06930153630673885, 0.01254167063494346, 0.0475492608467383, 0.03720527947215097, 0.026315070622201477, 0.06038935203105211, 0.008446578634902835, 0.05833005253225565, 0.05929526859628303, 0.021136191108130982, 0.04079847862677915, 0.029180188131119524, 0.02069197967648506, 0.03733147341491921, 0.04834087372624448, 0.05905113169657333, 0.0741093165374228, 0.05210160996232714, 0.011537848472861307, 0.09061313380620309, 0.016253787292433635, 0.04133465699851513, 0.03384245313437922, 0.08468140102922916, 0.04421541813228812, 0.02915208999599729, 0.010218069023851837, 0.02979791962674686, 0.023566165805927346, 0.03474251287324088, 0.00851022606782083, 0.03568994792710457, 0.07352697064301797, 0.04156118252181581, 0.04523331904783845, 0.05389970740569489, 0.033054629872952185, 0.05512773026047008, 0.06314531700419528, 0.0552008186600038, 0.033625043729054074, 0.043513073319835324, 0.014761173099811589, 0.08589367847889662, 0.023207102037434067, 0.025135946393545185, 0.04388794016891292, 0.01792254239054663, 0.016569619898551276, 0.07451793711100306, 0.07946526485362224, 0.08028040932757513, 0.02891960014988269, 0.011658109475060232, 0.01712614075014634, 0.06526978300618273, 0.030645745739872967, 0.02029472795714225, 0.016784576399784003, 0.01678601828669863, 0.03815595113805362, 0.04083380315984998, 0.05009568402809756, 0.02473153612975563, 0.04049950931221247, 0.08755342941731215, 0.01929989383955087, 0.02648057379493756, 0.06297412261899028, 0.053226468352867026, 0.020816370412441235, 0.020934935925262313, 0.049360057072980065, 0.07434425250227962, 0.04373972776478954, 0.008574807334558239, 0.02187045251152345, 0.07696367587362017, 0.021517945087647865, 0.05632018091689263, 0.06539221107959747, 0.03140797805307167, 0.048421191916401894, 0.00797508585466338, 0.048718118840562444, 0.031367747711816, 0.15625239270074026, 0.136138646996447, 0.09166489701185908, 0.112716798803636, 0.12635779540453637, 0.08522305517856564, 0.07467617826270205, 0.1179857182183436, 0.1550015133938619, 0.14973247184285096, 0.11506879116807665, 0.1662453543394804, 0.227515220908182, 0.11256489516901118, 0.10060536262712308, 0.14992164740605013, 0.19398244097828865, 0.11715787835419178, 0.11294767034373113, 0.11997211591473647, 0.23586919478007726, 0.09414623172155448, 0.06925319068666015, 0.1738097034394741, 0.11812089596475873, 0.1233057448906558, 0.07730350656700985, 0.14665204499449047, 0.10087424569896289, 0.10048822034150362, 0.09590401061411415, 0.07553920016757079, 0.15535914206079074, 0.16074205535863126, 0.13208431883582047, 0.142921188047954, 0.1901603075010436, 0.10589326066630227, 0.10846673364617995, 0.11090791265347175, 0.08183142502925225, 0.14904276813779557, 0.09080857903297458, 0.10610727061118398, 0.14610955624708108, 0.17312730077121938, 0.12304723661925111, 0.15025103544550283, 0.13074369648737566, 0.10539825579949788, 0.14262597103204044, 0.16456368671996252, 0.08812996705195733, 0.13442491181194782, 0.1534301077148744, 0.22564095790897096, 0.1395874505064317, 0.12993900823806012, 0.09916866650538785, 0.11041416986180203, 0.14485658705234528, 0.172499452318464, 0.069855404086411, 0.12031170912086964, 0.13091898922409329, 0.11576192826032639, 0.12391958838062626, 0.12154546220387731, 0.18035969696938992, 0.08050714858940669, 0.19668477454355784, 0.11113463834460292, 0.1678761454033, 0.12047344472791467, 0.06344298353152615, 0.15373151297015802, 0.13529533653387002, 0.16024178506008216, 0.11900736125452177, 0.11400573035436017, 0.16100619547069073, 0.15767373357500347, 0.08443482818880252, 0.08480481297842093, 0.11864437216094562, 0.10955167721424784, 0.09935866988130979, 0.09182635441954647, 0.07425585974540029, 0.0810031034052372, 0.16378038589443478, 0.07007083216948168, 0.1080308902476515, 0.10730152617075614, 0.13013758829661778, 0.1441283154168299, 0.07610062682735068, 0.06911287643015385, 0.20389396484409059, 0.11554240861109324, 0.07487128422196422, 0.10080342699906655, 0.12086216386939798, 0.1519336530140468, 0.1514140580381666, 0.10414681330855403, 0.1409203511263643, 0.18822452851704188, 0.15355232544243336, 0.14599732655499661, 0.12336518455828939, 0.1751877266381468, 0.20170514658093452, 0.17433186327772482, 0.11313979074891124, 0.18793421052396297, 0.15087258709328516, 0.2728230261376926, 0.09271351860037871, 0.19394387304782867, 0.15383995643683843, 0.12495845263557774, 0.09693551276411329, 0.17759925366512366, 0.1087660218722054, 0.13476552282060894, 0.07036001700907946, 0.12825712348733628, 0.09703988502068178, 0.10946821062160389, 0.06958727418844189, 0.19120260514318943, 0.09984190895089082, 0.1253431819911514, 0.16649907215365342, 0.11786036565899849, 0.1817572619765997, 0.12035208195447922, 0.21022393660885946, 0.11346496508589812, 0.2084452249109745, 0.22483198131833756, 0.07540984425161566, 0.12331282879625048, 0.10548485722392797, 0.12141697481274605, 0.09982302532132183, 0.16062150682721818, 0.06367034026022468, 0.07180320671094315, 0.08869196368115288, 0.11054218906377043, 0.11038841267249414, 0.07387740005339895, 0.08701290842145681, 0.16268759167620114, 0.11596449810479369, 0.1088560838252306, 0.08470358233898878, 0.10441988972680909, 0.10796357957380158, 0.13264937565795012, 0.10959779723946537, 0.18817066640726157, 0.1078832953103951, 0.10777216484504086, 0.1270898532654558, 0.16079154770289147, 0.1911764679742711, 0.21889995677130564, 0.17213775244142326, 0.16255276676799568, 0.13897413627377578, 0.10102521974061217, 0.18821202990199837, 0.12899196334183216], [0.09949866522635732, 0.014773683589217919, 0.04852576773347599, 0.02335914477173771, 0.015829862361507754, 0.019693188003397415, 0.054529574500130754, 0.011861961750712777, 0.003289921142693077, 0.024361939801435386, 0.009859052752809865, 0.04197412536346486, 0.017686307031129087, 0.09213336437408413, 0.03859191667288542, 0.08872962916003806, 0.011063933322605277, 0.025111519132873843, 0.03782447999609368, 0.015531293382602078, 0.0404797605504947, 0.02945219585672021, 0.017258889341194714, 0.035453766850488524, 0.03682736939351473, 0.047535147318350415, 0.03078958159312606, 0.053690206326012097, 0.06156437112284558, 0.032159235062343736, 0.0130605370338474, 0.02210925442964903, 0.03994855923312051, 0.0554081552129771, 0.025637731521523426, 0.005497652297240815, 0.04253862239420414, 0.023507292715034316, 0.012373635678419044, 0.00916591820506645, 0.06889337035162107, 0.006888579959715051, 0.05182206031999417, 0.0473503584840468, 0.02227297475162361, 0.06943355886531727, 0.04327699063079698, 0.015651098918169737, 0.025522860631878887, 0.047906587565583844, 0.050273005584520955, 0.06332521699368954, 0.027243508391880562, 0.020700547877433043, 0.04884833988866635, 0.046594772421355755, 0.040899543025131734, 0.07459224348089524, 0.04732592783070036, 0.04723535697641117, 0.04297286784276366, 0.03867510167349662, 0.033524210032607825, 0.04193516049001898, 0.04840749568705048, 0.034939399986926994, 0.02331689409246402, 0.02922058810612985, 0.05903029388615063, 0.053727810736745596, 0.03916366724297404, 0.022921744135341475, 0.011578435045001763, 0.013313162406640393, 0.03389513798590217, 0.027924380963668227, 0.03648671767275248, 0.008635699067131748, 0.039878863508680036, 0.01708970681232001, 0.052085939196071455, 0.027699522940175872, 0.04471839917823672, 0.027969895396381617, 0.04224581417760678, 0.04031199955248407, 0.02795402955130807, 0.024644407144348537, 0.05448051981095757, 0.026747857220470905, 0.013919234126141029, 0.0274580577721021, 0.01727814446868641, 0.02597279381006956, 0.015393511758052876, 0.027505100604944994, 0.09251530495073114, 0.029027599176125865, 0.020383091876283288, 0.04281087099973645, 0.05432540670569454, 0.024859343289530704, 0.01777498816539134, 0.026907233221988593, 0.021479989535042217, 0.03784825586314712, 0.02925759201337184, 0.02830731220144246, 0.04565509641543031, 0.032560771730329306, 0.030042470432817936, 0.0540791799181274, 0.018579937650689056, 0.03084149630740285, 0.010834194935991295, 0.012048295948521366, 0.035572863316961696, 0.04574216263634818, 0.051453676873019764, 0.048943714770887575, 0.03087100918803896, 0.027508951291175823, 0.03511308120297534, 0.06924755206065518, 0.010556003211864402, 0.03953406933162894, 0.053345856589398215, 0.015759175975940058, 0.030781513811754327, 0.04760418147114771, 0.05527037189209035, 0.01923581468872726, 0.06945508878145899, 0.006668574733859194, 0.0207771307323128, 0.02222986233287624, 0.05525566464556115, 0.023218313132279685, 0.06191211353455271, 0.050854377781174014, 0.048014868183859756, 0.03918029135093093, 0.01976495495598231, 0.04152450431138277, 0.021770473769200698, 0.08042093392993722, 0.047156209259160926, 0.086606269170131, 0.031162748711981943, 0.02350557771777468, 0.04231699250106301, 0.03651146723755768, 0.023704502132854292, 0.03602813995842423, 0.040020718039678674, 0.06538484897464514, 0.03961312544665166, 0.028954493813216686, 0.001979950341462557, 0.02714703937194177, 0.04079737940004893, 0.04336163108902318, 0.03562658293438809, 0.016157869582197497, 0.031728490854480436, 0.06165502340133701, 0.051003699590052874, 0.0377911842827286, 0.01970055010834975, 0.0431122626843197, 0.022138752043247223, 0.053389140338237794, 0.006026650920310723, 0.04493145238874214, 0.019519352420632328, 0.01014635041688702, 0.045343998287405284, 0.0211987096284117, 0.10491213295608759, 0.0340944305062294, 0.013512929901480675, 0.01032949804461428, 0.023149993137589524, 0.014308844693005085, 0.020566527033224702, 0.039207968794341595, 0.007804724371193775, 0.04079911984237177, 0.021118203144786612, 0.05419729929417372, 0.03037641822759594, 0.04484328015574387, 0.03238438994490674, 0.0344800894547786, 0.05485590234664934, 0.03110236588067242, 0.03640157509861248, 0.08956451221768345, 0.024838759929740002, 0.08832886602197375, 0.026355463811861615, 0.027172192665083066, 0.02060000764738236, 0.03680087260103651, 0.03899569929178272, 0.03241321411249893, 0.004245087254925498, 0.058780111239424775, 0.03996436231370483, 0.025423636759764383, 0.001570950000314042, 0.014923543137099062, 0.014954430051147938, 0.02532769869347768, 0.036725830020649095, 0.05700691603124142, 0.04946416470089129, 0.04715287425954427, 0.04455047533182161, 0.03599747356825641, 0.033811186240719895, 0.03178345558366605, 0.021593011416760937, 0.03275028656103781, 0.02717694071387606, 0.027512596720563512, 0.019207721642617668, 0.010827105093215193, 0.029236896695303063, 0.038649025572729964, 0.05096946071301188, 0.03030048676633409, 0.05751691652195794, 0.016881688331652964, 0.02038642857223749, 0.03732124789218817, 0.05660003250730889, 0.045630150075469694, 0.003973876383887338, 0.07142100829098906, 0.04232767942760672, 0.06898994624082531, 0.044810310139187744, 0.034877276713294644, 0.021680673052157675, 0.06024004040019853, 0.024330275964790156, 0.045968423530991585, 0.04469513560512236, 0.026859533906515156, 0.04173427680507302, 0.03178374735372407, 0.027247479518077204, 0.04409120211909924, 0.05376483839271324, 0.030481933815670863, 0.023311906860076954, 0.09464627131819725, 0.03305835842287966, 0.07182453985192946, 0.052906993710036786, 0.016508008918858, 0.01484969477834446, 0.06397491427404539, 0.049469528520213704, 0.018374716430636387, 0.05056821920775941, 0.007358351805513459, 0.03287066545869623, 0.03782603723396148, 0.015072641029421772, 0.03624193277209997, 0.025615375488996506, 0.038483072870544026, 0.017542997042515447, 0.01109518834190177, 0.05901344586163759, 0.059962485650820394, 0.05398352344387344, 0.008524184381323201, 0.05791747609951666, 0.01626986009068787, 0.004557916495416845, 0.03624069444569094, 0.01360870257485658, 0.011168640605839235, 0.014340817263083798, 0.06383975688368082, 0.044630399971668205, 0.07841711823961564, 0.046196224700127325, 0.10757196308778864, 0.09411246103367635, 0.08917522310678448, 0.03151276082332645, 0.011856680203761374, 0.07336727064102888, 0.03939629279609237, 0.06129001905875547, 0.010530631091179592, 0.04857492081022688, 0.019567704826061214, 0.014685479125806263, 0.04851640055754355, 0.011886199021578898, 0.07633261795022658, 0.039534140577805896, 0.03941308993047901, 0.03777444821649364, 0.02432811143808067, 0.022821202208953242, 0.027550983142906, 0.05949211160519293, 0.027855458769149015, 0.049822149598704915, 0.0328949773684144, 0.0013070469514267252, 0.02800258212456746, 0.06628915973539863, 0.017013432690873742, 0.06418338737317494, 0.06780272708939654, 0.041329109974737675, 0.030755607344742333, 0.015923315293288658, 0.007222358120738396, 0.025787511341539875, 0.043881164996751716, 0.025097403908148408, 0.02011232417342918, 0.06171724506254707, 0.007148241740651429, 0.036421999002673795, 0.016587760532274842, 0.0479751365658428, 0.011316411962200488, 0.008947746296014105, 0.013112601873997067, 0.05239905257310186, 0.09771913928644997, 0.037054091691970825, 0.10199427631284509, 0.07994614940668855, 0.07655782372291599, 0.037881921378097365, 0.0483671228534409, 0.04138537070580891, 0.02233458064230425, 0.017344103161511675, 0.03441212060196059, 0.039953580392258506, 0.046173419138150554, 0.18161778231816633, 0.14520174424563134, 0.1935220006853342, 0.1256922475461449, 0.09508484242750065, 0.0787236260782395, 0.14890117145010404, 0.14095476642251015, 0.09339354639606816, 0.1175985054246017, 0.10724374891391822, 0.11779412707047802, 0.0866880462105785, 0.22755260818770953, 0.10021670455379145, 0.16393727676144668, 0.15529066430670874, 0.10831890122166701, 0.10278046769755227, 0.08153672369995288, 0.1708417505558048, 0.15847394349319593, 0.11986861218299184, 0.16601933432476862, 0.09268827031233481, 0.13144595309027604, 0.11043922137469053, 0.1452981505010809, 0.109126371464559, 0.11283685878983565, 0.05635089480451175, 0.13006270517195972, 0.14399799598114832, 0.16600838276956761, 0.0882334029302001, 0.0990768200052636, 0.1594296329255615, 0.15041895929191793, 0.12364889362028667, 0.14131415928048746, 0.20697824577135698, 0.125265557585018, 0.13230914462889942, 0.10479443427175283, 0.060693858191370964, 0.1032078836911491, 0.1285750578556742, 0.09301062194364411, 0.08241394055741173, 0.10847682346190725, 0.1356012336909771, 0.1581437276410205, 0.10895495316279785, 0.07522800365196806, 0.29078460804053713, 0.10281432659498282, 0.14141136620725903, 0.13933732892785752, 0.10282918651189123, 0.08451948221772909, 0.10458156426570245, 0.08070125031684126, 0.12431122522268977, 0.17849464847573213, 0.18011549221617834, 0.09796445683709212, 0.16106250030653818, 0.16823319053011282, 0.14116537012159824, 0.1532027442008257, 0.07140688797725098, 0.12255546157913548, 0.1641060012791838, 0.09305372927337885, 0.15552743231611593, 0.10485264579100267, 0.06509240716695786, 0.07258214455630098, 0.11929132815982614, 0.14092404235686573, 0.11402880054499422, 0.14173832509134496, 0.09265249794615166, 0.1734936282570873, 0.13984513096511364, 0.14324662701359817, 0.1644935126283339, 0.10839829660419907, 0.17209287413528987, 0.1540815827569791, 0.1531934889831713, 0.10816547766860042, 0.09714242523269993, 0.07754038992737021, 0.08268179904137339, 0.12372839078307152, 0.1594801295016493, 0.0847353038511106, 0.10695022823555128, 0.11129460976059947, 0.18270351977220603, 0.13217434686209473, 0.15922371111810207, 0.14215808042458125, 0.13586302607187203, 0.10364978640739407, 0.1590499925826277, 0.1144089022917407, 0.09485530081604208, 0.07504156258489404, 0.15316321275063924, 0.17616621484713896, 0.10498927560235773, 0.1376597053770508, 0.056831100822559426, 0.14298157766461372, 0.17828153419707501, 0.13101094428982052, 0.18696250766515732, 0.17767408250698022, 0.1594064813107252, 0.10039205157331058, 0.128659793308803, 0.14719871351761477, 0.23321525433233806, 0.12078550298299108, 0.07602511945047549, 0.0807374230186854, 0.1160607279411384, 0.16636039316654205, 0.1732471300555127, 0.12850640368248734, 0.18464974819549493, 0.11617111201797213, 0.11362406797707081, 0.11252809142959969, 0.11980602411287171, 0.10978871663766247, 0.15135976166597434, 0.10737153062863009, 0.0810919643512794, 0.1469157644148384, 0.10170523396560124, 0.08756326138973236, 0.12321425122874123, 0.15550908472921166, 0.11640821929488863, 0.24397850249494824, 0.13773741120738642, 0.0741734177406345, 0.09022388540740524, 0.08758403813200337, 0.15255954728594848, 0.09705260755228144, 0.10819278191775084, 0.16414587199687958, 0.06090649749551501, 0.11265836336783, 0.08484265487641096, 0.0708701057093484, 0.13231255087469304, 0.12083412680242743, 0.1594085440571819, 0.18614313591803822, 0.13669051309781416, 0.23794488768492425, 0.18564826675823756, 0.10412523589496102, 0.07096847293100186, 0.15915779822639056, 0.13929011646125997, 0.12121912757200853, 0.14043660994086946, 0.09976140077092818, 0.10264857406062738, 0.11116631235927343], [0.04821121586220605, 0.0428038176282176, 0.031816001515835524, 0.07099847096417632, 0.06520125775464944, 0.05070087280390518, 0.021150102772350823, 0.07765120826661587, 0.0101128621692104, 0.03576593706384301, 0.009796079614066651, 0.025076440568747263, 0.02696193501885448, 0.04362536408007145, 0.02944287278556398, 0.03629723676879491, 0.051595327843512805, 0.026991760025599172, 0.02911008528566786, 0.05682065138327224, 0.05437044446755733, 0.010293619657334472, 0.028553829062730074, 0.020532069328640188, 0.027304411998816898, 0.05789340167705502, 0.005959883922644491, 0.06794566049107484, 0.05975836196116038, 0.012183380396371441, 0.028722319485885755, 0.02911157806270889, 0.05503346478300435, 0.024267511475565176, 0.05063350106190358, 0.04210736928507686, 0.059263872780970166, 0.04524766667080777, 0.006548898968113852, 0.03565039951354265, 0.026600898409794484, 0.03240807760240776, 0.048773982628647766, 0.04241514937686069, 0.10297377553901502, 0.046568228131426234, 0.035831568363521776, 0.05759315671665328, 0.048758196511438916, 0.030409171112946103, 0.04444541096953409, 0.04048179615555065, 0.04356486929048385, 0.04209315397643617, 0.0321787802635559, 0.0029446074622683227, 0.022314628320080892, 0.024527147811438357, 0.033787763211876154, 0.06413838014538799, 0.08440896243389164, 0.05236683233774134, 0.02138426011827375, 0.03282332067777004, 0.026030272511499267, 0.03129660670778581, 0.04528570195127811, 0.037245903363717456, 0.06478713426206793, 0.016197913326323032, 0.026864968972014527, 0.05180360416748694, 0.02110874267028911, 0.023438675861273493, 0.012250574022930647, 0.09000343616519656, 0.04991691040673426, 0.04977385147607752, 0.0438956313633493, 0.04862583129267607, 0.05565863302243607, 0.022727476166827337, 0.013482342391008777, 0.01874706761113235, 0.0520826008037797, 0.07285986893943378, 0.079286857641169, 0.043909056178693257, 0.03160005774615066, 0.05330708849110773, 0.03101767453231982, 0.03828760728772197, 0.02893660423745002, 0.047394805920443366, 0.04355840285175613, 0.024470427372891988, 0.014911875727453401, 0.02006097264321787, 0.06954526608543736, 0.10946806134389979, 0.028214152736057128, 0.03851383086293936, 0.05237872027126806, 0.059439348722142835, 0.04501653389473047, 0.029065352864563465, 0.022880874274830734, 0.08596430718898773, 0.011708182814930166, 0.016608790028840303, 0.06812712789646216, 0.023234441909672957, 0.03307626496202179, 0.0198188017987247, 0.07888837438076735, 0.014576441940984555, 0.05844386999628373, 0.002639635233208537, 0.0020772516270101604, 0.0268489182261484, 0.07795498839446477, 0.032913898317409415, 0.04040053140904222, 0.03233170509338379, 0.03634974520121302, 0.04388782481795975, 0.09111518186650105, 0.012064549406724316, 0.06484141027820961, 0.05531669208513839, 0.06494407262653112, 0.053630098301385126, 0.045370454367782385, 0.07589980081788131, 0.08475983289203473, 0.03788404180003064, 0.03501198627054691, 0.07716720923781395, 0.053892301195966344, 0.055480110459029675, 0.10442423235092844, 0.023916870022990873, 0.04874678694510034, 0.04630679198141609, 0.024149029083283882, 0.03339636724974428, 0.05787308633859668, 0.06827646666871649, 0.02877329782183681, 0.0663207523258669, 0.05845678251768861, 0.05379016810495939, 0.041268645719225915, 0.023278829974255393, 0.030390467295157056, 0.0912194319867662, 0.037520750758371184, 0.022395041505140916, 0.01742780384873705, 0.021837334913600768, 0.07533880842051335, 0.024861451837101152, 0.033013866881706884, 0.06046915453459535, 0.011123875954321452, 0.032198016731334586, 0.018119929923809, 0.043569663140390597, 0.04513483647523182, 0.014764667555157627, 0.06409594456532172, 0.053442198384021006, 0.041976561304181814, 0.04469367675483227, 0.029071361292153597, 0.03437051961996725, 0.02374636265449226, 0.12222215160727501, 0.05828153727842229, 0.05328930408826896, 0.030922706771109785, 0.06677771173417568, 0.035553725236760716, 0.054564003366976976, 0.04754738809008684, 0.040414912958762476, 0.01956125195803387, 0.01733413208941264, 0.056076597023223124, 0.028045073683772768, 0.015402470116636582, 0.05164798894631011, 0.0061377453384920955, 0.05735887214541435, 0.015809253556653857, 0.024850313684770038, 0.060037246639175076, 0.044163310035531006, 0.04775303169818861, 0.023774297941210012, 0.06377576424607209, 0.012981214593829853, 0.06571104789951018, 0.014252332903976952, 0.01659969426691532, 0.02628777315840125, 0.018500508341406072, 0.03238859346934727, 0.08634924689041716, 0.02855548808085067, 0.02031585244861032, 0.030212976104979004, 0.0526521088156317, 0.023785079862656336, 0.034713437647691796, 0.03509613818355969, 0.01398389512074313, 0.01628475563068475, 0.03200590989685484, 0.014576791386519159, 0.061401699137474806, 0.016422917234844396, 0.0430749636143446, 0.03342132376773017, 0.08614310795175177, 0.006919304449443838, 0.042815953227026124, 0.039818473892020326, 0.029904090001114776, 0.07911174132355622, 0.030230801219918897, 0.07362084596284799, 0.053200086911341975, 0.041620204890412946, 0.03855843436239021, 0.05180408592735018, 0.05380554710115705, 0.016077198553830385, 0.03662169864401221, 0.03737281994628055, 0.04149219586646982, 0.012326712437373186, 0.056523470008479695, 0.025464881510872926, 0.037491529647793086, 0.0364789755881897, 0.04966825446380036, 0.03326776450765984, 0.02548975999733167, 0.016239546538729752, 0.04001001414975949, 0.03908020743568029, 0.04515851056203246, 0.02423510973208717, 0.020759828089337264, 0.05813635792583227, 0.021413175888093453, 0.03586613633004682, 0.027237024989777377, 0.015545147371345332, 0.030329412714179074, 0.04479805579675095, 0.024443996737578084, 0.039799152607364316, 0.01774241339548358, 0.03505339047738484, 0.03420707071200013, 0.019267393708495156, 0.038558091702205796, 0.016536239368308867, 0.05347164001848016, 0.06285987089255027, 0.06116290230836187, 0.04279396869242191, 0.006523540842213801, 0.03231649233826569, 0.03074722404458693, 0.011164741573988326, 0.02387701966134565, 0.012745042847070311, 0.06348140896963221, 0.01192467110896749, 0.030697059950658252, 0.02086672279983759, 0.046928591294480224, 0.040790614405913014, 0.025740626268088818, 0.02861256305394428, 0.03930142342246004, 0.01874199216919286, 0.0038446773791552652, 0.07474241006587233, 0.02897589820037995, 0.03293092954637749, 0.05389671506626265, 0.06277854168521506, 0.04123427792053137, 0.066727947975908, 0.019965076985369836, 0.07312509470752307, 0.01661645238553839, 0.045925862421946864, 0.07917301303574018, 0.026544216987011687, 0.04160777073619621, 0.020712620711752346, 0.024033617061961974, 0.06794108716504914, 0.022338714616905366, 0.018504694902471135, 0.02367035485804081, 0.04428633861243725, 0.040345013673816404, 0.042556946232382736, 0.012533330591395497, 0.05159645760431886, 0.027350801741704345, 0.005011037515942007, 0.0539011594706348, 0.03469241663281407, 0.05306352495348879, 0.03718752221071294, 0.035895472791578086, 0.05205680290237069, 0.03829112209911857, 0.033675910106727054, 0.03748091396742633, 0.056940840291125436, 0.05177225924230047, 0.009318245924077928, 0.029215159825980663, 0.06461507135203906, 0.020723287282245498, 0.03453560719000442, 0.03840959431337459, 0.09686254989355803, 0.015508252029706324, 0.05719408991613558, 0.036335794521229606, 0.039250336520906, 0.023920182970219424, 0.026655082823708653, 0.04307596106082201, 0.012057797983288765, 0.03221034910529852, 0.028428110094474893, 0.012953121547720261, 0.033072950318455696, 0.010632665794608849, 0.02481917232008917, 0.02906360224421535, 0.05042093300393649, 0.10854520622108664, 0.12574715459985392, 0.07558998172836644, 0.21108718243028435, 0.197944488376379, 0.20285587411906036, 0.12913369573652744, 0.15526188085121767, 0.07294526257153068, 0.10249430912413768, 0.11762488686612674, 0.09376095953796591, 0.12404191467378821, 0.12350707980138914, 0.14150648324617318, 0.12549294824046747, 0.12676490284502506, 0.12387735636106559, 0.18858846755964415, 0.12129546276160649, 0.20906509379191057, 0.12565251253545284, 0.1134709497647626, 0.08932703174650669, 0.1929387455540044, 0.12904057359056814, 0.10758566949516535, 0.2562402816755431, 0.0874593708930271, 0.07297629876328365, 0.07245509565940925, 0.1087360509804317, 0.18720064631530217, 0.09032636455127172, 0.16219439171254635, 0.10975252357976777, 0.12593962784324372, 0.13398427117083753, 0.09612973207341773, 0.0939180471801332, 0.06393154231565339, 0.10173213109374046, 0.09506455423044306, 0.13038552499243192, 0.1313799994864634, 0.09851392092449324, 0.13373660588903086, 0.15692650367106709, 0.10363567287900619, 0.13448189518281392, 0.10445754163499389, 0.09738836703555924, 0.12289867816226822, 0.1262605884777648, 0.10843181623412029, 0.17556321434676647, 0.10661714896559715, 0.09754460650895323, 0.14009185986859457, 0.16991713802729333, 0.22283246075468405, 0.10620343259402684, 0.06384935136884451, 0.1427566297352314, 0.10839197944317545, 0.080110083467194, 0.11338426691613027, 0.10165416742009775, 0.1756284079913582, 0.08314804759408746, 0.1740602592804602, 0.16141620704105922, 0.14555945433676243, 0.12864999526313373, 0.09706575756094285, 0.20852310716041497, 0.13327338360249996, 0.10698720839406763, 0.10453108804566519, 0.20177871334765637, 0.13608310211982044, 0.15460102845515522, 0.1011796271694558, 0.1441763692668506, 0.11125546507537365, 0.17480777416910442, 0.1568367877709014, 0.08049287221261434, 0.11291292935077633, 0.22728578107697622, 0.1397277308361871, 0.08295956413660731, 0.10427016418959413, 0.14378667303494044, 0.10622581746429205, 0.1179790957165616, 0.15822730958461761, 0.11528628878295422, 0.09684716750468526, 0.20039163849183492, 0.09239928903324263, 0.0939742298796773, 0.1236245749252183, 0.11890715520296778, 0.134791103590812, 0.09570893179625273, 0.12356961358870779, 0.17188870294817857, 0.10667598473706416, 0.0949006744527391, 0.1814049937363182, 0.14350265184683458, 0.16384916220392498, 0.10650128911116294, 0.10607459915003606, 0.16172157494085176, 0.1274849913482155, 0.10057480140988316, 0.11516054267329828, 0.17019531024353846, 0.11247575602361135, 0.14297815784811974, 0.1590162965336016, 0.10367655461387974, 0.13016756597374166, 0.19310656083481653, 0.1516511653150831, 0.08574667386710644, 0.181376169568726, 0.08263715822249651, 0.22581159589546068, 0.1255533378571272, 0.16398398711213044, 0.14824379315333708, 0.18775248527526855, 0.09516999857234103, 0.17655422831220285, 0.16567252150603703, 0.11517502261059624, 0.15780614289854253, 0.13475059505019868, 0.07021191995590925, 0.12647507339715958, 0.16773910847093376, 0.12420233392289706, 0.11276118856455598, 0.13440485431679658, 0.12278043664991856, 0.14543393892901285, 0.11427535302937031, 0.0999109431036881, 0.11540140903421811, 0.16679476414408, 0.08172765666885035, 0.09539817632841212, 0.22755305602082185, 0.08212551567703485, 0.13353365606495313, 0.06988323759287596, 0.1676971207239798, 0.17340407520532608, 0.1056235565670899, 0.09589750346328531, 0.12342117726802826, 0.13116453747664178, 0.09356571787170001, 0.17065284640661307, 0.14113520245466912, 0.08303875595863376, 0.07379511411168746, 0.1578246397631509, 0.11274444232029573, 0.12009645067155361, 0.11759020015597343, 0.05356005313141005, 0.13742866420320102], [0.01537519131254937, 0.021550718329048583, 0.022565146841640984, 0.02319397238482322, 0.026884756749495864, 0.013393048030723418, 0.028774973803332875, 0.07743149184222732, 0.01347431362540062, 0.007896786306186445, 0.0222771731870515, 0.03154383772718055, 0.03606235169406448, 0.01452806409049247, 0.05638154083862901, 0.016153930686414242, 0.02230186846905521, 0.059395087882876396, 0.06798846926540136, 0.007949771409455155, 0.029613649871732508, 0.01369208689512951, 0.013420014708702053, 0.036467851006558964, 0.03755851123215897, 0.05852513813546725, 0.04265770189730184, 0.04792712003524814, 0.026953271823003888, 0.016874073472406183, 0.03445610663454447, 0.0132489619676822, 0.04919650638476014, 0.046261048543133905, 0.010625489438617868, 0.011265074850858321, 0.030218814898814474, 0.02013460556710405, 0.010238871211186051, 0.042960487971348424, 0.032223919805671485, 0.046769481617957354, 0.05094689942364182, 0.01119334012868681, 0.03201251543526139, 0.007159006698722286, 0.06513476810817208, 0.07247002342981951, 0.015877441237015382, 0.05245801048087222, 0.04471481990601335, 0.06197550227599485, 0.024758487540696348, 0.013591157355611878, 0.042879484460822175, 0.02974150961797152, 0.05743670689740351, 0.026745422976091504, 0.053729792059000046, 0.0323397830527808, 0.0185242909938097, 0.041632961348763535, 0.04967560639072742, 0.027415852893942168, 0.03566715932850327, 0.013629792291404945, 0.01552415349786835, 0.009430076976838921, 0.010464571466270303, 0.00551507792468848, 0.01997249337312366, 0.02930484519207052, 0.0619755769148469, 0.039992341705198796, 0.049983070963727574, 0.01675199993353869, 0.0138962682602661, 0.016469276443656002, 0.01465868208158229, 0.0496312335931829, 0.018116048703502332, 0.012399943329260817, 0.07023209280201367, 0.04102188967434423, 0.05813099071383476, 0.02051455294713378, 0.022171543944360952, 0.05645708214225514, 0.047009666051183424, 0.05826517101377249, 0.02533830249948161, 0.027076207101345062, 0.030775074514427354, 0.037060466528471024, 0.04307192038478596, 0.02790810969392104, 0.08673911954143218, 0.014581646304577589, 0.024095055015225495, 0.03576426786769714, 0.04914782149717212, 0.01976797782949039, 0.028497741358088594, 0.021063350373879075, 0.025716665500242795, 0.027501991218222038, 0.007742353432279612, 0.02108353509434632, 0.024634753287370716, 0.03781801355736596, 0.03549358667805791, 0.030231042099850516, 0.034218504027064355, 0.03798701288178563, 0.0478973730600306, 0.04912505325462137, 0.0376624152995646, 0.01617798475282533, 0.029284068449799503, 0.027058212352650504, 0.05384461036218064, 0.02600224392621645, 0.04711346494566117, 0.03224006215376513, 0.042779492147799046, 0.04264938645064831, 0.019550678686105778, 0.04655647251222815, 0.03336423861661127, 0.02681063867307135, 0.02189734624698758, 0.028472299687564373, 0.06283951484199081, 0.0207483133500708, 0.02793577526296888, 0.011879721556657126, 0.02779272142132478, 0.02601267640212817, 0.008075949237016695, 0.04333399775038872, 0.007021351451320308, 0.023212884852130498, 0.007331648908023323, 0.04362411218296204, 0.05412554421595164, 0.010301561909727752, 0.02536573906296066, 0.028812751240496124, 0.069144428308521, 0.03060211254549878, 0.05667379604918616, 0.024990443040483763, 0.039941024101738415, 0.04641684696876577, 0.10046095680445433, 0.04307966246934874, 0.02918629833896245, 0.01705511170439422, 0.011914627094353949, 0.027804236160591245, 0.03905270301869937, 0.04206670128873416, 0.021839177136176398, 0.08947204146534204, 0.016490173625892827, 0.024618709326854775, 0.03066429349460772, 0.017456132685765624, 0.0038432957122235423, 0.020020289379837256, 0.0536333756255252, 0.006567093460554523, 0.0654476677466716, 0.05431629398039409, 0.016723162195246135, 0.05316155969298311, 0.025402522446321588, 0.022045002252395664, 0.006485939400071012, 0.045472933511648855, 0.09585330369217054, 0.04964579834735819, 0.009079864697663911, 0.035679271178586144, 0.04576194532481687, 0.02242384192400745, 0.021506995228784423, 0.03204680180975369, 0.05021068214305809, 0.013271649634199483, 0.0608896833977529, 0.03695106632741434, 0.05743482057005167, 0.039402939046600034, 0.039758084275360615, 0.039295984964285574, 0.015846199788419262, 0.03993568063846656, 0.040308447421661446, 0.023683082478653108, 0.026340493633012687, 0.024415959670607532, 0.059755973517894745, 0.06703187059611082, 0.039051783603749106, 0.019452849203454595, 0.03648735210299492, 0.03219643574474113, 0.029858685830341916, 0.08546225912868977, 0.033952036539890935, 0.016267899124483978, 0.041294972877949476, 0.0530368144224797, 0.021498194629592553, 0.041827141107725244, 0.04234450031071901, 0.033561875511493, 0.0476748712493905, 0.028059075253882577, 0.0339370951987803, 0.007788652421108314, 0.046308695272143395, 0.06201646543507065, 0.029101206654948846, 0.023800363863951395, 0.061326361394354274, 0.030267465859651566, 0.049383402070296664, 0.04852453958509224, 0.053591001113610606, 0.046780972608498166, 0.024473054999751703, 0.022619796052042927, 0.036832818029714484, 0.010320899309590459, 0.038669401979339976, 0.017754879780113697, 0.035875534040055106, 0.03376609758873071, 0.03631172009876796, 0.005218354561033526, 0.022628898599318097, 0.06805961366210665, 0.03420710803142615, 0.027857460447454026, 0.03997622989118099, 0.042640209264521084, 0.028705159335264137, 0.029394313426954404, 0.037307595767612965, 0.02952172534008111, 0.05187881638162902, 0.016259169771469066, 0.07098943966307811, 0.009025870273554963, 0.022681856561186056, 0.03485084777431829, 0.04150323563122323, 0.035319484770298004, 0.0335328579614205, 0.001302867175711851, 0.012781965330110064, 0.03142481589955943, 0.014269520195999315, 0.03399780033422368, 0.0071729192111108986, 0.009044393431395292, 0.026256166997232606, 0.05478481223274555, 0.028057380612673502, 0.026116899380992566, 0.02753778563679329, 0.07141395152679511, 0.03566105251333543, 0.0396693827850478, 0.011503145647501307, 0.00926338043063879, 0.08689988484340054, 0.02035287331922778, 0.03874649712815881, 0.029843530750700405, 0.03922651994175144, 0.013493208281163658, 0.046844181538160355, 0.05798587242939642, 0.07013846175479037, 0.04640934576413461, 0.021433438640087843, 0.02140885022734957, 0.02948478589366589, 0.025174341297575405, 0.03418058070487209, 0.005972949114428567, 0.030465944137956415, 0.027864183033151285, 0.0058450401744007, 0.05259333411231637, 0.06548734168921198, 0.03643764941287892, 0.024467163619452288, 0.02566144971310028, 0.013181311178154178, 0.06902932841330767, 0.04944761862446155, 0.017776784586853216, 0.020398301238726293, 0.040402207390538285, 0.055446733321462355, 0.017199081568313495, 0.03458950322653566, 0.007063823926728219, 0.05856801476329565, 0.02590701832169933, 0.01778200761015926, 0.05511685673679624, 0.0586420904312815, 0.011989446606353989, 0.013745327297198986, 0.0533370288488056, 0.06482117636395351, 0.02927882337410535, 0.05960843964879002, 0.0015490829370849366, 0.03736581067953791, 0.03918046437736068, 0.03663860773667693, 0.03300460487870233, 0.04481478507763573, 0.04839521759588804, 0.029482478874602487, 0.0340683747615133, 0.03022042302680867, 0.02640055924920099, 0.04946110450795718, 0.04302313710962023, 0.07945054064371757, 0.09543796562190567, 0.016036971605249813, 0.04604264508400645, 0.019229168438219597, 0.030899969062634876, 0.012991475739649363, 0.01714113467772092, 0.04966293474925416, 0.006193974687318716, 0.04634686625961747, 0.013709371726560806, 0.026118926504360776, 0.056140230037271976, 0.049067221714981964, 0.013971831616280335, 0.11235627279217754, 0.11272450017609767, 0.07001741789281368, 0.12715720465140684, 0.13727443319346222, 0.05515778596912112, 0.13663761450776032, 0.19397085160017014, 0.1442117073706218, 0.06554826734853642, 0.1281060001679829, 0.21609861137611525, 0.1000814860952752, 0.10111304252807583, 0.09491722392184393, 0.07242716715804168, 0.12740951111274107, 0.10460678541234561, 0.12622398829885892, 0.14320010665271962, 0.1283524983695575, 0.1499138306826353, 0.14974666679544107, 0.09520128582205091, 0.09198893819536481, 0.16318208085639135, 0.12548794065202984, 0.20096364351255552, 0.09474897437861987, 0.0712430624823485, 0.08411137054541282, 0.15255490610642092, 0.14452464772122248, 0.15718381772083895, 0.13952905578272684, 0.08754659656967435, 0.1970377756016595, 0.07167554713253464, 0.10472452480878149, 0.18608483618923596, 0.100141224318317, 0.14362719016415731, 0.08630245511553117, 0.07316954553659473, 0.0837265665509871, 0.11807611265352794, 0.19089459095682415, 0.14713020862213202, 0.09782423079013824, 0.1638035646506718, 0.13726938489292348, 0.1322727615811995, 0.16950137247996672, 0.09138742368668318, 0.17973790104900086, 0.09568611266357557, 0.23697040283254214, 0.09409884962120227, 0.19672887931976998, 0.1257205560271229, 0.09806175197341613, 0.18002798834017344, 0.13466030918061733, 0.13474925155086176, 0.07917196809181146, 0.06509041227400303, 0.19122863374650478, 0.16320984650935444, 0.12701483443379402, 0.07556132040917873, 0.11701801871614796, 0.1133950420522264, 0.1349209209105798, 0.10510107103203024, 0.121289586648345, 0.157198446935841, 0.1188002587961299, 0.11475654292319502, 0.18914804181882314, 0.1344742684492043, 0.06275180062013012, 0.12163023836910725, 0.14728240402681486, 0.1373494113130229, 0.11900304577180318, 0.10076487263930695, 0.07569104951939412, 0.13659667170473508, 0.10740405959742409, 0.1570556288851159, 0.09088396427354642, 0.0961622746129121, 0.09931281448474952, 0.08832260314375162, 0.1713739120002304, 0.11939043498464993, 0.1384598474417414, 0.145079730078578, 0.07440507638135127, 0.11008246801793575, 0.06039877688246114, 0.0723308219707438, 0.14201182898666176, 0.08614406468612806, 0.1415485931294305, 0.12195544663284506, 0.08795656742794172, 0.07447712322963135, 0.12200037922177996, 0.2943488439278943, 0.19638650412006037, 0.09011936387313263, 0.09629133875880923, 0.08875801227986813, 0.08772949568395104, 0.13791035621293954, 0.09638712754739182, 0.09493495404188122, 0.12160202488303185, 0.11504824512771197, 0.14863092452287674, 0.12769019390855516, 0.18778612704149314, 0.09530544094741344, 0.10227502696216106, 0.13141030286039623, 0.08771217947027513, 0.1470119399683816, 0.12270446786923067, 0.07964389598263161, 0.06225748785904475, 0.09533047210425138, 0.1828859778387206, 0.11286554725042411, 0.09628667722323112, 0.10135655517556838, 0.10848113215927567, 0.12135885150304862, 0.09481355055634465, 0.0738163726138217, 0.15759918971785478, 0.14728834799357823, 0.1126857218997819, 0.17716444842517376, 0.15791272717927182, 0.14606911555996963, 0.15930577314325742, 0.09476348145731858, 0.11076561707471098, 0.11031713256878511, 0.11866293687905584, 0.09336761278765542, 0.09374880697578192, 0.07420402645532574, 0.21265552113098757, 0.10735298626657043, 0.08092928558055844, 0.11353959036724907, 0.13937713179205144, 0.08689372374543122, 0.1978881156870297, 0.1896180087434394, 0.09816936762737376, 0.21713529074830668, 0.09190272353589535, 0.1520813022341047, 0.11329691910317966, 0.11442913620599679, 0.16718222121042864, 0.10023522855980055, 0.1214748809912375, 0.09251464677176305, 0.15807900897094182, 0.14623014549059526, 0.14952181386096136, 0.1614392636609929], [0.060457225888967514, 0.03289306050698672, 0.020812485799459473, 0.05331190608974014, 0.0661261620532189, 0.01056368846911937, 0.031314302901072164, 0.0841854801401496, 0.026521173937778388, 0.0132196424695264, 0.047648442310414145, 0.009521901424575065, 0.018428089995203272, 0.012182231975852378, 0.005957875458989292, 0.015249168699873345, 0.07794842696083443, 0.01269804242266608, 0.04479711602575012, 0.030564362249736274, 0.05908348424626248, 0.017138717396716987, 0.026898112015000412, 0.05424487816968134, 0.016605875720935206, 0.04001885885372758, 0.0139309329180313, 0.03766057307698897, 0.07355970317231757, 0.006817616222958479, 0.05845501832664013, 0.013344266451895237, 0.049968010878988674, 0.015042707457074096, 0.010063407992544984, 0.02536571361789746, 0.01349576551001519, 0.028898226296795265, 0.04771411432219403, 0.02570090482809714, 0.037647080408143144, 0.018351714093504206, 0.04784041343789015, 0.04766028953183975, 0.04096464506749596, 0.02839134706716452, 0.01514698302240244, 0.02873056029368724, 0.03566943242081574, 0.04533147253096104, 0.013964113280443209, 0.07373295351862907, 0.08138798203851495, 0.03989415429532528, 0.024535588787070343, 0.04836715678019183, 0.019605718054143444, 0.02324766825352396, 0.03388313130874719, 0.00963635671152068, 0.030968646984547377, 0.044677391914384704, 0.013290082037981068, 0.05733922855662448, 0.011983137927018106, 0.015238274820148945, 0.09806922264397144, 0.059969406708010604, 0.0770576394030026, 0.02216397488622793, 0.05119768935920937, 0.024160981477637376, 0.007382111557360206, 0.022324517967977693, 0.03495221412075417, 0.04751048257042255, 0.033900647690253596, 0.050006324358816655, 0.029526963630425077, 0.04336856571691377, 0.048380296610827954, 0.01033471173806382, 0.06354366455759321, 0.05617490317672491, 0.02592134558861809, 0.022792254208720157, 0.051066090885017595, 0.011470134918844061, 0.010636869319049376, 0.023570228534351503, 0.04317826717825873, 0.05435898740376745, 0.02734762110880443, 0.058271189619387896, 0.02020375507085451, 0.04940139342631612, 0.026824908264513527, 0.0020007518926701906, 0.053654152367796214, 0.030108230654150248, 0.05944064472402845, 0.026122510865596787, 0.022028686877872263, 0.047190532953079255, 0.0268834844963359, 0.042435437573918273, 0.01014532582900886, 0.017653269161071097, 0.022210517299494574, 0.03171747483845268, 0.07433449516871146, 0.031351269488888125, 0.020756197926987494, 0.03395781087289963, 0.02225823697101857, 0.0449472860034023, 0.06623759107398135, 0.05653311199109469, 0.01877334387972951, 0.016645325746919428, 0.04270044281812651, 0.019852645429117338, 0.04898338871342795, 0.04257041515250291, 0.03009923667247806, 0.04189361718350223, 0.05319814969386373, 0.06107688442404781, 0.0506885132885405, 0.09571644317890916, 0.07613815659923212, 0.03746786913169282, 0.03460355568677187, 0.05783806714628424, 0.02303263372076409, 0.0658273555870567, 0.022790045577234457, 0.04095446704221623, 0.03679842987496938, 0.01670116408994155, 0.07830189620809895, 0.027355156240186522, 0.04886100813746452, 0.051683445793709586, 0.03333045435803277, 0.027762621607897536, 0.008014376424918217, 0.018637395996068205, 0.10025181874100651, 0.031115631240286996, 0.024602984277797595, 0.10043489427438804, 0.05822126301271575, 0.023340135613190274, 0.054592101502099206, 0.03196116729772516, 0.04215640022552439, 0.0076179771151925835, 0.026712195116228292, 0.09664018718259675, 0.02651892289785402, 0.004037808377428779, 0.0076999882502215245, 0.026688361573698263, 0.026109333715534637, 0.008805879042483866, 0.08893722016364336, 0.031620675032692294, 0.008200557104178836, 0.008896680598679398, 0.01424962215657745, 0.0648554220263447, 0.019633047748357058, 0.03398918972483703, 0.06249119567551783, 0.05889761993395431, 0.023287367641127536, 0.01810022865954254, 0.03233600700540202, 0.059468254313937256, 0.08623471017926931, 0.02466735689501677, 0.05527244481657233, 0.043676294918571196, 0.038374157822025676, 0.0487928459021662, 0.009625907272233494, 0.04909522146252649, 0.013646531750315001, 0.03609845314973167, 0.020250219452594007, 0.04762390309146472, 0.025400369793974927, 0.02312093148274081, 0.039224806640829356, 0.08017586743725197, 0.020801318809390068, 0.04762286493288619, 0.0350878973757582, 0.09251412429979869, 0.01923024730889925, 0.04494793061167002, 0.002956720584604357, 0.018203701857211332, 0.023243931221908758, 0.03713913248585803, 0.038027443390871794, 0.011827772067460631, 0.03893178129302604, 0.014468001866979259, 0.08302032694752727, 0.02988210885918566, 0.04109545983374119, 0.022982378024607897, 0.026515603165275285, 0.11065495479851961, 0.06514381976532084, 0.015990437673670903, 0.045185010747185776, 0.06398535014263221, 0.06621549118842397, 0.06588112948728458, 0.033134232208664925, 0.026387102203443646, 0.00992341773651008, 0.012592034896702638, 0.0217044048144349, 0.0524248877939369, 0.07200353738984891, 0.08210865408182144, 0.009106224086800856, 0.010906285889047598, 0.025232603706951653, 0.07236792426556349, 0.05038947951314705, 0.03774682166320937, 0.004241111039716218, 0.030873797966965606, 0.04134428541042975, 0.04078108438157609, 0.022071017285010645, 0.030120484996587038, 0.07849139746810709, 0.03196299594960042, 0.030432526288287978, 0.04640697089156934, 0.03515554731711745, 0.008257288568919259, 0.027313039571579014, 0.021599041896739175, 0.03933193374957357, 0.04962094700230019, 0.030772669107786248, 0.0047376956208609045, 0.025451699271798134, 0.02879273785012109, 0.05043456816513624, 0.03609208170590656, 0.028696972810264145, 0.010426682918997747, 0.02118557319045067, 0.03836477029004267, 0.08831729699990579, 0.02758421439544431, 0.04610072768160275, 0.030769262861992632, 0.009502418987852122, 0.014719244724671756, 0.015369773210425462, 0.03738457556547863, 0.04710003334496703, 0.06369500500815255, 0.017843252180942466, 0.02158941687749965, 0.059056777107928476, 0.0197209316039724, 0.02096033688368542, 0.009710904809513261, 0.040735429152846336, 0.021679829972397004, 0.037759344026978524, 0.05796948580869606, 0.013996708406401532, 0.06107666729284184, 0.01819047381702278, 0.021085619893191115, 0.10646707737552268, 0.07579350830721003, 0.06233534296708448, 0.03213230400745358, 0.03395605007452624, 0.05213997433228152, 0.054010685200669935, 0.009440819034352899, 0.03720570694921272, 0.03181584206010614, 0.02783540466667286, 0.03935468163607376, 0.041485281594629796, 0.02800156601837703, 0.013514799265457051, 0.06906822882592678, 0.026652713040156022, 0.05725476451750312, 0.029054944137377397, 0.04594633721613458, 0.07466405962726899, 0.11011792825801031, 0.02999798906967044, 0.02776320854068867, 0.010504015555073107, 0.046928197744169405, 0.026615446200594306, 0.06159144467008965, 0.024066746534247483, 0.014922678004950285, 0.031539376359432936, 0.03521624566721065, 0.017662948463112116, 0.0042175132881051725, 0.036884298481579335, 0.03744263441434928, 0.0426368403381535, 0.049058024172804186, 0.07576055864670447, 0.031916424698595486, 0.039683947539223094, 0.01429567432829312, 0.02836765262431332, 0.02036664927644389, 0.04085420331518565, 0.020169765555432866, 0.05123711224379284, 0.007141846548100668, 0.01925251682821129, 0.030656989065131972, 0.007861726401772882, 0.010279011646551746, 0.033233440813741515, 0.008606632323270398, 0.051117405095802884, 0.013691520318388939, 0.024909570147948604, 0.08397338366402046, 0.022503564699686, 0.0164308204714741, 0.04456231916057212, 0.009143677523492702, 0.018530362185889056, 0.018572115838261585, 0.018229038354807665, 0.03820034768432379, 0.18393143745405333, 0.08816697435187441, 0.10939028087471213, 0.16890685366732733, 0.1561518745230777, 0.10911146405019931, 0.22011346236935683, 0.1685390876872199, 0.1733953356742859, 0.17393040124859127, 0.15703003454421247, 0.07451949774154595, 0.0708516834835921, 0.08588687955800976, 0.11567298589008194, 0.12319867206471306, 0.13344734641058104, 0.1452606139438493, 0.0786540965948786, 0.12616281158157758, 0.16435780562460423, 0.18586994414883, 0.10369014567030327, 0.11844035025153841, 0.0672658769679921, 0.15420184630368436, 0.08286974645618882, 0.1145315949938127, 0.1479919073837144, 0.06791702631328787, 0.11726850670363222, 0.13786151526229723, 0.12743586541286536, 0.13923447658973082, 0.1480827632227114, 0.10174593928136996, 0.1051964730556522, 0.1269952112010547, 0.15422483507011617, 0.16919118698154176, 0.09775330352463893, 0.13349240113581928, 0.1686515345105103, 0.12933204509317875, 0.20661866292357445, 0.1783796367900712, 0.14484431913920812, 0.09165815237377371, 0.09787166038794176, 0.1499413520629917, 0.11262327632201569, 0.20340451039373875, 0.1758846363851002, 0.10583789220878057, 0.1467641525502716, 0.10684101802429982, 0.07507540791162423, 0.18914378061890602, 0.10379471470202718, 0.07007552763181073, 0.06706579056169305, 0.11372466079358544, 0.11853776073881558, 0.12320575597030775, 0.07901716032730681, 0.10533958966178553, 0.1720868894564254, 0.09404384757259063, 0.16132638257529053, 0.08679107496781008, 0.16954235599509307, 0.10727772316230194, 0.14440426203821385, 0.15776011108287744, 0.10246381576039962, 0.1619781290314027, 0.19022296342466558, 0.14647502877882548, 0.11371353960462979, 0.12397688387760095, 0.15650597480790956, 0.08358209287481648, 0.23106921091675758, 0.17084021706666264, 0.08565420990011521, 0.11638186499476433, 0.21669447368809155, 0.07393973028021199, 0.11500282399356365, 0.10515802726149559, 0.1660776204828705, 0.14348084373133524, 0.2151574833052499, 0.13374881951936654, 0.11104305647313595, 0.16044940320508821, 0.14256893337837287, 0.12071805660213743, 0.10016298493636505, 0.08525690050529582, 0.07622275634535722, 0.05944954710347312, 0.09592490949268852, 0.17023793581340993, 0.04907777632719704, 0.16312044273529733, 0.1681996030466897, 0.10925677910979305, 0.16236626463276999, 0.12299607507884502, 0.1947339049407414, 0.1066547737323812, 0.11124028624700648, 0.12542486403669628, 0.08754183325384345, 0.13974797832114355, 0.17593431871916565, 0.17597045749425888, 0.1270070584224803, 0.09771143791398831, 0.08611431771091052, 0.17213338267590317, 0.09885970915534667, 0.10801162663847208, 0.09959714101361376, 0.12321605613189084, 0.12733000037925585, 0.14397814204650267, 0.14063981760825428, 0.2197462392172643, 0.12882325239479542, 0.11855343489774636, 0.12172763528568403, 0.13587336694555624, 0.07278734711664063, 0.1769770234823227, 0.11129433156124183, 0.17936599600527967, 0.14160489796527795, 0.13726316951215267, 0.15006565967840807, 0.11694104570363249, 0.1127566152385303, 0.09591816485460315, 0.1107618376346571, 0.15716780429439886, 0.07857354091746466, 0.16546702039028915, 0.24884620415312902, 0.10569992568343878, 0.10314760942544256, 0.18758507711546762, 0.1638213965509619, 0.11337166652083397, 0.16439805632191046, 0.0893382750717657, 0.12677499944610254, 0.11781187754656587, 0.13736872241965362, 0.17965696539197648, 0.0711719791537949, 0.14804457527186188, 0.10552750314985003, 0.08964205519961459, 0.18299016010548386, 0.06985269673168659, 0.1582963437374149, 0.18357991560229234, 0.16714872872190817, 0.07311925930636269, 0.17287922836840153, 0.17139259885464395, 0.1186384010527815, 0.09528764975922448, 0.12737681929554256, 0.12247449878071036], [0.023420993238687515, 0.04341735577742968, 0.056856111623346806, 0.033437018282711506, 0.06420258991420269, 0.01848292919541044, 0.01984344788693956, 0.004322886383826179, 0.07389412594160863, 0.03738281137443014, 0.027320206597713486, 0.023220206244981716, 0.03330128074490598, 0.04153056023642421, 0.04056787850069148, 0.04068406405193465, 0.06315549502947501, 0.0016100550336497171, 0.029903458963547434, 0.04073360728632126, 0.036549807858786414, 0.041887062535222085, 0.07159687778247253, 0.01066900388936379, 0.0648842394085867, 0.016423186952514306, 0.08286778548998491, 0.018423314805009534, 0.039620283991098404, 0.024238743287112032, 0.02213723212480545, 0.0649213892008577, 0.0836347471922636, 0.009780599685784961, 0.024024480587935874, 0.01129241387492844, 0.04955871177038976, 0.04299305086689336, 0.057001467395041666, 0.016557414749903337, 0.027460595493071845, 0.022095040817345892, 0.031583935754107575, 0.05246451763170106, 0.048303130215832164, 0.02002285933122039, 0.06845427677035332, 0.02205388597212732, 0.011707882563184415, 0.026604974708919014, 0.07088889434401478, 0.0509651316595929, 0.030583422298410108, 0.10183158397142376, 0.06809689916138138, 0.03330210177227855, 0.03046967268788389, 0.004596852531124438, 0.07861150495175805, 0.02219700427459819, 0.04584296240604349, 0.04622456032250609, 0.08181048543857676, 0.009532957304535168, 0.03236727050638624, 0.06014242635241576, 0.027528333643983518, 0.056307081798357625, 0.022032434087512747, 0.02031293644436768, 0.0549994498225195, 0.05634082195215991, 0.05122438971219318, 0.015351859885933144, 0.06641986593604088, 0.03326049739761012, 0.009083629718848636, 0.020982650507773672, 0.04449352928038154, 0.01946998730168811, 0.03811631790761437, 0.016215378817703043, 0.037022719625383615, 0.05496453241045986, 0.03752010275742837, 0.01174611207430384, 0.03545596869662404, 0.03259065780522568, 0.029304224332528453, 0.01290661221303578, 0.05555781628936529, 0.04135748630921755, 0.030170343749757324, 0.02335828303226403, 0.008964305094975446, 0.03270260929795248, 0.08721591931368623, 0.05467045194070254, 0.02596234267444483, 0.023155784433973686, 0.053080301731824875, 0.0176189285037773, 0.051245760172605515, 0.019014612272647873, 0.02874599696536149, 0.020356394915974567, 0.0027470155203315827, 0.012317591230385005, 0.021644300182483027, 0.03581400787723916, 0.041583631852907796, 0.0174558443083827, 0.031522653863898346, 0.03229765620614801, 0.06655250596148626, 0.033277423453650305, 0.014961588595594679, 0.039437788605157814, 0.0074573390385402095, 0.05095004443345325, 0.06302488382373538, 0.026791142665648034, 0.040176133093025, 0.05674982589802571, 0.032333808551941595, 0.03996393144396799, 0.025620947957837155, 0.023540883591132503, 0.03284656050215874, 0.05931063062910523, 0.0076579776027106816, 0.029451534285077026, 0.026269250848729695, 0.04204708144866994, 0.06759649315582854, 0.039716296696237156, 0.01939981660273458, 0.046017848021749935, 0.052591569921267886, 0.03628425978656326, 0.07703648268112115, 0.010693772113882005, 0.03127214891303863, 0.01341537946635591, 0.009112083236686885, 0.05629374519256609, 0.057609163357743194, 0.036782195924648216, 0.051755618170968125, 0.030960077087261846, 0.06657373053686959, 0.009655577912261444, 0.03765170801697033, 0.03809076427881207, 0.04348494804331234, 0.03198825102299452, 0.019860730173864534, 0.060017745542739115, 0.04734434327110648, 0.03045277377324445, 0.02594839538713651, 0.033546326881540675, 0.03219772496127656, 0.025689429104594246, 0.027572502881022434, 0.015302498159664018, 0.007362783487354006, 0.012665525328234901, 0.048675896999027045, 0.013059665116348436, 0.024296515454937304, 0.019658701461074606, 0.03260135490979467, 0.062397971749305725, 0.09212989027478866, 0.015107996096568448, 0.004058552041117634, 0.053403348861528296, 0.007886827108450234, 0.04618525957422597, 0.05263897916302085, 0.051484635033245595, 0.058150708941476684, 0.019268379280609742, 0.08109703300786869, 0.02359101884732289, 0.029390418635947362, 0.05664953842226948, 0.02880476149065154, 0.05576522408851555, 0.043184004191841395, 0.051687466113695076, 0.037985204585960934, 0.01907695098114865, 0.07146189002586262, 0.07308735458978585, 0.017408267129212618, 0.033779963451836786, 0.09342239091971091, 0.050902475735970905, 0.1073152461488332, 0.017572706698306968, 0.07616774751139538, 0.021347634494304657, 0.030010857486299107, 0.056369357742369175, 0.010530035676700729, 0.022623887618205378, 0.031643368636390994, 0.03747519730989422, 0.007176584996549147, 0.014075180981308222, 0.02727266843430698, 0.02337371970393828, 0.026522531007815684, 0.04086757045505302, 0.03486380100782428, 0.06649756498102631, 0.03532753898096936, 0.03387048002332449, 0.0362131018191576, 0.009892514707254512, 0.031198029140276567, 0.06217246063585792, 0.012903052448694195, 0.052099428472242186, 0.03510641120374203, 0.1031088854319283, 0.034272081152136834, 0.03529505750962666, 0.07762042313281979, 0.01848057298255818, 0.02954755716824106, 0.10934646786855799, 0.0244297814289374, 0.028743540668593984, 0.02401977664391909, 0.012800937169231474, 0.07014258724770375, 0.00362186853141923, 0.03304057741271598, 0.0253132068818169, 0.03582523763179779, 0.04747017759031483, 0.019240954591493522, 0.011203792112480317, 0.06350471664752279, 0.04352698328771761, 0.05335311012874756, 0.026971884038565413, 0.04493423777499369, 0.05766890836613519, 0.007621263769189162, 0.03617620987019368, 0.03214672287659986, 0.07338544859417848, 0.02403404114634863, 0.033153947043631754, 0.030800899557237114, 0.0634108277569924, 0.014686315420216747, 0.07180892676115036, 0.016146904456296136, 0.030133919989956275, 0.02544446778483689, 0.0030413557417757276, 0.014011980533333761, 0.028439204142029797, 0.021250276593491435, 0.03840030177629419, 0.04328205928738628, 0.019457673587437187, 0.05543007189407945, 0.017186236900410483, 0.04512407151716096, 0.0180376473747726, 0.0315029458142817, 0.04887633624353579, 0.021998660006959523, 0.009731863059901764, 0.05299193950902138, 0.019146220924864923, 0.028192687280742184, 0.021962843536000167, 0.06522178343896355, 0.06813837800707136, 0.029510251312915767, 0.061490444732563834, 0.04792304543246116, 0.03129391631643687, 0.027067138480820825, 0.03721153895769801, 0.011995931704794722, 0.028602676798722575, 0.01463492148156677, 0.045499297989798446, 0.019565996614151766, 0.02871868932353599, 0.06754483628485884, 0.03633763674380524, 0.01948095073125192, 0.0421626698890967, 0.019748485214742165, 0.04856731443266783, 0.08563392170305763, 0.04125112255236932, 0.04727762970807297, 0.011886827514639922, 0.01588134790238525, 0.06707908306270838, 0.04157496356804456, 0.04514370492792555, 0.013031986824768995, 0.04030444406505142, 0.038388746324926615, 0.02031430708510535, 0.06915014157337801, 0.007898894853756895, 0.02562250180302986, 0.07743557662303958, 0.03029075657416667, 0.02765258528026087, 0.05592762465987887, 0.031393379372145445, 0.01845341461843678, 0.04897998246763434, 0.05542772416291492, 0.02087503994282867, 0.04600184477333512, 0.006345962714736483, 0.005369943949127836, 0.032767840261970244, 0.03084542163248573, 0.06842762391482081, 0.04472643303285752, 0.015040390259985412, 0.0034325356329126017, 0.03734101022460631, 0.05788815660136087, 0.04762919905728527, 0.018813041570995535, 0.018068298497902494, 0.037638866741742404, 0.03796181548386812, 0.09726673963346652, 0.020184133534452746, 0.014278329276878918, 0.028454294760844538, 0.051365562315498076, 0.035607193796230216, 0.08643091536526169, 0.05179672382239785, 0.07851038966327906, 0.18164813997490065, 0.12052977670516286, 0.1123457554993885, 0.11992996531937804, 0.24630335345864296, 0.2906677914517266, 0.11164934786834887, 0.185925068333745, 0.11824095595095839, 0.09162645121770245, 0.1615390625915357, 0.10895992003913436, 0.08195408380457334, 0.13341793870287283, 0.1865389118237155, 0.09401065363947834, 0.14856775291264057, 0.13590846077672072, 0.15596906361835344, 0.2331896871328354, 0.11980303855878965, 0.18579944436039242, 0.15308433984007153, 0.17366054787167481, 0.1374050783259528, 0.13240044830100878, 0.07071464655122586, 0.11538884256567274, 0.126047229926501, 0.056050453068954606, 0.19450860417314939, 0.15964943755950245, 0.12931694090366364, 0.18420358427933284, 0.0790796669732247, 0.12290299364498683, 0.17691982298025064, 0.14036353171936103, 0.1370437177164214, 0.10810244855071817, 0.13059094468397753, 0.08720592449286155, 0.1172184579606567, 0.09900114299463374, 0.10946344730577298, 0.18360911974949495, 0.11286940132933003, 0.06525822076946497, 0.11146969215146132, 0.1545717700251511, 0.16872843966952392, 0.12897273365940365, 0.17977800246860298, 0.18756412395409175, 0.1179244736475604, 0.14093010845993245, 0.1740384783063616, 0.1880672848118203, 0.1006141903677157, 0.130173618506108, 0.10938762780278921, 0.1710028619106327, 0.09489483226622854, 0.1346866906221424, 0.10567741189152002, 0.14478772931865283, 0.13130451925098896, 0.1072574146091938, 0.09143443259277514, 0.12974106600242002, 0.10460428840347699, 0.15181785422776425, 0.15740561724773475, 0.26887416946036474, 0.15382884203323297, 0.09324450617922203, 0.19272427420531, 0.17426687319363865, 0.1266701386443206, 0.09392008957053934, 0.1553362618599619, 0.12296883868319647, 0.1502409659858261, 0.10486809603337731, 0.10286535242838518, 0.19434810349983828, 0.1000856523002897, 0.1111019193860037, 0.09189658957932677, 0.11972971606467452, 0.2552066014281341, 0.07017694826104812, 0.1280016414821148, 0.09630536407764469, 0.07988952565938234, 0.13391841256192752, 0.125821712027703, 0.10719529472823654, 0.05954026045011623, 0.11249963367091757, 0.09650508407503366, 0.1195856359388147, 0.10063071948076997, 0.13530498530183518, 0.1516955415053027, 0.08100142742374114, 0.1157873733235257, 0.14613151364028454, 0.12318538634904794, 0.13411813255931648, 0.17433562236172812, 0.08472171958003726, 0.10337787706937109, 0.18179454069052423, 0.13855681009590626, 0.09762272624565022, 0.11957294733396598, 0.17149792106023856, 0.17856411689094134, 0.12814517877995968, 0.17514428682625294, 0.11403937212058476, 0.22871911845036916, 0.12074162890868527, 0.08742324568863426, 0.1105577207303473, 0.13966983822839601, 0.1171383908284562, 0.14187513132180485, 0.19948850838201387, 0.10873280758304255, 0.15293682632701738, 0.15302929707935878, 0.15488381470952714, 0.14855727633195265, 0.07157801450895411, 0.09832237727407898, 0.13669391934360775, 0.09699407033622265, 0.12240846375269548, 0.13600275000291212, 0.07808156910219363, 0.20044389925897121, 0.07800534247819867, 0.21942245587706566, 0.12716788479260036, 0.15668756434960024, 0.22893624965633663, 0.13676642759570054, 0.09750071207859687, 0.09975637282644, 0.19377584063581058, 0.1438638088958604, 0.08955356744783265, 0.18175609489636763, 0.11735108441540174, 0.20041238809270517, 0.18435968804572309, 0.10155827685126237, 0.10460829176008701, 0.14261945709586143, 0.16448935999401978, 0.12567972178970063, 0.07258181207414184, 0.13513611150639399, 0.10603541375270911, 0.10594225767999887, 0.18986582330295018, 0.1574938539415598, 0.09728223058794226, 0.09180607300783906, 0.08467582347137587, 0.16477281121270998, 0.10405830520072154, 0.116738068738154], [0.03471707459539175, 0.028122477566025088, 0.06191822034972055, 0.01625750057532319, 0.02343847569344299, 0.049215315375477076, 0.07174219962741647, 0.013061493768223693, 0.04262946466250079, 0.06414789999169962, 0.01989727946264403, 0.060536451637744904, 0.08730306356613125, 0.03876935697293707, 0.052088202110358646, 0.011916767872337784, 0.049269625318369696, 0.018070178039904152, 0.02952887031382748, 0.09369195931191955, 0.0980524763997112, 0.02043333400173911, 0.03562151088512369, 0.11323495528527669, 0.06872614539627518, 0.06685761601797172, 0.019683398439415863, 0.0335853731791888, 0.03232673143169709, 0.012048474912132536, 0.033131575744066916, 0.04052873381546565, 0.01248311051832778, 0.04575601153607879, 0.04659194971567818, 0.055296512453683784, 0.06218360896621432, 0.05056670946734292, 0.04708637443504163, 0.02791217072600765, 0.04151108967406409, 0.04791691486856767, 0.03131850981818778, 0.019498836914343492, 0.07516399744365897, 0.03189453515889389, 0.013026822325108307, 0.011085000986765538, 0.04415559848504407, 0.020315950836188028, 0.04996564279177359, 0.006032173771278134, 0.017423082941344807, 0.018067832005077174, 0.025821628082277517, 0.013071735406161418, 0.009165565366856754, 0.04239245577316199, 0.015759247222117016, 0.031222639605402946, 0.07868300218667303, 0.027425618709198067, 0.019314826698973775, 0.027011206839233637, 0.034023014695516655, 0.027206015939425145, 0.019002622558868358, 0.059171924500593116, 0.022211017719070827, 0.04508094722405076, 0.03723366598465613, 0.08668730660740818, 0.0460798186250031, 0.039829713824604235, 0.007725664863495955, 0.019623801012390425, 0.09205381971384798, 0.06020588294735976, 0.044069024202014716, 0.056794039239840846, 0.016472206018599014, 0.0639891702947872, 0.023865983289267336, 0.024905980697699955, 0.04162510730592268, 0.009686637004571301, 0.04015246918424964, 0.03904908981972507, 0.028129819314926863, 0.04205914580130151, 0.02043147142311292, 0.019627858651801944, 0.03030317715768303, 0.021209993665771823, 0.025306178955361247, 0.022897215094417334, 0.009884901544345277, 0.038302260251449685, 0.04191429553819554, 0.039820808052484474, 0.01896206652080374, 0.03532086558906095, 0.055863598095519204, 0.044366639839219194, 0.017827476241758893, 0.01668595981651119, 0.05601558315434626, 0.07925013532595974, 0.008904146180222077, 0.045369297465575595, 0.019713174252371703, 0.0969915801127042, 0.0347360260784626, 0.013934234839065798, 0.030831145255693367, 0.0662753719038197, 0.02464126722354974, 0.055391113805983744, 0.036957726148622375, 0.0329956855358822, 0.07927504434649434, 0.009556333684096379, 0.003461165781897892, 0.054983521212956736, 0.03936241014993616, 0.04645186276840312, 0.02183274462419961, 0.038889155723154545, 0.05975401255169085, 0.05164882354438305, 0.026480192118989568, 0.041804172697343996, 0.03940254210361412, 0.04650598272149052, 0.043083604757807085, 0.05560323063816343, 0.00943612611653017, 0.031027672745819603, 0.008847167050199849, 0.012797206922966455, 0.030434080133480684, 0.011087071366741188, 0.11019391739474875, 0.0439658156330032, 0.015796449600851963, 0.02185036617863391, 0.033382949219750505, 0.024323073315567205, 0.03889406492401447, 0.04368844748075519, 0.004658959265465715, 0.05006681575572916, 0.03539834750284042, 0.018801121407055428, 0.005197710557175534, 0.032910770270973444, 0.019624669537214295, 0.04343740648723074, 0.05745825716959579, 0.035639424209616015, 0.009635893611370452, 0.01841477713813739, 0.07538508450878517, 0.012587093465429331, 0.08586545820747103, 0.031196068174072673, 0.06597743396248136, 0.012921020904156779, 0.03692361619323492, 0.057665888885302205, 0.024197988777554462, 0.0589696124994329, 0.035665595305285284, 0.03446064603381923, 0.031253333136971505, 0.036892963373767476, 0.013918677727425737, 0.04023996288222926, 0.06354272817926747, 0.06074336410633155, 0.012025884785024183, 0.024938316284013645, 0.022292872791045477, 0.017724216782620976, 0.01280852234257119, 0.014832059653209788, 0.018062313819038014, 0.037988570119653425, 0.06316500809043646, 0.024392523071063415, 0.0855044572214995, 0.07343795363392149, 0.03161959955468774, 0.02472998058822538, 0.014305545316476907, 0.063328799658588, 0.06042778425450836, 0.030022270445312773, 0.050109515964452706, 0.04660593092973743, 0.046616251447371075, 0.03410690197987216, 0.018513157930491225, 0.041296581005943675, 0.00538008041413767, 0.039854765337492735, 0.02029179498952414, 0.07280449369656188, 0.03348712809383869, 0.01088782973654036, 0.037321366635816436, 0.023530279785128574, 0.03318616049364209, 0.013575093039045376, 0.04247150510283453, 0.0559604928961822, 0.031101785733231475, 0.021734380795221244, 0.03302379384902971, 0.03828923577176673, 0.026716164546087384, 0.02400711687680866, 0.0003538985531901874, 0.01308619074656495, 0.049126607099814076, 0.02896696189418435, 0.05571336026436516, 0.03970840872664537, 0.05167041792135153, 0.016616108029016426, 0.00963586222912584, 0.027497809746169617, 0.01050344982650131, 0.02332824089431337, 0.025637573762131587, 0.01932740504188197, 0.06681925164801733, 0.049116574959563356, 0.017857888181294714, 0.02058840130588838, 0.025544607679226568, 0.045710261312446425, 0.042546320373990705, 0.020349039596372416, 0.04019259435257741, 0.05308379279449582, 0.029435744775193076, 0.054358963655041795, 0.041420858087284226, 0.04559572460129857, 0.025591686135157943, 0.08111800652529512, 0.023595816089904735, 0.023136673495173454, 0.022726470238662193, 0.031101103805537735, 0.012709144103739942, 0.04259424530235784, 0.02402872482447752, 0.06525773900960173, 0.02153792285493442, 0.03970727896583932, 0.03726599817829473, 0.032178444388721666, 0.042741568825606785, 0.06467475529227938, 0.03536102129146457, 0.011674746305548718, 0.026753132830240896, 0.029526424195085253, 0.04720475504707013, 0.00580056305209707, 0.014359285289953862, 0.04098243625568492, 0.03761768627113529, 0.013982726344173508, 0.05886838186000075, 0.050397913703428845, 0.039310509006359746, 0.04050038122971143, 0.05830236151814461, 0.01643643365241587, 0.019519508483686616, 0.06857445210750614, 0.04569538782483765, 0.0450365947825568, 0.035312567105782885, 0.08796784467995167, 0.029672824910708835, 0.019683108365695392, 0.056099874167037864, 0.031238429115286896, 0.05340217160327094, 0.011550512480815607, 0.011649749923630484, 0.012891165363336248, 0.07419272206191506, 0.022353815413745384, 0.05927805416285992, 0.051434654143771956, 0.0621816615707108, 0.02783403911494783, 0.032258345279842615, 0.023946077562868595, 0.02797630924864539, 0.02842968768839325, 0.02246911038777658, 0.04482113955808537, 0.019780143962374756, 0.028500967792102268, 0.053038113817040405, 0.04185986685167466, 0.015344786158363734, 0.022587267083248923, 0.014038856457253652, 0.03919696634901421, 0.03458494007853525, 0.006733102990048272, 0.12380938072289739, 0.010590857011266053, 0.014614188844071967, 0.05731172074696847, 0.025482774479314685, 0.017746420144768696, 0.03364845997254763, 0.04172491641449077, 0.03463820168482406, 0.03554608493245073, 0.025437551816659312, 0.0018127096949943475, 0.03464518381016595, 0.04538565015952502, 0.06820482015609741, 0.007430120454435902, 0.05196755858404296, 0.008755063554937286, 0.047989803100270886, 0.0267530564950513, 0.060819108970463276, 0.03452533416982208, 0.06552899695400681, 0.009448517862308239, 0.04091722904039281, 0.025401506340131164, 0.041018242548618994, 0.047837241286677976, 0.060441701007740836, 0.023226691343422447, 0.02128872917299824, 0.022257611022463868, 0.03686209003041897, 0.030535907883729254, 0.16457116417586803, 0.1151694721941437, 0.20545079559087753, 0.17933554335364274, 0.10190382759485926, 0.10388221857803208, 0.1917820604784148, 0.1680188820298229, 0.14581965894571372, 0.2854531412678105, 0.0764057979519878, 0.13056886515447072, 0.13035969994962215, 0.09639356005936861, 0.23724178969860077, 0.16424518238220895, 0.25246974400111605, 0.0815278756033097, 0.1419174854776689, 0.1834313842867102, 0.18147203299616063, 0.0929924032783934, 0.1802007026438202, 0.1829403420644147, 0.182429825887084, 0.11752340516873769, 0.06491028836795262, 0.11095532189522471, 0.13372038890208515, 0.09362356976738997, 0.13910046592354774, 0.10578161451433386, 0.07120771759322711, 0.10982559501592602, 0.11214755542044129, 0.22373599798551627, 0.1146463081240654, 0.17306426486798696, 0.07931123061903886, 0.15897376595863275, 0.15088101449821675, 0.145193181133696, 0.12801894412509032, 0.24101441726088524, 0.13896967151335307, 0.07475543115288019, 0.053141193464398384, 0.11122581309505872, 0.10466214708451714, 0.1459786125591823, 0.14079327508807182, 0.08603992313146591, 0.15944762767425605, 0.10475322005472013, 0.09764823916235141, 0.06505618018231221, 0.1666710672101804, 0.13093767607850687, 0.11258512229791709, 0.1077675779483148, 0.15986655519476958, 0.14256849911596092, 0.1064227893948555, 0.06489047514540808, 0.10246596671640873, 0.10384673119655677, 0.11318454691874129, 0.12446053006819316, 0.11931350268423557, 0.13593178881066187, 0.11912647129169532, 0.1628999188542366, 0.11275030486285686, 0.0936817948573402, 0.1318410097488335, 0.1660777154777731, 0.1813889124563762, 0.15380676250372613, 0.12782249466649123, 0.18397826994104044, 0.07584880891122989, 0.22081966804606573, 0.07465867205922093, 0.13177591109914438, 0.1938532886228391, 0.10871990184698786, 0.10734487098774739, 0.07063670323363372, 0.058993673351194174, 0.13627903589180537, 0.14537487924098969, 0.14043348867978367, 0.08813891692885331, 0.12636011599430017, 0.09930282644927502, 0.07060702411191803, 0.10973222181200981, 0.18009183848542826, 0.16061126094843658, 0.12554934807121754, 0.10128577718777315, 0.19379679379718645, 0.1348734913127763, 0.1187955904752016, 0.1624275499156543, 0.1306060217320919, 0.09189112737242665, 0.16901959904602595, 0.08187188607241426, 0.07000768770064626, 0.14480735255139215, 0.23284656554460526, 0.24780055454799108, 0.12131834296243531, 0.11832527071237564, 0.10037224513611623, 0.12874359238360608, 0.1263732931443623, 0.09300416907561676, 0.1235472626451935, 0.1571622538779463, 0.09789180609264544, 0.1031951340181487, 0.20354249727513107, 0.1909144991742713, 0.2074273545295, 0.10099130656038012, 0.1365613200302635, 0.11811303852924279, 0.18718871766967432, 0.09391914640686341, 0.1483342418713229, 0.09442232083529234, 0.1556598280689546, 0.1267808484179633, 0.17524860480001994, 0.08802357954638344, 0.09729286323168448, 0.09390538571668522, 0.16364661950085843, 0.09007416665554047, 0.06291445224945034, 0.20117223874798842, 0.12870810500213078, 0.07933641783893108, 0.13349567167460918, 0.06634678092918225, 0.053803606491003714, 0.11923384267304625, 0.11687294792916093, 0.11061270920825855, 0.1258190114583288, 0.07547008459057127, 0.08039759232529572, 0.21529225393065385, 0.08178925407784325, 0.10952396584408623, 0.08727022247122866, 0.12521267256566457, 0.08510451511080776, 0.09818997473589011, 0.11547399871051311, 0.1613995557917016, 0.1763666948037488, 0.21023313754371234, 0.10739504865237645, 0.18942826321082457, 0.11390628426202706, 0.1715493675853525, 0.17736761538045748, 0.08928652320589338, 0.1149846256843635, 0.07490346035254852, 0.13289531746080943, 0.08355806594980614, 0.11959513542907578], [0.05442873062565923, 0.05510899251593011, 0.024327071583164588, 0.03762776590883732, 0.04586098768881389, 0.016169060320992554, 0.023298195363687615, 0.046761217061430216, 0.0542935969840203, 0.03467466276405113, 0.04221278987824917, 0.0592676725770746, 0.02890551376289555, 0.022632728929498365, 0.016235512648043886, 0.030858622531273534, 0.02893794434411185, 0.05871427298656531, 0.05641696715195264, 0.026076044787519743, 0.014454532946859087, 0.015991365570308905, 0.010964966445629085, 0.03854474152571388, 0.025002395434837257, 0.018097407650202513, 0.015200254806716527, 0.03664608519258244, 0.054814660988215885, 0.0435122794338635, 0.010464946356868106, 0.05043228489479848, 0.03376991095553551, 0.012007686475824033, 0.06945931605462517, 0.01541215620402779, 0.07212617580911942, 0.041004142590931485, 0.059312001269842894, 0.03335031168535352, 0.01121757909589048, 0.07646875243101801, 0.051024859704609425, 0.008766927739738353, 0.0246908630444003, 0.04172613777752433, 0.04050940235278436, 0.06768747791647911, 0.018332496285438538, 0.014176999401700283, 0.02059965311283512, 0.007384997027527008, 0.02095287469481783, 0.015585413335689476, 0.016791819761108075, 0.008030046343005129, 0.06335687065230948, 0.04828879955623831, 0.06783037060605628, 0.023510429243158017, 0.052942613405840735, 0.017492972048265592, 0.03126700222492218, 0.017497335028435503, 0.0051099581677200535, 0.08817509641604764, 0.015245508003447737, 0.012656625493296554, 0.021411252241315584, 0.027712498226069977, 0.031991911719420126, 0.04560042345630271, 0.016470652173406312, 0.049163285310247114, 0.02297319405313049, 0.04099298408254981, 0.05992474553308316, 0.0425764473288187, 0.04722839520711984, 0.03188570402562618, 0.03145720576867461, 0.09613808483949729, 0.02380950203431504, 0.021184002381882498, 0.008907742415820914, 0.0570088837827955, 0.027340615234736885, 0.03709486486124141, 0.03029983876539128, 0.026944332124133195, 0.02970198156046016, 0.05953775665589741, 0.020205610864130513, 0.049205737853688855, 0.03349432735038655, 0.03569519639547382, 0.01613815644356821, 0.007372399176737028, 0.010852801214371408, 0.05264860757493547, 0.003938243541467402, 0.05149464003209557, 0.028756449797323773, 0.05327944836712309, 0.059293226205876896, 0.038057509277548106, 0.14486546229038919, 0.01909489992872945, 0.026019370150087134, 0.01618701435758599, 0.04454583415229406, 0.008585872544374849, 0.07958169467747211, 0.016442265660901154, 0.04821315647235938, 0.011740040882224483, 0.046720206404903104, 0.02765658694053335, 0.05728107810552631, 0.043926681125802655, 0.04225733230954834, 0.0563795357676489, 0.04847048409283161, 0.017176552509356822, 0.011411253346263297, 0.010891863627226224, 0.061185592519385476, 0.026062519888260534, 0.008055366725394768, 0.008877490780183246, 0.035213847045919726, 0.07111405940460307, 0.12734385606433662, 0.03798725036904216, 0.0342147178016603, 0.042184142129761834, 0.023030940775892565, 0.040199919138103724, 0.08946434687823057, 0.023128476792148182, 0.014232562089871083, 0.01841164061001369, 0.010415018053858407, 0.020320966906313385, 0.03888346959969827, 0.020026284236727015, 0.04602570206459079, 0.05124450149014592, 0.021502102991299968, 0.020693842255111252, 0.04054400424606033, 0.014229045582136937, 0.0661211476794311, 0.0244566412376506, 0.04424194885151727, 0.04369639991117375, 0.020616440069196478, 0.0064575690027725485, 0.08554932874228273, 0.01836502186155745, 0.028992071082549434, 0.07528831862977572, 0.02798850421926805, 0.011509473834718977, 0.043764674104750156, 0.026354008354246616, 0.03129270852410367, 0.015131953471739377, 0.023982952548457042, 0.038407904761178155, 0.029336967039853334, 0.009184589792442108, 0.03347215282597712, 0.023608487731377994, 0.019309707152258073, 0.05918895572956119, 0.0747092364888106, 0.049214677552559545, 0.05015159531363419, 0.017347492443929826, 0.03148571441748312, 0.02027257887779602, 0.03069141793197819, 0.052778112768594704, 0.031724019308707545, 0.030104430858045816, 0.03690952980624778, 0.020693228180919374, 0.02216122342672731, 0.05027948559394904, 0.02480788997906659, 0.027735531097278, 0.019380356218399744, 0.046668291690626314, 0.04867246361183269, 0.03306254159126963, 0.0230107916785138, 0.03025659912132791, 0.02664415501723332, 0.039304018818906376, 0.01256423446881984, 0.06894430119012084, 0.03502174699679017, 0.02819092817870634, 0.05703791829624346, 0.009609066033070641, 0.028523305164916173, 0.09655118374420063, 0.04601860798097082, 0.004944827765159841, 0.04355644867090242, 0.02341251155095441, 0.022697873380301253, 0.06967581622302532, 0.035088799827333005, 0.01047294119572533, 0.0483699319884181, 0.02127080736681819, 0.028305824513414075, 0.03785481729677745, 0.054200383235833476, 0.06219629757106304, 0.05578072861369167, 0.028316718393138478, 0.021969596655773263, 0.05846953219068902, 0.04100407134475453, 0.011724452388339808, 0.07325364316680602, 0.033789690251329114, 0.0261011929916484, 0.033674186627779684, 0.03295139076986483, 0.03154978847929409, 0.012972937314771116, 0.02415588398330978, 0.06374923352684293, 0.011782722431235015, 0.025109247736898915, 0.048724354577383826, 0.03265684889629483, 0.038453753372388225, 0.019449181721678803, 0.010003908104928476, 0.01996054097877017, 0.045192715512322526, 0.023835696878709962, 0.1044336436316371, 0.05738750632320132, 0.08958107525748865, 0.06332486415547983, 0.043591756240597794, 0.021164565746273314, 0.07285282574594021, 0.03153962741738983, 0.04404166567006281, 0.00699274187042777, 0.10669968596526555, 0.028562392174665416, 0.033886296674609184, 0.01679359921919448, 0.05870064800339086, 0.014896053987156068, 0.010305931675247848, 0.04048188775777817, 0.036445347392665486, 0.03386295506996768, 0.02305043169430324, 0.010311233578249812, 0.02472454552272601, 0.030864305262054716, 0.051373290829360485, 0.12081060877868108, 0.021696348907426, 0.048046990031642575, 0.05192249707345452, 0.02213167492300272, 0.01918551997680749, 0.04682776777605925, 0.024127475418416516, 0.03851501829922199, 0.04969481571710535, 0.06149403418281248, 0.05119999298559768, 0.009549402448880886, 0.06987662187644414, 0.026746311856965934, 0.023407637973182967, 0.032354256204728565, 0.05393490640978728, 0.014892737647252423, 0.045483070824827464, 0.03898989103202309, 0.032407276931085756, 0.014061745987938983, 0.017389025572421293, 0.010977573626275574, 0.022052666305431297, 0.05627670378557273, 0.062115110856081755, 0.05530644959903189, 0.014626183646864124, 0.05023971665650606, 0.07937362191400357, 0.13458949726607117, 0.03286623462502446, 0.09882363823375531, 0.024089886274720942, 0.00971030515419053, 0.035744648027632914, 0.04479560628533363, 0.017774026342002407, 0.04451193793543747, 0.03177139801638467, 0.06146005993442876, 0.08485114334949426, 0.01608986171361591, 0.017377353073762994, 0.07759535126388073, 0.02956342470965215, 0.02232962055131793, 0.015325405501893588, 0.0699067624019725, 0.060524034446903636, 0.036556243763438294, 0.029386924180601324, 0.024522294589717473, 0.05110769186701093, 0.08058201135801417, 0.04552372185779469, 0.02493360385830913, 0.047058082917439084, 0.004164634205933128, 0.06514215056917497, 0.01660339906811714, 0.07028917795313255, 0.007684089326565819, 0.07379510054098708, 0.06254170582230602, 0.0167660523937749, 0.03217528580820986, 0.04774000721850565, 0.015396395531882132, 0.051378434124801836, 0.005011614694792245, 0.02146952652505466, 0.013714206288568676, 0.03248574272064226, 0.02481959979715092, 0.006783556309528649, 0.0205786762027336, 0.024150394635008912, 0.1816683874598571, 0.14517349004745483, 0.14557400212756225, 0.1308435904128211, 0.14481206158442156, 0.08493373463196413, 0.12884005292185716, 0.13138578060482228, 0.12220007207776819, 0.11389194003173284, 0.09732919878193311, 0.10526819420712334, 0.0570096844541175, 0.14753340770091328, 0.14128233598811285, 0.13061393345040934, 0.0617289769330195, 0.1994552058832986, 0.1852354324821915, 0.09644206852785178, 0.11902508458920888, 0.11957028747669288, 0.06747442470597369, 0.18585964398724691, 0.11668853568179266, 0.21516443150384085, 0.11094716590430055, 0.11932194365986756, 0.1250664482691458, 0.078401776562844, 0.11922009555356843, 0.2699816200350012, 0.09758725922022547, 0.08460013967539583, 0.20651769691279956, 0.10732796189508267, 0.11173670925199986, 0.15138280471520765, 0.1418950938220535, 0.14374811867518084, 0.11990141256579331, 0.14058377061571392, 0.1691293588706425, 0.10322182080043213, 0.1299743192004306, 0.1378877745675189, 0.15134886439357484, 0.1698662614715951, 0.1460977361670562, 0.18552044433142456, 0.12382593697735242, 0.08563094293432576, 0.11762693604188305, 0.0998562260397843, 0.0963532007964594, 0.07419066610080854, 0.12133077372397695, 0.17471488272505148, 0.13641221874526568, 0.14158280486507074, 0.12070249100880963, 0.08351360155003411, 0.09785314995263304, 0.06994381719934088, 0.12512423231133393, 0.08193821965583734, 0.10664168479187147, 0.05118672423330801, 0.05570019668500338, 0.1512202684368406, 0.11149048246443272, 0.1395489504294736, 0.12942197812455042, 0.2034618737442153, 0.16717178534184182, 0.15401229076087475, 0.13436878339520522, 0.15154825869415486, 0.1280161892729146, 0.1519672404974699, 0.11243303545883723, 0.28705681807228495, 0.15772326663136482, 0.09463455301842519, 0.21951700294656412, 0.22973431540387018, 0.09375426918268204, 0.06791433252926384, 0.08780665190092155, 0.16882912069559097, 0.118927429829325, 0.1462096944451332, 0.052055795277867994, 0.14478820429316588, 0.10342947287218911, 0.10526244701551539, 0.2243335023522377, 0.10572467864091907, 0.13187975409839833, 0.22603045058037552, 0.09686476870306901, 0.1279649463083063, 0.1961006780288049, 0.15673910586961678, 0.14692478893058641, 0.10234271083027124, 0.21438642325145857, 0.16004959680140018, 0.09854452285383429, 0.14527343825570174, 0.11826006349708353, 0.05890680051275662, 0.15210914931127004, 0.11505190921681267, 0.08911367319524288, 0.15944575491760457, 0.07601629849523306, 0.07714666319744927, 0.11528505384922028, 0.10626483322786433, 0.13820425687091692, 0.2381941271679742, 0.21372341311403684, 0.09116540024323122, 0.10354617411004645, 0.12857268298310892, 0.14001139918608324, 0.12408745794423989, 0.24011546692677907, 0.09285633665110384, 0.3099298807127135, 0.18215634913316794, 0.19419932791164943, 0.18171412072011403, 0.18009198776313237, 0.08764343708753586, 0.16960316630346434, 0.1888607908040285, 0.1877748497894832, 0.21119458095303603, 0.09889981736029897, 0.08406224461006266, 0.08245229135666575, 0.12341820528464657, 0.1440034242612975, 0.10004090970116002, 0.18429499651704515, 0.12604302300938539, 0.14045243337750435, 0.2269600299852235, 0.11452935582825116, 0.12059376255742141, 0.17464787060660975, 0.2831298102225576, 0.12332383463425295, 0.13710915563361986, 0.12000585267586367, 0.1541910847382886, 0.15423364245465823, 0.20803304202854633, 0.15994264611176082, 0.1970622164330312, 0.1470035668462515, 0.14107038878968783, 0.09627546103937284, 0.14775851847870008, 0.10094966486628566, 0.1066430825740099, 0.09200634940394334, 0.1471181714109012, 0.15268100505428656, 0.07821139320731163, 0.1418163701891899, 0.2347346299460956, 0.19173144176602364, 0.13515403840158666], [0.021367259423381517, 0.015770875615999103, 0.005873489451395082, 0.052296268088476996, 0.011605970844227289, 0.06382963314120259, 0.01670784087452505, 0.05348340581570353, 0.024976380402222276, 0.02713646779635123, 0.03297558393595474, 0.040381325475339375, 0.007170773344114423, 0.020162747807002494, 0.037734560535422394, 0.0321087486642812, 0.019833319055448686, 0.04442100067223821, 0.046182050103587766, 0.00910791872800993, 0.0667631435873253, 0.03867186166878257, 0.01456054047282253, 0.0319208860663431, 0.046248471896563254, 0.04294689012957471, 0.01651672300483499, 0.030561478475907018, 0.018858449134443487, 0.07741930535329239, 0.03994159746382918, 0.013565251736768653, 0.04557041524510298, 0.055124442758304734, 0.05557392131803291, 0.0625490407858576, 0.053389781553830416, 0.02641653874889016, 0.07747744901904038, 0.02242696488143078, 0.06682930075164352, 0.04143050006989922, 0.019762393486286913, 0.04032539722642728, 0.04743005920733724, 0.010947636661252804, 0.005957147730181792, 0.016672585891293626, 0.020915733384234563, 0.06503133222992931, 0.018775313327621137, 0.009388888204869415, 0.002844125755862998, 0.006980575313459018, 0.0351354423245149, 0.04261314928797739, 0.046818834862538745, 0.07008825016341039, 0.06297841774565832, 0.035738385149410794, 0.05956576658146722, 0.06114637998065778, 0.025854648988960043, 0.02950188158346074, 0.007592841633595526, 0.04828076230894242, 0.03616879348243986, 0.020272550040057728, 0.026274193976340548, 0.05499733279326132, 0.049600462030087195, 0.03736327635124326, 0.0482256483020527, 0.04068568575062922, 0.004974831311431314, 0.05834677163511515, 0.000516799146550641, 0.07819195317902736, 0.014853163788627301, 0.01878593409700053, 0.01026915168456201, 0.04321164431582604, 0.005658331934163081, 0.028346590897334472, 0.024391931049259644, 0.05294322408735752, 0.03861223540401884, 0.013924468175641127, 0.02441420735392187, 0.01467679048489247, 0.023992869337754588, 0.08299786743841, 0.08563487843743392, 0.09314615252826895, 0.0075491575490949404, 0.04895261036498206, 0.03590582384328757, 0.029530790567930256, 0.02909595479390451, 0.06359705847821065, 0.018915061007386873, 0.007184750317329807, 0.05611625400238803, 0.060251812982772074, 0.03814841261399644, 0.025784476593668972, 0.07111238342310701, 0.0018565110388278428, 0.06032711001379149, 0.023691236773239713, 0.00556772672903857, 0.04514834610745311, 0.03472057583608797, 0.02070967586977141, 0.046530515155089755, 0.06616375289325203, 0.016028632409870625, 0.047439833504280875, 0.04332892570112433, 0.022533856199256012, 0.08562456470515047, 0.018754531496337483, 0.006025413442070463, 0.02169851682681058, 0.025095045998958603, 0.029246345295437744, 0.05490937090611883, 0.017319545282849243, 0.02930421076182808, 0.053324550589812655, 0.029810581090194837, 0.05394099626157965, 0.013296668068505824, 0.02565839800185391, 0.01770794720921133, 0.04790195656408157, 0.006935163933251585, 0.02955739592601146, 0.016049178450235298, 0.09089522795485598, 0.07797427914504494, 0.011008466477505863, 0.059692550849701674, 0.018521851660417657, 0.03623367500092302, 0.024634775339758823, 0.015837509451167922, 0.047078177732016356, 0.012831289736953164, 0.024819258833304048, 0.012062164356133767, 0.042656019130455594, 0.03973692076812897, 0.0408123580605856, 0.04040040588006377, 0.004880358880784894, 0.03206951916217804, 0.08584253729454108, 0.029854733363858292, 0.04950364186827626, 0.035044895218951364, 0.011560615019074507, 0.035931862624628205, 0.021968611083658676, 0.010478392376431396, 0.0432599119043776, 0.029282972615744387, 0.019731532017301236, 0.06285325517611844, 0.03238323982805014, 0.029189874218510728, 0.050402103657169, 0.029162580147385597, 0.010612007795966097, 0.03662357818601387, 0.031219301213111197, 0.015979363982166563, 0.011286329960317483, 0.0483364971753742, 0.05338739650323987, 0.058071632470403395, 0.015832040458917618, 0.05162864391292844, 0.042124648179326735, 0.016717849266050116, 0.049821175900953155, 0.008513525444349008, 0.0613556673218097, 0.04950364865362644, 0.033157034377966604, 0.01390320119181914, 0.05058814438858202, 0.0045677416824868745, 0.09589276728885514, 0.03205736999266914, 0.021742436702230146, 0.014889465412124991, 0.011172327595496816, 0.036169278634978194, 0.04199232367266502, 0.02672107544328485, 0.03438220399298838, 0.02930318278127483, 0.03839203043441687, 0.05345436451690538, 0.05197599616699985, 0.03200611345736044, 0.028048819197075706, 0.07786994081522737, 0.040601140287305625, 0.022346821414040666, 0.026430616654189568, 0.03870662301778793, 0.05895933947925057, 0.0596427395939827, 0.029106607793697288, 0.05593280866742134, 0.04930650369663324, 0.023587821251047508, 0.030315801301704984, 0.04716850770637393, 0.023628909939101765, 0.033242176952106614, 0.017918695096990893, 0.0439866500507508, 0.03205982968211174, 0.05167452305821436, 0.01475503744690546, 0.02030673802697233, 0.018216297163494995, 0.045940250757017305, 0.0448908081411251, 0.0870461023545691, 0.025288939076874937, 0.03222913095461471, 0.06027727161667176, 0.01504336393970464, 0.028454152268490622, 0.03418842117701258, 0.04030127530651433, 0.05813784391752311, 0.019702909713877097, 0.05920762222792421, 0.02633592369966209, 0.05769026864852224, 0.026677947757499557, 0.047937963024846146, 0.00957148113021893, 0.027674525710088865, 0.0524273474833795, 0.026991242642647455, 0.05306326032483152, 0.04018221955214228, 0.05101708708597081, 0.04044683803138988, 0.014802555254261409, 0.017771037395245264, 0.021232872170263102, 0.02017870864697865, 0.058914298324712684, 0.034740765645567856, 0.03591842423858387, 0.02793098141306213, 0.06305723637342453, 0.02838083147071302, 0.019141223514452577, 0.03725149788494621, 0.08203318063169718, 0.027715434586363177, 0.05283224629238248, 0.02597630862146616, 0.03147094610280224, 0.08065638558140822, 0.030389544487531697, 0.051776605259094916, 0.044594200128423314, 0.04857833044869559, 0.08170501395527806, 0.0481970310876412, 0.055485609985355816, 0.014028925249086959, 0.006891740660648793, 0.03338890675721424, 0.029111374502203295, 0.011027515499985643, 0.04851528436743787, 0.01909686259127089, 0.02381197190178292, 0.03265362585495625, 0.021531851662855064, 0.036117438559553454, 0.03681640087493828, 0.00498415480667193, 0.0517838927251952, 0.012278814650406795, 0.004401534953753331, 0.12437322975269385, 0.018017365963065197, 0.03767162301976766, 0.04403324505048139, 0.009159260080195963, 0.022596501944852725, 0.019780410287369574, 0.01998928881117276, 0.030477170499839952, 0.0033223373050402316, 0.0488036854990891, 0.05270511597128851, 0.03317747524540339, 0.015025231787668807, 0.03150236905951585, 0.025497171296072856, 0.0329213859513402, 0.04361428699589201, 0.08444466016122273, 0.02045467053540051, 0.04835998127236962, 0.025750895895596062, 0.027131356731323258, 0.05809679933424507, 0.022159216659409658, 0.03145361631842596, 0.024531514184283357, 0.01764656523508685, 0.07191099878400564, 0.033090680438492975, 0.089274865974273, 0.017735526265044297, 0.05638992413878441, 0.028947508295199702, 0.03441207988985947, 0.008929238405211695, 0.022550093542252268, 0.061766832401709895, 0.032317293009587696, 0.016276660707912276, 0.05738998976136957, 0.007228047636869762, 0.02213565961989973, 0.023677223328767077, 0.008081485234600092, 0.05591760269765343, 0.02280167057844145, 0.08953504344182354, 0.030143361804740768, 0.03493408027238079, 0.011986042905066694, 0.016952924330585768, 0.006617663827325616, 0.0491043545438775, 0.007724491846082466, 0.08735054066138608, 0.10815051597143922, 0.10538820669587169, 0.1884068101644516, 0.11257012667400496, 0.13342499546706676, 0.09206095111689397, 0.15973814922784055, 0.17776303844792501, 0.1346847635826894, 0.0703958911555154, 0.11522558704018593, 0.09678443015686103, 0.1328054251415389, 0.12525449746421405, 0.08830528014472552, 0.13382588752678462, 0.1410968652261155, 0.20454060871686253, 0.16543358218457016, 0.09095755139631884, 0.1667438197348799, 0.12331802637449332, 0.057370156182774475, 0.10922501010021993, 0.13034482646201337, 0.10597466451248952, 0.10551628018064158, 0.11296639112489563, 0.1408228049320834, 0.15999679320624896, 0.11990623016442571, 0.08712903968989849, 0.28250615511621746, 0.18179432355931827, 0.17464023030229978, 0.17865246215036937, 0.08104865346103907, 0.1472742480358907, 0.16494591906666756, 0.06375398327197347, 0.25388652512005394, 0.14463094701724394, 0.14157622307538986, 0.17178609488265856, 0.06455726016845022, 0.06885848686631237, 0.1235157379082271, 0.08997940924018621, 0.10766853897699288, 0.0924121540571962, 0.0729123196963753, 0.09974508878907987, 0.10814141681683914, 0.1422136388719082, 0.13045883391584667, 0.11547045675771576, 0.11246607332889523, 0.15752163316522325, 0.14481748986457074, 0.24315864220261574, 0.12060742825269699, 0.09558383029486452, 0.11537430834557329, 0.1320793248180832, 0.09482179475682122, 0.1355742144265345, 0.13142719838236058, 0.13703489676117897, 0.2014011357511793, 0.17100748951945985, 0.11086840155933585, 0.12475873263818876, 0.13564603057290825, 0.135761327243277, 0.14611555449664593, 0.1556480351303305, 0.11524067765900067, 0.16262391795005116, 0.10841525997966528, 0.13287785196942942, 0.08541087367172752, 0.08504632394760847, 0.0906659916841558, 0.13244494662753173, 0.09679876081645489, 0.1373274132077183, 0.2002525795251131, 0.12439176732940332, 0.15275872445532254, 0.0960405861426677, 0.1639605640832867, 0.14430173539689609, 0.12963973358273506, 0.1835102029144764, 0.03910592391288706, 0.10550247877836227, 0.2078767754137516, 0.09262515298490014, 0.09690294308321816, 0.15517885530633585, 0.1227729863354138, 0.13946557204638207, 0.13977829526577676, 0.15025110329900468, 0.12456260887639863, 0.12054417521825858, 0.13594970213515417, 0.13103431303586277, 0.2176004672156913, 0.1048485745808908, 0.09381741365151745, 0.103937885590962, 0.1158497714038406, 0.08762194109814507, 0.11592929570802621, 0.11069376021623611, 0.09856086197708334, 0.10453626526785748, 0.09536443278193474, 0.11942301823624543, 0.13726593793502875, 0.1067832000553608, 0.12913453711995057, 0.1475584049310003, 0.07681015732565097, 0.09917347053331987, 0.23049677163362503, 0.16074281531785214, 0.1232446903096778, 0.14548097497650556, 0.11312339055751051, 0.09356498505387988, 0.1178903840482235, 0.12362685480288096, 0.07816867264253752, 0.10149843006261758, 0.1161232345870563, 0.06946428971631186, 0.19529299065470695, 0.15425984747707844, 0.3010476401873997, 0.11445211140172822, 0.17441680229135922, 0.0839907405897975, 0.06886738924575703, 0.11696184958730425, 0.11996143577354294, 0.12065763984407697, 0.1379984300583601, 0.13115009825144494, 0.12228484824299812, 0.09498371356832129, 0.16569895723036357, 0.07844381859259945, 0.11756907057549272, 0.06259529651807887, 0.09063747285732202, 0.16835439045514378, 0.09421264672917978, 0.11946457172078745, 0.1267337987997702, 0.07513323945126363, 0.1929666062018701, 0.10657909672175135, 0.09392639316086258, 0.1071037399981703, 0.12394177647573607, 0.17417475527950696, 0.2041274080319064, 0.1205091763819967, 0.08858723858637468, 0.12796607267643723, 0.15883434058300086, 0.12386871182492801, 0.11967100921486105, 0.2020522036722728], [0.05812567778463874, 0.03268123883754015, 0.03993323791239943, 0.034688274176525216, 0.04645168974197336, 0.03381827014631458, 0.031907335722020695, 0.025879016877817254, 0.0231778673561556, 0.04458147081147347, 0.020679950946941972, 0.03056327659370644, 0.049673458827393394, 0.025973865895399025, 0.03176308935508132, 0.01577831744881613, 0.023230665862294178, 0.027509080212829367, 0.051774250742580206, 0.04038871472169246, 0.05000568314322403, 0.02643032488413155, 0.03398331700425063, 0.01875697591874216, 0.056255557241716554, 0.020373458375356028, 0.029913036485335658, 0.008666999039373227, 0.04798462927075369, 0.001656912117531257, 0.008822481098052646, 0.04871103832764285, 0.01878124542002167, 0.029357245058885643, 0.011050148035532661, 0.06359303476555006, 0.060191620141267776, 0.10250747948884964, 0.049919875604765754, 0.07167099416255951, 0.09086717731718506, 0.01370742857190115, 0.07775003010673182, 0.030014569072851112, 0.05756331474653312, 0.07896363069968564, 0.07281123154929706, 0.06670429424515792, 0.05334298977894442, 0.09180231392383575, 0.02216915550109531, 0.020703599588679414, 0.00977841649936246, 0.022034820834440843, 0.034468401689082384, 0.0346940077974328, 0.02296190831943282, 0.02055852540901729, 0.03407618809225304, 0.0106270551581734, 0.04722794058865734, 0.08085043981139149, 0.018639202595555356, 0.04919935283916337, 0.044733669608831406, 0.030121485835739543, 0.055738126792545827, 0.07495443868849959, 0.05275621644354292, 0.029641649619277035, 0.05472245147185666, 0.009441232940714275, 0.05761183678571667, 0.05008511584518211, 0.049959240813872645, 0.026960993551516106, 0.02387646326263036, 0.1191504235778536, 0.04880001123196312, 0.026814777736685107, 0.029711406411869184, 0.029611332674643824, 0.032986253899122985, 0.031106586368488412, 0.011781177067730044, 0.0410643761445369, 0.027855879460860575, 0.05877484580768006, 0.04210238544536488, 0.03196589668680515, 0.029778611912791218, 0.031206514220684767, 0.032414194595600875, 0.01517910317384771, 0.012216182475510453, 0.01626902718895248, 0.089711530400174, 0.06940263123916728, 0.04096868574353201, 0.046059588103422096, 0.028608033832694803, 0.09114901362253086, 0.031895176374486515, 0.037272970125611336, 0.018411873008257577, 0.029954912274011543, 0.06698036978819541, 0.024899132583024244, 0.032834557217678854, 0.026869535512690033, 0.0529413750794317, 0.022251144583736147, 0.03166762626330767, 0.031309230851807764, 0.03413819262225713, 0.031185846044016734, 0.05244689607726676, 0.028217090792687874, 0.02833017543889582, 0.016415762083072747, 0.028670961170324256, 0.004423983436676541, 0.03711362974718213, 0.013228795058759195, 0.021261893113010695, 0.011565925403764206, 0.032591692571129115, 0.0857379546921168, 0.03903607551806739, 0.019133573032117317, 0.030026053278041736, 0.01388248466953103, 0.0024538114209592876, 0.09536994248628616, 0.026566890234659826, 0.04068787402606436, 0.04373061164681401, 0.021800212262730514, 0.032937073680971346, 0.04181969757857067, 0.054866667304720194, 0.02179016824811697, 0.04067695639761431, 0.05530558446688311, 0.04485069993617279, 0.03079011763579079, 0.014839749151308621, 0.018730708131832734, 0.03870229396436896, 0.0280483968090266, 0.03240307679932032, 0.060475254564413, 0.12094187816338879, 0.023429663219888295, 0.02753013345812048, 0.07610922386603695, 0.005585821137563991, 0.049424219344343455, 0.0483398118189403, 0.030398609715380838, 0.018923208516623293, 0.009020221469524716, 0.03217266666303788, 0.02692411856592766, 0.040101589235876284, 0.02508270344696939, 0.04654842169423189, 0.024284430746255175, 0.019562171372984136, 0.0052065366014306036, 0.04776201889451061, 0.02059050985345883, 0.014119901528049792, 0.01254748143920941, 0.05017938132264784, 0.043803411668964794, 0.04389268312869327, 0.04922350190047707, 0.014573670125433376, 0.02198118094487914, 0.01993832065324698, 0.026596248748579195, 0.04756209872929113, 0.022157635672816207, 0.032191465475729535, 0.01984375322769795, 0.041732689033129385, 0.038096514863095114, 0.1049336628722293, 0.057579904927739074, 0.015957840851375034, 0.04408712073096207, 0.010319943423382938, 0.04733246212292995, 0.06549199643943991, 0.03320265228727034, 0.021434190117620995, 0.021023990253784826, 0.025922432940985476, 0.019902439721460854, 0.06381852552294731, 0.032390700320580175, 0.011014538517753993, 0.022238479727613072, 0.04049811492274914, 0.01758066930675081, 0.028596488559352498, 0.04084229163293328, 0.007922736029805881, 0.03928358812949487, 0.037704667675175836, 0.050565067412597794, 0.02016010830577995, 0.038790025149605105, 0.038498804704951387, 0.0065339703495348135, 0.02553684523861323, 0.027301484120211432, 0.0698997327791793, 0.05020022252574563, 0.017699608013832142, 0.042661973275244236, 0.03519461057814104, 0.03789382966767464, 0.04775913851335645, 0.07922472418951136, 0.043385617301932404, 0.034090376259492974, 0.06700421350875072, 0.038546865340322256, 0.027082052680530717, 0.022547759381788116, 0.024252264793696146, 0.02856456009405, 0.025033014327553765, 0.033848699049225876, 0.0542768812738359, 0.11162422850195851, 0.02594762694622789, 0.027491998093734895, 0.03887965962556856, 0.02697825039337788, 0.02318171295337379, 0.04063621036974447, 0.02788768070084708, 0.06025424213813884, 0.01927221809247775, 0.012137479198697423, 0.04335345813472356, 0.06208795588463545, 0.06415345719350235, 0.0542145272982972, 0.01594519635130252, 0.09262104106268712, 0.024115180363878608, 0.010447086467008506, 0.04607428177925093, 0.044926875670041354, 0.039426602955375395, 0.03085706868608083, 0.017496910944048847, 0.0391511380938547, 0.005593600117468408, 0.0142190617875063, 0.04702471935057214, 0.046092602224754434, 0.023643247384045805, 0.036213807495577, 0.012762790778651834, 0.026300814601459672, 0.02904573641717434, 0.0315904496902866, 0.043908269078071625, 0.04426454406763826, 0.005582584949609424, 0.027577227181089774, 0.05575135822540947, 0.04033811975802694, 0.029924982094338963, 0.030616517843944684, 0.02449484445553805, 0.019669040638421263, 0.007001137469030384, 0.030138971683170115, 0.01300090822457735, 0.03684500112597432, 0.04362132001136031, 0.011203551232548696, 0.02621898158187313, 0.055347768988992484, 0.046187023765274456, 0.037861287128180265, 0.018100669707304666, 0.03599860332906246, 0.03927040419408253, 0.028749535525483743, 0.03328662778117827, 0.041722287091293504, 0.03851288430658834, 0.03156629723629781, 0.0410680945164391, 0.04570532497018576, 0.06946726169969354, 0.05308815238199063, 0.006954035264373357, 0.04627072784517493, 0.030600677443934337, 0.02632329785930259, 0.029257283279938356, 0.002884729715463306, 0.016082179000867263, 0.03983307596562164, 0.02223380801400968, 0.05185657400371773, 0.023380530499187962, 0.01671993576123246, 0.06581413772489343, 0.02179114194586873, 0.01643314615025052, 0.02827082058813955, 0.0331985064383064, 0.006599076632742903, 0.016841961802648645, 0.012752022427905883, 0.025466652487271597, 0.0606104526668787, 0.04697890127343791, 0.029699040111154318, 0.2171221814517464, 0.029996645570333515, 0.022763111129669205, 0.0710303553247026, 0.023373444897255728, 0.027738034891496812, 0.0366292337753943, 0.015561959772769893, 0.05089943250641227, 0.018461092242172787, 0.012596408054897828, 0.017571369984320233, 0.04066894968439426, 0.014495570744786943, 0.04131452825718692, 0.032458869341228686, 0.020352215140259693, 0.013274180569819041, 0.022572420737040893, 0.07399171963334084, 0.026424292707815766, 0.017168762927342738, 0.027430916371356164, 0.015667103862922107, 0.18114348634013108, 0.10400966781058482, 0.12535892400358403, 0.100475681014359, 0.0876734351207103, 0.10443472250231675, 0.11987551966948168, 0.08779838734439441, 0.12198049814573356, 0.12897744269243308, 0.08203080575913191, 0.14995702622192247, 0.19469231074409826, 0.11567751850400652, 0.11628222891262599, 0.08086828528238194, 0.07511574681848288, 0.20560346597007342, 0.09106226292039667, 0.09292041749826499, 0.11354809919638292, 0.10742530452885798, 0.1121688885614276, 0.18669992818364076, 0.11171854486955063, 0.14331431766705854, 0.12860644688563688, 0.0868208897965295, 0.19393334218433925, 0.0742882869339415, 0.0769163209146687, 0.10890634969941207, 0.06535500700452498, 0.10866962240210601, 0.05462345999798604, 0.16415671498647758, 0.10575039511812584, 0.17801429996533052, 0.11573714816144534, 0.16497497393616609, 0.2364080058676856, 0.09324309482638325, 0.2257329672574997, 0.08923108010951962, 0.13594022978629383, 0.20800788195005485, 0.1808618400245905, 0.11666242565427508, 0.11962774582207203, 0.18323540980262415, 0.1483094482017415, 0.0810970872906702, 0.11529721319675446, 0.16626281983086041, 0.07459018073443856, 0.1813038105943373, 0.13123518654278346, 0.13106662487345083, 0.058128900825977325, 0.12888414412736893, 0.12033271656504699, 0.20171164694641316, 0.17034485936164856, 0.16388914148722375, 0.1497524750552007, 0.11059143713542394, 0.13455757897879395, 0.16763840030346597, 0.1553174935813461, 0.18228723853826523, 0.19441191293299198, 0.05274439975619316, 0.11174598482570477, 0.15563149244657584, 0.14002885110676289, 0.11853406950831413, 0.12298756624971117, 0.19687711207994393, 0.09273166941212756, 0.08332426992378064, 0.18813197634049825, 0.10093087623161928, 0.18082106006996973, 0.11279246902891568, 0.1533639369798558, 0.16678766666778497, 0.15165811351367406, 0.11413638905755111, 0.10526997875422239, 0.17930293296064648, 0.12872786394187383, 0.13551690535885946, 0.10206837912223168, 0.11907514690288476, 0.09263282721596104, 0.12104816388870988, 0.13672043649213655, 0.13933236205152102, 0.13446666885699543, 0.11444937012025289, 0.1302655871425356, 0.1792902714971985, 0.1291233277214425, 0.14234946801194123, 0.08894780530993428, 0.1389864177576133, 0.12222023813852242, 0.07252513404403414, 0.1636439325021846, 0.10661468588347946, 0.1418003567627498, 0.09753679657088858, 0.10178156915519919, 0.1218955319906984, 0.13503967810954365, 0.16506078147462436, 0.12667324633470603, 0.1605920312660081, 0.13160007553441183, 0.10724427138588258, 0.14552664038326057, 0.11041862783687455, 0.14532207564583846, 0.17626095190644264, 0.20855191775730678, 0.10787294086601053, 0.14721738680132798, 0.1877370961010456, 0.08279050713671104, 0.09484441711434297, 0.11405750257628304, 0.12700597276645048, 0.17230765761009284, 0.19296531698533467, 0.21344495591308388, 0.1458400014255728, 0.07520155435694115, 0.17037905752658844, 0.08052481085594211, 0.11929367589099066, 0.22421604794050964, 0.14365984126925468, 0.08443223618503128, 0.1384641086416585, 0.09822905835296426, 0.06053221079387835, 0.0858431819028088, 0.09502820510949407, 0.15185349088694367, 0.14244900909917696, 0.10043274331837893, 0.1421852625374283, 0.39862268577728954, 0.10076110676995345, 0.09586511698684522, 0.1931812268282686, 0.09172344779861824, 0.11428163626364299, 0.1297893234129463, 0.1595537776925734, 0.11979030924183981, 0.05247992037662438, 0.089701087746237, 0.12398836469011647, 0.11131411085703544, 0.08564498860921178, 0.13016737598393643, 0.1357313631368535, 0.06580701989254781, 0.13965615896242006, 0.17193994591278688, 0.11287837156227656, 0.10772727296820708, 0.10101655484842402, 0.11957634000905923, 0.06369666741894824], [0.04578259653810944, 0.04407133122107812, 0.036565821285226514, 0.020646790940580622, 0.05390260135754943, 0.025880569026672413, 0.042339625036610026, 0.04827019751870206, 0.010131290332148117, 0.011943113690774356, 0.08143598839108433, 0.051329664420336485, 0.059821838912154944, 0.05463713926396199, 0.024822120554745197, 0.04209108444462929, 0.033146245671170096, 0.024374428238453608, 0.029934233919318234, 0.038820477801242044, 0.04442377927313958, 0.021963109860994985, 0.03766660525330475, 0.08309015498629638, 0.04101535198943956, 0.08803396791751895, 0.04477136901446751, 0.03381809372720974, 0.031268284656107426, 0.05720849521458149, 0.05088420957326889, 0.07214788214436599, 0.012788122187235525, 0.03193919972649642, 0.034749318579477925, 0.030864427398358072, 0.025571620158318962, 0.06258399891001837, 0.044529919113431654, 0.00961766391992569, 0.04609781337369766, 0.025977051617311578, 0.025408795502568995, 0.025560958676838448, 0.010315739898942411, 0.03665272126506482, 0.020548091236768023, 0.016861445935709134, 0.036254584057522674, 0.13241627173764364, 0.04139357419418437, 0.04625226829999259, 0.0421440441028348, 0.04270462259384138, 0.0335866759664246, 0.013252179071839367, 0.03182402519243104, 0.036914493289909193, 0.02037463054460074, 0.04863785493320652, 0.020925992833716527, 0.04295153130910226, 0.017168805335781405, 0.03179410179810865, 0.02592141683479505, 0.03178032075187989, 0.05329374849264111, 0.00889075274712273, 0.039233508852443526, 0.051512814592570066, 0.063331710573818, 0.07456737517246179, 0.03074823845443981, 0.1268321592360735, 0.059072451266859255, 0.01389192054713411, 0.02142152186882283, 0.01658974015819175, 0.05881684033998421, 0.08714358069534812, 0.014136929364342774, 0.03204453211011631, 0.01892548330527331, 0.04496579643871103, 0.0351123483851552, 0.058077488227614334, 0.026887006093082682, 0.041301500384828875, 0.020551360079220364, 0.03831317787989974, 0.0342192843423358, 0.03125761469293918, 0.03556787269189954, 0.02934114681556821, 0.021848425568480576, 0.015261236445180007, 0.05819766356476715, 0.06215723431003945, 0.044418347600315294, 0.031302798339830976, 0.044514658860862255, 0.014738588061715876, 0.06459133619708674, 0.0293658997730485, 0.027237537283716456, 0.030974709694939, 0.06272258290222713, 0.03738619387149811, 0.025124704764623727, 0.019800406714369143, 0.027804487218548144, 0.03257505828514695, 0.04747269495523401, 0.04464244736092431, 0.06358296530587332, 0.051276911715311665, 0.04413259614791189, 0.04889039209644709, 0.04769796858142529, 0.014503105876169034, 0.0036975485106397954, 0.0504216318950057, 0.02718134779882218, 0.019410014984064868, 0.05008786730468273, 0.05237636236207826, 0.0549240951160235, 0.013721204529117261, 0.0390991249920002, 0.03056467098316976, 0.024175748095980713, 0.05383854765178902, 0.04825113407735314, 0.026462823318849717, 0.00912068281987948, 0.018143447947555354, 0.03026422585493752, 0.05108288801940424, 0.0352883094788662, 0.042849120018737655, 0.09619432182184287, 0.03728906158357859, 0.051281193271279335, 0.00698691071011126, 0.04461009820391025, 0.05665132296936853, 0.03433947664286409, 0.0750125212860959, 0.0182452858758292, 0.004403524757695517, 0.05461691552773118, 0.033849292767367194, 0.04587414787550058, 0.06261750496923923, 0.04098736920527049, 0.02554615304273154, 0.08117397887898342, 0.034226548059710434, 0.03375125463519778, 0.013202725743342723, 0.005190596965673778, 0.005937960456191961, 0.02112047962977418, 0.010139420878009071, 0.01751189130092306, 0.028019703259425502, 0.022762836322986653, 0.03701059081192527, 0.06747194805315562, 0.036726447487516065, 0.04350403862606202, 0.021596000363518084, 0.11832928763968603, 0.052032697945833206, 0.030424502611692463, 0.016383794602006674, 0.022501990498442734, 0.008703650108405521, 0.03632805243666683, 0.05153992206656507, 0.024709580432889715, 0.025477548063333546, 0.04134219552257231, 0.03165017094995294, 0.0330102435047073, 0.008600105664559772, 0.019011302718094418, 0.017527721522908126, 0.014658400489549552, 0.02564393842060651, 0.018345961812883615, 0.0360557665117085, 0.007323200298872377, 0.044179713619606834, 0.04617522743397525, 0.0488436987091388, 0.012429984619042702, 0.02343981240742973, 0.1001695463699954, 0.049264197038220506, 0.014130805585799473, 0.015034056135586329, 0.0871603065835578, 0.0210586430371872, 0.01718924111420555, 0.026659147248470356, 0.012847644975408912, 0.02339046255552343, 0.01141188947284328, 0.006497316735996199, 0.033679825253784657, 0.02705858215423567, 0.026660466999081627, 0.03749089861022575, 0.07683909684419632, 0.03194953381483044, 0.07763552053698472, 0.03135516427989517, 0.032606328571481366, 0.030910262438867773, 0.03688479720481804, 0.02136535782899175, 0.04278972784855536, 0.03923854697495699, 0.0651405763679317, 0.05605991184711456, 0.05086115634601031, 0.01953223780063646, 0.052626551794154305, 0.015250695403665304, 0.04167285581518497, 0.01718470680394343, 0.04422945362914886, 0.04370228620246053, 0.033036224610571346, 0.017223973625472615, 0.0863514928413289, 0.03001983111192073, 0.05907296695347343, 0.020812655433214138, 0.044353326982153315, 0.05723033047148159, 0.09228397879217352, 0.05863487760403326, 0.013765810573074435, 0.020050930324941874, 0.029575706193489686, 0.04922936444303819, 0.012630720722622104, 0.10203392989933491, 0.024538564163127115, 0.02082761373770024, 0.03728435255054917, 0.03285036029826317, 0.07478389569691249, 0.017094711008082544, 0.013599802739918232, 0.042669396448348246, 0.07101383299699851, 0.038525362565581284, 0.022426953007067953, 0.03813098783471754, 0.06518843344279698, 0.01603878159741206, 0.020866812705727558, 0.057722736549164565, 0.05699291106845651, 0.06578333223504679, 0.028055036274184073, 0.015444118596081222, 0.024949778436816165, 0.05249613397089498, 0.007960499048099985, 0.0706971064209938, 0.028714665610875403, 0.043978368530848196, 0.038237589078822305, 0.00864097467690174, 0.014777393479432379, 0.06905965214329106, 0.044700329790690115, 0.033352588170341084, 0.018102089541831186, 0.01648291669386838, 0.035769404377788305, 0.02095039125664958, 0.008980440657718905, 0.018638842971995473, 0.032419192006013224, 0.020197147836110423, 0.04963251941704324, 0.08599066148911204, 0.03360200746517096, 0.03801156906411052, 0.053890859309051714, 0.06451120121138436, 0.022128158415268575, 0.05173661919044597, 0.03354683917547975, 0.057780452737850804, 0.03460425118516598, 0.09169378903295312, 0.0072949248964765245, 0.053860294699136696, 0.045734166101153405, 0.028967732031430517, 0.03813356287511332, 0.03480896520029221, 0.0376693397494299, 0.03709877322294882, 0.027856408718175123, 0.05457359445946557, 0.09823545015283994, 0.05620833120441862, 0.062015196574585776, 0.03325671795755625, 0.054866144832755835, 0.0317867939759578, 0.038529443953718455, 0.014906939385192735, 0.047871775326452086, 0.11655019596219063, 0.02234563058508294, 0.035067643105451546, 0.030458378472498486, 0.04932536018480148, 0.009633299063092895, 0.05859234702906438, 0.04362565924280456, 0.029315545689314604, 0.053487904502877166, 0.02489432685875467, 0.06891468992190701, 0.026121995178982615, 0.028541225274758678, 0.050604374946228096, 0.012994758152802075, 0.04737215642152088, 0.035736179910600185, 0.01965098991058767, 0.020586240171853985, 0.03180467676637428, 0.011775689415766724, 0.04925310977601579, 0.020777257957628796, 0.035518855322152376, 0.06481774976210934, 0.019993105570652654, 0.0222211719956249, 0.01872879805575524, 0.02542001847177744, 0.0289243634657136, 0.14298954366573266, 0.1395757525627102, 0.09838643776518957, 0.17368141960884842, 0.1761607187134879, 0.09416638421160833, 0.0895198035453047, 0.18627777083643846, 0.12372744083404541, 0.13222193930830273, 0.133867671713233, 0.16566109497632298, 0.27731506366814884, 0.12241984957030841, 0.10867039593202726, 0.14193481526204518, 0.12056983741266386, 0.13738211670092174, 0.19468051780547413, 0.11551306875688688, 0.09212258245263781, 0.1448853433664356, 0.14398321748844214, 0.1469296608120203, 0.06809472106397152, 0.15934306542788232, 0.1262004974165133, 0.1480873908315386, 0.07132862574820008, 0.1977138543235404, 0.09750841345105853, 0.07704748851912362, 0.10305950843862124, 0.06920892306204353, 0.11509521332170282, 0.13640926033258438, 0.0883903345093131, 0.13364830134170397, 0.14480743397559437, 0.16325430412377628, 0.26481479299919947, 0.21270052157342434, 0.09738106599875859, 0.15771661698818207, 0.11003809182771615, 0.09662172424473933, 0.12376412243715354, 0.08625176854963813, 0.08778269961476326, 0.19315468253833906, 0.1561660830463682, 0.11094590382916586, 0.17450931375580175, 0.1479967792651483, 0.13598615303635597, 0.10391811986586877, 0.13183058745094708, 0.15229794489485876, 0.06401223370007106, 0.18617485064480985, 0.1882326030837638, 0.14543283970228263, 0.1356720591762236, 0.1610653365829161, 0.12038704007863998, 0.1250361856073141, 0.2156077998557261, 0.10468278811978442, 0.07655861760888781, 0.08360177717570748, 0.10616844054311514, 0.16782049196107046, 0.0911736444437078, 0.25886064821055954, 0.15201737066464766, 0.08736070511596543, 0.09227719344198704, 0.13913037574716977, 0.12086624865021024, 0.18936551229229995, 0.14830463060310908, 0.2029018380812236, 0.18742042380784238, 0.1414135918021202, 0.20180679112672806, 0.1937390368963991, 0.1309454928019217, 0.15136398215379032, 0.10604814306965896, 0.11042285511004073, 0.15351708233356476, 0.17608579487672874, 0.08508925485823836, 0.13364181454692567, 0.08947943071169512, 0.10128532935466085, 0.14842634621475423, 0.22122796970818723, 0.15883666117276463, 0.17018954269587994, 0.13749567632164272, 0.10011874445314918, 0.196992748017822, 0.08088387801711049, 0.21642979074801716, 0.12073067735348429, 0.13385458955807344, 0.09010997973382473, 0.11960833972053868, 0.07919105528188602, 0.06379721952336175, 0.11430268441992146, 0.13160749870751584, 0.1144308325435434, 0.15034867663468632, 0.1661091452198369, 0.1042493942326733, 0.13760813671563352, 0.16635548057300703, 0.0997294621276004, 0.07447956595569849, 0.1131807810493878, 0.10101523170513765, 0.11900122729795319, 0.20493528539580957, 0.1408332950834717, 0.15831608910645756, 0.21318386920860835, 0.10921191437436001, 0.14641683761562618, 0.12717339449695178, 0.08303488152367727, 0.11246299277991056, 0.10859019309282303, 0.0856788135798914, 0.14053802378475666, 0.20458905611719402, 0.17349816087101186, 0.10241511051676103, 0.19377820193767548, 0.1904165358947856, 0.11882327470396246, 0.09105374052056245, 0.09086542669683695, 0.15935721966837132, 0.19820340376879486, 0.060624003011201105, 0.13619273980813368, 0.17309444610561642, 0.10232824446367365, 0.15108244440385274, 0.13091314025223255, 0.10436378166611705, 0.19188694842159748, 0.18000247542347225, 0.10242596707705941, 0.24443138390779495, 0.17826469295791217, 0.08340302069804498, 0.11568137258291245, 0.14651293174496718, 0.07788226979651622, 0.1817754874272006, 0.06956883839198522, 0.13260080612131528, 0.07680249666529042, 0.09074920721884285, 0.1278177449213607, 0.10200349081839834, 0.12363879701920918, 0.09734775671469313, 0.084398641916258, 0.16947786802692072, 0.1742197557219437, 0.10184514110109635, 0.09686098926301513], [0.029630477540194988, 0.014719129373718585, 0.04075957142880984, 0.02896868876580681, 0.0422428964770266, 0.03369447821751237, 0.02431485116747873, 0.024260726125378693, 0.024606609351134727, 0.015844225251514996, 0.017882071169359342, 0.034372378805918355, 0.030702973383345773, 0.05598452999921782, 0.0007507082440757326, 0.009530135447026362, 0.08571475557982922, 0.03222915470334036, 0.026433922816067934, 0.01320160022338054, 0.011942670946674687, 0.031138728572321788, 0.0160569578542241, 0.032674589194357395, 0.02331268208633576, 0.07427525906158344, 0.03616724981527243, 0.06491425779781171, 0.033562340307980776, 0.05759656296244689, 0.033307730220258236, 0.00942873941468341, 0.04297015031001397, 0.03001440961712173, 0.00930552339247827, 0.03253342676907778, 0.005909199477173388, 0.06674012767949275, 0.06215983309916087, 0.052722181127007516, 0.049617788421788385, 0.021852568024769425, 0.025648599956184626, 0.05503359370465789, 0.03775406163185835, 0.020026375838954533, 0.04201032520670976, 0.029890705897871937, 0.04793022094028337, 0.04298399920974459, 0.020812495977484753, 0.020037239184603095, 0.01948300499602088, 0.007494325982406735, 0.03935575372140322, 0.02489826236186283, 0.013121986013304974, 0.08247251848557166, 0.04967824928462505, 0.03478055154638631, 0.03984800034335681, 0.019830041731308614, 0.04054590075143746, 0.03342729148321918, 0.017600806529766748, 0.023777566783662354, 0.014227318710514476, 0.018871694138007503, 0.0473805804337774, 0.042644124411578686, 0.021273270448935882, 0.0414838736344661, 0.031588278378226926, 0.03221461709056582, 0.022746714330943565, 0.014070683142303355, 0.01683261159009167, 0.018010424549824426, 0.027909292041191032, 0.020707986317574978, 0.03489417223525899, 0.09950367960014514, 0.01967993451814566, 0.012866856846293169, 0.02671963016369513, 0.060534185330782614, 0.04063099922080125, 0.013574285582373185, 0.05239439782287393, 0.015601211327261158, 0.0394130967158292, 0.03150230799136417, 0.035617144512278695, 0.035766880227518935, 0.042339000784392865, 0.03628099264044847, 0.017909087041126828, 0.0183080147419657, 0.04000417535592403, 0.04854647662224514, 0.028070518746972084, 0.007731000693248851, 0.007672963896766305, 0.024565849752564515, 0.045492957080049176, 0.03341577335127762, 0.022140348296878592, 0.020901445133079375, 0.07644435231174741, 0.019300397651802217, 0.04325344885832497, 0.02783441061287054, 0.0346324578858912, 0.03354904780696545, 0.04691649640777281, 0.04262767672272665, 0.09370702278933354, 0.029424308067453758, 0.054496560378798416, 0.09475520333009106, 0.022598929403881942, 0.020019003555976918, 0.04925423275147166, 0.02836755762941071, 0.021302026763026203, 0.039569288691771884, 0.03756012614550335, 0.02574911474117211, 0.005987602926325053, 0.027120162599853108, 0.0720610703740801, 0.02864447794854641, 0.019761080521025827, 0.033321063433374674, 0.037246595469436476, 0.03453759529760905, 0.03595413214394024, 0.05449112192062395, 0.04283105402386614, 0.013460994831153324, 0.02481528601076986, 0.035079897447888336, 0.030904077592172792, 0.022082878077136617, 0.024437250403155173, 0.044886021076568534, 0.027253601600282958, 0.027595822433275834, 0.022485926181876233, 0.023996200944696153, 0.09458475533340659, 0.008213216023120497, 0.028482111303934028, 0.04410973291045853, 0.05084860684084041, 0.023760140308045914, 0.018912910051377754, 0.01779611604953451, 0.05512874127764787, 0.024705093620078902, 0.028083697593371783, 0.01397623700488891, 0.019135510249595557, 0.02328586807873632, 0.020818455211286033, 0.024539056101015637, 0.09619182481297425, 0.025186955263572078, 0.05810825979071004, 0.026477248973346183, 0.049569768498518636, 0.06125588874731745, 0.008899773022026887, 0.012396548957830029, 0.038795582351407835, 0.05008144836340632, 0.011000270622649362, 0.05665171312700425, 0.03492344423596348, 0.06900764243411166, 0.023049707358170832, 0.036302532734615464, 0.008786591684578784, 0.023400606654052223, 0.06470423085348946, 0.06729447043367795, 0.048313270921685865, 0.04061703157744237, 0.02271005817289863, 0.009255752000691635, 0.03494723367371729, 0.00907296993370567, 0.044472267385572195, 0.05808286901031222, 0.12163952072816235, 0.022114613159958805, 0.08847321756184101, 0.004627638937173677, 0.03926350010026779, 0.01951723199869905, 0.0051815800834447145, 0.028999721564884697, 0.02833820759717907, 0.011460840685426124, 0.02343720513662057, 0.026177945480282818, 0.03913696349731513, 0.03674082564456122, 0.026372593428407396, 0.01706749327214701, 0.011082471747483526, 0.07980129575090748, 0.015906357006835084, 0.05109481327235699, 0.053388919814356735, 0.04812178494674819, 0.03920981101691723, 0.03778193924309952, 0.007309370058854776, 0.03385621043188231, 0.01867360432100083, 0.019473020353221467, 0.03733254550024867, 0.014140811432818217, 0.04446884756907821, 0.07516212468700749, 0.010423732988004173, 0.006094630799322788, 0.03286538984892624, 0.04393701860681176, 0.029492521192878485, 0.020122990743922334, 0.048934157605149915, 0.006487782470815415, 0.005245971360376903, 0.03933699222813759, 0.012636229578804756, 0.017295513268826262, 0.03706441560227956, 0.0410525289231113, 0.018620385123150687, 0.04007621881152902, 0.04001497084807072, 0.03732954976814134, 0.0061377114117411626, 0.03674642355846507, 0.05275219951623252, 0.011975758858690304, 0.046449806807296615, 0.024952138042343513, 0.029215370171836445, 0.01140684202047331, 0.03049996927646654, 0.03651315339707902, 0.028462515212595463, 0.018754942010023763, 0.027282284971858774, 0.061696719378232956, 0.020038855794285024, 0.06249208455639226, 0.041701221971639564, 0.014118180593608745, 0.05237279666055526, 0.02901174859809024, 0.061994915162878375, 0.030966421389686208, 0.01820328625451241, 0.04556551282959325, 0.04660352552309632, 0.03442133171483874, 0.10059790552726813, 0.14433507860771247, 0.06409205655966486, 0.05624536903841155, 0.03136867391211646, 0.07189854766641345, 0.006344578079214054, 0.08799398184887, 0.023342763240049993, 0.013934475718997419, 0.011675278107369584, 0.060478966150965006, 0.056366738597197194, 0.03259432528700147, 0.06106929840253932, 0.017518284797136272, 0.02517976109603686, 0.06662232721490519, 0.04107581624495132, 0.026982728724500964, 0.018399038518379842, 0.021253601415082812, 0.06958148628473282, 0.06938156951218843, 0.05908361316791602, 0.02157810569873878, 0.020725906427417482, 0.04722986423543521, 0.04895504291302391, 0.02119522704742849, 0.008076287656357246, 0.03298011315720422, 0.03185330397848572, 0.03456063834684236, 0.012374885031022131, 0.08852226885833911, 0.0443533337675035, 0.010864829095745725, 0.0469266438989767, 0.014170626261537629, 0.01465996790544263, 0.02147607269164707, 0.11398054313446794, 0.06742016226053238, 0.01856401582647647, 0.026558289803298454, 0.008319393182838601, 0.03364644133086715, 0.019900470273569226, 0.007435247634670564, 0.010205986011507255, 0.052012491172977855, 0.06568461217518363, 0.038982691775475226, 0.05780764842139823, 0.04273790812918118, 0.07126371030296598, 0.011776028683276048, 0.042380347315754206, 0.04707218626780169, 0.0753957171525274, 0.07576988850321088, 0.02469140587241522, 0.026398026617243886, 0.0917416393224682, 0.01516287770521428, 0.022468219810564603, 0.0069023058749735355, 0.06028355485094445, 0.03256987427760448, 0.03717717794435365, 0.024241613490240912, 0.09110629305775676, 0.028643541570220674, 0.09548214503696986, 0.05056261111583028, 0.03210216348192521, 0.020389047717409473, 0.015126079054815429, 0.02868546824902296, 0.06757138736013855, 0.013131879053876867, 0.05309726171461599, 0.17366122640669346, 0.141773256074105, 0.1594198891626937, 0.12110623291560582, 0.15138462318905763, 0.11323550489864179, 0.07017578118081604, 0.13978478206055506, 0.2229723475341286, 0.12587691763682024, 0.11631971118705613, 0.21378099359571934, 0.06516862700560264, 0.1681592030716794, 0.044451483857950995, 0.2232639683144433, 0.11107568043683257, 0.23133169540337153, 0.11324082461318799, 0.11285486710923058, 0.10423270905656473, 0.07355238856481654, 0.10718730837106705, 0.04524052508973649, 0.16153013307069028, 0.0843897531075137, 0.2105711701193026, 0.11933115816542081, 0.17375922043408665, 0.13146848045289516, 0.1056513154347028, 0.13667139198098863, 0.08770335851503269, 0.09662029932120017, 0.12327417944158826, 0.11454175944839205, 0.1325936679329191, 0.14883482429598058, 0.17784070356615952, 0.13529043751103537, 0.15458542214972631, 0.07748048207057373, 0.10624565104288713, 0.12578032139156545, 0.10622662492096424, 0.1287514226777213, 0.13869713113776275, 0.11129348339246851, 0.16492909139820508, 0.07863262774688856, 0.19995155424943992, 0.0962769470310637, 0.08953804256660597, 0.14074516695524963, 0.07927123776503972, 0.11373699656022446, 0.24611659348011017, 0.0958083982446364, 0.13679407111236028, 0.09990239356245313, 0.09310907058949981, 0.1251322254538536, 0.21476500507976326, 0.07145320477762393, 0.08509213184671742, 0.13648586693618978, 0.12340399676135608, 0.11199179770691053, 0.05723246107144015, 0.09116630269480602, 0.18246254484568322, 0.17231809347867966, 0.10103049874305725, 0.18233462742396764, 0.07002254761755466, 0.05662143010912197, 0.11668217102331774, 0.12495826264577252, 0.09041655542595045, 0.13157549899603638, 0.11289088374802045, 0.08588666242680379, 0.06510219842727695, 0.1104309025353619, 0.13788454474083015, 0.18764192477932998, 0.10096996663404362, 0.15590670625013964, 0.11074632632413081, 0.13586175042603696, 0.1286261651132788, 0.11365311606121914, 0.073181162056114, 0.14333286881446838, 0.29418626693742617, 0.11599105596542358, 0.11320638896099158, 0.12522880812840803, 0.1706111165029662, 0.1212417906416314, 0.12195544663284506, 0.09850996506533452, 0.08805525356105395, 0.19073403600071157, 0.1318862001810755, 0.13346135137336596, 0.11443411665303366, 0.14319372842354433, 0.08030649899904217, 0.0976202292367816, 0.10889159834810666, 0.10430101039154188, 0.09470157192221709, 0.15847800113260746, 0.07952092508120195, 0.19900916410343988, 0.14812373316713742, 0.16311200175966534, 0.23284751549363136, 0.11958727799355984, 0.15218252608818666, 0.13574916789574282, 0.13838128665728228, 0.13469248531120165, 0.15614081440227373, 0.12496700217681271, 0.1821115386805364, 0.10354029799678496, 0.1737751117242234, 0.17206159367093019, 0.12479930903230395, 0.10485324290181909, 0.13464459430958542, 0.10586477576621942, 0.134846227775727, 0.20499619069908345, 0.15160840403820786, 0.12259708291717938, 0.12452509946056775, 0.13125187850424222, 0.11040602065622807, 0.05495850701949426, 0.09162740795207874, 0.1811202804424933, 0.16573612737868512, 0.20119381616158144, 0.06194641347974539, 0.0773604695818254, 0.15756480156310967, 0.1611399890056678, 0.04978781233408621, 0.13239341867821558, 0.1790426740688937, 0.23658317646809987, 0.11265378325645413, 0.14076679865164415, 0.14764626164521488, 0.1653308519827468, 0.0848277203206505, 0.100309107452631, 0.06452224776148796, 0.1644085736146995, 0.0974169062184436, 0.09595496859401464, 0.11922948647822652, 0.2272567804902792, 0.15262712937380585, 0.15600745512970857, 0.12920986807772092, 0.14616101634289536, 0.1147606141333069, 0.12485591242355959, 0.09950830042362213, 0.16510595833616598, 0.12746627735240118], [0.02661646400312228, 0.07699126510747842, 0.02056486631876656, 0.03650653428797211, 0.0391744322010449, 0.026334269770554135, 0.00844330046259399, 0.06140794844499656, 0.013100625730917921, 0.007784302163470004, 0.023245368019810746, 0.032719318222786696, 0.014156650984659791, 0.045270343311131, 0.029369082102285962, 0.03546107467263937, 0.013450084836222231, 0.034868635569832156, 0.028779285893376385, 0.046339639861668856, 0.035857030390096564, 0.061775870488158295, 0.01302397417436753, 0.05344726364793522, 0.06664853902267558, 0.02397057437337935, 0.04942426684179476, 0.01741760716374431, 0.05854995894644942, 0.017723947064951062, 0.026763957160125886, 0.046394563878753355, 0.0486379668914846, 0.05801694254790034, 0.015792100191382424, 0.07628102893275873, 0.03636681374960712, 0.04437557953808989, 0.01513441655385707, 0.017205673536019664, 0.021886520220765045, 0.02639626751520804, 0.05991021131298371, 0.030995693390390704, 0.01567139050790242, 0.08001880693648543, 0.05423393679250564, 0.03820333323840584, 0.04635986699057477, 0.021475792795951878, 0.10312762656914336, 0.04042852097856147, 0.04153576799269233, 0.04894710744598082, 0.03401772890772138, 0.018322645653305308, 0.027524881597076143, 0.047230047439890246, 0.02537082807560052, 0.032801688981375525, 0.06167501304298639, 0.03628364910504647, 0.039336619033877335, 0.07238837531102554, 0.019619071623310447, 0.021537885535508394, 0.03587634488940239, 0.047519432447318516, 0.010016119190757828, 0.02220810850017837, 0.010681108954096479, 0.01825975054608924, 0.028552879113703966, 0.04403382519792233, 0.032554953292544396, 0.04540015723822372, 0.028622371277638843, 0.03345136929835592, 0.03763609492619123, 0.04084786579811147, 0.026296784103448902, 0.04578111733176878, 0.07203841408980743, 0.013904381842751588, 0.032892229301588874, 0.03329880748476301, 0.05036030929269535, 0.016366999163957577, 0.014114865101873875, 0.07657094659017664, 0.06380273601306335, 0.0091405282728374, 0.02238490249562476, 0.017949614241453152, 0.03322239765631301, 0.04658440101359572, 0.05442596559545823, 0.04356946975791028, 0.03561367041298321, 0.038554159591772726, 0.012588554860225745, 0.06498095100479466, 0.0496606548715915, 0.031822545986090384, 0.012202443837720369, 0.012352917459793389, 0.07072006126067468, 0.04762099217623472, 0.03451405352513705, 0.03244198060461453, 0.041753547199602635, 0.032177603005298545, 0.060597641925726614, 0.056809489482215474, 0.051041863792176755, 0.049349034271602116, 0.017589174743209566, 0.06296988856047392, 0.05548058543354273, 0.0206448689901403, 0.019537618583334342, 0.0382496432534286, 0.018815336715696112, 0.04268400530729975, 0.017564024842743362, 0.08535517951739685, 0.049788758890437226, 0.05981719094727721, 0.016817454814112613, 0.07815459304090057, 0.026566913983385478, 0.07474431674927473, 0.012642467860132456, 0.05257333429264171, 0.0335897361593587, 0.08930251627628293, 0.03459865327126213, 0.030252711115671054, 0.027182772722361342, 0.02323360731160002, 0.01699167037648814, 0.016091027097510438, 0.07480425853282213, 0.09805531267608915, 0.040724630268024545, 0.09168615551399333, 0.02061416019153382, 0.09234641079923936, 0.02441216496351574, 0.0499529372235494, 0.02134368542049612, 0.027923680376261473, 0.06533264249031033, 0.05694588180631399, 0.016523791643391763, 0.08524698710867337, 0.010954447456502488, 0.03838943503797054, 0.029737428229834353, 0.01283937448170036, 0.028185625427535603, 0.009077328673031713, 0.018297434684687426, 0.05901826346027, 0.04368981472881777, 0.019839480153418014, 0.029032382848007337, 0.031238062706376826, 0.051750376487949064, 0.027369276553924595, 0.050632805563509464, 0.018944897888494388, 0.017210964412827576, 0.04723740615216749, 0.06317903340927192, 0.025661405608324066, 0.03903033171913453, 0.05068752941276346, 0.022139379688139473, 0.03784245438873768, 0.02726722488711987, 0.01690465843837176, 0.025233884441799352, 0.03905723223994885, 0.028083273508985127, 0.02543433047165828, 0.012562183596725975, 0.025064598436334302, 0.05634530706863318, 0.04234213900885411, 0.018451765778341463, 0.047188812866806984, 0.06275692355952092, 0.0547081750950643, 0.035824816940086227, 0.025898275397984043, 0.02103693500560309, 0.03853441761540515, 0.04881744958194239, 0.01448318239168397, 0.049633445617343695, 0.020959887354235564, 0.07410405110567808, 0.017347994559843625, 0.04530755417155368, 0.026879209725718414, 0.07352085025714976, 0.045831189823469946, 0.04179490390898926, 0.03362439912078636, 0.025652545637318065, 0.04003438373495426, 0.0358963684578027, 0.06985558729086604, 0.04107443881886346, 0.016583149886823127, 0.03749438967289669, 0.02792352600954473, 0.030529244669846127, 0.029428535340619937, 0.04028305664126362, 0.06695227843842336, 0.014604063405256187, 0.06010030968380826, 0.028886002488434315, 0.03349863265507987, 0.0434462613692241, 0.014963211990626795, 0.0672342029533216, 0.04738614781360541, 0.030340350698679686, 0.010963834140316715, 0.03101168306810515, 0.0845236959201949, 0.0277935153072966, 0.043128595022218566, 0.008223194728738495, 0.059309443192822595, 0.04818425088056496, 0.06252392820481743, 0.02347908092529646, 0.01195694223445441, 0.017187224168862616, 0.0051057007845624214, 0.11201050491737467, 0.037557568068483045, 0.08662366002265896, 0.021363208569320183, 0.022310385779876794, 0.012669059647513288, 0.024763985370684947, 0.06531687333647694, 0.044815103989094496, 0.03419947111979127, 0.05557222498048629, 0.020313479272382598, 0.006963594126448567, 0.0026701502252503163, 0.021774295617693236, 0.015533028735912271, 0.016858590999618173, 0.03796006486352001, 0.058920547632234435, 0.06428672825651509, 0.031256664743913073, 0.050342334900051355, 0.07992593584848301, 0.02836517257882016, 0.013654198347856956, 0.031541154121181796, 0.010420364909805357, 0.009894576605542429, 0.010901594667562416, 0.037403211529765806, 0.009890775961269225, 0.02515199374673622, 0.043213771523109505, 0.058563739992678165, 0.039399369952401946, 0.017621841115344847, 0.01736413690793727, 0.04549724881404212, 0.07807606618319239, 0.03176049395863499, 0.051675096420305114, 0.04655181776200022, 0.008104693676744188, 0.0227007605468056, 0.033802857223365984, 0.056669911436204395, 0.01097149819335235, 0.04255255611081209, 0.051645837990300994, 0.028394875449261496, 0.038325215091130564, 0.027847764182037542, 0.08088696535144534, 0.030705758769597327, 0.02210115611420146, 0.044011630317462344, 0.0693167287058064, 0.033480678618486436, 0.03154840426785605, 0.010339526792189904, 0.037634473227496655, 0.0547233844575073, 0.0308904186822474, 0.027437521909762706, 0.009657867967949381, 0.027517195491652404, 0.03497885001291122, 0.01937051915696689, 0.0557060117301132, 0.016494731684880595, 0.032657730991819074, 0.032575010787695646, 0.03360927796789578, 0.017406216257118752, 0.018026860364313637, 0.08786297030746937, 0.023433072858357003, 0.0844075782224536, 0.04725097345986536, 0.056032600812613964, 0.08535007014870644, 0.05592862889170647, 0.03670413386342781, 0.03484349584739123, 0.04006043608699526, 0.05218229116871953, 0.03653105315087097, 0.01886216750634568, 0.158265673954572, 0.028334263612383177, 0.037382312651191435, 0.041168524484549246, 0.021358955851090804, 0.0912138612142631, 0.02007714891806245, 0.03563087806105614, 0.030994933431169817, 0.015069470574547137, 0.009467421847927784, 0.04128687456250191, 0.06090562218534095, 0.06827669058527265, 0.025583306227677634, 0.036164637455450635, 0.05942188323076282, 0.05735246677483831, 0.023311459026964645, 0.015411569271236658, 0.08248025378478424, 0.1957948487251997, 0.11767414850848061, 0.10543018765747547, 0.1115961167961359, 0.1777795675609793, 0.09961863021765437, 0.14104958490601607, 0.190899096429348, 0.1630694576139961, 0.14702578208276204, 0.07623995042272977, 0.09175652638077736, 0.14133830155645097, 0.06801031809300184, 0.12073926760682038, 0.13669982259827002, 0.10846553263919693, 0.1239757982215711, 0.07664233525948864, 0.1148115721132074, 0.20568645080285414, 0.21947508305311203, 0.08408308242048536, 0.18410830439201423, 0.1317598433899028, 0.1641299942774432, 0.09554444133703198, 0.18071812630764075, 0.158602933000241, 0.17823155330760138, 0.12603916893047945, 0.150406772802983, 0.15081274030464037, 0.06048260309866496, 0.10064696360911642, 0.0676450626924634, 0.13625634568078177, 0.10309236988957439, 0.11241905763745308, 0.09506281718079533, 0.09777749329805374, 0.12466094217130116, 0.15776871490691388, 0.15795216363455566, 0.3126344398728439, 0.1836853056613888, 0.10026485339871474, 0.15856340155005455, 0.12887453607150487, 0.10854110108422381, 0.10924205489988838, 0.1668372540069478, 0.1393661666661501, 0.054365270638040135, 0.08010949992707797, 0.10329284306083407, 0.19279496398355278, 0.12204038564647947, 0.2667902527110917, 0.13039350456425122, 0.10952368764472858, 0.19689693887318882, 0.14403687603771687, 0.13510586241526262, 0.09668801033071109, 0.17412260307797364, 0.17411078299794877, 0.20512161111193045, 0.10139352854873453, 0.17373150906392507, 0.12124622826065336, 0.10881532422666039, 0.164406917989254, 0.11662680256579604, 0.13646851001041277, 0.09707629520978246, 0.08332179327096258, 0.18579943078969205, 0.10591320281050035, 0.16256343333848886, 0.12656031096620218, 0.1234269312449864, 0.15548089838453702, 0.11046516855380364, 0.11153221236807959, 0.2185771640922342, 0.09171575321150677, 0.0706917867064476, 0.1082251819648913, 0.10641229924346719, 0.09917835598545414, 0.07114862397845302, 0.11241945118776389, 0.09433772108916726, 0.15430377583418572, 0.11440892943314143, 0.11356147312160049, 0.1541046800890139, 0.16525516818676675, 0.11346957233867475, 0.1701318265071937, 0.18258324265480042, 0.1492137453917946, 0.10519444423594645, 0.1430122067353555, 0.13219487933175905, 0.21204872083451065, 0.17018777850483144, 0.15134339540132455, 0.13795484096876212, 0.14493019453116826, 0.11483610793948174, 0.2087377142161131, 0.12552182669086115, 0.1202737247305257, 0.11277301542993103, 0.09900577060346093, 0.1573099573808057, 0.07954983745834657, 0.19587267669183867, 0.11131761888308184, 0.18583495888326848, 0.10349491078938756, 0.28954373033983366, 0.12695874672915253, 0.10596422185855252, 0.1227157994040421, 0.10103936719575099, 0.22406326899571077, 0.10977752080985478, 0.16361342556774616, 0.11842549033463001, 0.10719690285623074, 0.09428980973150049, 0.17506926799459116, 0.13988577521273068, 0.10683088071112122, 0.13223730134112494, 0.05378246333982263, 0.09916446637362242, 0.11834937227623803, 0.32509790680238176, 0.1687308552541903, 0.15681527821081026, 0.18174545546727522, 0.0699335170377578, 0.234284408390522, 0.15937881065266474, 0.08700488813753639, 0.13606331603867666, 0.12480153462716512, 0.15268111361988954, 0.10764521772840194, 0.1296395164515291, 0.15003827400505543, 0.17300056400043623, 0.1829009870333331, 0.11325955896505288, 0.10503268148750067, 0.0816929360319461, 0.12966863917452948, 0.10386950283178262, 0.15053422882088593, 0.12068620616836206, 0.16244656246687683, 0.08989240748009511, 0.11666881745415074, 0.1350775132221835, 0.19288857467472553, 0.06345694099685975, 0.09653951972723007, 0.08430145534553699, 0.16431003675929137, 0.1203924547880888, 0.10027695846344743], [0.013196272875315376, 0.02451350586488843, 0.04077960178256035, 0.012103262374044528, 0.07388738130352326, 0.05540227909971561, 0.024323514363329326, 0.027403917462964143, 0.03379280133438962, 0.03783151640423706, 0.06929673227880682, 0.04272064959098186, 0.009628479768122946, 0.04060812580532261, 0.07376473609890256, 0.029304027557373047, 0.007617560664324888, 0.04103983014023729, 0.02744105368453477, 0.010243333427102437, 0.03251151008797543, 0.0625423707866243, 0.060737861187330315, 0.06298190541565418, 0.031633343281490464, 0.03804257132911256, 0.032728034005101235, 0.023056358697691133, 0.0631486689671874, 0.051826575970543284, 0.039297766118709526, 0.04136754898354411, 0.0271591240806239, 0.09752075600304774, 0.06475626091871943, 0.04073893717889275, 0.04077322694606014, 0.08541814756712743, 0.022425796104861156, 0.06072367302009037, 0.046621452418289015, 0.04278904592086162, 0.03738633297117693, 0.006759536593952882, 0.04760206783456462, 0.04478470562025905, 0.06790908066821949, 0.033256317621895244, 0.021378635062969158, 0.026799917819776704, 0.06103808579168149, 0.006801216031557747, 0.004100800599969391, 0.054921842379761596, 0.025627855444326997, 0.019133006455376744, 0.026017958797248344, 0.03530409898875015, 0.027388574089854956, 0.029180483293852637, 0.015232722707358854, 0.010451719164848328, 0.018967085983604193, 0.03736064702804599, 0.033831691568983455, 0.03670020514566984, 0.016548634506762028, 0.05082926520013383, 0.06704611304615225, 0.03825570596382022, 0.027685521370066062, 0.04286371191431369, 0.045917859101401906, 0.0682928804308176, 0.06797314794468028, 0.05810479926211493, 0.014814253197982907, 0.025105390265317898, 0.035516551695764065, 0.10605334064790181, 0.01615604093032224, 0.05446995162804212, 0.026656409359670112, 0.02283451845869422, 0.0260699668100902, 0.07998526016516344, 0.07730884663760662, 0.069255077014012, 0.0443150779631521, 0.03354567888059786, 0.02284553786739707, 0.03970293973439506, 0.02928901497008545, 0.02782784748290266, 0.02873579179868102, 0.03835374070331454, 0.03145607940054365, 0.008488059176930358, 0.03394875243040068, 0.009754874726890453, 0.02010313680927668, 0.03823965861062918, 0.014714415251676525, 0.0725635119846889, 0.017491967816437994, 0.041713252397520204, 0.03490238590165973, 0.012362794385158589, 0.016227546646924954, 0.0740733202546835, 0.023863523599824736, 0.026121720372300063, 0.01803653797001711, 0.03015099871637566, 0.06389604814882789, 0.050212985769446404, 0.04724481575457113, 0.010955025907605886, 0.002033477636619604, 0.04529713526634233, 0.04276464240891593, 0.04280494738902364, 0.02903919873226966, 0.02776963765999036, 0.024043041913371, 0.07368586318833487, 0.06121508165129593, 0.03975819962631379, 0.04123348403455956, 0.04244726104661822, 0.004269590426702052, 0.035499025136232376, 0.027877227868884802, 0.025868994915591817, 0.018503081685464298, 0.016609251432652985, 0.048231554949390035, 0.06519853004387446, 0.035574841246541054, 0.09191130700388125, 0.04202775337866374, 0.1440378124160426, 0.03293344351862158, 0.07748529288385596, 0.026253420626744628, 0.038825570206557, 0.01856029236556164, 0.012491194414906204, 0.01760873181878456, 0.04216506851038762, 0.03098302853426763, 0.021430802531540394, 0.03942980903333851, 0.06641449193869318, 0.04050384515098163, 0.04822759230488113, 0.041207099200359414, 0.010277870011382868, 0.011376014478238565, 0.0337530493603221, 0.03425982002434986, 0.029381631607455865, 0.05666063925517457, 0.045868207301412306, 0.031211202897663628, 0.027439791609400084, 0.019041801170845116, 0.026432075504479662, 0.050130788037287335, 0.039033724394227774, 0.023690758406051567, 0.019968652864918113, 0.04254634751539145, 0.009698580069068288, 0.0461152110115758, 0.03803488352735128, 0.02689639532140323, 0.05133883482111352, 0.03119453468493053, 0.03758455679884978, 0.08399596530944109, 0.026306061373491372, 0.010240289349375027, 0.0644085660044636, 0.030530238723648444, 0.01292047298712922, 0.07000090913580996, 0.02240312794622566, 0.0032683880459184623, 0.017587334216971482, 0.038585341668554714, 0.04732419078105262, 0.022793507802167108, 0.03352145178775702, 0.02052260037245495, 0.01872657415723162, 0.03338434700188892, 0.07425977489245789, 0.0535310627227383, 0.057054277775543075, 0.08853404144091265, 0.01261726367686476, 0.0143519367557019, 0.03522653904344354, 0.026585480397833244, 0.01809365874422448, 0.017280722901757275, 0.09679730875151497, 0.03477339978728976, 0.010191517948572124, 0.05192806784595762, 0.02774222823791206, 0.01823434789132859, 0.036494527610817125, 0.055115835541593175, 0.010812936433857041, 0.0021814001790646997, 0.08220385254493781, 0.007716172158585063, 0.03351821178304298, 0.06377607637218066, 0.03748461198327797, 0.04555812019056507, 0.04044932825490832, 0.05353445539783154, 0.03076789900660515, 0.029378866577254872, 0.04638089139812759, 0.018147985650492564, 0.022283736317019378, 0.02010436326132289, 0.003408591616399852, 0.03917315655520984, 0.04178848836038794, 0.0465252700793956, 0.031248359475284815, 0.014393620858235019, 0.06803152909768478, 0.06582174410245248, 0.05494499060192278, 0.01799459263150181, 0.016403027677110264, 0.07727006836129086, 0.04915355511807969, 0.027913597345884358, 0.07623935331191335, 0.035365523371313295, 0.05060487027679171, 0.016449995871101106, 0.052856816045407734, 0.002578519796121067, 0.04926798326362457, 0.04073304410225578, 0.0609909411785858, 0.034783845833901844, 0.020796404519517506, 0.017198513295235376, 0.04546254514051335, 0.09837682970932551, 0.03760667364778263, 0.05204081322465624, 0.07492150938404457, 0.0975104829828654, 0.019348436234784976, 0.031571063944803815, 0.019575699664918438, 0.041617300760533125, 0.020223890597532903, 0.03889953391626477, 0.034952465178711076, 0.02616786414624325, 0.03007995949259826, 0.03859942466286676, 0.03457191899152739, 0.08250791087214436, 0.021314555912145546, 0.07095983518021447, 0.051380978631121774, 0.030726593187344924, 0.031022376779999052, 0.036124339260693104, 0.06420632864215545, 0.003535322025917204, 0.020160732557997108, 0.038195156891431124, 0.07310068780290228, 0.007533133944629559, 0.020800316273900013, 0.0649855514722211, 0.039594638760068586, 0.045895277455981286, 0.024484444210039716, 0.06000810356012412, 0.03755581405545984, 0.026861101322408234, 0.016198001535875455, 0.023774723721934215, 0.01770193369260856, 0.09106828831136227, 0.036580094269343784, 0.046817633855555735, 0.011008892258230065, 0.04092408224408116, 0.040949836040713956, 0.05420160799154213, 0.015615263787497367, 0.00798416041236903, 0.012088265901963626, 0.029271552871380533, 0.013987303911043065, 0.039258370375526805, 0.0185808451912765, 0.03599533618294767, 0.025002410701875175, 0.04949861731646316, 0.05433138120653374, 0.029114682360419204, 0.07046084731285061, 0.060242707042821815, 0.04219378411237683, 0.016305581566744616, 0.04586183246491211, 0.049295809984739335, 0.040857456890600066, 0.06244046839752367, 0.01291091666956033, 0.006756651123786079, 0.04110792452203376, 0.028143457868801694, 0.12658779163445744, 0.052040646983576674, 0.025289422533075725, 0.03468187219862427, 0.037904781222875626, 0.0668203712307981, 0.06312807542937142, 0.04138567265389221, 0.10559308355940239, 0.06701934483966657, 0.03655389942494886, 0.018851171846368482, 0.06744697117911917, 0.03683452115261129, 0.03692011495253869, 0.01715445432013699, 0.022899021693904485, 0.016926330846867392, 0.027705220937994973, 0.03819023411987083, 0.07277269076023783, 0.03701279265806079, 0.024767318673964058, 0.14071475501571382, 0.1596428014870201, 0.19593394840402262, 0.07142609730362892, 0.12292518174009663, 0.1644202579877206, 0.16240709887019225, 0.261301012975829, 0.1378249829368932, 0.11111383446093116, 0.23782465127961977, 0.0988937309011817, 0.06682473421096802, 0.16912036149629525, 0.13916137122682162, 0.0768618956208229, 0.05722729063459805, 0.1629760776247297, 0.11284398340753146, 0.10175838361361197, 0.11573447473347187, 0.20932904391416482, 0.1117094728563513, 0.19757084628301008, 0.30928380680935724, 0.1126413457095623, 0.11150477241192545, 0.08000180963426828, 0.054887301554637294, 0.13882925547659397, 0.13134041375347547, 0.21387094019779138, 0.10613373347691127, 0.17492955763425144, 0.14246757381728717, 0.14358164689370564, 0.10253673113350358, 0.12454536051622458, 0.1346456663949149, 0.20526318065822124, 0.13083562441170216, 0.15592649233128342, 0.11421378276177815, 0.07291996000068528, 0.12124842671411377, 0.14183276359524044, 0.1929758478488241, 0.08525446456457887, 0.09587296763701098, 0.10178743848311049, 0.1751566497342927, 0.13908097839781217, 0.102863744300391, 0.09465017289455448, 0.17160666308232717, 0.13096971650208744, 0.09952132151062999, 0.12240756808647088, 0.19302998137261185, 0.12413572892546654, 0.13190872754369462, 0.1713696236589125, 0.11420615602816854, 0.10317297984978982, 0.1243417321571282, 0.13940550812653132, 0.11914950077022825, 0.16565839440694877, 0.13213121917630943, 0.1175455796931471, 0.0984192652893918, 0.161598963662982, 0.1162270504449095, 0.17390708678535052, 0.13316697574087552, 0.16293470055929252, 0.11908749624022416, 0.11301105908517327, 0.06129305211028882, 0.1788231815610613, 0.08073018983538661, 0.1331031120249203, 0.21712887180703028, 0.12351881845721177, 0.12236055918037891, 0.14801843810294354, 0.1819578776402133, 0.22499605108584675, 0.09686359483748674, 0.1624867588813816, 0.2195443750492164, 0.1091606103416, 0.1494996529072523, 0.11656524586890425, 0.12623344707701886, 0.16035037780446665, 0.13007038618837083, 0.10295302593814475, 0.20882322319916316, 0.16240503612373555, 0.12291300882186208, 0.12140002500798021, 0.1164694367242711, 0.14765542186796665, 0.1319742604557957, 0.1853576230683497, 0.19537064220224107, 0.16373614541121892, 0.09809576014855079, 0.22788794019392558, 0.11821323101009641, 0.12246620708278247, 0.09468832691865307, 0.12891341612807342, 0.15890458252813133, 0.19655874344919408, 0.13363304787448474, 0.08281718034829412, 0.12287863423781735, 0.14126195279615267, 0.14464869749333176, 0.11325807975871222, 0.1571319369333131, 0.1272150022642953, 0.12565785939139978, 0.1891302913427353, 0.10264059448880808, 0.1744922146733318, 0.10561760581497635, 0.10204408756856408, 0.2503183808709894, 0.10192025492766074, 0.17127837426960468, 0.12162392799343381, 0.08955681763057198, 0.11612573159592492, 0.11066723628235714, 0.075547030461686, 0.07129029530499663, 0.13493439661605017, 0.11035975813865662, 0.17162829477872166, 0.11100378965160676, 0.13746664859354496, 0.06901511310466699, 0.12900842460138456, 0.1398958989552089, 0.1425692590751818, 0.18236799777618476, 0.12840051150747708, 0.278929135629109, 0.08740072511136532, 0.11119806101279599, 0.1511805469968489, 0.16013499721884727, 0.1448228367205177, 0.19905858859419823, 0.14858854322561196, 0.14957554026373795, 0.15125525370240211, 0.1732623428106308, 0.1720247763608183, 0.1893172413110733, 0.07371894177049398, 0.13525817995624884, 0.163683681083577, 0.09390651887016636, 0.1260453164577484, 0.14888675936630794, 0.13971738996250288, 0.11087169245417629, 0.126430371510131, 0.1436400009053094, 0.20688895056290285, 0.16187839795436176, 0.16132000434611524], [0.07410417324198143, 0.05139660868527634, 0.02823523821176163, 0.027731531133343066, 0.0465284829427089, 0.04696798025231276, 0.050111721203263314, 0.03279666782223752, 0.007258954058800424, 0.053161518980882, 0.019461797384013022, 0.053936880946691544, 0.04923614640054958, 0.004653432173654437, 0.033762660808861256, 0.030434144594307457, 0.01518927950278989, 0.026871828961053064, 0.024730455562738434, 0.02317922272985535, 0.04713230786312904, 0.07469717213617903, 0.06446962737079177, 0.032889969779976776, 0.04085239841203604, 0.020022246953366057, 0.02622960744026516, 0.020504262963575975, 0.02151151936102126, 0.024629655793043118, 0.04952323456693973, 0.027997995227841393, 0.01266470006001847, 0.04502570090283241, 0.014492013524951679, 0.03371678166357534, 0.031030305461691957, 0.01746469410136342, 0.050656282875154696, 0.007089624796727938, 0.04582833319104143, 0.09184132290205785, 0.10328601699854646, 0.025019525051383034, 0.026037537925211445, 0.021881936716714075, 0.037525317299046686, 0.07936339639127254, 0.03586484711351139, 0.02830949708420251, 0.0026954455866611427, 0.03223352786153555, 0.02269789543268936, 0.06243994592555931, 0.07003771287522145, 0.040912923735699484, 0.03977289669481771, 0.0626636521358575, 0.06397386933011667, 0.041253008879721165, 0.051996942543025525, 0.04462826258635946, 0.031505117126341374, 0.03914950282445975, 0.0254047751825835, 0.031100825606180087, 0.06976804270276002, 0.050449845381081104, 0.01917303153978927, 0.02423378319612571, 0.06376171178583588, 0.03903283551335335, 0.08787164877035789, 0.011164748359338512, 0.02132379586276199, 0.036698532556848865, 0.04227121852870498, 0.03921248105221561, 0.05164542408393962, 0.041343294749302525, 0.056064122156905274, 0.025579290996704782, 0.0223638475539961, 0.020946601638570428, 0.02179025815400694, 0.0055904695265261185, 0.013563978635439915, 0.05821244205747332, 0.02915937067674739, 0.02772163300375853, 0.07835466587649924, 0.0609754298680595, 0.05739526876381465, 0.018072361226326654, 0.0520427911542356, 0.03395845548116735, 0.030282597190567424, 0.014286824535312397, 0.028051892960710183, 0.04123549249821475, 0.07446744732026543, 0.02342251654980438, 0.041804976761341095, 0.04319447398717914, 0.03756018042830484, 0.045250217962477884, 0.040623165534010956, 0.04979330846773727, 0.08447847156120197, 0.026648935296439698, 0.0390506300942174, 0.01444276884597327, 0.01591375982388854, 0.07455568401409046, 0.01671934373942869, 0.03234435977148158, 0.05827039573341608, 0.015472839287083064, 0.054686967483056445, 0.0379286927969328, 0.02533770878134029, 0.013069501329612519, 0.056940833505775244, 0.022538599159036363, 0.09569095061825854, 0.012990305266742195, 0.02215213784282761, 0.05814015093658652, 0.009979641996324062, 0.0264123521878251, 0.005973080156504044, 0.049385122156568935, 0.015115280169993639, 0.096175078568714, 0.04825734606544886, 0.03080565608771784, 0.01772178932359176, 0.03767498176810997, 0.050219784690333266, 0.025711305073595474, 0.010122942655081195, 0.040095981143947156, 0.03272980498149991, 0.04225959522383554, 0.06809623419706311, 0.03478268553901996, 0.022118183950494443, 0.029715192637273243, 0.027716091068993722, 0.04412191939939346, 0.07447429373860359, 0.07047871313989162, 0.01918735371769539, 0.023383546587345854, 0.014777907469709004, 0.03896410330863936, 0.008134671353868075, 0.013897506586675133, 0.06190133161310639, 0.02796905910197113, 0.024447238438629677, 0.10777447186410427, 0.040543095009135346, 0.05744998582771846, 0.009150490015079933, 0.011464888146812362, 0.026351477418627058, 0.06376419522400413, 0.013135024063688303, 0.016020484900634204, 0.004441024419585509, 0.06686818759356226, 0.005840510953151221, 0.05314756490822349, 0.03915798790486796, 0.027062977364818965, 0.0704197348760707, 0.015114206388326628, 0.04492719118882503, 0.05048370427851166, 0.018836878506200652, 0.01798921524147902, 0.018803759211940423, 0.0361561218409666, 0.03721358813345432, 0.0519077932196004, 0.026888705823304396, 0.08975779970309564, 0.08909648590322052, 0.004154489259235561, 0.03983303186084543, 0.011064541459615742, 0.02916822216606566, 0.04047328054106661, 0.04401509763140764, 0.021383805499811257, 0.032617680462343354, 0.03243660321459174, 0.026849452572475587, 0.017315312920670425, 0.038365340259458335, 0.02990801532619766, 0.044551890077335496, 0.010806102738050478, 0.05015492692057576, 0.055664400570094585, 0.04886223967852337, 0.06120458471455744, 0.010764956374519637, 0.07327855897269078, 0.0383601358958653, 0.03700785292312503, 0.02220379641013486, 0.032176703946398835, 0.06563936067478997, 0.03656731406226754, 0.012071602778243167, 0.05605332327208348, 0.059297467049743445, 0.009699702196355377, 0.06425273365208081, 0.036891592733029804, 0.006430779167983148, 0.03146702417039445, 0.025200631136872938, 0.04410714769203748, 0.0524966293014586, 0.022099671818848168, 0.04572547746023961, 0.045465713899050436, 0.03175275187407221, 0.02396506636536547, 0.0342840980073171, 0.042357090527990034, 0.026532118707629185, 0.029389061565910066, 0.017827874881082346, 0.01972557956885014, 0.03683159327400582, 0.012228764211093741, 0.0447319155958082, 0.01864339763830815, 0.013333713536017706, 0.02420626181576933, 0.04103413044608065, 0.01241533165531499, 0.039179667098713775, 0.06668302217232329, 0.04758820536413363, 0.02926163947475808, 0.0015128864865151367, 0.029520378448069096, 0.024201354311246957, 0.012817677476310303, 0.028368217504716346, 0.06078673606472356, 0.04658121189900807, 0.03948948618822864, 0.009340849621886653, 0.033417656285954375, 0.026089898776263, 0.021616237670449272, 0.037842335645109415, 0.009142027835228612, 0.007735447642127318, 0.0838320991024375, 0.03780225458155785, 0.02215949316242976, 0.029191573948732445, 0.024582433148420284, 0.027373678549858074, 0.008814387023448944, 0.016450201127944247, 0.027527700910078626, 0.01771910741393055, 0.02369705181834953, 0.0010290549710459474, 0.042040051825876744, 0.022201694647914598, 0.02884575518380318, 0.012767780555545219, 0.06120971443929842, 0.02728599146939814, 0.06004113464483193, 0.019220836028190594, 0.04494491113083703, 0.053870153812957663, 0.021896150329017212, 0.059616880624422004, 0.028135135636797974, 0.0510844147231962, 0.04622459764193211, 0.0246646071318537, 0.014454171626961656, 0.049031154186065705, 0.027517918131447265, 0.037226683859314234, 0.02892706064241273, 0.0186546426599047, 0.0056006611225062185, 0.08337320586932556, 0.06872782137777124, 0.06812017291252102, 0.0865105346643499, 0.05025554348581603, 0.036941431130149534, 0.051078290944652896, 0.04087824381089636, 0.043694781605154276, 0.07630633828895432, 0.01040799606458417, 0.01652391717237021, 0.01789120933972299, 0.03464994373332177, 0.02520745719916054, 0.027190959247361337, 0.02468547547635223, 0.03567482677421399, 0.007851241339397217, 0.061159943895680566, 0.04596324970147439, 0.03533856856769749, 0.06640091445297003, 0.025642774733049527, 0.04202227760106325, 0.016104010865092278, 0.014321027789264917, 0.10753420939935104, 0.047645880840718746, 0.007622647132458431, 0.12225807325116225, 0.07529664425445454, 0.009332292447132724, 0.022118005835052048, 0.04171963741204568, 0.0092195725134973, 0.02414314279199711, 0.09184436952429158, 0.04142570961266756, 0.06545379491789, 0.02385739642860634, 0.08690016304275819, 0.02667338800217424, 0.0727650233145271, 0.023190398201612488, 0.030744913632848432, 0.023620757340852703, 0.026244007649698427, 0.013349199401480811, 0.054212973453104496, 0.029056786359953027, 0.0345547452702054, 0.1682697364262172, 0.13950636557170323, 0.12984146204377922, 0.07220848210688148, 0.12319731499467577, 0.09143192879855633, 0.17848624821220124, 0.12759035426591123, 0.07323313105319228, 0.12024446630052157, 0.1003100099042058, 0.17380407159881933, 0.185734698548913, 0.12111596310777323, 0.10952111599700791, 0.13244970994336264, 0.07745437882840633, 0.09510597200798136, 0.08774179752383914, 0.09734000784478017, 0.14054444272603306, 0.14096901565790176, 0.1281161510518619, 0.1377564373293093, 0.13495678827166557, 0.11046361470861094, 0.09220003043966633, 0.0716594997793436, 0.10459024951394115, 0.19375582385276044, 0.14818537128823145, 0.13144308967249735, 0.10480482264288835, 0.1809062569269112, 0.11672398235116686, 0.08985409060759203, 0.09558967926672526, 0.0672374599214111, 0.1860169962580715, 0.11727507492261273, 0.15769126691988536, 0.17342021076806954, 0.1725045141897031, 0.10355906627540078, 0.0951950161584786, 0.15295872943741934, 0.15031198146087782, 0.13279882978115762, 0.18809471119727406, 0.08543492095278842, 0.14016629516014031, 0.06177015722330127, 0.07716302267674889, 0.08051334361412696, 0.1499003278357642, 0.11629014063094344, 0.12278994971088, 0.22337945497461728, 0.130749857585345, 0.1437045160148825, 0.1433734316378832, 0.10584058599280459, 0.10383472791207687, 0.09758594964763947, 0.17813240577067646, 0.08295925201049872, 0.13128754230482237, 0.12034879784498896, 0.28217874839901924, 0.10756883504135267, 0.1335011270961591, 0.16086074470409326, 0.17565886064299516, 0.11334261843668562, 0.09049003398311989, 0.10926852455096585, 0.095351452407028, 0.1203867279525314, 0.1799854984773057, 0.12780321070126124, 0.12129523205970015, 0.1401032049741064, 0.1326128297618457, 0.1047492166981101, 0.0785662941634655, 0.057036730859960826, 0.13730073321078504, 0.0776212238041418, 0.15702909816588673, 0.12280677737934248, 0.16143847656037125, 0.10046235458659274, 0.10500805745167391, 0.08587113754557711, 0.14122855530253478, 0.08113746690962996, 0.16761363377528532, 0.17878561786242894, 0.10377656389027834, 0.07424265545393739, 0.13701953472835676, 0.11457188640322004, 0.17441232396023615, 0.10510473512113094, 0.10855974044118609, 0.14640949586672442, 0.11730418407491275, 0.15737930365971156, 0.1497972583664315, 0.12015540179397378, 0.1375161273671048, 0.09980600087770394, 0.13321456818708352, 0.11799888179770537, 0.08472716143088681, 0.11823735971535955, 0.2643277948456151, 0.13468082807958126, 0.15051806611674173, 0.1129295127466321, 0.08428870567253657, 0.12845809198915958, 0.1716379706880876, 0.07524597125926188, 0.16542379770960125, 0.14683645724185876, 0.11749600592468466, 0.13422642674829277, 0.08208842016756535, 0.14293273671397141, 0.11941103530781609, 0.14367463333266123, 0.07746237197092601, 0.195125691060509, 0.2776264026761055, 0.07713292286332164, 0.13014222947614534, 0.16116915244076932, 0.17044563538261823, 0.06949989923409053, 0.08718118510608162, 0.11190286890736648, 0.08960458649588482, 0.21736920891063555, 0.12947969431323664, 0.15190651161330088, 0.13850389793515205, 0.1057566919230989, 0.1406840445207698, 0.1648470429437501, 0.2056220578295844, 0.13584105510796818, 0.1692168763173478, 0.06403650489768811, 0.17468722563769135, 0.1707521839333432, 0.14048938639461994, 0.08172706634338413, 0.15117457588868483, 0.0809010856651834, 0.14090034791401454, 0.21515599052820886, 0.14963890186377934, 0.13208494308803762, 0.13220201752015523, 0.17714834000383103, 0.14828616087990149, 0.17787419605468, 0.08830955491534301, 0.1487583126872778, 0.072264753015978, 0.15779991394707135, 0.09888256900012493, 0.14945928007364273, 0.06968348366873604, 0.14850767542208942], [0.01567507834572877, 0.02057211985811591, 0.031258408578911, 0.04208022788433092, 0.0255627398312624, 0.05908138757305486, 0.023659539009843553, 0.013617824630013533, 0.027047530515119433, 0.03899646942902889, 0.05068553112713354, 0.018944558620985066, 0.03826586363304939, 0.04610208814431514, 0.06308082225067274, 0.023581331063594137, 0.04157073290220328, 0.01792797406337091, 0.05247195437550545, 0.02459821248027895, 0.023949197127616832, 0.0588509842221226, 0.023228771053254604, 0.02252082323788532, 0.027520398176940422, 0.0498532332879092, 0.016777026001363993, 0.020998989631022726, 0.03726964869669505, 0.06484245522213833, 0.02198983226636691, 0.04076448402234486, 0.048062681153948815, 0.04304821237123438, 0.07918754047048943, 0.03608750159453068, 0.019629680518327013, 0.03626645163499883, 0.028979660677058355, 0.036469364139650545, 0.03884155649159636, 0.07612955277519566, 0.03319066935884101, 0.03834731158401285, 0.03500281586976988, 0.03418354590290359, 0.04495556413062981, 0.01992369313458247, 0.04218360947977219, 0.014885960778753673, 0.07316511470292296, 0.026126760191151073, 0.07601288546408926, 0.03537632904148527, 0.013771232916042209, 0.026548138919419477, 0.011094786309903222, 0.03013910060482366, 0.050810883686478646, 0.06866566078471285, 0.041667251115930934, 0.030707305829439844, 0.041223543496536355, 0.07914534916302987, 0.05458885131935988, 0.09905239274459225, 0.026096721445875506, 0.052487547110233984, 0.0032187705967641833, 0.05464213667437434, 0.039337911643087864, 0.11684438160487584, 0.0461917701177299, 0.039352656209043095, 0.054275208685014925, 0.023375256585755518, 0.038385587744414806, 0.01624546166775482, 0.05606518406420946, 0.0338537066376635, 0.03576311435816543, 0.010180996414939207, 0.029137362393417528, 0.01690128951200417, 0.04412777854927948, 0.03725316368841699, 0.03502924480874624, 0.06767647886382681, 0.06411742019866194, 0.05771418022257941, 0.006903861840588174, 0.026348717477438704, 0.003277753313471164, 0.024065966218976036, 0.03247419066194977, 0.021907101884218197, 0.021285097314310924, 0.03973583171942404, 0.029855113343468735, 0.04430364464808788, 0.06599762037928615, 0.028087020718625615, 0.03463110760120409, 0.001692785945903909, 0.021049201222402707, 0.05826684020991836, 0.021220215795827762, 0.1024093497544527, 0.050672801810183694, 0.048328426001327376, 0.011467871156388094, 0.029744759800710847, 0.02341588556633464, 0.04496963694691658, 0.01820368828651096, 0.021565683418884873, 0.025918887595513036, 0.027909366680043082, 0.08581443915941886, 0.0385618032887578, 0.02080133746910308, 0.009906337313753153, 0.021694240359855548, 0.07860009877809457, 0.05973016204578536, 0.0498433402473373, 0.04164090360115681, 0.03568321346704449, 0.019450330142197863, 0.01503382034466735, 0.014527904634763087, 0.0459686169134719, 0.05157468680824552, 0.03540805394628218, 0.021867653554571525, 0.017099721989195262, 0.08011362541999136, 0.04947560140863061, 0.002320385567145422, 0.05772489429052387, 0.04650122619100979, 0.053798171425504346, 0.04714380903169513, 0.05937331369412797, 0.06341824414474623, 0.01424411584490112, 0.04283287589039121, 0.12293381270553384, 0.015917958259316425, 0.02879083455939378, 0.03982242296582886, 0.062451324957822046, 0.04969426949641534, 0.014186907709310097, 0.053725992262895615, 0.10249830569539752, 0.028399157005229166, 0.05016780212255461, 0.046622500754892826, 0.02026375792255359, 0.0092776330587055, 0.030714365986308882, 0.049605198204517365, 0.018187820745099868, 0.021358725149184465, 0.06783885907913957, 0.033915161554302485, 0.03492219912420426, 0.07512227432536227, 0.04306440900212952, 0.023199113983927027, 0.059825360508901734, 0.04494406635473881, 0.02871797007641622, 0.04694433669958796, 0.01969147300613778, 0.02651327070114868, 0.010946305036278707, 0.019453137580837523, 0.033295326600117345, 0.028875101823359728, 0.04417233794395413, 0.015123027343569058, 0.024140749259718826, 0.028457227728462646, 0.04644287217940603, 0.03866334944697363, 0.02858683979138732, 0.03386047841714961, 0.03772867763681071, 0.012204371725342103, 0.015690189320594072, 0.02265578894210713, 0.03062884003988334, 0.054013362021318505, 0.030407783508832966, 0.006641250552742609, 0.04754340848220246, 0.044200894090213945, 0.0416155569255352, 0.026378106525433914, 0.015327234153768845, 0.03196855654407825, 0.00334905313710416, 0.036282420956662724, 0.020589885601241673, 0.03999884546335254, 0.02257178969947355, 0.03305733044232641, 0.07814569744680609, 0.03955562638917139, 0.03283985996884959, 0.018974714413551346, 0.003260240324639848, 0.05128570892182844, 0.03249672480991908, 0.025768536109743372, 0.01626826892606914, 0.08245079857962472, 0.023026633774861693, 0.06940389331430197, 0.010084043090630854, 0.04202478139528206, 0.02231902183432664, 0.17921950029475348, 0.01760526789751436, 0.039160549374563355, 0.020824785943010023, 0.031010600804750408, 0.03779881101633821, 0.035820830546851666, 0.07059622183442116, 0.024405028471457105, 0.033281671082867045, 0.028249594316418682, 0.0880764170682856, 0.009632391522505453, 0.05239717981645039, 0.024061469228139946, 0.058291864581406116, 0.03628170170954295, 0.045731099122869115, 0.04811705555766821, 0.028386108776820556, 0.027616414274754267, 0.02993669021608574, 0.058941371871956756, 0.037658981912370236, 0.038513203218047104, 0.038973416201770306, 0.010992143469463502, 0.04315492218094213, 0.020235615682655146, 0.03128028454791222, 0.07551589927503041, 0.06389856551374708, 0.02908603461193187, 0.016257498878985643, 0.004302968412438142, 0.0357317524696035, 0.010681637363242251, 0.024712511704170277, 0.03331645278792296, 0.06966062382395778, 0.04894362995401025, 0.03830686750422631, 0.013948266943251448, 0.005395211320969143, 0.024099295859092047, 0.03577177585767848, 0.022022615685792904, 0.03531287923189146, 0.032289730917130194, 0.02503761988399284, 0.008974842743815055, 0.047532473890376944, 0.0233173554962767, 0.017369626256238137, 0.006037955737805792, 0.04254559773419585, 0.01639418297314218, 0.03222449316776224, 0.08187820323343788, 0.024677772407553027, 0.04138933674299291, 0.05413844655933125, 0.06990704738668033, 0.033485167127634795, 0.028679056093096733, 0.03047189489006996, 0.014899506034063441, 0.04763745004311204, 0.04254558416349547, 0.012618371385282703, 0.04511716742334621, 0.010029051220044494, 0.06918992408152137, 0.031569795084318945, 0.023791366489604115, 0.06097885646990367, 0.017329735182491795, 0.028520499422614063, 0.05123525984319193, 0.03878253412299922, 0.018464880163914392, 0.05309102258511952, 0.03142805929694857, 0.04767534961657865, 0.04129282870729055, 0.05756457682166781, 0.01051025468456958, 0.03073866432532668, 0.10324209542678935, 0.042146798955010514, 0.026567578947703754, 0.01668759508590613, 0.048678611139101644, 0.02765155051435743, 0.016413261681529026, 0.011009233222076935, 0.02593676360057933, 0.028086131837751185, 0.055522389976041656, 0.05529521645179816, 0.06597079788999897, 0.03127446611012731, 0.049819924003843746, 0.03992294792884162, 0.05232744677258389, 0.03150913405365177, 0.05781691720975297, 0.02816033473105303, 0.07099067459681205, 0.048431468329259326, 0.0009605553766180362, 0.027167634606095295, 0.009346731672329562, 0.017697884534884776, 0.04820126514615757, 0.020565073271947246, 0.027582277177966068, 0.05551386418353234, 0.0418340418088649, 0.0224487679079175, 0.04525254873026695, 0.040121368531669886, 0.04511885019019246, 0.010385974210553935, 0.052723884249904325, 0.008571497780004782, 0.05808784267199891, 0.05236751765811017, 0.14895677060953208, 0.11488144764942781, 0.10146085957863502, 0.18672059636030877, 0.09477971880031483, 0.1633781096232789, 0.1620496873344694, 0.09977835057569401, 0.11371072368430239, 0.13058903121522494, 0.07384029097322907, 0.10732312394039971, 0.11786325621817793, 0.11473098929439272, 0.0927931514701673, 0.1106052521084036, 0.18879987193005426, 0.1619556966636862, 0.11025135538407735, 0.09638912244034664, 0.14771731783236774, 0.16151861154607364, 0.10995647085032292, 0.15886802306132658, 0.13258609548211098, 0.2261225413531065, 0.16596864775887557, 0.08756172790059022, 0.1255509765552623, 0.2507458579327379, 0.0992212597546833, 0.10078592758093562, 0.12789566788290227, 0.1218612931136574, 0.17522842516856535, 0.13609049815152371, 0.0920024546129363, 0.08642406216157333, 0.1800168060830661, 0.13554011125649723, 0.09255464641111237, 0.14549050160816737, 0.1368588169238397, 0.10313990126763072, 0.08743988336729151, 0.07406270796699183, 0.19144990401608603, 0.07560075007911239, 0.31049168056675364, 0.06681300912584577, 0.19008471869996615, 0.1429593895695039, 0.1903243094150509, 0.07017677184194326, 0.1088236498513392, 0.16286637208291463, 0.18827449583581515, 0.08601484447717667, 0.0932971333552684, 0.17594434746674129, 0.09509738175464527, 0.10415121021547488, 0.10560655926487275, 0.16441062279045582, 0.13968110190970556, 0.3239938760442393, 0.10855045129678079, 0.1712021476456097, 0.14059118021811756, 0.13657343866569654, 0.13820509825434002, 0.2326822243630886, 0.09545962445970092, 0.14832913928798266, 0.1438286200697933, 0.14991027515913757, 0.1423074666942869, 0.152860803263528, 0.13346635896180356, 0.13517888635396957, 0.0929798503805484, 0.08223811856337956, 0.11170752546084778, 0.0979695865618331, 0.09694358054548502, 0.0888946760179741, 0.1098234983427184, 0.200269095067467, 0.14179868756660394, 0.13064802304974624, 0.07725860790482589, 0.18195908543254646, 0.12131362035870552, 0.10136851096259696, 0.13654195464083127, 0.12188965587743691, 0.08072802530867712, 0.10408776719123125, 0.05370646741773401, 0.18503625531281742, 0.2501895677830492, 0.0743589699268341, 0.057296019446636946, 0.10360888431646995, 0.13545555222247327, 0.1312353086790868, 0.13354209704058512, 0.17752807534166745, 0.15154743088143213, 0.18161012844315597, 0.11094670450048787, 0.1550815398139613, 0.1206222338868039, 0.12917953756238731, 0.07211949902453593, 0.13293691165745258, 0.07256161887198687, 0.15500671097210475, 0.12404674584312098, 0.1573405728808471, 0.1270320149404662, 0.08410776073911361, 0.10476014789726053, 0.1357789962951626, 0.17164411821535655, 0.15441418705242022, 0.09018990437367133, 0.10815048883003847, 0.1984102348131793, 0.13709360361099243, 0.12429380044341087, 0.16153883188962936, 0.14604276125984533, 0.126413014584354, 0.10922450119895594, 0.08420871317918811, 0.20537025348416396, 0.11868477213595595, 0.09688257346195833, 0.14626141238425458, 0.08008816000074148, 0.11016068953488554, 0.09712888167372771, 0.14004627588604177, 0.08664108480193786, 0.11231258870767695, 0.14653929961579187, 0.25411806840981754, 0.2543574555643967, 0.08947263857615845, 0.10180903625275407, 0.20246366730758122, 0.0969701451914651, 0.0829632825085095, 0.11201745311596564, 0.15498673490115575, 0.11249597636716706, 0.19132050738802978, 0.1709702650883368, 0.11476701950388295, 0.09871026181748935, 0.11747687123715878, 0.10681369341909885, 0.10777346763227667, 0.10564121883362532, 0.1990437422479902, 0.11306348270071404, 0.11432168340044362, 0.17183995699243887, 0.1729539350739547, 0.08003762271255255, 0.1570103027458702, 0.14780141546257905, 0.12247527231063161, 0.2257871279226882, 0.09662251813071114], [0.0020580435728853835, 0.06617460266820022, 0.0164778124141906, 0.007348671655303666, 0.015492722059467008, 0.025509517240737165, 0.02207915631255933, 0.028104881456653987, 0.021776037756353617, 0.04326354545940246, 0.01667453837580979, 0.012420910061337054, 0.020023795709546124, 0.03535527070718152, 0.01019815232471696, 0.041722005499260764, 0.013895460803593909, 0.04466271859460643, 0.013057481081757163, 0.051444397906639745, 0.05465715604701212, 0.029928971880248616, 0.10911032411136798, 0.0353578423549022, 0.00868942801441465, 0.029495968150773218, 0.027979744332177297, 0.02363588019008083, 0.051838433369994164, 0.02285313915594348, 0.026856796017714908, 0.050668143667280674, 0.039429340844175646, 0.016746379967246736, 0.02882643389914717, 0.0403663027100265, 0.05485573610556977, 0.08788961637765169, 0.05404474426593099, 0.04453516418912581, 0.039345155004411936, 0.07371355420244591, 0.06465823296457529, 0.04322503859709416, 0.10127699694463185, 0.01409816465872739, 0.027147690765559673, 0.026945867309612886, 0.013957964056836707, 0.0509201481805316, 0.08546086813190154, 0.02228103405130761, 0.008669844645607685, 0.06216410108442817, 0.04666937056130596, 0.030083918744432073, 0.0238657491946859, 0.022842837298022847, 0.02032234433240124, 0.022068118244143467, 0.01860115713705974, 0.013463484206502991, 0.008237968980600792, 0.02096734445409051, 0.0313466147386602, 0.049993265952382765, 0.007458087971567043, 0.020477367531774298, 0.010443095832930079, 0.021666791922013675, 0.011759045799928052, 0.0450160657055676, 0.03995728858613542, 0.028606795506285768, 0.03678595840132662, 0.06532692244010312, 0.09947574431342737, 0.02324912031846387, 0.03894506700869117, 0.01364583964459598, 0.021901705834482397, 0.07057053249861513, 0.006776044502787824, 0.06098385727299111, 0.03898425579869321, 0.0559539111065013, 0.0139721250826759, 0.07784584603671517, 0.025930309036214436, 0.0705551840364933, 0.019513177751962627, 0.05492706370673009, 0.024616042684231485, 0.051396561187825034, 0.021961542445101907, 0.056749700369047265, 0.04344298743775912, 0.02717025375126728, 0.03945114217432482, 0.04568269921998892, 0.05414937097313149, 0.044320268756044764, 0.03623266737642033, 0.0494324805081955, 0.06269949235554252, 0.011684540110374135, 0.031729705432163816, 0.04647809832489916, 0.04698745081467288, 0.046631718653121164, 0.013370271306484938, 0.028708725036787133, 0.009578161307477524, 0.01542204076291195, 0.023341682673032795, 0.019539725434567248, 0.022933425115687505, 0.009917665455889488, 0.03195675682010395, 0.03061011925871883, 0.03957676954035248, 0.013700913787553353, 0.033478249463119676, 0.04850651430232184, 0.04267742351761886, 0.020619093141119395, 0.04228363911222134, 0.024430112214758992, 0.0749555854126811, 0.029167753976902792, 0.03601634701980012, 0.06388545621718679, 0.045018715384815416, 0.03410619291077767, 0.005054343741254083, 0.012798224725494427, 0.021585961437917182, 0.052462878969631026, 0.03000397714121001, 0.05084432528487273, 0.015704443644998328, 0.026007553462737372, 0.021227542277691618, 0.029733370590422834, 0.009310397818418486, 0.014137871679849923, 0.026639800518751144, 0.04297979907797916, 0.0015059964935062453, 0.0389932497803654, 0.04236881561311228, 0.01863247831352055, 0.017553166586107442, 0.03545411290334804, 0.04119528590568474, 0.04526939336210489, 0.05592179943674377, 0.050126842356153896, 0.015199221737150635, 0.013133701768570712, 0.04129191268501537, 0.018088717312951173, 0.03189331040318523, 0.03751026399965797, 0.049452996014484336, 0.013269692908839455, 0.042801042419991324, 0.037654490010546784, 0.05540332404364433, 0.024727078154683113, 0.02157046878710389, 0.04915783328137227, 0.011182131578347512, 0.03623204312420317, 0.05043613897370441, 0.04965080932847091, 0.04816865475316133, 0.05596021469682455, 0.01030190456991217, 0.024660171209169284, 0.009694026250924383, 0.052972475732011456, 0.025871658165540014, 0.01960590634761112, 0.020920742669009736, 0.018861010604138886, 0.03443530275087271, 0.06596583101366248, 0.03842866114739861, 0.02674977747457368, 0.025562753401962773, 0.05015956470742822, 0.02360831979396088, 0.009807250844979925, 0.061146529258361886, 0.05010130908340216, 0.04513296711125544, 0.03301176681582417, 0.027517785817118626, 0.04099863288658006, 0.02054197763625, 0.016689398292718188, 0.04053605181564178, 0.012084293927598213, 0.004051917240888412, 0.0017170685937994026, 0.004022936586157552, 0.03442261753869908, 0.042686794086226394, 0.035014232221458635, 0.07478266754852873, 0.044501464747424634, 0.039700371479349475, 0.036176667881331274, 0.07430798480553286, 0.043532397997166426, 0.07760911873940911, 0.02386712153176112, 0.07378387078642845, 0.01283137031298663, 0.0531507234887353, 0.03359667078724929, 0.02399439943422164, 0.03130345991147416, 0.026331606520605937, 0.033615038730204105, 0.022449412516185215, 0.01764440579739, 0.05024751641654542, 0.02481598999085171, 0.022064057212056856, 0.04671213183818119, 0.008912594789373023, 0.017762596419613277, 0.011038020070243095, 0.05518516146444848, 0.029053882230073214, 0.015299682239336627, 0.032651712386203666, 0.09711437459502902, 0.04291998960876039, 0.02693942461961082, 0.025421305991975323, 0.04238944307767919, 0.023705443600192666, 0.06298622768372297, 0.027949434172894274, 0.02938802001465644, 0.03324894194624253, 0.04716547126216548, 0.044497393537312746, 0.060339221863874366, 0.04076897931684341, 0.03200586579207863, 0.03989761821659548, 0.020788212905504873, 0.027528776388083185, 0.03566025862736361, 0.04657195328867861, 0.05106226055483733, 0.03317354992032051, 0.04757446842268109, 0.0452593985412802, 0.01564813032746315, 0.022323359369433353, 0.041596066007124524, 0.03929693152063659, 0.03395638255668538, 0.02002209428298686, 0.03476690959983638, 0.020328473199957182, 0.06445066910237074, 0.016995431156829, 0.0615621523133346, 0.06498553111617054, 0.04624221580369132, 0.03141163196414709, 0.07892653519021613, 0.02047042272585843, 0.04077638552657195, 0.03921970745016422, 0.008863641880452633, 0.03643403960657971, 0.025628674775362015, 0.053959387953260114, 0.021052225792248334, 0.05294290517589875, 0.03996319862614785, 0.04340680795056479, 0.03525108504774315, 0.041810720560273955, 0.025769503022144948, 0.046588940412870476, 0.04395453498831817, 0.01904526848479041, 0.03580237100166934, 0.05499389601339187, 0.026277956453018954, 0.023879784691546644, 0.05464093566739133, 0.08172414185745375, 0.038734514199729474, 0.04032344983092376, 0.023620857424767952, 0.026357195772496716, 0.03302052331023982, 0.031351778390152116, 0.02844483089367194, 0.04377174783231957, 0.07277936075947114, 0.029106573866946355, 0.03282265571345176, 0.08512380586138793, 0.014635055492232953, 0.035954959956662993, 0.01662724618134754, 0.08920484116034848, 0.03935021009030087, 0.0140003512912829, 0.09105327233139958, 0.06395172194710799, 0.02496615148681615, 0.043229449074715376, 0.04397308952840311, 0.00808689315869872, 0.013776784180663526, 0.07224473623292786, 0.033670688779758554, 0.0695541820355824, 0.05816785552139793, 0.020027690500553166, 0.0085497634551887, 0.03419889097235032, 0.07310774456709623, 0.09222945850342512, 0.044245643474693806, 0.07034686021506786, 0.035711484628596475, 0.014407956606841512, 0.03862622679610338, 0.007239727769047022, 0.02625736461154052, 0.024028923295970474, 0.04359829731817756, 0.06111484845834119, 0.04850107923682247, 0.004319076833780855, 0.019554400450683067, 0.0520748213997909, 0.021716577732669454, 0.06863898757312979, 0.01484194930110659, 0.10960189559097801, 0.09985063491123063, 0.08671793567814998, 0.08131769259593316, 0.10730463386114154, 0.09986081293651036, 0.2471000621361392, 0.11630475627524511, 0.06867435960365192, 0.12724700197577477, 0.1881791345242943, 0.13340937559093746, 0.10760956749852214, 0.10176588821091823, 0.07136587053537369, 0.2142146588968379, 0.11976989890847888, 0.0871255723759532, 0.12179414528821196, 0.11904317433280603, 0.0892622112961752, 0.16078259104064532, 0.2015002697174038, 0.1442066862114838, 0.08099620270409755, 0.11315503743078027, 0.09812082523213965, 0.12523783264415606, 0.09617629993174757, 0.13712626828679017, 0.13354272129280226, 0.13224518591804163, 0.08591213463140385, 0.07522901466914586, 0.16631330283624784, 0.07697466135557209, 0.15734351772282804, 0.2378360235265323, 0.14888370595872402, 0.132185963381614, 0.1764616897063596, 0.17746755001800402, 0.15610662980803422, 0.12166909128427505, 0.20917238374905928, 0.09553738457283803, 0.13074767270258494, 0.12221689974623066, 0.16550936097545282, 0.1170032402234418, 0.19526909265135015, 0.0858315314565386, 0.10439595101135117, 0.09355007763952017, 0.07938622230929987, 0.10394308995455503, 0.09509041998535395, 0.13816750741430692, 0.11041544550763709, 0.14552661324185984, 0.05297418564025845, 0.09096328501722642, 0.16049083455332688, 0.21906021317201002, 0.1280844227543899, 0.11553506686219148, 0.14148713142744132, 0.08829557709395885, 0.08008043827222926, 0.11654776680682387, 0.063718271973942, 0.05692035531891244, 0.13620530627667904, 0.09853963061634984, 0.09266208564596516, 0.11699665843376092, 0.1343905915107046, 0.10083866332258497, 0.1672055899564709, 0.10816008331520216, 0.10236076664711748, 0.14891266583331994, 0.1502660989229168, 0.13557280307369574, 0.18679351173341274, 0.17951122964067118, 0.11296844030065195, 0.12045899193201746, 0.12501341397208826, 0.1809014936110803, 0.18472351852272237, 0.18617612629064492, 0.09219549104039158, 0.19515417596059187, 0.111804209915655, 0.17320964778108255, 0.09708921451653753, 0.18138075646545204, 0.18243952893785068, 0.1660931860761983, 0.16107852730367864, 0.19939966100667203, 0.1546196203146662, 0.08612509284700666, 0.1424408531082528, 0.08218308258801699, 0.0560778149935816, 0.16641631802277906, 0.16183765871184214, 0.12883001060358115, 0.11668132963989462, 0.14823103669498647, 0.07550578910325255, 0.1544148927288396, 0.1112243610301188, 0.06247379803763969, 0.17016075924038887, 0.10474674683064222, 0.08019804874701159, 0.10754868255129882, 0.17561376520565578, 0.08299203882259981, 0.17682146254394734, 0.10079048733626093, 0.19564254475491388, 0.12938719641949448, 0.12020964388336454, 0.08582125843635627, 0.18216754496097565, 0.13064943440258503, 0.11440616101026535, 0.11610647477209568, 0.13324858993291855, 0.15337783337703773, 0.08694223899926458, 0.17730516301734106, 0.1390458031424454, 0.19104806200734206, 0.09129993338137865, 0.11841820286852972, 0.12271623366645404, 0.09466472747070448, 0.15664886071213655, 0.16154024324246816, 0.12703078000673226, 0.08185398631862231, 0.09648502657988242, 0.11284106570695128, 0.0766730389690825, 0.17064117560429232, 0.15063628048769065, 0.11290919740817376, 0.16613399317221983, 0.11723509563931397, 0.1822322772017547, 0.16143709234893322, 0.11798301764896937, 0.2037062549165317, 0.1671574411115476, 0.07497001785252776, 0.18124822500560964, 0.14282969438603946, 0.08313592217330422, 0.15038351262254374, 0.13618511307452405, 0.10380883501576525, 0.16600235737860203, 0.17777796621833528, 0.11743892755891595, 0.1038745239909206, 0.05449612611638648, 0.12494660541415215, 0.08573030081710645, 0.12252468323068959, 0.24893520080617496, 0.11672462017408439], [0.005903945919791502, 0.09728503972291946, 0.03308018010907939, 0.0027248405718377656, 0.01367349418744977, 0.03572576100538884, 0.021143578658146516, 0.05987060522394521, 0.053893149364739656, 0.0739445003813931, 0.03484399117795484, 0.040389182910855324, 0.05281826847099832, 0.06055185438266822, 0.03191414482093283, 0.06283687534076826, 0.013714566760297333, 0.011279784641893846, 0.03545993473380804, 0.023181980974706154, 0.07720135990530252, 0.07400440823818956, 0.015634639354954873, 0.024835268867069056, 0.02655156552126365, 0.029428040010056326, 0.023586089290412407, 0.006082783577897186, 0.0508701469350074, 0.017876198448772942, 0.03615734998935035, 0.020859664339306097, 0.019056028353848627, 0.10720896042351212, 0.050189793442509005, 0.028122659074142575, 0.05332348868250847, 0.02879570304815258, 0.021521875501743386, 0.05209307399179254, 0.04240355321339198, 0.03752081521919795, 0.011413255872737085, 0.04147493054292031, 0.02478402929513582, 0.06996864479567323, 0.031628233912800036, 0.012665848480537534, 0.004808550367930106, 0.04400146586288299, 0.0345918950624764, 0.014315757268507565, 0.031058295031211207, 0.04110223839857748, 0.02939031007034438, 0.040188753844371865, 0.059018277030970366, 0.010171573259867728, 0.03712193501581039, 0.04252215434930154, 0.05895967874675989, 0.033181936613151004, 0.04447622324473091, 0.04637315949159009, 0.002641786401259846, 0.08027574100664683, 0.017249993747100234, 0.03365322668105364, 0.02680650300213269, 0.044491310470870564, 0.023801878693380525, 0.014436261695144432, 0.015849287122754113, 0.07644865422376565, 0.04325231570484383, 0.02404001564718783, 0.031579392962157726, 0.010046654962934554, 0.02475715082670961, 0.06557370562638555, 0.018397384589271884, 0.07257326931825706, 0.03443357587925025, 0.03171738323622516, 0.05080965893076999, 0.05851350125989743, 0.09116188543183462, 0.020139750558882952, 0.07981262728571892, 0.060660840677363534, 0.05559747666120529, 0.0068313849707400155, 0.04801156711099403, 0.015086376274536763, 0.03197238687425852, 0.01989573409913906, 0.0382708237240357, 0.03169288133670177, 0.07771242569599833, 0.06309222163898603, 0.0076410540911768165, 0.09157221591366188, 0.043380490969866514, 0.02939841177846704, 0.00901309261098504, 0.0418827368744782, 0.02058053369234715, 0.026098796066695025, 0.0964451219354357, 0.0493745980784297, 0.04662867881623762, 0.038061980823321004, 0.028185398118304353, 0.0536370906047523, 0.0588808058361922, 0.0304448145574757, 0.047089533015553436, 0.06215199601969548, 0.004440111789985427, 0.13417314817862852, 0.008053054617318724, 0.05538970245314496, 0.014134881884924002, 0.042266190584216795, 0.022052220168656538, 0.03441088906090174, 0.030302196674581085, 0.02671681254703019, 0.03967735217884183, 0.0389952548513455, 0.03240451868623495, 0.038195312954485416, 0.01493399596906134, 0.04197838995605707, 0.022375252031322037, 0.0441403687665505, 0.027652568316885402, 0.05501467275566288, 0.02000523777678609, 0.037493680603802204, 0.02284108498133719, 0.014953458049733723, 0.02422487742400595, 0.021001729216160517, 0.02127784038228648, 0.08203538587050778, 0.034718072041869164, 0.019369496265426278, 0.007280660394046987, 0.055363280299518786, 0.05235727856467877, 0.020320871911410774, 0.03982414644477623, 0.0305748931132257, 0.02268188200624926, 0.03608505208311336, 0.044357360872839174, 0.028668925565268313, 0.00913753338889884, 0.012018011234301542, 0.04587829711713961, 0.016827358032709787, 0.02907313566122736, 0.01625885934169803, 0.03287192753383091, 0.037783201318234205, 0.019842363927247267, 0.033206224774143527, 0.01280496342639838, 0.05459946360705154, 0.02389759793212371, 0.023557137897504226, 0.002614296615190272, 0.027531597397423217, 0.030238349922001362, 0.025501982109355073, 0.046770401032907624, 0.0172238311331187, 0.058018299617937634, 0.03821453245888863, 0.0020708988428980645, 0.032054394616612365, 0.03193940667967711, 0.041880110943956037, 0.06260500635419573, 0.020017068034836223, 0.024161634567592825, 0.030259720382413695, 0.04452847722651703, 0.030653983154999356, 0.04893183362271104, 0.0543685004647289, 0.02307892677241138, 0.03106156557000109, 0.0271305577563388, 0.013441773630412561, 0.042071766552648375, 0.0708513849281839, 0.03373316149892552, 0.050000231114349196, 0.04209150852901595, 0.03609831065737775, 0.03957940225622483, 0.036431240649627786, 0.03576091251202992, 0.021245808440393636, 0.009378856912787472, 0.01112134417053312, 0.017588754051498005, 0.024992325975160514, 0.03910498074921114, 0.060214181430637836, 0.03907436864184482, 0.03481370476739747, 0.015416471686746393, 0.021620851708576083, 0.016769019288143942, 0.09404567283179079, 0.04491972730361989, 0.06273834527071033, 0.028981418082756654, 0.03251766440059457, 0.04757598155577268, 0.03360713379723685, 0.014511916653386183, 0.02729722292029432, 0.02198790692325149, 0.04263260288696204, 0.020451813902972, 0.03556992865300604, 0.006053833457242165, 0.042477924044110944, 0.07116771795387779, 0.019739911924781542, 0.02715008769051305, 0.01739801955409348, 0.06083280859248979, 0.03558028649006571, 0.05242248238729579, 0.06715886521020106, 0.06351644173264503, 0.029800528593893563, 0.02381324245860534, 0.02062706253491342, 0.040563077865434546, 0.05038175778463483, 0.05250133154913783, 0.04426355001383594, 0.03809354627238853, 0.04339050275406667, 0.0084957452823541, 0.011493144889495202, 0.053270742762833834, 0.11906084338469164, 0.03436334750482014, 0.03286106079550726, 0.04757725041625755, 0.04784145498914378, 0.02343509828538767, 0.02719216195068189, 0.028547729032912424, 0.08381409756839275, 0.04020251453455005, 0.030120993897851025, 0.05956554266491106, 0.0728085513359734, 0.013097269527081932, 0.09101258058633123, 0.0057142050521049115, 0.04343711471717272, 0.07872535634253706, 0.030818198807537556, 0.036033703945577145, 0.02206279513692217, 0.027405276229338985, 0.09028797303991658, 0.018824654697839702, 0.04041548632085323, 0.05613944632932544, 0.04967148429048913, 0.023072938700871806, 0.058005278530929766, 0.053022609291864295, 0.039665165689906905, 0.09226695434855563, 0.028751771298370192, 0.03322250622191599, 0.08741154095956258, 0.03664543040628944, 0.04687446455604263, 0.07048650950725589, 0.0624529059444155, 0.07623893262020179, 0.0230383283259081, 0.02906475236107196, 0.045297159015067985, 0.019445208899144615, 0.08270631451159716, 0.07873769210917608, 0.05156117378334914, 0.008432062226347625, 0.04878934466146997, 0.028075762126328688, 0.02627651117342923, 0.05730826021837337, 0.020180703539933478, 0.03342540854854243, 0.040432514157146215, 0.007012399029918015, 0.013374043961188622, 0.02524068845169885, 0.03301386348903179, 0.08309795135366065, 0.05442495118560536, 0.07387904889349427, 0.013502266723662615, 0.01861140301584133, 0.02312205276185913, 0.04131703883675592, 0.06152263443384852, 0.017949693969317844, 0.037105609463261705, 0.02222907353591706, 0.013826547938931202, 0.037492991890758276, 0.03919482896370547, 0.004152485884593001, 0.01587551080488733, 0.03828762425109744, 0.010416213123660003, 0.016044389689341187, 0.023987877016354884, 0.011503121050606881, 0.04987244261428714, 0.017388223204761744, 0.05790152374122824, 0.021192356844299605, 0.03280890520129885, 0.08783008171511547, 0.07341703439929656, 0.051517055436436615, 0.028349398335974132, 0.05282539648136922, 0.014863670903391071, 0.02061076582010303, 0.0005399817725576993, 0.015935535708974515, 0.0169065702107868, 0.03161217638158372, 0.05349057114550045, 0.06940425293786184, 0.02472389073643301, 0.09376978049320833, 0.17570843441145761, 0.07731358281203679, 0.07509882415511779, 0.10478987451642752, 0.212027156991618, 0.1168554417256798, 0.17340358666011266, 0.15854330334280217, 0.2001729059432234, 0.13770486866789206, 0.09172935105328049, 0.1431552962000881, 0.15951307916215487, 0.110530457193298, 0.1781042329967022, 0.09316796064376831, 0.11106498672493867, 0.15146854440016405, 0.09544855755354677, 0.11938830438469138, 0.14273279958537646, 0.11445796037358896, 0.09924993464457137, 0.10360945428588561, 0.12840157002210617, 0.08194575817989451, 0.16062504878001554, 0.1785599642566272, 0.14796229611550057, 0.06721405724861793, 0.10870308096387557, 0.1596848570874759, 0.19550660704927786, 0.19824474012213095, 0.11907334199973515, 0.20139257263924393, 0.14241797290742397, 0.12087060484502997, 0.13895808213523456, 0.09567695244082383, 0.15862008636551245, 0.08222186764968292, 0.21144835305001053, 0.152483374944755, 0.12061968259513378, 0.1372032141579049, 0.09610883319484335, 0.1278535444289446, 0.12561621091195516, 0.07344454220895257, 0.10076019074767828, 0.15391148759850434, 0.13529589293258532, 0.20203139978860105, 0.14031040242740087, 0.15704038898859704, 0.13285073771008424, 0.06414969810949904, 0.10322516597807407, 0.16442731475191458, 0.07416359255356447, 0.1740704101643392, 0.10730134975165129, 0.14334147263850483, 0.24756469577550888, 0.10199542982237679, 0.09992348243083272, 0.13941438336457523, 0.09678019609834466, 0.09391468843179089, 0.10564673532332693, 0.11726694607308932, 0.11896172298916749, 0.11675747483968735, 0.1002216510740774, 0.13587139919400215, 0.27661448983209475, 0.10837669883455549, 0.20578984596899577, 0.08377508180482046, 0.27357663427080425, 0.0734239893832377, 0.11378895198660237, 0.11490027021084513, 0.2064282659973417, 0.1658716443926096, 0.12859378542218888, 0.20207768944757326, 0.16518404414611204, 0.09830207550632102, 0.20623651200107165, 0.13527432908969267, 0.0872451031048383, 0.14331879599818162, 0.09537178810153689, 0.09965423973543303, 0.12222995475998946, 0.11236972814159733, 0.16334834907736095, 0.14556273844625267, 0.17471756972372532, 0.18479156201439245, 0.09763455989637546, 0.21636013234300272, 0.1227314192801714, 0.10597795540732996, 0.12316264185522284, 0.24553905161363737, 0.11270940955728292, 0.10753389727324247, 0.17035571592194693, 0.09965860950095312, 0.21993884816765785, 0.18908724508115224, 0.09077662003359624, 0.15671322654400552, 0.08880229347518512, 0.14576500973531178, 0.16420366960976804, 0.07638711788292442, 0.2630357284631048, 0.13410697744360991, 0.23059168511203357, 0.13168852935944284, 0.08832725789397955, 0.08491725301636116, 0.16393187562269823, 0.13786542362400464, 0.11985817631440503, 0.19007082230278424, 0.09606782253831625, 0.11415476378585611, 0.1245343546782221, 0.07111472436892134, 0.11676480301788875, 0.15381168866796152, 0.09499226989490644, 0.18491938444120543, 0.0980165751118745, 0.07771156395652465, 0.08897445816546679, 0.13959726212280138, 0.12978659570217133, 0.07834349719009229, 0.15402135598872388, 0.18177590811891214, 0.09129663570118801, 0.16704130305775575, 0.14535265043377876, 0.10156847523259264, 0.15933823425854954, 0.12994141025202616, 0.1305445736008031, 0.05731161218136549, 0.1557278987020254, 0.07719542272388935, 0.13963032034890993, 0.1054918732760208, 0.11665781161614827, 0.12786817364394665, 0.06288310393158879, 0.14526434588645185, 0.15578431210347585, 0.1258902440645865, 0.16391139743583544, 0.23699871131352016, 0.1128232813041125, 0.1284809179071869, 0.20407069607504777, 0.13161549185003552, 0.12727372268480913, 0.14782075371061051, 0.08040361093091113, 0.20509191841951438, 0.07677386927285365], [0.03873130472909127, 0.04781007952988148, 0.14159230435533182, 0.00203276050992177, 0.031039930480931486, 0.04221570757882936, 0.015220604071925794, 0.04405719394396458, 0.04467755476278918, 0.02827883917572243, 0.028056987062362686, 0.03378778017525162, 0.017703124521566287, 0.04832312325015664, 0.014732979969786746, 0.09691859688609838, 0.01406668996371861, 0.002664510963118768, 0.02763086198163884, 0.0330407674025212, 0.03178596277055996, 0.012414693832397461, 0.004140575474593788, 0.01751120767689177, 0.053292198040123494, 0.050275248142757585, 0.048294916549431424, 0.036866266413458755, 0.0158005479523646, 0.02111192499952657, 0.06358951995415346, 0.10399141521858317, 0.022410761465185454, 0.02817007340490818, 0.037164984670068534, 0.027837253674598675, 0.06712650587516171, 0.046717085143817325, 0.04976881674623915, 0.04625329288787075, 0.09217590851975338, 0.07434917188116483, 0.029212964765195335, 0.01121011096984148, 0.01187800062221608, 0.005960853803636772, 0.02536382050519543, 0.0459373941245888, 0.018740519748202393, 0.060972138973219056, 0.021889985838372792, 0.02573787989760084, 0.01243173354305327, 0.01799366982387645, 0.044795680924185684, 0.014237059080707175, 0.03198844440547483, 0.020472249681396142, 0.04836006608924695, 0.05539499502629042, 0.03624724570129599, 0.015448746204908406, 0.011894578080890434, 0.027557279947879057, 0.02657823364383408, 0.038833278364368846, 0.010792710153119904, 0.047346629934119325, 0.0577953126547592, 0.06105426885187626, 0.03944973082148603, 0.026595292014202902, 0.048728822730481625, 0.0185656069910952, 0.008119975981701697, 0.06540880804615361, 0.02839475161662059, 0.04324604604127152, 0.049179023930004666, 0.0019616371053936227, 0.04878179256671241, 0.04575940760384713, 0.01958204566368035, 0.02515159171473767, 0.037000137979962995, 0.014046627379554723, 0.016589977645448277, 0.017858188433040465, 0.02189849127483155, 0.04583673006189721, 0.027084227385265485, 0.0406295675119119, 0.05227724875190428, 0.042789347868944914, 0.009806587576999195, 0.03803760106010096, 0.011279429259177829, 0.023877855955756137, 0.02094546509241419, 0.026738647803930298, 0.037497588965509615, 0.02868803311139345, 0.01777678119417812, 0.013351341875802194, 0.025273627934179137, 0.029975393853549446, 0.045372418726661375, 0.039226319773920944, 0.05171821392806513, 0.09865616222045251, 0.05890956215028252, 0.04014167708477803, 0.017236095653580766, 0.05893563146569899, 0.0289827514040683, 0.015797854168340564, 0.03393825888633728, 0.001440421278987612, 0.06766687759331294, 0.04553505678528121, 0.01588382794787841, 0.04507760883175901, 0.009828831651248038, 0.04146837928731527, 0.028435585854042853, 0.014709044647003924, 0.024084683607465456, 0.01389227168900626, 0.03195810031944087, 0.016862446774861643, 0.06684219970234803, 0.11050980937268053, 0.026711379177868366, 0.06452192206467901, 0.017003977305388877, 0.021499283678297485, 0.06346908677369356, 0.06777258656386818, 0.04288349460278239, 0.025781762453594377, 0.01799199723505548, 0.06350427559976067, 0.044579570913421254, 0.05115019530057907, 0.01767254125193826, 0.03251389853124108, 0.04657890487994466, 0.00896613544318825, 0.031516587760831626, 0.05809901135840586, 0.03882619445877416, 0.058279460961265225, 0.03283146309799381, 0.05001623775543911, 0.03307792737281748, 0.00713133264798671, 0.06316716583179575, 0.043609774738018, 0.014811696817300149, 0.032776135352573225, 0.020893433330846683, 0.03150772948616317, 0.02853358836312379, 0.027481711502852182, 0.009872923704928585, 0.025851514157173888, 0.03515458719006606, 0.03382742019104106, 0.05664003214665821, 0.03720257551010166, 0.024414000400741185, 0.07455931417644024, 0.03161365219524928, 0.03348209336400032, 0.02188210974314383, 0.07018182692783219, 0.06421621489737715, 0.011189556447789073, 0.07208207781825747, 0.030007003407393183, 0.01500813609787396, 0.03530348152188318, 0.022764843090304306, 0.030929390341043472, 0.07032332862062113, 0.022876601200550795, 0.017822709533252885, 0.016701389702835252, 0.022355878160202076, 0.045857170929333994, 0.004150631363570158, 0.02294097381776997, 0.01730477696816836, 0.05501306462766869, 0.020152664776625376, 0.033510802180639336, 0.010970197102454091, 0.008723292000857847, 0.06584575745676245, 0.036895881074347665, 0.01189102340556149, 0.022902338033808128, 0.04994978882106287, 0.025802668117518936, 0.012315744766965508, 0.028260321955063512, 0.05039526741685612, 0.03583276937050479, 0.02192222642978387, 0.033191164689404626, 0.008649228207234825, 0.035797468586159606, 0.03890776115336588, 0.017101947584056428, 0.06434085499495268, 0.010195926729855793, 0.028446162518646036, 0.06619927420147828, 0.07101548183709383, 0.041040844550090175, 0.06579971885574715, 0.016820489561983516, 0.023360613800053085, 0.02620398935063609, 0.02548979053140751, 0.029319230134465864, 0.06519269464271409, 0.01152555426649217, 0.03588747964905841, 0.007578756094777158, 0.05629884438323123, 0.1003660297553454, 0.03134732720042978, 0.02085048545684133, 0.03066303481214813, 0.010216706016633128, 0.03318789754328983, 0.03255690068804792, 0.028461219210709845, 0.017088480360273803, 0.03542994348598378, 0.020997237314337065, 0.07205656490155629, 0.06155207606830767, 0.019179671004946743, 0.0348693683876523, 0.04303106918398823, 0.06526022923312016, 0.03561724629253149, 0.017778085677751472, 0.014183042604210121, 0.07795543622757707, 0.01647955964186362, 0.0420289306369211, 0.013448123870018338, 0.10083611203091485, 0.028637723132435764, 0.03814099622624261, 0.009446287178434432, 0.02689052768982947, 0.011485222993152482, 0.052596072001116614, 0.05244763568043709, 0.019927065453625152, 0.046842756614621194, 0.0529778734780848, 0.015344022806467754, 0.055545439810625145, 0.046271168892937045, 0.0022438669610502465, 0.09346900627549205, 0.03536241568092789, 0.07274797851485865, 0.081936279045684, 0.002715039557577776, 0.032686300708779266, 0.02723385114222765, 0.050881376689566035, 0.007276287235851798, 0.021498652640730143, 0.021638882080359117, 0.015051452077126928, 0.04938395168366177, 0.06751610032681908, 0.05779188605291503, 0.011526834153171097, 0.09077741391956806, 0.05071630947557943, 0.038613592474056144, 0.00953002688142338, 0.07299084655408349, 0.04055088459114943, 0.031536906491965055, 0.020579056182344044, 0.015220054458560688, 0.008494964967082654, 0.037175722486738644, 0.025726299001170055, 0.00776139397307166, 0.02417729006681059, 0.01304751425050199, 0.03793481318280101, 0.03918216750025749, 0.039169655314513614, 0.08477293540324483, 0.06442756498498575, 0.04782378932993327, 0.07120833506009408, 0.007257445166552705, 0.017350074269675782, 0.04608175584248134, 0.03942304064652749, 0.08159437882048742, 0.015881130771179284, 0.020540617173537612, 0.021278491775904382, 0.017462176736444235, 0.06428073000695024, 0.01438534103466996, 0.025434995435976555, 0.08670184082750763, 0.02679501031525433, 0.07638122141361237, 0.02715175858299647, 0.04168475731941206, 0.0036669291938388987, 0.02433400790739272, 0.01808561640791595, 0.06024016932185207, 0.04193097732162901, 0.04388738037752254, 0.020664566861731664, 0.03221334144473076, 0.047631075206611834, 0.05288712281201567, 0.03482050708095942, 0.04364837320255382, 0.025802537499527847, 0.07797126644956213, 0.014345497458374925, 0.0815009649044701, 0.014284439484721847, 0.03949480251009975, 0.03808107819142086, 0.042884349556905885, 0.064461885286229, 0.014162685705481895, 0.0167524223215878, 0.06044389946120126, 0.02532177508276488, 0.016692514464791332, 0.05698976945132017, 0.15091355703771114, 0.16158411731677397, 0.15800475009850093, 0.1591405498662165, 0.11887211565460477, 0.07476917148700782, 0.12358203077954905, 0.12278524067785059, 0.1141606941819191, 0.12940999519612106, 0.12763297983578273, 0.09406492287026984, 0.1701202235583748, 0.1356031878718308, 0.10231470090470143, 0.13160221970507077, 0.11662433269832816, 0.09271250079785075, 0.09916614914046866, 0.08136316122753279, 0.1050770916044712, 0.04863183293491602, 0.11323055159300566, 0.17429212826703275, 0.11438003741204739, 0.13162250790212834, 0.09280959915901933, 0.1990930446024452, 0.15033798292279243, 0.08408143358039004, 0.12286720770810332, 0.17378828887428555, 0.12775097707552568, 0.12315539510122367, 0.09298124816268682, 0.1326291553143944, 0.08444799855351448, 0.0831122345158032, 0.18894268998077937, 0.0838343518386994, 0.1901823463184493, 0.1805380838257926, 0.1366521758692605, 0.17006492295435496, 0.1342828401497432, 0.08244720234402589, 0.21669933199882507, 0.16946811069335255, 0.12863950511174543, 0.1017914011276194, 0.1316577238695962, 0.08259090249027524, 0.08536490292421409, 0.18748898298612662, 0.21983733932886804, 0.22393836426947797, 0.10191788684044566, 0.1725966456745352, 0.1023499100868191, 0.14074881747364998, 0.12227553874254227, 0.11285163049719163, 0.12130992912820407, 0.09651233761438302, 0.10271163031991039, 0.08338619981493268, 0.15064738132059574, 0.13239499287945883, 0.12901002594402858, 0.12907093124730246, 0.22385995276272297, 0.1026856695700969, 0.08480878240828003, 0.08395919549678053, 0.08013445644506387, 0.17313382827809878, 0.13283415431422846, 0.10351312945463828, 0.12979066691228322, 0.20255146973899432, 0.08121642124439989, 0.1135693984106183, 0.1592980921268463, 0.09466413035988808, 0.1199621143085616, 0.1084131361650569, 0.16356400107698782, 0.12039134199065821, 0.16813648571925505, 0.11049992311745882, 0.0870557918346354, 0.1296657079032489, 0.17669814558965818, 0.12537389248609543, 0.2582256208573069, 0.07730739457266671, 0.11550647339650563, 0.17905363919479506, 0.11058619205972978, 0.1157058948384864, 0.11084299042288746, 0.06892542434590203, 0.08757189914051976, 0.17882136308721133, 0.10422120788799864, 0.0615242018497416, 0.09052573171045099, 0.15719429430152687, 0.10077164441879306, 0.21540635637938976, 0.16178116388618946, 0.101122399525983, 0.17354099000138895, 0.10622550533818347, 0.11574115151805536, 0.12097378287996564, 0.13640589479889187, 0.10695566330105066, 0.17936264404228755, 0.1025554926267692, 0.093147027838443, 0.10795633281980242, 0.09943078458309174, 0.10654677809881312, 0.0864585249551705, 0.2139076625130006, 0.14334379322826862, 0.1254221498966217, 0.23152011100734982, 0.1742849357958351, 0.15808747708797455, 0.17261317478758947, 0.1111366603789585, 0.08701465904180493, 0.14744495387588227, 0.12836171287511075, 0.13336163386702538, 0.12791180344564573, 0.10450611117162875, 0.11436230050665991, 0.07667040625321013, 0.13736486834074768, 0.12129699625074863, 0.2558416287813868, 0.17520656277026447, 0.18055793776043824, 0.1110414687011923, 0.08934393405382123, 0.17506827733346395, 0.10793096918080534, 0.11742186918854713, 0.10567348317376205, 0.1361541583069733, 0.11170542878764016, 0.09549295409981694, 0.12160640821925231, 0.17052216056202138, 0.14409801204289707, 0.08557812576847416, 0.13332199385123594, 0.090092778871102, 0.05995150695421866, 0.12650095272277082, 0.10862115464572396, 0.17364434445542948, 0.04421810173828687, 0.11035566657249417, 0.06512031531227486, 0.09261928365698882, 0.14802970178425312, 0.13199217378028802, 0.27660607599786347, 0.08360614694122757, 0.07829956883298499, 0.07150330101805073, 0.14706338649349554], [0.049347629704113515, 0.016797097067215612, 0.038543516770005226, 0.04171277063765696, 0.050495083310774395, 0.010280096454412808, 0.027474792141999518, 0.07588209105389458, 0.008865492584715997, 0.0717051380446979, 0.0037170114394809517, 0.02198459906503558, 0.03631599147671035, 0.08443431928753853, 0.010650373862258025, 0.014704376326075621, 0.07580837500946862, 0.039974309637078216, 0.03789019950532487, 0.05437773193365761, 0.06101578913096871, 0.008635623580110925, 0.04680393762620432, 0.04302640086305993, 0.06162930013878005, 0.006407015175292534, 0.02008541686726468, 0.05256126315465995, 0.05772665169622217, 0.01747495524718293, 0.03520340778465782, 0.04981366791097181, 0.010560778402058142, 0.03938631493864315, 0.10213266352989844, 0.011492311987759811, 0.042758912180683444, 0.01610519490869982, 0.056984164752066135, 0.0593772627679365, 0.020454582325848084, 0.007967900168815894, 0.06973845179059676, 0.033536450804344246, 0.039205573565725765, 0.024444816068613102, 0.037233537063002586, 0.05530503485351801, 0.03294444257127387, 0.019955728469150405, 0.022971635118925145, 0.01327895576001278, 0.017415074531787207, 0.0373927247710526, 0.03705160825380257, 0.05214266133095537, 0.07181812091065304, 0.0460157615265676, 0.04222183135737266, 0.03267614643222519, 0.06333136452095849, 0.06367960904857942, 0.04981264332309365, 0.10690461032624755, 0.015420778687777264, 0.08840661256441049, 0.01772407429026706, 0.10478406625666789, 0.013924000834647034, 0.025584856680195247, 0.02995678163798792, 0.040110311803541014, 0.02268579206429422, 0.043333607592753, 0.051473079581878016, 0.015919349256104658, 0.025198458128475716, 0.03190902866689222, 0.023926194790484648, 0.024219318525865674, 0.0368038411917431, 0.026839724076645713, 0.012877180756601905, 0.0176310013380966, 0.08439331541636161, 0.03667043781440173, 0.02242777233810297, 0.053278355925743065, 0.037014190440199206, 0.06814336523945842, 0.015825470543599555, 0.04975899834451931, 0.02458230422676674, 0.04855210507022483, 0.017691725133252994, 0.0444087056177003, 0.041293656520013294, 0.02427149617246219, 0.016451919517878975, 0.054190351095582755, 0.05464454208101545, 0.01825295332153993, 0.06287003534712962, 0.08068889419415168, 0.04797098393152867, 0.052994975953229835, 0.08992893302014895, 0.00707094430358016, 0.03730077309800046, 0.043887373592172346, 0.018582458408283334, 0.016661787006471838, 0.005525486651874546, 0.01855588358427797, 0.005053539677256984, 0.016970391518303325, 0.013920715028819228, 0.03232481796294451, 0.0038872635091788, 0.05604392556207521, 0.030929407304418937, 0.007733972676630531, 0.052072470275951285, 0.011453476884136242, 0.037180689363075156, 0.031027418295187608, 0.06161564801420484, 0.0427009483267154, 0.05434986110776663, 0.04666715514447008, 0.020281089403267418, 0.01415356110581862, 0.007331840594166091, 0.0410682946842696, 0.03242922753893903, 0.06457932612725667, 0.01785278050894184, 0.00541491385748876, 0.025729350712416426, 0.040648288293076415, 0.04643313520188842, 0.09028749128005334, 0.03485687655795898, 0.03500446470986519, 0.017592216276430657, 0.03923229766743524, 0.06414200352238757, 0.019264206290245056, 0.08436162783099072, 0.009419926941128713, 0.03465858826945935, 0.04718370349811656, 0.03421727248600551, 0.025368426061634506, 0.0450809268680002, 0.08721631964934723, 0.044909494995538674, 0.029019256588071585, 0.026196435559540987, 0.04533647672672357, 0.019579048235235468, 0.08336304141474621, 0.02500255997957928, 0.006380951372973088, 0.043588129470923116, 0.0460236393181341, 0.08919127045997552, 0.023069603701255152, 0.03490614837833813, 0.002768955526075193, 0.03541262048695769, 0.06204051271613155, 0.014294315561918276, 0.03348854962470276, 0.05271177579249654, 0.020667146991140077, 0.09230703541210719, 0.08398901032549994, 0.03334322438708373, 0.016883145485605513, 0.021187084627204707, 0.06781785163496222, 0.0068969717415581855, 0.016672054937641536, 0.008303754646996302, 0.04283531861645835, 0.035037502579923184, 0.013103631641050535, 0.07234669290482998, 0.019137332116120627, 0.020511569089389274, 0.010304047892402326, 0.12649697650756153, 0.03321968690891351, 0.0290428933554462, 0.02709804235824517, 0.03323478092040334, 0.0023497046412168337, 0.084241601771542, 0.045774613573615036, 0.05408951400646141, 0.025319137277879884, 0.03437089281422751, 0.06356632084186588, 0.03633197097639952, 0.059951710514724255, 0.03636256612039038, 0.06026930561555283, 0.018840176186391284, 0.0543997775364135, 0.09961512219160795, 0.017732520354911685, 0.07490920754415648, 0.02143522149084934, 0.030442042741924524, 0.07672648038715124, 0.021904838969931006, 0.030149804494742836, 0.05895241842206035, 0.04006047679909638, 0.01306266084845577, 0.04501107847318053, 0.014442611086581434, 0.017690958388681923, 0.010470400082080491, 0.026274416196559156, 0.04808428231626749, 0.008145599160343409, 0.09955022710242442, 0.0586775303153055, 0.025584564910137227, 0.005688672627521945, 0.08292399533092976, 0.05569162339504276, 0.032416518578039746, 0.024680766443322812, 0.05341941996344498, 0.044064332132360766, 0.06481388211250305, 0.037998924564038, 0.050163527351937125, 0.08631940492029701, 0.024341775437018702, 0.04337211784773639, 0.03497222411845412, 0.04376007702999881, 0.06545239713575159, 0.023521358745970895, 0.033364072375531705, 0.02805347733997873, 0.045041218998708894, 0.026146498774843555, 0.026532508865264908, 0.024321210736941015, 0.017412396014801095, 0.09607385471463203, 0.04462300054728985, 0.06622955721936055, 0.026489535546196357, 0.03511337297303336, 0.09851294383406639, 0.033182910310902765, 0.036749103771788735, 0.0750391266441771, 0.016713964653068354, 0.02458659596075969, 0.0147713833555047, 0.04441489724974547, 0.07908413173364741, 0.030875138073627437, 0.07687254862061568, 0.04006828673716102, 0.048236640569354804, 0.041643790767661164, 0.047382303912724764, 0.08304145652800798, 0.022479408853022114, 0.07950320853186504, 0.002687400917888486, 0.03606867903311338, 0.022130641853436828, 0.046117392501660755, 0.07618323846587113, 0.023497136742142693, 0.024116059066727757, 0.03457004962755101, 0.01145515710647617, 0.030997006355651786, 0.05521585499601705, 0.051295428935970576, 0.01730442582629621, 0.027691129461995194, 0.02355081564746797, 0.02183583365487201, 0.007809580137420977, 0.055348016654274294, 0.018025559273415377, 0.06465374106275183, 0.04211105712290321, 0.015063496073707938, 0.06024428802941527, 0.004104200060412819, 0.011999231081322899, 0.013762480662470418, 0.07513371442577668, 0.020372762876961912, 0.058816799627883096, 0.0178276730169143, 0.02927622797765902, 0.016667520627379417, 0.02341866247089846, 0.09025294027690377, 0.029322453175804446, 0.0011700023855415306, 0.05224818031170538, 0.03740451092432652, 0.03464662908975567, 0.01979769766330719, 0.03409574007881539, 0.029614555715982403, 0.025127089815214276, 0.01897014956921339, 0.04716696064653141, 0.031010610982775688, 0.0364988566642361, 0.051229091959872415, 0.04269621554496033, 0.00331682017921204, 0.06024595722556114, 0.04406636095206652, 0.007831862379264618, 0.015523072930851152, 0.006461815359736127, 0.0457234757819346, 0.03029928236667599, 0.08555609373641865, 0.06292145473084279, 0.10648406110703945, 0.04621380554246051, 0.02064606490811067, 0.05862768513283559, 0.0332029745914042, 0.04551712989008852, 0.027641671044485908, 0.011101955032375242, 0.04431556990104062, 0.015815034675012742, 0.03155562727312956, 0.047242579981684685, 0.046710086055099964, 0.06070989875921181, 0.012090812104621103, 0.13733019520129475, 0.20784864335187844, 0.11065948741244418, 0.09461012575775385, 0.08548821309315306, 0.12907972506114415, 0.11641063487955502, 0.2302900898669447, 0.06545788648405246, 0.13406504397945745, 0.0813307815364429, 0.10359245698366847, 0.1818163895181247, 0.14230441328670296, 0.18188493512570858, 0.0809486781113914, 0.23551670940858976, 0.15816653998834745, 0.08181585265057427, 0.15661791951528617, 0.08322612661868334, 0.1202077032732112, 0.15542341289775713, 0.09411552122661046, 0.1657676656863519, 0.15267375830028737, 0.12283516728452273, 0.15612903503435, 0.13863078398363932, 0.09522789118013211, 0.09360719671738998, 0.23821155194725308, 0.08625844533422164, 0.14350072480738163, 0.16427952982485294, 0.15690142501677784, 0.12747406693441526, 0.07119026567254748, 0.08955106365361384, 0.19913389241056784, 0.0728615177795291, 0.09907795994409493, 0.17808812457535947, 0.0913416768557259, 0.08005351400268929, 0.10027333508644785, 0.07586315314152411, 0.07872225543750183, 0.13660220855048724, 0.15074753308934824, 0.12018751007105623, 0.08744050761950867, 0.1453988179564476, 0.18658000390444482, 0.10301107460899012, 0.161749856280429, 0.1740346106567553, 0.17570384751473153, 0.1341727410576173, 0.11890691093036107, 0.15535576295639786, 0.18884240250502313, 0.15217876700418337, 0.2287910431623459, 0.11925079247781209, 0.35610280452030046, 0.1073914592021278, 0.19649893737265042, 0.10743780314390149, 0.14530409446784429, 0.17612946539052896, 0.04791516764089465, 0.113278266175517, 0.08472171958003726, 0.1537947795752968, 0.11677842800106321, 0.15161696715014322, 0.08870930703622953, 0.0872187013072627, 0.14941123979432241, 0.09887266238885266, 0.2259456201323441, 0.09203833554472242, 0.08956875984690019, 0.18132050255579607, 0.10224202980420419, 0.11783004871436528, 0.17950144516570227, 0.0854639961783375, 0.1602923630603722, 0.08455478639474936, 0.1393417665468795, 0.15751662557678564, 0.12388734439654009, 0.10593473951199225, 0.08494898131383316, 0.10525401961058378, 0.10417181732399122, 0.0837341050750443, 0.141358060496194, 0.10932362837983028, 0.11074420250952244, 0.16780751837151392, 0.1505852953663894, 0.10438603761472873, 0.15700289314346655, 0.23390594869852066, 0.10292760801634618, 0.07650899634297405, 0.11248993740550109, 0.16473315762622015, 0.1545142845383712, 0.1442564363990511, 0.13732487548674854, 0.06208868870245559, 0.12479968901191439, 0.1073716799063342, 0.11302584436322961, 0.07571105273174387, 0.14236472147916043, 0.11345216113009624, 0.14013535396328994, 0.15547996200621128, 0.0799478796709861, 0.0943460331431457, 0.09981351904571056, 0.14915673487952777, 0.12809093669056892, 0.11709575168788433, 0.1836398709565401, 0.18837358908993856, 0.15311981365084648, 0.093527767408107, 0.13686776001538548, 0.09521445618676287, 0.10853238190923419, 0.17700092148567947, 0.13010364797498497, 0.1423646536256586, 0.20733321458101273, 0.12848701115165437, 0.17688759256686482, 0.12354943395725318, 0.14744294541222708, 0.10487897973507643, 0.10555012550737176, 0.13898784268115247, 0.10862779071820633, 0.18471088420067514, 0.11578179576567241, 0.19657521827944688, 0.21401618740388326, 0.1312187117125307, 0.10328240719224725, 0.1430143237646137, 0.15039601123758725, 0.217037133872509, 0.22619407251477242, 0.07386802948479142, 0.20571119018963405, 0.11585473828017712, 0.17466176700379166, 0.12999071260648115, 0.06488523006971393, 0.15780587148453507, 0.16204971447587013, 0.11383279891950743, 0.1748521775007248, 0.07805946921663624, 0.14703235030174255, 0.09773644192942552, 0.16820233075746469, 0.1267931027604001, 0.14575821081442492, 0.15201963697160992, 0.10860296990722418], [0.010179059197460967, 0.04519874429596322, 0.025179586373269558, 0.01721100851760379, 0.023816735217613832, 0.010135068075864442, 0.01974130970691996, 0.12158485794706003, 0.038242488101656945, 0.05313549377024174, 0.0384637549785631, 0.012921405124611087, 0.021870147170765058, 0.027354940805318098, 0.07412550638296775, 0.025970478309318423, 0.03552849391209228, 0.04099582035892776, 0.004275257890445313, 0.0513277984490352, 0.07455095462501049, 0.030084536211299043, 0.06363831340734448, 0.023608652276120017, 0.04642010393685528, 0.041638477838465145, 0.05703735511217799, 0.039460638271910806, 0.024861083731853535, 0.041124579164066484, 0.018063304480165243, 0.01933317767855312, 0.059690515244645734, 0.02125853266833084, 0.05640341680763023, 0.019635724569005624, 0.018176735179232698, 0.015829311051805104, 0.03204805709953819, 0.045727078802883625, 0.05741083435714245, 0.037695178362940035, 0.03750334972781794, 0.0418541705501931, 0.03957697310085807, 0.042319282556750944, 0.02126419504306146, 0.06431777801896844, 0.01062440887160067, 0.04961010401270219, 0.031957954434411864, 0.025433991204148958, 0.03432330036801951, 0.016645909287035465, 0.016358436052022234, 0.0814450875456844, 0.051380286525402746, 0.025785960889022266, 0.06629245063023907, 0.02361310855485499, 0.0386298773145037, 0.04210372894470181, 0.06134841378246035, 0.08149007441742079, 0.022166655099551593, 0.017218611502487744, 0.021790940081700683, 0.049054390617779324, 0.05008585884102753, 0.014881090593657323, 0.04143721078123365, 0.04470092011615634, 0.0750954043386238, 0.06508241234613316, 0.04848951021475451, 0.0391930545946317, 0.007307321731267231, 0.035681703726627996, 0.017335251672193408, 0.024709633019353663, 0.01004964645419802, 0.030124752981854335, 0.018340012757107615, 0.04118623085586088, 0.029465491750410626, 0.010721382551959582, 0.0606982076008405, 0.02492640120908618, 0.016779495868831873, 0.020853352267295122, 0.08429472427815199, 0.036251313518732786, 0.04301378011171307, 0.055263081033314974, 0.05229685502126813, 0.023051072909895862, 0.06248141798589911, 0.03121024277061224, 0.09979616890528373, 0.02473576340292181, 0.007373333858725215, 0.07207335864326783, 0.016383726748504808, 0.09470245401774134, 0.03354092574279223, 0.053928131237626076, 0.015974117210134864, 0.02821631047741643, 0.040079258648412566, 0.06692534059818302, 0.01856049253339214, 0.02126020356081426, 0.01916177973284253, 0.032052260623978715, 0.010573422902130654, 0.0298125081296478, 0.008991364223350371, 0.05896117152380092, 0.00813951185305736, 0.1150570660829544, 0.02709345206884401, 0.03215071266250951, 0.010554548602418175, 0.0679826270788908, 0.003180007587486346, 0.030714589902865033, 0.023151645370359932, 0.011581669112534394, 0.039514154328831604, 0.029487391468137503, 0.044807117631925006, 0.05472364569348948, 0.012207402232369142, 0.038665340947253365, 0.025426301706050123, 0.04744153662717768, 0.006432646835621978, 0.034708026330918074, 0.057552634605339596, 0.06560824984418494, 0.028027441951313188, 0.03366071431498442, 0.04175316043464201, 0.04333823859425528, 0.03231321501412562, 0.03624233989311116, 0.050530455341296535, 0.008467474120802112, 0.030484081379004886, 0.021395759590502297, 0.022545535483264496, 0.0380476739124528, 0.03561631669955594, 0.02546580771117338, 0.010126760262729866, 0.031937527137675455, 0.003964842538282807, 0.06780041328498296, 0.0731003824621439, 0.05134703491681388, 0.019066406546958854, 0.040318581342164955, 0.008519085190658058, 0.029314049519598484, 0.021558704686218073, 0.023091947859419242, 0.05445268630449261, 0.023871983235169734, 0.04482580787901368, 0.04833123513630458, 0.022391950778130974, 0.06239259096660784, 0.02866578394813197, 0.034264939571065564, 0.02555616313059415, 0.03229093870946339, 0.031787604825305085, 0.055184377756501944, 0.004114708871514137, 0.025839110537032996, 0.02151019961040999, 0.055001519354326386, 0.04482913948595524, 0.06168040061103446, 0.052220034679131846, 0.02855301821338279, 0.0795359139197639, 0.02462889583382223, 0.023450607899576426, 0.012422983833987798, 0.042674899367349486, 0.0026027227161518696, 0.023362143896520138, 0.06925319747201034, 0.013642352822768902, 0.03386804408260754, 0.02223963662981987, 0.05260482171018209, 0.017899221141955683, 0.012542014991465424, 0.017294142628088593, 0.03532467556319066, 0.03765719057992101, 0.034485636478556056, 0.03318954638338514, 0.022730063081585934, 0.02002403828581529, 0.028248020115175417, 0.03436575291146125, 0.03937421326658555, 0.02891224143760545, 0.026311525276729038, 0.046862498590988774, 0.008368167128147823, 0.02876484327550445, 0.030937023860003268, 0.02022695927215474, 0.02720585309102067, 0.029318130907735655, 0.0687545013747045, 0.028320925310254097, 0.01992369313458247, 0.02066161184172545, 0.023679106263443828, 0.06335747454847608, 0.026247096680370823, 0.028415889678789035, 0.03478055154638631, 0.027700143799717938, 0.023659700161910484, 0.0927587633154222, 0.061827629139380794, 0.04575670364179781, 0.08597820358616964, 0.07046013485108103, 0.026048955973237753, 0.011359662632457912, 0.06791389148150172, 0.026976067206955383, 0.046217476416911395, 0.009196370008534618, 0.018687497325507656, 0.031135827835117067, 0.006786661879492125, 0.011263745770390545, 0.012462684917928917, 0.049990707875362465, 0.017584045018468584, 0.036127090720193725, 0.031934307489011965, 0.043110875080206564, 0.06800008578492062, 0.034592115586357455, 0.022902095457538962, 0.03665979838530932, 0.022659488654296314, 0.04861608752980828, 0.003771801869983652, 0.03597326683146613, 0.030820292088070085, 0.016907185981316224, 0.037845304235816, 0.014199553905720157, 0.005427856912969479, 0.025746519344725778, 0.044015579391270876, 0.03258368246523397, 0.024428280170208642, 0.02784387448004314, 0.08516060281544924, 0.021413671218657067, 0.03646306733467749, 0.032588700231696875, 0.06639644290719714, 0.08820743539503642, 0.011178609981600727, 0.013623832209434892, 0.011496149103290268, 0.04115849912964872, 0.04496529093012214, 0.022808165854907463, 0.02300515814152147, 0.05538509180769324, 0.036179863781269105, 0.013984488838884448, 0.05526107596233487, 0.010138000195313777, 0.038806622116161246, 0.03211387499634709, 0.026828109253464, 0.01951854326762259, 0.041755996711019955, 0.0318169141454356, 0.059568806418350766, 0.03267796151340008, 0.03103368795875992, 0.02956206424693976, 0.01848557378564562, 0.055114827917090485, 0.03921742757250156, 0.029295589974416152, 0.02267247242187815, 0.049084680421011787, 0.018965208137940084, 0.06268287503293582, 0.029594929090567997, 0.021234151208773255, 0.033678624246801646, 0.011395898098791284, 0.032270284103495736, 0.027291250115792667, 0.04357480982850705, 0.035437139349856546, 0.025095061265996525, 0.08878898740346942, 0.033769113676888604, 0.0627668776682445, 0.02509872365875968, 0.06958871268268142, 0.024550241750798056, 0.04502018441313079, 0.0485746086841183, 0.09429221174546651, 0.03261064744687506, 0.04251760137932641, 0.04135365258636219, 0.08904320054820605, 0.03434627217107585, 0.007442887090811772, 0.024011128715106418, 0.021024431301546947, 0.08019787911325693, 0.023661963076197674, 0.02034524149660553, 0.030311417965484515, 0.03693463899461286, 0.018743113448311175, 0.03652267324339066, 0.035590501834771464, 0.13835561089217663, 0.02523470377283437, 0.02878497540950775, 0.05302168309156384, 0.042709056820188246, 0.025604714007515992, 0.041768885483699184, 0.029928948131522963, 0.04461710747065289, 0.09667361181761537, 0.0325629871471652, 0.01647542736360005, 0.021544309565797448, 0.14355702964322908, 0.05725741758942604, 0.06536677280174834, 0.09346112848392554, 0.127974323662264, 0.0943749523056405, 0.09242201995636735, 0.21370989669646534, 0.15213782420115812, 0.16092935816517898, 0.15964407713285514, 0.06768273495669876, 0.14190039996589932, 0.09974719224763767, 0.17981481977871486, 0.10642779698329312, 0.08999599263604198, 0.11989818273910455, 0.099645215219685, 0.11991988228900091, 0.26387534769518034, 0.10412875070635762, 0.1506368504571063, 0.04232580667095525, 0.08647742894079004, 0.16092008937682423, 0.10036636223750454, 0.11265905547354903, 0.15864441863128118, 0.13141372267689022, 0.14596453974289553, 0.17301030776330403, 0.12366688836898122, 0.1805652387972389, 0.12250782842082636, 0.09514349499451262, 0.19739297511322157, 0.10655174497514963, 0.07310658427221434, 0.11949494294822216, 0.147954560816288, 0.1539804403270994, 0.14119287793125423, 0.2238748533917325, 0.13383662195077964, 0.0975378415148173, 0.08053443926785674, 0.11812028528324195, 0.10204600782266685, 0.1824670231768063, 0.0970781883224845, 0.11614230142108031, 0.11560283893985407, 0.18160836425210747, 0.15152864903211594, 0.14770019160849707, 0.11889145390263625, 0.18030153294759138, 0.15846365690231323, 0.22468661197594234, 0.07719935144164733, 0.1628903786518744, 0.1251059254365308, 0.12031265906989574, 0.09882547027830567, 0.0952370378321835, 0.1443789933941194, 0.12818977210138524, 0.1097571240471942, 0.0958003643900156, 0.10724102120314326, 0.15427491095449242, 0.12677278742194176, 0.14163161867431232, 0.07532145828008652, 0.23192522355488368, 0.10527176330132143, 0.19249221522893223, 0.1694998661322253, 0.09426735700773341, 0.1720026968313115, 0.11801224893757276, 0.10446765180677176, 0.19431381033999579, 0.08026232636932816, 0.10697404481470585, 0.12443834197308336, 0.055345675708459954, 0.09651365397231919, 0.15145386090236052, 0.16560635077101843, 0.11656095752758638, 0.12949466279574803, 0.15523814569626534, 0.1811516559017556, 0.08096752781420946, 0.12086259813180991, 0.15984386498374598, 0.17402133851179055, 0.1584473042083638, 0.11339376640639134, 0.1371786104781287, 0.11297549027949572, 0.15484800163124288, 0.11200596551809992, 0.14054345206490584, 0.12225482985377312, 0.09738541540822812, 0.10733768530189991, 0.14364579559436866, 0.11149899807891675, 0.17438250913151673, 0.15771718695759773, 0.13246701258633817, 0.15514942045722688, 0.21176963938134058, 0.1067833968305162, 0.1799225847103766, 0.06135450702692781, 0.1512254795857838, 0.11574439491544451, 0.08127373031207494, 0.1573465032769101, 0.12448626011610031, 0.1811658644250461, 0.08949994961065905, 0.08890544436872005, 0.12358748620109898, 0.11278486265135662, 0.08621561620384455, 0.11106775514781475, 0.13341465459338256, 0.09508977537708622, 0.09250025504401752, 0.09821184391954116, 0.11768041817205292, 0.12344291753002576, 0.09623136304851089, 0.17601639431502136, 0.10230429896286555, 0.13819941213088377, 0.12937342215861591, 0.21607271847980364, 0.1087600914761424, 0.14709647186100483, 0.1679853488292013, 0.14975851401686668, 0.14063285583896296, 0.07979694634143795, 0.17682014618601116, 0.24224058432238443, 0.13909577046121868, 0.10611631548298256, 0.11884086233164583, 0.10160166916570493, 0.19138381470526966, 0.10083251579531602, 0.1730706023850611, 0.1500060028795685, 0.17978334932454995, 0.08847973149802003, 0.1284709841545139, 0.13707119838467666, 0.12102830995406423, 0.1368487203227622, 0.11534350285572664, 0.1931957881897688, 0.21860521472990513, 0.15367534384131432, 0.1713557815445321, 0.22871404300842965, 0.16156944738967077, 0.16475579355444225, 0.14844383884753498, 0.08008522872946092, 0.1264913718083075], [0.04593773678477321, 0.0468788512849382, 0.02811970405413636, 0.04246328465108361, 0.004051650067724819, 0.04755083504798157, 0.07461488619446754, 0.02617960110572832, 0.0567207676358521, 0.033562360664031336, 0.050829872488975525, 0.019492224590586762, 0.04115610390103289, 0.07548651192337275, 0.08545896144849913, 0.03786495800263115, 0.047352858885590515, 0.015633226305778538, 0.04184293061760919, 0.05139771130468164, 0.008518706907385161, 0.04875324659847787, 0.021788443072832057, 0.004368996655102819, 0.029465817447219576, 0.009356253214978745, 0.0641084024682641, 0.030617932589458566, 0.0772523789533547, 0.0030832796640295, 0.02448053245565721, 0.0190197216413383, 0.06561557123703615, 0.050343943028045554, 0.05646745355001517, 0.08957152826977627, 0.050910353527537415, 0.04179391324786203, 0.04309107882103749, 0.031612105135406764, 0.015476467753095286, 0.03245177525760872, 0.026030097788731967, 0.059410911319511275, 0.07067318806158644, 0.01297289999534509, 0.03136550515357937, 0.06852324306964874, 0.011325823242909141, 0.022503546039972986, 0.13124482174004826, 0.024993284405874353, 0.060182900966278145, 0.0168582754808345, 0.022032959952152202, 0.0913539311981627, 0.032384077818798165, 0.03186492728335517, 0.019517199768285667, 0.04979584618870701, 0.030833438704056398, 0.06257828564516135, 0.024131699298907603, 0.039691465707229714, 0.005854826345707157, 0.022004822801266397, 0.0692892683936017, 0.0415469298937491, 0.02827721747702786, 0.03683634641181145, 0.022607651971546665, 0.03684362030721136, 0.017783793853595853, 0.014928336987005813, 0.055063812261713405, 0.007340387590894741, 0.04359425324946642, 0.07427298596927098, 0.050688794880573235, 0.06613691683326449, 0.01827656464385135, 0.03720489949254053, 0.08026519657245704, 0.03338120877742767, 0.02940675097384623, 0.03679258090310863, 0.012686554824800363, 0.0033824196725618094, 0.006006631168669888, 0.027905052893662026, 0.01794921899480479, 0.03086925178234066, 0.03861187917313405, 0.011900189565494657, 0.017966518245105232, 0.05365233050127115, 0.07857586829257862, 0.022813780732186775, 0.048504465126565526, 0.02624710855473365, 0.04614029984389033, 0.009839653436626707, 0.03698262159845658, 0.011397864154007818, 0.06204613098608596, 0.03510121023282409, 0.036031349429062436, 0.04469266573765448, 0.013928407071424382, 0.024416996132848517, 0.007150824414566159, 0.0742233239912561, 0.03171932723905359, 0.05544576980173588, 0.05128785987783756, 0.03418814976300512, 0.0513258917656328, 0.018739775056019425, 0.002532722075037392, 0.03956800626058664, 0.03258755350751536, 0.0051257048450809506, 0.025891924310209494, 0.04219359072989651, 0.04467267948868019, 0.018341939796560576, 0.017203587040837322, 0.03417281487158366, 0.04245546114231859, 0.05034039089722293, 0.04482652034078326, 0.048075030491288216, 0.03678296266921929, 0.03553803750712957, 0.029127605059849362, 0.06193159427493811, 0.03274444437452725, 0.019238542399502227, 0.06898627536637442, 0.05343890070383038, 0.03310880410884108, 0.03970453429168888, 0.011016355295266424, 0.05676016677170992, 0.047797445207834244, 0.047406120491879325, 0.039267028482364755, 0.039760313262896876, 0.02326220247362341, 0.054888947002057514, 0.030030718206294944, 0.0190709018414574, 0.015000955501039113, 0.034899610693433454, 0.05004889225321157, 0.04783945331083877, 0.03062373406386801, 0.07976847501205546, 0.08098172955214977, 0.0736942838079163, 0.04656975822789328, 0.0412097149528563, 0.03524288155936769, 0.05186667060479522, 0.04534641047939658, 0.023341124577979957, 0.015208219111497914, 0.018808827868529727, 0.022267076585974013, 0.036969790501253944, 0.024527565110474825, 0.04332495287859014, 0.053349727631679604, 0.04267231075625334, 0.024706102940919142, 0.05518553465870874, 0.02323180071211287, 0.012760478670575788, 0.06331334263086319, 0.03957424199740801, 0.05005355718146477, 0.03384823764541319, 0.042846799428973875, 0.02086697385779449, 0.05996547120490244, 0.030114211940339634, 0.06263992376625538, 0.04831762372383049, 0.04499274445697665, 0.02135451483939375, 0.03556560977761235, 0.05760153662413359, 0.030804804526269436, 0.007988899979474289, 0.030709819801683937, 0.03055955482912915, 0.006922396872791329, 0.008912006160244346, 0.011212873455536152, 0.010287113354674407, 0.08528960589319468, 0.027873280491413813, 0.016333075805700252, 0.041883208456316164, 0.031212458187448125, 0.053380505980125496, 0.022041862331596867, 0.009371264105928796, 0.007661580623659704, 0.016151418410507695, 0.03663002087601593, 0.0346082104369998, 0.11102097694362913, 0.021591420252142206, 0.0231295471811401, 0.02076983648086233, 0.024534223235345314, 0.012299470952712, 0.043887471979750056, 0.04280023496331913, 0.10608557784663779, 0.024084011857796992, 0.06394453626126051, 0.018676070795793618, 0.01906238792331091, 0.05589215424177902, 0.03277256965105023, 0.03328685848308461, 0.02357596385159663, 0.004830897070600518, 0.021482461098847643, 0.03420597148526992, 0.020954489608162215, 0.009456574617485915, 0.0288590510774936, 0.045422070526650975, 0.004619430359785578, 0.023894854954310825, 0.015667936764657497, 0.06596730343465294, 0.05234379946653332, 0.044483924617192576, 0.0822160593899233, 0.05966405237891844, 0.016831851630870785, 0.04673835721665195, 0.026125199560608183, 0.020816616381385496, 0.03221139404922724, 0.05653652502223849, 0.04887875861355236, 0.02027891469853265, 0.06429381216210978, 0.0882814432095204, 0.04017070481287582, 0.02279886992515198, 0.016614739084616303, 0.07193229121289083, 0.05880055549953665, 0.014523682450609548, 0.01157630529321198, 0.023680743229176317, 0.02304905935722802, 0.03526883891650608, 0.008444239385426044, 0.061426391026803424, 0.040590388899935145, 0.044091867083417516, 0.023127455596945116, 0.018170982898612107, 0.027412916533648968, 0.024272023733439188, 0.030738487906221832, 0.015145758266693779, 0.05739465129694768, 0.01621137885376811, 0.02126581674175603, 0.049458122346550226, 0.026989441132172942, 0.005496483520671193, 0.04493856682841267, 0.025053372074450766, 0.016593981002058302, 0.024336649104952812, 0.007374260907194444, 0.009062223635347826, 0.03219056302415473, 0.030793171043374708, 0.015595837329913462, 0.029719443659165075, 0.060759187542966435, 0.04577889512958271, 0.010497212393342384, 0.0939551969724042, 0.026325196061017256, 0.009965279106316822, 0.000946607135119848, 0.01358596995539431, 0.018996371555009058, 0.037512934034956355, 0.027445635492248193, 0.02019184169226459, 0.04187238921544381, 0.02322157349304429, 0.025942266519580568, 0.022263979073613882, 0.03206163119258625, 0.023336420633963177, 0.028924689162522554, 0.02224096655845642, 0.03173803784219282, 0.04259971429460815, 0.008607549193714346, 0.0265363544624831, 0.04269847845924752, 0.011655212130530604, 0.04277454902018819, 0.007436478327560637, 0.028842481252338206, 0.03936823537307126, 0.03312845787565623, 0.004690820725435125, 0.036121197643556764, 0.026182635853599225, 0.05078862773786698, 0.06572106307638542, 0.021349103522620032, 0.05610665612454925, 0.04272428993135691, 0.012986869335041513, 0.025482029787131717, 0.03495353047869035, 0.034985628577747514, 0.033449940982141664, 0.018370619775461297, 0.027619596603991728, 0.0364915793761611, 0.0365140185292278, 0.014358601665922573, 0.007517116277345589, 0.06245818494686058, 0.022454647413854088, 0.023732216895690987, 0.032073105219751596, 0.08316545201731579, 0.02210928326738732, 0.03886873181909323, 0.0300569469774408, 0.05339394097349473, 0.011898092892287033, 0.05986181819545371, 0.04063829007957663, 0.14985245040484838, 0.11335264039891106, 0.13676691614091396, 0.17200682232422487, 0.07794139055269104, 0.1325398465352399, 0.17753581064088003, 0.06690543916608606, 0.15433623694947787, 0.14372648697878632, 0.14420929178595543, 0.2170689028820821, 0.12627125504825795, 0.168050651039396, 0.15168863401881286, 0.0952903028311474, 0.12151593235986573, 0.16246611784611428, 0.12663507195455687, 0.16146819639418805, 0.07393508910068444, 0.158564582200987, 0.1150001369948898, 0.062486961617001464, 0.12389513397855417, 0.12670479821307318, 0.0838653337476509, 0.1644796026604516, 0.14897486035312923, 0.10172314050474338, 0.14552995163415158, 0.12688745984009334, 0.17007126047142915, 0.13373636161642416, 0.09638340917548963, 0.16894855642957346, 0.20592245885304042, 0.15806428476103715, 0.1265901800777231, 0.26845383058701244, 0.1641748318714755, 0.1220186318137816, 0.12976590038410254, 0.21412719573293412, 0.17215527221560478, 0.0991223497050149, 0.16437938303819724, 0.1637074840920312, 0.09742939804813691, 0.12887505175811903, 0.2106372865715197, 0.06602086020367486, 0.1660050715186766, 0.13151698213602814, 0.08586691705776112, 0.15679614352328436, 0.14658196589776448, 0.09880735339330775, 0.1432989692049367, 0.18004145047494344, 0.07721351246748652, 0.15377198079867022, 0.08403420075774193, 0.1474560818501881, 0.19882709958723613, 0.12015894374677114, 0.14234614319034986, 0.11136396961020571, 0.10173732188663312, 0.10479191690683365, 0.10220616922846862, 0.10272611025720835, 0.08352748437651566, 0.12907726876437664, 0.18101191840001515, 0.16889164091220923, 0.29395974480680054, 0.19523427023419312, 0.09726497544241802, 0.14462743220584734, 0.08117522059806756, 0.11745541595986911, 0.1982930518154587, 0.07827921956777573, 0.11163695103355817, 0.11398500789489065, 0.08406897567744766, 0.15169090032577515, 0.12481396538870675, 0.14196712709963322, 0.10414372597421918, 0.12389475399894373, 0.13785968321774686, 0.07250922918319702, 0.09855230565049819, 0.1094846718811563, 0.16913087878908428, 0.1138938127883843, 0.13847942996237958, 0.16621802294892923, 0.13822527788579464, 0.1047200532630086, 0.10143044763909918, 0.12010732080255236, 0.20805307238229684, 0.18033658606665476, 0.11494764552584716, 0.1525655591062137, 0.12709020610366548, 0.08207932779831545, 0.06893681694886514, 0.12864992740963185, 0.11738074996641704, 0.22922267285840853, 0.14434129398848328, 0.0990347033366561, 0.15098823660186358, 0.14179270288773946, 0.08391791342624597, 0.1259740838514907, 0.11710803317172186, 0.11748983125601496, 0.1161562656717641, 0.18206984948899063, 0.1260343241904463, 0.0984298572210329, 0.1302053060914789, 0.14202534540423326, 0.1752706164760249, 0.11334657429584435, 0.10356967856309243, 0.11802197912974016, 0.14247898677630083, 0.15599214737968786, 0.1143138123942273, 0.16640502720006875, 0.062007033798311434, 0.07485528436622449, 0.15319077484309673, 0.10419182732169117, 0.1013495594795261, 0.13207762848053659, 0.05648479351241674, 0.14527353325060435, 0.1086459279592548, 0.11440754522170339, 0.08795139020574944, 0.11378011746065957, 0.0963401932801519, 0.1998837957424777, 0.11712591935481344, 0.11512109264731407, 0.11050503248614924, 0.08269808388182096, 0.3362953359527247, 0.18050472704427584, 0.12583155078547342, 0.09057668969035149, 0.22328467720321246, 0.17623157134013517, 0.09556751152766602, 0.08552187521542821, 0.122148652694055, 0.11399894500417368, 0.12046873569488525, 0.07551978049533707, 0.08683494904211589, 0.12121474423578807, 0.2220901841563838, 0.11854346043297223, 0.1570100449025631, 0.09656755679420062, 0.21697346014635904, 0.07968806182699543, 0.13665389934820787, 0.15364987163671426], [0.054909452330321074, 0.08493381605616637, 0.028135742925639664, 0.0318831357705806, 0.027637737237715294, 0.01829425065911242, 0.04593617954690542, 0.03522146360150405, 0.011099412222392857, 0.037789128321622095, 0.026504682144150138, 0.044868793072445054, 0.014493255244035805, 0.04357091164482491, 0.02937377756461501, 0.00699051033838519, 0.04400243616795965, 0.021505186932959726, 0.007486991867023919, 0.040302401674645286, 0.07690979340778929, 0.05293596036998289, 0.022028227170397128, 0.02522083790972829, 0.0033963131011530224, 0.06845967112375156, 0.040987789896982055, 0.04156109770493848, 0.006225603324959853, 0.007863308236535107, 0.04984598992658513, 0.02422003777298544, 0.035339518516723595, 0.02102638378606311, 0.07999938726425171, 0.014052946236915886, 0.09716022320623909, 0.023208152070375423, 0.05290644409667168, 0.011843481849479889, 0.038899255716907125, 0.02413274424283632, 0.11927426978945732, 0.03543632171515908, 0.029333615076861212, 0.026497543955753957, 0.026325900041099106, 0.012298859423026443, 0.0034332190449016965, 0.056249385965721946, 0.05503393975751741, 0.03986087554533567, 0.03477585608405726, 0.06914614500211817, 0.017385415766122084, 0.044781709888151715, 0.02912249569115894, 0.033571412321180105, 0.03072677639179996, 0.027794836754245416, 0.023564267604212676, 0.04390405537560582, 0.06346552446484566, 0.038246976610805304, 0.018550458696803877, 0.02163313828142626, 0.017229695372017365, 0.021367476554587483, 0.06616437714546919, 0.0200016177924616, 0.03113532571920327, 0.05709501701806273, 0.03517809842846223, 0.0027767962102578686, 0.02731750433200172, 0.033645793329924345, 0.01664161924938006, 0.04494270249935133, 0.03130884747952223, 0.03863919699298484, 0.033523500963513336, 0.046274894050189426, 0.035293011726545434, 0.012175167578139474, 0.008493694410260235, 0.034291446541569064, 0.044862601440399885, 0.07379037793725729, 0.018901765113696456, 0.09246467945298978, 0.03535653278231621, 0.022154519500743066, 0.015394987571718437, 0.06413590349256992, 0.013831938051485589, 0.015907432484839643, 0.03591116052120924, 0.11649200479899134, 0.05118311781968389, 0.05854721087962389, 0.05101766723341175, 0.04217758408880659, 0.07143415151430027, 0.013511246286465653, 0.04343235479401691, 0.023910298411335264, 0.04233884811401367, 0.01447434108039098, 0.028780320659279823, 0.02938017275716577, 0.048356412178171534, 0.07207913976162672, 0.03181645952697311, 0.025355325246761953, 0.04369707166084221, 0.018465585840333785, 0.01920001009213073, 0.029901548887469938, 0.01289356652913349, 0.040073921970490894, 0.08437801445169107, 0.007773868839389512, 0.05925195092069251, 0.054244250524789095, 0.025211039864059006, 0.021458364623997892, 0.0037668455957568115, 0.005877150995989463, 0.011961558817087539, 0.010231033283551889, 0.04333314958161541, 0.029078173783740828, 0.050910367098237784, 0.033018715014415126, 0.029616136702575853, 0.028417402811880623, 0.00791946379467845, 0.030712812141116177, 0.08156710171273776, 0.01025766832754016, 0.01292321426860456, 0.011315659636498561, 0.05185260457385864, 0.0166468711104244, 0.013217368529045155, 0.0369478738201516, 0.10002902855298348, 0.013876434681671006, 0.03786311578005552, 0.019265663444197605, 0.036262197220431905, 0.07108662623379912, 0.04450715087088091, 0.061131106157388, 0.042448740252958875, 0.03391865940232362, 0.0375772184426231, 0.11968776902982167, 0.046303762322557826, 0.04139300422476871, 0.035225354999836, 0.026647440823061124, 0.03557574709079095, 0.06001752841153315, 0.06499004337404456, 0.01538703853397497, 0.04366266993539674, 0.030495803071452037, 0.0185540108276265, 0.04202489674623523, 0.026350651302241852, 0.022476518293842673, 0.0681719451344439, 0.01281817619954901, 0.022508110884310942, 0.01609608727241201, 0.02493133076599666, 0.07571055740118027, 0.05952573301536696, 0.02919363330251404, 0.05368639635188239, 0.02997217420488596, 0.014813276107556053, 0.013448588666506112, 0.07225789981228964, 0.05377659401191132, 0.04270159632765821, 0.04330647297735725, 0.029749119388205663, 0.023056884562330585, 0.015443092311865516, 0.033748849228556664, 0.036619788567934713, 0.05509083831150617, 0.03669438331520983, 0.05466656732772078, 0.06610351255429642, 0.010912425782797592, 0.05070270484845553, 0.016063286889610544, 0.03872608340212277, 0.02973280062100717, 0.014789976911353213, 0.023234384234196374, 0.04106332780793309, 0.024866852975849594, 0.05396012416375535, 0.020349015847646763, 0.03642632805609277, 0.02526486974342593, 0.04899388565016644, 0.028297259705141187, 0.03155058575794101, 0.009690453764051199, 0.008581838653688985, 0.038284469063260725, 0.07149974549455301, 0.08107732156557695, 0.003547651643332626, 0.052138919210327525, 0.0193337154175554, 0.0266825193871877, 0.0694726492677416, 0.021072446135804057, 0.0589123305731586, 0.029496582224965096, 0.007550516315469784, 0.02283475933862584, 0.05651466262393764, 0.06513126686747585, 0.039154466308121166, 0.01317878787605358, 0.06331849271165473, 0.04346149108771767, 0.01857654836827091, 0.08119390745248113, 0.07324364834598132, 0.03625403444415756, 0.04476578467126403, 0.04321928122746093, 0.06596696416714362, 0.0330701886809298, 0.01790920578475509, 0.04645430549447026, 0.029501518567225764, 0.0404607344285718, 0.01676873939244875, 0.06770556766007628, 0.039830504317900965, 0.0274680237551885, 0.017311531784279004, 0.014209563993582768, 0.004218877567577043, 0.06273480331791298, 0.05072984964187656, 0.03758619206824473, 0.02325602780495371, 0.036759726237505674, 0.015162289076085602, 0.052695334888994694, 0.02746956911869347, 0.010632641197714423, 0.018811791370223676, 0.015518447018361517, 0.06526510789990425, 0.05466854525730014, 0.0031889464381882654, 0.022267086763999293, 0.0018053588282782584, 0.06291124277881213, 0.04040290967428258, 0.07834707985499076, 0.02039731397027416, 0.01849933447582381, 0.03592761838808656, 0.027247886639088392, 0.10732135974935123, 0.04944350330957344, 0.05919128989002534, 0.0063753386161157066, 0.06136659173560994, 0.032514224228050025, 0.026013416005298495, 0.052360996936580965, 0.04974594333076051, 0.04182604866634522, 0.020270176863830005, 0.05531094489353044, 0.0475761240481266, 0.026742620626464486, 0.010563592626047986, 0.029945463673876863, 0.02003683884894209, 0.010943762226296323, 0.04025862259524209, 0.054743614979088306, 0.02398222142697445, 0.021506347227841616, 0.03971992346591183, 0.02955494980726923, 0.03691618284210563, 0.03613058178286467, 0.0328489930502006, 0.02865557199610131, 0.04151552729308605, 0.03414132406136819, 0.08027743055884327, 0.03240448136680892, 0.06670417210885457, 0.024839446946446384, 0.07676905167422124, 0.03196675503360374, 0.027691319451800415, 0.02263655586700354, 0.03364861603560192, 0.00780778201962156, 0.028847393845873218, 0.038072922200496705, 0.06023898867091962, 0.04200228117406368, 0.056371620656656365, 0.01719171437434852, 0.07736622355878353, 0.022137328816045607, 0.00986970151175878, 0.04344092808397753, 0.05245256184467247, 0.024525183452559367, 0.02850994820307408, 0.023307021407942687, 0.0499059961709593, 0.0663111103432519, 0.060342119208403995, 0.08290481993130275, 0.012552060702416514, 0.010456046521929758, 0.04345523499484573, 0.02774516799088035, 0.04521230481831091, 0.042417911014386585, 0.04762103288833584, 0.06936950515955687, 0.03381981720615711, 0.009616752986663153, 0.08268000770892416, 0.1045633659565023, 0.04040159331634641, 0.03254296357876488, 0.02572947963406997, 0.02446830186194607, 0.023595427628606558, 0.061447907372244766, 0.14829175200845512, 0.181507194680827, 0.18971091375819274, 0.11237046095941748, 0.0978373536573989, 0.08021696630333151, 0.11634755826422147, 0.12375132526670184, 0.18008999287017755, 0.17152869940868445, 0.1032284636582647, 0.123562380405409, 0.11380527075380087, 0.10667627650712218, 0.10756322355674845, 0.08057901901858193, 0.09970192039119345, 0.10393817057566983, 0.1683428417891264, 0.11922431604138442, 0.28685751876660753, 0.14085342043212482, 0.17299759201705456, 0.10811148663716656, 0.08659003182713475, 0.19518551070775303, 0.056771457594420226, 0.06799480678247553, 0.1262795738875866, 0.1068425379427416, 0.19271381119532244, 0.1151203734001943, 0.1501765458711556, 0.08488682072077479, 0.1916486604937485, 0.13553046248853207, 0.3016684725880623, 0.10804528876074723, 0.10022815822490624, 0.113160594632583, 0.22563741595617362, 0.16204752959311008, 0.19444422477058002, 0.16310566424259118, 0.13146567131791795, 0.1453383740569864, 0.12915050983428955, 0.11770825167851788, 0.14563493457223686, 0.1454892395330327, 0.12678854300507478, 0.12265399843454361, 0.15917287527450494, 0.15970312325017794, 0.17045866325497627, 0.1405919130359377, 0.1283345850450652, 0.08027764769004923, 0.11969235592654773, 0.18227824116391794, 0.19506032099681242, 0.15571856206016882, 0.15170441674334662, 0.09491182956844568, 0.09300904774240085, 0.07295971536742789, 0.11151622608304024, 0.10230084521962063, 0.16594070568680763, 0.0996837220819933, 0.0749138622943844, 0.1491679171366351, 0.21445249899157456, 0.10402718758476631, 0.10847997864974396, 0.1982832673404898, 0.11297536135784217, 0.10198502788054091, 0.10559224896132946, 0.09634599475456135, 0.0651367630011269, 0.12634480824427946, 0.11643195444984095, 0.09840481249349457, 0.18904354742595128, 0.11612631513604096, 0.07879823778889009, 0.2087947925818818, 0.15701278618403844, 0.1578180036906685, 0.06203676041747842, 0.15179265343717166, 0.09721467564148562, 0.1994202206177371, 0.13690547299172195, 0.12425938514726502, 0.14449875482491084, 0.25175657655511585, 0.11386348227305071, 0.10218867659568787, 0.12410865537822247, 0.1344021266060216, 0.13013955604817184, 0.04170545942283102, 0.1317686372037445, 0.15877848358026572, 0.08296647162309714, 0.1341600931648697, 0.0976983489734786, 0.18625243433884212, 0.09497730141239506, 0.1000053748222334, 0.1576260325631925, 0.11734402765120779, 0.11204712545233113, 0.09351885824331216, 0.12484660292310373, 0.11151558147477252, 0.1485388201794454, 0.18060436312641415, 0.13828310264008387, 0.09073138888925314, 0.1720984788345439, 0.0972022855920451, 0.16262497646468027, 0.17007922647254808, 0.13488647847303323, 0.11641382399414267, 0.217480420800192, 0.14517563421811375, 0.1748389732092619, 0.1876167647008385, 0.15028930482055458, 0.10300191438623837, 0.143025723152927, 0.102747674100101, 0.09176943890218224, 0.079964904114604, 0.09854046521442276, 0.06804495052035366, 0.06346229463815689, 0.11301482495452676, 0.122046044628535, 0.123776946749006, 0.1144334924008165, 0.09608334741954293, 0.17251158452459744, 0.0832443181425333, 0.1645157550062452, 0.13417287676462106, 0.09427096681403262, 0.13043615727552346, 0.08535492167408977, 0.15355559598122323, 0.2101834009268454, 0.13077417628041335, 0.17797437496483326, 0.20034914862896713, 0.15941866779966013, 0.10464299882629088, 0.1061318132228085, 0.14577681624463626, 0.14169628306158952, 0.1944038655076708, 0.09873685360487018, 0.13652338992272103, 0.12368732584374291, 0.11097593578909125, 0.2486623211630753, 0.1670242039752858, 0.1114718159660697, 0.09361286248479571, 0.11993850128991262, 0.09504233899393252, 0.17574575383748325, 0.09617223550698586], [0.037434641271829605, 0.01747659730192806, 0.035593046341091394, 0.03101977120552744, 0.025030785340017507, 0.03852074174210429, 0.029063262976706028, 0.011405464594385453, 0.01049870771488973, 0.006472294484930379, 0.049955739573176415, 0.018726618262007833, 0.07830505818128586, 0.03787998755329421, 0.03555116715974041, 0.0226113499873983, 0.01799471476780517, 0.041568921213703494, 0.016004644500623857, 0.022421458569754447, 0.023637958203575442, 0.02974960793341909, 0.03673477650486997, 0.07039103284478188, 0.045612721903515716, 0.036313816771975586, 0.04755822429433465, 0.016184240845697265, 0.04509061295539141, 0.015089404237057482, 0.04791271134412714, 0.013491994551649051, 0.053934241445469, 0.03130966850689479, 0.04747673223859497, 0.02573882645395185, 0.07648621792239801, 0.06522485041724783, 0.026542610555355037, 0.0026338625965373857, 0.05014546135706561, 0.01803407658423696, 0.038311484935028214, 0.047296849212476184, 0.06555121219051735, 0.04645812903930034, 0.026962094474583864, 0.026203880785033107, 0.06424849959356443, 0.026343631857473935, 0.1023437829156007, 0.03346278565004468, 0.010041429395122188, 0.01035624080603676, 0.026107136958411763, 0.09189462861312286, 0.018096040402139937, 0.030101204424032142, 0.11496113480201789, 0.05180560923846705, 0.03175703003736479, 0.04604024985539062, 0.0023117141016492887, 0.03336194177557315, 0.010131096949667802, 0.008581672412609416, 0.03111874571602259, 0.03531665188659515, 0.08863008128745214, 0.04861973126285842, 0.020978994900360703, 0.025792771684271947, 0.04251333000138402, 0.06687284234379019, 0.03054615036983575, 0.016494392417371273, 0.047680394524442296, 0.04432126280984708, 0.021396935152422105, 0.05343519250995346, 0.02209037249641759, 0.04762084289853062, 0.06448228883423976, 0.0577957129904202, 0.04081989997731788, 0.038905728940985033, 0.032279013456510644, 0.0330845939793757, 0.06286167579569987, 0.08605364989489317, 0.04521038456420813, 0.018484852842188308, 0.020124817699460045, 0.0761119651475123, 0.029450730221079927, 0.02031045300619943, 0.05978447198867798, 0.021917524182104638, 0.007148414767081184, 0.04144368400531156, 0.04404590651392937, 0.06238157834325518, 0.07633477569158588, 0.05202479301286595, 0.0417116476622011, 0.032130234475646696, 0.037107407581061125, 0.039243775087275674, 0.03763748931565455, 0.03550381898613913, 0.03898996227820005, 0.021484661248645613, 0.02947933386479105, 0.08151372136282069, 0.027183921142880405, 0.0834537208346384, 0.02670989997152771, 0.03433892363682389, 0.062272612404610427, 0.029918308702430556, 0.0624206755310297, 0.055490902558501275, 0.050074330531060696, 0.041080131727669916, 0.054291432457310815, 0.0339735935974334, 0.011397222090246422, 0.012539207552825766, 0.04621120336066399, 0.03223927166046841, 0.027450726201225604, 0.03129800109724913, 0.012358535729747797, 0.06967220641672611, 0.04500679013186267, 0.07120624517223664, 0.0400088097501014, 0.02986287578408207, 0.041942325819815905, 0.05456081425238933, 0.028568617733461515, 0.0978907747194171, 0.08683543080197913, 0.02602733445486852, 0.04120649530419281, 0.013440017072883035, 0.005916341482329049, 0.021601426947329725, 0.025613940387432064, 0.05241594130971602, 0.02662980230525136, 0.08820858211921793, 0.008074719392295395, 0.04745273245498538, 0.04907978139817715, 0.004412185409039791, 0.021124657709151506, 0.06775684455143553, 0.04889051423275045, 0.024289261915587952, 0.040355347762150426, 0.036463606770017316, 0.02854073333687016, 0.019406612130946348, 0.011490243304121708, 0.004403836459719709, 0.02980302899543728, 0.025983066830251898, 0.010128882381000688, 0.007976291950659027, 0.003492528942712982, 0.023786475948457207, 0.07760231981852225, 0.04588140820020011, 0.05018694020275559, 0.035443446332854886, 0.08647556975483894, 0.022686843793573122, 0.01155210194909679, 0.021508028298350315, 0.029861053917557, 0.009496417345612176, 0.0076162298875195635, 0.061593656694250445, 0.033031827703650506, 0.03912987619904535, 0.06319537931787116, 0.029043127450027635, 0.03969777608290315, 0.03481555038264819, 0.00931269720396293, 0.03357567691377231, 0.057903952896595, 0.02494222634205861, 0.0270425008742937, 0.00866883447659867, 0.018542574119887183, 0.03286510147154331, 0.05925900089953627, 0.118549092273627, 0.08007257405136313, 0.04242540543366756, 0.06551533125873123, 0.04723701599453177, 0.03462909574487379, 0.004181641262091164, 0.012456640867250306, 0.02691342485403376, 0.08301934985710041, 0.0508052823798997, 0.03955832017319543, 0.011490450257302394, 0.06157552623855216, 0.028051489232374088, 0.06560757809451648, 0.014669462306691068, 0.049657017923891544, 0.003188553948088416, 0.018474020030615584, 0.033440478811306615, 0.1078741622290441, 0.02080676574925227, 0.05400010344705411, 0.04344440218327301, 0.015529569903654712, 0.06450409694973912, 0.0226857004620667, 0.017471459095499346, 0.016563353627654057, 0.034740914923271964, 0.017661413277632425, 0.011897976693165089, 0.04367164695369346, 0.08027652810726847, 0.05672675910006676, 0.011197352815153343, 0.05318518628233245, 0.023840280382760932, 0.02545542103637542, 0.005933069915045053, 0.06918789526181561, 0.05044916345338736, 0.08382824502353158, 0.024810906067224484, 0.012398715180877064, 0.018283073491017734, 0.03557096002623439, 0.0456954115735633, 0.044019131522093496, 0.04704142488273127, 0.015464193054607936, 0.016885372776804224, 0.07092555559107236, 0.012111613443786544, 0.03734621798087444, 0.024415969848632812, 0.005023838927237583, 0.04511175610657249, 0.014793846257297056, 0.06571034900844097, 0.022509769902431538, 0.05313749544854675, 0.06997757431651865, 0.021256269754043648, 0.028874009381979704, 0.009899669859026159, 0.056607693167669434, 0.02917836287191936, 0.018116864641862254, 0.06327503932906048, 0.016877952996375303, 0.06999097538313695, 0.04246174098391618, 0.014866390132478305, 0.0375083403528801, 0.04101325870890703, 0.03402418516842382, 0.056799654117120166, 0.09439674006508929, 0.014581393550283142, 0.058627664776785035, 0.021619023056700826, 0.0604419181389468, 0.04413629077108843, 0.016927891477410282, 0.028464862943759987, 0.03233304520004562, 0.017199086657326137, 0.021155544623200382, 0.05725163647106715, 0.03286017191463283, 0.040452941453882625, 0.04465143455724631, 0.08063316611307007, 0.05186600564047694, 0.06365385185927153, 0.029342293539749723, 0.03523226587900093, 0.03805324129228081, 0.041990966602627716, 0.045996687907193384, 0.002732765648813386, 0.02858620536114488, 0.025506942200341394, 0.01721390925480851, 0.05018758141834821, 0.009524423030338116, 0.06807556602039508, 0.09362601249345712, 0.07489592861384153, 0.06076508401227849, 0.058693061981882365, 0.02568645203219993, 0.007404504061144377, 0.027672948116170507, 0.02050147588098688, 0.009813583273041462, 0.05925989656576088, 0.041224836105746884, 0.0422833575201886, 0.03430265254740204, 0.08982239623687097, 0.016137038557124988, 0.008468084802318896, 0.016163789800235202, 0.0473375070307936, 0.04382895851241691, 0.02421601745299995, 0.017032295964392166, 0.05713156291416713, 0.009935015596316328, 0.021290605322324803, 0.059329107137663026, 0.02300479682162404, 0.0488022809316005, 0.0176624785776117, 0.04858001321554184, 0.018752928457355926, 0.012606245964499456, 0.06276291502373559, 0.05919265374541283, 0.014929631292553884, 0.027387479952137386, 0.05487738137266465, 0.007561731651159269, 0.028494345290320258, 0.008329644998801606, 0.05380240548402071, 0.06173928387995277, 0.04291452740186027, 0.00984944384877703, 0.049249995300280194, 0.2971435125385012, 0.21948059275746346, 0.11384422544922147, 0.13201242126524448, 0.15322817569332464, 0.21226913614996842, 0.13111938775650092, 0.11766626393156392, 0.13691892155579158, 0.16527751913028105, 0.2021475514130933, 0.09536353033035994, 0.2344975226691791, 0.18000835153673375, 0.09245821979961225, 0.15324549190700054, 0.09065417160413095, 0.19863770689283097, 0.0991024754143187, 0.0612658021439399, 0.08624566851982049, 0.1275693739631346, 0.11807197358991418, 0.2409055531024933, 0.15790660679340363, 0.1667439147297825, 0.1262000902955021, 0.07934772223234177, 0.12603747259293283, 0.12437233408646924, 0.10645390701081071, 0.057383496181241105, 0.1490392397556986, 0.22628722180213245, 0.0908514420901026, 0.10245852318725415, 0.1697647390621049, 0.09839717218918459, 0.12117769622376987, 0.05886486704860415, 0.12647780110793455, 0.08569153611149107, 0.1172326257718461, 0.17729175516537257, 0.16506288493318216, 0.10836031899920531, 0.2112907293651785, 0.1655233795089381, 0.12393128632434777, 0.19406587364418165, 0.1397436492677246, 0.06426247062959842, 0.14811373156096252, 0.09151690852429185, 0.10775555430778436, 0.23194386969719613, 0.09985901481871094, 0.1204864861709731, 0.14042215714497225, 0.11588187968092305, 0.15241895483008452, 0.17439358282302106, 0.13713656844837324, 0.0869565357321075, 0.15707382719431603, 0.08777314584170069, 0.18428796689425195, 0.09453286776053053, 0.13496578564601286, 0.10652011167258024, 0.20990630079592976, 0.19505227357149124, 0.1775237870003496, 0.15358219455395425, 0.11539661857698645, 0.0758175759443215, 0.202117777296475, 0.18254168917025837, 0.13261406469557965, 0.10905623129968132, 0.19594290506626877, 0.13822090812027454, 0.11247473143573318, 0.16538598973836216, 0.14529707841575146, 0.14226532966962882, 0.13681146875023842, 0.08013479571257319, 0.11575453222862311, 0.13714108749159745, 0.18060506880283356, 0.14323976023920945, 0.12891209977013723, 0.16303715934710844, 0.14119230796183857, 0.20994600866522106, 0.10750327498785087, 0.161220517541681, 0.09754172273512397, 0.10221246603344168, 0.163596937166793, 0.22055984341672488, 0.1589318189237799, 0.15526474426899636, 0.12811658531427383, 0.05404366200257625, 0.11687705985137395, 0.1141269574207919, 0.09907630431864943, 0.12717487370329245, 0.1536015463726861, 0.07654263132384845, 0.10898913097168718, 0.12878697791269847, 0.09818960154162985, 0.1583587961005313, 0.12068752252629825, 0.1395005030291421, 0.1225448628621442, 0.15949512512556144, 0.2018376916114773, 0.147103718615004, 0.10937968894307103, 0.10659445196922336, 0.12731955093996866, 0.09386171520288501, 0.1178899769272123, 0.13472992687353066, 0.1526266136871917, 0.11072245546217475, 0.21622696306024278, 0.16367031394370965, 0.1782831083983183, 0.20073717566473143, 0.15120531352502958, 0.11162265430071525, 0.1897921615413257, 0.14701462696705545, 0.1007614324667624, 0.16673252891216958, 0.07219615991094283, 0.14602863416075706, 0.1387301350810698, 0.17558295971580914, 0.08685722534677812, 0.1629018730350903, 0.09091466119779007, 0.07125548645853996, 0.08045241116945233, 0.16239534664366925, 0.0954579756196056, 0.1247231774032116, 0.1021099393921239, 0.15167956879096373, 0.06924346727984292, 0.11329557560384274, 0.2590217595653874, 0.18711220606097154, 0.12066913422729288, 0.08572954085788556, 0.1620634344539472, 0.08608005847781897, 0.05472331999668053, 0.1039345675547208, 0.21325651316770486, 0.07284813706896134, 0.16133698129228183, 0.06951337493956089, 0.15503036470285483, 0.1464964026319129, 0.11669932438858918, 0.06689927128276654, 0.1738885763500418, 0.2247993437839406, 0.09905883204191923, 0.11308687858815704], [0.014175060487884496, 0.05050444709403174, 0.03602864546701312, 0.047728750322546275, 0.018312550748565366, 0.039226679397480826, 0.03053665766492486, 0.0036098160531504875, 0.031075350008904934, 0.03652781993150711, 0.032555302738079, 0.06419431857232537, 0.037809894885867834, 0.026373366958328655, 0.03166298847645521, 0.003388237262177946, 0.03642224327528051, 0.0460083790655647, 0.04500093437465174, 0.05576564817290221, 0.06615103036165237, 0.05431377322279981, 0.010276431517143334, 0.01244446201183434, 0.04642585791381342, 0.05230825440958142, 0.033081068989953825, 0.04696723047111716, 0.04395774785163147, 0.04595901903563312, 0.0193786480064903, 0.017546221780191575, 0.05804844692881618, 0.05068772618791886, 0.08736367031399693, 0.023586699971929193, 0.050213192722627094, 0.029561585879751613, 0.006620425888935902, 0.018291024225098745, 0.016290360329938785, 0.04630365036427975, 0.022331323674214736, 0.06122263374605349, 0.024124215057651912, 0.056176911640380106, 0.08446612900921277, 0.03444872756621667, 0.016497961511569362, 0.018080442578398755, 0.03577384538948536, 0.009251793597026594, 0.05513270731483187, 0.039886195079556534, 0.06043757551482745, 0.048947046377829144, 0.008154130041865366, 0.03933846125645297, 0.010620983117925269, 0.005341973463405988, 0.06478095959339823, 0.03485315818605678, 0.02644381416030228, 0.06929612838264022, 0.015152984664642384, 0.04617652004318578, 0.04328725008027894, 0.03669453598558903, 0.050418507241244824, 0.06517247429915837, 0.030854720954916308, 0.012580279277504554, 0.039395403915217946, 0.02240449349795069, 0.02102039910719863, 0.020512225572019815, 0.04212063125201634, 0.011590024423120278, 0.028000358226043836, 0.08482428014810596, 0.01907320716418326, 0.021682912217719213, 0.05602965936330812, 0.07016648525106055, 0.02956775376307113, 0.007062888396571257, 0.046313204137342315, 0.05898063190813575, 0.07394426967948675, 0.06515439812626157, 0.05383307865953871, 0.015531050806332911, 0.0687705622985959, 0.06639275167669569, 0.04750866409657257, 0.00503734007777114, 0.005430452733500195, 0.05701676835971219, 0.06301897378372294, 0.017298866928155934, 0.03130217069493873, 0.03399051286812339, 0.02010022589404668, 0.011662121313357992, 0.030279333437127725, 0.022360850125551224, 0.010579595874462808, 0.05555612673716886, 0.0280168177892587, 0.017261221805321317, 0.02604530206216233, 0.09567983621465308, 0.046595427207648754, 0.06625264776604516, 0.040732582698443105, 0.030373045908553258, 0.03582650309960757, 0.036504793845649273, 0.019527048704081347, 0.024893485475331545, 0.04129495591457401, 0.07197851301836115, 0.03098094543176038, 0.027774421331871833, 0.017575890723881975, 0.08951548127723591, 0.06126745776938541, 0.05296018746282373, 0.018783094427947487, 0.10602523572742939, 0.030369866971990893, 0.0374203377536365, 0.014320578259815062, 0.05519046760829432, 0.036658722907304764, 0.03272906198565449, 0.05590142981548395, 0.022156991064548492, 0.009656278499668198, 0.04740638851321169, 0.017871811719877378, 0.061217972210475376, 0.06492161311741386, 0.0017486493099048467, 0.08582515322736331, 0.01838068075345031, 0.010318884908753847, 0.0036618071026168764, 0.046492238994687796, 0.021170979598537087, 0.05817313452384301, 0.04727551607148988, 0.019132729952356646, 0.04167342917727573, 0.036453408388687034, 0.04627153869452221, 0.018128623653735434, 0.031472360848316124, 0.024409221817872355, 0.023892836312630346, 0.031573703446026356, 0.08929655873881918, 0.04759488214871713, 0.028927379553871493, 0.017741712808076824, 0.03722658207906144, 0.048172756497349055, 0.03734730702957936, 0.0703120513686112, 0.01838414297838296, 0.023798353703958646, 0.02265187549138708, 0.029782998641686778, 0.02597044947158013, 0.028699086446847235, 0.07120178041181394, 0.040743266232311726, 0.07106143901390688, 0.03426516009494662, 0.05304598821593182, 0.024464147531294396, 0.011060028353572955, 0.013798428599589636, 0.0076597536681219935, 0.01617612217419914, 0.014124441775493324, 0.03888147131406835, 0.051957397522138696, 0.039702597074210644, 0.024244965453233038, 0.02155115598413561, 0.01749408823837127, 0.026382488165316836, 0.04998372575002057, 0.024228149659133384, 0.027335244630064284, 0.04169193621990936, 0.028535013286662952, 0.020004757713260393, 0.012653606860632343, 0.03516844966049705, 0.04185091358210359, 0.04947715186114822, 0.03104648512921163, 0.02358744296777461, 0.026457775018310974, 0.01517013633357627, 0.0780911228752562, 0.11189659245844398, 0.08746897216354098, 0.034937459376773665, 0.023089191310905983, 0.06450404266693763, 0.025385002672140087, 0.05801954812237194, 0.03873991533847792, 0.015719296776556542, 0.030241868126073053, 0.04595090375681009, 0.029844965852264847, 0.04269183560141495, 0.005703193276921021, 0.03399800728740437, 0.04717040421175105, 0.03076198896659272, 0.09149824881127902, 0.06876447583947863, 0.06906330266169139, 0.047781357142542086, 0.019522254854174595, 0.0453217525168189, 0.03549831945981298, 0.013689997855440846, 0.011910425266250968, 0.012250752138373042, 0.04249454815206783, 0.04810651112347841, 0.037206819746643305, 0.034285200626722405, 0.06600165087729692, 0.04683594412303396, 0.04936982458457351, 0.020268986034872274, 0.022595789483083144, 0.03197613238756146, 0.054329464345106056, 0.07523489756775753, 0.02990615274757147, 0.0030394117389472997, 0.02792545304899769, 0.040987487948898754, 0.008930099296516605, 0.04474850916968925, 0.08222859193171773, 0.030800316017121077, 0.027499277078147446, 0.03570960169391973, 0.033335770679903884, 0.07768972869962454, 0.04449770227074623, 0.027814232677753483, 0.03312274461079921, 0.04426007591454046, 0.06438894955707447, 0.018724307850269333, 0.06875277111040694, 0.030084390326270034, 0.04350878497851746, 0.019527179322072437, 0.06807802910251276, 0.01983035385741719, 0.07810967402266604, 0.04580948009554829, 0.03714322744469557, 0.04596915634881173, 0.02662220610571759, 0.021242844938699688, 0.05646251381507941, 0.10215204249003104, 0.009201932299349989, 0.02257119767766978, 0.03187570920480149, 0.034764714539051056, 0.016546960221603513, 0.013381899700367024, 0.032122339720704725, 0.011525749345310032, 0.032447273177759986, 0.036792055038469176, 0.08182812734906163, 0.03456303018278309, 0.010814484341868331, 0.04464025908548917, 0.014824142845879709, 0.039016238546797206, 0.023123063779036914, 0.0413591690760638, 0.0441226997146649, 0.045765131046729426, 0.01462862637293126, 0.030048516179834093, 0.053100338870925565, 0.05654400587081909, 0.05737845466605254, 0.009477862805527235, 0.01432004221715033, 0.012628296656267983, 0.014756762622190374, 0.03912039706483483, 0.026931046408468058, 0.030515694325523715, 0.04515044278066073, 0.011633982466134642, 0.019919913694528595, 0.04289195254178984, 0.03195674664207867, 0.026633961724915674, 0.08741546967732054, 0.06879637377070529, 0.035616842564195395, 0.04684534522571734, 0.015726312828649367, 0.012284465998943363, 0.0537190237082541, 0.030884817375668457, 0.007879824627057781, 0.04820565866040332, 0.011212407810879605, 0.03890739813713091, 0.029213507593210255, 0.04545472163174834, 0.030970197437064986, 0.0646470846342189, 0.010438928779746805, 0.05646348072748099, 0.05748146306723356, 0.05210693646222353, 0.054421768856367896, 0.020503789685400467, 0.016673395044303367, 0.0394366418809763, 0.006296821088264031, 0.0425592770001718, 0.05308006763724344, 0.07406009560717003, 0.01692922649505947, 0.05632760748267174, 0.03714720365990486, 0.038188873657158444, 0.02103433452014412, 0.020881872790466462, 0.03088422365752714, 0.09168764150568418, 0.1684411886547293, 0.08007636027676718, 0.16074957352663788, 0.10173498094081879, 0.1350342362586941, 0.12034729149724756, 0.14199004801256315, 0.10799593212349073, 0.08662535636020557, 0.13890804696295941, 0.13207267517490046, 0.14727487228810787, 0.08834740359868322, 0.11900160727756363, 0.10617009616856064, 0.11965422225849968, 0.14663334456937654, 0.21515404991805553, 0.1359548590012959, 0.1475920466972249, 0.08084104210138321, 0.10891586276037352, 0.15714499194707188, 0.14327528833278588, 0.11763046442398004, 0.1272619975996869, 0.13628677119101795, 0.14102920171405586, 0.12026320743773665, 0.07886892756713287, 0.172944557719997, 0.19628821153725895, 0.1811672214950834, 0.12513939078365052, 0.09518771512167794, 0.17141608973698957, 0.09806448646954127, 0.06942982692271471, 0.10935164509075028, 0.09647256867694003, 0.13080314972570964, 0.16888083863471234, 0.11119079390274626, 0.13096955365368299, 0.1114494718079056, 0.17238344997167587, 0.11801511235535145, 0.06253064570150205, 0.1787645968475512, 0.08605039971215384, 0.12125389570636408, 0.18978165781923703, 0.19330219605139323, 0.20268799098474638, 0.1179989225098065, 0.06918514719499008, 0.08595026829945189, 0.12343687856835978, 0.10340385138988495, 0.15796045533248357, 0.13090901475931915, 0.09716605182204928, 0.19668907645557607, 0.12749055533536843, 0.15909302527351038, 0.1209593436547688, 0.10482545010745525, 0.07139014173299074, 0.1933994979730674, 0.11845755789961133, 0.10418841429054737, 0.15077829786709376, 0.13615941016801766, 0.16605142903115067, 0.09636473589177642, 0.18880866574389593, 0.15132260508835316, 0.13442263193428516, 0.24837025254964828, 0.07066280647580113, 0.11867262635912214, 0.16633004908050808, 0.11039236853165285, 0.1067482012190989, 0.08733309552605663, 0.18807168171874114, 0.19434278378529207, 0.14824521807687624, 0.15665526608271257, 0.12572318874299526, 0.18727873212524823, 0.12942834278302534, 0.14367105066776276, 0.07442178869886057, 0.15587081174765313, 0.10572783382875578, 0.22348097738410744, 0.11455098752464567, 0.07160571909376554, 0.06989679472254855, 0.15117089822888374, 0.1564125269651413, 0.059726810082793236, 0.1528250580387456, 0.07940189646823065, 0.11805406026542187, 0.1368403472006321, 0.15915600689394133, 0.14779553934931755, 0.0785105185849326, 0.16416378532137188, 0.17641075886785984, 0.16311356239020824, 0.12849294154771737, 0.21178159516836914, 0.10062454481210027, 0.14828959426709584, 0.12340109263147626, 0.08273040929010936, 0.14036126541239874, 0.1626227508698191, 0.14556944237223693, 0.18938098289072514, 0.16124408984822886, 0.1474437460835491, 0.18026528560689517, 0.1777351913707597, 0.07858758659235068, 0.15762637183070183, 0.20235364963965757, 0.15393067656883172, 0.1138859282114676, 0.17672321067324706, 0.15480648885880197, 0.1367887242564133, 0.09673499888075249, 0.09718477938856397, 0.09581097667770726, 0.13928095623850822, 0.12234196732086794, 0.13491454268140451, 0.17020209559372493, 0.1612518522888422, 0.1929555189396654, 0.11855662401233401, 0.10511318288211312, 0.1126844733953476, 0.1614448819309473, 0.16410844400525093, 0.14993234111794404, 0.08067605631159884, 0.07316511470292296, 0.08691454119980335, 0.14972875347094877, 0.15960892901888915, 0.10436972563288041, 0.08130002354404756, 0.12054748646914959, 0.08740916608699731, 0.10631537730140345, 0.18932439307016985, 0.14781622109668596, 0.12025969262634005, 0.10239510051906109, 0.08704296752278294, 0.18382880224713258, 0.07185852767101356, 0.23227575474551745, 0.10082025466752903, 0.22004506603947707, 0.10065769803311143, 0.1867303672645773, 0.16363819209592684, 0.11975619250110217, 0.11358159168490342], [0.047298179141112735, 0.061782716906496456, 0.035022988715874295, 0.022516607839081968, 0.06349806021898985, 0.04679671462093081, 0.03133528659652386, 0.022434440640998737, 0.03163651204002755, 0.018493507556351166, 0.050871700780200105, 0.022051592523764287, 0.04772636866463082, 0.07117330229708127, 0.035987661951886754, 0.02344490820541978, 0.029990637142743384, 0.043155739815639596, 0.052913466934114695, 0.001616679655853659, 0.016435979033953378, 0.03606795300064342, 0.03066921965884311, 0.04579431823055659, 0.024435370861153518, 0.024726684604372298, 0.035485386582357545, 0.02787199636389102, 0.02635323312798781, 0.02657211495430342, 0.014639138576707669, 0.019104224696223224, 0.0021568297899128602, 0.09819192213139363, 0.04095461631992033, 0.03176893832694207, 0.03371556030054178, 0.03862104957391109, 0.006341429252643138, 0.01721491348663611, 0.012999694495062743, 0.07555175985076598, 0.05151980011058705, 0.04589646149958883, 0.029848484056336538, 0.024674228758418133, 0.0471830826385745, 0.05013189744204283, 0.026079678342544606, 0.04980326257646084, 0.042417985653238635, 0.033732523676007986, 0.03375436571825828, 0.028450635760756474, 0.020834025893626467, 0.014459737310452121, 0.04763958403574569, 0.03787624203999128, 0.028708012575017552, 0.052254826562213044, 0.03077794811023133, 0.08320324641785451, 0.02417825528287462, 0.024180112772488167, 0.019526404095813632, 0.03073098330891558, 0.055039021984807084, 0.027682895439543893, 0.024735522522990192, 0.02250207701165761, 0.03768363308959773, 0.07342240839664425, 0.05894086975604296, 0.044127581774124076, 0.05088402636881385, 0.056500949431210756, 0.01064535609579512, 0.04199643559487803, 0.04659627198374697, 0.013480841132280017, 0.008245084268440093, 0.016475581730316793, 0.029528585329119648, 0.09424118591206414, 0.07940819327320371, 0.08087819189365421, 0.052870759940040965, 0.04745037115312048, 0.021504369298262254, 0.03057004158784236, 0.08161451095449072, 0.0661513696291617, 0.020420092390850186, 0.03651741798967123, 0.016302808054855893, 0.03756208032635706, 0.06954397008355175, 0.022080635518899987, 0.03464996408937233, 0.026982106168621352, 0.11021709615098578, 0.01670794265477785, 0.03644904201584203, 0.0675511805872832, 0.09065923347537007, 0.03699978853442839, 0.026865021558478475, 0.01939254440367222, 0.08014981847788606, 0.05264069924929312, 0.010899349564819463, 0.08241509406694345, 0.005364739161450416, 0.025299693856920515, 0.030358247059796537, 0.03553003079390951, 0.02780249571826841, 0.022004105250484178, 0.027932318127048866, 0.019504256712804948, 0.06918186308549983, 0.03165992149817092, 0.04809296417183109, 0.01312180535335626, 0.03427115834451147, 0.009320887121638017, 0.019970327150076628, 0.030580904933490922, 0.04593475801604135, 0.021749250890154923, 0.0432801899234099, 0.028839461771505218, 0.03336692222261003, 0.029909067055476562, 0.03644855007795351, 0.023541857288884263, 0.011545016347164554, 0.01883317031232374, 0.0314953665781234, 0.05205183941870928, 0.02418139690001096, 0.027689085375251513, 0.02803031724345471, 0.054099661497665305, 0.03261573306683983, 0.04748877284250089, 0.03585630435762661, 0.015808798938191364, 0.022747513305928026, 0.057326770653682094, 0.0726081392328654, 0.019745363953656385, 0.026626808269481574, 0.027521792566403747, 0.0191314475211714, 0.015524964347215635, 0.04293935499819262, 0.024468837904610803, 0.023263294915003434, 0.039121594679142745, 0.07414633740804025, 0.030344632254647355, 0.015714726843205944, 0.017988962487184575, 0.024184129699798565, 0.020595704039026583, 0.02604853697786374, 0.04678588180935808, 0.032689442325915606, 0.0422570032200643, 0.039672517616833956, 0.030463019652026038, 0.037917276445244036, 0.0718554946194802, 0.03823547204956412, 0.07157420114214931, 0.03093884911920343, 0.0394609911101205, 0.019272506469860673, 0.061076409449534755, 0.027655112823205333, 0.04246747799749885, 0.062068678704755645, 0.0382080219153847, 0.03652908879199198, 0.03692079009488225, 0.0794715073757938, 0.0068695339058259764, 0.043686903813587766, 0.060808835950280936, 0.030649365724197457, 0.015949498263320754, 0.05894816400749343, 0.013918170522499298, 0.035852273859615834, 0.002329450158867985, 0.00896217449501689, 0.04550146251650793, 0.05506247554772666, 0.034598924685269594, 0.038023029520575485, 0.005203253764193505, 0.03427469690463372, 0.00985541326060359, 0.04352376024637904, 0.07302705318267856, 0.06839927472174168, 0.028790617428187813, 0.03118970012292266, 0.07874118656452213, 0.03292440543217318, 0.03649569129837411, 0.019408528992374028, 0.01567286971424307, 0.012704166201209384, 0.01532419940589794, 0.02163494488091341, 0.07853066428963627, 0.02220218997847821, 0.026563862272139107, 0.03351480892992445, 0.0427047141960689, 0.04242377355694771, 0.028500499602939402, 0.00756393519363233, 0.056522106153092215, 0.0037441897355685277, 0.011896910545017039, 0.015973966236093214, 0.01925430476798543, 0.060710489084678035, 0.03315038473478385, 0.014440229428665978, 0.043375720868685415, 0.031052809075585434, 0.01876515056937933, 0.054950069436537366, 0.0599386351449149, 0.021773226925038865, 0.039458276970045905, 0.019211095657997897, 0.08813477786523954, 0.009328729290116047, 0.006054114201106131, 0.019924227480909655, 0.10890360163258654, 0.06382879175777946, 0.03488355655489223, 0.025823265048010007, 0.02964919153600931, 0.026805220570947443, 0.05329775863460132, 0.026996893143015246, 0.030658627727202008, 0.031796568272901435, 0.043990076652594974, 0.07484801725617476, 0.004808066487644932, 0.04603756285671677, 0.050108881534210274, 0.07228806747921876, 0.05606089911556669, 0.01449644096594836, 0.04120009671896696, 0.02983919151925615, 0.002704451442696154, 0.03706216286601765, 0.012337367133503514, 0.03738888765552214, 0.06692098440336329, 0.023752961407548616, 0.006668855901807547, 0.028606100007891655, 0.04770404825519238, 0.035403670610061715, 0.0026566654019656456, 0.06249707178877933, 0.050895758239286285, 0.032102543461535654, 0.059782443168972216, 0.06300015800765582, 0.016349735536745617, 0.01608806529215404, 0.030237087846866677, 0.057460157067648, 0.017530428877632533, 0.048932081287992854, 0.05120894286249365, 0.027251308151919926, 0.02968266366847924, 0.057639731360333304, 0.021235509975148097, 0.025994980208841816, 0.04702522146648594, 0.030878171125160794, 0.01268619011222784, 0.06925022548862866, 0.04626409855804273, 0.018934236407013874, 0.015729602027152265, 0.05840940720268658, 0.003154128898001675, 0.042197254818997214, 0.03243890005562987, 0.0735369926052434, 0.022677922754415443, 0.03169078805616923, 0.03382861780534897, 0.01643424537698073, 0.059543605627758164, 0.029635295138827393, 0.0017600260097034542, 0.08172644887651716, 0.03536388810191836, 0.09952276679021971, 0.010195442425486232, 0.009406587790830858, 0.019622357429138253, 0.06647018609302384, 0.03426891917894993, 0.007929590081663003, 0.04708810130666409, 0.028722098962004696, 0.04099311639687844, 0.022285324088963013, 0.07678881061396428, 0.02681750544746007, 0.029195770687822784, 0.03498597802328212, 0.0534538488302912, 0.03358486427792481, 0.037007262597658803, 0.06388916101838861, 0.03272009514538305, 0.05997455678880215, 0.04956163964899523, 0.05767344098005976, 0.02799045161477157, 0.04649317537301353, 0.04213884313191686, 0.009908428049779363, 0.07208386915070669, 0.02683921517538173, 0.07011171390435525, 0.02445654454641044, 0.023714809079787562, 0.025549364209707295, 0.01768177611354206, 0.02822917719770755, 0.019447122367897203, 0.02360721887089312, 0.033100821144346676, 0.15054214053920337, 0.15177991054952145, 0.11752757137375218, 0.13231743632682733, 0.14659074614090578, 0.12901223796818936, 0.07551002316176891, 0.11266028362193278, 0.17036395333707333, 0.10808131897023746, 0.22507484257221222, 0.11424093773322445, 0.19589314130800112, 0.21699701888220652, 0.082451063208282, 0.13127885705658368, 0.10493362216012818, 0.05417912134102412, 0.13585185738546507, 0.11354999230908495, 0.1260330214032105, 0.08012632759554045, 0.160718686612589, 0.18263764759259565, 0.10365286017102854, 0.14172090031206608, 0.13934494209076675, 0.0656268959864974, 0.10952225593583924, 0.2226760855742863, 0.13484394789806434, 0.13316770855869564, 0.12879703380167484, 0.15426712137247833, 0.09428078521575246, 0.12819980084896088, 0.12068023506019797, 0.12671941385737487, 0.0744358818711979, 0.06842132032449756, 0.12926291594547884, 0.1257122236170939, 0.23768487306577818, 0.1044814328530005, 0.12942405444170746, 0.12155121618083545, 0.15043562411197595, 0.12344403032745634, 0.095748056125428, 0.13980671231235775, 0.09325390388923031, 0.11697574598448617, 0.15127446981413023, 0.09422468394041061, 0.08822675328701735, 0.0913221486178892, 0.08094474939363343, 0.15258921283696378, 0.12874082396073, 0.11155207987342562, 0.19374644649880274, 0.20049286234591687, 0.11300498619675636, 0.16429096992526734, 0.08752391992935113, 0.13546872937253543, 0.09326425833361489, 0.07318820524960756, 0.10986759633358036, 0.231632476406438, 0.21221584400960378, 0.23835013593946183, 0.0640027274244598, 0.16868795827031136, 0.07459992449730635, 0.12090877922517912, 0.11432637886277267, 0.0666851799136826, 0.11459992347019059, 0.12964209488459996, 0.13035805789487703, 0.0831728276929685, 0.13735025269644602, 0.14731662933315548, 0.1757301746734551, 0.18849860238177435, 0.1332886234990188, 0.26636977813073565, 0.10515451245009899, 0.06956077061061348, 0.15733583670641693, 0.09121930306511265, 0.12797170451709203, 0.10835819518459694, 0.10222670848348311, 0.1093691105821303, 0.14259587121861322, 0.1794528349169663, 0.14547729731670447, 0.17505957851452486, 0.20558207854628563, 0.1230154133268765, 0.17237237628017152, 0.1827502301228898, 0.16276866304022924, 0.1348807109253747, 0.10704873794955866, 0.1429936827293464, 0.14827731278325829, 0.07644390447863511, 0.09801630369786705, 0.18429534935525485, 0.08950453650738512, 0.05916961748152971, 0.12268612028232642, 0.13465682151062147, 0.0943872473601784, 0.1818490270525217, 0.07639695664069482, 0.06851666806531803, 0.18981345397021088, 0.09351746724652392, 0.12667609618178435, 0.08802830893546343, 0.1597069908997842, 0.07137089847986187, 0.13563583897692816, 0.044599441811442375, 0.2591937274805137, 0.13849882249321255, 0.16266851127147675, 0.12175759939210755, 0.08302051015198231, 0.12455051738236632, 0.12791476185832704, 0.08697931415268353, 0.22063316591084003, 0.10756673158279487, 0.13009443346943173, 0.11795152005340372, 0.10149032835449491, 0.12968025569404873, 0.12891900725662708, 0.10450023505836725, 0.10527544096112251, 0.10600583641124622, 0.10113110513027225, 0.13296896565173352, 0.10262810265911476, 0.32812219166329926, 0.13363498848463806, 0.10117618699691125, 0.1541775818914175, 0.11807083365108285, 0.20542802395565168, 0.12874507158994675, 0.14341141602822713, 0.06774906854012183, 0.10316588237349476, 0.15977958057607922, 0.10416159858661038, 0.07761262676545552, 0.13070735415177687, 0.05551238497719169, 0.10762072939957891, 0.1760057413152286, 0.14513669987874372, 0.10656740556338004, 0.19437192007899284, 0.11244236531534366, 0.11928941469107356, 0.1328331229410001, 0.06982890050858259, 0.14975181009088243, 0.08828610474509851, 0.11641172053558485], [0.11859079503587314, 0.02780345075630716, 0.02748471571664725, 0.015550512887005295, 0.03384380681174142, 0.02094315637701324, 0.05179452197626233, 0.0552611641718873, 0.028882619991366352, 0.05891765707305499, 0.02006337635352143, 0.05163876426273158, 0.050605776121041605, 0.015951182726504545, 0.04167224174099309, 0.031724731770477126, 0.07602991669305734, 0.0295240900346211, 0.0059186870930716395, 0.02071936534983771, 0.026944150616015707, 0.0525403032079339, 0.08056985879583017, 0.018864211593089358, 0.01416662460126515, 0.050772193619715314, 0.025345841023538793, 0.017210523365065455, 0.04150441628215568, 0.024181610638541833, 0.023203990954373564, 0.06135233571486814, 0.0020167841908654994, 0.02982482693291136, 0.00972228977895741, 0.08061726125223295, 0.067662731744349, 0.04359736433252692, 0.035326633136719465, 0.02880716689729265, 0.03750651848635503, 0.019087792274409106, 0.03436470118218234, 0.035211170225271156, 0.06216529530606099, 0.0309829437173903, 0.003572926648692893, 0.05788491998932191, 0.02892144237245832, 0.03873728940795575, 0.06953996672694172, 0.049114254369799576, 0.027569615714518086, 0.019583338272890875, 0.022515372905348028, 0.020928159056763564, 0.018847339819850664, 0.08507440172668014, 0.13231972977519035, 0.030026321299374104, 0.02062082849442959, 0.052930399775505066, 0.06660649020756994, 0.03200473942394767, 0.04712413830150451, 0.04709878484053271, 0.037486274394073656, 0.036637732426502874, 0.010220372650240148, 0.09465853923133441, 0.08453468140214682, 0.029908408876508474, 0.037605716913406334, 0.04807393804990819, 0.01876134398792471, 0.060557906915034564, 0.07456544134765863, 0.06673951021262578, 0.08238054306379386, 0.006344762131837862, 0.06783632814352002, 0.03373735484534076, 0.018605350483474985, 0.06219221279025078, 0.035047924877809625, 0.031370014018778286, 0.029518078214355876, 0.039155718205230575, 0.03315897498811994, 0.018407230132392476, 0.0282462474424392, 0.04166710523090192, 0.03252860577777028, 0.021240130798625093, 0.023141757418800677, 0.0687154381136809, 0.00747469681248601, 0.05504245876467653, 0.026263651238488298, 0.07690493509705577, 0.02453291366275932, 0.041674528404005935, 0.013906497175672224, 0.01767431731734957, 0.02804246810930116, 0.020318120451910154, 0.02908371402216809, 0.019392983755096793, 0.054163057024457624, 0.052588811676417074, 0.02061084215529263, 0.044299895742109845, 0.05242627200537494, 0.09607561890568052, 0.0366913366929761, 0.013252888140933854, 0.05703769437968731, 0.05463403496625168, 0.020755977403106432, 0.018613067122974565, 0.02190734276414982, 0.04859387229329773, 0.016923496266826987, 0.051857103261032274, 0.014656185072713664, 0.023942888448280946, 0.0042605031464648035, 0.011800009807172631, 0.04114623121651156, 0.04019110496821148, 0.030328717215784957, 0.019421828278739537, 0.011273082412247146, 0.033081323440585814, 0.027557653142139316, 0.06562190196876015, 0.03643147813688431, 0.02023137653512614, 0.0023053057624825408, 0.016004992249820913, 0.012759821339776474, 0.03682777651452592, 0.04313288336353643, 0.05607805587351322, 0.04032373481563159, 0.05790528282523155, 0.015707765073914613, 0.10168415866792202, 0.01043266590152468, 0.06167368989970003, 0.014811366031478559, 0.041116630126323016, 0.02580045778969569, 0.042435593636972566, 0.032080009313566346, 0.010883660987019539, 0.04878791295258062, 0.025824489803718667, 0.04580334274630461, 0.013486092993324357, 0.034858121669718196, 0.054048472815858464, 0.05324110435321927, 0.0039817558717913926, 0.07053298237068312, 0.04905358994645732, 0.030547673680952618, 0.027658731111192277, 0.013983343811040478, 0.06176212336868048, 0.04504989067624722, 0.00527642825285771, 0.01729905352528606, 0.02162856325906302, 0.022165659349411726, 0.03311718401632138, 0.0701996452574219, 0.008100351052624839, 0.07605181301810912, 0.03511560535324471, 0.02731846276271556, 0.03229312359222344, 0.04156516891505037, 0.05500374834186264, 0.04625254310667515, 0.03826461512861507, 0.03377242153510451, 0.05042985573943172, 0.014791440850655948, 0.052260159847459624, 0.014121798033426915, 0.09306686571133987, 0.01858841933842216, 0.03145449162860002, 0.0940437593630382, 0.043435533730579276, 0.05450679607955473, 0.07521856522985867, 0.06958583569420235, 0.021598137748826827, 0.02028417673760227, 0.004949973605107516, 0.046925242724163194, 0.041113956698349545, 0.07536170219204255, 0.02816020750573703, 0.018528732005506754, 0.056702725389706235, 0.03712495110396828, 0.028065112519211004, 0.037697295392198224, 0.08009167481213808, 0.011120071917373155, 0.10266491318387644, 0.016053646603333097, 0.060077592331383906, 0.04080975927146418, 0.03505261355478849, 0.06513236609420606, 0.047718911564775875, 0.07401483732142619, 0.05061329768172332, 0.0671510077746851, 0.03555884478347642, 0.02850063530994313, 0.057850246849868975, 0.029053118878177235, 0.06903365746672664, 0.024714169025953327, 0.015431865949981978, 0.036050657143018076, 0.018195762997493148, 0.04596850495519383, 0.020824010716751218, 0.04380392735557897, 0.05760805056031261, 0.04217385893155422, 0.03495899268559047, 0.03501038153522781, 0.06971767504832574, 0.023347260230886083, 0.009613369641426419, 0.01711499411612749, 0.06653491154845272, 0.008678607077204754, 0.1329933793417045, 0.01515424165076443, 0.012883090796614332, 0.025097285164520144, 0.0062030042920793805, 0.07737223537904875, 0.07554120863122599, 0.013236540535997068, 0.023584632136459862, 0.11525375981416021, 0.02492917132829981, 0.03936392328302775, 0.018883731349238327, 0.03794103195624692, 0.036359892692416906, 0.05193123321181961, 0.027472698861466985, 0.010070100044166403, 0.04526244855618902, 0.042211656724768024, 0.04261300001027329, 0.04622897758547749, 0.00824058982211032, 0.02697784496870424, 0.016955321255539144, 0.013890638964117637, 0.05423648129882557, 0.020797279829691564, 0.06401555852166244, 0.02845467304411743, 0.04278393994484629, 0.007439471515161651, 0.035149844230285714, 0.023703238361382058, 0.025710024338747774, 0.009522043916928982, 0.022468847455456853, 0.014743965451738663, 0.010791952738405337, 0.07554573445980038, 0.046701088680752685, 0.028412583516910672, 0.021687585627660155, 0.028634042079959596, 0.09480027162602969, 0.020797710699428405, 0.08607342919068676, 0.01643640990369022, 0.03619823172422392, 0.06148963727589164, 0.00015144302597036585, 0.011665204406848975, 0.016727849175887446, 0.02969321488801922, 0.03419085033237934, 0.012131531839258969, 0.06350523233413696, 0.021499699280996407, 0.02012141315000398, 0.022163355723023415, 0.002382405788271821, 0.07850576883980206, 0.013972013124397822, 0.041275159655404944, 0.051541998383722136, 0.016073653208357946, 0.033070399026785574, 0.053418439480343034, 0.06843875188912664, 0.043531481974891255, 0.06503541022539139, 0.050279719688530476, 0.03405742659898741, 0.04166141910744565, 0.055449315147208314, 0.056157305371016264, 0.01958700066565403, 0.030818500755620853, 0.15220590840492929, 0.05294164988611426, 0.05011457105034164, 0.04596977720835379, 0.03521805735571044, 0.03490011280934725, 0.030266783931957822, 0.03045729620914374, 0.03287177825612681, 0.12373318124030318, 0.04129500341202531, 0.016713152107383524, 0.06237311701157263, 0.046756966039538383, 0.08870809245854616, 0.020134201838767955, 0.026488256507686207, 0.024813591369560788, 0.04693662854177611, 0.016194422263652086, 0.043720219883003404, 0.007644494263721364, 0.0010657071002892085, 0.018211606790178587, 0.02638765860215894, 0.035466153507253954, 0.022099259608824338, 0.025009409790592532, 0.027720296289771795, 0.16610606467085226, 0.09781745901065213, 0.21774557871477945, 0.10816992885832276, 0.09971849700169903, 0.08075876973037209, 0.0976652093231678, 0.14145828011844838, 0.10537336034966366, 0.20541525392660073, 0.11974097974598408, 0.13463012794298784, 0.1737423384828227, 0.13241306905235561, 0.13188834435173444, 0.12582817168108054, 0.1697325086487191, 0.20424015341060503, 0.17969988951725618, 0.09642319846898317, 0.11040705202945642, 0.1240622978657484, 0.17564500495791435, 0.07113750957484756, 0.05463886952825955, 0.09166535841567175, 0.12069675060255186, 0.23501983178513391, 0.21252127976289817, 0.14048838216279233, 0.0728470039154802, 0.12553998428796018, 0.07803804108074733, 0.08579391347510473, 0.09463840031198092, 0.10966182380382504, 0.12363000320536749, 0.1406199365322079, 0.16467715134578093, 0.1387766690126487, 0.1445428053183215, 0.08746106044522353, 0.1714303796844823, 0.10793606497879539, 0.20332907087036542, 0.12626433399106773, 0.05992815177887678, 0.1914996134915522, 0.0752588159271649, 0.15149635076522827, 0.09735598055911915, 0.18657974606113775, 0.17157916884337152, 0.10607636334108454, 0.14464689259018215, 0.16508795001677104, 0.06467468743877751, 0.10315389265971524, 0.14793539898736136, 0.15828935482672282, 0.0673935433317508, 0.1755820233374834, 0.1574307501848255, 0.12454175070992538, 0.07682516652026347, 0.10725808635886226, 0.146672658888357, 0.15286990920347826, 0.08058554652546134, 0.23419647025210516, 0.12036377989820071, 0.07273164617695979, 0.11004412400403193, 0.162164142621415, 0.12376645659761769, 0.19831997608499868, 0.13669302367738315, 0.14159324073365756, 0.19701114988752774, 0.05591976043901273, 0.16644207521208695, 0.11102221866271325, 0.18600029072591237, 0.1207399054297379, 0.1859618585024561, 0.12450451270810195, 0.09720109137041227, 0.16995118691452912, 0.16321846390409128, 0.115629179669278, 0.12483147159218788, 0.16975279684577668, 0.14147555562002317, 0.10791657066770963, 0.15184024588337966, 0.10666432072009359, 0.07000138411032301, 0.10138668891574655, 0.07297982036003045, 0.1407830970627921, 0.08713627287319728, 0.1474348029920033, 0.13692444483084337, 0.10195804932819945, 0.11836352651672703, 0.10739479759441954, 0.06724096116210733, 0.13136733802301542, 0.13922222224729403, 0.09500922648502247, 0.11364417975502354, 0.11403505663786616, 0.16122540299381527, 0.1834647546389273, 0.1240046631012644, 0.16548369878104754, 0.10980393617813076, 0.18188942702753202, 0.10179655120841094, 0.11225801413612706, 0.0866539633965918, 0.1593584953142064, 0.14395185559988022, 0.18260190236781323, 0.08667049929499626, 0.090986083793853, 0.12648709703769, 0.13812005067510263, 0.13643895302500042, 0.09114931896328926, 0.14831790274807385, 0.0596144243276545, 0.1503906508109399, 0.10057468605892998, 0.09459219886256115, 0.11567424796521664, 0.18978460266121797, 0.07852248115731136, 0.1205719815833228, 0.11470486569617476, 0.15782801886754377, 0.13322679538811955, 0.12535791977175645, 0.16939687808709486, 0.1146802891577993, 0.1088285217327731, 0.16323518300695078, 0.23618387218032563, 0.1001926844141313, 0.2110129642699446, 0.1063199234860284, 0.1082386848117624, 0.10171481488006455, 0.09897029679268599, 0.07416038308292627, 0.09571649067636047, 0.19882821238466672, 0.12184507612671171, 0.12254588066467217, 0.19697118417492934, 0.12235072042260851, 0.13425211608409882, 0.1365399190357753, 0.08650478747274194, 0.08647957989679915, 0.16431064744080814, 0.10685105355722563, 0.12090835853346757, 0.08661200957638876, 0.17004097066819668, 0.09336198094700064, 0.07976638512419802, 0.1060057007042425, 0.0933295673291598, 0.061474112394664965, 0.04285695031285286], [0.04602555957223688, 0.007834692718461156, 0.02954655632908855, 0.054648182421390495, 0.02305743587203324, 0.03395765480984535, 0.01504914675440107, 0.016455722706658498, 0.030274916174156324, 0.05355492679934416, 0.01702046231366694, 0.02974195745108383, 0.017680641263723373, 0.03106660708518965, 0.028225796396977136, 0.03482635605282017, 0.031548071785696914, 0.02312334537106965, 0.02563133293629757, 0.06535030475684575, 0.07977905337299619, 0.012717699582156326, 0.011826000242893184, 0.04575118036674602, 0.0017829896491353533, 0.016860972657533627, 0.014146411891228386, 0.048058867787144015, 0.00809609324538282, 0.05580440270049231, 0.03611765569075942, 0.058326598789010725, 0.05324903642758727, 0.08881699732903924, 0.10295824387243815, 0.009763005272751408, 0.07607636920043401, 0.058117168955504894, 0.051834039855748415, 0.030355353107942, 0.12899300828576088, 0.02966157140742455, 0.048649149148591926, 0.06233759570334639, 0.07284591147410018, 0.04490000907597797, 0.013198736805601843, 0.05254048980506403, 0.02515239917140986, 0.024282122030854225, 0.04703311622142792, 0.0391631345929844, 0.006521640095992812, 0.026414174054350172, 0.04376708629674145, 0.040313624643853734, 0.05784324436847653, 0.04891541986060994, 0.028037206070231538, 0.050412936468741724, 0.04872488722737346, 0.04784786035971982, 0.013742934613089477, 0.04699216663305249, 0.041504585915910344, 0.03641231291528259, 0.06864403587366853, 0.02343015855045191, 0.026798559053401862, 0.009331236477009952, 0.017920712042333822, 0.014460302190855145, 0.0303337655163237, 0.009458826505579054, 0.028753735657249178, 0.013392946250470621, 0.036625274523560486, 0.055345991227243624, 0.03784069698303938, 0.03145316169996347, 0.025512073621419922, 0.025070250633039644, 0.03869069780090025, 0.06989155643220459, 0.010303541535644658, 0.02753597225195595, 0.06432024788643632, 0.02396088998232569, 0.007455452711188367, 0.008706601735736643, 0.032921175605484417, 0.04112477593922189, 0.0456322060365762, 0.025597984636468545, 0.09161161165684462, 0.047443687583186796, 0.0477850687290941, 0.028280094465506927, 0.009570639746795808, 0.03711817593180707, 0.04778669382046376, 0.023739205806383064, 0.02157437545247376, 0.02143629527251635, 0.028107768623158336, 0.053588005381503274, 0.016957019289423312, 0.041734246270997186, 0.029751799601529325, 0.03816159315673368, 0.04497417634619134, 0.03280123097023793, 0.05006284632587007, 0.023458945398618068, 0.021900657497878586, 0.02688225974062724, 0.014843172360477703, 0.05049752264416643, 0.02053899208216795, 0.04315194680488535, 0.028242744505405426, 0.012825023466055947, 0.03271981016067522, 0.013698711941417838, 0.02386399687800024, 0.004031885614884751, 0.022529861324333718, 0.07221804945064442, 0.02971307560801506, 0.06271986197680235, 0.03983211244589516, 0.0400025299085038, 0.021998349577188492, 0.02630502151857529, 0.02697169404876019, 0.06260181723960809, 0.016070766041853597, 0.055511652159371545, 0.04928446827190263, 0.018506971387458698, 0.029601446419422115, 0.01970034315516906, 0.028253417861248766, 0.046398845434721024, 0.044326758943498135, 0.06375943869352341, 0.01198868834347065, 0.015511364809104373, 0.035909053669976335, 0.050186387196715386, 0.033103609923273325, 0.0771700997969934, 0.025240142231008837, 0.026509900078443543, 0.028513028752058744, 0.04034619093207376, 0.036195446337972365, 0.039627018451158486, 0.08225776893751961, 0.0724559777549335, 0.025542147989783968, 0.037099587464971204, 0.06762039115918533, 0.01765034976415336, 0.013210459346217769, 0.061912133890603266, 0.05095649051613041, 0.011045081923449678, 0.008467752320159758, 0.0243130598350295, 0.050979492853262594, 0.04834096193579691, 0.06517762437994991, 0.06107773259282112, 0.022535077562289577, 0.02299312432296574, 0.004654840557902519, 0.0029226201711156008, 0.0221081144908177, 0.04209428373724222, 0.009667806809635034, 0.02681949525140226, 0.03290022922945874, 0.05560081844617214, 0.03692995710298419, 0.02467232716402837, 0.03940240978928549, 0.06663846956299883, 0.018768175139224956, 0.010060187495712723, 0.04168944938906601, 0.045310984166072946, 0.05986968920167003, 0.02188669833620744, 0.04712400259450078, 0.0651412820443511, 0.04716682833220277, 0.06506766778017793, 0.03933923139369913, 0.02424366775500987, 0.021195931027510335, 0.07664101211620228, 0.04839716159871646, 0.04198471390243087, 0.057102582683520656, 0.05996340845844575, 0.012835111585445702, 0.05798918368028743, 0.06986978224345616, 0.06523693512592997, 0.04107724116849048, 0.02646133054180869, 0.06245840886341674, 0.02279625247631754, 0.08861600847116538, 0.013987490508173193, 0.06839335789637906, 0.016499003062822988, 0.011322562882144536, 0.04636644199490547, 0.0366647788323462, 0.0002458009803376626, 0.027119324609105076, 0.023464726516976953, 0.0442368632315525, 0.047630929321582825, 0.039820903047387085, 0.027246940082737377, 0.03816873813048005, 0.02330588995079909, 0.015877086702468138, 0.045778579610799036, 0.07101493222372872, 0.06985636082078729, 0.02313293985623334, 0.008217161704253937, 0.0507703921092408, 0.01976181673152106, 0.09911399015358516, 0.039601111984146495, 0.060811679012009075, 0.03756646026990243, 0.04216160119644233, 0.039959062955209186, 0.02450098010844418, 0.011930587086161333, 0.01951398520863482, 0.02844870532862842, 0.02634547577638711, 0.017754990042054226, 0.006932053274275469, 0.04575419306222882, 0.04343472966658218, 0.040768928426717005, 0.04321089792730553, 0.007490387086623481, 0.015742729983425567, 0.03148507998724069, 0.09332456652607236, 0.0358564061378794, 0.0257504497588213, 0.04195973702839442, 0.007127543029907558, 0.05445208240832601, 0.04405521601438522, 0.06503026692995004, 0.06706389066364084, 0.04008774712149586, 0.05474008320431624, 0.013140838260629346, 0.05117685154878667, 0.007376277004368603, 0.09511225524225406, 0.024852659719597017, 0.044695634328361065, 0.023143504646473696, 0.026696439533095275, 0.03774741877402578, 0.019066540557625036, 0.05544799200392195, 0.013609641497688634, 0.060859848212982924, 0.00925696233753115, 0.013188228842669299, 0.05141717168901648, 0.02264013174655182, 0.09502841545534985, 0.1262796688824892, 0.03593955721173968, 0.023660346466515745, 0.020492520915078263, 0.02535428199917078, 0.06618042449866023, 0.07725436027560915, 0.03919941246775644, 0.05071847739496401, 0.02488371287472546, 0.008462990700666393, 0.023761003743857145, 0.018044179970664636, 0.006863463561915393, 0.006679297283491386, 0.020956715203023384, 0.01670993076238249, 0.02981836727953383, 0.07619798981717654, 0.016541511585403765, 0.035312621388584375, 0.04992516478523612, 0.010384761329208101, 0.043463367237044234, 0.043098569847643375, 0.04421422391065529, 0.04559160250106028, 0.0462396645120212, 0.014852693903126886, 0.01818969689442643, 0.029821410509092466, 0.014129903982393444, 0.03173160193754094, 0.02505854420763041, 0.015002740048138159, 0.015344273864424654, 0.03123639690290604, 0.034249692889196534, 0.043800253088452985, 0.0546034500002861, 0.020450265146791935, 0.025658540494207824, 0.04415074356698564, 0.03396080321233187, 0.03475160863516586, 0.026205843447574546, 0.037888713513634036, 0.04182719199785164, 0.05155452414016638, 0.027647732058539987, 0.05466901344646301, 0.043284016860915084, 0.03633629324446831, 0.026797673565202525, 0.054556271460439475, 0.02668987979580249, 0.018640832775937657, 0.09213696060968296, 0.01865068680074598, 0.021605023182928562, 0.014062638261488505, 0.016369099229840294, 0.07031583759401526, 0.014991454314440489, 0.026061323970290165, 0.07918842935136386, 0.08747083813484226, 0.1112282761771764, 0.11698445837412562, 0.09012509070869003, 0.1575169377028942, 0.10907149833760091, 0.16466758400201797, 0.09592309780418873, 0.1546431247677122, 0.1379032451659441, 0.16456307603844575, 0.09798569498317582, 0.07533109347735133, 0.08714892755129508, 0.10366246144154243, 0.15617242056344235, 0.08525132973279272, 0.09712090888725859, 0.1293490356100457, 0.20043186204774038, 0.15759654343128204, 0.07666100854320185, 0.19681584036775998, 0.13446113201124327, 0.16914398808564457, 0.1576641933726413, 0.1132799285863127, 0.05804786338870015, 0.13951946129756315, 0.11132684695933547, 0.19351164624094963, 0.11063182353973389, 0.15516740163522108, 0.15194772583033356, 0.07494424709251948, 0.1351457331329584, 0.1151253402765308, 0.2011800283300025, 0.1323309527443988, 0.3453931606241635, 0.13683229977531092, 0.08784837501921824, 0.13200003121580395, 0.1812515091150999, 0.15002741744475706, 0.08321822168571608, 0.07844623417726584, 0.07835016718932561, 0.07763387848223958, 0.1344886805330004, 0.0766596243317638, 0.11077059073639767, 0.12057316223425524, 0.22471691534987517, 0.12122230311589581, 0.12352649947362286, 0.19276286927717073, 0.09520672088755028, 0.09794204482542616, 0.17972761445811816, 0.16855974229318754, 0.15370499582162925, 0.1093930018001369, 0.18766670487821102, 0.11362519434520177, 0.19113317744008132, 0.102551373919206, 0.06911758546318326, 0.11726311913558415, 0.08152823522686958, 0.09689733838396412, 0.0795076529362372, 0.09902235399931669, 0.10498242918401957, 0.13862916907029493, 0.14374349106635365, 0.1257020863039153, 0.13327178225985595, 0.20227911935320922, 0.09969081277293818, 0.06746017547058207, 0.1830388924905232, 0.14464138288583073, 0.08996735167290483, 0.10439090271081243, 0.13322809817535536, 0.1318798219519002, 0.11214045115879603, 0.12833345867693424, 0.14500146784952708, 0.09502027303512607, 0.1367340071925095, 0.12007536180317402, 0.16382344572671823, 0.16657622158527374, 0.19904902125043528, 0.11522470494466168, 0.07544307211147887, 0.1078458469627159, 0.10563655051269702, 0.12641685509255954, 0.0801436777359673, 0.1682932815913643, 0.10494204277970962, 0.14685305420841488, 0.058626599476805756, 0.14466775075665542, 0.16147263401321002, 0.10282768694950001, 0.19117512447493418, 0.25201319849916864, 0.1180088562624795, 0.06472916701542479, 0.15214262822909014, 0.14463353902101517, 0.08167671904500041, 0.20093557930418424, 0.11888020379202706, 0.10965408850461245, 0.19360626116394997, 0.13948687804596765, 0.06445974111557007, 0.08345359869833503, 0.14719150747571672, 0.11111890311752047, 0.09049609330083642, 0.10512851098818438, 0.14922099214579376, 0.17505662010184356, 0.08395890372672252, 0.1217461321502924, 0.13514913937875203, 0.06890833204878227, 0.076682518103293, 0.21389629026608808, 0.18040460241692408, 0.17052267624863557, 0.21100820095411368, 0.05871169455349445, 0.08975647655980927, 0.06953578016587666, 0.15356668324342795, 0.1364166835056884, 0.12162934270288263, 0.12894868637834275, 0.11625508751188006, 0.12921190368277685, 0.132242688909173, 0.20774455608001777, 0.12317822101925101, 0.11983586608299188, 0.15940831335527555, 0.08094987911837441, 0.12644459360412189, 0.13954401069453784, 0.16151007557553904, 0.10758748796901532, 0.17559757536011084, 0.2048595066049269, 0.11180216752524887, 0.17264997852700098, 0.09817375096359424, 0.11400237839136805, 0.13696458696254663, 0.14347616183970655, 0.11799837968179158, 0.06752302138400929, 0.13795686300311769, 0.08429825266024896, 0.08356297175799098, 0.16027014782386168, 0.14060495447899612, 0.24594557551401003, 0.11651427431830338, 0.09835649401481662], [0.0339259468684239, 0.06229031538324697, 0.02090653244938169, 0.0659641618175166, 0.018368200798119818, 0.0351258546247014, 0.04287487042269536, 0.09578545019030571, 0.04260181775316596, 0.036503487665738375, 0.062458978832832406, 0.011256417592189141, 0.054595019202679396, 0.04053422994911671, 0.0381857795374734, 0.06099752296826669, 0.018865568663126657, 0.03684379333364112, 0.042530235701373646, 0.04361202408160482, 0.04371252190321684, 0.03429756692743727, 0.03356400950412665, 0.04607780337599771, 0.03667351836338639, 0.05939745597009148, 0.10029102449438401, 0.08386230069611754, 0.007687230943702161, 0.016755876064832722, 0.045796112955680916, 0.04025803905512605, 0.02695596051801528, 0.045262923530702076, 0.016604516954560365, 0.033120844712747, 0.06817558208214385, 0.057753942374672206, 0.03424681250804237, 0.0932257446859564, 0.019928337706785117, 0.05047155850167785, 0.03845383140391537, 0.029852599371224642, 0.019049909664317966, 0.04602926776611379, 0.0258809761476836, 0.017385626111977866, 0.08227975347212382, 0.017691226410014287, 0.027866934492651905, 0.019980574725195765, 0.02318589442542621, 0.010253736217107092, 0.025055485711033856, 0.029884151249591793, 0.017329701255740862, 0.023819627473130822, 0.01426277555791395, 0.09592556088630642, 0.014505708057965552, 0.017995208402031233, 0.017386594720716988, 0.04698077403008938, 0.016483466307233487, 0.058540730870195797, 0.056794955262116024, 0.009398321537966174, 0.08519908253635679, 0.03297382992293153, 0.02595144709838288, 0.018117745041048954, 0.03079761884042195, 0.013767936084020351, 0.0672908809834293, 0.05166268262213894, 0.028750376908906868, 0.03075052851012775, 0.04684607804353748, 0.03224276611581445, 0.022614574725074426, 0.029472575656005313, 0.00453010673767754, 0.01972958122912262, 0.0215726994709777, 0.024240083393773863, 0.032066777880702696, 0.04361279761152608, 0.026273435713457208, 0.012096462604988898, 0.05017457050936563, 0.08251089642622642, 0.029841325511889796, 0.029015378760440007, 0.06460985341774565, 0.016641607375017235, 0.020567921422688023, 0.07233994148139443, 0.061106285346405845, 0.030874344187655618, 0.03883984997602446, 0.05010116319837315, 0.04177313989826611, 0.007834727493380862, 0.059558682675872526, 0.09085779317787715, 0.05216249151687537, 0.031893921084702015, 0.019077037494363527, 0.0645129925438336, 0.04433449763538582, 0.013818624346250934, 0.05441384696002517, 0.051899233500340154, 0.0288441911605852, 0.02187217090145818, 0.049909829893814664, 0.024086636091981615, 0.02576222234139485, 0.030382240058055947, 0.025367391295731068, 0.04243019249822412, 0.011975843675567635, 0.027367714227044156, 0.02353226110738303, 0.027856004989839027, 0.036443264290158234, 0.04132309476179736, 0.037099947088531086, 0.02312513839985643, 0.004457029364337879, 0.02028481795319489, 0.02955909226355808, 0.013088687755433577, 0.015160399356058665, 0.045214228465088775, 0.04737010385308947, 0.050872732153428454, 0.03608423784109099, 0.07625196727791003, 0.03851926253576364, 0.023129123096753443, 0.05732482325817857, 0.04962851606043322, 0.03775390896147915, 0.036846269986459186, 0.013537710848530489, 0.05025288362854293, 0.025912587397864888, 0.06269115994551352, 0.08837636347327914, 0.023757867215733443, 0.02608921006321907, 0.03628687553906015, 0.07276901988578693, 0.052397736215165684, 0.005364003799123955, 0.08236659238381044, 0.04063011033992682, 0.04877610644325614, 0.04847588862425514, 0.039525234805686135, 0.02724069925690336, 0.11419574730098248, 0.02588568178803793, 0.0290477652368801, 0.05282098600374801, 0.022135165985673666, 0.05083587073854037, 0.026080623202558075, 0.027522099603499686, 0.039573868803147755, 0.028386305551975965, 0.018138976401782463, 0.040099139724458964, 0.03420142869332007, 0.01758894064862813, 0.059729910987828455, 0.04316779738292098, 0.0331036743841001, 0.053544022741594484, 0.020731022581458092, 0.04932490895901408, 0.04199477318408234, 0.06056504510343075, 0.04100969640005912, 0.02330246165261737, 0.014039853055562292, 0.05320280783676675, 0.014299167087301612, 0.04634750747521009, 0.054804686523441754, 0.013365131403718675, 0.05183196353859135, 0.01294326752291194, 0.04322413614551936, 0.04512341673086796, 0.060170721262693405, 0.0038369526820523398, 0.0600137896835804, 0.024552375743431703, 0.025854136695020964, 0.023977558195058788, 0.07077745175255196, 0.016830565807010447, 0.017869202752730677, 0.05140840501657554, 0.028374090225302746, 0.03098822271983538, 0.05226445836680276, 0.019703966532168642, 0.03214726231193968, 0.05879712211234229, 0.037047282593058686, 0.026704880508727262, 0.016441263125411103, 0.009479651593470147, 0.01671133702620864, 0.040501880792102644, 0.03228814993053675, 0.0085767598190744, 0.01672141157489802, 0.09895765568528857, 0.03965198853984475, 0.056446222189281664, 0.006238101091834584, 0.031208685532744442, 0.07545303979090281, 0.049788233025797775, 0.026802825342331613, 0.027190406241321137, 0.01648953410663775, 0.021119358350655863, 0.03360327293298074, 0.03598319040611386, 0.04847976645188672, 0.026558425510302186, 0.034697312262973616, 0.02695770944202585, 0.0463663266439523, 0.05606144194358161, 0.0313910927091326, 0.03500412204968078, 0.026048708307955946, 0.08225721932415452, 0.05395872638161693, 0.024224122553797703, 0.025392985636634485, 0.055407134017774036, 0.028885659828249897, 0.06035391214702811, 0.029284879299146787, 0.05594428947993687, 0.036665192738707574, 0.06620734198285, 0.007368992930943412, 0.03688152666602816, 0.039826310971485715, 0.022598761466464827, 0.03453304572030902, 0.039602587797812054, 0.015136104409715958, 0.025763514950605373, 0.029276014239128147, 0.0587488714871662, 0.04545212284262691, 0.043588611230786355, 0.0654394371168954, 0.038556473396186314, 0.029785169953746454, 0.02869110008967774, 0.041488501243293285, 0.08690190687775612, 0.09556567948311567, 0.014189258833149714, 0.054152919711279016, 0.040220984257757664, 0.09924427566251584, 0.048117367683776786, 0.053638006627027474, 0.025725294769342457, 0.08767532823341233, 0.0733416084466236, 0.03040205328060048, 0.05092978337779641, 0.06968342938593455, 0.010246978008321353, 0.03961111019764628, 0.026119314965658953, 0.019817914614187818, 0.05237976521519678, 0.03732388400073562, 0.038561660796403885, 0.020549828286415765, 0.011900702707602509, 0.07524472275482756, 0.00735654350968876, 0.014596204273402691, 0.0420907791038709, 0.006163663255782532, 0.010579207413164633, 0.01912927451277418, 0.03543379417221461, 0.032087378203868866, 0.035306389044438086, 0.022724782382803302, 0.04647601182971682, 0.054244681394525936, 0.04303400045526879, 0.023100466866578375, 0.026156344317964146, 0.019212987074362378, 0.043675548530050685, 0.04993098661569612, 0.039928172648485215, 0.0964490913652948, 0.0819519871313657, 0.026624087344056795, 0.05130783934146166, 0.035843710747680495, 0.02202128914983145, 0.056267998181283474, 0.003761689577783857, 0.04360736933137689, 0.002171937796187454, 0.04041978484019637, 0.04079525558544057, 0.0035115499756232437, 0.06088128313422203, 0.00962659768161497, 0.05069020962608712, 0.05080596770026854, 0.049602467101067305, 0.05587080413741725, 0.05047663055094225, 0.00994249474855938, 0.02461907234308975, 0.03524715632998517, 0.03480277017557195, 0.09596077006842409, 0.03329014937792506, 0.014548428622739655, 0.08141679942075696, 0.024396826679419194, 0.06043141441685813, 0.02170926651784352, 0.01560003067632871, 0.08871066410626684, 0.02565304096788168, 0.05238429782912135, 0.025807441611375128, 0.07297604091997657, 0.11093221777783972, 0.12898511013814382, 0.12109064018087727, 0.11911462407026972, 0.1129686167197568, 0.08716713264584541, 0.13521246026669229, 0.12389172773276057, 0.14380084084612982, 0.14930726108806475, 0.11594712760831628, 0.07380740238087517, 0.09207662527582475, 0.10215297208300658, 0.15708685506667408, 0.11327808297106198, 0.08899655805102416, 0.14068445164178098, 0.16379747140620435, 0.11797467166824, 0.1386607073779617, 0.10141072941145726, 0.13357487028198584, 0.1650345493108034, 0.16538955883256026, 0.16607396996447019, 0.28629048062222345, 0.14531208761036396, 0.08102371051375355, 0.1565326683755432, 0.14829883591404983, 0.13067884211029324, 0.1306166611611843, 0.19165982918015548, 0.055109097688857994, 0.16323461303753511, 0.12205785113785948, 0.16911652098808969, 0.09720552898943424, 0.1691446259085621, 0.1410663311502763, 0.14797757672412054, 0.15743358646120342, 0.11190686547862631, 0.08871673020933356, 0.10902182957423584, 0.21073625768933976, 0.0837270754522511, 0.1638514149401869, 0.09116175651018109, 0.07245885474341256, 0.1413776972996337, 0.10269938276282378, 0.16736530352916035, 0.09647871620420899, 0.1012114097497293, 0.17421039193868637, 0.18269267678260803, 0.19719891409788812, 0.09737567843071052, 0.13328981772065163, 0.12917792264904293, 0.09260285632418734, 0.12479666274573122, 0.09642314418618168, 0.09658480515437466, 0.10139889576073204, 0.14914039575627872, 0.19913562946021557, 0.12737684643694333, 0.07889158385140554, 0.12339247523673944, 0.1420732228351491, 0.18655962071248464, 0.1661813413458211, 0.16172276916248457, 0.20884747404072965, 0.16827563968087944, 0.20680269519133226, 0.177277980904494, 0.12516277310039314, 0.144369955307671, 0.05865382230175393, 0.09835581547979798, 0.1605552818093981, 0.08051205439759151, 0.19514952121036394, 0.11722206776695591, 0.11787213145622186, 0.10896217277539627, 0.1038051980680653, 0.2521263509988785, 0.15827726333269052, 0.06477422852601324, 0.10498498726103987, 0.12820478129599774, 0.11332537007651158, 0.20084599911102227, 0.12147855865103857, 0.13885307205574854, 0.1999645142682961, 0.2166312342243535, 0.11563287089977946, 0.1646407547273806, 0.10429159232548305, 0.21490554325282574, 0.11246515052126986, 0.1387116110750607, 0.1207923154745783, 0.16355777212551662, 0.09971380153936998, 0.13112651237419673, 0.13001975390527928, 0.08977977066699948, 0.22688771172293595, 0.09171681851148605, 0.13919198672686303, 0.113690842608256, 0.1058941020497254, 0.16479341153587612, 0.09082432104540722, 0.05940822432083743, 0.1828051507472992, 0.08694708373929773, 0.10415897265608821, 0.07333910465240479, 0.14439844020775386, 0.11769089475274086, 0.18011233024299145, 0.10399497074208089, 0.1403077697115285, 0.16324784447039875, 0.11822832162891116, 0.10770876931824855, 0.08175447237278734, 0.08609322884253093, 0.12834656797349453, 0.12439214730901377, 0.12851403041609696, 0.25746547164661543, 0.15843437133090837, 0.12913465925625392, 0.1108679740822741, 0.14319773178015435, 0.08314369818461792, 0.1314479208418301, 0.11574446276894637, 0.21443252292062553, 0.07412322650530509, 0.0928473664181573, 0.1667307104383196, 0.11114531848579645, 0.18428846901016577, 0.15867917319493635, 0.1889185341341155, 0.12788669764995575, 0.15205538219639234, 0.20403296952801092, 0.15955729250397, 0.12276211620441504, 0.16753340379468032, 0.06947356529001679, 0.21680420637130737, 0.28650734041418346, 0.1212696512894971, 0.07096104297254767, 0.21712166576513223, 0.14768504670688085, 0.24888781192047255, 0.08701714926532336, 0.08405754914773361, 0.21369700453111104, 0.10457291294421468, 0.10311556221651179, 0.07615813945553132, 0.1904817431100777], [0.045824713206716945, 0.024325772188603878, 0.01591489976271987, 0.08260703126766852, 0.08050967952502625, 0.026667281187006404, 0.06123236393822091, 0.02328322348850114, 0.11020999188934054, 0.06437322790069239, 0.030271523499063084, 0.04270921966859272, 0.040263993199914694, 0.053153556372438154, 0.05095898752499904, 0.06580077058502606, 0.004712555474335594, 0.05217938703883972, 0.034012090281716416, 0.026050947473517487, 0.03052652035174625, 0.06340181681194476, 0.047394202024276764, 0.03884034530658807, 0.0800805671938828, 0.031631490880889554, 0.04035327823034354, 0.026974810220833336, 0.04084926358024989, 0.06551368920398609, 0.07468493814979281, 0.06723087813173022, 0.02870474203622767, 0.025379260569544773, 0.028802213591656516, 0.03766392503998109, 0.015510716808161564, 0.03644384443759918, 0.054671534204057286, 0.015291234478354454, 0.060586181469261646, 0.025527651089110544, 0.03232399354289685, 0.024366270551191907, 0.06104725279978343, 0.033168857850666554, 0.07065730355679989, 0.013552919362804719, 0.022393536853737066, 0.04724980977230838, 0.006125985902534532, 0.044800488344792805, 0.06580565603716032, 0.0023946270521264523, 0.013949107478505798, 0.04381359647959471, 0.008922779600002935, 0.055908829239862304, 0.04143393684976867, 0.021485507721081376, 0.020339088880323937, 0.024648388448570455, 0.058460738376847336, 0.025747645712856735, 0.015717798910502876, 0.023612743842282465, 0.03309059562161565, 0.07501002427722726, 0.02783193396005247, 0.01108315961235868, 0.0836059773074729, 0.07212426912571702, 0.05020182726106473, 0.014839952711814215, 0.04930841377271073, 0.09703778156212398, 0.08120184631219932, 0.059458374844065735, 0.014885621511244347, 0.060005084079291136, 0.013107026860650097, 0.051653865059571605, 0.015849802809368287, 0.05829323522214379, 0.06399060878902674, 0.043345247860997915, 0.011236338044649788, 0.014042440818489661, 0.015294608493734683, 0.01538099448329636, 0.02080404312748994, 0.015399491347904717, 0.055159441594566615, 0.01589626379843269, 0.07675164046564273, 0.0661719495962773, 0.0609497744590044, 0.043821806753320355, 0.01774413008908076, 0.014052444121002086, 0.03942728488306914, 0.06190813731934343, 0.05565203766205481, 0.03658205184287258, 0.03555592029754605, 0.030775535918240036, 0.03834515044997845, 0.04805125801690987, 0.017177112300747206, 0.10595334494220358, 0.057278730374361785, 0.028517038894018958, 0.061063619064433236, 0.03425308556428977, 0.0580273512750864, 0.07657376929585423, 0.023712958375524198, 0.034475753616009436, 0.04121104488149285, 0.030511256706501757, 0.014180865354969032, 0.021062412299215794, 0.05096997639962605, 0.023196438859616007, 0.020081221824511886, 0.07700721068041665, 0.0496938386266785, 0.020266931770103316, 0.029795680461185317, 0.024004149982439618, 0.031550843601248095, 0.03919140914721148, 0.052581968650754006, 0.07861867028155498, 0.044540958878185065, 0.02745274145023099, 0.035477206842707734, 0.02238319767639041, 0.02513425175233611, 0.06280752191586153, 0.03627760335803032, 0.01906539892245616, 0.1695272382348776, 0.03714605015037315, 0.033369521011731455, 0.02424292136648936, 0.07345681690743991, 0.022690270395417298, 0.013166554737836123, 0.054528064759714265, 0.08975959782089506, 0.027065657578142624, 0.05796712450683117, 0.04339077416807413, 0.06095130116279636, 0.10185310710221529, 0.0382284526047962, 0.026777275106204406, 0.019138037792540023, 0.019203189028693095, 0.021705697423645427, 0.01082222897093743, 0.008745095027344567, 0.04282975123663034, 0.022670932147385817, 0.0652247214955943, 0.019177245242255073, 0.04521425899916461, 0.07331090473702975, 0.028457634849473834, 0.028274840908125043, 0.0369173499223377, 0.05859700177929231, 0.0336725208243089, 0.01908195687324873, 0.014118323934131434, 0.06708728655108384, 0.02441529809896435, 0.06383000633546285, 0.08401134091296367, 0.007318957758668278, 0.11167288624814578, 0.00947759987320751, 0.009063935239932366, 0.030316456087997982, 0.07851821995739426, 0.030715346469410827, 0.04995260474139026, 0.030919324274041822, 0.013226439694075711, 0.04445367552606123, 0.045654285566083024, 0.024573907355910966, 0.02407476003281772, 0.03448832008455481, 0.02852028568408319, 0.048831695424658914, 0.014665251996900355, 0.01741465044740055, 0.039461611969662566, 0.04858809117493885, 0.06290668302348681, 0.037091316123093875, 0.023992986385045306, 0.036695163630481274, 0.11407853716186114, 0.04402155389211007, 0.03519905498251319, 0.0781970014795661, 0.06522532539176089, 0.05253453905295048, 0.014013150158072156, 0.0348984809326274, 0.014991776618574346, 0.019016639396016086, 0.0689860853765692, 0.03653719728546483, 0.03281170076557568, 0.07838990220001765, 0.06640864296683244, 0.03332230175978371, 0.010452664024861795, 0.030477665830403566, 0.03886211270998631, 0.028246936155483127, 0.027515292200925093, 0.04137923674924033, 0.029652492608875036, 0.030174425137894492, 0.03343090128951839, 0.03460135044796126, 0.00670791619424043, 0.016273912641086748, 0.039530693619911156, 0.018129169874425446, 0.05706940910645893, 0.022896407637745142, 0.03468633356637188, 0.0535985871351191, 0.04252611020846026, 0.05645066659365382, 0.015798037372795597, 0.056740607999797375, 0.08441065877143826, 0.02309476038707154, 0.04291470721364021, 0.05077826311545713, 0.044898054895124266, 0.042604616710117886, 0.027914637200800434, 0.04461909897093262, 0.02455361406984074, 0.03470100349347506, 0.04192372378227966, 0.012147000741346605, 0.0714825853439314, 0.04207352735102177, 0.02843047648535243, 0.002684511843004397, 0.05055604628952486, 0.05909474114222186, 0.05784202300544296, 0.06597625331154891, 0.02514283013130937, 0.006405450727990163, 0.03653110743367246, 0.046860344242304564, 0.008655326540714927, 0.03867314409996782, 0.017110748183248297, 0.016741986453000988, 0.03294170128979853, 0.06551191144223724, 0.026582946069538593, 0.03201198617794684, 0.06142520359052079, 0.04207023645618132, 0.059933077943112166, 0.046972723212093115, 0.05976125252033983, 0.08243158925324678, 0.01872587187348732, 0.0136718597662236, 0.0408900706762714, 0.04162595547469599, 0.06398406771144696, 0.06863568989293915, 0.02668612410447427, 0.011510944559371896, 0.029969551667038883, 0.01974343352152833, 0.10497305861541203, 0.07787281101835625, 0.0373828317304807, 0.02312836144119501, 0.04828155280223914, 0.015039803327194281, 0.01825253262982837, 0.03935242550713675, 0.014191821151013886, 0.0014028909770006845, 0.018140866121809398, 0.12481974650706563, 0.011145058969434882, 0.008947589384791042, 0.019748688775247762, 0.045700948419315476, 0.025109439423041682, 0.04526117630302906, 0.07105719138469015, 0.009296403033658862, 0.03887626016512513, 0.016278051704700505, 0.021922982996329665, 0.01911244005896151, 0.04953292404700603, 0.009780295193195343, 0.04392371253509607, 0.03101889928802848, 0.04271170989211116, 0.07868697161653213, 0.027010579194341387, 0.037534128076263835, 0.06072593254170247, 0.053732468879648616, 0.05199114106861608, 0.028712148245956217, 0.036991177925041745, 0.04272126705784883, 0.04692180594429374, 0.02840284993206816, 0.1039827638970954, 0.04610636630760772, 0.017101647332310677, 0.0628657266497612, 0.026877055377034203, 0.0400295423875962, 0.024863524761583124, 0.060354726389050484, 0.027923402176903825, 0.015348200885845082, 0.004392323416790792, 0.022703747797225202, 0.021988563405882035, 0.07189562318048306, 0.02860839684892978, 0.05021915026009083, 0.08113328713391509, 0.046024565518434556, 0.05377533532945173, 0.026878130855038762, 0.026378075991358076, 0.12888102286628314, 0.1675081622919866, 0.08999366526092802, 0.27304222009011675, 0.09923329696591411, 0.26483476907014847, 0.16726720093616418, 0.17562277615070343, 0.1313298964606864, 0.2291696657027517, 0.11609369117234435, 0.12146802778754916, 0.17159877850541047, 0.19853028122867855, 0.16841030174068042, 0.2116889479969229, 0.08434511228863682, 0.20265865113054002, 0.09500997287354299, 0.1687631942331791, 0.15899963171354362, 0.11678456195763179, 0.13407382422259875, 0.15833955284740242, 0.18797412195375987, 0.11423721936132226, 0.10028605761804751, 0.101683866897864, 0.18563085554965905, 0.1461400631815195, 0.1274866062615599, 0.203265817835927, 0.18485918481435093, 0.14695183533642972, 0.0816103583201766, 0.16512784787586757, 0.10448017077786581, 0.1677932148533208, 0.11865244672766753, 0.10272290757192032, 0.12197201645800046, 0.1468688640743494, 0.10294217616319656, 0.10827496607920953, 0.13801095581480435, 0.16923020274511405, 0.19867197291127273, 0.08974434435367584, 0.10401456004806928, 0.12604299586798462, 0.14465194089072092, 0.07066017375992877, 0.08547350245394877, 0.0645270450040698, 0.10864362772554159, 0.16650832737130777, 0.0976089791261724, 0.10048034254993711, 0.11500673235527106, 0.08097620627709798, 0.09283133942101683, 0.13068219407328538, 0.1474099957517215, 0.12332591095141002, 0.15616623232407228, 0.09352266482476677, 0.13855885927166256, 0.12925132656736033, 0.096126285115523, 0.1304209173790046, 0.1711912639439106, 0.19436524329440935, 0.09206985349633864, 0.21856465190649033, 0.12502990237304143, 0.17650094974253858, 0.15412799455225468, 0.13410068063863687, 0.07049933381910835, 0.1698018277862242, 0.2112408841827086, 0.12815653745617184, 0.15475635869162424, 0.15250358171761036, 0.2165435403585434, 0.2493030753518854, 0.11891356057354383, 0.08952200878411531, 0.13713251080896172, 0.13253188053412096, 0.12241433986595698, 0.1518383188439267, 0.10882858280092478, 0.10094110853970051, 0.14945704090808118, 0.14448799325951509, 0.1356173421123198, 0.09355976711958647, 0.15473773969071253, 0.11896257794329099, 0.10642025167388575, 0.1599256827362946, 0.1450680728469576, 0.13886475642876966, 0.15004533076924936, 0.07043201635990824, 0.13481014328343527, 0.11925301807267324, 0.1326018917773451, 0.17211594432592392, 0.13573738852781908, 0.0614884023421577, 0.15554989182523318, 0.06198186693446977, 0.1810398061892816, 0.142826003155538, 0.12455502285489015, 0.11046888014035565, 0.1388062938515629, 0.13161185490233557, 0.05670427244954875, 0.16861315656985554, 0.13414752669632435, 0.1220031747860568, 0.09490904757486922, 0.2857548993613039, 0.2102274378495557, 0.11996668763458729, 0.07875825172024113, 0.12948494617428097, 0.19336287065276078, 0.15620831506592886, 0.15043284211839947, 0.15968031090285095, 0.13640057508434567, 0.09208424522408418, 0.06764032651803323, 0.24294039819921764, 0.06651590578258038, 0.11064519067960125, 0.1067559840157628, 0.07994392381182738, 0.22853702679276466, 0.14736309541123255, 0.16681343742779323, 0.05404422179396663, 0.17819598450192384, 0.08853943579431091, 0.13764608039387635, 0.12548286521009036, 0.1949518232473305, 0.10502613362457071, 0.22210598045161792, 0.09121765422501735, 0.14826357923448086, 0.1949322678680931, 0.117479571806533, 0.15631895698606968, 0.13391020228820188, 0.13810162166399614, 0.09472609417779104, 0.10990720920796905, 0.10497983039489814, 0.1344184928706714, 0.08715518364416701, 0.16059532894619874, 0.07007874388779912, 0.1381103340536356, 0.22356252372264862, 0.09994537197053432, 0.07660073427749531, 0.1872710239674364, 0.11536653233425957, 0.12396214609699589, 0.13989239771451267, 0.11950824223458767], [0.05764881015888282, 0.04232364892959595, 0.05887923842029912, 0.05226325396714466, 0.07207598457379, 0.04377259600109287, 0.05684177078572767, 0.05781380273401737, 0.038062520258660824, 0.04603427196187632, 0.013487030219818865, 0.024679231257843118, 0.012575958705773311, 0.04984210192092827, 0.008699572961112218, 0.019213210990918533, 0.01829986384005419, 0.07708828882979495, 0.01562765214060034, 0.07147318084857293, 0.01757692888246051, 0.04686325855020966, 0.031816697014229636, 0.00888493939835046, 0.015030909429437347, 0.01763135926531894, 0.044258925797683854, 0.03708603033529861, 0.012359954716105546, 0.04144486126356891, 0.013606636435724795, 0.008910353079305162, 0.049725824767457585, 0.06972650278891836, 0.03908961871638894, 0.0775322542924966, 0.01789962317395423, 0.06475124654493161, 0.031238106811153035, 0.05268278538382479, 0.041401418058999946, 0.04147917477946196, 0.03148128358381135, 0.03155353059992194, 0.04690495791978069, 0.007494026578829757, 0.02346209210476705, 0.06280180865100451, 0.037655877614659924, 0.041459544761372466, 0.02678647943373237, 0.0681280167773366, 0.016312263440340757, 0.023266246542334557, 0.06948403508535453, 0.029756613807486634, 0.0512568101153842, 0.08563324995338917, 0.024746496130579283, 0.014012591214850545, 0.007973706732237977, 0.0371040081206177, 0.07353473308363132, 0.01289109157265297, 0.05327541786911232, 0.029693085966365676, 0.0034533876501622474, 0.03810568865654724, 0.06879386319113628, 0.09992075472005776, 0.0490607281348535, 0.05866843794605561, 0.015510194336197205, 0.03958687971213034, 0.032860168521957736, 0.024172955924378972, 0.023165458647002066, 0.03873357442872865, 0.021551228926650116, 0.04119376598724297, 0.039060984538601976, 0.026896670128085783, 0.05081485990168793, 0.021394237975722978, 0.016822374192997813, 0.07896573415824346, 0.020311996673366854, 0.02774058448682938, 0.013969379560356694, 0.02697839118939425, 0.05427273542487195, 0.055044392589479685, 0.023465157386713793, 0.026267171138897538, 0.06620500782238585, 0.01465237170590886, 0.0374909223589514, 0.02903552107246859, 0.014696362827505385, 0.034122145269066095, 0.0768135500007442, 0.026946416922977993, 0.04313933623156377, 0.024528638892141835, 0.060903905491743765, 0.03664502328527825, 0.030303608027419875, 0.104769152056958, 0.156562171078154, 0.03640040123303022, 0.09473594650626183, 0.03345189855567046, 0.029227926462356533, 0.03524385864979454, 0.04442855955234595, 0.03867627214640379, 0.018373237224295735, 0.0777905590033957, 0.053303499040859084, 0.04681756260937878, 0.02891227536435638, 0.049014506329383166, 0.019905803558815802, 0.0035591027699410915, 0.07965419614421469, 0.03443288716620632, 0.007964839127713015, 0.04861145652830601, 0.036228053338293514, 0.0018898603988678328, 0.01967652827235205, 0.018749167677015066, 0.08066830065633569, 0.053867270039128404, 0.04801199458805578, 0.05069324607029557, 0.059293110854923725, 0.0329419693111309, 0.029272390862128565, 0.0063274747559002465, 0.017437176113682132, 0.00944232877476939, 0.016864037939480374, 0.02111631851377232, 0.002916505086302225, 0.04539929210607495, 0.035653805759336264, 0.007802503865345248, 0.05192708397018058, 0.07328355299042803, 0.04088951088488102, 0.023345518092225705, 0.020436809797372137, 0.07014510461262294, 0.017420501115598848, 0.023435415500508885, 0.016543048467221003, 0.02859319427183696, 0.01697320065328053, 0.017820299037599137, 0.06561954066689525, 0.02791640648086156, 0.019834474261317934, 0.03791854191305382, 0.03663041103365166, 0.03456222951146109, 0.038976744416036775, 0.03491804648989013, 0.017301608209631274, 0.019302633424688662, 0.033794555347412825, 0.04778915011723127, 0.021287171935130442, 0.03567612277609961, 0.03749263226719839, 0.028122063659663712, 0.0379401871801487, 0.017527507784377252, 0.014102830435149372, 0.021916331656809365, 0.05660381194736276, 0.043872014952025244, 0.036175636508102925, 0.025590344332158566, 0.046975247362362485, 0.031013922233666693, 0.027588282212881104, 0.026565573876723647, 0.01837027881161443, 0.03669547914926495, 0.06556255051067897, 0.026503659252609526, 0.0689244811822261, 0.0473726992495358, 0.0217245623935014, 0.03396918651248727, 0.0611319611115115, 0.032528707558023076, 0.011379617499187589, 0.05204874529902424, 0.07220926242215292, 0.0222444406577519, 0.0699338223785162, 0.02587862841651908, 0.028857317420520952, 0.03296574517818434, 0.014851581105696303, 0.028479987489325658, 0.05446726462936827, 0.04901138846097248, 0.02426172187551856, 0.009591788835158306, 0.043953727531645975, 0.07267466280609369, 0.03800594400880592, 0.023908220397840654, 0.02964053682184645, 0.01640133303590119, 0.00988365982526115, 0.031816116866788695, 0.04101846646517515, 0.033187307217823606, 0.042641725790287764, 0.07848834406052317, 0.05718208663165569, 0.024460919400943176, 0.026121279324537942, 0.008162814441935291, 0.009111921236451184, 0.020253688462876847, 0.022716502559238246, 0.03886030102148652, 0.06724282713340861, 0.050160104142768044, 0.01642277304615293, 0.013340984038742525, 0.03014708696199315, 0.021572037899334515, 0.018646523988406574, 0.036412699680243216, 0.05955325439572334, 0.014808103974376405, 0.010386467844780003, 0.02849225540246282, 0.04291975212150386, 0.07721624017826148, 0.00983630825898477, 0.008484330627002885, 0.026721940575433627, 0.06023134158125945, 0.05478310910984874, 0.03294254945857184, 0.003571257028462631, 0.07160706259310246, 0.03157908083604915, 0.023499333499265567, 0.06059535526271377, 0.016002147491755228, 0.049231454330895624, 0.047691108592386754, 0.015730926866776178, 0.08471565347697053, 0.07489788279469524, 0.017477913659864237, 0.01996358420832881, 0.003769710285788668, 0.024439715181610415, 0.06857084230120693, 0.02092431515588292, 0.02862056637448924, 0.03297438971432192, 0.03808592293145401, 0.030276425914572816, 0.06074748959924493, 0.013310798560269177, 0.04612795050655093, 0.06329071348799126, 0.006012838491837361, 0.03459145062203918, 0.07765051616089684, 0.018964453267731836, 0.0212118630297482, 0.01621765360635306, 0.08378186036965676, 0.058656583939279826, 0.03526267781853676, 0.10794185966785465, 0.021731040706591945, 0.040207478018211465, 0.01129057674136545, 0.07773742971143552, 0.031810335748429806, 0.021526011172682047, 0.023678461655176113, 0.04782375540318234, 0.06335868234080927, 0.012510617479815014, 0.06847800513995544, 0.06207149462508304, 0.01498044338742537, 0.07507884808416877, 0.00957845986288573, 0.019872994694326605, 0.04041154742506998, 0.019811702626092092, 0.03375383646094373, 0.02102623620469655, 0.026033297081344893, 0.09021218746368374, 0.03507522573428495, 0.014517121016979218, 0.038029638451657126, 0.03067738243511745, 0.06959393740232502, 0.011057482150915478, 0.043069124820509126, 0.10111992965851511, 0.027547858489145125, 0.10029636456498078, 0.033397167921066284, 0.051965665471340926, 0.026340259538431252, 0.05323893643383469, 0.060551494759108336, 0.030164335322167193, 0.07234265562146902, 0.0635701749207718, 0.04307633425508227, 0.07082895256046738, 0.03729333635419607, 0.02408540963993541, 0.021528196055442095, 0.020976097555831075, 0.040692698410046954, 0.05014363609786544, 0.00244391880447178, 0.05763622333428689, 0.01499100648132818, 0.022988944547250867, 0.07691949645855597, 0.04836678697860666, 0.05665858668674316, 0.044549725550626, 0.03189460979774594, 0.0029577375389635563, 0.03590200708380767, 0.02957692416384816, 0.03957225049712828, 0.042210632136889865, 0.03995176870375872, 0.06804990382598979, 0.02364572573320142, 0.10574079384761197, 0.12721193528601102, 0.13737659342586994, 0.12221031795654978, 0.1064094358256885, 0.1414039023220539, 0.15081123395689897, 0.13631303049623966, 0.20097302086651325, 0.1622044611722231, 0.07216983953756945, 0.08544851200921194, 0.13195182808807918, 0.23656843868749483, 0.07685889649604048, 0.08046986987548214, 0.18182977022869246, 0.11895691896123545, 0.06458157886351858, 0.10823470181120293, 0.14157506956585816, 0.11889465658792428, 0.13854530214198998, 0.1376326996833086, 0.2123364196824176, 0.1099511104236756, 0.1803704042519842, 0.09583619103900023, 0.08890719498906817, 0.13647891873759882, 0.09050933830440044, 0.09681303040789706, 0.1589215730449983, 0.14731912634202413, 0.11111972414489303, 0.1563716113035168, 0.14338825084269047, 0.12866281957498618, 0.10743114671536855, 0.1272619433168854, 0.09692401838089738, 0.05252195901370474, 0.0945138077118567, 0.09480876009911299, 0.13346595184079238, 0.09523002178009067, 0.08282281897429909, 0.12712646701506206, 0.20999560957508429, 0.09519946734820094, 0.1370751881705863, 0.1619948074221611, 0.14308898975806578, 0.06699952483177185, 0.13239322868841036, 0.12842261817838463, 0.14403232985309192, 0.23033188762409346, 0.1967837456613779, 0.06425225189221756, 0.13026888482272625, 0.07817908815507378, 0.17742515515003884, 0.1145080498286656, 0.12647674259330544, 0.10406685474195651, 0.09463445802352258, 0.1956572418234178, 0.12536367374871457, 0.16026034977819237, 0.18893236267779553, 0.11377179183598075, 0.042244921904057264, 0.16144736536911555, 0.13668664544820786, 0.10361945589206048, 0.10973959070231233, 0.20346830625619206, 0.11559992123927389, 0.1324383241257497, 0.1375534196517297, 0.06861656199076346, 0.12801962266010897, 0.1287189887038299, 0.11930123477109841, 0.26163914054632187, 0.13723359895603998, 0.1400096621364355, 0.09591348974832467, 0.0797752875036427, 0.112816204183868, 0.09727387103651251, 0.12513078695961408, 0.06813216262630054, 0.10253815605704274, 0.11365635945860829, 0.1054210342200739, 0.16293467341789178, 0.12416775577834674, 0.15399405173957348, 0.2077995174165283, 0.10065225618226187, 0.11914036768887724, 0.12098493799567223, 0.1422849664730685, 0.11643818340131215, 0.15133321737604483, 0.2614956168191773, 0.18992979558450834, 0.15988939468349728, 0.2792670189269951, 0.10323028213211469, 0.14002955678318227, 0.10794960853776761, 0.19917669439954416, 0.3013287436749254, 0.09603362437337637, 0.11892232724598475, 0.15993529079215868, 0.11713525599667005, 0.09791056080056088, 0.19307143986225128, 0.13862954904990538, 0.11016438076538698, 0.14442343743784086, 0.09791202643620116, 0.0967004071655018, 0.18269327389342443, 0.10074902884662151, 0.09290719963610172, 0.10279051680117846, 0.12421327190739767, 0.2208966410585812, 0.12923345395496913, 0.14296047522553376, 0.11366117705724069, 0.14299657328852586, 0.1804624136005129, 0.07372830555375133, 0.11766930376844746, 0.18259542914373533, 0.11848293510930878, 0.17615370266139507, 0.0764001796820334, 0.14012672299785273, 0.0982226122702871, 0.10244814838681902, 0.18042429350316525, 0.16636818274855614, 0.19419243399585995, 0.16672235088688986, 0.10240350756794214, 0.10294869688472577, 0.1917367343391691, 0.08265052536236388, 0.07174748541521174, 0.152592822643263, 0.10485546849668026, 0.13104920009417192, 0.09781778470746108, 0.17140702450914042, 0.0862516328426344, 0.09096587702099766, 0.1478855809462922, 0.11693040627454009, 0.1320280818534749, 0.13364735139267786, 0.09173142058508736, 0.07241599168628454, 0.0844105366351349, 0.09685294183769397, 0.13693158301923955, 0.10858742466994695, 0.09376679493912629, 0.09881628291415316, 0.1371824238449335], [0.04018337645434907, 0.023064921809626476, 0.015214670283187712, 0.03378043842634984, 0.019461956839742403, 0.05128200072795153, 0.022251166636124253, 0.035480521486273835, 0.058760637284389565, 0.15394937699394567, 0.016713484589542662, 0.008918514159241957, 0.04647794904719506, 0.0514303149123277, 0.01881265819871, 0.026539580896496773, 0.050575201333101304, 0.03909713009904538, 0.09118096583655902, 0.02853689282866461, 0.05573435413784214, 0.032635115419647524, 0.02293108925888581, 0.044205307960510254, 0.02621593665597694, 0.018678722171378986, 0.003694615967106074, 0.02519182544866843, 0.040699748388890705, 0.05544457558010306, 0.0514822737313807, 0.02575535387066858, 0.07305814365723304, 0.047929956311626096, 0.011416958129432584, 0.02424005964504821, 0.03387755714356899, 0.05805728145475898, 0.05852236292724099, 0.016233868896961212, 0.026402325136587024, 0.025610228800880055, 0.03200803031878812, 0.019830557417922785, 0.02227242344192096, 0.04313200805336237, 0.011536069014774901, 0.02941212836386902, 0.011031687642181558, 0.005778653580429298, 0.0029106561144414756, 0.07785522339067288, 0.02593822923621961, 0.02633789145121617, 0.03388619828703148, 0.056480498385748694, 0.05081307874726398, 0.04227153744016375, 0.009234998158977499, 0.021367510481338416, 0.020809713983908296, 0.01665261490935726, 0.036594072090727944, 0.04353620118594595, 0.07951271480747632, 0.028044342562290173, 0.043781732475118976, 0.07057373518390314, 0.05166407361892717, 0.032785295575324974, 0.012089247233234346, 0.038340831574584754, 0.01628062335242118, 0.011836404729235386, 0.07080267289919512, 0.04016176172133003, 0.03625028893085463, 0.017082714508952837, 0.02150911225804261, 0.042331499579761706, 0.04812358984989779, 0.1064291133412293, 0.05727163968341691, 0.10480786926512208, 0.05010760249570012, 0.08514935270484005, 0.017112500499933958, 0.019867471419274807, 0.02879816952294537, 0.03984467552176543, 0.004645299083287162, 0.05751747292067323, 0.030840312263795307, 0.04527036366718156, 0.03518111790929522, 0.02428642563921, 0.06315176308687244, 0.033136237279645035, 0.02567384485155344, 0.02892703010833689, 0.035115836055151055, 0.008236019888759723, 0.013792565208859742, 0.06135705831859793, 0.030573569969939332, 0.04940047740404095, 0.05137303637872849, 0.08102314054433789, 0.02562267822213471, 0.06272172794810363, 0.033963354504001994, 0.014292754931375384, 0.03495720474581633, 0.08133519201406411, 0.02655485980877919, 0.07188982849142381, 0.013002169451543262, 0.024029036950586096, 0.040564367081969976, 0.00858931610959449, 0.04867220916120069, 0.07425931348864521, 0.038877423852682114, 0.03745896335957306, 0.05177375880469169, 0.07794666276978594, 0.05568556747000132, 0.03504237446135708, 0.018907351153237478, 0.01362440557152565, 0.0277516208589077, 0.023207851818629673, 0.042713772638567855, 0.012993188192402678, 0.011475173041357525, 0.07312381227633782, 0.1013382211593645, 0.004207355618876005, 0.05226106569170952, 0.027484719109322344, 0.06500892021826335, 0.09776801416384322, 0.014776811635653888, 0.07587989260043417, 0.029131968040019274, 0.03618798923811742, 0.029799653283719505, 0.024404019150616865, 0.025004483626357148, 0.04157201533338853, 0.06020341307989188, 0.05082805062245045, 0.019575667434505055, 0.01184653356072626, 0.018390412641955272, 0.03646595450118184, 0.044295983987727335, 0.022383012775597826, 0.024833718414551446, 0.019163469285038964, 0.016241076635196805, 0.04153338633477688, 0.05059323340122189, 0.003073288023837709, 0.03621306449973157, 0.012509987290416445, 0.03613170815099563, 0.04002257722562977, 0.071571643065129, 0.041807728220841715, 0.010192223624991519, 0.05374011257663369, 0.016155062143557837, 0.03052335498588426, 0.01752054431874837, 0.010812809208541043, 0.020682749903893898, 0.026567843576361026, 0.011763188256216901, 0.013577788519406957, 0.040764612943998406, 0.02518440566823951, 0.05560910675142493, 0.046916971382285864, 0.09822056309453078, 0.05364232550242117, 0.04114855519895043, 0.02373902769094067, 0.01612738978915981, 0.04056883862774287, 0.024986641548041786, 0.012267661231037761, 0.0516945296632392, 0.03042587325243013, 0.04015012484576021, 0.07286974162395511, 0.011940634493449969, 0.036634855438023806, 0.04479074797460011, 0.03424763014273984, 0.019667424028739333, 0.051338061291192255, 0.030820933303662708, 0.02135380746663681, 0.04155918762886098, 0.029572367801197937, 0.023547745276508585, 0.0607325957555856, 0.05626575562304684, 0.03236850883279528, 0.012982173872712468, 0.030652778755341257, 0.02066741501247244, 0.08362116292119026, 0.05548412399366498, 0.004882107380711074, 0.05254039141748633, 0.02491819772071072, 0.009350512808720981, 0.04567968313183103, 0.026800757506862283, 0.04288553699318852, 0.051469313712524514, 0.01905177054660661, 0.04307571000286511, 0.024965537412624274, 0.013003558751993945, 0.03208813137773957, 0.05069806366892798, 0.008904705971612461, 0.011860589413637561, 0.013758344991531755, 0.0329241950863174, 0.005918404652870127, 0.014031501985820276, 0.05220306451831545, 0.06599401735833713, 0.012132398667745292, 0.03549247048795223, 0.03888517950794526, 0.057869035484535356, 0.0211677599498736, 0.01638080904792462, 0.0798268425943596, 0.06490393049482789, 0.05113620390849454, 0.038265985769352744, 0.019900979174833213, 0.023641023485522186, 0.028057786037347147, 0.043683857191354036, 0.008331993578134902, 0.011198753989966852, 0.01754623874356704, 0.027008440112695098, 0.012849358276330998, 0.060019618299390586, 0.03104131469236953, 0.019353101163038185, 0.061194060636418204, 0.051610197938446484, 0.08343093562871218, 0.030720781534910202, 0.04028273433712976, 0.047549213349286995, 0.01443507256252425, 0.031456198144171915, 0.03831120673567057, 0.022758502180555036, 0.0628745136782527, 0.05301417510158249, 0.01597400355551924, 0.09575982192265135, 0.024239099517996823, 0.04036987180422459, 0.03647188828991992, 0.029175587663693086, 0.030092064557330947, 0.049559271561780145, 0.0341280145969774, 0.04228553901027356, 0.06373103521764278, 0.03149678471631237, 0.04490481988926019, 0.013685700184266483, 0.02453205531596073, 0.014331539993041327, 0.03918888160426702, 0.010946398334843772, 0.01995909061016781, 0.059842439235321114, 0.028804340798939978, 0.022988347436434457, 0.009048797123666321, 0.016519944349836026, 0.018610280040385466, 0.05012967184718166, 0.03241710211815579, 0.06533880358827965, 0.02618290387493159, 0.01938914494322879, 0.026071563063721572, 0.07006092555820942, 0.07726682496390172, 0.03027712819831712, 0.01627706952526101, 0.00828478959322508, 0.05592565690832479, 0.05166765967650073, 0.02729056988443647, 0.03014765014605863, 0.05761033722332545, 0.07352866019521441, 0.035364570029612095, 0.043482953150357516, 0.044414408704532046, 0.06890107172408275, 0.04730327493910279, 0.052313292532094886, 0.035682093884263716, 0.026283922472170422, 0.03183202512030091, 0.026281629023807387, 0.043439571013940234, 0.04878786884780441, 0.04446585862232106, 0.03764183533244899, 0.023358188037361418, 0.05595787375101021, 0.04908715707382985, 0.027581664800111736, 0.01583332458644041, 0.04801117356068321, 0.05668559916583555, 0.02964047236101968, 0.02627767825366131, 0.01579616291980658, 0.07256330842418329, 0.056927425653806756, 0.02936009151328887, 0.023451155816603984, 0.01867097499780357, 0.017903792771643827, 0.02255671943670937, 0.03994244902527758, 0.04002256704760449, 0.03495605123628463, 0.07397425414196082, 0.046360945861254416, 0.01166504919196346, 0.028961557362760817, 0.03801625434841428, 0.11011505126953125, 0.10935656446963549, 0.08376561624131032, 0.0988572257171784, 0.14025032493684972, 0.14264004384832724, 0.13866278369511875, 0.14459710169051374, 0.19169987631695612, 0.2413846259670598, 0.11047438984470707, 0.06617940669613225, 0.16358173798237527, 0.2616615322019373, 0.12308161120329585, 0.0980792378208467, 0.12394943035074643, 0.14719940562333378, 0.14674448860543116, 0.1458194282438074, 0.12085605705423014, 0.12349779744233404, 0.17527719826570579, 0.20010520171906265, 0.09162760472723416, 0.12779289696897778, 0.10423781163990498, 0.09098495742572205, 0.18751989704157623, 0.08529554985995803, 0.13052784092724323, 0.16410541773906775, 0.14853906445205212, 0.14338195403771742, 0.11616318672895432, 0.11974981427192688, 0.14477064380688326, 0.1640212115432535, 0.12110171387238161, 0.11627912122224059, 0.09067843601639781, 0.1401359782155071, 0.0612871420702764, 0.07413579975920064, 0.10390379599162511, 0.10119929111429624, 0.22804248332977295, 0.07533060493213789, 0.08337119740567037, 0.07409634294786624, 0.07071259059011936, 0.11877366022339889, 0.15530074733708585, 0.08252715412527323, 0.11370823346078396, 0.15716709861797945, 0.10515242934759174, 0.18323972528534277, 0.13601528933005674, 0.21550494751759938, 0.07319913644875799, 0.09481781854161195, 0.15032943338155746, 0.1294999417981931, 0.19332511696432317, 0.07571129700435059, 0.12547622913760798, 0.19965648651123047, 0.1725818943232298, 0.24982904855694088, 0.1127731850636857, 0.1234576553106308, 0.09091430835958038, 0.08615594583430461, 0.1337015391992671, 0.11756552862269537, 0.10174692315714699, 0.10819495322981051, 0.1153116524219513, 0.10315180955720799, 0.1396838431911809, 0.19854580610990524, 0.1757521592080593, 0.19366605366979325, 0.13630249963275023, 0.20688063172357424, 0.11650410986372403, 0.11791770186807428, 0.10889653808304242, 0.13970889470406941, 0.06856115282114063, 0.08479312182004962, 0.1751733281250511, 0.17722466162272862, 0.1191466644938503, 0.20493011495896749, 0.1587827583508832, 0.08115862363151141, 0.13957169492329868, 0.0779745437737022, 0.15047397491122994, 0.2042678240686655, 0.11562223147068705, 0.12943478886570248, 0.1501426055495228, 0.16969760480735982, 0.08271744927125317, 0.16242066957056522, 0.11995827380035605, 0.10498961486986705, 0.13605111597904138, 0.06846651754208974, 0.10382755579692976, 0.1848861633666924, 0.1581902072897979, 0.1495262107678822, 0.1458539113934551, 0.14583485813013145, 0.1610053133751665, 0.0866570710869772, 0.1444724276661873, 0.14366833652768815, 0.17316652009529726, 0.09126511096422162, 0.15024559359465325, 0.12356745584734849, 0.10773631784000567, 0.10423870052077941, 0.1071382842159697, 0.08526741779808487, 0.1090239601741944, 0.07156798576137849, 0.14638672423149857, 0.14773117351744855, 0.09257817122020892, 0.14733789462063993, 0.24726741601313862, 0.13298250921070576, 0.14258139128131525, 0.15238770150712558, 0.19273821131459304, 0.15250487093414578, 0.15010630392602511, 0.17081942675369127, 0.25291746854782104, 0.15044968335756234, 0.13056459038385324, 0.10201613192579576, 0.10600466933101416, 0.10952987588409867, 0.11960414637412344, 0.1197276126061167, 0.13702364665056976, 0.08688844474298613, 0.10157655658466475, 0.09303887614182063, 0.1404086271567004, 0.10971138400158711, 0.10863399931362697, 0.07362828949200255, 0.049546250474772284, 0.14515936294836657, 0.1358325598495347, 0.1322674418666533, 0.16371196242315428, 0.1646575823958431, 0.08069170332912888, 0.09278539581490414, 0.13538184974874767, 0.1609342164759125, 0.1468652542680502, 0.11124002161834921, 0.05770408362150192, 0.1282743854182107, 0.058385644906333516, 0.09923824348620006], [0.018060169648379087, 0.013475313616384352, 0.059411399864724705, 0.058190450737518926, 0.018173579991395985, 0.10201725150857653, 0.05638103193736502, 0.06532359761851174, 0.010417366633191705, 0.03893555734040482, 0.01488122290798596, 0.03665143883387957, 0.02835652804268258, 0.01770454435609281, 0.03066778794995376, 0.045942418676401885, 0.028348811403183, 0.035750602172421556, 0.023157370509579778, 0.05803209423486676, 0.02070670558272728, 0.07214756323290722, 0.014342189600159014, 0.024541059475658194, 0.07286448297756058, 0.007910026220737823, 0.01951480284333229, 0.04386907011004431, 0.03724533678697688, 0.02069340968903686, 0.032076338439115455, 0.013987772948374706, 0.018403666127207022, 0.006644941783244056, 0.022854033125830547, 0.024492004786485007, 0.05013096106371709, 0.033588993163513284, 0.018467794471819485, 0.020561475340010862, 0.05404551440317716, 0.029757713034216846, 0.008331049566290208, 0.05752841769052403, 0.037049341946840286, 0.055037899009351215, 0.012259668088518083, 0.02045558486133814, 0.0013639379779176253, 0.05933207233569451, 0.007205969803700489, 0.02160044476789023, 0.011503720705929612, 0.01763137792503195, 0.012025636271573603, 0.08017854765057564, 0.023430764142956053, 0.0199261613057128, 0.04045646305062941, 0.014034957425402743, 0.03121093487633126, 0.027733161313725368, 0.06008701718279293, 0.008970938622951508, 0.01940248324535787, 0.030198540272457258, 0.012558315947119678, 0.015148353663140109, 0.07036746732358422, 0.007488125868673835, 0.014176248772335904, 0.008213811437599361, 0.022188364827473248, 0.006287440341631216, 0.03787250331203852, 0.051198188082448075, 0.03801121622590082, 0.011433165786521775, 0.07548324138458286, 0.03999863172482167, 0.015277533159990395, 0.021842216973059943, 0.014785271270998886, 0.02567390931238021, 0.045175277162343264, 0.055564781451331716, 0.023971064614930322, 0.05434024287387729, 0.048403013963252306, 0.0069624550357860115, 0.06739409973046609, 0.03557369452235954, 0.08048709787960563, 0.02179123694077134, 0.04482861362131579, 0.013673336428057934, 0.0284167361512248, 0.059476763143071106, 0.004524477017444691, 0.05156489894060152, 0.023561947014448897, 0.018211635627916882, 0.10123092441686563, 0.05086278822273016, 0.06772916032267468, 0.01962989934587053, 0.01238884758536837, 0.08336717369300978, 0.02486204555524247, 0.03256330605862396, 0.02970068555857454, 0.018414173241970793, 0.024285395962319205, 0.08115881362131663, 0.02023088459723762, 0.0670084407819169, 0.074416055077953, 0.0712330269494227, 0.018412675375917127, 0.04826383964557733, 0.021024100515725355, 0.03881067297022257, 0.03256083958383117, 0.004033986528936241, 0.04010719732780542, 0.04219637272347297, 0.07305638625153474, 0.03698796166905335, 0.014683757343196442, 0.029313798461641585, 0.026017241246466125, 0.021275472295071398, 0.027005513930427175, 0.020076656980173926, 0.02623574648584638, 0.027961656284917678, 0.026775276820574487, 0.02366662461177579, 0.05912853218615055, 0.02452933099786086, 0.02025397853659732, 0.0561856545640954, 0.01997579274965184, 0.01259950387092041, 0.01698120736650058, 0.0391914023618613, 0.01796998386271298, 0.040342642193926234, 0.009747076663188636, 0.07031536940485239, 0.04363211211083191, 0.023254514671862125, 0.06388004829308816, 0.015328604794506515, 0.037172078753688505, 0.02440246021641152, 0.04705562322799649, 0.0035284024530223435, 0.03461939608678222, 0.015513878781348467, 0.043225272691675594, 0.04665925021150282, 0.02927857910149864, 0.03807431998263512, 0.07069531508854457, 0.032261934730091264, 0.03915550107402461, 0.02037435064890555, 0.06891762119318758, 0.0668259962861027, 0.05496335175952741, 0.011798707019936825, 0.01696111255192331, 0.03537724845643554, 0.003671642467712185, 0.027889283739828637, 0.0194028445652553, 0.031050247605890036, 0.0774149355877723, 0.0323362682413842, 0.024880617058702877, 0.05491477204486728, 0.0371361876438771, 0.07735177076288632, 0.05067715121965323, 0.0506410226225853, 0.056113475401486666, 0.023103981677974974, 0.03870694532192179, 0.021641776032213653, 0.05868241576743977, 0.012237848098655897, 0.021636629344097207, 0.06517841826592173, 0.026155448651739528, 0.021970906228359257, 0.011820316663943231, 0.060364850131528716, 0.033081214874982834, 0.026592969728101577, 0.04664184918094959, 0.0018189119291491807, 0.02774538003307368, 0.04590454285166093, 0.04685257501634104, 0.0059595158173968744, 0.027242760307022502, 0.046944774354674985, 0.024838471552357078, 0.016498171857425144, 0.018393072499228374, 0.019016798851745467, 0.06013515924236604, 0.04239214025437832, 0.010266753911439861, 0.033281593051339896, 0.04843915952369571, 0.017052495951897333, 0.03685905697888561, 0.05354321528492229, 0.06976732345564024, 0.02801606122271291, 0.01706703526100942, 0.04904803953000477, 0.026773426116311123, 0.05953753273934126, 0.014866334153339267, 0.00952703708649746, 0.0350823266032551, 0.016302981081285646, 0.03706552839971014, 0.10854610188731126, 0.039002257332737954, 0.01150670541184289, 0.04194135551473924, 0.17090086452662945, 0.015324355468952229, 0.045043281745165586, 0.024803028275657977, 0.043385596945881844, 0.017747125821188092, 0.013239507430366107, 0.06048776675015688, 0.03446358069777489, 0.024034178549689904, 0.015050091614414538, 0.036227591934480836, 0.007398995204961726, 0.03882937000266143, 0.040481602773070335, 0.040956919946308644, 0.02009582220177565, 0.036177400699151416, 0.0043517406614098164, 0.02705627174249717, 0.04851418174803257, 0.024616755146001066, 0.025966731099677936, 0.02288250275887549, 0.06951857930315392, 0.0304094730610294, 0.015702979705695595, 0.019911460844533782, 0.02666222949379257, 0.016519403218158653, 0.04307698904137526, 0.024808071487184082, 0.02280174182461841, 0.03607078927702137, 0.030019502022436688, 0.010214443102345934, 0.032151262275874615, 0.055658412498555014, 0.10994845735175268, 0.03183355860944305, 0.027553493722475002, 0.03365649382716843, 0.06686924610819135, 0.023769940050052743, 0.054055607611579556, 0.02859406279666083, 0.07550070009061269, 0.02702239079267851, 0.13027739365186009, 0.037839489190706184, 0.05639619719503181, 0.05732143058308533, 0.015421655694288867, 0.01867454239566411, 0.02540072093584708, 0.01702789736113378, 0.04538298351690173, 0.08529370424470731, 0.033072573731520345, 0.031907257690493546, 0.038858346840632815, 0.04449687785069857, 0.05223373430115836, 0.02634204238919275, 0.02549861148664994, 0.025754953535007577, 0.00230062090226316, 0.042091277827109606, 0.04686789294438703, 0.055276085156947374, 0.01086169426395957, 0.01739368201898677, 0.012663917200240706, 0.011327719748286265, 0.06261027178594045, 0.02201894990035466, 0.03569471802828567, 0.00788748189474323, 0.051631982305220196, 0.09542164006935698, 0.02446944688979004, 0.010604311512517077, 0.014778835366347005, 0.04043946574841227, 0.06271005036043269, 0.01878256517063294, 0.044023362187934775, 0.023077227042189667, 0.025325847989214317, 0.03092744294553995, 0.076046350811209, 0.03350422039095845, 0.044577552271740775, 0.047255020921251605, 0.04149232818079846, 0.05946644941078765, 0.0481648006742554, 0.042333128063806465, 0.042285776497530084, 0.0026529962238523042, 0.01646847916500909, 0.0909778056666255, 0.10642173088022641, 0.04984749288165143, 0.03966887388378382, 0.02825171304201441, 0.05531182698905468, 0.05647033393116934, 0.03590928776455777, 0.048804062086024454, 0.08681451835270439, 0.030077021435967514, 0.017062819862206067, 0.026948915628184165, 0.017730873211153915, 0.037387873245669265, 0.03862703764545066, 0.10556885307388646, 0.12372349176023688, 0.1501952191548688, 0.10737879773867981, 0.07062974824969258, 0.2356199552970273, 0.13720139568405493, 0.1133119079417416, 0.0673680914832013, 0.11614653547959668, 0.10116231774113008, 0.08336989461843457, 0.14232083383415425, 0.08009983080306224, 0.1156112120619842, 0.20197337147380623, 0.09585015528968402, 0.1440997626632452, 0.06284131295979023, 0.1357138297919716, 0.15599324660641806, 0.15771026590040751, 0.09507252701691218, 0.12258258940918104, 0.16134961561432906, 0.06204229726323059, 0.132114174376641, 0.16174146958759852, 0.12401184200176171, 0.13354178491447652, 0.09285675055746521, 0.1493094866829259, 0.08667967308844839, 0.12923762015998363, 0.11673349541212831, 0.14906617759593896, 0.37320058420300484, 0.11573512612708978, 0.08739288124654974, 0.06369657242404562, 0.10806852858513594, 0.09151013674480574, 0.09461233099656445, 0.24574635763253483, 0.1726295274815389, 0.12086620793810912, 0.10935495634164129, 0.08008203282952309, 0.0891737099736929, 0.16020977177790233, 0.09951485507190228, 0.08230297972581216, 0.1252572794577905, 0.10393749882600137, 0.10209919139742851, 0.23269142529794148, 0.07289078978023358, 0.09967454828854118, 0.1521212136639016, 0.246109346726111, 0.12702546029218606, 0.14641854752387318, 0.11222412131194558, 0.22430165191846235, 0.09672547224909067, 0.09315960109233856, 0.10572975408285856, 0.10305374089096274, 0.1108484865565385, 0.07657073624432087, 0.1222429419202464, 0.1233250152851854, 0.09519096530441727, 0.10740929110241787, 0.13822449078517302, 0.13195877628667013, 0.11529045498796872, 0.17978394643536635, 0.2121653202921152, 0.10531553559537445, 0.09232481981494597, 0.09908446709492377, 0.05758363687034164, 0.09407491090574435, 0.09948077904326574, 0.13950323073991708, 0.10522075782396964, 0.18455921805330686, 0.18375873672110693, 0.09112367033958435, 0.2006529966103179, 0.08343187200703792, 0.11831387132406235, 0.15691589138337544, 0.11441822536289692, 0.11978090474648134, 0.13757916327033723, 0.16479685849377088, 0.08735789598098823, 0.20045581433389867, 0.10509377678057977, 0.10113917291164398, 0.14261246818516934, 0.0949534916185907, 0.13873312063515186, 0.15522066663418496, 0.11021431415740933, 0.2569777135338102, 0.15330681790198597, 0.13129877884473118, 0.1161354753587927, 0.09576305174934012, 0.07202742182250534, 0.1856442226895264, 0.09927430083709103, 0.17460232733615808, 0.16192008714590753, 0.1566105777663844, 0.09480562526732683, 0.09286846885723726, 0.13535294415695326, 0.1331456968826907, 0.17035579734614917, 0.08961464238486119, 0.13457724292363438, 0.12848774396947452, 0.21008961381656782, 0.18069808238318988, 0.07803990026669842, 0.1279297031994377, 0.15960848118577683, 0.10939815866627864, 0.10212172554539782, 0.14235032296606473, 0.10674045234918594, 0.1573267714785678, 0.11555318374718938, 0.0874320123610752, 0.2783557463969503, 0.1457175122840064, 0.26180416026285713, 0.09083014966121741, 0.14355358268533433, 0.19086265909884656, 0.07628721717212882, 0.1581665671297482, 0.09989326726645231, 0.10443899048758404, 0.11497869528830051, 0.2521110703902585, 0.10246854514947959, 0.12439506500959396, 0.1614308226853609, 0.1204472261347941, 0.14536319486796856, 0.1858391793710845, 0.1369194643838065, 0.15754577544118675, 0.1001234059887273, 0.14128039537795953, 0.1363005590225969, 0.26968238609177725, 0.14173396889652523, 0.11013797896781138, 0.20780258439481258, 0.09867120534181595, 0.14834645550165856, 0.11873756216040679, 0.19005296326109342, 0.1682978142052889, 0.125123689483319, 0.07559295371174812, 0.11878807230719499, 0.16316807589360646, 0.06732559483498335, 0.1714322795825345], [0.018504377687349916, 0.046506545905555995, 0.01573422285062926, 0.06068026713494744, 0.006168091544947986, 0.007882853437747275, 0.05105953962941255, 0.018846696907920495, 0.03591561849628176, 0.04182777553796768, 0.05413093178399971, 0.030196820186184983, 0.09340060316026211, 0.005486844506646905, 0.043054085091820786, 0.02702632629578667, 0.040213184497718296, 0.01255503947114838, 0.04208479781768151, 0.03152189390467746, 0.05861384980380535, 0.033741666935384274, 0.018407333608982817, 0.04273073262135897, 0.02738410254408206, 0.0178049064707011, 0.03177462784307344, 0.009131750574202409, 0.02435190766118467, 0.06405526639095374, 0.022738224161522727, 0.08520148455032281, 0.02500130808246987, 0.041714263414697986, 0.0395114944715585, 0.04729095274316413, 0.009601201812204505, 0.021355435950681567, 0.06369229086807796, 0.045888020523956845, 0.02648272305460913, 0.049257330263831785, 0.03250901986445699, 0.034847153151141744, 0.008920568424010915, 0.040417152124324014, 0.030049937710698162, 0.02367080269115312, 0.011169716932012566, 0.03352024060274873, 0.04026774889124291, 0.03826646752921598, 0.04434316931292415, 0.015824040531047752, 0.07118982462478535, 0.029008708761206696, 0.038785611279308796, 0.020855158866782273, 0.02790811817560877, 0.006387752414281879, 0.02348915547398584, 0.021284503596169606, 0.0580211766064167, 0.0222067124143775, 0.0628623611160687, 0.03921814003427114, 0.014539582222434027, 0.03588494532076376, 0.0591816207660096, 0.05012531565236194, 0.03717571570138846, 0.06900821240352732, 0.03539583013792123, 0.0464994653926364, 0.01183792295133961, 0.01808330599617745, 0.03832929987194283, 0.035890030940728526, 0.01974787962223802, 0.03212352376431227, 0.08917057514190674, 0.06638407321380717, 0.1241495031863451, 0.05917640961706638, 0.030199381655880382, 0.02623608066434307, 0.013278608858984495, 0.03397335950285196, 0.024038069948021854, 0.05531032742666347, 0.04060884165976729, 0.0355898775825543, 0.00840485721294369, 0.03204536331551416, 0.015362572257540055, 0.02267106785438955, 0.07811441019709621, 0.013316116578477834, 0.02073387073219887, 0.04624273827565568, 0.023008087716464485, 0.06275699819837298, 0.015273835144138761, 0.010285098953837795, 0.011988137033767998, 0.019516395704288567, 0.04217763837160809, 0.03804805049938815, 0.01650494702958635, 0.07326487292136465, 0.06089071477098124, 0.01669189869426191, 0.08000859498445477, 0.014920898546863879, 0.05219740553625992, 0.060911057250840325, 0.02048273983278445, 0.010418850080376225, 0.06826851423829794, 0.02365897243310298, 0.018319515910531794, 0.006907647641907845, 0.0669574285192149, 0.012565147946588695, 0.015355863242543169, 0.03959179909101554, 0.021183072788906947, 0.04673247092536517, 0.020351913192176392, 0.023446124479440705, 0.023830046378342167, 0.02415993992638375, 0.046834570089621205, 0.013376554540757622, 0.03533791717407959, 0.0015608944294009624, 0.035421797673084905, 0.013635922855298434, 0.06018062108861549, 0.026786377653479576, 0.03595085481980017, 0.036769473393048556, 0.058201504072972705, 0.008941431679496807, 0.030299343434827666, 0.013560721667350402, 0.019420920738152096, 0.023033585366127745, 0.07857458586139338, 0.034695514145174196, 0.042605288459786346, 0.04576083592006138, 0.0471773591956922, 0.07411046326160431, 0.02889113899852548, 0.0068242103110865825, 0.04446380266121455, 0.025528146419674158, 0.027539473492652178, 0.036426976057035584, 0.03999745446656432, 0.04231474994282637, 0.005411176401789167, 0.02389034439277436, 0.07909623001302991, 0.024943576626745716, 0.015231292694807053, 0.00779575583458479, 0.028147408638947775, 0.03977012487926653, 0.028054778430876986, 0.018817099210407053, 0.02405560159656618, 0.05331705956320677, 0.012500179066721882, 0.09415811286973101, 0.009807950584217906, 0.055413084769887586, 0.022581219639895216, 0.04181509032579405, 0.023618657274969986, 0.020848426103059734, 0.01978603534267417, 0.018439307875399078, 0.021432850010959164, 0.06681757566652127, 0.07475772460124322, 0.009344941188049103, 0.028178750171459148, 0.020879991552127258, 0.044803331406520944, 0.010022488090076616, 0.03108543643195714, 0.007846815594738083, 0.039242614792393785, 0.048162893990853, 0.026700424229992286, 0.005291680447823767, 0.04672082047909498, 0.020288554984810095, 0.021439472512741174, 0.006984315737749317, 0.03655810973473957, 0.04549187481669443, 0.08781948978347437, 0.07045790247086968, 0.0017006939534829663, 0.018270652907501374, 0.059856769894914966, 0.026984133291989565, 0.06517885931368385, 0.02061569707335106, 0.03284882341644593, 0.01233614661863872, 0.04966709416891847, 0.00998727381894631, 0.051043624590550146, 0.039837744286549945, 0.016475066043702618, 0.018664930947124958, 0.029107082768210342, 0.023240609792992473, 0.049580913436199935, 0.013790616117018675, 0.03810267596106444, 0.056125916341053586, 0.03852322857294764, 0.08515863506389515, 0.05168234317430428, 0.028707629202732017, 0.11614961602858134, 0.016720246191003492, 0.015456467933420624, 0.03163403877988458, 0.03436185472777911, 0.016247227555140853, 0.01704019750468433, 0.06182431788848979, 0.07501589360513858, 0.03528803467218365, 0.040187929424324205, 0.05092897592112422, 0.03520911765683975, 0.017540774840329374, 0.03167508675583771, 0.013666972617751785, 0.040633340166615586, 0.054689355926322084, 0.045360554541860304, 0.02758046379312873, 0.012701574197438146, 0.07731275499931403, 0.028884109375732284, 0.07572313065507583, 0.019680708048066924, 0.05290916841477156, 0.05101993693304913, 0.027384792953463535, 0.05049640306138566, 0.04355407379833715, 0.054965818234320195, 0.05156226622472916, 0.025595379061996937, 0.06252918006586176, 0.018153929617255926, 0.04836101603827306, 0.03277775705126779, 0.007123678772976356, 0.06361056132508175, 0.028963806706347635, 0.05089689139276743, 0.007234807541993047, 0.02268600241015, 0.003453573187081409, 0.024153208858998756, 0.08693497867456504, 0.059785944409668446, 0.05532429846269744, 0.013139513421005436, 0.020038535186488713, 0.02587281506774681, 0.03968285509784307, 0.018439475812816193, 0.023394250477265035, 0.09758339157061917, 0.07249873903180871, 0.02692646629709218, 0.016744033932419758, 0.07291787011282784, 0.02064003442813243, 0.0407490541360208, 0.03486549395269581, 0.030913108893271004, 0.036688245965966156, 0.08083790726959705, 0.02241203880735806, 0.0246621219973479, 0.0551046770332115, 0.05010572634637356, 0.046750869402395825, 0.020882115366735628, 0.016982108121737838, 0.025624479732609222, 0.006248985641702477, 0.02713439317553171, 0.033243897038378885, 0.047435344995132515, 0.044059667204107554, 0.025825107270585637, 0.011609302451168852, 0.02155087948111551, 0.03770849461268101, 0.02872874860518745, 0.026176199948947345, 0.042118290306202004, 0.02964431286922523, 0.009664402260178966, 0.02801532161954258, 0.08005863694208008, 0.06324192003480025, 0.03713508841714688, 0.024581491681081907, 0.02225004366066839, 0.05884425315473761, 0.06757349760404655, 0.01610099647327193, 0.026018225122243166, 0.03255052924422281, 0.06688304072512047, 0.054179840588143895, 0.03415259113535285, 0.03587832621165684, 0.06558103380458695, 0.015115833176033837, 0.028846990117537122, 0.0030271718153796557, 0.03874207986518741, 0.023980055203927413, 0.04572877514043024, 0.0320162236291383, 0.06411860084959439, 0.08152068991746221, 0.029312543171857084, 0.06611819605209998, 0.04326205946771162, 0.044012753292918205, 0.03112924604543618, 0.014825094491243362, 0.030860390114997114, 0.021568272029981017, 0.029574104850845676, 0.025574556518612162, 0.10471606347709894, 0.21559743184064115, 0.08085563738963433, 0.14733906170087202, 0.057208658062985966, 0.12995084188878536, 0.15956137728478226, 0.08164590676980359, 0.2379397036773818, 0.1681903206876346, 0.12597846718771116, 0.05718402045645884, 0.15679247943418367, 0.06327494433415787, 0.14861694670149259, 0.09729263252977814, 0.09265522565692663, 0.11477438839418547, 0.09224205211337123, 0.11845746290470872, 0.09840723486351115, 0.0724350924470595, 0.16620937841279165, 0.1402499856693404, 0.05646246631762811, 0.1168646833726338, 0.0987858370478664, 0.10702072802398886, 0.1468350730304207, 0.17467784828373364, 0.06166490287120853, 0.14381925628653594, 0.11302800210458891, 0.1032137598044106, 0.140242548925536, 0.16642978015754903, 0.12285017647913524, 0.07239837691720043, 0.10271155568105833, 0.09911616825099502, 0.15526158229580947, 0.1485779716500214, 0.09278970451227256, 0.09908724230315004, 0.0645670582141195, 0.0989781745842525, 0.11485639613653932, 0.17767542600631714, 0.1569280100188085, 0.14851747346775873, 0.13709586991795472, 0.15761717089584895, 0.10331197774835996, 0.17846324587506907, 0.19692218037588255, 0.07794797912772213, 0.11816839341606412, 0.17067230679094791, 0.13894985829080853, 0.10665756929665804, 0.10285533046615974, 0.15747210010886192, 0.11465029790997505, 0.10395393294415303, 0.22955615924937384, 0.16026910287993296, 0.11553486330168587, 0.1255467017846448, 0.19135655116822037, 0.11351447100085871, 0.12569330606077397, 0.13058262584464891, 0.08262313290366105, 0.11671068306480135, 0.09319839972470488, 0.1653093152812549, 0.08493673375674657, 0.10424988956323691, 0.07078110905630247, 0.1293009546186243, 0.14716492247368607, 0.15248693046825273, 0.15918711093919619, 0.11888443785054342, 0.13159850133316858, 0.1913022276546274, 0.20936887391975947, 0.17907801217266492, 0.10112136815275465, 0.14316362861011708, 0.15246487808014664, 0.07337791685547147, 0.10670261045119592, 0.08728748440210309, 0.11661069414445333, 0.10619001117135797, 0.13464574781911715, 0.09805378597229719, 0.06649171600916556, 0.23946906732661383, 0.11799538055700914, 0.1076192841199892, 0.09568131542099373, 0.13875205176217215, 0.1128727872190731, 0.11361427671675171, 0.1528083932186876, 0.09252521156200341, 0.2542735886360918, 0.17735928297042847, 0.09202445271824088, 0.10413011456174509, 0.1830945730741535, 0.08643493229257208, 0.11598352422671658, 0.14167343000216143, 0.12145688624254294, 0.07070908934942313, 0.1666502361851079, 0.1435773585523878, 0.09372518717178277, 0.10566799382546119, 0.23750291711517743, 0.1662028237645115, 0.11705247472439494, 0.18055826345724718, 0.11832246157739844, 0.07345814005072628, 0.13861805466668947, 0.16844759402530535, 0.14287804679146834, 0.11030652706644364, 0.10630173874752862, 0.08298255290303912, 0.12063511248145785, 0.12263228531394686, 0.13175970768289907, 0.15337552635797433, 0.12539681339902536, 0.16350271579410347, 0.08605833857187203, 0.08629852639777319, 0.18929805234074593, 0.1746894648032529, 0.07925775527421917, 0.13704578046287808, 0.12723461192633423, 0.12966086316321576, 0.19651991767542704, 0.04750153947887676, 0.10852005971329552, 0.08619201675589595, 0.15475071328026907, 0.18265497737697192, 0.15082625672221184, 0.12353143920855862, 0.11675178871623107, 0.10895477674369301, 0.09747471061668225, 0.06642101266022239, 0.1127063629350492, 0.11248170677572489, 0.14028965282653058, 0.1492630070341485, 0.1252127404191664, 0.13024394187544072, 0.09374999441206455, 0.1410532354244164, 0.08234571386128664, 0.07536252321941511, 0.09033526693071638, 0.15245816058346204, 0.06927115150860377, 0.18875236090804848, 0.1339783679161753, 0.13368043676018715], [0.021643341751769185, 0.032066645566374063, 0.032319332007318735, 0.004848070367838123, 0.007667431291858, 0.04644605790131858, 0.05635525439200657, 0.06920700280794076, 0.023872502314459, 0.03200922454042094, 0.03439212078228593, 0.015054551285824605, 0.031056310316281657, 0.043671450178538046, 0.011758047505281866, 0.032759748731872866, 0.020773086663601652, 0.044211241749248335, 0.023648092124078954, 0.050832172722688744, 0.058723894613129754, 0.0756614450365305, 0.035517002921551466, 0.05425467621535063, 0.007615386807758893, 0.04232329269871116, 0.017015210452622602, 0.028650754397468906, 0.05776405254645007, 0.03184635917256985, 0.03511106256129486, 0.01571726965318833, 0.03817276184314063, 0.10615172144025564, 0.053924931945013146, 0.0838916337649737, 0.025220946475331272, 0.027326562774500678, 0.022110316336953213, 0.02048827667853662, 0.03613076498731971, 0.031028639658221176, 0.018810539473114268, 0.03694828094116279, 0.014294322347268462, 0.03744072773094688, 0.03777156783533948, 0.015473818073847463, 0.07509386406413146, 0.037116143719426224, 0.007234611615006412, 0.03160321632666247, 0.03523385365094457, 0.035470645409077406, 0.05244792066514492, 0.061599492095410824, 0.047553182779146094, 0.051119372847356966, 0.0352360012142786, 0.02565537003933319, 0.025230564709220613, 0.03198845458350011, 0.026357804757675955, 0.027154532094885196, 0.018202151404693723, 0.06816041003912687, 0.020223327413467423, 0.04985784054068582, 0.020645535650796125, 0.020370639062353542, 0.03872866862054382, 0.03737008884283049, 0.025434874996010746, 0.02613259559231145, 0.03923540196514555, 0.03087010673646416, 0.04838750943807619, 0.027214419595631104, 0.018353532567354183, 0.059952436547194204, 0.06430907241467919, 0.03573232922436936, 0.05084069172984787, 0.023901467278067554, 0.01186399650759995, 0.0627950436568686, 0.035695827433041165, 0.030859368919794048, 0.054771933638091595, 0.04567595458190356, 0.04568061611748167, 0.04953060006456716, 0.04048855097166129, 0.059366161935031414, 0.03106285139386143, 0.05501875414380005, 0.06658133012907845, 0.06276771226631743, 0.03189188547964607, 0.03599373484030366, 0.03365569654852152, 0.006923985492903739, 0.02371126034164003, 0.014481177320703864, 0.0335635311369385, 0.057479481744979105, 0.034932271976556094, 0.0674871268815228, 0.00919966768872525, 0.01596594595217279, 0.03262120205909014, 0.044874027970113924, 0.043587098097694774, 0.0822520556726626, 0.03435743407213262, 0.011180271544227642, 0.03977000613563827, 0.010362167809424656, 0.05810496211051941, 0.010630239183748407, 0.005180945653202278, 0.009974118721272265, 0.06977514017905508, 0.015790453047624657, 0.05838359573057719, 0.023148361260869672, 0.02164552833086678, 0.039779074756162505, 0.06092442439070769, 0.04927488735743931, 0.026319973037711213, 0.09498810368989195, 0.10491331360702004, 0.03388547903991171, 0.0640532782833491, 0.043359039085251946, 0.030731295435024158, 0.025843921350315213, 0.045356425656271834, 0.014548845921776124, 0.06022349771644388, 0.0214401612257851, 0.04623290630323546, 0.03927887909646545, 0.024396660438339626, 0.009658382806394781, 0.039493669356618605, 0.05829590865011726, 0.03513153735548258, 0.05710921197065285, 0.03183466801419854, 0.080260792880186, 0.02845403352486236, 0.051498270194445334, 0.015268260978960564, 0.020205049376402582, 0.027494434034451842, 0.03213484512109842, 0.011304152530751057, 0.0413662970864347, 0.04477992194837757, 0.0068488894778835985, 0.020593805837311914, 0.037661414460412095, 0.0329145564963775, 0.06868761139256613, 0.0708589166668909, 0.03446164348029664, 0.05815404733376844, 0.0158213314799858, 0.03177185942019735, 0.023171624833984033, 0.006892067629710904, 0.04979894030839205, 0.03138433789302196, 0.07479948164629084, 0.1027704660913774, 0.0422085083222815, 0.08265847100743226, 0.024054013824622546, 0.05139339921463813, 0.016840511434046284, 0.02321628261623638, 0.1017045961426837, 0.03007869402478848, 0.04537161805533937, 0.03502438649801271, 0.01562419330834278, 0.055160676528300555, 0.019472112812634026, 0.033113489393144846, 0.021376511248360788, 0.028081346469532167, 0.02109937379801912, 0.06524522682385785, 0.02163649194075593, 0.04048722443569984, 0.026925874275288413, 0.015599462403250592, 0.011833483635980104, 0.007728719967417419, 0.07490816260022776, 0.026767967302086096, 0.035892069938459566, 0.05610635417646595, 0.019858862506225705, 0.03661902860871383, 0.009060259276468838, 0.0319685769001288, 0.08319554504539285, 0.10843990437154259, 0.05821374484470912, 0.033591805691165585, 0.022137084543438892, 0.0183209934205349, 0.04177522639344845, 0.0721082692699773, 0.03859678855431931, 0.05231468013620802, 0.06922064814716578, 0.014261045293616397, 0.031342027841934135, 0.011031061693626856, 0.03156623277547104, 0.045430168842098544, 0.01916306046769023, 0.04970069183036685, 0.05084219807758927, 0.04946791699954441, 0.07269390605922256, 0.07513190273727689, 0.03776762215420604, 0.025194710918835232, 0.03849589378972139, 0.0031185473697925253, 0.07673374749720097, 0.012303453105102693, 0.030352560936340263, 0.0045065870175936395, 0.019363464089110494, 0.02837084004256342, 0.03293201180973223, 0.01756760581130428, 0.03248049085959792, 0.07190854927258832, 0.06767169519194535, 0.0361482915468514, 0.04817744517432792, 0.036754297957356484, 0.007434294292969363, 0.02009544731117785, 0.009475259775561946, 0.030797937751880715, 0.007062046589063746, 0.02702216517978481, 0.07769715865807873, 0.013069223130254872, 0.015049106042299951, 0.031794454636318345, 0.03635385712342603, 0.0474834463426045, 0.023632499389350414, 0.02544402504073722, 0.015160097407975366, 0.06522700815860714, 0.034872320014983416, 0.017630426279668297, 0.0397367545270494, 0.009176306576201958, 0.10389836771147591, 0.023811719147488475, 0.010826307814568281, 0.05174421878265483, 0.04390088322439364, 0.02359007907632206, 0.050716055024947436, 0.04757819018725838, 0.043092954970364056, 0.01270328919469778, 0.040878464334777424, 0.017170267578746592, 0.020234126298289214, 0.033440030978194306, 0.08556792060179369, 0.0810963816142508, 0.024419693309547644, 0.03220556204074195, 0.014586446939834526, 0.026328792296616093, 0.04149267762633307, 0.034365905581840446, 0.013711152032815983, 0.037571807125849385, 0.016690894462434307, 0.03512830413611872, 0.020299664299402918, 0.052698371333203146, 0.06544542858111006, 0.03726822377315589, 0.015524328220635653, 0.014371115548003997, 0.020716305156903606, 0.08548696458871875, 0.03343322866463235, 0.06489552344594683, 0.07276905381253787, 0.01582036796025932, 0.04632009805313178, 0.09270918276160955, 0.04637532741097467, 0.0061135627745118526, 0.04034896274762494, 0.009271520306356251, 0.02439991062107895, 0.039916444170687876, 0.04583750359181847, 0.044052559549787214, 0.019656748976558447, 0.0474227988826377, 0.04313780952777181, 0.04133059596642852, 0.014437330387798803, 0.05619476389672075, 0.01758866923462067, 0.02539435288469706, 0.007566517019378287, 0.05703441027019705, 0.0682122026171003, 0.04147638600053532, 0.06571817251720599, 0.03269448723377926, 0.030877224568809782, 0.011142734986996012, 0.010183411999605596, 0.06340620014816523, 0.022311037173494697, 0.035792824013956955, 0.019663703960499594, 0.03446757048368454, 0.049432280340365, 0.03357306116127542, 0.030435630585998297, 0.05614219778882606, 0.022384585280503546, 0.034420758352747986, 0.055287606681564024, 0.03223336162045598, 0.06918645676757608, 0.036590550493981154, 0.049542603349047046, 0.030761113656418662, 0.048494619583444934, 0.1380153527217252, 0.09258165210485458, 0.26576585482273785, 0.05599075895068901, 0.1294537199927228, 0.09691640521798815, 0.20539941691926547, 0.23164767559085572, 0.2176228045885052, 0.16626376977988652, 0.11100209331406014, 0.08823746056961161, 0.16186923773161002, 0.08674152834074837, 0.16876455130321638, 0.11592620158834116, 0.13594246895185538, 0.20494171790778637, 0.09878468353833471, 0.16150360235146113, 0.12472308240830898, 0.14802316070667335, 0.11156507381903273, 0.11984185076185636, 0.14907562280339853, 0.17401942504303797, 0.10020559015018599, 0.11183331906795502, 0.16567241294043406, 0.0787942140762295, 0.1105188542444791, 0.1975967391793217, 0.16310050737644943, 0.22770202159881592, 0.15631476363965444, 0.13825735902147634, 0.09842015417026621, 0.09294493975383894, 0.08514876916472401, 0.13471190498343535, 0.12472306883760861, 0.12038659224552767, 0.10251037004802908, 0.07856927293219737, 0.0715017132461071, 0.08537472132593393, 0.09266958345792123, 0.11375362745353154, 0.12700689557407582, 0.10371787739651543, 0.08826271564300571, 0.09757550020835229, 0.0859063874397959, 0.16231152042746544, 0.10441420360335282, 0.09974294461842094, 0.1413283542330776, 0.11062725699905838, 0.1084403997021062, 0.156233135876911, 0.07698179954396826, 0.10828479126627956, 0.12319462799600192, 0.08080370910465717, 0.17764721252024174, 0.11949711426028184, 0.09097940022391932, 0.08672100944178444, 0.1595868630600827, 0.12115287541278771, 0.12799765169620514, 0.12871700738157543, 0.13778469152748585, 0.057030427269637585, 0.08429745198892695, 0.09747947393251316, 0.12722861367676938, 0.10359368513205222, 0.1445195044257811, 0.1593684290668794, 0.1651246587612799, 0.07144683333379881, 0.11903462479157106, 0.11924167296716146, 0.10559337532946042, 0.1263958476483822, 0.11557440832257271, 0.10263502371630498, 0.1438083861555372, 0.16790525455560001, 0.12330550061804907, 0.13371809545372212, 0.10058032468493495, 0.3007744348474911, 0.08301639144441911, 0.10983360851449625, 0.2183039044695241, 0.12484083537544523, 0.2028721182474068, 0.14566711070282118, 0.19722311065665313, 0.1034063823255045, 0.1226391928004367, 0.1203872300684452, 0.12209849538547651, 0.13721287649657044, 0.10138782885457788, 0.21999938706202166, 0.19184144586324692, 0.14046115933784417, 0.1339388500366892, 0.2161791670535292, 0.23585255710142, 0.21909906608717783, 0.14680829803858483, 0.19040934342358792, 0.132606655093176, 0.10848409057195697, 0.23223078144448145, 0.12138889703367438, 0.16605893362845692, 0.129569980182818, 0.1982115190476179, 0.09999214338936976, 0.116035825705954, 0.07393106538802385, 0.2275690830179623, 0.1457377461982625, 0.1528826928032296, 0.14891334436833858, 0.1021844425371715, 0.2849647860441889, 0.23108449152537755, 0.16082808002829552, 0.12157375711415495, 0.09938924466925007, 0.09776496754160949, 0.09026091306337289, 0.18676083348691463, 0.14220860414206982, 0.2539980762771198, 0.08969578838774137, 0.14648850448429585, 0.08691435120999813, 0.10858294633882386, 0.0721664536478264, 0.11882045199828488, 0.13279040237622602, 0.08973317566726889, 0.09198008331337146, 0.13663309546453611, 0.11784623855991022, 0.10362362888242517, 0.16834664158523083, 0.04460928396188787, 0.15004347158329828, 0.1384948462780033, 0.0967438266213451, 0.2109174808221204, 0.07615136767604522, 0.15903741254338197, 0.16290918764259132, 0.16763284988701344, 0.1330092434904405, 0.09920941253325768, 0.13132104836404324, 0.22408656988825115, 0.11472610384225845, 0.10843709523656539, 0.10954036603548697, 0.09205768057810408, 0.13874762771385057, 0.10191763578248875, 0.12986933626234531, 0.1575998818235738, 0.22391650187117712], [0.019065933268783346, 0.06788364917572055, 0.023499043425545096, 0.016164281738123724, 0.019965015917218158, 0.04617453532825623, 0.06788780181003468, 0.021956801181659102, 0.027855696256405542, 0.05179859318637422, 0.025360042761479105, 0.00766362131772829, 0.02765190844157977, 0.04959194980827825, 0.0892707472667098, 0.03658321213775447, 0.041197318118065596, 0.05617849601964865, 0.06537398562899657, 0.026226228335872293, 0.03878803704200046, 0.012580148659513464, 0.01376847891203527, 0.020769451412239244, 0.013273470652555781, 0.06917520665696689, 0.048208959733269045, 0.025676380876185637, 0.040481636699821265, 0.0519335504089083, 0.041369163896888494, 0.046240902838430235, 0.06183939493660416, 0.00238950368865127, 0.03766409806641085, 0.06328264570661954, 0.03061429564175861, 0.038867456173258166, 0.10101857009742941, 0.017117046684558903, 0.012178786714295191, 0.014789505329515253, 0.08879795085106577, 0.04571932654029556, 0.024773629049637487, 0.03038735960477165, 0.024262240954807827, 0.0476338029173868, 0.04097073831196342, 0.05816765874624252, 0.06545981352350541, 0.05150309118575283, 0.04677385477615254, 0.049951586938862286, 0.06313323908086334, 0.09660188388079405, 0.047857064687247784, 0.05473057692870498, 0.036264894397131035, 0.05314290337264538, 0.02065065350117428, 0.04200087321389999, 0.05927827807941607, 0.0507722004050655, 0.031164380588701794, 0.012502739688248506, 0.02863927697762847, 0.05337849073112011, 0.010202058141918054, 0.05435334199241229, 0.019816991806562458, 0.007278094683507723, 0.006398477084336004, 0.011907657691543656, 0.01636796098734651, 0.03366397128307393, 0.018262147471042614, 0.017428068477394323, 0.02761901306387569, 0.033369629577334435, 0.042571928285594494, 0.0542555956303009, 0.02177603606001607, 0.04266336427203246, 0.025767226537157382, 0.0336688092377569, 0.00407568462625412, 0.029885732236185243, 0.04179189121350646, 0.02955216442101768, 0.04675711192456739, 0.07253725946481739, 0.018449133062469106, 0.029999719333967993, 0.03477983229926654, 0.02792878295960171, 0.026545577449724078, 0.005675040010828525, 0.040129371852214844, 0.047676184214651585, 0.032137379449393065, 0.060173754314226766, 0.0375251578433173, 0.0529213481183563, 0.03562893405822771, 0.03133429254272154, 0.07369280460157565, 0.019167187656941156, 0.022997071700436727, 0.013060907683601337, 0.027291762409731746, 0.08377850162131445, 0.00874409164368574, 0.04206130014998572, 0.013221997834209884, 0.043413657761578045, 0.0639494556401457, 0.03210468763219459, 0.05089642320360456, 0.060373677872121334, 0.0204783717636019, 0.026826419701267566, 0.03207434015348554, 0.04643023107200861, 0.03426982841587492, 0.059536386015159745, 0.07627656417233603, 0.061745560328875265, 0.0596373180991837, 0.019169974739530256, 0.012691285062049116, 0.01521488232538104, 0.029362995643168688, 0.019535242014431527, 0.025012106967291663, 0.067921579283263, 0.07593109485294137, 0.024197493446990848, 0.022083724549572383, 0.04823853707473193, 0.029625568339335065, 0.053004197244133265, 0.043834580175046406, 0.03416889972452607, 0.031960383589778624, 0.0355915366006749, 0.0309519177036626, 0.027769052423536777, 0.02591832441144756, 0.07364067275609289, 0.0686732196648206, 0.02866394511823143, 0.046746506422225914, 0.05077247181907296, 0.04018800745585135, 0.03108369598963431, 0.05324813736868756, 0.06303938411708389, 0.04415000396381531, 0.04204616881906986, 0.019298099114426544, 0.024281709820830395, 0.030342654325067997, 0.030919096964810575, 0.01652985774645848, 0.06700909217553479, 0.012189164907405419, 0.010130599922766643, 0.01835318990716977, 0.0649733514125858, 0.014529229474386998, 0.011496612203440495, 0.0903835446972932, 0.07367369027010032, 0.02563221672815936, 0.027272488622527038, 0.024543994139613848, 0.04736188000866345, 0.05236645575080599, 0.036419569847307036, 0.018261299302269305, 0.03543618940083044, 0.0735740949000631, 0.010484287149405904, 0.022373345347919633, 0.022562295298225114, 0.03434448762397681, 0.04416539992338844, 0.058491733856499195, 0.08774892892688513, 0.02747199997039778, 0.015945688289191042, 0.024878695108262554, 0.05765597548867975, 0.07151351975543158, 0.04096524557098746, 0.013040725507640412, 0.04134305047669581, 0.03188889314021383, 0.031826647730278115, 0.05166209229667272, 0.04779167766017573, 0.014236991227205311, 0.022046210044728856, 0.01386659253122551, 0.02720382427131491, 0.049320566334894726, 0.04702131649745362, 0.048908247745462825, 0.030108793838215724, 0.05664817795955709, 0.0191475881729275, 0.06982562318444252, 0.02978954989729183, 0.03544681186654738, 0.02723850928513067, 0.02437214836079095, 0.005454136150157345, 0.019431465172341893, 0.009161344030871987, 0.0289284312831504, 0.021658924308472445, 0.04607023431786469, 0.020432979467191865, 0.023492197007206932, 0.11008066311478615, 0.04505218751728535, 0.03070981640900884, 0.04074913216754794, 0.060036194909896166, 0.04114646531109299, 0.03775933384895325, 0.04164977544652564, 0.09708493974592004, 0.03967873639027987, 0.027038042899221182, 0.02227157018413501, 0.04702495683782867, 0.08416280349982636, 0.02747297366814954, 0.0202673168387264, 0.0026793365291918492, 0.0026350061400860015, 0.038554977226470194, 0.03179861744865775, 0.059095032912279875, 0.03645785618573427, 0.07481995983315365, 0.04275340586900711, 0.013410492317884095, 0.02415128012320825, 0.015076937852427363, 0.04172266028555376, 0.04206396679260901, 0.05387432001797216, 0.047771369107067585, 0.01596517751126417, 0.02611888070324702, 0.032508069915430884, 0.03048450207071645, 0.05332163967458265, 0.0409755660886211, 0.05851203562425716, 0.0333024783592139, 0.04927004940275635, 0.012329422336603914, 0.013140880669068013, 0.06981288708214249, 0.021968728130949394, 0.04904197681961315, 0.06013378181627818, 0.036233647859522274, 0.07132052404007741, 0.06208912975021771, 0.04591092447351132, 0.011074018897488713, 0.04158391344494053, 0.017174371019271866, 0.03435559184955699, 0.040236213976251226, 0.046104836211140664, 0.037404090232614956, 0.053464576468936036, 0.02616307877802423, 0.05806101339736155, 0.011498876814065235, 0.02211180572131915, 0.02923415202115263, 0.07992430736443826, 0.05618786658825619, 0.03826314949297479, 0.06848057000232594, 0.005956192692143044, 0.011652663383366806, 0.028137359535321593, 0.036243490009967766, 0.06015230582228728, 0.037700016317623, 0.030449021474591324, 0.028796127132539238, 0.027054958777236085, 0.03285608374114547, 0.01225466898176819, 0.02368851754415248, 0.05421544671324747, 0.033459236911897144, 0.03148837088208113, 0.01831733781312193, 0.020448458547304784, 0.031030668477926935, 0.014806869040642465, 0.030367098549114804, 0.11327045623745237, 0.045107630613659105, 0.02261471891376589, 0.023852281970903277, 0.033378949255815575, 0.02144452929496765, 0.0425780995615891, 0.013219258249072092, 0.027363658283970187, 0.013256619235367646, 0.033296877052634954, 0.03418768496651735, 0.008294705534353852, 0.01286747261682259, 0.020232845563441515, 0.01758677781825619, 0.07796805697892394, 0.026052894869021008, 0.09531421440520457, 0.014264750094818217, 0.09758335085851805, 0.054763723364365954, 0.02312416979111731, 0.027027062506281903, 0.013610421812960079, 0.030273240192660263, 0.02327841946056911, 0.015947594972593442, 0.020807525708473155, 0.04582644686368959, 0.05611001826556666, 0.03265097278303333, 0.036518378116722615, 0.03210956629897867, 0.04816388465198023, 0.014652432774060538, 0.14462747291794845, 0.0067019247300257635, 0.06922496362988438, 0.019774327220927392, 0.11987349763512611, 0.11862793804279395, 0.09343457062329565, 0.12254358721630913, 0.13425818218716554, 0.12055311830980436, 0.12065497998680387, 0.09571473327066217, 0.12919754588178226, 0.1126096649095416, 0.13374734031302588, 0.0915344011570726, 0.12747493545923913, 0.19039270574493067, 0.1658092870243958, 0.12277146641697202, 0.15371904149651527, 0.19158360255616053, 0.3149648276822907, 0.09697043017617293, 0.19774294990514005, 0.10839435431574072, 0.08697349910757371, 0.11595654567437512, 0.11377993425620453, 0.17058040600802216, 0.20354451930948667, 0.1758119517139026, 0.08089405604239021, 0.13499846389251097, 0.07352671279971089, 0.09217495857072727, 0.1400383777384247, 0.21616251580417156, 0.172182970015066, 0.11976293713918754, 0.18298033491841384, 0.19187014789453574, 0.2449281801070486, 0.0772997678390571, 0.05159663063074861, 0.09414579745914255, 0.1835802277284009, 0.13693935903055326, 0.13397482596337795, 0.1089095455993499, 0.11763824043529374, 0.192678283101746, 0.14788577093609742, 0.27723806351423264, 0.17512308939227036, 0.11441076147769179, 0.10286209546029568, 0.14260191018027918, 0.16369677680943692, 0.10184313942279134, 0.18216503438140663, 0.11828070453235082, 0.14752857653158052, 0.1740944031625986, 0.08465609845838376, 0.1284190762255873, 0.11336428405983107, 0.1129153585061431, 0.15758035358573708, 0.12706714948373182, 0.12917290148990496, 0.06488781528813498, 0.11410660137023244, 0.12536954986197607, 0.15574454995138304, 0.1269939626966204, 0.1278573985078505, 0.0766612867425595, 0.08045000915548631, 0.08714514132589102, 0.16900435914950712, 0.09147301409393549, 0.1236025361078126, 0.09960121900907584, 0.07946258464029857, 0.15343857583190712, 0.08626740199646779, 0.10620449789400611, 0.19070773598338875, 0.1568604822137526, 0.10974445579839603, 0.22590819214071545, 0.09810361758406673, 0.12010029117975916, 0.15130967221089772, 0.1494742621268545, 0.09015339240431786, 0.13122323075575487, 0.14037784880825452, 0.13379709050059319, 0.1477627796786172, 0.13230415061116219, 0.11282260955444404, 0.12876700184174947, 0.11956351569720677, 0.14858984601284775, 0.1193425575537341, 0.13104907795786858, 0.13254207213010105, 0.0769969919430358, 0.1701064628681966, 0.1647537715200867, 0.10933652054518461, 0.0754020410989012, 0.07791480555066041, 0.17405113976980957, 0.13582014265869344, 0.11739692624126162, 0.08315606787800789, 0.1294866425118276, 0.17182755337229796, 0.10765908698418311, 0.2139185055025986, 0.146738042522754, 0.08813624350087983, 0.09325066727719136, 0.07874328323772975, 0.10258091733391796, 0.14006595340158257, 0.09560435597917863, 0.241652321602617, 0.24830104197774613, 0.1408576544906412, 0.060145262628793716, 0.05724443042916911, 0.11301976468946252, 0.10323788850967373, 0.08106170847479786, 0.08460298273712397, 0.10495367286992924, 0.17660221430872167, 0.13032722526362964, 0.11397280783525535, 0.15443051260496887, 0.08601961457835776, 0.1292284056544304, 0.15050081775656768, 0.12059570316757474, 0.12317846529185772, 0.1482572688588074, 0.1095265442771571, 0.07643337361514568, 0.12891746019678457, 0.11382167773055178, 0.0967784726193973, 0.1151531059294939, 0.2110035326331854, 0.12137943825551442, 0.11491591722837516, 0.1851083700145994, 0.1550003191722291, 0.21169448484267506, 0.10161652229726315, 0.08971296210906335, 0.14803835989109107, 0.15752691216766834, 0.1462696905114821, 0.11764494436127798, 0.10583803470113448, 0.13862382221434796, 0.07392368292702095, 0.1276968435517379, 0.0899922674787896, 0.10572767098035131, 0.09706481439726693, 0.09614421201071569, 0.23877625593117305, 0.19369866406278952, 0.24619245369519505, 0.08450076143656458], [0.025902407676247612, 0.03587312863341399, 0.034932112520826716, 0.05338841091309275, 0.014119692878531558, 0.057627985919160504, 0.03115031455776521, 0.017238626589200327, 0.015895832928695848, 0.02550504569496427, 0.03373544476926327, 0.04273786063172987, 0.05658123369461723, 0.007648691850980478, 0.018956963937463503, 0.049842692246394496, 0.025994859768876007, 0.035704336262175014, 0.030623903697622672, 0.033122412128640075, 0.05101729743182659, 0.05093433974044664, 0.008077720213415367, 0.055272488921348534, 0.04097154576863561, 0.03376539530498641, 0.007710147615788239, 0.010154837193632764, 0.06386874389967748, 0.025460559242804135, 0.11187973086323057, 0.04560967867395707, 0.05701765724058662, 0.03629313163193209, 0.0349643497195627, 0.01038024143781513, 0.02916516536580665, 0.00862502062227577, 0.07303202005901507, 0.03449865078021373, 0.049735290330967734, 0.056357795505651405, 0.04070454563147255, 0.014591155972863947, 0.01612017526557403, 0.082818449208779, 0.057370156182774475, 0.023603510677016208, 0.042725484152989726, 0.03273047333849328, 0.041059290524572134, 0.005994241543313754, 0.02307353581168822, 0.03154522533129368, 0.039461686608514616, 0.022670184062527757, 0.023354564660361836, 0.009758727957627602, 0.0609431994546737, 0.08899326715618372, 0.017078667047566602, 0.009735519515483506, 0.0202889553204711, 0.010401962191930838, 0.024534967927528278, 0.017068236267992427, 0.03586500996191587, 0.06061018803822143, 0.01916571014693805, 0.0386553325557283, 0.029892921314707825, 0.04963338794186711, 0.04047256807929703, 0.023585354776254723, 0.020099082562540258, 0.021463635144755244, 0.05443995698754277, 0.04508945266050952, 0.023007178479539495, 0.06405223333942038, 0.026122034194746187, 0.03167089340942247, 0.0083866665372625, 0.028635819841708456, 0.04018542902278049, 0.03179394234237926, 0.021343921211415103, 0.026546398477096642, 0.04189380717330745, 0.03630485332437924, 0.017926806983138834, 0.026086139692259685, 0.05567429021799138, 0.02806951790781958, 0.03911828003557665, 0.025249270223347203, 0.012063741950052125, 0.029717615007289817, 0.04195344361609646, 0.04642799190644707, 0.08109097369015217, 0.037644295021891594, 0.04374799232131668, 0.05228561169600912, 0.041532327820147784, 0.0068443577121278, 0.054137408400752714, 0.014152199794937457, 0.022417034521432858, 0.015988795618925775, 0.02090132638945111, 0.046794251538813114, 0.022032736035596048, 0.011668338390466357, 0.02829687124384301, 0.002035396406427026, 0.01473308853538973, 0.01878499602233725, 0.03700230250667248, 0.01297660988555955, 0.03510441970346229, 0.033475277479738, 0.03508875911523189, 0.04793877048151834, 0.00854969390534929, 0.07872564811259508, 0.036064180345939736, 0.02557572359884424, 0.07346373117927994, 0.03029446816071868, 0.05203700664320162, 0.06451871937939099, 0.06377596780657768, 0.032471289924745045, 0.05049777709479843, 0.02076306639771376, 0.030262906104326248, 0.013525578642397054, 0.039657328610441515, 0.025023626795570766, 0.09167576035750763, 0.03191224831555571, 0.058483761070030074, 0.06699377085481371, 0.03589895706889885, 0.043719917934920104, 0.057917876435177665, 0.031097161517079388, 0.052269153829131804, 0.038411813122885566, 0.040685923237885745, 0.01652245662574257, 0.020020725338586738, 0.052754397969692945, 0.02886646067989724, 0.029247793967702558, 0.054854358679481914, 0.0422127729148737, 0.024527054512873292, 0.04202661683250751, 0.03423811708177839, 0.08266525635761873, 0.029547061837677444, 0.02307448236803923, 0.026630436735493795, 0.017492585283304964, 0.031787363945373466, 0.026372573072356836, 0.01747898744153125, 0.01863544011887695, 0.02826082067830222, 0.02447719406336546, 0.022716412653348277, 0.04608188137145979, 0.04259779064783028, 0.011972671524355454, 0.0467277890337365, 0.02797400562225708, 0.019337084343922988, 0.029328451425369297, 0.01637507712335459, 0.027675170318356583, 0.04581079984615956, 0.025029002489256005, 0.024341071456936852, 0.020088049583137035, 0.02054422697983682, 0.047741401607968977, 0.06582190695085696, 0.021860394926209534, 0.029617751615920236, 0.04424249167953219, 0.014120169549382158, 0.048076787896986516, 0.009928409209741014, 0.028457658598199487, 0.06191822713507073, 0.07493723104042666, 0.008390784396656921, 0.03567845354388867, 0.019657753208386045, 0.025057797819109898, 0.016239741617547612, 0.021107568804706846, 0.06430886885417358, 0.07665936648845673, 0.110388880861657, 0.025123371443312083, 0.032068240123667886, 0.04636209597811103, 0.02892469594787274, 0.008660684422855931, 0.038535303103604486, 0.02170858798282487, 0.012365017435513437, 0.02536276199056634, 0.012595643854833074, 0.002647175665645461, 0.010926994777816747, 0.05690836899780801, 0.03627610379563911, 0.04240268129589302, 0.05883433297276497, 0.028571579538817917, 0.04852133350712912, 0.03502996066319091, 0.03598594865096467, 0.03610811209572213, 0.04424914810806513, 0.027540791546925902, 0.02261331773895238, 0.021955043775960803, 0.013544901623390615, 0.011406739392051739, 0.07007447590253182, 0.04444797243922949, 0.06536713921065841, 0.03364332685513156, 0.052081464257623465, 0.03187879314646125, 0.020714427311239497, 0.04100304675687637, 0.026688588882929513, 0.06357120629400015, 0.015399540541693568, 0.05698512827179261, 0.022805660364351103, 0.004832517921126315, 0.057316952251962254, 0.04416724214596408, 0.012168154918721743, 0.023778284334444573, 0.061180035317582745, 0.018808383428092514, 0.08915238361805677, 0.00875386085161673, 0.01926221139729023, 0.08802501125527279, 0.06699615251272917, 0.038998783233442476, 0.01699385865192328, 0.036823016591370106, 0.031043404580226967, 0.022221531619184783, 0.032747623311089616, 0.048712710916463814, 0.03363346095596041, 0.03434992947482637, 0.05276203827400293, 0.06277849418776375, 0.0412956649836685, 0.02592346940322646, 0.0524717745637255, 0.04240630128021751, 0.05038828868418932, 0.03235409674899919, 0.04097794435386147, 0.04546963583145823, 0.0075125141135816064, 0.042347289089645655, 0.0042301611808527794, 0.018209036838795458, 0.01288784563075751, 0.09792562427797488, 0.03173279615917376, 0.006508972271279032, 0.03662028729117342, 0.020870887308514545, 0.021207710395434072, 0.07432268865938697, 0.022304358692573648, 0.005013599833806178, 0.016956825906942998, 0.018107446575803415, 0.0274236187272306, 0.028605743777006865, 0.011470334238505788, 0.019773477355816534, 0.02157665872281151, 0.022416428928928714, 0.028185530432632992, 0.05769311171025038, 0.02550550370610186, 0.010600990931769567, 0.0656970361513751, 0.028711286506482532, 0.028171902056783438, 0.01728172374090978, 0.02990428338359509, 0.009936812865946974, 0.05848820547440222, 0.04331771630261626, 0.03256261395290494, 0.030478961832289184, 0.0363925777242652, 0.06224177298801286, 0.10596882911132914, 0.04893169791570731, 0.014860817663637655, 0.04168899816327861, 0.037165347686303515, 0.033479182448770316, 0.053041760942765644, 0.07117633534861462, 0.011278589572092252, 0.06024278846702405, 0.021868464403918812, 0.043788321050150056, 0.027715561811679175, 0.03110129718801805, 0.008810298849961587, 0.021707006996231418, 0.060946748192821226, 0.04084286160234894, 0.0670812815161688, 0.05513455293008259, 0.046611084403204064, 0.016343521852312342, 0.021012865672154084, 0.017319984634273818, 0.05522810594577875, 0.02037992651042129, 0.03208332056445735, 0.04866584111005068, 0.002346806872602818, 0.05076636839658022, 0.04971747878672821, 0.056303902861795256, 0.015841791007135595, 0.013551357035924281, 0.004122026447605873, 0.01703396176786295, 0.05596569725977523, 0.1243376609470163, 0.07293052479092564, 0.08243766892701387, 0.10021806162382875, 0.11242862498121602, 0.11179975194058248, 0.12754054979554244, 0.1202641845281635, 0.1028706178601299, 0.07913680640714509, 0.07160224499447004, 0.1646051723510027, 0.14374255468802793, 0.08383808378130198, 0.11775748617947102, 0.11310108032609735, 0.16805165527122362, 0.2422353188906397, 0.1014878720577274, 0.12403700208025319, 0.18108678795397282, 0.09742864487426621, 0.15047715045511723, 0.1421847604215145, 0.10557577413107667, 0.09097287271703992, 0.16703970171511173, 0.17022421583533287, 0.1827954612672329, 0.23703033104538918, 0.12188240912343774, 0.13133775389620236, 0.11427426737334047, 0.18022903826619896, 0.15148229151964188, 0.11725790798664093, 0.11491090963993754, 0.18377460086984293, 0.11778343335858413, 0.14267266781202384, 0.12774398816483362, 0.16140483479414666, 0.09144927215363298, 0.07053393910505942, 0.20653525739908218, 0.08246550243347883, 0.1811787701611008, 0.14551871509424277, 0.14336010521011694, 0.09775855538568326, 0.11989299873156206, 0.13450401542442186, 0.15349766266133102, 0.15309003953422817, 0.07327151577919722, 0.10337969554322106, 0.09366960836840527, 0.19191216278289044, 0.19280907751194068, 0.15049058544848645, 0.08361232160989727, 0.0953840288732733, 0.08620260190218687, 0.07076014232422624, 0.13735208474099636, 0.11256344310407128, 0.09337190791432347, 0.1842495889535972, 0.15804973697023733, 0.10303539330405848, 0.12624173877494677, 0.1408303773828915, 0.19164095233593667, 0.18833994732371398, 0.1083113287708589, 0.1550663813416447, 0.12190178808357034, 0.17000815671469482, 0.08852169888892344, 0.12578450116728032, 0.1068679422938398, 0.22152096112923964, 0.1504180229135922, 0.09790710705731596, 0.1333151270768472, 0.09865923598408699, 0.0858528713828751, 0.12786902859807014, 0.08755372118737016, 0.08017214906534978, 0.10441389826259442, 0.17560764481978758, 0.11293264757841825, 0.07682100031524897, 0.15840226305382593, 0.1217616977436202, 0.1434555072337389, 0.14664188053991112, 0.1347116878522294, 0.18572442552873067, 0.24337053511823925, 0.15060466075582163, 0.1298120000532695, 0.1420407345784562, 0.08618147232170616, 0.2109615584569318, 0.17829792760312557, 0.11784090527466365, 0.17028327552335604, 0.10582311371607439, 0.12098096178046294, 0.08520100957580976, 0.10573172183441264, 0.1355812576200281, 0.07073372017060008, 0.11166403815150261, 0.1358843727835587, 0.10534030212355511, 0.17329876657043183, 0.15192670481545584, 0.08734915644994803, 0.14178169704973698, 0.12083187406616551, 0.1025155269141708, 0.09670181851834059, 0.11063995917460748, 0.062019383135650835, 0.26728751031415804, 0.1395336426794529, 0.14822547270783357, 0.11282541868942124, 0.11165544111281633, 0.16151500173977443, 0.1540319954178163, 0.10754484204309327, 0.17448742421610014, 0.1616923843643495, 0.22607809730938502, 0.13870672562292644, 0.2111105511763266, 0.18145055057747023, 0.09596300923398562, 0.11708177386650018, 0.09951832917119775, 0.19331374471741064, 0.22140240749078138, 0.08128673104303223, 0.11274237278848886, 0.15913947778088705, 0.12479750412915434, 0.10284313040652446, 0.1558656005987099, 0.09896343001829726, 0.07885103459869112, 0.15159993592117513, 0.14720563457480498, 0.0990895221808127, 0.17231749636786325, 0.19049517810344696, 0.11601624318531581, 0.1502697222999164, 0.07545141130685806, 0.11034456573958908, 0.1194385431174721, 0.09078279470226594, 0.15143858029374055, 0.13024859662566865, 0.0663451524451375, 0.11424183339944907, 0.20583221369556018, 0.16623919324151107, 0.10629861748644284, 0.14480128644832543, 0.1196090318262577, 0.13970782261873993]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.01716157215248261, 0.05180008935609034, 0.007989061131541218, 0.0027874521786413553, 0.03809911704489163, 0.0691227355439748, 0.014370070604075278, 0.0246195761553411, 0.03733332920819521, 0.022492696265024797, 0.07518522201904229, 0.06187298920537744, 0.026035805964576345, 0.05129068597619023, 0.03508830449676939, 0.040566328048173866, 0.02879466149689896, 0.027876820747873614, 0.03256145026534796, 0.051621217347149334, 0.0278482357638755, 0.04329904641157814, 0.008740050967649689, 0.04577369076598968, 0.038433271792850325, 0.03294631532792534, 0.022814371057653, 0.06429801229387522, 0.03158568637445569, 0.020746326938803707, 0.03543606387185199, 0.03476884003196444, 0.01576057375807847, 0.00929598743095994, 0.051312677296144624, 0.024665326378973465, 0.04839093264724527, 0.0011561970604816452, 0.04675209415810449, 0.020289274231929864, 0.06534478148179394, 0.022658131584259014, 0.0375930317012327, 0.003366829270297395, 0.12437981154237475, 0.043101066856512, 0.028932346430208002, 0.024235859513282776, 0.017700059239619544, 0.012300380189636988, 0.07421926635184459, 0.027090693823993206, 0.005953732578616057, 0.009975695467021848, 0.009092369249888828, 0.05564249406701752, 0.05634800424533231, 0.0364612556461777, 0.053367108306182284, 0.051195080392062664, 0.0804665789806417, 0.044158397441996, 0.025748792437038252, 0.04012853725414191, 0.029234677885792086, 0.04419858707115054, 0.04095003281586936, 0.03260091386203255, 0.03033701909173812, 0.04494903323107532, 0.03585355629080108, 0.05042603558727673, 0.006653757225389459, 0.0687683027769838, 0.010960231967536467, 0.03390979773498007, 0.03757683846301266, 0.043626588835780106, 0.05409043002873659, 0.04572847319234695, 0.034898684493133, 0.054473965162677426, 0.03131298315046089, 0.010799712634512355, 0.036163650186998506, 0.010317050319697176, 0.04610303470066615, 0.03111884749627539, 0.018495616103921617, 0.055970453790255954, 0.04265986642401133, 0.017348255795825804, 0.017651259001078348, 0.022859871919666017, 0.058206850928919654, 0.0652373218908906, 0.031140475799994807, 0.024242984130978584, 0.0744966786088688, 0.046323382162622044, 0.025472252097512995, 0.025178091899890984, 0.04739149806222745, 0.04121984548068472, 0.035810204688459635, 0.0235708578755813, 0.03433818403365357, 0.03745378613738077, 0.03627989680639335, 0.038369313081992526, 0.02229171758517623, 0.059808336065283844, 0.058163003996014595, 0.04282423474692872, 0.05747163788016353, 0.012727104925683566, 0.033328364470175335, 0.08040289846914155, 0.009162702797246831, 0.059513207258922715, 0.07131088205746242, 0.017450180237314532, 0.02972530959440129, 0.0017963824461081199, 0.03437467903963157, 0.018885856860184243, 0.014825851057789155, 0.06359085666814021, 0.03804528546918716, 0.04261088976636529, 0.05916230287402868, 0.048522029005523236, 0.028140665697199956, 0.07445068750530481, 0.05788812267460993, 0.035962182961936505, 0.04122793022543192, 0.04769458947703242, 0.044979051620300324, 0.05507554752486093, 0.015027496398293545, 0.052285788115113974, 0.023358966656295315, 0.07523689924606256, 0.031249607979719127, 0.013918380868355078, 0.03693312246884618, 0.015721281491486088, 0.037022794264235666, 0.029980676248669624, 0.026168311979355555, 0.04613603525129812, 0.02410358250407236, 0.0606737057013171, 0.023533148291919912, 0.03312863090208598, 0.024152905214577913, 0.054808767911578925, 0.04265071977195995, 0.005501087804857109, 0.0323067485753979, 0.016996286110952497, 0.05415109784475394, 0.010128700024714428, 0.07888715980308396, 0.0390789928579969, 0.017106510732056837, 0.012460638286678918, 0.030585196667483876, 0.0668287104261773, 0.01633865336355354, 0.031173686696482555, 0.037091733422130346, 0.061261798787329874, 0.03983790374227932, 0.034779364110103676, 0.003209898539353162, 0.03148478821718267, 0.051965221030903716, 0.028393425080659132, 0.027153979088844996, 0.025993263515244638, 0.01947266242599913, 0.046480435878038406, 0.02879394224977919, 0.020203420892357826, 0.09303122226681028, 0.025397955905646086, 0.036527321208268404, 0.024357946622850637, 0.045361199150128026, 0.08080051999006953, 0.035374731091516357, 0.08228824194520712, 0.04437959646540029, 0.02021809251579855, 0.05354675045236945, 0.04041221917473844, 0.018461032870358655, 0.047217945767832656, 0.023632999808926667, 0.03594025610280888, 0.06580212765506335, 0.03601799246722034, 0.0531526301721377, 0.019777728377708366, 0.04570226138457656, 0.07441482692956924, 0.02332070406659373, 0.02987787819334439, 0.06736851896026305, 0.022107013567749943, 0.04007861404014485, 0.02871937125122973, 0.03413361590355635, 0.07049877063504287, 0.029196751170924733, 0.012064970098435879, 0.060206018654363494, 0.014149260890137936, 0.12603091794465268, 0.06643470549689871, 0.034941740932741334, 0.004908872194521661, 0.03178073126556618, 0.03862305464489119, 0.03131189749443105, 0.037819787926439724, 0.030819644087127278, 0.020871900022029877, 0.01967503210263593, 0.03242737853101321, 0.047851117327809334, 0.018087195698171854, 0.04799043753051332, 0.013314338816728975, 0.09374185877719096, 0.030498537567577193, 0.042179555233035765, 0.03389319398307374, 0.05802824694131102, 0.033071996976754496, 0.1312801462731191, 0.02250266564078629, 0.006850718977927629, 0.0380068057482796, 0.02142130134494177, 0.04657398210838437, 0.013365301885642111, 0.07554508985153266, 0.02909718294228826, 0.024949362834117243, 0.014648519323340483, 0.05812589491584471, 0.033809839348707876, 0.037691666944218535, 0.05390384986198374, 0.01636440716018634, 0.008306717300521476, 0.050345235637256076, 0.03875303481306348, 0.018944141321948597, 0.03261787723749876, 0.01120867841278336, 0.038483252682323964, 0.032085298494036706, 0.021091655462181995, 0.0028334394654458655, 0.015257417989362563, 0.04697655354227338, 0.036904128667499335, 0.0032461121653406216, 0.02202938067992883, 0.06045852189085313, 0.0706811947748065, 0.025000032436634814, 0.020512123791767017, 0.019720758577542644, 0.04187405841158969, 0.09569841450346367, 0.043069175710635524, 0.025439735003081814, 0.03085956908762455, 0.02784292962002967, 0.055000297991292815, 0.026686614346025244, 0.0388283827342093, 0.08333601536495344, 0.0297601455822587, 0.0265853514761797, 0.02553708611854485, 0.021434856778276817, 0.028346416174567172, 0.04349482072783368, 0.011362008667284889, 0.03910804772749543, 0.06749463147882905, 0.03657060495710798, 0.03988750804481762, 0.012652220952856754, 0.007693059559512351, 0.019867137240778123, 0.01639834069646895, 0.015871361563248292, 0.021808229153975844, 0.06638314362083163, 0.07476971431502275, 0.028542996251157353, 0.054586523944245915, 0.09026507926838738, 0.03151306277140975, 0.06254802298332963, 0.03269983069705112, 0.04224248257066522, 0.037067692926419635, 0.030545997699456554, 0.057949061904634745, 0.046704345648842197, 0.0533898426219821, 0.09300134636993919, 0.011089053537164415, 0.025134424778765867, 0.03633021017802613, 0.011932113789953291, 0.02389368448140366, 0.02210466074757278, 0.05049326144424932, 0.06231858993747404, 0.01753636266637061, 0.056290522151227505, 0.04345807805657387, 0.03546109163601484, 0.036714267783931324, 0.029905501353953565, 0.029240906837263277, 0.024377819217209305, 0.05687117849343589, 0.009093199607117899, 0.05860319680401257, 0.011118800512381961, 0.08926571932222162, 0.04416341860113399, 0.045717630202748945, 0.002564375945699534, 0.02845481044745871, 0.06842532368110758, 0.015729627472215464, 0.0843163559745465, 0.00605947759634416, 0.051482897983597856, 0.0615321339241096, 0.030533733178994486, 0.11625736738954272, 0.24528185970016889, 0.1927549982709544, 0.06658506885703121, 0.11837905139795371, 0.12272718522165503, 0.1008873957076243, 0.0837278761235731, 0.07614828034171037, 0.1255319911454405, 0.19927026437861578, 0.12130869419447013, 0.16538615258676664, 0.10679521691054106, 0.15935028504048074, 0.11721237828688962, 0.14249818931732858, 0.14221563376486301, 0.0824644642749003, 0.12118971986430031, 0.13236371241509914, 0.11629839161677019, 0.14472518196063383, 0.1443617178925446, 0.09642610259886299, 0.17698431094842298, 0.13658956065773964, 0.21476777350263937, 0.14892616868019104, 0.1072697639465332, 0.2531512374324458, 0.16414329356380872, 0.11610504984855652, 0.08057744481733867, 0.1913142648658582, 0.11706593685916492, 0.15054522108818802, 0.07552849288497653, 0.07901976590177842, 0.11918496101030282, 0.17148091697267123, 0.11936018589351859, 0.2103615163692406, 0.13381889861609253, 0.19512411685926573, 0.18702599140150206, 0.1378030391143901, 0.10778010370475904, 0.11301038733550481, 0.14281784716461385, 0.21467177436820098, 0.14571682017828735, 0.09661022986152343, 0.11070520031665053, 0.1490931697189808, 0.1431699525564909, 0.23652094123618944, 0.13589829632214137, 0.10438751682106938, 0.10821355866002184, 0.1818367184272834, 0.16406566915767534, 0.10664347612432071, 0.10287104533719164, 0.20435521937906742, 0.1218677256256342, 0.2272453811019659, 0.100727797485888, 0.11196559268449034, 0.11317080658461366, 0.15803560987114906, 0.13108860940805503, 0.09246845210769347, 0.17114342722509587, 0.2031845971941948, 0.13822731349085057, 0.10656944116843597, 0.16352938222033636, 0.09626811929047108, 0.15059963959668363, 0.11405846609600953, 0.0855365926399827, 0.10866195495639529, 0.11179671888904912, 0.12141588915671621, 0.11778639177126543, 0.09999189233141285, 0.12197622337511607, 0.11014353616961411, 0.16642291338316031, 0.12171291107577936, 0.10469549029533352, 0.07915139491004602, 0.1334584608141865, 0.1210415278162275, 0.10242168552109174, 0.10149189577038799, 0.14100382450435842, 0.16193373927048274, 0.11606274997549397, 0.12817244231700897, 0.11622231427047934, 0.08796061149665288, 0.12091143908245222, 0.14462877570518426, 0.17370972808982643, 0.1147727191980396, 0.07859151531010866, 0.18465255733047212, 0.06815178585903985, 0.1115348654400025, 0.20254096601690563, 0.10142742137291602, 0.07367788361651556, 0.1724979459707226, 0.10322137296731983, 0.12767257913947105, 0.17698827359293187, 0.10170764276491744, 0.18906483985483646, 0.16415029604520115, 0.098287229160113, 0.12697792212877954, 0.10561571948762451, 0.14328788194273198, 0.07451300416141748, 0.05354367329605988, 0.05913548038474151, 0.16337363129215582, 0.17265194627855504, 0.21003655237810953, 0.09194955602288246, 0.15204749761947564, 0.14718645917517797, 0.1032826853916049, 0.11923708607043539, 0.20868777403874056, 0.12316714732774667, 0.12269218638539314, 0.09527048960860286, 0.09412431504045214, 0.16407515507723602, 0.17713422647544316, 0.09889400231518916, 0.06618526923869338, 0.18373122891145094, 0.13024854234286717, 0.0489253773620086, 0.11207398186836924, 0.1577047561960561, 0.11771629910383906, 0.15442433793629917, 0.10144010997776474, 0.18219334286238464, 0.14759371589337075, 0.1475613633436816, 0.11522691696882248, 0.20628025036837372, 0.1386109571903944, 0.13492396074746335, 0.10729090709771429, 0.05273971786456449, 0.14242336047547205, 0.06993104038493973, 0.20523551000016077, 0.11769991926848888, 0.09481973201036453, 0.15519254814301217, 0.06638939292835337, 0.12494747393897601, 0.16165175368743284, 0.2322950522814478, 0.0924487542361021, 0.17975818924605846, 0.1522311091955219, 0.17116526248199598], [0.04945259567882333, 0.030590346748275415, 0.041194023830550056, 0.007044858872956995, 0.007216865379762436, 0.0239444948799376, 0.02938602851437671, 0.016235337925276587, 0.019089293533137867, 0.020944011331136738, 0.020747845160907934, 0.020796234885762845, 0.06884974054992199, 0.04025051749444433, 0.0073717367569250715, 0.0036915731616318226, 0.03493223465713007, 0.05142754988212671, 0.022145006439781616, 0.02302202652208507, 0.01671822076397283, 0.011101859189303858, 0.03649311625797834, 0.03326227855203407, 0.01693046142879341, 0.08226664417556354, 0.03908821075622525, 0.028129687000598227, 0.033960752322205474, 0.044988052387322695, 0.01745758475070553, 0.027666524085881453, 0.04189343737172229, 0.04341211070173553, 0.005334604573103466, 0.03693887644580432, 0.07565484967614923, 0.025548909591244798, 0.0636001458125455, 0.020777073056836213, 0.0034759368531272878, 0.02255658203336809, 0.07370660600385495, 0.03845947342259543, 0.008343231814381267, 0.031560814673347135, 0.012241874355822802, 0.028236042275758724, 0.05908448847809008, 0.019661061066601957, 0.018376390715794902, 0.04356473358348012, 0.07244586079780545, 0.02787452221049794, 0.01313118016280766, 0.05484986338498337, 0.0413271897206349, 0.044436688401869366, 0.11585093848407269, 0.005878008070534894, 0.003670192099109824, 0.020972165445398008, 0.0765988818768944, 0.05971980760140078, 0.032220757832484584, 0.052701211002256186, 0.0654358748080475, 0.02666073332407645, 0.027241192891129425, 0.04988411341660789, 0.04227873330403652, 0.07194550228970391, 0.04739643440448812, 0.011973674059845507, 0.021312277730820433, 0.012892674255583967, 0.046202697924205234, 0.06729495219354119, 0.03893956069701484, 0.06232387572526932, 0.022682406174551164, 0.03824780781620315, 0.05656566470861435, 0.008944506291300058, 0.05192611027242882, 0.01847291232219764, 0.02401667064987123, 0.05629441694223455, 0.03723798825272492, 0.0255352031838681, 0.007898073826384331, 0.05745668296835252, 0.0061130369098724, 0.034525456306125434, 0.026177073562783853, 0.040164899945791276, 0.03517764720267483, 0.00557208462019584, 0.014232002298480697, 0.004564475808625242, 0.0394909653945693, 0.018910821859857867, 0.03845457439976079, 0.045141574327967, 0.023034535315153853, 0.039242299273610115, 0.05305881931313446, 0.06778463056044919, 0.04175323846616915, 0.01590285576613886, 0.04566526426268475, 0.013427744918902005, 0.05216844566166401, 0.014928470997671996, 0.04958229086228779, 0.027856176319931234, 0.008116037085918444, 0.058793111970382075, 0.022260413372090886, 0.025234971794166734, 0.02600196742319635, 0.04679353229169335, 0.05629431176930666, 0.022064133547246456, 0.007363045571504959, 0.07045675574668817, 0.020656449886571084, 0.03656670677342585, 0.042392825574747155, 0.056970600837043354, 0.038765570747533014, 0.029606165630476813, 0.012125899998604186, 0.028722882669951235, 0.024893319234251976, 0.014652047705437456, 0.022167476126924157, 0.03609126067853399, 0.08566857448646001, 0.042368072617266855, 0.015796683695433394, 0.019853710729096617, 0.027817438755716597, 0.005378740307475839, 0.05825661468718733, 0.07444504887929984, 0.023834234635744776, 0.03146036095651133, 0.026601219017590796, 0.02375407250864165, 0.016541723627597094, 0.020435164349951913, 0.026932679981525456, 0.05806859941887004, 0.04810732875817588, 0.016878248159108416, 0.017427339052249278, 0.0703963932714292, 0.057265397161245346, 0.07227611169219017, 0.043871940313173194, 0.018798044250745858, 0.044222858268767595, 0.04036499313744051, 0.03344749825607453, 0.0606428323579686, 0.023607863479160836, 0.04702195432037115, 0.06192112447960036, 0.0273798650928906, 0.04201653380213039, 0.012016245346915509, 0.007519594626501203, 0.03212808012696249, 0.010144044245992388, 0.058820891194045544, 0.09972627979836293, 0.02552695389437888, 0.05185263171525938, 0.038078872952610254, 0.06839819585106202, 0.029630735383502076, 0.009113492045019354, 0.027306776693356887, 0.03196135389485529, 0.07153993512370757, 0.04529478074982762, 0.01117925374169967, 0.0400986206451697, 0.011041022587700613, 0.07217000238597393, 0.03771326471386211, 0.004795684071723372, 0.0441276699836765, 0.04308011030246105, 0.06058137744132962, 0.007689684695963348, 0.02496510654288743, 0.06903274144445147, 0.039331048261374235, 0.04225843832162874, 0.06814768072217703, 0.026248482588146414, 0.033948983132307015, 0.04235435603186488, 0.03933925853509988, 0.028920282077576433, 0.10342558486653225, 0.027812122433845485, 0.032873525483799834, 0.05545566284230777, 0.018045516684651375, 0.06688994142626013, 0.029520520940423012, 0.02290223794989288, 0.04569719951333744, 0.026903346912669282, 0.06045781621443374, 0.1040319169738463, 0.04991749733952539, 0.023785722774586508, 0.057215070218912194, 0.027011462986203175, 0.029689808642225604, 0.03094301193154284, 0.03563771430136902, 0.023115873004176786, 0.02837988661069955, 0.027668279795242206, 0.02542895986698568, 0.011418472958861716, 0.06582351507885115, 0.039759841681058915, 0.05702628820602383, 0.04472070619730013, 0.04748811127085771, 0.019942037328811626, 0.08094533971909966, 0.04075253841334155, 0.03732912568375468, 0.04640047052609069, 0.03574567600818617, 0.03815892990678549, 0.09407264459878206, 0.0228676615016801, 0.03063412243500352, 0.040229557547718287, 0.018476098044110194, 0.028910531529358456, 0.07130029012582131, 0.0027943198011988507, 0.013939615621763681, 0.01553002282577966, 0.10288705876363174, 0.03430193330028227, 0.05025423052055495, 0.04061162365334375, 0.021891502364139472, 0.04134203606684293, 0.017086385383403728, 0.12293531905327525, 0.05657451959060771, 0.054784262619380436, 0.018487911338784864, 0.024404455109366348, 0.03598329557904175, 0.03807273221069148, 0.08416238959346499, 0.025414770003408194, 0.02658373486649777, 0.03168818248169763, 0.010464193182997406, 0.03562334971502423, 0.010436771886556276, 0.033794460352510214, 0.028853500661041056, 0.006680469452736101, 0.08187861713979926, 0.024425477820581624, 0.05866030909653221, 0.07437678825642381, 0.03073138025190149, 0.007840389019942709, 0.013249613361300101, 0.008653735376096197, 0.11346674284764699, 0.021187137213668654, 0.019304258516058326, 0.051424136850982904, 0.009500537749512919, 0.03507119523627417, 0.044497468176164796, 0.03898816755307572, 0.0189811893339668, 0.0111618060618639, 0.052376053628644774, 0.050942546621497185, 0.006253675590934498, 0.06179520873618977, 0.035443124028721025, 0.041317585057445934, 0.057591616442160945, 0.042683917097747326, 0.06272382462131125, 0.022074138546096425, 0.023615178086661866, 0.0023494862377577063, 0.017710537516645024, 0.0436585206937577, 0.047114190978131125, 0.046834810969552824, 0.017437422082626393, 0.06092992052435875, 0.034070583392999, 0.06192329579166003, 0.03120712490220155, 0.039036044983991554, 0.01450325854654823, 0.027464176461632763, 0.033629345641072304, 0.048377026072038073, 0.01712408648537738, 0.02592089436283069, 0.022745112988299558, 0.06567048507609538, 0.023154580034315586, 0.045030443862612755, 0.0401237705456359, 0.0360934659173446, 0.018144316472379223, 0.08158820415181772, 0.025557837415752665, 0.0128072000474536, 0.04654107315997992, 0.023628930295152322, 0.011317849608271249, 0.01076296657057745, 0.02656857300150607, 0.036640331215624294, 0.01835059790339853, 0.013754673268912094, 0.08091349607067448, 0.025799791129039865, 0.05804960722369807, 0.01787813057723854, 0.008628240270939256, 0.01588216723342027, 0.0039952396348650965, 0.02134620108907776, 0.01196351639061634, 0.028815302532166243, 0.007984737167134881, 0.15608484883393559, 0.15744229885084288, 0.1508763868893896, 0.07975291620407786, 0.12391953409782477, 0.06354971030460936, 0.08492597897670098, 0.10053092733557735, 0.10037985151367528, 0.14164898917078972, 0.16451928338834218, 0.0938990278435605, 0.120841169995921, 0.12882322525339468, 0.11989320229206767, 0.09594817645847797, 0.1393527045313801, 0.14458851143717766, 0.09105738425361258, 0.17529147464249814, 0.12985571127917084, 0.132315387151071, 0.12734484672546387, 0.14058098862213747, 0.24038498103618622, 0.18049458973109722, 0.14234127130891594, 0.15101396664977074, 0.1325330747557538, 0.15546434213008198, 0.11786616034805775, 0.15471879499299185, 0.16525446251034737, 0.13975190025355133, 0.13187923841178417, 0.08268994824694735, 0.15374953486025333, 0.1538104401635272, 0.16417441117976392, 0.11574256287089416, 0.1512596234679222, 0.11304048036358186, 0.1893861261861665, 0.14720764303846018, 0.08782286210251705, 0.1713642632322652, 0.1019799660093018, 0.12669673721705163, 0.14396698693079607, 0.13471448341650621, 0.13782266234712942, 0.07524747082165309, 0.14599736726709775, 0.10441527568868228, 0.1114944111821907, 0.12464260815509728, 0.10511578167123453, 0.15000950412026473, 0.1417113058269024, 0.10262953436800412, 0.13464867909039768, 0.1124110577095832, 0.19644469528325967, 0.1265860138727086, 0.12652152590453625, 0.10621888283640146, 0.13793333140867098, 0.16250133381358214, 0.11160242038645915, 0.1085984915761011, 0.1726333408483437, 0.15530137158930302, 0.10500191670975514, 0.12035989867789404, 0.10031841016773667, 0.16506440485162394, 0.1432177892753056, 0.17215519079140254, 0.08731986409319298, 0.13912557171923773, 0.15160935398723396, 0.0688286516815424, 0.19251121420945438, 0.11757048192833151, 0.18880458096308367, 0.10282312719417469, 0.10197035116808754, 0.11035952065140009, 0.24667662914310182, 0.09268727965120759, 0.1158932519278356, 0.1733875868043729, 0.10447878656642777, 0.1638154797255993, 0.13104848084705217, 0.13901024790746824, 0.11320526259286062, 0.09928293858787843, 0.1447901991861207, 0.14602212022457803, 0.09005769182528768, 0.18357408020113195, 0.08330885360815696, 0.14932417018072947, 0.15579195240778582, 0.1335771365889481, 0.11497173351900918, 0.19787020236253738, 0.1831670677555459, 0.16762778801577433, 0.15888075237827642, 0.06254412140697241, 0.16884088649281434, 0.10893030877092055, 0.15388722318623746, 0.1802197287657431, 0.09460599347949028, 0.12406874394842557, 0.1469846764313323, 0.17902558855712414, 0.13809977604874543, 0.16299010972891534, 0.19485441276005336, 0.09487197242145028, 0.14455929371927465, 0.22326922017548764, 0.15604676944868906, 0.15847930391984327, 0.11353612983865397, 0.13067078111427172, 0.1560812797397375, 0.10919237256582294, 0.1746424287557602, 0.1190534880650895, 0.17608384069587502, 0.07995815269116845, 0.11547830062253134, 0.06559490306036812, 0.19599504369710172, 0.13095681076603277, 0.09405045650367226, 0.056262088141271045, 0.138307231345347, 0.10253675827490431, 0.13620276855570929, 0.13499811105430126, 0.12380277179181576, 0.08451623882033996, 0.12897837907075882, 0.06117759259151561, 0.06572487644319024, 0.15382340018238339, 0.12822295246379717, 0.14059994689055852, 0.19275835023394652, 0.07566205571804728, 0.043829657403486114, 0.15901985205709934, 0.13011013476976327, 0.19150911298181328, 0.09482218830713204, 0.1566571116979633, 0.12696768982069834, 0.14733600829328808, 0.09840618991958243, 0.13447410560079984, 0.13945139066449233, 0.20363845569746836, 0.1128646990816508, 0.17050816916993686, 0.16478380348001206, 0.1128768448584846, 0.08306122225310121, 0.0655764469078609, 0.13008939873959335, 0.13612411277634756], [0.05316392099484801, 0.03244002303108573, 0.029319762784455503, 0.06045582132147891, 0.032261001744440625, 0.05036308789359672, 0.03378874708765319, 0.02578830353117415, 0.024088021999757205, 0.017530461108045917, 0.015828783490828106, 0.03702425989987595, 0.051094362046569586, 0.030314071037407433, 0.046051445683198314, 0.059371963409440856, 0.022707505184890966, 0.0663207048284156, 0.04698241608483451, 0.028003664387922202, 0.04005351842248014, 0.04993430125926222, 0.022572564925732355, 0.03566741717181035, 0.04042034802426185, 0.02923954976722598, 0.12183814149882112, 0.03210051803450499, 0.05366222354184304, 0.0334277834211077, 0.0576975696853229, 0.055942898483148644, 0.016411070013418794, 0.06308744475245476, 0.09503261558711529, 0.06842860100524766, 0.01611412612588278, 0.011347880720027854, 0.025564923017684902, 0.03640363445239408, 0.05663174384140542, 0.03328454128599592, 0.025882416338260685, 0.031968081569565196, 0.030235116702637503, 0.018036532881004468, 0.005972003830330712, 0.02102703687601856, 0.02260854933410883, 0.03585172085357564, 0.08433473748820168, 0.04492679424583912, 0.008634703316991883, 0.0371782568150333, 0.050204700856868706, 0.03771870656471167, 0.00476239896046796, 0.02667305212734001, 0.06866260059177876, 0.09280068320887429, 0.019422745997352258, 0.05791147106460162, 0.003906670034796531, 0.014506318739482334, 0.02773630293086171, 0.03421309610296573, 0.09089493618479796, 0.036337592639029026, 0.02289441104845277, 0.04622467228078416, 0.02322257263585925, 0.010846054879948497, 0.044695430767855475, 0.00912319848846112, 0.03898802166804671, 0.04967033417363252, 0.005790703938276107, 0.02482571339766894, 0.025407299332852875, 0.03536498054329838, 0.012538145645521581, 0.03540378935368998, 0.012369365148645426, 0.04414354770311287, 0.04446524115545409, 0.002671168027778289, 0.03939593656520758, 0.024240816211594, 0.06624276829617363, 0.08883987752986805, 0.029269880282559564, 0.013820657406800559, 0.025009971278320466, 0.03045398835092783, 0.05303320800885558, 0.054266475939324925, 0.012615854020363517, 0.049501674116722176, 0.046895268439714394, 0.027965890343434045, 0.03842164509530578, 0.040556675887533596, 0.004965863622991102, 0.029174990552876676, 0.0361312704959086, 0.022741649067029357, 0.02981152425387076, 0.0637899117012109, 0.0727375630023224, 0.04214663610660604, 0.052219003305903504, 0.019172744858743887, 0.021228288666212132, 0.0713973884869899, 0.03190837048792413, 0.04156975241910134, 0.023791427557755793, 0.02217457360321922, 0.025683062749781778, 0.07085977840636458, 0.043371941428631544, 0.0359239339429353, 0.03070805561063545, 0.0019416659114150597, 0.03764391504228115, 0.042258261902523894, 0.0980786339246801, 0.0391327599728746, 0.027675911617864455, 0.0352326865707125, 0.03643724907721792, 0.031794281609888585, 0.06486033461987972, 0.03165838122367859, 0.0310110554232129, 0.022051797780607427, 0.02912451433283942, 0.022316012531518936, 0.023482029159952487, 0.07778008242270776, 0.028463712826903378, 0.08609790394880942, 0.05070518489394869, 0.034292006332959445, 0.06111381708511284, 0.02814958504002009, 0.025857724448932067, 0.033491080560322316, 0.020051381550729275, 0.017549909618017927, 0.004603557729361845, 0.0125515526493213, 0.05847589684916394, 0.04532704169728926, 0.02562463579566351, 0.024904794957754866, 0.12889512282397064, 0.06671171063291174, 0.024288381516401256, 0.06400702255112783, 0.04308579642591732, 0.04052849972088422, 0.026808372366109064, 0.0324398364339556, 0.019319169323093126, 0.030719309113919735, 0.05496932626036661, 0.04710440989583731, 0.00623511935451201, 0.031910083788846216, 0.029358931218406985, 0.019890042886670147, 0.09375430989478316, 0.024421411699482372, 0.05171106216896858, 0.010203785013540514, 0.05784804839640856, 0.026267824228852987, 0.018923317082226276, 0.07583010170076575, 0.0290762297809124, 0.030919819604605436, 0.022329637514693395, 0.06088572075324399, 0.06698100761111293, 0.04303843128894057, 0.04331139235624245, 0.010790761061278837, 0.029681686578052383, 0.003244838851969689, 0.011324229533784091, 0.06011597705738885, 0.07748838700354099, 0.030471972921597104, 0.03120942852858986, 0.048445873627705235, 0.02449923288077116, 0.017386555704953413, 0.0576332106388041, 0.05117567768320441, 0.04777964384162, 0.025569664281127707, 0.032838129704552035, 0.0467402367586536, 0.04996946633660367, 0.016546417393588593, 0.02983599222664322, 0.03380386145519359, 0.06378756397004638, 0.07816751913300582, 0.034018685642097674, 0.025452656006174426, 0.014662827930546232, 0.006936515066107469, 0.0014269199164118618, 0.005112936088283147, 0.005706509616824665, 0.015444651246070862, 0.023019149533606002, 0.03829795155408127, 0.041816165803798606, 0.04572665471849697, 0.04607732840148466, 0.007959217465083514, 0.035896127577871084, 0.03476197325757571, 0.03037201114264982, 0.042079301684030464, 0.037391445732542446, 0.008187536865339747, 0.052852687159819264, 0.05445993645116687, 0.008176626870408654, 0.04131125771839704, 0.03763558263225215, 0.05136807968041726, 0.023138033957885842, 0.04381618509069085, 0.022354288691920892, 0.05950089184833424, 0.03133296261408499, 0.005538676524468298, 0.055979525803455284, 0.02256858192517289, 0.031510487731013975, 0.0159027590748987, 0.003868049941956997, 0.01421193971431681, 0.027958821704877273, 0.011327607790008187, 0.035095368046313524, 0.05741844752005168, 0.0344280288554728, 0.04779015774173396, 0.07626217922994069, 0.0388818479010037, 0.02893776453233191, 0.01076222866374467, 0.030559422514800514, 0.00830195568102811, 0.04828582757285663, 0.025711128654490625, 0.029212150523172956, 0.0038923546422405964, 0.0447916063213987, 0.0630024310999683, 0.04027909060407962, 0.03049344176958714, 0.054533978192401786, 0.03355003507541759, 0.04560324955465538, 0.02282915124669671, 0.04420821209039007, 0.03090641853798713, 0.020465610216238668, 0.03492294212004968, 0.038615631471787176, 0.025006317367245044, 0.02513177509951804, 0.03544859980632152, 0.051799207260566096, 0.04206434677221945, 0.03889174433425069, 0.04775545406820519, 0.054130582338465114, 0.020801541029608676, 0.02959679506186928, 0.03763160980971796, 0.0195724308224661, 0.029044423451913253, 0.03889860771596432, 0.012991551226670188, 0.018101885981325592, 0.020633852974112545, 0.041981870840702734, 0.025752889092213342, 0.059852311919842444, 0.06035514708076205, 0.023950795077585747, 0.014148605255676168, 0.024798193713650107, 0.04358100485322731, 0.008671306888572872, 0.0110648637637496, 0.028151601985363022, 0.08833003310220582, 0.04978225852495857, 0.06720892073852675, 0.07539191057107278, 0.040570351760834455, 0.034463987818786075, 0.013144302181899548, 0.04456874488719872, 0.049688410346529314, 0.01588545473558562, 0.03255034264709268, 0.06823086233011313, 0.048929183943463225, 0.017918516981548498, 0.026385828253946135, 0.03308808504204665, 0.015864749239491563, 0.015968193599422063, 0.012350395854030336, 0.020202391215467026, 0.04724874107965401, 0.04879195362861667, 0.015653495843123113, 0.0348862842656672, 0.020851693249174526, 0.06366377882659435, 0.03543863891224776, 0.05543374616120543, 0.013351845688053539, 0.07173409113394362, 0.024827197693022232, 0.07776050668741975, 0.05401054270831602, 0.061014187788324695, 0.015609173935704997, 0.027731953521392176, 0.067377177067101, 0.06526349977191005, 0.04408978058823517, 0.03492053671340857, 0.04790657399488347, 0.024731895753315518, 0.027899024110021334, 0.06263065497790064, 0.02793426382621484, 0.06174416933208704, 0.02104189509658941, 0.19245826133659907, 0.11188652978411742, 0.2252151093312672, 0.19156521425715514, 0.11279020950730358, 0.13209828308650426, 0.12349397050482885, 0.14189476812524454, 0.1507627187030656, 0.11170009550239358, 0.10826801788061857, 0.1062866345580135, 0.21162003598042897, 0.075968231074512, 0.1640024704060384, 0.19004813209176064, 0.2013222085578101, 0.13457102754286357, 0.1204351753528629, 0.19558200586055005, 0.0727704990921276, 0.14695524158222334, 0.17422610680971826, 0.1909421155495303, 0.17720867533768925, 0.12022776076836245, 0.18441428297332355, 0.11489467908229146, 0.0997593312391213, 0.056772393972745964, 0.14897441252001695, 0.15256071436618054, 0.1333167962729931, 0.13499845032181057, 0.1429676269846303, 0.15429783186742238, 0.10633546193795544, 0.04095495219475456, 0.07251080338444028, 0.1271716167352029, 0.12045764843268053, 0.0917661887194429, 0.11586041083293301, 0.058739982678421905, 0.13325810299388, 0.11182787043175527, 0.11498022877744266, 0.12816035082297667, 0.12085183656641416, 0.14668665028044156, 0.12581557807113442, 0.0908126841698374, 0.09783445631286927, 0.1752278416284493, 0.14566275450800145, 0.34042191452213694, 0.11281102017632552, 0.14124577652130807, 0.15130739233323506, 0.13950503564306668, 0.14615219538765295, 0.10459094161966018, 0.1322797912039927, 0.11818413542849676, 0.10198623567287411, 0.08247270847537688, 0.19383237617356436, 0.09278825244733266, 0.09854149658765111, 0.09870716769780431, 0.10525392461568117, 0.08840556762048177, 0.23657419266445295, 0.07521223449813468, 0.18875146524182387, 0.11813077543463026, 0.15121937277061598, 0.20305901393294334, 0.1366444541407483, 0.10075759195855685, 0.10630498893026795, 0.13512961114091532, 0.15060915265764507, 0.1148772407323122, 0.15877082970525536, 0.11319038910525185, 0.13321470389408724, 0.12332759371825627, 0.16154037894947187, 0.2540028260222503, 0.14118660826768192, 0.17405788440789494, 0.11526705910052572, 0.11796210519969463, 0.07564931283039705, 0.15327812944139751, 0.06531565875879355, 0.15233275374131544, 0.09836245155228035, 0.13769151509872504, 0.18875749063278946, 0.23937057118330682, 0.15604556165635586, 0.10033759235271386, 0.11106932256370783, 0.07388615994048969, 0.24108218933854783, 0.14524058359009878, 0.19542808697691985, 0.11196815076151065, 0.14569099513547762, 0.09964372922799417, 0.08021647775811808, 0.14411762170493603, 0.10618798913700239, 0.08028893172740936, 0.09843855603997197, 0.09273679235151835, 0.1532419499542032, 0.16233967963073934, 0.15213349514773913, 0.1452243123203516, 0.10173969675919839, 0.07067326948578868, 0.07286595539855105, 0.0973112243892891, 0.14382746656026157, 0.09330352515514408, 0.10934305483741419, 0.08746540985469307, 0.12967617091323647, 0.2010370610015733, 0.13733168797833578, 0.06533671370042221, 0.12904186280710356, 0.09629561352942671, 0.12753651929753168, 0.13526613238666738, 0.1601318759577615, 0.1446649551923786, 0.12282661774328776, 0.18692453684551374, 0.16031204057591303, 0.16425773528005394, 0.1320040752845151, 0.11955620108970574, 0.0872200040944985, 0.06008591117071254, 0.13273009418376855, 0.10952354515237467, 0.1493522615305015, 0.055506376549601555, 0.1274329341415848, 0.11571983194776944, 0.20940592193177768, 0.12810312317950384, 0.24177622209702218, 0.1759091586406742, 0.12968526328248636, 0.10461211869759218, 0.13400023031447614, 0.19836667286498205, 0.09226840641349554, 0.12145197364900794, 0.07621801338557686, 0.12739865455244268, 0.19913974138242857, 0.11599956479455743, 0.1229105389543942, 0.13622389813619, 0.1836524645664862, 0.06551641012941088, 0.21534678100475244, 0.09789160931749002, 0.1212502723293645, 0.143684377095529], [0.02436028078331479, 0.0415364363496857, 0.033825591539165804, 0.04677435349939125, 0.04643295878278358, 0.05059556416901095, 0.015164173707099897, 0.06072410049715212, 0.012454440717452338, 0.018501134289960777, 0.0311780836034034, 0.06959140646670546, 0.04615501048309462, 0.04596644560141223, 0.044761543827397485, 0.011505506949366202, 0.014460953584473048, 0.024869629880413413, 0.015939600133736218, 0.04553774039127997, 0.029979244539780275, 0.010269200878350862, 0.03834757281999503, 0.06528871413320303, 0.02633334357025368, 0.017616124457812736, 0.0536228311913354, 0.017327221210247705, 0.04867242289973157, 0.005861274972890637, 0.023551104024850895, 0.028239226301333735, 0.0334822053222784, 0.007884429335328085, 0.023555243088464652, 0.07742644354168858, 0.04363660401265536, 0.07821263492639575, 0.026422431825527122, 0.011483211984990962, 0.023119479417800903, 0.03354022345904793, 0.04099069741953697, 0.013576707104220986, 0.01563912277509059, 0.10260318006787982, 0.025955408046554242, 0.035929467396012375, 0.027645133269418563, 0.01729695006672825, 0.02315719409047493, 0.04370982472651771, 0.08768397276954991, 0.03686732492808785, 0.007249310379847884, 0.04678007694227355, 0.07619790160762412, 0.013617576116562953, 0.024740938928776553, 0.010852789340008582, 0.039143596177122424, 0.031187443993985653, 0.04651091906375118, 0.0442346512073917, 0.03647344892046281, 0.026951436385778443, 0.05107313747118626, 0.025451677219410027, 0.027807494825018302, 0.080806905004595, 0.025336361889328276, 0.0411978677314307, 0.06912989408842155, 0.054733392849032364, 0.031305956920342784, 0.02740480125482593, 0.010958019943375672, 0.03167456089119826, 0.02220560809863465, 0.027002460522843257, 0.021066432619201284, 0.021379783483488218, 0.044655342918953726, 0.030130296612956693, 0.06726290498461042, 0.004218603609063263, 0.06524320478950228, 0.02982849780736225, 0.045041704151247225, 0.037386957223394086, 0.04232097210894738, 0.03959760735077517, 0.058791313852582655, 0.05398338773686971, 0.02438131536889289, 0.046985876613429615, 0.049997910524585416, 0.035842679374452145, 0.011362051923892327, 0.04152338133592691, 0.06552142450319869, 0.05037200723641685, 0.00506287462277604, 0.019547905174217055, 0.00881349983891206, 0.07083831634372473, 0.10527081335229532, 0.0330344943462738, 0.04351226586316313, 0.06263093317725829, 0.0529490594885179, 0.04262543755716511, 0.009505759924650192, 0.062275923655501435, 0.0666692071993436, 0.008314427154670869, 0.027245530426236134, 0.10937364998140506, 0.08178825663136584, 0.014246813021600246, 0.020836446567305496, 0.05558372614905238, 0.026414396274568777, 0.04546582925000361, 0.00852733023930341, 0.02279109221750072, 0.022637694109497324, 0.033438344818672965, 0.06879777155284371, 0.0609382800757885, 0.01775434204111142, 0.048650947266391346, 0.03536128252744675, 0.057249363378754685, 0.030780356909547533, 0.019631185169730867, 0.05844965111464262, 0.011468673524047648, 0.03649091101916773, 0.033022640339498005, 0.13476035238376685, 0.06669108316834484, 0.07655606631721769, 0.049855187468762906, 0.048867050491805585, 0.02307398703747562, 0.055207783821970224, 0.025882943899237683, 0.01204469971292253, 0.020412296023485915, 0.012380832390460585, 0.021407513513362834, 0.0371439670478659, 0.05721469023930175, 0.02116703731007874, 0.02104044981699969, 0.07476835045963526, 0.04361518944746681, 0.06683650000819139, 0.03203482905934964, 0.030663692991116216, 0.022444913829011575, 0.01796587024416242, 0.027382974479613558, 0.033960813390357156, 0.015488711917506797, 0.05181589922202485, 0.06400132285697119, 0.025612554479656473, 0.05818270865295615, 0.03631224935608251, 0.05606361325564129, 0.018783104605972767, 0.04188864352181554, 0.03824297325419528, 0.04878079851291009, 0.05856549061302628, 0.039217176514544656, 0.007007078467203038, 0.06816163818751063, 0.021016813049625074, 0.052079852736954174, 0.019246686516063552, 0.10163546020963363, 0.04634255077689886, 0.04384289222902485, 0.01904058998583683, 0.061398930714598725, 0.01037244507045086, 0.018396716232278516, 0.04260105440126998, 0.03304384795150586, 0.004284151364117861, 0.08028464338609151, 0.03079321175547583, 0.062370219667043, 0.009159657871350646, 0.015353401856763023, 0.036722162538873296, 0.04207699127229197, 0.016802557577778186, 0.027452023899448768, 0.03927132021635771, 0.04828822280147246, 0.06391293688544206, 0.04981155766706381, 0.021855660448116914, 0.04098692476483328, 0.05295937322080135, 0.030426450007195984, 0.029524252883025577, 0.04366936029068061, 0.01507082425190934, 0.038342348100351434, 0.03554471429171307, 0.0644523925813181, 0.0609656386077404, 0.03661501846675362, 0.031695001758635044, 0.017308525874146392, 0.014679879515564867, 0.033041422188814194, 0.04034094246370452, 0.00817983634104686, 0.0390860767635916, 0.028908794479710714, 0.008228407574019261, 0.0280480948609433, 0.026821093201371174, 0.022286080655508807, 0.05607459195224302, 0.017952357219266038, 0.060856245192033906, 0.04755751183256507, 0.007168417131262166, 0.025972315442881415, 0.007319203727612538, 0.02775359369947442, 0.05408196869705405, 0.04046560970268079, 0.08794630119310957, 0.038370188392166577, 0.026033753396144936, 0.024239452356206517, 0.0467899394487696, 0.022689388299893056, 0.04037304734811187, 0.06434843423111097, 0.018395533885008523, 0.07231156514691454, 0.0630343086751444, 0.022252610219376426, 0.05494046138067331, 0.041442272652472766, 0.024940021103248, 0.03556168445252946, 0.03789486104090299, 0.008156292872237307, 0.06880311840879065, 0.042658207405890734, 0.0494138547219336, 0.04923373081588319, 0.03751093235665134, 0.056828217048730166, 0.03106046634327088, 0.05517560429871082, 0.01808963672790144, 0.005806034164769309, 0.008665215340442955, 0.04868834133126906, 0.03915958246216178, 0.1036841542060886, 0.039986818430147, 0.053849855437874794, 0.017296656600332687, 0.019193516512002264, 0.023515107742111598, 0.0574236111715436, 0.017531090449275713, 0.03851256200245448, 0.006765181581223649, 0.04092771919178111, 0.036070181988179684, 0.011051976687407919, 0.011839960252733102, 0.01668769008080874, 0.08081994644765343, 0.05099085492214986, 0.03144564353195684, 0.031416988998119316, 0.06503572235149996, 0.03885036048346332, 0.07249748374202422, 0.06419218797236681, 0.05100070046527045, 0.052156595047563314, 0.027007473200293522, 0.036388190995369635, 0.0723511983773538, 0.02542481062534664, 0.015543215242879731, 0.05603301811165043, 0.06463704910129309, 0.0022311423090286553, 0.03541973153395312, 0.048135884904435704, 0.0231832379608282, 0.02195708786270448, 0.020261596788519194, 0.025345700227522423, 0.03387264455003398, 0.018634576683065722, 0.03752467608345406, 0.027105932024174502, 0.07702242343553475, 0.07246475121272461, 0.02984923044485705, 0.011834844946861267, 0.06748122362686054, 0.012426813315999295, 0.031314642168581486, 0.020834495779126883, 0.014349356626293488, 0.05410953078951154, 0.03196489245497754, 0.03382875011967761, 0.013916135765612125, 0.03707944176026753, 0.024137446490515555, 0.04882641302953873, 0.03882733779028058, 0.05646131959344659, 0.08320005730326686, 0.0536197709984013, 0.01644571092245834, 0.023477859562262893, 0.04360925565872874, 0.01496974628285638, 0.022574278226654445, 0.05236746337530868, 0.025252316845580935, 0.04719885179240789, 0.010296728195888656, 0.0050688173172862405, 0.039035583580178876, 0.09060402108090264, 0.027673758965517794, 0.01670774757595999, 0.019826437014022043, 0.08465685841760465, 0.030817547413919653, 0.10701775604060718, 0.07720868808350392, 0.16973267149712357, 0.18658442795276642, 0.2610081029789788, 0.17341049414660248, 0.14628731885126658, 0.08596769307873078, 0.1816421824374369, 0.12100466979401452, 0.0791483957852636, 0.07210371630000216, 0.2169051045285804, 0.19976418358939035, 0.14831666781433991, 0.1318965410547597, 0.07454752802316632, 0.24504999071359634, 0.1380510843758072, 0.08273762211735759, 0.19727641636771814, 0.07867867991860424, 0.0984346205368638, 0.11938435531088284, 0.16490142074014458, 0.09171198734215327, 0.1671327967196703, 0.10105152654328517, 0.08924845739134721, 0.15752636933965342, 0.15182401532573359, 0.10119797475636005, 0.0859636693660702, 0.11863772251776286, 0.1128106809088162, 0.17478175913648947, 0.10782164361860071, 0.10043328614639384, 0.16222405726356165, 0.19251444403614315, 0.17451385994042667, 0.14818892681172915, 0.20393794748399938, 0.12758859007486276, 0.12090248242020607, 0.07565516180225781, 0.30733953256692204, 0.09165692422538996, 0.1279406411839383, 0.09485612184341465, 0.10707974021456071, 0.19642159795122488, 0.14487232906477793, 0.14639983352805885, 0.11126955824771098, 0.15845757722854614, 0.11339826509356499, 0.11588197467582566, 0.09456696414521762, 0.14073212551219122, 0.23314066976308823, 0.0827092525682279, 0.08847800123372249, 0.15984036374304975, 0.15258994565478393, 0.1621819609510047, 0.10943406673946551, 0.1960954533091613, 0.14315000362694263, 0.10827369043337447, 0.1568929568997451, 0.07243011200002261, 0.1736254133284092, 0.12645018473267555, 0.08183645975909062, 0.1629463577909129, 0.09250615829867975, 0.07967463361897639, 0.14236994619880403, 0.103421391520117, 0.09294125530868769, 0.07407573583934988, 0.10030637295650584, 0.13919217671666825, 0.11132070621741669, 0.12475080734917096, 0.11101055464574269, 0.12365308696670191, 0.18518154323101044, 0.15962419605680875, 0.11723333144826548, 0.0791605958448989, 0.08723270627004759, 0.14471632029329026, 0.12503425856786116, 0.08431212191603013, 0.17372078821063042, 0.122944479276027, 0.07720731065741607, 0.061219166432108195, 0.11977561217333589, 0.20647142082452774, 0.11994315604014055, 0.08085180366677897, 0.10283631112958704, 0.108384976961783, 0.16377900168299675, 0.17570637166500092, 0.12568515006984982, 0.12071085056023938, 0.11964987963438034, 0.17206312716007233, 0.13699795731476375, 0.11049207246729306, 0.13492668845823833, 0.12850317385579857, 0.10445765020059687, 0.16799195776028292, 0.18004478886723518, 0.22344232802944525, 0.11104151619864361, 0.1316575745918921, 0.12083722092211246, 0.23228712699243, 0.14513076948268072, 0.08351884662572827, 0.19798301559473785, 0.19709855876863003, 0.08751812524029187, 0.19058580324053764, 0.1466196517327002, 0.10441031559769597, 0.2332649773785046, 0.08173368884516613, 0.09173640103212424, 0.17753382931862557, 0.05401041378666248, 0.20246525507952484, 0.07251764301742826, 0.14332962541707925, 0.17037436206425938, 0.18626462082777703, 0.22770370436566217, 0.20670320838689804, 0.16600013178374085, 0.13810116026018346, 0.14795377371566637, 0.1252919661679438, 0.16766075124698027, 0.10734364962471382, 0.07943958908851657, 0.05477888522935765, 0.07764463326228516, 0.07602550621543612, 0.13553445227444172, 0.11396898089775018, 0.15363577167902673, 0.25514572326626095, 0.12815930587904795, 0.10762543843260833, 0.0709996787565095, 0.11492712662688323, 0.11536227113434247, 0.13062492571771145, 0.13291407216872486, 0.09538760475282158, 0.2088499710495983, 0.15466748417488166, 0.10243035719863006, 0.069493039245052, 0.15528964650418076, 0.06286238147211926, 0.09472442498164517, 0.0719358738777893, 0.21224305326385157, 0.10169726117913212, 0.27281371663723675], [0.005330869237825806, 0.020625026929857473, 0.04387453570961952, 0.017023089940526655, 0.056864420284650156, 0.0333365645658757, 0.04441233238737498, 0.026786932355857322, 0.04396649756069694, 0.007628764125651547, 0.0035810822155326605, 0.042948230236236534, 0.03023904881307057, 0.08088748103805951, 0.024683675662215267, 0.02734215381289167, 0.015105622920340725, 0.020664259824635725, 0.008320149749384394, 0.0486577970774046, 0.02788589785008558, 0.0410682437941432, 0.02925618066053305, 0.009774406357402248, 0.03174861281045845, 0.023561293924493448, 0.08919892433498587, 0.03737699972199542, 0.04152185123945985, 0.048228077457419465, 0.007378127708631966, 0.06010012647935322, 0.01962762964623315, 0.018647436618006656, 0.05428021288077746, 0.022132400955472673, 0.048319309883351834, 0.032056993405733786, 0.06723020638206176, 0.06848662253469229, 0.03556476500151413, 0.038575540230210335, 0.01904107683471271, 0.05174053433750357, 0.022007179014118652, 0.06206059056733336, 0.031535389966198375, 0.020500088276873742, 0.05152939120307565, 0.030073852677430426, 0.057185737150056024, 0.013040433737582393, 0.04362648705552731, 0.02068776427768171, 0.055167936853000095, 0.037420870403626134, 0.010636983821833772, 0.05060257004307849, 0.03610971343836614, 0.06260591559112072, 0.041342487292630334, 0.0638656158532415, 0.05746125629437821, 0.023231256187760403, 0.008231589903256722, 0.019399560455765043, 0.08076481547738824, 0.023127330067966665, 0.013966820635167616, 0.04690854737002935, 0.05177214049867221, 0.026112811207505207, 0.03286209895408579, 0.03909207840583154, 0.02920858821432505, 0.008770281399068023, 0.0824561318648713, 0.04226949504975762, 0.05178652883374265, 0.013853239810227283, 0.0355731109822435, 0.029102950489946773, 0.022631570330954025, 0.02855724548654897, 0.04791878083986895, 0.050294236945254464, 0.011302115229357566, 0.019588885296668326, 0.031796415602522235, 0.042080129496753216, 0.03613414748438767, 0.01398587813933513, 0.06316983925976924, 0.005248755474375295, 0.014814232841932347, 0.024517110582174997, 0.013958584916378771, 0.021862467850691507, 0.015293331151562077, 0.017550257367214987, 0.007253949863037893, 0.029524687145437514, 0.06470522829996687, 0.06723965158952133, 0.027185693815616623, 0.018652357693229402, 0.03488929017579981, 0.020581293651568036, 0.030295784518654858, 0.013535245221906474, 0.031228244304656982, 0.03149928851053119, 0.06365517500255789, 0.03509519841255886, 0.025444796874320934, 0.04371270171499678, 0.020604268847299472, 0.01783657878903406, 0.030768845562956164, 0.022462645645386407, 0.04662969661876559, 0.06501086082841669, 0.06793692774538483, 0.012336160189339092, 0.0766382911907775, 0.03570900458310332, 0.021809961114610945, 0.022084391210228205, 0.05600729824176856, 0.0035929879606036203, 0.027136342267372777, 0.05186546959781221, 0.07346683886966535, 0.030127053215567554, 0.022428282935704504, 0.029717906777347838, 0.010644632607831486, 0.03187510870130999, 0.02464982694280999, 0.0689147917021598, 0.01221004088542291, 0.039755600837192366, 0.004876942881050387, 0.08414050683911357, 0.0120755518520517, 0.03435949681858931, 0.022948792237522345, 0.030455345420965126, 0.015490681365398424, 0.09262171281235558, 0.021760772414771572, 0.09174004476517439, 0.05013401447130101, 0.021130652566041266, 0.05644968271787677, 0.03253744708906327, 0.04086652211844921, 0.03417424997314811, 0.01277282546340887, 0.07877093353973967, 0.04991148891193526, 0.03559604885854891, 0.03372416412457824, 0.03326862963980862, 0.09990586766174861, 0.045644616442067285, 0.03247672838291951, 0.011412636709532567, 0.017850524380004833, 0.04465069495407598, 0.05670086281108005, 0.08190556176538978, 0.048032676335424185, 0.03051937877067498, 0.02886548698214548, 0.039806670775370936, 0.015387415120910321, 0.019716225963618075, 0.058675406500697136, 0.030277647277606384, 0.04260478634387255, 0.00410851851172213, 0.024733183273513402, 0.05199324791984899, 0.02484647317656449, 0.002836978025568117, 0.04414792086130806, 0.03172316435458405, 0.0371218264502074, 0.0854613363210644, 0.024969779952828373, 0.011854593708579029, 0.06145616514342172, 0.07834674737283162, 0.048981020626212866, 0.028409445292449424, 0.032507710291871, 0.051041398995688984, 0.0645484324278576, 0.036835827332522185, 0.08238814265600272, 0.04371467964457614, 0.03291884483769536, 0.04605127265676856, 0.014111444437211114, 0.06042105318712337, 0.0534692108631134, 0.07226345022874218, 0.03538230014964938, 0.028210420793454562, 0.06832764177982296, 0.0849036823159882, 0.01729810018358486, 0.03726846804576261, 0.05132226838863321, 0.027205824253282378, 0.05237118513988597, 0.024152160522394946, 0.03603291345228042, 0.02712354340058352, 0.05030380089634231, 0.035060253859098466, 0.03970895494733538, 0.02435879479162395, 0.03880995372310281, 0.03393107320048979, 0.038760875285203965, 0.020409318951091597, 0.06843795800315482, 0.019184066215530038, 0.03652861721015402, 0.03571563047756042, 0.011258129196773683, 0.07101472187787294, 0.015048625978774257, 0.10046076002929892, 0.02503312798216939, 0.06345311405935458, 0.03925931014652763, 0.01019526006919997, 0.021947842823075395, 0.0031528328961160567, 0.02799844984630389, 0.05260144599846431, 0.02229326973403139, 0.10340461813445602, 0.03767269171242203, 0.06347732418881995, 0.029968516901135445, 0.018288225268146822, 0.01622248816836093, 0.03477781365758606, 0.1402052023581096, 0.05675754423386284, 0.065604504330882, 0.030343095372830118, 0.011458034943124014, 0.042415536141821315, 0.011204137317171054, 0.020159020953412567, 0.03676420456862875, 0.013185566440889878, 0.010510972235351801, 0.03536329099110194, 0.053328177359487326, 0.0684644276542323, 0.03964935921664749, 0.019178315631246994, 0.024394287262111902, 0.026597470111612762, 0.09286095747458083, 0.021912672656721303, 0.019080565876460502, 0.03425607790372201, 0.016687547588454824, 0.03404062267925058, 0.019919627013483217, 0.02742358310414212, 0.033865265481706174, 0.02306930175317185, 0.012686291044311864, 0.0191336052625307, 0.03249388174819095, 0.018754234637266824, 0.057441171657826216, 0.017373185172410946, 0.03561719540240509, 0.07397602511835949, 0.06616126945508377, 0.04416169172951153, 0.027354839025065303, 0.05384745003123369, 0.05317221608545099, 0.042214014633957825, 0.06990311188357216, 0.04924052973677005, 0.029005872484828745, 0.03178146747606141, 0.03988456998818687, 0.017808943754062057, 0.009653875637533409, 0.012334161903709173, 0.038180120555417876, 0.06860244167702538, 0.06700421350875072, 0.03515705027218376, 0.010201136182461466, 0.025429351720958948, 0.03377144783735275, 0.02564719199602093, 0.0433758294342884, 0.011194905848242342, 0.006606113889055061, 0.0415956792421639, 0.04133107772629176, 0.007802528462239674, 0.0339492409756141, 0.047281826447163305, 0.061497833978916915, 0.030734029931149313, 0.011952498678251036, 0.01958529245374458, 0.007649876742756793, 0.058061664790979454, 0.05097047173018966, 0.061070743682129044, 0.05149563069322279, 0.14893193622784956, 0.024178355366789868, 0.0373062251268753, 0.05624849369217243, 0.021595810373712863, 0.05086072547627347, 0.04356854355760983, 0.05686183167355401, 0.030875979457050562, 0.03756543228934918, 0.04733933907534395, 0.019316864000367265, 0.06500502542725631, 0.021463850579623665, 0.039003346381442885, 0.03158626652189663, 0.02111523625041757, 0.029757804636444365, 0.04466604341619781, 0.04169435519725084, 0.07906805723905563, 0.034886759240180254, 0.06158284084605319, 0.016379100836015174, 0.03282843004646046, 0.07175571604498795, 0.14174691534468106, 0.09646256028541497, 0.1026682990736195, 0.14813249983957835, 0.16019145133239882, 0.13168341320540222, 0.2392081298998424, 0.20576042469058717, 0.13205017495368207, 0.09865255919950348, 0.10637632331677846, 0.10806757863610983, 0.21838295379919664, 0.09071070714188473, 0.10467102232256106, 0.20640017464756966, 0.16881096309849195, 0.09907986662749733, 0.10396179037966899, 0.08892168171171631, 0.1318825360919748, 0.14220959480319703, 0.13886415931795323, 0.13325647450983524, 0.12827325905007975, 0.13790106028318405, 0.12377917234386716, 0.16972561473292963, 0.2314230262168816, 0.11234213890773909, 0.15157678430633886, 0.10242885085088865, 0.10999877072338547, 0.1294987475765603, 0.12284947080271584, 0.11621463325406824, 0.21406405126409872, 0.15606515774769442, 0.13658801359789713, 0.15473818752382482, 0.09350857843777963, 0.12553190972123826, 0.15785313823393413, 0.13323421856122358, 0.17905695044568606, 0.09047852602920362, 0.10863527495946203, 0.1155237624687808, 0.14084918637360844, 0.11585264839231968, 0.14920005255511828, 0.16082706222576754, 0.1344890333712101, 0.1212558905993189, 0.11680968132402215, 0.09410228300839663, 0.12696029378899507, 0.13242046508405889, 0.1360923709081752, 0.13486669239188942, 0.13001148934875215, 0.10439477714576892, 0.12148451618850231, 0.08156264373766524, 0.06500373621072088, 0.18034829758107662, 0.14797817383493694, 0.09394612495920487, 0.11577414189066206, 0.20340569104467118, 0.21894543218825543, 0.19107293710112572, 0.17023898075733865, 0.10852082645786659, 0.09874652951423611, 0.2138840766357524, 0.1477554922125169, 0.1838780910308872, 0.04772483517548867, 0.16392173830951962, 0.18322109271373066, 0.07807572013033287, 0.1773084606975317, 0.17797258363238402, 0.1382593810558319, 0.0766472274969731, 0.11589660389082772, 0.1605982059346778, 0.17415148152836732, 0.09962891680853707, 0.09768042886363608, 0.10468055573957306, 0.12739326698439463, 0.1875204670109919, 0.10507815690445048, 0.07551092561334372, 0.10553410529558148, 0.09703995287418365, 0.10203633869865111, 0.09507147528763328, 0.17756998166441917, 0.11841391452721187, 0.17245119490793773, 0.06598458572157792, 0.08095930396978344, 0.04887334390410355, 0.08835213977311339, 0.17019506597093173, 0.17265856878033706, 0.0652635269133108, 0.1323542943490403, 0.1316345722547599, 0.09638162462839059, 0.13899971704397882, 0.1446917573256152, 0.2216418624988624, 0.11491392233542033, 0.13302110428256647, 0.14983916468918324, 0.10707975378526108, 0.15230538163866314, 0.11976456562323229, 0.12952050140925817, 0.12217732758394309, 0.13216722224439892, 0.15354609649096215, 0.07911175489425659, 0.13389204469110283, 0.12698031057204517, 0.19934007206133433, 0.14560312485056265, 0.23897080549171992, 0.09572322852909565, 0.1391543551747288, 0.10607157288385288, 0.17059766793889658, 0.09139286553753273, 0.09057694074830838, 0.12638315904353345, 0.14963039303464548, 0.15984765120915004, 0.14205149614385196, 0.15248276426323823, 0.08526625071785279, 0.17019571736454964, 0.1027648885335241, 0.10733651822166783, 0.15467231534421444, 0.1486493263925825, 0.15419511523629936, 0.24409580762897218, 0.0957644156047276, 0.08979885107172386, 0.11116870080253907, 0.10531991893159491, 0.16506202997905867, 0.11262494551816157, 0.12903703163777078, 0.12218537500926427, 0.13008031994104385, 0.2650419665234429, 0.06892121742878642, 0.18287664119686398, 0.20125558998967918, 0.12701587937772274, 0.0779273109510541, 0.07613396325281688, 0.12486184281962258, 0.2520953012364251, 0.1328519455024174, 0.1509629815284695, 0.07417911064944097, 0.20473001498196805, 0.1283879043268306, 0.19858730531164578], [0.05146498805178063, 0.05584173230454326, 0.044786554628184864, 0.041708126065454314, 0.06503007015479462, 0.03416089301130601, 0.011613748551878546, 0.021689066530338356, 0.029007609534476484, 0.03909781202673912, 0.10114918130316905, 0.009047173728634204, 0.04806412982621363, 0.05494866826172386, 0.0391555044666997, 0.07729404778884989, 0.01445457196262266, 0.028213487771738852, 0.04518929908850363, 0.05544143396296671, 0.056711593842399974, 0.03649248522041099, 0.027521653466724923, 0.025893596899030463, 0.05951504608882325, 0.01427200363416757, 0.07692902987556798, 0.02959763305261731, 0.0181208832655102, 0.04183308168181351, 0.01070983727861728, 0.0315953215717205, 0.05894632517759289, 0.021440446210492934, 0.034733617279146395, 0.028637841876064028, 0.04434551025873848, 0.029914929598037685, 0.1365292796066829, 0.05779030506632157, 0.03752987366169691, 0.015216833113559654, 0.01843670060458992, 0.05743389097707612, 0.06958074668156249, 0.052423032000660896, 0.04844585666432977, 0.04332453557955367, 0.0949119245633483, 0.036106005244489224, 0.0559402080917997, 0.040173337528748174, 0.02686765936336347, 0.036553363382284126, 0.03551048220002225, 0.1000608518453581, 0.021613092660637837, 0.022063902845340114, 0.047938767088843245, 0.02370486345275172, 0.01769718394747802, 0.05240238078736833, 0.041214824321546724, 0.029471310188195536, 0.008362527653974081, 0.041218379845044444, 0.01940014399588108, 0.03087773686274886, 0.013944399293645151, 0.05553589282291276, 0.01664991264364549, 0.023606784608481184, 0.04803761946303504, 0.02288843654761357, 0.025661529440964972, 0.03345091807256852, 0.031719289919627566, 0.020424770889803767, 0.01661952954184796, 0.037347181500600915, 0.026457164336794188, 0.055606704737458906, 0.009989615612929421, 0.02866848451750619, 0.012655499125165599, 0.030374012820954834, 0.0672910777585847, 0.05891195059354816, 0.01933617001798536, 0.0635246452210205, 0.09201410505920649, 0.01506082434207201, 0.022187092574313283, 0.053934000565537384, 0.0309269170809005, 0.040196258441678116, 0.0416511019824871, 0.02346207174871649, 0.0034087852109223604, 0.026220443824838315, 0.018819667465452636, 0.06015984434634447, 0.02479676030842321, 0.02933293314916747, 0.01662220636249653, 0.021564621511580687, 0.0032814386067911983, 0.03453521024701851, 0.03184135836948242, 0.034412242738263946, 0.04536247818863817, 0.07846401858010463, 0.01627567513579769, 0.046335056357617886, 0.03497424615280969, 0.010248946608044207, 0.046215871681592295, 0.02532888443342277, 0.031179793511650393, 0.03493325585233314, 0.043859930243343115, 0.03941338509321213, 0.01073971826450101, 0.041184130789978166, 0.01717448976290013, 0.005236633870351527, 0.043717804298337014, 0.00815116145115878, 0.03217606273080621, 0.031497598958334753, 0.041276767783399136, 0.022681317125846232, 0.02240286162123084, 0.04064593038388661, 0.014917227672412992, 0.021872250629322867, 0.0076758502151018804, 0.06215125641652516, 0.07187501607196671, 0.04955054560144033, 0.02570704387367836, 0.006285316527022847, 0.03752770913498742, 0.09074834547936916, 0.015889062845547284, 0.02879280231094786, 0.061401325943214555, 0.04979603957118733, 0.01077551522757858, 0.03562253547300186, 0.03401718607970646, 0.007869593167145337, 0.024222997882004296, 0.06744573624538523, 0.028548611128436666, 0.06814479694834777, 0.02921488501929811, 0.06741674922938858, 0.04977200246815171, 0.026515998411923647, 0.07713924002434526, 0.06573244889399835, 0.045051420772714276, 0.038218488318047354, 0.06997530800955636, 0.02306069284012275, 0.06586554353790623, 0.09214344740446125, 0.03281744795718363, 0.029516588829989945, 0.016018439117552977, 0.03167224708678467, 0.03874145222029515, 0.028198858556736792, 0.05124383991850274, 0.033000136725604534, 0.027482386645195738, 0.04297105615426387, 0.052023093282644234, 0.048327920492738485, 0.05553160108891981, 0.01508739746973983, 0.027846510588590587, 0.02469469337458057, 0.038472046676490984, 0.028221979637497237, 0.038609816426677365, 0.007922389976946371, 0.04283519648015499, 0.020229335841057555, 0.04118731311921563, 0.05489919288083911, 0.028260479714455347, 0.04307472951976316, 0.025676416499274116, 0.03421140994344439, 0.035177457212869606, 0.010553691951957132, 0.05320660424019609, 0.012908498540387621, 0.05346190982631274, 0.02863994872729693, 0.03030333322073732, 0.027501808013767004, 0.045314108819833825, 0.07303055442337479, 0.033933882335467, 0.02328138974761324, 0.0204719205919121, 0.009308109459068094, 0.027404930176479474, 0.016347910277545452, 0.04372457947049822, 0.01785849716647395, 0.04702992710684027, 0.06844420731067657, 0.03663220915145107, 0.04264929484842079, 0.016732364826436554, 0.026153994890462075, 0.014109439366231007, 0.030858707348150865, 0.030504084591354643, 0.023623462999239564, 0.09070677842412676, 0.02093130237023745, 0.049406132993421385, 0.07723073368625981, 0.05774790341300624, 0.05697094010455268, 0.0427332296302276, 0.07451340449707848, 0.0586496696674398, 0.016861703779016222, 0.04685351139466677, 0.04487176505582673, 0.05826096409665687, 0.07013652792998723, 0.022151613674525703, 0.019322797789105346, 0.08100346981414727, 0.014450190322739738, 0.0029333861893974245, 0.02730815072676965, 0.0014807917801330664, 0.007065917207260749, 0.020678017122138823, 0.029582128527441194, 0.013204783400786775, 0.024349449668079615, 0.024992807735023752, 0.03689123310946992, 0.012279145436228385, 0.03377737144806555, 0.02777489969905998, 0.034796571758176596, 0.030450727990163223, 0.0808733200122203, 0.06656345073133707, 0.016554831227819835, 0.020940679724195173, 0.02327599369787744, 0.024083441888381327, 0.0679613414353558, 0.060583691245743206, 0.03156689773978932, 0.014833664388528891, 0.06447621594582285, 0.03228564952899303, 0.06733949801751546, 0.024407615386215702, 0.017191473494416902, 0.0924396686522024, 0.05971674740846668, 0.04032175349337714, 0.08006007543631963, 0.013821356297869767, 0.026735682605898807, 0.024762433221829788, 0.01266795872444553, 0.056335736332195144, 0.018652152436386262, 0.024728262198290656, 0.013980545702257326, 0.032187031249382665, 0.05276667945353048, 0.030826286944959844, 0.04023289594001003, 0.00857011356856674, 0.05314287623124463, 0.008727048540354838, 0.019516332939799343, 0.01513409594606076, 0.014808361817683493, 0.033136518871677775, 0.018829594432775463, 0.03504650673962065, 0.052090878931007216, 0.048731499551130195, 0.04006987790177975, 0.023699686230559434, 0.008267320709169974, 0.10170301515609026, 0.054704490649913035, 0.07736942624407155, 0.02496772399172187, 0.01611152564042381, 0.020310514074351107, 0.03903723242027419, 0.007315962874729718, 0.04141216605369534, 0.05697351175227335, 0.02734394684167845, 0.04722452077216335, 0.10198725347540208, 0.011906246338704867, 0.053665979233171256, 0.052861043318573914, 0.05215387412213853, 0.02785453087251101, 0.016030729083078246, 0.0395971934444138, 0.008363304576570434, 0.07264627968626362, 0.004161529060054038, 0.04706569268767323, 0.052494956712637625, 0.02561205406008022, 0.010184178744176669, 0.026728378176423054, 0.02154712887879993, 0.02935078540550811, 0.02516526249902589, 0.07192169928124972, 0.012691268946842423, 0.06860295057828937, 0.015363506939528244, 0.055725814774632454, 0.0718529297571097, 0.022451100372044102, 0.013870740076527, 0.055438787676393986, 0.03486261357154165, 0.06253378731863839, 0.008182166260667145, 0.03846386693684118, 0.009309396131097205, 0.022833409053938727, 0.0034772839571814984, 0.05832840369216033, 0.021593927439036112, 0.07067926095000335, 0.13102181442081928, 0.1885798637356077, 0.2238560172596148, 0.13129905025873864, 0.14926456766469137, 0.16481414756604604, 0.06635811246399369, 0.13146516920200416, 0.10771502541112048, 0.09388904659343617, 0.19739457645586558, 0.19008204527199268, 0.11424808949232101, 0.16208285412618093, 0.11271332470434052, 0.17064412044627325, 0.07352824628885303, 0.1391827179385083, 0.10955019122255699, 0.06563685688057116, 0.157333801101361, 0.08715687998171363, 0.10473293185766254, 0.059413455825831206, 0.16160429694822856, 0.11314029965017523, 0.12394550841833864, 0.11948606771017824, 0.08974877518734761, 0.2028677484818867, 0.08144590178770678, 0.06325842200645379, 0.20772814910326684, 0.13425902357058866, 0.090705950611404, 0.11237066451992307, 0.15479135752788611, 0.11963561682828835, 0.2735952804131167, 0.1500815102564437, 0.11459544513906751, 0.10919433353202683, 0.10727356374263763, 0.13856609245496138, 0.12254779413342476, 0.1019547109359077, 0.08797451467918498, 0.17473373242786952, 0.24312930234840938, 0.09395853536469595, 0.12392399885824748, 0.12227139967892851, 0.12739792173462255, 0.14536200064633573, 0.10998486075550318, 0.16326631419360638, 0.15403002766626223, 0.06613200423972947, 0.11532501956181866, 0.14740299327032907, 0.10343668569943734, 0.26554476097226143, 0.1335862832409995, 0.14248836413025856, 0.09048838514302458, 0.10810102362717901, 0.17711739880698069, 0.09115935449621507, 0.11093957309744187, 0.08723417869103806, 0.15360388053315027, 0.10737947627369847, 0.29693664078201565, 0.11797920428216457, 0.09518660910959754, 0.09667132515460253, 0.0748676269182137, 0.17199976556003094, 0.1184905075601169, 0.18061340121286257, 0.10222763129110847, 0.1998205834201404, 0.10312234756669827, 0.13290164140718325, 0.07274679107857601, 0.08073979789125067, 0.14050624120448316, 0.0946798859430211, 0.12611200287938118, 0.11808468933616366, 0.173781829220908, 0.2410354247050626, 0.13174461706408433, 0.2500934600830078, 0.09983752561467034, 0.14866333135536738, 0.1340451357620103, 0.1514351876186473, 0.08405864837446383, 0.17741140803056105, 0.06082971447280475, 0.09792047419718333, 0.09168792649039201, 0.15808521078101226, 0.10918976699135133, 0.07807546228702579, 0.12947920576802321, 0.09701110156519072, 0.1221168294016804, 0.11711393642638411, 0.13746614647763117, 0.1421901344188622, 0.0869878569085683, 0.11391724938792841, 0.1511249342667205, 0.18789930668260368, 0.1206861383148602, 0.050603136619819064, 0.09685917757451534, 0.1079286825177925, 0.1301991314228092, 0.1125104630898152, 0.08680518849619798, 0.1188824972403901, 0.1344408845262868, 0.08369521144777536, 0.15330368307019981, 0.08106779493391514, 0.18692339690668242, 0.1884530319699219, 0.20200329486812862, 0.19828626646527223, 0.12294088304042816, 0.1345064988625901, 0.0873835174632924, 0.1472601887903043, 0.22483690748257296, 0.1236364764294454, 0.12601200038833277, 0.13306055430855068, 0.17281088632132324, 0.21941708187971795, 0.10826391952910594, 0.13638614942984922, 0.06678215613854782, 0.13141562257494244, 0.14798471491251672, 0.18180797568389348, 0.10351002854960305, 0.09679282363504171, 0.10532842776072876, 0.08205779109682355, 0.11708051179136549, 0.11815578623541764, 0.06681486152644668, 0.16052622693989957, 0.1374912794147219, 0.12044799966471535, 0.20321514484073433, 0.06732822076550551, 0.22320507147482463, 0.13390630749719484, 0.14461521857551166, 0.08051772695034742, 0.08783590354557548, 0.1621669110442911, 0.1713189778051206, 0.09591379508908306, 0.15731227797056946, 0.135967561176845, 0.11328213382512331, 0.13137902239603655, 0.08746030727135283, 0.16978308664900915, 0.13351942040026188, 0.1570138039865664], [0.06813148409128189, 0.029217514342495372, 0.010335248628897327, 0.060445643296199184, 0.037157975403325896, 0.049432243020938973, 0.058490424283913205, 0.05747610264058624, 0.03106835770553776, 0.038263278414628336, 0.027311984449625015, 0.04902357155723231, 0.029447038990578482, 0.03780936562855329, 0.07085178526384489, 0.04163362631308181, 0.011204491851718297, 0.0057465075598364425, 0.007935154916984695, 0.014477330027148128, 0.026782903554184095, 0.026327260503811494, 0.023750718849311982, 0.010860105643847158, 0.0332479071803391, 0.015819738619029522, 0.044668380969337056, 0.018727174660723125, 0.031200651678123643, 0.04362935047330601, 0.004985666243425969, 0.016185177224023, 0.02330366605227547, 0.03195673646405339, 0.042641372952078066, 0.015180797815056784, 0.07858869938978127, 0.04659913879420076, 0.027153750083276203, 0.02052487007209233, 0.016860989620909095, 0.04662432601409299, 0.03493383599977408, 0.043222806216882806, 0.03127270191907883, 0.014377641358545848, 0.10537215934268065, 0.05596098144139562, 0.04507187521085143, 0.02724174759350717, 0.025244238886183927, 0.07668730856052466, 0.012627227963613612, 0.026311340375936458, 0.04134836679856692, 0.053336014438952715, 0.03558675292879343, 0.03535631565111024, 0.027908423516367162, 0.02625256567262113, 0.03175719967111945, 0.044763338552521806, 0.054031536581793, 0.03242433190877948, 0.020419412159493992, 0.03626308949398143, 0.03298269498295017, 0.0528160700175379, 0.005058249134370791, 0.07093867845833302, 0.035427039356103966, 0.021359919370817285, 0.05846078587429864, 0.036218194224472554, 0.019246369300942336, 0.03052956358130489, 0.02541984205267259, 0.006709936956342841, 0.02397537840131138, 0.043065474302108796, 0.018709468289411495, 0.017131669114210775, 0.024688091228849122, 0.05611092071714146, 0.023798441913511072, 0.04585714718060834, 0.017254365208957876, 0.00906550944117563, 0.03508884732478431, 0.031866515055298805, 0.031512285848813396, 0.05949817770825965, 0.02566087804734707, 0.016361024663118378, 0.05736101631607328, 0.03378635525171246, 0.06647389767957584, 0.018573803694120476, 0.011517120924379145, 0.06712970856044974, 0.023660565294059258, 0.0900497529655695, 0.034500822092273405, 0.006970876503536212, 0.059518778031425815, 0.07942927535623312, 0.016053169932482497, 0.029562166027192558, 0.044962128956935236, 0.03942860463368041, 0.00739424121898732, 0.06403205370796577, 0.02159899439928787, 0.03529155287625534, 0.023442353521074568, 0.023933689209765623, 0.046737234241196086, 0.03327116736077836, 0.002869269507105595, 0.053171276314450164, 0.03166637436619826, 0.052149524712668996, 0.014169603369997015, 0.04214750463142991, 0.05825966130942106, 0.05592815391719341, 0.06591193497713123, 0.012219580239616334, 0.02031901102912213, 0.021415225063849772, 0.03098636692655938, 0.03252717746155603, 0.0566555027450834, 0.04472322016954422, 0.06447711161204747, 0.029898352987532104, 0.06338715367019176, 0.02814688955965851, 0.029531041625887156, 0.03694194003141352, 0.06898208201995917, 0.048694404041660685, 0.03830412283007588, 0.034910765809140036, 0.03411841671913862, 0.07410786447248288, 0.035564591975084374, 0.04651072568127087, 0.0565051461703011, 0.012575027416460216, 0.026685713590787988, 0.0489385816534715, 0.03704735044656055, 0.021036497350516062, 0.04916005548355835, 0.03658961411565542, 0.0759842445009521, 0.03380188691828932, 0.03824803851810949, 0.020846376927303414, 0.023720795454989587, 0.03584053520379322, 0.0853443161717483, 0.0547806188863303, 0.022153801949960843, 0.01986638406690742, 0.0117012634540775, 0.03414832315008555, 0.041427626474095244, 0.005451614120309907, 0.0342514163681439, 0.015263448469340801, 0.029369231379990066, 0.034484116560114284, 0.016191730175965598, 0.08613329633538212, 0.018659777473658323, 0.04716321174055338, 0.031157883615898233, 0.04178818301962955, 0.016968277881720235, 0.005527358136272856, 0.013078214567420738, 0.041750928054430654, 0.08429836122585194, 0.05245209026283451, 0.030922018058065857, 0.05104670513953481, 0.02910371044916766, 0.03946218193907823, 0.05061640876478382, 0.022897771493132626, 0.04054348516677107, 0.032533514978630204, 0.007607492900985692, 0.03404374733301146, 0.031163691875657866, 0.032521464196699004, 0.07808984044407095, 0.016180235792749693, 0.02965117964361395, 0.029289184603840113, 0.06043225580028125, 0.03961275225239141, 0.025662788123424565, 0.006216417233060513, 0.057215538408075056, 0.028298043413087726, 0.01806720096750983, 0.03749750414863229, 0.019519240462354252, 0.023662027537024448, 0.014651316583954861, 0.059401520394853184, 0.01617786261652197, 0.046068880640502484, 0.034675012209585736, 0.0403014415475939, 0.018402629664966037, 0.05891699889408691, 0.021651540151132003, 0.035276815095650296, 0.027487518066274266, 0.013203690111237978, 0.09512699980820928, 0.017534344024690132, 0.05710904912224837, 0.055344627371856144, 0.004175430970332984, 0.024141499040914432, 0.0360601328845535, 0.027458045897739272, 0.035738086594002585, 0.07009354952190604, 0.015033745705815298, 0.07203433609434537, 0.04563914744981697, 0.024110724085143635, 0.060428252443671227, 0.08083041624299117, 0.025952709173517566, 0.07326342764177493, 0.04697318461590579, 0.017358954596732343, 0.0074820589174383455, 0.08388326742819377, 0.014545468513720801, 0.020756895121719156, 0.06457627271967274, 0.02006646877686892, 0.020581726217642426, 0.01562976577718343, 0.020131786254101565, 0.027574075385928154, 0.04274323462907757, 0.030688357739044086, 0.03318661850477968, 0.034008921523179324, 0.042905228079429696, 0.06146258408469813, 0.026590476111908044, 0.04728385865954416, 0.11715566633003098, 0.03368794731795788, 0.03200731107166835, 0.028383474364610653, 0.02778070795881961, 0.019718319244150604, 0.11321989180786268, 0.008314138777287943, 0.045261128805577755, 0.022484993196225593, 0.022669763370816196, 0.017135424805538993, 0.034628220434699736, 0.035433862025716474, 0.024038027539583187, 0.017394319841904298, 0.062047501626823626, 0.06321099240865026, 0.014116670853192253, 0.06707346479275397, 0.02596431551501155, 0.08847855763243777, 0.09216725041291543, 0.021471680873738866, 0.007183830054210765, 0.04930444095017655, 0.023852924882833446, 0.08254810728664909, 0.01925485777402563, 0.06971861821200166, 0.04927972870479737, 0.02738856560816722, 0.0464166807276862, 0.060420089667396884, 0.07334548288158008, 0.07158383633941412, 0.029281791964811937, 0.03630521634061422, 0.04412810763876353, 0.052946650689201694, 0.07781651296785899, 0.053082395012357404, 0.03489228251523205, 0.04594133302037205, 0.04120559285261801, 0.012565512659161218, 0.07447571866214275, 0.01771407777310482, 0.020652039408949868, 0.030439566089106456, 0.012280058065828468, 0.06385730379926306, 0.006952955121440547, 0.02857025300285646, 0.04450602450274995, 0.0371023999926235, 0.044905776623636484, 0.01928164464022432, 0.06289455081735339, 0.05164989223703742, 0.03095183288678527, 0.030643119809350798, 0.023479996947571635, 0.014528377912938595, 0.05966425593942404, 0.040562229696661234, 0.04970254423096776, 0.033119830302894115, 0.05540819253240313, 0.01881067857279309, 0.1570852944361312, 0.00852125056553632, 0.0924980565905571, 0.09315659518220595, 0.06518974980073315, 0.04211204099868025, 0.03280296462721058, 0.009797878580034843, 0.017139536727752005, 0.02340925288652735, 0.016815629554912448, 0.024004675847079073, 0.012854632189763444, 0.021911722707695196, 0.06453930613185678, 0.026724627574107478, 0.010176820031899427, 0.022189860997189368, 0.027537861971982887, 0.035583563814205785, 0.11752434154706341, 0.14013781026005745, 0.1219397589032139, 0.12808415134038242, 0.07132140613560166, 0.14022306139980042, 0.1422379304255758, 0.1185294690408877, 0.20170346381408827, 0.13356020035488264, 0.11628558087561812, 0.16431878986103193, 0.13485906565827982, 0.14000222539263113, 0.12569767582629407, 0.1347269006073475, 0.13660489554916108, 0.07465910632163286, 0.16044997317450388, 0.06505350675433874, 0.09916272253862449, 0.14264577068388462, 0.11987961802099432, 0.09093746675976686, 0.11894952292953219, 0.11161427439323493, 0.1194457763007709, 0.10275422874838114, 0.1098013034622584, 0.09995776201997485, 0.24656743928790092, 0.1502797646181924, 0.11898559385112353, 0.11370732422385897, 0.10364494166736092, 0.1390473773436887, 0.10376382778797831, 0.14129969291388988, 0.14422378529395374, 0.1360554178910596, 0.09875079749950341, 0.12861233656959875, 0.18081473612359591, 0.1826174408197403, 0.060958066156932285, 0.12370880826243333, 0.17171626005853924, 0.13502646024738038, 0.1558962296694517, 0.2059819120913744, 0.22253835653620108, 0.22726482791560038, 0.08886450156569481, 0.2684152355151517, 0.10954924127353088, 0.12068069646401064, 0.1429577475147588, 0.10922849777021579, 0.11893824567752224, 0.10860317346772977, 0.10568237198250634, 0.12326645771307604, 0.10353463222937924, 0.16179843938776425, 0.09524086476968867, 0.21243012536849293, 0.14958330270435127, 0.10893719590135983, 0.05650348036683031, 0.1807034428098372, 0.09500196616032294, 0.09510873364550726, 0.10211998849575009, 0.12798671371170453, 0.0814273642109973, 0.13001405421112264, 0.1095773461940033, 0.0936734081645097, 0.14581029516245636, 0.12392517950917993, 0.1624709354447467, 0.08435193835092442, 0.10595510913325207, 0.2690628564783505, 0.10689899205629315, 0.1336317722286497, 0.19882112847907202, 0.10397464861827237, 0.0829247756462012, 0.11890000344387122, 0.12021451576479844, 0.12073161373181002, 0.2865796179643699, 0.10270618846906082, 0.1406079400330782, 0.10288220045289823, 0.1679367928632668, 0.12216778738158089, 0.15422137454152107, 0.1169204046683652, 0.1115975688610758, 0.14670602924057416, 0.12150211738688604, 0.13820342905819416, 0.10257236779268299, 0.18213185401899473, 0.09938312428338186, 0.18949091913444654, 0.11658219567367009, 0.15187115993882927, 0.06390448912445988, 0.13988785152988775, 0.07786880766174623, 0.25274552777409554, 0.1179764765713896, 0.11183559216026749, 0.07213573636753218, 0.11378812417387962, 0.14039702420788153, 0.19401146870638641, 0.15220666836415017, 0.09974981139280967, 0.1392477351639952, 0.09459635149687529, 0.14973051766199724, 0.10562010960919516, 0.1277691346726247, 0.1892677896789142, 0.09482301611985479, 0.12829309941402503, 0.1546707818550723, 0.09731347712555102, 0.19479311390646867, 0.1257473581603595, 0.11251718737185001, 0.12736472780151026, 0.14956374732511385, 0.12716519779392652, 0.08617137572062866, 0.3320277306650366, 0.18284234803702148, 0.13934947470469133, 0.1904999685606786, 0.0857700901106, 0.16579620486923627, 0.16601439458983286, 0.12133183223860604, 0.10134616001908268, 0.15914601885846683, 0.07467700607542481, 0.1235396359115839, 0.1314561175448554, 0.08887732587754726, 0.08036764857492276, 0.12347879846181188, 0.10936520900577307, 0.24155241410647119, 0.05631037947854825, 0.3217311246054513, 0.1583558783999511, 0.0998411625623703, 0.0962780462577939, 0.1357646927769695, 0.1251200389649187, 0.0944119460348572, 0.14975404925644398, 0.10646829195320606, 0.09319016230957848, 0.12851890229753085, 0.11314044892787933, 0.10010834929666348, 0.1472487486898899, 0.28261488356760567, 0.07975527072059256, 0.11726056784391403, 0.21038199455610343], [0.029015846949602877, 0.0436693670760308, 0.03252743869753821, 0.0221403449042035, 0.01222294577330883, 0.015586151242522257, 0.007710862622064139, 0.030975205025502613, 0.04821654236210244, 0.05430708286751594, 0.019464801597808088, 0.02855094868157591, 0.00422108916765345, 0.0766265457496047, 0.061310626167271814, 0.04193537422854986, 0.059083491031612666, 0.019274482703102485, 0.04790717789105006, 0.05611928705392139, 0.023989939762811576, 0.03468912573797362, 0.0402247331637357, 0.020650850276329687, 0.023633978595691066, 0.03979123749637178, 0.040963488165289164, 0.03006074677354523, 0.0958648252167872, 0.0357457099349371, 0.03156553388440183, 0.004573226789943874, 0.022465683785932403, 0.016033326175862124, 0.02847635732697589, 0.051017996322895796, 0.052441064068781476, 0.027974580680685382, 0.026850875799677203, 0.01707164929913623, 0.09691236114927701, 0.028015988280198405, 0.040301519579121044, 0.013814106151195509, 0.002083018750584285, 0.010372237269101399, 0.0557439146962549, 0.036051776725798845, 0.03918801986479333, 0.03854764226291861, 0.12685498515410082, 0.03218056481065495, 0.009969962694283043, 0.017043440902073468, 0.013901335220517856, 0.01375142393434154, 0.017307348615889038, 0.03947618690186313, 0.016978822315910032, 0.030452614317515066, 0.046400009122278006, 0.04323218696351562, 0.048283428951565704, 0.03205793656940971, 0.03369769447350076, 0.029344546276011636, 0.025746795847745876, 0.05714524896549327, 0.04576084949076176, 0.04492239733891828, 0.06695303161229406, 0.08913114547197308, 0.02979882886367185, 0.06763197375195366, 0.045360931128795655, 0.05269500579951065, 0.03112359724140593, 0.001211869268445298, 0.031157781835645437, 0.026903497886710932, 0.032559333236089776, 0.014778294234669634, 0.04389063734561205, 0.06353393436542579, 0.007480267584989113, 0.015698392808969532, 0.0505799714342824, 0.08448677682983023, 0.022404825980109826, 0.07976779647703681, 0.027115231346605078, 0.03813776979222894, 0.011242337142383414, 0.04074014497122594, 0.004678789875470102, 0.054760598710605075, 0.030837282604937042, 0.03714034706354141, 0.06166197159992797, 0.07876261470041104, 0.028638432201530253, 0.018519244389608502, 0.03337164482633982, 0.031888533516653945, 0.017958162086350576, 0.011342654304046716, 0.012684351282327302, 0.004248734380650733, 0.007571597550330418, 0.008525007953202086, 0.07222683647913591, 0.11323616307760988, 0.0762126190321786, 0.04036047748689141, 0.054530422668904066, 0.029077898977058272, 0.0057227206665889496, 0.044117291790566275, 0.044234098201351504, 0.03308962870921407, 0.013700968070354844, 0.047658111434429884, 0.0018581535176573588, 0.059574981087020466, 0.03296498182628836, 0.04341045168361493, 0.016209475563040802, 0.035831666751099486, 0.03647844633087516, 0.03833353393045919, 0.04215783193441374, 0.07251418248883315, 0.04099311300420335, 0.024084161135501096, 0.04970599797421268, 0.12071412109902926, 0.016356809264315025, 0.053850788423525434, 0.007218759340633239, 0.04133952209459884, 0.04423620505258441, 0.023540571465023925, 0.030984948788370405, 0.0261535046489111, 0.06089377496391535, 0.05511689405622227, 0.04651024392140763, 0.007177485751786402, 0.05396121321246028, 0.039807172891284735, 0.029502020683139563, 0.028301732947251627, 0.07078117012445416, 0.036266163257615905, 0.014874174625479748, 0.05246340822694557, 0.015415214700624347, 0.116133521177939, 0.07145963050425053, 0.11713612452149391, 0.0495467424126608, 0.04343834965090666, 0.07550291890012366, 0.018822362945814217, 0.00982469173946551, 0.01767765062062868, 0.01638050370716623, 0.02237294670859618, 0.038044881740851064, 0.022782695346644947, 0.02772361262967544, 0.027142121689394116, 0.06542490289679595, 0.028755866257207732, 0.03618589935025998, 0.02262122436825718, 0.007008464374978627, 0.0188683828871165, 0.04334527160972357, 0.016842438473499248, 0.01820039060632033, 0.017252309247851372, 0.02438506088219583, 0.025002936566514627, 0.10059398359486035, 0.06677934021822043, 0.05259824331317629, 0.0373358940705657, 0.03064752689429692, 0.03785323291750891, 0.044755633787385056, 0.026156117008732896, 0.04244956128033144, 0.008138993621936865, 0.03610783389636448, 0.08613658044487238, 0.01317989982531539, 0.002907216365981315, 0.036350237139101536, 0.01171930824472968, 0.04559898835473827, 0.01589112898467907, 0.00681174180603453, 0.04528929818687694, 0.03308704349079302, 0.06155884784779378, 0.06474465118455035, 0.023485116494287337, 0.03190507959308369, 0.05824997182935476, 0.056976137682795525, 0.05784215871244669, 0.02384940498242421, 0.011437250567334039, 0.04900201449968985, 0.061356427281030586, 0.022091468330472708, 0.010306798503734171, 0.013163905058588301, 0.05267832740875227, 0.02440140679079507, 0.015467784201194133, 0.006993503101901817, 0.05327195394784212, 0.034182158298790455, 0.0027079620132488863, 0.055723643462572775, 0.017175034287252595, 0.04400322326858129, 0.0511802510092301, 0.03488093401704516, 0.05964829001043524, 0.04606815121535744, 0.00435074109451047, 0.01453792829332607, 0.02532082174106368, 0.014238836842456033, 0.060929981592510424, 0.0505686263287706, 0.10109509527683258, 0.0369952152084027, 0.02751571119629911, 0.01834619590746505, 0.04131976654753089, 0.0587583099092756, 0.05322510449747954, 0.045322773712021966, 0.07277794940663235, 0.03442755048828466, 0.04115084864731346, 0.016719655865537267, 0.07696674285190445, 0.003954709890032453, 0.042894178136651, 0.0430677847138473, 0.05110699636861682, 0.03425714998905148, 0.0444265782300915, 0.010605988342181911, 0.02108270558528602, 0.0068969361184697065, 0.014840378492538418, 0.02418058774700122, 0.029624323227575848, 0.05228471602978451, 0.01781922864860722, 0.04660007856520159, 0.1232929884323052, 0.030189278269452707, 0.002979124114582581, 0.008481550329763974, 0.08071919078273432, 0.007132837299390563, 0.0490499326427068, 0.020226674287446907, 0.06698632732565914, 0.0354633715136775, 0.016342729662678072, 0.0775541981149997, 0.04950381489470601, 0.0208928735394563, 0.051385881046631506, 0.01641145677837942, 0.04290787097332733, 0.013529719402348357, 0.013067492017788547, 0.029826095793396235, 0.03263193309041006, 0.03119443290467773, 0.0025366054157659945, 0.024278300182361687, 0.02011995260337634, 0.037213649201606, 0.09248451303158488, 0.023004245511921387, 0.027832712578986372, 0.06077349106115954, 0.027428185267906104, 0.01651026165511991, 0.007237911839703364, 0.04539615727428879, 0.06073841080069542, 0.022054082747282724, 0.03331163858196565, 0.05537354653435094, 0.023331178950944116, 0.021947642655244896, 0.05887688390378441, 0.05486060459432857, 0.015180485688948205, 0.023063747944044213, 0.031222463186298097, 0.0318799704047186, 0.04524320869573525, 0.02577516370053802, 0.03164104126127703, 0.02868413832038641, 0.03960760895695005, 0.021908670996448824, 0.052655209720666916, 0.027135818099070872, 0.013915677754474538, 0.0662970578830157, 0.02619348562854741, 0.04465396888554096, 0.018570775731599758, 0.025456236974735345, 0.02578879038005003, 0.08534864522516727, 0.08496310162757124, 0.012504176486150494, 0.06649402981357914, 0.03156892316681998, 0.06968131235667638, 0.009291934880561062, 0.03172837889620236, 0.0379225656257144, 0.015920719896842326, 0.019969826730500375, 0.009727061576476055, 0.014849916998563069, 0.06505556271544524, 0.04476548272318073, 0.0817412341545735, 0.017547534745452658, 0.043597683243985684, 0.0707216083205172, 0.01640567566002054, 0.05722454935312271, 0.0330061281898192, 0.05021638862256493, 0.025126187363639474, 0.07239568313317639, 0.13069474697113037, 0.11719515706811633, 0.03471251144739134, 0.08061928328658853, 0.07985948012875659, 0.10171864181756973, 0.11894443391689233, 0.12760802331779683, 0.16106445448739187, 0.10671147211853947, 0.11496185404913765, 0.08042446231203419, 0.22463287200246537, 0.10662920653287854, 0.16215970500239305, 0.1320558339357376, 0.08523102117968456, 0.09290618183357374, 0.13501179032027721, 0.12728836547051156, 0.12927066481539182, 0.122633018131767, 0.09463061072996684, 0.08941158399518047, 0.1328043123441083, 0.07932061475834676, 0.0663164368431483, 0.23123192361422948, 0.21838064678013325, 0.17810687928327493, 0.0809444101261241, 0.19885809506688798, 0.12817465434116976, 0.2452649777489049, 0.09557497541287116, 0.18662613071501255, 0.09961040637322835, 0.21595192567578383, 0.17309292618717464, 0.15852910839021206, 0.10047471749463252, 0.07636657862790994, 0.10871809694383826, 0.09149760420301131, 0.13201825666640485, 0.13836800094161714, 0.1610394843987056, 0.10661495051213674, 0.13185254484415054, 0.16715395344155176, 0.17821285288248742, 0.15087589834417614, 0.16944698111287185, 0.1295901598142726, 0.12759481902633393, 0.14014743188662188, 0.07658099569380283, 0.049056412652134895, 0.15834128989705018, 0.08841339112924677, 0.0930271917687995, 0.10763907698648316, 0.14862242926444325, 0.10377740527370147, 0.14499245690447943, 0.10997201608760016, 0.1854310134159667, 0.18320403434336185, 0.223352082871965, 0.1628274241728442, 0.18778801336884499, 0.1089295284556491, 0.13261502821530613, 0.1525518119867359, 0.13828170485794544, 0.06818614008703403, 0.12900984952492373, 0.0905401845063482, 0.12824212786342415, 0.10463151801377535, 0.15627101170165197, 0.18156740787838185, 0.12817252374121121, 0.0718283871454852, 0.10343132527279002, 0.1400994323194027, 0.10118707069861037, 0.16849552573902266, 0.1878682840615511, 0.08714855435703482, 0.1826680866735322, 0.15949669932680471, 0.10502611326852015, 0.07668062499059097, 0.13991925413055079, 0.12497868654983384, 0.133205489388534, 0.09193834662437439, 0.17825273717088358, 0.09902027089680944, 0.12495134158858232, 0.13240834644862584, 0.17069920391908713, 0.16029750635581358, 0.10043578994061265, 0.11360794598502771, 0.11269011880670275, 0.14048196322151593, 0.14800900646618434, 0.13044796378484794, 0.20752564711230143, 0.2018896131111043, 0.09620569406875543, 0.20369443483650684, 0.10045388646956001, 0.1251993461378983, 0.18690361082553864, 0.12619483843445778, 0.10400680439280612, 0.15382422799510614, 0.07614878924297434, 0.06327817416084663, 0.09104154724627733, 0.12121288504983697, 0.14407408689813955, 0.08622611314058304, 0.11623000885759081, 0.12709038252277033, 0.09036248297031436, 0.1218253036162683, 0.17062764561602048, 0.15071459699954304, 0.11614042866442885, 0.08381516286837203, 0.1664795032037156, 0.0997682675453169, 0.13700132284845623, 0.13890261868281023, 0.1467628361923354, 0.14132173173129559, 0.12409094561423574, 0.0968381633449878, 0.15327025843518122, 0.10512576970670905, 0.09241489533867155, 0.18999397142657212, 0.10758048548762288, 0.16374668984540872, 0.1910402045718261, 0.09322277270257473, 0.05771375274551766, 0.13522820227912494, 0.15563932274069103, 0.1071153904444405, 0.1268677009003503, 0.11274302418210677, 0.19980575064463274, 0.13529024752123014, 0.12387719351266112, 0.07294757637594428, 0.11690026574901172, 0.14886063576808997, 0.08981544803828001, 0.0528102481870779, 0.12485371397009917, 0.09694359411618539, 0.18028277823967592, 0.14749627826469286, 0.1631238218396902, 0.23540010995098523, 0.1003070447061743, 0.11594297497400216, 0.095549645700625, 0.10938310197421483, 0.08570216875523329], [0.018897524269829904, 0.028822756239346096, 0.073069203778037, 0.01714229497260281, 0.014847913623920508, 0.04993420626435961, 0.026342588609882762, 0.019674287410452962, 0.02296054785672043, 0.025375937444290945, 0.03212202080924596, 0.06427129158484084, 0.024699239559205513, 0.05265741835215262, 0.026089503529614637, 0.041924439636724334, 0.025493463102195944, 0.04029421854232039, 0.04908624444422977, 0.005272914289629885, 0.025963453775537864, 0.03898202681115695, 0.08265633362212352, 0.021450067837057368, 0.013745414658582636, 0.049943749859396896, 0.027104295058442012, 0.018428532739302943, 0.05809856352529355, 0.07518416350441319, 0.04398409875908068, 0.035147187765687704, 0.07618786607469831, 0.028347413621044586, 0.038537973138902865, 0.03728248318657279, 0.03468614696924176, 0.008344560894849045, 0.02969921313758407, 0.02682047234182911, 0.04964820036132421, 0.029729418123939207, 0.042709487689925094, 0.047461611085704396, 0.06498797384223767, 0.04366324669016259, 0.06801380576299769, 0.050107683919902356, 0.01014533346252782, 0.03272991693977799, 0.019542079951081957, 0.047728078572877815, 0.03922662511467934, 0.050832006481609175, 0.02616952994971403, 0.031902022792824676, 0.012382823042571545, 0.03350414914478149, 0.03568578511476517, 0.0700775496661663, 0.06419733805315835, 0.024444631167820523, 0.03238146885165146, 0.01581353341628398, 0.016608477902731726, 0.04679514720503773, 0.04439304842214499, 0.027105971039938073, 0.034288997030151744, 0.0700590799429587, 0.02562828970673893, 0.031146541903061525, 0.03879790633384671, 0.011939122208527156, 0.017749412484200935, 0.03354722933311548, 0.02870836202055216, 0.0799454233742186, 0.029343487761382545, 0.03386889225138085, 0.03809777354555471, 0.06034961702036006, 0.05524846538901329, 0.04901213824216809, 0.1073618818606649, 0.009719252486580184, 0.030970153332288777, 0.046749390196055174, 0.013237689804684902, 0.03073408082127571, 0.019809107229645764, 0.02878212895510452, 0.01961841174800481, 0.017224923574498723, 0.06516852522534983, 0.017086169948535304, 0.02689356413403792, 0.014338707019175802, 0.013328130040983004, 0.029828307817557027, 0.06508697210145847, 0.04785240315166967, 0.06564012063401085, 0.06098394548254354, 0.09098024160734244, 0.027164759313953773, 0.047528341612113376, 0.02776518477393048, 0.011694948837560202, 0.02307832457258233, 0.04396452641646777, 0.02940925137538995, 0.04899169398205621, 0.04077983587714178, 0.07118892217321054, 0.034414824564009905, 0.03219713463581034, 0.03259016586733716, 0.04905382064836366, 0.09720919986388513, 0.042006101326218674, 0.04608090088835784, 0.07809007793132748, 0.015735949722251723, 0.025585204429392303, 0.03600685092221413, 0.049055062367447784, 0.01342276277552758, 0.05259610932054264, 0.04534785236631121, 0.0469906534999609, 0.036774786322244575, 0.057425639991249354, 0.016736045878912722, 0.0356135245279542, 0.07783055185739483, 0.012451983572516059, 0.016740783749680434, 0.027740318161834563, 0.020013386982360055, 0.01411255808281047, 0.009798632602074316, 0.02337016418044056, 0.03519682938765202, 0.025415859052113125, 0.018715049239939878, 0.008285899846149343, 0.006252271871614669, 0.035003158529954295, 0.008062282693572342, 0.05547014956495591, 0.007797060318158141, 0.013366768369451165, 0.028628715580063205, 0.042118422620530636, 0.11813304174159255, 0.00523974113665255, 0.02307066730489688, 0.009464878189776624, 0.027836115432104895, 0.04497958766296506, 0.03594483282150967, 0.026764856219025593, 0.048492994492075274, 0.06567916353898388, 0.05849389838320868, 0.018805385999647633, 0.06250488172684397, 0.04029258666560054, 0.025714869078780924, 0.02283533609339169, 0.040720830471920114, 0.02171669477996017, 0.031985981323357136, 0.027514639110969644, 0.07756767382047006, 0.07662676288081066, 0.03047776761065636, 0.02240770636126399, 0.023650370305404067, 0.025643605938447372, 0.04380445322021842, 0.02452082047238946, 0.02491117997228035, 0.03196144210440772, 0.02397126139008573, 0.02664262831344136, 0.039104556664824486, 0.05038823779406292, 0.05806129838206938, 0.0025659603249680784, 0.07882573202784572, 0.05944833931113992, 0.046667056756892374, 0.022975441700379764, 0.03233505027102573, 0.03696091526321002, 0.09552679264119693, 0.050251136400869915, 0.030074378542069877, 0.07176727149635553, 0.01671912151921008, 0.041606111718075614, 0.015352490923500486, 0.0197664171989475, 0.03526829608849116, 0.04007082445813077, 0.02667198852369828, 0.033672690458063564, 0.011702582356519997, 0.041649534566594024, 0.01600335189141333, 0.03894883627071977, 0.05737377955977406, 0.0330660190832402, 0.03937030151220305, 0.004124710477689015, 0.10359122883528471, 0.014948201099676746, 0.0021286180001750055, 0.02167964167892933, 0.008533755117761237, 0.035712512609149726, 0.008332169149070978, 0.019667015211390595, 0.03954999115584152, 0.028202196949028542, 0.045501988381147385, 0.07412779983133078, 0.025879885402641127, 0.02600937702559999, 0.07011007863496031, 0.02096878973368023, 0.05083220325676458, 0.04593324149027467, 0.029817380011081696, 0.039841072500816414, 0.015179888578131795, 0.06892172633005039, 0.011722826448801373, 0.024872773193887303, 0.01428883639164269, 0.005087577114214322, 0.09578832039343459, 0.021846301753872206, 0.03700821254668491, 0.03792240616998502, 0.06183381737875087, 0.011492245830595493, 0.059577484881239276, 0.02470952784642577, 0.03146867301048977, 0.00665920162074534, 0.08093022195888416, 0.029293418662356477, 0.018147395325026343, 0.09793916105159692, 0.033321138072226725, 0.050671193682189496, 0.10460414591112308, 0.089140421045678, 0.045587778956230195, 0.1159300963793482, 0.062296103286956034, 0.03391468997246452, 0.019308987905138304, 0.031030006906283752, 0.05771732183971575, 0.04332581801073892, 0.027699697662943175, 0.019742722756096294, 0.021949674867625748, 0.06759321583168847, 0.06758990458079747, 0.018784582115975872, 0.01623570772686175, 0.009978363805982684, 0.04676889129249113, 0.04549356436889086, 0.023173321171530654, 0.06686710193753242, 0.10028598297919546, 0.049449006228574684, 0.035136449949017594, 0.05888834436024938, 0.030143365197415863, 0.0808447129758341, 0.009650010532433433, 0.030532688235065768, 0.04305707403857793, 0.04170318293784346, 0.03031431870268924, 0.01643100367592914, 0.0060721950389311784, 0.07791089718895298, 0.044932096997009854, 0.0030615092920405523, 0.02859686514628785, 0.010066623400364603, 0.010348109412007034, 0.05168208533099719, 0.022304538504353592, 0.03518285835161805, 0.025527398334816098, 0.018752273671062927, 0.02954270225018263, 0.032951607901070795, 0.03255758600841675, 0.02497957121314747, 0.0164535870176873, 0.03124563515718494, 0.026578941016591022, 0.050436227183256827, 0.01729896870840873, 0.04343406130958881, 0.0245172598598791, 0.024349537877632037, 0.0360637460835278, 0.012937501671590974, 0.06750499949391399, 0.041645751733865054, 0.05190999845841101, 0.022827130908678685, 0.023344406991132667, 0.02399537991732359, 0.043503828280206235, 0.09093178742166076, 0.03560706826725176, 0.012719982004325305, 0.03832344411473189, 0.0544005816004106, 0.05508701137400099, 0.04121457665626492, 0.01314059313985386, 0.017728740914857814, 0.06476826420319931, 0.03390018628644092, 0.047637439865086756, 0.013257294377711202, 0.028002443024888635, 0.0359053556541247, 0.03873931144231132, 0.028422120326597775, 0.022180254637662853, 0.005387450152608965, 0.017308676848188043, 0.040750431562108655, 0.009065240571674491, 0.02957963491124766, 0.030355217400938272, 0.040426804284964285, 0.0270926547901971, 0.1088502552094204, 0.09227084235421248, 0.13620776257344655, 0.11439818143844604, 0.12880250279392513, 0.18260475221489156, 0.21085234146033013, 0.08749684638210706, 0.2196878987763609, 0.09490320538835866, 0.2981526569596359, 0.15051835110144957, 0.2029611284711531, 0.07824413252196141, 0.10707619826176337, 0.24644752857940538, 0.18343291777585233, 0.15303301545126097, 0.12865800197635377, 0.15450067312589713, 0.14629337138363294, 0.09664712181048733, 0.14396227789776667, 0.07175640136535678, 0.174578673605408, 0.10599091542618615, 0.08651627507060766, 0.10386197109307561, 0.08741347478436572, 0.24181704276374408, 0.09544712584465742, 0.11933915130794048, 0.1925830574972289, 0.06764422130904027, 0.1188532252396856, 0.11013753113469907, 0.12520911704216683, 0.07320860201226813, 0.1003628745675087, 0.13113495334982872, 0.09150567198438303, 0.19903291282909258, 0.11700640219662871, 0.08733202344072716, 0.10616949905774423, 0.0692357455513307, 0.1903254629245826, 0.13923792354762554, 0.09950935893825122, 0.0849385725866471, 0.08398273387657744, 0.1753592331494604, 0.20543366936700685, 0.1569212925221239, 0.07169555713023458, 0.15837710297533444, 0.04386424572606172, 0.11896438284644059, 0.13226456487817423, 0.09422807661550385, 0.1854126929704632, 0.120988968493683, 0.15211434688951286, 0.14068602584302425, 0.1217946745455265, 0.1746096826557602, 0.1408700445400817, 0.1697586593883378, 0.0786929020125951, 0.20365255565515586, 0.15931624972394534, 0.11413501841681344, 0.12601889430412225, 0.11039861105382442, 0.04558031167834997, 0.14773136350725377, 0.10013872730944838, 0.1833087730088404, 0.10791524752442326, 0.11412763595581055, 0.2779415414801666, 0.1293691745293992, 0.12915331896926674, 0.17822457796760968, 0.13801980391144753, 0.12628717347979546, 0.17784419123615536, 0.12803138845733233, 0.17676575481891632, 0.125679043254682, 0.09919871882136379, 0.1319834478199482, 0.11615884410483496, 0.10796433274767228, 0.21616050734051637, 0.1693162138440779, 0.2469355852476188, 0.1787823744650398, 0.09220256816063609, 0.13297674166304724, 0.11936688981950283, 0.15272050936307224, 0.11985401010939054, 0.10256103625787155, 0.19817881365971907, 0.21212629095784255, 0.09604978707752057, 0.13318004432533467, 0.12451424290026937, 0.13237836877150194, 0.1819917501083442, 0.15276929603091308, 0.19832030178180762, 0.0882747189274856, 0.15311388325478348, 0.1152576274637665, 0.06556050133492265, 0.07070002412157399, 0.2866804211267403, 0.18978353057588848, 0.1280214139925582, 0.13948994502425194, 0.1555268352052995, 0.141735705946173, 0.14498226530849934, 0.07283901077296052, 0.24493607825466565, 0.0591936172651393, 0.1258290944887059, 0.0983115207137806, 0.14508043575499738, 0.16030172684362956, 0.21121203287371568, 0.12279520157192435, 0.09841019327619246, 0.17124165195439542, 0.12196833879819938, 0.0674242673973952, 0.13210685976913997, 0.07495422155729362, 0.09405409345137221, 0.10792137469564166, 0.1584369090518781, 0.11747912397342068, 0.10653727182320186, 0.10362442276839699, 0.08507245433117662, 0.11874660024685518, 0.06827234117580311, 0.09972701261618308, 0.12283379664378506, 0.10934766887554101, 0.09734841489366122, 0.1274008665766035, 0.11736720640744482, 0.22952852930341447, 0.13583291268774442, 0.06376527409468379, 0.09684425658945527, 0.09427499731204339, 0.10025708417275123, 0.12024188786745071, 0.11228794431579964, 0.13202183933130332, 0.11176083795726299, 0.23557348921895027, 0.0969016674373831, 0.07617031915911607, 0.08025078448866095, 0.13087419234216213, 0.08419555638517652, 0.12732044660619327, 0.11939176491328649, 0.09110509883612394, 0.10220302761133228, 0.13220307603478432], [0.022828155496556844, 0.06705870665609837, 0.04253974876233509, 0.04042844973238451, 0.06585541301007782, 0.018004275326217924, 0.04445220310507076, 0.052665682908679755, 0.024326657676803212, 0.017515385756269097, 0.04429662859599505, 0.011921478601704751, 0.029651417130870477, 0.03520087006368807, 0.030562815189893757, 0.02211439602875284, 0.009471096115053763, 0.025731118296140006, 0.024741268018260598, 0.03307844305943165, 0.052316223803375445, 0.014133552804456224, 0.0373222385533154, 0.021735563142491237, 0.02594962523185781, 0.048078379061605246, 0.08817217871546745, 0.05791761180652039, 0.005613864565800343, 0.051169489443834336, 0.04575226263010076, 0.05001748625987342, 0.054338570285056315, 0.04473277733528188, 0.052580974596951685, 0.01985619925627751, 0.06361902944211449, 0.042193665368748565, 0.041078801799033365, 0.029430604872426817, 0.01342161011416465, 0.07623022023056235, 0.028751862900597707, 0.020767504016735723, 0.021698337015030638, 0.025488511492897357, 0.044630138735686026, 0.05640500797224896, 0.026185970853215883, 0.022230954774256264, 0.027470753162301013, 0.039023139247936864, 0.042923127833221636, 0.016712704274271215, 0.034352433269045184, 0.11051127500832081, 0.004556982237513044, 0.027716494797329818, 0.013938997306727936, 0.048956606936241896, 0.02435323758982122, 0.032928690380815945, 0.03449316143191286, 0.04536920925602317, 0.05993769198123898, 0.022142015796686922, 0.031602999195456505, 0.007035655393597803, 0.0511510332913271, 0.027768099081835577, 0.01760755286418966, 0.030114113552761928, 0.03745676151343754, 0.024638765125668476, 0.02703014135892902, 0.01245539405915354, 0.02892101489539657, 0.040717617608606815, 0.03356848104989954, 0.015206480365512627, 0.03656431154481002, 0.05299163416826299, 0.011841902559223984, 0.11667478856231485, 0.04431920006339039, 0.07693638519517013, 0.04211210545950702, 0.027214253354551535, 0.021186192353655185, 0.011217829305678606, 0.018090152414515615, 0.043587193092597384, 0.0277047561415072, 0.0677537979292018, 0.06555237248539925, 0.05073068763262459, 0.027710158976593187, 0.016718151214133416, 0.05077167454042605, 0.05014935275539756, 0.03800185244264347, 0.01433191997265177, 0.024634704093581865, 0.05301440241081374, 0.016279317172510282, 0.015048349475754159, 0.011876058315725198, 0.0025250503884827985, 0.0621282405086926, 0.011657274028818523, 0.012043544507053281, 0.05036817690623658, 0.04976603814533778, 0.007777166519580143, 0.044936046070818386, 0.03417219740471669, 0.10557920751827103, 0.014664005188803588, 0.028215173931260194, 0.013684019961926554, 0.06441664735653571, 0.05688382299350841, 0.06375968296613012, 0.09078318146722657, 0.057670245080121925, 0.014698320401034184, 0.007327656577607351, 0.043203369581273625, 0.016182032214211564, 0.057025093984391005, 0.012013793290991868, 0.01562278195550399, 0.019600506905200224, 0.03298046599541392, 0.03551251441240311, 0.007292823134256261, 0.027000986405515244, 0.014520501817709633, 0.04275431849860719, 0.06825459748506546, 0.06986456430916275, 0.010399988503195345, 0.02763727753024016, 0.01693832564965955, 0.02002788388303348, 0.01349484609506492, 0.030358420086226294, 0.060242109932005405, 0.015089258352028472, 0.09697201794811658, 0.016883937675239782, 0.05456826795956918, 0.019479110205013837, 0.031303897566561184, 0.03167963972581284, 0.045106232831520696, 0.023585553247747675, 0.036154462822846005, 0.01877306568037186, 0.03696658103061574, 0.028759761048214774, 0.0677946118105735, 0.04537593353805797, 0.057686048160706244, 0.06860003287770919, 0.050944080110639334, 0.03980759019032121, 0.05086828435638121, 0.02798276550934783, 0.04000273007633431, 0.020815296630774225, 0.025527430565229485, 0.12510934525302478, 0.03015624379206981, 0.04894449508615902, 0.060343727336398194, 0.033824373568807325, 0.045367180436317406, 0.03853463474661112, 0.04361222764211042, 0.04296790435910225, 0.02550662837789527, 0.04738016652741602, 0.03769958884056125, 0.023858738231605718, 0.029461746237107685, 0.03947612922638655, 0.038925742331360064, 0.07870314110602651, 0.047280218319169114, 0.05416990683547088, 0.024573171145415733, 0.0212005433692996, 0.0556627856567502, 0.030846052670053074, 0.046612451651266644, 0.10650981829634734, 0.02918137556740216, 0.036244127832885296, 0.04538178590259381, 0.0519049840846232, 0.02069498728295522, 0.045093079430184195, 0.022241305825965743, 0.04994566332814949, 0.1443759264158351, 0.08315678712512765, 0.008989583917095192, 0.024660486727952957, 0.0646153020539454, 0.09153358691505023, 0.016583387374079654, 0.026119172473305037, 0.025758821184613874, 0.028113251186109016, 0.012202138496961976, 0.02317321769494031, 0.04564322205260396, 0.017762876315308467, 0.006509366245674235, 0.0691565265879035, 0.037702835630625486, 0.05893238128295966, 0.016998028249612877, 0.04752994974010757, 0.041273751695241244, 0.07295590878597327, 0.032098675811929364, 0.0068931240239180624, 0.008848734466092927, 0.01751915332196014, 0.05509477381461433, 0.03868727459173117, 0.03674308855884841, 0.026198372777019228, 0.006859243922268173, 0.04269215451287372, 0.017218971126047627, 0.017896783504901186, 0.05647897507463183, 0.040491852044527016, 0.01756527165084013, 0.029620363975742033, 0.014942070535783256, 0.08227817248553038, 0.0663465570126261, 0.02264917831468795, 0.0658665681257844, 0.057431339685406, 0.04023836153958525, 0.09357231323208128, 0.021462339142869626, 0.02503491422560598, 0.047601742137755663, 0.06084792635270527, 0.05300932018352406, 0.06272888649255037, 0.020657011374299015, 0.01966323746767427, 0.04197361985487597, 0.04848678589665464, 0.014451525340388929, 0.041956839683864794, 0.04244998875739319, 0.04988823551684618, 0.02916305172922356, 0.009299846598878503, 0.009267711180395313, 0.04060844471678138, 0.044262559352708716, 0.09627585458968367, 0.036639829099710496, 0.02450444911872702, 0.007816199246527893, 0.044096508262945075, 0.04535226284393242, 0.047624177898147275, 0.002821159465903682, 0.06714258715510368, 0.02863918537540095, 0.01432760279359562, 0.01963795525287943, 0.030836478540939943, 0.02583132604403155, 0.0688397389437471, 0.014853776166481631, 0.014185470911408109, 0.01788003895697849, 0.05131872643583587, 0.031161513778248003, 0.01983719688308026, 0.04301226697862148, 0.014367778852049793, 0.09379171753036124, 0.019142806197383573, 0.03714738686435989, 0.06401620991528034, 0.09468813014349767, 0.08225274777838162, 0.03297655424103141, 0.04419220205662506, 0.026422553961830478, 0.046714201369988065, 0.07752951979637146, 0.026842524729935185, 0.032143160567751954, 0.023057434175695692, 0.015720499479877095, 0.02333297028339335, 0.07152372492211205, 0.01025900588969567, 0.050010368427527804, 0.02199391195816653, 0.0583325359704239, 0.04634820975895439, 0.034029935752706866, 0.05490108260086604, 0.03812579704182489, 0.014323365342404162, 0.011429412639699876, 0.03261128526979259, 0.046301458696169515, 0.03928428702056408, 0.03847765816109521, 0.04489433313054698, 0.040836015184010775, 0.023262329698939408, 0.04805767356551119, 0.030128729197063615, 0.0461889066999512, 0.021293602750769684, 0.03861275448330811, 0.02713649663408952, 0.0350236909996186, 0.04588463802688888, 0.024843487622482435, 0.029413580428808928, 0.03746821857722742, 0.041572646370955875, 0.051599239597895315, 0.03222018447039383, 0.009981745454881872, 0.05368215890069093, 0.006795964170513409, 0.008062889982414032, 0.12323221883603505, 0.03349640027486852, 0.0761262211682541, 0.06703865594629731, 0.0555179489643446, 0.014793742780706711, 0.016703255674136535, 0.14689485196556362, 0.1810475414884942, 0.1390095150896481, 0.08843443928552525, 0.14536045358649322, 0.12240688955145222, 0.13330036215484142, 0.09664157817938498, 0.12145433495087282, 0.14816372602113656, 0.10357525612094573, 0.10718660947999784, 0.11843424343637057, 0.20698575036866323, 0.12546006643346377, 0.11547303519078664, 0.1297918747046164, 0.13178954965301923, 0.10198751810405936, 0.21940112273607934, 0.2807866930961609, 0.1451963023947818, 0.11748808063566685, 0.10764370459531035, 0.16006134902792318, 0.11178760616374867, 0.15649980013923986, 0.14368718623050622, 0.11088205368391105, 0.17459551484457084, 0.1631315571389028, 0.08718754976455655, 0.15492447252784455, 0.09651187621057034, 0.20998042396136693, 0.09592758292066199, 0.2251968024564641, 0.1179361173084804, 0.09818480429904801, 0.06403998578233377, 0.0550850504077971, 0.15084046524550232, 0.07607066950627736, 0.10437528962003333, 0.190347162474479, 0.10938485937991313, 0.0990078401352678, 0.12049336651606218, 0.11481372985456671, 0.12230315511780125, 0.14211294427514076, 0.1967211847326585, 0.12155516525464398, 0.20656127243169717, 0.10745583860469715, 0.16543082733239445, 0.10915165367935385, 0.10696430783718824, 0.09779670940978186, 0.20001608292971337, 0.1490522404866559, 0.1009810742522989, 0.11051056254655123, 0.07566368420209203, 0.16735156998038292, 0.12238152591245514, 0.15075982814388617, 0.08386882820299693, 0.18554996060473578, 0.1872663420758077, 0.11239771092576639, 0.09072347038558551, 0.09933012391307525, 0.19321775915367262, 0.2130517177283764, 0.10247560869902372, 0.06330646907112428, 0.11924955754407815, 0.17578643879720143, 0.11616006546786853, 0.16470745471971376, 0.1407480032316276, 0.06748150861156837, 0.2733713095741612, 0.13132650378559316, 0.11279876583388873, 0.12506211921572685, 0.12201746473354952, 0.11206305066921882, 0.08701311876731259, 0.08791318868419953, 0.09701942040451936, 0.1031269548194749, 0.1263865924307278, 0.1540547806237425, 0.09952122651572738, 0.07803219210888658, 0.11135921307972499, 0.08124330480183874, 0.13516980755542005, 0.13977910950779915, 0.10436228888907603, 0.15342230456215994, 0.10449886441762958, 0.06638313683548144, 0.08406106395913021, 0.15922407752701215, 0.12191854789853096, 0.17991000467113086, 0.11764627428991453, 0.11149012962622301, 0.1045235088095069, 0.1826880220323801, 0.09737820936633007, 0.17802685286317552, 0.2368857759450163, 0.13419279855276856, 0.23646209867937223, 0.20288650318980217, 0.08114529041839497, 0.18274071706192835, 0.1698534914425441, 0.12107502030474798, 0.19141219103974955, 0.15655330941081047, 0.17279563285410404, 0.09964515415153333, 0.1890050202075924, 0.07939179308180298, 0.1786772965320519, 0.20882705013666833, 0.10496287380478211, 0.09061573259532452, 0.09678052179515362, 0.12136544686342988, 0.18654283375612327, 0.07382496965250798, 0.15086068558905805, 0.0909127884411386, 0.11590265642319407, 0.280844477138349, 0.11698835316513266, 0.11753179186156817, 0.0766687709838152, 0.09721874006624733, 0.12747114923383507, 0.11706010145800454, 0.1759320524122034, 0.11874402181378432, 0.16169999752725872, 0.0904153815603682, 0.1326073200574943, 0.09501174384994165, 0.1585252678820065, 0.17513733862766198, 0.12143718158560139, 0.11790761883769717, 0.2081626829292093, 0.1966978024159159, 0.09651103482714721, 0.12995276892823832, 0.20719795541039535, 0.09741373067455632, 0.17975652004991258, 0.09979654209954397, 0.15689128770359925, 0.16698863516960824, 0.12816641692604336, 0.13081380272550241, 0.13847639012549603, 0.13005876966885158, 0.18411944593702043, 0.11510574418519225, 0.10937867792589323, 0.10454045861427273, 0.08870339699621711], [0.07224281597882509, 0.011650228290818632, 0.00447768609072747, 0.03255131634484444, 0.03755604475736618, 0.04076701495796442, 0.047082388041807074, 0.013342350438636328, 0.04723332476403032, 0.031995032980505905, 0.027433601673692465, 0.06733685851629291, 0.05699289071240595, 0.04569719272798725, 0.0487421389802226, 0.06764880820576634, 0.05104767205193639, 0.02064856530965439, 0.0253176241447883, 0.047679105307906866, 0.04544900497421622, 0.045092065020331314, 0.00680098363331386, 0.056457750499248505, 0.03827058284410408, 0.08332646837724106, 0.0500849224627018, 0.025336477240281444, 0.038505776652268, 0.04715636871489031, 0.010617078148892947, 0.04891818828348603, 0.05176881906975593, 0.054058338715029616, 0.036740700115582774, 0.030631825593965392, 0.004429232753214559, 0.028737477958202362, 0.05050228935267244, 0.08715442368494612, 0.01517935423180461, 0.02044476562046579, 0.052999881761414666, 0.0453010198793241, 0.021997906833088825, 0.05819296810243811, 0.012500413161303316, 0.05875257628836802, 0.038648336859686036, 0.0475119108866368, 0.008337002862910075, 0.011971306820799197, 0.010087021859362721, 0.03234522829630545, 0.047370541508176496, 0.019513193019000546, 0.04428729195413845, 0.039442263543605804, 0.04622071981430054, 0.018732837035453746, 0.009034736181742378, 0.034099597550396404, 0.06741305799888712, 0.022335969942754934, 0.06085432493793113, 0.041758015352700434, 0.02870473525087748, 0.05161466948421938, 0.037097453472337553, 0.012531328064921712, 0.031824062511857064, 0.03256840185661401, 0.04100607980840972, 0.012942078390291758, 0.019277866896507994, 0.08454451337456703, 0.06097542308270931, 0.026740990446082184, 0.032799181794481616, 0.010259881199869727, 0.024217537371441722, 0.04154729630265917, 0.011001631933530527, 0.04124299031017082, 0.061032019688614776, 0.060475559905171394, 0.08843537566385098, 0.04017398892236607, 0.02471206896007061, 0.036107878001140695, 0.04228913863854749, 0.012548483974699463, 0.06103762438786881, 0.023246546974405646, 0.058958993426391056, 0.03148372630987849, 0.007464597666902202, 0.04432410926425031, 0.07744730849351202, 0.01983444711991719, 0.05712382082960435, 0.021019459336197803, 0.032550179798688204, 0.05573910049029759, 0.037875132635235786, 0.029057665062802177, 0.02470582813423659, 0.042474711180797646, 0.06322103472692625, 0.046412500951971324, 0.08196396327444486, 0.020799586848754967, 0.05044725337730987, 0.036467532095100195, 0.04907368476103459, 0.017074665387294123, 0.018472064153424332, 0.04614037787541747, 0.014158741720686001, 0.0317279039216893, 0.0274528618901968, 0.010929320456593164, 0.08706373069435358, 0.050874849182686636, 0.022562866963978325, 0.026184759668207595, 0.0259131590636181, 0.06535564482744251, 0.041786585069660626, 0.01528951439208218, 0.042130110386226854, 0.04602114909461566, 0.07489874453416892, 0.04187280312180519, 0.02764370495320431, 0.008297532480875296, 0.01324210113047489, 0.061868117323943546, 0.009680072178265877, 0.05051241988050086, 0.040388382239533324, 0.08636391681752034, 0.03651405245597873, 0.08500966948590108, 0.07739602481680256, 0.04750007384323648, 0.06424404161849193, 0.03252942341246775, 0.019962540960737636, 0.018379744375124574, 0.03292625783277409, 0.005992232655574168, 0.035075819452426264, 0.009894818333642823, 0.06293750886938401, 0.03390701574140361, 0.04423175386286207, 0.05139427791748728, 0.0435036959658776, 0.05709425027349165, 0.010340476741216012, 0.035035826598427126, 0.028453356686181257, 0.054509242198296955, 0.08303124457597733, 0.04018830940393465, 0.05203025182709098, 0.0193470435416592, 0.03069122115682278, 0.07941567072910921, 0.04775815124490431, 0.07603649169738803, 0.07311036371226821, 0.055534064171037505, 0.026961398976189748, 0.046129009021180015, 0.012765096101377691, 0.03680847558592047, 0.02424896541716797, 0.03409778925457171, 0.022195335078452314, 0.01822864480449685, 0.018931673240980933, 0.047832036923084936, 0.05892065619783742, 0.01476603141054511, 0.03330051400033491, 0.028451107342594435, 0.04539453557559422, 0.029680641634123664, 0.0172830197427954, 0.05425897134201867, 0.015939991987709488, 0.030808719673327038, 0.029178413762045757, 0.04131740524566599, 0.030964745408190147, 0.008754879502313477, 0.025654437053682547, 0.06912270161722388, 0.03166644221970013, 0.05512067349627614, 0.03065094331811581, 0.04502913089735167, 0.022470192651131322, 0.05144241997706039, 0.0184429108963481, 0.03749143804556557, 0.0396541734226048, 0.07492657804063388, 0.12219544446894101, 0.021258062782830427, 0.04859686802540507, 0.03984573403639453, 0.05199714610353112, 0.044801238125988414, 0.028983070315527062, 0.026718863419124057, 0.04268126402582441, 0.04762633563950658, 0.04993948865947979, 0.060418182983994484, 0.01960973158877875, 0.03949744879667248, 0.016320653525846343, 0.04228568828797766, 0.035138712863304784, 0.03854974572147642, 0.0645337217886533, 0.044754941681666036, 0.05269353337852018, 0.02091238142124244, 0.021227711911446283, 0.028510287470583404, 0.024730435206687877, 0.019550951796450784, 0.04998354593824063, 0.01941685122437775, 0.01697268327032881, 0.04801800301564591, 0.06872438799057688, 0.00936765514779836, 0.03837393390546952, 0.02991835619988186, 0.03427032713911363, 0.013707193629150944, 0.010057752403164548, 0.011593787747967457, 0.029023222625255585, 0.013537349528633058, 0.06167629547417164, 0.04533491948885577, 0.008765574910544922, 0.012653287101004804, 0.03343545765216861, 0.042203181822385104, 0.033785652967968156, 0.03098388688106622, 0.016280740399711897, 0.04894053583432521, 0.023215627829943384, 0.06514576716082436, 0.022649354733792797, 0.06879306930516448, 0.03173018040667687, 0.027127322840637395, 0.04641297592648438, 0.05277773618165936, 0.06399898869650704, 0.057271958594875674, 0.01271852824304785, 0.05376307080898966, 0.01856923715344497, 0.023178868195308105, 0.020410202742953385, 0.007588291208126715, 0.01841406976538045, 0.009102757621024336, 0.034238507239414115, 0.05303878556670887, 0.020614830244864737, 0.009643551727224673, 0.06845096551946231, 0.044533739265586646, 0.04748993313738278, 0.037779795072440586, 0.05226679252726691, 0.04863353605781283, 0.028969424976302043, 0.06002897529729775, 0.00596316039861579, 0.026173222876553024, 0.038908310766730986, 0.013472436627905284, 0.01958890904539398, 0.0262779835944197, 0.021440780388989618, 0.01482943372268762, 0.03404004931715982, 0.04841916648937123, 0.0296124488647495, 0.0385455388043608, 0.021643009269610047, 0.05244771371196423, 0.062254183393503935, 0.007750493307997073, 0.013122324432645525, 0.056236385234764645, 0.020838695910892317, 0.030785819116447653, 0.07387436700186559, 0.02714599103533796, 0.025461151264607906, 0.04733593622222543, 0.019307055776672702, 0.0599113241104143, 0.0359860843579684, 0.04729438613035849, 0.035275766759046485, 0.018881258089095354, 0.044711966666259935, 0.02082129996935172, 0.03925904551787036, 0.03403641236945987, 0.06588568245725972, 0.059221308279250345, 0.02978959060939295, 0.022370627815169946, 0.05029963469132781, 0.009241375539984022, 0.03771202978012817, 0.016773696090759974, 0.006537414762923228, 0.06220140015440328, 0.04816717215414558, 0.023533231412459697, 0.07078012518052544, 0.03940289833449891, 0.03913380491680332, 0.031744500888245444, 0.0535287523109998, 0.013191141454236848, 0.06469663804663078, 0.039748917267258675, 0.03569197335413524, 0.011205304397403129, 0.014364698303065129, 0.05441520742273756, 0.04260476938049708, 0.0013184675439593516, 0.06609788071364164, 0.030236042902937958, 0.17711581103503704, 0.09116404995854412, 0.08171943960977451, 0.1372919122555426, 0.08772446773946285, 0.08401180231677634, 0.11087216742868934, 0.15731539923165525, 0.1524387409112283, 0.11997781560889312, 0.10929876685674701, 0.22280031176550047, 0.13816688316208975, 0.06085868113275085, 0.1446062619132655, 0.1734381512339626, 0.13418471041534627, 0.12365430832973548, 0.07161969691514969, 0.10402758113507714, 0.16502575549696172, 0.10304188688418695, 0.08871932221310479, 0.20426795977566922, 0.11516479030251503, 0.2021389611597572, 0.09621156339666673, 0.12192183200802122, 0.09185732954314776, 0.08614192730081932, 0.17980625666677952, 0.15570955111512116, 0.26940671088440077, 0.1371938232332468, 0.21575897745788097, 0.14221904001065663, 0.1614977940917015, 0.10932266486010381, 0.11262853496841022, 0.14241345386419976, 0.1289112583867141, 0.13440033527357237, 0.10711838956922293, 0.09794208553752728, 0.08434049146515982, 0.2179889285138675, 0.11431483019675527, 0.1510570536234549, 0.15183263272047043, 0.08572152735931532, 0.09598259175462381, 0.09050692950508424, 0.10334572129483734, 0.13562203757464886, 0.13021891750395298, 0.07682204525917768, 0.11826124414801598, 0.10830000402139765, 0.06869186580713306, 0.08629412949085236, 0.12860969028302602, 0.10970640355455023, 0.15045952211533273, 0.1511181082044329, 0.15802418334143503, 0.06726345459797553, 0.11481987738183566, 0.1131314786949328, 0.08756147005728313, 0.09932687373033591, 0.11759630697114126, 0.15608989713447435, 0.15114588742809637, 0.10068200994282961, 0.16718649598104612, 0.19827661769730703, 0.08197474519589118, 0.0912131555378437, 0.12438376061618328, 0.11253821517207793, 0.053018117390040836, 0.07949379046580621, 0.06846203242561646, 0.16767300558941706, 0.10380844825080462, 0.15179120137223176, 0.22528949034001144, 0.09174826182425022, 0.10800462415707962, 0.10108201990702323, 0.09855796463255372, 0.21564598780657562, 0.13164404460362025, 0.2421410839472498, 0.14212675924812043, 0.17638851648994855, 0.1364296299538442, 0.12091605312057904, 0.12498368056757109, 0.09570394456386566, 0.14555285897638115, 0.07609948010316916, 0.21399214012282236, 0.12350127154162951, 0.1890063772776297, 0.10387245445911374, 0.1524248852261475, 0.0936800849490932, 0.15603737852403096, 0.11948019159691674, 0.20272047924143927, 0.07981283763157469, 0.10326103333915983, 0.14133701233991555, 0.1484433910144227, 0.1554582624563149, 0.07504475169948169, 0.1213789904224021, 0.13825038368148462, 0.09513466046856982, 0.18231047157730373, 0.07702644714819533, 0.23186591959425382, 0.10191083686160189, 0.1155436842569283, 0.1649494203073638, 0.14436766185930797, 0.17298764469368116, 0.19848207810095378, 0.14340533635446004, 0.12481236404606275, 0.216776576425348, 0.16192185133695602, 0.12884529121220112, 0.15003043014023984, 0.06619265848504645, 0.1581703940672534, 0.15680391953459807, 0.18982925026544503, 0.1317402608692646, 0.12504857565675462, 0.28299510745065554, 0.09898121442113604, 0.17678706081850187, 0.13188140972384385, 0.1229975407144853, 0.20144068077206612, 0.07709867720093046, 0.107140441957329, 0.08427892798291785, 0.06358373883579459, 0.0715761146109019, 0.16384526741291794, 0.12208032421767712, 0.14859432434397085, 0.09136665372976235, 0.20399092749825545, 0.13748061284422874, 0.12194830844444887, 0.17554965721709387, 0.1565917416342667, 0.11820635066500731, 0.10232990008911916, 0.10463275973285947, 0.20831616755042756, 0.18482703582516738, 0.13837842323950358, 0.1302343745316778, 0.11794910446873733, 0.10479326719152075, 0.159229166539652, 0.15163629182747432, 0.22668107066835674, 0.12412180538688387, 0.15487416594156198, 0.14750436640211514], [0.020971144250194942, 0.02717490680515766, 0.022370095165180306, 0.022385097574442625, 0.014184173213184943, 0.04122698027640581, 0.04890769134674754, 0.00853502906725875, 0.06144652994615691, 0.03142521284254534, 0.021737941407731602, 0.06029850297740527, 0.03636372980794736, 0.047055789469076056, 0.021397818944283893, 0.010268574081627386, 0.02233854159047561, 0.007310873862089855, 0.015614347765222192, 0.02296922292693385, 0.036998774124575515, 0.010473487416415342, 0.08827906155160495, 0.062583985339318, 0.031118793213473897, 0.031881873695445914, 0.050096627191773484, 0.03709866805002093, 0.0086551272210532, 0.06007129552641085, 0.037194473801978996, 0.03514132861580167, 0.04245733389897006, 0.04091225198603102, 0.018568202387541533, 0.0283865396465574, 0.03280754473858646, 0.02011037338525057, 0.023284370212682655, 0.024760843753548603, 0.01832906968359436, 0.11405484271900994, 0.04099769311557923, 0.015346307773143053, 0.043497640040836165, 0.013637577632575162, 0.05697347782552242, 0.03145164856687188, 0.019543718613151993, 0.1161741925669568, 0.07464531170470373, 0.06085621126528297, 0.059802778863481114, 0.025906394069482173, 0.015105577119226967, 0.0367210090293416, 0.02576373377814889, 0.04066245949694088, 0.06248837296984025, 0.005128090319755886, 0.032441848290285895, 0.013847251738687711, 0.02681842486241034, 0.010322839919743794, 0.037761610333940814, 0.08410536551049777, 0.049449677978243144, 0.046728294542325396, 0.050794493673103194, 0.037212974059262445, 0.03046726728124278, 0.05937140701072557, 0.03248884701835258, 0.018235533631273677, 0.004631655440399689, 0.027549916146589176, 0.01930270975987826, 0.04294315140162196, 0.07277907577476331, 0.03188078125406589, 0.03640524936573846, 0.04125779255160263, 0.0023294743316780242, 0.0193579119763204, 0.031404928038162847, 0.006864900359817381, 0.020517151736255203, 0.0226165204242404, 0.019169128267094493, 0.015851300675421953, 0.07849373841392142, 0.015155235704566752, 0.02938335508640323, 0.06561382061668805, 0.062194845506123135, 0.01653290436869221, 0.00720383581106684, 0.03683618695608207, 0.02412127869735871, 0.017169081838801503, 0.0412206122252558, 0.04040051783834185, 0.015836669764082347, 0.02328433289325663, 0.06340501271188259, 0.03962487428049956, 0.03429706820419856, 0.0450258535732116, 0.010462216101586819, 0.02216774584459407, 0.002821704838424921, 0.02104318092044975, 0.06626891903579235, 0.07356268194104944, 0.07551839628389903, 0.042110134315277846, 0.051171114535204, 0.030069411665733372, 0.00937642012390175, 0.009174288782690252, 0.010679304050946874, 0.029937864081668, 0.04105479523007359, 0.05493256323305624, 0.05775739611791713, 0.028566405709300722, 0.021101819916761348, 0.021362077112176588, 0.017754915403202176, 0.03991523298567959, 0.02768614053327058, 0.04206288452925427, 0.02760640757956675, 0.017813242273405194, 0.029890285206160376, 0.055446288881025145, 0.016121242261890854, 0.0023427227279171348, 0.033772591168859174, 0.04005090606265834, 0.06037849547075374, 0.0514201233163476, 0.04659030426825796, 0.019575222994067838, 0.010215174223828529, 0.026162593625485897, 0.027046911351914917, 0.030575771816074848, 0.015728112642786334, 0.04104947890820248, 0.04324756595971329, 0.03914873268721359, 0.02880118561110326, 0.07051882813019411, 0.02222811510520322, 0.048269780219665596, 0.05988967205796923, 0.01969059430328863, 0.04109692546938147, 0.02022811278168644, 0.02484733152336308, 0.035187652201524804, 0.025524321178506528, 0.02294003065409405, 0.06467506741838795, 0.04558259494868772, 0.02184822709698762, 0.012915944614048516, 0.050708625066493235, 0.0427854903973639, 0.05044052909527506, 0.0012230084809873784, 0.037040449745420895, 0.009189139369742146, 0.09040217048355512, 0.006658261001575738, 0.022231131193361113, 0.046151967253535986, 0.02817732864059508, 0.05553867820916431, 0.03268978498610003, 0.03923742399950113, 0.024559459649026394, 0.021826396929100156, 0.03751535640497293, 0.08369928265788726, 0.04342689597979188, 0.028171386370169263, 0.015372577256390026, 0.027812276800562228, 0.023202718701213598, 0.01965777186809906, 0.008765777622881745, 0.03873540986595409, 0.04069241342533912, 0.05723518878221512, 0.02035121769378228, 0.020974665846941725, 0.033642821346542666, 0.044084213208407164, 0.042925804653870206, 0.02777347986453346, 0.056872440568570576, 0.07352602747934205, 0.01445913511062307, 0.05161210462184889, 0.036362206496830494, 0.006962033495905676, 0.02180012235684054, 0.01840143883600831, 0.034966174978762865, 0.025503844687981263, 0.04679461455504809, 0.05030015377061708, 0.08596034454447882, 0.03799583722970315, 0.05314958015722888, 0.03485503772805844, 0.028513273024665456, 0.028634221891739538, 0.03630502974348409, 0.028316207795536945, 0.02542225594100143, 0.012970654892602136, 0.04779083627675261, 0.053670918968107016, 0.008697001313391541, 0.06077237826372896, 0.06614536459424666, 0.04977067593219025, 0.029727541974612644, 0.017609155903171216, 0.02643184649891087, 0.01749752671457827, 0.014916004613041878, 0.0070901175827852315, 0.04525248087676508, 0.05655668429764254, 0.04504912732435124, 0.06231350771018437, 0.05344464111008814, 0.04277759564242192, 0.07430248188653163, 0.02989988647667425, 0.03804362305839147, 0.016040508469034518, 0.02121533204003104, 0.042946944412376196, 0.019505003101325462, 0.06033692841551133, 0.019956697077889527, 0.046273207890668085, 0.057731455724154196, 0.0417572825348803, 0.05001194602144616, 0.021082502024780427, 0.04110610604818378, 0.06811306186552558, 0.04744008116956268, 0.022861955022173266, 0.029272448537605147, 0.016076747328042984, 0.009398965298065116, 0.0687142371066979, 0.05197492747434548, 0.04506005173815148, 0.08793140734945025, 0.023558432203052298, 0.004550094682989376, 0.017333619795473557, 0.03655630822426506, 0.01464443454252822, 0.05858416389673948, 0.038109668264431615, 0.07560077722051314, 0.011668670872625495, 0.037547729310712645, 0.009555360834513391, 0.04107805201783776, 0.007370871624776295, 0.015647058242133687, 0.017113106092438102, 0.02980701538867184, 0.045532617451889176, 0.032541348665420494, 0.026443217049485872, 0.02130460349975952, 0.030412943767649785, 0.020867372497117946, 0.06544176449200936, 0.02706330475796546, 0.04071713924141867, 0.022181382702131356, 0.03495353047869035, 0.048727078895483694, 0.022692531613366942, 0.061191204003989697, 0.042559321104948006, 0.006882108856059078, 0.11496061911540371, 0.0405282588409526, 0.047401557343878915, 0.04600105767271348, 0.03995426231995225, 0.004615812495883022, 0.01693174216364111, 0.013067144268591489, 0.015365272826914276, 0.02819338786814894, 0.014094091752277953, 0.017424307697053467, 0.05587448179721832, 0.011772224646327751, 0.05133816646412015, 0.04166797375572579, 0.015200692461803555, 0.018360882797943692, 0.03370729913668973, 0.08188102593911545, 0.038765981261219294, 0.028818603605031967, 0.11885368664349828, 0.043658524086432796, 0.04762669187039137, 0.020402175673682774, 0.06811125696237598, 0.00891594251152128, 0.04527326440438628, 0.027286208600604107, 0.02403060775915427, 0.03388765374464648, 0.019551940761240463, 0.06278937110411269, 0.027528219989367893, 0.03723095523725663, 0.013369977840089371, 0.07254235526280743, 0.028469989275825874, 0.0276608277843999, 0.015065039740875363, 0.07205786768879209, 0.030465255424912487, 0.029191943750317608, 0.013492355023377707, 0.009851442982575722, 0.07942821005625383, 0.016363998342837607, 0.06147094363612788, 0.05181875924712845, 0.044576995873025486, 0.04778154034699712, 0.03207850975117513, 0.0491184137894639, 0.1382410198982273, 0.11459761645112719, 0.0971113686848964, 0.07593391077326876, 0.12879482177751406, 0.1352576371282339, 0.17589347091104302, 0.18507164769939013, 0.17624081298708916, 0.15734334130372318, 0.0956825367840273, 0.07914726263178246, 0.1186331356210368, 0.07492738549730607, 0.06633590401283332, 0.076993178576231, 0.10232534711914403, 0.10900969736810241, 0.11729342250951699, 0.1305373404175043, 0.08318044085587774, 0.13757382998509066, 0.10829989545579467, 0.10587383420871836, 0.08936576931072132, 0.11337433316345726, 0.13847544017646993, 0.06102490185626915, 0.15387055836617947, 0.13250266281621798, 0.10124161812875952, 0.21300515665539674, 0.06806181211556707, 0.12000828183123044, 0.12855266620005878, 0.12146090316985335, 0.13876343757978507, 0.13058733487767832, 0.18359974239553722, 0.09931470081210136, 0.16971863939293794, 0.12531943326549871, 0.121362976995962, 0.15904465929738112, 0.09473265561142138, 0.12841396007154668, 0.12385166702525956, 0.09538396780512162, 0.1807742818657841, 0.14956700429320335, 0.11182397564074822, 0.10991981638861553, 0.16960039788058826, 0.14844079901065144, 0.09543559753469058, 0.09306280807192836, 0.07499340695462056, 0.09027023613452911, 0.12370603983955723, 0.10054272705955164, 0.15956801335726464, 0.09174222964793444, 0.09870359181825604, 0.107238137429314, 0.14511042700282165, 0.1836544323180403, 0.13313637381153448, 0.1932977041495698, 0.09514261289898839, 0.11069823854735919, 0.13441871000187738, 0.15641674745295728, 0.12420560446168695, 0.11167500327740397, 0.14019775204360485, 0.15466869196721486, 0.0937950966347541, 0.09797276210572038, 0.11468623312456266, 0.04992026915507657, 0.11603229732385703, 0.1261913643351623, 0.10719314377222743, 0.12330889329314232, 0.06797687310193266, 0.10449495605592217, 0.17831309964614256, 0.1082494735185589, 0.11787487273769719, 0.2186142663870539, 0.12138854419546467, 0.13007588232202189, 0.12437861732074193, 0.07465463477585997, 0.09536840899714402, 0.09084367286413908, 0.12399943838162081, 0.13696802034974098, 0.13121487120432512, 0.07296190025018794, 0.09394874410437686, 0.11895096142377172, 0.1222446925405945, 0.15009091475180217, 0.13679466822317668, 0.10276602847235543, 0.08359544644398348, 0.098436629000519, 0.1250061129352876, 0.12329053213553769, 0.09347463133079664, 0.11104266970817532, 0.14126693324318954, 0.19628840152706417, 0.09968458382146698, 0.08601595048925706, 0.11229963547417096, 0.13499640114605427, 0.14695392522428716, 0.1915537877274411, 0.09938217433435576, 0.13813641693975243, 0.2000485576157059, 0.15308714897504874, 0.11997586142803941, 0.0749508153115, 0.12077402217047555, 0.14234188199043274, 0.14718886118914398, 0.09482297540775367, 0.17550000202442917, 0.13124672163810047, 0.09160601374294076, 0.09254829532333783, 0.09518315536635262, 0.11523576506546565, 0.13496463213648113, 0.17037589555340155, 0.09512919147631951, 0.1950637408133064, 0.13610246750925267, 0.22482944359736784, 0.08632372040301561, 0.10937013517000846, 0.20049141028097697, 0.14452514983713627, 0.12350269646516868, 0.10069298863943134, 0.14773533972246305, 0.16015729387956007, 0.1372499923620905, 0.13222394777195795, 0.2059989297496421, 0.09137855523398944, 0.046123794479561706, 0.126209291230355, 0.09714365338108369, 0.09723543202770607, 0.11242356989532709, 0.11024773200707776, 0.15209207737020083, 0.09031434769609145, 0.0807537417858839, 0.16890342028013297, 0.10580346334193434, 0.1259247814970357, 0.13361315322773798, 0.12306531279214791, 0.26048196692551884, 0.09674751785184656, 0.19130080273108824, 0.09249116267476763, 0.19903688904430183, 0.18776330112346581, 0.13968522740261896], [0.057129262680453916, 0.037870508419083695, 0.02313430710429592, 0.03050750440784863, 0.06821022808019604, 0.015995718372453536, 0.023615315490003144, 0.05799077145223107, 0.036756357311138084, 0.02799317254019635, 0.04478280232953174, 0.015565701893397739, 0.023719353568074957, 0.030435064009257724, 0.043603691671575816, 0.036862466617354324, 0.03576864441856742, 0.008978370277743255, 0.018465972605294416, 0.015195605145501239, 0.01541599671223334, 0.035975227797670026, 0.06839529172118221, 0.007764527108520269, 0.0436833720388157, 0.061255610547959805, 0.009302337670565715, 0.020333913354469196, 0.026264948936711465, 0.020380616919802766, 0.04980255690004144, 0.023879302931683402, 0.013842746266163886, 0.010735074540467134, 0.010758254993041711, 0.031187372747808695, 0.0367886793267514, 0.011854174713205014, 0.054401959026498456, 0.07106570699917418, 0.012902485871953624, 0.018080468023461953, 0.009946769519176866, 0.0443550911732018, 0.006437773167687867, 0.048143443784543445, 0.08568176520722252, 0.016450000960113745, 0.028805467167070935, 0.05304944535185184, 0.016267492003472786, 0.016154375126851455, 0.032116480570818694, 0.024709526150088226, 0.03140405612066388, 0.029182468008782183, 0.05228393571451306, 0.05709016549267939, 0.025863278258059706, 0.012537838608425642, 0.020161601082820977, 0.03813189707164254, 0.0297398641705513, 0.056582438094275336, 0.05309065617620945, 0.034860662783363035, 0.0675778334428157, 0.09203695811863456, 0.019717365902449404, 0.03862703086010047, 0.013842756444189166, 0.04283968838197844, 0.027961247467568943, 0.03069353835391147, 0.012916126122166003, 0.025061202368565967, 0.021072860042165433, 0.031709278135427406, 0.046293353595371754, 0.00784692755301616, 0.029114434695137397, 0.03531738131174019, 0.017251242251534547, 0.030129051501197473, 0.01533490838482976, 0.029108880886009762, 0.029245873713599782, 0.08037873583712749, 0.039951487111725976, 0.05783888138830662, 0.020604182334084595, 0.006589817174244672, 0.03644871971170817, 0.013765428048957671, 0.043671877655599795, 0.052000403071620634, 0.0166213429266853, 0.08645690325647593, 0.07062139548361301, 0.025612669830609645, 0.031055770880941833, 0.037507305586976666, 0.07960407276238714, 0.04251344535233719, 0.04382830372612391, 0.03598406232361283, 0.02452990605628916, 0.026311089317979555, 0.08451331433440958, 0.034038858488202095, 0.0806158906114953, 0.010983034136838146, 0.006961726034725351, 0.07389050934995924, 0.011817805236205459, 0.0343526741489768, 0.07577890623360872, 0.04967116877170546, 0.024818526015483906, 0.013333072320425084, 0.009095867946078735, 0.09768175200692245, 0.07689050265720912, 0.0351831331583006, 0.03781070573521512, 0.012486184281962258, 0.04289514844172767, 0.028249270315947275, 0.059836081362196376, 0.04074901681659477, 0.016985602577083876, 0.10073433177811758, 0.059452030541641374, 0.036041524061667066, 0.02094817753615124, 0.018845446707148637, 0.012148425664885767, 0.01315477367357484, 0.023003186997292296, 0.01953977802103119, 0.027784271964005063, 0.044954624359628985, 0.027873811445065906, 0.04143139573612383, 0.02321866257781429, 0.03540388774126768, 0.01278882277464228, 0.029269120323338678, 0.0782077901863626, 0.027114137208887508, 0.018877929874828885, 0.07925999443978071, 0.027439545640455823, 0.021264271378251057, 0.052942633761891296, 0.0413579646764057, 0.06426418053784541, 0.0509778813325933, 0.03334215569442936, 0.002367850363953039, 0.05489642106528793, 0.021150884783959815, 0.019332768861204386, 0.011208698768833918, 0.014817401600469435, 0.003367864460285221, 0.07005500194749661, 0.04419259221426078, 0.037809728644788265, 0.045082433215741596, 0.031950490549206734, 0.0181135550873088, 0.015162594416843993, 0.007064322225882539, 0.042478524547602446, 0.0156881163961121, 0.030698953063360283, 0.031566985949341736, 0.029978311554129635, 0.0543862712968673, 0.0715163221050586, 0.040505602556679926, 0.03867944429761597, 0.039537879305758646, 0.011555841525218316, 0.026209819662783827, 0.02536060594554458, 0.04510792577639222, 0.020947902729468684, 0.0438804220009063, 0.05909719065363918, 0.09273337253502437, 0.023535306033279215, 0.0289217544985669, 0.026998662423076372, 0.052863896558327336, 0.057125612162053585, 0.057359754240938594, 0.042377409259123464, 0.03042340338496225, 0.0363132569805852, 0.05772986116686037, 0.021981906977349093, 0.01720098146636571, 0.0454680446668395, 0.03399122193721788, 0.005276843007387859, 0.0177825911502753, 0.052510108399604044, 0.029129430319049528, 0.03950360310929162, 0.040594819733606916, 0.024563164450228214, 0.017135769162060957, 0.023955300550109575, 0.020393074822745154, 0.028857615975929157, 0.02064353057981602, 0.019635339500382543, 0.07499065210244485, 0.031215128222746507, 0.02706756256520748, 0.04836628147001777, 0.012749127627882575, 0.0241011533487056, 0.05284096546737211, 0.012087356665038636, 0.022360970565517033, 0.05645110085606575, 0.021162523355867182, 0.0556839729127075, 0.007997351133131554, 0.024063939095607827, 0.006283664294252438, 0.004249036752818418, 0.04988690558820963, 0.021717108686321547, 0.05740520930183785, 0.0071204107786927906, 0.06992950689579759, 0.023739144738231386, 0.0163865426688322, 0.03271297052768724, 0.038090713388685665, 0.011445046934698309, 0.0356181962415576, 0.043001081328839064, 0.0644696680828929, 0.044260720522808175, 0.03508838592097163, 0.057890321128070354, 0.049767279864421914, 0.03654979428808604, 0.015953471085854938, 0.01637018658220768, 0.014326322058747922, 0.034662700191672356, 0.029386014943676333, 0.03593645291402936, 0.05246035481936165, 0.03431975841522217, 0.014479681150987744, 0.03582053877679365, 0.03569474856236151, 0.03253569307604006, 0.007083634180682046, 0.008502607815898955, 0.05993875049586807, 0.015258807289813246, 0.020902065992621437, 0.050749184497232945, 0.013031410070003142, 0.00709763278220115, 0.021335310602028455, 0.014232367011053222, 0.10801204054483346, 0.03127105307898351, 0.006366309435439429, 0.011045204907921808, 0.0761684396171144, 0.027998346369713545, 0.0352172227576375, 0.023680395479979258, 0.028427200857549906, 0.10850973919566188, 0.040555871823536496, 0.06978863624057599, 0.06659155565180949, 0.017450879128383737, 0.029760963216956173, 0.0184345275961927, 0.04822441336831876, 0.07055373875690357, 0.02937191159331373, 0.062304937812898836, 0.014873804823894585, 0.024035028414800763, 0.05398898904344865, 0.011830527767805117, 0.045334295236638615, 0.03189368359744549, 0.014180186819950385, 0.012746388890913554, 0.03636624378019145, 0.0136076627199405, 0.02240361479510154, 0.04020778335896986, 0.0591808200946876, 0.019729532035333768, 0.050727719041918, 0.0708112156550799, 0.023054553794541528, 0.060641495643981864, 0.08768125184412513, 0.019061899378097484, 0.06156406578208719, 0.07701942431075232, 0.021117734955623746, 0.020934267568268945, 0.07441425696015358, 0.021767150643946867, 0.05296996854511755, 0.003542261318736044, 0.047804613930306265, 0.07967794486986739, 0.0450943788247449, 0.006428446279772158, 0.012575449804509324, 0.04321342547024999, 0.05635527814073222, 0.07433917027498994, 0.03264333587139845, 0.048498137787516625, 0.0399840059024947, 0.04054444868649755, 0.00538305366977251, 0.05009965345795665, 0.025558395510805503, 0.02323849106739674, 0.015429357066750526, 0.05662250219445143, 0.014991059067792125, 0.05567223086420979, 0.03206054214388132, 0.02335830678098968, 0.04034841313425984, 0.05920625837253673, 0.05489513863410268, 0.06240340002945491, 0.03572363040543028, 0.025550999479102235, 0.019345888335789953, 0.10511647377695356, 0.10343772385801588, 0.0875962246209383, 0.14981395032789024, 0.1885257844946214, 0.09580104971038443, 0.21316982353372232, 0.22170069148497923, 0.09901554150772945, 0.2001751722501857, 0.10405432898551226, 0.12532938058887208, 0.16797873989811965, 0.21967576657022747, 0.11810063490910189, 0.20336169483406202, 0.1186688265630177, 0.12977534559156212, 0.0909600823319384, 0.093837118308459, 0.1401548007769244, 0.15509648115507194, 0.09284512046724558, 0.145796928022589, 0.08852044359913894, 0.14989313536456653, 0.07427423447370529, 0.11742953663425786, 0.06409935759646551, 0.12537543954593794, 0.18435909093490668, 0.12713896563010557, 0.1384155662464244, 0.14258710454617227, 0.12619234142558916, 0.11650108359754086, 0.1939367755715336, 0.08874381054192781, 0.1594435971762453, 0.13866640707211836, 0.20027585327625275, 0.13025456773383276, 0.09905644359865359, 0.22484358426715645, 0.1415705776640347, 0.13409142542098249, 0.1273597880665745, 0.12928772318576062, 0.12540620432368346, 0.2391933649778366, 0.10048362665942737, 0.10394043009728193, 0.15305889477687223, 0.06859833654016256, 0.1674703136086464, 0.09576377778181008, 0.18817103281617165, 0.22119546788079397, 0.11329044587910175, 0.10445353149303369, 0.10150475400899138, 0.12715554902596132, 0.12010904428149972, 0.18069037422537804, 0.2072952709027699, 0.11962136759289674, 0.11009432202471153, 0.1358627410871642, 0.10939162437404905, 0.09120341177497591, 0.11069021147808858, 0.14797250128218106, 0.1373484477932964, 0.14868287316390447, 0.15996651697371686, 0.1674205091382776, 0.08457809407263994, 0.13894476927816868, 0.09928505561713662, 0.0735878555902413, 0.11980198004416057, 0.07807474982525621, 0.09980159040008273, 0.13002890055733068, 0.14131395571998187, 0.11020839733204671, 0.1432495718555791, 0.1500245811683791, 0.13800704745309694, 0.08565925820065395, 0.10967752510415656, 0.09924819759492363, 0.21911050618759223, 0.17682710795530251, 0.1286178191325494, 0.15781642948942526, 0.07137030815439564, 0.1859580451356513, 0.10545400423663003, 0.18374260115836347, 0.07691010553389788, 0.09444647668195622, 0.12809177807399205, 0.16087001349244798, 0.0973622298666409, 0.11421456986239978, 0.13310977523880346, 0.16759751178324223, 0.1559192320065839, 0.14720996362822397, 0.16587226864482674, 0.130558469997985, 0.04631841189361044, 0.15649623104504176, 0.09039271170539515, 0.12915521886731895, 0.13347318502409117, 0.19643420513187135, 0.06716930107878787, 0.09512765798717737, 0.07781987850155149, 0.16497341330562318, 0.13297940152032034, 0.09843441019100801, 0.09297977574169636, 0.10505810619464942, 0.1250521990337542, 0.1712757008416312, 0.05941184091248682, 0.11155799669878823, 0.12420094971145902, 0.1771025796021734, 0.18965971150568553, 0.10946089601410286, 0.1095650986369167, 0.08304224362862961, 0.1566211629126753, 0.18647796580834047, 0.13263839696134838, 0.10964986801679645, 0.13815830647945404, 0.38176190480589867, 0.11844035025153841, 0.11309580810900245, 0.12631559052637645, 0.21321721241942473, 0.10256136874003069, 0.21859404604349816, 0.19623244952942642, 0.12132781531129565, 0.12414711474307946, 0.12023840019745485, 0.07818216191870825, 0.1625926781977926, 0.1837072494838919, 0.11090437748602458, 0.17138927403305257, 0.11828824984175818, 0.12125362429235663, 0.0981076480820775, 0.12690325613532746, 0.13129055500030518, 0.10761158953287772, 0.04257750245077269, 0.14660408613937242, 0.09686238704515354, 0.14084193961960928, 0.09453028932745967, 0.09034677488463265, 0.20828749266053947, 0.12438895819442612, 0.19300218857824802, 0.14370799011417798, 0.13132472602384432, 0.16224107492182935, 0.09841595403850079], [0.038942956764783175, 0.007383480501760329, 0.051198768229889016, 0.014896160856421505, 0.013691862978573357, 0.020495508165497865, 0.02079021797648498, 0.022759694705850313, 0.08848342272852149, 0.04500204038673213, 0.012829947085785014, 0.019300049902605157, 0.06445555455450501, 0.036516678386500905, 0.016666772542521358, 0.013440592979480113, 0.04826437229556697, 0.024091055051290562, 0.05943825628076281, 0.11173516897750752, 0.010355705611540802, 0.05606525191771133, 0.017864839772560766, 0.04135125396507127, 0.03359407539080296, 0.021222314165372933, 0.03142902620935014, 0.02628535927007241, 0.01959773848232414, 0.020540551016373292, 0.027655206121770397, 0.007534300176692861, 0.01856122026219964, 0.0562942914132561, 0.07526967927281346, 0.09516269753554038, 0.05779934993812016, 0.025249836800087775, 0.01790794879863305, 0.06991796501513038, 0.06441004521080426, 0.06861470280481236, 0.0149012837958123, 0.02975528048617499, 0.026909121245677983, 0.015756119175681045, 0.02877429187563913, 0.05994548834860325, 0.052622188813984394, 0.02355552468049739, 0.09694277987416301, 0.03518921622474279, 0.05674729835508125, 0.04024310110669051, 0.04049843044153281, 0.0479227231283273, 0.06499634696436779, 0.01795854206596102, 0.050552198995969126, 0.04618020788101213, 0.01940260877433632, 0.01537959330848285, 0.02128116859655295, 0.017304731167054603, 0.05171502820615258, 0.014543215777458889, 0.044748651662043164, 0.0537390031718782, 0.01956628499153469, 0.004627982021442482, 0.027926179081467644, 0.0015266479188410032, 0.018420709230537926, 0.01616549801214465, 0.032573606220207045, 0.029962827385004078, 0.020720372974340404, 0.06795608278896127, 0.016738870280927846, 0.08272521171186652, 0.05055001750588417, 0.021090142329090407, 0.04004417160259826, 0.042504264773534875, 0.04509743901767901, 0.039985569925712686, 0.01563623730492379, 0.013719549751840532, 0.023975751595571637, 0.038674711515860896, 0.023630093982709304, 0.022497535916045308, 0.0520690979569086, 0.041621528033699305, 0.024225055539448346, 0.08656411178942237, 0.0695358073072774, 0.05043907703033515, 0.03553749128643956, 0.031732938651527674, 0.022103132347443273, 0.04812315219481077, 0.07156781612762383, 0.014999598431001817, 0.09159376618585416, 0.03719550856788244, 0.019521125093368546, 0.04514819682974901, 0.04672489847455706, 0.10709166886018855, 0.0516683755309454, 0.01578426480825458, 0.06685617752373219, 0.03871649570230927, 0.013430543027685156, 0.0535342755860516, 0.03223329715962921, 0.03128185535648039, 0.026667009772998945, 0.0345908874379737, 0.0987144483785544, 0.030346521974674294, 0.04993965829323445, 0.043675151587064774, 0.05265494169933455, 0.007547296666806298, 0.1133371562297855, 0.014581033926723259, 0.030635445578289882, 0.030032736847975423, 0.014408714869724852, 0.049065800184117894, 0.048407349802021465, 0.023533567287293927, 0.026648138017792786, 0.03462194398577724, 0.04228754747392876, 0.02442123188770243, 0.034165690253887854, 0.01941177578243826, 0.027863891263093268, 0.017413571576720903, 0.0245299620354282, 0.018845840257459452, 0.04273402690887451, 0.0440828391749944, 0.01658160113064306, 0.008829678658262959, 0.018498654244467616, 0.0315427079663745, 0.01592458924278617, 0.10100910453391926, 0.02577930615682687, 0.09419098110603434, 0.028084628882684877, 0.04770272850458111, 0.03595183191022702, 0.04924383080963578, 0.031997825152107646, 0.00833867714806859, 0.00923290487844497, 0.05818897153117827, 0.00995565323890852, 0.02716495778544673, 0.02888754615560174, 0.01819926593452692, 0.012951974823538746, 0.019236120029485652, 0.05048937004591737, 0.031898111038442166, 0.010011489037424326, 0.04712679137342742, 0.002638970480932455, 0.020299871252583604, 0.029698025701301436, 0.08993858857346432, 0.04371985347409334, 0.017653094438303794, 0.0329971918836236, 0.03438061622104474, 0.033243676514497826, 0.044510095712861845, 0.02754505105050547, 0.07354233946119036, 0.03415932220273784, 0.019097215429480587, 0.029871316759714057, 0.01129747913884265, 0.03567103037078466, 0.013929385858188783, 0.018486752740240524, 0.04005659557878971, 0.03666012408211827, 0.03022943397185632, 0.06853809620120696, 0.05625910597986408, 0.012045172991098037, 0.07882962003350258, 0.019378809158557227, 0.044220503752252886, 0.04757908585348299, 0.004199136863462627, 0.052264611037181954, 0.05854396069688456, 0.012211129934127842, 0.011841654045773404, 0.014052716383178319, 0.01207115494513086, 0.04994564636477402, 0.038151740828262906, 0.016449444561398456, 0.0761015224935753, 0.045458395898874314, 0.03777827176132372, 0.024055757659620473, 0.008164608318890845, 0.08053183369338512, 0.03569742877568517, 0.0663559479372842, 0.05522796006074973, 0.04718001226761511, 0.020873545469450097, 0.02945398718916944, 0.0381141432028796, 0.0503287065242018, 0.06041675127510514, 0.05141219463465469, 0.08648656880749123, 0.05557861678036196, 0.017609071086293886, 0.029912378306367567, 0.022474589558052163, 0.023659118318131993, 0.030956558883190155, 0.014022495281616492, 0.027631827197702866, 0.06199991596596582, 0.021897917912740792, 0.03327191714197397, 0.0045256101709258345, 0.05658189526626042, 0.0165199324754732, 0.019462704924600463, 0.09718151563512427, 0.037803011148103645, 0.03222846259762134, 0.03156537442867245, 0.011035161741477038, 0.02645502864782299, 0.049446278517799716, 0.0236194036634905, 0.012091330335741597, 0.015605223165558917, 0.020432365392999988, 0.0411621733967747, 0.021402814658358693, 0.04491216163816197, 0.01528628626173096, 0.025189984922430346, 0.013666400951998574, 0.08830989418285233, 0.03859881737402507, 0.0843886945928846, 0.043853535050792355, 0.01787119934202305, 0.07338722635592733, 0.03186780087915914, 0.013491260037491364, 0.024781142128631473, 0.008519596636428364, 0.04933164341907416, 0.04105135505752904, 0.02242383174598217, 0.03864359050723059, 0.013537797361745365, 0.014711270241865089, 0.009581210474217576, 0.024040091982377425, 0.05805935098656586, 0.015089207461902072, 0.04368278171334948, 0.071031061001122, 0.028367917252970592, 0.002954995409319443, 0.04704761312210134, 0.030528793444058726, 0.08746497559228114, 0.01611292002988713, 0.030538985040038824, 0.041575787988092215, 0.049330028505729775, 0.026727674196341207, 0.09570776471602065, 0.055599332454481294, 0.047799864185175726, 0.018361680076590607, 0.027608960567574416, 0.010725016106984444, 0.07401840641562428, 0.02097127995719867, 0.050631909897284846, 0.018034933234698007, 0.0384573326446116, 0.03361993096768856, 0.03199955202373011, 0.038609215923185856, 0.04494153202644416, 0.07151425935860191, 0.04064840364402958, 0.027711149637720416, 0.009204296145721205, 0.0579672602138349, 0.020825819012575915, 0.023840360110625625, 0.04417108604684472, 0.03399980201252869, 0.04442494296069656, 0.03804771801722901, 0.010040572744661143, 0.0155471219082496, 0.03676717315933534, 0.025764347852340767, 0.06276741371090923, 0.04343596460031612, 0.04541338527841227, 0.10673187566655022, 0.05705580447933503, 0.05898861147995506, 0.005466870556119829, 0.09731119724788836, 0.03064927412196994, 0.06411615812352725, 0.01750295329838991, 0.02010922666106905, 0.053936266872499666, 0.041306789565299235, 0.03643871132018311, 0.023037938168272376, 0.060504424784864695, 0.031822159221129756, 0.056946919964892526, 0.047582760120608976, 0.013887192006222904, 0.030000866058149507, 0.014927585509472659, 0.02431124814652971, 0.03026509777243648, 0.02070324675046972, 0.03499618318996259, 0.04035039784918938, 0.03394334789897714, 0.021361502053748285, 0.16145553493074008, 0.07840003272784607, 0.11759929252522332, 0.05855766710426126, 0.10152599215507507, 0.09337887646896498, 0.09940297143267733, 0.12920498262558663, 0.14900190675897257, 0.16320891013102873, 0.061115153799099584, 0.06403928010591439, 0.08868557188127722, 0.10321327125919716, 0.11701564384358269, 0.13466914370656013, 0.10687554867139884, 0.09859148426247494, 0.16951932651656015, 0.15178854151495866, 0.1524261473012822, 0.16110307670065335, 0.14361482725611754, 0.08266420462833983, 0.1384555726711239, 0.14572276414505073, 0.13818869127758912, 0.21099019263471874, 0.13698510586151055, 0.09225278653736625, 0.17553471587598324, 0.09920272217797381, 0.1560190852199282, 0.23106334837419645, 0.12275391950138978, 0.2244447956659964, 0.1650554889014789, 0.09970466845801898, 0.1359288032565798, 0.1613305759217058, 0.18300196661480836, 0.13057087361812592, 0.13090943545103073, 0.10047511104494333, 0.101702241626169, 0.15281912764268263, 0.11695723554917745, 0.1142252500035933, 0.13968919004712785, 0.1324465615408761, 0.1804157303912299, 0.1576379340674196, 0.14849889517894813, 0.10135219219539847, 0.17156232760420867, 0.13294341202293122, 0.11093364270137888, 0.08169047294982842, 0.1346620733716658, 0.09023375130657639, 0.1767682246863842, 0.10121357427643878, 0.10006364062428474, 0.12109287934643881, 0.12332515099218913, 0.05159697329093303, 0.09974064438470773, 0.16476088256708213, 0.10880862708602633, 0.1389227168900626, 0.09720898951802935, 0.20323330243783339, 0.09920167723404509, 0.1569547171571425, 0.07625088840723038, 0.06930322585893528, 0.06348818074911833, 0.19031380569296225, 0.14600158775491373, 0.15435572447521345, 0.09962667764297553, 0.076006690439369, 0.13779431315405027, 0.1273682290422065, 0.16002370390508855, 0.1440602583544595, 0.14253183108355316, 0.1444474168653999, 0.1415612953049796, 0.22180773716952118, 0.06732830897505794, 0.09026508605373756, 0.09774701350501605, 0.06388331204652786, 0.12937126441725663, 0.20879575610160828, 0.09284506618444409, 0.07030895046357598, 0.12569956215364592, 0.09548200254461595, 0.07975885338549103, 0.10477738947208438, 0.154789715473141, 0.07855439944458859, 0.19888271231736454, 0.11350760422647, 0.11242973777864661, 0.07147479576191731, 0.12609685797776493, 0.17640115081199578, 0.24260460478918894, 0.09211437217891216, 0.11552931288523333, 0.1342293308781726, 0.07710519113710948, 0.1473717942301716, 0.11555469009493079, 0.13278087574456418, 0.1394015997648239, 0.1119863965681621, 0.1562142183205911, 0.09244470338204078, 0.10969115008733102, 0.1199089985873018, 0.10454230422952346, 0.11893755357180323, 0.17239072386707577, 0.07371406988906008, 0.14622720064861433, 0.11753973072128636, 0.05993220263293811, 0.11470728128084115, 0.10431367185498987, 0.16261661691325052, 0.1322631263839347, 0.10698266220944268, 0.15199120635432856, 0.08390980493277311, 0.11365878861397505, 0.15069221891462803, 0.10496227669396571, 0.07557020243257284, 0.10737174097448587, 0.07455979593630348, 0.18915342938687119, 0.10022377488868577, 0.1335296934204442, 0.10547490990055458, 0.1259767844208649, 0.15697187052241393, 0.08458154781588487, 0.20931387187114783, 0.08782666189862148, 0.19951493053564004, 0.10059501496808869, 0.2957968647990908, 0.10294906329363585, 0.17133465196405137, 0.13035564231021063, 0.09791985673031636, 0.17368623720748083, 0.11996972747147083, 0.14103243154074463, 0.10113246220030955, 0.15411088189908437, 0.14268964475819043, 0.09159925553415503, 0.10183805041015148, 0.17233861237764359, 0.13979912629084928, 0.06751052276896578, 0.16585568524897099, 0.12580586144966738, 0.09368099418601819, 0.05885517756853785, 0.14211755831326756], [0.015057418096278394, 0.017881759043250765, 0.021147941638316427, 0.1268428936600685, 0.03550443984568119, 0.023168483216847693, 0.03918025742417999, 0.02483582865845944, 0.03672229146052684, 0.05496263251240764, 0.033525054808706045, 0.005851374298799783, 0.022972354366044914, 0.04387578421405383, 0.04464944644964167, 0.013429728785662778, 0.04760705167427659, 0.009487672725559344, 0.01864049181209079, 0.0760423813813499, 0.044255862212074656, 0.032117474624621015, 0.015229745634964533, 0.03086698886805347, 0.00517678792987551, 0.027094001682209115, 0.01690872116679592, 0.0453491619388972, 0.027921368268185427, 0.012962707551196218, 0.02353913805979703, 0.010818273111778711, 0.06308669836393424, 0.008087594594274248, 0.010812302003614604, 0.008980308343390269, 0.026317323358463388, 0.0034721130962550107, 0.02057394850999117, 0.02615504153072834, 0.03494667388232691, 0.0689750388264656, 0.005732021261272686, 0.01282530845076378, 0.053375115019402335, 0.04870512828763042, 0.04789627044062529, 0.016322706094277755, 0.03600179922900029, 0.023750455916992257, 0.04735217017254659, 0.03705037332006863, 0.04761176070730601, 0.05102772651506322, 0.04181638972035476, 0.0410160305244582, 0.05656847384359155, 0.04344292636960745, 0.00876369621671204, 0.0316030025881316, 0.012554010642426354, 0.02248627393107329, 0.04820233044613685, 0.035058930715812106, 0.04655435887564506, 0.014795998909643717, 0.051744076290300915, 0.028321110211046677, 0.04142809466325811, 0.022763587800519805, 0.0351447823590466, 0.053886262234300375, 0.024158201180398464, 0.01092685737447547, 0.027510586560570767, 0.0341506064204233, 0.04616753963221397, 0.034035866148769855, 0.025266016467607448, 0.019592559563794305, 0.03264543593728116, 0.024786107308630432, 0.018124803501580442, 0.03688300587236881, 0.010030858667700418, 0.018987240169995596, 0.029090906493365765, 0.02353764189008091, 0.06186390362147774, 0.0678351746339883, 0.0524534032280956, 0.039397853426635265, 0.04060191381722689, 0.043529012107423375, 0.037396402430853674, 0.03198756570262568, 0.02272998505005879, 0.014506897190585732, 0.015126967935689857, 0.03745749433125768, 0.04175284491585834, 0.0631603669109089, 0.01059679249634168, 0.037513565072523694, 0.0341447845899633, 0.04287926732961621, 0.03361879102885723, 0.058136249360229285, 0.016286541874121343, 0.02554877388424107, 0.057724086833851676, 0.045687526996646605, 0.021838758140802383, 0.02877386100590229, 0.04256257128768733, 0.03177110624632665, 0.0070785324455105835, 0.022098472508202707, 0.04814153370846595, 0.02920787575255547, 0.047730663791298866, 0.03195830048727138, 0.027870237261855176, 0.03224456762628896, 0.05350011134786265, 0.0376219508637275, 0.014700866603691663, 0.05502058279567531, 0.026109606825879643, 0.030754287594131062, 0.04859620984643698, 0.11264670613620963, 0.035360325793070455, 0.020912104918222343, 0.013686483044044247, 0.08460043144545384, 0.019787122695041553, 0.03859480383938976, 0.022299536004928604, 0.028200124024546573, 0.024505529685744216, 0.010462308551983109, 0.0338930650614202, 0.06452426979584353, 0.019797860511711667, 0.01598622227486755, 0.04752674026946936, 0.0036139843785869224, 0.021738597890362144, 0.044874981311815124, 0.018155576761013696, 0.016893274317096387, 0.09685096051543951, 0.025099025606842976, 0.021341106987425258, 0.06202464856739555, 0.10226674204958336, 0.03251044139532106, 0.055855703340577226, 0.04177567422656076, 0.04174370165648205, 0.01471038136099066, 0.020315659066130008, 0.009555513504892588, 0.016668682618598853, 0.053069730156234333, 0.085360933494355, 0.025456498210717524, 0.01888380429175283, 0.07829352308596883, 0.033400740407939465, 0.08072760461696557, 0.025451046181842685, 0.02503831368604941, 0.019894366851076484, 0.11434277226882321, 0.0769198357260653, 0.056862659486276765, 0.009972002540182854, 0.041202627654586516, 0.008376904962850469, 0.026114551649828042, 0.030950679377253567, 0.024458742999870862, 0.028718638433409587, 0.03189183798219476, 0.059397557750344276, 0.02985042127381478, 0.06389125769159623, 0.013456106834512736, 0.04334288316645792, 0.0657295583348189, 0.0007638938228150696, 0.0288224034011364, 0.015732953990144388, 0.011983685844045664, 0.05366005562245846, 0.027886572992429137, 0.04911014584026166, 0.04270542665783848, 0.03341313385005508, 0.009930981705630464, 0.03621700339551483, 0.03461109081815396, 0.01102168349150036, 0.034170972649008036, 0.009786418971738644, 0.015745685003431778, 0.07388776806848389, 0.016628224968111942, 0.008242264107268835, 0.044034249282308986, 0.015784290253317783, 0.011822715285234153, 0.03719574944781406, 0.02759097938958023, 0.05914188575531755, 0.058020470929997306, 0.021773617082674588, 0.027259160498423234, 0.048639364673623016, 0.026373782561027577, 0.03000726125070027, 0.04063690247546349, 0.07073197633560215, 0.07088926075292484, 0.02621297654695809, 0.05983308223741395, 0.009992253417814416, 0.00372524673418541, 0.06762093398720026, 0.028403365618682334, 0.12460873568696634, 0.027868374683228985, 0.025475875474512577, 0.030452716097767864, 0.022558156234611357, 0.03662152561758246, 0.0343504180200398, 0.016175279094438468, 0.02459345934247332, 0.05697751510888338, 0.020547904639637897, 0.03295266641569989, 0.062135731535298486, 0.043259250332734416, 0.013110467033194644, 0.013894790750262993, 0.04659276735037565, 0.019025060015597513, 0.039981081416564326, 0.030255296334092106, 0.021986756806394885, 0.05203841460336532, 0.04816491263253348, 0.04444716837523239, 0.02840795930075858, 0.03252083655180676, 0.010194520466029644, 0.02705783406937761, 0.028588994140071527, 0.01729664472596986, 0.04952877480536699, 0.017717475537210703, 0.009441975088390921, 0.023131535288744738, 0.05207315898899521, 0.05776338079678161, 0.02543073084338435, 0.03998222814074584, 0.04131442986960922, 0.02491500860612307, 0.01542207638600043, 0.011267520969600549, 0.02612917747215501, 0.035543638813708506, 0.04316317655944398, 0.03920691027971251, 0.021502834112782563, 0.042123599842722924, 0.05821281525173357, 0.016172398713284304, 0.010910454638568419, 0.025932127510064414, 0.030857095827481577, 0.028707873475338732, 0.037120204751512835, 0.04949405416846275, 0.028056279689605747, 0.014999537362850137, 0.031843444864664755, 0.025701713981106877, 0.007461914060903447, 0.009133385843597353, 0.021477053174749017, 0.04118257694478546, 0.029967265004026036, 0.015649005637637207, 0.046241499949246645, 0.02016475796699524, 0.01742489802251969, 0.02552350693648415, 0.019651595503091812, 0.0076932359786172, 0.034264546020754745, 0.03571366611868143, 0.07544181682169437, 0.03442705176504595, 0.033084156324288676, 0.028076072556099722, 0.02318502250792725, 0.007728774250218911, 0.03240008445988808, 0.08702778190906559, 0.04125195715044226, 0.05141230320025768, 0.03262574485103999, 0.016217053102861558, 0.045581624643611054, 0.0323031828738749, 0.031639236358127425, 0.052006577740290334, 0.036657525292996845, 0.011237375355059547, 0.017609496867018085, 0.046195386709379296, 0.023744562840355293, 0.0541467552206346, 0.0518133140036038, 0.06116651890001126, 0.03183673754600542, 0.031653248106262515, 0.012561812946972038, 0.02834433307205992, 0.08070732320525817, 0.016185043213356818, 0.05826047555144344, 0.0180557201549943, 0.06923493130930833, 0.04838472405182464, 0.020631854688482623, 0.04307506539459739, 0.04499953659251332, 0.020288934964420538, 0.009265521208622625, 0.03396009414323738, 0.0044785431652729, 0.010257305311305183, 0.018259355299440876, 0.02262823363499982, 0.027429162358332957, 0.030630780650036674, 0.21637158601411752, 0.17965684325567313, 0.11141029998127903, 0.2003664512719427, 0.07827060217303888, 0.14183540988181317, 0.10992177735481944, 0.13320367091468402, 0.12174712281141963, 0.1595621101026024, 0.1577953677624464, 0.09937191488487379, 0.13567750102707318, 0.08096934628805944, 0.15247322406087602, 0.09361265213893992, 0.045862802769988775, 0.13503700468157018, 0.0727013156616262, 0.18399246489363058, 0.12989189076636518, 0.25401628815702026, 0.1709491897906576, 0.07529314301375832, 0.09218165571136133, 0.10500361983265195, 0.09754044708928891, 0.1354350604649101, 0.11792652282331671, 0.11347866470792464, 0.08447234438998358, 0.08804425450840167, 0.19761428609490395, 0.08277680072933435, 0.1465434386794056, 0.17526582601879323, 0.0781285712229354, 0.09593575248228652, 0.10995566339365073, 0.1316166046474661, 0.1436316684952804, 0.13770058032657417, 0.09135197701730899, 0.13530926007245267, 0.1883742676249572, 0.158502034842968, 0.18494598301393644, 0.097506065719894, 0.19377395430845873, 0.15311890441392148, 0.07481842634401151, 0.09241389110684395, 0.15039089508354664, 0.20666077280683176, 0.09531495400837489, 0.11001022439450026, 0.19865077547729015, 0.1456546935119799, 0.19698497200650827, 0.1541170294263533, 0.09676575008779764, 0.12650688311883382, 0.139875963596361, 0.13450533178235802, 0.14487542318446295, 0.09736401441373996, 0.23228001594543457, 0.12410568339484078, 0.13282970312450612, 0.15241632211421216, 0.12218627067548887, 0.09318062210721628, 0.13199948838778905, 0.11316453692104135, 0.13085245208016463, 0.19714818681989396, 0.07086741871067456, 0.10012815573385783, 0.14183889755180903, 0.09266661147453956, 0.09119356623185532, 0.1105596274137497, 0.10531319464956011, 0.12134650216570922, 0.11722991163177149, 0.1042243427197848, 0.07839471301329987, 0.09652427304536104, 0.18113949655422143, 0.07891881346170392, 0.11652499517159802, 0.16915103127913816, 0.1391920002975634, 0.13809866325131484, 0.12665863069040434, 0.09212609047868422, 0.08401083201169968, 0.08128120776798044, 0.060653152875602245, 0.09335945001138107, 0.099965008773974, 0.15148622702275003, 0.11119624253894601, 0.1479540044175727, 0.13414205770407403, 0.07975952513515949, 0.09738120849111251, 0.10977686263088669, 0.09633810339229447, 0.06877247576734849, 0.10204177376415048, 0.12287361307867936, 0.1206829763416733, 0.08729359121727091, 0.13933134424899304, 0.12177167220839433, 0.13988048263958522, 0.07842036842235497, 0.07109407654830388, 0.18341166605906828, 0.14080299170953886, 0.17211557791701385, 0.1453003625252417, 0.07964797397809369, 0.15908383790935787, 0.20127468396510395, 0.09728793706744909, 0.1101975068449974, 0.10984158808631556, 0.12996696388082846, 0.17271694993334158, 0.13484857550689153, 0.1036168842443398, 0.14692074486187526, 0.10314523455287729, 0.1719865205564669, 0.10184429293232304, 0.15791921397405012, 0.1069308424900685, 0.2230735035347087, 0.12503577848630293, 0.06537480665636913, 0.08488684107682534, 0.1645792116011892, 0.1453027781099081, 0.15552467746394022, 0.10448667792869465, 0.09331288893840142, 0.1195383013359138, 0.11292573330657822, 0.1175733453461102, 0.0711368853226304, 0.16431983480496065, 0.11595163308084011, 0.25803506108266966, 0.10020657402596303, 0.17303242800491198, 0.12666952796280384, 0.17280655726790428, 0.14885843731462955, 0.11754251271486282, 0.07518488275153296, 0.1488909934248243, 0.13284233744655335, 0.1472411083855799, 0.18347429484128952, 0.18944783216076239, 0.10073770409716026, 0.065549380145967, 0.14967242149370058, 0.11373492702841759, 0.19158924796751567, 0.09536249895713159, 0.1147728141929422, 0.1029461252370051, 0.1928474690232958], [0.050476240393306525, 0.02259742814515318, 0.09727041729326759, 0.05763580942792552, 0.03630306877728019, 0.04538855768207993, 0.009973578437763666, 0.06107221610311951, 0.02273366610253496, 0.04527753917500377, 0.05431547973837171, 0.0806247658495392, 0.07010920332478625, 0.03243156848475337, 0.01336472004186362, 0.047073482269687314, 0.07147793737905365, 0.09372397259409938, 0.04712182449709092, 0.060522012412548065, 0.06916821774627481, 0.03669760635654841, 0.053325330905084095, 0.016227015693272864, 0.07829127713505711, 0.003952793452689158, 0.009211159527434834, 0.03163542299132262, 0.02418908809444734, 0.021862842741289308, 0.023327338442738568, 0.015869902712958198, 0.03145491571298667, 0.022222474782860706, 0.02956042219219463, 0.007131444606264787, 0.04494238358789256, 0.014013293498594846, 0.04923097596370748, 0.01554760366811284, 0.026376379653811455, 0.028876309615692923, 0.05635186850226351, 0.0230292647943965, 0.035800871439278126, 0.034805474137621265, 0.01815468448746417, 0.00617340998724103, 0.02546422163556729, 0.032723023023988516, 0.03236109244504145, 0.023074529865490537, 0.010647803910874894, 0.03685071099815624, 0.01703264032091413, 0.02391127380542457, 0.07290220273924725, 0.01574053492264024, 0.006061252813586699, 0.03765000828674861, 0.04658971394279173, 0.01941698693138148, 0.0343496139560427, 0.06828529440930911, 0.019733184250071645, 0.05278010426887444, 0.03154933046815651, 0.026394637334825735, 0.03219117031299642, 0.029691762823079313, 0.05673253343307546, 0.0787117313593626, 0.031246652959712913, 0.009227107644879391, 0.04009361984208226, 0.01645317141498838, 0.024956536645601903, 0.049112910870462656, 0.0009713791763975418, 0.0476735141793532, 0.07423694218908038, 0.015184246469289064, 0.03211325413680502, 0.045116142835468054, 0.026173899715234126, 0.019509981852024794, 0.01959338568017951, 0.04882089314716203, 0.01744218709479485, 0.08259741642645427, 0.06853959576359817, 0.08102118636348418, 0.03698039600359542, 0.05005490407347679, 0.04369097163102456, 0.032911727005349736, 0.03668859201882567, 0.03858046639444573, 0.024181018616738062, 0.08362624514847994, 0.03554177284240723, 0.03530538481261049, 0.00761997200814741, 0.022935917035543492, 0.014351421069087726, 0.0367603674530983, 0.03065526219350951, 0.11123424049999033, 0.045412903518549035, 0.031270673099373064, 0.021260142492662584, 0.04011561794738684, 0.06705369228231055, 0.0753593680315784, 0.05146278281297002, 0.02948823963691081, 0.10308928255523954, 0.047614257716174634, 0.03433189740670579, 0.027472529227712324, 0.03738799877464771, 0.025296801601403525, 0.03891901804932526, 0.019073354745549814, 0.07040046448154108, 0.06338892464659043, 0.027244897692331245, 0.02276432910002768, 0.018940239745591367, 0.02323261834681034, 0.008658262901008129, 0.05084271037152835, 0.11712560722870485, 0.03851263664130654, 0.005418112301932914, 0.026791140969310488, 0.04674206541052886, 0.06902974231966905, 0.10397660958447627, 0.02539075325642313, 0.03577660024166107, 0.03244934270956686, 0.05719286176775183, 0.06354083506656544, 0.035282837093940804, 0.030631588106708865, 0.031806613983852525, 0.035214593434440236, 0.042438674185957224, 0.0038137056482290582, 0.04645088228530117, 0.04197632720960038, 0.022216074501297305, 0.005217138287012598, 0.029241609121007577, 0.03662599377068026, 0.08760026190429926, 0.012526669073849916, 0.009596793030920838, 0.0815468542277813, 0.033901322832597156, 0.012755370998222913, 0.04133996992771115, 0.08033737912774086, 0.018965762840317826, 0.046649157003100426, 0.0139470990148506, 0.03567520336114934, 0.05602406823475446, 0.024267111139904176, 0.039930347353219986, 0.004217221093962767, 0.011585689432519888, 0.02352337060230119, 0.015387057193687983, 0.05935449113271066, 0.023472382088324854, 0.037762923299201896, 0.09256732144526073, 0.05169890960678458, 0.05280430082763944, 0.03252051764034799, 0.057499369606375694, 0.07546355708369187, 0.026314726265679513, 0.01810771968614842, 0.008051533002539404, 0.020286510898066417, 0.07667640450277499, 0.047033859217273336, 0.031709220459950824, 0.04141497179599745, 0.018507685545565825, 0.03792147996968456, 0.049967976952237744, 0.019503137130024176, 0.01061717908097697, 0.030419386457651854, 0.06295914056577853, 0.034426139135445864, 0.05761746862637145, 0.04207383269178016, 0.022298823543159024, 0.034856269269117286, 0.02497435497519161, 0.018171661433630755, 0.03665538451501301, 0.03771215870178171, 0.023547767328896692, 0.04889246502092906, 0.04613068500267608, 0.04467235039919615, 0.013703286963781076, 0.02686870769996728, 0.09731682230319295, 0.004171493770887277, 0.04534077185339161, 0.02544782992585429, 0.018607608308749538, 0.041452230153871436, 0.009830840114903237, 0.02670274651609361, 0.02748845105192491, 0.010692158048706395, 0.07149400508829526, 0.07033595615731818, 0.012265061593747564, 0.015508472553587385, 0.01701121388136276, 0.048742071126720736, 0.023698183275493126, 0.04887178327356066, 0.046437179270599566, 0.010474061626674873, 0.04199989612347313, 0.026557877593274628, 0.03971406092335071, 0.014185970482815589, 0.0386455412954092, 0.04190963400261743, 0.0069319112060059395, 0.07957403401711158, 0.08719296447400536, 0.048117754448737414, 0.009135681836466705, 0.042389680564935715, 0.04048752299110804, 0.021075799795133725, 0.057975233000304015, 0.05331608586545501, 0.028469015578074113, 0.027673558797687292, 0.029395653533616235, 0.06255709499652896, 0.04442821689216154, 0.046175682052437744, 0.03955383166404707, 0.0627717427643282, 0.006452029188429671, 0.04638980734827263, 0.014406229735219052, 0.03939921049667256, 0.08334830363414117, 0.0317492438480258, 0.03326517928923879, 0.03609752016408103, 0.021154168893450072, 0.05472220041389976, 0.042785683779844215, 0.07698780457888331, 0.03104967424379928, 0.07226974024836506, 0.036364754395825524, 0.015941696806943843, 0.03981174960998552, 0.05420921776177628, 0.0013031552350314865, 0.06294848078063556, 0.04215421195008925, 0.029404148792049715, 0.029320895937936645, 0.020919120970315168, 0.046462207034762414, 0.11043066504810538, 0.028886616562626193, 0.019369864370673895, 0.01799325761385262, 0.07826473284512758, 0.00946743117778429, 0.04375017381140164, 0.013603590661659837, 0.028565584681928158, 0.003659611617747162, 0.05780303438327142, 0.031591677838670354, 0.006525272378764514, 0.04549015133774706, 0.03926824645272323, 0.045192250715834756, 0.022264694928058555, 0.07157023849764041, 0.06231950595974922, 0.06297335587441921, 0.025936375139281154, 0.04749542248568364, 0.04349618119054607, 0.02399897445658488, 0.03764548585084932, 0.030073014686682394, 0.016834175613309656, 0.05189261439123324, 0.013397373691467302, 0.025659137605024234, 0.007635189004109374, 0.04965996955122266, 0.018180485781548277, 0.013830904133750923, 0.0356465590053371, 0.028639677313289473, 0.029830597873244966, 0.010831004973234875, 0.0312633279577962, 0.06412485694246632, 0.09114594664424658, 0.0706571474937456, 0.028842352330684662, 0.042317881381937435, 0.02166343147733382, 0.02791774658752339, 0.01996159101171153, 0.018681168290121213, 0.043571328943861384, 0.06698261573910713, 0.016012064281052778, 0.04404221189075282, 0.027745222273681844, 0.054728008673659394, 0.05219994664990476, 0.02589759855930294, 0.027067671130810465, 0.028298197779804468, 0.04074430099821516, 0.02198685858664768, 0.05053530686667987, 0.005824678186659834, 0.03938451682084373, 0.043972567056438754, 0.020398857637441585, 0.08865582490605967, 0.06001978793314525, 0.05155365222266742, 0.041317961644381285, 0.09010463287787777, 0.16863679672990525, 0.2368922084569931, 0.15420289124761308, 0.10752180577921015, 0.12225185787039143, 0.12493325184498515, 0.2167692482471466, 0.13315321505069733, 0.10939786689622061, 0.13713837335152285, 0.20260457188955375, 0.14737121069005557, 0.08684513385274581, 0.12159815723342554, 0.16872158646583557, 0.16742451249488763, 0.18107069310333046, 0.13805256358214787, 0.11590614409318992, 0.17462478684527533, 0.10658254367964608, 0.1561608040439231, 0.17024164061461175, 0.2071442697197199, 0.1275921863104616, 0.11076501996389457, 0.11391382957143442, 0.10486893063145024, 0.12461466608302933, 0.07354641745665244, 0.057962347620299885, 0.11381466167845897, 0.12368276608841759, 0.06806639901229314, 0.1196509517197098, 0.12078399663524968, 0.1331322347479207, 0.20720692564334187, 0.1679379599434989, 0.11653387040964194, 0.09784708384956632, 0.1288180819579533, 0.13365459814667702, 0.12714827513056143, 0.16274944692850113, 0.11062731806721006, 0.06531362993908779, 0.22671999143702642, 0.11370036923991782, 0.055151696117328744, 0.08211758360266685, 0.13068000919052533, 0.19820727141840117, 0.17598674233470643, 0.07563942657517535, 0.10483133979141712, 0.09857832746846334, 0.06981203891336918, 0.09980011119374207, 0.08037010487169027, 0.10510715749114752, 0.08760575125260012, 0.13778143455939634, 0.10903897615415709, 0.16721978490906103, 0.12174980981009347, 0.1011317293824894, 0.12393368833831378, 0.14143957969333443, 0.14528114641351358, 0.0989162175516997, 0.1428887133619615, 0.14525506352739675, 0.14036668012184755, 0.06816256099513598, 0.10826696615133967, 0.1659149077853986, 0.14222084491380624, 0.15239243768155575, 0.15583307162991591, 0.18041076351489338, 0.07462842296808958, 0.16399263164826802, 0.10088941774197988, 0.1251991018652916, 0.146397146529385, 0.1486124547996691, 0.19047236575612, 0.14278906370912278, 0.1833480466157198, 0.15975337555365904, 0.08989470771380834, 0.12009308513786111, 0.18422381819358893, 0.09926308465323277, 0.1408397275954485, 0.09445847318108593, 0.1150760514927762, 0.24331744653838022, 0.12352882006338664, 0.1025992174233709, 0.05518972461244889, 0.09200518910906144, 0.11275403680545942, 0.12592185022575514, 0.19500154629349709, 0.33060288855007713, 0.12213903106749058, 0.133422457746097, 0.093033067882061, 0.21534246552203382, 0.12006998780582633, 0.11183601285197906, 0.11209897231310606, 0.12520083891493933, 0.15004964625196798, 0.12149123368518693, 0.12177224217780999, 0.07463128638586827, 0.10937073228082486, 0.15488853731325694, 0.1385812916393791, 0.12516541938696588, 0.1498819531074592, 0.18612377052860601, 0.185397330937641, 0.10296699697417871, 0.13017234286027296, 0.09250668077064411, 0.1256253711347069, 0.1453268661030701, 0.22971718917999948, 0.13581567789827073, 0.11672747002116271, 0.12497032699840409, 0.1655672128711428, 0.1153097932360002, 0.22434703234050954, 0.05750112022672381, 0.1556867251970938, 0.12247900425323419, 0.11165602465293237, 0.09443528763949871, 0.11536066979169846, 0.10324436851910182, 0.1750924467508282, 0.2152735535055399, 0.08687886382852282, 0.11777637659439019, 0.13027448952198029, 0.12230486502604825, 0.08216573244759015, 0.09161333513579198, 0.11366076315087931, 0.14350912507091249, 0.28625549535666195, 0.08709906879812479, 0.10068590473383665, 0.11733952217868396, 0.18443391977676324, 0.09804733310426984, 0.1317397587533508, 0.20264015426593168, 0.10124559434396879, 0.06390755610274416, 0.11275418608316354, 0.23963859251567296, 0.2474787389593465, 0.1451400654124362, 0.15196937109742845, 0.09980168539498534, 0.16137187156294072, 0.11311483423092536, 0.12778437456914357, 0.1431532741657325], [0.015019014710560441, 0.0411122230413769, 0.03411745659208723, 0.0481504462659359, 0.040575607014553886, 0.015074647796739424, 0.07344268980835165, 0.021859782548355203, 0.028321603845272745, 0.06039963183658464, 0.0611851786130241, 0.0072913320535527805, 0.07412465142884425, 0.04791597509756684, 0.042662268437977345, 0.07898381711649043, 0.08225086145102978, 0.06303278875670262, 0.027527856973132918, 0.029666986116873365, 0.01623378916909652, 0.04490206164440938, 0.04275648302531668, 0.02020944289064833, 0.009327809875165778, 0.03382631078628557, 0.08620517354990755, 0.03419068069862468, 0.03646776279700654, 0.027165254644517387, 0.047588188400758166, 0.016307103181523935, 0.09985010565391608, 0.00325956433412752, 0.05287768778258136, 0.03967439715883561, 0.05415633613509791, 0.045414850914052556, 0.03470931215477841, 0.04042556256588016, 0.05387764483956354, 0.038356736435421875, 0.05569904317547168, 0.009186352287153048, 0.03575672934363995, 0.04089729028886982, 0.027005122076453905, 0.05246915202587843, 0.08421452822429792, 0.027156163971605043, 0.06826143033270325, 0.0314353230143232, 0.03920950906883393, 0.03305291996470519, 0.008139935937444014, 0.07444912008941174, 0.05571151125643935, 0.04108445399573871, 0.033553112231727154, 0.028532041303281273, 0.016218062423701798, 0.03782920599249857, 0.048707347097141404, 0.027496028591745665, 0.02103405462444893, 0.04120370313259108, 0.016331728913688233, 0.007948469470388122, 0.05685062566772103, 0.06735559965350799, 0.03932636297707047, 0.045165723389280696, 0.06581926744963441, 0.017697984618800025, 0.025383426774559275, 0.02564248805200415, 0.03748446949092405, 0.06263500438737017, 0.00998826787274863, 0.024878218437411954, 0.00573273457121104, 0.02384945417621306, 0.05343498894944787, 0.04487530700862408, 0.007230596384033561, 0.06774716864206962, 0.0786621847323009, 0.04008946720776813, 0.044456253959132094, 0.03577412358884301, 0.07533358370086976, 0.06131159647234848, 0.03091036421912057, 0.02815233649952071, 0.030921040967639004, 0.005047916318289936, 0.06936007352279765, 0.006336164669067199, 0.025546907912939787, 0.02155538834631443, 0.09975884947925806, 0.010545437573455274, 0.054730495504502735, 0.055599556371037445, 0.09213861623512846, 0.04710108168157084, 0.06514777562447957, 0.032245809345373085, 0.031053273872073208, 0.07229525995041643, 0.05499576198469315, 0.08568671851285867, 0.049880350939929485, 0.0640675818015422, 0.05715535913727113, 0.03265733404883316, 0.07104451635054179, 0.04816842744393008, 0.018286271087293113, 0.054537676208253415, 0.0670223914619003, 0.06327654567680188, 0.03003159012379391, 0.032763972612363954, 0.023174505215138197, 0.05690106796100736, 0.046324820656861575, 0.0331305816902646, 0.060271870477923324, 0.06963006939206805, 0.05230120103806257, 0.007213879825680384, 0.010786219965666533, 0.040248166370604715, 0.06591949385723897, 0.07394580316862889, 0.09190632655684437, 0.03423896185787661, 0.07261146405445677, 0.03472810757479497, 0.015200044460860746, 0.0029212860016351832, 0.030660972065691437, 0.03962668596899935, 0.05017038734097566, 0.045117211528122425, 0.05065975697445018, 0.021511661853375177, 0.011643917066976428, 0.052312057598360946, 0.06275114922651223, 0.013635029733580138, 0.06655553901301962, 0.04238756014300244, 0.02568710851483047, 0.01547213869967631, 0.026427017025915638, 0.02035104127467743, 0.025285108746694665, 0.0014799067160181168, 0.03790596865915826, 0.07262311450072698, 0.04560952939625297, 0.04088597232475877, 0.03295817951272641, 0.03067043762920158, 0.05326815754441278, 0.027952982911041806, 0.04234652913042477, 0.01266510209201702, 0.054365514910646846, 0.026210052061027715, 0.03196950310042926, 0.021075365532721792, 0.03699784792427506, 0.026127703354826996, 0.033410691123987944, 0.037829409553004165, 0.017477082454466393, 0.02968387824616262, 0.08887135476938315, 0.048982051999441216, 0.01050989336467215, 0.03024395801393049, 0.05709546485117503, 0.004442755532051835, 0.05912474596074649, 0.02411421005880194, 0.04965429021311658, 0.04758906371093222, 0.016397538328809396, 0.029780627161796604, 0.04646936897188425, 0.06399124661194426, 0.00821632456167468, 0.02664331702648529, 0.021969632278861742, 0.03501184717086809, 0.02141205291263759, 0.029807619284838438, 0.047481023972587924, 0.15047909106527055, 0.060594520664640834, 0.014085437886283865, 0.04999324559633221, 0.04342269245535135, 0.06567837643836226, 0.021922526681529622, 0.02233927440829575, 0.014055653591640294, 0.010691432016236442, 0.03678553770961506, 0.032669442506240945, 0.024161154504067132, 0.02507576542640371, 0.009707871757979904, 0.035856860756341896, 0.03045777796900698, 0.12400754008974348, 0.050101339617477994, 0.005344850027800671, 0.03089754329994321, 0.022061894381684915, 0.04677582931305681, 0.054160346277058125, 0.021635453782177398, 0.011487694556957908, 0.021707794096853052, 0.022813300668661083, 0.05692486757678645, 0.09067549795976707, 0.035930624298219166, 0.014345555133851511, 0.013538976316340268, 0.023367115861869285, 0.03157065003844244, 0.05722772489700999, 0.0340209315930094, 0.026978131649749618, 0.01433081565690892, 0.014966945629566908, 0.042863372646804364, 0.04202672539811049, 0.03627883829176426, 0.014566126512363553, 0.043581768205123286, 0.04284439741500786, 0.05422746356842773, 0.05943474146936621, 0.025507563059883456, 0.02037089012031044, 0.03770356844844563, 0.10436499624380044, 0.07193346507847309, 0.013475464590426003, 0.037345183214970996, 0.03652957394453032, 0.040336114687046835, 0.027096759927059923, 0.009109208792714136, 0.0229519779594349, 0.07145901303738356, 0.02191609756222793, 0.06998416967689991, 0.010327311465516686, 0.01171725313179195, 0.049052595892654996, 0.03275883270959769, 0.08366512520504849, 0.06331666066710438, 0.0479455151196037, 0.0313043928971248, 0.013563623252723898, 0.03099626675248146, 0.02945525265697922, 0.034941252387527905, 0.01356048502826265, 0.038862852313156636, 0.015412303785394346, 0.03719990547480328, 0.06121199431696108, 0.021304075938782523, 0.03816596631492887, 0.03407222884041922, 0.0071589023739631686, 0.04080061940476298, 0.026116000322092856, 0.016594496688672473, 0.031995616520621946, 0.02506352635100484, 0.014694210175158722, 0.07547059349183526, 0.05783493909984827, 0.0180313963709133, 0.05214391662073987, 0.05148519482463598, 0.07515571253108126, 0.06913345639726945, 0.039635961542704275, 0.013897788178707873, 0.07726012782326766, 0.03883904251935227, 0.023217824587066258, 0.013151212212895709, 0.06347359903156757, 0.03573232922436936, 0.06620578135230712, 0.03301979388509478, 0.02018194695535515, 0.031081969118011848, 0.053123497271112034, 0.06410462981356041, 0.0035877742671540803, 0.033174771283354075, 0.0125922299755205, 0.08426869567483664, 0.023965139307879975, 0.029698066413402557, 0.004031313525047153, 0.028331103335533823, 0.017470059617023383, 0.002428786413344954, 0.009289325065245586, 0.0369935595829572, 0.03261321230924555, 0.013614738143847456, 0.03653125331870147, 0.04899165326995509, 0.07894265718225922, 0.025897350894021134, 0.009399879624002745, 0.020118147700226734, 0.032395039552024434, 0.029494522871183496, 0.006354013532732746, 0.024846274705071534, 0.034956946902509244, 0.06237971915730408, 0.04619094230500715, 0.029009919946214983, 0.027807313316900815, 0.024937266251072288, 0.018008546704160314, 0.02201580658688077, 0.04229688072311027, 0.012042480055242777, 0.032347019628754685, 0.02061046556835728, 0.011737628690233188, 0.014388346944802573, 0.0782092015392014, 0.02599389964182462, 0.12112017002488885, 0.0886706712522677, 0.10745119063981942, 0.16712286296699727, 0.23017335470233644, 0.08801446682108299, 0.11736390872725419, 0.1494411631886448, 0.11696411589426653, 0.0903784828260541, 0.2050507313438824, 0.07308221129434449, 0.15634622052311897, 0.18054408207535744, 0.08333160488733224, 0.20198131033352443, 0.09724614609565053, 0.15380252844520978, 0.11682061930852276, 0.13657750987580844, 0.13968005696577684, 0.19726494912590298, 0.10958323587796517, 0.1137338617284383, 0.10507219258163657, 0.27826476842164993, 0.20660646286393913, 0.19344960099884442, 0.24192256852984428, 0.11912108372364726, 0.11684145033359528, 0.12557233683764935, 0.15754292559410843, 0.08050416982067482, 0.1657230316528252, 0.140999916142651, 0.15970471102212155, 0.06867501099726983, 0.14655918069183826, 0.11928089229123932, 0.11014025206012384, 0.09969098919204303, 0.12836754827627114, 0.15111026433961733, 0.08968210912176541, 0.1473069262823888, 0.10678263008594513, 0.1899851911834308, 0.0885227709742529, 0.08696959753121648, 0.19909833717559064, 0.09710309734301907, 0.142692358898265, 0.26124054193496704, 0.19520738667675427, 0.10176983049937657, 0.09612820536962577, 0.15422064172370092, 0.18257553449698857, 0.06519782436745507, 0.14149048339043344, 0.1307322428162609, 0.15167338055159363, 0.09187909016119582, 0.09450616740754672, 0.12561866720872267, 0.17188750872654573, 0.0738572475633451, 0.20365887960152967, 0.21520793916923658, 0.14954381196626595, 0.1672655317400183, 0.16922860140247004, 0.15705649740993977, 0.11200980602630548, 0.09889506761516843, 0.1514956315181085, 0.1356703492679766, 0.06944732634084565, 0.10267677397600242, 0.15941543797297136, 0.11632326671055385, 0.12641931138932705, 0.11477157925920826, 0.08703337982296944, 0.1567512923585517, 0.1508943002138819, 0.11883242135601384, 0.09470725804567337, 0.18819102245782102, 0.1528304320360933, 0.1671211937708514, 0.1593141055532864, 0.14457720704376698, 0.10321213810571603, 0.09139429046107189, 0.1588029922651393, 0.12385808596653597, 0.08300169437591519, 0.08161890786141157, 0.17539149070424692, 0.12985442206263542, 0.10591107221054179, 0.1393273544630834, 0.2637300326355866, 0.1261735867176737, 0.10312681911247117, 0.14356240364057676, 0.14725303703120776, 0.1541928489293371, 0.1032088336401752, 0.2083564725305353, 0.16680754774383136, 0.14174595182495459, 0.18770293864820684, 0.1539090041603361, 0.19751516569937977, 0.15403348819485732, 0.10867047057087932, 0.20359874782817705, 0.1607553003621953, 0.20503129810094833, 0.10550873487123422, 0.08271767997315951, 0.09142848862601177, 0.12829053455165454, 0.11526338144072465, 0.08823058022452251, 0.11451600225908415, 0.1260984321790082, 0.17252354031162603, 0.07032604954604592, 0.0892161794805101, 0.10066856816411018, 0.20565994722502573, 0.10021765450281755, 0.14278632242764744, 0.13466585959706986, 0.13065107645733015, 0.08361233518059764, 0.10794570696141038, 0.14876912853547505, 0.08256825977670294, 0.1771400754473039, 0.10649470732148204, 0.09338362621409552, 0.12050446734896728, 0.14973196972693714, 0.12645192178232328, 0.09447183353560311, 0.15579611861280032, 0.10429677633302552, 0.21588751913181373, 0.15056077311081545, 0.15363605666373456, 0.08851493389478751, 0.13380261377564498, 0.17499533481895924, 0.08788313636822359, 0.1317694243043661, 0.12001391367188521, 0.17898544642542089, 0.12521206188414777, 0.10361780705196516, 0.11905773569430624, 0.10045681774084057, 0.21468841204685823, 0.1249035998646702, 0.098811947075384, 0.04527574784255453, 0.07475198419498545, 0.1022165711703045, 0.07364439791334526, 0.11896972970238753, 0.17374026216566563, 0.11074334755539894], [0.009533445001579821, 0.04020292844091143, 0.0635888007070337, 0.024130623820903044, 0.019856072030961514, 0.013167280770306076, 0.04350890711482082, 0.04207788354584149, 0.06471607807491507, 0.054747296031564474, 0.05133196126137461, 0.03175278240814805, 0.013619143532456031, 0.028257500945723484, 0.012006392170275961, 0.010401733186362045, 0.08387872124356882, 0.04142744326964021, 0.012067479829836105, 0.0574749152043036, 0.0321166264558477, 0.05634225026837417, 0.002040880877757445, 0.05022487709564822, 0.03368501265400222, 0.0809273449704051, 0.06118656960981233, 0.02827560426002102, 0.041331430564501455, 0.07181303868336336, 0.07732943339007241, 0.04006882617250085, 0.044762846614633284, 0.03932819162894573, 0.059277416339942386, 0.009547766331317169, 0.07932249430034842, 0.038137783362929306, 0.023928466186459576, 0.026533616573682854, 0.02900466469249555, 0.050038293536220274, 0.0959980148555977, 0.01754409626924566, 0.022797344917697564, 0.08994613388287169, 0.07108621911278792, 0.03113885410130024, 0.020476354818258966, 0.028587406368127892, 0.008042760392917054, 0.002994069696537086, 0.0396706380748323, 0.014721226046926208, 0.034333013596811464, 0.0657621890838657, 0.028340037945391874, 0.029660061667008058, 0.03797990862014038, 0.007783607513244663, 0.03886173951572605, 0.0041516063335750785, 0.048129547387361526, 0.03565159373517547, 0.02042600412720016, 0.03468265590657081, 0.037010326183268, 0.03335158733118858, 0.014891769038513303, 0.015929817355104854, 0.03498932998627424, 0.019578235689550638, 0.07804078236222267, 0.031477938406169415, 0.05707147863826581, 0.009886256069876254, 0.034143681970558, 0.08790800467665706, 0.03444957234231489, 0.01798523054458201, 0.0344172876461276, 0.011503219438184584, 0.02136195158319814, 0.04981877727966223, 0.04126346171168344, 0.010149095939206225, 0.026496931577899625, 0.005450562391031001, 0.04892187272863729, 0.06760359741747379, 0.018422025588474104, 0.01648734413486506, 0.03031064782823835, 0.01272361386301262, 0.08981050830334425, 0.018334168874259506, 0.03136065362819603, 0.02310044481419027, 0.04018163601202624, 0.014758548865626966, 0.002617470038655613, 0.04212263971567154, 0.04995499997000609, 0.008669845493776458, 0.018027359087552344, 0.03962491838527577, 0.055085885005870035, 0.045907341808612855, 0.017199585380564843, 0.034964135981031826, 0.02800982039687889, 0.045863983420921225, 0.027322108192103248, 0.029720665022198643, 0.019530035954500948, 0.023555772345779196, 0.015006164953644787, 0.014723336290834206, 0.01593158663516598, 0.007049475031505738, 0.047505648008414676, 0.06189329775848559, 0.02672440874656396, 0.02816920488008431, 0.03033360606059432, 0.04184832497100745, 0.03587836353108287, 0.03351999972281711, 0.04877968571547951, 0.022657921238403236, 0.07088519632816315, 0.011026559613778122, 0.0660195845578398, 0.033267411669450145, 0.03427198276455913, 0.011267298749381942, 0.018094774934330156, 0.037229269077735286, 0.02699759542675955, 0.0192187003392194, 0.02675407938659191, 0.025036568154713938, 0.032368440979293416, 0.011572204397193022, 0.05139470539454903, 0.032148364931344986, 0.03537099236356361, 0.03438598004036716, 0.051941926923713515, 0.02437954948150686, 0.04896666621789336, 0.016849826023514782, 0.10055169050714799, 0.016658424865454435, 0.060024239122867584, 0.10356822649815253, 0.043692946167928834, 0.026399020671046207, 0.032870570463793616, 0.016471549535968473, 0.05143870499783328, 0.04140748755474176, 0.04632582828136427, 0.04305666691756674, 0.01588989744362022, 0.00628767189170633, 0.015326021272423012, 0.035385692824742625, 0.02665509469807148, 0.04158823910568442, 0.035734568389930894, 0.031200780599777187, 0.017767018771597316, 0.05327646281304104, 0.03961398718612535, 0.05993759698633637, 0.06038861242788179, 0.04403919240991984, 0.062234573731465, 0.02528792805969715, 0.03979193978011608, 0.044173152185976505, 0.013995434456904019, 0.048275910783559084, 0.02790808255252029, 0.020806253455313187, 0.06375618172543389, 0.06361461217914309, 0.025779263748388206, 0.03247540523963315, 0.08795259799808264, 0.06232717340545995, 0.027421511875997697, 0.03577915492600628, 0.03319064900279045, 0.04566725576296449, 0.042717138172260354, 0.025588653083624582, 0.009025706576981714, 0.06452414087418999, 0.052734774736953635, 0.038422065787017345, 0.05755537588681493, 0.0032301023436178055, 0.03149618421282087, 0.016848297623385276, 0.0178286009135523, 0.0195858098366963, 0.02098531715039696, 0.014314934544797455, 0.02276352503603058, 0.028748667000659874, 0.06894691354994263, 0.02707317574614925, 0.036650736550135274, 0.055092507507652044, 0.04414290988019534, 0.03857281591211047, 0.02846177900210023, 0.05251446459442377, 0.014060970761680176, 0.026339294322367226, 0.02770833371739302, 0.018296408400471722, 0.007594402264138418, 0.0013291711158152403, 0.04751059452870062, 0.06258674019149371, 0.06768816323684794, 0.05082914645650557, 0.03536003402301243, 0.034819190723023245, 0.04328535018222673, 0.018276009941473603, 0.04757791877325092, 0.06604087020137481, 0.023772699991241097, 0.03909264498257211, 0.0577539966574737, 0.026872836585555757, 0.027255947635109936, 0.051693773096693416, 0.033430036157369614, 0.06751546928925173, 0.058999943014766486, 0.034432198453162394, 0.08261014574340411, 0.058499686286917756, 0.06398941456739392, 0.02484150630022798, 0.014676327384742243, 0.03879671211221388, 0.04013201813878758, 0.07950627551014934, 0.013691387155891528, 0.016844703084123985, 0.01606523598145161, 0.004655977104058755, 0.035050842578389814, 0.012737660386067415, 0.037424575204827955, 0.0225423446723393, 0.02942748021866594, 0.02790941248115684, 0.019382736179977655, 0.019248981660764133, 0.01963799087596791, 0.0678015939359154, 0.029346595451767956, 0.03707462076896003, 0.06826576617147241, 0.010774652639936124, 0.03350257155086313, 0.013616167308230485, 0.027901283631633435, 0.0032090219569259454, 0.026436918548175266, 0.018148499640769193, 0.031154545223606483, 0.008258638005437595, 0.015001011480178152, 0.057110399406935485, 0.044804532413503954, 0.03653107011424644, 0.057599419594875405, 0.06829131301492453, 0.022178487053939273, 0.0028551871489201274, 0.032019392387675386, 0.08179806146238532, 0.007405322544010622, 0.0728893241445933, 0.00661156846243622, 0.02933624100738338, 0.05221899652055331, 0.01687221259011754, 0.0276503851304629, 0.08378458808043174, 0.016616108029016426, 0.0663511778361031, 0.018934358543317233, 0.03647097905299493, 0.01973840218436505, 0.045531508047133684, 0.04540620298523988, 0.060154293929891925, 0.028651107235678604, 0.03073995354186211, 0.04615085106343031, 0.018096291460096836, 0.0618984139125262, 0.028597808309963772, 0.02745299250818789, 0.036055440814899545, 0.013737274782865174, 0.03230117101754461, 0.04768848605453968, 0.03715562427948628, 0.03969141481710332, 0.026642791161845838, 0.008759652148000896, 0.031235029654843465, 0.04416563401796988, 0.010413263192666429, 0.021354070398956537, 0.031727235564695935, 0.05336457058521254, 0.07896589700664793, 0.026963032549247146, 0.07116577734372445, 0.05937107452856643, 0.07885809814823524, 0.06997194247586386, 0.05859235381441457, 0.061635318744395456, 0.01439722896819668, 0.016305065880130445, 0.01892709991495524, 0.034535447734275034, 0.04802782141736575, 0.0678635984659195, 0.01952236341977758, 0.02218716382049024, 0.03806987897093807, 0.010016863034772021, 0.016860312782227993, 0.022296031371557286, 0.030318210101021186, 0.013204583232956273, 0.03575111446636064, 0.048535928795380254, 0.016738207012947117, 0.13880742021969386, 0.1618905844432967, 0.13256788360221045, 0.10921570738511426, 0.07905699033290148, 0.1594332427318607, 0.13510675808148725, 0.16733846068382263, 0.1348980814218521, 0.18045185559562274, 0.17930452073259012, 0.2100022185061659, 0.11950392675186906, 0.09387143860970225, 0.12599420920014381, 0.19323517036225113, 0.24149172593440327, 0.1545780532594238, 0.10888327950877802, 0.12030693223433835, 0.14488296849387033, 0.1795011330395937, 0.08139690477401018, 0.17951154176677975, 0.127868987885969, 0.19326749577053956, 0.16199328750371933, 0.1024533798918128, 0.10376941891653196, 0.10752832650073937, 0.17364822567573615, 0.12882555941385881, 0.09295217293713774, 0.052250840168978484, 0.11713290826550551, 0.09471485763788223, 0.12573709871087754, 0.08798526945923056, 0.20313137290733202, 0.18594014538185938, 0.1457014445747648, 0.15511429948466166, 0.14454140753618308, 0.1485366081552846, 0.1570512998316969, 0.11504987361175673, 0.11275242867746524, 0.07595766628427164, 0.07311915074075971, 0.12990440295210906, 0.1409655822707074, 0.09795331529208592, 0.1771303452551365, 0.131359317739095, 0.13029920176735946, 0.13494601313556942, 0.11474012237574373, 0.13701729556279524, 0.09286565972226006, 0.1375687409724508, 0.1175440326333046, 0.12969093583524227, 0.1799957307853869, 0.11321786298815693, 0.10365143524748938, 0.11055086752665894, 0.10199864607836519, 0.12966174525874002, 0.14433142808931215, 0.0835551211078252, 0.15963689823235783, 0.1324508363114936, 0.11428642672087465, 0.08267468120902777, 0.162888071632811, 0.11371902216758047, 0.14255031437746116, 0.1910866977913039, 0.14915881119668484, 0.14197959857327597, 0.09127653070858546, 0.07134702083255563, 0.1270796480987753, 0.09153709494109664, 0.10684164906186716, 0.09083324378090245, 0.17809899470635823, 0.11959038568394524, 0.11987843737006187, 0.08694175723940134, 0.12591188933168138, 0.10930092459810631, 0.1912729420832225, 0.08258952506418739, 0.1579104880137103, 0.08188430326325552, 0.13846425791936262, 0.05977253655769995, 0.13044761094663823, 0.07606323954782315, 0.07914942715849195, 0.19173995059515747, 0.10353305802813598, 0.13557596504688263, 0.14027047742690357, 0.1935685481876135, 0.25173201358744074, 0.10307202740971531, 0.12355480795460087, 0.186482824119074, 0.12849385078464234, 0.12962614931166172, 0.13121525118393557, 0.1536016006554876, 0.07394080915089164, 0.0978495062195829, 0.09065620720918689, 0.1573475617915392, 0.17746487659003052, 0.09750865772366524, 0.10244894227279083, 0.2739533297717571, 0.07096446278904166, 0.09906063015971865, 0.138818303921393, 0.12093882475580488, 0.08805390327636685, 0.15069307386875153, 0.15540689735540322, 0.09659493568220309, 0.15830394332962378, 0.1440733947924205, 0.14921029843389988, 0.08571574624095644, 0.15070279049021856, 0.17378022787826403, 0.09308496902563743, 0.09661092196724244, 0.09456534923187324, 0.07391896710864135, 0.1184307693370751, 0.08424353559634515, 0.10285236526812826, 0.08304781440113272, 0.08698347357234784, 0.11189996477748666, 0.09357860325170414, 0.09411075112542935, 0.12145038587706429, 0.10882156674883195, 0.10075770052415983, 0.15031955391168594, 0.11136360320129565, 0.11646351989890848, 0.166136110201478, 0.19109631941786834, 0.14586807920464448, 0.16786659163023743, 0.13977207988500595, 0.14170270200286592, 0.28458958332027706, 0.15728491943861755, 0.11677899797047887, 0.16415659285017423, 0.12267902280603137, 0.11156246824456112, 0.07604861033282109, 0.10737742031259195, 0.08527642195778233, 0.14088717076395238, 0.13261170339371475, 0.11763202505452292, 0.09123256163937704, 0.09720149170607328, 0.19966903940907546, 0.11525305413774081], [0.023843813853870546, 0.060039037971624305, 0.05577255565939205, 0.04827748837747744, 0.02233893683712397, 0.032701041882059405, 0.03983907760786159, 0.03357283724471927, 0.01734352471040828, 0.0729799424963338, 0.06002701433109386, 0.021523112131814872, 0.003602879728922354, 0.03475742368027568, 0.019267259697828974, 0.09228202461131982, 0.026873923937923143, 0.033970859101308246, 0.08863982505031995, 0.04580321043197598, 0.04441123655331986, 0.04248511990798371, 0.11158396423395191, 0.037470169365406036, 0.06481931717800242, 0.021096981962078383, 0.022076099512300322, 0.0467424012853631, 0.01784881277542029, 0.027467195942465748, 0.050993786193430424, 0.0193882357063038, 0.0072277168510481715, 0.07842875511518546, 0.04973922922675099, 0.06938567464905125, 0.041367837360927036, 0.03246969536745122, 0.013744729338213801, 0.007645518851599523, 0.049947417341172695, 0.012966421682254543, 0.038563194285546026, 0.055519960820674896, 0.04232916541929756, 0.0227875621390662, 0.014550854385431324, 0.02537320803717843, 0.021060458118362085, 0.04126344135563288, 0.04101137238155518, 0.0398793825879693, 0.08347172236868314, 0.008145080929222916, 0.04989858656855566, 0.05790589350674834, 0.08218747270958764, 0.06031300327075379, 0.04352941244308438, 0.019038082798942924, 0.02738711523956486, 0.047372505867055485, 0.050105851875352006, 0.020086397350366627, 0.016942473194961036, 0.009973089044381465, 0.025302699767053127, 0.06017431749829224, 0.038209921813436916, 0.03296684779758964, 0.02797104212056313, 0.11113578506878444, 0.04220214366380658, 0.0029560562564126614, 0.042229804143841775, 0.013615928124636412, 0.04009263596630522, 0.033447060600987503, 0.06104438259665455, 0.04547732363321951, 0.03855261931728039, 0.04008418141997286, 0.02922579925507307, 0.00808404415978917, 0.03836389497986861, 0.03527327992820314, 0.037287595947938304, 0.03110269157748137, 0.018428195168131163, 0.0028547963551578243, 0.0975108358210751, 0.03247326106897422, 0.00866996678191104, 0.05082505149766803, 0.009271504191149558, 0.025711956467213373, 0.0668213754626257, 0.04632723963420306, 0.04572757413344724, 0.030428797738360505, 0.05140411667525768, 0.02040173971493329, 0.0733941202717168, 0.010594989289529622, 0.03422851241858942, 0.028807950605239187, 0.04570119608459728, 0.05751684188310589, 0.010690125836325544, 0.06705114099064044, 0.024241718663168803, 0.010173234822494643, 0.04934962120439325, 0.03728121093341282, 0.02280646951736084, 0.027490912437705056, 0.03859773850334542, 0.09511743924979653, 0.026043899191011275, 0.038409811444580555, 0.012444468797184527, 0.054781735076435974, 0.07798987187977348, 0.025958665014643754, 0.031992139028651376, 0.013977292975011681, 0.06066284914101873, 0.043988845111536126, 0.0219645330881966, 0.03718280639233334, 0.05217286292463541, 0.04177483623581273, 0.029448955852006162, 0.017015960233818208, 0.029101247367049967, 0.033939459893320284, 0.025693446031904647, 0.009426553683754588, 0.008592517098544963, 0.04702917393296957, 0.04654094423832638, 0.016255790667076195, 0.0709216675854155, 0.07758032849856786, 0.05583826499059796, 0.06486876202481133, 0.03047532488458923, 0.023354720723416125, 0.031601126438805034, 0.02827695963372077, 0.09901147029761757, 0.04326162859797478, 0.015515223977022936, 0.04982372719262328, 0.038005499568368704, 0.07664430979639292, 0.017758862780673162, 0.05247938433395965, 0.036570750842137, 0.04119059383603079, 0.04546747809009893, 0.03340278619102069, 0.06146816842790161, 0.03688012549121465, 0.11523415015212127, 0.007271395846536117, 0.044204391938235076, 0.036854045997772894, 0.060007330030202866, 0.038742486986198595, 0.02647299795145435, 0.012808332352765968, 0.035965928475239446, 0.03828438763905849, 0.02352176925965718, 0.028760480295334543, 0.05072635518653052, 0.053057272253291946, 0.044917396535830836, 0.03449343623859542, 0.004145892644633672, 0.0893541392205017, 0.08051501281027283, 0.04433409051437463, 0.024302844490323747, 0.017889314530683414, 0.025330718174310665, 0.013865635796849216, 0.008306423834125911, 0.02586334611156157, 0.0071478922951168245, 0.06061941611447504, 0.022223718198282377, 0.020574822123827677, 0.03624303539150527, 0.02881642211494701, 0.07719269501311438, 0.03204951255715319, 0.06351823306509427, 0.021650625825194374, 0.039158093077795844, 0.02262047628339912, 0.02874952195478337, 0.024289738586438552, 0.033116220496594906, 0.06118403188884258, 0.02602348885765033, 0.023529255197250416, 0.037196061573922634, 0.047944639809429646, 0.06363866624555417, 0.013713115543526198, 0.013027669645712843, 0.007195189578591713, 0.01767536735029093, 0.013739768399058707, 0.07857414481363126, 0.03322009063724961, 0.050837658678314517, 0.009962146819036986, 0.04890004086441227, 0.029058370739221573, 0.016663259427462305, 0.03180488711223006, 0.0629829028621316, 0.05981598315494401, 0.04295235912182501, 0.015862671225996952, 0.01679173664056829, 0.021275163561637913, 0.0143890865479729, 0.03538227300824864, 0.05113063652866653, 0.06632881332188845, 0.0598686510430915, 0.06316937785595655, 0.1014345120638609, 0.04747673902394516, 0.053939371170209985, 0.03799161334921207, 0.01614196302502283, 0.035641887291733704, 0.05837548723710435, 0.023610469053632448, 0.020795591973832676, 0.03999710502102971, 0.024257131586117402, 0.06839689306382622, 0.017843258966292654, 0.02341028256341815, 0.024121746886521578, 0.018625803225274597, 0.013338134191664202, 0.027238543211881603, 0.013915672665461898, 0.08420637223337378, 0.015496038399370653, 0.027925215561741164, 0.049504327188645086, 0.050972178245761564, 0.02954596939629742, 0.03541344829968043, 0.0227420290466398, 0.015732292418501208, 0.04586742359346577, 0.021050115548340336, 0.058712949843278954, 0.10301989556423255, 0.025978452792125087, 0.03685554556016411, 0.042167192324995995, 0.020277861272916198, 0.07238438552511589, 0.04818648326077631, 0.041969267052731345, 0.010160846469391669, 0.048188956520919285, 0.012367189595741885, 0.05699360317417553, 0.0812182736450008, 0.04036281843270574, 0.02071355709007808, 0.019493232215089456, 0.04489175469747611, 0.04473188506173236, 0.044702317898294756, 0.018592868831806948, 0.032844752206334045, 0.02318521249773247, 0.07444120837109429, 0.03184027271345258, 0.04610745196363755, 0.009824777404511613, 0.028723486566117833, 0.03381997326921139, 0.0036001333584343748, 0.056477875847901614, 0.03896394385290997, 0.03813447889738849, 0.03681132882567389, 0.007264651208450752, 0.018171469747487987, 0.0110375654517806, 0.0639211403738175, 0.053243747247116904, 0.023200104645054256, 0.0488289405724832, 0.02329668731960867, 0.012204427704481142, 0.02741110654148672, 0.010592633076677365, 0.03146597244111555, 0.031952122425926585, 0.03312624924417053, 0.023979176501078264, 0.05186107947624155, 0.025236266099714806, 0.01707895881762462, 0.04324776952021888, 0.03164503783253687, 0.06321761491043226, 0.01292828207702509, 0.02383956452831626, 0.05206811408113156, 0.08788625762930938, 0.03062304195814899, 0.041273341181554964, 0.03258325159549713, 0.04267694175775562, 0.029252350330352783, 0.10062623436429671, 0.003439742947063808, 0.025346190469073396, 0.012961344543977507, 0.030472522534962212, 0.02500094845890999, 0.02268494219918336, 0.07369857214923416, 0.019934388542813913, 0.017183950237397636, 0.06659690250775643, 0.0063010178273543715, 0.033625213362808735, 0.03338183302964483, 0.017308400345167944, 0.045556427245693545, 0.03984751858349357, 0.03086370136588812, 0.02776096428611449, 0.09364744062934603, 0.01887608765225325, 0.12643578621957982, 0.19956679775246552, 0.09179774738316025, 0.12761845918638365, 0.12972807884216309, 0.0768923686285104, 0.17568605632654258, 0.11054874371205058, 0.10663257885192122, 0.10043304187378713, 0.09166938891368252, 0.15733694950384752, 0.054403193960232396, 0.1679495900337185, 0.1074812225997448, 0.04474923859483429, 0.11141308197485549, 0.11549318768084049, 0.11694511691374437, 0.18733323205794605, 0.1515758614987135, 0.20237176652465547, 0.14798908467803681, 0.15562018805316516, 0.09369776078632899, 0.16158539296260901, 0.13428402080067567, 0.13618425812040055, 0.11068987221057926, 0.1229716342474733, 0.15532740019261837, 0.14709084002035006, 0.12914463372102805, 0.15305886763547147, 0.15957182672406944, 0.11505447407918316, 0.179120732737439, 0.13385689657713684, 0.1560439331723111, 0.12069870478340558, 0.08009898263428893, 0.12643782182463578, 0.11885636007147175, 0.15567552936928614, 0.1353134127067668, 0.07618647507791008, 0.1317229310848883, 0.15294733004910605, 0.11785318675850119, 0.10394211964947836, 0.1255440826394728, 0.10171309140111719, 0.17395045874374254, 0.2231887187808752, 0.0742925549192088, 0.08795041990067277, 0.09969349298626184, 0.11730456405452319, 0.17316723934241704, 0.21830949559807777, 0.09816924549107041, 0.19942544533738069, 0.10677833495927708, 0.13151973698820385, 0.0875613818477307, 0.08291350517954145, 0.06699843239039183, 0.17080331833234855, 0.12422959745994636, 0.09681977504598242, 0.07546131113278014, 0.0947562414886696, 0.29045218016420093, 0.13606107687311514, 0.07493757030793599, 0.11226644832640886, 0.09456654345350606, 0.1143569807921137, 0.06095792366457837, 0.11625770665705204, 0.20154434735221521, 0.22717387708170073, 0.21269821455436094, 0.12239848928792135, 0.24024012738040515, 0.09449768571981362, 0.11720633932522365, 0.2020930786217962, 0.13539371054087365, 0.08659700038177626, 0.05875303090683051, 0.1864188654082162, 0.15142465675515787, 0.08022045397332736, 0.1491108794829675, 0.1043127015499132, 0.06758967387889113, 0.1356915467019592, 0.1088352935122592, 0.12781627928572042, 0.07270858277167593, 0.1292069639478411, 0.10510134923138789, 0.19469262287020683, 0.13127785282475607, 0.12043763164963041, 0.11515653931668826, 0.16047248696642263, 0.11273767054080963, 0.1219723421548094, 0.11838344830487456, 0.10162682245884623, 0.08237658041928496, 0.11016715597361326, 0.18697244141783032, 0.09415630118123122, 0.09673541278711387, 0.11874962651303836, 0.12426517983632428, 0.11129080317914486, 0.07382709346711636, 0.13987489151103155, 0.16261193502162183, 0.2576934051300798, 0.09969075849013669, 0.09367203073842184, 0.12916432480726922, 0.11158139258623123, 0.21626935792820795, 0.17926641420594283, 0.08878903490092073, 0.23276562988758087, 0.08107914682477713, 0.12029587211353437, 0.15105721647185938, 0.11341615127665655, 0.12194245947258812, 0.1210480553231069, 0.1144515685737133, 0.11286777284528528, 0.11475472444934504, 0.14530556010348455, 0.1874280369707516, 0.1498397753707, 0.15027369851512568, 0.1452968612845455, 0.13267425075173378, 0.08733714638011796, 0.15134334111852304, 0.1382348316588572, 0.14089251761989935, 0.22344995476305485, 0.10239081896309342, 0.09574611551527466, 0.10478401197386639, 0.1670699915183442, 0.18480581124978407, 0.1337108758411237, 0.14801395977182047, 0.10097202938050032, 0.12417463612343584, 0.1556205680327756, 0.16405417477445944, 0.20997304150036403, 0.09561500219362122, 0.1588299572467804, 0.1304296569100448, 0.09550355960215841, 0.1643628810665437, 0.11206856037357024, 0.12128908453243119, 0.09784830521259989, 0.12911656951265676, 0.09482980147004128, 0.15013632231525012, 0.20488865646932805, 0.26791735365986824], [0.022649924703208462, 0.05544031098751085, 0.049327260082853694, 0.007342469845233219, 0.03922591604558485, 0.042281067464500666, 0.05819910205900669, 0.01856648569394435, 0.025284742337784598, 0.021377313616020337, 0.030365999322384596, 0.011356522711659116, 0.04655843347843204, 0.04835498725463237, 0.027818293709840094, 0.06596469786018133, 0.04375497444665857, 0.04956625368712204, 0.009621062532200344, 0.021758864035031626, 0.04659602092579007, 0.0752159392993365, 0.023625651274674704, 0.06409152730235032, 0.02775320184550115, 0.04424582328647375, 0.03375731395291431, 0.03581240314192005, 0.0201155777488436, 0.03474962392023631, 0.016533481123458062, 0.041227903084031174, 0.04158310938094344, 0.0491056573311133, 0.024630600653056587, 0.06202704379601138, 0.024292510401989733, 0.016955021003793393, 0.011779670719988644, 0.013380227111546057, 0.029976920557341406, 0.035857817490718195, 0.01560012567123132, 0.01741500837462289, 0.030439627157258134, 0.08726500453693525, 0.037582432984241416, 0.02467454258086426, 0.015767343841227036, 0.022843673592433333, 0.004948895158512252, 0.048677433880844286, 0.03054104100114533, 0.006834370948906455, 0.04100190681804504, 0.07275194115936756, 0.03625888257686581, 0.03833463654986449, 0.03752171427809766, 0.030861095791416507, 0.03453271323814988, 0.0577524903097323, 0.016173759175996696, 0.008983807887748947, 0.0315391422648515, 0.023655189600374018, 0.07121479471347161, 0.0514459788932332, 0.016495030240288804, 0.04368436948529311, 0.016616219987294505, 0.051147901852216036, 0.030410453544131348, 0.11305161512323789, 0.045979856846055815, 0.051791868904339414, 0.014859126415103674, 0.078732521672334, 0.02990871760994196, 0.025066674753491367, 0.03648847847112587, 0.03358703898265958, 0.05301082992394056, 0.02491583811518337, 0.08775492717644998, 0.037558582478335927, 0.02363523727815066, 0.07254639254616839, 0.05231452068047864, 0.02383522699320955, 0.05693440777914865, 0.04103422883365836, 0.12259508802422456, 0.03301146486774087, 0.021758818233917867, 0.030402049887925386, 0.025619624814550792, 0.04247243469581008, 0.0731215663254261, 0.026213113950299363, 0.060112184046634605, 0.036196162192417045, 0.03500916695754443, 0.062406168452331, 0.022724816309554235, 0.0138436928225149, 0.026483121693932583, 0.04272455116733909, 0.030631669530911104, 0.015646992084969367, 0.03297256784779685, 0.021582275296428373, 0.05156585228230272, 0.03139933690960918, 0.023597999276327233, 0.010103276165734445, 0.06546098060373749, 0.04869717246453677, 0.03572710111205067, 0.01462501147761941, 0.036290933178471665, 0.035412837618163655, 0.007785147787736995, 0.0419289247531976, 0.11176376244319336, 0.048887912050953934, 0.023579532945794717, 0.04515433078631759, 0.06399872406784977, 0.09684146102517843, 0.02035976044966706, 0.09810289155159678, 0.06366693401443106, 0.03958306634532554, 0.03733822823102985, 0.010151681157627275, 0.07332698601697173, 0.06121825719518321, 0.042068512977233956, 0.006140626567815031, 0.011698970005714467, 0.1058055464444416, 0.05616213654034904, 0.04733631280916078, 0.027562195934089165, 0.020828977593087723, 0.026757102260099988, 0.021428271595920836, 0.01228634808545134, 0.03747687329139028, 0.031107906119099686, 0.045791434456727335, 0.029360814153083732, 0.07487995589950255, 0.04814503834183727, 0.07426542708916323, 0.04517270212194749, 0.013635634477915508, 0.02027458225243858, 0.023042596311175396, 0.04971726504819734, 0.02752862880671663, 0.043141592360500775, 0.032618199541632614, 0.0444654854280608, 0.0659470898764474, 0.04635666769796184, 0.06356113004897322, 0.006314028736336955, 0.03140774056581514, 0.009349828336520918, 0.03084573375859431, 0.022968758130446076, 0.0035081235858212623, 0.011860817571037581, 0.015511408913880587, 0.021049781369843652, 0.020326183144269244, 0.08963771257549524, 0.02403591899201274, 0.020390662630753856, 0.07122067082673311, 0.05282474169507623, 0.03444311947428754, 0.0400938539366637, 0.04195039360118764, 0.07723047584295273, 0.005728753691073507, 0.045893557369709015, 0.006685269663908652, 0.035968618866588385, 0.0441871130439852, 0.010123599985880511, 0.04825311539960759, 0.03664069762453437, 0.030879752111754248, 0.035645517454083474, 0.06499592627265624, 0.06787937440510307, 0.043875326202916246, 0.013250180786209447, 0.038985405915549824, 0.09467504120298795, 0.02515484020113945, 0.004406763066072017, 0.04891186094443713, 0.011147952073120644, 0.09449736002300467, 0.05277338677218982, 0.011451765279551702, 0.02973667166328856, 0.06083261860268457, 0.019151981687173247, 0.027915712678804994, 0.043928245149020634, 0.0269696058572403, 0.08801158304725375, 0.029380627375628268, 0.04988524317741394, 0.02730086156433182, 0.005577598565391132, 0.014594060102743762, 0.029039025705839907, 0.04514632407309754, 0.019304674118757248, 0.023861506654481803, 0.007092603989544192, 0.05475203559866973, 0.014232594320284469, 0.006945913624284523, 0.0483103430430804, 0.06918069600526776, 0.03255582181736827, 0.012423733615183404, 0.008740023826248944, 0.032153640541114976, 0.016962379716070633, 0.034896767631705315, 0.011225308457921659, 0.020824758801609278, 0.015790217256705676, 0.053775477821805646, 0.026590793327029263, 0.051124346509043656, 0.017794209366132106, 0.07012163408632789, 0.020801666558587124, 0.10186147343899522, 0.052326812342341454, 0.01621155866554805, 0.03914584891338434, 0.04747222337339606, 0.047161803780389686, 0.007694745719033692, 0.013421308166081352, 0.035060386173427105, 0.045050874552024264, 0.08266779407858849, 0.050551856335784705, 0.011198653057882828, 0.05444334287728582, 0.05104223359376192, 0.07918441242405347, 0.028069192211010625, 0.0066698953326392385, 0.013180154275947382, 0.016565643683341996, 0.03518888034990855, 0.025306214578449726, 0.06856016894536358, 0.0494726938860757, 0.020821623969823122, 0.06416436125125204, 0.02710638494629945, 0.032005512953868935, 0.02010470592150731, 0.027439772949687073, 0.0398038786037692, 0.02016949244508786, 0.06980237657470362, 0.03007405623793602, 0.04148489822234426, 0.04100198484957218, 0.06339556071907282, 0.018625833759350435, 0.03618750747825418, 0.03266866897631969, 0.05545898087854896, 0.01566589267791382, 0.019967229637716497, 0.0694063360403691, 0.01471720403060317, 0.041390113665589263, 0.02211388373481376, 0.057554989121854305, 0.0066546478026014355, 0.04782228298219187, 0.029498370164739232, 0.05684390477836132, 0.012458751111158302, 0.04320073686540127, 0.03080421420080321, 0.056123405761484585, 0.027939122136948363, 0.02137329668870994, 0.06468646680670125, 0.024102094816043973, 0.011682989657856524, 0.06071023802672114, 0.05616883707365819, 0.020804881118237972, 0.04668693783293877, 0.07317913323640823, 0.049237988623125215, 0.03178426643301334, 0.024612996061997752, 0.0372706800699234, 0.04773889442107507, 0.02389722134518836, 0.026709134923294187, 0.03484272910282016, 0.07044920365193061, 0.018572545011660883, 0.04572720433186207, 0.021389047182830315, 0.017323641938024333, 0.005522122814519597, 0.04104859681267824, 0.010936569755098649, 0.0688721254201872, 0.011116723347056125, 0.04071240985233869, 0.08554215662713562, 0.024150443828797767, 0.013489237154967018, 0.025578256230801344, 0.039893285770501406, 0.016341016361755983, 0.013114528913450028, 0.035828257112630775, 0.027136052193652307, 0.0143960398355765, 0.01632843292983515, 0.0372478371885206, 0.04379623616114259, 0.028040005027183464, 0.04655451833137444, 0.01671176280693284, 0.019229226113696183, 0.016660674209041253, 0.005373577504152698, 0.038203916778521876, 0.1158523362662111, 0.08082078783107655, 0.1510418408683368, 0.14471478680414812, 0.11025917889284235, 0.11882980221084186, 0.18702137736337526, 0.07611032309276716, 0.11451494374445506, 0.1073454206011125, 0.13733613916805812, 0.04228041607088276, 0.09387800682868276, 0.16803547899637902, 0.0787980342283845, 0.15941857280475752, 0.08501493491764579, 0.14359494618007115, 0.08533812793237822, 0.11197762989572116, 0.1361179245369775, 0.10293142138315098, 0.18165545458240168, 0.18373774284762995, 0.12089678272604942, 0.17184097479496682, 0.1628557869366237, 0.11471862638635294, 0.09086003912878887, 0.14430932141840458, 0.0950334162584373, 0.14768666162022523, 0.15224311926535197, 0.06369204659547124, 0.05791992561093398, 0.21334476343223027, 0.15320981453572, 0.19998508745006152, 0.12309934810868331, 0.07152687332459859, 0.1819383358316762, 0.1685788905514138, 0.1274052770542247, 0.09197654136057411, 0.0755819207323449, 0.09789949389440672, 0.06747414650661604, 0.12817329727113247, 0.09211804983871323, 0.1077388623463256, 0.06594541389495134, 0.15231965801545552, 0.12810321817440645, 0.17821118368634156, 0.07974113683615412, 0.16551957971283368, 0.1425391456910542, 0.1181673484721354, 0.10369519397084202, 0.16966808853404863, 0.13085113572222845, 0.18922584264406137, 0.07977591175585985, 0.05058623091982944, 0.16250494361988135, 0.10370588768273592, 0.168743760990245, 0.1957210919686726, 0.11004573891737632, 0.09645331863846097, 0.0756912666506001, 0.15289217872279032, 0.18244023461427006, 0.10512782566781555, 0.15327385467078003, 0.09707979645047869, 0.10902775318494864, 0.13589825561004026, 0.080023739886071, 0.11229166268770184, 0.13440944121352263, 0.1465069063540016, 0.1626152598432132, 0.07872389070689678, 0.1640354064958436, 0.1622287527258907, 0.24008691417319433, 0.19261897914111614, 0.13738970272243023, 0.09270676039159298, 0.19513333136481897, 0.0900039179250598, 0.17931849855397428, 0.17962826336068766, 0.10494179850710289, 0.1707520346556391, 0.17540754484278814, 0.14111301435955934, 0.1396853495389223, 0.13602325533117565, 0.0797337204484003, 0.22458458745053836, 0.08039597741195134, 0.2075680691216673, 0.13386740029922553, 0.18291330922927174, 0.06875857937016658, 0.18829709105193615, 0.094419070652553, 0.12256904585020882, 0.1320519662861313, 0.09558270392673356, 0.09383266033338648, 0.06871199794113636, 0.15469511412084103, 0.10773287088211093, 0.19346562799598488, 0.10748675944549696, 0.2155351016138281, 0.08472175350678818, 0.19695989335221903, 0.1787109790103776, 0.13990220933088235, 0.12515491566487721, 0.1784842126071453, 0.09819794073700905, 0.06494981981813908, 0.10816493484058551, 0.17382317914494447, 0.18719800002872944, 0.17052499683839933, 0.14432929748935358, 0.11710892883794648, 0.18788536957332067, 0.11865721004349844, 0.14731616792934282, 0.12548217310437135, 0.10309409336852175, 0.0914909274184278, 0.10898287487881524, 0.11810334904917649, 0.16066776934478963, 0.16339807212352753, 0.060131617289568694, 0.1460834869316646, 0.1095754395106009, 0.10804233034806592, 0.10255653757069792, 0.09535282983311585, 0.16829486936330795, 0.09206236246973276, 0.1308362486639193, 0.1608464547566005, 0.18726638278790883, 0.18725783324667386, 0.12428902355687958, 0.2064086834767035, 0.06274509669414588, 0.09747901931405067, 0.09389192358191524, 0.10665374235915286, 0.15902665097798618, 0.09594523840184722, 0.12147079621042524, 0.10468583474201815, 0.17190790548920631, 0.0992066983931831, 0.15020554645785264, 0.1346980764397553, 0.1790774150618485, 0.14509206584521703, 0.1362457876758916, 0.08546454579170261, 0.07551644210304533, 0.13631906945790562, 0.10745514649897814], [0.04460845275649002, 0.031343225456242046, 0.01874404982663691, 0.040834841318428516, 0.0119179145965193, 0.07629067770072392, 0.06344126683792897, 0.010794359841383994, 0.006059575559837478, 0.0535908552285816, 0.062012014245348315, 0.13564227148890495, 0.05770675704947539, 0.057133150686110766, 0.06533277141196386, 0.08873313718608447, 0.04795869905501604, 0.01301494287326932, 0.0631934522784182, 0.010050370790330427, 0.02027737272770277, 0.027237472822889686, 0.04426343466288277, 0.011397108435630798, 0.015434388403913804, 0.012862130849888282, 0.0717710577217596, 0.054808808623680046, 0.14753123638885363, 0.011898626390445446, 0.031234378261225562, 0.017277584677296023, 0.04462813366470592, 0.04641732194327882, 0.08581670546638114, 0.022791794501245022, 0.008699038614785033, 0.015534202601494533, 0.09254070251647915, 0.018527776967468004, 0.07377796753176621, 0.01891081507450768, 0.03064154221543244, 0.04600734769233635, 0.048936010005750825, 0.034642418779964955, 0.020495553966611624, 0.019699993709634458, 0.021640569936218004, 0.036130944799099646, 0.032963604400200505, 0.020822456871558512, 0.05360593227669597, 0.03130513589297022, 0.010654115134717097, 0.0966844887339643, 0.04612278685505901, 0.0222010398616216, 0.04567921154999307, 0.02748794384699847, 0.022191693041739718, 0.026339920270921927, 0.02355184362802122, 0.03055171774966376, 0.01979349583520421, 0.0834786162844726, 0.022083185114232556, 0.02135694060208542, 0.04766320383974484, 0.05836946863148894, 0.02193898454840694, 0.032439005228557756, 0.02579218814415591, 0.05166240781545639, 0.03182193191189851, 0.03727081238425203, 0.021766846999526024, 0.038214501924812794, 0.09239993364151035, 0.03839453762131078, 0.017623815652249113, 0.044398086544658454, 0.020691665854038935, 0.00852945150940546, 0.012681637142252709, 0.024515539773606827, 0.02615968949560608, 0.0223158802171903, 0.021624164655804634, 0.0032876654378404574, 0.048592464333134036, 0.04750582442751952, 0.013202992068337542, 0.011547224130481482, 0.009136633481830359, 0.04888187987463815, 0.025404327349471192, 0.014147725704658245, 0.03493600052648357, 0.024874981825373003, 0.036346681615603824, 0.021449611522257328, 0.06208542494901589, 0.014480741361954381, 0.020317177288234234, 0.027683536655136516, 0.0063921204834644285, 0.03052430154223527, 0.02609668073377439, 0.03536297207964318, 0.02494587516412139, 0.0673772788473538, 0.0334833079416837, 0.027375261232789074, 0.04903428901785186, 0.018759951294798936, 0.018546989686521034, 0.025639858728806888, 0.025558390421792865, 0.016295452735253742, 0.03095039099987064, 0.024915011998798166, 0.07587318867444992, 0.03391256955053125, 0.10723734354334218, 0.01778797193297318, 0.03791547493476953, 0.10547734584127154, 0.026202160698760833, 0.033335492480546236, 0.009720171901530452, 0.008402422120395516, 0.03570162212210042, 0.03487289337707417, 0.06317785275833947, 0.014178553246892989, 0.04473601055464574, 0.03444964358849185, 0.022242601827851365, 0.05166497267782688, 0.05831689573824406, 0.04290269375113504, 0.05595902047519173, 0.030853139968322854, 0.057044886850884984, 0.020015665163685168, 0.040260312147438526, 0.05021525886175888, 0.052964428306690285, 0.07230901385524444, 0.033066606016031334, 0.03732620119782431, 0.014128933677316775, 0.024522540558661734, 0.01517608030033963, 0.053763094557715316, 0.045210920606872866, 0.03316907498187252, 0.03518070739560893, 0.05109907786494919, 0.04424353323078581, 0.03059136794347848, 0.014818543235638311, 0.02346692157776228, 0.041040769911238124, 0.04857983679643699, 0.02544487829852317, 0.06482921700392451, 0.04766791965812445, 0.024819114644612585, 0.010690963827073574, 0.06437790300697088, 0.06769327260553837, 0.029577738405870538, 0.015518150159290858, 0.039251768229795356, 0.02226116824229913, 0.03553884157112666, 0.03239241362150226, 0.013417450694500335, 0.022136253338041048, 0.05785680828349931, 0.057252111445580206, 0.01276271783613733, 0.037835638504475355, 0.0467618786330734, 0.02239066156159554, 0.07437514620167868, 0.022079185150297623, 0.03106094810313412, 0.07843012575592313, 0.10164955338197094, 0.051493520449314795, 0.02248806187084743, 0.03472300499145474, 0.032950169406831264, 0.01029915311041155, 0.05504817542220865, 0.017693648780030862, 0.04885346622073224, 0.014650537965020962, 0.02285825870265918, 0.03439770173281431, 0.03355235227250627, 0.13234277282442364, 0.032207238022238016, 0.048037595714309385, 0.024944631748699715, 0.03788642345794609, 0.08238021058163472, 0.05860846223575728, 0.04309870555464711, 0.013026099685313446, 0.03532670099022133, 0.023364920801083957, 0.017611310251855423, 0.01530709523441536, 0.042352788615971804, 0.016458928784621612, 0.025332597716312324, 0.04435436514073184, 0.05159694275685719, 0.014989393264321344, 0.04067042549805982, 0.03269811400345393, 0.07929278803723198, 0.0043907331003408346, 0.0076086082429225954, 0.0607226552175624, 0.021716793167537878, 0.027820492163300514, 0.05637922703421541, 0.01509660858261798, 0.026835422164627483, 0.00833412163358714, 0.013665787725975471, 0.05643046660614865, 0.038950366367186816, 0.07845626971019165, 0.009696220463540937, 0.04450222470664552, 0.023752550893862332, 0.05625624256208539, 0.007820831944367715, 0.03225691696362836, 0.03613495833373495, 0.039864529456411085, 0.04364262940362096, 0.028344439941325357, 0.07244869707418339, 0.025605546909251382, 0.008936516541455473, 0.026406063864539777, 0.027103348502091, 0.03798283989142094, 0.013840417194712375, 0.028947240273867334, 0.05023187279169049, 0.034862776419946125, 0.008516371050583465, 0.021531590426872884, 0.05094607839626925, 0.030440271765525852, 0.039850785729608366, 0.0638055790747915, 0.027366530183436613, 0.03479349799454212, 0.026068289132256593, 0.05131485200087939, 0.04731411453602569, 0.028130173849474107, 0.05204134248197079, 0.0395134520450873, 0.08029454321201358, 0.08286423675183739, 0.01188261974935553, 0.04487904573657683, 0.0015440219140145928, 0.05481167882680893, 0.0427222848603768, 0.027818532893434167, 0.06316937785595655, 0.016243208931492906, 0.030692415378455604, 0.05367388416613851, 0.06011920688407762, 0.008685852134866374, 0.042649919100637944, 0.02307279111950525, 0.027853190765849183, 0.05940304031329496, 0.032087096611836126, 0.04069381120747753, 0.03718450951523014, 0.01738926305967782, 0.01916002232714423, 0.04745022526809147, 0.021961367722334604, 0.04204260651022196, 0.07419632508286408, 0.048298943654767106, 0.020463678087773066, 0.020645335482965623, 0.012321460576328849, 0.029506448124136244, 0.027702328682477986, 0.03125250193157366, 0.04486165488404887, 0.016847283213532398, 0.02102967128822846, 0.04632040000121508, 0.050301890820264816, 0.07184736576995679, 0.01198139918103282, 0.04236806583191667, 0.06070396836314883, 0.03168162104806729, 0.041114591128591976, 0.02135003311559558, 0.03367528924718499, 0.051557862532458136, 0.03437769512778946, 0.009566434526017733, 0.022737487951027494, 0.047746802746717415, 0.041109858346836906, 0.03191464693684663, 0.05568100092932582, 0.03277133132464119, 0.019244481277252947, 0.028638449164905717, 0.011166632142184036, 0.04723266997773733, 0.022464243595355322, 0.011153558468712228, 0.019233312590845993, 0.057394793789301596, 0.05101417277806571, 0.03439614110227142, 0.028779411422354833, 0.05209560153473701, 0.023136264677824717, 0.0165846952503281, 0.061956584719674926, 0.03283797364149775, 0.010860435581499977, 0.052904449203716855, 0.028701634345842258, 0.02607042482122779, 0.00985415542631277, 0.013170998294039496, 0.04867703354518328, 0.17959173103528364, 0.18156155890652112, 0.09540279036653893, 0.13614510664982454, 0.0644873846322298, 0.14378382318786212, 0.26219746630106655, 0.07292409227894885, 0.08424688077398709, 0.14272270298429898, 0.1540247215224164, 0.20508666655847005, 0.11301752552390099, 0.14984281520758355, 0.1729352753609419, 0.1609034381274666, 0.12755717390349933, 0.09073784175728049, 0.11122723123324768, 0.06703688496989862, 0.08659558902893748, 0.13034485360341413, 0.08298490741955382, 0.09608563408255577, 0.050465916482997794, 0.08165236642318112, 0.10378751544547932, 0.12136003215398107, 0.3313937075436115, 0.073456165513822, 0.09892796299287251, 0.19025531597435474, 0.11970980784722737, 0.12668223013835295, 0.268127835222653, 0.09658264741301537, 0.08705120493790933, 0.1504756576780762, 0.1478371742580618, 0.1341773686664445, 0.14931830763816833, 0.129026378637978, 0.09401395810501915, 0.13333234829562052, 0.118626011003341, 0.11632375525576727, 0.17185267273868832, 0.10994262195059232, 0.09753957856446505, 0.19380330773336546, 0.10637944457786423, 0.08603777896080698, 0.1803108560187476, 0.11120657662728003, 0.09711450351668255, 0.1770753160651241, 0.0888161084481648, 0.10335757530161313, 0.21774111395435675, 0.11627093808991568, 0.14725416339933872, 0.11181276624224015, 0.12244044989347458, 0.11437730970127241, 0.22105106205812522, 0.09626362060329743, 0.13163605146110058, 0.14425786132259028, 0.15391481242009572, 0.15900670204843792, 0.10003346617200545, 0.1302844775574548, 0.15023958177438804, 0.16534596974296228, 0.08397304439651114, 0.08557486201503448, 0.1292141428483384, 0.18838924967816897, 0.12321089926574912, 0.2900782802275249, 0.23788791788475855, 0.11125562792377812, 0.1089913294251476, 0.10211780361299004, 0.11889427660831384, 0.079069780718003, 0.1143558815653835, 0.11867178497569901, 0.18838749905782087, 0.1231559379292386, 0.13901996452893528, 0.15345446712204389, 0.07121797025735889, 0.11254633045090096, 0.08096237094806773, 0.08506014570593834, 0.1227122845926455, 0.18574636935123376, 0.12457103628133025, 0.06822037217872483, 0.09879395911203963, 0.1461004503071308, 0.11524389391498906, 0.08952444472483226, 0.07872695089983088, 0.12556057104042598, 0.13364923772002968, 0.17918171946491512, 0.18382625095546246, 0.18689061009458133, 0.17671509539442404, 0.11330313448395048, 0.13798947339611395, 0.1370674121592726, 0.15305874549916812, 0.08855057055396692, 0.1395815879638706, 0.12408496093537126, 0.13531248989914144, 0.0657728352983083, 0.16388292610645294, 0.08779280300119094, 0.1386579389550856, 0.13577354087361268, 0.1399773774402482, 0.1266134131167616, 0.13293968008032866, 0.21389667024569853, 0.12649804859289102, 0.11689143122306891, 0.10670234582253865, 0.08017649168946914, 0.14590292876320227, 0.11671339720487595, 0.1631045921572617, 0.076140735032303, 0.07884800154715776, 0.08982179234070437, 0.11869321311158793, 0.12072794964270932, 0.12259477589811597, 0.15940892403679235, 0.08296677017850534, 0.12476999631949834, 0.12117116871689047, 0.1395020500889846, 0.12434387632778712, 0.15069994064314024, 0.17413636376815184, 0.11195027814911944, 0.085298677906394, 0.24994545802474022, 0.1386149741177048, 0.10135451957051243, 0.11119080747344665, 0.15839602053165436, 0.1894030895616327, 0.12078995417271342, 0.13840142557663576, 0.10117173580718891, 0.16339940205216408, 0.09476230759173632, 0.09584420453757048, 0.19234390104455606, 0.09840681417179958, 0.11977463508290903, 0.10633840677993638, 0.13915807354663098, 0.06583931815943547, 0.08976138915334429, 0.1825635108564581, 0.1454855075904301, 0.24982742007289613, 0.08544629998505116, 0.07815928171787943, 0.14952824637293816], [0.013379272073507309, 0.052167573744165044, 0.019783684218834554, 0.011503560402031456, 0.007408437019746218, 0.018359434125678878, 0.09942562093159982, 0.02087607470873211, 0.029554054141044617, 0.04236962306978447, 0.04912287176453641, 0.022996379594717706, 0.04610456479713321, 0.07009457410978419, 0.018448323909459368, 0.04131914908066392, 0.08894000894257001, 0.017358050448819995, 0.025916261664990867, 0.03954649330782039, 0.005496754510594266, 0.03580572635733655, 0.05461477814242244, 0.008346963756983834, 0.030634902750274966, 0.0720830684793847, 0.0375478005568896, 0.025644620348300253, 0.021973160660958717, 0.010789566839646016, 0.058764471007244926, 0.041372359796826325, 0.03012745694390365, 0.025774222233199647, 0.002445428544888273, 0.015447090579462903, 0.05691834006990705, 0.04699374422697084, 0.03515228356367775, 0.05005461908876896, 0.04486124437036259, 0.03078056386272822, 0.042538931127637625, 0.01444905886559614, 0.022731102936502014, 0.09456664523375885, 0.018384119229657308, 0.07622152141162328, 0.04911189306793468, 0.029573494169328893, 0.02120746612282736, 0.0358578140980431, 0.030463453914437975, 0.04230543365702033, 0.029856582371784107, 0.03032708533906511, 0.06092063816530364, 0.04986157248328839, 0.009294710088787335, 0.01235758323621537, 0.036374501551368406, 0.011527613620273769, 0.022945674369111657, 0.06209215601640088, 0.08604495786130428, 0.09329855827880756, 0.0418841414419668, 0.0524760425489928, 0.03469001461884805, 0.028691802373422042, 0.01535644508632166, 0.03837375409368958, 0.015874433630545224, 0.06453079051737275, 0.03448926664090582, 0.025900239756863033, 0.053991940670779774, 0.023498300429699675, 0.02050484820002956, 0.014813221824754561, 0.02475086080708674, 0.04981178497629506, 0.09102492313832045, 0.04818846119035568, 0.013129544045243944, 0.04011282577578511, 0.020392949293766702, 0.014329302523817335, 0.007773605058901012, 0.0514635970549924, 0.015769589792138765, 0.008923967884454344, 0.03012599130826337, 0.04112771738852773, 0.029484046290495565, 0.05876300537160464, 0.0004749995340327067, 0.058844857050904205, 0.05686017604810851, 0.04979400057345629, 0.04200815050197499, 0.033676025457680225, 0.023606772734118358, 0.013550329055371029, 0.02693033733937357, 0.06348048616200686, 0.0291523885514055, 0.027891134444092, 0.033862951677292585, 0.0776911061257124, 0.014188202014858169, 0.05175331115190472, 0.05962177286190646, 0.051046803527112515, 0.0234146506326007, 0.04259091369541628, 0.026141520024144223, 0.008228254055471292, 0.03439381711983255, 0.013192245769979698, 0.0068981371254527146, 0.045782549040658135, 0.017849050262676816, 0.023568712008584822, 0.044228540999548774, 0.0937819534114429, 0.0384674224603389, 0.04442666983231902, 0.03913721455527203, 0.061998097492115836, 0.03910598158836365, 0.048351007646748, 0.05709071510604449, 0.01040995109360665, 0.03038701355191214, 0.014743066392838955, 0.047261229516672235, 0.056073343447808704, 0.047300479374825954, 0.028276576261435236, 0.026943738405991877, 0.03650138081450548, 0.026024998598066822, 0.05158722274271505, 0.07145011065793888, 0.03938053721295936, 0.01856485042454941, 0.059426144430679936, 0.03662539326718875, 0.024025554369602884, 0.04649398622236081, 0.07913516435239996, 0.04489057743921876, 0.012719061741206263, 0.03420788495402251, 0.02430910906488342, 0.0568666560575366, 0.05400480908740844, 0.03450322410623942, 0.007504059567249247, 0.04769449108945472, 0.06283891773117439, 0.02394095292714025, 0.0953047624123948, 0.03752934101170727, 0.02520217650037791, 0.039003326025392325, 0.04328496680994119, 0.0199933583249471, 0.0648434798100165, 0.038574756522263796, 0.07234057930431195, 0.1190921374197517, 0.045220793291394196, 0.02139742878664817, 0.01685004315472075, 0.044017876232309, 0.029182379799229757, 0.0544538432066994, 0.02972622900935156, 0.04811333379309092, 0.005005756393074989, 0.06839781587145158, 0.04522592640881028, 0.015305310687316316, 0.023318919519494687, 0.008083269781699138, 0.02471445401066116, 0.05237760068848729, 0.08761246196393456, 0.013709099464384573, 0.04780112286763532, 0.07836274044322115, 0.0462638644634613, 0.02795412963522332, 0.04576477820851973, 0.0482684231496283, 0.08306531381926366, 0.04419370161901627, 0.040306964822645695, 0.008670931997975069, 0.010824212837698204, 0.014027938828803599, 0.04904454507465873, 0.009082248900085688, 0.03644905219386731, 0.06231179780193737, 0.041055178602359126, 0.05369491535904152, 0.03014844742470554, 0.010972385377889233, 0.04588670077334557, 0.057850660756230354, 0.011868273822723754, 0.003968845470808446, 0.022935048510719622, 0.024420439698068157, 0.014714265973972422, 0.026822760701179504, 0.02306243497878313, 0.047854506610227485, 0.03176899260974356, 0.007719903253018856, 0.06798973812588624, 0.027323473743828278, 0.058645374540771754, 0.03517792879470757, 0.03922291352812733, 0.025846048557598676, 0.046535227580794265, 0.0213053159615291, 0.09680742570864302, 0.043632746541074345, 0.0324632323213986, 0.04497038333543709, 0.03185157371418817, 0.051354186675910435, 0.009029178131770874, 0.02290381384747369, 0.03517722651096327, 0.05653960217854806, 0.0506026175405298, 0.04861376354736941, 0.018850696871855428, 0.037004070090396066, 0.0035859778456922087, 0.041238325381917615, 0.02392650013124304, 0.021642763300665786, 0.013717297863747393, 0.04591889725998044, 0.04869231076112815, 0.04364078378837023, 0.0480418535215514, 0.044401346905423064, 0.03500291086467249, 0.025139620660671165, 0.016786321931119477, 0.05656481653984104, 0.038620293007365296, 0.019684372137167623, 0.020533557016668574, 0.015639563822852712, 0.04518258159181901, 0.01854826702869364, 0.0361237387572016, 0.03275784204847046, 0.007348479969160897, 0.054697237110563686, 0.041479968665433783, 0.03518923318811825, 0.017911719756999185, 0.008171285103474344, 0.04258974661518421, 0.06870832028133528, 0.059301775747111866, 0.04236096835562161, 0.01994879893027246, 0.06152602032359157, 0.0051532062934711576, 0.04880229450230088, 0.03001426373209272, 0.04089242180011102, 0.01611507268223379, 0.008030663809872099, 0.06557919497468642, 0.0481995416672102, 0.05499952785404665, 0.04879343622763242, 0.0792786270113928, 0.04381072288379073, 0.07722210272082261, 0.037293400815022845, 0.0316625915334693, 0.02065076376311481, 0.004039617945506636, 0.010078877742801393, 0.05280912521162203, 0.010840005740257246, 0.037231362358267815, 0.06084865917052541, 0.07243579812347889, 0.058456687522786, 0.02538384068092065, 0.06268446280487946, 0.04263092012011579, 0.045967731425272565, 0.024069587899638072, 0.018783075768234472, 0.0748349486717156, 0.054461558149861436, 0.0183851777442864, 0.10649275314062834, 0.054268966162843366, 0.029902855067380836, 0.05233722785487771, 0.03359963259260569, 0.06157692402069058, 0.08463359145181519, 0.04552781342395714, 0.031478932459971735, 0.01730440038123301, 0.020864159633804644, 0.07834927152310099, 0.04398209708077567, 0.016093636064657142, 0.02167916840075382, 0.042022491339594126, 0.08662827406078577, 0.0212627192293959, 0.012469711996215795, 0.009193163930571504, 0.025293215543829968, 0.01298816703326468, 0.03560890370447721, 0.031299924744027, 0.01169528386422566, 0.03249539827395763, 0.05412164263959442, 0.03986461427328842, 0.049764548760971854, 0.038943034796310325, 0.026093423765684878, 0.05655965628102422, 0.05271171472434487, 0.07865632897508995, 0.03718232463247009, 0.023073895435248102, 0.026720081389482533, 0.06323046636368547, 0.04560477965112243, 0.042213061292256625, 0.10569011406706912, 0.1333317511848041, 0.1374193818441459, 0.08141354245266744, 0.1413053654666458, 0.09206794002758605, 0.18678090455276625, 0.08687644824385643, 0.2483073387827192, 0.11520213686994143, 0.09123781350042139, 0.1038342190108129, 0.11402630353612558, 0.15458861126431397, 0.08553265713687454, 0.08873856546623365, 0.2459762452968529, 0.21289805668805326, 0.21530027421457426, 0.20134139752813748, 0.1056437361985445, 0.145126413287861, 0.13005978747137956, 0.12902897064174923, 0.15092695131897926, 0.17416980197387083, 0.1002821424709899, 0.17615733960909502, 0.12268792518547603, 0.11398660923753466, 0.19902586963559898, 0.20531655422278813, 0.1996313671448401, 0.10490188029195581, 0.09591822592275483, 0.1249869375356606, 0.10466342951570239, 0.1480435167572328, 0.12301724537142686, 0.144789045676589, 0.247983134750809, 0.09944508131593466, 0.11574709548481874, 0.11706430837512016, 0.10454088609133448, 0.26137448474764824, 0.11944099941423961, 0.09541202522814274, 0.11129244523388998, 0.12415859555559498, 0.11520550240363393, 0.057972763132836135, 0.10911800512777907, 0.08258719090372324, 0.11753289108829838, 0.14102580903896264, 0.1906382404267788, 0.17510756451104367, 0.1347388428236757, 0.07966366849307503, 0.09303561238838093, 0.0636240438159023, 0.10762444098613091, 0.11389698833227158, 0.18897512395467075, 0.17285298263388021, 0.07559809022183929, 0.1012799824987139, 0.10094969200768641, 0.12633824002529892, 0.09498975931533746, 0.18292993333722862, 0.09360948338040284, 0.09684792067855597, 0.14914745252047265, 0.10019764450511762, 0.10890567794974361, 0.15864413364657334, 0.12488285026379994, 0.10519700909831695, 0.056637887975999286, 0.14699760930878775, 0.19743581781429903, 0.07599786269877638, 0.06814420662288155, 0.07998462234224592, 0.06901848542370967, 0.11097632933940206, 0.07887616753578186, 0.14232631639710494, 0.1806382898773466, 0.06937930999057633, 0.16319527157715388, 0.16547149872141226, 0.11236927352313485, 0.08919411352170364, 0.060631731525063515, 0.17179408802517823, 0.1680144172694002, 0.13925175209130558, 0.07232010790279933, 0.13332706929317542, 0.12198433865393911, 0.11482883404408183, 0.12830976423408302, 0.12765670142003469, 0.10255655114139829, 0.0607644258333104, 0.09491402123655591, 0.13980935859893048, 0.12214508359985692, 0.150188786642892, 0.1228168604097196, 0.18386119550892285, 0.13848109915852547, 0.12644888194543974, 0.1088955949193665, 0.11640128466699805, 0.08810727684093372, 0.06993022614291736, 0.08569991601897137, 0.1217156523572547, 0.05558394667293344, 0.12337583755808217, 0.22025097427623613, 0.23058997520378657, 0.16691840679517814, 0.18977108624364647, 0.11392068277512278, 0.10121026302554778, 0.15535663148122175, 0.10192861447909049, 0.12711156638605253, 0.21498160702841623, 0.12798718868621758, 0.12022686510213784, 0.20652578505022184, 0.13012071991605417, 0.06512344335871083, 0.20064171935830796, 0.11145886951791388, 0.15766070570264543, 0.14096288170133317, 0.14957695161657675, 0.11443608440458775, 0.16724034452012607, 0.10195344886077301, 0.167193077770727, 0.17377790728850023, 0.05912266964358943, 0.1989779243511813, 0.12051824160984584, 0.20320398972502776, 0.04302845343149134, 0.07345914428255387, 0.07137825379946403, 0.14407769670443876, 0.09362689458898135, 0.137022126732128, 0.06548966227897576, 0.10851223620453052, 0.1297457478940487, 0.18403038143047265, 0.13554878293403558, 0.15721783946667398, 0.10265337808855943, 0.11176759616604873, 0.15408865309187345, 0.1662853607641799, 0.12954404657440527, 0.16523694273616585, 0.11829639226198196, 0.21850711213690893, 0.20145266370049544, 0.09535532684198447, 0.18964282955442155], [0.03618026411693011, 0.059696723840066364, 0.016467919373618703, 0.005784609845639872, 0.0040297834285801006, 0.010955612840397018, 0.03867863344826868, 0.05375251619677458, 0.009204965350883347, 0.04066614394209214, 0.056645837013742754, 0.02075197235015886, 0.017720561175208007, 0.0024744696316442317, 0.023445350949519446, 0.023349326370017867, 0.004694501777911293, 0.046515153122267554, 0.027821616835093925, 0.09996731579303741, 0.008149328558439655, 0.07171411506299462, 0.04771826695650816, 0.03407065124650087, 0.03446484277290957, 0.037383116715188534, 0.03806872206873127, 0.05468297769714679, 0.0708911402949265, 0.012264370336197317, 0.03852963733619877, 0.04950016437630568, 0.023346306889184883, 0.01903652386473758, 0.0328756492984082, 0.05202288293678846, 0.0076211212768352455, 0.0671492028715355, 0.06133254284837416, 0.04493633105552622, 0.03458415637058871, 0.019709159021398852, 0.02749465625467045, 0.04416090802156499, 0.02144703478552401, 0.04040608861084495, 0.0668110345889415, 0.031489198694803884, 0.09924964965986353, 0.08667162566312722, 0.029393967374094894, 0.01234531362674066, 0.13181118134941372, 0.02907367509656719, 0.01252181754846658, 0.026138685444103818, 0.06677910951631409, 0.018884331852729832, 0.021497321015756046, 0.048122158141008446, 0.04103476148364799, 0.01996560624268438, 0.06505935572619949, 0.015080233836280448, 0.05382778269371816, 0.11417088577789919, 0.023453483191717948, 0.03630488385845508, 0.03676722065678664, 0.01521812063375754, 0.04343556087198002, 0.0443590063202594, 0.01795761925833566, 0.03625550347247294, 0.010483470362877207, 0.05266129957245929, 0.07171581140054123, 0.01303349995786058, 0.020685616714347686, 0.017799094818266373, 0.022057353286072612, 0.04033967699589474, 0.024378031259402633, 0.03542117002819266, 0.059184647032192776, 0.03231356106698513, 0.03085513486127768, 0.031819814882640324, 0.04904607177845069, 0.020255647732743194, 0.03154134411098702, 0.025871010164597204, 0.025309983840478317, 0.036745823054973564, 0.05979264833565269, 0.021713361476681063, 0.03779887208448989, 0.015455572267196007, 0.028055192337238362, 0.046251976529934576, 0.09739163757434913, 0.03112111719591277, 0.019212630843477588, 0.041993283799716404, 0.03940493054687977, 0.024376859090157917, 0.041374680386590104, 0.022063426174489514, 0.06008268812937396, 0.045346098353288004, 0.013656084675208797, 0.01876240928790399, 0.031098610189344202, 0.011330762977844902, 0.051388164316969256, 0.13901676184364728, 0.02280923624389938, 0.03736525088814752, 0.043732922058552504, 0.03665729459109051, 0.0710076108308775, 0.06919575269733157, 0.030038063347871815, 0.039918340676065, 0.008250646559255463, 0.04694893038166421, 0.021390789321490696, 0.04474055673927069, 0.026458928527842675, 0.00921531131358019, 0.039683594701013396, 0.05044288361178977, 0.047432220341371636, 0.04694454026009355, 0.008330539816857448, 0.013075642071531286, 0.03135049256629177, 0.06973724399826356, 0.06073615127908332, 0.04856519401073456, 0.04468788206577301, 0.04303237536389913, 0.037029155530035496, 0.04748456592538527, 0.02200708401921604, 0.08031086876456227, 0.025180487128506814, 0.06757441362632172, 0.010062133194878697, 0.01958919403010181, 0.05464796189750944, 0.008125022585902895, 0.03879561288548367, 0.008812385345143932, 0.012182904573689615, 0.04841624878879104, 0.012020688903118883, 0.06896175311080047, 0.01815982099755534, 0.012019211393115776, 0.04117067204788327, 0.014887568906747868, 0.055788056791893074, 0.051099132147750685, 0.03798055662108319, 0.004899557605053165, 0.017434796152104224, 0.05785106787724154, 0.04887654658939157, 0.04025221383199096, 0.04055985143142087, 0.05420325004628726, 0.0812564276690994, 0.03209219580250127, 0.04869493329897523, 0.03781513996156199, 0.03778464659782393, 0.02298650860653392, 0.11636073541428361, 0.0021892959942176405, 0.04298603142212544, 0.052490997460803816, 0.08372125362179109, 0.032397190508033545, 0.025519983643399816, 0.05325134005397558, 0.04413787175768188, 0.05681763529511435, 0.014373203739523888, 0.04491996479087642, 0.01099340130375432, 0.051341993401625326, 0.02334831196016499, 0.024070610791178684, 0.031441721599549055, 0.09153858771813767, 0.02508965503823544, 0.040980817949665446, 0.07229988077389342, 0.01817110164224037, 0.043285414643053494, 0.028989550324955156, 0.044771603109048944, 0.023574331974876777, 0.0736410663064037, 0.07990051114133426, 0.028067022595288496, 0.04936272032292826, 0.018422198614903858, 0.01584123630475785, 0.05926496522235019, 0.02045047209997262, 0.022430193011782, 0.04104982835373708, 0.06072275021246501, 0.004938127231850688, 0.018456023585583483, 0.013512646613110389, 0.05206686896937234, 0.04005219527919378, 0.04667861560093505, 0.014305833693859833, 0.03201970451378396, 0.04060856006773455, 0.032724590439881594, 0.04017589221309338, 0.004778826293269438, 0.02857422921806574, 0.022160650064636554, 0.03955769592097827, 0.019538733077102473, 0.07528277499867336, 0.05470886720078332, 0.07729899430913584, 0.024710023176989386, 0.05482220969029835, 0.011992773124282914, 0.037650788602020056, 0.04314951764951859, 0.006531678173424942, 0.010856969115723456, 0.0474278709319021, 0.021977386237787347, 0.05406951418678675, 0.05228083820215293, 0.05939713705863271, 0.024083502956533005, 0.047984690338905366, 0.017498312118862356, 0.022741247035030807, 0.04541176018704261, 0.06860039250126906, 0.05515200485076223, 0.019951638599325503, 0.03564979222470096, 0.03762290759810379, 0.01197309815324843, 0.06687146491770234, 0.03732185178835477, 0.016563655575737357, 0.06345016921737365, 0.023309491275410568, 0.018503229266830852, 0.0251831537711301, 0.0165392351004162, 0.07759045224104609, 0.017169336289433495, 0.009647118276916444, 0.07589853195739643, 0.0441368098503777, 0.034935104860258956, 0.04922148325879659, 0.04826363269239664, 0.026167005799444656, 0.027971148989828568, 0.014462884016601103, 0.045555494260042906, 0.02216807663041566, 0.017110656581020782, 0.0727694405774985, 0.05766115949622222, 0.02360523245962603, 0.026858606009877155, 0.05730161057519061, 0.10744049014257533, 0.04018626022817833, 0.04127020634976881, 0.04672226236600961, 0.026396756060421467, 0.018011308341686214, 0.043119896203279495, 0.041592415488724194, 0.005691165819631091, 0.05901672997112785, 0.029886593975658928, 0.03163033737135785, 0.03866411279886961, 0.05423863225483468, 0.060155922413936684, 0.029790547343769243, 0.07750205948416676, 0.07445250597915479, 0.016884841823152134, 0.03183213707857898, 0.026958294678479433, 0.05842740195138114, 0.04258555326876896, 0.049521066647555144, 0.030419579840132167, 0.009600379936663168, 0.04035917130698051, 0.0007764403593942656, 0.06720237966094698, 0.08306563951607261, 0.04429131227412394, 0.032203645179314275, 0.037185486605657, 0.07999729737639427, 0.07171881731067385, 0.071587507213865, 0.017126642866060138, 0.0641435980796814, 0.03819197116951857, 0.02384456024239106, 0.05228066856839827, 0.02143987624107727, 0.018997867724725177, 0.020819915757913674, 0.0473282178863883, 0.034905130575810156, 0.010369064269720443, 0.024288537579455545, 0.01003066443705133, 0.038394768323217116, 0.043481453587966304, 0.03280559055773275, 0.0452509643509984, 0.006561666028574109, 0.013553904934919305, 0.005723484018484929, 0.045957685714321475, 0.03520489716902375, 0.024447837245783637, 0.004979487757996789, 0.05566286708095244, 0.023542038797001754, 0.0656410027295351, 0.04931209821786199, 0.02296570811553725, 0.1307633604322161, 0.04860633358891521, 0.05554250514666949, 0.16660830272095545, 0.17378545259790762, 0.22774164804390498, 0.11058840408389058, 0.10465614883495228, 0.08981920033693314, 0.16418343569551194, 0.1055435301469905, 0.08244938044143574, 0.18905542178877763, 0.2309552984578269, 0.22281168401241302, 0.10743141134402581, 0.15518965758383274, 0.15574183581130846, 0.20322544500231743, 0.09695415212107555, 0.21297642748270715, 0.2019210835652692, 0.24267929792404175, 0.08908166669841323, 0.14124678075313568, 0.24271013055528912, 0.14589450135827065, 0.1268894411623478, 0.09720057568379811, 0.10210267228207418, 0.10918472547616277, 0.1634753979742527, 0.09552373244826283, 0.14007372941289628, 0.16788089514843055, 0.11321424639650754, 0.15718374986733707, 0.1313436978629657, 0.20148668544633047, 0.060658011186335764, 0.15992539775158676, 0.10601477950279202, 0.08952813595533371, 0.07067688607743808, 0.1602101381868124, 0.11846983938344888, 0.09295904649687664, 0.0873902417453272, 0.19080051886183874, 0.1126289488747716, 0.1936923401164157, 0.13587141276470252, 0.2176355474761554, 0.15324086429817335, 0.0578834204269307, 0.14399296125130995, 0.1760290829198701, 0.07516916109515087, 0.12132302485406399, 0.1916223740471261, 0.1812884621322155, 0.06539585481264762, 0.21266301215759345, 0.08338197932711669, 0.08496862490262304, 0.10031255441052572, 0.12277145284627165, 0.18379948953432695, 0.18670826059366974, 0.07131504147712674, 0.14953044482639857, 0.13664528195347103, 0.21398433697010788, 0.14469349437526294, 0.1409966998866626, 0.1351214958620923, 0.08050012575196368, 0.12528451585343905, 0.14332237866308006, 0.13997504327978405, 0.1735796664974519, 0.14604239485093526, 0.09166638300354991, 0.0859441411282335, 0.14119628417704785, 0.10670913795807532, 0.12360739441854612, 0.11958198542041437, 0.13170458349798406, 0.08063391928694078, 0.12072305061987468, 0.1469548616026129, 0.14815915269511087, 0.10804706652249609, 0.06903805437364749, 0.13275505070175442, 0.09669833763369493, 0.15700138679572515, 0.17307706203843864, 0.0815825451697622, 0.1471458827810628, 0.14957112978611672, 0.13767182401248387, 0.2609581085188048, 0.08823775233966963, 0.09528127831539937, 0.11091116283621107, 0.16703888747308934, 0.08957862574607134, 0.08975306352866547, 0.05721745187682765, 0.19530715846589633, 0.14044867429350102, 0.12793846987187862, 0.12047444895974227, 0.12095049555812563, 0.06106949517769473, 0.19976773911288806, 0.19012920345578874, 0.12973147151725634, 0.15589589040194238, 0.17881223000586033, 0.10045919261340584, 0.1861177451376404, 0.12071888441486017, 0.1517474087221282, 0.16610956591154846, 0.12746726801352842, 0.21701210950102123, 0.12698747590184212, 0.19157981633075646, 0.11392845878643648, 0.10620797199330159, 0.1672370739813362, 0.20939782022365502, 0.14199040085077286, 0.10194022421325956, 0.12917417713574, 0.09321342927536794, 0.15104101305561407, 0.18372897617518902, 0.10001101344823837, 0.17859664585973534, 0.09464310934501034, 0.1678551243884223, 0.14512649471206324, 0.16849749349057674, 0.08030118606984615, 0.2919823851968561, 0.10048653078930718, 0.10890802568090813, 0.12251259173665728, 0.11786903733653681, 0.12098063608365399, 0.12062501588038035, 0.149005014449358, 0.1115276865395052, 0.0749907267412969, 0.12053949332662992, 0.09476931685847895, 0.18861522898077965, 0.09286104568413325, 0.12109507779989924, 0.09894359643970217, 0.10239222353058201, 0.08737010282597371, 0.08836367486843041, 0.17068525323910372, 0.09925664535590581, 0.0804082453250885, 0.11657645526741232, 0.2011270618864468, 0.12773788134966577, 0.1719664494906153, 0.11328456976584025, 0.19781088483120712, 0.25071483531168526, 0.13352605647274426, 0.18112383596599102], [0.00862075518151479, 0.13904851728252002, 0.03212817172919001, 0.025257041145648276, 0.014352615290720547, 0.01877135068311223, 0.030837723652699163, 0.020130184911457554, 0.03090914964143719, 0.031158803030848503, 0.052003717715186734, 0.020861007838643024, 0.045178608769284825, 0.005889372683928481, 0.0190693191585264, 0.04036711695204888, 0.034222958609461784, 0.08391328581741878, 0.023607335918183838, 0.04202823853120208, 0.0732996885531715, 0.03478205110877752, 0.08859875332564116, 0.04179172497242689, 0.03351128733317767, 0.02649445322874401, 0.017583702358284166, 0.020267666284261004, 0.055164567926632505, 0.03345083664836628, 0.06072733032384089, 0.047806276341101954, 0.054406983578311544, 0.05559309332498482, 0.015012773884726422, 0.028350258379110267, 0.010998670128174126, 0.05379948778344052, 0.020729344903624485, 0.0773265292601926, 0.017596107674762607, 0.026588744151272943, 0.05278927806232657, 0.07525357763682093, 0.04117360671183892, 0.018645860720425844, 0.0062279964331537485, 0.05759911425411701, 0.03300476433443172, 0.03585172763892582, 0.02083914035132953, 0.054703723905341964, 0.03423043945804238, 0.025379798308547055, 0.060779597876327376, 0.05164414843810456, 0.01772028297585036, 0.011768165310578687, 0.058187960514000485, 0.09758660104125738, 0.07312530505337886, 0.03568343059825046, 0.02400521358608135, 0.08189604191907815, 0.03081919964669006, 0.0695177854171821, 0.042393633031419346, 0.03470483382365533, 0.08288856223225594, 0.07930913394583122, 0.021170652205390588, 0.029035724632974182, 0.058815428987145424, 0.039389619404183965, 0.02960374326046024, 0.046202959160187414, 0.043912944184350114, 0.01912333902769855, 0.005062165129597166, 0.0565618242004088, 0.02998486959508487, 0.025192570140851394, 0.049050349941743274, 0.021050984073164206, 0.02030980839793171, 0.00792315587334867, 0.004951848906265306, 0.028714577401322976, 0.09536018515271799, 0.06748307602746145, 0.10217883105256728, 0.016900895961693356, 0.009093582979403436, 0.10117058229765721, 0.051483125292829106, 0.019822416694036553, 0.04786882709179606, 0.0305045561731926, 0.052460198756307364, 0.037435553901429684, 0.015194853667968085, 0.05224664682256324, 0.05864105227270296, 0.04057352730472173, 0.05178693934742894, 0.05295178719929286, 0.07739336495952946, 0.01689763899360384, 0.02690023074059614, 0.018872065635930215, 0.0766084220792566, 0.01601217284665576, 0.03626680447320853, 0.06104565824248961, 0.05056202079036406, 0.07111532147973776, 0.03812553580584271, 0.022634355717205575, 0.0077854166572381344, 0.042883206225399456, 0.0042527962609061176, 0.08923211148274796, 0.028459692506917884, 0.04337789896609528, 0.02385265177248844, 0.05899697781673499, 0.03419505385681987, 0.04536554855959756, 0.0070073905933116165, 0.026235544621678333, 0.04377020416515214, 0.007048903365752527, 0.047834072528140884, 0.035174207030130286, 0.037932319566607475, 0.00852247532124498, 0.052513294121516604, 0.015038335995216454, 0.028100107962797796, 0.04206067589776857, 0.053624768408813646, 0.024904169009200165, 0.07453471049666405, 0.047448606962071996, 0.02907056062083159, 0.03917129397658365, 0.018624110280403068, 0.013373830222657748, 0.05244907417467662, 0.021498610232291476, 0.06105116116149085, 0.023116073172007288, 0.0423007314093411, 0.033360259008726904, 0.08007061308515923, 0.025219000776165297, 0.027613951192636575, 0.018430926271581223, 0.06144718133977481, 0.016750963471297706, 0.017628126045955077, 0.024210746932242597, 0.04464474080928734, 0.017458056332543492, 0.02541083619663758, 0.04187508639214294, 0.035803337914070914, 0.02750288349177156, 0.047070846161139865, 0.03318802985761847, 0.028131619129063826, 0.044178594036826065, 0.05224936096263783, 0.006567690571370933, 0.011228207498788834, 0.058471676361347945, 0.026412375936550752, 0.044045882765203714, 0.011224152403883636, 0.06634434498846531, 0.01906210633127817, 0.10641753074846097, 0.058582128291683536, 0.04377003792407257, 0.02136604823837323, 0.07066178867327315, 0.012402687155242478, 0.05110805488324591, 0.041591767487781386, 0.0308765121070402, 0.03124560123043401, 0.03151932564963188, 0.004818539251573384, 0.030715689129595245, 0.05519571607666356, 0.04357778520456382, 0.09648033790290356, 0.04677033996475594, 0.06888087173657757, 0.06257939844259194, 0.0650589486051883, 0.061095327005854676, 0.025887445979086415, 0.04060423779966576, 0.05441180117694395, 0.01048295637260058, 0.031817314481096606, 0.02363065377409969, 0.05521545805303114, 0.02886092722682016, 0.050471677245306115, 0.03063431242480874, 0.017074307460071783, 0.05566214104848249, 0.0298208405396768, 0.06528247839638165, 0.032304943672248294, 0.03776800552649157, 0.09353050190423216, 0.0739152758781399, 0.06638996289776904, 0.028784385084041526, 0.04450931879026549, 0.0132732221391052, 0.027092174726671407, 0.01612040427114282, 0.06074286199041775, 0.03368730949504035, 0.0695898322654622, 0.03637124797595399, 0.05268179133002247, 0.03595620506842222, 0.05534425078492079, 0.012711313719462072, 0.02478373922141535, 0.0815272174243416, 0.03295827790030411, 0.04602567492319005, 0.029089668166956732, 0.040041654237679074, 0.029716960220996822, 0.009881597926973231, 0.02466471230478159, 0.025260328647813628, 0.0065813439681993, 0.04162500552566988, 0.02941158214317901, 0.04056961555033922, 0.02936890229050602, 0.060794003174773285, 0.0170392831787467, 0.04843931897942509, 0.025073017359578183, 0.06588560781840767, 0.025421894621104002, 0.07294091316206114, 0.014350611916077989, 0.041466292792132924, 0.041305466422012875, 0.02379560563713312, 0.029685347274477993, 0.02342737146786281, 0.009919281217402645, 0.05698786276791777, 0.04568435823810952, 0.020529153324397545, 0.047894258584294996, 0.04624621576762625, 0.016591962360377823, 0.043148811973099194, 0.051313647601221285, 0.01443201576226524, 0.08461307255285126, 0.012001004602227892, 0.03899277141317725, 0.021712983193408166, 0.015845410991460085, 0.01576199189626745, 0.052761821142796955, 0.008341098669916391, 0.11058425823492662, 0.022587803125913655, 0.01562493121517556, 0.007360682573302516, 0.050065027815955024, 0.015423894859850407, 0.044073550030589104, 0.02252004461895142, 0.027745030587539077, 0.04477320445169296, 0.016400629055819342, 0.03233557952834027, 0.008532869629561901, 0.03794664004817605, 0.03132689990369337, 0.025347859665219272, 0.04807790408709219, 0.020562464304800545, 0.031028168076383214, 0.019694797827729156, 0.026525779494217465, 0.16416400245257787, 0.07198332383164338, 0.015523081412538886, 0.013330166494207723, 0.08143712832991566, 0.029579743476850644, 0.01228529041899102, 0.018675599213955656, 0.024308352498337626, 0.025998471271512762, 0.05292268483234303, 0.0182882863362985, 0.04224476244832788, 0.05999321650181498, 0.028825029331658567, 0.03255258859800441, 0.047048902338636775, 0.039923704495387416, 0.05316948837467602, 0.05340085524533476, 0.01562892269742276, 0.04947833590475576, 0.044588948267378976, 0.03341026703960129, 0.03994477979306664, 0.03724702633917332, 0.036358969884791544, 0.054648894883160076, 0.02996846940368414, 0.03675950910629971, 0.06664938719144889, 0.021556674170174768, 0.039212738895522695, 0.011138252415029066, 0.042039101876850636, 0.016363138299701468, 0.0442127650603652, 0.0933504051395825, 0.023739402581538473, 0.021352204427655255, 0.05518040493396776, 0.018263095723731176, 0.05969362972038133, 0.008326288794965615, 0.015283889336777585, 0.03518717383433666, 0.011558718513697386, 0.04110878626150744, 0.015486018133482762, 0.04407989094033837, 0.00927554486718561, 0.10787147523037025, 0.25358883823667255, 0.10921952075191907, 0.14280028667833122, 0.09889341198972293, 0.18706629638160976, 0.20634012429841928, 0.18273469167096273, 0.14859137950198992, 0.19246545380779675, 0.1157544372337205, 0.17626046336122922, 0.1496625148824283, 0.09844314293669802, 0.09445387949900967, 0.07962128719581024, 0.2320391631552151, 0.1436779038714511, 0.09146795222269637, 0.11101843922265939, 0.1344390796231372, 0.08577091113797256, 0.24959422115768704, 0.1116382402500936, 0.08804128252501998, 0.13985613680311612, 0.11954504597399916, 0.10232946582670722, 0.11295774658875805, 0.06380844927792038, 0.14060704436685356, 0.11747955823583262, 0.1383660060486623, 0.07429999844836337, 0.16080210570778164, 0.12633106112480164, 0.11349563486874104, 0.17992402320461615, 0.09896117728203535, 0.18013119351650986, 0.07003556870456253, 0.18312848625438555, 0.2006908995764596, 0.14435776881873608, 0.12343320090855871, 0.08554579357483558, 0.10368865967861243, 0.16828614340296813, 0.09814855695835181, 0.12129399712596621, 0.18873439330075467, 0.15477670117148332, 0.19925530946680478, 0.15209810276116642, 0.1652062458119222, 0.1807626382048641, 0.15479812930737222, 0.13542419033391134, 0.15862323476799897, 0.2327607444354466, 0.12903714020337376, 0.14851224874811514, 0.13199351727962494, 0.28754484759909765, 0.09745989141187497, 0.11883214994200639, 0.14641520913158143, 0.11160152472023453, 0.20066408387252263, 0.16929897905460425, 0.093538718963308, 0.11270656649555479, 0.21176260975854738, 0.14499324400510105, 0.09054730233869382, 0.15355794371238776, 0.19333988188632897, 0.20158341739858898, 0.1541627219745091, 0.1336406474666936, 0.1403075661510229, 0.12312271685472556, 0.10309842242194073, 0.1410160788467952, 0.11288934347352811, 0.051163969561457634, 0.13360106173370564, 0.13901636829333647, 0.17057435347565583, 0.21896612750632422, 0.16968349127897195, 0.09874515208814826, 0.06306936179420777, 0.1353067902049848, 0.11717752872833184, 0.12531814404896327, 0.19447042979300022, 0.07204705862594502, 0.16569108622414724, 0.10589328780770302, 0.0947033768253667, 0.18520545480506762, 0.13322743321103708, 0.10221620476139442, 0.20184705539473466, 0.14322530744331224, 0.15683762915432453, 0.07261042589587824, 0.10732721550656216, 0.11579372441130024, 0.17266935748713358, 0.12221380562654563, 0.13982059513883932, 0.19523479949150765, 0.13576568343809672, 0.18049742600747518, 0.13347435210432324, 0.08067636165235724, 0.10695891348378998, 0.17219686641224793, 0.17158167942294053, 0.1471193384911333, 0.12441092915832996, 0.12534281558224133, 0.14300364362342016, 0.20775370273206914, 0.09508499849055495, 0.12341573541717869, 0.07069707249424287, 0.14771851205400058, 0.08114134134458643, 0.13174910896590777, 0.15284146501549653, 0.16412524453231267, 0.12954249951456273, 0.07773702259042434, 0.14921109910522187, 0.16865127666720323, 0.12319466870810304, 0.12225230570350375, 0.1765860923166786, 0.1586978193372488, 0.12977850756474904, 0.28697398251720835, 0.13379424065351486, 0.15242791149233068, 0.13496406216706547, 0.11748666928282805, 0.1298252586275339, 0.14855226874351501, 0.13968232327273913, 0.1889879075544221, 0.09327570521937949, 0.1488357199622052, 0.15111261207078183, 0.13543493832860673, 0.10663320310413837, 0.07954102328845433, 0.12029900694532053, 0.12914962773876532, 0.06981602191392865, 0.16735512550388063, 0.19845968644533837, 0.06567029508629016, 0.08024547155946493, 0.1184111868164369, 0.157701187101858, 0.19985862209328584, 0.09396568033844233, 0.11192661763301917, 0.13205614606184618, 0.1601854395121336, 0.05930015404841729, 0.16443139953272684, 0.11418038526816027, 0.17496543856603758], [0.06804355952356543, 0.00913830437431378, 0.045372452653412304, 0.042523850686848164, 0.031583766120352914, 0.027006474057478563, 0.06383878657860415, 0.11383441383285181, 0.016111059147598486, 0.013602995247180973, 0.07372866517731122, 0.03623103889237557, 0.01594457040274782, 0.029841328904564892, 0.03965288420606937, 0.01883308549544641, 0.0028918163776065087, 0.06426002790353127, 0.05429211438500455, 0.02404555588561509, 0.06678140296467713, 0.0564211062155664, 0.0455585103482008, 0.06091794438127961, 0.0390661922948701, 0.038776498554008346, 0.03597061036686812, 0.03412971432719912, 0.006267656804993749, 0.012745828251354396, 0.04496659371735794, 0.05247620879007237, 0.02185636612453631, 0.0292496802950544, 0.01645190085816596, 0.03014964164633836, 0.03114917461893388, 0.013230242034686463, 0.02421480287531657, 0.04104473934109722, 0.023036733768614273, 0.05931691386337791, 0.030502893762396913, 0.013892164819740822, 0.06576298975518771, 0.030495619866997004, 0.05167522873463375, 0.052760362292506864, 0.005891180131584406, 0.017855141810806732, 0.09054654916482312, 0.022921572805249264, 0.047215228235082965, 0.01941231352144054, 0.027461789714704667, 0.008530733940590705, 0.021625738857047896, 0.041729360818862915, 0.07531961266483579, 0.01393874709693981, 0.04435306235349604, 0.04463362979835697, 0.04728623013943434, 0.0893762255353587, 0.021767030203981057, 0.0415227808324354, 0.04914047974827034, 0.005095441759164844, 0.0877880057586091, 0.024284761532076767, 0.03282970908497061, 0.01671148800025029, 0.04653284592287881, 0.019684484095445702, 0.02568436214434249, 0.04330440005287528, 0.056145281730485816, 0.05367382988333702, 0.05379434788067426, 0.04928084828757814, 0.04125310048194868, 0.04665460563930018, 0.01615912656831954, 0.050255794543772936, 0.0188792513217777, 0.02896431221493653, 0.015002751922500985, 0.020357750289674317, 0.02267053520439991, 0.015781611736331667, 0.029951292289687053, 0.10628261084535293, 0.03461222057896001, 0.026022813715306774, 0.02449919216867004, 0.022537868037553768, 0.0486590523671891, 0.012272067467815109, 0.059311797709337304, 0.04506977853764381, 0.03550507088324853, 0.04408598757748093, 0.024778475486008183, 0.02504618638860328, 0.057018939671771865, 0.013194702914915979, 0.03827265576858606, 0.02690134523436427, 0.018103168412510837, 0.038856138209147115, 0.027206149950091327, 0.01651592572618808, 0.049531824820275815, 0.044189593089478355, 0.03599042698208775, 0.041097156171287806, 0.02841552157354142, 0.06543222428964716, 0.04953839982460652, 0.05305289230974657, 0.029717428410159688, 0.049933198639856916, 0.07048878259956837, 0.0548426200236593, 0.08344721368380956, 0.031833490755941184, 0.060303564848644395, 0.041262732286538394, 0.014969164439077889, 0.04686619321416531, 0.03426917702225702, 0.031536268669047525, 0.012405643023417463, 0.01090645297829594, 0.03676734957844019, 0.05620967809643064, 0.027242141143817986, 0.026742013337622796, 0.06824467051774263, 0.03957597565438066, 0.04888670765129583, 0.027615849394351244, 0.009914508571715226, 0.05850989145359822, 0.026752332158918892, 0.024391220283827612, 0.0034032731741068085, 0.0608136739049639, 0.05155755719169974, 0.055589778681418726, 0.03494979853608778, 0.008969049751093345, 0.15221280232071877, 0.03435908630490303, 0.013494343130982347, 0.020190603365855556, 0.02337636599051101, 0.04439990841118353, 0.03538891247340611, 0.01432330088157739, 0.03273255644100053, 0.058015958672123294, 0.08612746771957193, 0.015338809961186988, 0.02655286661216191, 0.08319152133273226, 0.03167013345020158, 0.02567557681218854, 0.015507868657420789, 0.03064854469682489, 0.05027416587940284, 0.007004393164866737, 0.040157140897853036, 0.034628875220992734, 0.05894698335656098, 0.016370173011507307, 0.03756173766617264, 0.024472171207889915, 0.027158781420439482, 0.016188598736854534, 0.03768569922872952, 0.013639384232062315, 0.08678424890552248, 0.06380084290036134, 0.03137812251225114, 0.029247091683958257, 0.0221328640556229, 0.03813126603407519, 0.01289053856661277, 0.03058650963274496, 0.024891192026968514, 0.029110723108585392, 0.05704079528472253, 0.036089062225073576, 0.024930530094674656, 0.03475838380732706, 0.06686388568154403, 0.009474913722702434, 0.038972924263881784, 0.009120981375287687, 0.06427093874663115, 0.06421536672860384, 0.06098697174872671, 0.038117501951221905, 0.01656174210698477, 0.005454477962172989, 0.03354524461818593, 0.013345245238659638, 0.05056194615151201, 0.013482801250315138, 0.01710900434825037, 0.06336409705025808, 0.07616379165223666, 0.016359976326514567, 0.0339824790135026, 0.07098669838160276, 0.03433957503044179, 0.06672921683639288, 0.011417747774560536, 0.04182101732918194, 0.04016282702130931, 0.029290253296494484, 0.09128907003573009, 0.045183439938617606, 0.034194507636129856, 0.001717710869602992, 0.05747193643557174, 0.025830477875258242, 0.019869988784193993, 0.02928934745224459, 0.051674373780510256, 0.0024757883220445365, 0.03702900964500649, 0.04231732837589724, 0.03805968398228288, 0.019355849229863713, 0.008658079696553094, 0.031239769221948724, 0.02258729761732476, 0.04417774586805275, 0.03324467056830015, 0.016187555489263365, 0.11907947595630373, 0.026174347548346435, 0.013429530314169824, 0.04202266775869897, 0.0966471421665379, 0.06266532811735358, 0.034276311817978106, 0.03092170593195728, 0.02060637400219483, 0.010104696000260966, 0.0695889773113387, 0.030162767906274115, 0.04615399268056665, 0.045525730321449895, 0.017353638274861232, 0.039811437483876944, 0.04393842995965055, 0.0466248247373317, 0.023098422779834697, 0.039494836436850686, 0.0030481421521731784, 0.03900256606617144, 0.02198130138484495, 0.023043654825804488, 0.042214564247322936, 0.06028092213507209, 0.00895884882525674, 0.04202865922291364, 0.011826461646705866, 0.029996866094214574, 0.05220145978299635, 0.04638295414458428, 0.011776890422749733, 0.009763829692799066, 0.010353262037304896, 0.030722912134868757, 0.06994199194014072, 0.08144731314054557, 0.07175376864948443, 0.02336137036659888, 0.05009734304621816, 0.027984302391165068, 0.00354354693055419, 0.023668855295649598, 0.01722594307336424, 0.02942214354074427, 0.026341976232028434, 0.01661772294236081, 0.06541804290775742, 0.02316315332427621, 0.01626607047260872, 0.019262784759380987, 0.003858124670971717, 0.020249157545289824, 0.05671736139005848, 0.04142289708501526, 0.03460572699883154, 0.030106992327741215, 0.05537731918905463, 0.02317634065236364, 0.02126161491365305, 0.02732148563622364, 0.022748855108927404, 0.008484255139982062, 0.06943598123533384, 0.011212779308802314, 0.013681997079402208, 0.0067535998366240945, 0.010045136740830327, 0.05058225131194506, 0.015024337817781737, 0.036600450319903235, 0.05711353423872164, 0.018338884692639112, 0.035800043626555374, 0.027610677261171595, 0.015281407594946879, 0.01947042495677514, 0.06597866211086512, 0.017145736841484904, 0.0380744319409132, 0.031127719341644218, 0.03295507860769119, 0.05454539115141545, 0.07573995153818812, 0.04436654145164149, 0.08228523603507451, 0.031097212407205786, 0.03376258277733411, 0.04566611921680825, 0.010489262507430144, 0.023388876479917338, 0.02669418679683336, 0.02546772457260106, 0.12567521631717682, 0.017702793735744696, 0.021794197049790194, 0.005461155170840877, 0.022575698061180965, 0.058015476912260056, 0.02025288948789239, 0.040185442593480857, 0.02138378344742315, 0.04315511556342244, 0.019526899426377246, 0.07839626685849257, 0.07621624919452838, 0.030985016641872268, 0.016591151511030536, 0.013321038501869355, 0.12020566766815526, 0.10495882973607097, 0.16364072981689656, 0.15503348596394062, 0.17534935367958887, 0.08835125767758914, 0.18424896470138005, 0.16511783269899233, 0.14538991557700293, 0.10040880460292101, 0.1064060227945447, 0.14538208528288774, 0.20314872983310903, 0.08605747004704815, 0.12202317799840655, 0.09509584826550313, 0.12780842185020447, 0.15599019319883414, 0.14765743033162185, 0.11734393265630517, 0.10700632272554295, 0.12314863689243793, 0.13197587536914007, 0.10735604645950453, 0.1787641490144389, 0.12293793819844723, 0.13784136277224335, 0.12067305615970067, 0.06101146686289992, 0.10157948785594531, 0.09824976724173341, 0.1902402796383415, 0.13514483746673378, 0.11046364863536187, 0.12547027160014423, 0.12930318021348544, 0.15675144163625582, 0.07586343812623195, 0.13680732968662465, 0.1003773816462074, 0.16285254353923456, 0.15615404583513737, 0.10126184525766543, 0.10293215420097113, 0.16955300899488585, 0.14854857751301356, 0.1434841142701251, 0.11996158505124704, 0.11953146170292582, 0.09838101627039057, 0.21801260938601835, 0.07861199349697147, 0.08746350317129067, 0.09651155729911157, 0.13033972387867315, 0.06890795885452203, 0.18873243911990098, 0.13094507211021014, 0.19719596925590718, 0.13942481923316205, 0.15991074139518396, 0.09675571455487184, 0.09373962639697961, 0.1285449309008462, 0.11627327225037984, 0.09615920763462782, 0.12791742171560014, 0.09889044679169144, 0.1554702046726431, 0.15733112767338753, 0.12383766206247465, 0.08223190996795893, 0.1794899779238871, 0.08655344521892921, 0.09756918304732867, 0.10666852763720922, 0.13318503834307194, 0.1634148047970874, 0.11877338880939142, 0.16880147717893124, 0.11690297988908631, 0.09546763117292098, 0.08697913773357868, 0.1627341527491808, 0.13462977510477814, 0.1600514017045498, 0.08612885871636015, 0.08482396123664719, 0.1500482348991292, 0.08369216482554163, 0.08203617297112942, 0.17161751964262553, 0.08613942350660052, 0.12775416619011334, 0.10220790627811636, 0.10616803342210394, 0.13105085571961744, 0.19587507870580467, 0.1052657582664064, 0.14127176441252232, 0.12297764606773853, 0.08021378397409405, 0.19265985409063952, 0.12311842851340771, 0.21234382928482123, 0.06271021320883717, 0.13760585683797086, 0.09835427520530564, 0.13411522842943668, 0.07605739736131259, 0.05204976649422731, 0.13069774609591278, 0.09423040399061781, 0.14049666029001984, 0.1781736064170088, 0.10580004352544035, 0.1254208471093859, 0.16177816476140702, 0.08673819673380681, 0.11267892297889505, 0.20811803532498224, 0.11266174925757305, 0.14672481108989033, 0.14823445651148046, 0.1644086686096021, 0.10705887526273727, 0.1593419797718525, 0.12567117224846566, 0.06806157462831054, 0.10552147097353425, 0.13482922368815967, 0.206473103591374, 0.10849796661308833, 0.16639708834035055, 0.10148489328899554, 0.13199023317013467, 0.10678840441895382, 0.10057604991431747, 0.064372922559934, 0.09311200864613056, 0.14483015132801874, 0.13016124202736787, 0.13667059130966663, 0.10234783376966204, 0.1689397626157318, 0.09566663870854036, 0.1303215798522745, 0.21816225349903107, 0.11388086634022848, 0.1652911034013544, 0.11769123402025018, 0.08942396047392062, 0.20110575588686125, 0.11223971404667411, 0.16544519870408944, 0.111519964810993, 0.10066727894757475, 0.193074194714427, 0.10883746482431889, 0.08055208117834159, 0.189193883644683, 0.14108816640717642, 0.14175074228218623, 0.1900078406823533, 0.0853288998561246, 0.28066678238766535, 0.0733923628660185, 0.10045371005045516, 0.07917599858982222, 0.17635080351361207, 0.1647111459502152, 0.17929990669446333, 0.17832208344978945, 0.12936788531286375, 0.07495315625731434, 0.16382571203368052], [0.014032730982372803, 0.07807994740349905, 0.011577861682911004, 0.027001486825091497, 0.07190430164337158, 0.050547931010701826, 0.05583007846559797, 0.02785170477415834, 0.031257916641022475, 0.03859451546200684, 0.0432659847927945, 0.05368627082290394, 0.018609976395964622, 0.0420838546540056, 0.03737126949376293, 0.031829209199973514, 0.029302456748804877, 0.013471622385882905, 0.03941282190914665, 0.022305885396365608, 0.038783531569476636, 0.027046495749215995, 0.07218163926154375, 0.024401518749073148, 0.03805478156677314, 0.029556761495769024, 0.04584397681589637, 0.04038796494049685, 0.030028679208563905, 0.03554577959169235, 0.03131375328770705, 0.05638171386505876, 0.05628421516822917, 0.09236315025814942, 0.022515539146427597, 0.05934307138834681, 0.06107153756810086, 0.011092250285271023, 0.05069073888340166, 0.03633511259353586, 0.034168574027717113, 0.035967777483165264, 0.014644290353836758, 0.039079284628054926, 0.006398269282986543, 0.01467754365876317, 0.026359063440135548, 0.02636221862797226, 0.06353687242205654, 0.02126681588457099, 0.020710196645398225, 0.043831591228289266, 0.01982076106859105, 0.025785289139353802, 0.04535347402894071, 0.0317873944794493, 0.007896150179606463, 0.044538736675998995, 0.031316867763442655, 0.02704641771768885, 0.039907877666077445, 0.056432237582547326, 0.014880295011347957, 0.04117147611188037, 0.06951162431921278, 0.02887062349223665, 0.07340604213199445, 0.08281199634075165, 0.019822808548009822, 0.04492751010028379, 0.006001656234730035, 0.014291438573439206, 0.10148952089782272, 0.012680629517750015, 0.032013896254024336, 0.024119443260133266, 0.13236767505960806, 0.0036274100420996547, 0.015184848669118114, 0.020805834459939172, 0.1017738338559866, 0.036051179614982436, 0.07265759765037469, 0.022974121949768493, 0.04595939901524356, 0.02004033330428813, 0.07608603153909956, 0.07114032549517495, 0.013885521961908256, 0.0587231685806598, 0.04362863461886134, 0.017774241776870828, 0.0187033665632563, 0.01923076469185097, 0.011421774031727441, 0.02055397243904216, 0.033867178950458765, 0.05258811278534787, 0.02067381190136075, 0.10037806696657624, 0.030752258774425303, 0.08101146295666695, 0.02049686523553516, 0.03468209272250533, 0.09011906531772443, 0.016430430313838378, 0.03742011044440525, 0.028762441261538436, 0.030332388090235845, 0.012808331504597195, 0.034961886637445004, 0.039777765183576515, 0.049291362187692096, 0.01272853578640414, 0.05184720343511019, 0.019767725075195943, 0.01785129790992609, 0.05647997930645943, 0.04014264399717961, 0.009719243156723678, 0.03574683969574315, 0.02264108508825302, 0.038873125333338976, 0.02003617727729891, 0.027871154980467897, 0.019196483406371305, 0.04242656912122454, 0.05608265294826456, 0.047725384788853784, 0.05527889429192458, 0.005518106735377971, 0.04635962950331824, 0.03877949428611568, 0.01419880666903087, 0.02626270637847483, 0.01697716160145189, 0.021944314440978423, 0.06678065657615662, 0.03733323760596769, 0.05664082942530513, 0.03107389115861484, 0.03172124070780618, 0.03936530749446579, 0.03084067188735519, 0.03159563369782908, 0.04805216046848467, 0.047451022546738386, 0.05521676762561713, 0.017954126499327164, 0.00897547887039504, 0.014172354829497635, 0.04316190430628402, 0.0810005928256682, 0.04291041547964726, 0.023926919126617055, 0.01953799686660724, 0.011547336088759559, 0.011726072390696831, 0.014510069341797913, 0.0490928567679865, 0.026191680725397806, 0.029951431389365877, 0.015693035774997303, 0.027650844837938036, 0.03352060361898371, 0.04162887317527618, 0.019782615526180183, 0.04768766502716711, 0.08982696277754647, 0.022231480638895715, 0.020006520207971334, 0.043746431690773795, 0.04718803255153554, 0.006905159114726952, 0.0541760204359889, 0.04985025791185243, 0.058653388039341996, 0.0269129023820694, 0.1073180145717093, 0.022786702095930065, 0.019746466573061686, 0.045687170765761814, 0.033569746517709324, 0.025353978354749934, 0.06443551741540432, 0.07227300400180475, 0.06916675889598471, 0.03607140674388834, 0.0116841694606202, 0.07011062146297523, 0.04932422024597015, 0.047462825663387775, 0.06213945669255086, 0.021537078078836203, 0.023049656468044435, 0.05633807388533439, 0.038858360411333184, 0.02402798013229455, 0.0779682741101299, 0.06139235571026802, 0.052449966448226144, 0.06690304393747024, 0.04356920512925301, 0.015978081550981318, 0.021746881106602292, 0.009766480220215661, 0.011812147102318704, 0.003998386765098465, 0.02183273953518697, 0.012342970984588777, 0.025192439522860304, 0.07028096089405672, 0.014489635259711316, 0.020400065429774777, 0.03847491687961987, 0.06921666514660631, 0.03447482402303389, 0.021287414511399608, 0.04633345840764897, 0.053706575983336995, 0.05661568631018911, 0.015172628253432257, 0.015942409268713424, 0.014798389049246907, 0.021902062065367187, 0.016829987355907048, 0.01443305900985641, 0.0268131475563028, 0.030693484071109976, 0.04308731973703418, 0.07978879713586398, 0.04043916380032897, 0.02530792957570936, 0.01676608801686338, 0.033714936048324616, 0.05106917143400226, 0.047986783619437895, 0.09975800809583493, 0.04609374216358576, 0.05139536018084202, 0.023590182552912405, 0.03935941781050392, 0.010346819347302829, 0.052483245198215754, 0.031217604875564575, 0.06373214122972318, 0.030628887537334646, 0.02883747705657567, 0.048320717843515534, 0.04723912623843976, 0.034519834643495936, 0.012354828384039658, 0.02514790048423622, 0.05255660501175693, 0.05359120128144111, 0.00804785279823201, 0.08621480874717236, 0.032409071656210084, 0.03183126176840492, 0.019668874397341694, 0.03870310481371624, 0.020576031612498418, 0.01808039847362254, 0.06733379153800861, 0.08324133937380143, 0.017808492528274655, 0.012733452620783021, 0.04146547855011054, 0.040747432437326224, 0.07478216543261494, 0.017999059088262062, 0.011496127050902163, 0.037849443299429755, 0.052815120068511794, 0.014441457577049732, 0.04251674303252782, 0.025074793424989496, 0.05285018675827554, 0.02699790076751794, 0.042588002780186276, 0.1020138995455844, 0.03234848865707006, 0.03697601606005004, 0.019923557427578738, 0.035717991779425314, 0.04556713452828782, 0.03658978374941008, 0.009296964521386793, 0.009496111156685012, 0.04507400241813489, 0.05551328742876649, 0.017425235593691468, 0.00580214276643736, 0.12926514154034002, 0.027763883683032224, 0.0037121985057768014, 0.11007977423391171, 0.06570709882570164, 0.0482992489955255, 0.03811902186966368, 0.05135251747976456, 0.04258198756724596, 0.005407135301668729, 0.022957256961879984, 0.02558348773579512, 0.02644652151502669, 0.07707453492496695, 0.03924591586525951, 0.024383020188127245, 0.02319626583318625, 0.05745027759777648, 0.03149281867912837, 0.10451523068227939, 0.028825182002037764, 0.02483289738717888, 0.030084142660988227, 0.028400724421122243, 0.02159991890325078, 0.05903070100716182, 0.03598009967910392, 0.015216144400515726, 0.028281812855441655, 0.043452683703175614, 0.01457737323029765, 0.04865439422428608, 0.021419783122837543, 0.05606377949672086, 0.04500010995460408, 0.03770592296496034, 0.03580023700903569, 0.013738747203855642, 0.02802318414407117, 0.045231629495642016, 0.04678887754146542, 0.11227944905736617, 0.004258667709239359, 0.009813656215555966, 0.07024524281067507, 0.056779521983116865, 0.030774229738329138, 0.05311712921996202, 0.02346536603623203, 0.03945852124265262, 0.02807641351994659, 0.026368031976744533, 0.06471250219536678, 0.020034521651853408, 0.06477797403931618, 0.034363937830286365, 0.05330244731158018, 0.060960366390645504, 0.03797245152028544, 0.13195212664348738, 0.15837919286319188, 0.14939567420099462, 0.10448411306632416, 0.18206307770950453, 0.23069113120436668, 0.1715475083994014, 0.06938082312366792, 0.13798078814787523, 0.1411532921982663, 0.1734764613211155, 0.12073546781071595, 0.08251882850059442, 0.15804375229137285, 0.17875477166048118, 0.14678997759308132, 0.09623769378023488, 0.16267146968415805, 0.07607846587364163, 0.1396481522492, 0.13241268907274517, 0.141673850693873, 0.16036241501569748, 0.1542606752898012, 0.1234776856643813, 0.16529924582157815, 0.1780091838112899, 0.17556569778493472, 0.12826819717884064, 0.0966911180210965, 0.1358500931944166, 0.09693511921380248, 0.09084851760417223, 0.15681388042867184, 0.1272260488143989, 0.16400517097541265, 0.1016930542620165, 0.10591032582202128, 0.09612647510532822, 0.12109378858336381, 0.1567346275384937, 0.1413444219423192, 0.11253417110336678, 0.08375242552054779, 0.15881458164325782, 0.11432222622845854, 0.1067365575581789, 0.12450706399977207, 0.12162337159471852, 0.08340583661837236, 0.13949404337576457, 0.10184760418321405, 0.17421374390167849, 0.12563379853963852, 0.14024178896631512, 0.07979566391025271, 0.09659916974071946, 0.10602314583957195, 0.18432637197630747, 0.12685569083052023, 0.11481748893857002, 0.1883691514709166, 0.07148970317627702, 0.09657516317175967, 0.14484304349337304, 0.0727389200723597, 0.19283560823116982, 0.20750805948461803, 0.1065515074878931, 0.13336434800709995, 0.15932222083210945, 0.10141266323626041, 0.2238458256636347, 0.12207824790052005, 0.11549932163740907, 0.12813057670635836, 0.31855153664946556, 0.12178164667316846, 0.09470903580742222, 0.11529231417391982, 0.23460611541356358, 0.10249048897198268, 0.13329641308103288, 0.12312585168651172, 0.1396658755838871, 0.09920801475111928, 0.12932949380150863, 0.12641522660851479, 0.1863642026271139, 0.13452051739607537, 0.12317607684859208, 0.11789194467876639, 0.08084366124655519, 0.09639475428100143, 0.055713784348751814, 0.1429091372660228, 0.10628384577908687, 0.10116697927670819, 0.0931664067985756, 0.13449277888451303, 0.12675234994718007, 0.1440553321902241, 0.12560278948928627, 0.10840258494551692, 0.17093148002667086, 0.0768198264496667, 0.10272858012467623, 0.10449916975838797, 0.13401970426951135, 0.16869854341660226, 0.10022309635366712, 0.0892708965444139, 0.13187367442463124, 0.15249434007065638, 0.16079533392829554, 0.12249154358037881, 0.07218598867101328, 0.29833852127194405, 0.10245391593447753, 0.06624185227389846, 0.17676925605961255, 0.14780617877840996, 0.13874409933175358, 0.13118473067879677, 0.09172958175518683, 0.12057255155273847, 0.09153235876666647, 0.0918450141325593, 0.1789284087717533, 0.08923441850181137, 0.13851947709918022, 0.18869117062006677, 0.11637393970574651, 0.10951507703534194, 0.17154011236769812, 0.11667135517512049, 0.17367641202041081, 0.21499198861420155, 0.16762060911527701, 0.12690459963466438, 0.12137851544788905, 0.07375097540872437, 0.17380127603454248, 0.14702435715922288, 0.12276149195219789, 0.12184456044009753, 0.09781007654964924, 0.1271505957203252, 0.13775316679051944, 0.12122739212853567, 0.12437550963035651, 0.15741865869079316, 0.12858648438538822, 0.08174122058387313, 0.07663987217737095, 0.14868885784276895, 0.09582123612718922, 0.13552747693445, 0.34932719809668406, 0.10573869038905416, 0.10199158931417124, 0.07841506906385932, 0.1696952027933938, 0.1463038343936205, 0.14999954322619097, 0.11005265318921634, 0.17445583162563189, 0.10008266674620764, 0.14908509515225887, 0.19816883919494493, 0.07597551854061228, 0.10613569444311516, 0.09919795207679272, 0.11373328497367245, 0.1714068345193352, 0.14570001965122564], [0.020810161817020605, 0.014903468678572347, 0.008182184920380158, 0.02995752802650843, 0.009608909121847578, 0.021175478285710727, 0.04464693247739758, 0.01584662387280592, 0.0563075940922967, 0.046769162706498585, 0.029754876757838895, 0.042412750755569766, 0.06181596512241023, 0.001186472868929351, 0.019986700200076615, 0.021076575021392534, 0.013754241551006479, 0.03621630111177053, 0.03788718680984207, 0.04603596490674785, 0.09079297272754566, 0.05409529173214521, 0.021686075887243663, 0.035740627707647424, 0.04015563115743654, 0.012338474841921456, 0.028739740872489553, 0.06986212158309561, 0.04617071517610124, 0.060457341239920685, 0.0557775496771293, 0.029856925031968524, 0.02525701909326017, 0.02401607353905482, 0.006881646604077625, 0.03234053283397641, 0.04146890515195472, 0.006358882869660322, 0.04486874218231865, 0.06686467278216567, 0.06863015983253717, 0.027075531959001507, 0.030808563610272746, 0.07659483780818326, 0.031287979135023694, 0.03078114740284426, 0.05016888099323426, 0.04186514924679484, 0.05890056477593524, 0.05685702086027179, 0.04462329910269805, 0.020839001251650707, 0.007993166268404042, 0.012997789507997888, 0.043236817965017896, 0.020826450050143257, 0.019866630035851682, 0.025274601631930897, 0.038000580189483504, 0.044149987000439844, 0.019641999321590577, 0.06074606467570577, 0.07318374727453504, 0.046984994517905374, 0.028555827348359993, 0.04978813124554498, 0.04627984057047537, 0.048675971637879095, 0.033302804056022844, 0.05126834521070123, 0.0672507117103253, 0.04820170958659478, 0.03715107130951115, 0.010278333111533096, 0.0446039472839662, 0.02132285778809871, 0.03408985718020371, 0.00795687482293163, 0.04928473968591009, 0.04773598011316998, 0.05134718419451799, 0.03145125501656106, 0.03248106422168868, 0.07095094637147017, 0.022067658536668335, 0.01981627764845533, 0.01630248235804694, 0.028670686363641704, 0.03432503402499216, 0.02404518099501729, 0.0524667567972626, 0.03819815940888865, 0.10197004582732916, 0.022107132311378206, 0.04926798665629966, 0.015728797963155166, 0.11478983185120992, 0.02318067309845771, 0.020448578987270594, 0.05362782520907266, 0.0351834859965103, 0.024230924867359654, 0.011164806034815098, 0.12100256633545671, 0.009445552664276744, 0.05269539595714637, 0.03331177768164447, 0.019751597994140217, 0.04334684920364192, 0.029795239413423196, 0.08635847496667079, 0.01842672613981579, 0.02124009856821171, 0.0651485084422997, 0.021054449690771953, 0.02733058139814862, 0.06261715213102953, 0.06296169864279882, 0.02475030440837145, 0.03231857204809785, 0.05474977607705763, 0.021681115796257342, 0.031315425876528025, 0.03512028385219829, 0.03885294570188437, 0.013177345989138951, 0.07477120709206377, 0.04392891350601401, 0.01175458443218044, 0.043627111307744465, 0.01223148004750588, 0.036486273232315264, 0.04921546804585627, 0.08472903418753829, 0.011166373450708176, 0.022984376310237815, 0.004485472704150847, 0.018944095520834838, 0.004132553494335818, 0.058692166315657754, 0.022996764663340788, 0.08321596894945417, 0.06330837575452668, 0.07586184356893812, 0.03772258099966815, 0.025211355382842675, 0.06107397350881781, 0.07419322417782885, 0.017474188502611857, 0.02637936351155596, 0.049917707685381174, 0.06612300008003201, 0.02044670283794403, 0.050875239340322356, 0.028640433879835264, 0.03935139074123331, 0.013971593280855035, 0.02046301312345479, 0.051469201754246435, 0.03190668772107788, 0.03873828685443316, 0.038257812815053124, 0.014952179011223572, 0.06990027560719422, 0.04784998417432819, 0.04418215973834906, 0.05749372419502054, 0.06027014021362577, 0.06645149245326008, 0.004298780579119921, 0.015088997116046292, 0.039663421854908974, 0.029727640362190347, 0.03446590128753867, 0.033259459239031584, 0.013520403964711087, 0.0062726389483681744, 0.039990340026893785, 0.02284124104439148, 0.024913393692778688, 0.0457783489088927, 0.01657681236974895, 0.0609685495229704, 0.05025475299251931, 0.033683245070278645, 0.045332476762788634, 0.012322208661186908, 0.019155114822621857, 0.011248671266782497, 0.03751574995528374, 0.033233328855463436, 0.03876006782853177, 0.05298121865572674, 0.054354627816272635, 0.038238583132624626, 0.03332341794988938, 0.006078730603413922, 0.030998505918043, 0.022424201547567333, 0.09882285791848387, 0.03974166372790933, 0.05307551466726831, 0.01478440613885011, 0.01611946619647954, 0.025530602716441666, 0.07743270641991071, 0.007145765087833362, 0.013257335089812321, 0.010366927732580473, 0.08371136736656938, 0.02512644011793392, 0.01678768578650696, 0.013560761531282748, 0.033328588386731486, 0.042585081686930995, 0.09920992821987186, 0.019264257180371454, 0.04652933111148221, 0.03229784280327814, 0.026795570106644715, 0.036615581650819094, 0.018346937206972922, 0.051392255883131704, 0.03196459050689425, 0.03418710142640131, 0.059061262224401744, 0.023812190729326436, 0.017260728171095252, 0.06119693083954709, 0.025400220516270826, 0.058374103025666306, 0.03602971415966749, 0.06080637965351343, 0.043022899622363706, 0.0729934453432049, 0.07179997688425438, 0.011634116476800824, 0.012851530436559446, 0.014260256496657218, 0.043604590730475526, 0.04854813224769064, 0.0498206500363137, 0.03871776456279414, 0.03673893931720938, 0.028247533266299536, 0.03963791233088289, 0.05180857104382344, 0.0437929147322263, 0.046812063083052635, 0.0029246668023655987, 0.03630192883844886, 0.032986535491155725, 0.0358612814119884, 0.03650665981695056, 0.042145343497395515, 0.017892249194639068, 0.02817400042632861, 0.09858333505690098, 0.017474071455321143, 0.032666260177003484, 0.05675296751516206, 0.04462571468736444, 0.04055761226585933, 0.02937658330691712, 0.03568730842588203, 0.02823134681342968, 0.053684835721339495, 0.047176840116402934, 0.017634166703958596, 0.041646087608699284, 0.08863278864217655, 0.020680999283545783, 0.008158355618693998, 0.017789736124021665, 0.03512662476194756, 0.034535753075033426, 0.0682160702667066, 0.03220075462013483, 0.038797784197543345, 0.037519034064774, 0.01348805395952825, 0.04676904057019523, 0.050232890594218454, 0.041644503229430745, 0.055187862033822706, 0.03894773704398956, 0.020178445714658926, 0.014139239776081272, 0.0398384669263448, 0.07150400669447013, 0.022060620432187403, 0.010952907182010157, 0.06643680895545653, 0.06458865598376308, 0.05080928234383464, 0.028679069663797106, 0.07123049601380314, 0.056262410445404906, 0.08008750182177339, 0.019815884098144512, 0.028769878005342822, 0.011866229735980076, 0.039405113751334805, 0.044245022615151744, 0.025287378446332047, 0.04482039995491505, 0.0114991575579292, 0.038636411606733284, 0.014835074045030134, 0.045716527583343644, 0.026501755961882215, 0.038593965848641734, 0.01870097472731556, 0.026167937088757753, 0.026880047716466442, 0.029703922170613493, 0.050858011336198876, 0.04451156474117722, 0.05432978325656482, 0.04959783609956503, 0.042531711515039206, 0.03775706075664077, 0.0709768392677818, 0.09743294678628445, 0.032407914754003286, 0.014714450874765004, 0.04712361582954015, 0.0010794690627205583, 0.024632264760189822, 0.033568511583975384, 0.06791995079921824, 0.02078497120445328, 0.02870319497638515, 0.02464191522449255, 0.021178060111456683, 0.05460541096648999, 0.024507244683003852, 0.04712619086993592, 0.014354046999609895, 0.014303238297413503, 0.0517855517433158, 0.06603231387478964, 0.03595622881714787, 0.030977457761764526, 0.004296168219298124, 0.02879783364811114, 0.014268497304458703, 0.02255194085384054, 0.011031071023483361, 0.03466472561870303, 0.01939000837904002, 0.04025042589221682, 0.10596878161387784, 0.04560799590711083, 0.08606938512197562, 0.1595536284148693, 0.12150066532194614, 0.12802932571087564, 0.1687684596649238, 0.13774598789002213, 0.12990019603499345, 0.11502636915871076, 0.09336580109915563, 0.11185819416173867, 0.13972098619810172, 0.13318312487431935, 0.08629036362149886, 0.11563798705382006, 0.1595732516476086, 0.12204520324511187, 0.20573267260832445, 0.09124399495444127, 0.13444608210452966, 0.10438282135874033, 0.1163611968180963, 0.228833655161517, 0.1419152191707066, 0.15689280762204103, 0.11204572767019272, 0.13126565276512078, 0.09975309550229992, 0.1785202563873359, 0.15348292488072598, 0.12224412257117884, 0.08580903123532023, 0.17890081953789505, 0.12747747318020888, 0.13326947524079255, 0.121580162484731, 0.10389549072299685, 0.11036898621491023, 0.15967805816658906, 0.1326661626143115, 0.17943241101290497, 0.19684291391500405, 0.1743380515170949, 0.08214470464736223, 0.09866519352155072, 0.2299631174121584, 0.14420033512370928, 0.15671892623816217, 0.13879116252064705, 0.066752253100276, 0.11041934029864413, 0.10804004368505307, 0.06875243184289762, 0.1406743550407035, 0.19512493110128812, 0.1389425436833075, 0.07043706466044698, 0.15699120877044542, 0.11714144423604012, 0.09569233482969658, 0.13162211435181753, 0.13328060321509838, 0.1793489647763116, 0.12390474203441824, 0.15082297261272157, 0.07727420063955442, 0.10510329662689141, 0.13543170850191796, 0.10674130051795926, 0.2403480958725725, 0.11674706611250128, 0.10848586833370583, 0.10988774203828403, 0.12378244288265705, 0.0802117008715868, 0.12986443723951066, 0.14175500348210335, 0.17167784140578338, 0.10209267746124949, 0.08891130691128117, 0.13309583812952042, 0.11891677682953221, 0.10572332157088177, 0.175056307975735, 0.12240812448518616, 0.07485235988029412, 0.08908561577222177, 0.15286028757691383, 0.10047277688447918, 0.08962216733821801, 0.09556462096848659, 0.236229768288987, 0.13690905565662043, 0.1378197175051485, 0.05488317945439901, 0.17029149936778204, 0.08392335527709552, 0.07232917991599866, 0.13790663784103735, 0.15409299571599278, 0.13245847661580357, 0.10223709006926843, 0.11917867777603013, 0.09706316555717162, 0.11469300490404878, 0.13391147793403693, 0.05644834939656513, 0.15640314961118357, 0.18500211143067904, 0.13555849955550262, 0.12720924828733715, 0.10047667167548623, 0.22287742048501968, 0.0886953224294952, 0.07959754525550775, 0.1487299363527979, 0.13585564361086913, 0.11147067602723837, 0.18964508229068347, 0.2308581051017557, 0.10226995152022157, 0.1724747536437852, 0.14163900113531522, 0.07871209776827268, 0.13851866285715783, 0.22247304075530597, 0.16192111851913588, 0.1244854594447783, 0.08427468035370111, 0.11202478129416704, 0.17106918192335538, 0.11483438446053437, 0.1166552331830774, 0.10265644506684371, 0.08486410336835043, 0.10952264948615006, 0.07013449232493128, 0.07387967314571142, 0.10657292883843184, 0.09141762528036322, 0.1803043692239693, 0.20127043633588723, 0.14613934393439973, 0.1257540892277445, 0.16444703297955648, 0.1912294208471264, 0.14898646330194815, 0.0917057516053319, 0.11087465765220778, 0.10754841792264155, 0.08814110859696354, 0.16628293160881313, 0.12243758647569589, 0.11873007113380091, 0.07432444606508527, 0.08150107347007308, 0.1744072213768959, 0.12833476146417006, 0.13993931162570203, 0.10709628289831535, 0.12452835642865726, 0.0937043357906597, 0.1802462459142719, 0.13458643028778688, 0.13206792542976992, 0.14716560100870474, 0.12201523913868836, 0.1516825407743454, 0.12367627929363932, 0.07277028196092163, 0.20705834004495824, 0.09325118296380554, 0.17546820587345532, 0.08185963851532765, 0.1012332925040807], [0.019357262279040048, 0.04907007834741047, 0.010336061174582158, 0.030433340530310358, 0.020017042589773024, 0.09179841234747853, 0.0088549099829314, 0.09304108816598143, 0.03485810470634273, 0.04342401559863772, 0.006391218031889626, 0.016213048049913983, 0.011152703514588731, 0.021184636812124933, 0.029797987480248724, 0.03952341293916106, 0.04614224384671875, 0.022346224303224256, 0.04746354491050754, 0.03805326843368156, 0.0126205070742539, 0.03642015678009816, 0.04442249684195433, 0.0418127527726548, 0.008447769463860562, 0.02413814029257212, 0.016745053431285278, 0.012127511519273477, 0.04323946085891553, 0.04384589474648237, 0.04630823726100581, 0.06401578922356878, 0.0586264773405024, 0.0382269496497299, 0.03546263530318226, 0.024315592466986606, 0.014794551933716451, 0.031229774401124035, 0.04187411269439118, 0.01133916833038841, 0.0646116922476462, 0.03310444112867117, 0.046866983707462034, 0.02288774953090719, 0.006846026484189289, 0.023712084761687686, 0.016075888981244395, 0.0075415392971730656, 0.048393972484128814, 0.03674282393019114, 0.06232994861368622, 0.04029168760670083, 0.14602421011243547, 0.03229903023956077, 0.0642738225204604, 0.08111094976110117, 0.09037300026310341, 0.023352912427591424, 0.028550565309290375, 0.07530239144606249, 0.080253770042743, 0.01627845034402396, 0.027925064587699513, 0.05554752630580749, 0.037750387364732366, 0.011266126580137228, 0.06301425117999315, 0.046424307461295805, 0.03414989395865372, 0.0670450341754726, 0.04482814543215292, 0.03614298540300556, 0.022735606712688292, 0.07196740540010588, 0.05878019266362701, 0.08691851741501264, 0.03788555832579732, 0.022455095246966397, 0.03561970598197409, 0.04902579036674329, 0.035214512010238, 0.044080277705299, 0.045301630560840876, 0.022836228366941214, 0.1480862916048084, 0.06266553167785917, 0.008947507960588803, 0.01803114022394376, 0.046092622580804994, 0.008361086615228226, 0.015489139394568545, 0.010172874350765986, 0.02595605604749705, 0.057121920931552134, 0.0709183563345245, 0.035192541046334166, 0.007006279492218579, 0.02971446660480329, 0.012937455870477217, 0.0332222008811576, 0.024034102214500308, 0.03484104633597391, 0.0702440282329917, 0.03385717734428389, 0.05433879420161247, 0.05683312624959009, 0.07227636953549725, 0.037549113522150686, 0.05473175757963743, 0.06494716674621616, 0.019933274049045782, 0.034077487486813746, 0.03379639756998845, 0.03929016991917576, 0.017977035537894284, 0.056600639796150584, 0.02512999903410673, 0.005864944151003978, 0.042684219045830626, 0.02608111683678414, 0.010452937983375574, 0.0238595999710794, 0.050021140170948844, 0.020681971284959997, 0.04544115432405046, 0.04555044595950416, 0.05783951242587396, 0.015370512813595789, 0.00830061048535364, 0.03091632854193449, 0.060373080761304924, 0.01403644511343113, 0.02859239699319005, 0.023252726732087985, 0.07584762826029744, 0.062760200883661, 0.027411545892911296, 0.13602377101778984, 0.05977128805326564, 0.018118979974782894, 0.06383604529712882, 0.016689238836988807, 0.01001640163095934, 0.01866151113063097, 0.015967143566480706, 0.036682648052062304, 0.01405563238742096, 0.0488776865282229, 0.059364540236336846, 0.051448564111654244, 0.05997659917920828, 0.04494346585124731, 0.0402838199931596, 0.006055983565082508, 0.034216563416911025, 0.027809868001246026, 0.04612567402156336, 0.03697354619258216, 0.04687745689547487, 0.046673828536378484, 0.013327301380091479, 0.01063829254625099, 0.05781568227601903, 0.012734852947427757, 0.06534038457487311, 0.04536867321335843, 0.03353497159800359, 0.0332659799605608, 0.03188219599957977, 0.015302258976069944, 0.019180464890918562, 0.039026840656463585, 0.02404496556014887, 0.03412539545180542, 0.04221476102247834, 0.02334207622334361, 0.06267692428082228, 0.06083920717771564, 0.042694017091499906, 0.023711881201182092, 0.053886638821235726, 0.04200994522709932, 0.03538663598841854, 0.05806281830051115, 0.02275787283932524, 0.010591070749796927, 0.050812169510338984, 0.016062533715739846, 0.050129271511520655, 0.022448180975126367, 0.04343589335413916, 0.0431542843580246, 0.08353088383695909, 0.008356276650114782, 0.03271777455561927, 0.016751038110149757, 0.009849028246078109, 0.015867807736088122, 0.019790730805003216, 0.02437532560101577, 0.026441943099988357, 0.015256988815963268, 0.037241743944053135, 0.05373154267934816, 0.031930399127304554, 0.01667289123205202, 0.01500566623040608, 0.050283217536551614, 0.030613203200378587, 0.022334604391029904, 0.026226474304816554, 0.05602211066122566, 0.02349832248208778, 0.05021381697484425, 0.05998077216957297, 0.03850862989202142, 0.036898384868566475, 0.030645616818219423, 0.02147132803552917, 0.04058511668284025, 0.03807199939287134, 0.04008373697953565, 0.017620485741645098, 0.026031397183292677, 0.014634005459291595, 0.06306252894656998, 0.06357196625322104, 0.06820982095918485, 0.046399798776422224, 0.041120653838983605, 0.0411065979860723, 0.03525248961523175, 0.011368498006569487, 0.028430815752861754, 0.013125556803840612, 0.04222666931205562, 0.09820377613816943, 0.06825693164552961, 0.061492989238883765, 0.013974181043782403, 0.04089468132172312, 0.03743467180590544, 0.026864492301163927, 0.005802587630958962, 0.013425258936227431, 0.08150694958333458, 0.07674515367086444, 0.045565746924174685, 0.019491507039804543, 0.058128561558468, 0.08691075497439929, 0.015967701661533544, 0.03536625618913344, 0.03278359245242817, 0.0527698821388185, 0.06387491856834718, 0.011420997109131088, 0.031083346544099704, 0.01882094650396279, 0.040336073974945715, 0.0032879798964131624, 0.043484527351600785, 0.026751366942854862, 0.023016876441293528, 0.08189352455415896, 0.05185817873903683, 0.03997848941279309, 0.012951592299421983, 0.043938029623989544, 0.025467407357479845, 0.037317492200859954, 0.04756927762978843, 0.08254218367593628, 0.027896206493356397, 0.020078967391912426, 0.04678895557299256, 0.04277291714346834, 0.05013927311769553, 0.023585302189790776, 0.0684061957789319, 0.10396428738853761, 0.05276112225172775, 0.017061671441687003, 0.015801146759518554, 0.03479528593431626, 0.018741245780672346, 0.044680876191705465, 0.06050487940332719, 0.037064266324575455, 0.03852573236716645, 0.048365915061107705, 0.022003849103514637, 0.02655210156392838, 0.01672824951154845, 0.012317111166859311, 0.04118409347055214, 0.015355127032047935, 0.05510671263826745, 0.04583077930978366, 0.048880990993763716, 0.032408321875014474, 0.03126424737274647, 0.032835303606199365, 0.038496053245450766, 0.014978694463414806, 0.043178168790681024, 0.027618716204805032, 0.0487410329681422, 0.00937939974080239, 0.04899112740531564, 0.04091677102925522, 0.035778717270919254, 0.10281994486493723, 0.0985693165234157, 0.062100895547441075, 0.003658117992537362, 0.023896296841225455, 0.03484370619324701, 0.04354862176946231, 0.006020010606984475, 0.018313349723549824, 0.0934550284541079, 0.028651253120707612, 0.0077608392706939155, 0.023769979065816318, 0.003470752421500427, 0.03342186998842018, 0.039047329021351676, 0.02078745803529663, 0.04129976672785623, 0.04496357423652496, 0.057958473185343404, 0.04626911971718073, 0.06379430182278156, 0.11683332148407187, 0.022334404223199402, 0.021203978452831507, 0.010098948808653014, 0.014528354164212942, 0.015446551144123077, 0.042787067991282256, 0.02583911732238318, 0.06015529137636934, 0.06368430451090847, 0.011161309034962739, 0.05030763801187277, 0.008274621745970632, 0.07502043978976351, 0.0487103597926242, 0.029411120739366328, 0.02474752241479499, 0.02769006585835346, 0.1630077516394002, 0.13876013989959443, 0.12309028288083416, 0.10506317485123873, 0.15652851574122906, 0.10276859333472592, 0.05863840598613024, 0.15836505219340324, 0.10468394841466631, 0.08299309055187873, 0.12023061061544077, 0.09165929231260504, 0.14593753404915333, 0.10650424752384424, 0.0970273253374866, 0.0941717785650066, 0.142947094514966, 0.05364399469856705, 0.1250122876039573, 0.14696552817310604, 0.1034382124032293, 0.08621666114777327, 0.2236336206219026, 0.16975044911461218, 0.1511318553239107, 0.09090987752590861, 0.0785887808139835, 0.10689912097794668, 0.08088982876922403, 0.17764791819666112, 0.09571937445018973, 0.16685245319136552, 0.1040288092834609, 0.13282978454870836, 0.0733577711507678, 0.1372221995677267, 0.10923897435090371, 0.10889919115496532, 0.17150102875062398, 0.12530609326703207, 0.1039342689993126, 0.13291043522102491, 0.09161233768931457, 0.1086264540042196, 0.1392433653984751, 0.18824326965425695, 0.12341099924274854, 0.13770710783345358, 0.11004012743277208, 0.10411104772772108, 0.150710810774139, 0.20848301931151322, 0.2830567184303488, 0.10121188472424235, 0.1509296383176531, 0.12808394777987683, 0.19990305256630692, 0.0959418864388551, 0.16443639355046408, 0.14100294240883418, 0.1643664501607418, 0.11504079481320721, 0.11565470615667955, 0.0878626038985593, 0.09205895622393914, 0.08296731979187046, 0.1397015122430665, 0.087881222899471, 0.12327645931925092, 0.1632874302033867, 0.16886454022356442, 0.17446744814515114, 0.15497148143393652, 0.1136834126498018, 0.1526352446526289, 0.16021160382245267, 0.11939883524818079, 0.10821429147784199, 0.15768625933144773, 0.20609111551727566, 0.13315225153097085, 0.07867209812892334, 0.05920328638915505, 0.10422079398163728, 0.2579804797257696, 0.18500768898853234, 0.09595133843166487, 0.07628186353083168, 0.11174329104168074, 0.2504104445023196, 0.08798225676374775, 0.0682740035865988, 0.14340445425893578, 0.13564151152968407, 0.12369635035949093, 0.09149611142597028, 0.1949984657445124, 0.10518704820424318, 0.17598302396280424, 0.07616077895675387, 0.10922156992767539, 0.1097759533939617, 0.2122343544449125, 0.14841820379453047, 0.13474705309740134, 0.11340634644563709, 0.14304943116647856, 0.08822295349091291, 0.16356739375208104, 0.2552253289946488, 0.08051436141665493, 0.1304193703191621, 0.08426787464746407, 0.10003276049558606, 0.11747270503214427, 0.08887277969292232, 0.0929105244576931, 0.16365981022162096, 0.07749287212001425, 0.138303010857531, 0.11775661765464715, 0.1261398092444454, 0.13372508436441422, 0.14184793563825743, 0.203210585085409, 0.14544140281421797, 0.16350418142974377, 0.12196505468870912, 0.1963007915765047, 0.17832312839371817, 0.1525118869862386, 0.11475822569004127, 0.0876154068059155, 0.2130505642188447, 0.18321885354816914, 0.14142607684646333, 0.16690403542348317, 0.28145404585770195, 0.11625450397176401, 0.0948781878022211, 0.151218463533691, 0.08633633436901228, 0.12022539946649756, 0.06282453278877906, 0.13831835931965283, 0.11177598964422941, 0.08120606001466513, 0.15562028304806777, 0.10512460941182715, 0.15400266913431032, 0.10614874945687396, 0.11110376500125442, 0.15568532741495542, 0.13660853249686106, 0.13372421583959035, 0.12549169973603316, 0.11594821326434612, 0.11286654469690152, 0.19478470007223742, 0.13514391465910844, 0.11506552062928677, 0.12148238558854375, 0.098662547234978, 0.1339518100555454, 0.15674264782241412, 0.13772854954004288, 0.16494355776480266, 0.15631621570459434, 0.11291536529149328, 0.07985926978290081, 0.1668864477957998, 0.14662911051086017, 0.11816813557275704, 0.11622344063861029, 0.21455061515527113, 0.06704921395118747], [0.06634464354387351, 0.03825273058776345, 0.0318941789280091, 0.009722215988274132, 0.03849730853523527, 0.00912682356179825, 0.00885978780154671, 0.05449177331424185, 0.080219531165702, 0.08784318422632557, 0.08755411473768097, 0.012171947929475988, 0.04498428312529411, 0.023198750967692052, 0.019893486451889788, 0.06843995968145983, 0.07556848573897566, 0.06743120202528578, 0.018801718517871838, 0.07089616145406451, 0.026971044351479838, 0.027396360279193947, 0.019429280289581845, 0.06193498016468116, 0.01940225254345153, 0.05117639693032418, 0.038615909671144824, 0.03604880813509226, 0.053165515552141836, 0.03218941629997321, 0.027461268939077854, 0.036416909990033934, 0.031737885171813626, 0.02641476777249149, 0.06659091104354177, 0.018225036694535186, 0.02224574174865016, 0.05585241923108697, 0.02693121095321008, 0.03665393923542329, 0.06324251714561667, 0.04730688813807709, 0.019152083467426043, 0.04250203239332352, 0.005795525353667992, 0.04162070022097655, 0.06712724547833204, 0.0715886132259454, 0.02470140578225255, 0.054735567553767135, 0.01804391703834491, 0.014359093603811093, 0.026584058866969178, 0.004945292985732002, 0.060118223008300574, 0.013345790611180876, 0.005475597788712808, 0.008409648518344122, 0.006207377026190183, 0.04811011414442744, 0.005974429168937994, 0.024362826985972266, 0.07371956602271114, 0.0184355063829571, 0.0443204010703734, 0.05023410177922674, 0.046598104028297324, 0.04424561633329306, 0.0283927652053535, 0.047642043725188286, 0.05611483247152396, 0.028964091691055467, 0.024732687942949787, 0.023876882258004377, 0.04485549717875464, 0.05094347621447273, 0.02940638456493616, 0.06312905930514846, 0.018563834318358983, 0.045114049554935524, 0.001339806622127071, 0.015449618122407367, 0.036128848125892024, 0.016703964743231024, 0.02260738903922694, 0.06657782888838223, 0.05702708887734583, 0.014763327448495796, 0.03192678592833025, 0.02192422471541379, 0.022310699602322917, 0.014519204119486468, 0.020984431662197624, 0.04147783467280013, 0.01683563446359975, 0.029222491396857158, 0.02374012182865824, 0.04375040112063289, 0.06233847779887063, 0.044247902996305905, 0.023357434863490716, 0.04037354946402567, 0.04597073394273009, 0.02654823730699718, 0.03490470309874841, 0.06838545296341181, 0.043372280696140866, 0.04338785307481885, 0.04148858945284571, 0.027970224485865662, 0.009597914310039153, 0.04786454214315329, 0.027222712989896536, 0.04389902403844254, 0.0544376805025552, 0.005002147859028939, 0.04334482038393617, 0.03395195850836379, 0.04790469106020672, 0.027156340390709893, 0.016111883567646146, 0.0984065088310412, 0.0249562380901937, 0.011493465497291513, 0.033445170880960565, 0.03983862638207419, 0.042984192592224905, 0.031950531261307855, 0.042047369826052866, 0.029488209102834975, 0.02120246531973992, 0.024731144275782362, 0.04612243401684931, 0.08602858481130429, 0.035690178629010916, 0.023180690061833178, 0.03579153140474643, 0.01550534281081387, 0.033175629630152664, 0.019328441504122953, 0.03143155035961952, 0.03141787787899375, 0.04394911688619426, 0.03560746521023767, 0.16035288838403566, 0.006521780467924795, 0.05866508598306349, 0.04767550228695784, 0.00506894411851785, 0.016598067479208112, 0.012248897193265813, 0.030323180370032787, 0.08163624443113804, 0.07114799294088568, 0.019700349940519248, 0.033353952025728564, 0.05211651737668684, 0.06975827179849148, 0.03777285705187491, 0.04989143480945911, 0.023373926657118967, 0.015672812038766484, 0.0292324115788298, 0.025404646260929958, 0.014988022623583674, 0.0690087755875928, 0.01683550384560866, 0.024491511152258942, 0.02584554304900978, 0.0403484300976353, 0.01449722976290754, 0.021656451048329473, 0.06495777224855763, 0.016051373511020626, 0.0397855547655906, 0.04691561431224857, 0.016193166973867586, 0.09795856715313025, 0.017254456811185395, 0.05974231460796935, 0.020432563864492943, 0.018904029724321196, 0.030941251133169447, 0.039408065378665924, 0.03717585140839219, 0.03132935620046087, 0.05461176883961473, 0.04921994298430426, 0.05225567812366145, 0.04278014354141695, 0.03408930417416351, 0.06489918074969735, 0.037987355541970046, 0.01933542702213994, 0.038982973367507966, 0.014703026041388512, 0.03235371337671365, 0.005265676017318453, 0.029941355144338946, 0.04079870593601039, 0.01576637353615037, 0.017523629956745675, 0.06288664588438612, 0.06416842567601375, 0.060697522280471664, 0.021306177701002786, 0.05177010828629136, 0.02259813042889748, 0.045200759544968605, 0.021232224169320295, 0.04695925768464804, 0.03900492736803634, 0.015598310590056437, 0.03848307965589421, 0.03559243226689952, 0.03550479268389089, 0.044945922148014815, 0.034050400368869305, 0.01183488650713116, 0.011039572219098253, 0.036724425453160486, 0.004309177007858774, 0.01619999303615519, 0.04221565668870296, 0.014251693384721875, 0.11066144837864808, 0.0371251919838999, 0.06310225717191185, 0.031038882144327675, 0.059950489151690683, 0.04116074847323554, 0.051181465586913485, 0.05455498902925423, 0.05012084410658904, 0.01797013314041708, 0.058175047992595603, 0.08193509160940136, 0.04971060861966439, 0.06183362060359546, 0.036219245953751464, 0.0499125745679651, 0.024341761866318326, 0.06325475113200289, 0.08467727553631578, 0.02747125018920217, 0.030545400588640144, 0.029670952154057365, 0.02896085168634142, 0.004975014939970736, 0.09620032685675792, 0.021892023139766285, 0.041788607104016204, 0.09178349136241845, 0.0648238972893783, 0.020688403796936785, 0.014236044670854296, 0.059836569907409806, 0.017956745644499148, 0.03906875037189041, 0.03142681418518935, 0.014426477220175522, 0.043826129021389146, 0.026714788816337074, 0.054934785435242314, 0.032262104363845925, 0.023188941047659943, 0.033863789668040614, 0.027752706514937536, 0.014753286826557346, 0.03069305998672332, 0.04898885092032807, 0.014922026611332382, 0.1149582171014377, 0.028174612804182937, 0.09183550785694804, 0.05246433781992112, 0.06995159999600478, 0.04029064266277211, 0.06147542196725096, 0.019986908849594847, 0.046033549322081466, 0.0742772403838379, 0.036181214065956216, 0.04630800655909947, 0.04099346923508814, 0.021018801157229712, 0.035822492957647355, 0.020667175828878368, 0.00969296773629529, 0.018238074744918516, 0.023216862763677324, 0.040618069736020904, 0.02915773880002754, 0.07083754281380347, 0.0901342441460916, 0.02108244434930384, 0.03160792535969189, 0.027336756066818322, 0.045450765772589614, 0.037724755704402924, 0.03497544037444251, 0.0508900280110538, 0.04322304370413933, 0.05910987247313772, 0.06296488097203629, 0.005734173065450574, 0.07458185510975973, 0.030463046793426787, 0.030823898501694202, 0.008871059964544006, 0.01972104695492557, 0.026607475110462735, 0.03903205859075699, 0.01929459617739277, 0.026822986314073205, 0.034981160424649715, 0.09009329455771617, 0.01157019254086273, 0.02229743424270834, 0.045774013070123534, 0.06623387948742934, 0.03633787762373686, 0.009174015672345246, 0.037841344983982186, 0.01526558246197445, 0.029353974520095756, 0.006537963104035173, 0.02330576442182064, 0.021927731045122658, 0.020360642545191304, 0.03657554469204374, 0.03233344214303153, 0.038029638451657126, 0.04486036906018853, 0.0716758660439934, 0.05006304310102548, 0.07341228465416602, 0.020811858154567223, 0.011013285772475814, 0.03547325098354902, 0.07026422822049685, 0.05222821781145675, 0.06375774235597678, 0.03576012880408338, 0.0034267846245451695, 0.013236200420318969, 0.05745520376201187, 0.046896788358156166, 0.04099810362926551, 0.0794644777530006, 0.0469253886091922, 0.06370894890278578, 0.10281114426574536, 0.15074872731098107, 0.08227526835565056, 0.10440110109214272, 0.09938925145460026, 0.08039989255900894, 0.09073765855282545, 0.19846295698412827, 0.1398670340755156, 0.12144319340586662, 0.15396317839622498, 0.1330570937799556, 0.16209171579352447, 0.11848802412194864, 0.0755300603008696, 0.20406285221023218, 0.098137320418443, 0.10274641881031649, 0.13270448627216475, 0.11769713727491242, 0.11111425515264273, 0.106934608359422, 0.14709164069167205, 0.12872695470494883, 0.06269864418676921, 0.14408336925719464, 0.13689936617655413, 0.11195483790444476, 0.11088823513793093, 0.18614981270262174, 0.060157421976327896, 0.12957057729363441, 0.19236082370792115, 0.06777085629957062, 0.1173890552350453, 0.13257301332695143, 0.09973645782364265, 0.1288701527352844, 0.14193250824298176, 0.11454055165605885, 0.1814410782286099, 0.11818319905017104, 0.05219472871561136, 0.16039837737168583, 0.10982346441596746, 0.09813683865857975, 0.16535658203065395, 0.13653658064348356, 0.0671034153284771, 0.22135994476931437, 0.07148892286100558, 0.14529633202723094, 0.1506191406931196, 0.16216568968125752, 0.09371241035738162, 0.11152823615287032, 0.06995898245700768, 0.14472400130970137, 0.08908875060400792, 0.10060597330863986, 0.11239401969526495, 0.22029768462691987, 0.1770302884812866, 0.12904715538024902, 0.09604192964200463, 0.10425554175994226, 0.13771915861538478, 0.169203020632267, 0.1215902997979096, 0.1142443846911192, 0.21207187244934694, 0.10050612688064575, 0.06347026742462601, 0.12298448570072651, 0.1683474015444517, 0.10661427197711808, 0.1776903130646263, 0.2027118889881032, 0.10565289642129626, 0.10669610330036708, 0.2587868236005306, 0.17222147009202413, 0.14849001994090422, 0.11964751833251544, 0.09693784692457744, 0.1810749950153487, 0.11628389810877186, 0.09100273504321064, 0.23076672000544413, 0.14453454076179437, 0.11790784953960351, 0.11632010473736695, 0.1308441875236375, 0.12231407953160149, 0.1496175822934934, 0.0939091108739376, 0.18081713813756192, 0.13458082558853285, 0.13357735372015409, 0.17608008161187172, 0.1526049684200968, 0.12135563524706022, 0.15212164792631352, 0.08081200758793525, 0.10541434386479002, 0.22111303944672855, 0.06350637227296829, 0.13449372883353913, 0.08388949637966496, 0.13562165759503841, 0.11103301415485994, 0.08286995001669441, 0.17345558958394186, 0.16934841711606297, 0.16049813559012754, 0.07784599531441927, 0.15679062024823257, 0.1600955743342638, 0.14523727233920777, 0.06812533656401293, 0.09684727607028824, 0.1558552732957261, 0.1595306803605386, 0.12585356246147836, 0.059786487237683365, 0.16759041430694716, 0.16708360293081828, 0.12644148591373647, 0.16876197287014552, 0.11370600786592279, 0.14455944299697876, 0.11079429196459906, 0.13922912973378385, 0.12378825114241668, 0.10000207035669259, 0.1852075718343258, 0.16597620663898333, 0.04533844108560255, 0.10759082636130707, 0.08412829999412809, 0.1830221191048622, 0.16433614678680897, 0.07597783234502588, 0.1619284331266369, 0.17078182234295777, 0.12942595433975967, 0.1032522598813687, 0.13902600349060126, 0.1175973926271711, 0.08461386643882308, 0.06879566809428589, 0.07180030258106333, 0.15995473760579312, 0.16903437753873213, 0.10571202396282128, 0.0745849356587444, 0.11301895723279033, 0.17931305670312472, 0.16386765906853334, 0.10058176996452467, 0.11713953076728753, 0.0680994979505028, 0.08813107984938792, 0.06278350177620139, 0.29313893456544193, 0.23583426379731723, 0.20566988097769873, 0.13494534817125114, 0.11069329202707325, 0.10398576980722801, 0.09366494683282715, 0.17893347064299242, 0.1150450153010232, 0.11646368274731295, 0.17061677548502172, 0.15452888661197253], [0.027681448463616625, 0.01866149077458041, 0.041600442557994805, 0.021694789973220656, 0.026421090022527745, 0.02652188639954797, 0.0312176421949906, 0.045671181088047366, 0.016097191588154862, 0.008095552113705447, 0.03811214830992477, 0.037663341499865055, 0.019761063557650362, 0.030995255735303675, 0.05610544493954096, 0.08791190625301429, 0.01594398177361914, 0.05698668211698532, 0.0015221917461271264, 0.0008240889437729493, 0.039505346944289546, 0.03584969203386988, 0.04847066051193646, 0.04692173809079187, 0.03426221525296569, 0.06876012643000909, 0.057797551820320744, 0.08372833752738577, 0.06410914885678462, 0.04045210685580969, 0.0336357238702476, 0.032884483824351, 0.017569000200767602, 0.01404415411941175, 0.03471264376171997, 0.036445533989795616, 0.0874137869104743, 0.053203282811279805, 0.06064488831907511, 0.01485353019753737, 0.05471342017075845, 0.05115892126091889, 0.09577521788222448, 0.023056601273960302, 0.08562677672931127, 0.03737775968121631, 0.03855513668219958, 0.02736439279812787, 0.007255250105767378, 0.01291830591591341, 0.026585524502609457, 0.05429550027474761, 0.06848139102969851, 0.016818481098328317, 0.012985178934676307, 0.012231324832620365, 0.020774304633960128, 0.019318263478843228, 0.03918184180344854, 0.02999853529036045, 0.03968964044802955, 0.026910434210939065, 0.07411773715700422, 0.025997789343819022, 0.010766148899814912, 0.022055434728307382, 0.015577505010047128, 0.009860282597531165, 0.09861825925431081, 0.03610704340306776, 0.024722416619104997, 0.0655064560206873, 0.06992264690675906, 0.024013578226523738, 0.029075849801301956, 0.038381034774439673, 0.042702190045799525, 0.029700152908584902, 0.011394086410291493, 0.012418122978747954, 0.052212587757302184, 0.029137440424944674, 0.0508918838043298, 0.05214413035927074, 0.030702176104698862, 0.031113171550844396, 0.03979210941387074, 0.04304472130856343, 0.05264233112601297, 0.11823092720338277, 0.027808644941874912, 0.02649860586305814, 0.046126518797661574, 0.026915499474853277, 0.06712909787893295, 0.008502829187948788, 0.04823983307661755, 0.02805107702235026, 0.07127149988498006, 0.0350001424417964, 0.07438733269061361, 0.03690015584496515, 0.028844655957072973, 0.008645026379131844, 0.007108147954568267, 0.055587939851518185, 0.048960891884884665, 0.007284879185525435, 0.06841758838189499, 0.0017972634814213961, 0.12859198051903928, 0.03145243227481842, 0.051865130330302885, 0.018289188787873303, 0.0012910995761298441, 0.011259419261477888, 0.04271930609164493, 0.010168146658023553, 0.024370971102533594, 0.03353909709091697, 0.013896766135336032, 0.023414540370660167, 0.06587418128869363, 0.022188887299437608, 0.054512295605880876, 0.04858187579416803, 0.029835259408823082, 0.011188583598206086, 0.033864349459431, 0.04511204109128032, 0.031352541742048094, 0.029877803554492335, 0.013650119504226106, 0.04620484209486416, 0.055359049633677514, 0.026250182318368127, 0.026976942517129437, 0.01851045905745455, 0.04756679758429527, 0.07894966644900185, 0.07898330821522645, 0.045731960862342796, 0.04177591510649238, 0.07704184310776846, 0.0278775807070945, 0.07810392683105809, 0.01143755845259875, 0.05976681650749274, 0.05890709228281464, 0.008775042170392615, 0.048017880879342556, 0.021133102077458586, 0.08446256670036487, 0.0468240290481065, 0.039648551759975295, 0.009022993285075893, 0.02808819119153278, 0.0673368110188416, 0.028769338570002998, 0.007102906695633594, 0.01901760800475521, 0.04968233406543732, 0.027634658385068178, 0.04293731600046158, 0.04037337304492082, 0.06454867670046431, 0.01736966527200171, 0.03438301484233566, 0.04921123059466481, 0.023508074726643305, 0.03315151110291481, 0.01655565564786749, 0.03933216105880482, 0.03150900173932314, 0.061922949738800526, 0.010257686139084399, 0.02119085897824594, 0.024524735619447062, 0.02634784216726465, 0.017446083582139442, 0.04749173804053238, 0.019698373707277433, 0.006150355911813676, 0.01814578041168196, 0.013518221626457359, 0.017986378965101073, 0.018758521282247136, 0.02307861634264035, 0.0415303634612688, 0.053997718396463563, 0.018150158658889786, 0.07811579440853425, 0.08615897888583796, 0.03730790789372154, 0.016854468899379884, 0.03993056448442595, 0.020597083161451986, 0.034406108781695366, 0.044344943681997914, 0.020219476727236594, 0.03279890359512397, 0.07649175476815019, 0.05623991022418652, 0.039240053322698386, 0.04765159749825086, 0.043854898906179836, 0.025688178903822387, 0.024056858582688228, 0.017901909836967076, 0.019988715449081998, 0.011603904705095505, 0.02509826564762209, 0.012429080471130354, 0.0633630860330803, 0.06734309425311429, 0.04442079371905752, 0.028382809400292378, 0.07008960723344769, 0.007898850748980684, 0.0746453795582056, 0.013162133234020854, 0.05371552246755787, 0.02689635630563966, 0.03437080121199999, 0.01869943275648568, 0.031428629266364236, 0.02583475603855082, 0.021601786570889608, 0.05917805167181151, 0.013722904259338975, 0.02291467719312225, 0.021569065915952836, 0.00796826318505087, 0.0353669788289283, 0.03784381824412516, 0.0635390505194664, 0.01967047404364816, 0.012970715112585043, 0.015036917857027479, 0.050704397793327055, 0.026561785954982042, 0.030596633375223194, 0.028303620970941017, 0.02218334706101034, 0.06219449266791344, 0.0198361722952021, 0.0554753301798233, 0.04423813548471246, 0.018027253914624453, 0.02595109765284828, 0.03480589482933283, 0.03954398951360157, 0.05837246775627136, 0.05335381919784205, 0.013974395630482053, 0.08040956168302468, 0.051766165997833014, 0.025557267446337, 0.010704878035799732, 0.06020975738231625, 0.06000905350915023, 0.034819390890853744, 0.042026569335056205, 0.09139028031911169, 0.03952074968921287, 0.03702581713774374, 0.01495594488057707, 0.061708546243608, 0.01089141409777637, 0.06212204548397234, 0.028988440920199667, 0.031212146061339548, 0.02165725002331393, 0.008334714503559684, 0.02623412139447672, 0.02191271845783506, 0.03614460710170014, 0.10773337978337492, 0.012651599245145917, 0.026057966918285404, 0.03951198301677193, 0.06909029478473322, 0.056395769717970064, 0.031526338309049606, 0.07024104267890964, 0.02948164427652955, 0.04130190411316497, 0.0017082559082025129, 0.008778011609267975, 0.02468746867296951, 0.03351260029843875, 0.032029007228889635, 0.04916533109332834, 0.041935967946691174, 0.05480173150343554, 0.00959383970725217, 0.014156108156644871, 0.05320612248033285, 0.05749284888484648, 0.04627778121669378, 0.019172775392819728, 0.04635027589808617, 0.05205062823370099, 0.037182982811438184, 0.049117847212723324, 0.02490334628549005, 0.006215664907358587, 0.062299998077963076, 0.06908954839621272, 0.03853196471131273, 0.052193551457354, 0.007581529606665883, 0.04952610816274371, 0.047084148840180466, 0.030534717054771524, 0.0318097861350647, 0.05941593926399946, 0.0019346415896766952, 0.056577722275895734, 0.02756949357821473, 0.07765730151108333, 0.046269055256353955, 0.014898550996024693, 0.048455115274659226, 0.01465015289639788, 0.030588161865515367, 0.01786215277388692, 0.0077224664190518, 0.02134702550912542, 0.08325995837471314, 0.03499043260567954, 0.009173689975536295, 0.029201236287397996, 0.02589533564501575, 0.01851433518874858, 0.06099030335566827, 0.03603384643793106, 0.030932783016136715, 0.036078042816370726, 0.0035810991789081265, 0.041104877899800024, 0.13067321026963846, 0.0575168893805572, 0.050212785601615906, 0.07884990144520998, 0.06290009444845573, 0.04925593926704355, 0.0507703921092408, 0.03091499861329794, 0.01697501912713051, 0.010818553855642676, 0.07777863035776786, 0.0887764480763248, 0.04824239454631295, 0.10746172828865902, 0.0927131250500679, 0.15757573954761028, 0.08607866748103074, 0.08156873698213271, 0.1093640351401908, 0.06429551528500659, 0.12507885188928672, 0.14861655315118177, 0.07900207649384226, 0.14037490396627358, 0.1735954899340868, 0.15620515309274197, 0.2875382522387164, 0.14860481449535914, 0.20504675512867315, 0.11683167942932673, 0.2772310610328402, 0.10723950807005167, 0.16830746297325405, 0.08743555431387254, 0.17188730516604014, 0.16624220593699388, 0.15450292586215905, 0.13450717739760876, 0.13630187538053307, 0.13900526746043138, 0.09906460637492792, 0.09550369530916214, 0.09578702439154897, 0.14384529846055166, 0.0535681616248829, 0.13077493623963424, 0.13410207842077526, 0.12629245248224052, 0.09312802885792085, 0.1458452261452164, 0.13442179055086204, 0.10769964302224772, 0.22411300561257771, 0.14702378718980721, 0.1387015144739832, 0.14636551322681562, 0.13106655701994896, 0.1816237127142293, 0.08127005943762404, 0.105740977052067, 0.16839918733707496, 0.10594286836151566, 0.1323117094912699, 0.1717354083167655, 0.1144380114440407, 0.11286591365933418, 0.09320703747549228, 0.128976275612201, 0.07346170235957418, 0.13226611193801674, 0.13421835218157085, 0.10683679753648383, 0.11396670102008752, 0.11376871807234627, 0.10584619069205863, 0.1137445079428809, 0.07453783854310002, 0.14905371969299658, 0.1327981376754386, 0.1180496226463999, 0.16988262773624488, 0.16551869761730942, 0.1708997381584985, 0.16228710673749447, 0.09512794975723539, 0.13404966837593488, 0.16783575899899006, 0.1378295426922185, 0.1451961395463773, 0.07248252204486302, 0.19806289273713315, 0.1378781936530556, 0.17545848925198826, 0.09611749130168132, 0.18938419914671353, 0.1113640306783574, 0.14974834956228733, 0.11917098318891865, 0.1960072030446359, 0.16501996080790246, 0.20859587325581483, 0.11179258661078555, 0.12590756027826241, 0.11162911395409278, 0.17371313433562005, 0.15706218353339604, 0.15006335265934467, 0.13674428021269186, 0.09262547189635889, 0.13616828540606157, 0.111842560714909, 0.1746956394719226, 0.22656741605273314, 0.14186895665313515, 0.09612878212439162, 0.12885108590126038, 0.2003971617668867, 0.17710271530917712, 0.08230904582887888, 0.1842707728168794, 0.09367936570197344, 0.2304948174527713, 0.16274876839348248, 0.12797957552330835, 0.12676503855202878, 0.1609192615641015, 0.1203496799405132, 0.2455627460564886, 0.13586348747568472, 0.07985435718936579, 0.07646050823054143, 0.07609435716377837, 0.15565762961549418, 0.13980079548699514, 0.09271359323923077, 0.12781276447432383, 0.08441606669553689, 0.16101142019033432, 0.10816626476922206, 0.11226684866206986, 0.16187124619526522, 0.1640722645180566, 0.15179999518607343, 0.19520597532391548, 0.06806812927659069, 0.14147620701364108, 0.06818846067679779, 0.20748099950807436, 0.07237310148775578, 0.1341503086899008, 0.1341903693974018, 0.16115201264619827, 0.11052135803869792, 0.14569373641695293, 0.1507646186011178, 0.15380882525018283, 0.14269326813519, 0.10082858707755804, 0.11434780699866158, 0.24307936217103684, 0.13239789700933866, 0.1318235578281539, 0.12908801675907203, 0.13848639173167093, 0.12032086934362139, 0.1016153416463307, 0.06899460777640343, 0.13570944645575114, 0.1600891011101859, 0.14591633661517076, 0.18219817403171742, 0.1712255028209516, 0.1884124691465071, 0.06801523747188704, 0.09347416314163379, 0.13239207517887863, 0.18714146449097566, 0.12207642942667007, 0.1732947225017207, 0.15599053246634348, 0.11525583613131728, 0.14540073142520019, 0.09464921616017818, 0.0957316355779767, 0.1251598418291126, 0.18514644939984592, 0.15453620121947356], [0.03525237426427858, 0.05730281836752381, 0.019657412244539176, 0.049366808496415615, 0.02399240284492927, 0.044937264041176865, 0.021159990723910074, 0.019703304960525463, 0.06867178117058106, 0.02791380599540259, 0.0017380801727995276, 0.028893052467278073, 0.03428356196465237, 0.030731909509216036, 0.0071356905391439795, 0.0034701922060256557, 0.03791449445166758, 0.037731758185795376, 0.013834988914563187, 0.0612632915643709, 0.037675368533070595, 0.03328753362542816, 0.02213194633701018, 0.04331556873928223, 0.020160045541290725, 0.0614844871951001, 0.08662397893411772, 0.008472459656851632, 0.08293747103640012, 0.04044894827529788, 0.009231085556426218, 0.01956671755760908, 0.04618946988401668, 0.05298524236838732, 0.0769817859732679, 0.048061503895691464, 0.02088222393233861, 0.03159672953188419, 0.02373421348498336, 0.06665270522769008, 0.02583906812859433, 0.026732754727293338, 0.041160222608596087, 0.04532031062990427, 0.020583548084167496, 0.00804944141834442, 0.07117198593914509, 0.042721664000834735, 0.11230192892253399, 0.10645664829228606, 0.062222475452082496, 0.04525369545444846, 0.06796058147613492, 0.04654919522415314, 0.01300596076595996, 0.02964195835271052, 0.07846611525331225, 0.04796960311276572, 0.02562847121485642, 0.02581982657180301, 0.05180981954825776, 0.04885598358565143, 0.04304497575919543, 0.08390086184122733, 0.04508818380002465, 0.035375158568578105, 0.01098286874392735, 0.029592113170240606, 0.0429268631684993, 0.026201969012618065, 0.03787160425313881, 0.04264598020485469, 0.042985396991883, 0.04413303380299892, 0.013959033597659851, 0.00459034410804244, 0.022204320578436767, 0.03512355099831309, 0.004305730474048427, 0.007528447812157018, 0.05898072011768818, 0.02060695754231087, 0.029490828248006955, 0.031046016940048764, 0.04491325407954199, 0.02980799926444888, 0.033640219164746146, 0.042000208249581714, 0.02005192607508174, 0.0816161801506366, 0.0670104967430234, 0.05112069259796824, 0.015845660353079438, 0.016740883833595684, 0.04663647857627698, 0.04345273459330201, 0.0346548970389579, 0.03590292310608285, 0.029386025121701614, 0.021093200825686966, 0.01942952286585101, 0.03360488445365003, 0.040317461759384186, 0.03804778926340597, 0.03531996653016124, 0.020446674000205736, 0.049481969459780624, 0.0342243055014738, 0.04289682103054864, 0.03041010070592165, 0.012798826925323477, 0.053190787588911395, 0.03164895297959447, 0.07879715891821043, 0.007780712713221354, 0.05632023859236922, 0.03031288699379989, 0.005709601192003382, 0.019210900579180037, 0.01960571975048099, 0.045901693004582605, 0.024377150860215937, 0.007993955913531994, 0.047504111126597436, 0.025008052720555236, 0.007306935814475375, 0.030304612259247472, 0.034737288153597286, 0.02459607000595757, 0.04833363036492041, 0.039345168575112305, 0.046424857074660916, 0.016820786421054175, 0.03577438821750028, 0.03049840864592365, 0.05484520184940525, 0.017424909896882515, 0.01880119095689484, 0.04711096793679254, 0.0256152516563556, 0.05351237926099982, 0.03333115324910198, 0.02106668706983328, 0.0034169115159394486, 0.03474759170785546, 0.025006281744156564, 0.008010495204611548, 0.05179896638063448, 0.0629870147843446, 0.013566974367547249, 0.0427066717695977, 0.06982069023485694, 0.05078824097290635, 0.05242803958909852, 0.04572008310684136, 0.05334571748971939, 0.019880002264731696, 0.06045940398637738, 0.03215924184769392, 0.015899213729426265, 0.060702353449804444, 0.006447881219043795, 0.05665147224707263, 0.02230752575477319, 0.0218200237889375, 0.021896050245101963, 0.08196537462728364, 0.0370497388898262, 0.0303065562620759, 0.02594990173487791, 0.041377900035253594, 0.026607839823035256, 0.029352980466293435, 0.05290970106476119, 0.02992536885929959, 0.019930000117580806, 0.010635363819476749, 0.026496588917715207, 0.028049031239269034, 0.07872856581317526, 0.021367352721946578, 0.03929091630769627, 0.05277735620204892, 0.015349849725940397, 0.03846138010599783, 0.017578017931165438, 0.034700735472142696, 0.04363227156656129, 0.033290610781737735, 0.062044346438986916, 0.03922530536406806, 0.0354673816556377, 0.04847673000767827, 0.0410020764517997, 0.01695786745819662, 0.031876933960510154, 0.02820778977391975, 0.03242545827691044, 0.023138049224923764, 0.021741308637761643, 0.013996261421457996, 0.026154883771336505, 0.0228671084956399, 0.0038788301670657738, 0.07017587617571865, 0.004137069144884923, 0.04919461327205811, 0.06042167743934052, 0.010020890988276472, 0.02160808676853776, 0.065303485840559, 0.040632458071091344, 0.05389570744175996, 0.022332258356202925, 0.05317046546510287, 0.06865531991102866, 0.04029649841998305, 0.0354656785327409, 0.02614266674832574, 0.033507351830069504, 0.024551301961764693, 0.016580700375405804, 0.07701627590826579, 0.03442071085529668, 0.02698766506676163, 0.13375869898923806, 0.023988502964909588, 0.017159500924338187, 0.049928689774657996, 0.027944845579830662, 0.021596013934218457, 0.04038919987423079, 0.018185220259640898, 0.017068193859553764, 0.05459599968578134, 0.028186125847111856, 0.02385033287906221, 0.04566252637388451, 0.011191911812472557, 0.04635751586673515, 0.028454165839190994, 0.03347651580614703, 0.014089953536832971, 0.0487203512207738, 0.013665570594769503, 0.013717690565889435, 0.016976315129016126, 0.03181926526927522, 0.020480261483628835, 0.03982329149065273, 0.018457738582843115, 0.04953668652368443, 0.032026330408241065, 0.05940136433179889, 0.06967169073011194, 0.03745214068996055, 0.06918007853840079, 0.039942842575588396, 0.021087748796812127, 0.07936999175165381, 0.00925646785513631, 0.035544368238853555, 0.013995621054034148, 0.06062489867742572, 0.023592185927554965, 0.018336876228983914, 0.013528811861760914, 0.085955038400633, 0.009296699044560748, 0.03327213766585503, 0.017661247036552856, 0.05008361967546599, 0.04704690744568195, 0.0266672082444919, 0.03766097341264997, 0.026644911583779112, 0.02242156713535743, 0.02811219267147992, 0.05298792597438608, 0.03189054876565933, 0.08776070829480886, 0.051294210965612104, 0.07201121840626001, 0.025059405947104096, 0.027679782660145844, 0.04188579028206212, 0.030633382831833193, 0.04515751990090523, 0.03181193030572363, 0.06714229538504567, 0.0369078097199755, 0.10664673309241023, 0.04016135460031884, 0.030960490993623222, 0.05826177155332906, 0.037083292446498356, 0.004672728861416025, 0.027510606916621327, 0.035820698232523034, 0.07264551972704274, 0.058980747259088924, 0.008985274371558001, 0.014127650397962757, 0.013399368584422129, 0.06384836070771728, 0.038794513658753464, 0.020495328353717923, 0.03383642774341362, 0.029569358498390232, 0.038374042471072504, 0.016919757538874234, 0.00960511780743088, 0.022663726105487773, 0.03029482439160347, 0.0558834791715656, 0.018686294622187103, 0.027745419048837254, 0.06026729715189763, 0.02466527379250952, 0.02459734395545508, 0.032484891159193854, 0.03118077738742743, 0.06259920487978629, 0.010227251298991697, 0.07544841218207564, 0.03326051436098559, 0.030647971334734132, 0.04823878474001374, 0.027813849305467944, 0.07239195119057383, 0.049533477053046227, 0.012316153584314244, 0.048068760827715905, 0.026837844534644058, 0.03603291684495551, 0.023229858405621986, 0.023125638819432685, 0.0010723875956110923, 0.008402430602083249, 0.02557487034105829, 0.01864158594980836, 0.025298548829076544, 0.016649234108626842, 0.030762989805745225, 0.016267247730866075, 0.06455942469515971, 0.025683751462825706, 0.03766142463843737, 0.01652612241118082, 0.019734239372025644, 0.008502016642263957, 0.033946102751152854, 0.10378564268882785, 0.24526353925466537, 0.06501901003399066, 0.11768271162041596, 0.1285616500037057, 0.09494557990027325, 0.11621898944888796, 0.04496722475492528, 0.11885671290968146, 0.07613814981388194, 0.11510407498904637, 0.11254140428666558, 0.12373893521726131, 0.1880210494356496, 0.17205346482140677, 0.11018312190260206, 0.12351980911833899, 0.1638997673456158, 0.09164110757410526, 0.14677846963916505, 0.10947914860610451, 0.09310417835201536, 0.09961518325975963, 0.10874142497777939, 0.0920368902651327, 0.1229256974267108, 0.1836858077773026, 0.09947163239121437, 0.24405688686030252, 0.11798413044639997, 0.20902364887297153, 0.10818705508219344, 0.11441715327756745, 0.12443014527005808, 0.13172681230519498, 0.1696753760001489, 0.11412196340305464, 0.12309143639036588, 0.15416447259485722, 0.2507582615528788, 0.06900749315640756, 0.1021904679281371, 0.19504422614617006, 0.17556657988045896, 0.15254741507981504, 0.0712212815082499, 0.139323337535773, 0.1355795341410807, 0.15569473191031388, 0.23796510802847998, 0.17521944136491843, 0.18505955620535783, 0.1257881788270814, 0.06574586353131703, 0.05296458436974457, 0.11647926191134111, 0.13300967775285244, 0.08487529241080795, 0.11030126842004911, 0.13671411254576274, 0.11941345089248248, 0.11192150826432876, 0.13092133695525782, 0.11937984983835902, 0.13147606647440366, 0.09793521876313857, 0.06433033770216362, 0.09885510868792023, 0.09991944514747177, 0.09894175082445145, 0.25402299208300455, 0.1740487648972443, 0.11483914777636528, 0.1756909689200776, 0.07478194830140897, 0.17788928667349474, 0.10481447819620371, 0.12383766206247465, 0.18195658842367785, 0.14746639558247157, 0.20542286708950996, 0.0808232237717935, 0.13195741921663284, 0.09992714651993342, 0.1345536434756858, 0.11858300545385905, 0.12902901135385036, 0.14590378371732576, 0.1299646840031658, 0.11962178828460829, 0.16735565476119518, 0.12685616580503328, 0.1543730135474886, 0.07170918211340904, 0.14426935570580618, 0.09510985322828804, 0.13624623550900392, 0.10441404754029852, 0.09774005173572473, 0.11890488889600549, 0.18952268814401968, 0.14518357307783195, 0.15739467926323414, 0.13639095345778124, 0.12727210777146475, 0.10670328220086438, 0.24498998107654707, 0.10473362396338157, 0.13823437025504454, 0.12208989156144005, 0.12417421543172427, 0.11018899801586356, 0.10491028734083686, 0.12018008689795222, 0.10380734902407442, 0.2033400631376675, 0.1912326913859163, 0.09520245968763318, 0.10531167473111834, 0.10099129977502994, 0.11689276115170547, 0.19165768500949654, 0.16052229143679142, 0.1741174054997308, 0.06763076595962048, 0.10423956904560328, 0.08792516482727868, 0.09081593435257673, 0.09980151576123067, 0.14140615505831583, 0.10141475312411785, 0.08803583388882023, 0.09964651122157063, 0.07491319733006613, 0.13443138503602572, 0.10125700730298247, 0.16282806199576172, 0.11939689463802747, 0.1774835634444441, 0.16535833265100205, 0.07528427456106458, 0.12482395342418126, 0.08531766331621579, 0.14516755965139183, 0.05722692422568798, 0.15569887097392762, 0.16051641532352992, 0.10963289785598006, 0.1645925651703562, 0.08826694970152207, 0.054888590771172724, 0.1562820446810552, 0.09122790010379893, 0.12392698441232954, 0.13973527614559444, 0.139148031228355, 0.2140970416367054, 0.0963539064728788, 0.11966503810669694, 0.15945313737860747, 0.11258286956165518, 0.1044320830010942, 0.07398839481174946, 0.10092821637434618, 0.061756932575787814, 0.16313272421913488, 0.1019175136461854, 0.0625547201239637, 0.15733563314591134, 0.1410802954009601, 0.12543842116636889, 0.08151463738509587, 0.0863893415246691, 0.1436721227530922, 0.13450029705251965, 0.05937015850629125], [0.020175090358991708, 0.06339478040380137, 0.030285653990826437, 0.012413253641820379, 0.026049602277843014, 0.03955457805256758, 0.05084502078326685, 0.028005750883104544, 0.009124560647511056, 0.0025506046534116778, 0.023712325641619306, 0.017255591661004082, 0.06208140802170549, 0.04061496204563549, 0.02009013438198183, 0.016999342911211506, 0.017883345118856857, 0.013247554007518505, 0.05524255534900086, 0.02959091555593269, 0.07190522445099694, 0.021951488252463083, 0.07309471669473819, 0.01476136308961681, 0.01795899329174842, 0.08593935745635203, 0.03203629130231483, 0.07154612336307764, 0.03585970042539494, 0.07919171346085412, 0.04422835100974355, 0.03551943886226841, 0.06871370784938335, 0.013062013695681733, 0.04542222319703017, 0.07170084291802985, 0.052435452584177256, 0.018757839354553392, 0.032182335787053616, 0.03438754406358514, 0.055471448959516625, 0.08559744366045509, 0.01627087450054075, 0.017314191641552106, 0.028431372151577046, 0.06017452784414802, 0.027343789082286612, 0.04974145821428724, 0.03071763991777386, 0.00572839194709169, 0.07790934334376029, 0.004075812275654503, 0.031277282030454705, 0.016508127662486265, 0.012472233601978846, 0.08345317800662347, 0.05354016187733837, 0.018376891135371158, 0.08474971593490668, 0.03887785811509405, 0.0215637122746557, 0.038982763021652184, 0.053603326702224355, 0.03560581297746726, 0.022609575618324534, 0.02316380980690675, 0.04140372168538826, 0.046726588026753495, 0.016193424817174673, 0.05930802505463362, 0.03193356788584164, 0.05578022649777787, 0.03551700631422656, 0.04486528165372355, 0.047566129227301905, 0.013615336951001413, 0.03325576461585505, 0.0271412769132959, 0.04643758299893566, 0.09782391187867948, 0.01577375260447817, 0.02770138212612697, 0.01893218044590737, 0.04254791493128453, 0.050214763531195264, 0.0365602572980736, 0.04852687713823148, 0.03006692822756512, 0.03430912237880485, 0.07056019162493092, 0.020896254340186715, 0.02533331696343209, 0.03664483668814812, 0.03833360856931124, 0.02522858338696616, 0.052340040382530005, 0.02094376027317984, 0.04587014451889055, 0.01086366964903261, 0.040649329844330034, 0.09316909379724946, 0.04822390785972987, 0.03085334352882845, 0.03601062357691782, 0.05255226917298777, 0.07063516974449158, 0.008286628423125615, 0.03926904033869505, 0.03404902633545654, 0.04228559329307505, 0.03603506440828953, 0.022893444136051194, 0.0641517269292048, 0.011666256984296654, 0.030309226297374283, 0.022875490099457756, 0.07537584286183119, 0.017633859666862657, 0.007500085048377514, 0.004643659148963967, 0.019107206857630184, 0.0240125689056835, 0.02965570886486343, 0.04799435267757092, 0.023971125683082, 0.033693680938865454, 0.041537885021950514, 0.024216003882299577, 0.014208013541065156, 0.008008742887925888, 0.030193563218095472, 0.010154735413379967, 0.04233279897432242, 0.045478589101029296, 0.04733526107988187, 0.03565752073856337, 0.005951847947601761, 0.024230989328186427, 0.02084391045251063, 0.006459254738209503, 0.03823243899803076, 0.035115160912807496, 0.02378616721502372, 0.017680634478373185, 0.020144488429650664, 0.02879835951275059, 0.038814903636063845, 0.05006092946444239, 0.025898455209763985, 0.025270381144114902, 0.033889964156384976, 0.019002381678936735, 0.009716133770000721, 0.025905705356438245, 0.010053544637880154, 0.03837280075198837, 0.017221317160874605, 0.05345233230452452, 0.06243215634354523, 0.036366345560444255, 0.06020472265247788, 0.05611842531444771, 0.040339558252266476, 0.06611774821898767, 0.05122496646695903, 0.020040835420201932, 0.06868632896138088, 0.030189719317214828, 0.04522072204521724, 0.0668163135913866, 0.010213084335971092, 0.017779361323586533, 0.04148845374584198, 0.032831524166145494, 0.08235869423619338, 0.029120836673038344, 0.05992033505546195, 0.05315156487215843, 0.024841156854693378, 0.02122572041116655, 0.016957485782248632, 0.023215792374685407, 0.02551826525346509, 0.05178894441840904, 0.02954721450805664, 0.025921147117125135, 0.021505709404924085, 0.04209959327376314, 0.01766919607429632, 0.03906284372455307, 0.016168322414159775, 0.008568928676790424, 0.0015153858278478894, 0.03912411882941212, 0.02256174398852246, 0.04122872750407883, 0.03072270518168807, 0.05328274265463863, 0.07883907202631235, 0.027199625835887024, 0.015000293929395931, 0.010154827863776257, 0.049584886258734126, 0.0704914763835924, 0.052925551642796824, 0.019026549399963448, 0.03638311555343015, 0.012433945567214062, 0.06374572550079652, 0.02946374113006251, 0.03188076429069042, 0.03129519874762211, 0.049342917278409004, 0.03387372002803853, 0.04720553536234157, 0.018299816342602884, 0.028787031370614256, 0.026979310604344522, 0.01950351710963462, 0.06221056037715503, 0.03239191829093865, 0.04627449371452842, 0.02234857203438878, 0.04877973321293082, 0.045507579509701045, 0.039221532709364376, 0.012166963241595243, 0.060612854680844715, 0.02131740915189896, 0.023747809630419527, 0.04661243808056627, 0.02123235139463629, 0.02564870173643742, 0.042683934061122794, 0.030582977857972895, 0.05077001891498055, 0.013281981178027178, 0.017871764222426072, 0.021417939203924367, 0.004298850553043718, 0.033495324796863964, 0.03411053553489702, 0.017363940132781863, 0.07339210502271142, 0.0068178634641559, 0.036199866993618865, 0.0547157068337713, 0.028903790283948183, 0.039914374638881, 0.02751701737621001, 0.021973952850592986, 0.005260322376021317, 0.06404098322881119, 0.01937705514553402, 0.021899040888196657, 0.029689387950514044, 0.026842521337260093, 0.025426954796005572, 0.016612985071593096, 0.025216742950890745, 0.06012656220367976, 0.05559002295402544, 0.07241282292774745, 0.016744247670950632, 0.03087840521974223, 0.044057407682495456, 0.01714307359153671, 0.004636800008094204, 0.040023679845035076, 0.055876429192721844, 0.0059298333030061, 0.049647196129496605, 0.03842360945418477, 0.04960550354527576, 0.05624099588021636, 0.03730942102681313, 0.053980585387242694, 0.020789653096081953, 0.04416802246123552, 0.08615443270121302, 0.041535476222634315, 0.05947323476097413, 0.025006868676947694, 0.02265509344371302, 0.09643096769494669, 0.018555564672819207, 0.06999132143599646, 0.0163932448984789, 0.12208047349538122, 0.07183204444923572, 0.041101980555270395, 0.023931470400254642, 0.036799929437360594, 0.03846927486093981, 0.028090296346428137, 0.04231727070042065, 0.013536352082155645, 0.03473052655213645, 0.028620915820023844, 0.021383471321314573, 0.048172627575695515, 0.028138163599318693, 0.012726215196640363, 0.06507121651832547, 0.013630752418456333, 0.040749230555125644, 0.03700668245021786, 0.015376833367294498, 0.01672155237091439, 0.019247081762711917, 0.05947381151573999, 0.01637329257625554, 0.006514907332270273, 0.0064415890789989915, 0.04271198469879372, 0.09172746472592865, 0.03278735153643148, 0.05185022970129337, 0.03282640801210489, 0.04656847579670804, 0.0023840143403504044, 0.021901548075090562, 0.022456420086590306, 0.00833508515331362, 0.02315172679456217, 0.027937751496210694, 0.015264837769791484, 0.043048711094473086, 0.03995372288461242, 0.018239350390753577, 0.014117062707165522, 0.04760494143036859, 0.039677925540932586, 0.07738791632332973, 0.03562892388020243, 0.04619856903861676, 0.01850954982052956, 0.06967277638614178, 0.09164360458297388, 0.06867725694818155, 0.027973769831338098, 0.03533637011423707, 0.05737658190940108, 0.05680145902026977, 0.038212089732821496, 0.06023849334035601, 0.010083891268420433, 0.015910026184948425, 0.03488027583807707, 0.04175067021112357, 0.05870633412684713, 0.01668561376365168, 0.18683739937841892, 0.1847140733152628, 0.10537383532417671, 0.14049053990415164, 0.09882125657583986, 0.14080063040767396, 0.09744869558406727, 0.09834866372070142, 0.13581292304609502, 0.1095608306516494, 0.1848511781011309, 0.07371586122150932, 0.12043763164963041, 0.1062178582485233, 0.09064735232719354, 0.07828375896705048, 0.10339384299835988, 0.07665133263383593, 0.10533471099500145, 0.1308827825954982, 0.11611502431333065, 0.15343993290194444, 0.1650751799877201, 0.10172103026083537, 0.08546209628028528, 0.14673741827053682, 0.11350480187684298, 0.18746239798409597, 0.1396006140857935, 0.1472186353057623, 0.13262752683034965, 0.09563609106200081, 0.1566020825079509, 0.0842933129253132, 0.09768941945263318, 0.11365059869629995, 0.13010862842202187, 0.0915183877306325, 0.13273233334933007, 0.08429011702537537, 0.09440733199673039, 0.12633245890694006, 0.159917038200157, 0.19939164072275162, 0.14337374376399176, 0.13563377623047146, 0.13163972912090166, 0.2044469573135887, 0.11286034967218127, 0.11523225025406905, 0.19754287706954138, 0.12167312178228583, 0.16703089433056967, 0.11326619503753525, 0.16156799532473087, 0.13727826013096742, 0.14626910697136605, 0.16616310232451983, 0.17934160945670946, 0.09284900168755225, 0.10218897515109607, 0.10396322887390852, 0.12329372125012533, 0.11038187838026456, 0.08346120507589408, 0.1855348835566214, 0.0818102683073708, 0.16660998548780168, 0.10112293556864772, 0.1669701383049999, 0.09069437480398587, 0.08213312883994409, 0.14379333624882357, 0.07276303520692246, 0.20415734499692917, 0.11583417866911207, 0.1864676656467574, 0.1441885150436844, 0.1036875740225826, 0.20819564616041525, 0.04805073554494551, 0.21170734986662865, 0.0712760528549552, 0.13254796181406292, 0.13235808057444437, 0.1816888792174203, 0.13430451255823883, 0.114949531853199, 0.11943958806140081, 0.20844267361930438, 0.05732535930084331, 0.048524159605481794, 0.14985566666083677, 0.09773291354732853, 0.06831659522971936, 0.1231361518480948, 0.14009247055011137, 0.11415047544453825, 0.15030173558209622, 0.16789856420031615, 0.1356805544346571, 0.1449137604130166, 0.12395206306661878, 0.13432017314646924, 0.15121462302548544, 0.15177563577890396, 0.10651605403316872, 0.09029244458568947, 0.11496676664267268, 0.1004890820809773, 0.15236935392022133, 0.11556599448834147, 0.18331452698579856, 0.2203222340238946, 0.12088826032621519, 0.10741154383867979, 0.1732095663568803, 0.12295832139040742, 0.12271187747163431, 0.13426530680486135, 0.11908528421606336, 0.1273224957819496, 0.1168180951582534, 0.09129829132663352, 0.09977891375975949, 0.1293139960616827, 0.10384392206157957, 0.12468589868928705, 0.07542957604995795, 0.10907485708594322, 0.1692204318408455, 0.1430443964366402, 0.08059556848768677, 0.16316477821341582, 0.13039302958973817, 0.1734393590262958, 0.07995704667908804, 0.09772667781050716, 0.13928554313523428, 0.2062583743993725, 0.21777738843645367, 0.11312178242951632, 0.062385812401771545, 0.11931912095418998, 0.2796880906181676, 0.21148238836654595, 0.09616156215114252, 0.13267685632620538, 0.15980677625962666, 0.17465669156185218, 0.10824157537094184, 0.17444774348820957, 0.13941062428057194, 0.07007577868976764, 0.16054770935858997, 0.12984000997883932, 0.07959620175617081, 0.12787252983876637, 0.10661879102034227, 0.17161214564527782, 0.1152087322303227, 0.13048711525542395, 0.10268541172678981, 0.14863278370882782, 0.1843178088643721, 0.07792803019817386, 0.1227824722549745, 0.17430120706558228, 0.0851570540773017, 0.16581926148916992, 0.047152965861771784, 0.08274042446698461, 0.09410046453454665, 0.11300831101834774, 0.13840716598289354, 0.1848310934645789], [0.037154589513582845, 0.029099496746701852, 0.02063212270981499, 0.023746866466743604, 0.017526189730103527, 0.008385469771123357, 0.07249599775033337, 0.07632262991475207, 0.023918776706393276, 0.03251743709136333, 0.022235421231016517, 0.05581066897138953, 0.020872049299733977, 0.02741583084155406, 0.016359324932896664, 0.008051925704681447, 0.04171824302258236, 0.0225266840841089, 0.057638740699206076, 0.03770706968914185, 0.014571169723889657, 0.0063484313099512035, 0.0338171098514327, 0.08577429024236542, 0.05000305721270187, 0.0912608497643045, 0.003870890035094427, 0.012601817675334002, 0.029170644536082233, 0.03271055155034576, 0.03902396706065961, 0.010658908136455076, 0.051028788422367403, 0.0681694820523262, 0.023241342610812614, 0.04279225878417492, 0.023252497726519192, 0.03410837779353772, 0.024738413082169633, 0.005208744808831918, 0.06501201433794838, 0.01454278830039714, 0.06787621243191616, 0.028812598570116928, 0.006280567630061081, 0.052263678051531315, 0.034153629293931384, 0.025395340153149197, 0.02572294873451548, 0.056581349045570405, 0.02725783396246178, 0.03444859864456313, 0.06442612649074622, 0.03183773499248283, 0.0404406022945685, 0.022132716474256346, 0.08485826796719007, 0.06046123603092773, 0.023603746467935185, 0.03624828725254961, 0.05181286617049149, 0.014477606530168226, 0.059778032691351006, 0.039500166329422166, 0.06216471176594496, 0.00961615757218429, 0.005362776922993362, 0.08487955361072506, 0.03230406157672405, 0.07700825562434536, 0.024444780445524623, 0.03000139192278896, 0.02434492383950523, 0.049185083247721195, 0.04091961069830826, 0.003240158868720755, 0.02331149804272822, 0.03375000273808837, 0.041154268463807445, 0.050018198721643, 0.034107685687818697, 0.025122499525813118, 0.02786237304098904, 0.041011436842381954, 0.028984437563589642, 0.038832491263747215, 0.029894797464034388, 0.024186636886692474, 0.04148050470809851, 0.0216065346196826, 0.03232615467693124, 0.02861841202580503, 0.044528945415679894, 0.02295100426168314, 0.0058705335832200944, 0.031027832201548984, 0.05346583854407072, 0.05297659104689956, 0.02412504287037466, 0.02152886101976037, 0.040063713411135335, 0.012204805139585264, 0.019740045935447727, 0.02617542302635099, 0.019434454119099037, 0.056780434612716944, 0.04511600034311414, 0.016782133673716868, 0.024752930338893617, 0.009046239046646016, 0.010926164420587676, 0.020315279086519564, 0.02157517782013331, 0.06270561274141073, 0.01813882033872817, 0.034567311738750765, 0.07929662176008735, 0.031054905748793056, 0.04014748873721276, 0.013060269860683807, 0.035754792126161714, 0.028812490004513944, 0.004481644070308123, 0.04071085261447089, 0.01919805251860193, 0.0401193023925381, 0.14245126183543885, 0.03149608921791826, 0.0725792743531721, 0.014986355123775346, 0.07006304937281779, 0.012081545860772687, 0.010114152233914604, 0.062041164109749455, 0.04408339896638479, 0.014129146567678877, 0.03254820865445903, 0.08438847067632846, 0.012040734523907304, 0.031282927441809855, 0.018096323690510223, 0.029911204440785304, 0.08888742247862474, 0.029920999093779495, 0.06508293481809752, 0.04886551700266344, 0.024735045852139592, 0.011026230524294078, 0.04519502931673612, 0.0041460304720593345, 0.05573935154825449, 0.0359556113502809, 0.015911513872976814, 0.01246008528063872, 0.0384276094181197, 0.05314265570736357, 0.04575440680075969, 0.060093775391578674, 0.024495409335941076, 0.0526439731807581, 0.06502825846629483, 0.039875250309705734, 0.04154706220807774, 0.02496861626527139, 0.023653323629072735, 0.015115073216812951, 0.038728794149522267, 0.005181391365892653, 0.05835485298718725, 0.031297838248844655, 0.05252254594649587, 0.021653092299987162, 0.03530247729005558, 0.026225322491622398, 0.027645133269418563, 0.07040138050381627, 0.03248615662700363, 0.013663234737967806, 0.012453314349321383, 0.04742648672046406, 0.017781517368608286, 0.019162139356402413, 0.04338408720546535, 0.08491836581379175, 0.042589254677295685, 0.05922895536891051, 0.07765788505119936, 0.11285050412906067, 0.0789696221639003, 0.02855156614844288, 0.024821615046156303, 0.031838973318891864, 0.06161216712955918, 0.026997994066083005, 0.019160202138924172, 0.03667457348534039, 0.012919408535318715, 0.08866784854659013, 0.02195130504800805, 0.011221774138643273, 0.041245728198971064, 0.06295085565320083, 0.06401836765663964, 0.02141572717976357, 0.010185502735631806, 0.015389347249375922, 0.03334358740331871, 0.037125555000134876, 0.025315225523497378, 0.022411385717402612, 0.04301836700843913, 0.023228102696261237, 0.04321011761203408, 0.004331995716451534, 0.03677390083404524, 0.02414108343821551, 0.022840518404596617, 0.08772763649799994, 0.041624391451478004, 0.01615664143381374, 0.023037564974012117, 0.061111150442489555, 0.0572442336540137, 0.04604715394920536, 0.027924754157928482, 0.03825653716921806, 0.026994976281587566, 0.017326859890350273, 0.02443176953654204, 0.0641757267128144, 0.0814095933788589, 0.02250904556629913, 0.03249353230265634, 0.011898267615054334, 0.029224242017205273, 0.09010582031416041, 0.04035849277196186, 0.029582515292401825, 0.0362468894704112, 0.05039345233568123, 0.05701730440237692, 0.056101037854594846, 0.036818894491131814, 0.025924063121367778, 0.04315216393609132, 0.03445533310462322, 0.023528473185641424, 0.04742755541311843, 0.03209879794823272, 0.06779311903353248, 0.03187041663165603, 0.035067473471696885, 0.029493393110377446, 0.05125661673290389, 0.049968292471021414, 0.04369235244978752, 0.021959925835419978, 0.010963075877433377, 0.06486446011279311, 0.06026832852512598, 0.08342033691172089, 0.011669475784791368, 0.031458654440939426, 0.007588992643702243, 0.022769813359315907, 0.03980753251484462, 0.030608657015753642, 0.012137714989616402, 0.06536992120423488, 0.009579185047186911, 0.037640630932790894, 0.009632148946236287, 0.08336482596184526, 0.012072736779893083, 0.03155979347814407, 0.04338401595928839, 0.03912854287773371, 0.03387934169066804, 0.013489508568974478, 0.014271454020802463, 0.040255613292434385, 0.01724613118650658, 0.06450710964522191, 0.07966938175793205, 0.02505158243833908, 0.03811057410868151, 0.016491995492417897, 0.04689869164888348, 0.03039627555491669, 0.003916553321427533, 0.012897247581609657, 0.017681248552565063, 0.04181383164333446, 0.014430843593020524, 0.03896912446777735, 0.031601255360458574, 0.044472827176962576, 0.046426125935145786, 0.04061508757461395, 0.022150824877566526, 0.033100335991808345, 0.030473167143229927, 0.09922022159610476, 0.03524464235774108, 0.07766398508101702, 0.009055378065178437, 0.038624442249004326, 0.03234095013301287, 0.06316494702228478, 0.0058663979122814324, 0.043631009491426606, 0.016919877978840044, 0.03684362369988646, 0.035181162014071427, 0.019180032324844172, 0.029124351484434943, 0.04186346987262368, 0.01743668587213116, 0.02976235082106931, 0.03999455372935959, 0.04142326349392533, 0.029425624425389936, 0.023487267450296452, 0.00819065303741289, 0.06673953056867633, 0.045797178255660195, 0.05815616436302662, 0.04054916789755225, 0.06133338423179729, 0.022885917486356835, 0.015574933362326451, 0.014419970069346684, 0.03962743575019496, 0.02164587777640138, 0.059994756776307306, 0.09901399444788694, 0.0313845652022532, 0.045427797362208366, 0.026457747876910225, 0.040200818197003434, 0.032901345419564416, 0.037753756291099956, 0.024282312020659447, 0.032085505447217395, 0.023530932875084024, 0.023341284033709338, 0.023736695226814066, 0.017186728838299, 0.032402096316218376, 0.02393909034851406, 0.040966188734663386, 0.032452735384660106, 0.10329630358942918, 0.09350738421614681, 0.09097075568778173, 0.18369990773499012, 0.10665868209408862, 0.06070291663386992, 0.10563996354384081, 0.14354784227907658, 0.09916128404438496, 0.17398267558642797, 0.15393442208213465, 0.21298349781760148, 0.13540295218782766, 0.13549426943063736, 0.13840817021472113, 0.11087065429559775, 0.13809208146163396, 0.1140793106917824, 0.224662184715271, 0.1332656890153885, 0.10004622941570622, 0.20300676673650742, 0.15393989107438497, 0.15061394311487675, 0.1387199434850897, 0.18537382648459502, 0.11069591117224523, 0.1113436949838485, 0.18121101414518698, 0.06999135536274739, 0.11971463901656014, 0.0747883061745337, 0.11962638875203473, 0.11545138992369175, 0.0699540020099708, 0.13726403803697654, 0.09006869766329016, 0.18774769481803688, 0.08863834584397928, 0.08103632447975022, 0.1338973915470498, 0.12386683906827654, 0.27572096777813776, 0.08802296207951647, 0.10765781133834805, 0.16855466685124806, 0.06364741934729473, 0.07585754844227008, 0.10308362357318401, 0.13064976009939397, 0.12811944873205253, 0.10737733210303954, 0.12772477205310548, 0.19762427413037845, 0.1515428168433053, 0.07255313039890357, 0.2649246071066175, 0.09330222915325846, 0.10462578439286777, 0.16096215854798043, 0.13723251330001013, 0.1806595144527299, 0.1494286781443017, 0.14053520107907908, 0.12106949702969619, 0.13904710592968123, 0.12549744014229092, 0.20715276497815335, 0.12616757489740849, 0.11522047088614532, 0.09437928814440966, 0.15643027744122914, 0.0988252531470997, 0.19080963837248938, 0.12034296244382858, 0.1484613993338176, 0.09141676354088954, 0.10286071803420782, 0.15554078588528292, 0.09189237587686096, 0.12987765510167393, 0.16367393732070923, 0.2058249805122614, 0.12289456624005522, 0.20091271267405578, 0.1416840830019542, 0.12830128254634993, 0.08123404279883419, 0.1035788862832955, 0.0791171696037054, 0.07451628827090774, 0.08331108598836831, 0.1615190865205867, 0.13153029499309404, 0.1648549818034683, 0.06697572860866785, 0.11537090209977967, 0.10393271515411989, 0.15148697341127054, 0.15452519538147108, 0.13960716873407364, 0.09455083536782435, 0.09017894603312016, 0.12359292805194855, 0.08945319176252399, 0.2289111167192459, 0.15088305010327271, 0.1890466415456363, 0.19317130664629595, 0.0882571991533041, 0.14402538165450096, 0.14985220613224165, 0.1732066622270005, 0.15415671015424387, 0.1299279752586569, 0.16545795516244002, 0.13400223877813133, 0.05256588397813695, 0.10836496696408306, 0.06482566148042679, 0.13078145017581327, 0.09707959288997309, 0.11799865109579903, 0.09533230414880173, 0.1510430079485689, 0.08181269067738738, 0.36145831857408794, 0.10283756641937153, 0.18678416152085575, 0.13814822344907693, 0.18597069302839891, 0.09024175801979643, 0.10769885592162609, 0.12912843030478272, 0.10532009535069976, 0.15677361616066524, 0.16209694051316806, 0.11318977842373507, 0.11812134379787104, 0.1111860034455146, 0.10574159451893397, 0.07207542817507472, 0.20490112794297083, 0.08767908731741564, 0.13006494433752128, 0.1459323636123112, 0.17882495932281017, 0.10427055095455476, 0.1406471457864557, 0.09997059990252767, 0.12498077643769127, 0.09551148489117622, 0.11612969424043383, 0.23175173572131566, 0.1856766023806163, 0.13493667649371283, 0.1551580514226641, 0.1378276835062674, 0.11300343235156365, 0.22833685896226338, 0.14509612348462853, 0.1413518451154232, 0.14234477254961217, 0.20091332335557255, 0.11723430853869234, 0.14681456770215714, 0.18394688091107778, 0.0874549536300557, 0.1622066189135824, 0.06630057947976248, 0.10448406556887285, 0.11436278905187335, 0.11666509908224855, 0.0937732138804027, 0.07243365395281996, 0.16124559619597026], [0.06342387598540102, 0.011194494486387287, 0.028415648798857416, 0.029241731257310936, 0.029393478828881468, 0.016757499459864836, 0.08431065628038985, 0.00603938999120146, 0.015351418838171023, 0.0213028562720865, 0.023157702991738915, 0.02795623309378113, 0.03124705668804901, 0.018057294356237565, 0.04024971343044724, 0.02558030710289521, 0.03723535214417747, 0.06530176914696183, 0.07076337893626519, 0.024405089539608786, 0.03749485107670937, 0.02428725005925766, 0.013051057051468109, 0.007888200293694223, 0.040732192540807385, 0.03486249143523829, 0.06461703231824295, 0.007908194176187473, 0.051884458400309086, 0.03272916376590729, 0.030758955915059363, 0.031396151187696626, 0.016425051227478043, 0.016526502390791262, 0.03919149057141372, 0.045560902184141536, 0.02573962712527386, 0.057974805523242266, 0.06049977003463677, 0.050445356871932745, 0.04127256086628352, 0.02606784808449447, 0.03745677508413792, 0.0059829876159450835, 0.00929247516406966, 0.00968801527882793, 0.018841175329206244, 0.07840950507670641, 0.015753433873344744, 0.020973454661933438, 0.0197065738029778, 0.014604967553168535, 0.03514561356444444, 0.07896327107612576, 0.0201144242393119, 0.006793512962758541, 0.03896872752479144, 0.07476822153798171, 0.02581350432176675, 0.05581240262836218, 0.04155018346916352, 0.04888279250423823, 0.03066136222332716, 0.031122525156076466, 0.01321633206680417, 0.04930717883897679, 0.03973386396786996, 0.038389214514089484, 0.03827493564624872, 0.02632390514814428, 0.03956786037555762, 0.05377657026318567, 0.07588728184678725, 0.046769335732928345, 0.02434061174946172, 0.062420777311282497, 0.055366238712200096, 0.05182959205870118, 0.0036397059448063374, 0.052335850428789854, 0.03845986358023115, 0.04023083319355335, 0.05218141585854547, 0.05395999524210181, 0.045839121897837946, 0.021864422031545212, 0.030688513802098374, 0.02560681407339871, 0.05105385350595627, 0.04808457408632551, 0.04454728282455887, 0.02309268237357693, 0.02160908591135272, 0.028336967574432492, 0.01191740484708654, 0.053785896727016995, 0.04202277971697705, 0.025850862763555985, 0.03781089233234525, 0.06188511462616069, 0.014451357402971812, 0.05789032791342054, 0.035023063354726346, 0.04510275873222521, 0.037383534014225006, 0.023420163729627217, 0.021289037906431725, 0.01792772300541401, 0.055659572793436904, 0.035579163514609845, 0.05152953030275447, 0.03383308595844677, 0.07354997976550035, 0.019786449249035547, 0.033739702576505284, 0.00605685802708779, 0.07373360491224698, 0.038516015745699406, 0.034755133624587736, 0.024767822486215403, 0.04144127520599535, 0.03400624470253076, 0.014738867957411068, 0.029731155173586946, 0.024949715672326938, 0.007263015090887035, 0.08259646647742816, 0.03795485371457679, 0.027673445143071667, 0.02809459316943373, 0.036480495506631475, 0.018788743231977736, 0.056052393679107936, 0.017904082845364298, 0.031192064817462648, 0.02054510059367333, 0.0470570719002613, 0.06869413889944553, 0.014538493173729097, 0.01731199149175414, 0.007700497999654284, 0.01091073198975729, 0.022205969418532083, 0.021124913856121044, 0.052923777273723056, 0.02146517881192267, 0.06881754406328712, 0.02224671544640192, 0.018783900188282132, 0.04008386590118919, 0.010131840793681996, 0.00797598745806941, 0.015105974062212875, 0.024858610471710563, 0.07124880967395646, 0.03309921980170267, 0.01746494515932032, 0.06307801990104572, 0.037035961236272535, 0.02312813582830131, 0.034030678748552284, 0.013740577552068447, 0.09338555325354848, 0.031881731203092, 0.031258554463940005, 0.0374715942889452, 0.04369504962648664, 0.014467859374625342, 0.04904951534367033, 0.03038790582546166, 0.0325809581471341, 0.0466725664612438, 0.03066576591559819, 0.026321518401216184, 0.03018580417015723, 0.07988281494804791, 0.08942516826625381, 0.021516761044040322, 0.03136227193421551, 0.023473796833838736, 0.04860067121418459, 0.013922336727513798, 0.07964882893221718, 0.057541723762239726, 0.023293376068717668, 0.01505011027412755, 0.016294295833046948, 0.06277317447321755, 0.041997219302824566, 0.020096890894430022, 0.06509228503065449, 0.040802193606006246, 0.03471073707831757, 0.023615817605916942, 0.07027803640812635, 0.023499129938759973, 0.08936608822218009, 0.03514727258256503, 0.05452040409935372, 0.013532939051011843, 0.07879373231636626, 0.024307606109817113, 0.0025335893276081023, 0.013800980739428528, 0.05587159463071397, 0.05627443069326026, 0.010923811600410512, 0.040769623925111124, 0.034708026330918074, 0.047099649972681484, 0.012280516925134828, 0.039183371899915595, 0.05059259897097945, 0.061175204148249965, 0.10817647672125272, 0.02129929226690105, 0.007570159056090883, 0.0826477026566863, 0.023715747154450843, 0.026792162164513553, 0.06117192003875971, 0.049839414922254424, 0.03500789809705956, 0.04367566727367895, 0.016267302013667564, 0.02603319869376719, 0.02650075003371707, 0.03814291987302048, 0.0531780820206872, 0.03535514517820307, 0.01667728304996022, 0.026260706396507363, 0.0719243184264217, 0.005909258000818747, 0.018536046613007784, 0.028659460001758168, 0.028213196001680832, 0.043279731912272315, 0.010552535049750336, 0.013626495459383088, 0.03836371177541358, 0.05243028214733515, 0.029938702072416033, 0.027275068751935447, 0.02151887128794832, 0.030087939064417566, 0.012404577723438186, 0.025127698800393512, 0.043456310472850285, 0.027505526385669197, 0.012280175961287958, 0.02568366834228592, 0.038597188889980316, 0.029443537749882256, 0.021177283188860332, 0.04690987051331571, 0.004407566705984729, 0.019628566024558883, 0.041248313417392116, 0.018202495761215687, 0.024113214308662072, 0.05008407090125339, 0.020199242812980498, 0.022224773320236375, 0.028188626248655573, 0.024604365096560547, 0.021357315492683222, 0.036004459086273394, 0.030129614685262953, 0.02941132429987192, 0.06036687216588429, 0.03804943810350128, 0.019202634326315353, 0.008030589171020048, 0.04737760845039572, 0.003850676052804504, 0.01471600471995771, 0.027816219089020575, 0.024792198856760348, 0.03757153231916683, 0.05779574013182095, 0.004582856898196042, 0.007941821523542916, 0.039798457108970196, 0.0424342196035598, 0.030261284405631677, 0.052746445539274385, 0.02429846454677837, 0.03481197450309992, 0.011013838778516012, 0.03557018988898822, 0.05811855995229312, 0.029785421011703353, 0.041933928948960135, 0.046818346317325316, 0.028937947736786943, 0.02131727005222014, 0.007541141506018383, 0.02867206378972956, 0.047185596610818586, 0.09052877833268472, 0.014945261346708451, 0.024045211529093127, 0.02177232108078897, 0.01690501975826919, 0.03576558083295822, 0.05710234519626413, 0.03233817831746169, 0.06229800997035844, 0.0013061784266028553, 0.017127262029264654, 0.008322981784918478, 0.04635718338457601, 0.00658282232637118, 0.0035930884686032577, 0.0466682475858501, 0.03467488668060728, 0.04909409170172044, 0.030079610047063658, 0.020728450933737413, 0.03779533691704273, 0.06727560716015951, 0.003576353674621454, 0.02379549028617995, 0.062129217599119456, 0.030246013975036994, 0.03870001747938139, 0.01792711571657232, 0.015446288211803352, 0.04599842156416603, 0.07426243474973099, 0.06918752206755535, 0.010908251944264131, 0.05831464978733233, 0.03986133016379816, 0.01640988257713616, 0.03274112633828606, 0.06300954214696373, 0.015327137462528688, 0.04190304542758635, 0.03751152946746775, 0.013585050540444042, 0.016676918337387697, 0.02006471137117062, 0.07352933873023305, 0.021304035226681402, 0.057824001115347655, 0.0941072634554335, 0.07001082253243242, 0.03165855085743325, 0.05146563605272344, 0.05938899463840893, 0.11864199728838035, 0.10788452345877886, 0.0873063544609717, 0.12571814044245652, 0.14131395571998187, 0.08322835899889469, 0.1326625935201134, 0.14102253850017274, 0.15293100449655736, 0.05137653083407453, 0.060951294377446175, 0.13672760182193347, 0.1302375772169658, 0.08163979316928557, 0.10024500624941927, 0.06472595754478659, 0.10601626549448286, 0.1275662255606481, 0.17416400728481157, 0.08048627006688289, 0.12491400859185628, 0.11212326386677367, 0.11383159791252442, 0.1719272301665374, 0.1328297166952065, 0.1084862347426159, 0.1297355970101697, 0.1446840763092041, 0.12792012228497437, 0.084299636871687, 0.0776024419548256, 0.18675449596984045, 0.11736240237951279, 0.11190900964928524, 0.136933672907097, 0.12503894045948982, 0.1405504545462983, 0.2577494792640209, 0.16258840342717512, 0.13012761383184365, 0.09191822127572127, 0.1731342761112111, 0.1081337086590273, 0.1539816888315337, 0.10626566782593727, 0.12371766992977687, 0.09744226985744067, 0.15386008178549154, 0.07879928951816899, 0.0978017102128693, 0.08749708386936358, 0.12757713640374796, 0.1593401748687029, 0.11918490672750132, 0.10490631112562758, 0.060974995605647564, 0.14828541449138097, 0.17018009748842033, 0.18428712551082882, 0.2575619321848665, 0.16936851532331534, 0.14935675343232496, 0.15376615896821022, 0.04896746688921537, 0.08482520974108151, 0.12233066292745726, 0.09911162206637007, 0.13593590073287487, 0.09891606148864542, 0.06146439577319792, 0.11665099912456103, 0.11771051798548017, 0.13628883393747465, 0.1858620731426137, 0.05812440213880368, 0.10074130711810929, 0.12174788277064051, 0.1186809316277504, 0.09772954122828585, 0.20496157184243202, 0.19926546035068377, 0.15242284962109157, 0.10532289770032678, 0.09795230427490813, 0.14953458389001234, 0.1591787649584668, 0.07961077668837138, 0.14717458481235163, 0.12518713250756264, 0.13221820736570017, 0.10322938646589007, 0.12944165564009122, 0.09426258012120213, 0.08932555932551622, 0.1371062650744404, 0.10314544489873306, 0.18616957164236478, 0.16727804392576218, 0.1773824617266655, 0.10883439784603459, 0.06522894198341028, 0.17624096226479324, 0.0812191760965756, 0.1288516151585749, 0.08961361779698304, 0.10267504371170487, 0.06395037166242089, 0.07857345270791224, 0.15404182060488633, 0.1232599573475974, 0.14512103929051332, 0.13491633401385375, 0.21557987135435852, 0.06801910512149334, 0.13031387169446262, 0.06494552469147102, 0.20182561368814536, 0.15923110714980535, 0.07692010035472256, 0.18670855914907797, 0.16475601068564824, 0.10839012025722436, 0.09655115660279989, 0.1405915737684284, 0.18681468202599458, 0.09833551371204001, 0.24458063447049685, 0.14503652096859046, 0.16035423188337258, 0.13789719263357775, 0.18243367996598991, 0.17057538484888418, 0.16615440350558075, 0.05131095042452216, 0.08276909257152251, 0.07414026451962334, 0.08695504295506648, 0.14589387710605348, 0.07950706939612116, 0.14581794903746673, 0.12624718062579632, 0.13620278212640965, 0.07667200759585414, 0.042351502792111466, 0.11117268380309854, 0.20906620658934116, 0.14885060702051434, 0.09730556540723358, 0.13597765777792248, 0.136430240635361, 0.10207869285451514, 0.08228087984025478, 0.06199466410492148, 0.07936951677714076, 0.12619288425360406, 0.16200935521296092, 0.0434133320647691, 0.2409245249416147, 0.10174093847828251, 0.09472669807395764, 0.15027995460799762, 0.14635030047169753, 0.1516849020762103, 0.11097121997071163, 0.1385124610470874, 0.14121286757290363, 0.11591607784586293, 0.04672145490933742, 0.1372878546161311, 0.15522515853600843, 0.1748110175664936, 0.17035343604428427, 0.16437525754528387, 0.10832703007119042, 0.10951065298702035, 0.10623047221451998], [0.10545614840728895, 0.016180481761693954, 0.01368178503720888, 0.016583114263734648, 0.06083217755492244, 0.07603336365095206, 0.011564765957051089, 0.046620081777551343, 0.027178730349987745, 0.06409302007939134, 0.05365583513464246, 0.061506722787661214, 0.04692657943814993, 0.02037534300637032, 0.04194265151662486, 0.04953528195619583, 0.03724727061178003, 0.021833711536601186, 0.0822847882019622, 0.04303023458591529, 0.03373755162049617, 0.0576812509181244, 0.03237737050013883, 0.03263110527768731, 0.07152429489152771, 0.0608563469722867, 0.01783724544968988, 0.06505163399768726, 0.010892191020372723, 0.0416312717965671, 0.035322741738387516, 0.01888366010306137, 0.02553297928534448, 0.030616880860179663, 0.025957989872300198, 0.03382827853783965, 0.018801791460386345, 0.018512194410764744, 0.0684635252026575, 0.046540465871138234, 0.05727434703814132, 0.009600945665234966, 0.036778195960713286, 0.02689896018377372, 0.016920495445707014, 0.037937069311738014, 0.0016687507512480287, 0.0050004960503429174, 0.05034727802766221, 0.01815153269230255, 0.04605895367317966, 0.0305463267889406, 0.003679129253474197, 0.036102527752518654, 0.009870330004819801, 0.05965627636760473, 0.02368874485338373, 0.026939102315476963, 0.012439881900458463, 0.04712392117029854, 0.014370073996750372, 0.06414090429565736, 0.014937281774889146, 0.02790458470449916, 0.027105879437710558, 0.05676647375470825, 0.04657822295225092, 0.02441848042820181, 0.02461248716073377, 0.038434747606515884, 0.006155339327441263, 0.027053242083638906, 0.017804757192996994, 0.0818480694932597, 0.012487796650800322, 0.006997075588775, 0.04765739557998521, 0.02546577717709754, 0.05623607989400625, 0.044004861930651326, 0.07035762856581382, 0.05103360602099981, 0.020128368133945123, 0.0043647536908143336, 0.03757933207920619, 0.0464421834663621, 0.049319531568991284, 0.03508550553981747, 0.09294183206345354, 0.03924915586997356, 0.04245690302923322, 0.01272557398104774, 0.02206853554317994, 0.004541059989216072, 0.047744600900581906, 0.11536411674959318, 0.01974144032491105, 0.014223423071338661, 0.059945026944790564, 0.029466109217277596, 0.032236442169440646, 0.04259916468124304, 0.07678627289299454, 0.0650289234306131, 0.026573556841218045, 0.0616625076425927, 0.054049582220613956, 0.06340991852006742, 0.022736214001529982, 0.01264726001370166, 0.04984849372080394, 0.05903474507587297, 0.03953626099973917, 0.059136206417211463, 0.02082510824714388, 0.015990376605519226, 0.04370632009314639, 0.02270187164789864, 0.02162957257990326, 0.041243916510471275, 0.03995209440056767, 0.02025088611324983, 0.029391589108854532, 0.016190037231094072, 0.04047608967604382, 0.03400562384298869, 0.056635455427957435, 0.02571894198523036, 0.064488992760224, 0.020937054650858045, 0.05489511827805212, 0.06448207848838397, 0.01566184521652758, 0.033161078446677754, 0.03303120345143335, 0.03127768915146589, 0.0028527883155870116, 0.06276307108678988, 0.04282969016847866, 0.047781302859740596, 0.08817979866372687, 0.014326810603961349, 0.013179247583528715, 0.020656314179567353, 0.013808627829088696, 0.09000819948102746, 0.027535699141610945, 0.03188366502789514, 0.016937904957947985, 0.043739863471793275, 0.040801467573536296, 0.0199725493522627, 0.03274940446551357, 0.03489000263756939, 0.02151167033506291, 0.026967320890565003, 0.02738918307503419, 0.012890932116923588, 0.016972230348203863, 0.028643107307808738, 0.01231724432935672, 0.0345250729338399, 0.03696987531813128, 0.02318604031045522, 0.06502268769379173, 0.005638359255889165, 0.02564081546318318, 0.026542496900739412, 0.018291295639106205, 0.042868353093841245, 0.03405059714402471, 0.03516401543415018, 0.010613641369023492, 0.06016137105013643, 0.03808291023597121, 0.07179254014045, 0.04650686481701476, 0.03716340368347509, 0.027201391723273054, 0.016207987875012413, 0.014456802646496465, 0.09341306784855467, 0.012182541557454636, 0.06427358503320388, 0.030333714626197304, 0.08165304495819978, 0.029871045345706598, 0.021721159540382878, 0.10237055112208639, 0.007035553613345006, 0.09987390866237027, 0.01778165646828711, 0.050065010852579556, 0.029404077545872757, 0.028398235893941352, 0.039624229672231844, 0.01823852936338101, 0.110271209318723, 0.014103424153290689, 0.06106628570705652, 0.030832631247384206, 0.05521465398903404, 0.0025359720457345247, 0.01080715361916061, 0.030691305973700116, 0.03532575104119522, 0.04766053719712155, 0.030392258627606288, 0.033839006176484485, 0.040898650751582215, 0.017334021827472106, 0.027321931772998402, 0.02380092365534178, 0.016781373714495982, 0.025691191599305187, 0.03037579058270369, 0.04153892996587923, 0.01843077190486448, 0.05533586748476539, 0.0011361815496846767, 0.03395562259746449, 0.055593385095042844, 0.03870147632967148, 0.019938395292099034, 0.03108446951955557, 0.01971420562560005, 0.04426127692152347, 0.027156476097713624, 0.07933474185743503, 0.02490816727679755, 0.008680844546428748, 0.07802920655480453, 0.02191926632076502, 0.022384916066325138, 0.027306663038741266, 0.013337620201387575, 0.05744748881884983, 0.03392020646216614, 0.005046267054110233, 0.04434139155117529, 0.04052821473617639, 0.07585412184042589, 0.05189129124794688, 0.05243358661287597, 0.014974479064611452, 0.020005928186167563, 0.04691015889069863, 0.014190102761079158, 0.02078153781725892, 0.04388288508302399, 0.05216463908020939, 0.026688692359519855, 0.021622792318729416, 0.04457928592871342, 0.022112809953146746, 0.07165139807122094, 0.02863686139296208, 0.03604119497218302, 0.04240406211465597, 0.01861759804056159, 0.04459492955356836, 0.06555364813123431, 0.025361321799989258, 0.07804429038826909, 0.044312370608427694, 0.0341665723494121, 0.052602002397179604, 0.009656062216631003, 0.03339116967150143, 0.04335127664463861, 0.06902457866817713, 0.016955701235149587, 0.011399724188127687, 0.04882248431178076, 0.01959534834272095, 0.06498618929513864, 0.04795139801821538, 0.048653824254870415, 0.0833910581256662, 0.0038350879830042167, 0.05106308497488499, 0.0569867906825883, 0.051283924374729395, 0.039095148776790926, 0.03259103099948593, 0.0344480592092233, 0.06670034517134939, 0.025272594864613245, 0.025979935391140834, 0.019293702207505703, 0.04203402982758624, 0.028230345974277173, 0.011785545136912592, 0.02841768610025091, 0.055632712984723706, 0.019072163916592087, 0.027135891041585376, 0.02522514491075916, 0.022507603679384505, 0.06217047252825328, 0.022253100460927402, 0.028421056722956042, 0.041547486292464395, 0.01307111285028181, 0.06287846953741141, 0.06083278823643923, 0.012862498106967126, 0.02499596292286047, 0.044805411116353104, 0.04202934115060738, 0.014821447365518128, 0.01269872095768473, 0.016176044142671993, 0.05319693172350526, 0.040343778740082464, 0.09981275230113949, 0.014889061683788896, 0.03544332080387643, 0.02848007230620299, 0.046013250946998596, 0.025875719197626625, 0.08870171422937087, 0.02893628871866635, 0.014743904383586985, 0.01745971535066409, 0.03728466806933284, 0.026302733159224902, 0.013588533121427255, 0.048595884149628024, 0.019209014251828194, 0.03716220606916717, 0.052389807533472776, 0.061556873310889514, 0.013322653415213739, 0.04267787813608136, 0.035651773546955416, 0.03492685387443219, 0.044492823603962145, 0.030086283438972065, 0.03624189205999885, 0.01840495364740491, 0.09274346913610186, 0.05022179315398846, 0.02988633613235184, 0.03316252033359238, 0.036631713820887465, 0.03232371195086411, 0.023509043335382427, 0.016156091820448637, 0.006848741896517042, 0.028478141874074936, 0.03932877177638667, 0.18245375103184155, 0.08589681331068277, 0.049448633034314425, 0.09369832397039447, 0.12352807367486612, 0.19323213052536758, 0.12497180620474474, 0.14346070481198175, 0.13753784048770154, 0.19208003234650406, 0.11294824031314679, 0.11831825466028281, 0.14959721267223358, 0.07764894874500376, 0.15345783265573637, 0.15306258600737366, 0.21902608286057199, 0.07681072729506663, 0.1819100273506982, 0.09722268914005586, 0.10981545091739722, 0.23030010504381998, 0.12531187438539096, 0.15887341062937463, 0.15281249157020024, 0.10386171324976853, 0.0804175819669451, 0.10561941750347614, 0.08641674076872212, 0.1451632170272725, 0.14454547874629498, 0.12037930477942739, 0.08964657424283878, 0.09853370700563703, 0.12695622257888317, 0.12210234946438245, 0.16414262859949044, 0.13550581809665474, 0.15041742580277578, 0.17176406963595323, 0.2758456553731646, 0.18429923057556152, 0.08205949421972036, 0.057711696784411154, 0.0912666783801147, 0.08517485205084085, 0.1678574721195868, 0.07331197682235922, 0.10971308712448392, 0.11831415630877018, 0.11052937153726816, 0.08800561872443982, 0.12974359015268938, 0.09576525020280055, 0.10040350524442536, 0.1829501265393836, 0.1644243291978325, 0.06853167725993053, 0.13181206344493798, 0.17238000301378115, 0.14918272277074202, 0.1621584157858576, 0.0789137990879161, 0.1396255706037794, 0.15003437921404839, 0.17190702339368208, 0.10864951740950346, 0.149439968967012, 0.09620210461850677, 0.1746793139193739, 0.07545998798949377, 0.1602836371000324, 0.0786990291838135, 0.17886112523930414, 0.09396271514041082, 0.15678527339228562, 0.07485597647194352, 0.17755428036408766, 0.10198552999645472, 0.12532723641821317, 0.10057150372969252, 0.16981718981904642, 0.1331900187901088, 0.17220461528216088, 0.07672636503619806, 0.08957988782120602, 0.13652210070618562, 0.18844007195106574, 0.1427753573017461, 0.08576295192220382, 0.118405514263681, 0.1988872585019895, 0.14750059374741145, 0.15817177827869142, 0.2505378733788218, 0.21476275234350137, 0.062066867016255856, 0.20879319123923779, 0.12072467910391943, 0.16639723761805467, 0.10293932631611824, 0.14906080359859125, 0.14747821566249641, 0.11303969326296023, 0.10978620605809347, 0.11832438861685139, 0.2128053145217044, 0.18859300017356873, 0.13264037828360284, 0.10214893479964562, 0.17222488990851811, 0.12816503271460533, 0.14175930539412157, 0.14961759586419376, 0.09636899030634336, 0.10910516724522624, 0.12133441067167691, 0.05498441009383116, 0.14278713666966983, 0.12080188281834126, 0.20369562905813965, 0.08075885115457432, 0.16038050475929463, 0.1491790586816413, 0.11276025218623024, 0.26670972417507854, 0.17104377757225717, 0.07756188591676098, 0.09534398852182285, 0.14123094374580042, 0.13440522072570665, 0.15059901534446649, 0.050701819360256195, 0.12915517815521785, 0.08593409202460732, 0.11150283180177212, 0.09201622208846466, 0.2366526855954102, 0.08880281594714948, 0.2489293654050146, 0.21851874222712858, 0.09163051564246416, 0.24434960686734744, 0.08871852832713298, 0.09957048137273107, 0.1382396492574896, 0.08190396042274577, 0.11627522643123354, 0.077421510592103, 0.10990697850606271, 0.10584978014230728, 0.07711865327187947, 0.15949693002871104, 0.13262144715658256, 0.06887672588761364, 0.13335970682757242, 0.23699469438620976, 0.06777665098862988, 0.0845227391858186, 0.12786737297262463, 0.08329113027346985, 0.10957571770995855, 0.17174893830503735, 0.08430482087922947, 0.1396325866558722, 0.16626239913914884, 0.10760202218911477, 0.12699745036661625, 0.09916772334171192, 0.11148916610649653, 0.12037679419985839, 0.10120058711618185, 0.09551065029310328, 0.12146359016852719, 0.0640299841761589, 0.24236483765499933], [0.009095080845457102, 0.02470969917651798, 0.017709416237526705, 0.06235866421567542, 0.023308444635144303, 0.051819576881825924, 0.060677607277674336, 0.034190667127924304, 0.10002397346709456, 0.05221742231931005, 0.012410797345052873, 0.06479560916445085, 0.03262827578665955, 0.01485035295731255, 0.015765433765149543, 0.029981388710439205, 0.02350851916708052, 0.08509184686200959, 0.008240677183493972, 0.05392086073490126, 0.0013263230710955603, 0.031892889711473665, 0.048577553526099236, 0.036528169377041717, 0.01814064390159079, 0.006091991722184632, 0.05991861157651458, 0.0209785691196365, 0.044241694400885274, 0.05189408002687352, 0.03571862281699266, 0.03095122899061867, 0.07085169026894228, 0.010933701248307313, 0.02994498869936381, 0.07270186527499131, 0.04347099397065384, 0.01889570240330483, 0.022087091779602424, 0.029350435959973505, 0.09150175005197525, 0.024769162592877234, 0.0201617401824998, 0.06227058358490467, 0.024099212738552263, 0.024373281514272094, 0.02311966771126858, 0.014579393568315675, 0.022700419582958733, 0.02200848180135446, 0.005845541866230113, 0.04120371670329145, 0.04198873422241636, 0.04997550190559455, 0.06376342169408288, 0.014142916587713574, 0.024306817312857935, 0.04414014484999435, 0.04851454815694264, 0.024173754899363433, 0.058302612576101503, 0.014337326200412852, 0.04266030407909836, 0.03041972911783627, 0.011700065839769585, 0.027453988258327757, 0.02608232632545488, 0.042488661860781055, 0.010481808800250292, 0.011950497848114796, 0.02980641827785543, 0.03812587168067694, 0.025729681498238018, 0.0336325618970607, 0.055005349684506655, 0.04612860529284392, 0.02334856810713453, 0.01796034866544817, 0.015020823006385138, 0.040230602491647005, 0.04827657574787736, 0.0652390792965889, 0.02996565348335675, 0.04014157530452524, 0.05354975296982697, 0.023641500156372786, 0.02879385743290186, 0.05169987991186125, 0.05709313069071088, 0.016123992025053928, 0.0071761286817491055, 0.011216864937783351, 0.06379794555583171, 0.04676109153245177, 0.07447595614939928, 0.031709895602294376, 0.021486783366916434, 0.05757478877369847, 0.05010011146909424, 0.08766065830630915, 0.023475491475047808, 0.09180278889834881, 0.035843127207564454, 0.03140822911102857, 0.00717982669760074, 0.03420865169859358, 0.030949586935873543, 0.012434191536158323, 0.00861246433175568, 0.015438027047951306, 0.01828599628061056, 0.071649762801826, 0.04221425551388945, 0.054605831658201556, 0.05086054566449352, 0.030739105373088802, 0.02943891692640526, 0.03650737567139523, 0.06918144917913846, 0.028065200728763427, 0.035496063330875974, 0.05509288748726249, 0.05144817056134343, 0.02385510128390576, 0.06645070535263845, 0.025448028397347246, 0.02859722476984773, 0.03722940817741411, 0.03801871743053198, 0.036666448028492074, 0.010744538407639732, 0.02153225539119116, 0.01426650580417897, 0.026241100127143518, 0.03862587056521859, 0.010530928798419024, 0.037262513900973966, 0.02386675851552614, 0.020971296920574138, 0.02902881714648434, 0.04543985832216484, 0.051728286780416965, 0.01845831873028406, 0.02751226763107947, 0.03898979603712048, 0.04399035145927753, 0.02250505917306457, 0.017155957275203297, 0.046489633420216184, 0.03498457345579352, 0.03028927058247583, 0.09046492140207972, 0.040461267078561444, 0.02020252013712057, 0.06747641959892851, 0.036866432654538324, 0.03684704690905554, 0.06600244476326875, 0.039332208556256125, 0.023249101658750857, 0.02871920501015016, 0.060817385491515906, 0.03914704992036734, 0.03460447849439723, 0.01769133158294218, 0.043742312983210595, 0.06000692290919168, 0.0418462384758251, 0.03855964894007359, 0.011702438167828535, 0.03802803710901311, 0.017514096539733664, 0.06837482710501977, 0.015288673008659055, 0.02922922246424215, 0.01955241403941597, 0.06088819062071187, 0.02558572350868157, 0.028170546683083688, 0.020996407805276767, 0.019496986210080128, 0.05381898209452629, 0.06287148741206952, 0.03081885020115546, 0.03394980415967958, 0.019935335099164928, 0.045584264144833596, 0.07489536542977605, 0.012944218320106822, 0.04322518787479826, 0.015646554429882338, 0.052001451408224444, 0.018840322071420293, 0.016518975741096904, 0.023451225366443396, 0.07548710903418915, 0.04401719091194017, 0.069343130503382, 0.03925464182559933, 0.030789513739624193, 0.024523634696379304, 0.018038373407242552, 0.0336367281020752, 0.047930081840604544, 0.06207007648689406, 0.04815668200275727, 0.07801041792013816, 0.0241310224602265, 0.04477646481245756, 0.020546208302091275, 0.01776243866022144, 0.04690378744687353, 0.03861128206231764, 0.06412385271063872, 0.04476481097351227, 0.07585718203336, 0.03141361328640154, 0.019409087087426866, 0.01444193085522524, 0.08279856813273259, 0.04811999700697405, 0.05148867231660655, 0.022194078092330267, 0.025135749618389776, 0.00897768750188074, 0.03690509557990091, 0.012131933871257519, 0.039172335527837276, 0.05232796245919807, 0.010326034123344081, 0.07852991111576557, 0.035674314480274916, 0.034909995671893866, 0.07258110639772244, 0.016495637529130493, 0.03666773385235241, 0.019985103946445242, 0.04071393994880574, 0.046162423478173356, 0.015340709859239203, 0.015002039460731404, 0.08318450528063945, 0.024754531681537628, 0.022201750627053634, 0.028746563542102064, 0.048151671021644554, 0.04043395943673594, 0.03392761945724487, 0.01613456699331956, 0.04609489567311747, 0.02563919885350125, 0.07984516303986311, 0.02446187104630683, 0.03475704030799014, 0.028755309858492444, 0.007879632940915014, 0.03144459180267794, 0.03275268178965364, 0.03930479913417782, 0.025618798698165586, 0.03430408425629139, 0.012680182532806481, 0.01951865352956312, 0.058453247350241454, 0.0445461123516517, 0.02828247781975993, 0.01354991175633456, 0.1173612895820822, 0.03783146212143557, 0.012083347371247197, 0.028470847622624466, 0.05715347959526947, 0.014622151452515806, 0.06778940744698048, 0.023943234501140456, 0.009667643113061786, 0.0471100349511419, 0.05168374774179288, 0.04737410720969949, 0.0022842626952167067, 0.0304849295477782, 0.07235419750213623, 0.06033800728619099, 0.013584203219839504, 0.03326487734115549, 0.059962784206228595, 0.03487462364137173, 0.06633331879441227, 0.049000813492706845, 0.04628937059481229, 0.039676629539046965, 0.03842530918440648, 0.06462035713983433, 0.045295272687716145, 0.05482898486245956, 0.03627211740240455, 0.03752665740570851, 0.04070887468489153, 0.049023018551192114, 0.013100413688724595, 0.012584904341825416, 0.041066452461693964, 0.022205616580322385, 0.04180799624217408, 0.017754649078207355, 0.024240816211594, 0.03563283224190984, 0.05743458308279514, 0.04377803445926734, 0.04124587747667517, 0.03601935971528292, 0.038193738753242154, 0.04783757376883711, 0.04896779597869941, 0.045413649907069545, 0.030103206102337157, 0.013229424399988992, 0.02520047846649374, 0.04490610910579562, 0.1023617573082447, 0.05590304133615323, 0.007757148040192468, 0.044620523894471784, 0.01790643566554146, 0.06013471819460392, 0.033191144333354065, 0.05266433601666774, 0.056146662549248764, 0.026636674168652723, 0.034207769603069337, 0.023357015868116702, 0.03434075228869915, 0.04790315757106457, 0.06890252378902265, 0.04143753308536751, 0.03339512553066015, 0.05304908912096705, 0.029845227088247026, 0.0462352472490498, 0.05064191150345972, 0.043938596200730116, 0.02997552277520299, 0.0179327730022903, 0.03125994546072824, 0.01325529015489987, 0.010426808447976197, 0.05406174496082323, 0.046514759571956735, 0.028674706683627198, 0.0312873209560556, 0.03807992807456425, 0.030913122463971376, 0.09638947527855635, 0.13930722911443028, 0.11998800720487322, 0.1473953936781202, 0.11088183655270509, 0.13435757399669715, 0.13382071708994253, 0.13106978684663773, 0.188633834410991, 0.14987153080957277, 0.11497488192149571, 0.1290777437388897, 0.16018953786364623, 0.09273744374513626, 0.10538717532264334, 0.11892456641154629, 0.10142655963344233, 0.128476955262678, 0.10911491100809403, 0.17985146066972188, 0.10374307818710804, 0.1860273778438568, 0.12578904735190527, 0.09406328081552472, 0.07044268971575157, 0.11993257089384965, 0.09291767621678965, 0.16771523760897772, 0.10011248836027724, 0.18304498573499067, 0.1289920447660344, 0.11936341572020735, 0.23600218764373235, 0.0954087275479521, 0.18768372253647872, 0.23660206688301905, 0.17902964619653566, 0.13582130973892553, 0.08243998951677765, 0.1880541890859604, 0.08605823000626904, 0.09755226038396358, 0.09827448627246277, 0.20449346410376684, 0.10303856884794575, 0.12394387993429389, 0.12171956071896212, 0.10510708963764565, 0.18890184217265674, 0.14032581874302455, 0.058166668085115295, 0.18846239575317927, 0.19626002519258431, 0.1502299601478236, 0.19145312027207442, 0.11436319617288453, 0.20929555142564432, 0.14260220873568738, 0.11144307322267975, 0.1586366697613682, 0.12926482941423142, 0.10740590521267482, 0.1444907481116908, 0.0786892854209457, 0.06222183084381478, 0.1573528815060854, 0.09535517756428037, 0.08389661421201058, 0.07390606137258665, 0.1266732191933053, 0.17272691082741531, 0.13545692286321095, 0.140823700598308, 0.12807511325393403, 0.1290949106748615, 0.16677332243749074, 0.10915486314999205, 0.06456641360585179, 0.09191697955663715, 0.12411941694361822, 0.05656137975997158, 0.12745595004941734, 0.0633373356291226, 0.12583099438675813, 0.11638228568647589, 0.16115085913666657, 0.1171304112566369, 0.19066428260079452, 0.12877565994858742, 0.21492216736078262, 0.0718997283173459, 0.22672370980892861, 0.14793803170323372, 0.09479835815727711, 0.13362326339951583, 0.1786644993616002, 0.1518425393317427, 0.13502594456076622, 0.11301828548312187, 0.09903100532080446, 0.06994166624333177, 0.1316485365054437, 0.0850348567057933, 0.1958541391151292, 0.11603106239012309, 0.14996476152113505, 0.1361538597515651, 0.08878412230738572, 0.1395015615437712, 0.15041218751243182, 0.08072408302021877, 0.16839120776525565, 0.10761910770088434, 0.17670915142766067, 0.13886892263378414, 0.17046992693628582, 0.14119206368923187, 0.11919223490570273, 0.1921659213091646, 0.07497189060917922, 0.10923563595861197, 0.0895452078964029, 0.2328278108366898, 0.06830592865922622, 0.1960772821413619, 0.1362728476524353, 0.10989200323820114, 0.1750368204499994, 0.07946257785494838, 0.11651238799095154, 0.12378544200743948, 0.11850730808717863, 0.14704089984297752, 0.12775580824485847, 0.10910125888351883, 0.07836284222347395, 0.12209519770528589, 0.05114744044840336, 0.14382661160613808, 0.15655245445668697, 0.2832802821482931, 0.16327907065195696, 0.13421972282230854, 0.16483478860131331, 0.08460535082433905, 0.12137888185679913, 0.07396237977913447, 0.07711538273308959, 0.10938664392701217, 0.13414090419454233, 0.13891983990158352, 0.14498896923448357, 0.0850486648934228, 0.123356947143163, 0.16521369612642697, 0.07584306850497212, 0.2005962710827589, 0.14002781973353454, 0.07771366062973227, 0.06591778394899198, 0.10268883832863399, 0.15619412011333875, 0.14154133280473097, 0.09410893943692956, 0.14288526640406676, 0.0659447353599327, 0.15905695435191902, 0.12386355495878629, 0.09636191997144904, 0.07920596948159592, 0.15233465363936766, 0.11494850047997066, 0.10376247750329119, 0.08646156479205404, 0.08238195441663265, 0.0786854245566896], [0.02656524139456451, 0.021198271973324672, 0.04673048960311072, 0.026765444848154272, 0.051479942963591645, 0.02947600565052458, 0.052874254395387, 0.034099529696894545, 0.003479586523358843, 0.05942820717713662, 0.022413287311792374, 0.013825748963946742, 0.022775528320510472, 0.04667387603382979, 0.02134589065930673, 0.03704936230289085, 0.01484089417915259, 0.03878039673769048, 0.0034126076955414775, 0.03380068251863122, 0.05866522169006722, 0.04002295720524021, 0.01077070611063391, 0.010854453447141817, 0.023740671442023346, 0.04190315060051424, 0.02987841084333403, 0.008330087742901273, 0.021032327752826468, 0.028339203347318938, 0.02804134683018284, 0.021973101289144585, 0.05652007733338645, 0.042555090439106734, 0.018851446653051034, 0.054156865392412455, 0.020052942181272165, 0.037201523780822754, 0.009771477630628007, 0.06634947471320629, 0.01853943250275084, 0.046406160042222054, 0.032372125424444675, 0.022693111760807887, 0.048678478824773004, 0.012150991375425031, 0.05342015617394021, 0.06605318561196327, 0.03791687271690794, 0.052098003548703024, 0.033807111637932916, 0.005473291617818177, 0.01491838796729488, 0.025542872325916375, 0.08369390187518937, 0.031249387455838065, 0.055679531901010444, 0.043366387619503906, 0.02627217024564743, 0.027525276843724505, 0.03837661751146827, 0.03497186449489423, 0.038871398461716514, 0.02954940956884197, 0.03401788157810058, 0.03835545400423663, 0.02666736430754619, 0.02009911648929119, 0.0062440467549354905, 0.053833394178322384, 0.024232373539624468, 0.012731242292959775, 0.022381392773240805, 0.010721262111993772, 0.0575907343466367, 0.054424174263009, 0.031582252987261326, 0.030424326192587614, 0.027002423203417232, 0.034886799952281375, 0.06461091871772494, 0.008093889702909758, 0.027610410936176777, 0.029124202206730843, 0.022700263519904444, 0.023639408572177802, 0.0182957671848791, 0.02130718362916793, 0.03675122080104692, 0.02003888293568577, 0.03383007326296397, 0.031963925542575974, 0.021028032626158426, 0.019152254797518253, 0.05194946884044579, 0.08328595305127756, 0.03112939532314028, 0.01646879468379276, 0.02686795622243413, 0.058370879984327724, 0.031475712811308246, 0.026083880170647587, 0.042338909182165346, 0.020337808145476238, 0.052444894398961744, 0.005945113911626062, 0.0642218670940825, 0.06622193048575095, 0.025691673359168426, 0.05147817198719297, 0.021270413816507374, 0.008847062725440731, 0.07722346657621008, 0.06158214874033417, 0.004500213877430984, 0.02224949574364083, 0.024507151384438788, 0.06589043898774044, 0.0048722325757678065, 0.06966336510543313, 0.021240451406421404, 0.07819794464324202, 0.02202095666767231, 0.02964704736535038, 0.036152013311428685, 0.01460268089015569, 0.03587664344481059, 0.00037119144222482907, 0.02772254902603371, 0.046335955416517596, 0.07090688230735914, 0.04678458920014756, 0.04190524388104677, 0.03075997032491224, 0.037280973446156294, 0.031263137967990975, 0.04366232388253723, 0.021532557339274457, 0.04631871723436883, 0.03250617001737867, 0.04647119762375951, 0.03049721781696592, 0.03497587124417935, 0.03824939558814679, 0.05129332887008786, 0.05789505730250052, 0.03125091415963002, 0.0630134708647217, 0.04937286102878196, 0.021212366841999546, 0.013402411813980766, 0.05968463234603405, 0.02284702385908791, 0.03509821789339185, 0.06899306750191109, 0.02284161763132683, 0.043748694605060985, 0.0360244894400239, 0.07468778121152095, 0.06555920533303704, 0.03680526611528226, 0.05265104351565242, 0.035170407234025855, 0.045389256573149135, 0.03454784117639065, 0.02353780304214784, 0.00551194097248039, 0.004664755650862519, 0.13057717042309896, 0.028883661542619978, 0.003258625623337658, 0.014570062015471714, 0.0372621983821903, 0.03540276815848691, 0.02128748406123902, 0.03693408938124776, 0.0309381604061595, 0.04668367747217417, 0.02621545659245125, 0.02811532241425344, 0.03420828189700842, 0.030432336298482757, 0.016773229597934654, 0.08493699160005365, 0.012699728582187422, 0.034317468359534226, 0.026259045682049224, 0.04729461004691465, 0.052948431843625646, 0.02851450117304921, 0.012412684520573487, 0.05243568667875869, 0.011734848392994275, 0.01914884176637445, 0.02785940614662, 0.0213335803377309, 0.05645757408014365, 0.041565406402306895, 0.04055051139688917, 0.06703186381076064, 0.025862435178299035, 0.03788829282192247, 0.011474333354271948, 0.022689895504819493, 0.052790743697966845, 0.043584818220032115, 0.028421718294599226, 0.038645042572170496, 0.028064554424158165, 0.05334467933114086, 0.003399501791656283, 0.016166113782674074, 0.05651075765490532, 0.057728836578982215, 0.014460748327629907, 0.051880061493388245, 0.0155146404369069, 0.034656437313450236, 0.05536329387021916, 0.04751076076978019, 0.02585244205381189, 0.030159775566841875, 0.051880617892103534, 0.027618906194610254, 0.00970264958284263, 0.01823312652829502, 0.030429961425917487, 0.01880675324771021, 0.018341737932392528, 0.00888095554962222, 0.13706985488533974, 0.03881439473479986, 0.010185832673284625, 0.04242964627753411, 0.05568197801975267, 0.06547271247420992, 0.03489191271364689, 0.008427865487257285, 0.02537625126673707, 0.030581681856087277, 0.03752513409459165, 0.009046121151186526, 0.021016536546604972, 0.017652314123032347, 0.012301270766848964, 0.046209622374070544, 0.10171070295785155, 0.04394650113369737, 0.03554267190130694, 0.06248493958264589, 0.022647850082388947, 0.033616066710757356, 0.051423085121704, 0.027918698232887045, 0.03707118398909058, 0.06567921782178537, 0.031102433734174286, 0.030086442894701446, 0.01917885337024927, 0.006747391241203461, 0.009745788294821978, 0.011532047846620637, 0.033767298595713716, 0.018201009769524847, 0.046225313496376784, 0.0268186962764178, 0.04975860818688359, 0.011982946240875338, 0.0240079514748816, 0.039353348314762115, 0.03168494247698358, 0.05740742811134883, 0.04708471202424594, 0.01578079579797174, 0.025771226501092315, 0.052018268898661645, 0.035903781452881436, 0.02148645936644503, 0.028463665329452072, 0.04017263524500387, 0.024404716345348527, 0.024173407150166373, 0.07016576600394078, 0.076185307997678, 0.037745766541255374, 0.06855040482644524, 0.035894051260714016, 0.044658745772072246, 0.05402891065127083, 0.03556149446272424, 0.032836579252034426, 0.10466644221118518, 0.023595127376860807, 0.040769552678934166, 0.0103176279226318, 0.07113731958504234, 0.06445681662963969, 0.0229011980949768, 0.057878290702189715, 0.027561245985063057, 0.004930000502749213, 0.01880581008403429, 0.022217789498556937, 0.0065094616646612325, 0.0310790310613811, 0.06449388499770846, 0.020568203014720763, 0.04448634359453406, 0.029856246496949877, 0.030563286771731715, 0.03028813742899469, 0.053694677871784995, 0.025066717161930034, 0.007839916589935976, 0.027592031118859137, 0.06728737974273306, 0.012746259121091237, 0.02320340062890734, 0.09875525547457592, 0.03642973769456148, 0.010363293329386838, 0.028476187693221227, 0.008608605163837118, 0.030070775521120856, 0.044014303745435815, 0.06942893804184028, 0.09688796103000641, 0.03800618828141263, 0.03277432705674853, 0.04186986167249935, 0.0525437196317528, 0.010159398645295628, 0.04607108587931309, 0.035846329892852476, 0.048428455633776527, 0.03773378700550113, 0.01714376569725573, 0.059951228754861016, 0.04716652299144438, 0.06290728691965342, 0.07513127848505974, 0.051419122477195094, 0.09263921901583672, 0.09771920713995184, 0.04467611966122474, 0.030928626989147494, 0.04556609297703419, 0.009506933790232455, 0.011523019938197519, 0.006903358452421213, 0.06916006175535065, 0.006527413580832737, 0.08053969112890107, 0.15858880590115274, 0.2045104953327349, 0.11881973275116511, 0.22965498108948978, 0.11367537200983081, 0.07747460595731225, 0.15729433750467642, 0.21373721451631614, 0.16116210924727575, 0.08757227233478002, 0.10246602099921022, 0.140333621895739, 0.14553324931434222, 0.05304847165410008, 0.13616665692201682, 0.20765159678246292, 0.11746030141200338, 0.08648722698645932, 0.12947076479239122, 0.12997108937374183, 0.14942810817488603, 0.14407800883054733, 0.07937727921775409, 0.07425386485244546, 0.12410030939749309, 0.06043674770210471, 0.08807913799371038, 0.0947915795924408, 0.11958155115800244, 0.12088272348046303, 0.12692625847245964, 0.15529306632067474, 0.19145617367965834, 0.08713828812220267, 0.13230843895248004, 0.12886509086404527, 0.17697961548609392, 0.10586854163557291, 0.19301111809909344, 0.13916500817452157, 0.10910289415291377, 0.06900891129459653, 0.1230617572686502, 0.14464071792151245, 0.0871037303337029, 0.09418093878775835, 0.14252480146075996, 0.11004250230533735, 0.15787882756974014, 0.10527575987258128, 0.08910238915788275, 0.1227389917309795, 0.0952268462362034, 0.21487325855663844, 0.09842860871659857, 0.2169988373560565, 0.15041077615959303, 0.0887180126405188, 0.1497365701943636, 0.08728099082197462, 0.12176130419330937, 0.09652611187526158, 0.06582177124385323, 0.07682707320366587, 0.08786331636032887, 0.09895260059939963, 0.0565719140161361, 0.09720147135002272, 0.10074707466576781, 0.2015903927385807, 0.08304003838981901, 0.05853965199951615, 0.1563412807881832, 0.16910995276910917, 0.1446621867695025, 0.16322245369000093, 0.11230296029576234, 0.09339249466678926, 0.13865663616784982, 0.12367271019944123, 0.11496098552431379, 0.07236635684967041, 0.07369352384869542, 0.07377384203885283, 0.11920471995004586, 0.14043871339942726, 0.08838935063353606, 0.13020458684435912, 0.14142425837261335, 0.1454747867371355, 0.09510622306593827, 0.06927208110157933, 0.12109526778970446, 0.1529857079897608, 0.11111641289400202, 0.07531088670449597, 0.1334002832216876, 0.13015628872173174, 0.13618618515985353, 0.12961373212082045, 0.17656832826989038, 0.13571331410535745, 0.09444225619414023, 0.11385255785925047, 0.08786045972790037, 0.2279640989644187, 0.14528170281222888, 0.10151908466858522, 0.18241010765944207, 0.1179122193051236, 0.10767125311706748, 0.16358333932501928, 0.18780678164746079, 0.08933739297624145, 0.13957671608243669, 0.11447805858084134, 0.12624700420669147, 0.1760157836335046, 0.13894147159797804, 0.13328068463930062, 0.15471620298922062, 0.16591437852808408, 0.07662009288157735, 0.15614743690405572, 0.05376070611444967, 0.11877427090491567, 0.1087755620745676, 0.1320605565394674, 0.10927284681903464, 0.12257770395704679, 0.16394361427852086, 0.07541354905281748, 0.16435184808714048, 0.13933817031128065, 0.14277858712843486, 0.28129619147096363, 0.12228205267872129, 0.13760832670543874, 0.1387047307299716, 0.10833025989787919, 0.14042093578193868, 0.1601029025124652, 0.16222605215651648, 0.15644724081669534, 0.1317757075386388, 0.06309910198407513, 0.11798662745526858, 0.17418399692646094, 0.16238386583115372, 0.19393537778939518, 0.160474902551089, 0.0786486751000796, 0.13644687831401825, 0.12734142690896988, 0.0635473829294954, 0.15367632093174116, 0.17420709425849573, 0.1733626981398889, 0.09345490631780454, 0.1017497865749257, 0.1887330769428185, 0.12084765679069928, 0.15488316331590923, 0.11214309066001858, 0.22144975566438266, 0.23553977959922381, 0.11783766187727451, 0.14641067651765688, 0.13152591165687355, 0.08995550445147923, 0.09191697277128696, 0.1185228872512068, 0.07162982065762792, 0.1713684294372797, 0.12619911320507526], [0.024516871398580924, 0.02586148014026029, 0.03791618739653911, 0.02961127499916724, 0.014039367054855185, 0.028653241228312254, 0.02694140254919018, 0.09919954663408653, 0.03226249112880655, 0.06483442136751753, 0.018846437368275862, 0.02668194772143449, 0.06271959056279489, 0.054610279455248795, 0.03823097675506558, 0.04679988677214299, 0.031191756084029163, 0.039498442850474796, 0.04064326034858823, 0.06936811416276864, 0.04366371487932546, 0.06167605798691511, 0.01116659736726433, 0.04383502122280853, 0.07325396207826478, 0.011564114563433188, 0.04034940379538706, 0.0342820420462106, 0.004813337008402283, 0.0011488288063057034, 0.030810131026165824, 0.06608062556811742, 0.06630515280578818, 0.0022319616400636733, 0.04406138729037983, 0.0049696286441758275, 0.050851683997149975, 0.09986893500068358, 0.02683505745205496, 0.027703353270356144, 0.016229173434632163, 0.03996912223686065, 0.022502456991268054, 0.01437053200788796, 0.05018958309665322, 0.02443757949263922, 0.0038546073150687982, 0.05835745856165886, 0.019202517279024636, 0.032546386787933965, 0.09537081779646021, 0.03729309547426445, 0.042381918124322376, 0.024636091697694998, 0.05818225403449365, 0.012031959369778633, 0.05329804361930915, 0.04000905402270811, 0.08820404271994318, 0.03075884734945638, 0.012805542725670551, 0.0051075141693997595, 0.019616109817954044, 0.05031879652025444, 0.02261969257545258, 0.0639027724308627, 0.029911672629948174, 0.021106710457908254, 0.026026861176693013, 0.010326109610364904, 0.00937111652456224, 0.03031041712633201, 0.058634395844170024, 0.038419816443430524, 0.05546025652438402, 0.045323930614228757, 0.055723494184868674, 0.027619433755587255, 0.06946272908576898, 0.02529564469919673, 0.04026245631809745, 0.032584303324776034, 0.04578810963513596, 0.07176411630851881, 0.010603182599879801, 0.02614503144286573, 0.04602135944047144, 0.04428744123184255, 0.057583745435944626, 0.05157249853281038, 0.06267270379300628, 0.02043116438601698, 0.05515779953982149, 0.01627305429428816, 0.042706288397312164, 0.008071464968712201, 0.07685565988400153, 0.0192945571616292, 0.06764352920332126, 0.03409225580149463, 0.02458703700852181, 0.008948581742255815, 0.047345791943371296, 0.1017282430880836, 0.034801134906177006, 0.03985800194953169, 0.074340045585164, 0.07235176834676947, 0.08261013217270374, 0.0435635359691722, 0.01435340239134218, 0.023110207236771072, 0.021348608192056417, 0.015375891899956124, 0.040153449667351584, 0.022135880143780793, 0.035638372480337105, 0.030356567685625384, 0.07236554939299822, 0.051511779826666625, 0.057735418368663104, 0.024125707834692936, 0.019117579961727773, 0.019379886332899332, 0.03108091399605785, 0.058030051844460626, 0.02763884324979569, 0.009167461024065102, 0.03198752159784947, 0.058395409025251865, 0.035831361410341094, 0.05946944175021989, 0.031153283148471798, 0.03440548452947821, 0.036363594100943634, 0.02320204016619495, 0.04606052787442293, 0.02820965744155858, 0.014112330773579223, 0.028119193456534828, 0.08588032490972962, 0.03949778127883162, 0.010024708595925143, 0.010445036443083413, 0.04128744453191757, 0.034797022983964, 0.013529085820274693, 0.0547227839540158, 0.05690798223284738, 0.09203940084470169, 0.029372769940112318, 0.022376627761072347, 0.011311874259263277, 0.0351379020139575, 0.037587576279682774, 0.05719972175679036, 0.05084381299093366, 0.0849151766992041, 0.010377337307935315, 0.04787052342934268, 0.020817656236301576, 0.09235761341239725, 0.06483493026878152, 0.0351516559187855, 0.040976960478084426, 0.02476901331517313, 0.04085386744035142, 0.011718976610739316, 0.02609419051025595, 0.0159699306490698, 0.05885979160666466, 0.021006668951096277, 0.0236352169221001, 0.027587082902235643, 0.02567377021270139, 0.010350330766024334, 0.007211041852964887, 0.013359137394997691, 0.025060035288333893, 0.017997732552300607, 0.015494019757690174, 0.04375176497602037, 0.03121130807059152, 0.013304786740003951, 0.016145097856808985, 0.0617510157504252, 0.027439494750329425, 0.026597731347594942, 0.027677662238212566, 0.038445037590073686, 0.017067143826612403, 0.05538577712806208, 0.032968337181955576, 0.09586725437215396, 0.05971929191478661, 0.022055007251245633, 0.06065144296735525, 0.07453456800431013, 0.07321015585746084, 0.006869153926215533, 0.06072420906275511, 0.02594203412133668, 0.02741404120544238, 0.03241063907210316, 0.0033500968087797184, 0.09503559435584716, 0.0470162071287632, 0.04030006072883095, 0.02563085626544697, 0.025909671393622245, 0.042955022371773205, 0.043417528803859434, 0.04409793318648424, 0.026636692828365734, 0.004067680457540388, 0.03437720997525113, 0.047938244616878886, 0.03854120975094182, 0.027495597722008824, 0.018772979167156985, 0.010625104369994785, 0.02406681438774935, 0.04520568910187908, 0.05797281741563763, 0.05647979610200439, 0.0370454200144325, 0.05036898775558386, 0.005633718500445996, 0.03293424079726849, 0.024006786090987067, 0.073572744615376, 0.02140935234326337, 0.015403175793055977, 0.08348974425877843, 0.04168684381459441, 0.05139091577646988, 0.027296842940683876, 0.017458551663107107, 0.027944302751815746, 0.04165137339649456, 0.040052602400204966, 0.08321718352713756, 0.026439429127744267, 0.054008330684155226, 0.04628532652610114, 0.028347724050815617, 0.03036973805033735, 0.07477740211678402, 0.03652989285598908, 0.02053977409377694, 0.049062716242458136, 0.04210859404078551, 0.010555790321502303, 0.04972592315503529, 0.027736224899334565, 0.05718136738453593, 0.03711963478209717, 0.048577159975788424, 0.046131271935467205, 0.10427184017109019, 0.03970218656052436, 0.02165348924297307, 0.038338758650102785, 0.07354415114969015, 0.04009704983660153, 0.03543306813974466, 0.034839804616889784, 0.035703613622380156, 0.042162177951208184, 0.01911940352459039, 0.02103989850729704, 0.04124001832678914, 0.06063344821866069, 0.014897847015942847, 0.053316262284559865, 0.053520637032176764, 0.033974462122257264, 0.041983258444815874, 0.056657453533262014, 0.02776054529074047, 0.01100169469801975, 0.027281877850847583, 0.05339289942224111, 0.02683381234029574, 0.020996238171522106, 0.027777106634208133, 0.010533396969549358, 0.03036506294405886, 0.03477123865325536, 0.01661569412265505, 0.02403893508017063, 0.08221754538161413, 0.034776887457285605, 0.029758238898856298, 0.022536324370386343, 0.031305006971316676, 0.032579794459577115, 0.004433878597670368, 0.014539797657302447, 0.007270869981896664, 0.04782590975186654, 0.027730438691963042, 0.02262139060933675, 0.022084762708150914, 0.04527339332603982, 0.059054680434720855, 0.0251537104403334, 0.09227521211973258, 0.013033091140511845, 0.04779532817857606, 0.01797721704601177, 0.01938533836177417, 0.05116402045158403, 0.03350195747667125, 0.050833349980946095, 0.028056418789284568, 0.00549362349556759, 0.06114422223929848, 0.00994723177115832, 0.07428887047405754, 0.025388366509495035, 0.0498564461512225, 0.022812262510082552, 0.02996008949620383, 0.050419677714152, 0.10120504509125437, 0.026064999933753694, 0.0130035316105932, 0.014370123190539224, 0.07837293882455144, 0.037676715425082614, 0.037543742917478085, 0.024784595871876394, 0.013571146509743162, 0.02969450071187956, 0.014422935267378176, 0.07624234565134559, 0.0239748406623091, 0.08876812923699617, 0.04163102413128529, 0.05855703606669392, 0.013753843759851796, 0.047916300794375796, 0.03862940912534084, 0.018041464134252498, 0.00976998994259962, 0.036828424515468736, 0.0606654750715409, 0.01681674404868058, 0.015101253154820629, 0.059840885390128405, 0.031680749130568335, 0.06527655478566885, 0.14157475743974957, 0.14603707513638906, 0.06585173535027675, 0.0966188201148595, 0.09773048439196177, 0.09810973796993494, 0.13913272347833427, 0.10146199273211615, 0.17010453582874366, 0.14070511981844902, 0.1397885682859591, 0.21306162433964865, 0.11364684639764683, 0.07138103579304048, 0.08486159957413163, 0.18433611573917524, 0.22012742662004062, 0.143030527180859, 0.18051961410258496, 0.1834767104259559, 0.20550298850451196, 0.14140720000224455, 0.10467052699199744, 0.17814061604440212, 0.14046235355947698, 0.1083606311253139, 0.13709827193192073, 0.071619235511337, 0.1416269639240844, 0.0922713376847761, 0.17110241656856878, 0.12048561764614922, 0.10098185456757035, 0.14256772558603967, 0.09727089226778064, 0.12762087477105005, 0.15335747732647828, 0.10908103853996311, 0.1110492514978562, 0.1061928067356348, 0.08894747961312532, 0.1682170821087701, 0.09157305729708501, 0.1427369522196906, 0.10035564138420991, 0.14739445729979447, 0.17337734092559132, 0.10175267713410513, 0.12175237467246396, 0.16905896764780792, 0.09456126445106097, 0.12007802166044712, 0.15160503850451537, 0.17484737347279275, 0.08869750052690506, 0.13425630943051406, 0.13499781249889306, 0.16258525502468857, 0.09414819268775837, 0.11010566034487315, 0.04823678645438381, 0.06064879668078252, 0.08729799490954195, 0.2022518693868603, 0.13237314405185835, 0.2141037727040904, 0.1274215347532715, 0.23165720222251757, 0.13762147671410016, 0.17610711444701466, 0.17115422950259276, 0.08769231875027929, 0.09399524410920483, 0.1580650990030595, 0.12403565858091627, 0.15691737058971608, 0.12755939949836048, 0.12387344799935818, 0.11486923401909215, 0.16351161817354815, 0.17876623890229634, 0.1258841236787183, 0.22125691601208278, 0.053572874050587416, 0.07218454339142356, 0.09170326138181345, 0.1099414209436093, 0.12281832604535989, 0.10409035919500248, 0.10215154715946742, 0.11397470773330756, 0.112185750156641, 0.1070807987291898, 0.14811343300555432, 0.136788384988904, 0.18912843215678418, 0.11197188948946339, 0.1341082395187446, 0.14041679671832494, 0.10653901565819979, 0.10296952790979828, 0.10492413624056748, 0.12982417297150406, 0.06835207582584449, 0.10366738082042762, 0.1806514805981091, 0.14846712616937502, 0.17607074497001513, 0.15229299158922263, 0.07995869551918336, 0.1294544528105429, 0.09391584872667279, 0.16629533522895404, 0.09237577779484646, 0.1302992289087602, 0.10755871129887444, 0.12659138787005628, 0.11877794856471674, 0.20500472666961805, 0.1094942120835185, 0.11558677123061248, 0.16994715641651834, 0.14285275100597314, 0.13884164552603448, 0.10490441122757536, 0.09992336707987956, 0.04951664599190865, 0.17615883238613605, 0.2022692805954388, 0.07265071051993541, 0.23930524183171137, 0.1672256745930229, 0.13481071325285093, 0.10302921185003859, 0.1069348594173789, 0.16203121761126177, 0.1461368469255311, 0.1302942077496222, 0.18815758425210202, 0.11123795887189251, 0.1286479460873774, 0.07325961427497012, 0.12424550232078348, 0.090238066789295, 0.08957371993788651, 0.20469179988971778, 0.18040993570217065, 0.2735366278461048, 0.14812209111239227, 0.23409113447581018, 0.1348906989608492, 0.09500928755317416, 0.11427424023193972, 0.14066083862313203, 0.07059888169169426, 0.12778087332844734, 0.18303767112748964, 0.06290280858853034, 0.12676551352654183, 0.17924415825733117, 0.15002365836075374, 0.13495062717369624, 0.09143293981573411, 0.17931676150432654, 0.11786443686911038, 0.16053455934992858, 0.08787993368293558, 0.10479096017245736, 0.17495792039803096, 0.13492134160229138, 0.15499725219394478, 0.1342896662120308, 0.10416032294077532, 0.16568982414901257, 0.2130318773644311], [0.022158103861979077, 0.08958889198090349, 0.033270183485001326, 0.04927210197118776, 0.011121766558582229, 0.04387709039396473, 0.04216198117605277, 0.07639563349740845, 0.029153871150421243, 0.07404408896608011, 0.017885021100352918, 0.03980260635060923, 0.0362042672932148, 0.027692030217232447, 0.0853222773543426, 0.05013967006068144, 0.03798190351309521, 0.058372264195765765, 0.013603611017710395, 0.03782941294567926, 0.05485015854771648, 0.034723914228379726, 0.02431780788382249, 0.025885800531666194, 0.023747458488547375, 0.024918409762904048, 0.07621363004935638, 0.015727781856964742, 0.08437753947717802, 0.044406469844813855, 0.034753226941185336, 0.016471011796966195, 0.010868998693435319, 0.016173828725836108, 0.021309714564787488, 0.013620928079555077, 0.02001007233879396, 0.05625592365062662, 0.04002213957054274, 0.009971213743223675, 0.04529421078041196, 0.05945901945233345, 0.014190702416401888, 0.036032469011843204, 0.03004180546849966, 0.01708300458267331, 0.08393665456346103, 0.022048796959487454, 0.02218281101834561, 0.07798706953014646, 0.022594700434378216, 0.00970341802375125, 0.018365369610754505, 0.06479890684464149, 0.006730250174379242, 0.02037835570185312, 0.028408330798681294, 0.05836438640419926, 0.060581031388470104, 0.0029892673649426016, 0.012252962466196289, 0.018894998423222984, 0.025859765143000653, 0.03261395530509097, 0.011079091794921883, 0.02748701934303556, 0.018407569399901798, 0.06615544762462378, 0.0267296097174819, 0.02838113850780896, 0.040765769846205197, 0.053952297262315235, 0.010369501076638699, 0.040753515503768406, 0.018830980340551053, 0.01785326566148017, 0.022111529218299047, 0.014135168565969383, 0.0403377363857414, 0.02097958861850202, 0.038842706608452966, 0.04573255797315921, 0.02613363035821489, 0.0347835676345442, 0.019089670120073215, 0.03813016341466989, 0.057617936815534315, 0.046650951728224754, 0.02526025570529912, 0.0698002256186945, 0.013920832924278719, 0.02166034753567406, 0.01565479693402137, 0.04788418573194316, 0.037206032646021674, 0.003320998470631561, 0.018014984305149744, 0.025755742331966758, 0.02329467885595347, 0.026228063773097735, 0.041111110243946314, 0.03203711572236248, 0.0147426677535155, 0.04274188095171537, 0.06759578069405896, 0.011169540512907718, 0.02777467917517892, 0.035394839476794004, 0.062394565503512106, 0.06122663710266352, 0.030859962637935365, 0.014241722312622836, 0.040623253743563376, 0.038115707226097584, 0.05743944817887885, 0.012914445899826075, 0.059601091114538055, 0.03798021735357387, 0.04135960673115083, 0.014926759393087454, 0.07328335621527263, 0.005964590411167592, 0.020293228394751037, 0.02573040413803288, 0.027470435947179794, 0.02396187894711537, 0.039335088937410286, 0.018653210951015353, 0.063931236974895, 0.015401353926530905, 0.05228736570903233, 0.005155637993344239, 0.03047071084646242, 0.048783933344696245, 0.030775155938629593, 0.06621876851256404, 0.01718760754114815, 0.08232354612222739, 0.025550317551408495, 0.039946303104183505, 0.03267728637105652, 0.036151134608579535, 0.015920041361823678, 0.04919967853597232, 0.048382003126399856, 0.029978155491075346, 0.03786127355747989, 0.03350235102698207, 0.07456293755343982, 0.029667457698711326, 0.03906562911080463, 0.05707842683685677, 0.04032115977523582, 0.036381833122244904, 0.06012219922350986, 0.04274834739044309, 0.004937002135972891, 0.01870070500964565, 0.03060186148754188, 0.013681873246761305, 0.046862196642905474, 0.05377774412876793, 0.03167828944112573, 0.010958633169398775, 0.07954256356294666, 0.025894575685794865, 0.023574128414371183, 0.051339113020471165, 0.05988457625997918, 0.03060479275882244, 0.019331494911706874, 0.021469431530152048, 0.010705677010784191, 0.023362517090780393, 0.05530946568718978, 0.014134851350848163, 0.0307701313868165, 0.033651913715792556, 0.05711799221379416, 0.018068254393126284, 0.07153064597930227, 0.03272736564810787, 0.009267203127300101, 0.023832797837842788, 0.054951711491282494, 0.030243011457579475, 0.018321795788194453, 0.03847685070442302, 0.01754244403647525, 0.03599118354863354, 0.05054204132673996, 0.03644838722954903, 0.04128079828140991, 0.03537454788706132, 0.08886119710015399, 0.05138763505965471, 0.024397076041038548, 0.08458289810057197, 0.049456449757729254, 0.020518281497061253, 0.06135781827781882, 0.016607953734429817, 0.06529553341014044, 0.012770292831451764, 0.05594831997794764, 0.003851287158405674, 0.024636130713458573, 0.040468578293387375, 0.06224037520587444, 0.01578937248060746, 0.007017226382491312, 0.03580662202356117, 0.09465903456189803, 0.04961712006479502, 0.017554069037682245, 0.07672520474131618, 0.009719208381803972, 0.073853678469147, 0.03358981419088585, 0.03706727223470807, 0.030257359080548798, 0.050130774466586966, 0.013070673498857235, 0.010766818953145827, 0.022031004074960947, 0.04137873802600162, 0.025645366736820767, 0.0047100601618045145, 0.02782585089361029, 0.03947276708536914, 0.016111858122582947, 0.07263196938272033, 0.03313449005197201, 0.03819809155538678, 0.031136618328413794, 0.030675502893115793, 0.0660483476572803, 0.041692957415112426, 0.011080705860097493, 0.036991608794778585, 0.03161393717995711, 0.009097332733550241, 0.013054894166998565, 0.021092905662953854, 0.035189619953078885, 0.025616707113970603, 0.036659754280533106, 0.04206309826778514, 0.026052017862509404, 0.0380330650535013, 0.023204240315992917, 0.048246391117572784, 0.017845737315448265, 0.059904233419469426, 0.029194335586258342, 0.014637599998552884, 0.010660628222727349, 0.05298160542068737, 0.031989479171378274, 0.014344167529738374, 0.013911626052244433, 0.03897174022027424, 0.0997380455955863, 0.02299162306423698, 0.039381612690963914, 0.08303896630448954, 0.008126648525441331, 0.025575616729578803, 0.03010642235832555, 0.05715938284993172, 0.06837773123489958, 0.03880018960418446, 0.05201449624395796, 0.014665993296408227, 0.01613701311206179, 0.03466615054224219, 0.06129561697265931, 0.01703896257095039, 0.012973413985621716, 0.02388096534247909, 0.05232863760154162, 0.009266668780972915, 0.03189260133409074, 0.000482425516695782, 0.05253791815734335, 0.034686944247888665, 0.0434854705152767, 0.011565279099158943, 0.02874003942789776, 0.0387267687224916, 0.04022580185639007, 0.046144557651132345, 0.021367636010316864, 0.045355791226029396, 0.02033006606091346, 0.04541072202846408, 0.02474508817041559, 0.019612130210069672, 0.052015167993626425, 0.0915521787745612, 0.022813560208305717, 0.06242772550987346, 0.026090948809204356, 0.04765968902834824, 0.01396093179937452, 0.08966249945972647, 0.01656782517342695, 0.012242303529222096, 0.05208457873335906, 0.021611416679141775, 0.04951271048880049, 0.06349417899868318, 0.005863385216798633, 0.04002990201115608, 0.019406286434137394, 0.044184039280350716, 0.07107151525893382, 0.04365602368488908, 0.023927275357501845, 0.03201644415301936, 0.008785483127992069, 0.06806283670344523, 0.05136908730491996, 0.03221258148550987, 0.05498561110081417, 0.07320167416972773, 0.023995424022099802, 0.04007719250928078, 0.035586050645049126, 0.07349887929324593, 0.043910630379936526, 0.008866565518214234, 0.05225527100265026, 0.03802954684942961, 0.05597356487331646, 0.01852642498644335, 0.05431712179311684, 0.05185438233560749, 0.012254875086780106, 0.03022247220256499, 0.03757219389081001, 0.06634998361447028, 0.030589905700513294, 0.033976395947060416, 0.008971411901127015, 0.04139367936711226, 0.04169284884950944, 0.012504040779146765, 0.03752011972080384, 0.0767839862299817, 0.052512710581400564, 0.01611324063768344, 0.08270733231412512, 0.14533460140228271, 0.13255585996168, 0.06184391397982836, 0.10738364926406316, 0.135456597166402, 0.09696037428719656, 0.1254392082669905, 0.2132583452122552, 0.15040454720812185, 0.08408340133194413, 0.11760724495564188, 0.11365543665098292, 0.1306550255311387, 0.1639671865850687, 0.1548914685845375, 0.14329153246113233, 0.1530580941055502, 0.19012278451451234, 0.1376497716243778, 0.18090787184025559, 0.18820414532508167, 0.1645110324025154, 0.09240995560373579, 0.13277195979441914, 0.11232775396534375, 0.12518399767577648, 0.10885972077293055, 0.14253431452172144, 0.11986621016902582, 0.10631180142185517, 0.11758540969874177, 0.11446690346513476, 0.12828932675932134, 0.09573479076581341, 0.09960783472550766, 0.12469765091581003, 0.229620240096535, 0.14514580581869396, 0.1647447877164398, 0.10186907981655427, 0.20758716309709208, 0.10159248858690262, 0.14716332113104208, 0.06302072440407105, 0.1483524537512234, 0.20291850290128163, 0.0534805050784988, 0.07350020922188248, 0.1691784576645919, 0.16511798197669642, 0.11361086368560791, 0.09433569905481168, 0.17692708330495016, 0.06645943131297827, 0.1509758194110223, 0.14634807487683638, 0.18655603804758616, 0.13403426563101156, 0.11934799940458365, 0.12422287996326174, 0.09641234190868479, 0.06602189836225339, 0.1433548397783722, 0.06407763769051858, 0.053026497297521145, 0.06000401877931186, 0.13009413491402352, 0.1343467038656984, 0.15691694989800453, 0.1735047698020935, 0.12118905489998204, 0.10625599870192153, 0.08042087964713573, 0.13420444221368857, 0.08428456660892282, 0.10443823731371335, 0.14701318847281591, 0.122874291613698, 0.06188943010887929, 0.17316284243549618, 0.1373199221811124, 0.09327790367283992, 0.1390865830970662, 0.09948074511651482, 0.1597291382827929, 0.2227801049926451, 0.143609385405268, 0.12180870664971215, 0.12909006593482836, 0.15581920237413474, 0.07081886953009026, 0.13668802965964588, 0.22553392579512938, 0.1543828115931579, 0.15649272980434553, 0.15555948631039687, 0.11400499753654003, 0.08434659828032766, 0.17358943740172045, 0.22989534533449582, 0.13304981988455566, 0.15638702761914047, 0.0971380758232304, 0.15600090048142842, 0.07853227920298066, 0.07017307382609163, 0.123933878328119, 0.139640620510493, 0.1393461770245007, 0.09666613436170987, 0.11912211509687559, 0.09893161351127283, 0.1676716756607805, 0.11814490253371851, 0.1031042578231011, 0.11193221554692302, 0.12400108043636594, 0.0857835929574711, 0.09002675062843732, 0.17157388984092645, 0.07352021243423223, 0.15233820916286536, 0.1365950025085892, 0.04184939705633691, 0.17536698201937334, 0.23738162219524384, 0.15112867978002342, 0.12455410004726478, 0.19136757057692322, 0.12968751601874828, 0.1289802518274103, 0.13157286628016404, 0.09664019396794693, 0.09362854342907667, 0.18434735227908405, 0.088501234272761, 0.25092509974326405, 0.09758571216038295, 0.12362078869981424, 0.08812512231192418, 0.20892721547612123, 0.12312860653868743, 0.0814893144581999, 0.08984740025230817, 0.15488747879862785, 0.11199174342410904, 0.08953030726739339, 0.16104754539472715, 0.1358599862349885, 0.14589695765503816, 0.1798792534640857, 0.13572750905794756, 0.11639785127980368, 0.13618287390896253, 0.08540727743612868, 0.13869197427162103, 0.17477082115198883, 0.10876274454806532, 0.08391146055821862, 0.122005983921034, 0.09487871027418546, 0.10270961507090501, 0.12277724753533091, 0.24809273172702107, 0.0879711898575936, 0.11121161814246859, 0.08059491030871868, 0.18543758163494722, 0.10267023289842264, 0.18073058421058313, 0.11597977871341364, 0.16379255881266935, 0.09358065242746047, 0.25979604944586754, 0.09075878813330616], [0.08221067860722542, 0.031166297450129474, 0.03323709133214184, 0.00994826908156808, 0.017752883190821325, 0.020208114658349326, 0.018379432249015996, 0.021978307349075164, 0.0228159791856472, 0.06006506657493966, 0.0730991814551609, 0.0477854690647551, 0.04395606169211013, 0.054417724787656746, 0.055221700575202703, 0.05875284770237548, 0.00978209076648844, 0.022954800665112476, 0.020222282469538704, 0.0919061569230897, 0.07903919235936233, 0.010656090519790138, 0.049876836128532887, 0.01543763858665313, 0.03990407447729792, 0.04203041323593684, 0.0279910894376891, 0.021808300400152802, 0.03765450018857207, 0.0368412929320974, 0.05604991363361478, 0.0367798448008086, 0.033494561444967985, 0.029734303576073477, 0.011691557858804507, 0.029188018425234726, 0.016027110795091306, 0.09400147306067602, 0.027303645254245827, 0.05151135574227997, 0.0271711460248168, 0.03376371932349034, 0.03209555455084358, 0.02613062784075737, 0.012574973981827497, 0.0253440802251654, 0.009904703740695757, 0.03398532207523074, 0.012922830896319022, 0.0228532273654959, 0.01941341274817075, 0.005600574185206954, 0.011732984118030539, 0.05391603635091867, 0.021430785568164926, 0.032459995709359646, 0.04637816029467753, 0.07051407159971339, 0.035825319056000025, 0.03124241211584636, 0.05584568137835179, 0.052378672773816755, 0.06796926672437362, 0.01926248281129769, 0.02149200639022248, 0.05031389071206961, 0.027778948856783763, 0.051775631561343155, 0.07266692072153091, 0.04325113505391138, 0.00985812146349677, 0.06175862891333444, 0.036123240033962896, 0.006836448114232293, 0.07428534209196057, 0.06013651631240334, 0.04459060050014939, 0.06532759418977158, 0.054915012924798896, 0.054944905785045454, 0.07287544131811176, 0.030045177787542343, 0.023637372967121855, 0.02281026422445263, 0.02433203167415091, 0.018070737831294537, 0.021033745891015445, 0.032168510636048656, 0.0294859360105225, 0.030006124704544033, 0.07846509745078427, 0.0074908103228413635, 0.02923264228073614, 0.04676203130345259, 0.0403590220292764, 0.07078013196587563, 0.026308610968823944, 0.013734379982841867, 0.010646248369344642, 0.04265771546800222, 0.017121343507564495, 0.031508730325315676, 0.022885788564703295, 0.016423862094857862, 0.05629838637209364, 0.0628063412649291, 0.025200588728434274, 0.006810949192315872, 0.04796306203518595, 0.06750666190470968, 0.01767698735264795, 0.0504963352078838, 0.03596357395872474, 0.05005017129172172, 0.0372084787647639, 0.0649291245000703, 0.040567471379680295, 0.024549047529165233, 0.06007311400026083, 0.0404579252935946, 0.04589199334649103, 0.021418125801054493, 0.02234674847152616, 0.03455074530627046, 0.14752246971641267, 0.04358000062139971, 0.06832640006073884, 0.029022703545966318, 0.03192235170198338, 0.05066449993423053, 0.017649321783600107, 0.04720661084034613, 0.0339751983327525, 0.00809995919865157, 0.018393023305439522, 0.031862308138183186, 0.012836012340682958, 0.035357784679425616, 0.0058350860656771275, 0.021083321355815445, 0.022504372156358192, 0.009631403405884547, 0.03771112732855337, 0.04437740818996515, 0.037523556500673294, 0.03302513395569154, 0.033464213966258934, 0.05854501921151366, 0.020577595635716404, 0.012389146988945348, 0.03273796097242406, 0.022102477561150278, 0.05506616338555302, 0.07493401478443827, 0.012797583509901804, 0.03503480540322406, 0.025608176232448647, 0.014377948395641786, 0.049931607475238185, 0.005058480684445905, 0.017748837425772632, 0.06115865467914513, 0.016157959488087466, 0.027562107724536742, 0.025404880355511392, 0.029998277447053363, 0.029802296177617142, 0.08379433862864971, 0.02970503836071917, 0.031480805216623206, 0.029850346634962728, 0.06756627120609794, 0.007951305746766073, 0.03968953188242657, 0.08232800409729991, 0.03842573326879314, 0.050911415434841595, 0.013394660399561482, 0.06855970075620071, 0.027992958801665475, 0.08138844344232764, 0.040501280288611136, 0.00927651347592473, 0.010101497555816812, 0.05241491332916277, 0.02963101358285972, 0.04213220027408429, 0.01924467465973326, 0.03047643428934472, 0.06469529454729386, 0.025502630110297884, 0.0811718822057758, 0.027318050552691733, 0.05097869557461568, 0.07357199822685548, 0.03969905851408839, 0.03555489910234298, 0.01706900810157614, 0.051014573113726716, 0.04664998820849827, 0.046628034207969904, 0.037622554759894095, 0.03005562044147934, 0.054227884260139296, 0.05561139341443777, 0.034470556037766595, 0.044649239496460984, 0.03950134698035462, 0.04142823715561202, 0.06760067293154341, 0.007118973132622029, 0.05678581539541483, 0.032493315171450377, 0.04998399716402803, 0.059372166969946454, 0.01903173340750592, 0.031029969586857727, 0.01266685186419636, 0.013841105059587529, 0.02629162384463208, 0.020665140223822424, 0.03907103364222816, 0.05760079702096326, 0.06073819366948945, 0.01801596987726433, 0.021665802957223992, 0.02706254819141967, 0.04429487119029675, 0.01752431188443942, 0.07616940313684088, 0.03898890037089586, 0.05837128710533891, 0.009249584965540894, 0.05818415393254586, 0.006369020606923316, 0.05502894573978015, 0.028900987934321165, 0.09454069126929555, 0.042449337363775284, 0.017487974637853246, 0.024907999339380434, 0.06622684307928596, 0.0661223486864141, 0.03476402582600713, 0.04283509809257729, 0.031811723352542946, 0.029275413735636642, 0.03520694973745516, 0.05788971723190375, 0.022429899545386434, 0.05987390290413584, 0.023809936296726977, 0.03885756991803646, 0.022957421506622007, 0.03531253657170704, 0.01863645961774247, 0.06930566858500242, 0.04167526800717626, 0.05944019689091614, 0.01758530200459063, 0.054022362788340876, 0.023633858155725256, 0.00962063081429473, 0.03582946829763906, 0.03220647806301713, 0.039272270165383816, 0.018107522910993015, 0.017124449501612356, 0.04037766817158886, 0.040027279473309, 0.02505203027145139, 0.024734241788142493, 0.037195501782532246, 0.06146580712603671, 0.00417782280627372, 0.04053839276145611, 0.016953614739967243, 0.04969193533595119, 0.023905714907284294, 0.0505951366919492, 0.020925684100283042, 0.025274208081620078, 0.029005014138030152, 0.023611300259030292, 0.020091072456645112, 0.08551439097417252, 0.013601181014174861, 0.09339360067886965, 0.015536706395713347, 0.021242846635037234, 0.0502004396569516, 0.07621748412826232, 0.010816281611498977, 0.01847426769589739, 0.046253245390419445, 0.025771923695823977, 0.05872234755328723, 0.07611199228891305, 0.04660409888518708, 0.030727237795612643, 0.05341121647506952, 0.024655567349067757, 0.040037460891263824, 0.03276631695085338, 0.03473623303164329, 0.025468818710318634, 0.024404863926715085, 0.0530416320211121, 0.03488504933193326, 0.029367009177803993, 0.035816861116992574, 0.017717132877026285, 0.023122429348794476, 0.01946220450502421, 0.050920063363654275, 0.020137056774858917, 0.029853179518665587, 0.01249257438550038, 0.027288980416155288, 0.013686522907976593, 0.0023958880670501715, 0.03901882376521826, 0.06121678477419274, 0.01872687610531492, 0.00785174939249243, 0.025148144756842936, 0.03630968449371202, 0.0068127914148915026, 0.04477936215698719, 0.07232430803456477, 0.07376569283327886, 0.021297909751800553, 0.06463207543960639, 0.07004711058522974, 0.07387845178267785, 0.053418239312512536, 0.02228767690914018, 0.03253490258274334, 0.036935918033123016, 0.01961859834513494, 0.03871608179594789, 0.01683167690810348, 0.02628887408146901, 0.03713490182001676, 0.032057702474828274, 0.006406870986601072, 0.01975199324078858, 0.042914825957268476, 0.019536738184147646, 0.040564085489937236, 0.037130270818514485, 0.02285765650283013, 0.15358238454375947, 0.08928343587155853, 0.15105443447828293, 0.04950964690319129, 0.10922439941870314, 0.1451998172061784, 0.1532363723963499, 0.18073906589831623, 0.08929199898349387, 0.13694934706602777, 0.17997105925210885, 0.11046114484114306, 0.1433239664350237, 0.19985319381313665, 0.10492329485714436, 0.15180771691458567, 0.10585515413965497, 0.12359991696264062, 0.1637742519378662, 0.2013091535440513, 0.18284248374402523, 0.09499539115599223, 0.11965088386620794, 0.17498658171721868, 0.17069241856890066, 0.08762911321329218, 0.07783910818397999, 0.13637768131281647, 0.12894245742687158, 0.1447803739990507, 0.15401942894927093, 0.08961364493838378, 0.12833206089479582, 0.1377667374908924, 0.09307811582194907, 0.09754957338528973, 0.08935762689049755, 0.18981653451919556, 0.127405724887337, 0.16070194036832877, 0.16755487264267035, 0.1082877836057118, 0.08821143196629626, 0.12548738425331457, 0.10692720554236855, 0.08677804709545203, 0.1434910081859146, 0.1268708628735372, 0.15593577469033854, 0.0864064609631896, 0.08297797279166323, 0.17679951872144425, 0.1129374448210001, 0.19164583778807096, 0.11083079036325216, 0.17568258222724709, 0.13448524714580604, 0.12098250884030547, 0.1596651795719351, 0.0858816344823156, 0.15040700350488934, 0.17883007547685079, 0.15414195880293846, 0.09038155658968858, 0.08591655189437525, 0.2169568088970014, 0.17654764652252197, 0.1191257791859763, 0.2351466906922204, 0.09927956626883574, 0.11747281359774725, 0.14813733100891113, 0.14454580444310391, 0.09689854617629733, 0.1802584866860083, 0.1514787088547434, 0.14847339583294733, 0.19985066966286727, 0.09567206020333938, 0.14154239131936006, 0.19736785574683122, 0.12424293745841299, 0.2188617552497557, 0.12402322781937462, 0.04976944099845631, 0.14940137389515126, 0.10135748476854392, 0.15714587404259614, 0.11965163025472846, 0.13423437917871134, 0.1331618053040334, 0.19180488639644214, 0.13578290465687, 0.12178360085402216, 0.1449315787426063, 0.16901723774416105, 0.1172376876430852, 0.14201942857887062, 0.1040769445576838, 0.15027114722345555, 0.10723561327904463, 0.12312986861382212, 0.09600122432623591, 0.1048687067148941, 0.11973306802766663, 0.129489750202213, 0.12462458626500197, 0.07678446120449475, 0.10477127587156636, 0.14473164161401136, 0.1231093497148582, 0.1784750252429928, 0.1397795844823122, 0.08864057143884045, 0.11308238668633358, 0.19179914599018438, 0.11581722886434623, 0.1567893581730979, 0.19098535180091858, 0.10521968573864017, 0.1459040687020336, 0.267660026039396, 0.10596783166485173, 0.1167946449880089, 0.18889797452305043, 0.11894315827105727, 0.12271422520279884, 0.08910238915788275, 0.12420865786927086, 0.10735863846327577, 0.09612005616405181, 0.1936197911522218, 0.10151356817888361, 0.1289065493536847, 0.10222641671342508, 0.059715091783021174, 0.14208999622081006, 0.13713439713631356, 0.09663332719355822, 0.11122769942241055, 0.12265678042812006, 0.1181635893881321, 0.09629885692681585, 0.09704977806125369, 0.059340513311326504, 0.15843401849269867, 0.1428028651114021, 0.0980503186583519, 0.10338977857359818, 0.1095732885545918, 0.15930096911532537, 0.09455109999648162, 0.12406524270772934, 0.13962254433759622, 0.13068497606686183, 0.13522759159760817, 0.16650925017893314, 0.07198219067816224, 0.10252073806311403, 0.13692274849329675, 0.09797959495335817, 0.17727023203458103, 0.07143817522696086, 0.169880849974496, 0.1348419530051095, 0.12122287308531147, 0.14864292102200644, 0.10338148009032011, 0.22334718384913035, 0.06525841075927019, 0.13437521590718202, 0.18261981569230556, 0.07389914031539645, 0.0969866132363677, 0.1556792613118887, 0.11648448663098471], [0.0323804442637733, 0.06284961822841849, 0.025772486879889454, 0.05385958902271731, 0.042682339503828964, 0.045220477772610526, 0.028510592811341797, 0.005573010396411908, 0.01374244861238237, 0.04011434230155178, 0.04219797745879207, 0.023385985920737897, 0.03132228925824165, 0.04799689379121576, 0.00895895145367831, 0.029384413601032326, 0.03548826017816152, 0.015027606660234076, 0.022493564789848666, 0.017226652142458727, 0.012327637789504868, 0.0476678450192724, 0.016656913428700397, 0.06932198056685072, 0.023306872130238583, 0.03491074884576457, 0.05265717068687081, 0.02960755323458995, 0.05870499062751021, 0.01861178469178932, 0.02171333263894277, 0.01994394910122667, 0.035862099046685865, 0.07297305536589452, 0.011408228776417673, 0.060656165571085045, 0.02300759917125106, 0.017064704493220364, 0.024386663921177387, 0.02111059507089002, 0.014669662474521568, 0.06064878311008215, 0.04885826346331409, 0.007760478798965258, 0.005102387413249484, 0.019146248066265668, 0.03980057413822838, 0.03130696115217038, 0.021433671038331728, 0.044252808804490736, 0.0550146150801863, 0.016935932117381265, 0.09316256629037005, 0.05235232525904264, 0.02809997395213161, 0.02080646380116897, 0.006609391637279519, 0.004207144424851451, 0.008655437650824232, 0.06289900879242591, 0.002739501593168825, 0.03433130708123956, 0.0230430220918996, 0.09084133191832475, 0.00966453118183251, 0.021766621386632323, 0.01070301715351109, 0.05182647079761539, 0.03349402200962816, 0.032261863483914306, 0.031392521025346856, 0.04419635469093919, 0.01854751555116049, 0.007864462594235582, 0.0416462301010532, 0.0028054592257831246, 0.005327201756050012, 0.04813364573887416, 0.027972621410819035, 0.05118913303262421, 0.04557413022433009, 0.13521832280925342, 0.034605394516672404, 0.007346217903042478, 0.022114214520635347, 0.015125124016776681, 0.024211064147363816, 0.11643484500902039, 0.06319126061030797, 0.038717683138591905, 0.02060467766464821, 0.01207347129405077, 0.033196117995040755, 0.05145634012296796, 0.03956708006028618, 0.0168280789761671, 0.019867076172626445, 0.025345559431506053, 0.04210854654333421, 0.04648131797356265, 0.045615018744553835, 0.06536954800997462, 0.027761089815092937, 0.045022552500345876, 0.03682556788304022, 0.019179419946989844, 0.04630425426044634, 0.011544745781325867, 0.02832508133724332, 0.02101943049845951, 0.03264325444719621, 0.027700216742232442, 0.03151375826980386, 0.032119662900056155, 0.04550689758200731, 0.027547904290258884, 0.022152246408430592, 0.0022999809589236975, 0.0068343412629993895, 0.036889163577663045, 0.011915253042908651, 0.049289017849202664, 0.02539533336779901, 0.058357058225997856, 0.030780570648078407, 0.040855998040309975, 0.0452435852826706, 0.02939939226156899, 0.03658404673582741, 0.02258683112449944, 0.04814687717173781, 0.021219577972910235, 0.026848419502909695, 0.08402121359748499, 0.01272720076875495, 0.03458112671173044, 0.02091497851402632, 0.054249821297292194, 0.01963363977016083, 0.08564690207796437, 0.02222051890566945, 0.02810534286046667, 0.034295449898179085, 0.05706360763204949, 0.0368853739595839, 0.021200811390631964, 0.04776489927566477, 0.03349742486274668, 0.05758759951485055, 0.05014161406350987, 0.03737813966082675, 0.06164572747158153, 0.025344278696658354, 0.008633475168608129, 0.014767860062420368, 0.011505519671897804, 0.04307171343160527, 0.03743732148515327, 0.013292189737382745, 0.0401495277349438, 0.04161202854343823, 0.05151970511568444, 0.015654913981312087, 0.06177109360162701, 0.0026444428658578545, 0.062182177257324965, 0.05639671966699617, 0.052742761094123125, 0.008773697822886919, 0.007905523292720318, 0.07236908456044537, 0.02332821036023753, 0.04546926263719797, 0.005655696673784405, 0.005650476194984678, 0.035580306846116266, 0.054735347029886076, 0.04236134494255696, 0.06977455663893904, 0.009543174345578467, 0.031078206641333442, 0.056450921044285805, 0.01588283559041364, 0.01324885425024799, 0.02153120026923716, 0.03111017242606197, 0.026125986661229814, 0.016889625495033603, 0.05223671306989022, 0.044368495632495196, 0.013213678146712482, 0.0355215524988515, 0.05594709522223898, 0.029542814208460704, 0.07042413856834173, 0.04891814078603472, 0.044262718808438094, 0.09699316109929766, 0.017745646614847437, 0.033615059086254666, 0.015535174602908748, 0.05456435959786177, 0.06612468284687825, 0.018963520282081196, 0.026468979327806404, 0.062388709746301174, 0.006146018800791353, 0.028054622367822697, 0.07033763213881425, 0.03125382507486003, 0.03760196800742831, 0.09187818092427083, 0.07082611628408943, 0.011893737545636083, 0.00497510951078896, 0.06106921697833708, 0.010004294869889106, 0.045617318978267055, 0.027399196555571895, 0.03760885853054268, 0.03154570369848183, 0.04291627462953329, 0.05849131316478763, 0.025350066600367427, 0.019506818182500343, 0.01591910667983549, 0.044689049146005085, 0.040318639017641544, 0.07269043874527727, 0.0313583126823817, 0.024648698878341486, 0.019256148686898605, 0.016467396901654344, 0.00845850134334926, 0.003868611005600542, 0.014943356359643596, 0.06989431806973048, 0.026018331991508603, 0.01809132458376033, 0.1166684374745403, 0.01924269842649145, 0.11923429050615855, 0.004122847050894052, 0.05011355664048876, 0.014662322421957339, 0.04168048933414476, 0.024438378467623676, 0.04628539437960301, 0.030002453830093145, 0.02377962613744395, 0.0030985647255355226, 0.06914427224546671, 0.0462406178537224, 0.044318324753216336, 0.07768282121313469, 0.0526588330976665, 0.06253336662692682, 0.04678665194660425, 0.019237943592348268, 0.029857260906802754, 0.014525502620797073, 0.02046535406926913, 0.04536779111783419, 0.03317984672529357, 0.05873937199690512, 0.010584750196098216, 0.0426575729756483, 0.07342633711440222, 0.02653109242341348, 0.04351888497227004, 0.06069252826273441, 0.04654776690793889, 0.015544446783938577, 0.01725004463722663, 0.03109661190371428, 0.031400042586028576, 0.017742337060293982, 0.018934417915131365, 0.03451983125082084, 0.05178540585828679, 0.0372650075171675, 0.014151071730468954, 0.019118662225082517, 0.04447073728910514, 0.08271411766431161, 0.054655924505953274, 0.033041608785944324, 0.00917342449871025, 0.04668222201455917, 0.03575399824018989, 0.04866481652217252, 0.02937963671450104, 0.04044178294550095, 0.04159797608320202, 0.016104853944852948, 0.10386627300509385, 0.06165314385933535, 0.024077090800606778, 0.008569887955673039, 0.051437120618564744, 0.02232045863222863, 0.031474403238722255, 0.046337604256612916, 0.03555160142215235, 0.022463124012574553, 0.014468551480344363, 0.06085043693227427, 0.01230244039158736, 0.021887785688574826, 0.03332143323495984, 0.04559627082198858, 0.052442451672894616, 0.04630631022155285, 0.04298311372154525, 0.02145290411343532, 0.017260455060750246, 0.02634033078460821, 0.05509135399812034, 0.04598613329497831, 0.030676133930683136, 0.025580890643011247, 0.036911690940282176, 0.019746095075138977, 0.02931489090302161, 0.027358357229136994, 0.04517185395317418, 0.01940208630237196, 0.04545402952602931, 0.009164360967198653, 0.054034874974084754, 0.036426616433475695, 0.03973626937451107, 0.039163426363042424, 0.03623278612004859, 0.003922889990332935, 0.023471501689138155, 0.055991406951631816, 0.05776405254645007, 0.009667712662901198, 0.0507050797210208, 0.009782719259549464, 0.031603168829211166, 0.015433299355208874, 0.036259801991816075, 0.0380139337586505, 0.03346559139234679, 0.020756228461063335, 0.030302814141448055, 0.04205058268936617, 0.04208005146522607, 0.08398162107914686, 0.021418923079701405, 0.09839655472231762, 0.1560876172568117, 0.11578003157462392, 0.1525940711476973, 0.06575582442539078, 0.14199447206088475, 0.11459456304354326, 0.07023003684090716, 0.0980513228901795, 0.11237026418426208, 0.21902634070387908, 0.09132661337831191, 0.0957425803478275, 0.10502625576087407, 0.05892274608569486, 0.10724454958524023, 0.18505372080419744, 0.14361478654401644, 0.12050046399235725, 0.09911966949169125, 0.1456941571086645, 0.16899802163243294, 0.1155044242207493, 0.20091900947902883, 0.09023717112307038, 0.18979187655661786, 0.1959152344082083, 0.1479094653789486, 0.13774288019963674, 0.13388354943266936, 0.07281089906713792, 0.08382052329501935, 0.08894686214625835, 0.19725359044969082, 0.1348305129046951, 0.14971687910812242, 0.1673563468669142, 0.18998168994273457, 0.1403572756264891, 0.08116777706891298, 0.07710165596966233, 0.18797252061111586, 0.09218984562903643, 0.1525489349982568, 0.18440702264862402, 0.1379031908831426, 0.17824129707046918, 0.14149460888334683, 0.12932485262198107, 0.11510000377893448, 0.1265352458826133, 0.10485888152782406, 0.14644350404185907, 0.08233113892908607, 0.1429631622242076, 0.10932037819709096, 0.10345968125121933, 0.11659196657793862, 0.0997007940230625, 0.16072003011192593, 0.12027702241071633, 0.11842048274619238, 0.10848341882228851, 0.11573987587222032, 0.12108514404722623, 0.1658860021936042, 0.08543824577437979, 0.08750749938189983, 0.06994137447327375, 0.1127565134582775, 0.07567572819867305, 0.10836486518383026, 0.1041696731533323, 0.06098171988768237, 0.10897076981408255, 0.13802103884518147, 0.09886698305074658, 0.1101953558889883, 0.1769085864403418, 0.09908361214080028, 0.19629578398806707, 0.2765408009290695, 0.09272710965680224, 0.10175878394927297, 0.084133063309959, 0.10352209290223462, 0.19326212177319185, 0.12065816910139152, 0.21660311573318072, 0.13751676519002232, 0.09176059080553906, 0.14611948999975408, 0.15334814068462166, 0.10394857251750571, 0.12375915556081704, 0.12559224505509647, 0.1086425624255623, 0.10104328234280859, 0.09680930525064468, 0.15509551763534546, 0.16260685957968235, 0.21476904914847442, 0.12497532101614134, 0.18688636246536458, 0.09953607286193542, 0.12871710237647804, 0.13218840610768112, 0.12742202329848493, 0.12054850427167756, 0.11121379623987845, 0.09695213008671999, 0.06967661010899714, 0.09992142646972622, 0.19782873030219758, 0.12837532428758486, 0.09959169237741403, 0.08313585431980235, 0.11371365495558296, 0.11637639600251402, 0.11741182687027113, 0.14686396505151475, 0.14827514147119863, 0.14314310971115315, 0.17180883937648364, 0.1227767454194171, 0.16022662658776554, 0.11604708938726357, 0.14506784214505128, 0.056590068220560036, 0.11055031112794365, 0.15774858955826077, 0.0719274871849588, 0.09394993832600967, 0.09098073015255587, 0.07124185469001532, 0.11468197192464556, 0.11439548086907182, 0.1319641095719167, 0.07315004444015877, 0.16612032747694425, 0.09681033662387303, 0.13222169503569603, 0.1244495649422918, 0.15224873753530638, 0.08541872432189328, 0.13717951971505368, 0.09343225681888205, 0.14691817999950477, 0.13380141955401215, 0.1738910733589104, 0.10033955331891775, 0.16001242665307863, 0.1022722449685846, 0.12750757299363613, 0.08632038201072387, 0.1307008130741971, 0.1756500939705542, 0.10055205013070788, 0.11007794218936137, 0.09865335987082549, 0.23231622257402965, 0.1242940854281187, 0.11315338180533477, 0.13653877909694398, 0.17373515958232538, 0.09270720822470528, 0.08689616647149835, 0.14429953694343567, 0.061291057217333994, 0.15042889304459095, 0.14604088850319386, 0.08045338147452899, 0.1824842986783811, 0.11210799682885408, 0.2123393780950989, 0.16745942990694726], [0.04942494537681341, 0.03662768332287669, 0.016005770868754814, 0.03592794069222041, 0.013597476212973041, 0.060554242825933864, 0.04406894617048757, 0.07322539575397968, 0.03547871997579932, 0.08653564724539008, 0.008249204672340835, 0.01974772016650864, 0.06871693089072194, 0.04106074258951204, 0.02598779452299433, 0.006985707158621932, 0.030667940620332956, 0.023181073434118713, 0.05368522248630013, 0.028199990013880388, 0.007789995072276464, 0.024173408846503923, 0.05325842395957027, 0.07605805554028068, 0.028567694925836155, 0.01750917376817337, 0.047201630393309255, 0.04318894731945225, 0.051218971610069275, 0.06941154040396214, 0.014035138085351458, 0.0379971162682133, 0.02415137511811086, 0.031200203845011334, 0.014664561587518879, 0.023069892078638077, 0.06738243571349553, 0.03964767984247633, 0.055850353091955185, 0.021236425997423272, 0.04728027938732079, 0.040497819760016034, 0.04091366333886981, 0.014605374674179723, 0.01613705212782536, 0.03395611792802811, 0.0164106408400195, 0.013506296373504614, 0.014666169715513076, 0.012833504305620278, 0.050062880252621005, 0.06242647022008896, 0.020543545052143078, 0.07082877614136253, 0.035104918426701, 0.050039623464856825, 0.028187150434990014, 0.005835588181590927, 0.04020949326721685, 0.014523249884535159, 0.03217895668266075, 0.06931719689496926, 0.019234610289069157, 0.028063986151080047, 0.02454672015405127, 0.035429258165614944, 0.004599103571048805, 0.012425429104561252, 0.02012313323627625, 0.0278973091127617, 0.063868180715612, 0.04027852742001414, 0.07426664166684661, 0.014803220218579684, 0.01053740456700325, 0.030456203767763715, 0.025857169746554325, 0.007202536416506129, 0.03927555088219898, 0.025443204013364654, 0.018045911931299737, 0.010502888338773378, 0.019060426957107017, 0.02375591133854219, 0.05345554516783782, 0.025700925184147697, 0.03271017496341041, 0.02769609973100679, 0.07768100273928472, 0.016829447920567224, 0.047191323446375985, 0.01510245755447873, 0.010691303942751671, 0.09869747821773801, 0.04120787273028067, 0.04004207832206573, 0.06005809802029814, 0.06980708560773305, 0.014227346700083996, 0.0161758151371032, 0.04409861172150288, 0.040964665423546515, 0.02579732974325972, 0.04150220765066998, 0.017585134067173516, 0.03793146461248398, 0.014540058893284627, 0.03261409779744489, 0.02137493365444243, 0.01860793909457113, 0.048329752537288835, 0.03235158616943019, 0.01944064744748175, 0.02511973788828722, 0.02039020461961627, 0.04105681047907897, 0.0363217386683183, 0.05615726465891514, 0.06129923356430871, 0.0676653441041708, 0.0031705051286345614, 0.024676211777010133, 0.04612735678840961, 0.03397917454796178, 0.01007235617310341, 0.02586086267339332, 0.00964414544536599, 0.02623984992637166, 0.060044384827571254, 0.03924563427322677, 0.02507396730860429, 0.04112148165170636, 0.03505773988685437, 0.02487508699830089, 0.019195323111489415, 0.018258478292929273, 0.027661906655079553, 0.0352476448751986, 0.010989442900089281, 0.028928448246525865, 0.01866813193607543, 0.02695769247865038, 0.051668684264378886, 0.05865910130419901, 0.015113534638658166, 0.036602618239287815, 0.009373389616874712, 0.01028029153323067, 0.009203514982280987, 0.003385447635082528, 0.04726540589971202, 0.025581433471026163, 0.08104114886373281, 0.01988568329917533, 0.029036705116076127, 0.051544278261384795, 0.06187012578759875, 0.03719955263659358, 0.04601728483768446, 0.024980958817260604, 0.05998827676687922, 0.032681360973843505, 0.05101768419678722, 0.033432468705411465, 0.04589047342804926, 0.021177345953349556, 0.06699978267507893, 0.034953849390149117, 0.07012968151164906, 0.04364409843193633, 0.027275877904945185, 0.06454354019037314, 0.03720469253935984, 0.033373239383633645, 0.07344268302300147, 0.043955936163131676, 0.0037379162552367362, 0.020388664345123937, 0.016807687302519168, 0.01324841913966728, 0.007489281922711858, 0.07912926788308791, 0.054508156542267115, 0.031133877046938454, 0.040944652033171484, 0.0752709142065474, 0.06803235691040754, 0.019453096868736402, 0.04663152187796576, 0.02069948936280395, 0.011423040347705995, 0.017396937290738736, 0.057848190888762474, 0.035798829048871994, 0.055337763990142515, 0.03223945825759854, 0.011158159784307438, 0.011580792954191566, 0.01077363992642079, 0.017393352929502726, 0.015843075134658387, 0.038279322375144274, 0.028474962937512567, 0.0532842625730804, 0.022603607902835523, 0.06434002039687974, 0.006162604317069054, 0.033973773409213336, 0.07014625812215464, 0.03200389125517436, 0.04001374948503716, 0.04629708893064942, 0.009580899196277772, 0.03612595417403749, 0.05180592814992581, 0.04997935937717557, 0.04882495078657355, 0.03026949128668223, 0.027798410937456147, 0.05486628732510975, 0.023695469135418534, 0.029353699713413204, 0.021641720053074614, 0.010034047782288065, 0.023751606033848863, 0.05642157101205417, 0.08467727553631578, 0.04793209369693484, 0.08007084378706557, 0.06097320427319833, 0.04731201447014298, 0.03627970003123794, 0.1053861982322165, 0.03482683781268341, 0.013896574449193264, 0.017639311695737497, 0.02939015400729009, 0.042260019308222194, 0.01979938382282853, 0.01997323297629399, 0.03512701152690819, 0.05211917044860976, 0.01787194742688111, 0.033293474199516435, 0.05327125505677291, 0.010217740782536566, 0.033934825499142916, 0.04598482711506741, 0.07994763539837939, 0.02656228807089584, 0.015881887337725078, 0.041546152971152744, 0.016647120472043753, 0.059810168109834194, 0.07131179807973759, 0.03578751787011113, 0.021141916247350828, 0.028747455815651586, 0.03224293574956911, 0.04232771335435765, 0.0356919937101858, 0.02808161109818944, 0.025492543687245676, 0.03150188729965261, 0.0591210275888443, 0.017323365435004234, 0.0340888563410512, 0.052799500192382505, 0.038842218063239536, 0.07543387796197619, 0.03092752436974219, 0.05319725742031421, 0.0399501198636634, 0.1077845481091312, 0.05104438454977103, 0.04743331278275166, 0.02058932920252638, 0.021384568851707236, 0.023765607603958676, 0.03642056390110936, 0.03233634288023625, 0.03469372620540006, 0.00477616219515247, 0.01466679566406778, 0.022176463323246156, 0.09637771626668316, 0.05087602983361908, 0.07106632446604115, 0.08301071210631303, 0.04747102915176323, 0.04674169221626861, 0.042374413527016125, 0.021625085767092447, 0.014378206238948872, 0.001261610656261577, 0.004501174852651144, 0.020281303141798292, 0.044818096328526735, 0.02809473735812519, 0.033707061649433205, 0.03280959052166768, 0.012816797077123607, 0.029705516727907316, 0.02345003793016076, 0.014951237543885196, 0.05661326054749744, 0.034626072871365716, 0.03017667108880622, 0.04602060287392565, 0.06224334718925612, 0.03859081744615521, 0.045663842731820684, 0.03430738193648202, 0.013767406826705804, 0.06506339979491063, 0.05293728012059416, 0.02618427451566926, 0.03771449964759605, 0.03762237494811416, 0.04993293061852455, 0.04492457204365304, 0.05101949927796211, 0.06424672183181558, 0.07341894786804914, 0.055032080571566305, 0.02069928919497345, 0.0316051603294909, 0.019597029413229654, 0.061282643383102756, 0.05181676096149853, 0.009110743978193827, 0.02255837506215487, 0.05263118618833167, 0.06687428762337991, 0.0587776345866067, 0.01955253447938178, 0.03297437953629664, 0.023708693782931993, 0.0245096297335944, 0.027362659141155224, 0.013999054441228509, 0.05880306607910565, 0.03118483841951404, 0.048072329921914, 0.026867474462570887, 0.03244780243507453, 0.011637001098798854, 0.022428260883316398, 0.011023650394885667, 0.008297880230072354, 0.023401008686050773, 0.03308859394331064, 0.12841889980648244, 0.12630780094436236, 0.045093751179852655, 0.14266485108860902, 0.06184257048049143, 0.1703768726438284, 0.14842236999954495, 0.1552250771118062, 0.131633920861142, 0.17411633341440133, 0.1128243805308427, 0.15319650167865412, 0.10763601679354906, 0.08388534374535084, 0.12253042363694736, 0.1283338793686458, 0.1004313048241394, 0.1612847883786474, 0.17531801893242768, 0.06939192395657301, 0.09250379021146468, 0.12867758449699196, 0.11760416440665722, 0.1967462498162474, 0.08734789437481336, 0.09980297461152077, 0.1232647206634283, 0.14854764113468782, 0.09245278473411288, 0.2626346599842821, 0.09433971598212208, 0.09763050904231411, 0.18110437558165618, 0.1463786225233759, 0.09427990312022821, 0.17173394268112524, 0.10696030448057822, 0.1083841695051108, 0.16602899666343415, 0.11359388673944132, 0.15358265595776693, 0.07356595926518951, 0.11819288853023734, 0.1031290650633829, 0.11358759671981845, 0.10556311266762869, 0.12919308112135955, 0.061108287024710856, 0.06376858534557478, 0.14225349601890358, 0.1681730587567602, 0.1468538548797369, 0.11161100385444504, 0.13239393436482974, 0.21442446192460402, 0.11946588807872363, 0.17318883032671042, 0.08211837070328848, 0.08681312735591616, 0.17164661522422517, 0.0880836977490357, 0.1441937940461295, 0.07770192875925984, 0.08175796004278318, 0.10262268794966595, 0.14035602712205478, 0.09331244110528912, 0.07837659612830196, 0.10610972012260131, 0.11835936031171254, 0.15619204379618168, 0.15934959293476172, 0.13277466036379337, 0.10477215118174042, 0.08695455440985304, 0.10569151184920754, 0.20039245273385728, 0.1588812002113887, 0.12776092439889908, 0.12169520131179265, 0.21481315392468656, 0.09292354554470096, 0.12070934421249799, 0.0881938443386129, 0.11783426920218126, 0.0981319939185466, 0.07740401117397205, 0.10643122358513729, 0.19403434890721524, 0.21806054109973566, 0.11912866974515574, 0.16022020764648914, 0.09098033660224505, 0.20571475928383215, 0.11703095159360341, 0.19432872453970568, 0.25381726026535034, 0.17623899451323918, 0.09753235216651644, 0.20340217623327458, 0.1567715669849089, 0.10295652039349079, 0.17881973460316658, 0.13768086209893227, 0.1787485291383096, 0.06447827869227954, 0.09466465283185244, 0.08152221662125417, 0.09647986971374069, 0.13793324998446874, 0.1165998647255557, 0.1281992308795452, 0.0849106033731784, 0.10848885388778788, 0.12689263027693543, 0.14826204574533872, 0.15645116274910315, 0.09411978921187775, 0.10089496815843241, 0.15305384647633347, 0.11960812258933272, 0.07946329710206815, 0.11940496920474938, 0.08279962664736168, 0.13690442804779324, 0.1107664584581341, 0.10614425755505051, 0.18526572228542396, 0.1131370494674359, 0.1108230414933392, 0.0895784425416163, 0.07698141277900764, 0.15290249245507376, 0.12653242317693575, 0.1299488198544298, 0.07601317044879709, 0.0826172771464501, 0.07442949007132224, 0.09956930072179862, 0.08204037988824503, 0.16259198609207356, 0.09913692463721548, 0.08978918194770813, 0.15375394533787454, 0.11996698618999549, 0.17172409035265446, 0.12236180768481322, 0.1089606053595032, 0.1252523668642555, 0.08617583369570118, 0.17354941740632057, 0.13624068509255136, 0.15323293900915555, 0.10614505822637252, 0.13424226375562803, 0.13873986527323723, 0.20372942010206835, 0.15237860913787568, 0.182466683909297, 0.11252086503165108, 0.17082349796380314, 0.09577593712934426, 0.11872632562049798, 0.1445589680224657, 0.10292302111962012, 0.14004039977278027, 0.12679025291332177, 0.11580208396272999, 0.18930791823991708, 0.12466813464249883, 0.0912419186372842, 0.13824348976569517, 0.0954589323539819, 0.12457689882389136, 0.1444017786000456, 0.1589283041123833], [0.023658560223079154, 0.039999995580209155, 0.007232523423486522, 0.058140388423843045, 0.014741860296843308, 0.07220057038856403, 0.02957198103623731, 0.01979923963413707, 0.07787255317504917, 0.0036852513356799526, 0.01529409789613315, 0.027392455310161625, 0.013352871972269245, 0.045737348430390866, 0.040154833878789625, 0.0173493618079062, 0.04290094313078693, 0.02208154136314988, 0.041491361268396885, 0.0950645406597427, 0.007323426759934851, 0.07197860801326376, 0.049414193989442926, 0.08056297166539089, 0.007272948843560049, 0.03342333223138537, 0.019370492015566145, 0.0805228091776371, 0.067071537753301, 0.021513997710176876, 0.09677450997488839, 0.009618867471415018, 0.054045293879296095, 0.03018800601629274, 0.08157625515013933, 0.08479411926652704, 0.025176042724134665, 0.01661587563077254, 0.06268094799348287, 0.02964061824604869, 0.021685337980410883, 0.039466867223381996, 0.026874763625008718, 0.03809152084535786, 0.03177827836147376, 0.03238946199417114, 0.04453801742887922, 0.015400236040087683, 0.042052923635180504, 0.03577259009970086, 0.028744721319526434, 0.023985276530895914, 0.0622979285461562, 0.04825467603015048, 0.018579902027600577, 0.037246032285370996, 0.014981456100940704, 0.02948567138186523, 0.05218466264860971, 0.027147071602355157, 0.05346003367698618, 0.01605709525756538, 0.04114758828654885, 0.01056182334598686, 0.011755608171889824, 0.04907808845330562, 0.000963042419503576, 0.062234689082418165, 0.020581420876884034, 0.00042501570247363167, 0.045186707084732394, 0.058169104025832245, 0.024459129764831493, 0.05593420984223485, 0.07431871244417769, 0.020054356926786046, 0.012216311397163995, 0.07135499361902475, 0.025067460157775452, 0.024661977808656435, 0.05380423752857106, 0.045324378447341065, 0.04921320513156908, 0.07078553310462407, 0.05128003636907254, 0.0324170919401305, 0.014265720399894884, 0.05804116624806609, 0.005556137350920055, 0.025342480578858937, 0.01455979747697711, 0.02182844780119402, 0.09836885013750621, 0.022557350474276712, 0.018223370891064405, 0.05341269228873508, 0.04351010472912874, 0.017266275194872702, 0.02659742600683655, 0.060704280489257405, 0.017393519170582294, 0.04121736204251647, 0.006358145386911929, 0.014399946500946368, 0.012797854075740491, 0.008256123185024729, 0.08331787133855478, 0.015033075652484382, 0.056884077444140396, 0.018311151270089403, 0.010435469947489244, 0.023834349986697947, 0.0266785533500037, 0.040725790562906435, 0.034090885160756965, 0.049408938735723495, 0.03399873671254941, 0.008542907706994032, 0.01710454298050276, 0.019140913084681545, 0.060561713496489186, 0.03135747129895857, 0.03759332007861563, 0.007118175853975117, 0.024285947272021855, 0.05112298604633127, 0.0213831303574677, 0.06260618021977798, 0.03785590973815747, 0.023997379899291054, 0.007760756998322904, 0.045552254255328856, 0.08960396902901785, 0.049474508967250586, 0.05067711050755211, 0.011850542854517698, 0.0066787171360504416, 0.021089787794543163, 0.012983247654379478, 0.03593646987740483, 0.01325068629479834, 0.034177252490605624, 0.0617786796231355, 0.04617797889347587, 0.02938089200428554, 0.04371994846899595, 0.035945870980088196, 0.027652953385508487, 0.047601932127560885, 0.05853171313979796, 0.014171650849415787, 0.017914786735283475, 0.09240649507514068, 0.04059035158050912, 0.022759547124483755, 0.057027468856956275, 0.019262610036613684, 0.03152207710913249, 0.027253725432923863, 0.03896539252517479, 0.015638846272070493, 0.05109695405034082, 0.05541078792884946, 0.033022623376122544, 0.019271715976563946, 0.03433383462418403, 0.023183312599680254, 0.051784086107675514, 0.0118013804479103, 0.024829002596171837, 0.02001621647338782, 0.02182776078448764, 0.032779463566839695, 0.044178987587136884, 0.041956921108067036, 0.035617086836802106, 0.05120638817814844, 0.05231350627062576, 0.009156851280879761, 0.06491028158260242, 0.007442356137159679, 0.04074669622683099, 0.035845315482999594, 0.007697364864205676, 0.07967555642660175, 0.020952014651681696, 0.00721910284898643, 0.04989468499219843, 0.009302914425331568, 0.03384188995031374, 0.05548175929912499, 0.05245849224073546, 0.04067867648388658, 0.053039219829120805, 0.036402430052735975, 0.020663788242797767, 0.01140299642325512, 0.01630347132283662, 0.03080780365105186, 0.08121218040053334, 0.013188384905723589, 0.035399290666516335, 0.011947089905983635, 0.029868673865816424, 0.011403945524112453, 0.05534529233617442, 0.0691766587219068, 0.030755349501435245, 0.03792350200404014, 0.004531307320576161, 0.057278323253350596, 0.01929349186164992, 0.006093599426094443, 0.012553221845467175, 0.034316216462424824, 0.05357972386160067, 0.03178397127028022, 0.042505720231149874, 0.04309220179649336, 0.03820342144795826, 0.08549789578786918, 0.03116225338141833, 0.0711096285709313, 0.03626924041392548, 0.09875880421272346, 0.07914433814585209, 0.03753246566546815, 0.005161677379094596, 0.04638193294938121, 0.06274535453745297, 0.021927785327924148, 0.040542603071246824, 0.020160875050351024, 0.021151768575821604, 0.04532921979469912, 0.051109113397875, 0.08179793932608195, 0.006178513842834426, 0.008805035114554422, 0.0290341097196298, 0.023910885344126394, 0.015831840291087116, 0.03323090648544686, 0.01873916946351528, 0.029906590402658497, 0.029365692819867815, 0.019635173259302974, 0.02820068211959941, 0.049369112122803926, 0.03513354242646268, 0.08692983537912369, 0.021662495099008083, 0.03185247277308788, 0.015860255641330565, 0.0721676546548094, 0.059907429319407256, 0.010067653077255403, 0.07535717636346817, 0.05351679991664631, 0.04711545305326581, 0.0767926171954189, 0.036889631766825914, 0.090178321780903, 0.05719016119837761, 0.040069379178541045, 0.06368490162172488, 0.023459630718986903, 0.0402188061603478, 0.06919174255537135, 0.010177357770901705, 0.0098867217145328, 0.034822237345256975, 0.06555803825280496, 0.04666047835988658, 0.023864141066691706, 0.023559339743639742, 0.07674726391477243, 0.06782060648713793, 0.01874762909886028, 0.028667965438216925, 0.03606263667877231, 0.020906015066429973, 0.03127836090113435, 0.0207071466304894, 0.020435403533545986, 0.020119979744777083, 0.03950259887746402, 0.01237641173481409, 0.03388054269765105, 0.05017706751823425, 0.07099507150373288, 0.014031295032639588, 0.016571129638967768, 0.08397845232060977, 0.026604706687586646, 0.019101320566343408, 0.02450110394108508, 0.0342103989262666, 0.025767560715654066, 0.0501224217005074, 0.025931883237457702, 0.03429278664823089, 0.025836472732148, 0.044302871118166616, 0.012975578512331205, 0.028895413769142966, 0.03872433617444975, 0.02516657207161188, 0.022215787820251923, 0.06202955437558038, 0.050877410652382035, 0.04735051454710109, 0.05902223289012909, 0.009361763767498945, 0.03978806873783469, 0.03293801684464727, 0.04622126942766564, 0.006331183797945934, 0.01712792190457029, 0.08299678856773035, 0.045192230359784195, 0.042613743006118705, 0.021214602614885995, 0.05130140343680978, 0.030773924397570745, 0.018400305682527165, 0.0806390829384327, 0.06506565253117255, 0.07817473874560424, 0.035126353347940106, 0.030774884524622133, 0.03631251059206469, 0.004055165303205805, 0.028210851663191403, 0.06730410563094275, 0.038237005538706265, 0.025534100564462796, 0.03370525335360851, 0.04477906360157898, 0.03848418227529951, 0.021669584093615413, 0.07601714666400637, 0.07241857690470559, 0.043356582788484435, 0.016427460026794245, 0.026073050751749958, 0.049980936971093924, 0.03771430626511574, 0.01773758901150099, 0.02634734514036349, 0.0654917046693819, 0.026185931837452308, 0.12582400547606604, 0.09353772151683058, 0.09673221688717604, 0.16895177268556186, 0.11990491380648953, 0.1139615848660469, 0.1571739518216678, 0.06973554766071693, 0.1458008906670979, 0.08858811389654875, 0.0837128126461591, 0.16450590267777443, 0.17176774729575428, 0.14960535509245737, 0.12721977915082658, 0.18332326651683875, 0.08793249300548009, 0.11639224658054964, 0.21630080124097212, 0.17110490000673703, 0.10788426561547176, 0.12178923269467694, 0.07785527767347437, 0.1609865722379514, 0.08715467474290303, 0.10914672072976828, 0.1327103352440255, 0.17851116401808603, 0.13778668642044067, 0.1317362439419542, 0.1995983767722334, 0.0881202504304903, 0.08811407576182059, 0.06897180899977684, 0.11381626980645315, 0.21072944519775255, 0.10352644909705434, 0.06800803821533918, 0.08111261895724706, 0.16951701949749673, 0.09840994221823555, 0.16304713381188257, 0.11077989345150334, 0.1440956507410322, 0.14942749749336923, 0.14290174123431953, 0.20970694720745087, 0.10297746676951647, 0.17753028736582824, 0.15752792997019632, 0.16899943298527173, 0.12078946562749998, 0.22234794603926794, 0.16168371268681117, 0.08817222621291876, 0.1346544059259551, 0.0981302365128483, 0.1801440178283623, 0.130415692659361, 0.1465491248028619, 0.24567701135362896, 0.06548153342945234, 0.12772216647863388, 0.10439472286296742, 0.09197303333452769, 0.12558152420180185, 0.07224830532712595, 0.09666912670114211, 0.09335102260644947, 0.09821100253611803, 0.08137391600757837, 0.16289697401225567, 0.19882323193762982, 0.13363303430378437, 0.2654120938054153, 0.11971298339111464, 0.10609351670635597, 0.1219573329601969, 0.12911344825157098, 0.14284802840224334, 0.11705680377781391, 0.1368484760501555, 0.0873702656743782, 0.20181787838893278, 0.22002924260284218, 0.14135082731289522, 0.22911071458033153, 0.15545629470476083, 0.1373214420995542, 0.11247800875987325, 0.2028537028070007, 0.1599904964012759, 0.1653147299907037, 0.10301454192293541, 0.09488750408802714, 0.10311849348779235, 0.1501836297767503, 0.10090151602136237, 0.10938916807728154, 0.11459323311490671, 0.15821403743965284, 0.15315950794943742, 0.12008936676595892, 0.1542288927095277, 0.08317660034767219, 0.10929498741669313, 0.11512752515929085, 0.12642457682107175, 0.09097863347934824, 0.10345483651118619, 0.14712330113564218, 0.07489295663045985, 0.10350588270063911, 0.11668487159269196, 0.11708934631730829, 0.09000490858618702, 0.19176254581127847, 0.16777873491602285, 0.10432744611586843, 0.11245388005461011, 0.13974401567663464, 0.11802074419600622, 0.09836523354585681, 0.13421646585421904, 0.10047380147235734, 0.19398644433489867, 0.13271120376884937, 0.1257411427795887, 0.155119442780103, 0.113519648223051, 0.12138878846807138, 0.13969711533614568, 0.13179181595998152, 0.23210671810167177, 0.1119910648890904, 0.10623537123735462, 0.08826721433017935, 0.10092291701585054, 0.08975925176803555, 0.20694266339497908, 0.10873711628041097, 0.1170877314039639, 0.13045066435422215, 0.2119071784296206, 0.08178892159568411, 0.1659137135637658, 0.07514320034533739, 0.1477322998855795, 0.07535942231437989, 0.1306229986782585, 0.16718513891100883, 0.0974198646311249, 0.1509374278996672, 0.13010834343731403, 0.1291432630802904, 0.08729454116629702, 0.07446843119604246, 0.1458627323486975, 0.1376668842775481, 0.12949270861489431, 0.07862296540822301, 0.11477673612535, 0.12098135533077375, 0.14024173468351364, 0.06492286162184817, 0.13233161770871707, 0.15814349693911417, 0.2176985698086875, 0.07008400253419365, 0.1262269059994391, 0.14125822085355008, 0.06978492465402399, 0.09887085070035287, 0.11334302555769682, 0.16444032905357225, 0.14983167366257735], [0.07863711964871202, 0.06368237068610531, 0.02206902239205582, 0.02677054064614432, 0.01288498645382268, 0.036161702791494985, 0.03584924080808248, 0.03598711233852165, 0.03596335343484368, 0.016479371348395944, 0.025928653410768936, 0.05444076783689005, 0.009788366367242165, 0.04577225227175014, 0.037321251284863265, 0.061937558597752025, 0.03913273961682405, 0.03491393456767712, 0.017396279111770645, 0.01824706363757806, 0.022351355724302784, 0.04098389171329992, 0.021123051277494857, 0.026521396157996993, 0.03933781664818525, 0.03733844875491091, 0.022297737887129188, 0.014478156143533332, 0.03504789773640888, 0.09252456695373569, 0.02101389365270734, 0.017111889818417172, 0.024030192156455348, 0.029942322056740522, 0.027535298805949942, 0.011019581729280097, 0.04421183546738965, 0.04797296864645822, 0.04501565858455641, 0.03708895482122898, 0.04333551088348031, 0.03723634619797979, 0.003754646808374673, 0.07145038885729653, 0.032639661604272466, 0.025214040685178976, 0.0437464791882251, 0.02931895532778331, 0.011246547452174127, 0.06499479990452528, 0.037118728937847276, 0.036233932844230106, 0.012498620132516538, 0.018555393342726996, 0.03761785929756505, 0.0654832161962986, 0.03313377419752734, 0.03923299655850444, 0.04658783779346517, 0.06162881159356662, 0.01766151505788522, 0.01598030375316739, 0.05451361196381705, 0.0377847619487771, 0.036770654043981006, 0.03196472282122288, 0.07784298940428666, 0.05190239208085196, 0.06405633169093303, 0.022631002057875906, 0.02924616209098271, 0.01792293254818235, 0.017535740110491003, 0.022889381407627037, 0.03986511978187731, 0.10485390108078718, 0.023373480520344207, 0.0340259561448225, 0.07155973477555172, 0.01102505496237427, 0.022033623220132928, 0.05948822359953608, 0.030384509757693325, 0.007432394394917148, 0.05169891978480986, 0.05614565831742116, 0.04393063019961119, 0.017142020165920258, 0.09108631698680775, 0.02880906340266977, 0.03184242366946169, 0.041684105925794156, 0.04446748710636582, 0.05871180311909743, 0.03491002620596971, 0.07264839671552181, 0.027989128471485207, 0.007460171074074293, 0.02104298584163189, 0.05327489200447287, 0.04761928905333791, 0.017402148439681957, 0.05944517733795302, 0.010432719336157399, 0.018796200331832682, 0.0798789540837918, 0.05862047230558736, 0.005353486930419291, 0.044557688159069846, 0.06051001591341836, 0.06143944604056222, 0.008610495732032826, 0.11335801439625875, 0.033809113316237926, 0.03169905600537147, 0.020967432663642933, 0.05148721346631646, 0.027491099034835185, 0.06305417618049042, 0.047089047863015106, 0.02206608942443771, 0.09352429330881153, 0.021484613751194308, 0.029814116257641996, 0.010765345683986587, 0.09768149416361536, 0.05727590088333402, 0.05705374851822853, 0.04219245418374028, 0.064950762981815, 0.040645665755229335, 0.004585318708060575, 0.019149089431656257, 0.08703768852033786, 0.05917649782661881, 0.02156132722406515, 0.024987248836883476, 0.048695357383361886, 0.008071589649521878, 0.03215958111520324, 0.02769934991374612, 0.06010203994810581, 0.033869855771107335, 0.0033561105374246836, 0.014962480869144201, 0.048999839794955084, 0.005426073638123593, 0.049405328929424286, 0.051961923350713084, 0.0281904718639063, 0.018550496016229902, 0.033318820875138044, 0.05486178185258593, 0.023868634664852704, 0.015621528362057038, 0.025419117716540183, 0.020114361474822675, 0.0165235711195107, 0.029211709475410835, 0.01812863552809826, 0.03256596252322197, 0.03861057638589825, 0.01019319732274328, 0.030782178776072602, 0.012744855401771409, 0.041016078021909506, 0.02910736096756799, 0.011717396472314639, 0.05365127198664205, 0.018107819770063673, 0.05088325623156769, 0.06601465160825423, 0.030388105993292162, 0.060515070999307294, 0.05119763507640787, 0.07537243661603757, 0.057591582515410016, 0.06557202285953931, 0.060621254944375584, 0.025525478080713322, 0.037210690788924694, 0.06674512169723, 0.009639415208117237, 0.034176448426608524, 0.04097863985225558, 0.035121406827654154, 0.06344057473220996, 0.049475587837930234, 0.008338341273234358, 0.04608683806977101, 0.04209222438346062, 0.07627610276852335, 0.02856790187901684, 0.029758683339293514, 0.0176490486732551, 0.024916304608008692, 0.03954775199027998, 0.07333595624991826, 0.02099417881774051, 0.04061830383060234, 0.032720162998884916, 0.014207207780730511, 0.03564174479937979, 0.0321962016501597, 0.03506306638675077, 0.010488924088089593, 0.015989642091361538, 0.02514947298914194, 0.032848959123449664, 0.04153924209198781, 0.0376807391377432, 0.016543350415304303, 0.06607533978032214, 0.04264311000172581, 0.03737635511372771, 0.03022513205983809, 0.016783103978793536, 0.02794590070178466, 0.06316101151917662, 0.039766711848122735, 0.04651212007073419, 0.07018406609339373, 0.05595900011914117, 0.021402860459472452, 0.02054963999294809, 0.05918567840542112, 0.026901735391999995, 0.01468537056020328, 0.010479608650452324, 0.03478293659697686, 0.060209594533911774, 0.03662805651713695, 0.06303667676235948, 0.036648626306227276, 0.026580874841394167, 0.02583462542055973, 0.02793901866035802, 0.017726896995944635, 0.05130995976339493, 0.017391983985102603, 0.04484423689012017, 0.024015893727274876, 0.06359090416559152, 0.01143252372276038, 0.026303864616368498, 0.05830842762121132, 0.06634412107190915, 0.04465467456196036, 0.02042939849863095, 0.017660990889583315, 0.015930395806208253, 0.060883216959025176, 0.08776025367634636, 0.028303213849929825, 0.04021349662382688, 0.040804883997355185, 0.021619596418791583, 0.04848622949793935, 0.023333840504554764, 0.022844275792262385, 0.04758053452574781, 0.01706803440382438, 0.03671310070369925, 0.06386674222137247, 0.018254849826917052, 0.019503629067912698, 0.02690303648289825, 0.01874583267739841, 0.04285054833495191, 0.054336643245603354, 0.05190875334665179, 0.05539067954357181, 0.07739318854042462, 0.016813164776457206, 0.003065253745132525, 0.05568667348208172, 0.0381550588645041, 0.02848536827202354, 0.037473779171705246, 0.044510804781956334, 0.054587443359196186, 0.03346060076728463, 0.03439062461256981, 0.04342411059354033, 0.04549995616876653, 0.005327477410901338, 0.02010031071092401, 0.02825772825495473, 0.033781442658177445, 0.030931151139416864, 0.013836949880767082, 0.03512723883613944, 0.03151782947991576, 0.052266989302422316, 0.026307532098144293, 0.11620338314345904, 0.06651319164250578, 0.048872383777052164, 0.038776308564203124, 0.04487044869789055, 0.022017516495127763, 0.008788085309788585, 0.045643099916300604, 0.035390198297266445, 0.05954329350164958, 0.024362592891390835, 0.017746498176295842, 0.05016821263624089, 0.02417963440530002, 0.04468070316527571, 0.047123018718723736, 0.025294187545244182, 0.024980013957247138, 0.023686341143080165, 0.027229835911254798, 0.05404300382360816, 0.012592902573357736, 0.024597181107050607, 0.023677481172074164, 0.02650606805192573, 0.014719541583742415, 0.05113812416259732, 0.02842861051405115, 0.007752431373644088, 0.017009731282347014, 0.04842611468796219, 0.007814037264324725, 0.05553946191711085, 0.05918241465198142, 0.03702966443129948, 0.03206517653805869, 0.028736948700887815, 0.032105556157018454, 0.06397660382624183, 0.0527295194832342, 0.04566223121115139, 0.018130118127114007, 0.01101165304758719, 0.015785635448992252, 0.027350889951256768, 0.04810660611838102, 0.02785251392716808, 0.02655955696744578, 0.020314508949273398, 0.02164630694980068, 0.03879001157890473, 0.04313452202560646, 0.04514987620392016, 0.05377707237909947, 0.042967168148607016, 0.020376309918771898, 0.008215813964073147, 0.1629718164248126, 0.1995515035731452, 0.144974502867886, 0.08252163085022143, 0.11588975068713937, 0.08320657802479607, 0.08154274909091846, 0.08694817618067775, 0.15309367648192815, 0.10717639074261699, 0.12523962397660526, 0.17003094192062104, 0.1456568105412381, 0.13786836846598557, 0.13366115279495716, 0.24110292536871775, 0.17454566966210092, 0.10375316121748515, 0.08769725169986486, 0.09021716791072062, 0.17195433085518225, 0.122648882280503, 0.07649637559162718, 0.08487513634775366, 0.06097135187259742, 0.12169825471937656, 0.10544474223362547, 0.08914006820746831, 0.14953573739954404, 0.1351705403732402, 0.1358610311789172, 0.11646890746695654, 0.08356206930641617, 0.10667337916259255, 0.1891038827598095, 0.08882432550724063, 0.15499858212258133, 0.1459437222885234, 0.1502355241349765, 0.10664581707013504, 0.09211527463048697, 0.11440620172236647, 0.1314435103642089, 0.13920052269739763, 0.10445515997707844, 0.1564374292003257, 0.12130360518183027, 0.07421150391123124, 0.06708073868815388, 0.13324907847813197, 0.1502789096640689, 0.12230768773172583, 0.14433695136436395, 0.10032006579318217, 0.15933129963065895, 0.2534196116030216, 0.16892723685928754, 0.07713514845818281, 0.12930567722235406, 0.21574919298291206, 0.10956783313304186, 0.1318249013274908, 0.1934867982885667, 0.0918385341231312, 0.16697366668709687, 0.09754049458674022, 0.19828376945640358, 0.10091971433056252, 0.1606818421610764, 0.10392509520586048, 0.13245607460183756, 0.1720678633345025, 0.11785979568958282, 0.09447471730943237, 0.12183001264929771, 0.2617639367069517, 0.13959886346544537, 0.10750520881265402, 0.12414324709347316, 0.17868431258414472, 0.10741772529269968, 0.11474821051316601, 0.1215864864311048, 0.12378983891436032, 0.12271584011614323, 0.11111234168389014, 0.0917151832420911, 0.19514405221811362, 0.16135978006890841, 0.08549624694777386, 0.12667958385178021, 0.10521179437637329, 0.0821278023400477, 0.15138418892664568, 0.14217070117592812, 0.19793720091027872, 0.1335637287369796, 0.13744600755827768, 0.12361728745911803, 0.12371164453881127, 0.09790157021156379, 0.08021985686251096, 0.09605948334293705, 0.1288283821195364, 0.13616610052330153, 0.13177770243159362, 0.158933460978525, 0.13376221380063466, 0.15018259840352194, 0.1446742375514337, 0.14660990796983242, 0.1262157101716314, 0.13119307665952615, 0.10403087202991758, 0.15372908381479128, 0.12343596933143479, 0.12319726071187428, 0.10173510307712214, 0.1205148489347526, 0.2140928211488894, 0.12406440132430621, 0.1949503304702895, 0.11925024964979716, 0.12781596715961183, 0.09040847407387835, 0.1122098992179547, 0.1588633954524994, 0.19587454944849014, 0.14401206879743508, 0.12621025475008146, 0.1575867318149124, 0.14408803757812294, 0.12723903597465583, 0.17362697395895207, 0.1882996287729059, 0.09203824733516999, 0.1084132379453097, 0.09995589604867355, 0.19736343169850962, 0.16697818573032105, 0.08802212748144354, 0.16502544337085315, 0.08107230040643897, 0.1493607975010361, 0.11538150081677095, 0.09462805943829672, 0.11221251836312668, 0.07344874912606818, 0.11710928167615618, 0.13804492327783788, 0.08504681927817208, 0.13488927403731005, 0.08520697389862367, 0.10682414964373622, 0.11144318857363292, 0.10170629248023033, 0.11405949746923787, 0.1042443730735353, 0.1328832395374775, 0.0822146073249834, 0.07447607150035244, 0.17989420837589673, 0.08339293766766787, 0.05571836446012769, 0.06652493708367858, 0.1451995593628713, 0.10343912164015429, 0.12859468108841351, 0.11114467387752873, 0.07585693776075329, 0.10881185012736491, 0.22423962024705751, 0.11816140450537205, 0.22525982478899614, 0.11875418626836368, 0.15536892653575965], [0.015016348067937153, 0.03626976967124002, 0.039638767285006385, 0.030167785672737018, 0.01786535545917494, 0.007801321518075253, 0.02538353025114962, 0.031208441260137727, 0.021102934410529475, 0.0146444956106799, 0.01667927115756486, 0.031069127842783928, 0.01735106323446546, 0.0430175290176911, 0.0062503863924315995, 0.015745639202318022, 0.051697267552039454, 0.031858786541436396, 0.010311735694163611, 0.009298975529548312, 0.06793580816260406, 0.06122766847589186, 0.0281132579714592, 0.048606808563428264, 0.01863010004828019, 0.042940484758998664, 0.015200030890160372, 0.05001615633123687, 0.015013233592201556, 0.04315938015601464, 0.0366568976481046, 0.023514067887195518, 0.04294142792267459, 0.024428700861920203, 0.01680486968585423, 0.07139419258705207, 0.027435979938932827, 0.03093703743070364, 0.03090847789176873, 0.034373983541237454, 0.004287944374872106, 0.007815424868437861, 0.02374903777880328, 0.056150421633252075, 0.025821141233401637, 0.04193741322628089, 0.07052212581038475, 0.03971244601000633, 0.013842509627076132, 0.05387559566380722, 0.06860913881765944, 0.02707158458153052, 0.064898149376469, 0.027174036583996246, 0.019419631521616663, 0.018908572516271045, 0.018576002147580897, 0.046371968662632365, 0.028520675841718912, 0.011623501644602843, 0.0571498494329197, 0.062493808035339625, 0.06361406256577798, 0.11966195755771228, 0.01835381585572447, 0.010406639842715646, 0.03433207382581063, 0.02830148019295718, 0.052298398688435555, 0.032166078088006804, 0.040598541498184204, 0.006714137088108275, 0.06228238330887897, 0.020154072736789073, 0.029018265926944356, 0.025037124553429227, 0.02433681534603238, 0.02512183795416994, 0.0212573740697865, 0.05895780599010842, 0.06487246004066297, 0.020530367902080928, 0.04076475543635232, 0.04167829088068434, 0.04015037251104202, 0.005602792994717934, 0.03377480319301997, 0.0017888859064052148, 0.04219028626435569, 0.022384877050561563, 0.012423285782071096, 0.047886625065335205, 0.02234979679009744, 0.021967971564403603, 0.03386231046169996, 0.07322537539792912, 0.042942774814686606, 0.029135496422116245, 0.0540874648307051, 0.039078775726790936, 0.04662058050079005, 0.016072576034015844, 0.013097372155503502, 0.021865007267998796, 0.03246939341936793, 0.037878667802682946, 0.016320504248142242, 0.06999603725437607, 0.00858226019356932, 0.03613069374114275, 0.02344161391790424, 0.04834321127938373, 0.044919791764446666, 0.05964023579976388, 0.11668487159269196, 0.024517149597938572, 0.030242298995809894, 0.03274734511173197, 0.026524439387555634, 0.007961527876822012, 0.009644081832707992, 0.021117539876805883, 0.03460774224783693, 0.05306805078206318, 0.011762943983610188, 0.0337072143198124, 0.08655117891196694, 0.03914979798719287, 0.015827105812994496, 0.07978002367807285, 0.0373675714779113, 0.026422901711027538, 0.06654789192335946, 0.06402944134814398, 0.007847098883108368, 0.05272566879700337, 0.014580781172428812, 0.0414473277383617, 0.02627527793603284, 0.08285509688513619, 0.07830385038895266, 0.04976128500753215, 0.0473479496847306, 0.06235303916037083, 0.02398235204496554, 0.02929216337257198, 0.009288328466936946, 0.023482627967106443, 0.031876937353185246, 0.0576651357114315, 0.020184472801962068, 0.010048068860279662, 0.035719922211553366, 0.036542269334729226, 0.009113178222573229, 0.054806077520229986, 0.03332889033481479, 0.025863313881148185, 0.05930140933820179, 0.01224825597767319, 0.058387924783996174, 0.03804579437045114, 0.010691930739475148, 0.022189540389393057, 0.04483623356957521, 0.013407181915161865, 0.019733177464721457, 0.04950195231607982, 0.01739778715584959, 0.009686348627188375, 0.031891525856086185, 0.04876457474061421, 0.03111356170848012, 0.0784033371933869, 0.03971609313573156, 0.029255661581243788, 0.06700010837188788, 0.04738057025575212, 0.02054521255195141, 0.04587824283433812, 0.02648603091282504, 0.009464543163111168, 0.009324762404763272, 0.02064038726634213, 0.07012029737234116, 0.06996224621044737, 0.03319823841697403, 0.014210048297952329, 0.013794057137731994, 0.05145714418696506, 0.005328633040854973, 0.02497148816473782, 0.02931811733703528, 0.03897460703072803, 0.018914375687018037, 0.018070766669032828, 0.019663698871486952, 0.04123935675514596, 0.05311082562963877, 0.025202449610722915, 0.02404641592875123, 0.07157940550574235, 0.011181162121439618, 0.061081328828419955, 0.030790341552346945, 0.055176615315888605, 0.045818613176899295, 0.03877093795953052, 0.038007148408464024, 0.05168407004592674, 0.06708803293960434, 0.108181653943445, 0.024585082827668105, 0.029667573049664497, 0.021580553513818553, 0.021144163894600103, 0.026316220739058087, 0.03500432221751128, 0.01685104738654835, 0.02635452912987343, 0.03337940387427807, 0.04593298025429249, 0.02330187302348869, 0.04652306484058499, 0.058107927308550904, 0.052110088257385154, 0.037829216170523844, 0.03324781218543649, 0.0328743940086237, 0.026137479348108172, 0.020665535470470786, 0.021819245170003602, 0.014175903567645167, 0.02162162184582225, 0.018314755987375975, 0.043529198704553504, 0.04431448085233569, 0.021763020062020848, 0.04104440346626299, 0.06351162413401262, 0.01450079376809299, 0.03068264786686216, 0.009758861968293786, 0.04838855777468, 0.0316316672999944, 0.07428309614104883, 0.04436604951375297, 0.03418446871052895, 0.03907271640907441, 0.02142880594224802, 0.0201876941469631, 0.03506909517039146, 0.056092783476092985, 0.04630294468786035, 0.0488948059667434, 0.005943072369388703, 0.02750417949365718, 0.04184812480317695, 0.04594914295843669, 0.024079287557729652, 0.038272832187690904, 0.06019749625452927, 0.033958041574805975, 0.017319530015811324, 0.09658565332314797, 0.04722959960677794, 0.02201579980153058, 0.017278163128399422, 0.03644169008891497, 0.03214793066893305, 0.04050725478945034, 0.029387314338237047, 0.03920808753796986, 0.008340101223438978, 0.06263457691030842, 0.06884541149650301, 0.018481921570907747, 0.03775267742042031, 0.008822289411909878, 0.057243921527905126, 0.010372238965438945, 0.038037285541317294, 0.045116929936089685, 0.01802492653951049, 0.01810884944695447, 0.121722939823355, 0.05744296977562564, 0.05506816167118294, 0.04905406152829528, 0.02886945301932948, 0.0612495376595429, 0.05137249015803848, 0.020510408794507384, 0.04045446815767458, 0.008275654815536524, 0.016818277537822723, 0.07069901988974639, 0.040256451283182414, 0.04142553319356271, 0.032055588838245185, 0.016095059291858758, 0.048354033912931166, 0.05255408764683774, 0.043976533093622754, 0.010997551393562129, 0.06530427972653083, 0.04489107955513256, 0.03374055413795369, 0.0215813083840268, 0.028000756865367293, 0.03658014515947018, 0.11421823395150048, 0.03954421343015773, 0.05333915266341396, 0.034382010610508065, 0.04087360941671899, 0.048128590652985234, 0.01843113831377455, 0.07202622081552233, 0.0608068478426763, 0.055342903892908774, 0.01006398644364838, 0.01610373775474727, 0.06690320000052452, 0.02737907290325633, 0.03707476665398904, 0.02625616530089506, 0.056305785796472003, 0.04632713446127517, 0.022037775854447057, 0.06537238428635256, 0.013773103976356131, 0.02681948507337698, 0.0430346484562116, 0.061986535255398066, 0.01469802693463862, 0.05563662134643112, 0.054714105491127284, 0.07430864298450095, 0.009030339274821537, 0.0058822472180639, 0.022096265573054552, 0.007952446533766176, 0.04369551442297442, 0.021870094584301114, 0.03486470685207418, 0.025994554428117614, 0.01447288053376334, 0.08842778964234249, 0.01418319357825177, 0.036769646419478316, 0.061825403544519625, 0.09556003407176052, 0.10497848011021103, 0.14332938114447252, 0.12389197200536728, 0.09193943228040423, 0.10824749219630446, 0.15001094261450426, 0.1188026200979948, 0.2117722313851118, 0.17492229730955192, 0.11698375269770622, 0.08900918558772121, 0.10357473364898137, 0.15289346793932573, 0.06868060891117368, 0.0783134720155171, 0.1560584402510098, 0.19197483227721282, 0.07231909010027136, 0.121459871796625, 0.10765305480786733, 0.2918549563203539, 0.1031092314847878, 0.09991181162851197, 0.1639306406889643, 0.22560723471854413, 0.0788030960996236, 0.152344017422625, 0.07652240419494254, 0.11382230876811913, 0.09685270435043744, 0.061420854181051254, 0.09301497135311365, 0.06789920119834797, 0.16680263515029634, 0.14683044542159351, 0.11388885948274817, 0.11044555210641452, 0.1106506935986025, 0.10948146919586829, 0.16344003272908075, 0.1122028220977102, 0.0668066173259701, 0.1587885801813432, 0.20924618121768745, 0.08834628401590244, 0.20723900677902357, 0.1361267590629203, 0.14638391509652138, 0.1433677997972284, 0.15200822401259625, 0.11541500687599182, 0.14259337420974458, 0.10517943504133395, 0.19363353827169963, 0.13986261002719402, 0.16007179846721037, 0.10182205055441175, 0.10932024249008723, 0.1573003221835409, 0.08436993988496916, 0.10974847951105662, 0.21638290397822857, 0.23226761232529367, 0.0897580236196518, 0.08165195251681975, 0.1455351627830948, 0.10050179782722678, 0.14880207819598062, 0.11662035648311887, 0.09358006210199424, 0.17022463652704442, 0.10371195378580264, 0.11179875449410506, 0.1041742396940078, 0.1444311455956527, 0.14494406378694943, 0.10984827165624925, 0.18665709905326366, 0.3541658855974674, 0.11261545281325068, 0.16282537499708788, 0.1124365231288331, 0.1172829730702298, 0.10518137565148727, 0.07512072726551976, 0.07881471261914287, 0.09892421747956957, 0.1803880190210683, 0.14719791284629277, 0.09336031853620495, 0.06890062389097043, 0.1229219383427075, 0.1020125492608973, 0.12780386209487915, 0.16076551909957612, 0.11052589743797268, 0.08488837456596748, 0.15196991392544337, 0.16646294694926056, 0.1397944443992206, 0.09986999351531267, 0.07060226079608713, 0.11305375250854663, 0.08315349623028721, 0.17368276310818537, 0.21997118714664662, 0.1788051189588649, 0.11867409199476242, 0.17893999814987183, 0.07199187337287835, 0.1771734050874199, 0.10125875792333058, 0.11130801761256796, 0.25158583000302315, 0.1188918338822467, 0.10577114471899611, 0.104798770110522, 0.1291367762855121, 0.07533288480980055, 0.11945333518087864, 0.13062446431389876, 0.07758729026785918, 0.09787284103887421, 0.11606177288506712, 0.15042829593377455, 0.20134689366178854, 0.16472869286579744, 0.056253182369151285, 0.1402319637792451, 0.15732169603662832, 0.13554663876337664, 0.08630281473909106, 0.1862407906779221, 0.06238293541329248, 0.18461162809814724, 0.10307315377784626, 0.13445787504315376, 0.09949749136077506, 0.13565107887344702, 0.1635767575353384, 0.1479899396321603, 0.12757523650569574, 0.0975421095000846, 0.1113980659948928, 0.08399787877819367, 0.15333295507090433, 0.08686622950647559, 0.11868057878954069, 0.13088476391775267, 0.05797287169843912, 0.18828622092093739, 0.11905388161540031, 0.1171950213611126, 0.13927065607692513, 0.08609248923936061, 0.14116736501455307, 0.11351891540523086, 0.14706597849726677, 0.09702978163425412, 0.15096391790679523, 0.17686351814440318, 0.08266322753791298, 0.1504763497837952, 0.13760344125330448, 0.17520065951560224, 0.09161580500325986, 0.07962366885372571, 0.11336667250309672, 0.0989578321043934, 0.11507720500230789, 0.1705235040613583, 0.2289121209510735, 0.10864974132605962, 0.16336316828216824, 0.13893771251397474], [0.017276807754699672, 0.033123606350272894, 0.034078121917056184, 0.027118481529344405, 0.026867304828816226, 0.01902488529283021, 0.016041142899276953, 0.027796293908197964, 0.03462398637618337, 0.040547057653644254, 0.05339733364858797, 0.04684464633464813, 0.044247312670839686, 0.04053410102746316, 0.04111506949578013, 0.04612054768949747, 0.01693259542142706, 0.011824668617919087, 0.009989853100185948, 0.024525722887899195, 0.048242011174027405, 0.07104522202696119, 0.03033061372116208, 0.03644277235226972, 0.0485667274998767, 0.044392393635852, 0.013748585961626043, 0.025042137230879495, 0.039794823553945334, 0.025418751307630112, 0.02297949933979128, 0.007265438309072384, 0.006422727501818112, 0.01835675730503031, 0.07848151799823556, 0.010382142184036118, 0.020644446602091193, 0.04490410742749061, 0.019239597521456223, 0.03184600294168506, 0.07214613830936806, 0.005676521761675498, 0.06023166049271822, 0.023240129729466777, 0.03946943208575249, 0.06420635578355618, 0.03218302110742245, 0.042913770835314474, 0.011139898710618061, 0.03024433460086584, 0.005861048087743776, 0.04098734545654484, 0.018378853797912598, 0.07419724110513926, 0.04114695724898151, 0.013691181899048388, 0.03852526417800358, 0.01133071632856237, 0.04986793374908822, 0.009937627107969351, 0.0024277747600405875, 0.03717100666835904, 0.0297041698358953, 0.0248747307674161, 0.022067933343350887, 0.05081191845238209, 0.07298638179366078, 0.05407298828608223, 0.04321456540908132, 0.01265048814405288, 0.010709275790889348, 0.011821041848244411, 0.011809410061687231, 0.08026274706103972, 0.01233031545832221, 0.04609556742278593, 0.0534344223727073, 0.047387840758476935, 0.023563463540215577, 0.03216586095680084, 0.00941085153525429, 0.015040307139445628, 0.04185412644541689, 0.05819670683039086, 0.03540747379884124, 0.04169770376756787, 0.035574325559926886, 0.02875391886170421, 0.03598619631624647, 0.05210404251036899, 0.046827140131167004, 0.024848066037520766, 0.041743016336113214, 0.041016485142920694, 0.03317925639982734, 0.024926358800647513, 0.02333228157034942, 0.006157356696868581, 0.029392159078270197, 0.053995574225804636, 0.026076848851516843, 0.02165497014565127, 0.026560169345300113, 0.053592965472489595, 0.010445223888382316, 0.05368682722161923, 0.05331157021490591, 0.03329794235261423, 0.046205300106001754, 0.07127056350665432, 0.026393929962068796, 0.0211102778557688, 0.05228543866957937, 0.04578464910654085, 0.056234105357101986, 0.0690084295347333, 0.03142214247158595, 0.04150242478187595, 0.0236200805021716, 0.03943296761385032, 0.028457706095650792, 0.05435566597485116, 0.0370692162375365, 0.03898696315341762, 0.04432815333296146, 0.006295330431644938, 0.04038382248420801, 0.032897881498294215, 0.030656110362282822, 0.06521230430475303, 0.03748918191662856, 0.024348034922565733, 0.025159248982423117, 0.028442895372531245, 0.03212541009166411, 0.006706092207293425, 0.04494310622768743, 0.06004545691290072, 0.04408232009570513, 0.022016668326354454, 0.04846499813720584, 0.07898510633302586, 0.07193077129444905, 0.01416985018711005, 0.03650722300101604, 0.07491314304726464, 0.0030765704369904207, 0.04545105075729745, 0.03682414635217615, 0.01927464215883187, 0.057473347788410525, 0.0566925541497767, 0.03061431599780917, 0.03449374157935381, 0.028796585143676827, 0.027661297669900314, 0.028001096132876616, 0.02725051256961056, 0.04946056507261736, 0.023451325450358645, 0.01472134139787938, 0.04202168049024684, 0.05019840405189565, 0.08587694580533675, 0.09451365164880242, 0.043243664383356056, 0.026525370676868727, 0.022949299442448785, 0.08457378537527152, 0.05924996281308787, 0.04079455669437136, 0.05270647982667599, 0.015347517261813794, 0.003552861520022686, 0.031390536310417314, 0.020828129424314414, 0.030523246420281272, 0.02952120965346694, 0.004128545472797538, 0.026015499107805744, 0.0381546076387167, 0.03236728746976171, 0.04492569501910891, 0.039236596186778376, 0.04248930646904877, 0.01875659424279417, 0.09563336335122585, 0.08899747407329933, 0.032301805447787046, 0.026846366934478283, 0.04071409261918493, 0.027825062096651112, 0.02054746019920068, 0.010215320108857538, 0.0365605049633554, 0.035380325612745116, 0.027368216342957954, 0.02457464865541884, 0.04237719552059259, 0.011112214481857206, 0.020860610895657113, 0.026077992183023264, 0.010893191011356456, 0.04055904736742377, 0.019293569893177067, 0.03549932369164058, 0.01947781420312822, 0.016919725308460847, 0.05038856349087187, 0.01417738277398582, 0.03203720732459, 0.026067859958857298, 0.018378763892022625, 0.015928857228053466, 0.038782839463757615, 0.003067306737648323, 0.049958660666431697, 0.03131831982838256, 0.02796650950663856, 0.04097919285829578, 0.01398873731626996, 0.0598020799724119, 0.014576991554349661, 0.05578073200636676, 0.04225739337770002, 0.06190467679074832, 0.01338615665944027, 0.0020475803508556312, 0.048634625106517754, 0.05214096160073366, 0.03468336497566529, 0.055573537945747375, 0.011021833617373236, 0.009053366208848144, 0.030825326817908456, 0.0348326155383672, 0.010629845633437591, 0.028865269850939512, 0.04276713263243437, 0.05523508467844554, 0.018060676853305528, 0.022040741052478552, 0.018698879750445485, 0.07612143071102244, 0.07268371446324245, 0.009372756034801049, 0.05743160431406327, 0.014919672094817673, 0.028727625629731586, 0.031858884929014106, 0.02384621077882392, 0.04992685094475746, 0.020728618871154528, 0.037737013439514806, 0.02775586679178689, 0.01994120273073869, 0.021401754447392056, 0.04950766558093684, 0.04843114263245037, 0.014893801250894154, 0.053715407116604705, 0.026554011640005877, 0.031983250219907076, 0.0419705426985664, 0.042143921966531446, 0.04548346098246319, 0.032719752485198636, 0.01193659212107637, 0.026136196916922927, 0.06140741240233183, 0.02191085757554642, 0.025473140978387425, 0.02234124724886247, 0.028680782964719192, 0.08453105123979704, 0.041257141157984734, 0.044099663450781784, 0.029020474558430057, 0.02822216453828982, 0.023455188010952303, 0.0227301054900246, 0.021893351372065287, 0.02391901588998735, 0.028367087743910294, 0.05208087732483234, 0.0315823683382145, 0.03179021379245179, 0.019114485842042735, 0.02805279880496008, 0.03473209736070462, 0.016183385891573768, 0.0149924772059811, 0.022325652817796384, 0.041927398049405644, 0.05189359487433519, 0.05065719211207969, 0.015504781323085939, 0.06401807588658162, 0.011160692416264542, 0.06092853631292071, 0.04710731402571712, 0.022802189657730714, 0.048945288972130845, 0.019266516701983552, 0.05381252583382385, 0.03451399924233556, 0.014297048361705882, 0.06134425436279603, 0.05064596914287124, 0.014580428334219115, 0.035999841655471494, 0.0331561862091933, 0.02111259674919503, 0.08541393386466162, 0.05135286013994898, 0.02979307488671371, 0.042203147895634174, 0.05498192665566291, 0.024722677855087177, 0.07266384695789643, 0.029894702469131777, 0.02311937085219792, 0.030743074802947894, 0.06703005212226085, 0.027422190411016345, 0.02372024075261184, 0.059533312251525264, 0.058338893843548636, 0.02298287844418415, 0.01921077335386404, 0.02095148878704224, 0.03506958371560488, 0.011959877746578838, 0.023668536384190832, 0.011230372025498321, 0.02579684628705893, 0.025940334391114966, 0.031714604635323794, 0.05423090713364737, 0.011039519632634307, 0.015045837199847614, 0.02366888413338789, 0.03366726557058947, 0.07713974892560925, 0.04231435299984046, 0.09462499246001244, 0.02449451366971646, 0.03447907504492572, 0.04347933655870812, 0.1011696323486311, 0.012086823166880225, 0.01822708417395396, 0.06071163580885955, 0.07385100504117352, 0.1044157235217946, 0.10516566756580557, 0.13032087417585508, 0.11474031236554895, 0.08126268376197134, 0.21010806996907505, 0.2329686747065612, 0.1434710728270667, 0.28795620266880306, 0.18893179270837987, 0.11985154024192265, 0.08152952444340501, 0.14127434284559318, 0.13639577105641365, 0.1020513546786138, 0.10669705324939319, 0.09774122560130698, 0.1645468726222004, 0.1449940311057227, 0.10952815919050149, 0.10018410773149558, 0.1103393342345953, 0.09938156365283898, 0.0931809206626245, 0.1552583931812218, 0.12186799703964166, 0.14947583632809774, 0.17840361621763023, 0.13021886322115148, 0.08537958642201764, 0.08052191351141248, 0.13879667222499847, 0.23079296573996544, 0.1747603988541024, 0.10808545124850102, 0.23173064685293607, 0.06970116629132203, 0.16660929338208266, 0.1626816884215389, 0.09970022405364684, 0.1310114056936332, 0.11546874684946877, 0.16101246513426304, 0.20223250399742806, 0.11798693958137717, 0.14712787446166786, 0.0909948233248932, 0.19686476274260453, 0.06299274840525218, 0.17636144294270448, 0.14224269374140672, 0.1583310847303697, 0.12728732052658284, 0.11153686711830751, 0.11058369505086116, 0.1449837309441396, 0.07341347887579884, 0.1409194826015404, 0.12469302330698286, 0.10100029036402702, 0.17184655235282012, 0.10846276421632085, 0.0721388440579176, 0.11428535463554518, 0.13330657753561223, 0.20819940524441855, 0.1874426119029522, 0.09726751994873796, 0.1316063180565834, 0.10185424704104662, 0.138557529343026, 0.1548017119722707, 0.15202279894479684, 0.11886462462799889, 0.1503287684172392, 0.10065159800329379, 0.11328630003013782, 0.07675075837011848, 0.0912006569228002, 0.14968801422842912, 0.2318682266133172, 0.15516840586704866, 0.13813329567866667, 0.11129877596561398, 0.15765788299696787, 0.06048543258969273, 0.10720673482865095, 0.1585119143128395, 0.13436034241957323, 0.06798093074134418, 0.09475029073655605, 0.14706139160054071, 0.142534735213433, 0.11990325818104403, 0.10235260387084313, 0.09567106275686196, 0.1657049147678273, 0.14294804446399212, 0.09054994862526655, 0.13770798992897781, 0.09643506604645934, 0.1788254885801247, 0.14399015211633273, 0.08430419662701231, 0.1617701444774866, 0.1239955300199134, 0.09857038860874516, 0.13347173295915127, 0.060715299897960255, 0.07079161956374135, 0.15614578127861023, 0.06330949533730745, 0.12895556672343186, 0.13885741467986787, 0.0765737828665546, 0.19614319503307343, 0.12842694723180362, 0.13728520832955837, 0.09129679176424231, 0.09617227621908699, 0.10765740421733686, 0.10060969846589224, 0.11405353993177414, 0.0958114584375705, 0.10392043367028236, 0.11311971289770943, 0.18424815045935766, 0.14576293341815472, 0.10578521753528289, 0.12329028786293098, 0.1824399224881615, 0.1343267820775509, 0.08395645421530519, 0.07937458543373005, 0.08174504752137832, 0.18443822168878146, 0.13197326979466847, 0.09408597102654831, 0.16542115142302855, 0.1325126237102917, 0.11499962130827562, 0.20434090229017393, 0.14192918342139038, 0.1155334926609482, 0.062273833767644, 0.12607050367764064, 0.12601995281875134, 0.1083360274455377, 0.2031870534909623, 0.13871329384190695, 0.16014148401362555, 0.08511810616723128, 0.06038878884698663, 0.12357745745352336, 0.1315807644277811, 0.07081154813723904, 0.0578358279807227, 0.07927745993116073, 0.13713084161281586, 0.18062425777316093, 0.1276531866086381, 0.21409349968390806, 0.15263244908835205, 0.0852630819593157, 0.0795041381248406, 0.1499847783041852, 0.17932066986603395, 0.19153154534952982, 0.1245722169322627, 0.11848106235265732, 0.16588906917188848, 0.14487866658185208, 0.12615546983267578, 0.14154729034219468], [0.06180633671049561, 0.04280515434220433, 0.05892482240285192, 0.02821783209219575, 0.0429962433741561, 0.050089930051139424, 0.01743151543528906, 0.01453949062020651, 0.05109987175092101, 0.017438217664935758, 0.024149995995685458, 0.03898372654137867, 0.04825827565842441, 0.010786239473548318, 0.02031185757368803, 0.09204841857509953, 0.04767894585217748, 0.05357833286481244, 0.046745464870972295, 0.008365516600731229, 0.019751511480925337, 0.026262304346476282, 0.0194663011601993, 0.019977441589747156, 0.05164384309734617, 0.01788363858525242, 0.07511139062366315, 0.03468343282916716, 0.0398082449766142, 0.049841681229216714, 0.03818534527506147, 0.05097379315910595, 0.04217692590983851, 0.010281199921986886, 0.07778590425316777, 0.03189391429935183, 0.036047132153596194, 0.005934679739376796, 0.04115737954686795, 0.008878690090828707, 0.010808339359105697, 0.077408157022936, 0.03536648349836469, 0.03610618505626917, 0.03653795385201063, 0.019879099813156893, 0.028584410636020557, 0.03475853308503117, 0.017441659533817853, 0.03320600085758737, 0.03839571827224322, 0.015688771182405095, 0.08113295465175595, 0.023082444976483072, 0.06041175725736788, 0.042726118583232164, 0.04259088316134044, 0.029465586745313237, 0.026698052750102112, 0.005287152074743062, 0.052025603862213235, 0.06201752394969974, 0.03430048462801746, 0.022314095670091252, 0.025016325758770108, 0.007818792098467904, 0.027801745937072804, 0.004598022579947221, 0.02727248692618949, 0.01856393609861178, 0.03444130100043757, 0.018429689641509737, 0.031791462296886105, 0.022172246228105257, 0.02903587051800319, 0.02926948673224875, 0.026432747254148126, 0.03099589016554611, 0.023515765921079686, 0.02431664419626551, 0.03314739239535161, 0.005027313874701836, 0.04205137996801308, 0.03471659283552851, 0.024004351846607666, 0.07689733550484691, 0.02516240586659738, 0.038127869966306856, 0.05253536008032305, 0.06550943478941917, 0.03825181456548827, 0.05997789518109389, 0.041558709261672835, 0.07974104184125151, 0.023391336169359938, 0.029360345963920866, 0.027682444213756492, 0.05382576405203768, 0.023097869773794497, 0.026073759820844446, 0.08843744519565787, 0.05076721317267843, 0.03458580181800893, 0.01928563442613397, 0.036740235319094997, 0.01611331697287304, 0.055604950724435706, 0.017189921345561743, 0.054235514386423996, 0.05528390866571239, 0.02547359559684992, 0.04769127144079123, 0.07904761297894375, 0.02528264227190188, 0.007783140172250569, 0.049450264911034277, 0.042635425592639616, 0.04291341121175459, 0.016389375552535057, 0.07682850491255522, 0.03906475040795548, 0.04318961567644562, 0.031940709466912916, 0.03548178356140852, 0.008381754791896259, 0.059962845274380276, 0.03340660634317568, 0.027247372648811767, 0.08372932140316282, 0.02690087874153895, 0.052582267206162214, 0.060144339821168354, 0.03491190235529627, 0.02276496183393257, 0.08331246341445617, 0.04894928554339068, 0.031218931411526034, 0.013357032240102333, 0.009370158093848398, 0.05607486336625048, 0.029427995905280113, 0.029897630347737243, 0.024985778112230555, 0.028442705382726023, 0.024963474666167582, 0.04045820349295225, 0.04057616341326918, 0.010001741881881441, 0.0071658064677779165, 0.014632901143548744, 0.01763276383280754, 0.05387962616181799, 0.02505380124785006, 0.04278047941625118, 0.015629034655700837, 0.044195825433624644, 0.01829705131240189, 0.03219620843550988, 0.07072422746568918, 0.03625161207414099, 0.040077908363725455, 0.04614873742684722, 0.036088590643235614, 0.01547678666455405, 0.07519468079720225, 0.012420606416916209, 0.04213369644380041, 0.058078872439052374, 0.015096284582146575, 0.021066731174609492, 0.03215098407651697, 0.042515430067266734, 0.049289302833910496, 0.03306744400677936, 0.05479976714455655, 0.05381031380966306, 0.05619317612477711, 0.023387144519282237, 0.021198390716952936, 0.017208406335807273, 0.040646269651395936, 0.04400718591309019, 0.019199189064758163, 0.033433849524174414, 0.04358340686719332, 0.025896909846259013, 0.02792522234709135, 0.011303646173993391, 0.03679217038942235, 0.03993468997733934, 0.013438872893207839, 0.04778668364243848, 0.013880977473620857, 0.07962221000343561, 0.05948972316192729, 0.018071165308356285, 0.03973875959802951, 0.06394586618989706, 0.026208362508831278, 0.043930640377636464, 0.015824228824515427, 0.02042588877624699, 0.02516014634498528, 0.01953669068669634, 0.031639049760997295, 0.01889372617006302, 0.08413583851818528, 0.05032457085326314, 0.019328204016866427, 0.04082171166581767, 0.02906337154230901, 0.06499811115541629, 0.02211959699967078, 0.05714138810123716, 0.05012370413169265, 0.03877192522798266, 0.0788277947743024, 0.060001942462154796, 0.0645613381639123, 0.029089145694992373, 0.042911341679947715, 0.06137301746223654, 0.030659648922405074, 0.027112330609400357, 0.03826262362833534, 0.07310893878872905, 0.029928496905735562, 0.04727723955043724, 0.017534157427560006, 0.009104105361205126, 0.04528412775003484, 0.04722719420013683, 0.029685316740402153, 0.03556860550971968, 0.013197504416374224, 0.014791864935042602, 0.043311908042856624, 0.02636934833468071, 0.021771364346412674, 0.03282631640987737, 0.08255298595343318, 0.014072135207243264, 0.05425148370808788, 0.014783915897299136, 0.04096269427931734, 0.00810710502056671, 0.01642092064555202, 0.050472182753895006, 0.00822787153135453, 0.02627601584286562, 0.018234702425875833, 0.013877986830526164, 0.030869027865784507, 0.019515016581863165, 0.03325554748464908, 0.03918233374133706, 0.025117853257272924, 0.04524533251034362, 0.025932268306080784, 0.05121003869654877, 0.004700289681620363, 0.1300656364432403, 0.03905182092317513, 0.013289793660598142, 0.028695259509342055, 0.022108772669785788, 0.02197194269060024, 0.04116002922611577, 0.006297360947688243, 0.03894713314782296, 0.043175512326083014, 0.04218574007973075, 0.05397610705611961, 0.022088024765253067, 0.04419255489483476, 0.019851880380883813, 0.030075549014977047, 0.009319473224292909, 0.06525852611022336, 0.020319686171465685, 0.046956295879291635, 0.01539623098714011, 0.03728673081578953, 0.03988664969801903, 0.06306947035981075, 0.016975970772494162, 0.03770293741087828, 0.005236082560648876, 0.02399910507457597, 0.02784647496550211, 0.0510006767165448, 0.03397492691874504, 0.008066419212679778, 0.023023515906451002, 0.02766769964780126, 0.01827624742873013, 0.03590467372643096, 0.09660037753305264, 0.045869364203619103, 0.022712582323168005, 0.02106759461042072, 0.033531409289155684, 0.006823237037419209, 0.038777974367673905, 0.09599619638174772, 0.017991579936019013, 0.03630151832476258, 0.035474703048488924, 0.04726363153063825, 0.02179210546559521, 0.049215200024523904, 0.06054869240948132, 0.02430797421506473, 0.02467453240283898, 0.032506984259401045, 0.062423749294664176, 0.034621485974639654, 0.03503124987972634, 0.03116910658510668, 0.07438722412501063, 0.020973515730085115, 0.024636485248005817, 0.05014858261815139, 0.021260860043444803, 0.049119136429258754, 0.026482904562726617, 0.023380379525146315, 0.039635920830603154, 0.06750186466212783, 0.07408625313213893, 0.029239678688879524, 0.01926307313676391, 0.020267013194305555, 0.031264725739934614, 0.009438611251035971, 0.0463728541508317, 0.06772868534816162, 0.04512730134384973, 0.08115831829075303, 0.06253375339188746, 0.019676679246393696, 0.03934218641370535, 0.02845382148266903, 0.016136553404586654, 0.05742657636957509, 0.07418491890920059, 0.07008416538259812, 0.047385503205337694, 0.0364176292371537, 0.029528310522437096, 0.0362378513839628, 0.03758895031309553, 0.16248331192348683, 0.09220262244343758, 0.17455374422882283, 0.14104346452014788, 0.20641232042440347, 0.12300598169011728, 0.09152630623430014, 0.10632337722927332, 0.0983339191547462, 0.16343260955597672, 0.09000099343912941, 0.15805219326700481, 0.12666177909289086, 0.19275962587978157, 0.10849641276789562, 0.12160317839256354, 0.17656212645981992, 0.12559805331485613, 0.12784205004572868, 0.13944750944418566, 0.07489091424005372, 0.09685695197965417, 0.05812404930059399, 0.11457450554839202, 0.17596479851220334, 0.05153648189402052, 0.17533777787217072, 0.18314392971140997, 0.13821877752031597, 0.16077059454151563, 0.1151923116828714, 0.09177170520914452, 0.0904015733727387, 0.12501903224204267, 0.1536725347063371, 0.20635540490703924, 0.11005737579294614, 0.24908295859183582, 0.1075331305286714, 0.06341308727860451, 0.17628335713275842, 0.17661303015691893, 0.15017134829291276, 0.10655539549354996, 0.16011457331478596, 0.10231242781238896, 0.07337382528930902, 0.1562095092875617, 0.13913581759801932, 0.1172718315252236, 0.06967688830835478, 0.06337347440421581, 0.2678216259394373, 0.13233635388314724, 0.12034532374569348, 0.1010443272867373, 0.09078044697110142, 0.13195212664348738, 0.05583230745313423, 0.08618793197508369, 0.11534437138055052, 0.18968910564269337, 0.09347473989639964, 0.13745827547141484, 0.16650231555104256, 0.10042268064405237, 0.14547139406204224, 0.08936253269868237, 0.13131838850677013, 0.08021497141037669, 0.08306051657668181, 0.1335863239531006, 0.13551947022122995, 0.07950014833893095, 0.18966443410941533, 0.09681246722383158, 0.1482964474707842, 0.11819548053400857, 0.08613825642636844, 0.1745438647589513, 0.0809661503881216, 0.13841283853564942, 0.17484513430723123, 0.12111518957785197, 0.07936898073447601, 0.19440961948462895, 0.08434769750705787, 0.09473363948719841, 0.10619790931897503, 0.16119955080960477, 0.11978213968021528, 0.09867681004106998, 0.13249344831066473, 0.1281724694584097, 0.13136773157332624, 0.19726074220878737, 0.09147450008562633, 0.1531169502330678, 0.14601091082606996, 0.08689362875052861, 0.10121128761342593, 0.1746709815093449, 0.13111238527510846, 0.13265783020428248, 0.10509254863219601, 0.16958181959177765, 0.1580404546111822, 0.06558140021349702, 0.0946676316005843, 0.1551896168717316, 0.09798087059919323, 0.110714095910745, 0.1976709301982607, 0.12629374169877597, 0.10804477985948324, 0.1334970694567476, 0.11626605263778142, 0.11675875048552241, 0.1408970095217228, 0.168560814378517, 0.12849010527133942, 0.1568507927336863, 0.17249661604208605, 0.12382372495319162, 0.09897442907094955, 0.11891480907797813, 0.12108251133135386, 0.1895577684044838, 0.17973444052040577, 0.10753010426248823, 0.1545980293303728, 0.11228542695088045, 0.16240561966385159, 0.07985924942685024, 0.12669052183628082, 0.1553104639585529, 0.09896448174757616, 0.08368554232375962, 0.12625459022819996, 0.15609050781599113, 0.10760360317570822, 0.10801546036132745, 0.13201208199773515, 0.19164837550904068, 0.11909025109239987, 0.13728576472827367, 0.16298962118370192, 0.1069513274622815, 0.1040068654609578, 0.16045551002025604, 0.16697742577110017, 0.16647365423185484, 0.11925835135791983, 0.15323513746261597, 0.14226265624165535, 0.1765486371836492, 0.13478910869785718, 0.19966221334678785, 0.1407857569200652, 0.139958704156535, 0.11541979733322348, 0.11638342562530722, 0.11452422610351018, 0.13105614829276288, 0.2195761033466884, 0.0528840456557061, 0.08029222940759999, 0.17507264709898404, 0.13573064388973372, 0.1570099906197616, 0.18999440568898404, 0.12505986647946493, 0.08417840301990509, 0.10658913225467716, 0.1341532671025821, 0.18295471343610967], [0.01591647057128804, 0.022425640041806867, 0.030908352362790277, 0.011711806191929748, 0.018933741076450263, 0.020091398153454065, 0.02578635443933308, 0.07005105287368808, 0.05795343167015484, 0.01838978499706302, 0.03128508857584425, 0.07633766625076532, 0.019513079364384924, 0.033542360844356675, 0.051100736883069785, 0.016995789084051336, 0.03174908099962132, 0.022549518483823965, 0.04753935084279094, 0.058481630470071516, 0.041864558921328614, 0.022416367860777036, 0.01820932182350329, 0.02213837206363678, 0.029388535701270615, 0.019161990078698312, 0.020094677173931683, 0.042326033980186493, 0.02149417600594461, 0.03823083426271166, 0.025141483239297355, 0.07307391281106643, 0.059015210052686076, 0.01145355576383216, 0.022296182345598936, 0.06938897232924189, 0.026038411539047956, 0.01664668451329427, 0.06051931862852403, 0.023470714588516524, 0.03056210612079927, 0.014511300882856761, 0.008862564706110528, 0.02455846729156162, 0.025248169300279448, 0.05819679503994329, 0.032361815084836314, 0.031428717475916655, 0.044589436812592406, 0.028831960566874062, 0.033910934281136305, 0.024553451221436262, 0.048095756343432834, 0.014125119462343199, 0.05118887858199222, 0.054178527622882805, 0.044924992735364606, 0.01375904303443219, 0.032622016301112514, 0.02597825601696968, 0.050074103221829445, 0.029153548846287385, 0.014845296175086072, 0.0143330344664199, 0.06486659749810185, 0.02673518897167274, 0.07478943254266467, 0.01620749763346144, 0.025882470621062175, 0.03170897279466901, 0.02475840102748147, 0.0034769130953853683, 0.04746223873059664, 0.08475162261830908, 0.12642919085919857, 0.052184163925371, 0.07369515911809035, 0.005968833799540464, 0.031166049784847667, 0.024387086309226494, 0.05951693241617509, 0.04214100765862635, 0.02778668245965881, 0.060830460861325264, 0.06106454187205859, 0.04152878926002553, 0.028967854167733873, 0.012296871315421802, 0.04026811869282808, 0.052605279721319675, 0.011209350162451821, 0.030267852624612193, 0.038983997955386124, 0.03538666991516948, 0.013666767360908645, 0.021767554372282963, 0.013064533605107238, 0.013368772592262497, 0.006087032479367086, 0.041576290104006014, 0.014098178229427763, 0.03252536238038114, 0.05017369859186666, 0.020864519257364527, 0.020517541893890927, 0.041342314266200574, 0.02949474678773965, 0.0609416931069323, 0.0569646025874785, 0.026246136553319435, 0.02888887608423829, 0.019040430530107448, 0.056845821639789004, 0.009599201830237039, 0.03666500953425254, 0.006116200579396848, 0.030431349030030624, 0.01663595687464944, 0.06173279708517449, 0.08548870842371668, 0.07027734430240733, 0.026695448871968046, 0.030077913709517037, 0.043924883008003235, 0.08665213813739163, 0.07101937662810087, 0.03608183582712497, 0.03983163407870701, 0.050931303296238184, 0.014887977724096604, 0.02512759023479053, 0.032070051812167676, 0.0029783580061380883, 0.029243464914283583, 0.052137833554297686, 0.03334206748487694, 0.03761734700362597, 0.02833007535498057, 0.043627732167286534, 0.04691942428637828, 0.019192072928750088, 0.0744057617017201, 0.009288892499171197, 0.06100703602922814, 0.024167110345193317, 0.0640279214297022, 0.08490405551024846, 0.0397863079394613, 0.03699485219216772, 0.022574476698147397, 0.03724104166030884, 0.030020988014127527, 0.024501344821016704, 0.049281706634376726, 0.07831079180219344, 0.08386188678975616, 0.06949118684445109, 0.07681171795619385, 0.02663805159474058, 0.07468440889247827, 0.003916843395148004, 0.020543049721579467, 0.06138576713523694, 0.02505135173643274, 0.01916936575435102, 0.04718341172805854, 0.06323316693305969, 0.03739389863663486, 0.014698841176660997, 0.09853885030107838, 0.031030176540038416, 0.014898009864347321, 0.08803341151880366, 0.03882734118295567, 0.01949102697627885, 0.018228280091924325, 0.034042899164238145, 0.04251344874501228, 0.031505944939064126, 0.02175212787863399, 0.03297333459236792, 0.017179141120452966, 0.054651497064956596, 0.03022290307230183, 0.04358852641390903, 0.07523957945938621, 0.03198678199467914, 0.06581873140696969, 0.014291591243818402, 0.022851342734481608, 0.04778827141438212, 0.08554871806076594, 0.03366687541295375, 0.03382387145289353, 0.06932322228593485, 0.059881855334554396, 0.04271035282207387, 0.005110812697759164, 0.046625411670122824, 0.05389184657750385, 0.03149763967043587, 0.029718415678611824, 0.027499017538502812, 0.1124048423288124, 0.09682291666311876, 0.042806809967649836, 0.022792208407606398, 0.04334041329899004, 0.014701948867046406, 0.03084330799590264, 0.044713910669088364, 0.04584274866751262, 0.06697920270796333, 0.03102201037108898, 0.06934277087982212, 0.012618863323171223, 0.038887211720326116, 0.02260381994502885, 0.04250909933554275, 0.007201842614449561, 0.0077400752509545, 0.05894306142415319, 0.029595200504575456, 0.037860405032656023, 0.05143715454531567, 0.02280591311864555, 0.07231850656015532, 0.021615915366315415, 0.06818836568189518, 0.04100289408649717, 0.05212448677048087, 0.04320298620898809, 0.03522934478574565, 0.05857136672628777, 0.05167552050469177, 0.0602341303601861, 0.026303069034059132, 0.037634795531630516, 0.018795107890452658, 0.043206195679626296, 0.018274291551538875, 0.007726117785620902, 0.06330513914248773, 0.03207669806267534, 0.02337750592934234, 0.018956938492400304, 0.01212149630633316, 0.017776923686532036, 0.04425822012126446, 0.03884747331695897, 0.059004604550344605, 0.05689049299274172, 0.03688461060768791, 0.05685701407492161, 0.08587177536849465, 0.016328195442578623, 0.004440013402407723, 0.041568042510854344, 0.05158547890771713, 0.04868714710963624, 0.05573675275913306, 0.05133040402350681, 0.03973671720762338, 0.050282732384013276, 0.02835203953353422, 0.030857679367597615, 0.03156735235825181, 0.008458053510236953, 0.009849916278783764, 0.03231891131560717, 0.04352114449388214, 0.059801096096634865, 0.012436729257128068, 0.02779214297022138, 0.024841314614085213, 0.014573288449485387, 0.011294995700674397, 0.017973133961537054, 0.018698057026735375, 0.03618487136970673, 0.0457691615447402, 0.0059657222923955745, 0.02442940484200205, 0.020080979248242717, 0.023159185590754663, 0.033395094996584315, 0.0367479163355061, 0.02130929217673838, 0.056876929077718935, 0.014754830493724771, 0.03607404285243579, 0.0068329095541100416, 0.07383126645748105, 0.041124806473297734, 0.049671236625207324, 0.021750670724681447, 0.0391781437875969, 0.01789486494713596, 0.012133245140181055, 0.016928717593795488, 0.06675327768815414, 0.12975079619458743, 0.03931659546547702, 0.1309776282204049, 0.030379254503973892, 0.04860494937747717, 0.06049135620040553, 0.060297030556414805, 0.06101844898824181, 0.005282074936466026, 0.03918808093294501, 0.06254506457064833, 0.04172563226893544, 0.01574192422309092, 0.07943156201924596, 0.026919367124459574, 0.01181041683802115, 0.044031161947974136, 0.017943366630268947, 0.05713235680013895, 0.07129942160099745, 0.03425682429224253, 0.026121800100164752, 0.03546161750065429, 0.005995040942382599, 0.02923544802303825, 0.031078030222228596, 0.008106580004096031, 0.07695720943489245, 0.0261594537046871, 0.08314723335206509, 0.007920145722372192, 0.02997224884373801, 0.02009625985686268, 0.04766032345859068, 0.03383109785084214, 0.03695607391585197, 0.03372915814231549, 0.11491180530616216, 0.01825704997671502, 0.04199646952162896, 0.026111744211188385, 0.07457531403217997, 0.01836444341045405, 0.010106909720759307, 0.0496503106052322, 0.02430761798417994, 0.05301918947537031, 0.01727605118815388, 0.02538304340227374, 0.04418189850236688, 0.01954389503225684, 0.07766798165227685, 0.09546004515141249, 0.06917385637227978, 0.19553676114550658, 0.1153493518275874, 0.08706052800906555, 0.16339865566364356, 0.1394187259886946, 0.12456815929285117, 0.18444968893059663, 0.14573724408234867, 0.13184252966727528, 0.12159371961440359, 0.11327630520931312, 0.10948644964290516, 0.186728426654424, 0.12025980119194303, 0.10558621678501368, 0.2234662938863039, 0.14552488976291247, 0.12639630905219487, 0.11785933428577014, 0.24182111397385597, 0.13118146014000687, 0.13638006975608213, 0.10375491862318345, 0.11354453688753502, 0.17642301321029663, 0.1853334672216858, 0.11821488663554192, 0.04457588986094509, 0.13118783836918219, 0.12641856500080653, 0.12536922416516713, 0.07334183236317975, 0.14862770826688834, 0.15776320520256246, 0.13895338667290552, 0.17829292001468794, 0.13561416656843253, 0.19774932813431534, 0.12467506927038942, 0.09434866585901805, 0.06324851539518152, 0.0947508199938706, 0.16327531156795366, 0.11620928639812128, 0.11550264645900045, 0.08735867629625968, 0.16744482783334597, 0.25229954027703827, 0.09347808507404157, 0.11965566075273923, 0.08017225084560257, 0.17913525338683808, 0.16673285460897855, 0.17941645186926636, 0.12030613156301634, 0.14011803774961404, 0.11349965858140162, 0.12726577025439056, 0.08149259856769017, 0.0975659532206399, 0.09757829577262912, 0.08613550835954291, 0.1341558319649526, 0.29034130754215376, 0.08350393242601838, 0.12640006813619817, 0.07861409017017909, 0.1004233727497714, 0.10624065702514988, 0.11365736369043589, 0.12400502951017447, 0.1389560058180775, 0.10922933236828872, 0.14392711621310028, 0.11221484573824064, 0.1067612562328577, 0.09845378915114061, 0.1134451450780034, 0.07853282203099557, 0.13770390514816555, 0.15847813683961118, 0.12089412286877632, 0.06976244478885617, 0.16248103204582418, 0.0975489898451737, 0.21946939692965575, 0.0758218914270401, 0.08632487391254731, 0.09133580752781459, 0.1290402750351599, 0.08865180797874928, 0.1181981268205813, 0.1921483472521816, 0.11105640325695276, 0.11630634404718876, 0.10407231694885663, 0.1435654977602618, 0.07962629478424788, 0.08445285007889781, 0.0923441309215767, 0.10699547973594495, 0.11397468059190682, 0.08160202591014759, 0.10524829277502638, 0.16611842757889203, 0.11089210278753724, 0.11880029950823102, 0.099193086980709, 0.08468144174133029, 0.14776693231293134, 0.15364143066108227, 0.13412483648530074, 0.09877432909395013, 0.07197826196040426, 0.14129137407456124, 0.10021169696535383, 0.12286312292729105, 0.23245173958795412, 0.16504593512841634, 0.09743956250271626, 0.2150947188160249, 0.1825265171272414, 0.14740390250725405, 0.1711022944322654, 0.2153252171618598, 0.08869011806590216, 0.20275587162801198, 0.15101005828806333, 0.1013654846964138, 0.10501968754189354, 0.13318769820034504, 0.1520053063120161, 0.09362926267619644, 0.189393603642072, 0.12235329885567937, 0.11900467425584793, 0.12185571555580411, 0.09461864815758807, 0.07534683548978396, 0.1684410258063248, 0.16874479236347334, 0.1206701791712216, 0.14424833469092846, 0.16204302412058624, 0.07310757493334157, 0.1112299860854234, 0.09701401248042073, 0.07342603855899402, 0.13665467287812913, 0.12919517100921699, 0.09404246336115257, 0.24922045692801476, 0.1559170199824231, 0.11950008624366351, 0.18273519378687653, 0.22735100186296872, 0.12939927434282644, 0.08751766383647919, 0.13232587730245932, 0.20495158380695752, 0.09356528360928808, 0.14551556669175625, 0.108172921197755, 0.18542844855359622, 0.0906256256358964, 0.102961840108037, 0.11671448286090579, 0.10897568240761757, 0.13129602399255547, 0.12495292936052595, 0.07839834317564964, 0.08702641126832791, 0.08359577214079243], [0.01542325025158269, 0.027983364316501787, 0.02873474346207721, 0.09914001875690051, 0.01245725663777973, 0.03747260191344789, 0.03893278552485364, 0.010861527174711227, 0.04809561724375401, 0.012380206441905881, 0.0830225186156375, 0.009507506304154438, 0.0477668432784932, 0.04854721622541547, 0.029209375314946686, 0.03574007809428232, 0.056285850437624116, 0.028291271633601615, 0.013082500364232277, 0.018080812379983918, 0.04694567680624979, 0.01174279403806265, 0.03633827456672277, 0.00819648928674204, 0.02822109923831054, 0.056897380123181004, 0.07955633782382522, 0.04772491320701582, 0.020273455884307623, 0.07776936156941311, 0.01723848918585905, 0.02176189878290253, 0.035559146731559715, 0.0056191554426082545, 0.17616768048277923, 0.015087779145687819, 0.02300610300153494, 0.03310320958761232, 0.03047207130917481, 0.018599516778652157, 0.026695543866870657, 0.008356249508714038, 0.04605469925861273, 0.05723873073501246, 0.04709016405312078, 0.05328456112848861, 0.012937304048266794, 0.043417440594307015, 0.0034197611509755787, 0.03963132714852691, 0.017464841682729975, 0.05579628063631909, 0.010811052651011517, 0.03888297087645956, 0.01643427591105657, 0.033644015568175485, 0.06420155854097434, 0.03183239831456116, 0.036202967898654084, 0.04095505736768246, 0.028306151906560575, 0.02534133894369006, 0.007928805525547691, 0.043499380483158996, 0.004826332650346947, 0.018752736771213155, 0.0320666761004499, 0.04461218809176769, 0.060779428242572715, 0.038535564339586666, 0.05440402177295514, 0.00671309426460149, 0.07072401033448321, 0.06953478271939925, 0.023110064744417156, 0.028163072619853274, 0.026238370720031004, 0.046411194772060425, 0.01237047540156969, 0.05447040285382952, 0.05484147669215288, 0.012757996080576308, 0.008479710651694663, 0.010826964297198823, 0.01982233187715922, 0.008169514127075672, 0.004691319448673832, 0.016938983828627636, 0.06277892845017569, 0.06719895305910281, 0.020404750714078546, 0.0783055399411491, 0.03467355335929564, 0.029102628185812916, 0.01054329764364021, 0.032284818323595185, 0.00925430841743946, 0.03671728387208922, 0.01624976866878569, 0.04700116061472467, 0.037514257178242714, 0.04479845952508705, 0.023809101698654037, 0.050438771689576764, 0.020867270716865147, 0.009037713254136699, 0.047525569796562195, 0.03156202246568032, 0.03747238478224192, 0.06047995002674205, 0.06175847963563033, 0.011578873548257564, 0.027954825133617436, 0.042004567837076526, 0.06377868873200246, 0.04916411990832005, 0.04351129216541137, 0.026139861006023626, 0.017314600458900844, 0.048822114510195594, 0.03145177070317524, 0.046324471211326976, 0.03013762818383319, 0.08134123097573008, 0.0305936681771917, 0.034504133343164406, 0.017559139390609095, 0.021205042056473236, 0.019940011901780963, 0.033862707404685874, 0.1022039707750082, 0.03487755151997719, 0.02054070877576513, 0.06947564160717384, 0.07799655544970717, 0.0861302497131484, 0.022605428073023046, 0.04033986020034977, 0.029208788382155553, 0.03376100179074066, 0.06581624796880142, 0.0329631022842867, 0.023433790409139225, 0.033292951727552075, 0.03248104725831321, 0.05189851425322039, 0.021564171982130835, 0.0282527715566435, 0.028208542947790453, 0.08440805319696665, 0.054881995410791466, 0.007880808502834822, 0.05412856708945973, 0.01530656767343836, 0.022452951076307466, 0.019448158830138187, 0.045341141654976776, 0.029263519016759734, 0.009551385467472886, 0.04676651302725077, 0.029290670595530952, 0.013551102585292287, 0.019838129868730903, 0.13061869676624024, 0.04246622270771435, 0.03938195195847324, 0.01268340811865138, 0.08515060120927435, 0.008620241191238165, 0.0183747859804758, 0.008747499585816903, 0.03196477031867419, 0.016720264850716506, 0.0228033024551613, 0.05177758574219687, 0.03301891518224563, 0.011421314324252307, 0.047186943502830606, 0.04559037096000143, 0.05324175913951226, 0.04379548637994698, 0.012659204774536192, 0.03515698241868189, 0.038020203422222815, 0.013449690437742641, 0.0187282399607024, 0.0675416471702712, 0.01840563557509865, 0.0380214688900326, 0.015722853996391808, 0.06377421040087938, 0.08376200643501111, 0.06328421312251262, 0.021900496345811656, 0.015320966186534082, 0.03580022683101041, 0.016872221071805273, 0.04529174769829426, 0.03368585743010044, 0.06033948649253164, 0.07272261487586157, 0.09565254553620305, 0.0427866439068956, 0.017519468840743815, 0.046817002817988396, 0.05183410431657519, 0.012176095474777477, 0.016270419882078255, 0.03672966713617955, 0.03973915993369051, 0.03105740954301187, 0.02204706839152745, 0.046143041125365665, 0.06826373056641646, 0.019240766298025846, 0.04247688249285732, 0.022552700813061426, 0.0024526044767948663, 0.021155240978779535, 0.03069945178659899, 0.021218619542196393, 0.0027340453234501183, 0.021280400155644332, 0.0390678004228643, 0.0708264351955482, 0.058369794328297885, 0.013735340109893253, 0.03872603251199637, 0.048623110367251296, 0.03610785085973995, 0.05566654474075351, 0.008308713041645075, 0.03432124101423791, 0.009036191639357379, 0.047185393050312996, 0.06317882306341614, 0.024124610304300274, 0.02571733555357371, 0.00893635199671345, 0.021622542957110063, 0.03182679022263203, 0.016330443089827895, 0.03591995094237583, 0.025308187419016446, 0.07015618508947746, 0.0189174562360027, 0.0718318476740803, 0.06107611767947674, 0.06880924558000905, 0.019201648754200766, 0.02007884525560907, 0.04488778866029211, 0.04061509435996413, 0.15026867735598767, 0.028070603563849415, 0.04324432595499924, 0.03586777499211686, 0.012671275912517948, 0.02566696789913944, 0.052351131037409813, 0.03452468616887927, 0.03979220440877335, 0.028320202670459236, 0.027597257534840276, 0.03756188694387674, 0.06404813498790775, 0.03043193935549685, 0.018026751798710654, 0.05821570581091302, 0.02128396585716733, 0.05134902980976871, 0.0235846372254725, 0.04580627401758518, 0.004821769502346537, 0.05012239795178175, 0.07288283056446485, 0.040558976121246815, 0.027042025899780647, 0.035944116967064996, 0.0434850735722908, 0.018584785783397298, 0.07684858954910721, 0.06107316605214562, 0.07369117611753088, 0.03219265291201217, 0.0647877042314836, 0.010517578621927117, 0.022275982358093773, 0.029856941995343993, 0.016456864341827374, 0.06059876150850739, 0.03301902035517352, 0.029518464979316508, 0.02142258547246456, 0.058837372809648514, 0.03711078668545399, 0.0713711834645697, 0.0525888489958431, 0.03682567644864321, 0.07752943158681903, 0.026233687132064785, 0.026951241306960583, 0.033868522449795685, 0.03559052558349712, 0.04781144677794405, 0.043844306974538734, 0.039831288025847504, 0.0826347494231803, 0.010326998491239334, 0.04459500079974532, 0.04278452687763742, 0.042932573040681224, 0.03316935657390526, 0.017595963486071144, 0.044667220674455166, 0.050815613075558624, 0.014499850604417068, 0.029277625759797435, 0.07511502757136311, 0.027829881391621063, 0.03864834703771131, 0.08743256875979048, 0.04011660521583898, 0.036978621634521654, 0.02447057665059609, 0.02998169744387269, 0.018640332356361405, 0.034651324552084715, 0.06298890789704663, 0.05608166567981243, 0.0880083871473159, 0.041072888366345844, 0.03451850810753448, 0.04878579931599753, 0.036591415626129935, 0.03791060305333563, 0.012413452961482108, 0.0333565440294998, 0.01690727927988129, 0.046555339358747005, 0.0653555973299912, 0.007442105927371553, 0.009870030601242823, 0.024000950689826692, 0.0768484470567533, 0.021477816526644995, 0.006109840585850179, 0.03236513990642769, 0.017456566948177557, 0.01289641552804304, 0.054205937044961114, 0.040363761596381664, 0.050156864138053994, 0.1093987286356943, 0.10380340673561607, 0.11744232023400919, 0.1184404045343399, 0.1081504277618868, 0.11924012590731893, 0.10898384518389191, 0.22258392694805348, 0.1164579830531563, 0.15620348389659608, 0.13024390116333961, 0.12940057713006223, 0.1603783741593361, 0.2747894749045372, 0.1407307413007532, 0.14195351568715914, 0.09090450352856091, 0.08308925932007176, 0.08303546506379332, 0.13963979269777024, 0.10070429303284202, 0.10399764417005436, 0.16326111661536352, 0.12088326630847794, 0.20278968981334142, 0.22314743671034062, 0.09222053576792989, 0.14503103840563977, 0.15913019542183193, 0.07201197158013072, 0.11197197769901582, 0.18430765798049314, 0.10001173948070832, 0.2647215351462364, 0.10466556690101113, 0.10823218444628374, 0.1573340996567692, 0.10839645098894835, 0.08073717196072851, 0.0707875212122287, 0.074974211198943, 0.15504149267716066, 0.13439473057431833, 0.09351146221160889, 0.26996251248887604, 0.16551332361996174, 0.08278996430869613, 0.0978098933451942, 0.13421593659690448, 0.1005936104006001, 0.15819767117500305, 0.08177883177995682, 0.10349626107407467, 0.14201404101082257, 0.11354547326586076, 0.14074545193995747, 0.1748303829559258, 0.16736229083367757, 0.1715440885829074, 0.07754458327378545, 0.06377260905823537, 0.08708614949136972, 0.1418712365307978, 0.11020008527806827, 0.08793100701378924, 0.16648200021258422, 0.12474909744092397, 0.16866064045046056, 0.10155786294490099, 0.15561627969145775, 0.12878951563366822, 0.18900329672864505, 0.20047545113733836, 0.11143023534012692, 0.11574854754975863, 0.08971330137657267, 0.31175454280206133, 0.09285701518612248, 0.11479986059878554, 0.19039075156407698, 0.08608241977968387, 0.15110076484935625, 0.13414789310523442, 0.15400982089340687, 0.07328611106744834, 0.09960383815424782, 0.08616204586412225, 0.1712376485977854, 0.1799518567110811, 0.0967979533597827, 0.13642534161252634, 0.10614012527678694, 0.1214409949524062, 0.16176265345088073, 0.08883171475359372, 0.09178440738469362, 0.06936363583164555, 0.15495991919721874, 0.1949589750064271, 0.1276643824364458, 0.09792554285377264, 0.11618571409157344, 0.1902335892830576, 0.09231534746608563, 0.11026831875954356, 0.17505242675542831, 0.1349761536610978, 0.1324919555336237, 0.22391834748642786, 0.11116211222750799, 0.09804010670632124, 0.14283808107886994, 0.09798948120857988, 0.15304788893886975, 0.11848537783537592, 0.0846882610182677, 0.13334844314626285, 0.16092637261109694, 0.10698268935084343, 0.16183976217039994, 0.23441666843635695, 0.13932692020067147, 0.13349466744278157, 0.08373411864574466, 0.13937806817037718, 0.0894629762374929, 0.12657921495182173, 0.1632863309766565, 0.12986409797200135, 0.14852534447397503, 0.13599588322852338, 0.08940932447356836, 0.1666470199291195, 0.1268294450959989, 0.18897156843117305, 0.21423657557794026, 0.1329447826636689, 0.16881602496973105, 0.0871592548542789, 0.15445835968213423, 0.1210402250289917, 0.16269588337412902, 0.15376634895801544, 0.10999389205660139, 0.21294305713049003, 0.1186939866415092, 0.12310169583984784, 0.12146738996463162, 0.2399398349225521, 0.17377004985298428, 0.1906435058585235, 0.12266583208526884, 0.117442822349923, 0.21907626731055124, 0.10970400154058423, 0.2417750007339886, 0.1435439610587699, 0.10476993915757962, 0.18239721549408777, 0.19605444265263422, 0.09725084834332977, 0.11271086162222282, 0.19179348700812884, 0.1177704461983272, 0.15663636209709303, 0.08194075737680707, 0.19486030244401523, 0.15787923469075135, 0.0907187070697546, 0.10730474921209471, 0.12867850730461733, 0.06885908397712878, 0.11275780267481293, 0.17381576954254083, 0.09371273605419056], [0.05824727125998054, 0.02608077078392463, 0.0162980854511261, 0.020758074076314057, 0.037095618035112105, 0.054582449341458936, 0.058676580366279395, 0.041180164752794166, 0.06343535001256637, 0.011236142965831926, 0.0196701771845775, 0.014840091811493039, 0.023022767821592943, 0.09713051015777246, 0.008227571279608777, 0.021794521050261598, 0.028768442903778384, 0.0022800557781010866, 0.01617701444774866, 0.033150995416300635, 0.039605899048703055, 0.04582938492032034, 0.03626501653343439, 0.032906040881893465, 0.05380426127729671, 0.06187252780156476, 0.05036714892568333, 0.02929107771654214, 0.014509741948651416, 0.05457342143303581, 0.037179970115955384, 0.026810002546491365, 0.022022215350131904, 0.03333612012543848, 0.09518752513187272, 0.06372370703944139, 0.01881985236624522, 0.01521165928404246, 0.061151577558900626, 0.052950766004089794, 0.010316248800206398, 0.009494708285533955, 0.10887721340571131, 0.030947958451828787, 0.017996277094685605, 0.006002243167521166, 0.013847937907225319, 0.04525949014350772, 0.0361513517397855, 0.017210884684962884, 0.03922613656946591, 0.05881135777703353, 0.07074657840920345, 0.011350980776894306, 0.04750450806958335, 0.03167703075866614, 0.03111909855423229, 0.046676281440470896, 0.027637531980872154, 0.050844332070222924, 0.036492040779973776, 0.021590166658695256, 0.010264193289913237, 0.034900879553918324, 0.03383642774341362, 0.05088789062574506, 0.05323668709024787, 0.08079176688832895, 0.017910691776445935, 0.046464235854468176, 0.013938283996789582, 0.08253848566008465, 0.07506824936717749, 0.021004097303375602, 0.028035650528701286, 0.06196725807551827, 0.013970008053417717, 0.04485097135018025, 0.007269087131135166, 0.05492337586890374, 0.06484561719532524, 0.021343888981001716, 0.026484421088493297, 0.03914012886317713, 0.04588410198422415, 0.0070776410201298335, 0.027728036677997028, 0.004339458329403507, 0.05306489559422646, 0.021842780157125423, 0.016964652808383107, 0.03112128682966743, 0.023224652345691408, 0.05158499375517879, 0.03341270637299333, 0.09226032506142344, 0.021874903701245785, 0.03659032318474991, 0.02004010769139443, 0.06279636001480476, 0.06169520624514137, 0.02030217827164701, 0.010381944560711938, 0.03101424453780055, 0.0339526065093066, 0.046179352926888635, 0.029689845961651633, 0.019385633524507284, 0.035230715426483324, 0.01440165301651827, 0.025365364172362855, 0.06214042699762753, 0.05380245637414711, 0.043845938851258585, 0.050969864441347976, 0.026214096129738858, 0.027008204321776117, 0.009810948860831559, 0.053210502423878224, 0.017148250813728998, 0.019112277210557034, 0.03154348488897085, 0.025959391047113707, 0.020630311021315198, 0.05812555564833539, 0.05145284227494683, 0.04451302359146731, 0.03889973069142018, 0.03675707995093294, 0.05132907070219517, 0.02303799584374896, 0.036602658951388936, 0.01606109013248767, 0.03052967893225806, 0.0040742770901748115, 0.029080674185284545, 0.02271394617855549, 0.01620621350593865, 0.01343372366058507, 0.035647315571882894, 0.0030903629334976097, 0.03951721112909062, 0.01057857128658465, 0.03341893532446452, 0.01974216296470591, 0.0856852460918682, 0.013262603066063352, 0.06781125627458096, 0.07231001808707203, 0.014484142518735357, 0.023126661710973297, 0.07687458422567163, 0.06527380671884332, 0.10363622249237128, 0.006860291410703212, 0.031751126782702546, 0.017148361075669527, 0.0014315283354205477, 0.030454297084361315, 0.01966758518080626, 0.02166380636793162, 0.004296037177222648, 0.05157763843557664, 0.08904930057802371, 0.0479136341517525, 0.04743902265493359, 0.025619903013908436, 0.00978434774359422, 0.024687858830605234, 0.028391450543754866, 0.021493468633187667, 0.023588104539417794, 0.027731907720278417, 0.04517607783366527, 0.02177725063769945, 0.06981703971645661, 0.018826915915789347, 0.037386567065758367, 0.02729862748778292, 0.044447887622352154, 0.0246497981050717, 0.03234678892684834, 0.09756705244737011, 0.07326661675636258, 0.02980329023141946, 0.0263515808952174, 0.01750754189145352, 0.028492760911051716, 0.0676850216197116, 0.027844761664580022, 0.041207794698753526, 0.005203722377440759, 0.04313062723459942, 0.04048355356124895, 0.014609705423936248, 0.04311290050723723, 0.03406393374981625, 0.03391062894037791, 0.06768208356308085, 0.04186613651524697, 0.06447615487767117, 0.027104593613850217, 0.01817699132620224, 0.024290177937863127, 0.03276030852326325, 0.0275207611931754, 0.07850531422133956, 0.03353946689250214, 0.03985891118645668, 0.050197647485349856, 0.022748973852555667, 0.05247884150594473, 0.012480614357627928, 0.043381518950419765, 0.017958513228222728, 0.0493524065906448, 0.028291661791237335, 0.008394793690448361, 0.00674383741404329, 0.04856562827314649, 0.019001404588509883, 0.04270017479679414, 0.021482450920822363, 0.01854501514961677, 0.031778193544596434, 0.015937408465625982, 0.03957629117316433, 0.05124799255281687, 0.025642253957422714, 0.014322503602930477, 0.03929885516741446, 0.027672929456457496, 0.016716816196484224, 0.019859374800164784, 0.02524967904069594, 0.06473811689232077, 0.029614202877772704, 0.029388535701270615, 0.043777729118508954, 0.06345354153641633, 0.035991834942251444, 0.04870421226535525, 0.045999218842812946, 0.014850183323557888, 0.0012862793269700237, 0.024798611012686576, 0.05957813627485718, 0.02215356955171696, 0.03768465767747589, 0.034493829788906236, 0.005115349128443215, 0.017321735254621932, 0.02951989329553076, 0.021993028166304742, 0.0055168357544711655, 0.04695838237447398, 0.08314230040247951, 0.06366316814507757, 0.022425606115055934, 0.00785682992344456, 0.03712219285911747, 0.03271403243499143, 0.04838799798328962, 0.033770945721438954, 0.024034626382802213, 0.019698545037369643, 0.0430224517892514, 0.016698507625343542, 0.021631489441330944, 0.0200105032085308, 0.020874999230727553, 0.04589533173878278, 0.013419160602747329, 0.027348776314673678, 0.038288112796310864, 0.05885607323476246, 0.11893279025597231, 0.03937630993979318, 0.0041778431623242795, 0.006712819033834551, 0.046691806321697574, 0.04253244772553444, 0.05121575535408088, 0.05148060792790992, 0.01727083495019802, 0.06550595390477351, 0.03599294095433184, 0.04020513028704694, 0.014706021773495843, 0.015535905724391341, 0.031741610329066, 0.03266390905316387, 0.05288605751203639, 0.014792093940611397, 0.08031188656709023, 0.03053699353975909, 0.04948206106200814, 0.05442703089543751, 0.0032843997760210186, 0.010526426718570292, 0.061464273636894565, 0.03224639627816422, 0.05071772761376841, 0.02231738147591906, 0.04716088097276432, 0.046777695284358094, 0.04652069675336991, 0.014081658446229994, 0.02272467381720032, 0.02184573856980673, 0.02063492505944201, 0.05538550910672971, 0.0043330270896798796, 0.04497329764334219, 0.06263577791729144, 0.050076515413820744, 0.020953916246071458, 0.05321644978331668, 0.03115347313827702, 0.02353955366249595, 0.02893989852496556, 0.041924534631626945, 0.08168332797608205, 0.08427015452512673, 0.10289167280175857, 0.03870364764173116, 0.020856007035555582, 0.015477321010881236, 0.044268971508634944, 0.11934774156127657, 0.014411839523485728, 0.049383961861687045, 0.021927552929680263, 0.018457507880936776, 0.04417341681463378, 0.017147964132683616, 0.02639718184114567, 0.027601788452427303, 0.04285878235740321, 0.029390215075441768, 0.03779126570693084, 0.07783767647509064, 0.011199518190031605, 0.0091286937739434, 0.057759404581572325, 0.04769827052950859, 0.015231599731902992, 0.0360374392808548, 0.012444679143040307, 0.02323363784567586, 0.044162600966436524, 0.1395730927054371, 0.12853502428957395, 0.08786617977810757, 0.124123447441629, 0.10757070101265397, 0.09332025782870394, 0.14316414429673127, 0.19841832295060158, 0.17708045936056546, 0.14444863822843346, 0.10278681878532682, 0.09601104951330594, 0.07564270389931542, 0.12878149534974778, 0.11035582942089864, 0.15843586410794938, 0.076370256287711, 0.13459683901497296, 0.05755262103463922, 0.07777386704193694, 0.05073899968660303, 0.10731776351375238, 0.11604866358850684, 0.14408132008143834, 0.22702029746557983, 0.15292981027492455, 0.17767862869160517, 0.12960976947631153, 0.09109595218407256, 0.1112982602789998, 0.11394401080906391, 0.10920892882027797, 0.20342103950679302, 0.07453635933675937, 0.1117496353441051, 0.11124970431306533, 0.20205574562507017, 0.09988656334046807, 0.15557214777384484, 0.18729308992624283, 0.12343012035957404, 0.11950186400541238, 0.11055616688515459, 0.11878888654921736, 0.12866166606545448, 0.09725185257515737, 0.08684645699603216, 0.20568987061934813, 0.15273633279970714, 0.19430547792996677, 0.09952987783721515, 0.11244381738028356, 0.19439535667853697, 0.1281902470758983, 0.0732517975515553, 0.11081341308142457, 0.15366779853190693, 0.15405579842627048, 0.06802922207862139, 0.12030877784958907, 0.1525574709687914, 0.11468117125332355, 0.0886668103880116, 0.11685318898941789, 0.2385575505239623, 0.12290882904614721, 0.12850183035646165, 0.18505560713154928, 0.1937310030417783, 0.10928195954433509, 0.08947448419140917, 0.13118253222533635, 0.13907974346407823, 0.22528408920126303, 0.11104089873177664, 0.15052439006311552, 0.10841279689754758, 0.1428800281137228, 0.15896624779062613, 0.14130689895578794, 0.15808631000774248, 0.2147845604590007, 0.1804608122578689, 0.06377956404217652, 0.1671081387570926, 0.116212950487222, 0.14321896992623806, 0.14233350886830262, 0.08326490489499909, 0.15255409186439856, 0.10667012219450303, 0.11862060986459255, 0.12554774672857352, 0.14464675688317843, 0.17358124069869518, 0.14333263811256203, 0.1972846673535449, 0.14264961119209016, 0.08450112106012446, 0.2012829485216311, 0.15629957802593708, 0.17494291120341846, 0.09403993242553302, 0.07053097390702792, 0.11163147525595767, 0.152500148330416, 0.15842293123049395, 0.10832117431397949, 0.10774434490927629, 0.054295788652130535, 0.14738883902984007, 0.14029645174741745, 0.11383067510489907, 0.20148026650505407, 0.14223048011107103, 0.13490665810448782, 0.14692094842238085, 0.11894708020346505, 0.12340983216251646, 0.12590749242476054, 0.11695943400263786, 0.10534581182790653, 0.16624363086053304, 0.1328195793820279, 0.1354202548308032, 0.16138255170413426, 0.13163666214261735, 0.09252479087029185, 0.11286330808486257, 0.0747482997498342, 0.11229179839470557, 0.05806511853422437, 0.10538138063358408, 0.08513830615473644, 0.07717513452683177, 0.1565730683505535, 0.1523183009454182, 0.14184414941285337, 0.13692399699773106, 0.11884890975696699, 0.12206996977329254, 0.14449327226196015, 0.13445839072976792, 0.07272394480449812, 0.13606928714684077, 0.11595483576612813, 0.11317651984947068, 0.13129367626139096, 0.13454628815608366, 0.18813166421438965, 0.09220096003264189, 0.13179539862487996, 0.14500909458313668, 0.1514999470008271, 0.1898699895079647, 0.08502389157989196, 0.14048323886735098, 0.12523682841232844, 0.15241431365055697, 0.0960404368649636, 0.07297544380916016, 0.10023815304573093, 0.08326470811984368, 0.15075321921280452, 0.12338132012103285, 0.20134116682623113, 0.16713346168398857, 0.0904039346746036, 0.08335268697036163, 0.15250321530870029, 0.1506055292806455, 0.12582581037921564, 0.2006256787904671, 0.12143769727221557, 0.11252514658761875, 0.07678392516183001, 0.1934533736535481], [0.026550503613959466, 0.04559323098510504, 0.048350329111729345, 0.011147401611586767, 0.01586329547821411, 0.010175070259720087, 0.010025295528716274, 0.057265526082898886, 0.04360424467761602, 0.03296817772622619, 0.014173875596108181, 0.01792157208546996, 0.039705718335296424, 0.020863967947661877, 0.011365277509737228, 0.018909371491255503, 0.02955706344385232, 0.03509627389056342, 0.01643426064401865, 0.022344889285575067, 0.04157731129920908, 0.0392755407041737, 0.013840918462457401, 0.006345700206501144, 0.023516955053699867, 0.01633317249694041, 0.02221408300101757, 0.03937030490487814, 0.054642703251114914, 0.0893250707803028, 0.06497113260307483, 0.06605383022023098, 0.017586102675912634, 0.02217042605791773, 0.022955107702208415, 0.03854935895651579, 0.05725348208631788, 0.021826549599479352, 0.021528891553836207, 0.06348354635494095, 0.034816273022443056, 0.0036464951117523015, 0.032048053706863096, 0.024450408893504312, 0.0062777555264931706, 0.02310503849626652, 0.022649005288258195, 0.03433173116562622, 0.03761856158130935, 0.0027283761633693105, 0.03460838007075446, 0.05685917181628091, 0.040510616930467744, 0.026370883520160402, 0.040571786862398894, 0.011711566160166902, 0.02468002344747739, 0.0710609301126429, 0.03879952463986618, 0.019991734929914986, 0.0764659975788423, 0.04940254015049764, 0.025343269375818114, 0.039703869327370606, 0.03953285475394555, 0.007469369464420846, 0.042832210926072936, 0.009937838301993906, 0.014947420784405299, 0.03197152513478484, 0.009869140024030847, 0.14052245819142886, 0.002917859823875395, 0.06920912662254912, 0.060651748308113644, 0.033695591014942954, 0.10215924853192908, 0.09284613826977355, 0.025190081613670503, 0.04080405279195734, 0.025325944680454474, 0.04163772127191935, 0.017058546787926128, 0.012994156801141798, 0.023096315928601792, 0.026424871158919165, 0.05393076056082334, 0.03595334165064352, 0.048846416241888485, 0.06755545535790068, 0.02595603738778404, 0.0025091578260928926, 0.007963576204409557, 0.060922612702207904, 0.024056537974891917, 0.03301131219736167, 0.03724751488438674, 0.02162249037064612, 0.041496918470199616, 0.0377815965829151, 0.02781056858865278, 0.037978656723030975, 0.011733523553370364, 0.03358269975121532, 0.052097179128655365, 0.024535863593752896, 0.022339951246976852, 0.019785307613866668, 0.06344795719321285, 0.061357696141515455, 0.030183015391230583, 0.0437146525031754, 0.0032949297913416687, 0.07375451736152172, 0.016431239466848116, 0.09400994796305895, 0.029741404445043633, 0.021983046916180422, 0.019317744399553964, 0.027991420223510692, 0.0427999499786113, 0.10762332818870034, 0.044756882291819365, 0.015977565864367143, 0.11407985351979733, 0.03390743304044008, 0.013564704667909868, 0.023943555108936768, 0.03116026527381369, 0.01926050827439342, 0.0074547775688448125, 0.015522504657773035, 0.020484213950112462, 0.0291518355453653, 0.046526450730328045, 0.01864620507694781, 0.03762584226205945, 0.01824161160870322, 0.09062639916581766, 0.002672063057876325, 0.01145092474429735, 0.07436988076993398, 0.03423988466550197, 0.041926909504192214, 0.05918909822191511, 0.03166542102449706, 0.08459732375506844, 0.02744702309636133, 0.03477250412106514, 0.01232982860944633, 0.018267881091950194, 0.0546458211195256, 0.02575766428240708, 0.06072534221623625, 0.033498357848397324, 0.02195194795993822, 0.03340481501072645, 0.01713923647600625, 0.03086932302851762, 0.01582814397157303, 0.022110821845542108, 0.003393598961078429, 0.023648041233952557, 0.030407769938132594, 0.02543498865062637, 0.02038205032502966, 0.05230742659685867, 0.0335060015453824, 0.012051588539699358, 0.09876946399786643, 0.05296139864783202, 0.032942708914301226, 0.051473676692694426, 0.03262932412326336, 0.02706020894194288, 0.011818810316201831, 0.025120353658816645, 0.03959826213706817, 0.014102606518593217, 0.032128158158489635, 0.013096034593347992, 0.033891538357628245, 0.024896267468908002, 0.021433265613658086, 0.021018738392740488, 0.07246682752988168, 0.0363760112917849, 0.06210333827350821, 0.05219215367521558, 0.0173282508871385, 0.08342611803007977, 0.01952362888758736, 0.03393496799149683, 0.01932632447486477, 0.0026380866890706655, 0.014769822724961808, 0.03381572224731956, 0.006316725488951696, 0.025638754413064038, 0.027945948199235966, 0.015421017871371337, 0.06050293879317386, 0.028729488208357776, 0.05098968444924269, 0.06267448155475513, 0.10607937603656735, 0.1037098096151437, 0.015096718844558512, 0.06698807794600725, 0.02925039954217417, 0.05275613162666559, 0.04850552364119461, 0.014010227368479329, 0.060084194477115355, 0.011249592378070312, 0.02049737922581179, 0.03536047167809946, 0.053528725169599056, 0.02377120212518743, 0.0169689496313887, 0.034207973163574934, 0.04080610875306385, 0.0536179660952517, 0.05349578568711877, 0.04906418527077351, 0.007638285668300731, 0.024620761895286183, 0.017267011405367936, 0.0432049369971667, 0.05124660834137883, 0.12643673616860593, 0.057500550257308145, 0.03298215554761035, 0.03549109645453947, 0.03928174590691924, 0.011943888917033161, 0.05633597381945167, 0.043153079958366494, 0.07659509565149035, 0.04839717856209193, 0.021541773541165248, 0.014084815330404257, 0.03172215333740626, 0.07886021517749343, 0.01923635073139199, 0.04393763268100364, 0.04349510231986642, 0.053732523162450106, 0.01703527812579913, 0.019089900821979557, 0.019891001317383986, 0.04014599256749664, 0.08164718920098883, 0.06882314197719097, 0.026039074807028686, 0.008554039922143732, 0.023493194453684346, 0.02016135850655181, 0.025914426227765422, 0.006541111506521702, 0.016206873381244283, 0.01331984343206776, 0.05586672614195517, 0.03508048098800438, 0.08210594672709703, 0.06611332417066608, 0.022855315557015792, 0.012260480634202915, 0.014527239670444812, 0.0797833688557148, 0.05985865622226681, 0.042663408376808674, 0.038425862190446684, 0.06669143600655453, 0.04179749930543559, 0.025514087174087763, 0.02986400554488812, 0.03646420727350882, 0.013143116441954459, 0.0577833636530808, 0.04926499092419233, 0.1063625490558999, 0.015232576822329844, 0.016911859391257167, 0.049849050119519234, 0.07405306598437683, 0.010501152137294412, 0.016612830704876354, 0.07477567863783666, 0.021645148351256336, 0.0704272191173264, 0.005773556086101702, 0.01525374032956149, 0.04512634460947343, 0.01585880357639066, 0.02546427252569369, 0.0738163726138217, 0.04858066460915974, 0.08030887387160744, 0.06064371445349284, 0.016767597757279873, 0.03716427220829895, 0.03166296472772956, 0.05005277347351823, 0.007498655035825712, 0.017903696080403667, 0.03407392857064094, 0.01868052707452859, 0.029030496520655494, 0.05900599554713283, 0.006024756959439921, 0.015975659180964743, 0.014205087358797235, 0.030939714251352207, 0.049165137710848024, 0.013074289242337857, 0.053754392346101146, 0.006933010008651763, 0.03605262150189706, 0.056837272098554034, 0.06633489978100572, 0.02459790205050792, 0.024533397118960108, 0.04006280756688543, 0.04027778781684382, 0.03663283679634333, 0.013886669534258544, 0.03278082402955208, 0.023992002509268265, 0.0504949272477201, 0.014927965489083102, 0.02452503247851772, 0.019796457640560608, 0.04274365532078913, 0.06442483727421079, 0.028745420210595642, 0.04189678933471441, 0.010892382706515491, 0.024853512977382967, 0.04408695788255759, 0.05604278562324388, 0.016055649977975657, 0.03589583241513797, 0.010464628293578113, 0.008214097270475966, 0.01884678002846028, 0.010857127723284066, 0.012925684984241213, 0.04899125971964427, 0.018546071967908313, 0.03344363739181842, 0.043004226338650496, 0.11953849132571902, 0.10568633462701525, 0.06688946645174708, 0.08866594864853791, 0.14600295839565142, 0.14270796520369394, 0.12898554440055574, 0.15915047004818916, 0.14758195009614739, 0.1219366512128285, 0.11269691094223942, 0.0805378726550511, 0.10685754035200391, 0.1037283879039543, 0.1110858041793108, 0.08376263747257845, 0.0902765668662531, 0.10231453805629696, 0.07801688435886588, 0.11603053313280855, 0.1292099766433239, 0.07271204330027103, 0.08637862745672464, 0.0782202413039548, 0.1459625991327422, 0.14898476696440152, 0.19006251703415597, 0.12207436668021338, 0.17661408867154801, 0.18759571654456003, 0.20750443610761846, 0.10712757693337542, 0.09070995396801404, 0.13410735742322036, 0.10503588417278868, 0.15720736288598605, 0.19363391825131007, 0.10170082348798003, 0.05828257543700082, 0.10209881820316825, 0.11215669528714248, 0.09604795503297023, 0.15653418829398497, 0.0843972848462207, 0.11402679208133902, 0.09046278401677098, 0.1560976460043873, 0.11489150353840419, 0.077255445931639, 0.09512500491525445, 0.1351997038083417, 0.10319200597171273, 0.09719552738325936, 0.12133940468941416, 0.20099651174885885, 0.12100251205265522, 0.07894556131213903, 0.1383142066853387, 0.08652755910796778, 0.07415023898439747, 0.17346928242061818, 0.10707588613565479, 0.11475659720599651, 0.1425877966518913, 0.08037890547088214, 0.07167739274778537, 0.1307596013482128, 0.13407667406967708, 0.1333854640168803, 0.17746577225625515, 0.09492208901792765, 0.18873603535549982, 0.0525480826119227, 0.17248768652124064, 0.15318810141512326, 0.13996857005570615, 0.16236583037035807, 0.23161475307175092, 0.08102806670857327, 0.1443890764244965, 0.14011049244020665, 0.09518618841788598, 0.10826339027179138, 0.0984228208128895, 0.1323669422417879, 0.12812065652438573, 0.13100114624415124, 0.15549976165805543, 0.14848247463149683, 0.11152989177831582, 0.1595542255256857, 0.1186266081141574, 0.14130581329975808, 0.18274773311402115, 0.15546880689050468, 0.1302691562367337, 0.09611352187182222, 0.13340421872479574, 0.09221451716231448, 0.08427727914282254, 0.1196348840104682, 0.08570672172520842, 0.0978707918631179, 0.11432219908705779, 0.10514149814844131, 0.15791632341487066, 0.06466272486639874, 0.10122014928076949, 0.12807953730225563, 0.2058343714369195, 0.1123847576922604, 0.11082337397549834, 0.20844103156455926, 0.13958014946963104, 0.12040909246674605, 0.18181109694497927, 0.09552315569349698, 0.16152292702879223, 0.11863089645547525, 0.08561884465494327, 0.13051447378737585, 0.14111256652644702, 0.172324946682368, 0.17196031553404673, 0.15211687103978225, 0.09885417909494468, 0.11044496856629848, 0.12289977738899843, 0.16026469240231173, 0.07298440047140632, 0.07544799827571426, 0.08109726370977503, 0.08596489072910377, 0.14284462215644972, 0.1457074156829289, 0.06657358125916549, 0.1340301672794989, 0.09963982086628675, 0.16401518615228788, 0.13479433341750077, 0.13847478878285202, 0.11468031629920006, 0.09962768866015331, 0.24086983501911163, 0.2997059593243258, 0.14180735924414226, 0.17421364890677588, 0.11938981073243277, 0.13554100692272186, 0.13218305925173418, 0.09186764327543122, 0.08686652806188379, 0.13061466626822948, 0.14007554788674625, 0.12552331946790218, 0.11715137798871313, 0.11647341293948037, 0.17265736098800386, 0.10407899373344012, 0.06725845379488808, 0.15584295109978744, 0.10898637611951147, 0.09023276743079935, 0.11167395833347525, 0.12679621045078548, 0.1611685689006533, 0.14270899657692226, 0.11197180127991097, 0.1272450206535203, 0.18041222915053368, 0.16365033787276062, 0.10043258046997444, 0.10653999274862663, 0.07315663301518985, 0.1153121002550636, 0.11165831131594521], [0.04240520544616239, 0.018439942305641513, 0.05199628775673253, 0.044416990530278, 0.06387333079640355, 0.026727731871817793, 0.058249225440834246, 0.031737501799528084, 0.0544278383521097, 0.026396023242601326, 0.03842057640265141, 0.032348892385406156, 0.061495343755398474, 0.022463373374193907, 0.061423303692468574, 0.045311903581023216, 0.0487826543061861, 0.022966832787330662, 0.058703016090605936, 0.08570784809333937, 0.04593690557937537, 0.031006604233490567, 0.012007968067856771, 0.043576848826238086, 0.06530719742711101, 0.08419342578521796, 0.022688192381922687, 0.03464192005672625, 0.0402736792873059, 0.05280727281102112, 0.04193360325215118, 0.05313121221427407, 0.06825965935630457, 0.08417785340653998, 0.051022932665156465, 0.024472442621897374, 0.01680728018150798, 0.020615982058058892, 0.028948716087532893, 0.03199606096105916, 0.00835105193047119, 0.025075171708262393, 0.060060886799224784, 0.021231420105323195, 0.01686521519773773, 0.03657300018572381, 0.006779837089457682, 0.055324142399643145, 0.07914436528725283, 0.026236402968476926, 0.01508955012208649, 0.046097596242491684, 0.08785305012549673, 0.06322134685303483, 0.02145087529372956, 0.020952509982245307, 0.04422775389892714, 0.0388532815767186, 0.03736834500783256, 0.01834415182072137, 0.026259546101625477, 0.022672960967091576, 0.049696342420897315, 0.010468231314527137, 0.024435562547296286, 0.014299467339047363, 0.0282260898633727, 0.07580978636230741, 0.041725428708429844, 0.027488166067217077, 0.04695029762972679, 0.06530031708202191, 0.04879666605432119, 0.02749980633546199, 0.03385682450607419, 0.04454267896445734, 0.03543214872479439, 0.02819849893317691, 0.05124438613919275, 0.028581364013786827, 0.04185194834800703, 0.012558461832148688, 0.04706599124308143, 0.023914831025259833, 0.05829269917947905, 0.01947615688134517, 0.057878894598356316, 0.035443290269800594, 0.03010665306023189, 0.02836739138833114, 0.028694584366998503, 0.028546473743127923, 0.01366758584377489, 0.04732003136138831, 0.02342849105064358, 0.02918965708730476, 0.017544644186273217, 0.09165099382932697, 0.04307487540479217, 0.034589102890874655, 0.08457191261862006, 0.09816317938800369, 0.07131349441728421, 0.054073202024613104, 0.0800756546003478, 0.06652179546654224, 0.024945564734350358, 0.04092152416706085, 0.025566504004278352, 0.018674540699326565, 0.07246482585157667, 0.04970990972859519, 0.08343440972800766, 0.012533282245775419, 0.06478376872837543, 0.050838025087224584, 0.046876378024795225, 0.02666171719985349, 0.029775928306792463, 0.012158990455126124, 0.01793276282426502, 0.03795623792601483, 0.021863312626789724, 0.020474227610975504, 0.022150784165465405, 0.006633301090914756, 0.04343643278947898, 0.014579198489497815, 0.01706908443676574, 0.012692685388693852, 0.05313304425882442, 0.03588833460318191, 0.0372708802377539, 0.014180381898768246, 0.026188067526423504, 0.012777750779475485, 0.03735811948510153, 0.03956228281770434, 0.022397409592356, 0.06359390329037394, 0.026101869830329503, 0.045963599147008996, 0.022572656527959874, 0.00972128045811717, 0.02322631814916219, 0.05891351122409105, 0.06966834555247, 0.005330083833541721, 0.013067307116995965, 0.03239719729338374, 0.07301502954214811, 0.057889703661203384, 0.025615312724507282, 0.058529297555131574, 0.053459972608834505, 0.06655979342758656, 0.033152267669460604, 0.03322070131876639, 0.05639207509479352, 0.04517120595223137, 0.13982108368405274, 0.011399345904854792, 0.08096573648176023, 0.01243465718081487, 0.019481720868498087, 0.017337019255916988, 0.028200924695868577, 0.012598562403582036, 0.052705831825733185, 0.0402713688755674, 0.04233388802302735, 0.014907697648076075, 0.020371421073962535, 0.021160380881545798, 0.009884005029951888, 0.03759845998138189, 0.020628981092678647, 0.02696741758180516, 0.05400978953444532, 0.02894174074754119, 0.07063571257250649, 0.027908993485782827, 0.030663302833480493, 0.019462774474439875, 0.018831058372078196, 0.00441604118428326, 0.032115683292171786, 0.06332217715680599, 0.029008148969816308, 0.016235052940568755, 0.0707139748015574, 0.06973796324538332, 0.012519307817066354, 0.003623393962958029, 0.03853448546890702, 0.02046518782818956, 0.0308133065700531, 0.05474057174952967, 0.05975488107651472, 0.02467564689660711, 0.05821821639048202, 0.017967692110687494, 0.021579359292185733, 0.06281817491565432, 0.03655457795996751, 0.06515625052686248, 0.013275831954420676, 0.03436192597395607, 0.04370569923360433, 0.027780368691310287, 0.009941606715853726, 0.04600581081051912, 0.04935649137145706, 0.02844674266608698, 0.02123374069508697, 0.016443911108321378, 0.013747799709173185, 0.044909087874527485, 0.0141977252538449, 0.027935130654701164, 0.02776937303133309, 0.11344065996153013, 0.040539631087865145, 0.041888901365122626, 0.03374608759103077, 0.03268104884773493, 0.032164147655878744, 0.03846274735406041, 0.03916135343856045, 0.020482833131349514, 0.0725458904302546, 0.04249157616868615, 0.04015048786199518, 0.05308133989040341, 0.04173381540126034, 0.025141590108562793, 0.03462727387834873, 0.09754782955029181, 0.06314790900796652, 0.020215293558846627, 0.05130061972886324, 0.01273058750666678, 0.04062151669391564, 0.026206576265394688, 0.08108876166599137, 0.05379716040832656, 0.06569716507302863, 0.09395702223160438, 0.049581717500197034, 0.10111960396170616, 0.020653688249045184, 0.05297371745109558, 0.1736824374113764, 0.05322554215256657, 0.015781267379809703, 0.032419246288814714, 0.019201087266472832, 0.051542103556650024, 0.06337096382464681, 0.02524942798273904, 0.052379517549914975, 0.06943617801048926, 0.02585193484888545, 0.03809620273698654, 0.04205400250586016, 0.01629038238232689, 0.03951585745172841, 0.017018134938552976, 0.010306012251281312, 0.01894341528947864, 0.03954085807449051, 0.06360502447932959, 0.03758213782150831, 0.050659804471901486, 0.06168864481151104, 0.03757622778149588, 0.116068463240351, 0.06113750474261386, 0.015844126863937293, 0.0452284234176789, 0.020638587452205162, 0.03886905073055199, 0.0369175534828433, 0.039837835888777456, 0.06870326519544635, 0.041111147563372336, 0.05411940347403288, 0.03295474273285695, 0.012745961413851805, 0.0150162988741483, 0.05875005892344883, 0.02878556912764907, 0.02360759545782847, 0.0271768694676991, 0.05360715703240462, 0.027863424770267944, 0.03914520091244152, 0.054683018409247906, 0.03399135764422161, 0.016992352304181883, 0.06522846700889723, 0.03561896977147885, 0.05198067466595343, 0.04986341131318893, 0.02077204511234803, 0.04361797483371837, 0.032733984757214785, 0.06743885590029614, 0.01600162501979087, 0.02429218979419342, 0.04473965768037098, 0.03419283843998398, 0.025114623430584158, 0.043214870749839714, 0.06160962262323924, 0.009352986917032726, 0.01774253722812448, 0.03201172833463975, 0.008767177101357706, 0.03478272285844598, 0.03957287474934544, 0.020740941067093184, 0.05430304558415498, 0.01292183853885425, 0.06585881925587143, 0.041565708350390196, 0.02993457657950265, 0.010659010764876646, 0.07465307414531708, 0.032424637249537876, 0.03561472553493721, 0.016434666068692292, 0.04687278518187148, 0.03593179137845125, 0.0321037750025945, 0.11350018783871617, 0.1051332743040153, 0.027435484608369212, 0.12278986828667776, 0.022039607898997407, 0.029685713683388064, 0.03182129069630589, 0.04559243031378303, 0.046117090553577454, 0.0311490151632045, 0.02452743618882128, 0.03581372967788151, 0.02792320879442351, 0.03714914766273328, 0.042671527048306804, 0.018119449860283306, 0.06810839354459729, 0.07025189245385782, 0.10587420740297862, 0.10834776610136032, 0.1500497412468706, 0.10335720210735287, 0.1693609021604061, 0.2304435202053615, 0.08939941107694592, 0.3207486873226506, 0.0776960187192474, 0.1363956896322114, 0.15807964679385933, 0.13506996791277612, 0.09541528219623224, 0.20539838554603712, 0.11706498691013881, 0.10817574390343257, 0.14869154484144279, 0.07756620139947959, 0.12181954963931016, 0.08049460247691188, 0.21287973624254974, 0.14540109783411026, 0.12181626552981989, 0.1803457055773054, 0.1463545209595135, 0.16356568384383405, 0.1139557087527854, 0.10751703567802906, 0.14948562080306665, 0.10538275127432176, 0.16612362515713486, 0.14338660878794535, 0.15030666174633162, 0.09623391434018101, 0.15225626927401337, 0.09105268200593335, 0.11158967071345874, 0.1169378294476441, 0.11185146987970386, 0.09161126560398511, 0.06846811209938355, 0.1298182832875422, 0.07527271232434682, 0.10799716705722467, 0.17059025833649294, 0.17721841910055705, 0.13306643042181218, 0.1739764330642564, 0.13877668258334908, 0.13067578870270932, 0.08610034667487655, 0.23952335012810572, 0.13942674627261503, 0.21076476973082336, 0.15725411394877092, 0.12117602702762399, 0.1338494462626321, 0.11094921508005687, 0.16723282635211945, 0.097190892989082, 0.32818771100469996, 0.1712180253650461, 0.0990446913721306, 0.19644766726664134, 0.08243743143975735, 0.10497168797467436, 0.22779715220843041, 0.15371304324695043, 0.217862870278103, 0.13222335066114152, 0.09290007501840591, 0.19477609624820097, 0.10918268987110682, 0.11625656671822071, 0.26257190906575745, 0.22266828242157186, 0.09212946279772691, 0.12352857579077993, 0.15766025786953314, 0.07658705501151936, 0.10980916768312454, 0.1478513963520527, 0.17587367125919887, 0.14486513659358025, 0.1578577115599598, 0.14406457383717808, 0.1108463356005294, 0.20820878259837627, 0.0811621452282582, 0.18813160993158817, 0.10943557987255709, 0.05096712994522282, 0.10761177952268294, 0.1369147824921778, 0.23087257146835327, 0.08560234268328973, 0.19177566867853912, 0.10540163490389075, 0.08382097112813167, 0.24579051669154847, 0.16748680200959953, 0.18190229205148561, 0.10898983664810658, 0.10398605479193584, 0.15542212368122169, 0.13532173154609545, 0.18507447040506772, 0.11000401579907962, 0.12442179928932871, 0.14148610005421297, 0.1621107826275485, 0.14322415393378052, 0.15363414319498198, 0.17408714283789906, 0.1621757319995335, 0.07757667119481734, 0.13699030343975338, 0.07673705196274178, 0.13574223326785223, 0.17026142669575556, 0.10525851151240723, 0.1071379788752113, 0.09491584649575607, 0.1714454295911959, 0.0629608097619244, 0.13730359662856373, 0.1080337061679789, 0.07310769706964493, 0.06702787402485098, 0.13138765336147376, 0.1581644636711904, 0.15503025613725185, 0.13800068279462202, 0.10746301750519446, 0.11384384546961103, 0.11391963783119406, 0.11448858944433075, 0.11598432489803859, 0.14051974405135426, 0.14363139708127293, 0.059726545454135964, 0.07034702984882252, 0.20123604818114213, 0.1269474151943411, 0.11783027941627161, 0.13971067246581825, 0.15273516571947507, 0.14979112440986292, 0.11888226653848376, 0.14099508497331822, 0.2262420313698905, 0.17067394884569304, 0.11885682147528444, 0.12360877862998418, 0.15532817372253963, 0.12281566618808679, 0.07065004323210035, 0.195129802982722, 0.14764451102486678, 0.24328484971608433, 0.140962366014719, 0.1330088363694293, 0.10297158387090478, 0.1749782357364893, 0.1107426622350301, 0.1017006877809763, 0.11854696167366845, 0.14486007472234114, 0.19385909688259872, 0.20705865217106684, 0.07662864242281232, 0.12475616777581827, 0.1353301318096263, 0.056441570831728835, 0.11287537922284432], [0.06973161894295897, 0.014331638380619032, 0.0203080068874572, 0.04009193368256092, 0.0455114200179066, 0.05112946605575936, 0.018504186001207148, 0.019232874935758964, 0.03271182380350573, 0.021057577737207924, 0.024427389592996666, 0.021467787779069374, 0.0580415597983769, 0.04857177580041545, 0.029885141910719018, 0.02910313369440181, 0.06973414309322834, 0.02953524175765259, 0.03265886414530022, 0.019652124760406356, 0.02849616376417024, 0.027866744502846683, 0.021122220072097013, 0.04041863472333976, 0.01348246367914336, 0.04918857091771705, 0.10624615994415113, 0.05534824396350554, 0.04180363326200417, 0.01840122849015253, 0.07585548569581338, 0.022802053950726986, 0.06429202082966055, 0.028081719663792422, 0.05179165855848363, 0.008918059540779462, 0.0759212968072721, 0.01211731568244951, 0.03676263036738549, 0.03702304532219257, 0.01778542233764061, 0.03018723927172167, 0.028689763375691006, 0.0584024182919945, 0.06614039093255997, 0.03079514218760388, 0.03062066708558372, 0.025161807059443424, 0.024152101150580814, 0.03858069370367697, 0.019682529914591993, 0.03885665050308619, 0.029957616236060858, 0.012583087564312985, 0.05895797562386308, 0.01879926391744188, 0.06308057797806603, 0.07105803955346346, 0.04334696116192, 0.020222197652661374, 0.04537996403606875, 0.029808236751705408, 0.0793605533295444, 0.031659256533852646, 0.07800899978194918, 0.02220464966792081, 0.019671810757634894, 0.014013552190070706, 0.050427694605397325, 0.1465809073831354, 0.02149622857437602, 0.0701291658250349, 0.03583977185189724, 0.03232033623914633, 0.05166010079639299, 0.020591790588306527, 0.012848621217666991, 0.024091876078663126, 0.09969564394227096, 0.1773725686860936, 0.2087220400571823, 0.06072122350867305, 0.06741879840514489, 0.08046958489077431, 0.05910742974707058, 0.025572663405910134, 0.024231174228979007, 0.11100129264273814, 0.012871135857754519, 0.04784568226230996, 0.037154134895120344, 0.06811182014644146, 0.042974347049104314, 0.06961765898657696, 0.09796491824090481, 0.02386295871942171, 0.033752900082618, 0.08048926919166531, 0.07990726256476981, 0.047366063177053414, 0.04790141373606665, 0.006620584496496511, 0.014568006054365208, 0.020975054308239902, 0.013763914915866085, 0.01914259754786534, 0.027149918056758385, 0.02336353319697082, 0.016136466891371777, 0.05655601254797407, 0.05684871219896844, 0.0435894933263106, 0.02886376011052302, 0.058465969881841114, 0.019582485015104924, 0.03793496246050511, 0.014507010845201356, 0.031963101122528315, 0.018381396607894982, 0.055919214218322716, 0.004612770538577544, 0.0797150878767882, 0.05213559099606105, 0.05523343583835023, 0.008238580510286348, 0.04398551689726966, 0.046705349880669794, 0.06393416824617557, 0.03525767701544932, 0.025277719500341585, 0.07596336597842829, 0.05037773746464934, 0.026455425590808903, 0.07252649111407143, 0.04705128738922732, 0.02034701925835439, 0.04279853862577251, 0.03771142588396158, 0.04374859621748328, 0.02554179006256163, 0.06068025356424706, 0.02840858694565083, 0.022895020033632005, 0.057930578610726764, 0.0228648998641542, 0.026099554329578365, 0.003965562209486961, 0.05184925600354161, 0.012252853900593306, 0.03733914764598012, 0.05844528813447271, 0.037379398343286345, 0.051000018537576707, 0.06968463717826776, 0.028996719047427177, 0.012467254003110741, 0.029426543840340207, 0.02282084258539336, 0.050016146153211594, 0.058233775198459625, 0.07717510060008083, 0.06529287355286734, 0.02072557564159589, 0.03230442798563412, 0.039335645336125574, 0.020603027128215348, 0.026892476781670536, 0.09655010487352099, 0.014605724119714327, 0.03858701765005078, 0.029255529266915152, 0.06451917399785348, 0.03711251016440136, 0.025418618993301476, 0.03470719173284514, 0.028726129460015466, 0.03515637173716511, 0.03790330880188516, 0.0651264221274427, 0.013136630495344954, 0.043463200995964665, 0.03668791348380702, 0.05918105758194413, 0.014485329955017992, 0.03261692728847265, 0.037373393308371305, 0.018618766817131212, 0.009854085876473358, 0.06553291888641459, 0.06086288804986647, 0.02708068543246814, 0.04216084802257163, 0.009403693838976324, 0.018479246446596723, 0.021785615278141837, 0.018585401553926722, 0.030488152589116777, 0.033859677745827606, 0.02667717931659094, 0.03445247307951961, 0.03838426799380353, 0.03523888498810785, 0.018518976368276135, 0.04963694346536483, 0.0187126777600497, 0.07117093420986619, 0.043581316979335885, 0.051235487152423174, 0.04145832679101399, 0.04768322062279497, 0.047498014489454884, 0.0156685881582754, 0.0033576448747356024, 0.019807003771087954, 0.07985825198037283, 0.05745985172688961, 0.02074396563693881, 0.060102399571665695, 0.07343289854803256, 0.05946352492485728, 0.050039623464856825, 0.06402979418635368, 0.030017249286174774, 0.03552811732515693, 0.09703672304749489, 0.07172092076923166, 0.020050994785768644, 0.036014545509325604, 0.017742576243888055, 0.016483410328094448, 0.04417421409328069, 0.002940767166104966, 0.054120499308087995, 0.00981053410630141, 0.041666969523898194, 0.022012715859870826, 0.028316082266558493, 0.0432980150383498, 0.10744563343801669, 0.031062101612665823, 0.019095573374735456, 0.04613543474780662, 0.014834042671801788, 0.062216843611427715, 0.017090163127120053, 0.027232317653085505, 0.02668696888057249, 0.01234193961136043, 0.05115286872855254, 0.02220090076194278, 0.016644528468272517, 0.02646214817650616, 0.017846415850466917, 0.052102905964212756, 0.17517978777842863, 0.3019029200077057, 0.20104022297476018, 0.08799493179789611, 0.33356615954211777, 0.26840220764279366, 0.028783160328332866, 0.05899884378803628, 0.0727807856830103, 0.07327686263514416, 0.06429859583399125, 0.03508864037160363, 0.10997424168246132, 0.04414031109107392, 0.03807280006419335, 0.02905024867504835, 0.07026905938982964, 0.038028868314410956, 0.0491827185531812, 0.09236043611807482, 0.11797062759952885, 0.01945343443990818, 0.09367428347468376, 0.038916958695543666, 0.05657496403104492, 0.07838441963706698, 0.08621572476944753, 0.06929999603224651, 0.049830308982304165, 0.03366004256531596, 0.0543869226904852, 0.05640853974702103, 0.02416694749678884, 0.019451239379122853, 0.0570125953693475, 0.016104043095505664, 0.05039071783955608, 0.033433964875127585, 0.009727819839359393, 0.03668872094047921, 0.11970946857971804, 0.08849892046834741, 0.020696812542155385, 0.072056008502841, 0.04360554746485182, 0.02478143898770213, 0.03594736036445413, 0.02682714064472488, 0.009911534043827226, 0.04912784542622311, 0.08160304371267557, 0.011764882049257202, 0.07843524190996375, 0.03217537741043738, 0.04998803784006408, 0.020553582281406437, 0.030472990724125078, 0.09006935584225825, 0.06976950833840029, 0.01632908941246569, 0.11361959643129792, 0.008384149172343314, 0.04826072516984173, 0.03657129706282701, 0.060810912267438004, 0.01909205347432622, 0.05641907061051045, 0.0355098070576787, 0.032490543355899196, 0.0321438391027706, 0.060912455032978735, 0.04489248072994607, 0.046726683021656105, 0.012264969991520047, 0.03158542174579842, 0.006592867613237883, 0.04229744390717574, 0.06159617405916963, 0.06506168310131345, 0.020986594492569566, 0.033964345165129216, 0.04136720632335969, 0.12705779927117483, 0.023196635634771416, 0.043315036089292595, 0.0031755415548104793, 0.04063342159081783, 0.08939989283680916, 0.04394730180501938, 0.021148058685607145, 0.020141224676210965, 0.0650449368570532, 0.013235353099714433, 0.061685150356165, 0.024817387772990123, 0.046654022099184136, 0.024977118309055055, 0.01581824414565095, 0.11005923497889723, 0.12755292627428258, 0.13588875611977919, 0.08365720670138087, 0.1645682600459882, 0.1480447652616671, 0.12650743951754911, 0.08390810859522649, 0.1008687699213624, 0.06669867597520351, 0.050302542213882716, 0.12827297406537191, 0.1663455603910344, 0.13886831195226737, 0.08659022860229015, 0.1498270867658513, 0.13795978070369788, 0.13209794381899492, 0.1854786058621747, 0.1345028347734894, 0.09095244202762842, 0.1285318351749863, 0.07746222947857209, 0.10987049367810998, 0.1822731521512781, 0.19601417838462762, 0.13608025227274212, 0.148427866133196, 0.09071023895272187, 0.11587949123765741, 0.10977397207170725, 0.16766476817429066, 0.12626457826367446, 0.10915060195007495, 0.14356450709913457, 0.1413792036473751, 0.1075048152623432, 0.09350749956709997, 0.13590690014617784, 0.11217620995427881, 0.0686213049505438, 0.2657559210700648, 0.11887017504445144, 0.136498718389443, 0.20035380337919506, 0.13382467973445142, 0.07424773768122707, 0.052594019432685206, 0.1376927907445601, 0.14315509263958248, 0.1161200183310679, 0.11637673527002335, 0.08987411417599235, 0.04547882658828582, 0.11649636099381105, 0.12763900522674831, 0.10680069268814155, 0.1021967918745109, 0.14333403589470045, 0.08780460272516523, 0.1014281270493354, 0.13811948070568697, 0.14686784627182142, 0.09164611516254288, 0.1635953222534486, 0.12454850891871111, 0.1309182835476739, 0.09798743881817375, 0.16683877392538957, 0.24259635380336217, 0.09637336685721364, 0.17135928278522833, 0.10504331413124289, 0.19630133440451963, 0.25920675535287174, 0.10994967192943607, 0.18245080618986062, 0.22708213914717945, 0.24351671870265687, 0.4236639934991087, 0.41225491570574896, 0.23195220210722514, 0.5540704716529165, 0.36191296417798313, 0.3612276166677475, 0.18643335891621454, 0.19892598928085395, 0.17372760070221765, 0.17211432941257954, 0.20334412077707903, 0.0943850421213678, 0.17354169567780836, 0.2414244966847556, 0.13328822994870798, 0.19973302526133402, 0.15937511942216329, 0.12552488009844506, 0.18368257795061382, 0.25804439772452625, 0.12809840057577404, 0.24639606848359108, 0.1374761616545064, 0.17523681186139584, 0.1654600721916982, 0.1656974780240229, 0.09810928335147244, 0.11677154765597411, 0.17500480716781958, 0.11327597272715398, 0.1075682243598359, 0.13189249698604855, 0.09933842239635331, 0.11323291289487056, 0.1308476480522326, 0.11804617568850517, 0.11816557071038655, 0.11082021200231143, 0.07913392941866602, 0.11907034287495272, 0.13922683628542082, 0.037537005064742904, 0.21817716769874096, 0.11603760346770287, 0.15098784305155277, 0.07452245615422726, 0.11038056202232838, 0.08302024552332503, 0.14369064675910131, 0.18231303643967423, 0.1279714195323842, 0.16550049930810928, 0.1412536475275244, 0.19344673758106573, 0.1087437727089439, 0.14092155891869748, 0.13635256194642612, 0.1475166750273534, 0.13944090051310404, 0.1725536808371544, 0.14729186280497483, 0.13948849295931204, 0.10893646308353969, 0.11781873075025422, 0.1635082797812564, 0.12023479039115564, 0.12013682350516319, 0.09633844265980379, 0.189177327390228, 0.13580794259905815, 0.16083413256066187, 0.12963731799806866, 0.10224588388311011, 0.09848750555621726, 0.14925886797053473, 0.14843395937766346, 0.11088133443679128, 0.15128323648657116, 0.19343778091881955, 0.07838437892496586, 0.1393407080322504, 0.23575704651219503, 0.22327387492571557, 0.14434379099735192, 0.10408378419067178, 0.1093415959871241, 0.21624685770698956, 0.10470238421112299, 0.20082904930625642, 0.16658551751502923, 0.1560836410416024, 0.15984683696712765, 0.17448807560971805, 0.110587182720857, 0.13716679039810384, 0.09046416144285883, 0.1500876306423119], [0.028015757578292062, 0.0036123168787785937, 0.030202407922063555, 0.04173393075221351, 0.03407115675508976, 0.04519868322781154, 0.02735766003440533, 0.01134532518751387, 0.017877021172483052, 0.007411280929643128, 0.06069079799843686, 0.0673434403059738, 0.07369403274995939, 0.06756942639393465, 0.07155011993433748, 0.021170769252681305, 0.024573785219607607, 0.027069516746061187, 0.03594181673335178, 0.05286646142069783, 0.009487103604312454, 0.015191674731405718, 0.025090968003496528, 0.03425566739003573, 0.0549378049160753, 0.0875284525432757, 0.04173520639804857, 0.030712255742400885, 0.02624677267989942, 0.06087459956428834, 0.03858272930873292, 0.04351748040478144, 0.04039143903979233, 0.014431673102080822, 0.054055512616676946, 0.040981900213020186, 0.03837267861568502, 0.034026906093848605, 0.05485695068325315, 0.04840575524472764, 0.0242059513859983, 0.02322615190808262, 0.06094181524323566, 0.025876843869420033, 0.014360052034524935, 0.02803583034048123, 0.047901739432875595, 0.04644804600892322, 0.01458383458001273, 0.01587424872975264, 0.02010047186299094, 0.023036106123722026, 0.01199994863210512, 0.053143514054162164, 0.03281390600438629, 0.033307428272174935, 0.0580134955900056, 0.021152616744594913, 0.07395121787807771, 0.04146781949592488, 0.02118778521461146, 0.03553744039631315, 0.02213452985909368, 0.03971126535907388, 0.021600397270438925, 0.01859711646102369, 0.031349752963121445, 0.023137335066816637, 0.022884097316169312, 0.00428801858963977, 0.02731787074091179, 0.14048275032213756, 0.04304892822567906, 0.13859480805695057, 0.02565396547184459, 0.21909669121461256, 1.3145384852375304, 2.7249139079025815, 2.999411395617894, 5.21553065095629, 3.744622196469988, 3.982218018599919, 7.24085932118552, 5.3790786521775384, 2.0700492305415015, 4.226042466504233, 2.0908727645874023, 0.12870482089264051, 0.11346649178969008, 0.1074377963585513, 0.02880788275173732, 0.044532823243311474, 0.09967916911201817, 0.075004629923829, 0.0432109114980059, 0.07072879400636468, 0.041094126512429545, 0.018964570315022553, 0.13837832824460097, 0.2896218161497797, 0.7853305680411202, 0.31945021556956427, 0.0994503806744303, 0.06545292639306613, 0.04579139713730131, 0.013269737013615668, 0.011903814638831785, 0.03560769251946892, 0.049319606207843335, 0.09071603364178113, 0.02803185412527195, 0.057654455570237975, 0.04663756762498191, 0.03417709982022643, 0.01978699377338801, 0.024509439743789177, 0.05428705929911562, 0.018440452903243046, 0.022830723751602427, 0.004259233437811157, 0.039433130462254794, 0.016156515904835293, 0.017829096244115914, 0.04848532026101436, 0.013812670201462294, 0.025463761928092157, 0.0768806706847889, 0.046908723789134195, 0.0021037912520114332, 0.03205846582672425, 0.05249630021197455, 0.02034818464224892, 0.03955399111977645, 0.03838446816163404, 0.05490073315533144, 0.04967652241300259, 0.0637355949729681, 0.033434565378619094, 0.03188736982909696, 0.0023647719353903085, 0.012226988145682429, 0.004693598902252103, 0.08990947942116431, 0.0387981098943523, 0.09776017029902764, 0.003236170779148649, 0.030028886161744595, 0.04546128645805376, 0.10522694606333971, 0.028504604739802222, 0.049534891798560104, 0.02268770044403417, 0.011064809480948108, 0.0439267082672034, 0.004979547977979694, 0.019974394967513423, 0.020716786916766847, 0.05055922522608723, 0.09319092226879937, 0.019467222271487117, 0.03474631266934531, 0.01913313876970538, 0.0421880742401949, 0.052276400583130975, 0.01612198186506118, 0.037429569222565205, 0.020059278002008796, 0.016003947305892195, 0.06387865051094975, 0.05464094245274152, 0.003042124818810927, 0.06965489698840038, 0.031920356809028556, 0.02488207590899297, 0.03555750467681459, 0.02958244065354977, 0.08814684221787111, 0.04386210155540279, 0.05645031375544412, 0.012202771230866867, 0.05358557961881161, 0.08819136090044465, 0.052544554229825735, 0.053868715318718126, 0.025377447184707438, 0.033241481453712494, 0.05178063575710569, 0.11993608570524625, 0.03194937775177615, 0.03145747718268207, 0.0029138233886832105, 0.04387827443757227, 0.037033006216266325, 0.0674390255340508, 0.03936417094830956, 0.0440107991120645, 0.03203893419621246, 0.03735781414434314, 0.03821455281493919, 0.0006569361357833259, 0.040649163603250466, 0.026126850097041045, 0.04002719126375658, 0.07044859297041382, 0.03369266313633748, 0.03321374294215015, 0.02876589839745845, 0.03152462500812752, 0.055026879600648365, 0.022619485622271895, 0.010675564474825348, 0.024192172036107098, 0.017439746065065265, 0.041060919008616886, 0.018079580838925073, 0.05282250592218978, 0.034697325833673985, 0.024707543131496226, 0.05666326857837183, 0.05735791541103806, 0.07620628830045462, 0.027090637844854167, 0.057883216866425106, 0.02987063143934522, 0.0724024549126625, 0.04260159044393471, 0.025193184215043272, 0.03833629217531, 0.0032446121788650218, 0.0786304021520274, 0.039122290177536864, 0.06544014957866498, 0.014984389068558812, 0.01647501515357622, 0.03250269931075828, 0.01840038371405431, 0.06800871675035783, 0.049010818491556814, 0.06562032776751689, 0.04434161546773144, 0.06320029869675636, 0.020393587116684233, 0.012541942048950918, 0.057983653619885445, 0.03230385123086827, 0.08447394573262759, 0.04838254256173968, 0.15828551431851728, 0.058394995118890486, 0.09072831512561866, 0.22416836049939903, 0.6688365819198745, 1.9367085226944514, 3.614921041897365, 5.168503940105438, 7.871678454535348, 5.71798746074949, 6.05787205696106, 10.84998209135873, 8.99668994971684, 4.046197031225477, 6.272608305726733, 3.8943063701902116, 0.9431597675595964, 0.23021811087216648, 0.11849987134337425, 0.0602568205712097, 0.13177204344953808, 0.030450490502906696, 0.08589371919099774, 0.0534296522715262, 0.0742387335215296, 0.021175211960715905, 0.08673772854464394, 0.09102145582437515, 0.30936362966895103, 1.105267537491662, 0.4745913307581629, 0.3104507513344288, 0.068962390933718, 0.07306500364627157, 0.00921701019563313, 0.07199964259884187, 0.050431324767747095, 0.035613273469997306, 0.027650057737316405, 0.01512541069782206, 0.03329764718988112, 0.039038589490311484, 0.07526521451239075, 0.09025275707244873, 0.02156214146608753, 0.055352522126798115, 0.01688328797795943, 0.074594272300601, 0.05287151989926185, 0.0687623316688197, 0.011193071259185672, 0.026963541450511132, 0.01232952157235039, 0.057353823844875605, 0.021353741309472492, 0.022384298599458168, 0.032369957505060096, 0.014444604283198714, 0.03493333727653537, 0.11622333207300731, 0.03928810378004398, 0.04521256944696818, 0.05531218321993947, 0.038420586580676694, 0.027037654437923005, 0.030058806163391898, 0.07211626919784717, 0.042742003088018725, 0.05855089532477515, 0.022529598392013992, 0.02807858822468136, 0.0424004319523062, 0.021522224947277988, 0.060699042198913436, 0.029453658099685396, 0.05056205810979009, 0.010135657553161894, 0.03034379765657442, 0.00428057972541345, 0.07187476501400981, 0.09612887711929423, 0.12290954829326697, 0.07874569882239614, 0.03145190980285406, 0.03824324466820274, 0.026096950451444303, 0.058943651749619415, 0.07420264902923789, 0.011011305298390133, 0.04979959509468504, 0.026465254170554023, 0.02477792926531817, 0.040126158988901546, 0.04032750068498509, 0.022076287805767994, 0.023344239053715552, 0.03562923600631101, 0.040234609240932126, 0.055803673275347264, 0.02987168656129922, 0.02401990895824773, 0.03922698473823922, 0.05948501412889787, 0.03572308418474027, 0.024558097489976456, 0.14743195314492497, 0.1538759595049279, 0.13867473948214734, 0.224532869511417, 0.10835417825728655, 0.18497068168861525, 0.10862338024058513, 0.1450167213167463, 0.10132122385714736, 0.13012842807386601, 0.14659488520451955, 0.12997691120420182, 0.13201102348310606, 0.20596099964209966, 0.11918976503823485, 0.15130819300455706, 0.10452018398791552, 0.10856971490596022, 0.13415188289114408, 0.1403055034045662, 0.12381965374307972, 0.12752720979707582, 0.05687417422554322, 0.14025776168065412, 0.1485354003629514, 0.12832030866827282, 0.09293578631643738, 0.12804850111050264, 0.10341142384069306, 0.1535376419446298, 0.08087966431464468, 0.2527833357453346, 0.1137865771140371, 0.08145519771746226, 0.20336620030658586, 0.26150028514010565, 0.09731267645422902, 0.10614369437098503, 0.13839820932064736, 0.13354981876909733, 0.21132680028676987, 0.12213348065103803, 0.13171016105583735, 0.12657838713909897, 0.15287498464541777, 0.10102749961827483, 0.1442418343254498, 0.10566804810826268, 0.13085037576300756, 0.14900538085826806, 0.13003040690507206, 0.16562150924333505, 0.07541715885911669, 0.21636298219008104, 0.13908521245632852, 0.18226296055529798, 0.128979695428695, 0.15663117808955057, 0.13812661889408315, 0.1485116516372987, 0.16148799604603223, 0.12901682486491545, 0.12166724566902433, 0.12286889047494956, 0.08019878835018192, 0.09447418805211782, 0.12473412895841257, 0.20523223946137087, 0.18367393341447624, 0.1287178894770997, 0.2132184744945594, 0.14997378603688308, 0.18178379269582884, 0.25682862581951277, 0.5023267482008252, 0.8689443756427083, 2.1744487370763506, 4.087864075388227, 7.154152750968933, 9.014284525598798, 8.392573612076895, 8.164410403796605, 13.237300617354256, 10.657847898347036, 5.522175933633532, 7.389324086053031, 5.248482917036329, 1.2398169061967304, 0.45707910188606804, 0.3522055707871914, 0.1847020225333316, 0.17556260366524967, 0.30140862081732067, 0.15984314573662622, 0.1569119015974658, 0.20157853194645473, 0.11563700996339321, 0.1996266988239118, 0.2770293732838971, 0.7777877013598169, 1.6491882652044296, 0.6152426834617342, 0.568445697426796, 0.15051635620849474, 0.13397923644099916, 0.12162392799343381, 0.11959605823670115, 0.12534852884709835, 0.09899416086929184, 0.14622312943850244, 0.10724027481462274, 0.19540881658239023, 0.09773722224469696, 0.13391753046640328, 0.16652835772505828, 0.1350727363356522, 0.14958426622407778, 0.12784426206988947, 0.12626408971846104, 0.071748659280794, 0.20571313079978737, 0.05440315664080637, 0.0835734008412276, 0.18183294577257975, 0.12794393886412891, 0.08401275226580245, 0.15059346492801393, 0.08679927845618554, 0.09636949242225715, 0.15602486633828708, 0.19797768230949128, 0.13469138608447143, 0.09892818012407847, 0.180826637627823, 0.1320833960281951, 0.12043033061282975, 0.09559832380286284, 0.16967613595936978, 0.18223887256213597, 0.1066980031984193, 0.09105723497590848, 0.11536391318908759, 0.13984344819826738, 0.1676993870309421, 0.15886186196335725, 0.09664163246218647, 0.1423681548663548, 0.12290243724627153, 0.2036048410726445, 0.07099503757698195, 0.2529074533709458, 0.2698520469878401, 0.2458042230989252, 0.1430836429021188, 0.13890754484704562, 0.1035442945680448, 0.09261534815388066, 0.2355008859719549, 0.24357211430157932, 0.06562924371766192, 0.20574935099908284, 0.12607708546732152, 0.09020517141159091, 0.12438838822501046, 0.1378827126962798, 0.11913727356919221, 0.10240305294947964, 0.14589498990348407, 0.12365429475903511, 0.14827820844948292, 0.14085176480667932, 0.11986159613089901, 0.15157945773431233, 0.20940172858536243, 0.1519953589886427, 0.06685414870402642], [0.046345607577157874, 0.05348457968128579, 0.03460339283836739, 0.019600467889436653, 0.021108608659622923, 0.0123819536695789, 0.030151402444711754, 0.04668153669419033, 0.05880993963884456, 0.025504908291622996, 0.03897555358707905, 0.039541580714285374, 0.04729089506768754, 0.024094498616510203, 0.04267696550648127, 0.04802480872188296, 0.015146056822101985, 0.04163818946108222, 0.03298895446849721, 0.046355375088751316, 0.0685392836374896, 0.08659446266080652, 0.10986927231507641, 0.03662381906594549, 0.023411982293639864, 0.051541665901563, 0.028805219501789128, 0.010033946002035268, 0.007450328075460025, 0.056461397624973736, 0.04159102449193597, 0.03140143019014171, 0.023915831864412342, 0.006429579433253301, 0.06201455196631806, 0.05912319890090397, 0.08985255711844989, 0.029936194885522127, 0.01050788744552327, 0.032471927747662575, 0.021241593041590283, 0.012249477340706756, 0.07005059825522558, 0.023153435006471615, 0.018194996252922074, 0.0038243276898616125, 0.03222623700276017, 0.0327087737885969, 0.0272181379675333, 0.01680440149669136, 0.04424859510202493, 0.0035548140045388466, 0.022401742038450072, 0.08626590243407659, 0.044858408093984635, 0.041724363408450565, 0.08685500653726713, 0.011208179689544653, 0.017191285200949227, 0.07422890154910938, 0.023940216716645018, 0.014837141880499465, 0.018799138388463428, 0.0395206343382597, 0.04452777494277273, 0.032648699690720866, 0.052539709489792585, 0.16228139347263745, 0.10047237654881817, 0.09012243085141693, 0.5249337436897414, 0.40981064257877214, 0.6944411279899734, 3.6203521447522298, 6.828097241265433, 10.113814370972769, 14.321147509983607, 19.08189163889204, 23.172471591404506, 27.732642071587698, 24.4638637815203, 28.412108148847306, 35.29622003010341, 29.46535083225795, 31.559572628566197, 24.93890517098563, 20.762108496257238, 14.11267375946045, 7.5916643142700195, 6.371465103966849, 3.624511727264949, 3.0994296286787306, 1.1679441971438271, 1.7709600052663257, 2.1356130838394165, 1.056720148239817, 1.4704482448952538, 2.5268492102622986, 4.278477481433323, 6.639359414577484, 4.935487415109362, 6.819197033132825, 5.836614055292947, 3.6244641755308424, 1.8160021368946349, 0.5179877164108413, 0.08854145104331629, 0.10855417645403317, 0.052922057187450786, 0.03266441456175276, 0.0474305307891752, 0.09712438977190427, 0.04252421370308314, 0.06357247515448503, 0.06010569725185633, 0.03842908523178526, 0.025514638483790413, 0.05707105116120406, 0.022394420645598854, 0.01657325854258878, 0.06678837830466883, 0.028233272156545093, 0.08837924724710838, 0.042263557868344445, 0.06308618267732007, 0.025194922961028557, 0.05319245678505727, 0.030692435734506165, 0.008706705212326986, 0.018571571313909123, 0.014407267893797584, 0.0073263376751648525, 0.04515576249520693, 0.04030158743262291, 0.08658219474766936, 0.01399357951179679, 0.015200748440942593, 0.10344896718327488, 0.046482006686606576, 0.012730286406752254, 0.0461112449743918, 0.04497855289706162, 0.027426114039761678, 0.02377581616331424, 0.026999173020677905, 0.05361186606543405, 0.06249862563397203, 0.03474276053852268, 0.0863676555454731, 0.04143391649371811, 0.052610233026955805, 0.02323723747394979, 0.05810002916093383, 0.06476618110069207, 0.010294381312892904, 0.05318505396800382, 0.07350931516183273, 0.030963907417442118, 0.03311037152473416, 0.029011385581855263, 0.008701982608597194, 0.03863762618441667, 0.049457443811531575, 0.026137908521507467, 0.03418920488495912, 0.039633868262171745, 0.04988860871110644, 0.06806745752692223, 0.0808336596403803, 0.03528159537485667, 0.022837985772639513, 0.014209230663254857, 0.017676168021612933, 0.03828098139326487, 0.01711198142064469, 0.05450169688888958, 0.006154601420608482, 0.03443328071651714, 0.011041477206163108, 0.023565919836983085, 0.037488520344985385, 0.051178283257676024, 0.04652349231764674, 0.057087844902915616, 0.09408728059913431, 0.026073167799040675, 0.013820691333551492, 0.058281293005815575, 0.061700213833578994, 0.03825295789699469, 0.06111572376851525, 0.02016838134399482, 0.01801152547289218, 0.06421758553811482, 0.0718337068600314, 0.058287033412073336, 0.058928405067750385, 0.0598823574504682, 0.06391875871590205, 0.03438381212098258, 0.03904998209327459, 0.04753949333514486, 0.016879018296354582, 0.021797778018351113, 0.06389312366289751, 0.11382975908262388, 0.11175032066447393, 0.037506080831268, 0.02527848963758775, 0.04809710323544485, 0.0428631555155984, 0.05858285432415349, 0.05754027169729982, 0.02705871107588921, 0.011577095786508704, 0.013623532805857914, 0.030494401896638528, 0.05212916526943445, 0.010262185674426811, 0.020574966312519143, 0.03418176814115473, 0.05179118697664567, 0.024724487847249423, 0.01128169386980257, 0.022836051947836365, 0.04318001440593174, 0.034072585071304014, 0.060521598506186686, 0.028944980752255236, 0.06376407308770077, 0.02176929311826825, 0.07880613593650715, 0.015366672305390239, 0.05774708917098386, 0.018196051374876072, 0.04024395266813891, 0.06617139319756202, 0.06892953626811504, 0.038475344356681616, 0.0344838044340057, 0.06562196303691183, 0.06124916446528264, 0.10772413813642093, 0.125675623438188, 0.09474154442016568, 0.12368381103234631, 0.5881527970944131, 0.4049692137965134, 1.3708695939608981, 6.105312619890485, 10.160505396979195, 15.975256511143275, 20.62034092630659, 27.294731855392456, 30.587269510541642, 37.31531095504761, 32.931991236550466, 36.50748559406826, 44.597203731536865, 38.127798557281494, 40.76051616668701, 32.134334564208984, 27.251607860837662, 20.4274537222726, 11.088250585964747, 8.750261664390564, 5.278322824410029, 4.162814727851322, 1.3708463609218597, 2.2214281133243015, 2.826535654919488, 1.7161669454404285, 2.3617511093616486, 3.645447083881923, 5.362175856317792, 8.821389504841395, 6.48505425453186, 8.21733135836465, 7.713023287909372, 4.935181260108948, 2.8235320789473395, 0.9991621396371296, 0.09577623568475246, 0.16776167654565402, 0.04739382204466632, 0.05383287849170821, 0.018100259193618382, 0.04776598493169461, 0.08800531338368144, 0.03941065738243716, 0.0645903048238584, 0.048575592559895346, 0.03671771813450115, 0.018887522663655024, 0.07066866223301206, 0.01266582218730556, 0.06576457752713136, 0.046249554159918, 0.11994128328348909, 0.0442472041052367, 0.02727045301747109, 0.03015153475904039, 0.03349577941532646, 0.03158084163442254, 0.028035221355301992, 0.03318943103243198, 0.023038238420018127, 0.05620424981628146, 0.037405192852020264, 0.03110004189823355, 0.04082495167053171, 0.0131705945657034, 0.046159281861037016, 0.03524746845609375, 0.015010002069175243, 0.04748513589480093, 0.034870508326483626, 0.052651650804494105, 0.07183266870145287, 0.038579116109758615, 0.03303125434155975, 0.04860734121341791, 0.03424345375970006, 0.05819062715662377, 0.02440930493841214, 0.05265098923285093, 0.05555035579683525, 0.07087351195514202, 0.04283523379958101, 0.05686831846833229, 0.01372490678581276, 0.06729846700493779, 0.007721653873366969, 0.003458338199249868, 0.034712067006954124, 0.07526811185692038, 0.03748880532969322, 0.036623052321374416, 0.029026052116283348, 0.04561716291521277, 0.05990639116082873, 0.03620473887505276, 0.07116486810679946, 0.060734136030077934, 0.06621751322277955, 0.09077704751065799, 0.06466132708426033, 0.05094589179913912, 0.031973014519150765, 0.028651673812419176, 0.06357112486979791, 0.05413231599543776, 0.11083577081028904, 0.14211335139615194, 0.15148531778582505, 0.20992984596107686, 0.18150709968592438, 0.1404215328927551, 0.12532441371253558, 0.13165981375745364, 0.19148579851857253, 0.17236324319882051, 0.19224932683365686, 0.1868342509759324, 0.3190528654626438, 0.08111170972032206, 0.151429827192, 0.19840750710240432, 0.1560452359595469, 0.1962781963603837, 0.24900218578321592, 0.21174802125564643, 0.2731582224369049, 0.1805357632360288, 0.18959637704704488, 0.11637784806745392, 0.11642848035054547, 0.12661751146827424, 0.09831026542399611, 0.1155789273657969, 0.15651335726891244, 0.1444214154034853, 0.25806841786418644, 0.11942189186811447, 0.1449799718601363, 0.10622095236820833, 0.18360086876366818, 0.15109894637550625, 0.16304969867425306, 0.10148580931127071, 0.10509531026972191, 0.11695833477590765, 0.09760669924850975, 0.17451091509844574, 0.10848419913755995, 0.12892279348203114, 0.10852164748523917, 0.15450387581118516, 0.11440780306501047, 0.13693931831845216, 0.12423261015542916, 0.11771943393562521, 0.125163858756423, 0.18236547362591538, 0.09708520437457732, 0.14666617209357874, 0.07162003618265901, 0.2110703004790204, 0.26106683697019306, 0.18044983356126718, 0.1015135749642338, 0.35370575743062155, 0.12989265072558606, 0.256057077220508, 0.05988787394016981, 0.1116620364731976, 0.183201238779085, 0.19007920899561473, 0.12785726280084678, 0.24521145490663393, 0.11946142331830092, 0.29846768719809397, 0.8004495224782399, 0.8439940458961895, 2.073140961783273, 7.357206038066319, 12.270493524415151, 19.028541633061, 23.76960151536124, 33.5608275277274, 36.18503359385899, 43.11746324811663, 39.205589226314, 42.90824604034424, 54.37733173370361, 46.68824325289045, 48.20289496013096, 39.5000365121024, 32.49461950574602, 24.615393570491246, 13.28693073136466, 10.589263098580496, 6.538064232894352, 5.065769612789154, 2.8365714592593054, 3.353010433060782, 4.142888162817274, 2.8453895917960574, 3.9202743938991, 5.095941296645573, 7.173787491662162, 10.733399135725838, 9.672851290021624, 11.13125124999455, 10.396909168788365, 6.925837550844465, 3.9649669442858015, 1.1532042452267237, 0.2130562774837017, 0.35521595925092697, 0.15012310445308685, 0.15721565458391393, 0.10735632465886218, 0.19668241324169294, 0.1713783224778516, 0.1270194077598197, 0.2431571494255747, 0.11098368465900421, 0.12240009063056537, 0.15521500765212945, 0.14174175847853931, 0.13432056669678005, 0.1510667431035212, 0.1923431275146348, 0.1887410700853382, 0.15177521508719238, 0.14739650647555078, 0.1342791896313429, 0.08363265730440617, 0.16268746953989777, 0.15336458837347372, 0.13042789271899632, 0.11181541252881289, 0.152162672153541, 0.1334075571170875, 0.1550255606749228, 0.18180136675281183, 0.11599763775510447, 0.1286611096667392, 0.21132192840533598, 0.14666946977376938, 0.1792326503034149, 0.08390023080365998, 0.18689436917858465, 0.17333761948559964, 0.08247812997017588, 0.11461565191192286, 0.14577863471848623, 0.1996741827045168, 0.09982438917670931, 0.2384139182312148, 0.11811103006558758, 0.18633266431944712, 0.2937909795769623, 0.1536514051258564, 0.22024379537573882, 0.08623258636466094, 0.1409969034471682, 0.14932080464703695, 0.09268228563347033, 0.09384074847080878, 0.11958034336566925, 0.10867388360202312, 0.1799728912966592, 0.13827272105429853, 0.1916019772844655, 0.09451486622648579, 0.17665937409869262, 0.15095834034894193, 0.25774434953927994, 0.15062266907521657, 0.15645752740757807, 0.15875120647251606, 0.09356693923473358, 0.11619049097810473, 0.11725997073309762, 0.0933518097070711, 0.16870435167636189], [0.060047811429415426, 0.04316534447882857, 0.030683458716209446, 0.03432001286585416, 0.02051164542457887, 0.060448961332440376, 0.007955663637923343, 0.005145072779019496, 0.08497108798474073, 0.038873199972191026, 0.06483497776623283, 0.07204895852399723, 0.029767548399312154, 0.05536514627082007, 0.07470901935760464, 0.04325640048565609, 0.0616524178268654, 0.03499067009293607, 0.0782544801809958, 0.03703992048810635, 0.05514146041657243, 0.073056650880192, 0.025970050832256675, 0.0332043791588928, 0.07823571190237999, 0.049393932933786085, 0.024453297756346207, 0.0893383157838668, 0.08937358603413616, 0.012896780240615564, 0.14460395489420208, 0.07109072458531175, 0.08486953164849963, 0.03642608717616115, 0.04546297601025019, 0.03895650710910559, 0.03719046026734369, 0.01445222762413323, 0.06248904471950872, 0.06196845908250127, 0.024882499993379627, 0.015555452621941055, 0.07005489338189363, 0.004905596566719136, 0.05565628868394664, 0.046108357807887454, 0.012650294761572565, 0.023478879061128412, 0.04325996957985418, 0.07246741106999771, 0.05648058659530111, 0.03876401350966521, 0.015889658260026147, 0.012349759727450354, 0.036538323653595786, 0.013758030320916857, 0.016181794726955037, 0.0397355535200664, 0.03889400385586279, 0.01011930316287492, 0.007761382946877607, 0.03360792089785848, 0.060003062044935565, 0.08362255391797849, 0.030698322025792937, 0.047276645832295926, 0.04727852198162249, 0.11068870513034718, 0.21390855817922524, 1.4343510504279817, 5.492913595267704, 9.013477666037423, 15.785551582063947, 32.14414194652012, 36.40086201259068, 46.74570138113839, 52.951759406498496, 53.274034227643696, 58.648410252162385, 57.69297041211809, 55.20104415076119, 57.321297373090474, 67.83322702135358, 59.667099543980186, 65.41166169302804, 56.13537188938686, 55.392282894679475, 49.64724131992885, 39.8631945337568, 30.495841639382498, 28.411611352648052, 23.55428031512669, 20.240797315325054, 13.087313328470502, 17.29548372541155, 21.675042731421335, 22.142152752195084, 19.683701174599783, 19.523190838950022, 28.649112939834595, 26.287870134626115, 27.468989201954432, 27.644724777766637, 20.204074348722184, 14.751619679587227, 8.134298648153033, 1.8587475631918227, 0.1312854659876653, 0.0671719473653606, 0.09793321708483355, 0.03931240211906178, 0.011074538824946752, 0.012129625155856567, 0.00876406517012843, 0.02003828073585672, 0.009194046026095748, 0.032029848612312756, 0.03802494977467826, 0.044681419019720385, 0.01337853416667453, 0.02724361865382109, 0.012939564418047667, 0.06701543647795916, 0.04510786810091563, 0.05067208595573902, 0.09074904437043838, 0.01683496101759374, 0.018444690354434506, 0.04545085737481713, 0.016921906798545803, 0.09003495411681277, 0.046046807896345854, 0.038470367302319834, 0.03872911984633122, 0.07023205887526274, 0.050190088605242114, 0.010634536854922771, 0.045024381152221134, 0.06687997374683619, 0.024957722385546992, 0.053432061070842404, 0.03802185904766832, 0.07830502425453492, 0.03488298997815166, 0.045817344316414425, 0.03934383525380066, 0.025402103450947573, 0.014662612495677812, 0.02595778800813215, 0.09069533153836216, 0.04082358781514423, 0.024127787544525096, 0.04056298965588212, 0.08076347876340151, 0.020857833991093293, 0.04053432494401932, 0.01528518703500075, 0.040866043751261065, 0.03742746237133231, 0.027393045635627847, 0.08233493193984032, 0.059206061597381315, 0.0449741967022419, 0.04765958724809544, 0.013713537083406533, 0.07436641345598868, 0.04462871720482196, 0.06774259531604392, 0.04492356102647526, 0.060664715112320015, 0.011220913247338362, 0.02889215001570327, 0.06832355021366052, 0.043927468226424286, 0.08005133590527944, 0.04136795949723039, 0.05567407647946051, 0.09282310200589043, 0.07622369272368294, 0.07971662136593036, 0.07538163755089045, 0.04452158670340266, 0.08449189298387084, 0.05894846934825182, 0.11021370347589254, 0.02715069497935474, 0.0331844980828464, 0.08058573651526656, 0.032517654222569296, 0.026729862471776347, 0.08069529277937752, 0.09502771656428065, 0.08760841110987322, 0.009903519697088217, 0.03797793747591121, 0.02117044185953481, 0.0345686993428639, 0.01777831298698272, 0.012228469048360628, 0.028449176910466382, 0.04033058462664485, 0.031822773295321634, 0.07231484247105462, 0.05221737821453384, 0.04621645182903324, 0.021633402910083532, 0.03557717540700521, 0.07953478076628276, 0.10882166174373456, 0.021920107704188143, 0.08130569609680346, 0.022313488381249563, 0.03391352289223245, 0.0494958862130131, 0.055206511568810256, 0.06757914980075189, 0.046364894935062954, 0.06005509211016553, 0.0712296614157302, 0.050156660577548404, 0.03491086758939283, 0.011538914621009358, 0.017509117789034332, 0.0430540749137955, 0.009363918116183152, 0.03486403510240572, 0.00624814722687006, 0.03604118479415774, 0.03692985871540649, 0.022022274721946036, 0.008539278392813035, 0.014850994172905172, 0.048977539741567204, 0.025850382700030292, 0.0438910648226738, 0.009975005905809147, 0.03724895677130137, 0.02387586106280131, 0.12351075746119022, 0.10332689873342003, 0.033368991754416905, 0.051790467729525905, 0.0490145911462605, 0.3471969509763377, 0.6339012565357345, 3.1022267128740038, 7.205718372549329, 13.443880115236555, 21.919115577425274, 40.4807573727199, 45.41753237588065, 60.02923270634243, 65.56312547411237, 64.98131806509835, 70.33806650979179, 69.49950926644462, 69.13130337851388, 70.36335795266288, 79.85732092176164, 71.45944322858537, 75.33030550820487, 70.07547324044364, 65.93459701538086, 59.58712577819824, 51.14707599367414, 39.547833170209614, 36.64478199822562, 27.365028517586843, 24.308086906160625, 16.551606110164098, 21.02562240191868, 25.63347315788269, 27.013291597366333, 25.27325769833156, 26.182775156838552, 36.45544706072126, 31.871352195739746, 34.23555667059762, 35.62060015542166, 26.13335783141, 18.82318241255624, 10.502685938562665, 2.6848251904760088, 0.652417282973017, 0.13677295510257992, 0.11091639434120484, 0.02338230486826173, 0.016736817712496434, 0.01331390964332968, 0.007144043305223542, 0.021324345476127098, 0.032265381687986, 0.018215881560796073, 0.03211092336901596, 0.10349058173596859, 0.04177471409950938, 0.017896147378321205, 0.022866223007440567, 0.029268156803612198, 0.059204643459192345, 0.02974217797496489, 0.06797040666320495, 0.02682204315039728, 0.07273231792662825, 0.0447709245740303, 0.025699160993099213, 0.06981621868908405, 0.047825526379581006, 0.06487140152603388, 0.041729018158678494, 0.04555737040936947, 0.04424119567764657, 0.03899834218568035, 0.024421504998047436, 0.031888085683541637, 0.017330954849187816, 0.04743922621543918, 0.024168226535298994, 0.09026639562632356, 0.027852132251220088, 0.025753856004614915, 0.060572576842137744, 0.04837617451058967, 0.07075398122625691, 0.056224449803786616, 0.02807575194830341, 0.042969692298876386, 0.030154513527772257, 0.02012004759827895, 0.06689375479306493, 0.011733012955768831, 0.028210872019241964, 0.054929211270064116, 0.11811459915978567, 0.04311691404187253, 0.08436310703733138, 0.06004528049379587, 0.07639323826879263, 0.02864766027778387, 0.07439421982105289, 0.022969446843490005, 0.07815361595047371, 0.06670158010508333, 0.022464272433093617, 0.07299712300300598, 0.010509742390630501, 0.00816966510111732, 0.02534994955307671, 0.030393140723130534, 0.036250132867800336, 0.07598091967936073, 0.03672136186755129, 0.20075232056634768, 0.1977283749729395, 0.14451704812901361, 0.14227165361600264, 0.15969126245805196, 0.1866383579160486, 0.2099830973893404, 0.11561298982373305, 0.15259989297815732, 0.11099988807524953, 0.1425861410264458, 0.1428632547280618, 0.08358944819441863, 0.1392159525837217, 0.15101996489933558, 0.14945044554769993, 0.16879083774983883, 0.0821378378729735, 0.12579930680138723, 0.13645180447825364, 0.13960659876465797, 0.21984823660126754, 0.11838156197752271, 0.18867373227008752, 0.17613800136106356, 0.16167232686919825, 0.16635923965701035, 0.1978124590324504, 0.11718647181987762, 0.13392407154398306, 0.19320097219731125, 0.19489523342677526, 0.20241188151495798, 0.10304760693439416, 0.1959282758512667, 0.19484081491827965, 0.132302033581904, 0.23058590399367468, 0.21948017206575188, 0.1697394839887108, 0.12352184472339493, 0.14911367504724435, 0.14608854880290373, 0.1377815566956997, 0.08653231563844851, 0.12603979318269662, 0.07490375890795674, 0.12547023088804313, 0.10838200497840132, 0.15453742258250713, 0.13306368914033684, 0.12938707428319113, 0.12058975920081139, 0.12371855202530112, 0.1922052763402462, 0.12015732883342675, 0.18499281550092356, 0.0933685763073819, 0.12154485152236053, 0.09530720513846193, 0.16521339757101877, 0.17277971442256654, 0.2088741133255618, 0.24676226026245526, 0.1172310651413032, 0.18659019550042494, 0.13002463935741357, 0.36464401334524155, 0.6207990710224424, 3.870198292391641, 8.952247534479413, 17.39584003176008, 27.204400062561035, 46.90612833840506, 52.54783282961164, 68.44348730359758, 74.98767593928746, 73.42804854256767, 81.69588375091553, 80.3586265019008, 82.1032566343035, 82.04692758832658, 89.1486952645438, 83.81681442260742, 86.29258264814104, 82.09018012455532, 77.14170782906669, 69.63956410544259, 60.27511555807931, 46.046135902404785, 44.24852922984532, 34.53991208757673, 30.405862467629568, 21.395075491496495, 26.83432858330863, 32.7934650012425, 34.50177342551095, 32.189704758780344, 35.33002301624843, 43.30790294919695, 38.60380227225167, 40.638408524649485, 41.66662032263619, 31.351032870156423, 23.682363407952444, 12.997395821980067, 4.02162993805749, 0.8180039290870939, 0.28706857029880795, 0.23387606601629937, 0.1093442558443972, 0.09683704376220703, 0.05104827594810298, 0.07213237083383969, 0.12876925457801136, 0.11537236773541995, 0.18532369631741727, 0.14620987086423806, 0.1630682498216629, 0.14123972398894175, 0.14846921605723246, 0.09484132299465792, 0.19249521435371467, 0.16178568292941364, 0.11392661317118577, 0.1653125315372433, 0.07930734939873219, 0.12348590950880732, 0.2259284531963723, 0.1258714757859707, 0.15960396214255265, 0.12692129159612314, 0.15012424439191818, 0.10440032077687127, 0.1595053845750434, 0.15005230610924108, 0.09980442667646067, 0.10505437425204686, 0.09089577756822109, 0.1553309014333146, 0.16568614648921148, 0.16013346372970513, 0.1892733672367675, 0.11084952471511704, 0.18982010361339363, 0.14251591265201569, 0.0815165779952492, 0.10490958844976765, 0.1547750048339367, 0.11821200964706284, 0.1525712316589696, 0.06570988760462829, 0.0840334611545716, 0.1804172367389713, 0.2001542326595102, 0.15296905674040318, 0.15071785396763257, 0.22628171209778103, 0.16678868447031292, 0.2031390674944435, 0.1576747785189322, 0.1505414212920836, 0.15551269453551086, 0.10180942980306489, 0.1725272179714271, 0.18642551505139895, 0.25249137569751057, 0.25618005490728785, 0.20613093195216997, 0.18693143076130322, 0.09339009265282325, 0.1871664481503623, 0.12504545439566883, 0.21379666775465012, 0.16389927880040236, 0.19542678418968404], [0.05326285818591714, 0.03193497245333024, 0.0560568787955812, 0.03804041358775326, 0.058004396435405524, 0.005579972165703241, 0.058840589065636904, 0.03001852153933474, 0.10918176027813128, 0.024669268667431812, 0.025390851644000838, 0.05606336559035948, 0.020855403139388988, 0.030180233397654126, 0.017960803283910667, 0.03496420383453369, 0.009983312022606177, 0.04615473906908717, 0.067557104197996, 0.02319262210013611, 0.006281219871847757, 0.023685828849141086, 0.05055523883285267, 0.04110288979219539, 0.05790542531758547, 0.029148717676954608, 0.07774328546864645, 0.023237853244479214, 0.01909063703247479, 0.043338153777377944, 0.06376561336219311, 0.01578663459180721, 0.040341441186943224, 0.016771200778228895, 0.03263056244967239, 0.09397239104977675, 0.05756621887641294, 0.05964463949203491, 0.018082926016567007, 0.07348139344581536, 0.038824990059116056, 0.022644325092967068, 0.02172527146259589, 0.014085750860561217, 0.06680836794631821, 0.06253118174416677, 0.035911767810050926, 0.025253195548430085, 0.029109264258295298, 0.02906813146546483, 0.08789541785206113, 0.06494277662464551, 0.04780440358445048, 0.023093584825151732, 0.04804862190836242, 0.01838914887048304, 0.03513056705040591, 0.042570337120975764, 0.02201542830360787, 0.03195415124563234, 0.06651766318827868, 0.10461610169815165, 0.059870740930948935, 0.08033157086798123, 0.4209472749914442, 1.7960583099297114, 4.235936267035348, 6.596888550690242, 15.976455075400215, 28.100801059177943, 34.07022428512573, 44.77342741830008, 56.550182819366455, 56.993630749838694, 68.34999234335763, 75.65634972708565, 72.72476577758789, 68.89800371442522, 64.30206217084611, 62.29467896052769, 59.37791551862444, 64.00602722167969, 61.76143945966448, 65.19093826838902, 66.78834996904645, 65.83640507289341, 65.90496989658901, 69.7623040335519, 60.348828996930806, 67.47929273332868, 61.72730990818569, 57.17959233692714, 51.04778970990862, 47.35717412403652, 47.592308112553184, 47.915566103799, 59.61218098231724, 51.35411146708897, 59.006749698093955, 58.924642835344585, 62.502082688467844, 60.6797091620309, 54.957204069410054, 50.14527082443237, 47.465423583984375, 29.83744076320103, 18.113729647227697, 10.839535474777222, 1.6676169506141116, 1.274161200438227, 0.049700121860951185, 0.08349811059555837, 0.03169966668688825, 0.029670178624136106, 0.020423115264358263, 0.02664338148731206, 0.024090456244136606, 0.03583319006221635, 0.04103328566998243, 0.01645498988883836, 0.05852709910167115, 0.04889888735488057, 0.03403359305645738, 0.02557691782047706, 0.04445878150207656, 0.02350311124298189, 0.030936762624021088, 0.046244176769895215, 0.03575497193794165, 0.0417745003609785, 0.027929127316123674, 0.03373704950458237, 0.02233300813739853, 0.03462443420929568, 0.04084540610866887, 0.020395463266010796, 0.011501398419828286, 0.025680479227698276, 0.044681419019720385, 0.047334884492946525, 0.05747131896870477, 0.02020836910898132, 0.0630341593974403, 0.032900164768631966, 0.045308755178536685, 0.05742507002183369, 0.07614684184747082, 0.0375776730610856, 0.025004744862339327, 0.017671755847654173, 0.007872409935641502, 0.004121836881885039, 0.0456422992449786, 0.02988395108176129, 0.030661385972052813, 0.028362183632063012, 0.06983956707907574, 0.07111034103270088, 0.02271319130834724, 0.0026454905663350864, 0.0564862150432808, 0.07660169101187161, 0.028852503214563643, 0.010223394675579454, 0.06377166589455945, 0.061362411959895065, 0.04871253449735897, 0.026138305464493375, 0.026485922347222055, 0.06684839472706829, 0.01137717392495168, 0.0929008824750781, 0.025605211034417152, 0.0145554344968072, 0.013100420474074781, 0.07414241547563247, 0.05434108425730041, 0.07016366254538298, 0.08127973534698997, 0.0351052203747843, 0.09285316110721656, 0.031995036373181004, 0.04657890487994466, 0.021548312922407473, 0.04900050136659827, 0.05345622031018138, 0.011174733002137924, 0.08398398238101176, 0.022681145795754025, 0.03306781720103962, 0.05525040939184172, 0.05096951499581337, 0.05688946840486356, 0.06774262924279485, 0.017948408145457506, 0.06400225244994674, 0.1440691335925034, 0.010709039999970367, 0.047359742623354704, 0.03829070140740701, 0.058478190297526975, 0.02605460986628064, 0.04037428906719599, 0.03951887014721121, 0.039367997885814736, 0.015573671287191766, 0.025904380516814332, 0.016389436620686735, 0.031164414515452724, 0.011084186744743159, 0.016859088026519333, 0.04640852812943714, 0.02523393533192575, 0.05165544943884015, 0.023631466319784522, 0.047391040051089864, 0.01079620884930981, 0.04472303357241409, 0.018961728949631964, 0.012679996783845127, 0.05675366979890636, 0.012381076663067299, 0.050862031656184366, 0.01716346526518464, 0.015472649297277843, 0.008979984342918863, 0.004945960494556597, 0.03221355179058654, 0.07785952530269112, 0.06796307848500353, 0.04633582988753915, 0.06779187052909817, 0.024415350685428296, 0.03715076936142785, 0.02916075149551034, 0.033431047174547396, 0.04046126029321125, 0.05628219652654869, 0.03352955010320459, 0.1401332640754325, 0.8556767904332706, 3.055232571704047, 7.452206151826041, 11.270965627261571, 24.886614765439713, 37.04593276977539, 44.44834205082485, 55.24966069630214, 66.1173346383231, 68.21969972337995, 78.63072763170514, 87.49871349334717, 84.19146129063198, 80.22747925349644, 73.9638727733067, 72.83483913966587, 70.40159388950893, 75.50662994384766, 72.23803751809257, 75.7955846786499, 76.31332969665527, 75.43290955679757, 76.31872149876186, 81.12141363961356, 72.53167533874512, 80.70753029414585, 71.78474399021694, 66.51270798274449, 59.304695401872905, 54.951072284153526, 55.19623599733625, 56.63491610118321, 66.85780416216168, 59.84930910382952, 69.17155429295131, 68.92589378356934, 71.27357196807861, 71.07388074057442, 64.47150788988385, 60.42609991346087, 55.82545443943569, 38.41960900170462, 24.88275330407279, 17.219420058386667, 4.027683990342276, 1.7277810765164239, 0.2639211895210402, 0.02197498592015888, 0.011441595735959709, 0.041959241697830815, 0.04940222802438906, 0.03302467255187886, 0.04624405802626695, 0.02669250063731202, 0.03796294863734927, 0.02629202078761799, 0.038380719255656004, 0.014328417035617998, 0.007755662048501628, 0.029050744005611966, 0.016380103371505226, 0.029196232091635466, 0.04124094791976469, 0.024745576715629016, 0.03427936861823712, 0.03614490904978343, 0.09809997385101658, 0.038080409834427495, 0.021919614069962075, 0.028685162908264568, 0.00932857153072421, 0.03252035479194351, 0.021762534909482514, 0.04513231232496245, 0.06284281252218143, 0.014698384861860956, 0.06134639174810477, 0.02523691749333271, 0.01599446138633149, 0.025568400509655476, 0.02268769874769662, 0.03011528741834419, 0.0548319738092167, 0.005357330831299935, 0.01616226988179343, 0.038038690108805895, 0.058250813212777884, 0.04065269198534744, 0.029119235330394337, 0.03736538998782635, 0.01560547252717827, 0.03824099532461592, 0.05807601580662387, 0.06140486111066171, 0.05384572994496141, 0.0401138808977391, 0.030107151783470596, 0.05146933746125017, 0.03743420022406748, 0.020508546215881194, 0.023797441074358563, 0.051726620976946185, 0.03421550490228193, 0.03391231170722416, 0.05668077478185296, 0.01610805663014097, 0.043975671354149065, 0.07135325656937701, 0.06353129486420325, 0.025220571584733467, 0.016799361677840352, 0.037588454982531924, 0.1830592349703823, 0.09057785677058355, 0.1880226507782936, 0.19192246294447354, 0.18533420003950596, 0.16593788298113005, 0.1325911573533501, 0.11718610541096755, 0.18654976838401385, 0.1868732531688043, 0.08577439880796842, 0.18023784565074102, 0.14254101844770567, 0.10285827530814068, 0.1084196704572865, 0.11857240673686777, 0.12320340823914323, 0.14885100057082518, 0.15483641225312436, 0.0966336325343166, 0.17482803522476129, 0.13222322852483817, 0.16062905213662557, 0.11353338855717864, 0.2166257652321032, 0.1234072537294456, 0.16230926769120352, 0.11644173892480986, 0.10329506865569524, 0.12239717292998518, 0.10354867790426527, 0.12194491576935564, 0.13636603765189648, 0.12437701597809792, 0.15845727867313794, 0.17504930549434253, 0.2358484858913081, 0.18289052402334555, 0.10950477687375886, 0.1115188520135624, 0.15469130075403623, 0.10767271875270776, 0.1946153241608824, 0.12252648813383919, 0.13303025093461784, 0.1174845386828695, 0.13685413503221103, 0.10558028638895069, 0.11702318915299006, 0.13155145171497548, 0.1524810136428901, 0.16511621778564795, 0.12583970677639755, 0.10332200649593558, 0.13876741379499435, 0.18796960291053566, 0.1048966623576624, 0.1447446694863694, 0.13071865854518755, 0.13860243479056017, 0.16539964186293737, 0.13808384404650756, 0.16883746667632035, 0.225532310881785, 1.1206731051206589, 3.498583661658423, 8.699300970349993, 13.305413808141436, 27.953261273247854, 42.49510267802647, 51.17829424994332, 62.464840344020296, 75.6118951525007, 77.02113573891776, 90.77103015354702, 99.65905461992536, 95.24958188193185, 91.6733649117606, 85.8957154410226, 86.21576336451939, 83.28674330030168, 90.14200973510742, 85.56257711138043, 87.64766202654157, 88.08113929203579, 85.68068259102958, 88.48751163482666, 93.3057746887207, 85.13169152396065, 93.9759770802089, 81.91225760323661, 76.78639779772077, 68.65088408333915, 64.66951070513043, 66.30465807233537, 68.65242658342633, 77.97113513946533, 71.65278380257743, 80.37321077074323, 79.6296215057373, 80.63897241864885, 81.49271147591728, 77.77168015071324, 68.92280878339494, 63.3863799231393, 46.04671607698713, 30.066366536276682, 21.523981945855276, 5.537848029817853, 2.265559596674783, 0.46854172966309954, 0.1271556168794632, 0.06366613334310905, 0.11240531051797525, 0.13883548442806515, 0.12566203916711466, 0.11121365374752454, 0.1261028019445283, 0.15661962942353316, 0.1518478590462889, 0.15982430960450852, 0.0883656901174358, 0.10114146636000701, 0.07699174686734166, 0.09192003296422106, 0.1161933136837823, 0.08687678072601557, 0.1442158735756363, 0.16864903750164167, 0.15817270108631679, 0.0768749506345817, 0.19898606677140507, 0.11671220298324313, 0.13717339932918549, 0.09999279478298766, 0.1436200655464615, 0.0503754949064127, 0.10059766125466142, 0.1284202840179205, 0.08555829897522926, 0.22844531599964413, 0.0861645293022905, 0.186932950679745, 0.14923279865511827, 0.11831963887172085, 0.18099956906267575, 0.17664280427353724, 0.08109112975320645, 0.09826370435101645, 0.08422917101000037, 0.21812802819269045, 0.12041158947561469, 0.07191210479608603, 0.12818898500076362, 0.08816757824804101, 0.10344557450818163, 0.11459125179265227, 0.1585456510739667, 0.101709264463612, 0.09509048105350562, 0.14334524529320852, 0.13825986960104533, 0.12988305624042237, 0.131913762273533, 0.11669054414544787, 0.10541690872716052, 0.15621493756771088, 0.12121129727789334, 0.1539953952389104, 0.09750929554658276, 0.10689962309386049, 0.23696532739060266, 0.1950891994472061, 0.10238630670521941, 0.10166417581162282, 0.1605861551527466], [0.0193160429729947, 0.015375082746946385, 0.03184468997642398, 0.021239121477784853, 0.021315258195889846, 0.05108446900599769, 0.0374848460778594, 0.019787519638027464, 0.02727965055964887, 0.07114464776324374, 0.03671775206125208, 0.025560663514105336, 0.05096170845042382, 0.03836337250790425, 0.017584845689790587, 0.029769726496722018, 0.04324288406808462, 0.016755703038402965, 0.04227279612262334, 0.05165203980037144, 0.04422012377264244, 0.02233077066817454, 0.058660851924547126, 0.03674226753147585, 0.02477535931393504, 0.038679966769580326, 0.04649431531184486, 0.03232476368014302, 0.03381809711988483, 0.03452984642769609, 0.04916026922208922, 0.051548078057489226, 0.02594522662859942, 0.053315095204327784, 0.06988455395081214, 0.019356580351346304, 0.029316312433885675, 0.054717233537563255, 0.0356386778210955, 0.04167098645120859, 0.021845433229048337, 0.010697502360147024, 0.04065328570348876, 0.0937821976840496, 0.037470800402973375, 0.012842124244863433, 0.017732525443924323, 0.029056365668241466, 0.045083576547248025, 0.016520872246474028, 0.03865174989082983, 0.006841758923006377, 0.03195553206439529, 0.03809681681117841, 0.057049338040607314, 0.09061071143618651, 0.0838635763419526, 0.025477783854252527, 0.08504358266613313, 0.05769691829170499, 0.13664802323494638, 0.8860982294593538, 2.6523477903434207, 7.9777678932462415, 9.524963225637164, 19.43029863493783, 33.073491300855366, 45.00796038763863, 54.359745843069895, 59.2791816166469, 59.99399144308907, 60.152507645743235, 62.917981011526926, 64.3550352369036, 62.07986845288958, 62.64694568089077, 54.20945283344814, 52.752127238682334, 59.52826063973563, 55.955184255327495, 44.196692194257466, 52.101539611816406, 47.390167645045686, 48.21503346306937, 53.63063314982823, 57.61799587522234, 62.59277752467564, 50.33180563790457, 58.16330092293875, 63.8257075718471, 62.5304730279105, 63.6186443056379, 63.79625415802002, 61.37051296234131, 57.236164569854736, 55.79385750634329, 67.97626958574567, 64.66864218030656, 63.6153439113072, 60.418262345450266, 62.37381894247872, 65.96487726484025, 63.535891260419575, 65.39492348262242, 63.66848373413086, 62.727440561567036, 51.779292583465576, 44.56559637614659, 22.29122461591448, 9.441163608006068, 5.550772547721863, 1.5773028539759772, 0.0028156648165479836, 0.014008384297734924, 0.04344940298636045, 0.03493783935638411, 0.05592638972614493, 0.09272104355373553, 0.02760318962724081, 0.036688432563096285, 0.0644847247749567, 0.044961409709815464, 0.02281440668074148, 0.04597924277186394, 0.07430668201829706, 0.015745873296899453, 0.02220123154776437, 0.027525753514575105, 0.08534910662897996, 0.039461791781442504, 0.030531836673617363, 0.012638021759422762, 0.09915916022977658, 0.023141808308927075, 0.1329131629317999, 0.062009965069592, 0.06868405586906842, 0.05566923852477755, 0.020186795088063394, 0.02681384135835937, 0.049762808318649016, 0.0694891173126442, 0.02630678910229887, 0.03732996367450271, 0.038190519104578664, 0.07109232592795577, 0.04622156798307385, 0.019885805435478687, 0.011484871003111559, 0.0519292315335146, 0.021223611863596097, 0.04299194824748805, 0.04356665723025799, 0.015869688974427323, 0.03459745904962931, 0.06393374076911382, 0.01281095658695059, 0.017876965193344013, 0.03837068711540528, 0.058801960067025254, 0.08621717004903726, 0.025187584604801874, 0.059837031311222484, 0.028182012228561298, 0.06017270937029805, 0.04693110865939941, 0.027265460696071386, 0.016908461627151285, 0.04433803280283298, 0.06713707066540207, 0.05775369131671531, 0.025397005956619978, 0.021323483736653413, 0.05225917597168258, 0.054709172541541715, 0.009915719756723514, 0.027239445663456405, 0.055000599939376116, 0.06038863278393235, 0.028504730268780674, 0.03463012033275195, 0.06007436250469514, 0.014977133832871914, 0.003779713164216706, 0.02194850948373122, 0.03309834449152861, 0.0895952091419271, 0.044381255483520884, 0.06651482012655054, 0.019517803664452264, 0.04941870963999203, 0.06475629484547035, 0.07408398682517664, 0.04595674594332065, 0.04190507085461702, 0.026734753012923256, 0.025966100062110593, 0.006754667681109692, 0.03470328337113772, 0.04581955634057522, 0.03713712062952774, 0.07446181547961064, 0.12611734973532812, 0.014199233297923846, 0.036997444195938964, 0.017049184701006328, 0.028595216306192533, 0.029749682572271143, 0.0530803390512509, 0.05937423650175333, 0.005941637267824262, 0.036560996901243925, 0.03394016217706459, 0.09409623726138047, 0.032904429361224174, 0.03517149967540588, 0.04317586516429271, 0.022420305060222745, 0.03664152543725712, 0.04486652337280767, 0.030376838919307505, 0.03737100825778075, 0.02604573462823672, 0.0756836806290916, 0.06408679112792015, 0.025163325281547647, 0.0332085487565824, 0.008064805995672941, 0.01637845962042255, 0.03158592725438731, 0.030954696304563965, 0.0929493298754096, 0.09230094216763973, 0.08019806910306215, 0.06379751129341976, 0.06407410252307143, 0.0563136194832623, 1.8800405349050249, 5.128004627568381, 12.58727318899972, 14.724540812628609, 26.89689884866987, 41.63668400900704, 56.37593936920166, 64.70760767800468, 69.16163226536342, 69.82702650342668, 70.3308334350586, 71.2679717200143, 74.40386744907924, 71.97172001429966, 70.50225244249616, 64.26301329476493, 60.33494649614607, 69.49561132703508, 67.78659071241105, 56.49669211251395, 59.09281703404018, 57.474074363708496, 59.05918080466134, 63.60415036337716, 70.1373677934919, 71.87168679918561, 58.325485774448936, 67.71421827588762, 71.43357508523124, 72.15760517120361, 70.28604534694126, 70.19395392281669, 70.52707140786308, 68.24334444318498, 62.96822343553816, 76.35110010419572, 72.71456582205636, 70.76317814418248, 68.21933841705322, 71.96235384259904, 75.3813956124442, 72.31475257873535, 73.55203219822475, 71.3841803414481, 71.53201716286796, 60.60687814440046, 54.79287222453526, 29.996561459132604, 13.994817546435765, 7.232169730322702, 2.5052754878997803, 0.12585718583847794, 0.033119769234742434, 0.03696784310575042, 0.03500021368797336, 0.018073463845731955, 0.049581605541918955, 0.012226888909935951, 0.027371863468683193, 0.008397631663163858, 0.026503123209944794, 0.03302649102572884, 0.037089107491608174, 0.026053785446232984, 0.05958253318177802, 0.05154671759477683, 0.08193433165018048, 0.05887229022170816, 0.06388291849621705, 0.02405187813565135, 0.014267988403194716, 0.05197166032823069, 0.10153798865420477, 0.021398757018947175, 0.035717961245349476, 0.024457092463438, 0.024560431650440608, 0.026726344267704656, 0.09259787587715046, 0.02964298633326377, 0.08976962656847068, 0.026342999123569046, 0.05561050453356334, 0.03409653396478721, 0.03682295891589352, 0.05929155022438083, 0.04182466445490718, 0.052296641282737255, 0.01753022531712694, 0.08943852183542081, 0.0391319118041013, 0.032084799770798, 0.018408744961821606, 0.021809844067320228, 0.039706023676054816, 0.012672620260023644, 0.0203072537135865, 0.01806070908371891, 0.010523324965366294, 0.0314534432919962, 0.005585615880720849, 0.0704314871025937, 0.03905104739325387, 0.0373491967496063, 0.08240604919514485, 0.049021597020328045, 0.03166852192953229, 0.06880916415580682, 0.052263264145169935, 0.03403487548764263, 0.0304005367548338, 0.04864470474421978, 0.019236900344757096, 0.03885972426672067, 0.02225022347244833, 0.22413095964917115, 0.1510506346821785, 0.12564420726682457, 0.1295394596776792, 0.10337339873824801, 0.14996016105370863, 0.1373199900346143, 0.07845390840832676, 0.17381997645965644, 0.1360856398407902, 0.16500495161328996, 0.1152347336922373, 0.17865708975919656, 0.1209579865847315, 0.12347881203251225, 0.22753716473068508, 0.214276771992445, 0.10377359190689665, 0.19808779497231754, 0.09358295266117368, 0.1510438086198909, 0.08150356369359152, 0.10921983966337782, 0.10494898419295039, 0.10999305067317826, 0.10772283534918513, 0.2722039579280785, 0.12922521653984273, 0.1366426899496998, 0.06684312250997339, 0.1255262778805835, 0.1277223564684391, 0.1077351982572249, 0.13321602025202342, 0.17752305418252945, 0.10794075365577425, 0.1179231165775231, 0.150624867528677, 0.11232434771955013, 0.23003308794328145, 0.15683690990720475, 0.13940458531890595, 0.11005913319864444, 0.1713607077087675, 0.1762372846049922, 0.20401557189013275, 0.10233762860298157, 0.24999471966709408, 0.0973461689427495, 0.14934529976121017, 0.1368714241044862, 0.10268372217459337, 0.08639871887862682, 0.12545078407440866, 0.17183881705360754, 0.17146161943674088, 0.15622557699680328, 0.14222879734422478, 0.1373275082026209, 0.2143680892352547, 0.25344612875155037, 1.803550313626017, 5.521095488752637, 15.453927959714617, 16.504514694213867, 30.487872055598668, 46.94263417380196, 63.186049461364746, 76.18286337171281, 80.192307472229, 81.14272376469204, 81.2505806514195, 83.072995867048, 85.27199649810791, 84.44640459333147, 84.14669404711042, 74.44839150565011, 71.25108064923967, 80.61166599818638, 76.49205126081193, 65.57251249040876, 73.80257729121617, 67.41044998168945, 68.72593157632011, 74.70552349090576, 79.72274821145194, 83.24878529139927, 69.4705422265189, 80.05187048230852, 81.87469564165387, 83.0634629385812, 81.47693906511579, 82.04561437879289, 79.31495148794991, 78.15124634334019, 74.5056655066354, 86.38812037876674, 82.53375312260219, 82.19490337371826, 77.22136892591203, 80.29414027077812, 84.67516013554165, 80.71661158970424, 81.11136654445103, 82.301940373012, 80.43678678785051, 69.04288060324532, 61.96283299582345, 36.86062778745379, 16.84938853127616, 9.580502782549177, 3.3884095507008687, 0.3918809246804033, 0.10810354777744838, 0.13192432027842316, 0.16349192708730698, 0.13298492479537213, 0.2154691480100155, 0.07509004391197648, 0.14425341013286794, 0.17660538985260896, 0.0938933485054544, 0.2514713747160775, 0.21074841703687394, 0.25758939928242136, 0.11578596197068691, 0.11491343379020691, 0.1592743976839951, 0.19894285766141756, 0.16558166566704, 0.12611075437494687, 0.11066325328179769, 0.22027226670512132, 0.16717964277735778, 0.33011293198381153, 0.16072372134242738, 0.10224225372076035, 0.1891965435019561, 0.10932666143136364, 0.23881555667945317, 0.19556695595383644, 0.1599370821246079, 0.12916386340345654, 0.08695142636341707, 0.11164463883531944, 0.16281268639223917, 0.09459842781403235, 0.15574113013488905, 0.09530088797743831, 0.10760694835335016, 0.13151706356023038, 0.08810731076768466, 0.0945474969755326, 0.08440268598496914, 0.18075687065720558, 0.16934374879513467, 0.09974947212530033, 0.0940913518092462, 0.06308679335883685, 0.11727747693657875, 0.16873223946562835, 0.1098124042951635, 0.20022645592689514, 0.09088254613535744, 0.10759438867015497, 0.20211167048130715, 0.11405394705278532, 0.18020488241953508, 0.1657489381198372, 0.1865306744085891, 0.13335085873092922, 0.08665312201316867, 0.12506975952003682, 0.064403850186084, 0.12976330838033132, 0.0835542729390519], [0.046255399739103656, 0.06050034678940262, 0.05903239055935826, 0.055677604861557484, 0.01574550349531429, 0.03323165287396737, 0.022698563789682727, 0.010477410196991903, 0.028682608223919357, 0.012047024543530174, 0.016844324800851088, 0.02296322807004409, 0.017777030555797473, 0.011811365090709711, 0.019640352177832807, 0.022750707509528314, 0.05925393902829715, 0.05693613125809601, 0.048635208646633794, 0.02177640246892614, 0.0471087321639061, 0.03508677779297743, 0.012010761087627282, 0.019785541708448103, 0.060997950445328436, 0.03958792804873415, 0.042313898381377966, 0.07508139259048871, 0.03843587736732193, 0.04222251667774149, 0.06941947247833014, 0.0106904863080542, 0.025753408171502606, 0.06073461778994117, 0.03944857391927924, 0.06179514088268791, 0.05097108241170645, 0.05787295063159295, 0.056832871798958094, 0.017760464123317173, 0.06463313395423548, 0.0576717649985637, 0.04517403544325914, 0.029737211098628383, 0.05341518929760371, 0.0609060496624027, 0.01838325070483344, 0.03365727074976478, 0.07347982602992228, 0.08235323202929326, 0.09192837215960026, 0.009039703906247658, 0.08344599232077599, 0.06795282582087175, 0.02844315321583833, 0.043430159733231576, 0.04938100344900574, 0.03738588513806462, 0.12781329373163836, 0.5666502937674522, 6.429078698158264, 22.722313438143047, 31.253181389399938, 35.72081749779837, 49.27309124810355, 53.96229498726981, 58.531395639692036, 65.6231301171439, 59.08624403817313, 54.86038439614432, 57.830826146262034, 58.20381586892264, 60.653306007385254, 48.62945876802717, 41.124657358442036, 42.02652658735003, 35.72950622013637, 40.908071586063926, 32.818419456481934, 34.83862556729998, 30.167407240186417, 35.72881140027727, 29.64733804975237, 24.927197456359863, 28.117740767342703, 25.39991467339652, 26.96700096130371, 28.660527093069895, 47.764216967991416, 45.363402434757774, 44.21098811285836, 52.387134892599924, 43.261951037815635, 57.91603537968227, 55.75630944115775, 41.486415318080354, 43.625171593257356, 52.498431137629915, 48.179187706538606, 55.3376179422651, 54.329482964106965, 47.98718466077532, 48.13672031675066, 47.07163095474243, 57.68714782169887, 55.2075754574367, 57.99477931431362, 59.57220104762486, 55.04343121392386, 43.391753809792654, 25.083382538386754, 16.185382195881434, 6.8880250198500494, 1.6937283894845416, 0.17385722803218023, 0.09685921828661646, 0.005069590847207499, 0.024234419322705696, 0.08862028324178287, 0.04251459886186889, 0.037226504047534296, 0.033758243545889854, 0.015859536394210796, 0.0352398145810834, 0.10034498838441712, 0.023197716201788614, 0.024961469595187476, 0.05272368747474892, 0.016118611242356043, 0.04730772612882512, 0.029043395471360003, 0.029871394791241204, 0.03548085057575788, 0.05155315010675362, 0.028273178497329354, 0.02839834615588188, 0.031254123630268235, 0.04241527151316404, 0.053435840510896275, 0.048718475071447234, 0.011561933073348232, 0.06863503849932126, 0.01994142834363239, 0.07094458171299525, 0.05199510371312499, 0.05370233853214553, 0.06565681259546961, 0.007107578409236989, 0.04376724235979574, 0.027925963646599224, 0.05918545448886497, 0.04178899386897683, 0.0809877345870648, 0.045034491323999, 0.03123770308281694, 0.03994767035224608, 0.016410247289708683, 0.07330551716898169, 0.029618012851902416, 0.048126124178192446, 0.05319552715601666, 0.029606023138122897, 0.0689801617658564, 0.05827792747212308, 0.000751200075943156, 0.09082748301859413, 0.023457662967432822, 0.10675544797309808, 0.022439383768609593, 0.02407917899212667, 0.020550410130194256, 0.06132160486387355, 0.05198700539767742, 0.04723320262772696, 0.020500883859183108, 0.009128473250062337, 0.005799320484844169, 0.07345940891121115, 0.0479911499922829, 0.06827856334192411, 0.030802103956895213, 0.012159066790315722, 0.027315714695890034, 0.056014175194182565, 0.04171825659328273, 0.013423032493197491, 0.07448455997343574, 0.01357118213283164, 0.0312823031895927, 0.04015176011515515, 0.012633619763489281, 0.03928018866905144, 0.072849616275302, 0.008462233285951828, 0.03608149655961564, 0.06650719339294092, 0.014270956993901303, 0.015417799919045396, 0.04228462638067348, 0.03552329633384943, 0.041341666265257766, 0.01409220288041979, 0.04267404441322599, 0.02299291736978505, 0.017116033971043568, 0.01865899546204933, 0.021928404491128664, 0.03176860584478293, 0.007477951236069202, 0.07735160112913166, 0.05058031748714192, 0.017144357719059502, 0.012665663579744952, 0.053876722031938176, 0.05587434948288968, 0.031788704052035294, 0.021223135192745497, 0.047322725145412345, 0.08271419230316367, 0.010236906004138291, 0.1255928421659129, 0.05225029055561338, 0.03753992276532309, 0.012639886882555271, 0.04429331055975386, 0.06560883338430099, 0.11358709460390465, 0.03087935856144343, 0.06973552730466638, 0.0609051947082792, 0.012345500223870789, 0.03430522419512272, 0.07736601999827794, 0.04227591399103403, 0.6404617673584393, 1.9344668601240431, 10.803030507905142, 30.689658164978027, 38.39222962515694, 44.99435928889683, 60.92479297092983, 66.64098562513078, 66.99883869716099, 74.92826189313615, 68.54880809783936, 63.596569878714426, 66.87807900565011, 65.17447103772844, 71.22360747201103, 55.59622989382063, 53.53691932133266, 51.62789133616856, 44.2186450277056, 51.9239992414202, 44.78138310568673, 45.44555446079799, 40.4881398337228, 48.14549936567034, 39.97834355490548, 36.165512629917686, 37.82661151885986, 36.17097391401018, 34.29076010840279, 41.267112800053184, 57.50614377430507, 56.71304859433855, 55.978526728493826, 59.88846915108817, 52.0671877179827, 66.15072768075126, 62.416321073259624, 49.32269443784441, 50.85332005364554, 60.52363872528076, 57.30481277193342, 63.6964293888637, 63.48129231589181, 54.81039210728237, 57.65067325319563, 54.959253787994385, 65.76233727591378, 62.3912033353533, 65.7122129712786, 65.64769199916294, 63.82486683981759, 51.98768295560564, 33.05609995978219, 21.086624111448014, 9.480217695236206, 2.9882460747446333, 0.6624555300389017, 0.1471999484513487, 0.0026634846789030625, 0.05251842723893268, 0.054648223133491616, 0.029230040098939623, 0.010018499152335738, 0.017026133170085292, 0.02454055905608194, 0.044745360767202716, 0.01966769713908434, 0.029614389474902834, 0.015773218258150985, 0.04474944894069007, 0.01582892767951957, 0.0692770072658147, 0.06332730009619679, 0.052753889068428955, 0.07705540023744106, 0.004489658417047134, 0.02712072748025613, 0.013847872598229774, 0.03957030310162476, 0.08662577705191714, 0.090622918281172, 0.0533579107640045, 0.045020544036690674, 0.052591865084000995, 0.010691612676185156, 0.0295321238892419, 0.02998220295246158, 0.039231446105986834, 0.04996008898264595, 0.05926282783704145, 0.021378463732876947, 0.04267860416855131, 0.028470420145562718, 0.02997305290773511, 0.08529545486505542, 0.07057208634380784, 0.030331119229750972, 0.04808169709784644, 0.004313228286004492, 0.07798330366079297, 0.01555478256861014, 0.021685953750940304, 0.05984056647866964, 0.05899431795946189, 0.070170176481562, 0.03372641686084015, 0.06809217655765158, 0.026908390124195387, 0.0291806020374809, 0.07707223469125372, 0.02521888372887458, 0.09238031040877104, 0.09428600315004587, 0.03451280841337783, 0.07764542714825698, 0.061764511811946116, 0.021454293413886, 0.009007892488235874, 0.11448058273111071, 0.14871841482818127, 0.14946483049009526, 0.18201005698314734, 0.10596773666994912, 0.10505543955202613, 0.14533464211438382, 0.13681697845458984, 0.09317697837416615, 0.08017612528055906, 0.15415124116199358, 0.08683585149369069, 0.13363664411008358, 0.07321294463638749, 0.1973539050668478, 0.10586743562349252, 0.26413775075759205, 0.14749737749142305, 0.15393210149237088, 0.11297544278204441, 0.09583185520023108, 0.14880446663924626, 0.14125423106764043, 0.16693948209285736, 0.1312639428568738, 0.1104862709928836, 0.11065716003733021, 0.19545590691268444, 0.1296512143952506, 0.06544654137854065, 0.14708420394786767, 0.16130954133612768, 0.09404105879366398, 0.2161775521401848, 0.08203453091638428, 0.12733705714344978, 0.14241443095462664, 0.19027246933962616, 0.13114025949367455, 0.09648341845188822, 0.13418005566511834, 0.11733896577996866, 0.20326645565884455, 0.13023137540689536, 0.39499534613319803, 0.09937596573893513, 0.1364842520228454, 0.08521977106907538, 0.18650683068803378, 0.14732532815209456, 0.21627610256629332, 0.13910627418330737, 0.11596848789070334, 0.1431308010859149, 0.1373909240854638, 0.1677177617592471, 0.1826191507279873, 0.171372188521283, 0.9120028508560998, 2.984692722558975, 13.003082054001943, 37.191344669886995, 44.853265694209504, 50.731632777622764, 71.26210744040353, 78.44809423174176, 79.3770614351545, 86.12540204184396, 78.5569099698748, 73.73169871738979, 75.4460347039359, 74.77226788657052, 78.36573723384312, 65.60954638889858, 62.03437859671456, 61.11853654044015, 51.245389529636924, 59.9297970363072, 50.061802114759175, 53.14471435546875, 43.67236375808716, 53.96265976769583, 46.13910279955183, 40.0482736996242, 44.79928861345564, 42.15918854304722, 43.376294067927766, 46.14300421306065, 66.25886249542236, 63.384316308157786, 62.149677004132954, 68.37114265986851, 60.43565368652344, 74.7535285949707, 73.29624816349575, 57.14742912564959, 60.78013842446463, 68.4302509852818, 67.82867595127651, 73.74033532823834, 73.30744865962437, 65.95598357064384, 68.7435383115496, 63.58162430354527, 77.06959247589111, 71.28496701376778, 75.76589502607072, 76.74808543069022, 71.42495931897844, 62.28434004102434, 38.81499971662249, 24.478559221540177, 11.56555882522038, 4.0065145662852695, 1.214823693037033, 0.336968116994415, 0.10581999245498862, 0.27653754396098, 0.16253711975046567, 0.15267819591930934, 0.07285753477896963, 0.1105736798739859, 0.05809525227440255, 0.1493061754320349, 0.21596352862460272, 0.09695261184658323, 0.08840541834277765, 0.12866022757121495, 0.14310983435383864, 0.13781829258160933, 0.2154093419334718, 0.18981443106063775, 0.18484199073697838, 0.2191552080746208, 0.13671242977891648, 0.059827212909502644, 0.10328661410936288, 0.13048084559185164, 0.22773157858422824, 0.12958310305007867, 0.10816972529781715, 0.1663780486477273, 0.06998980830290488, 0.16412520382021153, 0.14013517754418509, 0.13580225647560187, 0.14971287575151238, 0.1356597234095846, 0.14601046299295767, 0.1372014092547553, 0.10612609995795147, 0.1071319127721446, 0.2568861384476934, 0.175416162237525, 0.13761314430407115, 0.14285539729254587, 0.10177830540175949, 0.28449825250676697, 0.13419837611062185, 0.09992528733398233, 0.2523416094481945, 0.16433568538299628, 0.1664207149296999, 0.1680469869502953, 0.117575557370271, 0.284404668956995, 0.1370475310832262, 0.13946593845529215, 0.08927560557744332, 0.31180830991693903, 0.12350349713649068, 0.13330024001853807, 0.116308135379638, 0.1263265692229782, 0.114960374842797, 0.08552156987466983], [0.07861033787152596, 0.07286806564245905, 0.017077812093443105, 0.024002689435811977, 0.08187624905258417, 0.04272310249507427, 0.03188644362879651, 0.02377951248282833, 0.054931172236268005, 0.05377587815746665, 0.04158456144588334, 0.04321327958522098, 0.049101121324513636, 0.015356482405747687, 0.08930419904312917, 0.07395241888506071, 0.046018299247537336, 0.07175052525209528, 0.04771484035466399, 0.034347086413098235, 0.01021329892267074, 0.03988054288285119, 0.04486783973074385, 0.036201471728937965, 0.025623843606029238, 0.011733916255512407, 0.012313458952121437, 0.01737316481636039, 0.03242318857727306, 0.0409463992608445, 0.016091323956581097, 0.025621346597160612, 0.037499760277569294, 0.04885377834684082, 0.07759612479380198, 0.08370225464126893, 0.022425852084000195, 0.04172382058043565, 0.006383289350196719, 0.06846350484660693, 0.03384452945153628, 0.055505087333066125, 0.048057296978575845, 0.051853327213653495, 0.044472308097673316, 0.02650578985256808, 0.019379201012530496, 0.06489432243896381, 0.04533382365480065, 0.026349848934582303, 0.09416319509702069, 0.11857212175215993, 0.10331889880555016, 0.05413214636168309, 0.2126192059367895, 0.5726438207285744, 0.3915457012397902, 3.4903939068317413, 14.59359506198338, 25.619986704417638, 49.5358373778207, 50.90560524804251, 63.37643705095564, 62.65748609815325, 69.81898743765694, 61.696786471775596, 62.353731700352256, 60.70667512076241, 54.24075099400112, 47.142860412597656, 46.589384283338276, 39.871744292122976, 33.71989958626883, 26.33906272479466, 24.191591671534947, 20.89878477369036, 27.48078203201294, 22.928426538194927, 23.07354313986642, 21.44431390081133, 13.639488407543727, 14.352789606366839, 11.164745041302272, 14.661649193082537, 13.079599090984889, 18.211063487189158, 20.48754174368722, 14.915520736149379, 16.178055320467266, 13.122234974588666, 15.46267921583993, 28.12399067197527, 37.93513543265206, 49.0483204977853, 55.423848560878206, 40.65651553017752, 35.03014571326119, 50.26962273461478, 37.15745830535889, 38.12039177758353, 43.98082556043352, 39.70623125348772, 33.891478402274, 38.66299745014736, 39.724567549569265, 48.20142194202968, 51.49207142421177, 61.80568558829171, 60.842637470790315, 59.51722690037319, 50.63619579587664, 43.48153495788574, 32.15054471152169, 26.318214654922485, 12.097271459443228, 6.531176831041064, 4.1337108952658514, 0.556255082998957, 0.10878717180873666, 0.04399994933711631, 0.007825878548568912, 0.11875231351171221, 0.08765567107392208, 0.029202532289283614, 0.033149909760270796, 0.026079629148755754, 0.04664617144901838, 0.010395970727716173, 0.0617823437122362, 0.020761068112083843, 0.04623999360150524, 0.02649213433531778, 0.014514028593631727, 0.036592477533434115, 0.08719787706754037, 0.06728461131985698, 0.0059466991390633795, 0.007344949042557606, 0.02154473025750901, 0.027570579234244566, 0.04631132459534066, 0.02061918135067182, 0.039831304989222965, 0.08548085777355091, 0.020296295373035327, 0.04906633961945772, 0.0665941544409309, 0.03512073847066079, 0.022767423219712715, 0.029522963666490147, 0.01105254580865481, 0.048886324279010296, 0.028524329752794335, 0.03893204252900822, 0.06781676597893238, 0.050279102221663506, 0.02361327818860965, 0.09400151377277714, 0.012720690225251019, 0.008955356914417019, 0.04947064471031938, 0.030119331487055336, 0.038649571793419976, 0.05787845355059419, 0.05834971647709608, 0.011084144336304494, 0.0812947852537036, 0.015397411638072558, 0.03738964422206793, 0.01631095047507967, 0.028664348846567527, 0.06515347531863622, 0.05059917736798525, 0.018354485909055387, 0.026964884949848056, 0.03739817001457725, 0.028690591188413755, 0.02452673899408962, 0.056127748385603936, 0.0374895652889141, 0.0563472035740103, 0.029902922920882702, 0.007047735861436064, 0.014904028469962733, 0.03546303903151836, 0.03511908284521528, 0.05863112530538014, 0.038147228570388894, 0.04746921067791326, 0.031786240969917605, 0.05397787463984319, 0.05230135031576667, 0.020050708104723265, 0.052432680768626075, 0.07828892940389258, 0.03269167131345187, 0.05448740015604666, 0.05268568951370461, 0.04604459587218506, 0.07207846801195826, 0.038118533324450254, 0.03551086557230779, 0.09769529556589467, 0.02892244321161083, 0.053489326033741236, 0.042088417802006006, 0.06839717126318387, 0.03162588618163552, 0.08257676860583679, 0.05433794942551425, 0.027422176840315973, 0.05525897928912725, 0.07590003830513783, 0.06158707490456956, 0.042884668468364646, 0.06846070249697991, 0.015453224536031485, 0.06257185313318457, 0.026251805713400245, 0.02530883881263435, 0.018574029307014177, 0.021456205186301043, 0.06398213388664381, 0.08915729621159178, 0.0814558355403798, 0.03774165801171746, 0.02406831395014056, 0.10569797150258507, 0.06640415106500898, 0.10743692104837724, 0.3139113884951387, 0.6011889204382896, 1.145125987274306, 6.688550923551832, 18.89960217475891, 35.03207036427089, 58.25717108590262, 59.32508141653878, 72.3643696648734, 74.96677575792584, 78.37665285382951, 69.74683039528983, 70.20421641213554, 69.08158901759556, 62.68414633614676, 57.837833404541016, 55.9075300352914, 51.29834522519793, 45.90632425035749, 37.439110483442036, 34.80296046393258, 35.577392782483784, 40.19389751979283, 36.30141939435686, 35.07190786089216, 33.90588549205235, 24.26427503994533, 28.028690917151316, 21.44486801964896, 19.007733515330724, 22.522684744426183, 25.670314243861608, 27.27718939099993, 20.404826913561138, 28.67371129989624, 18.438804592405045, 20.591564961842128, 33.035304001399446, 40.81365251541138, 55.464547634124756, 60.98214340209961, 40.882602964128765, 38.65118898664202, 56.83768538066319, 41.75319487707955, 44.93980550765991, 49.438187394823345, 47.783828258514404, 44.02335548400879, 44.372036933898926, 45.9438236781529, 56.88882064819336, 59.685116222926546, 70.36750602722168, 70.14553887503487, 65.63041182926723, 59.971819741385325, 51.267300673893516, 39.712491580418174, 32.29290982655117, 17.145953280585154, 9.01708551815578, 6.276240910802569, 1.1961920985153742, 0.16083645315042563, 0.03227797869060721, 0.08296478207090072, 0.04012237276349749, 0.059632785485259125, 0.06762640976480075, 0.06702762296689407, 0.10446909030101129, 0.04429367357598884, 0.052499974479100535, 0.09974747044699532, 0.01335297035984695, 0.05141122432957802, 0.08122870272823743, 0.05618119319634778, 0.0517981521386121, 0.08796770897294794, 0.030961047392338514, 0.01653138953926308, 0.05140548053064516, 0.10585861466825008, 0.02956071396225265, 0.03178090429199593, 0.0053838564615164486, 0.045679862943610976, 0.029927709805113927, 0.039887351981763325, 0.01749040379322001, 0.04102046814348016, 0.04096249071881175, 0.020217347823615586, 0.020358187944761345, 0.013130909596968974, 0.05694538647575038, 0.038831069732883146, 0.06015191227197647, 0.019272715119378905, 0.027902569455493773, 0.05056309966104371, 0.04573707701638341, 0.0808121772216899, 0.014169269191500331, 0.018254860004942332, 0.022183387773111463, 0.05915749206074646, 0.007352782729347902, 0.04939559195190668, 0.022418176156601737, 0.050939109841627736, 0.009542139579675027, 0.061048087397856374, 0.042727105851684294, 0.044081254795725854, 0.026302485493943095, 0.03610100444140179, 0.022110993175634315, 0.04351357204307403, 0.027772938732856085, 0.1276673408491271, 0.10825834875660283, 0.15716950063194546, 0.13867574371397495, 0.14671168822262967, 0.2171845795320613, 0.11713864867176328, 0.11864239083869116, 0.2193097240690674, 0.09283000949238028, 0.1778531614691019, 0.09434433680559907, 0.11170962213405541, 0.11514917042638574, 0.17548948473164014, 0.17879950068891048, 0.08598001527466945, 0.11951410477714879, 0.2098177655466965, 0.16098829571689877, 0.16747798105435713, 0.20398083089717797, 0.18051430795873913, 0.12931601809603827, 0.13891526657555783, 0.08431399467268161, 0.10418317600020341, 0.13328512225832256, 0.07992696043636117, 0.14586645072059973, 0.11592194038842406, 0.08074629147137914, 0.1181572111589568, 0.09099043320332255, 0.26304047820823534, 0.261713480842965, 0.10334429637129817, 0.18691856573734963, 0.12800014870507376, 0.17592434425439152, 0.1287791204771825, 0.16291403238262447, 0.11703450711710112, 0.1298719011247158, 0.18622770852276258, 0.16959981434047222, 0.10951491418693747, 0.20959787948855332, 0.15583421156874724, 0.13265066487448557, 0.1559570806899241, 0.21846770282302583, 0.1769351035888706, 0.325896542519331, 0.45479778572916985, 0.8414102931107793, 1.677353982414518, 8.700503877231053, 23.20111206599644, 41.24915170669556, 68.18980857304165, 68.22432027544293, 81.6578562600272, 82.89089747837612, 86.90747737884521, 77.96568775177002, 78.27618190220424, 77.86034611293248, 73.30907453809465, 65.85472747257778, 65.84891183035714, 58.16407217298235, 51.06157841001238, 45.60348354067121, 40.92361123221261, 37.6270557812282, 41.89943013872419, 36.029543331691194, 34.84247486931937, 33.47937726974487, 23.52142228399004, 27.22204327583313, 22.865833691188268, 24.214508567537578, 25.64497937474932, 28.800931079047068, 35.41133083615984, 26.56558789525713, 31.148770809173584, 25.315381152289255, 27.835513625826152, 43.83221748897007, 53.3259859085083, 65.65166636875698, 71.03286552429199, 55.89729533876692, 49.4994010244097, 66.62629713330949, 52.64309958049229, 52.090731688908164, 59.39469541822161, 57.643433230263845, 51.4344083241054, 55.170649256025044, 57.1139040674482, 66.84389386858258, 69.25307750701904, 78.8650347845895, 79.13735553196499, 74.65773378099713, 69.9237871170044, 61.286071504865376, 47.582396507263184, 39.841210433415, 21.02802300453186, 12.321210162980215, 7.860938276563372, 1.8251475947243827, 0.31517007095473154, 0.09708641216691051, 0.20407156459987164, 0.22608040432844842, 0.1747713911214045, 0.15298595226236752, 0.22133340047938482, 0.26158312069518225, 0.132823949147548, 0.11853879211204392, 0.1830333692154714, 0.1697597721857684, 0.11951358909053461, 0.19624057837894984, 0.11838142627051898, 0.08454453373061759, 0.21126958621399744, 0.17613829991647176, 0.09328650749687638, 0.0775836193934083, 0.18070953605430468, 0.14024377028856957, 0.16519272939435073, 0.09083694858210427, 0.20477407904607908, 0.1036509263462254, 0.17056498969239847, 0.12977457206164086, 0.13709915402744496, 0.09646731003054551, 0.10821385043007986, 0.0931133453601173, 0.0904928363327469, 0.1313728205859661, 0.18082803540996142, 0.11011570944849934, 0.19439600807215485, 0.11961673998406955, 0.09840823230998856, 0.24185373793755258, 0.19383191476975167, 0.19564065842756204, 0.18011522080217088, 0.09727530274540186, 0.1908877920359373, 0.15388099423476628, 0.17558472390685761, 0.144710525604231, 0.2319236493536404, 0.09762965408819062, 0.15612060762941837, 0.15140867047011852, 0.1742866457040821, 0.18136073968240193, 0.15443585946091584, 0.10950884808387075, 0.06787372220839773, 0.07532263214566878], [0.01742506256726171, 0.009455542396088796, 0.060624586551317146, 0.04886373584823949, 0.02866643194907478, 0.02067251759581268, 0.05850742158613034, 0.021375976902033602, 0.05284337087401322, 0.04737187482948814, 0.012970849123251225, 0.046687653687383444, 0.01577845315581986, 0.02620978743237044, 0.062357673554548194, 0.05712724743144853, 0.01249152435255902, 0.030478524177202156, 0.04069558218387621, 0.011177872074767947, 0.023451973451301455, 0.01902718552654343, 0.019700265123641918, 0.046644101917211495, 0.037262792100331614, 0.037114576303533146, 0.024216051379750882, 0.056566872500947545, 0.012905651237815619, 0.026189290585794618, 0.03169601956116302, 0.04375581243740661, 0.035890366815562756, 0.04572311615837472, 0.0466203531915588, 0.07782711847020046, 0.018814863437520604, 0.07642751107258455, 0.07328008567648274, 0.01500960173351424, 0.047070228694272895, 0.026426586156178797, 0.08277939951845578, 0.03324587157528315, 0.026859723896320378, 0.011006035625801554, 0.035022242327353785, 0.01922873078313257, 0.040849711413362196, 0.07741290676806654, 0.1845484022051096, 0.04951595727886472, 0.32272743114403313, 0.7177349637661661, 1.673139899969101, 6.092851025717599, 15.749761411121913, 32.97352409362793, 51.63157388142177, 59.58152553013393, 60.19307122911726, 64.03074196406773, 65.45055770874023, 58.745928219386506, 56.496424606868196, 44.74718059812273, 46.411892550332205, 45.33377879006522, 49.31388759613037, 30.41404049737113, 29.411769798823766, 26.678508281707764, 13.696252584457397, 15.158561774662562, 13.94483915397099, 11.111050231116158, 13.270361014774867, 19.08019801548549, 11.540313414164952, 15.201446056365967, 16.649740730013164, 14.714184522628784, 17.855727400098527, 28.568849086761475, 19.869075638907297, 23.948100737163, 21.147342681884766, 27.024327073778423, 14.695922919682094, 34.70626585824149, 42.364156927381245, 40.59319659641811, 36.11673627580915, 28.020257541111537, 22.363661323274883, 29.29581478663853, 22.418338435036794, 29.556014401572092, 30.305919579097203, 27.27234823363168, 35.217225960322786, 27.85584579195295, 27.166030372892106, 25.496861151286534, 27.432924577168055, 28.05250413077218, 36.049481187547954, 53.91578722000122, 48.36982890537807, 50.39559357506888, 56.681135518210276, 54.57975360325405, 57.11235114506313, 50.977168219430105, 41.7606155531747, 32.90446247373308, 24.068632875170024, 10.7456887619836, 2.6857286734240393, 1.5830466257674354, 0.37037152743765284, 0.04262296090434704, 0.0635336290246674, 0.025090050284883807, 0.030329836798565726, 0.06762942924563374, 0.04471141366021974, 0.06751333868929318, 0.018378643452056816, 0.008457072178966232, 0.03902704082429409, 0.018212862079963088, 0.03726233069651893, 0.01448949785637004, 0.06989163107105664, 0.04590642239366259, 0.056783583015203476, 0.03014007430257542, 0.00977903142172311, 0.013842440925405493, 0.014899560316864933, 0.05139444415856685, 0.019673191576397846, 0.05851505510509014, 0.011079986612977726, 0.10859271045774221, 0.032827788830867836, 0.10676783802253859, 0.04556710060153689, 0.06934289980147566, 0.06447059767586844, 0.020691709958815148, 0.02157859254761466, 0.023338844700317298, 0.03746088361367583, 0.03460196452215314, 0.07196768359946353, 0.01654824265278876, 0.04235422371753624, 0.009033287509477564, 0.06415849870869092, 0.013094367093539663, 0.03079576983249613, 0.011629036794017469, 0.05142556855987225, 0.05792013595678976, 0.060453242888408046, 0.03603333753666707, 0.09431958384811878, 0.09662895742803812, 0.03832372231408954, 0.021926034707576036, 0.08205910066940955, 0.038134339797709665, 0.028327749676204154, 0.033447491470724344, 0.02019590442068875, 0.11013634369841643, 0.02369070751592517, 0.03380558493414095, 0.008729228334102248, 0.058771032440875254, 0.018867677210697105, 0.03699606337717601, 0.061481447358216555, 0.06888572326196091, 0.013950467941218188, 0.06415708057050194, 0.024720881433625306, 0.03125570461686168, 0.041714002178715806, 0.05804526459957872, 0.06813840514847211, 0.059780814684927464, 0.07957107560443026, 0.03559517354837485, 0.03235978626513055, 0.022123980335891247, 0.013540096747289811, 0.015716404521039555, 0.015999592807410017, 0.009464652576882924, 0.05586259047101651, 0.035531479466174326, 0.031920899637043476, 0.07532020977565221, 0.08205355703830719, 0.024332817078434994, 0.03634176902206881, 0.0404860878895436, 0.0036184385368999627, 0.02658743118601186, 0.046833633711295466, 0.0715898210182786, 0.05842871830931731, 0.014139254194950419, 0.00827430113817432, 0.009347640061085778, 0.01613448726545487, 0.013921966077759862, 0.07521886378526688, 0.07291691337845155, 0.03424630021410329, 0.013659826795836645, 0.05279080815879362, 0.07721729190754038, 0.1341794314129012, 0.07868181475039039, 0.523463059748922, 1.0926802243505205, 3.8142518315996443, 10.387890407017299, 22.14959600993565, 41.86135401044573, 60.87022181919643, 68.62295232500348, 69.01589379991803, 72.279358455113, 72.69049726213727, 66.34542315346854, 64.00627040863037, 52.11624200003487, 54.5767137663705, 56.23507159096854, 58.679392269679475, 37.263883863176616, 40.05079242161342, 36.681972231183735, 25.3774858883449, 25.102606466838292, 23.7498026234763, 22.997571536472865, 21.000235421316965, 29.53564575740269, 19.994902304240636, 21.88817524909973, 19.166034323828562, 21.833541563579015, 19.921954904283794, 28.24733509336199, 31.775838783809117, 27.865467309951782, 32.05365555627005, 28.181518282209122, 14.690411261149816, 34.9325304712568, 41.23801374435425, 47.31749643598284, 45.63047729219709, 37.28475277764456, 35.12298059463501, 40.045324189322336, 31.673443181174143, 40.79881463732038, 39.984996455056326, 36.798472676958355, 46.875785555158345, 35.82789618628365, 35.67103712899344, 35.0469707761492, 37.863339696611675, 37.35769844055176, 43.95764636993408, 60.725372723170686, 54.19626862662179, 58.50284549168178, 64.27002402714321, 63.54962090083531, 66.67006383623395, 57.93193980625698, 48.416017055511475, 40.27251986094883, 30.2489686693464, 14.714967932019915, 4.373197061674936, 3.0235021029199873, 0.7083484360149929, 0.05760060024580785, 0.10591825789638928, 0.018177736018385206, 0.02808618442421513, 0.029360329000545398, 0.013291691014144038, 0.059115144690232616, 0.05664724836658154, 0.012868418325004833, 0.05163379060104489, 0.05881843489727803, 0.02709827814916415, 0.015504184212269527, 0.05532214750668832, 0.056485003858272514, 0.09586158181939806, 0.07667860295623541, 0.05435089926634516, 0.02490799594670534, 0.015442658049453582, 0.06494740423347269, 0.02318015741184354, 0.04193759643073593, 0.03506287978962064, 0.020829678180494478, 0.024326949446861233, 0.046953059267252684, 0.015066600371418255, 0.041418306795614104, 0.02095772622020117, 0.02265928848646581, 0.04953917335452778, 0.05218309523271663, 0.04024010876725827, 0.035766110090272765, 0.061577548272907734, 0.013431651584271873, 0.054078592985336266, 0.01754756867220359, 0.04274943643914802, 0.032968052197247744, 0.04283068422228098, 0.03217099407421691, 0.07295415138027497, 0.06049958683018174, 0.017147640132212212, 0.06848747748881578, 0.014224510423706045, 0.013208343165128358, 0.07834576349705458, 0.03096029761114291, 0.005322692890851093, 0.03705250392002719, 0.01433941099925765, 0.08447387787912573, 0.08680749551526137, 0.12018157967499324, 0.11446942761540413, 0.17379162726657732, 0.1036284804078085, 0.09304654358753137, 0.09439249922122274, 0.07829447982034513, 0.17256338388792106, 0.14739038608968258, 0.14451798450733933, 0.11920699982770852, 0.16251182396497044, 0.11647208301084382, 0.14593975964401448, 0.08991929103753396, 0.14070498411144527, 0.1514495454196419, 0.21305379404553346, 0.08795244872037854, 0.08027199549334389, 0.08817000740340777, 0.11573722958564758, 0.14686454859163078, 0.11137938592582941, 0.0913761192932725, 0.11454573566360132, 0.14151294289955071, 0.07166367955505848, 0.15103904530405998, 0.16532395806695732, 0.1685629721198763, 0.08339337871542998, 0.12425293906458787, 0.16105708559708937, 0.1987315889980112, 0.14586396728243145, 0.17408816064042704, 0.1460665642682995, 0.09621851159525768, 0.17030387584652218, 0.10954113956540823, 0.21118015529853956, 0.08525453920343093, 0.14833584321396692, 0.11182726653558867, 0.10080622934869357, 0.11886903510562011, 0.1519640649535826, 0.13229727026607307, 0.2725144826940128, 0.2787933200597763, 0.8121064284018108, 1.6981432097298759, 5.055885800293513, 12.690195986202784, 25.564741577420914, 48.021873542240684, 69.50896576472691, 77.34108638763428, 78.28244917733329, 81.58109256199428, 80.95501817975725, 74.77915355137416, 74.87267630440849, 62.05282606397356, 63.9758859361921, 63.065338407244, 66.37292412349156, 44.38843815667288, 44.899822098868235, 38.844564301627024, 26.00762322970799, 26.89624571800232, 27.918167659214564, 22.539963177272252, 22.341579948152813, 31.279692241123744, 19.83899688720703, 24.14872476032802, 25.408693722316197, 24.227887323924474, 29.51048285620553, 40.92701584952218, 31.074963569641113, 35.503165176936555, 33.320152350834434, 42.845951965876985, 26.867709466389247, 49.89432621002197, 56.45759807314192, 54.87881449290684, 51.36851508276803, 42.61541421072823, 35.75836556298392, 45.60255595615932, 36.51301636014666, 44.9723265511649, 47.288748264312744, 41.274189540318076, 49.128898756844656, 41.12067951474871, 41.43644734791347, 41.08842945098877, 42.52517448152815, 44.2399377822876, 52.81639460154942, 71.10200704847063, 65.26422091892788, 67.99168069022042, 73.96123940604073, 72.00841345105852, 75.55678898947579, 67.94714273725236, 57.812861578805105, 48.342664922986714, 36.74737562452044, 20.511966398784093, 6.2094778418540955, 4.166042600359235, 0.9527491501399449, 0.25698230043053627, 0.22489208595028945, 0.08509878148990017, 0.17352040324892315, 0.14116474586938108, 0.11202933426414217, 0.11867496051958629, 0.15459954924881458, 0.08297213739050285, 0.15628996997007302, 0.19721738382109574, 0.0954715870320797, 0.11562510845916611, 0.14610359870961734, 0.09922666767878191, 0.19104359724691936, 0.14414647301392897, 0.07162507091249738, 0.09314483617033277, 0.11962735227176122, 0.16511370720607893, 0.17358297774834291, 0.1480369892503534, 0.11725311752940927, 0.15170540740447386, 0.08662722911685705, 0.18901453326855386, 0.16211101332945482, 0.1784871303077255, 0.1566630828061274, 0.13711191048579557, 0.09983951372227498, 0.15416093064205988, 0.19866202558789933, 0.1348301600664854, 0.17812429049185344, 0.12218101881444454, 0.1327223724552563, 0.11617499323827879, 0.1951096776340689, 0.14922686825905526, 0.09482624594654356, 0.10908417337174926, 0.12315117461340767, 0.12587725690432958, 0.15570971396352562, 0.20798080840281077, 0.18621896899172238, 0.1992279373641525, 0.16249670620475495, 0.2184518115328891, 0.1525041652577264, 0.15139127283224038, 0.11381109936961106, 0.15324657756303037], [0.06041016948542424, 0.023031498870945404, 0.02554364246316254, 0.03373166872188449, 0.07449809674705778, 0.07497603645814316, 0.04261754619489823, 0.06551856108542, 0.04322906230975475, 0.02976117017013686, 0.075505259845938, 0.010165486800750452, 0.03258547040500811, 0.019451127420844774, 0.04586852960554617, 0.05925484147987195, 0.042463165907455344, 0.04862911879484143, 0.007441234009872589, 0.02479740322035338, 0.04458253611145275, 0.029682025845561708, 0.018007271058325256, 0.021551714079188447, 0.04141700740105339, 0.027554947483752455, 0.03484694280528596, 0.016364251097132052, 0.06315848058355705, 0.04468907968008092, 0.019278969515913298, 0.05403085465409926, 0.021741683528359448, 0.051648012695035765, 0.030685192373182093, 0.05593282563079681, 0.03327131663848247, 0.021043399747993265, 0.026296451621289765, 0.037879973982593844, 0.06271704605647496, 0.02984324237331748, 0.06334414812070982, 0.03305203786918095, 0.02054845086032791, 0.014699589261519057, 0.06982657991881881, 0.10754843827869211, 0.06713686031954628, 0.17173926239567144, 0.9370529523917607, 4.287906621183668, 6.776477771145957, 10.317843879972186, 30.681028502328054, 42.84430176871163, 51.21724585124424, 63.176488740103586, 65.11946909768241, 64.43334838322231, 57.98538187571934, 50.71342502321516, 51.38294996534075, 47.51763582229614, 40.5364784513201, 35.490953717912944, 31.864994594029017, 27.686599833624705, 23.996491466249736, 41.02070883342198, 20.186644792556763, 11.860578468867711, 12.520934394427709, 8.122035077639989, 14.208916732243129, 22.024392945425852, 33.4735894203186, 39.02428988048008, 27.07953745978219, 29.887902055467876, 39.047906807490754, 42.4442001751491, 31.08174501146589, 24.104296241487774, 31.489670276641846, 43.709303855895996, 30.17649895804269, 24.521632841655187, 29.76670810154506, 27.678644146238053, 31.106636932918004, 17.545033488954815, 18.688429049083165, 23.29769376346043, 20.44872042110988, 14.044566648347036, 20.027008192879812, 13.428487249783107, 16.632955619267054, 17.37728313037327, 19.67751727785383, 19.187127317701066, 23.600348608834402, 23.753825630460465, 19.53997073854719, 21.18490811756679, 26.238748107637676, 33.200615542275564, 31.176025118146622, 42.390139716012136, 37.930716378348215, 50.21905027117048, 55.491002900259836, 52.926231724875315, 49.03959356035505, 48.76474714279175, 47.79040820258004, 40.79997846058437, 31.77347639628819, 17.693387951169694, 6.155683151313236, 1.9007105571883065, 1.1981694038425172, 0.050523965153843164, 0.1512447771217142, 0.09060431285096066, 0.0659197788419468, 0.029235108755528927, 0.027119870829795088, 0.06301566931818213, 0.0185827518746789, 0.01608466074269797, 0.036201719394219775, 0.017353139551622525, 0.02584942426931645, 0.015133127337321639, 0.013685656927659043, 0.029094933598701442, 0.03138986456074885, 0.020650278610576476, 0.0298008101859263, 0.028731164189853838, 0.057408025222165246, 0.03746412701106497, 0.027980763831042817, 0.01738198577160282, 0.026897803281566927, 0.03869444331420319, 0.031019262304263454, 0.019898185306893926, 0.02965109482673662, 0.05280274358977165, 0.07770602711077247, 0.04630855277978948, 0.01578031912712114, 0.02759274697330381, 0.08517033979296684, 0.06797977044646229, 0.03879015746393374, 0.04924860091081687, 0.0889143603188651, 0.0739931920543313, 0.09620557193245206, 0.05586536228656769, 0.03981475891279323, 0.026834782645372406, 0.026843664668766514, 0.05164942404787455, 0.09080078266561031, 0.047436970086502175, 0.04499607267124312, 0.05853051213281495, 0.045783424350832186, 0.05300780026508229, 0.03829388712931957, 0.020693382547636117, 0.05918565804937056, 0.013176491035015454, 0.0186724898272327, 0.06449396642191069, 0.08338421849267823, 0.03543370596266218, 0.029119374430073158, 0.09058426892650978, 0.035466679371893406, 0.051253210487110276, 0.06883198328848396, 0.029058374131896665, 0.02040347846091858, 0.04118836484849453, 0.018435905022280555, 0.04807764285111001, 0.04159273440018296, 0.0218433178961277, 0.055679592969162126, 0.032657076205526075, 0.025951520040897385, 0.06634927793805089, 0.005020810116548091, 0.015955125014962893, 0.009872338468475001, 0.024672797049528787, 0.01087060766959829, 0.08928722209696259, 0.0537937236284571, 0.04220501047426036, 0.017463179271934286, 0.01349413872230798, 0.034203854456011734, 0.01387996900094939, 0.029719711680497442, 0.053408166460160694, 0.04713830950536898, 0.028895325559590544, 0.06064672036362546, 0.05771429557353258, 0.06964518715228353, 0.012502411446933235, 0.047399182471313646, 0.03490035029660378, 0.045883939135819674, 0.0804331475602729, 0.03282501022996647, 0.021099436562508345, 0.04127837251871824, 0.19494775203721865, 1.3252457678318024, 5.8726087638310025, 10.007112622261047, 14.847567353929792, 41.089961528778076, 51.6576817376273, 62.75824192592076, 72.0226503099714, 74.8215584073748, 71.33120032719204, 67.37137331281389, 58.41464505876814, 60.698559624808176, 55.1718304497855, 54.76836592810494, 46.270899704524446, 45.874605723789756, 35.11998592104231, 32.4097125189645, 44.357004506247385, 32.91866111755371, 26.003200701304845, 18.476816449846538, 17.984084946768625, 22.564333983830043, 28.555069071905955, 31.273814065115793, 38.1273330279759, 23.787764106478008, 26.049793584006174, 31.421289580208914, 27.091260807854788, 27.295878308159963, 29.954583917345317, 31.003438813345774, 40.4773736000061, 31.30156169618879, 35.31452505929129, 39.07067952837263, 40.912386417388916, 44.10514620372227, 30.419609478541783, 28.79158227784293, 33.39597804205758, 24.390879903520855, 20.197739328656876, 22.486667019980295, 22.351585354123795, 24.964271306991577, 25.493618079594203, 28.522556713649205, 28.866476910454885, 31.8089782169887, 36.24645219530378, 28.49180051258632, 30.646402154650005, 38.31949935640608, 40.34538214547293, 37.93616376604353, 50.32384647641863, 44.82900258472988, 57.56859418324062, 61.10876737322126, 60.13945198059082, 56.69044610432216, 57.82636192866734, 57.20634290150234, 50.739994934626985, 40.65856177466256, 23.92122163091387, 10.037583078656878, 3.7492866090365817, 2.043278689895357, 0.13463242139135087, 0.0953601308699165, 0.05996193603745528, 0.10466480694179024, 0.03935067488678864, 0.05903422260390861, 0.036040869275374074, 0.008077749899322433, 0.011279929678754082, 0.017431869969836304, 0.04510485879810793, 0.03516180340998939, 0.03593357592555029, 0.021363859962938086, 0.06487461778202228, 0.008019236431989287, 0.041782133879938295, 0.01814912728566144, 0.0057008536033598435, 0.033095959440938065, 0.07225222047418356, 0.09519201024834599, 0.03627536419246878, 0.03449636072452579, 0.01580309245868453, 0.06381970617387976, 0.05450782406010798, 0.029836769149239575, 0.06706891182277884, 0.025172237839017595, 0.03330096183344722, 0.060163949483207295, 0.04845426710588591, 0.024958363601139615, 0.02877699923036354, 0.020181689112048064, 0.017348588277984942, 0.07967193983495235, 0.013096006603778472, 0.06560891480850321, 0.07377296672867877, 0.006774444856481361, 0.027315292307840924, 0.018940733379817436, 0.045204688262726576, 0.02384832950441965, 0.04865060799888202, 0.02130236433419798, 0.02726809510828129, 0.04144497322184699, 0.06281548791698047, 0.03975438286683389, 0.045967751781323125, 0.15559202884989126, 0.06630887117769037, 0.11532770656049252, 0.1486076914838382, 0.1306359858385154, 0.11652105966848986, 0.13439498841762543, 0.1957088376262358, 0.10843895442251648, 0.10393940550940377, 0.16595806261258467, 0.11752827705017158, 0.18405058820332798, 0.18559570743569306, 0.1377483627625874, 0.12900311845753873, 0.12161224362041269, 0.1374525757772582, 0.1093738264005099, 0.1242782755621842, 0.12288508032049451, 0.18633463207100118, 0.06317089777439833, 0.12686561101249286, 0.13589894771575928, 0.09264027074511562, 0.16227574806128228, 0.13721499352582864, 0.25849106375660214, 0.15474789057459148, 0.13796843881053583, 0.14608195344252245, 0.14519749661641462, 0.07370252800839287, 0.15301039309373923, 0.18730960546859673, 0.09985842449324471, 0.09917688356446368, 0.1515259620334421, 0.1554034368268081, 0.21885103439646109, 0.0985867413026946, 0.1255140778209482, 0.15170185188097612, 0.12532293450619492, 0.12283139462981905, 0.26407204142638613, 0.2055539193430117, 0.12223242462745734, 0.3076425391648497, 1.9133000416415078, 7.555260964802333, 12.454467926706586, 20.063658203397477, 45.440402371542795, 61.618640082223074, 75.84812695639474, 85.24573230743408, 82.37989916120256, 79.05342129298619, 74.388991355896, 65.38928849356515, 68.37044784000942, 63.6767520904541, 56.97697591781616, 50.569975989205496, 48.27184888294765, 41.63919578279768, 38.90672288622175, 57.071509633745464, 33.51854426520211, 22.783435004098074, 21.51796133177621, 20.138915879385813, 25.726377521242412, 31.062258788517543, 44.70114530835833, 49.649944169180735, 39.19343682697841, 43.414623805454795, 54.566218512398855, 59.40033040727888, 46.608943462371826, 39.04542282649449, 46.2202855518886, 60.14052200317383, 44.393816062382285, 42.80853591646467, 48.23159449441092, 42.27815212522234, 46.10854114804949, 30.812943526676722, 29.742941788264684, 35.93636451448713, 31.51261670248849, 23.131013427461895, 30.839159079960414, 23.36422450201852, 28.032246657780238, 26.296779462269374, 30.046588488987513, 29.436533178601945, 34.72506768362862, 35.95358909879412, 31.33010142190116, 36.59549147742135, 38.316786084856304, 49.33757400512695, 46.14874342509678, 58.92011260986328, 54.24788679395403, 65.73364121573312, 69.90355396270752, 69.85916192190987, 65.08701406206403, 67.98230757032121, 65.07000487191337, 58.490720885140554, 48.51407698222569, 30.257160595485143, 13.234508310045515, 4.901139863899775, 2.557046949863434, 0.2201002716485943, 0.25926063103335245, 0.18832294323614665, 0.12831627817026206, 0.19766951884542192, 0.13173731602728367, 0.10449507140687533, 0.09387732829366412, 0.09688796103000641, 0.17420636144067558, 0.1259601196008069, 0.1974723772811038, 0.1202580098594938, 0.13060887157917023, 0.09195346438458987, 0.10514268558472395, 0.09604236390441656, 0.13565753852682455, 0.19776957561927183, 0.1117981845246894, 0.17071580088564328, 0.15761873152639183, 0.10600641316601209, 0.13112899581236498, 0.09283572954258748, 0.05601263152701514, 0.17109545479927743, 0.09550911001861095, 0.1784558091312647, 0.22440628201833793, 0.1798854281327554, 0.19365827765847954, 0.10649888709719692, 0.12335987841444356, 0.12261498267097132, 0.11921689286828041, 0.09597536535667521, 0.20350943904902252, 0.12052429414221219, 0.16216074994632176, 0.21008343914789812, 0.12008395205651011, 0.12259504731212344, 0.09285264542060238, 0.18975720341716493, 0.13284625937896116, 0.1263447403907776, 0.11381565912493638, 0.0873399894418461, 0.10064137926591293, 0.11897604007806097, 0.18786348003361905, 0.07877500474985157], [0.03214737766289285, 0.08076751604676247, 0.02555548120290041, 0.01688550509113286, 0.06037006128047194, 0.028735126834362745, 0.032893545659525056, 0.07190248316952161, 0.023050251882523298, 0.02607171573410077, 0.05909768598420279, 0.03744469037545579, 0.015296404915196555, 0.012174419493281415, 0.0452234531486673, 0.028875342703291347, 0.054899538933698616, 0.035800701805523465, 0.06523986639721052, 0.03205639968759247, 0.04244468939889755, 0.04188847388806088, 0.04849848723305123, 0.034038091743631024, 0.032280794610934596, 0.03613649521555219, 0.008810679677740803, 0.06341441042189087, 0.06289159240467207, 0.0324021845257708, 0.01705658751805978, 0.051099898892321756, 0.031072903890162706, 0.03089552465826273, 0.012354930164292455, 0.043662717432848046, 0.023448724964899675, 0.036255164204963615, 0.07835889314966542, 0.022727966408378313, 0.08513783796557359, 0.03365316900557705, 0.06269981126700129, 0.015425380851541246, 0.03450054728559085, 0.05736159985618932, 0.04507207537868193, 0.25932433190090315, 1.5984743407794406, 5.633105661187853, 9.784771135875157, 25.91636037826538, 34.14644602366856, 47.68564673832485, 62.236869948250906, 71.42316668374198, 67.42626408168248, 60.18809631892613, 55.80803183146885, 48.129091194697786, 43.109340803963796, 40.546035698481965, 28.665906735828944, 32.37684406552996, 20.33166238239833, 16.263009207589285, 14.096884846687317, 22.03133593286787, 23.90445215361459, 18.102954728262766, 19.73152562550136, 13.394019842147827, 25.747458355767385, 23.887977974755422, 29.673348631177628, 37.45657478060041, 47.52357305799212, 44.45056894847325, 35.44522067478725, 30.80088840212141, 24.17055947440011, 27.342441661017283, 23.99304689679827, 26.71008610725403, 41.91887814658028, 33.72794907433646, 35.18210629054478, 38.12068707602364, 24.466130631310598, 23.03851900781904, 23.28322240284511, 34.012533392224995, 37.13604743140084, 24.93446179798671, 39.7469094821385, 37.46897036688668, 31.31582634789603, 30.293902669634136, 25.487835441316875, 29.060557467596873, 21.81452086993626, 23.498015539986746, 28.35637664794922, 16.13461865697588, 29.468175274985178, 18.828482151031494, 21.2921587739672, 33.17381634031023, 33.188817501068115, 31.298688616071427, 30.240380695887975, 32.34869691303798, 41.850612095424104, 46.62402105331421, 53.87804807935442, 52.64000415802002, 55.22856249128069, 53.66182361330305, 56.610208306993755, 50.89095149721418, 34.08151510783604, 20.190468038831437, 10.476580687931605, 3.5399367340973447, 0.8179487234779766, 0.15035424062183925, 0.06513795722275972, 0.029557124512004, 0.09013055291559015, 0.04750127824289458, 0.10392997387264456, 0.036664690622793775, 0.03460197809285351, 0.09828112234494515, 0.008576215294721936, 0.026543721656448076, 0.036921675583081584, 0.03604452318644949, 0.04408760588350041, 0.0855919678828546, 0.043790207377501895, 0.03989142658455031, 0.047293280118278096, 0.01880418329632708, 0.025189185947445885, 0.035714873911014626, 0.014476900853748833, 0.026995603926479816, 0.010177267016842961, 0.03529330349660345, 0.049458061278398545, 0.03532620905233281, 0.048796842473426034, 0.03508307299177561, 0.033010257075407674, 0.009705791199978973, 0.02825431013479829, 0.047314022933798175, 0.03650572004594973, 0.08058040323001997, 0.0750678354608161, 0.08785568284136908, 0.05319169343316129, 0.03344101146129625, 0.08332339461360659, 0.004493284762637424, 0.10751737494553838, 0.03189473532672439, 0.001038694939260105, 0.037071285769343376, 0.03796123194375208, 0.07989575461085353, 0.043388891233397384, 0.008480838716163166, 0.054003591117049964, 0.03712772970486965, 0.05634899829913463, 0.10584190913609096, 0.013267984696930009, 0.05298657229702387, 0.050732258441192765, 0.06385303581399576, 0.02440624644181558, 0.053481916431337595, 0.03458175774929779, 0.01166036814850356, 0.03895273784707699, 0.004935665421986154, 0.03715794147657497, 0.023918043888573135, 0.0768222895317844, 0.017046619838635837, 0.07225082947739533, 0.061916795426181385, 0.04640354768240026, 0.023747429650809084, 0.04644487385771104, 0.03077920000734074, 0.04834804923406669, 0.07637318755899157, 0.01994579641281494, 0.023319319855155687, 0.015020731404157621, 0.05171999508248908, 0.05615468622584428, 0.022192629420065453, 0.03441125886248691, 0.03163047647103667, 0.04171313026121684, 0.034215681321386776, 0.029274860729596446, 0.015786291931622794, 0.009787923623142498, 0.049999311699398925, 0.07566146539258105, 0.023710960089894276, 0.04744410148954817, 0.03308964567258954, 0.014398764153676373, 0.010290677359859859, 0.08492452012641089, 0.0274510281493089, 0.032532354683748314, 0.24977745275412286, 2.166816140924181, 7.712452667100089, 13.899569034576416, 29.859060083116802, 42.649932861328125, 61.85439246041434, 72.55805764879499, 79.56189741407121, 75.05454540252686, 68.44461291176933, 65.96075698307583, 56.29811259678432, 53.38264151981899, 49.2408481325422, 37.51089579718453, 40.73475224631173, 29.984322207314626, 29.538716861179896, 23.73430119241987, 26.26134886060442, 31.613320418766566, 32.72457013811384, 24.298064129693167, 16.3305960723332, 26.357593570436748, 26.71210629599435, 31.52140964780535, 28.235210486820765, 45.209677015032085, 37.58137137549264, 26.63414055960519, 25.949826376778738, 22.084531341280254, 23.633397715432302, 20.778827599116735, 22.321463176182338, 28.991916213716777, 32.150020122528076, 35.40749543053763, 35.330040386744905, 28.605255910328456, 24.280066558292933, 25.897956337247575, 27.66308191844395, 29.30912753513881, 29.048346008573258, 37.122435910361155, 35.35063484736851, 36.333030223846436, 29.097240482057842, 26.53558209964207, 26.651707342692784, 28.758385522024973, 28.62410463605608, 29.50942325592041, 21.090145111083984, 33.45620155334473, 28.776923315865652, 25.268173354012625, 40.3904446874346, 42.82620865958077, 37.775083678109304, 39.8770283971514, 42.741002900259836, 47.5054486819676, 53.63945388793945, 61.744722093854634, 60.97624438149588, 63.300708634512766, 61.643313135419575, 63.249375343322754, 61.167646408081055, 42.41761289324079, 26.948374577930995, 14.147503341947283, 5.036915046828134, 1.0451403238943644, 0.27610461147768156, 0.13100795873573848, 0.008818945930605488, 0.06000380843345608, 0.017149529852239147, 0.020742501697636077, 0.08037826764796462, 0.04246055694030864, 0.047128742161606035, 0.038910183523382456, 0.014124926079862883, 0.025948744832671115, 0.050684828843389235, 0.008221295678855052, 0.09979118167289666, 0.02530270315972822, 0.02875975426286459, 0.018130530337137834, 0.050595448818057775, 0.029042431951633522, 0.040972248052379916, 0.0461486967147461, 0.03602050643946443, 0.03755973938054272, 0.025112275699419633, 0.08159912178026778, 0.10517982859164476, 0.038580218729163916, 0.032833417278847525, 0.05268504151276179, 0.014725365110539963, 0.027211552785177315, 0.050092980066048245, 0.027497153263539076, 0.08678357715585402, 0.03106216946616769, 0.019826029893010855, 0.010698146968414741, 0.13102775838758263, 0.077651140413114, 0.041661975506160936, 0.007958562678790517, 0.03847416370574917, 0.07466993574053049, 0.04141447985810893, 0.015474008063652685, 0.057411424682608674, 0.03645272985366838, 0.07511891557701997, 0.07221139302211148, 0.021290227039051906, 0.12396065331995487, 0.2458301702780383, 0.11686726180570466, 0.11053169891238213, 0.2863098324409553, 0.18664048851600715, 0.07498452493122645, 0.19809212402573653, 0.1816176466111626, 0.10128255414643458, 0.1485902802752597, 0.08987730329058, 0.16675638620342526, 0.09689203902546849, 0.18026437636997017, 0.06680480563747031, 0.18884470952408655, 0.09651710771556411, 0.14771803707948752, 0.09589421256844487, 0.1673429390149457, 0.1348704650465931, 0.09775354101189546, 0.1822190729102918, 0.1056762719526887, 0.2373983955809048, 0.14516603973295006, 0.18078952176230295, 0.10124038319502558, 0.07486920111945697, 0.14357741283518927, 0.14411996943610056, 0.11569330122854028, 0.12341929094067641, 0.12937918970627443, 0.10955064584101949, 0.0863489279789584, 0.10011282084243638, 0.16566802960421356, 0.15561356555138314, 0.1398014740220138, 0.12970920199794428, 0.20418601988681725, 0.1500396989285946, 0.2103444579988718, 0.15165941630090984, 0.11969747208058834, 0.6180267397846494, 3.3514790066650937, 11.790835056986127, 18.848477329526627, 37.32431582042149, 51.55967044830322, 75.45765209197998, 84.80421597617013, 90.16026265280587, 81.21985571725028, 75.37664304460797, 72.17207826886857, 64.28979165213448, 57.12471546445574, 56.53991685594831, 42.96759407860892, 45.65522330147879, 34.496774196624756, 29.575458935328893, 23.426912886755808, 35.9574488231114, 37.188266617911204, 30.097821031297954, 28.640278305326188, 19.294377974101476, 36.373128277914866, 34.56320244925362, 42.4641067641122, 48.50073644093105, 59.86284419468471, 59.7994418825422, 50.47686317988804, 46.4404114314488, 38.89503949029105, 39.7231570652553, 34.99986546380179, 38.33965260641915, 54.80628572191511, 45.210705348423545, 48.69864198139736, 50.08776753289359, 35.988323143550325, 34.623960971832275, 36.165915625435964, 45.12063585008894, 48.21896961757115, 36.71556329727173, 53.93373441696167, 52.052214350019185, 48.127736295972554, 40.93154607500349, 37.92730828693935, 40.324228354862754, 35.38634163992745, 35.85835361480713, 42.042062759399414, 25.57710415976388, 42.81998307364327, 28.41040931429182, 31.409866741725377, 48.50870949881417, 49.5920205116272, 45.23236983163016, 45.23078216825213, 47.18374013900757, 57.556591170174734, 64.66738455636161, 72.2906631742205, 70.52183941432408, 72.86926746368408, 72.31004170009068, 72.06950896126884, 68.65455273219517, 50.55626024518694, 33.65683078765869, 18.57474783488682, 6.089322643620627, 1.320886424609593, 0.38945869037083214, 0.24363937069262775, 0.11680984417242662, 0.17666352673300675, 0.1600548079503434, 0.23879034231816018, 0.15226623016808713, 0.20971142553857394, 0.11033301707357168, 0.0853819137971316, 0.07627194334885903, 0.12288088697407927, 0.12280798517167568, 0.16687264639352048, 0.1264352026794638, 0.12352120690047741, 0.11266929456698042, 0.10496098069208008, 0.07908439636230469, 0.12355425155588559, 0.11585693673363753, 0.11160358746669122, 0.1393587842051472, 0.13565646644149507, 0.08010734897106886, 0.12288118552948747, 0.18753403771136487, 0.1742334757000208, 0.09201415934200798, 0.20226420515349933, 0.10509726445057563, 0.08579166073884283, 0.2514201046100685, 0.253939613699913, 0.2703137222145285, 0.10746399459562131, 0.23610383218952588, 0.10718082157628876, 0.16598965520305292, 0.2636895648070744, 0.10200726347310202, 0.19684721582702228, 0.16915614743317875, 0.15805065977786267, 0.19176372646221093, 0.12610639818012714, 0.2037895925875221, 0.1853552074836833, 0.14721252849059446, 0.19228009161140236, 0.11917436229331152], [0.03423441906592675, 0.01612916585457112, 0.028911444158958535, 0.04145128699019551, 0.037360375614038537, 0.007646259302938623, 0.01159809305266078, 0.04118815789531384, 0.0547263496555388, 0.033963015236492665, 0.017410146671214273, 0.02859833078192813, 0.0082906775808494, 0.017448609428746358, 0.11250599154404231, 0.09111206060541527, 0.020985946491626755, 0.035794248937496116, 0.015723983757197857, 0.028789755688714128, 0.05409710681332009, 0.015827745332249572, 0.04634703928604722, 0.034639521435435326, 0.025873892242088914, 0.03668842917042119, 0.040386716436062536, 0.042498520974602015, 0.06156344152987003, 0.012913653710191804, 0.014892286421465022, 0.06675585612122502, 0.011128016714272755, 0.1393862377320017, 0.049259837450725694, 0.04742117039859295, 0.018370741911764656, 0.03536719596013427, 0.07548107007252318, 0.020774014560239654, 0.06434555724263191, 0.11278725109462227, 0.024611856123166423, 0.03628347607861672, 0.05252832367217966, 0.03790960221418312, 0.5206761807203293, 3.559437070574079, 12.802169680595398, 22.966313328061783, 32.21769210270473, 48.883818422045024, 67.56233760288784, 75.49433858054024, 66.950562613351, 65.66106728145054, 60.87943513052804, 50.04027312142508, 46.00201831545149, 44.84648077828543, 25.804009744099208, 24.421677793775284, 23.8411123752594, 20.166119813919067, 20.35857449259077, 11.771195105143956, 22.32577105930873, 21.8400103364672, 12.713501981326512, 11.267375145639692, 30.18472909927368, 44.14062023162842, 37.94600241524832, 32.91985968181065, 33.60628959110805, 44.85368258612496, 25.968636887414114, 22.440155778612407, 15.8993387562888, 17.01702424458095, 13.288705127579824, 6.971689147608621, 12.099191767828804, 14.529473611286708, 20.766661303383962, 17.184236117771693, 14.883545126233782, 17.742791380201066, 18.489410059792654, 20.299011060169764, 21.686109474727086, 22.89911208833967, 25.707961320877075, 26.682196038109915, 26.929515429905482, 27.47770745413644, 27.54381087848118, 39.4523857661656, 36.49035133634295, 49.13733386993408, 32.44358846119472, 35.86782053538731, 43.1211701120649, 59.96400301797049, 66.60856533050537, 42.8010561806815, 55.40635299682617, 28.53955374445234, 19.889612776892527, 25.495299543653214, 15.284074034009661, 26.15630946840559, 28.908067090170725, 23.600847142083303, 32.27717215674264, 32.77382244382586, 44.70003359658377, 47.7303375516619, 49.69435010637556, 54.69959960665022, 56.4079566683088, 46.73478923525129, 31.38114983694894, 21.234073570796422, 7.462970648493085, 3.767688478742327, 0.44722424926502363, 0.052399120426603725, 0.060880482462900024, 0.022787494285564338, 0.04128117486834526, 0.03855511971882411, 0.03647489759272762, 0.01976532645390502, 0.06571900711527892, 0.06224454819623913, 0.05781930565301861, 0.0662187956539648, 0.05952147860080004, 0.07433165210698332, 0.03883998568302818, 0.05109004995652607, 0.036264008908931694, 0.0074613415469814625, 0.05932813683258636, 0.03139236496229257, 0.018696189359096543, 0.1010913158367787, 0.07337565054850918, 0.0389897349689688, 0.02079772257379123, 0.042107847652265, 0.010428228282502719, 0.019848786261198775, 0.11444399612290518, 0.021203418661441122, 0.011613276970040585, 0.03420831582375935, 0.06302297035498278, 0.034081942069211175, 0.026037565066612194, 0.030718321845467602, 0.021481974249971763, 0.04396489282537784, 0.03732784664524453, 0.08107691444456577, 0.03994657791086605, 0.031599199399352074, 0.04076787330476301, 0.03755173605999776, 0.020791885476293306, 0.05485992945198502, 0.02566384494171611, 0.04703506361693144, 0.028053027810528874, 0.015909598707886677, 0.04960913370762553, 0.03910785773769021, 0.011240622993292553, 0.055233191565743515, 0.009948895030122782, 0.049840188452175686, 0.05536834217075791, 0.02052692094418619, 0.05883726424404553, 0.0467201080173254, 0.02159430572230901, 0.05544090809832726, 0.025060776587841765, 0.021463278913870454, 0.03539724149076002, 0.044890638507370434, 0.01778141049934285, 0.017708932781325917, 0.028305268114698783, 0.028758380229451826, 0.03794031610180225, 0.008645850799179502, 0.026935565451692258, 0.027513709517994096, 0.028392926357420425, 0.02887795167043805, 0.035402530671230385, 0.04112884375665869, 0.03715314084131803, 0.033936247030006986, 0.09078386678759541, 0.03551854658871889, 0.017305528445701514, 0.04333246086857148, 0.02683852137332516, 0.013561580014148993, 0.038594281367425404, 0.024287158457030143, 0.04851472457604749, 0.09224440662988595, 0.027428393917424337, 0.017994409427046776, 0.008785471253629242, 0.054808601670499356, 0.046996801027229855, 0.1344965651099171, 0.6514935525400298, 4.790475470679147, 15.692654166902814, 27.867084503173828, 37.70633820125035, 57.05450391769409, 77.84282970428467, 81.97135203225272, 75.9940321786063, 74.74874128614152, 70.71461718423026, 58.29880469185965, 52.3496458871024, 52.35026775087629, 33.70765686035156, 36.56392581122262, 34.903212547302246, 32.2197140284947, 28.930862392698014, 19.824744394847325, 20.4775641305106, 30.111592360905238, 25.836824348994664, 18.448929854801722, 27.358806405748638, 28.331899881362915, 32.76744399751936, 28.041619777679443, 24.652017525264196, 29.031194380351476, 22.249019520623342, 17.927505765642437, 14.162269132477896, 12.762385163988386, 8.266984054020472, 5.435875398772104, 8.30515398297991, 11.636707510266985, 14.425937635557991, 13.77737888268062, 11.957628301211766, 16.85831001826695, 14.623314244406563, 16.138705934797013, 16.83192423411778, 19.01606093134199, 20.281609296798706, 21.82303067616054, 25.186858585902623, 30.033567564828054, 26.418129750660487, 32.148654801504954, 34.46257168906075, 39.15979017530169, 27.823109354291642, 33.618827615465435, 41.09481484549386, 44.90865673337664, 55.605967794145855, 34.3524740082877, 48.668434688023154, 38.13744960512434, 34.94608293260847, 35.92510148457119, 23.185324021748134, 31.16951813016619, 36.5486467225211, 31.52796527317592, 40.81815842219761, 40.41221339362008, 53.291977950504844, 57.23855127607073, 57.4239570072719, 62.272326605660574, 65.42008290972028, 55.62041309901646, 41.21327815737043, 29.882562364850724, 13.563389131001063, 7.061442502907344, 0.8151870859520776, 0.03786196227052382, 0.08299502437668187, 0.02865750921357955, 0.06315431437854256, 0.06844118782984358, 0.10163645765611104, 0.016813622787594795, 0.12159158901444503, 0.012768549844622612, 0.06881777476519346, 0.048429520933755806, 0.008503796948519136, 0.09257336719227688, 0.019259663498295203, 0.01027584373618343, 0.01240628763168518, 0.032674046366342475, 0.06813839157777173, 0.025648213191223995, 0.05594317328983119, 0.015760034322738647, 0.033415349266890965, 0.08268196188977786, 0.0494442293420434, 0.02137265377677977, 0.03996595347832356, 0.042082127782383134, 0.055272611057651896, 0.08466057678950684, 0.054596664650099616, 0.020018045125263076, 0.006613120611291379, 0.038570712453552654, 0.05531478540173598, 0.07055183207350117, 0.05478118207039578, 0.04789833997243217, 0.0685012246082936, 0.029756759692515646, 0.029046682973525355, 0.043939342589250634, 0.05385564673425896, 0.01836790733172425, 0.03208416534055557, 0.052871190809777806, 0.09012709917234522, 0.07074758264103106, 0.021888206380286386, 0.02676537529831486, 0.17403542489877769, 0.14937242759125574, 0.17138791696301528, 0.16040046725954327, 0.0840787940791675, 0.11310215241142682, 0.056529251126838584, 0.09987822414508887, 0.11007262247481517, 0.15675712775971207, 0.11881593295506068, 0.12555552273988724, 0.08959655942661421, 0.11028007098606654, 0.18916074399437222, 0.161763318415199, 0.08521360997110605, 0.08109928574413061, 0.13998668694070407, 0.23146452541862214, 0.16032200146998676, 0.11744092245187078, 0.24279410604919704, 0.10649576583611113, 0.16275867500475474, 0.0833392044795411, 0.11746076281581606, 0.13688279635139874, 0.1930964778044394, 0.1422820623431887, 0.159369433298707, 0.18763926492205688, 0.09522937038647276, 0.17420501794133866, 0.17369642880346092, 0.06905834257070508, 0.12267139607242175, 0.11349940073809453, 0.130703866481781, 0.12330095443342413, 0.11708869492369038, 0.1930009943566152, 0.10485489174191441, 0.22506971284747124, 0.11182082045291152, 0.32225823774933815, 1.1745359748601913, 7.497454558100019, 21.674955878938945, 35.45022685187203, 47.12196370533535, 69.73853424617222, 89.21634987422398, 92.8518419265747, 83.30253655569894, 82.66539369310651, 79.12375095912388, 67.60950197492326, 61.83237361907959, 61.01023496900286, 39.27436249596732, 37.0888101032802, 36.20261948449271, 31.809019906180247, 30.784205777304514, 18.60946798324585, 32.97924246106829, 36.58854675292969, 21.82576652935573, 21.432043382099696, 44.030880383082796, 60.083185468401226, 52.61534152712141, 46.26844351632254, 45.2749970299857, 56.244535037449424, 33.70159108298165, 29.74429668698992, 23.68677203995841, 21.473287888935634, 16.762040989739553, 9.377968873296465, 16.31755951472691, 17.937947171075002, 25.369191476276942, 22.04395386150905, 20.25888695035662, 23.07128323827471, 24.332398653030396, 25.64752241543361, 26.709926298686437, 30.21748638153076, 32.36478199277605, 34.723594665527344, 35.64677401951381, 39.69827904020037, 38.73608555112566, 53.938240323747905, 52.70592519215175, 65.02084636688232, 44.76132713045393, 50.96919863564627, 55.07815483638218, 73.16089725494385, 76.54147379738944, 56.273752212524414, 66.11192199162075, 41.82569932937622, 34.98407220840454, 38.85653952189854, 25.98905416897365, 38.650647027151926, 41.541212286267964, 38.79543358939034, 47.83198274884905, 49.43810054234096, 62.692880221775596, 64.54544367109025, 64.67618792397636, 69.09588146209717, 73.53928225381034, 65.84147725786481, 48.826836245400564, 34.92672177723476, 16.40311442102705, 7.201139509677887, 0.9354352163416999, 0.1477718720478671, 0.14510380450103963, 0.14010395136262688, 0.10037225192146641, 0.12584860915584223, 0.1732409011040415, 0.11376657390168735, 0.22846385357635363, 0.10039671310888869, 0.18015999054270132, 0.12009874411991664, 0.10422643939299242, 0.2092256894601243, 0.13657793056752, 0.13680205068417958, 0.10996375153107302, 0.13272131394062722, 0.21354753683720315, 0.09661296435764857, 0.1558332751904215, 0.15271265192755631, 0.15182588808238506, 0.11725971288979053, 0.14525662415793963, 0.0993454045216952, 0.1314230186066457, 0.1777938710791724, 0.2693974556667464, 0.19629836242113793, 0.17164908509169305, 0.24640220244015965, 0.13408876556370938, 0.14648808379258427, 0.15046142201338494, 0.1700658050498792, 0.1595797384423869, 0.20029410586825439, 0.10943229576306683, 0.15959979593753815, 0.16906029757644447, 0.14013645319002016, 0.10315501224249601, 0.1197688268231494, 0.0979518700124962, 0.18404714124543325, 0.21647688107831137, 0.13371345427419457, 0.1546062124626977, 0.16550032288900443], [0.040045321719454866, 0.05692033496286188, 0.09983458755803959, 0.02270597848109901, 0.04738487556044545, 0.021420364966616035, 0.026127777993679047, 0.05128385652122753, 0.019479878645922457, 0.07508211183760848, 0.04333295959181019, 0.03732372454500624, 0.06578774949801819, 0.023989363008045723, 0.029464820000742162, 0.049095923746270795, 0.04981555423832365, 0.02968902832695416, 0.021820327433358346, 0.06333576142787933, 0.029814723546483686, 0.03503023207719837, 0.016851902340671847, 0.03604241633521659, 0.062476261119757376, 0.08726146258413792, 0.09520794903593403, 0.019919669421921884, 0.008703705239375787, 0.03611185082367488, 0.02140777135666992, 0.02468417099277888, 0.07482030588601317, 0.03232019713946751, 0.03978207388094493, 0.026509582863322327, 0.04413402446412614, 0.031206554932785884, 0.014046025179725672, 0.012530596095270343, 0.04608009343168565, 0.011324841911638421, 0.022365654153483253, 0.03518748256777014, 0.08946233841457538, 1.3286194439445222, 5.929803729057312, 17.394968032836914, 31.36847632271903, 52.624436719076975, 59.72783374786377, 70.20773220062256, 67.15130996704102, 70.16986451830182, 59.04167134421212, 54.42795283453805, 39.09868424279349, 34.43506724493844, 37.534002031598774, 31.139679091317312, 19.879746334893362, 12.181475809642247, 12.378053375652858, 10.895458051136561, 17.077966894422257, 27.107464006968907, 56.988683632441926, 14.416942323957171, 23.119958843503678, 39.59044994626726, 37.750747612544465, 27.04541138240269, 27.181575230189733, 25.52971397127424, 15.183530126299177, 12.537630047116961, 7.158321235861097, 4.831769483430045, 2.5932077637740543, 1.8694360639367784, 1.9025472700595856, 2.7699527825628008, 2.051737470286233, 2.108304492064885, 2.5386917633669714, 3.6887691020965576, 5.101579325539725, 3.3522817407335554, 3.7072170036179677, 3.1166778802871704, 4.476664423942566, 3.585213367428098, 4.993875299181257, 13.834498286247253, 12.693901981626238, 14.586384568895612, 18.941383429936, 18.076014825275966, 20.35419886452811, 27.35647702217102, 38.55748905454363, 36.57786042349679, 36.061949729919434, 50.673684801374165, 55.431369985852925, 64.18918868473598, 50.06119762148176, 24.06643898146493, 31.718411922454834, 10.845398885863167, 31.82294409615653, 25.628689323152813, 15.309433221817017, 28.509441988808767, 26.136811086109706, 26.949229206357682, 30.508657591683523, 38.52473872048514, 38.5284594808306, 48.990243979862754, 51.48087787628174, 56.40752240589687, 57.058252470833914, 53.95460680552891, 41.06371470860073, 23.638414314814977, 12.345395105225698, 3.485681942531041, 0.28191050993544714, 0.06270225399306842, 0.06008179246314934, 0.07584190142474004, 0.10867766304207699, 0.02508134807326964, 0.017395761728818928, 0.02178270266657429, 0.02943184319883585, 0.03950859373435378, 0.012324332475795277, 0.026987420794154917, 0.04374923064772572, 0.01391369303954499, 0.037724925338157585, 0.04091536985444171, 0.1292355302721262, 0.046082034041838985, 0.05662919933508549, 0.1014311465301684, 0.028165291429364255, 0.017304924549534917, 0.018510920461267233, 0.015334306185000708, 0.036769453036997995, 0.027480049092056494, 0.026839975134602616, 0.0363466917936291, 0.03499437828681298, 0.05613837085132088, 0.04564075557781117, 0.06955582409032754, 0.05896614518548761, 0.06126480469746249, 0.09763835290712969, 0.0380284442300243, 0.01822360498564584, 0.05488434653463108, 0.026911085604556968, 0.02705100122173982, 0.0109440870749365, 0.02437488455325365, 0.061792908502476554, 0.05689027586153575, 0.032138431178671975, 0.05274698158193912, 0.04387711075001529, 0.005197290289548359, 0.09159167629799672, 0.054900414243872674, 0.04686183701934559, 0.00849190731865487, 0.026932869971330677, 0.013340018822678497, 0.00743181085480111, 0.031837086991540024, 0.054617970649685176, 0.04842908327866878, 0.0456173461196678, 0.059171870217791626, 0.09698235203645059, 0.053890808418925316, 0.010301488967213248, 0.039355139647211344, 0.04906203770743949, 0.018612042535096407, 0.004691902988789869, 0.045487935920911174, 0.03558560959728701, 0.025754724529438784, 0.020667379389383962, 0.03571486034031425, 0.03096914231511099, 0.04396645684859582, 0.05102691227304084, 0.02643524426301675, 0.014521153211327536, 0.006470535382894533, 0.019841318983318548, 0.02910425327718258, 0.005576066348502147, 0.008057377733556288, 0.02977643720805645, 0.015704677739579762, 0.04346380149945617, 0.05658706231042743, 0.09634309741003172, 0.02782449891258563, 0.02018934807607106, 0.028689641239387647, 0.011879774143121071, 0.028517144066946845, 0.1582324800214597, 1.5182194986513682, 6.6750887887818475, 20.590218748365128, 36.3541145324707, 59.35661234174456, 67.99066625322614, 79.31650788443429, 76.52435343606132, 78.08912249973842, 68.85652991703579, 64.83703177315849, 53.224288599831716, 48.2565906388419, 46.486078466687886, 41.45360592433384, 27.042958668300084, 18.5054760319846, 17.463027375085012, 14.965231622968401, 16.73651330811637, 18.06213058744158, 51.45572887148176, 22.373942920139857, 20.73659471103123, 38.31034510476248, 33.73165593828474, 25.790971449443273, 20.71239413533892, 15.374702862330846, 13.019512806619916, 11.45856351511819, 6.575016490050724, 3.852507310254233, 2.0473781270640234, 1.4603309077875954, 1.032305264047214, 1.3028876589877265, 1.364578651530402, 1.3772984147071838, 2.237983064992087, 2.5710870879037038, 3.072012254170009, 1.9699061470372337, 2.3605080332074846, 2.029853250299181, 2.4972375077860693, 2.8337923969541277, 4.340589599949973, 9.41663646697998, 10.90125024318695, 13.726486802101135, 15.959692546299525, 17.140584060123988, 20.14731104033334, 26.92729374340602, 26.26397701672145, 30.45111608505249, 31.517685413360596, 47.17352628707886, 56.58276987075806, 58.62318134307861, 59.070422989981516, 28.484588282448904, 31.694284302847727, 20.148617301668438, 32.8239015851702, 37.69958107812064, 27.95677706173488, 39.74107299532209, 36.9788270677839, 36.396109444754465, 39.75552872249058, 47.290367194584434, 45.59429802213396, 56.98895113808768, 57.72367450169155, 63.987100328717915, 65.92218058449882, 65.29685660770961, 53.77933154787336, 32.37318236487252, 19.733363424028667, 5.851810199873788, 0.4417290384215968, 0.10815513679491622, 0.05532838663618479, 0.04484233699206795, 0.024964041242908155, 0.047089631403131146, 0.05731695903731244, 0.046134678181260824, 0.0340038630446153, 0.010197528072499802, 0.06411471284393754, 0.09817280779991831, 0.07881944200822286, 0.05124518681051476, 0.022137254177193557, 0.036051627448094745, 0.050927445824657164, 0.03581279669223087, 0.005692160297517798, 0.05475416959130338, 0.05226376286840864, 0.061182315195245404, 0.025255488996793116, 0.050723240710794926, 0.050299621120627434, 0.042735044711402485, 0.0537656085299594, 0.04231654127527561, 0.03482798453686493, 0.03844284252928836, 0.05214144675327199, 0.054558310458170514, 0.0029080590216575986, 0.05427532742864319, 0.05775629010583673, 0.07164996636233159, 0.04419131317575063, 0.027463621759255017, 0.018906635298792804, 0.07478369892175708, 0.01899075328505465, 0.014294804107131702, 0.04185987024434975, 0.029260102592940842, 0.03125463253153222, 0.043208268604108264, 0.047940768767148256, 0.028432361116366725, 0.1240299181746585, 0.13773123653871672, 0.2175099506442036, 0.17825384996831417, 0.1489640309342316, 0.09957286981599671, 0.13166593414332184, 0.1519037296197244, 0.13653421934161866, 0.17602180902447018, 0.25920333553637775, 0.16085068881511688, 0.14265995206577436, 0.14378748727696283, 0.11888210369007927, 0.1665372872459037, 0.07917740315731082, 0.16135123052767344, 0.08652287043098893, 0.2244043821202857, 0.11290528226111617, 0.11345600163830177, 0.17032618607793534, 0.2220951917448214, 0.14702009595930576, 0.1694636187915291, 0.13433613229010785, 0.10706069373658725, 0.11626583550657545, 0.08877382893115282, 0.15948889617409023, 0.12613306460636003, 0.14712919081960404, 0.12031218409538269, 0.1065829372299569, 0.1871066420738186, 0.11534449351685387, 0.14203906538231031, 0.2035760169050523, 0.14681785181164742, 0.12656530498393945, 0.1580726443124669, 0.12473742663860321, 0.09292706035609756, 0.30946608845676693, 2.2607653396470204, 10.104020016533987, 26.675647360937937, 46.56490230560303, 71.45199475969586, 79.08242307390485, 87.58939443315778, 83.6090841293335, 87.03872885022844, 74.91577598026821, 70.84994724818638, 51.393493856702534, 48.54034117289952, 51.11252955027989, 45.93102857044765, 31.33202259881156, 23.312231131962367, 22.46362853050232, 19.66010856628418, 26.864904131208146, 36.74586091722761, 68.38685253688267, 23.229549305779592, 34.618173122406006, 52.65758657455444, 50.51881987707955, 38.92096669333321, 36.74812602996826, 31.005095958709717, 20.908666849136353, 16.703137636184692, 10.311645218304225, 6.673890224524906, 3.4077096922057013, 2.516612342425755, 2.4848408358437672, 4.511817531926291, 3.0209243212427412, 2.9796689578465054, 3.7422029205730984, 5.029774469988687, 6.914074684892382, 4.887787163257599, 5.1615466220038275, 4.591184633118766, 5.986985666411264, 4.942595422267914, 6.681400792939322, 17.32229334967477, 17.366574219294957, 18.809471879686626, 24.560902323041642, 25.601205723626272, 28.34775914464678, 36.68690892628261, 47.39901270185198, 47.5922976902553, 46.069047587258474, 59.60692119598389, 64.13267203739711, 73.3848237991333, 61.99291869572231, 39.27585983276367, 44.30424683434622, 20.65075319153922, 43.320218631199424, 38.41766003199986, 27.523365804127284, 42.19074378694807, 40.39245271682739, 40.15862151554653, 45.83613007409232, 54.40428727013724, 53.81345762525286, 65.31342111315045, 67.13443974086216, 73.45058849879673, 75.44968945639474, 75.16878768375942, 64.3038409096854, 40.453603812626426, 22.59357374055045, 6.706334403582981, 0.7140766829252243, 0.22914043441414833, 0.24092018231749535, 0.12790260251079286, 0.2813566353704248, 0.26077189136828693, 0.2731220972325121, 0.1396035182156733, 0.11182461346366576, 0.228451205683606, 0.13056613744369575, 0.16708531283906528, 0.22923000103660993, 0.19406800424414022, 0.16008816473186016, 0.21100250125995704, 0.19462076601173195, 0.11525093710848264, 0.09521115172122206, 0.2274080937994378, 0.14507945866457053, 0.1599273926445416, 0.1285712987716709, 0.12738783870424542, 0.17225713389260427, 0.12837731918053968, 0.14787342159875802, 0.21643934452107974, 0.13540749837245258, 0.21272135259849684, 0.2345654033124447, 0.19265707209706306, 0.08288588880428246, 0.19778853388769285, 0.22513224663478987, 0.13324858993291855, 0.14151491065110477, 0.15503336382763727, 0.13761170580983162, 0.2960888791297163, 0.20724594140691416, 0.17018543077366693, 0.20819289130823954, 0.1552282797970942, 0.0882353096136025, 0.23128118525658334, 0.12067217406417642, 0.15832921197371824], [0.059736011017646105, 0.005442367384343275, 0.03622945451310702, 0.04427567543461919, 0.014790346712938376, 0.010722333349154463, 0.022712512773328593, 0.026511245274118016, 0.025803794485649893, 0.07440363788711173, 0.08293576791350331, 0.00570127259873386, 0.015065972726526005, 0.028128667501732707, 0.0540994613298348, 0.012202850958731557, 0.04695581751210349, 0.034180567134171724, 0.04006301452006612, 0.042365847022405694, 0.058066597740565024, 0.01300583778148783, 0.04537945513480476, 0.017350881726347973, 0.052131753880530596, 0.04500181647017598, 0.023294470206435238, 0.021059771101655703, 0.08163633264069046, 0.056296340589012416, 0.057612101414373944, 0.027116456102313738, 0.06794468340064798, 0.018850964893187796, 0.05806097947061062, 0.05247829867792981, 0.06645386732582535, 0.032513793358313184, 0.012738137056918016, 0.03478945731850607, 0.0183270188115005, 0.05948666975434337, 0.01302321845599051, 0.20879928448370524, 1.2018282817942756, 7.913850545883179, 23.837725128446305, 44.82291596276419, 60.52024105616978, 67.47172614506313, 70.58965383257184, 71.51987865992955, 67.8359785079956, 59.12948962620327, 44.38448115757534, 39.0764604296003, 34.42593036379133, 28.121390308652604, 22.016803775514873, 15.232643468039376, 13.604273200035095, 17.39001223019191, 29.061483315059117, 30.236760684422084, 35.76097808565412, 43.14674990517752, 42.17037514277867, 28.355277095522197, 43.245942388262065, 24.02123921258109, 18.152929646628245, 12.937604836055211, 9.860884308815002, 6.192772201129368, 1.3137158836637224, 0.6893296965530941, 0.7647359445691109, 0.18036348319479398, 0.09717485242124115, 0.1274880583264998, 0.06263623253575393, 0.0133803687557312, 0.09196917247027159, 0.1684786844998598, 0.238881808838674, 0.1683783834534032, 0.032657714028443606, 0.22995245084166527, 0.28687779339296476, 0.40996475145220757, 0.7033950218132564, 0.5014289649469512, 1.6938178475414003, 1.7957530234541212, 3.2356705580438887, 4.024594213281359, 4.943378831659045, 7.467541694641113, 6.91158766405923, 9.04098732130868, 10.785136290958949, 18.43501956122262, 18.710757085255214, 17.10576489993504, 16.22097955431257, 22.564446892057145, 22.64860347339085, 34.09398365020752, 36.746517521994456, 31.803965091705322, 26.347398826054164, 10.645494869777135, 14.711264542170934, 11.447722588266645, 15.784255743026733, 24.18696764537266, 21.472671236310685, 23.477902242115565, 31.833936146327428, 30.68979365485055, 44.09702723366873, 40.85189192635672, 50.20756837299892, 55.29509149278913, 56.418973037174766, 51.14515134266445, 42.48926619121006, 25.97693998473031, 10.578771318708148, 1.850055149623326, 0.247480503150395, 0.04671873398391264, 0.034231657428400855, 0.0581656638532877, 0.06469786619501454, 0.045228294496025355, 0.031321464838193994, 0.05228509261671986, 0.03493425329881055, 0.02652726378957076, 0.04700175094019089, 0.05778104306331702, 0.024415145428585153, 0.05815698539039918, 0.06146989190684898, 0.05671953609479325, 0.041757682870541296, 0.11895324130143438, 0.07885785387562853, 0.0511564581788012, 0.020225987270740525, 0.04164285778201052, 0.05536626246092575, 0.028346271985875707, 0.032196985358106237, 0.03523506822862795, 0.01914317939164383, 0.008310492499731481, 0.044893261045217514, 0.04635727498680353, 0.03174185460167272, 0.029309340486569063, 0.030429354137075797, 0.06699872416044984, 0.16790030124996388, 0.04555714649281331, 0.019843341017674123, 0.036761256333972724, 0.07910011801868677, 0.02955740949671183, 0.06685084423848561, 0.10239284778279917, 0.013246464958813573, 0.015420636195423347, 0.10457899261798177, 0.0318509053571948, 0.05093458401305335, 0.012704030494205654, 0.016633398797629134, 0.061903753983122964, 0.0729723564748253, 0.014609025192580052, 0.010158703146901513, 0.039942357423050065, 0.10558010318449565, 0.018897196876683404, 0.05618084375081318, 0.03064927751464503, 0.022255714517086744, 0.01400931558704802, 0.02445114680033709, 0.015058415542755808, 0.03205382803987179, 0.022357620298862457, 0.033743071502872875, 0.06581950493689094, 0.031315520871430635, 0.04446134636444705, 0.027914762729778886, 0.06594507462744202, 0.011259248779554452, 0.05467851632939918, 0.09064858047557728, 0.038462397908525806, 0.10723468368606907, 0.030793181221399988, 0.013152408979034849, 0.039097201345222335, 0.06948567714009966, 0.026609483574117933, 0.08820305205881596, 0.03507022153852241, 0.03212679769577725, 0.009363639916825508, 0.0234260720733021, 0.11545062996447086, 0.04239718516224197, 0.008617571155939783, 0.022873722515734177, 0.11491598508187703, 1.759530435715403, 10.125491687229701, 27.816367864608765, 50.874661445617676, 69.71903760092599, 77.92729895455497, 77.16110025133405, 78.82520771026611, 76.52178955078125, 68.85896873474121, 53.24680423736572, 47.843092918395996, 37.203566551208496, 36.6608566556658, 31.29299804142543, 26.851594856807164, 23.34677583830697, 21.407978296279907, 27.448245355061122, 28.99909543991089, 35.73833738054548, 42.19303669248308, 50.274184226989746, 25.755535636629375, 33.31028938293457, 19.72942726952689, 16.8099661895207, 11.432952455111913, 9.99077480179923, 5.233291983604431, 1.8018614671060016, 0.8085433595946857, 0.5575476107852799, 0.21857466708336556, 0.1312050460172551, 0.09074608595775706, 0.026572272713695253, 0.08867813513747283, 0.11897944632385458, 0.03407583864671843, 0.18687401312802518, 0.029887693202389137, 0.1267870637987341, 0.2253995215786355, 0.2272940727749041, 0.3269800272371088, 0.29902419447898865, 0.23859416427356855, 0.8700043016246387, 0.9930513075419835, 2.47774498803275, 2.825244809900011, 3.716941007546016, 3.8187394993645802, 5.795755173478808, 7.333552633013044, 9.48975236075265, 12.83178550856454, 15.352666650499616, 17.464239835739136, 18.912088087626866, 25.031854697636195, 24.546889543533325, 37.48779651096889, 44.80698026929583, 27.99868164743696, 36.947063377925325, 17.473486151014054, 20.668596165520803, 21.30966649736677, 23.02809497288295, 32.081761019570486, 31.111073357718332, 35.16191482543945, 40.995212418692454, 38.85502134050642, 53.17691230773926, 48.58686631066458, 57.80668115615845, 60.68833882468087, 62.397720745631624, 59.21082523890904, 51.73627281188965, 33.311647755759104, 14.537717648914882, 3.3705162022794997, 0.38610496318766047, 0.025119948234143, 0.08219243280057396, 0.01914129645696708, 0.04492608178406954, 0.017936895102528588, 0.007298611037965331, 0.06769299440618072, 0.016530437893899422, 0.017960757482796907, 0.007691627850623003, 0.07600135715412241, 0.04703579643475158, 0.12322263792157173, 0.03915708206061806, 0.06861918792128563, 0.07559878232755832, 0.025501356160800372, 0.013854396712434078, 0.027664756502157876, 0.032936554601682086, 0.037765328705843, 0.05681312642991543, 0.026171060046181083, 0.04630762318681393, 0.04059357801452279, 0.03221695464370506, 0.016023131187206933, 0.027654790519071475, 0.08165807968803815, 0.04092211788520217, 0.03250071120315364, 0.030185234200741564, 0.01857566288007157, 0.0446381352708808, 0.0273623707637723, 0.03467831328245146, 0.025863317273823277, 0.01747669738584331, 0.07715005587254252, 0.0287335424550942, 0.02781701976034258, 0.01284533626000796, 0.05650872204984937, 0.04296409099229744, 0.05399346737457173, 0.1345697654677289, 0.14698383504790918, 0.09292584577841417, 0.11577064064996583, 0.1767098299626793, 0.1158376799098083, 0.08574813950274672, 0.1474039839314563, 0.21144304690616472, 0.17090366009090627, 0.16196321483169282, 0.09517149134938206, 0.15380260986941202, 0.0767969326781375, 0.1832313793046134, 0.11653819946306092, 0.21802755072712898, 0.13835163467696734, 0.16646621748805046, 0.14510166033038072, 0.2053820328520877, 0.060036323831549714, 0.13079662221883023, 0.1521910484880209, 0.10451643847461257, 0.19384775177708694, 0.1659962912755353, 0.09881723286317927, 0.18270399474671908, 0.10269447016928877, 0.1968815361282655, 0.06915593626243727, 0.14169491242085183, 0.13669187016785145, 0.19243832597775118, 0.17419580343578542, 0.22048676519521646, 0.0719619771199567, 0.20507678708859853, 0.24678690465433256, 0.07592226711234876, 0.1308596988341638, 0.1873500868678093, 0.5223816377776009, 3.1791869146483283, 13.962248734065465, 35.26517200469971, 61.76122406550816, 78.11802700587681, 83.95889118739537, 84.92300237928117, 86.9456090927124, 85.0184497833252, 74.9980218069894, 58.834816523960654, 53.3270594051906, 47.599496023995535, 41.2591849054609, 34.31620441164289, 26.914710555757793, 24.522053207669938, 26.83425910132272, 40.47016831806728, 44.40906735828945, 48.08062750952584, 56.96477140699114, 51.27010427202497, 39.31216069630214, 54.47688552311489, 32.609744208199636, 22.82483410835266, 18.629772356578282, 13.695352792739868, 8.688641565186636, 1.9661860380853926, 1.0360559884990965, 1.0162172530378615, 0.43860286474227905, 0.3806391736226422, 0.2060159474079098, 0.18026182507830008, 0.17864433330084595, 0.17106257299227373, 0.20846312466476644, 0.533419339784554, 0.28658366203308105, 0.35893517253654345, 0.5864388176373073, 0.39510847149150713, 0.6466820335813931, 0.8771362474986485, 1.0156759449413844, 2.1373342829091206, 2.5165786870888303, 4.213490980012076, 5.519523458821433, 6.792027405330113, 9.04739442893437, 9.122580017362322, 11.512689113616943, 14.97381785937718, 22.602547339030675, 21.772539854049683, 21.526203632354736, 21.661267927714757, 29.306657450539724, 31.70280279432024, 48.55673197337559, 50.896228654044016, 42.42392185756138, 40.367835249219624, 17.703073740005493, 23.6266735962459, 20.805265494755336, 25.843115942818777, 36.55743619373867, 33.54187631607056, 36.88185453414917, 46.742147377559114, 45.117509160723, 59.96341936928885, 55.18096385683332, 65.1722754069737, 68.58142294202531, 71.18675422668457, 67.0573216847011, 62.206728662763325, 39.75449344090053, 17.48710983140128, 4.2230812311172485, 0.6618367061018944, 0.1258630890931402, 0.22624189566288674, 0.1237481768642153, 0.15727643775088446, 0.19564254475491388, 0.1204960670854364, 0.13558991572686604, 0.08263816923967429, 0.11197210662066936, 0.2321745173207351, 0.16205918682473047, 0.07697736192494631, 0.18565046521169798, 0.13704801962843963, 0.18572187423706055, 0.2766343844788415, 0.19233954484973634, 0.16591121655489716, 0.1501660014369658, 0.16057098310972961, 0.2394766669188227, 0.21021156013011932, 0.17206980394465582, 0.14135327003896236, 0.09278003538825683, 0.16814777654196533, 0.11445821821689606, 0.13760665750929288, 0.16317032862986836, 0.10572440044156142, 0.18931790627539158, 0.18680455828351633, 0.07901152848665204, 0.1814581501696791, 0.20257270788507803, 0.1440339854785374, 0.10987813398241997, 0.13973333553544112, 0.1818974201700517, 0.10275185387581587, 0.19676237180829048, 0.1444469147494861, 0.15841544020388806, 0.2461985605103629, 0.1006198086376701], [0.014855068775692155, 0.02250841792140688, 0.050805608076708655, 0.02574373395847423, 0.008410180320164986, 0.02963666238688997, 0.04526549517842276, 0.0510093619647835, 0.034372375413243256, 0.014265871373936534, 0.028127836296334863, 0.04808621953374573, 0.03734365311850395, 0.012090605151440417, 0.020779877102800777, 0.03475142203803573, 0.00791896676777729, 0.03042025158980063, 0.08531545129205499, 0.05980473304433482, 0.03875596947701914, 0.014683876086824706, 0.04107504610770515, 0.05761976886008467, 0.01766274999161916, 0.05333990922995976, 0.04336119343393615, 0.05458178098446556, 0.019801378715783358, 0.03455846364210759, 0.03333944494702986, 0.02477760356850922, 0.055734496630196056, 0.030494262796959708, 0.01735684774549944, 0.020198409911245108, 0.03980255885315793, 0.026286807942337224, 0.027525646645309668, 0.03184841852635145, 0.04039018035733274, 0.06597548656697784, 0.2502249058868204, 1.2719222520078932, 9.841736810547964, 24.448739290237427, 46.329038756234304, 61.21443557739258, 62.757144110543386, 66.04490661621094, 67.86402143750871, 65.55009065355573, 55.724194867270334, 57.3176599911281, 39.93005010059902, 37.231442723955425, 34.37232501166207, 15.52052470615932, 13.716598646981375, 18.39395570755005, 22.29173357146127, 20.127845661980764, 22.59801537649972, 30.877280371529714, 26.354699645723613, 20.31304815837315, 18.682757581983292, 23.289312498910085, 13.188437410763331, 13.245720096996852, 4.677270208086286, 2.4824419702802385, 0.5782901006085532, 0.3605434905205454, 0.18628489545413426, 0.18071633497519152, 0.038272438637380085, 0.022816538977037584, 0.04824868795861091, 0.15263680528317178, 0.09188394847192935, 0.02060698638004916, 0.024656897277704308, 0.0217461754301829, 0.040659735178841014, 0.17419885684336933, 0.09424316044896841, 0.02497806486540607, 0.04715343065825956, 0.04406511244763221, 0.03605580383113452, 0.09227671846747398, 0.10373217412935835, 0.21418556331523828, 0.43467772964920315, 0.643473105771201, 0.6555402268256459, 0.7753632685967854, 1.3640566681112563, 1.5059480028493064, 1.4206527854715074, 2.393069245985576, 2.58743685058185, 5.786647387913295, 10.911940915243965, 10.92619514465332, 25.17759837423052, 24.703034673418315, 24.392295598983765, 39.32875994273594, 26.372363703591482, 42.63361154283796, 40.067336082458496, 28.62072433744158, 26.60313596044268, 18.110931260245188, 16.487906762531825, 19.27324502808707, 20.4970885685512, 26.21899437904358, 27.33611011505127, 37.64371061325073, 38.707789012363975, 50.81218671798706, 48.58296489715576, 51.469083309173584, 55.51014518737793, 44.4603659084865, 36.14258010046822, 23.9055586542402, 10.173710448401314, 0.9749829513686044, 0.08283866276698452, 0.020014377643487284, 0.09177178663334676, 0.0899403120524117, 0.024977898624326502, 0.08323686104267836, 0.05135496359850679, 0.04138746398634144, 0.060844472609460354, 0.11925787638340678, 0.006223579170182347, 0.07619466499558517, 0.01695857143827847, 0.03202389446752412, 0.02212966645934752, 0.03422953700646758, 0.019930054400382296, 0.07147820200771093, 0.006990570134283709, 0.09748969266989402, 0.024934808257967234, 0.019058438849502375, 0.04832920292392373, 0.06411906225340706, 0.004255292845690357, 0.03540042721267257, 0.024506028408982923, 0.046980804564165216, 0.07218285383922712, 0.04175030040953841, 0.08494812635970966, 0.07141773096684899, 0.04108229286170431, 0.04976520693993994, 0.022198939795738885, 0.02903276282761778, 0.08050632077668395, 0.058273564491953166, 0.08055898866483144, 0.02259373352197664, 0.016025533201172948, 0.05035669270104595, 0.0454393799549767, 0.07621027808636427, 0.02736351409527872, 0.009367435472086072, 0.032778730749019554, 0.08546834558780704, 0.0457822131658239, 0.06414260741855417, 0.052984428126364946, 0.019126750362504805, 0.040942969266325235, 0.021371276350691915, 0.027371629374101758, 0.027036200676645552, 0.028547203168272972, 0.03210050446380462, 0.009523258494612361, 0.013202408528221505, 0.04235390819875257, 0.02281835405821247, 0.0699265959805676, 0.030083253780113797, 0.05757417809218168, 0.04464662713663919, 0.04621606167139752, 0.010820500402977424, 0.027667463856882284, 0.038430106426988325, 0.0219196259443249, 0.035778591741940806, 0.0902068881051881, 0.012385329381296677, 0.036041710658797195, 0.05459929397329688, 0.04710835557697075, 0.03243212149079357, 0.02864303606163178, 0.06341035278247935, 0.011341219202482274, 0.021605720377660224, 0.03529866053057568, 0.03677032834717205, 0.0642889877781272, 0.11895776034465858, 0.15059244712548597, 1.80618693786008, 10.645199571337018, 28.863919973373413, 54.28076219558716, 72.53708798544747, 72.6775736127581, 74.56949165889195, 75.76870209830147, 75.48994731903076, 63.081277574811665, 64.45524910518101, 45.850328717912944, 49.26640708105904, 44.50920827048165, 23.989727394921438, 22.093560525349208, 25.817546572004044, 26.001496655600413, 19.816512516566686, 31.74261597224644, 40.937889780317036, 34.48827654974801, 25.281748397009714, 20.60544572557722, 19.86178524153573, 11.885768294334412, 8.283350535801478, 4.0792535202843805, 2.043955487864358, 0.9664969210113797, 0.5579354614019394, 0.16663275712302753, 0.02137881826742419, 0.06329148701791253, 0.1287302795265402, 0.06760613513844353, 0.17928805947303772, 0.13103501871228218, 0.03710696314062391, 0.04120924337101834, 0.03564221298854266, 0.04024906203682933, 0.057666933829230924, 0.06471453101507255, 0.11226885034037487, 0.06044411659240723, 0.08133213182113, 0.03273567770208631, 0.052532951281006844, 0.07922217968319144, 0.16282925621739455, 0.32023283786007334, 0.310681588947773, 0.4806077650615147, 0.6752090571182114, 0.9022358549492699, 0.9989217753921236, 0.983789901648249, 1.968160195010049, 2.4885867834091187, 5.31278806073325, 7.038482180663517, 10.706533925873892, 19.214628287724086, 23.922418458121165, 23.241613115583146, 33.915751934051514, 27.05567560877119, 33.65683773585728, 37.30881091526577, 25.944919211523874, 33.31788376399449, 26.61105169568743, 26.028664112091064, 27.18622531209673, 30.59469018663679, 36.76368999481201, 38.14210489818028, 48.16482925415039, 49.85407182148525, 58.35907336643764, 57.657169818878174, 59.03312505994524, 63.89283411843436, 54.79601975849697, 45.145680631910054, 29.5734543800354, 14.067594715527125, 1.4712642239672797, 0.05880134938550847, 0.10914420336484909, 0.02937279368883797, 0.037751004831599336, 0.04404843744954892, 0.10579950069742543, 0.015001766350386398, 0.011926390347070992, 0.05271796403186662, 0.046283796429634094, 0.02766874459172998, 0.027290714073127935, 0.03761620367211955, 0.032172307039477994, 0.021757759719288776, 0.07950075902044773, 0.07114194719386951, 0.006919184009478028, 0.11007167252578906, 0.06117804042462792, 0.05778102949261665, 0.04761015597198691, 0.03158757948715772, 0.024393895408138633, 0.04241913577009525, 0.030977298306035142, 0.03820207116327115, 0.07444457390478679, 0.06113601875092302, 0.008156630443409085, 0.05709174647927284, 0.03418149333447218, 0.02037321579908686, 0.04795940133876034, 0.08820871104087148, 0.05753587479037898, 0.055556438863277435, 0.007197617037620927, 0.011906458380898195, 0.02255503666986312, 0.027100040643875088, 0.08688744729650871, 0.02905937157837408, 0.028151968394273093, 0.10825296797390495, 0.06925498880445957, 0.11228290280061108, 0.1852934065141848, 0.14933969506195613, 0.1363662276417017, 0.13183495721646718, 0.10653421841561794, 0.12326093443802424, 0.11179197592926876, 0.07849966880998441, 0.0959105109795928, 0.11404009136770453, 0.13012506254017353, 0.14773339911230973, 0.08158005494624376, 0.1031792698694127, 0.1947944574058056, 0.16222704281764372, 0.13654844143560954, 0.09511581076575176, 0.08708199685705559, 0.10402548446186952, 0.08467374036886863, 0.1266688494277852, 0.2626331129244396, 0.17743263260594436, 0.12368945644370147, 0.13600261429590838, 0.1654895341822079, 0.18370221475405352, 0.10196795593947172, 0.1329308726957866, 0.11357975964035306, 0.16205124796501227, 0.12688337505928107, 0.12514343485236168, 0.09485105997217552, 0.1149290536663362, 0.12053224657263074, 0.15407118760049343, 0.293083267552512, 0.3466940208205155, 3.034052073955536, 14.907162053244454, 36.460661683763774, 65.87220219203404, 80.59932599748883, 81.89959103720528, 81.44637393951416, 85.42452335357666, 79.87637288229806, 70.09012699127197, 71.92031029292515, 51.49081727436611, 49.23338576725551, 46.94582339695522, 26.02195736340114, 22.849566221237183, 29.088140078953334, 32.70832177570888, 31.68925380706787, 31.807734489440918, 42.353477546146934, 38.03811468396868, 30.10283763068063, 27.099940844944545, 31.068887369973318, 17.511374677930558, 15.68788422857012, 6.118579336575099, 2.9665961393288205, 1.0055953030075346, 0.6676546824829919, 0.35320247443658964, 0.4702607574207442, 0.23000757502658026, 0.25753004103899, 0.18645809830299445, 0.42975856789520805, 0.2714229369802134, 0.14879141162548745, 0.10826374311000109, 0.11703359788017613, 0.11678895886455264, 0.30792016855307985, 0.2537402058286326, 0.1368708677057709, 0.1416557745209762, 0.1352469027042389, 0.12360302465302603, 0.23326557448932103, 0.22778122020619257, 0.5337006875446865, 0.561174353318555, 0.9032679338540349, 0.9275006992476327, 1.2713088563510349, 2.3731939239161353, 2.305267248834882, 1.895857891866139, 3.5291713689054762, 3.3175720146724155, 7.000634474413736, 13.869768210819789, 14.536129985536848, 30.30322367804391, 31.116659709385463, 33.13826935631888, 52.74871914727347, 38.43298428399222, 54.356323855263845, 51.98801646913801, 39.41353143964495, 39.16964272090367, 29.334832395826066, 27.402020726885112, 30.256552628108434, 32.180296897888184, 39.92995629991804, 40.39591639382498, 53.473037583487375, 54.83440855571202, 66.56597982134137, 64.82522678375244, 68.77203287397111, 75.285781451634, 66.41127123151506, 56.70912286213466, 38.4038713318961, 16.948224919182913, 2.234537409884589, 0.3200133182108402, 0.21317588963678905, 0.19868520434413636, 0.22190768537776812, 0.09879510583622114, 0.31554166387234417, 0.1415894545082535, 0.0981018737490688, 0.1507870645395347, 0.21577851926641806, 0.11932201151336942, 0.16120740824512073, 0.13575990231973784, 0.14013202914169856, 0.14332499780825206, 0.17908504179545812, 0.09551132882812194, 0.1503496944372143, 0.20337065149630817, 0.1771086999880416, 0.1435399441314595, 0.12541079122040952, 0.11653085771415915, 0.1927249798817294, 0.13434025778302125, 0.13661537212984903, 0.08584580783333097, 0.1669210395110505, 0.15685901657811233, 0.14287799250866684, 0.16701675366078103, 0.19599196314811707, 0.1841341701469251, 0.17303957976400852, 0.1645605926002775, 0.1692403264875923, 0.17951916850038938, 0.14450758935085364, 0.18760381825268269, 0.1420028316123145, 0.12139860008444105, 0.22880412531750544, 0.1562004576304129, 0.23003433644771576], [0.03685070760548115, 0.025719562844772424, 0.09330626643661942, 0.011134034471719392, 0.03714405865009342, 0.058126899147672315, 0.0655033483303019, 0.08010909280606679, 0.07091288734227419, 0.05230552330613136, 0.026741964143833945, 0.052118223892258744, 0.02496910989949746, 0.04610921615468604, 0.016152482014149427, 0.021838768318827664, 0.039910456099148305, 0.016434277607394115, 0.01638918725906738, 0.04236672233257975, 0.013119189600859369, 0.053188728235129795, 0.04859904273013983, 0.015479219212595905, 0.04261909664741584, 0.045058860909193754, 0.020262158276247125, 0.03608129299911005, 0.08658269007823297, 0.009924672178125806, 0.023883112905813113, 0.06194071378558874, 0.0644504858979157, 0.02315188285761646, 0.044546851954822025, 0.033621569629758596, 0.030943218884723525, 0.06244458710508687, 0.08874096069484949, 0.021892976481467485, 0.07132513807820422, 0.1109239939334137, 1.214784066591944, 10.280501655169896, 24.684422186442784, 42.98623609542847, 64.69827624729702, 70.04217747279576, 67.163302557809, 52.42643737792969, 51.64275005885533, 51.74111223220825, 42.24506480353219, 35.90773098809378, 26.62145836012704, 19.29307692391532, 18.231661421912058, 18.895396777561732, 17.46200598989214, 33.318550791059224, 36.718578815460205, 28.50167563983372, 34.69337347575596, 25.269762754440308, 26.828160320009502, 21.734540155955724, 15.311925888061523, 6.611813281263624, 4.947777909891946, 1.1341228634119034, 0.883325246827943, 0.10158723672585827, 0.17202009446918964, 0.15227724957678998, 0.03639532579109073, 0.07655529957264662, 0.06907392173473324, 0.05218524958140083, 0.10202064418366977, 0.026697708393580148, 0.08808143144207341, 0.11230485340846436, 0.05162268298278962, 0.07814186372395072, 0.04450425352635128, 0.06881957288299288, 0.02294193224848381, 0.07365490163543395, 0.14818131364881992, 0.07131116704217025, 0.15001576021313667, 0.008964317817507046, 0.06582633778452873, 0.050789143424481153, 0.09006959332951478, 0.02637945850645857, 0.018789447212059582, 0.010875091937902783, 0.053147347777017524, 0.10062193923762866, 0.1492444830281394, 0.030835104507527182, 0.2647317945957184, 0.7134459710546902, 1.208538830280304, 2.231839120388031, 4.593898773193359, 9.137249401637487, 20.221580335072108, 16.433160168784006, 27.164927346365793, 36.096072333199636, 30.39241770335606, 36.40980781827654, 25.430655241012573, 24.141404833112443, 25.257273367473058, 19.432739189692906, 16.73151581627982, 17.766986744744436, 14.570181369781494, 22.484797954559326, 32.39913041251046, 31.385874611990793, 35.21433898380825, 47.552203110286165, 40.58175638743809, 48.754574980054585, 51.047508307865684, 46.618511131831575, 30.66850437436785, 15.758801017488752, 4.280747805322919, 0.9469576094831739, 0.010723528418956059, 0.03665772885350244, 0.1097485473645585, 0.08783536071756057, 0.0171477961952665, 0.028570761904120445, 0.013625382661952503, 0.05197195888363889, 0.03699481148006661, 0.08936267519103629, 0.0262388762286199, 0.012999824264885058, 0.029347185777234178, 0.042879593026425154, 0.020034614950418472, 0.07051183243415185, 0.03035206560577665, 0.028645478787698915, 0.032487435665513785, 0.02476101677997836, 0.09228576333927256, 0.02855631589357342, 0.06737924659890787, 0.06389095235083785, 0.06012741715780326, 0.010758249055860298, 0.028249587531068494, 0.028469307348132133, 0.007354484155907163, 0.11655851480151926, 0.030348554187055145, 0.05545428202354482, 0.06774444093129464, 0.05474641054336514, 0.012251110913764154, 0.01406568827639733, 0.03369620508913483, 0.12002418669206755, 0.0425611836835742, 0.07153060526720115, 0.027703005521159087, 0.07350175628172499, 0.04516264284029603, 0.03476246858813933, 0.004244850191753358, 0.02649252618929105, 0.04608320112207106, 0.032231685638959916, 0.02921617423583354, 0.024806359882599542, 0.06149691795664174, 0.03610530296074493, 0.029847866589469568, 0.03840198454314044, 0.04487721708470157, 0.03667467526559319, 0.03936667813520346, 0.049003710837236474, 0.06752182716237647, 0.03271623767380204, 0.015188550077644842, 0.031446963282568116, 0.01043850215085383, 0.053745374615703306, 0.08280974360448973, 0.050594383518078496, 0.02386461434486721, 0.05645898204030735, 0.061932659574917386, 0.04451719318915691, 0.05691896092944911, 0.006388505588152579, 0.022223786051784242, 0.0052351262503569675, 0.04248526918568781, 0.03960536639871342, 0.021691773885062764, 0.03570146266637104, 0.0245601076499692, 0.030236124327140193, 0.047903948064361296, 0.0316498893579202, 0.15872454004628317, 0.029396291356533766, 1.760852004800524, 11.851149763379778, 30.146864891052246, 51.10682855333601, 74.11234188079834, 78.47125952584403, 77.03057139260429, 62.157222747802734, 62.2222717830113, 60.52819674355643, 54.631201539720806, 45.55987317221505, 37.06642300742013, 28.862473011016846, 27.681110756737844, 21.641000032424927, 20.81115583011082, 33.66430010114397, 24.072671515601023, 30.136543342045375, 31.03474392209734, 22.2141204561506, 22.50388813018799, 15.160609756197248, 11.819536328315735, 5.915232488087245, 3.97989775453295, 1.4895189872809818, 0.7693848322544778, 0.09128687836761985, 0.14223455132118293, 0.2734603333686079, 0.11667580636484282, 0.18105560248451574, 0.3294292129576206, 0.09172348851071936, 0.24898218257086618, 0.10596681386232376, 0.15188098512589931, 0.09920521918684244, 0.021849875937082937, 0.031325675147984705, 0.03122388810983726, 0.042705297736184936, 0.008512867265380919, 0.1387724078127316, 0.13947140744754247, 0.25326110582266537, 0.3234289549291134, 0.3169492711978299, 0.218305465100067, 0.2268869381930147, 0.34243659355810707, 0.055518851415919404, 0.19524830233837875, 0.11331251862325839, 0.17202377212899073, 0.11614779755473137, 0.20495128525154932, 0.17811123547809465, 0.3477132889841284, 0.3995493474815573, 1.0263744337218148, 1.829560786485672, 4.084855505398341, 8.408681273460388, 14.469742553574697, 14.946191821779523, 24.021011659077235, 30.177753107888357, 30.756642273494176, 36.58089678628104, 31.85170269012451, 29.617516381399973, 28.720689807619365, 29.622487817491802, 29.81410871233259, 30.25956814629691, 27.82476649965559, 35.51062406812395, 41.986504963466096, 45.963872705187114, 44.34399747848511, 56.62944786889212, 48.64571407863072, 57.450165612357004, 62.279643058776855, 58.809358324323384, 37.63984394073486, 19.760966879980906, 4.941184503691537, 1.060628509947232, 0.010482399125716515, 0.03238967912537711, 0.062032166735402176, 0.05555031169205904, 0.01920631028977888, 0.047864901766713173, 0.03027480760855334, 0.009885291701980999, 0.02201079560576805, 0.17989770961659296, 0.027906430319749882, 0.021124555928898708, 0.032462838771087785, 0.12388350388833455, 0.07365145467753921, 0.033997213401432545, 0.031191447350595678, 0.018821506295353174, 0.053665585682860444, 0.09765554019915205, 0.07574647225971733, 0.027982253215408752, 0.04492084010105048, 0.0239116605703852, 0.03310476343280502, 0.03583705092647246, 0.016102160160828913, 0.00995625798324389, 0.023286395639713322, 0.03437833295070699, 0.045589631356831105, 0.01753568582768951, 0.05792857014707156, 0.05006077679406319, 0.0695778289809823, 0.024489244845296656, 0.06257912702858448, 0.05930849324379649, 0.10463758411684207, 0.031070966672684466, 0.017133055021986365, 0.058803384990564415, 0.23834128784281866, 0.09456273687205144, 0.21207070536911488, 0.07755988423845597, 0.09473108141017811, 0.17477961496583053, 0.17150325434548513, 0.12649460163499626, 0.14642597069697721, 0.1350023451128176, 0.15589549685163157, 0.11491739643471581, 0.11643873980002743, 0.13156110048294067, 0.13621948765856878, 0.09080393785344702, 0.1244475564786366, 0.10236734843679837, 0.1383263524621725, 0.09548173113060848, 0.11677846871316433, 0.3183154878871781, 0.20798615525875772, 0.11999338120222092, 0.1331735032477549, 0.10021987331232854, 0.1790370965110404, 0.10789069134209837, 0.21843191688614233, 0.06498325802385807, 0.10131736299289124, 0.11207140343529837, 0.18616155135844434, 0.09430408610829286, 0.17423731620822633, 0.11694392269211155, 0.17070512074444974, 0.15706886031797954, 0.20727682832096303, 0.07564752149794783, 0.1773768434567111, 0.3235205300152302, 3.1148739542279924, 16.539217472076416, 37.90539366858346, 61.03909083775112, 82.80327374594552, 87.65370001111711, 84.77347019740513, 67.03089768545968, 64.45270606449672, 65.91335637228829, 57.062730584825786, 47.8837433542524, 38.9274319921221, 28.9362142426627, 29.721020221710205, 30.892990248543875, 27.46427137511117, 45.99847820826939, 52.70689099175589, 41.342420850481304, 45.125572545187815, 35.69598116193499, 33.284654004233225, 28.302244969776698, 18.612160410199845, 8.154468400137764, 6.2855866721698215, 2.0628771696771895, 1.1133398243359156, 0.25401680384363445, 0.4110071712306568, 0.541425455893789, 0.1495358595358474, 0.30137681109564646, 0.4447608957333224, 0.13809232573424066, 0.4077337011694908, 0.1112865080524768, 0.21819147121693405, 0.3197446454848562, 0.2127895996506725, 0.2330696950001376, 0.2465499330844198, 0.18042419850826263, 0.1918536052107811, 0.28675831694688114, 0.5729492700525692, 0.3014046038900103, 0.21854877418705396, 0.42518293485045433, 0.2637123907251017, 0.20542733184993267, 0.1981218031474522, 0.21573904209903308, 0.24236527191741125, 0.11648886996720519, 0.2626594400831631, 0.2827904612890312, 0.3278979765517371, 0.39069001429847305, 0.6154289277536529, 1.2196773354496275, 1.5182253611939294, 3.3562639270509993, 5.940269018922534, 11.168671642030988, 25.284036091395787, 20.34693625995091, 35.34573289326259, 44.56647879736764, 42.66373198372977, 51.23563425881522, 38.63558333260672, 35.36323887961251, 35.641038281576975, 29.463134356907435, 26.83998441696167, 28.429350103650773, 25.96123879296439, 35.642486980983186, 44.619618620191304, 45.27323913574219, 49.99547461100987, 61.83869647979736, 56.56400973456246, 66.77022906712124, 73.70902674538749, 69.64578969138009, 51.30930948257446, 27.49973671776908, 6.896921753883362, 1.447862582547324, 0.10192043134676558, 0.08630842622369528, 0.11470322364142962, 0.18668673746287823, 0.09555491113236972, 0.10378638229199819, 0.10226886586419173, 0.1868659249906029, 0.10600292549601623, 0.2842373422213963, 0.12971026051257337, 0.09454968185829264, 0.09648012077169758, 0.14902798964508943, 0.22392150945961475, 0.16079910658299923, 0.13051885712359632, 0.2232649861169713, 0.10021042810486895, 0.2348690613039902, 0.221827523250665, 0.08283579934920583, 0.15776312377836021, 0.18150456196495465, 0.2031037701027734, 0.13818238090191567, 0.125847727060318, 0.12200298479625157, 0.07108986284583807, 0.11649569602949278, 0.11199786380997725, 0.09034480713307858, 0.1511569611196007, 0.11950487670089517, 0.15859137076352323, 0.09227652847766876, 0.22476040944457054, 0.3477173059114388, 0.11303084516631705, 0.28280935170395033, 0.12703343986400537, 0.17336740717291832], [0.054979982652834485, 0.06861610058695078, 0.037874868006578515, 0.06630526815674134, 0.0419560322271926, 0.06025118873055492, 0.04731312726757356, 0.06808488230620112, 0.03941441646644047, 0.03626499957005892, 0.018204801083941544, 0.01633569664720978, 0.04260285930441959, 0.03434174294982638, 0.03156244315739189, 0.062176640411572795, 0.029370452743023634, 0.025861040788835714, 0.01125860501945551, 0.038725089348320446, 0.07815177712057318, 0.009366052956985576, 0.06296269608927624, 0.022905170917510986, 0.0659328813531569, 0.029868561907538345, 0.023666188653026308, 0.034431285823562315, 0.03240994018103395, 0.010881706806165832, 0.05333722223128591, 0.04556667651715023, 0.0173992901109159, 0.03651410673878022, 0.021741493538554226, 0.011262254689687064, 0.036905143077352216, 0.08344817041818585, 0.01904956191512091, 0.07842218689620495, 0.11990221323711531, 2.477528942482812, 11.901384370667593, 29.480011531284877, 52.81143011365618, 66.6957791192191, 68.8553626196725, 70.22954259599958, 62.754580225263325, 53.89422695977347, 46.09397077560425, 37.96218824386597, 25.369926248277935, 22.43023201397487, 21.37060914720808, 21.122004338673182, 36.40818541390555, 34.63975075313023, 35.965644223349436, 41.99709401811872, 34.99599879128592, 26.269771814346313, 29.613208498273575, 19.11220489229475, 9.102035062653677, 5.2590398362704684, 2.512115555150168, 1.355706887585776, 0.5477568932941982, 0.2272115493459361, 0.24153862627489225, 0.16335383164031164, 0.15136149871562207, 0.0660840996674129, 0.20495413509862764, 0.02924987707020981, 0.20277368995760167, 0.009539607795886695, 0.04599016040031399, 0.11779389636857168, 0.31678976118564606, 0.021519434472013797, 0.05932891036250761, 0.051356151034789424, 0.05439154012128711, 0.03571809355967811, 0.04144290369004011, 0.22135780059865542, 0.08853504567274026, 0.2217157142502921, 0.21318544340985163, 0.18446708656847477, 0.21389174408146314, 0.33882439881563187, 0.32576270827225273, 0.14826811184840544, 0.10520497509943587, 0.10896613541990519, 0.09182940782713038, 0.16178357947085584, 0.07337003227855478, 0.14993658874716076, 0.06418508371072155, 0.08808109895991427, 0.19794330772544655, 0.48205554166010445, 0.7859479263424873, 0.859712228178978, 1.2780201647962843, 4.285067413534437, 5.638581710202353, 14.979883636747088, 24.594995396477835, 27.89708682468959, 37.98973090308053, 33.22265870230538, 35.027783325740266, 25.223889010293142, 21.279019730431692, 17.925037418092998, 18.173378195081437, 20.22257219042097, 19.150720494134085, 15.965548140662056, 28.585835695266724, 25.695397240774973, 34.97900349753243, 38.26272562571934, 41.53935016904558, 40.39698641640799, 44.321870940072195, 32.44759062358311, 17.481707606996807, 6.23199999332428, 0.49627242450203213, 0.06113777615662132, 0.06443849618413619, 0.07658592185803823, 0.0270557815009462, 0.032449665013700724, 0.021860104852489064, 0.06546286014573914, 0.061107839191598554, 0.02568497452219682, 0.03522576212084719, 0.02784012387772756, 0.051401426283908744, 0.04121678868042571, 0.03831682839830007, 0.017279016386185373, 0.08715478330850601, 0.025338270269068222, 0.05576647259294987, 0.03131138180781688, 0.03688136042494859, 0.03847616199137909, 0.05452870936798198, 0.013849952308061932, 0.06801171587514025, 0.024566852288054566, 0.05359653117401259, 0.040549697154866796, 0.018069357012531588, 0.08346092687653643, 0.03063025139272213, 0.030076163089168922, 0.10781726028238024, 0.0728498673332589, 0.03909332351759076, 0.038720770472926755, 0.01083303294477186, 0.037443750604454956, 0.02752762796756412, 0.029465335687356334, 0.03492669102602771, 0.03769131749868393, 0.07849609293043613, 0.005856241515305425, 0.043996668620301146, 0.06834288167634181, 0.03755122376605868, 0.05596995845969234, 0.029106573866946355, 0.08006953421447958, 0.02366699102068586, 0.03357055736705661, 0.015671212392460023, 0.023944306586469923, 0.034433921932109764, 0.05105415206136448, 0.05562698954184141, 0.03461394066523228, 0.0066451076002392384, 0.012204456542219435, 0.07977308226483208, 0.01894237204188747, 0.04133458914501326, 0.054048774763941765, 0.0469122352078557, 0.020344486626397287, 0.041943336836993694, 0.021931658066543083, 0.04149181249418429, 0.03656996713419046, 0.014781939664057322, 0.03714313923514315, 0.020186883297615817, 0.012361438163290066, 0.01935823597679181, 0.030154829046555927, 0.032688692544720004, 0.03943404648452997, 0.02517476198928697, 0.019684216074113334, 0.015866225053157126, 0.10569998675159045, 0.10271445981093816, 3.2288246282509396, 15.317069292068481, 35.0445944922311, 63.92901338849749, 75.35319287436349, 79.64216995239258, 78.2965748650687, 70.99711009434291, 60.01729570116316, 54.901437827519004, 48.155855655670166, 35.89808341435024, 31.983902590615408, 29.883771351405553, 24.934143917901174, 37.27896492821829, 41.751662799290244, 36.49669851575579, 35.48583289555141, 36.109190532139365, 27.55493320737566, 23.231124809810094, 16.024131877081736, 8.256719827651978, 4.440287130219596, 2.1313251767839705, 1.0581723217453276, 0.30771850794553757, 0.250090773084334, 0.20575686916708946, 0.1939876385565315, 0.3069282317800181, 0.32146462319152697, 0.2846277169883251, 0.4808007947036198, 0.5069056110722678, 0.5357781446405819, 0.5509468764066696, 0.4709775618144444, 0.7703071513346263, 0.16004749334284238, 0.06845439890665667, 0.04838968753548605, 0.07594585977494717, 0.04150512195857508, 0.07423441125346081, 0.33119047273482594, 0.3003911982689585, 0.48151369073561257, 0.8633404906306947, 1.1384299865790775, 0.9482407463448388, 1.2403887212276459, 0.9854368418455124, 0.7916572828377996, 0.6589932643941471, 0.6143906063267163, 0.4088659861258098, 0.49357364646026064, 0.28521030715533663, 0.2640359162219933, 0.2795994739447321, 0.22653386928141117, 0.13166271788733347, 0.29969727407608715, 0.6228508523532322, 0.7071298414043018, 1.4406070347343172, 3.2321793053831374, 5.504560078893389, 12.947483437401907, 18.959226403917583, 26.235070773533412, 30.522022451673234, 33.533812931605745, 32.351493562970845, 23.327305248805455, 21.05997429575239, 22.17941246713911, 18.156575713838848, 25.17124250956944, 31.029060295649938, 23.501533065523418, 42.53730256216866, 38.56422880717686, 45.37208420889718, 49.261564186641145, 51.47147348948887, 50.66276223318917, 54.257836614336284, 43.47554908479963, 22.1379143510546, 7.7776007141385755, 1.1551100058215005, 0.020799427393025587, 0.03697118828339236, 0.012594230805656739, 0.014682352775707841, 0.03497301800442593, 0.016859871734465872, 0.07884129762117352, 0.05450089621756758, 0.004910630872473121, 0.042828920031232495, 0.022504913288035562, 0.05696685532374041, 0.00395170652440616, 0.021530499681830406, 0.039473333662109714, 0.013402521227752524, 0.034449378959834576, 0.0717634242027998, 0.018131615993167673, 0.03987578295969537, 0.06940197984554938, 0.023063055838325193, 0.012225605630581933, 0.04324817664123007, 0.055083228541272025, 0.03756636188232473, 0.022405535049204315, 0.0446346713496106, 0.04873722977936268, 0.07745445346725838, 0.020652940164187124, 0.054411567082362514, 0.028239982867879525, 0.04424185724928975, 0.02640794001386634, 0.06268790976277419, 0.0309055805472391, 0.015765035125826086, 0.02832229425465422, 0.051906941658152, 0.03869505399571998, 0.15208313427865505, 0.1582754041467394, 0.16914917209318706, 0.15920891905469553, 0.11495749785431794, 0.11498564348689147, 0.11427350741411958, 0.14450525519038948, 0.08685710999582495, 0.11084945686161518, 0.09923704926456724, 0.16745858852352413, 0.19136500571455273, 0.170639927099858, 0.0820027958335621, 0.1876213244561638, 0.18681257856743677, 0.12787193272794994, 0.14557472137468203, 0.16055826736348017, 0.19283001710261616, 0.1161874918533223, 0.1420551873743534, 0.14238515895392212, 0.15496522534106458, 0.16796546775315488, 0.20592089822249754, 0.19644659518131188, 0.13368856560971054, 0.19531268174094812, 0.22224647791257926, 0.18228943699172565, 0.1135520279141409, 0.1136895873184715, 0.12540810422173568, 0.11271892261824437, 0.08547222680811371, 0.16365519618349417, 0.16306762556944573, 0.2765196034950869, 0.4626442832606179, 5.317734309605189, 20.885145459856304, 43.96471963609968, 77.22008350917271, 88.98910209110805, 87.78424971444267, 86.69216660090855, 76.61741065979004, 67.71826907566616, 60.43519510541643, 49.79105166026524, 34.318323612213135, 34.29358802522932, 32.36155455453055, 30.041502407618932, 45.73695843560355, 47.43162407193865, 48.28272976194109, 56.1328774860927, 47.30204711641584, 34.57945775985718, 36.27096543993269, 23.22571737425668, 12.315259899411883, 6.386680790356227, 3.3633263366562978, 1.676760454263006, 0.751812566603933, 0.47165273129940033, 0.459968738257885, 0.40506846989904133, 0.4882039917366845, 0.2854062680687223, 0.5654404386878014, 0.47171542793512344, 0.5110790356993675, 0.3680819874363286, 0.3672379712973322, 0.5160811958568436, 0.8483347158346857, 0.5347023137978145, 0.26312133244105745, 0.179788954023804, 0.3049953297844955, 0.21673130456890377, 0.09645171729581696, 0.5217156420860971, 0.21496593286948545, 0.4198490524930613, 1.3767808824777603, 1.1394224933215549, 0.763182207942009, 1.4438640028238297, 0.9671613425016403, 0.5995749299015317, 0.5629423441631454, 0.5268589375274522, 0.3425599512244974, 0.37293150435600964, 0.21544352652771132, 0.2942433995859963, 0.3046906404197216, 0.279626723911081, 0.4094784046922411, 0.8395881823131016, 1.224203109741211, 1.3183603201593672, 1.9453440478869846, 5.401810552392687, 7.716957705361502, 18.542952878134592, 30.681622573307582, 37.480775356292725, 49.683059283665244, 46.07660722732544, 49.85066025597708, 36.43557521275112, 30.08604383468628, 28.18325706890651, 27.67133811541966, 30.35962220600673, 30.416347299303325, 26.360749789646693, 43.814982482365195, 42.36679029464722, 50.13187122344971, 57.339192458561485, 62.48056411743164, 62.38558224269322, 65.99560914720807, 57.57418053490775, 32.37931415012905, 11.449644633701869, 2.0914512021200995, 0.16738327113645418, 0.11652985348233155, 0.2507495491632393, 0.1934038270264864, 0.08794238604605198, 0.11375057404594761, 0.15027026512793132, 0.15443172039730207, 0.0919791062229446, 0.08040943954672132, 0.09246209423456873, 0.1749178868319307, 0.16559630845274242, 0.13593055387692793, 0.07796954975596496, 0.19804111176303454, 0.1752347626856395, 0.14710846836013453, 0.11968192005796091, 0.0999220439365932, 0.13761124440601893, 0.09498849724020277, 0.08579636298652206, 0.12326717696019582, 0.08255846173103366, 0.12991242323602947, 0.14340984182698385, 0.13752971163817815, 0.23263467262898171, 0.12376999855041504, 0.105088837045644, 0.15824225092572825, 0.10632037131914071, 0.19364256278744765, 0.18664587608405522, 0.16452918999961444, 0.2192523471478905, 0.11297048269105808, 0.07629670987703971, 0.23845959720867022, 0.13512594705181463], [0.038474611538861475, 0.05465910344251564, 0.0376984624724303, 0.03592255651684744, 0.06028843351772853, 0.037605662630604844, 0.045136047660240104, 0.02749911422974297, 0.024984446487256458, 0.017124932957813144, 0.027484169495957236, 0.04673293911452804, 0.02980471515495862, 0.03914983869929399, 0.013660824242314058, 0.0362022554368845, 0.06495378924799816, 0.055114658283335824, 0.06189823749342135, 0.06212200477187123, 0.03046928931559835, 0.016367872777794088, 0.025529350819332258, 0.021216287078069787, 0.03366125375032425, 0.05649627432493227, 0.027481938812083433, 0.017024957608165484, 0.06016257884246962, 0.019141461001709104, 0.06849196939063923, 0.015622778562828898, 0.035785282097224674, 0.04995840621579971, 0.04657902701624802, 0.03701719974300691, 0.07007988382663045, 0.04648153849744371, 0.00435208883469126, 0.17502044061464922, 2.4195594702448164, 15.825196266174316, 33.72409977231707, 55.186616216387065, 66.43935585021973, 68.87599876948765, 64.8054313659668, 57.88637004579817, 53.45161281313215, 42.728471824101035, 35.634802273341585, 23.687458174569265, 23.23082603727068, 20.929271732057842, 20.049874714442662, 27.55824749810355, 42.957585198538645, 38.308083466121126, 42.65270171846662, 31.50602981022426, 15.632753746850149, 19.38242380959647, 8.248085822377886, 2.3055666727679114, 1.7963321123804366, 0.3252895793744496, 0.1705862685505833, 0.07376595746193614, 0.0973088223753231, 0.09557735707078661, 0.1926931023065533, 0.06666972967130796, 0.26812951798949924, 0.4405165777674743, 0.25593762791582514, 0.5157655413661684, 0.7672957586390632, 0.9277982775654111, 0.678067318030766, 1.0292560905218124, 0.46728394286973135, 0.08217652115438666, 0.06982885301113129, 0.030958068623606647, 0.07553575320967607, 0.0629878697384681, 0.03801784212035792, 0.3415072448551655, 0.34809682411806925, 1.4923551550933292, 0.6310029891984803, 0.6600196978875569, 0.39301063120365143, 0.6605891244752067, 1.846092939376831, 0.46923589812857763, 1.0004659039633614, 0.8443238139152527, 0.6566049296941076, 0.5953983568719455, 0.3830660219703402, 0.23283522043909344, 0.4137154487626893, 0.03308755239205701, 0.06785477751067706, 0.04675913056624787, 0.03325917086164866, 0.30292392522096634, 0.3012787220733506, 0.39341821361865315, 1.9280184975692203, 3.032574713230133, 8.188373003687177, 15.618419613157, 30.842330932617188, 38.05664900371006, 43.14444310324532, 56.121645723070415, 56.68026351928711, 53.605685642787385, 67.30422592163086, 54.06696959904262, 23.558202573231288, 31.004084995814733, 19.562885897500173, 18.353463343211583, 23.661143609455653, 31.660887786320277, 42.958304337092805, 43.46920885358538, 44.81755542755127, 35.80837869644165, 29.443634237561906, 21.224049057279313, 4.821126580238342, 1.47333239870412, 0.05192224940817271, 0.03786658648667591, 0.03082008852756449, 0.038975960708090236, 0.012478739056470138, 0.022356714454612563, 0.021656956556918364, 0.04577426752075553, 0.011543340365668493, 0.034801884687372615, 0.02539191355130502, 0.02046583074011973, 0.041755867789366415, 0.0231061512936971, 0.03902479487338236, 0.04756628529035619, 0.014648714402158345, 0.04435247202802982, 0.048864770614142926, 0.02005184125820441, 0.04591943669532027, 0.09687903829451118, 0.022362660117713467, 0.02462896877633674, 0.01775016396173409, 0.09034053236246109, 0.024075932202062438, 0.09134798044604914, 0.0341039707085916, 0.02310434978322259, 0.06650500851018087, 0.06013514567166567, 0.018656576484707848, 0.013942902275760258, 0.021463791207809533, 0.030668293458542654, 0.0565111681685916, 0.03549345097105418, 0.016338229279166887, 0.017422082102192298, 0.059765344086502276, 0.026727229755903994, 0.017379566794261336, 0.0698359776288271, 0.02677588750209127, 0.013058425093601857, 0.03159425966441631, 0.035771867459906, 0.09661335790795939, 0.014990594271304352, 0.004746439392744962, 0.024790889284174358, 0.044923642450677495, 0.08608663348214966, 0.03522387918617044, 0.017800480726041963, 0.05430197010615042, 0.10579154148165669, 0.03475912680317249, 0.07664509689701454, 0.0564540355200214, 0.035459232450063737, 0.05378534711365189, 0.09193296584167651, 0.03776611241378954, 0.04039584951741355, 0.01075716339983046, 0.033866595410342724, 0.04149154108017683, 0.0553373195497053, 0.07857265203659024, 0.019731057042788182, 0.04246776976755687, 0.10947166436484881, 0.08258115194205727, 0.06780731398612261, 0.050135446180190356, 0.05286434778411474, 0.036199412375156365, 0.3215483272714274, 3.8115442054612294, 19.625280720846995, 41.6314937046596, 64.83860901423863, 77.51393672398159, 79.32399804251534, 74.95976502554757, 69.12403556278774, 66.44583851950509, 54.14904866899763, 45.82305703844343, 35.0615758895874, 28.65473403249468, 27.993114403315953, 23.97252365521022, 22.89230111667088, 34.04931715556553, 28.88298061915806, 31.11837591443743, 29.617304461342947, 20.44346932002476, 14.622292859213692, 6.760804372174399, 1.653246990271977, 1.3023137812103545, 0.2119896611464875, 0.24495912130389894, 0.16371889705104486, 0.49376428765910013, 0.39035601222089356, 0.9572753586939403, 0.34258853111948284, 1.3365319222211838, 1.3395525429930006, 1.8720603116921015, 1.652358489377158, 1.6248956258807863, 1.4338728189468384, 1.2867277775491988, 1.782608334507261, 1.206239519374711, 0.3289191174720015, 0.04848050266238196, 0.10471471997776202, 0.04264004980879171, 0.061738774978688786, 0.20432402033890995, 0.5508859711033958, 2.19670946257455, 2.5004371532372067, 3.862038935933794, 3.4497180666242326, 3.881445688860757, 3.7435625961848666, 2.6114322372845242, 1.8444195091724396, 2.039140386240823, 1.2604773747069495, 1.2943235699619566, 1.7772614785603114, 1.377892485686711, 1.1296883927924293, 1.2773090600967407, 0.7355403197663171, 0.26848428323864937, 0.19010354126138346, 0.07381515803613833, 0.2616283654102257, 0.2436108993632453, 0.35043424155030933, 1.2144681406872613, 2.50313783117703, 6.4469650983810425, 13.212796926498413, 24.11436070714678, 28.215003388268606, 37.518073286329, 42.65805530548096, 38.869827951703755, 38.530877453940256, 53.05670847211565, 51.316024916512625, 30.510964393615723, 34.67610372815813, 27.933999129704066, 27.697145462036133, 33.657289368765696, 40.769642625536235, 55.08661774226597, 53.39015252249581, 56.88162578855242, 47.623731340680806, 39.91019909722464, 24.683207988739014, 5.204684512955802, 1.6314139046839304, 0.0609257271779435, 0.01641662891155907, 0.053919374743210416, 0.027321237970941832, 0.058001220891518254, 0.02956986061430403, 0.02197063820702689, 0.03576214066041367, 0.06037985932614122, 0.06322004406579904, 0.04287014103361538, 0.06448837529335703, 0.047594508954456875, 0.04976390754537923, 0.04596692396860037, 0.01856124909993793, 0.04677888272064073, 0.08589157502033881, 0.019913182627143602, 0.02557156078650483, 0.03561265261045524, 0.06359652243554592, 0.03260986373892852, 0.020397994201630354, 0.05618990558598723, 0.03125829662063292, 0.05101007442655308, 0.02044831944762596, 0.040845161836062155, 0.008949965105525084, 0.04244607700301068, 0.03863534291407891, 0.018590938399678895, 0.013161716783153159, 0.038897912217570205, 0.03869346961645143, 0.02851992266784821, 0.0219058465944337, 0.045434959299330197, 0.017901640119297162, 0.14665070149515355, 0.10462704646800246, 0.08004910352506808, 0.07383854713823114, 0.16914354025253228, 0.13013769686222076, 0.09921644894140107, 0.13246775897485868, 0.22334056134734834, 0.060200502164661884, 0.054007597866335084, 0.15866651173148835, 0.14314382895827293, 0.13286293776971952, 0.1058345063190375, 0.08094500723694052, 0.16722080271158898, 0.15401926610086644, 0.15975626611283847, 0.2405637071600982, 0.13882454644356454, 0.08649658398436648, 0.22405062110296317, 0.19571182318031788, 0.14116442017257214, 0.1218977440148592, 0.07696778101048299, 0.0837522219600422, 0.21818665361830167, 0.18012895435094833, 0.17213570326566696, 0.10271486014659915, 0.17272017976003035, 0.15337779266493662, 0.15228586697152682, 0.13244303315877914, 0.22779099111046108, 0.20300876162946224, 0.09453543940825121, 0.6655604520014354, 7.104147868497031, 27.169207436697825, 52.55275215421404, 76.72847066606793, 86.86018099103654, 87.15064348493303, 81.2907829284668, 73.72835663386753, 67.09407765524728, 55.591157708849224, 47.43621335710798, 34.31389760971069, 34.32362508773804, 32.4157782963344, 31.38251863207136, 40.12764992032732, 55.759804385049, 53.47757475716727, 54.38921662739345, 40.166208948407856, 22.591854061399186, 23.957416534423828, 10.43382407937731, 3.0008231827190945, 2.1443899614470343, 0.5899424467767987, 0.500074391918523, 0.44490053824016024, 0.4278729190783841, 0.47216537807668957, 0.7856067046523094, 0.6603774215493883, 1.0957115931170327, 1.8939949061189378, 2.1211497570787157, 1.1211289720875877, 1.229806940470423, 1.2193584782736642, 1.774524756840297, 2.9795210914952412, 2.022004391465868, 0.9612231297152383, 0.5652266187327248, 0.21650395462555544, 0.5388163530400821, 0.2689421586692333, 0.6129692111696515, 1.6641977855137415, 2.2006410573210036, 3.0480637678078244, 4.661332777568272, 4.872511982917786, 5.1284988181931634, 4.311968232904162, 3.5314119458198547, 1.8163780995777674, 2.5921049543789456, 2.2460950868470326, 1.2405970586197717, 1.6575051503522056, 0.8806304314306804, 1.0812022345406669, 0.8875613680907658, 0.6415557829397065, 0.30834216305187767, 0.21002539726240294, 0.18503888802868979, 0.4732374091233526, 0.6064342132636479, 0.6227045602032116, 2.574619595493589, 4.198396018573216, 10.001255290848867, 19.890688010624476, 38.19580405099051, 49.581066676548545, 57.75938129425049, 72.78662558964321, 73.17588451930455, 67.07337202344621, 78.31489031655448, 65.21075453077043, 35.29067884172712, 42.860504967825754, 30.93805626460484, 29.495801312582834, 37.41750158582415, 46.87056050981794, 62.02133682795933, 65.29484857831682, 68.04490389142717, 60.21546527317592, 46.883320876530235, 33.317393915993826, 9.468932952199664, 2.9428328658853258, 0.2283035564635481, 0.08776089828461409, 0.1707003302872181, 0.11156856148902859, 0.16285772754677705, 0.11746851168572903, 0.09865685432617154, 0.16060885893447058, 0.2541986512286322, 0.17055766151419707, 0.10113456565886736, 0.19162394824836934, 0.12173318570213658, 0.13059459520237787, 0.16968293488025665, 0.18963285508964742, 0.1077270151249, 0.18252640856163843, 0.11542840115725994, 0.11697463318705559, 0.08595165929624013, 0.18147558851965837, 0.08443929973457541, 0.12923186618302548, 0.21972025132605008, 0.15683887765875884, 0.24920162079589708, 0.1016223169863224, 0.08634075163198368, 0.14649248069950513, 0.10248590207525662, 0.14946580758052214, 0.08250190583722931, 0.09621321902211223, 0.186277499422431, 0.1390356793999672, 0.18029336338596685, 0.12858241317527636, 0.13487248708094868, 0.09316582325845957], [0.030456844983356338, 0.1277384241776807, 0.031047184020280838, 0.03630768960075719, 0.029732471531523124, 0.06086959197585072, 0.04190354754350015, 0.01598315529658326, 0.004043904590486948, 0.04140265638540898, 0.07677812368742057, 0.03210055196125593, 0.04600204494116562, 0.006119228966001953, 0.008924777037464082, 0.03873213593448911, 0.03914986244801964, 0.05282849060105426, 0.027495339878701737, 0.07004453215215888, 0.025930242879050117, 0.05730977335146495, 0.015480243800474065, 0.049587071141494174, 0.04249227845243045, 0.03768490195008261, 0.07182402416531529, 0.03148485267800944, 0.013185445152755295, 0.09571703350437538, 0.004379528366761016, 0.034948980901390314, 0.06898250949702092, 0.04145223354654653, 0.02460970007814467, 0.016069961977856498, 0.11058980186602899, 0.05926898893501077, 0.7795458670173372, 4.411619731358119, 20.618336371013097, 43.901053292410715, 64.5227439062936, 75.3382681437901, 64.86104474748883, 61.332909311567036, 52.753603730882915, 44.23960426875523, 28.241653203964233, 43.972192423684255, 27.36650848388672, 18.523781061172485, 20.813849994114467, 26.699328558785574, 37.03166811806815, 50.00670984813145, 48.758577142442974, 48.243604455675396, 33.88902221407209, 10.450621349470955, 9.703069874218532, 3.77025887795857, 1.3835323601961136, 0.3921036198735237, 0.0642524350966726, 0.04775697737932205, 0.03690065796087895, 0.16195558809808322, 0.2798769676259586, 0.25411234157426016, 0.3571591478373323, 0.27441117806094034, 1.271007586802755, 1.7258456775120325, 0.5290255269833973, 1.5935730380671365, 0.963736966252327, 2.0818602996213094, 1.5992260490145003, 0.36697928660682266, 0.8573614028947694, 0.35257434099912643, 0.07388753058122736, 0.06482464367789881, 0.013713157951964863, 0.14942679181694984, 0.2115635004426752, 0.10959639945732695, 1.293906678046499, 1.0582594999245234, 1.0998010422502245, 1.9852990124906813, 2.886440417596272, 2.151073042835508, 1.3425643699509757, 2.854050738470895, 1.3080960937908717, 0.7895559413092477, 1.6492614384208406, 1.2431019927774156, 1.7869349994829722, 1.4027656252895082, 1.1777159699371882, 0.7537481827395303, 0.4883040892226355, 0.4275650270283222, 0.16985448210367135, 0.050270308407821825, 0.06734850217721292, 0.00953796404480402, 0.1419865739132677, 0.20899893662759236, 1.0539434743779046, 3.2493020551545277, 8.866038628986903, 18.72143472943987, 32.75990867614746, 51.902567522866384, 70.43335410526821, 84.34512070247105, 84.58091476985386, 79.38426671709333, 44.402744497571675, 33.285484313964844, 20.893960986818584, 18.71501980509077, 18.4334614276886, 31.08478832244873, 32.40174988337925, 40.50851195199149, 47.35267863954817, 42.23900597436087, 36.97331714630127, 32.51974071775164, 21.129777635846818, 3.272659510374069, 0.27067025165472713, 0.023611495337848152, 0.027047549174832444, 0.15171198919415474, 0.02092484102052237, 0.057309861561017375, 0.1244532290313925, 0.05062231541212116, 0.07783027365803719, 0.06407107625688825, 0.06916995479592256, 0.006847509931373809, 0.011085337709768541, 0.014802943715559585, 0.03040787171838539, 0.038035738481474776, 0.08151610302073614, 0.019670088975025073, 0.009232886218731957, 0.047095575369894505, 0.062121251598000526, 0.014786370497729098, 0.02810007064337177, 0.04917511896097234, 0.03633019321465066, 0.04083092277869582, 0.014446522840963942, 0.033620874131364484, 0.04480377245428307, 0.03669989641223635, 0.03030056819053633, 0.009432732593268156, 0.0917274850819792, 0.04125269675361259, 0.055333234768893035, 0.015239633586523789, 0.03778062288516334, 0.038391104234116416, 0.022997280349954963, 0.02387674824733819, 0.02941373988453831, 0.054519678066883764, 0.06554803664663009, 0.020783403788560202, 0.025428288117317215, 0.01728428860328027, 0.02150686121811824, 0.018965247153703655, 0.04343236157936709, 0.055759938300720284, 0.04939621281144874, 0.05364454770460725, 0.06880950342331614, 0.007785027347771185, 0.049390828636075766, 0.03906148326184068, 0.04790494211816362, 0.037358499464711974, 0.03563870835517134, 0.08652847513024296, 0.07042118694101061, 0.06532591820827552, 0.01219285698607564, 0.03355886960136039, 0.00672018834822146, 0.0298070866348488, 0.07916387316903897, 0.11323431067700897, 0.029124463442713022, 0.06654075373496328, 0.028446769807487726, 0.02316362999512681, 0.07419109357787029, 0.04496632230335048, 0.010729306992808623, 0.10236580137695585, 0.023418065360082046, 0.05911116168967315, 0.8620516540748733, 5.625399674688067, 25.681212493351527, 53.456966400146484, 74.54378332410539, 83.23978737422398, 74.26390293666294, 69.9224739074707, 61.908164569309776, 54.151042801993235, 39.27516153880528, 49.942984444754465, 35.29267644882202, 23.669382435934885, 24.36134832245963, 20.89108443260193, 27.3955363205501, 43.41250113078526, 53.13594920294625, 44.54222958428519, 29.93882887704032, 12.931348851748876, 7.64381662436894, 3.479001900979451, 1.6019978374242783, 0.5241160275680679, 0.394539723438876, 0.1706236694008112, 0.6030375212430954, 0.9859367864472526, 0.759664519556931, 1.8191450025354112, 1.8382890267031533, 2.0481608850615363, 3.181599893740245, 3.4596411798681532, 3.6060731623853957, 2.6808310619422366, 5.293802542345865, 4.379185106073107, 4.744433666978564, 2.5770677498408725, 1.3768721861498696, 0.5262238830327988, 0.024489434835101877, 0.054285837936082056, 0.07236278775547232, 0.11002680100500584, 0.3232649937272072, 0.9276552966662815, 3.768735919679914, 4.343823552131653, 5.051961805139269, 4.72126316172736, 3.9887736439704895, 6.098510767732348, 4.436200286660876, 6.500792358602796, 4.6668882966041565, 4.379518619605473, 3.8395914775984625, 3.4310812609536305, 3.7940694860049655, 2.830643777336393, 2.8013427896159033, 2.996490112372807, 1.5372767789023263, 1.2040052392653056, 0.6493498161435127, 0.3306474818715027, 0.06478980090469122, 0.31371075926082476, 0.11282618543399231, 0.2871203018086297, 0.7994928966675485, 3.1440583424908772, 8.310059411185128, 17.545686619622366, 31.50518560409546, 51.3456381389073, 69.11542674473354, 78.4804241997855, 86.96538366590227, 80.66427775791713, 45.9896366255624, 40.755708013262065, 28.152526923588344, 25.40727628980364, 25.84410606111799, 37.71824393953596, 39.30585868018014, 49.22286966868809, 56.77282394681658, 51.86675303322928, 44.89198453085763, 41.09495380946568, 24.434474638530187, 4.506729713508061, 0.4382407713149275, 0.02787239500321448, 0.028079840121790767, 0.11033516124423061, 0.024490820742877464, 0.04966512981003948, 0.05171527247875929, 0.0464625157681959, 0.052450383747262616, 0.0906922034919262, 0.07856343753103699, 0.030803488168333257, 0.02824454601587994, 0.010437228201356317, 0.05887085851281881, 0.043692406732589006, 0.03716348510767732, 0.03830244345590472, 0.019869878522253463, 0.04965848695220692, 0.044138543507350345, 0.016894073292080845, 0.023904218737568175, 0.020675097725221088, 0.015520821890926786, 0.04006250561880214, 0.020397858494626622, 0.015435214520299008, 0.03177854638280613, 0.05420001004157322, 0.01696710062346288, 0.02469089357847614, 0.026364381458344202, 0.008236956267085458, 0.052229239006659815, 0.03776970525671329, 0.05674589039491756, 0.05348876624235085, 0.024082951646830355, 0.03115851465346558, 0.12954439941261495, 0.20234786852129868, 0.14174616895616055, 0.07400668811585222, 0.14328846548284802, 0.11119788459369115, 0.1180869285017252, 0.16684498930616037, 0.20381135999092034, 0.17988641879388265, 0.1666748805769852, 0.09918673589293446, 0.16248209056045326, 0.08027307436402355, 0.11234623725925173, 0.14638287015259266, 0.21449698374739715, 0.1124624228104949, 0.07624611152069909, 0.15801196971109935, 0.17278693403516496, 0.2046987616590091, 0.09529128670692444, 0.0719487728284938, 0.1343130620994738, 0.09426015096583537, 0.15412186059568608, 0.2590545735188893, 0.11673542245158128, 0.16696632493819508, 0.13503647542425565, 0.07732167773480926, 0.18841643179101603, 0.10758665337094239, 0.1272958700678178, 0.13202985961522373, 0.26669077947735786, 0.1664527960653816, 1.7279958192791258, 10.11025949886867, 35.346222741263254, 65.12920352390834, 87.40677492959159, 94.19785390581403, 83.14467348371232, 77.1098711831229, 68.64265741620744, 55.9241292817252, 36.36489813668387, 53.607478278023855, 36.712968145098, 26.784164326531545, 28.92737787110465, 40.883485385349815, 53.05794177736555, 67.14775248936245, 57.89721965789795, 56.84556116376604, 40.548377241407124, 14.20836521897997, 12.158673558916364, 5.039639609200614, 1.8344190972191947, 0.7548080001558576, 0.4028605712311608, 0.3230748139321804, 0.6287297883204052, 0.7421447996582303, 0.8758846489446503, 1.1844433460916792, 1.283132627606392, 2.100995638540813, 3.7247599022729054, 6.594560469899859, 4.244827355657305, 3.973847610609872, 6.500224777630397, 7.127644070557185, 5.108820216996329, 4.445664601666587, 4.255647437913077, 1.4301400078194482, 0.28075132785098894, 0.2547271214425564, 0.3222478968756539, 0.7671873558844838, 0.5258763102548463, 2.514621683529445, 5.282213815620967, 4.227600600038256, 7.439550008092608, 6.933203944138118, 8.786406193460737, 9.11697803224836, 6.74924430676869, 7.465205362864903, 5.269633233547211, 5.071578306811197, 6.332977294921875, 5.453241986887796, 4.987185486725398, 2.6308765539101193, 3.726524744715009, 1.8840318407331194, 1.656820861356599, 1.003155073949269, 0.5347948659743581, 0.29171832650899887, 0.17071300532136643, 0.42752629624945776, 0.33863373047539164, 0.5256792094026292, 1.5318022498062678, 4.429717183113098, 11.399256297520228, 23.067315816879272, 39.07872554234096, 59.15654591151646, 79.11967931474958, 89.36119202205113, 89.78145381382534, 86.1267499923706, 54.35971457617623, 46.35914182662964, 32.157152448381694, 31.983037539890834, 31.490674291338237, 45.60424089431763, 47.97698817934309, 58.591754640851704, 66.84922313690186, 63.64694431849888, 63.40543188367571, 53.781058175223215, 33.50083678109305, 7.877261332103184, 0.9055452602250236, 0.15859351493418217, 0.09926341035004173, 0.2061133307537862, 0.10486745821045977, 0.18971653202814714, 0.2261456929679428, 0.1574670925204243, 0.1586626169404813, 0.24063883455736296, 0.22034354002348014, 0.09756463686270372, 0.0855631505006126, 0.0935006667194622, 0.16177002234118326, 0.15429553841905935, 0.1524151550339801, 0.08574728454862322, 0.037972220818379095, 0.11085310059466533, 0.09412161447107792, 0.11752519650118691, 0.13178265573722975, 0.07291500669504915, 0.10046831212405648, 0.09614026972225734, 0.12882302169288906, 0.0915177838344659, 0.08500861097127199, 0.09475698109183993, 0.11895710895104067, 0.11421674117445946, 0.17006371516202176, 0.09270731679030828, 0.22486718371510506, 0.12041131806160722, 0.1454205582184451, 0.16903592459857464, 0.08877711982599326, 0.11545429405357156], [0.024086593683542948, 0.017564420089391724, 0.08751826094729559, 0.0433254753505545, 0.011385391832196286, 0.03414504582594548, 0.07256454335791723, 0.03385618329048157, 0.04447600272084985, 0.06878046890986816, 0.013895382772066762, 0.022497824293428233, 0.1998221440506833, 0.0570717839790242, 0.01550302391738764, 0.04905707422377808, 0.01376934998136546, 0.02986278078917946, 0.01654474819744272, 0.04377144927691136, 0.009333438323145466, 0.05012875243223139, 0.05078291447300996, 0.03582369735730546, 0.0625278569225754, 0.033618777458156855, 0.058711918470050604, 0.03162908547424844, 0.10846705255763871, 0.02917221195197531, 0.047957793210766146, 0.04970016935840249, 0.04147809590878231, 0.02358480855556471, 0.01622893425103809, 0.036677823668079715, 0.04873248003423214, 0.5608469737427575, 6.930940134184701, 27.716588258743286, 56.771997111184255, 72.41336141313825, 72.30444145202637, 66.33962140764508, 61.16737542833601, 52.053086348942344, 41.41398729596819, 35.267280782972065, 26.08704113960266, 26.947184698922293, 29.32855122429984, 32.255879402160645, 38.074220997946604, 43.924041407448904, 44.03965595790318, 32.56444195338658, 20.849918093000138, 11.284759538514272, 7.021135568618774, 4.515885267938886, 1.5991661208016532, 0.6608918596591268, 0.14865692598479135, 0.031372707802802324, 0.22970323850001606, 0.17288559302687645, 0.31584914880139486, 0.6418832167983055, 2.440902816397803, 1.2429539092949458, 2.6920547911099026, 0.7206370308995247, 3.3870616001742224, 1.6109894577945982, 2.3784927938665663, 3.4043508895805905, 5.540631651878357, 3.0907202788761685, 2.3391590416431427, 3.0139665688787187, 1.0041805846350533, 0.20749064827603952, 0.17986653771783623, 0.07082942074963025, 0.13225787452289037, 0.20886541450662272, 0.06289548041032893, 0.13006236590445042, 2.5262950914246693, 5.26943130152566, 5.041985060487475, 4.804568154471261, 2.94805291720799, 5.4349439058985025, 3.8521764022963385, 3.4097424745559692, 3.625908532312938, 2.4316478158746446, 2.213157585689, 4.280719578266144, 3.6094091662338803, 2.7319919509547095, 3.017747474568231, 3.653636404446193, 0.9712303813014711, 1.3664392488343375, 0.34548454572047504, 0.4648327486855643, 0.4157627246209553, 0.39424000095043865, 0.14614216664007731, 0.35518189679299084, 0.18344196943300112, 0.44475845300725525, 1.153978209410395, 3.5231885356562476, 7.960430400712149, 20.159725734165736, 37.06014878409249, 45.28900807244437, 42.906046935490195, 51.348507744925364, 31.92225817271641, 26.847474575042725, 24.190386159079416, 19.476648330688477, 17.14556244441441, 37.758456638881135, 42.97473335266113, 39.18517541885376, 42.984169006347656, 48.98024204799107, 53.47581338882446, 32.48601763589041, 28.313530581338064, 12.23471030167171, 2.99280908703804, 0.18996403446154936, 0.013900717753650886, 0.06035195118082421, 0.015654416954410926, 0.05973662169916289, 0.04078542700569544, 0.05585932671757681, 0.014854782094646777, 0.019812013055863123, 0.04946295690855809, 0.0585805880171912, 0.043250846676528454, 0.029292126053145955, 0.06062593683600426, 0.00933238404936024, 0.029462350133274282, 0.006295833819811898, 0.043685031056936295, 0.02712814386800996, 0.01800721338284867, 0.0553047905809113, 0.042403322511485646, 0.04874396423942276, 0.041166356565164666, 0.10438242102307932, 0.015768711089289615, 0.03043319464528135, 0.04500595892646483, 0.006824941008484789, 0.10304533384208169, 0.009312975403320576, 0.028122409712523222, 0.08071811191205468, 0.03347415111160704, 0.01550672362957682, 0.06671920165951763, 0.01988476388422506, 0.019155613545860564, 0.05972412308411939, 0.05368707488690104, 0.017544081002207737, 0.05593069163816316, 0.02925444021821022, 0.04212247686726706, 0.04065917878012572, 0.03198670057047691, 0.014094045951164194, 0.03937309029112969, 0.03903396527415939, 0.04265604627185634, 0.014799629071993487, 0.06442201456853322, 0.07241304005895342, 0.01439442322589457, 0.028706560510077646, 0.00909268731317882, 0.013985549049851085, 0.025322110957599113, 0.03204978397116065, 0.01746983909314232, 0.0431248121894896, 0.02881006084914718, 0.021288269465523105, 0.06837364645408732, 0.0620350165824805, 0.0048323198737177464, 0.01482365430066628, 0.03696054885429995, 0.034958110590066226, 0.03906511003151536, 0.03369978775403329, 0.009455667925067246, 0.026312777173838446, 0.06729328299739532, 0.015122511656954885, 0.049055347352155616, 0.7354579184736524, 8.560664432389395, 32.77018158776419, 64.04509694235665, 80.16576535361153, 80.3750798361642, 76.33312511444092, 68.53322328839982, 62.50393090929304, 51.00493669509888, 45.25797741753714, 30.50979709625244, 36.99050004141671, 33.18952621732439, 25.56316086224147, 29.19205038888114, 44.35732412338257, 51.05314677102225, 38.47332552501133, 22.638507740838186, 13.614333323069982, 8.872812254088265, 3.8530701143401007, 1.6946261184556144, 0.6053070308906692, 0.25496479868888855, 0.1157545865114246, 0.24985116879854882, 0.7159702298896653, 1.368705990059035, 2.4130720240729193, 4.356019811970847, 3.239087551832199, 4.2446558220045905, 4.0339395403862, 6.189986842019217, 4.722844311169215, 7.080575670514788, 7.270081273147038, 6.137021158422742, 6.652156693594796, 6.8091521092823575, 5.861637992518289, 1.2814991495438983, 0.48069820020880016, 0.11587327585688659, 0.10797564392643315, 0.11354438082448073, 0.09474149692271437, 0.011559064566556896, 0.4960149611745562, 2.3672026225498746, 6.957227340766361, 7.31610483782632, 4.343496118273054, 6.204189394201551, 8.070524607385908, 6.467205200876508, 7.839745402336121, 6.610801015581403, 5.461387012686048, 5.7686294061797, 6.050587739263262, 7.2437984091894965, 7.922898837498256, 6.1147569588252475, 5.03064603464944, 2.432380199432373, 3.0954365858009885, 1.4738319090434482, 1.2001739591360092, 0.8900673336216381, 0.48242119061095373, 0.46955176975045887, 0.43261031487158363, 0.26174461202962057, 0.5273170843720436, 1.5580689374889647, 4.061390135969434, 10.338986379759652, 24.031142132622854, 45.10285888399397, 57.236789907727925, 56.65094559533255, 60.85192721230643, 34.49579450062343, 28.524026257651194, 25.257151773997716, 24.741011789866857, 23.363043308258057, 43.09786932809012, 49.65050349916731, 48.31897851399013, 52.003431047712056, 56.61548546382359, 60.63449028560093, 42.867536544799805, 35.02793271200997, 13.758413774626595, 2.5683045514992306, 0.01644644034760339, 0.04638648931203144, 0.04419789157275643, 0.03921475414452808, 0.02418221114203334, 0.04382362522717033, 0.07127332514418022, 0.016829346140314425, 0.049079720330025466, 0.013937005806448204, 0.03424921112933329, 0.005644270144070366, 0.035453977196344306, 0.023864407391686524, 0.059016295708715916, 0.028707771695085933, 0.06543688582522528, 0.019753462269103954, 0.04087771116090672, 0.01895316074868398, 0.03552395790549261, 0.0072051521690030184, 0.04896593340007322, 0.03408095480075904, 0.04518954336111035, 0.011817532125860453, 0.054204810676830154, 0.014528293096061264, 0.03588236688769289, 0.08127898895846945, 0.03586983434589846, 0.015477694205141493, 0.02513746970466205, 0.031882022973150015, 0.03052749065682292, 0.03779676862593208, 0.05981464644095727, 0.028945788208927428, 0.04364577780610748, 0.13934828048305853, 0.17241223342716694, 0.16573977789708547, 0.12895300186106137, 0.18292460005198205, 0.17263080312737397, 0.08409039702798639, 0.12179988569446973, 0.19832876989884035, 0.1397156800542559, 0.23225974131907734, 0.09639911047582116, 0.2452563467834677, 0.12133726051875524, 0.09441122000238725, 0.12326358072459698, 0.08791738881596498, 0.11161042031432901, 0.16069367581180163, 0.06037434283643961, 0.05639977307458009, 0.1571228445640632, 0.07742491683789662, 0.14689238209809574, 0.13605112954974174, 0.2625958206398146, 0.09830326972795383, 0.12732341858957494, 0.22731242036180838, 0.1767015518354518, 0.19398032394903048, 0.11490180369998727, 0.12285138427146844, 0.09745136222669057, 0.11563752565000739, 0.09230881317385606, 0.15053255962474005, 1.3524543706859862, 13.326431240354266, 41.11581924983433, 77.6141436440604, 92.03747136252267, 90.9256901059832, 81.41020856584821, 74.80440330505371, 66.62346921648297, 54.969912324632915, 44.875065667288645, 34.134978021894185, 36.887534686497276, 37.369281087602886, 43.87236418042864, 52.7871287890843, 60.23442690713065, 59.412100655691965, 44.51339456013271, 27.965102740696498, 16.086471114839824, 9.680204221180507, 5.525405543191092, 2.1185915172100067, 0.9926539574350629, 0.4122957092310701, 0.21686959000570433, 0.4720483443566731, 0.5589079377906663, 1.2246145733765192, 2.339996950966971, 6.455282960619245, 3.1684300175734927, 8.023414952414376, 5.290896024022784, 10.96617681639535, 7.229471223694937, 11.111943074635096, 11.883610010147095, 11.89207899570465, 9.943887489182607, 9.349879043442861, 6.438210368156433, 2.9568942827837805, 1.0963353025061744, 0.34477004834583824, 0.5068090962512153, 0.37584678935153143, 0.4356077568871634, 0.2586237852062498, 1.1304765790700912, 8.716326662472316, 12.191293614251272, 15.34754582813808, 14.379083326884679, 10.40007667882102, 14.31078861440931, 15.106078556605748, 11.463529740061078, 11.479620899472918, 8.047843081610543, 9.187303355761937, 10.534560799598694, 12.262459669794355, 8.559951373508998, 8.942723291260855, 9.537564652306692, 3.2872850341456274, 3.4364051009927477, 1.2210141037191664, 1.0609976329973765, 0.8088577655809266, 0.6705822082502502, 0.5570152050682476, 0.5797252835971969, 0.33763077429362703, 0.7930515908769199, 1.7045325125966753, 4.783379188605717, 10.54742191519056, 24.442538022994995, 43.92945058005196, 53.41315800803048, 54.40172685895647, 61.87767587389265, 42.50295761653355, 39.31310565131051, 35.91452285221645, 31.318966933659144, 30.147841112954275, 50.75173739024571, 55.31415040152413, 54.57372604097639, 61.31150885990688, 66.88497161865234, 71.96926035199846, 52.542996883392334, 44.127814701625276, 19.265464782714844, 5.703900422368731, 0.4249673235629286, 0.1019535099289247, 0.20180763251015119, 0.12455925691340651, 0.1441009161727769, 0.13591562610651764, 0.21858373231121472, 0.18753988668322563, 0.13713973042156014, 0.10554760814245258, 0.12398746902389185, 0.10495619023484842, 0.13260096896971973, 0.17083322815597057, 0.1475821943687541, 0.11724129744938441, 0.15563204884529114, 0.11839324635054384, 0.07828618812241725, 0.11156828328967094, 0.15091655616249355, 0.1250204707362822, 0.11529379338026047, 0.09131773814026799, 0.21178939832108362, 0.08442137283938271, 0.1578101191137518, 0.07464420569262334, 0.11519275951598372, 0.23514883486287935, 0.10780957248061895, 0.13297090626188687, 0.09628663651113, 0.0983380310769592, 0.08397945655243737, 0.16337065930877412, 0.2793127793286528, 0.11712245882621833, 0.2030739417033536], [0.03232470939734152, 0.03620593309668558, 0.024239696628813232, 0.03410543973690697, 0.021081187363181795, 0.01842768457052963, 0.006841672409791499, 0.03858354355075529, 0.015256262783493315, 0.03254795081115194, 0.0357471145024257, 0.020207755034789443, 0.03289478737860918, 0.04566158660288368, 0.027547086655561413, 0.0014012553895424518, 0.04575879352965525, 0.04669606412893959, 0.0494110964770828, 0.04184084412242685, 0.0474335943747844, 0.05937089810946158, 0.058470963899578364, 0.02430527873470315, 0.036297311407646964, 0.01820491813123226, 0.07480314573539154, 0.027418460164751326, 0.02159559154616935, 0.055721906412925036, 0.049583234025963714, 0.006816819792480341, 0.05712278267102582, 0.030066894300814186, 0.007229921241690005, 0.07929548182125602, 1.5272332664046968, 7.8431925773620605, 30.79439183643886, 56.33404867989676, 70.03490270887102, 69.43820531027657, 64.96258572169712, 53.64421687807356, 54.95307336534773, 43.65426370075771, 35.04418107441494, 23.79282065800258, 31.96406200953892, 53.532684394291465, 59.89870384761265, 76.83227675301688, 70.76557527269635, 47.36570303780692, 28.833563293729508, 19.591760873794556, 16.401497227805002, 8.278825521469116, 1.9242449743407113, 0.5695958957076073, 0.14238430399979862, 0.14542434444384916, 0.28663525783589905, 0.08582829484449965, 0.35192967844860895, 0.6350378298333713, 1.5063221199171883, 2.4499252693993703, 1.7533788915191377, 5.066654205322266, 3.7163625700133185, 3.5866208119051795, 3.426619214670999, 3.596409086670194, 5.504481477396829, 3.8153127346720015, 5.683964303561619, 6.184384856905256, 7.5219252450125555, 4.609327682426997, 0.45428600747670445, 0.3107083503689085, 0.045123847600604804, 0.0763824563473463, 0.053989548834839036, 0.10908854992261954, 0.26896490316305843, 0.5619033170597894, 2.035728169339044, 5.590327339512961, 3.4149054203714644, 1.8532823707376207, 4.687729852540152, 7.180766957146781, 2.5253132241112843, 9.852561235427856, 5.2785269277436395, 4.8086645518030435, 3.8848633340426852, 1.5713358713047845, 3.8702794994626726, 5.698017035211835, 3.1583390619073595, 5.343403126512255, 2.3994509492601668, 3.936634796006339, 2.1471544759614125, 1.0177110071693147, 0.47030993763889584, 0.5092903631074088, 0.19055081797497614, 0.13844033277460507, 0.0256834783524807, 0.02877125543143068, 0.1829146391579083, 0.36928714705365046, 1.7082694492169788, 4.689442149230412, 11.019950662340436, 23.055198158536637, 29.93553195680891, 32.30540268761771, 54.694666385650635, 65.89426967075893, 65.03463159288678, 31.91535861151559, 23.827794415610178, 29.585551193782262, 25.558185952050344, 31.08578191484724, 37.430223737444194, 45.37335572923933, 44.82281173978533, 43.71361173902239, 39.78631966454642, 26.372493982315063, 6.543594130447932, 1.023239601935659, 0.06493959429540805, 0.047914964080389054, 0.1006650465673634, 0.09876963363162108, 0.05700639355927706, 0.0515489940797644, 0.020058290733556663, 0.07730814096118722, 0.054871498474052975, 0.04241696785071066, 0.030671974511018822, 0.060906714626720974, 0.018479371975575174, 0.04246401068355356, 0.018909707366089736, 0.04452635680458375, 0.0301223611459136, 0.02102217177993485, 0.0428002485340195, 0.03810351395181247, 0.0058048713253811, 0.031372259969690015, 0.031293163142566166, 0.025985382331003035, 0.026731506222859025, 0.0909459755889007, 0.0689111276130591, 0.017846877254279594, 0.03298286122402974, 0.037284919127289734, 0.02469157550616988, 0.006181622805472995, 0.03480167094884174, 0.022221577420298542, 0.09414659813046455, 0.023898359587682143, 0.12956373766064644, 0.04959680472633668, 0.04672973642924002, 0.060305939721209664, 0.04879643874508994, 0.00990385642009122, 0.047952514208321056, 0.06153940103415932, 0.03652932627924851, 0.007296162374716784, 0.03610574061583195, 0.023733779222571423, 0.03189851137410317, 0.03809135799695339, 0.007109236579188811, 0.02776886921908174, 0.03354279510676861, 0.003588613954239658, 0.045420459005981684, 0.021791806910187006, 0.029151893220841885, 0.042195365098970275, 0.01612418540753424, 0.05682421029944505, 0.034053094152893336, 0.03906858752348593, 0.022394203514392887, 0.06566952155636889, 0.052487231591450315, 0.05076104528935892, 0.05321002744936517, 0.013419197922173356, 0.024454339307599833, 0.05187977650868041, 0.053637694500918896, 0.03384709431390677, 0.07091370158429657, 0.03633361303114465, 1.7866117996828896, 8.995450564793178, 34.47971289498465, 64.35147775922502, 77.16278171539307, 79.95428303309849, 73.43332917349679, 64.36043398720878, 66.10666220528739, 53.23916469301496, 49.55012287412371, 33.30774981634957, 32.99665812083653, 43.25295659473964, 43.14626700537545, 55.08008990968977, 56.80431318283081, 48.656806877681184, 27.272242273603165, 18.04157781600952, 12.153983524867467, 6.376472583838871, 2.0428433418273926, 0.6369531442012105, 0.17131068610719272, 0.2853979899414948, 0.7369840794375965, 1.167591141802924, 1.4519476890563965, 2.1537947825023105, 3.1510870967592512, 4.5702913999557495, 6.31892022064754, 7.083912977150508, 7.2283742768423895, 7.6225768498012, 9.368802462305341, 6.065070824963706, 9.09745967388153, 7.988889353615897, 7.054679734366281, 4.755944226469312, 4.516640016010829, 1.8813572185380119, 0.10290839868996825, 0.16980908811092377, 0.11712661146053246, 0.04355917977435248, 0.0678202740049788, 0.27993928428207127, 0.3861056145812784, 1.0378905300583159, 2.2227115758827756, 3.611128411122731, 4.947811348097665, 7.383856722286769, 6.485059465680804, 7.838170766830444, 11.193158830915179, 12.626894422939845, 11.138043982642037, 13.65466935294015, 8.378926481519427, 7.8826870066779, 7.2023458906582425, 6.653163748128073, 5.3010039159229825, 8.77146235534123, 3.0767055451869965, 3.6857257911137173, 4.092066867010934, 1.8324557968548365, 2.585948416164943, 1.5780810522181647, 1.0653533935546875, 0.4266671894916466, 0.20048097441239016, 0.1404297567371811, 0.2519420880292143, 0.3381852459694658, 1.7804163949830192, 4.822725100176675, 13.48662977559226, 22.16117170878819, 33.27632311412266, 33.3460031236921, 40.87066943304879, 56.10914938790457, 56.65963084357125, 34.103068419865195, 27.46738416807992, 38.88308164051601, 33.52805287497384, 36.749852657318115, 45.022377899714876, 52.12426022120884, 53.95776128768921, 50.0649322782244, 45.523478507995605, 29.611471448625835, 7.961572510855539, 1.2070595153740473, 0.05460763995402625, 0.020050799706950784, 0.10179217465754066, 0.0332392694295517, 0.06053998680519206, 0.0282215962652117, 0.04720248195475765, 0.025728212469922643, 0.03899725652965052, 0.017797055820535337, 0.02593211393936404, 0.0545033966191113, 0.016936754841091375, 0.04142475627096636, 0.01126230982065733, 0.01815010776876339, 0.02265125802452011, 0.04417292148407016, 0.036187965489391766, 0.026688945113814304, 0.05464530882558652, 0.028488292757953917, 0.059275299310684204, 0.0274991736015571, 0.03320677778018372, 0.04558895282181246, 0.05347906658425927, 0.029835873483014957, 0.005212504741004003, 0.0753943125850388, 0.033067559357732534, 0.037696752564183304, 0.04023480262341244, 0.02450438465790025, 0.06477325143558638, 0.03332700061478785, 0.006685642010000135, 0.05655837045716388, 0.18683368100651673, 0.11278579902968236, 0.12421023207051413, 0.10842230995850903, 0.11392213484006268, 0.11008045955428056, 0.16759901813098363, 0.1604116088045495, 0.07365339528769255, 0.12048818250851971, 0.1557054120515074, 0.1392302153898137, 0.10281744107071843, 0.13364242522844247, 0.1451152310307537, 0.13853413345558302, 0.12185571555580411, 0.12966372658099445, 0.15292955243161746, 0.20606580616108008, 0.1329069882631302, 0.16573600524238177, 0.1920049592320408, 0.30500553495117594, 0.08332026656717062, 0.11560788724039282, 0.19184346789760248, 0.12146310162331377, 0.11063360130148274, 0.16485826591295855, 0.1672433843570096, 0.07641349932444946, 0.2045655788055488, 0.16115115769207478, 0.1269822240407978, 0.2217975455735411, 2.7731068304606845, 14.193661962236677, 45.064251218523296, 75.93924563271659, 87.95741271972656, 88.26678821018764, 81.54376683916364, 68.13229138510567, 72.00721141270229, 55.82955387660435, 47.85750000817435, 31.678206171308243, 41.82423325947353, 68.28800051552909, 72.9721633366176, 89.88226522718156, 82.57109274183, 56.83622973305838, 37.02143342154366, 25.15742254257202, 19.971737010138376, 9.637260011264257, 3.075138943535941, 1.0686445598091399, 0.37415313880358425, 0.34737915119954516, 0.6587152821677071, 0.9358011909893581, 1.4805510342121124, 2.1704491802624295, 3.6008355234350478, 6.773284205368586, 7.4667035681860785, 11.482632943562098, 9.79489552974701, 10.248758809907095, 13.047897066388812, 10.589151058878217, 15.497510535376412, 12.024027892521449, 15.428791114262172, 16.0208922794887, 17.643513781683787, 15.353189502443586, 4.406579681805201, 1.522255533507892, 0.4365787404988493, 0.19419265112706594, 0.27090985594051226, 0.531519930277552, 1.4403648248740604, 1.0343134020056044, 6.574924426419394, 17.317323650632584, 12.16556009224483, 13.289515461240496, 14.503412655421666, 21.78374035017831, 12.212975467954363, 22.116842201777867, 16.231304577418737, 16.476914712360927, 14.438088297843933, 10.361306599208287, 13.654306309563772, 16.793045588902064, 10.437288624899727, 14.534567509378705, 7.519287535122462, 8.351726021085467, 6.67547311101641, 3.3646401975836073, 2.280507126024791, 1.9251897122178758, 1.0214287276778902, 0.34632720478943413, 0.34176951221057345, 0.20451148599386215, 0.3718625402876309, 0.7081657743879727, 2.5454221793583462, 5.986751164708819, 14.318614023072378, 30.20484413419451, 40.994225774492534, 44.34520646503994, 65.78257737840924, 75.59538623264858, 74.1578734261649, 43.228714329855784, 35.30743094852993, 44.96851199013846, 40.246762888772146, 45.68820640019008, 52.133119174412315, 61.73016561780657, 61.07639571598598, 62.46108831678118, 57.01316908427647, 38.01969848360334, 10.655944960457937, 1.9518466932432992, 0.1848309984696763, 0.2270867396146059, 0.24964815112096922, 0.12556419441742556, 0.2630690581032208, 0.22552841609077795, 0.1688301113567182, 0.15715656775449002, 0.13224925712815352, 0.15642539198909486, 0.16923122054764203, 0.10873210869197335, 0.11590581839638096, 0.10220264084637165, 0.1443764285317489, 0.12860093718128546, 0.1509214144732271, 0.10401572712830134, 0.15894351686750138, 0.15094698167272977, 0.20370341864015373, 0.11515549437275954, 0.09357595017978124, 0.13084889655666693, 0.10014065434890133, 0.19005639664828777, 0.1894768327474594, 0.10304316931537219, 0.16134150033550604, 0.11056101841053792, 0.06580825482628175, 0.10695577865200383, 0.1251563134470156, 0.1446580069937876, 0.19952300510236196, 0.07845336558031184, 0.1756437700241804, 0.13313812443188258], [0.0664981688771929, 0.08936809668583529, 0.08066373411566019, 0.010945094699439193, 0.0268649570976517, 0.039705704764596055, 0.04027062927239707, 0.04276068315708211, 0.012844098781767701, 0.05417639023757406, 0.039450063303645165, 0.04217368590512446, 0.015166127887953604, 0.02316623387326087, 0.06183834320732525, 0.02865912751959903, 0.050403060391545296, 0.03416620594050203, 0.0375878646570657, 0.05246576613613537, 0.015193762922925609, 0.07862230722925492, 0.005712315756162363, 0.06367377364741904, 0.05515756544524005, 0.02100563927420548, 0.03834466529744012, 0.007732903135807386, 0.02690433248478387, 0.026672066555225422, 0.03503465951819505, 0.06697426297302757, 0.023803642884429013, 0.01795306459202298, 0.10416663331644875, 1.2263615024941308, 5.660223611763545, 25.931900024414062, 63.43966565813337, 66.10218756539481, 68.42890998295375, 59.98188073294503, 52.23383331298828, 48.62009954452515, 42.65067284447806, 38.87517459051949, 21.29772080693926, 35.69464710780552, 49.82999631336757, 84.01741586412702, 95.79764189038957, 81.243590763637, 57.87054204940796, 33.31522607803345, 20.71354579925537, 6.8643655351230075, 1.7481886957372939, 0.2675271417413439, 0.24540475596274647, 0.08248864726296493, 0.06665523616330964, 0.21910506433674268, 0.5225768387317657, 0.8909838444420269, 1.185138491647584, 2.0988988024847846, 3.31221365077155, 2.7111642914158955, 6.065531577382769, 4.734369201319558, 5.022774159908295, 5.424846002033778, 6.804624055113111, 3.2009686487061635, 5.633332780429295, 8.57984493459974, 2.8126396919999803, 4.583000523703439, 3.6225675344467163, 1.5289440431765147, 0.3477564980941159, 0.0036991205914611264, 0.015297600833166922, 0.09143292624503374, 0.11509171208100659, 0.0752584088061537, 0.2528261648757117, 0.3668728380330971, 1.3135742055518287, 3.3255945784705023, 3.833665532725198, 2.8930631365094865, 3.5201834397656575, 5.1903495107378275, 8.36991206237248, 6.09040048292705, 8.392550161906652, 7.5274447202682495, 6.179938009807041, 6.90436544588634, 6.632703040327344, 8.700813940593175, 6.104262573378427, 4.163960312094007, 2.4632627708571295, 2.6706519510064806, 2.557798440967287, 2.126837943281446, 2.1398388913699558, 1.1217509444270815, 1.1157738651548113, 0.5790811095918927, 0.37345606620822636, 0.12510028002517565, 0.041626749360667806, 0.1302478230957474, 0.14871464217347757, 1.1761983313730784, 6.117886253765651, 18.555421420506068, 31.452170848846436, 57.15660074778965, 88.0064253125872, 72.21200261797223, 51.52851472582136, 27.021361930029734, 21.428807258605957, 16.119923216956003, 26.582379954201834, 30.066092082432338, 37.07078995023455, 41.411187171936035, 45.8143926348005, 48.168588229588096, 51.426723616463796, 43.060074601854595, 14.833479881286621, 3.151946936334882, 0.35400520850505146, 0.06801964116415807, 0.04459923146558659, 0.021234919649681876, 0.012818085445490266, 0.037581140375030894, 0.018360891279631426, 0.05679147777014545, 0.0206710994576237, 0.06232644737298999, 0.049684145753937106, 0.04995667255882706, 0.04798906688977565, 0.04207930846938065, 0.019487695369337286, 0.05129575802545462, 0.052272397226520946, 0.002949430573997753, 0.016298874248085276, 0.0524310624626066, 0.051648382496620925, 0.04139211195121918, 0.027962606233943785, 0.009567184307213341, 0.024061392892950347, 0.05827177994485412, 0.022678962609331523, 0.028589296088154827, 0.03058739851361939, 0.008415857961933528, 0.03348779645083206, 0.025772402063012123, 0.03848542060170855, 0.01664136988776071, 0.06476763316563197, 0.015659095453364507, 0.032787341358406205, 0.0381297529009836, 0.0457542507377054, 0.0330364010296762, 0.02932379667514137, 0.045161662357194085, 0.039295408209519725, 0.04968959439013686, 0.04546765111652868, 0.014335974219388195, 0.07506658017103161, 0.12128000573388167, 0.010082088909777147, 0.004525285746370043, 0.01820298091375402, 0.060150629840791225, 0.02670346406687583, 0.11599560215004853, 0.058999624103307724, 0.027070660077567612, 0.013783371907525828, 0.030723085161298513, 0.010105064953677356, 0.01580568615879331, 0.07553354118551527, 0.008544878851223205, 0.050532663972782235, 0.03683183076126235, 0.04164720719148006, 0.02287799898268921, 0.07364456754709993, 0.07176812645047903, 0.04937777701499207, 0.08849715627729893, 0.00934714388235339, 0.03943565800519926, 0.04422290237354381, 1.1812881039721626, 6.248683486665998, 29.77125222342355, 71.58694962092808, 74.37590789794922, 79.38170283181327, 68.8966349193028, 63.41723687308175, 57.65010002681187, 55.2078082220895, 49.61319514683315, 29.90221881866455, 27.92854479381016, 40.20737355095999, 74.89978122711182, 88.12951959882463, 83.13559218815395, 62.66972187587193, 35.60459150586809, 21.670116458620342, 8.473506229264395, 2.709472405058997, 0.8895382391554969, 0.7017497101000377, 0.29116244348032133, 0.6758595279284886, 0.7932093366980553, 0.9904067580189023, 2.965211493628366, 2.407336720398494, 4.0118312409945895, 5.907618565218789, 7.470591085297721, 7.936984573091779, 7.64118846825191, 6.81854954787663, 7.318403823035104, 8.268331136022296, 7.669106330190386, 11.260302747998919, 7.865486741065979, 5.983341336250305, 1.9112965720040458, 2.188954838684627, 0.5138861622129167, 0.1951827151434762, 0.024457362181107913, 0.17275809629687242, 0.07180134073964187, 0.054532027404223166, 0.07951261981257371, 0.2517359490905489, 1.3818684837647845, 3.0502326914242337, 4.038737705775669, 5.146531564848764, 4.98407529933112, 7.058236343520028, 8.012979626655579, 6.906933239528111, 11.109011803354536, 7.935210176876613, 10.226739968572344, 9.420982565198626, 6.981363645621708, 7.901556577001299, 6.53978521483285, 9.755902239254542, 6.615938774177006, 6.307110454354968, 6.821407428809574, 5.747088253498077, 6.389032321316855, 5.843606548649924, 3.264383771589824, 2.6774794246469225, 1.3023952054125922, 1.2556936485426766, 0.5401924220579011, 0.20147159482751573, 0.14292892334716661, 0.2213655494685684, 1.4737463593482971, 5.0551453828811646, 16.77502022470747, 29.06101257460458, 45.63146046229771, 82.15355464390346, 78.03284209115165, 58.31948253086635, 31.176938806261333, 26.878593819481985, 22.161060537610734, 30.099471228463308, 35.11255482264927, 42.696187019348145, 48.50360952104841, 53.33319813864571, 55.78204556873867, 61.86843476976667, 49.01931176866804, 17.3050149168287, 3.8216525316238403, 0.3962002343365124, 0.04962750165058034, 0.05111269945544856, 0.08255719965589897, 0.017292288531150137, 0.01880586606317333, 0.017674095097130964, 0.04078441938119275, 0.043961659606013975, 0.016596640859331404, 0.02806013885752431, 0.03341421950608492, 0.050825509508805614, 0.04595701735732811, 0.023507155311693038, 0.02510224695184401, 0.07112856648330178, 0.029091839479016404, 0.02893227179135595, 0.012417328244607364, 0.006361606763675809, 0.037383920779185634, 0.03852604449327503, 0.0334009745025209, 0.04074155632406473, 0.03509951389527746, 0.012572793339911317, 0.041164331138134, 0.02441118278407625, 0.04600890153752906, 0.032457600480743816, 0.023802336704518114, 0.023662290469344174, 0.012823029421269894, 0.03435081496302571, 0.03279155506087201, 0.007066031285960759, 0.013737718375133616, 0.11482100374996662, 0.16953318220164093, 0.15326926777405397, 0.14659662225416728, 0.07937017495610885, 0.109941773781819, 0.09403379168361425, 0.11039710470608302, 0.21612522351954663, 0.22782863623329572, 0.08920349087566137, 0.09601166698017291, 0.08999376704118081, 0.09593868375356708, 0.13399197932864937, 0.24724912270903587, 0.1947751734405756, 0.13602744867759092, 0.09813991242221423, 0.14077297332031385, 0.0835841420505728, 0.15010748457695755, 0.15322631650737353, 0.16922664722161634, 0.13832430328641618, 0.1306688812162195, 0.14041073061525822, 0.08981383312493563, 0.14721418411603995, 0.22244128531643323, 0.08741285053214856, 0.25445559886949404, 0.12853110235716614, 0.2129534115748746, 0.17881772613951138, 2.2710443309375217, 10.544952699116298, 41.8847416469029, 88.11177389962333, 86.91794831412179, 89.28741604941231, 77.54754516056606, 65.90472670963833, 64.32317774636405, 53.9614577293396, 50.658704485212056, 28.984556334359304, 47.221194403512136, 66.22754001617432, 94.40550082070487, 100.43762111663818, 86.47806480952671, 65.54394844600132, 39.669197354997905, 24.4180907862527, 9.462347796985082, 2.8031623491219113, 1.151920131274632, 0.61269589726414, 0.38816751965454643, 0.601570365684373, 0.7790586245911462, 1.3535723792655128, 2.312885731458664, 2.77095810004643, 6.587233594485691, 10.863356505121503, 13.269717437880379, 15.299575465066091, 14.512922133718218, 14.60661598614284, 15.307281017303467, 15.455513886043004, 12.918594564710345, 18.56483449254717, 17.79026668412345, 14.062201176370893, 14.543371745518275, 12.859300374984741, 9.37059770311628, 1.6477643187556947, 0.36134340188332964, 0.45309504281197277, 0.3652786878602845, 0.3082856003727232, 0.5289295007075582, 0.47179603789533886, 2.9572518978800093, 7.492490070206778, 12.37242533479418, 13.201930812426976, 8.717042326927185, 12.701854194913592, 16.967084067208425, 19.93161290032523, 15.802506923675537, 21.045442138399395, 17.984368085861206, 14.330907123429434, 17.066412040165492, 16.802151203155518, 19.46039649418422, 16.220859697886876, 12.294335399355207, 9.313803127833776, 9.445631299700056, 8.995993392808096, 7.630752273968287, 8.692176461219788, 2.5645447075366974, 3.1411581209727695, 0.9885763419525964, 1.4432016440800257, 0.5663274196641785, 0.2934703582099506, 0.25908464619091576, 0.3442778933261122, 1.6776726224592753, 7.662994521004813, 22.530444145202637, 41.09030546460833, 64.22691740308488, 95.29906695229667, 81.13555322374616, 59.51650428771973, 37.12118523461478, 32.869589465005056, 28.20043475287301, 39.827202865055625, 43.07823371887207, 52.34147827965872, 56.685877663748606, 62.077832630702424, 64.5188876560756, 70.08179610116142, 59.055227279663086, 25.4130346093859, 6.332675048283168, 0.8021521025470325, 0.13321614238832677, 0.18557472713291645, 0.22147501073777676, 0.11147079137819153, 0.1056860089302063, 0.1459502497954028, 0.13926997754190648, 0.10774348316980259, 0.08893110656312533, 0.09861720073968172, 0.1249574212623494, 0.1717575014169727, 0.12234989260988575, 0.14739304594695568, 0.15656389455710137, 0.12485262831406933, 0.12528860063425132, 0.10382982210389205, 0.14061768379594597, 0.09042531531304121, 0.13474592672927038, 0.16335904278925487, 0.11394831272108213, 0.12262248726827757, 0.16577910578676633, 0.1294479388743639, 0.07062479494405643, 0.15115356844450745, 0.09780910624457256, 0.10792803790952478, 0.08249357342720032, 0.1771773405905281, 0.094224989281169, 0.1621648482978344, 0.11542671839041369, 0.06273804671530213, 0.17062413080462388], [0.03666527755558491, 0.015442120310451304, 0.018216666965080158, 0.027452363166958094, 0.013595379539765418, 0.013641720088864011, 0.04308615265680211, 0.0295903591572174, 0.033959632739424706, 0.026922710605763962, 0.03568062824862344, 0.03935662903157728, 0.025885552866384387, 0.057267195279044766, 0.047872389400643964, 0.006875016044692269, 0.042041480142091, 0.04022045500044312, 0.053683868808937926, 0.053399362468293736, 0.0671549772045442, 0.04190806658672435, 0.059622926371438165, 0.055284403996276, 0.0059048241985562655, 0.024698976626885787, 0.016315603528970053, 0.054918320783014805, 0.01653919438831508, 0.04650849669373461, 0.020283041887783577, 0.05948245605187757, 0.01085175627044269, 0.045269172838223834, 0.45329841332776205, 5.441985036645617, 26.82651707104274, 45.41122688565935, 55.76402888979231, 60.279590197971885, 55.6108523777553, 47.49235132762364, 42.20845821925572, 36.95889963422503, 27.66203795160566, 37.059141295296804, 44.45387976510184, 67.15333189283098, 79.90075411115373, 58.28473111561367, 40.37328263691494, 32.23453106198992, 25.83619553702218, 12.660953623907906, 4.852458613259452, 1.2377869465521403, 0.5945897059781211, 0.2525862620345184, 0.36802900742207256, 0.2042337887521301, 0.5877397592578615, 0.4686469297323908, 1.2179986940962928, 4.190546291215079, 2.969772768872125, 3.850155779293605, 2.918341334377016, 4.713719155107226, 6.420140274933406, 7.016311347484589, 5.889381280967167, 6.832162371703556, 7.9273760829653055, 5.0744136060987195, 8.081318633896963, 6.699318894318171, 4.908366424696786, 1.3108754817928587, 0.5830800692949976, 0.28099975309201647, 0.14788107547376836, 0.05702531790094716, 0.07497923914343119, 0.12840618406023296, 0.06369127306554999, 0.1430831000741039, 0.49449971105371204, 2.8631845797811235, 2.4378128222056796, 1.5354042393820626, 2.535184225865773, 6.132881334849766, 5.283551778112139, 3.4421962073871066, 11.376523528780256, 13.124842286109924, 6.030399748257228, 14.357316357748848, 6.742707354681833, 4.809606466974531, 4.468894166605813, 1.6300517320632935, 3.3871679944651465, 5.575198071343558, 2.197208430085863, 3.0581555919987813, 5.135225108691624, 2.8007997444697788, 4.586671778133937, 2.7332708537578583, 1.1443637481757571, 0.9126796488251004, 0.8567788398691586, 0.28115942595260485, 0.301930767084871, 0.030175107065588236, 0.20992798677512578, 0.09813953922795397, 0.6731127096073968, 2.764674974339349, 14.985292809350149, 30.42444542476109, 41.029050145830425, 29.880088806152344, 28.77859088352748, 28.280448470796856, 19.923254217420304, 21.892620359148296, 19.717512845993042, 26.080106837408884, 25.833589962550572, 30.444883550916398, 40.35033968516758, 47.100090776171, 50.38829101834978, 46.7109569140843, 33.84839957101004, 16.569106885365077, 1.7518955596855708, 0.09689412891332592, 0.0973811609936612, 0.03105193715808647, 0.05706820131412574, 0.039499267270522456, 0.026258869262944375, 0.01555448570953948, 0.05494431885225432, 0.10432769038847514, 0.0405027527096016, 0.041706120994474204, 0.05396455839010222, 0.02190712054393121, 0.037606527762753625, 0.03654285626752036, 0.03189235366880894, 0.007856136121387993, 0.022620645917153785, 0.010418798342081053, 0.12908338915024484, 0.08973882786397423, 0.01757063207748745, 0.04145348883633103, 0.07843080429094178, 0.033536220102437904, 0.07073567435145378, 0.03504252713173628, 0.057451180049351284, 0.09608459592397724, 0.07430702128580638, 0.02766144016225423, 0.023597994187314595, 0.09450560422348124, 0.006803190992546401, 0.03039845704500164, 0.053786100287522585, 0.039295187685638666, 0.04651917004957795, 0.06622620525636844, 0.05636842814939363, 0.01629638741724193, 0.03293847146310976, 0.0235849391735558, 0.04091282195544668, 0.02078734946969364, 0.02167354504178677, 0.011205195831800146, 0.01753725833259523, 0.012714108435570129, 0.04251899237611464, 0.025224164427657212, 0.02797368331812322, 0.017125818446012478, 0.020781951723620296, 0.04103027297449963, 0.03515531661521111, 0.022134192287921906, 0.059207242248313766, 0.04862706283373492, 0.027709178493491242, 0.039706807384001355, 0.033314312009939125, 0.010732330714485474, 0.01690859394147992, 0.03554340811180217, 0.04764910388205733, 0.015782100281545093, 0.08268458103494984, 0.03781168621831706, 0.02622589415737561, 0.02419311011077038, 0.506663944040026, 6.845893314906529, 26.882031440734863, 52.8592198235648, 68.65425395965576, 73.45416682107108, 69.70108345576695, 59.43179185049874, 51.161799226488384, 46.941341808864046, 34.22216054371425, 42.88126271111624, 32.5279152733939, 53.977438586098806, 72.03576850891113, 67.05788448878697, 57.62923458644322, 48.81049060821533, 33.87138768604824, 17.135781117847987, 6.255760661193302, 1.8886313310691287, 0.6525498415742601, 0.4065241717866489, 0.4414310258414064, 0.6224919344697679, 1.2862151307719094, 2.4751587382384708, 2.8073957562446594, 6.503920350755964, 6.541487957750048, 6.9153818147523065, 7.422985502651759, 7.892014963286264, 7.999214376722064, 6.644770324230194, 6.9144711664744785, 7.709428463663373, 8.41041658605848, 8.43428451674325, 6.512318117277963, 9.473302500588552, 5.13100494657244, 1.6008747262614114, 0.1779829787888697, 0.17081782541104726, 0.10422980492668492, 0.04494344210252166, 0.13747955432959966, 0.10760564556611435, 0.08416085610432283, 0.21941382491162845, 0.18515855446457863, 2.5755245983600616, 2.2533930838108063, 2.464777261018753, 2.596969344786235, 3.3533543688910346, 4.922316670417786, 5.904559620789119, 7.464745044708252, 5.7157405870301385, 8.340746998786926, 8.09108258996691, 9.684867330959865, 7.922513212476458, 8.53257633958544, 6.817575063024249, 10.038943188531057, 8.44682775224958, 10.210610594068255, 10.811773947307042, 6.970843204430171, 7.290158527238028, 5.98098372561591, 7.281026857239859, 4.675459333828517, 3.9282283442361012, 2.900382412331445, 1.338267234819276, 0.5464278874652726, 0.1674432943442038, 0.35828858294657295, 0.08798547301973615, 0.5484172435743468, 3.8244283369609287, 15.40387487411499, 33.16214336667742, 51.067800521850586, 37.57558700016567, 31.29596839632307, 29.83250059400286, 24.471729142325266, 25.91112664767674, 26.676555837903702, 30.09008421216692, 35.128806659153526, 38.66048220225743, 46.57859025682722, 52.32430928094046, 58.99141502380371, 54.7352751323155, 40.1615640776498, 19.491282973970684, 2.4988544838769093, 0.18249668872782163, 0.11686118213193757, 0.06661370982016836, 0.04678114224225283, 0.012841491510958543, 0.03713564820853727, 0.048058830467717986, 0.05163214515362467, 0.04364583548158407, 0.015730752144008875, 0.0615652125062687, 0.029773224344743148, 0.009122962697542139, 0.030013727689427987, 0.02512876918938543, 0.008797546632454863, 0.025676835494648134, 0.008802273477028524, 0.014795162615233233, 0.08814960385539702, 0.06777135841548443, 0.032259237553392134, 0.012703477488165455, 0.027433700061270168, 0.02591850931224014, 0.04546375971819673, 0.07139531216983284, 0.040923284965434244, 0.05395483159060989, 0.024712828919291496, 0.036963269779724736, 0.020048830259059156, 0.04003623613555517, 0.0872081093756216, 0.03843016070978982, 0.04639463173225522, 0.03397328486399991, 0.10098703178976264, 0.13318107569856302, 0.12380579805799893, 0.15035126863845757, 0.137952981782811, 0.09886409249156713, 0.210530105179974, 0.19320387632719108, 0.1781432351895741, 0.13978276002619947, 0.07251449461494174, 0.135762928585921, 0.0995447648955243, 0.29315961631281034, 0.081614775583148, 0.13527579472533294, 0.14053772522934846, 0.08743771205523185, 0.18259709833988122, 0.10305068069802863, 0.09945995480354343, 0.2122124649052109, 0.12469630741647311, 0.13668018579483032, 0.20023584685155324, 0.08795883373490401, 0.09995335832770381, 0.1229039164526122, 0.1354885697364807, 0.07258086212511573, 0.2050222735852003, 0.11814851234001772, 0.13863754219242505, 0.12548362516931125, 0.9707856965916497, 10.56740493433816, 39.629717690604075, 66.17334406716483, 78.36907931736538, 84.76814092908586, 76.23023618970598, 64.64613696507045, 56.06595938546317, 49.788373129708425, 39.69612509863717, 50.404046058654785, 57.371539797101704, 79.91292040688651, 88.45108917781285, 68.68454115731376, 49.12027951649257, 40.405994755881174, 32.08112873349871, 15.897431475775582, 6.273460328578949, 1.9878218599728175, 0.7228678911924362, 0.4073996719505106, 0.8405158753905977, 0.5907885528036526, 1.1732717284134455, 2.589696317911148, 5.753461488655635, 12.040572421891348, 13.508646879877363, 12.20450040272304, 12.553730760301862, 12.815313935279846, 16.7878292288099, 15.355201005935669, 13.716071452413287, 18.286093609673635, 19.86425358908517, 16.540442092078074, 17.973938839776174, 16.383624723979406, 17.201584032603673, 6.627727695873805, 2.5707381580557143, 0.7886948532291821, 0.46464411595038, 0.20848121440836362, 0.3505345018846648, 0.24474182724952698, 0.35301441167082104, 1.1116182995694024, 2.858859760420663, 5.442714163235255, 5.825015340532575, 5.202433730874743, 8.327242306300572, 16.442475966044835, 14.767579691750662, 11.933957525662013, 21.060592685426982, 23.146556547709874, 17.419522966657365, 29.32203381402152, 18.323740686689103, 13.323239411626544, 12.80152349812644, 9.356408613068716, 11.745350411960057, 19.140143598828995, 11.556674684797015, 15.455758810043335, 13.80069443157741, 10.662189653941564, 11.84810037272317, 9.010511653763906, 7.851114392280579, 4.926088673727853, 3.0647385759013037, 1.2967747641461236, 0.797876734818731, 0.24913821848375456, 0.6674240891422544, 0.1330544746347836, 0.7946337716920036, 3.6349579095840454, 18.86528502191816, 35.42138140542166, 50.94147879736764, 39.56895916802542, 41.725287437438965, 42.81921182359968, 30.58811719076974, 32.81702981676374, 31.92924111230033, 38.323261805943076, 39.32542480741228, 43.92784554617745, 55.67007187434605, 62.48617131369454, 69.62998948778424, 62.81300067901611, 49.10945769718715, 26.732478414263042, 4.297650601182665, 0.4823151762996401, 0.2701651501868452, 0.12084471194871835, 0.09485589792685849, 0.10927720301385437, 0.12791218342525618, 0.13889575190842152, 0.29911525387849125, 0.29951743515474455, 0.06812609652323381, 0.19214270184082644, 0.11750832812062331, 0.12805417366325855, 0.10169923571603638, 0.11011127182947737, 0.17358867744249956, 0.13769247861845152, 0.18142638116010598, 0.08630888084215776, 0.22249522885041578, 0.25111332535743713, 0.0938451521630798, 0.11138258182576724, 0.13245733667697224, 0.10557267322604146, 0.20391038539154188, 0.10238572316510336, 0.1537262611091137, 0.16243350745311805, 0.1928460169583559, 0.15742737108043262, 0.08164733169334275, 0.1526908166706562, 0.09634967241436243, 0.17974453712148325, 0.13691514890108789, 0.196464101384793], [0.07643751946410962, 0.05967826090220894, 0.042695252025233846, 0.028638181143573353, 0.027539200382307172, 0.0034420132828277667, 0.06961411024842944, 0.02785053599758872, 0.049042472150176764, 0.04373130375253303, 0.034042298660746644, 0.030733727983066013, 0.03445163508877158, 0.06814708361136061, 0.015305142749899199, 0.02155965124256909, 0.013226189484287585, 0.02742079262887793, 0.036228938826492856, 0.031803000784878216, 0.038046170957386494, 0.04466038443414228, 0.027449572691693902, 0.08623479160347156, 0.04675234182338629, 0.05729420097278697, 0.017905473842152526, 0.04259246754060898, 0.06526567108396973, 0.03057120188272425, 0.03360560709344489, 0.027295251776065146, 0.008394451878432716, 0.04899262357503176, 3.4433339749063765, 19.771825177328928, 34.88013757978167, 32.301105226789204, 52.991204329899375, 57.44154289790562, 50.21664272035871, 41.307648590632844, 38.94894708905901, 31.15943976811, 37.7697057723999, 61.572670800345286, 81.79806395939418, 64.93689823150635, 52.03065061569214, 35.827753748212544, 28.256369488579885, 27.11512439591544, 12.258003268923078, 5.5489555937903265, 2.0227613108498708, 0.50678743741342, 0.14753187421177114, 0.05253685285736408, 0.21827631523566587, 0.41067064500280787, 2.220662291560854, 4.451779016426631, 0.6124161779880524, 4.232721856662205, 4.198454209736415, 4.154822996684483, 5.273953710283552, 5.924622544220515, 4.241302447659629, 2.884341844490596, 3.943568229675293, 4.320891456944602, 4.368137036051069, 6.603560558387211, 6.964880781514304, 7.752701844487872, 2.812888524362019, 0.260644761047193, 0.19299514538475446, 0.2087894185845341, 0.05302979837038687, 0.09986961353570223, 0.25371607712336947, 0.04239147529006004, 0.04055730013975075, 0.20751434271889074, 2.458597924028124, 6.882564170019967, 5.3324388691357205, 5.337226177964892, 2.566836093153272, 2.6847040312630788, 3.547349593469075, 5.667664263929639, 2.535904667207173, 5.676559695175715, 4.682380173887525, 3.970241061278752, 8.424053294318062, 5.312900968960353, 8.43445040498461, 4.3867747102464945, 10.521206361906868, 3.835871151515416, 9.346204314913068, 8.24639219897134, 4.750926324299403, 8.189293640000479, 4.338371387549809, 7.919020874159677, 4.609809713704245, 5.349979596478598, 2.1945153517382483, 1.1538656268801009, 0.35885464400053024, 0.187505661376885, 0.05184547656348773, 0.09358290516372238, 0.10546752743955169, 0.274393481867654, 2.165308816092355, 7.405496886798313, 20.498752662113734, 33.22503498622349, 47.13943495069231, 37.963035924094065, 37.20978518894741, 29.84335020610264, 20.217440945761545, 20.13390622820173, 23.344658374786377, 30.12262957436698, 33.861163411821636, 41.35718577248709, 50.15637057168143, 54.22561434337071, 49.612152917044504, 30.198576859065465, 8.985695293971471, 0.4491439605397837, 0.011004090774804354, 0.006521284289192408, 0.12790196468787535, 0.018442035586174046, 0.03391737357846328, 0.05568637492667351, 0.03403650736436248, 0.004963733023032546, 0.07105911842414311, 0.007866379455663264, 0.017126880353316665, 0.04778483124183757, 0.032841854861804416, 0.015094579762912222, 0.015231460632224168, 0.01035244609894497, 0.09774922552917685, 0.11346496508589812, 0.04381042093570743, 0.12485279116247382, 0.025054542547357932, 0.00518842607769849, 0.044551024945186715, 0.007612307955111776, 0.05203572760469147, 0.029913725198379586, 0.04368606582283974, 0.022429560277877108, 0.054383285742785246, 0.031161232186215262, 0.057936712567295344, 0.02630038033904774, 0.017555463427145566, 0.03303376492112875, 0.03109059329809887, 0.046713343023189476, 0.05251095996105245, 0.027730328430022513, 0.03722566944946136, 0.07875986663358552, 0.060388028887765746, 0.013066139188595116, 0.08300327536250864, 0.029666019204471792, 0.008512443180994263, 0.017119094163977673, 0.03357997204044035, 0.05981146411171981, 0.015633607981726527, 0.07600605940180165, 0.00806498495928411, 0.029360505419650247, 0.038928157916026454, 0.055919607768633535, 0.07762756132121597, 0.031219715119472573, 0.03851626001830612, 0.08339875271277768, 0.034597011216517, 0.04718090454116464, 0.02890243999926107, 0.05145865392738155, 0.05108376672225339, 0.060490039842469354, 0.06289811991155148, 0.016244722064584494, 0.04743819484221084, 0.04582786160920348, 0.04487648426688143, 0.03243948020307081, 3.131095175232206, 20.446616853986466, 43.878680092947825, 47.8868978364127, 64.9330975668771, 69.96755381992885, 55.7884726524353, 49.977815764290945, 47.91348859242031, 37.70476443426949, 39.700335706983296, 60.036604745047434, 70.130384853908, 66.60199928283691, 63.07495471409389, 44.87945345469883, 28.900040183748516, 25.08375426701137, 12.982672589165823, 6.073242775031498, 2.0554349975926534, 0.6649179607629776, 0.3077503719500133, 0.6053957832711083, 1.0241574155432838, 2.2809995795999254, 3.6678663151604787, 5.869812113898141, 5.381944784096309, 4.993780195713043, 6.6737017546381265, 7.26276091166905, 6.911852129868098, 13.269849453653608, 9.074803335326058, 9.09638704572405, 7.927625349589756, 4.928839291845049, 6.623066323144095, 8.372264896120344, 6.951618841716221, 6.081591904163361, 7.010469215256827, 1.5430088256086623, 0.6222755089402199, 0.28852079808712006, 0.0807503762521914, 0.13275936618447304, 0.2523555601281779, 0.08456115105322429, 0.04175636311993003, 0.25031126982399393, 1.871128384556089, 5.062011505876269, 4.6287974034036905, 3.708191054207938, 1.6593297038759505, 2.1196558943816592, 3.271490910223552, 5.73105571951185, 4.201592189925058, 6.853049959455218, 4.32293335880552, 7.401658875601632, 5.97754567010062, 6.99015702520098, 11.229787996837072, 7.636533175195966, 9.410521183695112, 6.651026742798941, 9.187089698655264, 10.676214592797415, 7.550800221306937, 11.02844136101859, 8.036815421921865, 8.529070104871478, 8.866259234292166, 6.068484561783927, 6.452225318976811, 3.9168623941285268, 2.4237273037433624, 1.1408932315451759, 0.4462011813053063, 0.11583481649202959, 0.1521155003990446, 0.3228686478521143, 2.6685008321489607, 9.461101463862828, 23.34403129986354, 33.24018553325108, 41.89870752607073, 40.490453583853586, 35.73429352896554, 31.928872857775005, 25.74325122152056, 29.439079693385533, 27.7776802948543, 35.3836144719805, 41.10712705339704, 48.852297919137136, 56.98413256236485, 60.85378238133022, 56.22379813875471, 35.222131388528005, 11.062894872256688, 0.5068027994462422, 0.0647424663017903, 0.0043772947142965025, 0.03146521248189466, 0.024458273114370446, 0.018282722349145582, 0.03179285329367433, 0.01634087895841471, 0.021543242569480623, 0.032042214913027625, 0.025012675240369778, 0.04316408918904407, 0.013318426142047559, 0.015020319194133793, 0.012220873696995633, 0.014421673192243491, 0.018030495615676045, 0.05160301564527409, 0.11081529940877642, 0.052552615225847275, 0.023850360020462955, 0.008842295168765953, 0.08858938275703362, 0.05317467577489359, 0.04692120883347733, 0.04649869864806533, 0.057234320257391245, 0.05518895786787782, 0.033000754192471504, 0.021997240172433, 0.024105728371068835, 0.02193489298224449, 0.022226976862709438, 0.03760700612994177, 0.009947798347898891, 0.02928468252399138, 0.046820269964103184, 0.13342591827469213, 0.11018204981727259, 0.14557333716324397, 0.20786101983061858, 0.15914368469800266, 0.11712073534727097, 0.27071310792650494, 0.2798939581428255, 0.12257773109844752, 0.16503783342029366, 0.06416106357106141, 0.21677268163434096, 0.07661519385874271, 0.14787977268653257, 0.11415853644055979, 0.17641112527676991, 0.10827109842960324, 0.0803035202303103, 0.13169808313250542, 0.1230995109570878, 0.16394583987338202, 0.1469313707202673, 0.11763312428125314, 0.1397887175636632, 0.13371390210730688, 0.1742659503860133, 0.1124048898262637, 0.18053212628832885, 0.15425644123128482, 0.16548048252505915, 0.08675178100488015, 0.13845424274248735, 0.17268025475953305, 0.2591770626604557, 6.195533241544451, 28.8446752003261, 54.82127298627581, 61.32359177725655, 79.96861716679165, 76.12628419058663, 67.9306755065918, 57.18202420643398, 53.06567512239729, 43.45876223700387, 51.558437143053325, 73.75729588099888, 92.87527820042202, 73.87799998692104, 63.921113286699565, 46.310361998421804, 39.00956664766584, 34.03427430561611, 17.071175030299596, 6.647668591567448, 2.8372050481183186, 0.6516049408486911, 0.6345874454293932, 0.8077796548604965, 1.8874757587909698, 2.2599120140075684, 5.901991392884936, 10.324948413031441, 6.911536421094622, 16.65225076675415, 11.628834332738604, 13.549740263393947, 16.260073593684606, 17.214716127940587, 12.950388652937752, 14.294138993535723, 14.014094454901558, 14.15000295639038, 14.266159466334752, 15.825312648500715, 14.89504439490182, 14.626454830169678, 7.365334561892918, 1.2606723585299082, 0.5633094044668334, 0.7289286745446069, 0.10141245289040463, 0.20637177117168903, 0.3267860476459776, 0.1238853359328849, 0.2257463072559663, 0.6966268792748451, 2.422414094209671, 7.395852787154062, 5.630467517035348, 7.564198085239955, 5.435811562197549, 7.256828887122018, 12.086370604378835, 12.755969371114459, 8.688308920179095, 12.907393200056893, 12.535343221255712, 11.869220290865217, 17.480602843420847, 13.932703256607056, 20.27037058557783, 13.947482075010027, 19.21753784588405, 15.113302946090698, 19.249336276735576, 18.640390941074916, 13.621756604739598, 17.546258108956472, 11.843948824065071, 19.504283053534373, 11.16980332987649, 10.614997489111763, 8.57583669253758, 3.6880968638828824, 2.137707748583385, 1.131286152771541, 0.41126235468047007, 0.5510446940149579, 0.2936685990009989, 0.7260105939848083, 2.7724211301122392, 9.413240534918648, 25.859864575522288, 42.40146180561611, 60.644912583487375, 51.03175326756069, 49.74552706309727, 41.98782859529768, 31.796231746673584, 32.845673765454976, 35.65415300641741, 42.35828569957188, 46.925774369921, 55.396003655024934, 64.50657544817243, 69.54715306418282, 66.32568332127163, 44.8302115712847, 15.893246923174177, 1.3107829838991165, 0.22841092784489903, 0.15202763011412962, 0.17746380450470106, 0.08710851400558438, 0.11936420282082898, 0.1299890298396349, 0.10996134951710701, 0.09305281325110368, 0.11604399526757853, 0.09520653089774506, 0.09284533759845154, 0.15808541434151785, 0.11317373785589423, 0.14298186264932156, 0.09943498471485716, 0.06686855400247232, 0.1885420421936682, 0.31938795319625307, 0.1251016913780144, 0.3178964246596609, 0.10996947836663042, 0.22823160461017064, 0.14550822494285448, 0.12510770319827966, 0.07676690750356231, 0.11155639535614423, 0.11883480979927949, 0.1287375669926405, 0.1010161138006619, 0.07774089024003063, 0.12140735318618161, 0.10975564484085355, 0.09355243215603487, 0.07371950495455946, 0.11357378174683877, 0.17859101401908056], [0.029981018908854042, 0.019768081306080734, 0.014320768249620284, 0.04548085880066667, 0.06846962523247514, 0.052554633867527754, 0.021059665928727815, 0.0514570186579866, 0.01509118199880634, 0.03820005252159067, 0.03207284737644451, 0.027959339087828994, 0.05247365410572716, 0.01978630506034408, 0.030567347803818326, 0.013981696667282708, 0.14620300408984932, 0.05804038593279464, 0.010755679104477167, 0.02469375021090465, 0.0530023719849331, 0.009256576420739293, 0.03645571880042553, 0.08186440183115856, 0.014998076816222497, 0.023690644751435945, 0.03302626371649759, 0.0453141189978591, 0.07071647859577622, 0.06329555144267422, 0.005925522909300136, 0.01422498285371278, 0.1629248753722225, 2.9011918774672916, 17.46133896282741, 33.998004708971294, 40.04050561359951, 50.534637451171875, 60.69323035648891, 52.20461613791329, 60.23558030809675, 43.37644345419747, 26.734707048961095, 27.29668082509722, 30.61238030024937, 52.448928696768625, 54.80397891998291, 69.6102705001831, 54.382195472717285, 28.98604324885777, 24.44533293587821, 16.52126853806632, 4.751404881477356, 1.4527757189103534, 0.12933771764593466, 0.202232246154121, 0.27730442423905644, 0.6378976106643677, 1.30623017677239, 2.0756492614746094, 2.298942433936255, 2.8902048213141303, 3.0211136596543446, 4.500880198819297, 4.507190465927124, 5.03797812121255, 4.8412820015634805, 8.536779999732971, 6.688124912125724, 8.465157100132533, 5.872717763696398, 3.8453367693083624, 5.093415192195347, 6.147459958280836, 3.132646143436432, 4.743597277573176, 6.778570915971484, 0.8117979392409325, 0.31276949548295563, 0.008705773074845118, 0.3890671213822705, 0.3013068677059242, 0.23765379616192409, 0.05339439898463232, 0.031136933847197464, 4.20901677438191, 11.860670532499041, 17.67257809638977, 14.808167593819753, 9.12023413181305, 3.732197948864528, 1.5831302212817329, 2.6801436245441437, 5.893786873136248, 4.558055187974658, 3.163705025400434, 3.55050841825349, 5.884306056158883, 6.107732764312199, 4.9092349495206555, 3.6204203239509036, 6.036364776747567, 8.925259862627302, 6.07461895261492, 9.469832743917193, 10.13160262789045, 5.946169776575906, 7.026912127222333, 6.274707964488438, 4.6983440944126675, 3.9839420403753008, 2.6198128504412512, 4.342767860208239, 4.307385461671012, 2.4231773103986467, 1.2665107995271683, 0.8047868811658451, 0.2927875348499843, 0.06381752129111971, 0.04979651793837547, 0.09535570003624473, 1.9225674186434065, 7.276393711566925, 21.733419758932932, 35.498954568590435, 41.17774854387556, 33.06839827128819, 23.136884655271256, 21.784570659909928, 16.463641916002544, 22.951850652694702, 24.20987238202776, 27.44917815072196, 30.844300746917725, 34.30040768214634, 46.79153169904436, 52.7386268888201, 47.53904322215489, 20.19797556740897, 5.0840672595160346, 0.10047469035323177, 0.0839505238192422, 0.039891860846962245, 0.03794236867023366, 0.01421710166947118, 0.09820959118327924, 0.09761684334703855, 0.08146215270140342, 0.06765016527580363, 0.06721578751291547, 0.0213438482689006, 0.037218395554061444, 0.05470919968294246, 0.014843752507918646, 0.027538194454142025, 0.039428553743554015, 0.06049210258892604, 0.0955770585153784, 0.03196905187464186, 0.17118248370076927, 0.08338932786136866, 0.029524816067091057, 0.031412422457443814, 0.06456994198794876, 0.025158877484500408, 0.019582452784691538, 0.03726623227287616, 0.062464963511696885, 0.04321094203208174, 0.04624187992885709, 0.0432505718698459, 0.054322370261486085, 0.03714114094951323, 0.05513932303126369, 0.02753368389260556, 0.09440087912870304, 0.007983235060237348, 0.010873447338651334, 0.03871082993490355, 0.04997182085311838, 0.04447371605783701, 0.01094036191768412, 0.036660222469695976, 0.023660536456320966, 0.04434803780168295, 0.12187147113893713, 0.015169763139316013, 0.0694580946915916, 0.056234661755817275, 0.027503731660544872, 0.024545240947710614, 0.021333627835182205, 0.05243942879938653, 0.02416416211053729, 0.02464050047897867, 0.03609625130359616, 0.044554729746388536, 0.10184488325778927, 0.020539670617186596, 0.043485857280237336, 0.004935875767841935, 0.08246955328754016, 0.031271463592669795, 0.012671182613952883, 0.02132267627998122, 0.01123189109577132, 0.01876500977336296, 0.013160975483645285, 0.06373762379267386, 3.461767762899399, 16.871596711022512, 38.79951565606253, 49.22423498971121, 56.621554715292795, 73.00049114227295, 61.122455324445454, 72.37925270625523, 53.20242261886597, 34.818128381456646, 36.853981835501536, 41.58001797539847, 58.091984612601145, 70.92536299569267, 79.57380662645612, 58.406119619097026, 30.041728224073136, 23.672279834747314, 14.904612064361572, 4.50389267717089, 1.5732074337346214, 0.16245264214064392, 0.40887952968478203, 0.7783658674785069, 1.8497772216796875, 1.6085112307752882, 5.092520611626761, 7.56178445475442, 7.721890926361084, 7.727735229900905, 5.6603352172034125, 9.845466256141663, 8.128245030130659, 8.674854602132525, 14.302685277802603, 9.45337506702968, 10.87851573739733, 8.958902171679906, 7.511358772005353, 6.317927931036268, 6.754766821861267, 4.900329530239105, 5.265391358307429, 4.728854937212808, 2.334219523838588, 1.2446342876979282, 0.2727669248623507, 0.5592333631856101, 0.6949745107974324, 0.16969236651701586, 0.12563473491796426, 0.0706642246139901, 3.920187975679125, 11.340557047298976, 16.916997977665492, 13.952272857938494, 8.129226463181631, 3.5112997336047034, 1.294941742505346, 2.544667648417609, 3.633385879652841, 4.57364911692483, 5.140595197677612, 6.832306546824319, 5.810218717370715, 6.488152282578604, 10.648863877568926, 13.52403279713222, 9.183063217571803, 9.511415106909615, 7.250701878752027, 12.784506491252355, 9.688859071050372, 8.05422934464046, 9.137639369283404, 9.176802890641348, 10.648838690349034, 11.279140182903834, 9.96200578553336, 5.61823217357908, 5.666245094367436, 4.7908089842115125, 4.2271424531936646, 2.368372308356421, 0.6668643248932702, 0.4714249606643404, 0.2980988898447582, 0.2441785346184458, 2.119798115321568, 8.668124403272357, 19.6277334349496, 37.77050828933716, 39.40858432224819, 31.9642322404044, 23.127278770719254, 26.96107414790562, 21.17142861230033, 29.784519808632986, 29.417755671909877, 32.4249255997794, 37.8095953805106, 43.854736600603374, 54.09145852497646, 60.962632860456196, 52.76119116374424, 24.575127022606985, 5.655550079686301, 0.3266410582831928, 0.12111129478684493, 0.0297782692526068, 0.07190054255936827, 0.042898958415857384, 0.014570021303370595, 0.038940544572791884, 0.08386259925152574, 0.025508735229128172, 0.0426704244289015, 0.016579772478767803, 0.02882223037470664, 0.06899003445037774, 0.08928083029708692, 0.10307097568043641, 0.021154679491051605, 0.07372046168893576, 0.034787106194666455, 0.04879988231030958, 0.08435474748590163, 0.08819509962839739, 0.008716519373202962, 0.07716941447662455, 0.04128313922722425, 0.012601471622474492, 0.01779419070641909, 0.04342244139739445, 0.061833322048187256, 0.03186973809663739, 0.07023287311728511, 0.03977188907031502, 0.05787181069276162, 0.04303054671202387, 0.05514812023778047, 0.02509186027704605, 0.07962655941290514, 0.09488520385431391, 0.09039287455379963, 0.11739562345402581, 0.0816025755235127, 0.15767439853932175, 0.12775089565132344, 0.0876243906095624, 0.23172947977270397, 0.0888276571141822, 0.20054228683667524, 0.08353322478277342, 0.1392762472054788, 0.21155695936509541, 0.11104243900626898, 0.07082602128918682, 0.08718020801565476, 0.20716436792697224, 0.2286010262157236, 0.08646423143467732, 0.11093944417578833, 0.209655066419925, 0.16185620985925198, 0.0798155924837504, 0.15097609082502977, 0.12119999288448266, 0.21793526996459278, 0.11321784941745655, 0.1372129443500723, 0.1413336196648223, 0.16396812296339444, 0.13095978274941444, 0.13336224454854215, 0.22485437297395297, 4.90334461416517, 24.868137768336705, 52.7788256917681, 65.59371839250836, 75.05817931038993, 81.20197800227574, 72.1011996950422, 77.46790490831647, 59.086911065237864, 38.52067749840872, 42.326417786734446, 44.488110065460205, 63.60417815617153, 63.59793867383684, 77.61348356519426, 63.66532230377197, 40.93340124402727, 32.197705609457834, 19.189871856144496, 5.201159170695713, 1.9556130511420113, 0.25206938119871275, 0.7791321777871677, 0.7006969494479043, 2.7151946808610643, 2.598760677235467, 7.361083132880075, 8.791627764701843, 12.433550374848501, 13.348506535802569, 12.414998684610639, 13.408388716833931, 14.529550909996033, 14.683707986559186, 18.922241142817906, 18.741707835878643, 16.11507511138916, 14.756215912955147, 13.97946115902492, 14.012238417352949, 14.620508909225464, 12.615425552640643, 11.751663718904767, 17.08617445400783, 4.441500459398542, 0.9724662921258381, 0.14339131782097475, 0.7413612274186951, 0.7748074669923101, 0.43709355858819826, 0.20857015677860805, 0.32743464569960323, 4.58366060256958, 9.462777716772896, 14.2030976159232, 11.879837138312203, 7.377691064562116, 5.502486910138812, 5.941329487732478, 7.15485234771456, 11.862387606075831, 11.031035644667488, 10.036965557507106, 10.863223620823451, 14.079137410436358, 16.49163099697658, 15.699268851961408, 14.165438379560198, 15.435437066214424, 17.111307825360978, 13.78063758781978, 19.271113668169292, 15.926092794963292, 15.21855252129691, 15.504363196236746, 14.549132670675005, 15.816748993737356, 16.607636383601598, 11.908265692847115, 14.201957242829458, 10.584924817085266, 6.972892488752093, 3.6329798442976813, 1.8955593364579337, 0.8499992436596325, 0.38642859725015505, 0.38441177404352594, 0.35458421600716455, 2.7108494511672427, 9.791014092309133, 25.998588834490093, 44.05630384172712, 55.7092319216047, 47.7576196534293, 35.64635017939976, 32.82513836451939, 26.082140922546387, 33.903001989637104, 35.830696310315815, 39.26622615541731, 43.90931470053536, 49.6765592438834, 61.15051909855434, 69.03918416159493, 62.39071001325335, 32.97173840659005, 9.220758063452584, 0.6529667877725193, 0.19882456186626637, 0.10480980987527541, 0.16868126791502747, 0.07863223419657775, 0.11364635106708322, 0.24152779685599463, 0.2215038077639682, 0.16374740909252847, 0.12039324188871042, 0.08796642654176269, 0.11337330857557909, 0.14123724055077347, 0.2664843148418835, 0.15705414967877523, 0.15282659152788775, 0.1193104764180524, 0.1366471139980214, 0.1918108303632055, 0.27453043737581795, 0.18371897456901415, 0.1171475239098072, 0.16364766444478715, 0.16038145470832074, 0.09616250531481844, 0.11433186142572335, 0.12146478439016001, 0.1402884450341974, 0.11954013338046414, 0.13458548033876078, 0.11558481704975877, 0.08121014479547739, 0.2018368366573538, 0.1569374959383692, 0.16298552283218928, 0.11866835158850465], [0.04511630229119744, 0.05414935061708093, 0.07971436862966844, 0.04926436667197517, 0.02633607467370374, 0.08173954460237708, 0.03653233897473131, 0.09203487501612731, 0.02843793188886983, 0.14804621732660703, 0.0685486677767975, 0.06588010489940643, 0.056167802307754755, 0.007597491294810814, 0.017796433264655725, 0.022405514693153755, 0.054265261361641545, 0.042160661425441504, 0.003852179431955197, 0.0791587909417493, 0.02981010272300669, 0.039277617021330764, 0.09369973532323327, 0.14434666798583098, 0.21992826302136692, 0.018058449562106813, 0.016203058318101933, 0.052578562404960394, 0.049955946526357105, 0.02474368699560208, 0.03561725647055677, 0.011659559843662595, 0.3261929808982781, 4.365428107125418, 25.858104944229126, 29.276106221335276, 50.775503703526084, 61.57071140834263, 47.68622343880789, 50.72905847004482, 37.32398925508772, 30.107190677097865, 31.342976433890207, 25.64816859790257, 20.65690061024257, 27.741044180733816, 26.29781995500837, 26.106291123798915, 38.07226855414254, 28.402186121259415, 12.149871059826442, 2.143185534647533, 0.8054864779114723, 0.22459150850772858, 0.4195926476802145, 0.15945923062307493, 0.8014578255159515, 0.863145072545324, 0.8024172197495187, 4.068923720291682, 6.434203428881509, 3.4850709353174483, 4.571488227163043, 1.3098056763410568, 6.652462414332798, 4.556558719703129, 5.680914912905012, 16.457904441016062, 7.5544653960636685, 9.387742383139473, 9.0952353818076, 3.23901589853423, 3.4562248374734605, 5.095393691744123, 4.309156383786883, 3.06796840259007, 4.676592758723667, 3.998013879571642, 2.021749262298856, 0.8914770036935806, 0.8154303814683641, 1.1491381376981735, 0.7809012542877878, 0.37987663596868515, 3.8837867975234985, 18.79095493044172, 32.06896243776594, 35.66185508455549, 33.869060039520264, 25.269128731318883, 10.488281454358782, 3.053181767463684, 2.3228533565998077, 4.803532438618796, 3.5165962151118686, 7.935887626239231, 3.8206641503742764, 6.969312863690512, 3.670870542526245, 9.456488728523254, 11.602545823369708, 5.7301828520638605, 8.67410853930882, 4.440354875155857, 8.03297219957624, 11.168929593903677, 6.339580689157758, 10.16576257773808, 7.397458689553397, 7.716638956751142, 10.037041987691607, 7.303809131894793, 6.098284951278141, 4.483445431504931, 4.010375593389783, 3.3216975075857977, 2.5409234379019057, 0.10210054168211562, 0.18890546554965632, 0.03741226318691458, 0.023104912967288067, 0.3084758887333529, 1.476874134370259, 5.885834225586482, 14.477228369031634, 30.990824358803884, 31.768567493983678, 23.193939788000925, 22.71880807195391, 21.662628037588938, 19.906601122447423, 24.647577626364573, 28.062954221452983, 24.915838888713292, 31.84557785306658, 41.33567762374878, 54.459355218069895, 56.25752469471523, 35.09341948372977, 12.447494540895734, 0.850984259375504, 0.11013388061629874, 0.12591853897486413, 0.061004980068121634, 0.04245651287159749, 0.07777930210743632, 0.13871736505201884, 0.07332315229411636, 0.041638511765216074, 0.0262600855369653, 0.10424098039844207, 0.02912892820313573, 0.06354875357023307, 0.04270791009600673, 0.03956230656642999, 0.016029675657461797, 0.03993601990597589, 0.08379710026617561, 0.17149287275969982, 0.23704623590622628, 0.0948726102443678, 0.0995306581524866, 0.04117296210357121, 0.029453817555414777, 0.05967883087162461, 0.02252230922957616, 0.05593880691698619, 0.04236812690006835, 0.02097532232957227, 0.07071944379380771, 0.055422326416841576, 0.026373648550361395, 0.0420931912958622, 0.08366736437061004, 0.09421116752283913, 0.004261668106274945, 0.058191549964249134, 0.048784832403595955, 0.04653820634952613, 0.042677236920488734, 0.007747343209172998, 0.012767145277134009, 0.07244767248630524, 0.10187085757830314, 0.04492292659623282, 0.01968759178583111, 0.0970863646694592, 0.03146954832066383, 0.07314847702426569, 0.06009889833096947, 0.0382721841867481, 0.025487648057086126, 0.014193274912291338, 0.012891237457681979, 0.06464131708656039, 0.1266180814376899, 0.035393122783196826, 0.07687902184469358, 0.10709844063967466, 0.08257957095546381, 0.07377237640321255, 0.019411797834826366, 0.012709001611386026, 0.024073192616924644, 0.08289141886468444, 0.016329454125038216, 0.026091647700273564, 0.033403529186866114, 0.16257230857653276, 5.874697131769998, 30.6602394921439, 45.03916127341134, 62.54381356920515, 73.02564362117222, 59.84957313537598, 62.54381356920515, 48.569513184683665, 40.757490226200645, 36.11495406287057, 30.4909223147801, 25.80902808053153, 34.344115325382774, 39.17124775477818, 43.642469133649556, 45.944039072309224, 30.599043233054026, 13.212425197873797, 2.876214189188821, 0.9063940803919519, 0.34708287566900253, 0.4965551293322018, 0.750763931444713, 2.8486448228359222, 3.2003925996167317, 5.16687502179827, 7.513002020972116, 8.507960609027318, 10.317473019872393, 9.230890274047852, 8.394202964646475, 10.171295949390956, 9.845709443092346, 9.253158382007054, 12.16244990485055, 8.262029119900294, 12.818926130022321, 10.349681394440786, 6.563323974609375, 4.824496456554957, 6.4765031933784485, 3.899173149040767, 3.7841574464525496, 3.5213186017104556, 5.0229960680007935, 3.6802992480141774, 2.763246468135289, 1.5057386883667536, 2.155588069132396, 0.7332566965903554, 0.38699131991182056, 4.57918552841459, 17.931320326668875, 30.61071273258754, 34.276526723589214, 31.620053223201207, 23.949572018214635, 9.399145245552063, 2.807084390095302, 2.998459275279726, 5.331859563078199, 4.1999693512916565, 6.701911875179835, 6.762943114553179, 7.114634871482849, 6.403756422655923, 8.95143893786839, 10.28383765901838, 8.208730357033865, 7.454056978225708, 6.936482191085815, 13.202114939689636, 10.651128121784755, 11.104164566312518, 13.454038381576538, 13.091386709894453, 10.323505793298994, 13.225405301366534, 9.344412548201424, 10.021530134337288, 9.778462171554565, 7.797324044363839, 5.601619030748095, 5.057850403445108, 2.1296474039554596, 1.8287832396371024, 0.7620443318571363, 0.23258541098662786, 0.14612554253212043, 1.6101270126444953, 6.836706927844456, 17.819004433495657, 32.75342600686209, 36.734716006687705, 28.080847569874354, 25.239805596215383, 22.840742009026663, 24.93427245957511, 30.337929930005753, 30.963952200753347, 29.196886335100444, 36.54460287094116, 47.136985710689, 60.421604428972515, 62.6081816809518, 40.56102296284267, 14.983151027134486, 1.7767269015312195, 0.13578206327344688, 0.04911005084535905, 0.05196383681946567, 0.039217437750526836, 0.004748030557363693, 0.06009297472025667, 0.06785797341061489, 0.02681427392443376, 0.016508446573945026, 0.011335379560478032, 0.046942955880825005, 0.07254294558827366, 0.01348039838818035, 0.04792423965409398, 0.03718591747539384, 0.07447837851941586, 0.07848369609564543, 0.0610690066324813, 0.1709376954074417, 0.041756895769919665, 0.10195443273655005, 0.03727029330496277, 0.044092871315245113, 0.00804721497531448, 0.04873528238385916, 0.0442519742064178, 0.03484410992158311, 0.03950798644551209, 0.01667079795151949, 0.016511929154928242, 0.03415120692391481, 0.01804838688778026, 0.01925285779205816, 0.04552899746756468, 0.03800150978245905, 0.1935557917292629, 0.15402172239763395, 0.16403529793024063, 0.1626627165824175, 0.1476165418113981, 0.23516769813639776, 0.18542171748621122, 0.1936974019876548, 0.1278721634298563, 0.3381457823727812, 0.24009207103933605, 0.0762865182810596, 0.11779853754809924, 0.10218784199761492, 0.20813953131437302, 0.1538445840456656, 0.10864128677972726, 0.14042907820216247, 0.0945298211382968, 0.26108304038643837, 0.1503118457538741, 0.16318646419261182, 0.19596179548118794, 0.2686811126768589, 0.27317024607743534, 0.21469230683786528, 0.1485288864267724, 0.13339789477842195, 0.15062682170953068, 0.10851999185979366, 0.19375169835984707, 0.10730504776750292, 0.8072040943162782, 11.833471809114728, 39.3935866355896, 53.48507186344692, 75.71356119428361, 83.13279901232038, 65.87293175288609, 69.93411908830915, 51.69119984763009, 45.9678053855896, 43.28190279006958, 37.642470359802246, 32.786589758736746, 40.997098854609895, 36.318220138549805, 39.059913294655935, 47.622887134552, 33.07984890256609, 16.140823398317607, 2.657687698091779, 1.184183874300548, 0.4728093892335892, 1.0030623589243208, 0.900127456656524, 3.6054708404200415, 4.129964513438089, 5.723000586032867, 11.017652545656476, 14.539189798491341, 14.061944093023028, 16.290727308818273, 11.46121164730617, 17.15912011691502, 15.0325996194567, 15.96297035898481, 26.786154985427856, 18.286963871547155, 25.70512819290161, 21.954278673444474, 12.195668373789106, 9.707564490182058, 11.675155367170062, 10.85033471243722, 13.0086110830307, 10.371881757463727, 9.992339015007019, 7.0124550972666055, 5.40315546308245, 5.001405409404209, 4.710684529372624, 2.258979001215526, 1.0933906776564462, 6.1118152652468, 18.407132966177805, 27.874902963638306, 31.361781733376638, 29.351112025124685, 22.57272219657898, 10.82720068522862, 4.45834766966956, 8.600564462797982, 10.519363352230616, 6.880351168768747, 13.555353539330618, 10.694745438439504, 13.219530599457876, 10.829565678324018, 15.369390964508057, 18.47740009852818, 14.403111934661865, 17.493410110473633, 11.13321237904685, 17.187064034598215, 20.724786247525895, 14.478622351373945, 21.27504709788731, 19.993486608777726, 14.87076565197536, 22.60374242918832, 18.02096598488944, 16.900756563459122, 14.712895631790161, 12.696142775671822, 11.048743997301374, 6.443769795554025, 1.5999494216271808, 1.5149060764483042, 0.7457136224423135, 0.2595698801534516, 0.46843267551490236, 1.957058927842549, 8.006040981837682, 18.374804735183716, 39.309311934879844, 44.898911884852815, 35.52383606774466, 34.785002844674246, 32.46355758394514, 30.73597833088466, 37.771380288260325, 40.04306255068098, 37.65140921728951, 44.70879874910627, 56.47780690874372, 69.4807630266462, 72.04981081826347, 50.93439858300345, 21.25816818646022, 3.382725489991052, 0.15245318013642514, 0.20677754868354115, 0.12103779587362494, 0.11583822273782321, 0.14337710929768427, 0.14554554436888012, 0.22218383555965765, 0.1976061301039798, 0.20057983696460724, 0.16946513870997088, 0.11560676087226186, 0.20655996964446136, 0.14602302946150303, 0.17007872435663426, 0.14831589428441866, 0.1820143046123641, 0.14650837198964187, 0.162531528621912, 0.30424704136593, 0.11100906186870166, 0.24238608937178338, 0.11735723194267068, 0.16298683919012547, 0.10265146461980683, 0.21301895805767604, 0.10100265166589192, 0.08299193704234702, 0.10088537367326872, 0.1673224608280829, 0.11186938998954636, 0.07552636228501797, 0.1395538223109075, 0.18274963301207336, 0.15512569887297495, 0.13704404341323034], [0.1044687374628016, 0.14583365033779824, 0.041273134228374274, 0.038071351391928535, 0.04642012429290584, 0.07345721045775072, 0.015718942242009298, 0.052455041890165637, 0.0735319782314556, 0.13008676602372102, 0.08659782819449902, 0.03174361540004611, 0.06425275400813137, 0.04815383554835405, 0.06508022067802292, 0.04059371372152652, 0.16763765391494545, 0.055866251167442114, 0.07648363270397697, 0.014751424247931157, 0.03795595633398209, 0.09062846191227436, 0.17292342813951628, 0.24864769194807324, 0.10871861941580262, 0.06782521373991456, 0.02305108817693378, 0.15772565507463046, 0.015814015176147223, 0.01453870182324733, 0.025399480913100497, 0.14959369786083698, 2.041638046503067, 10.864878160612923, 21.397995471954346, 29.42487062726702, 49.227253981998985, 54.34617601122175, 45.837134088788716, 42.576761381966726, 33.18808446611677, 25.88404083251953, 25.978280987058366, 30.20548336846488, 29.677833693368093, 18.832755293164933, 28.350382089614868, 29.24263674872262, 22.62037989071437, 8.56957289150783, 3.497882979256766, 0.8181685688240188, 0.1342921360794987, 0.20549116842448711, 0.0678791572738971, 0.7741458139249257, 1.6664500875132424, 3.1912222802639008, 4.250334237303052, 6.8843646219798496, 9.279485974993024, 9.50963636807033, 9.036288602011544, 6.73590897662299, 9.687620554651533, 7.619563068662371, 8.737861735480172, 10.081750171525137, 5.106234618595668, 9.894155757767813, 6.7910728965486795, 5.520181800637927, 4.291140139102936, 5.957443228789738, 3.4672448975699286, 3.767147387777056, 3.4336531800883154, 4.485317971025195, 6.4246887394360135, 5.93906524351665, 5.026260852813721, 4.41101393529347, 3.713267581803458, 3.1375561313969746, 17.6634464263916, 40.65237440381731, 55.998770305088584, 58.282893317086355, 56.752462250845774, 48.64628035681588, 26.050703798021587, 7.749229482242039, 2.6931754052639008, 3.753787304673876, 7.5604903527668545, 11.09484268937792, 16.55841360773359, 11.379605054855347, 9.591123972620283, 16.982524701527186, 23.602605036326818, 9.846848947661263, 6.425228093351636, 7.768333554267883, 16.335035971232823, 7.4435165609632215, 8.711435999189105, 9.06358025755201, 6.4608619298253736, 11.6731664453234, 12.156866158757891, 9.878702095576696, 3.7676802277565002, 7.27481256212507, 6.147225890840803, 7.504392334393092, 7.235568267958505, 2.137411581618445, 1.9559550327914101, 0.35917773523500984, 0.08456146317933287, 0.1568619478493929, 0.006767898689888949, 0.48575773728745325, 6.321904906204768, 13.790204388754708, 19.626362902777537, 33.02927643912179, 30.98258032117571, 24.38526749610901, 23.334006786346436, 17.439974989209855, 23.77143062864031, 31.12427146094186, 36.763203620910645, 41.450451442173545, 54.325282778058735, 56.969218254089355, 50.38394839423043, 20.953797136034282, 5.272495891366686, 0.5251783419932637, 0.06534016065831695, 0.08422740681895188, 0.03786339737208826, 0.08924043710742678, 0.11264444661459752, 0.04130561230704188, 0.03990876654695187, 0.07604768073984555, 0.0902532252616116, 0.1476243313934122, 0.05166610922398312, 0.19067927822470665, 0.0334109659306705, 0.011607407642129277, 0.11133323197386094, 0.053620517386921814, 0.1380076038518122, 0.008974728241030658, 0.184475608968309, 0.04179681059239166, 0.07149768953344651, 0.05110267410054803, 0.057079213937478404, 0.13246303637112888, 0.049610412746135674, 0.09228456233228956, 0.062495565441037924, 0.12635580051158155, 0.048272765773747645, 0.09720172240797963, 0.08827061379062277, 0.16588920487889222, 0.16870842288647378, 0.05370806876037802, 0.05252235256401556, 0.012864485366402991, 0.06703804526478052, 0.020051310304552317, 0.10502625576087407, 0.11040649563074112, 0.06722168398222753, 0.04708867806142994, 0.03849602610405002, 0.03920360581417169, 0.12190207306827817, 0.06186874836151089, 0.02314540115185082, 0.09352110419422388, 0.03288927428158266, 0.0498292877871011, 0.06886432905282293, 0.06932037922420672, 0.007306054567119905, 0.012571599966447269, 0.016056771257093976, 0.10611778790397303, 0.09539038674639803, 0.20671113367591584, 0.13822567143610545, 0.04069063566359026, 0.01935939457533615, 0.07703734442059483, 0.03896539931052497, 0.03333291065480028, 0.010461512969673743, 0.013100041342633111, 2.502009834562029, 12.965555701936994, 29.55416965484619, 39.73612240382603, 60.68700477055141, 66.12729835510254, 54.26919344493321, 51.78278405325753, 40.19969926561628, 32.44816732406616, 36.313384192330496, 36.40784842627389, 34.08963407788958, 26.679475818361553, 28.42481640407017, 32.98832375662667, 27.108450651168823, 12.269986305918012, 4.937429870877947, 0.7988193556666374, 0.5931056141853333, 0.466384476849011, 0.6857691247548375, 1.8401991299220493, 3.903742892401559, 6.652738605226789, 8.023406267166138, 10.291381665638514, 8.953700576509748, 9.7061687707901, 11.400562558855329, 8.32552523272378, 14.615865775517054, 15.071438312530518, 13.580140369279043, 15.250375270843506, 8.880838291985647, 8.3744501045772, 8.786005803516932, 5.909259208611079, 5.000316279275077, 5.1652591313634595, 2.6127649886267523, 4.618277830736978, 2.8535105160304477, 4.271369474274771, 5.003106849534171, 5.779142464910235, 5.165880126612527, 5.320546592984881, 3.0971588705267226, 4.621197376932416, 19.486803122929164, 40.65574080603463, 55.43833555494036, 59.75024168831961, 56.00257791791643, 46.73463290078299, 26.787561995642527, 8.690932733672005, 5.112861028739384, 6.5505019426345825, 10.105583361216954, 12.066523943628583, 11.477169922419957, 11.708588361740112, 10.841344611985342, 10.38834377697536, 9.318187441144671, 8.479197672435216, 7.7224684953689575, 8.011976480484009, 10.300975390842982, 13.903469579560415, 10.800910438810076, 11.010977932385035, 13.693851113319397, 13.06070259639195, 14.849005631038121, 14.729147468294416, 10.413446749959673, 10.910993354661123, 9.170723216874258, 10.066032477787562, 9.492394413266863, 5.320539210523878, 2.7456981412002017, 1.0278747017894472, 0.932969257235527, 0.14292744414082595, 0.07748542859085969, 0.7539779618382454, 6.764231136866978, 15.597995383398873, 24.530290297099523, 33.66990729740688, 32.08391843523298, 26.432548999786377, 25.106721537453787, 25.714994634900773, 32.95996815817696, 37.171733379364014, 42.98750066757202, 45.349829128810335, 58.965262004307334, 61.76865863800049, 55.61752264840262, 24.818449463163102, 6.104887476989201, 0.458916249019759, 0.04259263038901346, 0.101629543384271, 0.049984031090778966, 0.11388263053127698, 0.08105599520994083, 0.049129765680325885, 0.09304794136966978, 0.010767609446442552, 0.0357147348113358, 0.03936500893905759, 0.011978960695809551, 0.03581988399050065, 0.051261156132178645, 0.03281302051618695, 0.07478261326572724, 0.07073412729161126, 0.10111130547842809, 0.05527469416015914, 0.14742010592349938, 0.08014360988246542, 0.030527812960956777, 0.02007263496385089, 0.05650327680632472, 0.05147420595000897, 0.034668159005897384, 0.042958370942090235, 0.01591443326989455, 0.07396518891411168, 0.05999046164963927, 0.08079281183225767, 0.12364527024328709, 0.018724007598523582, 0.08696299538548503, 0.04548882480178561, 0.23339007209454263, 0.1686651459229844, 0.230116249195167, 0.07813030148723296, 0.1576320036713566, 0.21372190676629543, 0.19366217244948658, 0.1314165453825678, 0.2621550171502999, 0.2348321761403765, 0.15228589411292756, 0.13424030957477434, 0.09270570187696389, 0.10695935453155211, 0.21970579853015287, 0.14339715322213514, 0.37033800780773163, 0.1932046227157116, 0.10738179007811205, 0.06551630156380789, 0.2701976927263396, 0.22416510353130953, 0.23474380373954773, 0.3460477026445525, 0.2214143904192107, 0.1498734171369246, 0.08822823927870818, 0.2240455456610237, 0.11527490296534129, 0.16126348237906182, 0.15186928718217782, 0.2834675306720393, 4.386532391820635, 18.073417936052593, 38.137421812329976, 57.92167384283883, 72.26491315024239, 74.6926554271153, 62.77059582301548, 61.5141669682094, 48.05720860617501, 40.059814657483784, 39.562007495335166, 42.58136803763253, 43.45470448902675, 32.753488540649414, 39.60515233448574, 41.795175892966135, 29.735958848680767, 12.515846576009478, 4.228955498763493, 1.1746214159897395, 0.4204761545572962, 0.8044353457433837, 0.5045598883713994, 1.7163321822881699, 4.2027164953095575, 10.440349306379046, 11.433092287608556, 14.632442440305438, 17.227132558822632, 21.442580325262888, 18.17987997191293, 16.92074305670602, 22.336519922528947, 20.416835137775966, 18.856380905423844, 22.443492650985718, 14.492886134556361, 22.071618114198955, 14.116677658898489, 13.811906218528748, 10.642760753631592, 12.598594410078865, 7.461568849427359, 8.91677176952362, 6.876818878310067, 8.969676222120013, 12.98489601271493, 9.933796967778887, 9.938323719160897, 9.144192389079503, 5.29790415082659, 5.906678821359362, 24.417611360549927, 41.06112650462559, 55.59438514709473, 57.4738381249564, 54.87557315826416, 45.11636618205479, 28.204831225531443, 11.394421219825745, 8.627072708947317, 9.762740135192871, 15.402469600949969, 16.730814048222133, 20.346231017793926, 16.086007322583878, 14.748928989682879, 25.505178144999913, 32.912609236580984, 17.197639192853654, 14.679266350609915, 17.792213916778564, 26.462617329188756, 20.046588216509136, 21.472386360168457, 17.750785282679967, 19.566615343093872, 24.027199029922485, 20.498320136751445, 21.88750648498535, 16.66670823097229, 17.766298873083933, 16.062753438949585, 17.94773370879037, 16.04758725847517, 6.505329098020281, 4.604815695966993, 0.9714695513248444, 0.8041184970310756, 0.31779654430491583, 0.13325409963726997, 0.8124641520636422, 7.981581585747855, 17.109127828053065, 27.535665852682932, 44.217467308044434, 42.60666642870222, 36.254355771201, 36.0369987487793, 27.41053053310939, 35.511645453316824, 42.617005348205566, 49.24892888750349, 53.063691411699565, 69.46155820574079, 70.80954347337995, 64.79624584742955, 34.08885587964739, 9.803823096411568, 1.0772547892161777, 0.14655561159764016, 0.13926794193685055, 0.18245054834655353, 0.2111174315214157, 0.32213352301291054, 0.18514171322541578, 0.13586982499275888, 0.26094695340309826, 0.22829364985227585, 0.17881772613951138, 0.1546643493430955, 0.25041644275188446, 0.0916993733761566, 0.09319402995918478, 0.24467801781637327, 0.17844100349715777, 0.1582245004496404, 0.17457658371755055, 0.3388480118342808, 0.17644579841622285, 0.17167423159948417, 0.16075160913169384, 0.13352560863963195, 0.18502446237419332, 0.23640681164605276, 0.2318391038903168, 0.11991943445588861, 0.24239966007215635, 0.19017197830336435, 0.11399161682597228, 0.23519874789885112, 0.22572139145008155, 0.2614705924476896, 0.20506265998951026], [0.02145675988867879, 0.03821497011397566, 0.06117934999721391, 0.03696044707404716, 0.05417313666215964, 0.004597232510734881, 0.07636311131396464, 0.035949182230979204, 0.11407377384603024, 0.09784862412405865, 0.05946068186312914, 0.030039247391479354, 0.0338097307831049, 0.03923385490530303, 0.04021751355113728, 0.10622040954019342, 0.09550659265369177, 0.05740151807133641, 0.05691020782770855, 0.012515439319291284, 0.03874237163524542, 0.03725608817434736, 0.14329074536051067, 0.1681806312075683, 0.1746655667998961, 0.02403971369910453, 0.0438729920424521, 0.04701532842591405, 0.07051578829331057, 0.052015877062720914, 0.06247425265610218, 0.026721675946776356, 2.3358708066599707, 15.535908017839704, 34.88772848674229, 41.29990482330322, 48.21369593484061, 50.824290479932515, 43.36029584067208, 39.60670873097011, 34.47531121117728, 29.716069630214147, 23.333445719310216, 21.710360424859182, 22.2911707673754, 32.27681085041591, 43.1982673236302, 28.482734850474767, 17.422903265271867, 5.847288225378309, 0.8377389843974794, 0.05504193290003708, 0.2318298758140632, 0.05195269527445946, 0.9580417232854026, 1.1155842010463988, 3.724910591329847, 3.9823205045291354, 6.9675701686314175, 8.381221992628914, 6.885870209762028, 9.724612763949803, 8.826858605657305, 8.283869045121328, 9.716099483626229, 9.879728691918508, 9.713572076388768, 7.7559362309319635, 4.091587007045746, 8.44046493938991, 8.73930435521262, 4.557331272533961, 7.187689099993024, 10.7933976990836, 10.66476309299469, 8.092161297798157, 10.224356736455645, 13.511178629738943, 14.051031078611102, 14.974470990044729, 15.065412487302508, 14.58951473236084, 12.17575570515224, 12.161245260919843, 29.322318690163748, 54.11374487195696, 62.187030519757954, 60.608990396772114, 61.30800001961844, 60.115223612104145, 41.29513488497053, 18.216477870941162, 11.300949709756033, 13.294729215758187, 16.431912967136928, 21.831210442951747, 22.53462174960545, 25.269307647432598, 22.78780194691249, 18.478649037224905, 10.965877175331116, 15.583265202386038, 10.577556252479553, 9.002590707370214, 10.637757182121277, 12.024866887501307, 11.495576569012233, 12.337698238236563, 13.11960768699646, 8.774638550622122, 13.620858550071716, 10.69929129736764, 10.489220329693385, 9.539147973060608, 7.060560081686292, 3.7465729032244, 4.086703726223536, 5.283798004899706, 4.055087685585022, 2.043841276850019, 0.9331100668225969, 0.21231800424201147, 0.07019826104598385, 0.12330966682306357, 1.2942611447402408, 7.106907171862466, 21.45914830480303, 38.72125809533255, 43.07286623546055, 27.811349528176443, 30.319677012307302, 18.41471345084054, 15.003114938735962, 16.158518723079137, 23.483808210917882, 45.11659894670759, 50.168578556605745, 50.278863838740754, 54.29975509643555, 36.99753509249006, 16.000461101531982, 2.3780227048056464, 0.4356248016868319, 0.07477001287043095, 0.14674607637737477, 0.10603711687560592, 0.08280761978988137, 0.08930449759853737, 0.01740757841616869, 0.05514736706390977, 0.07352349654372249, 0.14167478707219872, 0.12782389244862966, 0.14481436860348496, 0.04491790204441973, 0.023136100133082697, 0.04338463003348027, 0.016994499867515903, 0.07015539120350565, 0.08154781096215759, 0.1664228726710592, 0.03512251623240965, 0.0755786094814539, 0.06942220697445528, 0.06389540354056017, 0.0571492998195546, 0.06388210425419466, 0.068095284248037, 0.03461523327444281, 0.037683975749782155, 0.015349613935021418, 0.025426361077864255, 0.03458409530243703, 0.0937961551493832, 0.16141554207674094, 0.04419418337887951, 0.039067081175744534, 0.004797949530516884, 0.07219812087714672, 0.022836996807849834, 0.018459643569907973, 0.08334794401058129, 0.08199050756437437, 0.020393263116212826, 0.02934393220181976, 0.05107850468318377, 0.04263291840574571, 0.018386092070224028, 0.013516165665350854, 0.05467294216422098, 0.06567075649010283, 0.05033389053174427, 0.05448193455647145, 0.054925034887024334, 0.02667328282924635, 0.029949504349912916, 0.02536570343987218, 0.1109492015093565, 0.13344251524124826, 0.140421275049448, 0.1147720678044217, 0.016294679205332483, 0.04274223718260016, 0.031708606385758946, 0.027377634409016798, 0.06757917694215264, 0.01516398202095713, 0.3169460685125419, 3.32387598497527, 19.966892378670828, 38.31166178839547, 54.15718500954764, 61.37117304120745, 60.180453300476074, 53.01631511960711, 48.31798492159162, 39.922535623822895, 34.39995799745832, 31.64708171572004, 28.405420507703507, 31.598909854888916, 36.11360958644322, 42.186588764190674, 27.10707664489746, 17.695703438350133, 5.451767665999276, 1.0160571187734604, 0.05020648201129266, 0.4096731985253947, 0.9510005925382886, 2.469559792961393, 6.590458861419132, 6.247905722686222, 7.963370357240949, 9.580538392066956, 11.074492284229823, 11.320181454930987, 10.775816151074, 8.850298353603907, 12.259791561535426, 15.05283624785287, 14.114700896399361, 13.811457191194807, 15.149388415472847, 8.739570992333547, 6.015925782067435, 6.296457997390202, 5.727906448500497, 6.701184485639844, 9.143265673092433, 8.738072787012372, 8.50175326211112, 11.08349975517818, 12.60615405014583, 12.77564753804888, 14.157421026911054, 15.631080968039376, 14.56498064313616, 12.570394277572632, 15.313517025538854, 36.68443536758423, 58.648590905325754, 68.73218495505196, 65.31094060625348, 68.40222890036446, 63.60326099395752, 45.654222760881694, 21.797416142054967, 15.416569232940674, 15.343319586345128, 18.847063371113368, 19.335801397051128, 22.573780059814453, 23.015232120241436, 21.881525823048182, 17.169047355651855, 14.325208732060023, 10.982115983963013, 8.678833314350673, 8.117842708315168, 8.385605437414986, 11.731657249586922, 14.612785986491613, 13.614475761141096, 18.795954159327916, 13.831971747534615, 14.399969611849103, 14.633859872817993, 13.664036393165588, 15.53428213936942, 12.976229003497533, 9.588164908545357, 9.855185917445592, 7.793353148869105, 4.292142416749682, 3.8058210611343384, 1.2733541237456458, 0.38305418831961496, 0.17607971520296165, 0.4061046742967197, 1.2221973602260863, 6.945537430899484, 16.265621730259486, 34.5571470941816, 37.00729731151036, 29.624947479793004, 27.99084060532706, 22.625360012054443, 20.11663474355425, 22.279998064041138, 27.253659316471644, 50.33359479904175, 56.268864154815674, 58.43101501464844, 62.21547644478934, 41.36805970328194, 17.31455305644444, 3.3155240331377303, 0.38261566470776287, 0.10437185623283897, 0.12595830112695694, 0.07154487485864333, 0.0779879041282194, 0.08454426231661014, 0.03098706921030368, 0.05643531473885689, 0.07114202861807176, 0.08820926743958678, 0.09506338036486081, 0.027590422990864942, 0.032204632447766404, 0.027749113672013794, 0.012378831560324346, 0.01782810897566378, 0.05256691874404039, 0.14536998021815503, 0.020017497208235518, 0.010532510633181249, 0.009029047513779784, 0.09640014184904949, 0.017256658657320907, 0.09175591569926057, 0.053693517576903105, 0.03033335500263742, 0.035370988970888514, 0.031039764239851917, 0.07804063986986876, 0.11431514232286386, 0.03148090021152582, 0.0856045682781509, 0.024992597389167974, 0.08756275248846837, 0.261728435754776, 0.11673170407967907, 0.26016015133687426, 0.1934087531907218, 0.16147245759410517, 0.14883855623858316, 0.16018531737583025, 0.12370572771344866, 0.2755581736564636, 0.17606068908103875, 0.1759430853916066, 0.09519433083810977, 0.13146101656769002, 0.08157955961568014, 0.17139607295393944, 0.14959924827728951, 0.2478463692324502, 0.2384251547711236, 0.2216907034495047, 0.10848123393952847, 0.10094477262880121, 0.18119384720921516, 0.3445192889443466, 0.37951657814638956, 0.3327968365379742, 0.1950478766645704, 0.07249607238918543, 0.1609145932431732, 0.11680749644126211, 0.20707990388785089, 0.18973601955388272, 0.7401317762477058, 6.4279457075255255, 27.438245160239084, 51.42040770394461, 67.00949723379952, 69.7720593043736, 68.2282738004412, 61.33377088819231, 55.00257928030831, 48.372952120644705, 42.95820011411394, 33.595683165958945, 32.41747713088989, 32.863884993961875, 45.534821442195344, 57.340971197400776, 38.42322901317051, 21.36168244906834, 7.32316073349544, 1.4222236211810793, 0.2784408889710903, 0.6532607834253992, 0.8977237056408609, 3.3382661385195593, 7.776441233498709, 10.532290475709097, 13.19914632184165, 18.160885334014893, 20.73840124266488, 20.184740986142838, 22.14068841934204, 22.52365401812962, 21.98558725629534, 19.42843999181475, 19.365841933659144, 20.807954447610037, 22.96567061969212, 13.42235633305141, 16.06251893724714, 16.00332202230181, 9.527758138520376, 11.862488354955401, 17.358667169298442, 15.207888773509435, 11.781377690179006, 14.84795297895159, 19.665305818830216, 19.098379714148386, 20.779661382947648, 20.537353379385813, 20.087002413613455, 15.416093281337194, 18.40250720296587, 42.872417654309956, 60.67427567073277, 70.08127498626709, 67.01995427267892, 69.15571240016392, 64.36702782767159, 46.484591552189414, 24.712117706026348, 16.21211886405945, 18.546770913260325, 22.151374748774938, 26.93266817501613, 27.23067467553275, 30.182335444859095, 29.65746852329799, 24.753971917288645, 17.608918700899395, 22.518371650150844, 17.190008333751134, 16.095724378313335, 17.000447579792567, 22.738989114761353, 21.728943381990703, 18.795408725738525, 22.277416808264597, 20.17986682483128, 24.70629164150783, 21.205309765679495, 18.82691012110029, 19.074521337236675, 19.667774166379655, 14.161324177469526, 13.969771027565002, 13.079786692346845, 10.055644052369253, 5.452265764985766, 2.6159843930176327, 0.4483601983104433, 0.25152047351002693, 0.43879654577800203, 1.4185411844934737, 7.676035421235221, 25.15583314214434, 46.826470715659006, 53.66414431163243, 39.964335986546104, 43.577861309051514, 28.963360854557582, 22.458773476736887, 25.617243903023855, 33.89204815455845, 58.22788095474243, 64.33298860277448, 65.39930779593331, 69.36774362836564, 50.95769589287894, 24.267182861055645, 4.675524473190308, 0.615831868989127, 0.22016296828431742, 0.3365134713905198, 0.2323757436658655, 0.28014634602836197, 0.2193819201950516, 0.08228413680834429, 0.20309621122266563, 0.18484995673809732, 0.26247742984976086, 0.18831526221973555, 0.22628001576023443, 0.19033342892570154, 0.08173172109361206, 0.12457172838704926, 0.16653181825365337, 0.16985444139157022, 0.27416239998170305, 0.38426594329731806, 0.09885174315422773, 0.12113872117229871, 0.27200582570263315, 0.1458106887127672, 0.20616329807255948, 0.21616387287420885, 0.14116064751786844, 0.13218775471406324, 0.11435851428125586, 0.14313983917236328, 0.23637492050017628, 0.15179535400654587, 0.18284880769039902, 0.310066999069282, 0.19597589543887547], [0.0248579132769789, 0.056731159399662695, 0.032046242018363306, 0.049189425871840546, 0.017667291087231467, 0.10409253729241234, 0.07104360032826662, 0.06971781075532947, 0.08768122470272438, 0.1349448867674385, 0.07481545436062984, 0.030100003417049135, 0.027634329295584133, 0.06323328228401286, 0.03557893281270351, 0.0867007008886763, 0.09351049869188241, 0.12761218952281134, 0.07108579842107636, 0.07795911388737814, 0.03006963897496462, 0.12512719072401524, 0.1420457557375942, 0.2073129535253559, 0.05727077115859304, 0.025942176613690596, 0.018542903209371225, 0.01955477025226823, 0.1445124883736883, 0.03319757684533085, 0.07599507391984973, 0.9288897961378098, 7.987557905060904, 29.717007637023926, 40.656769139426096, 40.077049664088655, 47.277464389801025, 42.93857145309448, 35.68021222523281, 30.279002257755824, 33.14392171587263, 22.557615075792583, 32.34055709838867, 38.44000891276768, 35.84347057342529, 30.224246978759766, 26.246689898627146, 21.08081889152527, 6.123619386128016, 1.57050393308912, 0.1125032366918666, 0.1648557417626892, 0.4759685939976147, 0.9673260365213666, 1.1278309438909804, 6.513531880719321, 2.7024818658828735, 6.76792801277978, 4.836631919656481, 8.684279833521162, 8.199728965759277, 5.945736816951206, 6.469798181738172, 6.069136389664241, 15.027305092130389, 17.69302317074367, 13.99679344041007, 18.142550774982997, 11.314898218427386, 7.8002570526940485, 12.438050201960973, 14.299320612634931, 15.725288118634905, 21.092608247484478, 20.739804778780254, 25.589572702135357, 22.650573287691387, 25.129245860236033, 25.624416181019374, 27.058599063328334, 28.525016375950404, 29.28435720716204, 24.86650320461818, 31.44349602290562, 37.55441583905901, 48.14753518785749, 54.848753111703054, 56.65387773513794, 58.1035464150565, 61.04267610822405, 50.38069316319057, 32.67155885696411, 26.993324211665563, 24.56858355658395, 31.16373028073992, 29.769563811165945, 34.322791303907124, 33.22175891058785, 32.33932031903948, 25.930284568241664, 23.0546874659402, 19.12844283240182, 19.05161486353193, 12.052771721567426, 9.096206392560687, 15.585723127637591, 8.990208148956299, 7.418882591383798, 16.446314845766338, 11.537788612501961, 12.87694706235613, 14.823198284421649, 12.13617616040366, 12.390274388449532, 10.806970136506216, 9.569915464946202, 9.892848627907888, 7.087474797453199, 2.7005761052880968, 1.1312338241509028, 2.001905858516693, 0.6891649482505662, 0.23800090753606387, 0.056987978118870936, 0.054963093916220326, 1.4333762398787906, 6.114568054676056, 22.83520082065037, 40.00943674360003, 40.524315629686626, 28.902690921510967, 31.47469343457903, 28.82035650525774, 27.80057634626116, 30.5564820425851, 33.61804594312395, 48.49471582685198, 46.81031615393502, 53.29376016344343, 45.36038344247, 28.585418803351267, 8.082980121885027, 0.3540940965924944, 0.08639318881822483, 0.04546536445351584, 0.04864724925053971, 0.04920407883556826, 0.02685682994446584, 0.04052442851077233, 0.03707469880048718, 0.12717335378485067, 0.21470522614462034, 0.17194369142608984, 0.10827440968049423, 0.10604202946914093, 0.021572299135316695, 0.08281173171209437, 0.04405170798833881, 0.0745383542297142, 0.06787256191351584, 0.052391279954463243, 0.031872533660914214, 0.045703150265450986, 0.05617138497265322, 0.07047868599849087, 0.08511002481515918, 0.031817874272486994, 0.021020477138725773, 0.029885484570903436, 0.08313294340457235, 0.0617880162649921, 0.12169144222778933, 0.05440250524718847, 0.0218791615084878, 0.07213390432298183, 0.06306626088917255, 0.008600323643934513, 0.010984289426622646, 0.044883741198905876, 0.025154188807521547, 0.013410701815571104, 0.018460240680724382, 0.022377572621085813, 0.013763896256153072, 0.07103068102151155, 0.0993963625015957, 0.06933462845959834, 0.10694459639489651, 0.024872786764587675, 0.013868179455000375, 0.026637374756059477, 0.07622737716883421, 0.07570241498095648, 0.038089067941265445, 0.08589226712605783, 0.04408871868093099, 0.030701015809816972, 0.043180713297000954, 0.11953678141747202, 0.10021462823663439, 0.05416469907920275, 0.056396892693425925, 0.032984591488327296, 0.11647652062986578, 0.06609946848558527, 0.0603367452110563, 0.08138456900737115, 1.0710520020553043, 8.58080986567906, 31.892676217215403, 51.217770440237864, 51.80252388545445, 59.584297861371724, 54.12031091962542, 44.364772592272075, 37.376733030591694, 41.95127064841134, 30.355950083051408, 31.609095914023264, 33.637935161590576, 33.05713176727295, 31.024363313402446, 32.102730682918, 20.782491036823817, 7.5371904373168945, 2.0719495628561293, 0.2493097521364689, 0.2197838029158967, 1.2381756114108222, 2.551173767873219, 4.304561018943787, 6.173272516046252, 9.451704025268555, 11.510998964309692, 9.26650413445064, 12.600426128932408, 10.582303609166827, 10.088742664882115, 12.575437801224844, 10.658956136022296, 10.257284249578204, 11.38070547580719, 13.865312678473336, 12.66241535118648, 7.410273773329599, 8.169549465179443, 12.179015278816223, 13.80839650971549, 17.0362777028765, 20.60927070890154, 21.96707378114973, 23.60689033780779, 22.725115299224854, 24.813618728092738, 26.28954986163548, 27.502130372183665, 30.349776608603342, 30.260033675602504, 27.519328900745936, 36.429398264203755, 44.587684699467246, 56.0105162348066, 63.57663549695696, 63.58154787336077, 65.43668910435268, 66.29554203578404, 56.03561660221645, 36.02643401282174, 30.610427856445312, 27.660358224596294, 31.80124487195696, 31.571474892752512, 34.04651355743408, 32.473396233149934, 31.638215814317974, 24.23193986075265, 22.852541787283762, 17.514782769339426, 16.70404437610081, 12.279587847845894, 8.210840003831045, 10.839049100875854, 13.717974390302386, 13.75356045791081, 22.610341480800084, 15.334874050957815, 16.548733030046733, 22.489819765090942, 14.16822373867035, 14.294110332216535, 11.22180277960641, 10.27685993058341, 8.714550529207502, 10.195187330245972, 6.084642163344792, 4.541848514761243, 2.9828668662479947, 2.259679900748389, 0.4315285672034536, 0.15568622308118002, 0.07886122619467122, 1.5860715891633714, 6.5541775396892, 24.66633255141122, 40.40301397868565, 41.68841334751674, 37.364340918404714, 27.391673122133525, 26.699665546417236, 23.73897906712123, 35.14284202030727, 43.46774278368269, 54.98240171160017, 52.938391072409495, 60.13886138371059, 52.559547492435996, 34.2243527003697, 9.823353614125933, 0.3319255161498274, 0.10275459515729121, 0.05515200485076223, 0.05172561674511858, 0.029979556665888855, 0.04876170793016042, 0.05235640325450471, 0.06706796865910292, 0.048024839255958796, 0.09124585414039237, 0.0695450489542314, 0.14865936871085847, 0.059338864471231184, 0.02016119396180979, 0.10362010728567839, 0.020154924298237478, 0.11410863697528839, 0.1371541153639555, 0.06626866119248526, 0.01748065833401467, 0.04334837251475879, 0.04886658908799291, 0.03125746202255998, 0.05842870473861694, 0.03528447236333575, 0.058860795838492255, 0.01786917052231729, 0.07400003168731928, 0.11269441393337079, 0.037972973992249796, 0.040225513479007144, 0.05483747672821794, 0.024342055332713892, 0.09374008780079228, 0.12242975618158068, 0.16536788642406464, 0.30505137677703587, 0.08218875514077288, 0.13576994463801384, 0.2227897944727114, 0.19083178575549806, 0.13079987918691977, 0.1747467467295272, 0.22716303409210273, 0.23216241225600243, 0.1911113964659827, 0.08307592610695533, 0.14429902125682148, 0.17628850042819977, 0.21034201527280466, 0.1924628210919244, 0.20999361468212946, 0.10892863957477467, 0.24581380401338848, 0.1493985376187733, 0.20790858513542584, 0.36673713102936745, 0.4007408006915024, 0.15315792017749377, 0.15717358541275772, 0.12180821810449872, 0.2914951156292643, 0.18594541081360408, 0.15601413191429206, 0.1899047712130206, 2.738756022283009, 14.261631846427917, 42.74522393090384, 63.23039286477225, 65.72037015642438, 69.45854268755231, 61.91375092097691, 54.245916979653494, 43.05870233263288, 48.14098998478481, 33.68466179711478, 44.0406356539045, 51.26300321306501, 49.17978041512625, 43.85904448372977, 36.28561919076102, 25.95194731439863, 8.25086944443839, 1.9119792325156075, 0.33599490778786795, 0.3969724071877343, 1.5022602464471544, 3.0898975687367574, 6.959339593138013, 10.470108440944127, 15.870988368988037, 18.273599011557444, 18.722968544278825, 21.803318636757986, 18.050205741609844, 16.20277874810355, 18.217348132814678, 17.873021466391428, 23.212706872395106, 29.62545469829014, 24.66378777367728, 26.122185128075735, 22.891500336783274, 14.39139814036233, 18.55230689048767, 19.807380846568517, 22.204384292875016, 25.731972558157786, 26.155110904148646, 32.57445778165545, 28.022140502929688, 30.078974042619976, 30.32385287966047, 31.727517536708287, 33.13859592165266, 35.082371847970144, 29.60815715789795, 40.49955572400774, 49.095505714416504, 57.58154909951346, 65.72259357997349, 66.46518925258091, 67.18548120771135, 70.1247707094465, 59.55978461674282, 42.38544273376465, 34.476923193250386, 29.901537895202637, 35.26616907119751, 35.18689707347325, 39.64377737045288, 37.13384485244751, 40.02276686259678, 30.76812069756644, 29.532032694135392, 22.875476053782872, 25.262250014713832, 18.1289826801845, 14.331998859133039, 23.899706533976964, 17.229505368641444, 17.377682651792252, 27.050672905785696, 17.59951605115618, 29.865699086870464, 26.049539974757604, 27.759066070829117, 24.02458824430193, 18.079047713960918, 19.654155697141373, 19.39824312073844, 16.17558002471924, 9.068642888750349, 7.187515829290662, 3.6074601965291158, 2.8068464142935614, 0.40629849103944643, 0.22734512574970722, 0.1351513649736132, 1.8663039462906974, 7.173012333256858, 28.156923396246775, 48.60862112045288, 52.03394406182425, 41.214428084237234, 43.22468090057373, 40.36733150482178, 39.48517778941563, 43.4518209866115, 45.589823382241384, 61.62974330357143, 61.22312082563128, 68.7140918459211, 60.751775877816335, 41.69765445164272, 14.093540157590594, 0.8197950986879212, 0.2088979570461171, 0.11048599279352597, 0.14156122745147773, 0.1023192403039762, 0.1626031276370798, 0.10818343849054404, 0.1023307346871921, 0.31186012285096304, 0.3031486560191427, 0.24617250476564678, 0.27842221568737713, 0.16963393108120986, 0.1663493194750377, 0.21506524325481483, 0.18757085502147675, 0.28654411701219423, 0.2391348752592291, 0.16733272027756485, 0.18354009916739805, 0.16090934138212884, 0.1466729167316641, 0.1335632944745677, 0.23569920818720544, 0.18307309065546307, 0.1862795621688877, 0.136783363829766, 0.16269952032182897, 0.21985730182911667, 0.29123849368521143, 0.2015653005135911, 0.2131641102688653, 0.20022891222366265, 0.2504366359540394], [0.026083196546616297, 0.049212563915976455, 0.028979433367827108, 0.022495208540931344, 0.11726227775216103, 0.04915327691872205, 0.09508981608918735, 0.03414265738267984, 0.08701044533933912, 0.009141004943688, 0.06655335413025958, 0.025592765005837594, 0.09135890485984938, 0.03183874600966062, 0.035378055913107734, 0.03575031379503863, 0.0880795790414725, 0.10979460632162434, 0.023525647087288753, 0.04633264755830169, 0.07407775787370545, 0.12159439814942223, 0.10555322641240698, 0.05851717891969851, 0.12231626441436154, 0.03447657125070691, 0.04418627505323716, 0.02973385574296117, 0.16154668932514532, 0.0335276875245784, 0.15937482086675508, 2.1209169924259186, 14.50345434461321, 29.556212425231934, 41.9813563483102, 55.253624643598286, 52.251568589891704, 45.38032129832676, 38.43753187997, 28.981658935546875, 22.031751087733678, 23.84268961633955, 33.616899490356445, 43.10281644548689, 43.29346111842564, 32.32825183868408, 26.905424288340978, 8.990247232573372, 1.3894849036421095, 0.1785141360014677, 0.022021903224023323, 0.18058522843888827, 0.4601103078041758, 2.2626952018056596, 3.2550212911197116, 6.047114074230194, 6.091842668397086, 6.819302993161338, 6.489453332764762, 9.474490642547607, 9.914452314376831, 9.841876643044607, 7.779790265219552, 9.627521242414202, 9.53826902593885, 10.990370443889073, 15.409803424562726, 15.239345005580358, 14.11593680722373, 19.665915523256572, 23.596700804574148, 26.3213152885437, 30.786825248173304, 35.18932894298008, 40.2583281653268, 37.286437715802876, 41.882254191807334, 43.96277414049421, 42.06794132505144, 41.01741886138916, 44.503667082105366, 42.96004833493914, 43.421356609889436, 41.870105266571045, 34.11995949063982, 42.989140442439485, 50.54508406775338, 51.434509072984966, 51.29745932987758, 54.09007930755615, 51.892919949122835, 47.08885553904942, 45.100892543792725, 40.70239795957293, 40.46453332901001, 42.59510115214756, 41.62048428399222, 41.2146886416844, 42.077779974256245, 32.416389737810405, 34.60361664635794, 26.023512022835867, 23.132971082414898, 19.769462789808, 17.0941892010825, 12.389905265399388, 20.500779799052648, 19.024487359183176, 21.71111604145595, 17.979080506733485, 10.379318935530526, 17.418939317975724, 10.353158099310738, 16.973747389657156, 10.081266403198242, 6.793674562658582, 6.181325043950762, 6.663330699716296, 4.405803220612662, 7.034440500395639, 2.710967787674495, 1.294360590832574, 0.6959709801844188, 0.12845760344394616, 0.11735583416053227, 0.2101052472633975, 0.7584529274276325, 7.5479914120265414, 21.727934156145366, 38.464622906276155, 30.171683856419154, 43.84368896484375, 30.588044234684535, 22.380347422191075, 13.185257741383143, 26.30425919805254, 46.52650308609009, 42.904045854296, 48.332124505724224, 52.05739770616804, 37.51698589324951, 19.681891168866837, 1.4934759863785334, 0.2290002762206963, 0.019248387942622815, 0.0674785366281867, 0.13231750418032917, 0.04509531859574573, 0.02989401714876294, 0.00689459262814905, 0.05387931064303432, 0.12991671157734735, 0.13001299569649355, 0.15792036748358182, 0.1498903262295893, 0.04905529646202922, 0.043375137328569374, 0.06011815515479871, 0.05290182666586978, 0.07357872250889029, 0.016550975452576364, 0.05456357588991523, 0.08308078441768885, 0.07099132599042994, 0.04206554777920246, 0.07420907475586448, 0.09774692529546362, 0.04641369178092905, 0.006804790214768478, 0.013091656346140164, 0.015053262069289173, 0.01769747571753604, 0.037440500421715636, 0.06359889730811119, 0.06830469372549228, 0.054793578905186484, 0.020452304144522974, 0.04414265203688826, 0.02466033066489867, 0.024720401370099614, 0.03679686924442649, 0.1057891258969903, 0.08643955990139927, 0.025776381670896496, 0.10702196974307299, 0.0908994891547731, 0.03806685609742999, 0.04245186151404466, 0.06323560287377664, 0.06195563477064882, 0.04788460981632982, 0.018886306389634098, 0.034967650792428424, 0.03192674182355404, 0.042765894306025336, 0.058940700122288296, 0.07400711559291397, 0.08738116973212787, 0.038321228697896004, 0.05191795428150466, 0.08275091461837292, 0.0903580521366426, 0.02323735112856541, 0.023550927605746046, 0.11247499606439046, 0.043468605527388196, 0.3453031325978892, 3.117754199675151, 17.475620985031128, 38.43168497085571, 52.59010566983904, 62.90192372458321, 60.35500594547817, 52.091787815093994, 46.50806604112898, 34.81358078547886, 26.693255833217076, 25.81794261932373, 37.53545420510428, 41.40639986310686, 41.59776714869908, 34.34131520135062, 24.138015849249705, 11.853707568986074, 2.158268771001271, 0.21462361195257731, 0.07161169698727982, 0.6016521698662213, 1.9668856348310197, 5.613052725791931, 8.68301612990243, 7.580827730042594, 9.012093237468175, 12.518874253545489, 7.698425991194589, 11.934826050485883, 14.431743724005562, 15.719105958938599, 12.045545595032827, 10.792485748018537, 8.899480308805193, 8.064323340143476, 9.515746440206255, 10.636408363069807, 11.009215695517403, 15.630905526024954, 20.203212772096904, 27.18767922265189, 30.574133941105433, 34.20023202896118, 39.12413896833147, 38.32676369803292, 42.015722138541086, 43.51841252190726, 44.03470884050642, 44.1171909059797, 46.48690530232021, 45.50653532573155, 48.754324844905305, 49.11162206104824, 40.95312370572771, 50.77125835418701, 57.80193901062012, 57.72648504802159, 58.14644111905779, 62.42396409170968, 58.22899614061628, 50.7279953956604, 47.72182600838797, 44.266827310834614, 41.87961040224348, 42.69066320146833, 42.696034158979145, 43.037086486816406, 41.94065727506365, 37.468487467084614, 35.17277485983712, 29.080398048673356, 21.94979534830366, 18.758640595844813, 13.960286736488342, 12.105369584900991, 15.573308433805193, 14.726798977170672, 20.921362945011683, 11.995872054781232, 15.66926826749529, 21.33851020676749, 13.420591490609304, 15.819392783301216, 14.77067164012364, 10.977399025644575, 10.567591667175293, 10.063844663756234, 7.566852297101702, 5.4613357697214395, 4.362123804433005, 3.9438313926969255, 1.4765756875276566, 1.0374760265861238, 0.17111167178622314, 0.374014391962971, 1.2455090007611682, 8.423756258828298, 21.432795524597168, 35.83062335423061, 31.196828024727957, 44.34035662242344, 33.37748541150774, 31.765770844050817, 19.24804391179766, 30.340535504477366, 52.29732247761318, 50.883106981004985, 54.100921971457346, 59.91079371316092, 43.769714968545095, 22.910123246056692, 2.400370934179851, 0.16936183853873185, 0.07424182085586445, 0.07626064574079854, 0.07960792684129306, 0.07317512987979821, 0.022779185624260987, 0.03753307295430984, 0.1231334919908217, 0.08026618044823408, 0.05191063628132854, 0.07233530030186687, 0.042779926410210986, 0.08230094412075621, 0.09821187784629208, 0.0661644721403718, 0.037166392630232234, 0.021127741650811264, 0.06678415781685285, 0.08085522348327295, 0.052548465984208245, 0.05910643908594336, 0.0748363532392042, 0.028186970623210073, 0.06756502948701382, 0.010403314172955496, 0.047096359077841043, 0.036799593562526364, 0.021220817995656813, 0.02939600297915084, 0.019744095093171512, 0.05533901249457683, 0.03403843440381544, 0.06405030629996743, 0.10353250841477088, 0.15232290141284466, 0.1327792201191187, 0.09680019252534423, 0.22782250227672712, 0.19525610549109323, 0.28625951228397234, 0.11050463893583842, 0.2073259949684143, 0.3371535199029105, 0.23345825129321643, 0.1819480660238436, 0.18051649284149918, 0.21620358074350016, 0.2279013751872948, 0.1967188234307936, 0.1900679860264063, 0.20617264828511647, 0.12299265526235104, 0.1723112945577928, 0.4931988779987608, 0.29027440398931503, 0.21503515701208795, 0.23421546923262732, 0.2662762217223644, 0.2213786587651287, 0.08225830498018435, 0.1171533457402672, 0.28522371500730515, 0.17670016762401375, 0.7873512453266552, 5.094566856111799, 23.463390929358347, 47.49135078702654, 64.05125999450684, 73.32565293993268, 71.46349402836391, 60.364031655447825, 54.990082945142476, 43.360222884586875, 32.58450835091727, 35.88945722579956, 46.918961661202566, 55.973947865622385, 56.70843499047415, 43.189397948128835, 33.360073225838796, 12.627886278288704, 1.9611375204154422, 0.37784379933561596, 0.3111775709050042, 0.59712829547269, 2.109223391328539, 7.250065250056131, 11.662602577890668, 12.881910681724548, 15.477854081562587, 20.84882722582136, 17.125299760273524, 24.8016574042184, 20.478020974567958, 25.031863382884435, 21.296650784356252, 22.738026789256505, 23.067496470042638, 25.31171771458217, 24.86816382408142, 24.01726484298706, 21.06716047014509, 25.64968851634434, 28.403673035757883, 32.729135104588096, 40.37575966971261, 42.09900672095162, 42.86248867852347, 41.73428882871355, 46.87909984588623, 51.360976287296836, 48.90874855858939, 48.76006753104073, 50.55473858969552, 47.65097175325666, 50.3849697794233, 50.34628220966884, 46.46718978881836, 54.79292433602469, 62.83296285356794, 62.32773848942348, 61.49405888148716, 66.59223706381661, 62.91848128182547, 53.614224978855674, 48.56457648958479, 47.339668137686594, 44.56898014886038, 44.1469326700483, 47.65267406191145, 48.22726229258946, 45.86356503622872, 38.88873747416905, 39.90819454193115, 32.19453375680106, 27.35254955291748, 24.752087218420847, 25.2585084097726, 18.07887748309544, 31.92269590922764, 34.40574584688459, 36.55440330505371, 30.35412618092128, 24.96176474434989, 32.24442877088274, 21.312579529626028, 31.545346191951207, 22.64333847590855, 20.365420205252512, 14.660499266215734, 19.008605514253887, 11.53213017327445, 11.725788627352033, 8.283320137432643, 3.576834491321019, 1.7823535310370582, 0.6183908145342554, 0.19599745928176812, 0.3892096680189882, 1.3559988204921996, 8.75298970086234, 25.953995295933314, 47.893179007938926, 42.55890103748867, 57.85357107434954, 42.38339648927961, 33.55188519614083, 22.29437562397548, 38.08469888142177, 58.55816010066441, 57.55272102355957, 61.148934909275596, 69.46372604370117, 53.09695243835449, 28.255084071840557, 4.143858305045536, 0.49288311494248255, 0.11602545769086905, 0.24521509185433388, 0.29424890929034775, 0.12258082521813256, 0.1250648062144007, 0.09990105006311621, 0.23913973356996263, 0.21488365371312412, 0.2647150754928589, 0.24774182055677685, 0.20520872143762453, 0.17558283757950577, 0.24058341181703977, 0.13915962060647352, 0.17744461553437368, 0.2212726715952158, 0.19413494850908006, 0.15917887352406979, 0.19760646937148912, 0.1515030682619129, 0.2102971098252705, 0.17465917500002043, 0.208740767623697, 0.1482955925166607, 0.16170961915382318, 0.12454217140163694, 0.07764473504253797, 0.14680090200688156, 0.18080605087535723, 0.1562412782971348, 0.23178951655115398, 0.15174457244575024], [0.030473428379212106, 0.048845632533941946, 0.04664830544165202, 0.025524611252227, 0.032874125987291336, 0.05426933935710362, 0.028774369907166277, 0.08208356185683183, 0.10998897267771618, 0.10229220068348305, 0.02250965285514082, 0.02015055962173002, 0.021053318233628358, 0.023751675583688275, 0.03281793310972197, 0.15002648106643132, 0.0237673514389566, 0.08526817775730576, 0.011358326766639948, 0.044123371464333365, 0.02485779283701309, 0.03152182944385069, 0.06739962979086808, 0.20730432255991868, 0.043036107306501696, 0.03250732013423528, 0.04372350059981857, 0.02299647289328277, 0.04034080336402569, 0.07004349399358034, 0.2619768338544028, 4.718125181538718, 20.443161862237112, 27.90734757695879, 52.814393520355225, 48.789913518088206, 46.92204318727766, 39.179220812661306, 32.96169131142752, 27.881819895335607, 31.03937837055751, 31.13314778464181, 18.32126886504037, 26.625863518033707, 39.89052527291434, 28.6338894367218, 14.142965299742562, 2.8059572620051245, 0.3679300770163536, 0.20649941717939718, 0.3434783619429384, 0.1506258174777031, 2.804798432758876, 4.595179413046155, 4.622461949075971, 5.606305156435285, 8.719389949526105, 11.64448254449027, 5.032215893268585, 7.174002017293658, 8.277804136276245, 8.740965843200684, 9.983523488044739, 6.690664912973132, 5.251171435628619, 6.006672518593924, 19.16085270472935, 23.120764834540232, 24.020850113459996, 29.1133759362357, 39.055539403642925, 42.48333937781197, 45.95572246823992, 48.54041412898472, 51.36995335987636, 51.63881390435355, 53.04453175408499, 55.95731387819563, 58.04370852879116, 58.414436612810405, 56.645651068006245, 55.04551567350115, 52.17245987483433, 44.88452216557094, 35.42992421558925, 37.92236116954258, 48.03295591899327, 48.81368677956717, 49.93910387584141, 49.825125626155305, 45.81458371026175, 55.768562589372905, 56.28564405441284, 49.414084093911306, 52.34866966520037, 50.91052804674421, 52.72172539574759, 53.22528566632952, 49.61135734830584, 42.86137696674892, 37.13355302810669, 36.68675259181431, 35.32630920410156, 34.33591992514474, 21.696429286684307, 20.075794969286235, 25.552538803645543, 14.797392674854823, 26.330869061606272, 16.004972219467163, 13.169227378708975, 22.79575937134879, 10.723240000861031, 9.614009601729256, 9.485538278307233, 6.925934391362326, 8.569501672472272, 11.429588658469063, 5.9855382697922845, 2.397046221154077, 3.9264760954039435, 3.946251537118639, 2.1070570732866014, 1.825212299823761, 0.10769446580005543, 0.052772596278893094, 0.2537501667227064, 2.7170168459415436, 9.498139704976763, 25.19695952960423, 45.85208313805716, 36.25095462799072, 30.47895404270717, 23.404447623661586, 46.74790743419102, 65.07171412876674, 66.47827271052769, 48.69505671092442, 46.199322836739675, 48.81938777651106, 48.31551831109183, 28.41911367007664, 8.1503290108272, 0.30749209438051495, 0.05037368321791291, 0.024798215766038214, 0.06621022575667926, 0.03449215720008526, 0.06070492509752512, 0.05085666444418686, 0.0939255314213889, 0.1586186478712729, 0.04415926257414477, 0.0634266919057284, 0.016792925773188472, 0.10332139581441879, 0.08075127191841602, 0.028018378419801593, 0.06055724195071629, 0.08198137448302337, 0.08370474486478738, 0.06358260568231344, 0.04601376324093767, 0.013580639214654053, 0.08301671714122806, 0.043163013711039505, 0.0670202812179923, 0.04284817006971155, 0.06772578800363199, 0.05489555932581425, 0.04391140730253287, 0.0816322478598782, 0.04786431144124695, 0.08273954915681056, 0.04421065142378211, 0.026213756862229536, 0.005508197155514998, 0.03323246033063956, 0.03142545372247696, 0.10118749139032193, 0.019482406188866923, 0.018071250125233616, 0.055355293942349296, 0.08188559247979096, 0.00652221473033673, 0.05654936969014151, 0.05104763812518545, 0.06827519780823163, 0.02296832386803414, 0.024955830969182507, 0.02366038378594177, 0.05153562693989702, 0.05333418917975255, 0.08676694626254694, 0.004285394355455148, 0.04636827064678073, 0.0721347253503544, 0.0105746798882527, 0.05394005988325391, 0.07381569407880306, 0.05989695952406951, 0.03208072856068611, 0.019211709732189775, 0.04920445542250361, 0.07778486609458923, 0.08945641480386257, 0.3815838029342038, 5.130139895847865, 23.10104932103838, 35.351538113185335, 60.920019558497835, 61.201956612723215, 58.036965302058626, 50.46249083110264, 42.19152545928955, 34.29202468054635, 32.02576548712594, 32.43473993028913, 26.29585361480713, 28.824237074170792, 34.4125029700143, 30.95842490877424, 15.659620693751744, 3.4951833869729723, 0.46933512708970476, 0.144631421991757, 0.8183724007436207, 2.1238714967455183, 4.300205366952079, 7.515981929642813, 8.65705679144178, 8.478220582008362, 11.68905176435198, 12.498418756893702, 12.734026091439382, 14.47015597139086, 17.56536044393267, 16.356617076056345, 13.903241157531738, 10.105638078280858, 7.052904903888702, 7.1572668467249185, 11.441703711237226, 17.777869360787527, 21.921135766165598, 29.515436921800884, 35.415381635938374, 40.98102419716971, 42.79688378742763, 48.68457882744925, 53.258390358516145, 52.10308558600289, 53.61930063792637, 58.801562445504324, 58.35832296098982, 59.45913301195417, 58.341890471322195, 58.140670640128, 56.372743197849815, 53.31198181424822, 41.51460068566458, 44.434824330466135, 53.90517732075283, 56.164505686078755, 55.604845660073416, 57.4518574987139, 52.995484420231406, 57.9895646912711, 57.48647689819336, 52.113285541534424, 53.29948895318167, 53.232984270368306, 53.101524353027344, 53.594075202941895, 50.85008219310215, 45.61588260105678, 40.17982046944754, 39.956894465855186, 32.84668125425066, 31.4381320135934, 21.521699462618145, 18.25132656097412, 17.31209339414324, 17.971163034439087, 15.35491612979344, 15.088695900780813, 14.74284063066755, 17.72855625833784, 10.92599972656795, 11.367523006030492, 14.79420518875122, 15.360855102539062, 10.957240564482552, 11.517467737197876, 11.09140419960022, 7.201159051486424, 7.592405165944781, 6.697159741606031, 4.3739913276263644, 2.877283343247005, 0.5629763251968792, 0.056682372731821876, 0.37164823178734097, 2.9184188502175465, 10.573766878673009, 25.592101846422466, 39.35503108160836, 36.48606429781233, 35.33814893450056, 21.484599556241715, 32.16941949299404, 56.43135820116316, 67.41285405840192, 51.24991280691964, 49.896789346422466, 56.68310185841152, 55.97996153150286, 33.668177195957725, 9.361472981316702, 0.4659391407455717, 0.03248755440914205, 0.024184209427663257, 0.019823527795129588, 0.021168027971205965, 0.02442776957260711, 0.061508235920752795, 0.04794375432123031, 0.05274072548906718, 0.05043218989989587, 0.07474048981176955, 0.09152946820748703, 0.021180183926065053, 0.01233816780482552, 0.025321888737380505, 0.022156475377934318, 0.017575249508289353, 0.040412775573453734, 0.024865998021726097, 0.030005402064749172, 0.01663748188210385, 0.06643484120390244, 0.04508822111945067, 0.05109618391309466, 0.016306305902877023, 0.04982084681146911, 0.026219792431220412, 0.053865085156368356, 0.04785449982487729, 0.07642772141844034, 0.0704059334737914, 0.04084045619570783, 0.08068698751074926, 0.119989527123315, 0.2701991583619799, 0.16608709283173084, 0.14249198750725814, 0.10378784792763845, 0.13118249151323522, 0.15628599375486374, 0.32538894404258045, 0.17477610015443393, 0.26318370337997166, 0.14227359422615596, 0.1459329200110265, 0.07283569273671933, 0.0898114921791213, 0.1710042054099696, 0.24090370748724255, 0.14746490280543054, 0.27100829780101776, 0.09847290348261595, 0.11908167440976415, 0.21218779337193283, 0.16343512013554573, 0.1788404570626361, 0.36616010484950884, 0.23062398337892123, 0.06829674129507371, 0.08988268407327787, 0.20464651446257318, 0.15814057923853397, 0.3163014602448259, 1.0325545306716646, 8.135396463530403, 30.69424397604806, 48.904801981789724, 73.19186537606376, 70.81834684099469, 66.82514762878418, 57.253528118133545, 49.4422972542899, 42.96616622379848, 44.8970810345241, 45.38368075234549, 28.29771648134504, 38.62141942977905, 52.49061094011579, 36.679526465279714, 18.695554426738195, 4.00461379970823, 0.794062608054706, 0.4553156707968031, 0.9852466349090848, 2.0357509681156705, 5.7798455357551575, 10.323955689157758, 11.286095329693385, 17.618297031947545, 18.71831498827253, 21.214979921068462, 16.86269085747855, 18.909899405070714, 21.118608406611852, 17.04051262991769, 24.711367300578527, 14.743679625647408, 11.360840576035635, 13.131260684558324, 26.968361071177892, 28.349202632904053, 29.23874228341239, 34.45571034295218, 44.20176785332816, 47.479205335889546, 49.27331011635916, 55.39139005116054, 57.699095249176025, 55.2862742287772, 56.95063182285854, 60.4366820199149, 60.95753288269043, 59.417013032095774, 57.770199639456614, 57.202438013894216, 57.325070244925364, 53.788079329899375, 49.04569060461861, 48.30923366546631, 59.531123297555105, 59.671636717660085, 59.262547629220144, 62.221271242414204, 59.03507055555071, 64.87074443272182, 62.31837926592146, 53.8224173273359, 54.34843070166451, 55.619610582079204, 56.40453815460205, 57.76694440841675, 55.45855828693935, 49.158852440970286, 44.86758245740618, 41.703754970005576, 39.71000065122332, 38.074870654514854, 27.978775058473857, 24.53333534513201, 35.09661218098232, 27.679451874324254, 34.256786891392295, 27.018170969826834, 23.782804829733713, 36.76345028196062, 23.074201481682913, 20.39111638069153, 19.837619406836374, 18.813906567437307, 18.664977141789027, 19.375689268112183, 15.049812044416155, 9.654945782252721, 10.805291278021675, 10.545933263642446, 4.116127175944192, 3.1754136085510254, 0.41274712500827654, 0.29548099317720955, 0.4375159330666065, 3.8622030871255055, 11.979245015553065, 30.530269963400706, 55.01602404458182, 49.49703516278948, 40.980419703892295, 35.32586799349104, 58.69039126804897, 73.6949496950422, 76.99273845127651, 58.78579698290144, 58.994222096034456, 65.461501121521, 65.90269783564976, 39.000485352107454, 13.680547050067357, 1.1912992639201028, 0.08224243404609816, 0.16005810563053402, 0.19500005351645605, 0.10341794456222228, 0.08134290017187595, 0.13539385981857777, 0.16927223120416912, 0.24032372289470263, 0.14736257972461836, 0.17068272908883436, 0.1748476041746991, 0.17416410227971418, 0.190939957808171, 0.2771034693079335, 0.22039905775870594, 0.21570508820669992, 0.18506298959255219, 0.22624549189848558, 0.11938393461917128, 0.1301427451627595, 0.17765748554042407, 0.10008863106902156, 0.2590673028358391, 0.13817402135048593, 0.3572761815573488, 0.16415024176239967, 0.18041864809181007, 0.24854789301753044, 0.2451471569282668, 0.3032350742391178, 0.15775983966886997, 0.16080031437533243], [0.011700449212055122, 0.015058948192745447, 0.1191952068890844, 0.0323078545874783, 0.0324493766363178, 0.050890872787152014, 0.014464768647615398, 0.014876432450754302, 0.018012987715857368, 0.06642686163208314, 0.04077312855848244, 0.08454492049557821, 0.059830876998603344, 0.04413123907787459, 0.012236759049950965, 0.1039790998079947, 0.08701214167688574, 0.04439209847311888, 0.032946539244481494, 0.02278506343386003, 0.0016781814338173717, 0.02935146394052676, 0.039908739405551126, 0.02209760059070374, 0.03851951698639563, 0.015622971945309212, 0.05249031553311007, 0.03226986001910908, 0.03526552766561508, 0.04075620250244226, 1.491180258137839, 6.051500124590738, 25.217441082000732, 46.310115337371826, 57.21755729402815, 51.83749764306204, 45.272592953273225, 29.189246790749685, 26.550975833620342, 23.858567987169536, 42.74119397572109, 26.466584750584193, 35.86593062537057, 39.62322459902082, 36.97330672400338, 23.095626252038137, 5.451730319431849, 0.9589630109923226, 0.14934154067720684, 0.3302543929644993, 0.15317373004342827, 2.315543634550912, 3.5644061182226454, 6.560181217534201, 8.009627989360265, 5.404963731765747, 8.425346527780805, 7.049624485628946, 7.739063399178641, 9.907322594097682, 17.495951414108276, 22.369258097239904, 8.36938226222992, 10.081994227000646, 11.119156173297338, 10.655133758272443, 16.571705511638097, 29.451423168182373, 34.03748437336513, 43.6603399004255, 45.83343069893973, 52.87605530875069, 55.93089682715279, 57.37764726366316, 55.91477353232247, 56.5092579296657, 61.209175791059224, 62.39974267142159, 60.6955441066197, 61.774133818490164, 57.44957154137747, 55.537409918648855, 55.515234742845806, 49.110590253557476, 36.539443833487375, 32.7378203528268, 43.26609563827515, 47.58088527406965, 46.048133509499685, 46.208755016326904, 39.50854458127703, 58.56087684631348, 62.85901165008545, 58.427916118076865, 55.10924802507673, 56.062245573316304, 55.5004871913365, 55.21618774959019, 57.547013078417095, 55.151131766183035, 51.57901423318045, 46.87059872491019, 41.69653926576887, 39.36418880735125, 31.068453107561382, 35.12591968263899, 31.279223237718853, 32.79775203977312, 27.77796343394688, 10.145648411342076, 14.486751743725367, 13.834521736417498, 12.02686710017068, 12.104242239679609, 14.530212725911822, 11.96682163647243, 9.592044608933584, 4.905094691685267, 7.929786239351545, 3.7084329383713857, 4.199969785554068, 7.616115025111607, 3.66758838721684, 1.5569071769714355, 1.7097468099423816, 0.04613070875140173, 0.09995951264032296, 0.35935133163418087, 3.4595582357474735, 11.852845992360797, 32.632527351379395, 44.26378052575247, 38.003846168518066, 63.03215381077358, 67.95345864977155, 65.39750126429966, 48.98337568555559, 39.15849781036377, 37.32126556124006, 46.072737080710276, 50.19033684049334, 40.271672180720735, 12.463017685072762, 1.2735547529799598, 0.14268792127924307, 0.05047520902007818, 0.02142636660885598, 0.03010069891544325, 0.009980703055459474, 0.10753802276615586, 0.06038642075977155, 0.12276663524763924, 0.16925209228481564, 0.05847301307533469, 0.06332275391157184, 0.1061228294191616, 0.03242790439565267, 0.047626498487911055, 0.0335793952856745, 0.0204771164738174, 0.014793546005551304, 0.03648764726572803, 0.02699444872061057, 0.025237974311624254, 0.1330832445195743, 0.022071234416216612, 0.07253523064511162, 0.08933087904006243, 0.05827898598675217, 0.03738835161285741, 0.010035128349305263, 0.010633515659719706, 0.10133227040725094, 0.08170196054769413, 0.05722697850848947, 0.03358053522450583, 0.01420528328578387, 0.03923454701102205, 0.060587843880057335, 0.012362082771557783, 0.04608864636559572, 0.027576937107369304, 0.09554515379880156, 0.0646661107561418, 0.030445452380393232, 0.06055283825844526, 0.031155664806387255, 0.09804305833365236, 0.026707599737814496, 0.03730528196319938, 0.013920911803974636, 0.04263788528208222, 0.05620472139811941, 0.07757397062544312, 0.06538649781474046, 0.007408906057077859, 0.03962548156934125, 0.050591496351574144, 0.06935741366552454, 0.007808955885203821, 0.024932964339054058, 0.04098197824454733, 0.04485853701563818, 0.043850596994161606, 0.011286246839777699, 0.12151289252298218, 1.5105213288749968, 7.686423846653529, 31.385850293295725, 51.32185445513044, 66.0811414718628, 62.23104040963309, 54.46658829280308, 38.24204778671265, 34.03601482936314, 32.51660360608782, 50.44596454075405, 28.211194038391113, 22.45726571764265, 35.82497794287545, 39.079552377973286, 22.519505943570817, 6.6995316829000195, 1.0338952073029108, 0.14738638273307256, 0.5508015613470758, 1.3012104289872306, 4.1273702297891885, 8.111306190490723, 11.802426389285497, 10.785254410334996, 12.527140004294258, 14.21914621761867, 11.865499530519758, 15.180333954947335, 18.670419318335398, 19.605735438210623, 18.77823451587132, 9.066856333187648, 8.255123479025704, 12.779338768550328, 11.60769964967455, 17.637364625930786, 28.543588910784038, 34.60643761498587, 41.76295709609985, 45.50610801151821, 52.566252504076274, 55.95202282496861, 57.0378212928772, 56.360437938145225, 57.845344407217844, 61.46877438681466, 63.02371869768415, 62.531633377075195, 62.47046838487898, 59.19797107151577, 57.86280870437622, 58.235652514866416, 56.278476987566265, 45.621594020298545, 38.14547824859619, 51.04478461401803, 52.8081818308149, 54.1534538269043, 53.290709904261995, 46.41935838971819, 61.485950333731516, 65.6310510635376, 59.95348344530378, 57.62982170922415, 56.41265017645699, 57.16242333820888, 58.640711648123606, 60.193640981401714, 55.501960209437776, 53.58332633972168, 49.17686217171805, 43.36388111114502, 39.03518812997, 33.13293661390032, 28.023547513144358, 26.46553557259696, 23.25283793040684, 17.806798185620988, 15.267450468880789, 17.86965332712446, 12.641960723059517, 17.19212406022208, 16.52518732207162, 17.620534351893834, 21.894470317023142, 12.62907268319811, 11.882408840315682, 12.408165999821254, 7.774820566177368, 7.351105519703456, 4.838093212672642, 6.799122818878718, 4.945909712995801, 1.7690855115652084, 0.1940819142120225, 0.16467479004391603, 0.5961393713951111, 3.442220526082175, 12.942614487239293, 30.66430766241891, 40.29595266069685, 31.413656984056743, 46.53175939832415, 64.84963580540249, 74.78246784210205, 60.0317896434239, 46.43347365515572, 45.52583394731794, 54.1638240133013, 58.16420766285488, 46.194295815059114, 17.144728660583496, 1.7789199267114912, 0.057781877661389966, 0.05801888994340386, 0.01457739358634821, 0.046660749773894034, 0.034372901277882714, 0.018249930448031852, 0.03922243516093918, 0.10087274613657168, 0.12302937757756029, 0.04512943194380828, 0.08431567743952785, 0.06748902677957501, 0.0363684795530779, 0.03486290194892457, 0.03905749008325594, 0.02260981989093125, 0.062030293978750706, 0.03615087676527245, 0.006294463603158614, 0.02627141707177673, 0.006645957041265709, 0.057441042736172676, 0.045459837785788944, 0.04399321148438113, 0.03179112642205187, 0.018573457641260963, 0.03745885818664517, 0.025213209479781132, 0.020330415506448065, 0.012580571895731347, 0.03721585104774151, 0.03554518587355103, 0.10491573597703661, 0.18424770262624535, 0.2752626309437411, 0.10465760768524238, 0.15679121735904897, 0.12280744234366076, 0.1571023120943989, 0.15401809902063437, 0.15191830455192498, 0.1672478626881327, 0.18206040428153106, 0.2300578680421625, 0.12234245586608138, 0.11755585271332945, 0.144662132486701, 0.24529336765408516, 0.23429944472653524, 0.19550409646970884, 0.12981930109007017, 0.052232305984944105, 0.1407430770673922, 0.16344438892390045, 0.14375062925474985, 0.14103342220187187, 0.11587341156389032, 0.0733602817303368, 0.10658602456429175, 0.1740040494395154, 0.1390289076204811, 0.15222490738545144, 2.8165261234555925, 11.236070036888123, 39.58994620186942, 63.84237630026681, 75.58174691881452, 72.10898862566266, 63.513413837977815, 44.43560600280762, 39.87605912344796, 35.902874197278706, 57.09059286117554, 39.68248578480312, 49.337806769779746, 53.4971513066973, 49.4874918120248, 28.99454436983381, 6.889507591724396, 1.0800539361579078, 0.3936464456575257, 0.4136747909443719, 1.8062250443867274, 4.129957565239497, 10.059592366218567, 19.02682716505868, 15.515994480678014, 16.131872381482804, 20.58011085646493, 19.038164888109478, 16.589640549251012, 21.101564475468226, 28.00107182775225, 38.41031231198992, 21.298735243933542, 21.430968148367747, 20.738583632877894, 16.433707339423044, 20.067748955317906, 32.29704053061349, 38.32238285882132, 48.601909160614014, 49.92390121732439, 57.475109645298545, 60.32914475032261, 62.12463569641113, 59.509702001299175, 59.82687337057931, 62.78821645464216, 65.84846714564732, 63.26385538918631, 64.1514321735927, 58.77739661080496, 56.274474825177876, 58.02751227787563, 54.9563181740897, 51.55383048738752, 44.32911096300398, 53.95580884388515, 58.1413585117885, 57.203629629952566, 56.20154653276716, 50.67822197505406, 65.28313391549247, 65.23405184064592, 60.18289906638009, 57.30057784489223, 58.604240553719656, 57.85211542674473, 58.20298555919102, 61.226316996983115, 59.59125995635986, 58.538983072553364, 51.597437381744385, 43.69778026853289, 43.3094037600926, 36.15089014598301, 42.97818660736084, 46.54187250137329, 45.52297823769705, 35.70317254747663, 19.994457619530813, 30.300861290522985, 23.414149045944214, 19.61762033190046, 21.206101860318864, 25.42822163445609, 21.368896416255406, 19.658241237912858, 16.397052117756434, 22.16648186956133, 13.35512730053493, 12.848474213055201, 14.519105161939349, 9.107798593384878, 5.953122317790985, 2.1038585134914944, 0.30477380167160717, 0.3915819078683853, 0.6077738042388643, 3.849862652165549, 14.939269678933279, 38.477008070264546, 55.23459700175694, 49.074866090502056, 76.27888747623989, 76.72390569959367, 70.3894762311663, 58.18474653788975, 50.85483823503767, 49.95220470428467, 61.269381931849885, 66.3676643371582, 55.162245409829275, 21.89787667138236, 2.9072661229542325, 0.34224071406892365, 0.1394871494599751, 0.1536901087633201, 0.12048777538750853, 0.19245518078761442, 0.24664015110049928, 0.21384533228618757, 0.13714559296412127, 0.20664129885179655, 0.141629678064159, 0.2330493660909789, 0.15106877870857716, 0.25694565953952925, 0.11626200856907026, 0.22309536593300955, 0.20408320826079163, 0.14166690249528202, 0.18419157420950277, 0.12912795533026966, 0.09069491763200078, 0.19789511816842215, 0.18955784982868604, 0.13555864883320673, 0.24270405088152203, 0.10085386250700269, 0.13969848597688334, 0.11364623571613006, 0.08500630395220858, 0.18211444281041622, 0.16749217600694724, 0.2350652664899826, 0.1703728421458176], [0.08073038661054202, 0.058017702507121224, 0.10849014310432331, 0.0306944747322372, 0.033143738484276195, 0.057828004471957684, 0.02285196868303631, 0.026273388216005902, 0.003756918628433985, 0.02887715439179114, 0.044089824693011384, 0.03128826751240662, 0.03467032013993178, 0.042219965386071374, 0.07928482203611306, 0.1048068989600454, 0.0412275909579226, 0.017160539082916718, 0.04403413732403091, 0.02092947711103729, 0.06289305125496217, 0.030440566928258965, 0.015562889365745443, 0.06019171513617039, 0.07494658803833382, 0.027364687960860983, 0.03157002917890038, 0.04639365464182837, 0.10040872996406895, 0.12736660055816174, 3.1265115354742323, 9.706530945641653, 30.494146278926305, 53.85747446332659, 55.131871359688894, 51.132755756378174, 42.34691844667707, 34.62963765008109, 26.906386613845825, 22.259601627077373, 24.120376110076904, 23.155495405197144, 36.81451606750488, 42.059162276131765, 22.884666783469065, 12.327690226691109, 2.0758138469287326, 0.20702505111694336, 0.08606069308838674, 0.7246068407382283, 0.8443642546023641, 4.822828020368304, 5.2024476272719244, 6.495398385184152, 11.768084049224854, 7.139061263629368, 9.352893693106514, 9.207764932087489, 16.841134071350098, 20.00466799736023, 19.14462171282087, 18.502804449626378, 12.140670776367188, 10.507675613675799, 15.963406358446393, 20.9556679385049, 32.11173554829189, 36.96771689823696, 43.59614201954433, 52.09969139099121, 57.99137469700405, 61.720806394304546, 63.15589427947998, 62.93619918823242, 61.05619035448347, 60.27482373373849, 60.01036834716797, 60.06876795632498, 63.065352303641184, 61.548282623291016, 59.455867358616416, 58.63363143375942, 57.3963622365679, 52.783943040030344, 45.233835901532856, 29.883945056370326, 39.175343717847554, 46.18796600614275, 40.335637296949116, 39.67037507465908, 37.77719940458025, 55.681783063071116, 57.452455043792725, 56.242599964141846, 58.275715827941895, 57.191126346588135, 59.18454715183803, 57.44009419849941, 59.018242018563406, 61.21852806636265, 58.525982992989675, 59.98465306418282, 54.23264939444405, 51.7463754926409, 45.66190052032471, 36.58593075616019, 30.14656959261213, 39.25660637446812, 23.282496316092356, 24.840284177235194, 22.003032445907593, 19.207763467516216, 12.091020686285836, 13.56591306413923, 14.795341219220843, 22.58115209851946, 9.488156880651202, 12.46520984172821, 11.063091158866882, 8.029439909117562, 8.306090252740042, 3.9271730865750993, 5.722604538713183, 6.759279242583683, 1.9479259550571442, 0.1549272680921214, 0.20526033081114292, 0.14534282524670872, 1.3196621303047453, 5.302720555237361, 13.961982096944537, 29.14383683885847, 58.78858321053641, 49.52566174098423, 51.031114033290315, 25.749304839542933, 23.35149540219988, 23.103984934943064, 41.385812350681846, 48.10449457168579, 52.9874210357666, 48.00658055714199, 19.740605184010096, 4.808806989874158, 0.3671675665037972, 0.04792180032070194, 0.08894930487232548, 0.06682172830083541, 0.03945628886244126, 0.05657866543957165, 0.011060704344085284, 0.0876112338155508, 0.02405977119425578, 0.058295901864767075, 0.035979448285486014, 0.045042939084981165, 0.03141585923731327, 0.04694298641490085, 0.01653849719358342, 0.056069960950740745, 0.0209034400260342, 0.028672630366470133, 0.006629491540869432, 0.03387968774352755, 0.028026339331907884, 0.0954429189275418, 0.06454955879598856, 0.051722743149314604, 0.013330126630275376, 0.03423870062189443, 0.045952881686389446, 0.03390048484184912, 0.0846293709639992, 0.0664322559854814, 0.04556088522076607, 0.07050689269921609, 0.024411308313054696, 0.016547355468251874, 0.07929018924811057, 0.04290657836411681, 0.02725974403853927, 0.03591576777398586, 0.016832737119070122, 0.02311846670428557, 0.022313225448929837, 0.05793777786727462, 0.04101370993469443, 0.030213973551456417, 0.06754830359880414, 0.046504062467387745, 0.05931531930608409, 0.0554561988849725, 0.06988946654434715, 0.04582314579082387, 0.014720510192481535, 0.03054748708382249, 0.08975537054772888, 0.04841160760926349, 0.07095550612679549, 0.026213395542332103, 0.02748185908421874, 0.025126960893560733, 0.037501561788043807, 0.03722705705357449, 0.04161025078168937, 0.009738728137952941, 3.3596898232187544, 11.170372213636126, 35.04694298335484, 62.451284408569336, 65.1548215321132, 61.34092058454241, 49.70963266917637, 38.75469977515084, 31.43170840399606, 24.743087564195903, 28.386575256075176, 30.604452405657085, 41.74178940909249, 41.29129600524902, 25.33296356882368, 13.517081992966787, 2.7064903250762393, 0.17311742130134786, 0.2098358960023948, 1.7360381420169557, 4.65386780670711, 7.852086271558489, 7.4006852592740735, 10.364046795027596, 10.838496719087873, 10.208009362220764, 11.059658748762947, 9.32530587060111, 14.802417959485735, 22.279377937316895, 24.1167665209089, 16.405497653143748, 8.63013425895146, 9.439522964613777, 13.857524616377694, 24.019319772720337, 28.40750323023115, 37.57161610467093, 44.32153047834124, 53.42845794132778, 56.351617200034006, 63.1507317679269, 62.11526952471052, 65.25026893615723, 62.37119252341134, 62.16541467394148, 62.74240698133196, 62.84444127764021, 64.04743153708321, 62.592207772391184, 60.12511089869908, 58.97457259041922, 60.63767256055559, 58.082250186375205, 50.60735034942627, 36.487426144736155, 46.04329408918108, 53.84713206972395, 46.925597190856934, 49.15305764334542, 45.08268478938511, 58.95464515686035, 60.61651529584612, 56.117351736341206, 59.655558586120605, 58.02591071810041, 59.48719678606306, 59.29451629093715, 62.00807966504778, 59.9985842023577, 61.445352009364534, 60.243181637355256, 53.27474641799927, 50.041565486363, 43.47564288548061, 37.21621574674334, 32.18030037198748, 29.81293794087001, 23.876461335590907, 18.48798394203186, 15.49269369670323, 11.971972857202802, 15.560728720256261, 16.212398529052734, 16.93891085897173, 19.16572686604091, 12.26521897315979, 12.384022746767316, 13.960157326289586, 13.683727587972369, 7.0808093036924085, 9.762604645320348, 8.074125511305672, 8.33145899432046, 5.772350166525159, 1.1624690166541507, 0.6621071430189269, 0.22576321634863103, 1.2471098005771637, 5.8381465673446655, 15.628591775894165, 30.525757108415874, 46.257069315229145, 50.1052040372576, 56.8233060836792, 35.986732006073, 29.91908209664481, 28.407131501606532, 42.44813980375017, 52.789268834250315, 59.193545069013325, 54.87771667752947, 23.463920729500906, 5.728844455310276, 0.3451018248285566, 0.06444634683430195, 0.0595355514170868, 0.10539919896317379, 0.007976406453443425, 0.10106597933918238, 0.019043041193591695, 0.006824113195762038, 0.03374981614095824, 0.16108543479016849, 0.04628979807187404, 0.1307397609842675, 0.02149669167452625, 0.08190875766532761, 0.04568763556224959, 0.04302095901221037, 0.034755025058984756, 0.0377015735554908, 0.05099650372618011, 0.025374904374725053, 0.06715556753001042, 0.008318006426894238, 0.032829261251858304, 0.036682614125311375, 0.018860808739970838, 0.0547728360896664, 0.049198385926761797, 0.008022496792753893, 0.039216148533991406, 0.0506396146624216, 0.07258782389440707, 0.050467524610991986, 0.20961890050343104, 0.1661971104996545, 0.16166679002344608, 0.11147165990301541, 0.12254210800996848, 0.1820464264601469, 0.06831831192331654, 0.11652285100093909, 0.08443134051880666, 0.1640300867812974, 0.16819568111428193, 0.13618135399052075, 0.17404216953686305, 0.1476391777396202, 0.13597054673092707, 0.21334195429725306, 0.15043050795793533, 0.18860783294907638, 0.14660922943481378, 0.0829811008380992, 0.23739367297717504, 0.0973951116736446, 0.20280186273157597, 0.15297848837716238, 0.13932591596884386, 0.1411451090659414, 0.08606900514236518, 0.12573458813130856, 0.2624266482889652, 0.39682559935109957, 5.040154644421168, 15.843812227249146, 45.617633547101704, 71.59496784210205, 73.26250771113804, 70.45191274370465, 58.1819429397583, 49.952527795519146, 37.94245883396694, 33.11968987328665, 36.117389406476704, 34.150687898908345, 49.931175981249126, 55.13729790278843, 30.287996700831822, 15.626522949763707, 2.703627450125558, 0.48286462681634085, 0.2004382809890168, 2.0600108206272125, 4.5592611346926, 12.589260373796735, 12.24251399721418, 20.563089506966726, 22.172889845711843, 18.35731438228062, 23.233480249132427, 20.865838153021677, 27.21970694405692, 27.585526125771658, 31.9146568434579, 28.093319586345128, 21.462884698595317, 18.37751453263419, 22.428571394511632, 27.26031916482108, 35.498492513384136, 41.11987352371216, 49.37918676648821, 57.018001556396484, 60.98931394304548, 65.24910163879395, 67.34027317592076, 70.16256890978131, 66.48642294747489, 65.2549798148019, 65.75551414489746, 63.54675824301583, 66.92179012298584, 63.29531683240618, 59.232844080243794, 58.47505964551653, 59.955421992710654, 58.496904781886506, 55.46064969471523, 43.58333648954119, 49.29162904194423, 58.077810287475586, 49.39965615953718, 51.54260219846453, 49.9585588318961, 62.02247633252825, 60.83101313454764, 56.67795671735491, 59.80473640986851, 60.816039766584126, 59.28728321620396, 61.55456379481724, 61.87437547956194, 61.50177138192313, 61.68289702279227, 63.67488997323172, 55.61879416874477, 55.66684791019985, 48.275486264910015, 40.63246781485421, 35.5901323046003, 42.58630820683071, 28.1059444631849, 33.16248035430908, 34.105281421116416, 29.349388871874126, 20.648618357522146, 24.98357687677656, 27.823477608816965, 33.817507880074636, 22.027573483330862, 22.54185482433864, 19.419202361788066, 15.767944846834455, 16.153886011668614, 14.926514523369924, 14.482789533478872, 8.384890641484942, 6.6054543767656595, 1.159253629190581, 0.5081090064985412, 0.3250287505132811, 1.7094942863498415, 6.802484009947095, 17.49507072993687, 36.22534009388515, 68.70462145124162, 58.24106863566807, 55.85458476202828, 33.608759675707134, 33.68279273169381, 35.12816047668457, 52.68326711654663, 61.29499299185616, 67.411867414202, 63.43915149143764, 32.046773365565706, 8.990361877850123, 0.7908959665468761, 0.17660059939537728, 0.20107637532055378, 0.2459602047290121, 0.1436254938266107, 0.18612590112856456, 0.11764963982360703, 0.16344619382705006, 0.16014970785805158, 0.34509788932544844, 0.35714731418660706, 0.22654039678829058, 0.18774848191865853, 0.15017194540372916, 0.12829012743064336, 0.1285737957805395, 0.1357518956065178, 0.29819643603903906, 0.14544387268168585, 0.0794853630608746, 0.14720533601939678, 0.18910988100937434, 0.14030718617141247, 0.17719347615327152, 0.11155824775674514, 0.1332112569361925, 0.15964387357234955, 0.0940885833863701, 0.16572151173438343, 0.18694798701575824, 0.15400239772030286, 0.08428466160382543], [0.03071311069652438, 0.04085735850302236, 0.07158213321651731, 0.03472910841394748, 0.02431286475621164, 0.005413705641071179, 0.021823028002732565, 0.05276336820263948, 0.0337603809311986, 0.06228975898453167, 0.14133379608392715, 0.04745179946933474, 0.02553518282781754, 0.021029092837125063, 0.018568405948047127, 0.014855957656566585, 0.01827586575278214, 0.01399157359264791, 0.03058406351400273, 0.01911114914608853, 0.005118087441327849, 0.02546592815113919, 0.04081288731790014, 0.0344348074203091, 0.03290490433573723, 0.01439762591118259, 0.02646123554690608, 0.011909506699469472, 0.016205704604674662, 0.7553882833038057, 4.025759339332581, 14.46851532799857, 44.301248686654226, 58.24878461020333, 52.82308224269322, 47.40156963893345, 44.666122913360596, 33.43282086508614, 30.234530312674387, 23.85883375576564, 29.516614641462052, 29.44015666416713, 37.63472659247262, 30.79155002321516, 16.301059280123027, 4.623266203062875, 0.50939301188503, 0.18706113951546804, 0.2804446028811591, 1.602206283382007, 4.379952013492584, 5.9864484838077, 8.949844326291766, 8.360554575920105, 7.253812500408717, 13.917460645948138, 12.433400988578796, 7.360651476042611, 17.706228222165787, 24.158158676964895, 21.793176003864833, 18.097595930099487, 8.480155655315944, 15.285552263259888, 31.832522187914165, 39.4947315624782, 36.102030413491384, 52.476179531642366, 51.36416898454939, 60.65419537680489, 61.00995009286063, 63.86307498386928, 59.541378838675364, 60.20562662397112, 56.65901592799595, 60.60497433798653, 58.23237991333008, 62.22315420423235, 60.492899894714355, 61.793533188956125, 58.836171422685894, 58.37003762381417, 60.0855895451137, 57.48457309177944, 49.00072533743722, 32.301292828151155, 33.36976943697248, 42.669783864702495, 39.472483430589946, 54.904303959437776, 39.16893400464739, 59.62613991328648, 56.34151104518345, 57.68623760768345, 56.8675730569022, 56.01730809892927, 56.511936460222515, 57.75559452601841, 59.40091405596052, 57.61797155652727, 60.73521137237549, 60.01297392163958, 61.12614481789725, 58.73381750924246, 54.07585981913975, 47.876305307660786, 44.89160932813372, 40.18168258666992, 42.44653476987566, 37.08340440477644, 29.687140805380686, 13.00342685835702, 27.988976751055034, 19.222375529153005, 16.29680871963501, 27.10227370262146, 9.010747023991176, 9.16477382183075, 11.999196767807007, 11.863548823765345, 4.200807477746691, 4.769758548055377, 6.141331647123609, 9.136714390345983, 2.896233252116612, 1.1434186846017838, 0.6418497785925865, 0.04972511909103819, 0.1348396459860461, 2.024725045476641, 5.8661408594676425, 20.14009186199733, 29.43236425944737, 29.78162588391985, 26.793987342289515, 28.698962790625437, 23.08412524632045, 31.92498881476266, 42.11302471160889, 43.69975355693272, 48.05784089224679, 47.95693915230887, 38.259300163814, 12.43459781578609, 1.2859646699258258, 0.05989235905664308, 0.04389234386118395, 0.055502597109547684, 0.010780953685753047, 0.03658247592725924, 0.030995265913328955, 0.06560548142130886, 0.0405289611246969, 0.08856666540460927, 0.12985055441302912, 0.03845727496913501, 0.055483360641769, 0.03393316987369742, 0.015004639946190374, 0.04932449844532779, 0.04982975258358887, 0.004089838866743126, 0.12049222657723085, 0.025501934611903768, 0.028548472028757845, 0.04464285787461059, 0.034389552527240345, 0.047622003193412504, 0.0800420128341232, 0.03246737138501235, 0.06601853961391108, 0.016254204591470103, 0.04815001878887415, 0.03271493488656623, 0.049396925273218324, 0.015607212969501103, 0.007839513709768653, 0.037589075842073986, 0.0515984966020499, 0.023438624971147095, 0.03002222634053656, 0.04393005005217024, 0.06627209457967963, 0.03855197470901268, 0.016767268667795827, 0.11722510760383946, 0.06537479987101895, 0.026176289854837314, 0.022123730974271894, 0.021253794797563126, 0.018553115161401883, 0.02443063468672335, 0.0960234667041472, 0.013864362695520478, 0.024616921387080635, 0.034016694141817946, 0.049957405376647196, 0.0038022600347176194, 0.03340492018365434, 0.024928401191053644, 0.055553069936909845, 0.01086426675984902, 0.045255873551858325, 0.02046761359088123, 0.04794288918908153, 0.8728359639644623, 4.852637095110757, 17.43844985961914, 48.949023791721885, 66.53319127219063, 59.86233697618757, 57.058165618351524, 48.06297213690621, 40.66588865007673, 32.85708965573992, 27.45549406324114, 33.439539773123606, 30.89159713472639, 37.684975964682444, 35.40351063864571, 16.937161649976456, 5.164215164525168, 0.7024844821010316, 0.4341420941054821, 1.3515033360038484, 3.6277491535459245, 5.609311989375523, 7.640729018620082, 9.19462502002716, 9.570675424167089, 11.502296345574514, 12.71522947720119, 10.164300850459508, 13.379777772086006, 15.949337993349348, 15.19258884021214, 13.936358877590724, 7.542564868927002, 5.103825764996665, 11.807952812739781, 22.886033841541835, 32.397146701812744, 40.051872866494314, 48.546573707035606, 52.56763519559588, 59.13311658586775, 63.06990337371826, 65.17986978803361, 63.56718594687325, 63.28450543539864, 61.4365416935512, 63.04979528699602, 60.919727734157014, 62.986108098711284, 62.425430161612375, 64.07193088531494, 61.37341036115374, 58.41588183811733, 60.698205266680034, 61.54434994288853, 54.587049211774556, 39.48244367327009, 40.24844782693045, 48.270469665527344, 48.22371523720877, 57.69409602028983, 46.89060606275286, 61.721542903355186, 57.54391418184553, 58.08377879006522, 57.31627035140991, 57.21495171955654, 57.15621859686715, 59.977753502982004, 61.42243685041155, 60.525639806474956, 61.07588849748884, 62.98150144304548, 62.430599621364046, 59.31807763235909, 53.65646307809012, 46.049814973558696, 43.113009452819824, 36.815384592328755, 32.685118266514365, 27.084953580583843, 20.177035433905466, 16.37352725437709, 16.76992198399135, 14.729241268975393, 15.894303049360003, 13.883119174412318, 16.691068615232194, 15.357219457626343, 9.845236097063337, 10.89343091419765, 12.411728688648768, 11.489064369882856, 7.947194950921195, 10.575084430830819, 6.653243218149457, 3.119200727769307, 1.203253748161452, 0.21506166058991635, 0.3574199766985008, 2.1515854724815915, 6.4646182996886115, 19.5611366885049, 34.72791644505092, 42.04957723617554, 40.90408679417202, 31.487287044525146, 26.331496136529104, 33.99436385290963, 47.4464966910226, 48.65819304330008, 54.97924722943987, 54.56623935699463, 43.59686115809849, 14.435251695769173, 1.7576088245425905, 0.14059464074671268, 0.032052596498812945, 0.08481842439089503, 0.048217393923550844, 0.0388749200584633, 0.015249453684581178, 0.03518124343827367, 0.039425201780561886, 0.08271112532487937, 0.11421315850956099, 0.03537855463634644, 0.04293997585773468, 0.04492242448031902, 0.04748666938394308, 0.01978657308167645, 0.06291093065270356, 0.04164398754281657, 0.04849519633821078, 0.07929585501551628, 0.028385699959471822, 0.026761068297283988, 0.04915341941107597, 0.04767568888408797, 0.030523558546389853, 0.07363200107855455, 0.03731870338586824, 0.04388369593237128, 0.046923258009233644, 0.07009591760912112, 0.008728015452756413, 0.01640556370174246, 0.11615399936480181, 0.18601183939192975, 0.125887787767819, 0.16864503414503165, 0.18850390852562018, 0.13566806939031395, 0.10293982164668185, 0.17848022282123566, 0.16655167218829903, 0.24520456099084445, 0.288165490009955, 0.12691202280776842, 0.09249781910330057, 0.15122702664562634, 0.11743951109903199, 0.10731291198836905, 0.2055288271180221, 0.10680832620710135, 0.09610568479235683, 0.08820633616830621, 0.1415959820151329, 0.07765797326075179, 0.08888855563210589, 0.10801591497978993, 0.1535085327923298, 0.11523952414946896, 0.18867432938090392, 0.10981307604483195, 0.20075333836887563, 1.423975435750825, 7.070767419678824, 23.17952401297433, 59.10173852103097, 74.33983285086495, 68.74716527121407, 64.02239022936139, 59.357473918369834, 46.19761010578701, 44.16349022729056, 35.76540061405727, 42.80711848395211, 41.37347929818289, 50.28210169928414, 40.02476446969168, 21.3328526360648, 5.867283403873444, 1.0237624538796288, 0.7230648291962487, 1.5544539200408118, 3.4202748579638342, 7.298084684780665, 12.52603610924312, 19.197148357118877, 18.384980372020177, 18.798443351473125, 26.102335861751012, 24.90346588407244, 11.467699527740479, 26.64160292489188, 34.445784841264995, 32.63899612426758, 27.827302592141287, 15.502949237823486, 20.967240163258143, 38.360493728092735, 41.48170791353498, 41.06852286202567, 55.0457067489624, 54.96351303373064, 64.93082550593785, 68.0931591306414, 70.82056331634521, 68.00009495871407, 67.60172694069999, 65.38320187159947, 67.179762840271, 62.33114310673305, 66.54069532666887, 65.32554571969169, 66.48101724897111, 60.51926136016846, 57.22260168620518, 60.02919796534947, 63.617449215480256, 56.984806537628174, 45.44511672428676, 43.24786009107317, 53.091949735369, 52.15812226704189, 60.06361239297049, 50.676908765520366, 64.3720930644444, 57.410411494118826, 59.48949663979666, 59.5048382622855, 55.65539380482265, 58.3698639188494, 59.454804284232004, 63.08354268755232, 59.39733573368618, 62.56779875074114, 62.993612153189524, 64.06209918430874, 60.11599486214774, 57.99398027147566, 50.41019868850708, 50.97431945800781, 42.75119243349348, 48.6298965045384, 43.86306401661464, 36.36999116625105, 20.542458568300518, 41.902664525168284, 31.30515738895961, 23.890849317823136, 36.88756595339094, 19.839900153023855, 22.98621644292559, 20.605801820755005, 20.1537207535335, 14.829024348940168, 12.917485458510262, 15.45822194644383, 17.07220162664141, 8.866999217442103, 4.571503860609872, 1.266980345760073, 0.36509266069957186, 0.4840949465121542, 2.813068743262972, 7.235807980809893, 26.471146242959158, 38.868924685886924, 40.92658158711025, 37.29603665215628, 41.901368686131065, 33.780265535627095, 43.455767563411165, 53.83159589767456, 58.112051010131836, 62.66537925175258, 62.52569266727993, 51.793175084250315, 19.763911179133824, 2.817031822034291, 0.20913899982614176, 0.14856973423489503, 0.13450476181294235, 0.15735497139394283, 0.11341910968933787, 0.15619236949299062, 0.21422206849924155, 0.15699720702001027, 0.24279212472694262, 0.3406466996031148, 0.09635679703205824, 0.20053048032735074, 0.14386644161173276, 0.10871507067765508, 0.168338716296213, 0.18786413142723696, 0.11539826063173157, 0.2059781937194722, 0.17340193103466714, 0.14688432110207422, 0.19068751563983305, 0.17214403567569597, 0.1402605301035302, 0.1302282405751092, 0.11522895257387843, 0.2612170103405203, 0.15478191232042654, 0.13753960467875004, 0.20843263130102838, 0.3596601193504674, 0.11087761606488909], [0.06585543336612837, 0.09282576186316353, 0.05957327117877347, 0.07060440496674605, 0.04221851671380656, 0.028465246316045523, 0.06850400660187006, 0.019221131190923706, 0.022954072936304977, 0.029923479139272655, 0.03409132281584399, 0.003680817109333085, 0.009171818915222372, 0.04876780456730297, 0.042016428629202504, 0.014420831808820367, 0.042671923991292715, 0.02527357025870255, 0.10330736371023314, 0.03311646816187671, 0.04585992578150971, 0.028388705869604434, 0.020636789334405745, 0.04703164719311254, 0.05264365426929934, 0.1189093536564282, 0.03581170425085085, 0.013401189602778425, 0.09388053776430232, 0.8111771611230714, 6.117701257978167, 18.910710607256206, 45.62184762954712, 55.65388951982771, 59.569289752415244, 44.64476762499128, 37.16198853084019, 32.06861850193569, 26.754806450435094, 20.30115631648472, 18.407355308532715, 38.02293981824602, 35.866420473371235, 25.17318105697632, 7.923957569258554, 1.579955871616091, 0.25225975098354475, 0.22079746638025555, 1.3244820088148117, 2.6667800673416684, 8.680962068693978, 6.031955710479191, 3.7494551028524126, 8.223497016089302, 7.028283527919224, 5.360728893961225, 4.189740300178528, 19.917996168136597, 11.096398217337471, 18.892777306692942, 21.01466335569109, 11.280072110039846, 14.801479952675955, 21.47676372528076, 28.683904307229177, 44.53855051313128, 50.63086652755737, 58.95410319737026, 55.95857497623989, 58.751125471932546, 57.27453947067261, 61.351523535592214, 56.05908414295742, 57.632885864802766, 52.388395990644185, 56.327691078186035, 55.11114835739136, 57.952440466199604, 60.573686599731445, 61.72302286965506, 62.232520375932964, 58.99235303061349, 58.20266941615513, 58.95982851300921, 56.98295831680298, 37.73945331573486, 35.591911043439595, 34.90333761487688, 45.721547331128804, 57.738429001399446, 40.89365407398769, 59.5317416872297, 53.965449469430105, 54.65229974474226, 52.642366545540945, 55.99333681379046, 55.0301844733102, 56.63340139389038, 57.586364201136995, 61.55641201564244, 57.75462525231497, 56.639845848083496, 56.35504266193935, 59.44046320234026, 59.90675680977957, 56.65681334904262, 50.88753645760672, 48.44383069447109, 42.80395705359322, 35.570979595184326, 29.7603748185294, 29.019691637584142, 24.580030713762554, 22.14115568569728, 23.278553213391984, 9.416399359703064, 11.988069227763585, 10.583766204970223, 12.263537509100777, 14.34364925112043, 7.783259153366089, 10.512085114206586, 5.314123851912362, 8.64097431727818, 8.001651457377843, 1.031108436839921, 1.6893564526523863, 0.23830714396068028, 0.21227047964930534, 0.3467951225382941, 2.8229519043649947, 6.676063707896641, 16.94878946031843, 22.094229289463588, 28.054637227739605, 25.438892330442155, 24.08982835497175, 22.21659575189863, 23.652932575770787, 37.21079615184239, 43.3386869430542, 46.01715496608189, 37.59619188308716, 20.043115854263306, 3.0787845764841353, 0.19152234441467694, 0.043789213323699575, 0.048709274136594365, 0.0139510141619082, 0.0817428422825677, 0.04404781998268195, 0.03519179465781365, 0.019980795249076824, 0.036330464628658125, 0.09840627812913486, 0.01690209187966372, 0.022668518259056976, 0.0733729839058859, 0.05464634019881487, 0.032075700616197925, 0.014001592162198253, 0.014008212967642715, 0.07646519012217011, 0.08947787686650242, 0.04536636280161994, 0.039786019562078376, 0.047764671966433525, 0.03998002290193524, 0.03289448543052588, 0.036223059320556264, 0.037487024175269265, 0.04366963170468807, 0.034883973853928704, 0.03663864844877805, 0.019434157260028378, 0.0043700496566348845, 0.03459965411041464, 0.06497982463666371, 0.03035449136846832, 0.04492436169779726, 0.04966385755687952, 0.014517843656774079, 0.062258369954569, 0.02289313031360507, 0.029906305417950665, 0.031047336690660034, 0.035470489346023114, 0.07457652860986334, 0.0312534892000258, 0.06759520393929311, 0.026934813974159103, 0.05549166251772216, 0.029950454298939024, 0.01333299428889794, 0.061910132212298255, 0.036122904159128666, 0.06047659127839974, 0.07278902988348689, 0.048630927090666125, 0.012481697469151445, 0.03181294471557651, 0.03380423125677875, 0.026850231191409484, 0.07063467441392796, 0.020533331403774873, 1.1666250165019716, 7.031863587243216, 23.243317161287578, 52.68871103014265, 64.20799051012311, 64.33390576498849, 52.74656867980957, 42.62537792750767, 35.028992312295095, 29.76061453138079, 23.560049057006836, 25.662243911198207, 38.24294410433088, 38.03844124930245, 29.024409464427404, 8.762490493910652, 2.4489935593945638, 0.16827316981341156, 0.578899696469307, 2.620583883353642, 8.008745568139211, 11.073646341051374, 8.506701248032705, 11.145043424197606, 10.974115133285522, 12.37114860330309, 15.452074527740479, 14.036531925201416, 11.666196533611842, 14.345480101449148, 13.26121631690434, 9.863553285598755, 8.815731934138707, 12.884381634848458, 23.168113333838328, 32.81384059361049, 42.22623865944998, 49.915122168404714, 55.98280681882586, 59.7765336717878, 61.98077324458531, 62.254824093409944, 63.271303858075825, 60.66887692042759, 58.75998442513602, 56.93035003117153, 58.077681745801655, 57.83150359562465, 60.237428528921946, 62.261591638837544, 61.79559680393764, 63.24797875540597, 60.64622579302107, 59.5477294921875, 60.94421318599156, 61.39718014853341, 44.50870105198452, 42.1543664932251, 42.53401606423514, 51.47330086571829, 61.70050375802176, 49.00829887390137, 61.14751747676304, 56.28169400351388, 55.86778286525181, 55.589806284223286, 55.32696287972586, 55.101980209350586, 56.229780537741526, 58.82211521693638, 60.67057922908238, 60.5734920501709, 58.06633881160191, 57.236866337912424, 60.69858046940395, 60.362787927900044, 57.04664897918701, 51.72138629640852, 48.60003662109375, 43.622315883636475, 33.11338438306536, 28.16882218633379, 21.60454109736851, 17.472263268062047, 12.069482139178685, 15.389780453273229, 17.720565829958232, 13.443275621959142, 11.644832559994288, 13.460750341415405, 15.763546637126378, 13.559550251279559, 12.150113378252302, 9.233402047838483, 8.20392654623304, 6.923578952039991, 6.226833573409489, 3.6136825254985263, 0.779503906411784, 0.4572249597736767, 0.6109907116208757, 3.086667090654373, 8.110291753496442, 21.088536603110178, 26.621984686170304, 29.156114305768693, 28.336049692971365, 26.29716682434082, 26.522321462631226, 29.628313882010325, 42.700345516204834, 50.770018100738525, 53.50066362108503, 44.588292666843955, 23.537686279841832, 3.5199851989746094, 0.22980203319873127, 0.06056132673152855, 0.03824590791815093, 0.04241896274366549, 0.027003702241927385, 0.025379923837525502, 0.02436450127113078, 0.03878056976412024, 0.015008349836404835, 0.10432211961597204, 0.03824609112260597, 0.016542195209435055, 0.02406653279571661, 0.05531800505039947, 0.06533181467758757, 0.020916033635980318, 0.014542036822863987, 0.09033331953521286, 0.031559226901403496, 0.035361560726804395, 0.037120391348642964, 0.05121884608109083, 0.020666846739394323, 0.024198950600943396, 0.02695503771038992, 0.018038232611226182, 0.08507882577500173, 0.046352270791041, 0.046040782505380254, 0.04844912041776946, 0.021208787569776177, 0.13012283694531235, 0.16677746150110448, 0.191814087331295, 0.11029100218521697, 0.1032703835517168, 0.14818306426916802, 0.19208706196929726, 0.17919305099972657, 0.1320474608136075, 0.07168516197374888, 0.1375412331627948, 0.13201149845761911, 0.14338033912437304, 0.11620982922613621, 0.16386330287371362, 0.13396288374704973, 0.2043891189885991, 0.15594104012208326, 0.12356065692646162, 0.13382624036499433, 0.11156799151961293, 0.1518714449235371, 0.08854092178600174, 0.07866671056087528, 0.13006957194634847, 0.16964220920843737, 0.1006580169445702, 0.11647677847317287, 0.22283510704125675, 1.9757914883749825, 10.468745725495474, 30.227568217686244, 61.56682736533028, 72.85179274422782, 73.52371828896659, 60.0816707611084, 51.18969276973179, 45.24118709564209, 38.75622143064226, 31.51674393245152, 27.92626404762268, 51.49090412684849, 46.29217856270926, 31.850139345441544, 10.17308337347848, 2.2001655399799347, 0.4782371265547616, 0.7915221729448864, 4.150300587926592, 6.617064382348742, 15.181970255715505, 18.934261526380265, 15.130829777036395, 19.974057708467754, 15.672231674194336, 16.624385016305105, 19.476064682006836, 35.118902002062114, 19.26982477733067, 29.34708206994193, 31.990659713745117, 16.856677191598074, 19.925913640430995, 25.902302435466222, 34.08436039515904, 47.189184052603586, 53.53079795837402, 61.67263453347342, 62.179971149989534, 64.29164682115827, 64.18892465318952, 68.4487748827253, 63.670186042785645, 63.63784217834473, 59.33579553876604, 61.683411189488, 59.7424110685076, 61.82820469992501, 64.92780998774937, 63.2427259172712, 64.26719611031669, 58.537857464381624, 56.80225304194859, 63.0691043308803, 62.0304320199149, 50.340511730739046, 46.197102887289866, 46.761192389896934, 52.925109590802876, 63.21389089311872, 51.80595629555838, 63.78186443873814, 55.626437187194824, 55.71530812127249, 58.812429428100586, 59.68856947762625, 55.0570079939706, 58.84994970049177, 60.07042857578823, 61.838224002293174, 61.58436461857387, 59.495750018528526, 57.523517744881765, 61.42031070164272, 63.498252868652344, 57.31522117342268, 55.9199812071664, 50.4908116885594, 45.71738536017281, 36.75689465659005, 31.149858202253068, 33.983677523476736, 30.128750937325613, 30.8785206249782, 29.749393190656388, 18.307874475206646, 25.22449176652091, 21.37083148956299, 22.054872955594742, 26.2695129939488, 15.861014229910714, 20.572042260851177, 12.423762968608312, 18.89449351174491, 14.477268321173531, 6.199966192245483, 3.8982481701033453, 1.2142798879316874, 0.48407442761319025, 0.8467336446046829, 4.1206435050283154, 8.529939498220172, 24.254679577691213, 30.464738028390066, 40.62997688565935, 36.88165651048933, 33.73825325284685, 32.30147695541382, 37.22503301075527, 50.85335826873779, 57.23940937859671, 60.27886758531843, 52.130530970437185, 30.341765335627965, 5.418963049139295, 0.45839513412543703, 0.19591481371649674, 0.19062395047928604, 0.23074085425053323, 0.2457215775336538, 0.07830991649201938, 0.14748303326112883, 0.12510941310652665, 0.09296663930373532, 0.2038932591676712, 0.1799486811671938, 0.09468333968626601, 0.15996241862220423, 0.13939018680581025, 0.18463788740336895, 0.20415331449891838, 0.05736933515540191, 0.20251267110662802, 0.12939147119011196, 0.09493760711380414, 0.11022217837827546, 0.16302642492311342, 0.14183804259768554, 0.10062925384512969, 0.14732492103108338, 0.12462027078228337, 0.1605823824980429, 0.10854274313896894, 0.1405245480792863, 0.19395433605781623, 0.07360409293323755], [0.08508043390299593, 0.07118795865348407, 0.040272505421723635, 0.06570686133844511, 0.02758433822808521, 0.014426709618419409, 0.011725432023272982, 0.010777434633512582, 0.02660684916190803, 0.017478753346949816, 0.04143908693056021, 0.0495272650649505, 0.06331798381039075, 0.05465538167793836, 0.03896847307415945, 0.04870557612074273, 0.06768029901598181, 0.029057407219495093, 0.0156393449953092, 0.029089115160916532, 0.018332140054553747, 0.03106456808745861, 0.05834864439176662, 0.028254315223810927, 0.02962289491136159, 0.11788091169936316, 0.023893061925524046, 0.041429024256233654, 0.19726698473095894, 2.0830499614988054, 12.765961749213082, 34.566944054194856, 47.263161523001536, 56.587675298963276, 49.37140130996704, 40.54490314211164, 32.18893003463745, 34.00736393247332, 18.237376315253123, 22.391617400305613, 28.95122582571847, 33.66008949279785, 23.98208785057068, 13.899358851569039, 3.065813158239637, 0.5222062500459808, 0.19207065499254636, 0.4734424895473889, 2.533064808164324, 11.953179717063904, 6.665316581726074, 7.057501137256622, 11.397850155830383, 6.334864599364145, 12.578702586037771, 14.079225131443568, 7.790130053247724, 12.592299342155457, 14.214262502534048, 9.702801500047956, 9.63053936617715, 11.397844076156616, 14.92010828426906, 29.501196588788712, 41.27989748546055, 45.1372663634164, 54.405819347926546, 56.26981953212193, 57.459399768284385, 52.80078547341483, 57.01929044723511, 54.260598523276194, 56.71061325073242, 51.688952105385916, 53.495650495801655, 54.203446115766255, 57.22972706386021, 57.21071331841605, 61.010283606392996, 58.98626640864781, 61.48308767591204, 59.641794204711914, 63.34538555145264, 62.02585315704346, 61.94165488651821, 45.614631925310405, 37.03708076477051, 31.203008447374614, 47.83945901053292, 38.510064125061035, 40.29800932747977, 61.045114925929475, 53.85113423211234, 55.17573186329433, 51.36505140577044, 54.7209027835301, 52.565359660557334, 53.6887652533395, 52.82827254704067, 59.80879415784563, 56.635409423283164, 56.54026426587786, 54.14340673174177, 56.586636543273926, 54.66986131668091, 61.89902073996407, 55.36054352351597, 54.836816106523784, 49.232958453042166, 45.46945626395089, 40.684270109449116, 34.798260007585796, 28.598064524786814, 24.337545531136648, 20.14660927227565, 17.82843313898359, 17.656156029020035, 10.894928250994, 7.111041784286499, 8.09070565019335, 18.20025209018162, 15.398698466164724, 6.678561151027679, 5.347554675170353, 5.974807645593371, 5.738640981061118, 1.9894905132906777, 0.13588582484849862, 0.28468938225081986, 0.16578753319169792, 0.5837391167879105, 4.247583619185856, 15.669386386871338, 42.11794751031058, 48.30282742636544, 32.340223584856304, 22.18204062325614, 17.70513388088771, 22.64018746784755, 30.79157781600952, 41.09528384889875, 45.954510007585796, 49.82585866110665, 24.410258429391043, 6.759694831711905, 0.18797865456768445, 0.08476188206779105, 0.04223264720556991, 0.020649942735742246, 0.014084077423571475, 0.009302403827730035, 0.05795823569808688, 0.06589577227298703, 0.0391471211665443, 0.058137579288865836, 0.030867840429501872, 0.03805338039195963, 0.060310974451048036, 0.009429688515540744, 0.016161012895671383, 0.0151441908508007, 0.04673385513680322, 0.05021548277831503, 0.08127824256994895, 0.03488909000796931, 0.014773447798298938, 0.036948766093701124, 0.028522826797728027, 0.021844892097370963, 0.07432368610586439, 0.02773787034675479, 0.010413412470370531, 0.009942683042027056, 0.012735542508640459, 0.030194204433688095, 0.06185540836304426, 0.049877433239349296, 0.07835689825671059, 0.02998987039817231, 0.027771400154701302, 0.05102249840274453, 0.021802604098671248, 0.05388973294092076, 0.024982573730604987, 0.04291881235050304, 0.051534381828137805, 0.039298027354691706, 0.02178930990131838, 0.041297812547002516, 0.022993417789361308, 0.026115981662379842, 0.05813076001192842, 0.07205217477998563, 0.052445854526013136, 0.022124672441610267, 0.00874251320159861, 0.010010533999385578, 0.031599745620042086, 0.03468129883653351, 0.08479454674358879, 0.0496750635627125, 0.04666577432570713, 0.026020749272512536, 0.023353060008957982, 0.1243316355560507, 2.194772435086114, 13.650280697005135, 37.8508676801409, 53.34264768872942, 65.00798525129045, 58.40803732190813, 47.16832208633423, 38.10048171452114, 36.70470673697335, 24.695078986031668, 19.536588702883037, 18.48185736792428, 32.752210072108674, 23.68584792954581, 16.43783630643572, 3.8702473640441895, 0.6285987496376038, 0.10800864108439003, 1.459518511380468, 3.0677884008203233, 11.903397611209325, 12.218989133834839, 9.616173097065516, 10.652757474354335, 15.119191544396536, 12.71278544834682, 14.256564872605459, 10.645708526883807, 13.807656526565552, 13.272272637912206, 15.090988806315831, 11.541079453059606, 11.972970792225428, 18.1718704359872, 30.823609011513845, 39.37308597564697, 48.03299413408552, 55.19409247807094, 59.25539098467146, 61.54469040461949, 58.47341292245047, 59.17002541678292, 57.82281834738595, 59.864345005580354, 55.404518672398154, 56.12326117924282, 56.581171785082134, 58.609333583286826, 59.18246269226074, 62.36509200504848, 60.37986660003662, 63.22518171582903, 59.18397045135498, 62.09492519923619, 63.669567653111045, 63.146396092006135, 51.209786960056846, 43.16818857192993, 38.07556200027466, 52.538598673684255, 47.20002671650478, 45.05254002979824, 62.80502414703369, 53.79892546789986, 56.00310945510864, 52.60228933606829, 55.246283871786936, 52.894408975328716, 55.00265918459211, 54.59509869984218, 62.815960611615864, 58.54160254342215, 58.731566292899, 56.820651871817454, 58.48933124542236, 56.8848671231951, 61.56116458347866, 56.978983947208945, 53.070504120418, 48.18116446903774, 44.767660413469585, 40.36820697784424, 35.50931085859026, 27.54277559689113, 19.88133920942034, 18.593252624784196, 16.26781041281564, 18.417716809681483, 17.32386190550668, 10.504380430494036, 12.632342679159981, 17.279947553362163, 13.613716670445033, 10.448952913284302, 12.212612424577985, 7.78144827910832, 6.769683735711234, 6.1709674511637, 2.8515404845987047, 0.6482988468238285, 0.35422676375934053, 0.4979588825787817, 4.826417633465358, 15.345475264957972, 35.84909861428397, 43.73167358125959, 33.33569547108242, 27.63167084966387, 21.882451670510427, 29.621716567448207, 37.05335691996983, 46.29828255517142, 51.97728150231497, 54.73650843756539, 29.681776796068462, 8.516349690301077, 0.5079768821597099, 0.1695506748344217, 0.030570245148347955, 0.054813001970095296, 0.016148940061352084, 0.06706657766231469, 0.04581056235890303, 0.05966502268399511, 0.03906120166980794, 0.009345374602292265, 0.037676508471901925, 0.027125015821573988, 0.034476181093071184, 0.03290189842560461, 0.016311459376343658, 0.0038671415532007813, 0.007330012790459607, 0.04229524884639042, 0.008106906549073756, 0.019004856635417258, 0.028309961880690286, 0.022254167457244227, 0.09079191421291657, 0.021764655331415788, 0.0032763623166829348, 0.03737251799819725, 0.030460390328828777, 0.04017783282324672, 0.020140427397564054, 0.06638464318322283, 0.0068456435359881395, 0.1357053481042385, 0.2163831346801349, 0.10000084220830883, 0.10651715325989894, 0.12549574380474432, 0.1152777121003185, 0.18001311485256466, 0.0682456883202706, 0.13914811265255722, 0.15934918581375054, 0.11287789658776351, 0.16931449036513055, 0.09512544596301657, 0.11308626790664025, 0.14964802137442998, 0.1442327962390014, 0.16361168851809843, 0.09310698070164238, 0.10560474757637296, 0.16238952481320926, 0.17016434190528734, 0.12119012698531151, 0.13919714359300478, 0.10113831795752048, 0.11364717209445578, 0.19482287445238658, 0.1580178051122597, 0.11985535360872746, 0.3991050698927471, 3.589082211256027, 18.494883503232682, 46.862073285239084, 63.45438889094761, 71.61376966748918, 63.22646018436977, 53.37392153058733, 43.45677852630615, 44.78907823562622, 28.38779640197754, 34.93456629344395, 40.55458893094744, 42.84392309188843, 31.860999379839214, 18.47120577948434, 4.200588609491076, 1.0836487604039056, 0.3154968534197126, 1.721862296972956, 4.573020304952349, 25.591460875102452, 16.733839988708496, 12.417688505990164, 19.355259827205114, 19.253833498273575, 24.777566262653895, 23.711307866232737, 15.717671155929565, 23.610062190464564, 27.63078495434352, 18.27350173677717, 17.320705686296733, 15.626500368118286, 17.323538814272197, 35.225980690547395, 44.87976959773472, 49.51622608729771, 58.320031438555034, 60.9384183883667, 65.0065608705793, 59.060723304748535, 63.350735664367676, 59.82465689522879, 63.216017041887554, 58.943910190037315, 59.61151395525251, 59.79692663465227, 63.244317054748535, 59.71618856702532, 66.70063591003418, 62.83581856318882, 65.32403101239885, 58.66260542188372, 62.25204481397356, 63.862116132463726, 63.894710132053916, 56.95956720624651, 47.477350166865754, 42.38257312774658, 53.50124379566738, 51.57033245904105, 50.92934029442923, 62.09172207968575, 54.003737517765586, 54.426563194819856, 53.069274289267405, 55.42135068348476, 55.230674743652344, 54.94874811172485, 54.774396964481895, 62.47665922982352, 61.56974560873849, 60.067628451756065, 58.411358560834614, 59.86724935259138, 57.54114532470703, 65.17684732164655, 57.21695280075073, 57.952707971845356, 50.299222060612266, 48.68983513968331, 45.5696770804269, 39.44011524745396, 36.32195479529244, 32.06366096224104, 28.79184283529009, 28.262209449495586, 31.04019478389195, 19.46859015737261, 17.487168891089304, 15.283794369016375, 29.159366062709264, 25.991715329033987, 16.57337655339922, 16.86483437674386, 14.12350252696446, 11.07557099206107, 4.923712824072156, 1.9084373882838657, 0.591461008148534, 0.4302984374974455, 0.8851902410387993, 5.959388724395207, 19.684790304728917, 51.667238984789165, 60.77123778206961, 44.744550704956055, 33.12095444543021, 28.57878848484584, 34.150343963078086, 43.21721853528704, 55.80278941563198, 60.00974300929478, 64.64720698765346, 37.77920395987374, 11.503268224852425, 0.9026409674968038, 0.30679542890616823, 0.1760546365486724, 0.1357805569257055, 0.11395950854888984, 0.1590584742703608, 0.13086780054228647, 0.1634686261947666, 0.10509841796010733, 0.16319884067135199, 0.11488587169774941, 0.1714291718921491, 0.10282039269804955, 0.09738541540822812, 0.14417841844260693, 0.06955870786415679, 0.08407123519905976, 0.16405773029795714, 0.1894932532949107, 0.15286600084177085, 0.1161562656717641, 0.17629411869815417, 0.21971081968929085, 0.14437808415719441, 0.12144883881722178, 0.12050187534519605, 0.13594485739512102, 0.16281409774507793, 0.12456250031079565, 0.19640624948910304, 0.16231175112937177], [0.04544726453189339, 0.059830490233642716, 0.0674230121076107, 0.016510685739506568, 0.028914236330560276, 0.022234352538362145, 0.023296142795256207, 0.027752687855224525, 0.0688995857323919, 0.05767614154943398, 0.0076605356797309855, 0.007302251378340381, 0.05445870830278311, 0.018051089153492024, 0.05660472118428775, 0.03277511415737016, 0.02636634072821055, 0.10996922052332334, 0.05401779624766537, 0.13812322621898993, 0.02874332693006311, 0.013629057777247258, 0.034087370349360366, 0.03143604226144297, 0.043506019948316474, 0.028943287807383707, 0.03819885829995785, 0.01402211275749973, 0.07449777105024882, 4.365806783948626, 16.427662406648906, 38.2475403376988, 54.51644509179251, 56.085313592638286, 48.722547258649556, 47.63275357655117, 26.838864019938878, 24.488712276731217, 19.70250299998692, 28.975056409835815, 46.770308426448274, 40.06982701165335, 24.710936512265885, 8.832444957324437, 1.8365222300801958, 0.34720875748566216, 0.1531967595219612, 1.2640854439565112, 2.701571217605046, 5.366499372891017, 12.428604994501386, 8.116590295519147, 10.214815122740609, 12.782572286469595, 12.529333897999354, 20.86202359199524, 13.213312830243792, 4.6672999773706705, 11.128203596387591, 17.656376634325298, 13.907031399863106, 17.665973833629064, 24.51427469934736, 37.584612710135325, 45.803706305367605, 54.1957996232169, 58.841653551374165, 58.09265511376517, 55.09951707295009, 56.53724527359009, 53.84297704696655, 55.56054047175816, 49.768820898873464, 50.91519028799874, 51.12735005787441, 53.89337233134678, 54.477809633527485, 53.488170760018484, 59.29875469207764, 59.51184899466378, 62.46064363207136, 60.22398376464844, 62.30025141579764, 58.47425365447998, 57.700450147901265, 51.38638237544468, 40.399366174425396, 30.330241748264857, 30.452387605394634, 30.344155515943253, 44.740923745291575, 60.888148171561106, 52.34066881452288, 56.170929295676096, 53.894317286355154, 54.69768190383911, 52.88392414365496, 55.10704892022269, 53.507132393973215, 58.3350464957101, 58.15404939651489, 56.67592784336635, 52.429883684430806, 52.656148297446116, 53.05506174904959, 55.946290561131065, 56.59565877914429, 54.261824880327495, 55.15894848959786, 51.705631256103516, 48.208206857953755, 40.28663165228707, 32.917188099452424, 22.203625202178955, 29.89050762993949, 34.26855019160679, 14.202780604362488, 15.513451439993721, 11.582942349570137, 16.47421533720834, 17.32720398902893, 7.401204637118748, 9.246103354862758, 6.815393762929099, 5.568421840667725, 8.171229192188807, 10.112032158034188, 3.688637520585741, 1.23899929864066, 0.0642261757914509, 0.22518054475741728, 1.6692552055631364, 7.493686897414071, 19.068731750760758, 24.092487777982438, 28.74651973588126, 30.48407139096941, 29.421730041503906, 22.859639372144425, 32.12227596555437, 38.05213267462594, 44.73248863220215, 46.91097470692226, 33.85773794991629, 8.195655584335327, 1.1870722621679306, 0.052480615875018496, 0.039969179912337234, 0.029555017660771097, 0.016295557908181633, 0.0551201408462865, 0.03144328901544213, 0.02212911345330732, 0.038588018489203284, 0.0528455896835242, 0.05215488174664123, 0.02881147220198597, 0.04587474498631699, 0.030733249615877867, 0.029701516763972383, 0.028297471747334515, 0.03353677989382829, 0.028542640020272562, 0.008566574160275715, 0.09486621844449214, 0.06438645933355604, 0.04371052701026201, 0.06406146141567401, 0.004312088347173163, 0.075620929710567, 0.03011203045025468, 0.05328035081869789, 0.02926532391990934, 0.009227746315965695, 0.02155097108334303, 0.025331391620316675, 0.03101323012794767, 0.037143607424306016, 0.06138115988246032, 0.03879653230043394, 0.03873333694147212, 0.010648275492712855, 0.005649077564677489, 0.05414789515946593, 0.03177474997937679, 0.020572179229930043, 0.03652370122394391, 0.047168816439807415, 0.08738845041287796, 0.04167267939608012, 0.046750231579478295, 0.027219610388523767, 0.0632054487775479, 0.04706614052078553, 0.057998527107494216, 0.046125494209783416, 0.027775249144594585, 0.048002630804798434, 0.028002848449562277, 0.025818586549056426, 0.051752123715622086, 0.009445427135298294, 0.002330576314956748, 0.043037094574953826, 0.28799186646938324, 4.6255404353141785, 20.165928738457815, 43.882796900612966, 62.547794886997764, 61.75099631718227, 53.37783684049334, 48.39913988113403, 32.28444692066738, 33.42944056647164, 26.38090303965977, 19.924322502953665, 34.80512135369437, 34.88576214654105, 25.484013932091848, 8.88207767690931, 1.9142916798591614, 0.25752124722514835, 0.47137947167669025, 2.365956072296415, 6.707113904612405, 8.700318012918745, 9.356686541012355, 11.954670974186488, 13.383525456701006, 14.28902164527348, 11.570963655199323, 11.932713798114232, 13.36742387499128, 11.161880646433149, 12.545980044773646, 16.605213199342998, 12.69750896521977, 18.776810135160172, 27.33006865637643, 37.77439233234951, 47.329996245247976, 54.76687901360648, 61.05865696498326, 60.18047414507185, 58.50663225991385, 59.97582885197231, 58.66558619907924, 57.149468421936035, 53.37435231889997, 53.36389875411987, 54.729480334690635, 56.73535231181553, 57.330163274492534, 55.90436165673392, 59.85875865391323, 60.15563433510916, 61.228769711085725, 60.62507547651018, 61.82197911398751, 60.226999282836914, 58.640649114336284, 54.421949590955464, 46.8550660269601, 37.185344900403706, 37.31114898409162, 34.303127901894705, 48.29641771316528, 60.71726417541504, 53.67429910387312, 55.300855023520334, 52.455366202763145, 53.933651038578574, 51.73580033438546, 54.188969544001985, 54.13104588644845, 57.85802139554705, 59.079691886901855, 56.781481402260916, 54.276075635637554, 53.487854616982595, 56.06936400277274, 57.592787810734336, 58.834406580243794, 55.34406239645821, 54.9813038962228, 51.65421806062971, 46.18563835961478, 37.402920791081016, 32.718278544289724, 25.197492803846085, 24.616102286747523, 21.48878584589277, 19.691375459943497, 14.979499748774938, 10.571457471166338, 15.316751411982946, 21.24032347542899, 16.20576647349766, 15.018183844430105, 11.879839743886675, 10.225729874202184, 9.885341967855181, 8.233842015266418, 5.183928506714957, 1.9997760185173579, 0.2600796770836626, 0.3129498500909124, 1.87567771758352, 7.977791343416486, 21.03078838757106, 25.24305214200701, 29.058000530515397, 26.09228876658848, 30.17835065296718, 26.02977408681597, 37.25640065329415, 44.610707555498394, 49.214351177215576, 54.68195465632847, 38.48775345938546, 11.332643917628697, 1.4758273448262895, 0.08631204281534467, 0.06473937896745545, 0.03530572747279491, 0.023159585926415663, 0.08658422356737511, 0.04968011864860143, 0.029681747646204064, 0.09263209439814091, 0.03044576450650181, 0.046453155377613645, 0.028035913461021016, 0.01963016058185271, 0.04258466099521943, 0.03823617094063333, 0.016052265784570148, 0.08315295340227229, 0.014539806138990181, 0.01352268977955516, 0.018542146642825434, 0.04234509402886033, 0.06804250100893633, 0.021700418421200345, 0.04574042897937553, 0.02455386852047273, 0.0853115768570985, 0.03206415534285562, 0.011723080899433365, 0.04952251531981996, 0.020367153088695238, 0.021105193932141577, 0.10830803109066826, 0.16859299050910131, 0.15976928041449615, 0.12073314722095217, 0.10324048051344496, 0.14063365651028498, 0.09228717469211135, 0.10798350814729929, 0.09973028315497295, 0.20846032910048962, 0.07025127498699085, 0.2282142069722925, 0.1930388973227569, 0.14228179092918122, 0.15561095997691154, 0.1628627758473158, 0.17274065794689314, 0.16900602834565298, 0.1472022554704121, 0.28983810597232407, 0.12493684808058397, 0.15569071498300346, 0.060960821009108, 0.0848144753170865, 0.1279435453138181, 0.15286914924425737, 0.17527102359703609, 0.12008081722472395, 0.4667158190693174, 7.106925410883767, 23.85697337559291, 51.66762113571167, 70.66031006404332, 69.55850642068046, 63.6440121786935, 59.76210921151297, 37.73751476832798, 34.589855739048545, 30.5434923853193, 40.02157524653843, 58.44456400190081, 51.08067205974034, 31.007249900272914, 11.453342812401907, 2.4661640780312672, 0.6691778036100524, 0.5531361017908368, 3.267037549189159, 8.513664211545672, 17.806023461478098, 25.484335286276682, 20.825689724513463, 20.508997780936106, 19.460888079234532, 21.059093611580984, 32.361995765141074, 26.591549839292252, 12.754272273608617, 18.99502526010786, 23.790048326764786, 20.661564588546753, 21.14084264210292, 30.138158798217773, 41.39763123648507, 48.57695817947388, 57.69604846409389, 63.47780432019915, 63.103219985961914, 60.91368280138288, 60.64042404719761, 59.446424756731304, 59.98365947178432, 55.333973612104145, 55.542589800698416, 57.198234353746685, 59.21778733389718, 58.36962073189871, 58.48918533325195, 61.450618743896484, 60.29054750714983, 62.472122056143625, 59.43222958700997, 61.62846483503069, 61.382359640938894, 60.887863295418875, 56.881844656808035, 50.99226318086897, 40.367869990212576, 42.75468390328543, 41.50230237415859, 53.700563294546946, 59.22914069039481, 53.21945265361241, 55.29339265823364, 53.81210272652762, 55.09555312565395, 52.93293326241629, 55.61376714706421, 56.187066486903596, 59.44994054521833, 60.6887765611921, 59.471313204084126, 56.54087570735386, 55.74245473316738, 59.24867902483259, 59.53315217154366, 59.46878405979702, 54.33172723225185, 56.711172580718994, 53.273450578962056, 49.33974879128592, 41.842510495867046, 37.53070511136736, 25.077907357897075, 37.213794299534385, 40.93169893537249, 20.303508281707764, 23.399085351399012, 20.085696152278356, 28.82202580996922, 27.155788728169032, 15.003264325005667, 19.754426888057164, 16.62444233894348, 14.975165809903826, 16.22781137057713, 18.556887490408762, 6.613502996308463, 2.214123602424349, 0.6993501388600895, 0.5291830013905252, 2.0798340312072208, 9.813541889190674, 24.45283351625715, 33.65056003843035, 40.198552812848774, 40.79928016662598, 40.486388887677876, 33.76055697032383, 43.22979130063738, 50.075566496167866, 55.98866415023804, 61.98991012573242, 47.88220432826451, 16.918875728334697, 2.7781714158398763, 0.1564771777817181, 0.13897093358848775, 0.1177094459001507, 0.17164015557084764, 0.1534128322132996, 0.13066979045314447, 0.16094804501959256, 0.3063941161547388, 0.0848588990047574, 0.16253686190715858, 0.10675223171710968, 0.1268670495067324, 0.11658511337425027, 0.07870812155306339, 0.14523386609341415, 0.16835846166525567, 0.10575669870844909, 0.1310121656528541, 0.10223727327372346, 0.15391570808632032, 0.21604949901146547, 0.1664244740137032, 0.1032249488468681, 0.09715068978922707, 0.16349483121718678, 0.10995699332228728, 0.1202656908759049, 0.09923173633537122, 0.20414499565958977, 0.10707776567765645], [0.008690645984773124, 0.005293806806938457, 0.11365116188036543, 0.012173433921166828, 0.03192342717998794, 0.01827539417094418, 0.012152640215520347, 0.03558774358992066, 0.04901887609490326, 0.022893403423950076, 0.0314387869355934, 0.04101105347009642, 0.02089135192467698, 0.04391915277977075, 0.023100029211491346, 0.06494426940168653, 0.04415123211219907, 0.04824515279116375, 0.029443259550524608, 0.049924201265509636, 0.07348720170557499, 0.025327922610033835, 0.03293908214462655, 0.04054470652980464, 0.02422167982773057, 0.035453916128192625, 0.05362537909033043, 0.057210693668041906, 0.46389941019671305, 6.505507579871586, 18.878875698362076, 50.94979926518032, 55.08016286577497, 49.94235563278198, 43.632296970912385, 45.1177419253758, 38.58448280606951, 21.819834504808696, 25.699184009007045, 42.596449102674214, 28.6373096874782, 25.134394475391932, 10.32470348903111, 5.2210887755666455, 0.5967622665422303, 0.01440980052575469, 0.22318265267780849, 1.8586932803903307, 4.034421571663447, 10.14500309739794, 6.963827695165362, 8.427396246365138, 8.914183565548488, 16.079052175794327, 6.82180347612926, 5.626571314675467, 8.918484500476293, 11.543168255261012, 8.900816099984304, 19.622859273638042, 18.144103697368077, 21.804586683000835, 31.369553293500626, 44.6505936895098, 52.89551026480538, 61.559344155447825, 57.71076127461025, 56.1460200037275, 54.42424249649048, 53.743162700108115, 52.643909045628135, 52.297214780535015, 50.45891598292759, 47.23577172415597, 51.6157180922372, 54.03482723236084, 55.74982329777309, 54.29923398154122, 56.02927984510149, 61.715386799403596, 58.61000061035156, 63.80819116319929, 60.218029158455984, 64.08040073939732, 60.17208072117397, 51.409245422908235, 41.828103406088694, 30.300892557416642, 27.807736464909144, 37.18022060394287, 46.81795917238508, 58.40320137568882, 52.6148099899292, 56.01681130273001, 53.66438749858311, 57.22081252506801, 56.73648486818586, 53.26043312890189, 52.05130761010306, 54.155715465545654, 56.52649641036987, 54.985476289476665, 54.45368548801967, 52.980615275246755, 50.61100510188511, 54.090888772692, 56.761543546404155, 56.1177408354623, 56.12762464795794, 52.936657496861045, 52.59757150922503, 52.33038200650896, 44.94653831209455, 37.8716219493321, 33.48908737727574, 23.770174741744995, 37.29231936591012, 32.553053855895996, 7.119788697787693, 11.133839453969683, 18.217344658715383, 17.52346280642918, 11.585228306906563, 12.852050798279897, 6.1912062508719305, 5.020117776734488, 4.8959647587367465, 6.221169054508209, 2.589823122535433, 0.5654891303607396, 0.14300657489470073, 0.6006511407239097, 3.9016089269093106, 17.17822940008981, 31.658928394317627, 38.90709114074707, 40.23869603020804, 22.76933363505772, 26.03573911530631, 23.983197825295584, 29.372356142316544, 40.510012762887136, 47.426499775477815, 44.6020188331604, 20.119889974594116, 3.5605863460472653, 0.03753922048157879, 0.03677836559446795, 0.0829634317862136, 0.019868455295051848, 0.055688268039375544, 0.14971606486610003, 0.05186342042205589, 0.044956361409276724, 0.03802930596949799, 0.054642475941883664, 0.034852079315377135, 0.02311275852844119, 0.033573729518268786, 0.018158974525119578, 0.005423484602943063, 0.02061015853126134, 0.03687052422070077, 0.024158391170203686, 0.06534294265189342, 0.03774382593110204, 0.04050218274018594, 0.021355130609923174, 0.0683884656588946, 0.01295716392009386, 0.00863849208690226, 0.07935306230293852, 0.08333494327962399, 0.023516668372654488, 0.03931822734219687, 0.03565110858263714, 0.02504274621605873, 0.06526240733053003, 0.09485144673713616, 0.04420882955725704, 0.039036723519010205, 0.048472214357129166, 0.04030031857213803, 0.07379347205694232, 0.035975763840334754, 0.030291876156947443, 0.029721251954989772, 0.01589655556849071, 0.04065747565722891, 0.15103375273091452, 0.021433075623852865, 0.050943503355873485, 0.017950116357366954, 0.024219201478574957, 0.01954229368961283, 0.06238325432475124, 0.04830489779955574, 0.007404511694663337, 0.03606191064630236, 0.0463268698326179, 0.005418270061324749, 0.028570738155394793, 0.012185998693374651, 0.06638961684490953, 0.6688674145511219, 7.965063112122672, 22.470163311277116, 57.10414184842791, 60.750386238098145, 57.59609167916434, 48.66275453567505, 57.021020548684255, 37.726300375802175, 21.154692138944352, 15.743118933268956, 42.60878215517317, 39.442870208195274, 27.462287664413452, 13.146001287869044, 5.454909988812037, 1.146148458123207, 0.16969449711697443, 0.6827155543225152, 4.054118846143995, 6.7545405711446485, 10.399018815585546, 10.978744370596749, 14.468736801828657, 13.999376433236257, 15.729144368852888, 12.218690361295428, 12.36621277672904, 12.434446692466736, 13.413172551563807, 13.01819178036281, 16.03400179318019, 14.916316304888044, 22.89792742047991, 36.00808729444231, 44.42573608670916, 55.76507806777954, 61.35680416652134, 62.26237678527832, 58.22594240733555, 57.980823857443674, 55.81626892089844, 55.149922779628206, 54.46605328151158, 53.91530779429844, 50.645412581307546, 53.830782958439414, 55.47641168321882, 57.738470690590994, 56.568345410483225, 58.25943967274257, 61.456691469464985, 59.51810237339565, 62.89276599884033, 59.807140486580984, 62.657319341387065, 61.48287922995431, 53.36904042107718, 49.4423736844744, 37.21524994713919, 31.34016936165946, 41.68296248572213, 51.21338612692696, 59.39267349243164, 54.23918417521885, 55.73485687800816, 55.59999234335763, 55.60768052509853, 57.289304392678396, 52.86597694669451, 54.36059699739729, 55.82074703489031, 57.72639124734061, 56.719097001211985, 55.06211839403425, 52.67522805077689, 53.94074862343924, 55.64835180555071, 57.48554931368147, 56.7280011177063, 55.422219208308626, 53.208901814052034, 53.37499850136893, 51.2620130947658, 44.37691804340908, 34.63042974472046, 28.122656617845806, 22.053123746599468, 19.184702396392822, 10.284900733402797, 11.852884207453046, 19.70928791591099, 18.81778018815177, 16.40377971104213, 15.00220993586949, 14.428313050951276, 12.056256243160792, 10.518846579960414, 10.967214703559875, 4.977341192109244, 2.512700072356633, 0.6785858816334179, 0.023877228310863887, 0.6504148447087833, 3.8990641491753713, 16.96997104372297, 28.951896326882498, 33.38359635216849, 43.95482887540545, 29.038227694375173, 32.17614187513079, 30.90233210154942, 34.02358797618321, 46.53293364388602, 53.91538075038365, 51.76476042611258, 23.075307982308523, 4.5823790941919595, 0.042132715960698466, 0.01578747427889279, 0.032796671214912615, 0.04133143734985164, 0.054178229067474604, 0.15269358509353229, 0.050646145561976094, 0.025869568277682577, 0.03216108407026955, 0.032616167329251766, 0.026771901108856713, 0.0129494116575058, 0.005420128399107073, 0.023685090942308307, 0.010170283195163523, 0.015328670951670833, 0.06778982135334186, 0.05388848104381135, 0.047107307240366936, 0.11577217413910798, 0.006419806832647217, 0.06691124742584569, 0.03990094643086195, 0.014215771740834628, 0.034247053387973986, 0.04445920558646321, 0.07328453686620508, 0.032981843421501775, 0.049893107398280075, 0.03790351914774094, 0.1210267221821206, 0.17445657801415237, 0.16838974212961538, 0.08969593766544547, 0.17231080601257937, 0.1442610640078783, 0.10295192671141454, 0.11010642030409404, 0.18522891854601248, 0.12741276808083057, 0.1483256109058857, 0.10992341940956456, 0.13922683628542082, 0.21538272979004042, 0.16479531143392834, 0.16278592497110367, 0.1458432583936623, 0.10151868433292423, 0.0703255542154823, 0.09654958240155663, 0.1462058810783284, 0.09877868528876986, 0.24524302035570145, 0.141257162338921, 0.15213433653116226, 0.10122856990035091, 0.29415700850742205, 0.17863262178642408, 1.2711642469678606, 11.123028056962148, 30.04385437284197, 67.14481340135846, 70.73777553013393, 64.20595468793596, 55.591880321502686, 56.062940393175396, 47.14284651620047, 31.72084379196167, 36.04594802856445, 52.74988644463675, 35.484950474330354, 33.37207623890468, 13.344899552209036, 6.738995713847024, 1.2161579642977034, 0.4012256275330271, 1.2132108424391066, 6.31831876720701, 11.42969809259687, 17.993246146610804, 15.744786500930786, 21.301045519965037, 17.178476061139786, 26.70981686455863, 15.044946568352835, 17.867664405277797, 21.675895622798375, 21.330552782331193, 16.113940817969187, 26.028601578303746, 20.167257581438335, 25.768947396959575, 36.706582750592915, 47.99698509488787, 57.51366172518049, 64.35530621664864, 62.741364751543315, 60.848050117492676, 60.41403784070696, 58.53537695748465, 58.484120096479145, 56.76463549477713, 56.94171033586775, 53.67373282568795, 56.5587534223284, 59.328715324401855, 59.22299153464181, 58.094274044036865, 59.729237283979145, 64.65164688655308, 60.630453382219585, 63.475393295288086, 59.74631595611572, 62.699870109558105, 62.32806505475725, 56.781926086970735, 52.045773369925364, 41.26008817127773, 37.085280418395996, 45.21326923370361, 53.87684951509748, 59.05772863115583, 52.87792437417166, 57.81477928161621, 56.14650637762887, 57.955167634146555, 58.10730539049421, 54.13699007034302, 54.400573457990376, 56.72771971566336, 59.15961701529366, 57.96005916595459, 58.48274435315813, 56.16853216716221, 54.75846127101353, 58.1148441859654, 60.12440913064139, 59.31774411882673, 57.35556936264038, 52.99174281529018, 54.51199129649571, 53.22819348743984, 49.985250336783274, 43.73433474131993, 40.089948994772776, 27.77523626599993, 44.7282988684518, 41.03073508398873, 17.11462559018816, 19.645319325583323, 26.273160798209055, 31.671667916434153, 20.397619894572667, 24.88698649406433, 14.615202222551618, 17.602079936436244, 15.175947904586792, 12.509021707943507, 4.23226284129279, 0.8675058814031738, 0.16548668433512959, 1.0626295911414283, 4.857287177017756, 21.142421620232717, 38.16947037833077, 50.912511757441926, 53.5557141985212, 33.44878087724958, 35.79551758084978, 35.00856808253697, 41.18229266575405, 53.40532738821847, 62.11440794808524, 59.01191915784563, 30.612293447766984, 6.920067071914673, 0.28091317202363697, 0.13296811069761003, 0.20064688979515008, 0.10749458973961216, 0.11173090777759041, 0.22376612494034426, 0.15457939675876073, 0.09610051435551473, 0.1538816456283842, 0.10808790075991835, 0.18684742812599453, 0.15046002423124655, 0.06189995418701853, 0.0878261054999062, 0.07152805397553103, 0.11291647808892386, 0.10265897600246326, 0.16201343999377318, 0.18350272545857088, 0.19330880498247488, 0.21061365998217038, 0.10246986150741577, 0.16583201794752053, 0.08700570916490895, 0.12356856864477907, 0.15813251824251243, 0.13187915698758193, 0.10799253266304731, 0.0881844534139548, 0.12213392848415033], [0.023971741453611424, 0.005200036660036338, 0.011257553290176605, 0.05632521225405591, 0.04623479941593749, 0.03146945671843631, 0.032030221806573014, 0.034666964784264565, 0.04782670024516327, 0.03315022188637938, 0.02566742930295212, 0.029384182899125984, 0.03523115308157035, 0.03339192623804722, 0.020669165632820556, 0.016855739456202303, 0.07173110557986156, 0.0018831026141664811, 0.01450214914179274, 0.005502604330623788, 0.03212281469521778, 0.022567586175033023, 0.028138872668413178, 0.027432602530877506, 0.04136466520971485, 0.01660067305367972, 0.02847246253596885, 0.053577528800815344, 1.4240265701498305, 8.504034876823425, 28.630097457340785, 48.06333344323294, 50.341241291591096, 43.941672461373464, 36.90376567840576, 32.01101098741804, 36.06254380089896, 55.51642983300345, 54.5761718068804, 24.333359241485596, 31.517807006835938, 21.041492087500437, 12.756763202803475, 2.308428027800151, 0.3032905241208417, 0.30118302149432047, 1.3835580902440208, 2.704160507236208, 6.8938410963330945, 5.766352134091513, 6.276502336774554, 12.024831277983528, 14.785608530044556, 11.035347001893179, 9.659756541252136, 7.473730802536011, 7.7900579656873425, 11.349742565836225, 15.821009976523262, 21.45892596244812, 23.73782045500619, 31.18720129558018, 50.541144439152305, 51.6007308278765, 62.1733842577253, 58.996125902448384, 56.95069088254656, 52.83884423119681, 53.122414112091064, 53.119078976767405, 55.97744975771223, 51.76185607910156, 49.804906368255615, 43.649128981998985, 49.22942876815796, 52.14106443950108, 56.13437482288906, 55.979923316410606, 57.20138883590698, 57.35519763401577, 61.70624991825649, 59.75990663255964, 61.79718794141497, 54.42197043555123, 46.8524500301906, 55.27930865968977, 46.367191314697266, 34.68145384107317, 30.053689547947474, 44.09830570220947, 51.26923227310181, 51.999185698372976, 58.11915554319109, 55.80627046312605, 56.522542885371614, 53.432029315403526, 58.50761890411377, 58.261308738163535, 54.00046839032854, 54.838831084115164, 57.310364382607595, 55.573863642556326, 51.591614791325156, 50.368697098323274, 52.99962902069092, 53.91454349245344, 54.652209418160574, 55.65148196901594, 53.71125657217843, 53.70704596383231, 54.297566413879395, 51.564440386635916, 47.156159264700754, 41.54291112082345, 34.38679116112845, 37.8039082799639, 30.71953889301845, 11.662857055664062, 14.878226280212402, 22.331934111458914, 22.923118114471436, 19.324178797858103, 16.790460859026226, 8.097165737833295, 12.527472649301801, 9.17742301736559, 8.153143031256539, 4.233805341379983, 3.058371637548719, 0.3769922921700137, 0.27122608040060314, 0.11647113306181771, 1.7058662410293306, 6.862088263034821, 19.000858272824967, 39.42028856277466, 37.89621162414551, 26.481783935001918, 13.628751703671046, 22.582020623343332, 36.49986342021397, 43.60233633858817, 44.6452887398856, 45.84156356539045, 25.712672199521744, 6.302755670888083, 0.5615728433643068, 0.048089697025716305, 0.02450977561862341, 0.03987745215584125, 0.019400428980588913, 0.014839255517082555, 0.0556107759475708, 0.0257070235176278, 0.03043105047462242, 0.024457547081900493, 0.07017955383551971, 0.011281950864940882, 0.03636256612039038, 0.031165574810334613, 0.0392810639792255, 0.041802286369992156, 0.062383810723466535, 0.04674251663631626, 0.059417649172246456, 0.04546189374689545, 0.027864077860223394, 0.020059278002008796, 0.03726256139842527, 0.0360360856034926, 0.02806649842698659, 0.13640795754534857, 0.06433569812881094, 0.006796942533193422, 0.033609220292419195, 0.028417857430343117, 0.07015454303473234, 0.019242508436686227, 0.03343411415283169, 0.019814654253423214, 0.06963695652250733, 0.04953122431678431, 0.06573917996138334, 0.018110338831320405, 0.06815655596022095, 0.05377368309668132, 0.026469668040850332, 0.036564569388117106, 0.02095531063553478, 0.05594411984618221, 0.02885538020304271, 0.015117790749562638, 0.06889069013829742, 0.023295486312625662, 0.03079210574339543, 0.018786283542535136, 0.025893154154930795, 0.015740540011652877, 0.017599883722141385, 0.03222058141337974, 0.023899999946089726, 0.028169969928317835, 0.08911686909518071, 0.055930477899632285, 1.792467936873436, 9.547707285199847, 32.337086473192485, 55.87054130009243, 58.07364484242031, 49.72793422426496, 43.30633265631539, 35.89547436577933, 41.374417304992676, 41.25404323850359, 47.4125199999128, 35.14155660356794, 29.15965093885149, 23.783935649054392, 9.525496499879019, 2.4918928231511797, 0.6222153093133653, 0.8758793835129056, 1.5285235685961587, 4.957598754337855, 9.879896317209516, 11.76352516242436, 11.796651567731585, 12.782202294894628, 15.908157757350377, 11.582624469484601, 15.885008096694946, 11.47480058670044, 7.955934047698975, 14.566631708826337, 17.662079368318828, 19.53258306639535, 23.636880499976023, 33.46703379494803, 47.18742615836007, 54.23741238457816, 63.21872683933803, 61.99471133095877, 57.14609854561942, 56.61823695046561, 54.8613988331386, 56.39482109887259, 58.42990330287388, 55.43848841530936, 51.742098876408164, 46.20659065246582, 52.6463165964399, 55.86671979086739, 58.23455122538975, 58.2956154687064, 59.019305092947825, 58.09838390350342, 60.960416385105674, 59.45665945325579, 60.7756290435791, 56.353896209171836, 49.25260101045881, 57.378547055380686, 47.912689549582346, 43.27271727153233, 34.454094886779785, 49.73033135277884, 51.75009625298636, 51.46167652947562, 56.75232328687395, 57.91618129185268, 56.638584750039236, 55.795386110033306, 59.634199823652, 57.77682474681309, 55.15262562888009, 57.15598930631365, 58.8856634412493, 57.060319559914724, 52.22401898247855, 51.131855964660645, 53.183297702244346, 56.743106501443044, 54.56339406967163, 56.044211523873464, 54.9200451033456, 53.23580871309553, 53.642104625701904, 52.03240156173706, 48.264973640441895, 43.157901763916016, 34.302589416503906, 29.594663756234304, 24.178688866751536, 13.87286102771759, 13.727200729506356, 15.80471818787711, 12.550063848495483, 16.684733595166886, 21.797386612210953, 12.021661162376404, 12.622408492224556, 12.685804724693298, 9.580468910081045, 5.950600121702466, 5.41345225913184, 1.34817373752594, 0.5819264511976923, 0.24302117100783757, 2.5514497416360036, 9.854493703160967, 24.75544146129063, 40.683582237788606, 36.87794617244175, 26.340309926441737, 17.998611892972672, 25.736311708177837, 41.876348223005024, 47.50546605246407, 50.65200989586966, 51.747657435280935, 32.094365051814485, 8.054976275988988, 0.8579625849212918, 0.04925174252795322, 0.04066165882561888, 0.03031080389129264, 0.021911261303882514, 0.012621065169306738, 0.03166257117741874, 0.018239655731511966, 0.0185445978505803, 0.02491092212897326, 0.021095445080261146, 0.02942399594134518, 0.011452545594823147, 0.038076688069850206, 0.027624660171568394, 0.034248359567884884, 0.030693314437355314, 0.013602448178322187, 0.06056574399449995, 0.01642543968877622, 0.010844634197253202, 0.025864508102781007, 0.027176560734265616, 0.04289199664656605, 0.04257963305073125, 0.06312520522624254, 0.0693997610360384, 0.04057604806231601, 0.05062843919066446, 0.01820901478640735, 0.16302405005054815, 0.12692952901124954, 0.09394341760448047, 0.09662145961608205, 0.16246287444872515, 0.22758563927241734, 0.1183795128017664, 0.0983633811452559, 0.20929670493517602, 0.15391021195266927, 0.1313733769846814, 0.06535093579441309, 0.13186995605272905, 0.08922257128038577, 0.10630123663161482, 0.09164376743137836, 0.19919126933174475, 0.12396785936185292, 0.04886696567492826, 0.08436528513474123, 0.1526428306741374, 0.2044934369623661, 0.11263117446963276, 0.08610104556594576, 0.217300201899239, 0.1330280253397567, 0.2518240229359695, 0.14338951291782515, 2.3361087824617113, 12.521538887705121, 41.65109804698399, 63.330162048339844, 66.24731458936418, 56.634735448019846, 49.065399169921875, 43.73903867176601, 46.59764916556222, 63.821434429713655, 64.55218342372349, 34.174825940813335, 42.27751636505127, 29.40964365005493, 15.313385009765625, 3.530603132077626, 0.9590264133044651, 0.6219304874539375, 2.3592061144965033, 7.8013288123267035, 18.737255777631486, 17.571421010153635, 16.44923656327384, 22.455436604363577, 26.260117292404175, 22.667337553841726, 21.32220104762486, 16.32316149984087, 17.61657735279628, 17.679531506129674, 23.308590275900706, 25.7585164138249, 27.116809334073746, 35.86243568147932, 51.71151638031006, 54.05244786398751, 65.43706430707658, 64.16630826677594, 61.480864252362935, 58.004895891462056, 56.3908189364842, 57.874311447143555, 61.55804484231131, 57.5290971483503, 55.560081890651155, 49.220420428684776, 54.103451115744456, 57.59723465783255, 61.44892338344029, 60.35455431256975, 59.23993819100516, 59.27852153778076, 62.353773389543804, 59.49476337432861, 59.37520572117397, 60.82680252620152, 57.353745460510254, 57.272545337677, 52.61124903815133, 45.66757719857352, 39.82696662630354, 51.3407952444894, 55.63709919793265, 51.632261753082275, 58.658297538757324, 58.580616678510395, 60.2004154750279, 58.15829821995327, 62.89282158442906, 60.41018853868757, 57.22413028989519, 58.16021244866507, 62.151434898376465, 57.89259215763637, 55.260534627096995, 54.07495307922363, 56.30433818272182, 57.93126235689436, 57.73405163628714, 58.42009939466204, 55.23672662462507, 52.16609879902431, 55.83730806623186, 52.8759754044669, 49.59039115905762, 45.91430425643921, 37.80611433301653, 44.36627687726702, 50.80172620500837, 20.72877972466605, 21.328002793448313, 32.922034467969624, 33.473863874162944, 30.420568329947336, 23.981582369123185, 15.132184675761632, 26.20999472481864, 18.052837371826172, 15.811946051461355, 11.665701474462237, 9.277377196720668, 1.4235373735427856, 0.44688226761562483, 0.6716318747826985, 2.716444705213819, 9.451942869595118, 23.789379562650407, 47.81737068721226, 48.646148341042654, 36.39926045281546, 23.19516440800258, 34.124892711639404, 48.60606418337141, 54.51292930330549, 57.081424713134766, 60.11715521131243, 38.16635758536202, 10.743104900632586, 1.7878953708069665, 0.14222535038633005, 0.08868373305137668, 0.11017739506704466, 0.1547013023602111, 0.13426481825964792, 0.19000143531177724, 0.17800695821642876, 0.09168669155665807, 0.15925372950732708, 0.15552722875561031, 0.08819587994366884, 0.1914066949060985, 0.1002919812287603, 0.10516027321240731, 0.12143498313214098, 0.12989246073578084, 0.10805856769106217, 0.14951931685209274, 0.144444254892213, 0.15175428906721727, 0.1513963347034795, 0.22710343157606466, 0.12208773382008076, 0.13402883735086235, 0.16223861862506184, 0.23107507345931871, 0.14409171523792402, 0.1393429743392127, 0.12080053931900434], [0.03281273892415421, 0.09597447647580079, 0.01733090735173651, 0.04204943935785975, 0.027202477379302894, 0.07204632580812488, 0.011039047202627574, 0.030306027004761354, 0.04778483463451266, 0.04288759295429502, 0.02492102381906339, 0.08342073724738189, 0.04804136836901307, 0.007543805604135352, 0.038197867638830624, 0.03907801576757005, 0.046245147074971876, 0.03327668724315507, 0.06811796088836022, 0.0307373988575169, 0.0465908335255725, 0.03368425608745643, 0.03591516048514417, 0.057487115263938904, 0.0792318352365068, 0.014622448311586465, 0.052262202237865756, 0.07741699154887881, 1.5082051903009415, 14.378431064741951, 35.96702344076974, 46.40148414884295, 45.45714405604771, 38.82180200304304, 33.39448070526123, 30.41209500176566, 20.932113545281545, 29.643450532640728, 19.97823531287057, 36.576634066445486, 38.229586192539756, 13.454681958471026, 6.221466089997973, 0.6165053014244352, 0.3947110671017851, 0.386263441826616, 0.7795281708240509, 2.3730054540293555, 4.086041041782924, 7.178600421973637, 12.309069054467336, 11.386570623942784, 14.303005763462611, 11.92576994214739, 14.930141483034406, 14.09191688469478, 9.551091926438467, 23.44522660119193, 31.50145094735282, 29.236192294529506, 30.113388470241002, 42.7560144833156, 57.08771283285958, 58.10128477641514, 59.736713545663015, 55.88699116025652, 54.07072510038103, 49.29362317493984, 52.619333267211914, 54.27715608051845, 55.052932875497, 51.46459477288382, 51.899489470890586, 42.64961324419294, 44.04049321583339, 52.65206275667463, 56.077090399605886, 58.34519781385149, 58.76443822043282, 57.142443793160574, 60.184816769191194, 58.851582527160645, 61.704915864127024, 50.32569817134312, 51.070638860974995, 58.51630415235247, 47.06083345413208, 40.436410495213096, 27.765503576823644, 43.49761656352452, 50.60341419492449, 50.41791813714163, 57.604252338409424, 55.27854435784476, 52.638482502528596, 53.16408593314034, 53.15646723338536, 55.3293183190482, 55.55908135005406, 55.136682987213135, 54.37333651951381, 54.997764178684776, 49.26941565104893, 51.80139480318342, 52.18442814690726, 54.64672034127371, 55.82222352709089, 54.67995357513428, 52.353029659816194, 57.25760323660714, 56.071052415030344, 57.06677096230643, 56.4400087084089, 48.004805292402, 40.47872502463204, 30.053088528769358, 22.146507535661968, 19.54667227608817, 23.741376195635112, 28.951951912471227, 17.376023769378662, 11.075591836656843, 22.558992556163243, 14.66814923286438, 10.189955336706978, 8.215031504631042, 11.453531282288687, 2.0364644612584795, 2.0418558291026523, 1.7717844524553843, 0.04097709957776325, 0.1068089029618672, 0.284453170640128, 3.0461471506527493, 10.35662351335798, 31.119442462921143, 47.7890567779541, 36.434070927756174, 37.83029753821236, 27.365474939346313, 26.187598943710327, 36.25915002822876, 49.265792165483745, 52.305087089538574, 37.06933082853045, 12.268371718270437, 1.9183114298752375, 0.08062526796545301, 0.032873990280287604, 0.046892690006643534, 0.019933302886784077, 0.02823116530531219, 0.05447080318949052, 0.03552460251376033, 0.03506922069936991, 0.038427996183080335, 0.022222719055467417, 0.019205725053325295, 0.014003577725296574, 0.040727079779441865, 0.04807223492701139, 0.003870465950707772, 0.011384420678950846, 0.07690934557467699, 0.041710243094712496, 0.037229160512132306, 0.03275638659085546, 0.052833810315600464, 0.049888652815882645, 0.025850452249869704, 0.06137457809277943, 0.008079961075314453, 0.06203887066138642, 0.06595426199159451, 0.029786771296390464, 0.021890230110979507, 0.034249278982835155, 0.06821208048079695, 0.05127342404531581, 0.023595604047711407, 0.06582291118268456, 0.05220476085586207, 0.048586048784532716, 0.13987170239644392, 0.03764262921842081, 0.06718160291867596, 0.04114421596750617, 0.047513970240418396, 0.05917525610753468, 0.027149758601029004, 0.036455728978450806, 0.0634897481650114, 0.034128245298883746, 0.020409203600138426, 0.03383635310456157, 0.012431010055089635, 0.046119183834109984, 0.05064828294728484, 0.013625108703438724, 0.024534905163039054, 0.04773900977202824, 0.06019444963229554, 0.05227167797940118, 0.09397895926875727, 1.8395837800843375, 16.31259502683367, 42.42616612570626, 53.397566250392366, 55.22569635936192, 46.529508181980674, 38.205594062805176, 31.114689895084926, 23.673572199685232, 41.667686871119905, 34.40626348767962, 35.92409399577549, 33.04827628816877, 14.837513310568673, 6.85467757497515, 0.7307623475790024, 0.6614971128957612, 1.218711535845484, 2.7469431715352193, 9.383471846580505, 12.29203380857195, 11.945196236882891, 14.942483220781599, 12.498421362468175, 12.902619787624904, 10.185399055480957, 13.642338906015668, 9.516796486718313, 8.706195320401873, 18.965721232550486, 21.246769666671753, 27.387469461985997, 33.03117677143642, 44.878511973789756, 57.19086578914097, 60.45460837227957, 61.138714109148296, 58.23609372547695, 56.12654767717634, 52.23253399985177, 54.732673031943186, 55.85806928362165, 57.44748708180019, 55.11409439359392, 55.98117399215698, 45.2020583152771, 46.663858549935476, 55.49400799615042, 57.61277777808053, 60.99877044132778, 61.01543916974749, 60.24974768502371, 60.04226752689907, 59.801866803850444, 60.40180206298828, 53.84277554920742, 53.79775469643729, 58.09866877964565, 49.40160860334124, 45.32121297291347, 31.691970552716935, 46.81938355309622, 52.58599928447178, 52.393721784864155, 60.36786706107003, 56.197929995400564, 55.689405236925396, 54.837847914014546, 54.95994860785348, 57.80637196132115, 57.16360453196934, 57.675950799669536, 57.8204733303615, 56.70259502955845, 52.12981183188302, 52.86356939588274, 54.16330637250628, 55.87437670571463, 56.17171444211687, 54.471111570085796, 51.92762272698538, 57.44922065734863, 55.08772597994123, 57.65637425013951, 55.850457532065256, 47.62361669540405, 42.48582335880825, 33.64452205385481, 24.16069824354989, 17.44389377321516, 13.255213941846575, 15.140322753361293, 10.632503475461688, 13.885786414146423, 20.044814688818796, 13.46223725591387, 12.440606270517621, 10.770166397094727, 8.733354091644287, 7.520480019705636, 5.001649030617305, 2.559510303395135, 0.7539494090846607, 0.1952118378664766, 0.7286008607063974, 3.668085617678506, 13.632660065378461, 32.58891698292324, 44.40358522960118, 41.724248681749614, 35.803143228803364, 29.680512223924907, 31.67530529839652, 42.84037256240845, 54.588504859379356, 58.13178389413016, 41.2743285042899, 13.982637354305812, 2.1831926107406616, 0.021685748494097164, 0.006727553421764502, 0.07081289163657598, 0.03477391208122883, 0.018392707786655853, 0.054824744018593004, 0.04051226916323815, 0.009050213565517749, 0.03979945455544761, 0.06451621558517218, 0.043403316887893846, 0.04168409574776888, 0.021531705777826052, 0.032731457214270315, 0.0061063134760063675, 0.03126537374087742, 0.013471423066221178, 0.03326047704155956, 0.022463826296318854, 0.033886893785425594, 0.02295539777592889, 0.0361980926245451, 0.017572835619960512, 0.042922045569866896, 0.03546354793278234, 0.06094327409352575, 0.027010906587487886, 0.015808802330866456, 0.033726569531219344, 0.09763038690601077, 0.2200507250215326, 0.09335320748920951, 0.1608417864356722, 0.17757123016885348, 0.13584172007228645, 0.09120426672909941, 0.21085690121565545, 0.18627536882247242, 0.1312301518129451, 0.14242861233651638, 0.22775538159268244, 0.11392355976360184, 0.13544837332197598, 0.14493693916925363, 0.16753564296024187, 0.11014990761343922, 0.09506712587816374, 0.09476924900497709, 0.10095073016626493, 0.16766491745199474, 0.1281888492937599, 0.13033011582280907, 0.11919587185340268, 0.14013216484870228, 0.1490442609148366, 0.10185405026589121, 0.25764265071068493, 3.3061283315931047, 21.84766377721514, 49.105702195848735, 62.6054162979126, 63.345649582999094, 52.728023937770296, 44.97715902328491, 41.096579687935964, 30.98994541168213, 38.494343825748985, 28.552039657320293, 46.44161694390433, 45.506139278411865, 18.583485194614955, 8.093893136296954, 1.0237495345728738, 1.3048716953822543, 1.9342180277620042, 3.833145720618112, 8.804351653371539, 14.987811531339373, 20.059541395732335, 22.09620257786342, 22.599979979651316, 26.28679837499346, 20.29673205103193, 24.771201712744578, 22.517480543681554, 14.128236855779376, 30.94322919845581, 35.52113669259207, 30.888272421700613, 34.52761377607073, 46.418416908809114, 59.381966318402974, 61.057044982910156, 66.14602375030518, 58.51726300375802, 58.20980174200875, 53.604987348829, 57.768323625837056, 56.852116789136616, 60.47943428584507, 56.83344350542341, 58.51717962537493, 47.055597986493794, 48.36183500289917, 57.57188762937273, 60.246836389814106, 62.616707120622905, 62.16986152103969, 61.19263907841274, 63.030785015651155, 59.64013358524868, 61.79941136496407, 57.75866215569632, 54.282200472695486, 58.78242710658482, 51.23942450114659, 50.63573374067034, 36.663587297712056, 51.19976418358939, 54.94126490184239, 52.58117723464966, 61.69534819466727, 57.87398835590908, 58.35243088858468, 55.50608743940081, 57.52173205784389, 59.03896154676165, 59.66812092917306, 58.96426841190883, 60.57069887433733, 58.19812876837594, 54.69508327756609, 55.84985998698643, 55.653458731515066, 58.44925403594971, 59.54629816327776, 59.515934535435264, 55.260895933423726, 61.23823315756661, 59.551120213099885, 61.40300273895264, 60.9493340083531, 51.25006914138794, 43.73554720197405, 35.862765720912385, 23.644155263900757, 23.697107485362462, 30.69313226427351, 38.768227917807444, 28.59037808009556, 18.77299210003444, 31.29658678599766, 25.774347884314402, 20.725425481796265, 20.20389195850917, 21.650463478905813, 12.350857257843018, 6.462549039295741, 4.811119002955301, 1.006352765219552, 0.18110745613064083, 0.925508303301675, 4.287475398608616, 15.78579476901463, 38.47231456211635, 59.999688965933665, 49.867009367261616, 50.11162417275565, 37.76442166737148, 37.18396915708269, 48.75011076245989, 60.05089718954903, 63.993916511535645, 50.667219502585276, 18.958927631378174, 3.0621705651283264, 0.12390976319355623, 0.16059980727732182, 0.12844430415758065, 0.13437027617224626, 0.130344812891313, 0.16049962836716855, 0.17694410096321786, 0.06525914357709033, 0.11889852423753057, 0.1822432151862553, 0.21079020122332232, 0.07010605492229972, 0.12470917244042669, 0.14615535736083984, 0.10608095023781061, 0.11809303531689302, 0.1342337006436927, 0.08685567150158541, 0.1876849846116134, 0.19060816775475228, 0.12814880215695926, 0.15714592832539762, 0.08166901767253876, 0.1917310075036117, 0.15748967416584492, 0.27215895748564173, 0.11702917383185454, 0.07583762665412255, 0.06842644326388836], [0.045269081235996315, 0.051036347302475145, 0.02471815372285034, 0.07344831486365624, 0.058848636490958076, 0.03229602432942816, 0.052159064915031195, 0.0158939499940191, 0.015025087598977345, 0.0382866403753204, 0.02712449334960963, 0.023504061192008, 0.038713455865425725, 0.012605143345094152, 0.04152354079165629, 0.05035016519416656, 0.06943229679018259, 0.028935396445116827, 0.03626373749492424, 0.02258828658211444, 0.030974441673606634, 0.031209883147052357, 0.0074836984276771545, 0.03488685762775796, 0.040746648729379685, 0.01753759420742946, 0.09336977731436491, 0.175938661343285, 4.421730663095202, 20.344205617904663, 43.393060071127756, 47.871722970690044, 49.195542403629844, 46.20647600718907, 34.68699850354876, 24.037192276545934, 27.53286746570042, 14.928008386066981, 35.26214953831264, 33.0271190234593, 24.517804384231567, 13.729170543806893, 2.2125057578086853, 0.3786956864808287, 0.4190591020243508, 2.4151438900402615, 2.5720122839723314, 10.539705072130475, 12.476661341530935, 9.405247500964574, 11.646826692989894, 7.704882604735238, 13.336427961077009, 9.015669822692871, 17.234615768705094, 12.458074041775294, 9.69088968208858, 30.040630408695765, 31.317375796181814, 37.533897808619905, 47.04095813206264, 56.09740693228585, 58.6646203994751, 58.22631761005947, 55.328620025089805, 55.07817568097796, 51.70024640219552, 54.934858662741526, 52.23742205756051, 57.8771949495588, 56.12675959723336, 56.753765038081575, 51.07556165967669, 46.56391218730381, 42.107851777757915, 49.00380686351231, 49.43706178665161, 57.094834736415315, 53.8562376839774, 57.475717612675254, 58.32304000854492, 62.854008947099956, 58.24836424418858, 59.60248129708426, 55.907908712114605, 56.01204136439732, 49.95503609521048, 50.852854524339946, 29.895750045776367, 32.430838516780305, 52.47035346712385, 49.70206955501011, 56.64944131033761, 52.12633425848824, 53.35465070179531, 48.43545464106968, 51.70432499476841, 51.76823105130877, 54.1821950503758, 53.5950722694397, 51.37283338819231, 49.74602038519723, 48.82841696058001, 51.20549644742693, 53.22207907267979, 50.56184312275478, 48.85688720430647, 50.60543612071446, 50.852663448878694, 50.93807765415737, 53.64317464828491, 53.35463333129883, 55.17793096814837, 54.68682186944144, 54.655426434108186, 43.75976514816284, 31.741837774004253, 21.51205710002354, 21.830970730100358, 15.729403189250402, 8.626185945102147, 18.209111043385096, 26.095339025769913, 8.812861459595815, 9.069873588425772, 9.37262223448072, 4.461676725319453, 5.713266159806933, 4.915556073188782, 0.7725105445299829, 1.2266716744218553, 0.3992295132151672, 0.2111352634217058, 2.9209323610578264, 10.664358360426766, 18.017573526927404, 26.69205379486084, 18.938334907804215, 23.177722692489624, 30.431480475834437, 32.31719030652727, 41.21548421042306, 43.352763993399485, 46.436117444719585, 42.81124223981585, 23.90425065585545, 4.751968554088047, 0.09831473018441882, 0.21168674954346248, 0.04674689657986164, 0.053059273931596956, 0.10005165769585542, 0.04127790093688028, 0.03941829090139695, 0.04800589795091322, 0.027839750683467303, 0.0329423187566655, 0.0522959152502673, 0.017065534002280662, 0.033833632179136784, 0.03924926104290145, 0.027152908699853078, 0.02352980481061552, 0.02109704981558025, 0.08797099308243819, 0.024765798755522286, 0.030664612406066487, 0.017554294650575945, 0.016752152603917887, 0.037832849725548706, 0.0438759538478085, 0.0260896222732429, 0.037199277829911025, 0.05112173075654677, 0.020311749008085047, 0.014563660037570765, 0.01279574298366372, 0.05069934610011322, 0.02712979440444282, 0.024554007620151554, 0.01736681712126093, 0.06047908828726836, 0.03279659318338547, 0.031731798712696345, 0.07182722006525312, 0.009259024235819067, 0.035650983053658686, 0.024634604009666612, 0.010124434583953448, 0.02810222838473107, 0.023363378830254078, 0.057238622169409475, 0.04761616100690194, 0.05887286697647401, 0.010821547891412462, 0.03725036473146506, 0.022548005350732377, 0.08604290190019778, 0.007676181849092245, 0.0476255722876106, 0.013173065281340053, 0.044208039063960314, 0.008098682704647737, 0.21761643993003027, 5.130533337593079, 22.608357770102366, 48.274551732199534, 56.32570736748831, 54.875698225838796, 48.19377892357962, 37.43049471718924, 27.14460039138794, 30.68004185812814, 20.600856440407888, 26.18176940509251, 34.948000635419575, 24.674854516983032, 12.057861277035304, 2.7950175404548645, 0.3315054758318833, 0.5420691413538796, 2.291683954851968, 5.316121459007263, 11.066430636814662, 11.168828845024109, 11.592825293540955, 11.970074261937823, 9.616929582187108, 12.579981054578509, 7.566704647881644, 6.6122418982642035, 6.757021078041621, 12.703523499625069, 19.91098369870867, 25.021984781537736, 36.35656377247402, 46.875990527016775, 55.66732038770403, 59.77960477556501, 59.76471478598458, 58.79798412322998, 56.48822920663016, 53.554407937186106, 55.359775747571675, 55.84512826374599, 58.803681646074565, 59.79598862784249, 58.48629488263811, 54.567924295152935, 47.450519698006765, 44.320755754198345, 51.11573614392962, 52.45112085342407, 58.851881299700054, 56.42422587530953, 58.40094321114676, 58.55887576511928, 62.16396944863455, 57.156902994428364, 60.59556647709438, 55.97039038794381, 53.969368253435405, 50.438946860177175, 51.11102873938424, 34.19618122918265, 39.2316449710301, 52.633629185812815, 50.570121901375906, 58.20525067193167, 55.330044405800955, 54.251072543007986, 51.14160081318447, 53.42211423601423, 54.798854623522075, 55.70440639768328, 54.805458886282786, 53.82807663508824, 51.291706221444265, 52.42709745679583, 54.43215649468558, 54.93666866847447, 52.82736233302525, 53.67058529172625, 55.31882653917585, 54.58488137381417, 54.53483697346279, 54.7554110118321, 55.537726061684744, 56.952160426548545, 56.584579876491, 51.50918483734131, 43.66907031195504, 32.18383353097098, 26.80961905206953, 16.141789197921753, 15.544112103325979, 9.222815598760333, 9.914074506078448, 21.2198315007346, 14.726013830729894, 10.650545341627938, 16.627138239996775, 13.817615900720869, 8.14579791682107, 6.190754617963519, 4.144477128982544, 1.5093737904514586, 0.5881948662655694, 0.31837853736111094, 2.5587123462132046, 10.49801674910954, 23.02775624820164, 30.156665325164795, 19.942005668367656, 26.68595675059727, 31.108349663870676, 35.36587572097778, 45.70745985848563, 48.30614171709333, 52.76418931143624, 49.00541189738682, 27.761091470718384, 6.033339270523616, 0.12537898149873528, 0.07556642977786915, 0.08952857700309583, 0.027269652346149087, 0.054350213945976326, 0.021396085287311246, 0.051274065260908434, 0.028859434449779134, 0.016696112396727716, 0.03741105878725648, 0.007421867772271591, 0.0075225335313007236, 0.027361751600567783, 0.014118360405388688, 0.014593476562627723, 0.04811554581725171, 0.04031896810712559, 0.03712748543226293, 0.017194944201037288, 0.0031013556248841007, 0.014731359967429723, 0.04100279230624437, 0.010658897958429796, 0.035259661730378866, 0.02619846098657165, 0.004696072162395077, 0.005672027739430112, 0.03146468661725521, 0.03631683286013348, 0.14095908190522874, 0.2132325880229473, 0.14804548450878688, 0.12723083927163056, 0.1119965881641422, 0.07700179597096783, 0.10607035152081933, 0.18290341618869985, 0.20376802874462946, 0.11167318480355398, 0.10411486787987606, 0.10736849757709674, 0.09735170578850166, 0.0970782358199358, 0.1589195645813431, 0.20256214988018784, 0.1255079031522785, 0.1699914647532361, 0.09279412177524396, 0.09411535837820598, 0.10449572280049324, 0.1625229383685759, 0.14236852127526486, 0.17290209499853, 0.10238586565745728, 0.1083689635353429, 0.21631122353885854, 0.4926555614386286, 6.612518523420606, 28.808181524276733, 55.63868686131069, 62.773666926792686, 63.024844305855886, 57.38210105895996, 46.03086028780256, 33.89473710741316, 38.48577322278704, 25.124734742300852, 45.376756872449604, 43.56986393247332, 31.09928921290806, 17.04974157469613, 2.884469300508499, 0.8273034957902772, 0.6150599675519126, 7.991025924682617, 9.176804627690997, 17.310552631105693, 21.085515873772756, 20.250474418912614, 22.38312496457781, 19.55405126299177, 27.550427300589426, 19.929504122052872, 26.491669484547206, 19.882833072117396, 17.57582269396101, 35.501622676849365, 34.99346964699881, 41.46382325036185, 50.03416912896292, 57.987160614558626, 62.615685735430034, 61.98076629638672, 60.0535375050136, 59.98814105987549, 57.37964834485735, 58.02005686078753, 58.04473686218262, 60.89839676448277, 61.450292178562705, 62.270971706935335, 57.511365345546174, 52.10201556341988, 47.26311983380999, 51.82010282788958, 54.20480101449149, 61.43657643454415, 59.451691491263254, 61.086088453020366, 62.70208658490862, 64.28239182063511, 60.012216567993164, 59.26181806836809, 53.46180234636579, 54.92798689433506, 51.57606472287859, 52.37935291017805, 39.38594709123884, 44.25756883621216, 54.24742473874773, 53.07034778594971, 59.08847440992083, 56.00758409500122, 57.53942911965506, 53.4570324080331, 56.02470793042864, 56.84670761653355, 57.540718010493684, 57.4876754624503, 55.30688953399658, 55.07616070338658, 54.174468653542654, 56.675962584359304, 57.72423035757882, 54.74210868562971, 54.017724241529194, 57.355510302952354, 56.47932161603655, 56.211326122283936, 57.510225840977256, 58.34879698072161, 58.41840403420584, 60.76025268009731, 57.394830158778596, 48.486127853393555, 38.969882011413574, 29.055132661546978, 26.979295798710414, 21.272029842649186, 13.247392007282802, 28.17141386440822, 38.77673946108137, 19.705650533948624, 17.357810803822108, 23.83842168535505, 15.003328595842634, 15.859753131866455, 14.920401845659528, 5.796202029500689, 3.1671682681356157, 1.1744165526969093, 0.42022821786148207, 4.053133504731314, 13.354240536689758, 24.93076535633632, 34.27352510179792, 28.416928461619786, 33.41068043027605, 40.77992943355015, 45.620926993233816, 53.270626136234824, 55.55853591646467, 59.35008798326765, 55.344767638615195, 32.75899151393345, 8.164369583129883, 0.29429830663970535, 0.34963202316846165, 0.19605940952897072, 0.15744767284819058, 0.16310824267566204, 0.13273082700158867, 0.13169384907398904, 0.1857813410460949, 0.09068498387932777, 0.09204036436442818, 0.11220903069313083, 0.10197894820677382, 0.11195702957255499, 0.08984189054795674, 0.12449117270963532, 0.1029589766902583, 0.09405800181307963, 0.11321223793285233, 0.13164568665836537, 0.13653142377734184, 0.08852163782077176, 0.12037877552211285, 0.15639161451586656, 0.13768904523125716, 0.11348264092313391, 0.06652866902628116, 0.13267596065998077, 0.10583251821143286, 0.12570249342492648], [0.025546337943524122, 0.06517950392195157, 0.016646877895774584, 0.05182880835075464, 0.039254210955862484, 0.021416208939626813, 0.023807425717157975, 0.05629419641835349, 0.03476103687924998, 0.018467526450487118, 0.07499595824629068, 0.08257115712123257, 0.01242524929278131, 0.0729046386799642, 0.033017476688006094, 0.035521379472421746, 0.02879958426845925, 0.11103105997400624, 0.11657372755663735, 0.01769307711427765, 0.03127635583015425, 0.03998735786548682, 0.0328359380364418, 0.021446525884260024, 0.037206758678491623, 0.021685466902064424, 0.008386986296890038, 0.20812487495797022, 4.4182804482323785, 26.436677966799053, 46.971055780138286, 47.05541385923113, 43.9360339982169, 43.30424472263881, 28.331069571631296, 19.203375680106028, 20.16188488687788, 32.924539293561665, 46.362362316676546, 32.64479439599173, 19.57916031564985, 5.042965190751212, 0.6626102360231536, 0.07154584516371999, 0.3252238157604422, 1.2567942866257258, 4.765865385532379, 12.684521045003619, 11.798269629478455, 7.874126826013837, 10.485805290085928, 9.592514480863299, 7.677410296031407, 5.656498943056379, 6.10717864547457, 7.084167889186314, 21.348671947206768, 28.316803182874406, 35.73989030293056, 51.75161790847778, 54.50363956178938, 58.76009559631348, 56.29709815979004, 54.145838601248606, 54.8671623638698, 53.70637198856899, 50.481007780347554, 53.02201264245169, 53.87855529785156, 54.776345934186665, 54.0095705304827, 53.12110785075596, 50.70723417827061, 45.39498199735369, 40.19582217080252, 43.709095409938264, 45.408030714307515, 51.837216241019114, 51.451573848724365, 52.87524584361485, 55.16673047201974, 59.24120276314871, 57.00016205651419, 55.26754535947527, 50.36642851148333, 51.890098980494905, 50.20420544488089, 51.37160703114101, 34.93083163670131, 37.03480175563267, 49.46223163604736, 51.20142132895333, 59.919235774448936, 55.52669927052089, 52.65640538079398, 49.75533791950771, 45.16742501940046, 48.41026742117745, 48.597278186253135, 46.90431833267212, 45.73211554118565, 48.09315511158535, 50.19379356929234, 52.00429957253592, 52.37972811290196, 53.14401606151036, 51.58831092289516, 49.00725317001343, 50.04524803161621, 48.57623209272112, 48.491384165627615, 52.72268424715315, 49.2289319719587, 44.90716634477888, 44.58336639404297, 39.93118265696934, 38.60648775100708, 27.6650447845459, 17.308409111840383, 15.444136210850306, 13.976670588765826, 8.851786136627197, 13.189981647900172, 14.908489159175328, 10.612087062426976, 9.978954178946358, 9.605150648525782, 5.249347099236079, 3.486715921333858, 3.040044678109033, 0.47207222878932953, 0.5416215253727776, 0.0620902900450996, 0.5750275413904871, 5.465508162975311, 13.685415131705147, 30.491175924028667, 59.767466272626606, 50.99511194229126, 33.299095835004536, 16.791702849524363, 33.67530952181135, 39.994275774274556, 49.65435627528599, 46.003592082432334, 22.96102922303336, 6.835272124835423, 0.28769301250576973, 0.15656675797488007, 0.050849743386996646, 0.026147012765120183, 0.06304220003741128, 0.014440756989642978, 0.05982641223818064, 0.046893887620951445, 0.07187504999871765, 0.021586746842201267, 0.006842190640911992, 0.03144267154857516, 0.044336523062416484, 0.06148331332951784, 0.09165214733885867, 0.08288969538573708, 0.03392278828791209, 0.023970101095203842, 0.05579405504145792, 0.0159093883620309, 0.021458975305514674, 0.03430986876732536, 0.03167963294046266, 0.03162766733605947, 0.00431827743471201, 0.054241366750959835, 0.06806384772062302, 0.02029983393315758, 0.03916589283783521, 0.07799666401531015, 0.04289155559880393, 0.03455379871385438, 0.026738659678293124, 0.008244172487008785, 0.06821404144700084, 0.036458867202912054, 0.04672230986346092, 0.07058476816330637, 0.057344643266073296, 0.030567734568778957, 0.06654272827186755, 0.04900226216497166, 0.035149752628058195, 0.07550712581723928, 0.05395570011543376, 0.025275171601346562, 0.012100200484772878, 0.014488732808136513, 0.07281621878168412, 0.017145358558212007, 0.044798561305339844, 0.0032704902322231127, 0.013134898534709854, 0.007234503049403429, 0.06520121704254832, 0.00862081624966647, 0.2954928268279348, 6.1133008769580295, 32.51079143796648, 53.24564388820103, 54.36718736376081, 50.506552832467214, 50.647733279636924, 34.00573110580444, 27.183779546192714, 25.631532873426163, 34.282658508845735, 43.44742972510201, 27.862580333437236, 20.472283499581472, 6.107772282191685, 0.7408474407025746, 0.12639116575675352, 1.7553257984774453, 2.930111365658896, 7.2196690525327405, 8.769340549196516, 12.951578531946454, 11.090910008975438, 11.887305583272662, 10.292001792362758, 13.662019678524562, 11.260406970977783, 8.410325390951973, 9.984511000769478, 20.68967526299613, 25.77303293773106, 36.99158048629761, 48.94516406740461, 54.631493364061626, 58.09864446095058, 59.47796263013567, 55.97534792763846, 57.335944175720215, 55.16381222861153, 54.63600621904646, 54.10103661673409, 55.07955142429897, 56.50812537329537, 55.61430215835571, 56.12962225505284, 53.80633919579642, 48.067238330841064, 41.903067520686555, 44.965284551892964, 48.381029401506694, 54.46184614726475, 54.35576452527727, 55.46784455435616, 56.313294410705566, 59.59547751290457, 55.72250298091343, 54.8766188621521, 51.31290170124599, 52.330263887132915, 51.578031063079834, 52.65686396190098, 39.26832798549107, 43.02049766268049, 51.95347349984305, 52.99324015208653, 58.59177548544747, 58.54130377088274, 55.924514906747, 51.58206101826259, 48.45136601584298, 50.14497900009155, 50.696718079703196, 49.28129012244088, 47.06546095439366, 50.014939989362446, 52.169076102120535, 53.507156712668284, 54.0704402242388, 55.1533899307251, 55.31108972004482, 52.69571828842163, 52.56140960965838, 53.781228406088694, 53.1846421786717, 55.324339934757774, 53.17556088311331, 49.260476793561665, 46.791483061654226, 43.300145285470144, 38.44359070914132, 27.172858715057373, 20.34396764210292, 15.152277129037039, 10.381090726171221, 5.042222602026803, 10.503795913287572, 14.068025503839765, 14.3301454271589, 12.70976037638528, 14.125700763293676, 9.989377345357623, 9.479726978710719, 6.07813126700265, 1.8205688404185432, 0.6731138495462281, 0.2561277805694512, 1.0041456265108926, 6.390718127999987, 15.266283171517507, 31.36997365951538, 47.315700326647075, 45.84120225906372, 38.78700195040022, 25.239558935165405, 41.28753355571202, 46.294447149549214, 55.152299063546316, 52.826243673052105, 26.391875982284546, 8.631833093506948, 0.32462369224854876, 0.08799750344561678, 0.062349612558526654, 0.04798384556280715, 0.07219716414277043, 0.05783738861126559, 0.07116125151515007, 0.03217780656580414, 0.055525253393820355, 0.018785077446539487, 0.051379126230520863, 0.04934539732390216, 0.06047707303826298, 0.052806628202753406, 0.04248204953702433, 0.027569544468341128, 0.055515618196555545, 0.0320179267520351, 0.06773361151239701, 0.07559283836079495, 0.07547868162925754, 0.02745273127220571, 0.03382551011496356, 0.039570523625505824, 0.02846478151955775, 0.011402435783695961, 0.03150767859603677, 0.020687489470999156, 0.05707175683762346, 0.1752419958689383, 0.14605762117675372, 0.11807388705866677, 0.12281958812049457, 0.1285453923046589, 0.13205848022231034, 0.23021205833980016, 0.1408588080001729, 0.12279909636293139, 0.18542901852301188, 0.1796771857355322, 0.16112717826451572, 0.1289161845509495, 0.15489320563418524, 0.2074826822749206, 0.12609293604535715, 0.11325302467282329, 0.24827533907123975, 0.14764623450381414, 0.11151537791426692, 0.10870790534785815, 0.1428266138370548, 0.14369824635131018, 0.23821022201861652, 0.12378724691058908, 0.1970677939908845, 0.12198528860296522, 0.4873169021947043, 9.461033718926565, 38.14487722941807, 60.94075298309326, 61.13825552804129, 56.58564642497471, 55.7077693258013, 37.548270157405305, 31.746149131229945, 27.495876993451798, 44.768980571201865, 59.22126143319266, 39.88369171960013, 25.242416381835938, 6.207404238837106, 1.0797538608312607, 0.16444244608283043, 1.514853747827666, 2.4051011375018527, 12.065615466662816, 24.18309576170785, 23.493843146732875, 16.160104649407522, 18.622353417532786, 15.777132102421351, 15.342225245067052, 17.036256858280726, 12.61540036542075, 11.81296420097351, 26.54473635128566, 32.48193209511893, 39.03644922801426, 54.36460958208357, 55.45365285873413, 62.748438017708914, 60.09333678654262, 59.69608742850167, 59.24296065739223, 57.996749128614155, 56.504689489092144, 56.15538270132882, 57.401674134390696, 57.32285724367414, 57.220409529549734, 57.90400109972273, 55.34223502022879, 48.98419904708862, 43.46546377454485, 47.64013256345476, 48.94525786808559, 56.078469617026194, 56.46085330418178, 57.08021572657994, 58.724770954677034, 60.68159212384905, 57.503795283181326, 55.00234651565552, 51.10570294516427, 50.8083096231733, 51.4533908026559, 52.82049403871809, 41.32600225721087, 48.470348494393484, 53.61308200018746, 55.50761604309082, 61.364711216517854, 60.323641777038574, 57.36259746551514, 54.518050125667024, 49.18480396270752, 53.05017716544015, 53.145360537937705, 51.05836139406477, 49.47692012786865, 53.51442800249372, 54.347284248897004, 55.84959595543997, 55.9152946472168, 56.538940634046284, 56.130108628954204, 54.48148175648281, 55.35320969990322, 56.381129673549104, 54.020743233816965, 60.20892701830183, 57.715110846928184, 53.574265888759065, 49.492640427180696, 45.21669122150966, 42.96272686549595, 32.436334541865754, 22.28994962147304, 22.70315204347883, 21.32549623080662, 15.47327869279044, 20.970974820000784, 21.978114468710764, 21.357239076069423, 15.885497944695608, 16.24212292262486, 16.458031245640345, 10.476896830967494, 10.297082662582397, 2.5733791249138966, 1.963450402021408, 0.23852598507489475, 1.1702058357851846, 7.195407680102757, 18.921956266675675, 40.51932334899902, 68.6746608189174, 59.71636227199009, 44.178880487169536, 28.582974774496897, 46.284045696258545, 53.22561223166329, 61.86473832811628, 60.7338147844587, 33.298974241529194, 11.413733737809316, 0.8073008805513382, 0.1994206141680479, 0.16557796086583818, 0.1977956449346883, 0.13570393675139972, 0.13698334167046206, 0.16231720655092172, 0.1431835096861635, 0.17119941993483476, 0.059290545992553234, 0.14179681480995246, 0.1799329255840608, 0.17642736940511636, 0.15431170112320355, 0.1863786554230111, 0.18810815976134368, 0.12844766969127314, 0.11717691804681506, 0.16767798603645392, 0.17398585113031523, 0.1451713458767959, 0.10347208487136023, 0.12656147804643425, 0.08486646467021533, 0.1308651678264141, 0.06781367864459753, 0.10495330646101918, 0.09894485172948667, 0.10060208530298301], [0.013387384807824023, 0.03569808016930308, 0.01755469668257449, 0.07777672367436544, 0.017671849146219235, 0.04930313477026565, 0.05964607120092426, 0.043958911539188454, 0.04126591122310076, 0.05772248549120767, 0.05585802053766591, 0.04757223264979465, 0.03124166912000094, 0.06688789225050382, 0.06982531784368412, 0.07410587636487824, 0.05896471347659826, 0.06619280097740037, 0.023183738380404453, 0.07585659849324397, 0.01084893271659634, 0.012976799875364771, 0.011126545989619834, 0.10692279506474733, 0.028372670390776226, 0.09273358288088016, 0.044006894143032174, 0.725084203694548, 12.314499071666173, 30.270431654793875, 46.571742807115825, 49.27766663687569, 41.534274509974885, 37.987062794821604, 22.10199737548828, 16.65810636111668, 28.604703528540476, 35.13019282477242, 34.40411302021572, 28.832126753670828, 11.437735421316964, 2.92049549307142, 0.34566131766353336, 0.16744462427284035, 2.158187129667827, 3.0837258313383376, 3.9700239300727844, 6.975951433181763, 7.475845660482134, 11.926096507481166, 7.153663771493094, 6.233984138284411, 14.017495598111834, 6.957786670752934, 6.159717449120112, 13.502376130649022, 28.901985679353984, 38.7179160118103, 47.525834696633474, 54.31881400517055, 56.22691787992205, 58.07340860366821, 55.07773447036743, 55.393321650368826, 49.34157269341605, 51.955776827675955, 51.28166954857962, 52.41776255198887, 55.02784987858364, 57.2271214893886, 55.664304869515554, 55.99683175768171, 53.47169310706002, 45.662977491106304, 41.10360779081072, 43.72773742675781, 41.5737750189645, 44.73907552446638, 48.23174040658133, 50.859406675611226, 52.898181847163606, 55.11983707972935, 55.4514468056815, 54.26626130512783, 53.2837165423802, 50.74742603302002, 49.28767899104527, 44.64285339627947, 29.639410155160085, 35.0435904775347, 41.710074356624055, 52.323465074811665, 57.21207863943917, 57.01271397726876, 51.45438092095511, 46.00622544969831, 42.913696902138845, 44.48867286954607, 44.72011041641235, 44.12439618791853, 46.27550983428955, 48.628294944763184, 49.57814843314034, 52.092364515577046, 52.931109360286165, 52.383497510637554, 48.862939085279194, 51.17244734082903, 50.689220973423545, 49.5065507207598, 47.01186949866158, 42.68614687238421, 42.47553307669503, 41.70603745324271, 38.15266268593924, 31.561094284057617, 24.56007375035967, 23.186123064586095, 15.566464458193098, 13.371479885918752, 8.505535687719073, 2.9710217075688496, 11.921426449503217, 13.343015721866063, 10.908828990800039, 19.276667015893118, 21.525595664978027, 8.126137120383126, 7.1656672188213895, 5.043964862823486, 2.6001151416982924, 0.5659999858055795, 0.2412653395107814, 0.40436917170882225, 3.4765858820506503, 10.828177775655474, 19.90748528071812, 37.36414984294346, 38.18867519923619, 24.921776124409266, 24.995685849870952, 36.150351660592214, 39.146050112588064, 43.91479335512434, 42.37709447315761, 30.635795729500906, 9.941268018313817, 0.8342163562774658, 0.08598015776702336, 0.016810610092111995, 0.0178412013088486, 0.10458273134593453, 0.016147674593542303, 0.09446750448218413, 0.022967402756746327, 0.04431421961635351, 0.021816437731363943, 0.026677781516419988, 0.016713674579347883, 0.04538235587200948, 0.051079495344311, 0.09086700089808021, 0.08301814206476722, 0.026140239289296523, 0.010695917132709707, 0.023060044839179943, 0.04713517128090773, 0.01634600359414305, 0.057113262824714184, 0.07040022699428455, 0.015546908169718725, 0.017276756864573275, 0.031106620295239345, 0.03596712948222246, 0.09347668729190316, 0.06034677395863192, 0.03082580179242151, 0.05025084463081189, 0.04899757688066789, 0.033627045407359085, 0.04029891400464943, 0.13814683923763887, 0.017446507666526095, 0.038713713708732805, 0.023823627437065755, 0.02606081506902618, 0.03465479186603001, 0.0703938351944089, 0.03568106929638556, 0.02139485883526504, 0.03792469622567296, 0.011656585315774595, 0.043909802567213774, 0.07575473003089428, 0.07038230009909187, 0.019861537630536726, 0.031587922147342136, 0.04127440648153424, 0.00654538330854848, 0.027079369074531963, 0.013901455660483666, 0.05547587300783821, 0.08951259071805648, 0.9381678125688008, 14.674748284476143, 35.204482964106965, 52.65195853369576, 55.91152177538191, 45.74156509126936, 43.35839898245675, 24.726288557052612, 18.04220141683306, 23.066737379346574, 30.357152121407644, 34.58322715759277, 29.33409936087472, 11.677019221442086, 3.579197747366769, 0.21419120872659342, 1.101902655192784, 3.4806408073220934, 5.235569255692618, 10.631574153900146, 9.092406596456255, 8.58929535320827, 11.555582080568586, 9.388480629239764, 8.351835455213275, 15.461551870618548, 7.07169109582901, 7.506328276225498, 15.66458865574428, 28.64548945426941, 36.13346406391689, 48.12627717426845, 53.647524220602854, 58.16924510683332, 60.288998058864046, 57.735472542899, 59.04638917105538, 52.67197976793562, 54.504786014556885, 53.370760100228445, 55.124144962855745, 58.18458672932216, 58.35178470611572, 55.88599756785801, 57.58649621691023, 56.53451810564314, 48.6915409224374, 43.24174220221383, 44.78817844390869, 43.883919034685405, 47.016906942640034, 50.30625363758632, 51.760424750191824, 54.13788638796125, 56.67936372756958, 55.47807577678135, 51.95421348299299, 53.2458245413644, 50.58734648568289, 49.38919217245919, 46.54760823931013, 34.38503674098423, 40.40851695196969, 46.993686062949045, 52.82052877971104, 57.83881310054234, 59.99457509177071, 54.34788874217442, 48.63806758608137, 45.814965861184255, 45.234725270952495, 46.59567935126168, 45.067971978868755, 48.95269938877651, 51.49586514064244, 50.91329342978341, 54.10154383523123, 53.57715286527361, 55.69450521469116, 52.566398416246685, 53.25578825814383, 53.852728843688965, 52.501999037606375, 50.3692946434021, 47.585981777736116, 47.75959989002773, 47.215437820979524, 42.37354394367763, 33.88200453349522, 26.43536475726536, 23.682045527866908, 16.760272673198156, 13.284971339362007, 10.037433692387172, 7.556547250066485, 7.506951008524213, 9.42127091544015, 6.76067887033735, 12.603536316326686, 13.367090361458914, 9.222562858036586, 10.79076520034245, 6.5198525701250345, 3.7365753139768327, 1.006880828312465, 0.3651191507066999, 0.4313910688672747, 3.2395763141768317, 11.225721563611712, 24.837887048721313, 44.71778971808297, 45.74784278869629, 31.58012887409755, 26.43654247692653, 40.02481658118111, 44.65579094205584, 48.920049803597585, 49.428241048540386, 35.604122502463206, 12.789431027003697, 0.9846039265394211, 0.13518979719706944, 0.07193329544471842, 0.007090628180386764, 0.044458048684256415, 0.013335169841801482, 0.025929686480334828, 0.056826195014374595, 0.11490552207188946, 0.0440077864165817, 0.03286765954856362, 0.07009384807731424, 0.03853751173509019, 0.015998149224157845, 0.05428708304784127, 0.06561311494026865, 0.05007158924958535, 0.027177011960053017, 0.03868919484583395, 0.027927205365683352, 0.048137343754725795, 0.051506283693015575, 0.03808205867452281, 0.020328235712700655, 0.01783283836474376, 0.05739502449120794, 0.07984996028244495, 0.037234877169664414, 0.01877065857739321, 0.16501926870218345, 0.12778212183288165, 0.08406934887170792, 0.22726503147610597, 0.10849844837295157, 0.20650922879576683, 0.1407930308154651, 0.09943647070654801, 0.17081853108746664, 0.09764388296753168, 0.13014341012707778, 0.16250178164669446, 0.16871325405580656, 0.1728572981165988, 0.16650060564279556, 0.09785237642271177, 0.11597288479762417, 0.1615719986813409, 0.2220773734152317, 0.15511508658528328, 0.08461955256227936, 0.21254654840699264, 0.14628582607422555, 0.24178933139358247, 0.15939409126128468, 0.16832416850541318, 0.15795783618731157, 1.6947388095515115, 19.198862825121196, 44.13587461199079, 59.44118581499372, 63.04391016278948, 52.05716494151524, 49.785705021449495, 30.975284712655203, 23.052349397114344, 38.405042103358674, 44.80206789289202, 44.30752638408116, 35.223521028246196, 14.205786568777901, 3.7924935477120534, 0.8705451211759022, 0.9037375886525426, 5.1353718893868585, 7.908464823450361, 13.823388985225133, 14.049360036849976, 15.555239643369402, 23.40699413844517, 17.829911368233816, 14.758616515568324, 21.545391082763672, 13.147838217871529, 11.152951342718941, 18.550590685435704, 34.40506839752197, 41.9123329435076, 51.331519399370464, 55.89087520326887, 60.73951230730329, 62.41665458679199, 60.224900926862446, 59.80576474325997, 54.169771671295166, 57.21618849890572, 56.475691182272776, 56.371287550245015, 59.60009806496756, 60.19354370662144, 57.29834747314453, 61.1585442679269, 57.14284678867885, 51.47562851224627, 44.941737106868196, 46.85996103286743, 46.519408975328716, 49.48927402496338, 51.745076179504395, 53.8664550100054, 56.89610930851528, 58.62985161372593, 55.84691047668457, 52.052103178841726, 50.81185320445469, 49.2062599999564, 49.926228863852366, 47.308213642665315, 38.03532498223441, 45.594926834106445, 49.837868622371126, 55.43218987328665, 61.64969852992466, 62.20722893306187, 56.74947452545166, 50.41267572130476, 46.471327441079275, 48.403875078473774, 49.18096855708531, 49.052913257053916, 51.28503247669765, 53.3149174281529, 52.44927610669817, 55.4688937323434, 54.78963783809117, 57.21374273300171, 53.81338119506836, 54.99264683042254, 56.24065099443708, 54.11232743944441, 51.91437251227242, 49.26871735709054, 50.20948954990932, 52.783668586185996, 49.12814835139683, 39.69411359514509, 33.055773394448416, 28.357314654758998, 20.545328174318584, 19.489962816238403, 15.4308443069458, 7.206168268408094, 18.473521266664775, 21.078225476401194, 18.361761229378835, 31.435724462781632, 35.07937370027815, 17.90155598095485, 18.3724718775068, 11.883412855012075, 5.85034282718386, 1.0585926877600806, 0.4889683478644916, 0.5831026509404182, 4.165775963238307, 13.259251713752747, 27.7472437109266, 48.13444478171212, 48.11390243257795, 34.891650744846885, 36.40679924828665, 48.91869143077305, 50.24417495727539, 55.66663599014282, 57.059642110552105, 42.470693656376426, 16.100989375795635, 1.6925083292382104, 0.3474567213228771, 0.15782629538859638, 0.06673514044710568, 0.19885637158794062, 0.1582351941615343, 0.13916658237576485, 0.11592267320624419, 0.171782254374453, 0.14937924008284295, 0.14892139179365976, 0.25431736771549496, 0.12153159294809614, 0.16355815210512706, 0.16386711624051842, 0.1805238617318017, 0.14176751566784723, 0.1122200908139348, 0.11610211857727595, 0.1589616880353008, 0.20001879706978798, 0.18056365102529526, 0.14247080364397594, 0.11396854663533823, 0.09371995566678898, 0.1651001229350056, 0.17229289268808706, 0.1617144774645567, 0.0974533571196454], [0.041651013772934675, 0.007349529153933483, 0.054327028404389105, 0.04008593882567116, 0.07306357193738222, 0.03674336675820606, 0.06196530389466456, 0.02458881985928331, 0.026334534399211407, 0.0387094016186893, 0.04685172684756773, 0.02662396351141589, 0.03457590199208685, 0.07229324470141105, 0.04000243491360119, 0.017645823935578977, 0.026572988568139926, 0.024864347485293235, 0.05797963669257505, 0.018285828343193446, 0.0362222382931837, 0.023596582834475806, 0.02506380794303758, 0.0158448003099433, 0.08602407255343028, 0.05208976613357663, 0.08883434746946607, 1.556169907961573, 15.400173221315656, 39.83456795556204, 49.785062313079834, 52.908308846609934, 48.65122052601406, 35.13291651862008, 32.99354532786778, 32.13483483450753, 34.89079959051949, 44.48947538648333, 27.71667684827532, 15.156574589865548, 6.111039672579084, 1.0540336923939841, 0.03445019320185695, 1.310311809182167, 4.065040111541748, 4.980956426688603, 8.40291861125401, 5.111748014177595, 10.482592616762433, 6.7464407086372375, 8.762163928576879, 6.600501613957541, 17.336062942232402, 9.632221698760986, 11.720499311174665, 27.930233206067765, 42.206158365522114, 43.65538930892944, 57.133459772382466, 57.22580133165632, 61.17746421269008, 53.56376716068813, 54.33646937779018, 50.726807253701345, 51.58523287091936, 50.78631510053362, 53.58352436338152, 53.74367686680385, 56.01360123498099, 52.09319829940796, 53.29215860366821, 53.40372930254255, 51.67914472307478, 42.80249793188912, 41.80090468270438, 43.569895199366975, 43.3002529825483, 48.94608122961861, 51.614460468292236, 49.93159287316458, 52.40218121664864, 58.334490639822825, 55.05578163691929, 52.24803195680891, 50.177771023341585, 48.32974474770682, 50.84867170878819, 36.42555243628365, 26.696776832853043, 32.14847762244088, 43.44753394808088, 52.610571588788716, 58.294170243399485, 54.34351485116141, 48.68083374840872, 42.84206444876534, 41.02817814690726, 42.25751250130789, 43.30384520121983, 42.90649856839861, 44.36171538489205, 48.355904715401785, 49.969266005924766, 50.27972194126674, 50.18254443577358, 49.27425854546683, 48.20419774736677, 47.93068538393293, 50.83577585220337, 52.75554575238909, 53.8125057220459, 52.23722403390067, 47.029160090855186, 43.65059157780239, 39.918453557150706, 39.2910590171814, 36.78734513691494, 27.770105021340505, 20.539608069828578, 15.537024940763201, 9.678244829177856, 8.411690711975098, 5.470025794846671, 5.60844042471477, 7.359296577317374, 8.746397597449166, 8.388551473617554, 5.46264203105654, 7.526853254863194, 4.730180740356445, 2.291544556617737, 1.3812321807656969, 0.25297302699514795, 0.08679745319698538, 1.3837729415723254, 4.875956986631666, 18.63464478084019, 27.589670726231166, 39.587184292929514, 25.419416529791697, 20.560636792864116, 25.095248324530466, 31.213809422084264, 44.386141777038574, 48.37577656337193, 36.78803300857544, 14.916415316717965, 2.5914689770766666, 0.16036047440554413, 0.04250438690983823, 0.008299150786894773, 0.03430524115849819, 0.0667481818901641, 0.04273053245352847, 0.018491466862282584, 0.011171280107061778, 0.038231268525123596, 0.03124759273071374, 0.09010212908365897, 0.015978213865309954, 0.062183317196156294, 0.055890105066022704, 0.04410341914211001, 0.05107183129127536, 0.023377768861662065, 0.012928408454172313, 0.0322099046648613, 0.020860902665715133, 0.03853467545871224, 0.028227915122572864, 0.021743586819086756, 0.03934871731325984, 0.011815937568566628, 0.038091856720192094, 0.044424488342234066, 0.046795788420630355, 0.03454037729118552, 0.03981511175100293, 0.04894456972501107, 0.03701053652912378, 0.030218075295644145, 0.0315024945884943, 0.07584961636790208, 0.06416999987725701, 0.005837096225669873, 0.036870734566556554, 0.07148830539413861, 0.02658369924340929, 0.08011726236769132, 0.030636032511081015, 0.011826062159213637, 0.03475336604086416, 0.023448066785931587, 0.033356255652116876, 0.047928042842873504, 0.017740075842344334, 0.03492071991786361, 0.02932043114144887, 0.025418668187090328, 0.03040993446484208, 0.050050140757645876, 0.07589439289378268, 0.06371146626770496, 1.9289532474109103, 17.518689393997192, 46.54280355998448, 55.723371505737305, 57.738825048719136, 52.014694077628, 39.75675507954189, 28.826225996017456, 27.511784894125803, 29.80706671306065, 37.47032873971121, 32.05241182872227, 16.497689826147898, 6.569088808127812, 1.3547762632369995, 0.17633261877511228, 1.3777299629790443, 3.7238162500517706, 7.792963181223188, 9.457017660140991, 11.388543043817792, 11.643968377794538, 12.808728780065264, 8.272236023630414, 10.668814761298043, 15.469009024756295, 7.156932464667729, 9.974627188273839, 23.012412888663157, 36.663465704236714, 44.26823084694998, 55.947113922664094, 56.93642970493862, 61.380712917872835, 55.71744816643851, 56.75645399093628, 52.426333154950825, 53.717815671648296, 53.1370643888201, 54.433560030800955, 55.05323164803641, 56.761140550885884, 53.564052036830354, 54.57460151399885, 56.087707247052876, 55.02279159000942, 45.78439378738403, 43.22327389035906, 45.23269987106323, 44.76082338605608, 49.05179112298148, 52.393506390707834, 52.194176469530376, 54.344251360212056, 59.046694891793386, 54.5217604637146, 51.93534564971924, 50.50629227502005, 48.758559771946494, 50.02670676367623, 39.4772082056318, 31.334120954786027, 37.613954952784944, 45.66387728282383, 53.96234709875924, 59.105837958199636, 56.636027812957764, 50.65076616832188, 45.802907262529644, 43.81504849025181, 43.486801692417686, 46.171606472560335, 44.384196281433105, 46.87222112928118, 51.22240488869803, 53.28461633409773, 53.220102310180664, 52.90019335065569, 51.79934508459908, 51.218687602451865, 51.22377715791975, 51.955314772469656, 54.96914802278791, 55.60006182534354, 53.28515829358782, 47.77449335370745, 47.883934429713655, 46.36100046975272, 46.737047399793354, 39.601678235190256, 28.124285970415386, 20.007754734584264, 15.00000388281686, 9.546234267098562, 8.397229773657662, 4.668075135775974, 4.98486522265843, 10.43396999154772, 8.683107325008937, 13.047256963593618, 14.437608003616333, 12.942716104643685, 6.680771546704428, 5.097060390881129, 2.118596076965332, 0.656678917152541, 0.1952440682798624, 1.6779992963586534, 5.406773737498692, 20.881824220929825, 30.95372792652675, 39.075056893484934, 26.198566675186157, 26.301837750843593, 30.840604305267334, 37.6651805468968, 49.06723696844918, 54.65022918156215, 43.87057154519217, 18.33344210897173, 3.156450237546648, 0.1536789129355124, 0.016816479420023303, 0.04328651386978371, 0.04813223438603537, 0.061141175617064746, 0.07515310017125947, 0.050793523368026526, 0.023805529211780856, 0.023075120190956762, 0.03320557677320071, 0.05934526305645704, 0.040912587860865254, 0.050854340461747985, 0.033449289588523765, 0.01966119507726814, 0.032318358309566975, 0.006003137985577008, 0.014160895221201437, 0.01842775072769395, 0.07951822451182775, 0.08095461529280458, 0.03069931947227035, 0.030807756153600555, 0.017122759949415922, 0.0452175295379545, 0.07576353741543633, 0.09361434169113636, 0.0622567618265748, 0.13674921994762762, 0.12844002938696317, 0.1274077740630933, 0.18770249081509455, 0.12588815417672905, 0.07110600519393172, 0.1964461337774992, 0.07392500607030732, 0.09179553535899945, 0.09097573613481862, 0.19933604156332357, 0.07592171071363346, 0.13171231879719666, 0.1419375701142209, 0.08286399247923068, 0.15568029268511704, 0.10434947814792395, 0.0808262364672763, 0.21184112983090536, 0.2250706220843962, 0.1526866504656417, 0.13234220285500797, 0.13544115370937757, 0.14240571856498718, 0.11136966930436236, 0.17472276730196817, 0.24461241705077036, 2.68587132862636, 21.585094826562063, 52.77519178390503, 61.881420952933176, 65.51872648511613, 60.655508586338584, 46.38406154087612, 41.823910168239046, 44.62994016919817, 46.604131834847585, 55.08312279837472, 36.37458392551967, 19.862066643578665, 8.510891880307879, 1.6055850620780672, 0.4379806752715792, 2.509524528469358, 9.37367228099278, 12.188023618289403, 13.888863597597394, 15.105637345995222, 17.11243690763201, 15.959885358810425, 16.912483385631017, 18.69908584867205, 26.774212769099645, 15.478104216711861, 17.531937871660503, 31.009487220219203, 45.51044716153826, 44.05243369511196, 59.657872336251394, 58.874178068978445, 64.33110564095634, 57.113125869206016, 58.389020102364675, 54.84954520634243, 57.487272466932026, 54.866828850337434, 57.66749831608364, 57.8150189944676, 58.00344024385725, 53.81333603177752, 54.757780347551616, 57.34989963259016, 57.0999242918832, 46.8885042326791, 46.476156439099995, 47.48679624285017, 46.98162399019514, 51.72082349232265, 54.46947874341692, 53.14289392743792, 56.57499483653477, 61.987339292253765, 55.176565647125244, 51.95635005405971, 49.54991790226528, 48.944934776851106, 50.74109969820295, 41.58361019407, 35.2606383051191, 41.68286173684256, 48.64517559323992, 54.7549524307251, 61.92662593296596, 58.71902479444231, 51.81556912830898, 46.91116925648281, 44.330035073416575, 46.23654433659145, 49.19420140130179, 47.29713126591274, 48.577649525233674, 54.07653726850237, 54.73269387653896, 54.754931586129324, 55.46365826470511, 53.824189117976594, 53.33547019958496, 53.85973262786865, 56.05385214941842, 58.4909918648856, 57.91821711403983, 55.655095032283235, 49.12282950537545, 50.61765800203596, 48.86978306089129, 50.89948388508388, 45.22144726344517, 34.83817393439156, 27.330937181200298, 20.96859506198338, 14.298825553485326, 12.024780035018921, 11.043588433946882, 11.223567622048513, 13.988378303391592, 15.495571987969534, 14.663528680801392, 13.761310304914202, 20.023360388619558, 15.75757987158639, 6.629827354635511, 4.279365113803318, 1.2382356481892722, 0.3646827984069075, 2.165549180337361, 6.5343634486198425, 23.68086086000715, 35.8486921446664, 50.875620297023225, 35.568620681762695, 32.744278703417095, 35.64632586070469, 44.39548363004412, 56.13503837585449, 62.17433616093227, 51.42461831229073, 23.569474288395472, 5.142388267176492, 0.18017176991062506, 0.11164683728877987, 0.10782574875546352, 0.17685232231659548, 0.10623566300741263, 0.19503057402159485, 0.08064378518611193, 0.07899921307606356, 0.08536577823438815, 0.10163348567272935, 0.22005010076931544, 0.19814305486423628, 0.12373179702886514, 0.1457011324486562, 0.15874933371586458, 0.13150806618588312, 0.08184891087668282, 0.09481555901999984, 0.10367093634392534, 0.188022555783391, 0.18888425454497337, 0.21449021196791104, 0.08411530604852097, 0.11761618804718767, 0.18927424933229173, 0.15595318589891705, 0.17293329403868743, 0.23027863619582994], [0.019876685924828053, 0.04015834190483604, 0.04650234916646566, 0.026832999794610908, 0.04781962312491877, 0.020634048052930405, 0.01736003516374954, 0.053576524568987746, 0.04464156865807516, 0.07453677324312073, 0.031342143192887306, 0.05974509660154581, 0.009486425069293805, 0.015917225441496288, 0.07921866487179484, 0.03747964510694146, 0.024414229406309978, 0.015531697110938174, 0.028574463312647173, 0.03225280504141535, 0.03087190485426358, 0.059861974258508, 0.0018088337757425116, 0.0562249112075993, 0.06053759157657623, 0.04871612734028271, 0.05499898502603173, 1.3467615161623274, 19.83206605911255, 35.913282598767964, 49.238145283290315, 49.11724315370832, 35.869745186397004, 27.547705343791417, 24.038430792944773, 23.338026319231304, 31.54561022349766, 31.838244029453822, 24.247585466929845, 14.187759467533656, 1.9640501184122903, 0.5359558665326664, 0.05612448123948915, 1.5186971873044968, 2.903901892048972, 5.4852184653282166, 10.220795784677778, 10.396654691014971, 6.854847805840628, 13.054209504808698, 5.015106388500758, 7.324584245681763, 15.569799593516759, 7.837849412645612, 15.88678162438529, 33.3393988609314, 50.450953347342356, 55.088344369615825, 59.13629886082241, 54.517080851963584, 56.888146672930034, 55.920780250004356, 54.017578329358784, 51.453203201293945, 52.019300733293804, 52.391182218279155, 55.075017724718364, 53.969788619450156, 55.548301219940186, 53.570399216243196, 54.88524852480207, 53.5097588130406, 48.03835466929844, 42.15761825016567, 38.82402195249285, 43.37585285731724, 49.591461181640625, 53.28252492632185, 52.47178479603359, 53.949360915592735, 56.109486375536235, 59.80791173662458, 55.99201318195888, 51.700597286224365, 51.46467815126692, 51.7577531678336, 42.948604651859824, 29.2131381716047, 29.41423988342285, 28.42137704576765, 46.94693510872977, 54.06480870928083, 54.51844269888741, 51.59429332188198, 45.2316437448774, 38.82495648520333, 43.018493107386995, 42.14270394189017, 42.50304446901594, 41.096350397382466, 42.484353814806255, 43.40174184526716, 41.31541667665754, 45.714842319488525, 45.87207657950265, 45.56415326254708, 42.946857179914204, 44.562122276851106, 46.32664162772042, 49.05355943952288, 52.44998829705374, 55.75164719990322, 53.92737681525094, 51.03223269326346, 44.647136960710796, 40.78721114567348, 39.903480189187185, 41.16757638113839, 34.58923734937395, 29.82127230507987, 19.56960654258728, 14.721502712794713, 10.382907680102758, 6.968478645597186, 3.329385037933077, 7.288550887789045, 9.842659183910914, 11.92640049116952, 8.431517396654401, 2.9893716829163686, 4.532845386437007, 0.8782882371119091, 0.6028819467340196, 0.14823018174086297, 0.4767843016556331, 2.903572286878313, 9.27840987273625, 24.546766213008336, 35.38450384140015, 20.72291544505528, 20.707132611955913, 22.82318217413766, 32.89083010809762, 38.53219066347395, 45.88379124232701, 38.08335440499442, 23.122698170798166, 4.98769965342113, 0.4649943485856056, 0.03561456947188292, 0.08031228690275125, 0.09236678042049919, 0.013403960570160831, 0.026750652784747735, 0.08088248702032225, 0.08441323041915894, 0.020151424753878797, 0.021172962617129087, 0.07640459015965462, 0.08306963608733245, 0.03583677611978991, 0.02685976291208395, 0.06929939892143011, 0.05453336411820991, 0.011022151680663228, 0.029774347320199013, 0.03875351996560182, 0.03589366788842848, 0.029026907070406845, 0.0268645058718643, 0.020192398090979884, 0.05432534563754286, 0.041787205929202695, 0.026003319404221008, 0.007820535933465829, 0.04404371823849423, 0.024711972268830453, 0.05121913445847375, 0.05337003279211266, 0.07343519878174577, 0.024043442249032, 0.00980379625356623, 0.05951287477676358, 0.10982773918658495, 0.039296884023185284, 0.026997651405898587, 0.060181367477136, 0.02944154285692743, 0.04840324805783374, 0.02096606880825545, 0.07575468931879316, 0.04979131696745753, 0.057154368476143906, 0.052542552551520724, 0.03514117594542248, 0.10802832538528101, 0.04509436186136944, 0.05419820174574852, 0.07124815149498837, 0.047312754073313305, 0.04721377956281815, 0.013871958895054246, 0.1046569902183754, 1.8513470802988325, 24.002932446343557, 42.02097845077515, 55.18693583352225, 53.78194407054356, 40.721786907741, 30.347504547664098, 30.03939710344587, 28.54158956663949, 32.766651902879985, 33.733556270599365, 23.692365339824132, 13.163050430161611, 3.3938617152827124, 0.6237698601824897, 0.3676390397761549, 2.12395487512861, 4.060483396053314, 9.193313547543116, 11.099337305341448, 11.130446996007647, 11.856768250465393, 8.49988419669015, 8.091083458491735, 6.640433779784611, 11.611896361623492, 8.711399521146502, 17.407254184995377, 31.33355815070016, 47.51875448226929, 56.394689083099365, 60.960124560764854, 56.60067537852696, 57.85231692450387, 58.28222976412092, 56.23101036889212, 54.19883598600115, 53.48641286577497, 54.46085602896554, 56.20713288443429, 55.58212505068098, 57.38243109839303, 53.14682313374111, 55.92959751401629, 55.1762182371957, 51.27466923849923, 44.60575001580374, 40.92838117054531, 44.85269594192505, 51.255467891693115, 54.53132118497576, 55.78647157124111, 55.152194840567454, 57.978680338178364, 59.761977195739746, 54.88589470727103, 51.8263874735151, 51.93231276103428, 51.75696107319423, 46.37689099993025, 34.412273679460796, 34.717928409576416, 33.56894302368164, 46.97703470502581, 53.4379700251988, 56.04358271190098, 53.29399987629482, 46.21818024771554, 40.86896365029471, 45.16157463618687, 43.73268801825387, 45.063247203826904, 43.022154808044434, 45.13109983716692, 44.594757965632844, 45.510683400290354, 48.379539012908936, 49.007294859204976, 47.4681715965271, 46.76789740153721, 46.53624793461391, 49.85577065604073, 50.77580942426409, 54.67054918834141, 54.88763175691877, 53.39529071535383, 49.61482102530343, 45.67775978360857, 43.65364531108311, 44.86363935470581, 45.79681716646467, 37.60706581388201, 30.662428174700054, 24.824423176901682, 16.20652903829302, 10.241738523755755, 7.9179604053497314, 6.342107662132808, 13.150085091590881, 13.442480053220477, 13.765978625842504, 10.71841447693961, 9.26669955253601, 6.652945748397282, 3.5351813435554504, 1.0119928568601608, 0.6426238513418606, 0.6901260795337814, 3.84233558177948, 11.796022755759102, 26.84752321243286, 40.92680392946516, 21.49012337412153, 18.441495282309397, 25.618096794400895, 36.37285382407052, 44.963491916656494, 51.8550557409014, 43.60336119788033, 26.110725811549596, 7.201922050544193, 0.7772671292935098, 0.04010999628475734, 0.07379441522061825, 0.039157367045325894, 0.016639101884460876, 0.035683220252394676, 0.03867466401840959, 0.04621499637141824, 0.03592359806810107, 0.011984302462743861, 0.061236733703741004, 0.11764697996633393, 0.05524545269353049, 0.06792852069650378, 0.032190508741353235, 0.014435634050252182, 0.031878077292016575, 0.06281285520110812, 0.05772241085235562, 0.03134362918457814, 0.015259004064968653, 0.02013969627608146, 0.06816990952938795, 0.015372392355597444, 0.023541358565645557, 0.022017445248950804, 0.05031473209549274, 0.05773766431957483, 0.11608947068452835, 0.13851552802537168, 0.1771953081978219, 0.16279674081930093, 0.1410454594131027, 0.11504699662327766, 0.09811001616929259, 0.19314709651683057, 0.12202627211809158, 0.250043655612639, 0.12298947971846376, 0.11500959577304976, 0.0947825482913426, 0.12669156678020954, 0.2238161058298179, 0.09424645134380885, 0.22946735258613313, 0.1286505652325494, 0.12761212166930946, 0.18756484320121153, 0.12907566742173263, 0.14607030978160246, 0.10121616628021002, 0.18982783891260624, 0.24942222610116005, 0.12188181201262133, 0.24430539352553232, 3.329966732433864, 29.23006398337228, 49.73119987760271, 62.82787677219936, 59.9579233442034, 46.738513469696045, 36.441387380872456, 35.86862652642386, 34.61805847712925, 42.78150394984654, 43.57652725492205, 30.25720923287528, 18.083798544747488, 3.5692876619952063, 0.9278634169272014, 0.336617612945182, 4.438564845493861, 6.309367316109793, 12.55149257183075, 17.923296894345963, 21.550451108387538, 18.234899282455444, 21.1786356312888, 12.770074214254107, 14.142107197216578, 22.02233280454363, 13.245004432541982, 20.1174806867327, 39.01089027949742, 56.6670480455671, 60.48010131290981, 62.45928873334612, 55.75725439616612, 60.08611066000802, 59.70040920802525, 59.79768398829869, 55.89119134630476, 57.032075132642476, 57.49672201701573, 58.130453314099995, 56.47921739305769, 57.680845805576865, 53.698864459991455, 56.41843107768467, 57.40925809315273, 53.41616310392107, 47.32783188138689, 43.04639707292829, 48.18757765633719, 54.80226271493094, 57.7728990146092, 57.1150609425136, 57.94881698063442, 59.143010820661274, 62.856135095868794, 55.43928745814732, 50.69035700389317, 50.36064066205706, 52.270554542541504, 49.85260575158255, 40.77606623513358, 37.104940346309114, 37.12521171569824, 50.00387845720564, 56.57492535454886, 58.298832484654014, 55.40813173566546, 49.237492152622764, 41.486390999385286, 47.26097978864397, 46.37436185564314, 46.00204610824585, 45.981427328927175, 47.271402086530415, 46.175313336508616, 45.33928871154785, 50.13536269324166, 51.01026248931885, 50.50373533793858, 48.23109075001308, 49.889618805476594, 50.83692577907017, 52.97290277481079, 56.67443745476859, 57.99553319386074, 54.326481342315674, 52.089352471487864, 48.965018544878276, 47.49526262283325, 48.324484961373464, 48.93075697762625, 39.33921698161534, 35.27048390252249, 22.393436091286794, 17.973202330725535, 15.105150972093854, 14.971076795033046, 7.403346419334412, 15.582285506384713, 19.128814561026438, 20.911878653935023, 19.85734534263611, 12.602055481501989, 13.606474041938782, 4.451277877603259, 1.5771533591406686, 0.9524000031607491, 0.7322784119418689, 3.8938851356506348, 12.236561128071376, 31.908660548073904, 45.45035914012364, 31.29981075014387, 31.233292170933314, 33.76520878928048, 43.00660473959786, 49.98028932298933, 59.042338371276855, 51.018183435712544, 33.12041596003941, 9.486988714763097, 1.0223939844540186, 0.13926838976996286, 0.1537737992725202, 0.28635401864136967, 0.12912735821945326, 0.11763878326330866, 0.118959049561194, 0.1776947642543486, 0.10375192628375121, 0.08074541616120509, 0.15184703123356613, 0.2242720542209489, 0.10739872631217752, 0.17953394699309552, 0.21507186575659684, 0.11852785412754331, 0.09825220996780054, 0.15618501417338848, 0.11085093606795583, 0.14959312789142132, 0.11988508701324463, 0.09202640689909458, 0.07895519650940384, 0.1465486226869481, 0.1278139315545559, 0.07151453755795956, 0.08321675605007581, 0.12151871435344219], [0.046027015029851875, 0.04915495290021811, 0.07123909305248942, 0.05899585823395422, 0.03752826553370271, 0.012838128521772367, 0.04699117936460035, 0.018944711291364262, 0.02550725602278752, 0.04027122977588858, 0.05364233907312155, 0.03849179543820875, 0.017974223010241985, 0.046439554143164835, 0.028530809762222425, 0.005139559257908591, 0.0533804550899991, 0.04017783282324672, 0.07085142564028502, 0.027677984542346427, 0.021608610936839665, 0.06903905860547509, 0.008448710083030164, 0.08518876880407333, 0.02404507073307676, 0.0020567045264345196, 0.15048004101429666, 5.520591310092381, 24.470943995884486, 44.46288463047573, 48.17117295946394, 42.47299698420933, 38.83442340578352, 24.424828801836284, 18.056170770100184, 26.65896299907139, 37.776997906821116, 29.22094099862235, 21.59136210169111, 7.596566268375941, 1.494702126298632, 0.16537190335137503, 0.26758926840765135, 0.3306540229490825, 1.7132190636226108, 8.375137976237706, 8.747030752045767, 6.442523896694183, 13.465216296059744, 11.817977326256887, 8.021107281957354, 9.617259621620178, 13.516617332186017, 8.221442086356026, 16.20405547959464, 24.12661211831229, 31.98610864366804, 42.70779398509434, 49.32926048551287, 54.57547351292202, 56.08361823218209, 53.46060378210885, 49.028764792851035, 49.4904864856175, 50.044556685856406, 54.54460266658238, 54.54710749217442, 55.13803441183907, 55.36230836595808, 55.50540999003819, 52.5764594078064, 50.598564352308, 43.98055110658918, 39.901628494262695, 42.63156877245222, 51.0084524835859, 52.534749371664866, 53.3405111176627, 50.74573414666312, 57.80173403876168, 56.31031363351004, 55.39528104237148, 55.6183876991272, 52.530907017844065, 49.676604407174246, 46.330060141427175, 39.196678161621094, 48.06880862372262, 30.6307270186288, 30.359517983027867, 59.24385002681187, 54.434091567993164, 54.00522443226406, 45.409496784210205, 39.071610586983816, 42.89846297672817, 50.27633816855294, 51.76178659711565, 49.185425826481406, 47.484673568180625, 48.5586462020874, 44.5314598764692, 42.53587818145752, 41.6199631690979, 39.22461339405605, 38.579427991594585, 39.58453702926636, 42.40720101765224, 46.51115798950195, 48.617532185145784, 51.44850621904646, 51.99006271362305, 52.75441667011806, 50.62387663977486, 51.64207260949271, 50.61016436985561, 45.53848314285278, 44.68578631537301, 41.10965967178345, 35.35377195903233, 28.92932336671012, 21.96790930203029, 10.900783845356532, 5.316103654248374, 10.073934316635132, 8.99539932182857, 15.22323387009757, 20.154339143208094, 8.06216766153063, 6.485518915312631, 5.047709941864014, 3.9543322920799255, 0.5126869465623582, 0.052812243080032725, 0.1720273412231888, 1.2731067027364458, 6.547842085361481, 18.375466551099503, 25.79135881151472, 27.48655424799238, 30.4069915499006, 17.98119797025408, 18.521085160119192, 32.22054433822632, 44.271697998046875, 42.931574617113384, 32.04186446326119, 6.131687981741769, 1.0827807784080505, 0.035815911167966466, 0.033142873352127414, 0.06330019940755197, 0.03648542845621705, 0.029572646000555584, 0.040422729682177305, 0.059683478836502345, 0.01729572022200695, 0.058221032310809405, 0.010720930478003408, 0.049303501179175716, 0.05741598443793399, 0.023195149643080573, 0.03484872056703482, 0.03080529985683305, 0.037013101391494274, 0.009037374834796148, 0.08097784154649292, 0.012235464744402893, 0.06731393081801278, 0.06162049275423799, 0.022477208703224148, 0.026458387396165302, 0.008592931853075112, 0.018638476563085402, 0.04146588906379683, 0.013012802943454256, 0.05422951952953424, 0.02504164698932852, 0.044841984153858254, 0.06009864727301257, 0.06942342833748885, 0.052628214204949994, 0.031590653250792196, 0.05479901736336095, 0.008760041457467845, 0.04333014027880771, 0.049079944246581624, 0.028932404105684588, 0.044490581045725515, 0.02447967410885862, 0.04113361046516469, 0.009597949933127632, 0.01926144295638161, 0.06518628927213804, 0.023845812139500464, 0.06924833916127682, 0.029257083112107854, 0.0617560369095632, 0.021458408728774105, 0.053757008098598034, 0.07768007993165936, 0.041374215590102334, 0.21839387821299688, 6.182128429412842, 28.7209347316197, 50.41192184175764, 54.89821038927351, 49.42076826095581, 41.28390312194824, 28.670501232147217, 23.491607563836233, 25.466077157429286, 40.296445982796804, 32.43703978402274, 22.32243071283613, 8.925681965691702, 1.8336239627429416, 0.22721989532666548, 0.7904251175267356, 1.7400232596056802, 6.04243619952883, 8.800371204103742, 11.254970874105181, 10.841203910963875, 9.61249315738678, 10.151219998087202, 11.594925386565071, 6.384448681558881, 8.75840321608952, 11.46143398966108, 17.918268135615758, 25.417978252683366, 35.57341146469116, 46.10878780909947, 51.85334300994873, 54.15963077545166, 57.55136265073504, 55.2260159764971, 51.882320472172324, 50.902238845825195, 52.14460802078247, 55.63178730010986, 56.33967672075544, 55.99096747807094, 55.480497223990305, 56.017450537000386, 54.8559444972447, 52.84752253123692, 47.28127200262887, 41.3527250289917, 43.79335968835013, 52.59296832765852, 56.07627746037075, 54.49960265840803, 52.83294868469238, 60.30797358921596, 57.61785691125052, 56.10270145961216, 54.57276718957083, 52.78384576525007, 50.64089625222342, 48.08625207628523, 40.91438749858311, 51.000656604766846, 35.075163091932026, 32.38093308040074, 59.34113870348249, 55.82517998559134, 54.298723288944785, 47.325844696589876, 41.48731858389718, 43.175411224365234, 51.04336370740618, 53.00671965735299, 50.395666531154085, 49.50915976933071, 50.03958524976458, 45.990095206669395, 43.90671607426235, 43.03649588993618, 42.41662972314017, 41.20958866391863, 42.76929249082293, 44.31723996571132, 47.74745791299002, 49.47840009416853, 53.18468039376395, 55.067652634211946, 54.05971915381295, 51.64639786311558, 52.145587716783794, 49.845063482012065, 46.84554699489048, 44.9604937689645, 40.616566862378804, 36.55696024213518, 28.494020462036133, 19.671142305646622, 11.308067270687648, 7.951316101210458, 11.457408377102443, 14.095537764685494, 12.096871938024249, 17.161159413201467, 9.093572156769888, 6.77027302980423, 8.037987061909266, 4.484076849051884, 2.2057505888598303, 0.2749149767415864, 0.2941777988203934, 1.5763836290155138, 6.768164685794285, 19.47026641028268, 28.180370092391968, 28.512950829097203, 34.58902890341622, 25.08629035949707, 25.9110780102866, 38.96890926361084, 49.62098755155291, 49.78798055648804, 38.39781945092337, 8.647923384393964, 1.0843166559934616, 0.06451451924762555, 0.048015767242759466, 0.032858730027718205, 0.03974727860518864, 0.0729505280032754, 0.07493282734815564, 0.004877412342466414, 0.03439920808055571, 0.026075476514441625, 0.04141711596665638, 0.006543860845600388, 0.059007854733083925, 0.025527406816503832, 0.04865989375061222, 0.05991546317402806, 0.03722176787310413, 0.02757356987733926, 0.037339663332594294, 0.08311310982597725, 0.054914018870996575, 0.021767649367185574, 0.041047375449644666, 0.07751015440693923, 0.011133804617981826, 0.06134801344679935, 0.10600025206804276, 0.02308813449261444, 0.18069232840623173, 0.10097487244222846, 0.10616239479609899, 0.1273795198649168, 0.12322308575468403, 0.0692887594923377, 0.1278683907751526, 0.15248808397778443, 0.12737357589815343, 0.17640173435211182, 0.1397904274719102, 0.1807330133659499, 0.11949585218514715, 0.10030811679150377, 0.11440753165100302, 0.05433141852595976, 0.16580216240669998, 0.1250196700649602, 0.1239018514752388, 0.18373534083366394, 0.149762164535267, 0.1499223666531699, 0.14345526296113217, 0.19097377599350043, 0.17948171336735996, 0.08538179166082825, 0.5225834612335477, 8.627047521727425, 34.304819788251606, 59.016852378845215, 60.630634035382954, 54.475940568106516, 49.30244391305106, 33.977073260716026, 27.48498569216047, 37.302661759512766, 51.03977148873465, 38.894626072474885, 28.50129348891122, 9.339568785258702, 2.471731973545892, 0.3404488930744784, 0.8625411220959255, 2.045056994472231, 8.235268133027212, 16.6748080934797, 17.75112748146057, 17.22296016556876, 25.035068239484513, 21.372467790331157, 16.78567007609776, 17.963570390428814, 19.789402382714407, 13.60587649685996, 20.343887737819127, 28.313058103833878, 39.12839126586914, 49.59291335514614, 56.87685585021973, 59.00244181496756, 59.62763377598354, 57.02341072899954, 53.3646456854684, 54.04806007657732, 54.515298639025005, 58.328786168779644, 57.00658219201224, 56.87683847972325, 56.4166453906468, 56.024318831307546, 56.64870827538626, 55.48668112073626, 49.73440647125244, 44.51632669993809, 46.53762020383562, 56.40510095868792, 58.778925214494976, 56.64257301603045, 54.49982500076294, 61.73472363608224, 57.95695332118443, 54.83922365733555, 56.8409823008946, 51.99718114307949, 52.30757107053484, 48.529620102473665, 48.6580228124346, 51.67093195234026, 39.158914702279226, 37.088202135903494, 59.03782899039132, 59.20981775011335, 55.74147851126534, 50.119743142809185, 42.92519964490618, 45.80676351274763, 53.49700192042759, 56.83311346599034, 52.793771266937256, 52.492737088884624, 51.34052773884365, 48.4292186328343, 45.708786964416504, 45.128504684993196, 44.636193547930034, 42.312413692474365, 44.13180644171578, 48.08260079792568, 51.10717248916626, 52.777672290802, 56.82990339824131, 57.411019461495535, 55.55218178885323, 53.28599207741873, 52.507891110011506, 53.025017738342285, 50.55956758771624, 48.76072760990688, 44.13235534940447, 38.4040276663644, 33.425247328622, 24.94154896054949, 13.20817984853472, 11.782477242606026, 20.09754283087594, 17.89065773146493, 24.05244878360203, 28.876098428453716, 18.934386593954905, 16.334087542125157, 10.199874758720398, 10.330177800995962, 3.4526119913373674, 0.5125246409858976, 0.7559033185243607, 1.7634447685309818, 8.53891830784934, 23.069679941449845, 35.40552909033639, 39.1858354977199, 42.706734384809224, 28.29667772565569, 29.155777318137034, 44.29352576392037, 56.104838030678884, 57.4150424684797, 45.52679279872349, 13.005224704742432, 1.69347326031753, 0.1538640580007008, 0.2019216399639845, 0.23443086338894709, 0.12289094286305563, 0.23175138288310596, 0.09445280741368021, 0.1962565646639892, 0.07695855293422937, 0.12012551911175251, 0.14168582005160196, 0.12016845680773258, 0.18917784307684216, 0.15317930760128157, 0.14437659138015338, 0.10715106103037085, 0.1323481196803706, 0.14102663685168537, 0.25333645035113606, 0.20531850840364183, 0.2271000931837729, 0.1715068777224847, 0.0729391761124134, 0.18373992773039, 0.10360110151980605, 0.1433655877730676, 0.19395714519279345, 0.10605775112552301], [0.028406503843143582, 0.07750955051077263, 0.056474958147321425, 0.03513878071680665, 0.04322148307359644, 0.025173267515908395, 0.018949316847803335, 0.0426725312801344, 0.047400865238159895, 0.07429693147007908, 0.08040234207042626, 0.019003733659961393, 0.018815686161230718, 0.03194215813917773, 0.012412763400269406, 0.026146673497610858, 0.0264047220615404, 0.018972946829827766, 0.02156345612768616, 0.029011046314345937, 0.023359916605321423, 0.020737833376707773, 0.054903864594442506, 0.020221212080546787, 0.10469832657171146, 0.10744634589978627, 0.21328157825129374, 8.288756234305245, 30.293819291251047, 42.63075930731637, 44.69052151271275, 35.0804819379534, 27.05321420942034, 18.26922685759408, 25.157888071877615, 36.615658623831614, 37.83864579881941, 25.563758407320293, 9.732271415846688, 2.7695652033601488, 0.32286604227764265, 0.1429681833833456, 0.21146490930446557, 2.8570677765778134, 5.080947084086282, 8.169681480952672, 9.874137129102435, 8.81485038144248, 8.051181691033499, 3.5833045669964383, 7.343670078686305, 3.530396206038339, 9.591545207159859, 13.798358099801199, 24.018928936549596, 31.012457575116837, 40.81982251576015, 48.44016899381365, 53.57996341160366, 52.52930545806885, 52.77200950895037, 55.27506678444998, 51.383544036320274, 48.380789688655305, 48.743367535727366, 53.35984100614275, 54.91594566617693, 52.18605749947684, 55.52110249655587, 54.28461844580514, 53.66612107413155, 45.56466048104422, 39.96567004067557, 41.525683062417166, 48.27548279081072, 52.32954127447945, 52.42836550303868, 53.736079011644634, 50.600075585501536, 52.55568081992013, 55.84853982925415, 51.6396164212908, 54.48095369338989, 55.627305712018696, 52.49154199872698, 43.09228645052229, 45.113774503980366, 52.629932744162424, 26.0515810080937, 43.98129456383841, 56.51047733851841, 55.28406817572457, 50.03120572226388, 40.594245774405344, 43.12522438594273, 50.68917581013271, 56.22439220973423, 54.58065686907087, 53.09768894740513, 51.10608509608677, 52.87537785938808, 50.66809844970703, 49.77459485190255, 49.99625628335135, 43.45498936516898, 38.632807527269634, 37.564341340746196, 39.629870550973074, 40.98446702957153, 43.61596523012434, 49.15492670876639, 50.142442907605854, 53.18885973521641, 51.183463709695, 46.60960701533726, 46.084965910230366, 46.20131002153669, 48.705541542598176, 45.95442662920271, 40.70862701960972, 40.6696754183088, 25.400409732546123, 20.905606167657034, 9.474509750093732, 10.062951820237295, 19.57546213694981, 10.055450371333531, 9.992629102298192, 6.74987485579082, 7.8145382063729425, 8.965780019760132, 2.2649155855178833, 1.0833202408892768, 0.6035540220992905, 0.13915594294667244, 0.7221821365611893, 3.2384441920689175, 10.362877760614667, 26.678892169679912, 30.666829858507427, 19.606001206806727, 16.896507740020752, 18.38148021697998, 26.171889066696167, 43.07207761492048, 45.42621067592076, 33.00132383619036, 11.432968088558741, 1.3750627232449395, 0.08275297057947942, 0.03103221214509436, 0.025146187183314135, 0.0306169113942555, 0.051196369608598094, 0.08110955197896276, 0.030401035478072505, 0.08023033344319888, 0.02378793988775994, 0.030940582776176076, 0.06632608561111347, 0.02984270633065275, 0.014780418049278004, 0.07015811212893043, 0.035120273674173016, 0.052949181624821255, 0.017847825506968156, 0.02522804564796388, 0.030366616789251566, 0.038948418971683295, 0.05185004649683833, 0.03754070308059454, 0.05005121623565044, 0.06423176692000457, 0.049934114662132094, 0.021770305831783583, 0.04458705854735204, 0.0095540385393958, 0.08724140508898667, 0.053860220060284646, 0.039948606730571816, 0.06953102363539593, 0.03283121543271201, 0.03435538150370121, 0.030320333915629556, 0.014108550485356577, 0.032213619644088407, 0.001305592554022691, 0.040379659671868594, 0.030786897987127304, 0.04003644308873585, 0.1479818243533373, 0.06082839811486857, 0.02149578243760126, 0.02556629365842257, 0.06503403958465372, 0.028048915888315866, 0.043982405814209154, 0.022777511339102472, 0.017225183114143353, 0.008821673641380454, 0.05552892426827124, 0.05027069517278245, 0.6012680647628648, 10.352782896586827, 35.38048430851528, 49.39306926727295, 50.825836454119, 39.78950888769967, 33.740664277757915, 22.961880377360753, 25.35318282672337, 39.14563322067261, 38.082711696624756, 28.57475331851414, 11.94564265864236, 3.3135440136705125, 0.47868164841617855, 0.16320627741515636, 1.004475665943963, 2.0660685641424994, 5.450174357209887, 8.251548630850655, 10.08406479018075, 7.845593179975237, 9.600355522973196, 10.492105569158282, 10.118016294070653, 4.929921039513179, 7.769375784056527, 12.733124562672206, 22.633150679724558, 31.310556139264786, 41.20467281341553, 48.67773832593645, 56.490490845271516, 55.47873932974679, 54.007340158735005, 55.66131019592285, 51.59770141329084, 49.491344588143484, 50.28241089412144, 54.4418283871242, 56.413897378104075, 53.70058066504342, 56.004130840301514, 56.280860219682964, 56.42374644960676, 49.47829587118966, 42.58318151746477, 41.49371092660086, 50.1680782863072, 54.187256813049316, 55.29924651554653, 56.090844358716694, 52.360071659088135, 52.484882150377544, 54.813765457698274, 51.046111719948904, 54.2759644644601, 55.827938420431956, 51.985935483660015, 44.28040756498064, 48.29464244842529, 56.16979326520647, 32.85924359730312, 45.75412048612322, 59.031645093645366, 56.83658409118652, 54.28028276988438, 41.54779917853219, 44.743855885096956, 53.0741171836853, 56.17103351865496, 56.68342842374529, 55.267910139901296, 54.01897144317627, 55.41129664012364, 52.98800121034895, 50.67835399082729, 51.08092219488961, 44.41537284851074, 40.868866375514436, 40.47360072817121, 42.34116881234305, 43.33180822644915, 47.613996914454866, 51.36673634392874, 51.12398712975638, 54.140478066035676, 53.327403341020855, 47.954184191567556, 47.24019772665841, 48.14739274978638, 48.60464327675955, 47.444217681884766, 39.6257016318185, 35.384813036237446, 23.32349763597761, 20.223096779414586, 7.615743296486991, 10.328219277518135, 11.559636354446411, 15.141314608710152, 15.259663275309972, 8.881275159972054, 9.71694368975503, 9.950018405914307, 6.989702352455684, 1.6403043419122696, 0.8493074093546186, 0.16147050341325148, 0.698344712810857, 3.6064761579036713, 12.274021472249713, 27.10833947999137, 32.95249884469168, 24.51807188987732, 17.5661838054657, 18.637880904333933, 29.187009470803396, 48.7866096496582, 53.18453795569283, 39.02343872615269, 13.280876244817462, 1.7534802917923247, 0.087825698378895, 0.06288315821439028, 0.022849912721929804, 0.05802235047199896, 0.01439766662328371, 0.0010297729459125549, 0.04614286809893591, 0.06552303263119288, 0.025362650032288263, 0.012452949636748858, 0.05220287113583513, 0.09326923878065177, 0.030848773595477854, 0.08256633273724999, 0.02022079478151032, 0.0596707495195525, 0.011907275167426892, 0.051068377548030446, 0.042670186941644976, 0.020301170647144318, 0.03728677492056574, 0.017696493538096547, 0.04542637922401939, 0.022417048092133234, 0.06387893549565758, 0.031820605375937054, 0.018195077677124312, 0.08921943644859961, 0.20397376056228364, 0.1464868217174496, 0.16178344376385212, 0.1299118125545127, 0.06722315640321799, 0.12107758516711847, 0.17814029034759316, 0.15495481661387853, 0.12450543551572732, 0.1665654464491776, 0.11590923821287495, 0.08386128967893974, 0.08427902297782046, 0.14072835285748753, 0.10722985930208649, 0.13132965218807968, 0.08941302927477018, 0.13653317439768994, 0.1438418650733573, 0.1579324725483145, 0.13239713705011777, 0.21830348377781256, 0.09525744816554443, 0.19861725584736892, 0.2735016425805432, 0.8508302047848701, 13.9257515839168, 43.16010781696865, 57.60768474851336, 57.11788885934012, 47.14461135864258, 36.94678544998169, 28.021157332829066, 36.29564196722848, 48.82991429737636, 49.65359544754028, 33.29906456811087, 12.956450956208364, 3.3792405341352736, 0.6562804813895906, 0.4030772681747164, 1.911783597299031, 4.836164219038827, 10.402042150497437, 18.00589186804635, 20.156262057168142, 18.239700487681798, 17.928721700395855, 11.68907174042293, 14.371240547725133, 10.107421159744263, 15.902620043073382, 20.832597970962524, 30.696140834263392, 35.3823881149292, 46.8052648135594, 53.1882517678397, 58.1317526272365, 58.092780181339805, 58.292516572134836, 58.75346006665911, 54.98018871034895, 51.55029385430472, 52.46504156930106, 55.22736392702375, 58.11788749694824, 52.87845591136387, 57.28133480889456, 56.40783854893276, 58.045066901615684, 50.94083956309727, 43.71699203763689, 44.420281750815256, 53.238018240247456, 56.213726724897114, 57.410644258771626, 58.27084861482893, 52.28965514046805, 52.74596071243286, 55.208558627537315, 51.78074128287179, 56.098595074244905, 55.391570704323904, 53.00157104219709, 48.40572329929897, 51.483000550951274, 53.603628976004465, 35.58759273801531, 48.20437492643084, 59.35577160971505, 59.30076272147042, 54.627873352595735, 43.76129027775356, 46.77913958685738, 56.66711057935442, 59.02088928222656, 58.502067293439595, 57.017699309757774, 55.04089512143816, 57.578088896615164, 54.84334046500069, 52.78240401404244, 54.172307763780864, 47.98885917663574, 44.59473017283848, 41.730922426496235, 44.23492118290493, 45.3241103717259, 48.82477263041905, 52.959999970027376, 54.27343184607369, 57.829902035849436, 56.172325883592876, 49.40107706614903, 48.40237774167742, 47.677204677036826, 51.62662328992571, 49.81117711748396, 44.81765617643084, 42.34267309733799, 29.848022869655065, 24.32782326425825, 16.869583470480784, 15.40520545414516, 31.46208940233503, 19.06734558514186, 18.715698991503032, 14.319283655711583, 15.746262993131365, 18.401365961347306, 7.85051337310246, 3.5257263651915958, 0.9341748782566616, 0.5432198824627059, 0.8862917476466724, 4.053802703108106, 14.041888986315046, 32.46485342298235, 40.30869913101196, 30.17816652570452, 25.738019227981567, 28.579260962350027, 37.47014808654785, 54.60703917912075, 60.847021784101216, 47.77572318485805, 18.3632880960192, 2.7873708307743073, 0.3511458347950663, 0.17384201527706214, 0.10632286154265914, 0.14951489280377114, 0.1158874300973756, 0.17041876539587975, 0.11233027133026294, 0.14203005443726266, 0.16667397134006023, 0.08262766551758562, 0.13844622245856694, 0.24341531842947006, 0.11171465686389379, 0.265028504388673, 0.0688170555180737, 0.08836124571306364, 0.0683305391243526, 0.1586757805198431, 0.14189873076975346, 0.14788658517811978, 0.16047765740326472, 0.08459496245320354, 0.12571268502090657, 0.1393840935613428, 0.15477348491549492, 0.1976063743765865, 0.14264019312603132], [0.06104243520115103, 0.022319045583052293, 0.013594091171398759, 0.03839920594223908, 0.059289032859461646, 0.04118901963478752, 0.038378568299646885, 0.05055619556722896, 0.01772414892911911, 0.038170933191265376, 0.0711903470967497, 0.007842511986382306, 0.03566922886031015, 0.010632714140228927, 0.04581959705267634, 0.10182843556893723, 0.022384315562833632, 0.02726526222457843, 0.014825827309063502, 0.04137837500976665, 0.01661930392895426, 0.0857664735189506, 0.07444002772016184, 0.04147568032411592, 0.04865315589787705, 0.017814696034682647, 0.7139014580420086, 12.917228375162397, 33.19413982118879, 50.000581536974224, 46.611420495169504, 34.253014019557405, 23.258492027010234, 13.994268638747078, 25.571356262479508, 23.00221119608198, 31.01061282839094, 21.99325806753976, 7.328949451446533, 1.187450721859932, 0.1907373879637037, 0.13580585271120071, 1.8386507672922952, 2.1931189809526717, 4.004107015473502, 5.73455240045275, 7.23641334261213, 5.562632254191807, 3.6551498089517866, 9.363063250269208, 9.468291980879647, 2.5414402101721083, 11.740053279059273, 22.407632998057775, 32.136245318821494, 40.833072730473106, 46.64649152755737, 55.34693200247628, 59.79078442709786, 56.53685964856829, 54.37398965018136, 53.41474567140852, 52.164910657065256, 48.92135606493269, 51.17664057867867, 51.236172744206016, 51.78771032605852, 53.03646489552089, 54.45201097215925, 52.654595375061035, 51.63438095365252, 42.758974415915354, 37.61359364645821, 41.9094946043832, 51.25721883773804, 51.84203829084124, 57.1183648109436, 50.8355257170541, 52.38788529804775, 53.89230925696236, 56.709911482674734, 54.859387329646516, 54.70686742237636, 52.627771854400635, 55.30360651016235, 43.25757714680263, 46.95916393824986, 49.702149459293906, 24.68228040422712, 53.389589718409944, 53.14731298174177, 53.808454922267366, 45.31802027566092, 43.65381554194859, 48.20405183519636, 52.56005471093314, 53.69180161612374, 52.35907111849104, 52.88317721230643, 52.47028398513794, 51.68160438537598, 50.61158527646746, 52.05121380942208, 50.28044802801949, 51.52193825585501, 48.26860754830496, 41.903463568006245, 38.02517366409302, 39.883636134011404, 41.73411512374878, 45.89936562946865, 46.716595377240864, 46.469569546835764, 49.39590760639736, 50.612234933035715, 47.98405449731009, 48.95233808244978, 45.60642262867519, 45.945772647857666, 42.19059787477766, 36.03811740875244, 26.737896272114344, 15.798947708947317, 8.315558910369873, 22.704883881977626, 6.010919604982648, 10.339274730001177, 17.69416614941188, 7.42637882913862, 3.8817483697618758, 6.858160359518869, 6.493291778223855, 1.519811178956713, 0.42574584750192507, 0.09898441032107387, 0.1482661169554506, 1.6132912657090595, 8.496635045324053, 20.921720777239116, 35.39011103766305, 41.51253359658377, 36.513579164232524, 28.696386745997838, 29.399919646126882, 35.784139905657085, 44.5677398954119, 39.61923285893032, 15.933058364050728, 1.6017154582909174, 0.06923244108578988, 0.020780877941953282, 0.04653527168557048, 0.05024263774976134, 0.03947005633796964, 0.018190494173073342, 0.004611731531830239, 0.02433614190002637, 0.04383340630946415, 0.07548877823033504, 0.05004674808255263, 0.049431554307895045, 0.017361278579171215, 0.031176312627004724, 0.03367405092077596, 0.02969161354537521, 0.02260659176058003, 0.03734782950154372, 0.024707420995192866, 0.027357062923588922, 0.05182091359581266, 0.07449533510953188, 0.06952219589480332, 0.032675315226827345, 0.04259303751002465, 0.039414932153054645, 0.08923059156430618, 0.034288793469646146, 0.03799443266221455, 0.036659886594861746, 0.03343035846150347, 0.029901525138744285, 0.023235912634325877, 0.02543533979249852, 0.032071303709277084, 0.03501183360016771, 0.017054292373359203, 0.02436019596643746, 0.015934865655643598, 0.029845172805445533, 0.05485487436609609, 0.05039209865831903, 0.029721642112625495, 0.027314820726002966, 0.03131844535736101, 0.0132496896964897, 0.04253211185070021, 0.010876790819955724, 0.03458900450329695, 0.011726816234711026, 0.04765621492905276, 0.0323177442353751, 0.02217054649788354, 0.9469822538750512, 14.507000531469073, 38.121333258492605, 54.35501759392874, 51.547170639038086, 39.10122380937849, 25.991131680352346, 17.070276975631714, 27.73154946735927, 28.582252161843435, 34.154648372105186, 23.82902945790972, 8.422088691166469, 1.2427811814205987, 0.17182676627167634, 0.2031881527176925, 1.143416404724121, 3.9036178248269215, 9.689674615859985, 10.063184584890093, 9.714926975114004, 11.733594928468976, 9.191556521824428, 9.217350840568542, 5.892008568559374, 4.008259866918836, 11.674395407949175, 23.965266261781963, 34.0981490952628, 46.08933285304478, 53.529804365975515, 60.04210077013288, 60.83208315713065, 58.53676659720284, 56.414557456970215, 55.96091999326433, 52.3043783732823, 49.90655851364136, 51.334239619118826, 54.26972845622471, 52.780642645699636, 52.73516321182251, 54.4874050957816, 54.108988830021445, 53.51220457894461, 45.70843955448696, 39.18241350991385, 44.25483819416591, 54.298723288944785, 53.346733229500906, 56.67955480303083, 52.20162493841988, 51.130296094076975, 53.85372938428606, 57.35340847287859, 56.019660064152305, 55.47829811913626, 54.95574494770595, 56.121423380715505, 46.27653121948242, 47.877795696258545, 50.60034309114729, 28.098324026380265, 53.420394556862966, 54.963919503348215, 56.3839749608721, 48.05667706898281, 45.71645082746233, 50.21911627905709, 53.66280678340367, 54.27040243148804, 53.437904017312185, 54.08384329932076, 54.15165424346924, 53.04529605593, 52.54341377530779, 54.10948910032, 53.80333062580654, 53.84481137139456, 49.53531626292637, 42.868283476148335, 40.065800530569895, 40.941308294023784, 44.678136348724365, 47.612694127219065, 50.423306465148926, 50.84188331876482, 51.95068032400948, 51.81683717455183, 49.399187156132285, 48.47353424344744, 47.14567790712629, 46.56134482792446, 43.487350600106375, 37.140073912484304, 25.339291640690394, 19.980199916022165, 8.3862099306924, 8.96326390334538, 14.331391760281154, 13.452623554638453, 14.95006891659328, 12.958315679005214, 11.535609483718872, 7.482106855937412, 6.3368913020406445, 2.4532095960208347, 0.8980602047273091, 0.2504199168511799, 0.07638926205358335, 2.00597511444773, 8.938077551977974, 23.674815927233013, 35.007518904549734, 39.672126020704, 35.32241473879133, 33.95474522454398, 31.869003704616002, 40.47802325657436, 51.90806007385254, 45.9116187776838, 21.6664981842041, 2.148820306573595, 0.12055070272513799, 0.05794955723519836, 0.06519165648413555, 0.021476863184943795, 0.035455860131021054, 0.030292761645146778, 0.019515272728832703, 0.016024642623960972, 0.042013398970344236, 0.05176256297688399, 0.001130344982292237, 0.016103269565584402, 0.03519086167216301, 0.017077778166692172, 0.07539581214743, 0.03502589623842921, 0.04344869730994105, 0.01768800336867571, 0.02369552681089512, 0.04173099948093295, 0.06910858808883599, 0.04015713071982775, 0.04865673177742532, 0.037234225776046515, 0.03791178709694317, 0.03289780007409198, 0.05357440753972956, 0.12548496866864817, 0.07364402471908502, 0.1150011955095189, 0.10319978198302643, 0.17098630565617765, 0.15052231374595845, 0.14323020646614687, 0.1266463492065668, 0.1864200189177479, 0.07002487499266863, 0.20727088435419969, 0.12629699866686547, 0.12606261910072394, 0.14765806815453938, 0.1401639338582754, 0.20144503696688584, 0.0837447445041367, 0.1246959138661623, 0.08312460420919315, 0.13473706506192684, 0.07630542226667915, 0.2443368232675961, 0.13050251800034726, 0.0968799814581871, 0.08904993161559105, 0.14391342337642396, 1.4107147987399782, 18.985217877796718, 44.54958772659302, 62.86091545649937, 57.51006950650896, 45.434270586286274, 33.3665315764291, 22.942692926951818, 34.64075824192592, 35.381269454956055, 40.705500330243794, 27.24881989615304, 9.116733976772853, 1.8178209364414215, 0.33260711814676014, 0.3045539291841643, 2.500012227467128, 7.06695112160274, 14.043679884501866, 15.311767816543579, 18.83071252277919, 14.111992835998535, 10.836067455155508, 18.07193796975272, 18.613878352301462, 5.506687530449458, 15.491253682545253, 27.790213108062744, 35.48632621765137, 47.93315894263131, 53.377148968832834, 59.53934301648821, 60.13468551635742, 57.766187054770334, 58.944667543683735, 59.29430089678083, 55.68990550722395, 53.39400182451521, 56.10303149904524, 56.01554325648716, 53.485992499760215, 53.7467931338719, 56.43863296508789, 55.555947712489534, 57.55548293249947, 46.915265219552175, 42.01836592810494, 45.39934546606881, 56.580265045166016, 55.687372888837544, 59.09360218048096, 51.76727914810181, 51.58994027546474, 54.99348061425345, 59.041754722595215, 57.233426979609895, 56.73078734534127, 57.92256668635777, 57.133956568581716, 48.1333122253418, 51.01764842442104, 52.12865843091692, 33.79481158937727, 54.836979389190674, 56.52861908503941, 57.654418332236155, 49.89653921127319, 47.84607022149222, 52.85620430537632, 55.44443954740252, 55.22453601019723, 54.169848101479666, 55.835105487278526, 54.94938039779663, 54.93936456952776, 53.89811100278582, 55.624988487788606, 54.04791069030762, 55.70732464109148, 52.303200653621126, 47.15563120160784, 44.18261514391218, 44.56429706301008, 46.94636535644531, 50.33308063234602, 52.39857162748064, 52.41343035016741, 53.957601479121614, 53.49176645278931, 50.37789303915841, 50.26592629296439, 48.45963784626552, 49.00582184110369, 46.67808151245117, 42.87341819490705, 32.05928359712873, 21.730293069566997, 11.954084719930377, 32.340602261679514, 21.49419675554548, 20.58514482634408, 35.44012764522007, 19.111874852861675, 14.074533360345022, 16.19069061960493, 11.567229866981506, 3.7159105028424944, 1.3669224743332182, 0.35477225163153236, 0.26876014843583107, 2.3297531349318366, 10.437207852091108, 27.0895220211574, 44.363091128213064, 53.54874168123518, 47.93104669025966, 38.01354585375105, 37.958575180598665, 48.328626087733674, 59.337615966796875, 53.90900230407715, 28.271556513650076, 3.2816682841096605, 0.28651548283440725, 0.13707149694008486, 0.17018781921693257, 0.08159559339817081, 0.08847722770380122, 0.1571777651884726, 0.07416856621525117, 0.1871409352336611, 0.12791009353739874, 0.23525512058820042, 0.1515030682619129, 0.12149757120226111, 0.07753737044653722, 0.2278387328343732, 0.14948583793427261, 0.09391280210443906, 0.09903396373348576, 0.1737487574240991, 0.12331881347511496, 0.22965289120163235, 0.18281387670763902, 0.09075247097228255, 0.11660506230379854, 0.13389589877000876, 0.16316070700330393, 0.0953550147158759, 0.18295126647821494], [0.055323341728321145, 0.004554225688999785, 0.022585626724841337, 0.05345529071720583, 0.026543563897056238, 0.04116253980568477, 0.04770492695804153, 0.03663564253864544, 0.016617493936792016, 0.042989502128745825, 0.03415747319481202, 0.048654702957719564, 0.006233205037590648, 0.00991650007199496, 0.01667025003449193, 0.024644603919503943, 0.03701919802863683, 0.05648788423942668, 0.06979439021753413, 0.05553541106304952, 0.0214528634013342, 0.024346090919737304, 0.019128041275377785, 0.042245834533657343, 0.024179617441924553, 0.18475258696292127, 1.9290144784109933, 11.669766170637947, 40.213001591818674, 44.892474378858296, 38.36987727028983, 28.727926356451853, 22.00623730250767, 17.99292652947562, 23.387384584971837, 32.921117305755615, 25.96646383830479, 14.024698274476187, 3.4966342576912472, 0.4576412002955164, 0.14402642659842968, 0.18487993441522121, 0.6814877316355705, 2.346685460635594, 6.8881188205310275, 7.4932917186192105, 7.891664947782244, 8.269905771527972, 11.40372920036316, 10.32908867086683, 5.814077573163169, 5.453704910618918, 19.319361959184917, 30.193796498434885, 40.942329679216655, 48.40967335019793, 53.49110984802246, 55.29539373942784, 53.05043772288731, 53.49901342391968, 54.26488208770752, 54.37021330424717, 50.240148476191926, 47.87330021177019, 49.62267596381051, 52.422126020704, 52.08418301173619, 50.24365036828177, 52.64982891082764, 53.64700657980782, 51.734907490866526, 42.52721725191389, 37.15340403148106, 46.532999651772634, 51.966369356427876, 54.703636510031565, 50.57090704781668, 49.40149048396519, 52.223126138959614, 51.386566502707346, 52.620886189596995, 50.19672918319702, 49.99221590587071, 48.197291237967356, 54.10876996176583, 46.096249784742085, 44.49650001525879, 45.006608963012695, 27.525700398853846, 51.55589410236904, 50.528154781886506, 50.66075072969709, 42.1170129776001, 46.156556674412315, 50.843609946114675, 52.20851755142212, 52.286521502903526, 53.01022154944283, 51.45469011579241, 54.1575219971793, 51.13686214174543, 50.61127608163016, 49.72623538970947, 49.67286627633231, 50.404098170144216, 49.39978470121111, 48.96731839861189, 39.48503882544381, 36.68045404979161, 40.231654030936106, 42.031699521201, 46.8528356552124, 47.71890776497977, 49.44348887034825, 51.157505239759175, 49.038850103105815, 46.24571248463222, 49.55948209762573, 48.888192313058035, 42.06717354910714, 38.67468779427664, 29.92418554850987, 27.626496178763254, 11.330287609781537, 5.149545780250004, 9.437247429575239, 16.964226620537893, 10.781769020216805, 9.707726904324122, 12.783928053719656, 5.114274552890232, 5.927503441061292, 1.0926172563007899, 1.477968692779541, 0.17832851596176624, 0.08555086901677506, 0.7746818565896579, 4.7975252866744995, 17.663988385881694, 32.488456453595845, 29.549861771719797, 25.379950761795044, 16.58585204396929, 18.941128083637782, 35.95707709448678, 40.289105210985454, 45.18951334272112, 24.858547517231532, 4.539992477212634, 0.5344944106681007, 0.026252100876133357, 0.032916439431054254, 0.00921872943373663, 0.0358479244501463, 0.08800042793154716, 0.0192469647154212, 0.06480139028280973, 0.007679099549672433, 0.026059035610939776, 0.11924009876591818, 0.021868174330198338, 0.018474912304165106, 0.0522031900472939, 0.06878021785191127, 0.046030400919594934, 0.030081153714231083, 0.04736818699166179, 0.017594429996929, 0.055744182717587264, 0.05460803011166198, 0.024378792914961065, 0.0830768421292305, 0.011805883375927806, 0.00771753940664764, 0.10381038886095796, 0.02106772522841181, 0.06553662368761641, 0.04810261293979628, 0.019573950740907873, 0.03268771884696824, 0.019815850171393583, 0.027210027777722905, 0.01259435379012887, 0.04567586297967604, 0.011740951815487018, 0.03124739256288324, 0.012854644912295043, 0.04260272699009095, 0.03995000451271023, 0.04997711681893893, 0.013672849579182054, 0.042363129489656, 0.05857028107025793, 0.03278517683169671, 0.02941553800233773, 0.01302606999940638, 0.014207983006989318, 0.012899265375121363, 0.09455785141991717, 0.04645201204610722, 0.058498471709234376, 0.24495464297277586, 2.39443348135267, 15.346274307795934, 46.90307460512434, 52.71628148215157, 44.23821810313633, 35.149842330387656, 27.454832247325353, 20.884296042578562, 28.85728965486799, 34.019023009708945, 29.41171768733433, 16.498841490064347, 4.407076043742044, 0.6225692331790924, 0.04863067264003413, 0.7896291688084602, 1.6883388672556197, 3.975531680243356, 9.354010616030012, 6.4017292857170105, 11.487567901611328, 7.297447187559945, 8.84952015536172, 8.675509469849722, 4.937044680118561, 6.955305295331137, 19.001238686697825, 30.467635427202495, 43.05028806413923, 48.1087920325143, 54.07762118748256, 56.60343381336757, 56.02557298115322, 56.471032415117534, 57.896684646606445, 56.592243739536826, 53.119436808994834, 49.96350942339216, 53.008578300476074, 54.17189087186541, 53.100770473480225, 49.659119265420095, 53.556652205330984, 55.994775090898784, 53.296911171504426, 44.81055164337158, 39.45259421212332, 48.3870986529759, 53.33945151737758, 55.61716481617519, 52.392092432294575, 48.83475719179426, 52.6036650793893, 52.5468670300075, 54.57122121538435, 51.9668105670384, 51.010971205575125, 50.23423555919102, 56.1725412777492, 46.626640524183, 47.686233861105784, 48.78389637810843, 33.377513204302105, 52.50877353123256, 52.84610162462507, 52.67787878853934, 44.09604058946882, 47.3934645652771, 52.353297165461946, 54.56803894042969, 53.17489733014788, 52.299351351601736, 52.72751324517386, 54.134311539786204, 50.41632005146572, 51.24623373576573, 49.561722891671316, 52.339029039655415, 52.18897226878575, 52.381697927202495, 50.53570747375488, 41.25561005728585, 39.796245166233604, 42.794424125126426, 45.07925932747977, 50.56024851117815, 50.24015889848982, 51.45144878114973, 52.765068258558, 51.1770053591047, 46.7550710269383, 50.20278453826904, 48.27353382110596, 44.43233340127127, 40.3093592098781, 31.18425178527832, 25.235191992350988, 13.145404611315046, 7.50190053667341, 8.666458572660174, 13.816337432180132, 17.456991127559117, 16.26499465533665, 11.17315149307251, 9.732755184173584, 6.838214252676282, 3.522919075829642, 2.0102122128009796, 0.19388066072549137, 0.17422344695244515, 0.8951495609113148, 5.446447517190661, 18.555351938520158, 33.77967493874686, 36.773810046059744, 31.615512575422013, 20.57258595739092, 25.686362845557078, 39.63692644664219, 46.22056695393154, 52.19636862618582, 31.91821084703718, 5.606702940804618, 0.5605413615703583, 0.04993685594360743, 0.03132385328145964, 0.04562511195295623, 0.03183512602533613, 0.038672010946486673, 0.006979897202524755, 0.07412661239504814, 0.05487196666321584, 0.006165128891422812, 0.05573356703722051, 0.007800236710214189, 0.046363130744014464, 0.019140726487551416, 0.014851827074640563, 0.032466150021978786, 0.049886990405086956, 0.02210989055622901, 0.047250118505741866, 0.06895805509494883, 0.06360043079725333, 0.042028513337884627, 0.043140289573264975, 0.04029949415209038, 0.023657445729311024, 0.08080951057906662, 0.011924766103870102, 0.13128816655703954, 0.10237267493669476, 0.1004689024495227, 0.1613300195229905, 0.135135894375188, 0.1953298622476203, 0.14161675875740393, 0.1588339198912893, 0.12144126636641366, 0.13761394497539314, 0.11704563509140696, 0.08378679331924234, 0.13661606423556805, 0.128864425899727, 0.1206505016556808, 0.16104438342154026, 0.16464870715779917, 0.10942983268094914, 0.1347705168383462, 0.14443540679556982, 0.08388101469193186, 0.12360240040080887, 0.1566426046192646, 0.10284726947013821, 0.1992308957768338, 0.33859217699084965, 3.705833009311131, 20.096948759896414, 54.527381556374685, 57.278447832380024, 50.98357793263027, 38.66827113287789, 30.49067565373012, 26.560307264328003, 34.32189498628889, 43.77872330801827, 35.08650950023106, 17.86398880822318, 4.9723910348755975, 0.7173889109066555, 0.4430260445390429, 1.0358409200395857, 3.3281862565449307, 6.316342438970294, 13.981986829212733, 18.715103183473857, 13.697550160544258, 17.42460557392665, 18.448665823255265, 19.976501737322124, 10.880333559853689, 8.79774478503636, 20.686402661459788, 33.10043641499111, 45.59537499291556, 51.7703606741769, 56.83616719927107, 58.722672598702566, 55.364378929138184, 56.005975587027415, 57.09234728131975, 57.97876024246216, 54.64931896754673, 51.7831175667899, 54.21604667391096, 55.6681090082441, 54.273400579180034, 50.171597548893516, 53.97603504998343, 58.3760895047869, 57.00128071648734, 48.41097961153303, 40.90711273465838, 51.853193623679026, 56.967793873378206, 57.84580646242414, 55.61417361668178, 49.56206335340227, 52.463891642434255, 54.73510490145002, 56.86788919993809, 54.66912133353097, 53.93015262058803, 52.053381647382466, 57.79971211297171, 49.79990019117083, 50.132958616529194, 53.25414848327637, 37.89043072291783, 52.65835782459804, 54.733864648001536, 53.884756565093994, 47.02218409946987, 49.710904189518516, 55.37734079360962, 55.25797769001552, 54.87000070299421, 55.46401262283325, 54.668572425842285, 55.99285043988909, 51.71373632975987, 51.69273887361799, 50.25444439479283, 53.146621635981965, 53.67248909814017, 53.76775237492153, 53.273964745657786, 43.78801999773298, 41.042821475437705, 44.12655707768032, 46.86672510419573, 53.92359699521746, 52.959555285317556, 54.11565562656948, 55.58160393578665, 52.84195702416556, 46.962710993630544, 50.20861060278756, 49.911349296569824, 46.068807874407085, 42.491128308432444, 33.062804971422466, 31.186808722359793, 18.19218349456787, 10.030860696520124, 18.40606815474374, 28.290024825504847, 22.75539902278355, 15.12534591129848, 21.61684809412275, 12.315551723752703, 13.769774947847639, 5.199918482984815, 2.754360807793481, 0.7079155306730951, 0.30416347299303326, 1.2805214077234268, 6.089233619826181, 21.312774079186575, 39.77937494005476, 40.72136654172625, 34.63263579777309, 23.90343597957066, 30.532166821616038, 46.98804065159389, 53.17876747676304, 58.72306169782366, 39.201687812805176, 8.70925600188119, 0.8923282665865762, 0.11013949210090296, 0.2529127188026905, 0.07969574284340654, 0.14389259235135146, 0.15141355592225278, 0.13612829255206244, 0.19998852083725588, 0.13716366913701805, 0.11401875822671823, 0.16373177564569882, 0.12873242369719914, 0.14308738841542176, 0.11690682039729186, 0.15113861353269645, 0.2060926082943167, 0.1340072735079697, 0.14004463383129664, 0.17448420796011174, 0.12741423371647084, 0.15113428447927746, 0.08731698710471392, 0.12150671785431248, 0.15312388486095838, 0.09324133063533477, 0.22948903856532915, 0.07850768230855465], [0.04348502268216439, 0.11200554482638836, 0.025171284497316395, 0.02496846529122974, 0.008769953157752752, 0.02036582655273378, 0.02288838565748717, 0.03480863271813307, 0.06116184379373278, 0.07613150695604937, 0.026891308005100915, 0.03335769075368132, 0.03650273449186768, 0.013496623856813779, 0.028444998831089054, 0.07550633193126746, 0.0418440807344658, 0.04227704375184008, 0.04317538340442947, 0.005920673080254346, 0.0652151337957808, 0.019273391958060007, 0.05715228537363665, 0.06818428090108292, 0.059596232803804536, 0.1448780559003353, 4.356018509183611, 17.731795855930873, 45.18672364098685, 52.67691993713379, 47.34414972577776, 26.56769493647984, 16.71308398246765, 15.87605881690979, 25.979488236563547, 27.33114215305873, 25.626158441816056, 10.22414915902274, 2.4222549370356967, 0.2091934997588396, 0.03687801185463156, 0.6160849354096821, 0.6459656634501049, 2.913404856409345, 9.555086272103445, 6.359426481383188, 10.451981459345136, 9.399854830333165, 6.223017709595816, 4.905953228473663, 4.0712544066565375, 9.801439864294869, 18.989800214767456, 34.371585028512136, 46.67596231188093, 52.616856234414236, 54.72418928146362, 57.12238086972918, 53.081767150333945, 52.79343775340489, 51.75233357293265, 50.02504614421299, 47.092343534742085, 46.24000106539045, 50.60274369376046, 52.37858166013445, 50.83517483302525, 50.476616518838064, 53.16518027441842, 53.26437970570156, 49.22837611607143, 38.80617550441197, 36.34212194170271, 47.640622411455425, 53.09817879540579, 50.602552618299214, 40.60459859030587, 52.551289558410645, 51.011631284441265, 48.473093032836914, 48.84447077342442, 46.71608468464443, 44.790120465414866, 46.725016593933105, 50.98509611402239, 53.50579833984375, 37.523232323782786, 37.05477435248238, 26.284498521259852, 53.14008338110787, 51.397412640707834, 50.11813810893467, 44.82834250586373, 44.801171575273784, 48.41442939213344, 49.34164217540196, 51.78164454868862, 53.669886997767854, 50.31844425201416, 52.175669942583355, 52.605363913944785, 53.53621755327497, 48.68640272957938, 46.47780663626534, 49.72300100326538, 48.852117265973774, 50.942336899893625, 45.9957024029323, 37.301331179482595, 37.8459518296378, 40.4818343435015, 42.59550762176514, 44.466928482055664, 49.15342589787075, 49.96838705880301, 51.70268521990095, 48.34424563816616, 47.528492382594514, 44.17147718157087, 45.20572349003383, 38.563794544764924, 30.537541253226145, 26.125308343342372, 19.051045111247472, 7.915254081998553, 10.493087870734078, 5.632735235350473, 9.470888001578194, 20.633493866239274, 10.727613023349218, 5.042929146971021, 4.406389474868774, 3.0992947901998247, 1.7150911688804626, 0.4348917124526841, 0.044213409668632915, 0.5983601350869451, 2.781502425670624, 11.186258401189532, 22.68602125985282, 29.11159893444606, 24.75476748602731, 23.953268459865026, 23.74269461631775, 35.04248571395874, 45.94493191582816, 42.692490577697754, 25.25906947680882, 6.351733088493347, 0.7006000546472413, 0.025610125324289714, 0.03401933364304049, 0.010799351314614927, 0.022120046529120634, 0.06584735879940645, 0.005758178362157196, 0.02239627474253731, 0.015097907977178693, 0.01785042429608958, 0.04667331284976431, 0.011414375455517854, 0.04784729039030416, 0.04185916796060545, 0.03376391949132085, 0.0657941277271935, 0.06029545635517154, 0.026590884929256778, 0.016194155938657265, 0.021769437306959714, 0.006514051105893616, 0.041645846728767665, 0.06434021717203514, 0.015127419161477258, 0.0383171133830079, 0.03793006683034556, 0.06704191291438681, 0.03143348079174757, 0.08271888098014252, 0.02587030448817781, 0.0262462298518845, 0.02496613621977823, 0.06896186167640345, 0.015832593464957814, 0.06952604997370924, 0.03381724895111152, 0.09112772797899586, 0.025898567168042064, 0.042635184712707996, 0.029252048382269483, 0.029429034063858644, 0.05654093210718461, 0.030481346882879734, 0.07233821121709687, 0.01074032046433006, 0.04980203103540199, 0.072323989123106, 0.09480015627507653, 0.02385815978050232, 0.03241699694522789, 0.06955561374447175, 0.07461991413895573, 0.22787556371518544, 5.047001659870148, 22.01547145843506, 51.99208811351231, 56.51377773284912, 50.91434260777065, 29.894874572753906, 19.18192137990679, 18.68662425449916, 26.134598084858485, 33.50907039642334, 27.877355677740915, 12.623098969459534, 2.944622027022498, 0.2658236117235252, 0.09102440745170627, 0.7941751905850002, 1.8227042172636305, 6.6085671697344095, 11.131070596831185, 11.074656435421534, 11.58362066745758, 8.769276278359548, 10.73653451034001, 6.9638945715768, 7.7139804022652765, 12.615918006215777, 21.134651797158376, 32.641987323760986, 47.46588216509138, 53.37782989229475, 56.76626137324742, 56.92732409068516, 55.75853286470686, 53.67349658693586, 54.326036657605854, 51.959320408957346, 51.1027638571603, 48.539997237069265, 52.62546852656773, 53.874664306640625, 52.21727922984532, 49.88291726793562, 54.069516113826204, 55.241781439099995, 52.38417843409947, 41.02013560703823, 38.544878074101035, 48.91666950498308, 55.28583301816668, 51.78701203210013, 45.32936668395996, 52.91122709001814, 52.90951088496617, 50.69691957746233, 51.82982683181763, 49.79657547814505, 45.655928543635774, 48.19370596749442, 51.69394786017281, 54.774938923971995, 39.52590118135725, 41.06118903841291, 30.609396048954554, 54.77334778649466, 53.911691256931846, 50.20856891359602, 47.13002361570086, 47.01669154848371, 49.557168347494944, 51.24234274455479, 53.99283232007708, 54.05673490251814, 53.76591805049351, 53.50644799641201, 54.17513568060738, 52.513703278132844, 49.02225433077131, 47.37906094959804, 50.733703340802876, 51.50260489327567, 53.49863474709647, 47.58247988564627, 39.768601758139475, 39.2157370703561, 42.70270095552717, 45.35100337437221, 47.44041354315621, 51.43781641551426, 51.433935846601216, 53.03927196775164, 49.379944120134624, 47.64067799704415, 44.825156756809776, 45.43924897057669, 40.870203903743196, 33.941255296979634, 30.07249484743391, 19.043645279748098, 10.286860993930272, 10.506026285035269, 11.335405826568604, 17.039492981774465, 12.378656131880623, 10.443080816950117, 12.670005389622279, 6.5424880640847345, 4.450212631906782, 3.226691097021103, 0.595985968198095, 0.27609790755169733, 0.5384840337293488, 2.7330254954951148, 12.562917147363935, 27.46008334841047, 30.786634172712052, 26.38092562130519, 22.409606286457606, 29.307376589093888, 42.37070213045393, 53.214304038456504, 49.27338654654366, 31.494214398520334, 8.75409185886383, 0.7809020142470087, 0.01675065473786422, 0.04782088180737836, 0.011789452650451233, 0.1004632298967668, 0.06665581970342568, 0.043031333812645504, 0.015738870815507004, 0.07914007694593497, 0.01581805754852082, 0.002689928884917338, 0.042196918944162984, 0.0234197956243796, 0.04663313679131014, 0.02742108439893595, 0.018029677980978574, 0.0484207372979394, 0.026748871630323783, 0.01867349066638521, 0.02870684888746057, 0.032611207238265445, 0.011095320656230407, 0.021624805871397257, 0.006105799061645354, 0.05741007439792156, 0.06459880008229188, 0.09090812012021031, 0.09720671642571688, 0.1601424611040524, 0.10027517391634838, 0.15963985664503916, 0.13575516614530767, 0.12341120280325413, 0.11892766053123133, 0.17921917459794454, 0.10354521737567016, 0.2103828630809273, 0.16174879776579992, 0.1407569870352745, 0.05264751174088035, 0.07489625431065049, 0.15745054983666965, 0.19890568751309598, 0.13354128279856273, 0.11096642951347999, 0.13621827986623558, 0.0947918306503977, 0.2060122833188091, 0.11468623312456266, 0.1187421761985336, 0.13751956075429916, 0.14863391007695878, 0.4346593820622989, 6.6853026407105585, 29.162649086543492, 60.535346439906526, 62.913409096854075, 59.60164056505476, 34.875885282244, 25.327686411993845, 23.796086311340332, 34.873522894723074, 39.173370429447715, 33.11534724916731, 13.395971417427063, 3.5789597715650285, 0.593945097710405, 0.4117811625557286, 1.1296336757285255, 3.2406148527349745, 8.318920969963074, 18.949924503053936, 16.628442764282227, 20.99606650216239, 21.9772025176457, 15.095354012080602, 11.583177719797407, 9.433469346591405, 13.208735704421997, 24.63751663480486, 40.109285831451416, 51.34835141045706, 57.61448703493391, 58.952519008091514, 61.10185391562325, 58.68090697697231, 55.752331597464426, 55.633135250636506, 52.54628338132586, 51.12129470280239, 50.70517751148769, 54.69024385724749, 55.577858856746126, 52.19898114885603, 51.38428054537092, 54.33227961403983, 57.75513594491141, 54.33255059378487, 42.45583493368966, 40.612682819366455, 51.27737903594971, 59.24202959878104, 53.472092628479004, 45.60604395185198, 55.013807569231304, 54.95610277993338, 53.44266700744629, 52.64466987337385, 51.92692790712629, 47.45611299787249, 49.2832738331386, 54.79957028797695, 56.99633012499128, 44.49333511080061, 44.43839570454189, 32.712775571005686, 55.528748989105225, 54.89464248929705, 53.625606128147666, 48.42659221376692, 49.241720131465364, 53.09492356436593, 52.710222652980256, 56.73889936719622, 56.73736728940691, 55.27583108629499, 56.68033300127302, 55.65683208193098, 55.82096242904663, 49.45949404580252, 49.06431525094168, 50.21520791734968, 52.614625862666536, 55.73185525621687, 51.495778288160054, 42.750990935734336, 42.53491933005196, 45.29927750996181, 47.08258131572178, 47.82932506288801, 54.39707156590053, 54.01346499579293, 55.879810197012766, 50.906842027391704, 49.89090422221592, 48.42547355379377, 47.15459244591849, 41.11931071962629, 36.200535024915425, 30.02879762649536, 23.490447214671544, 14.75328551019941, 18.45026912008013, 13.886648859296526, 20.676082849502563, 32.52524716513497, 21.663807494299753, 16.1877532686506, 13.508863142558507, 5.65924825838634, 3.5387186280318668, 0.8099315879600388, 0.4086917111916201, 0.848135226539203, 3.5705572281564986, 14.57275220326015, 29.589358806610107, 39.121311051504954, 36.851991176605225, 34.169989994594026, 35.919688837868826, 46.05736071722848, 56.77779885700771, 55.59223815373012, 38.57506104878017, 11.966356975691658, 1.2767576553991862, 0.08126138097473554, 0.1532018892467022, 0.04815548099577427, 0.1356170435569116, 0.15028465007032665, 0.12472186104527541, 0.05712483184678214, 0.09255681772317205, 0.15709045130227292, 0.1497916400964771, 0.0938004231346505, 0.16830652659492834, 0.17271046313856328, 0.1460185239889792, 0.1214716647352491, 0.17712651831763132, 0.1563661287405661, 0.062588205827134, 0.15196871970381054, 0.11042275332978793, 0.13795216754078865, 0.17295065096446446, 0.13360297520245823, 0.12425078132322856, 0.1272830864680665, 0.19685926660895348], [0.05255889506744487, 0.08671294844576291, 0.054217662130083354, 0.007826331470693861, 0.03833607504410403, 0.06519748509994575, 0.051758311954992156, 0.030179578611361127, 0.034174114266144376, 0.04376333739076342, 0.017446560252990042, 0.031642544216343334, 0.021358757379597852, 0.03477299266627856, 0.01296776348525392, 0.06908093100147587, 0.03193281810464604, 0.024249508245182887, 0.08833960044596877, 0.07139538680868489, 0.024840094947389195, 0.007692845820981477, 0.04180475963013513, 0.01904778754604714, 0.09393660511289324, 0.18985808800373757, 5.279389372893742, 25.28334300858634, 40.22678681782314, 51.91782576697213, 36.102700914655415, 26.912666048322404, 21.693955727985927, 22.393449987683976, 41.5153615134103, 37.624915736062185, 20.43747823578971, 6.526122885090964, 0.953502703990255, 0.14444364421069622, 0.06551758399499313, 0.6190426966973713, 1.8875860614436013, 4.941457220486232, 8.034676245280675, 3.61459447656359, 9.936421649796621, 3.6434082218578885, 8.514977421079363, 7.257600571428027, 5.767013081482478, 13.656608768871852, 26.48278968674796, 35.00019550323486, 48.061870847429546, 51.40142869949341, 54.70277493340628, 51.236346449170796, 51.0903821672712, 48.87658882141113, 49.16320201328823, 46.7260935647147, 45.85590812138149, 46.804389340536936, 50.03018086297171, 50.622163908822195, 51.74159165791103, 49.520388058253694, 51.537120069776265, 52.3496458871024, 49.091277735573904, 40.53682933534895, 35.88893263680594, 46.5982015473502, 50.83281591960362, 52.750338077545166, 52.89312008449009, 51.3271107673645, 51.056822368076865, 48.896321705409456, 45.18311057771955, 36.86471332822527, 41.53805085590908, 46.27200794219971, 50.66907467160906, 50.31927803584507, 40.72925622122628, 33.160149233681814, 24.768514496939524, 51.62769678660801, 51.364485127585276, 50.44580820628575, 49.62742853164673, 45.40892008372715, 43.99674735750471, 46.01152345112392, 46.72864007949829, 46.88891765049526, 47.09014790398734, 48.35524811063494, 50.807149274008616, 50.449098178318565, 51.349949496132986, 50.7336025919233, 48.16425255366734, 49.79517194202968, 49.28374631064278, 47.13572461264474, 41.059080260140554, 40.99291256495884, 39.46817902156285, 39.96976252964565, 45.0026068006243, 45.140097754342214, 47.35584354400635, 48.26802737372262, 51.743995734623496, 46.196432386125835, 48.008275917598176, 46.64625528880528, 45.04224279948643, 35.73814630508423, 30.01300437109811, 21.9908835206713, 12.31139235837119, 4.888065959726061, 15.374145269393921, 20.302123853138514, 13.102085198674883, 5.688212692737579, 12.59444112437112, 3.1956385118620734, 4.8809961676597595, 4.591799982956477, 0.2496320019875254, 0.12307747213968209, 0.07788616458752326, 1.0039840808936527, 7.1967929771968295, 21.001479148864746, 32.628737109048025, 32.64304344994681, 24.994702679770334, 22.400907141821726, 30.26583194732666, 36.5825400352478, 44.1912065914699, 37.32629953111921, 12.173618265560695, 1.2390660664864948, 0.014864435951624597, 0.04514438007026911, 0.044702633417078426, 0.03181474622605102, 0.014814438098775489, 0.023875387784625803, 0.056077370553144386, 0.08527786723737206, 0.03937614030603852, 0.07733570305364472, 0.027423369365611246, 0.016489878463159715, 0.05903550503509385, 0.0129665565410895, 0.03612081427127123, 0.017439023425270404, 0.03792024164327553, 0.05553869517253978, 0.030349175046597208, 0.017854768616546477, 0.027175283392093012, 0.07207118733120815, 0.025219099163743, 0.01683322566428355, 0.01688431595851268, 0.06337045492338282, 0.012052181409671903, 0.028061969205737114, 0.09020381434155361, 0.023722596965464096, 0.04686779794948442, 0.06931136149380888, 0.0319584904770766, 0.0061831626558809406, 0.028467539764408554, 0.051158432715705464, 0.02535793760658375, 0.07566875964403152, 0.06262775763337101, 0.02131937859979059, 0.03527497287307467, 0.02936460037848779, 0.031080289743840694, 0.005552421099439795, 0.0706274751573801, 0.04199908866680094, 0.009641135294389511, 0.01008802609119032, 0.011661097573648607, 0.02352541808171996, 0.010380255856684275, 0.14438618586531707, 6.925200487886157, 28.36923255239214, 47.4931503704616, 57.24970660890852, 41.86585296903338, 29.4754604612078, 24.107949256896973, 19.846608638763428, 37.70780774525234, 37.96172966275896, 23.122084992272512, 7.223599127360752, 0.9763388271842683, 0.16247290319630078, 0.02518475511377411, 1.1467188618012836, 3.3985897472926547, 7.46681821346283, 10.040345856121608, 9.521727102143423, 7.649989230292184, 6.065129016126905, 8.688886489186968, 8.132652793611799, 8.05716061592102, 13.545201352664403, 25.202714375087194, 37.819746698652, 49.25316034044538, 55.04160383769444, 56.22441305433001, 54.747576917920796, 53.10889291763306, 50.66474594388689, 51.56756707600185, 50.225157737731934, 47.92961188725063, 49.13420370646885, 52.003722872052876, 52.210820879255024, 51.90543712888445, 49.22653136934553, 52.26370014463152, 54.30685268129621, 51.340326241084504, 41.853724888392854, 38.41471399579729, 48.11106756755284, 53.0023318699428, 54.03505999701363, 52.20749616622925, 52.86947883878435, 52.08137593950544, 51.13340541294643, 46.002084323338096, 39.33001756668091, 41.906256743839805, 47.99015154157366, 51.16270249230521, 52.94655173165457, 42.71699687412807, 37.66324894768851, 28.290954147066387, 52.25724526814052, 53.68021896907261, 51.664348534175325, 50.160595076424734, 47.36449057715279, 47.43774890899658, 47.747805322919575, 48.59231717245919, 49.893683501652305, 49.326575006757466, 50.62760782241821, 54.00440801892962, 53.66399145126343, 52.50108882359096, 51.031416279929026, 48.39816018513271, 51.48857300622122, 52.63186434337071, 49.07099941798619, 43.498300961085725, 42.190483229500906, 42.12112978526524, 42.32816525868007, 46.26923213686262, 48.54410362243652, 50.504694189344136, 52.06822647367205, 52.201430388859336, 48.329425130571636, 48.875595229012625, 48.65486485617501, 44.65003783362252, 38.94521590641567, 30.723607063293457, 26.50823746408735, 21.302812099456787, 6.036963190351214, 11.291672996112279, 16.084718431745255, 11.679359027317592, 11.521720903260366, 18.384186540331157, 9.414751768112183, 4.745108510766711, 5.896323834146772, 1.085970544389316, 0.07169436290860176, 0.09262149568114962, 1.4155543276241846, 7.920061366898673, 22.826883826936992, 35.294753960200715, 33.57898664474487, 26.147896936961583, 25.860149451664515, 32.3832676751273, 41.47405447278704, 48.98746470042637, 44.02976172310965, 15.08108936037336, 1.5515289455652237, 0.030191476722913127, 0.010629456323970641, 0.1113923934421369, 0.07852804514446429, 0.06494668498635292, 0.005004158867190459, 0.014430772346843566, 0.050945169159344265, 0.07337193896195718, 0.09325754083693027, 0.02568063359441502, 0.017717002259035195, 0.08645382270749126, 0.025895518849470785, 0.0227252115562026, 0.05987288510160787, 0.04595897153818181, 0.057988606925521574, 0.04024973717917289, 0.0596952989165272, 0.008606527150342507, 0.1080444473773241, 0.015391557577199169, 0.025859598901921084, 0.03622486422370587, 0.0839375230882849, 0.12046827429107257, 0.11450458930007049, 0.20719393848308496, 0.1470110850142581, 0.22711005407784665, 0.163847343730075, 0.19387881511024066, 0.11772336943873338, 0.12143008410930634, 0.10798652762813227, 0.11111730177487646, 0.13557259951319012, 0.11360270090933357, 0.11731704909886632, 0.18078117578157357, 0.15915842247860773, 0.1423664449581078, 0.13045161430324825, 0.10888805639530931, 0.18008978930967195, 0.11690980595137392, 0.104112791562719, 0.15552819227533682, 0.11811317423624651, 0.12255235388875008, 0.35707278390015873, 8.469280855996267, 35.260735579899375, 54.37746722357613, 65.06903907230922, 46.25860486711775, 35.59459999629429, 30.484974656786235, 32.445134435381206, 52.10226222446987, 47.46992949077061, 26.22436707360404, 8.70245545251029, 1.4429581314325333, 0.2810666023620537, 0.272497682166951, 1.9029589508261, 3.4203823379107883, 11.67906025477818, 16.4200211252485, 12.221113545554024, 23.422248908451625, 11.075214896883283, 15.83830577986581, 15.377211162022181, 10.359751071248736, 19.325995751789637, 32.980861391339985, 39.64419078826904, 52.5806040082659, 55.099902697971885, 58.977261543273926, 54.89954096930367, 55.56672089440482, 52.40551635197231, 52.81687750135149, 51.230325835091726, 50.09141533715384, 50.61857516424996, 54.48991339547293, 53.41032314300537, 53.04145022800991, 49.68011672156197, 52.46833848953247, 57.00459500721523, 53.25310625348772, 44.26868942805699, 40.53572109767369, 50.64653818947928, 55.53326531818935, 54.33873101643154, 52.93410055977957, 54.66947569165911, 55.23752914156233, 53.30114957264492, 49.904078006744385, 40.289636748177664, 44.769581590379985, 50.74388245173863, 52.90845128468105, 55.12114681516375, 45.499826839991975, 42.01705619267055, 33.82356670924595, 52.3899940763201, 56.294555119105745, 52.97598777498518, 53.550461360386436, 49.38346338272095, 48.99916199275425, 50.46028825214931, 51.747855458940776, 51.9452155658177, 51.440467153276714, 51.51648391996111, 55.26715973445347, 55.43686948503767, 54.18796900340489, 52.57563257217407, 48.550443853650776, 51.65741423198155, 53.752845014844624, 51.06110940660749, 46.0867064339774, 44.05838482720511, 42.39104298182896, 43.80580391202654, 48.619008677346365, 50.42422015326363, 53.27436774117606, 52.95200259344918, 53.98646082196917, 48.4879378591265, 50.13632501874651, 49.690539019448416, 47.29624537059239, 40.089354923793245, 35.413477829524446, 25.41526324408395, 19.758420365197317, 13.31345808506012, 22.321536132267543, 30.60939952305385, 27.53370646068028, 15.440144470759801, 19.703416688101633, 10.296843818255834, 10.643261892454964, 7.463088767869132, 1.5933922763381685, 0.18229087548596518, 0.3382287807762623, 1.5133274240153176, 9.023936441966466, 25.967242036546978, 42.19043806621006, 45.83373989377703, 35.37296288354056, 32.89808750152588, 39.59079040799822, 47.4241304397583, 55.75513866969517, 50.871562549046104, 21.264845405306133, 2.6720993476254598, 0.12418676832956926, 0.11351973643260342, 0.18715446522193296, 0.09799204607095037, 0.15870421113712446, 0.1622096180383648, 0.12510338771556104, 0.21875476384801523, 0.21125121148569243, 0.1975982862391642, 0.08838684005396706, 0.1392603830567428, 0.11470611420060907, 0.13084477106375353, 0.18490907070892199, 0.20226980985275336, 0.10856959955500704, 0.10738789689327989, 0.13518523744174413, 0.175494465178677, 0.08430180818374668, 0.1453611185508115, 0.12820659976984772, 0.14177508811865533, 0.16590239559965475, 0.25796256640127724], [0.023664549990956272, 0.0035006692425148295, 0.01826379631113793, 0.07448002057416098, 0.04292134328612259, 0.01807564533581691, 0.03546351400603141, 0.06334525413279023, 0.025957711672942554, 0.009102754228349243, 0.017008608306891153, 0.027821077399754097, 0.1496266203799418, 0.015434513932892253, 0.05055000732785889, 0.034109829858477624, 0.04731193304594074, 0.0068911948640431675, 0.011774955749777811, 0.0051137694141029245, 0.02557735377922654, 0.041004702382321866, 0.029211733224136487, 0.02291346261543887, 0.025816296493368487, 0.15886748023331165, 6.929319032600947, 31.420125756944927, 42.64053542273385, 43.79755987439837, 37.39410352706909, 24.658878871372767, 20.796331848417008, 32.54790524074009, 31.325077874319895, 33.53268732343401, 14.954006808144705, 5.255750298500061, 0.6714695149234363, 0.15426020031528814, 0.11269640204097543, 0.640494065625327, 3.3833883915628706, 7.176097333431244, 8.90689924785069, 13.773627723966326, 5.43949237040111, 4.703854015895298, 8.990776164191109, 4.968947768211365, 10.223391805376325, 16.478385993412562, 27.79381227493286, 40.02878747667585, 53.391375405447825, 53.834257057734895, 54.48426798411778, 51.63292530604771, 49.7177585874285, 47.49918140683855, 45.026314054216655, 42.48026132583618, 46.38932132720947, 48.96832936150687, 51.86251810618809, 52.251613753182546, 51.075141293661936, 50.52164779390608, 50.7618921824864, 52.7658360345023, 50.51849678584507, 42.5152976172311, 34.84061970029558, 41.10807548250471, 50.853403432028635, 51.82076638085501, 52.10485390254429, 49.21136345182146, 48.88738284792219, 43.07024676459176, 37.11312185014997, 37.03825153623308, 40.83829777581351, 45.50798749923706, 49.70045062473842, 51.63366528919765, 40.03052800042288, 22.175316504069738, 29.798721926552908, 54.48034920011248, 52.31643697193691, 52.8957326071603, 51.824886662619456, 48.31534808022635, 47.33419295719692, 46.44508409500122, 45.87319523947579, 44.23516089575631, 43.657421657017295, 41.44689049039568, 42.9580785206386, 48.02495159421648, 49.97658245904105, 50.873115471431184, 49.216605867658345, 50.901002066476, 52.432009833199636, 48.553410734449116, 44.812861919403076, 41.813696316310335, 39.69100775037493, 38.791097913469585, 42.22185434613909, 43.79482923235212, 48.3853303364345, 47.87208080291748, 51.64483799253191, 48.761512756347656, 47.65919494628906, 50.41372489929199, 48.05124357768467, 40.73803179604666, 37.491527693612234, 24.41979135785784, 25.6229362147195, 7.536156892776489, 7.683163404464722, 16.885899577822002, 3.728932729789189, 10.78013619354793, 19.26395181247166, 8.835637654576983, 3.031024830681937, 4.436568106923785, 0.8467386386224202, 0.1518756111285516, 0.056461831887385676, 0.7703891726476806, 5.181665565286364, 18.352987391608103, 25.984876564570836, 23.521788801465714, 21.741656848362513, 27.06310670716422, 32.45121758324759, 41.92223065240042, 46.39230557850429, 40.92867299488613, 21.124799251556396, 2.9439843126705716, 0.09367236322058098, 0.023684660072571466, 0.018498067311676483, 0.03568839068923678, 0.048483997117727995, 0.03579494104321514, 0.04072223164673362, 0.020749380346387625, 0.07358732633292675, 0.030254953673907688, 0.00820366818723934, 0.060438423683600764, 0.03835194258551512, 0.06205714360943862, 0.007039917865768075, 0.061115601632211886, 0.009439679943690342, 0.06943286675959826, 0.03752489660733512, 0.017442828310387473, 0.006350233244510102, 0.043074044199394326, 0.02630315554727401, 0.037782057986727784, 0.02094355331999915, 0.04824707983061671, 0.03277973158817206, 0.03696013834061367, 0.032505586477262635, 0.026328885595181158, 0.020468967268243432, 0.021673044622210518, 0.047276194606508525, 0.030235978442111185, 0.054325006370033534, 0.03334861874048199, 0.02769958909734019, 0.034186032733746936, 0.041435219280953915, 0.038872446798320325, 0.05241710838994809, 0.011812457532089735, 0.01889153110927769, 0.06332039939505713, 0.012501343602447637, 0.032162899151444435, 0.042462490765111785, 0.04414707947788494, 0.051026396586426666, 0.03326251943196569, 0.019417064962908626, 0.2788457301046167, 7.8429233346666605, 36.96796703338623, 48.62593950544085, 49.70483841214861, 40.51325757162911, 30.556867667606898, 24.650940554482595, 35.82877860750471, 35.789705412728445, 35.96869795663016, 17.027119977133616, 4.964656821319035, 0.845463861312185, 0.044170231092721224, 0.16910314027752193, 1.2080723238842828, 4.10443422624043, 9.223281128065926, 8.918832778930664, 7.858073013169425, 11.020361474582128, 8.611348935535975, 8.552746091570173, 4.9873765621866495, 7.745983804975237, 18.95828492300851, 29.91695942197527, 42.45850304194859, 53.77276202610561, 56.83236306054251, 54.64267996379307, 52.37022645132882, 52.038647992270334, 50.22076300212315, 47.2813275882176, 44.8551139150347, 48.95663206917899, 50.192101682935444, 52.127400806971956, 53.37764229093279, 50.54593869618007, 49.90589496067592, 50.881383827754426, 54.5289865902492, 51.65504142216274, 44.14346204485212, 36.06491661071777, 43.635795388902935, 54.198085580553325, 53.87500824247088, 53.62085703441075, 52.151497159685405, 51.66470289230347, 46.745124680655344, 39.892126832689556, 38.97396060398647, 41.289419991629465, 47.25499391555786, 49.696771553584504, 54.95519951411656, 40.89183712005615, 27.113350868225098, 32.90470218658447, 53.30690962927682, 52.656242098127095, 53.41102491106306, 53.478731632232666, 51.49733121054513, 48.64138535090855, 47.523680755070274, 47.207558563777376, 46.11240782056536, 45.54085942677089, 44.35159533364432, 44.71206092834473, 50.1440236227853, 51.45826843806675, 51.65104273387364, 48.68209484645298, 50.52565343039376, 53.44727366311209, 50.90591444287981, 45.957167693546836, 43.16080958502633, 40.63702583312988, 41.622419357299805, 45.02410452706473, 46.7823600769043, 50.90404190335955, 50.077373027801514, 52.80900866644723, 51.57719727924892, 48.71768004553658, 52.190632888248985, 48.10811110905239, 43.11173445837838, 34.92534603391375, 26.998469352722168, 23.676099606922694, 13.346243160111563, 9.544049058641706, 13.938087241990225, 11.627874612808228, 13.68042458806719, 21.71558199610029, 12.118730970791407, 5.902024831090655, 5.546977528503962, 1.7208617563758577, 0.4912469227399145, 0.2316530224468027, 0.7467704000217574, 5.502811304160526, 18.53220922606332, 29.472104481288365, 32.37330395834786, 28.015129770551408, 28.591029473713466, 36.20002085821969, 45.82327938079834, 53.876936367579866, 46.70556163787842, 24.862509727478027, 3.5918638791356767, 0.09125011534030948, 0.03958194676254477, 0.06180998044354575, 0.019844046694093516, 0.025751755938732197, 0.01972230394104762, 0.055364647547581365, 0.03346647009519594, 0.08449513638125998, 0.06075094334248986, 0.04323514198352184, 0.042140909271048646, 0.04251869721338153, 0.03142781502434185, 0.05701613732214485, 0.0296465859615377, 0.013330342065143799, 0.049278303781258206, 0.023427347719137157, 0.04996484551312668, 0.004527548236572849, 0.059293653682938645, 0.051006532473755736, 0.04567533711503659, 0.039806647026645284, 0.01998254926210003, 0.23699645857725823, 0.14536042644509248, 0.09313189650752715, 0.18928959779441357, 0.20253012302730763, 0.1542052932615791, 0.16016331927052566, 0.15080657920667104, 0.10698411427438259, 0.17102310939558915, 0.04901870306847351, 0.1262969850961651, 0.20167959295213223, 0.10033499356359243, 0.12653348169156484, 0.1062946141298328, 0.08465481602719852, 0.10452475052859102, 0.12247691436537675, 0.07292450618531023, 0.09546351246535778, 0.10321196847196136, 0.13210981818182127, 0.13847401525293077, 0.12074028540934835, 0.5383098402193615, 10.97943832193102, 42.96687841415405, 55.03708750861031, 57.014444078717915, 46.92584037780762, 34.99840981619698, 31.283072539738246, 44.20479031971523, 43.71890279224941, 41.0728793825422, 18.517647538866314, 6.449431274618421, 1.0465389745576041, 0.4506684387368815, 0.37504324104104725, 2.279592786516462, 7.544701439993722, 15.29067655972072, 21.264798504965647, 25.22591267313276, 13.154696089880806, 13.305079426084246, 18.79429006576538, 13.278095228331429, 14.607720749718801, 20.24206362451826, 29.621542862483434, 42.250456605638774, 55.14833164215088, 57.37511811937605, 58.0591995375497, 55.81036295209612, 55.047888483319966, 53.160198416028706, 49.23199265343802, 47.66124813897269, 51.24866907937186, 52.97626570292881, 55.27335752759661, 54.66320494243077, 51.96529585974557, 50.3490024294172, 51.091820444379536, 57.51023973737444, 53.595343249184744, 45.06114189965384, 38.10490424292428, 45.593519823891775, 55.24388326917376, 56.433526039123535, 56.159523827689036, 53.89284774235317, 54.58848054068429, 47.79325348990304, 41.605361529758994, 41.31502410343715, 43.282781737191335, 49.51688616616385, 52.364230155944824, 56.564041001456125, 43.139138153621126, 29.09373164176941, 37.75236654281616, 52.468651158469065, 55.220676285879954, 56.056124210357666, 57.12289156232561, 52.551428522382466, 51.86869158063616, 50.08761814662388, 50.73538480486189, 48.16991880961827, 48.337287017277305, 45.37925474984305, 45.38870429992676, 51.112863063812256, 53.53213201250349, 53.150265966142925, 49.46375676563808, 51.739253589085166, 56.02949523925781, 54.2240822655814, 48.863960470472065, 44.78732034138271, 42.97357995169503, 43.47121340887887, 47.26832403455462, 47.829234736306326, 53.70740032196045, 51.8246955871582, 56.86477640696934, 53.59475612640381, 50.937810148511616, 55.06124986921038, 50.464158398764475, 45.191299029758994, 41.34283079419817, 26.429912158421107, 29.94946656908308, 13.888349430901663, 12.861215472221375, 29.59315252304077, 12.542364375931875, 19.08882246698652, 30.69508123397827, 19.002006462642125, 9.905678476606097, 11.310852629797798, 2.5247271869863783, 0.7089070060423442, 0.30929588473268915, 1.0410728050129754, 7.08459563766207, 21.92570768083845, 33.92261675425938, 35.15369858060564, 33.52504777908325, 38.57828501292637, 43.51439993722098, 53.106961318424766, 58.09396832329886, 53.99201590674264, 31.23656824656895, 5.847969148840223, 0.214026039732354, 0.13326168565877847, 0.11709759730313506, 0.12024100577192647, 0.11406517002199378, 0.14879761343555792, 0.2090382238051721, 0.1424147430807352, 0.1323662365653685, 0.115854697568076, 0.20085635355540685, 0.26868816944105284, 0.11987235769629478, 0.0918400404708726, 0.12827141343482903, 0.10564914412264313, 0.11467754787632398, 0.13201529825372355, 0.059354097582399845, 0.14500072146100657, 0.0706833525161658, 0.12770978999989374, 0.1266781860696418, 0.12152304340686117, 0.10930616288845028, 0.12103456604693617], [0.02181068036173071, 0.03065368459959115, 0.03801666825477566, 0.022655829654208252, 0.02073924133687147, 0.02641952091029712, 0.015058476610907486, 0.028876038201685463, 0.06757825413452727, 0.03015518867011581, 0.02729093629334654, 0.04072207219100424, 0.07371181715279818, 0.015192458439352257, 0.07478903899235384, 0.026691691484302282, 0.02309221588075161, 0.02563477141250457, 0.046270100200282674, 0.024983399846990193, 0.07608449804995741, 0.033447002925510914, 0.03236649697646499, 0.05337814807093569, 0.08496575469949416, 0.5705965991531099, 8.207403251102992, 28.57856614249093, 44.42058399745396, 39.94577039991106, 30.233967508588517, 17.818332195281982, 23.104688440050396, 20.43680078642709, 38.50757319586617, 27.8993866784232, 11.381703410829816, 3.0025858538491383, 0.15919940599373408, 0.08258440212479659, 0.12354868756873266, 1.60652209179742, 2.1125470186982835, 6.247569169316973, 6.26272188765662, 4.317883321217128, 5.540849217346736, 4.8232926811490735, 2.572216170174735, 4.418201846735818, 7.099671057292393, 19.54149760518755, 29.082635368619645, 42.60462018421718, 46.97849382672991, 54.549018246786936, 51.4681522505624, 51.36142097200666, 48.15946524483817, 44.88233000891549, 42.469835553850444, 44.536045687539236, 48.68289736339024, 51.599983896527974, 52.637092862810405, 51.638511657714844, 49.859289918627056, 50.197795731680735, 48.49879789352417, 52.42791387013027, 51.56132064546858, 50.58258349554879, 42.99286815098354, 35.33976091657366, 41.41909074783325, 51.6267865725926, 49.79153803416661, 49.6668769291469, 43.419032437460764, 37.05469792229788, 36.84515067509243, 37.679976735796245, 37.369100434439524, 45.39069843292236, 47.19791099003383, 50.24735375813076, 49.62034484318325, 23.748140266963414, 26.205184834344045, 38.56760910579136, 48.95845249720982, 49.20654835019793, 51.33827999659947, 51.189935956682476, 50.3100369317191, 48.23394993373326, 49.73152296883719, 48.19615520749773, 47.09151322501046, 41.728685106549946, 39.333307538713726, 44.114043372017996, 49.20835835593087, 50.080777645111084, 49.808293615068706, 48.91500193732125, 50.692017623356406, 49.10284996032715, 47.74467168535505, 42.260903222220286, 38.61836222239903, 40.81659855161394, 40.616962909698486, 40.02858597891671, 41.18160131999424, 47.1663453238351, 46.58950240271432, 49.38297700881958, 49.17045245851789, 50.64987332480294, 48.9903690474374, 47.71277945382254, 33.925854614802766, 39.9415146282741, 28.818207774843486, 14.178624323436193, 9.608398931367056, 7.0467501027243475, 10.860351409230914, 11.393660392080035, 26.4042455128261, 11.654248237609863, 4.358752191066742, 3.905674925872258, 1.5683376150471824, 0.19998953863978386, 0.04929433756374887, 0.3305736572614738, 2.883307865687779, 13.409924268722534, 27.456850699016027, 29.083750554493495, 27.159304516656057, 22.774695907320293, 21.326922348567418, 32.715002468654085, 39.541718755449565, 43.51426444734846, 20.916057995387487, 6.555946724755423, 0.3746325373649597, 0.05527876876294613, 0.03397026538316693, 0.03162474963547928, 0.03704202055398907, 0.04228526420359101, 0.011229018348136117, 0.026500293718917028, 0.004320981820845711, 0.05630171797903521, 0.044095307255962064, 0.026274417892896702, 0.023594893282279372, 0.05170869408175349, 0.014973488403484225, 0.03530508625720229, 0.03855772529329572, 0.09074207581579685, 0.029170637750732045, 0.05095306730696133, 0.0220094402320683, 0.026358049030282667, 0.041604897140392234, 0.021392144695190445, 0.00980071909725666, 0.013673921664511519, 0.011324945388228765, 0.027779240626841784, 0.023546401777171662, 0.028574887397033826, 0.007801744754293135, 0.03308652101882866, 0.01408082215181951, 0.03865010444340961, 0.09540668515754597, 0.06443418748676777, 0.0723870996651905, 0.04638057587934392, 0.006975432018017662, 0.01400146069603839, 0.03837510098570159, 0.08118754279400621, 0.05762791128030845, 0.02894281961822084, 0.020124883856624365, 0.015123761857726743, 0.0657986399850675, 0.04599443517093148, 0.00961938824704183, 0.09730950769569192, 0.015433372297723378, 0.784791539822306, 11.116162368229457, 34.75934662137713, 50.667097909109934, 45.4111921446664, 38.16190031596592, 22.714468921933854, 27.29236946787153, 28.658336673464092, 41.09906019483294, 31.552832875932964, 12.358779072761536, 3.3219424315861295, 0.17061186289148672, 0.17167640291154385, 0.5561634536300386, 1.316923888666289, 4.503373733588627, 9.620962142944336, 9.071344000952584, 8.799778870173864, 12.621697170393807, 8.69680917263031, 10.032052312578474, 6.6075184260095865, 9.2265111718859, 15.973444768360682, 34.02233035223824, 43.18892894472395, 50.62587424686977, 55.260079520089285, 53.506163120269775, 53.461760657174246, 50.859156540461946, 46.01748847961426, 44.430724893297466, 46.73849262510027, 50.32252631868635, 54.75461196899414, 53.501858711242676, 51.72576018742153, 50.28977598462786, 49.331476960863384, 48.92942639759609, 52.817582743508474, 54.13865416390555, 52.57131426674979, 43.751844201769146, 37.02138131005423, 43.6202974319458, 51.360239778246196, 50.7970917565482, 51.656014169965474, 46.980908325740266, 38.22822434561593, 38.20422874178205, 39.72637060710362, 39.495763369968955, 47.49213245936802, 49.68740538188389, 51.027195249285015, 48.458456652505056, 25.48873175893511, 31.04785864693778, 41.39197192873274, 48.996865613119944, 49.341065474918906, 52.57580280303955, 51.460026332310264, 51.56254352842058, 50.55403682163784, 51.705099718911306, 50.47931241989136, 47.019745281764436, 42.876326016017366, 40.886323724474224, 46.56941516058785, 51.83145271028791, 51.73547724315098, 50.917528356824604, 49.59106513432094, 51.857643944876536, 50.9449702671596, 49.20822981425694, 44.89314488002232, 41.196404457092285, 41.09795543125698, 42.21429123197283, 42.496051107134136, 43.50718423298427, 48.762780802590505, 49.60053552900042, 51.786355427333284, 51.132130418504985, 53.192146233149934, 49.96650757108416, 47.95432315553938, 34.43541465486799, 32.48127201625279, 25.779493025371007, 14.216482451983861, 7.572768688201904, 8.31295941557203, 11.594646590096609, 11.228845647403173, 12.806950909750801, 8.656608632632665, 5.710359641483851, 7.072969564369746, 2.1018650318895067, 0.6146094745823315, 0.26177674744810375, 0.42368801363876885, 3.626475896154131, 13.104806286948067, 29.412207535334996, 29.905467101505824, 28.789987666266306, 29.55599355697632, 26.69918785776411, 39.902347632816856, 44.231693744659424, 48.85295452390398, 25.788393667766027, 7.557512181145804, 0.4316703810223511, 0.08614232085113015, 0.029188554467899457, 0.03231008696768965, 0.021635742159560323, 0.029903906796659743, 0.07897858561149665, 0.0744545076574598, 0.036300157862050195, 0.00566491881285661, 0.0244848801687892, 0.023983449575358202, 0.047642919035362344, 0.048636318051389286, 0.06134268694690295, 0.025073979182967117, 0.10012762647654329, 0.06251771282404661, 0.01436521059700421, 0.032413767118539126, 0.046156058819698434, 0.026007653546652625, 0.017225111867966394, 0.08098224523876395, 0.022104528433244144, 0.03001516279099243, 0.08843091090342828, 0.1015167369374207, 0.11002673315150396, 0.17135456018149853, 0.14281490232263291, 0.06413907225110702, 0.07479853169726473, 0.0914804372670395, 0.22315434419683047, 0.14325756499809877, 0.1529600593660559, 0.11784652354461805, 0.15013898217252322, 0.11217543642435755, 0.153779431113175, 0.1743329217923539, 0.16566604828195913, 0.1353156247309276, 0.1410410896475826, 0.0798076129119311, 0.19207577114658697, 0.18751034326851368, 0.08361941230084215, 0.1958656877811466, 0.21044101353202546, 1.0940242665154594, 14.210219519478933, 40.16411059243338, 56.64154468263899, 52.38386229106358, 41.929623535701204, 26.990192311150686, 31.3182338987078, 30.011725902557373, 49.46262420926775, 36.31318269457136, 15.871909005301339, 3.8715649162020003, 0.3944102589573179, 0.3268436959811619, 0.8705621116927692, 2.6512740765299116, 9.04965259347643, 14.931803839547293, 14.028174979346138, 13.942285690988813, 17.102454083306448, 12.858701961381094, 12.381913099970136, 12.795825106757027, 13.0121477161135, 23.190592493329728, 35.2528007371085, 46.28146096638271, 50.438147817339214, 58.794086183820454, 55.52055011476789, 56.95820883342198, 52.191810607910156, 48.55290004185268, 45.51223979677473, 49.0656076158796, 53.50151130131313, 56.56168556213379, 53.08543927328927, 52.13576296397618, 51.83605241775513, 50.335641043526785, 49.23744004113333, 53.0744229044233, 56.98723145893642, 56.196363176618306, 46.93029069900513, 39.49662494659424, 44.90834059034075, 54.32854495729719, 53.67894744873047, 53.35575893947056, 48.85153014319283, 39.81052371433803, 40.87785734449114, 41.041939054216655, 40.28764956338065, 50.30695193154471, 51.21324716295515, 54.055435589381624, 52.327321325029644, 30.580828530447825, 34.68477855409895, 47.20058604649135, 50.3817458152771, 50.384698799678254, 52.98014279774257, 51.98078339440482, 53.15723500932966, 52.96069131578718, 54.53333963666643, 53.466940539223806, 51.20970010757446, 45.29484803336007, 43.50292151314871, 48.04302733285086, 53.70189734867641, 53.837380273001536, 50.05617754799979, 49.6780218396868, 52.70154435294015, 52.69266108104161, 51.376411710466655, 45.68312726702009, 43.80501529148647, 44.6384482383728, 45.419064453669954, 45.29387181145804, 45.72422586168562, 51.10334403174264, 51.36435311181204, 54.87227971213204, 54.32663767678397, 54.39887809753418, 53.0909491947719, 50.93472514833723, 39.03974962234497, 43.75384528296334, 31.748692171914236, 17.845261675970896, 19.704712527138845, 15.489669493266515, 20.203949281147548, 19.982494558606827, 36.972695282527376, 18.653304168156215, 13.249094315937587, 11.505777393068586, 4.068981911454882, 1.3441495363201414, 0.5571254534380776, 0.6366002517087119, 3.715944375310625, 16.297074488231114, 33.90080288478306, 40.599759169987266, 38.14329304013933, 35.04138789858137, 31.376362528119767, 44.07794400623867, 51.56335646765572, 56.25814308438982, 31.8846823147365, 10.127097589629036, 0.833165875502995, 0.21901811685945305, 0.10813338974756853, 0.11893607436546258, 0.10377336799034051, 0.12124757175999028, 0.2420546928686755, 0.2055684942752123, 0.09580007261995759, 0.12808617337473802, 0.09845770429819822, 0.10410188750496932, 0.1343113657619272, 0.08809854409524373, 0.10134759172797203, 0.06457813190562384, 0.1923700382134744, 0.17248281463980675, 0.07577653136104345, 0.11059679756207125, 0.15607772421623978, 0.07908074584390436, 0.1631625254771539, 0.1703799803342138, 0.14804825293166296, 0.06262486707419157], [0.04424769604312522, 0.01794395356306008, 0.023927331336640885, 0.03316500037908554, 0.02888259963531579, 0.03777413269770997, 0.027481394287730967, 0.07323936000466347, 0.029980245378932784, 0.002886923503995474, 0.00649270905913519, 0.04087880699496184, 0.02585391277846481, 0.05639533545555813, 0.0820134352626545, 0.015370394069967526, 0.06823403108865023, 0.03304905570777399, 0.03440194257668086, 0.05268352498699512, 0.03809173797656383, 0.07315182898725782, 0.05260820759992514, 0.04340917603777988, 0.06542102167648928, 1.1156606312308992, 9.799183436802455, 33.22160605021885, 49.633119106292725, 40.69552966526577, 27.646449668066843, 26.367746625627788, 21.891057014465332, 28.268445457730973, 38.019861766270225, 23.98642873764038, 10.25337849344526, 2.1768332719802856, 0.2923239325838429, 0.18046154507568904, 0.6979718442474092, 1.1523255152361733, 4.1182116355214795, 8.813597968646459, 7.39592661176409, 5.453889037881579, 14.951823336737496, 9.39466278893607, 8.863023110798427, 1.6257972632135664, 7.95422739642007, 21.103079182761057, 35.35032565253121, 44.020753383636475, 51.99606595720564, 50.655761923108784, 53.720782552446636, 49.6235305922372, 50.51883029937744, 48.35341378620693, 45.492565972464426, 41.486759253910606, 48.22839484895979, 49.79012060165405, 52.34736687796456, 50.49222217287336, 52.00286129542759, 51.785320145743235, 53.54274538585118, 49.998052392687114, 52.66017130443028, 50.15634625298636, 51.173121316092356, 41.764235564640586, 36.497348172324045, 38.29232842581612, 41.46080425807408, 38.85899918419974, 36.82561928885323, 35.29798834664481, 36.15223809650966, 36.43900414875576, 38.13918318067278, 35.9942603792463, 43.57257720402309, 41.47935247421265, 54.8438754762922, 25.7221234866551, 25.054896661213466, 48.667552266802105, 48.20345776421683, 51.173215116773335, 49.354881967817036, 53.1055543082101, 46.38734456471035, 49.129145417894634, 48.162758690970286, 48.76037672587803, 48.65659843172346, 44.59346907479422, 37.372393880571636, 41.11134113584246, 48.28402212687901, 49.155103887830464, 49.8632538659232, 50.43230438232422, 48.415211064474924, 50.894022600991384, 47.98395374843052, 48.20911359786987, 43.269232749938965, 39.04763582774571, 39.7120885848999, 39.52753053392683, 40.937441621507915, 41.930867263248985, 44.70811782564436, 45.837630884987966, 45.730635574885774, 48.62154129573277, 48.67367710386004, 48.57744107927595, 35.07765402112688, 28.50216027668544, 26.38980368205479, 17.856776578085764, 12.797783630234854, 5.487805366516113, 12.025928224836077, 10.144218819481985, 7.389119114194598, 7.046230724879673, 3.0800858438014984, 4.759106959615435, 1.8972816211836678, 0.6981673166155815, 0.06505866362048046, 0.29965162224003244, 2.4181880695479254, 9.263070855821882, 24.871351310185023, 34.741715567452566, 40.683985233306885, 20.676296506609233, 22.152747017996653, 34.00172199521746, 38.437278270721436, 43.88832419259207, 27.714988436017716, 4.743702369076865, 0.6402649379202298, 0.0229138239353363, 0.04846143243568284, 0.02661116634096418, 0.024200497660785913, 0.029447398614138365, 0.06237140031797545, 0.06312420777976513, 0.017588345234149268, 0.04811305559373327, 0.02050229860469699, 0.03425980984632458, 0.013432764381702458, 0.03924294388187783, 0.07819507444011313, 0.00403664299353425, 0.019508997976247753, 0.05864758656493255, 0.016192907434222952, 0.07043075428477355, 0.02224172482133976, 0.018275769061541984, 0.06240248400717974, 0.05907371334199395, 0.0339285592282457, 0.043490210082381964, 0.06477993500552007, 0.02488029814724411, 0.044291794033987184, 0.07984797217484031, 0.08466181172324078, 0.050748682381319146, 0.028542996251157353, 0.007907329892207469, 0.04457094334065914, 0.01588871340001268, 0.006789788653674934, 0.05761878498430763, 0.05469668749719858, 0.014227808103896677, 0.01765791542961129, 0.0009817207922294202, 0.031340623274445534, 0.04691462025844625, 0.014066304046926754, 0.038841376679816415, 0.030540993503694023, 0.04057669606325882, 0.004650065367708781, 0.09504410997033119, 0.03566620598680206, 1.5667655851159776, 12.162978836468287, 37.85720443725586, 54.168673855917795, 45.94450112751552, 32.1292519569397, 27.69028237887791, 23.552411249705724, 25.407748767307826, 40.86668464115688, 25.837804044995988, 11.884858080318995, 2.519129978758948, 0.2811796191547598, 0.4621326135737555, 1.254948454243796, 1.9521365634032657, 4.735198208263942, 7.849202769143241, 7.962580868176051, 8.857577460152761, 13.00514827455793, 7.5662625687462945, 9.048574754170009, 8.452405418668475, 13.115699325289045, 17.868578093392507, 34.71016379765102, 43.20305463245937, 51.91614430291312, 52.943355560302734, 56.325905391148154, 51.607581751687185, 51.156226771218435, 49.46547991888863, 46.75272600991385, 43.91411590576172, 50.97816528592791, 51.06087664195469, 53.84458902903965, 51.79181671142578, 52.69932092939104, 52.459232875279014, 51.733191285814556, 49.6302946635655, 53.1478271484375, 52.547301292419434, 52.61328138623919, 42.9555424281529, 38.89503254209246, 40.752379826136995, 44.92518997192383, 41.8249454498291, 38.94681746619088, 37.47229160581316, 37.08198349816458, 38.27014977591378, 40.61463178907122, 38.466321740831646, 45.2018255506243, 43.709241322108674, 55.387335777282715, 28.35345666749137, 29.81085000719343, 51.80922889709473, 47.81583513532366, 51.583853653499055, 50.75188677651541, 53.19330310821533, 47.374919823237825, 49.86580038070679, 49.6858628817967, 50.390462330409456, 51.31969356536865, 48.12491880144392, 39.72743368148804, 42.77048758098057, 50.20258304050991, 51.05214275632586, 50.076834542410715, 50.56262826919556, 49.658389704568044, 53.02243300846645, 49.379534176417756, 48.99846369879586, 45.00461483001709, 42.391776016780305, 43.2323134967259, 42.029576846531455, 42.87828540802002, 44.77976417541504, 46.72928973606655, 48.81629582813808, 48.9836015020098, 50.29045343399048, 50.575847217014854, 50.52935334614345, 38.794426100594656, 31.725342750549316, 21.450252873556956, 15.55571733202253, 13.692939162254333, 10.336711713245936, 14.396680508341108, 13.181232128824506, 14.138558404786245, 7.819244742393494, 7.048528841563633, 5.235530606337956, 3.055619499513081, 0.5749394404036658, 0.1918704600206443, 0.2414453684219292, 2.729124516248703, 10.492753488676888, 25.88314972605024, 33.66182654244559, 41.40975931712559, 24.998105560030254, 29.241695267813547, 38.96028307506016, 43.20255088806152, 50.9493476322719, 33.49912405014038, 6.300775868552072, 0.6864688300660678, 0.03345141001045704, 0.062219143845140934, 0.027182521664404442, 0.017245659604668617, 0.028129741283399717, 0.04697538646204131, 0.052172292955219746, 0.022392542799934745, 0.012940725561098328, 0.053426018716501336, 0.05338299959631903, 0.02889976996396269, 0.018152148462831974, 0.03369042397077594, 0.023598055255466273, 0.010509738149786634, 0.04258914950436779, 0.01318429333956114, 0.03856398477884276, 0.04880210111982056, 0.04862451832741499, 0.055695209452616315, 0.029487208263682466, 0.07233546315027134, 0.008081216365098953, 0.1269186453095504, 0.1591507007500955, 0.10393099846052271, 0.20603312791458198, 0.13137163993503365, 0.12815503110843046, 0.11022120128784861, 0.08567243535071611, 0.10276590633605208, 0.10512134565838746, 0.08996348402329854, 0.23199964527572903, 0.1496338942753417, 0.09333372674882412, 0.18514539088521684, 0.154013973527721, 0.11830935228083815, 0.08589817716607026, 0.15095857105084828, 0.15913645151470387, 0.09375515806355647, 0.11138497026903288, 0.18976491157497677, 0.21682659802692278, 0.12317820744855063, 2.3155536225863864, 16.714067152568273, 47.77668898446219, 60.02786391122, 52.72481734412057, 37.18318053654262, 36.54670122691563, 30.41224786213466, 38.71101645060948, 48.459749017442974, 30.476633344377788, 13.056481565747942, 3.2392888324601308, 0.5545653136713165, 0.56692892738751, 1.3814553916454315, 2.938803127833775, 7.5716317892074585, 14.40297818183899, 17.06100981576102, 18.22579366820199, 24.728425128119333, 22.49430309023176, 15.138179234095983, 9.59588348865509, 13.038061891283308, 24.01526549884251, 39.38508204051426, 46.723738125392366, 55.061246395111084, 53.102674279894146, 57.43393809454781, 54.004852703639436, 54.6263655935015, 52.24062865121024, 49.78139019012451, 46.87329462596348, 51.811198711395264, 53.15779781341553, 54.99160460063389, 53.60078368868147, 54.85069860730852, 53.13170037950788, 53.96495962142944, 49.493119852883474, 55.19294949940273, 53.63229029519217, 57.75885670525687, 46.841492721012656, 41.206882340567454, 41.74135167258126, 45.066127232142854, 43.08983721051897, 40.68192509242466, 39.34965664999825, 40.622809818812776, 40.48301901136126, 42.60281365258353, 40.00121702466692, 47.388315950121196, 45.78936174937657, 57.425030503954204, 33.325231484004426, 31.520874636513845, 51.467488697596956, 49.42307506288801, 51.358756337847026, 51.522275243486675, 52.5612393787929, 49.01052924564907, 49.53837694440569, 51.44467428752354, 52.90619659423828, 52.70583486557007, 50.5879614012582, 41.82472310747419, 45.09180082593645, 53.86942883900234, 53.83547994068691, 50.3539981842041, 50.648893628801616, 48.97972093309675, 54.625045435769216, 51.23948703493391, 52.95270436150687, 47.13295922960554, 43.885034220559255, 44.71455185753958, 43.35326426369803, 44.621067319597515, 46.70116342817034, 48.530050890786306, 50.6435226712908, 49.47935894557408, 53.094697747911724, 52.556021281651084, 52.004459381103516, 40.405907903398784, 33.090097495487754, 27.47604857172285, 22.220524958201818, 16.28162169456482, 12.034976516451154, 22.013076066970825, 22.104399715151104, 19.23750696863447, 17.8974061693464, 12.370983583586556, 8.253048573221479, 5.05337576355253, 1.3387895439352309, 0.4439690996493612, 0.5100283920764923, 3.662167489528656, 11.495750273977007, 31.483083384377615, 42.81567171641758, 50.63493469783238, 30.222648893083843, 34.134884221213206, 43.783100673130576, 49.10175561904907, 57.794751099177766, 39.86223915645054, 9.377618857792445, 1.0322156974247523, 0.10153899288603238, 0.12444092040615422, 0.13089639400797232, 0.12762037265513623, 0.13227004744112492, 0.1996714278523411, 0.16411700711718627, 0.18059347942471504, 0.13835167538906845, 0.08523552665220839, 0.15849944283919676, 0.08934616643403258, 0.14267014366175446, 0.11212289745786361, 0.10350343997457198, 0.13100798587713922, 0.15377347357571125, 0.19902021065354347, 0.1249195725790092, 0.1881707478314638, 0.1449681653508118, 0.11242099146225623, 0.17490350188953535, 0.1679458852325167, 0.15313349291682243], [0.05662641055615885, 0.03690169272678239, 0.03558551799505949, 0.025693966807531457, 0.022599158409450735, 0.043683572206646204, 0.025295817725626484, 0.02793468112525131, 0.029204215056129863, 0.03329875320196152, 0.04423007448869092, 0.05138848662110312, 0.011215626611374319, 0.045204016513058116, 0.06176723952272108, 0.10865589563867875, 0.08793276441948754, 0.03201076481491327, 0.010774369351565838, 0.016942308650219014, 0.043401128612458706, 0.012511742999777198, 0.02364401412861688, 0.023840541618743112, 0.009269376983866096, 1.665297229375158, 14.534927078655787, 37.70217275619507, 44.841766425541465, 34.758349554879324, 30.09042467389788, 21.564861672265188, 31.363397189549037, 46.614463806152344, 41.61005503790719, 26.416717529296875, 7.871942486081805, 1.1697548542703902, 0.13561758638492652, 0.2674981275839465, 1.1071607044764926, 1.8016507412706102, 3.151321164199284, 8.386050122124807, 5.003987533705575, 5.046569134507861, 10.478170956884112, 6.108772388526371, 7.795051983424595, 10.597632203783308, 16.52417462212699, 15.184323957988195, 37.65983738218035, 43.25681631905692, 51.604031222207205, 49.97547769546509, 52.90630429131644, 51.802006244659424, 50.55155284064156, 48.31297179630825, 47.90921197618757, 43.90704958779471, 42.90719338825771, 45.063837800707134, 46.58462824140276, 46.87578208105904, 47.34233277184622, 48.87264224461147, 51.25869185583932, 52.458864620753694, 53.819714478084016, 51.57047142301287, 53.131676060812815, 49.416262354169575, 42.43778698784964, 35.37196929114205, 35.31947217668806, 31.500030040740967, 34.75058494295393, 34.26309585571289, 40.62272991452898, 38.018697943006245, 38.3839682170323, 34.88123539515904, 40.69879184450422, 41.057350158691406, 53.44102028438023, 33.087637833186555, 32.45634535380772, 59.688340187072754, 47.66997855050223, 51.88739613124302, 46.90300859723772, 49.217189516339985, 47.94480759756905, 49.65132686070034, 47.97320141111101, 52.77817256110055, 48.75940745217459, 50.68602480207171, 39.66312115533011, 42.18972587585449, 49.14509848185948, 51.43234123502459, 46.35479572841099, 49.66315269470215, 47.75995077405657, 48.8501752444676, 51.056256089891704, 48.50721563611712, 46.538179533822195, 45.39299133845738, 41.385999952043804, 40.64734738213675, 38.85960367747715, 39.37165812083653, 40.5673041343689, 43.850869928087505, 45.330964769635884, 49.17367989676339, 49.107407978602815, 51.71426786695208, 40.05308880124773, 34.45210075378418, 26.26475347791399, 12.63352734701974, 10.17427933216095, 11.42778560093471, 9.36116291795458, 7.354649969509669, 11.041363273348127, 4.016407064029148, 3.3101165975843156, 5.759430859770093, 1.8289615043572016, 0.188953519399677, 0.15926664881408215, 0.0034090871590056588, 1.3343050245727812, 6.332028431551797, 21.61101508140564, 28.254877362932476, 25.34496658188956, 22.42998014177595, 16.74165323802403, 36.526315212249756, 44.02263287135533, 42.20459849493844, 31.286178384508403, 8.038403953824725, 1.1614268954311098, 0.0919286503589579, 0.04966072611776846, 0.009526339043597025, 0.07393164892813989, 0.05074146955407091, 0.06441541920815196, 0.026178508664348295, 0.0848742610375796, 0.06344858144543, 0.09268628899008036, 0.021427016306136335, 0.03564165658982737, 0.0365808881553156, 0.0475682394712099, 0.021713470042284046, 0.04197992344519921, 0.030021418883864368, 0.007468020027902509, 0.02475273865275085, 0.03835773727457438, 0.07257145084440708, 0.02182732312940061, 0.043155268233801634, 0.04882323070030127, 0.03879149078524538, 0.007301466822225068, 0.06647696465786014, 0.06740166539592402, 0.03751377881105457, 0.044265975776527605, 0.013814239313692918, 0.02251848059573344, 0.021985048594485437, 0.03761282796040177, 0.03925654511632664, 0.051943029543118815, 0.012274078475976629, 0.03963515408603208, 0.024323117420343415, 0.052421118531908305, 0.01688049071734505, 0.10454817355743476, 0.06625351629086904, 0.038915723761809726, 0.025708000608054653, 0.00916621760864343, 0.03772272349202207, 0.025680367269420197, 0.012087177701427467, 0.09367414776768003, 2.3701523499829427, 17.01824712753296, 44.83871616636004, 49.871296405792236, 40.57454068320138, 33.99532617841448, 27.565591744014196, 27.940170867102488, 43.347549370356965, 40.82511704308646, 25.81666762488229, 9.259230239050728, 1.4731185244662421, 0.1270006259105035, 0.16113219942365373, 1.2645709493330546, 5.310554214886256, 9.098564437457494, 9.513675877026149, 8.087046555110387, 8.821716070175171, 10.68060759135655, 11.004444888659886, 6.52077841758728, 5.07708431993212, 14.55846757548196, 21.269941908972605, 36.291962896074565, 44.59912838254656, 51.921775817871094, 51.72524602072579, 54.669093540736604, 53.27440595626831, 53.413748604910715, 50.62870563779558, 50.05713292530605, 46.12860059738159, 45.84241819381714, 47.659643105098176, 48.78165558406285, 48.837265491485596, 49.049689292907715, 51.711915901729036, 53.09587894167219, 54.01044947760445, 54.01535143171038, 50.84976257596697, 54.943564755576, 50.214818818228586, 43.906181062970845, 36.15839420046125, 36.922890595027376, 34.184344972882954, 36.409290177481516, 36.09415463038853, 41.87265872955322, 39.45720434188843, 40.07585457393101, 36.17085926873343, 42.77262762614659, 44.18226078578404, 54.86176708766392, 34.574833733694895, 34.085961954934255, 58.209395272391184, 48.328601769038606, 53.67160667691912, 48.00475318091256, 51.14927509852818, 49.46541043690273, 52.12869317190987, 48.60329532623291, 54.226639202662874, 50.954631737300325, 52.83018677575247, 41.601744992392405, 41.97918503625052, 49.64687653950283, 53.214915479932515, 47.76209429332188, 50.41501726422991, 48.32924100330898, 50.17699629919869, 53.64929601124355, 50.50495474679129, 48.3648088318961, 46.09529788153512, 41.96680334636143, 42.71777854646955, 41.014455454690115, 42.030504431043354, 42.85348033905029, 46.40417310169765, 46.140805108206614, 51.45529113497053, 51.461332593645366, 53.351121016911094, 39.98362765993391, 34.37548991612026, 23.671404361724854, 11.907694203513008, 5.449627186570849, 11.797824944768633, 13.778426323618207, 13.307081375803266, 11.570294891084943, 7.7163063117436, 8.761431762150355, 6.974113200392042, 4.000304179532187, 1.0043372448001588, 0.3327272188450609, 0.23728744153465542, 1.7962342947721481, 7.188892875398908, 21.62271932193211, 31.14939614704677, 31.120071274893625, 25.864646673202515, 20.53152905191694, 39.587663718632285, 48.36937379837036, 48.05441543034145, 36.70275429316929, 10.3907721723829, 1.2406298454318727, 0.0708672490769199, 0.0734614852283682, 0.04649179794692567, 0.09188379240887505, 0.04500228126666375, 0.022111649658264856, 0.02739002785113241, 0.05856237613729068, 0.07533441151359252, 0.06269307341426611, 0.017471986656476344, 0.09004401934466191, 0.014941256293760878, 0.0398495134764484, 0.040706598199903965, 0.10650736878493003, 0.055922807061246464, 0.04962737951427698, 0.0723461297207645, 0.03323884195248995, 0.029012321960180998, 0.03164556708985141, 0.03439219202846289, 0.02028980179290686, 0.01140103121620736, 0.15202319249510765, 0.13852820305952004, 0.20918670083795274, 0.07470868009009532, 0.04944961691009147, 0.1525959846164499, 0.08809706488890306, 0.08333888556808233, 0.08219518086739949, 0.10227834499840226, 0.09644244850746223, 0.15350766426750592, 0.06951249284403664, 0.18908953852951527, 0.1712679655424186, 0.28981419439826694, 0.2864983023277351, 0.1437120341828891, 0.08205565371151481, 0.08864772319793701, 0.13503511835421833, 0.1087404139606016, 0.08288685232400894, 0.12292222332741533, 0.19840007035859994, 3.6654166408947537, 22.047961235046387, 50.98008646283831, 56.39607177461897, 45.14359964643206, 38.68611758095877, 32.411390508924214, 39.90962587084089, 58.56738730839321, 49.35336378642491, 30.589006560189382, 10.102663380759102, 1.929851736341204, 0.2697716270174299, 0.6814190638916833, 2.1443474037306647, 6.756013589245932, 11.559349741254534, 20.040965386799403, 15.934354203087942, 13.75814974308014, 16.735521452767507, 10.737613218171255, 17.259888104030065, 18.16775015422276, 21.986968210765294, 19.591050420488628, 40.23097310747419, 44.72540494373867, 52.1179964201791, 51.90241813659668, 55.16267967224121, 55.43509422029768, 55.58993482589722, 51.80366686412266, 53.322438853127615, 47.77161679949079, 48.97946384974888, 50.35894530160086, 50.402614729745046, 50.96442174911499, 50.91682658876692, 53.938480036599294, 55.023027828761506, 55.62425545283726, 53.74920763288225, 52.83035353251866, 56.66137831551688, 54.01685571670532, 45.38817623683384, 37.784644399370464, 38.87934698377337, 34.793827056884766, 38.173806054251536, 38.69079371861049, 44.07741594314575, 41.35236372266497, 42.17963014330183, 38.27137960706438, 44.6671964100429, 46.88978270121983, 55.722162519182476, 37.992749895368306, 37.08693061556135, 57.796568053109304, 50.86703927176339, 56.57376153128487, 51.62749181474958, 52.034927231924875, 52.48044572557722, 53.26390722819737, 49.62226949419294, 56.238705498831614, 52.28334617614746, 55.455671310424805, 44.0544764654977, 45.496356214795796, 50.96735736301967, 54.86762094497681, 47.27454267229353, 50.514786447797505, 47.4898465020316, 51.53856182098389, 54.99730559757778, 53.47047022410801, 51.573288917541504, 50.38376426696777, 44.61077356338501, 44.282957553863525, 42.75757435389927, 44.407333782741, 44.39974634987967, 48.79831389018467, 48.92670270374843, 53.53476537976946, 53.0499061856951, 55.133184569222585, 44.50405618122646, 39.21948562349592, 29.749045780726842, 17.51957528931754, 16.589984485081263, 20.26055451801845, 19.59690601485116, 15.512732301439558, 17.401329108646937, 11.008902158055987, 11.911309003829956, 14.95959837096078, 4.943354947226388, 2.0367654051099504, 0.8226430458681924, 0.37531009529318127, 2.23892519729478, 8.302181022507803, 26.804539918899536, 37.5843243598938, 35.44813196999686, 31.62301662990025, 26.29196436064584, 44.83692700522286, 54.883782454899375, 54.00699274880545, 43.71166624341692, 15.185298442840576, 1.9732723321233476, 0.19330478805516446, 0.09245902047093425, 0.1000879593193531, 0.25068397553903715, 0.1226623308445726, 0.1297112511737006, 0.1861495277179139, 0.16545800944524153, 0.2221718526312283, 0.15505012364259788, 0.09048911117549453, 0.07376648671925068, 0.14128834780837807, 0.1483884703900133, 0.14120054537696497, 0.24802088843924658, 0.1294236880327974, 0.13788339123129845, 0.08598770307643072, 0.11032600102147885, 0.14111437142959662, 0.10666881940726723, 0.06544227339327335, 0.10568657211427178, 0.13339343001799925], [0.05915213841944933, 0.0679818264075688, 0.039015129142041714, 0.03609878223921571, 0.046042187072868855, 0.03685319782899959, 0.08559309425098555, 0.07099202488149915, 0.03872412243591888, 0.007471964012698403, 0.09009960493338959, 0.03431121226666229, 0.042137947465692244, 0.04032091550262911, 0.023820855621514574, 0.050255886146000454, 0.05060470064303704, 0.03661603626928159, 0.014643002833638872, 0.045610119721719196, 0.02563976034122918, 0.03001779889953988, 0.03320619424006768, 0.03450883898351874, 0.03710421168112329, 3.573299812419074, 19.553815024239675, 42.9712210382734, 45.32740381785801, 35.080579212733674, 22.9474333354405, 25.295742068971904, 47.96058348246983, 46.643489905766074, 42.06194850376674, 21.999184880937847, 6.136731939656394, 0.7817909494042397, 0.13504764411066258, 0.7810625827738217, 3.829017622130258, 6.814207358019693, 5.895351954868861, 3.8437217473983765, 4.413579557623182, 6.776329687663487, 10.47449883392879, 8.045137626784188, 6.4599074210439404, 7.871321490832737, 21.351687465395244, 29.443106174468994, 37.2729616846357, 48.060276235852925, 50.43459728785923, 50.43662963594709, 49.4980912889753, 49.34012746810913, 51.039920875004356, 50.63266611099243, 48.24912479945591, 46.485571248190745, 45.582295009068076, 42.233846936907085, 43.59710781914847, 41.83666011265346, 41.20880699157715, 43.61125087738037, 48.18993656975882, 49.34292759214129, 51.8708872113909, 50.115841729300364, 51.7561411857605, 50.30044494356428, 47.55326965876988, 40.46437004634312, 36.28036635262625, 34.06622212273734, 35.0670336995806, 43.498294012887136, 46.90742070334298, 45.7967198916844, 42.73988424028669, 36.825570651463096, 38.56046288354056, 40.31956263950893, 50.35214648927961, 39.69660799843924, 34.307939529418945, 53.328389985220774, 47.997408935001914, 45.97354459762573, 41.55235372270857, 45.91550976889474, 46.278709479740684, 47.472361360277446, 47.33363362721035, 50.805210726601736, 48.48237235205514, 49.55183213097708, 40.284158093588694, 36.56629514694214, 49.27672863006592, 48.37431049346924, 49.416759150368826, 48.32678828920637, 45.84084790093558, 47.16222504207066, 48.73762137549264, 52.02588415145874, 48.610604831150596, 47.05226979936872, 45.49672099522182, 45.59289448601859, 45.12159817559378, 45.21526684079851, 43.559149810246055, 43.58585868562971, 44.97788858413696, 46.2549501146589, 49.534256662641255, 51.866492475782124, 42.14651155471802, 32.86969368798392, 16.003893511635916, 15.221170255116053, 8.68045745577131, 11.271653498922076, 12.325056859425136, 15.17316688810076, 15.679146868841988, 6.171067331518445, 6.487691095897129, 2.7424817766462053, 3.9064244627952576, 1.3257053260292326, 0.04994094750976988, 0.0284291109336274, 0.7115209943481854, 4.808659340654101, 16.413024289267405, 36.08367674691336, 46.95317806516375, 41.56255715233939, 39.24967902047293, 33.44715847287859, 32.14057404654366, 40.61716440745762, 34.111687660217285, 10.673318062509809, 1.1805794962814875, 0.0978927763977221, 0.041696061712822745, 0.03828679643837469, 0.015342594490253499, 0.04123914301661508, 0.041633426145251305, 0.004518800647929311, 0.035253015479871204, 0.04207402268158538, 0.0469007408246398, 0.023685727068888288, 0.033004031516611576, 0.009977439302019775, 0.022977056613724147, 0.06064845062792301, 0.010872597473540475, 0.010901587034043456, 0.043971481400408914, 0.06313967159284012, 0.0402112269241895, 0.02749980124644935, 0.05701773187943867, 0.04117581534332462, 0.05573366542479821, 0.06895222647913865, 0.03394347342795559, 0.13130390856947216, 0.04956076094614608, 0.019118597764255743, 0.07948222144373826, 0.04336450807750225, 0.059519415854343345, 0.06864584756216832, 0.008550838933193257, 0.04030534651662622, 0.039264148101210594, 0.015416006890258618, 0.03893326049936669, 0.05511178468753185, 0.08829817588308028, 0.010480586589047951, 0.08007490821182728, 0.03555953010384526, 0.015211769545982991, 0.010093489146259214, 0.06215217922415052, 0.020740128521408354, 0.03789075929671526, 0.10371323621698789, 0.05091704727549638, 4.5741876023156305, 23.723036425454275, 48.31359713418143, 50.175474643707275, 38.50282410212925, 27.00456987108503, 26.82934151376997, 43.28725290298462, 45.49438292639596, 41.90799726758684, 24.424936498914445, 7.476355484553745, 1.012379133275577, 0.046114267847899876, 0.5203776795949254, 2.8408548065594266, 6.399164966174534, 9.57045134476253, 8.652004582541329, 9.903410758290972, 8.902125835418701, 12.002863679613386, 14.298764756747655, 8.480436188834053, 9.110349450792585, 16.446434702192033, 28.53489671434675, 40.83539342880249, 47.58825036457607, 50.708867004939485, 50.27989912033081, 50.20786714553833, 49.48128707068307, 52.5076652935573, 52.46133817945208, 50.73181343078613, 48.2184728213719, 47.486886569431846, 43.47900233949934, 45.59202248709542, 42.63410139083862, 43.91287565231323, 45.79332569667271, 49.3538293157305, 51.1180533681597, 52.434615407671245, 50.74597385951451, 51.996833733149934, 52.050428662981304, 47.96140684400286, 42.76179885864258, 37.165542534419465, 35.46751396996634, 36.45829234804426, 44.42335980279105, 50.957824434552876, 46.65468692779541, 44.73927354812622, 39.074250902448384, 39.965722152165, 42.67750678743635, 52.993591036115376, 41.34845536095755, 36.82452147347586, 53.58624458312988, 50.34684501375471, 48.81085886274065, 45.24736751828875, 48.25069856643677, 48.032990659986226, 49.00198296138218, 49.34369536808559, 51.60827309744698, 50.53162540708269, 52.24187585285732, 42.22205931799752, 39.551536560058594, 51.56959247589111, 51.76444775717599, 49.5166916166033, 48.580550398145405, 46.82073497772217, 46.85067823954991, 49.79227801731655, 53.57600293840681, 50.88541725703648, 50.73716006960188, 45.94869783946446, 48.203353541237966, 46.38028866904122, 46.72075039999825, 45.13691895348685, 45.43834570475987, 46.966348375592915, 49.552495683942524, 50.68178987503052, 53.57866757256644, 44.85211229324341, 35.22536924907139, 21.382874454770768, 15.199012449809484, 10.832097428185598, 9.568913187299456, 15.975131443568639, 11.171439630644661, 14.552048308508736, 9.14824492590768, 10.153379150799342, 5.9686207090105325, 4.807092956134251, 1.4376532903739383, 0.2297193876334599, 0.2632510411952223, 0.7549134716391563, 5.819175813879285, 17.37666474069868, 36.35040419442313, 41.80574062892369, 36.97660711833409, 33.54769890648978, 38.06252717971802, 38.27195978164673, 47.84325967516218, 40.707702909197124, 13.016750029155187, 1.5282986206667764, 0.05739369456257139, 0.00919061094256384, 0.04043720283412507, 0.037428707483091524, 0.005813168112321624, 0.005605303574286933, 0.03172343237591641, 0.027136986875640493, 0.052384718520832915, 0.0038600919984414107, 0.04226528134729181, 0.032354985629873614, 0.03430559399670788, 0.05723554162042482, 0.033616066710757356, 0.01732749262425516, 0.06488058210483619, 0.048112729896924326, 0.02611033625102469, 0.03159754716658166, 0.0347201110396002, 0.0038244574596839292, 0.06293976160564593, 0.00855196954216808, 0.02349659052145268, 0.1042059679914798, 0.28495197530303684, 0.10596497503242322, 0.12456801001514707, 0.20143529320401804, 0.10732628591358662, 0.1321725691003459, 0.1407019714159625, 0.09979208412447146, 0.09466685807066304, 0.18137072771787643, 0.08017630169966392, 0.13976194257182734, 0.2106689198740891, 0.31303808678473743, 0.13097051717340946, 0.1290309519640037, 0.11765654731009688, 0.07850015735519783, 0.25339911984545843, 0.21714683941432408, 0.1094856286155326, 0.1652691595788513, 0.10555830863969666, 0.22923510361995014, 5.878875604697636, 28.75467344692775, 56.00099720273699, 58.61371789659773, 44.49695859636579, 34.15974834987095, 34.935837813786094, 56.12192712511335, 55.39537484305245, 46.12385497774397, 26.145103761128016, 8.050325325557164, 1.345548186983381, 0.21780077075319632, 1.5410505192620414, 5.7462939875466486, 10.787467411586217, 10.882408465657916, 11.38999695437295, 15.74234594617571, 16.130246503012522, 18.064671891076223, 19.342923300606863, 15.234378780637469, 14.320885215486799, 24.670524052211217, 31.904581955501012, 41.94852958406721, 49.00376170022147, 50.97498301097325, 51.510348660605295, 50.41922092437744, 50.2877471106393, 53.607193401881624, 55.01500265938895, 51.92506231580462, 51.70160130092076, 50.67141621453421, 45.363020283835276, 48.45184196744646, 45.12079913275582, 45.44460950578962, 47.26133067267281, 51.88821949277605, 53.2701084954398, 55.101215907505576, 51.6943439074925, 53.65651866367885, 55.91392585209438, 50.479208196912495, 45.988483224596294, 39.97745418548584, 38.34815720149449, 39.43896532058716, 47.259096826825825, 52.92067664010184, 49.73118250710623, 45.31453922816685, 42.053006172180176, 43.14417559759957, 45.33097519193377, 53.77736520767212, 45.54551819392613, 39.93861028126308, 54.84819378171648, 52.99531418936593, 50.624161515917095, 45.99864149093628, 49.790388107299805, 51.14835098811558, 51.91046762466431, 51.596235343388145, 53.8013573374067, 52.62355429785592, 54.46697391782488, 44.65739597593035, 40.06400442123413, 54.39880861554827, 53.13184629167829, 49.931561606270925, 49.079941749572754, 46.10057156426566, 47.267003876822336, 51.26560531343733, 55.603970187050955, 52.82392297472273, 51.85724442345755, 49.068355628422324, 49.189619064331055, 49.200576373508994, 48.67418779645647, 47.52586248942784, 48.568964276994976, 49.27450173241751, 50.58210754394531, 53.63124459130423, 55.78498813084194, 45.828153542109895, 38.238952364240376, 20.976092168263026, 20.591062954493932, 14.684248208999634, 21.27748417854309, 18.905357020241873, 22.13208828653608, 28.40681709562029, 21.450390100479126, 17.813103675842285, 9.376460245677404, 9.829575725964137, 3.4172172163214003, 0.488187272633825, 0.4496540017426014, 1.2221222328288215, 6.903497789587293, 20.56672167778015, 43.136709758213584, 56.47967250006539, 51.404221875326975, 48.93070486613682, 43.95205307006836, 42.34555312565395, 53.75443615232195, 47.76287249156407, 17.691835028784617, 2.2498629646641866, 0.20484027692249843, 0.07643173834575073, 0.14565330930054188, 0.1454758723931653, 0.0943283640912601, 0.16446130935634884, 0.16013521435005323, 0.11209734382906131, 0.15140332361417158, 0.1739493730877127, 0.13648441487124988, 0.11331599272255387, 0.12360541309629168, 0.13940370322338172, 0.16511536283152445, 0.06452282451625381, 0.10822259674647025, 0.09775730688124895, 0.12260119483939239, 0.2014001179486513, 0.16537027486733027, 0.0944885051410113, 0.15995306840964726, 0.11639690133077757, 0.0976415623777679], [0.023193955421447754, 0.034490569428141625, 0.04566420574805566, 0.03063175774046353, 0.01941357390023768, 0.019695118435525467, 0.039331268785255294, 0.03211075034258621, 0.021373749610834887, 0.09021211282483169, 0.005041740801451462, 0.04915784685207265, 0.0372018528703068, 0.007858270962190415, 0.02899352993283953, 0.024187632636832337, 0.03646147617005876, 0.022895452599706392, 0.02272884002221482, 0.03413859295791813, 0.029916795569338968, 0.07067158671894244, 0.06619951847408499, 0.014341014038239206, 0.012117890740877815, 3.467705649988992, 23.799867868423462, 40.82465846197945, 43.17757906232561, 29.834762232644216, 23.929078306470597, 42.55005945478167, 52.97346905299595, 51.699634960719514, 41.290986810411724, 15.768393005643572, 4.127254715987614, 0.45556434031043735, 0.06401753984391689, 0.6353648837123598, 0.7845443359443119, 4.191994556358882, 13.612693548202515, 9.725993718419756, 7.456888369151524, 6.247479711260114, 8.88443832738059, 12.615100724356514, 4.279935734612601, 6.589761435985565, 19.44530848094395, 33.49606684276036, 47.382125105176655, 49.57525103432791, 51.36401612418038, 49.02062497820173, 50.026720660073416, 49.027736459459575, 49.37032781328474, 49.9093690599714, 50.441861629486084, 48.68409245354788, 48.19858360290527, 47.85121883664812, 45.821729932512554, 41.429245540073936, 39.06834145954677, 35.426530020577566, 39.4937310218811, 45.25412464141846, 49.3509875025068, 50.51570013591221, 50.88959659848894, 48.926240648542134, 45.84732362202236, 39.16878114427839, 36.39419869014195, 34.14839499337332, 42.161464078085764, 48.53321579524449, 52.77093253816877, 47.84559774398804, 47.400047983442036, 38.83560807364327, 40.36941596439907, 39.687061173575266, 51.22695943287441, 40.80760063443865, 37.38674191066197, 55.98076057434082, 43.41178546633039, 46.534483092171804, 41.06311368942261, 38.44549104145595, 39.43842683519636, 44.93557405471802, 46.28674854551043, 50.95660155160086, 49.99608257838658, 49.29890033176967, 39.76306751796177, 35.10025303704398, 43.65706035069057, 50.47137062890189, 50.42609964098249, 51.608019488198416, 48.917023863111226, 46.824417522975374, 46.989458084106445, 50.376305375780376, 49.7906208719526, 48.751514298575266, 48.21151072638375, 44.336476053510395, 45.28262267793928, 48.43404763085501, 47.912911891937256, 48.441572529929026, 46.417301722935264, 49.563807351248606, 49.7823212487357, 52.346119676317485, 43.120565618787495, 33.703613008771626, 28.351591076169694, 14.967974424362183, 3.770493813923427, 5.707051864692143, 17.23412070955549, 12.349049857684545, 7.6453695467540195, 4.842110574245453, 8.278895003455025, 4.729340008326939, 3.597434163093567, 0.8126939311623573, 0.18053767670478138, 0.04428348198000874, 0.41066309969340054, 3.9115470222064426, 16.11767373766218, 37.266086442129954, 58.28695106506348, 56.39294855935233, 41.41742665427071, 29.13531139918736, 31.931645189012798, 46.20816789354597, 34.92245210920061, 16.248820986066544, 1.5871360749006271, 0.037641506242964945, 0.05650118691846728, 0.05411282507702708, 0.021104842790269425, 0.06497056263365916, 0.05810518602707556, 0.02460695879666933, 0.029812752402254512, 0.003351936274806836, 0.07332632783800364, 0.03901352779939771, 0.04375482177627938, 0.01725083513052336, 0.06048503225403173, 0.05053180901865874, 0.03968594582485301, 0.03699965622009976, 0.025890633397336518, 0.009140933697511042, 0.05413637024217418, 0.03804991986336453, 0.022557260568386743, 0.06310554128140211, 0.11560701871556894, 0.044245212604956966, 0.031229051761329174, 0.018060291784682443, 0.0537573779001832, 0.04011211670669062, 0.06393190872456346, 0.03276256125952516, 0.033663920392947536, 0.019470492810277, 0.0515763526117163, 0.06655139316405569, 0.037628037322844775, 0.06394766430769648, 0.026537199238581315, 0.0445566058957151, 0.0965723404660821, 0.012998820033057459, 0.02061764955786722, 0.08394707686134747, 0.0626983999141625, 0.036019994145525355, 0.03851409549159663, 0.01836964438137199, 0.04125179769471288, 0.02140835828946105, 0.13742664216884545, 4.513506812708719, 27.46956937653678, 47.95002569471087, 50.8493526322501, 34.73548303331648, 26.045980760029384, 39.622137205941335, 54.40112931387765, 54.33532639912197, 45.22053704942976, 18.59453977857317, 4.68829048531396, 0.5158635761056627, 0.08706001910780158, 0.7229033921446119, 1.6172920167446136, 4.603106873376029, 11.611575875963483, 8.15591709954398, 10.02934946332659, 13.61148977279663, 14.532543846539088, 13.74650890486581, 5.485542859349932, 9.721698863165718, 21.894143751689366, 33.508618763514924, 45.68323496409825, 50.56140538624355, 50.65349333626883, 49.33872045789446, 49.66825614656721, 50.169995989118306, 50.6416779245649, 51.270302295684814, 52.05363178253174, 50.83089126859392, 50.204990591321675, 48.9554717200143, 46.6603045463562, 44.216876711164204, 40.14476333345686, 37.79631042480469, 42.0589781488691, 49.16934422084263, 50.58596726826259, 52.516371386391775, 52.054948466164724, 50.77121319089617, 47.97879123687744, 41.75206232070923, 36.5037648337228, 35.08622809818813, 43.46320561000279, 49.85893556049892, 52.9971797806876, 50.54836014338902, 47.62964078358242, 40.20524045399257, 41.291118826184956, 41.82598420551845, 51.32326146534511, 43.44531052453177, 38.722248213631765, 56.49105017525809, 45.52982568740845, 49.065913336617605, 42.93733467374529, 39.92216042109898, 41.687565667288645, 47.5169027873448, 47.49448789869036, 52.17776482445853, 50.01514496122088, 52.49319914409092, 41.22000401360648, 36.75129788262503, 45.3557767868042, 51.85754667009626, 51.85977356774466, 52.92798614501953, 49.781914779118125, 46.74718482153756, 47.97140530177525, 52.58097226279122, 51.44514676502773, 52.2409656388419, 49.04597200666155, 47.667720385960166, 48.58797802243914, 50.82625682013375, 49.821661949157715, 50.484634740012034, 47.98702137810843, 50.40877430779593, 51.66823605128697, 54.81814282281058, 46.38064997536795, 35.869439465659006, 23.476710626057216, 17.41635979924883, 9.037838918822152, 9.915016855512347, 11.992347581045967, 18.500968388148717, 10.928215333393641, 9.012312974248614, 12.036088228225708, 8.633661338261195, 7.052483669349125, 2.3577628433704376, 0.4330039194652012, 0.16373406909406185, 0.7025606408715248, 3.9606955392020087, 16.630549805504934, 38.39915003095354, 59.29819188799177, 55.87316424506051, 44.40851150240217, 31.965357848576136, 33.034626552036826, 50.511593750544954, 39.94441897528512, 18.45408194405692, 1.8389751613140106, 0.10435219907334872, 0.05822549707123211, 0.02378945641352662, 0.023173657046364884, 0.035878295677581, 0.12876459982778343, 0.02986567813370909, 0.018926294154620597, 0.030384289233812263, 0.03527673027877297, 0.0434079580674214, 0.016915657491024052, 0.0209069548374308, 0.024895604200927273, 0.06027365502502237, 0.009287595649116805, 0.06114258696990354, 0.02531997357229037, 0.05740419149930988, 0.07489658000745944, 0.04062140812831266, 0.04564222460612655, 0.01658655613261674, 0.06558611603187663, 0.043168642159019194, 0.10937775511826787, 0.12178199951137815, 0.07873258274048567, 0.1350309250078031, 0.12293145140366894, 0.154125823240195, 0.08150374689804656, 0.12232972654913153, 0.168148346511381, 0.19014630253825868, 0.08823485499514, 0.14474104610936983, 0.11153479080115046, 0.14636676173124993, 0.13965020142495632, 0.08006351560886417, 0.1125897838334952, 0.21028062142431736, 0.06928767383630786, 0.10893228330782481, 0.07179074880800076, 0.19065823006842816, 0.12398446989910943, 0.1092866210799132, 0.23559379098670824, 6.821146002837589, 32.731372424534385, 52.88861417770386, 56.160781451633994, 41.35874564307076, 33.843567098890034, 50.48552758353097, 58.67083903721401, 55.23697675977434, 47.34049497331892, 20.66546252795628, 5.279982575348445, 0.9624749996832439, 0.32889032044581, 1.3932566898209708, 2.0120430631296973, 10.897462606430054, 23.194987228938512, 18.077262026923044, 15.58019757270813, 16.90574884414673, 18.957272223063878, 22.547316108431133, 11.909682256834847, 12.207143323762075, 22.9729106426239, 40.485787868499756, 49.64984342030117, 51.66694368634905, 52.12983267647879, 49.5396727834429, 50.156599862234934, 49.82450723648071, 50.804342201777864, 51.81127861567906, 53.860180786677766, 52.20202098573957, 52.846240588596885, 52.541840008326936, 49.13898754119873, 46.126929555620464, 42.58080870764596, 38.91185065678188, 43.19965696334839, 49.76148360116141, 53.208147934504915, 54.725794315338135, 54.08647666658674, 52.76073605673653, 49.60261998857771, 43.94172804696219, 39.038620540073936, 37.290165424346924, 46.03862489972796, 52.57218973977225, 53.45592417035784, 51.55749566214425, 50.53743757520403, 41.9233249936785, 43.809205055236816, 43.89740548815046, 53.89156232561384, 46.020503997802734, 41.61984852382115, 58.51154463631766, 48.06844384329659, 52.43537623541695, 45.475327491760254, 41.73035962241036, 43.71770075389317, 48.82309464045933, 50.84292207445417, 55.51858377456665, 53.02061952863421, 53.2692677634103, 43.92605985913958, 38.4807253565107, 46.732572759900776, 53.84178195680891, 55.12387745720999, 53.77596514565604, 50.38525812966483, 46.5913645199367, 48.31595604760306, 53.278474126543315, 53.33645336968558, 53.666760308401926, 50.65053687776838, 48.078737599509104, 50.09692873273577, 53.90847424098423, 52.2295949118478, 53.77853945323399, 50.03894254139492, 51.79363019125802, 53.15742261069161, 57.0629494530814, 48.85318381445748, 39.54725299562727, 33.16337667192732, 19.547627653394425, 10.390182444027491, 12.899206485067095, 26.43123231615339, 19.252567189080374, 13.667824029922485, 14.114605358668737, 18.3430358341762, 15.464459691728864, 9.314702919551305, 3.21205558521407, 0.8742627331188747, 0.4300117428813662, 0.8712336985128266, 5.253839109625135, 18.608542135783605, 42.09729398999895, 62.409650802612305, 62.1128237588065, 50.176502977098735, 40.89924737385341, 42.22106225149972, 58.53915677751814, 48.653798307691304, 22.14479133061, 2.8176035284996033, 0.23008172533341817, 0.13967825206262724, 0.19962361827492714, 0.16295226104557514, 0.1245327533355781, 0.2011293824762106, 0.09757512701409203, 0.08332826649504048, 0.11535659858158656, 0.2393300762133939, 0.10745940769889525, 0.10940885237817254, 0.06005083091024842, 0.17779250043843473, 0.13654647368405545, 0.1613510541085686, 0.20638264130268777, 0.11530933183218751, 0.2456471286714077, 0.19270364674074308, 0.1474949483360563, 0.10484685110194342, 0.1266830443803753, 0.20930263533123902, 0.1409255622753075], [0.056068505493125746, 0.041632713683481724, 0.058603882124381404, 0.04747246764600277, 0.07297564058431558, 0.021955303315605437, 0.05080054959814463, 0.040467177118573866, 0.03752551407420209, 0.06064474582672119, 0.06054557114839554, 0.04219127692548292, 0.022565696455006088, 0.04861092048564127, 0.06798667793295213, 0.02775723403984947, 0.023110897646152546, 0.03874975748892341, 0.028982558021587983, 0.1006741321512631, 0.049757254509521384, 0.032140453213027546, 0.036282665229269435, 0.0404799641110003, 0.1581205760261842, 6.057652320180621, 24.934538228171213, 41.39803423200335, 42.28905037471226, 34.31813948495047, 25.740711654935563, 26.656718730926514, 32.02889565059117, 19.78848695755005, 22.319337027413503, 11.813694630350385, 3.449409306049347, 0.4672301486134529, 0.017232280590438416, 0.12509749803159917, 2.2730425894260406, 4.134758770465851, 7.851954255785261, 5.89989173412323, 8.456715907369341, 11.447152835982186, 15.431488752365112, 12.507416674068995, 6.438061416149139, 16.700507743018015, 31.4703369140625, 40.209638663700645, 50.25034148352486, 51.70832020895821, 53.40173864364624, 53.645797593253, 52.553509507860454, 48.81403071539742, 50.515873840876985, 50.34718547548567, 51.28039108003889, 49.231766836983816, 48.46316058295113, 47.10761914934431, 48.97733422688076, 47.298663343702046, 45.92861754553658, 37.83818374361311, 34.08935267584664, 36.183168002537315, 40.533011300223215, 44.15662540708269, 46.40922791617257, 43.98595333099365, 39.447904178074424, 37.603821005140034, 36.34505755560738, 40.10669067927769, 46.44266264779227, 52.697726317814414, 47.46347461427961, 43.63902282714844, 46.532263142721995, 39.99004432133266, 38.765452112470356, 39.02095127105713, 49.16685676574707, 41.715143067496165, 37.45639065333775, 53.63417673110962, 44.401191575186594, 43.77826820101057, 37.43163422175816, 36.563967500414165, 33.428964614868164, 36.59465421949114, 37.83349370956421, 42.90693630490984, 42.589949062892366, 40.15236118861607, 33.425698961530415, 32.79496233803885, 34.28674404961722, 41.73555340085711, 45.659291471753804, 47.39268636703491, 49.18399102347237, 48.448173318590435, 47.69913666588919, 49.43289981569563, 48.11085912159511, 50.74195780072893, 49.533499308994834, 52.13161488941738, 49.96398537499564, 51.573434829711914, 48.903919560568674, 49.69545486995152, 49.05831895555769, 51.706531047821045, 50.53845201219831, 49.72539813177926, 44.02578387941633, 36.58428750719343, 20.146591901779175, 18.94423566545759, 17.065348965781077, 10.186337062290736, 11.052800008228846, 14.317577872957502, 13.581574303763253, 9.084406614303589, 10.100531152316503, 5.013672019754138, 5.16370838029044, 1.9417440124920435, 1.0653943227870124, 0.07653318611638886, 0.4477370860321181, 3.0161309327398027, 11.097335355622427, 27.67667954308646, 43.352909905569895, 32.75984614236014, 21.34031500135149, 24.11254722731454, 41.42878695896694, 47.2410488809858, 38.67462873458862, 14.002015011651174, 1.4190942176750727, 0.040642893939678154, 0.022632167441770434, 0.01228420645929873, 0.012785301177895494, 0.050383328593203, 0.007245719233261687, 0.03826661341424499, 0.04788371075743011, 0.024352513253688812, 0.030651357224477187, 0.024711765315649763, 0.04601489978709391, 0.03164098697847553, 0.0591878972149321, 0.017780236633760587, 0.0385061803806041, 0.04611636112843241, 0.056217359112841744, 0.012278683184246932, 0.021450103460145847, 0.027187368100775138, 0.06218801944383553, 0.08055111765861511, 0.013827348610253205, 0.05894136508660657, 0.08480069427085773, 0.06834078500313417, 0.01124221585424883, 0.05345833394676447, 0.00891736997956676, 0.010303968164537634, 0.051980274330292425, 0.03325382061302662, 0.046835126488336494, 0.020742834179795215, 0.022682596164356385, 0.03889790203954492, 0.037652040499129465, 0.025785479129159024, 0.014991802063637545, 0.07011051289737225, 0.01278162606260074, 0.017494519108108113, 0.028948902684663023, 0.04604230581649712, 0.07143548822828702, 0.022198690434119532, 0.03798086874719177, 0.0319209369564695, 0.158048488465803, 7.043162226676941, 27.97173653330122, 46.29406499862671, 48.416437421526226, 38.20913764408657, 29.459243365696498, 33.893809522901265, 44.768028667994905, 34.41749177660261, 31.17436797278268, 13.70897126197815, 3.835644466536386, 0.3074491024017334, 0.16201521775552205, 0.174227043188044, 2.111855455807277, 5.075861436980111, 8.932201113019671, 9.896142074040004, 9.060334580285208, 12.212011405399867, 13.067660348755972, 11.460118174552917, 8.607306821005684, 16.42759813581194, 27.466979435512, 38.46651629039219, 49.51801872253418, 52.17889738082886, 52.97995172228132, 52.58810111454555, 51.8090169770377, 49.417863913944785, 50.282063484191895, 49.42152214050293, 51.678317887442454, 50.55325167519705, 49.47793109076363, 49.56343214852469, 51.04080677032471, 48.477612836020334, 47.57470137732369, 38.92583390644619, 35.756176880427766, 38.88903277260916, 43.25446435383388, 46.49838720049177, 48.35704074587141, 45.93248421805245, 41.6602384022304, 39.118834018707275, 38.0243433543614, 40.230271339416504, 48.139562129974365, 52.51121929713658, 49.947288853781565, 46.66155522210257, 48.20134203774588, 42.261990615299766, 40.66434962408883, 41.110549041203086, 50.09125205448696, 43.39892782483782, 39.660373142787385, 54.12408379146031, 46.23707239968436, 45.9371395111084, 41.01471948623657, 38.13782480784825, 36.14279549462454, 38.77386290686471, 40.89973027365548, 44.76063925879342, 46.45101090839931, 43.1290910584586, 35.45127950395857, 33.90376281738281, 36.50991746357509, 44.436290400368826, 48.0720534324646, 49.7119186265128, 51.01161043984549, 47.82363101414272, 47.141675744737896, 49.25854866845267, 50.25852646146502, 52.72622435433524, 52.92029101508004, 52.91947112764631, 52.41212408883231, 53.48140321459089, 51.586101395743235, 51.684734548841206, 50.76637724467686, 53.88379423958914, 51.606338024139404, 52.686734267643516, 47.383889947618755, 38.41013860702515, 27.224188532148087, 18.925157649176462, 13.601676310811724, 10.101249422345843, 12.312890563692365, 16.22559836932591, 11.609547001974923, 12.970752085958209, 10.18266407081059, 9.097972972052437, 6.3556705457823615, 3.600705678973879, 1.0405928364821841, 0.20738595032266208, 0.4623030072876385, 3.833724592413221, 12.948906949588231, 32.58466468538557, 47.763084411621094, 41.289548533303396, 29.11576611655099, 28.470521654401505, 44.882635729653494, 52.242445605141775, 45.02661977495466, 17.210456882204326, 2.0148034521511624, 0.044692720020455975, 0.10739774243640048, 0.023626641935801933, 0.03414742409118584, 0.025373404812333838, 0.03542913942198668, 0.025413048220798373, 0.054694746887045245, 0.0234349829344345, 0.0384052177625043, 0.048412102939827104, 0.05626937900004642, 0.04515937230150614, 0.05796019666429077, 0.031537859833666256, 0.026207336224615574, 0.13811215252748557, 0.05703996747199978, 0.017364583044712032, 0.06837946149919714, 0.05101230341408934, 0.05074364425880568, 0.045166602092129846, 0.010879964667505451, 0.04174304008483887, 0.1513102421803134, 0.14650439577443258, 0.08257925204400506, 0.197847702141319, 0.12862775288522243, 0.07869111068014588, 0.1323741347129856, 0.08555364422500134, 0.09975460185004131, 0.10785565179373537, 0.07821963062243802, 0.09852928295731544, 0.13658728078007698, 0.11640212605042116, 0.1672829565192972, 0.24198808787124498, 0.13058630350444997, 0.11675120517611504, 0.10719088425061532, 0.16290289083761827, 0.15571191241698606, 0.20232664394591535, 0.1418541238776275, 0.08175025867032153, 0.3953688660902636, 9.33593053477151, 35.57813971383231, 53.65436124801636, 54.955387115478516, 45.5641428402492, 37.534352915627615, 35.576868193490164, 41.480311325618196, 29.11987771306719, 31.265097549983434, 16.6774605682918, 5.07418909243175, 0.6224575191736221, 0.44709055072494913, 0.27577899609293255, 3.942500812666757, 8.652915665081569, 15.591085399900164, 16.191897869110107, 15.660673345838275, 16.925167322158813, 25.56326334817069, 20.96814169202532, 14.081366913659231, 22.10468806539263, 35.57294940948486, 41.57133272715977, 52.660890442984446, 53.295410360608784, 55.793704645974294, 54.81088890348162, 52.32869359425136, 50.14443356650216, 51.08825601850237, 50.67770433425903, 52.12705339704241, 50.83439663478306, 51.44888489586966, 51.40657731464931, 52.738501821245464, 50.73350531714303, 50.07477787562779, 42.43208251680647, 37.624391147068565, 40.62011391775948, 44.829110281808035, 49.34171513148716, 51.203443254743306, 47.57481949669974, 43.46036727087838, 40.05076462881905, 39.90474476133074, 43.415586130959646, 51.736474309648784, 55.84247752598354, 54.37079347882952, 50.47861760003226, 50.93513856615339, 44.79663092749459, 42.38550526755196, 42.342117241450715, 52.95866938999721, 46.85223811013358, 43.2336927141462, 56.435384682246614, 47.92977864401681, 48.289730072021484, 43.16250147138323, 40.54652902058193, 37.75107765197754, 40.55575622831072, 42.644221442086355, 45.94585255214146, 47.63859006336757, 44.82674094608852, 36.40311670303345, 36.70712471008301, 38.13933604104178, 45.91057654789516, 49.553395475660054, 51.49879033224923, 52.45994853973389, 48.81010845729283, 48.696158000401084, 50.82585382461548, 50.5510629926409, 53.58249602999006, 53.63014677592686, 54.85268579210554, 53.27921758379255, 55.282393659864155, 53.359997340611045, 53.738128730228965, 52.614035265786306, 56.10880545207432, 52.94892801557268, 54.74039942877633, 49.2930325780596, 43.47479520525251, 25.37672679764884, 23.70690791947501, 23.792016404015676, 18.6801780632564, 21.658024856022426, 24.27956107684544, 27.139886038643972, 18.32267587525504, 21.000786066055298, 13.315066593033926, 12.631927524294172, 5.095855746950422, 1.748440133673804, 0.4708953776529857, 0.6982186681457928, 3.95475526366915, 14.114878943988256, 32.489040102277485, 49.33904354912894, 41.707819666181294, 30.67580345698765, 35.89178139822823, 51.42423268726894, 61.00671223231724, 52.790279797145296, 22.51038990701948, 3.4813701510429382, 0.14451404900423118, 0.18100307030337198, 0.12339997983404569, 0.09480236829923731, 0.17598085265074456, 0.17696213642401354, 0.1406488014119012, 0.17283357653234685, 0.11823905605290617, 0.15081712364086083, 0.1959528388189418, 0.1624968419117587, 0.11779008300176688, 0.26221703525100437, 0.08770866465887853, 0.10031524140919958, 0.1886511506246669, 0.22043381232236112, 0.13599771527307375, 0.2117935645260981, 0.08591092683907066, 0.1421752202191523, 0.11109657253005675, 0.13826179664049829, 0.26299251935311724], [0.010490730687576746, 0.059241664329809804, 0.08773442863353662, 0.04723235445895365, 0.04145087308383413, 0.0332429878014539, 0.025190185090260844, 0.08528826917920794, 0.04540318689708199, 0.017990986217877696, 0.043173096741416624, 0.007975847510221814, 0.03257262234443, 0.037049321590789726, 0.03569069431562509, 0.05376495035099132, 0.027637594745361378, 0.09509861668837921, 0.01905837099600051, 0.055023232474923134, 0.010716100156839405, 0.047546801157295704, 0.03128779593056866, 0.07456299183624131, 0.05978010222315788, 5.757536172866821, 22.853227921894618, 42.336457933698384, 41.29311295918056, 31.751360280173166, 23.97175066811698, 21.88453960418701, 22.370614733014786, 24.174759660448345, 30.008543627602712, 11.658101882253375, 3.0591146605355397, 0.12169624625572137, 0.09353852897350277, 0.3424113249140126, 2.338607962642397, 3.4879088401794434, 9.569182429994855, 5.562407306262425, 8.031203883034841, 15.340218952723912, 14.482650569507054, 8.233701314244952, 8.014033147266932, 22.567476306642803, 35.68007673536028, 44.23268386295864, 51.97109065737043, 53.29366288866316, 51.0414251599993, 50.51150689806257, 51.10109976359776, 53.742752756391255, 52.243491309029714, 48.97395740236555, 51.34829929896763, 49.06867177145821, 49.92240388052804, 48.95891455241612, 49.810753277369905, 48.02288103103638, 48.58999994822911, 43.910631384168354, 35.289362158094136, 33.31984315599714, 33.31146362849644, 32.51628398895264, 35.719424383980886, 33.89295836857387, 35.60102707999093, 34.59392043522426, 37.933870860508506, 42.98680932181222, 51.20956809180123, 45.02214166096279, 47.10369341714041, 51.4013557434082, 45.954371043613975, 39.01858540943691, 39.63375459398542, 40.56201655524117, 47.2294453893389, 43.54900891440255, 40.685597215379985, 50.41983583995274, 41.961849280766074, 43.02149472917829, 37.98443290165493, 38.2398556300572, 33.49767882483346, 35.4659297806876, 32.81547689437866, 35.65897853033883, 35.027946608407156, 33.63342578070504, 35.18437140328543, 39.76249081747872, 34.737487588609966, 36.6484819139753, 42.96778167997088, 46.98506334849766, 48.665631089891704, 46.9834235736302, 47.65694720404488, 50.07344382149832, 46.65390525545393, 49.06516987936837, 46.657386302948, 48.94707134791783, 48.66088547025408, 50.3478490284511, 46.62359373910086, 51.099758761269705, 49.65497119086129, 48.625609466007774, 51.684203011649, 48.24441739491054, 44.377248082842144, 40.239720889500205, 29.14698784691947, 23.19692403929574, 13.925990428243365, 7.646879042897906, 6.402135321072169, 24.00064648900713, 6.101283967494965, 8.845970494406563, 6.8895332132066995, 8.494632227080208, 6.721702950341361, 2.402040673153741, 0.673017714704786, 0.04526425345933863, 0.27950390907270567, 1.5207742644207818, 8.469426768166677, 17.074934005737305, 31.122937406812394, 20.627546208245413, 19.708546195711406, 33.42983661379133, 38.46131903784615, 46.28447995867048, 35.74502502168928, 16.61757751873561, 3.556772870676858, 0.05874916325722422, 0.03925178519317082, 0.022766198464004055, 0.08023199585399457, 0.053357717381524186, 0.035250318303172073, 0.0345990705702986, 0.02712223043532244, 0.002918330769586776, 0.009068395759511207, 0.03921125968918204, 0.03879845594721181, 0.016391987912356853, 0.05021692805790475, 0.02914901962503791, 0.01454295454147671, 0.04218679859435984, 0.022292584413662553, 0.028437026044619933, 0.014242063276469707, 0.028835940174758434, 0.03998606864895139, 0.008026382253904427, 0.028321398588429605, 0.0540319403101291, 0.013781519506924918, 0.053317330977214236, 0.10260422501180853, 0.01417388831863978, 0.045810104347765446, 0.009488559910096228, 0.027776266947122555, 0.05070097119148288, 0.027937318930136304, 0.01828264431761844, 0.05271834061880197, 0.05998356094849961, 0.020435534151537076, 0.0731977725933705, 0.008314971679023333, 0.061229548017893515, 0.049901327850031, 0.028595813417008946, 0.08351894840598106, 0.037039998519633494, 0.015500645652147276, 0.09049432910978794, 0.016090920228245, 0.0286140592236604, 0.16210905914860113, 7.2480329019682745, 26.93236071722848, 48.579588072640554, 46.8373898097447, 38.42771407536098, 30.760797296251567, 27.012358801705496, 28.075005871909006, 26.132847138813563, 29.337493555886404, 12.782793760299683, 2.971766467605318, 0.252371790685824, 0.03627292825175183, 0.20176747680774756, 2.7735753996031622, 6.813583757196154, 9.031289373125349, 11.815830332892281, 12.429965104375567, 10.449063215936933, 12.128722480365209, 12.199099046843392, 11.756648182868958, 18.143504415239605, 31.304108210972377, 44.49116727284023, 53.19275072642735, 54.02205991744995, 54.57819373267037, 53.269316400800435, 52.587600844247, 53.84007964815412, 52.949056557246614, 49.35695253099714, 50.33323696681431, 49.68769025802612, 48.80838530404227, 49.02802133560181, 51.56559378760201, 49.29002053397042, 50.41318988800049, 45.3994323185512, 37.91957841600691, 35.58402483803885, 35.917785031454905, 35.935485567365376, 39.035782200949534, 36.85258872168404, 38.02068165370396, 35.23322071347918, 39.94553068705967, 44.59559869766235, 52.03124468667166, 46.59012426648821, 49.40138973508562, 50.25994389397757, 47.89582627160208, 41.19265937805176, 40.66547870635986, 41.68592936652047, 50.06795127051217, 44.872988155909944, 43.399362087249756, 52.2494215965271, 44.917373248508994, 44.93251684733799, 40.4565463747297, 40.14489534923008, 35.20786326272147, 36.94316891261509, 35.13768645695278, 37.538066727774485, 36.53643873759678, 37.02945164271763, 36.806765351976665, 39.81504004342215, 35.346667425973074, 38.10881607873099, 44.58110128130232, 47.74748917988369, 50.40858670643398, 48.09486436843872, 49.608560698372976, 49.9957594871521, 47.326369285583496, 48.95029183796474, 47.13109711238316, 49.400086947849815, 50.202607359204976, 50.37439809526716, 47.983793939862935, 53.8467047555106, 50.0857629776001, 49.55524369648525, 53.28606503350394, 49.34770447867257, 46.685304164886475, 40.839899335588726, 30.463449137551443, 22.03658182280404, 15.9129433291299, 12.010554466928754, 12.354425157819476, 19.574798583984375, 13.453122087887355, 15.359069415501185, 11.052392670086451, 9.954247253281729, 6.7413098982402255, 3.8586195537022183, 1.290293071951185, 0.27578911983541077, 0.36591561511158943, 1.838130955185209, 9.483599730900355, 19.97885196549552, 36.8978944505964, 27.066731929779053, 23.215918677193777, 38.930214745657786, 42.362235750470845, 52.34266989571707, 42.11858327048165, 20.24761870929173, 4.5784620472363065, 0.024041610204481652, 0.05035686233480062, 0.05771434307098389, 0.07401088824761765, 0.050913345866969655, 0.013437462388537824, 0.039087250629173856, 0.04022661270573735, 0.032888867160571475, 0.029413159737097364, 0.03552986794550504, 0.019071846701470867, 0.01619664785851325, 0.038206569850444794, 0.042788991638060124, 0.05067954984094415, 0.043623260621513636, 0.018040968803688884, 0.027536623645573854, 0.013270440993697515, 0.024454524208392416, 0.042368320282548666, 0.03155021595635584, 0.06066151921238218, 0.039348503574728966, 0.1596376581915787, 0.15485153001333984, 0.1907757930457592, 0.07103009748139552, 0.17326019863997186, 0.08691540293927703, 0.1034266637372119, 0.11863280992422785, 0.11937143600412778, 0.11402114666998386, 0.22252637360777172, 0.15047235999788555, 0.12485728306429726, 0.1453348456748894, 0.10974852700850793, 0.13408408367208072, 0.12028133789343493, 0.15533219064985002, 0.13578533381223679, 0.13864202052354813, 0.07352017172213111, 0.16519704487706932, 0.09819646831601858, 0.11675250796335084, 0.38091493025422096, 9.182182533400399, 32.03439514977591, 55.19002430779593, 52.97984055110386, 45.30457203728812, 34.89073010853359, 30.654844215938024, 31.351790223802837, 34.034826687404085, 36.67280755724226, 15.193961109433856, 4.010570577212742, 0.3369146484349455, 0.1992025330130543, 0.7939128960881914, 5.1891127313886365, 9.32933669430869, 19.160751955849783, 12.319232531956263, 14.989265441894531, 25.298668997628347, 24.704618862697057, 16.100221599851334, 12.517632263047354, 27.32848446709769, 39.270537512642996, 47.35697957447597, 56.241783550807405, 58.1506621497018, 56.67355503354754, 55.43479892185756, 54.1748924936567, 55.94811793736049, 52.519261837005615, 49.998962606702534, 51.01730796269008, 49.02068403788975, 49.17172050476074, 49.53953034537179, 52.33391516549246, 51.370794091905864, 52.41773475919451, 48.89260789326259, 40.4296464238848, 38.749165534973145, 37.79451084136963, 36.55319431849888, 39.07442808151245, 38.70425237928118, 40.05301584516253, 37.05767869949341, 41.3932260785784, 47.10473564692906, 54.029463223048616, 48.521553243909565, 51.45296001434326, 52.39641768591744, 49.938516753060476, 44.0201975277492, 43.785126073019846, 45.00838770185198, 52.27969837188721, 47.41404512950352, 46.71533080509731, 53.741894653865266, 47.480848584856304, 47.02698877879551, 43.13183559690203, 43.78399351664952, 37.39706693376814, 40.07051140921456, 36.001451764787944, 39.99674585887364, 37.840598242623464, 37.79261745725359, 37.91079936708723, 43.01666920525687, 36.90382126399449, 39.688381331307546, 47.11086048398699, 50.92459467479161, 51.87483031409127, 49.81194836752755, 48.91097893033709, 50.37232058388846, 47.58480058397566, 48.68747970036098, 46.48004048211234, 48.44959075110299, 49.69918605259487, 51.089607443128315, 48.00857816423689, 53.24171815599714, 49.65398454666138, 50.275827475956504, 55.3672902243478, 49.687040601457866, 49.81201784951346, 44.39748123713902, 33.64926767349243, 27.64614568437849, 19.29718678338187, 16.952517168862478, 14.043134450912476, 35.51182958057949, 13.936665466853551, 13.917027252061025, 19.078348057610647, 21.669517176491873, 13.86859049115862, 6.585178230490003, 1.584210883293833, 0.6092917684997831, 0.6984358536345618, 2.103844617094312, 11.125020452908107, 23.25520726612636, 43.14457164491926, 31.85808461053031, 29.508412293025426, 44.442762647356304, 49.48534829275948, 59.179092815944124, 49.26931142807007, 26.08259776660374, 6.852795047419412, 0.20926075614988804, 0.1767017146838563, 0.0798293056764773, 0.2989885578198092, 0.1801316277789218, 0.18853167417858327, 0.14924132105495247, 0.10492328128644399, 0.12645025258617743, 0.07391906210354396, 0.16921577709061758, 0.14434976210551603, 0.11375995139990534, 0.064875662725951, 0.20402626560202666, 0.15808858988540514, 0.16359336807259492, 0.14631545091313974, 0.08515963929572276, 0.11751442136509077, 0.10984576786203043, 0.16741888065423283, 0.14829742456121103, 0.09855112499956574, 0.18136673793196678], [0.0316513482082103, 0.0864945212379098, 0.010973400635910886, 0.03109144825222237, 0.03951356400336538, 0.04248775940920625, 0.0047121771910626975, 0.039591456430831125, 0.026585134344973733, 0.025070033501833677, 0.0477027352899313, 0.06478986875819308, 0.06164882837661675, 0.03635805046984127, 0.0208327790855297, 0.022570262995681593, 0.026596611764814173, 0.0103235897009394, 0.032773438175874095, 0.028412040688895752, 0.03497378135632191, 0.04765223192849329, 0.039222825318574905, 0.03837690928152629, 0.0707725188029664, 3.7075413976396834, 23.46440884045192, 38.868702343532014, 41.902021816798616, 28.4583831514631, 19.70166747910636, 23.122896194458008, 29.59492083958217, 41.066386290958945, 23.8326963697161, 10.17728877067566, 1.751708175454821, 0.3856961322682244, 0.1712834361408438, 0.1267938491489206, 2.5849587321281433, 6.8551066262381415, 4.486251200948443, 11.515299030712672, 12.1004832642419, 8.750841838972908, 9.11138733795711, 11.486622078078133, 18.222599233899796, 21.23099204472133, 33.10826703480312, 49.46024445125035, 50.1012852532523, 47.14083153860909, 48.595134666987825, 45.96235452379499, 46.34686435971941, 47.89296361378261, 49.57449715478079, 49.49639940261841, 50.73850107192993, 47.9224830354963, 48.4840920312064, 47.568274293627056, 49.23322248458862, 50.93949508666992, 48.366639682224815, 43.39769451958792, 35.868167945316856, 33.61672578539167, 32.11599131992885, 32.569208417619976, 35.8807407106672, 35.94507755552019, 37.78909124646868, 42.80878257751465, 46.738711493355886, 49.17632368632725, 46.81230681283133, 49.16391767774309, 53.546181270054404, 47.20771142414638, 45.65505654471261, 38.099894591740195, 37.88041142054966, 39.72112471716744, 48.82891723087856, 42.334630557468955, 41.80735608509609, 48.28906651905605, 42.47927815573556, 39.056578159332275, 35.40619611740112, 35.70057392120361, 32.81583820070539, 34.84241233553205, 35.088573115212576, 34.5536139351981, 33.18117448261806, 34.216063499450684, 34.69783421925136, 39.64904063088553, 34.574753829411094, 33.93046474456787, 41.1248345375061, 47.37520817347935, 48.62260437011719, 50.379598821912495, 48.99940865380423, 48.03613124574934, 47.24166032246181, 47.57223129272461, 48.54217897142683, 46.49497216088431, 48.00323847361973, 47.956181798662456, 48.731927326747346, 46.83465916769845, 48.85515362875802, 46.85328728812081, 50.01386649268014, 47.911814076559885, 48.04142229897635, 39.70643622534615, 39.214736529758994, 25.141040427344187, 22.644370283399308, 16.464810950415476, 19.145425966807775, 11.457067046846662, 13.31926851613181, 19.472997052328928, 6.487536932740893, 5.112973502704075, 2.738703259399959, 4.299749825681959, 0.9351081081799099, 0.38829239723937853, 0.11484863369592599, 1.637028809104647, 6.901589206286839, 20.838062729154313, 26.23659242902483, 30.965699672698975, 29.161832673209055, 35.15038776397705, 49.8849252973284, 44.288290296282085, 39.1492462839399, 19.144140550068446, 3.1551680777754103, 0.08184532142643418, 0.02477159853359418, 0.06774930602737836, 0.022698606198121394, 0.05600329488515854, 0.02952569137726511, 0.054884292251829586, 0.01032940304971167, 0.026466655345367532, 0.0072453909919464165, 0.02303616888821125, 0.0568932139181665, 0.09656521584838629, 0.05772002240908997, 0.010939948011322745, 0.02566486444058163, 0.028950789012014866, 0.09259813372045755, 0.011442072406810309, 0.020261807134374976, 0.035212741033839326, 0.043788575500782044, 0.020137177214824727, 0.013503445678257515, 0.011883533227124383, 0.03783129248768091, 0.03353597582983119, 0.03466680193586009, 0.051741545354681354, 0.022763328260875175, 0.02805346716195345, 0.02155806347062545, 0.02967147123334663, 0.030310892100845064, 0.012518380768597126, 0.022480306215584278, 0.1030646517340626, 0.03353340418211051, 0.03165456785687378, 0.014480758325329848, 0.04483899520710111, 0.04644847348598497, 0.05845075034137283, 0.028761708443718295, 0.02929954244089978, 0.012488704191387763, 0.07819308633250849, 0.04754723881238273, 0.06494711246341467, 0.07447215635329485, 5.137157576424735, 28.63587314741952, 43.50411312920706, 47.84416988917759, 32.95032753263201, 24.505471331732615, 26.660660096577235, 30.625373431614467, 38.363109724862234, 26.347390140805924, 12.002928818975176, 2.381384547267641, 0.29503071733883446, 0.22894808330706187, 0.4630273569907461, 3.9210647514888217, 6.423144068036761, 8.457538400377546, 12.02682193687984, 12.252903291157313, 12.756305490221296, 11.319633415767125, 12.48941649709429, 16.91283253261021, 20.604188101632253, 33.57260472433907, 49.282308033534456, 51.350025926317485, 50.2766786302839, 49.55988161904471, 48.60896505628313, 48.58250284194946, 49.586486271449495, 51.52385595866612, 51.54163639886038, 52.490593569619314, 49.22173016411917, 48.57588815689087, 47.81721782684326, 48.645463943481445, 51.4177291733878, 50.596910681043354, 45.26463726588658, 37.07600804737636, 35.04972921098982, 33.403138160705566, 34.83013139452253, 37.07982955660139, 36.816027300698416, 38.735102381025044, 42.64668457848685, 48.11478137969971, 51.26640435627529, 48.91861500058855, 49.43340008599417, 53.272119998931885, 49.30015795571463, 46.75617231641497, 39.22179242542812, 39.212002413613455, 41.82736342293875, 51.189585072653635, 45.42620025362287, 44.69660118647984, 50.72013003485543, 44.6157033102853, 42.52590751647949, 38.51071378162929, 37.243431840624126, 34.63312217167446, 36.55874245507376, 36.50133296421596, 35.2979153905596, 35.41019133159092, 35.7208696092878, 35.64454364776611, 42.682620661599294, 35.22068963732038, 35.498416083199636, 41.62865883963448, 49.19716828210013, 50.27143274034773, 49.766753809792654, 48.344481876918245, 48.167302812848774, 47.17854636056082, 49.03500427518572, 48.89586312430245, 48.1972530228751, 46.376835414341514, 49.29143449238369, 48.69135332107544, 48.11337784358433, 48.11166858673096, 47.48987429482596, 49.18261875425066, 50.20441041673933, 47.514679363795686, 42.329631328582764, 36.93127359662737, 27.169539213180542, 16.764238357543945, 9.888355748994009, 12.298142143658229, 7.591063295091901, 12.482998967170715, 18.10421235220773, 13.197336316108704, 14.240331275122506, 6.741674244403839, 3.462159250463758, 1.7788515303816115, 0.09270213278276579, 0.2075941384370838, 1.2987412129129683, 7.393411363874163, 19.944859640938894, 32.211383138384136, 31.684761796678814, 28.690687486103602, 40.31364624840872, 53.63204710824149, 50.283154351370676, 46.18704884392874, 22.931834629603795, 4.389477125235966, 0.07159271836280823, 0.019596881831863096, 0.05287456312882049, 0.040171332457768064, 0.028741369356534312, 0.06388476411146776, 0.03474897252661841, 0.024129796008180295, 0.0073286650502788165, 0.024311602681076953, 0.0779287087331925, 0.033105085736938884, 0.042866127498980076, 0.03459817829674908, 0.028072415252349207, 0.045833076150821786, 0.04185375325115664, 0.05065816241715636, 0.04651389104713287, 0.031059916729905775, 0.04349758915070977, 0.02158266375772655, 0.05800940402384315, 0.016211458581632802, 0.030910350648420196, 0.18241143758807862, 0.12977534559156212, 0.17809353928480828, 0.10612311440386943, 0.14057233051529952, 0.070280024515731, 0.09593991190195084, 0.1891336025936263, 0.10741211380809546, 0.14669861963817052, 0.10277314630470105, 0.15521274134516716, 0.13169204417083943, 0.12279991060495377, 0.12756210006773472, 0.11623448718871389, 0.11235469180558409, 0.14164748282304832, 0.17166467782642159, 0.1537355977509703, 0.119894342230899, 0.1733164084809167, 0.15181845133858068, 0.15410596930554935, 0.18715977136577877, 7.027860556329999, 33.73937886101859, 50.29688399178641, 53.828288555145264, 38.57362624577114, 30.298655237470353, 31.793379511151993, 37.395691190447124, 48.911242961883545, 30.689696380070277, 14.171375615256173, 3.1522830554417203, 0.7595071537154061, 0.5792060143181256, 0.688050522335938, 5.459278668676104, 12.747699277741567, 9.395261202539716, 21.834139108657837, 22.245237963540212, 24.10778944832938, 19.065546001706803, 16.93827509880066, 21.673274414879934, 24.191471815109253, 35.74718243735177, 53.16162627083914, 53.2362186568124, 52.04046842030117, 51.823900018419536, 50.75461394446236, 49.85190398352486, 52.83256653376988, 53.85080419267927, 52.8148764201573, 53.73884092058454, 48.42357669557844, 48.47916923250471, 48.461378370012554, 49.60768175125122, 52.037977491106304, 52.5988221849714, 47.221854482378276, 39.48430579049246, 37.69685391017369, 35.398890086582725, 37.3529771396092, 39.97925724302019, 39.500060830797466, 42.259065423692974, 45.31186069761004, 51.55474417550223, 52.799910000392366, 48.75275455202375, 50.33174657821655, 55.40622098105294, 50.24367816107613, 50.45486518314907, 41.81339406967163, 41.23649556296212, 44.09082249232701, 53.23774378640311, 47.83658593041556, 47.22327538899013, 52.074483326503206, 47.34517458506993, 43.8169766153608, 40.5337929725647, 39.225259576525005, 36.83936282566616, 38.82701315198626, 40.0667142186846, 36.3985413142613, 35.944983754839214, 38.44171469552176, 37.297249112810405, 43.506670066288535, 37.70038706915719, 37.315265791756765, 44.2569956098284, 50.953287260872976, 52.77980538776943, 51.05102062225342, 48.72817529950823, 48.96701267787388, 46.81362002236502, 48.5661050932748, 51.25982093811035, 47.81341368811471, 46.69452095031738, 49.34297970363072, 49.207069465092246, 48.246956961495535, 48.77294601712908, 46.899555342538015, 50.481949261256624, 50.1444856779916, 50.78495325360979, 44.1982798576355, 43.72031675066267, 27.83931950160435, 26.365113258361816, 23.05728782926287, 28.60034874507359, 18.444231135504587, 18.79438386644636, 31.72077430997576, 17.180312122617448, 13.903171675545828, 9.501268999917166, 9.331140620367867, 2.8752544692584445, 0.9651034814970834, 0.3425680665033204, 2.0037106531006947, 8.762318525995527, 25.58641995702471, 36.89750187737601, 42.341759409223286, 39.17773042406355, 45.94636671883719, 60.48274857657296, 55.02167640413557, 52.564914975847515, 26.5395564692361, 5.446748026779719, 0.2663034445473126, 0.2280870766511985, 0.13314568331199034, 0.11623406649700233, 0.08286352429006781, 0.16998758353292942, 0.13027516805699893, 0.10684857690440756, 0.1335424091666937, 0.09239396931869642, 0.157212709741933, 0.10810577337230955, 0.16353193351200648, 0.10557010836367096, 0.13440819270908833, 0.11426151091498987, 0.09609784092754126, 0.14532480335661344, 0.15146906008677824, 0.07416427787393332, 0.13928304612636566, 0.10350270715675183, 0.11393413133919239, 0.11579292373997824, 0.11031492732997451], [0.03463571485398071, 0.009843729735751237, 0.1161826199718884, 0.03709316513101969, 0.03046697551118476, 0.05334305763244629, 0.006297294366439539, 0.03358855550842626, 0.05568283636655126, 0.014004542093191828, 0.04035031642498715, 0.01994292451334851, 0.008615532158208745, 0.03544756843309317, 0.0029846113424615134, 0.0864078723160284, 0.018560419590877633, 0.05277008569932409, 0.03671044423910124, 0.034356138070247004, 0.022239015770277808, 0.0361140492771353, 0.0044250203230019125, 0.03291768115013838, 0.13550978074116365, 4.3804987498692105, 21.273176295416697, 39.56038509096418, 43.39332757677351, 39.24360282080514, 30.243347576686315, 22.295657566615514, 27.539372716631206, 36.69157811573574, 24.647469929286412, 7.7079554455620904, 1.7233660391398837, 0.5033085069486073, 1.8488502885614122, 0.8597250389201301, 2.0750067702361514, 5.198052891663142, 11.38974334512438, 11.623240164348058, 10.799916846411568, 5.924592580114092, 7.230976377214704, 18.21461922781808, 21.190999950681412, 23.144204582486832, 40.59552771704537, 46.95479352133614, 48.1486052104405, 44.77963215964181, 42.82491976874215, 39.886193071092876, 40.57298081261771, 43.06425394330706, 44.89841856275286, 46.626616205487935, 49.37782839366368, 49.92803192138672, 51.157581669943674, 47.3720189503261, 47.84942967551095, 48.52455486570086, 47.369208403996055, 42.15710408346993, 37.61956909724644, 33.51512227739607, 35.871367590767996, 43.443566526685444, 44.69840771811349, 44.59798540387835, 45.734495299203054, 48.15803391592843, 48.97189031328474, 46.13106025968279, 49.93028661182949, 50.18256180627005, 45.46363019943237, 45.27996499197823, 42.04008252280099, 36.633411271231516, 35.33164542061942, 40.3174330166408, 48.8015969140189, 43.17210388183594, 41.90638528551374, 50.72530991690499, 40.73019422803606, 37.360105991363525, 33.46401827675955, 34.6134101322719, 34.51676068987165, 36.2555821282523, 39.21005344390869, 41.69005312238421, 41.30181557791573, 38.85841900961739, 35.814083167484824, 33.585907050541465, 32.992127895355225, 33.499943937574116, 37.50109188897269, 45.19269561767578, 47.673827852521626, 47.06444999149868, 44.795540060315815, 48.517332213265554, 49.533422878810335, 50.27089078085763, 47.69109412602016, 49.756275926317485, 46.912677015577046, 47.89844574247088, 47.8779832976205, 47.125090394701274, 44.85044819968087, 46.037474972861155, 47.71011134556362, 46.57980271748134, 44.552662304469514, 45.56351055417742, 36.5591002873012, 29.405512945992605, 19.845441341400146, 13.883209500994, 10.155811888831002, 12.6365750006267, 15.899304015295845, 17.565692220415386, 11.480861152921404, 12.095727222306387, 7.348853434835162, 2.1802003255912235, 1.5422139082636153, 0.26419222354888916, 0.16154426016977855, 0.820868758218629, 5.346594955239977, 17.066995688847133, 29.851569925035747, 35.21450226647513, 31.233031613486155, 38.39883736201695, 44.21364579881941, 40.28189992904663, 34.43735320227486, 15.443021024976458, 2.764332775558744, 0.005545064507584486, 0.0320955952629447, 0.05313037083085094, 0.05797615580792938, 0.0417167672089168, 0.03781012898044927, 0.05527169503537672, 0.017508032133004496, 0.05430939667192953, 0.051139596583587785, 0.05424758552440575, 0.03723408667636769, 0.006975828961003572, 0.021765181196055243, 0.02331377792039088, 0.04247711319476366, 0.04621744588283556, 0.020360566210001707, 0.06251944308834416, 0.014940157067030668, 0.02703961031511426, 0.07398490035640341, 0.02282684083495821, 0.04020872312997069, 0.05150685366243124, 0.03202344663441181, 0.03335744308839951, 0.026987678637462, 0.016333384539133737, 0.04873650035421763, 0.020517027903614298, 0.02461207834338503, 0.022460567631891797, 0.027427688241004944, 0.05834434247974839, 0.05184937474716987, 0.017458161505471383, 0.0017403372559264036, 0.036134876909532716, 0.037779350632003376, 0.03679971909150481, 0.007224791516949023, 0.05644442067880716, 0.02181028850775744, 0.019636051962152123, 0.04383901100871818, 0.021240110442574536, 0.02959153302279966, 0.048820933859263144, 0.19765423823680195, 5.590779406683786, 25.67705225944519, 46.02109112058367, 47.110262938908164, 44.11805943080357, 31.809311730521067, 24.75883044515337, 28.09582962308611, 37.62918540409633, 26.916086299078806, 8.534798894609724, 1.9516423727784837, 0.5476845343198095, 2.1359055595738545, 0.24016383290290833, 3.497965923377446, 7.039107518536704, 8.867502093315125, 11.681258491107396, 11.550288421767098, 12.86910080909729, 13.083374568394252, 15.494229248591832, 16.550218207495554, 23.33857696396964, 41.77869129180908, 49.85701090948922, 50.315925530024934, 48.31012303488595, 45.827785287584575, 43.68044798714774, 43.48063169206892, 45.44273001807076, 48.338086060115266, 49.21057483128139, 51.051670278821675, 51.047921725681846, 49.25250720977783, 48.413932595934185, 48.11444786616734, 50.90041494369507, 48.863633905138286, 44.583415031433105, 38.73710346221924, 35.088882310049875, 36.356876441410606, 45.45892626898629, 45.81398963928223, 45.01251145771572, 46.959632941654746, 49.90019048963274, 49.6668004989624, 48.37400824683053, 49.28656380517142, 50.44241748537336, 47.71076447623116, 47.67048576899937, 43.21767711639404, 39.010202407836914, 37.16426059177944, 42.3846297945295, 50.45519174848284, 45.331402506147114, 44.14918736049107, 52.245919704437256, 43.51101963860648, 38.16897358213152, 35.2612566947937, 36.44423961639404, 36.223078455243794, 36.82861048834664, 39.8814891406468, 43.1777458190918, 40.92413929530552, 39.717303207942415, 36.36502667835781, 35.19049276624407, 35.43720245361328, 35.727974142347065, 40.25532306943621, 48.38474668775286, 49.22718450001308, 48.40781123297555, 46.16846588679722, 48.39606877735683, 49.265799113682334, 50.66193192345755, 49.26165451322283, 50.95836986814226, 47.753506319863455, 47.308008670806885, 48.669046129499165, 47.64585440499442, 46.3956754548209, 46.46031107221331, 49.56769834245954, 47.953075953892295, 47.378977571214946, 44.330549240112305, 36.70822947365897, 26.98281853539603, 18.783263274601527, 12.169588310377938, 5.854369308267321, 5.632644040243966, 11.850271684782845, 17.971602507999965, 14.756523370742798, 13.57301412309919, 7.470262782914298, 6.1116359148706705, 2.036171551261629, 0.29274969973734444, 0.20230848634881632, 0.7947566679545811, 5.298356217997415, 19.345950978142874, 34.96878964560372, 41.900357723236084, 34.92805930546352, 43.605998039245605, 51.041070801871165, 47.408945151737754, 38.4297707421439, 17.960846696581157, 3.670676861490522, 0.06188151839056185, 0.05887045817715781, 0.030540684770260538, 0.012880144258295851, 0.0830124830827117, 0.025531035282516053, 0.032193260200853856, 0.03639178044561829, 0.055098454867090495, 0.010072306979314556, 0.05014333075710705, 0.04622298612126282, 0.04861957859247923, 0.01400669729004481, 0.02778972908189254, 0.058956007872309, 0.01895890794029193, 0.05648548222546067, 0.026408347134877528, 0.014565766888803669, 0.027584407777924622, 0.061962610110640526, 0.01835704398607569, 0.006075102985570473, 0.05843538830855063, 0.15550908472921166, 0.15536220903907502, 0.20216896597828182, 0.10377911518194846, 0.15835499630442687, 0.15959029644727707, 0.09217403576310192, 0.1819058611456837, 0.13396600500813552, 0.09558527557445423, 0.10328054800629616, 0.15326805998172077, 0.16532786642866476, 0.11417113005050591, 0.1729933443878378, 0.1726380634520735, 0.11574257644159452, 0.14954761176237039, 0.12175241538456508, 0.08173795683043343, 0.08499843294599227, 0.14671635654355797, 0.12991159542330674, 0.08703899130757366, 0.35469796561769074, 7.363059026854379, 31.484789167131694, 53.12709719794137, 53.822097710200715, 51.435123988560264, 39.60017742429461, 31.893687180110387, 37.06066295078823, 44.55662277766636, 31.911912305014475, 10.46442220892225, 2.5626626142433713, 1.0729220445666994, 3.2597202275480543, 2.38580099599702, 6.12783477136067, 12.110767466681343, 22.03134982926505, 21.443471431732178, 22.05641892978123, 16.36911862237113, 16.18226592881339, 25.406812497547694, 24.60755773953029, 25.26672986575535, 42.71408905301775, 51.610753604343955, 53.66174370901925, 49.849736145564485, 47.47856957571847, 44.90845176151821, 43.94068929127285, 47.616526058741975, 49.94385296957833, 50.786971705300466, 53.32745197841099, 51.58332559040615, 50.590685095105854, 49.326283182416645, 48.27435718263899, 51.07556513377598, 50.57722296033587, 46.096746580941335, 41.80895069667271, 37.455692359379356, 39.4536121232169, 49.06149428231375, 48.249253341129844, 48.37519638878958, 49.757186140332905, 52.36665160315377, 51.13819966997419, 49.029167788369314, 51.04384660720825, 50.22918769291469, 48.56287070683071, 50.884976046425955, 46.375859192439485, 40.8262357030596, 38.533396175929475, 44.944926330021445, 52.330256938934326, 48.60323626654488, 47.49563087735857, 54.773952279772075, 45.63216917855399, 40.781194005693706, 37.44532912118094, 37.42986243111746, 39.334130900246755, 39.72683613640921, 43.142699105399, 46.93859379632132, 45.86547579084124, 42.95860310963222, 40.057719775608604, 38.06978457314627, 37.438377448490684, 37.06145504542759, 40.862991673605784, 50.35525580814907, 50.63385425295149, 50.059425830841064, 46.890724182128906, 48.52400595801217, 50.87009300504412, 53.01362269265311, 50.92531728744507, 53.08647802897862, 48.67358677727835, 48.35380635942732, 48.892420291900635, 47.59470176696777, 46.85903344835554, 48.86198023387364, 49.254018442971365, 49.41938556943621, 47.3351274899074, 48.30995280402047, 39.67724336896624, 34.66350317001343, 27.42581135886056, 20.03309828894479, 18.14448584829058, 25.14125755855015, 26.369226591927664, 30.260992527008057, 22.757617235183716, 18.224468299320765, 15.32207373210362, 4.938329662595477, 3.1066310022558485, 0.36576674452849794, 0.4898881699357714, 1.0685593358107974, 7.093175360134669, 21.661314828055247, 38.201949732644216, 46.273599079677034, 40.75890418461391, 47.94518280029297, 55.93168197359358, 53.575690269470215, 45.69471338817051, 22.83134457043239, 6.0051469547407965, 0.24960866038288387, 0.12857614351170404, 0.16741381878299372, 0.08544472578380789, 0.1968486136091607, 0.1214009342449052, 0.10896855778992176, 0.1068235118208187, 0.20217105586613926, 0.11678407341241837, 0.13590966856905393, 0.1352623054491622, 0.14569510705769062, 0.10349710924284798, 0.09798534214496613, 0.13865723327866622, 0.22014633060566016, 0.09171079312052045, 0.18159560779375689, 0.1381670595811946, 0.1310927349009684, 0.17296111397445202, 0.08190316653677396, 0.072593679651618, 0.14097768733544008], [0.03237583701099668, 0.005918313898811383, 0.012062377246495868, 0.02974919741973281, 0.08884583506733179, 0.016869011601167064, 0.04399537601109062, 0.05097739278737988, 0.03710749579061355, 0.05544295048873339, 0.0322329477140946, 0.020625313610902855, 0.00932126710124846, 0.03827647931341614, 0.0365912799191262, 0.03493255017591374, 0.04722367938874023, 0.051310054758297544, 0.02261888002976775, 0.09381215500512294, 0.03535477537661791, 0.01549655238964728, 0.024442464944773486, 0.10803725490612642, 0.08971271105110645, 2.7253857340131487, 15.460313354219709, 33.612525599343435, 42.81783608027867, 32.05388137272426, 24.98739664895194, 19.565286500113352, 24.501863479614258, 24.95739606448582, 21.57334542274475, 7.804309589522226, 1.681929588317871, 0.09452104089515549, 4.867902287415095, 13.296312536512103, 13.576899903161184, 5.334944997514997, 6.72860164301736, 6.44197325195585, 8.49604618549347, 10.349735242979866, 13.168907761573792, 13.333869286945887, 18.00039758001055, 26.58564039639064, 42.44032655443464, 49.04861232212612, 45.38057490757534, 41.836670534951345, 39.079413414001465, 38.06858948298863, 37.1924980708531, 36.00092370169503, 38.467016560690745, 42.128842285701204, 45.46936593736921, 48.44453246252877, 48.47943673815046, 49.01862389700753, 47.831385203770225, 49.39273575374058, 45.86915833609444, 41.34524181910923, 33.76819651467459, 35.58535194396973, 44.009528568812776, 48.62306989942278, 49.9400314603533, 48.4556565284729, 47.926280226026265, 49.473320960998535, 48.73622478757586, 48.38907888957432, 50.146427699497764, 47.11673171179635, 45.89753825323922, 43.141316413879395, 38.67867258616856, 34.36530385698591, 37.75180721282959, 41.47145584651402, 47.84995773860386, 44.33050060272217, 40.76838500159127, 49.483850955963135, 43.31733512878418, 36.808113302503315, 33.04626478467669, 35.42276062284197, 36.71421534674508, 42.491291591099326, 46.42679991040911, 48.43826518739973, 47.455571038382395, 47.83602312632969, 44.22777496065412, 42.260062490190776, 38.13390254974365, 34.52082886014666, 34.178306988307405, 41.836583682468955, 46.094474520002095, 46.11907809121268, 46.44234650475638, 51.27939053944179, 49.13848727090018, 45.98172262736729, 45.53689547947475, 47.07208606175014, 48.58782516207014, 47.14489276068551, 50.16284629276821, 46.664695807865684, 46.78617116383144, 45.58378539766584, 48.7169782774789, 47.06748982838222, 49.60227952684675, 45.06311518805367, 38.690991742270334, 31.570870399475098, 15.265068973813738, 6.834702372550964, 4.954426033156259, 0.3729595685643809, 6.472108892032078, 11.716122814587184, 10.978838171277728, 23.972144978387014, 4.971621956144061, 5.576160396848406, 2.293071206126894, 0.040469328074582984, 0.057384134004158635, 0.48329861781426836, 4.646969548293522, 13.745612587247576, 25.42217149053301, 25.3582706451416, 20.69249623162406, 26.921872411455425, 36.931843348911826, 42.16850955145699, 35.30990103312901, 18.967696257999965, 3.7572318741253445, 0.028771930573774234, 0.06247458513826132, 0.07068454673779861, 0.007356016796880535, 0.06979472269969327, 0.028664874711206982, 0.04702064135511007, 0.03365313168615103, 0.015012041066906281, 0.02212411943557007, 0.03139219193586281, 0.018913225570161427, 0.02113108173944056, 0.05408305096040879, 0.08572095060454947, 0.004728339471122516, 0.011596399259620478, 0.029195292320634638, 0.011288700592038887, 0.05936909320631197, 0.04223564633035234, 0.03269837523943611, 0.027646732915725027, 0.045635914230453115, 0.0014757454939951587, 0.02788619470915624, 0.013126041108210171, 0.036307282479746, 0.04811490460165909, 0.04648058515574251, 0.035441312340221236, 0.047989012606974156, 0.053058096673339605, 0.013530948398900884, 0.036195839888283184, 0.03609716393319624, 0.05781212675252131, 0.030048519572509185, 0.03369352826848626, 0.0242059004958719, 0.052842543061290465, 0.046400870861751695, 0.04459983536175319, 0.03131261334887572, 0.06421753125531332, 0.04125391472397106, 0.04537579104570406, 0.07649867582534041, 0.04404781659000686, 0.1088833948597312, 4.055482864379883, 17.96603352682931, 39.00651638848441, 49.43749952316284, 39.659869398389546, 29.521370683397564, 22.457060745784215, 26.033722400665283, 29.12748772757394, 24.626366513116018, 8.943522334098816, 1.715134920818465, 0.21667457904134477, 4.123400637081691, 10.505025744438171, 4.653836105551038, 3.605393324579511, 8.222805670329503, 11.266644716262817, 10.383896929877144, 15.90885431425912, 15.427952119282313, 11.52371677330562, 18.5450599193573, 29.046673229762487, 46.16032954624721, 50.436640058244976, 48.445136955806184, 44.0512490272522, 41.825258118765696, 39.44096987588065, 40.25385699953352, 38.38994366782052, 42.04012073789324, 44.95220456804548, 47.65174995149885, 50.258568150656565, 48.94482013157436, 48.14586762019566, 49.41411883490426, 51.82341711861746, 48.07069853373936, 42.140265124184744, 35.30218505859375, 37.469053745269775, 46.24791506358555, 51.41130208969116, 52.19268260683332, 50.314751284463064, 49.6982376234872, 49.522243227277485, 50.040064675467356, 47.549562794821604, 50.685611384255544, 49.1772860118321, 48.85928780691964, 44.09970923832485, 40.553008215767996, 35.650050095149446, 38.40716477802822, 42.145858424050466, 50.801507336752756, 46.71437542779105, 43.30236176082066, 51.895091261182515, 44.665667806352886, 39.66623394829886, 34.88977820532662, 37.02350051062447, 38.39668689455305, 43.854712281908306, 47.05461481639317, 51.3234977040972, 49.06468003136771, 49.42177922385079, 45.87454319000244, 43.832286970955984, 38.76670626231602, 35.20356927599226, 35.514827728271484, 42.6810052054269, 48.99318306786673, 48.8185088293893, 48.386657442365376, 52.62991189956665, 52.20201056344168, 49.63939332962036, 48.074509620666504, 48.713087286267964, 50.43673038482666, 47.85682603291103, 49.23773186547415, 46.103125027247835, 46.1870071547372, 47.18242345537458, 49.666699750082834, 47.982824666159495, 50.08625282560076, 44.133963857378276, 38.64355639048985, 31.280008384159633, 17.04826855659485, 11.28013116972787, 7.794333713395255, 7.718836324555533, 9.844995515687124, 11.79193547793797, 12.859405466488429, 13.770957010132925, 12.696587460381643, 6.990514857428415, 3.43353180374418, 0.6618265009352139, 0.04546395649335214, 0.8421602100133896, 5.118137751306806, 16.563065426690237, 29.356451715741837, 28.748896019799368, 27.293955394199916, 31.70691612788609, 43.59807709285191, 47.04340042386736, 41.76503113337925, 22.758515289851598, 5.097404326711382, 0.027430246318025247, 0.03384460409038833, 0.0240160582720169, 0.01268046666934554, 0.023984594603202174, 0.02623438093412135, 0.020190484622227292, 0.0774331610383732, 0.02800069749355316, 0.05486591752352459, 0.06369607709348202, 0.05554956530353852, 0.021275095708136047, 0.0729722682652729, 0.027258312329649925, 0.03076498130602496, 0.04697993943201644, 0.013640768443500357, 0.017933999454336505, 0.0235336571931839, 0.015209664391087634, 0.05954657761113984, 0.030352174171379635, 0.06023389965827976, 0.040518711853240214, 0.11380072456917592, 0.09156083688139915, 0.12315884205911841, 0.13318935382579053, 0.14494314097932406, 0.10462028825921671, 0.19621055998972484, 0.1080004715227655, 0.10196084489247628, 0.11857155178274427, 0.15146986075810023, 0.18564089786793503, 0.13876619243196078, 0.13806594429271563, 0.14017796596246107, 0.12319238883044038, 0.08850683218666486, 0.10181825075830732, 0.12539487278887204, 0.20406081660517625, 0.1475388766931636, 0.14138480834662914, 0.10474411411476986, 0.19099956032420906, 0.1582627562539918, 5.468489374433245, 23.301635129111155, 47.54022789001465, 55.540144034794395, 43.911572865077424, 35.19092008045742, 29.581611565181188, 35.56757845197405, 35.07001100267683, 27.815143244607107, 10.871822885104589, 2.400422611406871, 0.5630709401198796, 5.6123813561030795, 18.927301168441772, 20.042256014687673, 11.452613251549856, 14.653083801269531, 16.620513132640294, 16.21104884147644, 18.722600289753505, 20.441270215170725, 19.510774408067974, 21.79894127164568, 28.560014452253068, 46.34271281106131, 52.400666509355815, 50.42415761947632, 46.223050934927805, 43.61406142371041, 42.06771898269653, 42.86141170774187, 39.38583592006138, 43.0961149079459, 46.55309731619698, 49.270989418029785, 52.074372155325754, 49.956668921879356, 50.313243525368826, 49.27175371987479, 52.799406255994526, 50.42467178617205, 43.83621270315987, 38.23328610828945, 39.59229816709246, 49.22954341343471, 54.05759647914341, 53.66701391765049, 50.89403649738857, 50.15492534637451, 51.07810470036098, 50.67122513907296, 48.221686363220215, 50.95631667545864, 52.044084957667756, 50.029635429382324, 47.85268490655081, 42.30702189036778, 37.03960296085903, 40.911125319344656, 44.460678577423096, 53.107638767787385, 50.06864261627197, 45.70478480202811, 52.730483600071494, 47.071530205862864, 42.11582483564104, 37.20729773385184, 40.221346378326416, 42.069925035749165, 46.273282936641145, 49.433952467782156, 51.9030156816755, 51.985216345105854, 52.06188971655709, 48.57311235155378, 47.23935004643032, 41.79894181660244, 38.2241770199367, 37.45520598547799, 43.28554017203194, 50.71203885759626, 50.6257700238909, 49.30201659883772, 54.29605518068586, 54.81504740033831, 50.56432015555245, 50.827986921582905, 50.8578085899353, 52.762111800057546, 47.525980608803884, 49.81212554659162, 45.09313488006592, 46.57178797040667, 45.579783235277446, 51.28093303952898, 49.522413458142964, 50.77175862448556, 45.941714899880544, 43.23422425133841, 37.80974129268101, 20.96704387664795, 11.720418538366046, 11.330744453838893, 6.952037036418915, 15.860069274902344, 24.0871376650674, 21.517164025987896, 38.122893129076274, 17.289633342197963, 12.047576206071035, 6.965616422040122, 1.1276962139776774, 0.19510623067617416, 1.6140918284654617, 6.182372050625937, 17.988120113100322, 33.84823281424386, 34.93791879926409, 31.73055042539324, 38.000611782073975, 49.38016993658883, 53.18092141832624, 48.92128310884748, 28.686245850154332, 6.508012839726039, 0.13834273229752267, 0.19855880684086255, 0.17107973992824554, 0.13244379311800003, 0.13087147820208753, 0.09727566236896174, 0.12630083917507104, 0.11785349888460976, 0.09709016446556364, 0.16238799132406712, 0.23287989518472127, 0.10184085954512868, 0.16076365991362504, 0.11946613235133034, 0.12959569666002477, 0.22678533435932227, 0.11504748516849109, 0.1383677702397108, 0.07807437663099595, 0.09365822255079236, 0.10275929740497045, 0.1034130116126367, 0.09719788189977407, 0.14950875884720258, 0.08898190169462136], [0.057675150888306756, 0.04262046728815351, 0.037072405352124145, 0.024137241233672415, 0.04528541696657028, 0.03318120040265577, 0.031971986538597515, 0.03594695324344294, 0.010285741865767964, 0.05273562290572694, 0.024995247068415796, 0.024070605702166046, 0.029691806927855526, 0.01737076958774456, 0.05029447103983589, 0.0354161760104554, 0.05460810475051403, 0.05400828657937901, 0.024819323294130818, 0.022745386098644564, 0.0202147541235068, 0.039340849699718614, 0.020002277667767236, 0.05899319837668112, 0.029974213202617, 1.7013381868600845, 14.621191569737025, 33.46590123857771, 37.47501182556152, 33.15176623208182, 26.958274023873464, 13.481991853032794, 16.321186474391393, 24.277073621749878, 19.494703224727086, 8.075450011662074, 1.4677634175334657, 0.6327734770519393, 5.238612132413047, 21.751841170447214, 38.74148082733154, 8.978749700954982, 6.232528056417193, 11.056180306843348, 9.61220133304596, 17.54705367769514, 14.333950434412275, 12.219414710998535, 17.106539624077932, 31.32840953554426, 43.89853457042149, 44.8100756917681, 43.72099072592599, 40.4287223134722, 42.92983061926705, 43.296181338174, 43.15333679744175, 39.065075806209016, 35.8631409236363, 37.57422515324184, 41.30145079748971, 45.55924436024257, 49.16354942321777, 48.203728743961875, 49.31727484294346, 48.8388739994594, 46.12155512401036, 40.34827954428536, 32.9159791128976, 35.757100990840364, 46.08883605684553, 49.94036149978638, 50.92140545163836, 47.563393184116904, 48.03242438180106, 50.32266180855887, 49.52440064293997, 47.65200356074742, 48.52499260221209, 46.225503649030415, 42.995762075696675, 37.9588565826416, 35.249323163713726, 33.4171769959586, 37.23535108566284, 41.62202330998012, 47.0017147064209, 44.33776494434902, 39.925568512507844, 52.273625646318706, 43.76619570595877, 37.75378744942801, 33.12126016616821, 36.467668942042756, 39.57888466971261, 47.644033976963584, 46.684327942984446, 47.869683674403596, 48.86353315625872, 50.34256492342268, 47.652482986450195, 48.686701502118794, 46.19524424416678, 45.380581855773926, 38.48754153932844, 34.66201278141567, 38.842368670872276, 45.590132577078684, 45.913039684295654, 44.0201975277492, 39.97190604891096, 40.34667451041085, 41.07531125204903, 45.41051469530378, 48.383370944431846, 48.14274093082973, 47.797120162418906, 47.466983454568044, 49.17105695179531, 48.85202693939209, 48.050329889569966, 48.62314632960728, 46.1139155796596, 46.63864006314959, 39.45707927431379, 26.266203914369854, 19.831331287111553, 17.338169983455114, 4.775006175041199, 7.06642392703465, 8.56006862436022, 14.146983964102608, 14.981448718479701, 6.156999400683811, 9.000927482332502, 7.37602002280099, 1.9056937183652605, 0.4817923243556704, 0.2693382331303188, 0.4367491884955338, 3.5791128490652357, 11.725685272897993, 30.08093343462263, 27.645530768803187, 22.30663398333958, 23.9804949760437, 32.31703397205898, 44.43247931344168, 35.58886773245675, 16.988211802073888, 2.4455142489501407, 0.007168720775683011, 0.05366964332227196, 0.032636645516114574, 0.061344885400363376, 0.014038580802402325, 0.06571273066635643, 0.06359183375856706, 0.042042375808315616, 0.03580601473471948, 0.03598711573119674, 0.025197565854926194, 0.02176690467500261, 0.04592202530641641, 0.0357165431071605, 0.021971644135192037, 0.10121834437761988, 0.05978917423635721, 0.04771598368617041, 0.05054599379322358, 0.0427850900617029, 0.0425438606845481, 0.025505440941612636, 0.05279486919088023, 0.08468255453876086, 0.0588587670187865, 0.057673949881323745, 0.027767761510663798, 0.03317881874474032, 0.0392771963296192, 0.019151589833199978, 0.09101657715759107, 0.009712900550636863, 0.08021867621157851, 0.015999971090682914, 0.041880178797457895, 0.08767994227153914, 0.027866172837093472, 0.06010992452502251, 0.036517557089350054, 0.0298440362592893, 0.031067441683262587, 0.04376812445531998, 0.031925357612116, 0.01449504996916013, 0.032685550927583656, 0.04002209546576653, 0.06933910679072142, 0.05060501276914563, 0.03047909414661782, 0.023817993900073425, 2.229060709476471, 17.894590411867412, 41.11158084869385, 43.85768263680594, 39.36879893711635, 31.885741915021622, 21.124556064605713, 26.16577638898577, 28.15407289777483, 21.966309479304723, 8.855843884604317, 1.7082112580537796, 0.6823543022785867, 6.547241934708186, 27.18173156465803, 36.17373929704939, 5.9025081651551385, 7.534854105540684, 11.507384163992745, 12.497160264423915, 16.512930699757167, 16.354838337217057, 16.57475577081953, 19.273743561335973, 31.185102939605713, 46.11376619338989, 48.9579313823155, 46.017384256635395, 41.89661264419556, 45.812332493918284, 45.14449943814959, 43.24795389175415, 39.929720061165945, 36.77832637514387, 39.98233182089669, 44.11713532039097, 47.952263014657156, 50.60483510153634, 48.0545266015189, 48.69767270769392, 50.041169439043315, 47.417675563267295, 42.09246499197823, 34.0019200188773, 38.24378831045968, 48.882755347660606, 50.88256502151489, 50.56625175476074, 48.44600895472935, 48.40063374383109, 50.52433327266148, 50.98302902494158, 48.694521699632915, 49.432271003723145, 47.32085241590227, 45.50981487546648, 39.60949148450579, 36.475617681230815, 35.451331615448, 38.793310914720806, 42.5382753099714, 48.63352346420288, 47.82874836240496, 43.732531683785574, 53.59296696526663, 46.12281622205462, 38.24111325400216, 34.811173234667095, 38.349227224077495, 42.56633560998099, 48.14463778904506, 49.13200807571411, 48.66984517233712, 48.20318678447178, 52.47756917136056, 49.824413435799734, 51.25513090406145, 47.85019397735596, 46.82704741614205, 39.42834152494158, 36.29043081828526, 42.35123675210135, 48.66210487910679, 47.94631883076259, 47.84712634767805, 43.25113269260952, 43.69760308946882, 43.95543336868286, 48.361306939806255, 49.730584962027415, 47.6466360773359, 47.46170629773821, 49.11994252886091, 48.675931794302805, 49.097357409340994, 47.63310446058001, 50.792860303606304, 48.48903914860317, 47.1663487979344, 39.976609979357036, 30.388940129961284, 20.123664583478654, 20.377468381609233, 11.600090503692627, 11.063951866967336, 13.332084468432836, 14.163393003599984, 9.344038214002337, 12.315855707441058, 9.32108223438263, 5.360561268670218, 2.906038897378104, 0.23487652518919536, 0.3575395074273859, 0.41845409306032316, 4.235188901424408, 13.447639959199087, 31.574094363621303, 29.45300735746111, 26.066920893532888, 30.83616440636771, 38.75686066491263, 50.31279189246041, 41.298251152038574, 20.45606119292123, 3.410870688302176, 0.027695690913658057, 0.02017050515860319, 0.10392977031213896, 0.06495540416134254, 0.041480046696960926, 0.023903163615614176, 0.054426477889397314, 0.052604214421340396, 0.06826179674161331, 0.015364918292367032, 0.009777687922386187, 0.034713006777954955, 0.014850904267015201, 0.055796178856066296, 0.03346418682485819, 0.049689343332179954, 0.06046335306018591, 0.01327580735752625, 0.04127529875508376, 0.05016210242839796, 0.07485813421330281, 0.04330370455448117, 0.025903932683702027, 0.022503412029306804, 0.05490892646568162, 0.13704264563109192, 0.1328753956726619, 0.2033004502632788, 0.17701378650963306, 0.11655813482190881, 0.21842506368245396, 0.10217153001576662, 0.1481442792075021, 0.06721728707530669, 0.1431940405496529, 0.14014855825475284, 0.14118725966129983, 0.1275312810071877, 0.10648856657956328, 0.12317888598356928, 0.0885456647457821, 0.10780732652970723, 0.1261163047913994, 0.11491845494934491, 0.08868210456733193, 0.09412552283278533, 0.21866305305489472, 0.1852832692010062, 0.18858013514961514, 0.19841467243220123, 3.3004279860428403, 22.23821680886405, 47.708461148398264, 51.32394586290632, 45.585366112845286, 37.58524152210781, 23.07097578048706, 26.43406023297991, 35.16849129540579, 27.18089951787676, 10.368582231657845, 2.258271153484072, 1.1720651303018843, 6.462813070842198, 27.475253002984182, 50.76124947411673, 16.473534413746425, 19.187686647687638, 22.750549180167063, 19.147607701165335, 29.307150772639684, 22.13921366419111, 18.3587543964386, 22.035190446036204, 33.6957893371582, 48.82166331154959, 49.70474461146763, 49.099938665117534, 44.425406047276084, 48.7253543308803, 47.205397674015586, 46.86396319525582, 42.75934614453997, 38.14849376678467, 41.95551947184971, 46.63933835710798, 49.06898096629551, 51.78340939113072, 48.7140530858721, 49.27920913696289, 50.4968010357448, 49.95291689464024, 44.24016012464251, 35.69885771615164, 40.245654651096885, 50.59670918328421, 52.983085359845845, 50.8944742338998, 48.17515427725655, 49.49561078207833, 51.9389865057809, 52.018418312072754, 50.90130778721401, 51.65986347198486, 49.07914270673479, 47.38898992538452, 41.39831215994698, 37.92497021811349, 37.66363109861101, 40.491395064762656, 45.83630377905709, 49.97633579799107, 50.52148451123919, 46.58872767857143, 55.838673387254985, 49.75553594316755, 41.480474608285085, 37.25325311933245, 40.56613336290632, 44.694085938589915, 51.73655768803188, 51.846717902592246, 50.21661145346505, 49.12562615530831, 54.8700840813773, 51.80882242747715, 52.97432368142264, 50.48571171079363, 50.522384302956716, 42.67804527282715, 38.37272950581142, 43.92793934685843, 50.24276099886213, 50.03558308737618, 50.21996743338448, 44.047191279275076, 45.55078492845808, 46.54822315488543, 50.000352246420725, 51.95944895063128, 48.45111240659441, 48.08595677784511, 48.06096063341413, 48.97002819606236, 49.06018802097866, 49.13897711890084, 52.109453610011506, 48.36461080823626, 49.007833344595774, 41.84991727556501, 30.14038222176688, 23.289498363222393, 20.726396492549352, 10.306785821914673, 12.341226186071124, 14.94308945110866, 16.398045710154943, 23.331371682030813, 14.371679152761187, 14.506153719765798, 14.614698478153773, 5.21823263168335, 1.5127734137432916, 0.6290580364210265, 0.8442427154098238, 4.8527660710471014, 16.31543336595808, 38.22095305579049, 37.84301274163382, 33.564444065093994, 36.497577462877544, 43.16891118458339, 56.93078429358346, 48.48487370354788, 26.453341484069824, 5.168178677558899, 0.1999848024653537, 0.1687054509030921, 0.16765338235667773, 0.17647823239011423, 0.11401024939758436, 0.15151256775217398, 0.12706500531307288, 0.12128498618091856, 0.18653279143784726, 0.07191665098071098, 0.12639795110694, 0.137714327446052, 0.07774471717753581, 0.17070677636989526, 0.07750400687967028, 0.15396114279116901, 0.11315981431731156, 0.13150316716304847, 0.1303142381033727, 0.12163078119712216, 0.10373231662171227, 0.09635217620858125, 0.15551124247057097, 0.16149524280003139, 0.15641947516373225], [0.03669003390574029, 0.08953503665647336, 0.04341254835682256, 0.0959168349259666, 0.011717935907654464, 0.020394740626215935, 0.028792239126882384, 0.06752233606364046, 0.046646860162062306, 0.030874415433832576, 0.029188286446567093, 0.024203780073938624, 0.027199590212798545, 0.07514700014144182, 0.0435959190529372, 0.05051111709326506, 0.0230953083040991, 0.033580243454447815, 0.05150881802131023, 0.07775051865194525, 0.03846830455586314, 0.05098869039544037, 0.04955911889140095, 0.040993143538279195, 0.06742545483367783, 0.4608444284115519, 10.159192187445504, 27.06257516997201, 34.69969981057303, 33.15432664326259, 24.161888122558594, 12.074217336518423, 11.425165261541094, 17.641229561397008, 15.539321320397512, 7.848658204078674, 1.2847448268107005, 0.3831576784806592, 0.5932380099381719, 1.4351930852447237, 6.539162048271724, 3.5221458716051917, 4.914835631847382, 8.785552433558873, 7.971718617847987, 18.147829668862478, 17.892028263637, 16.254094668797084, 20.663433653967722, 33.96572685241699, 42.77180426461356, 45.12265430177961, 40.786082063402446, 43.74744599206107, 45.09320783615112, 47.821970394679475, 46.336278779166086, 43.39376878738403, 37.764477252960205, 33.56701489857265, 37.33739580426897, 43.05959170205252, 44.97659274509975, 48.42225306374686, 47.66865839276995, 48.30205617632185, 45.65084246226719, 39.13489825384957, 32.43578563417707, 36.319842542920796, 46.49661193575178, 49.58012172154018, 49.74291801452637, 49.64726216452462, 48.5049227305821, 47.932495389665874, 45.98724297114781, 46.71299621037075, 46.17341300419399, 41.328427178519114, 38.86438056400844, 34.451735973358154, 35.85024159295218, 34.03857176644461, 38.581133774348665, 42.012411321912495, 46.42379828861782, 45.43426711218697, 37.8773055757795, 51.161424023764475, 42.78230994088309, 37.93453788757324, 33.24943011147635, 37.73383917127337, 41.26495885848999, 47.955358437129426, 45.923785073416575, 47.88353143419538, 50.24509906768799, 50.50378050122942, 47.2066205569676, 49.42410339627947, 48.888682161058696, 48.58058861323765, 45.61805738721575, 38.36608702795846, 33.1797570501055, 33.29434674126761, 34.21799162455967, 36.21774918692452, 35.481994015829905, 37.06462689808437, 41.627074650355745, 46.76520497458321, 47.77121032987322, 46.737929821014404, 46.05097532272339, 46.54642357145037, 45.4020413671221, 45.82213292803083, 45.51609604699271, 49.42996767589024, 49.799511092049734, 45.34966584614345, 39.84344775336129, 34.73259258270264, 20.19574519566127, 17.335463660103933, 14.804849828992571, 14.53266978263855, 13.148252504212515, 13.435405050005231, 6.098804763385227, 12.314558131354195, 9.032870088304792, 3.5266081350190297, 2.4152646149907793, 0.7591281511953899, 0.23141748937112944, 0.26153923305017607, 3.3801731126649037, 13.199604902948652, 27.072771651404246, 21.660289968763077, 22.685316017695836, 29.739655290331157, 40.6956582069397, 38.59557213102068, 37.579328605106895, 15.537431410380773, 4.268923708370753, 0.08475244364568166, 0.10049864263939005, 0.03355354988681419, 0.04447585005047066, 0.041940565021442514, 0.02899634585316692, 0.017482454755476544, 0.03214084676333836, 0.0316652513907424, 0.02315692776548011, 0.05443240150011011, 0.06495990284851619, 0.06552986547883068, 0.026193986048123667, 0.0660331416875124, 0.07122384637062039, 0.06682185043713876, 0.07337662763893604, 0.03651992517656513, 0.0582227422190564, 0.05321648031739252, 0.018311965512111783, 0.010669479712045618, 0.061371178632336, 0.0548609913592892, 0.00819299737590232, 0.03544329705515078, 0.046197164471128156, 0.016741022933274508, 0.045248290923024924, 0.029577578950141157, 0.014895456876339657, 0.04256187239661813, 0.021607837406918406, 0.04895940589319382, 0.026340413905147995, 0.005785184479983789, 0.05505919822358659, 0.028259261744096875, 0.050852379495544095, 0.033507955726236105, 0.0321456982887217, 0.06809642418686833, 0.040678876651717086, 0.06522584786372525, 0.04768543603963085, 0.047914499283901284, 0.017154506906600933, 0.012548617985365646, 0.09408794556345258, 0.9653213726622718, 13.771233201026917, 34.61769717080252, 43.39119100570679, 39.12104007175991, 29.180502482822963, 16.23191601889474, 17.06496160370963, 26.035289219447545, 20.71333909034729, 8.572167175156729, 1.4091290895427977, 0.5040364935994148, 0.9278397496257509, 3.746227664606912, 16.607827459062847, 7.804855891636439, 7.891473003796168, 7.973607659339905, 14.104375873293195, 12.998198338917323, 9.10060807636806, 16.41334216935294, 22.076516594205582, 34.44861970629011, 45.26505763190133, 48.52092443193708, 42.94391809191023, 45.84327629634312, 46.32521724700928, 49.797291142599924, 49.28547293799264, 46.04198782784598, 38.676087856292725, 36.14005790437971, 40.401374203818186, 44.91520193644932, 45.92263862064907, 49.199530669621055, 48.66368906838553, 49.83445358276367, 48.3731883593968, 40.34974908828735, 34.16379220145089, 38.35652978079659, 48.3830235345023, 51.04087625231062, 51.215814522334504, 50.08893830435616, 50.074836935315815, 49.24168886457171, 47.42899765287127, 48.739438329424175, 48.118227686200825, 43.52500983646938, 41.01510511125837, 36.94320017950875, 36.80621644428798, 35.622191292899, 38.24587624413626, 44.82773106438773, 49.55269718170166, 47.23355524880545, 39.265288148607524, 53.5714727129255, 44.765509946005686, 40.1591009412493, 34.36038800648281, 40.35671465737479, 43.459901741572786, 49.894447803497314, 49.547211578914094, 49.140929562704905, 49.00979968479702, 49.55142566135952, 47.40542241505214, 50.70906155450003, 50.58278499330793, 50.59207820892334, 46.08126252038138, 39.92613479069301, 34.09389679772513, 36.2445900780814, 37.18727649961199, 40.422208377293174, 37.06132650375366, 38.93930646351406, 44.296447481427876, 48.88814714976719, 47.973545346941265, 48.18028899601528, 45.984838894435335, 46.752593994140625, 45.12810863767351, 46.34776415143694, 46.31996440887451, 49.46678965432303, 50.58176013401577, 47.288456439971924, 42.575868538447786, 35.82021842684065, 24.66805223056248, 23.901106595993042, 17.50813681738717, 15.635286365236555, 12.096665229116168, 14.157553042684283, 7.767117619514465, 15.016731670924596, 13.486510787691389, 5.344784080982208, 4.969453249658857, 0.13368479295500688, 0.47193853024925503, 0.35639840151582447, 4.054047627108438, 13.077611906187874, 30.255621569497244, 28.048727784837993, 27.10796080316816, 32.221089771815706, 46.17699827466692, 44.30125216075352, 41.858922140938894, 19.26794876371111, 4.83587543453489, 0.14038761971252306, 0.042506605719349215, 0.018958193782184805, 0.02341337498676564, 0.04422986753551023, 0.018817621682371413, 0.015721776822049702, 0.06885578629693814, 0.011121778432945055, 0.0434681034114744, 0.07852474067892347, 0.026633569870942404, 0.09034883763108935, 0.028866871193583523, 0.018839350070006082, 0.0754315098747611, 0.042759176809340715, 0.024594124306791594, 0.04975438769906759, 0.015291629725002816, 0.023694763458999138, 0.03223652359364288, 0.022005475891221846, 0.09112885434712682, 0.029601392136620622, 0.11568085689629827, 0.14966267773083278, 0.14916432090103626, 0.1608228688793523, 0.11431187178407397, 0.12378662265837193, 0.10914362661008324, 0.11257199943065643, 0.12801882198878697, 0.21797907618539675, 0.08411417289503983, 0.13138694768505438, 0.18813688893403324, 0.11710963451436587, 0.13237725597407135, 0.12074717932513782, 0.09549058601260185, 0.1672950887254306, 0.13948105621550763, 0.2869427427649498, 0.11846050274159227, 0.11674853174814157, 0.07716134669525282, 0.10367437651646988, 0.16352759088788713, 1.8531855302197593, 18.24989696911403, 41.130090849740164, 49.50107206617083, 44.8254451070513, 34.26444728033883, 19.82950564793178, 19.589035442897252, 27.432431255068096, 22.595553977148874, 10.679775544575282, 2.069129679884229, 0.6034049072435924, 0.8358430489897728, 2.1662867750440324, 11.431169373648506, 6.157601722649165, 8.200924055916921, 15.435880013874598, 16.095807756696427, 24.51256196839469, 27.156891754695348, 23.924589770180837, 28.23193093708583, 36.01320811680385, 47.229803221566335, 49.823857579912456, 46.292275837489534, 47.98126826967512, 49.13591296332223, 51.46093307222639, 50.46067040307181, 48.21555805206299, 41.72146245411464, 38.125800950186594, 41.876382963997976, 47.07509810583932, 47.50938483646938, 51.04909944534302, 49.26845332554409, 51.77234091077532, 50.58327831540789, 43.805439131600515, 36.21649851117815, 40.3205805506025, 50.842272417885916, 53.63064009802682, 51.60815497807094, 52.372804233006065, 51.24330507005964, 51.70063550131661, 50.76107576915196, 51.65823759351458, 50.57938732419695, 45.448497022901265, 41.64542831693377, 38.692544664655415, 39.97861106055123, 37.911678314208984, 41.697991439274375, 47.17004523958479, 51.23975454057966, 49.913930552346365, 43.099648066929404, 55.78786815915789, 47.56932347161429, 42.28857789720808, 37.977724415915354, 42.61653981889997, 45.913967268807546, 53.10901798520769, 50.7674993787493, 51.16088901247297, 51.43243156160627, 51.659418787275044, 49.57486193520682, 50.169381073543, 51.91678353718349, 51.92016383579799, 49.5251475742885, 42.38221182141985, 36.942168372017996, 37.75716079984392, 37.7343533379691, 41.33933932440621, 39.232284205300466, 41.97256340299334, 46.302687713078086, 51.74752541950771, 49.89227301733834, 48.250490120479036, 46.506912640162874, 46.17637988499233, 45.01655878339495, 46.402776513780864, 47.33870928628104, 49.14785691670009, 52.06515189579555, 48.43658372334072, 44.127839020320344, 37.26358509063721, 21.12250460897173, 21.569609028952463, 22.500386238098145, 19.423567567552837, 18.08320447376796, 23.137562104633876, 13.78941924231393, 23.43504227910723, 15.437948840005056, 9.202844738960266, 7.082270162446158, 1.0326353034802844, 0.6431548999888557, 0.6523844961609159, 4.880865454673767, 15.663344928196498, 35.28167050225394, 31.50604370662144, 34.286379269191194, 39.560551847730366, 52.487619740622385, 51.27078866958618, 50.3375517981393, 24.47270015307835, 6.49367002078465, 0.38555727686200825, 0.2900319498564516, 0.08014699577220849, 0.08752611838281155, 0.07755692582577467, 0.06133744865655899, 0.1431201480861221, 0.14959224579589708, 0.13548296503722668, 0.12355482152530126, 0.18785353271024569, 0.1415980311908892, 0.24357328138181142, 0.16926369523363455, 0.13330384982483728, 0.17037638409861497, 0.08800829893776349, 0.16173899972013064, 0.18456202718828404, 0.1408603550600154, 0.08365355618298054, 0.09117424155452422, 0.09757699298539332, 0.17639412118920259, 0.13647343617464813], [0.06778323277831078, 0.032779894436576536, 0.052307579267237864, 0.01882099569775164, 0.007949005513052856, 0.02314545034563967, 0.031928811355360916, 0.05981966760009527, 0.026669045378054892, 0.008939638650710029, 0.02943953439327223, 0.06978001206048898, 0.011136567951845271, 0.046261140145361423, 0.007105534746577697, 0.05299003961096917, 0.07155548714633499, 0.017971719216023172, 0.03206820619691696, 0.004439516375506563, 0.04228885704651475, 0.033793079533747265, 0.005334512970875949, 0.044336577345217974, 0.0695320957207254, 0.9481971029724393, 9.907295669828143, 26.911606448037283, 35.4141274860927, 34.03787694658552, 27.600129502160208, 24.77408000401088, 23.074901512690953, 25.502296379634313, 20.09114180292402, 6.912437515599387, 1.4017744213342667, 0.006145450103628848, 0.09215937262134892, 0.4014983986105238, 0.684770538338593, 3.5263562628201077, 6.402949563094547, 6.640349532876696, 15.91019879068647, 7.824980480330331, 8.110896246773855, 21.07593083381653, 19.48620731489999, 30.820694242204937, 43.77218852724348, 44.54365743909563, 41.70736108507429, 44.92608628954206, 47.50443771907261, 50.93319654464722, 48.97058057785034, 46.16745144980294, 42.851090158735005, 36.67756707327706, 33.7889438356672, 37.599634715488975, 42.952447005680625, 48.60467454365322, 46.248140880039756, 46.91543892451695, 44.02646132877895, 37.49006162370954, 33.77701725278582, 38.94596631186349, 47.26013905661446, 49.34287200655256, 49.40355409894671, 48.94708177021572, 45.279412610190256, 43.99402018955776, 43.65206112180437, 41.056474685668945, 41.00180973325457, 37.677979128701345, 34.8363048689706, 33.93114219393049, 35.24110344478062, 33.84794446400234, 40.73391498838152, 42.24883420126778, 48.35271201814924, 46.056777068546836, 35.77764333997454, 50.98729869297573, 41.498918601444785, 39.296707902635845, 32.28136192049299, 36.36673593521118, 38.817369052342, 45.86802577972412, 46.37913179397583, 48.14771931512015, 45.162161758967805, 49.64063358306885, 49.33247750146048, 46.200059345790315, 47.04591914585659, 48.49282591683524, 46.625869274139404, 45.198785713740754, 38.506211348942344, 35.81205776759556, 32.6057767868042, 33.45392949240548, 34.35728563581194, 41.70019749232701, 43.14704520361764, 50.10994618279593, 46.15429156167166, 47.341141155787874, 45.06358419145857, 46.47706317901611, 44.49596152986799, 48.70677137374878, 46.83082376207624, 52.40208741596767, 47.81577260153634, 49.9486437525068, 39.79921204703194, 32.3586745262146, 21.7913590499333, 31.587396689823695, 20.238030195236206, 16.62086922781808, 18.732046365737915, 12.72192667211805, 5.654949929033007, 13.129434176853724, 15.374489205224172, 5.352490936006818, 3.902781435421535, 0.06789823767862149, 0.34600650199822014, 0.08919918217829295, 3.2504066015992845, 9.547345110348292, 28.053846870149883, 34.129464626312256, 26.19595067841666, 27.05344523702349, 31.64641121455601, 42.80216441835676, 38.971872670309885, 17.20784088543483, 3.2968422813074927, 0.10959365817585162, 0.05203835014253855, 0.12291885779372283, 0.11776002390044076, 0.05028378411329218, 0.04723901428016169, 0.05291273411629455, 0.06502223986067943, 0.011856284108944237, 0.03151476589430656, 0.04409359395503998, 0.035244167383228026, 0.09040573279240302, 0.008922889013774693, 0.009947166462162775, 0.049976468817996125, 0.03537279726671321, 0.026100933452003768, 0.023402202907683592, 0.03802552652944412, 0.03993326844647527, 0.031735388162944994, 0.050635706300714185, 0.024459820174212967, 0.04447329197345035, 0.056482690053858926, 0.056557386581386836, 0.031052005011588335, 0.02336725665788565, 0.03392089856788516, 0.061851072524275096, 0.04196427982034428, 0.01589623835336949, 0.02362021112016269, 0.027695952149640237, 0.013863411898325597, 0.03898354333692363, 0.009408830349067492, 0.05919422794665609, 0.02413362294568547, 0.01752104134564953, 0.035851941377456696, 0.037394417715924125, 0.07259013091347047, 0.022149922425991724, 0.07281822045998913, 0.03472363602902208, 0.041866374002503495, 0.04745370615273714, 0.064205147991223, 1.0759518934147698, 12.733748163495745, 32.49452223096575, 41.34298365456717, 39.58521447862898, 31.223571641104563, 20.555038281849452, 19.71014949253627, 23.51896435873849, 21.329666887010845, 7.922342113086155, 1.543317043355533, 0.06834448301898581, 0.055416351916002374, 0.5874281216944967, 2.1502357849052975, 4.775741381304605, 7.821977121489389, 8.635308061327253, 10.567907810211182, 14.300054516111102, 14.245790822165352, 17.168050289154053, 21.606429270335607, 33.03389004298619, 45.454465525490896, 46.92351967947823, 45.357677119118826, 46.85810933794294, 50.16723755427769, 52.256741523742676, 51.25451946258545, 48.96455996377127, 44.45765263693673, 37.67705501828875, 34.42008692877633, 39.79393489020211, 45.23724399294172, 49.97251428876604, 48.0854287147522, 48.911295073372976, 45.53411272593907, 40.40836409160069, 34.62069879259382, 40.24392454964774, 48.21638488769531, 49.554166725703645, 49.78603853498186, 50.441493374960764, 48.53349372318813, 46.099439007895334, 46.71342699868338, 44.06586108888899, 43.776023932865684, 40.17839956283569, 36.29046903337751, 35.35699244907924, 36.4836984361921, 35.81374617985317, 41.37899964196341, 45.42723553521292, 50.149696826934814, 47.346383571624756, 39.634220123291016, 52.488227707999094, 44.01344040461949, 40.42054080963135, 34.60397447858538, 38.49889489582607, 40.27358293533325, 47.51062856401716, 49.10287080492292, 48.78123869214739, 47.94176776068551, 49.900235652923584, 48.59350184031895, 46.3882235118321, 47.28734820229666, 50.20910392488752, 47.718476976667134, 47.87443624223982, 40.36998571668352, 36.654968057359966, 34.35884550639561, 35.26895877293178, 35.21892826897757, 41.779542446136475, 45.456695897238596, 49.91708156040737, 47.49383476802281, 47.36823913029262, 46.04642077854702, 46.66048867361886, 45.77142150061471, 48.34460694449288, 49.2827388218471, 51.88371706008911, 50.45232909066336, 47.17791754858834, 41.53147438594273, 34.694235052381245, 28.46247911453247, 26.78442488397871, 20.952374492372783, 16.3787088734763, 17.233814988817485, 15.665967873164586, 6.211791591984885, 13.307832649775914, 14.13397433076586, 7.6548416784831455, 3.3258811916623796, 0.7725167327693531, 0.21717817416148527, 0.28703969184841427, 3.181134147303445, 13.289443373680115, 31.66045352390834, 34.032186371939524, 29.548142092568533, 34.393166133335654, 38.988781111580984, 49.90750694274902, 43.92076185771397, 20.849197217396327, 4.180648148059845, 0.20348098129034042, 0.028818864841014147, 0.032437454776040146, 0.04732181930116244, 0.06597390558038439, 0.07040681556931563, 0.033606434906167645, 0.07277432602963277, 0.015920473927898065, 0.03103245302502598, 0.044247044649507315, 0.057316036229687076, 0.0874139836856297, 0.011449020605401268, 0.025055149836199622, 0.04041287396103144, 0.03318867785856128, 0.0037277992981086883, 0.04203422660274165, 0.050715322207127295, 0.048400167508849075, 0.04413238240938101, 0.016253571857565215, 0.043371849826404026, 0.009844877308101525, 0.13387407708380902, 0.2364526263305119, 0.1585684498505933, 0.09620341419109277, 0.08654240545417581, 0.1315374874642917, 0.09174005155052457, 0.1298281220453126, 0.10037047415971756, 0.09484755194612912, 0.08916866845850434, 0.13829338923096657, 0.10187251998909883, 0.21541927568614483, 0.08867387393755571, 0.09217419861150639, 0.11604052116828305, 0.1550228465348482, 0.12912080357117312, 0.08352968282997608, 0.2505418360233307, 0.10310867508607251, 0.149171879781144, 0.16536365236554826, 0.14082097288753304, 2.133979822908129, 16.21454725946699, 39.85401943751744, 49.383557183401926, 45.66677815573556, 37.63587304524013, 34.11817727770124, 33.52310228347778, 33.51266261509487, 27.69192910194397, 9.77391197000231, 1.776088752916881, 0.31829931161233355, 0.33336224619831356, 1.5221050615821565, 2.2895278419767107, 7.183665224484034, 13.319817423820496, 14.21405839920044, 25.81509906905038, 15.187513181141444, 14.917377642222814, 26.524956566946848, 22.35449317523411, 33.38930082321167, 47.9792845589774, 50.157277311597554, 46.68112482343401, 50.981688022613525, 52.42539862224034, 53.75429024015154, 51.24359342030117, 51.483566829136436, 46.613265241895405, 39.92840337753296, 36.451479639325825, 40.51969160352434, 47.174148150852744, 52.871393067496165, 49.01236704417637, 51.590113980429514, 47.149391719273154, 41.409137453351704, 36.58663599831717, 42.75142172404698, 50.49782936913626, 51.58784886768886, 48.96797152927944, 53.54975611822945, 51.07753494807652, 49.231412478855674, 48.77507563999721, 45.15618978227888, 45.41375255584717, 41.705870696476524, 38.36713968004499, 37.64375925064087, 37.895377840314595, 36.741080556597026, 43.187768595559255, 49.04280015400478, 52.765155111040386, 49.07304566247122, 43.005982875823975, 55.489491667066304, 45.9355275290353, 42.87275811604091, 36.14564078194754, 40.51136071341378, 41.68049240112305, 49.89967284883772, 52.589362212589805, 51.73809323992048, 50.48557274682181, 53.10133327756609, 50.94524819510323, 47.26015295301165, 48.434804984501426, 50.00949954986572, 48.080276625497, 50.24571050916399, 42.47141974312918, 39.683423791612896, 36.96548305238996, 36.61293840408325, 37.57012224197388, 45.01970979145595, 47.49745825358799, 53.63458667482649, 46.890741552625386, 47.76014879771641, 45.571136202131, 46.989114148276194, 46.6495487349374, 50.33205229895455, 50.691107409340994, 55.271981784275596, 51.284657273973735, 50.637213706970215, 42.96713202340262, 37.28774050303868, 29.210292884281703, 36.01796415873936, 23.719635282244, 21.82698941230774, 27.07950792993818, 27.679979937417166, 20.838771445410593, 24.80762243270874, 24.57434187616621, 7.797241534505572, 5.924758034093039, 1.1081086993217468, 0.7231309999312673, 0.5935039956654821, 4.2186921409198215, 14.569786190986633, 36.43061419895717, 43.763722147260395, 36.67243235451834, 36.37571995598929, 43.911823000226704, 55.47074542726789, 51.66625234058925, 25.989931379045757, 5.541503216539111, 0.532357242490564, 0.13328764640859195, 0.2143297248653003, 0.1859031245112419, 0.06974894194198505, 0.2532551889973027, 0.14829973158027443, 0.1676951665431261, 0.07400417075093303, 0.12250487000814506, 0.10141275823116302, 0.07632820068725518, 0.14079482214791433, 0.12609313960586274, 0.09158374422362872, 0.11050415717597518, 0.18056038048650536, 0.1383926317627941, 0.10768311390919344, 0.14477391434567316, 0.1313091740012169, 0.1442551336118153, 0.22619984006243093, 0.1854604889771768, 0.1404397447726556], [0.06983599798487765, 0.021986929832824638, 0.03265578020364046, 0.031114301311650445, 0.03814759497929897, 0.04960162571764418, 0.035120100647743256, 0.03218598630545395, 0.03206176011423979, 0.04107896464743784, 0.01605157707152622, 0.018737976938220005, 0.008295226309980665, 0.06598932868135826, 0.03659473026969603, 0.02487071044743061, 0.0168039808049798, 0.041786160985273976, 0.01967912197246083, 0.05223052483052015, 0.01956604071892798, 0.006968658542194004, 0.05301268232454147, 0.043565680139831135, 0.01057892497296312, 0.3957413818155016, 8.882319126810346, 22.167310442243302, 42.24077776500157, 37.63311808449881, 28.415099348340714, 26.200076171330043, 27.73270113127572, 31.94067437308175, 15.580753428595406, 5.827778552259717, 1.1742202660867145, 0.05304218163447721, 0.20276036352983542, 0.8527593069842884, 3.1793115479605536, 4.977769374847412, 11.145096404211861, 5.694546410015651, 9.44655019896371, 15.125012397766113, 9.559951748166766, 11.115267787660871, 21.045143365859985, 31.906006336212158, 40.64829233714512, 45.95029592514038, 46.663420813424246, 48.388130460466655, 51.323132923671174, 50.39045538221087, 46.396234784807476, 46.92040688650948, 42.38834708077567, 41.02425241470337, 36.33653906413487, 32.83721085957119, 36.21337182181222, 41.07923698425293, 43.56735910688128, 44.649607045309885, 41.07765279497419, 35.55381754466465, 34.314036573682515, 41.37545953478132, 47.945592744009836, 48.91111789430891, 48.26428576878139, 46.671199321746826, 42.720609937395366, 41.345689977918354, 39.475818565913606, 37.759502342769075, 35.57043068749564, 32.69140291213989, 33.410100255693706, 34.05345133372715, 36.63496766771589, 37.305541787828716, 41.948936053684776, 44.27641235079084, 48.10532488141741, 45.956799439021516, 34.91421849387032, 49.714121205466135, 43.46713481630598, 39.11341094970703, 32.81695686067854, 34.6659836769104, 35.8074928011213, 40.42084305627005, 42.5570284979684, 45.28428677150181, 45.92388582229614, 47.05284649985177, 47.32957240513393, 48.99696636199951, 47.06331743512835, 44.66814831324986, 48.241631167275564, 49.0504709652492, 44.635568210056846, 42.57777581896101, 43.342008181980674, 41.39638403483799, 37.579554421561106, 42.005206039973665, 47.33027417319161, 47.716819831303184, 45.290825026375906, 44.80467694146292, 45.19381080354963, 48.62892723083496, 46.60343701498849, 47.45503602709089, 45.71243824277605, 48.373758111681255, 49.794237409319194, 51.15744270597185, 43.087943826402935, 34.293327467782156, 34.429835251399446, 24.324142456054688, 22.542575699942454, 20.47786464009966, 11.818917938641139, 11.972319398607526, 2.2773654546056474, 12.474374515669686, 12.59311488696507, 6.836627457823072, 3.5604771290506636, 0.2910540135843413, 0.41175163271171705, 0.24609889728682383, 2.499184306178774, 9.715330839157104, 22.948357445853098, 34.12966612407139, 27.89678978919983, 17.889335836683, 32.67383439200265, 42.39744574683053, 40.74835334505354, 20.85450390407017, 1.9609740206173487, 0.1338113804480859, 0.03646830901769655, 0.030588032943861823, 0.01003950065933168, 0.07198088110557624, 0.03029770477275763, 0.03844617074355483, 0.049371765194726844, 0.06535702225353036, 0.04845585487782955, 0.035511649280254326, 0.02509326484453465, 0.01274766623308616, 0.05040139119539942, 0.04870656678186996, 0.023010593207020844, 0.0313973691580551, 0.06488171525831733, 0.03792078786396554, 0.07249519707901136, 0.02125671080180577, 0.03862552111968398, 0.0412642386342798, 0.022483861739081994, 0.02920145002592887, 0.04499449846999986, 0.046621937570827346, 0.06068417549665485, 0.0383999014406332, 0.017777807478393828, 0.028294640559969202, 0.03923705080524087, 0.029223583838237182, 0.03192832959549768, 0.011846724398700255, 0.03605451461459909, 0.045460550247558525, 0.022208642846505557, 0.025794783540602242, 0.058235491892056804, 0.038272533632282696, 0.023095903718577962, 0.028167802008933256, 0.012939977476240268, 0.01927085593342781, 0.033269504949982674, 0.07629476926688637, 0.02074215903745166, 0.03421225132686751, 0.03218258345233543, 0.7657766544393131, 11.47509675366538, 28.18589391027178, 46.85441984449114, 42.65141977582659, 31.004595688411168, 30.618088245391846, 28.8816465650286, 33.03284086499895, 21.108314650399343, 7.264021141188485, 1.3101877186979567, 0.18817692250013351, 0.2163878030010632, 1.5455330844436372, 3.06335979274341, 7.8278500863483975, 12.48105868271419, 10.789468492780413, 10.540890608515058, 12.679961289678301, 15.434738772256033, 14.806116138185773, 22.9919330733163, 34.95247180121285, 44.92656224114554, 47.66901969909668, 48.22075183050973, 49.28094271251133, 51.519343103681294, 49.87052515574864, 48.53138494491577, 47.8491586957659, 45.986985887799946, 41.74362373352051, 37.934127943856375, 34.713432925088064, 39.061928272247314, 43.737617765154155, 47.6856050491333, 46.37248931612287, 42.45718288421631, 37.657294341496055, 36.40743153435843, 43.89352491923741, 49.44684485026768, 48.70338412693569, 49.196358816964285, 49.306994983128135, 44.76206016540527, 44.253226212092805, 41.949425901685444, 39.537344864436555, 37.00061314446585, 35.29452466964722, 34.23113414219448, 35.29829754148211, 38.046317032405305, 38.90563549314226, 44.4637496812003, 45.87116289138794, 51.24067865099226, 48.30176782608032, 38.17599473680769, 50.78893804550171, 45.30607284818377, 40.42299004963466, 35.51915298189436, 36.91293382644653, 37.11243050439017, 42.33499533789498, 44.689413275037495, 46.721004009246826, 47.51125737598964, 48.456636224474224, 49.85376957484654, 50.321921825408936, 47.2323705809457, 45.65512602669852, 49.256710869925364, 50.45040096555437, 46.61247662135533, 44.098170212336946, 43.28897605623518, 41.40298482349941, 39.31716339928763, 43.9258131980896, 48.42462934766497, 47.409445422036306, 45.458238397325786, 46.04326977048601, 45.333306312561035, 48.56592444011143, 45.946199962071006, 49.54992832456316, 48.10599538258144, 49.78912353515625, 51.554459299360005, 51.94077219281878, 44.63327530452183, 36.97040932519095, 32.77256481988089, 27.496288674218313, 18.05373890059335, 15.505403688975743, 14.56974971294403, 11.426837171827044, 8.85062405041286, 11.906018819127764, 10.320738673210144, 5.189156591892242, 4.709162439618792, 1.1979140575442995, 0.2597706450947693, 0.2851586027869156, 2.6566194125584195, 11.283603531973702, 27.909503255571636, 38.726622104644775, 31.421657834734233, 22.167317390441895, 36.537282943725586, 47.575316292899, 46.4752253804888, 24.3010379586901, 2.992507274661745, 0.015763766265341213, 0.015906949028638855, 0.026924629163529192, 0.019787823282448307, 0.0067799045188751605, 0.038401224583919556, 0.008740843157283962, 0.05085461866110563, 0.03308711134429489, 0.026383673905261924, 0.05569733326722469, 0.05445872526615858, 0.026143280822517614, 0.05011725465634039, 0.049797942861914635, 0.024076841438987424, 0.007011627620418689, 0.03954535676166415, 0.0865774042904377, 0.02746196952648461, 0.03990202869421669, 0.05171632420803819, 0.021950696062828814, 0.016309221907119666, 0.015874046865584593, 0.21115331245320185, 0.15860920266381331, 0.13959766924381256, 0.13658063113689423, 0.07649678271263838, 0.14238705885197434, 0.10097388178110123, 0.09412738201873642, 0.12173547915049962, 0.1669086358909096, 0.09906722552009992, 0.17761396430432796, 0.13398931947137627, 0.11369323105152164, 0.09108592343649694, 0.0817862142409597, 0.08610616171998636, 0.14778260647186212, 0.1522714820291315, 0.13581577289317334, 0.1775108812642949, 0.13557664358190127, 0.1546513486121382, 0.11749992785709244, 0.08095003518142871, 1.1502597289425986, 13.863525254385811, 32.73153918130057, 54.81214305332729, 48.5032308442252, 38.360639640263145, 35.10427256992885, 38.199615137917654, 42.62564543315342, 22.215859242847987, 8.99300045626504, 2.0969761056559424, 0.26587387759770664, 0.635634072124958, 2.4876444339752197, 9.286157982689993, 10.973875420434133, 17.207486527306692, 12.76340741770608, 18.828608955655778, 23.485616479601177, 16.00107949120658, 14.529055850846426, 24.651876824242727, 33.80133594785418, 45.063528605869834, 52.09630414417812, 51.11829655511038, 52.451388359069824, 52.42755603790283, 50.2332558631897, 49.238103594098774, 50.60264294488089, 46.555758476257324, 45.32137972967965, 39.196824073791504, 36.22990158626011, 39.92742715563093, 44.88452563967024, 49.63971989495413, 48.66691998073033, 44.14702647072928, 39.369580609457834, 37.23130028588431, 47.02632522583008, 51.805094718933105, 49.469245842524934, 50.4184844153268, 51.406365394592285, 47.47384132657732, 46.418639251164024, 43.36594125202724, 41.34291417258126, 39.11624581473214, 37.17400891440255, 35.918299198150635, 37.31104128701346, 40.53607545580183, 42.05338832310268, 45.83598068782261, 48.57577003751482, 52.8124098096575, 49.4398375919887, 42.31652355194092, 52.52713762010847, 48.08653000422886, 42.19979728971209, 36.71260683877127, 38.40341969898769, 38.83016416004726, 44.610544272831504, 46.40096303394863, 49.69911657060896, 49.764961174556184, 50.40520640781948, 51.7443014553615, 51.71656772068569, 48.03675658362252, 44.83281714575631, 48.66159418651036, 52.193499020167756, 49.65355028424944, 46.825577872140066, 46.006107330322266, 44.40749706540789, 40.757636138371055, 47.61441033227103, 51.42017493929182, 48.88527059555054, 45.503943647657124, 45.10684714998518, 44.818809577396934, 50.98152126584734, 48.30868475777762, 50.34665741239275, 49.861690521240234, 53.76627240862165, 52.81066581181118, 55.95265163694109, 45.375572204589844, 41.634356362479075, 38.597753865378245, 32.23951986857823, 29.62230716432844, 25.771794421332224, 19.792245932987758, 26.52853488922119, 12.877105133874075, 22.8961695262364, 21.00728610583714, 16.07453237261091, 8.481919629233223, 1.2457293889352252, 1.2073125817946024, 0.7693977515612329, 3.2166337966918945, 13.128127915518624, 30.54745285851615, 43.89415373120989, 37.81478221075875, 25.830268723624094, 42.97889879771641, 54.14740194593157, 52.39002881731306, 30.316192490713938, 4.119097096579416, 0.18717339634895325, 0.07877041106777531, 0.17552342505327292, 0.12765258949782166, 0.1008323733029621, 0.1115720152322735, 0.15256809682718345, 0.16879831520574434, 0.16945553065410682, 0.1507435433034386, 0.12775094993412495, 0.14146000359739574, 0.09305919826562915, 0.16927172908825533, 0.1240002933357443, 0.08118147669093949, 0.08169147039630584, 0.15571183099278382, 0.2130171667252268, 0.22019268811813422, 0.1492673767996686, 0.08357452042400837, 0.10137115724916969, 0.11011259497276374, 0.10341802598642451], [0.07494449815047638, 0.05345230855579887, 0.02103824627452663, 0.05951656600726502, 0.03780480587322797, 0.012214747373946011, 0.06999620688813073, 0.03824429639748164, 0.04411907973034041, 0.020288354816979597, 0.022271412424743176, 0.007283885979891888, 0.045655276227210245, 0.035661646231476746, 0.05283464152099831, 0.02380718822990145, 0.008175268952202584, 0.036177210709346194, 0.029027633102876798, 0.024073601434273378, 0.053278956429234574, 0.010169793801781322, 0.04328803378822548, 0.05940453987568617, 0.031305044290742705, 0.19994707591831684, 6.223744664873395, 23.04677173069545, 38.90060499736241, 35.502248014722554, 28.83971244948251, 16.576433760779246, 17.630763837269374, 22.12448522022792, 18.146235057285853, 6.806292925562177, 1.0810423174074717, 0.02646919815534992, 0.11908679056380476, 0.9038310093539101, 2.685956661190305, 6.952279354844775, 7.508615970611572, 11.98932250908443, 5.2838857259069165, 13.318192413875035, 27.178113290241786, 19.289727892194474, 19.791311400277273, 32.78670787811279, 41.44796051297869, 44.76909521647862, 49.20958123888288, 49.24208491189139, 50.19356427873884, 47.34037337984358, 46.801658698490684, 46.49800852366856, 46.449881826128276, 44.03867278780256, 42.22851766858782, 39.93569203785488, 35.55483545575823, 35.923333168029785, 36.26358992712838, 36.78527109963553, 38.50631904602051, 34.39961406162807, 38.99110875810896, 45.63573013033186, 48.5357414654323, 48.27138335364205, 49.12167610440935, 44.74222305842808, 42.351858615875244, 37.581044810158865, 34.91043867383684, 34.28951985495431, 32.79756791251046, 32.35210500444685, 33.823879378182546, 35.10245214189802, 40.403430870601106, 42.2041677066258, 46.93781212397984, 45.783775397709434, 49.719693660736084, 43.18172018868582, 35.38448994500296, 50.3227139200483, 41.64576530456543, 40.23939085006714, 33.61734070096697, 35.0461300441197, 33.13292619160244, 35.356651987348286, 37.296074867248535, 41.95516858782087, 41.39897223881313, 44.340342726026265, 43.45003529957363, 47.09028686795916, 49.60316889626639, 47.752384185791016, 44.0136627469744, 46.83663593019758, 46.91503940309797, 46.28533806119646, 47.70294080461775, 46.08596992492676, 41.12105819157192, 44.0783747945513, 48.60363231386457, 47.44591304234096, 44.85777507509504, 45.32630252838135, 46.75875357219151, 48.787023067474365, 46.32095800127302, 44.25482429776873, 44.26910979407174, 44.98852627617972, 47.026221002851216, 46.493905612400596, 47.55593776702881, 38.32990428379604, 35.555009160723, 35.73475905827114, 23.6572265625, 18.998146738324845, 20.924444471086773, 7.660193528447833, 3.555562364203589, 9.084695833069937, 8.511493768010821, 3.399868432964597, 1.5964766251189368, 1.5203686633280344, 0.1974264404603413, 0.34674233251384323, 1.9022884496620722, 10.155295116560799, 24.01873438698905, 29.046397038868495, 31.801748616354807, 35.549652099609375, 38.01492854527065, 46.579528263636995, 36.400198459625244, 16.85223208154951, 1.493024570601327, 0.14215387350746564, 0.024659509637526104, 0.03705740972821202, 0.008890725605721985, 0.017106251192412207, 0.03863842346306358, 0.02892311496127929, 0.04713757668754884, 0.018031847596700703, 0.03575130784884095, 0.051613644896341224, 0.02912222088447639, 0.01497556472064129, 0.02075210296814995, 0.053082523934010944, 0.05889915342309645, 0.025456157246870652, 0.008674909909521895, 0.015218892467341252, 0.059480820782482624, 0.02856700960546732, 0.018483069991426807, 0.009350982694221395, 0.011202130549853402, 0.09330242592841387, 0.0931844829714724, 0.00897680879903159, 0.06808184925466776, 0.07405613974801131, 0.06077526203755822, 0.02752213692292571, 0.04399420214550836, 0.06490855131830488, 0.05318720492401293, 0.03888166130387357, 0.018561898797218288, 0.017414290823840668, 0.028549160741801773, 0.012640618004037865, 0.07105246878096036, 0.045359139796346426, 0.01662824023514986, 0.014672033954411745, 0.053304883252297125, 0.03656339552253485, 0.08287170063704252, 0.05663594397317086, 0.02794412463637335, 0.10723374052239315, 0.09738054352679423, 0.5043401515909604, 7.634295855249677, 26.70889275414603, 46.1468048776899, 39.206454277038574, 32.80010053089687, 21.950858422688075, 23.67803989137922, 31.329840864453995, 18.01459969793047, 8.127430353845869, 1.0686888545751572, 0.03453012801972883, 0.15394321589597634, 1.109850851552827, 3.673995929104941, 8.202429209436689, 9.660498261451721, 10.46790325641632, 9.314294712884085, 9.04824732031141, 17.626591444015503, 18.54876330920628, 22.988340854644775, 29.773697989327566, 43.7781639780317, 47.084700516292024, 49.99801417759487, 49.86289255959647, 52.22076722553798, 48.17964628764561, 47.95573016575405, 47.53501326697213, 46.90302249363491, 44.270429951804026, 44.28919356209891, 40.492305278778076, 36.86986889157976, 37.285089765276226, 38.410378319876536, 38.80758598872593, 39.589095047542024, 35.476998261043, 40.10095494134085, 46.82492126737322, 50.84387397766113, 47.9501507622855, 50.4864239011492, 47.92097527640206, 44.02383490971157, 39.63071475710188, 37.213940211704795, 35.629545961107524, 36.14256967817034, 34.05190188544137, 35.84738935743059, 35.954589639391216, 41.587066922869, 44.680734974997385, 48.71808304105486, 46.82107891355242, 52.07713406426566, 45.06169775554112, 38.18173394884382, 52.23737342017037, 43.787224428994314, 41.85263402121407, 35.520806653159006, 35.60651963097708, 34.42409256526402, 38.468430519104004, 40.43085193634033, 43.573984214237754, 44.88779476710728, 45.86105326243809, 45.511333056858604, 49.125424657549175, 48.68745190756661, 47.88157204219273, 43.53214911052159, 47.83825349807739, 49.128374167851035, 48.926438672201975, 48.74488571711949, 47.90731859207153, 43.18343639373779, 46.14598846435547, 50.290081705365864, 47.34488276072911, 44.98145648411342, 46.771989890507285, 47.30679621015276, 50.020185879298616, 47.843770367758616, 47.33809437070574, 45.238206318446565, 47.417779786246165, 46.37494897842407, 49.15382194519043, 47.725070817129954, 42.00181531906128, 34.68541431427002, 23.450878960745676, 15.408775091171265, 15.840030670166016, 14.776263202939715, 15.601631028311592, 10.866956540516444, 11.310116120747157, 13.562760319028582, 6.38086427961077, 3.9465841821261813, 0.9298489732401711, 0.15989745567951882, 0.38236077981335775, 2.6797777584620883, 10.94796906198774, 24.937849044799805, 33.49259969166347, 34.07413959503174, 31.495788165501185, 41.21444198063442, 49.825493880680625, 43.855921268463135, 20.85784251349313, 2.3069022468158176, 0.1472199788050992, 0.07321320926504475, 0.07094981321798903, 0.01944133616052568, 0.03857713818017926, 0.0367137283485915, 0.031158222883407558, 0.10014551265963487, 0.03315205053825464, 0.07205493641751153, 0.06170556068952594, 0.028430045615615587, 0.01810409970182393, 0.03769619616546801, 0.025288216437080076, 0.03857835615053773, 0.02942171267100743, 0.0016506594173344119, 0.016245549877307246, 0.014915963900940759, 0.04218092926644853, 0.010622462324265922, 0.06116263089435441, 0.048157492852104564, 0.049369746553046365, 0.23305012605019979, 0.178718307188579, 0.08402616011777095, 0.19238241469221457, 0.10224910692444869, 0.16059893875249795, 0.1866362001746893, 0.22170438271548065, 0.14442213465060505, 0.12865591208849633, 0.07295695372990199, 0.1316972960318838, 0.11308354019586529, 0.10803675279021263, 0.1735308798296111, 0.11610815753894192, 0.10490701001669679, 0.16598463404391492, 0.14616896877331392, 0.1292746410306011, 0.16976544473852428, 0.13137621326105936, 0.10049187085990395, 0.24680082819291524, 0.14777500687965325, 0.7227107967649187, 9.532456857817513, 32.647928033556255, 52.27650567463466, 46.02866465704781, 39.46912745067051, 25.386673143931798, 26.55901837348938, 32.47731154305594, 24.531137977327617, 10.137231537273951, 1.5409760432583945, 0.4787039043647902, 0.28631026670336723, 2.5794915854930878, 4.238299088818686, 18.09872327532087, 15.72969675064087, 21.47717888014657, 15.347601413726807, 24.710922615868704, 36.66552931921822, 24.528176307678223, 22.15509377207075, 34.77342367172241, 45.770066601889475, 49.520603452410015, 53.67379535947527, 51.73065866742815, 51.67378766196114, 49.566190583365305, 47.647723470415386, 49.891234261649, 50.18450730187552, 46.99038566861834, 46.461481843675884, 43.562332085200715, 38.74624729156494, 39.34648479734148, 39.625764165605815, 40.66384587969099, 41.79596103940691, 37.49034649985177, 42.37523235593523, 50.28692374910627, 52.0341386113848, 47.32303067616054, 52.441792896815706, 48.96724544252668, 46.782836028507774, 42.219905376434326, 38.58299241747175, 37.69760431562151, 37.08792073386056, 35.345392431531636, 38.07933834620884, 39.09005805424282, 44.24158797945295, 47.39885984148298, 51.91800989423479, 49.39567484174456, 53.03983129773821, 45.46624272210257, 41.448384353092735, 52.92722531727382, 45.45892626898629, 43.55777754102434, 37.63325704847063, 37.47546345846993, 36.647738456726074, 40.33669689723423, 42.97834294182913, 45.73849746159145, 45.613311767578125, 48.380181721278596, 46.90131671088082, 50.683443546295166, 51.774359362465994, 49.4216228893825, 43.37494611740112, 48.05468988418579, 50.982563495635986, 49.27378954206194, 50.35854230608259, 49.72127437591553, 44.737640721457346, 48.392587729862754, 52.656071867261616, 47.096554143088206, 44.43565116609846, 45.59864412035261, 49.25188882010323, 52.041743414742605, 49.76144191196987, 49.236304010663716, 48.76288502556937, 48.208557741982595, 50.817720958164756, 50.00400352478027, 51.09210532052176, 44.453688689640586, 38.61371735164097, 39.241723333086284, 32.38678693771362, 24.274900572640554, 29.573780945369176, 18.174418687820435, 11.009083679744176, 21.163613625935145, 19.66042992046901, 12.522496002061025, 5.441387057304382, 3.9525683181626454, 0.6731169436659131, 0.6804174376385552, 2.9138228339808325, 13.673636198043823, 31.36739240373884, 40.37251833506993, 43.98193727220808, 45.510964802333284, 49.4358354296003, 56.90819569996425, 50.10296671731131, 23.47424748965672, 4.060353985854557, 0.30385245968188557, 0.11559116813753333, 0.12073184443371636, 0.12033134592430932, 0.09160537592002324, 0.08966121024319104, 0.14684024346726282, 0.18850127580974782, 0.07133431187165634, 0.12289550261838095, 0.1501945677612509, 0.09220902102866343, 0.10415203124284744, 0.11155896021851472, 0.23037802800536156, 0.12812472773449762, 0.11721123834805829, 0.0958946943283081, 0.08514248593045132, 0.137610009472285, 0.18338643812707492, 0.09030866835798536, 0.17783581811402524, 0.075288983594094, 0.2229477031422513], [0.025125949876382947, 0.017768910187961798, 0.01586961094290018, 0.03454615501686931, 0.04749357347775783, 0.08468523475208453, 0.0412972697189876, 0.04631485637011273, 0.02539795420930854, 0.01866218288029943, 0.029421709278332334, 0.010133982419834604, 0.01201247947756201, 0.033676995762756894, 0.015637942124158144, 0.021297833416610956, 0.00027058394178831283, 0.03452286769502929, 0.02340308839588293, 0.07870757872504847, 0.07384054203118597, 0.01921333821623453, 0.02183622890152037, 0.013305709547629314, 0.05762048132185425, 0.17254779115319252, 5.264306136540004, 22.85565284320286, 39.61502572468349, 42.34255845206124, 32.16807154246739, 20.579306602478027, 19.204214675085886, 20.951829058783396, 16.908809525626047, 6.618873085294451, 1.0597608536481857, 0.19778006577066012, 0.19754044791417463, 1.114587894507817, 2.512538309608187, 6.085881548268454, 10.793222257069178, 9.266284397670201, 9.944515432630267, 5.682671938623701, 9.919729471206665, 14.78140139579773, 24.668917281287058, 28.795860631125315, 39.02597829273769, 44.81341430119106, 49.28637620380947, 47.55436052594866, 47.16306924819946, 49.157428060259136, 46.81319618225098, 46.90178224018642, 47.112330027988975, 49.295447077069966, 47.07615770612444, 44.32348987034389, 44.46789428165981, 40.77176530020577, 39.48452465874808, 40.48116731643677, 38.758469172886436, 43.18392971583775, 44.244436740875244, 47.152445452553884, 49.494380950927734, 47.11945193154471, 49.42996072769165, 43.48315041405814, 41.412232875823975, 37.3114720753261, 33.885061740875244, 33.00708041872297, 32.904969692230225, 31.53834240777152, 32.977241379874094, 34.297416482652935, 41.211145060403005, 42.752793993268696, 46.35040099280221, 48.35477563313076, 49.368830476488384, 43.6871668951852, 34.864229679107666, 49.00738518578665, 43.726556232997346, 39.30266598292759, 33.923349789210725, 35.18071665082659, 32.90661294119698, 34.13224390574864, 33.9537273134504, 36.10128695624215, 38.93702745437622, 42.250619888305664, 43.03610679081508, 43.03100333895002, 45.95558697836739, 48.37528324127197, 44.74726397650582, 46.74074036734444, 48.24653312138149, 47.31315728596279, 46.76177256447928, 48.825912134987966, 45.59916523524693, 46.95942449569702, 48.43496131896973, 46.64444875717163, 45.38143648420061, 48.04172107151577, 48.35977486201695, 45.586540358407156, 42.05210638046265, 40.31393807274954, 40.298308100019185, 44.36524159567696, 45.1146673474993, 49.247681685856406, 46.19521992547171, 45.1607860156468, 35.88955797467913, 28.66264455659049, 17.58153932435172, 16.333161694662913, 11.144869719232831, 12.821463091032845, 14.135354416710989, 8.118664332798549, 9.54199412890843, 4.976290277072361, 5.740814898695264, 1.1923869826963969, 0.15790249487119062, 0.1206566763243505, 2.248472673552377, 9.784276945250374, 26.080978836332047, 32.6972393989563, 31.696869032723562, 37.29048156738281, 44.328704493386404, 47.61585555757795, 37.40999753134591, 16.15463468006679, 3.206501368965421, 0.287068353167602, 0.03767302758725626, 0.04930455630112972, 0.017217541113495827, 0.01867589946570141, 0.008788852054359657, 0.04544005170464516, 0.018155831211645688, 0.02016968073855553, 0.0162048581322389, 0.12073059592928205, 0.022509255912154913, 0.006927583848924509, 0.015549198225406664, 0.004349262312254203, 0.04245465707832149, 0.0294108832521098, 0.03636806903939162, 0.028598860039242675, 0.02610013447701931, 0.03046039372150387, 0.03437876721311893, 0.060653580352663994, 0.005224338391729231, 0.04845411104283162, 0.01730921119451523, 0.031819842024041076, 0.03035044390708208, 0.07587687990495137, 0.006091760596193905, 0.01611076737754047, 0.05686337873339653, 0.0621072059231145, 0.014871192464072789, 0.03778251260519028, 0.037079289089888334, 0.0074771666799538904, 0.055925728154501746, 0.05437552330217191, 0.01853641132558031, 0.05415192905015179, 0.032283936228070936, 0.07330095062830619, 0.03751016900475536, 0.03494313871487975, 0.03991885297000408, 0.039741921571216414, 0.04548577478687678, 0.041963747170354636, 0.02474434856724526, 0.2172488910811288, 7.4915390355246405, 27.68860786301749, 44.32845088413784, 46.01663385118757, 36.113581793648855, 20.50936082431248, 20.294107369014196, 26.347892148154124, 22.015784127371653, 7.909540057182312, 1.3773035172905241, 0.20498314925602504, 0.07790481072983571, 1.3072866286550249, 4.723214302744184, 5.624168540750231, 11.727925198418752, 11.474857909338814, 11.826904892921448, 7.973673667226519, 18.860671418053762, 18.551021473748342, 22.32790415627616, 32.112930638449534, 42.84760563714163, 47.29911150251116, 49.49377645765032, 49.44401345934187, 48.021206515175955, 48.790118489946636, 46.10041870389666, 47.04264654432024, 48.88869605745588, 51.35619592666626, 47.09568909236363, 46.48340688432966, 45.61767871039254, 42.85872275488717, 40.924125398908345, 41.50602660860334, 39.843378271375386, 43.49839128766741, 47.3976161139352, 48.92904077257429, 50.30345351355416, 47.97811378751482, 51.46872547694615, 45.076789242880686, 43.37115934916905, 39.5645991734096, 36.834669317517964, 35.73542261123657, 34.168225152151926, 33.26905877249581, 34.05961785997663, 36.652240889413015, 42.281584535326274, 45.41812992095947, 48.45647989000593, 50.32167169025966, 50.301768575395855, 45.550875255039756, 37.50209937776838, 50.310231481279644, 44.818785258701865, 42.25385774884905, 36.13303674970354, 36.880450998033794, 35.1372834614345, 35.303810937064036, 35.54360369273594, 38.93202127729143, 41.39967400687081, 44.499241079602925, 45.27547645568848, 45.35836499077933, 48.02667474746704, 50.55486018317086, 45.65813112258911, 47.18323292051043, 47.33558259691511, 48.91295569283621, 47.613062381744385, 50.883013180324006, 47.520870208740234, 49.75901351656233, 48.993582589285715, 47.02414696557181, 46.45397431509835, 47.62367575509207, 49.64683485031128, 47.78430073601859, 44.172001770564485, 43.34015301295689, 42.48223808833531, 46.36899784633091, 47.6485572542463, 49.24616697856358, 46.79782329286848, 45.259988921029226, 36.512304169791086, 25.16551545688084, 17.2727335861751, 17.838806799479894, 13.632092918668475, 10.425900527409144, 16.637515374592372, 13.131526453154427, 9.41312415259225, 5.648398646286555, 4.997084064143045, 1.102796258670943, 0.09863078501075506, 0.16642705244677408, 2.5238291323184967, 11.17535754612514, 29.771978310176305, 36.43359497615269, 35.28487362180437, 42.62181350163051, 48.46935142789568, 53.910920006888254, 43.346392495291575, 19.9631472996303, 3.86966849224908, 0.30629228161914007, 0.02363912358746997, 0.06291300696986062, 0.03613691929993885, 0.02056506648659706, 0.03890711993777326, 0.024364976245643835, 0.019943041560639228, 0.016762356074260812, 0.07533525968236582, 0.06214905117771455, 0.013067926280200481, 0.023768187733367085, 0.01797690661624074, 0.004345134698918888, 0.04022610719714846, 0.03986828175506421, 0.042445507033595016, 0.03444577254621046, 0.03260131419769355, 0.022574770164542964, 0.03438070782327226, 0.048145330111895285, 0.013854774995706975, 0.01916201043474887, 0.11722782174391405, 0.14709518264446939, 0.11732679286173411, 0.15159234989966663, 0.1075516070372292, 0.19634915755263396, 0.11279841299567904, 0.12287524156272411, 0.11765219111527715, 0.0742535459409867, 0.10820847643273217, 0.138131816472326, 0.12821084739906446, 0.09940044049705778, 0.08316718228161335, 0.19212492422333785, 0.11131052140678678, 0.2333910491849695, 0.09830229942287717, 0.2040786485054663, 0.12836990957813604, 0.1401603240519762, 0.13751369821173803, 0.1318817897034543, 0.1954766158014536, 0.3965928346983024, 9.182829584394183, 33.46582480839321, 51.09901877811977, 54.00171559197562, 42.248611858912874, 28.246932097843715, 27.73466052327837, 31.20789303098406, 24.141012259892054, 8.92217138835362, 1.8898294610636575, 0.5952105926615852, 0.3024295988891806, 2.6484140242849077, 6.936571214880262, 10.446341259138924, 20.603310891560145, 17.660606350217545, 17.742536033902848, 14.009057010923113, 16.868560348238262, 19.186990090778895, 29.909570012773784, 32.763400145939414, 44.23438964571272, 48.4508171081543, 53.864801338740754, 49.43488700049264, 48.86248745237078, 48.94921834128243, 46.108263220105854, 46.37228087016514, 51.120881284986226, 55.04638072422573, 49.73132494517735, 49.66456665311541, 47.69361979620797, 44.86774574007307, 44.61084304537092, 45.78322649002075, 42.6042936188834, 47.16514328547886, 49.76529468808855, 51.27350541523525, 50.026592118399485, 47.02821513584682, 52.74956335340227, 48.605570861271445, 45.97369745799473, 40.924896648951936, 38.51914194652012, 37.05085209437779, 36.22063616343907, 34.72820132119315, 36.25599207196917, 37.95284639086042, 45.707588400159565, 47.07457004274641, 49.979865482875276, 52.26067073004586, 51.56089333125523, 47.705615861075266, 40.826332977839876, 51.710759026663645, 46.9044885635376, 44.93505293982369, 37.82322079794747, 39.490816252572195, 36.494311809539795, 38.65127236502511, 37.59737307684762, 41.635436807359966, 43.60176658630371, 47.56961529595511, 47.57068531853812, 47.28500665937151, 50.92435148784092, 52.296297618321006, 45.859521184648784, 47.47798245293753, 48.703415393829346, 49.22991166796003, 47.99787099020821, 52.19232130050659, 49.986501012529644, 52.45537315096174, 50.10356078829084, 46.48772866385323, 46.883098534175325, 49.695513929639546, 51.200928006853374, 49.28631019592285, 46.25223684310913, 45.18965925489153, 45.43052550724575, 49.49989434650966, 50.221204212733674, 53.90300948279244, 49.206193992069785, 48.29189790998186, 40.707824502672466, 31.162347589220317, 20.63413483755929, 20.03283599444798, 16.424285582133702, 24.73827246257237, 27.342021295002528, 16.60018617766244, 19.091500997543335, 9.130183952195303, 12.250437549182347, 2.8744882132325853, 0.5792101940938404, 0.33401705963271006, 3.0416366841111864, 12.599558472633362, 32.881516047886436, 41.92918579918997, 43.53150292805263, 48.370697430201936, 54.56474896839687, 58.88111237117222, 50.616066864558626, 25.2224611554827, 5.510214175496783, 0.40965791791677475, 0.13023099542728492, 0.1804832039134843, 0.1378574576228857, 0.0823575814387628, 0.1457057600574834, 0.12107694734420095, 0.18751517443784646, 0.10029858337449175, 0.2598823048174381, 0.15728657506406307, 0.08299358588244234, 0.12248927727341652, 0.09830771413232599, 0.09371773685727801, 0.10759404940264565, 0.12848861249429838, 0.13597608357667923, 0.141546828938382, 0.09771709689604384, 0.13359548417585237, 0.10399235159690891, 0.17377382250768797, 0.15734768392784254, 0.11869851925543376], [0.042874039217297516, 0.04254445101001433, 0.02829485260216253, 0.031060652940401008, 0.030926313184733902, 0.04512835646580372, 0.029093281365931034, 0.08012812571333987, 0.056332950945943594, 0.018693900999746153, 0.011995255714282393, 0.04807135961683733, 0.10343194952500717, 0.017124603868329098, 0.06765697776739087, 0.021041757693248134, 0.037033328520400186, 0.015005206522930945, 0.027342686462881308, 0.04261460813826748, 0.038721890055707524, 0.0613997449566211, 0.051773765590041876, 0.017885000744302357, 0.005236573650368622, 0.3775310761162213, 3.87336927652359, 20.176250287464686, 41.92921011788504, 37.38857970918928, 31.42781046458653, 22.740627152579172, 16.220375061035156, 25.552811520440237, 19.015084709439957, 8.087682315281459, 1.3450983996902193, 0.20913978692676338, 0.050482381135225296, 1.3226137033530643, 6.830661126545497, 4.939190370695932, 8.973198958805629, 7.737657257488795, 7.958280801773071, 4.356600855078016, 23.711769921439036, 19.869572435106548, 19.889390434537614, 26.442486660821096, 35.82041992459978, 42.6892214502607, 45.595552171979634, 48.529835496629985, 46.451184613364084, 47.209076745169504, 47.92284434182303, 46.30843039921352, 43.6247547013419, 44.35440240587507, 50.17023222787039, 48.09118529728481, 49.873749119894846, 46.647505964551655, 48.139433588300435, 48.415707860674175, 46.396620409829275, 45.73983498982021, 51.014719758714946, 46.17088038580758, 48.230003356933594, 48.73231642586844, 47.96578073501587, 44.700471333095, 43.41036803381783, 35.375078610011506, 31.735556602478027, 33.2280261857169, 33.153315680367605, 32.09500428608486, 32.538841315678184, 33.055832454136436, 37.67977523803711, 41.621595995766775, 45.248652935028076, 46.856945514678955, 48.4207626751491, 43.421974999564036, 33.380334172930034, 47.427194595336914, 40.81248869214739, 41.233559949057444, 36.68532821110317, 34.58353287833077, 34.265534673418315, 34.2279622895377, 34.61870813369751, 34.378342151641846, 33.508250508989605, 36.713801928928916, 40.04343775340489, 43.15247869491577, 42.042097500392366, 45.15305961881365, 47.05011238370623, 45.649463244846885, 45.54334340776716, 46.42452784946987, 45.17344215938023, 48.488837650844026, 46.1348991394043, 48.469611985342844, 48.70912333897182, 46.970180307115825, 45.56111689976284, 48.6163718359811, 44.647755350385395, 41.857251099177766, 39.038835934230256, 39.10111958639962, 38.70234857286726, 41.98263481685093, 42.58700997488839, 47.54601921354021, 46.910575185503276, 46.604663372039795, 35.765094893319265, 22.71688689504351, 15.226254599434988, 22.589849506105693, 23.72380072729928, 11.506881288119725, 10.187348893710546, 10.011921644210815, 8.317155258996145, 4.1532149229730875, 2.65212653364454, 0.16871553393346922, 0.08355933481029101, 0.34246316498943735, 2.0697207110268727, 10.701899477413722, 22.144002710069927, 32.358122144426616, 35.22857584272112, 34.85509974615914, 40.033908299037385, 45.86839403424944, 37.87541913986206, 15.39269174848284, 2.3612050243786404, 0.4127706566027233, 0.05476252914273313, 0.027310997181172882, 0.038638196153832335, 0.03765687845381243, 0.043023201570447, 0.03096106435571398, 0.07310383620538882, 0.02025364096542554, 0.01818223131288375, 0.05054597343717303, 0.02949545924950923, 0.018653651998777474, 0.05277979214276586, 0.036897316175912104, 0.05590328900143504, 0.05600563583097287, 0.023029176584844078, 0.005819267293970499, 0.01468691592370825, 0.03132705596674766, 0.029282972615744387, 0.019796886813959906, 0.015957314986735582, 0.013796955330430396, 0.015238020369516951, 0.042330793903342316, 0.012280224306908036, 0.046161599058125696, 0.032679732489798746, 0.04737195964636547, 0.020905962479966025, 0.12732462638190814, 0.024342421741623963, 0.031065599460686957, 0.0010503654235175677, 0.031990340910851955, 0.07759273211870875, 0.040270188224634955, 0.12398692619587694, 0.0361154063471726, 0.05724533288074391, 0.04913966889892306, 0.02533082165090101, 0.03195499262905546, 0.03300193823607905, 0.017137131321110895, 0.05341139628684946, 0.03732376864978245, 0.0705804391098874, 0.49775461639676777, 4.592589037758963, 23.575991698673793, 48.30780233655657, 41.781515734536306, 35.42013420377459, 24.745370047433035, 21.078647579465592, 28.199218818119594, 20.51920815876552, 9.884887729372297, 1.62164397750582, 0.22865099353449686, 0.046274873694138866, 0.7984366619161197, 3.6665596195629666, 3.518378862312862, 6.998866157872336, 11.271087220736913, 10.392517907278878, 10.132530212402344, 13.948747515678406, 12.023604920932225, 17.073559999465942, 29.509614331381663, 38.848472663334434, 44.85971014840262, 49.02890028272356, 49.75707496915545, 47.40194484165737, 47.03050456728254, 48.767505577632356, 46.551075390407014, 44.23035274233137, 47.04258748463222, 50.70166172300066, 49.37427091598511, 49.73045642035348, 47.66149132592337, 49.411638328007285, 49.17461790357317, 48.30549553462437, 47.198908056531636, 53.50324487686157, 47.992368016924175, 47.1467409815107, 49.57872860772269, 49.77062395640782, 47.329026971544536, 44.215865748269216, 36.93459483555385, 33.31443745749337, 33.15453161512102, 34.63855913707188, 33.40222794669015, 33.86566237040928, 35.914818150656565, 41.009164401463096, 44.29369599478585, 47.434580530439106, 49.093560218811035, 48.81602484839303, 45.609462465558735, 37.184219292231965, 49.75807203565325, 43.71104090554373, 43.310675280434744, 37.27755444390433, 36.80779715946743, 34.58242116655622, 35.56757150377546, 35.74352421079363, 35.3310478755406, 36.197335379464285, 39.28379814965384, 42.36882611683437, 45.12203243800572, 44.49561411993844, 47.78975854601179, 48.76976721627371, 46.71522658211844, 46.20677477972848, 46.756735120500835, 47.01945693152291, 47.56110027858189, 47.33672210148403, 50.99645641871861, 47.022274426051546, 47.02691234861101, 46.07506125313895, 50.729687282017295, 47.21086590630667, 44.87313754217965, 41.678800514766145, 41.13106707164219, 41.1769495010376, 43.789051805223735, 44.24459307534354, 49.04775421960013, 48.710387911115376, 47.18237829208374, 37.26122270311628, 24.929464306150162, 19.76460599899292, 16.23934190613883, 11.30867610658918, 13.052885004452296, 12.523502622331891, 11.783917256764003, 8.987315961292811, 8.252173968723842, 3.6251120950494493, 0.8720691108277866, 0.16929948117051805, 0.289337618542569, 2.3286327379090443, 12.227786421775818, 26.439346075057983, 35.12418610709054, 38.803781849997385, 41.464396476745605, 45.16160937717983, 51.28034939084734, 42.920068400246755, 19.64318970271519, 3.348703635590417, 0.3258679626243455, 0.012499544636479445, 0.03267782919907144, 0.021280664784301604, 0.01604269165545702, 0.022070701766226972, 0.015050960139238408, 0.0786405937480075, 0.03242024373529213, 0.059912572614848614, 0.03889499790966511, 0.05968098182763372, 0.017250329621934464, 0.04262877255678177, 0.052429298271558115, 0.051396411910120926, 0.01910563774539956, 0.06890464081828084, 0.039002488034644296, 0.06347642173724515, 0.0319627550696688, 0.016225823167977587, 0.03343771378110562, 0.04004688574267285, 0.06793552317789622, 0.14182251771645887, 0.09685205295681953, 0.10494804781462465, 0.1475915852934122, 0.11378455507968153, 0.08608260976948909, 0.12141678482294083, 0.23401223442384175, 0.11593138559588365, 0.17670911071555956, 0.07816600599991423, 0.27787143524203983, 0.15565159065382822, 0.11210147610732488, 0.23133155969636782, 0.14552099497190543, 0.18459881735699518, 0.09298957378736564, 0.16131198406219482, 0.1413846726396254, 0.1570754556783608, 0.13118238294763224, 0.1773483314152275, 0.18166576831468514, 0.1171093223882573, 0.6841391750744411, 6.898287074906485, 28.930153676441737, 55.50601100921631, 48.308997426714214, 41.020451750074116, 32.03495795386178, 24.5513277053833, 35.58509486062186, 26.51773738861084, 11.38901378427233, 1.8663252251488822, 0.5476794317364693, 0.5473306104540825, 2.702125770705087, 10.336446813174657, 11.669481294495718, 16.533321925571986, 15.974462679454259, 17.15401840209961, 13.166597485542297, 30.36800868170602, 27.160522188459122, 23.398590292249406, 28.557304654802593, 39.64571591785976, 46.046219280787874, 47.38626275743757, 49.96459681647164, 48.1001866885594, 47.076470375061035, 48.906507764543804, 46.609971795763286, 44.892679350716726, 47.342016628810335, 51.18355403627668, 49.58523906980242, 51.06253031321934, 48.22632775987898, 50.54217972074236, 52.57525389535086, 50.608778204236714, 48.80475834437779, 53.96566833768572, 47.428386211395264, 47.29080145699637, 49.8775497845241, 51.316667624882285, 48.4372889654977, 46.7008090700422, 39.726453985486714, 34.25463989802769, 35.17499828338623, 36.823649474552695, 34.9243871825082, 35.784011363983154, 37.57877622331892, 42.33556509017944, 46.02461733136858, 48.61729942049299, 49.57716873713902, 49.609109606061665, 47.17654527936663, 42.18221139907837, 50.508602551051546, 45.90005350112915, 45.86147710255214, 40.039560658591135, 38.17619970866612, 36.94941186904907, 36.729914801461355, 38.35180500575474, 37.72640807288033, 37.16087334496634, 39.62898118155343, 43.848497118268696, 48.376269885471885, 46.882000718797954, 49.548097474234446, 49.56487389973232, 47.27372278485979, 47.44075400488717, 48.32106644766671, 47.22836147035871, 50.82905347006661, 47.88984039851597, 52.21535805293492, 47.89906413214547, 46.79722227369036, 46.33587230954851, 51.87641797746931, 48.88436385563442, 46.081971236637656, 42.31729480198452, 45.043764454977854, 43.29950257710048, 47.35386678150722, 46.594355719430105, 51.47536448069981, 49.83443968636649, 51.13084152766636, 40.003218105861116, 27.398501464298793, 19.67702395575387, 27.93279014314924, 32.16757822036743, 21.13890756879534, 19.265734025410243, 16.861221313476562, 17.137191602161952, 11.221855759620667, 6.937666424683162, 1.982708202941077, 0.4367956817150116, 0.7457161194511822, 2.8827956531729018, 14.06416838509696, 29.609675339290074, 43.13080726351057, 46.59461627687727, 45.75378349849156, 49.6337513923645, 57.65528685706002, 50.64108385358538, 25.255279234477452, 4.912630881581988, 0.6795794197491237, 0.102409906153168, 0.17823605878012522, 0.09301216221813645, 0.10500326699444226, 0.0873786455818585, 0.16308186123413698, 0.22414781445903437, 0.08508535328188113, 0.1416616506342377, 0.10226581245660782, 0.12096703824188028, 0.12279779357569558, 0.14685693542872155, 0.16914241388440132, 0.234446469694376, 0.10561688656785659, 0.14904977061918803, 0.09607731524322714, 0.11721556740147726, 0.12361595753048148, 0.15193753423435347, 0.11251509748399258, 0.12349049640553338, 0.18628782672541483], [0.05280626518651843, 0.05541112380368369, 0.05551304654883487, 0.02538222916025136, 0.02733837267650025, 0.04830057553148695, 0.0365919347054192, 0.056663255007671456, 0.05582163070461579, 0.012689886431741928, 0.035182783712766, 0.04933951781796558, 0.028707666522158042, 0.021369508766968335, 0.07175461003290755, 0.016867194823654633, 0.045186333890472136, 0.09938647624637399, 0.06903468883995499, 0.03900902571954897, 0.034212841652333736, 0.013374817491109883, 0.01777000941469201, 0.0042841229504639545, 0.04065605751903994, 0.08725865344916071, 4.316798099449702, 19.43273571559361, 37.70573370797293, 40.66552734375, 30.151009491511754, 27.11577578953334, 18.686136143548147, 26.15186435835702, 25.075763838631765, 10.574862957000732, 1.9570806409631456, 0.3158100651843207, 0.07613468928528683, 0.875336229801178, 3.3613230841500417, 2.616574989897864, 7.03639337846211, 13.335502113614764, 10.338744929858617, 8.771791526249476, 14.745746714728218, 11.240061776978628, 15.607045412063599, 31.94741412571498, 37.812499727521626, 44.512129987989155, 45.48230348314558, 48.44646406173706, 46.598000049591064, 47.47823258808681, 47.02925736563546, 48.97715704781668, 51.198183468409944, 49.64859274455479, 47.69215720040457, 48.761992182050435, 50.03889042990548, 48.19374418258667, 48.360045841761995, 49.03203044618879, 50.08986241476876, 49.10360731397356, 50.37807021822248, 48.44797529493059, 49.67184836523873, 49.083638191223145, 47.40518965039934, 44.93888487134661, 39.01143223898751, 33.28512300763811, 33.78152663367135, 31.78057050704956, 31.984395912715367, 32.4998653956822, 33.36018092291695, 32.76016228539603, 34.633222920554026, 39.26397493907383, 42.558623109545024, 44.75452831813267, 48.4174588067191, 42.59523664202009, 32.37062890189034, 49.83244555337088, 43.317689486912315, 42.54382692064558, 38.902359417506624, 35.1796292577471, 32.5079322542463, 32.78689200537545, 33.29810224260603, 35.52953011648995, 35.77605220249721, 33.99382536751883, 35.93041338239397, 38.11164052145821, 42.45576197760445, 43.8734689440046, 45.404188360486714, 48.575200285230366, 45.65604666301182, 44.4786570412772, 44.44738667351859, 45.541047028132844, 45.29775585447039, 46.47362034661429, 47.980663776397705, 46.31038979121617, 44.87827573503767, 47.394343512398855, 43.23164299556187, 41.303424085889546, 42.520223890032085, 43.6765569959368, 41.36355379649571, 39.30086292539324, 41.37892321177891, 44.433417320251465, 47.57134192330496, 43.073804242270334, 39.310882227761404, 30.769552026476177, 25.7916419506073, 18.702134370803833, 7.942751577922276, 6.4757197839873175, 13.03978157043457, 13.527323637689863, 7.355775577681405, 8.350415417126246, 3.3140058517456055, 0.8601467077221189, 0.1199846009590796, 0.26384703921420233, 2.3930318994181494, 11.188874397959028, 28.74232997213091, 32.36462913240705, 30.35909414291382, 27.823461975370133, 36.548636300223215, 48.890200342450825, 35.49697780609131, 15.17706482751029, 3.944354678903307, 0.27852676436305046, 0.047452176056270085, 0.06336375778274876, 0.030224114257310117, 0.019280543717156564, 0.0386735546136541, 0.04913815576583147, 0.03789366003391998, 0.04732645708801491, 0.06687385336096797, 0.02781370172410139, 0.059739566541143825, 0.0386413242002683, 0.06331395331237998, 0.050936093753469844, 0.017643600037055354, 0.0443515254716788, 0.05901431438646146, 0.03664481293942247, 0.04494757777346032, 0.034808446121002944, 0.06797798589936324, 0.023840258330372826, 0.014670391899666615, 0.032262257034225125, 0.04793369843225394, 0.013817991612346044, 0.05927460041961499, 0.039645484781691005, 0.009804780977512044, 0.039597590387399705, 0.046506718931985755, 0.06996796626065459, 0.019821909489110112, 0.02362359022455556, 0.03205728178311672, 0.0384447797467666, 0.05755405952887876, 0.04164703755772539, 0.10731276271066495, 0.015672316708202873, 0.03964497588042702, 0.06774133324090924, 0.01753250349845205, 0.04165012828473534, 0.0030361831845116933, 0.06167825644037553, 0.020372058896880065, 0.031034946641219512, 0.05763148715985673, 0.14224106525736196, 5.386548834187644, 22.930220910481044, 44.9803204536438, 45.01301520211356, 35.2984538759504, 30.997751712799072, 21.151026964187622, 30.372625759669713, 27.16175549370902, 12.389464923313685, 2.0906046075480322, 0.12190203235617705, 0.022021329861932566, 0.7866069195525986, 3.165939522641046, 4.994183625493731, 8.884777920586721, 11.053809234074183, 7.611229572977338, 10.9776109457016, 10.66491595336369, 13.892012868608747, 17.16397864477975, 32.228163037981304, 39.961893694741384, 45.24962568283081, 47.53594779968262, 49.762056827545166, 47.55070229939052, 48.391997132982524, 47.77201632090977, 48.450355052948, 49.302186829703196, 49.91389928545271, 48.60825981412615, 50.623268672398154, 50.025657585689, 48.24156863348824, 49.06244271142142, 50.580367020198274, 51.37216288702828, 49.71663645335606, 50.645377840314595, 49.44347497395107, 49.89476047243391, 52.34917688369751, 49.13713584627424, 46.216540472848074, 41.17900269372122, 35.042781012398855, 36.12920829227993, 33.91909054347447, 34.26011855261666, 34.32739795957293, 34.6978029523577, 35.825950690678184, 36.399951798575266, 41.39105824061802, 43.537721565791536, 46.198225021362305, 49.88659981318882, 42.60489811216082, 35.20319059916905, 50.71417195456368, 45.50721277509417, 45.70173454284668, 40.731997285570415, 37.56033917835781, 34.04717363630022, 34.826539175851, 33.81812974384853, 36.980334826878135, 37.56271546227591, 36.77205562591553, 37.98462397711617, 40.42706864220755, 44.07047816685268, 45.388443742479595, 47.16605002539498, 49.70036377225603, 46.08491727284023, 44.62268624986921, 43.91436604091099, 46.22008752822876, 46.731033733912874, 49.76013912473406, 48.20254060200283, 47.442459787641255, 46.57370219911848, 48.48940045492989, 44.75236742837088, 44.242480822971885, 42.593909536089214, 45.89657245363508, 43.14426245008196, 41.26331908362252, 43.1566858291626, 47.621202196393696, 49.27843441282, 47.212026255471365, 40.8073331287929, 31.626143319266184, 20.869739566530498, 19.61011975152152, 13.096050688198634, 9.17972981929779, 15.7872782094138, 9.151336005755834, 9.028619527816772, 5.674251156193869, 3.302612325974873, 1.034456274339131, 0.25673194815005573, 0.43836643600038117, 2.1118003044809615, 12.432838184492928, 29.323930672236852, 36.54520389011928, 39.50723137174334, 33.70951202937535, 42.24325132369995, 53.792015484401155, 42.58802093778338, 17.85156716619219, 4.706570327281952, 0.3996357928429331, 0.04081801025729094, 0.03021983609401754, 0.03538060381210276, 0.05115919267492635, 0.046200716601950784, 0.045296782428132634, 0.045504570206893344, 0.015218761849350162, 0.06220220082572528, 0.05054871132597327, 0.02188467630185187, 0.043302143923938274, 0.025211472430133393, 0.03023984269904239, 0.04107858127515231, 0.011283538636884518, 0.005576730888736035, 0.01488694635086826, 0.02497724044535841, 0.0096145714965782, 0.04294015566951462, 0.03593297542205878, 0.01703761737527592, 0.05915595857160432, 0.2540547475218773, 0.1341820369873728, 0.17049197932439192, 0.08864443908844676, 0.09643883191581283, 0.1263037704463516, 0.10086709393986634, 0.22347119290913853, 0.11507031108651843, 0.1062600291999323, 0.11584912001022271, 0.11847526766359806, 0.12186995122049536, 0.07482136440064226, 0.22168817929923534, 0.09783757078860487, 0.23637701038803371, 0.25751068922025816, 0.19446729496121407, 0.11213325868759837, 0.10999366814004523, 0.1415150599288089, 0.08783998832638774, 0.08644658952419247, 0.10836506874433585, 0.2289160835955824, 6.557462734835489, 27.686400072915212, 51.02584382465908, 52.26337010519845, 39.59166240692139, 36.05626262937273, 28.07626870700291, 34.987959725516184, 32.31030811582293, 14.373370170593262, 3.250611356326512, 0.5896599590778351, 0.3104325123131275, 1.290719734770911, 7.114721723965236, 8.61050820350647, 12.934595397540502, 22.956035205296107, 23.836158309664043, 15.119499002184186, 26.80776388304574, 20.87339605603899, 20.3100517477308, 36.00123984473092, 41.58273819514683, 48.25625017711094, 49.36737482888358, 51.120339325496126, 47.57107094355992, 48.17816979544503, 47.32331207820347, 48.975624970027376, 50.87672506059919, 51.728886876787456, 50.592022623334614, 52.36952815737043, 50.90938854217529, 49.648443358285085, 50.058293274470735, 52.21710899897984, 52.47633586611067, 51.40201929637364, 52.000693457467214, 51.546715532030376, 50.85879870823452, 52.263206822531565, 52.314752033778596, 48.71961859294346, 43.755641392299104, 36.487665857587544, 37.56930930273873, 35.604713099343435, 35.86580555779593, 35.81381218773978, 35.63859598977225, 36.300724574497764, 38.08311816624233, 44.373311928340364, 46.35633475439889, 49.17917592184884, 53.347872734069824, 44.16513000215803, 38.7906289100647, 53.41574273790632, 48.86891106196812, 47.64779642650059, 43.43586097444807, 39.75640419551304, 36.266629764011924, 37.76106916155134, 36.492675508771626, 39.187075751168386, 39.766757011413574, 38.22224889482771, 40.12808070863996, 41.46899618421282, 46.36873034068516, 47.40555443082537, 50.85611322947911, 52.426829951150076, 47.205175331660676, 45.60860783713204, 44.65419633047921, 47.51297358104161, 46.80602216720581, 50.940037046160015, 50.145830154418945, 48.95944261550903, 48.18472194671631, 51.05362272262573, 45.89129529680525, 46.36784444536482, 45.933766160692485, 48.886684553963796, 46.694934368133545, 43.70869936261858, 45.211229937417166, 50.08054140635899, 51.94995076315743, 51.7077956199646, 45.57856035232544, 33.66047511781965, 29.79805142538888, 24.171794516699656, 13.014271259307861, 15.433144160679408, 25.95823196002415, 20.63296754019601, 14.632489340645925, 15.261728627341133, 10.663658329418727, 4.361412482602256, 0.7040411499994141, 0.6506275247250284, 3.235499675784792, 14.881088938031878, 35.79301275525774, 41.96489953994751, 42.299945150102886, 37.66874149867466, 48.28155204227993, 60.785293987819124, 50.46881716591971, 23.36990291731698, 6.923973262310028, 0.46697740788970676, 0.14675633582685674, 0.10667861066758633, 0.09024299973888056, 0.14168587433440344, 0.17976071339632782, 0.10847742735807385, 0.17087973494614872, 0.0860335516876408, 0.12231355027428695, 0.12737192027270794, 0.11822384329778807, 0.11673430965415069, 0.1739815899303981, 0.12116358269538198, 0.07757892393107925, 0.18297122897846357, 0.1388026840452637, 0.07589876944465296, 0.10775525575237614, 0.07512982642011982, 0.10665374914450304, 0.13719247973390988, 0.07175012491643429, 0.09224132608090128], [0.018237433529325893, 0.10801691921161753, 0.03303864019523774, 0.040002818285886727, 0.012461164999487144, 0.025444554298051765, 0.02540714666247368, 0.05596807552501559, 0.018020198846768056, 0.04018942220136523, 0.07736581643777234, 0.036231853134397946, 0.02460426331630775, 0.033690318797848055, 0.0160612512845546, 0.018033201274062906, 0.035957209300249815, 0.015450267819687724, 0.02841383371768253, 0.04469090493928109, 0.03013423890141504, 0.03149611296664391, 0.08619062575910773, 0.05530131648161581, 0.022949228196271827, 0.019132256674181138, 1.992801764181682, 18.786810329982213, 38.97741733278547, 41.25167390278408, 32.69769450596401, 24.627599818365915, 26.51041398729597, 30.5287344115121, 20.726292269570486, 10.292356150490896, 2.9680995557989394, 0.18102204214249337, 0.05433839386595147, 0.525667918579919, 2.1084747229303633, 2.0145061995301927, 4.461223355361393, 5.800128195966993, 3.334420744861875, 9.971652490752083, 6.80377767767225, 7.943506325994219, 11.50579389504024, 29.30373920713152, 35.35945211138044, 40.82647541591099, 47.123530524117605, 49.2586042540414, 47.20173944745745, 49.15771641050066, 47.643005643572124, 49.55941261563982, 44.995366777692524, 42.89933497565133, 43.224830286843435, 45.189447334834504, 44.792854581560405, 45.633600507463726, 46.30397660391671, 47.86701556614467, 47.04927165167672, 46.17940582547869, 45.5848137310573, 45.253641741616384, 45.80545030321394, 46.020847933632986, 44.23864541734968, 41.73367738723755, 35.38434403283255, 33.44850294930594, 33.00407532283238, 31.337226799556188, 33.02315160206386, 32.12032004765102, 32.02468156814575, 32.97494847433907, 34.25285073689052, 34.876156261989046, 41.03123188018799, 42.93912730898176, 47.72558150972639, 44.04099348613194, 29.268418039594376, 48.82649578366961, 43.859482220241, 42.660772051130024, 42.580405712127686, 39.73304435185024, 35.94116224561419, 33.6356839452471, 33.04536499295916, 32.58129480906895, 35.4140545300075, 34.30969047546387, 33.49870368412563, 35.380352292742046, 36.8786792073931, 42.6000656400408, 42.46311664581299, 47.46511786324637, 47.840973717825754, 48.50930009569441, 46.14894839695522, 47.173703466142925, 44.85217135293143, 44.215539182935444, 46.370491709027974, 46.34262943267822, 44.306324345724924, 47.61132880619594, 44.174892221178325, 47.12389530454363, 48.85237087522234, 48.265557289123535, 45.3831353187561, 42.46969311577933, 39.34085675648281, 44.496795313698904, 45.16517032895769, 43.741706780024934, 39.90934099469866, 30.61336694444929, 21.25775476864406, 15.180042130606514, 16.366844824382238, 12.962012120655604, 9.697608590126038, 7.45542403629848, 8.678658740861074, 3.8314099737576077, 1.7911501675844193, 0.18699186109006405, 0.24516072762863977, 0.6109180269496781, 2.7511550826685767, 11.84672028677804, 25.943288121904644, 27.887397561754497, 26.213194370269775, 33.07626363209316, 36.22695902415684, 44.715944971357075, 39.605030741010395, 21.765629870550974, 3.244338218654905, 0.11580926286322729, 0.006573737590640251, 0.054100346818034134, 0.010391702742448874, 0.023116751707025936, 0.04559787894998278, 0.014172966359183192, 0.06550971298877682, 0.01615807314270309, 0.024112269448648607, 0.042808245069214275, 0.04063799830951861, 0.02716567024721631, 0.04803797569391983, 0.051466307802391906, 0.03584068108882223, 0.10731589075710092, 0.009689051741068917, 0.03719433130962508, 0.08348006156406232, 0.026582739116357904, 0.043071370771420855, 0.043029796930828264, 0.0222025207642998, 0.04357371060177684, 0.028434705454856157, 0.058045915993196626, 0.03101510288459914, 0.011249391362071037, 0.024624973901414444, 0.007918372201467199, 0.05907874807183232, 0.04748217408944454, 0.022421302506700158, 0.035904063044914176, 0.09639159909316472, 0.11217565355556351, 0.005074251958701227, 0.03492793274511184, 0.020062012498133948, 0.03186265419104269, 0.017188654181414416, 0.025155517039820552, 0.05284459902239697, 0.045134480244347026, 0.01602650011357452, 0.04559518177328365, 0.015377086121588945, 0.03291152683751924, 0.032635305409452746, 0.08421694380896431, 3.0649342111178806, 21.92957087925502, 43.650390080043245, 47.340904917035786, 36.64739799499512, 30.52286318370274, 26.576289858136857, 30.599018914358957, 26.11313509941101, 12.007783004215785, 3.515197455883026, 0.3363889737852982, 0.07814903583909784, 0.31689246424606865, 1.7540939045803887, 3.8501019307545254, 6.329850605555943, 7.369878683771406, 8.235864809581212, 14.114216259547643, 9.411071828433446, 15.51462915965489, 20.14700358254569, 29.32761321749006, 37.871510778154644, 43.10469593320574, 48.45660843167986, 49.00075313023159, 48.25937339237758, 48.20883914402553, 48.204836981637136, 50.6940986088344, 47.419912883213584, 45.99530635561262, 46.907941818237305, 46.535452365875244, 46.74173395974295, 47.27666882106236, 48.09007705960955, 49.32137080601284, 47.90910427910941, 47.892442498888286, 47.93522950581142, 47.27209343229021, 49.87099068505423, 48.032327107020784, 45.95083441053118, 45.15997307641165, 38.267273221697124, 35.45296444211687, 34.41345139912197, 33.011482102530344, 32.85810061863491, 33.83538906914847, 35.01105553763253, 34.99035685403006, 36.460387229919434, 36.43463025774275, 45.02344444819859, 44.83760445458548, 48.28814935684204, 45.4976590020316, 32.23691429410662, 50.304575647626606, 46.411687578473774, 45.35660014833723, 44.19216544287545, 41.95487676348005, 37.51582554408482, 35.03401933397566, 34.752784047807964, 34.28387444359915, 37.17921311514718, 35.249159881046836, 35.35300070898873, 36.90130601610456, 40.23148727416992, 44.12535851342337, 44.31643050057547, 49.38539498192923, 49.257655824933735, 48.76087004797799, 46.35196781158447, 45.32714326041085, 45.651547704424175, 45.82546806335449, 46.507572719029014, 46.99562808445522, 45.630668367658345, 48.590910162244526, 45.42050620487758, 48.398438113076345, 52.036872727530344, 49.14421953473772, 48.46315016065325, 45.267208099365234, 41.408699716840474, 47.41736289433071, 48.84513085229056, 48.26123203550066, 41.80706773485456, 34.345883641924175, 23.363036360059464, 18.971309321267263, 10.570547257150922, 14.21818562916347, 11.634487560817174, 9.773768663406372, 11.316460694585528, 6.501507588795253, 2.671870925596782, 1.0190537465470177, 0.12873745842703752, 0.7247373365930149, 2.7775777791227614, 11.836112124579293, 28.261382613863262, 33.93970932279314, 30.819321972983225, 36.34714548928397, 42.424918924059185, 53.2244553565979, 43.27496153967721, 24.900585855756486, 4.840013521058219, 0.23822832533291408, 0.05470365944451519, 0.024330815400129983, 0.04219732267249908, 0.035218912309833934, 0.023184742612232054, 0.036884318837629895, 0.0191145536955446, 0.057551956070320945, 0.0033484840158572687, 0.07365612299846751, 0.08678435747112546, 0.01890133594029716, 0.009951999327833099, 0.0435794001179082, 0.01974148103701217, 0.07721039799175092, 0.006593161503717835, 0.048674740096820254, 0.0606128614661949, 0.008288842143623956, 0.06009342933871916, 0.04041596808071647, 0.00624478847852775, 0.043193754740059376, 0.06774486840835639, 0.1784952591572489, 0.12306987254747323, 0.135728798274483, 0.1451227491987603, 0.08393508714756795, 0.0900624483557684, 0.12089560207511697, 0.131215631163546, 0.16778427176177502, 0.24329030513763428, 0.22774873194949968, 0.07332317265016691, 0.11401185074022838, 0.06836257954793316, 0.0896990792825818, 0.12146520508187157, 0.1099674291908741, 0.10201028973928519, 0.10788784828037024, 0.11247129804853882, 0.10460973025432654, 0.22002408573670046, 0.1271888515246766, 0.09765203217310564, 0.2639859217618193, 3.6293200978210995, 25.87979027203151, 50.246492181505474, 52.66828680038452, 43.10563046591622, 33.9681066104344, 35.124304226466585, 39.19040046419416, 29.469835894448416, 15.213115555899483, 4.026381637368884, 0.7921879515051842, 0.2023149731435946, 1.972047277859279, 4.368305095604487, 8.090241857937404, 12.302919030189514, 17.34663983753749, 14.45637161391122, 18.061281170163834, 10.963182142802648, 13.446555171694074, 14.801158598491124, 31.54438386644636, 38.85974611554827, 44.65164286749703, 48.59211914879935, 50.74703345979963, 48.172833578927175, 49.14341006960188, 49.64771032333374, 52.354565211704795, 49.56769486836025, 48.64030490602766, 48.092859813145225, 49.77912507738386, 49.210877077920095, 50.777296338762554, 49.931276730128694, 53.061197008405415, 50.71795177459717, 50.99033505575997, 50.622532163347515, 49.813216413770405, 51.42905126299177, 49.64285353251866, 47.519317286355154, 47.72153070994786, 40.0568790435791, 37.68920741762434, 35.56971154894148, 34.85107673917498, 34.989033222198486, 35.50527048110962, 36.07099281038557, 37.05294350215367, 37.77897119522095, 38.817956175122944, 46.281231675829204, 47.90147168295724, 50.70548323222569, 48.634777614048545, 35.829212869916645, 52.50454902648926, 48.28101008278983, 48.17682531901768, 46.9363807950701, 44.099969795772004, 40.07905421938215, 37.705469676426475, 36.52522087097168, 35.460607460566926, 39.47831991740635, 36.59680816105434, 35.970462799072266, 39.42459297180176, 40.815469469342915, 46.2900767326355, 46.30505010059902, 52.073333399636404, 51.07815333775112, 50.41293280465262, 47.61700548444475, 47.2754841532026, 48.05712175369263, 47.106330258505686, 48.02413518088204, 49.595001288822715, 46.85697678157261, 49.925464562007356, 47.864392621176584, 51.501548767089844, 54.053260803222656, 52.60398122242519, 50.722443784986226, 47.0522906439645, 43.81298834936959, 48.67988184520176, 50.13383756365095, 49.94184494018555, 46.20608343396868, 34.87584706715175, 25.16943771498544, 18.631653581346782, 24.241797617503575, 23.306024653570994, 17.89915016719273, 16.095449924468994, 16.321638107299805, 10.973698241370064, 3.792343727179936, 1.306089910013335, 0.8493940447057996, 1.1121102103165217, 4.199922016688755, 14.555871554783412, 33.02689320700509, 38.383391516549246, 36.830055713653564, 44.6771879196167, 49.24798045839582, 58.65080043247768, 51.084761074611116, 31.409269196646555, 5.67186792407717, 0.4471710521195616, 0.1253355009747403, 0.15968588846070425, 0.12445138341614179, 0.10657794321221964, 0.08304588736167975, 0.13100856941725525, 0.14577108940907887, 0.21317548251577786, 0.08355706850332872, 0.2063203246465751, 0.12213156718228545, 0.15761884009199484, 0.15428317551101955, 0.219776719010302, 0.10597522091120481, 0.20734413899481297, 0.10700706911406346, 0.23428326845169067, 0.09665565778102193, 0.1556514820882252, 0.14824500094567025, 0.09761271785412516, 0.07871038786002568, 0.1949488648346492], [0.04279535968921014, 0.004733120174413281, 0.014025603820170676, 0.07819179033062287, 0.00999396587056773, 0.005060753776758377, 0.03424746390166027, 0.02873617856364165, 0.03951405933392899, 0.028009913695443953, 0.057169384456106594, 0.02222391836611288, 0.05134199000895023, 0.01331677136477083, 0.028650479590786353, 0.04203278471582702, 0.014571191776277763, 0.053060305304825306, 0.010411390436014958, 0.04574657989931958, 0.044761391157018285, 0.04444479010999203, 0.024519714460309063, 0.036142228836459775, 0.03551079093345574, 0.08782565766679389, 1.3773084027426583, 14.04291124003274, 41.70610693522862, 43.815156187329976, 34.7382310458592, 25.631753478731426, 17.940469367163523, 23.329195158822195, 18.08735602242606, 11.286322014672415, 4.464996227196284, 0.3362082934805325, 0.10010031544204269, 0.27754188435418264, 0.9701999851635524, 3.0436675122806003, 7.2234232510839185, 5.772732317447662, 5.803401666028159, 14.747850281851631, 8.40872209412711, 20.680085011890956, 25.26993124825614, 26.707775831222534, 36.167458125523154, 41.176998138427734, 46.948005131312776, 47.7214994430542, 48.397930894579204, 49.022101470402305, 49.276912757328574, 45.54663685389927, 42.281487260546, 40.81062657492501, 38.96773154394967, 39.10661561148507, 38.303633144923616, 38.39271947315761, 39.66849211284092, 40.071220125470845, 42.176017080034526, 40.396037987300325, 41.53619221278599, 41.5586314201355, 42.8812210219247, 40.00188405173165, 39.59726960318429, 34.192859990256174, 32.975115231105256, 32.42996999195644, 32.68892240524292, 32.348960944584434, 32.389395986284526, 31.593135901859828, 30.670651367732457, 32.997127124241416, 33.76963826588222, 34.05076585497175, 39.061758041381836, 43.46011713572911, 46.154173442295615, 43.97505160740444, 27.431081567491802, 48.48638146264212, 46.70008645738874, 44.397529874529155, 43.41391856329781, 41.55397960117885, 38.196537085941856, 36.31853975568499, 33.045330251966206, 34.27211461748396, 33.07901511873518, 34.08200148173741, 32.38605390276228, 34.04535320826939, 34.788928576878135, 37.53219549996512, 42.084005560193745, 43.603048528943745, 44.357987676348, 44.93809972490583, 47.25304841995239, 48.45437111173357, 48.169025966099326, 49.28910337175642, 44.848832743508474, 47.4152888570513, 46.61529411588396, 46.07482501438686, 46.65703889301845, 48.54833507537842, 45.539351667676655, 48.70700066430228, 48.68590245928083, 44.56232724870954, 41.90208087648664, 45.59671252114432, 44.77328150612967, 45.82842104775565, 37.102095058986116, 35.825662340436665, 19.936725037438528, 22.521666833332606, 11.978598833084106, 7.71140262058803, 15.059878247124807, 4.872517194066729, 7.486255799021039, 4.859541867460523, 2.1165411472320557, 1.7068947915519987, 0.08283892061029162, 0.915287720305579, 2.4002847330910817, 12.491085801805768, 24.265838384628296, 29.23440660749163, 28.19524965967451, 31.03348629815238, 42.22825016294207, 44.67244577407837, 42.004101276397705, 20.10223981312343, 1.6157078274658747, 0.0452798835134932, 0.028591647211994444, 0.04922443149345262, 0.017068383849358985, 0.0647464357316494, 0.0650757219908493, 0.035629809368401766, 0.06508089921304158, 0.056486581452190876, 0.01638122125794845, 0.04607643612793513, 0.034503085006560595, 0.03577962650784424, 0.04957313063953604, 0.023737614641764333, 0.0444042883547289, 0.051185299309768846, 0.06723558716475964, 0.054400174479399405, 0.03444265467779977, 0.02319575014657208, 0.029433458112180233, 0.03399585972407034, 0.03587976470589638, 0.010933222881119167, 0.02021539194642433, 0.03456544576744948, 0.023431549547240138, 0.013207359289351319, 0.03435798368549772, 0.04206776998138853, 0.020302497183105776, 0.024823114608547518, 0.03460488561540842, 0.021324174146034887, 0.048699245389018736, 0.05191116893131818, 0.06964959084455456, 0.0576993270910212, 0.032090499464954646, 0.025267409160733223, 0.010466959061367171, 0.0381776981854013, 0.028477585475359644, 0.025077370161722814, 0.01925059487777097, 0.019613039446994662, 0.04049709372754608, 0.029054784681648016, 0.04927452094852924, 0.05524257231237633, 1.4187241175345011, 18.219055652618408, 46.912958417619976, 49.03437893731253, 42.643304279872346, 27.28288517679487, 22.975559643336705, 31.001191071101598, 24.047774382999965, 13.856736864362444, 4.245670693261283, 0.4517979009875229, 0.09612062613346747, 0.5507928760988372, 1.968621381691524, 4.670155252729144, 6.151766538619995, 8.268790585654122, 8.840562190328326, 12.311738031251089, 10.28749328000205, 16.413496766771587, 22.795271260397776, 28.505571842193604, 36.53790133340018, 44.11893490382603, 48.38023383276803, 47.799409593854634, 47.25557061604091, 49.00023201533726, 51.330303464617046, 47.00905895233154, 44.9552652495248, 42.725522313799175, 41.28751618521554, 41.948369775499614, 40.91408177784511, 41.796256337847026, 41.82062367030552, 43.01374053955078, 44.85329348700387, 43.3230048588344, 43.43472146987915, 43.86966480527605, 45.83370862688337, 43.87067576817104, 41.86177090236119, 37.665177072797505, 35.0346794128418, 33.68200411115374, 34.500046798161094, 35.35678052902222, 33.4852728162493, 32.755107470921104, 33.26328829356602, 34.438086237226216, 34.58625657217843, 35.97583723068237, 40.23811585562569, 45.29932614735195, 49.60813685825893, 45.12709420067923, 31.21046733856201, 49.072541918073384, 49.14196831839425, 46.19210365840367, 45.23181397574288, 43.50014918191092, 39.624006271362305, 38.2826634815761, 35.53652695247105, 35.341025488717214, 34.79015840802874, 35.22893020084926, 34.12317303248814, 35.41203260421753, 36.666578497205464, 40.04544578279768, 44.28582715988159, 45.69996622630528, 45.9636538369315, 48.972991602761404, 47.323402404785156, 49.82164805276053, 48.970538888658794, 48.57949774605887, 45.37789985111782, 48.20360715048653, 48.10222945894514, 47.42776434762137, 47.62341519764492, 49.77016537530081, 47.655602727617534, 50.98876476287842, 49.43738835198538, 47.09462601797921, 43.805140359061106, 47.933989252362935, 47.063821179526194, 49.80954776491438, 40.512746879032676, 35.91076387677874, 20.83801930291312, 23.182735817773, 10.321394409452166, 11.744861432484218, 13.653020024299622, 9.55862637928554, 14.668797152382986, 6.322040396077292, 2.464830458164215, 0.8841614733849252, 0.10888214635529689, 0.6855749551739011, 3.122283990894045, 13.509491954530988, 30.049899305616105, 34.20488732201712, 33.25149025235857, 38.62575510569981, 45.49618945802961, 51.33320781162807, 46.858352524893625, 24.308279718671525, 2.4722641621317183, 0.27319198633943287, 0.04610408642994506, 0.008499383078222828, 0.02137841623542564, 0.05435401374208076, 0.017619116797244976, 0.03973670024424791, 0.02323029436437147, 0.01266510718102966, 0.015783564220847826, 0.037016002128698995, 0.0065318367809855515, 0.05741511591311012, 0.04113348832886134, 0.030284585298172066, 0.030637152093861784, 0.019872662212167467, 0.03600361770285027, 0.02102716070865946, 0.01777471335870879, 0.018363081251404116, 0.07958358779017415, 0.03818780157182898, 0.01316399241997195, 0.04080756760335394, 0.07817857925380979, 0.08873682163123574, 0.10113235363470656, 0.10639047755726747, 0.12023876660636493, 0.0879923737208758, 0.16995814868382045, 0.1324786969593593, 0.10627514696014778, 0.10147244217140333, 0.14908414520323277, 0.11076778838677065, 0.08422216174325772, 0.18454329962176935, 0.08946941553481988, 0.14290816017559596, 0.08054190993841205, 0.17018757494432585, 0.05956297101719039, 0.11208004797143595, 0.1309623611824853, 0.0971267307177186, 0.11067791642355067, 0.22376904264092445, 0.14058610477617808, 0.15709320615444863, 2.0163919840540205, 21.311712741851807, 53.520181110927034, 56.232736996241975, 46.0329065322876, 35.66537782124111, 26.980402299336024, 33.40529557636806, 28.004087345940725, 15.962711538587298, 5.669101238250732, 0.8979655355215073, 0.25299286735909327, 0.9108988472393581, 3.9448401842798506, 10.479772516659327, 17.080145154680523, 13.98396532876151, 14.132338898522512, 28.311868224825176, 16.546122244426183, 26.10748447690691, 28.85372175489153, 31.333092621394567, 39.718324593135286, 45.070476804460796, 48.97871691840035, 48.54189756938389, 48.3714165687561, 50.316870485033306, 52.74457107271467, 49.4090119089399, 48.117282731192454, 46.02976247242519, 42.481765610831125, 44.04204613821847, 40.97684832981655, 43.557093143463135, 43.79673998696463, 43.6259880065918, 46.90834828785488, 44.1050454548427, 44.53641741616385, 45.09792913709368, 47.72692251205444, 44.49402298246111, 43.4549754687718, 37.89649302618844, 36.77590840203421, 36.43157652446202, 36.66584546225411, 37.06151063101632, 34.49846608298165, 33.97244923455374, 33.67145674569266, 36.480738503592356, 36.80468436649868, 37.618620668138774, 42.777487891060964, 47.9770541872297, 50.694307054792134, 46.28472661972046, 33.81425959723336, 51.11778933661324, 50.45953089850289, 48.049298082079204, 46.703689098358154, 47.27000897271292, 42.284457615443635, 41.13868924549648, 36.550599166325156, 37.51045111247471, 36.569404465811594, 37.828883579799104, 36.38694477081299, 37.73206043243408, 38.361292770930696, 40.90193632670811, 46.64984055927822, 47.731074060712544, 48.03740971429007, 50.3013516834804, 50.63219363348824, 52.6455522945949, 51.758854457310264, 50.670578956604004, 46.47187982286726, 49.170171056474956, 48.38347169331142, 48.4110803604126, 48.92144986561367, 50.72019951684134, 48.09968989236014, 50.240721702575684, 52.69540214538574, 49.295985562460764, 46.13209554127285, 50.222767557416645, 49.896900517599924, 52.445694310324534, 43.69442081451416, 36.97994225365775, 22.672903060913086, 28.027693850653513, 18.120860236031668, 14.75824304989406, 29.09830355644226, 12.142065627234322, 17.439130783081055, 10.623360514640808, 7.234657619680677, 3.8063078692981174, 0.23607538800154412, 1.7316104024648666, 3.2598541975021362, 16.741703612463816, 32.1994218145098, 40.35046475274222, 38.96360431398664, 42.71519381659371, 51.66926438467843, 57.44952985218593, 52.712876864842, 29.748357909066335, 4.036443931715829, 0.38828786462545395, 0.1712427104690245, 0.1315422507801226, 0.11962785438767501, 0.14999825400965555, 0.09733242860862187, 0.11168600233005625, 0.14088252958442482, 0.1681480479559728, 0.1362458283879927, 0.10880543797143868, 0.11503547509866101, 0.11588295176625252, 0.23838889385972703, 0.1002330029649394, 0.14315430553896086, 0.12214241017188344, 0.08150520574833665, 0.12108925596943923, 0.08797674705939633, 0.12442854392741408, 0.21751318047089235, 0.09399116611374275, 0.07500380889645644, 0.12249528909368174], [0.017432616358356814, 0.019683340763939277, 0.04792427018816982, 0.03229674357654793, 0.036865876255823035, 0.10283046894307647, 0.031144228098647933, 0.03587557814483132, 0.04759636474773288, 0.006739888764319143, 0.024085996572726538, 0.0505144079881055, 0.03122163876625044, 0.023528798882450377, 0.07419607402490717, 0.035900955354528766, 0.012020759301127067, 0.024711587200207368, 0.014478259620123675, 0.042350281429077895, 0.03313933139933007, 0.034768826461264064, 0.06829597455050264, 0.046456819466714344, 0.03580588920574103, 0.05824334254222257, 0.35878193218793186, 13.203931025096349, 33.18905026572091, 42.18644980021885, 32.84359972817557, 26.29386990410941, 20.25772660119193, 24.56888059207371, 32.79176616668701, 15.83621437208993, 5.560173894677844, 0.46264124342373436, 0.06425650630678449, 0.11134649733347551, 1.1661363627229417, 2.563732202563967, 2.1995260885783603, 3.319691215242658, 7.355793816702707, 13.507157359804426, 9.476897324834551, 12.629281997680664, 23.700878620147705, 24.03876951762608, 32.51046139853341, 38.89290986742292, 44.929303305489675, 46.76879371915545, 50.35826090403965, 48.3275317464556, 47.04286193847656, 41.569338594164165, 39.61780500411987, 35.87558862141201, 34.90940339224679, 34.77392394202096, 33.73755495888846, 31.428470543452672, 32.37455810819353, 32.40896211351667, 33.327427114759175, 33.6563583101545, 34.296224866594585, 33.164780208042686, 34.456898484911235, 32.892285755702424, 31.40802546909877, 31.950627667563303, 36.4162974357605, 34.36661359242031, 32.12251567840576, 32.018945830208914, 32.527130126953125, 35.103536060878206, 35.595468521118164, 35.76417078290667, 38.38109513691494, 39.92512035369873, 43.10071114131382, 43.08699539729527, 48.902648040226524, 43.70394679478237, 29.291260242462158, 43.71004383904593, 42.974674292973106, 48.6820045198713, 46.83156027112688, 45.35112844194685, 41.79018013817923, 35.81787688391549, 33.35419157573155, 32.235128607068745, 33.419181551252095, 34.92378963742937, 38.85567447117397, 35.16044528143746, 33.10307673045567, 33.6044830594744, 36.668909617832725, 40.45379836218697, 41.39017581939697, 40.68522548675537, 41.189438888004844, 41.87258924756731, 46.107182775224956, 46.44461161749703, 47.13298354830061, 48.30609655380249, 47.13743734359741, 49.34013441630772, 48.21818099703108, 49.29601335525513, 44.87324523925781, 49.49015992028372, 49.96841137749808, 45.85022102083479, 42.11632858003889, 45.10900803974697, 45.69197579792568, 47.54851014273507, 36.87871394838606, 30.305794511522564, 22.68791811806815, 21.841735226767405, 5.521129361220768, 15.90191306386675, 7.640400716236659, 11.617026737758092, 15.551306962966919, 5.532402379172189, 0.9010121577552387, 0.23147703760436603, 0.08455543100301709, 0.319926492869854, 2.6298184735434393, 11.476199780191694, 27.473828622273036, 37.14412471226284, 27.79771716254098, 27.61043541772025, 36.27342162813459, 43.755839415958945, 41.47158786228725, 18.642605679375784, 1.6699691329683577, 0.12388013835464205, 0.044713629077055624, 0.04965555228825126, 0.04105748901409762, 0.07978456307734762, 0.06258294718073946, 0.03815070266968437, 0.0071563722865123835, 0.019844837187390243, 0.036815997146602185, 0.02610304199957422, 0.053840199884559424, 0.048901777914060016, 0.052434027660638094, 0.01062778034247458, 0.048033239519489665, 0.025074542367032597, 0.005543155703760151, 0.014287352096289396, 0.024901933236313716, 0.03890461275087936, 0.06139443202742508, 0.010804648976773024, 0.026482122551117624, 0.026608979761866585, 0.08456609757351023, 0.035308238052363904, 0.027147058031654785, 0.08259524511439459, 0.04929894820920058, 0.10973919036665133, 0.012541112539890622, 0.04956812644377351, 0.09682473513696875, 0.03194164584523865, 0.03184042877650686, 0.03135333562801991, 0.01982063384327505, 0.057663697217191966, 0.020433822546952536, 0.03335309028625488, 0.050531415468347926, 0.057875725839819224, 0.007422078966296145, 0.05551157073516931, 0.07594879783157792, 0.04207161727494427, 0.04109310870990157, 0.017354450820546066, 0.043119987805507014, 0.03452741727232933, 0.7232110670634678, 15.776228836604528, 40.002127238682334, 46.6809024810791, 37.656557832445415, 30.222864287240164, 24.383285522460938, 26.39780800683158, 33.118783133370535, 17.14475645337786, 6.384056976863316, 0.5533551871776581, 0.16837385083947862, 0.09100622271320649, 1.1112692611558097, 2.335481490407671, 5.630906556333814, 7.4695497240339, 10.906633360045296, 10.274178794452123, 6.601121740681784, 16.266347817012242, 22.610661097935267, 28.80909868649074, 34.29243809836251, 42.5581818989345, 46.10987172807966, 47.361211027417866, 49.030873571123394, 48.256208487919395, 49.99928222383772, 44.17442669187273, 42.336270332336426, 37.68494817188808, 37.4348269190107, 36.58310978753226, 33.72174085889544, 34.206256117139546, 33.95609664916992, 35.24666895185198, 35.95494399751936, 36.43402576446533, 36.077711718423025, 37.21756369726998, 36.890494619097026, 35.36576107570103, 34.48080376216343, 33.9656399999346, 35.96262870516096, 35.572768756321494, 32.75379078728812, 33.94157491411482, 33.78567818232945, 35.7168014390128, 34.65488392966134, 36.28948933737618, 38.694361618586946, 41.67974199567522, 45.09442029680525, 45.044424533843994, 51.87830441338675, 46.01829447065081, 32.55840049471174, 45.77111577987671, 44.97487654004778, 48.75750364576067, 49.01897825513567, 47.760367665972026, 43.828642640795024, 37.736969334738596, 34.77473340715681, 34.81123229435512, 34.966531481061665, 35.61997481754848, 39.096012660435264, 35.8606777872358, 34.10179689952305, 35.479464871542795, 39.36495310919625, 43.08093309402466, 42.61310393469674, 43.428360394069124, 43.81578152520316, 42.881401675088064, 48.733247484479634, 47.405540534428184, 47.886765820639475, 48.80761405399868, 48.425786222730366, 49.06128583635603, 48.84923723765782, 49.02355711800711, 45.66887303761074, 51.10824251174927, 51.68700660978045, 47.591015747615266, 44.11402252742222, 48.108142375946045, 47.222101143428254, 49.31252574920654, 38.32846948078701, 34.41638701302664, 25.570406096322195, 20.556643315723964, 8.827240756579808, 13.713815024920873, 9.13676997593471, 13.139452610697065, 16.37346124649048, 5.291796684265137, 3.1602102986403873, 0.9309905405555452, 0.20058709728930676, 0.34676678691591534, 3.4713280498981476, 13.487726722444807, 30.01514789036342, 39.62365191323416, 30.807131358555385, 30.704193796430314, 43.12214285986764, 50.28212949207851, 47.40588447025844, 23.308798721858434, 2.4190911182335446, 0.12394010727959019, 0.0077159151634467495, 0.06404215030904327, 0.05141066453818764, 0.05326949765107461, 0.02577370824292302, 0.040868863064263544, 0.00944389873516879, 0.036045737764132876, 0.022327717260590622, 0.03690000656726105, 0.019444957841187716, 0.016785324484642063, 0.033092478556292396, 0.011443705979867705, 0.010242451331578195, 0.02130786725319922, 0.0477131779438683, 0.05927710421383381, 0.049826899343835454, 0.03731738702793207, 0.009295944174352502, 0.04277455580553838, 0.06481736299714871, 0.024403637474668876, 0.1793400895382677, 0.16394345143011638, 0.08914690105510609, 0.20804735911743982, 0.16277177073061466, 0.3039673220898424, 0.07698789278843574, 0.19055126580808843, 0.17841988748737744, 0.12595446061875137, 0.09000817912497691, 0.09834531854305949, 0.08656250366142818, 0.13978474134845392, 0.12325561472347804, 0.12781580431120737, 0.09440136767391648, 0.1475902825061764, 0.10768943107021706, 0.08651497228337185, 0.17223972268402576, 0.08507720407630716, 0.14519523030945233, 0.07467224954494409, 0.1347552090883255, 0.15423855504819325, 1.1328731647559573, 19.48407769203186, 45.99939884458269, 53.95033366339547, 45.17695794786726, 37.02544253213065, 29.369948591504777, 34.19301632472447, 42.35561064311436, 22.079728399004253, 7.323098199708121, 0.8996861374803952, 0.4803432449698448, 0.5635969404663358, 3.3177837175982337, 5.826497043882098, 6.785902568272181, 13.71875866821834, 13.506124683788844, 19.84889112200056, 14.673217943736486, 16.69045717375619, 28.154852833066666, 28.636324780327932, 36.10406623567854, 43.64626979827881, 46.074432441166465, 46.755046708243235, 51.03091253553118, 50.00876998901367, 52.25462927137102, 46.73078012466431, 45.175943510872976, 40.121427808489116, 38.18508298056466, 38.56039340155465, 36.055758884974885, 34.964867387499126, 35.33255216053554, 35.73175048828125, 36.76329394749233, 38.14531149183001, 38.039149965558735, 37.658239296504426, 37.94938618796212, 35.85501153128487, 34.9396766935076, 36.08110591343471, 39.528246198381694, 37.61008480616978, 34.488189697265625, 36.01504591533116, 35.56941625050136, 38.320552008492605, 37.64238698141915, 38.07986640930176, 42.414621693747385, 43.88310956954956, 47.82376650401524, 47.0429870060512, 53.11487531661987, 46.02629879542759, 35.934815066201345, 49.49788631711687, 45.942444460732595, 50.56996904100691, 51.93198619570051, 51.94496890476772, 46.81163631166731, 39.28211668559483, 37.14127942493984, 36.66588020324707, 36.79285158429827, 38.488719258989605, 41.69355501447405, 37.34408344541277, 35.53685004370553, 37.32416296005249, 40.834858417510986, 44.05503926958357, 43.87287834712437, 45.226998874119346, 44.99235473360334, 45.65401084082467, 49.201813152858186, 49.21622371673584, 50.89028794424874, 51.357769693647114, 49.87806395121983, 50.05284241267613, 47.969755104609895, 48.95564889907837, 44.33592367172241, 50.12258495603289, 54.00990751811436, 50.088754177093506, 46.688024384634836, 51.0196008682251, 50.17088883263724, 51.577225072043284, 41.85278688158308, 34.87737567084176, 26.8565228666578, 24.284139939716884, 8.83194729260036, 26.92107163156782, 17.324341331209453, 17.213008608136857, 23.458650520869664, 11.633203881127493, 4.067382957254138, 1.8818904927798679, 0.4874158054590225, 0.9478224430765424, 4.1780668922833035, 16.284406185150146, 35.436775139399934, 47.76681212016514, 37.64868204934256, 37.47102703366961, 47.892675263541086, 57.76337998253958, 54.666804109300884, 28.087693282536097, 3.42407335128103, 0.29523387072341783, 0.1530023863805192, 0.20351916924118996, 0.11288871243596077, 0.1604283686195101, 0.1499535928347281, 0.12074352880673749, 0.14889097985412392, 0.069020025698202, 0.09982603123145443, 0.0984727270635111, 0.0874917980815683, 0.10872870923152991, 0.0917966685124806, 0.10695972094046217, 0.17051393671759538, 0.08752294962427445, 0.12393454329243728, 0.11541002642895494, 0.12148898094892502, 0.07484020053275994, 0.2030083273670503, 0.12139625235327653, 0.11327908720288958, 0.11925733355539185], [0.07101714424788952, 0.05142014367239816, 0.010306723016713346, 0.10318280503685985, 0.02382456890440413, 0.030503942099000727, 0.012859489652328193, 0.05746359724019255, 0.051678651943802834, 0.04621338824342404, 0.01791863572517676, 0.04230018179597599, 0.0831056527261223, 0.0668023018432515, 0.014259030044611012, 0.005126338427154613, 0.040095438315932236, 0.014771441030981285, 0.0504876024621938, 0.034060486791921515, 0.026394371009830917, 0.0286026123378958, 0.026424976331847053, 0.02318102084765477, 0.033569057804665396, 0.04518393866185631, 0.4969317434089524, 10.291673489979335, 34.011793409075054, 42.61379528045654, 45.781934125082834, 26.613712855747767, 26.45383828026908, 28.54049175126212, 23.982912949153356, 17.042760372161865, 5.770294368267059, 1.2922482298953193, 0.1576350163668394, 0.31227123364806175, 0.7860588803887367, 2.6675454548427036, 7.328688893999372, 8.282098991530281, 11.951461774962288, 7.465569274766104, 4.437560396535056, 11.279624819755554, 16.014790024076188, 24.9053783757346, 31.943332059042795, 43.96238504137312, 44.20687477929251, 48.25714302062988, 48.008626801627024, 49.59968090057373, 45.09578561782837, 41.19267674854824, 38.40231146131243, 33.44235379355294, 31.913003172193253, 34.165032454899375, 33.71399014336722, 33.956468377794536, 33.86348063605172, 33.849372318812776, 33.07419306891305, 32.33868455886841, 32.42647852216448, 32.53695140566145, 31.796200479779923, 34.460455962589805, 30.902238300868444, 39.184623037065776, 47.41630329404558, 32.65294810703823, 33.11540978295462, 32.43671669278826, 38.49993365151541, 40.70808853421892, 41.41795471736363, 42.99702664784023, 43.18153606142317, 43.69950689588274, 42.912574768066406, 44.58004515511649, 45.794753551483154, 43.390888759068076, 26.948289462498256, 37.74387584413801, 46.30875696454729, 45.99485124860491, 47.67549194608416, 44.495871203286306, 41.40050431660244, 34.6246314729963, 31.76321390696934, 32.51072195598057, 36.00548866816929, 34.69437401635306, 33.7665011542184, 34.15590252195086, 32.56633186340332, 33.11754287992205, 33.19248267582485, 35.18191521508353, 34.79070036751883, 36.816336495535715, 35.4431813785008, 40.91559648513794, 41.41035686220442, 44.1483223097665, 42.43516056878226, 46.26615408488682, 45.78201750346592, 50.44020101002285, 48.05094133104597, 46.29848405293056, 45.883534158979145, 47.507835388183594, 47.0247688293457, 51.5927334512983, 45.4636857850211, 46.5848297391619, 43.05226482663836, 46.162723200661794, 32.813069343566895, 34.23120362418038, 18.239564997809275, 17.46604984147208, 6.280016388211932, 6.373620348317282, 7.952096036502293, 12.190165400505066, 17.918464422225952, 4.703371984618051, 3.6388052574225833, 0.23190158339483397, 0.23462720428194317, 0.1724807790347508, 3.7076061027390614, 11.19301552431924, 30.385261058807373, 39.50521986825125, 33.94084187916347, 36.93945162636893, 38.60888835362026, 41.379690987723215, 42.78678458077567, 16.841630867549352, 1.9181974359921046, 0.2626730650663376, 0.04238366195932031, 0.03925733560962336, 0.09037814355854477, 0.021054895827546716, 0.06679204917911973, 0.11320408194192819, 0.018101799468110715, 0.023281615360506942, 0.0621782960370183, 0.024436464998871088, 0.05167863158775227, 0.01694062927604786, 0.05475990321221096, 0.03778435143509081, 0.014138822477044804, 0.07798786341611828, 0.04559738361941917, 0.05115986103191972, 0.10580655746161938, 0.0625173599858369, 0.02026903353232358, 0.07975826984537498, 0.06697312303419624, 0.025828237013359154, 0.05650507831679923, 0.003711210813240281, 0.07528804043041808, 0.052048480670366964, 0.07854331896773406, 0.0192055723829461, 0.028951745746391158, 0.11615744632269655, 0.018109626369550824, 0.05379717058635183, 0.043052568566054106, 0.018087526483993446, 0.04823384161240288, 0.04109482879617384, 0.054830209618168216, 0.010049157060815819, 0.03341194302109735, 0.039776699883597236, 0.04715062830863254, 0.024322862969711423, 0.06570985367787735, 0.01729030890523323, 0.009739390557764896, 0.02320450494465019, 0.011540403157206518, 0.05615818068119032, 0.5828043669462204, 12.950127226965767, 39.746579442705425, 48.64858715874808, 50.545698983328684, 31.024957384381974, 27.916039773396083, 33.4250145639692, 34.25104073115757, 20.439984798431396, 6.361648602145059, 1.0846044634069716, 0.12294207726206098, 0.06347557356847183, 1.195298929299627, 3.163992072854723, 4.425591690199716, 6.605479998247964, 8.342815824917384, 6.7143769434520175, 6.3904836262975415, 14.445298790931702, 18.343685490744456, 27.337544918060303, 33.36413444791521, 44.297260420663015, 44.26754297528948, 48.37345239094326, 47.64205721446446, 51.68342481340681, 47.832972867148264, 43.75148984364101, 40.29112018857683, 35.1611088344029, 32.770150320870535, 34.575570242745535, 33.91258702959333, 35.69509874071394, 34.21912070683071, 34.454626423971995, 34.56497771399361, 33.405590874808176, 33.69812740598406, 34.38417863845825, 33.663462843213765, 35.694469928741455, 32.77047341210501, 40.69333750861031, 47.44834838594709, 35.02403824669974, 34.170014313289094, 33.51680721555437, 39.191859585898264, 41.35693563733782, 42.02395575387137, 44.160846437726704, 43.75397035053798, 44.34696088518415, 44.517900466918945, 47.48270027978079, 47.606989656175884, 45.12109790529524, 29.61590439932687, 42.51501274108887, 46.39346940176827, 48.82457460675921, 48.95816414696829, 45.91286597933088, 43.3982503754752, 35.97009801864624, 34.353071553366526, 33.17350019727434, 37.51021834782192, 36.560399600437705, 36.42801209858486, 35.58050904955183, 33.81083066122872, 34.563796520233154, 34.98832450594221, 37.4787951196943, 37.82622241973877, 38.75139243262154, 38.625880173274446, 42.77926662990025, 44.43292052405221, 46.04183496747698, 45.62344571522304, 48.56478493554251, 48.57783017839704, 50.902753012520925, 50.05611848831177, 46.38849449157715, 46.49602828707014, 48.35318102155413, 48.216780935014995, 51.42865521567208, 47.934656279427664, 46.481558663504465, 47.720019476754324, 45.29996885572161, 38.47038991110665, 34.47282028198242, 25.1940621307918, 21.056903191975184, 11.940066729273115, 12.487642969403948, 9.758100475583758, 14.6931505884443, 12.639494981084551, 4.950721774782453, 2.31900492310524, 0.7780949962990624, 0.2224450579711369, 0.47274392417498995, 3.6524252465793063, 13.041859081813268, 32.77935668400356, 44.27852112906319, 37.244640827178955, 42.246979032244, 42.322266238076345, 49.86474425452096, 49.30554975782122, 21.04760476521083, 2.388201815741403, 0.26331504061818123, 0.03970659025279539, 0.07761647405901126, 0.07202246173151902, 0.014474137519885386, 0.05685886986819761, 0.039308130741119385, 0.013246892435875322, 0.05906759974147592, 0.02626482001505792, 0.06115065475127526, 0.026632073701226285, 0.08015222727720227, 0.0154901164849954, 0.05169338633173278, 0.0026838708394539674, 0.03442042926326394, 0.03870923198493464, 0.0257097088199641, 0.02943024524886693, 0.051668755510555844, 0.03487659139292581, 0.05637720839253493, 0.029743049892463853, 0.023046723500426327, 0.18155941473586218, 0.11114294361323118, 0.15200472277190002, 0.1680555229208299, 0.11382194235920906, 0.1010717401014907, 0.11804103239306382, 0.17667404402579578, 0.13019386599106447, 0.21369652955659799, 0.17150286079517432, 0.059569423885217736, 0.1985087716685874, 0.13255393292222703, 0.11135730639632259, 0.07976215785103184, 0.13779277966490813, 0.07824912653969866, 0.16162339092365333, 0.13680207782558032, 0.17525418235787324, 0.14700815374297754, 0.15078392970774854, 0.08875146441693817, 0.11599685065448284, 0.16635925322771072, 1.126095631292888, 15.150043283190046, 45.72458021981375, 55.93375253677368, 57.43870803288051, 35.908950396946494, 34.63124615805489, 39.54901436397007, 32.78339358738491, 23.232886178152903, 8.100795303072248, 2.0270726680755615, 0.41561200842261314, 0.8945626009787832, 3.1037433743476868, 7.811836225645883, 14.996931041990008, 13.311794860022408, 17.87128094264439, 13.58411647592272, 8.372700895581927, 14.292957799775259, 19.653799601963588, 27.355076960154943, 34.54243080956595, 44.54301125662667, 44.95598438807896, 48.511269909994944, 49.72625623430525, 53.938823972429546, 50.54510143824986, 45.627708435058594, 43.087353229522705, 37.11701284136091, 35.1632593018668, 37.42512028557913, 36.539374351501465, 38.118227413722444, 36.258819988795686, 37.80611433301653, 36.655885219573975, 35.39733716419765, 35.821510791778564, 37.03421115875244, 36.62007767813546, 37.93884924479893, 34.769685540880474, 43.00897060121809, 49.17408289228167, 37.45948954990932, 36.1465232031686, 36.13475642885481, 42.31678063528878, 43.736811774117605, 45.93210554122925, 46.696786063058035, 47.60686806270054, 48.89679765701294, 47.93195343017578, 49.33448205675398, 48.01969528198242, 44.350494044167654, 32.96319907052176, 43.8406526020595, 47.69209466661726, 49.32659585135323, 51.7074099949428, 48.32597534997122, 45.81132500512259, 38.476278509412495, 35.73514815739223, 36.23980276925223, 39.25573090144566, 37.97759934834072, 37.68875925881522, 37.40096834727696, 35.13539702551705, 35.84443984712873, 37.07145697729928, 38.91317081451416, 38.58153329576765, 41.33808170046125, 38.69532741819109, 45.58193370274135, 45.10818815231323, 50.430647236960276, 47.29737445286342, 51.42143603733608, 50.578654289245605, 54.59181220190865, 51.034518650599885, 47.15186527797154, 45.93915796279907, 49.28498656409127, 48.43717084612165, 55.84338426589966, 49.76639250346592, 50.97243649618966, 49.11455767495291, 48.87705782481602, 37.32019901275635, 38.4665857723781, 20.614262989589147, 22.242554221834453, 11.218621373176575, 12.5535101549966, 16.314113208225795, 22.341717175074987, 23.521757534572057, 9.148813809667315, 7.943772963115147, 1.6381032828773772, 0.9061579502054623, 0.6274936603648322, 4.931522599288395, 15.496377979006086, 38.69402463095528, 50.65370873042515, 45.17147581917899, 47.148707321711946, 49.45211158479963, 55.87665918895176, 56.70112201145717, 25.9689165524074, 3.938196837902069, 0.42271122176732334, 0.11084841191768646, 0.13859506590025766, 0.24143329049859727, 0.18507008706884726, 0.1775155902973243, 0.18166594473379, 0.09128467312880925, 0.08528072386980057, 0.09769029476280723, 0.09859721109803234, 0.12972051996205533, 0.16277177073061466, 0.08067416319889681, 0.21317517038966927, 0.13622302961136612, 0.14410694156374249, 0.10624902336192982, 0.08326925430446863, 0.17907991207071713, 0.20722049634371484, 0.07306620465325457, 0.17550334041672094, 0.14674887194165162, 0.10038402450403996], [0.04550566943362355, 0.04947556069652949, 0.038821417572242875, 0.041434713772365024, 0.10815553034522704, 0.02926934084721974, 0.02121337955551488, 0.06595373273427997, 0.011385258669698877, 0.024469207706195966, 0.014653703330882957, 0.030172562559268305, 0.04494348959997296, 0.03064737083124263, 0.04149870980264885, 0.04375304062185543, 0.03029981840934072, 0.05255319198061313, 0.06529172004333564, 0.015887256246060133, 0.035792674736252854, 0.003849945355406297, 0.07139871841562645, 0.027819070632436445, 0.039370538999459574, 0.05226146263469543, 0.15383507098470414, 7.386929563113621, 30.281423704964773, 42.0594436781747, 39.44445092337472, 28.64973827770778, 18.80010744503566, 19.26924286569868, 36.17885317121233, 22.214177778788976, 9.430489437920706, 1.6888511883361, 0.269887737929821, 0.036659547327352424, 0.41455954632588793, 2.2572002623762404, 2.7532990361963, 4.0985695123672485, 8.826287116323199, 4.709039977618626, 4.005317739077976, 15.445234026227679, 13.297843745776586, 21.50043797492981, 28.9281838621412, 37.389448234013145, 42.03575726917812, 48.24374689374651, 46.79832703726632, 48.373528821127756, 44.361652851104736, 40.98140982219151, 36.1920200075422, 34.352025849478586, 32.854984351566856, 35.72854042053223, 39.194406100681846, 43.76032795224871, 42.76902151107788, 42.945425851004465, 39.70163154602051, 36.37216247831072, 33.44261087690081, 32.450109345572336, 32.49500165666853, 32.98861558096749, 31.449634756360734, 35.34286676134382, 34.39518805912563, 33.17684922899519, 32.18898909432547, 37.44525269099644, 43.79406493050711, 44.78215435573033, 44.009354863848, 45.30242504392351, 46.65381840297154, 45.04097475324358, 48.65632050377982, 46.56374543053763, 49.90221241542271, 39.170431341443745, 25.074586118970597, 41.12867341722761, 48.847142355782644, 45.570340633392334, 45.565737451825825, 41.35273545128958, 38.02977337156023, 33.3142602784293, 34.12062651770455, 37.293792384011404, 37.54897539956229, 33.3202600479126, 33.128653049468994, 32.19282797404698, 32.34778669902256, 31.90169150488717, 33.06195034299578, 33.107593059539795, 32.848268917628694, 32.43782493046352, 33.6882574898856, 33.380403654915945, 34.877254077366416, 38.78402117320469, 41.488089833940776, 40.308855465480256, 43.96609885351998, 42.25447613852364, 45.48760495867048, 48.274235589163645, 48.89954219545637, 47.29121140071324, 47.88133927753994, 49.359137739454, 50.12413093021938, 46.60175207683018, 46.42912755693708, 40.91456120354788, 35.90519142150879, 26.106468302862986, 24.44138809612819, 14.173430544989449, 11.905752182006836, 13.483567357063293, 9.174264192581177, 15.755848033087593, 13.82308760711125, 3.5033047454697743, 1.46233155471938, 0.6246476130826133, 0.14035555214754172, 0.44323457192097393, 3.096667502607618, 13.606919595173427, 24.16873730931963, 30.20480591910226, 24.74704282624381, 25.014730862208776, 36.85542358670916, 43.43860898699079, 40.88117510931832, 19.042632579803467, 2.5536831532205855, 0.11630221855427537, 0.0580772032429065, 0.007857917275811945, 0.037590999488851855, 0.028701244188206534, 0.03971620848668473, 0.03219064784103206, 0.0029059063693109366, 0.02650986106267997, 0.015485103807545133, 0.01667631953023374, 0.0027281344352689174, 0.05076238539602075, 0.04950360454885023, 0.03500679547765425, 0.04312339744397572, 0.11293857118913106, 0.04513716045767069, 0.03419342537277511, 0.051167355451200686, 0.017533541657030582, 0.053920012566127946, 0.08623833355626889, 0.02837899942616267, 0.01258293489393379, 0.045517289345817905, 0.026559489113943915, 0.027977020014077425, 0.04341821412422827, 0.03179793552096401, 0.018320786467354213, 0.041264679682041915, 0.05804552244288581, 0.019407377179179872, 0.02881529913949115, 0.02221239005614604, 0.04485555485423122, 0.03833873490137713, 0.03173785463773778, 0.0554826074678983, 0.021038583845698407, 0.014929797533633453, 0.03374212155384677, 0.05925974728805678, 0.045104862190783024, 0.021875677231167043, 0.05516317014449409, 0.05353041811447058, 0.021493304088445644, 0.018553305151207105, 0.04352997562714985, 0.3061019932585103, 9.276565994535174, 35.51509870801653, 47.66249534061977, 48.13884646551949, 31.398961544036865, 25.093417474201747, 25.74647692271641, 35.738278320857454, 23.40580599648612, 9.716740454946246, 2.0415868035384586, 0.08224391325243882, 0.08950653818569013, 0.5115245346512113, 2.205920602594103, 4.491064131259918, 6.171230179922921, 8.825456806591578, 9.184200116566249, 7.5903293916157315, 13.104675139699664, 18.34335892541068, 25.406920194625854, 32.18861389160156, 40.66155992235456, 44.293418066842214, 48.113982336861746, 48.99536827632359, 49.535274573734824, 46.46050214767456, 42.61371537617275, 38.94046681267874, 35.04113776343209, 34.91153301511492, 37.67573138645717, 40.34859568732125, 44.0179636819022, 44.526154926845, 44.76070179258074, 39.496294907161165, 37.8972156388419, 34.60591650009155, 35.35051325389317, 33.69319418498448, 35.3042973109654, 33.3596111706325, 37.512768336704795, 36.41063812800816, 35.16061898640224, 34.225367137363975, 38.39070449556623, 44.49185514450073, 46.675965785980225, 47.1068548474993, 46.607553822653635, 49.428154196058, 46.11725418908255, 49.94262661252703, 47.11643641335623, 49.48888145174299, 42.29265996388027, 27.439309971673147, 43.69163111277989, 48.68729209899902, 48.519406250544954, 48.17028706414359, 43.61832414354597, 40.37147263118199, 33.666256019047324, 34.98657703399658, 37.99817991256714, 38.671182428087505, 35.06959063666207, 34.488908835819785, 34.165539673396516, 33.746212414332796, 32.91331100463867, 34.471145766122, 34.502836499895366, 34.63087442943028, 34.768160411289756, 35.06361518587385, 34.927454812186106, 38.224639075142996, 42.789167812892366, 43.781815256391255, 44.163632665361675, 46.50353928974697, 44.310833726610454, 48.37498099463326, 51.07196249280657, 49.01256854193551, 46.97357102802822, 47.87849399021694, 50.88605301720755, 53.15689107349941, 48.500715596335276, 48.52285255704607, 45.21142101287842, 40.179566860198975, 29.483527319771902, 23.732920237949916, 20.767804282052175, 12.022692101342336, 12.223153710365295, 9.070618782724653, 12.168057101113455, 6.893239642892565, 8.343604445457458, 2.7429926863738467, 1.1796715621437346, 0.21180588672203676, 0.42770814363445553, 3.5063576102256775, 14.944315808159963, 28.78316800934928, 33.71551179885864, 30.503877231052943, 31.543355533054896, 42.2571998323713, 49.67055252620152, 47.00920139040266, 24.142231668744767, 3.1231347109590257, 0.13053126074373722, 0.034330961028380055, 0.03656298500884857, 0.021486903806882243, 0.020014662628195116, 0.026168936231572713, 0.02113807573914528, 0.04700689423563225, 0.049774071999958584, 0.028892954079700366, 0.014036159280554523, 0.011776236484625509, 0.09303409925528935, 0.05624833084376795, 0.06790505017020873, 0.038599899637379816, 0.04779444947572691, 0.054500882646867206, 0.02202675474940666, 0.07620626115905386, 0.022048340644687414, 0.04470950019146715, 0.09328108600207738, 0.04390087643904345, 0.004973251597091023, 0.09214453306049109, 0.15920942117060932, 0.0916133758478931, 0.13472135019089493, 0.1491606296705348, 0.11197547893971205, 0.22056491885866436, 0.22219743340143136, 0.054753002511071305, 0.13123568865869725, 0.10001689634685006, 0.14221510450754846, 0.1830562629870006, 0.1323856698083026, 0.2145047461880105, 0.1512422122593437, 0.1297915354371071, 0.11974210611411504, 0.14724075554737023, 0.10715957664485488, 0.13516169227659702, 0.07788732488240514, 0.11602541697876793, 0.08255135068403822, 0.21638621522911958, 0.1606628160391535, 0.6556027063301632, 11.150083473750524, 41.25007234300886, 53.760887554713655, 51.89672408785139, 38.10244458062308, 29.714054652622767, 28.301209688186646, 46.16511685507638, 29.34517478942871, 12.443905796323504, 2.27395475762231, 0.7574155288083213, 0.24381798825093678, 1.45919292313712, 4.0387641957827976, 9.697464415005275, 12.664142847061157, 16.991795335497173, 12.479350294385638, 7.672541345868792, 20.554435525621685, 17.300965854099818, 27.275424548557826, 30.123376505715505, 42.47774607794625, 43.37348352159773, 49.4405254636492, 48.88350575310843, 51.130799838474815, 49.479470116751536, 46.16910859516689, 40.401843207223074, 37.24738189152309, 37.5672595841544, 39.525664942605154, 43.19691937310355, 48.2074043410165, 46.29801157542637, 48.40713725771223, 42.54387903213501, 41.03172172818865, 36.61507497514997, 37.93324204853603, 34.598756381443565, 37.23416641780308, 34.27347993850708, 38.50639547620501, 37.387030260903494, 37.28337008612496, 35.812985352107454, 40.890259878976, 47.33561386380877, 48.26690871374947, 48.71801355906895, 49.172675882067, 51.49555594580514, 50.23766449519566, 51.131522451128276, 47.27757903507778, 47.74337584631783, 41.72479064123971, 32.145469052451, 43.491175583430696, 50.86856092725481, 51.17795031411307, 51.23262916292463, 45.04887138094221, 41.857275417872835, 36.68155881336757, 36.995898791721885, 39.68097455160958, 40.32183470044817, 36.07629428591047, 36.84396948133196, 34.425367559705464, 34.70903124128069, 34.61220114571707, 35.7347069467817, 37.37437759126936, 36.619261264801025, 36.76735864366804, 36.80037995747158, 37.10058382579258, 38.416312081473215, 44.39176286969866, 45.62779528754098, 45.45122766494751, 50.55338716506958, 47.33215018681118, 50.720060552869526, 52.61837094170706, 50.684850556509836, 48.26139531816755, 48.44280236107962, 52.057366439274375, 54.84235034670149, 48.843362535749165, 51.806894302368164, 44.55254765919277, 40.785953521728516, 28.484365940093994, 29.75339535304478, 17.56110119819641, 14.521117533956255, 24.239245891571045, 13.533956561769758, 22.0921847820282, 23.276962075914653, 12.045455268451146, 5.7486068691526135, 1.523210802248546, 0.42768819470490727, 0.831917262503079, 4.167301527091435, 17.62703091757638, 34.1717791557312, 40.173358644757954, 33.906062671116416, 36.396321364811485, 49.51583351407732, 58.38801956176758, 52.34290266036987, 29.468091896602086, 4.426469334534236, 0.20057667499142035, 0.10081966434206281, 0.15559143173907483, 0.10305520652660302, 0.12557862007192203, 0.1074553636301841, 0.11053681506642274, 0.08590486073600394, 0.20772232727280684, 0.09394916479608842, 0.09575837664306164, 0.08383698455457177, 0.17324959992298058, 0.10684225974338395, 0.16426814400724002, 0.1095916022147451, 0.25128002784081865, 0.13407185647104466, 0.11236333634172167, 0.23151272854634694, 0.18506923211472376, 0.11264890458967004, 0.18889265480850423, 0.10034142607556922, 0.10578382653849465], [0.017573751642235687, 0.01932776466544185, 0.024550297729937092, 0.029594067351094315, 0.05970804858952761, 0.004720665664145989, 0.04099682119808026, 0.0765654029590743, 0.04165689667154636, 0.01017719237799091, 0.04727366367088897, 0.023696156152124916, 0.06699427975607769, 0.04612937882276518, 0.044441061560064554, 0.025947343657857606, 0.03851623287690537, 0.003709973759084408, 0.0746635982234563, 0.04038732372490423, 0.03317834037755217, 0.03511480128924761, 0.02869612124881574, 0.029556890417422568, 0.053833730053156614, 0.06286647303828172, 0.17827027051576547, 5.242093614169529, 28.43774700164795, 40.79342630931309, 39.709500380924766, 27.233629396983556, 18.16832685470581, 27.695288555962698, 29.62724038532802, 31.003157411302837, 9.320169414792742, 2.7210732911314284, 0.2614549861422607, 0.19342250031019959, 0.2229796214295285, 1.3336555851357323, 2.823965907096863, 4.226485414164407, 4.483653008937836, 6.56911312682288, 7.133811465331486, 8.313741087913513, 13.984741789954048, 19.610682555607386, 26.24648666381836, 35.49976750782558, 41.23626627240862, 43.32350165503365, 48.586904525756836, 49.01274224690029, 44.281790256500244, 41.1848634992327, 37.59324932098389, 32.87622846875872, 34.090266363961355, 36.352658884865896, 42.65281983784267, 47.27281257084438, 46.128020422799246, 47.15726055417742, 45.21336650848389, 42.12847055707659, 40.649153913770405, 35.01414748600551, 32.3428395816258, 32.72486891065325, 33.73877436774117, 33.66302163260323, 32.435615403311594, 33.35279498781477, 34.48205096381051, 40.3093592098781, 47.10831049510411, 47.09033203125, 46.412191322871614, 45.24491827828543, 50.080906186785015, 40.604879992348806, 39.709173815590994, 49.5357574735369, 39.31322724478585, 36.07510266985212, 24.949171134403773, 39.47375495093209, 48.82086426871163, 44.52959428514753, 43.181310244968955, 38.66858032771519, 33.95300817489624, 31.689618587493896, 33.488913672310964, 33.665595940181184, 32.401246138981406, 34.28965534482683, 32.89586755207607, 33.45658023016793, 36.19122443880354, 33.144439356667654, 34.684226172310964, 35.84589202063424, 33.239369119916645, 33.35339253289359, 31.824472699846538, 33.37468876157488, 33.485887731824604, 34.10713659014021, 35.01688160215105, 36.77618980407715, 40.91717372621809, 38.78033515385219, 43.09403044836861, 45.07091106687273, 48.6182895387922, 45.83161721910749, 47.814827646527974, 49.15232808249337, 52.1403591973441, 47.35604851586478, 45.51989671162197, 39.66679327828543, 35.83285025187901, 29.231828825814382, 19.1715372971126, 21.464857986995153, 12.739163415772573, 9.330644692693438, 9.794809545789446, 13.142177173069545, 3.3384302897112708, 5.402727280344282, 2.1747498980590274, 0.7492016724177769, 0.4061533116868564, 0.40010753752929823, 4.167036192757743, 14.278508152280535, 27.792870794023784, 35.8255546433585, 28.281792947224208, 28.867369753973826, 37.00424010413033, 46.61989034925188, 39.13398109163557, 16.9559200491224, 1.9970851114818027, 0.04034176688375218, 0.0034332345239818096, 0.0492492896238608, 0.01966612463417862, 0.020794200977044444, 0.03895084473437496, 0.028438352580581392, 0.024148672852399092, 0.07120699834610734, 0.01902894293224173, 0.0074274309112557346, 0.05352429772860237, 0.0063366540624493995, 0.011688876797312071, 0.02700662163884512, 0.05224984272250107, 0.01780452479475311, 0.014965876936912537, 0.021027489798143506, 0.027884535691035644, 0.01313392907780196, 0.03533317421429923, 0.005184872250538319, 0.05589224584400654, 0.08206102092351232, 0.007657132826612464, 0.034484510110425096, 0.05573705131454127, 0.004085762567618596, 0.030898656097373793, 0.06571117682116372, 0.028277572011575103, 0.048697114789060185, 0.05855816922017506, 0.06983434235943214, 0.043801097864551206, 0.020967814339590923, 0.051283232269010375, 0.034063533414155245, 0.05777726362326315, 0.02008674679590123, 0.07080125476100615, 0.019878930179402232, 0.04898834201906409, 0.0711246852629951, 0.07341341102229697, 0.03975218780604856, 0.016695666259952953, 0.015206370103572096, 0.05158933977197323, 0.032583726570010185, 0.1562024796647685, 6.841558507510594, 32.007130418504985, 46.914004121507915, 44.39642858505249, 32.11902073451451, 20.955843380519322, 31.361632347106934, 39.65591934749058, 34.5878963470459, 10.657774073737007, 3.3417265585490634, 0.11250286349760634, 0.35856721656663076, 0.5969762493457113, 1.7224918689046587, 2.983064889907837, 5.558966645172664, 6.669891970498221, 6.777301566941397, 7.660483615739005, 7.845878924642291, 14.108772345951625, 21.117746829986572, 29.116141319274902, 35.13577570234026, 43.75724990027291, 45.65304504122053, 48.873503821236746, 49.77424396787371, 46.434272697993684, 42.150600569588796, 39.275578430720735, 34.25300012316023, 35.624498094831196, 38.50318193435669, 44.702660015651155, 48.78288541521345, 48.30474165507725, 48.81381532124111, 47.88891281400408, 44.138876233782085, 40.18348911830357, 36.00858061654227, 33.80544580732073, 34.79222897120884, 35.65278768539429, 35.78238895961216, 34.764866965157644, 34.82492024557931, 34.95073822566441, 41.685703550066265, 49.05907283510481, 49.110531193869456, 49.05797501972744, 46.53447266987392, 51.0725530896868, 42.169430187770296, 40.80300440107073, 49.32880537850516, 42.9181159564427, 40.04926381792341, 27.2718323298863, 40.35798617771694, 50.03498206819807, 46.04792158944266, 44.456665992736816, 41.066702433994834, 36.26017141342163, 33.527563026973176, 36.772781712668284, 36.36466189793178, 34.65235478537423, 35.695772715977256, 35.36130033220564, 34.90099607195173, 37.02748530251639, 35.26189940316336, 36.328347137996126, 36.62857185091291, 34.32718256541661, 33.894889967782156, 32.9739270891462, 34.89276940482003, 34.39546946116856, 36.53866216114589, 38.49231147766113, 39.04931729180472, 43.025694915226524, 42.19982508250645, 44.2629154750279, 47.2100008555821, 49.26316227231707, 47.571859564099995, 47.93371132441929, 49.20253229141235, 53.52968277250017, 49.83672216960362, 48.13756799697876, 42.409365381513325, 39.30208233424595, 30.81174843651908, 22.17048576899937, 20.787771667752946, 12.139656339372907, 14.104625139917646, 12.769780652863638, 9.922355890274048, 6.635362029075623, 3.9108187641416277, 1.5336595901421137, 0.12172292625265461, 0.35600615399224417, 0.6939993745514325, 4.353800296783447, 16.521171263286046, 31.060150010245188, 40.60486957005092, 31.942678928375244, 31.13573251451765, 42.26836558750698, 53.456229891095845, 45.23494413920811, 21.703210728509085, 2.6903309864657263, 0.027913593953209262, 0.051276253536343575, 0.054519138631543944, 0.02810768210994346, 0.01855087260316525, 0.023234221385791898, 0.02372524494837437, 0.025326663927574242, 0.040206338079380136, 0.021546474092506936, 0.04289966069960168, 0.012708876082407576, 0.055100215665463886, 0.03995888653610434, 0.009233889602390783, 0.046566806600562165, 0.024648062751761506, 0.051646662410348654, 0.04090211128017732, 0.07001960956092391, 0.05783124786934682, 0.06887824580605541, 0.03829764960599797, 0.013409159844741225, 0.05359268727313195, 0.0709435096276658, 0.14529802836477757, 0.12331284236695085, 0.17681944050959178, 0.0849449440304722, 0.1682305849556412, 0.11566761189273425, 0.16620295947151525, 0.22258023571755203, 0.1398649306169578, 0.08827207264091287, 0.11925772710570268, 0.196996059268713, 0.1518105531909636, 0.16647355923695223, 0.1518337998007025, 0.1563704035111836, 0.13002586072044714, 0.21346235355096205, 0.177986955004079, 0.1219274095658745, 0.14280579638268265, 0.08867736839290176, 0.15749431534537248, 0.14623945499105112, 0.1319802858467613, 0.4297394874904837, 8.864041021892003, 37.47659254074097, 53.12180267061506, 51.19823210580008, 36.99435976573399, 26.648721354348318, 37.103363105228965, 36.96717493874686, 38.70776816776821, 13.24784971986498, 3.8376755118370056, 0.5827332021934646, 0.5868752513613019, 1.388158774801663, 4.559044872011457, 8.314759867531912, 13.846596837043762, 12.676620943205696, 13.30033814907074, 14.096334201948983, 13.365243009158544, 22.704183850969585, 28.219736848558696, 30.949364457811626, 36.2799459866115, 45.61204719543457, 46.725839955466135, 48.01438685825893, 52.64250898361206, 49.09644719532558, 45.55809790747506, 41.03049189703805, 35.9688195501055, 39.15522868292672, 41.764562129974365, 47.78432158061436, 51.29932492119925, 49.3955671446664, 51.922849314553396, 52.16275324140276, 46.621384211948936, 44.030366216387065, 39.96601745060512, 36.21099206379482, 37.08407143184117, 38.245553152901785, 36.868232590811594, 37.53777142933437, 37.0722872870309, 36.625962802342, 43.91984816959926, 51.49318661008562, 51.20046942574637, 49.193221705300466, 46.83704587391445, 52.538237367357524, 41.8058101109096, 41.56796979904175, 50.7063239642552, 41.12298631668091, 42.32511152539934, 32.97097063064575, 41.68030827386038, 51.39114536557879, 48.529262270246235, 47.80041708265032, 43.01044014522007, 37.889854022434776, 35.00957209723336, 37.9391827583313, 37.708436557224815, 35.882950237819124, 38.337311063494, 37.81463977268764, 37.06998743329729, 39.013204029628206, 36.40219259262085, 39.62556266784668, 38.847531182425364, 37.21658400126866, 37.237953186035156, 35.25969682421003, 37.187075001852854, 36.995144912174766, 38.81309938430786, 39.834046840667725, 40.18761287416731, 46.48205893380301, 42.88616119112287, 47.38961526325771, 50.5576742036002, 51.389008794512065, 46.970343589782715, 48.02695614950997, 50.28807020187378, 54.053594316755024, 51.147395610809326, 50.11608839035034, 44.51461744308472, 39.25842332839966, 33.35014425005232, 24.959155695778982, 28.931102105549403, 17.60989144870213, 19.393778903143748, 16.97331312724522, 25.292344399860927, 11.887497527258736, 12.60050082206726, 3.973788550921849, 1.692785388657025, 0.7142498450619834, 1.1657165395362037, 5.628136830670493, 19.16411314691816, 37.09015457970755, 44.84492785590035, 39.76532220840454, 38.7861716406686, 50.132211685180664, 60.58144078935896, 50.93991545268467, 25.430787256785802, 4.105469507830484, 0.1216558598514114, 0.14723023825458117, 0.1742682031222752, 0.08610308117100171, 0.09513060961450849, 0.18960302669022763, 0.07958518234746796, 0.1509574989655188, 0.15977890204106057, 0.07343231500791651, 0.17004075353699072, 0.10534142170633588, 0.08067825476505927, 0.17137638186769827, 0.15012104170663015, 0.1469598827617509, 0.09370411865945373, 0.16751064573015484, 0.12642387114465237, 0.12793909412409576, 0.11552634090185165, 0.1281417046806642, 0.20250508508511952, 0.19298750508044446, 0.13018237160784857], [0.022788369595738392, 0.012903521486025835, 0.018545157641970685, 0.020047898969746063, 0.01963321229309908, 0.017467635550669262, 0.03302164289302059, 0.007400338704298649, 0.03943944423060332, 0.023850578848006468, 0.036163232887962034, 0.005210655733078186, 0.01767112989909947, 0.07789869712931768, 0.03338568371587566, 0.01625515623683376, 0.022820959632684077, 0.02043752565181681, 0.03250067727640271, 0.04287827666848898, 0.022175038399706994, 0.022755989904648492, 0.027176201110705733, 0.05117238339568887, 0.0215904703031161, 0.02811902721545526, 0.04003762713234339, 4.376670292445591, 20.968707970210485, 41.68034648895264, 39.78221327917916, 35.78840609959194, 25.446439811161586, 19.39182472229004, 21.054782254355295, 35.09574365615845, 16.761601516178676, 3.62746992281505, 0.31907064308013233, 0.4245041827005999, 0.09712502759482179, 1.2539320630686623, 1.8357868066855838, 3.1454188866274695, 4.2285967980112344, 7.510928852217538, 8.124374883515493, 6.613122148173196, 8.592950974191938, 15.044534887586321, 22.08615721975054, 28.028810773577007, 38.249360765729634, 41.987797328404014, 46.38485710961478, 49.02721187046596, 44.93112025942121, 41.100352559770855, 36.34637771333967, 31.481308119637625, 32.5586645262582, 36.46883623940604, 44.008291789463584, 46.8532212802342, 48.13593864440918, 46.834256172180176, 46.55937153952462, 43.727421283721924, 43.06963879721505, 41.655194010053364, 36.261495045253206, 33.39926106589181, 33.199774810246055, 34.327943393162315, 33.49028246743338, 32.29119709559849, 32.945126805986675, 40.955159527914866, 47.677378382001606, 46.59334823063442, 45.02891615458897, 47.03270714623587, 46.277399744306294, 47.633649894169395, 44.82171392440796, 42.02313586643764, 39.29535647800991, 48.405716351100374, 27.20481869152614, 41.556088379451204, 48.81915153775896, 40.656116008758545, 40.66306420734951, 34.80505534580776, 33.00926215308053, 31.580531869615825, 32.95050471169608, 32.607468673161094, 34.92742007119315, 34.39210305895124, 33.831689153398784, 31.46429545538766, 34.20689535140991, 34.42123685564314, 36.317448888506206, 37.91070556640625, 35.250379289899556, 32.827208927699495, 31.210210255214147, 31.097218649727957, 33.330178601401194, 33.94293328693935, 35.02538619722639, 34.54448747634888, 34.885133334568565, 38.75754506247384, 42.121400765010286, 43.67606714793614, 46.55864545277187, 48.03603744506836, 47.6409524508885, 48.04653269904, 48.392598152160645, 48.8002941267831, 45.17136812210083, 39.784186567579, 35.21398115158081, 24.850713423320226, 16.945473432540894, 18.940197025026592, 9.12655178138188, 10.522378870419093, 8.479193329811096, 7.3181814806801935, 4.823447712830134, 4.350061731679099, 2.21927330323628, 1.0123142110449928, 0.24854507031185286, 0.9933801527534212, 3.909768717629569, 15.816575288772583, 25.83942471231733, 29.680474008832658, 32.62157351630074, 33.07337665557861, 43.594172205243794, 51.30190965107509, 38.94484765189034, 17.126937798091344, 2.397697831903185, 0.12649617583623954, 0.08424783750836339, 0.03873800186972533, 0.053196701021598916, 0.01658396073617041, 0.03200088534504175, 0.019315992082868303, 0.024369805718639066, 0.013066900844153548, 0.03779313846358231, 0.05438100925779768, 0.03199577936902642, 0.023769397222037827, 0.040388806323919973, 0.043227912192898135, 0.05833132817809071, 0.044378429385168214, 0.014092079047778887, 0.0554782885925046, 0.016633855112429177, 0.035250230093619654, 0.044077366790069, 0.02973422215187124, 0.040838376485875676, 0.06047748015927417, 0.056353137362748384, 0.036095416705523214, 0.01620393871728863, 0.03764572673078094, 0.046542321664414237, 0.061364210077694485, 0.027941853240398423, 0.08882752819252865, 0.02273115891564105, 0.008980958040670624, 0.021852934433679496, 0.03574845800176263, 0.030629844271710942, 0.015969710125188743, 0.046621211538357396, 0.017931821356926645, 0.013557954940811863, 0.016963080303477387, 0.06345150593136038, 0.059532565863004754, 0.026919918434162225, 0.057543949357100894, 0.03571444643395288, 0.015219006121956875, 0.032109227031469345, 0.02980135301394122, 0.2171459166066987, 4.9881473779678345, 25.82977887562343, 47.01958894729614, 45.71903555733817, 37.14529895782471, 26.866873945508683, 22.093006406511577, 23.40439898627145, 40.534425258636475, 17.055166380746023, 4.486122225012098, 0.5718333785023008, 0.10297385017786707, 0.3944274123225893, 1.2446105118308748, 2.6869454767022813, 5.28262506212507, 6.484051542622702, 8.880743622779846, 5.891411892005375, 7.492431879043579, 12.275880983897618, 18.208034072603496, 25.61191984585353, 31.677636419023784, 40.721168518066406, 44.20987640108381, 47.09022086007254, 49.6752529825483, 46.77749981198992, 42.89120558329991, 38.68150397709438, 33.85790818078177, 33.74471507753645, 38.506513595581055, 45.72349977493286, 48.99341235842024, 49.19995103563581, 47.083835465567454, 47.4402711050851, 46.29570129939488, 46.47235924857003, 42.71991164343697, 36.943599700927734, 34.84527151925223, 34.19827611105782, 35.918976647513254, 35.433210713522776, 33.69130080086844, 35.53759002685547, 41.7555433682033, 49.16203819002424, 48.62957688740322, 46.863667896815706, 46.68147223336356, 47.17286968231201, 46.8755910055978, 43.10506418773106, 43.881775515420095, 40.266648633139475, 47.368325982775005, 29.777995450156077, 41.409342425210134, 50.361811433519634, 43.10779135567801, 43.621638434273855, 37.8710070337568, 35.56127643585205, 33.73647798810686, 33.832401343754356, 34.501676150730674, 35.53620386123657, 34.534572396959575, 34.41744661331177, 33.82985830307007, 36.21166256495884, 34.93547303336007, 37.584362574986045, 37.798912525177, 36.805212429591585, 34.69519737788609, 32.898667676108225, 32.70070307595389, 34.937838894980295, 35.536763191223145, 36.06237357003348, 35.82161848885672, 36.81420339856829, 41.03151328223092, 43.578368527548655, 47.406641823904856, 48.351308482033865, 49.13641323362078, 47.922997202192036, 48.58795370374407, 50.66538517815726, 52.0347500528608, 46.56512117385864, 41.115763664245605, 35.079147883823936, 29.336291517530167, 18.69250590460641, 14.459890007972717, 10.272655401911054, 14.07445866721017, 11.94814314161028, 6.761064061096736, 4.3875055738857816, 4.184509175164359, 3.6229959343160902, 0.3783925441758973, 0.025253767214183296, 0.9239215084484645, 5.233754907335554, 16.181670120784215, 32.00490699495588, 37.203934805733816, 37.712886878422324, 36.86633573259626, 47.89297751017979, 57.94442571912493, 45.15643644332886, 19.848107712609426, 2.7349920528275624, 0.05065846436523965, 0.05041219008022121, 0.03391976202172892, 0.04024366429075599, 0.020007573633587787, 0.03056945126237614, 0.03761857175933463, 0.038644143513270786, 0.020716742811990634, 0.04433019233069249, 0.06588637456297874, 0.0032136919741917935, 0.013176180605244423, 0.012089271830128772, 0.040713651571422815, 0.01991890776636345, 0.04133730667776295, 0.03773666060130511, 0.021211121730240326, 0.04990093090704509, 0.06700441028390612, 0.027289609757385085, 0.056827657257339785, 0.047569443870868, 0.0531037349386939, 0.12914744285600527, 0.08584346010216645, 0.0964953742389168, 0.06495945501540389, 0.14893061986991338, 0.16547343933156558, 0.12321855314075947, 0.18263979176325457, 0.11870556244892733, 0.0811779550941927, 0.14605026585715158, 0.15977730069841656, 0.12531996252281324, 0.17725561639027937, 0.1580018459686211, 0.04969096163819943, 0.20036210864782333, 0.08642636918063674, 0.16620168382568018, 0.1371300680828946, 0.09880218974181584, 0.08973188645073346, 0.14274972224874155, 0.13687025702425412, 0.14491005561181478, 0.14795793992068085, 0.27935313859156197, 6.9066349012511115, 28.899150814328873, 54.214994021824424, 52.059013162340435, 47.04760408401489, 35.635924407414024, 28.309617008481705, 28.211590085710796, 43.537669454302105, 21.122072083609446, 5.231046412672315, 0.8059294798544475, 1.1130709073373248, 1.0959146107946123, 4.240805651460375, 8.125431878226143, 7.952553749084473, 12.906608922140938, 14.259391052382332, 14.307320594787598, 9.74265810421535, 12.694006204605103, 21.224954060145787, 26.18252154758998, 31.91451093128749, 41.124671254839214, 48.49202339989798, 48.676539761679514, 51.84900385992867, 49.224450383867534, 45.636654240744456, 41.081008774893625, 35.32675041471209, 36.655874797276084, 40.135379791259766, 47.855311325618196, 50.93875510351998, 50.43417344774519, 47.04250063214983, 50.2024371283395, 48.55427231107439, 49.154839856284006, 45.51386220114571, 40.37575966971261, 37.17358160018921, 36.53843634469168, 36.79006883076259, 39.03229420525687, 35.558372088841026, 36.647061007363455, 43.24332291739327, 51.36387021200997, 49.964575971875874, 46.71120704923357, 46.686408928462434, 46.84997647149222, 46.67860262734549, 44.27809728894915, 45.322835377284456, 42.35737201145717, 48.54143898827689, 31.934622492109025, 44.96620866230556, 53.240238189697266, 46.17917306082589, 45.41104623249599, 39.34834344046456, 36.85724401473999, 36.50078405652727, 35.91046510423933, 35.424153736659456, 38.17056471960885, 36.900447913578574, 36.566823210035054, 34.509996618543354, 38.691127232142854, 37.593086038317, 40.1733968598502, 40.47123834065029, 39.364623069763184, 36.16245542253767, 34.12284994125366, 33.661197730473106, 37.276050158909385, 37.72173540932791, 38.67084544045584, 36.948609352111816, 37.802789619990754, 43.04207876750401, 46.570474760872976, 48.710377488817485, 50.895394870213096, 49.934681347438264, 48.854465757097515, 48.58903414862496, 50.89052070890154, 51.75584936141968, 49.45270912987845, 44.23041180201939, 40.57248401641846, 27.558952740260533, 22.588199308940343, 24.955457517078944, 14.405273692948477, 19.4096086365836, 12.71619267123086, 15.889154434204102, 11.138604181153433, 10.85809324468885, 3.651552813393729, 3.2135542247976576, 0.3507174892084939, 1.5221159181424548, 6.472534034933362, 19.843221391950333, 35.09136976514544, 41.662413188389365, 44.01356199809483, 43.69494192940848, 55.50197410583496, 65.381409236363, 52.03292267663138, 24.75571938923427, 3.9756788952010016, 0.3186494628233569, 0.21461651447628224, 0.13003709726035595, 0.19073972212416784, 0.1811970363238028, 0.17231176953230584, 0.16374751765813145, 0.10928874489452158, 0.11221766165856804, 0.06208723663751568, 0.164126167339938, 0.11708458300147738, 0.07670471976910319, 0.12366010301879474, 0.0974570212087461, 0.12653236889413425, 0.17469509664390767, 0.12260274189923491, 0.16620191452758654, 0.11276241671293974, 0.1445333193987608, 0.14819656711603912, 0.09918625413307122, 0.17071187895323547, 0.10993462880807263], [0.04745814037908401, 0.010212008857966533, 0.012527194938489368, 0.022255305699738007, 0.019495734312970723, 0.05139152645798666, 0.015768158083249415, 0.028395582822018435, 0.06392346774893147, 0.06394824784781251, 0.022299702246008173, 0.04595067984025393, 0.012491551493959767, 0.036773157838199816, 0.0786258288260017, 0.011466901699480201, 0.07568600121885538, 0.04789315935756479, 0.023180053935253193, 0.045239354616829326, 0.012375815472166454, 0.024444144318944643, 0.036413228937557766, 0.05697598161974123, 0.07136473738189254, 0.06610783482236521, 0.052087360726935525, 2.934989652463368, 16.788162742342266, 39.286692074366975, 46.27709402356829, 38.81248446873256, 32.20819044113159, 32.84377690723964, 42.17524235589163, 32.43650129863194, 18.644578967775615, 5.464358236108508, 0.8861592433282307, 0.31830894680959837, 0.2733780135001455, 0.6204750026975359, 2.4361780413559506, 5.501067306314196, 5.441171228885651, 4.233443600790841, 1.9677585022790092, 4.4785643219947815, 6.598517903259822, 12.725899304662432, 21.66147289957319, 25.775381428854807, 36.30466767719814, 44.55004630770002, 47.521016120910645, 48.57918160302298, 45.249851499285015, 39.999455656324116, 40.10824360166277, 34.485966273716514, 32.605755942208425, 33.601721150534495, 39.34426832199097, 44.65905659539359, 46.178134305136545, 47.99285439082554, 45.63935708999634, 48.34033727645874, 44.340342726026265, 42.79257937840053, 42.675710678100586, 36.5821578843253, 32.90893016542707, 33.81424570083618, 33.412500858306885, 32.769361700330464, 30.488264628819056, 37.04108987535749, 44.086320059640066, 47.6969062941415, 47.24055903298514, 48.92453486578805, 47.246183599744526, 48.654003279549734, 49.05330583027431, 50.335769585200715, 45.29955196380615, 49.93282617841448, 32.270415033612935, 40.002874170030864, 49.40772301810128, 40.37963329042707, 38.19227089200701, 32.74768679482596, 33.25427300589425, 32.33084699085781, 33.162129470280235, 33.77628769193377, 34.31953954696655, 33.166812556130544, 34.07025555201939, 33.410492828914094, 32.988775389535085, 34.86941303525652, 38.8256756237575, 40.834771565028596, 40.63810280391148, 37.63170065198626, 34.69111878531319, 32.84925556182861, 33.8429765020098, 33.550936767033164, 33.983642782483784, 35.72879750388009, 36.05140583855765, 39.24485697065081, 40.89738525663103, 43.87559856687273, 46.60040412630354, 48.14611428124564, 47.184403691973, 49.33639281136649, 50.58209364754813, 49.04937662397112, 42.24079860959734, 35.64550249917166, 30.927352564675466, 30.10305997303554, 19.168026719774517, 9.582960707800728, 7.493059822491237, 17.440230335508073, 19.554629700524465, 3.259866791112082, 3.910615963595254, 2.3206963751997267, 2.183234517063413, 0.07652210563953434, 0.03527613316795655, 0.9458489375455039, 5.425414017268589, 15.712024007524763, 30.118950503213064, 27.67497202328273, 29.57587582724435, 38.9458794593811, 40.13411521911621, 47.47038459777832, 41.78787681034633, 18.72168139048985, 1.7897978744336536, 0.016603410942479968, 0.020534476431618844, 0.0107561769795471, 0.07788864802569151, 0.0372589312360755, 0.024402144697627852, 0.030488943082413504, 0.018838552791359167, 0.015300384523080928, 0.038979400880634785, 0.013163045863620937, 0.04077449241386993, 0.029569782582776885, 0.03175609026636396, 0.06448802245514733, 0.03499692279313292, 0.04167726968548127, 0.056193725738142214, 0.03534910282386201, 0.07605108020028897, 0.02620070693748338, 0.03768542102937188, 0.029480314347893, 0.029195160006306002, 0.003525516770813348, 0.04368662561423012, 0.011479613204885806, 0.078916560725442, 0.08303273735301835, 0.028454116645402143, 0.03441396282453622, 0.029477681632020643, 0.036701379011252096, 0.05452525901741215, 0.022922873896147524, 0.038638097766254625, 0.019192692091954604, 0.062363081478646824, 0.02237841739718403, 0.036382728788469515, 0.020266226093683923, 0.04429156333208084, 0.041849872030849965, 0.04236723801919392, 0.025455509245927845, 0.02248595162693943, 0.024209603600736176, 0.06785152732793774, 0.05886650910334928, 0.015427421545609832, 0.045272093931479115, 0.027854754789067165, 4.084439047745295, 20.07959042276655, 45.90836354664394, 51.17127309526716, 43.494767802102224, 34.276234899248394, 33.90220989499773, 40.910402706691194, 34.72442497525896, 23.086364303316387, 5.94380304643086, 0.9357269321169172, 0.2526668719947338, 0.10792107614023344, 1.0653090987886702, 2.822582347052438, 6.096747662339892, 6.229677992207663, 8.438677515302386, 4.464042586939676, 5.76299615417208, 9.290781140327454, 15.15379183632987, 23.975994280406407, 29.563428129468644, 38.10031843185425, 46.77133328574044, 47.373453753335134, 51.328983306884766, 47.37280062266758, 43.10954924992153, 41.06460060392107, 35.527122565678184, 33.95324093954903, 35.80069746289934, 42.52694974626814, 46.492981501988, 48.52485016414097, 48.4329046521868, 47.89576373781477, 48.76171425410679, 46.24162694386074, 45.14567715781075, 42.60920252118792, 38.028265612465994, 34.64473955971854, 35.67891638619559, 35.18625783920288, 34.49789980479649, 32.3697395324707, 38.82108633858817, 46.71669612612043, 49.53555597577776, 48.80875008446829, 49.31318235397339, 48.54479496819632, 49.72551277705601, 49.11429016930716, 50.1294914654323, 46.22469765799386, 49.52700274331229, 32.914151736668174, 41.70900433404105, 50.75967918123518, 42.29802049909319, 40.959529944828574, 35.1244466645377, 35.56227697644915, 34.47812870570591, 34.97749573843819, 34.91893284661429, 35.492909635816304, 33.7721917288644, 35.58739471435547, 34.47695098604475, 34.407350880759104, 36.46520233154297, 40.02163430622646, 42.70028993061611, 42.40035356794085, 38.40156800406319, 35.80301816122872, 34.89436749049595, 35.46848324366978, 35.236590589795796, 35.13948604038784, 36.42488193511963, 37.68996129717146, 41.28377458027431, 43.17185027258736, 46.12606450489589, 47.721711363111226, 49.59394863673619, 47.57271419252668, 49.301662240709575, 50.89290394101824, 50.44148990086147, 46.572413308279856, 39.69665316173008, 34.20391804831368, 27.00274075780596, 15.162336383547101, 16.306093250002178, 9.59189782823835, 9.041825447763715, 11.90748575755528, 6.766259576593127, 7.558558753558567, 2.000516435929707, 3.619307743651526, 0.25187181894268307, 0.07419955490955285, 1.2126681229897907, 5.840079469340188, 19.122364895684377, 33.20983580180577, 31.629336016518728, 33.64627647399902, 43.56252316066197, 47.00557790483747, 55.00507715770176, 47.90336159297398, 21.773981605257305, 2.5234699973038266, 0.03897078687857304, 0.03983774767922504, 0.045977047711078606, 0.07219083341104643, 0.012574718683026731, 0.020351104039166654, 0.051447800759758265, 0.020263420351381813, 0.0483637573197484, 0.06741776703191654, 0.05865758817110743, 0.041459130855011087, 0.060569021318640025, 0.06234585347452334, 0.026603773701936007, 0.011793012414792818, 0.06611483051840748, 0.04732873357300248, 0.023123723654342548, 0.029681642473276173, 0.034647531541330476, 0.01992630210172917, 0.015782454816092337, 0.047296401379363875, 0.030679998187614337, 0.1977290263665574, 0.10767574501889092, 0.11233431539897408, 0.1585679477346795, 0.07220156783504145, 0.10381562715130192, 0.16567868260400637, 0.20470547915569373, 0.15380616539290973, 0.11260330703641687, 0.18640372050659998, 0.07582188464168992, 0.10783136024006776, 0.1338100912315505, 0.14519561028906278, 0.1483545164976801, 0.10351950089846339, 0.1407612075230905, 0.09460844977625779, 0.0842863307999713, 0.07449505012482405, 0.14263587764331273, 0.18440577414418968, 0.2119616919330188, 0.11472690451358046, 0.1279720166432006, 0.1695710580263819, 4.5828011972563605, 24.707200118473597, 51.40211657115391, 58.40325696127755, 50.283470494406565, 43.73928880691528, 44.076995577131, 52.14800568989345, 41.48112773895264, 24.338823999677384, 7.646270206996372, 1.4197762267930167, 0.47866628638335634, 0.8670882838112968, 2.4857749342918396, 6.526605784893036, 14.13413153375898, 11.072692700794764, 12.212985021727425, 4.704126298427582, 6.077465542725154, 9.949250629970006, 15.777872085571289, 25.287194047655376, 30.102879319872173, 39.21422931126186, 45.55250808170864, 49.40849079404558, 54.24209894452776, 49.74323068346296, 44.603728090013774, 43.90182801655361, 38.186840874808176, 35.633791310446604, 38.07965448924473, 44.952809061322895, 48.426950045994346, 50.35111468178885, 50.71789618900844, 49.51700775963919, 51.226980277470176, 48.27082749775478, 47.70342370441982, 47.15045131955828, 40.569874967847554, 36.54094117028372, 37.36837782178606, 37.63175971167428, 37.19420385360718, 33.70694466999599, 40.1132185118539, 48.19816671098982, 51.9341470854623, 50.185035364968435, 49.84133577346802, 49.43564782823835, 50.845934118543354, 49.643357276916504, 50.45750897271292, 47.27547720500401, 49.207694802965435, 36.70194482803345, 42.743601526532856, 51.58760568073818, 44.54687098094395, 42.09369829722813, 36.71305499758039, 37.16027579988752, 36.929046698978965, 37.60386616843087, 36.4431939125061, 37.652767590114046, 35.01025996889387, 36.967748165130615, 37.41289840425764, 36.820272650037495, 37.73383569717407, 43.457483768463135, 45.63060583387102, 45.43725831168038, 41.22534023012434, 38.92216525759016, 37.48184190477644, 37.230876445770264, 38.88441916874477, 37.72608845574515, 39.735910483769004, 39.2991224016462, 43.40912430627005, 44.614181654793875, 48.229489190237864, 49.84297554833548, 51.36693089348929, 49.60522903714861, 49.73844337463379, 50.896527426583425, 50.351111207689556, 46.87801592690604, 40.36828340802874, 36.84815924508231, 32.3401506287711, 25.110412767955236, 16.350495713097708, 14.147658807890755, 31.28044264657157, 33.1064361844744, 13.46081895487649, 10.69582154069628, 4.748382415090289, 4.425434052944183, 0.2625055754823344, 0.31110225351793425, 1.9974813759326935, 7.446352294513157, 22.313274724142893, 38.94896445955549, 38.620693343026296, 40.24579014096941, 49.5176157270159, 52.81991386413574, 58.81761973244803, 53.981597082955496, 25.801181827272686, 3.9411372286932806, 0.14383620609130177, 0.08193999741758619, 0.12781102742467607, 0.2674747588379042, 0.0859072898913707, 0.10144251199173075, 0.18370691021638258, 0.09645404467093092, 0.13047640797282967, 0.08039781624185187, 0.10003176983445883, 0.12180614178734166, 0.118208521977067, 0.12055385112762451, 0.12249876319297723, 0.10331955019916807, 0.21637478869940552, 0.20836120870496544, 0.11004284157284669, 0.21017224581113883, 0.12912180780300073, 0.0991867155368839, 0.168701990374497, 0.14225141970174654, 0.09631098234759909], [0.00812697337408151, 0.007442632640179778, 0.019440023195264593, 0.009680883027613163, 0.04579412145540118, 0.03512796486860939, 0.04182365683040448, 0.00635773190463494, 0.03501085990241595, 0.026246927046616162, 0.013468579156324267, 0.026777824719569514, 0.061231176501938274, 0.043016009099249325, 0.028692477515765598, 0.026400742453656027, 0.041272598185709546, 0.031243148326341594, 0.010018390586732753, 0.03462272430104869, 0.01436766010842153, 0.04585000220686197, 0.061483279402766905, 0.025528046335758905, 0.012123678644586886, 0.015370704499738557, 0.033691231427448134, 1.5841419441359383, 13.974791969571795, 36.53424310684204, 42.663634708949495, 37.409292289188926, 27.394886663981847, 18.767261573246547, 18.088658809661865, 26.79271408489772, 18.654679911477224, 8.00132315499442, 1.185707375407219, 0.1752158994121211, 0.08025041807975088, 0.5542366855910846, 1.2241648946489607, 3.3808562074388777, 6.099133500031062, 8.954688957759313, 2.9002397571291243, 3.6324569923537116, 7.611671652112689, 10.01063014779772, 18.13202772821699, 27.558806828090123, 38.025343894958496, 44.91201966149466, 46.867690903799875, 46.53728321620396, 44.84271832874843, 41.53513608660017, 39.30955859592983, 34.71831056049892, 34.155874729156494, 32.87677737644741, 36.17965221405029, 41.84301424026489, 43.00388451984951, 47.78880664280483, 46.33550405502319, 45.879330498831614, 46.98417745317732, 45.75141416277204, 41.89492770603725, 41.236304487500874, 35.65004662105015, 34.814723764147075, 31.977927139827184, 35.19130917957851, 32.03041730608259, 34.60590607779366, 40.41444376536778, 44.579683848789756, 43.77266100474766, 46.73760672977993, 46.11589929035732, 48.002967493874685, 44.548375265938894, 48.57911559513637, 45.42468902042934, 50.54886736188616, 34.29124995640346, 40.124214036124094, 48.42049169540405, 41.66160372325352, 39.958318846566335, 35.6465516771589, 36.01207208633423, 36.89176613943917, 39.863580158778596, 39.70782239096505, 40.192156996045796, 34.06482206072126, 31.57626567568098, 32.315081528254915, 32.26704863139561, 38.034619740077424, 44.33983898162842, 46.71973248890468, 44.532502106257844, 43.71287522997175, 41.45542982646397, 36.87561157771519, 34.28697681427002, 33.90065697261265, 33.91767658506121, 33.6372264453343, 36.26650469643729, 39.20743744713919, 42.34064074925014, 45.8441343988691, 45.120135579790386, 48.64395618438721, 49.88259417670113, 50.46285561152867, 46.41057934079851, 47.751286370413645, 41.27731275558472, 37.6926919392177, 25.64016601017543, 22.80082287107195, 9.94641489642007, 11.548040679522924, 8.720855150903974, 5.187913298606873, 5.827679540429797, 2.9760871614728654, 5.323525633130755, 2.6003826473440443, 4.6646904945373535, 0.8825014510325023, 0.10098733034517084, 1.2728351801633835, 4.792300241334098, 16.05506178310939, 29.47511305127825, 29.8758156640189, 28.828199284417288, 33.65441281454903, 40.46810817718506, 47.39579221180507, 35.82018715994698, 14.763066836765834, 1.5399455385548728, 0.05965816269495657, 0.08112378085830382, 0.030498897191137075, 0.008744179005069392, 0.08293754567525216, 0.06047904757516725, 0.0420695443504623, 0.04996087608326759, 0.017135317936273556, 0.022327746098328913, 0.034732765717698, 0.052584414769496234, 0.01820573067691709, 0.03904362761282495, 0.01200194691773504, 0.01365723564023418, 0.05538076614694936, 0.05561008384185178, 0.11012451683304139, 0.025648092751258185, 0.0649859043104308, 0.009842876477965286, 0.026621826126107147, 0.055774625191198926, 0.045420160450573475, 0.03420026839843818, 0.030354162278984274, 0.02044760698585638, 0.03032470028847456, 0.029368349284465824, 0.04622298951393791, 0.020755780627951026, 0.13704740894692286, 0.037207101338676045, 0.025208020383226018, 0.03021372588617461, 0.020309119684887782, 0.04627391017441239, 0.022869273022349392, 0.03513221928317632, 0.08751450186329228, 0.016426630517733947, 0.01088576699008367, 0.05511096026748419, 0.053976520962480984, 0.021473217755556107, 0.019333918978060995, 0.023173762219292775, 0.07515660819730588, 0.016443113829674463, 0.018006909738427827, 0.040089043123381476, 1.9521652247224535, 17.913321018218994, 41.051423345293315, 49.07659271785191, 42.22848987579346, 35.07660831723894, 27.673962797437394, 24.833327293395996, 30.64553710392543, 20.848924500601633, 8.981770430292402, 1.560384098972593, 0.33275202608534266, 0.08654318576944725, 0.9954360595771244, 1.9152735471725464, 5.481687043394361, 6.2390554547309875, 5.663434113774981, 5.009117475577763, 5.520262573446546, 9.931583098002843, 11.408144780567714, 19.890632425035747, 30.6213504246303, 39.1808432170323, 46.00378315789359, 48.47015047073364, 48.405622550419395, 48.49666479655674, 43.98359441757202, 41.257468700408936, 37.29365342003958, 35.062538215092246, 35.103768825531006, 37.94741289956229, 44.542055879320415, 44.9435783794948, 48.54838023866926, 47.37046602794102, 48.1843432698931, 49.44986036845616, 47.85222979954311, 45.05637543542044, 43.268906184605186, 36.78274195534842, 36.53318350655692, 33.36784478596279, 35.50604867935181, 34.45457083838326, 36.569772720336914, 42.296978269304546, 46.577975341251914, 46.0169222014291, 48.864690031324116, 48.18067462103707, 49.72480753489903, 46.38804633276803, 48.77460663659232, 47.64726488930838, 49.87187658037458, 35.67871836253575, 41.32085016795567, 48.797664233616416, 42.735847336905344, 42.22681188583374, 37.16787365504673, 36.595078059605186, 37.67179523195539, 41.57783624104091, 40.23135873249599, 39.73801578794207, 36.08628926958357, 33.394501549857004, 34.73672676086426, 34.996363571711946, 38.79435314450945, 45.976487159729004, 47.02996608189174, 46.18491922106062, 44.8269042287554, 42.76286540712629, 37.08440841947283, 36.36296306337629, 35.064657415662495, 35.973342827388215, 34.82223129272461, 38.46884741101946, 40.75514868327549, 44.44856439317976, 47.162221567971365, 47.2265236718314, 48.77053846631731, 50.03792463030134, 49.803148474012104, 48.50690644127982, 48.96619279044015, 43.10509198052542, 36.64437552860805, 29.58498838969639, 23.478531054088048, 18.58078408241272, 18.17305510384696, 11.600265077182225, 10.639630590166364, 11.30536094733647, 5.877621454851968, 7.240308676447187, 5.02324663741248, 3.114142656326294, 0.8379343482000488, 0.144567056159888, 1.121586901800973, 6.478030928543635, 18.233737196241105, 31.96390220097133, 34.23550803320748, 33.453248568943565, 41.685627119881765, 47.46501364026751, 52.00006464549473, 42.60530458177839, 17.413721220833914, 2.412546783685684, 0.04671730227502329, 0.006214027093457324, 0.04986556566187313, 0.04035080497020057, 0.08668484352529049, 0.04248745406844786, 0.02451154829135963, 0.013059856802491205, 0.006463751304961208, 0.0091201959710036, 0.05408728501892515, 0.05166855873540044, 0.059022972493299415, 0.02196939309526767, 0.0369484777163182, 0.03130900354257651, 0.034594548134399314, 0.0527150632946619, 0.03928823609437261, 0.0284289107657969, 0.027608283728893315, 0.09054768231830426, 0.06696227325924806, 0.053218790729131014, 0.059655211067625454, 0.07982134646070854, 0.0916065972830568, 0.13355884328484535, 0.12038036329405648, 0.14573773262756212, 0.1158344636538199, 0.10236024417515312, 0.27328421281916754, 0.11787884895290647, 0.16149024878229412, 0.10719325912318059, 0.1031907642526286, 0.14976456654923304, 0.1189537298466478, 0.14086933886366232, 0.1623056171728032, 0.16088460199534893, 0.13017865323594638, 0.23237932633076394, 0.1861603707075119, 0.14479619743568556, 0.10312519062842641, 0.12123428604432515, 0.2431248240172863, 0.10280068125575781, 0.1441341915300914, 0.14042639120348863, 2.547120145389012, 20.946885415485927, 47.23681395394461, 56.00420727048601, 49.043154512132915, 39.8856372152056, 30.16452373777117, 28.49076870509556, 36.818195138658794, 24.928032977240427, 11.006560615130834, 2.323952474764415, 0.6227473893335888, 0.3454642710941178, 2.2095981538295746, 5.2891042573111395, 10.21331604889461, 15.470131158828735, 18.610901049205236, 9.079972795077733, 7.520505206925528, 12.273073043142047, 12.653089131627764, 22.19035587991987, 32.89011096954346, 39.42518009458269, 47.18036331449236, 46.93893425805228, 48.410726002284456, 50.480597836630686, 47.26914392198835, 43.51264899117606, 38.006726196834016, 37.22510944093977, 37.380762985774446, 40.528019019535606, 46.58787652424404, 47.15708337511335, 49.915653705596924, 48.32594755717686, 47.26354367392403, 51.07310547147478, 50.305534499032156, 46.68494980675833, 44.93476111548287, 38.89498390470232, 37.37920658929007, 34.68455968584333, 38.90196337018694, 36.31182084764753, 38.3558349609375, 43.869418144226074, 47.702311992645264, 47.72316353661673, 52.05651528494698, 49.744363239833284, 51.38727174486433, 48.53966719763619, 51.90511751174927, 50.159472942352295, 52.05035918099539, 37.28997087478638, 43.63272081102644, 51.87904439653669, 46.142726285117014, 44.91689034870693, 40.22969811303275, 40.097202914101736, 41.12793343407767, 43.3396110534668, 43.602662903921946, 43.67282233919416, 38.3690539087568, 35.054554734911235, 36.53184597832816, 35.45308256149292, 42.980264118739534, 48.27812658037458, 50.14746992928641, 48.82114219665527, 47.05893659591675, 45.9461270059858, 40.00526087624686, 37.99085998535156, 37.024497577122276, 37.600975717817036, 36.9319440977914, 40.693966320582796, 43.94836705071585, 47.424950327192036, 49.9343513080052, 47.858920914786204, 50.69019719532558, 51.433942794799805, 50.68489224570138, 48.68061140605381, 49.299518721444265, 44.481644766671316, 40.0567227091108, 30.58469867706299, 27.32521707671029, 14.589016199111938, 20.58519867488316, 17.875237941741943, 16.9789776461465, 16.578182969774517, 13.673667464937482, 12.270657675606863, 6.311335393360682, 7.586032799312046, 1.8266373319285256, 0.34306858107447624, 2.0460171486650194, 7.144196850912912, 22.187289987291607, 36.888503960200715, 40.76893390927996, 40.69203472137451, 47.179567745753694, 56.033528668539866, 57.91550036839077, 48.764497007642476, 20.72711389405387, 3.025727480649948, 0.13076082271124634, 0.1608417864356722, 0.14033393402184757, 0.13478435895272664, 0.15346210742635386, 0.1114972203171679, 0.08290146796831063, 0.1460189311099904, 0.06972380221954413, 0.06794701756111213, 0.13095808641186782, 0.10371171629854611, 0.1508123196129288, 0.18368217082960264, 0.10622086415865592, 0.25959634301917894, 0.23456613613026484, 0.12530746390776976, 0.20955891800778254, 0.11263413288231407, 0.14964863205594675, 0.11408743954130582, 0.15999778386737618, 0.1992951530430998, 0.174067601029362], [0.07967786344566516, 0.037949116700994115, 0.031551474638815434, 0.04213846654498151, 0.055102923020188294, 0.01490949746221304, 0.01044009331547256, 0.024774273657905202, 0.01213660728119846, 0.05270312786368387, 0.04523221642843314, 0.08695350946592433, 0.07348017208278179, 0.043311256649238725, 0.029997161256947687, 0.04120641727266567, 0.025599114397274594, 0.02116189571097493, 0.035497169342956374, 0.05374702684847372, 0.05122935998120478, 0.03145882407469409, 0.04034646913143141, 0.036739180197141, 0.005225200131202915, 0.003797049733943173, 0.08336272928863764, 0.3882970655603068, 9.303405148642403, 32.390389578683035, 44.92148658207485, 42.87325143814087, 31.927851472582134, 26.452764783586773, 29.919641426631383, 32.155839238848, 25.607405253819056, 11.189688205718994, 2.8346428998879025, 0.4435755493385451, 0.22152577872787202, 0.8556265788418906, 0.4764759753431593, 4.172022828033992, 3.4618511412824904, 3.790966246809278, 4.251998330865588, 2.0380990249770026, 4.8315258622169495, 7.0947330594062805, 15.88011656488691, 26.2701279095241, 35.816021714891704, 42.326195444379536, 46.758458273751394, 46.555285998753135, 47.59211356299264, 43.59760808944702, 41.67210592542376, 37.311791692461284, 33.34701061248779, 33.01342064993722, 33.82543230056763, 37.68234954561506, 40.96787820543562, 45.60743359157017, 46.719305174691335, 48.00043140138899, 46.666464124407085, 47.272447790418354, 42.37467302594866, 42.241573333740234, 37.38455670220511, 34.34792641230992, 33.83559056690761, 33.6316123008728, 32.29327808107649, 33.4061085156032, 34.58418253489903, 39.54650606427874, 41.36572510855538, 43.91381018502371, 41.89453860691616, 45.041579246520996, 42.84394046238491, 46.512016092027935, 42.891685009002686, 51.057062080928254, 32.55314418247768, 35.056295258658274, 53.60763461249215, 40.2539438520159, 43.43585055215018, 40.75301211220877, 43.83697700500488, 42.08993237359183, 45.547950063432964, 43.58880819593157, 44.57179069519043, 41.8644563811166, 34.14631748199463, 34.270207336970735, 33.34602744238717, 38.93868112564087, 46.036203452519004, 46.06722021102905, 48.517221042088096, 46.10649837766375, 45.02639743259975, 43.416287899017334, 38.90317235674177, 33.90410327911377, 35.80293825694493, 35.392727034432546, 37.21058423178536, 39.267588002341135, 44.09892756598336, 43.11668504987444, 45.5058057648795, 45.877246039254324, 50.255754130227224, 50.76409476143973, 52.30694920676095, 46.78783178329468, 39.27640526635306, 29.354964801243373, 26.122405733380997, 20.812243223190308, 16.520287105015345, 18.999746561050415, 11.126727104187012, 6.857722188745226, 9.38368376663753, 4.451194933482578, 5.760044038295746, 1.3987684569188525, 3.406056455203465, 0.6843567405428205, 0.10050089537565197, 1.4485990915979658, 7.011463676180158, 22.048623050962174, 35.69546699523926, 34.87701089041573, 29.406801836831228, 30.59170593534197, 52.41089425768171, 50.603084155491416, 34.57131099700928, 9.686435886791774, 1.569908233625548, 0.02807018965748804, 0.0030574813385361005, 0.04176653435985957, 0.033883056669895134, 0.033491528393434625, 0.015960018948784897, 0.08932825310954026, 0.07308512899492468, 0.060120075408901484, 0.08533910502280508, 0.021389164230121032, 0.07237751196537699, 0.02705470941561673, 0.02962133088814361, 0.028143596968480518, 0.028951627002762895, 0.0733436169102788, 0.018223477760329843, 0.0408386648632586, 0.045884169837726016, 0.01572054867366595, 0.08075790120554821, 0.08605203498154879, 0.032172629343611855, 0.014288447930344512, 0.08767800166138581, 0.05423690877588732, 0.004135275692013758, 0.07000149946127619, 0.03379794802250607, 0.010545963438094726, 0.022398390075457946, 0.040474230490092716, 0.00826883384226156, 0.009899707178452184, 0.039869285986891816, 0.09305439423769712, 0.05526090293590512, 0.04272157918395741, 0.025630389772621647, 0.036245881845908504, 0.027390044814507877, 0.02521018490993551, 0.02378613837728543, 0.058867811890585084, 0.05334310852257269, 0.04316385170178754, 0.022181192712326134, 0.03951557585969567, 0.028562704300773994, 0.022953411364661794, 0.022012242581695318, 0.9007290186626571, 12.53574447972434, 37.750111852373394, 50.15454319545201, 47.48539618083409, 35.597236837659565, 24.7236065523965, 29.66874544961112, 37.44677782058716, 27.464290482657297, 13.12698233127594, 3.049168097121375, 0.5382900812796184, 0.09768336013491664, 0.8454130526099886, 2.061648641313825, 4.503858370440347, 5.259970460619245, 6.522170662879944, 5.067156646932874, 5.688995667866298, 7.479694093976702, 8.262357422283717, 18.221562215260096, 26.91079350880214, 37.26500252314976, 43.35063784463065, 47.077592509133474, 46.68641240256173, 49.81456783839634, 45.26961217607771, 42.22247273581368, 37.97755071095058, 35.17407764707293, 35.15736722946167, 35.941269942692344, 39.901645864759175, 43.92254407065255, 47.13273688725063, 48.72783831187657, 47.48443038122994, 47.963984625680105, 49.701308727264404, 45.18296119144985, 45.103994914463584, 38.704307964869905, 36.55422612598964, 34.15427664348057, 35.22525460379464, 33.87985406603132, 34.2085976600647, 37.14188739231655, 42.53842469624111, 43.32950837271554, 46.084465639931814, 44.76629161834717, 46.24058471407209, 45.226613249097554, 47.97423321860177, 45.65803732190813, 52.36857278006417, 33.12750312260219, 36.90206336975098, 54.58759117126465, 42.2642730985369, 46.091705662863596, 42.92150667735508, 44.33226891926357, 43.32595089503697, 47.14772762571062, 45.03970670700073, 46.89697756086077, 43.02054282597133, 36.75959055764334, 34.205988611493794, 34.437030111040386, 40.403687953948975, 47.81779105322701, 47.75643151147025, 49.971520696367534, 47.645097051348, 45.92804084505354, 44.533224718911306, 39.80409663064139, 35.53835085460118, 37.74405302320208, 36.802933420453755, 39.62410702024187, 41.87727233341762, 45.647278036390034, 45.29909685679844, 47.97484813417707, 47.52918372835432, 50.77939816883632, 50.75610433306013, 52.30647325515747, 45.36173834119524, 41.21748529161726, 33.00077840260097, 24.721542937414988, 18.3607520035335, 19.412394864218577, 13.383512428828649, 10.390939797673907, 10.25745187486921, 12.275266068322317, 4.70067434651511, 7.118554524012974, 4.647725164890289, 0.3154481074639729, 0.6521252957837922, 0.17818237308944973, 1.37742380797863, 7.736034853117807, 23.175490583692277, 36.19476454598563, 35.423062869480674, 34.70180858884539, 36.127009187425884, 55.470627307891846, 55.63411842073713, 40.20859643391201, 13.519607663154602, 2.360102649245943, 0.03933547230969582, 0.089537024764078, 0.04760204069316387, 0.10545937823397772, 0.019143747664721947, 0.016457456363631145, 0.04004187136888504, 0.03423307217391474, 0.008672049036249518, 0.037329600658267736, 0.04066738226850118, 0.006298781206299151, 0.04182629293895193, 0.017412859114951322, 0.03960484731942415, 0.05644216454987015, 0.059287234741662226, 0.014705012452655604, 0.005983647067166332, 0.0645797128922173, 0.039915019247148714, 0.02824028311962528, 0.04680492150198136, 0.021482174417802265, 0.03321244694026453, 0.19187918598098413, 0.12218146664755684, 0.12381265126168728, 0.17180676305932657, 0.09688131817217384, 0.12123078480362892, 0.10569819541914122, 0.10140992195478507, 0.09360418402190719, 0.2387495216514383, 0.13058506857071603, 0.1632051917591265, 0.11646882604275431, 0.22935995406338147, 0.18949855943875654, 0.08102912522320237, 0.12518432337258542, 0.1072406955063343, 0.13278686042342866, 0.18224571219512395, 0.12020410703761236, 0.24994773790240288, 0.07419087644666433, 0.13353950503681386, 0.19036210381558963, 0.09033097180404834, 0.1679176174636398, 1.0271179995366504, 15.106980085372925, 41.58373178754534, 55.909899371010916, 53.34226553780692, 42.64913729258946, 35.86445413316999, 39.19251619066511, 42.53954683031355, 32.65561274119786, 15.474935838154384, 3.973847610609872, 0.6712089574762753, 0.9068022327763694, 3.50042102592332, 5.875088836465563, 10.4431711435318, 12.001982126917158, 7.980600152696882, 7.535254495484488, 5.503271188054766, 7.694942338126046, 9.511228374072484, 18.78777960368565, 27.757059778485978, 39.540346486227854, 44.67742763246809, 48.34878976004464, 47.1376770564488, 52.17828246525356, 49.07003709248134, 46.10916648592268, 40.52239097867693, 37.39011526107788, 37.254545484270366, 38.32599939618792, 41.864154134477886, 45.57399191175188, 49.791287899017334, 50.31640842982701, 48.53101321629116, 49.22196292877197, 51.00961978094918, 47.052221161978586, 46.12500837871006, 41.7751407623291, 38.724631445748464, 37.469713824135916, 37.45515734808785, 35.99783522742135, 35.89009646006993, 37.92571020126343, 43.56504535675049, 46.02484662192208, 47.64015688214983, 45.80849361419678, 48.05743094852993, 48.06861407416207, 50.022381510053364, 48.256878989083425, 52.59531681878226, 36.99841056551252, 39.26220314843314, 56.03370237350464, 43.94101933070591, 48.526291915348594, 45.45976005281721, 47.29556792122977, 47.23230457305908, 49.77860048839024, 48.3429011617388, 50.16518783569336, 46.59972667694092, 38.115055561065674, 36.68618631362915, 36.38729565484183, 43.01609945297241, 50.08888619286673, 48.9910569190979, 52.33727809361049, 50.304881368364605, 48.09578847885132, 48.246408053806846, 42.24806295122419, 36.77198961802891, 41.028775691986084, 39.874280384608674, 42.070182119097026, 43.83366618837629, 49.12538991655622, 46.50233725139073, 50.25444439479283, 48.65944371904646, 54.093570777348106, 53.26774263381958, 54.71172768729073, 47.26952607291085, 42.01577772412981, 32.39604888643537, 30.205330508095876, 22.558544397354126, 25.063929319381714, 27.467050654547556, 18.721570219312394, 13.231089796338763, 22.354114498410905, 11.40704001699175, 12.106981566974095, 5.109423841748919, 3.997233944279807, 1.1456050872802734, 0.5020930607404027, 2.305122856582914, 9.596284747123718, 27.32083797454834, 45.47963190078735, 44.56300122397286, 40.3075908933367, 45.220808029174805, 65.15717697143555, 61.94018881661551, 47.390108585357666, 16.659110375813075, 3.346385759966714, 0.17529701148825033, 0.26577302015253473, 0.1096150998824409, 0.10692300541060311, 0.08695099210100514, 0.07415340774293457, 0.11477449695978846, 0.2856701910495758, 0.12616652995347977, 0.1573862111462014, 0.18357737788132258, 0.19002643254186424, 0.19328150073332445, 0.13840052991041116, 0.09588153074894633, 0.2257381919771433, 0.14713307203991072, 0.15066851090107644, 0.07038765374038901, 0.19323681241699628, 0.07640522119722196, 0.21158993616700172, 0.11004126737160341, 0.13712947097207817, 0.15324713396174566], [0.036304829575653584, 0.04939544606687767, 0.027130393211596777, 0.013236529509803014, 0.02331384238121765, 0.014372993393668106, 0.010441501275636256, 0.02981352593217577, 0.02474660299984472, 0.024915030658511177, 0.010620600593808507, 0.030170116440526078, 0.04261849953659943, 0.03793971559831074, 0.01649498613551259, 0.06502143918935742, 0.03960114251822233, 0.029469844552555254, 0.03055145651368158, 0.029902447946369648, 0.015496881479131324, 0.03988963525210108, 0.025345442384215336, 0.046355575256581814, 0.01518403273075819, 0.02908867411315441, 0.021517702511378696, 0.11943399693284716, 6.61428336586271, 29.944033077784947, 42.35884850365775, 43.742745535714285, 35.358055523463655, 25.89470979145595, 25.11461990220206, 28.075648580278667, 22.207802806581768, 14.809519018445696, 3.895312990461077, 0.5706287345715931, 0.19501593123589242, 0.5871010678155082, 1.0857943424156733, 2.7307701536587308, 3.32766774722508, 4.111341604164668, 3.052765961204256, 5.307582122938974, 7.404547589165824, 5.330896803310939, 12.692599194390432, 21.480925696236746, 33.374323981148855, 41.9816620690482, 47.332824162074495, 47.05337456294468, 46.87399639402117, 44.37668875285557, 41.30160713195801, 39.46275247846331, 36.22383580889021, 35.56449345179966, 33.6641263961792, 33.98320852007185, 38.75159045628139, 42.73136574881417, 44.29935530253819, 48.76245423725673, 47.91355112620762, 45.89405025754656, 47.278200898851665, 42.255997794015066, 42.23112671715872, 38.069391999925884, 32.81029353822981, 33.06934322629656, 32.43979821886335, 33.02998515537807, 33.021848814828054, 33.35183613640921, 35.054426193237305, 37.453274386269705, 37.21594476699829, 39.32335077013288, 39.65755912235805, 43.51043946402413, 43.45365878513881, 51.60977390834263, 37.14319017955235, 34.382448537009104, 50.424727371760774, 41.84895495006016, 44.58870608466012, 40.935503074101035, 44.50789506094796, 43.83053602491106, 47.03601448876517, 47.90515422821045, 46.43038518088204, 43.702939305986675, 38.38924189976284, 30.854875905173166, 31.950926440102712, 37.77298879623413, 46.49406542096819, 47.07986109597342, 49.57446936198643, 47.433326380593435, 47.622821126665386, 43.504022802625386, 42.881874152592246, 40.02515009471348, 35.755593231746126, 34.56793417249407, 38.32573536464146, 40.9004876273019, 44.204863275800435, 43.30888611929757, 43.535439082554404, 42.12916885103498, 47.063348702022004, 47.11564779281616, 49.54745823996407, 50.556374890463694, 33.00563519341605, 27.691692863191875, 20.737536191940308, 17.045011588505336, 19.147237709590367, 9.311633552823748, 9.139854976109095, 10.00419351032802, 7.3630329711096625, 3.12739525948252, 5.809757096426828, 8.674653972898211, 0.930418074131012, 0.7029465373073305, 0.22334531109247888, 1.69213790340083, 7.068803250789642, 19.23034511293684, 36.79752424785069, 35.43485743658883, 26.784291131155832, 34.008972440447124, 48.3044741494315, 42.400770459856304, 32.053686823163716, 10.284373538834707, 1.3416853142636163, 0.03305243820484195, 0.05845444157187428, 0.04517092775287373, 0.025305651394384246, 0.046809345550302944, 0.03595753838973386, 0.03869263841105359, 0.032349377537944486, 0.0326947179356856, 0.05634411284700036, 0.03590060251631907, 0.007125346272784684, 0.03829278790258935, 0.06990562924849135, 0.016665437524872165, 0.0185173122611429, 0.02903818092974169, 0.05966593870627029, 0.05004659880484853, 0.009375856939836271, 0.04553198980699692, 0.02224743299718414, 0.04642435495874711, 0.03412232847352113, 0.02248600421340338, 0.07370877731591463, 0.07119603322020598, 0.023759190359019806, 0.04560180766774075, 0.019944960118404458, 0.04893292606409107, 0.03536707382383091, 0.011137896184144276, 0.039381853570895534, 0.03560381129916225, 0.04120595247617789, 0.019317544231723462, 0.024425813695415854, 0.021744384097733667, 0.052379174889730554, 0.04342856517593775, 0.011127848776855638, 0.007293779020463782, 0.014416555341865336, 0.03951433074793645, 0.030251320118882825, 0.05643849367541926, 0.01775808585807681, 0.039064540062099695, 0.04032838956585952, 0.027614833288160816, 0.053186451750142236, 0.2447185127862862, 8.584002562931605, 33.99232108252389, 49.349563121795654, 48.307618209293906, 41.62204762867519, 30.440419333321707, 31.19823850904192, 33.47931473595755, 27.780852147511073, 17.721040044512065, 4.475644775799342, 0.686978816986084, 0.22770432861787931, 0.5856170845883233, 1.860174332346235, 4.37053416456495, 4.044911614486149, 6.366152771881648, 5.854928638253893, 5.62335820708956, 5.63747911793845, 7.851464407784598, 15.788442032677786, 24.627935068947927, 34.501505919865195, 45.12294960021973, 46.59098931721279, 48.04291616167341, 48.14104209627424, 47.77621650695801, 43.7504997253418, 42.04569666726248, 37.73323815209525, 36.23036364146641, 35.40845080784389, 36.607744625636506, 41.333006041390554, 44.840025901794434, 46.73267698287964, 49.55135270527431, 47.97020673751831, 47.91594130652291, 48.511766706194194, 44.22643395832607, 43.24419491631644, 38.778681482587544, 34.11940016065325, 34.96080616542271, 35.061106886182515, 35.034113134656636, 34.42581224441528, 36.07459545135498, 37.40521717071533, 39.48539318357195, 40.422500201633994, 41.65441581181118, 41.90463433946882, 45.09459400177002, 46.45787572860718, 51.4556177003043, 39.1163569859096, 36.44483368737357, 51.89366340637207, 43.506756918770925, 45.95084135872977, 42.929372038160054, 46.01644624982561, 46.29819917678833, 49.48023441859654, 50.6831100327628, 48.90318305151803, 45.70689010620117, 38.96280179704939, 32.103713853018625, 34.13975143432617, 40.11832543781826, 48.44967065538679, 48.77509648459298, 49.273157255990164, 47.900544098445344, 48.99019186837332, 45.20973260062081, 45.10943535396031, 39.98843233925955, 37.832392420087544, 35.899295875004356, 40.747397967747276, 43.08100952420916, 46.7325553894043, 44.958860942295615, 45.999965122767854, 45.213442938668386, 50.03034067153931, 50.12694495064871, 51.659967694963726, 49.03682122911726, 38.21810776846749, 26.241240773882183, 22.22251214299883, 18.973088060106548, 16.489341565540858, 8.762564318520681, 8.607085347175598, 9.630336999893188, 8.890836749758039, 7.517840572765895, 3.9986452971185957, 4.020781823566981, 0.8207764231732914, 0.25476232383932385, 0.31771460441606386, 1.461002060345241, 8.838965841702052, 22.974161318370275, 42.561728954315186, 40.49262489591326, 30.39192090715681, 40.226703439440044, 57.368982860020225, 50.20880862644741, 37.9088260786874, 11.742620638438634, 1.6578136937958854, 0.046608858808342896, 0.04172101144545844, 0.044711576508624215, 0.04972274082579783, 0.03405840368941426, 0.06282040729586567, 0.06578149340514626, 0.029871588173721517, 0.01988648566683488, 0.06646525314343826, 0.04691261179479105, 0.05522434346910034, 0.06604321793253932, 0.09416694061032363, 0.025155566233609403, 0.030186913574912717, 0.011245927440800836, 0.021899744868278503, 0.03455046710691281, 0.030680259423596517, 0.12812886679811136, 0.0375513662584126, 0.025336009051118578, 0.007913757315171617, 0.01726862631871232, 0.1354360646967377, 0.15776461655540125, 0.21791008274470056, 0.20973735914698668, 0.1055265599861741, 0.17056158344660485, 0.13636303852711404, 0.11761911931846823, 0.07906723621168307, 0.11053602118045092, 0.09276691252099616, 0.10077812442822115, 0.1615266046885933, 0.08181541838816234, 0.14065424326275075, 0.08224816766700574, 0.07711847006742444, 0.11698781033711773, 0.1330727950802871, 0.15624876932374068, 0.14497064878898008, 0.13497281526880606, 0.13488320793424333, 0.10677437910011836, 0.09297052052404199, 0.11248460412025452, 0.1941421545509781, 0.39019316381641794, 10.125786985669817, 38.787762778145925, 55.14323166438511, 54.04147318431309, 47.934562478746685, 37.37556920732771, 35.79649032865252, 37.60974781853812, 30.41362360545567, 20.298995426722936, 5.777239092758723, 1.2544591490711485, 0.47155903918402536, 1.0767486563750674, 2.5751509155545915, 7.582291194370814, 8.384201032774788, 12.099044118608747, 9.829998697553362, 9.892410891396658, 10.648694515228271, 8.232884900910513, 17.43429831096104, 26.03660069193159, 36.44956193651472, 45.633600507463726, 47.4962214742388, 47.23756435939244, 49.23648466382708, 49.62044211796352, 46.027476515088765, 43.2467622756958, 40.589194434029714, 38.79762922014509, 37.533991609300884, 37.845468929835725, 42.20940317426409, 45.20991325378418, 48.04175581250872, 51.46421957015991, 49.2529935836792, 48.21339021410261, 52.030337946755544, 45.50647626604353, 46.763467924935476, 41.50925404684884, 36.1778769493103, 37.66294322695051, 36.27621480396816, 36.320235116141184, 36.38019806998116, 36.50699574606759, 39.307091985430034, 42.33706590107509, 41.570974894932334, 41.39157588141305, 43.41880314690726, 46.63558285576956, 48.75941092627389, 52.79079048974173, 41.080390385219026, 38.435141699654714, 52.04006542478289, 45.98487363542829, 48.32644087927682, 45.50358234133039, 48.537113734654014, 49.851914405822754, 52.32690790721348, 53.96934393474034, 50.58150999886649, 49.31068795067923, 41.52044759477888, 33.23641960961478, 35.868032455444336, 42.91018806185041, 50.904656818934846, 51.14732960292271, 49.98171022960118, 49.71071311405727, 51.6416209765843, 47.44501672472273, 47.199550764901296, 43.41797978537423, 40.287006855010986, 38.33037328720093, 42.07476793016706, 45.759314264569966, 48.98169074739729, 48.110852173396516, 47.48030662536621, 47.38741268430437, 51.26837764467512, 52.2051476751055, 52.65265335355486, 54.765565804072786, 39.21842949731009, 30.233067716870988, 23.054194143840245, 20.855417592184885, 24.292898144040787, 15.11480028288705, 16.27128103801182, 20.911944661821636, 19.351335832050868, 9.939131447247096, 13.502113836152212, 15.562517881393433, 3.3156553975173404, 1.7717151876006807, 0.892330003636224, 1.9929511504513877, 9.924527202333723, 25.072645834514073, 47.559536933898926, 46.6525434085301, 36.50438322339739, 48.13551827839443, 59.80133874075753, 58.1763322693961, 43.985484327588765, 14.39815352644239, 2.033737293311528, 0.15834651461669377, 0.09730155526527337, 0.14573030945445808, 0.09625633313719716, 0.09870613632457596, 0.13652376990233148, 0.13333100479628357, 0.18211223078625544, 0.1493917251271861, 0.13700980453618936, 0.09986191894859076, 0.142788453027606, 0.18232795063938412, 0.1388844203736101, 0.14978754174496445, 0.10805677635861294, 0.09370045457035303, 0.21565738719488892, 0.17103551301573003, 0.101900543485369, 0.17414081495787415, 0.10645030398986169, 0.1414405025009598, 0.13954025161053452, 0.16603416710027627], [0.007905792162221457, 0.06666390784084797, 0.054564807430974076, 0.03573150819699679, 0.052214959237192354, 0.04762330258797322, 0.06539250963500567, 0.022939481040728942, 0.034795058625085015, 0.01547852880321443, 0.07460522385580198, 0.0259166704823396, 0.039394277547086985, 0.030994448278631483, 0.07678349089941808, 0.023177587460460405, 0.016863252535196285, 0.048467118559139113, 0.07853679824620485, 0.02533104387111962, 0.02937638313908662, 0.04961152893624135, 0.07827658006655318, 0.019259677068995576, 0.04311228643304535, 0.061892395306910784, 0.04792567814833351, 0.12853543141058513, 2.822281620332173, 20.48685039792742, 40.9765738759722, 47.91578844615391, 38.97122648784092, 24.58511505808149, 25.569516726902553, 31.69359643118722, 30.18733467374529, 17.888086897986277, 7.112660714558192, 1.5570558032819202, 0.14430161326059274, 0.15547993486481054, 2.2566585200173512, 3.7192013434001376, 2.3026885986328125, 4.748571753501892, 5.083831020763942, 4.640494695731571, 2.042103575808661, 5.318575041634696, 12.984347105026245, 21.550414630344935, 33.34933131081717, 43.282128606523784, 47.806517601013184, 48.69743994304112, 46.79497800554548, 48.475604806627544, 43.334163665771484, 41.356501374925884, 38.63727869306292, 34.157934870038716, 33.413803645542686, 33.89898245675223, 36.635210854666575, 42.88019616263253, 44.275109563555034, 48.1029485974993, 45.82219893591744, 46.35114792415074, 47.312914099012104, 45.085172244480674, 41.83092437471662, 41.23985154288155, 38.681559562683105, 36.65726443699428, 31.812455790383474, 33.014358656747, 30.26597785949707, 33.48739549091884, 33.68236541748047, 33.739729745047434, 33.715522221156526, 36.711547238486155, 36.54660395213536, 43.96689789635794, 44.131201948438374, 51.3207357951573, 39.379863943372456, 34.03528526851109, 51.672401496342246, 45.65181868416922, 49.30941990443638, 45.77447870799473, 47.32502480915615, 47.70472649165562, 48.58433716637747, 47.5693929536002, 47.179268973214285, 45.17133338110787, 39.21674108505249, 31.382358823503765, 33.30833346503121, 34.852310044424875, 45.151958329336985, 46.853634698050364, 49.513710839407786, 47.46152911867414, 49.33162634713309, 48.56739051001412, 46.18964747020176, 41.88761820111956, 37.34815856388637, 34.82637241908482, 37.182402338300435, 42.41695976257324, 42.38620356151036, 42.10364464351109, 43.17313916342599, 43.07304688862392, 44.08858169828142, 48.32673270361764, 41.54389776502337, 33.64024543762207, 32.157135077885215, 20.843207870210918, 17.107286555426462, 13.74081746169499, 9.599387117794581, 5.093617992741721, 4.400981605052948, 8.547130210059029, 7.399403316634042, 5.140820579869406, 3.920316517353058, 1.5282637711082185, 0.4526252251650606, 0.054528159754616876, 0.3830980216818196, 1.939237232719149, 7.961115666798182, 20.60320840563093, 27.266523906162806, 30.38717528751918, 29.62038251331874, 45.805488518306184, 41.880652632032124, 40.11248895100185, 31.544439452035085, 9.735007269041878, 1.0139398723840714, 0.014310354433421577, 0.04739131146509733, 0.0014999181980134121, 0.05683284126488226, 0.06506688746490649, 0.08293715891029153, 0.023842738375865986, 0.10100146422960929, 0.04279931554836886, 0.04773101323683347, 0.04775837516146047, 0.03872248716652393, 0.09276099569563355, 0.024360849056392908, 0.02317184366152755, 0.08716858471078531, 0.01652160506429417, 0.060672457196882794, 0.026362138900107572, 0.026506777121020213, 0.020403987362182567, 0.0756506020469325, 0.0058390521028611276, 0.04020120156928897, 0.021589103055053523, 0.02618664429922189, 0.02030485000328294, 0.042319472546556165, 0.11595459149352141, 0.06426663683461291, 0.024842505443042943, 0.019850433404956545, 0.01553127302655152, 0.08233245528702225, 0.007212165676589523, 0.019662141633619155, 0.015499105377654945, 0.029822801505880694, 0.02682135104467826, 0.034296515198158364, 0.00977044880190598, 0.009968441079503723, 0.046696617134979794, 0.05634405856419887, 0.010537977929094007, 0.04694433669958796, 0.06327362119087152, 0.07231710199266672, 0.007072990934830159, 0.017775636166334152, 0.04782031862331288, 0.01632444653660059, 0.23903108654277666, 3.9628407955169678, 25.53679244858878, 47.16902038029262, 52.65235110691616, 43.480086258479524, 27.067911386489868, 27.746993575777324, 32.80932079042707, 32.76879889624459, 19.70600836617606, 7.552875995635986, 1.3055228718689509, 0.187805478860225, 0.3691077423947198, 1.8302360645362308, 3.846423728125436, 3.9533591100147794, 6.159466879708426, 6.05769487789699, 5.639205311025892, 4.855633071490696, 7.942397219794137, 12.74883530821119, 23.112697975976126, 32.869530405317036, 44.25879519326346, 49.17891536440168, 48.65113714763096, 48.324846267700195, 49.830708503723145, 45.440496172223774, 44.28539637156895, 39.964235237666536, 35.63388858522688, 35.36848824364798, 35.94999688012259, 38.929467814309255, 43.9778482573373, 46.08112703050886, 48.81202268600464, 45.99525077002389, 46.783273765019004, 48.35798570087978, 44.62634795052664, 46.19233642305647, 42.684559209006174, 39.841745444706504, 36.9911983353751, 33.82715197971889, 33.80555350439889, 31.779865264892578, 34.74163566316877, 34.99344532830374, 36.65162944793701, 36.00745153427124, 38.206809997558594, 38.55149275915963, 44.882816382816856, 45.438387393951416, 52.44508981704712, 40.99675839287894, 34.804631505693706, 51.90856729234968, 47.06908791405814, 50.10921662194388, 47.20451872689383, 49.94247375215803, 49.20753499439785, 50.792245388031006, 48.91866711207798, 48.747449602399556, 47.586874621255056, 40.62242071969168, 34.102279799325125, 34.87902586800711, 36.49775811604091, 46.73529645374843, 49.80962419509888, 49.925937039511545, 48.00705998284476, 50.0919121333531, 50.06176042556763, 47.82305778775896, 45.02836724690029, 39.86722796303885, 37.961698395865305, 40.603945459638325, 44.12070322036743, 44.22681958334786, 44.26317603247506, 44.140043531145366, 45.006299768175396, 45.5041937828064, 49.7514191355024, 45.880480425698416, 40.985255650111604, 34.10547249657767, 23.926184381757462, 20.366590976715088, 16.354353700365337, 9.722966040883746, 5.705207117966243, 9.54032221862248, 8.645884088107518, 9.54038301536015, 11.300174985613141, 3.8568338666643416, 2.746577956846782, 0.7622088630284581, 0.21252408889787539, 0.393940088472196, 2.0451601317950656, 9.074142387935094, 23.658826385225566, 33.65592752184187, 35.291057518550325, 32.84713636125837, 49.73528889247349, 50.74232952935355, 46.70805604117257, 35.755464690072195, 11.589541401181902, 1.414077184029988, 0.08949432455535446, 0.07022871369762079, 0.07743295069251742, 0.04387537370036755, 0.06752950139343739, 0.0857385110908321, 0.032375341680433066, 0.028870915262294666, 0.09132974821009807, 0.06862870098224708, 0.05350404345829572, 0.024971394866172756, 0.029061912692018917, 0.011401084650840079, 0.013136772139530097, 0.034154765840087614, 0.038189806642809083, 0.11014024527477366, 0.048540675147835693, 0.02247950724059982, 0.05303191200696996, 0.039664826422397576, 0.05172421896298017, 0.060240820715469975, 0.019669737833152925, 0.09298050855951649, 0.20331024830894812, 0.11913622862526349, 0.20328370401901857, 0.17499857821634837, 0.20442550203629903, 0.1309158272509064, 0.1624811813235283, 0.19646482063191278, 0.11880183299737317, 0.16369043929236277, 0.13285168765911035, 0.13902725199503557, 0.1248440109193325, 0.16547903046011925, 0.1418598371424845, 0.056622848247310946, 0.07837933062442712, 0.14748972361641272, 0.16870919641639504, 0.0912365514252867, 0.0977129035496286, 0.18681389492537293, 0.12485346969749246, 0.1577608303299972, 0.26855628937482834, 0.23033305470432552, 0.33949802124074524, 4.874454438686371, 27.585435799189977, 53.87492486408779, 59.77404621669224, 49.35253347669329, 34.99390390941075, 36.15835945946829, 40.59857450212751, 39.2530905859811, 24.14068395750863, 9.168262686048235, 2.48292704139437, 0.26312385659132687, 0.9902827761002949, 4.680963175637381, 8.218422225543431, 10.035853845732552, 12.923115236418587, 10.349091666085378, 9.71750909941537, 6.930970532553537, 8.788483704839434, 15.40822444643293, 23.34559985569545, 36.41818387167794, 46.72765343529837, 50.0901403427124, 49.97332375390189, 49.10383660452706, 52.07194028581892, 47.28969669342041, 45.889756270817344, 42.41073417663574, 37.7900744165693, 37.63094677243914, 36.25318499973842, 40.8991049357823, 46.60665055683681, 48.194734300885884, 49.51752887453352, 48.58830806187221, 47.7264152935573, 51.101697308676584, 48.38409008298601, 47.79196112496512, 45.13025563103812, 42.10531568527222, 40.528491497039795, 35.97663279942104, 36.15877982548305, 32.52212047576904, 37.328137329646516, 36.506196703229634, 38.12183352879116, 37.72656788144793, 39.10011209760393, 39.7837245123727, 47.93050473076956, 47.796592099326, 55.136967863355366, 43.34891816547939, 37.673476696014404, 50.696124008723665, 49.15379762649536, 50.71288653782436, 50.481581006731304, 51.22936003548758, 51.26617159162249, 50.78031880514962, 50.65487602778843, 50.91644443784441, 50.61088350840977, 43.59705570765904, 35.92788771220616, 35.457373074122835, 37.43442392349243, 49.144778864724294, 52.246958460126606, 51.10494906561715, 49.559930256434846, 53.133228983197895, 53.15422643933977, 50.12479795728411, 46.91565779277256, 40.77463838032314, 38.585670948028564, 43.398288590567454, 48.07099035808018, 46.37232950755528, 46.46918739591326, 46.303761209760395, 47.135689871651785, 46.360475880759104, 53.32828228814261, 47.47620023999895, 41.374844619206016, 35.46745491027832, 24.969743013381958, 20.533153193337576, 16.45650785309928, 12.420180303709847, 9.925844754491534, 9.062827246529714, 15.44613208089556, 20.67956042289734, 19.23118758201599, 9.394523824964251, 5.1854753494262695, 1.176842451095581, 0.4141553294445787, 0.9923158841473716, 2.7878498222146715, 10.777698244367327, 26.776384081159318, 35.78629037312099, 41.72265407017299, 41.77687781197684, 58.93191759926932, 55.3894167627607, 55.678385393960134, 40.92218337740217, 13.578748992511205, 1.5477112361363001, 0.18776991005454743, 0.14058520910995348, 0.2257909955722945, 0.1664387232490948, 0.21623305630471024, 0.18964403734675475, 0.10610456325645957, 0.18953578386987957, 0.10172148487929787, 0.18754180015197822, 0.1543171972568546, 0.12212851377470152, 0.1368200590035745, 0.10120788136763231, 0.16332625597715378, 0.13197115276541027, 0.09311340642826897, 0.26051396663699833, 0.11110646557062864, 0.058129348659089634, 0.11407139897346497, 0.2549731582403183, 0.10346594412944146, 0.12438701758427279, 0.12938391231000423], [0.07315009193761007, 0.06682135510657515, 0.05316938998709832, 0.09136046549039227, 0.03698617033660412, 0.04182643543130585, 0.014750121460695351, 0.019116937049797604, 0.02150804186905069, 0.04232790334416287, 0.04705891751551202, 0.015440425669242228, 0.10658307972231082, 0.01358707681564348, 0.03129422504987035, 0.05800238118640014, 0.02715635226507272, 0.06134883447417191, 0.08620627277663775, 0.019489096544150795, 0.06078777422330209, 0.037062227326844416, 0.04311812861955591, 0.0092466452125726, 0.05858587380498648, 0.007387065711165113, 0.042862775535987954, 0.03846562434253948, 1.5279687983649117, 10.854620882443019, 33.71572719301496, 47.23357261930193, 40.815243652888704, 32.496644905635286, 27.895514794758387, 24.784978253500803, 28.631686857768468, 26.490571669169835, 9.178095255579267, 2.3450432973248616, 0.36894445972783224, 0.10934236273169518, 0.9030158988067082, 2.7071391131196703, 1.6336439507348197, 4.873238938195365, 5.368539537702288, 4.425984697682517, 3.667923637798854, 6.155627131462097, 9.711413792201451, 19.284056425094604, 32.375134808676584, 42.832917145320344, 44.06695890426636, 47.524719510759624, 46.24939850398472, 47.34249605451311, 44.37504550388881, 44.432809352874756, 41.80863107953753, 35.060936655317036, 34.70763117926461, 36.0324581010001, 37.03881434031895, 43.4392169543675, 44.19901984078543, 47.32464960643223, 47.264721393585205, 45.9497435433524, 47.81254516329084, 45.647090435028076, 43.01548801149641, 44.43693658283779, 42.88104731695992, 40.95478432519095, 34.47111102512905, 31.123746871948242, 31.71342658996582, 32.60045099258423, 31.311647006443568, 31.446490696498326, 34.265253271375386, 36.47102492196219, 37.25691829408918, 43.72024032047817, 42.71932799475533, 48.161567074911936, 40.59067440032959, 31.688725743974956, 40.9469120161874, 41.387535503932405, 46.86234426498413, 48.5983065196446, 49.17029959814889, 46.171154839651926, 42.193894795009065, 41.506440026419504, 50.04200322287423, 44.68961477279663, 39.382657119206016, 31.935046332223074, 34.30487537384033, 32.69942113331386, 42.18945142201015, 43.716856547764365, 49.48728336606707, 48.39597845077515, 45.4808999470302, 47.28828968320574, 45.25091804776873, 45.4207945551191, 41.54070159367153, 36.45558949879238, 38.896425655909944, 38.55383082798549, 42.107170854296, 41.03913198198591, 43.28316388811384, 41.888215746198384, 46.733034815107075, 48.51941319874355, 48.425758429935996, 37.592029912131174, 27.937389850616455, 19.241418804441178, 14.008860724312918, 10.085142629487173, 10.87758207321167, 6.446799210139683, 9.708768265587942, 5.255524916308267, 4.734993236405509, 9.942648104258947, 2.3681586512497494, 2.0207369966166358, 0.310282366084201, 0.3121630751660892, 0.27866027291331974, 2.607913626091821, 10.872207641601562, 22.78759871210371, 38.62680428368704, 34.02103451320103, 29.779749870300293, 46.357508999960764, 43.33170052937099, 46.0848582131522, 29.92580795288086, 5.941442830221994, 0.2275037265249661, 0.030662369847829853, 0.05688496632501483, 0.021689161525240967, 0.0367672410128372, 0.012508399518472808, 0.011744353820436766, 0.017890912480652332, 0.05468573933467269, 0.017290970476876413, 0.04253459868154355, 0.04438510277707662, 0.03071010478639177, 0.05342530964740685, 0.0431343523918518, 0.024254249508625696, 0.042404089256056716, 0.010919632672864412, 0.03023623289274318, 0.056857550117586336, 0.020069327105634978, 0.064007646803345, 0.014302761626562901, 0.06006803177297115, 0.029485111590474844, 0.056466825905122926, 0.040332036691584756, 0.01164828598432775, 0.09207130556127854, 0.11764432010906083, 0.023103854452658976, 0.024027878352041756, 0.014517619740217924, 0.00861481121475143, 0.08234729484788009, 0.02368522834564958, 0.05287724673481924, 0.034133032363440306, 0.07598845141806773, 0.0422688504414899, 0.023597361453409706, 0.027460549691958085, 0.04097541341824191, 0.02020540730362492, 0.05016752392319696, 0.008014504498402988, 0.024706187757796476, 0.03616331431216427, 0.020130727739472474, 0.02034762315452099, 0.0676868808056627, 0.013710770356867994, 0.04012423534212368, 0.01323551170727504, 2.0653609335422516, 14.448468906538826, 40.45945072174072, 51.769294125693186, 46.57102714266096, 35.700202192579, 32.32882506506783, 29.82722691127232, 31.827012266431534, 26.73631729398455, 9.72168322971889, 2.706505741391863, 0.3034300852034773, 0.3154997575495924, 0.5710417181253433, 3.189042717218399, 3.2211145162582397, 7.157088364873614, 6.577711956841605, 4.970388216631753, 5.069035266126905, 5.81431120634079, 13.285324828965322, 22.960978848593577, 32.855842454092844, 45.42205565316336, 47.49851437977382, 48.9224226134164, 46.545141628810335, 49.38784769603184, 45.84133774893624, 45.632923058101106, 42.735114301954, 35.72255802154541, 36.31763996396746, 36.102836404527935, 39.58275134222848, 44.65077781677246, 46.44415998458862, 47.71870626722063, 47.1505138533456, 46.76774801526751, 48.2499794278826, 48.07483271190098, 44.43897935322353, 45.79288796016148, 44.24724381310599, 42.3503543308803, 35.66329683576311, 32.68116821561541, 32.29239913395473, 34.63571037564959, 32.95062630517142, 33.26764481408255, 35.00230080740792, 37.618228094918386, 38.110435009002686, 45.240297726222444, 45.653743335178916, 51.28718294416155, 41.17582736696516, 34.347495623997276, 42.02953168324062, 42.55470085144043, 48.30681916645595, 49.496131896972656, 49.052708285195486, 48.196672848292756, 42.92497035435268, 42.38061720984322, 49.5947059903826, 48.23587458474295, 40.99912772859846, 33.60746383666992, 35.97315175192696, 35.096452372414724, 44.14817292349679, 46.94909599849156, 50.67379249845232, 48.70025396347046, 46.99472829273769, 49.025995935712544, 46.86502626964024, 46.02801500047956, 42.795685223170686, 38.311206681387766, 40.02297878265381, 41.35446555273873, 43.70820256641933, 42.94189269202096, 43.98753752027239, 45.275639738355366, 49.537299973624094, 51.576763016836985, 48.456097739083425, 38.890477997916086, 30.72072356087821, 22.548130784715923, 19.239091157913208, 13.741487094334193, 6.3912878802844455, 6.984214578356061, 8.999600376401629, 9.270699109349932, 9.60487185205732, 8.890171459742955, 5.39693682534354, 2.5365406445094516, 0.9520852714776993, 0.23463906507406915, 0.5268377129520688, 2.7903472653457095, 11.998975293976919, 24.133850404194423, 39.217689514160156, 38.99038961955479, 34.793236460004536, 53.86336306163243, 50.871486118861604, 52.594500405447825, 34.325202328818186, 7.622953789574759, 0.4374538064002991, 0.04233394230582884, 0.046671809894698005, 0.03897472916703139, 0.0239816192271454, 0.027721887454390526, 0.009402592067739792, 0.02593368135525712, 0.05252081568219832, 0.02911979512178472, 0.04612403196681823, 0.009682894035774683, 0.022113590268418193, 0.012104563464942788, 0.03970576583274773, 0.005163079826161265, 0.011133472983991461, 0.04846106602677277, 0.08414158570979323, 0.052378784732094834, 0.06430694181472063, 0.04368024059970464, 0.006698614751387919, 0.01994089230096766, 0.03682285374296563, 0.009881027109388794, 0.13403988390096597, 0.20694332835929735, 0.15845209466559546, 0.19648375175893307, 0.09438790553914649, 0.12728676412786755, 0.11481652541884355, 0.07147012744098902, 0.2395080966608865, 0.13982932109917912, 0.13928409107029438, 0.09487028286925384, 0.14266208266573294, 0.12444739363023213, 0.13893892030630792, 0.1489459683320352, 0.233095397906644, 0.0892052279253091, 0.14398251181202276, 0.1338285609547581, 0.13987324945628643, 0.10556077850716454, 0.11629620673401014, 0.07666742748447827, 0.14668264692383154, 0.09179896874619381, 0.1568262976195131, 0.215487251324313, 2.4070006012916565, 16.930333307811193, 46.72496100834438, 57.92222275052752, 52.889708518981934, 43.63169595173427, 40.02183927808489, 34.96102850777762, 37.4864798273359, 33.59615911756243, 12.018000330243792, 3.5193932993071417, 0.5772510192223957, 0.6278735314096723, 2.6007589357239858, 6.6233433825629096, 7.393871682030814, 10.865113530840192, 15.249640498842512, 9.473567400659833, 7.801365290369306, 9.215315886906215, 13.972430450575692, 24.00054052897862, 33.831741264888215, 46.924363885607036, 47.55861629758562, 49.72512367793492, 46.07245915276663, 49.83755942753383, 48.38006360190255, 48.33388934816633, 45.517562116895405, 38.08984749657767, 37.78151076180594, 39.374083042144775, 41.36160830089024, 47.4708605493818, 48.126725333077566, 50.6383011000497, 48.873048714229036, 46.62828377314976, 48.845794405256, 51.22010850906372, 45.964678696223665, 50.74591132572719, 46.946889945438926, 44.35298844746181, 37.27632808685303, 34.109749112810405, 34.48332595825195, 35.8720554624285, 34.781546115875244, 35.79879018238613, 37.39584057671683, 39.13005883353097, 40.99549034663609, 46.977368218558176, 46.34232718603951, 50.72290236609322, 44.88021428244454, 38.522959981645855, 45.75771270479475, 43.51678316933768, 46.27725730623518, 49.18459899084908, 49.02380725315639, 47.85873678752354, 42.30215467725481, 43.42893362045288, 52.98057358605521, 50.463977745601106, 42.50153323582241, 35.340441840035574, 38.98552935464041, 36.73094660895211, 46.003449644361226, 48.18625055040632, 52.18938568660191, 50.39807408196585, 46.75350420815604, 50.72933292388916, 47.469634192330496, 49.4198510987418, 45.87715571267264, 40.02825941358294, 42.741909640175955, 42.14823470796858, 45.9621947152274, 45.097745009831016, 45.53603737694876, 46.888674463544575, 51.80226680210659, 53.743711607796804, 51.47808122634888, 41.74726111548287, 31.51771320615496, 22.212626593453543, 16.810610634940012, 13.591161949293953, 15.90412085396903, 10.341175062315804, 18.725153752735682, 15.670357397624425, 12.011563692774091, 25.060712303434098, 11.075902768543788, 6.184978493622371, 2.3457061988966803, 0.8184374858226094, 0.8518250999706132, 3.4131679364613126, 14.325251289776393, 30.20018536703927, 49.76342214856829, 45.90425368717739, 44.85610750743321, 60.153397015162874, 58.962579999651226, 60.01808084760393, 38.56443725313459, 9.090303897857666, 0.6377168489353997, 0.10361716244369745, 0.12635137646325997, 0.16002686587827547, 0.11237113270908594, 0.1619592657578843, 0.12489787302911282, 0.14415982658309595, 0.20059810312730925, 0.13210130935268743, 0.20109093668205397, 0.11260062682309321, 0.15338843209402903, 0.22867482368435177, 0.1557289165045534, 0.17817864114684717, 0.09646541691784348, 0.18339740325297627, 0.14779399228947504, 0.16490952244826726, 0.1090685399249196, 0.1058855117963893, 0.08940747207296745, 0.15713542460330895, 0.12656618707946368, 0.11589603392141205], [0.06415375574891057, 0.03600804175117186, 0.020799513906240463, 0.047749801871499846, 0.031537279686225314, 0.03875821203525577, 0.03868154436349869, 0.02100248578270631, 0.038635794139866314, 0.024388226248057823, 0.005565467207426471, 0.03836250737575548, 0.007415732119365462, 0.037106467810060294, 0.05238962432901774, 0.07759533769318036, 0.05167286743276885, 0.062479870926056585, 0.0669693775208933, 0.03111980762332678, 0.04076921341142484, 0.04111259962831225, 0.008165479388221033, 0.08913601056805678, 0.04140251050037997, 0.02418286762466388, 0.03827496957299965, 0.029963013982134204, 0.9778076112270355, 10.450808950832911, 31.331963539123535, 50.48371410369873, 45.636550017765586, 38.89732544762747, 31.705936431884766, 24.175980806350708, 38.59169503620693, 29.764345714024135, 14.376341394015721, 3.683422463280814, 0.7565804421901703, 0.21971505374780723, 0.26567813381552696, 2.626055806875229, 0.9282580528940473, 4.182189345359802, 2.755889411483492, 3.686474025249481, 2.6549151497227803, 4.69493122611727, 10.430084211485726, 21.145629950932094, 29.973118237086705, 42.01065690176827, 47.34318045207432, 46.524005208696636, 49.65094818387713, 46.43053456715175, 47.035017422267366, 46.35345472608294, 42.684534890311106, 36.048522336142405, 34.676260062626426, 36.782901763916016, 37.53241089412144, 43.0326361656189, 46.01846470151629, 47.592388016836985, 47.16591106142317, 44.270489011492046, 43.99757766723633, 46.36482892717634, 45.998731817517964, 46.199861322130474, 42.62831701551165, 43.01669699805123, 41.821551254817415, 35.268993513924734, 33.540938309260774, 32.47089488165719, 34.932659012930735, 36.763356481279644, 34.1927627154759, 36.67720576695034, 37.300806590488975, 43.685224873679026, 43.081179755074636, 47.85487706320626, 41.05390732628958, 26.453994614737375, 40.4316405568804, 43.42866611480713, 46.47620507649013, 44.831580366407124, 48.84003782272339, 45.572758606501985, 45.59178277424404, 45.3978967666626, 48.46368864604405, 45.976532323019846, 41.64717926297869, 32.68898146493094, 31.912242344447545, 33.67302009037563, 38.88742426463536, 44.79550531932286, 44.703552859170095, 49.27739913122994, 47.71631261280605, 48.00358240944998, 47.59631722314017, 43.43794890812465, 43.82046808515276, 39.64672688075474, 38.74586514064244, 39.006558077675955, 40.85404239382063, 38.91464730671474, 39.32185343333653, 43.50455086571829, 46.04202604293823, 48.19886153084891, 46.683271816798616, 38.234647955213276, 28.846575532640728, 19.160218681607926, 14.256756816591535, 9.544778619493757, 2.4570454359054565, 3.107316485473088, 10.985590951783315, 8.877246073314122, 7.449571916035243, 4.874335016523089, 2.821700142962592, 1.2984887978860309, 0.7149094353829111, 0.03276911251513021, 0.6657500618270465, 2.376243314572743, 12.665529881204877, 28.83127212524414, 45.279933725084575, 31.709959438868932, 36.94584049497332, 39.68771777834211, 37.35786172321865, 38.556293964385986, 20.902251924787247, 6.421560313020434, 0.1556769000100238, 0.038948608961488516, 0.05329520395025611, 0.04484470168660794, 0.021265301055141857, 0.036170496605336666, 0.030330671396638666, 0.04535088881051966, 0.05000732519796916, 0.03050836953999741, 0.007063778549698847, 0.07378941441753081, 0.016845637766112174, 0.07185480929911137, 0.0856425730245454, 0.017481850859309946, 0.011987033566193921, 0.052457993517496755, 0.016225719691387246, 0.040023771447262595, 0.039203778840601444, 0.0211700194714857, 0.025172371849683777, 0.1110105478603925, 0.014524776588327118, 0.04849197329687221, 0.045803071332297156, 0.013796649989672005, 0.03860851363944156, 0.056489628074424605, 0.03822378089119281, 0.016446869521002685, 0.05918734081621681, 0.038238226901739836, 0.06717531968440328, 0.02813755122146436, 0.04173978650942445, 0.05555105468790446, 0.05777309741824865, 0.025546824792400002, 0.05431988343064274, 0.011804930882395377, 0.011910880732882236, 0.030333928364728178, 0.10597450166408505, 0.08983125790421452, 0.01263934320637158, 0.014712915689285313, 0.07054371679467814, 0.08956801345837967, 0.0890582911670208, 0.043621744095746956, 0.07456720553870712, 0.0708933455337371, 1.1685762660843986, 12.635615280696324, 36.434258529118125, 54.9493282863072, 49.90711784362793, 44.095245020730154, 35.66525622776577, 27.53827316420419, 39.42639602933611, 32.75190087727138, 16.13611251967294, 4.257320650986262, 0.48999147010701044, 0.13410982729068824, 0.4315901239003454, 1.7994603216648102, 3.6447544353348866, 8.191417183194842, 6.497273530278887, 5.027364747864859, 7.219749391078949, 7.093035093375614, 13.514022180012294, 21.14103545461382, 32.4525933265686, 43.53745058604649, 47.99222557885306, 48.26423018319266, 50.069056034088135, 48.261013167245046, 47.716444628579275, 48.33159991673061, 44.0605457169669, 39.63423401968819, 35.55867086138044, 38.28132247924805, 39.151744161333355, 43.54991218021938, 46.9110163961138, 49.282377515520366, 46.15398236683437, 45.39870970589774, 44.837865012032644, 46.288110392434255, 46.97153867994036, 47.43693249566214, 45.77098376410348, 45.46266092572893, 41.93803433009556, 36.791423729487825, 34.80187654495239, 35.13110303878784, 35.456268310546875, 38.52736513955252, 34.33393621444702, 38.41652052743094, 39.896431241716655, 45.58589417593819, 45.26048571722848, 49.190588338034495, 41.88582556588309, 30.989896774291992, 42.08165012087141, 45.36036607197353, 46.64132901600429, 45.44440800803048, 48.25298799787249, 46.70775726863316, 45.9055495262146, 45.67419883183071, 48.581474508558, 47.926544257572715, 41.51756061826433, 33.56567737034389, 33.36361333302089, 34.6150290625436, 40.17906311580113, 46.99427318572998, 48.427120276859824, 50.46807023457119, 47.405068056924, 47.81627287183489, 49.7496577671596, 46.32371991021292, 46.165030002593994, 40.616987228393555, 40.936694690159385, 40.95972102028983, 42.84468044553484, 40.73589175088065, 41.2643335206168, 45.109279019492014, 46.485407965523855, 49.87483998707363, 48.0440799849374, 41.40770265034267, 28.497732537133352, 20.481211934770855, 19.289420434406825, 10.910298534802028, 5.1285470213208875, 8.148111666951861, 10.016723717961993, 7.567699108804975, 12.62624476637159, 8.082207134791783, 2.6930225448948995, 1.9366416462830134, 0.4639562985726765, 0.2662472618477685, 0.8749560330595288, 3.210225820541382, 14.029011368751526, 30.004916667938232, 45.07948166983468, 36.78443036760603, 40.067961420331685, 47.278218269348145, 45.0601761000497, 48.45355469839913, 25.897765261786326, 7.250261102403913, 0.1120363978136863, 0.03295127881158676, 0.017361734893971255, 0.023202484606632164, 0.011109493556432426, 0.05684502436114209, 0.0355229604590152, 0.03604364787627544, 0.05536864072616611, 0.04100596785013165, 0.03803525672161153, 0.04928092292643019, 0.031968994199165275, 0.03687479899131826, 0.033144539155598195, 0.052306032207395346, 0.052386584492134194, 0.051491749472916126, 0.035441234308694086, 0.028966839757880995, 0.025371297961100936, 0.03472171238224421, 0.013136640673370233, 0.1131443844309875, 0.04655903398192354, 0.06413460749068431, 0.1569218353501388, 0.06252606559012618, 0.10086223562913281, 0.14622193521686963, 0.1075282586472375, 0.09120156615972519, 0.11943379337234156, 0.1413662029164178, 0.23347410187125206, 0.1806257234088012, 0.1103241214794772, 0.10471103553261076, 0.0911866519600153, 0.11567116741623197, 0.2139152485345091, 0.24358563071915082, 0.13156699016690254, 0.11367419814424855, 0.11903927954179899, 0.1356994177081755, 0.1252106369606086, 0.11124886971499238, 0.1384915757392134, 0.16009154383625301, 0.1353797327194895, 0.1226742323487997, 0.13054616137274674, 0.14719093750630105, 1.507380525980677, 15.129243850708008, 42.85187530517578, 61.373014313834055, 58.49772466932024, 51.011322089603965, 41.968592507498606, 34.190851960863384, 49.42616353716169, 38.25310584477016, 19.14076372555324, 5.101029983588627, 1.4482756746666772, 0.500568148280893, 1.7456794189555305, 6.709026396274567, 8.091148597853524, 11.473692349025182, 9.275244968278066, 10.38600310257503, 9.751282555716378, 8.529318502971105, 13.347338369914464, 25.334982020514353, 33.0491760798863, 47.4292825290135, 48.57771553312029, 49.93531363351004, 51.90875141961234, 48.186021259852815, 48.934481212071006, 50.92687020983015, 46.07113552093506, 40.49080794198172, 38.09484325136457, 40.67028685978481, 40.89411612919399, 46.17602900096348, 49.513280051095144, 51.90460334505354, 46.881333691733225, 46.3770786012922, 45.73320293426514, 48.00096641268049, 49.01258591243199, 51.63845954622541, 47.20189578192574, 47.80712904248919, 44.91151591709682, 38.484484331948416, 36.48856217520577, 37.2235495703561, 38.510998657771516, 40.13590785435268, 36.817889417920796, 39.51151493617466, 40.94878455570766, 47.22534595217024, 46.27441201891218, 50.36295788628714, 43.86368588038853, 34.41495221001761, 44.1124244417463, 47.98876885005406, 46.79983132226126, 46.13954053606306, 49.15275887080601, 46.01458065850394, 44.89021274021694, 46.523574420383994, 50.59298494883946, 50.71204580579485, 44.449915817805696, 35.637699672154014, 35.236965792519705, 38.257566588265554, 42.88799204145159, 48.72835942677089, 49.64534098761422, 52.76919201442173, 48.43109464645386, 48.92387478692191, 52.06432853426252, 48.223076002938406, 48.314007077898296, 45.19785465512957, 43.87140185492379, 43.14867108208792, 44.44456223079136, 42.402976512908936, 43.606022357940674, 47.60888304029192, 48.07098340988159, 51.379371643066406, 50.1426339830671, 41.70063522883824, 32.62144150052752, 20.702374832970754, 18.124942302703857, 14.959396873201642, 6.55152028799057, 10.384276475225176, 18.624359709875925, 18.19640973636082, 20.43435502052307, 12.690526025635855, 9.788878389767238, 3.591154945748193, 1.6238050843988145, 0.8260873439056533, 1.1915362626314163, 3.675545811653137, 16.980388130460465, 37.51236534118652, 55.15587043762207, 43.35478591918945, 50.78275762285505, 51.056839738573345, 52.287869453430176, 53.58463954925537, 30.985251903533936, 9.082217931747437, 0.2869038219962801, 0.23390383166926249, 0.05765843178544726, 0.08694805404437439, 0.11451374952282224, 0.17096752380686148, 0.1112281268994723, 0.1544454132339784, 0.12579930680138723, 0.14581416281206266, 0.10092826387179749, 0.09776462827410017, 0.09374516324273177, 0.12950357874589308, 0.14998635250542844, 0.11636632654283728, 0.21802828354494913, 0.14580521972051688, 0.17277398758700915, 0.15721150194959982, 0.15139566973916121, 0.09769180111054863, 0.08108972518571786, 0.2562976043139185, 0.09054201655089855, 0.1473902232412781], [0.0556450657147382, 0.030846205340432267, 0.017450473703710095, 0.08885052374431066, 0.015257363706561071, 0.050327179820409844, 0.016357749035315852, 0.03225482368309583, 0.04986579975645457, 0.031034254535500492, 0.03226477439914431, 0.04471861630944269, 0.06811813730746508, 0.059609681367874146, 0.027706435515678356, 0.012063095645446862, 0.043321746800627024, 0.06085074905838285, 0.04126319708302617, 0.046302300079592636, 0.04214174047644649, 0.008483831903764179, 0.03868017711543611, 0.07719138544052839, 0.05281697925446289, 0.02605740543055747, 0.03893884484257017, 0.025955153595922247, 0.2736388695027147, 4.8603139860289435, 21.825306211199077, 39.209848472050254, 46.438639640808105, 41.97441509791783, 27.9288227217538, 29.100542613438197, 25.105248519352504, 28.76950090272086, 15.424075024468557, 6.669417321681976, 0.9078854460801397, 0.164172267009105, 0.12152020713048321, 1.2056352432285036, 1.8332965288843428, 8.492774452481951, 5.386611367974963, 2.4026110768318176, 5.820360916001456, 4.276888949530465, 10.75809563909258, 16.388947044100078, 29.750584806714738, 39.62341914858137, 46.1057688168117, 49.02055549621582, 45.40194409234183, 46.567403657095774, 45.940266200474326, 45.05592032841274, 42.53441905975342, 38.93629789352417, 36.29898057665144, 39.310986450740266, 42.04305982589722, 43.59809793744768, 45.020199639456614, 45.696096079690115, 45.43836654935564, 43.26156541279384, 45.728648390088765, 45.35037803649902, 45.097463607788086, 47.16809974397932, 46.36830997467041, 45.30434969493321, 43.071789264678955, 41.25601305280413, 36.129958697727744, 33.43129226139614, 32.89871631349836, 34.135704108646934, 34.05759246008736, 33.9853207724435, 35.58510875701904, 42.88839503696987, 44.9152193069458, 49.604735715048655, 42.42523506709507, 31.406024387904576, 45.78855923243931, 42.95360388074602, 44.75686291285923, 45.1571694782802, 46.477097920009065, 45.95790767669678, 44.698803765433176, 44.17087268829346, 48.16068465369088, 44.193739209856304, 39.39147090911865, 30.576423372541154, 32.48328699384417, 32.07212734222412, 36.01985059465681, 40.97777591432844, 44.552662304469514, 45.61243282045637, 47.403476919446675, 47.14179386411394, 47.63370547975813, 44.392488956451416, 43.65549005780901, 41.18149014881679, 39.00316040856497, 39.409213134220664, 40.09705352783203, 39.89803974969046, 41.36472109385899, 40.97036566053118, 45.10683325358799, 49.40605197634016, 46.92256430217198, 40.22096422740391, 26.853714057377406, 19.189409800938197, 17.43237018585205, 9.520291430609566, 2.7616842091083527, 5.045815689223153, 4.649303708757673, 4.900002096380506, 10.01553383895329, 5.485022612980433, 1.9725338688918521, 1.9539365811007363, 0.21023895937417234, 0.38481585521783146, 1.1881721402917589, 3.6497540984834944, 14.955273117337908, 25.870566538402013, 32.98523528235299, 44.09247268949236, 44.96253653935024, 38.074634415762766, 45.710107122148784, 37.06456783839634, 19.131769282477244, 4.282999021666391, 0.06279007678053208, 0.015472766344568558, 0.02837635822860258, 0.011805188725702465, 0.038089539523103406, 0.026518992447693433, 0.08008664008229971, 0.011511098077919866, 0.0772999713995627, 0.024324077547394803, 0.06611960061958858, 0.012838025893350797, 0.05904344389481204, 0.0392268422458853, 0.029009231233171055, 0.08380012653235878, 0.07375911782894816, 0.023102370157305683, 0.045043542981147766, 0.02754476267312254, 0.03752547336210098, 0.04842442852844085, 0.0771144734961646, 0.022408795409968922, 0.01739546486974827, 0.026355409529060125, 0.0324559041431972, 0.06423117659453835, 0.03608951684353607, 0.08909722550639085, 0.06410802927400384, 0.030128186369048696, 0.0260303318833134, 0.05614171602896281, 0.03284352405795029, 0.011926728766411543, 0.04023867705836892, 0.013930836226791143, 0.059969440634761534, 0.07439363628093686, 0.05839685430484159, 0.12085722413446222, 0.06732100793825728, 0.062029805433537276, 0.0860689440742135, 0.04016492369451693, 0.021889646570863466, 0.02597353680591498, 0.053739142271557024, 0.023147387563117912, 0.014415356031219875, 0.0854312161515866, 0.03487106133252382, 0.029527564133916582, 0.41986129326479776, 7.036090697560992, 27.17717007228306, 47.39892584936959, 51.03746121270316, 47.9809764453343, 33.91158996309553, 33.3729065486363, 35.62489761625017, 35.04124893460955, 18.45983678953988, 6.639146191733224, 1.063198257769857, 0.30498042915548595, 0.2673184515110084, 1.1341657468250819, 2.9341576056821004, 6.581156960555485, 6.475675054958888, 6.5068099328449795, 5.274187343461173, 6.667213005678994, 13.112471887043544, 19.808489084243774, 30.58631065913609, 42.30133826392037, 49.54481792449951, 48.97922761099679, 47.13170855385916, 47.69852869851248, 48.485151631491526, 47.28111219406128, 42.97874246324812, 39.50852026258196, 37.969046115875244, 41.05407755715506, 43.77420003073556, 45.222823006766184, 47.16224588666643, 47.83787134715489, 46.53739438738142, 45.17484222139631, 44.70299005508423, 46.1115288734436, 45.0368127822876, 48.388814858027864, 47.79186732428414, 47.03082071031843, 44.56418936593192, 42.85591220855713, 36.770311628069194, 35.23337009974888, 34.50689772197178, 36.867985929761616, 36.388494219098774, 35.471533502851216, 37.94476216179984, 45.534505299159456, 45.58967399597168, 51.47742114748274, 43.17590454646519, 32.34250259399414, 48.876564502716064, 44.21338176727295, 43.85935367856707, 45.578556878226145, 47.05820008686611, 45.67400428227016, 44.872852666037424, 45.95510407856533, 50.653350898197715, 44.92051036017281, 41.59216342653547, 33.955318450927734, 34.149402482169016, 33.81282132012503, 36.99989400591169, 42.79003633771624, 47.222222736903596, 48.793453625270296, 49.721458503178184, 47.49701704297747, 49.89959641865322, 47.28381156921387, 45.0034510067531, 43.35235057558332, 41.2174505506243, 41.24255091803414, 41.662284646715435, 41.466685908181326, 42.74085003989083, 43.50359896251133, 46.98027603966849, 49.77403899601528, 48.286780561719624, 40.19343893868582, 29.141382387706212, 19.912840604782104, 13.647327712603978, 7.1211752976690015, 5.3237045492444715, 7.258453897067478, 6.40748803956168, 9.265143156051636, 9.579751508576528, 6.877250535147531, 3.7882655688694546, 1.376388852085386, 0.6924399925129754, 0.2112997267395258, 1.2415924966335297, 3.814902356692723, 16.17136594227382, 31.718780176980154, 40.25913415636335, 43.20900229045323, 50.47236769539969, 44.13253600256783, 49.57760647365025, 43.33677966254098, 23.118822813034058, 5.452592330319541, 0.021375186408736875, 0.0027735492081514424, 0.04620770551264286, 0.04489598197064229, 0.0797077596985868, 0.0456639343340482, 0.054640623541282754, 0.02777085902302393, 0.016196651251188347, 0.027484673308208585, 0.030032611318996975, 0.06511063261755876, 0.03755812107452324, 0.01940364354023976, 0.008853493541079973, 0.040548333299479315, 0.04309491593656795, 0.02998620630907161, 0.07319874289844717, 0.03170754108577967, 0.004090126395957279, 0.03674957535362669, 0.05473611377445715, 0.009940202148365123, 0.01972921990922519, 0.01766789498339806, 0.11239543783345393, 0.21693344015095914, 0.10961463169327804, 0.238646465752806, 0.17013783832745893, 0.1162382462727172, 0.1319617075579507, 0.14579029195010662, 0.14811758563986846, 0.08939848148397037, 0.14660488681069442, 0.10556064280016081, 0.12506950167672976, 0.167881166562438, 0.2022522629371711, 0.17380768140511854, 0.21715131774544716, 0.1927129698118993, 0.15894058559622082, 0.1902316893850054, 0.11118373713855233, 0.1575061489960977, 0.1519506842430149, 0.1584170279758317, 0.21743274692978176, 0.10044157784432173, 0.1429842103804861, 0.11274800462914364, 0.5876344506229673, 7.955001252038138, 30.618171623774938, 52.272319384983604, 57.21798113414219, 52.57274906975882, 37.21896375928606, 38.55511277062552, 35.93554810115269, 39.295141083853586, 20.250627279281616, 8.738778029169355, 1.2805688508919306, 0.5481701482619558, 0.6389482542872429, 3.7047395365578786, 6.191422079290662, 18.07089400291443, 13.662595510482788, 8.843126944133214, 11.498804875782557, 8.573040911129542, 15.77447441646031, 19.729931013924734, 33.10363258634295, 43.612831592559814, 51.632133211408345, 51.65954385484968, 50.093579701014924, 49.608036109379356, 50.23721981048584, 48.88556589399065, 46.115878445761545, 43.80696078709194, 40.4017459324428, 43.510248388562886, 46.38334935052054, 46.854423318590435, 49.68445239748274, 48.414026396615164, 46.54603794642857, 46.92361348015921, 46.26975325175694, 46.529879910605295, 45.39700044904436, 49.119998114449636, 50.51841688156128, 49.96288408551897, 45.977129868098665, 44.76081643785749, 39.69570125852312, 37.04376840591431, 36.89056062698364, 37.59322847638811, 37.397028718675884, 37.30650758743286, 39.228681564331055, 46.15334660666329, 49.306557246616904, 53.52450289045061, 46.3052133832659, 36.893263476235525, 45.68731355667114, 43.34634385790144, 44.23519911084856, 46.559274264744346, 47.62971721376692, 44.91097395760672, 44.62837335041591, 46.08544186183384, 51.90227222442627, 47.486396721431184, 43.86975860595703, 35.26528664997646, 35.82419279643467, 35.5627772467477, 39.31897687911987, 43.04933268683297, 49.07828460420881, 49.93846811567034, 51.31076513017927, 47.821070602961946, 50.85056856700352, 48.591500759124756, 47.712164538247244, 45.82925830568586, 44.73002896990095, 43.44612346376692, 44.96875170298985, 43.69935403551374, 43.93779536655971, 45.91119146347046, 49.52441801343645, 51.97854954855782, 52.85881682804653, 45.421433789389475, 30.163669109344482, 24.32175748688834, 24.45477553776332, 13.365206531115941, 7.528113484382629, 11.681799582072667, 12.35362958908081, 12.277190719332014, 18.08009168079921, 12.498773983546666, 8.936529840741839, 5.478506939751761, 1.26414178950446, 0.8492053576878139, 1.8321492075920105, 5.011023887566157, 19.688116754804337, 34.073896408081055, 42.712411063058035, 56.70883798599243, 55.55395357949393, 48.8219655581883, 58.01812873567854, 49.03164829526629, 26.7746296610151, 6.312481411865779, 0.14432731616709912, 0.08606346151126282, 0.21960008277424745, 0.25127720513514107, 0.15409767760762147, 0.18766622990369797, 0.13360604218074254, 0.12830559802906855, 0.1732930125934737, 0.09878210510526385, 0.1257362708981548, 0.17155756428837776, 0.10412885248661041, 0.11000856876905475, 0.10374959212328706, 0.12564869916864804, 0.1364116623465504, 0.22711527879749024, 0.14512874744832516, 0.13306429982185364, 0.15027224645018578, 0.10204245229916913, 0.18318850946213516, 0.08068300451018981, 0.15963145638150827, 0.08858481621635811], [0.059000838680991104, 0.0315381889231503, 0.05243721677522574, 0.0854662556999496, 0.09461879743529217, 0.022532281998012747, 0.024941315408796072, 0.03376096447131463, 0.09646758822990315, 0.01962137864237385, 0.028887145819940736, 0.03250396477856806, 0.009139530826359987, 0.022979255067184567, 0.06255955807864666, 0.0655420044703143, 0.04906568483316472, 0.026192976727283428, 0.046412148113761625, 0.02287374796079738, 0.008101781913345414, 0.025579294389379875, 0.0176838405563363, 0.025555981622476662, 0.016277515662035773, 0.020965887300137962, 0.024332693245794092, 0.07651452640337603, 0.12667935314987386, 2.3216919217790877, 18.79783364704677, 39.55770308630807, 47.806656564985005, 40.71202816282, 32.88480601991926, 26.225444044385636, 28.58379987307957, 27.926088605608257, 18.611759151731217, 7.910165395055499, 1.5210881275790078, 0.5118721617119653, 0.23264037232313836, 0.98377611381667, 1.8852959786142622, 5.058861366340092, 5.25346086706434, 6.338337395872388, 3.8553842987333025, 6.280572244099208, 8.782827002661568, 16.76801644052778, 25.974860736301967, 38.9044577734811, 43.581908634730745, 46.386819975716726, 46.895584447043284, 46.808485303606304, 45.472412722451345, 43.94847822189331, 40.85328851427351, 37.976532799857004, 36.407059805733816, 40.392855712345664, 43.694809913635254, 44.33733068193708, 47.25053317206246, 42.24283790588379, 42.274629388536724, 45.60271576472691, 45.72244712284633, 46.31450659888131, 46.101721491132466, 45.35507501874651, 43.152027062007356, 47.69376570837838, 44.107696192605154, 43.93543645313808, 41.05577639171055, 40.380029337746755, 37.54692915507725, 37.70310728890555, 34.23290940693447, 34.8180832181658, 36.57745047977993, 43.39373057229178, 43.528494358062744, 48.12069777079991, 43.06981945037842, 30.409822940826416, 48.03858743395124, 44.34862845284598, 46.9632842200143, 47.782525471278596, 47.860380036490305, 48.71923991612026, 46.864515577043804, 47.776761940547395, 44.995220865522114, 44.45219482694353, 35.722613607134136, 31.870883192334855, 34.07192659378052, 33.17064448765346, 35.29740469796317, 38.95324454988752, 44.510361671447754, 44.950807980128694, 49.38262265069144, 47.139257771628245, 49.080970082964214, 46.89566087722778, 44.445274421146934, 44.790474823543, 41.01042202540806, 39.06067064830235, 38.81886291503906, 37.885421071733745, 40.13303477423531, 43.84401553017752, 43.75878197806222, 45.182460921151296, 44.259847845349995, 39.26293618338448, 25.551899569375173, 16.07582300049918, 12.585469262940542, 4.167113491467067, 3.94934435401644, 6.141676017216273, 7.845056431634085, 6.748531682150705, 9.547318186078753, 6.566152759960719, 1.4129323597465242, 0.8669974144015993, 0.1204318641019719, 0.23968397293772015, 0.878198073378631, 6.289752551487513, 14.816750356129237, 27.415976183755056, 32.62360239028931, 52.299702235630576, 36.87816504069737, 36.65193864277431, 49.26161282403128, 36.786511353084016, 16.879588876451763, 2.149663209915161, 0.08729323837906122, 0.024200187231014882, 0.026414023080308522, 0.03906378010287881, 0.028512519850794758, 0.017019023819427406, 0.03337385006515043, 0.0410646305951689, 0.016795814636030366, 0.014693473964663488, 0.0361944251427693, 0.022346946943019117, 0.042322841472923756, 0.08233434161437408, 0.0413621817715466, 0.028876292652317455, 0.030030531609164815, 0.06244100444018841, 0.02099013644536691, 0.10530467224972588, 0.028042315438921963, 0.028852727131119797, 0.05268808134964534, 0.05184540531731077, 0.019324234587007334, 0.09420856194836752, 0.043597014886992316, 0.04819946024300797, 0.04522922069632581, 0.02622699168776827, 0.010541699693671294, 0.04057952216161149, 0.0437901564873755, 0.06778959065143551, 0.012054229737259448, 0.017994470495198454, 0.04575830837711692, 0.04167586511799267, 0.010991632023693194, 0.02132555835747293, 0.042744747762169154, 0.03352194372564554, 0.02326791064946779, 0.024765640996130447, 0.021929734419765215, 0.040052582044154406, 0.04240152778636132, 0.01730252762458154, 0.04610539600253105, 0.04438982538080641, 0.017098319118044207, 0.07617625634052924, 0.008156927302479744, 0.021598514335762178, 0.23720970856291906, 2.899103943790708, 22.355438130242483, 43.21016263961792, 53.15107890537807, 45.64564520972115, 36.40077863420759, 28.59385391644069, 30.862491130828857, 33.69399670192173, 19.82430144718715, 10.405426791736058, 1.6115545417581285, 0.2589398468179362, 0.1112855648888009, 0.5808518145765577, 2.21308810370309, 3.731496180806841, 6.241143822669983, 5.5380169578960965, 5.604406995432718, 6.130745198045458, 10.993413754871913, 17.51991922514779, 26.863936594554357, 40.6755952835083, 45.325083119528635, 49.12736667905535, 48.71338258470808, 48.74854394367763, 47.280233246939524, 45.51790605272566, 43.15178040095738, 39.42449917112078, 37.675533362797324, 42.0289306640625, 44.308321952819824, 47.35093116760254, 48.47176940100533, 43.67958293642317, 42.703767504010884, 45.908280168260845, 45.453079359872, 45.82913671221052, 46.160426821027485, 47.16944769450596, 45.803390162331716, 49.28445502689907, 46.34826789583479, 46.51870025907244, 43.492186546325684, 39.91505936213902, 37.74099234172276, 38.5344557762146, 34.991784708840505, 35.833979334150044, 38.457952635628835, 43.92175545011248, 45.8105502809797, 49.718286650521414, 44.82385744367327, 33.025760650634766, 47.08718449728829, 45.61890506744385, 48.12598534992763, 48.09076145717076, 48.88993631090437, 48.799439498356406, 48.02782814843314, 48.88123369216919, 48.81678567613874, 46.670605250767295, 37.837315218789236, 34.12822437286377, 34.50094658987862, 34.75819322041103, 37.148460388183594, 40.51228134972708, 46.92320006234305, 46.43934140886579, 50.6124016898019, 46.849236488342285, 49.26519462040493, 47.9513076373509, 45.956320013318745, 45.90889508383614, 42.37179299763271, 40.62395627158028, 40.40618930544172, 38.74910994938442, 41.557762895311626, 45.54248183114188, 45.95969336373465, 47.42271300724575, 46.8028016771589, 41.028459548950195, 28.34715986251831, 18.591826507023402, 12.37374028137752, 4.978955345494406, 5.204917711871011, 9.068798354693822, 7.20357745885849, 9.104161211422511, 7.343876787594386, 7.638589841978891, 4.087295191628592, 1.1425626448222568, 0.5020791643432209, 0.3200280288500445, 1.0625824736697334, 6.586341619491577, 17.870391573224747, 30.35590144566127, 34.707422733306885, 54.39829444885254, 43.37844800949097, 41.64028664997646, 54.840752261025564, 43.335716588156565, 21.05920478275844, 2.9640917479991913, 0.07459086605480739, 0.042427715845406055, 0.024676993788619126, 0.04004486031564219, 0.07288148706512791, 0.013452225614206066, 0.014358432032167912, 0.031230059385831867, 0.01598911453038454, 0.06058055641395705, 0.032284570658313375, 0.020151536712156873, 0.013529326700206314, 0.044020909283842356, 0.04141347901895642, 0.034326937315719466, 0.05114463470610125, 0.06610978900321893, 0.036582995006548505, 0.055294266502772055, 0.01868650327170534, 0.06860820243933372, 0.0477816523052752, 0.11031411987330232, 0.03268162899517587, 0.05716711814914431, 0.14753133138375624, 0.16260909874524387, 0.19842129493398325, 0.10639238424066987, 0.11152103011097227, 0.16422280429729394, 0.13497068466884748, 0.16610816812941007, 0.18648894450494222, 0.1018146952348096, 0.09079249775303261, 0.09796256372439009, 0.10703038357730423, 0.06653399552617754, 0.1765755478824888, 0.1279544968690191, 0.13370258414319583, 0.09930381711040225, 0.11100904829800129, 0.13250366704804556, 0.10687655968857662, 0.09839420020580292, 0.13284544513693877, 0.1322862237159695, 0.13179104243006023, 0.113739636061447, 0.06455285647617919, 0.2142357884773186, 0.31336942900504383, 3.774308374949864, 26.336943524224417, 50.091721057891846, 60.63628986903599, 50.519664083208355, 43.588582379477366, 34.581340721675325, 37.36195421218872, 37.65274327141898, 23.873556988579885, 11.124734708241053, 2.465653168303626, 0.8889377628053937, 0.9713289588689804, 3.6555988362857272, 6.4296901396342685, 9.822986228125435, 13.022033265658788, 12.833592908723013, 10.049874441964285, 10.447613648005895, 11.812688878604344, 19.093875544411794, 29.420468943459646, 42.01754951477051, 47.233815806252615, 49.984795229775564, 50.437376567295615, 49.927649770464214, 48.98097160884312, 47.9980377469744, 45.567349433898926, 41.02626044409615, 39.946913378579275, 44.464538301740376, 45.87925754274641, 49.87684801646641, 49.076443331582205, 45.823720591408865, 45.7507575580052, 45.42688812528338, 47.136360372815815, 46.22517360959734, 48.581279958997456, 46.381209305354524, 45.420773710523335, 51.208991391318186, 48.622781549181255, 47.755952085767476, 45.64551666804722, 42.95549726486206, 40.95784500667027, 42.94588095801217, 36.685984815870015, 38.581227575029644, 40.12684392929077, 45.53345264707293, 46.90450593403408, 50.2375567981175, 46.60069247654506, 34.72353213174002, 47.41550077710833, 46.26691491263253, 48.362439496176584, 49.337789399283274, 51.24213777269636, 51.43044785090855, 49.46414239065987, 50.20382329395839, 49.89431231362479, 48.586088112422395, 38.939834526606965, 35.300260407584055, 37.214575971875874, 37.13338279724121, 39.5294760295323, 41.830007212502615, 48.800655433109824, 49.2159492628915, 53.3236791065761, 48.33384765897478, 51.162434986659456, 50.54319415773664, 47.656488622937886, 48.51057856423514, 45.15022127968924, 43.05544015339443, 42.591682638440815, 41.74443667275565, 43.345708097730366, 48.07496125357491, 47.51332793916975, 49.42273460115705, 48.63116455078125, 42.64412416730608, 30.05325528553554, 20.334841183253697, 16.7981664112636, 9.523796796798706, 10.50693302495139, 12.592479126793997, 15.84818090711321, 14.622739280973162, 19.55210750443595, 15.524384430476598, 5.920466218675886, 4.004966855049133, 1.3649628651993615, 0.7853112976465906, 1.7739225434405463, 8.14386544908796, 20.1021077973502, 35.74633823122297, 44.68683896745954, 61.24698093959263, 47.255108560834614, 49.108908789498464, 62.56018352508545, 47.922086988176616, 22.831261192049297, 3.714422719819205, 0.20627871687923158, 0.11069232172199658, 0.12584228520946844, 0.16333285133753503, 0.14619400671550206, 0.14847172663680144, 0.12272171622940473, 0.10197230534894125, 0.07108701978410993, 0.12831201697034494, 0.1210426270429577, 0.09966528628553663, 0.11086859154914107, 0.1471776653613363, 0.11115104532135384, 0.17097956101809228, 0.1808222678623029, 0.24742323479482106, 0.11367001158318349, 0.1670932245573827, 0.08539083653262683, 0.2097980880311557, 0.19088334084621497, 0.27332888756479534, 0.1717339019690241, 0.17360238384987625], [0.058096493993486674, 0.050674172450921366, 0.020559840070615922, 0.11515134173844542, 0.01345323069420244, 0.043793427026165385, 0.04443051034052457, 0.035862808115780354, 0.034920584210859876, 0.02979118177401168, 0.006607888682213212, 0.07933506755424397, 0.033799790245081694, 0.0661205912807158, 0.049609069246798754, 0.049954155193907876, 0.04857614556593554, 0.010310090246743389, 0.05722262231366975, 0.03826803155243397, 0.05101969266044242, 0.017998707946389914, 0.051509387990725894, 0.07124372744666678, 0.047128833763833554, 0.07085477760327713, 0.019177409786997095, 0.06708431456770216, 0.05057794600725174, 1.389594663466726, 11.612523436546326, 33.433234282902305, 49.277729170663015, 47.696513720921104, 38.34801128932408, 25.5377356665475, 25.29092870439802, 24.362057038715907, 17.846420288085938, 9.892177258219037, 3.1175726779869626, 0.24547833630016871, 0.09795051972780909, 0.07146739294486386, 1.4104048439434596, 1.3239021599292755, 2.7820250604833876, 4.673040926456451, 3.4195737412997653, 4.106785757201059, 8.692061815943037, 11.256246737071447, 19.119055816105433, 32.0553891318185, 41.56144544056484, 44.75336102076939, 44.681763308388845, 43.217121260506765, 41.81108379364014, 41.987474237169536, 39.71989836011614, 41.47130993434361, 40.169387749263215, 44.35123750141689, 45.585143770490376, 46.120370456150596, 48.03267799104963, 43.3678172656468, 47.74183334623064, 48.5502736227853, 46.41027014596121, 48.85707827976772, 47.45250340870449, 46.95672859464373, 44.60856403623308, 47.32946123395647, 45.029496329171316, 44.14980227606637, 44.173735346112935, 45.868671962193076, 43.601846490587505, 44.89079986299787, 40.0955422946385, 36.2666506086077, 35.63916574205671, 38.14329651423863, 43.746921403067454, 46.815159048352925, 44.90461982999529, 30.736843381609233, 48.58563995361328, 46.267067773001536, 47.026818547930034, 45.46746907915388, 46.63919939313616, 46.60551452636719, 45.65740156173706, 44.96777548108782, 43.34262657165527, 41.07705872399466, 34.65765626089913, 32.826413358960835, 33.26410123280117, 33.60123477663313, 34.3210438319615, 40.17646101542881, 44.70902803965977, 44.201125144958496, 47.18699884414673, 47.63186073303223, 46.449631690979004, 48.64666598183768, 44.090023449489046, 43.94926684243338, 42.05805056435721, 39.7765748160226, 39.49087878635952, 39.41505309513637, 40.372379371098106, 41.174486364637104, 42.19318607875279, 45.06721115112305, 46.30507441929409, 40.88097708565848, 29.512317180633545, 16.960844584873744, 7.148850841181619, 3.3412681945732663, 3.2668770892279486, 8.249476330620901, 2.747615626880101, 6.553669886929648, 3.4529190148626054, 5.596966343266623, 4.342924628938947, 0.5798725528376443, 0.7102327549031803, 0.22186503266649588, 1.3886205043111528, 6.090907267161778, 18.839105946677073, 34.65039191927229, 44.368194580078125, 43.17639786856515, 28.522662673677715, 45.53483533859253, 45.392577920641216, 34.906342710767476, 13.561762384005956, 1.4289270043373108, 0.015360821637191942, 0.07709379853414637, 0.05784142589462655, 0.04742364026606083, 0.05713150863136564, 0.08928011104996715, 0.03674975177273154, 0.02389254454257233, 0.0386938394180366, 0.02645703880781574, 0.03739409201911517, 0.018412531187225665, 0.01961444571082081, 0.0060811326173799375, 0.01823287207766303, 0.04240340054301279, 0.03564130035894258, 0.014944901723148567, 0.029229517626975263, 0.040351490290569406, 0.05751401239207812, 0.034509934817573855, 0.06845070089080504, 0.01818794966675341, 0.015660820628649423, 0.029743236489593983, 0.03525789414665528, 0.05497342800455434, 0.017964497907087207, 0.10573236644268036, 0.06005235082869019, 0.03529083362913557, 0.03741217837003725, 0.024465072035257305, 0.09501137065568141, 0.026075345896450535, 0.05256503920203873, 0.038651118853262494, 0.008822626134912883, 0.044165522059691806, 0.07836819586477109, 0.02243520399289472, 0.016500601012791907, 0.05210367949413402, 0.02868006032492433, 0.02657741431279906, 0.03269235324114561, 0.0316177607247872, 0.03189382269712431, 0.014709283830597997, 0.053413292792226584, 0.06074993911066225, 0.021013126908136264, 0.053435860866946835, 0.1030013986996242, 1.984077432325908, 14.23531641278948, 39.08534370149885, 53.80402544566563, 52.71615294047764, 43.30787515640259, 29.689454555511475, 32.66942923409598, 29.413461685180664, 19.958723034177506, 10.688525932175772, 3.14612478017807, 0.38888950805578915, 0.1577858818428857, 0.6068582162261009, 1.2199947812727518, 2.324794292449951, 6.515117807047708, 8.04229668208531, 4.9148169585636685, 6.445090821811131, 6.180311041218894, 14.493376851081848, 25.140703439712524, 36.727677481515066, 44.73280477523804, 47.18500471115112, 45.9231493132455, 46.52345282690865, 43.954783712114605, 44.36617265428816, 41.52177470070975, 41.843003817967, 42.279201303209575, 46.44437885284424, 46.94501393181937, 47.9154896736145, 48.771160330091206, 44.67838648387364, 48.251382963997976, 48.6140580858503, 47.991099970681326, 49.2489914212908, 47.19596202032906, 46.407212938581196, 45.01472098486764, 47.79450069155012, 48.00108105795724, 46.10272550582886, 45.1073682648795, 46.04022993360247, 45.00885670525687, 44.793299266270225, 40.269021442958284, 38.884773526872905, 36.69847420283726, 41.05972991670881, 46.153443881443565, 49.07710688454764, 46.463034766060964, 33.16809449877058, 48.775839941842214, 47.0248487336295, 49.56695488521031, 47.14342669078282, 48.7199764251709, 48.622138840811594, 47.640195097242085, 46.9270076751709, 45.75288370677403, 42.6627835546221, 36.226750578199116, 34.41937126432146, 36.0636624608721, 34.58138935906546, 35.53984819139753, 40.20127303259713, 45.92576878411429, 46.41258042199271, 49.98542056764875, 47.229681628090994, 47.325056076049805, 49.434244292122976, 46.37201336451939, 45.70308596747262, 43.811671665736604, 41.9655214037214, 41.29435668672834, 41.47144889831543, 42.26507908957345, 43.68627405166626, 44.81217404774257, 46.81587471280779, 47.89160524095808, 41.8569210597447, 31.260914734431676, 19.365051576069423, 11.112818547657557, 6.67418508870261, 7.913433653967721, 7.844442384583609, 9.048022372382027, 9.120162044252668, 7.72501848425184, 6.751177208764212, 5.093203272138323, 1.1452125140598841, 0.41791368063007084, 0.19096490075545652, 1.4587157773120063, 6.683405348232814, 19.632798671722412, 35.98370953968593, 44.2227965763637, 47.98686156954084, 37.08926521028791, 50.34078271048409, 51.58268983023507, 39.96367938177926, 15.961975029536656, 2.021799853869847, 0.02242350435283567, 0.04788581421598792, 0.015789031516760588, 0.032424691532339366, 0.041288045035409074, 0.07033828353243214, 0.023080938628741672, 0.06993038899132184, 0.025326784367540052, 0.040680630664740286, 0.02835237031935581, 0.03305611586464303, 0.030924759339541197, 0.019426498296005384, 0.04750099325818675, 0.025546305713110735, 0.05330557535801615, 0.05375819214220558, 0.0053734256819422755, 0.08381021634808608, 0.03251692479742425, 0.031034091687096015, 0.08369544893503189, 0.01295577546781195, 0.05789680113749845, 0.04037012964753168, 0.14456119361732686, 0.16836880253893988, 0.102899184184415, 0.2296037652662822, 0.10686059375958783, 0.12321758962103299, 0.14418699512524263, 0.19042722960667952, 0.13229402686868394, 0.058937965626163144, 0.1476917370621647, 0.14226180128753185, 0.09376133273222617, 0.11610802183193819, 0.10177345387637615, 0.1758622040173837, 0.1831808691578252, 0.18143046594091825, 0.09999648601348911, 0.08262075803109578, 0.19684896644737038, 0.15105527586170606, 0.11900432141763823, 0.1143695879727602, 0.2090099560362952, 0.19237891345151834, 0.07529262732714415, 0.12459519212799412, 0.2728970678789275, 2.3854290502411977, 16.322468417031423, 41.41530050550188, 59.29767772129604, 59.35605648585728, 48.56352383749825, 36.27357448850359, 36.34216710499355, 33.79164668491909, 25.93504408427647, 13.713286093303136, 4.598736456462315, 0.642140300146171, 0.4064083051468645, 0.8239370392901557, 5.667944363185337, 6.82989421912602, 9.884889466421944, 13.704003299985613, 10.401263952255249, 9.78580641746521, 12.034081935882568, 13.872631737164088, 21.711022240774973, 36.00628771100725, 45.91768108095442, 49.37278747558594, 48.4112297466823, 48.189064570835654, 45.4995037487575, 44.93577207837786, 42.923969813755576, 45.42289291109358, 44.07308374132429, 48.26207276753017, 50.04665504183088, 50.79637609209333, 49.68454967226301, 44.35082408360073, 49.008576801845, 51.57746131079537, 49.07692970548357, 51.286519391196116, 47.34761340277535, 47.03112990515572, 45.179646900721956, 50.2556186403547, 48.8884493964059, 47.39172056743077, 47.03717483792986, 49.06327302115304, 47.34348269871303, 48.92513588496617, 42.67326143809727, 40.7731271471296, 39.404557841164724, 41.507555212293354, 47.47913237980434, 51.79686457770211, 47.725859437670024, 36.84253815242222, 48.971244130815776, 48.05205304282052, 50.23234564917428, 49.92199741091047, 50.18750892366682, 51.64951760428292, 48.096351282937185, 49.713527134486604, 47.41876295634678, 45.50704254422869, 38.11824825831822, 36.87502098083496, 37.94484901428223, 36.57778051921299, 36.71063355037144, 42.619260038648335, 48.18330104010445, 48.650445801871165, 51.85025800977434, 49.43016569955008, 46.42883225849697, 50.35488755362374, 48.019507680620464, 48.098717144557405, 45.85638754708426, 43.85314546312605, 43.60254825864519, 42.83698878969465, 44.530205726623535, 46.545520305633545, 46.339784145355225, 49.68503604616438, 50.38017552239554, 45.073005948747905, 33.8576580456325, 20.23771926334926, 11.301069566181727, 8.108598130089895, 7.772553716387067, 16.559071949550084, 10.791141271591187, 15.651162999016897, 13.645770447594778, 11.832476479666573, 9.201759951455251, 2.0843336411884854, 1.596114993095398, 0.48801014785255703, 1.9713214082377297, 8.080010635512215, 25.98334448678153, 45.68024723870413, 53.70573622839791, 51.944062164851594, 41.22681324822562, 58.18050118855068, 58.457501547677175, 44.10769966670445, 19.495316403252737, 2.4102936131613593, 0.14039714634418488, 0.1523125876805612, 0.172284777409264, 0.1420522289616721, 0.11376966802137238, 0.25192645458238466, 0.14455903587596758, 0.10905758158436843, 0.11599804487611566, 0.0809956191639815, 0.12978416654680455, 0.1270321642181703, 0.07594280636736325, 0.1037906367065651, 0.08668370358645916, 0.13563438691198826, 0.14568163135222026, 0.11833183893135615, 0.0987566736127649, 0.14200405297534807, 0.18051205522247724, 0.11154444635446582, 0.20108272640832833, 0.08379507144646985, 0.14117516816726752, 0.3518651361976351], [0.07343545662505285, 0.03098206501454115, 0.01884965192792671, 0.041052145550825765, 0.029235631227493286, 0.040064310521951745, 0.03116555106160896, 0.10548317445708172, 0.08493313073579754, 0.07249645915414606, 0.07177580068153994, 0.014110649703070521, 0.04296023691339152, 0.03590221742966345, 0.03990452570308532, 0.031693580227770975, 0.05260942217760852, 0.013959106540174356, 0.026141900003754666, 0.050697256212255785, 0.05188456357323697, 0.024130080992888128, 0.05545516751174416, 0.023084568791091442, 0.019022376409598758, 0.07872053195855447, 0.04712411794545395, 0.021060704087306346, 0.021459234845159308, 0.35515893516795977, 6.704431465693882, 26.177180119923182, 48.58776610238211, 45.552323954445974, 34.886394432612825, 20.385344164712087, 17.539422818592616, 26.591508150100708, 23.201410838535853, 14.698165450777326, 3.443143333707537, 0.682703612106187, 0.29812277427741457, 0.5714499790753637, 0.6282890119722911, 1.3386225700378418, 6.068333872726985, 4.372528297560556, 2.379987959350858, 3.800739322389875, 2.221499115228653, 7.985031366348267, 18.987663643700735, 30.08847223009382, 37.22090925489153, 42.14813395908901, 44.820946148463655, 44.1013629095895, 44.04349831172398, 40.50422143936157, 41.45834459577288, 43.47439220973423, 44.16372299194336, 43.840819358825684, 46.2238221849714, 47.9257938521249, 45.63203368868147, 47.322902134486604, 48.09106370380947, 45.528297083718435, 47.40665919440133, 46.74334594181606, 46.76182815006801, 46.71186017990112, 45.78375802721296, 45.6882654598781, 46.1473503112793, 47.012387139456614, 45.111412116459434, 46.44390637534005, 44.386159147535054, 45.525920799800325, 44.08609424318586, 40.30639927727835, 35.033091749463765, 40.29352079119001, 44.87272065026419, 46.34375156675066, 46.58586502075195, 31.01733868462699, 46.88650662558419, 47.043695722307476, 43.786470549447195, 43.622600759778706, 43.37189585821969, 42.62025710514614, 43.201102188655305, 40.72964184624808, 39.878595215933665, 35.08264282771519, 31.478369031633648, 33.44619962147304, 32.90800258091518, 34.00156218664986, 35.278220721653526, 40.6079545702253, 43.52071237564087, 43.71121808460781, 48.54341575077602, 48.09268263408116, 47.04187182017735, 47.77821063995361, 47.55466277258736, 44.05738776070731, 42.46528100967407, 40.58536945070539, 40.23200144086565, 38.93848657608032, 40.24960470199585, 41.230506215776714, 42.14972162246704, 43.74766486031668, 45.911403383527485, 39.23678316388811, 29.09960286957877, 19.022732939038956, 11.926424809864589, 4.865639345986502, 6.396887694086347, 5.566571448530469, 9.34986080442156, 9.042135511125837, 5.183664909430912, 5.6324851002011975, 5.505433814866202, 0.8483429668205125, 0.18610460869967937, 0.06731303515178816, 1.682504986013685, 7.485202278409686, 19.151573385511124, 32.599495615277974, 41.033021041325156, 43.82261855261666, 34.53227254322597, 39.12088373729161, 48.33030407769339, 32.53072234562465, 10.527947851589747, 0.7496407659990447, 0.04762012365141085, 0.012374374433420599, 0.044430890320135016, 0.05711739510297775, 0.01438027577075575, 0.03855509936277356, 0.06805469428322145, 0.07765526590602738, 0.06529275141656399, 0.03836744711069124, 0.031315256242773364, 0.027070553208302175, 0.026708994127277817, 0.00889273576571473, 0.049135282170027494, 0.06633283024919884, 0.09605203981378249, 0.0405766044610313, 0.08245448981012617, 0.04893400493477072, 0.014861889748967119, 0.006516871267064873, 0.05008653398337109, 0.029379066745085374, 0.022190887281405072, 0.012655147983293449, 0.07659071910062007, 0.07188713470739977, 0.016502344847789834, 0.027257548977753947, 0.017545030951233845, 0.02220928915111082, 0.10557196754962206, 0.08889737658734832, 0.04704108900789704, 0.04243481671437621, 0.05302658550707357, 0.10527685909931149, 0.047218322354768, 0.08673683966376952, 0.0291885341118489, 0.010720962708416795, 0.047775504778006246, 0.07332136774701731, 0.03691854075129543, 0.024772019225305746, 0.07178996849272933, 0.031042186609868492, 0.027288378216326237, 0.028069214263398732, 0.02724470091717584, 0.007235668433297957, 0.022176733040916066, 0.0048837557967220035, 0.09812187696141855, 0.6154826677271298, 8.678542358534676, 32.407815660749165, 53.88655267442976, 50.22093323298863, 41.09843833105904, 25.408535650798253, 19.460257530212402, 27.243867567607335, 27.090317589896067, 15.05308290890285, 4.06065536396844, 0.8643420083182198, 0.26023541444114273, 0.1504960815821375, 1.090666658111981, 4.534862969602857, 5.76648154429027, 6.076174480574472, 7.028290041855403, 7.281806358269282, 6.390565267630985, 9.299552372523717, 18.987319707870483, 30.440634727478027, 39.843816007886616, 44.77612679345267, 46.87214469909668, 45.871621472494944, 45.279412610190256, 42.50390951974051, 42.55415194375174, 45.15646423612322, 45.7689653124128, 45.64950493403843, 48.224507331848145, 50.26995277404785, 47.067733015332905, 47.34282609394619, 50.379418168749126, 46.57156215395246, 48.7490268434797, 47.709180286952424, 48.683401107788086, 46.25949771063668, 45.85101658957345, 46.82603645324707, 46.25354310444423, 48.88633714403425, 47.917522021702354, 47.580888748168945, 46.96699455806187, 47.90885761805943, 44.982891287122456, 41.07366452898298, 38.18075772694179, 41.845484324863975, 46.83397477013724, 49.06132057734898, 46.17920085362026, 34.359390939985005, 49.15392616816929, 49.19490316935948, 47.245384556906565, 46.12420586177281, 46.76580946786063, 45.866194929395405, 46.732857636043, 44.149645941598074, 42.78830623626709, 37.62960924421038, 33.872791222163606, 35.173664229256765, 33.44863149097988, 35.61668831961495, 37.64935949870518, 41.65428032193865, 45.04347610473633, 45.116439138139995, 49.03851311547415, 47.99171836035592, 47.239742619650706, 48.35008559908186, 48.67790160860334, 46.109506947653635, 45.10113573074341, 43.12665918895176, 41.72163963317871, 41.92901904242379, 42.171135970524375, 44.34374039513724, 44.598162582942415, 45.867820807865684, 47.75537885938372, 41.85512147630964, 29.931352615356445, 19.655244827270508, 11.313723104340689, 6.281712182930537, 8.846794724464417, 8.511525903429304, 7.840435879571097, 7.317829728126526, 6.097927553313119, 6.241068695272718, 4.459821990558079, 1.3053186599697386, 0.3386178527559553, 0.2279312578695161, 1.6454065995556968, 8.047269855226789, 22.3216073513031, 35.96314287185669, 45.11390651975359, 49.188298906598774, 36.320731912340435, 46.921747888837544, 54.13816431590489, 38.35818345206124, 12.774369069508143, 1.0855851364987237, 0.0772081520408392, 0.014612597679453236, 0.041416084593428035, 0.06100409797259739, 0.012636296584137847, 0.01968357994753335, 0.019538736469777565, 0.07444941185946975, 0.027124069265222976, 0.028770875451820235, 0.02972046146169305, 0.03870190380673323, 0.025651007059163282, 0.03646223952195474, 0.006479052269631731, 0.05436086355309401, 0.04683736226122294, 0.0481072710826993, 0.04446219114054527, 0.04154459912596004, 0.05905191201184477, 0.006012816439449255, 0.06905814579554967, 0.023786216408812573, 0.017346201531056846, 0.026632048256163086, 0.18319239068244184, 0.17641331015952996, 0.07784273156097957, 0.1350877048181636, 0.12175211682915688, 0.1401545022215162, 0.32244269070880754, 0.215165164321661, 0.1557856827442135, 0.15928275723542484, 0.18691852502524853, 0.1328877992928028, 0.14050938960696968, 0.13071968991841587, 0.1298368072935513, 0.1306220894413335, 0.1806174452815737, 0.12800548199032033, 0.09120649232396058, 0.12544279093188898, 0.15973607291068348, 0.12857839624796594, 0.14885769092610904, 0.13284210674464703, 0.08547920214810542, 0.16702876373061112, 0.2084817165242774, 0.08207493089139462, 0.21079818079514162, 0.7265583074518612, 9.77243982042585, 35.99160269328526, 60.02356992449079, 56.65154314041138, 46.125894274030415, 30.888678891318186, 26.960217782429286, 36.86550889696394, 31.77918781552996, 19.811278785978043, 5.632391733782632, 1.4518829839570182, 0.717464798263141, 1.3898643404245377, 3.035066076687404, 8.404349071638924, 13.947551556995936, 13.136095762252808, 9.769544158663068, 8.898682134492056, 5.540682894842965, 8.879010915756226, 22.61901456969125, 32.65287515095302, 41.35000480924334, 46.18129573549543, 49.71228688103812, 48.701330934252056, 48.261190346309114, 44.52593258449009, 45.14867183140346, 47.84732437133789, 47.826514516557964, 47.48401696341378, 50.061809062957764, 51.015053272247314, 46.16555806568691, 47.81274666104998, 51.65342944008963, 46.57578318459647, 50.65238162449428, 48.957848003932405, 49.671956062316895, 49.752742767333984, 46.84999731608799, 47.54412235532488, 47.58335188456944, 51.6868884904044, 49.265208516802105, 50.906970569065635, 48.67127997534615, 50.18127291543143, 46.53993047986712, 44.15830339704241, 39.30688353947231, 45.640305519104004, 48.54959617342268, 51.23086779458182, 47.99843379429409, 38.16063574382237, 49.42893239430019, 51.157185622623985, 48.9601582799639, 47.76979637145996, 47.0040979385376, 46.22058432442801, 46.95279938834054, 45.890332971300396, 43.64830214636666, 38.81489896774292, 35.01364026750837, 37.45771081107003, 35.788958481379915, 37.49777065004621, 39.933423451014924, 45.32660477502005, 46.846707344055176, 46.873985971723286, 52.706053733825684, 48.62376471928188, 47.88425057274954, 49.932992935180664, 51.86430031912667, 48.9687670980181, 47.4527188028608, 44.41745383398873, 44.63338647569929, 45.16989857809884, 44.92729180199759, 46.81325871603829, 46.44998604910714, 48.422909668513704, 48.70304366520473, 43.274582862854004, 34.22569717679705, 24.07907428060259, 16.67355568068368, 10.266496692384992, 13.06511470249721, 16.862824610301427, 16.487616675240652, 15.387956551143102, 10.821149672780718, 12.792516027178083, 11.103894455092293, 2.5967487394809723, 0.6924548117177827, 0.49344445339271, 2.400150763137, 9.832744104521614, 25.314924308231898, 42.379873752593994, 50.724441392081125, 53.30402265276228, 44.88303872517177, 52.0051646232605, 60.562805720738, 41.9438464982169, 14.979317358561925, 1.6679339621748244, 0.14452624906386646, 0.10481916687318257, 0.1557034578706537, 0.1417912779642003, 0.17796182206698827, 0.14264406077563763, 0.08290133904665709, 0.1919438232268606, 0.2483565461422716, 0.15882205909916333, 0.22182778109397205, 0.08719812812549727, 0.08017000489469085, 0.13343107514083385, 0.25953150221279686, 0.16156134568154812, 0.27975040727428024, 0.1362710834613868, 0.2172838356345892, 0.17282046723578656, 0.07728868057685238, 0.08948924232806478, 0.1969399715640715, 0.12114641575941018, 0.13980189471372537, 0.07312143061842237], [0.04441683107454862, 0.029957300717277185, 0.005919912272864687, 0.032897152073149166, 0.015761242115071843, 0.06228414749992745, 0.04688310569950512, 0.051147437055728266, 0.05117063616801586, 0.031125405537230626, 0.04717045170920236, 0.046153476993952475, 0.06289724460137741, 0.03781322988548449, 0.01272532801210348, 0.06241934560239315, 0.06546461076608726, 0.03361516086650746, 0.04864821616294129, 0.030741839869213954, 0.04792645846360496, 0.029430733794080358, 0.023038330022245646, 0.023356997208403688, 0.03143549943342805, 0.011921303878937448, 0.04622712518487658, 0.015589674535606588, 0.009375563473440707, 0.12713652290403843, 3.31183779665402, 14.532056604112897, 36.77568258558001, 48.26328870228359, 40.72898524148123, 27.49284757886614, 20.67962643078395, 27.620367867606028, 25.89902114868164, 13.453151617731367, 6.094775242464883, 1.0468423068523407, 0.21560895336525782, 0.447352085262537, 0.6540112974388259, 2.7838552594184875, 3.9076260668890814, 4.5643081324441095, 5.738683104515076, 6.321876244885581, 5.163179448672703, 5.070731495107923, 12.656128099986486, 20.48455228124346, 31.31814009802682, 43.55092314311436, 44.88695056097848, 44.88990701947893, 45.16791139330183, 44.52352850777762, 44.494318280901226, 45.66665308816092, 44.67750406265259, 47.378651005881174, 49.25331667491368, 45.593245370047434, 44.86916317258562, 48.651783330099924, 46.90621519088745, 45.41612189156668, 44.20283440181187, 44.08856085368565, 46.966862542288645, 48.09086915424892, 47.270147936684744, 45.58732550484793, 45.04670354298183, 46.39605065754482, 46.74987724849156, 48.75154556546892, 47.973819800785606, 48.437146527426584, 46.5443252154759, 40.33262177876064, 34.89707381384713, 39.428320680345806, 45.71609994343349, 47.23584468024117, 48.35170105525425, 31.54974787575858, 47.4261280468532, 44.643819195883616, 45.458564962659565, 40.83062696456909, 38.30673551559448, 37.537774903433665, 37.09373985018049, 35.47258962903704, 33.48336206163679, 33.24991648537772, 32.79832526615688, 33.18688242776053, 34.04524898529053, 34.404213769095286, 38.14471742085048, 43.148855209350586, 43.56988477706909, 44.99660355704171, 47.665955543518066, 46.81929670061384, 43.73664154325213, 47.841453143528526, 48.93682622909546, 43.40252351760864, 43.68850094931466, 43.237965856279644, 42.875836168016704, 42.410744598933626, 43.769284180232454, 43.593564237867085, 43.93782663345337, 44.91410412107195, 45.15828813825335, 37.73354387283325, 26.93366003036499, 19.316007716315134, 10.958631072725568, 6.5733054961477, 10.310758454459053, 4.125376965318408, 6.988015242985316, 6.080821956907, 6.250504348959241, 5.4019564645630975, 2.377251237630844, 0.7450879045895168, 0.10955787902431828, 0.5027065106800624, 1.9424674936703272, 7.325493591172354, 17.171592133385793, 25.961794648851665, 44.87712580817086, 33.688587529318674, 33.710804394313264, 48.50560017994472, 45.46255670275007, 29.568899835859025, 7.1680969170161655, 0.40023103090269224, 0.03879175541390266, 0.049461321639163155, 0.05298168005953942, 0.03153781233621495, 0.024198840339002863, 0.014512445910700729, 0.03162145534796374, 0.004098061438915985, 0.013745356983106052, 0.037919054206992896, 0.02866445741217051, 0.06034764926880598, 0.020422848939363445, 0.036792051645794084, 0.047358772318278036, 0.013026927498036196, 0.04278717316421015, 0.024000984616577625, 0.02831917638624353, 0.010134772064962556, 0.03811782764803086, 0.06835499352642468, 0.003423729308581512, 0.06120667460241488, 0.009109263075515628, 0.04440033249557018, 0.09622706792184285, 0.08121609554759093, 0.056194176963929615, 0.005634388129692525, 0.015735171103317822, 0.024404120930869664, 0.04081240216536181, 0.01679564669861325, 0.016514399022396122, 0.01261129172053188, 0.04389994345339281, 0.05709489488175937, 0.04214310093915888, 0.012673258082941175, 0.11404224910906383, 0.03859886147880128, 0.0515119935651975, 0.0255019685386547, 0.014792078673573477, 0.03500339601721082, 0.04817892098799348, 0.01930431110252227, 0.01887470344081521, 0.018479789274611642, 0.024345342834879245, 0.019240561041182706, 0.048424414957740476, 0.0369703638633447, 0.04649242219914283, 0.11332572970007147, 4.769657799175807, 18.964897871017456, 43.32320983069283, 53.35592917033604, 43.8174421446664, 29.84780400139945, 25.139734166009085, 32.9190536907741, 30.331690447671072, 16.51906074796404, 6.246697170393808, 1.1768032589129038, 0.23284873685666493, 0.19201322378856794, 1.1224232912063599, 2.7375235855579376, 4.194565389837537, 5.840432524681091, 8.059417911938258, 7.296204328536987, 5.301402134554727, 7.996719104903085, 14.635536125728063, 24.102081503186906, 35.03151798248291, 46.132616656167166, 47.25960404532296, 47.38137469972883, 46.52713189806257, 46.35995129176548, 45.656008447919575, 46.92382192611694, 46.90974834987095, 49.03564350945609, 49.84855842590332, 45.2829145022801, 44.8123060635158, 49.12992014203753, 48.98830543245588, 47.165549755096436, 45.36135271617344, 46.446800300053184, 48.66299077442714, 48.813846588134766, 46.17267649514334, 46.25022186551775, 46.13763672964913, 47.05186332975115, 48.59911598478045, 48.86476298740932, 49.33239759717669, 51.14873661313738, 48.84514822278704, 42.825055258614675, 36.08191885266985, 41.12933349609375, 46.53064768654959, 48.470716748918804, 49.99674265725272, 34.320911816188264, 48.369606563023154, 47.261191708701, 45.48463807787214, 42.87336260931832, 41.81098651885986, 39.370171206338064, 39.44786596298218, 37.78159066608974, 35.258602482931956, 35.49225997924805, 34.93123810631888, 34.58282763617379, 35.78291702270508, 35.33598109654018, 39.751408440726145, 44.60499961035592, 43.78251355034964, 46.80615070887974, 49.349264349256245, 48.04050166266305, 44.88800668716431, 48.27664661407471, 49.46928753171648, 46.29180335998535, 46.544464179447715, 45.02280173982893, 45.309998580387656, 44.14717238289969, 44.80308927808489, 45.31387220110212, 46.0842467716762, 47.93535109928676, 46.422165461948936, 41.03526183537075, 28.93850541114807, 18.27247166633606, 9.821524500846863, 4.828550296170371, 7.911416939326695, 7.66571387222835, 8.557658467973981, 7.687920314925058, 8.757810013634817, 6.466849539961133, 3.4496592240674153, 1.296564906835556, 0.37090974141444477, 0.16899693597640308, 2.2972514161041806, 7.812467643192836, 21.730525834219797, 32.227975436619346, 46.78279781341553, 40.575037479400635, 38.3913437298366, 51.81848737171718, 50.82178912843977, 35.3443397794451, 9.462501525878906, 0.7277226192610604, 0.03343142376148275, 0.026113148778676987, 0.025742137704842856, 0.036811057411666424, 0.06442464728440557, 0.030637854377606084, 0.01358733550711934, 0.03644393264715161, 0.04841126834175416, 0.02609066721717162, 0.009818901291250117, 0.06216351075896195, 0.07015526906720229, 0.011701590847223997, 0.05102453400780048, 0.02515904711825507, 0.01283454246419881, 0.04529662636507835, 0.010602388713907982, 0.0632695092686585, 0.056822717522404025, 0.10070569081498043, 0.011288413062824734, 0.0338034543341824, 0.02198427845723927, 0.05563264173854675, 0.13772888880755219, 0.2440580539405346, 0.11389213002153806, 0.16645229394946778, 0.10074318666011095, 0.1323112209460565, 0.16534193924495152, 0.11603533716074058, 0.09651509925190892, 0.10014693079782383, 0.13637393579951354, 0.1687402461788484, 0.18422746871198925, 0.0934103469231299, 0.11798332977507796, 0.17155295025025094, 0.1365333508167948, 0.12199379743209907, 0.1745691741151469, 0.16043888591229916, 0.13856466753142221, 0.0844672146652426, 0.26221939655286924, 0.09588171395340137, 0.07981198946280138, 0.053542998153716326, 0.12388866075447627, 0.1162526990686144, 0.1439946304474558, 0.33481061990771976, 5.723258103643145, 22.193585055215017, 48.52917889186314, 57.59038373402187, 50.23602819442749, 38.268371037074495, 30.731079850878032, 37.03031669344221, 35.523909023829866, 19.361230066844396, 9.578222904886518, 1.6241926636014665, 0.676451536161559, 0.8011988965528352, 2.4028114889349257, 6.496246499674661, 10.745400411742073, 13.51138881274632, 10.87982199873243, 11.58524567740304, 6.603203160422189, 8.60194194316864, 13.727696657180786, 24.80986843790327, 37.457794189453125, 47.059627941676546, 49.483027594430105, 50.28346354620797, 50.23221363340105, 47.848390919821604, 47.30554206030709, 49.49741036551339, 48.72371455601284, 51.828385080610005, 52.98856748853411, 45.26457125799996, 45.452054500579834, 50.860372475215364, 50.74406657900129, 50.23359979901995, 47.25415665762765, 48.30694770812988, 49.45740958622524, 51.36555862426758, 48.116570540836875, 45.57894945144653, 46.688538551330566, 47.0269227709089, 50.045098645346506, 50.61741828918457, 49.783485071999685, 51.91074207850865, 51.70773308617728, 44.25811774390084, 37.36578266961234, 42.57644176483154, 49.2583714893886, 50.735013076237266, 51.735727378300254, 37.21167509896414, 48.81232840674264, 50.42344890322004, 48.9679228918893, 44.28632743018014, 42.42524896349226, 40.65587977000645, 40.48895624705723, 38.803840909685405, 36.29008340835571, 37.44705574853079, 36.259660720825195, 36.48151670183454, 37.249605315072195, 37.203580447605674, 41.99995667593819, 46.703595297677175, 46.17119305474417, 50.35121890476772, 51.34979316166469, 50.226582118443076, 45.20556020736694, 49.11076395852225, 52.496485642024446, 46.96358299255371, 48.350578921181814, 48.83570214680263, 48.62672117778233, 45.809487206595286, 46.8589049066816, 47.100170680454795, 48.694236823490684, 49.04097277777535, 50.14483656202044, 40.9938679422651, 30.626665796552384, 22.693296023777553, 13.443389398711068, 10.971193415778023, 16.89031515802656, 10.298073649406433, 15.868605136871338, 14.176744835717336, 13.717235275677272, 13.99175773348127, 8.462203247206551, 3.042441589491708, 0.8617764945541109, 0.7566341821636472, 2.8173807518822804, 10.3086097240448, 23.822536366326467, 36.20986645562308, 54.88789231436593, 43.56717150551932, 44.658267974853516, 60.13865293775286, 58.01221581867763, 40.635156767708914, 10.927758489336286, 1.127432073865618, 0.11549404263496399, 0.13125217705965042, 0.16372834225850447, 0.11339979858270713, 0.15767712625009672, 0.07247625238129071, 0.1511938055711133, 0.10448300705424376, 0.06269998090075594, 0.12740028303648743, 0.16333760108266557, 0.16099736094474792, 0.19667864058698925, 0.12640290441257612, 0.1055406192317605, 0.11781266464718751, 0.15932272294802324, 0.16591969824263028, 0.10122217131512505, 0.13660657831600734, 0.21546525321900845, 0.1659064260976655, 0.14194586181214877, 0.14410825792167867, 0.08283801815871682, 0.18523563604269708], [0.024153398848803978, 0.02382147648105664, 0.06642687520278351, 0.03899544144847563, 0.033060485630163124, 0.03146456787362695, 0.0386699414146798, 0.09937832025544983, 0.03249427190582667, 0.022557750809937716, 0.01871459122880229, 0.08205121609249286, 0.04101213234077607, 0.03058803633653692, 0.026142534433997104, 0.037872452421912124, 0.03008207312918135, 0.04574749252891966, 0.0698995292186737, 0.025391801593026946, 0.015616434260404535, 0.03480666496657899, 0.02387252097417201, 0.061321475942220004, 0.03785684272380812, 0.015172341572386878, 0.03217083801116262, 0.015760736606482948, 0.02166174871048757, 0.052938277567071576, 1.4045657515525818, 9.176980938230242, 30.40336459023612, 47.85018702915737, 42.650763171059744, 31.05326087134225, 21.500238214220317, 20.63390554700579, 27.29896330833435, 21.488134452274867, 7.680523089000157, 2.3734077981540134, 0.38692998034613474, 0.1728375663182565, 0.9365582189389637, 2.762274805988584, 3.0829511071954454, 2.4927474515778676, 7.4518457140241345, 6.550242253712245, 6.994794947760446, 3.7513654232025146, 6.955518952437809, 16.28018515450614, 24.983611617769512, 38.63098015104021, 45.65597023282732, 49.34328195026943, 46.693357127053396, 48.92091138022286, 46.69585500444685, 48.86636107308524, 47.85663148335048, 48.7801582472665, 45.409941468920024, 45.751897062574116, 47.09303835460118, 49.372735364096506, 43.65279763085501, 43.640391622270855, 41.93252788271223, 43.6429694039481, 44.55978420802525, 47.69462728500366, 47.61465351922171, 46.74365166255406, 45.56316661834717, 47.49604082107544, 48.937628746032715, 47.73507969720023, 46.14813198362078, 43.464230469294954, 42.19622938973563, 38.30243458066668, 35.28320952824184, 39.55424288340977, 43.36416598728725, 47.31393895830427, 46.80182198115757, 34.018227440970286, 49.42127547945295, 43.83341605322701, 41.66410507474627, 37.05694219044277, 33.73938580921718, 32.81092235020229, 33.02179670333862, 32.394197191510884, 32.231327942439485, 32.34415626525879, 33.052882943834575, 34.55685874394008, 35.51613746370588, 39.60211944580078, 45.177298409598215, 43.46858351571219, 44.11120503289359, 45.93056651524135, 48.866041455950054, 46.55426113946097, 48.91160079411098, 45.248343740190776, 46.75734656197684, 48.24145746231079, 45.81257568086897, 44.952885491507395, 44.25090551376343, 44.460289478302, 44.50231565747942, 45.541116510118755, 45.4390092577253, 47.46950912475586, 44.246573311941965, 36.89203017098563, 22.577118669237407, 12.90099390915462, 6.675037980079651, 2.73102810553142, 4.3373604246548245, 7.362865345818656, 5.768989843981607, 4.569548811231341, 4.8714093906538825, 2.5366954590593065, 1.6074264432702745, 0.9015107452869415, 0.4416788811130183, 0.21673201024532318, 3.058417235101972, 9.094706450189863, 25.022938421794347, 31.84890604019165, 44.80942256110055, 44.61990002223423, 35.45679289954049, 46.409158434186665, 46.85707058225359, 21.271371500832693, 5.487619502203805, 0.366703312844038, 0.054272274021059275, 0.06322712797139372, 0.025575243535318544, 0.017188023143847073, 0.0421007196418941, 0.02456368352951748, 0.04737698759085365, 0.08552256732114724, 0.032324909565172026, 0.03460279572755098, 0.06396959455949919, 0.06684308179787227, 0.041787090578249524, 0.021583135339564512, 0.04370206228590437, 0.0334853164053389, 0.049806794351232905, 0.023232133194272007, 0.029519082446183478, 0.04257118868242417, 0.04241114941292575, 0.03444203042558261, 0.07095813884266786, 0.06060476654342242, 0.09022323401378733, 0.048754077803875716, 0.016148943454027176, 0.020574778019051467, 0.053353978653571436, 0.003963182247909052, 0.03293494647368789, 0.04000056215694972, 0.04476545558177999, 0.041087914524333816, 0.04582690826750227, 0.032726578547486236, 0.02149469169255878, 0.07417831676346914, 0.03402516904420086, 0.03252122670944248, 0.03689181664958596, 0.024347015423700213, 0.0484093921924276, 0.03131632832810283, 0.08046801747488123, 0.07374463110630002, 0.030436041099684577, 0.06731737099055733, 0.019807865510561636, 0.042032367416790554, 0.06133896178965058, 0.02946315419727138, 0.05568470912320273, 0.028621516323515346, 0.01968943570474429, 0.04149936119626675, 1.8201137334108353, 12.6170540366854, 37.10147319521223, 53.37368876593453, 48.45592056001936, 35.54826593399048, 21.23880181993757, 27.540694611413137, 32.278825828007285, 22.665053333554948, 9.19773781299591, 2.3831133459295546, 0.22911635999168667, 0.1365627178124019, 0.9348484192575727, 1.1698977266039168, 4.656298807689121, 8.773598057883126, 11.506069217409406, 7.1993438346045355, 6.056856751441956, 6.456975715500968, 9.431543827056885, 20.416765655790055, 29.21747384752546, 42.089859417506624, 47.03121675763811, 49.635648250579834, 48.943124771118164, 48.387564182281494, 47.18412228993007, 49.35078600474766, 50.21527739933559, 48.349550587790354, 46.41663122177124, 45.323314802987234, 46.432483536856516, 49.34755856650216, 46.52109738758632, 45.22187457765852, 44.35042108808245, 45.77130338123867, 46.48392799922398, 49.31211233139038, 48.53467491694859, 47.12667458398001, 45.26750339780535, 47.98348127092634, 48.86970315660749, 50.061948026929585, 47.65789563315255, 46.81220953805106, 44.986104828970774, 40.85983371734619, 37.80749702453613, 41.84417111533028, 45.764945779527935, 49.99380704334804, 47.0995557648795, 35.925184862954275, 49.864177976335796, 46.61453676223755, 43.41529778071812, 39.50775596073696, 36.08785956246512, 35.00561162403652, 35.00254052025931, 33.71594953536987, 34.18730837958199, 34.0132942199707, 35.043861457279746, 36.994495255606516, 36.289767265319824, 41.24231815338135, 45.57680245808193, 45.4702205657959, 46.9017197063991, 47.069824423108784, 49.606107984270366, 47.27963917595999, 49.12982634135655, 44.93674482618059, 49.15485027858189, 49.877066884722026, 47.25598750795637, 47.443178926195415, 46.84533854893276, 45.329130445207866, 46.31087269101824, 46.63799735477993, 47.84841176441738, 48.82525553022112, 46.5928236416408, 39.71536118643624, 27.076035567692347, 17.768407651356288, 9.070037739617483, 5.228258882250104, 7.082937623773303, 6.760520798819406, 8.282864161900111, 7.618359293256487, 9.660506078175136, 4.825943853173937, 2.9277867589678084, 0.3500956797174045, 0.3607708811759949, 0.3260383834796292, 2.682724663189479, 9.701813987323217, 25.68409252166748, 30.7680755342756, 48.077004023960654, 44.40186555044991, 38.47724430901663, 53.72502095358712, 51.09521811349051, 26.92622545787266, 7.667686292103358, 0.29809009603091646, 0.09487136852528368, 0.051692572089710405, 0.051971368558172665, 0.03516891784965992, 0.07735244251255478, 0.015144416463694401, 0.02782495353104813, 0.06738456631345408, 0.05325319923992668, 0.03143061737396887, 0.008662671682291796, 0.010342985624447465, 0.024599712042670165, 0.03709890892995255, 0.027048122536923205, 0.027254573601697172, 0.047682996706238816, 0.03408905311620661, 0.03812632969181452, 0.013549633556976914, 0.027158677943849137, 0.03805326843368156, 0.03726439344297562, 0.025005492947197387, 0.026813015241974165, 0.038655814315591536, 0.06524826666074139, 0.12796358923826898, 0.13317771016487054, 0.15242769436112472, 0.15799032444400446, 0.13139699000333036, 0.14395325338201864, 0.16343685718519346, 0.17099999849285397, 0.18926860392093658, 0.09009328777236597, 0.24411594654832566, 0.128512211942247, 0.10902577186269419, 0.12457516177424363, 0.18902346278939927, 0.0994767349745546, 0.1700173169374466, 0.16695499340338366, 0.22036275613520825, 0.15858229196497373, 0.21255087746041162, 0.09850585314312152, 0.14665808395615645, 0.10939603485167027, 0.073038276151887, 0.1640017240175179, 0.09572604444942304, 0.09304636038307633, 0.12538743604506764, 2.301748203379767, 15.356396096093313, 42.75008072171892, 60.41924204145159, 55.671482358660015, 42.11942400251116, 30.538868359157018, 30.206393582480295, 36.697998251233784, 27.960331065314158, 11.792096155030386, 3.393885599715369, 0.7400076314806938, 0.4571668228932789, 2.2917936061109816, 6.444660033498492, 6.495130445275988, 7.035861841269901, 14.63358541897365, 14.509028536932808, 13.41644081047603, 8.166712863104683, 10.149793011801583, 20.036398683275493, 27.713574477604457, 41.2995365687779, 48.03059005737305, 52.79476138523647, 50.31040866034371, 54.88145480837141, 49.587531975337434, 52.283426080431255, 51.96574749265398, 50.80144827706473, 45.79253012793404, 46.576210498809814, 47.06533241271973, 52.923108509608674, 48.084716524396626, 46.962401798793245, 47.05337456294468, 48.781252588544575, 47.44079916817801, 52.095432145254954, 50.76012734004429, 48.24256222588675, 47.78020824704851, 49.17770985194615, 50.44297334126064, 51.27310936791556, 49.759534631456646, 47.390442098890034, 45.21955735342843, 42.15787533351353, 39.3032009942191, 42.95394434247698, 46.50965370450701, 52.800552708762034, 48.80263566970825, 39.2153514453343, 53.0781888280596, 48.72037247249058, 45.552813802446636, 41.42547961643764, 37.079895564488, 35.85249975749424, 37.63703686850411, 36.79983452388218, 36.30693973813738, 35.73627723966326, 36.17696326119559, 39.31718076978411, 38.31864125388009, 44.929157393319265, 48.08782236916678, 47.37236636025565, 48.552389349256245, 49.77547379902431, 51.23094769886562, 47.917139870779856, 51.14529030663626, 47.311611311776296, 47.6959821837289, 52.59993042264666, 49.131480012621196, 50.700713293892996, 47.999476024082725, 48.193368979862754, 48.865065234048025, 50.042395796094624, 49.60592385700771, 50.80734729766846, 47.48533364704677, 42.38723189490182, 26.309345279421123, 16.1967841897692, 9.37472927570343, 7.560077803475516, 9.340514608791896, 15.134943110602242, 13.775292686053685, 13.876748544829232, 14.491796135902405, 8.093105384281703, 6.9721789956092834, 2.6143213851111273, 1.2578027525118418, 0.6507948243192264, 3.8751718997955322, 12.333364299365453, 31.389425141470774, 41.74741050175258, 54.00298711231777, 51.87723091670445, 47.94929265975952, 57.96300867625645, 59.248922211783274, 29.724800041743688, 10.239188534872872, 0.5288657184158052, 0.14920763857662678, 0.1524384966386216, 0.27425964762057575, 0.1613862972174372, 0.11494505352207593, 0.09205280191132001, 0.13801799900829792, 0.14833224697836808, 0.15855200216174126, 0.1343625680144344, 0.1653491181454488, 0.1714860059853111, 0.1001281760899084, 0.12774974214179174, 0.1736410739166396, 0.18784939364663192, 0.16696389578282833, 0.11030518356710672, 0.13374439547104494, 0.13448645493813924, 0.10564714244433812, 0.07838518638163805, 0.14377023891678878, 0.1376999153622559, 0.15809720728014195, 0.2148257882467338], [0.06992208372269358, 0.00776449911895075, 0.019706195519704903, 0.06270737014710903, 0.03139502481956567, 0.024868237187287638, 0.09384919623179094, 0.006053774085428033, 0.08189623869423356, 0.010874811194038816, 0.03998074893440519, 0.048954791855067015, 0.027980485631685172, 0.03409533974315439, 0.03688826791143843, 0.045322095177003315, 0.027488062590626732, 0.06325437793774263, 0.033743465053183694, 0.03289822755115373, 0.0777566661792142, 0.04551200016534754, 0.0015289300229466918, 0.030784031176673513, 0.09458708270852055, 0.021061552256079655, 0.031453711313328574, 0.021010909794962833, 0.03377410090927567, 0.058394303013171465, 0.44285434803792406, 6.638207750661032, 23.062585830688477, 45.866733414786204, 44.913954734802246, 34.91272463117327, 33.6007206099374, 22.39598434312003, 24.567781039646693, 20.927194220679148, 10.739994713238307, 3.30680056980678, 0.4648374712892941, 0.13384818418749742, 0.6757691470640046, 0.16064125219626085, 4.625498311860221, 13.904719386781965, 13.497599244117737, 5.336762385708945, 2.7937468886375427, 4.998801571982248, 7.031713332448687, 10.551293798855372, 20.04965932028634, 29.32648066111973, 40.673298903873985, 46.139193126133506, 47.812538215092246, 49.826251234327046, 51.22138350350516, 48.598032065800254, 48.85829768862043, 48.5126873425075, 45.72617483139038, 44.83299779891968, 46.96251991816929, 45.68524299349104, 45.13502904347011, 42.25229787826538, 39.33787945338658, 40.249514375414165, 42.41708830424717, 45.91363375527518, 45.66857426507132, 48.13687317711966, 48.73889636993408, 47.176069327763145, 45.81791884558541, 46.95469624655587, 46.9633606501988, 44.491684913635254, 37.30470452989851, 36.99542284011841, 36.30675213677542, 42.05603906086513, 44.14085994447981, 47.12417670658657, 48.32020834514073, 35.055145331791465, 46.95314679827009, 43.698634896959575, 43.030002798352925, 37.4267635345459, 35.840298720768516, 36.34702736990792, 38.125509125845774, 36.7792192186628, 36.28765153884888, 37.681588717869346, 37.044761998312815, 37.07280840192522, 41.546340056828086, 43.53361518042428, 43.52762583323887, 47.26540231704712, 47.072027002062114, 48.406053338732036, 44.3318589755467, 46.02881751741682, 46.73794371741158, 46.55438968113491, 48.20668172836304, 45.75734097617013, 50.54740129198347, 48.40247849055699, 48.52447843551636, 49.17079292024885, 46.35397236687796, 47.06804568426949, 46.812629904065815, 46.252299376896445, 41.065750530787874, 31.341975893293107, 22.78061750956944, 14.535053883280073, 6.026688975947244, 1.996656060218811, 6.745347235883985, 6.020365246704646, 5.799418611185891, 5.507906070777348, 8.16920552934919, 4.881210693291255, 2.329482589449201, 0.45291159408433096, 0.330201548657247, 0.5359038093260357, 3.5356518668787817, 12.204353622027806, 24.428271634238108, 49.492296491350444, 38.851724420275005, 39.270596572331016, 47.51821947097778, 45.30003138950893, 42.51577009473528, 16.07333901950291, 3.342584009681429, 0.2836302976523127, 0.010360807346712266, 0.01283670190189566, 0.02473511200930391, 0.02246197050304285, 0.07023743965796062, 0.0686381326190063, 0.0037809828728703515, 0.014215041467520808, 0.02856016657980425, 0.03880273411050439, 0.017313390970230103, 0.06737016780035836, 0.033616083674132824, 0.02586739357294781, 0.0279538633102285, 0.029200086170541387, 0.030971622360604148, 0.06474586576223373, 0.03984708432108164, 0.06969894069646086, 0.044598712386297326, 0.05566279583477548, 0.01474569910871131, 0.04295375011861324, 0.03165258653461933, 0.007562273631005415, 0.02576930963966463, 0.039612239958452325, 0.012660482116708798, 0.05902365781366825, 0.01504958949850074, 0.07652566116303205, 0.03156339649909309, 0.06154139592711415, 0.05934177538646119, 0.028303761766957383, 0.05176941957324743, 0.03882512576611979, 0.0708295428859336, 0.013001480738499334, 0.03078693530655333, 0.02734972456736224, 0.07844388644610133, 0.022771806555933187, 0.029088741966656277, 0.0917390337479966, 0.023189753593344773, 0.012926674797199667, 0.043192781042307615, 0.030670325670923506, 0.05596642668492027, 0.020987999060058167, 0.02853643481752702, 0.06064790779990809, 0.023781546391546726, 0.07382704596966505, 0.6535945683717728, 8.173380528177534, 28.59757467678615, 52.11540821620396, 50.15883370808193, 38.05939701625279, 36.75805500575474, 25.110383238111222, 29.982946463993617, 25.4072676045554, 12.942826407296316, 4.311387624059405, 0.34043301535504206, 0.13158174151820795, 0.26523073496563093, 1.3174099368708474, 4.055475481918879, 6.8304882901055475, 6.487092248031071, 5.643767237663269, 4.4675818255969455, 4.660350041730063, 8.426771777016775, 14.841718707765851, 24.475854635238647, 34.00122519901821, 44.89444766725813, 48.90093183517456, 51.142361640930176, 50.25615017754691, 52.31378970827375, 48.600245067051475, 48.782555375780376, 48.654441016060964, 46.47825826917376, 45.35082272120884, 47.30099793842861, 47.210157190050396, 46.80043928963797, 44.52931635720389, 42.44842120579311, 43.603791986192974, 44.46058477674212, 47.773975712912424, 48.43871682030814, 49.27372006007603, 50.179178033556255, 48.66142395564488, 47.26096589224679, 49.38600294930594, 48.4382130759103, 46.56844588688442, 39.64348554611206, 37.98172310420445, 38.45119898659842, 43.50674649647304, 45.75335618427822, 49.569900921412874, 48.23143121174404, 37.41617795399257, 48.839134556906565, 46.61018024172102, 45.231939043317524, 38.207609040396555, 37.586301122392925, 36.729529176439556, 38.68480437142508, 37.66030291148594, 36.421842098236084, 38.89581421443394, 37.87856319972447, 37.521585600716726, 42.86281524385725, 45.47865220478603, 46.17637641089303, 48.87571334838867, 49.00977884020124, 50.42390053612845, 45.936604499816895, 47.215938091278076, 48.892058985573904, 46.61204235894339, 48.74123443875994, 47.20951795578003, 51.46197182791573, 51.47750799996512, 49.84321526118687, 49.32025909423828, 49.42882122312273, 49.14158616747175, 50.28152847290039, 48.27433981214251, 46.061974321092876, 34.13128505434309, 26.820447819573538, 14.659337180001394, 8.857250026294164, 4.8926956312997, 6.018708969865527, 5.956040126936776, 8.68996172291892, 6.066520392894745, 6.9482103160449435, 3.0560978395598273, 1.1776315058980669, 0.5842094229800361, 0.41774594677346094, 0.5120101485933576, 3.959653309413365, 13.120030658585684, 25.10518251146589, 45.347515378679546, 43.750951358250205, 45.29388223375593, 52.413965361458914, 50.05689321245466, 48.95514515468052, 19.847649131502422, 4.854917407035828, 0.2588843697948115, 0.0416555192454585, 0.024284515563132505, 0.01678545001362051, 0.043180411348917654, 0.033306379935571125, 0.07958927391363041, 0.023275740943582993, 0.009705253460976695, 0.02436899995830442, 0.008911671133578887, 0.02940972295722791, 0.03050046121435506, 0.052272678818553686, 0.012939782397422408, 0.05053039088046976, 0.057249322666653564, 0.015244629300598587, 0.04015465745968478, 0.028908071839915853, 0.05345657654106617, 0.0472060747976814, 0.023819144016930034, 0.06766322707491261, 0.0015201200938983156, 0.07152984530798026, 0.010706582006865313, 0.20039268343576364, 0.14842512485172066, 0.06431485353303806, 0.11830042275999274, 0.1301912875579936, 0.11950174186910902, 0.137344430865986, 0.14096535156880105, 0.1175108929829938, 0.07022740412503481, 0.17457518593541213, 0.07381142609353576, 0.1192976249647992, 0.07610246565725122, 0.18167741197560514, 0.07013999524393252, 0.09699254363243069, 0.10208279120602778, 0.08928959018417768, 0.09303297967250858, 0.11827260282422815, 0.11464393325150013, 0.1070585563512785, 0.09513013463999544, 0.09915747067758016, 0.1349252906760999, 0.08236629382840224, 0.24756998834865435, 0.12412555090018682, 0.16056414347674164, 0.8534495128052575, 9.613998310906545, 33.267210551670615, 58.07946743283953, 56.59300456728254, 45.35269526072911, 43.865568842206685, 31.59860760825021, 32.49985497338431, 29.023853608540126, 15.806568145751953, 4.973413722855704, 1.049845774258886, 0.389998831387077, 1.7616017588547297, 3.1697673286710466, 11.515997324671064, 21.17152762413025, 24.472073078155518, 10.37393581867218, 7.919314435550144, 8.92734432220459, 8.927051629338946, 13.942175388336182, 25.776649475097656, 33.98861421857561, 43.819074971335276, 48.62230212347848, 50.45678983415876, 50.32231092453003, 52.47816671643938, 49.93630722590855, 50.30184847967965, 49.56482526234218, 47.07700886045183, 44.604912757873535, 48.292158467429026, 49.73830441066197, 48.3754152570452, 46.94020230429513, 43.790997300829204, 44.35608386993408, 45.81568152563912, 49.269144671303884, 49.64892625808716, 52.55421475001744, 52.25464316776821, 50.13626595905849, 49.76117788042341, 51.89078337805611, 52.43301037379673, 48.19612741470337, 39.81467873709542, 40.89849696840559, 40.135397161756245, 45.453246116638184, 48.10121502195086, 51.17920446395874, 49.87844957624163, 39.89306483949934, 50.32704612186977, 48.4560421534947, 47.63436555862427, 40.28237240655081, 40.40704393386841, 39.57748808179583, 42.55335637501308, 40.13425765718733, 38.631265027182444, 42.61529609135219, 41.76611157826015, 41.295277323041645, 45.99687317439488, 46.790770871298655, 48.03702408926827, 52.029215812683105, 52.876124790736604, 52.30258226394653, 44.791524001530235, 46.61855976922171, 49.55523327418736, 47.39747020176479, 50.01361288343157, 48.108809403010774, 53.592358997889924, 52.6492417880467, 52.97798538208008, 52.3041421345302, 51.44937126977103, 51.19308001654488, 50.70988144193377, 50.07987437929426, 46.93212154933384, 34.799760818481445, 25.952940906797135, 16.978996753692627, 9.12963765008109, 5.9750886133738925, 13.30747308049883, 13.020280582564217, 15.249591861452375, 15.843558618000575, 18.089588131223405, 12.479866198131017, 4.5983443175043375, 1.8023964783975055, 0.9731747912509101, 1.1343356519937515, 4.846779329436166, 15.769565514155797, 32.38666187013899, 58.10536684308733, 48.01251779283796, 53.19582877840315, 58.918493679591585, 59.79971981048584, 53.50497497831072, 24.315497159957886, 6.0637050696781705, 0.4609047366040093, 0.09098818725241081, 0.09969056171498128, 0.10379140345113617, 0.20147087558039597, 0.1069546387131725, 0.18804680662495749, 0.17499476484954357, 0.10059399716556072, 0.08516802598855325, 0.17871111471738133, 0.1555358732917479, 0.18148062324949674, 0.26005801824586733, 0.12161410280636378, 0.07571148699415581, 0.13621821201273374, 0.10403953013675553, 0.15298543657575334, 0.19752568299216883, 0.1721265973257167, 0.10369346370654446, 0.1614273078739643, 0.17453118972480297, 0.12247204248394285, 0.2106207845998662, 0.21387495712510177], [0.032797139404075484, 0.018486254017001817, 0.061063591923032484, 0.08305489830672741, 0.03604619577527046, 0.03771525282146675, 0.02517429719279919, 0.01739829944978867, 0.027969751207690154, 0.0241097113716283, 0.05165114074147173, 0.021389459392854145, 0.0077202934106545785, 0.08050857351294585, 0.04686591162213257, 0.028094625399847115, 0.02617803368983524, 0.019942225622279302, 0.01954587805084884, 0.03866306106959071, 0.032255502218114476, 0.04268364568373986, 0.06255182956478425, 0.049567017039018016, 0.05753138967390571, 0.02018585192438747, 0.11738478046442781, 0.03423688214804445, 0.08171107327299458, 0.0359367853961885, 0.0642878342685955, 3.7029768654278348, 17.50410338810512, 40.302664620535715, 46.26265914099557, 40.18588972091675, 31.889420986175537, 26.696373837334768, 24.530477898461477, 22.01846092087882, 15.045787300382342, 5.707371481827327, 1.5024209235395705, 0.22824083268642426, 0.22872131690382957, 0.8361921959689685, 3.3460672284875597, 6.655461430549622, 3.754383546965463, 3.953039492879595, 3.655693505491529, 2.4271868552480425, 3.3063539309161047, 7.24002206325531, 12.069025295121328, 20.426861388342722, 35.37575953347342, 43.75293854304722, 50.88473285947527, 48.73599897112165, 44.564394337790354, 48.40410089492798, 46.48204156330654, 42.877552373068674, 45.80011061259678, 46.895473275865825, 48.95494018282209, 46.05031524385725, 42.529947893960134, 41.28775242396763, 37.24004806791033, 37.95122398648943, 41.38589572906494, 44.342013767787385, 44.856604303632466, 45.62284122194563, 45.961058684757774, 45.646506786346436, 44.04627759116036, 43.2783522605896, 38.439612865448, 35.70723376955305, 34.649283681597026, 34.30686603273664, 35.61610467093331, 41.7989696093968, 43.69336816242763, 44.831201689583914, 47.51571811948504, 38.042537212371826, 46.8167918750218, 43.1910377229963, 40.840482984270366, 37.35376576014927, 41.366843768528526, 43.10051311765398, 45.35296624047415, 45.3297974722726, 43.923440388270784, 44.811899593898225, 43.77752474376133, 43.889185769217356, 44.24261631284441, 44.391929626464844, 46.51264142990112, 46.808332443237305, 46.59386239733015, 47.12423576627459, 47.72323996680123, 45.847010953085764, 46.16826786313738, 44.0447906766619, 43.139798232487266, 46.41368865966797, 42.97252035140991, 46.5236473764692, 51.44573736190796, 51.08157532555716, 45.92186042240688, 50.53218126296997, 50.935364382607595, 46.070273944309776, 36.14256967817034, 25.676169838224137, 19.022665194102697, 12.048047815050397, 5.539488673210144, 4.755583354404994, 5.210372916289738, 3.9947564772197177, 6.786977367741721, 5.730526787894113, 4.9972599404198785, 2.106231323310307, 0.5536179159368787, 0.2707902709288256, 0.26588470701660427, 0.4287419595888683, 4.133016075406756, 14.241147688456945, 30.75181327547346, 30.530210903712682, 36.08790125165667, 33.04726879937308, 31.026016984667095, 51.83493375778198, 36.57623454502651, 15.836243901933942, 3.0826306215354373, 0.10675274740372385, 0.041093322448432446, 0.02433810116989272, 0.031794804081852944, 0.014350460942036338, 0.018909722633127655, 0.03035785011681063, 0.05038268059226019, 0.02862182505694883, 0.07215682523591177, 0.03538441378623247, 0.002726861121897985, 0.039454120943056684, 0.02320343116298318, 0.02299641352146864, 0.009850375986258899, 0.02993223224101322, 0.05153119610622525, 0.015811535130654062, 0.045241766808820624, 0.025221082182335, 0.05940474343619176, 0.047271818055638244, 0.017607849723260318, 0.03158087216849838, 0.022106243430503776, 0.004584565110105489, 0.01078006565304739, 0.020263858006468842, 0.06632455890732152, 0.03394716126578195, 0.013215190431635295, 0.02570622623898089, 0.018352804838546684, 0.016356498834543994, 0.03326181714822139, 0.035471931232937744, 0.023895684463371123, 0.03452293894120625, 0.09170651834990297, 0.030053622155849422, 0.03976830640541656, 0.036472509149461985, 0.04727042705885001, 0.07879013608076743, 0.007978765210802001, 0.04099297390452453, 0.020928781612643173, 0.06652795656451158, 0.03543911388676081, 0.07178777682461909, 0.026357414600040232, 0.02724453467609627, 0.06110718101263046, 0.038471324036696126, 0.019632937486416528, 0.03610016645065375, 0.14793743459241732, 4.583082165036883, 21.173851796558925, 48.00419385092599, 50.11019284384591, 44.99440792628697, 36.74075746536255, 27.475015027182444, 26.182514599391393, 26.621506997517177, 17.55539151600429, 5.880374678543635, 1.2889003923961093, 0.06612508318253926, 0.374662311481578, 1.0545904168060847, 3.053455135651997, 3.99265855550766, 6.466791348797934, 8.041614890098572, 7.230114800589425, 3.3214795078550066, 4.236164254801614, 9.245504072734288, 15.218335390090942, 22.955100672585623, 37.998152119772776, 43.98789187840053, 51.03068324497768, 49.671063218797954, 46.78221069063459, 47.99936137880598, 48.693253653390066, 45.5705942426409, 46.13893256868635, 45.716051306043354, 49.36033977781023, 47.945512839726035, 45.86987052645002, 43.36123732158116, 40.23531225749424, 40.9097078868321, 44.325421469552175, 46.172148432050435, 46.83089671816145, 48.80626262937273, 47.16297892161778, 47.34870774405343, 45.596719469342915, 46.53653975895473, 41.698540346963064, 39.0587077822004, 35.664061137608115, 35.93025009972708, 37.474987506866455, 43.5381349836077, 46.44735268184117, 48.04270076751709, 47.78401585987636, 40.10132319586617, 48.72510419573103, 44.372551100594656, 42.47511965887887, 40.033755438668386, 42.87298393249512, 44.51888363701956, 48.274464879717144, 46.194090843200684, 46.03124591282436, 45.13297585078648, 45.794829981667654, 45.06283726011004, 46.08673422677176, 45.4123420715332, 48.27425990785871, 48.877763066973, 48.225903919764924, 47.151048864637104, 47.52402121680123, 47.79618910380772, 46.09416879926409, 46.19438961574009, 45.546442304338726, 47.67683294841221, 45.67322955812727, 48.09793199811663, 50.395239216940745, 52.65455715996878, 47.9484623500279, 52.92226777757917, 51.88433197566441, 49.21425042833601, 38.4979499408177, 28.282096930912562, 22.219543525150844, 14.783489329474312, 7.752392649650574, 5.2040101034300665, 5.825611582824162, 7.490154606955392, 6.744591185024806, 4.692456364631653, 5.881918481418064, 4.3710140245301385, 0.7159125272716794, 0.6569395288825035, 0.08740669621952943, 0.7240364370601517, 4.033259919711521, 16.58253080504281, 29.365202971867152, 38.56891884122576, 41.65417957305908, 37.202854360852925, 40.57417590277535, 57.67886209487915, 42.49169111251831, 19.538261481693812, 3.892204974378858, 0.05963315867951938, 0.0546833237500063, 0.03952574709962521, 0.03578055610081979, 0.03249961876177362, 0.00558423124519842, 0.018114118271374276, 0.009994093095883727, 0.04366650705092719, 0.0868855948959078, 0.029303630614387136, 0.029947221079575162, 0.04237867811960833, 0.04579696790980441, 0.01890991092659533, 0.03308422417779054, 0.042878734679626565, 0.029043972226125852, 0.013034469414768475, 0.06051980038838727, 0.001776061806594953, 0.04544207373900073, 0.014851631995822703, 0.022953380830585957, 0.03317670850083232, 0.031490548979490995, 0.040263399481773376, 0.12558502544249805, 0.08066707929330212, 0.12635362919952187, 0.22099964267441205, 0.18498894785131725, 0.10008150645132576, 0.09647501818835735, 0.1387261181537594, 0.09957604535988399, 0.19536382971065386, 0.0927386786788702, 0.09948201397699968, 0.14854172430932522, 0.1732372912977423, 0.1634477815989937, 0.15891267066555365, 0.10842059326491185, 0.1624378500772374, 0.16070882071341785, 0.07170617620327643, 0.20118103256183012, 0.18407032000167028, 0.2657911234668323, 0.12180733600897448, 0.11257202657205717, 0.1542538492275136, 0.16058536805212498, 0.13353096906627926, 0.14644855234239781, 0.08905745656894785, 0.32390800065227915, 5.012179459844317, 24.682714666639054, 54.73625830241612, 57.835543973105295, 50.78659650257656, 42.92213201522827, 37.70918001447405, 34.016580717904226, 30.95181369781494, 21.302059956959315, 7.89097968169621, 2.1896917819976807, 0.6126874834299088, 1.1491667990173613, 2.0687659851142337, 6.566932260990143, 14.648869718824114, 14.256875804492406, 13.032355683190481, 9.57603509085519, 4.557204467909677, 6.162674341882978, 11.401156629834857, 16.419680663517543, 25.817746332713536, 41.14649207251412, 47.86146395547049, 52.895531109401155, 50.20092936924526, 46.146200384412495, 50.07615014484951, 50.13764517647879, 46.30910437447684, 46.32993507385254, 46.200677735464915, 50.76383072989327, 49.219906261989046, 47.03728600910732, 45.152010440826416, 41.65505852018084, 43.43534333365304, 46.771784918648855, 47.799736159188406, 48.02510445458548, 50.79216548374721, 49.413646357400076, 50.33490106037685, 47.641077518463135, 47.63569961275373, 42.20534542628697, 39.97131197793143, 38.054258823394775, 36.67829316002982, 38.72871003832136, 45.78582164219448, 47.2661839893886, 48.886924266815186, 48.96411875316075, 42.54374006816319, 50.956862109048025, 46.226128986903596, 45.491596698760986, 41.470629010881694, 44.44806064878191, 46.99543006079537, 49.89435747691563, 49.02968542916434, 48.33050210135323, 48.04043218067714, 48.00150489807129, 46.928313936506, 47.27996226719448, 48.50516939163208, 50.83818687711443, 50.78821195874895, 49.467463629586355, 48.77112211499895, 46.68772908619472, 48.659843240465435, 47.1285332271031, 47.154588971819194, 48.79392262867519, 48.93916777202061, 44.83356755120413, 47.90704761232649, 51.37478583199637, 52.48728970118931, 49.369869232177734, 54.050293922424316, 53.32707330158779, 48.69246155875069, 38.65282876150948, 29.10655106816973, 23.919797250202723, 15.3066018308912, 8.899634906223842, 11.203769598688398, 12.739298037120275, 11.547121780259268, 14.276201350348336, 15.55036721910749, 13.317514095987592, 6.055163562297821, 4.0279028585978915, 1.7254453961338316, 0.7774009363991874, 0.7635006851383618, 6.088362055165427, 18.458798033850535, 38.67213780539376, 38.523012093135286, 44.99567597252982, 45.05969320024763, 46.410898957933696, 64.22024713243756, 47.18487269537789, 22.751697369984218, 4.6079458594322205, 0.3222784852342946, 0.15962891866053852, 0.12573929716433796, 0.13330417552164622, 0.11431428736874036, 0.12317865528166294, 0.10495081623750073, 0.10114306091730084, 0.10821678170136043, 0.18050638266972133, 0.07079366873949766, 0.08372766577771731, 0.20463481651885168, 0.11799672405634608, 0.1393888025943722, 0.16047087205307825, 0.10504245239176921, 0.1723890003881284, 0.060400690351213725, 0.15443737937935761, 0.12075354398361274, 0.12232197767921857, 0.19163689469652517, 0.13556596344070776, 0.06878232131046907, 0.13538331538438797, 0.0794822960825903], [0.02853156972144331, 0.048762366109128506, 0.06385724951646157, 0.03401241597852536, 0.0841662979551724, 0.0347469708483134, 0.035662938840687275, 0.009335864085837134, 0.05336448237566011, 0.03571941331028938, 0.038051731551864316, 0.05643432068505457, 0.07702089673174278, 0.10798278890017952, 0.08189169250960861, 0.006714359308326883, 0.05239515099674463, 0.020723646905805384, 0.024012782644214373, 0.02542779957210379, 0.05993190407752991, 0.01952278920050178, 0.02244776876510254, 0.028066990364875113, 0.0411817525247378, 0.04661496562351074, 0.12809513003698417, 0.027137132760669504, 0.0897113336250186, 0.028751052051250423, 0.06585909066987888, 1.4549714582306998, 13.356910381998334, 32.45027610233852, 49.51948479243687, 39.11872979572841, 38.903141089848106, 24.670096737997874, 18.090923922402517, 23.57009788921901, 17.368418966020855, 9.728958862168447, 1.687300328697477, 0.38811722663896425, 0.04568187819261636, 0.7076984537499291, 0.6295238371406282, 1.2099438863141196, 2.5767611605780463, 5.495071445192609, 4.885442146233149, 1.8968019783496857, 1.706191177879061, 6.3341128911290845, 10.270662137440272, 17.25187509400504, 29.793267590659006, 41.469489506312776, 44.89621250970023, 45.465638228825156, 45.996254784720286, 46.16890362330845, 44.665650435856406, 45.1402645111084, 45.3892115184239, 45.79900932312012, 49.70971604755947, 45.616646902901785, 43.01107937949044, 41.768341950007844, 36.49391228812081, 35.80139228275844, 38.499165875571116, 41.44621998923165, 40.07948848179409, 40.647239685058594, 40.117463861192974, 40.15145097460066, 39.29648903438023, 34.83498123713902, 33.12570701326643, 33.08273935317993, 33.452435629708425, 35.35674926212856, 39.04199389048985, 42.14485788345337, 43.948488644191194, 46.061835357121055, 49.251127992357524, 35.23232439586094, 46.70553037098476, 43.026493958064485, 41.19053670338222, 40.50215435028076, 43.327691418784006, 46.082443714141846, 47.73622267586844, 45.15268094199044, 46.013805934361045, 46.23006861550467, 45.996768951416016, 45.30848387309483, 45.514678614480154, 47.80533640725272, 47.86280843189785, 47.38253157479422, 48.10789918899536, 47.937675271715435, 48.09591702052525, 48.78951052256993, 48.10343844549996, 45.309672015053884, 37.54830837249756, 43.554119314466206, 45.97400317873274, 44.29815673828125, 48.55522421428135, 48.25364807673863, 51.3806848526001, 50.29984392438616, 49.285799503326416, 38.98250688825335, 35.15069348471505, 24.890087127685547, 15.913101400647845, 8.207564796720233, 6.631624332496098, 2.5949717376913344, 3.335369173969541, 5.214183568954468, 4.222458498818534, 2.6746958025864194, 3.080802376781191, 2.2659767057214464, 1.0639388923134123, 0.3320700169673988, 0.14925795873360975, 1.2514576358454568, 5.238689431122371, 17.919763735362462, 28.596810374941143, 23.94732253892081, 35.14785514559065, 44.46329110009329, 38.633373805454795, 43.83054992130825, 35.516755853380474, 10.479641369410924, 1.1794975314821516, 0.04804678647113698, 0.0630205547703164, 0.02409012715465256, 0.06579709292522498, 0.048946690146944354, 0.04480755528701203, 0.026657199852966836, 0.0557238809498293, 0.04203018253403051, 0.03238042390772274, 0.08397012669593096, 0.05164711024346096, 0.04964219871908426, 0.036026579327881336, 0.005788772233894893, 0.036762308063251634, 0.011670385021716356, 0.008722282680017608, 0.018906799843534827, 0.059148481115698814, 0.03435970716444509, 0.021521308925002813, 0.0067410015617497265, 0.01981507324879723, 0.07004031844969306, 0.046877131198665926, 0.061591675371995995, 0.017667703297255293, 0.046378272252955606, 0.053476885094174316, 0.07102926288332258, 0.05180565334324326, 0.057096448726952076, 0.032303559460810254, 0.027381077974236438, 0.0233405003257628, 0.04142260192228215, 0.05806769696729524, 0.027672929456457496, 0.02004244185185858, 0.05983249869729791, 0.07831264420279435, 0.01129501944940005, 0.05109529163954513, 0.07677431032061577, 0.018749159195327332, 0.02550259279087186, 0.062072553139712126, 0.030792149848171642, 0.04149675562179514, 0.033344452535467486, 0.0167315879038402, 0.05561894890187042, 0.052550542301365306, 0.01957970980687865, 0.039710831096661944, 0.08679100032895803, 0.1331236987773861, 1.9329892822674342, 16.44197222164699, 38.59824023927961, 53.385069915226524, 43.33495576041085, 40.3364189692906, 31.667745658329554, 21.95466603551592, 24.544659171785625, 18.74085668155125, 9.042472498757498, 1.8579061797686984, 0.4367533954126494, 0.03537633243416037, 0.8770852216652462, 2.0246410156999315, 3.3490612506866455, 4.051556697913578, 6.30555579492024, 5.335951617785862, 4.647724296365466, 4.302132189273834, 7.591145804950169, 14.162319506917681, 20.45729102407183, 34.637596811567036, 45.13675914491926, 48.74867595945086, 46.012169633592876, 47.15137890407017, 47.49847616468157, 45.63319403784615, 46.976061957223074, 46.88103839329311, 46.334194319588796, 50.577229908534456, 48.16442278453282, 45.85200323377337, 43.77960572923933, 38.80679389408657, 37.55798026493618, 41.719954695020405, 44.10050480706351, 44.414268084934776, 42.847591740744456, 44.33771283285958, 43.44589417321341, 41.534583704812185, 37.98985597065517, 35.62437302725655, 34.5696052142552, 36.255415371486116, 37.36255175726754, 39.19758142743792, 44.95446968078613, 45.233901909419465, 47.2517352104187, 49.82721355983189, 37.12940842764718, 49.198787212371826, 45.21631601878575, 42.07041140965053, 41.8060428755624, 45.49330595561436, 48.61061872754778, 49.15540613446917, 48.19283396857125, 48.38699095589774, 48.31985398701259, 48.52017055238996, 47.743344579424175, 48.21883760179792, 50.10088920593262, 48.64670419692993, 48.040004866463796, 47.75398921966553, 48.31082827704293, 49.36751726695469, 49.73762696129935, 48.94468464170183, 45.47670323508126, 42.67392151696341, 46.43558938162667, 44.913308552333284, 45.42600917816162, 50.14371790204729, 47.60918181283133, 49.36634302139282, 50.55179950169155, 49.99978596823556, 40.86375944955008, 38.260953835078645, 26.851148435047694, 17.336950574602398, 9.216139248439244, 6.104598692485264, 5.4888180664607455, 6.792454285281045, 6.7629075050354, 6.780600658484867, 5.963299257414682, 4.731975981167384, 2.2969782650470734, 1.0570108869246073, 0.5563293418713978, 0.2969241828790733, 1.1008374094963074, 5.724701591900416, 18.63922016961234, 32.58974034445626, 31.140832492283412, 41.71688706534249, 47.42956740515572, 40.232449599674766, 50.912536076136995, 40.2245877129691, 13.482311470167977, 1.6354165013347353, 0.07287936325051955, 0.0711313145501273, 0.08171277639589139, 0.03769167372956872, 0.046197330712207725, 0.03545652848801442, 0.008077025563190026, 0.05286672944203019, 0.031461175198533704, 0.010742124519310892, 0.07450454961508512, 0.06641691430870976, 0.04235328733921051, 0.01215886916699154, 0.03976666095799633, 0.0472985455500228, 0.05003170156851411, 0.035809085105678866, 0.05591398949867912, 0.08160772560430424, 0.09202207106032542, 0.016459100114713823, 0.03960840284292187, 0.018055687924580913, 0.059765791919614585, 0.06984271548156228, 0.04160216264426708, 0.17439663623060497, 0.17866171736802372, 0.1503747866622039, 0.16775296415601457, 0.12648635064916952, 0.12911681378526346, 0.11733547810997282, 0.06407980900257826, 0.13492531781750067, 0.12180783812488828, 0.17441772509898457, 0.09524558058806828, 0.1602056191435882, 0.2359891054885728, 0.1750479077122041, 0.10604378008948905, 0.11241533248020069, 0.10726075300148555, 0.13150364213756152, 0.1459902019373008, 0.13439824538571493, 0.13748205133846828, 0.06682309215622288, 0.116597801979099, 0.1228607344840254, 0.12948642538062163, 0.3235047065785953, 0.12534899025091104, 0.206919009664229, 0.15265744631843908, 0.17978865546839579, 2.0664062031677792, 18.309059143066406, 43.5827875818525, 60.11738450186593, 51.06788737433297, 49.7939247403826, 35.64892796107701, 27.859476225716726, 32.00055047443935, 24.46496159689767, 11.879574843815394, 2.6384070983954837, 0.8975279618586812, 0.4189942883593695, 3.113074370792934, 5.387085148266383, 6.317512341908046, 7.3082603216171265, 12.92425126688821, 10.830719947814941, 6.267814482961382, 4.582750388554164, 9.08095075402941, 14.345017177718026, 21.267642055238994, 35.097161088671, 48.1406877381461, 51.70886564254761, 48.3362899507795, 49.672463280814036, 48.51171459470476, 47.574215003422324, 48.595652307782856, 46.70328262874058, 45.50558342252459, 51.596989222935264, 49.823676926749094, 47.54749917984009, 46.585392543247764, 41.220490387507844, 40.058011599949424, 43.32011093412127, 47.22373744419643, 45.24246556418282, 43.75892094203404, 44.56888287408011, 43.96296174185616, 44.37547629220145, 39.00222587585449, 36.91520241328648, 36.4621833392552, 37.14969021933419, 38.16955375671387, 42.11361878258841, 45.7712790625436, 47.008409295763286, 49.513425963265554, 51.35099867412022, 40.15957689285278, 51.331675733838765, 45.699997493198936, 44.75024822780064, 45.28599950245449, 47.035788672310964, 49.60139710562569, 50.81078665597098, 47.587868213653564, 49.02747242791312, 50.619551386152, 51.1029896736145, 48.75310891015189, 49.238308565957205, 50.30129957199097, 49.569303376334055, 48.56353078569685, 50.416497230529785, 49.96837663650513, 50.5090263911656, 51.27620479038784, 49.99918842315674, 47.01705632890974, 42.65174981525966, 46.60885313579014, 46.12452547890799, 45.68447869164603, 50.24366079057966, 48.96997261047363, 51.72442265919277, 52.138695103781565, 53.05500268936157, 42.291687216077534, 40.07888051441738, 29.0302928515843, 20.345711639949254, 10.564497113227844, 11.239471180098397, 8.166121397699628, 9.02408582823617, 10.5298490524292, 12.491078853607178, 10.284644518579755, 9.263690114021301, 7.925683328083583, 2.0958283501011983, 1.3665538941110884, 0.5518307632633618, 2.492658427783421, 6.966282146317618, 21.653296606881277, 35.62424101148333, 34.86398996625628, 44.76488808223179, 54.852724007197786, 49.87056337084089, 57.4083548273359, 47.18612337112427, 15.593166385378156, 2.29852163365909, 0.1234318438385214, 0.1651517187378236, 0.12443805698837553, 0.07551321906170674, 0.10243347845971584, 0.17610592022538185, 0.1168105634195464, 0.1970809575702463, 0.09997870839600052, 0.07407578333680119, 0.13768605967717512, 0.1908141981278147, 0.16142072608428343, 0.10245160891541413, 0.0939750305509993, 0.25940475187131334, 0.08048946596682072, 0.09490399927433048, 0.1235607247799635, 0.17289465825472558, 0.2325349279812404, 0.07859994271504027, 0.13953528473419802, 0.14263062578226837, 0.16419723709779127, 0.13998683621840818, 0.11714437550732068], [0.015675809467211366, 0.036481696513614485, 0.033355376949267726, 0.003940020030963102, 0.0866844839017306, 0.0734745945249285, 0.09364937445414917, 0.06101314962974616, 0.028333350982783095, 0.011419500091246195, 0.02530491179121392, 0.02974462409370712, 0.003240189826880981, 0.05309316336310335, 0.03499786595680884, 0.053451979466314824, 0.020844368463648216, 0.03089375707453915, 0.07169386757803814, 0.04953818269340055, 0.05625539778598717, 0.058942267538181374, 0.02376210636326245, 0.01694746721269829, 0.022199843943651234, 0.03098153236455151, 0.055906081173036776, 0.0217967805718737, 0.034820612253887315, 0.03392253044460501, 0.03418334573507309, 0.7919523641467094, 6.871396243572235, 25.570282765797206, 47.59247486931937, 47.32673406600952, 36.989586353302, 24.267384358814784, 23.836712428501674, 28.50604953084673, 25.5609860760825, 14.117285626275198, 4.2429487364632745, 0.7701699786952564, 0.2670305355318955, 0.5394742063113621, 2.1487184720379964, 2.127685840640749, 4.295443245342799, 6.533477553299495, 5.694917270115443, 3.531748499189104, 2.465580863612039, 4.849641987255641, 11.048815216336932, 19.30552635874067, 29.81011697224208, 38.21106576919556, 45.578463077545166, 46.18591628755842, 45.52539621080671, 49.79788868767874, 47.17706986836025, 46.56340844290597, 47.54281956808907, 48.4506642477853, 48.23138952255249, 45.5386186327253, 43.64945207323347, 41.516824109213694, 35.646294593811035, 35.12671872547695, 35.63916574205671, 34.28640706198556, 34.97127015250069, 35.508515289851594, 33.957038130079, 33.513746534075054, 32.12985645021711, 32.52727951322283, 34.05603606360299, 35.7880482673645, 36.879235063280376, 39.15033367701939, 41.570033414023264, 43.22470869336809, 44.77470588684082, 46.52259125028338, 48.40753330503191, 33.897856848580496, 46.2697046143668, 45.49003682817732, 39.96437420163836, 39.784089292798726, 44.39054693494524, 45.74976396560669, 47.163197789873394, 47.92287908281599, 48.32268190383911, 47.348825863429475, 47.476690087999614, 46.62578589575631, 47.7650785446167, 47.162676674979075, 46.604277747017996, 47.21443728038243, 46.564718178340364, 46.23990379061018, 44.998660223824636, 45.394224643707275, 49.33376291819981, 48.60532767432076, 47.35769176483154, 45.10573196411133, 48.365889276777, 46.87515674318586, 46.97220223290579, 46.890001569475444, 46.729595456804546, 50.08301496505737, 50.47096415928432, 45.16468048095703, 33.81428044182913, 19.918666669300624, 13.531606333596365, 8.005245413099017, 4.487932230745043, 5.007584095001221, 4.691464509282794, 7.187833275113787, 5.3186631969043185, 2.7108709471566335, 3.723785851682935, 1.976237258740834, 0.4913902836186545, 0.417433142129864, 0.08650300971099309, 1.9963659729276384, 5.080234459468296, 20.948860440935405, 31.68934760774885, 35.18042482648577, 25.380819286618912, 44.151105063302175, 42.54837104252407, 43.07035446166992, 26.907824890954153, 7.458031347819737, 0.8997783639601299, 0.02829980930047376, 0.04838356714961784, 0.016746851549084698, 0.032518624527645965, 0.009292017152932073, 0.07144749829811708, 0.11953155669782843, 0.02074327862023243, 0.03455803955772093, 0.05079638000045504, 0.02218618503372584, 0.08413811161049775, 0.028299186744594147, 0.04651699873751827, 0.007310593966394663, 0.03608315218506115, 0.1266877127013036, 0.03484709547566516, 0.010308077542244323, 0.049000511544623544, 0.03163263760507107, 0.048063732883227725, 0.024782387240390693, 0.013548351125791669, 0.05228909258065479, 0.03230280289426446, 0.05074348819575139, 0.018063072081921355, 0.02398533759904759, 0.06124007209603276, 0.046914260634886365, 0.04552596441603132, 0.055207207067204375, 0.028525303450546095, 0.05697143543511629, 0.025425672364820327, 0.03427258666072573, 0.03255110260631357, 0.00538552735399987, 0.052042814902961254, 0.04791274527087808, 0.02261942794679531, 0.05800661524491651, 0.008270882169849106, 0.02308534741002534, 0.05558044543223722, 0.07922638660030705, 0.06189819678132023, 0.06827088232551302, 0.06180861658815827, 0.008934340988551932, 0.008337822193945093, 0.03002036715458546, 0.006837658026987421, 0.053942027634807994, 0.010419334384745784, 0.016341328487864563, 0.03566549352503248, 1.0467411237103599, 9.071544630186898, 31.214219365801128, 54.13951921463013, 50.452301297869, 43.64960493360247, 25.998988355909074, 21.707970244543894, 28.061488151550293, 26.290586880275182, 15.589049577713013, 3.9610776901245117, 0.7822717321770531, 0.20906166040471622, 0.6587776531066213, 0.6154484695621899, 1.9885629287787845, 4.750799085412707, 7.425567626953125, 5.211863739149911, 4.813652055604117, 4.708937925951822, 6.748724494661603, 13.430900880268641, 21.596554143088206, 32.05358954838344, 41.964843954358784, 48.52993277141026, 48.95175443376814, 47.86593859536307, 50.41624709538051, 48.62895849772862, 48.35562331335885, 47.27958011627197, 48.93158728735787, 49.411415985652376, 46.510171345302034, 45.640573024749756, 42.91677148001534, 37.85336555753435, 36.50020388194493, 36.90486696788243, 36.452501024518696, 37.34140144075666, 37.27195419584002, 36.538755961826865, 36.1863294328962, 34.1381915637425, 34.33769518988473, 35.51302119663784, 36.273730822971885, 38.598139490400044, 39.99610315050398, 43.10573468889509, 45.04747826712472, 48.25583675929478, 47.963032722473145, 49.34912885938372, 36.81427982875279, 47.031338351113455, 46.879172801971436, 41.13254008974348, 41.56599303654262, 45.81172800064087, 47.44559689930507, 49.74495383671352, 48.8178904397147, 49.690094334738596, 47.95614358357021, 48.775169440678184, 47.63599838529314, 48.36633743558611, 49.13292176382882, 47.65134695598057, 48.42366354806082, 49.051617418016704, 47.50575787680489, 47.56913934435163, 49.202799797058105, 50.7217698097229, 48.816837787628174, 46.898457527160645, 47.137208053043906, 48.060849462236675, 48.490637234279085, 48.80487993785313, 49.069522925785606, 49.447456291743684, 51.729081426348, 50.89375856944493, 46.680707931518555, 35.30528742926461, 24.132443393979752, 15.824699469975062, 9.67183598450252, 5.815379926136561, 5.994019848959787, 9.589153289794922, 7.747094648224967, 7.444212249347141, 5.036248888288226, 5.111089238098689, 3.911035026822771, 0.6184805440051215, 0.3668432267648833, 0.12999466168028967, 2.2182362845965793, 6.670205073697226, 19.521372147968837, 34.678747517721995, 35.51538705825806, 29.065073796680995, 50.42406381879534, 46.41176748275757, 48.95976570674351, 33.375428744724815, 9.955358965056282, 0.9724900679928916, 0.05281844149742808, 0.10014581121504307, 0.07461808887975556, 0.021713266481778452, 0.01520437521061727, 0.08296652590589863, 0.024112233825560127, 0.023200983347903405, 0.038521773115332635, 0.03356167873633759, 0.027331017356898104, 0.09663625167948858, 0.02223503785873098, 0.009893753881832319, 0.05832707376352378, 0.05664754692198975, 0.0705857045416321, 0.06353274692914315, 0.021541997457721403, 0.052923285335834534, 0.035084477559264214, 0.009792502886349601, 0.005876817665661552, 0.02756538165600172, 0.01795722740436239, 0.01893541875428387, 0.025808291476485983, 0.054919983193810494, 0.12470440912459578, 0.10860332274543387, 0.1390590210046087, 0.21634782371776445, 0.12845613780830586, 0.2333169531609331, 0.11119998126689877, 0.18720741809478827, 0.11022884837750878, 0.09225210800234761, 0.10746928716876678, 0.07854261329131466, 0.12995671800204686, 0.08690925541200809, 0.2232114632747003, 0.12877171087477887, 0.15328760179025785, 0.09944599055285964, 0.20131053775548935, 0.174905890332801, 0.1315273365804127, 0.1768674265061106, 0.06209042575210333, 0.11357215326279402, 0.1176545252757413, 0.2107137031853199, 0.15969157458416053, 0.14637935534119606, 0.08796449950230972, 0.06968684920242854, 1.353904590010643, 10.371913024357386, 35.93035432270595, 60.0886675970895, 57.98683752332415, 50.28973429543631, 33.59464093617031, 34.49588482720511, 38.862553187779014, 34.12549025671822, 19.532430206026348, 5.836689182690211, 1.2837370123182024, 0.6934634404523032, 0.9615448095968792, 5.971745227064405, 6.984305773462568, 11.074822323662893, 14.886333090918404, 12.132258244923182, 10.582011784826006, 5.6862085717065, 8.813790781157357, 16.18993500300816, 23.118341650281632, 33.147545201437815, 42.54731144223894, 47.988087926592144, 49.580562932150706, 47.115658215114046, 51.57153102329799, 49.774070262908936, 50.22728736060006, 45.9789502961295, 49.949123178209575, 50.30223757880074, 49.565898759024485, 47.83904906681606, 45.235169955662315, 38.62609904153006, 39.01175880432129, 38.355299949645996, 38.14604800088065, 39.331910950796946, 38.48909098761422, 37.043559959956575, 37.267253739493235, 35.41776486805507, 37.12498589924404, 39.315367289951865, 38.88712201799665, 41.30747488566807, 42.9679970741272, 45.18281180518014, 47.48087985174996, 47.853174754551475, 48.908123220716206, 49.67094509942191, 39.02077061789376, 48.92155408859253, 49.89387457711356, 43.11378070286342, 43.808569295065745, 48.073335375104634, 50.381561688014436, 51.369095257350374, 49.60197033200945, 50.751056466783794, 49.86596713747297, 50.48552063533238, 50.437960215977256, 49.71764741625105, 51.278146811894004, 49.32305227007185, 49.069095611572266, 49.73287091936384, 49.31260565349034, 47.928045068468364, 49.77057531901768, 52.85187905175345, 50.41052872794015, 47.62781340735299, 46.863299642290386, 48.38308606828962, 49.174201011657715, 48.908043316432405, 50.006216526031494, 51.461589676993235, 53.72076170785086, 54.549077306474956, 50.28311613627842, 37.5452754838126, 25.20678949356079, 17.01319578715733, 12.194548845291138, 11.393557906150818, 9.577540244374957, 12.826937402997698, 13.538337400981359, 15.382019315447126, 9.010863406317574, 14.542758566992623, 8.948452949523926, 2.3681449719837735, 1.765433581812041, 0.34252990569387165, 2.830623149871826, 6.854119113513401, 26.29386990410941, 39.1128168787275, 45.860268115997314, 34.435341698782786, 55.874262060437886, 54.00692674091884, 55.9694002696446, 38.30723925999233, 11.761755108833313, 1.246380022593907, 0.1233734626855169, 0.22365749148385866, 0.13160316965409688, 0.07342955337039062, 0.11029593513480254, 0.18249591519790037, 0.1570391540548631, 0.09959895948746375, 0.052131774236581156, 0.1140899094087737, 0.09571249410510063, 0.14870179072022438, 0.18870277356888565, 0.1949604813541685, 0.12532859348825046, 0.1583133071128811, 0.20975576101669244, 0.1692512644720929, 0.1493014528283051, 0.2629766959164824, 0.12812254285173758, 0.1718621857996498, 0.10873573885432311, 0.07759356671678168, 0.1314084708158459, 0.15061941210712704, 0.16989851902638162], [0.02080276408897979, 0.002653575947208862, 0.05389601956786854, 0.04600675736687013, 0.00837301865353116, 0.008259947578023587, 0.010019800243233996, 0.02182953176088631, 0.0298189338562744, 0.0804793354389923, 0.047118418251297305, 0.03949507392410721, 0.027012753899076154, 0.014539829887715834, 0.03815286380371877, 0.06175165357334273, 0.03312453255057335, 0.12084350415638515, 0.027022246603987048, 0.07609777698027236, 0.03671494292627488, 0.04812709787594421, 0.005210083643240588, 0.04053485420133386, 0.058032514926578314, 0.06774554694337503, 0.09125867166689464, 0.09979466255754232, 0.035522034258714745, 0.009632718067483177, 0.04658625002152153, 0.25643759965896606, 3.737482488155365, 22.091547284807476, 44.596772943224224, 47.35857418605259, 37.4076247215271, 32.88019241605486, 28.60011771747044, 31.968831947871617, 24.05241404260908, 18.247944525309972, 4.767025300434657, 1.4857540407351084, 0.07143252303025552, 0.5556956987295831, 0.3778745234012604, 1.498455022062574, 2.2396391247000014, 3.833997743470328, 2.9306902374540056, 3.2956906173910414, 4.756829687527247, 4.307139669145856, 9.386516894612994, 16.53713127544948, 28.716559103557042, 36.49958896636963, 48.36929736818586, 50.13425098146711, 52.75881487982613, 49.34598479952131, 46.00990799495152, 48.090837887355256, 49.42905746187483, 48.5114540372576, 49.41252769742693, 46.56041724341256, 46.512488569532124, 40.341362612588064, 36.817972796303884, 36.71106781278338, 38.03880602972848, 35.886347906930105, 33.922613280160085, 34.131427492414204, 34.51489509854998, 31.871091638292583, 33.42437532969883, 37.0127203805106, 40.02666480200631, 41.52246952056885, 45.376378195626394, 43.90850176130022, 44.290159361703054, 43.87708895547049, 44.209594999040874, 47.14135265350342, 47.6734595979963, 31.79847948891776, 47.78687851769583, 44.620296069553916, 41.01194715499878, 39.190271922520225, 43.32014567511422, 44.487964153289795, 45.43979787826538, 46.90360614231655, 47.23768942696707, 47.91435364314488, 49.396091733660015, 47.91755676269531, 48.03525577272688, 44.84049490519932, 46.6917381967817, 44.86427511487688, 43.99373878751482, 43.372013977595735, 43.96105793544224, 43.06949635914394, 46.11725071498326, 47.573777266911094, 46.47837291445051, 46.19446604592459, 46.32490457807268, 46.677518708365305, 47.896979672568186, 49.05357681001936, 47.87517275129046, 42.04460232598441, 38.97751113346645, 38.95596824373518, 33.96401759556362, 22.526210955211095, 13.204015272004263, 8.357805694852557, 3.2500524606023515, 4.197862310068948, 6.16239641393934, 6.946805477142334, 4.953792010034833, 4.984374071870532, 2.3571811488696506, 1.844730658190591, 0.14305831997522286, 0.7278899188552583, 0.39724268125636236, 1.9790326058864594, 8.023021510669164, 17.41769732747759, 22.526054620742798, 23.30174630028861, 27.61775013378688, 38.5164703641619, 46.30222913197109, 38.975207805633545, 22.326851504189626, 4.3855414049966, 0.2929960350905146, 0.07099307661077806, 0.044872178962188106, 0.02471160246724529, 0.008355642219872346, 0.027630989206954837, 0.036281484578336985, 0.02904729704771723, 0.06797277475042002, 0.03028680071500795, 0.027112496850479926, 0.024006066843867302, 0.0737407770273941, 0.04103246803528496, 0.0787569625037057, 0.02321958029642701, 0.013960296520963311, 0.030073435378393958, 0.0254754870132144, 0.024254721090463654, 0.06698038335889578, 0.014172320902746702, 0.03574067181242364, 0.020371851943699375, 0.05996694362589291, 0.06830178959561245, 0.04369829302387578, 0.014916108089632221, 0.04992854388962899, 0.02022266753816179, 0.07061118353158236, 0.07772079881812845, 0.03683423956057855, 0.05706289517027991, 0.020259486544611197, 0.04815166762896946, 0.014560343697667122, 0.04547642118164471, 0.02218985421183918, 0.07976681938660996, 0.11950719729065895, 0.05976422450372151, 0.006640721295428063, 0.021404465194791555, 0.02190509850957564, 0.012841023321795677, 0.011359448893927038, 0.054926327496234856, 0.045434884660478146, 0.09494378856782403, 0.027414553499381458, 0.05093627356524978, 0.0025002685932642116, 0.09118948145104305, 0.015263156699282783, 0.10377195663750172, 0.07633256366742508, 0.08668276042278324, 0.030315892903932502, 0.37820727697440554, 5.204101732798985, 25.88095756939479, 49.56449522290911, 55.27850614275251, 43.008272307259695, 33.52442591530936, 32.90411158970424, 32.69036763054984, 30.628976072583878, 19.395401307514735, 6.084283896854945, 1.297065285699708, 0.06410511157342366, 0.2450927384197712, 0.9009441414049694, 2.718389332294464, 4.187435669558389, 4.5455940280641824, 4.228771805763245, 5.595068182264056, 4.39892624105726, 6.622126145022256, 12.407328741891043, 18.843452044895717, 29.199394634791783, 39.25156545639038, 48.79025745391846, 50.81682811464582, 51.78141178403582, 50.963462897709434, 47.42031587873186, 48.32334893090384, 50.11348628997803, 49.01397902624947, 50.25234603881836, 49.33043820517403, 47.03592068808419, 43.16441222599575, 37.90496635437012, 38.63224819728306, 39.01335341589791, 37.62989412035261, 35.16398886271885, 36.02671888896397, 36.68577984401158, 33.14085408619472, 34.32421568461827, 38.681695052555625, 41.076186725071494, 41.88250780105591, 44.63846213476998, 45.14157772064209, 45.31819398062569, 46.11544418334961, 46.31095606940133, 49.74279989515032, 48.640885080610005, 35.12750734601702, 49.92768103735787, 45.73266444887434, 42.118888991219656, 41.36124004636492, 45.47618906838553, 47.1135424886431, 47.94912242889404, 48.82329961231777, 47.65873983928135, 48.57866396222796, 48.94529260907854, 49.0230255808149, 49.12539686475481, 47.06529419762747, 49.17008072989327, 47.75966589791434, 45.07332903998238, 44.888166495731895, 46.128249713352744, 45.855671882629395, 47.26002093723842, 49.114234583718435, 47.554023538317, 46.06529208592006, 46.661353724343435, 47.67972687312535, 48.942506381443565, 50.01119838442121, 49.85037190573556, 47.35586091450283, 46.08230822426932, 43.25894594192505, 35.754839352199006, 23.86169293948582, 15.173425708498273, 7.48748563017164, 4.7043065173285346, 6.054618997233255, 7.676130090441022, 9.695371270179749, 7.317992142268589, 8.574947323117938, 4.769685157707759, 2.9811760655471256, 1.0922519330467497, 0.37054056408149855, 0.34431277002607075, 2.590248699699129, 7.709284288542611, 18.254729441234044, 30.884680203029088, 29.136344943727764, 30.70340517589024, 45.06149973188128, 50.39574990953718, 45.31770413262503, 26.622545753206524, 5.842728470052991, 0.473124120916639, 0.06602458536092724, 0.017871547091220106, 0.017342727431761365, 0.017406319733709097, 0.0431791832005339, 0.09521865631852831, 0.023166081202881675, 0.02552234155258962, 0.053154720059995136, 0.006514358991158328, 0.03056958018402968, 0.04742495323132191, 0.030530666200710193, 0.04566970527438181, 0.02865751599892974, 0.033325982812259874, 0.06147812932197537, 0.021909685406301702, 0.013159418245777488, 0.046660023741424084, 0.02635284636302718, 0.016116368684119413, 0.04726944996842316, 0.011850731147985374, 0.06648823512451989, 0.03941501018458179, 0.07481419228549514, 0.14658134164554731, 0.11544877077851977, 0.13494836086673395, 0.16182724998465606, 0.11319138655172926, 0.09232459589838982, 0.1332130754100425, 0.10080238205513783, 0.13621966407767364, 0.15948481139327797, 0.09791526983359031, 0.19582980684936047, 0.20341821680111544, 0.09778594105903592, 0.17353329541427748, 0.16536941991320678, 0.1469330806285143, 0.3674914991217, 0.12464787358684198, 0.11577513255178928, 0.10276330076158047, 0.1989860124886036, 0.1272666659206152, 0.10369735171220132, 0.1685879693499633, 0.2726997227541038, 0.20618685680840695, 0.20801911848996366, 0.13753478708011763, 0.15623637927430017, 0.15501287207007408, 0.5647659748792648, 5.945079777921949, 29.658896378108434, 52.61266647066389, 59.82014056614467, 50.29943398066929, 43.59209816796439, 37.920169012887136, 41.366631848471506, 32.868060861315044, 24.046211038316997, 6.556405740124839, 2.4556633957794736, 0.21524752490222454, 1.5696696064301898, 1.454669754420008, 6.817834751946585, 7.976774300847735, 9.872874294008527, 10.317642382213048, 8.888281549726214, 11.095844098499843, 6.2993475794792175, 13.653238024030413, 21.25459681238447, 34.25415699822562, 39.10906832558768, 51.28994137900216, 50.95897088732038, 53.20768935339791, 51.969051361083984, 51.676122256687705, 47.70298944200788, 51.03465414047241, 48.32955367224557, 51.30908714021955, 50.63255493981497, 51.75941031319754, 44.981765678950715, 40.358093874795095, 41.47393635341099, 41.408862999507356, 38.33496604646955, 37.77805750710623, 37.84950930731637, 38.98372629710606, 35.016026973724365, 35.93384231839861, 40.92510162081037, 43.71625205448696, 44.47437347684588, 48.18169600622994, 47.9974228313991, 47.399033546447754, 48.28932012830462, 46.98000158582415, 51.11150121688843, 49.11664908272879, 36.51362780162266, 53.295229707445415, 48.66328607286726, 44.467359270368306, 42.62192119870867, 47.88453197479248, 49.567003522600444, 49.44238758087158, 49.85421773365566, 49.95857967649187, 49.393948214394705, 50.34981884275164, 50.51283400399344, 49.711213384355815, 47.38150324140276, 51.0046830858503, 48.614155360630576, 47.66844994681222, 46.45365817206246, 48.44854852131435, 46.65495790754046, 49.37076554979597, 50.62999452863421, 47.47583198547363, 45.25412811551775, 46.323455878666465, 47.26824065617153, 49.8056081363133, 51.04297808238438, 51.976451192583355, 47.16713047027588, 46.48370565686907, 46.2319689478193, 41.80612277984619, 27.044393471309117, 16.396122796194895, 10.257635133607046, 7.001762688159943, 9.017651796340942, 14.51996065889086, 16.787242106028966, 14.07532979760851, 13.269685302461896, 10.100853375026158, 4.599190694945199, 2.7437841296195984, 1.5383376819746835, 0.7870383592588561, 3.1106312104633878, 10.639984948294503, 22.541245119912283, 30.821927547454834, 33.37253482001168, 39.33947059086391, 52.57570900235857, 56.65095254353115, 52.18481724602835, 31.833029406411306, 7.605121237891061, 0.6424774506262371, 0.14756072552076407, 0.1374062318354845, 0.13159878631787642, 0.07294376979448966, 0.18387696466275624, 0.27060595367636, 0.15865923783608846, 0.15782431406634195, 0.1373116983366864, 0.1263683805508273, 0.09872252973062651, 0.16302596351930074, 0.1375535282173327, 0.16087310761213303, 0.1057844100786107, 0.08488910059843745, 0.07943861199808971, 0.1461071270917143, 0.10220184017504964, 0.11430283369762556, 0.06054525902228696, 0.12075051771742956, 0.16655651692833218, 0.11500192832733903, 0.07572497627032654, 0.1057512704282999, 0.1523101720958948], [0.08075470530561038, 0.015168161796672004, 0.06525281963071652, 0.025368159736639688, 0.04695241465898497, 0.036891894681113105, 0.016819463277767812, 0.04114142040322934, 0.025874989772481576, 0.033631309999951293, 0.015558341484782951, 0.020768392897610153, 0.028069750306063464, 0.021748370490968227, 0.026007687473403554, 0.02504778603490974, 0.11290633399039507, 0.00983500971259283, 0.03699636193258422, 0.0407713406187083, 0.052548910424645455, 0.02223783342300781, 0.04952740416462932, 0.024532048530610542, 0.010940495928350304, 0.018297293888671056, 0.01846673765352794, 0.03467336676216551, 0.03976789249905518, 0.04847674357837864, 0.055616923474839756, 0.09154069796204567, 3.1957123364721025, 14.085878900119237, 32.28362703323364, 43.67194339207241, 38.621600082942415, 30.092036655970983, 29.37455177307129, 37.569090434483115, 28.97189324242728, 26.41775107383728, 8.50553481919425, 2.1342488484723225, 0.1346712200237172, 0.2712455950677395, 0.7136046939662525, 1.2287217187029975, 4.845216419015612, 4.8206645250320435, 2.1920595977987563, 3.4869580226285115, 3.4162138530186246, 5.332414550440652, 10.490621260234288, 17.964306899479457, 29.501273018973215, 40.80939326967512, 49.700624329703196, 53.35153790882656, 47.50705371584211, 44.97774267196655, 46.64819731031145, 50.11272546223232, 48.756047998155864, 50.462091309683665, 49.55169664110456, 47.344187940870015, 44.51001426151821, 41.22801876068115, 37.97265917914254, 36.638580730983186, 36.704487868717735, 35.12684031895229, 33.90868214198521, 32.46855681283133, 33.43381098338536, 34.81802415847778, 39.500995363507954, 43.50622190747942, 43.5181484903608, 45.61613621030535, 45.81035920551845, 45.26285852704729, 46.52961587905884, 45.34952688217163, 48.01041943686349, 47.85691288539341, 45.3034325327192, 32.09295456750052, 45.24716602052961, 44.9351258959089, 42.729510579790386, 40.24992779323033, 40.65995488848005, 42.77039378029959, 44.622258935655864, 45.048867906842915, 46.55445916312081, 47.871424198150635, 48.70784487043108, 47.75859587533133, 46.54135833467756, 46.28637681688581, 47.152796336582725, 44.30636950901577, 42.52681425639561, 41.738683564322336, 42.32332583836147, 44.30269391196114, 45.60732242039272, 47.4162893976484, 44.69826528004238, 44.243175642830984, 47.64035143171038, 47.53407178606306, 48.146517276763916, 49.24524981634957, 52.30651147024972, 50.874376569475444, 44.05805478777204, 33.479276520865305, 22.509074960436138, 21.07170111792428, 12.754561492374965, 6.860742918082646, 3.7931371246065413, 6.64983034985406, 8.694897549492971, 6.604430385998317, 1.8182569359030043, 3.770539845739092, 3.2851350009441376, 4.168710708618164, 0.6555692681244442, 0.07529132453990833, 0.4497174583375454, 2.965736516884395, 10.35290014743805, 15.67013679231916, 22.952284915106638, 27.420874663761683, 30.261645657675608, 39.175729342869346, 41.92154278073992, 35.050629002707346, 17.369634900774273, 2.8822649845055173, 0.12914126818733557, 0.029534576793334315, 0.06187731147344623, 0.06490245807383742, 0.05287045459928257, 0.019186386805293814, 0.007127900108961123, 0.052797050680965185, 0.03249065192150218, 0.05573036435193249, 0.04582043843609946, 0.036666695693773885, 0.04057666552918298, 0.03953323812623109, 0.029491201442267214, 0.02565058976012681, 0.03415210598281451, 0.07946322924856629, 0.04044624092057347, 0.0461045172996819, 0.05223379536931004, 0.05570918388132538, 0.029714659987283603, 0.02384107087605766, 0.017962496228782193, 0.034125995955296924, 0.10613527375140361, 0.03259831168023603, 0.0281886635680816, 0.07221875512706381, 0.040433016273060014, 0.14971253648400307, 0.03744648849325521, 0.008812276779540947, 0.061219709260123115, 0.013519206350403172, 0.014105319810499038, 0.025280876384515847, 0.01841505533749504, 0.037529771881444116, 0.01338333819460656, 0.013617527770942875, 0.02686060090283198, 0.008314477196628494, 0.06265320948192052, 0.029134929845375673, 0.011164818757346697, 0.03208577686122485, 0.05410604651219078, 0.009451101384391742, 0.04073659284040332, 0.04565120840977345, 0.06458028286163296, 0.08017138232077871, 0.01698059498864625, 0.051284633443823884, 0.05047068658417889, 0.05321906892848866, 0.06934249268046447, 0.15099141214575085, 3.634637858186449, 17.726046221596853, 40.6408542905535, 48.01274013519287, 43.2106420653207, 34.81699235098702, 31.074126311710902, 39.026315280369346, 29.735364777701243, 27.195740870067052, 9.239360996655055, 1.6842046890939986, 0.2647537791303226, 0.35658931412867134, 0.8399355922426496, 1.1751907340117862, 3.547355673142842, 7.428089823041644, 6.198107983384814, 4.9507856113570075, 3.943371508802686, 6.650081353528159, 11.263794217790876, 20.23508242198399, 30.052560465676443, 41.83051790509905, 50.4940356527056, 54.0566098349435, 51.680600370679585, 47.80981799534389, 49.037915570395334, 49.68852751595633, 47.39273847852434, 50.11281926291329, 49.97072165352957, 48.5146050453186, 46.39188173839024, 42.2290735244751, 40.47811358315604, 37.91250514984131, 37.84024041039603, 36.82077986853463, 34.95898573739188, 34.89816468102591, 36.73937824794224, 36.1789539200919, 39.94578429630825, 45.00295768465315, 45.01469666617257, 49.32255547387259, 47.75392321177891, 46.7381660597665, 48.29593481336321, 48.68258816855294, 49.405336311885286, 48.308827195848735, 45.87870168685913, 34.17011158806937, 46.40760203770229, 46.72358526502337, 43.38290875298636, 42.507550375802175, 42.85358803612845, 44.475940295628135, 46.35077272142683, 47.236845220838276, 48.97530882699149, 50.83700220925467, 50.79310349055699, 48.44526549748012, 47.35760143824986, 48.417931284223286, 48.00876576559884, 46.373948437826975, 44.63711765834263, 43.01430681773594, 44.42866127831595, 46.563314642224995, 47.756094523838584, 48.50193847928728, 45.92511565344674, 44.99285847800118, 47.654341629573274, 48.15799222673689, 49.84285395486014, 50.59129306248256, 52.06727457046509, 50.98190689086914, 46.095416000911165, 37.15615899222237, 27.10782183919634, 20.367575883865356, 12.194455913134984, 6.228492021560669, 4.419117706162589, 6.883803989206042, 9.106386372021266, 8.579169222286769, 6.484204402991703, 6.978609553405216, 3.6871267216546193, 1.9747896449906486, 0.6697656320674079, 0.25851682094591005, 0.5248690928731645, 3.7814263701438904, 10.675323486328125, 19.53775600024632, 24.726915631975444, 26.677483422415598, 33.353614875248496, 44.85575662340437, 48.65160615103585, 41.283621719905305, 20.914789949144634, 4.062836229801178, 0.2124918449137892, 0.016926863496857028, 0.06630635381277118, 0.045317365787923336, 0.0684698491490313, 0.05482411637370076, 0.011861208576842077, 0.04391709003331406, 0.043629513321710486, 0.003789517147067402, 0.051119108218699694, 0.03197338432073593, 0.040866399982145855, 0.03139434628454702, 0.0403412036996867, 0.10638053701924426, 0.05139865446835756, 0.005548819774828319, 0.01483494512337659, 0.08467586418347699, 0.09567391260394029, 0.017905417863013487, 0.018089051491447856, 0.07318323837327105, 0.019877310177045207, 0.033438382138098986, 0.03708394384011626, 0.04140549266178693, 0.13333557812230928, 0.15183720604649611, 0.14678699203899928, 0.1909064653196505, 0.08222057164779731, 0.1141042672097683, 0.22054355857627733, 0.1778550749378545, 0.14840748294123582, 0.0984987828082272, 0.06490540291581835, 0.20499338156410626, 0.10993766864495617, 0.09517723854099001, 0.1415340317679303, 0.15954938078565256, 0.24643683486751147, 0.14722140372863837, 0.1262478863022157, 0.131327698007226, 0.11565265698092324, 0.26617007170404705, 0.1589233779481479, 0.11295592811490808, 0.12714573740959167, 0.18867731493498596, 0.10635575692036323, 0.16958424874714442, 0.08938548075301306, 0.12913659986640724, 0.1356632382209812, 0.20159306616655417, 4.337742141314915, 20.114647558757238, 45.42149632317679, 54.904595783778596, 50.36928422110421, 41.30882283619472, 40.108924525124685, 47.472378730773926, 39.51389122009277, 33.18373489379883, 11.474190882274083, 2.6540731149060384, 0.8060167123164449, 1.0174568550927299, 2.6881959353174483, 4.698524747576032, 9.822597129004341, 12.556733250617981, 10.578118188040596, 10.311186637197222, 7.5802953243255615, 11.413777164050511, 15.870314393724714, 23.096381868634904, 31.34983777999878, 44.734611306871685, 50.9653354372297, 56.91302122388567, 52.790818282536094, 51.692818777901785, 50.16404833112444, 50.03456170218331, 47.522944246019634, 50.799447195870535, 52.17561435699463, 51.003863198416575, 47.39927325929914, 44.67269243512835, 41.415053844451904, 39.55512530463082, 40.596010616847444, 38.80870117459978, 37.068076678684776, 35.364385332380024, 38.23541225705828, 39.20641606194632, 42.71253265653338, 48.0192471231733, 46.42274216243199, 50.619798047201975, 49.71148089000157, 48.85763413565499, 51.572208472660606, 50.207905360630576, 50.894297054835725, 50.353272097451345, 45.143853255680625, 37.92563377107893, 48.257931641169954, 47.973819800785606, 46.7235609463283, 44.83939708982195, 44.21107496534075, 45.50550699234009, 48.81157452719552, 48.70571872166225, 49.98509400231497, 52.77487564086914, 52.48457990373884, 50.40285096849714, 50.11846467426845, 49.71531629562378, 51.51305845805577, 48.58119658061436, 46.504067352839876, 44.815519605364116, 45.998690128326416, 48.659019878932405, 49.93626206261771, 48.963448251996724, 46.59498453140259, 45.419436182294575, 48.11506278174264, 48.506277629307334, 50.506921086992534, 50.67341382162911, 53.835896832602366, 53.39345986502511, 47.66263083049229, 40.916055066244944, 30.226869923727854, 26.6419347013746, 16.369644948414393, 10.790912849562508, 7.368630613599505, 13.63387860570635, 17.733407838003977, 13.1181172983987, 11.847575783729553, 12.821250302450997, 10.489929914474487, 9.267185057912554, 1.5308235308953693, 0.620241043823106, 1.1427180022001266, 4.223999696118491, 13.528708934783936, 23.525370597839355, 32.84415558406285, 38.674013819013325, 41.674162592206685, 51.89537613732474, 54.23520980562483, 46.05145474842617, 25.131319897515432, 4.732494056224823, 0.31117173550384386, 0.1181492315871375, 0.133577095876847, 0.22701940179935523, 0.11726780102721282, 0.12360469384917191, 0.0854423101991415, 0.1118510491879923, 0.1294474231877497, 0.13524676699723515, 0.11453206996832575, 0.14363747675504002, 0.21151908354035445, 0.104435095696577, 0.12995606660842896, 0.15857173396008356, 0.18629694623606546, 0.16507375506418093, 0.22213166978742394, 0.12946881061153753, 0.1805299414055688, 0.1702142006584576, 0.1831473766693047, 0.11313029125865016, 0.10669754179460661, 0.12745449798447744, 0.18491080775856972, 0.1658660261226552], [0.11239276440548045, 0.02982947150511401, 0.06193547549524477, 0.027781718975997398, 0.024490819046539918, 0.07476412997181926, 0.008033420358385359, 0.0541101550417287, 0.09564740224076168, 0.031706825231334994, 0.05362251227987664, 0.048577726552528996, 0.027861214442444698, 0.020239340839907527, 0.05676245343472276, 0.008769459523526686, 0.03107876643272383, 0.045735723339021206, 0.018518168911603943, 0.04688330586733563, 0.02769184870911496, 0.1074193198499935, 0.0654512368408697, 0.010557529915656363, 0.029745611362159252, 0.018762948723243814, 0.0598827577861292, 0.007540671620517969, 0.046828229179871936, 0.04695649943979723, 0.06282245647162199, 0.020225658181256483, 1.329830167548997, 9.282643931252615, 27.453407866614207, 47.366620200020925, 41.1668815612793, 34.390630040849956, 43.09005260467529, 38.25920983723232, 28.851303781781876, 19.125887632369995, 7.485699074608939, 3.107286955629076, 0.5058677781905446, 0.14819731350455964, 0.5705957849110875, 1.1149918671165193, 1.385726036770003, 3.631138354539871, 2.653305773224149, 4.834860563278198, 2.557788452931813, 5.184181247438703, 8.529535634177071, 15.583362477166311, 27.52990058490208, 39.156503677368164, 44.60274839401245, 43.98712410245623, 47.44510357720511, 48.48500224522182, 50.83653667994908, 51.73813840321132, 49.61691243307931, 51.05672856739589, 49.1808226449149, 46.742939472198486, 45.42618635722569, 39.994644028799875, 37.05144269125802, 37.167265687670024, 35.13764476776123, 33.97688913345337, 35.01903554371425, 34.82987431117466, 33.378996644701274, 39.66350678035191, 45.74173184803554, 45.88659831455776, 47.2031638281686, 46.84512315477644, 48.614488874162944, 47.56922272273472, 46.38132047653198, 46.234112467084614, 48.0054931640625, 46.94895356042044, 46.66265998567854, 29.80549989427839, 45.91083363124302, 46.0385936328343, 41.67913750239781, 41.44385412761143, 36.34656184060233, 38.394803932734895, 37.526859283447266, 39.62767839431763, 42.98146268299648, 45.0662453515189, 46.02058737618582, 47.047638825007844, 45.471992356436594, 44.53375973020281, 41.364794049944194, 39.95175974709647, 38.67140824454171, 37.56846857070923, 40.10762173788888, 44.55794293539864, 44.09147909709385, 47.45299673080444, 44.73748091288975, 44.5858781678336, 45.16881813321795, 48.751906871795654, 48.57812547683716, 49.296464988163535, 47.421250411442344, 48.4890148299081, 45.34653568267822, 38.674441133226665, 26.2360417842865, 14.878926311220441, 11.381529705865042, 3.4178297434534346, 3.3820393553801944, 4.59619037594114, 5.474459179810115, 8.6470696244921, 6.759960600308009, 6.287619020257678, 1.3251406763281142, 0.5798400374395507, 0.6699500307440758, 0.25548113669667927, 0.6795308366417885, 4.40163082735879, 13.349338582583837, 19.73953342437744, 32.80181673594883, 34.84294387272426, 34.43512977872576, 36.02616998127529, 42.776383127485005, 26.3423752784729, 9.067344444138662, 1.8507013320922852, 0.023583465056227784, 0.035197680949100425, 0.05248078550877316, 0.0459980347992054, 0.06902259734592267, 0.005021184583061508, 0.1219655160925218, 0.02779567813766854, 0.004469043675011822, 0.035448813544852395, 0.06992010240043912, 0.022552268246987035, 0.011921736445011837, 0.04228774764175926, 0.03327860749725785, 0.022093519202566574, 0.02433597735528435, 0.0547594825204994, 0.017270794238096902, 0.004031829635745713, 0.007250854047015309, 0.033114575049174685, 0.007532908331735858, 0.007458756328560412, 0.032448694708624055, 0.0302117242078696, 0.04750966154304998, 0.02306326788051852, 0.028594619195376123, 0.048902263066598346, 0.015692626957648566, 0.016670345029394542, 0.030659482681325505, 0.02586744276673666, 0.01680178744053202, 0.02704466540100319, 0.06416441553405353, 0.03714544286153146, 0.0836643652458276, 0.034666666228856356, 0.0778168590207185, 0.014278855141518372, 0.03439090620460255, 0.0567381856297808, 0.013844326404588563, 0.04509513878396579, 0.05129345100639122, 0.06347404686467988, 0.04389165175546493, 0.012733502662740648, 0.07202450412192515, 0.009224477473513355, 0.03777566279417702, 0.02911216838817511, 0.08480917595859085, 0.05582217013995562, 0.04564181409244027, 0.014862576765673501, 0.03408844243468983, 0.055391812697052956, 1.841684090239661, 12.568968159811837, 32.17575625010899, 52.09945167813982, 47.30443034853254, 37.72493505477905, 44.37939507620675, 43.20292956488473, 32.27721037183489, 26.861393553870066, 10.343627776418414, 3.3835631821836745, 0.5025768833500999, 0.13456618280283042, 0.5022442926253591, 1.5081228975738799, 4.059048158781869, 6.282171198299952, 3.9589810711996893, 5.511031023093632, 4.045193885053907, 5.97808632680348, 8.927471126828875, 17.428644214357647, 26.919054916926793, 42.37911639894758, 47.65875373567854, 48.78343432290213, 48.40599775314331, 48.91501235961914, 51.93873289653233, 51.73486580167498, 49.309937545231406, 51.077875409807476, 51.56492328643799, 48.55427578517369, 47.03501394816807, 42.70190191268921, 40.194592339651926, 38.38952677590506, 36.67749759129116, 36.399434157780235, 36.55028302328927, 36.9726744379316, 34.572398390088765, 41.92262322562081, 46.917787415640696, 47.60972377232143, 48.441819190979004, 49.2021883555821, 48.76828724997384, 49.370529311043875, 47.462112767355784, 47.56892742429461, 48.1838812146868, 46.8890392439706, 46.68562030792236, 31.99300820486886, 46.94533702305385, 48.522710118974956, 44.498949255262104, 41.41392476218087, 38.85801253999983, 40.58626924242292, 40.06409822191511, 43.147972788129536, 45.30675377164568, 48.18797370365688, 47.81292036601475, 48.68382494790213, 47.6250376020159, 46.60144288199288, 43.39354297092983, 42.024244104112896, 39.641046728406636, 39.740277426583425, 43.55346270969936, 46.53413568224226, 46.941710063389365, 48.321372168404714, 47.38188886642456, 45.243789196014404, 46.01844385692051, 48.68962321962629, 51.20371423448835, 50.64630195072719, 49.94684764317104, 50.34357588631766, 46.53662313733782, 38.72913040433611, 28.509290865489415, 19.685674462999614, 12.125997917992727, 5.18008919273104, 3.521324464253017, 7.041939343724932, 9.625845858028956, 9.181471211569649, 6.6077585731233865, 6.9621844461985996, 3.735906549862453, 1.5446647767509734, 0.5212245455810002, 0.08967252142195191, 0.793554521032742, 4.683264766420637, 14.65812645639692, 25.25884539740426, 32.54873555047171, 34.51964766638619, 37.42395298821585, 41.98205116816929, 47.36915976660592, 32.19792447771345, 12.729690415518624, 2.189988817487444, 0.02240432725687112, 0.05624500262950148, 0.038084284269383976, 0.018841226219332645, 0.08513109332748822, 0.0416408594963806, 0.04045324000929083, 0.02618762308598629, 0.06558242480137519, 0.007807991517308567, 0.04454612931502717, 0.039067284736250124, 0.04776503837534359, 0.03016518009826541, 0.048778698447027376, 0.060500781051814556, 0.04848478761102472, 0.006023935083898583, 0.033320747914591005, 0.04544960887038282, 0.04379919796649899, 0.055613666506750245, 0.023931640034009303, 0.056434816015618186, 0.11550244289849486, 0.041570848253156455, 0.028822298228208507, 0.017514054131295, 0.16999820939132146, 0.13069011936230318, 0.13824715385479586, 0.08635818998196296, 0.10962158667721919, 0.1487374680915049, 0.1515840446310384, 0.0984911017918161, 0.13154900898890837, 0.1103055431906666, 0.1436212733387947, 0.143284462126238, 0.1347882401730333, 0.1467725663845028, 0.1471516096166202, 0.1495791772114379, 0.10999582588140454, 0.12788331854556287, 0.2445876912346908, 0.14530986201550278, 0.10274384716259581, 0.10510755104145833, 0.15718559548258781, 0.14017621534211294, 0.08908930700272322, 0.16257369278797082, 0.1730375305882522, 0.13633789201932295, 0.20262335373886994, 0.15387562023741858, 0.16033393011561461, 0.21850393659302167, 1.9271167516708374, 13.68034815788269, 39.02867419379098, 59.80477115086147, 53.36202621459961, 43.971737316676546, 52.257314750126426, 47.415994099208284, 37.94137838908604, 27.97799686023167, 11.544715097972325, 4.427056457315173, 0.9276115447282791, 0.4168212663914476, 2.0549605659076144, 3.2329121232032776, 6.963433384895325, 9.187520486967903, 7.532133017267499, 8.972912345613752, 7.9629829951695035, 9.636176092284066, 11.048706650733948, 21.747833796909877, 32.21683400017874, 47.94051013674055, 51.641325678144185, 53.10170848029, 51.19335447038923, 51.44272531781878, 51.56690352303641, 52.22908421925136, 50.978780201503206, 52.19528818130493, 53.33907631465367, 51.27306420462472, 49.12459782191685, 44.24688250677926, 41.30388266699654, 40.319694655282156, 38.54322440283639, 38.551687308720176, 38.66962603160313, 38.90225172042847, 36.832275663103374, 44.017890725817, 49.892630849565776, 49.11058677945818, 49.897484166281565, 51.60675491605486, 50.607183592660085, 49.86028003692627, 48.29633433478219, 46.3976001058306, 47.861491748264854, 47.41400344031197, 47.56246212550572, 35.591893672943115, 48.759178161621094, 50.488956519535606, 46.63126802444458, 44.66887092590332, 39.524653979710166, 41.34201438086373, 40.91635036468506, 42.86896787370954, 47.18278476170131, 49.4817248071943, 50.38334042685372, 51.66154841014317, 50.4738233430045, 48.14096219199044, 44.68078361238752, 43.52816431862967, 42.01666014535086, 40.89143065043858, 43.208373478480745, 48.2410648890904, 48.73897974831717, 49.29525947570801, 47.66138710294451, 45.04937859943935, 46.568845408303396, 50.39183807373047, 50.964939389910015, 52.28894989831107, 50.843464033944265, 50.95660155160086, 48.664911951337544, 41.655777658735005, 31.508301871163503, 21.114576714379446, 14.546137997082301, 6.407739911760602, 6.692757189273834, 11.21113382066999, 14.427243028368268, 18.28333864893232, 12.123337626457214, 14.987318209239415, 6.512166993958609, 3.664018750190735, 2.3909263781138828, 1.17134382043566, 1.063192720924105, 5.812901156289237, 17.37756105831691, 29.76351887839181, 43.617170742579866, 45.241767270224436, 44.60968269620623, 48.57615218843733, 55.72909334727696, 36.31518030166626, 14.419297763279506, 2.9579773332391466, 0.1701073178223201, 0.14929590241185256, 0.09845456946641207, 0.13748678751289845, 0.1818685552903584, 0.09899458156100341, 0.12400593874709946, 0.16325207852891513, 0.19030484903071607, 0.11402192019990512, 0.15494725773377077, 0.12908921098070486, 0.07517605501094035, 0.126165010035038, 0.11930499385510172, 0.11583957980786051, 0.16314780126724923, 0.13473007615123475, 0.1204066633113793, 0.10556546039879322, 0.11051949885274683, 0.14940501084285124, 0.06277062996689763, 0.15314859710633755, 0.1977796179375478, 0.14146445478711808, 0.17448806203901768, 0.08240364039582865], [0.041079687287232707, 0.06197127500282867, 0.053265691069619994, 0.032195970948253355, 0.03128913603723049, 0.029817797310118164, 0.016657444382352487, 0.004544801685759532, 0.043144343820001395, 0.07430280079799038, 0.01409595602724169, 0.023177602727498327, 0.07182449235447816, 0.07813378915722881, 0.12778708870921815, 0.025445753608697226, 0.0030605408953436252, 0.02049920109233686, 0.010385917383246124, 0.054313671442547014, 0.014037871733307838, 0.05331703581448112, 0.05704596572156463, 0.04040904702352626, 0.026938829205131958, 0.037790234333702495, 0.004031958133314869, 0.04258383657517178, 0.07529007603547402, 0.027772843737953475, 0.03795516584068537, 0.012694846522728247, 0.6123934334942273, 7.940498624529157, 25.502249479293823, 45.51439026423863, 43.20039347239903, 43.63600383486067, 34.33288703645979, 34.68048456736973, 26.748956067221506, 29.344490391867502, 19.9246803351811, 5.485812102045331, 1.0791517559971129, 0.12354743906429835, 0.19119727185794286, 0.8513573993529592, 2.0384410066264014, 6.964932893003736, 3.479915371962956, 3.056226815496172, 2.682206371000835, 4.0574891567230225, 8.250563723700386, 13.86503735610417, 21.3546439238957, 27.39010977745056, 37.89169529506138, 45.203468799591064, 48.96290281840733, 47.249508312770296, 47.32633801868984, 47.57307549885341, 51.949464389256065, 50.52667481558663, 49.3232398714338, 45.97494465964181, 44.18560981750488, 36.899628026144846, 37.21734830311367, 36.58058411734444, 36.75878456660679, 35.596361364637104, 36.879613740103586, 35.83325672149658, 38.2941175869533, 42.73420408793858, 46.23624208995274, 47.146032265254426, 49.592121260506765, 48.89956651415144, 48.05122620718819, 46.47211953571865, 48.93600286756243, 46.021747725350515, 46.740743841443745, 40.58803408486502, 47.57830054419381, 30.68785858154297, 44.88066244125366, 48.32838984898159, 43.29600763320923, 42.24203538894653, 37.272579533713206, 34.17271716254098, 34.20211499077933, 35.50456523895264, 35.07809175763811, 39.07574129104614, 41.49972111838204, 40.51264265605381, 37.980726037706646, 38.134590421404155, 36.176549843379426, 36.73629672186715, 37.364521571568076, 38.937107358660015, 41.48250000817435, 44.441185406276155, 46.22453784942627, 49.615463733673096, 46.70243494851248, 46.85086931501116, 46.443388734545024, 47.73983226503645, 48.067735127040315, 46.307523659297395, 47.69209466661726, 48.59095879963466, 47.11006144114903, 37.50023031234741, 28.975157158715383, 17.592131853103638, 9.788075004305158, 3.9645661200795854, 2.409909942320415, 4.048000957284655, 6.068744250706263, 5.160988594804492, 6.099076177392687, 5.086175603525979, 2.889908654349191, 0.27551833008016857, 0.2791035734117031, 0.10253291098134858, 1.18317497415202, 6.2335090552057535, 13.66511423247201, 16.74982258251735, 22.776304415294103, 32.02550492967878, 31.190348829541886, 43.01838541030884, 43.22809246608189, 26.71774649620056, 9.933178578104291, 1.1359146301235472, 0.02035695979637759, 0.041545562645686526, 0.02439630081477974, 0.07760236053062336, 0.04725731436961463, 0.028526487494153634, 0.018368107499554753, 0.04170398021649037, 0.029584506792681556, 0.017231547772618275, 0.037685058013136895, 0.019069497273968797, 0.03441085513415081, 0.03585058770009449, 0.04534131807408162, 0.029843625745603015, 0.020582043432763646, 0.03296023208115782, 0.019791275329355682, 0.02919106844014355, 0.08343174987073455, 0.028923006395676305, 0.020420925292585577, 0.05839416730616774, 0.04383470909669995, 0.025987265265679786, 0.03139976777934602, 0.027273443660565784, 0.03327096040759768, 0.015589063854089804, 0.0790356368358646, 0.06872552114405803, 0.03229690642495241, 0.04106949569125261, 0.01534086761863104, 0.05076776957139373, 0.07316474829401289, 0.030996595841965506, 0.0436038002371788, 0.08004208747297525, 0.02175414312763938, 0.062304639257490635, 0.03918598425973739, 0.027744448743760586, 0.05157717363908887, 0.06757940764405898, 0.04328991333022714, 0.030792217701673508, 0.011892771481403282, 0.050781608293099065, 0.019650258789105073, 0.06708279464926038, 0.003654791898692825, 0.0164161132249449, 0.03360840944307191, 0.013767176972968238, 0.07623087840953044, 0.041407382381813865, 0.07576706579753331, 0.04204367859555142, 0.8890456770147596, 9.371726785387311, 30.495772157396587, 50.209225518362864, 46.843754359654014, 45.55773312704903, 39.26176193782261, 36.344331468854634, 28.888403688158306, 25.92213259424482, 16.921436139515468, 5.299109663282122, 0.9615491522209985, 0.06119335495999881, 0.3832668683358601, 0.9531510600021907, 3.228881733758109, 7.222034479890551, 8.455034443310328, 5.678147792816162, 1.8253543036324638, 3.982571942465646, 6.280359021254948, 15.763918365750994, 26.583215475082397, 35.54084178379604, 40.87910802023751, 46.80774532045637, 50.54604639325823, 50.53653083528791, 48.241092681884766, 49.767921107155935, 49.86042594909668, 50.21754251207624, 51.08835676738194, 47.08947045462472, 46.25537395477295, 40.49565083639962, 39.46891900471279, 38.38843590872628, 39.0310435295105, 37.448976925441194, 37.77452434812273, 37.859497342790874, 39.097565582820344, 45.800541400909424, 48.58204426084246, 49.79625933510916, 49.859588691166465, 50.303842612675254, 49.568031855991904, 48.96865940093994, 50.20961461748396, 45.59346423830305, 47.27332673754011, 44.470829895564485, 47.08883122035435, 32.82837969916207, 44.32114832741873, 48.64673893792288, 45.369089535304475, 44.799233027866904, 37.174220834459575, 36.36847298485892, 34.74467550005232, 38.26304871695382, 38.725677149636404, 42.07182536806379, 43.10230227879116, 43.153176988874165, 41.24677194867815, 42.13759354182652, 39.18161446707589, 39.213854108537944, 39.617669514247346, 41.24016073771885, 43.04867260796683, 46.251277991703574, 49.24173750196184, 49.81327894755772, 47.32401384626116, 47.03324910572597, 47.24096550260271, 49.455081939697266, 49.39192281450544, 48.070497035980225, 48.49319417136056, 50.0086727142334, 47.89035109111241, 39.88804129191807, 30.42725944519043, 19.966557128088816, 11.149801203182765, 4.4826463886669705, 3.6502005202429633, 6.658882984093257, 8.246972373553685, 8.835791383470808, 5.160213436399188, 5.465491661003657, 4.330651504652841, 1.5989368302481515, 0.4894384369254112, 0.32589385552065714, 1.3815096744469233, 5.961818856852395, 16.392924887793406, 20.449554204940796, 30.010218143463135, 34.53914778573172, 36.118966647556846, 46.339690344674246, 50.381749289376394, 30.598709719521658, 11.011390481676374, 1.6897600995642799, 0.03250688247914825, 0.014090971339360943, 0.04728094095896397, 0.03471123580155628, 0.06291971768119506, 0.04460686159187129, 0.02040680158617241, 0.02478254839245762, 0.021152197749220898, 0.04967693631936397, 0.06161272352827447, 0.020470280233504515, 0.0207044613281531, 0.06279666535556316, 0.04261431297553437, 0.04475100617855787, 0.03056132241285273, 0.03441271432010191, 0.03882241841139538, 0.025181233517027328, 0.03514937264844775, 0.03507081525666373, 0.019824180885085037, 0.04716888090063419, 0.03224333608523011, 0.0637930261769465, 0.05646908203405993, 0.02162888556319688, 0.1370257908212287, 0.19230514312429087, 0.21233614826841013, 0.15925830283335277, 0.14488446127091134, 0.14675142323332174, 0.16454623479928288, 0.15015480560915812, 0.23209363594651222, 0.13861960172653198, 0.09232739824801683, 0.1787744356053216, 0.2188880688377789, 0.1436801158956119, 0.21550673885004862, 0.07853346663926329, 0.150522951568876, 0.13703504603888306, 0.06747224660856382, 0.07992660081280129, 0.13311989898128168, 0.0916998754920704, 0.12571379781833716, 0.1287008175360305, 0.10760674479284457, 0.0823655135131308, 0.12101087160408497, 0.18660964231405938, 0.1808379963040352, 0.13354192062148026, 0.19675431081226893, 0.08248803658144814, 1.0383460713284356, 11.079462851796832, 33.135455335889546, 56.638626439230784, 54.08801221847534, 53.046650954655235, 44.89180735179356, 43.93108688082014, 39.43298292160034, 37.933374064309255, 24.233986105237687, 6.651384140763964, 1.6228170288460595, 0.3391865465257849, 0.9634501359292439, 2.653334000280925, 5.930610154356275, 13.354385580335345, 11.231003063065664, 9.459837760244097, 5.63458389043808, 7.008755615779331, 11.548071077891759, 18.006994894572667, 29.795397213527135, 38.03015204838344, 43.53315659931728, 49.54183367320469, 52.59617839540754, 51.93305969238281, 49.17418711526053, 50.48755645751953, 50.4752824647086, 51.52068758010864, 53.35712078639439, 50.29449381147112, 48.62816987718855, 41.31004919324602, 40.90110601697649, 41.56642729895455, 40.546574183872764, 38.99635464804513, 40.3002153805324, 39.69887311117989, 42.450422286987305, 46.92226552963257, 49.77575520106724, 50.92378520965576, 51.76477779660906, 50.75924491882324, 50.78165633337838, 50.441854681287495, 52.14428840364729, 47.25842979976109, 47.62918567657471, 45.619530405317036, 48.08093670436314, 36.617784772600444, 46.99371385574341, 50.188919407980784, 46.74896008627755, 45.761009625026155, 39.57141535622733, 37.64331109183175, 37.36764826093401, 40.323707239968435, 39.94149725777762, 44.00380672727312, 44.90927512305123, 43.975614411490305, 42.966416358947754, 42.44812938145229, 40.49533816746303, 39.63614477430071, 40.573647839682444, 42.82619823728289, 44.26740401131766, 46.88912609645298, 51.58368342263358, 50.96764918736049, 49.1457759312221, 48.52903297969273, 47.18184675489153, 51.18931756700788, 51.504508699689595, 49.34135035106114, 50.53796216419765, 52.63540097645351, 50.53814281736101, 41.38779258728027, 32.14955806732178, 21.725363322666713, 13.637357916150775, 6.596411296299525, 7.301345126969474, 9.61795791557857, 13.630573000226702, 15.57343350137983, 11.427196741104126, 10.617461494037084, 8.746304665293012, 3.4733795055321286, 1.1283781145300185, 0.43943626859358376, 1.8526079612118858, 8.081868410110474, 20.034051929201397, 24.561277525765554, 34.466108322143555, 43.29715061187744, 42.028350489480154, 56.40572282246181, 56.762022972106934, 35.51228468758719, 12.741376417023794, 2.001838113580431, 0.10748760082892009, 0.2067567990826709, 0.07093050889670849, 0.1519132698220866, 0.12100544332393579, 0.20630266916538986, 0.09440267724650246, 0.15384857383157524, 0.16415919842464582, 0.1024484605129276, 0.09030178122754608, 0.057919708479728015, 0.14445146093411104, 0.17272434596504482, 0.1139920646590846, 0.11262005328067712, 0.15611585788428783, 0.1789682252066476, 0.08878495012010847, 0.13275856551315102, 0.1403304599225521, 0.10687726536499602, 0.0989023075838174, 0.1466742738017014, 0.16664194448718003, 0.12464264886719839, 0.1614148092589208, 0.07834528852254152], [0.05190431572762983, 0.037282228735940795, 0.0714144129306078, 0.050752909654485326, 0.04851591879768031, 0.05562596495396324, 0.11278431982334171, 0.05146969369213496, 0.03011532813044531, 0.01826545872193362, 0.048162527581942935, 0.10088118711220366, 0.03623216186783143, 0.0822360897436738, 0.03294240018086774, 0.02543441528853561, 0.0850018256210855, 0.09570278426898376, 0.02713009974520121, 0.0811094773401107, 0.03458301303908229, 0.0787974778296692, 0.04746180446818471, 0.02237788644353194, 0.07542920964104788, 0.02482524690484362, 0.035247254717562876, 0.050518180642809184, 0.15559373875813826, 0.06434294488281012, 0.05538131236763937, 0.10026747932923691, 0.40229543298482895, 3.375510654279164, 22.10078317778451, 43.85226651600429, 50.16090774536133, 47.23683132444109, 52.462185859680176, 47.075560161045615, 61.39750671386719, 57.29778119495937, 29.041833809443883, 8.074191519192286, 1.6586026400327682, 0.13073210710925715, 0.16114643508834497, 1.1150605891432082, 3.784675521509988, 5.061486916882651, 5.554923662117549, 4.8547423992838175, 1.7398625825132643, 2.718115095581327, 8.043547357831683, 18.09294237409319, 23.974090473992483, 34.480848925454275, 41.31378732408796, 46.46767963681902, 44.147022996629985, 49.66523020608084, 51.703116008213584, 51.32925428662981, 50.70022691999163, 51.15005677086966, 47.44793496813093, 46.43089587347848, 41.97490494591849, 37.93593447549002, 39.30492762156895, 38.918878759656636, 40.49234001977103, 40.68255043029785, 41.03751652581351, 38.91076673780169, 42.90265621457781, 43.74886342457363, 47.64326967511858, 47.49887568610055, 47.05442374093192, 45.39121259961809, 46.80199916022164, 43.72126865386963, 48.87889562334333, 46.787956850869314, 48.77725042615618, 37.23444087164742, 35.24070392336164, 30.866750376565115, 41.649885586329866, 48.99394736971174, 43.203270026615684, 44.72078091757638, 40.334681919642854, 40.6661422593253, 37.110943589891704, 36.473877157483784, 32.06736087799072, 34.133553641183035, 33.63189022881644, 33.87436498914446, 33.56707048416138, 37.13159016200474, 36.62808200291225, 36.78700467518398, 36.55569566999163, 39.373096397944856, 41.87925257001604, 44.781285830906455, 48.12053796223232, 47.26014600481306, 45.6549071584429, 47.39663641793387, 46.55851343699864, 48.352708544049946, 46.57140234538487, 47.50280836650303, 45.32509354182652, 47.49935163770403, 45.11310747691563, 38.02962398529053, 27.3285539490836, 19.247356040137156, 9.809061169624329, 4.112181901931763, 2.9184720473630086, 6.743857715811048, 8.345583813531057, 7.376570667539324, 3.9084220698901584, 4.46396051134382, 3.651859402656555, 1.1840048496212279, 0.1966548240078347, 0.2595258839428425, 1.6992946565151215, 8.315894160951887, 14.838948113577706, 27.133860213415964, 25.412852219172887, 36.68109328406197, 39.38837548664638, 43.48692675999233, 38.76032781600952, 19.369758980614797, 5.934700472014291, 0.3352790262017931, 0.051043078369860134, 0.02232726094579058, 0.06245260738900729, 0.052795625757426023, 0.04970470875767725, 0.007804380862840584, 0.015775898471474648, 0.011703713813663592, 0.03676121562187161, 0.05324009333604148, 0.025218188230480467, 0.11696545939360346, 0.018743970098772218, 0.052372688094952276, 0.014427544216492345, 0.09465410161231246, 0.06972597353160381, 0.03719076560810208, 0.030591069388070276, 0.016987979145986692, 0.02485041885769793, 0.05272660517532911, 0.039350352582654784, 0.013066778707850193, 0.014155282040259667, 0.0009250034282948555, 0.05836148227431944, 0.031113079948616878, 0.03745098039507866, 0.029016976710408926, 0.08721321195896183, 0.08776037581264973, 0.03604838065803051, 0.08489089193088667, 0.05864662304520607, 0.10368324496916362, 0.022464879721935307, 0.04120763185034905, 0.020008618577516506, 0.06315336442951645, 0.032551940597061596, 0.021908252001074806, 0.018550669042659656, 0.04510734902162637, 0.060708487406373024, 0.018356445178921734, 0.037961333724004884, 0.02865983998136861, 0.06404036576194422, 0.0745890543663076, 0.009702447718674583, 0.06798153463751078, 0.032512504141777754, 0.014890562942517655, 0.024288654626746262, 0.049884333940488954, 0.12824402776147636, 0.11936918326786586, 0.05377892817237547, 0.11703001521527767, 0.5551875031420163, 5.088784217834473, 26.168394122804912, 49.52664491108486, 54.70142003468105, 52.00628328323364, 49.08032737459455, 46.85186638150896, 53.960766383579795, 52.374888692583355, 27.91842474256243, 8.75258583681924, 1.6729888852153505, 0.10634441181485142, 0.0803776705371482, 1.1722557715007236, 3.878387612955911, 7.872389776366098, 4.845889960016523, 5.0889327355793545, 3.6012439472334723, 3.272765253271375, 10.340411628995623, 20.27808482306344, 28.925732885088237, 35.192271505083355, 43.31441341127668, 47.14035906110491, 48.49233259473528, 52.223629883357454, 51.03924342564174, 50.530958380017964, 51.59069415501186, 51.761463505881174, 50.02169016429356, 47.62277596337454, 44.17577116830008, 40.93001747131348, 39.53186968394688, 41.00116007668631, 41.7701450075422, 41.63068771362305, 41.52768414361136, 39.50870786394392, 44.19175549915859, 46.98688725062779, 49.24116774967739, 49.56221621377127, 49.74783386502947, 47.709628445761545, 49.3476801599775, 45.10122258322579, 49.12414618900844, 48.6475692476545, 48.39832694189889, 41.905829429626465, 37.673761572156636, 33.25306749343872, 42.99734279087612, 50.35833733422415, 45.1069826398577, 45.05529499053955, 42.066864354269846, 41.063488892146516, 38.2094155720302, 36.683170795440674, 34.571575028555735, 36.34572458267212, 35.654938152858186, 36.03369140625, 35.411042485918315, 38.24705743789673, 37.65342419488089, 37.45189864294869, 37.824554852076936, 39.799927711486816, 43.18122339248657, 46.47360645021711, 50.300559588841026, 48.22280502319336, 47.14745317186628, 47.961542333875386, 47.4333541733878, 49.37314878191267, 47.30818932397025, 48.08896882193429, 48.216645445142476, 49.87847736903599, 46.76062958581107, 40.384111404418945, 28.913731609072002, 20.588000535964966, 10.065586924552917, 4.354460375649588, 3.723420202732086, 9.185061693191528, 11.487303001540047, 8.65897536277771, 7.125923088618687, 5.463906603200095, 3.2387049666472842, 0.8555911864553178, 0.40666302719286507, 0.1871765311807394, 2.1977004493985857, 7.789322325161525, 20.100968292781285, 26.437529121126445, 27.499915633882793, 40.30548211506435, 41.362709590366904, 49.098740100860596, 44.667012282780235, 23.161620242255076, 8.323759521756854, 0.5294748257313455, 0.07297345570155553, 0.017529017524793744, 0.052665794866957834, 0.05829255668712514, 0.0047602272243238986, 0.020804395965699638, 0.011171744055380779, 0.025099061229931455, 0.035804165726793666, 0.028411657316610217, 0.04163160427872624, 0.07529673924935715, 0.02331304340623319, 0.10341696747179542, 0.03131971761052098, 0.04264470116634454, 0.022694438296769346, 0.03234380676544138, 0.014011218029606556, 0.03275152488744684, 0.041812030132859945, 0.02028459234030119, 0.03692965854757598, 0.03446718032604881, 0.07694807635354144, 0.014508386574951666, 0.04664881434291601, 0.02069347245352609, 0.08161166789276258, 0.13110832763569696, 0.14237229392996856, 0.17731520533561707, 0.2148033965911184, 0.2180541900119611, 0.19006855599582195, 0.1562031310583864, 0.12093475354569298, 0.15479028544255666, 0.18050643695252283, 0.1616195911275489, 0.08224384539893695, 0.20294359512627125, 0.0755428574713213, 0.111562027196799, 0.1716850067355803, 0.16260850163442747, 0.16316173837653228, 0.16536861924188478, 0.15474292369825499, 0.17007287538477353, 0.08404623118362256, 0.1115411486742752, 0.1981952613485711, 0.11458047665655613, 0.14826309068926743, 0.11753583593027932, 0.3378162586263248, 0.19427963931645664, 0.16558446123131684, 0.22841763177088328, 0.6215261348656246, 5.53969190801893, 28.98982306889125, 53.738420554569785, 60.86833190917969, 57.96319627761841, 59.58973135266985, 56.957218715122764, 68.03917857578823, 62.26019505092076, 33.235662255968364, 9.628930858203343, 3.004470552716936, 0.22785241210034915, 0.6063357985445431, 3.3521779520171027, 9.314328585352216, 11.5005202123097, 11.952433654240199, 10.779064433915273, 4.62471490246909, 5.20329270192555, 10.968917880739484, 27.018825837544032, 35.506715706416536, 42.645208086286274, 45.99528898511614, 48.453044005802695, 50.77600049972534, 54.320606640407014, 52.710841042654856, 51.25928940091814, 51.2560202734811, 54.39581046785627, 50.613860811506, 51.06509419849941, 45.47102655683245, 43.42560543332781, 41.53490332194737, 43.05798666817801, 44.722983496529714, 43.550412450517925, 45.25588948386056, 42.92270871571132, 47.9295563016619, 48.89727013451712, 50.928391865321565, 51.64114155088152, 50.8433598109654, 50.27918692997524, 50.31556074959891, 47.92991413388933, 51.5774439402989, 49.36372355052403, 49.83260883603777, 43.30618674414498, 37.60087844303676, 38.181410857609336, 42.93846723011562, 51.19755813053676, 46.693065302712576, 46.630138942173545, 44.48475408554077, 43.38972840990339, 41.55126632962908, 39.28022330147879, 35.55160454341343, 37.974080085754395, 36.680804933820454, 37.822300161634175, 36.57158620016915, 40.2786933353969, 39.72351837158203, 38.79574973242623, 38.98299673625401, 42.40672506604876, 45.477985177721294, 49.14653328486851, 52.09128407069615, 46.273508753095356, 47.40607901981899, 48.47910322461809, 46.91999346869332, 50.214078835078645, 50.49125289916992, 49.64703287397112, 49.6676481791905, 52.59335395268032, 49.902747426714214, 44.143524578639436, 32.894113131931846, 23.083463430404663, 12.624623230525426, 7.40276711327689, 7.288137469972883, 13.322171994618007, 14.117892725127083, 15.911749976021902, 12.864548870495387, 12.517231004578726, 8.817330888339452, 2.805868455341884, 0.9734004991395133, 0.8214465443577085, 2.307635064635958, 10.526645064353943, 21.540497813905986, 36.81100722721645, 35.86555889674595, 47.805617809295654, 49.079323359898154, 55.83286121913365, 48.80004399163382, 26.794001238686697, 8.452445370810372, 0.9082833932978767, 0.16441994586161204, 0.10142357407936028, 0.08059729196663414, 0.16110714791076525, 0.1886882936315877, 0.08970882983079978, 0.12481131910213403, 0.08475620272968497, 0.1699887506131615, 0.09643436037003994, 0.14892500159995897, 0.17310974028493675, 0.10022076897855316, 0.1896609328687191, 0.14581104155097688, 0.13732426480523177, 0.11584047547408513, 0.15013164042362145, 0.20257964251296862, 0.15329255509589398, 0.07151693278657538, 0.17017057085675852, 0.11517401837876864, 0.14670448218073162, 0.1541037437106882, 0.06119991639362914, 0.1275528177086796, 0.06856776853757245], [0.027612563588523438, 0.04785461178315537, 0.02626069961115718, 0.009593900775403848, 0.020188238671315566, 0.05498381976836494, 0.00787025473878852, 0.02873746438750199, 0.016650290926918387, 0.0651176350989512, 0.03756732200937612, 0.09017157714281764, 0.04973433020391634, 0.027794295622568046, 0.056693337857723236, 0.020910216894532953, 0.06429434141942433, 0.03905643496130194, 0.04840253898873925, 0.03249650428603802, 0.0586037328466773, 0.02890050956713302, 0.024714968000937785, 0.01902089381058301, 0.00917426757847092, 0.030834700779191086, 0.07120701191680771, 0.06969914425696645, 0.0345066982055349, 0.01239622665369617, 0.03348148607515863, 0.03317606049988951, 0.06557358349008219, 2.4649848384516577, 15.736123834337507, 40.048614161355154, 48.68040296009609, 49.3430700302124, 47.20768363135201, 59.423975127083914, 79.79981763022286, 66.43290097372872, 41.60276985168457, 15.260538748332433, 3.1038043882165636, 0.39561962549175533, 0.10206983797252178, 0.45961155742406845, 2.7507516528878893, 7.457735180854797, 6.466616775308337, 3.452747915472303, 1.7933317933763777, 4.288459871496473, 12.324445417949132, 17.19492765835353, 23.45341157913208, 32.25278050558907, 41.38568728310721, 47.62322759628296, 42.80512087685721, 48.97820275170462, 51.12738479886736, 48.361522333962576, 52.09421273640224, 50.66118151800973, 46.80478538785662, 46.60192230769566, 41.603596687316895, 38.668747084481375, 41.125831604003906, 42.2611220904759, 45.097015448978965, 45.16415589196341, 45.19186183384487, 44.974570819309776, 42.65278509684971, 42.67449474334717, 46.373656613486155, 44.305268219539094, 45.814621925354004, 44.892411845070974, 44.408883231026785, 42.45022078922817, 45.791348934173584, 43.662163802555625, 48.120336464473176, 43.72887693132673, 42.56729793548584, 28.474202462605067, 39.64275598526001, 50.59552798952375, 45.312527724674766, 46.137014865875244, 43.475997243608745, 44.037929330553325, 42.05570902143206, 43.082326207842144, 35.5144316809518, 32.63460486275809, 34.88208654948643, 34.53868920462472, 38.35342393602644, 43.35028001240322, 40.093120847429546, 39.900572368076865, 37.48105328423636, 40.09756422042847, 43.020706108638215, 46.33420474188668, 47.285336698804585, 47.781504086085725, 47.668106010981965, 44.46715777260916, 46.68671464920044, 48.39602708816528, 46.251423903873985, 45.92987864358084, 45.20733894620623, 47.68193640027727, 43.27175842012678, 37.604550565992085, 26.72893830708095, 17.810807296207972, 7.498854620116098, 2.380626759358815, 2.12196313057627, 5.557362914085388, 9.022280165127345, 6.1955892613955905, 3.920390776225499, 2.273493353809629, 1.9798713837351118, 1.2781665112291063, 0.22975716846329824, 0.25215039827993935, 2.6983798231397356, 9.899575352668762, 16.146920442581177, 20.636498962129863, 26.181647811617168, 27.575755221503123, 42.441434792109895, 41.262200423649375, 34.853578090667725, 12.40222442150116, 2.252652232136045, 0.10573909072471516, 0.021482025140098164, 0.017526939511299133, 0.04186055895739368, 0.0563806892771806, 0.027184151844786744, 0.004568590699428958, 0.06013554600732667, 0.031436123685645204, 0.031828632445207665, 0.009966197673098316, 0.0298345469470535, 0.07746148987540177, 0.07110664301684924, 0.06758972137634243, 0.039965458147759945, 0.027836994134954045, 0.05418586937178459, 0.03902042171518717, 0.05890278358544622, 0.0017539945755353464, 0.031578602468861, 0.03831175974171076, 0.062142964718597274, 0.053547445950763564, 0.05994193282510553, 0.017311260370271545, 0.013079321427669908, 0.04179974186367222, 0.02800566776256476, 0.004371819360780397, 0.06872856098094157, 0.025273420980998447, 0.07093848168317761, 0.03657121563862477, 0.039230957560773404, 0.02835233978527997, 0.019168312328734567, 0.1060147387906909, 0.04858371462406857, 0.018307224248668978, 0.0316199184661465, 0.08295340982398816, 0.029384264323328222, 0.06352798361331224, 0.030506812302129607, 0.0717049412695425, 0.04322095720895699, 0.09337359068116971, 0.051801731410835467, 0.024497366909469877, 0.016118058236315846, 0.028506779444536993, 0.033997064123728445, 0.061014710260289054, 0.0457712208985218, 0.0518267184628972, 0.08506454939820937, 0.07911813990878207, 0.051213936880230904, 0.04219293933627861, 0.018567573046311736, 2.7915972896984647, 18.968180894851685, 44.98475340434483, 54.73806830814907, 54.23767989022391, 53.78072813579014, 59.648388045174734, 81.02418749673026, 68.6741327558245, 40.95785542896816, 15.148221118109566, 3.959078780242375, 0.36644403104271206, 0.131864459919078, 0.30003703013062477, 2.8200523342405046, 4.698996790817805, 4.859579648290362, 3.4170617503779273, 0.8390577850597245, 3.5450284608772824, 13.262241176196508, 21.915573733193533, 27.107870476586477, 36.16279241016933, 43.322963169642854, 49.28789438520159, 47.28941181727818, 50.90098122188023, 50.681213174547466, 49.79287903649466, 52.46875190734863, 52.16051244735718, 49.00797230856759, 48.04728657858712, 43.222506114414756, 39.96977990014212, 42.180707114083425, 43.972397395542686, 47.16091183253697, 48.35451854978289, 48.27170991897583, 46.875313077654155, 45.167563983372276, 47.56582505362374, 47.172744614737375, 46.65623985018049, 47.761448110852925, 46.134555203574045, 47.57427058901106, 44.98941911969866, 48.259852818080354, 45.530551774161204, 49.49003832680838, 44.63751023156302, 42.02584218978882, 31.108012676239014, 41.94319684164864, 50.90948929105486, 47.021253040858674, 47.90694686344692, 46.608384132385254, 47.03363125664847, 43.47152607781546, 43.191628319876536, 36.2784104347229, 34.072798592703684, 35.7559232711792, 35.58110659463065, 38.875751291002544, 44.2854380607605, 41.27819865090506, 40.92378841127668, 38.817355155944824, 41.51015036446707, 45.54453502382551, 47.58437326976231, 49.56170204707554, 48.71589435849871, 46.70802477427891, 46.50426885059902, 47.60653107506888, 50.076900550297324, 48.56334318433489, 47.5016063281468, 47.77331215994698, 48.17683574131557, 45.54344415664673, 39.23881551197597, 29.344000543866837, 19.103761093957083, 10.185375605310712, 2.923399622951235, 4.65209037065506, 5.610723342214312, 7.741156544004168, 8.677316001483373, 4.671995222568512, 4.981592186859675, 4.2045299751417975, 1.091641142964363, 0.4384094551205635, 0.4860932592834745, 2.5999939824853624, 11.736202239990234, 19.22250928197588, 25.58057825905936, 27.665451254163468, 34.341058118002756, 47.91698701041085, 46.35872840881348, 37.42830950873238, 15.923930168151855, 3.283950550215585, 0.1312804448285273, 0.0020862252526317854, 0.04706833218889577, 0.024334739028875316, 0.02645774109156004, 0.05049190437421203, 0.03132375150120684, 0.026620764218802963, 0.025340494167591845, 0.07688843312540225, 0.023503572646794573, 0.020358362667528645, 0.022073320911398957, 0.041401211105819256, 0.03937578746782882, 0.05989097484520503, 0.011179082411607462, 0.1254880085055317, 0.03571067377924919, 0.02143447001331619, 0.08010331847305809, 0.013738295129899467, 0.02759751198547227, 0.057396028723035536, 0.02738173445686698, 0.05303277713911874, 0.03165093769452401, 0.019476358745513216, 0.05608432214441044, 0.10149750725499221, 0.06187855997788055, 0.1499728225171566, 0.14578795778964246, 0.163651952786105, 0.1345942605819021, 0.1566971724054643, 0.0769408703116434, 0.07002846444291727, 0.26645101234316826, 0.11239688989839383, 0.11161457973399333, 0.21419259293803147, 0.15111114643514156, 0.14527461890663418, 0.11859671186123576, 0.10688930257622685, 0.2124933919736317, 0.113819465706391, 0.1835140705640827, 0.0802885110356978, 0.07018427643924952, 0.11206017368073974, 0.09050150801028524, 0.13019229178982122, 0.0978906729391643, 0.13560601057750837, 0.1304127885294812, 0.12248192195381437, 0.18191171011754445, 0.1885748425764697, 0.14210345835558005, 0.23014317346470697, 3.702338933944702, 21.2356629712241, 50.66384962626866, 60.70535496303013, 60.38154806409563, 57.72942066192627, 67.13684381757463, 84.3370121547154, 72.2111827305385, 45.62957750047956, 18.272172893796647, 4.193984346730368, 0.6902727516634124, 0.40883694482701166, 1.3360210124935423, 6.340304170336042, 14.074824316161019, 13.256765127182007, 8.945768339293343, 5.463999101093837, 6.013064427035196, 15.46410185950143, 22.029675313404628, 27.783693960734777, 36.144939013889854, 43.73647826058524, 49.822912624904085, 49.32555014746529, 54.05036687850952, 52.36679056712559, 49.94617714200701, 53.40997920717512, 53.77247714996338, 49.91883945465088, 51.05525207519531, 44.724366188049316, 42.60949434552874, 44.558794089726035, 47.50656039374215, 49.238301617758616, 50.00114434106009, 50.368599823543, 49.44651828493391, 47.66057068961007, 49.017814431871685, 49.047031606946675, 47.80230351856777, 48.80752372741699, 48.15017202922276, 47.41103308541434, 45.843279770442415, 49.51832096917288, 47.07057135445731, 51.19386168888637, 47.4507976259504, 44.16259043557303, 35.58986827305385, 43.50395679473877, 50.06492533002581, 50.31418153217861, 49.45705870219639, 48.7238187789917, 48.30625636237008, 46.168639591761995, 46.35513619014195, 39.364306926727295, 35.23715686798096, 37.793426922389436, 38.11914805003575, 41.49571200779506, 47.287987436567036, 44.05789845330374, 43.822948592049734, 41.32449797221592, 43.24369812011719, 47.197792870657786, 49.545276505606516, 51.22680309840611, 49.860405104500906, 47.78108719417027, 46.52662467956543, 48.33713068280901, 52.3265118598938, 50.195402077266145, 49.61470985412598, 48.81286689213344, 51.368567194257466, 46.27895266669137, 42.76581144332886, 31.303538458687918, 20.637334483010427, 10.58223499570574, 5.469740918704441, 5.917143242699759, 11.82737215927669, 15.707439933504377, 15.138471058436803, 11.984397973333087, 9.857107094355992, 8.151784658432007, 2.5966790403638567, 1.1825171751635415, 0.6048945358821324, 3.4838513093335286, 13.380591579845973, 22.115671430315288, 28.29326789719718, 36.32574156352452, 40.077813965933665, 54.840436117989675, 51.464025020599365, 43.09523248672485, 17.54367859022958, 3.845180869102478, 0.32070680814129965, 0.07975195946970157, 0.12423882553619997, 0.16573953362447874, 0.1156484093517065, 0.12815494968422822, 0.14436243713966437, 0.09561112097331456, 0.11170163577688591, 0.18125841660158976, 0.1390362357986825, 0.06679276842623949, 0.1434668523392507, 0.16021743922361306, 0.16154622792133264, 0.11097155923822097, 0.0879292224666902, 0.23995487125856535, 0.09667135229600327, 0.14379329553672246, 0.17165471693234785, 0.10842562120940004, 0.1435685104557446, 0.08654939436486789, 0.12908197779740604, 0.16675003511565073, 0.12881243654659816, 0.09899275630180325, 0.15674510411918163], [0.05148107611707278, 0.037088791972824504, 0.03248185132231031, 0.04524573963135481, 0.01786619853893561, 0.033106900818113766, 0.029779857024550438, 0.03928292316517659, 0.09080562740564346, 0.03160607974444117, 0.010141358095487314, 0.03291252089132156, 0.05424072892804231, 0.07806875836104155, 0.04820850511480655, 0.029560181312263012, 0.031662995261805396, 0.04124010653634157, 0.055077783297747374, 0.04998545601431813, 0.04190813104755112, 0.03495346262518849, 0.050766249652951956, 0.022019833692216446, 0.08397885944162096, 0.037174307741224766, 0.006905934765070144, 0.027276736251743774, 0.05687436082267335, 0.024901120690628886, 0.052249177758182795, 0.025727321892710667, 0.0686036833961095, 0.5920430283461298, 10.26305559703282, 35.72536161967686, 49.47415474482945, 47.20959786006382, 45.29736328125, 45.63075869424002, 43.669942310878206, 46.06591394969395, 24.71714993885585, 10.31290544782366, 3.2504263605390276, 0.6420749436531747, 0.05704873414444072, 0.5933957557593073, 2.359316851411547, 2.984240003994533, 3.230541918958936, 18.722499540873937, 26.35180398396083, 8.979742424828665, 7.680195655141558, 9.106540969439916, 19.537488494600566, 28.52831503323146, 39.590950216565815, 43.68172298158918, 43.825092111315044, 49.55528538567679, 50.323464325496126, 48.072633607046946, 52.6857510975429, 49.91480255126953, 47.8443957056318, 45.64320639201573, 42.96479395457676, 39.855614049094065, 45.29362167630877, 45.556381702423096, 46.40377010617937, 46.84222575596401, 45.306705134255544, 44.797975403921946, 44.829204082489014, 45.10817078181675, 45.23207105909075, 44.15405804770333, 43.8913813999721, 41.148364612034385, 41.3637170791626, 40.47250986099243, 43.10155187334333, 44.59040144511631, 47.43547337395804, 46.516219752175466, 49.59892702102661, 30.697954314095632, 37.16456978661673, 47.67395986829485, 46.35199213027954, 47.237143993377686, 45.23052161080496, 47.19638933454241, 44.24080630711147, 46.91369840076992, 38.76462180273873, 33.17380939211164, 32.51795155661446, 36.45685407093593, 44.28498295375279, 46.65197365624564, 45.66884524481637, 43.60173879350935, 40.14468342917306, 39.31829942975725, 43.49495192936489, 46.02549975258963, 49.02086121695382, 48.434909207480295, 44.41874967302595, 45.652166094098774, 48.20733833312988, 48.52930743353707, 46.625184876578196, 47.971026624952046, 48.39623900822231, 46.816298552921836, 42.465145519801546, 38.1668370110648, 25.581566640308925, 15.883795636040823, 8.618368353162493, 2.7634877009051184, 3.2192254747663225, 6.917854504925864, 9.500341415405273, 7.14054513829095, 4.4359028169087, 2.92201497725078, 1.6362041447843825, 0.17419798831854547, 0.5788426995277405, 0.388486241123506, 5.119215590613229, 11.024916887283325, 22.2371780531747, 28.58010516847883, 24.41192773410252, 31.96902997153146, 41.930071694510325, 39.32480294363839, 27.698988471712383, 5.871142693928309, 0.8009183087519237, 0.06851029662149292, 0.05084939054878695, 0.017393900846530284, 0.02052638490152146, 0.03704863966309598, 0.024493587469416003, 0.04980753056172814, 0.03250613609062774, 0.04071179577814681, 0.014652414114347525, 0.03040797689131328, 0.044224510501538, 0.06518451151038919, 0.035043229415480576, 0.07220364415219852, 0.06423629953392915, 0.07360752632043191, 0.017392891525690044, 0.03981785303247826, 0.031381576255496056, 0.06887215256158795, 0.052574056932436566, 0.033986048107700687, 0.006484603958337435, 0.029514234313475232, 0.054047838385616026, 0.026134812705484883, 0.03910802397876978, 0.03192055358418396, 0.011005477530748715, 0.03048421030065843, 0.054650238382497, 0.027404835181576864, 0.012975380889007022, 0.016215151508471796, 0.011851024614380938, 0.07501204631158284, 0.06119211324091468, 0.06547704831297908, 0.007040438217310501, 0.02557553191270147, 0.060296345236045976, 0.06328647942947489, 0.04426327859982848, 0.02226168562525085, 0.02158556110225618, 0.03979352755205972, 0.047767959468598874, 0.05840285933975663, 0.0042411207936571115, 0.03305568499490619, 0.008336547396278806, 0.07567326511655535, 0.03839850026581969, 0.02714736676508827, 0.04379758983850479, 0.024051930722115294, 0.0375901241786778, 0.03468734458354967, 0.05228873634977, 0.08067353216132947, 0.027659770966108357, 1.3014324456453323, 14.045456886291504, 41.080769062042236, 55.323895250047954, 53.176352977752686, 51.86769451413836, 52.90720755713326, 52.17582975115095, 57.5879761832101, 39.505129541669575, 17.784605639321462, 4.157857622419085, 0.5037334327186856, 0.18870518915355206, 0.4280053691140243, 1.2658223850386483, 2.902071041720254, 2.5520920157432556, 13.362333450998578, 20.825319732938492, 10.26234427520207, 10.291585768972125, 13.93304111276354, 21.755905866622925, 30.45033093861171, 40.76934037889753, 46.19610929489136, 47.07823174340384, 49.89980139051165, 51.61762884684971, 48.99452059609549, 53.45546211515154, 51.71256555829729, 48.96420560564314, 47.58883401325771, 45.34395790100098, 42.08563838686262, 46.79218830381121, 47.5602456501552, 47.88064793178013, 48.42355237688337, 46.8014189856393, 44.86013051441738, 47.09282990864345, 46.39478955950056, 47.934743131910054, 45.929906436375205, 45.56272888183594, 43.99927997589111, 42.99491786956787, 42.28690685544695, 45.64582586288452, 47.75412470953805, 49.108971323285786, 48.29221057891846, 48.17762436185564, 33.484970569610596, 38.501298972538535, 47.94757645470755, 46.71156488146101, 48.44603327342442, 46.410468169621055, 48.280263151441304, 46.133217675345286, 48.984011445726665, 40.7602972984314, 32.835581507001606, 34.70596361160278, 39.13365452630179, 45.669932637895855, 47.579721450805664, 47.37287705285208, 44.06995357785906, 39.99375465938023, 41.32799291610718, 45.69608218329293, 48.19789225714547, 49.60598986489432, 49.65425552640642, 46.63981430871146, 46.55626222065517, 49.60205371039254, 50.115577697753906, 48.96840579169137, 50.31431007385254, 49.55102613994053, 47.67967128753662, 44.45448425837925, 41.017335483006065, 29.42899785723005, 19.002168008259364, 9.312034811292376, 2.545182249375752, 4.648793016161237, 5.9302623101643155, 7.172391338007791, 6.172479552882058, 6.010765876088824, 6.699775738375528, 2.036649457045964, 1.127384522131511, 0.11171545753521578, 0.5046307817101479, 4.313221514225006, 11.98708518913814, 22.79243986947196, 25.88581783430917, 29.012043407985143, 33.423579760960166, 46.14881638118199, 45.099770409720286, 31.28677592958723, 8.992295214108058, 1.413594827055931, 0.04315625210957868, 0.0254187072028539, 0.03728610656357237, 0.010590291282694255, 0.02348988998814353, 0.007757133621323321, 0.06662339251488447, 0.022679137332098823, 0.048874700974140844, 0.0034513490765155958, 0.02419479627029172, 0.020307240142886127, 0.026892186707950065, 0.07208996918052435, 0.0673665851354599, 0.04081982194579073, 0.02392110408150724, 0.027558433457410762, 0.030927738108273064, 0.05512063617685011, 0.051503532233514955, 0.005298338996778641, 0.01332966607463147, 0.04297614177422864, 0.020073364388995936, 0.007798793126962015, 0.03169638936274818, 0.06336099614522286, 0.07473036606929132, 0.2514180690050125, 0.11809238392327513, 0.12656975617366178, 0.12301655326570783, 0.1775655983281987, 0.1637416144034692, 0.07098804866628987, 0.14439060991363867, 0.19965067825147084, 0.23224321220602306, 0.07485704855727297, 0.05226492316329053, 0.11707075445779733, 0.14013357620154107, 0.14433666637965611, 0.11547512507864408, 0.1882118127707924, 0.13206555055720465, 0.12159431672522, 0.1895455547741481, 0.13992241610373768, 0.15096129876162323, 0.07837603294423648, 0.1778604489352022, 0.19274180755019188, 0.18682206448699745, 0.09336534648069314, 0.12630729882844857, 0.2991656283182757, 0.15448068348424776, 0.17514710953193052, 0.10090912239892141, 0.08086361696145364, 1.6726190022059848, 16.92791359765189, 45.66934551511492, 61.76355866023472, 59.282461166381836, 57.070300647190635, 54.83255338668823, 53.34148733956473, 54.91829415730068, 32.858586992536274, 14.99469198499407, 4.790821577821459, 1.1656422806637627, 0.3230917773076466, 1.1951476974146706, 4.635618797370365, 7.747626185417175, 8.300569908959524, 25.860140766416276, 30.81271423612322, 10.914342386381966, 8.645593132291522, 12.194108503205435, 22.173760107585363, 30.48812566484724, 44.81757627214704, 46.9589832850865, 50.49614443097796, 54.561101164136616, 52.25056804929461, 48.92943334579468, 53.964171000889365, 53.15741913659232, 51.61445699419294, 49.24330084664481, 47.397772448403494, 44.92517954962594, 49.672831535339355, 48.98092297145298, 50.794705050332205, 50.73555156162807, 47.417411531720845, 47.41455929619925, 49.18703433445522, 49.47992869785854, 49.752871309007915, 47.68733515058245, 48.86434262139456, 44.99625267301287, 44.79072148459298, 44.39045313426426, 48.11073752811977, 50.102928502219065, 50.92942367281233, 50.426881313323975, 48.14990104947771, 36.01570946829659, 41.432591097695486, 47.06501974378313, 46.58514240809849, 48.89988613128662, 48.943083081926616, 49.68586982999529, 49.91318709509713, 51.420737743377686, 43.243044989449636, 35.435885769980295, 35.72867938450405, 40.51198257718767, 48.57513427734375, 48.67334359032767, 50.42260817119053, 46.77278198514666, 42.81999349594116, 43.6361323765346, 46.93919134140015, 49.322569370269775, 51.744270188467844, 49.10684517451695, 48.28926454271589, 47.570879868098665, 49.729254381997244, 51.5356296811785, 50.13588728223528, 53.043694496154785, 53.40348611559187, 50.36040442330496, 46.753271443503245, 42.38737780707223, 30.153097425188335, 21.697775500161306, 11.712363839149475, 4.548279941082001, 7.6649695464542935, 16.41029712132045, 19.86675841467721, 14.999375070844378, 9.961906773703438, 10.52982473373413, 5.268813780375889, 2.0858081792082106, 1.1067754051515033, 1.0539178528956004, 6.328972092696598, 15.35080279622759, 30.185496875217982, 38.329598563058035, 34.74933079310826, 42.20804132734026, 54.51329755783081, 50.574217864445274, 34.530361788613455, 10.24628438268389, 1.584271680031504, 0.2453501746058464, 0.0957473504490086, 0.09176802754934345, 0.10686184904937233, 0.2347512947661536, 0.1068424836599401, 0.1717352726097618, 0.1535067686012813, 0.16743589831250055, 0.07209427109254257, 0.05731969353343759, 0.16733035897569998, 0.1652245662574257, 0.2555566983563559, 0.21326278283127717, 0.09191847233367817, 0.15330917920385087, 0.06266916184020893, 0.08298308894570385, 0.18132313527166843, 0.15174998715519905, 0.20238769852689334, 0.14321122105632508, 0.09057050145098142, 0.11428132413753442, 0.10458674827324492, 0.2608289425926549, 0.17703252764684813, 0.17486616889280931], [0.015590342892599958, 0.049303501179175716, 0.02028338285163045, 0.0922725454771093, 0.015638032030048113, 0.05118631711229682, 0.05860357678362301, 0.02985620917752385, 0.018443053388702016, 0.07149460898446185, 0.03387967756550227, 0.031797314661421945, 0.018974453177569166, 0.061168004891702106, 0.04341981885954738, 0.037582694220223596, 0.028732701071671078, 0.0201416589386229, 0.03981212619692087, 0.011968857309381877, 0.026112561845885854, 0.07527619320899248, 0.08596419862338475, 0.05661243273477469, 0.019923162180930376, 0.03926838215972696, 0.010904998368849712, 0.06189800000616482, 0.05513561483738678, 0.03663728120071547, 0.02601071882859937, 0.026591551589912603, 0.09655589956258025, 0.3338441417685577, 6.296570471354893, 23.145394461495535, 41.12566484723772, 47.94648558752877, 50.2296393258231, 38.4648973601205, 24.754079614366802, 20.303935595921107, 19.788521698543004, 16.37916919163295, 7.487740107945033, 1.030126678092139, 0.5029233161892209, 0.12112999521195889, 1.2817738205194473, 1.8201455431325095, 8.223805342401777, 14.098105992589678, 2.1750291287899017, 2.0489095534597124, 3.080755259309496, 8.15590146609715, 11.981348582676478, 21.254016637802124, 30.470202786581858, 41.93424756186349, 41.351081780024934, 47.41734552383423, 48.67509453637259, 51.82922581263951, 52.4625506401062, 49.25596046447754, 49.46505955287388, 45.21883821487427, 43.316018445151194, 44.93262454441616, 47.14998231615339, 47.11220496041434, 47.4650935445513, 48.02846390860421, 47.61368424551827, 46.501281125204905, 48.009502274649485, 45.89141689028059, 43.54487821034023, 42.79880843843733, 42.13054806845528, 37.96233763013567, 38.97441918509347, 38.66068022591727, 43.26695721490042, 43.84460265295846, 49.76965468270438, 47.7752229145595, 51.248033319200786, 32.363506998334614, 37.85597808020455, 51.20401995522635, 43.936881678445, 49.714711802346365, 47.887415477207725, 48.596698011670796, 47.20573813574654, 46.97654833112444, 40.69188533510481, 35.52431549344744, 34.52745049340384, 41.075144495282856, 47.08299820763724, 48.87337180546352, 48.70788655962263, 44.81024939673287, 41.453265462602886, 39.20024258749825, 45.08134726115635, 46.837521825517925, 47.87015267780849, 48.00322110312325, 43.47047689982823, 45.184489795139854, 47.92167704445975, 47.83020748410906, 46.45723302023751, 45.96175003051758, 45.159726415361675, 45.48818860735212, 41.324484075818745, 32.1603034564427, 23.01161731992449, 13.657951508249555, 7.518312181745257, 0.76961450278759, 4.370059081486293, 2.959181542907442, 4.696280913693564, 4.10383494411196, 3.146788550274713, 2.935543119907379, 2.4022174179553986, 0.5880361976368087, 0.3298153265246323, 0.872991647039141, 4.204672413212912, 11.495937875338964, 17.947170904704503, 28.372560739517212, 28.377476590020315, 38.17048828942435, 48.30119112559727, 32.1977334022522, 11.521080800465175, 4.500999186720167, 0.08807157911360264, 0.053454004893345494, 0.025859273205112134, 0.05269646125712565, 0.020625936166782464, 0.023635612168748463, 0.04517317709646054, 0.01852213155611285, 0.04568429716995784, 0.0179337263439915, 0.01795940041275961, 0.036768150249762196, 0.05650751765019127, 0.04640731015907867, 0.04146335134282708, 0.050539493427744935, 0.010992749910136419, 0.04644631913730076, 0.045921485871076584, 0.0472728426435164, 0.08022001971091543, 0.048082324742738686, 0.05307176236861518, 0.04877770778590015, 0.053509719403726716, 0.0414039014971682, 0.03314220838780914, 0.07512490025588445, 0.02449075797838824, 0.03812701501218336, 0.04356860123308642, 0.02507391132946525, 0.05628518208063074, 0.031032351244773184, 0.06205729288714273, 0.050212653287287266, 0.040923284965434244, 0.02424408675038389, 0.1008892006107739, 0.012700805756529527, 0.050441706353532414, 0.014381604003054755, 0.0383160582610539, 0.03994838281401566, 0.0249787281333868, 0.046290754806250334, 0.03219088872096368, 0.04067328213048833, 0.008523275144398212, 0.02371734510441976, 0.02433126323324229, 0.023212991721395935, 0.07260795602841036, 0.07459535795663085, 0.03883934107476047, 0.04542686437655773, 0.032246073974030356, 0.05815236456692219, 0.04286984587088227, 0.032721377576568296, 0.054117954801768064, 0.03278855254341449, 0.002535202120530552, 0.4559665215866906, 8.00820187159947, 29.46283905846732, 49.23136036736624, 55.939790521349224, 55.900620051792686, 45.78478636060442, 29.673105444226945, 26.93990993499756, 20.721607446670532, 14.122437715530396, 6.659243421895163, 1.0087818120207106, 0.3147152082196304, 0.25958399368183954, 0.8752551312957491, 2.262060744421823, 6.804587577070508, 17.69121663911002, 5.763928949832916, 2.5997403732367923, 4.5259058730942865, 8.120328426361084, 13.367021747997828, 22.69660336630685, 33.55875696454729, 43.58572319575718, 45.44651331220354, 50.26660026822771, 50.937980379377095, 51.77003410884312, 53.26873622621809, 51.161184310913086, 50.47858285903931, 47.5933746610369, 44.5833420753479, 45.56140177590506, 48.33241285596575, 48.34760161808559, 47.72958714621407, 49.165592193603516, 49.9102132661002, 47.876604080200195, 49.646650723048616, 47.544633047921316, 46.53370489392962, 44.482019969395225, 44.016542775290354, 39.490465368543354, 40.61950247628348, 41.21334069115775, 44.49348102297102, 45.603570393153596, 50.25640031269619, 48.46876083101545, 51.432699067252024, 36.325380257197786, 40.66942180906023, 50.72232566561018, 45.64908456802368, 50.2826714515686, 49.099938665117534, 50.146729946136475, 48.63188716343471, 49.75869389942714, 42.072356905256, 36.558419363839285, 35.26883370535714, 42.828074250902446, 48.80478266307286, 50.43484047480992, 49.34775659016201, 46.88628428322928, 43.96452856063843, 41.21517848968506, 45.963007654462544, 49.47371700831822, 49.478056158338276, 48.698072229112896, 46.04092822756086, 47.66706725529262, 49.51722315379551, 49.17592069080898, 48.4501222882952, 48.23542642593384, 47.94276482718331, 48.62950740541731, 43.1812025478908, 35.11484425408499, 25.16167484010969, 15.520436116627284, 8.221872006143842, 2.8468293888228278, 5.7576964156968256, 5.069697516305106, 5.7983594451631815, 7.267847427300044, 4.726224175521305, 4.480406028883798, 1.6444451425756728, 0.6671566920621055, 0.16517202050558158, 0.8011211635810989, 4.955152988433838, 13.42993073804038, 24.242805106299265, 29.51846981048584, 29.5113513810294, 40.35834053584507, 54.038297857557026, 39.106674671173096, 15.343835490090505, 5.777836203575134, 0.18970423697360925, 0.10702929792127439, 0.026584601694984094, 0.008877090444522244, 0.013193361111916602, 0.03616478334047964, 0.03451505097161446, 0.03317825895334993, 0.020900371351412365, 0.01241717642239694, 0.03005650932235377, 0.04198488014351044, 0.04139324849737542, 0.023404655811776007, 0.02885855913960508, 0.024986571998202374, 0.03242737853101321, 0.02809125816981707, 0.057328623054283004, 0.018513622726978998, 0.08802343026867934, 0.055672220686184506, 0.06149260925927332, 0.01937386263827128, 0.07283409139407532, 0.03590532512004886, 0.08489948218422276, 0.05553367740607687, 0.0462706396356225, 0.04521643031122429, 0.11564250609704427, 0.1248138432524034, 0.11742630680756909, 0.16762887367180415, 0.16113644705287047, 0.11626447843653814, 0.17518790305725165, 0.15453939033406122, 0.1402610865022455, 0.15788341446646623, 0.15047797826783998, 0.1416670653436865, 0.08872610756329127, 0.21028001074280056, 0.10868188352989298, 0.09994676975267273, 0.08635191353304045, 0.11741167759256703, 0.1383961872862918, 0.05855590969856296, 0.24543784133025578, 0.1751615758985281, 0.19067162434969628, 0.21066537792129175, 0.11022023098277194, 0.11991723600242819, 0.1359978374093771, 0.1843646549220596, 0.14343357698193618, 0.15674055793455668, 0.10817972011864185, 0.08194282012326376, 0.22110993175634316, 0.564721842961652, 10.022839869771685, 33.60396889277867, 56.46626247678484, 61.85829734802246, 64.5552475793021, 49.94370010920933, 37.06442887442452, 31.816923482077463, 28.08834293910435, 21.904340233121598, 9.422575439725604, 1.67659250327519, 0.8684136526925224, 0.3909048656267779, 2.4989893223558153, 5.128758941377912, 17.824516092027935, 19.232629333223613, 3.201707111937659, 3.1716023044926778, 3.6566619106701443, 11.526365774018423, 14.202651194163732, 23.552815982273646, 34.01020574569702, 45.50142839976719, 47.436387062072754, 54.68878126144409, 51.00534316471645, 52.92262213570731, 55.332250458853586, 54.29808752877371, 53.04438236781529, 49.58638899666922, 46.504901136670796, 49.44716099330357, 51.235762800489155, 50.5409186226981, 49.43987233298165, 50.28950153078352, 51.39650590079171, 48.94484097617013, 51.793654509953086, 50.48044497626168, 46.975763184683665, 47.624999386923655, 45.92166934694563, 42.07760279519217, 42.221628529684885, 42.94927167892456, 45.959561347961426, 48.58589703696114, 52.36897924968174, 50.74714115687779, 50.26160798754011, 38.342779295785085, 41.35600457872663, 50.251800605228965, 46.482972621917725, 51.89031784875052, 50.738177980695454, 51.632209641592844, 50.9829352242606, 51.6421594619751, 43.8863821710859, 38.16358872822353, 38.16904306411743, 44.719099453517366, 51.18758051736014, 51.796722139631, 51.47995376586914, 48.77252565111433, 45.14948129653931, 43.11814069747925, 48.46605798176357, 52.79443481990269, 51.15611907414028, 48.6757789339338, 46.20465905325753, 47.39862012863159, 50.046064444950645, 50.832624844142366, 50.03325891494751, 50.75331810542515, 49.975519384656636, 49.61373015812465, 45.244866166796, 35.24773550033569, 28.353152683803014, 16.509145668574742, 10.351875288145882, 2.4687676983220235, 11.230637414114815, 7.143506373677935, 9.11358904838562, 11.085195984159197, 10.779817444937569, 8.23233425617218, 3.9814445972442627, 1.6192350153412138, 0.7585814148187637, 1.4442497364112308, 5.632063865661621, 16.07129798616682, 27.47374871798924, 37.57767840794155, 38.31598009381975, 48.70753220149449, 59.913593837193076, 45.23535408292498, 17.35488908631461, 7.54451470715659, 0.3938851271356855, 0.25486068427562714, 0.11102648664798055, 0.11794307907777173, 0.07513927162757941, 0.17831498597349438, 0.1484725951616253, 0.14660039490887097, 0.10165511058377368, 0.07487595254289252, 0.13822659424373082, 0.12124735462878432, 0.21775501035153866, 0.11446154303848743, 0.13085038933370793, 0.13225377617137773, 0.0895938045744385, 0.15099226709987434, 0.16444909572601318, 0.1254193407616445, 0.16935008631220885, 0.15558304504624434, 0.30048421184931484, 0.11573501756148678, 0.12898302025028638, 0.09607515750186783, 0.15989535222096102, 0.1593257627849068, 0.14561105013958045, 0.09917921772492783], [0.01935490606618779, 0.016734269813501408, 0.06263395265809127, 0.031110878102481365, 0.026348108492259468, 0.08341516647487879, 0.0297594432985144, 0.02603217919490167, 0.017660403956792185, 0.017527134590116993, 0.01579036144539714, 0.03569403949326702, 0.03620086783277137, 0.027722399748329605, 0.01094335425711636, 0.005326457912035818, 0.0243343454785645, 0.05287444777786732, 0.08295953699520656, 0.04813970844926579, 0.10528800742966787, 0.03881848630096231, 0.07317271429513182, 0.04769812464447958, 0.0444115181453526, 0.028790607250162532, 0.01951882994866797, 0.01959523808078042, 0.024614088503377776, 0.03983019558446748, 0.029008223608668362, 0.05661067872175148, 0.06233987558100905, 0.06647946166672877, 3.91184709753309, 18.69868459020342, 31.361392634255544, 40.357364313943044, 48.156453200748985, 45.113927364349365, 32.99961110523769, 26.44090247154236, 32.28191082818167, 23.739323002951487, 7.086861184665135, 2.16976261138916, 0.3721047230064869, 1.067053096635001, 1.1000192591122218, 4.285061768123081, 0.9744304610150201, 0.9059693717530796, 1.3639996711696898, 0.6410094808254923, 3.7563559668404713, 3.560796311923436, 9.322358965873718, 17.24591875076294, 27.456673519951956, 34.29931681496756, 39.56455748421805, 46.604593890053884, 48.81441286631993, 49.3538362639291, 53.512961932591026, 48.21412672315325, 48.043058599744526, 45.17343521118164, 45.7589043208531, 46.19828060695103, 49.81310871669224, 47.83648518153599, 47.4393504687718, 46.50476912089756, 46.506606919424875, 48.18494428907122, 47.57496540887015, 44.746840136391775, 44.95493868419102, 43.06686299187796, 41.53321490968977, 38.28555393218994, 39.19372170312064, 37.95655672890799, 43.09218570164272, 44.46601479394095, 47.90512296131679, 45.37627049854824, 53.70487117767334, 33.55380637305123, 36.818855217524934, 50.321334702628, 44.899822098868235, 47.22158350263323, 43.20313801084246, 45.043232917785645, 43.40584475653512, 43.98865270614624, 35.84294598443167, 32.53592307226998, 35.6350211415972, 45.1334240095956, 45.96677010399954, 48.48183386666434, 49.52277476446969, 48.60286453792027, 42.991610527038574, 40.61878333772932, 44.43475137438093, 45.33913932527815, 48.6099899155753, 48.714331013815745, 46.37610585348946, 44.77591487339565, 47.80445051193237, 49.3827338218689, 47.71731662750244, 48.85307959147862, 47.70442771911621, 43.99118185043335, 37.53899431228638, 27.165510995047434, 18.757160629544938, 10.231766121728079, 4.629460087844303, 2.4353692276137213, 2.4424650754247392, 2.7722413454736983, 4.133482907499586, 4.762467282158988, 3.509081086942128, 5.877107288156237, 0.8954907826014927, 0.463261858693191, 0.11229610709207398, 1.0322395818574088, 6.621210285595485, 15.062198945454188, 18.86412467275347, 26.84567846570696, 29.748958928244456, 37.63422632217407, 40.03168140138899, 26.926378318241664, 8.041091169629778, 2.0904712889875685, 0.03342322027310729, 0.012022769461119813, 0.016549148497038653, 0.03446100905005421, 0.02458862817314054, 0.022293159472090856, 0.014608977695128747, 0.0507497612519988, 0.047277375257440975, 0.02293324700024511, 0.06368360561983925, 0.03236139439312475, 0.024519638125119463, 0.055802594404667616, 0.012652809581985431, 0.03612861742398568, 0.042979944963008165, 0.07584869356027671, 0.020909129542165568, 0.022333757918594137, 0.01378186555978443, 0.03141755557485989, 0.012426519001434957, 0.03960501356050372, 0.019550500570663383, 0.014322530744331223, 0.007902651393253888, 0.04619012467030968, 0.051968752805675776, 0.040383537499500174, 0.09156633301505021, 0.04172274849510618, 0.041531523756150684, 0.06696064477520329, 0.02247746824286878, 0.06941189324217183, 0.04138174054345914, 0.037548044829496315, 0.015796773601323366, 0.09458563742893082, 0.021266717496993284, 0.030269484501332045, 0.05921297586922135, 0.0423628818243742, 0.04981771197968295, 0.008031817319403802, 0.041425360167132955, 0.013291868281417658, 0.011828180036640592, 0.01248174496660275, 0.021495036049080745, 0.003404695341097457, 0.12049743772617408, 0.0062348500609264845, 0.008495383114287896, 0.012876281697702194, 0.046172560791351965, 0.019864857363115464, 0.05649287486448884, 0.04242818742724402, 0.04180248314514756, 0.04572509748062917, 0.013881496552910124, 0.1713107946727957, 4.897430828639439, 21.707874706813268, 39.41457714353289, 50.5970253263201, 57.148335865565706, 50.102112088884624, 35.76938888004848, 28.857699598584855, 34.92974771772112, 29.0560394014631, 9.104981098856245, 2.376255039657865, 0.08864203028913055, 0.2115069106221199, 0.23277119387473377, 3.825575658253261, 4.768767126968928, 1.9402835880007063, 6.284570932388306, 3.2277220359870364, 2.1497272636209215, 4.754018706934793, 10.192995173590523, 19.485597610473633, 29.766767161233084, 37.73765025820051, 42.98195947919573, 47.46813685553414, 50.32206078938076, 49.73757484980992, 55.5728109904698, 50.60721833365304, 49.578391620091026, 47.57488203048706, 46.532117230551584, 47.88965974535261, 50.42790617261614, 48.56051526750837, 48.69580364227295, 46.48911830357143, 46.72927236557007, 49.32355601446969, 49.81839976991926, 47.12560108729771, 47.43190547398159, 44.744832106998985, 43.39049618584769, 39.668016161237446, 40.874226910727366, 39.535503591809956, 45.333177770887104, 46.38281781332833, 49.49359927858625, 46.76205049242292, 54.03499051502773, 34.24859496525356, 37.28417260306222, 52.284850461142405, 45.73297364371163, 49.9056830406189, 46.342434883117676, 47.21089717320034, 47.28252962657383, 46.144039494650706, 37.91061871392386, 34.92098603929792, 38.148577145167756, 48.46353578567505, 48.37091629845755, 50.157982553754536, 50.45373957497733, 51.12452561514718, 43.37012754167829, 42.11070053918021, 46.465918268476216, 46.97067710331508, 48.75430400030953, 50.32173769814627, 46.48065192358834, 46.530873503003804, 50.052352564675466, 50.93761212485177, 49.94151142665318, 49.53192554201399, 48.737277439662385, 45.56948947906494, 40.817241259983604, 31.335684299468994, 20.21978075163705, 12.563553776059832, 5.046444501195635, 2.485030174255371, 5.1246212891169955, 5.605151321206774, 7.773748806544712, 5.904143163136073, 5.056601030485971, 3.768704652786255, 1.1362749593598502, 0.45782060495444704, 0.190383002694164, 1.3490446507930756, 7.107450434139796, 17.314427988869802, 21.511106933866227, 28.224454675401958, 33.85667140143258, 42.887818336486816, 47.31996304648263, 33.999043464660645, 9.184826322964259, 2.6842710716383795, 0.08687716070562601, 0.06248460031513657, 0.033523036167025566, 0.10846208568130221, 0.07361399954450981, 0.02395228615828923, 0.030914900225720236, 0.038643115532717535, 0.014293121340285455, 0.03483012192217367, 0.06817318006817784, 0.005814941633226616, 0.03585769874708993, 0.062422405795327256, 0.024643502996436188, 0.008414450849938606, 0.04005843101601515, 0.019987989416612045, 0.06509374388094459, 0.0450463385454246, 0.031658462647880824, 0.018335760038878237, 0.008495718989122127, 0.029015439828591685, 0.012596209583404874, 0.07188959778951746, 0.035281524128679714, 0.039749836682208946, 0.027099187386089137, 0.061975868684904914, 0.19400848315230437, 0.11177272589078971, 0.14023360583399022, 0.13207422223474297, 0.08785501109170062, 0.1689379577125822, 0.2122342458793095, 0.13082783482968807, 0.14390008337795734, 0.18481791631451674, 0.10958365656967674, 0.06827696199928011, 0.15288523052419933, 0.09631936225507941, 0.13921561331621238, 0.04436498421377369, 0.08791694098285266, 0.11492059912000384, 0.15595879059817108, 0.18052717298269272, 0.1917408462613821, 0.14482922852039337, 0.2454677511538778, 0.1936841027012893, 0.11597775667905807, 0.07906224897929601, 0.1489944700151682, 0.10973581126225845, 0.08191829108233963, 0.12100148067942687, 0.11559547004955155, 0.1874996902687209, 0.1694848569376128, 0.2516335445855345, 5.752559091363635, 25.31247854232788, 48.00879355839321, 60.02236788613455, 63.65724154881069, 58.17895521436419, 44.64830425807408, 39.863434246608186, 40.97194637571062, 30.805279663630895, 9.884234598704747, 3.2555361092090607, 0.5756048932671547, 1.5908494527850832, 2.0268242699759345, 8.046737449509756, 4.474518733365195, 3.188188523054123, 7.676401938710894, 2.3091614970139096, 5.623576206820352, 4.719971665314265, 11.245657682418823, 20.940244674682617, 31.676545551845006, 37.85390056882586, 45.68729271207537, 53.601603576115195, 53.23019804273333, 49.27787855693272, 57.29580790655953, 52.24154928752354, 51.47385324750628, 49.14118317195347, 49.140637738364084, 49.54568992342268, 53.69369500023978, 49.657430853162495, 48.58346516745431, 47.23497615541731, 46.200566564287456, 50.267364570072715, 50.64039945602417, 48.31186008453369, 49.161218302590505, 46.60508721215384, 45.567356382097515, 43.07004874093192, 42.478798730032786, 40.687810216631206, 46.87598010471889, 48.222113677433555, 50.137134483882356, 47.95802654538836, 53.03554425920759, 37.58500528335571, 39.72090932301113, 51.19223233631679, 48.33955907821655, 51.02285609926496, 48.37431744166783, 48.102055753980366, 49.244819028036936, 46.79647534234183, 39.13984884534563, 36.13794912610735, 40.82096896852766, 49.569970403398784, 49.686971119471956, 50.963403838021414, 50.70718901497977, 51.89142608642578, 45.462636607033865, 45.149137360709055, 48.22647019795009, 49.629704066685264, 50.76561641693115, 50.480656896318706, 46.78470161982945, 48.350592817579, 51.09497145244053, 51.70676033837454, 51.528285435267854, 52.26297058377947, 51.590475286756245, 47.623078210013254, 42.38814558301653, 31.269440174102783, 21.409230709075928, 14.665013858250209, 7.163453783307757, 6.246385369982038, 6.405168209757123, 9.099714364324297, 13.192494290215627, 13.752969861030579, 10.829638634409223, 13.734952313559395, 3.462408734219415, 1.3093058403049196, 0.511309411908899, 1.7062869327408927, 8.758601239749364, 20.57680525098528, 27.107974699565343, 36.580921104976106, 40.43589285441807, 48.33378512518746, 54.05160365785871, 39.29114586966378, 12.623229248183113, 3.003390976360866, 0.1900251568960292, 0.1375643169241292, 0.1503262985497713, 0.2662035641925675, 0.14551392463701113, 0.09755272857312645, 0.07345214180116143, 0.10392857609050614, 0.12412689439952374, 0.1807758289256266, 0.13357514169599327, 0.11416481967483248, 0.18836905647601399, 0.15641971943633898, 0.2760932935135705, 0.07663037268710987, 0.1203974216644253, 0.08046361378261022, 0.09466763838593449, 0.09822652741734471, 0.1542110608092376, 0.13183602930179664, 0.07948338852397033, 0.09260291060698883, 0.10362562377538, 0.13168737584991114, 0.153270869116698, 0.14282187766262464, 0.0987502478861383, 0.12065468143139567], [0.024839331595493213, 0.051082630176097155, 0.02286113060212561, 0.047933114892137904, 0.03120928942891104, 0.015972699071945887, 0.08101991071764912, 0.02614649198949337, 0.053512745669909885, 0.03689056135980146, 0.029919638631067107, 0.06951609586498567, 0.007877694027099227, 0.01496243167535535, 0.05158133305875318, 0.06061271897384098, 0.03609711643574493, 0.07854630452181612, 0.011725620316740657, 0.005195751711393574, 0.020577583761353577, 0.024989874767405645, 0.023954857806009904, 0.022188507319827164, 0.06233067464615617, 0.05727075080254248, 0.03144021864448275, 0.049973493441939354, 0.04272512113675475, 0.04349249674539481, 0.00749850066910897, 0.03077835523124252, 0.06573129538446665, 0.07642213028988668, 1.7164554042475564, 6.060528440134866, 20.95628980227879, 36.92984226771763, 40.18474326814924, 46.790760449000764, 31.150566918509348, 26.46960026877267, 17.677763189588273, 17.23770945412772, 10.469223414148603, 3.470040896109172, 0.46487655490636826, 0.20163187836962088, 0.2791909415807043, 0.7981464117765427, 1.9314793518611362, 1.5838467542614256, 5.123263350554875, 3.157845739807401, 1.504153521997588, 2.259425857237407, 4.355682390076773, 10.66730179105486, 21.09136278288705, 31.226323127746582, 35.25183146340506, 40.473635469164165, 45.65008858272007, 47.705938952309744, 52.48179367610386, 49.32082537242344, 49.585183484213694, 47.22011048453194, 47.2375921521868, 46.246101583753315, 50.81163433619908, 49.65827505929129, 46.91953488758632, 46.36560365131923, 48.321347849709646, 46.89907244273594, 47.400190421513145, 47.17801134926932, 45.232564381190706, 43.37683950151716, 40.035916328430176, 39.13307087762015, 39.50098841530936, 39.13882746015276, 42.759624072483604, 43.55288600921631, 48.82559946605137, 47.95062323978969, 50.59196008954729, 36.836736406598774, 39.20181635447911, 51.26075199672154, 43.73544297899519, 44.66970818383353, 42.06700331824166, 43.14160476412092, 40.5580769266401, 34.99810756955828, 33.47147716794695, 34.681252343314036, 38.1187242099217, 46.194236755371094, 46.04236650466919, 49.71964502334595, 48.760414940970286, 48.25806713104248, 45.39219576971871, 41.65630572182791, 41.267637389046804, 45.41375950404576, 47.87523528507778, 49.033472197396414, 45.72055721282959, 46.33140809195382, 48.17700597218105, 47.752467564174104, 48.06224605015346, 46.90550300053188, 45.66239036832537, 39.906679834638325, 32.72359391621181, 22.719087736947195, 13.224812967436653, 6.1329134702682495, 2.7380787900515964, 1.765153591121946, 4.414137150560107, 4.973500575338091, 4.928696853773935, 5.068792513438633, 1.4390420615673065, 2.2031997314521243, 1.2760795546429498, 0.608203506895474, 0.3308465911873749, 1.9568680695125034, 9.575990796089172, 21.18579227583749, 29.35364464351109, 27.681730883462087, 29.810193402426584, 33.81348834718977, 40.820638929094585, 19.127902609961374, 4.401194827897208, 0.49961179388420923, 0.0574730085209012, 0.018281105739463652, 0.018531573370897343, 0.03053676283785275, 0.010841054076861058, 0.02797357814519533, 0.043680915742048194, 0.03286752384155989, 0.046344409962849956, 0.003113706234476662, 0.01824795760746513, 0.016402031926970397, 0.037545368008847745, 0.03392928186804056, 0.04690751260412591, 0.08353266838405814, 0.08292174938001803, 0.07927931233176164, 0.025736426136323383, 0.05737172359866755, 0.02958231173189623, 0.035303661333663125, 0.010162737885756152, 0.06322655800197806, 0.07334166272942509, 0.05391295240925891, 0.03209473352347102, 0.024358275712334683, 0.03941071166523865, 0.032771290612540076, 0.013985936662980487, 0.023953989281186035, 0.02038056094066373, 0.019122036240462745, 0.01228457032370248, 0.03502502092825515, 0.06845872796007565, 0.017542932581688677, 0.04850406479090452, 0.006407584720623812, 0.024544441972726157, 0.030211771705320904, 0.010111191276726978, 0.03341486072167754, 0.02888251481843846, 0.01792241177255554, 0.03541351954585739, 0.049117511337889094, 0.03479025459715298, 0.05237741409135716, 0.003425137692829594, 0.07902120439601795, 0.009459550841711462, 0.04777139964114342, 0.03674232181427734, 0.050631329749843905, 0.012032041642149644, 0.051058084171797545, 0.03525013509871704, 0.025628423717405115, 0.06831244938075542, 0.04602389716144119, 0.08527653730873551, 0.024067713446649056, 2.1298478160585677, 9.727545772280012, 26.70939302444458, 46.594150747571675, 49.58276898520333, 52.408382483891074, 34.89512831824166, 30.85295820236206, 22.7423711504255, 21.39701403890337, 12.238284281321935, 3.4746753445693424, 0.8351972465004239, 0.3350379562803677, 0.46759677465472904, 1.8674026301928928, 2.402266489607947, 4.43427346433912, 5.76356851203101, 4.114296759877886, 3.2061797976493835, 2.8248259638037, 5.864584028720856, 13.113885845456805, 22.806492601122173, 33.523060594286235, 38.71672786985125, 44.12117917197091, 49.124139240809846, 49.050040176936555, 52.99567896979195, 50.3589175088065, 51.75914280755179, 49.33449942725045, 48.38073410306658, 47.70776285443987, 51.354107992989675, 49.410540512629915, 47.111464977264404, 48.32761859893799, 48.242131437574116, 46.64820425851004, 47.97129760469709, 49.021879128047395, 47.62429761886597, 45.479812553950715, 43.11101879392351, 41.09572158540998, 40.5127329826355, 41.064826420375276, 44.50705780301775, 46.18989413125174, 49.60276242664882, 49.711592061179026, 51.32241725921631, 38.511248792920796, 40.25990193230765, 52.5336446080889, 45.33910805838448, 46.64888170787266, 44.10462508882795, 44.76152515411377, 43.0603803225926, 37.98315095901489, 34.791006088256836, 37.00705412455967, 39.96006631851196, 47.40125696999686, 48.46797915867397, 49.941038949149, 49.531647614070344, 49.877237115587505, 47.24508578436715, 43.502685274396626, 43.89647442953927, 47.241823605128694, 49.28655685697283, 50.468685150146484, 47.85130221503121, 45.558695452553884, 49.04290785108294, 49.04696907315935, 49.617853913988384, 48.481816496167866, 48.32657289505005, 42.935795647757395, 34.674304144723074, 25.76037679399763, 15.646660566329956, 7.453178899628775, 5.642454028129578, 5.899322850363595, 7.575928381511143, 7.133962154388428, 7.108401468821934, 6.634764918259211, 3.3805448412895203, 3.2866429771695818, 1.0407395086118152, 0.4154923962695258, 0.1968577466905117, 2.246257935251508, 8.404915349824087, 23.075907264436992, 29.64880759375436, 32.199470451899934, 33.873333181653706, 39.1447160584586, 46.17000143868582, 24.693680661065237, 6.482488632202148, 0.6022131283368383, 0.08079404676599161, 0.009067006459060525, 0.03450568379568202, 0.03865993980850492, 0.02656925662553736, 0.018111429576362883, 0.008671896365870322, 0.05170876872060554, 0.005076634464785457, 0.02060937143063971, 0.026823047382224883, 0.02338734807978783, 0.09275126550346613, 0.05535440845414996, 0.02628164429084531, 0.0032248110427255078, 0.013793968080010797, 0.04254442047593849, 0.021129548250298415, 0.03715183126873203, 0.036878815918628655, 0.0568713243784649, 0.017658575304916928, 0.029822882930082933, 0.06057108406509672, 0.06173106682087694, 0.014620545020859157, 0.021999738877639174, 0.05306220520287752, 0.02526910210560475, 0.12252095128808703, 0.14668317618114607, 0.1468218687389578, 0.17017314928982938, 0.19368695254836762, 0.1494643555155822, 0.11653370756123747, 0.11422723132584776, 0.17312766718012945, 0.11971644391970974, 0.063254099738385, 0.11600907785551888, 0.12064777394490582, 0.16820515346314224, 0.09019409772008657, 0.10808920354715415, 0.1004461579556976, 0.14836740866303444, 0.10397244337946177, 0.1476031339594296, 0.07568190965269293, 0.14720081697617257, 0.06993092503398657, 0.131893677636981, 0.1377398403627532, 0.12081648489194256, 0.10082491620310716, 0.2352368544254984, 0.14037631531911238, 0.09650775750300714, 0.11509625826563154, 0.1929502942200218, 0.1537366969777005, 0.11780817274536405, 2.4131797211510793, 10.171904785292488, 31.985872404915945, 56.639408111572266, 56.98957647596087, 61.74854360307966, 42.956539494650706, 38.88364791870117, 26.34397336414882, 24.6807187965938, 14.56812470299857, 4.565689521176474, 1.042598803128515, 0.5536634049245289, 0.8596691819173949, 2.9193281957081387, 5.329232275485992, 7.440288254192897, 8.755301713943481, 7.873002086366926, 4.6250723004341125, 4.1514201164245605, 6.630386250359671, 12.22815728187561, 23.842066015516007, 35.54928037098476, 41.425351074763704, 49.95831911904471, 50.35588114602225, 49.06910603387015, 55.47884702682495, 53.329623290470664, 54.01009511947632, 52.26029552732195, 51.80593545096261, 49.8062994820731, 52.85488414764404, 50.11049509048462, 48.0273973601205, 48.00166123253958, 47.67471374784197, 46.80615765707833, 49.097854205540244, 50.33213220323835, 48.7152099609375, 47.184389795575825, 43.57113197871617, 43.4975575038365, 41.60939148494175, 44.19895035879952, 46.05367469787598, 47.239680085863384, 50.97111981255667, 51.56029231207711, 49.93213483265468, 41.01278788702828, 43.30188233511788, 53.14536401203701, 47.22411959511893, 48.51505320412772, 46.23729474203927, 47.65235791887556, 44.767986978803364, 38.9321984563555, 36.75463996614729, 38.03255612509591, 41.76282160622733, 48.74634483882359, 49.788779599326, 51.03311858858381, 49.35789053780692, 51.8142454964774, 49.50199270248413, 43.091487407684326, 45.63344069889614, 48.55983086994716, 52.30354458945138, 50.212741306849885, 47.17210190636771, 45.465801511492046, 48.64418894904, 49.46991286958967, 50.88937773023333, 50.309085028512136, 49.98627519607544, 44.63127074922834, 35.402527468545095, 26.41633711542402, 16.37908755029951, 7.2350914478302, 4.717301385743277, 4.8485541599137445, 8.8770124401365, 12.404995015689305, 11.790955781936646, 13.68503211225782, 7.54105624130794, 4.533720859459468, 3.4842794920716966, 1.3370200331721986, 0.6477490706103188, 3.1385201939514706, 11.667204890932355, 28.13148604120527, 38.34363045011248, 38.970312799726216, 40.5876658303397, 46.72190727506365, 53.7798387663705, 29.023184844425746, 6.901589206286839, 1.0136375171797616, 0.1800478829869202, 0.1105973268193858, 0.0794809932953545, 0.1534348303186042, 0.16235920786857605, 0.13958081443394932, 0.2510364609105246, 0.18684907018073968, 0.12088851816952229, 0.1448584869503975, 0.11342263807143484, 0.10064165746527058, 0.1632832232862711, 0.15125126391649246, 0.17699731167938026, 0.27218523036156383, 0.11142019980720111, 0.12913934114788259, 0.12815437971481256, 0.18410685232707433, 0.15328955597111157, 0.10296134477747337, 0.08635007470313992, 0.20073566931699002, 0.11656759360006877, 0.09598316850938968, 0.09252497407474689, 0.08884230668523482, 0.13556554274899618, 0.1254354491829872], [0.011018191580660641, 0.060734041035175323, 0.009855560841970146, 0.06821429250495774, 0.04927139968744346, 0.06328755830015455, 0.05767665045069797, 0.015262184697868568, 0.01191403846522527, 0.01984948175959289, 0.007724970213270613, 0.06927569090787854, 0.06547250891370432, 0.03952556728784527, 0.01779945444182626, 0.018212415943188325, 0.07814457107867513, 0.03998276757608567, 0.03275602018194539, 0.033997328752385716, 0.03902331227436662, 0.07917981874197721, 0.017089337010734847, 0.03651339427701064, 0.011193603061006537, 0.06830470051084246, 0.010901606541925242, 0.0072637843799644285, 0.02490701885627849, 0.03348091271306787, 0.07222934705870492, 0.07681343464979104, 0.03024836509887661, 0.09822975045868329, 0.28526486137083595, 2.536979683807918, 15.016419001988002, 30.486520630972727, 44.55619198935372, 46.77711418696812, 42.123054436274934, 25.93224743434361, 40.48069483893258, 28.966543129512242, 11.92361513205937, 5.15614526612418, 0.7357735186815262, 0.587626145354339, 0.10900254560900585, 1.2512381161962236, 1.6987798384257724, 2.662912526300975, 7.142329088279179, 4.208091361182077, 0.6902545126421111, 1.930319219827652, 3.0093273435320174, 9.254179767199926, 17.71451394898551, 22.875357934406825, 27.839618274143763, 36.262620653424946, 45.50013256072998, 47.023250647953574, 50.8810989516122, 52.31442199434553, 48.21502998897007, 47.5314245223999, 47.98237998144967, 46.1242927142552, 48.07153926576887, 49.42759139197213, 48.75066314424787, 48.46983085359846, 48.54441629137312, 47.86528893879482, 49.97391087668282, 47.83829518726894, 45.36088718686785, 43.49465315682547, 40.40141936710903, 37.40898656845093, 35.74629306793213, 39.41869395119803, 42.613444396427695, 43.577819619859966, 48.63715737206595, 45.183298179081504, 52.91382919039045, 36.27946308680943, 36.75767980303083, 51.268672943115234, 42.77660199574062, 45.82980373927525, 39.940138884953086, 36.48672785077776, 33.55230556215559, 35.50549629756382, 33.79903956821987, 37.93231793812343, 42.73268590654646, 45.623223372868125, 47.33861548560006, 49.06516987936837, 47.718744482312886, 49.367777824401855, 46.29749046053205, 44.45035702841622, 43.310675280434744, 47.03245006288801, 46.68502623694283, 48.55560636520386, 49.671827520642964, 46.90044123785836, 48.58440317426409, 48.95333514894758, 48.16922746385847, 48.8071346282959, 43.95902211325509, 36.17144291741507, 27.406575271061488, 20.480070693152292, 11.279371210506984, 5.224860344614301, 3.448825005974088, 4.2490449122020175, 6.270373157092503, 4.672280532973153, 4.491021573543549, 2.1421587211745123, 4.084370868546622, 3.4289106002875736, 0.4829497422490801, 0.17223552933761052, 0.34183804424745695, 3.0629320442676544, 12.162021722112383, 17.227512972695486, 19.874217305864605, 15.406320640019008, 33.44091204234532, 41.76270348685128, 34.06264380046299, 13.47130378655025, 2.055263463939939, 0.10958526469767094, 0.06364229640790395, 0.12006272748112679, 0.07677929076765265, 0.04104051885328122, 0.004160278011113405, 0.009114765994516867, 0.03080613784758108, 0.037601381074637175, 0.018978341183226024, 0.033686688635498285, 0.027429750987461636, 0.12173051227416311, 0.010886821263868893, 0.042807590282921276, 0.1140061646167721, 0.011903776471236987, 0.05246084336457508, 0.08651323523372412, 0.06760454058114972, 0.003995193409666951, 0.06362843393747296, 0.040154833878789625, 0.02183333325332829, 0.05779950600117445, 0.031478705150740485, 0.03835282807371446, 0.0522078074780958, 0.04791445857180016, 0.04659908451139927, 0.06857614844505276, 0.06649002645696912, 0.05606383377952235, 0.016015504453597323, 0.04799227296773877, 0.027539493848702738, 0.03852760851649301, 0.03309716384059616, 0.02771036932244897, 0.03141999490825193, 0.01915694177815957, 0.04683601197653583, 0.027021934477878467, 0.015110199639041508, 0.023482797600861107, 0.03456752547728164, 0.056431766000709364, 0.04669261717104486, 0.04109568035762225, 0.05138788611761161, 0.016534398842070783, 0.059049822123987336, 0.03534050239250064, 0.0640296788354005, 0.02998672878103597, 0.030110215369079794, 0.07060575525143317, 0.018577311720166887, 0.013765954761765897, 0.05348923782418881, 0.05978954064526728, 0.13861392917377607, 0.049695779236831834, 0.029079008381813765, 0.014882264459239585, 0.40038275133286205, 3.4995724771703993, 18.632292815617152, 36.973845209394185, 50.89598199299404, 54.57792622702462, 44.80285651343209, 30.748471191951207, 29.78964410509382, 26.89180060795375, 14.069785135132925, 6.552178195544651, 0.9583803394011089, 0.43991341441869736, 0.1526041677487748, 0.5175601850662912, 2.1996337856565202, 2.837389826774597, 6.70674695287432, 4.764071881771088, 2.3796607426234653, 1.9315831405775887, 4.343531293528421, 9.511264852115087, 18.58253502845764, 25.324580567223684, 31.7703948702131, 39.48826626368931, 49.1416973386492, 48.77742413112095, 52.51569046292986, 52.95564692361014, 51.44435467038836, 48.26536273956299, 49.45238603864397, 47.68781457628523, 50.86397164208548, 51.37043973377773, 49.657059124537874, 47.62707689830235, 48.86242839268276, 48.83379486628941, 51.220059871673584, 49.465174198150635, 48.299850123269216, 45.383239541734966, 42.136929988861084, 39.42644466672625, 37.742507049015586, 40.970087732587544, 44.92270599092756, 45.98059007099697, 50.558518409729004, 48.290039266858784, 53.83096708570208, 38.541344915117534, 39.12881858008248, 53.30172279902867, 44.85398135866438, 48.11138718468802, 40.996654169900076, 38.63714667728969, 36.28567130225045, 36.077346937997, 34.860807691301616, 38.3340801511492, 44.8206056867327, 49.38562774658203, 48.339896065848215, 52.00575522014073, 47.89892864227295, 50.84607308251517, 47.40306002753121, 45.22846146992275, 44.92976883479527, 48.564374991825645, 48.26116950171334, 51.347357818058555, 47.91131033216204, 47.87134081976754, 48.62221874509539, 49.84443467003958, 49.82304116657802, 49.60068838936942, 45.81846080507551, 39.43874992643084, 30.228659084865026, 21.756058726991924, 11.645807913371495, 6.394611290522984, 4.274222578321185, 4.16161355801991, 9.481810569763184, 9.185040848595754, 8.655014021056038, 6.555440809045519, 4.524871460029057, 2.4257576976503645, 0.3266007261616843, 0.2381446755358151, 0.4566445680601256, 3.252674754176821, 12.161508423941475, 22.05565115383693, 24.770473888942174, 19.200141293661936, 38.75976848602295, 45.73442929131644, 40.86141095842634, 15.851368393216815, 2.3922775856086185, 0.2326576885368143, 0.010542919360367315, 0.030118388323379413, 0.03390355182013341, 0.03419034482379045, 0.03541747879769121, 0.016052267480907694, 0.03265617714662637, 0.01717275780226503, 0.06339224268283163, 0.0682672318071127, 0.09080645521836621, 0.021819891474608864, 0.01403088282261576, 0.036776509801191945, 0.0959361121058464, 0.009678072196298411, 0.04514912981539965, 0.033006311394274235, 0.009643662837333977, 0.04739292637844171, 0.012671975651755929, 0.035193847226245065, 0.016471181430720856, 0.014441354100459387, 0.027587339049205184, 0.0399382726422378, 0.04334440647757479, 0.05697562199618135, 0.026970722047345977, 0.062211157487971444, 0.1861528389688049, 0.1905422955751419, 0.06502986659428903, 0.10786500879164253, 0.11661864657487188, 0.13380017104957784, 0.20130510947534017, 0.10239263065159321, 0.06691277412963764, 0.08722953072616033, 0.08094153313764504, 0.15045275033584662, 0.1311282901359456, 0.09567306443516697, 0.19399436962391647, 0.08257745392620564, 0.12736022232898644, 0.19914867090327398, 0.11482531923268523, 0.16817438868539675, 0.16009353872920784, 0.16094895425651753, 0.10354008765092917, 0.08824128072176661, 0.12515552634639399, 0.09794351724641663, 0.041875164423670085, 0.09910889435559511, 0.18675886573536055, 0.10987376421689987, 0.3252265570419175, 0.14179391068007263, 0.10750531059290681, 0.2724035286477634, 0.4955763561385018, 4.504897126129695, 21.08711048534938, 43.858759607587544, 61.245285579136436, 60.42734364100865, 53.56399645124163, 37.229000432150706, 51.1346560886928, 36.54720844541277, 17.43920373916626, 7.842374426977975, 1.2556254693440028, 0.8861309619886535, 0.6160025341170174, 2.8386431080954413, 7.171322618212018, 5.582258743899209, 17.306335074560984, 13.082193374633789, 3.7187887941087996, 3.9636711052485873, 4.449028398309435, 10.989996978214808, 20.432015214647564, 26.8833099092756, 34.83447401864188, 47.12538569314139, 52.23439611707415, 49.5311473437718, 53.314660344805034, 54.43962580817086, 51.88292843954903, 50.377736704690115, 51.72339085170201, 49.13027450016567, 52.83337252480643, 53.21035746165684, 49.740413188934326, 50.346754687173025, 50.348908628736226, 49.451694692884175, 53.10590866633824, 50.86307185036795, 48.99074077606201, 46.49484361921038, 43.473391669137136, 40.51177760532924, 38.43324136734009, 42.98087208611624, 47.36153759275164, 49.16582495825631, 52.314734663282124, 50.49322271347046, 54.144594873700825, 40.58807577405657, 40.62753806795393, 54.05782229559762, 46.628311565944124, 48.52055617741176, 43.189602919987266, 39.57188088553292, 38.9346581186567, 38.8970753124782, 38.110879693712505, 41.02898413794381, 46.75026634761265, 51.09275497709002, 50.15386574608939, 51.17726591655186, 47.72536611557007, 51.20591333934239, 50.8454373223441, 47.759047508239746, 47.966864653996055, 50.04624162401472, 50.773436614445274, 52.11448410579136, 49.288457189287456, 48.366709164210725, 49.41622413907732, 50.32884917940412, 51.550728116716655, 51.21937200001308, 47.387826102120535, 40.36561182567051, 32.428969451359336, 23.63690655572074, 13.805965508733477, 7.254086954253061, 5.619899306978498, 8.011850544384547, 14.06628498009273, 10.001863258225576, 11.546167271477835, 13.570837599890572, 7.422790084566389, 7.714816791670663, 1.3745527906077248, 0.7311886304191181, 0.6878594468746866, 4.300721270697458, 14.270896400724139, 25.081619432994298, 28.987339087894984, 23.81529460634504, 45.630376543317524, 54.78249856403896, 46.117198603493826, 19.38685849734715, 3.3335511343819753, 0.31230296194553375, 0.08972422579037291, 0.29946567650352207, 0.19196065089532308, 0.13283061236143112, 0.17554345540702343, 0.07835520191916398, 0.22960509519491876, 0.06658318931502955, 0.1331725668694292, 0.13881858890610083, 0.16243345317031654, 0.2844027147761413, 0.08798988349735737, 0.09733270680797951, 0.1841025368443557, 0.05958427023142576, 0.21820234134793282, 0.16815579682588577, 0.14235246713672364, 0.10677949525415897, 0.19396154209971428, 0.1811176748680217, 0.14321584866515227, 0.07989425504846231, 0.06216074912143605, 0.10749278483646256, 0.16911855659314565, 0.19030626038355486, 0.14175345642226084, 0.2069539949297905], [0.03658530202561191, 0.013918361360473292, 0.021839701304478303, 0.02821021723294897, 0.06908994873187371, 0.11772374941834382, 0.04088598589545914, 0.030986170151403973, 0.019286362154941474, 0.04521986369841865, 0.07187390327453613, 0.027730252094832913, 0.05198698504162686, 0.04287715708570821, 0.05784995507981096, 0.009870095910238368, 0.03953472411792193, 0.012059430708177388, 0.012670916288958063, 0.08235086394207818, 0.039330261160752604, 0.02476615159373198, 0.03971671060259853, 0.060259745057140074, 0.02391221696910049, 0.01600773013862116, 0.02982613311282226, 0.03382743036906634, 0.051068469150257964, 0.04306163379390325, 0.033443304909659285, 0.014417318693761314, 0.03669668694159814, 0.05607664791334953, 0.0787753372320107, 0.6895744577050209, 5.9525304181235175, 16.06638387271336, 33.517880712236675, 47.44287320545742, 36.04834515707833, 25.845174346651348, 22.411352021353586, 18.82364967891148, 18.74622242791312, 9.749358773231506, 3.4612414368561337, 0.4993382085646902, 0.3008857960147517, 0.3615059788737978, 2.0227550140448978, 2.3867207637854984, 1.438042389495032, 2.3378701508045197, 3.129205048084259, 0.43046432573880467, 2.3145061816487993, 5.2954323291778564, 12.060328756059919, 19.357835871832712, 25.35879349708557, 26.47647030012948, 40.57992901120867, 44.7008569581168, 50.26342841557094, 52.13079152788435, 52.16594246455601, 47.21741458347866, 47.54144035066877, 46.85735198429653, 47.19519771848406, 43.725013732910156, 46.49949891226632, 46.77481780733381, 49.63297666822161, 47.886310713631765, 47.510913440159385, 44.926722049713135, 45.370899541037424, 41.67246723175049, 40.43417317526681, 36.66051271983555, 38.33227709361485, 39.329301902226035, 40.98086438860212, 40.38527522768293, 47.86125898361206, 45.87458487919399, 50.54994780676705, 38.06029333387102, 38.631014892033164, 51.54650708607265, 43.353569984436035, 44.43061024802071, 39.79649530138288, 41.136952195848735, 41.32993841171265, 42.77281870160784, 42.391776016780305, 46.21156556265694, 44.62493051801409, 47.42972373962402, 48.25985629217965, 49.31667382376534, 47.53807742255074, 46.49876240321568, 48.31649453299386, 45.209822927202495, 43.36776168005807, 44.155176707676475, 44.862819467272075, 46.73989268711635, 48.609962122780935, 48.44013772691999, 49.88044718333653, 50.3806688444955, 48.06311804907662, 46.64579323359898, 40.453072275434224, 33.62022420338222, 23.706888811928884, 16.088694538388932, 6.111671958650861, 2.781736275979451, 3.4386699966021945, 6.40449857711792, 10.643134219305855, 8.120364035878863, 7.089980925832476, 4.585248265947614, 2.480682338987078, 1.1695442370006015, 0.30633342798267094, 0.3079793910895075, 0.5940011175615447, 4.3360902070999146, 14.538037266050067, 20.734260116304668, 21.79359289578029, 29.151799474443706, 39.9010900088719, 40.37577356610979, 23.30327490397862, 9.631693635668073, 0.8218227241720472, 0.025543745939752886, 0.07838979363441467, 0.09024838730692863, 0.017103284298043166, 0.045300263312778304, 0.019788603597719754, 0.032002479902335575, 0.07673524027424199, 0.013946249149739742, 0.050548548477568796, 0.02633457680765007, 0.042343906592577696, 0.04873201523774436, 0.013683448296173342, 0.14294311829975673, 0.03416157493899975, 0.06293795670249633, 0.030860444397798607, 0.08634227833577565, 0.03537212212436965, 0.04838222025760582, 0.038396546084965975, 0.021471572308135883, 0.008336825595636452, 0.0972953127431018, 0.007070689428863781, 0.04263126278030021, 0.03158613760024309, 0.0044713214322525474, 0.01089069145798151, 0.012196730572863348, 0.02347897575236857, 0.0386289748629289, 0.01701416041968124, 0.03348828160337039, 0.061597788972514014, 0.06682527025363275, 0.03433645376935601, 0.03965763395119991, 0.034123790716486316, 0.03901574321623359, 0.048000941252602, 0.02615610004535743, 0.05366432021505066, 0.03943355793931654, 0.030569970341665403, 0.051486171915062835, 0.025700451905972192, 0.050043592894715924, 0.006568799552042037, 0.08582275799874749, 0.04078105724017535, 0.01823095521623535, 0.06258612272462674, 0.04391525798876371, 0.09790412150323391, 0.12109929828771523, 0.06611564476042986, 0.10194935729461056, 0.0596418846398592, 0.045977556612342596, 0.03360953920387796, 0.0673484071823103, 0.02907968352415732, 0.015385625484798635, 0.0445724191543247, 1.2640700276408876, 8.64255850655692, 22.563003403799875, 44.472271646772114, 52.16377115249634, 43.48486661911011, 28.94566031864711, 32.72534833635603, 24.74430697304862, 18.24216536113194, 9.1040152992521, 2.9096089686666216, 0.47860548964568544, 0.2651934155396053, 0.28340534972293036, 0.910368232854775, 2.0399991401604245, 5.159575939178467, 4.827498512608664, 4.278976883207049, 2.2434664964675903, 3.6881624375070845, 7.526049869401114, 14.653962748391287, 21.210119656154088, 29.650238922664098, 33.72435685566494, 43.102847712380544, 47.024212973458425, 50.989251136779785, 52.440087114061626, 52.49402597972325, 49.65524217060634, 49.556174755096436, 48.23104558672224, 48.62511614390782, 47.337799072265625, 48.671919209616526, 48.780325004032676, 50.29728698730469, 48.91513395309448, 49.344650745391846, 47.752151421138215, 48.069586821964805, 43.69368083136422, 41.270819664001465, 40.12991155896868, 39.58743790217808, 41.84571361541748, 43.935439927237375, 43.87136016573225, 49.31053161621094, 47.09608513968331, 51.652637345450266, 40.30412374223982, 40.74912806919643, 53.0036381312779, 45.72808906010219, 46.85620205742972, 42.21996096202305, 42.698108196258545, 41.540142263684956, 43.74929768698556, 44.6495931489127, 46.812181745256694, 46.3660900252206, 48.90592064176287, 48.57252522877285, 48.810209206172395, 47.39089720589774, 49.98698043823242, 50.02461188180106, 46.680843421391074, 45.53916754041399, 45.901901721954346, 46.628443581717356, 48.076705251421245, 49.557804107666016, 47.3173713684082, 50.783369064331055, 49.87123734610421, 49.021048818315776, 50.05681330817086, 42.71442256655012, 35.53619691303798, 25.130625077656337, 17.41289438520159, 7.765850441796439, 4.814587891101837, 5.890691884926387, 7.316133499145508, 5.915057914597647, 9.122864024979727, 6.963409500462668, 5.6587410398891995, 3.9824746676853726, 1.696350900190217, 0.16835159489086696, 0.08314696872340781, 0.7411363880549158, 4.708275241511209, 15.708800043378558, 23.346527440207346, 23.522362027849468, 26.37816892351423, 42.408542019980295, 49.482888630458284, 29.149906090327672, 11.263934918812343, 1.0884850323200226, 0.04307721635060651, 0.019078625266307166, 0.02626413639102663, 0.02298859679805381, 0.007341374011178101, 0.01334972441795149, 0.018876072385215333, 0.037573673097150664, 0.07878052123955318, 0.010722708239752268, 0.03288271284795233, 0.03301704242559416, 0.047719698665397506, 0.03425554186105728, 0.11233770807406732, 0.017965301971084306, 0.046377162848200114, 0.016955857298203876, 0.016056182627965297, 0.04088118865287729, 0.015893078076520135, 0.026418274102200354, 0.014547724642657807, 0.019533630493762236, 0.04277741243796689, 0.12210036814212799, 0.06544524537665503, 0.02519530463697655, 0.029254402898784195, 0.009998691018803843, 0.06668994322951351, 0.09704181206013475, 0.17278202144162996, 0.12635592264788492, 0.1552932970225811, 0.20661970786750317, 0.1434892847069672, 0.105000383220613, 0.07049481477588415, 0.1761707474610635, 0.23800715005823544, 0.14313951347555431, 0.08987275710595505, 0.18957972579768725, 0.13929262704082898, 0.1378463567899806, 0.14074777252972126, 0.12536827421614102, 0.0699604752340487, 0.10394056580428566, 0.18649239146283694, 0.10073522065899201, 0.1324292996100017, 0.15891402773559093, 0.10209577158093452, 0.2624130504471915, 0.17344039039952414, 0.21094641355531557, 0.25150199021611896, 0.08044106606394053, 0.11529540829360485, 0.10054090180035148, 0.19348825035350664, 0.14347552401678904, 0.16889043311987603, 0.18560068788272993, 1.3075570655720574, 9.498823234013148, 25.485587699072703, 51.54163292476109, 61.12958417619978, 49.20343555722918, 38.06667178017752, 34.230599130902974, 28.75979253223964, 24.639133828026907, 12.173316887446813, 4.883196141038622, 0.9020971081086567, 0.5919453193034444, 1.0264694286244256, 3.9063719170434132, 7.959203175136021, 6.2800129141126355, 5.81014141866139, 7.36374168736594, 2.6961735529558997, 4.108869348253522, 6.877897151878901, 14.112051027161733, 24.23551992007664, 31.183119228907994, 36.67930064882551, 48.39382798331124, 48.41109078271048, 54.401556628090994, 55.82631254196167, 57.175117697034565, 51.07246276310512, 51.39012745448521, 50.20352104731968, 50.39684077671596, 47.75626475470406, 50.12017045702253, 49.84872170857021, 52.42934519904, 49.92098992211478, 51.88187231336321, 48.84883771623884, 48.91840655463082, 44.487064361572266, 42.70870072501046, 40.42918784277779, 41.14484534944807, 42.973944732121055, 45.50248452595302, 44.8496595791408, 51.400275298527305, 50.01547500065395, 51.99265439169747, 43.88787950788225, 42.377042361668174, 53.35110364641462, 48.23840025493077, 48.1667434828622, 43.191232272556846, 44.94471788406372, 45.49485887799944, 46.30692611421858, 47.88301726749965, 49.026999950408936, 48.504425934382844, 51.05128117970058, 49.39507382256644, 50.05746643883841, 49.31487076623099, 50.124784060886924, 52.34016507012503, 48.13210323878697, 48.20552485329764, 46.80597700391497, 49.80470487049648, 47.999187673841206, 49.22019461223057, 47.922351019723074, 52.324486460004536, 52.495919363839285, 50.07135588782174, 50.52298184803554, 44.052920069013325, 37.17817783355713, 27.679781913757324, 19.306650229862758, 8.606068304606847, 4.2533692973000665, 6.652537107467651, 13.471140503883362, 17.429929631096975, 17.700346572058542, 15.154243469238281, 10.109714933804103, 8.590292419706072, 3.3444854276520863, 0.8190630951098034, 0.5147206517202514, 1.0809441741023744, 5.913287426744189, 18.668637105396815, 29.663190364837646, 30.739059856959752, 39.95247541155134, 49.22674676350185, 54.94774409702846, 35.99796724319458, 13.457314457212176, 1.7084047219582965, 0.18090829253196716, 0.20639414925660404, 0.21892960875162057, 0.11475927063396998, 0.19685522254024232, 0.09514858400715248, 0.13524002235914978, 0.1443486628787858, 0.12834962138107844, 0.10808470485998051, 0.1155158778918641, 0.12823541036673955, 0.10445017274469137, 0.1521013868706567, 0.23532633962375776, 0.10180282765733344, 0.1475145715687956, 0.09097734426281281, 0.13580235147050448, 0.07673348286854369, 0.1639254702521222, 0.12102541939488479, 0.0748391148767301, 0.08531656408948557, 0.1949287937687976, 0.1999594388263566, 0.1659496080662523, 0.1124368691816926, 0.09640469481902463, 0.11764863559177943, 0.13317598668592318], [0.04622543902535524, 0.033692822592066865, 0.03807919864941921, 0.11021134895937783, 0.04591395413236959, 0.018657095563997115, 0.024923064513131976, 0.041692411194422414, 0.024679998002414192, 0.019725523589711105, 0.044314297647880654, 0.030240663726414953, 0.03846268628590873, 0.005728807125706226, 0.042540128741945536, 0.06510400333042655, 0.047866031527519226, 0.018600792424487214, 0.06078472760106836, 0.014069286208333713, 0.03717603800552232, 0.02692406258678862, 0.06879954252924238, 0.10456338631255285, 0.04410793479265911, 0.034543288206415515, 0.04472110992563622, 0.07157260658485548, 0.005433129130064377, 0.032381292432546616, 0.01977553162058549, 0.013448600540868938, 0.05570592352056077, 0.04372222495398351, 0.06105814328683274, 0.23896754852363042, 2.285959073475429, 10.507449797221593, 24.544560159955704, 48.953140599387034, 38.68537759780884, 33.517741748264854, 17.52601800646101, 19.965443679264613, 22.117026329040527, 11.384711112294879, 4.7585068089621405, 0.606894422854696, 0.1445716159152133, 0.3803450422627585, 0.41418673204524176, 0.6385889564241681, 4.521382161549159, 4.501755237579346, 0.8591046407818794, 1.3691724964550562, 2.451778701373509, 4.648902450289045, 8.399401954242162, 10.70114038671766, 20.539601121629985, 23.130384615489415, 36.87032399858747, 40.7836571420942, 46.45484978812081, 48.982785088675364, 50.90464639663696, 48.5277475629534, 49.21798161097935, 46.88478694643293, 47.257620334625244, 47.1937837600708, 44.7188458442688, 45.33579724175589, 46.42400673457554, 47.00598784855434, 46.97587088176182, 44.79096119744437, 43.11589295523507, 41.35793617793492, 40.15272944314139, 38.22088009970528, 38.973922388894216, 38.55195828846523, 40.90720306124006, 41.26837737219674, 47.06291443961007, 44.691049575805664, 52.85121897288731, 40.85211774281093, 37.749333654131206, 50.736017090933665, 42.94911881855556, 46.14006165095738, 41.22616011755807, 45.41488511221749, 43.30023561205183, 47.56484188352312, 44.426437854766846, 45.87177780696324, 47.79736334936959, 48.38319723946707, 45.86902979442051, 48.50172308513096, 42.88239179338728, 46.354899951389854, 47.793948309762136, 45.03702122824532, 44.4570620400565, 45.622347899845664, 44.95780829020909, 49.25309085845947, 46.23817021506173, 47.89131689071655, 46.24903719765799, 49.51829317637852, 45.81633465630667, 45.265422412327354, 37.37663228171212, 29.892644201006206, 19.0776549748012, 11.628524269376483, 4.172586500644684, 3.469238813434328, 4.050557894366128, 2.558842624936785, 4.981492306504931, 8.643638951437813, 6.070440913949694, 3.685833922454289, 3.8684369240488325, 0.396930989410196, 0.20801941704537186, 0.1350308707250016, 1.805399620107242, 5.668494573661259, 20.267591306141444, 22.419615166527883, 27.301843336650304, 30.71718692779541, 42.43333319255284, 39.2900584765843, 20.975795132773264, 4.884369518075671, 0.22180220032376902, 0.05254065265346851, 0.032805709301361015, 0.04632035589643887, 0.04882928662534271, 0.04561533426333751, 0.01623818607601736, 0.05605401198512741, 0.0551629156938621, 0.01952314543138657, 0.028864394540765455, 0.05159023883087294, 0.014617282963757004, 0.10718549668256726, 0.04562966153025627, 0.015948487246142964, 0.0440497063100338, 0.032040372690452, 0.09248580903347049, 0.057088978056396754, 0.04886800044083169, 0.06308647444737808, 0.07443067750760488, 0.07902591342904738, 0.04193778981321624, 0.04927929783506053, 0.04597024539751666, 0.040631538656141074, 0.042550978516893725, 0.05900710155921323, 0.04903398367709347, 0.021100142238927738, 0.040483434817620685, 0.05505330853962472, 0.009655918876108314, 0.09335530416241714, 0.06977270423833813, 0.04306825968836035, 0.08440267919961895, 0.04640537972695061, 0.041431063253964694, 0.017353948704632263, 0.053154737023370605, 0.03559702255630067, 0.07800414825656585, 0.014126977800125522, 0.017284451451684748, 0.027214514590533714, 0.05956098969493594, 0.04000197011711342, 0.014687908281173025, 0.034106650921915255, 0.02463465998880565, 0.07700640322374445, 0.012952899327501655, 0.03835825974653874, 0.033248273589249165, 0.07950151219431843, 0.06171028329325574, 0.0476264272417341, 0.02510196535981127, 0.06814973668328353, 0.013165909281399633, 0.052795143997562785, 0.08913843293807336, 0.03646194775189672, 0.05322561679141862, 0.28867952099868227, 3.7205644931112016, 14.01905025754656, 29.830138206481934, 55.366043022700715, 42.8653860773359, 37.73933172225952, 19.73400786944798, 23.169537714549474, 24.989896263395035, 12.306054404803685, 5.711493066379002, 0.35912698081561495, 0.1577315176171916, 0.18012363463640213, 1.143309576170785, 1.472898570554597, 4.336275637149811, 6.629346626145499, 5.5374758669308255, 2.5756190504346574, 4.849371876035418, 5.653798699378967, 11.650708998952593, 15.54105315889631, 22.34090076174055, 28.513511896133423, 38.158780574798584, 45.07621949059622, 47.96386650630406, 51.52392544065203, 51.43349116189139, 51.374671186719624, 51.418910367148264, 48.971928528376985, 48.93209450585501, 49.57604660306658, 48.05830642155239, 47.78094128199986, 49.05964953558785, 48.59379366465977, 48.1667434828622, 47.01136228016445, 44.47282402856009, 42.118725708552766, 41.031040804726736, 40.50457232339041, 40.471200125558035, 41.198777266911094, 42.11229167665754, 43.21834761755807, 48.061759676252095, 46.80844708851406, 52.164024761744905, 42.007221017565044, 40.241162640707834, 52.06130954197475, 45.357968943459646, 47.0402945790972, 42.974552699497764, 46.849201747349326, 45.32668467930385, 48.75055544716971, 47.56692634310041, 48.413265568869456, 49.91055720193045, 49.251273904527935, 46.86956344332014, 48.75061798095703, 44.17167173113142, 48.20002882821219, 49.70963614327567, 46.734198638371055, 46.12017590659005, 47.02704436438424, 46.281721523829866, 49.42604889188494, 46.780060223170686, 47.667428561619346, 48.43777881349836, 50.18937104088919, 46.82480314799717, 45.76438644954136, 40.546970231192454, 32.275132860456196, 22.44413709640503, 13.086546421051025, 6.019913179533822, 3.8684425694601874, 5.084240095955985, 6.753444927079337, 6.805897746767316, 8.272507871900286, 7.54813471862248, 4.199444328035627, 3.6345160475799014, 1.4525863804987498, 0.20999909724508012, 0.20699187075453146, 1.363202365381377, 5.685290106705256, 21.071506568363734, 25.542106083461217, 27.488117592675344, 33.695316859654014, 48.078702858516145, 44.5014123916626, 25.451220171792166, 6.784601518086024, 0.39190795751554625, 0.012445276253856719, 0.0640524233292256, 0.053902502969971726, 0.038635122390197854, 0.059515317502830706, 0.040820062825722356, 0.04625094515670623, 0.005949238556370671, 0.009684739651025405, 0.05332373295511518, 0.03470397547685674, 0.04114470790539469, 0.014126159317259277, 0.11453695542046002, 0.022236210027975694, 0.05423632862844637, 0.01100047757583005, 0.05223983433097601, 0.010677665388876838, 0.022629782391179885, 0.05083752636398588, 0.10566492684717689, 0.05397496711728828, 0.02497333717266364, 0.05887497043503182, 0.021935929444485476, 0.02094008430971631, 0.00684919354638883, 0.03993465265791331, 0.02619814037877534, 0.03285557823255658, 0.13564423924045904, 0.1741536935525281, 0.08407509606331587, 0.23751238946403774, 0.1758596934378147, 0.06499410779880625, 0.14381812991840498, 0.11502197225178991, 0.08671858028641768, 0.14672444468098028, 0.17237187416425773, 0.12327214383653232, 0.2504199168511799, 0.11595398081200463, 0.10434747646961894, 0.10735272163791315, 0.08700024017265864, 0.10851102162684713, 0.1750391274690628, 0.11502856761217117, 0.15861110256186553, 0.1874410512724093, 0.13586975713925703, 0.15972885329808506, 0.12861899978348187, 0.15856281800993852, 0.12672026881149837, 0.1494522233094488, 0.12617696582206658, 0.17353799087660654, 0.13913697110755102, 0.14729163210306848, 0.17511979171207973, 0.13429627514311246, 0.12359830204929624, 0.6478726182665143, 3.8731573564665656, 16.61285274369376, 38.4894939831325, 62.93741512298584, 51.395123209272114, 44.652497495923726, 26.792882578713552, 28.86391649927412, 30.55468245915004, 15.729495252881732, 6.61235784632819, 1.1069267456020628, 0.5380780526569912, 0.8857102702770914, 2.519444167613983, 3.6916196005684987, 8.773129054478236, 12.096824169158936, 7.164416543075016, 4.616391829081944, 5.115807499204363, 7.211487548691886, 11.942415220396859, 13.15309453010559, 25.48523507799421, 31.083245822361537, 43.00231422696795, 45.63293695449829, 49.54937941687447, 52.34429924828665, 52.67287955965315, 51.671578134809224, 53.65119286945888, 50.95210606711251, 50.95194625854492, 51.13818577357701, 49.83956050872803, 49.52841322762625, 51.29635109220232, 50.13546691622053, 50.98787886755807, 48.63473245075771, 46.75025592531477, 43.787894930158345, 44.59007487978254, 41.89556346620832, 41.92696932383946, 43.76167590277535, 43.28547069004604, 44.85264035633632, 50.32416261945452, 48.62006132943289, 54.619643211364746, 44.607664244515554, 43.44870471954346, 52.55269309452602, 48.03732981000628, 48.816083908081055, 45.18014717102051, 49.58537803377424, 49.10397556849888, 50.898028237479075, 48.576614243643625, 49.756960323878694, 50.88262408120291, 50.48959575380598, 47.14230803080967, 49.153877530779155, 46.00902557373047, 48.049214703696116, 50.46639224461147, 48.136355536324636, 48.2182365826198, 49.88594320842198, 47.19500664302281, 52.15225798743111, 47.583640234810964, 48.17154816218785, 48.29755374363491, 52.37198087147304, 48.48975133895874, 47.25706100463867, 40.91993563515799, 34.64052895137242, 23.388803754534038, 13.709694743156433, 5.869490759713309, 6.521659970283508, 8.505294237818037, 8.130890556744166, 11.792409692491804, 20.434374128069194, 15.987417595727102, 11.653438772474017, 8.258437769753591, 3.2304411700793674, 1.3680197468825748, 0.3232067482812064, 2.5323827990463803, 7.325972148350306, 24.378658022199357, 29.05208761351449, 36.696421010153635, 39.8392128263201, 54.279678276606965, 50.68117148535592, 29.602310248783656, 7.424993532044547, 0.6595743075013161, 0.09304228917296443, 0.15436857592846664, 0.11243583102311407, 0.20414248508002075, 0.1608622781932354, 0.09918765191520963, 0.14384428065802368, 0.1567354689219168, 0.15262282746178762, 0.17795209187482083, 0.12995344746325696, 0.07535112383110182, 0.2194899022579193, 0.18022670410573483, 0.0839431956410408, 0.12363788778228418, 0.11978239752352238, 0.11180354495133672, 0.13155442369835718, 0.16119728450264248, 0.17226830257901124, 0.2024487123957702, 0.14357525509382996, 0.09370563179254532, 0.16581715803061212, 0.21814698646111147, 0.19172833407563822, 0.07822469249367714, 0.11045516016227858, 0.14509988256863185, 0.137184296601585], [0.05635761230119637, 0.03434278450108, 0.03172378521412611, 0.021529671869107654, 0.024005250905507376, 0.03298364493197628, 0.04673829614850027, 0.053431888044412644, 0.015701134090444872, 0.011507018386120242, 0.03246067763705339, 0.00939497975299933, 0.04090043529868126, 0.022164485483829464, 0.003887536619523806, 0.049064548287008486, 0.0726201900147966, 0.016050666138263683, 0.02547133098622518, 0.07554264712546553, 0.0296991486767573, 0.08858674325581108, 0.006070900733383107, 0.031569713660116704, 0.04847160367561238, 0.020556740861918246, 0.024982616139043654, 0.04379502836880939, 0.029083951509424617, 0.03302439095984612, 0.019483598714162196, 0.016546588723680804, 0.06405185335980994, 0.023988981332097734, 0.013600428688472934, 0.05027304629662207, 0.639578966157777, 6.181252087865557, 24.813111509595597, 42.796619755881174, 42.118357454027446, 29.33507558277675, 24.771955592291697, 17.723185300827026, 17.064864328929357, 11.398478967802864, 8.10234648840768, 1.4440949218613761, 0.31362216972879, 0.12542755103537015, 0.7850852097783769, 0.9979555415255683, 5.119950362614222, 5.028385698795319, 6.764053957802909, 1.6683062336274554, 3.115086091416223, 2.3014726638793945, 5.508009425231388, 10.034723894936697, 13.755374806267874, 17.149925913129533, 28.406681605747767, 33.93969890049526, 38.30435575757708, 46.24054649897984, 49.72896603175572, 51.85966239656721, 49.68634925569807, 47.418575354984824, 46.20165048326765, 46.88010038648333, 45.01935543332781, 45.23808472497122, 45.57066025052752, 44.53563574382237, 44.055362360818044, 44.21806137902396, 44.143361295972554, 43.7422001021249, 44.620494093213765, 43.04478161675589, 41.49711554391043, 39.94370331083025, 41.798649992261616, 42.36462593078613, 45.83915948867798, 45.737531661987305, 48.98720761707851, 38.438091209956575, 36.24872425624302, 53.07937697001866, 43.72739349092756, 46.204527037484304, 41.467842783246724, 46.129889488220215, 46.02788993290493, 47.41907909938267, 45.57487085887364, 48.609875270298545, 47.56466123035976, 48.32208088466099, 46.94581992285592, 46.713534695761545, 44.46530955178397, 48.56058127539498, 47.121994972229004, 49.22322402681623, 44.35156406675066, 45.77282156263079, 44.290065561022075, 46.76290512084961, 44.618607657296316, 45.92405605316162, 45.06902463095528, 43.08185373033796, 45.6211701801845, 40.74412884031023, 34.82447556086949, 24.935349430356705, 17.172922713415964, 8.231504814965383, 3.4448100328445435, 2.760104362453733, 6.348367120538439, 7.979828902653285, 3.5644321739673615, 5.211091186319079, 5.08249740089689, 3.5935097336769104, 2.997393378189632, 0.6667045706084797, 0.11562879968966756, 0.3950329641146319, 2.046574741601944, 8.173104337283544, 21.67885034424918, 26.95855368886675, 27.18289191382272, 32.19394315992083, 34.56160088947841, 28.689155408314296, 12.81516454901014, 1.8747212546212333, 0.08901105155902249, 0.007663758721069566, 0.06849878866757665, 0.017726832535117865, 0.05134795093908906, 0.037447692892913303, 0.060450996937496324, 0.08428574047450509, 0.0390073056332767, 0.01916852267459035, 0.028854481144143, 0.036451145474399836, 0.035583601133631806, 0.04928833592150893, 0.10272684307502848, 0.0593487982239042, 0.07327108151678528, 0.032275237409131866, 0.03472436884684222, 0.04864236040573035, 0.029657045578850166, 0.06194925654147353, 0.05753971529858453, 0.014262427808716893, 0.0462811331796859, 0.06593694577791862, 0.07201587994183813, 0.03384939454761999, 0.038190634455531836, 0.03387387948376792, 0.031073361901300292, 0.11336317804775067, 0.01380923851060548, 0.03734204499050975, 0.06224712662930999, 0.017550128445561444, 0.05493969463610223, 0.01188875625043043, 0.05354113557509013, 0.04450003303853529, 0.005832238763105124, 0.03278493595176509, 0.008066295380038875, 0.009614985402939575, 0.038626820514244695, 0.03938555158674717, 0.029142695678664104, 0.04268696711265615, 0.08315608823405844, 0.021748682617076805, 0.0313262315467, 0.05165590066462755, 0.013503540673160126, 0.055632275329636674, 0.02366888752606298, 0.023334971961698363, 0.01772098017058202, 0.06633450623069491, 0.028423789522743652, 0.019928140931629708, 0.04536750952580145, 0.04362185944670013, 0.020233101710411053, 0.016332680559051887, 0.06229274453861373, 0.030312052395726954, 0.0927022277776684, 0.012186264170200696, 1.1434664534670966, 8.378128307206289, 29.97370535986764, 48.98081874847412, 49.18943493706839, 35.801625047411235, 28.35691860743931, 22.726108891623362, 24.000903572354996, 14.966150522232056, 7.528693658964975, 1.7057882909263884, 0.2563811455454145, 0.1346999763378075, 0.7581127913934844, 1.2884030533688409, 3.692724798406873, 5.120901831558772, 5.453021381582532, 5.9608074596949985, 4.613581282751901, 3.054632855313165, 8.335105061531067, 11.043723923819405, 17.96295200075422, 23.065698623657227, 32.73518698556082, 38.08164514814104, 42.0823449407305, 48.133242743355886, 51.83588566098894, 53.50640978131975, 51.61543321609497, 48.42486558641706, 47.953583172389436, 47.47152410234724, 46.9854177066258, 48.27574334825788, 48.02102238791329, 47.08701079232352, 46.04698705673218, 45.66338743482317, 45.96154505865914, 44.88359458105904, 46.33406230381557, 44.57168647221157, 43.59191056660244, 42.50203698022025, 42.97098479952131, 44.00354616982596, 49.06856754847935, 47.57770299911499, 51.144592012677876, 39.69635786328997, 38.38684824534825, 54.832195554460796, 45.71605478014265, 47.046276978084016, 44.5120917728969, 47.11772183009556, 47.88242319652012, 49.28184250422886, 46.740003858293804, 49.730036054338726, 48.85946498598371, 46.83135182516915, 48.96368449074881, 48.20583404813494, 45.31840590068272, 49.37249565124512, 49.613834381103516, 50.25486823490688, 46.66363273348127, 47.01100444793701, 45.757598059517996, 49.724050181252615, 45.6331592968532, 46.07307406834194, 45.90837744304112, 45.154108796800884, 45.769816466740195, 43.20819282531738, 36.720955099378315, 27.852720839636667, 18.475508451461792, 10.431941986083984, 6.202367229121072, 5.319460068430219, 6.082820866789136, 8.216006858008248, 8.438940678324018, 7.70536550453731, 6.348124802112579, 4.730254564966474, 2.050067514181137, 1.4808498067515237, 0.18102490556027206, 0.1638737116008997, 2.1372572013310025, 7.743588413511004, 25.785188811165945, 26.22417426109314, 27.46311797414507, 32.75638593946184, 41.621366705213276, 35.49961117335728, 16.808998652866908, 2.517280238015311, 0.13929895098720277, 0.019402788586116264, 0.06804811249354056, 0.015728202548676302, 0.07114533986896276, 0.036544474573539834, 0.015940444909834435, 0.07123626356146165, 0.0376468530989119, 0.022532614480171884, 0.06593711541167327, 0.05666572487513934, 0.028665678775204078, 0.012057832758208471, 0.14369167813232966, 0.03231881971337965, 0.08877595953111138, 0.06835732768688883, 0.01957210003664451, 0.053522340155073574, 0.049594725016504526, 0.02310711650976113, 0.01861094161202865, 0.027312189706468155, 0.017184830636584332, 0.07461879455617496, 0.00983467638226492, 0.05974306099648986, 0.03729073077972446, 0.036345745237278085, 0.06489922824714865, 0.10352087832455124, 0.1562738615487303, 0.14719040824898652, 0.16177840903401375, 0.17039737797209195, 0.19424461333879403, 0.12282963043877057, 0.12319340663296835, 0.1441141611763409, 0.07421396020799875, 0.09551561038408961, 0.08992503144379173, 0.07567041526947703, 0.14968392944761685, 0.09430553817323276, 0.11391058617404529, 0.11746211988585335, 0.20000556563692434, 0.07729155077998127, 0.10051123624933617, 0.22049464977213315, 0.09882436426622526, 0.121276233079178, 0.11029617262205907, 0.0998065233496683, 0.14376196078956127, 0.14439180413527147, 0.1486871750759227, 0.08981076614665133, 0.16409137206418173, 0.16185516491532326, 0.11742997089666979, 0.13091611223561422, 0.11905844137072563, 0.08429269545844623, 0.2039911446294614, 0.09261017771703856, 1.2673180933509554, 9.840417521340505, 35.27059159960066, 57.972840377262656, 56.585590839385986, 39.815505572727744, 36.200799056461875, 27.22053551673889, 26.321704387664795, 17.003647225243704, 10.314805780138288, 2.1451783648559024, 0.44031342438289095, 0.821058585175446, 2.041770279407501, 4.31141802242824, 9.81515039716448, 10.592209134783063, 13.646508693695068, 6.1346787469727655, 6.444372986044202, 4.077429183891841, 8.36446988582611, 14.110976661954608, 16.07576220376151, 27.21405805860247, 38.360118525368826, 43.82632194246565, 44.57613679340908, 50.38108573641096, 52.97557088306972, 56.196592467171804, 53.039963313511436, 52.0987777028765, 50.365928241184776, 50.54246459688459, 48.191142082214355, 49.70406021390642, 49.93139484950474, 49.116027218954905, 48.539319787706646, 49.73305852072579, 46.944840226854595, 48.04714414051601, 48.33408389772688, 47.57237025669643, 45.52707420076643, 44.220093727111816, 43.9597864151001, 46.27761513846261, 50.5159398487636, 50.229806082589285, 52.152577604566304, 43.010742391858784, 41.79849713189261, 55.22091252463204, 47.564880098615376, 49.72127090181623, 46.893347127096995, 50.25805745806013, 49.23824255807059, 50.56330919265747, 48.911826610565186, 51.735591888427734, 49.25321592603411, 48.0868044580732, 48.78580018452236, 47.81058924538748, 45.6099523135594, 48.37103789193289, 49.71364525386265, 52.310676915305, 47.78599609647478, 48.772470065525596, 47.839257512773784, 49.32533127920968, 45.959036758967805, 46.05126714706421, 45.893678528921946, 47.00063426154, 48.424917697906494, 45.82636090687343, 40.6548444884164, 29.986097472054617, 21.26869123322623, 9.573475548199244, 5.758548872811454, 5.010366414274488, 12.562138080596924, 12.672284398760114, 10.174556391579763, 11.323446239743914, 11.123210447175161, 8.215182627950396, 6.525936152253832, 2.8881151505878995, 0.6963020509907177, 0.7795767539313861, 2.9378460134778703, 10.947406257901873, 27.28842462812151, 34.673036098480225, 35.29851640973772, 41.16730540139334, 46.98230143955776, 40.75945656640189, 19.79856184550694, 3.7328106931277683, 0.24726342622722897, 0.10942002106457949, 0.13827501450266155, 0.10864475409367255, 0.17217276484838553, 0.1786591253642525, 0.0979255632098232, 0.20554923745138304, 0.13241969155413763, 0.13937031930046423, 0.17806003322558744, 0.2900850927191121, 0.11881890493844237, 0.1129498959385923, 0.30828736456377165, 0.2042395155876875, 0.10417553569589343, 0.11705740088863031, 0.0934416680995907, 0.19910627603530884, 0.18082175217568874, 0.10677217386130776, 0.11660658222224031, 0.12409904732235841, 0.12552545006786073, 0.14875747130385467, 0.1744049007871321, 0.17911006616694586, 0.1589727345854044, 0.15301118019436086, 0.17687513466392243, 0.17634981285248483], [0.11395034832613808, 0.02897433756983706, 0.03678446901696069, 0.0325406463816762, 0.06473692267068795, 0.01648243154133005, 0.0141981892021639, 0.0495100947363036, 0.03683200718036719, 0.046501867406602414, 0.03518126718699932, 0.026965804364798323, 0.035991482104041746, 0.02573803935333022, 0.05275110028950231, 0.022329601891604916, 0.09111620645437922, 0.007579134378050054, 0.06752365242157664, 0.023917250002601316, 0.038171889925641675, 0.05182803142815828, 0.02187266114300915, 0.04239768388548067, 0.04413331200235656, 0.02281636425427028, 0.020727321172931364, 0.008286418077269835, 0.07506632232772452, 0.05224515404552221, 0.018205123388075402, 0.038008627614804676, 0.03912211375843201, 0.11336019249366862, 0.028420171234756708, 0.017799778442297663, 0.170459599633302, 3.1048333730016435, 16.744644437517437, 37.241896288735525, 42.69495023999895, 32.00524050848824, 15.899269274302892, 10.355133124760219, 17.107823303767614, 19.827257905687603, 6.6303567205156595, 2.7306305382932936, 0.35011397302150726, 0.1308536734431982, 0.6275952234864235, 1.274540745786258, 2.529295627559934, 4.059865440641131, 2.767839227403913, 5.784020968845912, 3.5175533294677734, 1.4872492062194007, 4.252439975738525, 5.7432901944432935, 9.992173995290484, 12.708617397717067, 21.91115641593933, 28.20439175197056, 37.21407222747803, 43.52240078789847, 48.72783831187657, 50.453447750636506, 50.780495984213694, 46.868118218013215, 47.60077796663557, 45.20561579295567, 45.555120604378835, 43.56248494556972, 43.42758566992623, 43.998887402670725, 44.86236088616507, 46.55869409016201, 45.95308910097395, 45.65669979367937, 46.658643926892964, 44.812156677246094, 44.37439584732056, 42.696176597050254, 45.59391587121146, 43.985182080950054, 49.37211697442191, 45.4265580858503, 56.66649913787842, 42.08070516586304, 33.2459316934858, 51.59323372159685, 42.51473133904593, 45.19941799981253, 40.07400982720511, 43.84544685908726, 44.5877229145595, 48.12981033325195, 46.61166020802089, 47.93309988294329, 46.87509420939854, 47.55283887045724, 46.718360219682964, 49.17085892813546, 47.35792800358364, 48.669758319854736, 46.795280252184185, 47.99638754980904, 46.71853045054844, 44.995776721409385, 46.34760086877005, 46.36394303185599, 44.473053319113596, 44.273421151297434, 42.240888936179026, 39.53656666619437, 40.05184507369995, 41.2979211126055, 34.45653370448521, 23.911365611212595, 13.558779001235962, 7.443814464977809, 4.635645721639905, 2.117154977151326, 2.4530903909887587, 6.550832850592477, 8.302950535501752, 7.997317518506732, 4.237133528505053, 1.5648704639502933, 1.4711258028234755, 1.139315013374601, 0.21134182305208274, 0.26535848953894203, 3.7552164622715543, 8.141188655580793, 21.744866916111537, 35.532646383558, 21.36152264050075, 34.88855184827532, 38.28479310444423, 25.627740894045147, 6.265513326440539, 0.5327440617339951, 0.09251081304890768, 0.041635013917194943, 0.0628001665962594, 0.05679422244429588, 0.04357753075393183, 0.02454892369652433, 0.016140624614698545, 0.0152960062758731, 0.059101295790502, 0.01116461943768497, 0.023588621922369515, 0.01190714879027967, 0.05486568342894316, 0.01644604340461748, 0.054362967011651823, 0.04507202109588044, 0.02084506905105497, 0.05838590953499079, 0.03787243885121175, 0.05020837851666978, 0.020127357116767337, 0.02704834475714181, 0.050006270076015165, 0.050583493031029186, 0.026749504364228675, 0.003075767433204289, 0.010729455422343952, 0.07129330121512924, 0.03343008026214583, 0.04219746855752809, 0.012950614360826356, 0.04161443734275443, 0.03884683210136635, 0.02049038013709443, 0.070462353660592, 0.05144262353756598, 0.026233517498310124, 0.02369919089999582, 0.027828597264098268, 0.00918073910621128, 0.01849210129252502, 0.018367203351642405, 0.044653093575366905, 0.020698442722537687, 0.06152450719049998, 0.015121200388031346, 0.022560213892055408, 0.010464585885139448, 0.05483841310654368, 0.007397037631432925, 0.030296683577554565, 0.05765491697405066, 0.012272836756892502, 0.04944971529766917, 0.010727642037506615, 0.012380411698749023, 0.07132099222924028, 0.04437435817505632, 0.03364611224138311, 0.0338934687897563, 0.03883310533793909, 0.02374950596796615, 0.02759543397197766, 0.060656721969800334, 0.03684707744313138, 0.032003904825874736, 0.014031173744505005, 0.06249606755695172, 0.3391153546316283, 4.493054790156228, 22.078392607825144, 42.721242223467144, 48.0407726424081, 36.47522858210972, 19.80125948360988, 14.871458734784808, 22.87607533591134, 22.219486202512467, 10.154617667198181, 2.801572948694229, 0.457303344139031, 0.15291820732610567, 0.6920103984219688, 1.8958218480859483, 3.516101373093469, 6.63595392874309, 6.689239663737161, 6.787814191409519, 6.116387179919651, 4.35113479409899, 6.227063298225403, 6.760943336146219, 12.723844374929156, 17.990221943174088, 25.74517239843096, 31.83977610724313, 40.645568643297466, 46.17270081383841, 50.56071751458304, 51.86793770108904, 52.417147636413574, 49.07207291466849, 49.600000517708914, 46.84388290132795, 47.88327087674822, 44.73588282721383, 45.281201771327424, 45.5400082724435, 47.56879540852138, 47.18305574144636, 49.19178342819214, 47.2260650907244, 49.76997429983956, 46.64816951751709, 45.8564327103751, 43.83860635757446, 46.20224802834647, 46.52059711728777, 51.30893080575125, 47.6301896912711, 54.78747694832938, 41.150879859924316, 36.11981780188424, 52.477687290736604, 45.50705991472517, 47.38065903527396, 43.73907341275896, 46.744756426130024, 47.44172327859061, 50.62642315455845, 48.45131043025425, 48.17717620304653, 47.72162103652954, 50.09963853018624, 48.23970651626587, 49.504963057381765, 48.42395537240164, 49.936241218021934, 47.47873285838536, 50.24855579648699, 48.07565607343401, 48.30368552889143, 46.95053774969918, 48.50283132280622, 45.831155163901194, 45.85302461896624, 43.99147367477417, 41.97049978801182, 42.14464596339634, 44.09842382158552, 35.142157622746055, 26.175404855183192, 14.780868121555873, 9.07275014264243, 6.345438020569937, 5.596446965421949, 4.530782205717904, 4.845362331186022, 5.926984931741442, 8.18692864690508, 4.949678676468985, 3.519533783197403, 1.5121536127158572, 0.5870378826345716, 0.31314100697636604, 0.43068756375994, 3.771402725151607, 10.76249384880066, 26.58009225981576, 34.6566869871957, 23.94576093128749, 39.54205574308123, 43.60014418193272, 29.70576545170375, 8.777058260781423, 0.803501301578113, 0.010698276738237058, 0.0545980285054871, 0.03858594895739641, 0.011038176981466157, 0.06498192130987133, 0.03456288769042917, 0.04615458639870797, 0.0428684243400182, 0.06339003744402102, 0.015523469873837062, 0.06064350410763707, 0.023111472704580853, 0.010318367525802126, 0.005720450542867184, 0.04733907105401158, 0.04835357250911849, 0.038971770754350085, 0.0488501753258918, 0.04006020877776401, 0.03420557114960892, 0.027086230759908046, 0.02380275569989213, 0.09214400380317654, 0.04761881747149995, 0.06820930527257067, 0.039715041406452656, 0.05334580909194691, 0.0599649419475879, 0.04535512965438621, 0.0006518641395294772, 0.0462671248242259, 0.008315936895087361, 0.18283873823072228, 0.08883655949362687, 0.11406971620661871, 0.1323212632643325, 0.12368143615978104, 0.08421194300587688, 0.16343438731772558, 0.13019283461783612, 0.1300455518066883, 0.12485581742865698, 0.14144627004861832, 0.0860411784212504, 0.10212082309382302, 0.07888930397374289, 0.1256727600204093, 0.1541746641908373, 0.18575566528098925, 0.12600373583180563, 0.17043492810002395, 0.09818935726902314, 0.09817727256034102, 0.12890591153076716, 0.12039820876504694, 0.07678178777652127, 0.10133061478180544, 0.11651934976024286, 0.09065429374043431, 0.07199382755373206, 0.2136097177863121, 0.1068713553249836, 0.16457712171333178, 0.11214186929698501, 0.0854710258011307, 0.19024611503950187, 0.1557951143809727, 0.1040082700284464, 0.36924450791307856, 5.124190500804356, 24.974733557019913, 48.875536169324604, 54.06693485804966, 44.072934355054585, 24.911678654806956, 16.958918196814402, 26.532736812319072, 26.76255021776472, 9.964926634516035, 3.995141233716692, 0.8733524648206574, 0.22769529053143092, 2.1922967050756728, 3.9950126920427596, 6.875140454087939, 10.586094720023018, 11.170431273324148, 14.292626023292542, 8.576010397502355, 4.360180045877184, 7.593818255833217, 8.437413811683655, 15.894209248679024, 22.68493560382298, 30.281885760171072, 33.73535932813372, 41.78559085300991, 47.59236022404262, 50.62810809271676, 54.946073055267334, 54.548108032771516, 49.8653244291033, 50.72887086868286, 49.119362354278564, 49.34383085795811, 47.26565245219639, 47.474067143031526, 47.58642993654524, 48.50232410430908, 50.865552357264924, 51.040101528167725, 49.44842209134783, 50.87680843898228, 49.16155181612287, 46.5649231501988, 46.400549616132466, 47.41031742095947, 49.55064746311733, 52.16352449144636, 49.54453999655587, 54.345123359135215, 42.81075586591448, 39.18090227672032, 52.54281275612967, 46.974519457135884, 49.44537878036499, 44.40888670512608, 48.932438441685264, 47.76316779000418, 51.80154766355242, 49.75904130935669, 49.47542626517159, 48.58859988621303, 52.622849055698936, 50.1608486856733, 51.643076624189106, 48.01572091238839, 50.864878382001606, 47.89176852362496, 52.410039629255024, 49.637955052512034, 48.937972681862966, 47.93621962411063, 49.44165454592024, 46.284327098301475, 46.266869749341694, 43.612147194998606, 44.53461783272879, 44.05488640921456, 46.09647560119629, 38.428857054029194, 28.634671109063284, 17.6967282976423, 11.3581394638334, 7.638285858290536, 6.750562293188913, 5.0655242545264105, 16.992564848491124, 16.26561825616019, 16.1753785269601, 12.97981514249529, 6.292620854718344, 3.422134803874152, 1.6994686871767044, 0.6031310505100659, 0.6111593140023095, 5.294545131070273, 12.376318063054766, 28.705115420477732, 42.11115217208862, 31.084291526249476, 44.791850566864014, 50.34187705176217, 35.920974254608154, 11.178735239165169, 1.0380273227180754, 0.12017901481262275, 0.12992470471986703, 0.13784464688173362, 0.08592683848525796, 0.18428460136055946, 0.14741177351347037, 0.09233324721987758, 0.08500839384006602, 0.09426747235868659, 0.16800235291676863, 0.20610402125333036, 0.11899365484714508, 0.12447757486786161, 0.20138001974139894, 0.139262391520398, 0.1685741136648825, 0.09650164390248911, 0.22184064611792564, 0.28754254058003426, 0.1362844913133553, 0.05554958226691399, 0.11180070867495877, 0.16840290570897715, 0.14889042345540865, 0.11615216732025146, 0.11275818265442338, 0.13800551396395477, 0.16190608218312263, 0.08574389187352997, 0.09675091052693979, 0.10289380340171711, 0.16353080714387552], [0.05736240052751132, 0.09119712175535304, 0.0031119216873776168, 0.00819978442242635, 0.040121256573391814, 0.035004542741392336, 0.022167645760678818, 0.0815257178619504, 0.013900022255256772, 0.07612871139177255, 0.014063963101112416, 0.04451040444629533, 0.0344882250896522, 0.01466176941591714, 0.015893251102949892, 0.04453859079096999, 0.007958164887635835, 0.027113058338207856, 0.02958556530731065, 0.04048801153632147, 0.033492929568248134, 0.01616314858464258, 0.012053097431947078, 0.038662250220243416, 0.0372351350129715, 0.01743068592622876, 0.030658132396638393, 0.06608343470309462, 0.04564971563273242, 0.0757821292749473, 0.030390538541334014, 0.029438944067806005, 0.042455773268427165, 0.032646847290119956, 0.016019789402240088, 0.053199170889066796, 0.006077476161798196, 1.1952714622020721, 12.640580637114388, 32.858114515032085, 45.68756716591971, 37.71489838191441, 27.743882519858225, 21.366245678492955, 31.848353658403667, 18.59154336793082, 8.794435705457415, 5.121840272630964, 0.5958421730569431, 0.25724049657583237, 0.04970778252131172, 1.2022615671157837, 1.8846391567162104, 4.986608786242349, 4.6568959185055325, 7.137919587748391, 2.768035514014108, 0.94173321553639, 4.018028165612902, 1.2657587655952998, 4.5940698725836615, 7.888846584728785, 14.636661733899798, 22.00966797556196, 31.5633350781032, 38.562467438834055, 44.35703924724034, 47.27914237976074, 51.311050006321494, 49.901757308415, 48.20868975775582, 46.57713808332171, 46.99195943559919, 44.056922231401714, 47.27836765561785, 45.38004337038313, 47.70009551729475, 47.2318286214556, 50.85138150623867, 49.454189096178325, 48.65145329066685, 45.889655521937776, 46.52552686418806, 43.45109142575945, 46.4862938608442, 46.301951204027446, 49.94272041320801, 48.24457720347813, 55.86315883908953, 48.92139775412423, 32.07321473530361, 52.813313075474326, 43.71854496002197, 46.056363650730674, 41.148649488176616, 43.02550383976528, 43.45194258008684, 45.608767645699636, 46.923634324754985, 48.41767420087542, 46.699144976479666, 48.91910832268851, 47.98580891745431, 48.10765252794538, 47.73411737169538, 47.36591843196324, 47.51541587284633, 47.25620290211269, 47.65170478820801, 47.914464814322336, 45.31929874420166, 45.073606967926025, 45.5503819329398, 43.29758140019008, 41.556279454912456, 36.700913020542686, 35.77411018099104, 33.206386021205354, 30.132690565926687, 22.691986288343156, 11.32757260118212, 6.698092537266867, 4.837061839444297, 6.563064285687037, 0.8324238296066011, 9.286851934024266, 10.295645253998892, 6.442624645573752, 3.1325104364327023, 4.652396959917886, 1.0736080706119537, 0.7229032835790089, 0.46955578667776926, 1.430014614548002, 4.82294396843229, 11.987892048699514, 25.5571836744036, 33.81453057697841, 25.00717122214181, 34.489356994628906, 37.95881836754935, 19.267962660108292, 1.5740698788847243, 0.28563987410494257, 0.0396129049227706, 0.03502916677721909, 0.048051848342376094, 0.06422257955585207, 0.05503085581585765, 0.03197883634961077, 0.04587807998593364, 0.06066874561033078, 0.013849435773278986, 0.03481918733034815, 0.04971817767779742, 0.057008001687271256, 0.02979612150894744, 0.05276985499741776, 0.04234883275681308, 0.05717888394636767, 0.01708199526183307, 0.02971174567937851, 0.05181673721277288, 0.010641224665700324, 0.049102003420037885, 0.03774799552879163, 0.019990418571978807, 0.06989634010408606, 0.01575298773656998, 0.03515797307980912, 0.03510134254715272, 0.05830234794744423, 0.026539272163063288, 0.019820335287866846, 0.04375875049403735, 0.03971321614725249, 0.04073072011981692, 0.02724495197513274, 0.02208088318418179, 0.04146223176004631, 0.05151846678927541, 0.05638923542574048, 0.02402414132042655, 0.043790655210614204, 0.04769979044795036, 0.02878823916294745, 0.04847235684948308, 0.05766135627137763, 0.01795518840663135, 0.023851303184138875, 0.03700336780665176, 0.025855237618088722, 0.026744961572278823, 0.07480243327362196, 0.03357360738196543, 0.0313390321098268, 0.02498498761893383, 0.06852881384215184, 0.08511073727692876, 0.01155833768591817, 0.03770022666347878, 0.005594604773380394, 0.04308325870494757, 0.028905802140278474, 0.027198645352785076, 0.0597130697486656, 0.033382206223905087, 0.051329009634043486, 0.004720752601445253, 0.053217745785202296, 0.01330609800892749, 0.02035877657389002, 0.04957382953060525, 1.8667295234543937, 15.268129655293055, 38.49223504747663, 51.71306930269514, 41.58586141041347, 28.128937789372035, 16.675119025366648, 25.003434828349523, 19.147263765335083, 9.789023433412824, 4.370461208479745, 0.6712865818824086, 0.08221961491342102, 0.07369958995176212, 0.313547069472926, 2.632760601384299, 5.39887363570077, 6.1125048739569525, 6.084876665047236, 5.782503655978611, 4.326971130711692, 4.357068121433258, 3.568609344107764, 8.023441008159093, 11.196864826338631, 20.297610998153687, 28.13020236151559, 34.09955957957676, 40.60175677708217, 46.46782207489014, 50.17121539797102, 53.08801358086722, 50.88379485266549, 49.36391462598528, 50.28402635029384, 48.22338172367641, 47.13395629610334, 50.23688282285418, 48.944729804992676, 49.329395975385395, 49.64583083561489, 52.07100575310843, 50.57724380493164, 49.830545221056255, 50.03845269339425, 48.26928152356829, 45.75203602654593, 48.92000811440604, 47.58849355152675, 50.45890556062971, 49.96287366322109, 54.94444717679705, 47.18734972817557, 35.94643592834473, 53.67312485831124, 46.895730359213694, 48.154233251299175, 42.08993237359183, 44.88754115785871, 46.232663767678396, 48.51001228604998, 49.55591767174857, 50.0729991367885, 47.65576948438372, 50.79601131166731, 48.92540339061192, 49.47477313450405, 49.316944803510395, 49.54112843104771, 49.112375940595356, 50.39201177869524, 49.054775374276296, 49.87057726723807, 47.04327188219343, 46.971674169812886, 46.78537906919207, 43.949176515851704, 44.28780739648001, 40.80038145610264, 40.4659993989127, 39.17725447246006, 34.479452337537495, 25.979580300194876, 14.635631663458687, 7.1288860610553195, 5.85174115215029, 3.423730501106807, 6.4620088168552945, 9.360833747046334, 6.115390981946673, 5.95402558360781, 4.591127744742802, 2.547170954091208, 0.9115881302527019, 0.18477728563760007, 0.39315339497157503, 1.172260656952858, 5.994843644755227, 11.799726145608084, 24.484294959477015, 36.119070870535715, 25.236899512154714, 38.11552109037127, 43.746671267918174, 24.597811153956822, 2.7538501151970456, 0.2994007542729378, 0.11865446876202311, 0.021687304035627415, 0.03853698926312583, 0.05266569308670504, 0.03143263940832444, 0.06888600146131856, 0.031254459505102465, 0.02512486930936575, 0.024994958691032867, 0.024940411260883723, 0.05299300141632557, 0.1049796946878944, 0.022759898266355907, 0.04754019222621407, 0.022655436103897433, 0.0217962021207703, 0.023526234020079886, 0.02640785519698901, 0.04753316938877106, 0.08596981010798897, 0.012581001069130642, 0.06955004297196865, 0.07577527607125895, 0.015427540289238095, 0.014724182763269969, 0.05452025482164962, 0.04508649424782821, 0.02293759980238974, 0.014263579621911049, 0.04320399722616587, 0.03998138336464763, 0.042710159439593554, 0.13279112162334578, 0.10016892211777823, 0.16355971273566994, 0.09706144886357443, 0.12174858844705991, 0.10978862842811005, 0.09949856344610453, 0.18653477276010172, 0.12437772165451731, 0.14303951098450593, 0.1266248667878764, 0.07558260605271373, 0.1100195406803063, 0.21745920979550906, 0.15005427386079515, 0.13036185769098146, 0.15405270430658544, 0.23758539983204432, 0.10087373001234871, 0.15159439907542296, 0.16075065918266773, 0.16435669282717363, 0.1062428147665092, 0.09083103854209185, 0.10464753144021545, 0.08708878899259226, 0.10363814274647407, 0.25682713304247173, 0.12240416184067726, 0.20416122621723584, 0.09779105042772633, 0.14501479427729333, 0.09495781388665948, 0.17002347803541593, 0.11166867254567997, 0.08102881988244397, 0.11884071305394173, 2.0755218054567064, 18.396988596235, 43.46987935474941, 57.176309313092915, 50.38118648529053, 37.861349037715364, 30.733348437717982, 41.66506740025112, 28.01063254901341, 12.721263987677437, 6.716017586844308, 1.0985967240163257, 0.6290397973997253, 0.47414290053503855, 2.8474742685045515, 4.890132614544459, 11.214568836348397, 9.923762900488716, 12.827249203409467, 10.27934217453003, 5.98456335067749, 6.710901975631714, 3.1146444465432848, 7.184824705123901, 10.958508610725403, 21.865880216870988, 29.593444347381592, 35.74956566946847, 41.97598886489868, 48.301066058022634, 51.05371304920742, 54.4961633001055, 53.12177835191999, 52.67659337180001, 51.542341641017366, 51.192353929792134, 49.138028689793174, 52.76653780255999, 50.55625329698835, 51.06834595543997, 52.18504653658186, 53.70299168995449, 53.334160464150564, 51.24032081876482, 51.082436902182444, 50.215305192129954, 47.64785201208932, 50.25733137130737, 49.73777634756905, 51.910234860011506, 51.32852125167847, 56.660381249019075, 49.35778284072876, 38.45807075500488, 54.988057545253206, 48.597076688494, 49.2394619669233, 44.87287698473249, 47.25038031169346, 47.904334340776714, 50.81645291192191, 50.95877981185913, 51.250579833984375, 48.23105253492083, 52.01735871178763, 49.24436739512852, 50.52736268724714, 49.795269216809956, 50.196774346487864, 50.58706508363996, 50.32434327261788, 50.10655198778425, 51.8336136000497, 48.70318610327584, 48.99838726861136, 47.37818200247628, 43.71656819752285, 45.17733315059117, 43.168209416525706, 43.51378502164568, 43.47378771645682, 37.11032520021711, 28.574689047677175, 14.355069484029498, 9.277900917189461, 8.721557787486486, 10.58311220577785, 8.301705070904323, 17.207361459732056, 19.021120956965856, 13.756053124155317, 10.413405929292951, 9.913786155836922, 2.4445484493459975, 1.8325593684400832, 0.8600007412689072, 1.9023379555770328, 6.646858257906778, 16.150135721479142, 31.562900815691265, 42.31679800578526, 34.328613894326345, 43.93170527049473, 50.69211837223598, 29.825899805341447, 4.48558417388371, 0.5038741337401527, 0.357381707323449, 0.12780367210507393, 0.11269177443214826, 0.26521309305514607, 0.112597417352455, 0.11422833055257797, 0.12160981446504593, 0.1817892345466784, 0.11263084877282381, 0.1630324096019779, 0.08682286433343377, 0.180839190525668, 0.11929417800690446, 0.16548451302306993, 0.1472227472279753, 0.1361524619694267, 0.07041100213038069, 0.16033148738954747, 0.20076024585536548, 0.17887848216508115, 0.17234847827681474, 0.10556826274842024, 0.13994802401534148, 0.1687188180429595, 0.16514270779277596, 0.1391415987163782, 0.13638557946043356, 0.25130706067596165, 0.09049637150019407, 0.1342534731541361, 0.15415881361280168, 0.10337949876806565], [0.12206796130963735, 0.023337689494448047, 0.04850405461287924, 0.040562640210347514, 0.07492117690188543, 0.03330702793651393, 0.055806875960635285, 0.035040294751524925, 0.016124860549877797, 0.015333790498386537, 0.02391943658169891, 0.028952895863247768, 0.0942295558218445, 0.06194958223828247, 0.05806932545133999, 0.028567630465009382, 0.0462381581642798, 0.006483209568874112, 0.04022724713597979, 0.03276059690064617, 0.047042520716786385, 0.05990822320537908, 0.05393259260537369, 0.060397738723882606, 0.03698818219293441, 0.028923372804586376, 0.004105066888899143, 0.06075159473610776, 0.07089453297001974, 0.05218452015625579, 0.023953853574182307, 0.03670824578564082, 0.08278834939535175, 0.03384631399863532, 0.07262341984148536, 0.06784380559942552, 0.06538550036826304, 0.5629568376711437, 8.54672634601593, 25.60176852771214, 36.523073877607075, 39.89010143280029, 32.10913692201887, 36.19279473168509, 27.915299790246145, 25.43152376583644, 19.738303593226842, 6.71803560427257, 2.34719072495188, 0.19540824661297457, 0.32862153915422304, 0.42930956770266804, 2.2789763510227203, 5.290618530341557, 6.7522798010281155, 1.3609759019953864, 6.451887897082737, 4.223251461982727, 2.5615042192595343, 2.8526231007916585, 3.742766158921378, 5.007828150476728, 7.157500045640128, 15.784622260502406, 24.613953556333268, 30.262729576655797, 37.81227043696812, 41.89530985695975, 47.692563670022146, 48.31350333350045, 47.99516814095633, 48.465787002018516, 46.50954948152815, 45.80587761742728, 47.27862821306501, 47.57635504858834, 48.32893875667027, 49.979959283556255, 50.51817716870989, 47.974198477608816, 50.3740611076355, 46.81224080494472, 46.33923871176583, 43.986717632838655, 47.63511943817139, 49.188246795109336, 50.96408476148333, 48.68522500991821, 43.10620716639927, 30.68409960610526, 36.26874201638358, 53.204538345336914, 46.00678130558559, 45.31841632298061, 41.503223010471885, 40.08532844270979, 41.197088854653494, 45.89459569113595, 45.71221937452044, 44.99339696339199, 46.46142973218645, 46.06901284626552, 46.11234528677804, 46.04883527755737, 46.69168608529227, 46.95414386476789, 46.99465881075178, 46.25626332419259, 46.15354463032314, 44.60440901347569, 47.072499479566304, 47.9976486478533, 43.882598876953125, 42.97154065540859, 40.14320693697248, 38.84546061924526, 34.24660778045654, 32.16686255591256, 28.376132113592966, 29.534176213400706, 16.167994328907557, 1.4449199118784495, 3.802956666265215, 3.51395503112248, 10.433534860610962, 4.745870207037244, 4.879800643239703, 4.074992537498474, 2.056294620037079, 0.8487483507820538, 0.35366718950016157, 0.20138790431831563, 0.4820659639579909, 1.952822046620505, 7.8651158809661865, 18.990851129804337, 31.653380257742747, 37.94316407612392, 28.698294026511057, 39.08342252458845, 37.53397076470511, 12.314755286489214, 0.5592878631183079, 0.11214381669248853, 0.07024233189544507, 0.04256853900317635, 0.028504652237253528, 0.006652381495639149, 0.0599339125411851, 0.03334732273859637, 0.049882725812494755, 0.023600935636620437, 0.0703020633331367, 0.03552074504217931, 0.07033685860889298, 0.053237202776862044, 0.03331132306318198, 0.031819071886794906, 0.019275610767570988, 0.0487517775701625, 0.028471054575805153, 0.04189878762034433, 0.039964053580271344, 0.05157003205801759, 0.026253948187721626, 0.03216339787468314, 0.04490556288510561, 0.03097096418163606, 0.02676883413057242, 0.04360824464155095, 0.1029322627665741, 0.029722500459424088, 0.02096533090142267, 0.05848728945212705, 0.032798560934939554, 0.018592136013986807, 0.07167765059109245, 0.039476987573185136, 0.012091650943537908, 0.022596719076058695, 0.009525718184054961, 0.03168119017833045, 0.041105854990226884, 0.05127865894298468, 0.0062764841215019775, 0.025381896678092222, 0.03170390413807971, 0.023099718781720315, 0.04932526518989887, 0.07492135332099029, 0.039884451244558604, 0.022139072651043534, 0.015411996748298407, 0.03932018491572567, 0.029526125639677048, 0.05561710667929479, 0.0747441335448197, 0.03627406819058316, 0.04302597677867327, 0.03476585108520729, 0.028735815547406673, 0.03398830423663769, 0.04311129916459322, 0.0850132725068501, 0.008896278566680849, 0.06367917478616748, 0.0183907264644014, 0.050458059047481844, 0.033013042461659224, 0.013039052070650672, 0.10147774831524917, 0.027420187036373785, 0.015500109609482544, 0.8704882870827402, 10.957710436412267, 29.450592858450754, 42.80310589926583, 44.84978117261614, 35.64338329860142, 34.27460207257952, 36.27599246161324, 29.29594680241176, 17.376426764896937, 8.736330526215689, 1.6305770810161317, 0.41286006037678036, 0.1301821001938411, 0.28679943616901127, 0.928874596953392, 4.3231378964015414, 2.3843381830624173, 5.084414669445582, 6.086313205105918, 4.882754496165684, 6.648424642426627, 3.7678109407424927, 5.999466802392687, 8.19593003817967, 10.863348688398089, 18.91772481373378, 28.846500839505875, 33.19168015888759, 41.23230927331107, 44.094484192984446, 49.54937594277518, 52.39634820393154, 51.24474334716797, 51.04155370167324, 50.88174513408116, 47.563327176230295, 50.10192796162197, 50.354970932006836, 50.739181995391846, 51.29322092873709, 53.060731479099815, 51.05017989022391, 52.037140233176096, 48.81953368868147, 49.131195136478965, 46.124452522822786, 49.80017811911446, 50.651533944266184, 52.62577772140503, 50.755961894989014, 45.17716639382498, 33.92348527908325, 37.98194197246006, 54.59316710063389, 47.73551048551287, 45.74647399357387, 43.52019126074654, 42.546036447797505, 43.96894761494228, 47.16436856133597, 47.81886454990932, 46.6845919745309, 48.630643435886924, 47.59484420503889, 48.13302040100098, 47.991624559674946, 47.803439549037385, 50.10257066999163, 48.26085335867745, 48.402888434273855, 49.21962138584682, 47.64691053118025, 48.749513217381065, 48.3571241242545, 45.79269688470023, 45.225327832358225, 43.090851647513254, 40.8907219341823, 37.72078350612095, 36.44967310769217, 33.613477502550396, 30.012184483664377, 15.386803150177002, 4.975530317851475, 3.4965313374996185, 4.592543005943298, 9.524287513324193, 7.349469218935285, 6.595010365758624, 2.456979428018842, 2.7660207535539354, 1.3679170438221522, 0.9508733536515916, 0.17359235510230064, 0.4225548058748245, 2.0537446311541965, 9.232295547212873, 18.337543283190044, 30.707084247044154, 39.46810259137835, 30.96502569743565, 42.56649194444929, 43.06065477643694, 14.999998671667916, 1.1447282029049737, 0.1681876608303615, 0.031256607068436484, 0.020978355381105627, 0.048309437198830504, 0.012153049881037856, 0.03427681054121681, 0.047437010798603296, 0.04276791634038091, 0.07672831243170158, 0.06245895169143166, 0.016145981648670774, 0.08747314515390567, 0.04582346809495773, 0.06496801134198904, 0.05731998530349561, 0.06581261780645166, 0.03438257040189845, 0.017703105861853276, 0.041929172418479405, 0.10379881983889, 0.015049411383058344, 0.022906032656984668, 0.042138927948794196, 0.05471963215885418, 0.02848615197997008, 0.015651852092040435, 0.028659249655902386, 0.09447868673929147, 0.03887187682890466, 0.009415662348536509, 0.011449932386832578, 0.014697650347703269, 0.04403990487168942, 0.21682062691875867, 0.08074627790067877, 0.10691437444516591, 0.14554702357522079, 0.15857332173202718, 0.08558452435370002, 0.09601091380630221, 0.27195925105895313, 0.13009216716246946, 0.10446501909089939, 0.10758870254669871, 0.15715575351246766, 0.11156211540635143, 0.15007004301462853, 0.14049750167344296, 0.10145214040364538, 0.1290795486420393, 0.12289604544639587, 0.11827451629298073, 0.17295280870582375, 0.3658843753593308, 0.13428208019052232, 0.18578797711857728, 0.1799948758312634, 0.13985643535852432, 0.11623228873525347, 0.09844656275319201, 0.11424012349120208, 0.23839405072586878, 0.17724627974842275, 0.10530125243323189, 0.17319292867822306, 0.1903195053871189, 0.11111943237483501, 0.18926766754261085, 0.13212227608476365, 0.1419497023203543, 1.1762931091444833, 12.144890938486371, 33.35796792166573, 49.725147996629985, 52.381030900137766, 43.10310479572841, 45.49344491958618, 39.13972725187029, 36.79615545272827, 24.94791351045881, 9.728885037558419, 3.3347366707665578, 0.7132532671093941, 0.6463170360241617, 0.90481705644301, 4.145208426884242, 11.507463199751717, 14.863492625100271, 8.298929265567235, 12.562086837632314, 11.436906848634992, 5.611092899526868, 3.1197272709437778, 4.738414789949145, 7.259838325636728, 11.807639275278364, 21.564550740378245, 28.046876089913503, 33.574109009334016, 41.33382592882429, 46.20951236997332, 49.52601957321167, 53.88171672821045, 49.46541043690273, 53.11407627378191, 50.729683807918, 48.183457374572754, 50.451637744903564, 52.12448603766305, 51.90450259617397, 51.88924435206822, 55.09492778778076, 50.23698009763445, 53.097946030753, 49.87006657464163, 51.119102546146934, 47.978363922664094, 51.91133614948818, 51.48661708831787, 54.09637784957886, 49.634223869868684, 46.67753607886178, 38.24506677900042, 40.631710461207796, 55.3927275793893, 49.690160342625205, 48.442479269845144, 44.296325887952534, 44.64311395372663, 44.56504052025931, 49.776950291224885, 49.99098954881941, 48.38492039271763, 50.315129961286274, 49.16466808319092, 49.784676688058035, 49.22713238852364, 51.49794612612043, 50.4582211630685, 48.81946073259626, 49.11366135733468, 49.31807735988072, 47.553293977464946, 50.65132897240775, 50.231442383357454, 44.86640126364571, 44.96711540222168, 44.08780697413853, 44.2865879876273, 39.49803195680891, 39.15230349131993, 36.252174036843435, 36.35912765775408, 19.723090512411936, 4.797591294561114, 6.741831013134547, 8.184086833681379, 17.833333356039866, 9.593033858707972, 12.253354924065725, 10.330017123903547, 5.431989184447697, 3.8475406510489325, 1.6038933928523744, 0.8371256973062242, 0.8070339720164026, 2.783899337053299, 11.937132852418081, 25.73844654219491, 39.63729470116751, 43.99399587086269, 39.73106064115252, 49.51550347464425, 50.30845621653965, 19.181547914232524, 2.049933544227055, 0.35358864228640285, 0.16875940800777503, 0.1287932340055704, 0.22175414647374833, 0.11678203780736242, 0.1429884580097028, 0.10738430744303123, 0.08089963360024349, 0.14370713516005448, 0.14072589656072004, 0.1183263427977051, 0.18009205561663422, 0.14236352725752763, 0.17548492497631482, 0.11369057797959872, 0.16772040804581984, 0.1564814525523356, 0.11554376568113055, 0.12566393906516687, 0.27211463557822363, 0.10824283066072635, 0.12115444961403098, 0.2043890647057976, 0.1241747582597392, 0.1118099774633135, 0.11329365534973995, 0.14661693759262562, 0.11390707136264869, 0.23220448142715863, 0.10862757358700037, 0.0897465767338872, 0.10999602944191013, 0.07875738319541727], [0.06378622725605965, 0.014179111341945827, 0.03699522199375289, 0.08086990698107652, 0.029234901802348237, 0.059471375575023036, 0.06674475528831993, 0.034676857824836455, 0.04426455424566354, 0.020991693683234707, 0.021563462913036346, 0.01801843804839466, 0.03291974728927016, 0.014168926531315913, 0.07621076663157769, 0.024794405791908503, 0.06588771806231566, 0.051576678308525255, 0.061872921351875575, 0.029969941824674606, 0.035662877772535594, 0.031695883854159286, 0.04602938650974205, 0.04309927213138767, 0.03110343457332679, 0.06762448951069798, 0.03667192041341748, 0.05204266562525715, 0.008435871352308562, 0.05803179567945855, 0.03355122251170022, 0.07269204008792128, 0.03582539030217698, 0.13913383627576487, 0.02847541416329997, 0.056998698972165585, 0.0752905442246369, 0.18074353065873894, 3.7110940984317233, 14.725127935409546, 34.64124114172799, 40.71351160321917, 32.80433893203735, 20.060272693634033, 13.705064637320381, 22.201373985835485, 21.062307153429302, 8.240191800253731, 2.9078265385968343, 0.38318346281136784, 0.022072732282270278, 0.08505749263401542, 1.4563758628708976, 2.4274065920284817, 1.8911902223314558, 5.745259574481419, 3.9377651810646057, 4.405296436377934, 7.359864592552185, 4.311489675726209, 4.864124204431262, 4.262622560773577, 5.332968235015869, 9.245171427726746, 16.457909652165004, 21.812259231294902, 28.43180455480303, 33.57415764672415, 37.54548045567104, 42.92989662715367, 46.81538486480713, 46.142479624067036, 49.59124231338501, 50.09797443662371, 49.0708361353193, 47.59027576446533, 50.111665861947195, 49.12931912285941, 50.42964322226388, 50.92658185958862, 50.343204157693044, 47.55439874104091, 46.98141554423741, 47.78205646787371, 48.81771673474993, 49.383435589926584, 52.354283809661865, 47.290308134896414, 50.06871904645647, 39.304983207157676, 33.58786644254412, 54.64193303244454, 45.25956508091518, 47.031682286943706, 43.93450192042759, 41.38920307159424, 39.47424479893276, 39.98947804314749, 42.01448883329119, 43.12726715632847, 42.71370690209525, 44.8843206678118, 45.435729707990376, 45.08377913066319, 44.32951395852225, 47.01625381197248, 48.122889927455354, 46.89997223445347, 48.06057153429304, 48.78028678894043, 45.40629366465977, 45.04766239438738, 45.04184675216675, 42.76595040730068, 37.80894224984305, 34.175246306828086, 33.134843894413535, 26.83014576775687, 21.989127363477433, 13.559480769293648, 9.12396444593157, 3.7222272838865007, 2.351346181971686, 5.841113882405417, 4.780539980956486, 1.759737144623484, 1.768927548612867, 1.756810975926263, 3.1611048792089735, 0.7680501267313957, 0.8163527005485126, 0.06443902544145073, 0.9179095796176365, 3.545297703572682, 12.581928287233625, 21.751320055552892, 24.062039034707205, 33.28112779344831, 36.410565171922954, 42.82835217884609, 26.331537825720652, 7.5980279956545145, 0.1192053034901619, 0.05043652913134013, 0.0450907147356442, 0.028177986819563166, 0.03232008178851434, 0.06951730365731887, 0.06565510268722262, 0.022004943241232207, 0.010819668349410807, 0.06346300709992647, 0.01873981746445809, 0.04999930830672383, 0.03178798480491553, 0.058212543837726116, 0.039010420109012296, 0.04227639235822218, 0.0538745032224272, 0.06940927409699985, 0.04745230158524854, 0.05115049724866237, 0.01143583412548261, 0.049138929295752726, 0.014506578279126967, 0.0350970372424594, 0.03921468289835112, 0.07047504226544074, 0.046698075985269885, 0.023916372996089712, 0.042700897436589, 0.02215584264402943, 0.03284601088879364, 0.017341784268085445, 0.028854654170572758, 0.06331387188817773, 0.039174835929380994, 0.03785908867471984, 0.011766307820965136, 0.12538644538394042, 0.03466994355299643, 0.05307131792817797, 0.027380601303385835, 0.017071381277803863, 0.04244991072586604, 0.06268404889851809, 0.0038511268545075184, 0.026859177675630366, 0.010732230630570223, 0.024431470981133834, 0.019023723301610777, 0.028177048744899885, 0.01292023974071656, 0.010768219279790563, 0.020400408089959195, 0.03964393772184849, 0.012533109219345664, 0.04130767844617367, 0.04021216669519033, 0.05503092027668442, 0.03227839259696858, 0.04079479757430298, 0.023793586995452642, 0.014185320785535234, 0.011211202563052731, 0.10791197020028319, 0.026754087868279645, 0.009369577946407455, 0.028771862720272372, 0.05867298413068056, 0.07714197452047042, 0.023056467263294116, 0.09264193315591131, 0.3387245727436883, 4.628691443375178, 19.37274844305856, 39.18443543570382, 47.48743200302124, 36.852557454790386, 28.17798686027527, 19.646031515938894, 29.772822516305105, 22.399276052202495, 10.13559523650578, 3.221718792404447, 0.5821716466120311, 0.08663681003132037, 0.19679834773497923, 0.7053537081394876, 4.342024402959006, 1.905103555747441, 5.40155086347035, 6.436267043863024, 5.601630755833217, 8.969776102474757, 4.30643572977611, 5.535020981516157, 7.824273501123701, 9.576121943337576, 9.857644711221967, 19.886984620775493, 24.354863916124614, 32.46724360329764, 34.655439785548616, 41.76242903300694, 44.43111399241856, 50.21286290032523, 48.8690048626491, 51.20515251159668, 51.271552971431184, 51.99931424004691, 49.636120728084016, 52.53275523866926, 50.839288166591096, 51.1758519581386, 51.742553983415874, 52.06887265614101, 50.043323380606516, 50.192657538822715, 49.36237907409668, 51.899968896593364, 51.846016134534565, 53.60112067631313, 48.33764484950474, 50.37737887246268, 39.60718815667288, 36.10845054898943, 54.62261356626238, 46.87238788604736, 48.75830268859863, 45.1405737059457, 43.72395065852574, 40.468240192958284, 42.685434682028635, 44.55739055361067, 45.15853827340262, 43.651995113917756, 46.825636931828086, 47.5188239642552, 47.55263042449951, 47.37435007095337, 48.84465142658779, 50.39560399736677, 48.76105070114136, 49.951103414808, 50.14354419708252, 47.71432890210833, 47.82868582861764, 46.719638688223704, 44.69014630998884, 40.12755611964634, 39.52490758895874, 36.300734996795654, 31.44097035271781, 25.10977874483381, 19.474827902657644, 15.0137300491333, 4.3223731602941236, 4.2319623317037305, 7.92118958064488, 7.894452043942042, 0.4266308471560478, 1.2805523489202773, 0.6497697478958538, 1.6326848821980613, 0.16640817560255527, 0.050482174182044606, 0.07428294686334473, 0.7819746966872896, 3.60474670784814, 13.791860665593829, 24.32326177188328, 25.615131650652202, 38.59198686054775, 37.17419304166521, 46.643997124263215, 31.030033043452672, 8.978270275252205, 0.2619736854519163, 0.05670666767816458, 0.048393846955150366, 0.08727558289787599, 0.07144460095358746, 0.01343995176388749, 0.05835955523486648, 0.025557616891871606, 0.028435870838750685, 0.04251635966024228, 0.013097341621427663, 0.03046914343056934, 0.039800910013062615, 0.012770565093627997, 0.062068814411759377, 0.009027431752266628, 0.02472328344759132, 0.025667917848165547, 0.028121726088491932, 0.035546726148043356, 0.03840355874438371, 0.07761473700936351, 0.010466057457961142, 0.05933753454259463, 0.03448754994730864, 0.09487580614430563, 0.011293498682789505, 0.02523909728708012, 0.048654346726834774, 0.005056617257650942, 0.03152447912309851, 0.08692469886903252, 0.02452858121666525, 0.02355274947227112, 0.11849590869886534, 0.12535211151199682, 0.1879151165485382, 0.20839057570057257, 0.07288276949631316, 0.17925263994506427, 0.16159380679684027, 0.16435788704880647, 0.14076198105301174, 0.1507792749575206, 0.08695555864168064, 0.09126669873616525, 0.1440483975623335, 0.08216833123671156, 0.1594947858580521, 0.08563991995262248, 0.22263147868216038, 0.1290132693414177, 0.11980077225182738, 0.13791691086121968, 0.15187970948006424, 0.11791627694453512, 0.09452011808753014, 0.15761119978768484, 0.13919970845537527, 0.14977950789034367, 0.09268597686397177, 0.1343829512063946, 0.12144001786197935, 0.17396510152944497, 0.10219902425472226, 0.18424806903515542, 0.08536513362612043, 0.20330260800463812, 0.12870611010917596, 0.11898112909070083, 0.16572406302605355, 0.3948852877531733, 4.837820061615535, 20.97669666154044, 46.84557826178414, 53.888522488730295, 43.45352676936558, 30.67462226322719, 21.651920863560267, 33.63017054966518, 28.133103234427317, 12.097779546465192, 4.3843636853354315, 0.9024505977119718, 0.15278191678225994, 0.4716940405113356, 2.7771422139235904, 5.453595910753522, 7.00832656451634, 17.134752784456524, 14.121594377926417, 10.582653624670845, 14.07726400239127, 10.697686263493129, 7.157764511448996, 7.8316585677010675, 8.907624466078621, 13.615489329610552, 21.57363898413522, 26.300877162388392, 34.56843444279262, 37.68280117852347, 42.72635609763009, 45.791658129010884, 51.67337771824428, 49.56838968821934, 53.555109705243794, 51.41523824419294, 53.38349267414638, 50.75211954116821, 53.29741144180298, 51.419167450496126, 52.297523975372314, 55.98639208929879, 54.23517159053257, 51.68351861408779, 50.67709289278303, 52.62216465813773, 53.31289897646223, 52.957411766052246, 55.86794267381941, 47.05709532329014, 49.53173099245344, 42.35223381859915, 38.86822291782924, 54.59613398143223, 49.553437164851594, 50.90835673468453, 47.4665526662554, 46.26997559411185, 42.74254192624773, 42.89462409700666, 44.89750140053885, 46.83071953909737, 44.54996987751552, 48.43012537275042, 48.68703154155186, 48.10639490400042, 48.72542033876692, 49.95789875302996, 51.346913133348735, 49.39179079873221, 50.83199255807059, 51.180632318769185, 47.8845910344805, 47.4811612537929, 45.86632694516863, 44.55742529460362, 40.17687790734427, 41.147860867636545, 38.81744548252651, 30.068461418151855, 23.986793518066406, 17.079481601715088, 11.632225053650991, 5.948509582451411, 6.430936472756522, 9.683046902929034, 11.54997227873121, 6.37904862846647, 5.627237907477787, 5.437255918979645, 6.3010963542120795, 3.366426536015102, 1.6964036630732673, 0.27068558654614855, 1.1758399563176292, 5.127229903425489, 16.426330089569092, 28.030466181891306, 32.64131334849766, 42.62263338906424, 45.19787549972534, 54.22595827920096, 35.956833907536094, 11.548647778374807, 0.4189777049635138, 0.20440761585320744, 0.12000564911535808, 0.2069331096219165, 0.19712228035288198, 0.10464903100260667, 0.12350402639380523, 0.11452725236969334, 0.10884513905537979, 0.12392441954995904, 0.15614070583667072, 0.19784224671976908, 0.1586718721581357, 0.12307496156011309, 0.16266448077346596, 0.16215100618345396, 0.13378836454025336, 0.12306448497942515, 0.19127819394426687, 0.1289362556168011, 0.1637991541730506, 0.13095587438770703, 0.09995082060673408, 0.12378620196666036, 0.10282006700124059, 0.27730607986450195, 0.1471948322973081, 0.13452882266470365, 0.19721791307841027, 0.14567010982760362, 0.13737070374190807, 0.13521996486399854, 0.1491212203566517, 0.11319665198347398], [0.029083334042557647, 0.059318610200924535, 0.036208765980388434, 0.02304193813220731, 0.04074239431481276, 0.05243435335744705, 0.06499976678086178, 0.09550752903201751, 0.05058457190170884, 0.020950905246926204, 0.02018495456182531, 0.0556010864675045, 0.014084940011213933, 0.027868059164445316, 0.05529509431549481, 0.06271527508007628, 0.03242111565279109, 0.02797556116378733, 0.009618941262098295, 0.040696138582591496, 0.03459026657843164, 0.024611523641007285, 0.03051240003800818, 0.03337307992790427, 0.019325335510075092, 0.04259239968710712, 0.0237507850064763, 0.043516961325492175, 0.009146576564359878, 0.052187074840601, 0.07180542552045413, 0.028864231692360978, 0.009155041288717516, 0.028952006982373338, 0.011512855483618165, 0.04689568913142596, 0.015994961805907742, 0.05688666944791164, 0.5643341009105954, 9.007856573377337, 33.2448581968035, 41.890849113464355, 36.31441599982125, 26.45993706158229, 27.58286496571132, 27.432780402047293, 26.424355336597987, 18.035261903490337, 4.375852142061506, 1.5999451875686646, 0.16972269703234943, 0.20568149749721798, 0.13389420243246214, 5.30184942483902, 0.7974290102720261, 1.4098083845206668, 3.4216243284089223, 2.7182920575141907, 9.501183015959603, 2.700185703379767, 3.081090292760304, 3.387981585093907, 3.2697178167956213, 1.927025122301919, 7.865334749221802, 11.175605075699941, 17.084512097494944, 20.873594079698833, 27.46504783630371, 32.34707450866699, 39.419138635907856, 45.33522401537214, 46.818032128470286, 46.31579201562064, 47.7523946080889, 50.53012112208775, 50.08213254383632, 50.131037439618794, 48.87578630447388, 47.96596833637783, 47.00524091720581, 46.53642858777727, 48.02767876216343, 47.293921198163716, 50.46368244716099, 50.989105224609375, 52.21924557004656, 49.09945576531546, 50.07209587097168, 43.305328641619, 30.39530120577131, 52.07014070238386, 47.39742156437465, 45.761513369424, 45.733088288988384, 39.594712666102815, 39.37558037894112, 39.894913060324534, 38.86955349785941, 41.21727337156023, 43.350450243268696, 44.86561611720494, 46.40660497120449, 46.20582635062081, 46.5035114969526, 48.21882717950003, 48.08202757154192, 46.637729849134175, 47.977078505924766, 48.84446382522583, 47.36639090946743, 41.59842375346592, 40.567773137773784, 37.327647481645855, 32.82296705245972, 29.210122653416224, 25.53840616771153, 17.98123618534633, 15.358376332691737, 8.454757383891515, 3.613505780696869, 3.1366413576262335, 6.426471386637006, 6.999432436057499, 3.3669889058385576, 0.7161039827125413, 0.053152938905571184, 0.571671398622649, 0.6655402045164789, 0.11145915450262171, 0.106188084131905, 0.33178269809910227, 1.611719018646649, 6.290749183722904, 17.387905188969203, 20.55835952077593, 28.583521945135935, 41.48381321770804, 35.25215802873884, 38.40255812236241, 19.139893463679723, 2.5401500165462494, 0.013114965720368283, 0.11930393534047262, 0.10767625392015491, 0.03979565475934318, 0.07182648046208279, 0.06464166992477008, 0.0223733623112951, 0.07834049127995968, 0.03289239554266844, 0.03830440442210861, 0.020115966210141778, 0.01587442005984485, 0.06442547509712832, 0.021119982602873018, 0.033943191835922856, 0.017476156254165938, 0.029816952534019947, 0.033333921671978066, 0.13046433004949773, 0.02259380816082869, 0.05735879072121211, 0.03580210976568716, 0.027368046709203293, 0.030730515119752715, 0.017566487924861054, 0.010407574524703835, 0.02798095721352313, 0.03422736230173281, 0.029214460934911455, 0.09384617675095797, 0.0711546561547688, 0.05552885980744447, 0.05864357642297234, 0.02704339654051832, 0.0421413842455617, 0.11973123598311629, 0.0743929577459182, 0.035921609960496426, 0.05240038250173841, 0.06948446934776646, 0.03737738987963114, 0.04148177356858339, 0.042179667191313844, 0.021244687161275318, 0.05480988070900951, 0.04340031776311142, 0.043816788986857445, 0.05546597996726632, 0.10038908637527909, 0.06890250343297209, 0.05145909158246858, 0.04086267821756857, 0.028511698823422194, 0.009232753056234546, 0.01924103092668312, 0.018056882146213735, 0.040216180229825635, 0.03030223060133202, 0.024095736942919235, 0.0637626006667103, 0.047729442428265295, 0.04356581245415977, 0.027419818931126168, 0.02147198621449726, 0.035480837005057504, 0.1090126693514841, 0.023625566457797374, 0.07248828280717134, 0.05459613200010998, 0.02717738176163818, 0.033118127179997306, 0.0687000285834074, 1.093257901923997, 11.875740306718008, 37.600211415972026, 46.608891350882395, 42.24485288347517, 26.621809244155884, 23.989998374666484, 25.827908073152813, 28.484761987413677, 16.91131435121809, 4.93681799513953, 1.181651907307761, 0.15617076493799686, 0.03812965112073081, 0.10175920464098454, 1.3922025178159987, 1.2362050371510642, 3.2447073417050496, 8.344099504607064, 5.176422280924661, 5.038986478533063, 1.5671807399817874, 4.827519357204437, 4.997610824448722, 4.486541722502027, 4.017885727541787, 9.999961188861302, 14.473547560828072, 20.79721600668771, 24.608700718198502, 31.123246601649694, 37.352928502219065, 44.255602496010916, 48.28851761136736, 51.78671325956072, 48.390676975250244, 49.26621947969709, 50.88159922191075, 50.94641201836722, 51.4072756086077, 50.72658143724714, 50.57030255453927, 49.35709496906826, 48.9068204334804, 50.82261943817139, 49.461366585322786, 52.405151571546284, 52.646361759730745, 53.715772901262554, 48.8842214175633, 49.79290335518973, 44.39161695752825, 34.599805559430806, 52.78690297263009, 49.79315349033901, 48.800064836229595, 47.554287569863455, 42.13755185263497, 40.685399191720144, 41.79187897273472, 40.92014408111572, 43.49902009963989, 45.51200703212193, 46.583686760493684, 47.89960609163557, 48.921925817217144, 47.31571422304426, 49.74774006434849, 49.597249031066895, 48.91044739314488, 49.37378454208374, 50.558494091033936, 49.56618363516671, 44.513293811253135, 41.88870906829834, 41.42574712208339, 35.51131541388375, 33.12358086449759, 28.339391776493617, 21.58034920692444, 16.861179624285015, 12.302524719919477, 4.791301003524235, 3.236555801970618, 8.870202336992536, 12.006648710795812, 5.094574672835214, 1.3969805985689163, 0.132796332772289, 0.6286511868238449, 0.20649787011955464, 0.04426155512088111, 0.12412684011672225, 0.27747511650834766, 1.9331336745194025, 6.962700349943979, 18.794510671070643, 23.655868189675466, 30.10441139766148, 43.948394843510215, 39.27748571123396, 44.6566664150783, 22.665810687201365, 3.6655690670013428, 0.029329842422157526, 0.09995796558048044, 0.005624761838199837, 0.04474253127617495, 0.04698581215260284, 0.01974725876269596, 0.09229343757033348, 0.10344271109040294, 0.0335157894130264, 0.08159291318484715, 0.019523600049849068, 0.03338457091844507, 0.012498553127183445, 0.035018293253545246, 0.034562616276421716, 0.07838367324854646, 0.07618310954421759, 0.015615855809301138, 0.005940891303388136, 0.06380197605384247, 0.02335549086066229, 0.017888138968763605, 0.03673206915014556, 0.016044182736160498, 0.007460126121129308, 0.08438657077827624, 0.020842678911451782, 0.02104250917078129, 0.013225149629371507, 0.03793083357491663, 0.06793576745050293, 0.0304191625410957, 0.032747925259172916, 0.08784604085875408, 0.08390099076288086, 0.48346086910792757, 0.13968632662934916, 0.10119022588644709, 0.14703460303800447, 0.1433946155011654, 0.17875705153814384, 0.1677053174270051, 0.11998150683939457, 0.10621857749564306, 0.08315481937357358, 0.1633276401885918, 0.11343002731778792, 0.09125642571598291, 0.33022863577519146, 0.11093008039253098, 0.11413169359522206, 0.1931753507150071, 0.09749223039086376, 0.09834941010922194, 0.08598015098167316, 0.11245600386921849, 0.11515520938805171, 0.05974544265440532, 0.116019160885896, 0.1175233915980373, 0.09665714377271277, 0.16542215565485613, 0.07163323368877172, 0.08595305029302835, 0.13422558536486967, 0.2966401752616678, 0.20902419170098646, 0.11181247447218214, 0.09957552967326981, 0.1555302550217935, 0.10635334133569684, 0.1952345416482006, 1.3492979343448366, 13.865434271948677, 42.54986490522112, 54.90191725322178, 46.831904206957134, 36.61544322967529, 37.80053492954799, 38.523088523319785, 35.04902049473354, 23.836318118231638, 5.878566409860339, 2.1392246271882738, 0.3707195073366165, 0.6445053475243705, 0.7275265497820718, 10.336451155798775, 3.168821939400264, 7.742312550544739, 10.546850425856453, 11.763856070382253, 19.53980050768171, 5.572596839496067, 6.665756923811776, 6.249446485723768, 6.382051987307412, 3.8386217696326117, 11.000064049448286, 13.030725462096077, 20.834849187305995, 24.808077539716447, 32.38933345249721, 35.5104329926627, 43.64005463463919, 48.5725599697658, 50.885274818965364, 47.757699557713096, 50.911945479256765, 50.89955684116909, 51.75649206978934, 51.52750028882708, 53.516126837049214, 50.75228977203369, 51.33353090286255, 50.18618876593453, 52.17944976261684, 50.48062562942505, 55.356781073978965, 53.90984998430525, 54.5332110949925, 49.05733231135777, 49.5400584084647, 45.14307158333914, 37.45652266911098, 52.482551029750276, 51.059869153159006, 49.97031518391201, 50.02746411732265, 42.44902222497122, 43.324578625815256, 43.5961663382394, 42.240065574645996, 44.47516904558454, 47.07568522862026, 46.72610051291329, 49.97368506022862, 48.31674814224243, 49.90060043334961, 50.34987790243966, 50.47153738566807, 48.95384931564331, 51.03923300334385, 50.560147762298584, 49.18869147981916, 44.49427311761038, 42.64441251754761, 40.069496972220286, 36.21327454703194, 34.71818201882498, 29.192682674952916, 23.258031708853586, 18.450109311512538, 11.83119193145207, 6.8154467429433545, 4.903006758008685, 14.930528845105853, 12.756454876491002, 14.489516258239746, 3.750127341066088, 0.3610741049051285, 1.9009654692241122, 2.7263886630535126, 0.5195630575929369, 0.49022624322346275, 0.6359058661120278, 2.509243126426424, 8.821569289479937, 23.01164858681815, 29.69199412209647, 38.649257387433735, 48.965782846723286, 47.50606707164219, 50.754933561597554, 26.132789816175187, 4.725080328328269, 0.2011132604841675, 0.2909252276378018, 0.21004660826708588, 0.10310393212629215, 0.12252861873379775, 0.12832646976624215, 0.13766890631190368, 0.16037306801549026, 0.16898260531680925, 0.1380867888884885, 0.12505693520818437, 0.10442155892295496, 0.15381685910480364, 0.11791558483881609, 0.1247486767492124, 0.09469720894204718, 0.14732169120439462, 0.10917789262852498, 0.19116329082420894, 0.12075840229434626, 0.11338718461671046, 0.0885450608496155, 0.1272160064961229, 0.09434378040688378, 0.0649741045864565, 0.3247544052345412, 0.19577438410903725, 0.11833856999874115, 0.14754864759743214, 0.14710884833974497, 0.10693173815629312, 0.17644107581249305, 0.10895200832081692, 0.2284332380763122], [0.050714019419891496, 0.1077838424327118, 0.04103623729731355, 0.03543804180143135, 0.13149334197597845, 0.04822415213233658, 0.02319820983601468, 0.0254234264139086, 0.08130034924085651, 0.08348109972264085, 0.0414007870214326, 0.024189932870545557, 0.054916020549301586, 0.02936099735753877, 0.011787323746830225, 0.013466968483823751, 0.014355572007064308, 0.07969595997461251, 0.06845841583396707, 0.07217106090060302, 0.023505862702482512, 0.08913953216480357, 0.019457885629630516, 0.03582766678716455, 0.008795776504224964, 0.03500854270532727, 0.03854052443057299, 0.02184371992812625, 0.03350190658654485, 0.026672185298853686, 0.051977716253272126, 0.0213824535187866, 0.02697652521809297, 0.01459667585524065, 0.054418342254523716, 0.02929786985207881, 0.018016093709905232, 0.01426152535714209, 0.23890819028019905, 5.300854963915689, 20.36328363418579, 38.84650979723249, 39.272715772901265, 34.55099099023001, 22.543508495603287, 25.21290217127119, 20.165920053209575, 13.69551954950605, 8.537099616868154, 2.078442871570587, 0.8365802637168339, 0.10124330768095595, 0.16911206979836735, 0.09444730449467897, 1.1620246576411384, 1.3945570886135101, 8.804815445627485, 3.386777809688023, 2.271677051271711, 0.36167382129601067, 3.7497920904840742, 3.0269266963005066, 1.0496235404695784, 0.9765912422112056, 2.3210867771080563, 5.369749827044351, 9.19627434866769, 12.420981083597455, 18.98935031890869, 25.449761050088064, 30.572066852024623, 37.063508238111226, 43.3982503754752, 45.94272238867623, 47.86475740160261, 48.427790778023855, 49.59125620978219, 49.88038117544991, 49.08381189618792, 47.67366804395403, 47.31929949351719, 47.43199232646397, 49.12907941000802, 48.63103253500802, 49.73392704554966, 50.41142157145909, 52.142287322453086, 51.04503127506801, 50.79610858644758, 45.536065169743125, 29.273240089416504, 49.471246923719136, 51.154604366847444, 46.86217750821795, 45.8295362336295, 42.60489463806152, 41.844292708805625, 39.69031640461513, 42.21552106312343, 43.95266103744507, 46.48085342134748, 47.50712319782802, 47.918915135519846, 48.161171027592246, 48.86658341544015, 47.69840015683855, 47.40515143530709, 46.67307880946568, 46.23930624553135, 44.09735032490322, 37.5632643699646, 35.55552680151803, 31.692929404122488, 27.723145621163503, 24.822538478033884, 22.437558889389038, 12.964199934686933, 7.455275518553598, 6.210956505366734, 3.9568314722606113, 2.6702511268002644, 0.9832975566387177, 4.238974801131657, 4.360031093869891, 1.559602860893522, 0.3876586455319609, 0.22702662141195365, 0.10709236775125776, 0.04049955680966377, 0.08906922236617122, 0.1477633767894336, 0.425368962011167, 4.0654613460813245, 9.692223736218043, 20.241299322673253, 19.906201601028442, 32.56693288258144, 40.983320576804026, 33.85121011734009, 32.83671753747122, 9.907455478395734, 0.7580074284757886, 0.08831986864762646, 0.06585726541067873, 0.06415457677628313, 0.033254258268113644, 0.06376188820494072, 0.04347502786133971, 0.009919578076473303, 0.05313815362751484, 0.0050333681034057266, 0.036304985638707876, 0.035725330135651996, 0.047270450807575665, 0.04417525564453431, 0.013677605261494006, 0.04599866244409766, 0.032472097381417236, 0.03632749603795154, 0.04091942410117813, 0.008085864329976695, 0.017066882590630224, 0.05554122271548424, 0.03851572397564139, 0.054616654291749, 0.02477234322577715, 0.03571741163198437, 0.04592364361243589, 0.02049635294159608, 0.06570896479700293, 0.02676054582531963, 0.048331062109874826, 0.042651215102523565, 0.025415014276014905, 0.0649603438962783, 0.07224224600940943, 0.040268054232001305, 0.05726560750710113, 0.09155317622103862, 0.10237295992140259, 0.036852536257356405, 0.026048647239804268, 0.015565934291641628, 0.05302499434245484, 0.08906578219362668, 0.050285354921860356, 0.03593465479622994, 0.031245014297642877, 0.03751226907063808, 0.01713452235396419, 0.06698643589126212, 0.019442523596808314, 0.013518438757663327, 0.01223779296768563, 0.0602593311507787, 0.05178215567554746, 0.01270304322575352, 0.06144003636602845, 0.03965595118435366, 0.04635027589808617, 0.028245131252333522, 0.03423570828246219, 0.028985435010067055, 0.02595743177724736, 0.018888903482417976, 0.029762303323618004, 0.10133961894150291, 0.002043235394272155, 0.035477356120411835, 0.01693905337846705, 0.01836408717956926, 0.07801990383969885, 0.02519702641958637, 0.06247858849487134, 0.24273648485541344, 7.084190470831735, 26.196499586105347, 45.235847405024934, 42.37415885925293, 36.54445348467146, 24.010599783488683, 30.3879291670663, 26.68449589184352, 17.810214962278092, 10.059661848204476, 2.062091806105205, 0.6516647062131337, 0.16542687825858593, 0.3925577497908047, 0.6946431142943246, 1.5514923589570182, 1.6620981267520358, 4.961871462208884, 2.9424594002110616, 1.015523953097207, 1.6833812189953667, 2.1690343533243452, 1.5694790737969535, 2.2559967041015625, 1.8963961601257324, 3.397318661212921, 6.662733588899885, 11.794701729501996, 14.037393501826696, 21.02951339312962, 26.152581759861537, 32.715954371861045, 40.095556191035676, 44.77861424854824, 47.77231856754848, 49.37201622554234, 51.26724508830479, 52.713953835623606, 52.70322929109846, 52.3694725717817, 50.55597536904471, 51.189154284340994, 49.81130913325718, 49.763255391802105, 50.796205861227854, 50.619641712733674, 52.24678822926113, 52.58170529774257, 51.8469089780535, 49.59768329347883, 46.916463783809114, 33.0765380859375, 49.9735495703561, 51.20483636856079, 50.39699363708496, 47.76494305474417, 44.10130384990147, 43.814169543130056, 42.36900329589844, 43.93182338987078, 45.703308309827534, 48.316091537475586, 49.61994184766497, 50.28698628289359, 49.923199449266704, 51.10868372235979, 49.5775717326573, 51.71454232079642, 48.78979539871216, 47.429914815085276, 45.77973502022879, 41.292953150612966, 37.901294231414795, 34.60769523893084, 30.25450985772269, 27.27998604093279, 25.655445098876953, 17.129812615258352, 10.590577176639012, 8.756356971604482, 5.684439820902688, 0.3689319204006876, 1.3435262611934116, 5.8629151582717896, 3.792913479464395, 1.383669261421476, 0.1261176754321371, 0.16646218699003967, 0.08267696108669043, 0.16614406263189657, 0.035264353800032816, 0.026194856269285083, 0.329929347549166, 4.510536023548671, 9.930081418582372, 24.38041591644287, 17.88826928819929, 34.281623227255686, 45.30355412619454, 38.848080090114046, 38.18998493467058, 13.208089521953038, 1.0425497314759662, 0.03624620075736727, 0.05583815642499498, 0.00620215612330607, 0.02310546258065317, 0.07249660164649997, 0.018316116450088363, 0.02751231682486832, 0.07096448314509221, 0.04590507550165057, 0.1252356341906956, 0.061273435662899695, 0.028007764435772384, 0.11106254399887153, 0.029438034830881015, 0.04169369362560766, 0.02973251902897443, 0.09307215149913516, 0.021039903596309677, 0.03488246411351221, 0.021691897717703666, 0.019920356438628266, 0.02696049991729004, 0.050414809225393195, 0.02124909933523408, 0.03598239312746695, 0.09420474179621253, 0.05658530829740422, 0.0749642231634685, 0.05682480401758637, 0.02036169936348285, 0.08350860753229686, 0.04556196069877062, 0.03002082177304796, 0.04098115721717477, 0.14186207630804606, 0.26103087461420466, 0.13688878103026322, 0.1226264906248876, 0.21065654339534895, 0.12142612146479742, 0.08672347252390214, 0.15123539976775646, 0.17917543623064244, 0.18787688788558754, 0.19398332307381289, 0.08512243522065026, 0.16571195796132088, 0.07543161844036408, 0.16683869250118732, 0.07079150421278817, 0.09886340038584811, 0.13818611284451826, 0.14800660445221833, 0.15109096680368694, 0.15962490173322813, 0.18218636752239295, 0.09780413258288588, 0.10868136784327881, 0.07102200934397322, 0.1294546156589474, 0.11711521207221917, 0.07857107783534698, 0.11857852712273598, 0.12189664478812899, 0.13213985014174665, 0.11627388293189661, 0.12751956949276583, 0.2030421591230801, 0.1172003410756588, 0.2083635971482311, 0.2846272555845124, 0.10430864391050168, 0.35935998974101885, 8.29118549823761, 27.886838231767925, 51.80358695983887, 50.6462185723441, 46.66667257036482, 30.512784821646555, 35.01874719347273, 29.68161698750087, 19.621757984161377, 11.53539148398808, 2.7982430245195116, 1.1029464048998696, 0.7633999905415944, 0.6207602045365742, 2.1560937677110945, 3.500541316611426, 5.947156420775822, 14.098993624959673, 9.080235089574542, 7.362617816243853, 4.830046330179487, 9.153484736170087, 7.538645216396876, 5.306976326874324, 1.4676067573683602, 4.356035879680088, 7.616161925452096, 12.662576896803719, 14.145884411675588, 21.492834908621653, 26.439530202320643, 32.05782447542463, 39.15315464564732, 46.155246938977925, 47.02055822099958, 49.360958167484824, 51.42801250730242, 52.19728231430054, 53.309240749904085, 53.191555636269705, 51.43242808750698, 50.84494400024414, 52.437804630824495, 52.572325229644775, 52.81605413981846, 52.41097068786621, 53.43055977140154, 55.19380412782942, 51.5679874420166, 49.795387336185996, 48.69095032555716, 37.670047760009766, 51.112776211329866, 53.710106645311626, 52.0013986996242, 49.92887265341622, 45.249782017299104, 46.379513944898335, 42.58245195661272, 45.052091870989116, 46.82125956671578, 50.470880780901226, 51.094349588666645, 51.19511236463274, 50.914690017700195, 51.604194504874094, 50.263362407684326, 50.776243686676025, 49.34431028366089, 46.59196553911482, 45.95145974840437, 40.06179141998291, 37.97617149353027, 34.040333134787424, 31.798284939357213, 27.64952424594334, 27.054279020854406, 18.29943241391863, 9.8841746704919, 8.718692524092537, 7.5913655417306085, 5.039951843874795, 3.720381668635777, 9.304725306374685, 7.938602634838649, 7.850389174052647, 1.0881730147770472, 1.0386522263288498, 0.7144982431616101, 0.9891766011714935, 0.1537718858037676, 0.47184760655675617, 0.46035946586302345, 5.094692357948848, 13.003910626683917, 29.736115183149064, 28.262772253581456, 43.19833680561611, 49.60370738165719, 44.66555316107613, 42.57222768238613, 15.848008939198085, 1.767290813582284, 0.12185939321560518, 0.10556378441729716, 0.11000493182135479, 0.13204058046851838, 0.15956105158797332, 0.11449015007487365, 0.11122790298291615, 0.19183670968881675, 0.18022607985351766, 0.2111158844615732, 0.15217264661831514, 0.14518900135798113, 0.19289934981082166, 0.09622799072946821, 0.056873977450387816, 0.21589990918125423, 0.2084642510328974, 0.1257783943521125, 0.11144189935709749, 0.07592089647161109, 0.14211252358342918, 0.10408165359071322, 0.18399975235973084, 0.15251137129962444, 0.11365194898098707, 0.1274953322218997, 0.11041257530450821, 0.11164553450154406, 0.11173669568129949, 0.14657549267368658, 0.1412257868796587, 0.14962575185511792, 0.11540890006082398, 0.11878123267420701], [0.03803979612088629, 0.04105240339413285, 0.048403743388397355, 0.0191827295015433, 0.055450967379978726, 0.04879844381607004, 0.04151735255228622, 0.03387717377128346, 0.03823560097121766, 0.0680871553985136, 0.028384878932099258, 0.02913023777572172, 0.043313814726259024, 0.037313400634697506, 0.047634037011968236, 0.02233579013097499, 0.022689183043049913, 0.05062939253236566, 0.023623132213417972, 0.042357053208564005, 0.045634906605950425, 0.008071360643953085, 0.045163772601102076, 0.04873821704781481, 0.05744657279657466, 0.09101840920214142, 0.057200630993715355, 0.03611152512686593, 0.009757493023893662, 0.060881310275622776, 0.06912667104708296, 0.05229976593649813, 0.06424670826111521, 0.031178120922829424, 0.03685955230944923, 0.03191972237878612, 0.0710165471370731, 0.07749422919005156, 0.18200969057423727, 2.0040821645941054, 10.32777111870902, 34.05990621021816, 49.79981681278774, 38.151047229766846, 25.80722154889788, 15.700293711253575, 15.436505351747785, 16.774143014635357, 10.397833279200963, 4.962569756167276, 1.2223016917705536, 0.17471990388418945, 0.2065478374383279, 0.47745214296238764, 0.7737379329545158, 1.2931827626058032, 4.950523316860199, 1.6052003055810928, 0.79254947496312, 1.185084643108504, 1.1667930760553904, 0.8465942463704518, 1.142641680581229, 1.2905834849391664, 0.5641540448580469, 1.0225824543407984, 2.5207311042717526, 4.7938757453645975, 8.963756356920515, 13.292004653385707, 20.838047095707484, 27.794437612806046, 36.38443647112165, 40.89427246366228, 40.12683698109218, 44.85892500196184, 44.60539218357631, 49.16543238503592, 48.217819690704346, 47.42438057490757, 49.55939524514334, 50.09210320881435, 48.966689586639404, 48.93888636997768, 51.400268350328716, 52.357403550829204, 53.272404875074116, 51.574438844408306, 51.57772881644112, 45.688995020730154, 31.354569503239222, 50.59616722379412, 51.92164727619716, 48.725882393973215, 45.390510831560405, 43.670380047389436, 40.92645304543631, 42.54993438720703, 43.81334965569632, 44.036668232509065, 48.91649580001831, 48.35073178155081, 48.346642766680034, 49.12237787246704, 45.53520359311785, 46.92025055204119, 44.53603526524135, 44.820723806108745, 39.181569303785054, 35.589715412684846, 32.49946934836251, 26.643128054482595, 22.799261263438634, 20.279731546129497, 16.663385254996165, 12.370761241231646, 8.3607691015516, 4.133178489548819, 1.9436007014342715, 2.796690970659256, 0.045703431857483726, 2.097442937748773, 5.989196930612836, 1.7094604138817107, 1.443920674068587, 0.1692373545042106, 0.05502174648323229, 0.0574640247172543, 0.04277829114081604, 0.17310151644051075, 0.6329400166869164, 1.528855670775686, 4.460981471197946, 14.770140102931432, 22.175670862197876, 21.9551454612187, 35.56368398666382, 36.001597676958355, 35.296324253082275, 23.347196204321726, 5.032395243644714, 0.1653140921677862, 0.009857498059448386, 0.017742281081154943, 0.005270103458315134, 0.017266536430854882, 0.03195083660206624, 0.03843633537845952, 0.0620071559346148, 0.032511659365679534, 0.044153169329677305, 0.021022383822128177, 0.024760528234764934, 0.029800199504409517, 0.04442868508132441, 0.029173233147178377, 0.04646824938910348, 0.057053619596574984, 0.021316639014652798, 0.0372256999835372, 0.020160535782841698, 0.028461395629814694, 0.05321629711293748, 0.028814406865941625, 0.02435849284354065, 0.007225981497737978, 0.028829497484756366, 0.04210266703739762, 0.0545426057651639, 0.008144885002236282, 0.08759575643177543, 0.03422065159039838, 0.02519863624391811, 0.03268771206161805, 0.04110105096229485, 0.0820483323186636, 0.03532326081767678, 0.03962635009416512, 0.04440352161015783, 0.01867483925473477, 0.049645306409469674, 0.043279226403683424, 0.023260541759165268, 0.005605377364970211, 0.030466341080942323, 0.05395816659022655, 0.017574404732191136, 0.03398260793515614, 0.07269339037260839, 0.0697690062224865, 0.012641306717081793, 0.026114650037405745, 0.013226801862141915, 0.027078756696677635, 0.009021340204136712, 0.04277411136510117, 0.08117249288729259, 0.03766684613323637, 0.013586952134833803, 0.05966113467833825, 0.03581733948418072, 0.033207714158509455, 0.02596088552049228, 0.01989873661659658, 0.020056935359856913, 0.01719655402536903, 0.0017285530110322206, 0.06776168929146868, 0.04058431940419333, 0.0146588025215481, 0.053092159131275754, 0.019975743555862988, 0.015548119354727013, 0.062085160320358615, 0.19521099648305348, 2.9903225004673004, 13.484744208199636, 40.81091145106724, 53.823369230542866, 40.805085386548726, 25.807593277522496, 17.84262830870492, 16.97923125539507, 15.40055537223816, 11.81952851159232, 5.065399621214185, 1.2631960745368684, 0.21247013179319246, 0.11349397924329553, 0.26309416389891077, 0.5728204026818275, 1.7803856709173747, 1.6738045385905673, 1.7516901535647256, 0.9652476566178458, 0.7067801515970911, 1.2162697868687766, 0.48034042226416723, 0.7291374461991447, 0.9680197707244328, 1.0421666034630366, 2.1504244719232832, 3.7059771844318936, 6.041979789733887, 11.72889620917184, 16.15832417351859, 23.181757858821324, 30.264470100402832, 39.68371909005301, 42.947937624795095, 44.62688643591744, 47.36139862877982, 47.37713977268764, 52.401986667088096, 52.38401515143258, 52.71970346995762, 52.73370409011841, 52.71388782773699, 51.248634338378906, 51.44083193370274, 52.77645983014788, 53.46899025780814, 55.143919536045615, 52.40999446596418, 52.7354029246739, 46.63261597497122, 36.16052729742867, 51.63706990650722, 53.206452574048726, 49.87126166479928, 48.81376668385097, 46.32803821563721, 44.287209851401194, 43.44153765269688, 44.94459976468767, 47.373102869306294, 50.85118348257882, 50.89138923372541, 51.925086634499685, 51.45655223301479, 49.27933767863682, 49.9945296560015, 46.60477106911795, 46.15998213631766, 42.10944638933454, 38.721518652779714, 34.09287888663155, 27.908122301101685, 25.854974780763897, 22.41473231996809, 18.283295222691127, 15.120171240397863, 8.807551298822675, 4.395549850804465, 2.7912346805844988, 2.0230266451835632, 0.3902314603328705, 0.2044020247246538, 4.395090401172638, 0.8519419708422252, 0.40505270074520794, 0.06685057282447815, 0.03478784919051187, 0.027422209070729356, 0.05101346710164632, 0.14072158107800142, 0.32439285463520456, 1.3521395304373331, 5.343874301229205, 16.590981551579066, 22.097689492361887, 23.457615239279612, 37.944703102111816, 40.082854884011404, 41.05162484305245, 28.770895753587993, 6.1100669247763495, 0.2355625240930489, 0.08553324746234076, 0.08760769864810364, 0.058689452175583155, 0.04019666217001421, 0.018110282852181366, 0.035448158758559396, 0.018392756980444704, 0.01294980860049171, 0.012390524415033204, 0.029343518295458386, 0.01880145219287702, 0.03033595039908375, 0.030589172882693152, 0.024680204955594878, 0.025045031182734028, 0.056712323267545016, 0.016491603638444628, 0.04350247799551912, 0.05646299896761775, 0.02641583646514586, 0.03546692703717521, 0.009797641092778316, 0.06826704181730747, 0.032042890055371184, 0.040598765414740355, 0.03340957493388227, 0.06180436217359134, 0.03755892513852034, 0.11921701500458376, 0.024358260445296764, 0.02656668667415423, 0.03381828371701496, 0.06369830268834319, 0.06709723387445722, 0.12142735639853136, 0.14272315081741127, 0.13965367552425179, 0.09111439476587943, 0.1821297234190362, 0.11347042050744806, 0.12936137137668474, 0.13613978693527834, 0.1984864750078746, 0.1449135432818106, 0.0904693997332028, 0.1520626289503915, 0.10428014543971845, 0.18049829453229904, 0.10523745657077857, 0.06813780125230551, 0.11447113752365112, 0.1531933532761676, 0.07012886726962668, 0.1871485619672707, 0.19836893917194434, 0.10984579500343118, 0.13330013145293507, 0.11330692749470472, 0.09851732038493667, 0.1586470106350524, 0.10195286532065698, 0.14681316992001875, 0.11969135169472013, 0.14582226452018532, 0.11740966912891183, 0.20786739805979387, 0.1281871258148125, 0.047661086810486655, 0.17432184810084955, 0.06951732401336942, 0.12113665842584201, 0.1771046830607312, 0.3135546962065356, 2.964000552892685, 17.128919771739415, 45.00665760040283, 61.00601046425955, 47.3514974457877, 34.46235282080514, 24.03088504927499, 23.529199055262975, 23.880473920277186, 14.982777561460223, 6.312639483383723, 1.6829697553600584, 0.449139129370451, 0.3296283765562943, 0.756561660340854, 1.9398313036986758, 3.5583010401044572, 9.920448609760829, 5.297806441783905, 1.4789153848375594, 4.177200104509081, 5.751055674893515, 3.9725969348634993, 3.9775631598063876, 4.159222074917384, 1.5497149229049683, 2.8048633549894606, 4.07079712833677, 6.296384607042585, 10.766945038522993, 15.43693961415972, 23.884392704282487, 30.987916537693568, 37.82217509405953, 42.875836168016704, 43.54598297391619, 48.99074077606201, 47.56382049833025, 54.04309558868408, 55.08411986487252, 54.0278651373727, 54.40168864386422, 54.50868395396641, 52.08815390723092, 52.778884751456125, 53.52421801430838, 55.001846245356965, 56.29429108755929, 53.134788853781565, 52.28948490960257, 48.229173047201975, 40.222270488739014, 53.36845677239554, 54.935682024274556, 51.57239259992327, 49.826473576681956, 46.94444765363421, 44.56101751327515, 45.91111503328596, 47.25118977682931, 47.71083048411778, 52.44793163027082, 52.071370533534456, 52.083172048841206, 51.64297587530953, 48.51944446563721, 50.35745143890381, 44.816957882472444, 44.554646015167236, 39.728496755872456, 37.395958696092876, 35.86699717385428, 28.767366068703787, 26.329427310398646, 22.970226900918142, 18.386679206575664, 15.35361681665693, 9.773476839065552, 6.687019280024937, 3.890274677957807, 5.884566613606044, 1.7543695526463645, 7.346145374434335, 14.914511510304042, 8.629533239773341, 2.864675836903708, 0.2309244658265795, 0.24255740589329175, 0.30169398550476345, 0.17961322702467442, 0.7425654913697923, 0.6308340611202377, 2.933137740407671, 7.729053650583539, 19.07149887084961, 31.165425641196116, 32.633625166756765, 46.98021697998047, 45.26214286259243, 47.816147804260254, 32.964251722608296, 8.537745799337115, 0.4249689520469734, 0.11722387267010552, 0.16566800246281282, 0.13515143282711506, 0.14171036944857665, 0.11232875819717135, 0.15183553685035023, 0.11252328740166766, 0.12195897501494203, 0.16216296197048255, 0.05504444347960608, 0.14224801345595292, 0.10569869074970484, 0.16720271296799183, 0.12501401108290466, 0.08837028379951205, 0.1950501294008323, 0.08920872916600533, 0.19301562357161725, 0.1357038417564971, 0.15955657325685024, 0.165812096159373, 0.11110257756497179, 0.1298786729042019, 0.10654375861798014, 0.10156501470399754, 0.09941939876547881, 0.19588627453361238, 0.09676194350634303, 0.2638337942106383, 0.19357474999768393, 0.21320649156613009, 0.11016305083675043, 0.09370199484484536, 0.14387253485620022], [0.008902338732566153, 0.06003833229520491, 0.05695146614951747, 0.04457865489114608, 0.06538031636072056, 0.11913058321390833, 0.02976807426395161, 0.06122580250459058, 0.01660150256274002, 0.007298258199755634, 0.028067268564232757, 0.00263319127095331, 0.010892382706515491, 0.017838288697281053, 0.04166236227112157, 0.05251438656289663, 0.013494088680350354, 0.03501710581726261, 0.022092855934585844, 0.047286206390708685, 0.012925383036157914, 0.06326335495603935, 0.07514251502496855, 0.029850238069359745, 0.05006472586787172, 0.03588070108422211, 0.05015206689547215, 0.023452826709087406, 0.02144273117716823, 0.06871196401438542, 0.036514846341950555, 0.01917820197663137, 0.05515986907162836, 0.06465336108314139, 0.015700742236471603, 0.046728118123220544, 0.04560167535341211, 0.023136882144691687, 0.03958908834361604, 0.7421888772930417, 8.67467655454363, 23.69547986984253, 42.88662672042847, 42.401020595005576, 31.193326132638113, 23.72344810622079, 26.754406929016113, 25.327215671539307, 18.108742577689036, 8.395668166024343, 3.1108361823218207, 0.8672888587628091, 0.24402849695512227, 0.45807584268706186, 0.9828783848455974, 1.5200346069676536, 0.5751378440431186, 1.0484926125832965, 0.5151153962527002, 0.5519661445702825, 0.6787910163402557, 0.23668810512338365, 0.2125213611871004, 0.5014702741588865, 0.17465466952749661, 0.5219569834215301, 0.9488154926470348, 1.6275794761521476, 4.115639499255589, 5.0274520346096585, 9.68086690562112, 18.069367136274064, 20.254502637045725, 29.85433530807495, 32.073461396353586, 34.86790180206299, 39.25997625078474, 46.13533687591553, 46.95999424798148, 48.80865280968802, 50.10369627816336, 50.91895273753575, 50.10264362607683, 50.37578078678676, 50.27104711532593, 52.634341376168386, 52.10102891921997, 53.0332305090768, 50.00992686407906, 47.50719615391323, 35.26028394699097, 48.827624865940635, 51.33984681538173, 48.71527944292341, 46.57509878703526, 45.02728680201939, 42.25400366101946, 43.96778379167829, 43.35688427516392, 46.64384773799351, 48.142143385750906, 50.85736043112618, 50.78549868719918, 49.74018389838082, 46.22065380641392, 42.8271883555821, 38.772205761500764, 36.06828301293509, 30.008613109588623, 24.73573637008667, 20.94669607707432, 19.641570772443497, 15.339769056865148, 12.259442414556231, 9.070860232625689, 5.03644300358636, 2.541794785431453, 1.659800227199282, 1.0805970898696353, 0.7580899926168578, 0.18077356261866434, 0.41592125754271236, 0.8863141121608871, 0.6121058974947248, 0.14595725227679524, 0.10500538402370044, 0.06698282608496291, 0.11871932313910552, 0.07757028618029185, 0.14707566797733307, 0.4969870575836727, 3.5458657188074927, 10.183549097606114, 16.269648211342947, 25.303944417408534, 28.730960982186453, 39.95381988797869, 39.894972120012554, 32.038789885384695, 14.955344336373464, 1.8809705078601837, 0.08971779327839613, 0.024821801643286432, 0.04100826808384486, 0.02601634388390396, 0.06147436345262187, 0.03234277539221304, 0.03250619037342923, 0.031216892413794994, 0.04412811442411371, 0.060334241416837485, 0.03255960465009723, 0.025359666174543754, 0.022659844885181104, 0.07764643816543476, 0.0378430956043303, 0.06109982569302831, 0.0594165703015668, 0.0481017478076475, 0.04447231827569859, 0.051605543188218556, 0.018511551498834575, 0.0529592985819493, 0.06659377446132046, 0.0272121380216309, 0.026404197893238494, 0.022404505372313515, 0.021090654623029486, 0.024997581228879944, 0.0410748696886003, 0.026344200130552053, 0.01969718118198216, 0.05091235859851752, 0.07670078426599503, 0.047533776677612743, 0.018909556392048086, 0.03187758535412805, 0.07472628807382924, 0.08726068226886646, 0.058599546285612245, 0.047289314081094096, 0.04700679924072964, 0.04587461606466344, 0.03626795798274023, 0.046670106771801195, 0.0327603322719889, 0.04673886611791594, 0.01976130952659462, 0.006216105106951935, 0.02021570916154555, 0.06620663630643062, 0.016823688854596446, 0.05297333747148514, 0.03231238380872777, 0.06868689214544636, 0.036637603504849334, 0.04428770246782473, 0.029796420064355646, 0.026014299797160283, 0.037910355388053825, 0.02226835223180907, 0.0274818794402693, 0.05393859424761363, 0.002189948660088703, 0.06462847920400755, 0.1008837791159749, 0.013047571925978576, 0.025934507471642325, 0.027317492457638894, 0.005778694716614804, 0.02367209699670119, 0.05818858476621764, 0.016547845709802847, 0.05612211315227406, 0.07139871163027627, 0.9716006985732487, 11.122239436422076, 29.249734333583287, 49.71218613215855, 46.43096535546439, 34.85945974077497, 20.918719155447825, 23.881983416421072, 25.447183268410818, 19.033994231905254, 10.031646711485726, 2.9502066416399817, 0.8877288305333683, 0.27720470673271586, 0.23513849398919515, 0.5209274015256337, 0.893645384481975, 1.3015638100249427, 1.8603656249386924, 0.4139828458428383, 0.14047376651849064, 0.09541116348866906, 0.15865475950496538, 0.08789121093494551, 0.4294425334249224, 0.07851524118866239, 0.46029258945158547, 1.7300154651914323, 1.599375001021794, 3.8910137925829207, 6.655090570449829, 12.651948758534022, 19.894518205097743, 22.651903867721558, 32.627569811684744, 34.95206880569458, 37.684427056993755, 41.825643743787495, 49.890796525137766, 51.045941489083425, 52.93859951836722, 51.560149874006, 53.6811535017831, 54.05835383278983, 52.72407041277204, 54.099865845271516, 56.005649021693635, 54.070881434849326, 53.2295275415693, 51.80768639700753, 47.682700702122276, 38.09408589771816, 49.00545358657837, 53.19226435252598, 52.691354819706504, 49.78867885044643, 47.51374135698591, 43.93145513534546, 45.60896219526018, 47.13661050796509, 49.34590836933681, 50.09001874923706, 51.83351632526943, 51.98153032575335, 51.46855872017996, 48.43102169036865, 44.95290633610317, 42.69359186717442, 38.26103721346174, 32.291304792676655, 26.146390914916992, 23.891750846590313, 20.732095752443584, 17.054443768092565, 14.005926847457886, 10.451295324734279, 5.946659190314157, 3.888672249657767, 2.503853929894311, 1.8853804426533836, 1.3102088889905383, 0.6105467325874737, 1.7560194241149085, 0.37245514563151766, 0.2146903933691127, 0.03874319266261799, 0.014849954317989094, 0.11561544612050056, 0.05443738194714699, 0.252398280692952, 0.26466041271175655, 0.2791183111923081, 2.4350761004856656, 9.925664101328168, 20.00672119004386, 28.575550624302455, 30.398500851222447, 44.11044767924717, 45.1232761655535, 36.37318386350359, 17.806132895605906, 2.03784823843411, 0.07034719948257719, 0.03626336769333907, 0.019051170043115104, 0.04845744604244828, 0.0967117997684649, 0.008414441520082099, 0.025317471474409103, 0.02666328800842166, 0.027816449790926914, 0.07813971276794161, 0.021438602291579758, 0.016537679558885948, 0.013337103666604629, 0.0504070739261806, 0.03893607981236918, 0.010906670109501906, 0.047050021921417544, 0.029237137575234686, 0.020365997882825986, 0.008427464303427508, 0.021799854335508177, 0.009099783941305109, 0.03474357138786997, 0.02318608102255634, 0.061878234281071594, 0.0336612774990499, 0.05191271938383579, 0.06434369127133063, 0.060596522342945845, 0.048218442260154655, 0.078000151685306, 0.044301167995269806, 0.10558229485260588, 0.020009722893259356, 0.043633377578641684, 0.11874707522136824, 0.09831942564674787, 0.17195699071245535, 0.11373717297932931, 0.11133946092533213, 0.21509258821606636, 0.1325840191649539, 0.15557197135474, 0.08725725566702229, 0.08528978909764971, 0.16958267454590115, 0.16915549603956087, 0.09768198270882879, 0.12003969800259386, 0.17704859535608972, 0.13019130112869398, 0.1048755259918315, 0.08627234173140355, 0.15293639206460544, 0.11213318404874631, 0.06390962563455105, 0.14345049964530127, 0.20249920897185802, 0.09141440223902464, 0.14558071962424687, 0.08680657270763602, 0.14860261604189873, 0.10966687888971396, 0.14468539266714028, 0.13990552058177336, 0.08286612986453942, 0.19284508058003016, 0.11087928526103497, 0.13077026791870594, 0.09300387730555874, 0.09697979395943028, 0.1107104861044458, 0.09657232689538173, 0.14287674400423253, 1.2403950180326189, 12.880757280758449, 32.7381260735648, 55.40856947217669, 53.363196986062185, 43.335716588156565, 33.63405459267752, 37.48251240594046, 34.07429245540074, 23.10206549508231, 10.80818520273481, 4.149826373372759, 1.5567151244197572, 0.7793119081429073, 1.1636211148330142, 1.7394662094967706, 3.8333185570580617, 5.147339727197375, 10.179162178720746, 2.423048334462302, 0.9610423679862703, 1.7576691870178496, 0.7241378916161401, 0.6462618304150445, 1.4622599014214106, 0.7977489531040192, 1.8296715234007155, 2.0825694501399994, 2.5080167693751196, 5.14536817584719, 6.60192425761904, 12.558239272662572, 20.94137375695365, 23.53115497316633, 33.47672305788313, 36.546037673950195, 38.27357176371983, 43.92743212836129, 52.62529482160296, 53.221783774239675, 57.251992566244944, 53.870933123997276, 55.415333543504985, 55.39715705599104, 54.053114891052246, 55.15434878213065, 56.36831719534737, 54.58392947060721, 55.09794330596924, 51.74621220997402, 49.288766384124756, 42.57831083025251, 49.642276832035606, 55.10867827279227, 52.88137762887137, 50.7024781363351, 48.740845339638845, 45.26084354945591, 47.87412357330322, 47.57588951928275, 50.05204684393746, 50.64050715310233, 51.872478348868235, 51.92618792397635, 51.81436014175415, 49.26084157398769, 43.49884639467512, 41.9070279938834, 37.941013608660015, 32.25637967245919, 26.2318502834865, 23.306590931756155, 22.781734432492936, 19.042101042611257, 13.774812391826085, 11.612313253538948, 6.298373094626835, 4.510785290173121, 2.937478627477373, 2.8518772550991605, 3.5745385459491184, 1.4173883263553892, 2.2414534730570654, 4.558342669691358, 3.138924709388188, 0.2102943549730948, 0.2902988855327879, 0.3531468617064612, 0.39995896550161497, 0.5210058401737894, 0.3979817958814757, 0.755470521748066, 5.437104795660291, 12.331003648894173, 23.086056845528738, 33.33062328611101, 39.0648569379534, 48.56485441752842, 50.95407240731375, 42.957335063389365, 21.748750959123882, 3.1632473128182546, 0.27890926812376293, 0.12273690184312207, 0.10182758740016393, 0.07769493984856776, 0.15225858986377716, 0.10903649950133902, 0.06559024152479001, 0.18621592915483884, 0.0965448258710759, 0.18739644438028336, 0.10943559344325747, 0.09316823205777577, 0.10495220723428897, 0.14479197694786958, 0.12967945502272674, 0.12774162686296872, 0.12384151614138059, 0.2061584669032267, 0.09428366898958172, 0.07560314530772821, 0.14414948570941175, 0.090733967322324, 0.1566391305199691, 0.11029775360865252, 0.0968627127419625, 0.12006883429629461, 0.11124804868761982, 0.10462615080177784, 0.19615310164434568, 0.1590039607669626, 0.27804663298385485, 0.1585805956274271, 0.34218279431973186, 0.17544839265091078, 0.12941774406603404], [0.07258134388497897, 0.021919715850214874, 0.009292342849741024, 0.04604373752538647, 0.03348135715350509, 0.07485562363373381, 0.030504569743892977, 0.01854411100170442, 0.034963705111294985, 0.07576912175863981, 0.0851300483835595, 0.0664969135874084, 0.08032325202865259, 0.012952656751232488, 0.007883420862656618, 0.09133227236036744, 0.034836720675230026, 0.08524886665067502, 0.01595958468637296, 0.011524025866362666, 0.013601439705650722, 0.020464161543973854, 0.056305582235966406, 0.045733199188751836, 0.006222904027838792, 0.02871962570186172, 0.04439512134662696, 0.04494170844554901, 0.05727552090372358, 0.05594854728717889, 0.031571901935551844, 0.05379400522048984, 0.047109811034585745, 0.004348089294840715, 0.04695026709565094, 0.015200789153043712, 0.04108856252527662, 0.03088816933866058, 0.05268417638061302, 0.29348197472946985, 2.839178119386945, 16.437893629074097, 37.223167419433594, 43.06963184901646, 29.901253019060405, 25.96041543143136, 18.858510528291973, 18.178907224110194, 17.313086986541748, 11.765009471348353, 5.150807746819087, 1.4061104229518344, 0.3586748865033899, 0.21692223075245107, 0.6736801277313913, 0.6513008485947336, 0.5437953344413212, 0.9252324381044933, 0.32000088744929855, 0.09019531908312015, 0.031275022508842606, 0.1288977148277419, 0.10332556880478348, 0.19838685249643667, 0.19261740493987287, 0.26579516753554344, 0.7507243592824254, 0.17118074665112154, 1.502102283494813, 2.1973539079938615, 3.448072863476617, 6.989023166043418, 13.973339796066284, 18.87903724397932, 23.418660163879395, 27.293554135731288, 32.66780335562569, 38.538954734802246, 45.64695494515555, 48.70479461124965, 49.922601904187886, 51.671922070639475, 53.35318463189261, 54.29315083367484, 54.21758222579956, 54.80915880203247, 53.43298816680908, 50.64463438306536, 50.322237968444824, 49.57150942938668, 36.30174943378994, 47.5458767754691, 53.20598357064383, 51.24481977735247, 47.821928705487935, 47.16001551491873, 45.763385908944265, 45.769524642399375, 45.57547187805176, 45.945727484566824, 49.48950678961617, 49.57183946881975, 50.86002853938511, 46.45385619572231, 38.95288324356079, 34.64925241470337, 30.71116978781564, 28.217695815222605, 20.682676689965383, 17.09266233444214, 12.148655125073024, 9.188721656799316, 8.57860815525055, 5.534157233578818, 2.886032428060259, 1.5334137976169586, 0.5256859947528157, 0.1504314171948603, 0.17075405668999466, 0.9897929280996323, 0.4840882697275707, 0.26808953870620045, 0.028199114703706334, 0.11352397049111979, 0.01706365615661655, 0.057052574652646265, 0.03269864326076848, 0.07469539437443018, 0.042029337757932286, 0.24173854983278684, 1.9155938157013483, 7.838727491242545, 13.698339649609157, 31.003650733402797, 21.747573239462717, 35.553563935416086, 41.50292771203177, 38.700681005205425, 27.142667055130005, 7.464821474892752, 0.20379207602569036, 0.1173703276685306, 0.05267227487638593, 0.04521434720871704, 0.002542965409312663, 0.04541273388479437, 0.029040318315050433, 0.018420337732615213, 0.02841584218133773, 0.047377890042428455, 0.05179645919374057, 0.06781764807445662, 0.06391535925545863, 0.05019969666110618, 0.03651717032438942, 0.04478676836671574, 0.10025970331792321, 0.028079012309068015, 0.018143802482102598, 0.02433350239880383, 0.03736782592854329, 0.031025698208915334, 0.041069261596671174, 0.053274844507021565, 0.0223714301828295, 0.029454010937895094, 0.05819089178528104, 0.046117877654199085, 0.04841243202931114, 0.04533089577619519, 0.08196888265333005, 0.00793214900685208, 0.045329915293093236, 0.020029339340648482, 0.07634389520223651, 0.04690398761470403, 0.10170647568468537, 0.017719512838604193, 0.07131483113127095, 0.06143240284706865, 0.028144607985658304, 0.031005457509309053, 0.056534133186297755, 0.030721202226621763, 0.058981948266071935, 0.009585901695702757, 0.11608636299414293, 0.013500383788985866, 0.030203463044017553, 0.041261056305042336, 0.024118805437215736, 0.024186679295131137, 0.03788937169260212, 0.028187379440558807, 0.03435158170759678, 0.02906070489968572, 0.03347468715427177, 0.032719898370227644, 0.059512867991413386, 0.04227887579639043, 0.023960576159879565, 0.03849874024412461, 0.01457628927060536, 0.030113635185573782, 0.021503672103530595, 0.02235202068862106, 0.006847704586107284, 0.048746651238096614, 0.07177097629755735, 0.05031667270564607, 0.049179922988904376, 0.01662263383955828, 0.033226591002728255, 0.024043476175782934, 0.03430829795875719, 0.29831802951438086, 4.303907019751413, 20.66088887623378, 43.25607286180769, 49.34009967531477, 32.64067758832659, 27.95545516695295, 22.95720771380833, 23.733015775680542, 23.81310244968959, 12.692125848361425, 6.898037374019623, 1.8214282457317625, 0.06923431384244136, 0.05452248380918588, 0.11553125349538666, 0.42862511585865704, 0.16657063045672008, 0.44150840597493307, 0.39045537688902443, 0.06474978769464151, 0.0691688284277916, 0.17281125273023332, 0.045681956224143505, 0.18769726609545095, 0.7771022181425775, 1.3854815470320838, 0.8630495348146984, 0.22765938245824405, 1.0396433217184884, 2.349819532462529, 4.4169207726206094, 8.800577044487, 16.331980500902446, 19.24940402167184, 23.469392435891287, 28.00835701397487, 35.24420234135219, 40.20318031311035, 48.56873498644148, 50.913223947797505, 51.79840012959072, 54.105747495378765, 55.258589131491526, 55.719056674412315, 55.674727167402, 56.31790106637137, 56.03577988488333, 51.67410380499703, 52.08862638473511, 49.97867039271763, 39.46717153276716, 50.370534896850586, 55.44799702508109, 53.02874197278704, 50.57982506070818, 47.9619140625, 47.998458112989155, 46.7003470148359, 46.144484179360525, 48.896099363054546, 50.58013078144619, 52.431151730673655, 52.111690929957796, 49.92818130765642, 44.09356008257185, 36.936679295131135, 31.528138978140696, 28.729682513645717, 23.740469455718994, 20.541517087391444, 13.685395155634199, 10.827555043356758, 11.450361166681562, 8.114412903785706, 5.422674689974103, 2.3521873482636044, 0.747821857886655, 0.4283541089722088, 0.7497544341853687, 1.1514364715133394, 0.443653010896274, 0.2697330048041684, 0.13505206815898418, 0.08871397535715785, 0.02039638437729861, 0.11152493847267968, 0.01828058496383684, 0.03908429900184274, 0.013421393831127455, 0.2973020454602582, 1.7224740641457694, 8.670744742665972, 16.83130063329424, 32.985454150608604, 26.38453347342355, 39.04529081072126, 44.60295336587088, 43.21319900240217, 31.120172023773193, 9.079372644424438, 0.6044003452573503, 0.041693089729441066, 0.037358669098466635, 0.027221186286104575, 0.04036865383386612, 0.07038990647665092, 0.03103867858382208, 0.05292670515232852, 0.009200040034816732, 0.01868545663143907, 0.02192977343552879, 0.049927512516400645, 0.018364706342773776, 0.11643149304602828, 0.009312913487000125, 0.036100716064018865, 0.08101301001650946, 0.038715457543730736, 0.05596164979838899, 0.041820525391293425, 0.039737541627671034, 0.03587701324639576, 0.04192913170637829, 0.08175897784531116, 0.025771455506661108, 0.02639323446367468, 0.04329526697152427, 0.012217334288704609, 0.02903082561013954, 0.031732867405350716, 0.058330228951360495, 0.04464068656255092, 0.030149217561951706, 0.03029545203649572, 0.0646601328626275, 0.030458191875368357, 0.2480652103466647, 0.1261820276933057, 0.09035743466977562, 0.14586235236908707, 0.14577902826879705, 0.11870557601962771, 0.10764152649790049, 0.1480253455894334, 0.1227417601538556, 0.17313198266284807, 0.1807493796305997, 0.1815797979278224, 0.18296957335301808, 0.2120779656938144, 0.06114492113036769, 0.1494712901434728, 0.11268982025129454, 0.17546631954610348, 0.16287213963057312, 0.1646366020930665, 0.0993185481056571, 0.12562372907996178, 0.08472543116658926, 0.13020150629537447, 0.12798246608248778, 0.10645202746880905, 0.08563067152031831, 0.09327527774231774, 0.1732344821627651, 0.10321388872606413, 0.16463854270321981, 0.10445669346622058, 0.3487585314682552, 0.14219005299465998, 0.21379942260682583, 0.10888511155332838, 0.14103081662740025, 0.12194768419223172, 0.20210390804069384, 0.5216603821941784, 4.98089736700058, 24.258129358291626, 48.093099525996614, 55.42027718680245, 40.499500138419016, 36.473411628178184, 27.729649135044642, 26.959118230002268, 25.257268156324113, 15.146722044263567, 7.36802351474762, 2.4563953450747897, 0.7488728814891407, 0.275249928768192, 1.6452693726335252, 2.124412153448377, 1.8713203285421645, 2.2591800647122517, 1.3922014321599687, 0.36692893930843895, 0.45867360489709036, 0.5569192873580115, 0.27554129170519964, 0.840327514069421, 1.2752175437552589, 1.0035784798009055, 2.3078298313277106, 1.5444805409227098, 2.9678435581071034, 3.437771941934313, 4.400750577449799, 9.427711895533971, 16.54749972479684, 21.0412506375994, 25.85972908564976, 30.825839383261545, 36.394855294908794, 42.651777608054026, 51.1189774785723, 53.78325380597796, 54.20955010822841, 57.13465486254011, 57.31232377461025, 58.65603242601667, 56.231333460126606, 58.32354027884347, 56.039007323128835, 52.32194341932024, 51.95909806660244, 52.209594522203716, 43.23921305792672, 51.47481904711042, 56.83130693435669, 54.47698974609375, 52.32227693285261, 49.19132832118443, 49.62516689300537, 48.67116533006941, 48.54989842006138, 50.161411489759175, 52.292111328669954, 53.08805874415806, 52.40862219674246, 48.89657531465803, 44.775369439806255, 38.52239370346069, 32.69646120071411, 29.457607064928325, 23.189696175711497, 18.97280318396432, 15.082053422927856, 10.4524131161826, 10.59699296951294, 7.280258212770734, 4.59318528005055, 2.899742526667459, 1.6045199249471938, 1.229465393083436, 0.8803853988647461, 1.9899794927665164, 1.9966106797967638, 1.3264473719256265, 0.5804661895547594, 0.1979720504688365, 0.1222761222826583, 0.387435896056039, 0.08698132940168891, 0.1914059349468776, 0.13032905730817998, 0.45332628754632814, 2.119336494377681, 10.653244716780526, 18.632108688354492, 38.45672280447823, 32.453632082257954, 45.70428453172956, 51.46780136653355, 48.45909241267613, 36.11325522831508, 11.938760467938014, 0.8139782622456551, 0.1578694095036813, 0.13081382986690315, 0.1256747277719634, 0.13115849851497582, 0.19162419252097607, 0.13597319301749977, 0.11376713030040264, 0.16161534349833215, 0.10453146802527563, 0.09576928748616151, 0.14240654637770994, 0.13892665239317076, 0.12977875183735574, 0.09713574166276626, 0.15833472167806967, 0.22786538568990572, 0.11986680727984224, 0.14237145254654543, 0.19591912919921534, 0.09896649699658155, 0.171055014112166, 0.11691123087491308, 0.27083855548075264, 0.13287330578480447, 0.12535771621125086, 0.12940337269433907, 0.1431194016976016, 0.14031418865280493, 0.09429496659764222, 0.1043329354641693, 0.08976018814636127, 0.09614791002656732, 0.11896283578659807, 0.17451001943222114, 0.09786300228110381], [0.06426226028374263, 0.03745650367013045, 0.010860891896300018, 0.07037502620369196, 0.022841485316998193, 0.06775703454124075, 0.033373863635850806, 0.0427174129789429, 0.05702417117676564, 0.05169269761868885, 0.03073290695569345, 0.05869884988559144, 0.015064227195190532, 0.008351929785151566, 0.04862640126209174, 0.043031408451497555, 0.04621087766385504, 0.009936069870101554, 0.017321757307010036, 0.028343737657581056, 0.034968007023313215, 0.030215581679450612, 0.03479377280122467, 0.021744363741683106, 0.021764093843687857, 0.025216661526688507, 0.06439433033977236, 0.03851851614724312, 0.025357014798958386, 0.08892905060201883, 0.028571484543915306, 0.03330173875604357, 0.05377680096509201, 0.055575953530413766, 0.04020873670067106, 0.07232613329376493, 0.020851428620517254, 0.04002498941762107, 0.03134931191535933, 0.012605888885445893, 1.5378673757825578, 10.187592949186053, 29.043760197503225, 36.45843826021467, 41.17834956305367, 19.426305157797678, 14.980394329343524, 17.72352749960763, 18.912574461528234, 24.10986348560878, 6.52784560407911, 3.941122463771275, 0.8995655210954803, 0.13909088500908443, 0.057187196000346115, 0.23055395856499672, 0.07696276663669518, 0.08838918099978141, 0.06301364728382655, 0.009387952674712454, 0.12307623720594815, 0.025587652244472077, 0.0798548593052796, 0.10389127023518085, 0.029420952711786543, 0.8809292039700917, 0.3096783070691994, 0.5128797590732574, 0.027961201666455184, 0.6891609856060573, 1.1981289088726044, 2.9154940928731645, 5.990787199565342, 8.967055882726397, 15.9558310849326, 21.035923106329783, 27.487525258745464, 33.75269160951887, 41.23092310769217, 46.868066106523784, 51.35846103940691, 53.330439703805105, 54.05197538648333, 52.79862110955374, 53.22580330712454, 52.32919039045061, 51.46127005985805, 50.09986434664045, 51.991733755384175, 48.41532570975167, 37.39460379736764, 45.5147967338562, 50.60470655986241, 52.560172830309185, 49.788310595921104, 48.62802743911743, 46.68558209283011, 47.36236790248326, 47.85565526144845, 48.697353090558735, 50.53767728805542, 50.63780082975115, 50.84554501942226, 41.96090085165841, 36.27415813718523, 29.281796795981272, 25.676840339388164, 20.30829037938799, 14.630597693579537, 11.87102769102369, 8.198983771460396, 4.366697021893092, 4.03451624086925, 3.607953301497868, 1.047127508691379, 0.5580704084464482, 0.18631143974406378, 0.17896994868559496, 0.7307874262332916, 0.11240245388554675, 0.3697336773787226, 0.16215442599994795, 0.14007705423448766, 0.12336955432380949, 0.05354646207498653, 0.03233896881075842, 0.04209723536457334, 0.052777369772749286, 0.05447647234957133, 1.1722112596035004, 4.392683284623282, 16.95705955369132, 27.41239091328212, 19.27569600514003, 21.358588763645717, 38.15386125019619, 34.537907532283235, 32.543430600847515, 18.686775377818517, 1.8997035026550293, 0.11119726712682418, 0.037861751924668036, 0.025602888748315827, 0.019839207043073008, 0.005638240512260901, 0.012163856399378606, 0.05389160569757223, 0.02770720565292452, 0.006577675638254732, 0.005899699562827924, 0.03662014140614441, 0.05796256475150585, 0.03293492951031242, 0.017605228881750788, 0.04189269098320177, 0.047649436364216466, 0.04290205592821751, 0.12145799903997354, 0.01343367955580886, 0.006723358379011708, 0.026507901792813624, 0.052383049324687035, 0.07012030415769134, 0.04866726264091475, 0.018866045333977257, 0.04832680430263281, 0.054571389220654964, 0.044186471828392575, 0.041723783261009624, 0.0147599873598665, 0.007926532433235219, 0.0366272287044142, 0.00925830244419298, 0.03026578648548041, 0.0654697608468788, 0.033406911683934074, 0.03805606739063348, 0.07298361337078468, 0.029884351417422295, 0.03197175244401608, 0.02503802191599139, 0.018172575759568384, 0.03326442950804319, 0.023856032573218857, 0.06107531700815473, 0.010899034046035792, 0.019381289204050387, 0.028086559314812933, 0.002461967835967828, 0.010163284106446164, 0.033793245774826834, 0.06373530998826027, 0.018908455468980328, 0.018024300590955784, 0.03524090702246342, 0.024889466851683598, 0.017987412034666965, 0.056826717486338954, 0.04467661838446345, 0.07471533651862826, 0.011336877426531698, 0.0270754844615502, 0.018060468203787292, 0.019689413652356182, 0.04240953449958137, 0.03451219433918595, 0.025596922729164362, 0.06380940601229668, 0.07069076890391962, 0.022328677387642007, 0.020956141840932623, 0.042213509125368934, 0.06135495486004012, 0.009648065681436231, 0.03318234373416219, 0.01958627293684653, 2.0081370898655484, 13.434824006898062, 34.1657064301627, 42.88425043651036, 45.794968945639475, 24.546114819390432, 17.81301508631025, 18.374151604516165, 21.793518202645437, 27.156169142041886, 7.796871542930603, 4.4150195717811584, 0.9999049454927444, 0.3804245394255434, 0.08972377795726061, 0.10619274566748313, 0.10815654136240482, 0.13640581337468966, 0.18648730245019707, 0.08392513303884439, 0.05334032652899623, 0.1364293856812375, 0.0649220948772771, 0.18177765873926027, 0.13809247501194477, 1.4766318159443992, 1.4200514405965805, 0.949100694486073, 0.6719311901501247, 1.5390780993870325, 2.5400948652199338, 4.1272303972925455, 7.938800658498492, 13.109054241861616, 16.886314732687815, 21.963254008974346, 29.570428439549037, 35.039831502096995, 42.48794603347778, 47.43139478138515, 53.07805333818708, 55.588013648986816, 56.444664001464844, 54.9007499558585, 55.79988506862095, 54.59840256827218, 53.41442952837263, 51.67964499337332, 52.32860326766968, 49.44169623511178, 40.16975252968924, 48.99504518508911, 53.29872465133667, 55.3064900125776, 52.17167125429426, 50.185129165649414, 48.7969103540693, 49.68523406982422, 50.21161569867815, 49.143826961517334, 50.550114563533235, 53.104046549115864, 51.414279392787385, 43.287694113595144, 37.831235545022146, 31.350998129163468, 26.316392489842006, 23.624073232923234, 19.16629488127572, 13.54183234487261, 9.47303238936833, 4.50299288545336, 3.1048262076718465, 2.8186774594443182, 2.8452495421682085, 0.3634265586733818, 0.22415937669575214, 2.1150644379002705, 1.7505811559302467, 0.16147511745137827, 0.4678354018500873, 0.12042506518108503, 0.08360681190554585, 0.08451409464968102, 0.019993266722719585, 0.11236552122448172, 0.14309802784451417, 0.043500947899052074, 0.10686626631234374, 1.3880731165409088, 5.869187210287366, 15.721273796898977, 26.814930949892315, 26.94892348561968, 24.209108080182755, 39.17815773827689, 39.950814792088096, 37.64342226300921, 20.504276479993546, 2.8121381189141954, 0.07664831315300294, 0.05709722225687333, 0.02500354894436896, 0.07166458879198347, 0.01398863977686103, 0.06506988658968892, 0.09909550007432699, 0.04128164645018322, 0.06135289211358343, 0.013710135078456785, 0.007993061943644924, 0.046456208785197566, 0.01972127765683191, 0.016611139456342374, 0.044778602197766304, 0.008251562581530638, 0.039620487551603994, 0.02505325841983514, 0.014848526001774838, 0.027608734954680716, 0.029854991207165376, 0.08228500533316817, 0.08211746146636349, 0.046088605653494596, 0.05029132603002446, 0.036943398881703615, 0.045941075177064965, 0.03619734962869968, 0.07658989128789731, 0.01660396734119526, 0.045725823513099124, 0.06541421597025224, 0.06650194831724678, 0.027535169884296398, 0.026545010872983506, 0.03691854753664561, 0.15465669546808514, 0.1355565046625478, 0.1758273544588259, 0.09902314788528851, 0.21628196510885442, 0.13485849568886416, 0.1313677451440266, 0.21390935885054724, 0.13042144663631916, 0.09617715488587107, 0.17341191907014164, 0.10396321530320815, 0.05143285941864763, 0.1563124159084899, 0.1186516053442444, 0.10429195873439312, 0.11953892558813095, 0.0853490319901279, 0.05847506903644119, 0.11994783793176923, 0.09402640243726117, 0.10942756637398686, 0.10523058979638986, 0.13474493606814317, 0.07545105846864836, 0.0981769265074815, 0.06902281447712864, 0.15021100187940256, 0.13366958019988878, 0.20175176193671568, 0.0884319015645555, 0.13036022920693668, 0.10548209558640208, 0.19636090977915696, 0.18202351911791734, 0.12729063177747385, 0.12332382106355258, 0.14954364911786147, 0.14095852550651344, 0.09157606320721762, 2.460334756544658, 15.361277205603463, 39.579596860068186, 48.798511913844514, 54.34293120247977, 29.896097455705913, 26.382061651774816, 28.207772050585064, 26.87819950921195, 28.258023159844534, 8.99026026044573, 5.469592400959559, 1.4495809589113509, 0.564838171005249, 0.24237382145864622, 0.5874572172760963, 0.32791700267366, 0.6248574703931808, 0.2626046687364578, 0.2290600687265396, 0.3233854201223169, 0.1738438337509121, 0.17302600906363555, 0.3223135247826576, 0.4754805916122028, 2.9537217787333896, 1.9309962349278587, 1.298501717192786, 0.8165859537465232, 2.5320518910884857, 2.5959957284586768, 3.7468933888844083, 7.657620957919529, 11.129555021013532, 18.15149310656956, 24.72120247568403, 30.128403527396067, 37.61880132130214, 45.63247489929199, 51.90894596917288, 55.386460304260254, 57.80061190468924, 57.043925285339355, 56.027678285326274, 55.828674929482595, 54.166648456028526, 53.83857536315918, 52.124906403677805, 52.67908777509417, 51.13684824534825, 46.76245696204049, 51.556432587759836, 55.20171117782593, 57.688134465898784, 55.28050722394671, 53.29126228604998, 50.199800286974224, 51.71264198848179, 51.75866338184902, 51.259007998875205, 54.204328536987305, 53.74981212615967, 51.907823835100444, 43.67962115151541, 39.83019406454903, 32.653382369450156, 30.49773849759783, 23.495602778026036, 18.557943616594585, 15.547520194734846, 11.227762596947805, 6.452020347118378, 6.125126710959843, 5.651908789362226, 3.2590703538485934, 1.7652354495865958, 1.6028442148651396, 1.2501226046255656, 3.4080640503338406, 1.416981965303421, 1.348039767571858, 0.7356515995093754, 0.30607411903994425, 0.27108038536139895, 0.15568907292825834, 0.17025188649339335, 0.2763999913419996, 0.07841436338743993, 0.28551336803606575, 1.5482901079314095, 6.118487707206181, 18.233514853886195, 31.181180681501115, 28.81445574760437, 30.360358715057373, 44.56233419690813, 44.53669534410749, 44.79069716589791, 24.99781894683838, 4.528773307800293, 0.29509007558226585, 0.11880082876554557, 0.13845565409532615, 0.19317140164119856, 0.08236655845705952, 0.10281601614717926, 0.17855020692305906, 0.12707602472177573, 0.1502647011407784, 0.080018718726933, 0.09078657414231982, 0.11351314107222216, 0.08223616438252584, 0.1201267269040857, 0.1662989178938525, 0.16671160289219447, 0.14115159586071968, 0.18118913817618573, 0.06184260440724237, 0.09198813073869262, 0.09047241242868559, 0.20795225564922604, 0.181595539940255, 0.23170011277709687, 0.15625455044209957, 0.18634289662752831, 0.21677755351577485, 0.09423911638025727, 0.14922465623489448, 0.07171930585588727, 0.1287002611373152, 0.21325445042124816, 0.17856256983109883, 0.08497335429170302, 0.27814548196537153, 0.3146108495337622], [0.04537207606647696, 0.06315653997340373, 0.050653663729982715, 0.05197323452947395, 0.048532844853720496, 0.021649406158498356, 0.057616966510457654, 0.037739944710795365, 0.06257235524909836, 0.007683219105404402, 0.07938698905387095, 0.050190244668296406, 0.06012259955917086, 0.041072929078446965, 0.0076148668803008536, 0.09652240707405976, 0.04924390544848783, 0.05945550464093685, 0.011490901483089795, 0.023039385144199644, 0.008464821048879197, 0.011621991056017578, 0.022992925851472786, 0.0421716570854187, 0.0642548438959888, 0.0666012926293271, 0.11128969038171427, 0.04355670312153442, 0.018044522630849054, 0.05016201421884554, 0.017763118891577636, 0.06329311550195728, 0.03327879748706307, 0.036165180283465555, 0.10234376255955015, 0.038040199849222384, 0.053509637979524474, 0.054890633161578856, 0.02849818579852581, 0.04761676490306854, 0.15491814858147077, 5.142127709729331, 20.109005621501378, 35.158416407448904, 42.16947882516043, 39.33194916588919, 29.04414929662432, 27.55693081447056, 24.422923258372716, 15.828058923993792, 14.374630400112697, 5.421256388936724, 2.084389226777213, 1.0305842821087157, 0.15380985662341118, 0.09246439446828195, 0.04116346600598522, 0.027184005959757736, 0.08953916893473693, 0.06925749938402857, 0.032836277303951125, 0.1381630426538842, 0.027689129480027726, 0.10463748233658926, 0.2073550091258117, 1.3747335523366928, 1.2117808163166046, 0.9770542745079313, 0.627254381775856, 0.3856381039534296, 0.7268619111606053, 0.6364798524550029, 2.787620314529964, 4.282221691949027, 6.983338236808777, 10.46648929800306, 17.814739976610454, 23.143858909606934, 31.83771596636091, 38.24182197025844, 47.11894471304757, 48.11011913844517, 49.68346922738211, 51.4069698878697, 53.76944078717913, 52.799215180533274, 51.40022666113717, 50.8498980658395, 49.7589544568743, 50.960120814187185, 40.40206554957798, 46.26511880329677, 51.54556213106428, 53.31539337975638, 50.13642576762608, 50.07181794302804, 48.916120597294395, 48.77779585974557, 48.00114706584385, 46.18138606207711, 50.4089480127607, 51.189796992710654, 45.65803037370954, 37.59794282913208, 29.694036892482213, 25.447584526879446, 19.558887209211075, 11.211218067577907, 13.117524964468819, 8.739509327071053, 3.6785895568983893, 1.912898566041674, 1.288817665406636, 0.8033627718687057, 3.445492693356105, 0.3649904190429619, 0.33336927582110676, 0.8416244930454663, 0.4810827395745686, 0.45823271998337334, 0.021098432330680744, 0.17523415200412273, 0.04652884935161897, 0.02505664770225329, 0.019605175226128528, 0.030059308279305696, 0.04270708906863417, 0.14131878688931465, 0.4350037792963641, 1.3737573304346629, 7.872397593089512, 17.822487218039377, 28.458909477506364, 27.036298819950648, 19.150979314531597, 34.75881161008562, 35.99703965868269, 28.135465621948242, 9.09336371081216, 1.0942628937108176, 0.05066302412056497, 0.027391043957322836, 0.023873954379398907, 0.02609852804536266, 0.05096955231523939, 0.03424560132303408, 0.01761964944723461, 0.04228369000234774, 0.012296412456115442, 0.014579128939658403, 0.0955683800524899, 0.03377312381884881, 0.04513381528002875, 0.04280236895595278, 0.006594870563796056, 0.022268465886424695, 0.0408090943071459, 0.032627030674900324, 0.04026200169963496, 0.06206757269267525, 0.0448887487873435, 0.031132455516074384, 0.011455139294931931, 0.01377761538606137, 0.07323113616023745, 0.010414285236038268, 0.0392534543893167, 0.030638380242245536, 0.025906563703236834, 0.01602623887759234, 0.009562333629998778, 0.03800373537732022, 0.03938495108325567, 0.05466101351859314, 0.030714179389178753, 0.05064449332920568, 0.051674109151852984, 0.014870573300868273, 0.08091727551072836, 0.07378250693104096, 0.06580425146967173, 0.02414019964635372, 0.07471442728170327, 0.06952124594577722, 0.04187524924054742, 0.03491302872342723, 0.09844846943659441, 0.018297148003642048, 0.028553099637585025, 0.04413684716980372, 0.02741618367976376, 0.03606005485302635, 0.039219079805271964, 0.06004019148115601, 0.020437754657385603, 0.06854611648512737, 0.054963691027036736, 0.037574439841721735, 0.00924810575920024, 0.019458581128024628, 0.031923142195280106, 0.03511570713349751, 0.06616392931235687, 0.09237813909671136, 0.07612338489187614, 0.07263100586299386, 0.034008158171283345, 0.05069030462098973, 0.026542425654562454, 0.02268326112867466, 0.05765097468559231, 0.06572305118399006, 0.06465763585375887, 0.06285092780100447, 0.04463204202641334, 0.044109434355050325, 0.21981333275990828, 6.413910346371787, 24.752856731414795, 40.78406361171177, 48.3193815095084, 38.70611449650356, 30.13522665841239, 29.05620789527893, 27.25069417272295, 22.66980937549046, 16.81214792387826, 7.918542316981724, 2.2323750002043585, 0.7443500927516392, 0.11538767548544065, 0.026557943750438944, 0.022913304856047034, 0.08768608301345791, 0.04705837129482201, 0.021848895453980992, 0.11414200732750551, 0.1447610357510192, 0.04620392946526408, 0.1888171202902283, 0.5732161243047033, 2.473067330462592, 2.6445215131555284, 1.5537285932472773, 1.2073429801634379, 1.472837122423308, 2.404142503227506, 3.1560085926737105, 5.340596922806331, 6.862869501113892, 8.491909401757376, 13.746866737093244, 21.696094036102295, 25.263094220842632, 34.082814420972554, 40.962729590279714, 45.758188656398225, 48.907685484204976, 49.92090654373169, 52.10020208358765, 55.68908214569092, 53.75871624265398, 53.065192222595215, 53.06993784223284, 51.6924227305821, 49.82852676936558, 43.41430071422032, 48.975058691842214, 53.08814559664045, 55.18131126676287, 53.10805565970284, 51.007319927215576, 51.08547673906599, 49.77077681677682, 49.18349422727312, 49.61824996130807, 52.69245958328247, 54.1785819871085, 48.24212448937552, 38.77698612213135, 31.43481077466692, 27.476891040802002, 20.510448217391968, 16.698739426476614, 16.44145631790161, 10.535592607089452, 4.305292316845485, 0.9203793385199138, 1.413983817611422, 2.3018198566777364, 0.2351034272994314, 0.9468872589724404, 0.5340351781674794, 1.81719505574022, 1.709611320069858, 0.1798175610601902, 0.10045783554336854, 0.15841797792485782, 0.04428963968530297, 0.1039861294307879, 0.024570316209324768, 0.09749187076730387, 0.11097537939037595, 0.0979510150583727, 0.5845372368182454, 1.9568014102322715, 9.53559136390686, 25.30827488218035, 34.94792767933437, 24.874616963522776, 22.273982661111013, 40.15991735458374, 38.68668038504464, 32.408312456948416, 11.226949657712664, 1.2247364925486701, 0.08505711943975516, 0.04776274153430547, 0.06798994168639183, 0.05442961272118347, 0.018967201334557364, 0.03997987701690622, 0.002012135165776791, 0.006111995782703161, 0.06660972681960889, 0.017343254992738366, 0.03427168760182602, 0.022176916245371103, 0.04102660210004874, 0.015760763747883693, 0.04827940523890512, 0.023644453480041454, 0.03410603006237319, 0.04680103010364941, 0.04201532940247229, 0.06831872582967792, 0.017650970623695424, 0.037896177398839166, 0.008461519127844699, 0.09137004640485559, 0.0737347516364285, 0.022287602270288125, 0.04687418635668499, 0.040762587516967735, 0.023475442281258956, 0.04118728258513978, 0.041214267922831435, 0.03504888839753611, 0.04031694268009492, 0.03001868099506412, 0.050809804815799, 0.051046915485390594, 0.12399310086454664, 0.12454651402575628, 0.19244591199925967, 0.1271583717316389, 0.11726371624640056, 0.09598910569080285, 0.15304080503327505, 0.18853812026126043, 0.20311915927699634, 0.08112692926079035, 0.15010988659092359, 0.16374905114727362, 0.12455943333251135, 0.16053546858685358, 0.12457440181502275, 0.1884438581764698, 0.0902526688628963, 0.17261614677097115, 0.06212067484323468, 0.20954861784619944, 0.23354553803801537, 0.10334215220063925, 0.11870727235717432, 0.09682995985661234, 0.10893287363329104, 0.20535694062709808, 0.24919380407248223, 0.22190944956881659, 0.18431993946433067, 0.126270929351449, 0.17345679737627506, 0.18824782940958226, 0.08821810196552958, 0.12306354860109942, 0.13970684552831308, 0.12933737837842532, 0.16846271178552083, 0.22564318350383214, 0.09825220996780054, 0.16396483885390417, 0.32063887321523254, 8.216607877186366, 26.907421895435878, 46.195035798209055, 53.35169424329485, 50.87768043790545, 40.31973287037441, 40.784025396619526, 32.436994620731895, 22.882224491664342, 19.62087903703962, 7.710147602217538, 3.156664328915732, 2.3691993611199513, 0.3319735564291477, 0.2314718264554228, 0.14552083212350095, 0.13127660432032176, 0.11096951684781484, 0.2735988087952137, 0.27013024634548594, 0.3534612948341029, 0.14279491268098354, 0.7211263360721725, 0.8147551034178052, 4.876247073922839, 3.87759074143001, 1.213381941829409, 1.075129617537771, 1.1408612046922957, 2.572630673646927, 2.420695500714438, 5.255156661782946, 5.874607673713139, 8.581022654260908, 12.01991890157972, 21.84149203981672, 25.877017940793717, 35.149720736912315, 41.30186768940517, 49.71281841823033, 50.883409227643696, 51.00326565333775, 53.45866176060268, 56.44311107907976, 52.5494760785784, 53.26596736907959, 53.45950249263218, 51.734921387263704, 52.03134890965053, 49.34834023884365, 52.200805050986155, 57.09122167314802, 56.85240166527884, 54.79259429659162, 51.246178150177, 51.96878732953753, 51.773956366947715, 51.29659080505371, 49.82535491670881, 53.23779589789254, 55.41491665158953, 48.59888322012765, 39.40248032978603, 33.47103248323713, 29.696715423039027, 21.557507004056657, 13.87052035331726, 15.499570676258632, 14.193465675626483, 5.3574793083327155, 2.9741707614489963, 2.557938490595136, 1.9838505302156721, 6.279282050473349, 0.6886080609900611, 0.5745393761566707, 3.14239924294608, 1.9598223567008972, 1.627635930265699, 0.2815010276223932, 0.732648240668433, 0.3528322385890143, 0.22176243817167623, 0.22733648121356964, 0.37000756125364986, 0.22760649743889058, 0.36085482952850206, 0.6978607816355569, 2.2482594507081166, 10.093635933739797, 24.441514900752477, 34.06000695909773, 34.10162319455828, 30.009387833731516, 45.999221665518625, 44.79282331466675, 38.5078615461077, 14.246473482676915, 1.597732077751841, 0.1873334084770509, 0.2385705512549196, 0.15489239139216288, 0.13149305699127062, 0.12067172623106412, 0.1843932212463447, 0.07165776951504604, 0.14136964987431253, 0.1212913915514946, 0.12504160031676292, 0.19831884971686772, 0.15331042770828518, 0.09761548627700124, 0.09623485071850674, 0.11779602696853024, 0.09243044057594878, 0.179459118151239, 0.10304732873503651, 0.10426789109728166, 0.2014828585088253, 0.10921420103737287, 0.08851560564445597, 0.04075990051829389, 0.2320930931184973, 0.1702628651899951, 0.08010754574622427, 0.12267805928630487, 0.19510400508131298, 0.13697998970746994, 0.06385524105280638, 0.14467012562922069, 0.11745692230761051, 0.10709267987736634, 0.08199656688209091, 0.1208698313151087, 0.13772249700767653], [0.07401195354759693, 0.039659255649894476, 0.061364922539464066, 0.05743935318397624, 0.11954370247466223, 0.036243327161563296, 0.014000334327907434, 0.056754338155899725, 0.009851415841174977, 0.04231388820335269, 0.045025154682142396, 0.07610058611524956, 0.03357407217845321, 0.041246165854058096, 0.058443150749163966, 0.077896634382861, 0.0694983589595982, 0.04133366973006299, 0.027384245036435977, 0.00789592117403767, 0.0422670964284667, 0.05738597283405917, 0.02458609893385853, 0.009726849534282727, 0.03181269705029471, 0.03275598964786955, 0.1094487298812185, 0.01588608746949051, 0.018094291478129368, 0.037794013773756366, 0.018668440669508915, 0.06183504552713462, 0.06645983164863926, 0.010586541528547449, 0.02871994800599558, 0.03326586800228272, 0.045293494925967286, 0.042514161206781864, 0.02684611757285893, 0.015805374032684734, 0.05020879581570625, 0.828219572348254, 11.276065605027334, 28.679365396499634, 42.066853931971956, 42.023969650268555, 23.546760627201625, 14.35906904084342, 23.406429597309657, 29.256682532174246, 20.580854313714163, 12.028228078569684, 5.801096166883196, 2.954154304095677, 0.5218398411359105, 0.08342701369630438, 0.06029696948826313, 0.05276016891002655, 0.07004389432924134, 0.059741378229643614, 0.07204545728330101, 0.08421593279178653, 0.044368271715939045, 0.2340719997882843, 0.07613181229680777, 1.2540596276521683, 1.2470619231462479, 2.733635199921472, 1.3290050689663206, 0.8704419295702661, 1.5976406655141284, 1.7419417223760059, 1.7092227637767792, 3.5719648897647858, 2.771942355803081, 6.241807809897831, 10.265779290880475, 14.21938853604453, 21.398903948920115, 27.334600618907384, 33.747199058532715, 38.26672083990914, 41.75529670715332, 45.61485774176461, 47.69316816329956, 50.34597301483154, 51.8923328263419, 53.09951979773385, 50.9499625478472, 50.989320618765696, 42.29777036394392, 44.63170848573957, 48.13612624577114, 50.48095914295742, 51.50958088466099, 52.95841230664934, 50.60649224690029, 52.2481882912772, 51.38546173913138, 51.7417653628758, 47.20326805114746, 48.507747173309326, 40.36406237738473, 36.10548366819109, 23.6007342338562, 20.335965054375784, 10.145563295909337, 11.447095513343811, 10.459112916673933, 2.5149208903312683, 1.962509355374745, 0.09598270032022681, 0.2939641417137214, 0.5653909870556423, 0.8089425553168569, 0.3414387399596827, 0.9881171094519752, 1.581833296588489, 1.8553811609745026, 0.30850886553525925, 0.02933716381500874, 0.05358247532110129, 0.15042179556829588, 0.05700422903256757, 0.14349604291575296, 0.08711624251944677, 0.13916514388152532, 0.23713696960891995, 1.4693084146295274, 4.974785992077418, 9.056244696889605, 12.622248683656965, 20.668132373264857, 31.11679867335728, 38.67165837969099, 39.45967790058681, 35.21131999152047, 21.35732592855181, 5.538618845599038, 0.22793033506189073, 0.05094126079763685, 0.012582484516315162, 0.03132093218820436, 0.008550001790614, 0.021406953721972447, 0.03713604515152318, 0.0764039455513869, 0.047890234871634414, 0.06434806103685073, 0.042851474535252364, 0.028593333371515785, 0.0058201977351148215, 0.022638852708041668, 0.01887939211779407, 0.04290746385231614, 0.08030275348573923, 0.04566181391211493, 0.05553279531055263, 0.03507789237690823, 0.01764590196710612, 0.006598097421894116, 0.06219030610684838, 0.04251638001629284, 0.042737701176000495, 0.010933483268932571, 0.029669299921286956, 0.05373120680451393, 0.08745244983583689, 0.016551187494769692, 0.01507123646193317, 0.04342128449518766, 0.03381474515689271, 0.025483015359246304, 0.0358333155911948, 0.06010644364037684, 0.12575574485319002, 0.05929635425231286, 0.051112448397491655, 0.017899114272690246, 0.11199984513223171, 0.04789595492184162, 0.0502936669758388, 0.03207323753408023, 0.026267242385074496, 0.045865944387125115, 0.005610443052968809, 0.012963582861370273, 0.08349479255931717, 0.016443592196862613, 0.024955581607563154, 0.06372805644891091, 0.04156326223164797, 0.04773409717849322, 0.07081293234867708, 0.02657496989039438, 0.016217509417661598, 0.02999841993940728, 0.021095082064026167, 0.014893640098827226, 0.025468776301879967, 0.03776225494220853, 0.0521953088630523, 0.01480410570677902, 0.05563672651935901, 0.07935336764369692, 0.0370781016536057, 0.01073165811664824, 0.0858804809727839, 0.05414903849097235, 0.043687707877584865, 0.04790678094806416, 0.04352301046518343, 0.012083163318623389, 0.027265267313591073, 0.018675044511577914, 0.026270027771326046, 0.03362862978662763, 1.4078145772218704, 13.864199229649135, 33.045715876988, 47.32709884643555, 47.04653753553118, 28.316589525767736, 19.285894223621913, 22.037964514323644, 29.05386287825448, 25.19270896911621, 14.071416224752154, 6.619418953146253, 3.3758320084639957, 0.817528737442834, 0.05417642077164991, 0.049707304154123576, 0.15783993394247123, 0.06987865069614989, 0.008613822249961751, 0.12453960653926645, 0.1036275304587824, 0.3728914165071079, 0.7855242490768433, 0.1972683553716966, 0.7498345556003707, 2.6154715291091373, 3.2248695833342413, 2.420137256383896, 2.2521563044616153, 4.084372171333857, 4.061507386820657, 3.159579315355846, 5.253035289900644, 4.75577312707901, 10.208676389285497, 13.891731466565814, 18.32782449041094, 24.606178522109985, 28.820443357740128, 35.01371669769287, 39.75617837905884, 43.262354033333914, 48.25910241263253, 49.90927873338972, 53.58617162704468, 53.009453773498535, 53.68885905402047, 51.419261251177105, 50.69815635681152, 43.39582198006766, 46.1709429195949, 51.62199926376343, 53.7935961995806, 54.68173578807286, 52.87285566329956, 52.68291275841849, 53.15652281897408, 52.899192810058594, 52.20810760770525, 50.470158168247764, 49.691883495875764, 42.80908135005406, 35.60660995755877, 25.88811595099313, 21.917394161224365, 16.486579656600952, 13.070658496447972, 13.176869528634207, 3.554395066840308, 1.113778320806367, 0.6730366051197052, 0.7871109896472522, 1.2989506359611238, 1.821163454226085, 0.7054715561015266, 3.4059800250189642, 5.490359263760703, 3.0786073974200656, 0.786347284913063, 0.10699803781296525, 0.11587977622236524, 0.15950254829866545, 0.22409038325505598, 0.11509921667831284, 0.06090227022234883, 0.10897585882672242, 0.41950685371245655, 1.5420957888875688, 4.71570633990424, 9.501280290739876, 16.425183636801584, 23.170324598039898, 35.8936504636492, 41.234914847782676, 43.94238812582833, 39.21331909724644, 23.851354019982473, 6.0916072981698175, 0.272491059665169, 0.01246354156838996, 0.040056656646941385, 0.04284248733893037, 0.07916839899761335, 0.044796881931168694, 0.051359635312110186, 0.02370262428719018, 0.024270880401932766, 0.020794197584369352, 0.03885104241115706, 0.020743941888213158, 0.028946622807000364, 0.027586149916585003, 0.046788205791796954, 0.060226849679436, 0.07439279489751373, 0.048615303821861744, 0.13727493530937604, 0.013225230205404972, 0.005285223338952554, 0.011006542830727994, 0.003982486993273986, 0.05421227795471038, 0.060724032643650255, 0.027425544070346013, 0.022496543558580533, 0.028824774881026576, 0.050358741876802275, 0.01605604522462402, 0.022813242993184497, 0.05718427151441574, 0.028609750526291982, 0.062005283177963326, 0.033971883689186404, 0.03868618554302624, 0.03638609432216201, 0.16401614967201436, 0.16382558989737714, 0.1558040710432189, 0.12201337995273726, 0.19220701338989393, 0.16101496214313166, 0.08984083881867783, 0.12073875192020621, 0.14127977112574236, 0.08015673953507628, 0.1514352283307484, 0.20262928413493292, 0.1540711468883923, 0.1589535591857774, 0.10543132081095662, 0.15824081243148871, 0.1526987962424755, 0.1476578645940338, 0.14830882394952433, 0.10938484580921275, 0.2153064895953451, 0.11779442562588624, 0.09338854559298072, 0.08861478032278162, 0.1495401614478656, 0.1524078268557787, 0.16782505171639578, 0.1436399059104068, 0.23417491997991288, 0.0964392526075244, 0.1109863513016275, 0.13596218717949732, 0.18389504083565303, 0.1758073376757758, 0.1459869449692113, 0.1494481520993369, 0.15445252428097384, 0.23449168726801872, 0.1230524613388947, 0.11724099889397621, 0.1827734224498272, 1.916224581854684, 16.75801624570574, 37.27683877944946, 53.02996832983834, 54.05671058382307, 35.17961883544922, 25.24083045550755, 33.05649253300258, 38.01904535293579, 27.510853835514613, 15.958587782723562, 7.967874526977539, 4.6910028883389066, 1.089503051979201, 0.3331778203802449, 0.21978807768651418, 0.4021998681128025, 0.436412010874067, 0.33739301562309265, 0.20925752632319927, 0.26063588580914904, 0.27447667026094025, 0.3809558594865458, 0.3564806671014854, 3.6312855694975172, 5.271458872726985, 4.003400036266871, 1.7511401602200098, 2.3572766866002763, 2.615174493619374, 4.226530577455248, 2.8968503390039717, 5.231557973793574, 4.259241827896663, 9.335545778274536, 14.795606987816946, 18.27277912412371, 24.027013165610178, 29.835755825042725, 35.45666088376726, 40.82448475701468, 42.63252762385777, 47.72992760794503, 48.766115937914165, 54.09337622778756, 52.60725382396153, 56.28919805799212, 53.83603927067348, 53.63689347675869, 49.261949811662944, 49.3654328073774, 53.05140004839216, 55.492277894701274, 57.01490960802351, 56.90138646534511, 54.781831536974224, 55.63039766039167, 55.505965845925466, 54.12194374629429, 50.699914251055034, 50.144277232033865, 43.35103389195034, 38.76942648206438, 26.12652948924473, 23.276286363601685, 12.188784446035113, 14.953344992228917, 16.03767044203622, 4.463944009372166, 3.103527980191367, 0.8276861895407949, 0.777079527931554, 2.2086325713566373, 1.8567102210862296, 0.3141275697520801, 2.414490759372711, 12.211815987314496, 8.635207312447683, 1.428772624049868, 0.4581911393574306, 0.22845136853201048, 0.31586670928767746, 0.2788366377353668, 0.23485198936292104, 0.35477276731814655, 0.604219094983169, 0.5653932126505035, 2.390130592244012, 6.74877096073968, 13.752883877073016, 19.653019666671753, 31.980546610695974, 41.29346036911011, 47.71638904299055, 46.86317457471575, 44.5502165385655, 28.052648305892944, 7.314902799470084, 0.4927733008350645, 0.15958064767931188, 0.1945154166647366, 0.1236630342900753, 0.19008181457008633, 0.12283900779272829, 0.17448629784796918, 0.14379485616726534, 0.1502947331007038, 0.1324402918773038, 0.1329026184976101, 0.13498196192085743, 0.07827408984303474, 0.10679609222071511, 0.18931220658123493, 0.246394901403359, 0.24585666028516634, 0.16049641211118015, 0.1669842382626874, 0.1082040930965117, 0.10591776256582566, 0.09295055802379336, 0.0884677485695907, 0.21242347572531017, 0.12519906115319046, 0.11872860549816064, 0.07088634983769485, 0.10711914952844381, 0.17318621118153843, 0.10671243563826595, 0.10441885156823055, 0.14263476484588214, 0.12365894950926304, 0.13031285389193467, 0.11707631844495024, 0.15196109297020094, 0.176525634846517], [0.060958798974752426, 0.048875786630170684, 0.054147399828902314, 0.054777938673006635, 0.03359287438381996, 0.033453964694802246, 0.05612979756136026, 0.05327831521364195, 0.08866136853716203, 0.050304279263530455, 0.05699242930859327, 0.05334923230111599, 0.03050817615751709, 0.03611335717141628, 0.031973913578050475, 0.03379213637007134, 0.06631957846028463, 0.036970954188810926, 0.02465914492495358, 0.05786332221967833, 0.041900792691324434, 0.04541885427066258, 0.03815251435818417, 0.0377167829179338, 0.05654228239187172, 0.033511660527437925, 0.012745508491726858, 0.03360632634056466, 0.026960883289575577, 0.05628688859620264, 0.05970302064503942, 0.027434319224474684, 0.03328498572643314, 0.08257687717143979, 0.030549848385687386, 0.07210041861981153, 0.019769670774361918, 0.040107207505830696, 0.023269391552145993, 0.027402982780975953, 0.009976857458241284, 0.08130781312606164, 4.227707862854004, 22.46368932723999, 36.3113066809518, 37.7187511580331, 24.787597724369594, 17.439221109662736, 26.434173141207012, 21.041598047528947, 24.49620590891157, 18.659076384135656, 9.272001896585737, 4.55274589572634, 2.0037191212177277, 0.4017279062952314, 0.06591754646173545, 0.043225964797394614, 0.09178373563502516, 0.1360422135995967, 0.08400484054748501, 0.1482095407055957, 0.4309983599398817, 1.7891436581100737, 0.30108954651015146, 1.070760611976896, 3.2758237634386336, 4.015351806368146, 4.1382775987897595, 2.560928604432515, 5.778405521597181, 3.649290306227548, 2.706875732966832, 2.561066265617098, 1.1830668428114481, 4.325946271419525, 5.594395509787968, 7.443804911204746, 10.977712563105992, 15.754918711526052, 20.014456272125244, 26.423997504370554, 31.74576003210885, 38.246866362435476, 43.25073317119053, 48.82521384102957, 48.70229325975691, 47.91616364887783, 45.41000052860805, 49.22817114421299, 44.58840036392212, 41.364193030766074, 48.842014585222515, 49.799879346575054, 51.957183837890625, 52.791610377175466, 52.856027126312256, 52.03607021059309, 52.29332726342337, 50.14530209132603, 48.821684156145366, 43.4597419330052, 35.91089241845267, 26.619964497429983, 20.944451808929443, 15.557569026947021, 8.94617394038609, 7.297171865190778, 5.35790662254606, 2.540933208806174, 0.10267988166638783, 0.13187552003988198, 0.3239671146231038, 1.0771415552922656, 1.163215839437076, 4.509044332163675, 4.655887995447431, 2.0912924792085374, 2.6439728225980486, 0.23420586117676326, 0.1700683699122497, 0.13758422514157637, 0.09332890236484152, 0.20737856786165917, 0.11861176176794938, 0.0958047341555357, 0.12414119791771684, 1.2379781305789948, 4.479213110038212, 7.537871360778809, 18.06817204611642, 29.75338840484619, 28.957227332251414, 22.454324892589025, 34.139546462467735, 38.968683447156636, 29.11935486112322, 15.561821324484688, 1.6573838825736726, 0.05132104702559965, 0.029507055412977934, 0.04904128132121904, 0.005416912567203066, 0.08629167319408484, 0.0413940593467227, 0.004728953121230006, 0.03515116398089698, 0.0277154244083379, 0.05951786200915064, 0.021580450037228208, 0.04856930932562266, 0.03613611862861684, 0.060842823769365034, 0.02929867391607591, 0.033190336876681874, 0.04162547032215765, 0.027254159695335796, 0.07376252407474176, 0.03906400062675987, 0.03538866141544921, 0.02877191361039877, 0.05172393397827234, 0.04415112354659608, 0.08039407072854893, 0.02059738850221038, 0.05188643293721335, 0.03906765453783529, 0.011862953260008777, 0.06392070611140557, 0.0966827856110675, 0.023989948244499307, 0.008540963704165603, 0.028273424466273615, 0.02368497728769268, 0.02369397466203996, 0.0757192222933684, 0.030453543910490613, 0.0469347761411752, 0.0638641162908503, 0.08062758855521679, 0.0390682516486517, 0.014324737679479378, 0.06060276486511741, 0.02247970910476787, 0.05483940716034599, 0.05977043988449233, 0.0850705544331244, 0.04790096251027925, 0.029188313587967838, 0.047705988865345716, 0.06416947740529265, 0.014286907655852181, 0.023607393593660424, 0.04570562352559396, 0.06605267671069928, 0.05181720540193575, 0.006526435218152723, 0.019240113208070397, 0.040074244274624755, 0.10294039161609751, 0.041904799440609555, 0.012391618552750774, 0.04137839536581721, 0.025033175479620695, 0.04254902433604002, 0.048355737035827975, 0.05294948357290455, 0.06582912656345538, 0.01516317795696003, 0.049990707875362465, 0.03861860006249376, 0.003522492200967723, 0.09302597040576593, 0.04292343317398003, 0.009043050780227142, 0.08559913321265153, 0.0565422959625721, 0.13971107958682946, 5.5822730745588025, 25.82194130761283, 41.966223171779085, 41.6042810848781, 28.317963532039098, 21.5027882031032, 28.512037140982493, 26.78027159827096, 29.866036074502126, 18.752329894474574, 11.73444174017225, 5.5628359232630045, 2.0599947529179707, 0.24465405195951462, 0.02647461456113628, 0.032957599365285466, 0.12548373373491423, 0.18633540560092243, 0.3206999685083117, 0.4124912630234446, 0.33146427518555094, 0.9204633682966232, 1.3059131652116776, 1.2918326407670975, 3.6414510011672974, 4.371549470084054, 5.717389481408255, 6.091526525361197, 3.6377463085310797, 6.6621929321970255, 6.7441491058894565, 3.811573301042829, 3.0731975734233856, 7.634260245731898, 9.26399757180895, 12.953221780913216, 13.869695254734584, 20.347030060631887, 23.64637347630092, 29.34334741319929, 34.57538958958217, 41.44873523712158, 45.23565632956368, 49.44628552028111, 51.522205761500764, 50.65715503692627, 48.73377207347325, 49.11861889702933, 44.67261947904314, 43.15997232709612, 51.5692902292524, 51.24667842047555, 55.15749979019165, 52.61407000677926, 53.543155329568044, 52.39718893596104, 53.94963189533779, 52.29604400907244, 50.63308647700718, 44.908507347106934, 38.35569947106497, 29.72997644969395, 22.382820980889456, 18.242776802607946, 12.341327803475515, 9.273236070360456, 8.463032688413348, 2.5002419522830417, 0.9101147321718079, 0.925207468015807, 1.9551386194569724, 3.381448107106345, 2.5439700058528354, 3.8807087455477034, 7.11068959747042, 4.859052887984684, 3.150752063308443, 0.4369644469448498, 0.3145214186183044, 0.4641529108796801, 0.3860536387988499, 0.033033961696284156, 0.15803536559854234, 0.1721485818603209, 0.16698425183338778, 1.405172850404467, 6.026817083358765, 11.15498890195574, 22.168778249195643, 28.97096392086574, 33.197999545506065, 26.95443688120161, 40.02105065754482, 42.9717560495649, 33.55831922803606, 18.370041745049612, 2.107340646641595, 0.08919713300253664, 0.033543575422040055, 0.06645772140473127, 0.03619877455223884, 0.04245560024199741, 0.07286101566361529, 0.0572917786027704, 0.022528606034549217, 0.06665306485124997, 0.023267768157113875, 0.0388418889737555, 0.026421904264550124, 0.06887165723102433, 0.053603964525141885, 0.002519074191306052, 0.025877695430868437, 0.024915939895436168, 0.012051874372575964, 0.08529705620769944, 0.03763717379687088, 0.07783634654645409, 0.00830208884352552, 0.03175195798810039, 0.04432332894897886, 0.07970328815281391, 0.03129368222185543, 0.033454785722174814, 0.031963813584297895, 0.041335267680031915, 0.012768294545821846, 0.06775884622974054, 0.026836896281955496, 0.041623997901167185, 0.026135961126003946, 0.02600531599351338, 0.014485104342124291, 0.02986043645069003, 0.11666988953948021, 0.10579994853053774, 0.20907345334334032, 0.14071027668459074, 0.09216492982315165, 0.12779972303126538, 0.15042505253638538, 0.21560984903148242, 0.15216160006821156, 0.149974328864898, 0.19703590284500802, 0.15442300800766262, 0.15514190228922026, 0.16117186658084393, 0.11637608387640544, 0.0920010432600975, 0.13237462325819901, 0.13860304547207697, 0.15755250650857175, 0.1476023332881076, 0.14919400002275193, 0.0973596717896206, 0.10632052059684481, 0.20736559427210263, 0.07635342183389834, 0.17096432112157345, 0.15602056442626885, 0.2420402265020779, 0.10143422707915306, 0.17292007617652416, 0.09844676631369761, 0.10424343669520957, 0.06239363591053656, 0.19856481866112777, 0.10600347510938134, 0.28210001119545525, 0.21181632259062358, 0.1409592583243336, 0.12463274225592613, 0.21983393308307442, 0.11285173227744442, 0.31302864157727783, 6.41542157956532, 29.17523227419172, 48.28818757193429, 49.352272919246126, 36.24931137902396, 28.6321245942797, 37.670193672180176, 32.995848655700684, 34.045116969517295, 25.159600802830287, 12.65842274257115, 6.346782496997288, 2.597417937857764, 0.5386945424335343, 0.2223604310836111, 0.1080308495355504, 0.22030810692480632, 0.43863329025251524, 0.5566874455128397, 0.9380006215402058, 1.0253367636884962, 3.9909718802997043, 1.035044482776097, 3.935707211494446, 10.98901207106454, 9.075092554092407, 10.768107993262154, 10.367251651627676, 12.723208614758082, 7.070126448358808, 5.650865256786346, 4.436055243015289, 2.219680424247469, 6.7654353465352735, 10.387064439909798, 10.86837831565312, 13.152347598757062, 17.832193851470947, 23.86127778462001, 28.43770010130746, 34.830398900168284, 41.57064485549927, 44.65784413473946, 48.48895229612078, 50.033040046691895, 52.22870554242815, 48.27856084278652, 51.500110489981516, 50.82520069394793, 46.85878678730556, 54.49225493839809, 53.01512697764805, 57.43413264410836, 53.5325072152274, 56.91523422513689, 54.573576654706685, 55.15898323059082, 53.30203546796526, 52.534499236515586, 47.45728029523577, 39.36665194375174, 31.40879671914237, 24.722258601869854, 17.330966438565934, 10.860974141529628, 9.828251225607735, 8.610244171960012, 4.684389071805136, 0.6690671752606119, 0.37866889791829245, 0.8640509439366204, 8.38049156325204, 4.83096045255661, 10.836373175893511, 10.137389608791896, 9.579602122306824, 8.277749419212341, 0.36497093151722637, 0.6205337366887501, 1.703565627336502, 1.0913297768150056, 0.46812337211200167, 0.283198993653059, 0.3151812532118389, 0.5877653807401657, 1.809286920087678, 6.332603394985199, 11.685252836772374, 26.073957681655884, 37.9806878226144, 39.28052207401821, 32.39355795724051, 46.71105418886457, 47.83200706754412, 39.28397185461861, 20.986274753298076, 2.9833610568727766, 0.0931864914351276, 0.16130473730819567, 0.1448692213743925, 0.14272908121347427, 0.22536340994494303, 0.14549032518906252, 0.08825713129980223, 0.12049753272107669, 0.2700731136969158, 0.1451425352799041, 0.11115835992885487, 0.13553926987307413, 0.15192069299519062, 0.10696331039071083, 0.08658114980374064, 0.16918305813201837, 0.15585644037595817, 0.09609130663531167, 0.13685100020042487, 0.10475612418459994, 0.10914506510432277, 0.11381319604281868, 0.1828446550560849, 0.12747984805277415, 0.2176253151680742, 0.11216670367866755, 0.1745111458003521, 0.20238095388880797, 0.13077823391982488, 0.14665737827973707, 0.17800872240747723, 0.1381559180361884, 0.1602085775562695, 0.11919588542410306, 0.13597240591687815, 0.09370919410139322, 0.21176588029733726], [0.04869491633559976, 0.02263408260686057, 0.037285618018358946, 0.03460889236469354, 0.026598470950765268, 0.04964647688237684, 0.044013821985572577, 0.035956500231155326, 0.02618009813262948, 0.03439704355384622, 0.035456762582595856, 0.030972324644348452, 0.01194883628548788, 0.052519763952919414, 0.08000885282776185, 0.04615876617442284, 0.06411049914147172, 0.039044879509934356, 0.017975069482677748, 0.026849849515461495, 0.06669723748096398, 0.03914403043953436, 0.01544225262477994, 0.013738435077747064, 0.055109304642038684, 0.04694148345983454, 0.03977185853623918, 0.018191406802673424, 0.048034925679011006, 0.04035116459376045, 0.06069740014416831, 0.043514990181263, 0.044116935559681485, 0.014733475300350359, 0.03308665672583239, 0.050329035613685846, 0.022765904997608492, 0.048743770856942446, 0.011755352873089058, 0.05077749976356115, 0.10822805895337037, 0.02285485415320311, 0.5972289357866559, 8.798493453434535, 24.905668463025773, 40.78423036847796, 37.255469594682964, 25.572457551956177, 20.60173886162894, 15.943459817341395, 23.88808740888323, 29.045535462243215, 18.209335122789653, 9.72638281754085, 6.983047715255192, 2.053147954600198, 0.5242238332118306, 0.06622025450425488, 0.04102278534056885, 0.09343176827366863, 0.37301458418369293, 0.18249457169856342, 0.4946359066026551, 1.0070113241672516, 0.7813614095960344, 0.2239994459918567, 1.9406970058168684, 2.9644220045634677, 3.0514282158442905, 4.28078384910311, 4.548821900572095, 7.541706766401019, 5.0052929265158514, 2.477681585720607, 3.6339484666075026, 5.6235184499195645, 3.3501102115426744, 4.329635330608912, 4.869060031005314, 8.698793751852852, 11.16151934010642, 16.41814684867859, 23.265839747020177, 29.06741533960615, 34.096561431884766, 40.258140563964844, 42.482349259512766, 47.085360595158164, 42.541867528642925, 45.49684606279646, 40.414648737226216, 37.69514812741961, 48.73761442729405, 43.73124279294695, 49.82755749566214, 52.7344788142613, 52.0668055670602, 51.7544458253043, 51.802975518362864, 47.849745818546836, 45.03401265825544, 38.5203926222665, 29.846747875213623, 19.98798189844404, 15.425428186144147, 9.34867353098733, 10.802230596542358, 5.34747086252485, 3.9750865612711226, 1.1545624009200504, 1.0269726301942552, 0.7825191531862531, 3.719659924507141, 2.005848092692239, 1.711381807923317, 3.9703075034277777, 8.574032766478402, 5.663557010037558, 0.8470628697957311, 0.6057506299444607, 0.3441408835351467, 0.14997526524322374, 0.12390889466873237, 0.12767206345285687, 0.13787144901497023, 0.3628075990293707, 1.198565125465393, 3.927140951156616, 5.92407363653183, 12.737215314592634, 12.791703956467764, 21.03828375680106, 21.46840156827654, 30.28914315359933, 31.01015772138323, 29.143788201468332, 17.073881353650773, 5.660114177635737, 0.2707262715058667, 0.06224768981337547, 0.051023811368005614, 0.0435858292372099, 0.042744849542421956, 0.03192087249564273, 0.06412579332079206, 0.07990201748907566, 0.01137728164238589, 0.06856415194592305, 0.028070632401587706, 0.04176662935476218, 0.029626898267971616, 0.005211225278409464, 0.013213810461041118, 0.012595173121163887, 0.05965635779180697, 0.05508282481293593, 0.11953066103160381, 0.05320378153451851, 0.07303257645773036, 0.07884377427399158, 0.02050208316982857, 0.019786710485017726, 0.10012318207217114, 0.04052973465461816, 0.03075562770079289, 0.021149821180318083, 0.016032154006617408, 0.07638362342757837, 0.029437637887895107, 0.03448245754199369, 0.07077139243483543, 0.04778187282915626, 0.07163592747279576, 0.06616535423589603, 0.06537660477416855, 0.016107261047831604, 0.06438685966921703, 0.01595875178463757, 0.022541092775229896, 0.07543175414736782, 0.029598983337304423, 0.019206147441374402, 0.04210132693073579, 0.03625294878812773, 0.01738205362510468, 0.03651393710502556, 0.03293509575139199, 0.044278247082339864, 0.05302474667717304, 0.01956813399946051, 0.05357324045949748, 0.01572038752159902, 0.08723045353378568, 0.018604485351326208, 0.027631019741030674, 0.025629366881081035, 0.03193277399986982, 0.03966074503426041, 0.06424198565738541, 0.01846601840640817, 0.06189544192914452, 0.09088061909590449, 0.04240437763343964, 0.056670963165483305, 0.04513852092038308, 0.04088688495435885, 0.03878719565857734, 0.02227339374699763, 0.057269006967544556, 0.03958669650767531, 0.006915421532799623, 0.020252884398879747, 0.06071633805653878, 0.050054910858826976, 0.013588773153190101, 0.029422221572271416, 0.032449461453195126, 0.060682424876306734, 0.9332893086331231, 12.331708022526332, 29.460712909698486, 47.564192226954866, 41.41376147951399, 30.411452293395996, 25.113339696611675, 19.154786927359446, 24.810582365308488, 32.447878973824636, 21.11549735069275, 9.933738776615687, 5.9592927524021695, 2.0244607967989783, 0.3010879451675074, 0.03273455472663045, 0.07028259616345167, 0.042076088820717165, 0.2718128232019288, 0.05634836386889219, 0.3886243094291006, 0.35620602326733725, 1.843194454908371, 1.2393745013645716, 2.651778906583786, 5.477547219821385, 4.419305307524545, 4.91876266683851, 7.9633590664182385, 8.89555891922542, 9.15573160988944, 4.7370559828622, 3.2661264666489194, 5.725980494703565, 4.449466569083078, 7.101467600890568, 6.803886243275233, 11.639842884881155, 13.294532929147993, 20.115495238985332, 25.73427936008998, 32.11930561065674, 37.69974783488682, 43.962794985089985, 44.20283440181187, 50.56141233444214, 46.42731755120413, 47.097582476479666, 40.98494298117501, 39.73200907026018, 52.554075786045615, 47.33205986022949, 52.323069027491975, 53.3797093800136, 53.17739520754133, 52.516774381910054, 52.28524303436279, 49.683017594473704, 46.40238046646118, 39.56792041233608, 31.053670815059117, 22.305831466402324, 17.645229986735753, 12.41545900276729, 9.567144870758057, 6.706230180604117, 7.263876531805311, 2.6231651391301836, 1.547980587397303, 4.528845829623086, 7.783434595380511, 4.343377998897007, 3.5756815246173312, 5.559673624379294, 3.6360654958656857, 3.3701353541442325, 2.6445191247122626, 1.33763245173863, 0.7327847076313836, 0.27342105976172854, 0.24426223869834626, 0.11060273474348442, 0.06229159102908202, 0.2363278301698821, 1.2045454617057527, 4.0474802766527445, 7.78468440260206, 15.943124566759382, 19.6951413835798, 26.563385316303798, 26.250761543001445, 33.79977260317121, 38.13619198117937, 35.1716423034668, 21.918745585850306, 6.826940366200038, 0.3642369194754532, 0.042835389862635305, 0.04820514636646424, 0.10546895236309085, 0.024998380203864405, 0.033649698298956664, 0.024148945962744098, 0.04907230733494673, 0.03532136431229966, 0.06223213779074805, 0.05250447655894926, 0.0730652411335281, 0.01581140620900052, 0.03956898335101349, 0.04824454889499715, 0.058736352516072135, 0.08900174205856663, 0.021569208408306752, 0.04303833968671305, 0.04301046207547188, 0.012658715381153991, 0.06873719194637877, 0.027496868278831244, 0.019074733867975216, 0.022396632669759647, 0.020384728842015778, 0.04057239754391568, 0.06231576044644628, 0.021090554539114237, 0.07839581902538027, 0.043718574435583184, 0.06124222305204187, 0.06448973914874451, 0.03424844438476222, 0.07210233208856412, 0.07723556485559259, 0.03996586187609604, 0.0147679194342345, 0.11538656268801008, 0.17333896298493656, 0.06751899088599853, 0.09087151994130441, 0.095322126123522, 0.1679590895239796, 0.14443198697907583, 0.2211433428206614, 0.10452145963375058, 0.1468229272535869, 0.10390758900237934, 0.1753366379333394, 0.168389619993312, 0.10121583379805088, 0.19822228061301367, 0.13434386758932046, 0.19888736706759247, 0.11501669324934483, 0.1385855528392962, 0.14422147827489035, 0.1298920807561704, 0.13838489646358149, 0.13391624124986784, 0.10674744125987802, 0.12286734341510705, 0.159450463950634, 0.1609159503132105, 0.17665252089500427, 0.21699818596243858, 0.13785915396043233, 0.13981807098856994, 0.15447901428810187, 0.20030171903116362, 0.10785636425550495, 0.10805862875921385, 0.10684793229613986, 0.12387115455099515, 0.13959471083113126, 0.08517108618148736, 0.13073370845190116, 0.2784291096031666, 0.14863966405391693, 1.2097933058227812, 13.510606271880013, 33.6261579649789, 51.67423234667097, 49.217109612056184, 36.94083431788853, 33.86905656542097, 25.771945544651576, 33.34258113588606, 38.94232545580183, 23.433583157403127, 13.52921267918178, 8.475698385919843, 2.8708532197134833, 0.7057559979813439, 0.4656909597771508, 0.21900632392082894, 0.4026107074958937, 0.9729357297931398, 1.0572448457990373, 1.3993996573346001, 3.6330942724432265, 7.2587639604296, 1.6284490866320473, 5.643090222563062, 10.498213904244558, 12.137147171156746, 8.647474357060023, 11.18162395272936, 13.498765672956194, 10.332544531141009, 7.051512658596039, 7.771947486060006, 9.123582295009069, 6.005126978669848, 7.358527064323425, 7.244577041694096, 12.388029251779828, 13.120142698287964, 20.747324466705322, 25.096132482801163, 31.445799350738525, 36.259497438158306, 43.281923634665354, 43.37632533482143, 52.52714804240635, 46.99017027446202, 47.74813536235264, 45.76238536834717, 42.483273369925364, 55.70296812057495, 50.15109688895089, 54.89954096930367, 56.551364013126914, 54.583814825330464, 53.986870765686035, 54.81109387534005, 50.40474087851388, 47.25256552015032, 40.43092836652483, 31.50666904449463, 25.823033911841257, 19.60272686822074, 13.161481005804879, 13.911276749202184, 9.343791552952357, 8.380370838301522, 2.0038663361753737, 1.1803041739123208, 4.733545405524118, 10.825969985553197, 8.94376117842538, 11.375058327402387, 12.634322047233582, 19.117902415139334, 13.236665725708008, 7.4086174964904785, 2.7823390322072163, 1.9027400825704848, 1.7760660627058573, 0.9744735615594047, 0.3858230454581124, 0.37387895637324875, 0.7459012238042695, 1.7230698721749442, 4.896269610949925, 9.722868766103472, 18.968946933746338, 23.437904936926707, 30.029954501560756, 31.46584837777274, 40.33184010641915, 43.120280742645264, 40.165621825626914, 26.99411804335458, 8.544340508324758, 0.6885200685688427, 0.20658834597894124, 0.11772735922464303, 0.14936484156974725, 0.18529150661613258, 0.10374294248010431, 0.16380980717284338, 0.16266518644988537, 0.1147021786975009, 0.1967668365687132, 0.14719831996730395, 0.23102247342467308, 0.06774045793073517, 0.1458132400044373, 0.1309914296226842, 0.11612008618456976, 0.15139979523207459, 0.18041976088924067, 0.20700727349945477, 0.18585262793515409, 0.1747345466698919, 0.23516878379242762, 0.12298215154026236, 0.12424774148634501, 0.37816349789500237, 0.11440825089812279, 0.17136118268328054, 0.24650626257061958, 0.06040458514222077, 0.16908070790980542, 0.14803545576121124, 0.19397477353257792, 0.23571636155247688, 0.1446576677262783, 0.20767553549792084, 0.22813210423503602, 0.20452222041785717, 0.10621169036520378], [0.01895925060047635, 0.00281318773964553, 0.06273070496640035, 0.0345701039103525, 0.023775543052969233, 0.04572063950555665, 0.04874632554128766, 0.012005868001974054, 0.1678554229438305, 0.07137517325047936, 0.013639423247825886, 0.03036768887458103, 0.030082069736506258, 0.07762510502444846, 0.07280627145831074, 0.04852237845105784, 0.05207557796633669, 0.04412953595497778, 0.051426230131515434, 0.011572061056670333, 0.048658516324524365, 0.06700455277626004, 0.06123770400881767, 0.07250961594815765, 0.04323322172941906, 0.013786035157474024, 0.07424258081508534, 0.04285161702760628, 0.06504632106849126, 0.014333735053826655, 0.06381613029433147, 0.0017403907965802188, 0.029032545696411814, 0.07705525774508715, 0.027687429749806012, 0.05649124298776899, 0.028522185582135404, 0.02689226982848985, 0.027230987724448954, 0.05169082825471248, 0.012600201913820845, 0.023055559722706676, 0.10298359394073486, 3.23568879706519, 15.392028195517403, 33.49275950023106, 39.479633126940044, 37.692789213997976, 30.151537554604666, 18.39409293447222, 22.481992619378225, 24.212474482400076, 24.761885915483745, 13.757276875632149, 9.393266201019287, 3.792322882584163, 1.5255636359964098, 0.490508676639625, 0.19005997931318624, 0.05804789053010089, 0.06667545650686536, 0.1379126768027033, 0.06758005903767687, 0.1520760232316596, 1.3068561660391944, 1.378759924854551, 1.3020752625805991, 3.5777032332760945, 3.6575161048344205, 5.86328558410917, 2.4222705704825263, 7.961892127990723, 15.706168413162231, 2.909934014081955, 0.9965360462665558, 2.9585127787930623, 2.870550973074777, 3.6801246745245795, 1.0757249913045337, 3.7892691493034363, 6.410570868424006, 10.629928299358912, 13.946307829448156, 19.997455767222814, 24.18411888395037, 31.3255329813276, 33.605021544865195, 40.87341397149222, 37.194245542798726, 38.9682491847447, 33.4196331841605, 30.354192188807897, 47.86834614617484, 42.895836557660786, 45.09037297112601, 49.68705449785505, 48.88051802771432, 47.83735023226057, 44.94306421279907, 40.64358493259975, 38.39508880887713, 29.84970085961478, 21.128158705575125, 14.71181344985962, 9.68275421006339, 5.599799471242087, 4.003329685756138, 2.197083579642432, 5.625951622213636, 0.5813898114221436, 1.1160795858928134, 4.802001663616725, 7.092344616140638, 4.475449357713972, 2.440429470368794, 2.592727469546454, 0.9033848590084484, 1.3780513171638762, 0.7776986775653703, 0.5640909682427133, 0.3704565071633884, 0.24280105424778803, 0.2198647250022207, 0.13863307743200234, 0.24808966474873678, 1.023221037217549, 2.824591027838843, 6.899470439979008, 15.491806064333234, 20.0949216229575, 22.634364877428325, 22.460651227406093, 29.594695023127965, 35.160837854657856, 32.648522104535786, 24.24585015433175, 9.07119722025735, 1.4292904819761003, 0.025476382679439018, 0.041095710891698084, 0.01084112617120679, 0.016919023024716547, 0.023136490290718417, 0.02573094018069761, 0.03653262056676405, 0.10956348372357232, 0.03376529352473361, 0.03359040790902717, 0.04218506493738719, 0.054680419620126486, 0.02064314720753048, 0.057106172133769305, 0.07438334969005414, 0.05590349595461573, 0.02156766134846423, 0.030652500555983613, 0.0026111289168641505, 0.03613748926935451, 0.056995815198336325, 0.02770931928950761, 0.05149312689900398, 0.04522239124136312, 0.027791198110207915, 0.019911789934017828, 0.03317512072888868, 0.01598341653256544, 0.03536465484648943, 0.08761288944099631, 0.04891077528840729, 0.07628138177096844, 0.030538934149912426, 0.049826115635888915, 0.0078047006224681225, 0.04148110181891492, 0.07680733461997338, 0.03174461963187371, 0.04514652763360313, 0.015146285827670778, 0.007798468278321836, 0.07400558888912201, 0.021336479378598075, 0.014853669297216194, 0.04774854997439044, 0.020768301295382634, 0.03975855585719858, 0.025779406240742122, 0.011371045905564512, 0.08408874140254088, 0.05994951206126383, 0.04569507909140416, 0.012658844302807535, 0.03255975732047643, 0.029350134011890208, 0.0418076841160655, 0.014844468362363321, 0.028159927610041838, 0.03262343783197658, 0.047198505739548376, 0.04321406329316752, 0.03926617692091635, 0.03728951280936599, 0.01107263214154435, 0.05247678215216313, 0.0362860443336623, 0.04479999979957938, 0.028732219311807836, 0.031059672457299063, 0.002703235804801807, 0.03303267926509891, 0.07692548113742045, 0.055306541201259406, 0.07064690840031419, 0.023040391072364788, 0.03082149988040328, 0.02800079757746841, 0.038223614650113244, 0.038159258996269534, 0.010278245750149446, 0.03387497531782303, 3.998294413089752, 19.3856668812888, 37.49408115659441, 44.84391689300537, 41.007680961063926, 35.02806125368391, 20.76929119655064, 26.406465462275914, 33.57675627299717, 30.30506147657122, 20.428301402500697, 14.74701476097107, 4.5599880899701795, 1.4908280713217599, 0.3653188571333885, 0.12147821938352925, 0.15480334045631544, 0.06590215050216232, 0.2633790671825409, 0.4525065358195986, 0.42376634372132166, 1.3226072979824883, 2.0440755614212582, 1.9695524403027125, 3.5180868208408356, 4.277680175645011, 5.887206929070609, 6.242422725473132, 7.677401610783168, 5.905726483889988, 7.278561983789716, 5.136262995856149, 5.942263586180551, 5.137030337538038, 3.8867410847118924, 3.726581198828561, 5.6234559161322455, 8.963116254125323, 13.837123836789813, 17.621402876717703, 24.123959643500193, 28.096109288079397, 34.76767403738839, 36.01445184435163, 45.075107778821675, 39.97727353232247, 42.79887792042324, 35.701980931418284, 33.80445916312081, 53.00562531607491, 45.872059209006174, 47.11533859797886, 50.363527638571604, 49.407403400966096, 48.34876891544887, 46.67409324645996, 43.443969522203716, 40.240794386182515, 32.81261076245989, 23.50180925641741, 18.280352660587855, 11.899043696267263, 7.218911698886326, 5.070183455944061, 3.9780412827219283, 8.11453970840999, 4.640526831150055, 3.3444973698684146, 6.912306368350983, 5.243920121874128, 3.8852949908801486, 3.520550391503743, 4.7614628332001825, 2.917113023144858, 1.416621636067118, 0.9820105114153453, 0.9101766688483102, 0.460960647889546, 0.31245413954768864, 0.04913049510547093, 0.13096484462065355, 0.312246317842177, 1.0366576590708323, 3.1332484654017856, 7.4786388363156995, 17.952182292938232, 23.127478531428746, 23.068427528653825, 24.06365622792925, 32.270029408591135, 38.083284923008506, 38.38769939967564, 29.283867359161377, 11.413829275539943, 1.6128095601286208, 0.058264173567295074, 0.11645733165953841, 0.038702080225838084, 0.09163644603852715, 0.037358689454517195, 0.026817478306059326, 0.012906790328478175, 0.055883075443229506, 0.03193023967157517, 0.05672679981216788, 0.044799629997994216, 0.02281533118470439, 0.08712948752301079, 0.0581994956093175, 0.051578289829194546, 0.11840377721403327, 0.04659725246684892, 0.04853325876008187, 0.025878219599170343, 0.07023870851844549, 0.07271644699254207, 0.04873899397041116, 0.04912850699786629, 0.029691705147602727, 0.13310155139437743, 0.05956527803625379, 0.004864867926309151, 0.03792958167780723, 0.033040529915264676, 0.07947405188211373, 0.05970515124499798, 0.04997486069000193, 0.025947906841923083, 0.03244659464274134, 0.028438970047448362, 0.0580155040536608, 0.027219323707478385, 0.03942008901919637, 0.11317308646227632, 0.09246092715433665, 0.1715168657579592, 0.14136332592793874, 0.09146234073809215, 0.15080410933920316, 0.19560305401682854, 0.10646275510745389, 0.28134987716163906, 0.18335754610598087, 0.1266362661761897, 0.17845803472612584, 0.13400169595011643, 0.15311838872730732, 0.19995475693472795, 0.18805235704141005, 0.09310774744621345, 0.10125643054821662, 0.17585311164813383, 0.07785046686019216, 0.1613998950592109, 0.15927635186484881, 0.1890289317816496, 0.13523055001028947, 0.154963203306709, 0.0936119125357696, 0.1289817446044513, 0.09845946170389652, 0.15553727107388632, 0.08958708707775388, 0.10125002517764058, 0.10536920771534954, 0.1367825495877436, 0.15955984379564012, 0.14969386320028985, 0.14379372979913438, 0.09930714193199362, 0.1281993937279497, 0.10819820341254983, 0.1296051147260836, 0.1742223748671157, 0.13361191829400404, 0.21365865373185702, 5.444050822939191, 22.257079430988856, 42.71140357426235, 51.24914155687605, 48.860382148197715, 42.57771328517369, 28.17751611982073, 32.8548002243042, 34.390011651175364, 35.503561224256245, 20.005390610013688, 13.073436907359532, 4.701995807034629, 1.9415247099740165, 0.7271060752017158, 0.588694865150111, 0.40954530824507984, 0.40921095332929064, 0.8394579578723226, 0.6018550246953964, 0.9547138618571418, 4.67192747763225, 5.157436328274863, 6.854718829904284, 10.265424064227513, 10.93719674859728, 15.56932885306222, 10.107070275715419, 18.514183861868723, 26.857910769326345, 8.75153318473271, 5.803718243326459, 8.1120913369315, 5.126161183629717, 6.631120153835841, 3.859689576285226, 5.050163090229034, 9.552106363432747, 14.50327021735055, 16.594408750534058, 24.540349551609584, 26.680822031838552, 34.32608127593994, 35.62949732371739, 47.77368041447231, 42.27177367891584, 45.33610643659319, 39.0012218611581, 36.64876331601824, 56.20882824489048, 49.52750996180943, 49.69707727432251, 51.880281175885884, 52.09899657113211, 50.672482763017925, 47.235504218510215, 43.61878619875227, 41.221546513693674, 34.10387093680245, 25.453327213014873, 19.15684359414237, 12.579598035131182, 8.820091928754534, 5.530252345970698, 4.82016555752073, 10.445648176329476, 4.696187547274998, 5.020154254777091, 13.879810963358198, 17.484684910093033, 10.1022230386734, 7.692210827554975, 8.960596663611275, 12.741886241095406, 5.086623328072684, 5.402000759329114, 3.5707294132028307, 1.522381903869765, 0.6620616540312767, 0.5726544058748654, 0.8614404297300747, 0.8867316554699625, 1.5863272611583983, 4.5279260618346076, 10.208379353795733, 20.84527322224208, 28.497466768537247, 30.827197756086075, 31.53834935597011, 39.755702427455354, 45.161519050598145, 42.773534366062705, 33.77264336177281, 15.023139647075109, 2.373035852398191, 0.16512213461101055, 0.17216735013893672, 0.16466681047209672, 0.17912593031568186, 0.09739354425775153, 0.11123031178223235, 0.10195925033518247, 0.1633816244346755, 0.10910674823181969, 0.22013020861361707, 0.18363090072359356, 0.17403113655745983, 0.13506293828998292, 0.1466096229851246, 0.14372935039656504, 0.30155130316104206, 0.06358746399304696, 0.10339110171688454, 0.19090928802532808, 0.21464566434068338, 0.18747896780925138, 0.1260963287204504, 0.09007332527211734, 0.16285434844238417, 0.16926997846790723, 0.16765526868402958, 0.1455179551350219, 0.14422078616917133, 0.0897617352062038, 0.28409864966358456, 0.15456176841897623, 0.223334617380585, 0.21881714835762978, 0.1433905442910535, 0.11662826820143632, 0.18569432571530342, 0.15925368879522595, 0.13947558722325734], [0.07541600534958498, 0.03299279836937785, 0.043292885313608816, 0.026729482492165904, 0.013728237544585551, 0.045021239535084794, 0.02782610704057983, 0.07585317867674998, 0.05738830699452332, 0.03771049629098602, 0.03415732730978301, 0.03611336734944156, 0.00793527196427541, 0.1012060357523816, 0.04054394317790866, 0.04501352459192276, 0.0784887308254838, 0.03149111555623157, 0.06086400763264724, 0.03272859379649162, 0.04240903238366757, 0.01975594231459711, 0.02208550740033388, 0.024607235299689428, 0.0446999328477042, 0.0010090058515613365, 0.06950029278440134, 0.010286266882238644, 0.0628953989861267, 0.02071749259318624, 0.08198963225420032, 0.06368951565985169, 0.10349782848996775, 0.0532340611597257, 0.05971112913851227, 0.02822537231259048, 0.019058118241706064, 0.007212643195608897, 0.06204031594097614, 0.03098877233320049, 0.03248340856017811, 0.03785089536436966, 0.03792067251301237, 0.32645665960652487, 6.578560071332114, 24.473275116511754, 35.96095418930054, 42.66242572239467, 35.4059077671596, 22.1178549017225, 10.660314508846827, 19.274401903152466, 16.55618497303554, 12.555148192814418, 13.21101210798536, 8.605078186307635, 5.647811523505619, 1.4209725111722946, 0.5126120362962995, 0.27725573256611824, 0.17793706910950796, 0.1003723129896181, 0.1998448342617069, 0.32233762634652, 0.46687785323177067, 0.4686596319079399, 1.2169018558093478, 3.4438609523432593, 1.3444673078400748, 1.8053960374423434, 8.87878509930202, 6.241238057613373, 4.081516461712973, 7.071074443204062, 3.636904925107956, 4.278294656957899, 3.1808570878846303, 1.8201911406857627, 1.1281974613666534, 2.433129302092961, 3.52071475982666, 5.232298825468336, 8.338246515819005, 12.302185995238167, 17.734159980501445, 23.892431770052227, 26.334393535341533, 30.334014620099747, 27.481768676212855, 32.55598252160208, 25.02104503767831, 26.249493496758596, 40.86831051962716, 37.28208466938564, 42.33250093460083, 43.08485882622855, 41.47719505855015, 39.37306860515049, 35.75866780962263, 32.87981721333095, 26.25194447381156, 20.460537569863455, 14.280334659985133, 9.182345816067286, 4.293696641921997, 2.8212324423449378, 1.959268020732062, 1.6386292832238334, 5.974958334650312, 3.8686627405030385, 3.5280865814004625, 5.405304627759116, 4.617736305509295, 2.730535000562668, 2.8393483502524237, 3.3761021196842194, 1.6202900558710098, 1.5736409361873354, 1.107018157839775, 0.5211842134594917, 0.10375371761620045, 0.0658371943448271, 0.09144419671169349, 0.20101253874599934, 0.8797699404614312, 2.856962033680507, 7.349826182637896, 14.213403531483241, 13.346158044678823, 17.750222478594097, 26.240724870136805, 25.525089945111954, 32.721537249428884, 37.709336348942344, 22.913008485521587, 14.217392665999276, 3.088217624596187, 0.043098495208791325, 0.06436411517539195, 0.0518249576645238, 0.018896109524316022, 0.028459521176825677, 0.01987649593502283, 0.019880137971735427, 0.04768868961504527, 0.014841172378510237, 0.014327270311436482, 0.017776231580813016, 0.021236865348847847, 0.028710577437388043, 0.014151092934688287, 0.12605648514415535, 0.02279536359544311, 0.03415874544797199, 0.039073130315435786, 0.044494116213172674, 0.040655355235295634, 0.03774477927280324, 0.01556026513156082, 0.0349642988294363, 0.029984469259423868, 0.013759713935931879, 0.0811478349247149, 0.04288197807701571, 0.07362157199531794, 0.04105512771223273, 0.057456004433333874, 0.03312846126833132, 0.0345016770463969, 0.021732777756239687, 0.016577835261289562, 0.027803242106788924, 0.05541863179366503, 0.011173338612674602, 0.012204926427719849, 0.030008177272975445, 0.030643316584506204, 0.04012960933947137, 0.023550013279808418, 0.03519139771482774, 0.0304049540178052, 0.07572639440851552, 0.03315128040100847, 0.03240020998886653, 0.05130773077585867, 0.05692994301872594, 0.024084332465593303, 0.015216982391263758, 0.06414538262678043, 0.08730919752269983, 0.08325431974870817, 0.06550155699785266, 0.05426973630008953, 0.04007481424404042, 0.05052352749875613, 0.08451663237065077, 0.03184225742838212, 0.06086273877216237, 0.03280991282580154, 0.03341050113418272, 0.07090416138193437, 0.05130685207300952, 0.055076344803507836, 0.013320505003710943, 0.05368751593466316, 0.07022939901798964, 0.09196521661111287, 0.03898564679548144, 0.06700476312211581, 0.031021301301994493, 0.023420972882636955, 0.024717822937028747, 0.04723139772457736, 0.05159658991864749, 0.04917411472914474, 0.07715336712343351, 0.05930571125022002, 0.016577039678980197, 0.05762778235865491, 0.5431501290627888, 8.32484952041081, 28.55509512765067, 42.03676128387451, 47.62585401535034, 38.29377365112305, 27.904816695622035, 16.301370212009974, 24.300355298178538, 26.584016254970006, 19.275680371693202, 17.93023293358939, 9.786553348813738, 5.364913880825043, 1.9516445440905434, 0.4976579930101122, 0.19753481607351983, 0.2283196784555912, 0.1854309184210641, 0.17194176438663686, 0.2529695800372532, 0.5306484198995999, 1.3185140490531921, 1.55817902301039, 2.0001203886100223, 3.5891855657100677, 4.917869389057159, 3.0178284645080566, 5.040251050676618, 5.995682205472674, 7.993355308260236, 6.940465245928083, 6.648585319519043, 4.905414308820452, 3.440958342381886, 2.3668426190103804, 4.254807574408395, 5.2220936587878635, 7.54229302065713, 9.794958932059151, 16.359804562159947, 21.94311465535845, 27.568803548812866, 29.057618379592896, 34.72321251460484, 31.12760659626552, 34.48297160012381, 27.905169316700526, 28.1432615007673, 47.22295924595424, 43.14196259634835, 44.446090834481375, 44.05872876303536, 43.200904164995464, 40.53820855276925, 38.84194483075823, 34.66093928473336, 29.85935538155692, 21.652789388384136, 16.60163140296936, 9.811275039400373, 6.523688410009656, 5.115792300019946, 4.350108632019587, 3.0993890251432146, 6.787035124642508, 6.723816505500248, 4.536136661257062, 5.860117639814105, 5.641559881823404, 3.446282833814621, 2.3892488224165778, 2.7670749255589078, 2.2684730631964545, 1.326797278864043, 0.5352147434438977, 0.6400742967213903, 0.724910281598568, 0.09628865176013537, 0.09185297334832804, 0.1520776924278055, 1.1543574290616172, 2.6490163462502614, 8.567523172923497, 16.774044002805436, 18.63463956969125, 24.811820881707327, 29.700446605682373, 30.147500651223318, 36.071211678641184, 41.56041363307408, 28.54563515526908, 17.177232333592006, 3.5878903780664717, 0.1092156395316124, 0.014006962766870856, 0.03421318091984306, 0.020128693830754076, 0.010924383266163724, 0.03471503220498562, 0.020987276420263306, 0.00898632694900568, 0.0382468782232276, 0.04715856038300054, 0.08808298528726612, 0.08498795636530433, 0.06631794997623988, 0.03342990045036588, 0.04020584953416671, 0.05960919960801091, 0.0404373419338039, 0.03972645436546632, 0.0396829399147204, 0.04408728697204164, 0.04278965999505349, 0.03389347557510648, 0.03316398257655757, 0.016612352337688208, 0.02475366654938885, 0.08350546591516052, 0.040435079019516706, 0.06363844232899801, 0.02913429880780833, 0.02997243883354323, 0.041746700781264474, 0.02916576247662306, 0.021679870684498122, 0.028781810043645755, 0.057500658822911124, 0.01801956950553826, 0.04168404485764248, 0.045721450354903936, 0.020552301546558738, 0.16182490225349153, 0.12764101369040354, 0.10966983730239527, 0.15008897414164885, 0.11131647215890032, 0.18534920923411846, 0.14374347749565328, 0.14719519870621817, 0.17697280299450668, 0.10770154970565013, 0.07138256249683243, 0.10184839806918587, 0.21842860563525132, 0.3038986272045544, 0.1533511940922056, 0.10594312620482274, 0.13958968967199326, 0.08708980679512024, 0.16012203719999107, 0.13438247623188154, 0.16802794725767203, 0.09508098834859473, 0.16698140198630945, 0.10797362189207758, 0.1395615983222212, 0.17266584267573698, 0.21797861478158406, 0.1148107171590839, 0.2012782802007028, 0.09566368029585906, 0.24197538569569588, 0.16381618540201867, 0.19339793734252453, 0.2185400210853134, 0.18045410833188466, 0.12429409899881907, 0.08686832617968321, 0.1018634479758995, 0.18604202062955924, 0.15031423419713974, 0.17909953530345643, 0.07863473120544638, 0.11528396819319044, 0.8412389765892709, 9.935159683227539, 32.43520893369402, 48.607502460479736, 54.9689222063337, 45.602257183619905, 33.7812626021249, 20.340868745531353, 31.142715454101562, 26.89977366583688, 20.67724667276655, 19.89767963545663, 12.574746455465045, 7.406719769750323, 2.5535155279295783, 1.3523121497460773, 0.4803494874920164, 0.775028832256794, 0.6193853840231895, 0.8311993181705475, 1.6872358407293047, 2.337733792407172, 3.310841815812247, 5.771718314715794, 8.74445470741817, 8.281754187175206, 8.559014235224042, 18.5724584034511, 15.01376826422555, 11.689288871628897, 14.97761504990714, 9.835776124681745, 8.619060567447118, 8.853431991168431, 4.97740980557033, 2.243854944195066, 5.076530201094491, 4.996155176843915, 8.515956248555865, 10.172518832342965, 16.36236149924142, 21.030480929783412, 26.372709376471384, 29.450592858450754, 35.50200135367257, 34.339519092014854, 38.63705635070801, 31.671681812831334, 32.722405774252756, 50.118294443402974, 45.463664940425325, 48.275041580200195, 45.56531708581107, 42.411456789289204, 41.760264669145855, 37.19419343130929, 35.31030402864729, 28.763165882655553, 22.943453754697526, 17.127832378659928, 11.568023698670522, 6.244657874107361, 4.353420751435416, 4.445878258773258, 4.74255461352212, 13.22692608833313, 8.99804311139243, 11.433748892375402, 13.216491631099156, 11.996178644044058, 8.185841253825597, 5.599808156490326, 10.135607395853315, 7.395674739565168, 4.014582293374198, 3.00083903329713, 1.774833191718374, 2.209247052669525, 0.8636844264609473, 0.31389784493616646, 0.5534208150846618, 1.5011002229792731, 4.003973696913038, 9.600768072264534, 19.595281873430523, 20.815448079790386, 28.917558329445974, 35.944066592625205, 33.44824586595808, 43.50439453125, 47.71032673971993, 33.64185047149658, 19.969195706503733, 5.19522454057421, 0.13384138526661055, 0.11090574134141207, 0.15156286076775619, 0.10378087258764676, 0.11400915017085415, 0.17266725402857575, 0.18953564816287585, 0.10374598910233804, 0.18658843130937644, 0.14856278603630407, 0.11531622574797698, 0.130645431045975, 0.13931628077157907, 0.14322897153241293, 0.17546428394104752, 0.1468092751290117, 0.11599856056272984, 0.12770030408033303, 0.16912737754838808, 0.16626997158995696, 0.12144695248986993, 0.12102347878473145, 0.10786254570952483, 0.12741655430623464, 0.134163268708757, 0.2230963023113353, 0.1231635646628482, 0.17561327666044235, 0.10748238289462668, 0.12317428551614285, 0.09713382819401366, 0.1336079692201955, 0.07046595668154103, 0.08708904683589935, 0.12329152279666492, 0.10417350687618766, 0.10414608727608408, 0.13116012699902058, 0.13060253406209604], [0.08039357539798532, 0.06839913901473794, 0.037480133652154884, 0.06694483490926878, 0.05514739081263542, 0.022433039466185228, 0.011689185530745556, 0.04008403214226876, 0.06942589141960655, 0.029248289298266172, 0.02109765710442194, 0.060420164306248934, 0.04186713056904929, 0.04422205759744559, 0.07647773623466492, 0.05202022307951536, 0.06739843556923525, 0.009332810678253216, 0.02500057696098728, 0.008921426770809506, 0.05651800101622939, 0.012343097361736, 0.06536721384951047, 0.0573404227782573, 0.07428852442119803, 0.09422184087868248, 0.04576687488172736, 0.011686331442823368, 0.049225808919540474, 0.04419935042304652, 0.034296108077147176, 0.0773304986900517, 0.08673636468925647, 0.028447402541392615, 0.00759666517842561, 0.10157513166112558, 0.018425277467550974, 0.005260228653371866, 0.04426007252186537, 0.026433715862887244, 0.02486608114226588, 0.013067972929483014, 0.030530479603580067, 0.010409442192342664, 1.0922531272683824, 9.409691742488317, 24.488048723765782, 41.615509373801096, 38.86982100350516, 24.4814635685512, 25.632821764264786, 18.135609524590627, 17.520546300070627, 23.621590988976614, 21.861485481262207, 16.1256902217865, 10.665378877094813, 7.009005316666194, 2.7053571173122952, 0.9554702384131295, 0.28476073699338095, 0.10008248354175261, 0.11867114715278149, 0.10269328951835632, 0.5842678855572427, 1.467461388025965, 0.9888409163270677, 0.9355709233454296, 2.505043591771807, 2.8222903055804114, 2.2733129177774702, 3.192721788372312, 2.799875634057181, 6.525399838175092, 6.972290601049151, 6.56307818208422, 2.983278112752097, 1.8007447613137109, 1.3408351370266505, 2.3171879691737036, 1.969195693731308, 3.912366475377764, 3.9585468087877547, 6.6131442955562045, 12.135801826204572, 16.301476172038488, 19.314076117106847, 21.875965527125768, 18.2070335320064, 21.96507269995553, 18.43655685016087, 22.135317461831228, 38.99726833615984, 33.35244410378592, 40.434874943324495, 37.95076540538243, 34.57481983729771, 32.51886524472918, 27.360487869807653, 22.33016058376857, 18.3104088306427, 12.568948183740888, 8.631506528173174, 4.623699162687574, 1.9548528747899192, 2.191772550344467, 1.3736521303653717, 1.2149133682250977, 4.70409676858357, 5.759002677031925, 2.165683150291443, 4.696878024509974, 2.887523033789226, 3.3873697093554904, 2.0772095663206915, 2.1151847285883765, 0.556861856154033, 0.5079882272652217, 0.11629886659128325, 0.35784188977309633, 0.48101418039628435, 0.27593780042869703, 0.3405962437391281, 1.061215958424977, 2.7363617164748053, 6.614048429897853, 7.210167390959604, 13.69849077292851, 22.510855436325073, 16.926885264260427, 21.427985634122575, 32.92053713117327, 36.718304361615864, 27.148038012640818, 15.911416462489537, 4.749298708779471, 0.47656282782554626, 0.0755976831008281, 0.007188828312791884, 0.042206123271690946, 0.04230256345389145, 0.012748644171681787, 0.011739245299915118, 0.04145468984331403, 0.027101353609136174, 0.08265706643994365, 0.0511402920819819, 0.027586908179468343, 0.013246054445127291, 0.05886080262384244, 0.034680111400250874, 0.008718967188282736, 0.04009607953152486, 0.03340187356142061, 0.04959459609485098, 0.015770241185756664, 0.02303189581393131, 0.02058879315986165, 0.057303646180246554, 0.06835503423852579, 0.07143024315259286, 0.011249398995589997, 0.016177916899323463, 0.038142594176211526, 0.07143285551241466, 0.07467090604560715, 0.025004790663453083, 0.018491544893809726, 0.01935463465218033, 0.017952947544732263, 0.06893082548465047, 0.01660370101620044, 0.010529196837783923, 0.0341841939038464, 0.003630013920233718, 0.10003841947764158, 0.036449184508195946, 0.052336637529411485, 0.04376389039680362, 0.027648556478587643, 0.05124477290415338, 0.044423626602760384, 0.016761718251343285, 0.025733732352299348, 0.015950626327789257, 0.03712537518835493, 0.02413868990593723, 0.010307264148390718, 0.035899102953927856, 0.016425010515376925, 0.05829299094953707, 0.08057471032121352, 0.04322355260540332, 0.050028288537370305, 0.0847378619281309, 0.014596667373552918, 0.009621543443894811, 0.016152278453643833, 0.038429210760763714, 0.03673456615901419, 0.059793164022266865, 0.05096530129334756, 0.0372455776669085, 0.022113206896132657, 0.06208837657634701, 0.039154825931681056, 0.07615166623145342, 0.045745989573853355, 0.006167639895076198, 0.0038434632255562712, 0.044541837581034215, 0.06973455699958972, 0.025349902055625404, 0.025629994525973285, 0.03400926757603884, 0.029054051863827875, 0.0019957150424098863, 0.035534098611346314, 0.05852373356797865, 0.04415600899873035, 1.5638363765818732, 12.561338169234139, 28.963022129876272, 47.08046211515154, 45.048180035182405, 30.15962873186384, 25.94083367075239, 23.427644184657506, 18.953978776931763, 23.58494966370719, 23.60706751687186, 17.781334774834768, 13.171370897974287, 6.678852541106088, 2.852341264486313, 0.9145491485084806, 0.45297803623335703, 0.1755264513194561, 0.29042902854936464, 0.40075409997786793, 0.2989860065281391, 0.6423303442341941, 1.4656157727752412, 0.45243395971400396, 2.50682841028486, 1.3651614316872187, 3.6136668920516968, 5.381352015904017, 3.8813071591513495, 5.2763877511024475, 7.819391523088727, 7.523597155298505, 5.716797581740788, 5.128044579710279, 2.804831870964595, 4.958687884466989, 2.7136048461709703, 4.990399028573718, 6.354864120483398, 8.865181394985743, 14.196316174098424, 18.823331798825944, 21.453202383858816, 25.57731260572161, 23.612594808850968, 25.84398446764265, 21.561415365764073, 26.24438657079424, 43.31051547186715, 38.15940591267177, 41.410304750714985, 38.58664716993059, 36.99319246837071, 33.273582049778526, 29.861762932368688, 24.21417157990592, 22.080110549926758, 14.775238343647548, 11.529269252504621, 7.816917095865522, 3.791246780327388, 4.18572814975466, 3.1280097407954077, 4.211125552654266, 5.64215178149087, 6.351218053272792, 6.192217648029327, 6.652401617595127, 2.9661395124026706, 2.4089895231383185, 2.2204534113407135, 1.5090486364705222, 0.9870978955711637, 0.753690208707537, 0.3132830379264695, 0.3708452263048717, 0.22378411968903883, 0.12539445209716046, 0.3518414960375854, 0.8734978884458542, 2.433202258178166, 8.440240859985352, 10.792274696486336, 21.866189411708287, 21.44173959323338, 21.363494191850933, 25.68034396852766, 34.21160970415388, 41.61917454855782, 33.51005009242466, 19.96579282624381, 6.114562409264701, 0.6416799819895199, 0.03107748060886349, 0.08063980897090264, 0.04697763241295304, 0.02465337228828243, 0.03478224788393293, 0.04171648222420897, 0.07617544209850685, 0.06105088974748339, 0.08398656081408262, 0.03655183667849217, 0.034191009788108725, 0.030114985470260893, 0.06368505768477917, 0.018514635440494333, 0.020925960603303144, 0.023422414769551585, 0.04166882870984929, 0.051644528417715004, 0.009890667395666242, 0.006818304087833634, 0.0457427054643631, 0.02403541687609894, 0.056939245733831606, 0.029739650432020426, 0.014691714862627643, 0.03682844487151929, 0.03158816981262394, 0.029667545908263752, 0.07086994286094393, 0.007556055705728275, 0.02976055270326989, 0.035765624937734435, 0.024871807977823273, 0.07436166371085814, 0.004651777820462095, 0.04814485174470714, 0.0681280642747879, 0.02222091584865536, 0.08912924557392086, 0.08086965592311961, 0.09542276643748794, 0.11034743594271795, 0.18347000649997167, 0.1338297687470913, 0.05852963003729071, 0.10351555182465486, 0.15745344039584908, 0.14740994146892003, 0.13692805463714258, 0.08971224964729377, 0.1857564388109105, 0.14689429556684835, 0.10175716903592859, 0.11944497562944889, 0.17110996187797614, 0.20096322282084397, 0.08392525517514773, 0.18886630050837994, 0.10179440703775201, 0.1590000388345548, 0.17618961073458195, 0.1093841672741941, 0.1557354847235339, 0.19676784080054077, 0.23298039979168347, 0.1600672658532858, 0.15379334108105727, 0.15433523271765026, 0.15108897191073212, 0.17314001651746885, 0.19690771400928497, 0.16055828093418054, 0.19449850757207188, 0.11571448509182249, 0.2035420901541199, 0.16251375100442342, 0.21889484061726502, 0.09944955286170755, 0.1725198897932257, 0.0852034455165267, 0.07424120338899748, 0.18373794640813554, 0.18633647768625192, 2.3980830226625716, 14.005610704421997, 34.28998538425991, 53.64403969900948, 51.31213045120239, 37.1801997593471, 38.31257895060948, 27.27804923057556, 27.15476734297616, 31.948011670793804, 29.667147363935197, 23.744970151356288, 15.122827189309255, 9.21026541505541, 3.6283514755112782, 1.8188439501183373, 0.9430540246622903, 0.39696003070899416, 1.0901705133063453, 1.271536952682904, 2.0769652937139784, 3.842775923865182, 3.431574365922383, 4.1563611541475565, 7.045333104474204, 10.536348223686218, 8.7450270652771, 10.13976502418518, 10.047067369733538, 15.09262684413365, 16.440662486212595, 15.24430080822536, 8.37211377280099, 6.806337220328195, 4.72893397297178, 4.797541788646153, 3.2393389897687093, 7.459248151097979, 6.161612136023385, 8.421472907066345, 14.567128505025591, 18.9826956817082, 21.289878027779714, 27.259176186152867, 25.53849823134286, 30.215363706861222, 25.80963257380894, 29.45389325278146, 46.925486019679475, 42.082049642290386, 45.81738036019461, 39.97805520466396, 38.67806461879185, 34.95828396933419, 30.28612416131156, 24.507458516529628, 22.168045214244298, 15.824176618031093, 12.35708110673087, 7.578113589968, 3.837598647390093, 4.315468387944358, 3.712825502668108, 5.312656479222434, 10.166315828050886, 13.146321773529053, 7.69850936957768, 14.185034036636353, 11.213135770389012, 8.999094894954137, 7.257796423775809, 7.0730273212705335, 3.523942849465779, 2.98909592628479, 0.8931984198944909, 1.6667919605970383, 0.8263800910540989, 0.6853229744093758, 1.0004108612026488, 1.2858596869877406, 3.620852415050779, 8.907207574163165, 11.131939990179879, 21.619804552623204, 30.30987310409546, 25.84971673148019, 30.81709507533482, 41.68479333605085, 47.88384757723127, 38.330244745527, 24.6146970135825, 7.447622946330479, 0.8536263661725181, 0.2509141889001642, 0.24477084140692437, 0.12555066442915372, 0.15033946212913307, 0.13845641405454703, 0.09124268538185529, 0.19912680850497314, 0.1261001827993563, 0.29539020519171444, 0.1283301202846425, 0.09323033836803266, 0.14085255190730095, 0.14744187332689762, 0.1360246802547148, 0.1412815217460905, 0.16038134614271776, 0.07780339010059834, 0.20773036112742765, 0.15289436360555037, 0.0885385876255376, 0.10694669306810413, 0.14603163328553947, 0.20920673119170324, 0.18592052214912005, 0.07497573790273496, 0.1904535839068038, 0.13046477788261004, 0.20618110283144883, 0.14389233450804437, 0.08410450377102409, 0.09972498379647732, 0.10413750380809818, 0.08028984096433435, 0.19451681444687502, 0.10345425297107015, 0.13733315361397608, 0.12056569834905011, 0.11513287201523781, 0.2720028672899519], [0.06215204351714679, 0.016274124683280076, 0.03222246095538139, 0.09046421572566032, 0.017365334522245184, 0.07345017404960734, 0.041030574922582934, 0.01905899355188012, 0.049595617290054045, 0.01249354044973318, 0.0449296169515167, 0.03651320767988052, 0.03851942877684321, 0.06155755863125835, 0.026699386071413755, 0.022876260236703923, 0.017556365878720368, 0.02025780886677759, 0.10226383113435336, 0.03407357233975615, 0.04697931857247438, 0.03945750683279974, 0.037160482590219805, 0.06246951648167201, 0.008031313507152455, 0.08938896163765873, 0.08649257384240627, 0.01862639863975346, 0.021310837540243353, 0.03337611297943762, 0.0563766757425453, 0.053164864158523936, 0.04419467531676803, 0.04429748694279364, 0.04936778897951756, 0.05228834958480937, 0.01752461213618517, 0.05792405788919755, 0.05227674663599048, 0.0498851108630853, 0.014039226258838815, 0.039808058379484076, 0.01794194001039224, 0.05645437139485564, 0.008477986324578524, 2.8093384291444505, 9.648960777691432, 29.988098553248815, 32.01888329642159, 39.055101667131694, 27.228671857288905, 15.791332483291626, 25.435143777302333, 26.670714139938354, 24.49713523047311, 20.91929759298052, 20.266135658536637, 13.546033399445669, 7.0992893406323025, 4.272800803184509, 1.7089120490210397, 0.36633641538875444, 0.14469874623630727, 0.2295317319887025, 0.24400697382433073, 0.2897554604070527, 0.8955545106104442, 0.3981991170772484, 1.5008055759327752, 1.2034601313727242, 1.6892272595848357, 3.5116655996867587, 4.103782398360116, 3.6412297444684163, 5.814866193703242, 7.141926961285727, 3.8622686607497076, 2.614613860845566, 1.6885153949260712, 2.7688588755471364, 2.1145292094775607, 1.3879308956010001, 1.7699650015149797, 2.7703427502087186, 5.931450017860957, 9.31012405667986, 13.560757500784737, 14.942806312016078, 14.321796298027039, 13.614524398531232, 13.972870792661395, 19.19658555303301, 33.111880098070415, 27.623666524887085, 33.9601856640407, 35.93351227896554, 31.084722314562114, 22.066003969737462, 18.96201263155256, 13.338386484554835, 10.546224219458443, 6.658335813454219, 4.018769885812487, 1.3368544706276484, 0.9467358099562782, 2.6404659364904677, 2.184840419462749, 2.995889310325895, 3.1689168257372717, 5.611049039023263, 5.0971515859876355, 3.2839972334248677, 2.763603214706693, 0.9440724785838808, 1.3594694456883838, 0.6040636290396962, 0.7877529380576951, 0.2562036136431353, 0.13834721062864574, 0.17418596467801503, 0.11784769062485013, 0.37354446575045586, 0.8873557448387146, 2.4132845955235616, 4.605448416301182, 7.698841146060398, 15.507776498794556, 14.16508662700653, 20.290101732526505, 23.72429231234959, 24.84665220124381, 35.57744836807251, 29.34808955873762, 21.39949801989964, 10.100750889096942, 1.6002175786665507, 0.03835859222869788, 0.021921020333788226, 0.06496975517698697, 0.028693895653954575, 0.052306798951966424, 0.008332903663228666, 0.13680814392864704, 0.046830186753400734, 0.008869025207656835, 0.050578102070306025, 0.06296754761465959, 0.05556241336411663, 0.03413305611216596, 0.014520610383312618, 0.07527764527393238, 0.06875686267656939, 0.01805385248735547, 0.05084180113460336, 0.025960671781961406, 0.05414967631388988, 0.047116063734782596, 0.06229148924882923, 0.03804046108520456, 0.027606421150267124, 0.020500788864280497, 0.025392710829951932, 0.0876269486865827, 0.030283034845654453, 0.005193442995992622, 0.04061333016891565, 0.01363607298117131, 0.031658652637686045, 0.04730770916544965, 0.1213353199086019, 0.015048663298200284, 0.021274629215310727, 0.03489156326811228, 0.030841648977782046, 0.06715791526117496, 0.040796005366636176, 0.0014245725033106282, 0.07029866387269326, 0.06290984499667372, 0.07881116388099534, 0.06536427579287972, 0.03095156147277781, 0.017497550463303924, 0.02334814571908542, 0.016871472986947213, 0.05037165439820715, 0.02424986277973013, 0.021456617396324873, 0.12041301439915385, 0.07826038343565804, 0.02134043863043189, 0.031074552730258023, 0.00823823785010193, 0.0729695473398481, 0.08153940391327653, 0.058950403173054965, 0.042057228939873834, 0.007756388929140354, 0.042869567671524625, 0.091969369245427, 0.09125009498425893, 0.06777439146701779, 0.044357703533023596, 0.06255391945264169, 0.05469382407941988, 0.03562736324965954, 0.08264975183244262, 0.0367298944454108, 0.052695209360016246, 0.06723330728709698, 0.004278932581655681, 0.0023077588786171483, 0.0629391712801797, 0.0665951586727585, 0.025109497098518268, 0.06518429437918322, 0.038065122440457344, 0.09169541073164769, 0.03152608046574252, 0.02528991616730179, 0.026109896899600114, 3.7246317948613847, 13.399308289800372, 35.848761626652305, 37.47842339106968, 42.02280582700457, 31.421987874167307, 18.04488515853882, 24.103835923331125, 25.369542360305786, 28.62945474897112, 27.609424454825266, 22.642605440957205, 16.0004107270922, 7.2262372715132575, 3.9832307185445512, 1.5626461718763625, 0.3716554785413401, 0.1369452215731144, 0.2348862418106624, 0.15894319117069244, 0.3097709949527468, 0.7005668335727283, 0.5169365299599511, 1.698670621429171, 2.2441917146955217, 2.456853926181793, 1.894482582807541, 4.7556237408093045, 5.355991959571838, 5.822190029280526, 5.323979437351227, 5.362916707992554, 7.0442787153380255, 5.560985965388162, 4.961760725293841, 3.479473292827606, 2.5505688403333937, 2.9971156673771993, 4.396391885621207, 7.509991713932582, 10.939292498997279, 15.977076939174108, 18.157386916024343, 17.54930141993931, 15.566487039838519, 16.494179248809814, 23.641412462506974, 37.33767025811331, 31.46939195905413, 36.79585668018886, 36.534340381622314, 31.205353464399064, 25.475540603910172, 21.811215264456614, 17.083575827734812, 12.92852440902165, 9.233282191412789, 5.946995309420994, 3.8556183661733354, 3.041752197912761, 4.769877101693835, 4.53895936693464, 3.938297152519226, 5.8634896874427795, 4.809171336037772, 5.4198519842965265, 5.335690191813877, 1.6042667499610355, 2.8803983075278143, 1.402861814413752, 0.6076654557670865, 0.6281406027930123, 0.2685159572533199, 0.12101323290594987, 0.19726929175002234, 0.09545855915972165, 0.504600003361702, 0.8180334589311055, 3.0217179358005524, 5.459082816328321, 10.288315773010254, 15.034567696707589, 16.56385404723031, 26.42158647945949, 23.221480710165842, 29.0978102343423, 40.616830893925254, 35.16791459492275, 25.018574953079224, 12.517048614365713, 1.7759718277624674, 0.052212099212088754, 0.020790523317243372, 0.005646433822611081, 0.007849345682188869, 0.04743975208007863, 0.048268409578927925, 0.025832357417259897, 0.012140554658669447, 0.03917584016120859, 0.06950945979250328, 0.04107188752719334, 0.020226691250822375, 0.051474982872605324, 0.009924840115542923, 0.10812915568905217, 0.012549914835420038, 0.04329990136570164, 0.009738544085329133, 0.02069699574661042, 0.019996569491922855, 0.03184635238721967, 0.0693880088095154, 0.02705688581668905, 0.03546975652820297, 0.02480277552136353, 0.03886425688064524, 0.07209594028868846, 0.020542584925091693, 0.061310517601668835, 0.020255125260778835, 0.05465592789862837, 0.03628384248752679, 0.07392605779958622, 0.10337582110826458, 0.005251337300121252, 0.0814300240682704, 0.022142032760062387, 0.03526357009208628, 0.05133468897214957, 0.043036955475275, 0.12825803272426128, 0.10001505751694952, 0.09440937438713652, 0.17697178519197873, 0.13860664170767578, 0.1581508929708174, 0.161670752667955, 0.10521288681775331, 0.12824585980602674, 0.1765559110790491, 0.17425556880022797, 0.12938000394829682, 0.2576211547212941, 0.19977732002735138, 0.08266917150467634, 0.2114959726376193, 0.09440635490630354, 0.1789798145847661, 0.26280616649559563, 0.13291549709226402, 0.07235904902751956, 0.16688749273972853, 0.10641988526497569, 0.1371925747288125, 0.15838357619941235, 0.17928776091762952, 0.15624697799129145, 0.15270985636327947, 0.17302742041647434, 0.10869908439261572, 0.19477117008396558, 0.1330621556511947, 0.15813342747943743, 0.16557904652186803, 0.17265532538294792, 0.09677647772644248, 0.22218523334179605, 0.18399954879922525, 0.14662958548537322, 0.18673754616507462, 0.1787455707256283, 0.16564855564917835, 0.1936081474913018, 0.11187798702823264, 0.19910753811044352, 4.202477216720581, 16.626290559768677, 40.567293712071006, 46.42721332822527, 52.0953939301627, 40.07938078471592, 25.80202603340149, 36.6727728162493, 39.886526584625244, 36.10096386500767, 30.899552822113037, 27.948847430092947, 19.54194576399667, 9.835957646369934, 5.912746335778918, 2.805868889604296, 1.0304557404347827, 0.40856528654694557, 0.7101914999740464, 0.8686270926679883, 1.220121368765831, 2.76078137755394, 2.139104336500168, 6.472418086869376, 6.731895089149475, 5.605167388916016, 10.094466243471418, 11.067385145596095, 11.351388420377459, 14.402992946760994, 17.011071375438146, 8.764374324253627, 9.005133748054504, 8.791678139141627, 6.869102903774806, 5.960557324545724, 2.748636794941766, 3.1374440916946957, 3.3377925753593445, 7.028074647699084, 11.681844745363508, 16.644229071480886, 19.535037517547607, 21.88229012489319, 20.604832547051565, 20.991772515433176, 26.718656710215978, 39.543289048331125, 35.18742861066546, 39.411453928266255, 39.824315888541086, 34.17265115465437, 25.62834538732256, 21.358904906681605, 15.335841587611608, 13.312659042222158, 7.691314509936741, 7.1132678134100775, 2.3055265034948076, 2.8909508841378346, 5.411376919065203, 7.21562259537833, 10.139856219291687, 11.37973359652928, 13.953029343060084, 12.725552763257708, 11.218709962708608, 10.61037346294948, 8.296150854655675, 7.853357791900635, 3.9370178154536655, 2.6789378949574063, 1.8339581276689256, 0.814155387026923, 1.1126240513154437, 0.9578268719570977, 1.0610638580151965, 1.471074559858867, 3.4946331764970506, 6.764757028647831, 12.186487197875977, 22.891472543988908, 22.51364861215864, 29.416671752929688, 31.605889320373535, 34.47377218518938, 47.220034054347444, 40.52562883922032, 29.10412440981184, 14.26992278439658, 2.3309080558163777, 0.18208115388240131, 0.1566749843103545, 0.1978022131536688, 0.12667425056653364, 0.1509113178721496, 0.10963259251522166, 0.17813403425472124, 0.16942904064697878, 0.21390452768121446, 0.13682114465960435, 0.10382491629570723, 0.11198094793196235, 0.07380825733499867, 0.11143771279603243, 0.26217396184802055, 0.10679276739912373, 0.10995423168476139, 0.10206242158476796, 0.15198144902076038, 0.13065616546997003, 0.1431470587849617, 0.14449753346187727, 0.14852368884852954, 0.08936727565846272, 0.1162202243826219, 0.10225003651742424, 0.19213838635810784, 0.1589250878563949, 0.15275849375341619, 0.0936320921672242, 0.19046110207481043, 0.20005026752395288, 0.14547830154853209, 0.2702644334307739, 0.10791610247854676, 0.24988083434956415, 0.12133271433413029, 0.08832076431385108, 0.1546229722776583, 0.10822528374514409], [0.07834897296769278, 0.03318862018308469, 0.040899040909217935, 0.02021176856942475, 0.018023250558014427, 0.05696419546646731, 0.05473651071744306, 0.02822978957556188, 0.02681083544822676, 0.08295064140111208, 0.05255909523527537, 0.01886929721305413, 0.05457325179928115, 0.024508009731237377, 0.015957925668252364, 0.02584158379717597, 0.017996609576844742, 0.015177635841869881, 0.05555217766336032, 0.10491461639425584, 0.010590844288734453, 0.09969162701496057, 0.0684924375798021, 0.06552309369934456, 0.021019793514694487, 0.07059422694146633, 0.07406489963510207, 0.0515023549752576, 0.052413712322179756, 0.015879906015470624, 0.044923272649092336, 0.053498584644070694, 0.03652328731758254, 0.03821226954460144, 0.029432101042142937, 0.05524668423458934, 0.019542514213493893, 0.05932960246822663, 0.003342585638165474, 0.051083356208567104, 0.04927769988509161, 0.020083442330360413, 0.031211464133645807, 0.05682041389601571, 0.04838075801464064, 0.32879472843238283, 3.8390981554985046, 15.49390094620841, 27.087482724870952, 40.81185293197632, 31.705154759543284, 23.437171901975358, 16.05052982057844, 20.837345327649796, 17.51002672740391, 17.800054958888463, 23.451844760349818, 21.73156632695879, 16.14661819594247, 7.966011541230338, 4.882456157888685, 2.58329507282802, 1.06577191395419, 0.47483191213437487, 0.13874291868082114, 0.23626079091003963, 0.12923405106578553, 0.019924146056707417, 0.632057215486254, 0.5111271302614893, 3.41880835379873, 1.871931552886963, 2.6919077932834625, 3.7913722821644376, 3.934749662876129, 2.4637730291911533, 8.759911843708583, 6.208482078143528, 4.024384464536395, 7.087026638644082, 2.450680668864931, 1.7411650440522601, 1.0864621294396264, 1.6870481308017458, 1.9091324252741677, 4.313148992402213, 7.669338226318359, 7.9783967052187235, 9.825894049235753, 7.96099146774837, 11.509611061641149, 18.33932375907898, 26.67403190476554, 29.528249400002615, 32.19327960695539, 29.49372727530343, 24.335172721317836, 15.105114494051252, 9.983623368399483, 7.140301517077854, 4.711239950997489, 3.3771024431501115, 1.4092347238745009, 5.025416212422507, 2.694991707801819, 1.9268210189683097, 2.3026881643704007, 1.6180621811321803, 5.103721542017801, 2.1680631254400526, 5.10341625554221, 4.604472628661564, 0.967090557728495, 1.6970892548561096, 0.34415952967745916, 0.4335740788706711, 0.17207869275340013, 0.22518078903002398, 0.11545057568166937, 0.17283889624689305, 0.562988321696009, 1.439480015209743, 2.9778984699930464, 4.634169663701739, 9.836133088384356, 12.93584520476205, 19.652689627238683, 17.382423060280935, 16.012384210314067, 25.735868760517665, 28.37504472051348, 26.875741583960398, 21.3539525781359, 14.02582996232169, 1.6623488047293253, 0.02067826478742063, 0.02062611428222486, 0.03653232540403094, 0.023901202649410282, 0.04876467652086701, 0.04767623510477798, 0.03317141932036195, 0.040572821628302336, 0.09369251571063485, 0.01166392197566373, 0.015807908360979388, 0.014880276351634945, 0.03003149852156639, 0.036272358282336166, 0.018690496450290084, 0.022517664657373513, 0.04245802939736417, 0.11142456278737102, 0.009759360691532493, 0.0032908263508163926, 0.03458527595336948, 0.02086534028473709, 0.0342002073302865, 0.04834482619272811, 0.028259153178493892, 0.0649319811324988, 0.027513161600966538, 0.05257892881387046, 0.09135622464652572, 0.0037942724052949673, 0.0377138211125774, 0.020790519924568276, 0.005374160196099962, 0.05849142173039062, 0.021450013554255878, 0.014001378423667379, 0.047998607092137845, 0.054194225530539236, 0.05788449251226016, 0.018703943318022147, 0.06287928377943379, 0.04647072943459664, 0.023513547111568705, 0.04733252997643181, 0.02755866924832974, 0.059912124781736305, 0.03599955667076366, 0.02302382294354694, 0.013525893313011952, 0.03528047239940081, 0.0862337127327919, 0.04499475631330695, 0.046731134211378436, 0.018891770292871764, 0.07426009380391665, 0.07369640762252466, 0.043174033119742355, 0.05002154389928494, 0.018228568469307253, 0.09849808391715799, 0.06668368035129138, 0.12189034798315593, 0.07856512029788323, 0.04476316213341696, 0.04248489938410265, 0.028393581143713424, 0.015888916960518275, 0.06346596551260777, 0.08809835410543851, 0.037015835887619426, 0.01883317540133638, 0.10221990956259625, 0.08908995161099093, 0.03338896443269082, 0.04865850953917418, 0.03307758131995797, 0.021385369523029243, 0.034987898277384896, 0.021660115137430172, 0.044860151928982565, 0.045191633248967786, 0.07725229752915246, 0.02274664817377925, 0.04672604859141367, 0.00930240043505494, 0.02107033589189606, 0.41113628287400517, 5.40399489232472, 18.732084580830165, 33.786327838897705, 45.755951336451936, 39.937265804835725, 28.802793196269445, 22.982811825616018, 25.637676818030222, 23.734580857413157, 26.421093157359532, 28.539965425218853, 23.356814248221262, 19.408835649490356, 9.199682440076556, 4.816301924841745, 1.9651653042861392, 0.6711126597864288, 0.2392000417624201, 0.06194147374480963, 0.13384922913142613, 0.6992437445691654, 0.3624062862779413, 0.9302608711378915, 0.8682474387543542, 0.6567463906747955, 1.9326383982385908, 2.87417402437755, 3.9880640591893877, 2.881143501826695, 4.5198036176817755, 6.5221545951707025, 4.702864766120911, 4.62742383139474, 5.424468193735395, 4.22111575944083, 3.4893039081777846, 2.5889357072966437, 4.407618003232138, 3.179783808333533, 6.2049484848976135, 10.181448136057172, 11.91301999773298, 13.509518010275704, 9.75117312158857, 12.765226108687264, 22.80008462497166, 28.928663287843975, 30.13058873585292, 32.090008531297954, 31.501485688345774, 26.113607576915197, 17.17549875804356, 12.56504329613277, 9.859960198402405, 8.001305784497942, 5.248535897050585, 4.076541551521846, 3.9609565309115817, 3.5843991254057204, 4.013751549380166, 5.488429835864475, 5.46496012381145, 5.388704947062901, 3.4576364074434554, 2.058838963508606, 4.188558237893241, 1.4555361079318183, 1.5161465470279967, 0.7993768943207604, 0.5047519409230777, 0.33061434222119196, 0.039437608793377876, 0.14014136578355516, 0.1782561027045761, 0.19425704410033567, 1.0615991950035095, 3.2219908578055243, 6.156572086470468, 10.759866561208453, 14.308202147483826, 23.841400725500925, 18.549023866653442, 19.843759877341135, 30.002439635140554, 31.348618371146067, 31.51732063293457, 26.976568630763463, 17.12488807950701, 2.7678694086415425, 0.1835787213806595, 0.044625914855194945, 0.0702886554811682, 0.06591962277889252, 0.04341018705495766, 0.04220705286466649, 0.023170335617448603, 0.01797549526340195, 0.03781452249469502, 0.04249666178865092, 0.05408050984676395, 0.020480727976454154, 0.03865144455007144, 0.012697206128255596, 0.016378240792879036, 0.02805536536366812, 0.02671945035191519, 0.0636203797268016, 0.019516516144254377, 0.04949659528210759, 0.010423945030197501, 0.05870212720973151, 0.016217746904918125, 0.04631903953850269, 0.10287749820521899, 0.10844360238739423, 0.030383213755807707, 0.026329721889591644, 0.0699197631329298, 0.0492541615052947, 0.034172407750572474, 0.015089964028447866, 0.024452778677056943, 0.034285631496459246, 0.028862331794308763, 0.05096657693918262, 0.0417165670410863, 0.06866002894405808, 0.06518885413450853, 0.048031984229705164, 0.015924831819055334, 0.17945352702268533, 0.08730033585535628, 0.15008376299270562, 0.18511009349354676, 0.16526415199041367, 0.12921537778207234, 0.14610639427389416, 0.12546367623976298, 0.1397111474403313, 0.14421233162283897, 0.09704786459250109, 0.1001084442915661, 0.162372195028833, 0.13608922250568867, 0.16647627337702683, 0.2009839859924146, 0.11800922267138958, 0.14425142881061348, 0.17652543128601142, 0.16326220227139338, 0.2887989160205637, 0.18869471257286413, 0.20191258830683573, 0.20713232750339167, 0.17642107260014328, 0.10817877695496593, 0.23139463631170137, 0.14563329251749174, 0.12494841031730175, 0.09673646451639277, 0.151221666218979, 0.12976872308978013, 0.24545029923319817, 0.26413112825581003, 0.10162012531821217, 0.13216692368899072, 0.15795307287148067, 0.13446535249905928, 0.10517522812421833, 0.14808109402656555, 0.17393509671092033, 0.09507720212319068, 0.16869941194142613, 0.1685252320021391, 0.17070099525153637, 0.5560601534587997, 6.286415244851794, 22.123008728027344, 38.51705053874424, 53.34559025083269, 48.31537587302071, 37.05460064751761, 28.095483950206212, 32.88342332839966, 27.49704429081508, 28.348170825413295, 33.16276175635201, 30.164113794054302, 22.912266765322002, 11.674184356416974, 6.557396726948874, 3.6429322702544074, 1.5220915994473865, 0.8924667962959835, 0.46789424440690447, 0.965987748333386, 1.9050319024494715, 1.1333736521857125, 2.555236292736871, 3.793880147593362, 7.7415569339479715, 7.508589914866856, 10.587482622691564, 9.750622476850237, 12.41775711945125, 8.974565148353577, 16.679496390478953, 14.816260508128575, 7.530719058854239, 15.758380651473999, 7.169085298265729, 5.22611232314791, 2.6151243363107954, 3.7064926539148604, 3.120381053004946, 4.885661014488765, 10.576119712420873, 11.85370670046125, 14.924859115055629, 14.638117381504603, 17.018518107278005, 24.270795924322947, 31.18440464564732, 31.004484517233713, 34.496645654950825, 31.14317056110927, 28.115564244134085, 18.029692922319683, 12.202448078564235, 9.238120743206569, 8.725498284612383, 5.652533692973001, 2.834318071603775, 8.210119128227234, 6.052412075655801, 6.977795745645251, 7.515541587557111, 6.364061364105769, 12.756843975612096, 8.450089931488037, 13.32634265082223, 10.781342574528285, 3.234824614865439, 4.995988420077732, 3.728175376142774, 2.3194784862654547, 1.6754736261708396, 0.569945368383612, 0.504472655909402, 0.5296883742724146, 1.219459769981248, 1.9052677069391524, 4.0178835562297275, 7.495035716465541, 13.08709098611559, 20.12602002280099, 28.608884607042583, 26.00440447671073, 25.822476318904332, 35.61600044795445, 38.59403657913208, 36.87735210146223, 31.530591692243302, 19.378102030072892, 3.360960692167282, 0.27163607840027126, 0.13110904688281672, 0.21813771767275675, 0.10319938843271562, 0.16578749247959682, 0.10955699014344386, 0.09756428402449403, 0.12767548326935085, 0.16298267298511096, 0.14417478149490698, 0.1545249918209655, 0.12238027740802083, 0.12553180115563528, 0.11076169514230319, 0.10287516404475484, 0.16653139756194182, 0.1512440035917929, 0.2551109551319054, 0.11351579414414507, 0.200294892968876, 0.15277187446398394, 0.10550259412931544, 0.12556175169135841, 0.16896011866629124, 0.16039976158312388, 0.17747231333383492, 0.1751562561839819, 0.21143565087446145, 0.2524408112679209, 0.15738211279468878, 0.1365125197917223, 0.05880428744213922, 0.1340894169573273, 0.1644164446209158, 0.17292956209608487, 0.2193178664892912, 0.22090862398701056, 0.15877709936882767, 0.09554942178406886, 0.11270776750253779, 0.15070987439581326], [0.028348948806524277, 0.017303045007533262, 0.021004249973754798, 0.03709511252652321, 0.0413609773718885, 0.01983903062396816, 0.0054057837447284585, 0.024893802690452764, 0.03394087803150926, 0.042947504203766584, 0.06702720906053271, 0.09499518081013646, 0.054356904301260195, 0.019331196356298666, 0.028376085118257573, 0.018093797843903303, 0.027090281613969376, 0.05319343048280903, 0.027780470471563082, 0.03333581478468009, 0.04476999158837965, 0.03697487272854362, 0.024875762140644447, 0.03107106845293726, 0.049401960003056695, 0.03376920188644102, 0.05146156144993646, 0.020315250248781273, 0.009191877258542393, 0.030324160853134732, 0.014535804478717702, 0.045879881496408155, 0.018107743434874073, 0.04832727249179568, 0.01361959136556834, 0.01582707527891866, 0.04155527248180338, 0.016287459592734064, 0.0195090760077749, 0.024252271579046334, 0.026660548423283865, 0.05815308381404195, 0.0240952042929296, 0.02750424395448395, 0.03306500467338732, 0.04174355577145304, 0.6708356546504157, 3.54672794682639, 17.77191996574402, 28.200233255113872, 38.431361879621235, 31.850181034633092, 23.845842361450195, 15.106738635471888, 15.668429272515432, 22.88866720880781, 22.534086738313945, 21.319161210741314, 13.220182861600604, 18.519693783351354, 11.774095109530858, 5.604406561170306, 3.394980158124651, 0.9063893035054207, 0.5125167156968797, 0.05745215035442795, 0.31663052258746965, 0.23754848752702984, 0.4622586582388197, 0.3269551657140255, 0.8166937051074845, 0.8220953866839409, 1.8208541508231844, 2.3524324893951416, 1.1074210447924477, 2.059572215591158, 3.3689932440008437, 4.1597266878400525, 4.879587854657855, 2.588740506342479, 2.258228595767702, 2.4209621378353665, 1.932683561529432, 2.0856084184987203, 1.2080929513488496, 2.6670712402888705, 4.084119430610111, 5.312867530754634, 5.368876525333949, 3.6752227204186574, 5.728577818189349, 15.158283846718923, 20.700839281082153, 24.95019425664629, 30.941641535077775, 26.538187674113683, 17.2069410937173, 10.107558386666433, 4.417027601173945, 3.4645763550485884, 1.9791066476276942, 2.1588465571403503, 2.3809415996074677, 1.6047220740999495, 2.66936132311821, 3.8809614862714494, 5.245790490082332, 4.768279884542737, 2.899485009057181, 3.1632145260061537, 1.082069565142904, 2.7391805137906755, 0.8182858739580426, 0.7705468641860145, 0.500434829720429, 0.30263562926224297, 0.24090311037642614, 0.23284330857651575, 0.07486282967563186, 0.5258472689560482, 0.7821396078382219, 2.3698874499116624, 5.809277670724051, 8.245682614190237, 14.230965103421893, 16.8812929221562, 10.657450113977704, 16.132869447980607, 18.649361065455846, 24.990481649126323, 31.23503964287894, 25.761264426367624, 14.84151199885777, 6.563357847077506, 0.15556186118296214, 0.0633612811299307, 0.07460143084504775, 0.07168803217687778, 0.024288815778813193, 0.031852462595062594, 0.052003829673464806, 0.019322892784007957, 0.02974957400666816, 0.02334223567907299, 0.05743657797574997, 0.006394142093735614, 0.06595851640616145, 0.060587396046945026, 0.023351380634786825, 0.049655786382832696, 0.05122185538389853, 0.00849185133951583, 0.03858944002006735, 0.03194861439988017, 0.10164563144956316, 0.09703590202012233, 0.0030446633879494455, 0.03307438881269523, 0.09193555784544774, 0.021375556210322038, 0.009008013776370456, 0.04741619334423116, 0.05314835879419531, 0.020735120932970728, 0.09232785965182952, 0.045935049786099365, 0.0744632404031498, 0.03290780846561704, 0.02592172726456608, 0.04884047906047531, 0.08716144652238914, 0.02524889024373676, 0.041932707585926564, 0.01656192191876471, 0.034882023065750084, 0.030919975667659725, 0.026975093509203622, 0.0487888255821807, 0.052747063006141355, 0.036808835209480355, 0.03799843941149967, 0.11663134875042097, 0.04679529309006674, 0.03369357576593757, 0.024422069878450463, 0.03160949616826006, 0.027281024593061635, 0.019537124949108278, 0.04883378191984125, 0.0808538528425353, 0.04422907704221351, 0.008372557249718478, 0.026407437897952538, 0.04042551167575376, 0.012831427988463213, 0.009196545579470694, 0.052883102492030175, 0.013287114295443254, 0.05375795465494905, 0.06605622544884682, 0.04644152868006911, 0.012847810368319708, 0.0121189399256504, 0.03780076180451682, 0.0733047572097608, 0.063408520737929, 0.019705866430220858, 0.019853098351242285, 0.02831278458636786, 0.03578794873984797, 0.0817731117297496, 0.025868871082950915, 0.038547554053366184, 0.013379680890856045, 0.031086623868239776, 0.018986792336883287, 0.018277460310075964, 0.05319294872294579, 0.05081074119412473, 0.016695142091651047, 0.005334585489306066, 0.01799771558892514, 1.056177863052913, 5.492859312466212, 22.11208094869341, 34.9730349949428, 44.239368030003135, 36.82170050484793, 28.373609917504446, 20.897297859191895, 16.56905824797494, 23.461037227085658, 28.318027802876063, 35.52584062303816, 20.726156779697963, 19.71495417186192, 13.898698772702899, 6.297980955668858, 2.8033445222037177, 1.054221510887146, 0.2279942530606474, 0.09756950874413763, 0.14174817741981574, 0.5785509837525231, 0.26593288300292833, 0.6132843771151134, 0.99752953009946, 1.4294493134532655, 2.859552408967699, 2.8451876597745076, 1.7080126915659224, 3.186225005558559, 5.243142792156764, 5.413325020245143, 5.9494237048285346, 5.66422837972641, 5.139884310109275, 2.855938042913164, 2.8547216738973344, 2.9810032291071753, 2.0154900210244313, 3.7078605805124556, 4.815409081322806, 7.084041084562029, 8.347343444824219, 6.440999201365879, 9.163934826850891, 19.575759172439575, 23.69283434322902, 28.255999497004918, 32.85365377153669, 28.63827896118164, 20.86802336147853, 12.777798005512782, 7.96625212260655, 5.303172622408185, 3.988417548792703, 3.6113455423286984, 3.665969022682735, 3.541617763893945, 5.114738779408591, 4.051169335842133, 5.393477056707654, 4.741776415279933, 4.654540044920785, 2.245558121374675, 1.5278435136590685, 2.1635945652212416, 0.714532767023359, 1.1244349032640457, 0.5369045670543398, 0.09962880824293409, 0.15229581429490022, 0.1430116639073406, 0.18389342592230865, 0.34843921288847923, 1.1982763409614563, 3.1078925345625197, 6.440740380968366, 11.112690005983625, 17.773328713008336, 19.572632483073644, 14.933068411690847, 19.623854603086198, 22.33626283918108, 28.725400686264038, 35.82926845550537, 30.554543495178223, 18.98805274282183, 7.86392947605678, 0.35401318807687077, 0.008577011725200074, 0.03195619363603847, 0.04591870727017522, 0.03477055672556162, 0.06036079927746739, 0.040602354864989004, 0.06158905622682401, 0.04350186052865215, 0.06152504323316472, 0.01793571105892105, 0.07215740199067763, 0.05032938166654535, 0.07682114959295307, 0.03917114809155464, 0.009137592760712972, 0.034493320887642245, 0.03302504574613912, 0.0560877046414784, 0.046867119414465766, 0.0871633260643908, 0.020222523349470327, 0.014715684112161398, 0.022470844044749225, 0.012697215458112103, 0.055380270816385746, 0.007258673314936459, 0.05809053645602294, 0.03943244853456106, 0.055671918738101206, 0.03271492810121604, 0.04042265165065016, 0.056221152123595984, 0.04020822101405688, 0.05450950682695423, 0.01443718619910734, 0.07285172651921, 0.026246794732287526, 0.05311871020655547, 0.02547630125523678, 0.018887922999316027, 0.026376274480883564, 0.18603450246155262, 0.13471582691584313, 0.2547622966979231, 0.12804721189396723, 0.08229925456855978, 0.15443439382527555, 0.11373996854360614, 0.12961548274116858, 0.09061508120170661, 0.12230144520955426, 0.189699134390269, 0.18989267971898827, 0.13934259435960225, 0.16001592789377483, 0.10632434753434998, 0.07452393536056791, 0.11034566496631928, 0.14402557164430618, 0.11341096726911408, 0.111942766766463, 0.11389683905456748, 0.13037682617349283, 0.12382387423089572, 0.17840904449777945, 0.10983272641897202, 0.131049566503082, 0.12985078511493547, 0.1574996757720198, 0.1290233659424952, 0.13157355838588305, 0.11843180071030344, 0.13680001507912362, 0.11870497890881129, 0.1032724937956248, 0.287594272089856, 0.11052979901432991, 0.11559120884963445, 0.11136333857263837, 0.18798036447593144, 0.088099609395223, 0.0884071553924254, 0.08584585533078228, 0.1651571470179728, 0.12645840857710156, 0.10088579436498028, 0.18589240365794726, 1.159962345446859, 6.70020956652505, 26.422613075801305, 38.98457397733416, 51.58636542728969, 45.14560420172555, 36.73535524095808, 27.211653981889995, 26.36673739978245, 33.23282044274466, 37.26606559753418, 33.84330306734358, 20.946440730776104, 24.725072622299194, 16.513840913772583, 7.8444545439311435, 4.821731507778168, 1.7227988924298967, 0.9063255212136677, 0.6163365361945969, 0.7538090337600026, 1.0558602000985826, 2.0362998758043562, 3.4069132549422125, 2.8799149734633307, 3.7218290652547563, 6.7197461639131815, 6.9114000626972745, 9.548575810023717, 7.201278473649706, 10.184298634529114, 11.689523373331342, 12.316398535455976, 7.561662861279078, 9.297114423343114, 5.824941081660135, 4.584708912031991, 3.740269584315164, 2.832607729094369, 4.10929535967963, 5.037706272942679, 8.543351258550372, 10.64368052142007, 6.949964736189161, 10.882953899247305, 19.320558786392212, 23.38393827847072, 29.60319267000471, 34.158379554748535, 30.2852452141898, 20.31610189165388, 12.568940367017474, 7.58916209425245, 5.791926716055189, 4.5422471676553995, 5.354813805648258, 6.097557996000562, 6.436423812593732, 6.672165768487113, 10.562225920813423, 12.91231860433306, 13.427760294505529, 10.807577235358101, 11.887074555669512, 4.704896679946354, 7.9007314784186224, 4.0548649089677, 3.7036994780812944, 1.9878018839018685, 1.0946589410305023, 0.6238063382250922, 0.8290029817393848, 0.5740182069795472, 0.7119274096829551, 1.647547838943345, 3.376209165368761, 8.345023615019661, 12.277840375900269, 21.31273933819362, 24.762318440846034, 19.29880918775286, 25.61615824699402, 28.82691560472761, 34.39187029429844, 42.90431335994175, 35.72715425491333, 22.58820799418858, 9.306418061256409, 0.6604511375938142, 0.09834903012961149, 0.1611286031880549, 0.15782223774918488, 0.0888487934800131, 0.13707030271845205, 0.11566625482269696, 0.13385425029056414, 0.16334419644304685, 0.14573956467211246, 0.09698883204587869, 0.17410443191017422, 0.1823443304747343, 0.20042173830526216, 0.24188915746552603, 0.0960295395925641, 0.1457102655300072, 0.0963659029720085, 0.20526312637541974, 0.16818050907126494, 0.17734293027647904, 0.14629259785371168, 0.1465920489281416, 0.18839537006403717, 0.13185425475239754, 0.19625804387032986, 0.0922446305464421, 0.10977277785007443, 0.1831845332469259, 0.133606205029147, 0.1517090443521738, 0.14998884951429708, 0.09571972728839942, 0.16581485101154872, 0.10856467339077167, 0.11263703701219388, 0.12737785066877091, 0.10499298040355955, 0.14838011083858355, 0.1102943541482091, 0.16297993170363562, 0.1348598799003022], [0.011684908215621752, 0.011409262694152338, 0.019074874663991586, 0.0758063258337123, 0.020598233278308595, 0.0031484468033470747, 0.043565775134733746, 0.07182937102126223, 0.030033578231398548, 0.019397132996735827, 0.047331892153514285, 0.037391201459935734, 0.018568502639287283, 0.017536657829103724, 0.026741903075682263, 0.02800060249865055, 0.02864536004407065, 0.047761771229228804, 0.053584470214056115, 0.04439048695244959, 0.04813875510756459, 0.06070960698915379, 0.08048381377011538, 0.04147014008568866, 0.024170504716624106, 0.02367073144497616, 0.041802547605974336, 0.054035343163247616, 0.04595151783100196, 0.05455805261486343, 0.019268543825351765, 0.022789570602721403, 0.011970139740567123, 0.06258478601064, 0.022729391331917474, 0.03274292784876057, 0.02672681924221771, 0.0071406760751934984, 0.025632082717493176, 0.03626166796311736, 0.046143020769315105, 0.03542834892868996, 0.07099598074065787, 0.023268319466816526, 0.02131473402758794, 0.0585174842604569, 0.07631817872502974, 0.2673168773097651, 4.976367575781686, 17.70554903575352, 30.233230999537877, 40.66036135809762, 33.30066612788609, 27.216955457414898, 21.288564818246023, 14.687341894422259, 17.218416043690272, 14.60440298489162, 30.734863145010813, 28.12210076195853, 12.251220958573477, 7.8853490352630615, 5.783960172108241, 3.76923315014158, 1.573549741080829, 0.6216731869748661, 0.37870524025389124, 0.2481078223458358, 0.19784550368785858, 0.11716873491449015, 0.45093029897127834, 1.2416446081229617, 1.6845701209136417, 2.468304991722107, 1.8465565145015717, 3.8662860223225186, 3.872491632189069, 1.955721833876201, 2.9817729592323303, 4.030978739261627, 3.909801721572876, 2.004364435161863, 1.787651858159474, 2.7590132781437466, 0.7214617495025907, 1.8924137566770827, 1.7097827451569694, 2.93167427607945, 2.670715787581035, 3.8430616685322354, 3.3816834773336137, 10.444026640483312, 15.796981368746076, 20.49088556425912, 15.155959674290248, 10.458700367382594, 11.139419725963048, 5.341972666127341, 3.1775814465114047, 1.4142644596951348, 1.197296536394528, 1.195968127676419, 4.208521715232304, 1.753523935164724, 3.60781911441258, 1.882738390139171, 3.8531456759997775, 5.56143455845969, 3.447363930089133, 3.0192934487547194, 0.5530558175274304, 1.4151133341448647, 0.5832275013838495, 0.6170334188001496, 0.4551935887762478, 0.23231380698936327, 0.06346105291907277, 0.15083688258060388, 0.4056488887539932, 1.344532664333071, 2.7669950212751115, 5.484421159539904, 9.115759491920471, 11.261392746652875, 14.849867207663399, 12.073539887155805, 14.531630158424377, 19.061635902949742, 24.202585458755493, 31.215897355760845, 31.7136732510158, 19.192609446389334, 8.830005271094185, 1.2189630823475974, 0.055152574820177894, 0.0335125765497131, 0.03547703042360289, 0.02118415505226169, 0.017894786915608814, 0.0487186413125268, 0.04346435111282127, 0.04452215667281832, 0.06257255202425377, 0.05158283601381949, 0.023536627480228032, 0.029287681648773805, 0.07467673466141735, 0.07762571570596524, 0.09426228156579392, 0.031064842894141163, 0.02832028579099902, 0.021592380379193594, 0.01436232343049986, 0.030593976910625185, 0.006789752182417682, 0.0722441119807107, 0.039628501050174236, 0.07806141661213976, 0.017375275060268383, 0.02771779928090317, 0.02995946185131158, 0.0336785462152745, 0.062192206004900594, 0.07028599562389509, 0.028965567504721026, 0.029007168486714363, 0.017007186776027083, 0.04391167871654034, 0.03827654377424291, 0.042491474388433356, 0.04028351465240121, 0.0368904426161732, 0.010273488371499946, 0.02802562347746321, 0.04005461764921035, 0.04748182464390993, 0.05611843549247299, 0.022372090058135133, 0.022123006638139486, 0.05219639791175723, 0.03964536603806274, 0.03549844498879143, 0.04230155922206385, 0.020096266642212868, 0.03516966763085552, 0.012050545292108186, 0.03730568229886038, 0.004809438400635762, 0.1010364494951708, 0.04644974913182003, 0.015351267864129372, 0.0077864251299096, 0.09718126457716737, 0.007652938632028443, 0.017729358381724784, 0.038561674367104254, 0.10374999245894806, 0.04567448555358818, 0.04016279648723347, 0.03570060771224754, 0.05544717776189957, 0.03840630002585905, 0.05419019842520356, 0.0939802552706429, 0.03237413728077497, 0.07449469728661434, 0.04758921977398651, 0.021598692451204573, 0.04115790880418249, 0.0200717002818627, 0.031428473203309944, 0.05993934760668448, 0.050797038179423125, 0.04621525760740042, 0.04417605970853141, 0.014482139144092798, 0.07738309193934713, 0.02825448485756559, 0.04724011689956699, 0.04026969289407134, 0.03193806318034019, 0.060071383735963275, 0.16169200438473905, 0.37496637659413473, 7.07717843566622, 22.256127527781896, 35.76362187521798, 44.42863348552159, 38.114885330200195, 30.712295395987375, 23.484681946890696, 19.103898320879253, 24.026835986546107, 20.472950526646205, 25.769346918378556, 34.562219279153005, 17.360465015683854, 10.29367196559906, 7.122205368110111, 4.144021587712424, 1.1245822267872947, 0.5307005856718335, 0.18071968693818363, 0.1348691215472562, 0.3568972876029355, 0.5522658399173191, 0.4402574316731521, 0.5417484385626656, 1.237788466470582, 1.7547016548258918, 0.8027668009911264, 3.3437634663922444, 2.6440134261335646, 3.6259046239512305, 4.8826528787612915, 5.315612503460475, 4.768549561500549, 3.3173987439700534, 3.7576926265444075, 2.8636972265584126, 1.9654514832156045, 3.0785046943596432, 2.6747546451432362, 3.8972932270595004, 4.959984157766614, 5.644880252225058, 5.362936684063502, 14.45924208845411, 16.58883629526411, 23.276842219488962, 24.166150842394146, 18.390134198325022, 11.857921651431493, 8.08464160987309, 4.840727014201028, 4.288038202694484, 2.97616337452616, 3.611839081559862, 6.4461690953799655, 3.5188222442354475, 5.316707279000964, 5.368214709418161, 3.524391225406102, 4.118033153670175, 2.0658887795039584, 1.6555028749363763, 1.270533480814525, 0.5135326183268002, 1.2395742620740617, 1.0316286832094193, 0.2949843598263604, 0.3393724379794938, 0.06209776071565492, 0.21086930483579636, 0.475142029779298, 1.5113058239221573, 2.6392541272299628, 6.487473964691162, 12.069540330341884, 12.263319509369985, 20.110152074268886, 18.284509420394897, 17.22171470097133, 20.28229716845921, 27.656799009868077, 35.62735380445208, 35.54170683452061, 25.118371929441178, 11.458786725997925, 1.7766260440860475, 0.04355070147929447, 0.05349721400333302, 0.09918673589293446, 0.033679709902831485, 0.04168464196845889, 0.00327864452680972, 0.030184491204896143, 0.061421098453657966, 0.03958072879218629, 0.06530989799648523, 0.054602595046162605, 0.023053746337869337, 0.006287036189210734, 0.07037407625466585, 0.05747241819543498, 0.014084546460903116, 0.03421256684565118, 0.03203182993456721, 0.037683843435453515, 0.04006638344643371, 0.03845528346885528, 0.07538180039929492, 0.04401672950812748, 0.035056532094521184, 0.017986397624814084, 0.08088028178151165, 0.056934529915452003, 0.056970675475895405, 0.043040273511516194, 0.0994715713230627, 0.047653758632285256, 0.004599594236684165, 0.03300760400348476, 0.036973946528243165, 0.011775467195548117, 0.00893071252253971, 0.03025418353666152, 0.014126366270439965, 0.03141443092109902, 0.02668384083413652, 0.07388528463031564, 0.04055031801440886, 0.1375249076102461, 0.05495699727907777, 0.13387974963656493, 0.14168444941086428, 0.10286466032266617, 0.08764519449323416, 0.11489201922501836, 0.13334040929164204, 0.1324504834732839, 0.10378102186535086, 0.14599446313721792, 0.10359674532498632, 0.19006489190672124, 0.08647839246051651, 0.08862795747284379, 0.08461212938917534, 0.11307163190628801, 0.08966228911387068, 0.09472771587648562, 0.1400261233959879, 0.23082176276615687, 0.16714070843798773, 0.1500369305057185, 0.10116133386535303, 0.11391368029373032, 0.2378106191754341, 0.12877796696765081, 0.22538471594452858, 0.14873377686100347, 0.1874858752957412, 0.12721652218273707, 0.13466169339205536, 0.14740293898752757, 0.2659408354333469, 0.11151521506586246, 0.1494137096617903, 0.2266860239739929, 0.12151171187204973, 0.10994622497154133, 0.14608806025769028, 0.20344405541462557, 0.1078743115067482, 0.18666456293846878, 0.1499123243348939, 0.23480503473963055, 0.14467397970812662, 0.3157174587249756, 0.7996772953442165, 9.389905878475734, 26.39433217048645, 41.25607558659145, 52.74184043066842, 46.19529982975551, 40.39645835331508, 33.11334269387381, 24.726443154471262, 26.135037558419363, 24.180992194584437, 37.93371105194092, 38.96416016987392, 20.345947878701345, 13.758584874016897, 8.499122500419617, 5.754678726196289, 2.362815269402095, 0.9014777956264359, 0.8837410530873707, 0.9492031804152897, 1.183168460215841, 1.3521526668752943, 2.412119686603546, 2.869421022278922, 4.545694342681339, 5.880365559032985, 5.047231384686061, 8.238856877599444, 9.542269451277596, 9.272712349891663, 10.37656136921474, 10.949343068259102, 9.554912567138672, 5.954167153154101, 5.789377595697131, 5.320208736828395, 2.5613361597061157, 3.6920421378953114, 3.4635451989514485, 5.84342155286244, 5.039680429867335, 7.740407007081168, 7.017483421734401, 13.127094370978218, 18.16678782871791, 23.570040566580637, 25.618412937436783, 21.023737703050884, 14.083917771066938, 8.33703144959041, 6.2153564521244595, 4.428431332111359, 6.256320425442286, 5.685843791280474, 13.455471447535924, 6.547980180808476, 10.084724000522069, 9.518266030720302, 10.990867240088326, 10.79775161402566, 9.704717465809413, 6.295880428382328, 4.071711250713893, 4.905044317245483, 3.6243204346724918, 1.8902978130749293, 1.476839393377304, 0.6342832446098328, 0.3047766243772847, 0.5366477008376802, 0.7477866283484867, 2.13540072951998, 3.704355214323316, 7.806751012802124, 13.83402841431754, 18.349535873958043, 23.812431948525564, 20.817650658743723, 23.96575437273298, 28.281033856528147, 34.85339396340506, 41.525957516261506, 40.57986647742135, 27.77087800843375, 12.768044471740723, 2.2114422491618564, 0.15351390678967747, 0.16955716162919998, 0.10885780051882778, 0.17032660676964692, 0.12253646259861332, 0.12769658570843084, 0.1334613785147667, 0.12375840917229652, 0.09380135272762605, 0.13298819533416203, 0.16330564208328724, 0.10743386085544314, 0.12466172927192279, 0.12816518199230942, 0.09538584734712328, 0.11543509151254382, 0.08475470316729375, 0.12529592881245272, 0.08851823157497815, 0.1314784549176693, 0.08361483218946628, 0.18221542239189148, 0.11860024024333272, 0.19141087468181336, 0.09270420231457267, 0.14303271206361906, 0.16024122866136686, 0.15316687683973992, 0.10066109749355487, 0.21908339192824705, 0.14305620294596466, 0.10190283693373203, 0.09555347942348037, 0.18277640800390924, 0.10965774580836296, 0.1976308287786586, 0.11693162763757364, 0.0922409121745399, 0.12813118738787516, 0.08997793681919575, 0.1417475395968982, 0.2052295660333974], [0.036943921353667974, 0.060879193246364594, 0.017880364653787444, 0.05869990840022053, 0.031204292018498694, 0.09020285082182714, 0.042760642444981, 0.013946564668523414, 0.10842491553298064, 0.09088604737605367, 0.09651931973972491, 0.025273658468254974, 0.05903416832110711, 0.04736656868564231, 0.01705098451514329, 0.037648369624678574, 0.02997772122866341, 0.04478386762951102, 0.053843012412211726, 0.06243267881550959, 0.06154931443078177, 0.04151345436860408, 0.01662501719381128, 0.02945969706135137, 0.006299091636070183, 0.01372532662935555, 0.050144911743700504, 0.04651308359046068, 0.0812403124624065, 0.0015422127700211214, 0.03537578960614545, 0.05379615956917405, 0.0776325621243034, 0.045605146060032506, 0.0032024923296246144, 0.010681896902886885, 0.03482886663238917, 0.04412855547187584, 0.02003711535196219, 0.01582817959466151, 0.05314784989293132, 0.045032258943787644, 0.044196778775325844, 0.048622788063117435, 0.02939995883830956, 0.04000073857605457, 0.07005121572209255, 0.09405492126409497, 1.4413006603717804, 7.561040997505188, 18.97934491293771, 32.765349115644185, 39.869899545397075, 32.065818377903526, 21.711473873683385, 15.124863011496407, 11.929417746407644, 27.64439821243286, 33.50219862801688, 15.188725641795568, 12.878947275025503, 12.02910007749285, 7.841694372040885, 9.302692089762006, 3.793165785925729, 1.8305513390472956, 0.6184099763631821, 0.4310479201376438, 0.09308536936129842, 0.4349268877080509, 0.1306956833494561, 0.2584626195686204, 0.7555015172277177, 1.769917015518461, 0.5883620572941644, 1.6181642327989851, 1.7964378552777427, 3.144221842288971, 3.4326971513884406, 5.203477697713034, 5.3708372201238355, 2.3076155228274207, 2.5419315780912126, 1.813823442373957, 1.1263044029474258, 1.2138273864984512, 0.4087398871779442, 0.4181211766387735, 1.279096158487456, 3.586669449295316, 2.374006428888866, 4.844181571687971, 7.365486553737095, 7.2853759952953885, 4.436927676200867, 2.045038321188518, 4.261671960353851, 1.9818279530320848, 2.9383673455033983, 2.1865468536104475, 0.7327097430825233, 1.405693096773965, 2.7838685044220517, 2.8096480582441603, 5.384646330560956, 4.1430575251579285, 2.1733743718692233, 1.7821302115917206, 1.3114925686802184, 0.43367409493241993, 1.014930099248886, 0.6248176810996873, 0.08930962053792817, 0.3057542847735541, 0.20839684536414488, 0.14336942828127316, 0.25124515114086016, 0.5285476754818643, 1.1824303226811546, 4.100601860455104, 8.668820091656276, 9.260524341038295, 11.095682552882604, 20.392024857657297, 15.268006324768066, 15.544994524547032, 14.940298012324742, 25.69167821747916, 28.10428558077131, 30.78112425122942, 24.338132653917583, 9.841555288859777, 2.0253340985093797, 0.07861333699630839, 0.06057526384081159, 0.033782752230763435, 0.00941124593373388, 0.081699117485966, 0.019170432750667845, 0.060286628614578924, 0.01979960604304714, 0.03807444551161357, 0.042752347354378016, 0.011768029603574957, 0.0163478610837566, 0.01611914558868323, 0.03488189075142145, 0.040362903249583075, 0.11072522388505084, 0.03871559325073447, 0.03937778914613383, 0.027439986688217947, 0.05496929572629077, 0.060232671509896, 0.07097010820039681, 0.015545191476121545, 0.01746496551537088, 0.07160223820911986, 0.06351945442812783, 0.024277034714551907, 0.025747148685955575, 0.023932416956605654, 0.07129653782716819, 0.053641711428229294, 0.044700591026672294, 0.02655267492601914, 0.08820900959627968, 0.01891396178065666, 0.10325277556798287, 0.04226178689194577, 0.06851856117802006, 0.05766077273126159, 0.01950687076896429, 0.04398593080363103, 0.012199073215015233, 0.013700368415032114, 0.06284450207437788, 0.06596884370914527, 0.015491673722863197, 0.03341620082833937, 0.02670120115258864, 0.03980050967740161, 0.014995652749868376, 0.029891604956771647, 0.03302032992775951, 0.09042567493660109, 0.06621672612215791, 0.05944998815123524, 0.04171491480831589, 0.05496548575216106, 0.02214344241656363, 0.04706081062821405, 0.026699213044984, 0.09528441314718553, 0.05027028126642108, 0.02449717352698956, 0.019822365803910152, 0.06445438747427293, 0.008067275014972048, 0.03759169498724597, 0.051138996080096276, 0.015390885827530707, 0.0898049578868917, 0.06826681790075131, 0.09512299645159926, 0.036004370876720974, 0.008432957892572241, 0.013512913786273981, 0.10745038318314723, 0.017105174018070102, 0.006459896801970899, 0.030472000062997853, 0.02439653660569872, 0.028877578476177793, 0.031086674758366177, 0.03568751198638763, 0.04724277675684009, 0.05276236057813678, 0.01632067048922181, 0.051721012885017056, 0.03334926334874971, 0.02496895214010562, 0.011672667443885334, 0.1040597301242607, 1.883226718221392, 9.958828721727643, 23.23579052516392, 39.072124753679546, 43.942641735076904, 37.91963400159563, 28.359077760151454, 17.676034825188772, 14.18614227431161, 24.17919261114938, 35.64602708816528, 25.133086477007183, 18.688920634133474, 13.973074895995003, 9.354347603661672, 9.011309828077044, 4.634671236787524, 1.8790497652121951, 0.3927734967853342, 0.26255014166235924, 0.06432395947298833, 0.16940848103591374, 0.3609977832862309, 0.3881298473903111, 0.9645920289414269, 0.8695366010069847, 0.6164231172629765, 1.4740150592156818, 2.1551160258906226, 2.6872868069580624, 2.314235201903752, 3.8274034687450955, 4.192616854395185, 1.6930398664304187, 3.8795379740851264, 3.201357964958463, 1.301835115466799, 2.637971967458725, 2.9840037652424405, 2.9496816183839525, 3.78368410042354, 5.993102252483368, 3.4502880360398973, 6.813173379216876, 9.97017252445221, 11.615254078592573, 8.573523810931615, 4.626292143549238, 5.7324579528399875, 3.9521496891975403, 4.520074163164411, 2.7622606924601962, 3.0406993286950246, 3.079458551747458, 2.984731589044843, 4.073048344680241, 2.636336535215378, 3.941050810473306, 2.528644233942032, 1.4847869383437293, 1.5658309438398905, 1.2281921356916428, 0.9744607508182526, 0.8352154855217252, 0.3919539079070091, 0.363528773188591, 0.22986399701663426, 0.05827051108436925, 0.15863080721880707, 0.5825931525656155, 1.1395778506994247, 4.401693361146109, 9.331784197262355, 10.452229857444763, 15.23104885646275, 22.9262204851423, 18.610663073403494, 16.752584491457256, 18.86504704611642, 28.048984868185862, 34.243230955941335, 35.75223725182669, 28.617455210004533, 12.652140702520098, 3.0290851976190294, 0.19587259526763642, 0.06554731061416012, 0.022363250443179692, 0.017526937814961587, 0.10566306087587561, 0.027007929515093565, 0.03666037853275027, 0.043835028008158715, 0.015390987607783504, 0.034144313008125336, 0.060569808419261656, 0.03676096456391471, 0.0166282198790993, 0.028728650217609744, 0.028555498258875947, 0.07895577326416969, 0.014677650528028607, 0.05226946934791548, 0.02633340294206781, 0.07108182899121727, 0.034634245825665336, 0.07435643899121455, 0.057724826437022, 0.03688971319102815, 0.06325422866003853, 0.03532696222620351, 0.0939680009282061, 0.02853934234008193, 0.028800958301872015, 0.03223609272390604, 0.06648048625460692, 0.04523161253226655, 0.029391086992940733, 0.050759827319000445, 0.04589854120942099, 0.026706724427640438, 0.06281780172139406, 0.04181199281343392, 0.023333248482750993, 0.06032159352408988, 0.021751333992662172, 0.05821234706257071, 0.053236062838030715, 0.07522167970559426, 0.17658032476902008, 0.11164077118571315, 0.11006722133606672, 0.08969124220311642, 0.18978507763573102, 0.1428509596735239, 0.10709572649960007, 0.18204570721302712, 0.19961618153112276, 0.1296119407883712, 0.08497143403760024, 0.19868586930845464, 0.18679006477551802, 0.10569930143122162, 0.11889039538800716, 0.11061738431453705, 0.1295514426061085, 0.1680940772805895, 0.12241378346724169, 0.1521605144121817, 0.10327735210635833, 0.15170485100575856, 0.10693276274417128, 0.10604038062904562, 0.23201346024870872, 0.14221547091645853, 0.2184448769049985, 0.26327867114118164, 0.1084284032029765, 0.12261157642517771, 0.16529281330960138, 0.22345466379608425, 0.11867755252335753, 0.16459393581109388, 0.12833450362086296, 0.14364249791417802, 0.08176306941147361, 0.1672498575810875, 0.2071613823728902, 0.12112253132675375, 0.19313370223556245, 0.08673204920653786, 0.07827140284436089, 0.1341168704841818, 0.1204811664564269, 0.08993121289781161, 0.22206422340657028, 2.5971754023006985, 11.726002284458705, 27.170967067990983, 45.185229778289795, 51.657219682421, 45.043955530439106, 35.663915225437705, 26.418357304164342, 21.064447198595317, 36.22500310625349, 42.91582652500698, 26.63062650816781, 23.141791820526123, 20.714518547058105, 14.082971947533743, 13.534211039543152, 6.196126443999154, 3.344900582517896, 1.019339274082865, 1.0644178837537766, 0.4282069754387651, 1.0003337796245302, 0.9543342079435075, 1.7197027099984032, 2.632400597844805, 4.7179089188575745, 1.9539352783135004, 5.282421827316284, 5.879036716052464, 7.6277124370847424, 10.064917291913714, 8.00201884337834, 10.399050082479205, 7.052604828562055, 8.395306859697614, 5.853189417294093, 3.4316714235714505, 2.829075655766896, 3.664026132651738, 2.517220961196082, 4.550008739743914, 6.848644801548549, 4.04864844254085, 7.793063930102757, 9.977153726986476, 10.85024699143001, 8.512985893658229, 6.281514593533107, 6.75138087783541, 4.118139547961099, 5.982482365199497, 6.322783419064113, 5.066130484853472, 7.4685691595077515, 6.760849969727652, 7.244282611778804, 12.160143971443176, 10.032133953911917, 7.530566198485238, 7.838647586958749, 5.1056457587650845, 4.22496462719781, 4.444304491792407, 3.1382859093802313, 1.4058761383805956, 2.220844030380249, 1.3501204273530414, 0.49797489600522177, 0.6395893884556634, 0.7800337608371462, 1.806368893810681, 5.600127339363098, 12.03477588721684, 14.04152160031455, 18.479661737169536, 29.796519347599574, 23.487495967320033, 23.799735852650233, 24.757397379193986, 35.88976294653756, 39.24630914415632, 41.34361246653965, 33.451407296316965, 14.345105767250061, 3.6115307552473883, 0.26650306954979897, 0.20105605998209544, 0.12321900097387177, 0.09989832235234124, 0.15702752396464348, 0.09625401254743338, 0.13482758163341454, 0.08135256929589169, 0.0987133966492755, 0.17144289187022618, 0.0881816442789776, 0.2153716560985361, 0.12825276729251656, 0.11542553773948125, 0.0931596282337393, 0.2228222420173032, 0.1076713345412697, 0.14015454293361732, 0.21498711673276766, 0.1693463000868048, 0.10810932889580727, 0.19074455329350062, 0.10785306657531432, 0.16964121854731015, 0.17159888707101345, 0.10821891908666917, 0.23810670471617154, 0.06991708970495633, 0.13699161979768956, 0.08896702142166239, 0.16395105102232524, 0.15163523331284523, 0.08008172748876469, 0.1605081914791039, 0.10842109538082566, 0.17697162234357425, 0.08133876789361238, 0.2560247246708189, 0.11967940947839192, 0.19542527784194264, 0.14447340475661413, 0.09993817949933664, 0.14576897237982067], [0.02893705546323742, 0.022994069182979207, 0.009451343112492135, 0.004080337680144501, 0.026237687095999718, 0.029503835764314448, 0.05977945761489017, 0.13317116908729076, 0.06307219807058573, 0.023048368947846547, 0.056259940577937026, 0.02665577662576522, 0.02581186226702162, 0.014939052751287818, 0.0666199659130403, 0.0653117707531367, 0.03169177193194628, 0.016394581612465636, 0.0219088083997901, 0.024690165849668638, 0.03217950290335076, 0.07191673240491323, 0.052031147493315597, 0.033304490215544186, 0.038768074541751824, 0.06054611397641046, 0.02979190441380654, 0.04398544904376779, 0.05286184738257101, 0.038927231715726, 0.03960562424202051, 0.014369375105681164, 0.07231541244047028, 0.03896489040926099, 0.007333069590718618, 0.056407613546720574, 0.04187491675838828, 0.031173096371016333, 0.017057810577430894, 0.04083498041810734, 0.0461814801341721, 0.002958851396605106, 0.007605677819810808, 0.02418827554876251, 0.014933972220335687, 0.06998926547488996, 0.026491717036281313, 0.031117001881024668, 0.18058855326047965, 1.6545575942311967, 11.247710006577627, 19.877444744110107, 33.23677396774292, 34.90156582423619, 32.830425943647114, 26.429127011980327, 22.017972809927805, 17.84458248955863, 15.045820304325648, 14.856342928750173, 17.112224987574987, 13.435590045792715, 12.238766312599182, 11.785867094993591, 7.57337144442967, 4.13290273291724, 2.889854154416493, 1.1584981211594172, 0.622388200036117, 0.2347784090254988, 0.11119859027011053, 0.2806783446243831, 0.38865153225404875, 0.021199778321066072, 0.46843756096703665, 1.2012693860701151, 1.3963982526745116, 1.7182253492730004, 0.7798083786453519, 2.297746475253786, 1.8058308426822935, 2.227910131216049, 3.990927585533687, 2.047168595450265, 1.6015658548900058, 2.109276371342795, 1.5718417870146888, 1.603861691696303, 1.4947101601532526, 2.7838415801525116, 2.0916066680635725, 1.2746308552367347, 2.3346650770732333, 3.223302330289568, 2.965803827558245, 3.350668021610805, 1.4626339099236896, 1.0324480278151376, 1.9429139154297965, 1.7495200357266834, 1.347691923379898, 3.2439458625657216, 2.292465844324657, 2.810157665184566, 1.614717383469854, 2.4484995859009877, 1.6906416522605079, 1.3459996027605874, 0.9093604183622769, 0.8776353778583663, 0.3110764691872256, 0.08867954649031162, 0.5834636858531407, 0.11293805550251688, 0.15211440117231437, 0.2861142786485808, 0.7279016982231821, 1.575481340289116, 4.111177018710545, 6.316355466842651, 20.256854602268763, 19.41728813307626, 12.921650035040718, 14.760383095060076, 16.456261192049297, 22.923048632485525, 22.7872565133231, 29.954674243927002, 31.318220002310618, 22.69780193056379, 13.478817394801549, 5.015237970011575, 0.4666945944939341, 0.050055491006267924, 0.03275157238489815, 0.04068487150860684, 0.03207484566207443, 0.05146481502535088, 0.04598081358043211, 0.015487609298101493, 0.05508673656731844, 0.06510696174310786, 0.059933939682585854, 0.016100648724074875, 0.06875277789575712, 0.05516755687338965, 0.015692136716097593, 0.036609281453170946, 0.0232186812375273, 0.054346990904637744, 0.02095068641938269, 0.01786519939612065, 0.08333571002419506, 0.05203256563150457, 0.05436223080115659, 0.04816850547545722, 0.022654503118246794, 0.03659506614453026, 0.01437880504610283, 0.029006456024944782, 0.07351632442857538, 0.02615799315805946, 0.035941752272525, 0.01709459226445428, 0.03393565331186567, 0.07335017155855894, 0.04750745630423937, 0.027342694944569042, 0.0647669682013137, 0.011306616461037524, 0.05645058177677648, 0.024751927803403566, 0.0279151817251529, 0.03957814357376524, 0.04596208601391741, 0.0195268468399133, 0.08160879090428352, 0.035368702307875664, 0.046015659746314795, 0.028773460670241287, 0.03328998992219567, 0.002343560506622972, 0.01993034447410277, 0.11458338078643594, 0.009113307992395545, 0.009581448809642876, 0.06486733710127217, 0.05930430668273142, 0.0372774552420846, 0.011897089508628207, 0.030396007533584322, 0.05622058554685541, 0.03780588135123253, 0.022172977349587848, 0.043746597931853363, 0.019322480573984127, 0.020055418834090233, 0.004823560410711382, 0.06717529932835273, 0.01989968995829778, 0.0400655895604619, 0.019236257432826927, 0.022611641757456318, 0.08420002114559923, 0.032346327523035664, 0.04077297588810325, 0.04368818624477301, 0.048473554463790994, 0.06586600494171892, 0.011578289159972752, 0.02478801059935774, 0.037068103440105915, 0.04349049845976489, 0.0191622954194567, 0.07703986178551402, 0.034060561430773566, 0.054633105373276133, 0.01974356413951942, 0.03542951940159712, 0.05106600946081536, 0.012787786312401295, 0.04057256378499525, 0.07472809976232903, 0.028282735663067018, 0.19020865990647248, 2.6393904856273105, 14.729036297116961, 24.560294355664933, 40.33953523635864, 39.14273929595947, 36.33549683434622, 29.405342715127126, 21.94209327016558, 18.853268112455094, 19.327494825635636, 16.690172297613962, 20.37405334200178, 17.009697369166783, 16.43251051221575, 13.121355158942086, 7.689140592302595, 4.114119146551404, 2.5938083486897603, 1.4100533085209983, 0.42643578190888676, 0.20502520485648087, 0.13170984892972878, 0.17200288682111672, 0.2624169588088989, 0.26537841132708956, 0.8969658634492329, 1.2371616086789539, 1.538307066474642, 2.6072878539562225, 1.7608091213873454, 2.3446515926292966, 3.7343618784632002, 2.5713899859360287, 4.267788980688367, 2.7571702684674944, 2.8972515974725996, 2.0523206847054616, 2.7080454187733785, 3.208747808422361, 4.299992144107819, 3.375797267471041, 2.4565384345395223, 2.849387628691537, 3.688039106982095, 4.393828000341143, 4.217945209571293, 4.146809986659458, 3.1383968634264807, 2.7530150285788944, 2.885310032538005, 2.242985333715166, 3.05341084088598, 3.0774537793227603, 3.1882441086428503, 3.2703537940979004, 2.754067680665425, 2.5055314855916158, 2.6363912522792816, 1.2523263778005327, 0.5772264291133199, 0.6044785124914986, 0.24987524322101048, 0.23208793625235558, 0.20676355729145662, 0.21534539679331438, 0.2126509342342615, 0.14055485145321914, 0.6630357046212468, 1.8133408682686942, 4.242254785129002, 8.546862704413277, 22.202735832759313, 19.48417844091143, 15.591062818254743, 19.069410937173025, 19.05353604044233, 24.760923589978898, 25.621254750660487, 32.48010124479021, 34.84576484135219, 28.181921277727398, 17.168006862912858, 6.10920751946313, 0.6240151098796299, 0.05697232431599072, 0.07673534205449478, 0.034188553491341214, 0.024680888579626168, 0.047024844879550595, 0.07620058182094779, 0.017170503369665573, 0.039830443249749284, 0.036482073100549836, 0.03370316007307597, 0.030700483159827333, 0.04531952013660755, 0.03313309566250869, 0.03272698227582233, 0.04199769767001271, 0.003934811002441815, 0.03876725012170417, 0.0587323559448123, 0.023951811183776175, 0.1414994943354811, 0.04568429716995784, 0.04186983113842351, 0.04637685411476663, 0.02731459341677172, 0.024164876268644418, 0.0037779150464172873, 0.05998980347067118, 0.08409216121903487, 0.07489811349660158, 0.05649493082559534, 0.0035577300087814884, 0.03719090470778091, 0.05032575150419559, 0.048604179240231, 0.003539049727675904, 0.06175213533320597, 0.0067638317206209254, 0.06321583714868341, 0.03216451745746391, 0.011309073605973805, 0.013176039809228053, 0.022021209421966757, 0.051162782125175, 0.10973208610500608, 0.06374818858291421, 0.11590315853910786, 0.05961953369634492, 0.14388149151844637, 0.10553669051400252, 0.12677157962960856, 0.22525578072028501, 0.14293257386556693, 0.10608500109187194, 0.17102722131780215, 0.10029685989554439, 0.09874113516083785, 0.09412978403270245, 0.14648471825889178, 0.12458289707345621, 0.09858640203518526, 0.07346286265445606, 0.13503821247390338, 0.09255052091819899, 0.19709313048848084, 0.13761896613453115, 0.1538966005401952, 0.15516687237790652, 0.11471999702709061, 0.11840985688780035, 0.28014737740159035, 0.11795052939227649, 0.12170001891042505, 0.12388407385775022, 0.10807047598063946, 0.11810478754341602, 0.16541538387537003, 0.12416810861655644, 0.13057174214294978, 0.16313849176679338, 0.28840750988040653, 0.09546759724617004, 0.1556153026010309, 0.1126503837960107, 0.13790201023221016, 0.0613576757854649, 0.06533435918390751, 0.10639147500374488, 0.12244082987308502, 0.117733289620706, 0.23666867188044957, 0.2440600624041898, 0.3149893635085651, 3.090120996747698, 15.78989941733224, 29.789015293121338, 44.850069522857666, 47.69471761158535, 45.61872441428048, 37.63503926140921, 34.1778484072004, 27.992351838520594, 24.895935773849487, 24.598547663007462, 29.176743507385254, 24.740073783057078, 21.68948629924229, 18.073456151144846, 11.588877848216466, 6.4644341724259515, 4.606032499245234, 2.006727908338819, 1.4150973750012261, 0.8206957589302744, 0.7702223073158945, 0.6698423879487174, 1.5578775363309043, 1.4004194140434265, 2.5596764087677, 3.724163225718907, 3.728111105305808, 4.222133670534406, 4.516115427017212, 8.537770118032183, 6.933282545634678, 6.377634235790797, 9.577238866261073, 7.660310779299055, 2.8656752918447768, 5.359760054520198, 3.9915902699742998, 3.677693239280156, 5.43321293592453, 6.443882703781128, 3.7636220455169678, 3.277046863521848, 3.068238079547882, 6.850593336990901, 4.677583745547703, 4.654833172048841, 2.971640314374651, 4.002823335783822, 5.083733745983668, 4.938841657979148, 3.5573534795216153, 7.8269476890563965, 8.88989005770002, 7.773349285125732, 7.109197037560599, 7.479904276984079, 5.381783238479069, 4.91740038565227, 4.004633341516767, 1.712248595697539, 2.075573048421315, 1.8304099866322108, 1.3012110803808485, 0.7267842324716705, 0.41546202504209107, 0.6394428791744369, 1.308300631386893, 2.6037483981677463, 5.200240271432059, 9.106695566858564, 25.001715149198258, 26.27755205971854, 20.26757393564497, 23.723474161965505, 27.09411130632673, 32.927964755467, 31.362751007080078, 39.92686087744576, 40.8350772857666, 32.74092967169625, 19.139403615679058, 6.908786237239838, 0.820635016475405, 0.1855962909758091, 0.17687111773661204, 0.0947153258270451, 0.09512222970702819, 0.12248357757925987, 0.12272729378725801, 0.10922560042568616, 0.134075615555048, 0.14722444356552192, 0.11859475768038205, 0.09371524663375956, 0.19965493945138796, 0.10118385444262198, 0.09804046632988112, 0.17166960399065698, 0.08447619846888951, 0.1576698116425957, 0.20319928069199833, 0.13697871406163487, 0.21331976620214327, 0.10780190503490822, 0.1701643554759877, 0.08538012925003256, 0.0880330451098936, 0.1330749121095453, 0.10063409179981266, 0.24554689547845296, 0.15681150555610657, 0.1317837413932596, 0.15199953876435757, 0.10908532688128096, 0.20696538074740342, 0.18800912079002174, 0.17584765622658388, 0.08961537520268134, 0.1656920768852745, 0.15910525247454643, 0.21152172982692719, 0.1456578690558672, 0.09455318988433906, 0.12366958893835545, 0.14027118310332298, 0.13772348766880377], [0.04995807034096547, 0.04644156260682004, 0.06160426898194211, 0.022919269178860953, 0.04626848867961338, 0.04267854988574982, 0.014536035180624043, 0.0069794290133618885, 0.00837524000754846, 0.080364819083895, 0.02657738038604813, 0.022320916643366218, 0.056658617220818996, 0.04544421451698456, 0.016536783892661333, 0.04256135671000395, 0.03655510043193187, 0.024549734545871615, 0.028283700879131044, 0.017354868119582534, 0.053647791101996384, 0.05640863474192364, 0.007665738346986473, 0.03530631779826113, 0.014168222551234066, 0.04150910495913454, 0.03770115625645433, 0.06739998941442796, 0.05110132720853601, 0.03009500600663679, 0.0342172792713557, 0.01771966041997075, 0.035801862100405354, 0.03518958602632795, 0.0603490945483957, 0.05355851285691772, 0.04816449194082192, 0.04912240357537355, 0.03864935126953891, 0.0037686666141131093, 0.026748936091150557, 0.027697701073650802, 0.030531147960573435, 0.060772412190479894, 0.045921485871076584, 0.042936949591551504, 0.006414570238640798, 0.014661133289337158, 0.04885873165247696, 0.1801924787993942, 2.3620804974011014, 9.027550373758588, 17.736937522888184, 31.649916580745153, 40.5394800731114, 41.968505655016216, 35.40834311076573, 28.692994288035802, 15.591283423560006, 23.293630804334367, 20.46452236175537, 20.803757735661097, 14.643971238817487, 16.74313494137355, 10.115227460861206, 4.172148764133453, 5.849271501813616, 3.9619792188916887, 2.5104964077472687, 1.109977656177112, 0.39891122600861956, 0.22787390808973992, 0.14287825035197393, 0.19451502311442578, 0.2805327852921826, 0.4274506260241781, 0.8617959820798465, 1.5579942443541117, 1.0157453183616911, 1.7695233566420419, 3.053256460598537, 1.2263624795845576, 2.193784922361374, 2.475497680050986, 1.8012861779757907, 1.1757511496543884, 2.570524718080248, 2.6055892365319386, 2.0512480565479825, 1.5724790671042033, 1.6380029682602202, 1.704507868204798, 1.9745488464832306, 1.6773902433259147, 1.694080684866224, 0.516265974513122, 2.1018659004143307, 1.8826209221567427, 1.7654986126082284, 0.7427774657096181, 3.0485444962978363, 0.7299221583775112, 0.9999858268669674, 3.711276488644736, 1.2844975143671036, 1.0498433858156204, 1.2058908066579273, 0.3009227626025677, 0.17234983534685203, 0.18012849294713565, 0.2555720603891781, 0.12895355825977667, 0.22828833013772964, 0.15892073166157517, 0.42017770771469387, 1.0074364670685358, 2.8001153469085693, 5.177806709493909, 7.779540130070277, 11.21279444013323, 27.73438606943403, 44.22411673409598, 16.74351535524641, 20.39865517616272, 20.315134355000087, 22.99057470049177, 30.73599222728184, 35.286186831338064, 24.413939237594604, 16.884013141904557, 5.749180964061192, 1.4173781211887087, 0.012037529294112963, 0.09799583229635443, 0.020894624159804413, 0.04495212056541017, 0.015254634299448558, 0.02103880436957947, 0.018463870843074152, 0.022781881104622568, 0.009260969934985042, 0.02295382527102317, 0.03083599338840161, 0.02957823034375906, 0.04062147598181452, 0.04768429610079952, 0.03624350018799305, 0.038771297583090406, 0.039406945795885155, 0.031091970724186728, 0.058971451329333444, 0.07012625490980488, 0.05055244326857584, 0.10923495063824312, 0.012909183860756457, 0.1302092687359878, 0.05355397345764296, 0.07310497614422015, 0.014280154536079084, 0.008157894214881318, 0.012593514103043293, 0.0646992911185537, 0.019344529569415108, 0.05771066541118281, 0.07583115343004465, 0.02354041370563209, 0.07422928831407002, 0.0588804055005312, 0.02419841455827866, 0.034758916457316706, 0.036023247720939774, 0.08319809633706297, 0.0755821717903018, 0.03376877780205437, 0.06089961715042591, 0.03966471107144441, 0.035176690468298535, 0.08697041855858904, 0.04888992051460913, 0.034692277533135245, 0.06303806097379752, 0.02210232149809599, 0.04768770234659314, 0.054516838397830725, 0.048095946333238056, 0.04348685133403965, 0.006396705683852945, 0.07778343438569989, 0.07135853557182209, 0.03382827175248947, 0.039516780259353776, 0.00449752136566011, 0.00464167570628758, 0.035885108169168234, 0.03606217527495963, 0.02721540516774569, 0.07367789718721594, 0.026143626875377128, 0.009056707993814988, 0.047647763775395494, 0.028304548867579018, 0.047550957184284925, 0.015861782345122526, 0.03156499105638691, 0.04634692393509405, 0.03261718173910465, 0.04317038260134203, 0.03546303224616817, 0.024051649130082557, 0.043228997848927975, 0.08132247626781464, 0.03383347272340741, 0.04720970835270626, 0.021041650823982697, 0.05215159424447587, 0.031493595601724725, 0.05440406927040645, 0.034472215055887184, 0.0405089273782713, 0.03862527006172708, 0.028557910450867245, 0.0015808640330630752, 0.025685052553723966, 0.025307566559474384, 0.04843210615217686, 0.24406177231243678, 3.4176360624177113, 12.198667390005928, 23.641813720975602, 36.97345611027309, 44.09273672103882, 45.03745549065726, 38.94040427889143, 30.9367812701634, 17.96499650818961, 21.977442230497086, 20.998680761882238, 23.99593734741211, 19.50514289311, 22.40863527570452, 14.724572079522268, 6.660436340740748, 7.3412017311368665, 4.057017113481249, 2.2260488825184956, 0.8227149162973676, 0.3589453777032239, 0.23846315273216792, 0.17953796392040594, 0.01895840752071568, 0.5126533997910363, 0.4175576940178871, 0.40228324649589403, 1.146602805171694, 1.309644456420626, 2.262966181550707, 1.4938582458666392, 1.8388796235833849, 3.319773290838514, 3.1298959595816473, 3.922392725944519, 2.398419793163027, 3.027338377067021, 3.480115349803652, 3.1591020609651292, 2.846420313630785, 1.7015634604862757, 3.0747218344892775, 4.125923701695033, 3.274722691093172, 2.469398247344153, 2.056340651852744, 2.6244902908802032, 2.174587049654552, 2.6846471428871155, 2.324726330382483, 2.4601436810834065, 2.060508051088878, 3.06645912357739, 2.62580914582525, 2.019599663359778, 1.6245617866516113, 1.3150764278003146, 0.4219809009560517, 0.3990410976111889, 0.20428094693592616, 0.23927421921065875, 0.0393598826069917, 0.10119426995515823, 0.11169438223753657, 0.4506249582128865, 0.8849169271332877, 3.5202514018331255, 5.918957156794412, 7.818960734776088, 11.388124414852687, 32.914975098201204, 43.28689507075718, 17.36357433455331, 19.47717465673174, 20.439362934657506, 27.811250516346522, 34.622178758893696, 39.711147103990825, 30.339281354631694, 20.720037153788976, 8.00481288773673, 2.018111228942871, 0.02275748098535197, 0.04688630838479314, 0.05265688230948789, 0.013593609411535519, 0.012486433643581612, 0.040209537371993065, 0.050387046965105195, 0.029946925916842053, 0.04842152439856103, 0.020320183198366846, 0.03220124655802335, 0.026523769334224716, 0.09471352770924568, 0.01995538071995335, 0.04900888466675367, 0.020298319103728448, 0.02475722037654902, 0.04551508749968239, 0.04055478616750666, 0.07686807707484279, 0.020155285618134906, 0.04198007611557841, 0.041516694373318126, 0.08467007627976791, 0.04568034131079912, 0.07092244111533676, 0.016642516611942222, 0.03309509770146438, 0.01650492158452315, 0.017637571253414665, 0.02587750374472567, 0.05091953071366463, 0.0336355711998684, 0.01998481048004968, 0.08024973275938205, 0.041092121441449435, 0.027198655530810356, 0.06396148606602635, 0.0483362495100924, 0.03740203087883336, 0.029098563761051213, 0.017703943852601305, 0.006475069269072264, 0.029385512827762535, 0.1631999263273818, 0.17315271869301796, 0.07456899008580617, 0.14162232274455683, 0.1522661487438849, 0.14802742190659046, 0.09406748094729014, 0.17691439470010145, 0.06763644529772656, 0.17024356765406473, 0.119480164455516, 0.11182697476553065, 0.1561720405838319, 0.08071495672421795, 0.13790377442325863, 0.10658182443252631, 0.07799399737268686, 0.06472399657858269, 0.20293256214686803, 0.15755902044475079, 0.16181255291615212, 0.14841297907488687, 0.11418115879808154, 0.14902276492544583, 0.10301997698843479, 0.14334943863962377, 0.13263239871178353, 0.10111942075725112, 0.13149364053138665, 0.17040891306740896, 0.0904610605378236, 0.11796796774225575, 0.19916867411562375, 0.10008669045886823, 0.2147717768592494, 0.15918394896600926, 0.1694958492049149, 0.13268954493105412, 0.16757525583463057, 0.15662470486547264, 0.07640373520553112, 0.16256100418312208, 0.11549124707068716, 0.11355723906308413, 0.10071989255292074, 0.10142904307161059, 0.08855044841766357, 0.12427566998771258, 0.2105111876236541, 0.5317442810961178, 3.6706425547599792, 13.397635510989598, 26.586065973554337, 43.39800718852452, 51.789162499564036, 56.66033608572823, 47.720596177237375, 41.47373832975115, 23.98130965232849, 33.02072320665632, 29.426288059779576, 32.69533559254238, 25.443783862250193, 27.923462186540874, 17.343613897051128, 9.542550853320531, 9.832863092422485, 5.724280791623252, 3.7670648779187883, 1.6581790170499255, 0.8270588432039533, 0.5786689945629665, 0.5171987701739583, 0.954912536910602, 1.3243482559919357, 2.066967704466411, 2.998768470117024, 4.089131253106253, 4.465440043381282, 5.537755531924112, 8.58846504347665, 4.434761141027723, 6.50243387051991, 6.410750653062548, 6.581622489861079, 5.320327724729266, 7.278155079909733, 8.229193670409066, 4.890542558261326, 4.004063154969897, 4.983513798032488, 4.79475382396153, 5.059663014752524, 4.0410579698426385, 4.476285312856946, 2.4560985267162323, 4.448320984840393, 4.031014783041818, 6.2668221933501105, 2.9635541311332156, 9.702202217919485, 4.82937148639134, 5.741007276943751, 10.417427199227468, 4.9321922319275995, 5.301654006753649, 4.621880037443979, 2.16005163533347, 2.0823193149907246, 1.3524202810866492, 1.0118972105639321, 0.692325292953423, 0.5836142120616776, 0.6869909763336182, 0.69913876163108, 1.5262946082012994, 3.7579123633248463, 6.939435609749385, 10.684588040624346, 15.733747550419398, 34.79788133076259, 52.03259611129761, 25.13355895451137, 28.603452852794103, 29.0708338533129, 33.38018478666033, 40.389881883348735, 45.51054096221924, 34.04225083759853, 23.740653582981654, 9.229105455534798, 2.1463808374745503, 0.12824128648000105, 0.19724307315690176, 0.11390932409891061, 0.1590368425739663, 0.10465425572225026, 0.11773400886782578, 0.11199972299592835, 0.11468161908643586, 0.26744341052004267, 0.06724166005317654, 0.08142992228801761, 0.15981666930019855, 0.22941401973366737, 0.09988629871181079, 0.1742821130901575, 0.1503473874181509, 0.13203749991953373, 0.10913650877773762, 0.09774320013821125, 0.13630034189139092, 0.18168810568749905, 0.19258442813796656, 0.09936720585184437, 0.15909217031938688, 0.17579231491046293, 0.19539053684898786, 0.15049290603825025, 0.14944988914898463, 0.11708589935941355, 0.19477129222026893, 0.07027342915534973, 0.15139807175312722, 0.12748154439032078, 0.1819812056741544, 0.24740762848939213, 0.11640327955995287, 0.08202473965606519, 0.14613732190004416, 0.14466310957712786, 0.2193723799926894, 0.10615600299622331, 0.1424054607216801, 0.10873953186507736, 0.11968249002737658], [0.018940782573606287, 0.050755942706018686, 0.051887111472232, 0.03964487410017422, 0.035123934370598624, 0.009691424917296639, 0.011315904757274049, 0.032260984781065156, 0.02589176994349275, 0.02385705546475947, 0.02781145238051457, 0.03914881071874073, 0.032901942530380826, 0.0032443651497097953, 0.0660602016640561, 0.0494621494518859, 0.02934327402285167, 0.012192491425334342, 0.023204282724431584, 0.012880309651206647, 0.051952552782105546, 0.0240802680408316, 0.03972896833771041, 0.024294352624565363, 0.14494639794741357, 0.006998089150459106, 0.05879604324166264, 0.058048026237104616, 0.01660059332581503, 0.03288543038070202, 0.0182016594668052, 0.04469169203990272, 0.02763503327566598, 0.0774961155174034, 0.020542751166171262, 0.051737263798713684, 0.023678685571732264, 0.045884875514145405, 0.030666868535003493, 0.022995821499664868, 0.05432344913216574, 0.008543800828712327, 0.010046832230208176, 0.027842700614460876, 0.062026473826595714, 0.05056534221928034, 0.07116613696728434, 0.04937112397913422, 0.005764288570000125, 0.035458143401358805, 0.5175949260592461, 2.622654012271336, 9.293004563876561, 20.58701910291399, 34.757734639304026, 44.123732634953086, 42.05303743907383, 24.787797485079082, 19.689836433955602, 19.7541698047093, 16.33208646093096, 20.23011098589216, 20.580725772040232, 19.809100525719778, 16.010765280042374, 12.472425545964922, 11.358225447790963, 9.958691494805471, 5.276459838662829, 3.0862619238240376, 2.0300779810973575, 0.7078906148672104, 0.23542887983577593, 0.0029293408484331197, 0.39045537688902443, 0.361715347639152, 0.29657810287816183, 1.0439514219760895, 0.36405146228415625, 1.1096033219780241, 0.33967539029461996, 2.146957755088806, 2.0925346868378774, 2.045519701072148, 4.171139972550528, 1.0657846161297388, 2.2149940814290727, 1.4719043267624718, 2.0359073025839667, 1.0666607405458177, 1.2326750265700477, 2.923480178628649, 2.983403180326734, 0.7386842167803219, 1.067908159324101, 2.17627198781286, 1.4749733677932193, 0.8490168335182326, 0.8391452889357294, 1.938353942973273, 2.0773643808705464, 1.342722007206508, 2.0585412766252245, 0.7752501975212778, 0.89325769671372, 1.1188178275312697, 0.5453967856509345, 0.43689295649528503, 0.07445072143205575, 0.2084982999201332, 0.06945472237254892, 0.12825784273445606, 0.2966130610023226, 0.6594663932919502, 1.0250993307147707, 2.8595296101910725, 4.56754469020026, 7.453447273799351, 10.619911602565221, 15.12727403640747, 20.634284223828995, 47.771366664341514, 24.91885961805071, 20.878367492130824, 30.61856072289603, 27.180006674357823, 31.70465448924473, 23.09726255280631, 17.133406570979528, 6.673513719013759, 1.8858503145830972, 0.23817016131111554, 0.0066515036409587735, 0.027203785255551338, 0.025981752168653265, 0.06038090427006994, 0.038206739484199455, 0.03216563704024468, 0.029500711110553572, 0.018909266318327615, 0.032586834260395596, 0.012552711247865642, 0.05399031557941011, 0.08628258082483496, 0.020949478627049496, 0.018609949254563878, 0.02258485319492008, 0.01928904915361532, 0.004708915558044932, 0.007278013259305486, 0.019101843038307767, 0.06823071983775922, 0.035653921110289435, 0.027823001046531966, 0.0020930725191387212, 0.011595418776518531, 0.0529672815464437, 0.02213315412934337, 0.05529243106554661, 0.07919305696019105, 0.06484904379716941, 0.023538557912356088, 0.03513017350009509, 0.01354669634851494, 0.030095504729875495, 0.04019405998821769, 0.05829920633030789, 0.035016278004539866, 0.04392945972670402, 0.05577678293255823, 0.05934934105191912, 0.049432137848011086, 0.0433427440667791, 0.03233479582039373, 0.01651093170845083, 0.014046017546206713, 0.01627710514834949, 0.04340588853561452, 0.030285599708024944, 0.06025393001203026, 0.03971350113196032, 0.02927495233182396, 0.021022394000153457, 0.061362880149057934, 0.023234187459040965, 0.03299550911677735, 0.014651947621522205, 0.0016319204005412757, 0.05765270494988986, 0.013939245820178517, 0.027561013586819172, 0.07436158907200609, 0.014389922842383385, 0.026658285508996675, 0.00497523376751425, 0.037494145400289974, 0.014533719679872905, 0.018394242972135544, 0.02769796739864562, 0.056321337819099426, 0.017620119332735027, 0.04949196767328041, 0.03160206960248096, 0.07080408425203391, 0.06155885463314397, 0.07297602056392602, 0.023278784173141633, 0.08868319700871195, 0.029147584523473467, 0.07269056766693081, 0.11323472458337035, 0.03895251393052084, 0.020038974537913288, 0.0510417416558734, 0.0694831937019314, 0.03580295114911028, 0.07184830893363271, 0.016251736420339773, 0.06324879359453917, 0.04269790170448167, 0.05664003214665821, 0.025347890199295113, 0.04680772385160838, 0.03370361469153847, 0.021832568205094764, 0.026446282331432616, 0.60561161168984, 3.7892674122537886, 12.12900996208191, 25.84773996898106, 42.5627155985151, 51.59839275905064, 48.60899632317679, 32.51125349317278, 22.52221052987235, 20.81037415776934, 17.85687906401498, 25.893144709723337, 22.54056419645037, 25.958905935287476, 19.69427112170628, 11.305927225521632, 11.513760004724775, 10.542135204587664, 6.899962893554142, 3.223343368087496, 1.609073274901935, 0.4824385611074311, 0.2114198545792273, 0.13727564098579542, 0.233975566391434, 0.16561157549066202, 0.4756669987525259, 0.419954849673169, 0.49499097040721346, 0.5640928681407655, 1.1858238662992204, 0.8702639905469758, 1.2396288705723626, 3.1779160456998006, 2.6057911685534885, 2.9242835640907288, 2.5429729393550327, 3.0627946002142767, 3.110941708087921, 1.884334738765444, 1.1777165127652032, 2.7383853793144226, 2.680173371519361, 2.8453963228634427, 2.5737621443612233, 2.255484708717891, 2.474369249173573, 2.6202171487467627, 0.9613858695541109, 2.458399683237076, 1.8321231518472945, 1.1587414166757037, 2.1812343043940405, 2.1178382890565053, 1.2544322248016084, 1.1918803070272719, 1.1012581012078693, 0.4170056650681155, 0.3153829409607819, 0.11359589520309653, 0.048432380958859406, 0.05028524974893246, 0.22673723979720048, 0.5810449527842658, 1.5732111249651228, 3.022868514060974, 6.25470757484436, 8.59020209312439, 13.348461372511727, 17.647517681121826, 27.491112266268047, 51.67431225095476, 23.850791215896606, 23.747462817600795, 31.919829777308873, 29.69361652646746, 36.7869873046875, 27.760436603001185, 21.429321425301687, 9.550691536494664, 2.7008933339800154, 0.28291536601526396, 0.05520687119237014, 0.029890224138008695, 0.056633097518767626, 0.014459060471771019, 0.022337203180151324, 0.0880332961678505, 0.08863886153059346, 0.030620405849601542, 0.04835038339453084, 0.028870114590972662, 0.06676362534718853, 0.00214022646209092, 0.060874708129891326, 0.04426022519224456, 0.0059377433249859935, 0.05484662677294441, 0.04814828173922641, 0.023084867346499647, 0.03536510607227683, 0.041301388426550796, 0.028085349826142192, 0.021929766650178602, 0.020619751320087483, 0.023121591358046447, 0.03998916276863643, 0.05557722578357373, 0.060781070297317843, 0.021690367621236613, 0.0034761777330589083, 0.009190788209837462, 0.03675605197037969, 0.02890392259827682, 0.016841612357114042, 0.05810341505067689, 0.012836857116781175, 0.010370526512685631, 0.020440621467839395, 0.08013912476599216, 0.027588763972744346, 0.05940456023173673, 0.044622118451765606, 0.019079919571855238, 0.004377324824287955, 0.0004770533217067298, 0.11874536531312124, 0.17066913124706062, 0.152529257482716, 0.1350431250674384, 0.11568112831030573, 0.10441149624862842, 0.1328967423843486, 0.11491669075829641, 0.1357872744223901, 0.12662774377635547, 0.08961433025875262, 0.09574384242296219, 0.1360011893723692, 0.0893410842067429, 0.10346825793385506, 0.1543761348085744, 0.11321945754545075, 0.11773847362824849, 0.13530468674642698, 0.17778913490474224, 0.12407778203487396, 0.13743000770253794, 0.149375603135143, 0.20831295129443916, 0.24453416839241982, 0.1326736264995166, 0.10534404085150786, 0.1437685832913433, 0.14012376458517142, 0.20528059186679976, 0.11616193822452, 0.1747879066637584, 0.15606693550944328, 0.16147210475589546, 0.19118957727083138, 0.15547861850687436, 0.17174549134714262, 0.15402062317090376, 0.159939741981881, 0.16032022370823792, 0.1461411759789501, 0.1142282626990761, 0.14624241340373242, 0.0891435287360634, 0.13822373082595213, 0.1318169217556715, 0.17765417428953306, 0.10987270570227078, 0.15445698904139654, 0.1539616041949817, 0.7865126303264073, 4.057988124234336, 14.227485792977468, 28.821414368493215, 48.858155250549316, 56.67981536047799, 54.54030173165457, 39.60129608426775, 30.145947728838237, 29.661001682281494, 26.09485786301749, 30.091932432992117, 30.617494174412318, 30.91789606639317, 25.767952067511423, 19.436126436505997, 17.860057864870342, 13.614489657538277, 7.980741722243173, 4.281708828040531, 2.9850258018289293, 1.2259700149297714, 0.7539348612938608, 0.4813881346157619, 1.1720091104507446, 1.4926344943898064, 1.4875996559858322, 3.574038709912981, 1.7677886954375674, 4.262864010674613, 3.027739418404443, 5.029107877186366, 7.334593994276864, 5.937078492982047, 9.80313696180071, 6.209918183939798, 6.177312893526895, 8.201561553137642, 8.3388649054936, 5.399738252162933, 3.524270934717996, 5.744453583444868, 6.130910652024405, 3.216241874865123, 4.170039551598685, 5.360886965479169, 4.29558481488909, 4.8249198624065945, 2.545143165758678, 6.8801383801868985, 5.421668069703238, 5.985131800174713, 8.252954772540502, 4.01877726827349, 4.404670229979923, 3.983685391289847, 3.0875065198966434, 1.8026367340769087, 0.9867762156895229, 0.9662315866776875, 0.3254056902868407, 0.3469972716910498, 0.6264908398900713, 1.1859822635139738, 1.8220675885677338, 4.030724261488233, 7.01699400799615, 12.02293963091714, 16.20612951687404, 22.08128305843898, 27.972344500677927, 56.52755601065499, 33.43653120313372, 29.997773919786724, 40.427398681640625, 35.83251673834664, 43.73821531023298, 31.95774609701974, 23.047879968370708, 10.08816943849836, 3.1718700272696356, 0.3836957567504474, 0.1308447439223528, 0.10289248704378094, 0.14037833735346794, 0.12340904506189482, 0.172482787498406, 0.26504603773355484, 0.1488900841878993, 0.07846674629087959, 0.15274733863770962, 0.05483663195211973, 0.23109741083213262, 0.20014831583414758, 0.20663371283028806, 0.09879106855286018, 0.09106674125151974, 0.08861226974321262, 0.069217017984816, 0.09722369337188345, 0.13888104126921721, 0.18486154611621583, 0.08497336786240339, 0.1032642631658486, 0.18426535810743058, 0.11363413065139737, 0.17777689413300582, 0.1502594764211348, 0.21882113814353943, 0.12393129989504814, 0.1013418377510139, 0.12247459377561297, 0.13228482593383106, 0.1026865720216717, 0.10030760789023978, 0.13711344397493772, 0.10743246307330472, 0.14796473884156772, 0.12036456699882235, 0.14603577234915324, 0.1758192391800029, 0.23780174393739018, 0.1652598636490958, 0.15507467303957256, 0.09108379962188856, 0.07535889305706535], [0.03268716923360314, 0.01645160569543285, 0.0982624219198312, 0.048186900559812784, 0.02722610396865223, 0.03683708601498178, 0.04335632833785244, 0.012605906696990132, 0.015211145293765833, 0.05349658975111587, 0.03673674764909914, 0.029429034063858644, 0.0235202272888273, 0.031018332711287906, 0.024072453013754318, 0.06314790222261633, 0.04150381917133927, 0.057871071089591296, 0.0562310349861426, 0.027946477456550513, 0.02870730689859816, 0.007983760076708027, 0.023506030639899627, 0.02346979347722871, 0.05780734308063984, 0.03124807109790189, 0.02896660566329956, 0.05200194673878806, 0.02763873977320535, 0.02386914865512933, 0.054836978004979234, 0.03909372046057667, 0.006184844574558416, 0.01157398131077311, 0.07658936203058277, 0.09229585315499987, 0.02303597889840603, 0.027219844483105198, 0.04157563531771302, 0.035399277095815966, 0.03765561977135284, 0.04156638688540884, 0.12130614290280001, 0.02739335606539888, 0.13098275794514588, 0.049333974186863215, 0.059457872728151936, 0.04579267617581146, 0.05304929607414773, 0.05274076959384339, 0.015804295162005082, 0.2939960871423994, 1.7217435262032916, 7.008881551878793, 15.894362109048025, 31.46153007234846, 33.46056154796055, 31.163865770612443, 35.19995273862566, 29.854439531053814, 24.40546590941293, 16.07118681498936, 17.958303655896867, 23.587749787739344, 17.525291919708252, 20.63272782734462, 17.55520565169198, 10.70924198627472, 10.884355698313032, 5.599431650979178, 4.420346668788365, 2.4173330068588257, 1.1766134862388884, 0.47690812072583605, 0.16316591815224715, 0.18152201388563427, 0.24834416966353143, 0.12188957445323467, 0.40626057450260433, 0.23793473680104527, 0.7117682525089809, 0.7518943707857813, 0.9795594257967812, 3.561222106218338, 2.0797510870865414, 1.3717887103557587, 1.060520161475454, 2.378408112696239, 1.5629351735115051, 1.4896870468344008, 1.3427324295043945, 1.4550775268248148, 2.1190485783985684, 3.791821309498378, 1.432813978620938, 0.7315908659781728, 1.314807402236121, 1.2960924293313707, 0.5121147515518325, 2.1217242862497057, 0.8451279593365533, 1.5440514896597182, 0.8542103405509676, 1.4840162311281477, 0.5116225693907056, 0.4749129020742008, 0.37487404154879705, 0.28458141375865253, 0.10439411896680083, 0.055845549064023156, 0.2337029038795403, 0.21779106770242962, 0.9043634150709424, 1.7583183007580894, 3.5992537225995744, 6.579984452043261, 8.950501799583435, 14.593876464026314, 10.593639595167977, 14.979871477399554, 14.509079779897418, 37.07554946626936, 38.05770860399519, 23.678491524287633, 32.59253699438912, 25.435541561671666, 26.038952657154628, 16.491318328039988, 7.645739538328988, 3.3157257480280737, 0.26607507680143627, 0.025539769724543606, 0.012941298923189086, 0.006269862891973129, 0.0490105742189501, 0.02865268143692187, 0.07448042090982199, 0.0240249182430229, 0.023872565078948225, 0.023744483112490604, 0.027903280220925808, 0.021920618301789676, 0.05733789184263774, 0.007793338553580854, 0.03652940091810056, 0.06477162295154162, 0.03292755722733481, 0.017154176120779345, 0.02602809271775186, 0.03302623996777194, 0.019872080368388976, 0.016372337538216795, 0.05593526157151375, 0.05474899236911109, 0.013207129435613751, 0.049549619401139874, 0.036290332674980164, 0.011486256910887147, 0.049333804553108554, 0.011086095972651882, 0.011706133639173848, 0.02788033047025757, 0.05121772310563496, 0.029468439985066652, 0.040266551276935, 0.004593651542173964, 0.03869808704725333, 0.0212721830965685, 0.020492989104241133, 0.06650373286434583, 0.006242219375313393, 0.06856732748981033, 0.04556513284998281, 0.015267726632633379, 0.03645169848044004, 0.06838307809084654, 0.010855592537804373, 0.03364549816719123, 0.02596136219134288, 0.012888880396660949, 0.06676794761525733, 0.030979452654719353, 0.09059631970844098, 0.0378605644883854, 0.05185008381626435, 0.009730145518135811, 0.007910452849630798, 0.02106190170161426, 0.031578599076185904, 0.031239623336919715, 0.04417688073590398, 0.010007936906601702, 0.028961306304803917, 0.09433504766119377, 0.05097775919628995, 0.044263994454273155, 0.008651790525098997, 0.03578380967623421, 0.05350939370691776, 0.0070468431638021556, 0.01759328836176012, 0.05161634885839053, 0.0345295410869377, 0.016205558719645654, 0.013157799091589237, 0.025249631543244635, 0.016590286378881762, 0.06771927406745297, 0.03137567639350891, 0.02829404853816543, 0.026040491248880113, 0.01794591961827661, 0.027019099897838066, 0.022907070815563202, 0.05271535167204482, 0.009393535321578383, 0.02223020838573575, 0.011440765378730637, 0.03868362068065575, 0.06194010988942214, 0.06329446578664438, 0.03063595447955387, 0.042086972522416284, 0.09525483580572264, 0.018658981891348958, 0.06775571139795439, 0.041437896101602485, 0.40926705460463253, 3.285010801894324, 10.410205415316991, 22.334539685930523, 36.48495258603777, 41.2199136870248, 36.214066641671316, 37.00665807723999, 31.983714989253453, 25.62792502130781, 18.172443662370952, 16.96099397114345, 26.89974934714181, 21.960003989083425, 24.95350854737418, 21.06218555995396, 18.240357092448644, 11.933767318725586, 6.618830093315669, 5.574926223073687, 2.959517879145486, 1.2177387880427497, 0.4350601519857134, 0.2656517523740019, 0.03871654998511076, 0.18865363406283514, 0.051232661054070504, 0.21391287366194384, 0.456695376762322, 0.3648188039660454, 0.8174064382910728, 0.901444248855114, 1.9737943155424935, 1.4215012256588255, 1.1382454250540053, 1.5850023265395845, 2.80049706356866, 1.6149816321475166, 2.5982024329049245, 1.961927660873958, 2.7143142138208662, 1.770404583641461, 1.9926256707736423, 1.0300580646310533, 0.9679797100169318, 2.3280458322593143, 1.1672204988343375, 1.0941484655652727, 2.121756204536983, 0.9751414571489606, 1.6134190474237715, 1.1076281879629408, 0.42809208588940756, 0.6299857294985226, 0.8459373701895986, 0.4037296931658472, 0.09179560999785151, 0.08138656390032598, 0.08259183886860098, 0.13202239573001862, 0.248707864433527, 0.8101825916341373, 1.8723273830754417, 3.6454718368394032, 7.902243580136981, 9.75251064981733, 17.06404444149562, 15.363306079592023, 17.478587865829468, 17.31664620126997, 43.7740159034729, 37.06192404883248, 26.180970362254552, 38.37319850921631, 29.930751596178325, 31.77753414426531, 19.480301346097672, 10.800596032823835, 4.069289803504944, 0.445158028709037, 0.03946049238688179, 0.018899705759914856, 0.05272988589214427, 0.012249116020809327, 0.03489490505307913, 0.06421611311712436, 0.012099366734868713, 0.07475836242416076, 0.019893642514944077, 0.0497936918400228, 0.04706638479339225, 0.01575188511716468, 0.027508435604561652, 0.03556504998622196, 0.05818529387137719, 0.07910408744854586, 0.016580098175576756, 0.043262744788080454, 0.04988129410360541, 0.017499974529658045, 0.019777568921978985, 0.0472117982405637, 0.023320748171369945, 0.0195251148792782, 0.0889831366283553, 0.04240368892039571, 0.0258127273991704, 0.01658947892220957, 0.02640115127100476, 0.011697299113231046, 0.047702806536108255, 0.05194195067243917, 0.013196028602708663, 0.005312895269266197, 0.012922650236370308, 0.050711227248289754, 0.10144234914332628, 0.05708611463861806, 0.02870049440701093, 0.05482131741674883, 0.08123261108994484, 0.007905324821227362, 0.07420005702546664, 0.022669792208554487, 0.11378384261791195, 0.11789240608257906, 0.07168005939040865, 0.18093536607921124, 0.1582842929554837, 0.1302455567887851, 0.10065832228532859, 0.19068398725773605, 0.1328900655997651, 0.22437223313110216, 0.09977181628346443, 0.11380969480212245, 0.06615305918135814, 0.09991428828133003, 0.1381264424749783, 0.10890478228351899, 0.16268867733223097, 0.18644431047141552, 0.1710380371659994, 0.14084364952785627, 0.14963943112109387, 0.15835667907127313, 0.1366729118994304, 0.14713035789983614, 0.10479000343808106, 0.1968533769249916, 0.10512266880167381, 0.15775758693260805, 0.19508240052631923, 0.1390134370220559, 0.10639821964183024, 0.11303960505340781, 0.14544883955802235, 0.07847545189516884, 0.13623668173594133, 0.17134655346827848, 0.14762666555387632, 0.08620810482118811, 0.1264819944543498, 0.17528821767440864, 0.11058972044182674, 0.09755784472716705, 0.12351838419479982, 0.29399063172084944, 0.07543974728988749, 0.18135670918439115, 0.14493019453116826, 0.1550369057804346, 0.14151310574795517, 0.12560473009943962, 0.2166758139750787, 0.19075091795197555, 0.5895935712116105, 3.3044664093426297, 12.685393043926783, 25.56214816229684, 41.27548885345459, 48.038014207567485, 45.30706991468157, 46.33998564311436, 40.7157107080732, 34.903295925685335, 24.74746666635786, 27.15167018345424, 33.04842220033918, 27.64503570965358, 31.669545241764613, 26.169752495629446, 18.64927247592381, 15.402136087417603, 8.664701546941485, 6.2799230217933655, 3.8208170107432773, 2.0962682579244887, 0.7353912591934204, 0.7336792339171682, 0.597906113735267, 0.7513917663267681, 0.5828791686466762, 1.2751598954200745, 1.4721660784312656, 2.6899145288126807, 2.806588896683284, 4.466912192957742, 7.5395884343556, 5.2515440327780585, 5.648571916988917, 6.14248982497624, 5.867812769753592, 5.286840447357722, 5.85755375453404, 3.696165459496634, 5.288453732218061, 5.161254363400595, 9.951528770583016, 4.8893400856426785, 3.399242009435381, 4.570223655019488, 6.547688356467655, 6.04099531684603, 7.557209065982273, 5.455025936876025, 4.189864499228341, 4.117435608591352, 5.282081799847739, 2.103491344622203, 2.580183582646506, 1.684047160404069, 1.0775327171598161, 0.5903093985148838, 0.3675722990717207, 0.5946316665836743, 0.4777509697846004, 1.7469968625477381, 2.724101620061057, 5.293719598225184, 9.588129299027578, 13.098462581634521, 20.78379556110927, 18.73580707822527, 23.26072587285723, 21.658549445016043, 46.44403144291469, 46.088658877781455, 32.824745791299, 44.11297334943499, 35.707640239170615, 35.61087615149361, 22.769599403653825, 11.989880102021353, 4.517939763409751, 0.5639749658959252, 0.10689139924943447, 0.08480861277452537, 0.13567760959267616, 0.17036706102745874, 0.13299314863979816, 0.17942757984357222, 0.0911593409255147, 0.21124190198523657, 0.1116107731525387, 0.1151202241224902, 0.14282873086631298, 0.1038572620600462, 0.11261552745210272, 0.10394296781825167, 0.13876450966511453, 0.16313509909170015, 0.1027174453650202, 0.13099011326474802, 0.17010353159691605, 0.0937281320137637, 0.0884742760764701, 0.12617757650358336, 0.10969548592610018, 0.17316060326993465, 0.19798628613352776, 0.12432466021605901, 0.1509468731071268, 0.09756065386214427, 0.08195428736507893, 0.12312790086226803, 0.16035550752920763, 0.1200196947902441, 0.08071391856563942, 0.14394004909055574, 0.09677437426788466, 0.16788044731531823, 0.2612994387745857, 0.14526650362781116, 0.18373261312288897, 0.1637457398963826, 0.18792779158268655, 0.10747129563242197, 0.13141649109976633, 0.0732728321371334, 0.3120297837470259], [0.023461101443639824, 0.01871669977637274, 0.05740007957709687, 0.026616815144994428, 0.03173060788373862, 0.02773067957189466, 0.029989476847861494, 0.04359982741464462, 0.0467510322508003, 0.02015093111965273, 0.03811588364520243, 0.01222532573488674, 0.06193707683788879, 0.010434505579593991, 0.03575509407424501, 0.0025967011419457515, 0.016901031668697084, 0.018684053760288016, 0.022355459164828062, 0.08526916163308279, 0.01268965403349804, 0.06049319503030606, 0.02115512902050146, 0.005884801478324724, 0.05496748064511588, 0.0047182271789227214, 0.04041268057855112, 0.060578195112092156, 0.01121716179685401, 0.03794467568929706, 0.025362322639141763, 0.0842261922412685, 0.057911498206002374, 0.04691364656069449, 0.03917065276099103, 0.028099420946091413, 0.012310659995169511, 0.023200521944090724, 0.038107978712235174, 0.04865074031321066, 0.027575349335425665, 0.03456384103213038, 0.018983671075797508, 0.04672554647549987, 0.057729474401899745, 0.027984207396262457, 0.01174783385691366, 0.04402292114017265, 0.04210148638646517, 0.022172678794179643, 0.10292932470994336, 0.03886258429182427, 0.034000022536409755, 1.0062426796981265, 6.660660854407719, 18.20587318284171, 26.936713763645717, 31.59390367780413, 36.89783886500767, 35.42217002596174, 31.606556347438268, 29.433712209974015, 23.04162311553955, 17.431828226361954, 16.614925043923513, 14.529969538961138, 15.037181956427437, 18.92055446760995, 17.875437702451432, 10.089635508401052, 7.757244229316711, 5.259537066732134, 3.7523225375584195, 1.4775380130325044, 1.0998418629169464, 0.4854679214102881, 0.4670940616301128, 0.16752916973616394, 0.1830957265836852, 0.1948623244783708, 0.20555250799017294, 0.30947159816111836, 0.2843276688030788, 0.7388057016900608, 0.7308557682803699, 1.0217810230595725, 0.6274256440145629, 1.1714469577584947, 1.6909117634807314, 0.7869493897472108, 1.727967266525541, 1.4794654867478778, 0.698120904820306, 1.1619287942137038, 1.1144905111619403, 0.5991921275854111, 2.2180287071636746, 1.1450834295579364, 0.26285561812775476, 1.0674294935805457, 1.1194129841668266, 0.766034660594804, 0.28361827401178225, 0.7717194812638419, 0.5240762382745743, 0.5368676004665238, 0.39098742976784706, 0.1795457670731204, 0.13001556055886404, 0.30752604827284813, 0.44899582277451244, 1.261923468538693, 2.3175553551742007, 4.850986897945404, 5.421982041427067, 10.3933265038899, 10.937884620257787, 8.670269659587316, 12.777076261384146, 17.69301274844578, 18.347183908735, 27.02039439337594, 39.50931930541992, 31.007642473493302, 32.659479413713726, 26.70340715135847, 14.597380093165807, 6.9695404171943665, 2.7598383767264227, 0.3919717940901007, 0.00898520227721227, 0.022856102657637427, 0.05521940373416458, 0.025888043089902828, 0.024560299336111972, 0.04968957742676139, 0.01823612565307745, 0.09215486714882509, 0.061605816041784625, 0.02424768468232027, 0.05752557462879589, 0.014602187255929624, 0.04688214896512883, 0.018817871043990766, 0.01940379960329405, 0.031328036449849606, 0.03772563101457698, 0.07437919027038983, 0.08555798684912068, 0.053734803040112765, 0.0246799182745495, 0.0483449822557824, 0.0767089741836701, 0.020020603202283382, 0.01619676999481661, 0.09260100392358643, 0.04405680039365377, 0.02403462807913976, 0.040870304951178174, 0.00918455671385995, 0.04173088412997978, 0.06028364984584706, 0.05218433355912566, 0.030989827455154488, 0.007243422392223562, 0.0321063873624163, 0.019252338712768893, 0.045564243969108374, 0.018700114684179425, 0.04961489786260894, 0.017043086367526224, 0.07155322762472288, 0.030320737643965652, 0.01992725713976792, 0.01577447185159794, 0.06163364954824958, 0.030322298274508545, 0.046953008377126286, 0.014015699753404727, 0.035568612295069864, 0.03368783196700471, 0.0520324468878763, 0.06659364553966693, 0.06756075471639633, 0.02427416111874793, 0.04144600120240024, 0.009438802937178739, 0.04716394455837352, 0.10986001709742205, 0.016043602588719556, 0.013031139504164457, 0.05578197033277579, 0.048905777877994945, 0.013206093821541538, 0.09047171353761639, 0.045814066992274353, 0.06504843131239925, 0.030465564158345972, 0.018136784733672227, 0.06782903389206954, 0.09960577876440116, 0.005975446123297193, 0.030761435960552523, 0.09442581529063837, 0.039924040370221646, 0.02756609920678394, 0.023121637159160206, 0.05109117293198194, 0.01952537102624774, 0.003470792921559353, 0.023879177402704954, 0.07223360147327185, 0.04244386497884989, 0.043808575320456705, 0.05669753798948867, 0.08119070476719312, 0.03444921950410519, 0.03446919896772929, 0.02036960599278765, 0.019604474638721774, 0.026654429733753204, 0.02280979773162731, 0.02950773055532149, 0.0174694234904434, 0.04370261529194457, 0.024575644405558705, 0.06114015781453677, 0.060562758440417905, 0.08618538746876375, 1.739330068230629, 8.489653842789785, 23.835826533181326, 32.87208039419991, 39.219711439950125, 42.43430594035557, 41.744023254939485, 35.04215220042637, 29.334252221243723, 21.779156276157924, 22.017479487827845, 18.32271930149623, 22.477497134889873, 23.601085117885045, 19.02828107561384, 18.73084953853062, 11.967195102146693, 8.824096696717397, 5.712748084749494, 3.5282463899680545, 1.9672402100903648, 0.8019872999617031, 0.4179747487817492, 0.2735164617853505, 0.04039713194859879, 0.0608808963692614, 0.06544694171420165, 0.15561497690422194, 0.43480635274733814, 0.6224863976240158, 0.8064185678958893, 1.3077010235616138, 0.6135307124682835, 1.0512993591172355, 1.6724564794983183, 1.3206708133220673, 1.2375191152095795, 0.9070675671100616, 2.2920821734837125, 1.4444228985479899, 1.6233688678060259, 1.3517795268978392, 0.9263457783630916, 1.3883548442806517, 1.1722714049475533, 1.5546143800020218, 1.2180018424987793, 0.676748083106109, 0.7189277740461486, 0.413148112062897, 0.36542023026517456, 0.09154291677155665, 0.33331241458654404, 0.09280719035970313, 0.15935511620981352, 0.15481391203190598, 0.20568710219647202, 0.37505512897457394, 0.725978567131928, 2.6917753432478224, 4.9678516898836405, 7.7315437112535745, 12.749714255332947, 14.653035163879395, 14.8664299760546, 14.962912661688668, 20.004549877984182, 17.71831808771406, 31.694593497685023, 43.92836318697248, 32.58223628997803, 36.11363043103899, 28.75310662814549, 19.1438695703234, 9.94521633216313, 3.501608733619962, 0.6902765514595168, 0.03730807752747621, 0.04022944558944021, 0.06521780043840408, 0.043190365457641225, 0.025882869260385633, 0.0361979908442923, 0.034899257855223756, 0.02765226806513965, 0.07350365617977721, 0.03554310955639396, 0.02336874434591404, 0.01486480575320976, 0.042166313622146845, 0.06524468399584293, 0.07085877417453698, 0.052713333030364344, 0.03822782835257905, 0.02255308079267187, 0.027247946010902524, 0.05225979683122464, 0.03071028459817171, 0.037337305423404486, 0.031089426217866794, 0.057124879344233444, 0.038890241379184384, 0.05615555135799306, 0.020393907724480544, 0.044869614099817615, 0.01775509012596948, 0.014282709220424294, 0.03233167455930795, 0.008373566570558717, 0.0364927328856928, 0.07496363283800227, 0.032847086366798194, 0.10298075766435691, 0.010510040097869933, 0.022529038600623608, 0.02245019283145666, 0.058429525765989504, 0.012802195851691067, 0.08309693355113268, 0.030280558192836385, 0.03930061596578785, 0.03118708437042577, 0.07858052982815675, 0.11493520119360515, 0.1558643113821745, 0.15933286026120186, 0.11946691945195198, 0.07983909693679639, 0.20700009459895746, 0.14565130083688668, 0.10936834383755922, 0.1833009562854256, 0.17364734358021192, 0.10287808174533503, 0.1561583477471556, 0.25962533003517557, 0.1700916572340897, 0.11336850454764706, 0.1283363356654133, 0.15523875637778214, 0.14745053143373557, 0.1875090676226786, 0.16567987682563917, 0.15909052826464176, 0.09570558661861078, 0.07950476237705775, 0.10529483349195548, 0.1802389041653701, 0.09832653669374329, 0.09082704197083201, 0.24421208138976777, 0.08907323929348163, 0.15224256286663668, 0.12295929848083428, 0.16111070343426295, 0.1602072204862322, 0.1459860493029867, 0.10517018660902977, 0.12964419834315777, 0.09186212000037942, 0.1641879818801369, 0.10013226087072066, 0.09940915967204741, 0.11469122714229993, 0.151412036003811, 0.11685104481875896, 0.11461740253227097, 0.08580389472522906, 0.16445448329406126, 0.15935960811163696, 0.1816121776189123, 0.14826013227658613, 0.12251403023089681, 0.22598821856081486, 0.21289148846907274, 0.2566883862018585, 2.185921949999673, 10.448079177311488, 25.73878526687622, 38.26225662231445, 44.6373747416905, 48.96504633767264, 49.374910150255474, 42.87710768835885, 40.94434118270874, 33.138106073652, 27.517185381480626, 26.721342188971384, 23.98972044672285, 26.27706742286682, 27.494136469704763, 25.896363462720597, 15.877731595720563, 11.589997376714434, 8.041466372353689, 5.738333523273468, 2.523788094520569, 2.0135595074721744, 1.264374554157257, 0.9421417479004178, 0.6550387080226625, 0.5084661873323577, 0.9622889182397297, 0.9346153289079666, 1.0929582608597619, 2.0349417201110294, 2.9170428897653307, 3.033482104539871, 5.5823733891759595, 4.656303150313241, 5.1737116149493625, 5.391077756881714, 2.9939961433410645, 5.645126479012625, 3.8604721171515326, 5.97141649041857, 3.244621140616281, 3.6588979278291975, 5.267627809728895, 5.8732419184276035, 4.814410712037768, 4.731673734528678, 3.816862617220197, 3.3566771277359555, 3.234878897666931, 1.9430272579193115, 1.7240414257560457, 1.979695507458278, 1.5079268280948912, 0.9483445350612912, 0.5187794853534017, 0.4839370378426143, 0.4038427642413548, 0.9803237276417869, 1.727244762437684, 3.5770839750766754, 6.904163513864789, 9.085866604532514, 15.479306255068098, 18.2760135105678, 16.21844346182687, 22.58129106249128, 27.915718419211252, 27.48670710836138, 36.55576515197754, 47.505299295697895, 40.637070996420725, 43.192441259111675, 34.82714714322771, 20.236364364624023, 10.865546924727303, 3.98577549627849, 0.799476503261498, 0.069150650474642, 0.07842360503439393, 0.15955209492572717, 0.09745670908263751, 0.07151272586945977, 0.26025525480508804, 0.17253365048340388, 0.203939643821546, 0.13349107120718273, 0.10662537959537335, 0.11402101096298013, 0.0846204346578036, 0.2044260720057147, 0.14527123980224133, 0.13361172830419882, 0.18064829148352146, 0.18615848438016006, 0.11652270172323499, 0.19732793074633392, 0.11874774018568651, 0.1594010123184749, 0.10495802906474896, 0.14223433418997697, 0.2005710160093648, 0.15751491566853865, 0.17207018392426626, 0.141231364437512, 0.1146552919277123, 0.13993597323341028, 0.17157270918999398, 0.12184507612671171, 0.11752382586044924, 0.1563308042074953, 0.1943971344402858, 0.12240076916558401, 0.18181473389267921, 0.06934119667857885, 0.1349377350083419, 0.10924438227500234, 0.22116690155650887, 0.11538052372634411, 0.10428976706628289, 0.1370124372520617, 0.18335956814033644, 0.13969997875392437, 0.11336465046874114], [0.05671595682256988, 0.032400243915617466, 0.017512800537848046, 0.03045047014685614, 0.049861307854631116, 0.018893049331381917, 0.009593065329162138, 0.043688776570239236, 0.015948231099173427, 0.04462150437757373, 0.027023695276251862, 0.014685976152707423, 0.03856715014470475, 0.04812603936131511, 0.021978924815942134, 0.017636546665536504, 0.052615155798516104, 0.030501787750316516, 0.018892450524227958, 0.053297460079193115, 0.022430086142516563, 0.028282325149380734, 0.11605567964059965, 0.017637995337801318, 0.014085323383499469, 0.04523335297458938, 0.03262440135170307, 0.0163671891537628, 0.06586926190980844, 0.02026948475811098, 0.021172056772879193, 0.027216484038425342, 0.006048875910762165, 0.06060949593250241, 0.014099794839109694, 0.03626063998256411, 0.06650285755417176, 0.06316367816179991, 0.03269861611936774, 0.02448318892025522, 0.06799222156405449, 0.016079517447256615, 0.022747845788087164, 0.012493370815978518, 0.04716896911018661, 0.027301577418776493, 0.01630782412498125, 0.040492825742278776, 0.027626663546210954, 0.03741098414840443, 0.05575083236077002, 0.056978851822870116, 0.048991029017737935, 0.07532737510544912, 1.088921683175223, 6.273772997515542, 15.880672420774188, 23.754489183425903, 31.59683929170881, 39.69335971559797, 38.016022886548726, 35.51934405735561, 25.644334929330007, 16.83641450745719, 17.09391474723816, 11.732623049191066, 19.979767390659877, 24.70714279583522, 12.77345277581896, 9.114471469606672, 14.680821010044642, 17.823548555374146, 7.589796117373875, 5.612670574869428, 3.522367996828897, 1.4421425866229194, 0.708600959607533, 0.42649161177022116, 0.24173784415636743, 0.1985671121094908, 0.07517674711665936, 0.3252040839620999, 0.16572563722729683, 0.47735258830445154, 0.9284264381442751, 0.21283470865871223, 0.4740122418318476, 0.9742539333445686, 0.6534229261534554, 1.0663811841181345, 0.1494368612766266, 1.8629579544067383, 0.9067854593907083, 0.7879996533904756, 0.4264998084732464, 0.9132055406059537, 0.5599256860358375, 0.42716314430747715, 0.9548865897314889, 0.1775808110833168, 0.09027032434408154, 0.4086831887917859, 0.2541734368673393, 0.1240346407783883, 0.09809536659823996, 0.04514415615371295, 0.16324050272149698, 0.1341533213853836, 0.5462737785918372, 1.0352553171770913, 1.2954780565840858, 3.425754163946424, 3.6901978254318237, 6.973095723560878, 12.812426958765302, 16.162555626460485, 19.099684238433838, 21.68439153262547, 23.174675907407487, 15.518063306808472, 18.785679510661534, 25.997107131140574, 33.08339248384748, 32.25086627687727, 26.276825972965785, 17.77336171695164, 7.592486807278224, 2.8443547444684163, 0.4500342256256512, 0.04481677657791546, 0.08009628885026489, 0.016419514381725873, 0.01662083063274622, 0.036997501871415546, 0.03177656166787658, 0.086405056395701, 0.06488666177860328, 0.030503928528300354, 0.025456900242716074, 0.02323474725043135, 0.03874053280534489, 0.021329095221257637, 0.05782284760581596, 0.00769818334707192, 0.023302658427772776, 0.02972532995045185, 0.021744628370340382, 0.11484771088830062, 0.010916943129684244, 0.04310366903830852, 0.0341211376445634, 0.013173351962385433, 0.03394893224218062, 0.07609228084662131, 0.04823059821501374, 0.07854588383010455, 0.058356250769325664, 0.028312301130167077, 0.06127059938652175, 0.025004076505345956, 0.054116567197654925, 0.028757009588714157, 0.05632031323122127, 0.0049868757320967105, 0.042577000334858894, 0.016375692893884013, 0.03406772676057049, 0.018016047908791473, 0.027990052975448113, 0.019723991796906506, 0.03809517814910837, 0.04666018319715347, 0.023879979770364504, 0.04156174570588129, 0.021852722391486168, 0.022176129144749472, 0.06344777398875781, 0.022559413220733404, 0.0841612767960344, 0.01506253594665655, 0.054591124411672354, 0.028096282721630166, 0.046858339171324453, 0.03806089177461607, 0.012415614095516503, 0.026934947984825288, 0.019527116557583213, 0.0231336624960282, 0.0070167420781217515, 0.026829468019838845, 0.026446657222030417, 0.019414379660572325, 0.017011483599032675, 0.013243649886654956, 0.02695097158929067, 0.0811740942299366, 0.016848245036921332, 0.02584486112131604, 0.06536465577249016, 0.012067564646713436, 0.043439123180827925, 0.014526298203106438, 0.03684439383713262, 0.06521756295114756, 0.02950236334332398, 0.07190009472625596, 0.04483802490202444, 0.04835268023556896, 0.025645935009898882, 0.05814490068171706, 0.04512329459456461, 0.03542859320129667, 0.013215678128679948, 0.02890937462715166, 0.008185473270714283, 0.007179265209872807, 0.05721242393233946, 0.019123303404610072, 0.03276957391894289, 0.07543777953833342, 0.06507891110543694, 0.069432093229677, 0.03521197089659316, 0.06378797787640776, 0.011992650139810783, 0.012932289674478983, 0.02920425237555589, 0.08450543654284307, 0.058860232654426775, 0.2522644193044731, 1.7072628289461136, 8.911305274282183, 20.351249354226248, 30.771914413997106, 38.1462390763419, 44.80890839440482, 41.82986824853079, 42.031918389456614, 28.105402503694805, 19.287964786802018, 17.384644746780396, 12.101621900285993, 20.420376982007706, 26.52495309284755, 20.41789300101144, 16.14150432177952, 18.523230416434153, 16.419458321162633, 10.016923478671483, 5.105257962431226, 4.487754617418561, 2.1333427599498203, 0.6522484634603772, 0.34753171301313807, 0.06223250419965812, 0.0847880667341607, 0.14835712207215174, 0.11034005348171506, 0.2584800443478993, 0.414467346987554, 0.31698767627988544, 0.464667837534632, 0.4771476707288197, 0.3898602473948683, 0.8594428769179753, 0.9487013901982988, 0.6763093695044518, 1.1356596095221383, 0.8323105956826891, 0.845466629735061, 0.9656832218170166, 0.7674494332500866, 0.697912893124989, 0.34964920367513386, 0.5081320766891751, 0.9216054784400123, 0.595261672777789, 0.3290041514805385, 0.5212400161794254, 0.19223282486200333, 0.06430949310639075, 0.08635768786604915, 0.10445872907127653, 0.12120181135833263, 0.4632095843553543, 1.1267408366714204, 1.3607963344880512, 4.123673788138798, 5.554618375641959, 7.75483580998012, 12.535278081893921, 19.01246002742222, 18.40440058708191, 19.02966203008379, 21.559407336371287, 19.14958620071411, 23.047447443008423, 29.34784984588623, 37.681769371032715, 36.77828121185303, 31.62949582508632, 22.54336084638323, 9.740788170269557, 3.539913066795894, 0.7722721344658307, 0.1276480975959982, 0.039744245553655286, 0.007151636112082217, 0.04735875874757767, 0.04639738319175584, 0.013105911518713194, 0.03724865143054298, 0.048204467831445594, 0.02564257795789412, 0.034050977123635154, 0.023976771094437157, 0.033736842551401684, 0.030689372148896967, 0.035926339349576404, 0.04506420097979052, 0.027197415508063774, 0.007942304131574929, 0.06565462092735938, 0.06258020589926414, 0.05075748298051102, 0.06409591063857079, 0.03694707654150469, 0.04180365361805473, 0.05412582241530929, 0.03732988564297557, 0.060798060814184804, 0.008764293327528452, 0.06224921651716743, 0.05926163361540862, 0.031213248680744852, 0.016725978115573525, 0.02157587501486497, 0.03454784117639065, 0.005457278615462461, 0.016489707133067504, 0.07619284652173519, 0.028390999317967465, 0.04561740379514439, 0.041158628051302264, 0.04486329015344381, 0.008742939830491585, 0.018494121630543044, 0.05125553107687405, 0.04572817463693874, 0.0444459571902241, 0.03626580363405602, 0.06885817474020378, 0.21014034109456198, 0.11644646152853966, 0.1379890934165035, 0.16235721297562122, 0.11248478053935937, 0.0788156015000173, 0.16364271113915102, 0.14306300186685153, 0.14323663897812366, 0.1979217574532543, 0.1648532176124198, 0.09425859712064266, 0.10667922134910311, 0.09914364891925029, 0.12988845737917082, 0.0795220107372318, 0.13704883387046202, 0.0764536957389542, 0.10966333015156643, 0.19415542669594288, 0.11244035685168845, 0.1175902680094753, 0.15713551959821156, 0.11347545523728643, 0.14584806242159434, 0.15843377422009194, 0.1805826500058174, 0.14671527088752814, 0.14389932341873646, 0.2035541952188526, 0.13852531250034059, 0.18786257079669408, 0.15391348249145917, 0.13740444050303527, 0.11463805713823863, 0.12486496408070837, 0.13855241318898542, 0.1722912099212408, 0.17002339661121368, 0.08468752141509737, 0.24879354983568192, 0.10095272505921976, 0.08694375213235617, 0.1372566827173744, 0.19635500652449472, 0.17035235038825444, 0.10111298145992414, 0.15922637097537518, 0.060371418350509236, 0.1138333146061216, 0.13473490732056753, 0.19902848878077098, 0.12705972631062779, 0.2727199159562588, 2.173309015376227, 10.089837006160192, 22.172012635639735, 34.676020349775044, 43.55436944961548, 51.888486998421804, 50.69403607504708, 48.65821041379656, 37.42875419344221, 25.74819486481803, 25.642907074519567, 19.64964631625584, 29.87846987588065, 34.505150250026155, 22.34799313545227, 18.34854575565883, 22.62465476989746, 23.79074662072318, 11.690004536083766, 7.761406200272696, 5.581350701195853, 2.405032524040767, 1.3810962566307612, 0.8342304155230522, 0.5398050599864551, 0.6086284869483539, 0.5353252632277352, 0.8989177101424762, 0.6219348300780568, 1.1711060617651259, 3.07266212786947, 1.1439279658453805, 1.8071336299180984, 3.158635880265917, 2.47572306224278, 3.606556713581085, 3.0196200140884946, 5.903456160000392, 2.9172854253223965, 3.869327161993299, 3.393371433019638, 1.4757604684148515, 3.503240474632808, 2.4719916624682288, 3.138155847787857, 2.157625411237989, 1.2062358281442096, 2.591892817190715, 1.8388138328279768, 0.5239115985376495, 0.7176515311002731, 0.7126295034374509, 0.35343154785888536, 0.496727314378534, 0.7514003972922052, 1.530071605529104, 2.0665781710829054, 5.449063513960157, 6.783115906374795, 10.70537531375885, 18.875597885676793, 24.166729279926844, 27.483582156045095, 31.36558587210519, 35.452325207846506, 26.946953671319143, 30.06743655885969, 35.84371028627668, 42.924150466918945, 42.29271902356829, 35.24650566918509, 23.51136997767857, 10.991767900330679, 3.755016267299652, 0.7099288797804287, 0.1600599376750844, 0.17948232404887676, 0.14281115680933, 0.1652006818247693, 0.09514276896204267, 0.14194039281989845, 0.1549833015139614, 0.1435749429677214, 0.13064209265368326, 0.13205472113830702, 0.10601485414164406, 0.15113786714417593, 0.12255333097917692, 0.13001627980598382, 0.11239581781306437, 0.12694134909127439, 0.1114231175077813, 0.13884243262665613, 0.2502267515020711, 0.10411770415625402, 0.17825427066002572, 0.1515308746269771, 0.11221620959362813, 0.11843379560325827, 0.1533588208258152, 0.10827670312885727, 0.13521440087684564, 0.19187001218753202, 0.0947405266176377, 0.10840724648109504, 0.10557099724454538, 0.12403545502041068, 0.12251948565244675, 0.13273295760154724, 0.09986170860273497, 0.16822237468191556, 0.13461342241082871, 0.1664237683372838, 0.08558708921607051, 0.14134286131177629, 0.15293443788375172, 0.08108998302902494, 0.08861123836998429, 0.10002335600022759, 0.17187134602240153, 0.06079794546323163, 0.12387053029877798], [0.057082280915762694, 0.11390564643910953, 0.03645877560068454, 0.030522025057247708, 0.02340552772927497, 0.01714927370526961, 0.04250741317602141, 0.017934538889676332, 0.007492048649250397, 0.043543397049818716, 0.0459728848987392, 0.04910064974267568, 0.01426366443878838, 0.044511479924299886, 0.018580388876476457, 0.046698506855006726, 0.025333875058484927, 0.019046500025849258, 0.020620624933923994, 0.003777745836747012, 0.07306872201817376, 0.031597832151289494, 0.02414804181483175, 0.07176526981805052, 0.061893480962940624, 0.04315543108220611, 0.027825391186135154, 0.03257554004501019, 0.03638286788814834, 0.03940312225105507, 0.039408757484384944, 0.036447179437215836, 0.012595943258410054, 0.04623477905988693, 0.010186769051610358, 0.034737735986709595, 0.01747672791991915, 0.04946815448680094, 0.010453613973887903, 0.04646729604740228, 0.04578917154244014, 0.06923530450356857, 0.04226873509053673, 0.04588750823001776, 0.08194412969584976, 0.028143663125644838, 0.023939360066183975, 0.048115176015666554, 0.07148409847702299, 0.04521132094253387, 0.02035058326353984, 0.051070134953728745, 0.009856518424515213, 0.01853400931161429, 0.017043410367997627, 0.9766126296349934, 5.002988730158124, 12.907472235815865, 24.08205505779811, 38.093248639787944, 40.693813460213796, 37.54039090020316, 32.77090767451695, 22.617911543164933, 24.98044150216239, 32.880890710013254, 36.470198086329866, 13.773626855441503, 16.9174530846732, 15.003095831189837, 13.174558384077889, 14.66011016709464, 10.195809194019862, 8.475141661507742, 6.266445253576551, 4.626888820103236, 3.1321925563471655, 1.437843497310366, 0.5552520996757916, 0.42811925443155424, 0.22774433504257882, 0.20009482013327734, 0.19418862062905515, 0.2036141777145011, 0.06261614111385175, 0.12154688712741647, 0.04984825623354741, 0.23589370346495084, 0.175517060394798, 0.2694338522851467, 0.36093112400599886, 0.4700068767581667, 0.1989452461046832, 0.5948298530919212, 0.8060187207801002, 0.4508172278957707, 0.2600393721035549, 0.23120084671037539, 0.39079258165189196, 0.7046882552759988, 0.26657806124006, 0.10349736030080489, 0.26307416068656103, 0.2514303912009512, 0.18162732252052852, 0.335381810686418, 0.45041800503219875, 1.2464830513511385, 1.8675363830157687, 3.141931108066014, 4.444809104715075, 5.688825002738407, 7.83738214629037, 16.147062880652292, 20.806788887296403, 15.075968538011823, 20.861118589128765, 17.517581156321935, 18.21256082398551, 19.25728849002293, 23.627286774771555, 29.86783913203648, 32.5499758039202, 26.53299389566694, 16.84731101989746, 6.984922426087516, 2.795227723462241, 0.4958472273179463, 0.07549939730337688, 0.051156695666057725, 0.04766229799549494, 0.038549280924988646, 0.07455551438033581, 0.09904721552239996, 0.025679203581863215, 0.05687713263822453, 0.018312043543638926, 0.07113808632961341, 0.038769747130572796, 0.01832198747433722, 0.00532603170722723, 0.02924193481781653, 0.029508751750524555, 0.04562888460765992, 0.027103594471035258, 0.024131187004968524, 0.0131483046903408, 0.03338664384292705, 0.050453570538333485, 0.01467135881206819, 0.03616590292326041, 0.007307805187468017, 0.07529372655387435, 0.02739002785113241, 0.04392930705632482, 0.017340020077036958, 0.05526855681091547, 0.04766257958752768, 0.02548789232969284, 0.019566892280376384, 0.025286509921508174, 0.03673271375841328, 0.08536055351474456, 0.034688501485756466, 0.02998010627925396, 0.0380389377740877, 0.021254239238000343, 0.03714156842657498, 0.025788832788488696, 0.023675272540588464, 0.04077446187979408, 0.03974840836599469, 0.05826580205133983, 0.08401459109570299, 0.05359977796407683, 0.040814339382840056, 0.09338247270456382, 0.05345396418124437, 0.013609102910517581, 0.038205002434551716, 0.026317511651931063, 0.05165263691118785, 0.037730034706848006, 0.011177261393251163, 0.07162638727043356, 0.05007389626864876, 0.03952139090480549, 0.053301890912864885, 0.05300368495019419, 0.037256729389939985, 0.019807176797517707, 0.04183723770880273, 0.004213886942514884, 0.018169010058045387, 0.05979168481592621, 0.02777882163146777, 0.05695119473551001, 0.0626068791108472, 0.07093344695333924, 0.022765594567837458, 0.03798435302451253, 0.03702420561707445, 0.10260914439069373, 0.02864615053736738, 0.03200695484078356, 0.02956361130678228, 0.013741273898631334, 0.006563418769344155, 0.011879908153787255, 0.0343583975918591, 0.039973536107156954, 0.07025907135435513, 0.03288963729781764, 0.08705992411289896, 0.006451459219014006, 0.03021991073286959, 0.027961096493527293, 0.06366826394306761, 0.02788215912213283, 0.04341159840779645, 0.040724514917071374, 0.018966356558459144, 0.030224667263350317, 0.06860233989677259, 0.066171501763165, 0.03143239174304264, 0.03376399752284799, 0.01416834638387497, 0.06138214375823736, 0.09225478821567126, 0.06037243615303721, 1.7334328932421548, 7.366159660475595, 17.152583599090576, 29.52923951830183, 43.10304226194109, 46.64999341964722, 42.56621749060494, 36.98941612243652, 26.587730067116873, 24.368260043007986, 28.885759898594447, 38.49970783506121, 19.435382979256765, 21.967106785093033, 18.846377236502512, 18.23657727241516, 22.398292882101877, 15.335374321256365, 12.27249721118382, 8.149985074996948, 4.550492942333221, 3.6219730292047774, 1.9511555646147047, 1.1148892726216997, 0.7028051848922456, 0.1585367622652224, 0.18074365279504231, 0.16691080720296927, 0.07933838559048516, 0.0961850191067372, 0.2630401525114264, 0.1423188117997987, 0.2759499326348305, 0.19058136562151567, 0.44266348970787867, 0.2833859164799963, 0.32646786900503294, 0.2538974088217531, 0.53989875210183, 0.41185194732887404, 0.2026533992694957, 0.11801033546882016, 0.298210006739412, 0.07936235823269401, 0.1430637075432709, 0.3296520709991455, 0.02487613363856716, 0.2500174641609192, 0.1924262616251196, 0.12075543031096458, 0.2293927680168833, 0.4080127961933613, 1.1300828116280692, 2.3186787920338765, 3.6437821217945645, 5.160108344895499, 8.259959425245013, 9.835363575390407, 17.139769383839198, 23.37167297090803, 17.811258929116384, 23.95526432991028, 19.9264486517225, 23.19607983316694, 21.082618474960327, 26.520059823989868, 32.590261459350586, 37.021992751530235, 31.49379403250558, 20.948431389672415, 9.559699875967842, 3.8356587971959795, 0.8768258584397179, 0.11433832107910089, 0.03482128739623087, 0.030367149439241205, 0.02809455754634525, 0.04762146036539759, 0.015001498329054033, 0.008226933456691248, 0.05295169559706535, 0.03656740566449506, 0.008900791672723634, 0.044367508364043066, 0.026305800137509192, 0.03331290404977543, 0.00726592685428581, 0.05189538620678442, 0.024787927478817955, 0.052209330789212666, 0.01266736670264176, 0.04574672917702368, 0.034988132371966324, 0.03777886547946504, 0.01603725828629519, 0.017406390979886055, 0.0420354581438005, 0.04765047452279499, 0.03366682113015226, 0.020629715606836335, 0.060262201353907585, 0.04780837640698467, 0.024190496054611037, 0.05687230825424194, 0.030576603021472692, 0.04613175030265536, 0.04146862355992198, 0.025219092378392816, 0.06740088508065258, 0.04302451792838318, 0.012971295260025986, 0.03762157427679215, 0.023050599631720355, 0.014258628012612462, 0.0036020955968914287, 0.023254524849887406, 0.03023267736924546, 0.031614483400647125, 0.035363480980907164, 0.01246143810983215, 0.03367710432835987, 0.15671596782548086, 0.23052885276930674, 0.09101769674037184, 0.14198459259101323, 0.13859216177037784, 0.16174915060400963, 0.11028843053749629, 0.11981306730636529, 0.15863828467471258, 0.15379359892436437, 0.12010274747652666, 0.15412249841860362, 0.1908473784902266, 0.2036141777145011, 0.09554028870271784, 0.13045212998986244, 0.18315547837742738, 0.08871898973094565, 0.1394262441567012, 0.16419748137039797, 0.15772284593965324, 0.12614179056669983, 0.14206556896013872, 0.12188148631581239, 0.18802402141903127, 0.11776311802012579, 0.1536686263446297, 0.15231880306133203, 0.19001548098666327, 0.15603562790368283, 0.15689178981951304, 0.11469086073338985, 0.08808807429990598, 0.10157452097960881, 0.11777313319700104, 0.16116354774151528, 0.15180033445358276, 0.19937127110149178, 0.10765289195946284, 0.15458698278026922, 0.130728863711868, 0.18898345636469976, 0.08013551495969296, 0.1680779552885464, 0.20869777564491543, 0.14194757172039577, 0.16496902996940271, 0.1508116139365094, 0.18865568323859147, 0.10224095771887473, 0.06120298337191343, 0.1133916290210826, 0.13871558729026998, 0.11909242240445954, 0.10968021210283041, 2.0134442108018056, 8.267641527312142, 18.40557483264378, 32.838930538722444, 48.424969809395925, 53.72492715290615, 51.76969712121146, 46.103100708552766, 34.35561111995152, 36.241661412375315, 44.658431257520405, 47.55878305435181, 22.60530056272234, 27.046318122318812, 25.332690852028982, 22.824672562735422, 25.858443668910436, 18.08324442590986, 14.12614631652832, 10.521644966942922, 7.396951471056257, 4.898447002683367, 2.6611268392630985, 1.4832235936607634, 0.885699630847999, 0.3284483498760632, 0.6625053073678697, 0.5600573218294552, 0.7359275732721601, 0.6965621198926653, 1.3227590726954597, 0.9590761363506317, 0.493013393666063, 1.2721211441925593, 1.409619914633887, 1.3474479764699936, 1.9450124885354723, 1.5823530001299722, 2.670014236654554, 2.453040450811386, 1.7903415709733963, 0.6083933338522911, 1.2395674224410738, 1.5879878806216376, 1.721975748028074, 1.4000341147184372, 0.4138357394507953, 0.7245488124234336, 0.6802017720682281, 0.4617668560573033, 0.6107335739902088, 0.9598668196371624, 1.7359575863395418, 3.2085589042731693, 4.771463896547045, 7.121894001960754, 9.961008719035558, 13.118633202144078, 22.881847551890782, 29.043577807290212, 23.45095365388053, 30.6871429170881, 27.11932979311262, 28.304873125893728, 28.887792246682302, 35.0475127356393, 40.765894072396414, 43.66333457401821, 34.61738797596523, 24.4555606842041, 10.573322193963186, 3.856260206018175, 0.9015711077622005, 0.2123438021434205, 0.1558086307985442, 0.14694258011877537, 0.1756108882171767, 0.10556297696062497, 0.11191867877330099, 0.10194418007241828, 0.1682392702038799, 0.14744503530008451, 0.10988396259823016, 0.13192388601601124, 0.10599399597517081, 0.15601380621748312, 0.05185557994991541, 0.12417372688651085, 0.1473573007221733, 0.1359190730644124, 0.09391113290829317, 0.15598335356584617, 0.11927341483533382, 0.14063251657145365, 0.10525316465646029, 0.10735690819897822, 0.16727874960218156, 0.13136332109570503, 0.12165238575211593, 0.1515287168856178, 0.14870436915329524, 0.20770441394831451, 0.09163078705647162, 0.11186949176979916, 0.08280315502945866, 0.11029936173664671, 0.08986817699457918, 0.17615416406520776, 0.3142198233732155, 0.09862768410571984, 0.08509904611855745, 0.11609248338001114, 0.15886843018233776, 0.15315310257886136, 0.08990713168999978, 0.14840239392859594, 0.1411414992596422, 0.1519830503634044, 0.15310294527028287, 0.12334497778543405, 0.12574904092720576], [0.04137766254799707, 0.041769672584320815, 0.06390665365116936, 0.03582480676206095, 0.05311885269890938, 0.0301033350239907, 0.036725830020649095, 0.01298344273319734, 0.039921234627919536, 0.04420763872829931, 0.05105977711666908, 0.050484606730086465, 0.016056094418412874, 0.018350172122674327, 0.0328301162059818, 0.019024892078180398, 0.003306486302920218, 0.03671931947714516, 0.057719167454966476, 0.029499248867588382, 0.02158138811189149, 0.022741996816226413, 0.008161700796335936, 0.05489507417327591, 0.02247875915574176, 0.05604278901591897, 0.08934573217162065, 0.039328408760151694, 0.013079320579501135, 0.044622732525957484, 0.03891869235251631, 0.052449277735182216, 0.04955025043870721, 0.02110675795535956, 0.04339357312502606, 0.011189184949866362, 0.05484368193096348, 0.06606824908937727, 0.00856613480885114, 0.04142424397702728, 0.028590707440993617, 0.012279885039398713, 0.01008894550614059, 0.026610827073454857, 0.02023791761270591, 0.020435942968885814, 0.033566397947392294, 0.056935486649828296, 0.01578196118186627, 0.03658463366861854, 0.062269111163914204, 0.039916651123868566, 0.05222413981599467, 0.04473045335284301, 0.024603812090520347, 0.07739055582455226, 0.5784818274634225, 3.892480731010437, 11.208238158907209, 21.968088218144008, 31.681305067879812, 37.501175267355784, 32.98749344689505, 40.677210739680696, 37.317933900015696, 31.245781557900564, 34.841255460466655, 18.73996557508196, 20.87295831952776, 23.619060107639857, 24.55885260445731, 14.112128325871058, 20.895362785884313, 16.234509434018815, 13.304309044565473, 6.960002277578626, 4.175714492797852, 3.0526660808495114, 3.3555730155536105, 1.4478275158575602, 1.093312184725489, 0.7079460918903351, 0.42951711799417225, 0.18880437740257808, 0.198866427476917, 0.08162966942680733, 0.12188449901129518, 0.053427813441625664, 0.13333443818347795, 0.21168801161859715, 0.17767712234386376, 0.14693405771894114, 0.08639375200229031, 0.33625568236623493, 0.20112182359610284, 0.17089505626686982, 0.1778510037277426, 0.1462082288094929, 0.21565448306500912, 0.2758142799139023, 0.21992971508630685, 0.26662707860980717, 0.36126664600202013, 0.25871435606053894, 0.7246409303375653, 1.0258615698133196, 2.2670028678008487, 2.3899067299706593, 5.172661134174891, 4.713205856936319, 9.47868996007102, 13.629456077303205, 16.587959085191997, 13.427608302661351, 12.742902415139334, 12.505847249712263, 14.948144265583583, 20.72326980318342, 19.212740114756993, 27.063721622739518, 31.413604872567312, 33.22466673169817, 27.237296308789933, 18.422043800354004, 8.773512073925563, 2.711755322558539, 0.3268278454031263, 0.0347561073223395, 0.07505088565605027, 0.05506611928077681, 0.006269792918049331, 0.04747577889689377, 0.021616268204525113, 0.05524320334994367, 0.01953677211089858, 0.03887464864445584, 0.014157143770717084, 0.0028175623821360724, 0.036620056589267085, 0.009336196567996271, 0.039068621450236866, 0.06355237694723265, 0.04549858892070396, 0.033317022757338624, 0.04285546771383711, 0.097003033783819, 0.04827942220228059, 0.03863116992371423, 0.0037787602465998915, 0.017132788696991544, 0.04579755484259554, 0.033348900332514725, 0.02309246693870851, 0.03290431061759591, 0.04455310804769397, 0.047233521539185724, 0.015668527090123723, 0.034527220497173924, 0.057191592907266955, 0.06644291577062436, 0.046630317478307655, 0.027236137805240493, 0.06263465833451067, 0.026156133972108364, 0.0313733218769942, 0.054892729834786484, 0.043128384676362784, 0.026521370712933794, 0.03426886489614844, 0.01546578252288912, 0.06254519349230186, 0.03988947918904679, 0.13692787821803773, 0.016334595724142024, 0.03941740541319762, 0.02865424546013985, 0.03329165233299136, 0.016141608490475585, 0.023989357919033085, 0.013356388480003391, 0.03417096247098275, 0.026625111931934953, 0.04965117234470589, 0.05514419830537268, 0.013938906552669193, 0.0318479435518384, 0.03804318540330444, 0.053313860270593844, 0.03485552627327187, 0.009263822326569684, 0.0659826858235257, 0.03785719556201782, 0.021564850517149483, 0.046864157609109364, 0.024906175776517818, 0.01674805085973016, 0.04939674546143838, 0.004280938924888947, 0.03937301225960255, 0.05460393176014934, 0.04598678129592112, 0.054063967163009305, 0.08488897846213408, 0.04133169519315873, 0.022358017241848365, 0.01994376420043409, 0.06580127270093986, 0.12362251217876162, 0.020484624463798742, 0.08707177811967474, 0.034807835439486165, 0.05761948387537684, 0.04493104526773095, 0.06068283199731793, 0.028026832966133952, 0.027769893806959902, 0.008064967995908643, 0.044424247462302446, 0.03859787421034915, 0.034516726953110526, 0.028869598904358487, 0.013530743990226515, 0.020753010508737395, 0.09212013972657067, 0.0076672752288037115, 0.06646163655178887, 0.022290022943967154, 0.0517350449892027, 0.06642743838684899, 0.018244305392727256, 0.1183697690388986, 0.14980477653443813, 1.1612618757145745, 5.49124515908105, 15.084968192236763, 27.999593598502024, 38.7942350251334, 43.45202248437064, 38.56598670142037, 41.12526879991804, 40.63284649167742, 34.27522393635341, 38.46045398712158, 18.221263442720684, 20.687392779758998, 23.152210644313268, 26.811149392809185, 19.125305720738, 21.64558584349496, 20.358492851257324, 16.735102823802404, 10.39205150944846, 5.7900350689888, 4.549504126821246, 4.349566672529493, 1.4053139856883456, 1.1569418332406451, 0.7517586637820516, 0.3304264694452286, 0.3086183810872691, 0.2546776698103973, 0.01720038096287421, 0.06654147298208304, 0.09157081134617329, 0.12893120731626237, 0.06469619699886867, 0.07777345992092576, 0.050724289047398737, 0.12557369390768663, 0.06105000765195914, 0.1205287046198334, 0.1279015304254634, 0.1763598280293601, 0.1129468832431095, 0.08367986977100372, 0.034331442788243294, 0.07316698067422424, 0.2443890976054328, 0.2918233094470841, 0.4637812908206667, 0.8160872576492173, 1.1167085064308984, 2.328796237707138, 3.382969545466559, 5.521900177001953, 7.277375144617898, 13.006755914006915, 14.197722315788269, 17.944455896105083, 18.419130768094742, 16.044837508882793, 16.527214459010533, 19.336673395974294, 21.068306922912598, 21.213671922683716, 29.39983974184309, 36.0907951763698, 37.67060361589704, 32.05112293788365, 21.679670231682913, 11.355044909885951, 4.240783504077366, 0.509986757167748, 0.052145297439502816, 0.08498521508382899, 0.055229653005621264, 0.04853925361697163, 0.034730536730161736, 0.05801196888621364, 0.05611390627122351, 0.02194192599771278, 0.07188480054693562, 0.02265719011692064, 0.021307049618501748, 0.05231131799519062, 0.02194439247250557, 0.02363940348316516, 0.04005758284724184, 0.04977034345003111, 0.00807408326571541, 0.029905189227844988, 0.07560673475797687, 0.03512835502624512, 0.112485567639981, 0.056078228899942975, 0.03243826562538743, 0.030996134438152825, 0.03564090680863176, 0.01344140213248985, 0.06792340454246316, 0.06634472496807575, 0.04714075562411121, 0.01259330375718751, 0.02026490125406001, 0.03902275248297623, 0.06904739101550408, 0.030688232210065638, 0.04067831007497651, 0.03652698194075908, 0.025665025592648556, 0.01289259537588805, 0.012425299334738935, 0.033357490585850816, 0.006143332226201892, 0.029769947020603076, 0.02400198545573013, 0.06827732162283999, 0.04242909327149391, 0.04558956350332924, 0.05187284866614001, 0.014430570482675518, 0.02165043244271406, 0.0907366271795971, 0.10358721869332449, 0.09644711682839052, 0.13489418663084507, 0.21419850976339408, 0.14684199408761092, 0.11180715475763593, 0.11804446578025818, 0.13171318732202053, 0.21274735406041145, 0.12536243881498063, 0.1237423550337553, 0.14587685944778578, 0.1265119585607733, 0.15996788761445455, 0.11768131383827754, 0.1749257171260459, 0.20185078733733722, 0.16524618438311986, 0.17440655641257763, 0.10736804295863424, 0.0760359556547233, 0.11586948963148253, 0.17012581468692847, 0.13286210995699677, 0.12283737930868353, 0.1465645275477852, 0.12724875259612287, 0.1410949653280633, 0.11548493669501372, 0.20248928878988537, 0.2285150693995612, 0.16156232277197496, 0.15919313633016177, 0.16490850464573928, 0.2099718472787312, 0.11676077251987797, 0.1528152192809752, 0.12734082979815348, 0.09802965726703405, 0.050533206800797155, 0.16800544703645365, 0.12013258944664683, 0.0812131032081587, 0.10825748701712914, 0.12441304618758814, 0.10178211876856429, 0.2761488248194967, 0.1311633703964097, 0.15856872126460075, 0.14872228247778757, 0.15128257152225288, 0.14542950130999088, 0.113257889768907, 0.24332852022988455, 0.15379981430513517, 1.5336557903460093, 5.831215739250183, 15.619524376732961, 30.29141174043928, 42.236970152173726, 49.62939139774868, 46.48933022362845, 51.81754241670881, 48.187143393925254, 41.20877225058419, 45.10034711020333, 29.052462816238403, 31.198071752275737, 36.008733476911274, 35.946449824741904, 22.557132175990514, 31.90834093093872, 26.482131344931467, 20.75995455469404, 12.729545371873037, 8.414476939610072, 6.22366041796548, 5.357514483588083, 2.543838858604431, 1.7053797585623605, 1.0232423160757338, 0.7557195712413106, 0.6063221735613686, 0.36879952464784893, 0.3215931648654597, 0.3573811373540333, 0.8297181576490402, 0.7066649634923253, 0.5999388960855347, 0.8097682510103498, 0.43617598925318035, 0.9302725962230137, 0.5898125480328287, 1.113004248057093, 0.6757448283689362, 0.8645442660365785, 0.5593303665518761, 0.7625719064048359, 0.5078232075486864, 0.5632724378790174, 0.7354410365223885, 0.7886093035340309, 0.8638622026358331, 1.3546919077634811, 1.7839928716421127, 2.93109974690846, 4.133799484797886, 7.282065178666796, 8.582828317369733, 15.370961257389613, 19.340762410845073, 23.579523120607647, 22.029555456978933, 20.48363859312875, 22.44679478236607, 24.39631165776934, 31.36913640158517, 27.79469817025321, 37.25581005641392, 43.44406679698399, 42.75061225891113, 34.97081504549299, 24.002409594399587, 12.486506070409503, 4.269612014293671, 0.5869687263454709, 0.1922136087502752, 0.12872658829603875, 0.11944839544594288, 0.13264607797775949, 0.19898613462490694, 0.14824151327567442, 0.19163856389267103, 0.146691942853587, 0.2778631028320108, 0.0973473699497325, 0.07479984805520092, 0.11550917396587984, 0.09701830760708877, 0.09299438460064785, 0.19773016630538873, 0.10286586132964917, 0.10679597686976194, 0.12886183389595576, 0.1425307589982237, 0.14155659984265054, 0.2012179312961442, 0.18358875012823514, 0.13720214207257542, 0.19404626398214272, 0.09271362038063151, 0.07542096544057131, 0.1391843328518527, 0.1267535305981125, 0.09668742000524487, 0.23903624340891838, 0.06190516533596175, 0.24221347006303923, 0.15668580015855177, 0.07137461006641388, 0.09424263797700405, 0.11713940863098417, 0.08329080457666091, 0.07223286187010151, 0.20535133592784405, 0.13045436915542397, 0.1471688308353935, 0.14719069323369435, 0.10155488417616912, 0.18423364338065895, 0.12507802407656396, 0.2251799205052001, 0.12190857343375683, 0.14297313668898173, 0.12795547395944595], [0.08320801651903562, 0.011099800683691033, 0.01621556541483317, 0.0173085224814713, 0.0431385185968663, 0.019520366830485206, 0.029295535691614662, 0.005891536786553583, 0.06353352045906441, 0.05405982470672045, 0.005701559279779238, 0.014515841978469064, 0.0400169894897512, 0.008361321557978434, 0.004713179302468363, 0.018116343866235445, 0.02885211305692792, 0.03133288797523294, 0.03861981464017715, 0.07968141218381268, 0.0338211267787431, 0.04559115466794797, 0.03713953960686922, 0.05313696279855711, 0.017998580721073916, 0.05783991954688515, 0.07709249574691057, 0.04919238767719694, 0.04951158072799444, 0.030717768839427402, 0.07628125963466507, 0.042620009277015924, 0.028236418862694075, 0.022218997290890132, 0.03123112807848624, 0.007103562330095363, 0.021373471411477243, 0.033924240352852006, 0.016595112459201897, 0.044253572156386714, 0.0117215703108481, 0.047765214794448445, 0.023218674452177117, 0.03514697402715683, 0.05614980077371001, 0.047839073331228325, 0.04647599147366626, 0.026551809793870364, 0.01619881747423538, 0.1039410000666976, 0.058746659463005405, 0.035111791986439905, 0.029062832106969187, 0.006335063745999443, 0.048285841143557, 0.11684795069907393, 0.017250746920970932, 0.4423199067158358, 3.1075748716081892, 10.600100551332746, 18.862439734595164, 26.260522024972097, 36.840106282915386, 44.25231599807739, 35.24535574231829, 38.04369061333792, 30.26250376020159, 23.859361818858556, 27.004540341241018, 20.852857181004115, 19.054883990968975, 25.24728880609785, 22.327216284615652, 22.568327460970195, 15.199240003313337, 12.794795904840742, 10.451111197471619, 7.640841058322361, 7.0526039600372314, 5.838640757969447, 3.9567103130476813, 3.227819962160928, 2.0800040449414934, 1.203541447009359, 0.9277997974838529, 0.7566763056176049, 0.49404205275433405, 0.2994146778115204, 0.46411730136190144, 0.2708307116159371, 0.21552112379244395, 0.030333965684154203, 0.25812139787844246, 0.2847901311303888, 0.27262597956827705, 0.25316231112395016, 0.1645157007234437, 0.2715990575296538, 0.32821110689214295, 0.41118532738515307, 0.7015454439180238, 0.8825695759483746, 1.6584663902010237, 2.1900682875088284, 3.426889325891222, 4.814778098038264, 5.666602058070047, 7.851858718054635, 10.46621310710907, 13.74785772391728, 12.265958087784902, 16.746086188725062, 19.446552208491735, 19.05840846470424, 18.80858598436628, 21.453108583177837, 19.362715244293213, 29.65218094417027, 30.14763961519514, 31.38449192047119, 30.892830439976283, 24.994176353727067, 16.92720835549491, 8.230506011417933, 3.3323482275009155, 0.24797583371400833, 0.04313849824081574, 0.08336049690842628, 0.04095869092270732, 0.027164944214746356, 0.019988657773605416, 0.03210288272904498, 0.027603895303660204, 0.01984823664783367, 0.06390039077294724, 0.014751293629940068, 0.04591312971232193, 0.03966884674238307, 0.05160053220710584, 0.009535527255918299, 0.004283769688169871, 0.01711825786956719, 0.05081142312181847, 0.02336063076342855, 0.038013418072036335, 0.02330546247373734, 0.023303694890013764, 0.05134306887962988, 0.03776734395484839, 0.05142048293990748, 0.05298954428040555, 0.036362864675798585, 0.04516137058713606, 0.04942770362166422, 0.0776785532278674, 0.1056296294555068, 0.018136565906128714, 0.0638632138392755, 0.017665447168318287, 0.02305153601004609, 0.022724831576592157, 0.05559670313128403, 0.06334700475313834, 0.014133574008675558, 0.04331947370831456, 0.07964680689786162, 0.02369919598900846, 0.0753063065931201, 0.009186079176808042, 0.02229355980775186, 0.012835270193006312, 0.08348797328237977, 0.0075475231278687716, 0.06928595714271069, 0.07183161697217397, 0.020255530685452477, 0.1232687375907387, 0.039086036051490476, 0.05196297847266708, 0.036840410836573155, 0.10746353997715882, 0.04545317457190581, 0.027831112932679907, 0.03065633088616388, 0.03488967015541025, 0.025189009528341036, 0.031050919355558496, 0.020599870244041085, 0.07541270766939435, 0.005014591343102178, 0.0072995397827721065, 0.02494895232043096, 0.0369236263712602, 0.0027410454723784433, 0.04039033302771194, 0.05201622650825551, 0.029739063499229293, 0.02550311865551131, 0.03005720142807279, 0.02443039889580437, 0.006647514279133507, 0.05937642138451338, 0.035807755177042315, 0.058749916431094916, 0.047103602439165115, 0.012197026583765234, 0.014137210956375514, 0.060476347005793026, 0.052319015974977186, 0.05247613415122032, 0.02423251942465348, 0.00972804969309696, 0.0990708963945508, 0.019481697119772434, 0.036779953366411586, 0.04901716957933136, 0.02818362714190568, 0.07084447744169406, 0.04663366944129978, 0.022390595404431224, 0.02229653179113354, 0.028614557946899107, 0.020630801262866174, 0.03778730645509703, 0.07097129563667945, 0.0583382628059813, 0.026370220252179673, 0.021930404473096132, 0.02675679013399141, 0.06130952015519142, 0.04208345431834459, 0.05190794928265469, 0.07039971809302058, 0.8960809995021138, 4.686103105545044, 13.75729511465345, 24.107421193804058, 31.101668970925466, 41.252948897225515, 48.88466262817383, 38.96231542314802, 39.432479177202495, 35.030982971191406, 23.71638526235308, 25.71446830885751, 22.9110004561288, 21.616099425724574, 24.446012122290476, 26.828092575073242, 27.01565398488726, 19.47104808262416, 16.625387293951853, 11.856641445841108, 9.54948341846466, 8.394370589937482, 6.909685594694955, 5.5415748698370795, 3.90021060194288, 2.642725620950971, 1.2042448435510908, 0.8339658954313823, 0.6386018757309232, 0.36258362819041523, 0.3130081226783139, 0.43525776852454456, 0.14947916114968912, 0.2528698353895119, 0.09171225875616074, 0.24238321238330432, 0.2530483715236187, 0.25525361033422606, 0.09592459736657993, 0.2053557192640645, 0.3122907483151981, 0.18369779070573194, 0.4213335785482611, 0.5084547336612428, 0.8304372962032045, 1.488201109426362, 2.00294092297554, 3.5002931356430054, 4.851357323782785, 7.2988342217036655, 7.07944745676858, 12.764351504189626, 13.935175946780614, 16.967490536826, 22.551134143556865, 19.01419186592102, 20.352837017604283, 19.160480976104736, 22.754322052001953, 21.780568497521536, 32.60966430391584, 33.180927821568076, 35.8952693939209, 37.739119802202495, 28.890267542430333, 19.876901047570364, 10.70614308970315, 4.4692428793225965, 0.28355707015310017, 0.02998341413746987, 0.03351505320253117, 0.04730406203972442, 0.043876089554812224, 0.016269802415211285, 0.07043310880128827, 0.0449480900673994, 0.06332802612866674, 0.03552128787019423, 0.012117240195428687, 0.062283611457262716, 0.022504881057622175, 0.07158703902470213, 0.08823292795568705, 0.02575897385499307, 0.05102032030533467, 0.02753968214217041, 0.05259865043418748, 0.008461140844571804, 0.06017540993967226, 0.03588358485805137, 0.013351790557083274, 0.01962815211819751, 0.01648254519594567, 0.035866797901690006, 0.06264088728598186, 0.021250598897625293, 0.044127693732402155, 0.035914163038666756, 0.035157287759440284, 0.05716527931924377, 0.01587445229025824, 0.035472436741526635, 0.05114643621657576, 0.016740858388532485, 0.004415064093856407, 0.046529188619128296, 0.0868741547954934, 0.009610651260507959, 0.034149140784783025, 0.06918068243456738, 0.033981871724660904, 0.03088707011193037, 0.0475811418145895, 0.04527713205399258, 0.029611085009362017, 0.020526864965047156, 0.04343879748401897, 0.031555542456252236, 0.048656087169157605, 0.23171723900096758, 0.1200750225356647, 0.101949737274221, 0.08418254208351884, 0.21997092930333956, 0.2216132011796747, 0.16896714828908443, 0.07062759729368345, 0.20307140398238385, 0.22101018710860185, 0.1299279345465558, 0.19384872886751378, 0.08431367576122284, 0.1528810371777841, 0.0427919636214418, 0.1556466780602932, 0.08820169498877865, 0.12064774680350508, 0.10238283260592393, 0.20894863004130976, 0.19339873801384652, 0.2025634798088244, 0.12647077148514135, 0.2975536191037723, 0.11180990960981164, 0.19112112665815012, 0.18079604926918233, 0.13590599090925284, 0.09965744920607124, 0.10257794535053627, 0.22263652698269912, 0.1299763276640858, 0.21384541371038981, 0.152329062510814, 0.07997242228261062, 0.09391839323299271, 0.21752799967569963, 0.14605051012975828, 0.156664195603558, 0.17231217665331705, 0.08294634627444403, 0.16873359653566564, 0.14127218510423387, 0.11019876892013208, 0.13164078763553075, 0.10688617452979088, 0.0880890649610332, 0.11993194664163248, 0.2636712172201702, 0.17834186953093323, 0.07805505195366484, 0.1013757712872965, 0.13056780663984163, 0.22237450389989785, 0.17083651226546082, 0.23445263079234532, 0.15145288381193364, 0.8326963835528919, 4.696858048439026, 14.220081618853978, 25.117376599993023, 35.910729135785786, 46.78438547679356, 56.20279026031494, 47.01639972414289, 48.55013813291277, 43.271324157714844, 33.116313048771445, 39.30395834786551, 31.874826295035227, 29.043944324765885, 35.07834884098598, 33.655538422720774, 33.21889625276838, 25.374477318355016, 24.68315761429923, 19.19631804738726, 14.742611340114049, 11.146650195121765, 9.57069192613874, 5.340041501181466, 4.692845029490335, 3.2665175199508667, 1.7892168313264847, 1.4337071478366852, 1.1371422899620873, 1.171878723161561, 0.9229320415428707, 0.8048072914992059, 0.4284241609275341, 0.8097831787807601, 0.5087242477706501, 0.7293883955904416, 0.8569457052009446, 0.6407696051256997, 0.6863878944090435, 0.8348128157002586, 0.6104656883648464, 0.46034448380981174, 0.9870072432926723, 0.8108603666935648, 1.3549920916557312, 2.2070134239537373, 2.7584328864301955, 4.71074880020959, 6.278920744146619, 8.601170693125043, 11.503170950072152, 15.765763112476893, 19.926502500261577, 20.28760732923235, 26.33620354107448, 29.485559667859757, 28.12170818873814, 27.955974544797623, 30.94052287510463, 28.358355147497996, 39.93173851285662, 41.13161250523159, 42.50413533619472, 42.24361957822527, 33.2899763243539, 21.217144284929546, 11.066242166927882, 4.809051479612078, 0.46834332602364676, 0.11439056827553681, 0.13736450193183763, 0.10783862735011748, 0.1233604619545596, 0.2335286018039499, 0.12407892197370529, 0.19697772525250912, 0.13767081978065626, 0.12248357757925987, 0.10201118540550981, 0.1724566231880869, 0.1386580475206886, 0.10045649204403162, 0.1298682913184166, 0.08980026920991284, 0.08549056760966778, 0.19101994351616927, 0.10456806820418153, 0.1494419774306672, 0.12380997783371381, 0.09436655882745981, 0.18107029955301965, 0.10923122548099075, 0.11360852273979358, 0.20971021774624074, 0.2145800907164812, 0.21951504876571043, 0.12172896521432058, 0.14762306931827748, 0.17600636556744576, 0.09809733434979405, 0.0894058435889227, 0.11247975259487118, 0.13594890146383218, 0.09992496842252356, 0.09614563014890466, 0.17343403931174958, 0.16616002177553518, 0.1807303942207779, 0.11448561746094908, 0.12881835337196076, 0.16811950877308846, 0.12196464756769793, 0.11753081477114133, 0.09626123894538198, 0.20353432771350655, 0.08742477239242621, 0.12167656874018055, 0.1484441916857447, 0.08801791377897773], [0.03159014095685311, 0.026344556361436844, 0.01653297900754426, 0.04921343583347542, 0.013721069670282304, 0.05908236466348171, 0.054588956492287774, 0.02599184537705566, 0.04290699227047818, 0.02680589401695345, 0.021077262038098912, 0.03586157318204641, 0.09743366603340421, 0.021385595135922943, 0.05706353299319744, 0.010512678750923701, 0.040286167724324126, 0.0269879042503557, 0.01887826744600066, 0.01958559440182788, 0.05908296177429812, 0.013672292332297989, 0.0878214846764292, 0.08856479943330799, 0.05335117630394442, 0.032973120853837044, 0.0066237256895484665, 0.020917519627671157, 0.043372762456004105, 0.07007510015474898, 0.0043620090166639, 0.013751462950105113, 0.0183132869590606, 0.04930995065452797, 0.02385348467422383, 0.05768507107027939, 0.0340107908871557, 0.09779768650020872, 0.07711259395416294, 0.00883137499580958, 0.05976853998644011, 0.051975806177194626, 0.024124318534242253, 0.02803269211601998, 0.06472272093274764, 0.02730355365201831, 0.01694464959603335, 0.034704345278441906, 0.0407468455045351, 0.029534125567546914, 0.07611471321433783, 0.04827223990910819, 0.024558911731998836, 0.09449094108172826, 0.07198862319013902, 0.05801320381994758, 0.035596038680523634, 0.08648647381258862, 0.3037758395075798, 2.2177527334008897, 6.607296083654676, 16.10625958442688, 25.563183443886892, 38.89772149494716, 38.81655958720616, 44.20966100692749, 35.48377970286778, 32.9082145009722, 26.52833686556135, 16.324059554508754, 23.82195098059518, 20.890509469168528, 19.658854416438512, 20.57237230028425, 23.92030794279916, 16.036975622177124, 15.031128338405065, 12.788237673895699, 13.598729406084333, 7.834463902882167, 8.163413337298802, 8.086771232741219, 4.842974756445203, 4.457750124590738, 2.792246077741895, 2.570676709924425, 1.7606184801885059, 1.555428079196385, 1.3654621584074838, 1.4805955461093356, 1.7252055747168404, 1.5541361485208784, 1.289343991449901, 1.3527523832661765, 1.1005234377724784, 1.259312248655728, 1.2184400132724216, 1.549596586397716, 1.7073044095720564, 1.945903595004763, 2.517134977238519, 3.0660500483853474, 4.2084470220974515, 6.152813979557582, 8.22359950201852, 10.573184098516192, 12.592974185943604, 16.000692129135132, 12.571822132383074, 21.466207674571447, 20.559478180749075, 10.385750361851283, 13.363834261894226, 17.422449895313807, 17.785913637706212, 25.557994876589092, 28.569146122251237, 29.110374314444407, 30.73206649507795, 26.657260690416607, 18.500878061567033, 14.591583558491298, 6.204769568783896, 2.1437826454639435, 0.2052719880427633, 0.027764233128566827, 0.01436581279683326, 0.03676536486351064, 0.03711412168507065, 0.06684581629399743, 0.037605085875838995, 0.04012181975745729, 0.032233558395611386, 0.061836294031568935, 0.02148820659411805, 0.020496005192399025, 0.009776678601545947, 0.02793692537982549, 0.04862224184242742, 0.044556358230433295, 0.013823313023229795, 0.0539763648994267, 0.014207295142114162, 0.009225312919755067, 0.025499641163540736, 0.03522784861602953, 0.028626432309725454, 0.015004287107980676, 0.024504074228129218, 0.0320262625547392, 0.006105756653206689, 0.055033206939697266, 0.032411202256168635, 0.032506726416093965, 0.05419890402949282, 0.016069637977385094, 0.04981843461947782, 0.020416402856686285, 0.018913208606785963, 0.036248260111148865, 0.04906592232042125, 0.03992444070588265, 0.05823974630662373, 0.012573414199453379, 0.06260454495038305, 0.03708283443536077, 0.030485655580248152, 0.0052219346814256695, 0.057314652018249035, 0.04173495534009167, 0.022891685034015348, 0.08896502652870757, 0.07382311725190707, 0.07813920386667762, 0.016767633380368352, 0.041695067659020424, 0.06221898099673646, 0.03733912389725447, 0.026421120556603585, 0.0816331028140017, 0.0520966600493661, 0.032890682241746357, 0.06405541566865784, 0.02844021685554513, 0.01889679314834731, 0.05403201494898115, 0.012396929785609245, 0.03747784698914204, 0.039928976712482314, 0.05953614852790322, 0.05848667877061026, 0.007376113307795354, 0.030355227578963553, 0.02630249397563083, 0.06086070995245661, 0.049679674208164215, 0.09079550366316523, 0.02296370474089469, 0.06067183294466563, 0.06213058145450694, 0.0661508607278977, 0.027285872725769877, 0.018400597452585186, 0.03955184694911752, 0.03331975046811359, 0.04767474911308714, 0.015759579704276154, 0.013677245637934123, 0.035154427734336684, 0.05210833424436195, 0.0200152224195855, 0.05535264426310148, 0.03272839362866112, 0.06446985807269812, 0.046681930244501145, 0.058621130484555445, 0.0227415778208524, 0.05458639162991728, 0.02658433367365173, 0.02023730014583894, 0.0298854540368276, 0.03125086666217872, 0.021140465878748467, 0.039744856235172064, 0.02472546324133873, 0.029010971675493887, 0.07971598354301282, 0.05041404587349721, 0.0423286904447845, 0.041327780046101124, 0.027840132359415293, 0.055631040395902734, 0.05781925815556731, 0.040625821998608966, 0.5834133114133562, 3.2227482114519392, 9.71357033933912, 19.55931278637477, 32.63788788659232, 45.297974722726, 44.91391999380929, 49.919186864580425, 40.45609821592058, 33.527931281498496, 32.14171355111258, 18.450534888676234, 24.573384761810303, 23.697626863207134, 21.274623257773264, 25.334502594811575, 26.426432847976685, 25.239451238087245, 20.49640417098999, 17.9756498336792, 17.741354840142385, 14.32996129989624, 10.499987431934901, 10.732051185199193, 6.922332618917737, 6.24292082445962, 4.143640739577157, 2.411765979869025, 1.8322901257446833, 1.413856144462313, 1.471509907926832, 1.5934681636946542, 1.3538518271275928, 1.4485163646084922, 1.0803287156990595, 1.2120349683931895, 0.8655975695167268, 0.901267232639449, 1.1385092394692558, 1.5459436795541217, 1.648818816457476, 1.8959875191961015, 2.4998704407896315, 3.4392095676490237, 5.57716006892068, 8.075200745037623, 8.927866305623736, 11.504639625549316, 15.582169124058314, 19.4036158152989, 16.790054389408656, 24.050958395004272, 20.784304516656057, 14.208147219249181, 17.71983105795724, 18.625504425593785, 19.37624338694981, 27.75749577794756, 30.769951547895158, 34.40202508653913, 34.69891813823155, 30.73826081412179, 24.314345496041433, 18.133266244615825, 8.778670242854528, 2.7550032990319386, 0.3935422769614628, 0.07094107368694884, 0.017378272488713264, 0.07009067253342696, 0.06605440018964664, 0.0230174684630973, 0.022306791240615503, 0.024155709260542477, 0.020150452752464583, 0.013332511680865926, 0.06007456606520074, 0.027992502486865436, 0.010631493625364133, 0.014233349190492715, 0.04776685684919357, 0.04350733969892774, 0.03215483815542289, 0.06687777529337577, 0.06052657895322357, 0.05270511257861342, 0.02581407598751996, 0.022354419309911982, 0.01617707551590034, 0.021854780048930218, 0.025430237209158282, 0.037660885203097544, 0.02673786409598376, 0.04281966481357813, 0.06125298461743763, 0.04671167043436851, 0.03482626784326775, 0.03769734288964953, 0.036238251719623804, 0.03025174420326948, 0.04773587494024208, 0.008426763716020753, 0.06097971820937736, 0.03585561903725777, 0.03535448360655989, 0.04969453073239752, 0.05057315215734499, 0.015015574538015893, 0.013959427996139442, 0.0918614278946604, 0.014146995431344424, 0.03556119929999113, 0.03078772919252515, 0.10198670386203698, 0.06243681109377316, 0.05260747817478009, 0.0038786024337501396, 0.0435623824596405, 0.17655945303184645, 0.1170587172465665, 0.14008917286992073, 0.11689658808921065, 0.0969546338809388, 0.13117942453495093, 0.3049156426319054, 0.09045303346855299, 0.17721489071846008, 0.11355863684522254, 0.18456964035119328, 0.17171069607138634, 0.15394120743232115, 0.16495069595319883, 0.21115298675639288, 0.1498699566083295, 0.07512800116091967, 0.11637286762041704, 0.09695949219167233, 0.13876436038741044, 0.19517877964036806, 0.10765816417655774, 0.1348187606781721, 0.25448314739125116, 0.15855877394122736, 0.2846742102078029, 0.06434085499495268, 0.12041867338120937, 0.13492345863154956, 0.14245621514107498, 0.06894228594111544, 0.14201755582221917, 0.12521176332873957, 0.26653639918991495, 0.11955747673554079, 0.1577847690454551, 0.1041277057624289, 0.30195448866912294, 0.13639225624501705, 0.15791256433086737, 0.1603828389197588, 0.16625003623110907, 0.09559955873659678, 0.15731132802154335, 0.12931722588837147, 0.08940350942845855, 0.1288235102381025, 0.12354074870901448, 0.12029785343578883, 0.11621970869600773, 0.18486943069313252, 0.11741310251610619, 0.24531768634915352, 0.2582997983055455, 0.13855064899793693, 0.12945283789719852, 0.1595250620905842, 0.1627537759819201, 0.6000767201185226, 3.725571538720812, 9.733271956443787, 21.759810754231044, 35.349231311253135, 49.77934047154018, 52.34668942860195, 55.275695596422466, 49.64463227135794, 43.218014104025706, 39.322305066244944, 25.577415091650828, 34.29815993990217, 32.06607893535069, 27.661350079945155, 31.28628260748727, 35.83073105130877, 25.847901514598302, 27.741289104734147, 22.928157295499528, 23.785092524119786, 16.44376485688346, 13.58213015965053, 12.743279354912893, 7.890789474759783, 6.664746395179203, 4.6869898693902154, 3.7023089698382785, 2.3515439885003224, 2.0587864177567616, 2.060262692826135, 2.572604400771005, 2.78908616730145, 2.0751344433852603, 2.111099187816892, 1.907060559306826, 1.8184482284954615, 1.9034616095679147, 1.6909539955002921, 2.135641310896192, 2.4540194954190935, 2.714135514838355, 3.5741907017571584, 4.073941188199179, 6.743870309420994, 9.014398302350726, 11.870617747306824, 14.382870963641576, 18.3201675755637, 24.30147569520133, 19.03396643911089, 31.52814940043858, 29.072067158562795, 18.551356724330358, 24.290497541427612, 26.44289139338902, 25.995331866400583, 34.932117053440635, 37.66714341299874, 40.13372611999512, 41.10771417617798, 35.827976090567454, 26.45118580545698, 18.816790069852555, 8.959646497453962, 3.1033434186662947, 0.4260269509894507, 0.2534826067941529, 0.15054291406912462, 0.17678125255874225, 0.17019260967416422, 0.12598070635327271, 0.16208558183695587, 0.10894575222794499, 0.24155325548989431, 0.16050312960786478, 0.1505039254469531, 0.07424617705068418, 0.06487030908465385, 0.1067016130047185, 0.17356661148369312, 0.16747153497167996, 0.07854993468416588, 0.1398069837263652, 0.13649772772831575, 0.09554796293377876, 0.0910180699346321, 0.09735687622534377, 0.06661326198705605, 0.11145683391285793, 0.10479615096535001, 0.16440564234341892, 0.11151516756841115, 0.14071911121053354, 0.12935014840747627, 0.16879402686442646, 0.12079494819045067, 0.14182401049349988, 0.13395187790904725, 0.1205963274197919, 0.18147157159234795, 0.15708517229982785, 0.1806581573826926, 0.0868027186287301, 0.11371781437524728, 0.10246769698070628, 0.09538679051079921, 0.14177588878997735, 0.1940407542777913, 0.14365425014070102, 0.16393738532704966, 0.12231087684631348, 0.1209815317498786, 0.23296650339450153, 0.18784114266080515, 0.20957833768001624, 0.11757110618054867, 0.10652972651379448], [0.058229568281344006, 0.03848618734627962, 0.031069426398192133, 0.02852797009316938, 0.04293497844732233, 0.0025031901106038795, 0.08701381087303162, 0.10448823177388736, 0.04248620895668864, 0.005873158241489104, 0.0328028560616076, 0.06152190840137856, 0.06479351249124322, 0.015329907581742321, 0.05067848114828978, 0.03405631040888173, 0.02663456222840718, 0.07340818630265337, 0.025963287534458295, 0.02444243780337274, 0.0435324115678668, 0.09647841764880077, 0.0944410212604063, 0.03517499752342701, 0.0719952117651701, 0.008249793301469513, 0.03383288239794118, 0.04348459181242755, 0.049722160678356886, 0.03045962019158261, 0.0662439421617559, 0.044951550595994504, 0.024163417418354323, 0.01004614436533302, 0.03336602316371032, 0.01883999807094889, 0.056987197803599496, 0.12823425685720785, 0.009828271859857653, 0.039832356718501875, 0.05060087370553187, 0.09532455527888876, 0.06286997427897793, 0.06697493472269603, 0.015086880086788108, 0.053323556536010334, 0.06253181278173413, 0.05826910651688065, 0.031223382601248365, 0.03219928898449455, 0.02072232885153166, 0.012523071990082306, 0.05478505650535226, 0.028462264154638563, 0.057733063852148395, 0.09021241816559009, 0.046915010416081974, 0.07694490759500436, 0.041155598392443996, 0.17244231966989382, 1.1600978353193827, 5.469764803137098, 11.933158482824053, 20.398366825921194, 32.727797576359336, 41.40671600614275, 44.56163937704903, 43.244406836373464, 34.04303250994001, 31.335670403071813, 30.453287397112163, 24.112102542604717, 20.66538609777178, 15.699079513549805, 17.839157683508738, 14.296392815453665, 17.030064276286534, 23.164500270571025, 21.137660367148264, 15.37340876034328, 15.553655454090663, 15.461272205625262, 11.7410512140819, 6.368409633636475, 7.904222079685756, 8.973691412380763, 7.079440074307578, 6.669033867972238, 7.47581786768777, 5.347721866198948, 6.410184809139796, 6.36082306929997, 6.964830841336932, 4.426071550164904, 4.913673545633044, 5.044798646654401, 3.759997691426958, 4.667253511292594, 5.108541854790278, 5.277545928955078, 7.170838849885123, 9.607197761535645, 9.61081256185259, 16.253861904144287, 19.432782615934098, 19.462873526981898, 11.682906082698278, 14.998756681169782, 20.077738727842057, 18.63024483408247, 24.032031502042496, 19.931845664978027, 16.836338077272686, 20.58935022354126, 24.882411105292185, 29.5963591166905, 35.98408474240984, 24.2270987033844, 26.88613087790353, 16.65614696911403, 8.280896084649221, 4.196080965655191, 0.7312340108411652, 0.15251834663961614, 0.048486276995390654, 0.036603558010288646, 0.0561840464361012, 0.03408346198765295, 0.08725734387657472, 0.03864240985629814, 0.05396284169650503, 0.03187097981572151, 0.028250892014641846, 0.011645361498397375, 0.08224556209253413, 0.06495778581925801, 0.014616324533043163, 0.04013625219730394, 0.02147423046907144, 0.0020920538684419754, 0.061579380317458084, 0.0274511299295617, 0.05684713460505009, 0.06284121796488762, 0.008055780631756144, 0.01936919940635562, 0.043356789741665125, 0.009274529609163957, 0.016364702322919453, 0.0275091395846435, 0.030129872528570037, 0.009704849732640599, 0.056431898315038, 0.06631847244820424, 0.03910966603351491, 0.01642576029657253, 0.05271061549761465, 0.045443339206810505, 0.0872063994673746, 0.025217206051040972, 0.09288329484739474, 0.0756076236388513, 0.016793802779700075, 0.05197482230141759, 0.04288089242098587, 0.036438090460641046, 0.00591185042867437, 0.014234312710219195, 0.014304887137508817, 0.007174805538462741, 0.052863855846226215, 0.041362541395106485, 0.05197417430047478, 0.011186239259716655, 0.09317314465131078, 0.021707578661984632, 0.06797354828034129, 0.029480361845344305, 0.00048299495600596335, 0.02089931453312082, 0.08153998066804238, 0.01755920554777341, 0.022829214011185935, 0.04193617489987186, 0.030523209100855247, 0.010173716582357883, 0.004203230974131397, 0.0931341288877385, 0.037883081672979255, 0.013063425048520523, 0.054067573576633415, 0.0745104867964983, 0.04987747395145042, 0.06214289686509541, 0.03763579297810793, 0.007163194956124893, 0.12231315672397614, 0.05271197935300214, 0.04773000221965568, 0.020190560957416892, 0.014636231054152762, 0.05993583279528788, 0.024002721666225364, 0.02219038177281618, 0.007805490267596075, 0.05408885922016842, 0.03493206502337541, 0.052366981615445445, 0.030590628340308155, 0.01548630990354078, 0.039491857668118815, 0.007286784172590289, 0.05449462655399527, 0.053693517576903105, 0.03901630640029907, 0.04283180719773684, 0.07494977715292148, 0.035838265504155836, 0.03029708730589066, 0.014566862722858787, 0.04101079223411424, 0.009619702069487954, 0.046943671735269685, 0.0302446060148733, 0.07374627316104514, 0.06943733830537115, 0.06742584159863846, 0.05599784624895879, 0.04639490653893777, 0.06774849178535597, 0.0831638981721231, 0.023107869683631828, 0.06719359263245549, 0.05850286861615522, 0.04827001092157193, 0.3798026756516525, 1.7593476112399782, 7.68460168157305, 15.512560333524432, 26.63256331852504, 38.01301779065813, 45.39631952558245, 48.445043155125205, 47.07675525120327, 37.060332911355154, 32.028551714760916, 32.399641105106895, 26.340560061591013, 22.497902257101877, 19.15533757209778, 23.733319759368896, 15.52268385887146, 22.50336354119437, 26.430912699018204, 27.282056604112896, 18.064093453543528, 21.95787957736424, 20.052162408828735, 15.877752440316335, 11.343537824494497, 10.851228424480983, 11.529422112873622, 10.54466608592442, 8.32793538911002, 8.357032707759313, 7.203805446624756, 6.761048861912318, 6.433567668710436, 7.185235517365592, 5.9365339279174805, 5.410872306142535, 5.458509155682155, 5.423703457627978, 5.447074157851083, 5.783708734171731, 6.894231498241425, 7.881783740861075, 10.250702568462916, 9.85835429600307, 17.141054800578527, 21.068079369408743, 23.92103750365121, 16.453690358570643, 20.520747184753418, 21.935610600880214, 25.685393571853638, 28.643580436706543, 18.281910794121877, 18.024189949035645, 22.13543210710798, 26.33306121826172, 33.15385069165911, 38.742547375815256, 29.736976759774343, 31.270843710218156, 20.91012944493975, 11.718061361994062, 6.210269936493464, 1.5028032915932792, 0.3419963871794087, 0.0514545114710927, 0.054499925912490914, 0.04749154465805207, 0.00806410116742232, 0.05443274076761944, 0.07180065541927304, 0.0866059638293726, 0.04417833619351898, 0.06093076190778187, 0.020201744910861765, 0.02853738815922822, 0.09396552427538804, 0.008014637660900397, 0.019980895332992077, 0.037816235795617104, 0.03570576457838927, 0.04658924914630396, 0.040239918777453046, 0.058008216587560515, 0.014418709690549543, 0.008098734442942908, 0.06635354592331819, 0.017246543396530405, 0.043407154003424306, 0.046297414627458365, 0.09787379098790032, 0.029291549298380102, 0.03527087791423712, 0.08550332406801836, 0.02981114766693541, 0.032967865600117614, 0.08003504427948169, 0.05898605340293475, 0.031942972381200106, 0.057139562842036994, 0.018990507316110388, 0.08318189292081765, 0.05462707658963544, 0.047491561621427536, 0.014351376964311515, 0.0030935567130135106, 0.028527220311973776, 0.019345803518912623, 0.04114999708586505, 0.018047509881268655, 0.021628193457477858, 0.028733661198722463, 0.033609912398138216, 0.04443997929670981, 0.02846980607137084, 0.05227556937773313, 0.09734321731541838, 0.12161725120885031, 0.09619098342955112, 0.08840766429368939, 0.19484793953597546, 0.1460348359708275, 0.16808129368083818, 0.13773343499217713, 0.1990379747003317, 0.09261462890676089, 0.08010901816721473, 0.12001039886048862, 0.20780767340745243, 0.13489880066897186, 0.08910688105970621, 0.18119861052504607, 0.13275712701891149, 0.1030126420248832, 0.1679051595606974, 0.13043113611638546, 0.15833386672394617, 0.275435603090695, 0.11912321432360581, 0.1746086377118315, 0.09622495767793485, 0.09695297147014312, 0.17047759438199656, 0.09011734183877707, 0.13541775782193455, 0.08383414149284363, 0.0732736870912569, 0.11018529321466174, 0.1119159646332264, 0.09883922418313366, 0.18308461218007974, 0.13010927981563977, 0.06421251009617533, 0.15092362649738789, 0.19535568729043007, 0.12887769804469176, 0.10638892371207476, 0.12909062233354363, 0.16531532710152014, 0.11570556914167744, 0.11598720188651766, 0.17949662756706986, 0.20960087861333573, 0.20100750401616096, 0.11036921691681657, 0.15636835433542728, 0.2090462033769914, 0.19221499296171324, 0.16340527816542558, 0.12862718291580677, 0.14680050845657075, 0.16836276357727392, 0.17727058487279074, 0.15942539886704513, 0.29405452257820536, 0.11162590448345457, 0.4125562938196318, 1.7665640754359109, 7.706630076680865, 16.976354701178415, 28.370359897613525, 41.76086916242327, 51.60436126164028, 55.73081997462681, 54.65785482951573, 45.67456013815743, 42.16923911230904, 43.261676583971294, 34.20981706891741, 31.474630900791713, 25.568333796092443, 29.37693500518799, 22.972349575587682, 29.807876178196498, 33.91328879765102, 32.161310945238384, 24.61876344680786, 24.148926258087158, 23.68044396809169, 19.494022301265172, 12.950631839888436, 13.431927476610456, 13.74101287978036, 10.473193441118513, 9.949405227388654, 10.29908287525177, 7.870108161653791, 8.861636076654706, 9.076401421001979, 8.7468900510243, 5.997857425894056, 6.950381193842206, 6.896460132939475, 5.739882971559252, 6.713245255606515, 7.196607547146933, 8.666772978646414, 10.624364529337202, 12.144312500953674, 13.129342113222394, 21.915340968540736, 25.603430884225027, 26.730986288615636, 20.001504829951696, 25.414292233330862, 30.057267870221818, 28.472960472106934, 36.32476881572178, 28.82673842566354, 25.476124252591813, 30.564132009233745, 32.03253303255354, 39.777537141527446, 46.993567943573, 35.068454606192454, 34.500925745282856, 23.745510373796733, 13.694300140653338, 5.991408629076822, 1.6321898230484553, 0.46748831761734827, 0.20586569261338028, 0.1757402712745326, 0.16716348007321358, 0.14896954063858303, 0.1763178538531065, 0.15829215039099964, 0.21603865602186748, 0.08547043547566448, 0.18799301236867905, 0.13485795286084923, 0.2423839180597237, 0.13951737140970571, 0.1391476783901453, 0.1512854349400316, 0.10266937794429914, 0.1640626293207918, 0.12431061454117298, 0.13484976972852433, 0.17884782595293863, 0.12968923949769565, 0.19637395122221538, 0.21632558133985313, 0.11968577413686685, 0.2419016696512699, 0.0984073637851647, 0.11384893448225089, 0.11615619781826224, 0.17952182835766248, 0.20200189708599023, 0.19402761783983025, 0.1368297484836408, 0.15736216386514051, 0.18745002150535583, 0.11461557048772063, 0.17046173023326056, 0.15747850547943795, 0.22289047549877847, 0.1782455989824874, 0.16949545565460408, 0.17886287585965224, 0.18471971872661794, 0.15764773211308888, 0.1067176807139601, 0.15087603405117989, 0.14807538076170854, 0.141643615173442, 0.3028938796903406, 0.10879649487989289, 0.13605530932545662, 0.06345389437462602, 0.23715173453092575, 0.2153754694653409], [0.035173307971230576, 0.03896273606057678, 0.0324392359304641, 0.02698092382135136, 0.011424748559615441, 0.036905119328626564, 0.021997896655063544, 0.02169324121704059, 0.04945808841979929, 0.02941499517432281, 0.037736412936023304, 0.03247250450242843, 0.048939752126378674, 0.046741855064673085, 0.03296640674982752, 0.023246311183486666, 0.009008477724689459, 0.04380444982754333, 0.02776219243449824, 0.03788753964805177, 0.003382911186365943, 0.023936187914971794, 0.04948035793911133, 0.040685773960181644, 0.010711302914257561, 0.035369547083973885, 0.033181169868579934, 0.08613607154360839, 0.017311577585392764, 0.03870544915220567, 0.013577976812874632, 0.04677342051374061, 0.07020428643694945, 0.07648197707853147, 0.0989440307021141, 0.07016495854726859, 0.051933733613363335, 0.030839246963816028, 0.029127214902213643, 0.040358428311135085, 0.058160663050200255, 0.02944174302475793, 0.03053919199321951, 0.013006160933790463, 0.035981992791805945, 0.02838710113428533, 0.024161415740049312, 0.0431206934819264, 0.07290205346154315, 0.06027963291853666, 0.03114257925855262, 0.03467995533719659, 0.009704104192288858, 0.04189742715763194, 0.009855968811150109, 0.02387911294187818, 0.035563224727021794, 0.07885662572724478, 0.04992245064516153, 0.09840848336794547, 0.08144881270293679, 0.5569059337888445, 3.2351763674191067, 10.804020626204354, 17.407195125307354, 27.197050605501445, 34.565238271440776, 41.25015572139195, 43.014181750161306, 41.04022979736328, 41.32962226867676, 31.08444091251918, 25.896696976252965, 16.46656710760934, 20.71831226348877, 26.720791544233048, 24.86348421233041, 21.07128596305847, 20.68957277706691, 25.304307460784912, 15.405043908527919, 13.593543444361005, 17.42050266265869, 18.687023775918142, 8.908347947256905, 10.587190798350743, 12.827922310147967, 16.130448000771658, 14.745414938245501, 15.579184872763497, 13.752202953611102, 18.531658581324987, 21.03354161126273, 19.642058883394512, 9.427995034626552, 8.077706439154488, 10.587705833571297, 10.51319682598114, 12.380454846790858, 15.201789992196218, 12.101720912115914, 17.984166588102067, 15.84759031023298, 23.478817667279923, 29.620472839900426, 20.43520096370152, 19.233718463352748, 20.63549494743347, 26.270847048078263, 11.791161622319903, 13.370073744228907, 23.718593052455358, 29.554197447640554, 29.712004934038433, 29.050671918051584, 30.437261377062114, 26.188990320478165, 21.94370698928833, 13.78529896054949, 5.8032457658222745, 2.511161914893559, 0.4675594280873026, 0.07704143598675728, 0.014431154022791555, 0.06814841353999716, 0.032747158514601846, 0.04829249078673976, 0.05329465094421591, 0.00495043712934213, 0.04086129739880562, 0.04601547993453486, 0.012306358083151281, 0.030460095166095665, 0.030373911040702035, 0.032123554298388104, 0.02229301697973694, 0.037853636645845005, 0.10922699142247438, 0.05809931669916425, 0.051573027790124924, 0.05761261031563793, 0.057639018898563724, 0.02332606110056596, 0.01825557416304946, 0.05601377485852156, 0.011934850830584764, 0.025600178000916327, 0.038985181998993666, 0.07599021560911622, 0.029752186366489956, 0.006572285101615957, 0.03436640430507915, 0.044782005050884824, 0.05363261566630431, 0.024956178718379567, 0.05229027323158724, 0.037837996413665156, 0.03567120339721441, 0.020166829195139662, 0.022675529222137163, 0.03331999134804521, 0.03696058278105088, 0.05492898056815777, 0.02442386290723724, 0.019385855744725893, 0.047426924375551086, 0.03503517520480922, 0.07840706913598947, 0.013757547712884843, 0.041122601234487126, 0.036953101932470284, 0.03096930855619056, 0.10140536219945975, 0.018198960593768528, 0.04156395773004208, 0.02075451685647879, 0.03912644959720118, 0.021491207415238023, 0.029606104562325136, 0.053698477667889426, 0.04595390288159251, 0.007321482757106423, 0.046540689787694385, 0.034740480660860024, 0.01681433355302683, 0.03306278247120125, 0.05253023714093225, 0.02212817537864404, 0.05701253430119582, 0.036547656902777295, 0.021810695628768632, 0.05214479532358902, 0.01234431957293834, 0.009735363452429218, 0.008732652391440101, 0.06902688568724052, 0.017778038180300167, 0.03681402600237301, 0.010191609550799643, 0.05948425416967698, 0.0212597574240395, 0.05080550968913095, 0.05469741692234363, 0.029190155810543468, 0.0052220008385899875, 0.08869804335491997, 0.03096446381615741, 0.023477211561320082, 0.07147931480514151, 0.02262034566540803, 0.020792487676122358, 0.0526031592993864, 0.03929286709587489, 0.04032998751582844, 0.03231675696692296, 0.05126782952408705, 0.035516382062009404, 0.025649904439757978, 0.02255374236431505, 0.01057132113991039, 0.036696941392230134, 0.05064025927068932, 0.03346084164721625, 0.04266405977042658, 0.1431754758315427, 0.05979229549744299, 0.029648913336651664, 0.04781143659991877, 0.02195897588639387, 0.005461077563398118, 0.025707764817135673, 0.08864555188587733, 0.02564213182111936, 0.0482136484102479, 0.03845359391665884, 0.05840284576905625, 0.0925220020913652, 0.8897834345698357, 4.908610045909882, 13.405605094773428, 22.614190782819474, 33.34337670462472, 40.53237901415144, 46.62115839549473, 48.15334735597883, 45.20964922223772, 44.91259983607701, 35.52735185623169, 30.756784711565288, 20.578172309058054, 22.272789308003016, 22.913896117891582, 28.04953030177525, 24.060548646109446, 26.084908042635234, 30.711826392582484, 20.615883656910487, 24.145023107528687, 22.51236493246896, 24.910466194152832, 15.620160136904035, 16.167443684169225, 15.888836554118566, 20.108225686209543, 17.883360385894775, 16.781963212149485, 16.71384481021336, 21.743869849613734, 22.315286227634974, 18.716819388525828, 12.617043614387512, 12.85842490196228, 13.167472090039935, 12.649297152246747, 14.117286494800023, 17.427414383207047, 17.227450438908168, 22.21224617958069, 20.67360234260559, 27.046861818858556, 36.030967712402344, 27.75253302710397, 20.633035285132273, 25.375278098242624, 25.923715046473912, 13.987874558993749, 15.101437159946986, 26.539784022739955, 32.43157849993025, 32.81647743497576, 33.03137132099697, 35.40351063864571, 31.653797149658203, 25.049049752099172, 18.09647379602705, 8.233393856457301, 3.360025073800768, 0.8396599984594754, 0.14770255291036197, 0.027679916670812026, 0.04256048479250499, 0.02628923370502889, 0.02238599832967988, 0.039454463603241105, 0.03393118515876787, 0.018645334855786393, 0.07024697307497263, 0.07215293044490473, 0.008096395193466117, 0.021732988102095466, 0.01927800090717418, 0.04830718446256859, 0.03526597549872739, 0.031263229570218494, 0.044885559672755856, 0.013879834142114435, 0.056348160308386595, 0.006006313105379897, 0.04751857410051993, 0.04536077167306628, 0.057294370606541634, 0.015269266907125711, 0.016847164469904134, 0.001393400498532823, 0.026227144358147467, 0.08579320779868535, 0.03290282801858016, 0.042692517529108694, 0.024204095592722297, 0.10805056097784213, 0.020363139554059932, 0.005434510372911713, 0.033848583698272705, 0.009926424494811466, 0.012252741094146456, 0.05090680818206497, 0.08925799080835921, 0.057036581582256725, 0.08251720001654965, 0.032288146537861655, 0.005384351367995675, 0.021705960355965153, 0.043857029506138394, 0.05832685663231781, 0.0350577772062804, 0.027955788653343916, 0.009870850780446614, 0.011579980408506734, 0.046195515631032844, 0.015444598659606916, 0.049201503795172484, 0.03251848542796714, 0.14465514357600892, 0.09504262397864036, 0.14095005738948072, 0.10952617786824703, 0.1422301544142621, 0.12551846115716866, 0.09845995703446013, 0.1157872783286231, 0.12250149090375219, 0.17055345459708146, 0.1165156721004418, 0.179718657795872, 0.15904313937893935, 0.15967651110674652, 0.12461169409964766, 0.0928866264543363, 0.18883753062358924, 0.1613192172454936, 0.10664291972560541, 0.16512091324797698, 0.06642568098115069, 0.22987789341381618, 0.13548314145633153, 0.14879892979349407, 0.18060687370598316, 0.10812619727637086, 0.13757525490862982, 0.15570670126804284, 0.1439439845936639, 0.179410507902503, 0.17678361386060715, 0.2651801433946405, 0.18972023682934896, 0.1608555064137493, 0.1725190891219037, 0.1639645267277956, 0.1335067046540124, 0.09946974606386252, 0.13041639833578042, 0.08810469162251268, 0.12048996027026858, 0.13319339789450169, 0.09676123104457345, 0.14829053064542158, 0.12509797300611222, 0.13882278225251607, 0.13071964920631476, 0.09133080672472715, 0.2752518286662442, 0.17511411915932382, 0.12516061535903386, 0.24256592829312595, 0.11966784724167415, 0.09824155696800776, 0.07270956664745297, 0.14381209095673902, 0.14982920379510947, 0.22312443437320845, 0.14661225570099695, 0.20042674589369977, 0.23602596351078578, 0.8000156400459153, 5.048261020864759, 14.106584531920296, 26.06612011364528, 36.2565027645656, 46.79769822529384, 54.141402176448274, 56.04617786407471, 54.12107522147042, 53.744302204677034, 43.31707457133702, 39.456050940922324, 27.246448823383876, 33.281822613307405, 38.15179763521467, 37.09674494607108, 31.826921939849854, 32.71400540215628, 37.4404410634722, 26.327797957829066, 25.016464437757218, 28.610583441598074, 28.909243072782242, 17.553525924682617, 20.51828752245222, 19.993359804153442, 22.901281663349696, 20.93636757986886, 22.64198705128261, 19.901270117078507, 25.522663286754064, 27.32176729610988, 25.23651909828186, 13.146613597869873, 13.409248556409564, 15.587899650846209, 15.386238609041486, 17.355491842542374, 20.685304846082413, 18.081281559807913, 25.820112194333756, 23.101334197180613, 33.446578298296245, 40.16483320508684, 31.25512341090611, 29.028536694390432, 31.16934095110212, 36.87869657788958, 18.73619965144566, 22.161605971200125, 36.03646373748779, 38.73321941920689, 39.580712045942036, 39.179846150534495, 40.894678933279856, 35.899820463997976, 28.633762632097515, 20.370513234819683, 9.399596878460475, 3.693782661642347, 0.9559595435857773, 0.19596419749515398, 0.12908007789935383, 0.1904786897024938, 0.20749816644404614, 0.09255590170089688, 0.11257921904325485, 0.11415614799729415, 0.10992460006049701, 0.17144741091345037, 0.1707876713148185, 0.10372834719185318, 0.11357499632452216, 0.2754171740795885, 0.12326934827225548, 0.08051081946385757, 0.18311131931841373, 0.1908516396901437, 0.12162289662020546, 0.14275478411998066, 0.0888821774029306, 0.11717739302132811, 0.20627214866025106, 0.21486807454909596, 0.0984651410420026, 0.11856248655489512, 0.13382545326437267, 0.16375541580574854, 0.20310458434479578, 0.14552114424960955, 0.12685508014900343, 0.07978725686137166, 0.18725171286080564, 0.07497046568564006, 0.08781563570456845, 0.10484385876251118, 0.11363093475145952, 0.08659767891679492, 0.21724905392953328, 0.14929431463990891, 0.16140886529215745, 0.15254902999315942, 0.09443653614393302, 0.08950695887740169, 0.07388386649212667, 0.12541034338729723, 0.14024216894592556, 0.09983407865677561, 0.09317323286086321, 0.19029064050742558, 0.19075402564236096, 0.16597775369882584, 0.07350907088922602, 0.19219469119395527, 0.05806755447494132], [0.020652404121522392, 0.02688024958063449, 0.040209571298743994, 0.024687865615955422, 0.032921470768217526, 0.012564848543011715, 0.023960065562278032, 0.020885586073356013, 0.02450494614562818, 0.046907007095537016, 0.038841804156878164, 0.03630820528737136, 0.05398197638403092, 0.08454794676176139, 0.03504423364730818, 0.02112208097241819, 0.03680152399465442, 0.005469406156667641, 0.06415460391768388, 0.021331481968185732, 0.02470142613830311, 0.01144621825577425, 0.02971965739769595, 0.0186354893126658, 0.02870879628296409, 0.04857140939150538, 0.032258158682712486, 0.04423036625874894, 0.05589836283719965, 0.059259570868951936, 0.022340868965589573, 0.041366171557456255, 0.060225628316402435, 0.020606200975765075, 0.06019253616354295, 0.08882998448929616, 0.10646660240100962, 0.029158227345240966, 0.019536078308842013, 0.03207593471077936, 0.07005061182592597, 0.06319012067147664, 0.022587088967806528, 0.034358702932617495, 0.012416422400357468, 0.07353591373456375, 0.09569029922464065, 0.06461243185081653, 0.05582337114693863, 0.07438765160207238, 0.05707327675606523, 0.024838753144389818, 0.029844429809600115, 0.01438164641149342, 0.03788949382890548, 0.01745178157995854, 0.009202092603248144, 0.024349688851673688, 0.051913472557706494, 0.02109556382388941, 0.04292903108788388, 0.0662513721202101, 0.1814730100865875, 1.5345483081681388, 5.259034625121525, 9.881279008729116, 22.625375645501272, 31.767018045697892, 32.90575136457171, 36.37027256829398, 41.69248846599034, 36.20622212546212, 34.94252545492989, 26.146079983030045, 28.278336218425206, 23.939610038484844, 22.860747609819683, 17.424940824508667, 15.80916850907462, 16.882970912115915, 25.690220832824707, 16.57085609436035, 26.803270135607036, 17.911814996174403, 18.4372273513249, 14.622518675667898, 22.36446384021214, 19.032180752073014, 23.148354394095286, 23.38425268445696, 16.972488028662546, 10.186004417283193, 26.130326679774694, 49.99576643535069, 40.226807662418906, 16.343405076435634, 16.450247526168823, 16.84323763847351, 16.93360243524824, 21.386028936931066, 20.582369021006993, 19.20175674983433, 19.392919063568115, 38.63242537634713, 36.81262615748814, 28.422514813286917, 19.205314227512904, 19.592068331582205, 24.55385684967041, 24.87186895098005, 24.043214627674647, 29.69645139149257, 31.69615684236799, 33.82705123083932, 31.543727261679514, 24.231826952525548, 17.67489879471915, 10.02878144809178, 4.615756503173283, 1.078502099428858, 0.2570310192448752, 0.05992333418024438, 0.030076010418789725, 0.029830336637262787, 0.04021944398326533, 0.021320323459804058, 0.04189457731055362, 0.025266369305817143, 0.059077709913253784, 0.06742389420313494, 0.06120370940438338, 0.07910726977778332, 0.052432473815445385, 0.07593209229941879, 0.08529569913766213, 0.054579304331647496, 0.023342581731932502, 0.0446223695097225, 0.05968152465564864, 0.01371109944635204, 0.11069576867989131, 0.05782889335283211, 0.04154270601325801, 0.026453291598175253, 0.017858700726979544, 0.059200341547174115, 0.007231895778594273, 0.035044369354311905, 0.04478130955249071, 0.027279457177168558, 0.06520690316600458, 0.061144541150757244, 0.018515442897166525, 0.013654658903500863, 0.08292468065129859, 0.026917238220838562, 0.020186070751930987, 0.0603478392586112, 0.015671948602955257, 0.04422462245981608, 0.037511081634355445, 0.033719872390585284, 0.040352314710617065, 0.0716097495917763, 0.03418040428576725, 0.03666254984480994, 0.023083958109574657, 0.030800807955009595, 0.012995652122689145, 0.02215857714015458, 0.03273367263110621, 0.047851493914744685, 0.04404457997796791, 0.030340245525751795, 0.046407846201743395, 0.03188428249476211, 0.021522974728473594, 0.008559044117906263, 0.02022303225073431, 0.02363390565317656, 0.020601510602448667, 0.0650475560022252, 0.0651710018781679, 0.039059206776853116, 0.038778965028801134, 0.019569601331438338, 0.018020685695643936, 0.03383469747911606, 0.03551884853680219, 0.031718295865825245, 0.06102169917098113, 0.05799168747450624, 0.06069742728556905, 0.018011518687541996, 0.04211240401491523, 0.024873341466965418, 0.05595641150804503, 0.02713113960011729, 0.019723890016653707, 0.004658522034463073, 0.00830448916115399, 0.06437984361712422, 0.04918842842536313, 0.10599065079752888, 0.02177881126824234, 0.0754637877855982, 0.046828955212341886, 0.061250989724482806, 0.047636825790894885, 0.008021398414192455, 0.03633661215592708, 0.04377364773037178, 0.061603251179414134, 0.015476270977939879, 0.009440555253864398, 0.0546151954414589, 0.0565981224312314, 0.02758780723836805, 0.02476217707486025, 0.04798100250107901, 0.023251837851213555, 0.05050694410290037, 0.05379532157842602, 0.1532674900123051, 0.03777174425444432, 0.022133013333327005, 0.02910045687375324, 0.015718402806669474, 0.035323715436139276, 0.030979696927326064, 0.026400430327547447, 0.008628706763764578, 0.03222073408375893, 0.03924363598759685, 0.05193099911723818, 0.055486135849995274, 0.042296890901135545, 0.03551523533782788, 0.39850467496684616, 2.4546163891042982, 6.961235582828522, 13.487761463437762, 27.592483009610856, 38.409099851335796, 37.88252714702061, 43.55357388087681, 46.43653086253575, 41.596172537122456, 40.176325525556294, 30.976858479636057, 32.90191943304879, 28.411977870123728, 27.534079926354543, 19.767857755933488, 21.066955498286656, 20.502605438232422, 23.620025907244, 16.707332611083984, 30.417955807277135, 22.02691340446472, 19.88213130405971, 24.176503658294678, 27.70788390295846, 27.45801452228001, 30.442858151027135, 33.90471472058977, 27.510000944137573, 18.253011499132427, 37.14663648605347, 54.800782748631065, 37.92941359111241, 18.389413322721207, 20.950399466923304, 22.701187440327235, 22.55043237549918, 28.82399215017046, 22.39922741481236, 24.098369428089686, 23.300464357648575, 40.9205436025347, 40.41490929467337, 27.79895567893982, 21.528308936527797, 21.746782881872996, 26.803862469536917, 20.708946091788157, 24.34283137321472, 32.0769077028547, 35.42930930001395, 36.892592975071494, 34.62982872554234, 28.18769349370684, 21.29726917403085, 13.415501935141426, 6.060361249106271, 1.720166067991938, 0.7060545533895493, 0.03434706944972277, 0.03185871868793454, 0.01601127378775605, 0.11272838139640433, 0.01850533951073885, 0.08324589234377656, 0.01769673781070326, 0.06422185352338211, 0.037007774891597886, 0.01776897125611348, 0.06343326691005911, 0.054206741108958206, 0.04851430049166083, 0.0792209447494575, 0.04968497356665986, 0.03880813524925283, 0.029279349238744805, 0.023965649905481508, 0.03526619941528354, 0.058573972300759385, 0.01780021609738469, 0.022805777411641817, 0.021277828507923653, 0.009743464312383106, 0.08290777155863387, 0.025571107864379883, 0.04667623394301959, 0.06631870993546077, 0.02977131087599056, 0.042780391206698756, 0.040525765224759064, 0.025895008251869252, 0.007996488545489098, 0.06109569341476474, 0.043857667329055924, 0.05928291925894363, 0.025056389858946204, 0.04108788399025798, 0.03845999589455979, 0.04436007501291377, 0.03268510987982154, 0.005945924760973347, 0.08295427156346184, 0.02636424744767802, 0.05277996856187071, 0.04235642556367176, 0.03970460553786584, 0.08746260750506606, 0.02357970257954938, 0.01502186625397631, 0.06129348637270076, 0.09406757594219275, 0.009982240785445486, 0.027796770579048564, 0.016332948580384254, 0.12772340141236782, 0.12595873538936886, 0.1770934872329235, 0.12854180963976042, 0.09588326101324388, 0.1325963277901922, 0.14957430533000401, 0.10949028336576053, 0.05386308008538825, 0.08903627270566565, 0.11270727217197418, 0.1739044404987778, 0.14651685367737496, 0.16177591202514513, 0.14164646502052033, 0.20990630079592976, 0.14250673885856355, 0.07996739433812243, 0.13158014017556394, 0.07280119601637125, 0.09757124579378537, 0.12134385587913649, 0.1373826866703374, 0.13999582002205507, 0.12722493601696833, 0.2014194019138813, 0.11053123072321926, 0.16760767623782158, 0.1572547382009881, 0.17708814037697657, 0.17106158233114652, 0.19450257878218377, 0.13757324644497462, 0.1321917444999729, 0.08446044967110668, 0.195742682952966, 0.16582177206873894, 0.18692696600088052, 0.08572521858981677, 0.13437170109578542, 0.19823273005230085, 0.18012112405683312, 0.12223631941846438, 0.13002450365040982, 0.09298753818230969, 0.14788368104823998, 0.24637584814003535, 0.2833604578460966, 0.16792014161390917, 0.11793481452124459, 0.13174057299537317, 0.08622670346604926, 0.0827297850378922, 0.09909277236355202, 0.18084560946694442, 0.0745181610275592, 0.12697526227150643, 0.15525547548064164, 0.18504312208720616, 0.10860961276505675, 0.1362554771559579, 0.13098064091588768, 0.5148846400635583, 2.505116547857012, 7.809439965656825, 14.615624325616018, 29.692230360848562, 42.25677599225725, 43.42239189147949, 49.858098302568706, 53.860618523189, 49.76885911396572, 49.189636434827534, 41.866176060267854, 41.499158314296174, 38.35564041137695, 34.26460361480713, 28.220598425183976, 25.228936876569474, 25.93110271862575, 36.65680932998657, 24.66863587924412, 38.84898683003017, 28.949777126312256, 30.61464888708932, 27.096461534500122, 33.49243640899658, 30.212171009608678, 34.767601081303184, 35.81896775109427, 28.616963624954224, 18.617778028760636, 37.10140371322632, 58.88009098597935, 48.70720216206142, 24.880547251020158, 25.400616441454204, 26.284550632749283, 25.356992176600865, 31.444298539842876, 29.071434872491018, 29.59042535509382, 29.66859606334141, 49.72290372848511, 47.31597130639212, 38.41534628186907, 28.373556068965367, 30.44083275113787, 36.2758708681379, 35.12480797086443, 34.27847916739327, 39.77798877443586, 43.15965270996094, 44.02768073763166, 42.166334765298025, 32.86529895237514, 24.03353578703744, 14.455697638647896, 7.069068585123334, 1.7798408887216022, 0.662577394928251, 0.1516338355307068, 0.09179672958063227, 0.19294158183038235, 0.22193311687026704, 0.10758995105113302, 0.21579431556165218, 0.161968860243048, 0.14457882195711136, 0.17016960733703204, 0.20349588191934995, 0.1992833193923746, 0.1628030240535736, 0.20446860258068356, 0.15513278277856962, 0.16431161096053465, 0.12234213016927242, 0.1266553465809141, 0.0995353739708662, 0.06505466026387044, 0.1673575546592474, 0.13082142945911202, 0.08792584336229733, 0.14405261805014952, 0.0736861549583929, 0.14190812169441155, 0.06826841245804514, 0.18393227883747645, 0.3075397275388241, 0.06483702694198915, 0.1586870170597519, 0.10731663714562144, 0.10506812815687486, 0.1045657272583672, 0.17202179080673627, 0.15103847533464432, 0.11091658433101007, 0.16521440180284636, 0.15881163680127688, 0.11617492538477693, 0.08942416403442621, 0.10904483191136803, 0.09411084612033196, 0.13579951519412653, 0.09433276778353111, 0.1522751325475318, 0.10705398302525282, 0.08540055315409388, 0.12134104674415928, 0.15453218429216317, 0.1980257633009127, 0.116525904408523, 0.2230017145297357, 0.06533931927489382, 0.1688975848789726, 0.10623945601816688], [0.04874800830813391, 0.015395701729825564, 0.06949945140097823, 0.029693540584828173, 0.02559335363496627, 0.01998924640273409, 0.049252261607242484, 0.05298598536423274, 0.02742044148700578, 0.022531852824613452, 0.029498071609331027, 0.044659454841166735, 0.03932135538863284, 0.009157523878716996, 0.009220463090709277, 0.007636913331225514, 0.08137893038136618, 0.05036417694230165, 0.0692080341811691, 0.0073996338760480285, 0.05931422686470406, 0.04825384482475264, 0.029125678020396402, 0.047814059137765846, 0.020047702194590653, 0.03207988378458789, 0.04091525789616363, 0.042541641875037124, 0.05401680897921324, 0.02233250262880964, 0.0377163316921464, 0.08272297933165516, 0.019193134836054275, 0.02441557969099709, 0.04321217696581568, 0.04437600022980145, 0.009313007633733963, 0.045852305833250284, 0.023123017977923155, 0.01599847661730434, 0.04593165371833103, 0.021418554974453788, 0.02473856575254883, 0.04721153700458152, 0.020312327459188442, 0.04402678878977895, 0.017256958909066658, 0.05523583785231624, 0.029444782861641476, 0.040575702009456496, 0.04187629418447614, 0.036499297711998224, 0.016186116995023828, 0.03748291564573135, 0.04796028682695968, 0.027064901011596833, 0.054238713679036925, 0.030341907936547483, 0.10113269968756608, 0.048234774598053524, 0.0515029079812978, 0.03040971394096102, 0.040476008251841576, 0.01884790978926633, 0.6101376031126294, 3.26218010698046, 7.94693352494921, 13.954174058777944, 21.84349138396127, 28.796826430729457, 35.1714824948992, 39.94006592886788, 39.184056758880615, 38.35088784354073, 36.17844670159476, 34.834918703351704, 23.15527653694153, 25.67461517878941, 21.32642034121922, 27.558242286954606, 30.38713707242693, 31.087800366537913, 23.336011341639928, 26.39155810219901, 27.67536285945347, 20.859784534999303, 17.69545156615121, 19.018605709075928, 13.796430843217031, 17.97964678491865, 17.713230269295828, 28.18916824885777, 16.6063266481672, 35.69043302536011, 76.11783518110002, 58.847629002162385, 25.27669358253479, 20.241203784942627, 23.72317886352539, 20.65720111983163, 23.6403545992715, 18.780546528952463, 26.277687549591064, 34.46947125026158, 33.43064260482788, 36.28843321119036, 18.052898168563843, 19.638378075190953, 26.49553963116237, 30.806700570242747, 31.42951624734061, 31.771134853363037, 36.540128231048584, 30.473534447806223, 21.701805455344065, 13.5455869776862, 5.339241589818682, 2.1906391254493167, 0.5269457900098392, 0.05238730373925396, 0.050444047299346755, 0.033911270155970535, 0.063739557617477, 0.03242912915136133, 0.030428628104605844, 0.011014055061553205, 0.02021404675074986, 0.040820412271256955, 0.1232489107974938, 0.014998889361907328, 0.057863457926682065, 0.036127277317323854, 0.030394043174705336, 0.02794227732478508, 0.054199090626622946, 0.023300466759662544, 0.046473660705877204, 0.040095590986311436, 0.02095743953915579, 0.021644961754126207, 0.0780256035338555, 0.05639510814632688, 0.011648440351044493, 0.03754138500828828, 0.02989911294675299, 0.026446441787161996, 0.04284681299967425, 0.026881732179650238, 0.046578948984720876, 0.053033662627318075, 0.01883607783487865, 0.06468883489391633, 0.03547538158350757, 0.008554274016725165, 0.01501635994229998, 0.05179693416825362, 0.01814581942744553, 0.01990526751615107, 0.032698405773511956, 0.02585925963441176, 0.022821633078690087, 0.0540260166994163, 0.022789740236476064, 0.010448506301535028, 0.021898308070376515, 0.020117743971890638, 0.005657658912241459, 0.031727571439530165, 0.03429914791403072, 0.12153479563338415, 0.0747085918805429, 0.008399693561451775, 0.07875744426356894, 0.033423064210053, 0.040819011096443446, 0.030388414726725647, 0.04945851589686104, 0.03193187154829502, 0.022454990074038506, 0.02494422802036362, 0.012038480939476617, 0.028452617083010927, 0.025519783475569317, 0.007670937621566866, 0.04401026985474995, 0.013272502891985434, 0.054545384366065264, 0.014827717029090439, 0.031818902253040245, 0.030026226304471493, 0.01695785897650889, 0.09823912102729082, 0.008937946554007275, 0.03190298970522625, 0.024999581210847412, 0.036076302374047894, 0.009700031285839421, 0.026133177436089942, 0.05491056852042675, 0.07336036315453903, 0.04261800081336072, 0.018935596869726266, 0.03641792779256191, 0.0711154504013913, 0.07218415662646294, 0.008558022074534424, 0.009631077709075595, 0.03790739019002233, 0.022839229188061187, 0.0167519456507372, 0.027573858254722187, 0.0435165474191308, 0.06242640236658709, 0.03825834207236767, 0.057899019947009425, 0.035857817490718195, 0.036959130716110976, 0.02406895177305809, 0.07347715938729898, 0.04668910235964826, 0.009850356478377112, 0.017692086453150426, 0.04416942363604903, 0.02646853997638183, 0.007656146406329104, 0.033367661825780354, 0.027415620495698283, 0.01642806053028575, 0.000849995092721656, 0.0403643485291728, 0.047273263335227966, 0.06192000489681959, 0.02413254916401846, 0.01520957109252257, 0.0555692054996533, 0.03174992577571954, 0.007869155512058308, 0.02434377032997353, 0.034339150946055136, 0.11735287574785096, 1.220628804394177, 4.759111736501966, 10.862860577447073, 17.777857201439993, 27.149302584784373, 34.214795453207834, 40.70925235748291, 44.80009807859148, 43.876963887895855, 41.52421004431588, 40.20388902936663, 40.02848523003714, 26.96249679156712, 28.47219443321228, 19.839764663151332, 24.866223539624894, 32.30782413482666, 26.661969832011632, 27.01029518672398, 24.609152351106914, 31.35648720605033, 25.61094014985221, 23.566682849611553, 24.87565745626177, 22.731863737106323, 24.41275109563555, 22.830809559140885, 27.32292764527457, 20.166376897266932, 47.39171361923218, 79.18666689736503, 53.889516081128804, 25.55190130642482, 24.18441765648978, 27.776931626456125, 24.447158575057983, 25.44699045589992, 23.400971787316458, 27.589462280273438, 40.30887631007603, 40.08004433768136, 36.93672793252127, 19.629500014441355, 22.712516478129796, 31.17460421153477, 33.52942167009626, 35.086283683776855, 37.06181982585362, 39.9067771094186, 36.12687022345406, 27.002660853522165, 16.337909051350184, 7.371191893305097, 3.2231668404170444, 0.9070797264575958, 0.1139621412647622, 0.07105371728539467, 0.027689439909798757, 0.08569176681339741, 0.03913792023169143, 0.008379736998384553, 0.025059034449181387, 0.04677890307669129, 0.10821398613708359, 0.06240152048745325, 0.06888485473713704, 0.0713853444904089, 0.03596089035272598, 0.018984339432790875, 0.0569286063047392, 0.027785121829115918, 0.015547372966206499, 0.013601968962965267, 0.0423155879335744, 0.02731653063424996, 0.027474442696464912, 0.09509200775729758, 0.010235625269290591, 0.04085154006523745, 0.018135208836091415, 0.028805948926934173, 0.0592257526836225, 0.030009154363402298, 0.03277567734143563, 0.023596659169665406, 0.04792526084929705, 0.012258317803830972, 0.052948095968791416, 0.014728147104116423, 0.08923909360808985, 0.04666135706273573, 0.042252385789262395, 0.038308305998465846, 0.021778745111078024, 0.02482639023635004, 0.05163492036185094, 0.051739380827971866, 0.042617315492991886, 0.0401326084642538, 0.0503425622092826, 0.0434405922091433, 0.06156577569033418, 0.03554089413955808, 0.01708663983403572, 0.03581479837053588, 0.09096439781465701, 0.029786815401166677, 0.05371432824592505, 0.07121827559811728, 0.024655246741271446, 0.03292595588469079, 0.007529943981873137, 0.1550473009369203, 0.15391437815768377, 0.1268815972975322, 0.18398460745811462, 0.14791736352656568, 0.09904740551220519, 0.15592637019498007, 0.12502166495791503, 0.17601434513926506, 0.1073249831263508, 0.130207056711827, 0.08215173427015543, 0.07241261936724186, 0.10233010364962475, 0.14331084356776305, 0.19668070333344595, 0.13320757927639143, 0.10973883074309145, 0.17080155414130005, 0.12165343069604465, 0.1556050567222493, 0.1398791798523494, 0.11822349045957838, 0.14199337283415453, 0.18157749090875897, 0.11953359230288438, 0.14145879580506257, 0.16497848874756268, 0.21505416956331047, 0.0747755022187318, 0.1534286556499345, 0.12000839039683342, 0.08939408457704953, 0.18120380810328893, 0.12729962915182114, 0.10528952734810965, 0.15482915192842484, 0.08508555005703654, 0.21942225231656007, 0.1261414648698909, 0.13653647207788058, 0.08585981958146606, 0.18025501258671284, 0.18390441818961076, 0.0794807490227478, 0.10838862748018332, 0.12029098666140012, 0.10778659728488751, 0.1454310076577323, 0.0833307702892593, 0.16264481682862553, 0.11328065461878266, 0.06961225106247834, 0.12422609621925013, 0.13540000734584673, 0.2271162694586175, 0.11556599448834147, 0.23397377505898476, 0.1513352394104004, 0.15269651636481285, 0.1417197875146355, 0.12753646501473018, 0.12836623191833496, 0.2166912845735039, 1.1300017131226403, 4.883144463811602, 10.69337751184191, 19.998100212642125, 28.829368318830216, 38.70005566733224, 45.82629142488752, 52.6691483770098, 52.909191267830984, 51.50164256777082, 49.63316426958357, 48.599671840667725, 36.299380098070415, 38.72690003258841, 30.32468318939209, 38.9340432030814, 43.373309816632954, 40.02888822555542, 36.00184086390904, 37.159275259290425, 39.6789665222168, 31.11703143801008, 29.305493627275737, 30.56775896889823, 23.91335800715855, 31.89688335146223, 28.435499259403773, 38.114301681518555, 24.6796817779541, 45.42023869923183, 82.66987528119768, 67.93799890790666, 33.66482816423689, 30.568429470062256, 35.4227363041469, 30.152760437556676, 35.841000488826204, 30.01263611657279, 38.35059601919991, 46.328969274248394, 47.73449604851859, 48.10720784323556, 26.984260286603654, 29.58063186917986, 38.100572041102815, 42.047680377960205, 42.6376519203186, 44.532887731279644, 47.650700773511616, 42.67069755281721, 31.97715241568429, 19.30145297731672, 8.266028676714216, 3.8842970558575223, 0.9658595323562622, 0.236505497779165, 0.11795139791710035, 0.2219876168029649, 0.20651743906949246, 0.1033168224883931, 0.0787040503429515, 0.12203045189380646, 0.08379195697073426, 0.1567731818982533, 0.21980402325945242, 0.22079772422356264, 0.17098256014287472, 0.09162117221525737, 0.09319061692804098, 0.16316590458154678, 0.08856194280087948, 0.07160220428236894, 0.11052935796656779, 0.08050176780670881, 0.07078153653336422, 0.08033576421439648, 0.1368703655898571, 0.12229035794734955, 0.07167159127337591, 0.1663848611393145, 0.1235887889883348, 0.149313055777124, 0.08862765891743557, 0.13582661588277134, 0.20015738106199674, 0.17949917885873998, 0.14115292578935623, 0.14715965704194137, 0.10791306264166321, 0.1498434937426022, 0.1273698303848505, 0.10561474918254785, 0.12159601306276661, 0.16887439255203518, 0.10873738090906825, 0.15935787106198923, 0.0982528885028192, 0.13574198899524553, 0.16022028907069139, 0.12917775980063848, 0.12255023685949189, 0.0927674960611122, 0.10794728794800383, 0.12009740062057972, 0.13531616755894252, 0.2461353481880256, 0.21309350191482476, 0.1157913902508361, 0.21865816760276044, 0.09848912046956164, 0.1148628829313176, 0.06405738342021193], [0.06814109893249613, 0.04058983589389494, 0.005761818702532244, 0.05394476213093315, 0.01549989587095167, 0.048083505393671136, 0.0044084360789773715, 0.0422943022900394, 0.05846006662717887, 0.06154408971113818, 0.09407935531011649, 0.019439018963436996, 0.018388371947886686, 0.037609516709510765, 0.02478877904026636, 0.05429707108331578, 0.029003443329461982, 0.015387153884928142, 0.024510920646467378, 0.04805309684681041, 0.020868721085467508, 0.03954136358307941, 0.03709787755672421, 0.015997562291366712, 0.015979177385036434, 0.013969574639174556, 0.05265123011278255, 0.054611517781657834, 0.01112855360510626, 0.03053084940516523, 0.02958201996183821, 0.011163606724169637, 0.047881966922432184, 0.04240774655980723, 0.03134758843641196, 0.0656912075355649, 0.04408579419500061, 0.0198687555467976, 0.06079505490405219, 0.04060114367998072, 0.01335096444069807, 0.04463830829731055, 0.006819672184064984, 0.009696075426680701, 0.03487705958208867, 0.05782840480761869, 0.0353232540323266, 0.03789797890931368, 0.04109576517449958, 0.039050280648682795, 0.030602007372570888, 0.04533951995628221, 0.05686582824481385, 0.013198752072639763, 0.012583638025846864, 0.050156996452382634, 0.02336634572462312, 0.05318818201443978, 0.0342280713708273, 0.021070354551609074, 0.023420128106538738, 0.04686663765460253, 0.007967115612700582, 0.05953961584184851, 0.02333834088806595, 0.11727459994809968, 0.9189950185162681, 4.108455061912537, 6.452947931630271, 15.33005894933428, 19.65611856324332, 27.950678280421666, 36.04074035372053, 36.28511892046247, 41.30381318501064, 43.696286405835835, 45.1633221081325, 40.176711150578086, 41.57247223172869, 42.04887546811785, 30.985887663705007, 29.72220836366926, 22.496265956333705, 27.573700291769846, 21.833001341138566, 25.908255304609025, 27.145258733204432, 27.416078669684275, 29.63280589239938, 30.780655247824534, 30.46013137272426, 27.65110843522208, 36.07221916743687, 29.699338368007115, 41.98348944527762, 79.84885801587785, 46.643500328063965, 24.579308101109095, 28.605033567973546, 24.196120159966604, 24.21118038041251, 17.525774819510325, 23.056122268949235, 25.12809419631958, 28.556872129440308, 37.50356197357178, 24.045874050685338, 24.272802216666086, 33.08465358189174, 29.966538293021067, 33.8701057434082, 31.66926383972168, 25.806448561804636, 14.604597534452166, 8.056181788444519, 2.707983753510884, 0.6586137190461159, 0.12480380093412739, 0.08415494606431041, 0.06674886042518274, 0.011549174070491322, 0.04838411337030785, 0.03147115984133311, 0.08544760277228695, 0.021159749843978455, 0.04758514856387462, 0.05012793479753392, 0.021711174897583466, 0.05887932662985154, 0.030525383805590015, 0.010912553008113588, 0.0011203612936826954, 0.03168571600690484, 0.016573175422048995, 0.07144671119749546, 0.04115970013663173, 0.0446414499144469, 0.03178362182474562, 0.03770034201443195, 0.020638665483732308, 0.03505199608792152, 0.026291391446388195, 0.03350732129599367, 0.05508320139987128, 0.028191930714196393, 0.03971510247460433, 0.07973721490374633, 0.04341763397678733, 0.01850489846297673, 0.08014577440917492, 0.01860366771662874, 0.017243547664423074, 0.023192014811294417, 0.06814415234008006, 0.03415681501584394, 0.0488182468605893, 0.03417486065466489, 0.01118987875192293, 0.020587390288710594, 0.003656035738198885, 0.04998134409210511, 0.05800068484885352, 0.04594330755727632, 0.02759866719134152, 0.05147064703383616, 0.06731072134737458, 0.03374770589705024, 0.04601976488317762, 0.05484370228701404, 0.00325819751014933, 0.01457983800875289, 0.06692741691534008, 0.06182192944522415, 0.032635135775698085, 0.0504075760420944, 0.03881244733929634, 0.021148072256307517, 0.0838876236230135, 0.0398603089685951, 0.06366595013865403, 0.0027265417863548335, 0.028031279066843644, 0.011273408957224871, 0.013196390770774866, 0.02378941739776305, 0.05362966403897319, 0.1265175768307277, 0.07423242314585618, 0.009827324455337865, 0.02475701511970588, 0.023759860412350724, 0.06137920570160661, 0.0314557062062834, 0.05601391735087548, 0.03493123042530247, 0.01764614793605038, 0.044564761886639256, 0.019265783884163414, 0.03745426111189382, 0.030188779546214, 0.07467917060213429, 0.033292758345071755, 0.00930314343090036, 0.05987403182578938, 0.020206569294844354, 0.014451238659343548, 0.03137530319924865, 0.04106613015756011, 0.03286584107471364, 0.05347290548628994, 0.018579801943685328, 0.029957131083522524, 0.048590408372027535, 0.10969507201973881, 0.11440055631101131, 0.018094444148508564, 0.05708539539149829, 0.04200764160071101, 0.044332485779055526, 0.05009201315364667, 0.030517960632486, 0.05140717686819179, 0.04186797534514751, 0.05491880593555314, 0.04854510258883238, 0.04217768586905939, 0.01176332905223327, 0.03825859652299966, 0.018931983670751964, 0.02855922680880342, 0.024970131094700525, 0.017030358746913925, 0.03323137467460973, 0.04453591397032142, 0.04457635126475777, 0.02843992508548711, 0.0032587112883837627, 0.06545179323958498, 0.05094399868643709, 0.014552772943196552, 0.026493024912529757, 0.3441459589770862, 1.4778274489300591, 5.60221483877727, 9.728807738849095, 19.55088288443429, 24.498776742390223, 33.22198472704206, 40.88442686625889, 43.30639519010271, 45.995122228349956, 46.185155459812705, 46.496889863695415, 43.012121609279085, 43.76655353818621, 41.425420556749614, 35.18873834609985, 32.07795688084194, 27.24920552117484, 28.614458799362183, 25.234901905059814, 24.209328685488018, 27.668035984039307, 26.527664627347672, 25.76434247834342, 30.178718907492502, 27.884342091424124, 28.91931274959019, 34.59548725400652, 31.28750201633998, 53.318554810115266, 84.01053714752197, 40.85404239382063, 26.336207015173777, 28.84194803237915, 23.870300020490372, 25.53988265991211, 18.341991867337907, 26.309503350939067, 31.667669228145055, 34.9596631867545, 43.878294467926025, 27.132692916052683, 28.53581213951111, 37.973023959568565, 35.67966679164341, 38.325533866882324, 35.23142807824271, 29.90606812068394, 18.04730486869812, 10.785271780831472, 4.247926686491285, 1.1473596159900938, 0.18508198857307434, 0.02924393310344645, 0.04803562457008021, 0.03356819945786681, 0.015790563309565187, 0.01452533298704241, 0.06784256388034139, 0.06964146878038134, 0.03859802009537816, 0.05428977343919022, 0.05254141939803958, 0.03713224196274366, 0.015912477392703295, 0.03107302263379097, 0.005897571507375687, 0.027796444882239615, 0.02998883223959378, 0.07586323456572634, 0.041018022024737935, 0.028737477958202362, 0.05707704941076892, 0.026554574824071357, 0.050605603094611845, 0.03813541866838932, 0.04179547048572983, 0.01645897458573537, 0.018644530791789293, 0.033326060843787024, 0.028174022478716712, 0.024437876351709877, 0.012815159263222345, 0.03195071107308779, 0.05244877901194351, 0.021256059408187866, 0.005924605614771801, 0.023947984246270995, 0.023821172836635793, 0.040272882008658986, 0.039596525087420426, 0.020920612051018646, 0.031059987976082733, 0.055007310650710545, 0.028495515763227428, 0.06655038893222809, 0.01349263237456658, 0.04245813796296716, 0.06076892452048404, 0.017372133443132043, 0.031835010674382956, 0.03707939087014113, 0.005807869177910366, 0.0776325621243034, 0.06098062066095216, 0.057599962422890325, 0.017207200239811624, 0.03216198652184435, 0.035101037206394334, 0.016171545455498353, 0.024975326976605823, 0.23946274338024004, 0.20071097064231122, 0.17205085924693517, 0.08495046730552401, 0.12832029509757245, 0.17500505144042627, 0.14889161767704145, 0.06725886770124946, 0.15465980315847055, 0.12709739857486316, 0.16670263265924795, 0.15311188836182865, 0.14307176853929246, 0.10546752065420151, 0.09746145204241786, 0.2186245529779366, 0.1421790878687586, 0.15898599315966877, 0.1403180563024112, 0.17201185705406324, 0.09128366889698164, 0.10623498447239399, 0.11929934844374657, 0.13760154135525227, 0.13872679668877805, 0.13221102846520288, 0.17471598195178167, 0.1433424497289317, 0.11604392741407667, 0.06916675211063453, 0.07895870453545026, 0.14664322403924807, 0.13534948362835816, 0.10559718869626522, 0.1337420477398804, 0.09437545442155429, 0.12303751999778406, 0.18441148740904673, 0.19834277486162527, 0.08566251516874347, 0.10745212701814515, 0.14723687432706356, 0.17192248042140687, 0.09686106390186719, 0.17506104415016516, 0.2470508004937853, 0.1136690548488072, 0.1433289875941617, 0.11505488120019436, 0.08490921237639018, 0.0869326377287507, 0.21981246423508438, 0.10075871154133763, 0.13890109876436846, 0.10078591401023523, 0.1375871564128569, 0.10399249408926282, 0.11531990340777806, 0.1409218439034053, 0.08053207118064165, 0.12675081645803793, 0.22456128655799798, 0.17790247739425727, 0.16260856948792934, 0.08195630939943449, 0.4140961069081511, 1.702538162469864, 5.86809286900929, 9.684480837413243, 20.507290261132376, 28.107523441314697, 37.07527848652431, 47.43630368368966, 49.65743432726179, 56.38797017506191, 55.830064569200786, 60.65997627803257, 54.28736298424857, 54.72111470358712, 51.81972762516567, 43.92275946480887, 40.8219382422311, 32.63049152919224, 37.980441161564414, 32.398081234523225, 35.63977370943342, 38.58064045224871, 39.272705350603374, 39.98973512649536, 41.80601508276803, 41.01880155290876, 40.867692129952566, 47.19782066345215, 38.20861652919224, 50.358177525656565, 89.41242803846086, 57.08874464035034, 34.08712925229754, 40.20991311754499, 36.73809630530221, 34.94973421096802, 26.403965847832815, 32.89556877953665, 35.91743762152535, 42.85461636951992, 51.13668843678066, 34.80588912963867, 35.90417351041521, 44.42026090621948, 42.28368983949934, 44.12842614310128, 40.99159935542515, 33.61980731146676, 21.8100722857884, 12.797974705696106, 4.788901269435883, 1.2545262426137924, 0.30075483875615255, 0.2026104072907141, 0.14933922008744308, 0.17184230472360337, 0.1200997212103435, 0.14897296045507702, 0.13802101170378073, 0.3209188910467284, 0.11919178707259041, 0.10690583168928113, 0.08366243820637465, 0.14361342947397912, 0.06371006848556654, 0.2523053485367979, 0.10578506147222859, 0.1735734918287822, 0.14103586492793901, 0.13035940139421395, 0.13333233472492012, 0.17593529580959252, 0.10252531138913971, 0.08162804772811276, 0.10608323011547327, 0.10410145324255739, 0.14934277561094078, 0.11160832364112139, 0.10845861836735692, 0.1913817926709141, 0.1432998784418617, 0.1181404377732958, 0.14102095072822912, 0.17868239911539213, 0.2681289480200836, 0.0972157884389162, 0.06762919175837721, 0.11636464377599103, 0.13160373962351254, 0.12601973568754538, 0.21663105780524866, 0.21185384557715484, 0.10235280064599854, 0.11934840652559485, 0.18817773674215588, 0.16189221292734146, 0.19828824778752668, 0.14025815523096494, 0.1501814177525895, 0.13525371519582613, 0.1672834993473121, 0.10446771966027361, 0.14394906003560337, 0.14674811198243073, 0.14302964508533478, 0.15124077376510414, 0.12795050708310945, 0.12875936153743947, 0.22291132009455136, 0.12063899370176451, 0.15591896059257643], [0.02168485282787255, 0.04834396784592952, 0.03891060421509402, 0.03247218219829457, 0.017083097881238376, 0.05576333436848862, 0.0152109111991844, 0.015864688171339885, 0.017571045983848826, 0.06338283818747316, 0.06245210527309349, 0.028609808201768568, 0.038458733819425106, 0.06520327300365482, 0.006262979154208941, 0.04866906075871416, 0.023573002046240226, 0.016193356963672807, 0.02451544308236667, 0.029711823710905652, 0.04220283916220069, 0.031199742441198657, 0.022606147320142815, 0.04825131728180817, 0.08004963956773281, 0.011032325465099087, 0.054264196061662266, 0.044206746454749785, 0.043506169226020575, 0.016693410131015947, 0.040634707414678166, 0.0028287925607790904, 0.03549499124554651, 0.06083946502102273, 0.028329909113901, 0.021967240442921008, 0.030990658660552332, 0.05282332694956234, 0.01744124393111893, 0.06953278782644443, 0.010267245849328381, 0.04180977400392294, 0.030013642872550657, 0.028971789670842032, 0.02284263713019235, 0.02265436910758061, 0.08922189274536711, 0.00586611038306728, 0.028096443873697093, 0.02632771512227399, 0.01792893249408475, 0.11220086791685649, 0.06329553787197385, 0.03365315543487668, 0.03213053642373, 0.04769141732582024, 0.03811973433143326, 0.028917978451188122, 0.023579609280984317, 0.08250449784100056, 0.009824205738758402, 0.018428951734676957, 0.11672238100852285, 0.06171493125813348, 0.04048566719783204, 0.0367893850031708, 0.04607634113303252, 0.2604688033461571, 0.6161747734461511, 2.5645594724587033, 5.463746360370091, 10.036546060017177, 18.993614775793894, 25.772266898836406, 36.45758710588728, 42.31341770717076, 43.63771309171404, 44.76838302612305, 47.71075752803257, 44.36028058188302, 38.130164418901714, 37.76549168995449, 28.541346379688807, 39.662954398563926, 35.39984546388899, 27.914895057678223, 26.045273780822754, 30.209812096187047, 33.87528215135847, 27.43188582147871, 24.53267526626587, 29.39763716288975, 32.89459950583321, 30.738371985299246, 24.321106093270437, 47.34069299697876, 70.08177525656563, 26.65111674581255, 25.930835212979996, 29.836377688816615, 21.09592601231166, 27.08279616492135, 33.72526012148176, 21.9236319065094, 39.72562714985439, 36.2670362336295, 34.06977265221732, 33.185840197971885, 34.4987335886274, 26.058431931904384, 24.330713714872086, 17.20520404406956, 10.47132350717272, 5.13966109922954, 1.681127505643027, 0.1682348054434572, 0.09562790114432573, 0.07041790283152036, 0.041257256508937905, 0.08122328123343842, 0.07045275917542831, 0.03958027756639889, 0.06921519951096602, 0.0430799813808075, 0.05058633270008223, 0.04925479932821222, 0.018896508163639476, 0.028796425687947443, 0.07365062007946627, 0.030766921916178296, 0.04064494650810957, 0.03391208779066801, 0.010383102311087506, 0.020187762000464966, 0.053151524160057306, 0.03434613646407213, 0.006402190791309944, 0.02473028253630868, 0.09836818517318793, 0.04834936559200287, 0.02527638278635485, 0.02817063489263611, 0.09057234028088194, 0.04363775412951197, 0.04313691725422229, 0.04731545803536262, 0.03807486620332513, 0.03761636991319912, 0.06170047167688608, 0.02897790666403515, 0.07959815593702452, 0.047635499254933426, 0.02687590865285269, 0.041208463055746894, 0.026196489842342477, 0.01768909750639328, 0.05759431701153517, 0.049593225454113314, 0.04565426521003246, 0.06385832160179104, 0.028696982988289425, 0.033566058679882965, 0.020379668667114208, 0.05990658115063395, 0.05574874247291258, 0.03251823437001024, 0.04091285927487271, 0.05196123124499406, 0.07011478088263955, 0.008219774064075733, 0.046679908210145574, 0.08105471277875559, 0.021587710361927748, 0.024863492531169738, 0.04357627207147224, 0.0686626277331795, 0.04318085578935487, 0.046775696998728175, 0.03314297513238021, 0.09744766421083893, 0.06974862981587648, 0.03454230433063848, 0.0344412840370621, 0.029020661155560186, 0.041149613713579516, 0.030010060207652192, 0.0636508527344891, 0.04624547277178083, 0.04220567883125373, 0.001222078039843057, 0.029316441355539218, 0.013205319443451507, 0.015302881531949555, 0.02705510126959, 0.024429443857765624, 0.027389130488570248, 0.09151122918618576, 0.046672485037041564, 0.004003927427610117, 0.02043994632549584, 0.05828853975981474, 0.03576882423034736, 0.03674570091867021, 0.029577378782310655, 0.05313142595280494, 0.020656711122553264, 0.06257223311279501, 0.055305642142359696, 0.023404197800638418, 0.05574221835870828, 0.049726123322865794, 0.02716173474410815, 0.04927702474274805, 0.01614338794856199, 0.03881954142291631, 0.009602194169669278, 0.067398863046297, 0.02866614357169185, 0.01611694204621017, 0.029669065826705525, 0.039336551180375476, 0.02678753455568637, 0.044191761008862934, 0.00990425845208977, 0.007682476957727755, 0.046412731653877666, 0.0329446800585304, 0.037927393402372084, 0.012834320243980204, 0.03352091235241719, 0.02988482978461044, 0.030263581246669804, 0.05294407904148102, 0.0603226384680186, 0.028495050966739655, 0.025184792433200136, 0.019583389163017273, 0.04351254066984568, 0.08487987252218382, 0.09172950033098459, 0.0466615708012666, 0.005231735695685659, 0.030602526451860155, 0.4293608106672764, 1.220768419759614, 4.224348843097687, 8.48930469581059, 13.854147791862488, 23.828157458986553, 32.32375635419573, 40.6945777620588, 48.28121158054897, 50.436237062726704, 51.17576163155692, 52.665410246167866, 49.79234749930245, 42.21447535923549, 40.70719569069998, 31.561271463121685, 42.850016662052695, 37.34730740955898, 28.352417911802018, 26.775479078292847, 32.23259251458304, 31.251892498561315, 28.762995651790074, 24.051378761019024, 31.57822506768363, 35.38911049706595, 29.883013997759136, 26.192394937787736, 54.875729492732454, 71.52948801858085, 26.89525212560381, 27.92975378036499, 31.61819110597883, 24.75311381476266, 25.949616193771362, 37.61174542563302, 27.964859553745814, 43.896318095070974, 41.19526495252337, 37.405484676361084, 36.978653362819124, 39.272833892277305, 31.196657793862478, 29.733162198747905, 21.625967604773386, 12.978461112294879, 6.70319208077022, 2.6525786008153642, 0.3230304648833615, 0.07682238452668701, 0.04205320861988834, 0.05091602947296841, 0.041547126668904505, 0.026108154760939733, 0.0530686411075294, 0.06988527998328209, 0.019882550163726722, 0.04007634434050747, 0.03003265881644828, 0.018552764019529735, 0.03936094790697098, 0.014991576450743845, 0.006479373725596815, 0.020703904929437807, 0.020827014930546284, 0.005988890870607325, 0.052071757814181704, 0.037094800400414636, 0.0213373462070844, 0.027568429974572997, 0.021571932726406624, 0.020390825479158332, 0.013266690391381937, 0.026103238774729625, 0.012202586330074285, 0.02598538402734058, 0.005441519639654351, 0.04989027112190213, 0.07761034688779286, 0.01256943289523146, 0.044014263033334694, 0.07697441708296537, 0.025831907887810042, 0.022115683548950722, 0.048424448884491406, 0.03065272107986467, 0.06078349266733442, 0.026197124272584915, 0.02380255044304899, 0.028011474325986843, 0.0028534185049855815, 0.05632968719250389, 0.02666084697869207, 0.030056746809610298, 0.01526321267842182, 0.060753704980015755, 0.016588303360289762, 0.05868012231907674, 0.029677639116666148, 0.016795395640656352, 0.018948181997984648, 0.05121459845187409, 0.05010978398578508, 0.030733392108231783, 0.05262226006016135, 0.04282850951754621, 0.037088361103087664, 0.0544323098978826, 0.03336855409932988, 0.13174378925136157, 0.13299183228186198, 0.09540615590023142, 0.18998434980000767, 0.1631014301840748, 0.07944290033940758, 0.12942412229520933, 0.2931750869112355, 0.12319841422140598, 0.17256786221904413, 0.29076080503208296, 0.1619848193866866, 0.13045803324452468, 0.11815444273608071, 0.07837183959782124, 0.13805693334766797, 0.1143935809710196, 0.09414749379668917, 0.1438867433794907, 0.07832641846367291, 0.17024937591382436, 0.1672782339155674, 0.14671605798814977, 0.19081643729337625, 0.21581783358539852, 0.11993494576641492, 0.1576088113444192, 0.1532075482287577, 0.12009862198361329, 0.09181940622095551, 0.11400374903210572, 0.15786311269870826, 0.19019031231956823, 0.18720059203250067, 0.09203040347035442, 0.17189757818622248, 0.13348054034369333, 0.13524228866611207, 0.2101513333618641, 0.1276004101548876, 0.1687461222921099, 0.18735824285873345, 0.14282850016440662, 0.15754312915461405, 0.19929185536290916, 0.10248708951153926, 0.16925195657781192, 0.13931999914348125, 0.11098014270620686, 0.21872294055564062, 0.1113394337839314, 0.14567650162747928, 0.09584428596177272, 0.16881241516343184, 0.1530975712729352, 0.10831723202552114, 0.10793820914945432, 0.10482783855072089, 0.1272695836211954, 0.13246592693030834, 0.06891772297344037, 0.096243155987135, 0.20846934004553727, 0.2605699322053364, 0.11209602747112513, 0.08004280672009502, 0.11295041841055665, 0.4768123115812029, 1.4662596753665378, 4.1659418514796664, 9.25613568510328, 15.161042281559535, 25.510095732552664, 36.06806761877877, 46.032517433166504, 53.49472638538906, 57.267678124564036, 58.050246783665244, 61.77070835658482, 58.04064089911324, 52.58594369888306, 50.755267075129915, 39.54109341757638, 52.95419127600533, 46.961793831416536, 38.70309550421578, 35.55072212219238, 41.743269375392366, 43.54117829459054, 40.39576700755528, 33.44010952540806, 40.85079411097935, 43.859985964638845, 40.259523255484446, 32.43725517817906, 56.94663313456944, 81.487382207598, 38.04819999422346, 36.86601611546108, 42.316426277160645, 31.569025652749197, 37.476436206272666, 43.383179732731406, 33.33019944599697, 53.515174933842246, 50.61799498966762, 45.72237764086042, 42.92626966748919, 46.72837604795183, 37.36564370564052, 33.839245319366455, 23.69331898008074, 15.10710688999721, 7.627094047410147, 2.688231110572815, 0.44116487726569176, 0.2011612057685852, 0.18849738101874078, 0.1614098016704832, 0.19095403062445776, 0.1639221047184297, 0.13536765479615756, 0.11933752282389573, 0.10324795118400029, 0.15568910006965908, 0.1274164185992309, 0.1175632623157331, 0.08144978979336363, 0.17571730964950152, 0.1440009136817285, 0.11753717942961625, 0.12699835960354122, 0.04269334194915635, 0.29812198717679295, 0.10620971582829952, 0.06976542355758802, 0.15031743688242777, 0.08644969042922769, 0.14667078613170556, 0.14943432355565683, 0.16119128625307763, 0.0585951493786914, 0.1376022198902709, 0.07160163431295327, 0.10263557332967009, 0.14989922860903399, 0.11152170186064073, 0.18370465748012066, 0.21837622273181165, 0.10165658979011433, 0.14737289345690183, 0.11963503328817231, 0.07098515810711042, 0.13595564610191754, 0.11836550783898149, 0.08162177806454045, 0.10878464765846729, 0.08218950831464358, 0.11812149307557515, 0.11856226942368916, 0.13574471670602048, 0.08976432042462484, 0.09468489353145872, 0.10333937020706278, 0.1502084234463317, 0.09321561415812799, 0.1448029556444713, 0.12592896127275058, 0.14262888873262064, 0.15835133221532616, 0.23703787635479653, 0.21039171117757047, 0.1472970468125173, 0.2121599055826664, 0.10762162506580353, 0.16696100522364887], [0.05022610185135688, 0.03201389964669943, 0.0722204175378595, 0.0678897967029895, 0.08767141308635473, 0.043522274254688194, 0.06774931959807873, 0.06824488086359841, 0.04426888329908252, 0.03807490013007607, 0.05691152418564473, 0.013901716896465846, 0.0319403634140534, 0.032654643657484224, 0.0290937495550939, 0.06147397668766124, 0.043411320208438804, 0.04162312259099313, 0.04139228158497384, 0.05965855624526739, 0.017347494140267372, 0.02474061832098024, 0.06233760927404676, 0.08088841063103505, 0.02416592460524823, 0.006981057921491031, 0.0035175649765213685, 0.06726413991834436, 0.04629485994311316, 0.0358595715037414, 0.036198906866567473, 0.03962242476908224, 0.011929312288495047, 0.14987174794077873, 0.0259820117082979, 0.013627625220189137, 0.0765305601858667, 0.06577488447406463, 0.024811482821990336, 0.0542796395186867, 0.049550274187432866, 0.07744895054825715, 0.05488513024257762, 0.04274833042706762, 0.03821970968108092, 0.03640998214749353, 0.05233905989942806, 0.032467490128640614, 0.06065159224505935, 0.05338239570015243, 0.05540091185165303, 0.025331155829397694, 0.019333174285878028, 0.07010353755738054, 0.01811185196441199, 0.02459694870880672, 0.014151793522095042, 0.01959664434460657, 0.0899631515411394, 0.0642865721934608, 0.003604047657323203, 0.09395526482590608, 0.01666254866203027, 0.05761322099715471, 0.009891823449704264, 0.010923062667383679, 0.05251659519438233, 0.060883800499141216, 0.09845241851040296, 0.29698875227144783, 1.3423285654612949, 2.6870114845888953, 5.410054590020861, 10.041200484548297, 17.93951051575797, 23.19022944995335, 30.45716449192592, 35.34635475703648, 40.25469078336443, 44.81723233631679, 42.065662315913606, 47.79344456536429, 41.3425007547651, 47.992232527051655, 42.599690437316895, 40.60968814577375, 43.29075479507446, 38.31601136071341, 39.56007589612688, 40.53719064167568, 37.92413296018328, 38.05397742135184, 31.772614819662913, 35.44080856868199, 38.01313591003418, 32.82087217058454, 54.84701953615461, 44.93720688138689, 32.25256858553205, 30.93828555515834, 25.314373663493566, 36.012214524405344, 38.65632370540074, 35.409704957689556, 42.68931872504098, 32.789032050541465, 35.52342612402779, 31.868524278913224, 24.717862129211426, 16.4626396383558, 8.076682448387146, 5.3066653949873785, 2.2083166454519545, 0.3525685598807675, 0.07101998730961766, 0.019578508799895644, 0.021588541567325592, 0.08754570090344974, 0.019527959637343884, 0.05510868038982153, 0.016629666855026568, 0.05125383134665234, 0.05560916442690151, 0.01483074329527361, 0.03316480699660523, 0.05336962227842637, 0.01985897446450378, 0.009685860081974949, 0.0850753313196557, 0.031169184616633823, 0.056620208746088405, 0.06108993265245642, 0.04967529087194374, 0.006929000714860324, 0.018005369463935494, 0.025988958210551312, 0.08577406632580928, 0.034474260838968415, 0.05913431330450943, 0.04588284669443965, 0.08197872141110045, 0.0418868521893663, 0.021769501767786484, 0.011575602161298906, 0.040205927565693855, 0.07294481473841838, 0.08181300958884613, 0.03388584205614669, 0.10806852179978575, 0.0401276381952422, 0.03764655454350369, 0.034446983731218746, 0.016844017763755152, 0.03395384483571563, 0.05552555873457875, 0.034151067824235985, 0.1127701655828527, 0.08565912249365024, 0.018545946438929865, 0.0448302624614111, 0.01465349637770227, 0.028787228145769665, 0.06623740108417613, 0.029486628116241524, 0.037766926655811925, 0.049878929409065416, 0.033426823294056315, 0.08854704895722014, 0.005845796740946493, 0.0828388798981905, 0.020539183768310716, 0.053633446871702156, 0.02279021351465157, 0.022366868731166636, 0.04005340985687716, 0.05241004823307906, 0.060229950584471226, 0.049710744326668124, 0.031269122646855455, 0.020827832565243756, 0.012875672712522959, 0.03859084119488086, 0.02647150008540068, 0.0481280037201941, 0.03770834194230182, 0.0346699096262455, 0.04798690575574126, 0.011410145637845355, 0.03170889476314187, 0.026358949785519923, 0.04762463590928486, 0.04255928039284689, 0.0555114757402667, 0.008247996880007642, 0.010295490717648395, 0.07377195571150098, 0.03780517228213804, 0.04756950493901968, 0.054240318414356024, 0.05332930372761829, 0.024227752716147473, 0.010734372256722833, 0.04120116201894624, 0.053278260930840454, 0.034237570861088376, 0.02944504070494856, 0.06913529522716999, 0.022328763900856887, 0.03049160972503679, 0.08836275884615523, 0.08106757101735898, 0.01559818845375308, 0.06496258984719004, 0.022997792643894042, 0.06525913000638996, 0.04716855859650033, 0.06271583826414176, 0.013973668749843324, 0.026009124271305542, 0.05384943135348814, 0.042456987846110544, 0.05661013928641166, 0.010310181000802134, 0.05743135325610638, 0.04676631285942026, 0.03628771352980818, 0.025996014974745255, 0.027805510110088756, 0.08764755579509906, 0.03116474699761186, 0.02834656714860882, 0.028419187358979667, 0.01403971650038979, 0.050809645360069614, 0.008712469367310405, 0.040423571065600426, 0.030944046697446277, 0.016385475672515373, 0.06820190924086741, 0.037252956735236306, 0.01537883504559951, 0.029392053905342306, 0.02445372862608305, 0.04497240876246776, 0.2711105394576277, 0.552386781999043, 1.6724959973778044, 3.933760847364153, 7.579169716153826, 13.962108033043997, 23.72431836809431, 30.04060956409999, 35.793530396052766, 42.09351069586617, 48.01498787743704, 50.64142778941563, 47.97276367459978, 50.432849815913606, 44.81826066970825, 54.55328791482108, 46.24901287896292, 43.04338502883911, 43.65806436538696, 42.978679929460796, 42.216215882982524, 42.09624481201172, 36.75395209448678, 40.05301931926182, 33.17857585634504, 35.33141613006592, 37.37438106536865, 36.51271063940865, 63.11341299329485, 46.808245590754915, 36.06882149832589, 35.5655426297869, 28.57304232461112, 41.30969483511788, 42.13257694244385, 36.354663440159385, 49.20361621039254, 40.05245304107666, 41.47141415732247, 35.458463941301616, 29.515082563672745, 19.412009239196777, 10.699392914772034, 6.9777006421770364, 3.0495441683701108, 0.7123099405850682, 0.10019894050700323, 0.08798747469804116, 0.05875334981828928, 0.13249856446470532, 0.04304872466517346, 0.06085071513163192, 0.06774738577327558, 0.024885183599378382, 0.033775827780898125, 0.029686093662998507, 0.060929051999534876, 0.05300748135362353, 0.013370455359108746, 0.021187261046309556, 0.02005133405327797, 0.034478430436658006, 0.06800815356629235, 0.027999394706317356, 0.012347787735052407, 0.04071730887517333, 0.013575651134098215, 0.06816473909254585, 0.02593134210578033, 0.03673334479598062, 0.09334644928042378, 0.011055603457082595, 0.055316885467618704, 0.024854532476248484, 0.03872539129640375, 0.07728072136108365, 0.030944966112396548, 0.02906194661876985, 0.09587489467646394, 0.04443939575659377, 0.07971922015505177, 0.03149641491472721, 0.09207786020955869, 0.012401436106301844, 0.02115071175753006, 0.018732687757749642, 0.08104566112160683, 0.050664286195699654, 0.025343564538551227, 0.02549423323944211, 0.024721619340458086, 0.05911857129207679, 0.07800543747310128, 0.019471661586846625, 0.021323415883151547, 0.030915738216468265, 0.0287869092343109, 0.030281474215111563, 0.02810230471992067, 0.03307600711871471, 0.03345613261418683, 0.023672780620732477, 0.03261714441967862, 0.061187852040997574, 0.020632573935602392, 0.02514258585870266, 0.042747126027409516, 0.0667722359565752, 0.11011304959122624, 0.14404029585421085, 0.08077795870069947, 0.1607210479144539, 0.1468911471643618, 0.12122701214892523, 0.21034303307533264, 0.18998426837580545, 0.13282100430556706, 0.1349540605608906, 0.1251383458397218, 0.16979690162198885, 0.17202104441821575, 0.09960884574268546, 0.1280954693044935, 0.12605029690478528, 0.1842638381889888, 0.1580488005919116, 0.14275304707033293, 0.17671331763267517, 0.10526949020900897, 0.12691732895161423, 0.150043607290302, 0.13852638458567007, 0.18280015672956193, 0.0841804046982101, 0.12358646839857101, 0.11271728056349925, 0.1831051039376429, 0.14039599283465318, 0.18622173741459846, 0.049735907797834704, 0.14016240036913327, 0.23216447500245913, 0.2050906970564808, 0.13723115622997284, 0.20524002904338495, 0.18260720851165907, 0.08935118759317057, 0.12093304363744599, 0.1113607669249177, 0.1163854883717639, 0.10578960087150335, 0.11100471245923213, 0.07873142244560377, 0.1689701745552676, 0.261345986276865, 0.10083825620157377, 0.11988501915974276, 0.15843236286725315, 0.08263014895575387, 0.09537982195615768, 0.2726533109588282, 0.1272761518401759, 0.1355069037526846, 0.15570915756481035, 0.09198129789105483, 0.13630450809640543, 0.23958889661090715, 0.10020103718021087, 0.2504899145237037, 0.13525713501232012, 0.15022975658731802, 0.09887162423027412, 0.12399608641862869, 0.1105931606143713, 0.0988731441487159, 0.1283156674887453, 0.2605648567633969, 0.6938839150326592, 1.5832450836896896, 3.8120700972420827, 7.9662903376988, 14.552400061062404, 24.751435824802943, 32.85178470611572, 41.167420046670095, 47.76620067868914, 54.85470424379621, 59.05374731336321, 55.6688802582877, 60.56432042803083, 53.43701812199184, 62.37860625130789, 56.265306677137104, 53.506847517830984, 54.18099301201956, 51.97015265056065, 51.4491662979126, 51.56631987435477, 47.95804738998413, 49.584481716156006, 42.39910289219448, 46.714184352329795, 47.345268385750906, 44.12573719024658, 67.13961614881242, 57.56764922823225, 44.3128730228969, 41.8200226511274, 36.50256279536656, 48.84822627476284, 49.68774931771414, 46.85443721498762, 56.951938084193635, 46.29289422716413, 47.32852322714669, 40.25481237683977, 33.49039363861084, 22.684617723737443, 13.713233981813703, 8.078471609524318, 3.3812168623719896, 0.7788357394082206, 0.16315202175506524, 0.1543179979281766, 0.10238035595310585, 0.2866045337702547, 0.14285561442375183, 0.16478370848510945, 0.09913261593984705, 0.1921623929270676, 0.15972641057201795, 0.14284330579851354, 0.15388191704239162, 0.09582455416343041, 0.10189763935548918, 0.1553045335624899, 0.19159749895334244, 0.1196307720882552, 0.2030239472431796, 0.1793304407703025, 0.14321606579635823, 0.07453891741377966, 0.13464524570320333, 0.09907278272190265, 0.15759494208863803, 0.17024029711527483, 0.21907390600868634, 0.10078917776367494, 0.15633190343422548, 0.07412965223193169, 0.052034119476697276, 0.14832652014281067, 0.10122257165078606, 0.13002671567457064, 0.14616603750203336, 0.2166080961802176, 0.2523455449513027, 0.16128643043339252, 0.1207555253058672, 0.1569657094244446, 0.12333192277167525, 0.17359331862202712, 0.20228903953518185, 0.1506857592612505, 0.22976607084274292, 0.18408280504601343, 0.11515814065933228, 0.18242097779044084, 0.1965982070458787, 0.1022404148908598, 0.14181068406573363, 0.0887311151517289, 0.0724520558225257, 0.12770886719226837, 0.12348368391394615, 0.10936372979943242, 0.08577173216534512, 0.15893567300268582, 0.09853203780949116, 0.20710076205432415, 0.13136652378099306, 0.08464722322033984, 0.14246662386826106, 0.17801569774746895], [0.02311092478755329, 0.02798158146574029, 0.023841915652155876, 0.049663901661655734, 0.060971290804445744, 0.052988448446350436, 0.08807217622441904, 0.04433061641507915, 0.06265909916588239, 0.04433547133313758, 0.04408764320292643, 0.02230922209231981, 0.016044043636481677, 0.0019274448776351555, 0.02877183218619653, 0.010535852418148091, 0.07701650661017213, 0.030673871016395942, 0.017732094574187483, 0.041472131585968394, 0.007071786535172058, 0.024586241426212446, 0.04962724719994834, 0.014588726817497184, 0.019977151516026685, 0.018297487271151373, 0.008819421753287315, 0.06861534741308008, 0.050037811776357036, 0.027801321852686148, 0.020558795126687204, 0.08580379294497625, 0.003348627568422151, 0.04141352651640773, 0.05204566814271467, 0.05418364716959851, 0.008386960003658064, 0.08410539265189852, 0.02050781000538596, 0.038842967844435146, 0.027392636818279113, 0.01259568880777806, 0.034724457056394646, 0.022426359288926636, 0.03860017444406237, 0.08100398550076143, 0.04400178477434175, 0.03783147569213595, 0.058316257915326526, 0.01872824165703995, 0.04902697441035083, 0.030037164288972105, 0.023329277356554354, 0.022131157540051, 0.05579649776752506, 0.01186918221147997, 0.014762884704396129, 0.024295901380745426, 0.02873483845697982, 0.018337242637893984, 0.035696685779839754, 0.04165957009951983, 0.017597493582538197, 0.06468601218823876, 0.05901482328772545, 0.050859375191586356, 0.004603539917817605, 0.02459255519456097, 0.02538990678398737, 0.050000149690146954, 0.060005572624504566, 0.3194030709564686, 1.1362410868917192, 1.4373202111039842, 4.354532897472382, 8.794421809060232, 13.911926405770437, 18.49453435625349, 25.223388739994594, 31.18273707798549, 37.10502372469221, 44.035511357443674, 40.7442295891898, 48.23864344188145, 48.5858553477696, 51.61401925768171, 50.72232566561018, 49.57733201980591, 47.412249020167756, 48.57057973316738, 42.996766090393066, 47.346546854291645, 48.774735178266255, 49.07046440669468, 43.83140107563564, 41.44999633516584, 44.09311887196132, 44.117395877838135, 38.274144990103586, 37.94378593989781, 36.9850526537214, 35.04726607458932, 38.34491586685181, 39.01571232931954, 34.21947159085955, 23.94773074558803, 19.44115172113691, 16.68377995491028, 9.010896410260882, 4.528947012765067, 1.9957758103098189, 0.7788653235350336, 0.07359345350414515, 0.025206013615908365, 0.06471868364938668, 0.035115724096872976, 0.04522703242089067, 0.03608631415824805, 0.027864252582990696, 0.04109555822131889, 0.0097358121337103, 0.020090504183566997, 0.032256323245487044, 0.0793325434039746, 0.03186418089483466, 0.027822537946381738, 0.04739592889589923, 0.03320152252646429, 0.06661351983036314, 0.04434498778677412, 0.029653802181461027, 0.043787476274051836, 0.03338292207834976, 0.015960458300209472, 0.033725470304489136, 0.02980278472283057, 0.07256178172039134, 0.024646941472643187, 0.01428331820560353, 0.027957233932933638, 0.06466653823320355, 0.03458206648273127, 0.010786736500449479, 0.04581035201304725, 0.039315486060721536, 0.046998446474650075, 0.015403842453711798, 0.04335986689797469, 0.01805515188191618, 0.045290441518383365, 0.06124474720231124, 0.018420590486909662, 0.09765630694372313, 0.02138159008297537, 0.04213068374831762, 0.026051273170326437, 0.07687755620905332, 0.03573020540976098, 0.030866072845778296, 0.021287806365372877, 0.016747465623276572, 0.06633287774665014, 0.08780897249068532, 0.05301432777196169, 0.037864499991493564, 0.05397688058604087, 0.0587527866342238, 0.05177929225776877, 0.02790167378926916, 0.04748109521876488, 0.03184579598850437, 0.04158148768224886, 0.04590282955073884, 0.07771144860557147, 0.02877685334533453, 0.036521221178450754, 0.0415818710545344, 0.015809489347572838, 0.033575134085757394, 0.06660268362611532, 0.038197949063032866, 0.02078200939909688, 0.022604384825431874, 0.0691324793068426, 0.03240058996847697, 0.018814215436577797, 0.08809747200991426, 0.03513249748253396, 0.015923074413357035, 0.02655481909667807, 0.014919673791155219, 0.03168959044186132, 0.03481485149157899, 0.048692439682781696, 0.031019119811909537, 0.0060682273054096314, 0.024996164787028517, 0.06069637555629015, 0.032223492328609736, 0.058650375343859196, 0.023857354020167674, 0.009278555018162089, 0.07718685961195401, 0.05137969280726143, 0.0881660786856498, 0.041280978093189855, 0.030766619968094995, 0.05722456970917327, 0.013648048276081681, 0.03447645589975374, 0.02814576997687774, 0.023253725874902945, 0.02979067965809788, 0.02275748098535197, 0.02352644775861076, 0.016599838455606784, 0.020011400571092963, 0.04380804606314216, 0.047752753498830965, 0.048697908675032, 0.06457347037004572, 0.037742173698331626, 0.026796469165544425, 0.0246074744832835, 0.07302613716040339, 0.032217409262167554, 0.046425281159047566, 0.02482271257654897, 0.060961716675332615, 0.0763934011171971, 0.02106841903046838, 0.05427971415753875, 0.029207112400659492, 0.0066883540296527955, 0.021883831525753652, 0.013835529198071786, 0.03543582299192037, 0.022013036467667137, 0.035075948374079804, 0.02558976079204253, 0.0738741091585585, 0.024698829045519233, 0.00812481393638466, 0.08833071163722447, 0.046070478590471406, 0.031397141848823855, 0.225638230198196, 0.4519703303064619, 1.7308583685329981, 2.4425228323255266, 6.97323295048305, 11.108463764190674, 18.57692435809544, 23.761638879776, 30.543801580156597, 37.610460008893696, 43.55507121767317, 51.02619818278721, 46.25944559914725, 52.99613755089896, 53.11561529976981, 56.21254553113665, 55.502971172332764, 54.58426993233817, 53.10366439819336, 53.57478700365339, 47.76717690059117, 49.164709772382466, 50.839680739811485, 52.3914531980242, 45.13840239388602, 42.82919985907418, 49.89017466136387, 50.53513077327183, 41.342875957489014, 41.29463808877127, 40.15201377868652, 40.16615683691842, 42.573012828826904, 45.19461332048689, 39.33278294972011, 28.550293922424316, 24.500750030790055, 20.79201180594308, 12.285650151116506, 6.713285207748413, 2.8970776753766194, 1.0788717653070177, 0.13050249085894652, 0.015056118701717683, 0.042098032643220255, 0.010992761784499245, 0.08196279619421278, 0.017661482827471833, 0.06039841725890126, 0.061674287010516436, 0.05460434905918581, 0.007416157051920891, 0.014448734865124737, 0.06273649287010942, 0.005580074370040425, 0.03633021017802613, 0.04482798258374844, 0.03877549771485584, 0.06998429859855346, 0.05927437650305884, 0.07575481145509652, 0.024966926713074957, 0.03778469409527523, 0.03834670768784625, 0.022282810116718923, 0.04789160890504718, 0.022794532390045266, 0.04504478809290698, 0.012785966990382543, 0.0781245067981737, 0.0031070833086102667, 0.04109496111050248, 0.01504094326602561, 0.08296516883586134, 0.0319475965973522, 0.04839645252962198, 0.01695674448274076, 0.05584415128188474, 0.03679470132504191, 0.028356824901753237, 0.028720144781150987, 0.008413531434988337, 0.06241674002792154, 0.024410175159573555, 0.00882951241718339, 0.011690575679365014, 0.023041916079819202, 0.05188418020095144, 0.05007067661998527, 0.029566118493676186, 0.03565155302307435, 0.03374830300786665, 0.0334831043811781, 0.043355744797736406, 0.07536075902836663, 0.040599474483834844, 0.04871160829705851, 0.02434899335327957, 0.04627014769773398, 0.07575157484305756, 0.041058635738279135, 0.01668480291430439, 0.07538879609533719, 0.07372135735516037, 0.04680120313007917, 0.07424579707107373, 0.1600387538118022, 0.09845429126705442, 0.12335607861833912, 0.2072594306830849, 0.15086135055337632, 0.16375388231660637, 0.1312788434858833, 0.27664988221866743, 0.23050488691244805, 0.09585582784243993, 0.21189803177756922, 0.09977337691400733, 0.05450786816488419, 0.1026628300813692, 0.08945309676762138, 0.12259826356811182, 0.1341229501579489, 0.17298984314714158, 0.112136156032128, 0.12387069314718246, 0.10394002976162092, 0.17187168528991087, 0.09753462525882892, 0.10332090726920537, 0.07897549149181161, 0.23180042739425386, 0.08206030167639256, 0.1245150842836925, 0.15410556218453816, 0.08068092140768256, 0.21087523523185933, 0.2020710262336901, 0.11841178392725331, 0.09224045077072722, 0.11650003865361214, 0.13325180618890695, 0.10909463638173682, 0.1516884168876069, 0.0908038564292448, 0.13353550168020384, 0.07927640820188181, 0.10692440997809172, 0.13164058407502516, 0.0860501215127962, 0.14940516012055532, 0.1531379712479455, 0.11526609558079924, 0.16370178439787456, 0.16936514978962286, 0.08950797667992966, 0.14766946754285268, 0.14005036066685403, 0.07413366915924208, 0.13487688398786954, 0.16707779467105865, 0.15863909891673497, 0.12422587908804417, 0.052159797732851336, 0.14309695575918469, 0.12534546186881407, 0.1500086220247405, 0.12600801060242312, 0.09757987675922257, 0.1514345905078309, 0.12112668396106788, 0.12155078191842351, 0.09949087564434324, 0.1903873181768826, 0.15545944310724735, 0.0938497187037553, 0.21315338941557066, 0.5177223277943475, 1.4368255862167902, 2.955804935523442, 7.164850805486951, 11.3567750113351, 19.68105912208557, 24.93451738357544, 32.87810795647757, 40.48423147201538, 49.6938533101763, 56.19660288946969, 54.47759076527187, 60.74801690237862, 61.97274807521275, 64.1136965070452, 64.63706956590924, 62.69212981632778, 62.79797172546387, 63.18263789585659, 56.83197396142142, 59.11387702396938, 62.99940000261579, 61.12389360155378, 56.24073089872088, 51.39703048978533, 55.19492973600115, 57.99497038977486, 51.26871463230678, 49.43753426415579, 48.757104124341694, 47.79093279157366, 50.0372645514352, 50.138472012111116, 46.61954641342163, 34.00951439993722, 28.50571080616542, 23.241321291242325, 14.005046163286481, 7.704057506152561, 3.4451101081711903, 1.0361028888395853, 0.23387180481638226, 0.09057857601770333, 0.13038038169699057, 0.08937907538243703, 0.19912041670509747, 0.08349626498030764, 0.10734858935964958, 0.191399217450193, 0.10476577973791532, 0.14121691164161476, 0.11173987122518675, 0.15183282271027565, 0.07464555597731046, 0.1264294758439064, 0.2079467052327735, 0.14258280263415404, 0.12244031418647085, 0.10319854704929249, 0.19738591834902763, 0.08093414389129196, 0.13547155207821301, 0.09014622028917074, 0.18790233294878686, 0.12627949246338435, 0.1318971381655761, 0.14645415704165185, 0.16498169143285069, 0.17066643067768641, 0.12989119866064616, 0.16682528464921884, 0.05515782668122223, 0.14243792183697224, 0.12110547295638494, 0.07937337085604668, 0.09853435161390475, 0.17707002349197865, 0.06324815577162163, 0.14364238934857504, 0.12937701839421475, 0.09667177977306501, 0.192609004676342, 0.06402771108384643, 0.1207111898277487, 0.11654113073434148, 0.10830211426530566, 0.1395758611283132, 0.10558969766965934, 0.11110552240695272, 0.07163735239633492, 0.18029671534895897, 0.25224373755710466, 0.10421448360596385, 0.1916591235037361, 0.17365395251129354, 0.18069121560880116, 0.14343357698193618, 0.12502281846744673, 0.14530756856713975, 0.0760639180828418, 0.1265795813607318, 0.16790106120918477, 0.25559523914541515, 0.15319405895258698, 0.16845961766583578], [0.04707631176071508, 0.07881007143961531, 0.00453703966923058, 0.007061160676780024, 0.026815953298604915, 0.03873696710382189, 0.06194758055997746, 0.054677780118903944, 0.07178492697754077, 0.06207729609949248, 0.03436881988974554, 0.041325537487864494, 0.03346553371687021, 0.02488367385896189, 0.0535618376785091, 0.027524644109819616, 0.039430555421859026, 0.029221083436693465, 0.02941571781411767, 0.0830850252615554, 0.02239233415041651, 0.006987307229012783, 0.09594929604125874, 0.02410892766368176, 0.07401667615132672, 0.05173843766429594, 0.013882240396924317, 0.014887826750054955, 0.01140938907129956, 0.06103793651397739, 0.016738156122820716, 0.030491653829813004, 0.02977748554466026, 0.07405349346143858, 0.03785475283595068, 0.024304513686469624, 0.008761641951943082, 0.02654016952562545, 0.04471122367041452, 0.05668989768517869, 0.034901860037020276, 0.0554715134203434, 0.01459733912322138, 0.05721846289400544, 0.0156983079920922, 0.06183049255715949, 0.0695814455726317, 0.06233309701617275, 0.047383091013346396, 0.01946218923798629, 0.019105569891897694, 0.03407181832673294, 0.03246587521529623, 0.01992720624964152, 0.03061652123661978, 0.037961913871445825, 0.019006400302584683, 0.058426872694066594, 0.013721920383561934, 0.06029401107558182, 0.0378515806847385, 0.037044473458081484, 0.02919578765119825, 0.08158382760094744, 0.04714942730164953, 0.07088755763002805, 0.08805722809795823, 0.014874732720532587, 0.025959241769409606, 0.037030329395617755, 0.009060634167066641, 0.029653981993240968, 0.05239959200844169, 0.09177389687725476, 0.223186818882823, 1.4298894384077616, 2.9285210967063904, 6.112812331744602, 10.075469868523733, 13.299942101751055, 18.031735692705425, 23.234822988510132, 30.529821804591588, 33.24804047175816, 39.21482685634068, 40.14960275377546, 35.98829187665667, 38.98134306498936, 47.316617488861084, 46.05456754139492, 45.50568764550345, 49.18734700339181, 49.64144304820469, 48.27620887756348, 43.41501637867519, 44.44679955073765, 41.82690831593105, 43.87305552618844, 44.41210372107369, 36.48479972566877, 37.73837634495327, 37.301640374319895, 33.12955978938511, 25.316809007099696, 19.811956235340663, 14.068212236676898, 9.178584235055105, 4.468811656747546, 1.7356118048940385, 0.3171413508909089, 0.06549359099673373, 0.05147698115823524, 0.04605884850025177, 0.04271417297422886, 0.02843013043249292, 0.034812079676027806, 0.0625185202807188, 0.04874972500173109, 0.11575512933943953, 0.07657951648746218, 0.07488035623516355, 0.06036337771053825, 0.016114740200074654, 0.02371706860139966, 0.034780744928866625, 0.004019840770134968, 0.024114579860387102, 0.04350982652977109, 0.014737592311576009, 0.05110992085454719, 0.047851738187351396, 0.0831908020856125, 0.033912857927914174, 0.007300582182194505, 0.03828520866643105, 0.026978145220449994, 0.04678916252617325, 0.013519965461455286, 0.02664014487527311, 0.02090618639652218, 0.018813906703144312, 0.010386957238162202, 0.02158031772289957, 0.03170267598969596, 0.004423214571683535, 0.005570387010396059, 0.013098908189151968, 0.011149542389570602, 0.027935732854530215, 0.0338646480148392, 0.020643381302111914, 0.026150751493072937, 0.027109686019165174, 0.0463193889840373, 0.09379296603479556, 0.035974383021571806, 0.04231241238968713, 0.08212512212672404, 0.022619044574509774, 0.0327489362763507, 0.03449712746909686, 0.0508406272690211, 0.06919757117118154, 0.007733630016446114, 0.07880139976207699, 0.08415045416248695, 0.09232319811625139, 0.03865100010963423, 0.04752556301121201, 0.024035825693447675, 0.013150079059414566, 0.0347843208084149, 0.07737169933638402, 0.07149776417229857, 0.0903274230659008, 0.02911718954731311, 0.026465895386146646, 0.07671905042869703, 0.03883685424391713, 0.02107976413598018, 0.04374395843063082, 0.03215866170025297, 0.031927315185644796, 0.014906537353194185, 0.021510353977126733, 0.038021014271570105, 0.0333284289310021, 0.02375300720866237, 0.033055233769118786, 0.018964253099901334, 0.05051246737795217, 0.028869911030467068, 0.012741848643470024, 0.03933675813355616, 0.06809087377041578, 0.0333421387310539, 0.00943892337714455, 0.04633637950090425, 0.055496741352336745, 0.01744714718578117, 0.012321272282861173, 0.018597935792058706, 0.031896183998989205, 0.02945855033716985, 0.020743874034711292, 0.06139538197645119, 0.022629913009170975, 0.047625996371997256, 0.03937385703570076, 0.020083340550107614, 0.017447269322084527, 0.057507471314498355, 0.026987069652282765, 0.04831266363284417, 0.017692312066044127, 0.021454954985529184, 0.02279887840683971, 0.03961978866053479, 0.011907827325298317, 0.04957638082227536, 0.03304385473685605, 0.0420216533488461, 0.026888205403728143, 0.02179714698078377, 0.05799851353679385, 0.09904758871666022, 0.04587784589135221, 0.03642988697226558, 0.025282766104542782, 0.0023122020107361353, 0.02823360463870423, 0.0411280362999865, 0.025500721730557934, 0.04747190785461238, 0.023589626154197112, 0.03128941762926323, 0.0759906702275787, 0.015521768447277802, 0.06345639816884484, 0.0379982731704201, 0.009136322203890553, 0.044085220832909854, 0.06634115587387766, 0.028918025948639427, 0.05462756174217377, 0.10595732794276305, 0.05961178482643195, 0.04280804490138378, 0.035628723712371926, 0.2655781991779804, 0.503393893795354, 2.545517065695354, 4.255642226764134, 8.186624663216726, 13.382194876670837, 17.297780105045863, 23.39502239227295, 29.48576463971819, 34.4755266053336, 39.07678352083479, 43.94608456747872, 45.68612541471209, 42.62068789345877, 46.11508287702288, 52.49623203277588, 50.58271203722273, 50.95253338132586, 55.054214818137034, 55.09599781036377, 53.37311553955078, 49.10123103005545, 51.22056361607143, 48.823681763240266, 50.42484201703753, 48.90841851915632, 41.4271992955889, 43.214369773864746, 41.86617258616856, 39.08993993486677, 30.683397838047572, 24.086534908839635, 17.432903460093907, 11.455054674829755, 6.582228285925729, 2.37530118227005, 0.5586851068905422, 0.1546779064727681, 0.026695240222449814, 0.04520475272355335, 0.05148915746914489, 0.032569921775055785, 0.03650847489812544, 0.02895098239449518, 0.04364326722653849, 0.08368755078741483, 0.05974634510598012, 0.09431193675845861, 0.044969589449465275, 0.029400352388620377, 0.07040243901844535, 0.04933221338848982, 0.026300019019150307, 0.0068256471089885706, 0.03608157459114279, 0.02565988738621984, 0.02247245217274342, 0.02301772461006684, 0.12147870792874269, 0.06555702045027699, 0.022668167117184827, 0.04043693481279271, 0.03260953464944448, 0.029834553732403686, 0.003795461113830762, 0.03375078983871, 0.06757851197783436, 0.0174168607752238, 0.02842757065913507, 0.05052268611533301, 0.05495959606819919, 0.014894473000562616, 0.030233495003942932, 0.04604637363393392, 0.003878211003861257, 0.009489066266853894, 0.01972988317720592, 0.03337343276611396, 0.022508979409134815, 0.01944974490574428, 0.09009579835193497, 0.04776490266833987, 0.030658115433262925, 0.01694062418703522, 0.06452564722193138, 0.008989608513989618, 0.011295805701852908, 0.040531943286103864, 0.028313354555783526, 0.0820624390617013, 0.027645458966227512, 0.057748799079230854, 0.033560952703867636, 0.06393984079893146, 0.0530314913152584, 0.06132087204605341, 0.04683011211454868, 0.07585590638752494, 0.057369090882795196, 0.02245037433957415, 0.06526513504130499, 0.04976704576984048, 0.06562137271144561, 0.19715867697128228, 0.08490768567259822, 0.1868995531861271, 0.13153059354850224, 0.09900358572070088, 0.12834455950983933, 0.1358140901263271, 0.07631436535822493, 0.1372224981231349, 0.10464006076966013, 0.12567096868796007, 0.12865137947457178, 0.12967070192098618, 0.14987827544765814, 0.1399395830397095, 0.11184653693011828, 0.10129740727799279, 0.1250911062317235, 0.24946310105068342, 0.14477164803871087, 0.1384966376104525, 0.08029315221522536, 0.1984004910503115, 0.12371426368398325, 0.11523454370243208, 0.10786544983940465, 0.08763860591820308, 0.11007775219955615, 0.06758226427648749, 0.11819492413529328, 0.14921899725283894, 0.15952071946646484, 0.08616260904818773, 0.1225538466657911, 0.12006655441863195, 0.21224696162555898, 0.10060599366469042, 0.10770116972603969, 0.15236365422606468, 0.11194534519953386, 0.10497945720063788, 0.18265433955405438, 0.06501354104174034, 0.16236672603658267, 0.05626062250563076, 0.1302599281604801, 0.24925715210182325, 0.14351335912942886, 0.12266120447644166, 0.26560816328440395, 0.09419512695499829, 0.13437487663967268, 0.07060165689992053, 0.11590676834540707, 0.07767288746046168, 0.1639063355645963, 0.10515291789280516, 0.09438908619007894, 0.09824904799461365, 0.16563769908887999, 0.22609169515115873, 0.13757847116461822, 0.09983435685613326, 0.12526390195957252, 0.09130234218069486, 0.16682316761996063, 0.20372695023460047, 0.12247448521000998, 0.10049131446118865, 0.22510636730917863, 0.11822186197553362, 0.10695967344301087, 0.1376931028706687, 0.38051334608878407, 0.5929194784590176, 2.24259797164372, 4.4184289659772595, 8.62440025806427, 13.840022104127065, 18.85766111101423, 25.783113036836895, 33.07239348547799, 38.253991740090505, 42.37655598776681, 48.02328750065395, 51.507096903664724, 48.47104331425258, 53.67056792122977, 60.65547384534563, 59.575543131147114, 59.72772952488491, 62.87713255201067, 61.134440967014854, 61.69459778921944, 56.05521747044155, 59.04355430603027, 55.501668385096956, 57.47864280428205, 55.57866137368338, 49.15976960318429, 49.48085975646973, 47.54776668548584, 44.290013449532644, 36.76098019736153, 26.602670431137085, 19.908911398478917, 11.843414681298391, 6.961579952921186, 3.041935456650598, 0.8048398068972996, 0.3082018962928227, 0.11260367344532694, 0.11026542141501393, 0.17084268693413052, 0.17824011641953671, 0.12163170400474753, 0.1391999934400831, 0.23241015896201134, 0.21849192652319158, 0.1360838892204421, 0.14261525017874582, 0.12670525961688586, 0.131211519241333, 0.19435218828065054, 0.19791856833866664, 0.1709459192518677, 0.1262234861829451, 0.1563649345189333, 0.12400910072028637, 0.08789218124002218, 0.11213201018316404, 0.1892003704394613, 0.21368742361664772, 0.06227094320846455, 0.14495991436498507, 0.10461039521864482, 0.10199737721788031, 0.1467207127383777, 0.11746897308954171, 0.14328045876962797, 0.15249372938913958, 0.11491948632257325, 0.09603844197200877, 0.05704811667757375, 0.0659313750054155, 0.1075462330398815, 0.15968979682241166, 0.08733026603502886, 0.15277036811624253, 0.10232804768851825, 0.11978417528527123, 0.09889096247830562, 0.11451978848448821, 0.1385035722383431, 0.13339138084224292, 0.1096483888104558, 0.10701841421957527, 0.20313175288694246, 0.11265372218830244, 0.1314873844385147, 0.14378446101077966, 0.17250258715025016, 0.2781847555722509, 0.10624033811369113, 0.1064659645780921, 0.14324388573212282, 0.1743223773581641, 0.13225463112550123, 0.198256858757564, 0.1130829295143485, 0.22896914503404073, 0.131629008267607, 0.11625149127628122, 0.1906868778169155, 0.22554547446114676, 0.14208920912018844], [0.053780061325856617, 0.046717811176287274, 0.022147004725411534, 0.02870870807341167, 0.010212659403415663, 0.007713742155049528, 0.039724408582385094, 0.044540117494761944, 0.015020806043009673, 0.03355177551774042, 0.07849888849471297, 0.06390905566513538, 0.04678689282653587, 0.0326788028968232, 0.045690353094999275, 0.03180342147658978, 0.07058104300605399, 0.025276873027905822, 0.024746029637753963, 0.037580970741276226, 0.0753342147384371, 0.035541467501648834, 0.07965980084346873, 0.033554574474692345, 0.05622986790591052, 0.01922261039726436, 0.021206088696739504, 0.009134919332739497, 0.028406939801893065, 0.0771162783993142, 0.06447479780763388, 0.0573814877175859, 0.02283633523620665, 0.057964159308799675, 0.01582671226268368, 0.030398429903600897, 0.03725731971540621, 0.07832709021334137, 0.032624733833862204, 0.017329429841733406, 0.02286573446222714, 0.047765811905264854, 0.031722075305879116, 0.005379129616942788, 0.029867527141634907, 0.04851076193153858, 0.0680250490882567, 0.054106803078736575, 0.059939754727695665, 0.07913350872695446, 0.0755443706044129, 0.020695543681670512, 0.032145928990628035, 0.08053584383534533, 0.08775116809244667, 0.0627956882651363, 0.016787436424887607, 0.0213768064110939, 0.05113731331325003, 0.04309668012761644, 0.034463075189185996, 0.013011678271660847, 0.04173378825985959, 0.022891401745645062, 0.05181761591562203, 0.030963232275098562, 0.026116865454241633, 0.018319524392219524, 0.025237049807661345, 0.023023093518401896, 0.017898400114583116, 0.04574965027027896, 0.048887576176119704, 0.0033080632607119954, 0.027171500559364046, 0.02518766263632902, 0.2662799943770681, 0.6982869559100696, 1.4252300198589052, 2.685904549700873, 4.400077036448887, 6.426484414509364, 9.683502878461566, 11.754011341503688, 16.28385727746146, 18.260060446602957, 20.76195910998753, 18.938541616712296, 22.10648591177804, 23.958686317716325, 25.78117275238037, 25.430055958884104, 27.635455880846294, 31.055800437927246, 31.0076459475926, 30.609441212245397, 27.39787265232631, 26.26888244492667, 26.506012303488596, 23.46573073523385, 25.184935671942576, 22.779406785964966, 17.859715666089738, 14.89561414718628, 9.075756107057844, 3.3897069096565247, 1.112870712365423, 0.18928624583142145, 0.06515176541038922, 0.019723369241026894, 0.03394544796485986, 0.02960950063009347, 0.05277193470724991, 0.04380269920719521, 0.03615937541638102, 0.01905858134185629, 0.030687679204025438, 0.07390189516757216, 0.03714297299406358, 0.014812609446900231, 0.01794174832424947, 0.032971604328070364, 0.029915794730186462, 0.03640445887244173, 0.05219620792195201, 0.02627109476764287, 0.020236511348879764, 0.06710779187934739, 0.050252741136189015, 0.055968696384557655, 0.029535967790122544, 0.06401674595794507, 0.01803205963889403, 0.023467807065961615, 0.029380573092826774, 0.011375765116619212, 0.026668607722967863, 0.008885620477875429, 0.04895912090848599, 0.02116680491183485, 0.02557760144450835, 0.011485703904846949, 0.03896122971283538, 0.04578519871990595, 0.05761407595127821, 0.02015152992680669, 0.02864642195137484, 0.026780192806784595, 0.05905113169657333, 0.03527675402749862, 0.037359697079019885, 0.03375554297651563, 0.03644537453406623, 0.06655794102698565, 0.03004922524892858, 0.0603236426998462, 0.08718202648950474, 0.014663489502189415, 0.01161162558543895, 0.0352809304105384, 0.01438497462575989, 0.012737368616009397, 0.024755963390426974, 0.029509796694453274, 0.03732607227617076, 0.020805245830810497, 0.05963372864893504, 0.027386290819517205, 0.05367658473551273, 0.027269026397594383, 0.024366333315681134, 0.03527471502976758, 0.03403254471985357, 0.04375523228996566, 0.07354690600186586, 0.06183562906725066, 0.012116673618688114, 0.016371714982337186, 0.12982995408986295, 0.07566865107842854, 0.03753660133640681, 0.002555199183656701, 0.05329247623948114, 0.05917189735919237, 0.05788538817848478, 0.018209971520783644, 0.038968456110783985, 0.04572960634582809, 0.04041611057307039, 0.05452990019693971, 0.041056674772075245, 0.04705923642697079, 0.07210391986050776, 0.024402190498741608, 0.01234628223547978, 0.007646994665265083, 0.03930333349853754, 0.05584444644461785, 0.06421725984130587, 0.08395701739937067, 0.090216272244496, 0.03073051172707762, 0.04260508829195585, 0.008728807642390686, 0.01613822260073253, 0.052620916560824425, 0.029598192844007696, 0.018062739599762217, 0.07372074667364359, 0.040353247696267705, 0.005161394090724311, 0.07333147791879517, 0.03650959108823112, 0.03981058592242854, 0.02080572928701128, 0.08915539631353957, 0.029192622285336256, 0.02189948023962123, 0.03978494069139872, 0.06499665909047637, 0.04473275697923132, 0.027185291783618074, 0.01817281324682491, 0.0113003917504102, 0.015253514716667789, 0.013849665627016552, 0.022155769701514925, 0.03304410240213786, 0.04247380533654775, 0.048674546714339934, 0.07829269527324609, 0.017970217957294414, 0.039308171453220506, 0.04825408909735935, 0.023775617691821287, 0.02963980400402631, 0.0778750026864665, 0.030002243484237363, 0.08379180090767996, 0.009377629612572491, 0.02518853116115289, 0.018563109982226576, 0.012295592276911651, 0.023454824994717325, 0.01589886598022921, 0.0461424202658236, 0.05109778864841376, 0.033570082392543554, 0.005573779685489301, 0.07577482823814664, 0.10084751820457832, 0.1401721169906003, 0.41540964213865145, 1.1531108788081577, 2.1660105841500417, 4.008867400033133, 6.311917304992676, 8.765883820397512, 13.07391025338854, 15.103764806474958, 19.965113639831543, 22.82100565092904, 26.06388279369899, 24.723330361502512, 27.248517649514334, 29.276738507407053, 32.25500045503889, 31.566951615469797, 32.861029284340994, 35.90954099382673, 36.14816297803606, 35.58664778300694, 33.04897805622646, 32.032838753291536, 32.41727563313076, 29.227583476475306, 30.23631599971226, 27.43478843144008, 21.97833333696638, 17.608611243111746, 11.108667867524282, 4.601569150175367, 1.7906263385500227, 0.3028252933706556, 0.12104565330914088, 0.05256961252806442, 0.025574022172284976, 0.012387770411026264, 0.05479676801977413, 0.03249513025262526, 0.05147580050730279, 0.03231367302526321, 0.03195493156090379, 0.010469096446675914, 0.0026495887058055295, 0.03489515950371112, 0.019382093268047487, 0.026436971134639213, 0.04181340077359762, 0.06843901651778392, 0.02438297608335103, 0.06383532605000905, 0.025353578019088933, 0.02325984456443361, 0.02456349353971226, 0.02945812964545829, 0.025072111515328288, 0.02425649037052478, 0.004326324435948793, 0.03914382687902876, 0.07327822649053164, 0.06731295372758593, 0.010595172493984657, 0.005319471969934446, 0.011376767652109265, 0.01719351758116058, 0.06550141450549875, 0.1172091756016016, 0.006603158020880073, 0.006019334616472146, 0.04247848383550133, 0.04118516894855669, 0.0862001252493688, 0.04299099151311176, 0.0495133584897433, 0.022914317569562366, 0.04082106705754995, 0.034739120198147636, 0.08953012406293835, 0.032251817772963216, 0.05334189394488931, 0.03476977641029017, 0.05785976669618061, 0.03236575737329466, 0.029961287110511745, 0.02057071529062731, 0.023892410531906143, 0.06940805951931647, 0.019738822876076614, 0.03890738117375544, 0.058429044006126266, 0.07901816455913441, 0.04582922885726605, 0.008682796182776136, 0.07029761892876454, 0.09162649192980357, 0.03276893948870046, 0.05195654935336538, 0.04396576813555189, 0.03742115878100906, 0.055594843945332935, 0.0055968604782330135, 0.12987659658704484, 0.21402654184826783, 0.1715170286063637, 0.21216160192021302, 0.11237765343061515, 0.12429951370826789, 0.09788316834185805, 0.11238582977758986, 0.14662094094923564, 0.13151877346847737, 0.16671978602451937, 0.25444186532071655, 0.1452845526593072, 0.09382604461695467, 0.16905370221606322, 0.15760411588209017, 0.18302510465894425, 0.16702176124921866, 0.08986150699534587, 0.09138247716639723, 0.12564086887453282, 0.19527467020920344, 0.14586408941873483, 0.16515938618353435, 0.21147086684192928, 0.10311524330505303, 0.0960572509627257, 0.14991450921765395, 0.06698306357221943, 0.13684753967182978, 0.18297128326126508, 0.1203617307224444, 0.1584195385554007, 0.11315564132694687, 0.24257268650191172, 0.08647214993834496, 0.16704481786915235, 0.1985087309564863, 0.12064465268382005, 0.1353071430431945, 0.13494962294186863, 0.07744960872722523, 0.06612562601055418, 0.07837329844811133, 0.11382388975471258, 0.18017943735633576, 0.3143629128379481, 0.08543422206171922, 0.15126180835068226, 0.08713401335158519, 0.10138391370752028, 0.18802129370825632, 0.1312881258449384, 0.23160034098795482, 0.27177680656313896, 0.08514941377299172, 0.10506063034491879, 0.12046933280570166, 0.11969209808324065, 0.1525907056140048, 0.17604201579732554, 0.0704695868438908, 0.17968874797224998, 0.08821303330894027, 0.12817997405571596, 0.05433386464470199, 0.13222324209553854, 0.09724777457969529, 0.12805158165948732, 0.14193463884294033, 0.09263626060315541, 0.1785072556563786, 0.19393613774861607, 0.2050383005823408, 0.08569049116756235, 0.14962763818246977, 0.5451646723917553, 1.0551678772483553, 2.2130253527845656, 4.418087201459067, 7.390717199870518, 9.9172237770898, 13.245395268712725, 17.17058638163975, 21.385507822036743, 24.817518404551915, 28.520244700568064, 29.28929042816162, 31.165606294359478, 32.67140599659511, 36.35756778717041, 36.311164242880686, 37.4838673046657, 40.538413524627686, 40.98419604982649, 40.10643012183053, 38.616027627672466, 36.30295147214617, 36.40757744652884, 33.10100964137486, 34.340088844299316, 29.870396069117955, 25.003848246165685, 19.152631248746598, 12.110449586595808, 5.419769040175846, 1.8210697621107101, 0.39561927265354563, 0.26878590562513893, 0.1218886109335082, 0.11479262741548674, 0.07943356369755097, 0.18824690660195692, 0.08580122129725558, 0.09831579548439809, 0.13238086578037056, 0.13118764837937696, 0.12890824569123133, 0.15834248411868299, 0.11613771452435426, 0.13145685036267551, 0.15518049736108097, 0.07429906885538783, 0.11285944043525628, 0.11933646430926663, 0.11202067615730421, 0.08111632375844888, 0.18195909900324686, 0.13053439557552338, 0.20068752047206673, 0.15977951272257737, 0.14668646029063634, 0.12780671194195747, 0.1974616428571088, 0.14380259146647795, 0.12487481640917913, 0.06545554553823811, 0.12896605687482016, 0.14713315346411296, 0.06938877555408648, 0.11242639938635485, 0.165461374978934, 0.0754358796402812, 0.1018485269908394, 0.153709935556565, 0.07558010225849492, 0.25313644536903923, 0.1164133083075285, 0.12470877889011588, 0.13783336962972367, 0.14920472087604658, 0.09681783443582909, 0.24571009672113828, 0.12154874631336757, 0.13072070772094385, 0.11784709351403372, 0.18052669800817966, 0.11002918266292129, 0.10553521130766187, 0.10461609491280147, 0.1130085281495537, 0.14541469567588397, 0.11047747717904192, 0.12053029239177704, 0.22785949600594385, 0.15238942498607294, 0.18841782957315445, 0.14495373969631536, 0.17322731683296816, 0.1876391020736524, 0.1186832386468138, 0.16875845805874892, 0.12574410119227, 0.08948356977530889, 0.12854662723839283, 0.16956010647118092], [0.02229580745500113, 0.03770457607294832, 0.033429031925542016, 0.03124399310243981, 0.026418935673843538, 0.02219811707202877, 0.029094702896795104, 0.0576876291472997, 0.011621866375207901, 0.006844942524496998, 0.028894440071391206, 0.053197484729545455, 0.019646918700475777, 0.021982731397396753, 0.03919891035184264, 0.10489597025194339, 0.018413740675896406, 0.03504137022952948, 0.06774574371853045, 0.056263886259070466, 0.03798815282061696, 0.036051305143960884, 0.054052384570240974, 0.019780696968414953, 0.01448194236893739, 0.022512697781037008, 0.07623837622148649, 0.08817041452441897, 0.037695873861334155, 0.06265484475131546, 0.05186072324535676, 0.02682011611094432, 0.05323725366698844, 0.025948397083474056, 0.01684006190459643, 0.06210110589329686, 0.022341206536761353, 0.0744049067475966, 0.06029107980430126, 0.03917881553726537, 0.03850324232397335, 0.0053241127253776145, 0.041040562958057435, 0.04614475103361266, 0.03456449581842337, 0.044615251677376885, 0.04155876015179923, 0.014239193073340824, 0.015623275589730059, 0.05359899764880538, 0.02467431696797056, 0.013540489449431854, 0.0178048555805747, 0.050729656259396246, 0.03134325599031789, 0.03602849279663392, 0.01946346488382135, 0.0746117988601327, 0.01509028802891927, 0.05513843075771417, 0.03660376835614443, 0.057879898830183914, 0.06526708922215871, 0.0475707975482302, 0.01797286594020469, 0.04169710665675146, 0.03312473611107894, 0.0662109110770481, 0.0034916370932478458, 0.06268965359777212, 0.03657916467636824, 0.05089887610769697, 0.012343093969060906, 0.07037706859409809, 0.03202381304332188, 0.03733654207150851, 0.059550465616796694, 0.06213895457663706, 0.0869894175391112, 0.26736005927835194, 0.44972022676042145, 0.8224649982792991, 0.4915744108813149, 2.0189769310610632, 2.4117444838796342, 3.640069612434932, 4.281961568764277, 4.660657065255301, 5.14861124753952, 6.300647326878138, 7.32981276512146, 8.53600093296596, 8.590409670557294, 9.913471749850682, 10.646983521325247, 14.273781640189034, 10.258509738104683, 11.762398685727801, 13.016996690205165, 11.201334255082266, 8.014651536941528, 6.164523431232997, 5.369419353348868, 2.7055534039224898, 0.8736623653343746, 0.1710331245724644, 0.02669438187565122, 0.052126922711197815, 0.03759594940181289, 0.04922561892973525, 0.0978311314912779, 0.03838660215426769, 0.0774158855367984, 0.02645865881017276, 0.027771315337823968, 0.0374647139438561, 0.024086736175896864, 0.02424741835732545, 0.03223091550171375, 0.02767503121867776, 0.02653446643879371, 0.09578447309987885, 0.0131175170120384, 0.03798490942322782, 0.03601846744173339, 0.10468816211713211, 0.014239528948175055, 0.05015861475840211, 0.0121816433467237, 0.01731267341944788, 0.0444093604039933, 0.022306151721360426, 0.06542794951902968, 0.016568261132176434, 0.02483322817300047, 0.0353588940841811, 0.025476538742493306, 0.005765338178857097, 0.026481203136167357, 0.058951468473034244, 0.033237420421625884, 0.02641470161532717, 0.04295275606481092, 0.03201852386285152, 0.05021709769165941, 0.057760625944605896, 0.047676092612424066, 0.04314072383567691, 0.015574909613600798, 0.03406479548928993, 0.008529138535128107, 0.02923294422881944, 0.07203614778284516, 0.07768853447799172, 0.010597468486854007, 0.030599001462438276, 0.061308217367955616, 0.0081188954146845, 0.02878087366532002, 0.05657761710296784, 0.03828649449029139, 0.05151516571640968, 0.02992776069524033, 0.047343617238636525, 0.028508309541004043, 0.054610452481678555, 0.04919568196471248, 0.05738631888691868, 0.01894185465893575, 0.048826552129217556, 0.06453752837010793, 0.03547820428918515, 0.018834203381889632, 0.0826391191887004, 0.05957711847232921, 0.01977210841141641, 0.03767208442358034, 0.034119617726121626, 0.04501730063930154, 0.048362305254808495, 0.07104918467147009, 0.104870959451156, 0.00887357902580074, 0.016500122645603757, 0.058270361806665144, 0.015720506265227283, 0.04889896199373262, 0.07402289831744772, 0.07183709274977446, 0.05503871664404869, 0.020541002242160693, 0.04003097748916064, 0.0664238692926509, 0.038824932383639474, 0.007805670079376016, 0.026308193669787476, 0.04054970054754189, 0.016042544074090462, 0.11484015200819288, 0.036433707124420574, 0.039085452511374436, 0.02197106398775109, 0.033165641594678164, 0.006514823787646102, 0.010864110696794731, 0.05589426787836211, 0.02336332624379013, 0.036827902043504376, 0.03966564405709505, 0.054166405594774654, 0.003693476876443518, 0.0252651598171464, 0.024208697756486278, 0.03852586468149509, 0.01942597412770348, 0.03828034017767225, 0.009776588695655977, 0.02123097057587334, 0.028193097794428468, 0.05687730905732938, 0.04162284778431058, 0.06293180917522737, 0.06588289367833308, 0.02059345639177731, 0.04982872460303562, 0.022353063936212232, 0.019160522746720483, 0.02160408510826528, 0.03658793813415936, 0.05902290463979755, 0.05437663609960249, 0.048520705862236876, 0.07327634694853, 0.07299639018518583, 0.018189237186951295, 0.04427929202626858, 0.02346378504963858, 0.030572535204035894, 0.029491384646722248, 0.019305588444694877, 0.08088167956365006, 0.04572349953066025, 0.03904233839628952, 0.03813103872484394, 0.06127958997551884, 0.035380827728658915, 0.04736097077173846, 0.07063281522797686, 0.051087047439068556, 0.02366425482822316, 0.028927800245583057, 0.0584889722189733, 0.04285541003836053, 0.043207294906356504, 0.1440359125179904, 0.5095502148781503, 0.7799164014203208, 1.012753576040268, 1.2273231766053607, 2.848513675587518, 3.6313494060720717, 4.863544029848916, 5.904256505625589, 6.135252841881343, 6.85176237140383, 8.449694752693176, 10.014409099306379, 10.778703127588544, 11.643541932106018, 12.859810199056353, 14.50067593370165, 17.069599526269094, 13.814355458532061, 14.263976863452367, 15.628900970731463, 13.771148954119, 10.449714609554835, 8.380079882485525, 6.930111995765141, 3.826853258269174, 1.2684210113116672, 0.20076367924255983, 0.12622712313064507, 0.05657786816092474, 0.03674492060339876, 0.09411883247750145, 0.010906917774783713, 0.0325117272191814, 0.0374414707267923, 0.03217014251276851, 0.03184148050578577, 0.026472877511488538, 0.04117566267294543, 0.04430834011041692, 0.05026888348428266, 0.004911867502544607, 0.0137291289699663, 0.015083428039880735, 0.027829133306763003, 0.052058719763798375, 0.04375793285933988, 0.1331376630280699, 0.0022404467204718715, 0.023709896486252546, 0.05442968396736043, 0.042711954164717875, 0.06418762821704149, 0.0077875353828338635, 0.032966505137405226, 0.029064294349934374, 0.005368879497317331, 0.026824019383639097, 0.027276836335659027, 0.028365389710026126, 0.019711922355262295, 0.21056944664035523, 0.031207674515566657, 0.04131368348108871, 0.02740841106112514, 0.005535759672056884, 0.018126605012054955, 0.041728105529078414, 0.0205707695734288, 0.023545027743758898, 0.02899328905290791, 0.006520313560031354, 0.019700831700382487, 0.02472420286254159, 0.061070275492966175, 0.07365490842078413, 0.016278394364884922, 0.01485824431957943, 0.06445503886789083, 0.08101766476673739, 0.06800398057592766, 0.05694719137889998, 0.048860411026648114, 0.06211350272808756, 0.05785710005355733, 0.018010032695851157, 0.029468131251633167, 0.11694162924374853, 0.006458627941486026, 0.03768678488475936, 0.05374852980354002, 0.016530897601374557, 0.017719828357387866, 0.027579332335985134, 0.06116928732288735, 0.03304891321542008, 0.04470237557377134, 0.022569765968780433, 0.13417948569570268, 0.13397407957485744, 0.14129357252802166, 0.12303476514560835, 0.0904134273795145, 0.18505461647042207, 0.10066078536744628, 0.11085512262902089, 0.09909201240433113, 0.10907400213181973, 0.10571504344365426, 0.17043709941208363, 0.11717404105833598, 0.10397582926920482, 0.10132125099854809, 0.17007139617843287, 0.2147673528109278, 0.1619760255728449, 0.1307207891451461, 0.12006343315754618, 0.1746489562626396, 0.13000637319471153, 0.15713367398296083, 0.1619883749101843, 0.13336556937013352, 0.12210172521216528, 0.15916056664926664, 0.14742866903543472, 0.16833794276629174, 0.1352792823953288, 0.09731128545744078, 0.12082325667142868, 0.21143664153558867, 0.1605230513960123, 0.07855592614838056, 0.19602304005197116, 0.0967824352639062, 0.1854201161435672, 0.14715995559734957, 0.16360726446977683, 0.11623201732124601, 0.09400672492172037, 0.11825804146272795, 0.1504922682153327, 0.12020618335476943, 0.15023298641400679, 0.14120800926217011, 0.09670793211885861, 0.10055584992681231, 0.16478054651192256, 0.10419692311968122, 0.12139014553810869, 0.1337879981313433, 0.12227148110313074, 0.14747954559113297, 0.08646423143467732, 0.19536116985338076, 0.17674242678497518, 0.10093982610851526, 0.16049151308834553, 0.12943841224270208, 0.14850500199411595, 0.09966226680470364, 0.09633694309741259, 0.17979037894734315, 0.12617840431630611, 0.19674858397671155, 0.12203657227967467, 0.09164044939513717, 0.13843878571476254, 0.13335005805960723, 0.14988464010613306, 0.1146168868456568, 0.1821071282029152, 0.08475992110158716, 0.13647258122052464, 0.13069712184369564, 0.2201055506510394, 0.30316515799079624, 0.4983014070561954, 0.6257062362773078, 1.2454665516104018, 1.560344363961901, 2.865266216652734, 3.694546094962529, 4.858413219451904, 6.5112055369785855, 7.0441388828413825, 7.973420926502772, 8.736974971635, 10.867683495794024, 11.908395971570696, 13.413113491875784, 14.363868509020124, 15.52905535697937, 18.135920456477574, 15.886380365916661, 16.484915563038417, 17.324732167380198, 14.46894177368709, 11.548248256955828, 9.41058806010655, 7.545815757342747, 4.2052695240293225, 1.5366880276373454, 0.3618633768388203, 0.20654747102941784, 0.0789322755964739, 0.0964440159233553, 0.1155759689531156, 0.1630772336253098, 0.06697356408195836, 0.11246459412255458, 0.0651034808584622, 0.14587882719933987, 0.17195085675588676, 0.10110042856207915, 0.09819362525429044, 0.11049834213086537, 0.10048774536699057, 0.058898359537124634, 0.23363146771277699, 0.1314786584781749, 0.1104791938726391, 0.24090832152536937, 0.21243369446269103, 0.04453777315627251, 0.17666473452533993, 0.07585017276661736, 0.08559994066932372, 0.16590220560984953, 0.0819180535950831, 0.16794963074581964, 0.1725352518260479, 0.12369781599513122, 0.12369861666645322, 0.13609291373619012, 0.09575962514749595, 0.09273845476231404, 0.2483851531786578, 0.1653992347419262, 0.07148736901581287, 0.09920506990913834, 0.055569772076393874, 0.08163108077964612, 0.13072433109794343, 0.1338794103690556, 0.07540185110909597, 0.10978035030088254, 0.105709248754595, 0.11667534496103014, 0.10628119949251413, 0.19848386943340302, 0.2535209575934069, 0.1431729652519737, 0.05617492014010038, 0.24719394424131938, 0.1649068897323949, 0.15052604568856104, 0.24031864745276316, 0.12538962092782768, 0.2318826929799148, 0.14024505950510502, 0.1571075368140425, 0.08853868940579039, 0.2426338360777923, 0.19278565448309692, 0.20546036293464048, 0.19730438558118685, 0.15054758239005292, 0.18499286978372506, 0.10524409942861114, 0.15119011434061186, 0.16916137215282234, 0.24025749787688255, 0.12166774778493814], [0.03742961672001651, 0.06042726856789418, 0.06761182126189981, 0.047139707287507396, 0.054111742813672335, 0.045134476851671934, 0.059186139809233804, 0.03254184399598411, 0.022691693622618914, 0.0074991121987945265, 0.06484609895518847, 0.03313907016334789, 0.008539611723140945, 0.018161610633667027, 0.07533012995762484, 0.042056801462812085, 0.03095123577596886, 0.019468981373522962, 0.04131620763135808, 0.046301099072609625, 0.043338435369410684, 0.02375022691142346, 0.037496805257563076, 0.030297487641551664, 0.029321669467857907, 0.03783339933891382, 0.030115189030766487, 0.03533262460093413, 0.04530257711719189, 0.03472586162388325, 0.09364950337580272, 0.022755333422017947, 0.05917466578206845, 0.001973041794761749, 0.02268750706155385, 0.025736885843798518, 0.0308267110293465, 0.05290504292185817, 0.057246574599828036, 0.011474804936109908, 0.08445962185838393, 0.005842574971861073, 0.030225084562386786, 0.029970756066696982, 0.02835860605617719, 0.060633957119924684, 0.038287390156516006, 0.03893780668399163, 0.05218317326424377, 0.023113360728270242, 0.04348026615168367, 0.0108092545332121, 0.015153944791693772, 0.030892786769462482, 0.06535121399377074, 0.023525346835543002, 0.025004714328263487, 0.017033602144303064, 0.01650827524385282, 0.024313935145203556, 0.019581161871818558, 0.012468114046246877, 0.05818987398275307, 0.04260615698461022, 0.022480703158570186, 0.03196954720520547, 0.05219123765294041, 0.026848232905779566, 0.024090556328051856, 0.06065822831754174, 0.04272325177277837, 0.04590477016089218, 0.03549610743565219, 0.04529237534318652, 0.017315446931336607, 0.025808186303558092, 0.013373932002910545, 0.03870406494076763, 0.08428451911147151, 0.009612886185225631, 0.029201704476560866, 0.046552157029509544, 0.01385894968240921, 0.005507372311382953, 0.05432516921843801, 0.16160637326538563, 0.22641954970146927, 0.17224371246993542, 0.29689633580190794, 0.29577794724277084, 0.516930341720581, 0.6305892999683107, 1.187324351498059, 1.095548527581351, 0.5543489967073713, 1.7794777367796217, 1.9864901942866189, 2.104342064687184, 2.1073988378047943, 1.6536196959870202, 1.0508570628506797, 0.708935124533517, 0.3107690656823771, 0.20298521646431514, 0.046959610522857735, 0.0603397579065391, 0.058565103848065646, 0.03207651146554521, 0.024149112203823667, 0.026521864347159863, 0.005892534233030996, 0.027596456863518273, 0.015124462445133498, 0.05149623458938939, 0.012514898187613912, 0.03389925330079027, 0.0202711081531431, 0.03974773661632623, 0.016510460126612867, 0.06503118295222521, 0.037454512169850726, 0.014138908990259682, 0.10495504351066691, 0.07402271511299269, 0.017584482673555613, 0.055995956528931856, 0.04818969951676471, 0.03668848006054759, 0.05609245099393385, 0.03629142850903528, 0.08039922759469066, 0.021282870023112212, 0.01110854700008141, 0.05186353238033397, 0.010115438905943717, 0.021937831038875238, 0.07058253578309502, 0.08937667336847101, 0.011882777508747364, 0.03366969133328114, 0.05226221920124122, 0.0539045725017786, 0.015434011816978455, 0.07908991963735648, 0.08019962973360505, 0.022768608959657804, 0.027216492520113076, 0.02420869606014873, 0.08670746588281222, 0.024323454991515194, 0.028437538338559012, 0.05374182927023087, 0.024799218301528266, 0.04485164309984871, 0.033187439532152245, 0.06719273767833199, 0.02871696584458862, 0.024586075185132877, 0.058470461783664565, 0.061441054168556414, 0.08413691060351473, 0.04987840693710106, 0.02792710019275546, 0.047964649807129583, 0.008203948931103306, 0.030748492905071804, 0.027885212529716746, 0.013351407184797739, 0.024125548378963555, 0.048202483116516044, 0.04035673875893865, 0.031629767401942184, 0.0569674660052572, 0.05100085313564964, 0.07883918737726552, 0.07170371312115874, 0.006626855432321983, 0.03373228958142655, 0.036651934164443185, 0.026834411147449697, 0.08810149572257485, 0.024369590283770646, 0.014844537912202733, 0.009897265300553824, 0.030911019005413567, 0.04066228647051113, 0.05393522871392114, 0.06271773137684379, 0.017908557783812284, 0.05092477239668369, 0.03926167144839253, 0.04044418156679187, 0.02271913697144815, 0.03474917269444891, 0.021753822519843067, 0.06000522657164505, 0.0033069371046232326, 0.017164586544302956, 0.027974292303302457, 0.005725785948535693, 0.02668833443229752, 0.03129002831078001, 0.04059440582724554, 0.011733314055683357, 0.07276324555277824, 0.04939258264909897, 0.07203017667468105, 0.010264330693254513, 0.03856638679280877, 0.096475696723376, 0.021340442023106983, 0.01318648161499628, 0.0619869220203587, 0.022357516822272112, 0.04537716168644173, 0.059296177833208015, 0.03198031894862652, 0.048348408857626576, 0.03612219509003418, 0.04320607354332294, 0.05354444682598114, 0.0607689448765346, 0.06407440786382981, 0.02401285049771624, 0.07227704128516571, 0.03453173954039812, 0.02140377478541008, 0.031800778582692146, 0.01741423993371427, 0.01556920143775642, 0.030959551222622395, 0.015452586713113954, 0.011045399138570895, 0.028647609387657473, 0.022530585660466125, 0.03934824912409697, 0.06019755732268095, 0.07615440751292876, 0.04798692271911672, 0.03544678133247154, 0.0612497412200485, 0.022700618054451685, 0.0095686601208789, 0.030317724948482852, 0.0400565514740135, 0.011031904773387526, 0.0057473336762216476, 0.0893266246254955, 0.015590819563450558, 0.06421816907823086, 0.04731429774048073, 0.05225681806249278, 0.012750500813126564, 0.028475746645459106, 0.07046440283634833, 0.04685499399368252, 0.03221262219761099, 0.06487743370234966, 0.11012022170637335, 0.055527085438370705, 0.19445209577679634, 0.2026775415454592, 0.4199168517121247, 0.35923057954226223, 0.4266435493315969, 0.6629492864012718, 0.9150349795818329, 1.0073491803237369, 1.5182639019829887, 1.56948841043881, 1.2896467809166228, 2.55122218813215, 2.5836733153888156, 2.715486070939473, 2.8245489043848853, 2.3011452300207953, 1.786442763039044, 1.0925201986517226, 0.519833005964756, 0.3019583156066281, 0.028913761356047223, 0.03310470236465335, 0.04132654171969209, 0.07123090992016451, 0.012617647049150296, 0.03630527062341571, 0.011324828340938049, 0.035049668712807555, 0.03730994689145258, 0.04608129783134375, 0.025465716108945862, 0.04012943970571671, 0.023592319938221147, 0.03893944873873677, 0.028091231028416326, 0.024460278185350553, 0.053780393808015754, 0.017326340811061006, 0.07344067455934626, 0.05795895494520664, 0.0834993998120938, 0.01525889549936567, 0.057273885634328635, 0.05379670239718897, 0.02641043871907251, 0.01694692947369601, 0.021760090487077832, 0.05514628480055502, 0.02928507946697729, 0.06544392901871886, 0.007949237911296743, 0.04423658163951976, 0.06747152057609387, 0.10586336441338062, 0.040353810880333185, 0.04411156495500888, 0.006270328536629677, 0.015216994265626584, 0.05395838372143252, 0.058343630017978806, 0.015168412854628903, 0.026742116814213138, 0.016701228550768325, 0.051487199895616086, 0.018800178243379508, 0.037046607450715134, 0.03424523491412401, 0.027226175214829187, 0.03747313795611262, 0.012641359303545738, 0.08274144226951258, 0.02972419001162052, 0.04350482911935874, 0.025511758102636253, 0.04213754373735615, 0.03407055285892316, 0.05624033770124827, 0.03287087580455201, 0.03240401317764606, 0.030911395592348914, 0.032948150765150785, 0.025137873432998146, 0.02817705213757498, 0.01936058879696897, 0.02075588410454137, 0.04955980421176978, 0.03159179997497371, 0.020968095931623663, 0.01761821943468281, 0.04645232077954071, 0.034165004933519025, 0.008281702258890229, 0.12191839862082686, 0.12251249674175467, 0.15821771509945393, 0.09404447861015797, 0.16496992563562735, 0.13329787871667317, 0.14538610221019813, 0.1850773338228464, 0.10106424907488482, 0.13857806181269033, 0.1488399404500212, 0.12488925563437597, 0.08911828723336969, 0.06698256145630564, 0.21288726798125676, 0.11512546241283417, 0.12765891344419547, 0.12965136367295468, 0.10970559609787804, 0.14778906612523965, 0.11556360604507582, 0.21905781115804399, 0.19088004316602433, 0.1062868381185191, 0.12672987686736242, 0.1110828457666295, 0.14928822139544146, 0.18289915498878273, 0.11912469352994647, 0.10778388993016311, 0.16902516303317888, 0.10153183434158564, 0.12697435303458146, 0.1544295083731413, 0.10944656535450902, 0.05381478535543595, 0.13530459175152437, 0.13650512376001903, 0.13324215742094175, 0.12962263450026512, 0.20097486648176396, 0.09608496233288731, 0.07623849835778986, 0.10776658728718758, 0.13154750264116696, 0.1850335140313421, 0.14298320614865848, 0.09455565296645675, 0.1753972175398043, 0.16388663090765476, 0.10303421943847622, 0.1196992498423372, 0.1323892253318003, 0.133163718772786, 0.09164481237530708, 0.3058566892785685, 0.06988880158002887, 0.12464878282376698, 0.10922279807605914, 0.07330163594867502, 0.14088205460991177, 0.15584695445639746, 0.14126409696681158, 0.1768239052700145, 0.11777436813073498, 0.10362746939063072, 0.08631079431091036, 0.1462625116109848, 0.08874029573053122, 0.10772576662046568, 0.12514933810702392, 0.1728679375456912, 0.14449058526328631, 0.1625245397112199, 0.12072191068104335, 0.10495572883103575, 0.16536229529551097, 0.12080284633806773, 0.10206320868538958, 0.13894559709089144, 0.10977397885705743, 0.19995209707745484, 0.1985650493630341, 0.14349628718835966, 0.22943399580461638, 0.24048244580626488, 0.43856657668948174, 0.3221100185598646, 0.5615607925823757, 0.7250848008053643, 1.0311393780367715, 1.0456453710794449, 1.8195591803107942, 1.6364860896553313, 1.557104874934469, 2.7778548385415758, 2.8780007447515215, 3.228305684668677, 3.227684038025992, 2.5141331383160184, 1.7622424044779368, 1.327439118708883, 0.6291548226560865, 0.43241970081414494, 0.10121427316750799, 0.13638139968471868, 0.16673138897333825, 0.1424881877111537, 0.0986922602834446, 0.07966853358915874, 0.13024763310594217, 0.15716834712241376, 0.25971733938370434, 0.17512288583176477, 0.06603169640792267, 0.14134432694741658, 0.12725864563669476, 0.10578090883791447, 0.16452385671436787, 0.10446345846035651, 0.1291336685951267, 0.12402565697474138, 0.18293852359056473, 0.2160331191761153, 0.11131573934108019, 0.07406318294150488, 0.10804769756006342, 0.12969826401344367, 0.10294991146240916, 0.08268099837005138, 0.17611320769148214, 0.1456351788448436, 0.12494874958481107, 0.20838651806116104, 0.07323902752250433, 0.13824298764978135, 0.18845426690365585, 0.29659148358872955, 0.12282486712293965, 0.14384626198027814, 0.10794747793780905, 0.08690551668405533, 0.11542243004909583, 0.18087124451994896, 0.10246566137565033, 0.10036239280764546, 0.11853383880640779, 0.11009356206549065, 0.34458988372768673, 0.1839985174259969, 0.10582096276006528, 0.0755798579858882, 0.08854869101196527, 0.07616987811135394, 0.19257148168981075, 0.15398327660347733, 0.12444880498307091, 0.0801134490008865, 0.189974646749241, 0.15032914839684963, 0.15607768350413867, 0.1500594307269369, 0.11858168909592287, 0.14317975060216018, 0.11578708833881787, 0.13155617431870528, 0.07734507362225226, 0.14142813959292003, 0.08068951844636883, 0.16235956070678575, 0.12843526607113226, 0.08533137650894267, 0.15250530519655772, 0.16137738126729215, 0.10063806801502194, 0.17955669148692063], [0.0336228724169944, 0.06569500733166933, 0.036492658246840746, 0.06062988590981279, 0.1012309854850173, 0.037157992366701365, 0.01122756882770253, 0.03172286579917584, 0.10902144280927521, 0.03212717767538769, 0.016976693412289023, 0.018350329882066165, 0.03165060860503997, 0.05033034518627184, 0.040292579880250354, 0.04875330088127937, 0.043543210452688594, 0.02602621487208775, 0.019470757438934276, 0.03861382317596248, 0.05380241905472108, 0.0828645353072456, 0.02525859329450343, 0.03749591976936374, 0.02334256816123213, 0.06727421616337129, 0.08211225031742028, 0.0678241348692349, 0.04595508013984986, 0.07175502393926893, 0.01668585803625839, 0.02400109318218061, 0.003742716466409287, 0.016290591031845127, 0.0441432830744556, 0.0311152275119509, 0.01789730936954064, 0.025136808133018867, 0.03136763914621302, 0.048982689822358746, 0.0386852016672492, 0.051081880394901545, 0.021180102501862814, 0.0474543779024056, 0.03052199791584696, 0.042737697783325396, 0.026560152381924645, 0.02497436515321689, 0.002076845778252131, 0.011358490463213196, 0.023057055892422795, 0.014959597095314945, 0.020828305843419263, 0.04526670975610614, 0.055448887670146565, 0.02845650678500533, 0.015099053005022662, 0.03514959317232881, 0.046363096817263534, 0.04710660156394754, 0.002115027155793671, 0.0012420128685854642, 0.04704000674454229, 0.04836848331615329, 0.05268176758129682, 0.04562090503584061, 0.03815005806141666, 0.01674211028564189, 0.05993022131068366, 0.05756074309881244, 0.010643566459683436, 0.03659420440505658, 0.006614396257126438, 0.0066832599280002925, 0.022053711249360015, 0.0052769227352525505, 0.03621577863980617, 0.07640989630350045, 0.02795608720875212, 0.16589855509144918, 0.02429489714891783, 0.02884779078885913, 0.011381374904885888, 0.009047374744633479, 0.03722713847777673, 0.08109860720911197, 0.04061531488384519, 0.030198560628507818, 0.041161864663341215, 0.041881607113672156, 0.028247796198619262, 0.026328313929427947, 0.05637488441009607, 0.016962968345199312, 0.03506861001785312, 0.05091249091284616, 0.016826233360916376, 0.040964146344257255, 0.10338869970291853, 0.03743449877947569, 0.023580331920779178, 0.012628198268690279, 0.010902189233872508, 0.04780853586271405, 0.017871743866375515, 0.0237938838545233, 0.047250115113066773, 0.03340484554480229, 0.02268899305324469, 0.030860651350979294, 0.03123613566692386, 0.00480291640685339, 0.025820891871782284, 0.010898794014272946, 0.06411730484770876, 0.031364083622715304, 0.040433223226240704, 0.02133596029930881, 0.054030647700918574, 0.05488044495827385, 0.03216569132304617, 0.04153278922396047, 0.022177910299173424, 0.05185648240149021, 0.00906148148767118, 0.06202601920813322, 0.0343984108019088, 0.05049749889544078, 0.036212270613759756, 0.0952647966997964, 0.066269088669547, 0.014181814455826367, 0.02006949843572719, 0.040344287641346455, 0.018682321799652915, 0.022606277938133905, 0.02408275656801249, 0.05362588120624423, 0.04457021391551409, 0.0417887597743954, 0.04460190150088497, 0.05004321630778057, 0.0761351574744497, 0.005852403127521808, 0.014123324737218874, 0.04542355651834181, 0.06528520610715662, 0.01175679306366614, 0.016211769011403834, 0.03234034962952137, 0.006189938676210919, 0.03369528228150947, 0.054968644332672865, 0.02936545872528638, 0.022593214442687373, 0.0009056828857865185, 0.03593526208507163, 0.014069196302443743, 0.04211639380082488, 0.05336704384535551, 0.028244347544386983, 0.0289913348720542, 0.027996161486953497, 0.03537227140207376, 0.0031590730858234955, 0.026792094311011688, 0.08219678899539368, 0.02423266530968249, 0.01748938938336713, 0.03782520942123873, 0.01530560924272452, 0.03251736584518637, 0.04488599732784288, 0.046758893078991344, 0.0242128792285387, 0.03402126407516854, 0.04419546241738966, 0.053470238843666654, 0.042867250474435944, 0.03790314256080559, 0.060459288635424206, 0.013214240482609187, 0.03974320060972657, 0.027206764024283205, 0.04724351636001042, 0.01779333914497069, 0.0674689964258245, 0.03145609636391912, 0.026371714725558246, 0.013984359069062131, 0.04920265730470419, 0.009190260648860462, 0.018232634590406503, 0.0462926784530282, 0.03205384839592235, 0.03581198923555868, 0.04562604154593178, 0.008217126929334231, 0.01743086234533361, 0.027933422442791716, 0.0130208766620074, 0.03163640008174947, 0.06970113914992128, 0.005338357719925365, 0.05498953642589705, 0.03043168151218976, 0.014154825725459626, 0.0304010388707476, 0.022424978470163684, 0.05508719797113112, 0.029424888214894702, 0.06713282303618533, 0.029567886077399765, 0.030931035788463693, 0.032936809052314074, 0.021929866734093854, 0.01248400957722749, 0.043815611728600094, 0.03974005899259022, 0.045476916512208324, 0.022102838881047707, 0.03337774146348238, 0.036766423378139734, 0.05234096997550555, 0.013741241668217948, 0.044681697219078026, 0.03255810848038111, 0.03197965059163315, 0.031087858801973716, 0.05125507985108665, 0.028891257742153745, 0.03716114416186299, 0.0027827556561013417, 0.04512382724455424, 0.08839481962578637, 0.0174721342378429, 0.014086375960947146, 0.004843030548987112, 0.04222422319331339, 0.01381655566261283, 0.0476986640798194, 0.04753914049693516, 0.03795309630887849, 0.004760377350196774, 0.021855921684099094, 0.05564926923917873, 0.037230273309562883, 0.04000186833686062, 0.054921163844742944, 0.005777542903420648, 0.052085542253085544, 0.027554806687736084, 0.1053575776251299, 0.027908918846930777, 0.024246207172317163, 0.07544744866234915, 0.1319989591304745, 0.014331597668517913, 0.016789594166246907, 0.042549183791769404, 0.03991544672421046, 0.08203365560621023, 0.027940155206514255, 0.04593255616990583, 0.02650525380990335, 0.007228278338776103, 0.027966044710150788, 0.05010855923007641, 0.14965989573725633, 0.02027953046906207, 0.01864753839825945, 0.06255898132388081, 0.060259249726576466, 0.03843568737751671, 0.06142091524920293, 0.04336587871823992, 0.026638455323076675, 0.05235146351956895, 0.018828613949673514, 0.13387250288256577, 0.025396566605195403, 0.0493970881216228, 0.05353070649185351, 0.04713149022843156, 0.05680757601346288, 0.03613249185894217, 0.08019367898149149, 0.025372551554547887, 0.014627388046522225, 0.012998373048113925, 0.011891852066453015, 0.04175277706235647, 0.018513912800699472, 0.032430530326174836, 0.09993683599999972, 0.025644918903708458, 0.01752896324199225, 0.02169748206090714, 0.01239288826140442, 0.06248549598136118, 0.0306660610783313, 0.01410658358197127, 0.06204790196248463, 0.0038614668800229473, 0.03820980306980865, 0.04048188775777817, 0.0630187430818166, 0.07394801519278969, 0.011044709577358194, 0.018456367942105447, 0.02383172235983823, 0.0430719000287354, 0.009319000794286174, 0.026767387154645154, 0.0147703791236771, 0.04719228357342737, 0.007650253329692143, 0.04359824303537607, 0.03990669022979481, 0.008511482205774103, 0.006111456771447722, 0.052508466344858916, 0.05799709539860487, 0.03888226859271526, 0.03254336391442588, 0.0428591894784144, 0.07635483318673712, 0.014142523037402757, 0.05078829864838293, 0.028034876998780028, 0.04485894752932446, 0.022505529058564986, 0.016658083901607564, 0.0252667933902038, 0.02014983189292252, 0.04818453586527279, 0.029512290310646807, 0.04336318154154079, 0.03985700111037918, 0.024423900226663266, 0.03224097478336521, 0.04037319662581597, 0.05193565047479101, 0.031780870365245004, 0.02421333215066365, 0.030344924024705375, 0.045567694319678206, 0.060074973186211925, 0.011690914946874338, 0.048325786500104835, 0.04251099244824477, 0.02637363667599857, 0.18899921194783278, 0.14930253848433495, 0.15188226077173436, 0.1627020716134991, 0.2011989594570228, 0.07008901012263127, 0.13394290767610073, 0.17555433910872253, 0.205551164490836, 0.09484531956591777, 0.10072677289800984, 0.11533926879721028, 0.07722572609782219, 0.12244112842849322, 0.08804371846573693, 0.20408236687736853, 0.11173472114439521, 0.13669303724808352, 0.047574281825550964, 0.09483573865145445, 0.1291603214506592, 0.11783143292580332, 0.17701268728290284, 0.161178964057139, 0.09870420928512301, 0.1521975217120988, 0.2866907891418253, 0.0947730555864317, 0.14907828266067163, 0.12195641015257154, 0.07814746842320476, 0.14355207633759293, 0.10028363524803094, 0.09108196757733822, 0.13252314100308077, 0.20472062405730995, 0.10562352942568914, 0.14686814482722962, 0.09468688842441354, 0.07548508699983358, 0.09604147502354213, 0.15559006109833717, 0.10811737632112843, 0.10226588031010968, 0.10120405443012714, 0.12765113743288176, 0.09920028623725687, 0.202394307457975, 0.14349277237696306, 0.06283255985804967, 0.08104418191526618, 0.10067957400211267, 0.09157549323780195, 0.13156689517199993, 0.08102500651563917, 0.11895119212567806, 0.16683668403753213, 0.14317414590290614, 0.21223898205373967, 0.15356957380260738, 0.11384353334350245, 0.07252097462436982, 0.24210438877344131, 0.0987955808107342, 0.156055427555527, 0.10598383830594164, 0.12878207888986382, 0.0890319300815463, 0.12470425984689168, 0.145122192800045, 0.12007272908730166, 0.0843509951872485, 0.07542114864502635, 0.15767279719667776, 0.0753143404477409, 0.10123996250331402, 0.16601131404084818, 0.13380710567746842, 0.12071671310280051, 0.22046408855489322, 0.20042057122503007, 0.07044908151562725, 0.07891463368598904, 0.13994860755545752, 0.08643708324858121, 0.13779401459864207, 0.10351800812142235, 0.17339559351759298, 0.15063375633742127, 0.12868549621530942, 0.11604770006878035, 0.19264462776482105, 0.31868347099849154, 0.22183061737035, 0.20581526389079435, 0.13962361642292567, 0.14545772836676665, 0.14304671702640398, 0.143228645835604, 0.1350656117179564, 0.18933170767767088, 0.10052219458988734, 0.07954807326729808, 0.20276636177940027, 0.10145722263093505, 0.10485274757125548, 0.16202375372605665, 0.15637108204620226, 0.0800526522632156, 0.16248139845473425, 0.19395145906933717, 0.11637579889169761, 0.11654484910624367, 0.12374179863504, 0.11965931127113955, 0.08444767964205571, 0.09396484574036938, 0.24277228436299733, 0.2603964986545699, 0.08624012488871813, 0.11538536846637726, 0.08995580979223762, 0.0963516401659165, 0.13091152533888817, 0.11347289716026612, 0.1467092726379633, 0.1630193003054176, 0.14569969395441668, 0.10689044930040836, 0.15995685463505133, 0.21628181583115033, 0.20985693058797292, 0.11232736720038311, 0.13356098745550427, 0.12549292109906673, 0.13505214958318643, 0.07599174909825836, 0.10569592232682876, 0.09804628137499094, 0.11715346787657056, 0.08852815854230098, 0.13344848634941237, 0.2571837439068726, 0.059446140857679505, 0.09077577865017311, 0.07631665202123777, 0.13117213706885064, 0.0823531641757914, 0.09622110359902893, 0.12166457224105086, 0.11120279718722616, 0.13679058344236442, 0.16261900535651616, 0.10125580629599945, 0.07180795645607368, 0.11014390257852417, 0.05190872959792614, 0.125662161303418, 0.06502351550651447, 0.11246881461037056, 0.12252133126769747, 0.17082199161606176, 0.09610176285994904, 0.15839904679783753, 0.10683607828936406, 0.11241683204259191, 0.12190094670014721, 0.15876200875001295, 0.1305880541247981, 0.21910206521196024, 0.08988862804004125, 0.18063849343785218, 0.1347628358219351, 0.08826956884669405, 0.07663926828120436, 0.1296106515718358], [0.08501316394124712, 0.03870947625754135, 0.036431949718722274, 0.02690335878703211, 0.03701632782550795, 0.039095087708639245, 0.012864653303820108, 0.04507677762636116, 0.06669537829501287, 0.027401381438331943, 0.007844159978308847, 0.0414316603647811, 0.03470047423616052, 0.02554979338310659, 0.03106504984732185, 0.022444511797013025, 0.02341850471150662, 0.01893569016829133, 0.02620989260529833, 0.03925942889015589, 0.020222243453775133, 0.06600504355239016, 0.037799699897212644, 0.037283334748021195, 0.024627065485609428, 0.08537904359400272, 0.0526157596946827, 0.032586661233965836, 0.003975796637990112, 0.038255882382925065, 0.010729704783963305, 0.023644341521763375, 0.04695374458762152, 0.023988530106310333, 0.058261778338679245, 0.032384454405733516, 0.0264365996367165, 0.01509267307950982, 0.015869193643863713, 0.018706932264779295, 0.04901162255555391, 0.02404386972609375, 0.028680260492754833, 0.061444596121353764, 0.09412583495889391, 0.04042829027665513, 0.04192668219496097, 0.02599117871639984, 0.01802133030391165, 0.04689567556072559, 0.08920992338763815, 0.026541777653619647, 0.042129682909165106, 0.02758393619608666, 0.04122058169117995, 0.07356009672262839, 0.015607682855001517, 0.03493286569469741, 0.01792077480682305, 0.02908194643844451, 0.04621083016640373, 0.039618896386985264, 0.03318095952272415, 0.028227574158725992, 0.04209286220637815, 0.06863047874399594, 0.009681828735795404, 0.01269096615059035, 0.04371837766042777, 0.021500476203592758, 0.03788254902298961, 0.0322132701985538, 0.04332225230921592, 0.0315331677640123, 0.028916886009808098, 0.0037513546412810683, 0.04440389819709318, 0.0728997667985303, 0.03627154404031379, 0.022566515786041106, 0.0466787920200399, 0.04120727901213935, 0.03309918587495174, 0.020759661848257695, 0.05237571096846035, 0.062456508965364525, 0.026654855514477407, 0.0764096723869443, 0.025113977125978897, 0.028260657829897742, 0.01811383498300399, 0.015423933875613978, 0.028630489949136972, 0.02423057542182505, 0.02283012155177338, 0.10246072842606477, 0.012059060906592225, 0.024067903436454277, 0.042151236574032476, 0.014308452839031816, 0.05223261471837759, 0.016574315360880325, 0.06211954168975353, 0.05416282632255128, 0.0031793771860455827, 0.05197923956438899, 0.04475135901676757, 0.036798077036759684, 0.03249938466719218, 0.039251391642860005, 0.03261796883972628, 0.0678971791639924, 0.03221386730937021, 0.0727605517687542, 0.03975734467219029, 0.020702344298894917, 0.0621524913502591, 0.028692463945065225, 0.006429188851533192, 0.03651201345824769, 0.033435182845486064, 0.009081929988626922, 0.02013957583611565, 0.0573122092921819, 0.015265621477738023, 0.050975228260670385, 0.031225160362997224, 0.01473852020821401, 0.05140515822651131, 0.003542108436314655, 0.017197822885853902, 0.030689392504947524, 0.021211310023708, 0.07556260284036398, 0.038328285462089946, 0.011400621550689851, 0.06410462981356041, 0.0245631712355784, 0.025920052979407564, 0.07198839927358286, 0.06022969274116414, 0.08084151707589626, 0.030120203404554298, 0.02100247221200594, 0.058310795708426406, 0.04397418536245823, 0.05465432994865945, 0.02367733189437006, 0.03653622358771307, 0.09285892186952488, 0.025728950376755426, 0.04608188137145979, 0.037062044122389386, 0.07531285445605006, 0.07639813729162727, 0.05262542881869844, 0.053648730872997215, 0.019669580073761087, 0.02898060723340937, 0.030887565442493985, 0.09127699889774833, 0.08319880201348237, 0.0725605467866574, 0.07279781691197838, 0.03192554760192122, 0.05212203047371336, 0.04512661602348089, 0.032981877348252704, 0.0069561607753192735, 0.05904445491198983, 0.03946163571838822, 0.034255494363605976, 0.0044497342647186345, 0.03637923772579857, 0.027643604869289056, 0.07017006113060884, 0.08330453812543835, 0.004264518801522042, 0.022968125396541188, 0.05065612341942532, 0.012962024775333703, 0.022437701001763344, 0.01410920187897448, 0.03128719203440206, 0.07066694553941488, 0.020450514508411288, 0.0049196502992085046, 0.035349852605057616, 0.04867406834715179, 0.03385912473978741, 0.04660297590973122, 0.06404789071530104, 0.014656403900257178, 0.07919233092772109, 0.1117811193689704, 0.01768677182761686, 0.006284164289744305, 0.01640032371506095, 0.07728282481964145, 0.044338321180215905, 0.04439942665132029, 0.019902960497087667, 0.027193247606711726, 0.0501516903085368, 0.03134555622403111, 0.062238488878522596, 0.02117100843627538, 0.04491715904857431, 0.008636434429458209, 0.02854063155661736, 0.12723453050213201, 0.018395874848855392, 0.04837387088420136, 0.03145437288497176, 0.010111934272572398, 0.01747967445823763, 0.041820148804358075, 0.021295906377157996, 0.03276121097483805, 0.0431867624366922, 0.02807699197104999, 0.08150414044835738, 0.03406012038301144, 0.03300789577354278, 0.03576772839629224, 0.04559419111215642, 0.034619674286139865, 0.013751731819606252, 0.0366760221576052, 0.04353740219292896, 0.06953549518116883, 0.015508160427478808, 0.026537506275677254, 0.027834875409358313, 0.054169004383896074, 0.007942462739135538, 0.04249097566519465, 0.03501001512631774, 0.030690647794732025, 0.05189619027078152, 0.014691782716129507, 0.026414964547646896, 0.022767962655052543, 0.010581551751654063, 0.10776563733816147, 0.042606112879834006, 0.015465836805690612, 0.020803432445973158, 0.03298417418929083, 0.024214110769597546, 0.0380435077074383, 0.05417874136141368, 0.02549901182231094, 0.025665600651076863, 0.012490074832125433, 0.040542850736528635, 0.03600856422313622, 0.030246550017701726, 0.06325287837535143, 0.056199472929750166, 0.032210020015814474, 0.028195321692952087, 0.036779664989028654, 0.009321255226885634, 0.06107748832021441, 0.010222998580762317, 0.015408476847889168, 0.02738682516584439, 0.04959324920283897, 0.014672900782898068, 0.08434980096561567, 0.04597476783341595, 0.04732738668099046, 0.03988923830911517, 0.008751379957954799, 0.04550236157540764, 0.038048830814659595, 0.03591253116194691, 0.05588582351005503, 0.03627318948773401, 0.0678219703425254, 0.026203285370554243, 0.05165136465802789, 0.034899610693433454, 0.02029039042203554, 0.027938348607027104, 0.015822162685383643, 0.05184321025652545, 0.031040839717856476, 0.06904310267418623, 0.042381042814148326, 0.07131656139556851, 0.03509580230872546, 0.050873685495129654, 0.02022000598455114, 0.039583544712513685, 0.028564030836735452, 0.04138990331973348, 0.04924064508772322, 0.023757936765572855, 0.024226641615054438, 0.028953509937439646, 0.03857725013845733, 0.02460865004520331, 0.016111532425773994, 0.05963974725455046, 0.052136371311332495, 0.014375107030251195, 0.08087283825235707, 0.024222867264013206, 0.0632560539192387, 0.031636447579200776, 0.01939987936722381, 0.017431964964738915, 0.011797994558167244, 0.020129657350480556, 0.01567139050790242, 0.021989034987719994, 0.0659746994663562, 0.022607039593692337, 0.05130646870072399, 0.03527238765465362, 0.007014696719124913, 0.012519163628374892, 0.03701118453006659, 0.05160009455201881, 0.03820633575586336, 0.04798695325319256, 0.03687465649896434, 0.02064962891329612, 0.018625998304092457, 0.039634278775858026, 0.021230668627790043, 0.10983339138329029, 0.00769955144330327, 0.007782961208639401, 0.05133720633706876, 0.01881616622475641, 0.0757077279101525, 0.033477648959628174, 0.04497723653912544, 0.040046950203499625, 0.055594789662531445, 0.0032096672013202415, 0.01710378471761942, 0.03601162102339523, 0.01959616088840578, 0.02376114114719842, 0.015548004003773843, 0.029225059651902745, 0.035344308973955255, 0.0324970674701035, 0.24156913320933068, 0.16498832750533307, 0.11809458237673555, 0.16573861081685337, 0.0859251625037619, 0.08623603332255568, 0.10129014695329325, 0.09642160391168934, 0.1442199040736471, 0.0782975535839796, 0.1439309295799051, 0.1286633624030011, 0.13868376399789537, 0.11798461899161339, 0.1359714695385524, 0.11402345368904726, 0.10121270575161491, 0.15153292380273342, 0.14681668473141535, 0.130546934902668, 0.15268325779054845, 0.1054468389068331, 0.16554007147039684, 0.12363339588046074, 0.16461461755846227, 0.12009845913520881, 0.13884864800742694, 0.15059626049229077, 0.10295303950884513, 0.18191864474543504, 0.11284396983683109, 0.09790336154401302, 0.07365983458501951, 0.11500950077814714, 0.23488730032529148, 0.1614110501749175, 0.09775369707494974, 0.08881580310740642, 0.12493303471377917, 0.06693410048527376, 0.18631099191095146, 0.16675375348755292, 0.12555360927113465, 0.20391371021313326, 0.16120436840823718, 0.1832892583417041, 0.11500129050442151, 0.07701951252030474, 0.09209867766393082, 0.18948498873838357, 0.14979169437927858, 0.1070763882515686, 0.18686147380088056, 0.12601513522011892, 0.1571699348943574, 0.1705775833023446, 0.15111878673945153, 0.10798673118863787, 0.1675847146127905, 0.11644882283040456, 0.1320348129208599, 0.1627905797213316, 0.1596410780080727, 0.1072920538218958, 0.1218093309019293, 0.22234531332339558, 0.08932910127831356, 0.09340569895825215, 0.2995942181774548, 0.09393322600850038, 0.072289349910404, 0.1396654820335763, 0.11120331965919052, 0.11656189390591212, 0.14018610838268483, 0.13425818218716554, 0.13737313289727482, 0.1351528713213546, 0.09600268996187619, 0.10635558050125837, 0.07564917712339334, 0.11306547759366886, 0.18708445397870882, 0.13684098502354963, 0.18607180831687792, 0.14975972180919989, 0.13724923240286963, 0.13343871544514382, 0.14778027231139795, 0.07487411371299199, 0.19406295594360146, 0.11024683634085314, 0.08669425480599914, 0.13128951005637646, 0.13028891517647676, 0.12597677085016454, 0.22590479946562222, 0.13813866967601435, 0.07991026847490243, 0.14229473737733705, 0.16008545059178556, 0.191830969282559, 0.09463029860385827, 0.11033760397029774, 0.10239271207579545, 0.09403670259884425, 0.15866690528179916, 0.0571292694658041, 0.10874911956489086, 0.12374927609094552, 0.0747110956747617, 0.15746729608092988, 0.11844303725021225, 0.23295982660991804, 0.08081409747579268, 0.08017504640987941, 0.07780121200318847, 0.11788718136293547, 0.24583899123328073, 0.11140782332846097, 0.09748102099235569, 0.11239621136337519, 0.12247916710163866, 0.15603929199278355, 0.1283924640821559, 0.10771792954100029, 0.05261019231485469, 0.07880531490913459, 0.2146048436739615, 0.1375674788973161, 0.15985139672245297, 0.08981585515929119, 0.16320953438324587, 0.158002497362239, 0.11721517385116645, 0.11684815425957952, 0.1196780116962535, 0.09860308042594365, 0.15407791866787843, 0.13771189829068525, 0.13673427860651696, 0.13205070421099663, 0.13784086065632956, 0.13367078799222196, 0.1900437216141394, 0.17800228989550046, 0.12422267640275614, 0.17764470194067272, 0.1328898620392595, 0.15833654015191964, 0.14369486724691732, 0.11325723158993892, 0.10304586988474641, 0.12944970306541237, 0.17518057487905025, 0.24351340745176586, 0.1450173862810646, 0.17678225679056986, 0.14280312295470918, 0.18344762841505663, 0.16676431149244308, 0.28198110471878735, 0.14779518651110785, 0.2239246442914009, 0.11112234329006501, 0.11515599648867335, 0.17103707364627294, 0.08888416551053524, 0.15316903458109923, 0.12753594932811602, 0.10042230066444192, 0.0637107945180365, 0.07456649307693754, 0.11726075783371925, 0.0800354378297925, 0.14267467627567904], [0.05863293699387993, 0.050216917879879475, 0.008646173951482134, 0.02133121564319091, 0.0496601527556777, 0.0162275228981993, 0.01406313359205212, 0.001835442950583196, 0.05584004275234682, 0.025854984863794277, 0.022352229338139296, 0.022796084538900425, 0.023246272167723094, 0.030903660293136324, 0.05514249178980078, 0.014898423770708697, 0.011938035704328545, 0.03786973488916244, 0.07906107511371374, 0.049302116967737675, 0.004423300236729639, 0.010904307111299463, 0.04217248150546636, 0.04403224421132888, 0.021530793148225973, 0.03664924716576934, 0.022785721612828116, 0.04312052045549665, 0.014693188979955656, 0.007190641697629222, 0.022041136299126914, 0.13317046341087135, 0.09036617420081582, 0.039538853003510406, 0.037836557919425626, 0.010208893534062164, 0.015196602591978652, 0.0039052701322361827, 0.08090554364025593, 0.045684029148625474, 0.0408034726445164, 0.03047010355762073, 0.03408709215000272, 0.03338718327826687, 0.03994359914213419, 0.02665909635834396, 0.05022307558517371, 0.07427194781069245, 0.03597399625661118, 0.04376648918592504, 0.037186372093856335, 0.01767425624919789, 0.014736979933721679, 0.009216097566033048, 0.03739003437970366, 0.0065298694535158575, 0.02471748197318188, 0.01828941948977964, 0.025319133885204792, 0.018587477871083787, 0.06897853328181164, 0.03780966418396149, 0.03390869511557477, 0.019337861266519343, 0.013706109669458653, 0.043013169430196285, 0.0692666731774807, 0.07601304152714354, 0.04845399229920336, 0.02150265939001526, 0.07243058697453567, 0.027374928750629936, 0.038049875758588314, 0.020384158872600113, 0.04572158266923257, 0.019487274677625725, 0.06668531562068633, 0.0014351771574833297, 0.07991514035633632, 0.02614083300743784, 0.03168893226289323, 0.03759364238274949, 0.039666230989886184, 0.032673354260623455, 0.0033894575650005466, 0.0021171641170180267, 0.054621431178280284, 0.030541709358138696, 0.02957545852820788, 0.07788303654108729, 0.014576689606266362, 0.02493473870812782, 0.05484397030834641, 0.05401655452858124, 0.04400469568957176, 0.012486987497790583, 0.08477913721331529, 0.06764787861279078, 0.016830323230741278, 0.0728274281801922, 0.011300487593481583, 0.03679129847192338, 0.016392703766801527, 0.013396673104060548, 0.007107507587144417, 0.02589611935296229, 0.04435018875769206, 0.008910299644672444, 0.02111738720642669, 0.01683091864522014, 0.006029772605480892, 0.026222291136426584, 0.04092913732997008, 0.021618464961647987, 0.0602575737450804, 0.03116865875199437, 0.02489485781240676, 0.020153733469279747, 0.06019598990678787, 0.010424163857741016, 0.010319674553881799, 0.04176166926377586, 0.010198943666182458, 0.0459682674679373, 0.041548775508999825, 0.014888669829815626, 0.01228679676673242, 0.042959999426134994, 0.005925957595796457, 0.028231726793040122, 0.04041317930178983, 0.008678488333576491, 0.032925854104438, 0.011112243319595498, 0.007384544953570834, 0.010703258881611484, 0.059390914892511706, 0.04562314080872706, 0.02868774812668562, 0.06570453396333115, 0.03603897616267204, 0.03246158008862819, 0.025737886682951024, 0.04134362044611147, 0.043184808255838494, 0.10546908807009459, 0.03602753945493272, 0.02905024528237326, 0.039875179063528776, 0.014470434415021112, 0.03019361410822187, 0.02840392880274781, 0.044982681782650094, 0.019950534283582653, 0.05485082011935966, 0.037612118891307285, 0.018583879939147403, 0.04313760257459112, 0.04464849650061556, 0.026457406913063357, 0.029124225955456495, 0.019301532501620904, 0.04384411359205842, 0.03616296486662967, 0.024901629591892873, 0.08486179634928703, 0.06483756977000407, 0.04666203220507928, 0.02679661165789834, 0.05342505519677486, 0.06467528454959393, 0.045284266849713664, 0.06666850152292422, 0.021635068713554313, 0.040231182639087947, 0.02861448670072215, 0.0479114255202668, 0.04187323399154203, 0.04090139203305755, 0.0066659309917927855, 0.03916308031018291, 0.03994326326729996, 0.017757163050451448, 0.03643626859411597, 0.052820188725101094, 0.029864334634372165, 0.020714271248185208, 0.016374300200758234, 0.05951616567160402, 0.003653250351947333, 0.020308627746999264, 0.016774649432461177, 0.013968576344528368, 0.01922464769865785, 0.012759704292485756, 0.06253282379891191, 0.032128755269306045, 0.03235108405351639, 0.007009302789811045, 0.0009952613826109363, 0.03581846245963659, 0.05830131657421589, 0.008438916278204747, 0.0698887880093285, 0.07123559181179319, 0.034522786270827055, 0.030303394288889, 0.049351093625383716, 0.06332592945545912, 0.05847178492695093, 0.023487652518919537, 0.05835115497133561, 0.014331385626324585, 0.017643728958708898, 0.02993944167558636, 0.04018288112378546, 0.062205878485526354, 0.04965108074247837, 0.021976327723158256, 0.028435743613434688, 0.06549776398709842, 0.02948785965730037, 0.06294696764754397, 0.042269732537014146, 0.040345631140683375, 0.014681608083524873, 0.03661527291738561, 0.048315404914319515, 0.05432178332869496, 0.03603068446474416, 0.05459768584530268, 0.033727248066237996, 0.025886085516374027, 0.024470183100285273, 0.0447940660108413, 0.0503273019567132, 0.019814742462975637, 0.04057756458808269, 0.029517447176788534, 0.04878783492105348, 0.06042657646217516, 0.055747426114976406, 0.05125815700739622, 0.04255302429997495, 0.05142147020835962, 0.038704231181847196, 0.014462370026324476, 0.04706404384757791, 0.03679928143641778, 0.02920787575255547, 0.03027886864063995, 0.03245403817189591, 0.0043277451186440885, 0.015622408761243736, 0.10022789359624897, 0.029230752560709203, 0.015572790888005068, 0.02982425017814551, 0.046785033640584776, 0.05817126855254173, 0.03223874240315386, 0.03830282004284007, 0.017626750316204767, 0.07234026039285318, 0.06421761946486575, 0.016480752167158892, 0.011133822429526066, 0.015628513880074024, 0.09130058477499656, 0.002117021200579724, 0.06921332675431456, 0.020598184084519744, 0.025869125533582907, 0.08570528323096888, 0.017975564813241363, 0.07276880953993116, 0.03181995398231915, 0.055050251739365716, 0.028304553956591656, 0.012341451914315777, 0.06579019900943552, 0.029007813094982078, 0.050674226733722856, 0.027157051156141927, 0.03479625623939293, 0.05626127050657358, 0.011840400452326452, 0.04013524457280125, 0.018959879941706146, 0.011557987392214792, 0.09018637599157435, 0.04523926979995199, 0.021137846733576486, 0.041817923209496906, 0.027530745835974813, 0.034854528826794455, 0.021930840431845615, 0.037948020866939, 0.038602335578096766, 0.02498000208288431, 0.01801656698808074, 0.030449557517256056, 0.03325827519542404, 0.006065078054754329, 0.038908052923423905, 0.02954464964568615, 0.023454278774027313, 0.06152431041534458, 0.059211639155234606, 0.020499723564301218, 0.007057543661046241, 0.034693169806684764, 0.022421960685668246, 0.022070528739797216, 0.005786416021042636, 0.008434398931318095, 0.021658608789688776, 0.03669732137184058, 0.04468759708106518, 0.03157231244923813, 0.02328089272071208, 0.07493201989148345, 0.07446191047451325, 0.03728178429550358, 0.061055273083703857, 0.010488542412141604, 0.0356586606773947, 0.0787742380052805, 0.02184865457404937, 0.017278895946219563, 0.015794626037989343, 0.06566589139401913, 0.04051100369542837, 0.009500159466240023, 0.029389353335968087, 0.023660633147561123, 0.04499343317002058, 0.042842741789562364, 0.0025357332862248378, 0.017927168303036263, 0.01989644656090864, 0.03128014884090849, 0.013959528080054691, 0.05783324954765184, 0.03315860518653478, 0.07856582597430263, 0.07143751026264258, 0.014222272954482054, 0.047277690776224644, 0.04564652651814478, 0.06642465639327254, 0.015788907684119682, 0.18459775884236607, 0.12422609621925013, 0.10331313804324184, 0.07479302877826349, 0.12368428600685936, 0.13894609920680523, 0.18987332790025643, 0.12869460215525969, 0.14568745318268025, 0.09144233752574239, 0.11270649864205293, 0.11176290748906986, 0.10438391380012035, 0.11715182582182543, 0.18802715625081742, 0.10712023518447365, 0.11922872651900564, 0.10198525858244725, 0.12515568919479847, 0.11438254799161639, 0.06247685823057379, 0.1267376257372754, 0.10204757523855992, 0.1435060580926282, 0.08675046464694397, 0.12876978383532592, 0.21654500599418366, 0.10035929190261023, 0.1229373953704323, 0.14271286422652857, 0.09954731618719441, 0.1795069548700537, 0.13752217989947113, 0.21038620147321904, 0.08873595310641186, 0.09045202923672539, 0.07229956186243466, 0.10926441262875285, 0.15540754874902113, 0.15943914598652295, 0.09881366376898118, 0.08488334662147931, 0.0732032415856208, 0.14947888973568166, 0.13788032425301416, 0.08605257102421351, 0.2308233641088009, 0.08964755811861583, 0.17716934744800839, 0.11814438684710435, 0.11863770894706249, 0.12723690537469728, 0.13284149606313023, 0.12674077413976192, 0.14777012142751897, 0.14064721363995755, 0.13753121798591955, 0.15255114702241762, 0.17341666881527218, 0.12956337125173636, 0.09233737949814115, 0.14482295885682106, 0.0711140458339027, 0.11954849293189389, 0.20770579815975257, 0.16359118318983487, 0.164657433118139, 0.1010265089571476, 0.09904503063963992, 0.14684302546083927, 0.1579359873597111, 0.1116064033870186, 0.18795075320771762, 0.06345909873821906, 0.0970579544082284, 0.09682163423193352, 0.1399825614477907, 0.09141913841345481, 0.19232743978500366, 0.06746147825781788, 0.09897793031164578, 0.14299757752035344, 0.10548696068248578, 0.16530387343040534, 0.13212276462997707, 0.06863525563052722, 0.10431105949516807, 0.16219806937234743, 0.11948977251138006, 0.15735136158764362, 0.1357155397002186, 0.10370773329798665, 0.17543022148311138, 0.10741859381752354, 0.12842162751725741, 0.13511252562914575, 0.1825931899781738, 0.18501546499984606, 0.1356471162289381, 0.1658798682370356, 0.12019854305045945, 0.15941167888896807, 0.17779062768178328, 0.08328327962330409, 0.13341544169400418, 0.08370726901505675, 0.17318584477262838, 0.08285914095384733, 0.1341324903603111, 0.07104331534355879, 0.08197068077112947, 0.11348234236772571, 0.08776986173221044, 0.13464220586631978, 0.17642200897846902, 0.09675378073006868, 0.10354909859597683, 0.25472915704761234, 0.12620781202401432, 0.13349774799176625, 0.05491659730406744, 0.12580834488783563, 0.07776180947465555, 0.070139757756676, 0.07890949039054768, 0.05589771483625684, 0.0984253313924585, 0.12810851074755192, 0.0755581787920424, 0.13045499340764113, 0.19105840288102627, 0.1206630002707243, 0.1966893207281828, 0.0902843971603683, 0.11695134586521558, 0.1196100903408868, 0.15427530450480326, 0.10011383185961417, 0.1077188794900264, 0.18587404250034265, 0.13449136753167423, 0.2776051509593214, 0.09864734805056027, 0.1827754851962839, 0.1473041714302131, 0.2176361038748707, 0.1338403538933822, 0.18214203204427445, 0.14788631376411232, 0.07936823434595551, 0.2293043684746538, 0.09408057667315006, 0.10687354020774364, 0.14098378057990754, 0.08344770222902298, 0.11257470678538084, 0.08604864230645554, 0.09942553950739758, 0.152573538678033, 0.10847191765372242, 0.16405626466231688, 0.10734662839344569, 0.07186873283769403, 0.061913294185485156, 0.10343828704208136, 0.16063154914549418, 0.20075633749365807, 0.09488042018243245, 0.0884058051077383, 0.11786871163972787, 0.21180839730160578, 0.06902077208672251, 0.157170830560582, 0.12269122286566667, 0.17958052163677557, 0.13937398338956491], [0.044328665626900535, 0.03859062745634999, 0.06801969544695956, 0.030461625262562717, 0.028228977029877048, 0.032501878283385716, 0.017039437545463443, 0.05325056991672941, 0.061335562329207144, 0.044983991355236085, 0.001546839318637337, 0.1088795272101249, 0.05827331343399627, 0.047255492503089566, 0.018698491289147308, 0.01906683063134551, 0.06706686943237271, 0.051820743962058, 0.02904116648382374, 0.07528796579156603, 0.039310186702225886, 0.03406843582966498, 0.0325662983980562, 0.03973006417176553, 0.04540044561560665, 0.05050178723675864, 0.028083874012476633, 0.06679694820195436, 0.045781554986855814, 0.08751023387802498, 0.07127188664994069, 0.023734591768256257, 0.034959511764879735, 0.05779124144464731, 0.02573068912274071, 0.021666328821863447, 0.04308734687843493, 0.06111710797995329, 0.007723705593629607, 0.09013145536716495, 0.0342904728438173, 0.03038306108542851, 0.02814521866717509, 0.030372499687863246, 0.05369339883327484, 0.03192999879164355, 0.017136724200099707, 0.04439489743007081, 0.05742967048926013, 0.022517243965661952, 0.01738965491365109, 0.0482292140035757, 0.05044958075242383, 0.005770625238905528, 0.04434191741581474, 0.005258269807589906, 0.06151964209441628, 0.0044157193042337894, 0.04492630909330078, 0.06672020589134522, 0.039674556614564996, 0.04411796693290983, 0.057422708719968796, 0.014719748536923101, 0.051850741995232444, 0.05415810711149659, 0.0180800948292017, 0.02035722442503486, 0.015235579339787364, 0.04504659978140678, 0.058097600005567074, 0.030904491498534168, 0.007633887913211116, 0.019461422493415217, 0.0393540098864053, 0.011301763239316642, 0.04545968511540975, 0.024372743775269816, 0.04434190723778946, 0.018657809722104242, 0.047351138799318244, 0.0445830110859658, 0.05159893425713692, 0.10624246871364967, 0.022907611947240572, 0.014469650707074573, 0.027785264321469834, 0.03386845120361873, 0.01834393129684031, 0.05100917197497828, 0.1109003469880138, 0.10016847428466592, 0.03963894709678633, 0.005710947235846626, 0.027830476806099926, 0.01982275765788342, 0.07252557509179626, 0.02193930515620325, 0.03472422296181321, 0.08930841953094516, 0.02915572015834706, 0.02361576841212809, 0.01107252951312278, 0.016006257717630694, 0.020064490847289562, 0.024140752652393918, 0.07934428884514741, 0.030219507004533495, 0.029199862253985236, 0.009175747632980347, 0.03463004908657499, 0.02474430955148169, 0.0072957103007606095, 0.01116977715199547, 0.03841975876795394, 0.01530517328397504, 0.010745108377055397, 0.01795381946223123, 0.02058647765911051, 0.007923114313078778, 0.03812894544431141, 0.056893169813390286, 0.019643336035577313, 0.02455561574814575, 0.026363290713301728, 0.04705895822761314, 0.020120617567694614, 0.010881902733152466, 0.04143350258735674, 0.011081041734931725, 0.0251234630455396, 0.009176816325634718, 0.04273885468553219, 0.025278508297300765, 0.015113554994708725, 0.0019911584677174687, 0.012307398786236132, 0.030335522922022, 0.028506429999002388, 0.056937210128775666, 0.025752134222005094, 0.006777005053923598, 0.02011736568861774, 0.023897404549643397, 0.030197281589997665, 0.04888888914138079, 0.028806505325649465, 0.05498117348179221, 0.0314713192970625, 0.0324047968855926, 0.015512540371024182, 0.01960403359095965, 0.0012182881037006155, 0.019586530780153613, 0.04050959912793977, 0.030821543985179493, 0.03072880521150572, 0.0036848170732680175, 0.029339457263371775, 0.031163681697632586, 0.05293316141303096, 0.030924728805465356, 0.05696185452065297, 0.025417077022471597, 0.04706682923382946, 0.01423231272825173, 0.018051536986604333, 0.02882180968299508, 0.02279483773080366, 0.01649061467365495, 0.0185091545738812, 0.045884651597589254, 0.01346352237409779, 0.007728524888599557, 0.011976763090517904, 0.03264820436015725, 0.03971402021124959, 0.03300776345921414, 0.05999473642025675, 0.056113546647663624, 0.03337380935304931, 0.06043638807854482, 0.03641303216240235, 0.07327176005180393, 0.13246682259653295, 0.012087390591789569, 0.027493445069662163, 0.08197658402579171, 0.020026421640068293, 0.0776630894147924, 0.01965916625756238, 0.051587999665311406, 0.03501710242458752, 0.06548932301146643, 0.02629072648206992, 0.01650538807734847, 0.03662108796249543, 0.04802144318819046, 0.026882492138871124, 0.03900836754058089, 0.06906457152217627, 0.0016954130426581416, 0.026435137393751314, 0.037621869439525266, 0.020473623714808906, 0.05073542719972985, 0.026556686764316897, 0.030935924633273056, 0.06271820635135684, 0.010203756175802221, 0.033553380253059525, 0.039784859267196486, 0.032348963631583114, 0.036300659977963994, 0.014015524182468653, 0.027108406980655024, 0.037671419459262064, 0.01402323488478682, 0.016460389331249253, 0.008229400779652809, 0.04760953171976975, 0.02325998366411243, 0.014503485855779477, 0.02488865260966122, 0.03986748108374221, 0.029754540883004665, 0.01170482491475663, 0.01831645062858505, 0.04275275108271411, 0.06871544489903109, 0.022922351424183165, 0.012390096937971455, 0.033813113280172856, 0.039220837210970264, 0.01781317781257842, 0.06555620620825461, 0.01823939279919224, 0.04561606029580746, 0.04986639008192079, 0.05274011820022549, 0.07162322529724666, 0.03892620373517275, 0.003954804460850677, 0.03827512563605394, 0.026084141406629766, 0.016803207275058542, 0.03165152801999024, 0.026630472358582274, 0.01649244162919266, 0.00889141601510346, 0.037630775211645026, 0.032062811843518696, 0.026415984046512415, 0.04227750176297767, 0.008447583714899207, 0.07374809842024531, 0.03812646879149335, 0.030603425510759865, 0.04466540559328028, 0.014741183458162206, 0.020471596591440693, 0.011700201546773314, 0.03833864329914961, 0.0419153710162001, 0.05420185226414885, 0.050379077571311166, 0.05360613583720156, 0.0497972575415458, 0.0434744273578482, 0.015228305444387453, 0.07759136147797108, 0.03676035048972283, 0.04950983010764633, 0.02310322511142918, 0.030489533407879726, 0.06126008887908288, 0.05310835576217089, 0.034848276126597605, 0.0436697165215654, 0.023897416424006224, 0.020568308187648654, 0.01424493347959859, 0.0823597866775734, 0.025754117240597094, 0.011161089359250451, 0.018376675700502734, 0.0632988762642656, 0.035715935818318806, 0.023612202710605094, 0.010552457866391965, 0.05402183013835123, 0.02006684536380427, 0.0629327998363546, 0.07293819223663636, 0.029492178532694067, 0.02988032091941152, 0.02414851848568235, 0.029868331205632006, 0.03361323721972959, 0.011410153271364314, 0.009259282927294927, 0.0372881489539785, 0.040801406505384614, 0.03356779572953071, 0.033615656197071075, 0.04581342238400664, 0.010360585126493658, 0.0229463308517422, 0.030211384940360273, 0.04764970777822392, 0.021148080737995248, 0.007304041862620839, 0.011508102345812534, 0.02966635168663093, 0.044088382806096754, 0.04594018629619053, 0.026242657365011315, 0.05490355246833392, 0.018200058124161193, 0.07882655305521828, 0.040983131754079034, 0.03962469786139471, 0.020930050473128046, 0.03122327064297029, 0.026102870669482008, 0.046177011981074295, 0.04299923571358834, 0.027678049003173198, 0.04085153667256236, 0.03198492280872805, 0.03362702505130853, 0.0265336182700204, 0.009975372314719217, 0.05007358753521528, 0.006354222606335367, 0.060849093432937346, 0.05291407083028129, 0.029401136096566916, 0.016047061420977116, 0.02812087452704353, 0.06376530123608452, 0.07036999825920377, 0.006621445811885808, 0.023699569183268716, 0.03455948144463556, 0.04826348680736763, 0.016371407945241247, 0.037779852747917175, 0.009181262426344412, 0.06472418656838791, 0.027759671676903963, 0.03391878493130207, 0.10720165260136127, 0.18573631346225739, 0.31930579617619514, 0.15641328692436218, 0.15252913534641266, 0.11808907267238412, 0.12277685398502008, 0.17187647574714252, 0.1976846908884389, 0.14092713647655078, 0.10158765063221965, 0.2630366784121309, 0.08998392828341041, 0.14112438660647186, 0.1268906896667821, 0.13227943836578301, 0.2035075527216707, 0.18369661005479948, 0.14182160847953387, 0.1226791585130351, 0.14680407755076885, 0.13981556040900095, 0.13308352950428212, 0.08328673336654902, 0.13900468392031534, 0.10242378897964954, 0.1265222044395549, 0.14395885808127268, 0.061548269486853054, 0.2561943312840802, 0.18692208054874623, 0.1301706058106252, 0.1762832621378558, 0.07743861645992313, 0.10247611081493752, 0.13996475668890135, 0.11963667534291744, 0.14742495066353253, 0.054276426655373404, 0.13893617902483257, 0.17039736440139158, 0.18788602096693857, 0.057844540370362144, 0.12052926101854869, 0.10735743745629277, 0.11438101450247423, 0.09685424462492977, 0.08068894169160298, 0.11155849202935185, 0.10907183760511023, 0.09224507837955441, 0.10857945866882801, 0.11088978898312364, 0.1449542282415288, 0.13833701903266565, 0.09759687406143971, 0.1498241147824696, 0.10084208313907896, 0.148045633786491, 0.17135348809616907, 0.11247938618596111, 0.14027701850448335, 0.13013272998588427, 0.15836300301764691, 0.16029449366033077, 0.10132452153733798, 0.12094765928174768, 0.09452288651040622, 0.18774454641555036, 0.0731066589110664, 0.16641086260122911, 0.1160518934151956, 0.09336251698966537, 0.13748657038169249, 0.08322046763662781, 0.05640876705625227, 0.08890643502984728, 0.156142972143633, 0.08590678099010672, 0.1314362228981086, 0.13440710705305847, 0.095160573720932, 0.1677180603146553, 0.12181211289550577, 0.15929415662373814, 0.15509858461362974, 0.12976626679301262, 0.16613602877727576, 0.13111524869288715, 0.17794359661638737, 0.1686287357338837, 0.1704282784568412, 0.11941320661987577, 0.07773124147206545, 0.1771632677742413, 0.1126498816800969, 0.22741236857005528, 0.06521868253392832, 0.13307728698211058, 0.1388414419655289, 0.11144483062837805, 0.11050062879387822, 0.1403890039239611, 0.10795874840446881, 0.09654739751879658, 0.08745828523699727, 0.22351707544709953, 0.08993169465767485, 0.15224097509469303, 0.17519250352467808, 0.16922473375286373, 0.09556673121239458, 0.04999664505677564, 0.05956785646932466, 0.12581397672849043, 0.10583657585084438, 0.0874886903911829, 0.09406339616647788, 0.11844761057623795, 0.10588374760534082, 0.09272905705230576, 0.1429208352097443, 0.12688368718538964, 0.0971228698534625, 0.19700934498437814, 0.07189654598810843, 0.14095505140721798, 0.12661842070519924, 0.167285059977855, 0.12434596621564456, 0.11252287349530629, 0.07113577252519981, 0.11002459576619522, 0.11760998623711721, 0.1185097915253469, 0.10146520220275436, 0.10259387056742396, 0.13673297581928118, 0.15313992542879923, 0.15236161862100872, 0.06148588497723852, 0.18140466803950922, 0.09299249827329602, 0.19106303048985346, 0.09502696339040995, 0.1358243224344083, 0.09318742102810315, 0.12857265584170818, 0.10206955298781395, 0.1278424843081406, 0.14125942864588328, 0.11504783800670079, 0.1582198864115136, 0.10939987535987582, 0.2004631289413997, 0.08424042790595974, 0.14432707189449243, 0.06733690601374422, 0.10953256966812269, 0.0929582661816052, 0.14300125518015452, 0.08435363468847104, 0.11907786104295935, 0.13268802501261234, 0.10153494203197104, 0.17927227674850396, 0.11274248135409184, 0.08933972035135541, 0.10764101081128631, 0.1925066951662302, 0.0531002710174237, 0.21050798493836606, 0.0731233712285757, 0.158961185919387, 0.11331621663911001, 0.2529073448053428], [0.02471974997648171, 0.037516503129154444, 0.01755691209941038, 0.03658025372507317, 0.01266288837151868, 0.08133171112941844, 0.012027258818436946, 0.016837536057989513, 0.12480713932641915, 0.043350615072995424, 0.01401729685520487, 0.014370146939264876, 0.05423461872019938, 0.05863287592572825, 0.06270670518279076, 0.027694091267351593, 0.050249996462038586, 0.026098704464467506, 0.028905530726271014, 0.03648454636069281, 0.05307799471276147, 0.04480222539444055, 0.03911558625155261, 0.07710721995681524, 0.006148816485490117, 0.0257910125822361, 0.01291286152055753, 0.031911501927035194, 0.04016000770830682, 0.01830937011566545, 0.026980197788881402, 0.027912703375997286, 0.022859452924292003, 0.02202325520504798, 0.029056813501353775, 0.0574412802234292, 0.0357164922170341, 0.06385509177510228, 0.006905388544380132, 0.023644261793898683, 0.06905656480895621, 0.06642251222261361, 0.03816394088789821, 0.011209350162451821, 0.026058233243280222, 0.023477903667039106, 0.04640795476734638, 0.0391447123672281, 0.004519560607150197, 0.0311191935491349, 0.033119789590792995, 0.06378983027700867, 0.025831549960587705, 0.008781418703230364, 0.027264738056276525, 0.09592906891235284, 0.03315584354900888, 0.06074539292603731, 0.046650931372174194, 0.02286476076447538, 0.021265828616118858, 0.06080561290894236, 0.02955321954297168, 0.023801500410107628, 0.005327152986345547, 0.01613849401473999, 0.02020594334628965, 0.008905184338800609, 0.05565897568262049, 0.046352548990398645, 0.016798472796965922, 0.018028188596612642, 0.04900697459067617, 0.07811605225184134, 0.036601549546633444, 0.11933377731059279, 0.028106133353763392, 0.02168357209302485, 0.04629100247153214, 0.007260883642759706, 0.037928689404257705, 0.036357548353927474, 0.016102762360657965, 0.03630278379257236, 0.08009603100695781, 0.04592989631263273, 0.041842564208699126, 0.01967038244142064, 0.042399315762200525, 0.01972021914220282, 0.0630181459710002, 0.02421079612603145, 0.018596229276486805, 0.009436449268832803, 0.03825291718489357, 0.01837301839675222, 0.05248376088482993, 0.07231463212519884, 0.03266585984134248, 0.017638836721224443, 0.09227973116295678, 0.03882304944896272, 0.0472789189246084, 0.005475593123784555, 0.06591207746948514, 0.031869453111929555, 0.0231736757060779, 0.009565745812973805, 0.09762890769967011, 0.023515268894178525, 0.08708422245191676, 0.019703399955428073, 0.02133722576711859, 0.04468705764572535, 0.03514375098581825, 0.02871292856122766, 0.043331948574632406, 0.03350643241511924, 0.017104529409802387, 0.03457808008949671, 0.07271867258740322, 0.010143685470601278, 0.053739817413900576, 0.042336666623928716, 0.00999238488397428, 0.06540437721248184, 0.08811500535479613, 0.009843782322215182, 0.056909854989498854, 0.012059259378085179, 0.013605140266008675, 0.001492378401703068, 0.0082351785053366, 0.00789379227041666, 0.01689332690356033, 0.0265761132219008, 0.057355228412364206, 0.015993083960243633, 0.05945175912763391, 0.025421987919669067, 0.04970122787303158, 0.03795254330283829, 0.01622234906868211, 0.010465815729860748, 0.03639460315129586, 0.004391335724254272, 0.034655202379716296, 0.03408088694725718, 0.04684793383681348, 0.008273146780473846, 0.0754550075424569, 0.030975418764033487, 0.030972015910914967, 0.036560138554445336, 0.004396157987814928, 0.017477867858750478, 0.03782057163438626, 0.00996995930160795, 0.06645833887159824, 0.025838874746114016, 0.011872647829087717, 0.026483065714793544, 0.03750439127907157, 0.027920299575531056, 0.043779615445860794, 0.06020709752504315, 0.015794831294832484, 0.00384475159392293, 0.05010940061349954, 0.057218903941767554, 0.004299361998814025, 0.006032549934129098, 0.014159692517880882, 0.032401584022279294, 0.021090610518253276, 0.02881608284743769, 0.026901348627039363, 0.01670560340530106, 0.04191522852384618, 0.035999824692096026, 0.026818748862881745, 0.021334426810166666, 0.027259308079789792, 0.03385850388024535, 0.0765200157516769, 0.02816997162465538, 0.018629940592550805, 0.06971868606550352, 0.04892375905598913, 0.06468365767172404, 0.037891203737152476, 0.06641048858208315, 0.0540515703282186, 0.0306769549580557, 0.08249321380364043, 0.0251111645983266, 0.04797547244067703, 0.039678763531680615, 0.06937762722373009, 0.011829169001430273, 0.0334480648328151, 0.029408376065215895, 0.07630518477942262, 0.020402172281007682, 0.007890209605518197, 0.03737960529646703, 0.06571413523384503, 0.0070564139002401915, 0.06645817602319376, 0.05739157074796302, 0.02081758838279971, 0.11888021736272744, 0.011051834195054002, 0.01581003556826285, 0.01236696059017309, 0.0134115822147578, 0.007632888770396156, 0.019051439760785018, 0.07151493789362055, 0.018139822874218225, 0.01640527362802199, 0.0037738162708202644, 0.06471304502338171, 0.033100200284804614, 0.046909918010767014, 0.07111481257847377, 0.030887775788349763, 0.007835227064788342, 0.03095763436119471, 0.055121277392442734, 0.015937265973272066, 0.05569393041410616, 0.011199936337236847, 0.03637278485777123, 0.012219629433405186, 0.013250677813110607, 0.01532248271230076, 0.06249096497361149, 0.011626141993994159, 0.013973481304544424, 0.04399535904771515, 0.03932095166029675, 0.05502210949946727, 0.028350039551566755, 0.010491751034611037, 0.014803143883390086, 0.039833496657333205, 0.05524588356326733, 0.03078010245891554, 0.044027229837541065, 0.05164039953212653, 0.05004369128229363, 0.025183404829087, 0.027427908764886003, 0.03444901933627469, 0.046175872042242966, 0.042816085541354756, 0.012821199921225863, 0.08358693082949945, 0.07147962014589991, 0.03172121695908053, 0.008374701420377408, 0.03785504121333361, 0.05425015377945133, 0.03758305384378348, 0.08655974880925246, 0.005823981840096946, 0.039099762814917734, 0.03480825613119772, 0.004200124555999147, 0.044342249897973876, 0.021975752664729953, 0.02193398035264441, 0.025569574375237738, 0.03071129900802459, 0.09654736359204565, 0.024012361952502812, 0.012426597881130874, 0.015152017752240812, 0.031728847085365226, 0.05825063679367304, 0.050558271884386025, 0.04758889746985265, 0.0785004287692053, 0.047283024061471224, 0.007171552811217095, 0.03272549628413149, 0.0270541988180152, 0.03685432080445545, 0.013582399164858674, 0.046069202944636345, 0.03365326400047966, 0.03312671064798321, 0.02130013534666172, 0.05490444813455854, 0.0859116053740893, 0.010730614020888294, 0.04097003602821912, 0.0509100583648043, 0.051732269780976434, 0.0361151552892157, 0.035106669047049115, 0.010248985623807778, 0.03152370559317725, 0.03718699973874858, 0.02658436929674021, 0.08217274849968297, 0.028605411294847727, 0.040747076206441434, 0.007669996154228491, 0.050548735074698925, 0.043713224186961136, 0.00605329274964918, 0.040136109704950025, 0.0580390967162592, 0.007801822785820279, 0.013966596718611462, 0.042880699038505554, 0.026305275969207287, 0.07401119358837605, 0.030596853899104253, 0.009377166512422264, 0.06716683121131999, 0.016414135295365537, 0.012389920518866606, 0.0271997123491019, 0.06776856963655778, 0.01894625835120678, 0.05679429029779775, 0.03840748406946659, 0.01452298864855298, 0.01479642977938056, 0.030880909013961042, 0.025010894085945826, 0.039061473083815405, 0.04778026130848697, 0.025157768079744916, 0.012702980461264295, 0.03756521515814321, 0.02657302249489086, 0.08762225322425365, 0.05506423295342496, 0.024875648486028825, 0.04939301012616072, 0.06998237155910049, 0.05876870506576129, 0.058539529863212786, 0.039356544214699946, 0.036747346366090436, 0.04189954079421503, 0.05334038420447281, 0.016553440231031606, 0.1339238001299756, 0.11848811911685125, 0.09080997002976281, 0.1017653928803546, 0.06667736319026776, 0.12953956824328217, 0.08827634062618017, 0.18722041882574558, 0.20452148760003702, 0.16048400849103928, 0.09984649584761687, 0.12844248568373068, 0.11893619650176593, 0.17045968105750425, 0.13069495053163596, 0.1441399319363492, 0.17158025449940137, 0.10783147559102092, 0.20597188334379876, 0.08380732578890664, 0.12676940831754888, 0.15071304993970053, 0.17609089746006898, 0.2616225028676646, 0.10722743693206992, 0.0712480361440352, 0.1005965688132814, 0.09137447045317718, 0.08979237106229578, 0.1505926778273923, 0.10880685610962765, 0.1093897380466972, 0.15650141505258425, 0.13586531952023506, 0.11024094665689127, 0.17172257043421268, 0.11475339452070848, 0.10476265169147934, 0.08445660916290113, 0.1001615057300244, 0.1540566940924951, 0.15308499123368943, 0.1477230175265244, 0.10237218639148132, 0.09709805582783052, 0.12368254895721163, 0.12341251916119031, 0.11381902465862886, 0.11209241087947573, 0.1902273196194853, 0.0859004163316318, 0.1365609129092523, 0.09284881169774703, 0.12916536975119794, 0.10153349675238132, 0.15184965037873813, 0.07976586265223366, 0.17027669373367513, 0.11394002102315426, 0.07604217782084431, 0.08827418288482086, 0.17805008590221405, 0.09326572396925517, 0.17542909511498042, 0.167964599228331, 0.18658993765711784, 0.08202174053128276, 0.05176993525986161, 0.11328596076262848, 0.18132650080536092, 0.08304750906037432, 0.07513509185186454, 0.14904139749705791, 0.2774933012468474, 0.14364363785300935, 0.1494204950119768, 0.09382628888956138, 0.07491501580391612, 0.14015634783676692, 0.11654345132410526, 0.1728107234729188, 0.10425304475107364, 0.1606325940894229, 0.13847533161086695, 0.15614688050534042, 0.1424028958593096, 0.14107212583933557, 0.1298123121793781, 0.10210010741970368, 0.18360394931265286, 0.13282742324684346, 0.09761652443557978, 0.17814251594245434, 0.11897245741316251, 0.13768173062375613, 0.0771998603429113, 0.09118954930454493, 0.15259479039481708, 0.1748848014644214, 0.21042434871196747, 0.17184748873114586, 0.16230048744806222, 0.11887944383280617, 0.0775971222402794, 0.1924917266837188, 0.2019212328429733, 0.14112856638218674, 0.13271492214075156, 0.22852155619433948, 0.07222094679517405, 0.12851309403777122, 0.13646852358111314, 0.12567852756806783, 0.1604312863200903, 0.10390572981642825, 0.11996154433914594, 0.10160919411906175, 0.12095342682940619, 0.1198072861880064, 0.12045595209513392, 0.1004349146304386, 0.11560045049658843, 0.11238371953368187, 0.16404102476579802, 0.12250496500304767, 0.11614869322095599, 0.17107968564544404, 0.06109930322106395, 0.10489121372146265, 0.08963605016469955, 0.1373485563588994, 0.0933341881526368, 0.17802423371800355, 0.06719744671136141, 0.08544441365769931, 0.12862925923296384, 0.1072860759283815, 0.1833192767309291, 0.14275424129196576, 0.08822179998138122, 0.12533907006893838, 0.11724800137536866, 0.10854785250765936, 0.13166231076632226, 0.1376419956130641, 0.10919812654278108, 0.17035387030669621, 0.1014430887464966, 0.13828730955719948, 0.04324236838147044, 0.17816318411912235, 0.12136816100350448, 0.07730317408485071, 0.1303437136645828, 0.12132488404001508, 0.11084480889673744, 0.12128352054527827, 0.12646104129297392, 0.17074959192957195, 0.09350386261940002, 0.09620939886995725, 0.08722713549754449, 0.12405119703284331, 0.14346390749726975, 0.17488139521862778, 0.13855233176478318, 0.08555033297411033, 0.16317335489605153, 0.10762206611356565, 0.2096059676259756, 0.11154066691441195, 0.06523413956165314, 0.13578047550150327, 0.12049895764461585, 0.10132629929908685, 0.09802035455192838], [0.026076572348496745, 0.009652447321319153, 0.031332881189882755, 0.052578657399863005, 0.04080489756805556, 0.02852822793647647, 0.014926966346268142, 0.0804807400064809, 0.01635165070183575, 0.051394525582769086, 0.021565841178276708, 0.02315631029861314, 0.017740481267017976, 0.05976348490055118, 0.018357347630496536, 0.0263774619171662, 0.034707934728690555, 0.012943406622590763, 0.035816942541194816, 0.04556946868875197, 0.02954084306423153, 0.02006478261734758, 0.0385270114056766, 0.03666612572435822, 0.04053002303200109, 0.05633367019306336, 0.056471280487520356, 0.020703813327210288, 0.052494861717735014, 0.017258899519219995, 0.04751310510826962, 0.09598305994378668, 0.03896871395409107, 0.03235935539539371, 0.028511006717703173, 0.039301060406225066, 0.008353571839896696, 0.07656547081257616, 0.02046699612401426, 0.04028486154441323, 0.035632649037454805, 0.02688357270588832, 0.00980755703390709, 0.002666875233574371, 0.0585621657914349, 0.008329790035661842, 0.009252155765092798, 0.03819785067545516, 0.018257648783868978, 0.06215586366930178, 0.004001027538574168, 0.02441124724490302, 0.026389582248936807, 0.009726347418368926, 0.06279145420661994, 0.05366509374497192, 0.044302158656397035, 0.028238278048645173, 0.07400568388402462, 0.01740252672295485, 0.022621624703918184, 0.04344711293067251, 0.05303270250026669, 0.027984227752313018, 0.044636479645435295, 0.013591939367220869, 0.008639697334729135, 0.047691261262765954, 0.03005974254171763, 0.04862749031079667, 0.009689541134451116, 0.03922092881319778, 0.012067379745920854, 0.051545957635555945, 0.05248336733451911, 0.03802842048129865, 0.038756763362990956, 0.010740507061460187, 0.021945562945412736, 0.009473576160546924, 0.04828641789832285, 0.03682996139728597, 0.022711667997230376, 0.07013466195868594, 0.06585862248071603, 0.0166560584745769, 0.06893572450748511, 0.020163977651723793, 0.05914601803358112, 0.030218146541821103, 0.026285576401278377, 0.02307678938710264, 0.007408364925400487, 0.031151532528123686, 0.017719059916479245, 0.042548474722674916, 0.06993895888860736, 0.035537576103316884, 0.0524059091694653, 0.022670141654089093, 0.08329799026250839, 0.022367671098826186, 0.008563214563764632, 0.057014597047652514, 0.11919203134519712, 0.013493838470562227, 0.11666846461594105, 0.015598185061077987, 0.01769189815968275, 0.01747902136828218, 0.05744232516735792, 0.03954540425911546, 0.06942000852099486, 0.0368567567451724, 0.03800641559064388, 0.007466179501664425, 0.018332229960443716, 0.002485188576559137, 0.012836517001103078, 0.05229309254458972, 0.024491361874554838, 0.06771493144333363, 0.03543441163908158, 0.02272063314116427, 0.063429806381464, 0.026492680556007793, 0.05200911885393517, 0.025885242436613356, 0.028935789995427643, 0.06522852807704892, 0.029412718689335243, 0.004424405824725649, 0.07772578605051551, 0.05121174521212067, 0.034285947015242915, 0.014309046557173133, 0.024796382025150315, 0.019018961682117412, 0.01754422010188656, 0.047733581491879055, 0.051267385083649836, 0.034400497297091145, 0.028326353590403284, 0.06459704267659358, 0.04175588136006679, 0.04891230199219925, 0.023452160048431585, 0.049130624027124474, 0.029832837038806508, 0.0213473121901708, 0.01554769866301545, 0.03518462593534163, 0.012112768649655794, 0.012234900712168642, 0.07231383823922702, 0.07167201875043766, 0.01806320439624999, 0.040396558586508036, 0.02878678370533245, 0.037963579674916606, 0.009398339349510414, 0.061828192323446274, 0.03401050590244787, 0.06473192865295069, 0.00930824940691569, 0.046108245849609375, 0.04503339888261897, 0.03668729601694005, 0.05226565598111067, 0.02877844450995326, 0.026628750575972453, 0.0387397253486727, 0.03651121278692569, 0.05476556219426649, 0.016880916498069252, 0.02885757865650313, 0.015406968803810222, 0.01124419887284083, 0.048811960233641524, 0.012388739867934158, 0.006737979112326035, 0.020781279973951832, 0.04640380213303225, 0.02084630398478891, 0.027889509352722337, 0.02167086991747575, 0.017527283867821097, 0.01512254388736827, 0.016107780127120868, 0.11485184995191437, 0.05049486278689333, 0.039059786924294064, 0.024500315144125904, 0.035150817928037474, 0.020908540913036892, 0.005952978556576584, 0.04699678406385439, 0.03445223219958799, 0.03463666819568191, 0.039633081161550114, 0.031538416232381544, 0.08860496192106179, 0.022546090185642242, 0.02245723263227514, 0.016646833790998374, 0.029396345639335256, 0.08610244334808417, 0.018547400200207318, 0.0837938907955374, 0.040794580443097014, 0.05292286125144788, 0.016061570196013366, 0.07462943398526736, 0.05400127391996128, 0.08040004862206322, 0.03068295320762055, 0.040575627370604446, 0.03178039539073195, 0.02849977696314454, 0.0047096479517806855, 0.008425608510151505, 0.07484173402190208, 0.026061987238270894, 0.06717470221753631, 0.028058598583031977, 0.023611529264599085, 0.019068123240556036, 0.0217763973799135, 0.04305670762966786, 0.043151169882289, 0.013741727668925055, 0.05928440525063446, 0.013932117809807616, 0.01841426484419831, 0.00433634639817423, 0.024228897743991444, 0.014357977413705416, 0.05862389212208135, 0.04376633312287075, 0.04733603460980313, 0.05394635329555188, 0.033022250181862285, 0.057986272765057426, 0.0323349620614733, 0.028804754705301354, 0.05473911968458976, 0.040960645103561025, 0.013025576365180314, 0.02392538563747491, 0.044454645831137896, 0.027684018414999758, 0.04164495784789324, 0.03063316909330232, 0.018391888455620835, 0.014131342476632978, 0.05279084208554455, 0.030492030416748354, 0.04348177249942507, 0.03801149781793356, 0.0602092824078032, 0.013774091244808264, 0.03370877495035529, 0.038722113972263675, 0.03918160092351692, 0.030820804382009164, 0.013638720964081585, 0.01900599996692368, 0.0436133370468659, 0.06322773865291051, 0.03954232371013079, 0.006336755842702197, 0.03804814549429076, 0.033958336737539084, 0.01929574629424938, 0.03308949639488544, 0.04466063888477428, 0.04798031039535999, 0.005877930039007748, 0.0250212230852672, 0.0944797181125198, 0.06495536344924144, 0.03118758987901466, 0.01802696384090398, 0.030638953604336296, 0.05001226493290492, 0.04268377460539341, 0.03917037456163338, 0.12344978430441447, 0.04900065742965255, 0.04777378808440907, 0.012964117207697459, 0.020633607005168284, 0.053027267434767315, 0.03797208511137536, 0.027063610098723854, 0.03774312025468264, 0.04194944025948644, 0.05002981863383736, 0.03379101000194039, 0.029657815716096332, 0.021537049241097908, 0.04553188124139394, 0.0487694500147232, 0.02894902482096638, 0.03212947112375072, 0.08197855856269598, 0.038260262326470444, 0.04580852336117199, 0.03114114754966327, 0.021790271724707315, 0.014291950867378285, 0.02354125169638012, 0.035202766569065194, 0.026719000822465335, 0.03910400365878429, 0.021184804749542048, 0.028902311077607528, 0.02501101452591164, 0.020260294001283388, 0.02966761715444071, 0.04400623596406408, 0.02608149851273213, 0.013553275593689509, 0.08463673985430173, 0.03673216075237308, 0.0029215101302335305, 0.029677971598825285, 0.04074872504653675, 0.032729289294885736, 0.04148054202752454, 0.021407089428976178, 0.06046758033335209, 0.019214530741529803, 0.03491984800036464, 0.009996551088988781, 0.06060364017529147, 0.05511150309549911, 0.023011621187574098, 0.041363382778529606, 0.033661135006695986, 0.02178020735404321, 0.02126002374903432, 0.07054741481052977, 0.05452394944482616, 0.024070766854232976, 0.03403700269492609, 0.04264915914141706, 0.006293456402740308, 0.024456681949751716, 0.047861780505627394, 0.025627972491617714, 0.02287091507709452, 0.06212739912526948, 0.15376518187778337, 0.13394688389131001, 0.16301233853612626, 0.07265437460903611, 0.09691392856517009, 0.1131433327017086, 0.1374114565551281, 0.08816390058823995, 0.10415777164910521, 0.10402627156249114, 0.11246079432645015, 0.10431351579193558, 0.2141059168747493, 0.160107625116195, 0.10852070432156324, 0.12792415278298513, 0.10166713422430412, 0.12991756653147085, 0.09671985397913627, 0.1463417780718633, 0.09164931784783091, 0.11039027185844523, 0.18300697420324596, 0.14310486747750215, 0.22148767220122473, 0.14122855530253478, 0.10020389381263937, 0.12255919352173805, 0.21153458128018038, 0.26906027804527965, 0.2084090725651809, 0.15359500529510633, 0.11154639374996934, 0.16502780467271805, 0.20391723859523023, 0.11536810653550283, 0.1745582361306463, 0.11438079737126827, 0.1255255586334637, 0.1021705868520907, 0.11643009526388985, 0.09332373192799942, 0.12325154351336615, 0.14174452690141542, 0.10698493530175515, 0.08052389483366694, 0.1251574262444462, 0.12966724139239105, 0.1422069620873247, 0.06293990409799985, 0.12032700330018997, 0.14661917675818714, 0.1447327272700412, 0.18445662355848721, 0.19910725312573568, 0.1121635145640799, 0.09546999247478587, 0.1483695935457945, 0.0701580782021795, 0.08594131163720574, 0.19305231874542578, 0.13201121347291128, 0.1895025356539658, 0.1356649888413293, 0.09545605536550283, 0.19153430020170553, 0.10271315023835216, 0.0780374032578298, 0.16643083867217812, 0.11473862959870271, 0.16266011100794586, 0.10026120288031441, 0.12520087962704046, 0.09574633943183081, 0.10519846116325685, 0.1356368703501565, 0.12152017998908247, 0.1543876834745918, 0.17437797651759215, 0.16189012303948402, 0.10950618144124746, 0.20425038571868623, 0.1115560018058334, 0.1498558430799416, 0.11728620289691857, 0.122042624812041, 0.11172321319047894, 0.10656454893095152, 0.11829937781606402, 0.15306775644421577, 0.11460100912622043, 0.13651188196880476, 0.13011033833026886, 0.1225033908018044, 0.10907168832740613, 0.1434867198445967, 0.13216480665973254, 0.12669318169355392, 0.1295234869633402, 0.257099307009152, 0.07505090601210083, 0.06592576352081128, 0.20325129718652793, 0.1724644670529025, 0.13232236249106272, 0.23521101581198828, 0.12551837973296642, 0.14672014276896203, 0.1266659860100065, 0.14984284234898432, 0.1837857152734484, 0.13286343988563332, 0.1579100808926991, 0.13213226412023815, 0.0781865588256291, 0.10989190145794835, 0.14309031968670233, 0.1024494104619537, 0.15300264422382626, 0.13791079047535146, 0.22934125363826752, 0.11583341870989118, 0.12759179276015076, 0.1659382629607405, 0.19934203981288842, 0.12395766776587282, 0.06768727435597352, 0.0990847520796316, 0.11817235606057302, 0.15764068891959532, 0.10412009938486985, 0.16799806457545075, 0.10735513722257954, 0.07466039553816829, 0.2522325281585966, 0.12555204864059175, 0.14202349978898252, 0.12129418711577143, 0.14329071821910994, 0.17453551877822193, 0.15004625357687473, 0.1387170257845095, 0.14107394431318554, 0.14696749592466013, 0.2380365984780448, 0.094239252087261, 0.12104384840599128, 0.09051051216998271, 0.14613422778035912, 0.1525905699070011, 0.10969264964972224, 0.09521365551544086, 0.08112898522189685, 0.1455794439784118, 0.19462278804608754, 0.10952509899756738, 0.14008188540382044, 0.11445411986538342, 0.12058982705431325, 0.08103819045105151, 0.1592648574816329, 0.14551529527774879, 0.17569978987532003, 0.10328136903366872, 0.16644250947449887, 0.11938746300126825, 0.08224248832889966, 0.1102701033066426, 0.11663498569812093, 0.10357748171580689, 0.1146971575383629, 0.09098424496395247, 0.09318411656256233, 0.09671395072447402, 0.10622064702744995], [0.036042199204010625, 0.08160534394638878, 0.024448936472513845, 0.05464102387694376, 0.015744597651064396, 0.04245642466204507, 0.045297661130981784, 0.03758554067462683, 0.04076881307576384, 0.07601344186280455, 0.05900197183447225, 0.0040868333806949, 0.02359669648909143, 0.03872079422165241, 0.04884827542783959, 0.049235050566494465, 0.0656309604112591, 0.04000267579353281, 0.007423541209261332, 0.009391266470109778, 0.0617475009390286, 0.04303373921928661, 0.011332414362446537, 0.023700442797105228, 0.024253440355615954, 0.032849240715482404, 0.04706089883776648, 0.043348460724311214, 0.030945010217172757, 0.012426854028100414, 0.01631940502141203, 0.018179600293348943, 0.01454368227028421, 0.0030952394798597588, 0.02761152203726981, 0.02839079575746187, 0.034581153853131194, 0.029241676974509443, 0.011189014467942928, 0.06266565381416253, 0.04313146183267236, 0.054143864661455154, 0.052113419864326715, 0.0482675173053784, 0.037063126385744126, 0.05800096983356135, 0.05620817853403943, 0.014440164967839206, 0.02960976865142584, 0.02041652499298964, 0.012360461072863212, 0.06519688120377914, 0.04269401369882481, 0.027187208645045757, 0.007417887316218444, 0.06980775057205132, 0.048476380562143664, 0.036575229173260074, 0.02966349505420242, 0.03093383474541562, 0.028332543526110903, 0.038920280124459944, 0.04632550258455532, 0.03342748825837459, 0.01645844872109592, 0.02260461892001331, 0.026230006079588617, 0.0068410782675657955, 0.03991113802684205, 0.04908932838588953, 0.01524326714154865, 0.048117985150643756, 0.03008005448750087, 0.0470799622791154, 0.08519107582313673, 0.07008134267692055, 0.03664859237947634, 0.031107332757008926, 0.011085727019235492, 0.06457908185464994, 0.011504920016575073, 0.030585573254419223, 0.024748740385153463, 0.008307612118577319, 0.03624024661257863, 0.0357506835966238, 0.059357130633933206, 0.057985974209649224, 0.06088316946157387, 0.014635264141751187, 0.02725750148030264, 0.013761157519184053, 0.02111225069633552, 0.07840807336781706, 0.07153182663023472, 0.031836296498243294, 0.03062894182013614, 0.009578330941232187, 0.05669013177976012, 0.01608417898283473, 0.017881787880989056, 0.05273472045415214, 0.008244236947835555, 0.02954606099852494, 0.051144363292093785, 0.002937938311203782, 0.022817205637693405, 0.011719355742180986, 0.010041163070127368, 0.04039003447230373, 0.04688084278521793, 0.014247194697548236, 0.035558003400053294, 0.08889440460396664, 0.01475460488083107, 0.022433056429560696, 0.05313858110457659, 0.11104150262794324, 0.023647164227440953, 0.058846207335591316, 0.017882566499922956, 0.01532348185511572, 0.04229895364759224, 0.029984058745737587, 0.03204156691208482, 0.05870763012873275, 0.09943704067596368, 0.030763376570705856, 0.021095445080261146, 0.01106262459818806, 0.02092347546879734, 0.036444224417209625, 0.04364231049216219, 0.06388173105993442, 0.036849543917924166, 0.02716933603265456, 0.07585042382457427, 0.015636876824178865, 0.08126361335494689, 0.023022002773359418, 0.030929549796772853, 0.020595091661172252, 0.011660376630191292, 0.04156187462753483, 0.008019138892580355, 0.08277872098343712, 0.035064070618578365, 0.03453537988077317, 0.059036217496863434, 0.02719796003241624, 0.06914619928491966, 0.021464639376582842, 0.04323934890063746, 0.05236801977402397, 0.08691770995834044, 0.016802632216630236, 0.013265369792601891, 0.02647381049713918, 0.032268635263400416, 0.033892841144864044, 0.024884226865002086, 0.059283306023904254, 0.003607767301478556, 0.021603213190766316, 0.020968696435115168, 0.02593840565532446, 0.0056327609179009286, 0.01890302379615605, 0.014076671213842928, 0.04169891155990107, 0.0672103456620659, 0.030532016485397304, 0.0346970171002405, 0.06307669675775937, 0.04790166140134845, 0.027261952670024972, 0.01786138772565339, 0.02302943273181362, 0.06603053611304079, 0.03865245895992432, 0.018128954439557025, 0.031432500308645625, 0.012813326370503222, 0.019500236392819455, 0.028480642275618653, 0.035182206958000145, 0.01822319277562201, 0.03411553294530936, 0.030038029421120882, 0.02024709988784577, 0.0440438335894474, 0.037944590872419734, 0.04405424231663346, 0.05607973185500928, 0.05135999832834516, 0.012988567368925681, 0.027611406686316644, 0.08556612926934447, 0.029641459629471813, 0.059475996398500035, 0.014415944660348552, 0.023875084140204957, 0.011423857982403465, 0.038260540525828085, 0.018452909109847884, 0.0304677083290049, 0.014910143766818302, 0.03253464473943625, 0.08050441409328155, 0.055626137980393, 0.06634770373680762, 0.025856080697849393, 0.025523783439504247, 0.05059588986581989, 0.019252906985847012, 0.05386779929644295, 0.02176240598782897, 0.032405404174434285, 0.026751563718010272, 0.0065563637014877585, 0.041965487612677474, 0.027013405292694057, 0.02668271616234311, 0.03992457980556147, 0.03672203022454466, 0.017055722385911003, 0.04180692754951971, 0.05679618341049977, 0.04264405995075192, 0.028235265353162373, 0.03110581962391734, 0.061053753165262084, 0.017156817318339432, 0.010089910722204616, 0.06465543740029846, 0.025277081677424054, 0.05008541440059032, 0.010049145186452993, 0.03492623980024031, 0.022837883992386714, 0.06188791019043752, 0.05517055939084717, 0.095525849477521, 0.059967405029705594, 0.03013796066599233, 0.023855903651565313, 0.05021990343396153, 0.019731224980205297, 0.03112969727122358, 0.02408554365060159, 0.04465196720723595, 0.025585983048326204, 0.047117726145578284, 0.010195619692759854, 0.007952300648737167, 0.03824769246524998, 0.02002412819170526, 0.031398824615670104, 0.05677793421117323, 0.06736140112791743, 0.015493878961673804, 0.019929457289565886, 0.03347662776442511, 0.07341501236494098, 0.033485207839735916, 0.013897700817324221, 0.009108900059280651, 0.045999609000448666, 0.009415973626476313, 0.032639285017337115, 0.030994838436267207, 0.02620473234648151, 0.04903547984680959, 0.05268705336909209, 0.00204949381960822, 0.025440813873761466, 0.0035472112316970845, 0.06692938466689416, 0.04737995278888515, 0.02875018013375146, 0.06522143060075385, 0.07655994075217418, 0.008504281252888697, 0.025353998710800494, 0.05937072169035673, 0.017688094970903227, 0.0419631161327873, 0.014146350823076708, 0.12355673499405384, 0.02948896906205586, 0.018091804647286023, 0.08665905919458185, 0.051795987611902614, 0.05755110790154763, 0.036609240741069825, 0.014033398491197398, 0.045677070772009234, 0.04730009939521551, 0.017259140399151614, 0.06646580954215356, 0.06340965389141015, 0.02607611264102161, 0.09673666807689837, 0.005592958477791399, 0.055569666903465986, 0.03537593888384955, 0.04622756962531379, 0.036031308716961315, 0.04323782558952059, 0.09282057785562106, 0.01591892177904291, 0.07412876335105725, 0.04989547209282007, 0.03947175946086645, 0.07694250558103834, 0.031119654952947582, 0.022658538705270206, 0.04005221224256924, 0.023094843507611325, 0.08295637502201966, 0.00956393582081156, 0.02187413695667471, 0.009356857111145343, 0.045763499170009575, 0.01632593592096652, 0.06179436056741646, 0.022094662534072995, 0.047031932177820375, 0.10306894686073065, 0.1079287300152438, 0.04655523418581911, 0.02351101956862424, 0.03242737174566303, 0.043273431714624166, 0.01585382821836642, 0.007328149363664644, 0.05322720117068716, 0.033599958289414644, 0.006782280239609203, 0.03990891921733107, 0.029731487655746083, 0.04150326277262398, 0.01956128079577216, 0.031598249450325966, 0.017811189704973782, 0.0331852003665907, 0.05913848629487412, 0.09239490569702216, 0.02060667595027813, 0.03575678023376635, 0.013729186645442886, 0.019996213261038065, 0.0879255515922393, 0.15040846914052963, 0.14943425570215496, 0.09819079576326267, 0.16668262944689818, 0.16857424937188625, 0.14934515048350605, 0.18359637686184474, 0.10267378163657018, 0.1334703487477132, 0.12606028494025978, 0.14070438700062887, 0.11041475340191807, 0.13796864237104142, 0.16839468186455114, 0.11177051386662892, 0.1277094100202833, 0.2037749226604189, 0.09603358366127525, 0.09811511196728263, 0.1296024548688105, 0.187337995373777, 0.16236390333090508, 0.10787697814937149, 0.13661591495786393, 0.09544559914086546, 0.13678482946540627, 0.11780969266380582, 0.11347219148384673, 0.08281133816178356, 0.08040787213082824, 0.09285483030336243, 0.14447379830692494, 0.09028702987624065, 0.1892788905118193, 0.09686995949596167, 0.12831426970660686, 0.09506367213491883, 0.10149533594293253, 0.10512701142579317, 0.10075211618095636, 0.1864672720964466, 0.14488199140344346, 0.11662060075572558, 0.13556988537311554, 0.12248303475124495, 0.13603721958185944, 0.11190269248826162, 0.14807342658085482, 0.1463997113917555, 0.18586439373237745, 0.15383636020123959, 0.16073843198163168, 0.13530494458973408, 0.18453974409827165, 0.12521219759115151, 0.08865548563855034, 0.07388637707169567, 0.11952249146997929, 0.0744131916601743, 0.12136722462517874, 0.13099573153470243, 0.1546740388231618, 0.27968952911240713, 0.10568534396588802, 0.10173103186701025, 0.15365950683397905, 0.08850801962294749, 0.15468108201665537, 0.11554843400205884, 0.16600908844598702, 0.16041346799050057, 0.12706496460097177, 0.16258837628577436, 0.14797385835221835, 0.1599800062498876, 0.1531821574483599, 0.11096593418291636, 0.09569762061749186, 0.19148567638226918, 0.14659605228475162, 0.09298655430653266, 0.12998263803975924, 0.08631416662995305, 0.08882732463202306, 0.1355722059628793, 0.13673502499503748, 0.11881156318954059, 0.18581399215119226, 0.08005746307649783, 0.09560910572430917, 0.16334505139717034, 0.08391721453517675, 0.2418093888887337, 0.20176989239241394, 0.11935934451009546, 0.1193090650652136, 0.08185874963445322, 0.15742772391864232, 0.08321808597871236, 0.08247270169002668, 0.1608150385852371, 0.11780940767909799, 0.10604465539966311, 0.2723158076405525, 0.12680606277925627, 0.15982570738664695, 0.1584782318345138, 0.10691729214574609, 0.12697896707270825, 0.15094114627156938, 0.06367463538689272, 0.22534948640636035, 0.13685456929462297, 0.07844574563205242, 0.15357055089303426, 0.10382750829947845, 0.2693175513829504, 0.09904863366058894, 0.18326442396002157, 0.07311693871659891, 0.16687241569161415, 0.0780528127881033, 0.1572175680526665, 0.13265439681708813, 0.13870581638600143, 0.20297513343393803, 0.09451289168958153, 0.09365601731198174, 0.10921705766980137, 0.11223755630531482, 0.1001882671511599, 0.14859171876949923, 0.12202050457043306, 0.0713473872414657, 0.2105182579585484, 0.17657632141241006, 0.12411122024059296, 0.17352659148829325, 0.12728455210370676, 0.06652353930154017, 0.11106542777270079, 0.17933021006839617, 0.15230489309344972, 0.0671188859269023, 0.14410715869494847, 0.1506529181663479, 0.1197647149009364, 0.1201078500598669, 0.1541502233594656, 0.12509969648505959, 0.10035726986825466, 0.1684917937964201, 0.1845837810209819, 0.18899790916059697, 0.1008728886289256, 0.09467120748013258, 0.09977577214262315, 0.10951095832777874, 0.1001161728054285, 0.11796289230031626, 0.12477344327739306, 0.07257419891123261, 0.16709509731403419, 0.08256493495511157, 0.2061787143881832, 0.09971714671701193, 0.13562967787895883, 0.1203027388879231, 0.09094007233423845, 0.13851617941898958, 0.2049709763377905, 0.1710989831813744, 0.07756903767585754, 0.13668550550937653, 0.07401512230613402], [0.0272853349867676, 0.06252659484744072, 0.04047103798282998, 0.035142343025654554, 0.026497528688716035, 0.03948307063962732, 0.043101952344711335, 0.02235139304372881, 0.055487126511122496, 0.05047591130382248, 0.021450975377644812, 0.013055137591436505, 0.04402243259495922, 0.03262253198772669, 0.023971529411418096, 0.03750128358868616, 0.04275367049766438, 0.0414141439832747, 0.06455881401364293, 0.03757956956646272, 0.021351475002510206, 0.03830368517498885, 0.047753839154860804, 0.01865503960289061, 0.019610442354210784, 0.047717547709388394, 0.024799538909324577, 0.026626869337633252, 0.01061091705092362, 0.037623175619436164, 0.02857227503721203, 0.04409008253631847, 0.054940882072384865, 0.012276447411360485, 0.03305453827072467, 0.020891611464321613, 0.040014458554131646, 0.019421326162825738, 0.014357300575024315, 0.0403356770319598, 0.06410555940653596, 0.07667333073914051, 0.03857162847582783, 0.03586948150768876, 0.06016616150736809, 0.06560199375131301, 0.015416056084047471, 0.08732167578169278, 0.029360834509134293, 0.02262192325932639, 0.023580959565671425, 0.041949250269681215, 0.038039938613240204, 0.06296654338283197, 0.03295749758503266, 0.07872574310749769, 0.03479596107665982, 0.06841379537114076, 0.039452027662524154, 0.028940651698836257, 0.02109597942658833, 0.02499139298950987, 0.04802237278116601, 0.09084599345390286, 0.06948427257261106, 0.013134163172383393, 0.025190451415255666, 0.052646660179431946, 0.03544174660263317, 0.07755929391298975, 0.05708977872771876, 0.02832194820179471, 0.030344320128538778, 0.07059788424521685, 0.06914712209254503, 0.031634968372860124, 0.026203806146181056, 0.050029950948165994, 0.019780445910458053, 0.015200566932825106, 0.02921415220147797, 0.050905712348009856, 0.008637693111917802, 0.02289055866588439, 0.04197492264211178, 0.02538791698004518, 0.04025728588125535, 0.015540129604882427, 0.030872902300740992, 0.023693547184978212, 0.019179974649367586, 0.03369793535343238, 0.05203210762036698, 0.022452820458316376, 0.03293525181444628, 0.019708524591156414, 0.03577790302889688, 0.035278026280658584, 0.008807784877717495, 0.027771110080980828, 0.0455027822671192, 0.03204471870724644, 0.05343093131003635, 0.06966230659080402, 0.034465073474815915, 0.13888680881687573, 0.014607937840212668, 0.01553484212074961, 0.03414339359317507, 0.03394233688179936, 0.056019206531345844, 0.04499982496989625, 0.07880122334297214, 0.03088308371869581, 0.01036053423636726, 0.06027221653078284, 0.02919405060155051, 0.05174650205299258, 0.00513203557680494, 0.07381861177938324, 0.046701967383601835, 0.04794303168143545, 0.03231515562427895, 0.04197575045483453, 0.01073278024393533, 0.05105860325108681, 0.024759483290836215, 0.018870805257133076, 0.03417541705338018, 0.0117709074402228, 0.03115031116509012, 0.01820430066436529, 0.006951147673784622, 0.052450285359684906, 0.021691482115004743, 0.022530580571453487, 0.04808503549013819, 0.022526156523131897, 0.023202579601534774, 0.015431499541071909, 0.00704704163529511, 0.05590725164594395, 0.010266186486530517, 0.050210241095295975, 0.06621538940817118, 0.036132946477404664, 0.0035516308271326125, 0.045489452446677854, 0.04386197263374925, 0.011431331197465104, 0.027440519338207583, 0.019499162611152445, 0.09936648660472461, 0.02167777231495295, 0.017724708720509495, 0.0747121541893908, 0.008899153010653598, 0.06923151827816452, 0.017289973030399, 0.016968320290158902, 0.025994941193078245, 0.04779268867735352, 0.024120137062189833, 0.09028909940804754, 0.05068157187529972, 0.016573188992749368, 0.006241090886760503, 0.07745125078197036, 0.028313610702753067, 0.019545767788908312, 0.012601984764582344, 0.04499109222420624, 0.018649299196632843, 0.0361459777424378, 0.03115015510203583, 0.0418359993823937, 0.033710579853504896, 0.06172598459358726, 0.03257063084415027, 0.04654279663892729, 0.040822396986186504, 0.027848437628043548, 0.04693555984912174, 0.011509197331698877, 0.02528695436194539, 0.0783446439142738, 0.01977744508933808, 0.01412542734760791, 0.06109373244856085, 0.03668101278266736, 0.04768768199054258, 0.02854498435876199, 0.013545194241617407, 0.03788491032485451, 0.03166674077510834, 0.053769940976053476, 0.040494603504027636, 0.02754831310760762, 0.028861704149416516, 0.024170635334615196, 0.044355868095798154, 0.01130556473175862, 0.05066625733992883, 0.028145958270345415, 0.02255102652790291, 0.04005021056426423, 0.027823162198598896, 0.016007797992123023, 0.032601463475397656, 0.016331401520541737, 0.07575097773224115, 0.04958743415772915, 0.02264587045647204, 0.010757512845365065, 0.1175952348858118, 0.0626416133184518, 0.014418051511581455, 0.06145054687346731, 0.029534013609268835, 0.04801305988803506, 0.050675648264586926, 0.039097035104142766, 0.012869549782148429, 0.03885651818875756, 0.04839092925457018, 0.03341296421630042, 0.02249121875502169, 0.03473187005147338, 0.013606152979524007, 0.046170447154768875, 0.02277709573640355, 0.023195806125711118, 0.07123252483350889, 0.04490064011354532, 0.08376605728907244, 0.032811191864311695, 0.02155957999639213, 0.04077355942821928, 0.02550109662115574, 0.02264288829506508, 0.031667276817773066, 0.02732400469748037, 0.019043505990079472, 0.06823500817907707, 0.038665113638022115, 0.011308540107815393, 0.048488519553627284, 0.022897956393925206, 0.028314543688403707, 0.03343741861837251, 0.04256540756406529, 0.007819203460322959, 0.054104058404586146, 0.020932535607633845, 0.04453259254140513, 0.03770441322454384, 0.016137649238641773, 0.06164823126580034, 0.05613453034311533, 0.049118240763034136, 0.020085918983178477, 0.05750921514949628, 0.005715524378631796, 0.012197595705012125, 0.008431441366805561, 0.03657405191500272, 0.03554987794320498, 0.02018217765726149, 0.009008285190377916, 0.026266319577449133, 0.046380477491766214, 0.07850567384489945, 0.026160339192886437, 0.03673723619431257, 0.00756988933842097, 0.037160723470151424, 0.04890217485704592, 0.06238805156733308, 0.07525306195020676, 0.07011208709861551, 0.01582627460759665, 0.05887004427079644, 0.00670045442945723, 0.012459672222446119, 0.060234795324504375, 0.0488343111771558, 0.054871512044753344, 0.02181982192476945, 0.019813463424465487, 0.048138449766806195, 0.025581284193322062, 0.03602677610303674, 0.02879683280895863, 0.050244588537939956, 0.12598880806139537, 0.04832817155069538, 0.024591344009552683, 0.026344510560323085, 0.01841245485203607, 0.0247015822013574, 0.02710022045565503, 0.014441545786602157, 0.031552617970321856, 0.056601186016840596, 0.03931725025177002, 0.03786473747875009, 0.014546069017212306, 0.037270781850176196, 0.028348212596029043, 0.05487067744668041, 0.033213980429406674, 0.022617858834564686, 0.03877156221174768, 0.08008119144609996, 0.10520143314663853, 0.05681301447163735, 0.026461071002164056, 0.03749745325850589, 0.015912689434896623, 0.04479974874162248, 0.036018162100975, 0.051196783514959474, 0.003701855935755053, 0.06923137578581061, 0.04582108982971736, 0.009474091847161097, 0.0065988047946510565, 0.004688904712176216, 0.051238031658743105, 0.053041520062834024, 0.014796041318082383, 0.02565693066987608, 0.0199239272291639, 0.058662514335342815, 0.044898913241922855, 0.0485632669712816, 0.016144042734854987, 0.010054900859748679, 0.016866177021126662, 0.03841288520821503, 0.04276023193129471, 0.043911858528320274, 0.0581241442954966, 0.054432862903922796, 0.010864080162718892, 0.006676113682000765, 0.027506208313362937, 0.027946577540465763, 0.025215558907283202, 0.07563281764409371, 0.02458828890563122, 0.026795817771926522, 0.08180154913238116, 0.12724130228161812, 0.11399891786277294, 0.14933375109519276, 0.14034548268786498, 0.23141048688973698, 0.09143466329468147, 0.07861826994589396, 0.12395552359521389, 0.1694496681115457, 0.07616852782666683, 0.09695297147014312, 0.11353707978768007, 0.07880285861236708, 0.13744762247162207, 0.0777552616117256, 0.12170831060835294, 0.18069546323801788, 0.12407030457896845, 0.07866873938058104, 0.22121695029948438, 0.15623499506286212, 0.2633988532636847, 0.09397408738732338, 0.08991796110889741, 0.09245138016662427, 0.12139132618904114, 0.16230487078428268, 0.07192173999335084, 0.10269093500184161, 0.08071865474006959, 0.25166530002440723, 0.09266574973506586, 0.08004488982260227, 0.10147974999355418, 0.13884418324700423, 0.09679367858916521, 0.12161495776048728, 0.18373527298016207, 0.1029111806835447, 0.11436394256140504, 0.2243900786020926, 0.2125846277922392, 0.13466853302504334, 0.15947422624698707, 0.14277803072971956, 0.06826687896890299, 0.16125447143401417, 0.18166747822293214, 0.14488546550273895, 0.09067774391067879, 0.07028678950986691, 0.091756003908813, 0.1862708090671471, 0.11013099684246949, 0.1256920982684408, 0.16093954976115907, 0.14222403402839387, 0.15653118916920253, 0.18560166497315678, 0.16051048492746695, 0.08066587828631912, 0.1595612144363778, 0.1630428454705647, 0.10540499365223305, 0.1014521811157465, 0.19032342731952667, 0.1775519462036235, 0.13333055696317128, 0.1740134267934731, 0.13253608745123657, 0.127860764041543, 0.06936761204685483, 0.16106459019439562, 0.17717240085559233, 0.11294575008962836, 0.12414997816085815, 0.08261580472545964, 0.1832646139498268, 0.11665185407868453, 0.0896992828430874, 0.20018919078367098, 0.13741756337029593, 0.1301733199506998, 0.10774701155189957, 0.15075184857206686, 0.15913422591984272, 0.12591445419405187, 0.09685026840972048, 0.11855441198817321, 0.20066556307886327, 0.09335058155868735, 0.12997890609715665, 0.09552637194948536, 0.10205895427082266, 0.1454933921673468, 0.13910353290183203, 0.14012509451380797, 0.0886380405032209, 0.1362208854407072, 0.1257705097751958, 0.16480394239936555, 0.16045745063040937, 0.21854376659861632, 0.13075010185795172, 0.33130302812371937, 0.08743417688778468, 0.11783531414610998, 0.12450474341000829, 0.14034599837447914, 0.14368707766490324, 0.0964024013706616, 0.2380888999572822, 0.15960435569286346, 0.10679603793791362, 0.20339526874678476, 0.10217003723872559, 0.16270318441092968, 0.18988214885549887, 0.15207818097301892, 0.11795196788651602, 0.07846603382911001, 0.1150479330016034, 0.14384254360837595, 0.11420854447143418, 0.1353746708482504, 0.07433199137449265, 0.1645195140902485, 0.1657988375851086, 0.128606487597738, 0.09654946026525327, 0.0674310934596828, 0.10426635082278933, 0.14253755791911057, 0.121241084965212, 0.13841860608330794, 0.1447783519646951, 0.15098449108856066, 0.17288088399384702, 0.16034541092813015, 0.08597200856144939, 0.12273323775402137, 0.08863440355552094, 0.13967511723084108, 0.11488695735377924, 0.13357891435069696, 0.16326697915792465, 0.17934777055467876, 0.09029340810541596, 0.06457610987126827, 0.14225793363792555, 0.0693554323432701, 0.18782818264194898, 0.14664945299071924, 0.1062207759491035, 0.14068722006465706, 0.1198643102709736, 0.2066656175468649, 0.10025481108043875, 0.10807120879845959, 0.10937634376542908, 0.13952735944518022, 0.1074293621682695, 0.1300605067184993, 0.15088279225996562, 0.16023381905896322, 0.09756477935505764, 0.1969873197376728, 0.10590949122394834, 0.13999945696975502, 0.14179271645843983, 0.1907954705613, 0.145171603720103, 0.15738237063799584, 0.1334928082568305, 0.1215115354529449], [0.015608361390020167, 0.012460639134847691, 0.021970534730436544, 0.02695559580544276, 0.05206770356744528, 0.023472974110128622, 0.050425380800983736, 0.04613029484504035, 0.039062948897480965, 0.014536513547812189, 0.05686807419572558, 0.01643134972878865, 0.029049302118697336, 0.010685590677894652, 0.017397383427513496, 0.011884702003694006, 0.067471052386931, 0.035072786400892904, 0.03347071772441268, 0.04300860288952078, 0.02112836590302842, 0.07320927376193659, 0.06032847386917897, 0.012398492960658456, 0.04099234625963228, 0.05238435211192284, 0.04045291770515697, 0.03409903436633093, 0.04149051649229867, 0.037329526019415686, 0.004107529971016837, 0.03713749721646309, 0.059543958465967856, 0.05231054785794445, 0.06144823306905372, 0.05320819879748991, 0.05281931341492704, 0.03770896280184388, 0.013121666253677436, 0.024114243985552872, 0.011141526346494044, 0.019597227884722606, 0.013095032057857938, 0.041167214911963255, 0.03251302661374211, 0.0498908885887691, 0.013614059608828808, 0.012173753680794366, 0.05261599378926413, 0.04637790245137044, 0.025566682119720748, 0.013219521181391818, 0.03488247089886239, 0.05460089531594089, 0.029369265306741, 0.04064440028741956, 0.014375108726588743, 0.06582320973809276, 0.0664107667814408, 0.025309860007837415, 0.05534733811925564, 0.034394505832876475, 0.00967747762998832, 0.020546805412907685, 0.024328192862282907, 0.055548486432858875, 0.02396741579286754, 0.03170628918867026, 0.06289697318736996, 0.06713639891573361, 0.015420341032690235, 0.0053052765932599345, 0.06211707860763584, 0.023546898804072822, 0.030243147164583206, 0.04761099396273494, 0.023089790118059943, 0.01299990908176239, 0.06558851804584265, 0.027481591062886373, 0.015150016073935797, 0.048020530558590374, 0.014576251951179333, 0.033620741817035844, 0.021579740968133723, 0.025357978318684866, 0.03945229568385652, 0.05088613322004676, 0.020860731335622922, 0.02513773094064423, 0.03443622895117317, 0.06842472657029118, 0.0386852016672492, 0.025308289199269245, 0.006241809709795884, 0.04194457855607782, 0.0124256436912609, 0.004330622107123158, 0.057821456609027724, 0.06902024961475815, 0.016899252210610678, 0.04374293384275266, 0.05127946639965687, 0.017644075011568408, 0.0028540546315655646, 0.0196844332053193, 0.06214696128985711, 0.10646603921694414, 0.06024386055235352, 0.04210757963093264, 0.06841747981629201, 0.02229141563709293, 0.03136585459911397, 0.04660136438906193, 0.04168252493920071, 0.030068587245685712, 0.08089412389589207, 0.0292598718910345, 0.021952166787481735, 0.02936167249988232, 0.08800258567290646, 0.06120543966868094, 0.030446826413805996, 0.02648106912550117, 0.05331693064155323, 0.05243713195834841, 0.03025269415229559, 0.001830992821071829, 0.027743814313518148, 0.01467234268784523, 0.026943371997081807, 0.05431918793224862, 0.008285630976648202, 0.08325259626976081, 0.03195299434342554, 0.07625989935227803, 0.03074126989979829, 0.006215274325638477, 0.05106033351538437, 0.019809673806386333, 0.03044012248782175, 0.018097531482843415, 0.012558233674748667, 0.06408491837126867, 0.10114883525030953, 0.022216059234259383, 0.021659531597314135, 0.03407036286911794, 0.037779065647295544, 0.04650695302656718, 0.03330701097313847, 0.024295121065473983, 0.07470211865646498, 0.044470713540379486, 0.031015516790960516, 0.011431936789969248, 0.0528174745850265, 0.07203042773263794, 0.01749630704788225, 0.03436362909685288, 0.051306237998817644, 0.0198047205007502, 0.05531947407871485, 0.05451943379427705, 0.051450959340270074, 0.008327226021460124, 0.001432748108137665, 0.06747208376015935, 0.015265940389196788, 0.02121354579659445, 0.025159435579553246, 0.07199024488883358, 0.030057438915329318, 0.016817660070955753, 0.020774611671056067, 0.03283667763961213, 0.04836424247228673, 0.023114017210900784, 0.04472742369398475, 0.042981461488774846, 0.07368269442979779, 0.05359708757272788, 0.027606867287041884, 0.02722085889295808, 0.012928241364923971, 0.04467574646696448, 0.021240532830623642, 0.015427804917895367, 0.016891952870147567, 0.02477300988643297, 0.016014048995982324, 0.020519465540668795, 0.02861815078982285, 0.029428911927555288, 0.04660114047250577, 0.010789912892505527, 0.022432525475908602, 0.013256468261325998, 0.05181775501530085, 0.04092160559126309, 0.04536275978067091, 0.05233629147655197, 0.04786783303799374, 0.024802580442545668, 0.03888983425817319, 0.02782100615357714, 0.037626089927341254, 0.026546922645398548, 0.08906740389232125, 0.04004494852519461, 0.05252257987324681, 0.018340857533205832, 0.03694351762533188, 0.038444569400910816, 0.01133338297118566, 0.02679859467649034, 0.026441634366554872, 0.012089388029250716, 0.02282323781400919, 0.025695836171507835, 0.021023398231981055, 0.05025227294702615, 0.07167100773325988, 0.03224623342975974, 0.02394471370748111, 0.04088613178048815, 0.04444457297878606, 0.014812314284167119, 0.010214908747002482, 0.036290671942489486, 0.05020729625331504, 0.01186111951912088, 0.032608214898833206, 0.022687535899292146, 0.016017024372039095, 0.051572155872625966, 0.04925880268482225, 0.017045144024970274, 0.04445207418341722, 0.03273447669510331, 0.0357271350388016, 0.05830339289137295, 0.026736756387565817, 0.026934919147086994, 0.03877862236861672, 0.07353047866906438, 0.011201040652979697, 0.025747605000755618, 0.054558144217090945, 0.045553767388420444, 0.025207095879263113, 0.05490609697465386, 0.04512034296723349, 0.02179083490877279, 0.0057153971533158, 0.02278948069683143, 0.025968198431655765, 0.018788297095202973, 0.013694409181230834, 0.03058777849322983, 0.01875308621674776, 0.0520232120262725, 0.05076995784682887, 0.04691803668226514, 0.03731264406815171, 0.02318236604332924, 0.004621442216115871, 0.04050358391499945, 0.023944420241085545, 0.0440786729699799, 0.06869569952998843, 0.020392686361446977, 0.013786244655161031, 0.024697874007480483, 0.06388325776372637, 0.12118137388357095, 0.030463504804564372, 0.04068595716463668, 0.02763009523706777, 0.030800604394504, 0.022892787653420652, 0.041837040933647325, 0.058949697496635575, 0.05457595915400556, 0.02584526824232723, 0.04011756195021527, 0.04845081675531609, 0.030001907609403133, 0.026924730943781987, 0.05888381174632481, 0.0267752445901611, 0.020360176052365984, 0.06548842734524182, 0.022397051665133665, 0.02593264150034104, 0.030284520837345293, 0.018093811414603676, 0.014866771808426296, 0.04730883214090552, 0.027590501022392085, 0.023568571212568452, 0.018673636551414217, 0.02268021789911602, 0.016373416408896446, 0.023881886453766907, 0.04179147730714508, 0.014385519150112356, 0.03862789938492434, 0.026952257413151007, 0.04904608874182616, 0.08531939358051334, 0.03706004244408437, 0.017704174554507648, 0.014277382720527905, 0.07002328722072498, 0.030558903435511247, 0.031173086192991053, 0.0323881795629859, 0.0366375695780984, 0.020653993589803576, 0.029236123165381805, 0.015458827538947974, 0.03470390083800469, 0.07591894229075738, 0.03456762386485934, 0.04709949051695211, 0.029875971509941986, 0.016437325925965394, 0.021847699536010623, 0.052576672684933455, 0.03999336968575205, 0.065983533992299, 0.028012407311637486, 0.0958427863993815, 0.030534852761775255, 0.03705449202763183, 0.025428798714918748, 0.02365838210763676, 0.021262464778763906, 0.026002773183530996, 0.035084423276462724, 0.010793015493878295, 0.035023490831788094, 0.02960166015795299, 0.0174342567167644, 0.009374767042962568, 0.014995388121211102, 0.03577928724033492, 0.051162663381546736, 0.029504293775452033, 0.023322374959077154, 0.014505172015300818, 0.16645059761192116, 0.08821726058210645, 0.09134131044681583, 0.1587060567523752, 0.1468992895845856, 0.18112558658633912, 0.15985128815684999, 0.1209682324635131, 0.12418636120855808, 0.07056660378085715, 0.132449031408344, 0.07891822992158787, 0.09389357920736074, 0.11048336686300379, 0.10373657782162939, 0.12475810838597161, 0.10851995793304273, 0.09226157356585775, 0.1475758704223803, 0.09676731071834054, 0.1065883112273046, 0.1462525642876114, 0.14539984932967595, 0.11073258599000317, 0.1573511173150369, 0.20758267119526863, 0.12598108633288316, 0.13142542062061174, 0.13523197493382863, 0.137065607256123, 0.06600977972682033, 0.07613975115652595, 0.23919341926063808, 0.1350136495062283, 0.14852681010961533, 0.1551512117896761, 0.10205865571541445, 0.15225953981280327, 0.08258863618331296, 0.12670718665633882, 0.10542187560349703, 0.19908699207007885, 0.07002674774932009, 0.11381964212549583, 0.0813348391758544, 0.13229587248393468, 0.18499172984489373, 0.09499678215278046, 0.14057095987456186, 0.13373667374253273, 0.16203089191445283, 0.12991515094680445, 0.08634510782680341, 0.10564469971827098, 0.08929754261459623, 0.12097097374498844, 0.1085004907633577, 0.14032433953668388, 0.13632447059665406, 0.07309151400945016, 0.1071997798447098, 0.1527161667389529, 0.10078208028737988, 0.13092158122786454, 0.11203419936022588, 0.217556538858584, 0.06567681580781937, 0.07195585673408848, 0.172014394775033, 0.13061763825161116, 0.10193084685930184, 0.14113299043050834, 0.14377542292433126, 0.1386523749679327, 0.11124245755906616, 0.12617703367556843, 0.12628706491419248, 0.06233069500220673, 0.12599087080785207, 0.15434398581939085, 0.0966078278475574, 0.1613346878439188, 0.13270569406449795, 0.1442886803831373, 0.130866728456957, 0.15894864659224237, 0.13015734723636083, 0.13305801658758096, 0.13996376602777413, 0.08979041688144207, 0.12339894846081734, 0.11576213182083198, 0.1955552172980138, 0.13695678380983217, 0.08305411120610577, 0.11698734893330506, 0.10052505800766603, 0.08053030698959317, 0.11428274906107358, 0.1413088259952409, 0.0756347786102976, 0.15902168410164969, 0.17077107434826239, 0.0764545031956264, 0.06071833294949361, 0.12367432511278562, 0.17271730277155126, 0.1693215471293245, 0.11155798312808786, 0.10419019883764641, 0.11517237632402352, 0.14574249594339303, 0.08577780505376202, 0.14676301261144026, 0.1451687403023243, 0.13685663204107965, 0.2526645378342697, 0.07214588725141116, 0.09649929617132459, 0.11689608597329684, 0.1806975802672761, 0.18758696344281944, 0.19607209813381943, 0.07666029608143227, 0.1594036314636469, 0.10994655066835028, 0.09510611450033528, 0.13507416125919136, 0.09922250147376742, 0.07510602341166564, 0.07015049218067101, 0.13704534620046616, 0.0910080751138074, 0.1566095192517553, 0.17552069734249795, 0.12294536137155124, 0.17636350568916115, 0.17367382001663956, 0.14731026467468056, 0.0644745331789766, 0.0970921457878181, 0.08713569611843143, 0.16674168913492135, 0.1026527877630932, 0.185587809288076, 0.13576617198331015, 0.1393948279853378, 0.12891866798911775, 0.13451620191335678, 0.12542816171688692, 0.1801632067986897, 0.11626282281109265, 0.18727305957249232, 0.1349509392998048, 0.10078922526112624, 0.0995460201853088, 0.15319491390671047, 0.18037068923669203, 0.09981593463037695, 0.10165775008499622, 0.16557576241237776, 0.05252128726403628, 0.2179292445736272, 0.11470618205411093, 0.10950826454375472, 0.09867728501558304, 0.10542387049645185, 0.1492820874388729, 0.07877055356012923, 0.09479205456695386, 0.09619888836251837, 0.11351257110280649, 0.1683049388229847, 0.13033409203801835, 0.08542696173701968, 0.0976399542497737], [0.019157323454107558, 0.011802156522337879, 0.06226408321942602, 0.026990584463679364, 0.016770936149571623, 0.03617620987019368, 0.053943805396556854, 0.039940803577857356, 0.050173159156526835, 0.06402940063604287, 0.007461875893308648, 0.0238443142734468, 0.029367348445313315, 0.005425538867712021, 0.026003736703257476, 0.013318553367363555, 0.07534899323114327, 0.018229255486013632, 0.016891705204865763, 0.0686731178845678, 0.02028733192543898, 0.024927391870213405, 0.03451055567711592, 0.027567600465512702, 0.05502990925950663, 0.03041962394490838, 0.0279253987661962, 0.011442044417240789, 0.04701714011441384, 0.0385399137490562, 0.041644954455218146, 0.05364559264853597, 0.05499398761561938, 0.0470860385602074, 0.06273473546441112, 0.04701397135587675, 0.0538701843470335, 0.04200295970908233, 0.024480534151994755, 0.02183592864977462, 0.027853586012497544, 0.0335695090304528, 0.007506583717518619, 0.016715856069432836, 0.07958509413791554, 0.02439184283970722, 0.024699597486427853, 0.01918997964821756, 0.06144465718950544, 0.029548096603580883, 0.036830969021788666, 0.011334538177054907, 0.024275036428921988, 0.02887694743861045, 0.011174661755960966, 0.039687689659850936, 0.022376917834792818, 0.08363771917564528, 0.062088960116463046, 0.029572700283357074, 0.008354781328567436, 0.03865333427009838, 0.03448773993711386, 0.058497643896511624, 0.04025874473154545, 0.022207748876618486, 0.0509590553785009, 0.041119252664170096, 0.014287766002650772, 0.03415253345987626, 0.021199937776795456, 0.1144490579941443, 0.02094338198990694, 0.03354470179017101, 0.03388469872464027, 0.011330028463687216, 0.015962780586310794, 0.02140320142331932, 0.02756771581646587, 0.042303588041769605, 0.019334492340151752, 0.031319894029625824, 0.039083525471921475, 0.029982291162014008, 0.03309535215209637, 0.095494630081313, 0.01542549450615687, 0.02701231454765158, 0.04403724840709141, 0.0672700906704579, 0.02039948188965874, 0.015053234927888428, 0.03053516149520874, 0.008169202849135866, 0.0341948876157403, 0.050211323358650715, 0.02297722115846617, 0.03661408887377807, 0.008272847376896866, 0.0881718055212072, 0.09213394112884998, 0.06432694502707038, 0.033855650640491924, 0.030780723318457603, 0.040310686587222984, 0.015391403210482426, 0.0514019012584218, 0.058319922004427226, 0.0662152808425682, 0.02071258848133896, 0.045225960335561206, 0.029724688734859228, 0.0058816653742854086, 0.03462114331445523, 0.009683154423588088, 0.003469470626441762, 0.029623057759766067, 0.06128828200910773, 0.04659260789464627, 0.04262012802064419, 0.030837503128818104, 0.06486269592174462, 0.017720693489536643, 0.035353309740977626, 0.010125235255275453, 0.009244149051872748, 0.09622913066829954, 0.011778579126777393, 0.007295337954669127, 0.027754945680499077, 0.13265116699039936, 0.06251210133944239, 0.04485818078475339, 0.032769903008426936, 0.09486193010317427, 0.038167567657572884, 0.018091697778020586, 0.04388711914154036, 0.033692954906395504, 0.025085251345964413, 0.01112602012498038, 0.031652800273150206, 0.11226946102189166, 0.01982278479928417, 0.01172549054691834, 0.06076520614858184, 0.0031205465035912183, 0.05380769127181598, 0.006135843320017946, 0.02586276426778308, 0.03385788302070328, 0.021698686460565244, 0.009641428760785078, 0.018920306083081023, 0.028726207491542612, 0.07111975231340953, 0.05428131550018277, 0.03503104292654565, 0.11616872357470648, 0.028085438035694615, 0.03285972408152052, 0.07041098855968032, 0.02168144318940384, 0.05047582309427006, 0.037013491549129994, 0.016032281231933405, 0.07791774360729115, 0.02918048668652773, 0.08810467805181231, 0.023878464940935373, 0.019897790060245564, 0.026973510826272622, 0.07812255261731998, 0.028297015432534472, 0.07439253705420665, 0.02139930663231228, 0.018150199370990907, 0.026752730798242346, 0.013219650103045362, 0.07980203535407782, 0.05041553865053824, 0.041588174644857645, 0.027864042237134914, 0.0036629559472203255, 0.04560330383745687, 0.0528185772044318, 0.038805811266813955, 0.04437925380521587, 0.0395847423268216, 0.021972699257146035, 0.014631279444854175, 0.053195255742009194, 0.07005868639264788, 0.015107219173972095, 0.10631125180849008, 0.06063466279634407, 0.030483606404491832, 0.018268152505957654, 0.03466198094455259, 0.018515938227730136, 0.049275749096913, 0.02260260027833283, 0.019500487450776354, 0.028987470615123, 0.030816285338784968, 0.012481006211601198, 0.01491307164542377, 0.08004108324114766, 0.06200309829520328, 0.024492011571835195, 0.05299502345068114, 0.10497151155556951, 0.030103643757424185, 0.04563899477943778, 0.03771900851279497, 0.04839144494118435, 0.04820765694603324, 0.05394999702860202, 0.02766793204604515, 0.038067219113664966, 0.07674779995743718, 0.02687611390969583, 0.026056504675320218, 0.03758558477940304, 0.023356722401721135, 0.03675298159942031, 0.042127440350928476, 0.0587326545002205, 0.04351218443896089, 0.05483034532517195, 0.0328900104920779, 0.01677633898465761, 0.029609673656523228, 0.016162539599463344, 0.009331453608215919, 0.006290871184319258, 0.0317140516292836, 0.044853997616363425, 0.04135039901094777, 0.04098686708935669, 0.005937200496971075, 0.031865521001496484, 0.0511432504946632, 0.013551332439029855, 0.045351299324205945, 0.03139717916824988, 0.004636190174746194, 0.05909576573010002, 0.014554888276117188, 0.047974885507885895, 0.04099962354770728, 0.003289936833815383, 0.06205229886940547, 0.02005348670562463, 0.07844738768679754, 0.030416594286050116, 0.04548288083502224, 0.03808457603944199, 0.037433803281081576, 0.060357175900467804, 0.024717276716338735, 0.017679993262780563, 0.023736072670934454, 0.022298691228830388, 0.009885099167669458, 0.008016142312304249, 0.01091075234580785, 0.004880194760127259, 0.01660205896145531, 0.08973650048886027, 0.03417969860934785, 0.029157955931233506, 0.040004748718014786, 0.06937215823147978, 0.08255674503743649, 0.06727978693587439, 0.04919157682784966, 0.06685528185750757, 0.03310586265953524, 0.0066847310767376, 0.020891238270061355, 0.06306927358465535, 0.060023044901234765, 0.0352053246460855, 0.006846326735935041, 0.0071483036569718805, 0.03836535383015871, 0.02878989478839295, 0.008795471163466573, 0.038917837398392816, 0.011024164385162294, 0.03195081963869078, 0.03230832956199135, 0.022799792732777338, 0.04272176917376263, 0.04385447482179318, 0.015544538386166096, 0.05327651709584253, 0.05892092761184488, 0.033740377718848844, 0.010387398285924323, 0.05545367134202804, 0.0061810778570361435, 0.020568718701334934, 0.008489691053650208, 0.03246737477768745, 0.08075752801128797, 0.03245842829346657, 0.04141899550865803, 0.014065795145662767, 0.05984793536897216, 0.04040647876848068, 0.05022306201447334, 0.025574695618290986, 0.02491140049616141, 0.03970034433794873, 0.029350500420800278, 0.04358948314828532, 0.03380363414596234, 0.050452841113188436, 0.03273153863847256, 0.0523144935390779, 0.04580221298549857, 0.07263326538460595, 0.04520861358780946, 0.015069587621837854, 0.05243659930835877, 0.047920093805130036, 0.047118211298116615, 0.035000223865998645, 0.028710353520831892, 0.05295938339882663, 0.10768305962639195, 0.01911163599496441, 0.09850971400737762, 0.03382846174229469, 0.007466310967824289, 0.04286099098888891, 0.056253497887934954, 0.05877559898155076, 0.04499567233558212, 0.01332353551073798, 0.03859872237912246, 0.016687398310750723, 0.0469379890044885, 0.08104560683880534, 0.008545632025093904, 0.0331908254218953, 0.01761648408137262, 0.0484035194718412, 0.015690689740170325, 0.012305721108402525, 0.09643631455089365, 0.09656394020255123, 0.10341437546802418, 0.20367007542933735, 0.13230033724435739, 0.1502260382154158, 0.1575955663408552, 0.10270749804164682, 0.16871537108506474, 0.1851811089685985, 0.09816828875669412, 0.119307260162064, 0.1571178776877267, 0.07068208365568093, 0.08999452021505151, 0.08947923393653971, 0.20311138326568262, 0.05914837933544602, 0.149979458589639, 0.1274085340223142, 0.11532253612365041, 0.106467016307371, 0.17771829584879534, 0.08070338770215, 0.16744017308311804, 0.2443654845867838, 0.09727579129061528, 0.0563973099924624, 0.1574545396225793, 0.12170126741485936, 0.12818069330283574, 0.24257651343941689, 0.14238058562789643, 0.13340549437063082, 0.10807022492268256, 0.25415400362440516, 0.1103842668235302, 0.1531035830932004, 0.19918841948466642, 0.11802656602646623, 0.0888999007376177, 0.10693227419895784, 0.11217467646513667, 0.11585498255278383, 0.1922330962760108, 0.10651416770581688, 0.09765957069716283, 0.08202020704214062, 0.1766016036272049, 0.11879043360905987, 0.11776260233351163, 0.1137752795059766, 0.08943940393094506, 0.13615200056561402, 0.08042482872094427, 0.2957055882683822, 0.16424546736691678, 0.11630487841154848, 0.13103583295430454, 0.10471592098474503, 0.11376696066664797, 0.09809985850006342, 0.10700633629624333, 0.18694833985396794, 0.15885884926787444, 0.08206560103488819, 0.20528692938387394, 0.13502703021679605, 0.07772970798292331, 0.1389522331633738, 0.10652021345283304, 0.2286308817565441, 0.19350198390228407, 0.0970037326748882, 0.13501964775579317, 0.1613882513982909, 0.13044512750846998, 0.05639271631038614, 0.14400263716067585, 0.11455461090164525, 0.15002752601036004, 0.09308612253516912, 0.09885590257389204, 0.15425133864794457, 0.09434938510613781, 0.2641003227659634, 0.12794160470366478, 0.07160240105752434, 0.12854828286383832, 0.16095036560935633, 0.09215269583676543, 0.0626409687101841, 0.15653996941234383, 0.09272284167153494, 0.14492055933390344, 0.10523511562496424, 0.1945147109883172, 0.17913773682500633, 0.10881296292479549, 0.1532873303762504, 0.22655071052057402, 0.14218659246606485, 0.0977743516809174, 0.11343911290168762, 0.14745024644902774, 0.12049705774656363, 0.1532953099480697, 0.18418727229748452, 0.12190641569239752, 0.053081648623836894, 0.10330804903060198, 0.08720589056611061, 0.09047001720006977, 0.12383382155426911, 0.09777381563825266, 0.1428497111690896, 0.1369014832058123, 0.06875181437603065, 0.14742990396916866, 0.11025608477315732, 0.11412437898772103, 0.09672177423323904, 0.18160133462931427, 0.10170392439301525, 0.068692700405206, 0.11732331876243864, 0.18040294679147856, 0.07090608163603715, 0.12252431682177953, 0.19296927962984356, 0.3560324268681662, 0.09061385983867304, 0.11132305394858122, 0.25643689398254665, 0.24573471397161484, 0.13996301963925362, 0.09774897447121994, 0.16923272689538343, 0.1462465524673462, 0.07260581185775143, 0.12523487423147472, 0.1463542224041053, 0.17863009763615473, 0.11825737649840967, 0.07190274101282869, 0.2926016705376761, 0.1331501073603119, 0.16733793142650807, 0.06407377682626247, 0.09095066426587955, 0.18476770472313675, 0.12806908786296844, 0.14222841736461433, 0.13433959281870297, 0.1603802740573883, 0.1290383887078081, 0.1535706323172365, 0.11235136698399271, 0.2910184312079634, 0.15023901180497237, 0.15132341933037552, 0.1062274459483368, 0.09179456505392279, 0.21430772675999574, 0.11076035842831645, 0.10334042193634169, 0.15379407389887742, 0.1392758400844676, 0.21867161616683006, 0.1423104251069682, 0.07717730583889143, 0.11844318652791636, 0.2643665799072811, 0.14463348473821366, 0.18196867991771015, 0.10536789135741335], [0.02875725386132087, 0.03748252209542053, 0.032276438416114876, 0.05090588876711471, 0.07428412751427718, 0.049425230361521244, 0.018348647115219916, 0.015009825650070394, 0.05476708211270826, 0.013875991089402564, 0.032755687699786255, 0.012875193497166038, 0.022498518095484803, 0.04661676713398524, 0.06301795598119497, 0.07369180036974804, 0.03666489079062428, 0.07785112503916025, 0.053138143449489555, 0.011698673994812583, 0.03222056105732918, 0.012257070995734205, 0.032300624796854596, 0.02895249892026186, 0.021122062312705175, 0.0223624684315707, 0.012361007293553224, 0.034184326218175035, 0.07594343061958041, 0.02646379532026393, 0.031235019476818185, 0.010812935585688268, 0.05690283215205584, 0.004879971691739878, 0.0038813865477485316, 0.06730105900870902, 0.012256400094234517, 0.07639702449419669, 0.0946631193427103, 0.028888116125017405, 0.029353014393044368, 0.016732383486149565, 0.0958100538700819, 0.038414113356598785, 0.037539105130625625, 0.0468754857512457, 0.018449587680931603, 0.04115722009113856, 0.08688580524176359, 0.04738493662859712, 0.0267599334474653, 0.025699993894834603, 0.0690280527674726, 0.0733073695695826, 0.013688119161607963, 0.03147780948451587, 0.026532223880557076, 0.04328431880899838, 0.07701294430132423, 0.03667212736659816, 0.01600726873480848, 0.04085996068481888, 0.078433104524655, 0.06734587624669075, 0.009178356600127049, 0.013312952908953386, 0.024227153908993517, 0.003775524058645325, 0.026640708059338585, 0.058563685709876676, 0.09486836940050125, 0.019027845401849066, 0.007902491937524505, 0.04197041716958795, 0.04175384575501084, 0.040716755869133134, 0.02311756255637322, 0.032543821925563474, 0.02851905075034925, 0.04126532768298473, 0.04815949792308467, 0.03255490579509309, 0.03299591623778854, 0.024569881946912835, 0.08086074675832476, 0.024038203958688036, 0.06751907909555094, 0.03365889923380954, 0.05984852569443839, 0.0302359207666346, 0.055382852642131705, 0.03828326127092753, 0.04686187433877161, 0.040575532375701835, 0.04144007759168744, 0.0369808574074081, 0.012421490208777999, 0.031326950793819766, 0.13155031177614415, 0.06710413457559687, 0.026550663069688847, 0.04722116880917123, 0.012127603969669767, 0.00914150960410812, 0.06065918505191803, 0.047741567849048545, 0.021678723960316608, 0.04555695989568319, 0.012633344108637954, 0.04888346764658179, 0.03588638720767839, 0.03845490348924484, 0.012427966825530996, 0.0554629265596824, 0.00347970611515588, 0.07012579350599221, 0.035658375692686865, 0.02342995668628386, 0.05361924174108675, 0.052477016246744564, 0.039729514558400424, 0.015178502670356205, 0.04639264362465058, 0.05347353991653238, 0.05134735382827265, 0.03516866000635283, 0.045312853530049324, 0.005498428371668394, 0.018812695518136024, 0.026807503841285194, 0.015190115797200372, 0.03743743344343134, 0.02983365806617907, 0.028316306183114648, 0.01374598971701094, 0.06990548675613743, 0.012791411385738423, 0.08877075516751834, 0.02145134348289243, 0.008894499956763216, 0.03048281591119511, 0.06875070157860007, 0.0519787849459265, 0.05480113439261913, 0.02540764368937484, 0.028340911559228386, 0.015277166751080325, 0.04616264060937932, 0.02416748014677848, 0.02026256200458322, 0.046730476032410345, 0.01801483842012073, 0.02427706015961511, 0.02566473212625299, 0.014783288252406886, 0.026567716351045028, 0.040982833198670826, 0.04293500558872308, 0.05877972447446414, 0.058302748283105235, 0.048923382469053776, 0.036110218946955035, 0.035958406914557726, 0.029785017283367257, 0.04679239235286202, 0.009372145353284265, 0.04393593973613211, 0.061658049667520184, 0.0725608521274158, 0.02120588343989636, 0.04481514809387071, 0.030442860376621996, 0.03448770601036293, 0.05701749439218214, 0.033187795763037035, 0.04519605051193919, 0.03569641436583229, 0.053690202933337004, 0.026538591931707094, 0.00927376710543675, 0.014563597273081541, 0.020751346401604157, 0.02926138163145099, 0.014506846300459333, 0.02783908911182412, 0.03932621369936636, 0.025917698462892855, 0.008958635086725866, 0.012732948808531677, 0.062400495899575095, 0.04115827860576766, 0.019660486008173654, 0.039451393232281716, 0.012231934665968376, 0.028682964454804147, 0.035921630316546986, 0.024215147231838534, 0.04615848118971501, 0.029070801500763212, 0.01473604525173349, 0.010650182176115257, 0.03254620697615402, 0.03994651684271438, 0.04370753467082977, 0.020928569570449845, 0.05711723903992346, 0.03294174200189965, 0.018587834101968577, 0.09606260460402284, 0.07215978364859309, 0.008396568059522127, 0.040893449780664275, 0.024237642364044274, 0.05866826831230095, 0.06115060046847377, 0.03402423266587513, 0.04551896532731397, 0.026375141327402422, 0.012718892955620374, 0.0195048843576972, 0.04655441655112164, 0.05999115375535829, 0.013108465354889631, 0.03836591362154909, 0.06594261154532433, 0.030956392642110586, 0.05360232586307185, 0.016285381579239453, 0.028264718861984353, 0.03907986477549587, 0.03151925779613001, 0.01729948609136045, 0.034688196144998074, 0.01583123978759561, 0.04743993189185858, 0.034322296136191914, 0.058757638159607134, 0.011320603612278188, 0.037562582442270856, 0.023397242816697274, 0.08731996587344579, 0.017636068298348358, 0.0865319153027875, 0.01899796611230288, 0.029606932375047888, 0.034310828894376755, 0.03958960063755512, 0.06515048297920398, 0.015012862094278847, 0.03188311202185495, 0.03544014186731406, 0.010056723574442523, 0.039081557720367394, 0.027469942312953726, 0.008789308369159698, 0.01431523310020566, 0.030595561289893727, 0.0651727592838662, 0.03542618440198047, 0.022488433368770138, 0.0598335097144757, 0.03305835163752947, 0.041460345432694466, 0.04021796138424959, 0.059676632418164184, 0.015564495797402092, 0.006061679442479674, 0.04366885817476681, 0.019661157757842114, 0.029289707075804472, 0.014193209603295794, 0.015351503655048353, 0.009534478071145713, 0.01923095298531864, 0.027448685507157018, 0.04899331568075078, 0.04303551698103547, 0.03298288836543049, 0.018182524779279317, 0.023324704030528665, 0.05511864806924548, 0.04340104040290628, 0.050732160053615055, 0.03237094138083713, 0.023762586426788142, 0.015934702807239125, 0.03241360427013465, 0.0228860107849219, 0.07734347906495843, 0.07797486947051116, 0.033610903059265444, 0.010167569055088928, 0.019833846616425684, 0.022483052586072257, 0.016110653722924844, 0.05117481255105563, 0.03205300022714904, 0.04969995901254671, 0.0447794571518898, 0.03799624774338944, 0.043242015543260744, 0.029547241649457386, 0.04906478577426501, 0.06113316211849451, 0.011932207936687129, 0.03757658401238067, 0.0024835643333582474, 0.00917026846270476, 0.029179051584963287, 0.020912861484768133, 0.017968613221975308, 0.06323959265968629, 0.013549779442005923, 0.05203509656712413, 0.009490998395319496, 0.037300192950559516, 0.043316681536712816, 0.0324178960041276, 0.01682023680768907, 0.040232322577919276, 0.027204278889777403, 0.03357617902968611, 0.039875358875308714, 0.018876679674057022, 0.012228586095651346, 0.07156323601624795, 0.01561363021443997, 0.021172798072387065, 0.007293397344515792, 0.026441357863534774, 0.03268975784469928, 0.06930538360029459, 0.05574257458959307, 0.007411163882352412, 0.038017027878335545, 0.012867043443423296, 0.06265032570809126, 0.035680675746074746, 0.08663942917649235, 0.018001854652538896, 0.025912171795165966, 0.03483869521213429, 0.024564041456739818, 0.018017065711319447, 0.022422193083912134, 0.04725951960842524, 0.01820549488599811, 0.0357806544883975, 0.023020406519728046, 0.039833065787596364, 0.0021040762367192656, 0.02144566923379898, 0.13972707944256918, 0.1185919214040041, 0.12890395734991345, 0.17566793944154466, 0.19314811431935855, 0.10856583368565355, 0.16075550392270088, 0.12506141353930744, 0.12910763999181135, 0.1406973845192364, 0.11291621346026659, 0.06826302488999707, 0.08077584167144128, 0.19681088706212385, 0.1641543943967138, 0.17343667202762195, 0.11358532362750598, 0.19478707494480269, 0.11206414989594903, 0.09417963600052254, 0.07706329838505813, 0.11308797781488725, 0.16681096756032535, 0.07786880766174623, 0.12868728754775866, 0.22792900513325418, 0.1479846199176141, 0.2142479478248528, 0.09311483813715832, 0.16088164358266763, 0.12311849636690957, 0.12280577314751488, 0.1815387737005949, 0.16634218128664152, 0.07881433942488261, 0.14881301618048123, 0.16073187733335154, 0.16348569813583577, 0.1161938157996961, 0.13097726181149483, 0.07225118231560503, 0.07029677075999123, 0.1506413830710309, 0.10700725910386868, 0.15261720919183322, 0.14362131405089582, 0.12166442296334676, 0.09271347110292741, 0.1279914905982358, 0.14448198143924984, 0.20441626038934502, 0.1359579259795802, 0.11130353928144489, 0.1571478960769517, 0.1407942793198994, 0.0898229865623372, 0.09189717990479299, 0.11115904524922371, 0.13063978563461984, 0.17376422802252428, 0.10822245425411633, 0.10696619416454009, 0.2672600160752024, 0.10785685280071837, 0.08602416754833289, 0.0771721014752984, 0.2375746246959482, 0.12888706182794912, 0.18118380489093916, 0.16807920379298075, 0.14710146587874207, 0.12194650354129927, 0.12051190409277167, 0.10704853438905307, 0.1502370983362198, 0.14902317204645701, 0.07565394043922424, 0.12570070209247725, 0.0944641593045422, 0.08143481452550207, 0.07188875640609435, 0.08891146297433547, 0.14142013287969998, 0.09943425189703703, 0.22692463759865078, 0.10402952174523047, 0.12374569342604705, 0.1256641833377736, 0.12942896703524248, 0.10624022954808814, 0.11458005596484457, 0.15901918709278107, 0.12418047152459621, 0.1173499444765704, 0.07044926472008228, 0.08852440624364785, 0.07920290928866182, 0.11872062592634133, 0.1444922001766307, 0.10273900920791285, 0.13205018852438244, 0.08114345158849444, 0.09184238141668694, 0.09577681243951831, 0.1669979446700641, 0.10875325184315443, 0.1521179974079132, 0.1661413756332227, 0.0952953239902854, 0.14060514446880135, 0.11003991030156612, 0.18706446433705942, 0.15300417771296843, 0.24393111360924585, 0.16981913042919977, 0.18695629228438648, 0.07030097089175667, 0.10124056639948062, 0.132060760099973, 0.10773215842034135, 0.14150287343987397, 0.1446489824780396, 0.11356561897056443, 0.10678328826491322, 0.11571356228419713, 0.09695624200893299, 0.13924166906092847, 0.11853520944714546, 0.07600082789680787, 0.09030168623264347, 0.119842529296875, 0.1327936322029148, 0.1748634140406336, 0.08051007986068726, 0.10104780817138297, 0.18161220476031303, 0.11614675261080265, 0.15503322812063353, 0.10564043173300368, 0.10927988322717802, 0.20733801860894474, 0.10068762821278401, 0.10431979224085808, 0.1622914629323142, 0.13416609141443456, 0.12093890618000712, 0.08208842016756535, 0.12415001887295928, 0.11469371058046818, 0.14158083711351666, 0.08656061733407633, 0.16762906366160937, 0.07980004046112299, 0.12016062651361738, 0.1330521676157202, 0.16900889176343167, 0.11957482009061746, 0.12282673987959113, 0.16378224508038589, 0.1885246309850897, 0.14097284259540693, 0.13310441481215612, 0.2410583591886929, 0.19175357557833195, 0.12580440938472748, 0.14184732495674066, 0.09270467050373554, 0.09952154542718615, 0.2001981610166175, 0.16689737220960005, 0.10783402009734086, 0.14352075516113214, 0.1872372736356088, 0.13930820620485715, 0.08869222830981016, 0.10735922878874199], [0.02973832728873406, 0.03422399676804032, 0.08842464123985597, 0.010678765463775821, 0.02351417306012341, 0.03622565471700259, 0.08570051312978778, 0.09022794304681675, 0.020478458276816776, 0.0470575740161751, 0.024414192086883953, 0.038592961616814137, 0.029163173865526915, 0.057460475979106765, 0.04905917428966079, 0.008227752787726266, 0.04542319689478193, 0.025153554377279112, 0.05922041939837592, 0.047462784951286655, 0.04860787047073245, 0.027293000736140778, 0.02973738412505814, 0.06241885705717972, 0.017260326139096702, 0.014301139927868332, 0.029106926705156053, 0.05668071032102619, 0.04125139057370169, 0.00572985631047881, 0.018990892384733473, 0.01805302806730781, 0.04464428958349994, 0.014181890791015965, 0.08642721056405987, 0.019412242275263582, 0.028922317682632377, 0.01834977517968842, 0.04011871885242207, 0.030667418148368597, 0.005382992601620832, 0.015317641364942704, 0.036120675171592405, 0.005053578693020556, 0.024339614302984307, 0.04615449818915554, 0.019223343215084503, 0.020954119806577052, 0.03621989056201918, 0.050076274533889124, 0.016996795012216483, 0.04295185022056103, 0.029453305261475698, 0.05491176274205957, 0.050196263273911815, 0.058046642025666575, 0.011697180369602782, 0.08578788129878895, 0.05559040293363588, 0.03378749858321888, 0.0425009874493948, 0.040328739011394124, 0.025223775966359035, 0.016983358322509697, 0.007108179760897266, 0.05016453836911491, 0.060537164099514484, 0.05531444274155157, 0.027535889131416167, 0.013181733566203287, 0.05534379955913339, 0.055411754841251035, 0.05539557856640645, 0.011722123316888298, 0.042722396818654876, 0.06526527074830872, 0.01436550575973732, 0.08107729442417622, 0.039670234346496205, 0.015133286793051022, 0.031170083675533533, 0.015160329806219255, 0.026361433223688176, 0.09794826020619699, 0.008112442546657153, 0.024719003587961197, 0.010035530381303812, 0.0470548632687756, 0.01019044586324266, 0.03159131821511047, 0.05558444539617215, 0.06628035235085658, 0.024490154082221643, 0.030869821751756326, 0.025041382360671247, 0.04775995275537882, 0.022162631386891007, 0.0487803913918989, 0.017935470178989426, 0.00696944521873125, 0.055538963193872144, 0.02503012546471187, 0.015755279488595467, 0.05950323957949877, 0.03570520478699889, 0.017443379620090127, 0.042277528904378414, 0.008710030882087137, 0.026100263398672854, 0.033985440818859, 0.05306662246584892, 0.005962424612204943, 0.038115747938198705, 0.02609089283006532, 0.04563541550721441, 0.007667197197276566, 0.05538814521527716, 0.01131396075444562, 0.08814924423183713, 0.031226700637489557, 0.013593373620616538, 0.023098597502601997, 0.04862982447126082, 0.019853044068440795, 0.01693227481363075, 0.0252915175099458, 0.015611669248236077, 0.011241699319465883, 0.031477616102035554, 0.012334046552756002, 0.037073524934904914, 0.02000187393943114, 0.043431937494980435, 0.07626912742853165, 0.04085395225722875, 0.022589370541806732, 0.04366544514362301, 0.030599221986319338, 0.05346952298922198, 0.016292358615568707, 0.04423703286530716, 0.022617187084896222, 0.024762270373425314, 0.01995230695631887, 0.03028319090870874, 0.03105161485395261, 0.046694618849349875, 0.036183385378015895, 0.03808358198563967, 0.007324633704099272, 0.034496594819107225, 0.07259536241846425, 0.043243908655962775, 0.011203387535975447, 0.03566837051351156, 0.03033640841022134, 0.06052591398890529, 0.05312986532226205, 0.04148145126444953, 0.027120038767212203, 0.01804824948443898, 0.053461336464221985, 0.05970421486667224, 0.012682558253540524, 0.02340602475617613, 0.03828441138778414, 0.03779523174411484, 0.011458793206007352, 0.03217398641364915, 0.017870690440759063, 0.04484760920916285, 0.09905662680310862, 0.039234367199242115, 0.023015958722680807, 0.016838326551286236, 0.019746271494243826, 0.06309011139507804, 0.033107667562684844, 0.08217399021876709, 0.0058312722747879365, 0.012059243262878485, 0.006143037487553167, 0.06242957791047437, 0.051720707544258664, 0.016509442324084894, 0.04476609340469752, 0.020009046054578254, 0.034688063830669434, 0.03602015360125473, 0.09282013680785894, 0.031323320631469996, 0.008171486119473619, 0.03903621801042131, 0.008305505267344415, 0.030454694027347223, 0.08705737960657903, 0.04399896885401436, 0.04207995647032346, 0.023695876256429722, 0.07975298405757972, 0.017530552710273435, 0.022792430627825003, 0.03130024365548577, 0.009938387067190238, 0.021617762677903687, 0.00706142106459343, 0.03344916066687022, 0.04030407426346626, 0.033499385828950574, 0.030198150114821534, 0.07244416446025882, 0.02468367226954017, 0.03377806016110948, 0.014815374477101224, 0.0268784378921347, 0.030479925352015665, 0.018497829824419956, 0.02205092247043337, 0.0026183654928380357, 0.024439070573342696, 0.023399554924773316, 0.015863502431394796, 0.05561168857717088, 0.03605836869350501, 0.041938960286123414, 0.033681094114269526, 0.04013688323487129, 0.06280568987131119, 0.00921324941529227, 0.03714147682434746, 0.011418915702961385, 0.020130676849346076, 0.005660339549649507, 0.04151318295459662, 0.016489237247567092, 0.04821289184370211, 0.0816066467336246, 0.009838787456309157, 0.03323542892134615, 0.011802388072412993, 0.02843592512155218, 0.06010863530848708, 0.02723579514505608, 0.0194405473635665, 0.04122842555599553, 0.020902033762208054, 0.04812469586197819, 0.08754414705825703, 0.10026321134396962, 0.07492512597569398, 0.05125705778066601, 0.049857396100248606, 0.05252299717228327, 0.05083783170474427, 0.08552938659808465, 0.02633704667511795, 0.016995999429907118, 0.012519718330752636, 0.023547663852306347, 0.05251403711736202, 0.033257460953401666, 0.03200338235391038, 0.05999046164963927, 0.049190094228833914, 0.013322678012108164, 0.05825704216424908, 0.05617258258696113, 0.017241951410791705, 0.028207075615812625, 0.050672370940446854, 0.03136867730479155, 0.050123249513230154, 0.03235015785321593, 0.09342551218079669, 0.007722334952891937, 0.09052527709198849, 0.02209530714234071, 0.010804704955912061, 0.033135524817875454, 0.015066132182255387, 0.012166662141680717, 0.031172112495239292, 0.026110268397522823, 0.012663982509236251, 0.018832094834319184, 0.015809582646137903, 0.03515801379191024, 0.0027952865015582313, 0.09883182136608021, 0.022634847655094097, 0.032256173967782936, 0.014715276991150208, 0.025902327948382924, 0.03782629168459347, 0.05334932390334351, 0.0496123567489641, 0.029051833054316894, 0.018803867777543407, 0.03909313013511045, 0.006690536367906523, 0.06321849022060633, 0.03520576569384762, 0.03407224580379469, 0.03309130808338523, 0.03961830945419414, 0.018379147264308164, 0.03557289385103753, 0.02098039777151176, 0.054344877268054655, 0.05886413423078401, 0.03489444364926644, 0.03444704819204552, 0.004889777370928121, 0.033971025342387814, 0.024159919570333192, 0.006044275443335729, 0.06042537545519216, 0.031981994930122576, 0.00842158734199724, 0.05240453174337745, 0.08165484986134938, 0.020366515265777707, 0.0934295766055584, 0.0282316385834877, 0.04293980622398002, 0.018710718490183353, 0.028523681751851524, 0.0371135924277561, 0.010752197371662726, 0.02371751473817442, 0.032483561230557303, 0.05642709767978106, 0.05979958296354328, 0.043905371733542, 0.02475152407506747, 0.04024321645764368, 0.03274856986744063, 0.01686771899195654, 0.05788596493325063, 0.02623116467813296, 0.033564749107296975, 0.02531929503727172, 0.044240686776382585, 0.03676916805229016, 0.042331034783273935, 0.09320444547172103, 0.018953067450118915, 0.07379774682755981, 0.01229287135148687, 0.06369623994188649, 0.044057183765939305, 0.02030655482251729, 0.09730745173458542, 0.10342189363603081, 0.1713317749755723, 0.2920412820364748, 0.1293407032000167, 0.10534550648714815, 0.25398903819067137, 0.15848045742937497, 0.08299283270857163, 0.0906574557136212, 0.07073809672147036, 0.11838616244494915, 0.05173558781721762, 0.15873021259903908, 0.08822227495589427, 0.06968397899929966, 0.12549472600221634, 0.09644215673740421, 0.16031995229423046, 0.12497236260346004, 0.12789688924593584, 0.19886766241065093, 0.20345510196472916, 0.1332034266420773, 0.0861091608447688, 0.18825234845280647, 0.1307895654546363, 0.1506432829690831, 0.08197750004806689, 0.10476062965712377, 0.08547171112149954, 0.1328879485705069, 0.0673207975924015, 0.08237755072436162, 0.15785598808101245, 0.0743406494813306, 0.10996775488768305, 0.10942246379064662, 0.16328816302120686, 0.095854884678764, 0.1251334332461868, 0.0699915046404515, 0.11923795459525925, 0.07442836370319128, 0.12293637756790433, 0.11607295514217444, 0.09936364354299647, 0.14610487435545239, 0.13002326871667588, 0.06888913629310471, 0.12100848316081933, 0.13130119442939758, 0.08943980426660605, 0.10586727956043822, 0.16939041843371733, 0.09766924660652876, 0.12065085449389049, 0.15657851020140306, 0.172969554950084, 0.10931867507419415, 0.13532580275620731, 0.13840073347091675, 0.06353717776281492, 0.14912776143423148, 0.13430445827543736, 0.08506731103573527, 0.12925984896719456, 0.13128169333296164, 0.15669175769601548, 0.056855246491198025, 0.215222799086145, 0.1317590291478804, 0.21428237669169903, 0.16704081451254232, 0.15116010952208722, 0.19387198904795305, 0.17243827560118266, 0.12727035715111665, 0.1616584440427167, 0.07560463129941906, 0.060369620232709816, 0.07311658587838922, 0.10453021952084132, 0.135783922459398, 0.08823385754866259, 0.15330870422933782, 0.14530682217861923, 0.12500227242708206, 0.09711654590708868, 0.10918925130473715, 0.15579891417707714, 0.1465541459619999, 0.06591146000261817, 0.17544775482799324, 0.12295581081083842, 0.1420218577342374, 0.10364977962204389, 0.23128905626279966, 0.18822302216930048, 0.2446875987308366, 0.12327333805816514, 0.10640410254044191, 0.1649383601865598, 0.0943674680643848, 0.12127039767801762, 0.07890065586460487, 0.15266853358064378, 0.08118503221443721, 0.06875301538301365, 0.08439294222210135, 0.08200941833534411, 0.09490110192980085, 0.1426568715167897, 0.10112895417426314, 0.13119883063648427, 0.21655466833284923, 0.1088105473401291, 0.17716444842517376, 0.15859390848449298, 0.12049468287399837, 0.12064104287752084, 0.14750315860978194, 0.11026361651186432, 0.10572276517216649, 0.10273133497685194, 0.09360128667737756, 0.11703423570309367, 0.12863875872322492, 0.2090868611953088, 0.1253475924687726, 0.08692445459642581, 0.11232244782149792, 0.10015263727733068, 0.1601613922310727, 0.13249263406864234, 0.13160907290875912, 0.18737361846225603, 0.09922849972333227, 0.09633485999490533, 0.062494486570358276, 0.18237710371613503, 0.19124088808894157, 0.07430464641324111, 0.09851472838116543, 0.14216425509325095, 0.11825014331511088, 0.1351284169192825, 0.08407401040728603, 0.22041075570242746, 0.13380774350038596, 0.11038809376103537, 0.12083051699612822, 0.10991054081491061, 0.07102546308721815, 0.20998819997268064, 0.18871342656867846, 0.115952393040061, 0.10322603450289794, 0.11931329912372998, 0.14332735911011696, 0.05511553020083478, 0.14821733028760978, 0.14639929070004395, 0.09963602785553251, 0.11940598700727735, 0.08741057743983609, 0.06813722449753966, 0.11253571137785912, 0.06808757609022514, 0.15556287898549012, 0.13808923161455564, 0.16823913449687616, 0.12794687013540948, 0.09110062050500087, 0.11513283130313669, 0.08253362734935113], [0.028781514880912643, 0.026120680517383983, 0.05534973334787147, 0.042527816724032164, 0.02430005231872201, 0.007414522630694721, 0.0061980849131941795, 0.011373884726448782, 0.03731398078213845, 0.03565656061151198, 0.04788634686597756, 0.04632245935499668, 0.06833619810640812, 0.017105051881766746, 0.02860083118347185, 0.04402862761967948, 0.010684221733494528, 0.04627668198996356, 0.023449171101674438, 0.008872093882278671, 0.055927896073886325, 0.04579517997003027, 0.019847349463296787, 0.054773151608450074, 0.033698359437819035, 0.07973175269684621, 0.022927460792873586, 0.01805868704936334, 0.021516111346759965, 0.04283821256831288, 0.06866233596312148, 0.03843498509377241, 0.026387202287358896, 0.019355253815384846, 0.036239856454942904, 0.050399559150849066, 0.009772542082438511, 0.01966806354799441, 0.017948871245607734, 0.02130405727906951, 0.010953362648641425, 0.001854716525745711, 0.07288734960768904, 0.06042335342083659, 0.03644592075475624, 0.028783350318138088, 0.01770181834165539, 0.028517551187958037, 0.029263172963900224, 0.025999801200149313, 0.04619002289005688, 0.029390065797737668, 0.03356552263721824, 0.10619594835277114, 0.029337207919784954, 0.025618296582251787, 0.039232776034623384, 0.006613668528318937, 0.027018426451832056, 0.07465073319950274, 0.04132758327094572, 0.05551823055637734, 0.00924339927067714, 0.031658537286732874, 0.03219682929505195, 0.08550180414957659, 0.04013418945084725, 0.024570623246420707, 0.014964306128344365, 0.03475297588322844, 0.04161781983982239, 0.05281232111155987, 0.04545903032911675, 0.04333870339074305, 0.03773210423865488, 0.059894801782710214, 0.020668137652267302, 0.06706053870064871, 0.05936244356312922, 0.08946156488465411, 0.019447907772181288, 0.04951708025432058, 0.03685714351013303, 0.03282113240233489, 0.06007958722433873, 0.0613147516601852, 0.008370053455499666, 0.039534690191171, 0.0341294700545924, 0.021753403524469053, 0.0421040851755866, 0.031824513737644465, 0.04159169963427952, 0.028726370339947085, 0.01679785193742386, 0.02937041542359761, 0.03647392728765096, 0.010681592410297265, 0.059434069719697745, 0.02757177684855248, 0.054103003282632144, 0.07797366167817797, 0.08726233110896178, 0.02353775724103408, 0.08017330257488148, 0.022663698964087025, 0.05382910583700452, 0.016176629379125576, 0.04276157882330673, 0.0162853578305138, 0.027501158316486647, 0.058080745195703845, 0.03603397196690951, 0.04334926139563322, 0.07750441400068146, 0.04821347538381815, 0.02788663236424327, 0.04819149424188903, 0.04731437237933278, 0.0766202693006822, 0.010699085891246796, 0.09800447004714183, 0.028999972622841597, 0.06257182599178382, 0.0847652747428843, 0.03141998812290175, 0.017728851176798344, 0.029621958533035855, 0.034173649469656606, 0.04619048768654466, 0.03644747459994895, 0.016640386011983668, 0.024428583814629486, 0.01484923337453178, 0.026618338456111293, 0.05811353200780494, 0.03719174609120403, 0.01722098298237792, 0.03006081801972219, 0.08369626996240445, 0.014590211112850478, 0.026518324090700065, 0.011633501554440175, 0.02593271783553064, 0.025190917908080986, 0.030770847241261175, 0.034076666459441185, 0.06172560461397682, 0.06482197703527552, 0.018089146486350467, 0.018100820681346313, 0.022311613928260546, 0.028114908507892063, 0.049607515401606045, 0.015766239525484185, 0.030669938905962875, 0.040064775318439515, 0.007719599608598011, 0.008560953345814986, 0.015717954973557165, 0.006985216492986572, 0.024200607922726443, 0.05218118176396404, 0.031515166229967556, 0.04369829980922597, 0.06912017068160431, 0.02337190631910094, 0.02048715709575585, 0.012270152302724975, 0.03358987865171262, 0.012514402008881527, 0.04772268421947956, 0.015698204515501857, 0.012574425216631165, 0.01873265383099871, 0.038040226990623136, 0.062307590884821754, 0.04461379961243697, 0.03887549681322915, 0.0351050168142787, 0.01785830208765609, 0.01036283531824925, 0.04542370579604592, 0.026427018722253184, 0.06008210458925792, 0.01730575575493276, 0.06289457795875412, 0.03664456866681576, 0.04619698805202331, 0.038931791471051316, 0.06875614342944962, 0.030492763234568492, 0.012456684972026517, 0.03673724637233785, 0.0554288403530206, 0.011088353797926434, 0.027936604772029177, 0.03775994113779493, 0.02446943162275212, 0.0191913384145924, 0.030954709875264337, 0.059847412897007804, 0.012642626467693065, 0.020958927227184176, 0.05078423422362123, 0.024300651125875965, 0.019432041927107742, 0.038877444208732674, 0.03691459507016199, 0.024283467226528695, 0.033250373655131886, 0.008847318872410272, 0.017567571884553348, 0.03181410161778331, 0.039264952165207694, 0.00937566695003105, 0.029752430639096668, 0.016979940202353255, 0.061459931012775214, 0.05894593841263226, 0.010209118298787092, 0.03785933294732656, 0.08328929144356932, 0.01735564334584134, 0.03705606962155018, 0.02958949402506862, 0.04529344064316579, 0.02168010308274201, 0.03865318499239428, 0.024058095212759714, 0.047038703957306485, 0.03221514634788036, 0.04319875893582191, 0.009118849078991582, 0.012616714063499655, 0.06669976841658354, 0.014420612981276852, 0.10052679505731378, 0.031935637417648516, 0.028826576391501085, 0.05242595987926636, 0.05995982579354729, 0.03001779889953988, 0.052461172454059124, 0.07389649402882371, 0.04890350139300738, 0.04139824590778776, 0.0654317018176828, 0.03782654274255037, 0.03527505090460181, 0.03320434523214187, 0.06643923132547311, 0.02515260103557791, 0.020002849333520447, 0.03126456628420523, 0.014115932946359473, 0.03306260944477149, 0.022530867252498865, 0.018981601543990628, 0.04142143144937498, 0.0363193807591285, 0.04855083960241505, 0.036503206073705635, 0.06362793860690934, 0.028708820031689744, 0.04223043857408421, 0.044139866650636704, 0.04286072975290673, 0.009714905621616967, 0.11878856085240841, 0.02682010593291904, 0.038407100697181056, 0.03261299178536449, 0.0444681995681354, 0.0785999291443399, 0.018118430361417786, 0.021629189207617725, 0.017245378012635877, 0.07893772423267365, 0.02941163981865559, 0.05579668775733028, 0.027716701750510504, 0.07016307900526694, 0.041181043455643315, 0.02907401097140142, 0.06476137028740984, 0.04931660369038582, 0.05308806077976312, 0.04865542559751442, 0.0063704646142598775, 0.06203600045825754, 0.05946754863751786, 0.016477125397484218, 0.05266934021243027, 0.030746996735355685, 0.02069029860597636, 0.01220337682337101, 0.0723864957690239, 0.07656300094510828, 0.015364076908943909, 0.04238372981282217, 0.022697829275525043, 0.012349049810187092, 0.020619700429961085, 0.021134331922179887, 0.11355862327452217, 0.03727265460682767, 0.05630830316139119, 0.04238047284473266, 0.03402852100719299, 0.05097147256934217, 0.09205075273556368, 0.0406327837679003, 0.07310844345816545, 0.05084215397281306, 0.016225061512419155, 0.03020774120731013, 0.03949443610118968, 0.04488230609734144, 0.05224904205117907, 0.04168087949178048, 0.050232615787535906, 0.08314840721764735, 0.026521752388881784, 0.04075038406465735, 0.021264754834451845, 0.02352945027606828, 0.007394316706008145, 0.042553183755704334, 0.02895513502880931, 0.04896934303854193, 0.046589978571449, 0.025522166829822317, 0.03675345657393336, 0.027295694520164813, 0.06181043506200824, 0.03438698427219476, 0.02340031149131911, 0.0978938349123512, 0.022537403241065995, 0.004979193867516837, 0.07841856351920537, 0.02187454916669854, 0.05561432129304324, 0.017829837543623786, 0.01970784435980022, 0.03386586259252258, 0.02431333464171205, 0.015288513552929674, 0.03503837110474706, 0.005643759122384446, 0.01336719499834414, 0.13683642526822432, 0.13728944238807472, 0.15836222948772566, 0.1150743822966303, 0.15072317368217877, 0.11827710829675198, 0.20229125155934266, 0.0903953512066177, 0.09671850369444915, 0.12156428476529461, 0.1291046001549278, 0.18032188899815083, 0.15254415811172553, 0.04124672903812357, 0.17960800230503082, 0.13616178504058293, 0.0990542315744928, 0.11861306455518518, 0.12309876456856728, 0.049891818181744645, 0.09777265534337078, 0.07177073881030083, 0.08519856006439243, 0.1601751393505505, 0.08489718195050955, 0.1968737601169518, 0.09615885479641811, 0.15465543339295046, 0.16588239238730498, 0.0845360452575343, 0.16301118502659456, 0.08932513863380466, 0.09453706110694579, 0.09180574052567993, 0.14336176083556243, 0.10725137564752783, 0.08794703401092972, 0.11869585939816066, 0.05630437783630831, 0.08112465616847787, 0.11621536607188837, 0.09506638627499342, 0.1834072284400463, 0.140549097476261, 0.14304075948894024, 0.14897642098367214, 0.12466073861079556, 0.13288633365716251, 0.0681683285427945, 0.16328418680599757, 0.109597383333104, 0.08815469286803689, 0.1393169050237962, 0.17268294175820692, 0.14628365476216587, 0.06659861241600343, 0.10337609930762223, 0.07370357295232159, 0.11191209698362009, 0.1749712468257972, 0.18187235508646282, 0.2912810242601803, 0.1030785074191434, 0.07060426925974232, 0.1320475015257086, 0.198466403942023, 0.10568486899137497, 0.10950504150241613, 0.12681776072297776, 0.10931948253086635, 0.1484614536166191, 0.12852357061845915, 0.14800307607012136, 0.14952513868255274, 0.10827150555061442, 0.16621321892099722, 0.11635693561817918, 0.1052540603226849, 0.17520593851804733, 0.12710745446383953, 0.09677199939531939, 0.20498982604060853, 0.16554730465369566, 0.14678483429763997, 0.15700806358030864, 0.08326041977852583, 0.15424057708254882, 0.1555270930486066, 0.12164494900831155, 0.07629472855478525, 0.09088426961430482, 0.11213561320411307, 0.11348661035299301, 0.22216463301862988, 0.09686900276158537, 0.07850397750735283, 0.09724888737712588, 0.16987958789936133, 0.1125587137149913, 0.10774775794042007, 0.09818989331168787, 0.20373326061027391, 0.11726862883993558, 0.12413883661585194, 0.18554944491812161, 0.0970860186165997, 0.09592037009341375, 0.23454428730266436, 0.13480727986565658, 0.10171842468636376, 0.12238267942198686, 0.24856702770505631, 0.14198202772864274, 0.08526988088020257, 0.13763920004878724, 0.17487630620598793, 0.0918898449412414, 0.1973195169121027, 0.09580752293446235, 0.2476681587951524, 0.1272330241543906, 0.12756879042301858, 0.1606348603963852, 0.12346817260341984, 0.28607780060597826, 0.11626758612692356, 0.06124748848378658, 0.09129956018711839, 0.06567761647914137, 0.20595437714031764, 0.10144689532795123, 0.12168335409036704, 0.11862470821610518, 0.12444809930665152, 0.187303647931133, 0.20934228891772882, 0.11628123825149876, 0.18636435190481798, 0.1233562957495451, 0.14592024497687817, 0.19239521186266625, 0.11988778758261885, 0.1021850939307894, 0.10600237588265113, 0.08432763322655644, 0.07003464589693717, 0.13446505394365105, 0.1269487722643784, 0.1381083663020815, 0.10514183741595064, 0.11258181104702608, 0.13205887377262115, 0.08399287797510624, 0.10647635294922761, 0.09893120639026165, 0.08816532551177911, 0.2297232145709651, 0.07568113612277166, 0.07956070758934532, 0.13958561846188136, 0.0871200423155512, 0.12172078208199569, 0.20185846835374832, 0.10571068724883453, 0.0784494707893048, 0.23132813987987383, 0.09196425309138638, 0.22058984823524952, 0.09827573477689709, 0.11334455226148878, 0.08198747451284102, 0.18881758169404098, 0.07699775190225669, 0.13927723786660604, 0.1399332998054368, 0.118848000520042], [0.02404814788938633, 0.023414214673851217, 0.04904164094477892, 0.026982891572905437, 0.031490850927574296, 0.06599789179329361, 0.05254980609087007, 0.04098421062475868, 0.09250098786183766, 0.017868008531097854, 0.03785411501303315, 0.02994036109053663, 0.09303211114768471, 0.04133237372817738, 0.02652428502083889, 0.03811889973336032, 0.04667679712708507, 0.06397435108997993, 0.05383319401049188, 0.047420898984585486, 0.037460927718452046, 0.03013730587969933, 0.06471853437168257, 0.0544213142379054, 0.05822749196418694, 0.00500002658892689, 0.020218586150024618, 0.02374015575540917, 0.05211570652733956, 0.031608651392161846, 0.042666159836309295, 0.03229640091636351, 0.0312307447062007, 0.04727497324347496, 0.025551055458241274, 0.07116498345775263, 0.035730005241930485, 0.013887398959403592, 0.019457152811810374, 0.001576950794385214, 0.03003369697502681, 0.052996767285679064, 0.024567164414163147, 0.014502281456121376, 0.0460279581935278, 0.06925376065607582, 0.03376192120569093, 0.029725815102990185, 0.07300558433468853, 0.027925030660948584, 0.045874249655753374, 0.06966092916471617, 0.014470246121553438, 0.06532380796436753, 0.028047212765419056, 0.012975783769174345, 0.053747057382549555, 0.013344747363589704, 0.04419117407607181, 0.057091061158904007, 0.023185002151876688, 0.04784695451546993, 0.01620071567595005, 0.05878099333494902, 0.022480728603633385, 0.04489845523078527, 0.10047357755580119, 0.008201082120649517, 0.0631231696211866, 0.024810590548440814, 0.024178860875378762, 0.018991665914654732, 0.011604588329126793, 0.0633756932137268, 0.041535751029316864, 0.011284134899532157, 0.0898983853736094, 0.040043394680001905, 0.05697349818157298, 0.06471231220556156, 0.047214872004198175, 0.01486741641669401, 0.03275901252137763, 0.05584982722731573, 0.041382839770189354, 0.07131584214844874, 0.09879168601972715, 0.006309531745500863, 0.00845740211661905, 0.040719619286911826, 0.030848732883376733, 0.03508697796080794, 0.01912033311756594, 0.03274213735546384, 0.018361330631056, 0.03307471790217927, 0.0346777908104871, 0.05711273356739964, 0.026830231371734823, 0.05002097732254437, 0.03436628895412598, 0.021940156717651656, 0.026181360207764164, 0.018042500596493483, 0.055961307138204575, 0.050656489828335385, 0.026449500283758556, 0.03198151317025934, 0.07526948249765805, 0.059767590037414005, 0.03667665319517255, 0.04029713963557567, 0.01043666247278452, 0.03411841332646353, 0.03431067283132246, 0.03843463225556271, 0.01340676800880049, 0.045824282336980104, 0.026004533981904387, 0.0071956492860668474, 0.049639077457998476, 0.0071967739578602564, 0.0311561940637018, 0.00984960500084396, 0.028600932963724648, 0.04262299483109798, 0.049008423262940984, 0.058522186508136134, 0.05047818100345986, 0.02097677778718727, 0.027092922811529467, 0.04491703351959586, 0.04941778004701648, 0.04289574555254408, 0.011698099784553051, 0.07683407568505832, 0.006543618269331221, 0.0349634472679879, 0.01816078112460673, 0.030146713767732893, 0.11060382039951426, 0.00875799058537398, 0.012409547144281012, 0.02910971887675779, 0.07767134718596935, 0.03217570649992142, 0.026728739496320486, 0.029929273828331913, 0.05306751473939844, 0.022937153665614978, 0.022412227100825736, 0.02040586860052177, 0.039676917916429896, 0.022220352664589882, 0.04864378532926951, 0.017448946999918138, 0.07956105364220482, 0.012264140482459749, 0.019787918277350918, 0.03914500413728612, 0.02656301240702825, 0.017324773395167928, 0.035375891386398246, 0.022849610773846507, 0.025078861242426292, 0.053058225594993146, 0.07174579586301531, 0.04485262019027557, 0.05338062133107867, 0.03237025945314339, 0.03605088105957423, 0.056877156386950185, 0.045273474750242064, 0.055836979166737626, 0.06858373446656124, 0.06208316542740379, 0.05810960329004696, 0.0189211457701666, 0.043419890105724335, 0.023534576608134166, 0.02596876161572124, 0.05554302083328366, 0.041944866933460744, 0.01698247453064791, 0.03915665458355631, 0.05961978475430182, 0.012642565399541386, 0.0506801299883851, 0.006145869099002863, 0.015133062876494867, 0.04817385572407927, 0.043263250296669345, 0.029452161929969276, 0.023319545468049388, 0.008008645348516958, 0.019538210605138114, 0.026904191688767502, 0.027619532143164958, 0.043967478043798885, 0.048242560787392516, 0.04928561160340905, 0.032091228890099695, 0.023657720535993576, 0.043743717550699196, 0.05811340308615139, 0.003934040017026875, 0.07136041511382375, 0.02202335698530078, 0.03274780312286956, 0.07276940665074758, 0.008831978043807405, 0.030838025600782464, 0.03563946152904204, 0.012508727759788079, 0.014214764964500708, 0.014336347413648452, 0.029493742555912052, 0.08777330190475498, 0.060410644459937296, 0.028712806424924305, 0.08999606727489404, 0.08941068832895585, 0.007135054412563997, 0.025105446244456937, 0.07138784828462771, 0.021331946764673506, 0.04368399968370795, 0.015499687221433436, 0.04453103530353733, 0.07487209167863641, 0.031030417419970036, 0.03126967904557075, 0.009581373322622051, 0.029104657005518675, 0.03438260093597429, 0.042803193376000435, 0.03778931152607713, 0.04916239303669759, 0.007338149273501975, 0.05495547057528581, 0.021418437927163074, 0.06388991419225931, 0.009566819594640816, 0.031105141088898693, 0.04304878573332514, 0.03254528756120375, 0.025263241259381175, 0.00955450757672744, 0.042263364485864124, 0.04288856325937169, 0.012412808353214391, 0.04549700454143541, 0.0380738280447466, 0.022175991741408194, 0.07411153534693377, 0.027429749291124086, 0.01776779060518103, 0.009881144156679511, 0.02099363598972559, 0.016716403986460397, 0.0714284178933927, 0.04680614286501493, 0.09758798525269542, 0.022911861272794858, 0.021098473042781864, 0.022782425628975034, 0.04334207231711064, 0.030956911721399853, 0.020614110997744968, 0.02058508835865983, 0.03762579815728324, 0.004298461243576769, 0.045737667341849635, 0.02595054803948317, 0.0519743134001536, 0.05681724853015371, 0.02873272482039673, 0.045521591257836135, 0.07385778360600982, 0.03573893815545099, 0.012561241281218827, 0.016620913753286004, 0.013063618431000837, 0.03442112476165805, 0.05151774414948054, 0.016234825631337504, 0.03663770867777722, 0.013245235114092273, 0.03175493336415716, 0.06432942846523863, 0.007490906165912747, 0.02680185673359249, 0.0318370971695653, 0.031359669752418995, 0.02077440302153783, 0.012503000924230685, 0.017899855572198118, 0.05487008712121418, 0.05665069193180118, 0.03104783541389874, 0.01839156275881188, 0.021995973008285676, 0.008601493268672909, 0.05967965189899717, 0.05211430535252605, 0.054051804422800026, 0.050903279799968004, 0.03480896180761712, 0.01460873511885958, 0.12172592537743704, 0.0649735549730914, 0.012462838436476886, 0.0355759235098958, 0.022249548330104778, 0.0041575685359670645, 0.05586117233282753, 0.04875670712707298, 0.04857499205640384, 0.07418984507343598, 0.04276708174230797, 0.04946855142978685, 0.026389265033815588, 0.025060737572078193, 0.01243599983198302, 0.03822496832747545, 0.019089739669912627, 0.028684555619422878, 0.026603446308789507, 0.011299550366987075, 0.030563809243696075, 0.03827325966475265, 0.08519374925111022, 0.0444531360907214, 0.03243422834202647, 0.024825158695291196, 0.01537945251246648, 0.05818563313888652, 0.0484349933186812, 0.03084890590980649, 0.023460143012925982, 0.0062702288767988125, 0.07545610676918711, 0.07865648503814425, 0.020521185626941066, 0.06279025998498712, 0.046094342667077265, 0.03834923183811562, 0.01185743507396962, 0.041855262991573126, 0.07477160742772476, 0.06329451328409569, 0.03369163854845932, 0.1851440066737788, 0.09669435463313546, 0.1189527798976217, 0.12674297259322234, 0.16098830928759916, 0.18376921330179485, 0.13992119474070414, 0.15072499215602875, 0.11632433879588332, 0.06176347365336759, 0.1750737598964146, 0.19325749416436466, 0.199606912742768, 0.20231614022382668, 0.20493985872183526, 0.1342802345752716, 0.12995708441095694, 0.16121351506028855, 0.156014566176704, 0.08247285775308098, 0.09875487549496548, 0.2940715673778738, 0.16042363244507993, 0.10993095114827156, 0.10493451104100261, 0.08170736168644258, 0.13072582387498446, 0.12418329423027379, 0.13793249002524785, 0.15174563096037932, 0.10730835901839392, 0.10035530211670057, 0.12581226682024343, 0.15233268588781357, 0.11875609973711626, 0.14664173126220703, 0.1077338954699891, 0.047688567478741915, 0.1134648225935442, 0.0940255814098886, 0.08476209919899702, 0.11604535233761583, 0.09993762310062136, 0.0918731801211834, 0.204264458534973, 0.19367279830787862, 0.10628576603318964, 0.13794690210904392, 0.1630958526262215, 0.13624533984277928, 0.10530178169054644, 0.20449214774583066, 0.10633407094116722, 0.30481896496244837, 0.041200887212263684, 0.18532626117978776, 0.11188722188983645, 0.12896665398563656, 0.08471554491136755, 0.14226216769644193, 0.1518530159124306, 0.20513100203658852, 0.14659774862229824, 0.1190056920583759, 0.11172319961977856, 0.12557620448725565, 0.21984516962298326, 0.16360293541635784, 0.12011521895016943, 0.11786781597350325, 0.1538411642291716, 0.06419466462518487, 0.15022322908043861, 0.09668159138943468, 0.08561816611992461, 0.13943366732980522, 0.14291789036776337, 0.10392814861344439, 0.2419899334864957, 0.18410728658948625, 0.15606776332216604, 0.10110805529568877, 0.07919811204607997, 0.2025798867855753, 0.1262125481984445, 0.1521102621087006, 0.17028480901249818, 0.13198578198041233, 0.06970286262886864, 0.1324394776352814, 0.13939364733440535, 0.09660398733935185, 0.06575944780239038, 0.10364131829036133, 0.12675226852297783, 0.1296154555997678, 0.12067297473549843, 0.1175622580839055, 0.12782381102442741, 0.13364190954182828, 0.09377435381923403, 0.12803142916943344, 0.11655069807810442, 0.09188125468790531, 0.16767209635249206, 0.15120976471475192, 0.12172006283487592, 0.13218071152056965, 0.19994776802403585, 0.2405681312084198, 0.15464891945677145, 0.1928726833845888, 0.19530338581119264, 0.2043931766280106, 0.09832848408924681, 0.09516508597880602, 0.12897746983383382, 0.17860803167734826, 0.17759006630097116, 0.182665277538555, 0.10991188431424753, 0.1373941810535533, 0.29196183915649143, 0.10557580127247743, 0.14441350368516787, 0.1119650634271758, 0.08485240542462893, 0.09733014873095922, 0.17950672416814736, 0.0923862000927329, 0.14883128234318324, 0.1428890254880701, 0.1524484303912946, 0.1629153351698603, 0.1429046725056001, 0.14599766582250595, 0.11609103131507124, 0.14814902895263263, 0.14793926663696766, 0.1401629839092493, 0.12921929971448012, 0.12244549819401332, 0.13535635040274688, 0.13287843550954545, 0.20275148829179152, 0.106300843081304, 0.1301683530743633, 0.18851973196225508, 0.11679294865046229, 0.11392464541963168, 0.14749220705458096, 0.1025940944839801, 0.10677528833704335, 0.09642471838742495, 0.09669451069618974, 0.1753326074353286, 0.2742595933377743, 0.2802228033542633, 0.07139515610677855, 0.15644547662564687, 0.14090942671256407, 0.13605852558144502, 0.11662818677723408, 0.29489954294902937, 0.05923957444195237, 0.1348647517817361, 0.21598453606878007, 0.09792103059589863, 0.08559368457645178, 0.1320629721241338, 0.10058706253767014, 0.17802473583391734, 0.12288216261991433, 0.16548288453902515, 0.13953558328960622, 0.15008786134421825], [0.040297875846070905, 0.03219925845041871, 0.03510909480974078, 0.031355221955371756, 0.038447748337473185, 0.04560376863394465, 0.00792354772732194, 0.034025613484638076, 0.022241551794910004, 0.04991435232971396, 0.029911089089832137, 0.042046810034662485, 0.02763322158716619, 0.015906833677685688, 0.06238056732607739, 0.0339493936459933, 0.015257904838238443, 0.03929257532581687, 0.021143719454162886, 0.12350713408419065, 0.005628231272567064, 0.02669273303555591, 0.05021079070866108, 0.03552535568763103, 0.05940120826874461, 0.05606991684596453, 0.04083598464993494, 0.03833182741488729, 0.027895901152598004, 0.11177875128175531, 0.02674458159266838, 0.04704082098656467, 0.0401702094823122, 0.0903446917821254, 0.026107315073854158, 0.042350753010915856, 0.026058789641995515, 0.02551484713330865, 0.05565127091748374, 0.018446634357262934, 0.04689326336873429, 0.004882394061756453, 0.03982293186709285, 0.04758429700242622, 0.00783685639700187, 0.03732973636527147, 0.023625172907486558, 0.02464659372344613, 0.059109533205628395, 0.005305416117023144, 0.02490473897861583, 0.023955300550109575, 0.03367551316374114, 0.019772066002977744, 0.018134961170809608, 0.044641717935779264, 0.04220076284504362, 0.09329263466809477, 0.0708835678441184, 0.06452180671372584, 0.03529922032196607, 0.059823786307658465, 0.040982232695179324, 0.01713161143873419, 0.0782237561153514, 0.02776578188474689, 0.060191898340625424, 0.014741799228691628, 0.0197683238823499, 0.07334625641150133, 0.0018335504740077469, 0.01491669162974826, 0.0671357000246644, 0.08254257722624711, 0.053974973902638466, 0.011033817393971341, 0.0261354827588158, 0.01279026550972568, 0.0698934088328055, 0.032544106910271306, 0.057888523010270934, 0.02437229424581996, 0.037357569871736426, 0.04081335211438792, 0.009590286728260773, 0.02720907104334661, 0.06862844992429018, 0.09274988129202809, 0.04586920814056482, 0.02303940719658775, 0.014275057041751487, 0.05091781062739236, 0.03647547095481839, 0.059364031335072856, 0.04864631626488907, 0.06773072773856775, 0.049667816808713336, 0.05013734268556748, 0.05269897183669465, 0.027810792505208935, 0.05046688339539936, 0.03752403826053653, 0.031173154046492915, 0.07187616958149842, 0.011313713089163815, 0.050856901931443384, 0.03876107206035938, 0.04985411199075835, 0.016716561745852232, 0.01081294661188232, 0.03466635410274778, 0.0653621248368706, 0.02025556461220341, 0.025412356115079353, 0.034534986330462356, 0.028964956823204244, 0.04474935394578746, 0.057866077071854045, 0.0032336135502971175, 0.02759824480329241, 0.054025633327130757, 0.030367919576487372, 0.052239769870149236, 0.032069508984152756, 0.04959050792136362, 0.05862241970109088, 0.07888947360749755, 0.028317200153001716, 0.020512010137151395, 0.04318067258489983, 0.029558322126311914, 0.010235238504329962, 0.056576076828475506, 0.02530450975921537, 0.05677273663293038, 0.04092056404000946, 0.06054401730320283, 0.010517475145336772, 0.029599909537604878, 0.04759339615702629, 0.022681703890806863, 0.00838679715525359, 0.026747903021584665, 0.055611848032900264, 0.03801568437899862, 0.019891394867694805, 0.0268249472802771, 0.014550031661721212, 0.0437920631707779, 0.04530820556517158, 0.02528909344359168, 0.016357058625934378, 0.0389772838513766, 0.02634431208883013, 0.01289150123817048, 0.12066320383122989, 0.034132547210901976, 0.0005542978542507626, 0.042495718624975, 0.05291394530130284, 0.06666490528732538, 0.02042621956206858, 0.02801456844567188, 0.043211355938443115, 0.04491504880466631, 0.04040788333596928, 0.04371362452262214, 0.04527090649519648, 0.014995055639051964, 0.036940813663282564, 0.04833597131073475, 0.02532380390247064, 0.04028975378189768, 0.03300925962893026, 0.025462939204382043, 0.02784760811898325, 0.03716612460889986, 0.041142970855746946, 0.0375954947833504, 0.008196570710944278, 0.013016366948639708, 0.04541299512077655, 0.011936415701971521, 0.015305451483332684, 0.050370734983256886, 0.012658267548041684, 0.01340905636815088, 0.018140162141727548, 0.037162348561521084, 0.05200220797477024, 0.003437842836969399, 0.001472994140515636, 0.025180797558277845, 0.008088800690269895, 0.04381309436368091, 0.04286602571872728, 0.021575232102934803, 0.014616858879370349, 0.012150808170969998, 0.042720581737479994, 0.042797731169100316, 0.036326176287340264, 0.03788668130125318, 0.021116991959778324, 0.016082504697676216, 0.0436898995456951, 0.017804110888391733, 0.03657957519005452, 0.015396359908793653, 0.04393016540312341, 0.013815788918041756, 0.015428975390802537, 0.07840003272784607, 0.02860840702695506, 0.012660431226582398, 0.03566572083426373, 0.03819463102679167, 0.02500263461843133, 0.07459210098854133, 0.0199043481012008, 0.04828349341239248, 0.029527581097292047, 0.0352135077784104, 0.0024781358411668664, 0.03981479623221925, 0.04427414873082723, 0.07169434933790139, 0.07564413560820477, 0.048440591232585054, 0.04105121595785022, 0.011474422411993146, 0.07187478537006037, 0.012538940379662173, 0.043812378509236236, 0.04031189098688109, 0.028240922638880353, 0.04521724794592176, 0.01640019309706986, 0.03197675324710352, 0.0894048936398966, 0.06467078586242028, 0.01680257454115365, 0.006930695780153785, 0.0057867976969906264, 0.04300806684685605, 0.016670153343251774, 0.029972150456160307, 0.024783910551507558, 0.06383099021123988, 0.05696611572057009, 0.030328924168965647, 0.036810256740344424, 0.05140575533732772, 0.016062282657782947, 0.03072190790304116, 0.02481267704362316, 0.11196038153554712, 0.019699508557096124, 0.07086099298404795, 0.05175420003277915, 0.05391137142266546, 0.0498108112785433, 0.0038269960288224475, 0.032713238549019606, 0.02489267292964671, 0.022403065181736435, 0.036885438420410664, 0.051012072712183, 0.02057321908484612, 0.055807791982910464, 0.04552300600335002, 0.06915092867399965, 0.03946394952280181, 0.044571228325366974, 0.04919281515425869, 0.030304571547146355, 0.07968473700540406, 0.05295343264671309, 0.018124464234071117, 0.05617346468248537, 0.021458116958716085, 0.018319073166432123, 0.02008258567989937, 0.050728292404008765, 0.008233947812446525, 0.052145090486322127, 0.06560050775962216, 0.06838379055261612, 0.022729625426498905, 0.02159186638891697, 0.017369151281725084, 0.014931885725153344, 0.019989444874227047, 0.01472896643515144, 0.035654786242438216, 0.05838643200695515, 0.06826480265174593, 0.04908489755221775, 0.036615937881703885, 0.03473858415548291, 0.034806505510849614, 0.042533017694950104, 0.01408915625818606, 0.05257196365190404, 0.037765142108712874, 0.03154651794050421, 0.023622848925047686, 0.029671640867101293, 0.02668423777712243, 0.06497675087302923, 0.02336411164807422, 0.021987808535673788, 0.016488892891045128, 0.01558860414661467, 0.05966272245028189, 0.023665135227409855, 0.026942835954417075, 0.01920150626184685, 0.05621323361992836, 0.010548699630557426, 0.025699469726532698, 0.03965031595102378, 0.024445238456662213, 0.06185601904456105, 0.01877034136227199, 0.05208292989326375, 0.020732483128085732, 0.0306920150427946, 0.06709385477006435, 0.046834753294076235, 0.022328945408974375, 0.06962018313684634, 0.03881097152563078, 0.017518026953829185, 0.02013690410447972, 0.06527544877358846, 0.07251025377107517, 0.06278375283415828, 0.009389229168716286, 0.04338044347241521, 0.015047915213342224, 0.012184511005346264, 0.061434940568038394, 0.003988437745387533, 0.0295870954037777, 0.04749834018626383, 0.01760554270419691, 0.057273946702480316, 0.02486044421259846, 0.05688508506864309, 0.023245753088433827, 0.03913810343614646, 0.10776510808084692, 0.25517319036381586, 0.16930224959339413, 0.19134961654032978, 0.14030702332300798, 0.14120586509151117, 0.07946622837334871, 0.10621358347790581, 0.10072310880890914, 0.1681712538536106, 0.10791450113590274, 0.14159955110933098, 0.11776238520230566, 0.15554062303687843, 0.15846775525382586, 0.1323979784335409, 0.0968575965879219, 0.09777669262673173, 0.20124085220907414, 0.19265967767153466, 0.10228557139635086, 0.14147684483655862, 0.15412661034081662, 0.1361493542790413, 0.1159157385783536, 0.14485931476312025, 0.11399046331644058, 0.12937980038779123, 0.07597339472600392, 0.26919777638145853, 0.1293816188616412, 0.10088166208671671, 0.1059848153963685, 0.18044154186333927, 0.10454216852251973, 0.08674728910305671, 0.10987659370792763, 0.10167039119239364, 0.11867802749787058, 0.12240010420126574, 0.09700238917555128, 0.09503046463110618, 0.16828307642468385, 0.18181557527610234, 0.1367401818611792, 0.14093147910067014, 0.08293851598032884, 0.05448874704805868, 0.18198074427034172, 0.055044935417494605, 0.16411509364843369, 0.14321168246013777, 0.088049106033785, 0.1257194432296923, 0.0856381014787725, 0.11880225368908473, 0.1430732206042324, 0.13149866169052465, 0.10257432197353669, 0.08466390161109821, 0.10551216147307839, 0.15989822920944008, 0.1720504928380251, 0.15504253762108938, 0.16107620671391487, 0.10482678682144199, 0.1570242398551532, 0.12112797317760331, 0.08171576194997344, 0.1124050933867693, 0.10906708785997969, 0.1779950838536024, 0.12925181511257375, 0.137827995632376, 0.15199797813381466, 0.08904723783156701, 0.1576223684740918, 0.04953537695109844, 0.15699119519974503, 0.14414628302412374, 0.14135958041463578, 0.17238718191427843, 0.15932853120778287, 0.18265978140490396, 0.14599772010530743, 0.16860882751643658, 0.09415685079459633, 0.1780609017504113, 0.1039013871923089, 0.10360951535403728, 0.13763777512524808, 0.1255232109022992, 0.19993345093514236, 0.17551734537950583, 0.14672570675611496, 0.14721924598727906, 0.11047052219510078, 0.12118978771780219, 0.09358513754393373, 0.14148301950522832, 0.2076321228274277, 0.08024005685001612, 0.0823847431955593, 0.11471379521702017, 0.10600806200610739, 0.11732395658535616, 0.17069867466177258, 0.13118582990552696, 0.05603874155453273, 0.11282011254557542, 0.11385197431913444, 0.14806251573775495, 0.09105892452810492, 0.0983392863667437, 0.10433515427368027, 0.10368496844811098, 0.1265690776386431, 0.12944575399160385, 0.1290106094841446, 0.14895086735486984, 0.2310390839619296, 0.07197901513427496, 0.10398715401866607, 0.14032731152006558, 0.13361612521111965, 0.17659644676106317, 0.13143785138215336, 0.25789650423186167, 0.13875923066266946, 0.08226435072720051, 0.07121584644275052, 0.15781748800405435, 0.12207672798207828, 0.16144978095378193, 0.1433062023882355, 0.11017124075442553, 0.1489402007843767, 0.09547889485423054, 0.18485060813171522, 0.09550447562443358, 0.1592472291418484, 0.10941495240799018, 0.15165257666792187, 0.0854288005669202, 0.07806958617376429, 0.07760320869939667, 0.09933314339390822, 0.11435658724180289, 0.060478647239506245, 0.07969106773712806, 0.08293954056820699, 0.15568410605192184, 0.14232808058815344, 0.10015832340078694, 0.1399619746953249, 0.22806202513831003, 0.10481012200138398, 0.10509005840867758, 0.12449839232223374, 0.1308054703154734, 0.13156127690204553, 0.20173914118536881, 0.12347849990640368, 0.10551013943872281, 0.13673153732504162, 0.17370193850781235, 0.13872219622135162, 0.12095992719488484, 0.08842374557363135, 0.1279089535985674, 0.14300151302346162, 0.1262475470347064, 0.11638907103666238, 0.15670778469315597, 0.06422456087810652, 0.13865511624940804], [0.011366978088127715, 0.014482863480225205, 0.051680019191865406, 0.04219032019110663, 0.03217177778216345, 0.025707603665068746, 0.023207699148250476, 0.022504541790112853, 0.008990616138492311, 0.055630572206739864, 0.021399221815434948, 0.09077147673815489, 0.0400738710803645, 0.07347783792231764, 0.02062759518490306, 0.015917427305664335, 0.031774040910282304, 0.02624916112316506, 0.03394173637830785, 0.010402476182207465, 0.02715285780972668, 0.024579710526657955, 0.028594673478177617, 0.04016648432505982, 0.004318448340719832, 0.04071315284818411, 0.030705534853041172, 0.08054266989763294, 0.01987538653026734, 0.013423782274393099, 0.03298103596482958, 0.025536626411069716, 0.02431327526989792, 0.06010250135191849, 0.022909252305648158, 0.028334149957767556, 0.019430167474118725, 0.028123758300872784, 0.08757772097097975, 0.022660557346950685, 0.035584276275975366, 0.022208196709730794, 0.032315868086048534, 0.015345476567745209, 0.05702846630343369, 0.023739080277404616, 0.0389538913566087, 0.026963025763896958, 0.06895645375230483, 0.012857465921635074, 0.0852252332759755, 0.020073632410328304, 0.05489524041435548, 0.02436801608252738, 0.041886000627917905, 0.07753621693700552, 0.04869191042546715, 0.029450550409299985, 0.0636145036135401, 0.01023171266673931, 0.03174341183954051, 0.03247397013806871, 0.008855758151704711, 0.016030330443754792, 0.05838694769356932, 0.0033243493734127177, 0.008289241631116186, 0.007396952814555594, 0.015685057899515544, 0.017869389349860803, 0.04033719355772648, 0.011143571281406497, 0.04535278531589678, 0.04084732636277165, 0.009862582831244384, 0.021949174448049495, 0.031043014422591244, 0.02516022776918752, 0.04911033243739179, 0.011233058176003397, 0.012186472819718932, 0.03434990911877581, 0.04372943778123174, 0.027569074582840716, 0.017310125520452857, 0.021454793833462254, 0.01640362139525158, 0.0295786612134959, 0.039246713143906424, 0.035389621542500596, 0.022448584703462462, 0.040829745520438464, 0.017682788827057396, 0.021744755595656376, 0.005936863773968071, 0.04679184273949691, 0.03121349634602666, 0.035908286925405264, 0.03200176065521581, 0.07608181105128356, 0.01748513157612511, 0.027925746515393257, 0.07107404619455338, 0.04395395144820213, 0.007883868695768927, 0.015160002413072755, 0.027908186029110636, 0.022312309426654662, 0.041427626474095244, 0.03483305658612933, 0.05670898148257818, 0.013345255416684916, 0.026760367709877234, 0.04161837963121278, 0.05541174127055066, 0.06199963776660817, 0.052041708890880854, 0.05915378725954464, 0.043503814709505866, 0.052362957902784855, 0.0694197846044387, 0.019928963655339818, 0.055033576741282425, 0.025632123429594294, 0.020020304646875178, 0.012386696629359253, 0.03739453645955239, 0.03397945953266961, 0.05183934599959424, 0.024010925154600824, 0.0218276793602854, 0.11411272175610065, 0.031382346392742226, 0.0296859952754208, 0.014163732345748161, 0.01268222153053752, 0.039263045481805287, 0.028928668770406927, 0.05101411510258913, 0.009581938203025078, 0.03150448948144913, 0.044478537049144506, 0.03162480052560568, 0.03323511340256248, 0.04964797644476805, 0.034439031300800185, 0.025800640994150723, 0.016915240191987584, 0.03744731969865305, 0.01665444695390761, 0.016466647120458738, 0.015352674127955521, 0.013713132506901664, 0.022476385979514037, 0.005000759406747031, 0.03905175306967326, 0.02277850030389215, 0.02258318569511175, 0.013597389699758163, 0.05286478543920176, 0.016010369639843702, 0.07017106536243643, 0.04173354059457779, 0.018550509586930275, 0.007346686940374119, 0.07897614288542952, 0.016432338693578328, 0.02491081695604537, 0.058022099414042065, 0.017239607072302272, 0.0592063194406884, 0.03175837014402662, 0.02077742080603327, 0.06657257702733789, 0.02813313395849296, 0.010031902763460363, 0.06470434620444264, 0.01874739839695394, 0.024454780355361954, 0.033206309591020854, 0.03218120941892266, 0.013270770931350333, 0.0730533464146512, 0.056484874936618974, 0.02439113546695028, 0.07001325168779918, 0.016332795910005058, 0.01887605372550232, 0.07599551496761185, 0.03289861431611436, 0.03164016255842788, 0.03801368270069361, 0.0698799059859344, 0.0074649946098881105, 0.032263488575283966, 0.03583658952265978, 0.04599697289190122, 0.013825260418733316, 0.035878862254321575, 0.006226300943775901, 0.07635148800909519, 0.0369404913591487, 0.014670363061928322, 0.07226630686117069, 0.013519744089405452, 0.013311967336838799, 0.023856224259361625, 0.029838689403342347, 0.06793436288301434, 0.02457828729945634, 0.039723441669983525, 0.06901201898498194, 0.02999170244272266, 0.03461000516212412, 0.00839383525973452, 0.04468809919697898, 0.03156606314171638, 0.012307484451282238, 0.016812810241909962, 0.029052562479461943, 0.023774552391842008, 0.02214623289182782, 0.031842342245259454, 0.06288533631180014, 0.0060313934560066885, 0.0786840742720025, 0.00934407435956278, 0.026586922284747874, 0.011758167945247675, 0.03048765047320298, 0.07701683909233127, 0.04796587795551334, 0.020518692010747533, 0.05525114220966186, 0.027357503971351043, 0.016664499450208883, 0.024214582351435508, 0.09053278847464494, 0.027590928499453833, 0.012239971913264265, 0.048790460851575644, 0.046181558165699244, 0.013724955979601612, 0.023623992256554108, 0.013512122444808483, 0.030766541936567852, 0.04260187542864254, 0.026277513708919287, 0.045218906964042356, 0.061385644998933585, 0.03804824388186846, 0.041321496811828444, 0.032926247654748816, 0.04053641143920166, 0.02860491257160902, 0.03947330652070897, 0.029901637097022364, 0.00981486146338284, 0.03762003739497491, 0.02491168717720679, 0.062340574472078254, 0.05330921230571611, 0.031319171389830966, 0.013177033863030374, 0.07468954540256943, 0.015932463641677583, 0.1824982493583645, 0.07224759965070657, 0.028365365961300473, 0.06544551679066249, 0.009346851264126599, 0.07074699910091502, 0.004559365591766047, 0.012747959699481726, 0.027692664647474885, 0.040292562916874886, 0.05880603127713714, 0.009352760455970253, 0.011255231852244054, 0.025455473622839366, 0.01629807018408818, 0.027735356374510696, 0.03278993336217744, 0.07048937292503459, 0.031537462890680344, 0.06644303112157754, 0.03416845867676394, 0.055492028926632235, 0.022151355831218616, 0.027102673359747444, 0.04576942278072238, 0.03996988898143172, 0.0337033466702061, 0.014772463922521897, 0.027114946361897246, 0.033311692864767144, 0.013938602908248348, 0.02916457164766533, 0.059970607714993615, 0.010978887439705431, 0.0055202903458848596, 0.013931586856155522, 0.03461126723725881, 0.03683103008994034, 0.02972830193383353, 0.08793103415518999, 0.06755326368979045, 0.0555168463449393, 0.11263871299368994, 0.05910460025604282, 0.046226368618330786, 0.04159903120515602, 0.01153769071346947, 0.04681410547345877, 0.039417273098868985, 0.0065724992642312175, 0.02543713621396039, 0.019287978764623404, 0.06956039063100304, 0.014582655625417829, 0.01446111304020243, 0.0394472847027438, 0.027813275943377187, 0.11673122910516602, 0.025484170565115552, 0.053135524304317575, 0.026305196241342595, 0.029934851386185204, 0.03646301644455109, 0.022295284983036772, 0.04124643048271537, 0.014609786848138486, 0.005572424311789551, 0.039778905122407844, 0.02989997129355158, 0.030394209415784905, 0.011794779150347625, 0.03577716003305145, 0.024907410710251758, 0.042100946951125345, 0.05997410217033965, 0.02563850165876959, 0.021324096114507744, 0.038981382202889235, 0.07760881339865071, 0.04546937120280095, 0.06377488215054784, 0.03726057668349572, 0.021034217472853403, 0.04111715599096247, 0.020720513770356774, 0.029057963618210385, 0.11134596807616097, 0.11651544139853545, 0.11378454150898115, 0.12577652159546102, 0.11016305083675043, 0.08589295923177685, 0.16529201263827936, 0.07722046745142766, 0.12411755775766713, 0.1441621064607586, 0.11140365033809628, 0.163611308538488, 0.1256374219166381, 0.16824248645986828, 0.07011011934706143, 0.15180040230708464, 0.12526705036205904, 0.10891619524253265, 0.10526510687278849, 0.11317820261631693, 0.14026325781430515, 0.07905372657946177, 0.15412997587450913, 0.12534570614142077, 0.10152463508503777, 0.12401910232646124, 0.15734380270753587, 0.22629505209624767, 0.1145758219063282, 0.1326028417263712, 0.08938217628747225, 0.1467607191630772, 0.13144367321261338, 0.12387715280056, 0.08827918368790831, 0.1780380622616836, 0.19160337506660394, 0.17642670444079808, 0.14150299557617732, 0.14275455341807433, 0.11967658677271434, 0.045911307845796855, 0.05789517265345369, 0.0771898723074368, 0.21769376578075544, 0.12655862819935593, 0.15387297395084584, 0.11478673773152487, 0.16515971188034329, 0.13306489693267004, 0.22474941717726843, 0.1397768703422376, 0.11209746596536466, 0.10667072609066963, 0.136594703953181, 0.11942327607955251, 0.11294470514569964, 0.08421477928225483, 0.1539303915841239, 0.11301358323544264, 0.09108872578612395, 0.21257008000143937, 0.11027872070137944, 0.12959971358733519, 0.13573980411248548, 0.09325906075537205, 0.10281726465161357, 0.06599466196660485, 0.08781718276441097, 0.08975855966231652, 0.09327637696904795, 0.14482275529631547, 0.08080840456698622, 0.14681141929967062, 0.041277592203446796, 0.11056880120720182, 0.1029475840872952, 0.06358240212180785, 0.10318923754883663, 0.14045532393668378, 0.07901999660368476, 0.13547335698136262, 0.1443555975066764, 0.11849090111042772, 0.13820967158036573, 0.1910251546651125, 0.07517413475683757, 0.07551687636545726, 0.11352960911712476, 0.15926609241536685, 0.3349147614623819, 0.12156542470412594, 0.08907533596668925, 0.1706176304391452, 0.051498874090611935, 0.17011764512530395, 0.0686330571770668, 0.1414587279515607, 0.09110568916159016, 0.13081594689616136, 0.06165569515100547, 0.11158359103969165, 0.3197695884321417, 0.1978351899555751, 0.09993414900132588, 0.0662435418260949, 0.15021375673157827, 0.11310162315411226, 0.18723445092993124, 0.10525458957999945, 0.1524263508617878, 0.10297298843839339, 0.15516512175755842, 0.1447325644216367, 0.10411738524479525, 0.14235602266022138, 0.15197219380310603, 0.0853265928370612, 0.16754282186073916, 0.18887303157576493, 0.12757278020892823, 0.15641343620206627, 0.16101914191884653, 0.060688735251980166, 0.11881012469530106, 0.10865147837570735, 0.17170015163719654, 0.13136492243834905, 0.10480734679315772, 0.17584286576935224, 0.1587373372167349, 0.16234072457466805, 0.22757095577461378, 0.16720264511448996, 0.09301382462893214, 0.11147905593471867, 0.0646762480693204, 0.13506920795355523, 0.14495562602366718, 0.07859182065086705, 0.07902589307299682, 0.08643566511039223, 0.14810322783887386, 0.09366449221436467, 0.11262656043150596, 0.145858674709286, 0.13734878706080572, 0.1479253295276846, 0.09852397681346961, 0.18882230429777078, 0.11640219390392303, 0.07004449822540794, 0.0790667205250689, 0.09882547706365585, 0.1733137893357447, 0.09895918917443071, 0.09637003525027207, 0.08117733762732574, 0.20328062347003392, 0.13288842354501995, 0.122405098219003, 0.1942616988505636, 0.14054068364202976, 0.13447699615997927, 0.16800354713840143, 0.11392657245908465, 0.10953696657504354, 0.11788733064063958, 0.12395219877362251, 0.09502562667642321, 0.1904061000261988, 0.14049997154091085, 0.11532036481159073, 0.1004270368388721, 0.14314556600792067, 0.10629909924630608], [0.07691814617386886, 0.013109794435357409, 0.007006254895324153, 0.011847201917719628, 0.0696616212704352, 0.058801627584866116, 0.0488291916304401, 0.021437754122806445, 0.030051542446017265, 0.03210961379642997, 0.0246907612641475, 0.04451699980667659, 0.036077425349503756, 0.04288804078740733, 0.069499661746834, 0.02590392589835184, 0.023346624104306102, 0.01606262701430491, 0.04880734280283962, 0.07311921180891139, 0.023870213955108608, 0.018619061979864324, 0.03219734158899103, 0.06651880312711, 0.053398870530405214, 0.017842344640355026, 0.05514089383983186, 0.042552193094577105, 0.027682844549417496, 0.02098701348794358, 0.03067147239510502, 0.013586727370108877, 0.03672671890152352, 0.04742066489000406, 0.025503088121435473, 0.06797191979629652, 0.0408384138053017, 0.01784103676410658, 0.013033459245759462, 0.0321665327064693, 0.03256827972031065, 0.03915184377027409, 0.01075209050239729, 0.04350196909425514, 0.0513014407562358, 0.005193864535872957, 0.031980668394161124, 0.042360588376011164, 0.03284582429166351, 0.016385017661377788, 0.02383926258023296, 0.009862595553775983, 0.05933423686240401, 0.015532334933855703, 0.04861611806388412, 0.044385747385344336, 0.017590214598125646, 0.053720943962356875, 0.029606654175690243, 0.04894989961758256, 0.034577055501618555, 0.06069196507866893, 0.05553946191711085, 0.039891657286456654, 0.025945343675890138, 0.029439276549965143, 0.02262034566540803, 0.06224987469613552, 0.01927715104206332, 0.04225750194330301, 0.010845224522719426, 0.04625815459127937, 0.1128828702494502, 0.040254246044371805, 0.03258149418979883, 0.016917728719168475, 0.023912624090111682, 0.014825781507949744, 0.020024913595989347, 0.03925338653581483, 0.01966047752648592, 0.03283216538173812, 0.015276852928634201, 0.008185089050259973, 0.0806424959695765, 0.03026604772146259, 0.005947125343871968, 0.02038949215784669, 0.05012592633387872, 0.05295681853645614, 0.04323162377945014, 0.021825638666216816, 0.03988123159589512, 0.045391390565782785, 0.03446779779291578, 0.046377091602023156, 0.06215969739215715, 0.03910611390269228, 0.04183014362518277, 0.0399415363956775, 0.009417153429239988, 0.014260042758126344, 0.0779643589630723, 0.006662910662791026, 0.030861122932817255, 0.028851804323494434, 0.031929503461079936, 0.04753375292888709, 0.03272402386314102, 0.006019587794850979, 0.01878862618468702, 0.014290870300361087, 0.07719897146203689, 0.07855330700320856, 0.007953487236851027, 0.04330892927412476, 0.02503725008240768, 0.00923216188259955, 0.03506958032292979, 0.01526373006137354, 0.024897680518084338, 0.0462402175180614, 0.045981597288378646, 0.049057552590966225, 0.02690698894938188, 0.07354029707078423, 0.06413198156016213, 0.05819935990231378, 0.022199399503214017, 0.07315794258777585, 0.011034881845781845, 0.03512336779385805, 0.023314975534698794, 0.026807749810229455, 0.04769791090594871, 0.014670753219564046, 0.008628439590600985, 0.013644975360615976, 0.027106675020019923, 0.018742492588769113, 0.049220869184604714, 0.0722694213369063, 0.01699507492594421, 0.06216484747294869, 0.027178053511306643, 0.04996854692165341, 0.042960827238857746, 0.0374821862205863, 0.020019487012177706, 0.038470910130334754, 0.005276719174746956, 0.026303559275610105, 0.051637905915932994, 0.019101753132417798, 0.05707898323557206, 0.04735753059919391, 0.019469390190871697, 0.06226261079843555, 0.03858269198930689, 0.013349139181497906, 0.057691666430660656, 0.04881703228290592, 0.06945718545466661, 0.07387018722615071, 0.054131820664874146, 0.015194539845521961, 0.05616201440404568, 0.039679455637399635, 0.048508095288915296, 0.06874444548572813, 0.007362456942376281, 0.06200137481625591, 0.044776804079966884, 0.009658225047002946, 0.024413689970970154, 0.08621525658028466, 0.05917455721646547, 0.028691534352089678, 0.03406341467052698, 0.05978821750198092, 0.033701070185218535, 0.03861328713329775, 0.01865849334613553, 0.061205493951482434, 0.004617352346290967, 0.045035963744989464, 0.02116202632896602, 0.024691419443115592, 0.02610993930803878, 0.017157343182978884, 0.030992609448730946, 0.030111806533698524, 0.03534613084048033, 0.03920281532087496, 0.005261467403865286, 0.050836790153490644, 0.024224202281662395, 0.02580788265913725, 0.05914852861315012, 0.05730275729937213, 0.04844122566282749, 0.02612470762271966, 0.009259379618535084, 0.0389158832175391, 0.01123353060601013, 0.04075288446620107, 0.01376457988018436, 0.004249783141338932, 0.04034721891262701, 0.03141000348010233, 0.010114932549186051, 0.03868451634688037, 0.010979562582048987, 0.025810474662908485, 0.068423810548016, 0.03607264846297247, 0.011202390937666808, 0.01692197465204767, 0.015899800662217394, 0.01310724568819361, 0.02428570299941514, 0.03232432941773108, 0.036508091525839906, 0.039626964168356996, 0.05084879004529544, 0.05435441068506666, 0.010554658016189933, 0.01766400188872857, 0.030240392312407494, 0.040414220853043456, 0.049464836450559754, 0.023414536977985075, 0.0784781388938427, 0.06348135468683072, 0.03744024936375873, 0.03757961027856384, 0.024102976911568215, 0.05130636013512101, 0.01108044377594654, 0.045137021357991865, 0.011850375765269356, 0.013010325442467417, 0.05384739574843219, 0.016486294101923704, 0.012636232123311077, 0.04137340474075504, 0.02986173584525074, 0.02234548978906657, 0.046482654687549384, 0.04027569792898638, 0.008662068634293973, 0.039495637108172686, 0.04314515806202378, 0.027921027304338555, 0.043315049659992964, 0.02359712396615318, 0.03225677786394954, 0.05508514540269971, 0.000906765043120166, 0.032341652416757176, 0.08854983773614679, 0.040195617226085494, 0.03857322642579675, 0.01461333897896111, 0.03437822099242892, 0.04051191971770354, 0.003445405321794429, 0.004500981046086443, 0.049476117095244784, 0.07261072445128645, 0.041433088680995364, 0.012605182360857725, 0.056114350711660724, 0.08447565564087459, 0.027986597535865645, 0.04237217436145459, 0.10293820673333746, 0.02883383332352553, 0.06787933369300195, 0.045091243992958746, 0.017735527961381843, 0.040829131446246586, 0.010557446795116578, 0.03597852208518556, 0.01876904536038637, 0.031180529722145627, 0.04284752206876874, 0.0815848046913743, 0.02323070996707039, 0.020645827420854142, 0.07875828564699207, 0.03279460846845593, 0.05115872787843857, 0.033194547186472585, 0.02417362597770989, 0.06604713986494712, 0.0201595061059509, 0.03558446287310549, 0.01032010287911232, 0.03519889213410871, 0.0221444347740284, 0.06316454668662377, 0.04074571913640414, 0.024717666873974458, 0.01698531928871359, 0.031006349782858576, 0.06817256938666105, 0.01316020025738648, 0.016183273933295692, 0.019936632797388092, 0.03025047534278461, 0.04218331092436399, 0.02144173881970346, 0.02666286053135991, 0.01980937016196549, 0.05940414632537535, 0.038877444208732674, 0.030647625281874622, 0.02437637054494449, 0.016072916997862712, 0.019184865190514495, 0.022546626228306974, 0.028145110101572106, 0.033459525289280076, 0.010964805293562157, 0.05956767326486962, 0.019854901558054344, 0.039389826357364655, 0.040581215106483014, 0.023002825677394867, 0.04731367009558848, 0.029399792597229992, 0.029164469867412533, 0.04460721782275608, 0.019553173998636857, 0.023442558777917708, 0.016485167733792747, 0.04181564672450934, 0.032437542985592566, 0.03277975533689771, 0.054636603221297264, 0.08088831563613244, 0.056328927233283005, 0.041108474135398865, 0.06269407086074352, 0.05532719919990216, 0.07340404045368944, 0.03780238689588649, 0.02075813344812819, 0.021093472239694426, 0.06310284071202789, 0.02813876240647265, 0.1266440964703049, 0.1026400380900928, 0.10883097124419042, 0.11829337956649916, 0.13084696951721395, 0.12609094115240232, 0.0742265877446958, 0.08070262774292912, 0.15890406684151717, 0.14312146444405827, 0.11339001410773822, 0.1202890867633479, 0.05098780490724104, 0.13519510334091528, 0.12061767413147859, 0.16084357776812144, 0.10842947528830596, 0.14071741487298692, 0.1440167778304645, 0.1647918237639325, 0.1599977702966758, 0.12890094465443067, 0.10245740360447339, 0.14590276591479778, 0.09467773498701197, 0.07118296463574682, 0.12199656585497515, 0.12342355214059353, 0.11839039650346551, 0.14853685242789133, 0.10778544377535582, 0.0849433426878282, 0.15551756641694478, 0.12238529856715884, 0.20165728272071906, 0.18303524197212287, 0.08863639166312558, 0.06786345597356558, 0.14550431658114704, 0.07835822818534714, 0.09609511321676628, 0.2740790487400123, 0.10182939230331353, 0.1418895705470017, 0.1022664774209261, 0.06993950171662228, 0.11891001862074647, 0.06944774703255721, 0.1877193727663585, 0.11772125240947519, 0.15026858236108506, 0.09612624440342188, 0.11317911185324192, 0.12497156193213803, 0.1792580953666142, 0.17272061402244226, 0.14941824227571487, 0.09046850406697818, 0.14403251984289714, 0.13953588184501442, 0.1433638371527195, 0.11428570747375488, 0.16026959142514638, 0.11229709775320121, 0.0598193011911852, 0.13888083770871162, 0.10473866547857012, 0.19615080819598266, 0.16975267470947333, 0.1467752940952778, 0.133969587673034, 0.15071744684662136, 0.1410624770713704, 0.09638104108827454, 0.10272987612656184, 0.12215094614241805, 0.10822185035794973, 0.16905766486057214, 0.1554292075868164, 0.14437119024140493, 0.08130380298410143, 0.1025576503681285, 0.21920689887234143, 0.12061367077486855, 0.23899178579449654, 0.18278493040374347, 0.15661984655473912, 0.1421230137348175, 0.18829312840742723, 0.14907862192818097, 0.0845819345808455, 0.1499780879489013, 0.244723235390016, 0.1810824724712542, 0.14576848383460725, 0.09744095349950449, 0.2428749059992177, 0.1702762051884617, 0.09831901174038649, 0.2614655984299523, 0.10780740116855927, 0.09627514891326427, 0.12988298838692053, 0.09990710938083273, 0.144091131697808, 0.1223903875797987, 0.12728466066930974, 0.15614701621234417, 0.14030586981347629, 0.15882953655506882, 0.07790831875588212, 0.1753680541047028, 0.1428079948361431, 0.14774521919233458, 0.10986294836870261, 0.07288411978100028, 0.19700189466987336, 0.16925106091158731, 0.1839904971420765, 0.09755966998636723, 0.0639313862525991, 0.11010951442377907, 0.09688249882310629, 0.1994118746370077, 0.11430975475481578, 0.22355382490370954, 0.11839007080665656, 0.1105995320581964, 0.14957600166755064, 0.16299696293260368, 0.07552879822573491, 0.10017521892275129, 0.09051537726606641, 0.11367424564169985, 0.15678642690181732, 0.14058079863233225, 0.12144594825804234, 0.1280154971671956, 0.07632904885602848, 0.09141924697905779, 0.16711892746388912, 0.2701751653637205, 0.10041177658630268, 0.21425404106932028, 0.1209826445473092, 0.12189794757536479, 0.10072361092482295, 0.15740421946559632, 0.0912687818386725, 0.11503429444772856, 0.11346080566623382, 0.13977886523519242, 0.12113007663616113, 0.08511978214872734, 0.14409742850278104, 0.14235978174422467, 0.09032670381878104, 0.10430751754237072, 0.1326111334242991, 0.08233806677162647, 0.09491385160280125, 0.1269021433378969, 0.1739572033818279, 0.09810298654649939, 0.1211935468018055, 0.16155089624226093, 0.13075945207050868, 0.12111831083893776, 0.14547948219946452, 0.09976628622306244, 0.12858558871916362, 0.17460520432463714, 0.15508210978337697, 0.08053659022386585, 0.11388921232095786, 0.1621852722018957], [0.04000465033043708, 0.049793189724109004, 0.029741054999509027, 0.07405612617731094, 0.04005657183006406, 0.072359829342791, 0.050730233014162095, 0.0446881399090801, 0.052946318207042556, 0.08619143321577992, 0.025871417285608392, 0.06794450019619294, 0.030168586344059025, 0.020702607231214643, 0.04159292099731309, 0.026429176463612487, 0.03008195777822818, 0.049333753662982156, 0.0389779352449945, 0.04418558973286833, 0.025456857834277407, 0.046572828598852666, 0.006208839269155371, 0.009952197799326053, 0.008472296808447157, 0.023773970548063517, 0.02915940121082323, 0.04012422855677349, 0.02596811531111598, 0.05512570822611451, 0.012175788437681538, 0.00420757953543216, 0.042785381831760914, 0.01035589475317725, 0.01900231552177242, 0.05133115719737751, 0.08143606981528656, 0.04484504434679236, 0.04128427577338048, 0.02707194081241531, 0.024325471936858127, 0.012984116179203349, 0.017337792785838246, 0.026979388635871664, 0.011723487172275782, 0.023442117730155587, 0.014625832504991974, 0.01983464728774769, 0.022355265782347748, 0.027860883656623106, 0.061838105720068724, 0.02646496070415846, 0.03385224439469831, 0.01174331481368946, 0.06693958304822445, 0.0227237052084612, 0.05595184836004462, 0.027436410808669667, 0.018347880370648842, 0.017696342564054897, 0.006904027657583356, 0.03368951812652605, 0.013056527740055961, 0.022863885454301323, 0.012648162465276462, 0.04153430574972715, 0.018920477413173233, 0.03577859852729099, 0.07672019715287856, 0.01990137272514403, 0.10656311722206217, 0.01709861258443977, 0.016048759454861283, 0.034131441198821576, 0.04859666446489947, 0.03671205575977053, 0.07394565389092479, 0.05991880835166999, 0.014132618122468037, 0.026300914685374925, 0.06940968800336123, 0.02652698559021311, 0.013095708048370267, 0.034347049093672206, 0.02352271581600819, 0.02597119755643819, 0.015446481594283665, 0.0588321073779038, 0.09645573422312737, 0.01775117837158697, 0.06315592929188694, 0.052096208823578696, 0.020262616287384714, 0.013741435050698263, 0.01998369598628155, 0.01789897686934897, 0.06533796899020672, 0.005978681887167373, 0.030072264905486788, 0.029919312934258153, 0.03147138036521418, 0.019232461029397588, 0.054937350297612805, 0.05560012294777802, 0.02538947421791298, 0.1247891445777246, 0.04724987084046006, 0.02696287478985531, 0.09574581695986645, 0.05493651909221496, 0.030690698684858422, 0.01677711760359151, 0.03297867127028959, 0.017734723897384744, 0.02238309589613761, 0.02602448800046529, 0.06590852194598742, 0.04920517127694828, 0.04021079605445266, 0.03479200861017619, 0.018986485299787352, 0.006484729911400271, 0.020452509401366115, 0.0033788872616631643, 0.020144125413415686, 0.025936456563483392, 0.06252808083913156, 0.05519028779651437, 0.11860277796430246, 0.020289304766005704, 0.04441800494013088, 0.04180569940113595, 0.039430887904018164, 0.0051603130996227264, 0.03731302065508706, 0.034063699655234814, 0.04647471243515611, 0.027141139509954622, 0.07108154400650944, 0.023683102834703665, 0.07864450889506511, 0.0680969398734825, 0.030256538053176234, 0.034793691377022436, 0.006327904777468315, 0.09003678616136312, 0.018289721437862942, 0.010295811325444706, 0.010482313460670412, 0.03299116988533309, 0.05496986908838153, 0.087174067273736, 0.012921027689506965, 0.014557473494538238, 0.024708693248352835, 0.012708069473904158, 0.010238255440656627, 0.028691259545407126, 0.031716725057257075, 0.032118970794337134, 0.015168029482343366, 0.02842065808363259, 0.006203982230675007, 0.007688446369554315, 0.039572467628334246, 0.017696166144950048, 0.011348246280769152, 0.05779001329626356, 0.05454492974760277, 0.008814319169947078, 0.020845769638461725, 0.04134047204362495, 0.08093735336193017, 0.04886141525847571, 0.016288110986351967, 0.001701102770831702, 0.02385187315355454, 0.022118146631068418, 0.019115978619083762, 0.028502189155135835, 0.024790007188650112, 0.035941284083362134, 0.007961887500381895, 0.03874008836490767, 0.02699135460092553, 0.05898598554943289, 0.06625431017684084, 0.045584410029862604, 0.01952434134935694, 0.06250032875686884, 0.05964295672518866, 0.05664888024330139, 0.010000756309766854, 0.012669392129672425, 0.04862253021981035, 0.014229376367958528, 0.05823251312332494, 0.09630273814712252, 0.025795589300936887, 0.036975086467074494, 0.035151343792676926, 0.03156880781586681, 0.027468988971252526, 0.020458434708416462, 0.03802522797403591, 0.01372679480950215, 0.07900352177343198, 0.017329433234408498, 0.06143968352781875, 0.02277507370204798, 0.016664755597178425, 0.027539329303960716, 0.08559202895100627, 0.008286265406890638, 0.047860006136553626, 0.018895795701869895, 0.023586793270494257, 0.002169148593176422, 0.014420156666476811, 0.04443811671808362, 0.031044503806957176, 0.031432965105133395, 0.034235959340419085, 0.05439899382846696, 0.026310858616073216, 0.0071382901764341766, 0.04524001618847251, 0.028678000971142734, 0.01135389762930572, 0.06334176646279437, 0.006089209304523787, 0.1108856431341597, 0.029261008437190737, 0.029769512758191143, 0.014318369628329362, 0.06264213579041616, 0.019831008643710187, 0.013863670589801456, 0.054109876842371056, 0.06273702891277415, 0.04125671028824789, 0.02581046278854566, 0.03073704262663211, 0.07546526699193887, 0.0417691263636308, 0.03138379167233195, 0.07561712312911238, 0.03372313275134989, 0.03181878350941198, 0.018582176816250597, 0.056365876857723506, 0.01784031412431172, 0.10369203199765512, 0.02813489136419126, 0.08289137136723314, 0.014509360272703426, 0.037557791985039196, 0.0819925092426794, 0.03051004891416856, 0.024726033210754395, 0.012195052046860968, 0.04708159415583525, 0.07572781933205468, 0.056321951893291304, 0.06695752351411752, 0.05212509405932256, 0.039626814890652895, 0.03463789973674076, 0.05936029939247029, 0.00612925092822739, 0.027200619889689342, 0.0033211935494494227, 0.04496108740568161, 0.016222535665812235, 0.04159336204507521, 0.030181512436164275, 0.06106313730456999, 0.038383565710059235, 0.04842153118391122, 0.010157105196932597, 0.04220189939119986, 0.04121294477954507, 0.02080122720716255, 0.020470254788441316, 0.0999855005315372, 0.021000017611575977, 0.03805718358073916, 0.06877910505448069, 0.008990753541833587, 0.08126850559243134, 0.037756338116845915, 0.059197980245309215, 0.06185946600245578, 0.027106710643108402, 0.05042647324236376, 0.028519936238548586, 0.020787729449304085, 0.025983568946165696, 0.04767228603096945, 0.056294620502740145, 0.03485740242259843, 0.04400918759139521, 0.03617081890947052, 0.012168416154703923, 0.04432564953874264, 0.016340383627851094, 0.036495877895504236, 0.01779446212042655, 0.05967700561242444, 0.05411406001076102, 0.024636195174285343, 0.07236930847700153, 0.04435284522229007, 0.03671466472691723, 0.034907953281487734, 0.032932792125003676, 0.0422544926404953, 0.09080861295972552, 0.03818680412535157, 0.03285507611664278, 0.023783816091184105, 0.03931044115285788, 0.013866606101925884, 0.027374185754784515, 0.03693158558702894, 0.03801155210073505, 0.03280403671254005, 0.07295475527644157, 0.09930826830012457, 0.01495915265487773, 0.03584664201896105, 0.022461597308782593, 0.06038488048527922, 0.018962144552330886, 0.05128440274191754, 0.05162288315062012, 0.041573559000555954, 0.055247386518333635, 0.028427818324416876, 0.01861205610579678, 0.04596971274752702, 0.04147883890462773, 0.03543616225942969, 0.04589026647486857, 0.04581628240911024, 0.0417797691853983, 0.061124605791909356, 0.02690721965128822, 0.01964175165630877, 0.057124879344233444, 0.04239763638802937, 0.014424160023086836, 0.13536475066627773, 0.12379023246467113, 0.22002646060926573, 0.12682021701974527, 0.1080603658088616, 0.14558494011206286, 0.15700875568602765, 0.14376247647617543, 0.12079687522990362, 0.2339856901339122, 0.1707574493650879, 0.21027669949190958, 0.15438389724918775, 0.15430461721760885, 0.1454679335334471, 0.17323425146085875, 0.09590564588350908, 0.1792875166450228, 0.13776889523225172, 0.0649980500872646, 0.14592187346092292, 0.19688756151923112, 0.05164142751267978, 0.11593156201498848, 0.12216822164399282, 0.09435409413916723, 0.10188989048557621, 0.13386417047253676, 0.0978332349498357, 0.1395368996475424, 0.18813482618757657, 0.11468404824180262, 0.13438718526491097, 0.09461532333599669, 0.07726456544228963, 0.12552117529724324, 0.1439902606819357, 0.10806094256362744, 0.13752535544335842, 0.11014257943523781, 0.10924761888704129, 0.12734454817005567, 0.14639070044670785, 0.13744317128189973, 0.12250941619277, 0.09811453521251678, 0.08124718602214541, 0.14170685463718005, 0.11848284011440617, 0.08125252609274217, 0.17164677807262965, 0.09085703321865626, 0.19717722811869212, 0.08727711638701813, 0.1525662647826331, 0.179933224139469, 0.22150589765182563, 0.11727123441440718, 0.06515544307019029, 0.0896449593294944, 0.08103936431663376, 0.09649789160383598, 0.08811475429683924, 0.12284170836210251, 0.08913298430187361, 0.12075657024979591, 0.12941333358841284, 0.17005850401307854, 0.19639509437339647, 0.0901221458667091, 0.16039366833865643, 0.10015762450971774, 0.059665280527302196, 0.13509793712624482, 0.13142946468932287, 0.10374956498188631, 0.16567442140408925, 0.1248879392764398, 0.25111006838934763, 0.13801421278289386, 0.20677397958934307, 0.1802898214331695, 0.052652461653841395, 0.15482943691313267, 0.1739048340490886, 0.11141793350023882, 0.16935092769563198, 0.09217521641403437, 0.15982722730508872, 0.10670546708362443, 0.11222844358001437, 0.2180623324321849, 0.11226558658693518, 0.05859092210552522, 0.1214253343641758, 0.16932901101452963, 0.182475816990648, 0.08296869043260813, 0.11686257991407599, 0.10985338781028986, 0.1508191999580179, 0.12260567317051546, 0.15080489643982478, 0.12823500324572834, 0.1122923819348216, 0.23883330715554102, 0.10639650294823305, 0.19635116601628916, 0.18855703781758035, 0.10781694137092147, 0.1155108567327261, 0.22889757316027368, 0.05699012228952987, 0.09796466718294791, 0.08277289236762694, 0.10040048576359238, 0.1747280191630125, 0.1771097585026707, 0.12831758095749787, 0.14518258241670473, 0.11776777277035372, 0.06437681735094104, 0.11593912089509623, 0.11184484737792186, 0.18202259631029197, 0.18825359695724078, 0.17072265408933163, 0.07791768253913947, 0.15596282109618187, 0.12579376995563507, 0.186404304046716, 0.09756402618118695, 0.10752517809825284, 0.09088369964488915, 0.09000000277800219, 0.12576713067080292, 0.13744942737477167, 0.09964485559612513, 0.2847813373165471, 0.22474469457353863, 0.198480558182512, 0.1808190108942134, 0.09400819055736065, 0.13166293501853943, 0.18474862431841238, 0.1581971012055874, 0.09714335482567549, 0.13533328021211283, 0.10072411982608692, 0.09828021989337035, 0.13600412064364978, 0.17457271606794425, 0.16305588691362313, 0.060387275713895044, 0.09005812608769961, 0.08723527113241808, 0.16621080333633081, 0.07467809173145465, 0.11329320073127747, 0.15206665944840225, 0.09014229157141276, 0.1391515324690512, 0.12114371519003596, 0.09551017531859023, 0.14672580175101757, 0.09252542190785919, 0.1010993496913995, 0.11718591542116233, 0.09384348975228411, 0.08775514430765595, 0.14949121193162032, 0.16306212943579468, 0.24544172255056246, 0.10076100498970066, 0.09943267091044358, 0.0856288123343672], [0.03519875303442989, 0.06757538393139839, 0.054278394406927485, 0.051977560190217834, 0.0026205075430750313, 0.05762653385422059, 0.02004088631032833, 0.015807328213538443, 0.05437775568238326, 0.02785389474593103, 0.04378924385777541, 0.028657794198287383, 0.004032709610848022, 0.10247510658310992, 0.06816970596888236, 0.0548932251653501, 0.03678497452554958, 0.08684781406606946, 0.023181322795738066, 0.0462720442031111, 0.022220154193096926, 0.057304921826081615, 0.025112521668363894, 0.06651226883488041, 0.035103079596800466, 0.032577141387654204, 0.03767227780606065, 0.06333998870104551, 0.012950942602141627, 0.017321984616241286, 0.03975355166143604, 0.02603258122690022, 0.045655086237405024, 0.037766217586717436, 0.03789740554722292, 0.05382554013548153, 0.02685998343596501, 0.04251711961946317, 0.02271583759491997, 0.04468538166422929, 0.028595324871795516, 0.005201810180941331, 0.03260462544858456, 0.02363374619744718, 0.008856739482975431, 0.033211178079779656, 0.03796300970550094, 0.048451892233320644, 0.03638563631102443, 0.03383084000753505, 0.02844533640226083, 0.011025059203218137, 0.0059040214068123275, 0.018355020255382572, 0.015493018918537667, 0.07417380450559513, 0.005119151469053966, 0.01867504620791546, 0.02516422942946, 0.007669205660931766, 0.026421653206593225, 0.040064666752836535, 0.009702647038336312, 0.05313133095790233, 0.044185722047196965, 0.006085280162681426, 0.02814840608542519, 0.013328796701638826, 0.07193147018551826, 0.03088046457352383, 0.01841902137467904, 0.030381778654243265, 0.046589927681322606, 0.02740634831466845, 0.015341357860182012, 0.02907676243090204, 0.020554488125656332, 0.0527542724407145, 0.044873695487954786, 0.05706543967659984, 0.05391039093956351, 0.019838591272543584, 0.03929817663239581, 0.06605083788079874, 0.05845011930380549, 0.049390638646270545, 0.00402648574838947, 0.02962723414280585, 0.04154637349503381, 0.042760259072695456, 0.08116148026393992, 0.05492398655042052, 0.051239364980054755, 0.012973370729014277, 0.03809296612494758, 0.025473677021052157, 0.07368171055402074, 0.0031609721357069376, 0.05861551221460104, 0.04853602718295796, 0.03276046797899263, 0.03708707867190242, 0.03882217753146376, 0.02439948484035475, 0.043489948846399784, 0.030651245266199112, 0.05077050746019397, 0.05787495230989797, 0.05348204196031604, 0.04207482335290738, 0.046174528542906046, 0.09606335777789354, 0.061493437071996074, 0.027290045716134564, 0.011423244756380362, 0.028843614405819347, 0.037955664563924074, 0.06962872589273111, 0.04620005163763251, 0.08720119510378156, 0.04411273542791605, 0.04734717615480934, 0.058363721439880986, 0.04921050116951976, 0.035341204676244936, 0.02931751004819359, 0.09392279692526374, 0.04344579318006124, 0.06807016488164663, 0.0661488047667912, 0.04864692355373076, 0.05506985800872956, 0.027984987711533904, 0.013092166943741696, 0.032404488152159114, 0.028295368288776705, 0.04794685183359044, 0.08431421180388757, 0.02943290171346494, 0.05370201622801168, 0.005619710144985999, 0.06255366160933461, 0.02623142421777759, 0.02804205589927733, 0.03187271686536925, 0.1058038297508444, 0.018774244634966766, 0.04469038246731673, 0.020637367785509144, 0.024465233187324235, 0.019117220338167887, 0.041230932742889435, 0.07022131766591753, 0.05557697472561683, 0.04434179188683629, 0.016786732444805757, 0.027103633486798832, 0.059886170817273, 0.014907438108431441, 0.015008541522547603, 0.0218812463073326, 0.05746848947767701, 0.03535916889086366, 0.068281942446317, 0.023652421177497933, 0.02653413395663457, 0.025706161778154116, 0.028494436892547777, 0.008903572818131318, 0.04244057747668453, 0.06841576990804502, 0.034993506369314024, 0.022849534438656907, 0.017423932806455662, 0.022627371895526136, 0.05748678956712995, 0.03574821033648082, 0.04739602389080184, 0.03189624845981598, 0.022143698563533168, 0.012733696893389736, 0.047636374565107484, 0.03246148848640067, 0.06849161655242954, 0.017041992229808654, 0.024619969705651914, 0.01813520713975387, 0.03503715652706368, 0.05550196607198034, 0.053614458069205284, 0.053280045477939506, 0.05365088182900633, 0.02837909951007792, 0.028996288177690337, 0.03223172974373613, 0.07504900611404862, 0.01282416342291981, 0.03096314745822123, 0.005355318550885255, 0.014655082453308361, 0.02785468863190285, 0.01696597595166947, 0.06194570780332599, 0.06027740053832531, 0.02954825266663517, 0.016690463592697467, 0.0240958302414843, 0.037318391259759665, 0.11191105203969137, 0.04012841511783855, 0.05457791333485927, 0.07475636753120593, 0.04387114642720137, 0.0036177485516028745, 0.007278038704368685, 0.019447141027610217, 0.027616522840357254, 0.0436523969152144, 0.02197732516963567, 0.02249705245984452, 0.03570083841415388, 0.04104195395484567, 0.06889375711658172, 0.02000223865200366, 0.010932865802065601, 0.029096429768417562, 0.032326456625014544, 0.015418246055820158, 0.027370329979541044, 0.038253341269280226, 0.025635863853884593, 0.026737801331494535, 0.037610436124461036, 0.07592798037720577, 0.0841402964932578, 0.035775073537869115, 0.046187485169087134, 0.04272979285035815, 0.0626551229506731, 0.056562733437333784, 0.020571300527080894, 0.04662226666031139, 0.08092138743294136, 0.03216347251353519, 0.04789060467321958, 0.019914672011509538, 0.03406608470582536, 0.024247377645224333, 0.05247632074835045, 0.0576455599761435, 0.08013319436992918, 0.07351576802986008, 0.01650552887336484, 0.031633285606013875, 0.02695540920831263, 0.06933438418699162, 0.06372012437454291, 0.04301450614418302, 0.023097143741324544, 0.027370270607726913, 0.04046137225148933, 0.024978583944695334, 0.023663952880139862, 0.03899107507563063, 0.005016682503212775, 0.02297360965582941, 0.05504628230950662, 0.054069314018956253, 0.08004479482769966, 0.009479436158601726, 0.06660796941391059, 0.029504449838506322, 0.04422434086778334, 0.03900358386869941, 0.04724118559222136, 0.042923636734485626, 0.040049942542931864, 0.016334731431145753, 0.03549517445000155, 0.03827083050938589, 0.02238517051695713, 0.04787988381992493, 0.02631260754008378, 0.025361639015110474, 0.020472990980904018, 0.019374888922486986, 0.04267999855801463, 0.06550190983606236, 0.048520417484853945, 0.02447936198275004, 0.023512252806020633, 0.03447638126090169, 0.011584948981180787, 0.03855579146849258, 0.08083619736135006, 0.017687625085402812, 0.01925540908372828, 0.065646675282291, 0.07255453496639218, 0.006668175670451352, 0.035062815328793864, 0.03266172417040382, 0.029349672608077526, 0.07004498677062136, 0.024589690080444728, 0.06651409409408059, 0.02726891274297876, 0.06693472473749093, 0.03757245512679219, 0.016069551464170218, 0.026001538249797056, 0.012432550329581966, 0.02553742708239172, 0.06721418617027146, 0.040117473740662844, 0.052549884122397215, 0.06191642901727131, 0.0348734837025404, 0.038899723906069994, 0.028575470937149863, 0.016265829592677097, 0.07298279912876231, 0.026758634052904587, 0.061646467074751854, 0.011857625063774841, 0.025055646863100783, 0.0217821971579854, 0.050913383186395676, 0.042551243145551, 0.08012031577527523, 0.03945535248411553, 0.02116080157325736, 0.06422342093927519, 0.010596694108763976, 0.03812263167596289, 0.024641560689945306, 0.02363487086924059, 0.10922338840152536, 0.0059028933423438245, 0.028329184777768593, 0.015863381991428987, 0.040461606346070766, 0.06282453957412924, 0.062024777489049096, 0.0169499455618539, 0.060555498115718365, 0.07011957812522139, 0.050520820144031725, 0.007609760904285524, 0.014576994947024753, 0.04904515575617552, 0.06289493758231401, 0.07315968642277376, 0.14649672832872185, 0.08600199980927364, 0.09289949826364007, 0.06508243948753391, 0.11814581177064351, 0.15196118796510355, 0.13545971842748777, 0.11732368517134871, 0.12124641825045858, 0.07974908248122249, 0.12561591235654695, 0.1761327495000192, 0.19000950987849916, 0.1342915796807834, 0.24686447477766446, 0.141342413478664, 0.1398684997111559, 0.05788669775107077, 0.22194653829293592, 0.08908373623022012, 0.1361765092504876, 0.07854531386068889, 0.16075292548963002, 0.07737957034260035, 0.09365019548152174, 0.10839054773428611, 0.24754268409950392, 0.08793538356465952, 0.10582636389881372, 0.1197205829833235, 0.11082520602004868, 0.18781854744468415, 0.13636117934116296, 0.10662904368447405, 0.11273401323705912, 0.1270527916827372, 0.16364507244101592, 0.14281228317746095, 0.1125455094235284, 0.07085202275110142, 0.15621587394603662, 0.12206824629434518, 0.06406501693917172, 0.12687406555882522, 0.09907304735055991, 0.21183951491756098, 0.14425146952271461, 0.08248021985803332, 0.12893458642065525, 0.08052161495600428, 0.13671130341078552, 0.1046778823115996, 0.11101683109466519, 0.1276380145656211, 0.10087059518056256, 0.09865718002298049, 0.14716558743800434, 0.11772951696600233, 0.09102191722818784, 0.11725760943123273, 0.08362669298159224, 0.0913022200443915, 0.14946493905569824, 0.08533082689557757, 0.12463209086230823, 0.2112944070249796, 0.09326752887240478, 0.17111769717718872, 0.06758103612810373, 0.06197829784027167, 0.11656011614416327, 0.11233236800347056, 0.1738707444497517, 0.12822458094784192, 0.11690023860761098, 0.1021783153659531, 0.11006243766418525, 0.10137748119554349, 0.2328703956944602, 0.21680139723633016, 0.10568566966269698, 0.09612460234867674, 0.15142294684691088, 0.23298210969993047, 0.09900026768445969, 0.10172838558043752, 0.07991718953209263, 0.07525619678199291, 0.10119462279336792, 0.1791469920426607, 0.19548345543444157, 0.1425916100186961, 0.0772544349144612, 0.20739148716841424, 0.18376516923308372, 0.1548820233770779, 0.07157029956579208, 0.17994887115699904, 0.12758502098066465, 0.2066613563469478, 0.058985334155814986, 0.16299522588295595, 0.1734263447246381, 0.09942538344434329, 0.2231525257229805, 0.09055222171757903, 0.11389526485332421, 0.13110893831721374, 0.09152779901134116, 0.20389049074479512, 0.2379517001765115, 0.15710837819746562, 0.08944477114294257, 0.08867808764002152, 0.12867489749831812, 0.11513125710189342, 0.19014042642499718, 0.18357212602027825, 0.16293331634785446, 0.12748951039143971, 0.22051375731825829, 0.144980433263949, 0.06260971538722515, 0.08202450216880866, 0.1282872368714639, 0.23596953653863498, 0.12412261962890625, 0.11799035939787116, 0.11219010635146073, 0.16823677319501126, 0.1289065900657858, 0.08025255546505962, 0.0983723174514515, 0.09540990819888455, 0.09428566388253655, 0.15485203212925366, 0.17179089891059057, 0.09128782831664596, 0.16969541992459977, 0.06478777208498546, 0.13645094952413014, 0.09836606814392976, 0.08904776030353137, 0.15777034339095863, 0.2356974168547562, 0.12825098953076772, 0.17088092916778155, 0.15345347646091664, 0.11734291485377721, 0.12184750528207847, 0.10559777902173144, 0.1702071846063648, 0.1948177854397467, 0.09129506828529493, 0.08607280493846961, 0.11020575783082417, 0.12970135813312872, 0.09877618827990123, 0.10751244878130299, 0.10720368820641722, 0.20751347419406685, 0.10770273714193276, 0.1500595664339406, 0.12624490074813366, 0.09265805514795439, 0.16550607686596258, 0.17088329046964645, 0.10148205701261759, 0.15879839179771288, 0.09807193678404603, 0.18978647541786942, 0.07474090371813093, 0.07407871460808174, 0.0994846670489226, 0.15852822629468782], [0.01729599163601441, 0.04278872700940285, 0.03844820974128587, 0.02901090042931693, 0.054693759618593116, 0.052930118183472326, 0.017142218637413213, 0.032238267428640804, 0.05963372864893504, 0.09634676828448262, 0.09446512960961886, 0.016949721645297747, 0.07778679313404219, 0.057739876343735626, 0.04304254999650376, 0.028474057093262672, 0.028599925339221954, 0.008275076364433127, 0.014868768397718668, 0.04734684027997511, 0.03131561925900834, 0.018718781182542443, 0.052604065143636296, 0.01758516799392445, 0.0239221032243222, 0.021158038239393915, 0.0848592518429671, 0.02302916471048125, 0.03319646065522518, 0.04870292304881981, 0.0237936327965664, 0.0036958148536671486, 0.015000456777800406, 0.02848826561655317, 0.03226651484146714, 0.023358328833377788, 0.023741634961749827, 0.04632634396797844, 0.0390742770396173, 0.04629445282210197, 0.06330813148191997, 0.018604085015665208, 0.03501241035493357, 0.02858277197395052, 0.019268323301470706, 0.03922873196591224, 0.0396397138413574, 0.042393999440329413, 0.039328948195491514, 0.07696605753153563, 0.013104976836725004, 0.021441467405696, 0.05979115555861166, 0.030324883492929593, 0.018913066114432046, 0.06205297740442412, 0.02688654638560755, 0.03071342282263296, 0.04283575287887028, 0.0793283704136099, 0.02749680381800447, 0.04725391151649611, 0.008885248131783945, 0.04593962989747524, 0.06760573480278254, 0.024994444700756242, 0.030997121706604958, 0.027655343525111675, 0.0655423030257225, 0.023304656713402698, 0.045788998516010385, 0.05821294417338712, 0.06937322353145906, 0.02123991197108158, 0.038913776366306205, 0.04873414244502783, 0.02500137932864683, 0.011157342149609966, 0.0031814721629156596, 0.010192869929596782, 0.028483509086072445, 0.04860268646318998, 0.05935392116329499, 0.013490296517764884, 0.012075792731983321, 0.013943462915319418, 0.05261275039187499, 0.06915972248784133, 0.00960874542527433, 0.036312632728368044, 0.05308618123776146, 0.035039975840066157, 0.028388797471831952, 0.033452580483364205, 0.012220381759107113, 0.007146327423730067, 0.01535385986790061, 0.07814332257424082, 0.03398278435426099, 0.02429837633722595, 0.02575591535839651, 0.06019115873745509, 0.056055202814085145, 0.044258009775408676, 0.0833183191716671, 0.037466498490955145, 0.014205768438322204, 0.010613252059556544, 0.03648522150303636, 0.021051606629043818, 0.04082291267280068, 0.0303628339565226, 0.04953964154369064, 0.023492254682683518, 0.054855837885822566, 0.05040851920577032, 0.0264884600681918, 0.022922329371795058, 0.042457703700555224, 0.04963347275874444, 0.020326077971341353, 0.0781963975833995, 0.06982081915651049, 0.036402918597949405, 0.04299012977363808, 0.01777683717331716, 0.012438102442372059, 0.007398980786092579, 0.0112919321150652, 0.05640979164413043, 0.048202954698354006, 0.022641232669619576, 0.027508684966181005, 0.035176425839641264, 0.09545518684067897, 0.05357933370396495, 0.032684597585882456, 0.037508438740457804, 0.020677884807810187, 0.01365343838863607, 0.016998375998809934, 0.0317230354329305, 0.040483824975256405, 0.037056089977600744, 0.02812415354752115, 0.011168208039764847, 0.03879048316074269, 0.023971183358558586, 0.08237864316574164, 0.06994009204208851, 0.02535559835710696, 0.08280396927148104, 0.05966060542102371, 0.03882036923563906, 0.03921097470447421, 0.02026010231514062, 0.08250318826841456, 0.027470169622184973, 0.05382878014019557, 0.07094591842698199, 0.04725089542833822, 0.026649898816166178, 0.049488106809024296, 0.012169585779442318, 0.023977503912257295, 0.0412667967113001, 0.034551858103701046, 0.056554954033344984, 0.04090841826317566, 0.007432163693010807, 0.05163569728444729, 0.049438661962215386, 0.052552486304193735, 0.028670119786901132, 0.029992482757994106, 0.037750126128750186, 0.04015939702679004, 0.07749703153967857, 0.021096522254603248, 0.03418235507394586, 0.03833757460649524, 0.03686376940459013, 0.04753320331552199, 0.06714061261819941, 0.06030245205121381, 0.060769046656787395, 0.017347071752218262, 0.05640558472701481, 0.06675835991544382, 0.023458314361050725, 0.05209798997800265, 0.04687809132571731, 0.02199242596647569, 0.023932669710900103, 0.02631267878626074, 0.014704350881012422, 0.024334052012168934, 0.009183156387215214, 0.035248472687921355, 0.018379749464137212, 0.027686440785016333, 0.030915799284619943, 0.017666487023234367, 0.021288686764559576, 0.03045202399204884, 0.06148536929062434, 0.011917165663492466, 0.036276175041816065, 0.05267257682446923, 0.06247014751923936, 0.04846768852855478, 0.028094223367848566, 0.07831064930983953, 0.03645356784441641, 0.022581000812351704, 0.0203073554938393, 0.029791127491210188, 0.03496038028970361, 0.016144163174820796, 0.03612666663580707, 0.03338610780026231, 0.011497733482558812, 0.042683163923876624, 0.008915604092180729, 0.031639480630734136, 0.052062197255768945, 0.033134571476174254, 0.023352442542091012, 0.027732974716595242, 0.015539066001240696, 0.05821647934083428, 0.05823653683598552, 0.02564121240616909, 0.016124585743195245, 0.07500268252832548, 0.04974706291354128, 0.021523005262549435, 0.05087808579472559, 0.01667894546075591, 0.04504128685221076, 0.04377831944397517, 0.06655738462827035, 0.07844213582575321, 0.03091192145698837, 0.06141957853521619, 0.04339636868930288, 0.03174120320805481, 0.01724089459250016, 0.05873981983001743, 0.03610066517389246, 0.020091917232743332, 0.06464992091059685, 0.06495345676583902, 0.002571641147369519, 0.020285242037581544, 0.03879607089662126, 0.04256380282874618, 0.01475763284335179, 0.03718888945877552, 0.022081290305192982, 0.008602112431877425, 0.018470695209024206, 0.04054083888019834, 0.056413153785147836, 0.00966373729586069, 0.05851812208337443, 0.026699883098314916, 0.0645875364009823, 0.061621605551668575, 0.02514953405729362, 0.025073916418477893, 0.06600355077534914, 0.024725403869524598, 0.014260716204132353, 0.029358479992619584, 0.03221938040639673, 0.022034505315657173, 0.013471111788281372, 0.014735436266554254, 0.02370594741244401, 0.11068782303482294, 0.0024164061178453267, 0.05812616632985217, 0.00946091893794281, 0.044800566376319954, 0.02507376714077379, 0.011059759484071816, 0.03935247639726315, 0.03669299910377179, 0.00684549383419965, 0.05404171460707273, 0.0671931312286428, 0.04877009801566601, 0.056954906322062016, 0.03441822402445333, 0.021969138644635677, 0.0349717287878905, 0.011548368310156678, 0.0995491753731455, 0.020059730924133743, 0.06981119074459587, 0.02518076023885182, 0.038466587862265963, 0.021249684571687664, 0.05221581419131585, 0.02492153611300247, 0.05371258780360222, 0.004039670107886195, 0.062453496269881725, 0.05572419986128807, 0.13602940285844461, 0.03694760919149433, 0.04305485522906695, 0.014931500656530261, 0.02339399602663304, 0.028034994046070745, 0.027130067514787828, 0.04075483864705477, 0.017805126994582157, 0.11350992481623377, 0.048476214321064096, 0.009260944489921843, 0.07058494458241121, 0.01846143150968211, 0.05202063359320164, 0.02959971615512456, 0.030225661317152635, 0.04207193957907813, 0.034256291642252884, 0.017620972590520978, 0.026186810540301458, 0.049011564880077324, 0.030667143341686045, 0.03914997101362262, 0.006949321566415685, 0.06234167369880846, 0.04651123118985977, 0.03955385880544782, 0.03675184166058898, 0.014800104046506541, 0.016762873457212533, 0.02739742897184832, 0.02608019233282123, 0.03613252239301801, 0.025289773674947873, 0.03686328764472689, 0.05504226877487131, 0.015214853487642748, 0.05824997861470495, 0.04293806238898209, 0.025572741437437277, 0.027156528684177568, 0.07338957408709185, 0.11187565965311867, 0.13047697794224533, 0.13308880850672722, 0.16226717137864657, 0.16374781621353968, 0.1220809348991939, 0.13894542067178658, 0.18747953777866705, 0.15164864116481372, 0.17778334021568298, 0.12356371033404555, 0.23344250928078378, 0.13845801539719105, 0.10975172290844576, 0.1717926495309387, 0.08466299915952341, 0.11045397951134614, 0.12024172501904623, 0.09283509850502014, 0.10713566507079772, 0.11269905511289835, 0.20342892408370972, 0.08137851647500481, 0.09857998309390885, 0.09909500474376337, 0.11999716742762498, 0.08549676941973822, 0.11566290285970483, 0.13894719843353542, 0.06566405256411859, 0.1356207076460123, 0.1979094895401171, 0.1851811632514, 0.13213097490370274, 0.1042985948068755, 0.19283309765160084, 0.1584143138357571, 0.1410980187356472, 0.15651731991342135, 0.10652418966804232, 0.11324882454105786, 0.09305972073759351, 0.10265643149614334, 0.1074270008664046, 0.14378788082727365, 0.07273626700043678, 0.08560369296797685, 0.08675760962069035, 0.2058429888316563, 0.06724513415247202, 0.102046740640487, 0.07764637709728309, 0.10888732357748918, 0.20050869935325213, 0.11893422875021185, 0.10345364228955337, 0.11450916262609617, 0.25564349655594143, 0.1464869709951537, 0.053686314927680154, 0.07862220544900213, 0.10588484683207103, 0.12131576452936445, 0.16566946809845312, 0.11176315176167659, 0.13844314190958226, 0.11451721005141735, 0.2296131561909403, 0.09311523847281933, 0.10243081860244274, 0.09363092508699213, 0.12774929430867943, 0.0789866941049695, 0.13346226061029093, 0.1533230756010328, 0.13502066555832112, 0.05462768727115222, 0.07761406525969505, 0.10140589824212448, 0.10175368815128293, 0.1132186840155295, 0.10630327902202096, 0.06586172338575125, 0.09663516602345876, 0.0943897036569459, 0.12161256931722164, 0.20785971704338277, 0.09175910481384822, 0.12148550684962954, 0.16851088777184486, 0.11277752768780504, 0.2174515559204987, 0.14044471164899214, 0.0716170302725264, 0.11986209824681282, 0.1452991683036089, 0.15614405779966287, 0.07985966333321162, 0.1128468264692596, 0.054114385707569976, 0.12546753031866892, 0.11664607296032564, 0.07295961358717509, 0.2820310177547591, 0.11348076138113226, 0.15359254899833882, 0.08708422923726694, 0.1497027384383338, 0.09456168514277254, 0.15782055498233863, 0.11236023543668644, 0.09318942949175835, 0.07622973168534891, 0.17755121338580335, 0.08037769089319877, 0.17127190104552678, 0.09964925928839616, 0.18081914660121712, 0.17367470211216382, 0.1563538879688297, 0.15784423585448945, 0.1991108629320349, 0.1475101610911744, 0.11370395869016647, 0.09866038949361869, 0.09715047265802111, 0.11452483678502695, 0.0804392204486898, 0.1326642491455589, 0.1582643711673362, 0.10195552517793008, 0.1729098574391433, 0.11342997982033662, 0.204038940636175, 0.10996420614953552, 0.08100761566311121, 0.11940741193081651, 0.10924651966031108, 0.07801746111363173, 0.15176594629883766, 0.09251257723995618, 0.08536333550832101, 0.16407606431416102, 0.16737417876720428, 0.088013666149761, 0.11730293557047844, 0.10303846706769296, 0.10137659231466906, 0.15357466281524726, 0.12512111105024815, 0.12416303317461695, 0.11293192833129849, 0.13078659347125463, 0.09960022834794861, 0.13163374444203718, 0.16167140406157288, 0.1442584448627063, 0.17465621658733912, 0.17067054259989942, 0.09502740443817206, 0.09333411351378475, 0.13020054277564796, 0.16316705809107848, 0.11041201890579291, 0.1435712788786207, 0.09899978592459645, 0.152392301974552, 0.15446480576481136, 0.11318903203521456, 0.10091609773891312, 0.16376900007682188, 0.09531278948166541, 0.15465012724910462, 0.1217849850654602, 0.0820257845999939], [0.007317984060916517, 0.0850512297557933, 0.025788164431495324, 0.026204823948709027, 0.01863427473498242, 0.015078378043004444, 0.05426127836108208, 0.042181930105601034, 0.07186345383524895, 0.07290176169148513, 0.010282188886776567, 0.051088207733950446, 0.03570760001561471, 0.0053338721793677124, 0.05869084995772157, 0.020525185590876, 0.034221839026681015, 0.004012050764036498, 0.046650018742574115, 0.03601353449214782, 0.015121029057939137, 0.04425505814807756, 0.04862102387206895, 0.01987739499392254, 0.06401968401457582, 0.05882213969847985, 0.06670298467257194, 0.033595300146511624, 0.009557587277543331, 0.06723043708396809, 0.02332921459206513, 0.04647813903700028, 0.03870429224999888, 0.03727340099534818, 0.04055477259680629, 0.04350987741989749, 0.041513993803943904, 0.03496124542185238, 0.0408878620447857, 0.03140033435608659, 0.046029094739684036, 0.015517424126820905, 0.04282114401991878, 0.022208393484886204, 0.09153490327298641, 0.04431279469281435, 0.06828820532453911, 0.06448842957615852, 0.023083941146199192, 0.024695198883169463, 0.010872735725050526, 0.05474242754280567, 0.03759226495666163, 0.05294217575075371, 0.005938388781422483, 0.04109720366873911, 0.02522753844303744, 0.06383245584688016, 0.01829239825851151, 0.054584410307662826, 0.06376613583415747, 0.019441414192052822, 0.06795262904571635, 0.017150486586615443, 0.0722769462902631, 0.031989214542720995, 0.06467492492603404, 0.01788388964320932, 0.13336510796632084, 0.06144793451364551, 0.019373777821393948, 0.040953652800193856, 0.09071301416094814, 0.055280437959092, 0.03189443337864109, 0.03868923555793507, 0.012703278168503727, 0.017286471789702773, 0.050352770768638165, 0.04818075981789401, 0.03073133614712528, 0.09712685285402195, 0.012909546876991434, 0.011702904660653855, 0.006413649551437369, 0.027090483478137424, 0.023106519398944717, 0.03988051913412554, 0.019383392662608197, 0.02728569121765239, 0.052777424055550776, 0.0501978781872562, 0.03692161451492991, 0.043263158694441826, 0.014586258646366852, 0.035960181283631494, 0.035818245328430615, 0.0396443855549608, 0.05075025997523751, 0.014297564048320055, 0.023639437409916093, 0.02699456237522619, 0.0249462466620441, 0.01498759345018438, 0.03771200603140252, 0.06439155513154608, 0.030150282861930982, 0.05848813083555017, 0.06354643976581947, 0.0234693456441164, 0.01946212477715952, 0.03986272455326148, 0.07993796627436366, 0.03034062889803733, 0.021286021818273833, 0.033014562380101, 0.018272897162075554, 0.05128966138831206, 0.026744211791083217, 0.05793902637170894, 0.008129614571641599, 0.034662099688180854, 0.07228560439710106, 0.048061425864164314, 0.01245877570805273, 0.012346009125134774, 0.02520956744306854, 0.03608497065891113, 0.04153393255546689, 0.05921545252203941, 0.07478129012244088, 0.015181927575862833, 0.02065662121666329, 0.07228405733725854, 0.015265629959425755, 0.015858372706653814, 0.03927889605984092, 0.10700989860509123, 0.07303231861442327, 0.08010043469922883, 0.025367141934111714, 0.014212371432222426, 0.021175898977422287, 0.09399854857474566, 0.040801460788186104, 0.007584588951431215, 0.02294957933814398, 0.02257539441676012, 0.05510898233790483, 0.02414105460047722, 0.04376999721197145, 0.021132124987031733, 0.010013690035391067, 0.034863977426929135, 0.039023196923413446, 0.025106341910681555, 0.051933245068149905, 0.04335719686267631, 0.01988698947908623, 0.021259262093475888, 0.01171319549238043, 0.031243945604988506, 0.01922046622660543, 0.026783208894942487, 0.058144032156893184, 0.05112332870651569, 0.016354977219764675, 0.06100563146173954, 0.0202817000847842, 0.02712778763712517, 0.03998744607503925, 0.05483128170349768, 0.01565901911817491, 0.014333443283768637, 0.07238770356135708, 0.026596545607649853, 0.02125840713935239, 0.045361267003629885, 0.022642252168485096, 0.0409574967010745, 0.055056942094649584, 0.023275321948208978, 0.04456576272579176, 0.0042432891371260795, 0.0627372528293303, 0.03048191006694521, 0.036326926068535874, 0.008313324535265565, 0.02712520581137921, 0.01715882578199463, 0.024540501380605356, 0.029792474383222203, 0.04437004608501281, 0.03559086485100644, 0.06205109107707228, 0.0495154687336513, 0.028399418241211345, 0.056711648125201464, 0.03805146353053195, 0.0416067732897188, 0.011825150377782328, 0.07969401936445918, 0.012020252096200628, 0.054294458723493984, 0.014325653701754553, 0.054033735035253425, 0.014263866302956427, 0.05290290553654943, 0.007814965160962726, 0.011179842370828348, 0.03741311814103808, 0.02141113519402487, 0.040002367060099325, 0.032723657454230955, 0.05866391211748123, 0.019039195596373508, 0.022560305494282926, 0.024825586172352945, 0.0468432044477335, 0.03227658090846879, 0.07971300477428095, 0.03244746995291539, 0.0778812248525875, 0.018207455852202008, 0.017878025404310653, 0.01426677212917379, 0.02188773310211088, 0.04819940596020647, 0.017892990494146943, 0.08548271017415182, 0.021053189311974814, 0.0034205681835633834, 0.032237578715596876, 0.031106555834412575, 0.03296572482213378, 0.01802800708849515, 0.07122508808970451, 0.007586144492961466, 0.08545715654534952, 0.029205022512802055, 0.022982018401048014, 0.03755378523575408, 0.03233543364331126, 0.07937844629798617, 0.058643603564373085, 0.031298957831625424, 0.023644292327974523, 0.05422910562317286, 0.033322359435260296, 0.04959525766649416, 0.025579357153869102, 0.026873199601790736, 0.030092946652855192, 0.013857160894466298, 0.016554639541677067, 0.07788858017218964, 0.02260583689037178, 0.018004634949777807, 0.02831183124466666, 0.053432244275297434, 0.014907497480245573, 0.005877941065201802, 0.025037387485748956, 0.04566907084413937, 0.012456690061039158, 0.028310538635456135, 0.053705039101519754, 0.0702993016956108, 0.03344969670953495, 0.056396611101393185, 0.06544489932379552, 0.044676669274589846, 0.024544408045975224, 0.025960120472258756, 0.056254939774849584, 0.1226321631776435, 0.10699252132326365, 0.009010567612546896, 0.01608393301389047, 0.04886206665209361, 0.022041177011228034, 0.02210312895476818, 0.06404535299433128, 0.05789470446429082, 0.027603808790445328, 0.03360824320199234, 0.04482612679047244, 0.020435015072247813, 0.049970202547098906, 0.040088819206825325, 0.11048780448202576, 0.052092520985752344, 0.019877242323543345, 0.03682087920606136, 0.029764379640775065, 0.047988171223551035, 0.06643477335040059, 0.03283484898773687, 0.035629300467137776, 0.03155745253232973, 0.036628137941339185, 0.04189540512327637, 0.02129883086308837, 0.06580647027918271, 0.03772437911746757, 0.02365115231701306, 0.028035306172179322, 0.048009439903710566, 0.02002734105501856, 0.009157422098464199, 0.021762092165382843, 0.06916705066604273, 0.07319380316351141, 0.03649676677637866, 0.043915661717099805, 0.04594536012570773, 0.02357571109730218, 0.034237455510135205, 0.04034865740686655, 0.03002125603545989, 0.052980903136943064, 0.017677918641961048, 0.035236662785921774, 0.05298516433686018, 0.03577077162585088, 0.03700921338583742, 0.05724557036800044, 0.06166629386799676, 0.029458044828580957, 0.02814629584151719, 0.002447317840830822, 0.04734974780253001, 0.08149911928921938, 0.007973777130246162, 0.01659047127967434, 0.026239310491031835, 0.019836260504754524, 0.07108830900064536, 0.022271468403882215, 0.06613441982439586, 0.05187032451587064, 0.026395931640373807, 0.02847905450367502, 0.03432668965043766, 0.020139718328469565, 0.04335106969145792, 0.026520415674895048, 0.13951844349503517, 0.03065715530621154, 0.08276786442313876, 0.04359382916507976, 0.024314934288018515, 0.139246635937265, 0.1680214468921934, 0.07215581421873399, 0.11671350577047893, 0.11230973207524844, 0.10486202993031059, 0.13859478091554983, 0.06453767764781203, 0.13861243639673504, 0.18848048549677643, 0.15072936192154884, 0.060714980986501486, 0.12477098698062555, 0.109205692208239, 0.11954389246446745, 0.11353102725531374, 0.1464860617582287, 0.1273362021893263, 0.23012004899127142, 0.10279829959784235, 0.06007870512881449, 0.09721174437020506, 0.1699634412569659, 0.12224959156342916, 0.14711222744413785, 0.2602462167186396, 0.09232205139206988, 0.10860878495233399, 0.057754356281033585, 0.15287999223385537, 0.06688994142626013, 0.12134001537093095, 0.14627141399042948, 0.08763036850307669, 0.11487886921635695, 0.13443418060030254, 0.09962694227163281, 0.19982352826212132, 0.1448727361857891, 0.14218291480626377, 0.07873205348317112, 0.09395475592464209, 0.20417729392647743, 0.09674352128058672, 0.16478171359215463, 0.09622020114745412, 0.15321968043489115, 0.11778835952281952, 0.11250155392502036, 0.15821116045117378, 0.13278320990502834, 0.12601865003151552, 0.06831392180174589, 0.29094946490866797, 0.12884495194469178, 0.10950865809406553, 0.1544307025947741, 0.11864396503993443, 0.11223720346710511, 0.12775480401303085, 0.2249003505068166, 0.08103865185486418, 0.23709039496523993, 0.10588635317981243, 0.16495953047914164, 0.12491293650652681, 0.14624554823551858, 0.13918336933212622, 0.1752631797322205, 0.09465903456189803, 0.13541621076209204, 0.2770746722817421, 0.14355648681521416, 0.1871210541576147, 0.10618977368410144, 0.14146141495023454, 0.0861424904848848, 0.0999279132645045, 0.08354684976594788, 0.15307866728731565, 0.1008120851059045, 0.13563022070697375, 0.07547857306365456, 0.12263140321842261, 0.13487313847456658, 0.21657152314271244, 0.09184631013444491, 0.1847005161855902, 0.12875951081514359, 0.10284387000969478, 0.1444054562598467, 0.2407846110207694, 0.1496261725468295, 0.23795463144779205, 0.12048594334295817, 0.11648201676351683, 0.13782818562218122, 0.11877150248203959, 0.15173888632229396, 0.1269569689674037, 0.2436251485986369, 0.06491919753274747, 0.11673163622617722, 0.1811520087399653, 0.08492181277168648, 0.11971940233239106, 0.12010647941912923, 0.13688928314617702, 0.11510047875344753, 0.10933904469545398, 0.19919124219034398, 0.09919499366411141, 0.12177340925804206, 0.20079171630953038, 0.3177919845495905, 0.1381156944802829, 0.10229661794645445, 0.09247183121208634, 0.08421758841723204, 0.10213284673435347, 0.12792248358683928, 0.08483529955680881, 0.16297706828585692, 0.15359435390148843, 0.14811230663742336, 0.11883080644266945, 0.12300661951303482, 0.13714376091957092, 0.13263492286205292, 0.19220816689942563, 0.12164789385029248, 0.09891574936253683, 0.10706433068428721, 0.15196026515747818, 0.09113280342093535, 0.11738733175609793, 0.12846497233424867, 0.19382666290870734, 0.17148582956620625, 0.24028100232992852, 0.18083202519587108, 0.1532538514584303, 0.13750902989080974, 0.1518598012626171, 0.1913996652833053, 0.07187553854393107, 0.1409290906574045, 0.09391023045671837, 0.07193616564784731, 0.08360854895519358, 0.16396771584238323, 0.1472964497017009, 0.10312015589858804, 0.08259550974305187, 0.12113638701183455, 0.14022349566221237, 0.21106177807918616, 0.1275195830634662, 0.06635886563786439, 0.07746542537850992, 0.09863301739096642, 0.15486523642071656, 0.0834703313718949, 0.1719047977988209, 0.16138085536658764, 0.11453909959111895, 0.07844411036265747, 0.1033796751871705, 0.07148851573999439, 0.1450984576450927, 0.1274679329778467, 0.16405148777578557, 0.05614914259474192, 0.21809723627354416, 0.17844489828816482, 0.09182760292398078], [0.10311011358031205, 0.05685610823067171, 0.03277910055060472, 0.0486576477997005, 0.028947772923856974, 0.02883164504809039, 0.09240572154521942, 0.06041418641273465, 0.04066068512786712, 0.016135645863999213, 0.04672451849494662, 0.028955711783575158, 0.037590677184717994, 0.053717893947448046, 0.02513033490894096, 0.019532337884551713, 0.020192085964871303, 0.0371386439406446, 0.09440334899617092, 0.04248714194233928, 0.041918078370924504, 0.024099390853994658, 0.0835406140291265, 0.027355680408488427, 0.021722955961844752, 0.05288507702893444, 0.02420922531746328, 0.04547279101929494, 0.06057189830711909, 0.02581145005699779, 0.029236835627151386, 0.03398745946053948, 0.047453492414206266, 0.04248062800616026, 0.07098819794399397, 0.07304457295686007, 0.0027577011746221353, 0.011124261022944535, 0.016446291069899286, 0.013272172106163842, 0.055129545341644964, 0.0300844581797719, 0.02057976694777608, 0.03530365115563784, 0.032908585388213396, 0.03078817024028727, 0.0198644112263407, 0.041893685037004094, 0.04200088678460036, 0.057449605848108015, 0.025825868926144073, 0.010757464499744986, 0.043193880269037824, 0.048830307820545774, 0.006935512106533029, 0.04994527317051377, 0.022950710795287575, 0.004159933654591441, 0.025491047517529557, 0.03495414116020713, 0.0655478263007743, 0.06661585399082728, 0.005537436925806105, 0.058572642372122834, 0.043832748130496056, 0.014028127122271274, 0.029881654240723168, 0.031485266584370813, 0.009411671714458083, 0.04095504379698208, 0.04660793600071754, 0.01771737545329545, 0.01607522232058857, 0.049200835438179116, 0.028514745445655923, 0.05272756530238049, 0.015213796669351203, 0.006960354545818908, 0.026647771608882716, 0.029385556932538748, 0.02409428487797933, 0.0062074843195400065, 0.05343726543443544, 0.007975199509279003, 0.07035294667418514, 0.0386715970401253, 0.018196149762453775, 0.017858941606911163, 0.019375752358298217, 0.014447623764031699, 0.025851047664348568, 0.020788240046905618, 0.048401365123156986, 0.002344113088578784, 0.03870998515880533, 0.04990318025063191, 0.018185679967116033, 0.027830807591921518, 0.05833218313221421, 0.023404455643945506, 0.04216910240107349, 0.07417953812650271, 0.01492345323120909, 0.07048511851046767, 0.061126376768308024, 0.017353505960532596, 0.03702778149662273, 0.043769308498927524, 0.016934225601809363, 0.012202123229924058, 0.04414517957983272, 0.04673795009564076, 0.013308989416275705, 0.039504614126469405, 0.02734822330863348, 0.0382593327334949, 0.014815942750179341, 0.008350481112886752, 0.020967417396605015, 0.023045731142961552, 0.047913379701120515, 0.021077323106250594, 0.05297779205388256, 0.018859550057511245, 0.015771747533498064, 0.04563968349248171, 0.02267210601296808, 0.0642420467255371, 0.05931778238820178, 0.02845007596936609, 0.02252000560318785, 0.02144049710061933, 0.07399150250213486, 0.03155794447021825, 0.06254486101014273, 0.008957274624013474, 0.055328189861029387, 0.04254088191581624, 0.02026071978200759, 0.046347985842398236, 0.02346115742277886, 0.0197640050069562, 0.049949737930936475, 0.05104950409648674, 0.03798839709322367, 0.043938314608697376, 0.0837049823520439, 0.010519017964335424, 0.024887222597109418, 0.019167666024129306, 0.015511123929172754, 0.04073232485513602, 0.024417284510231445, 0.09212171392781393, 0.008084854160967683, 0.07389014294104916, 0.02746455474490566, 0.019717097881117036, 0.07848473425422396, 0.017891338261376535, 0.007439581777102181, 0.04244435352406331, 0.02712007099762559, 0.03160583207915936, 0.04574560959424291, 0.03157440233709557, 0.03395851315664394, 0.04494047351181507, 0.04378205817192793, 0.03277140257081815, 0.028937652574053833, 0.011759607287655984, 0.028995714815599576, 0.09154863682176385, 0.009281362456801747, 0.07888610807380506, 0.02084680779704026, 0.06437602346496922, 0.013119754481262394, 0.0753046984651259, 0.005743403686210513, 0.028755564309124435, 0.09280807245522738, 0.00338140208207603, 0.035899418472711525, 0.010528176490749632, 0.036403776944747994, 0.01714411683912788, 0.04534747238670077, 0.05957878766847508, 0.0080001271895266, 0.02894302996407662, 0.01738702559045383, 0.05330105292211686, 0.04513392045295664, 0.03290400527683752, 0.05037742194586566, 0.023453257578824247, 0.02816395810805261, 0.06221214136374848, 0.034331500463719876, 0.03608295201723065, 0.03656901718516435, 0.05754578818700143, 0.05787234673542636, 0.029957694267588, 0.06721359584480524, 0.05278497615030833, 0.04383751144632697, 0.0350698754856629, 0.046859051633094034, 0.022879456136641756, 0.01675048510410956, 0.03844677124704633, 0.03724258193480117, 0.027194786184866513, 0.027301758926893984, 0.0432915384215968, 0.04035030285428677, 0.028619568928011825, 0.030790073531014577, 0.02545237441414169, 0.06085414173347609, 0.018179710555289472, 0.0188386121631733, 0.13039585229541573, 0.1078690392896533, 0.016846409599695886, 0.004497109579720667, 0.023540079527135407, 0.02809757363450314, 0.03548208550949182, 0.0341042692639998, 0.009347953035363128, 0.0455920944389488, 0.05630248472360628, 0.051580233832022974, 0.022402719128876925, 0.03292181342840195, 0.04005229705944657, 0.010960981748732073, 0.09015830499785286, 0.046455872910363336, 0.01195621959465955, 0.03962370380759239, 0.05885924877864974, 0.03863333445042372, 0.010189844511582382, 0.042998604676021, 0.024727583663272004, 0.04079500113480857, 0.03321420434596283, 0.016669635960300053, 0.06591751932033471, 0.037550104183277914, 0.053627686109393835, 0.05326134844550064, 0.005801166948263666, 0.03710292585726295, 0.03014895293329443, 0.011261870469232755, 0.011000621764521514, 0.0061083783428849915, 0.011200666610550667, 0.06943792863083736, 0.04362317580463631, 0.052876574985150776, 0.06035322682665927, 0.013509569456800818, 0.015973046821142946, 0.028394181647204926, 0.0317955810044493, 0.015468927532700556, 0.024171944907201186, 0.017290682099493485, 0.03742857177608779, 0.005511397720381085, 0.018232622716043676, 0.041061407553830316, 0.06619928777217865, 0.06265420692839793, 0.0442254163457879, 0.042387044456388266, 0.018499551607029777, 0.021486781670578887, 0.004756481711020959, 0.10191371385008097, 0.05464204167947173, 0.030213956588080952, 0.027636190177872777, 0.014079856087586709, 0.032728200246180804, 0.003991673509257713, 0.03611814762864794, 0.04597838442506535, 0.006200272764544934, 0.05584323865228465, 0.024529015479077185, 0.02875842772690313, 0.021860006464911357, 0.06608412680881363, 0.026698873777474676, 0.02223725836457951, 0.061357417942157814, 0.01300991153610604, 0.046689601082886965, 0.006403429541803364, 0.04008358091648136, 0.042824764004243274, 0.04402361324589167, 0.0632188566295164, 0.05924146755465439, 0.007552319522281843, 0.05670306465721556, 0.02777266053349844, 0.0430922323305692, 0.02479281971630241, 0.011929183366841503, 0.06850505833114896, 0.01099666760170034, 0.01274716157266604, 0.02607554436794349, 0.03853315554027047, 0.022473804153768078, 0.024186811609459773, 0.039874500528510125, 0.019201530010572503, 0.018721568265131543, 0.014638875644387943, 0.03710035081686718, 0.009386514180472918, 0.0262896815381412, 0.011022343366805996, 0.04505977353879383, 0.013320297202361482, 0.010880827255147909, 0.03340914745682052, 0.03642582594017897, 0.06779223693800823, 0.04985170319144215, 0.009090807771177163, 0.03633286664262414, 0.0192223644283201, 0.0954372463747859, 0.030086147731968334, 0.04348424236689295, 0.014340628969616123, 0.03035034891217947, 0.029402611910232475, 0.03160368112315025, 0.02459930152898388, 0.00933749511438821, 0.21043992787599564, 0.14187195577791759, 0.1254081992166383, 0.1331946056868349, 0.06640117229627711, 0.10572864807077817, 0.22495950518974236, 0.13475989097995417, 0.07215772090213639, 0.06784402951598167, 0.12780411993818624, 0.13453579800469534, 0.13090421073138714, 0.18886077723332814, 0.10054143105766603, 0.11076534566070352, 0.12680157087743282, 0.20185382717422076, 0.14853614675147192, 0.11895994522741862, 0.1592141573450395, 0.1453666961086648, 0.1518289279192686, 0.07189646456390619, 0.1640666462481022, 0.12773364729114942, 0.13713797980121203, 0.15022872521408967, 0.13447589693324907, 0.09778441435524396, 0.18297500163316727, 0.181979699326413, 0.17748405198965753, 0.22928303533366748, 0.162844699674419, 0.12991055047937802, 0.1263612966452326, 0.05461823527834245, 0.09332321624138526, 0.08415278832295112, 0.10336517489382199, 0.1414815810109888, 0.14517271651753358, 0.09668666004602398, 0.17735069271709236, 0.09649205620267562, 0.12241922531809125, 0.19110744739217417, 0.07191118877381086, 0.14385018391268595, 0.2085904042635645, 0.08745956766818251, 0.15885818430355617, 0.09620251173951797, 0.08793410791882447, 0.1664099669350045, 0.09524376889956848, 0.12871554174593516, 0.10760656837373972, 0.10102097211139542, 0.16136436696563447, 0.10597931926271745, 0.0773620166416679, 0.14677321777812072, 0.1843478272535971, 0.21056548399584635, 0.20348137484065124, 0.07946145148681742, 0.12555339213992867, 0.08885171796594347, 0.18924595442201408, 0.10002277246011154, 0.09069981665483542, 0.11870636312024933, 0.18390490673482418, 0.1893333633031164, 0.11854493963931288, 0.10859227619533028, 0.1048436484166554, 0.11362896021455526, 0.11025911782469068, 0.06367265406463828, 0.12616692350379058, 0.11826967155294758, 0.12214668494250093, 0.07372890266456775, 0.08850612651024546, 0.18055495220635617, 0.10862684076918022, 0.10965354567659752, 0.06482117636395351, 0.1444581105772938, 0.11864229584378855, 0.11885812426252024, 0.2635212338396481, 0.12942009179719857, 0.0595843991530793, 0.09533754922449589, 0.10181744330163513, 0.09853805641510657, 0.13476506141679628, 0.1365857608616352, 0.11991024709173612, 0.18650284090212413, 0.18606062605977058, 0.13956804440489837, 0.09656973489161048, 0.1163235924073628, 0.10162121097424201, 0.06826162710785866, 0.1559625089700733, 0.23316610125558718, 0.1429340395012072, 0.16869080811738968, 0.06374510803392955, 0.13306349915053162, 0.0935469495930842, 0.0826575956972582, 0.12406239286065102, 0.11870772019028664, 0.11808391580624239, 0.07634047538574253, 0.15727704843240126, 0.1419871167412826, 0.15908742057425634, 0.12984712102583476, 0.07320139597037009, 0.1258246704403843, 0.17902006528207234, 0.08614554389246873, 0.0785389831289649, 0.11710823673222746, 0.15356212348810264, 0.1380903444119862, 0.18551061914435454, 0.09255837835371494, 0.07769178466073104, 0.09574998316488095, 0.1330766084470919, 0.092526616129492, 0.05289817275479436, 0.04894722618960908, 0.18972487800887652, 0.11113938808973346, 0.08187639154493809, 0.07137388403394393, 0.1635418672646795, 0.12221239427370684, 0.19759812339075974, 0.11955791099795274, 0.10735680641872541, 0.10275381484201976, 0.0827235628717712, 0.17050130239554814, 0.09516376962086984, 0.20516642156456197, 0.121641909171428, 0.08613257030291216, 0.15597863096211637, 0.08532989730260201, 0.1635785081556865, 0.1119196287223271, 0.14597384924335138, 0.09737554272370678, 0.10199434416634695, 0.09227340043123279, 0.14280154875346593, 0.1235327555664948, 0.0962307523669941, 0.12659334205091, 0.10825965154383864, 0.11462946688490254, 0.12520921203706945, 0.15911566120173248, 0.12135274468788079, 0.1589228215494326], [0.021267280681058764, 0.024668988771736622, 0.04110599069723061, 0.01126750570256263, 0.0012430702169824923, 0.04718457880829062, 0.009591795620508492, 0.06670863686927728, 0.03308685689366289, 0.025227419699409177, 0.03754533747477191, 0.028760073174323355, 0.016715662686952522, 0.08279948415500776, 0.039359723151262314, 0.007498824669580374, 0.04106115988854851, 0.03559701577095049, 0.013087026192806661, 0.02612541160280151, 0.0042047470758136895, 0.06928145845553704, 0.05029407748952508, 0.03612068534961768, 0.05046530580148101, 0.012170355916688485, 0.0037569665499696775, 0.02715288325478988, 0.0370496337168983, 0.05468987161293626, 0.03141713488314833, 0.06098655105701514, 0.013237448924753283, 0.026541889611897723, 0.0451934822568936, 0.003477405245316082, 0.010923011777257281, 0.06657468727124588, 0.03578047467661755, 0.008617872255854309, 0.037499722958143265, 0.026513163831883242, 0.020464427868968675, 0.026982996745833328, 0.04132427541272981, 0.083453815829541, 0.08224455786070653, 0.013513747536178147, 0.006335501401086471, 0.06203529478183814, 0.005930869765247085, 0.046290832837777476, 0.03220765532127448, 0.056907744745590856, 0.020357234603060142, 0.023971006939453737, 0.007549853895657829, 0.02164878529895629, 0.02321468127359237, 0.042650054807641676, 0.027888788409265022, 0.055926416867545674, 0.08233463338443212, 0.03962276403659156, 0.017914630672229186, 0.053768831571297984, 0.05656227881887129, 0.03190289131764855, 0.037509490469736714, 0.028100223313750963, 0.04860781958060605, 0.031797199310468774, 0.03806954988145402, 0.030656819431377307, 0.07894130011222192, 0.033025673391031365, 0.00567830800511209, 0.05591660525117602, 0.03065545218331473, 0.012687774491496384, 0.0368879320366042, 0.06914577180785791, 0.015250771738854902, 0.04132623298625861, 0.044531907221036296, 0.060201927088201046, 0.03337329027376004, 0.01801373071170279, 0.021307146309741905, 0.08381184483213083, 0.020434526527034383, 0.033770257008395026, 0.031402994213359695, 0.04408397572115064, 0.052499377368284125, 0.024799269191654663, 0.036636443209967444, 0.09218288385974509, 0.03500860377347895, 0.031057592747466903, 0.026808764220082333, 0.03997484567974295, 0.006548070307222328, 0.05852311610111168, 0.017801508706595217, 0.04630223222609077, 0.021514214841382842, 0.027716486315642084, 0.030887280457786152, 0.067845569790474, 0.011631756023104702, 0.02747532139931406, 0.016128505979265486, 0.037313583839152537, 0.03399220920567002, 0.04827291505145175, 0.019736558265451874, 0.01492135486166392, 0.05253550596535206, 0.06369459788714137, 0.02182172691183431, 0.005936614836433104, 0.059675417840480804, 0.0474738077526646, 0.0289482614690704, 0.04557226764570389, 0.016695873213133643, 0.014364460815808602, 0.044530411051320176, 0.024501212506688068, 0.04497388118345823, 0.011504686770162411, 0.0335529900954238, 0.05274931574240327, 0.05423151102981397, 0.046389759850821326, 0.02531219077562647, 0.02227235898109419, 0.018570772338924662, 0.036205512404974015, 0.045802413153329065, 0.015529412144262875, 0.0604503523292286, 0.00874007641271289, 0.03095155129475253, 0.008431880718230136, 0.03591141836451633, 0.02424239380551236, 0.015842177772096226, 0.017216004231678586, 0.023021025682932565, 0.07289553952536412, 0.023620926974607364, 0.01778522047347256, 0.04452267235943249, 0.019428404979407787, 0.014782143224562918, 0.009826944475727422, 0.027952133045930947, 0.008882508546646153, 0.04339707097304719, 0.027717985878033296, 0.07296721317938396, 0.0035214003957142787, 0.043100306897291114, 0.04924475700993623, 0.05611873744055629, 0.04317381938121148, 0.03931797967691507, 0.05356724560260773, 0.04622792924887367, 0.012094247188153011, 0.04025126049028976, 0.02616185911132821, 0.023043134050177674, 0.025035794624792676, 0.027690250759146044, 0.015423290963683809, 0.00562227500735649, 0.011116455325723758, 0.03664659070117133, 0.06482152241681303, 0.05020042947892632, 0.027828727882089357, 0.0253885615883129, 0.025466243669922863, 0.013480665561343943, 0.03346050577238202, 0.05547012581623026, 0.07115661033562251, 0.01745306231480624, 0.0361327734509749, 0.0727562837834869, 0.06376804251755987, 0.025498282397165895, 0.0712816711249096, 0.025447514407070618, 0.061095116659998894, 0.021175590243988802, 0.030300836211868694, 0.060631059775395055, 0.05097419349476695, 0.03155207514230694, 0.023904590235490884, 0.0021702507884973393, 0.009069220179558864, 0.023556394901658808, 0.07564750792724745, 0.04934615049777286, 0.03921021135257823, 0.042505540419369936, 0.036553003758724244, 0.03306150682536619, 0.022236515368734087, 0.024896079175440327, 0.0446524455744241, 0.06428455015910522, 0.029699538834393024, 0.033334610385021994, 0.05181176694376128, 0.04462685462619577, 0.061919672414660454, 0.06646836083382368, 0.04162579262629151, 0.016650682780891657, 0.024722112974684154, 0.01615450913751764, 0.05843670466648681, 0.014185939100570977, 0.06572031668786492, 0.027709533028038483, 0.04440684303907411, 0.030112878619027988, 0.05711126114640917, 0.037697760188685994, 0.023217749948214208, 0.08520426654389926, 0.013115118390747478, 0.03212956951132842, 0.06385323937450137, 0.022020378216568912, 0.0349869890404599, 0.07387659938207694, 0.037223803478160074, 0.010269513852628214, 0.02213942718559078, 0.032503133573170216, 0.04911721617515598, 0.03600970755464264, 0.03856179989608271, 0.028783994926405803, 0.02788961452565023, 0.061394214896219115, 0.01648754091002047, 0.0329610463231802, 0.054909421796245236, 0.04905505218942251, 0.063030291747834, 0.03778699093631335, 0.05373659776523709, 0.03520665457472205, 0.033180742391518185, 0.023172854678705335, 0.01881264123533453, 0.02993532975337335, 0.055103937430041175, 0.012901115231215954, 0.005968983077244567, 0.023525043191122155, 0.023519604732947688, 0.05597366665356925, 0.01710604932824416, 0.02142708924865084, 0.09849226887204818, 0.10852706219468798, 0.039986241675381146, 0.04089130561000534, 0.04520978066804154, 0.014665543766958373, 0.058251620669450076, 0.027566479186394384, 0.024082227310697948, 0.0269890357074993, 0.04092000424861908, 0.0174792113580874, 0.025523780046829155, 0.020107774596129144, 0.050209172402641604, 0.050120257173797915, 0.038937138326998265, 0.08618651383689471, 0.06168710453701871, 0.03011197956012828, 0.03691056117947612, 0.061882780465696535, 0.05558536820379751, 0.023586772914443697, 0.01170444069430232, 0.02887257088774017, 0.028359762958383987, 0.00995051333614226, 0.02365713699587754, 0.03985112499711769, 0.01077643973154149, 0.07484377641230822, 0.037271358604942045, 0.022341729008725712, 0.00530496022630749, 0.03009627147444657, 0.039706637750246694, 0.007772493957807975, 0.08494335625852857, 0.0697788449802569, 0.029236364045313427, 0.061803364727113924, 0.03920052187251193, 0.028413531769599234, 0.010050702424320792, 0.04608350307015436, 0.05077838525176048, 0.0058525689445169905, 0.03142149107796805, 0.023190891835838556, 0.028368041085611497, 0.028087326059384004, 0.03544279154656189, 0.04402734518849424, 0.02121337955551488, 0.01680581284953015, 0.038839303755334446, 0.06150592890168939, 0.0521065463045878, 0.04149099825216191, 0.02001880169180887, 0.01590590238837259, 0.017898471360760074, 0.044741808636380095, 0.0031486817460972816, 0.030430897804243223, 0.017531314365831868, 0.016652075474017432, 0.04288339621520468, 0.04237414889835885, 0.07232679147273302, 0.03226883203855582, 0.05666009981983474, 0.03816731320694089, 0.09041116785790239, 0.0068187213868701035, 0.008232850282053863, 0.1324373741767236, 0.004497003134539617, 0.15236586625022547, 0.1044145632269127, 0.10266084197376456, 0.10818311279373509, 0.10729647787021739, 0.11679638203765665, 0.20384839443223818, 0.14163075014948845, 0.11195046813892466, 0.13003996067813464, 0.08839933866901056, 0.07841413268553359, 0.09057247598788568, 0.2256061490625143, 0.2118968375559364, 0.0764413464016148, 0.13046848268381186, 0.1413042933813163, 0.13385754797075475, 0.18108678795397282, 0.07988328313721077, 0.25340530808482853, 0.1996297115193946, 0.13239202089607716, 0.2104196532496384, 0.1093772394316537, 0.0981870706060103, 0.11712083034217358, 0.0727282195751156, 0.13164864507104668, 0.08989925389843327, 0.10673264241112129, 0.07730898234461035, 0.1024786824626582, 0.08848317845591477, 0.0837102002863373, 0.13930798907365116, 0.1587153391114303, 0.14079623350075313, 0.11572401172348432, 0.1585221059088196, 0.13743295254451887, 0.11299405499760594, 0.14966585327472004, 0.114173898473382, 0.1764805665505784, 0.20199243830783026, 0.14327857244227613, 0.11245850766343729, 0.13454342473830494, 0.09693439996668271, 0.21945535125476973, 0.247335106666599, 0.23230422607489995, 0.12942869562123502, 0.11446709345493998, 0.07188804394432477, 0.11946782868887697, 0.18219064229301044, 0.11387328031872, 0.09102359999503408, 0.14170541614294052, 0.22047020894076141, 0.10041139660669224, 0.11173042601772717, 0.1369505819997617, 0.06984268834016152, 0.12974863845322812, 0.11516234757644789, 0.10055888297834567, 0.14370292824293884, 0.119597035327128, 0.11690873386604445, 0.1015867685366954, 0.20859283341893128, 0.1238046038363661, 0.1466624808630773, 0.12979627161153726, 0.07391058041581086, 0.1235324570110866, 0.10561192647687026, 0.1517174853278058, 0.12420480379036494, 0.13506889582744666, 0.08558567107788154, 0.11021138288612876, 0.06825329469782965, 0.11976969534797327, 0.06320380672280278, 0.131544666364789, 0.16819015783923014, 0.12584299088588782, 0.1309063277606453, 0.1845178681292704, 0.10089515136288744, 0.16044447704085282, 0.09361298462109906, 0.19921385097716535, 0.13944565025823458, 0.1267278819744076, 0.08838206316743578, 0.18832089406039032, 0.09522451207573925, 0.18620393265570911, 0.04978640776659761, 0.07120986176388604, 0.09861981309950352, 0.13758201311741555, 0.06929611481193985, 0.13193508184381894, 0.0911308695961322, 0.09343396672712904, 0.11412276407437665, 0.1405660608517272, 0.1225480248353311, 0.1044863590172359, 0.0902407741440194, 0.0929497777085219, 0.15869161752717836, 0.13668786681124143, 0.09953439009508916, 0.09038893226534128, 0.13306640328041144, 0.14796547165938786, 0.1374640158776726, 0.1475996734308345, 0.1314048474388463, 0.10760168292160545, 0.1298935463918107, 0.16103579316820416, 0.17638578877917357, 0.07442156478230443, 0.13618235822234834, 0.16695506125688553, 0.1316364450114114, 0.21837319646562847, 0.16387871918933733, 0.1100164804873722, 0.16340307971196516, 0.09467839316598006, 0.13278186640569142, 0.08194903550403458, 0.2189192950193371, 0.1304430104792118, 0.13959944700556143, 0.11879113928547927, 0.10238325329763548, 0.15615139954856463, 0.15302435734442302, 0.08118548004754952, 0.14468232568885597, 0.11723681911826134, 0.15763519278594426, 0.12186822774154799, 0.16148700538490499, 0.12830060401133128, 0.2061858797179801, 0.13963829992072924, 0.11179478506424598, 0.04149310849606991, 0.14073838160506316, 0.08281768924955811, 0.25117721621479305, 0.07689204293170146, 0.0924386101375733, 0.10733843847577061, 0.10222453038607325, 0.13821847896490777, 0.12339508081121103, 0.13898934902889387, 0.13415375564779553, 0.14369089103170804, 0.11661392397114209, 0.09148780615734202, 0.24945680424571037, 0.11013567873409816], [0.03133163947079863, 0.046273598048303805, 0.06552117344524179, 0.03154886227899364, 0.02599655949909772, 0.010822329903021455, 0.05672230791034443, 0.01199191392931555, 0.06869924826813595, 0.03621611112196531, 0.04997530513043914, 0.017401410532849174, 0.017904986993276646, 0.07093468867242336, 0.05090141382866672, 0.03547450966600861, 0.03088142809325031, 0.044982834453029294, 0.05798556708863803, 0.01307889649511448, 0.07654228527098894, 0.03505788577188339, 0.011788757152057119, 0.06495349747794014, 0.06854315128709589, 0.003365750399617744, 0.00904023994891239, 0.01869543788156339, 0.03346188998382006, 0.025721079370539104, 0.027133261718388115, 0.0482761516634907, 0.09394503930317503, 0.015106084324153406, 0.04302151541092566, 0.03288778489721673, 0.06342357064464263, 0.04794504014509065, 0.048731085644768815, 0.04865511686408094, 0.02916109754836985, 0.012524127112036305, 0.014570933932970678, 0.033208070389394245, 0.034929381417376656, 0.01799348831575896, 0.03797599347308278, 0.07523653962250267, 0.04488202789798379, 0.015999850650717105, 0.04731848430154579, 0.06733824272773095, 0.01609248934047563, 0.08362360564725739, 0.0085753043614594, 0.08696539739945106, 0.017146298329212835, 0.028725946255560433, 0.01999706312614892, 0.040754767400877814, 0.040140391260917695, 0.07404528997306313, 0.01637429341540805, 0.017024891451001167, 0.02157687076500484, 0.04275856612782393, 0.06506814954004117, 0.032670114255909405, 0.03957491713975157, 0.03520699044955628, 0.018046118884480426, 0.012772510792793972, 0.029827113595924208, 0.06372496232922588, 0.07882589487625019, 0.07631431786077363, 0.0428823343079005, 0.04372598743066192, 0.029013061563351324, 0.07052889080452067, 0.027036249870434403, 0.02388473290817014, 0.028263282064082365, 0.025303861758272563, 0.030189434332506995, 0.05489269590803555, 0.05920132542295115, 0.020545037829184105, 0.01393876236397773, 0.08157116613749947, 0.07448567955621652, 0.01750432393912758, 0.09257329933877502, 0.05741158753101315, 0.02795671994265701, 0.01422147567583514, 0.09536800866148301, 0.05715418527168887, 0.037868618699056764, 0.03449708675699575, 0.036535799503326416, 0.06658228007810456, 0.051425839973879714, 0.02274910277420921, 0.020957968796470335, 0.03129664063453674, 0.061608638747462204, 0.010288824111090174, 0.026288424552019154, 0.059243591369262764, 0.034358363665108166, 0.06794336025736161, 0.04766981955617666, 0.028907539189926217, 0.03876087867787906, 0.05397054985431688, 0.03019118495285511, 0.05519763293809124, 0.04344554212210434, 0.022801562012838464, 0.03398786997422576, 0.07897739138986383, 0.056214611046016216, 0.037165269654776366, 0.047537973416703086, 0.018676879948803356, 0.025071916436510425, 0.0437406573577651, 0.044489291829190085, 0.05252490046301058, 0.04130403471312352, 0.0770014092060072, 0.04989928885229996, 0.016715048612760644, 0.06402295455336571, 0.013369415504192668, 0.04975014685520104, 0.04248758977545159, 0.09225698666913168, 0.03604806853192193, 0.006631082705488163, 0.04798613561849509, 0.03582991613075137, 0.017722142161801457, 0.023729981122804538, 0.043665964222912274, 0.057115413780723295, 0.08129825935299907, 0.01641027782378452, 0.025142543450263993, 0.01440952911174723, 0.0012907506607007235, 0.012173965722987694, 0.03015873401558825, 0.044244330509432724, 0.015138501334669334, 0.008408364390821328, 0.04808308809463467, 0.03949329276968326, 0.004373273970226624, 0.07701907825789281, 0.06047586524592979, 0.031606106885841916, 0.008065859421289392, 0.03699692850932479, 0.03303273015522531, 0.06102583823459489, 0.05869232237871204, 0.013252606548901116, 0.009243418778558927, 0.01615706382186285, 0.08861237152346543, 0.006043876379927886, 0.04786319525114127, 0.02716829957041357, 0.027374694656048502, 0.014343024198231953, 0.07431731466203928, 0.049328847854797325, 0.019676711476807083, 0.03771858103573322, 0.03996627578245742, 0.052699847146868706, 0.038445186867777786, 0.03224131405087454, 0.024284737783351114, 0.04918421133022223, 0.04646615610857095, 0.027093514833333235, 0.06240564598036664, 0.040555305246795924, 0.026274867422346557, 0.04018193796010954, 0.013454173857878362, 0.04116797147850905, 0.02714351438251989, 0.06332637728857142, 0.017016216380787746, 0.02791027252429298, 0.03913636977917381, 0.02346906405208366, 0.026125036712203707, 0.04432490993557232, 0.062426239518182616, 0.007280056497880391, 0.024784349902932132, 0.02988019199775798, 0.09228861318635088, 0.029288651953850473, 0.03132725613457816, 0.03243751584419182, 0.06294592948896544, 0.04644763549523694, 0.027045338847009198, 0.01661925982417805, 0.06482252664864063, 0.04244768173832979, 0.028656518552452326, 0.056570241427315135, 0.03536595424105014, 0.042150035567049465, 0.03042209041970117, 0.015833989550758685, 0.033011380050863535, 0.026347070333680937, 0.01578502985648811, 0.004170587926637381, 0.01866498014091381, 0.007634912501089275, 0.06330600766731159, 0.04132014313446624, 0.07955867198428937, 0.01827793358825147, 0.032891503269118924, 0.04560243191995791, 0.025766422473160282, 0.022929113025643995, 0.008043308309944612, 0.052707551912005456, 0.021989703344713365, 0.024388814877186502, 0.027803706903276697, 0.02173888117873243, 0.07163387151168925, 0.0418523656470435, 0.039162381419113705, 0.04736748131524239, 0.031043730277035917, 0.07601283118128777, 0.01388168569454657, 0.05389119179121085, 0.034845792688429356, 0.014291959349066019, 0.03244954966274755, 0.023992991474057947, 0.04867132706567645, 0.015192500847790922, 0.03145538050947445, 0.03370512782463005, 0.07031344236539942, 0.0317041585887117, 0.02592220393541668, 0.051611273416451046, 0.023515112831124237, 0.02601895115471312, 0.04987747734412551, 0.03704749972426465, 0.016013222879597118, 0.06294179721070187, 0.042516854990805895, 0.03693493415734597, 0.017178796763931, 0.037923810737473626, 0.05844430425869567, 0.00942629499227873, 0.01746818346769682, 0.01779484549271209, 0.024415633973798583, 0.035136097110807896, 0.045480268475200446, 0.03167701379529067, 0.01783186805966709, 0.012245736068247684, 0.009419246709772518, 0.047726619722587724, 0.043640977170850546, 0.08825892263225146, 0.029278708023152182, 0.02782301970624498, 0.00973597158943968, 0.019328541588038206, 0.020576545602775047, 0.04708013869822025, 0.04045252415484615, 0.053283411011632, 0.003910804009397647, 0.017696795486179844, 0.026761405868455768, 0.03572245993252311, 0.017496139110465134, 0.043535390336598666, 0.04334921050550682, 0.015843463595956564, 0.07705580057310206, 0.009426611359231174, 0.06567658510591302, 0.0525013485125133, 0.018826105066442063, 0.014892204997262784, 0.012893525817032372, 0.02031306706235877, 0.023163250015516366, 0.04654966341331601, 0.05009931419044733, 0.033537214156240225, 0.007652106578461826, 0.01987544250940638, 0.036761276690023284, 0.05495344175558005, 0.01631416503473052, 0.0531292885674962, 0.05269991160769548, 0.05480570771864482, 0.030532980005123785, 0.025400741291897636, 0.03183601490621056, 0.03107624567512955, 0.03842325322329998, 0.03183120409292834, 0.004455830477776804, 0.04392736305349639, 0.022609385628519312, 0.046817036744739325, 0.036322451130087884, 0.020462242986208627, 0.05018679092505148, 0.06709133061979498, 0.07493372301438025, 0.07069543043949775, 0.030188026372343302, 0.06570103272263493, 0.032885121647268534, 0.0228872660747064, 0.03141935369265931, 0.0032262756181548214, 0.01903770281933248, 0.03569382575473615, 0.07030788516359669, 0.03382970006870372, 0.01187636620098991, 0.03257505828514695, 0.02736647250796003, 0.15191694748188767, 0.13765286574406282, 0.1345366665295192, 0.12279068252870015, 0.13616234143929823, 0.11325993894466332, 0.0931561202076929, 0.13210078009537288, 0.13943161815404892, 0.1211430909378188, 0.1941250011857067, 0.09685615809368235, 0.12463339364954404, 0.2053168120660952, 0.14659764005669526, 0.0745945708560092, 0.07101803312876395, 0.08440088108181953, 0.14158401265740395, 0.1430168750562838, 0.13144724230681146, 0.09865708502807788, 0.1040293046140245, 0.16030486167541572, 0.08386315565024104, 0.12491362861224584, 0.1468233750866992, 0.19142891014260904, 0.15742324558751924, 0.08747469899909836, 0.09678983808095966, 0.21135658797408852, 0.09578973853162356, 0.08506872917392425, 0.12319964915513992, 0.11516579453434263, 0.15621647105685302, 0.14239278568753175, 0.1069456549095256, 0.15589257915105137, 0.09783524341349091, 0.09029640723019838, 0.11249379148440701, 0.08983065400804792, 0.14786883470203194, 0.19260460776942118, 0.06745189055800438, 0.14404511345284327, 0.08904133457690477, 0.12961297216159956, 0.13113267347216606, 0.2393663642661912, 0.08497147474970136, 0.1327049205345767, 0.12902529298194818, 0.1711251474916935, 0.13396745707307542, 0.09480186618332352, 0.14695046469569206, 0.09536623089973416, 0.16827916806297644, 0.18923026669238294, 0.1544643443609987, 0.03929923175434981, 0.09554262286318199, 0.14133668664310658, 0.1629261238766568, 0.13878479786217213, 0.10475626667695385, 0.19779346005192824, 0.08690234792551824, 0.09454795837934528, 0.16779477548386368, 0.16296467823641642, 0.178008532417672, 0.18206937451447758, 0.10560353299868958, 0.17678552732935973, 0.18304917908140592, 0.19089403455810888, 0.117109675226467, 0.10870898421853781, 0.12650165839919023, 0.17201938879277023, 0.09892892651259899, 0.1512236882533346, 0.11450467072427273, 0.11646939601216998, 0.06303900413747344, 0.08722590056381055, 0.10501695983111858, 0.10982199878032718, 0.188159402725952, 0.11310728892151799, 0.11777906359306403, 0.06156530750117131, 0.2009173131414822, 0.13615661460374082, 0.12606325692364148, 0.0893287823668548, 0.07764820914183344, 0.1482974924147129, 0.12561205827764102, 0.16715707470263752, 0.07897284520523888, 0.12439264942492757, 0.16309222924922193, 0.06675888238740818, 0.10843554139137268, 0.13077944171215805, 0.10633331098194633, 0.123544806348426, 0.10276292078197002, 0.08323441831661121, 0.14226851878421648, 0.146654392725655, 0.07453380125973906, 0.15310427519891942, 0.13295327792210238, 0.12421249837747642, 0.07290155813097954, 0.14658283442258835, 0.16209160722792149, 0.10101313503193003, 0.17911320099873201, 0.102628184083317, 0.12494182852762085, 0.15310633794537612, 0.10240958045635905, 0.1494017131626606, 0.14925916652594293, 0.13202626337962492, 0.07909855738814388, 0.21642072552016803, 0.19173541798123292, 0.06674693338572979, 0.09532821258263928, 0.16297875105270318, 0.2336151014481272, 0.13791415600904397, 0.12920522689819336, 0.16583911542381558, 0.12200644532484667, 0.06955996315394129, 0.10762612375297717, 0.13210485130548477, 0.14829891733825207, 0.22401047897125992, 0.11983438687665121, 0.17229175274925573, 0.10916270022945744, 0.14404524915984698, 0.08136499327208314, 0.16189271504325525, 0.12646292762032577, 0.14712252760572092, 0.16204396049891198, 0.11217488002564226, 0.10430489839719874, 0.11486331719372954, 0.17799029339637074, 0.18001920809703215, 0.13057353347539902, 0.09019003329532486, 0.1555504346532481, 0.08936280411268983, 0.17837359782840523, 0.09874864654349429, 0.10266580885010106, 0.1360906202878271, 0.13013583767626966, 0.23712087475827762, 0.07393392880580255, 0.0989992023844804, 0.1159574549113001, 0.09936776903590985], [0.01255836259640221, 0.007927803838226413, 0.048885160591453314, 0.044108009431511164, 0.023843401643846716, 0.03957444216523852, 0.04243234684690833, 0.030298495266054357, 0.004366030608902552, 0.012513474960412298, 0.046595803794584105, 0.0305648507949497, 0.024681584078020284, 0.023566671314516237, 0.02488610810334129, 0.04890722315758467, 0.017867119650223424, 0.06374341848173312, 0.01683859626895615, 0.03466643552695002, 0.03864285768941045, 0.013999164703169038, 0.023893504669623714, 0.022662925434165766, 0.008392919237459344, 0.02114823510471199, 0.037139376758464744, 0.014164261603062707, 0.031198307339634215, 0.016647127257393937, 0.049574779479631355, 0.04711668459432466, 0.0368917962935354, 0.016340322559699416, 0.06906675640493631, 0.01782234651701791, 0.05624407982187612, 0.008118648597571467, 0.045835542625614574, 0.04497081759784903, 0.037042057873415093, 0.0134289527112352, 0.06557687438492264, 0.032537233350532394, 0.07973904694829669, 0.025183269122083272, 0.07447646505066327, 0.03431321055229221, 0.028456723916211298, 0.03514030742059861, 0.02351692791229912, 0.020113547232800295, 0.014834882358887365, 0.04736500805509942, 0.0071410908297236475, 0.088471215883536, 0.05756706704518624, 0.09613282619310276, 0.07488267682492733, 0.011942010223200279, 0.055068565399519036, 0.04301409223782165, 0.02787726349197328, 0.018808052642270923, 0.021670551006016985, 0.038183078968099186, 0.02935095164658768, 0.03758926583187921, 0.02667700289748609, 0.014367125762094344, 0.0174020008583154, 0.10160455293953419, 0.03026600700936147, 0.01947118152332093, 0.015455930194418346, 0.014614548467631851, 0.021944295781265413, 0.025946868683344552, 0.031704297688390524, 0.014958967754085149, 0.03135165964652385, 0.04119418667895453, 0.030131053179502487, 0.08465254293488604, 0.02882070027823959, 0.020689586144206778, 0.050423809992415566, 0.047633063314216476, 0.024856539243566136, 0.023237344343215227, 0.017480833056781973, 0.04414065035858324, 0.04172091305788074, 0.027777196540098106, 0.04233669376532946, 0.04986204745780144, 0.06727971229702234, 0.008551885573459523, 0.05939831092421498, 0.005990786103731287, 0.032192717372838936, 0.04471026015068803, 0.006313346384558827, 0.038590118555086, 0.08247935811855964, 0.035740447895867486, 0.04282230092212558, 0.028992132150701115, 0.017350910564086268, 0.02657359416064407, 0.02543565022226955, 0.0404146008326539, 0.05780236263360296, 0.014239583230976547, 0.04769901352535401, 0.05055033641734293, 0.042613105183201175, 0.018484527145379355, 0.018193245632573962, 0.02953903137573174, 0.03976164997688361, 0.03312376241332718, 0.011536464261423265, 0.056576918211898634, 0.025845061289146543, 0.02942228942577328, 0.058739385567605495, 0.05491479240091784, 0.02328505553305149, 0.03599877296281712, 0.04468466241710952, 0.047592843150986094, 0.04038582755518811, 0.03309050741206322, 0.019363844068720937, 0.13193084778530256, 0.03287782061046787, 0.01540445483156613, 0.02700380402218018, 0.06460006894277674, 0.04944579675793648, 0.049562433534967046, 0.035928568337112665, 0.07501363408352647, 0.018462859825896363, 0.02519290262301053, 0.08202968617635113, 0.051478931946413856, 0.014520668058789201, 0.01554275383906705, 0.03393715626693197, 0.03677885074700628, 0.041344434688133855, 0.04071893735921808, 0.00793180295399257, 0.020515855734369585, 0.023249064339324832, 0.005990273809792208, 0.024776261765509844, 0.07204648187117917, 0.04283731011673808, 0.021413370966911316, 0.04033890346597348, 0.038305401868586025, 0.0026560941602968213, 0.011205175475749587, 0.014248680689239075, 0.011594532440150422, 0.04305712492870433, 0.030617525468447378, 0.017453211592510343, 0.05265158973634243, 0.042731132957019975, 0.05223457229190639, 0.05379842248346124, 0.04982779161738498, 0.029278619813599756, 0.06712498595671994, 0.06924772169440985, 0.018565674844597067, 0.05746950049485479, 0.011536448994385344, 0.026523911826578633, 0.015343946471278156, 0.02436214336194098, 0.03140074486977287, 0.0640950488990971, 0.006959380423982761, 0.01667909643479756, 0.0169131740528558, 0.023489915433206728, 0.07971812771367175, 0.035041455046406815, 0.12338430567511491, 0.026673662808856795, 0.026247147570497224, 0.05151409702375531, 0.021343916122402464, 0.11789512022265367, 0.01537430752068758, 0.06442580757928745, 0.03150726129700031, 0.0196381978291486, 0.05710025530840669, 0.030402453616261482, 0.05568511624421392, 0.00667169429860743, 0.08975775899099452, 0.07957824771957737, 0.07533281695629869, 0.011392988031730056, 0.013820316442953689, 0.02828547015919217, 0.027895897759922912, 0.039475752639451196, 0.03664206147992185, 0.04199079357619796, 0.05760114307382277, 0.07796893907444817, 0.04588441411033273, 0.03745556389912963, 0.04272704478353262, 0.033950689647878916, 0.0088164794558127, 0.030453411596161977, 0.01029058575763234, 0.027166911966300437, 0.05167750861229641, 0.03681473167879241, 0.05803472695073911, 0.032850702958447595, 0.07816352256174598, 0.09657390109662499, 0.050393947666244845, 0.08146251911031348, 0.04061151508774076, 0.01573601927209113, 0.030561183313173906, 0.013197115955076047, 0.025738566914307218, 0.025061991165525148, 0.02767866477370262, 0.02603157699507262, 0.009480457353804792, 0.027934146778924123, 0.013288932769293231, 0.02634446306287178, 0.10315579934311764, 0.0181561263743788, 0.03529541713318654, 0.03211897418701223, 0.036633895310972414, 0.029837607139987603, 0.01655641899976347, 0.021114964836410115, 0.04103106346779636, 0.02043859943348382, 0.06277628894895315, 0.03242037265694567, 0.0750290300430996, 0.06253526652497904, 0.03369320257167731, 0.015023530361109545, 0.01528988080099225, 0.03999526958380427, 0.04493158131039568, 0.04439338768965431, 0.05784184658633811, 0.054636267346463034, 0.06018022753830467, 0.0056882222499033165, 0.045220399741083384, 0.028642706972147738, 0.04286953713744879, 0.06481800082006625, 0.08247629114027534, 0.008625035041144915, 0.03294964014951672, 0.049247868092996736, 0.04220583828698311, 0.14959357572453363, 0.05203672844384398, 0.0788424579160554, 0.029388240538537502, 0.049037013335951736, 0.06017447356134653, 0.002166557013489572, 0.026719221346346394, 0.017645644123799036, 0.057353111383106024, 0.07961243909916707, 0.04833608326901283, 0.0169240170424538, 0.05458950610565288, 0.0257854163646698, 0.004451939503529242, 0.03298270855365055, 0.026375879234235202, 0.08300433387713772, 0.0543745767458209, 0.058594755828380585, 0.048556634291474304, 0.014965914256338562, 0.02711739587331457, 0.02334611350670457, 0.04468114760571292, 0.03960129179592643, 0.044979540165513754, 0.020047922718471715, 0.03161551138120038, 0.04293505308617439, 0.09122262788670403, 0.029534122174871818, 0.029553938790091445, 0.0276375591222729, 0.0219575543555298, 0.06263460405170918, 0.04883241467177868, 0.0522056531294116, 0.06424762428339038, 0.021300072582172494, 0.025235233030148914, 0.042641596868634224, 0.03224598237180284, 0.014189318204963846, 0.026081937864156704, 0.02993535010942391, 0.04321369009890726, 0.061117793300322125, 0.027286973648837635, 0.020282025781593153, 0.051860716460006576, 0.02238199158039476, 0.034131217282265425, 0.013229638986688639, 0.04325506037899426, 0.0192543946738754, 0.02643146991197552, 0.010238132456184497, 0.052777254421796115, 0.023691591307786957, 0.09303634520620108, 0.016976598417386413, 0.07791589120669024, 0.03792398715657847, 0.09430709201842546, 0.01149108468754483, 0.0038253514295709984, 0.058773733010249476, 0.041032501962035894, 0.05373752396553755, 0.04603785462677479, 0.11886640238974776, 0.08641459659806319, 0.1306768065052373, 0.10010580479034356, 0.09805775540215628, 0.13374039211443492, 0.14017248339951038, 0.18726495786436967, 0.07123002782464027, 0.09428052737244538, 0.189193992210286, 0.07725076404001031, 0.09034231690956013, 0.20379888851727757, 0.09896034268396241, 0.12431410221116883, 0.09058100517307009, 0.1696412456887109, 0.25817603351814405, 0.09370160807988473, 0.09879819995590619, 0.12370469634022031, 0.18847885701273168, 0.12455777770706586, 0.12138593862099306, 0.08346963926617589, 0.11490351360823427, 0.14731528583381856, 0.12526002073926584, 0.2916587511343615, 0.11573767741875989, 0.23514511649097714, 0.13648921889918192, 0.16576058178075723, 0.18310522607394628, 0.08851388216550861, 0.1657882117267166, 0.1510177935872759, 0.0884126786674772, 0.07912468098636184, 0.1135439940595201, 0.12594323764954293, 0.15714633544640882, 0.09772045564438615, 0.15294445306062698, 0.11811231928212301, 0.1616331889693226, 0.06595298634575945, 0.138140148882355, 0.11364822382373468, 0.1020402606310589, 0.18399398481207235, 0.19395318254828453, 0.2141644608761583, 0.1105803566585694, 0.16437675032232488, 0.13845621049404144, 0.10254765554730381, 0.1433214151433536, 0.22110782829778536, 0.2445969193109444, 0.10896832708801542, 0.10046954027244023, 0.1846289714532239, 0.14897415467670985, 0.2062193179236991, 0.11948620341718197, 0.07791046971189124, 0.08662566848631416, 0.07364614174834319, 0.07126615302903311, 0.1608603647244828, 0.10631969956947224, 0.10225323920271226, 0.0977502026196037, 0.10013310903949396, 0.1218349388135331, 0.10948391192193542, 0.13214417919516563, 0.11745184686567102, 0.10651347560009786, 0.14032982209963457, 0.11938062336828027, 0.22901620822293417, 0.17342599188642843, 0.15142613596149854, 0.1694023742207459, 0.15960758551955223, 0.15026905733559812, 0.2053402215242386, 0.140206016600132, 0.1282883903809956, 0.12010099685617856, 0.09751702406044517, 0.10324983751135212, 0.17494274835501397, 0.11749082191714219, 0.1870612752224718, 0.18775480586503232, 0.1928544036511864, 0.11519346519240312, 0.11754000213529382, 0.16174417015697273, 0.1106479319610766, 0.2183763041560139, 0.2411258327109473, 0.13615886734000274, 0.10208458932382719, 0.08857766445726156, 0.11056249761687857, 0.07415600653205599, 0.10964217342968498, 0.099925857303398, 0.15499352025134222, 0.14354936219751835, 0.16387086175382137, 0.10560423188975879, 0.10529978679759161, 0.0741687494197062, 0.072675911310528, 0.124210299924016, 0.13673001740659985, 0.26515864740524975, 0.18078424275985785, 0.08091186758662973, 0.19733520464173385, 0.11398821058017866, 0.08559828504387822, 0.12384600804320403, 0.11171711994601147, 0.15666666547102587, 0.16524759573595865, 0.13673296224858078, 0.16002043336629868, 0.11416849733463355, 0.20171058843178408, 0.1251650665487562, 0.07610860639916998, 0.16863244053508553, 0.16299080183463438, 0.20941121450492314, 0.12418467844171183, 0.10061863477208785, 0.15249353939933435, 0.11301230758960758, 0.09681900151606117, 0.1563281443502222, 0.13487115715231213, 0.09116848079221589, 0.1320318409374782, 0.154762899769204, 0.12622320119823727, 0.10137136759502546, 0.1227575700197901, 0.11812916052128587, 0.184291861685259, 0.08126096028302397, 0.09413116824414049, 0.1843633521348238, 0.10582433507910796, 0.12835046276450157, 0.17753361218741961, 0.1337784986410822, 0.16161585918494634, 0.08086407157991614, 0.1951838686530079, 0.08176131200577531, 0.17287416649716242, 0.0885000264804278, 0.18245368317833968, 0.07018274973545756, 0.16173492851001875, 0.21201966596501215, 0.12743078997092588, 0.1510670552296298, 0.10993446595966816], [0.02252281304182751, 0.0662584492404546, 0.06726806863610234, 0.028842070738651922, 0.057576349404241355, 0.041931567647095234, 0.07913251128047705, 0.05492589323382292, 0.023197095342246548, 0.040928190773619075, 0.04416307594094958, 0.054701294749975204, 0.011603034483934087, 0.02083673494468842, 0.020009071499641453, 0.0052436393203346855, 0.010254298553003796, 0.031124703253486326, 0.017262865556403995, 0.046847078882689984, 0.014636897714808583, 0.017981325575549687, 0.02830916629838092, 0.007628571591340005, 0.05239990074187517, 0.05620838548722012, 0.021696119901857207, 0.04749239621950047, 0.02810115460306406, 0.06962999475321599, 0.0455576553940773, 0.049387201866401095, 0.055373831519058773, 0.0634338300941246, 0.03288636675902775, 0.049082749988883734, 0.05543809896335006, 0.03393625720803227, 0.01698085792096598, 0.07417168747633696, 0.04059883326824222, 0.04939374294398086, 0.03511412275422897, 0.043687029342566214, 0.013873398237462555, 0.026819125449817096, 0.06930926482060126, 0.043090576705123694, 0.03370298704664622, 0.02863759421078222, 0.049753230796860795, 0.04308485665491649, 0.01774694092039551, 0.030298993989293064, 0.05644637146698577, 0.08551698297794376, 0.07575774272637707, 0.010632937208616307, 0.04022101818450859, 0.025944035799641694, 0.019445685569995215, 0.021862920772816454, 0.05436171172186732, 0.05943428006555353, 0.046063927334866354, 0.032421811151185205, 0.03734582443056362, 0.02168833540885576, 0.03806492905797703, 0.06007355504802295, 0.039601502141782215, 0.07753103971481323, 0.04490674692871315, 0.023881221489448632, 0.03193607846541064, 0.046168910272951634, 0.04402654112449714, 0.10552926734089851, 0.09276068356952497, 0.0433329053090087, 0.019569083948486617, 0.011762590297231717, 0.07309076762092964, 0.027967566324930106, 0.020016187635649527, 0.08071862759866885, 0.045542697089591196, 0.04464589771149414, 0.022443675502602543, 0.026474285471652235, 0.07360792665609292, 0.019559296080842614, 0.03977442000593458, 0.008378547017595597, 0.03915202358205404, 0.03702297407601561, 0.022489452867635658, 0.09322403477770941, 0.03819144869755421, 0.049537850211241415, 0.029670117555984428, 0.023895659018307924, 0.007895993268383401, 0.012128859259454268, 0.019791997969150543, 0.041924032515713146, 0.05200505782184856, 0.02717510188397552, 0.05200567528871553, 0.05322945051427398, 0.01843712808165167, 0.052504015155136585, 0.016831529326736927, 0.03388265972690923, 0.010116731515154243, 0.030547439586371183, 0.05845237882541759, 0.012975129831050123, 0.047643125988543034, 0.030186662516955818, 0.03272822399490646, 0.029980248771607876, 0.014734851030100669, 0.04614028627318995, 0.07119504255907876, 0.012603015289641917, 0.06274008232035808, 0.02546157025998192, 0.020526067686400244, 0.014131284801156392, 0.022997390611895492, 0.009007262298837304, 0.03766084788367152, 0.039309928858918805, 0.0083841432351619, 0.023195431235113313, 0.06660643592476845, 0.04821411320673568, 0.035144551657140255, 0.08097883899297033, 0.009604775147246463, 0.01587164824429367, 0.11128857758428369, 0.05493465990626386, 0.06213864923587867, 0.06612777696656329, 0.019207200866990855, 0.022311440901830792, 0.06706359210823264, 0.03030731961397188, 0.04987714486196637, 0.008798167491996927, 0.019755467340084057, 0.05693654516445739, 0.03145798608394606, 0.046949398570827076, 0.006428634573239833, 0.06863955754254546, 0.015183841044615422, 0.04313653727461185, 0.03090610301920346, 0.018846204970031977, 0.05946208643061774, 0.04092283034697175, 0.07662314628916127, 0.03337570585842643, 0.0425264935807458, 0.022802198139418448, 0.040896984948111434, 0.016041909643848027, 0.023898661535765444, 0.03070358745753765, 0.028151600289025476, 0.07666900847107172, 0.00616621963646529, 0.0615260067528912, 0.04437606808330331, 0.04029074105034981, 0.026856828248128295, 0.062259740595306666, 0.019671693710344176, 0.02478143898770213, 0.03125836108145969, 0.016740756608279686, 0.02247602635595415, 0.027743780386767218, 0.04770458769053221, 0.015201062263388718, 0.028743615307446038, 0.09894468209573201, 0.017013351266671504, 0.022110124650810446, 0.03085256999890719, 0.013328990932287914, 0.030584569022591625, 0.06350808896656547, 0.05665368087855833, 0.009981742910375553, 0.09230711005095925, 0.025710412800045948, 0.052667630304183276, 0.04426996895511236, 0.018337678596643463, 0.062220602695431025, 0.03625947968768222, 0.041595529964459796, 0.0026954640343319625, 0.06854627933353186, 0.05481639464518853, 0.047974607308528254, 0.03498964550505791, 0.040251063715134344, 0.04278697638905474, 0.006891391639198575, 0.03227638074063829, 0.00795662630948105, 0.023865360733387724, 0.038167248746114116, 0.06520741206726857, 0.03947081629719053, 0.0489086107616978, 0.02796632460584598, 0.03553530301100441, 0.05290607429508652, 0.04455172383625593, 0.0379593184749995, 0.031466437237603326, 0.08218853122421674, 0.03630622396511691, 0.021544859179162552, 0.02423232264949807, 0.019473288374553834, 0.060781300999224186, 0.0020986261162241654, 0.0313511846720108, 0.007496200435395751, 0.0566901419577854, 0.040852931062025685, 0.007472354170334126, 0.0383476881709482, 0.036803800479641983, 0.02222512785478362, 0.006314232296842549, 0.024297083728015423, 0.015591287752613425, 0.09791620621191603, 0.044097010378858874, 0.06875313751931701, 0.017633947876415083, 0.017190224989982586, 0.022707169310056736, 0.011870612224031771, 0.02552780884850238, 0.06009321899286338, 0.010522879676760306, 0.00971107105059283, 0.029197738439376866, 0.00941202200816146, 0.06765393114515714, 0.0019193993606937251, 0.022391874442941377, 0.05772806304906096, 0.06243017502129078, 0.05797456803598574, 0.013080938885520612, 0.038047802834106345, 0.08240485497351203, 0.007141597186481314, 0.06121738188500915, 0.03157350667087095, 0.025353186165115664, 0.04135789343022874, 0.0522066539685641, 0.05617979880688446, 0.054576719113226445, 0.011873294981861753, 0.09460380859673023, 0.03669865130047713, 0.028833650119070495, 0.01917417487129569, 0.065815359087927, 0.042720581737479994, 0.02517381204026086, 0.049621584825217724, 0.018647260198901807, 0.04790805320122412, 0.016556637827306986, 0.021549551248816506, 0.02388259891553649, 0.022294463955664208, 0.0359873905378793, 0.07413261742996317, 0.021848535830421106, 0.02735164312512747, 0.015412017104348965, 0.003128638457772987, 0.07175266942275421, 0.03750280689980302, 0.02536334383434483, 0.02883561108527439, 0.03909447702712246, 0.022180293653426424, 0.05371152589629803, 0.07784742702330862, 0.00741603661195508, 0.04878906306943723, 0.055997527337500026, 0.0525883977700557, 0.058080650200801234, 0.006302714164900992, 0.06821950365390096, 0.02597564535348543, 0.03786831335829837, 0.04694355299164142, 0.011959079619763153, 0.03151160392111965, 0.012485163086759192, 0.08459279792649405, 0.04808781409103956, 0.024366051723648394, 0.048940593509801796, 0.04943898765902434, 0.025015031453222036, 0.01776871341280639, 0.025313646233241473, 0.06635822781494685, 0.05898540879466704, 0.058210691437125206, 0.020427517260291746, 0.011161323453831886, 0.025888024430189813, 0.06245331306542669, 0.01130204992036202, 0.0044969085637213925, 0.024808402273005674, 0.019567328239125863, 0.018399674644959823, 0.029805963659392934, 0.032599794279251776, 0.04172518104314804, 0.042195514376674376, 0.013313862994047148, 0.014438153111508914, 0.04092406528070569, 0.01673837155768914, 0.019000503833272626, 0.02978303256843771, 0.027700191297169243, 0.015029832255095243, 0.03358698809253318, 0.03756786144471594, 0.01867879511389349, 0.15814294054039887, 0.18459637463092804, 0.12316425676856722, 0.11179005567516599, 0.1184136973960059, 0.1023446378697242, 0.12240674027374812, 0.1005676021533353, 0.16723488909857614, 0.0645792582737548, 0.16475573927164078, 0.07533682031290871, 0.1007526997210724, 0.16215384245983192, 0.1324827138866697, 0.11965601359094892, 0.10314591987324612, 0.09480705697621618, 0.14104001756225312, 0.16824868826993875, 0.1510470655879804, 0.20835819600948266, 0.10795542358287744, 0.13904736377298832, 0.1386368093746049, 0.12110180886728422, 0.1296403171228511, 0.11832292298121111, 0.1306843382439443, 0.2080908396414348, 0.1251625016863857, 0.17459961319608347, 0.19443810438471182, 0.1233267251934324, 0.15577877525772366, 0.10089126335723059, 0.18063960623528275, 0.15073090898139135, 0.060157754458487034, 0.16630251412945135, 0.0593045170285872, 0.12303595936724118, 0.14585183507629804, 0.14201496381844791, 0.16076326636331423, 0.19818449978317532, 0.17023736584399426, 0.12372415672455515, 0.07157027242439133, 0.08946056065282651, 0.1185035625738757, 0.139224040721144, 0.16070450523069926, 0.1000922273046204, 0.15914433609162057, 0.17543539191995347, 0.1460195282208068, 0.11434758986745562, 0.13383801973291806, 0.12218105952654566, 0.15966042982680456, 0.19120720561061585, 0.0870627671746271, 0.11263914725610188, 0.10719015143279519, 0.11103616934269667, 0.08584048811878477, 0.06859457067080907, 0.12845771200954914, 0.12347501223640782, 0.13657118592943462, 0.18758088376905235, 0.08432086144707032, 0.11390488647988864, 0.2533155786139624, 0.11652268815253462, 0.10919239970722369, 0.17750081180461816, 0.1510131795491491, 0.14675895497202873, 0.07540732010134629, 0.12230049526052815, 0.14974688392664703, 0.14601578270750387, 0.13034561356263502, 0.1797061591808285, 0.1047312965882676, 0.10172333727989878, 0.10694219438093049, 0.16040920679058346, 0.19542302510568074, 0.05744293584887471, 0.23579254746437073, 0.0853907483230744, 0.17542461678385735, 0.13875211961567402, 0.10494485191468682, 0.19731962547770568, 0.11197149593915258, 0.09034334149743829, 0.1477325034460851, 0.17511968314647675, 0.14568932593933173, 0.06351889124406235, 0.22245062195828982, 0.1318009626120329, 0.1299145131238869, 0.074671591365976, 0.12600493005343846, 0.14676644599863461, 0.10055526638669626, 0.09845271706581116, 0.09120807331055403, 0.13471026292869023, 0.16831339336931705, 0.16749286811266625, 0.1487553949866976, 0.17046474292874336, 0.11568647516625268, 0.1010329821812255, 0.11028053917522941, 0.12319625648004667, 0.14179169865591185, 0.14303828962147236, 0.18246425475393022, 0.08269155637494155, 0.1715188335095133, 0.12430665189666407, 0.1798345380063568, 0.14842459559440613, 0.09351150970906019, 0.08922428118863276, 0.0990109071135521, 0.10651892423629761, 0.15293472286845955, 0.08169744828982012, 0.18003417657954351, 0.09088799477155719, 0.0869368107191154, 0.14923951615180286, 0.12484550369637352, 0.12381655962339469, 0.173245867980378, 0.09943479472505194, 0.1358171978167125, 0.18406882722462925, 0.06214924116751977, 0.11264091823250055, 0.19542511499353818, 0.1858012764049428, 0.18950778751501016, 0.10996703564056329, 0.10168597035642181, 0.20525292120873928, 0.16845876271171228, 0.1808550682451044, 0.07041684431689126, 0.15376457119626658, 0.08488884275513035, 0.12889073948775018, 0.1348894097443138, 0.22721709976238863, 0.10825733773942504, 0.1332409224872078, 0.14597958964960916, 0.1567657994372504, 0.07776688491659504, 0.15063010581902095, 0.12245091290346213, 0.04699854825490287, 0.06502548325806856, 0.08987646190715687, 0.06622956400471074, 0.22775348169463022, 0.12012052509401526, 0.15257195090608938], [0.0429057268026684, 0.08162841413702283, 0.03600533778912254, 0.07489243415849549, 0.03305495556976114, 0.028966456385595456, 0.028270527121743987, 0.06688895755048309, 0.0254284475730466, 0.006021984719804355, 0.010591516038402915, 0.04116042616910168, 0.016725640544401746, 0.04815088392102292, 0.13152535525815828, 0.02787374359156404, 0.02164997443157647, 0.04724868679685252, 0.050177094659635, 0.016109708862911378, 0.03495434472071273, 0.03839487010346992, 0.01127660061631884, 0.04097857199875372, 0.008386598683760633, 0.03165533799411995, 0.028267667096640383, 0.019911233535302535, 0.005449327033212674, 0.0626636521358575, 0.027650040773940936, 0.0632070569055421, 0.07168542660240616, 0.010535502124444714, 0.01611864856178207, 0.10266024486294814, 0.03493967479360955, 0.02233376300760678, 0.0784032354131341, 0.024810872140473554, 0.01981421490199864, 0.038400230530117235, 0.025969122935618674, 0.026823593602914895, 0.04446525811882956, 0.00339986798852416, 0.026323452226019332, 0.015225876289020692, 0.01325591016627316, 0.06672493528042521, 0.048573397499110015, 0.01843404074731682, 0.04632378249828305, 0.0019335084361955523, 0.0036754269967786968, 0.03357160231098533, 0.034822593576141765, 0.05899274375821863, 0.033255832469356914, 0.0032349492040728883, 0.030653114630175487, 0.05204814140285764, 0.0368133305039789, 0.09351224931223051, 0.05351512393515025, 0.042714763299695084, 0.06537401955574751, 0.02185137041046151, 0.05043055463050093, 0.02676396394547607, 0.0788419083026903, 0.0284801673011056, 0.03888579018946205, 0.02145227137953043, 0.050639523060194085, 0.019283715868368745, 0.008164961157100541, 0.02910556284976857, 0.012480138534946101, 0.06263123173266649, 0.06505134901297943, 0.03141486518351095, 0.07569033705762454, 0.018916282370420437, 0.04871499079412647, 0.040079217936311445, 0.008443941678186613, 0.014623739224459444, 0.031176889381770576, 0.06737591499196631, 0.021174513069646697, 0.028300743982461945, 0.02657782143381025, 0.049075978209397624, 0.027841684508270452, 0.04648706177249551, 0.020551947012011493, 0.02094460165660296, 0.032117535692772696, 0.08973054973674671, 0.038567740470170975, 0.05163943261972495, 0.011189160352971936, 0.04436603255037751, 0.025666995040540184, 0.02363862656056881, 0.014348759515477079, 0.026323155366948674, 0.045907755714974234, 0.07467028179339, 0.016656306139858704, 0.03692427097952791, 0.01937425958125719, 0.04931568427543555, 0.05939219732369695, 0.0475400259851345, 0.019119612174108624, 0.06729767311896596, 0.0340685240392174, 0.049357057948197634, 0.026539094047620893, 0.02295932310101177, 0.01509643385985068, 0.0291906918532082, 0.020801249259550656, 0.02377066438618515, 0.056052451354584525, 0.03281487970213805, 0.009907372079656591, 0.05310832183541996, 0.047535126962299855, 0.016488733435315744, 0.020661701747615422, 0.0514534054590123, 0.06546793558767863, 0.027147521131805012, 0.03363779679472957, 0.07842397822865418, 0.05138615924598915, 0.014599135544683253, 0.04029747890308499, 0.018520881355340992, 0.021362004169662083, 0.027674773375370672, 0.043906827191157, 0.030198601340608935, 0.04040748639298337, 0.034321230836212635, 0.01959170460967081, 0.01963946668963347, 0.02756348854329969, 0.05455850723332592, 0.01838684863676982, 0.014112889716800834, 0.024140342138707638, 0.006325958654217954, 0.05336867572207536, 0.04368530586361885, 0.013855693562488471, 0.031091332901269197, 0.030451996850648096, 0.03738859588546412, 0.0541296357821141, 0.05374762735196522, 0.025847549816327434, 0.033649403136223555, 0.07025097643158265, 0.033689955781613073, 0.03430473564990929, 0.044582397011773925, 0.02537221398337611, 0.03737630083092621, 0.03135979188872235, 0.028233119486165897, 0.0563551865385047, 0.0343529252069337, 0.07472332287579775, 0.008115663043489414, 0.09118054514484746, 0.035937603030885966, 0.018926635118467466, 0.04461601163659777, 0.03571740145395909, 0.0247395106125623, 0.01706152386032045, 0.05957698276532548, 0.027459832141175866, 0.06074149813503027, 0.024230271777404205, 0.05431268417409488, 0.05876224541238376, 0.07007710183305399, 0.001584511370830504, 0.01161988081210958, 0.03624428389593959, 0.030332930918250765, 0.016186335822567344, 0.04485308498676334, 0.03419339483869927, 0.04919412811951978, 0.021351551337699805, 0.056793252139219215, 0.019245938431205492, 0.0213058180774429, 0.035434635555637736, 0.061942423693835735, 0.02487518368954105, 0.04755244996132595, 0.021705748313771825, 0.019803911347740462, 0.041212917638144324, 0.015088861409042562, 0.022815738305715576, 0.045923019360218725, 0.05103922429095421, 0.047870072203555276, 0.03971126875174897, 0.05147074881408896, 0.02612394087814859, 0.009533881808498075, 0.04341690794431737, 0.029368949787957326, 0.060550707658486705, 0.01705939495669944, 0.02031020025190498, 0.08474506118467875, 0.10296371965003864, 0.02818488921704037, 0.048433948374752483, 0.050285147968679667, 0.03378313560304897, 0.018248115366856967, 0.04708335156153355, 0.051433001911001544, 0.012096896867400833, 0.027762552058058124, 0.0059240534569003755, 0.02008378499054483, 0.0708977152992572, 0.02464926545508206, 0.029174369693334614, 0.025157101419089094, 0.09054817764886788, 0.03330986760556698, 0.03591428517497011, 0.008379786192173404, 0.033725745111171684, 0.009345110821803766, 0.047213555646262, 0.01293716240408165, 0.022655653235103403, 0.04808574795190777, 0.04736284352838993, 0.015293268387072852, 0.011756711639463902, 0.057539084261017184, 0.02303837751969695, 0.027719792477520447, 0.022781645313703587, 0.04229477387187736, 0.013059789797158113, 0.048415957018733025, 0.029240808449685574, 0.008340080867388418, 0.00694152816764212, 0.012614617390292031, 0.04231835974912558, 0.007520271465182304, 0.052624003895159276, 0.01348916336428374, 0.05897713066743953, 0.01714523133289601, 0.033079739061317275, 0.05024000842656408, 0.07683075086346694, 0.04523638941879783, 0.055511686086122475, 0.057582958335322995, 0.015604654892480798, 0.015255874322195138, 0.027836278280509368, 0.018120949422674518, 0.02862860701446022, 0.027428806127448167, 0.058005224248128276, 0.11248444127185003, 0.012908126194296139, 0.022909844327451925, 0.09238156569855553, 0.07007127321724381, 0.07231419786278691, 0.022392105144847716, 0.02753762448472636, 0.035517203089381964, 0.018445971089282205, 0.07687210078750338, 0.02469021673979504, 0.055164065810718706, 0.035313554374235015, 0.07036790158599615, 0.05267978286636727, 0.0012152945980363125, 0.027101144959617938, 0.028337294967578988, 0.08960400974111897, 0.07265924649047, 0.0255546839242535, 0.05070152759019818, 0.060887254242386134, 0.047074028490377326, 0.027344532078132033, 0.03865107135581119, 0.034866124990263155, 0.02680957337309207, 0.015001440653577447, 0.028565459152949706, 0.02100560874012964, 0.03648340981453657, 0.03284428062449608, 0.043516119942069054, 0.023442930275840417, 0.011495830191831504, 0.04238301735105259, 0.01929224335721561, 0.024517000320234468, 0.023612328239583542, 0.040131899395159314, 0.026676302310079336, 0.10001760880861964, 0.08625222316810063, 0.032510373541819196, 0.04894278517791203, 0.0377535357672189, 0.04044615271102105, 0.037356721702963114, 0.03820551812116589, 0.032042201342327256, 0.051941831928810904, 0.05233050018016781, 0.03759697059701596, 0.037763876640903096, 0.06994126590767077, 0.005632288063809807, 0.008974402544221707, 0.021748036312471544, 0.03098099971456187, 0.031551722304097245, 0.005179544902473156, 0.002848907731406923, 0.04595797069902931, 0.053121980745345354, 0.03181507531553507, 0.1798997452216489, 0.1493492488350187, 0.22612195781299047, 0.07741173290248428, 0.12625564874282905, 0.11210241927100079, 0.16893042597387517, 0.18407657609454223, 0.061772443886314116, 0.08568768881793533, 0.13971044176391192, 0.22307866040085042, 0.12072049932820456, 0.16612518578767776, 0.21471396567566053, 0.26532765690769466, 0.11020056025258132, 0.08400709328374692, 0.1809955792767661, 0.07673690947038786, 0.19142543604331358, 0.17164101052497113, 0.1791160237044096, 0.09703233971127442, 0.12213601837200777, 0.1499889445091997, 0.07506617305002042, 0.06789033274565424, 0.15039396206183092, 0.11531619860657624, 0.10952963839684214, 0.13217114417680673, 0.1289111633918115, 0.12008758900421006, 0.12459557210760457, 0.19727283370281967, 0.10014747362583876, 0.09989589319697448, 0.1839573574917657, 0.1525386484073741, 0.17264913714357785, 0.12923945220453398, 0.10219381310577903, 0.06291219951318842, 0.15371818654239178, 0.06230516851480518, 0.1215669989053692, 0.10976188736302511, 0.08969966282269784, 0.14533271507493087, 0.2609810158610344, 0.06261177813368184, 0.14771931272532257, 0.14123736268707685, 0.1265521821166788, 0.09810276941529342, 0.15645888447761536, 0.08421952224203519, 0.15896190516650677, 0.10908059749220099, 0.12902404447751387, 0.17371021663503988, 0.22662589220064028, 0.12963274467204297, 0.2268305112208639, 0.1392571803714548, 0.1718905349927289, 0.13083266599902085, 0.09308968484401703, 0.12019406471933637, 0.21883043407329492, 0.07314192237598555, 0.052731521161539216, 0.10040111680115972, 0.09310375087495361, 0.12574833525078638, 0.1219301779887506, 0.11871707040284361, 0.0894430951614465, 0.20241726908300603, 0.16593286182199204, 0.05096193575965507, 0.11997672995286328, 0.08664320183119603, 0.11936637413288866, 0.12008042367441313, 0.10318490849541766, 0.12486125927950655, 0.12216681029115405, 0.18927244442914212, 0.14563093121562684, 0.07965321226843766, 0.11697001914892878, 0.1794520342456443, 0.09697197723601546, 0.06811986078641244, 0.1502607384962695, 0.1532819020961012, 0.21611010575933115, 0.18653462348239763, 0.0971638330125383, 0.1327593254723719, 0.07078136011425938, 0.1794397391911064, 0.13161232987684862, 0.05843593113656555, 0.15683625851358685, 0.1755974396531071, 0.1350718949522291, 0.2430675828031131, 0.0814294201721038, 0.20342976546713284, 0.16929751341896399, 0.11487216529037271, 0.19322001188993454, 0.14944632005478653, 0.14140394303415502, 0.08990643958428077, 0.1461999506822654, 0.16722297402364866, 0.0733882916559066, 0.10955724120140076, 0.11281543743929692, 0.15657219982572965, 0.15582099370658398, 0.0916628274800522, 0.17790455371141434, 0.1219869035163096, 0.15850168200475828, 0.2060998279069151, 0.1788708282900708, 0.14897476535822662, 0.14693686685391835, 0.22680548684937613, 0.19321271085313388, 0.19294658941881998, 0.15392603538930416, 0.11645243263670377, 0.09786660530205284, 0.1085979894601873, 0.14430297033063003, 0.14093788447124617, 0.11696921847760677, 0.15981839277914592, 0.08295013928519827, 0.07198616010802132, 0.12769137455948762, 0.17119263458464826, 0.14383889308997563, 0.08266490351940904, 0.13453112968376704, 0.08824362166758094, 0.13060769092823776, 0.08369983905660254, 0.1048423388440694, 0.21150752130363668, 0.1359496885644538, 0.10970545360552413, 0.1719724748815809, 0.1565834635070392, 0.1882014718971082, 0.07274673001042434, 0.1648322915924447, 0.13225266337394714, 0.132137461698481, 0.14993615448474884, 0.10578407759645156, 0.07985022491110222, 0.0853499344417027, 0.10127758727009807, 0.09920817759952374, 0.09880865618054356, 0.14506910422018596, 0.13612556484128746, 0.08544141453291688, 0.19434768280812673], [0.03564043861946889, 0.03474778509033578, 0.021180568994688134, 0.014896181212472064, 0.01740937483763056, 0.008074964513070881, 0.021908206199961047, 0.04506412973361356, 0.009933684819511004, 0.03311804236311998, 0.04494745563715696, 0.03951201015817268, 0.04285939643159509, 0.06801352756364004, 0.019151532157723392, 0.04107991459646395, 0.02387772873044014, 0.02352751645126513, 0.017288468378995146, 0.0450759091015373, 0.05951191804238728, 0.007369165957373167, 0.013045576184854975, 0.018321916228160262, 0.009885969388830875, 0.018379347432138662, 0.02233566120932145, 0.013682770609323467, 0.011326218489557505, 0.04602231956752283, 0.04809989879972168, 0.046874023508280516, 0.03144055791199207, 0.04336598049849272, 0.023049268006746258, 0.01907080684655479, 0.041229453536548784, 0.06631278632474796, 0.018970381967457275, 0.012916069294858192, 0.0022149469503866775, 0.05615460480164204, 0.03125643404200673, 0.03733330545946956, 0.0408231026626059, 0.062370301091245244, 0.01842979820711272, 0.03735881159082055, 0.02768945517683668, 0.05508039226489408, 0.016220528898494582, 0.05193469034773963, 0.022675656447453157, 0.07410919440111943, 0.05260635180664914, 0.019822077426527227, 0.055997473054698536, 0.03710687832374658, 0.04452374783743705, 0.041799042972603014, 0.03930763541055577, 0.04529024474322796, 0.012153920102199274, 0.017413057586444274, 0.025847370004547492, 0.0324435514131827, 0.08386416666741882, 0.07468938255416495, 0.026331226540995494, 0.022834280971437693, 0.031207610054739883, 0.014770541972081577, 0.04382588814145752, 0.03369722967701299, 0.03012879365789039, 0.06563831573086125, 0.084225337287145, 0.04147415022764887, 0.057297179741518836, 0.013530830503441393, 0.05748081845896585, 0.05108940874093345, 0.028662944279078926, 0.025115970322596173, 0.020464075030758977, 0.016519335364656787, 0.025638318454314555, 0.03105071240237781, 0.005799065186043403, 0.06523422777120556, 0.0708361246756145, 0.0418446846306324, 0.028482504854244844, 0.02732477313838899, 0.015207886629338776, 0.019176933116146495, 0.027250000275671482, 0.07802983080702168, 0.05829546760235514, 0.03641061657773597, 0.01288389740511775, 0.033983313611575534, 0.016335694950872233, 0.008422897762752004, 0.07078399961548192, 0.015309453143605163, 0.035433997732720206, 0.04738974404920425, 0.06726764115904059, 0.005247241069030548, 0.027951691998168826, 0.025152974229838167, 0.04788161747689758, 0.009034457134215959, 0.025297093371461545, 0.05406754304255758, 0.04821834047990186, 0.059731580183974335, 0.08250464711870466, 0.0331609529176993, 0.016856892965734005, 0.039593570067414215, 0.024000557139515877, 0.04196345200762153, 0.004526912534077252, 0.03959360738684024, 0.043955115135759115, 0.025950929715431163, 0.04537646958072271, 0.14057412184774876, 0.02386305032164923, 0.02933205783899341, 0.015555216831022074, 0.020068339837182845, 0.007325431830914957, 0.014797500168372477, 0.08333585251654897, 0.01896485699606793, 0.023419159497799616, 0.05532199822898422, 0.04414395821679916, 0.045947714642222436, 0.020190058841503093, 0.017953078162723353, 0.031069901372705187, 0.0769008028187922, 0.040976678886051686, 0.0722785544182573, 0.03358719843838896, 0.014911120857245155, 0.012732056534982153, 0.027498379715585282, 0.022045704536139965, 0.05551603210291692, 0.008261034082222198, 0.035415361768433025, 0.08642082554953438, 0.0029380352144861327, 0.03902809933892318, 0.02424713846163026, 0.08952154738030263, 0.036774056897099526, 0.042965556627937725, 0.08025117125362158, 0.05074267056105392, 0.004904690298384854, 0.03460754547268152, 0.05352270317130855, 0.038091598876885006, 0.10651018470525742, 0.005249942486573542, 0.07656234276614018, 0.023691006071333374, 0.009728282091340848, 0.031790451279708316, 0.032785763764487844, 0.014671362204743283, 0.045042101094233136, 0.027445355596553003, 0.05775696864085538, 0.02990341485877122, 0.03117782576009631, 0.07222431911421673, 0.028083828211362873, 0.033254129346460104, 0.02425054131474878, 0.05423968398411359, 0.040778000439916334, 0.04481863576386656, 0.058822275405483584, 0.049388114496001174, 0.024429348862863014, 0.00766952202788421, 0.014386603109804648, 0.025954732904210687, 0.03703944890626839, 0.01626139197365514, 0.016519009667847837, 0.009915451735391148, 0.0449126942881516, 0.05721504307751145, 0.020749600870268683, 0.049225079494395425, 0.03734206195388522, 0.008145900260257934, 0.031542348342814615, 0.0074054090572254995, 0.02807233722082206, 0.03078591071867517, 0.033645474418465576, 0.03020535276404449, 0.01837610742742462, 0.04426558901156698, 0.09328597823956183, 0.030039552732237747, 0.03371376896809254, 0.04971913780484881, 0.0291666445721473, 0.0206184383548264, 0.056613861050988944, 0.034803998323955705, 0.02536390532207276, 0.0628565935684102, 0.03403497726789542, 0.017367624577933123, 0.04355251316779426, 0.039209013738270314, 0.035521433755223236, 0.015593299608943718, 0.03343519641618643, 0.039864848367869854, 0.03443136724776455, 0.023962297942489386, 0.04110926462869559, 0.05113506396966321, 0.050787240133753846, 0.03482111097712602, 0.01225741280774985, 0.03255538416228124, 0.05534051884231823, 0.027981367727209414, 0.06311377191117831, 0.037018431284065755, 0.06195879674383572, 0.06215021147259644, 0.031979620057557306, 0.05412691146401422, 0.01995730945574386, 0.020438613004184196, 0.01625461849783148, 0.05814261401870421, 0.035923326654093604, 0.012830147253615516, 0.11347411173794951, 0.05989028273948601, 0.03026083657251937, 0.02625567336300654, 0.04586131338562284, 0.027945405371221047, 0.012249509571120143, 0.04006974558745112, 0.06772025115787983, 0.007415330087366913, 0.03447862721181341, 0.047912161730762036, 0.039933224341699054, 0.015544197422319224, 0.027344662696123123, 0.02654800490875329, 0.03667738601299269, 0.02320251683704555, 0.010950254958256014, 0.02519529785162636, 0.02551696416256683, 0.05231084641335266, 0.03297086811757513, 0.03112966673714774, 0.03639284235292247, 0.014269862856183733, 0.04487385155100908, 0.005550597536577178, 0.022880892934543744, 0.0418870048597455, 0.03165031344230686, 0.021552314582679952, 0.04993687629965799, 0.026406501519626806, 0.020611944774697934, 0.030478300260646, 0.009082569507881999, 0.02751402503677777, 0.025360298908448646, 0.01858848040657384, 0.02638694444405181, 0.01067694359725075, 0.08342540556831018, 0.014418894591342126, 0.005039323944531913, 0.02816139833469476, 0.015157610577132021, 0.02642156838971589, 0.04291277678151216, 0.007484354910307697, 0.026800852501764894, 0.02985031610088689, 0.029752145654388835, 0.02245685095632715, 0.029895883120064224, 0.019935988189120377, 0.014053724007681012, 0.08220021559723786, 0.024050780605258684, 0.05422890545534236, 0.06323996585394655, 0.023031593865848014, 0.027127292306561555, 0.02374380118479686, 0.05946919747761317, 0.0177302286028862, 0.04188804980367422, 0.004571304415419165, 0.03824719713468637, 0.03212965772088085, 0.0769972430009927, 0.008367156110970038, 0.05121837110657777, 0.03157971187361649, 0.0649191364645958, 0.027430292119139006, 0.03869727619790605, 0.029926552902907133, 0.03872603251199637, 0.03719507769814559, 0.02314515518290656, 0.011370104438226138, 0.03106603372309889, 0.031596977197166, 0.045125815352158885, 0.07770198982741151, 0.06019966756658895, 0.00206585181461248, 0.0226321844051459, 0.09634699220103876, 0.04024720624355333, 0.035779484015490325, 0.057583066900925975, 0.028236330653141652, 0.04852832920317139, 0.046543868724256754, 0.04087500719885741, 0.04580558191186615, 0.02344587172514626, 0.0916368260181376, 0.1655590840216194, 0.1079851637727448, 0.08610008883156947, 0.1145984171224492, 0.1729196012020111, 0.08860528083252055, 0.09448070877364703, 0.15015016442963056, 0.16191441459315165, 0.1182024965861014, 0.09406672098806926, 0.14626762776502542, 0.11519176885485649, 0.11930251041693346, 0.09779791720211506, 0.12954357159989222, 0.14852895428027424, 0.1276826893112489, 0.11620346456766129, 0.11383559448378426, 0.05618829745799303, 0.19503780720489367, 0.19681551467095101, 0.16280039133770124, 0.08517072655792747, 0.11767314427665301, 0.06932250303881508, 0.15592007339000702, 0.15286252674247536, 0.12453643099537917, 0.07680335161941391, 0.1672855078109673, 0.21228915293301853, 0.12984622535961016, 0.09580068330147437, 0.11627096523131643, 0.1436491882694619, 0.12064974169645991, 0.08179819716938905, 0.11031680008662598, 0.11312427265303475, 0.15098261833190918, 0.12370268787656512, 0.1033132601795452, 0.10317023856831448, 0.1654252226331404, 0.14205821364053658, 0.05896524951926299, 0.1379982264978545, 0.13018550643963472, 0.11719447853309767, 0.13728952381227696, 0.12397521468145506, 0.21455992465572699, 0.07968936461423125, 0.10181560447173459, 0.12931969575583935, 0.09273860404001814, 0.1787725764193705, 0.09871940168419055, 0.1040165074435728, 0.05601044325158, 0.16544342094234057, 0.16595905327371188, 0.08835693023034505, 0.15969860420695373, 0.17145492908145699, 0.12065449144159045, 0.08142462292952196, 0.10193998672600303, 0.07936735225043126, 0.0819682584011129, 0.06688219934169735, 0.0962588165753654, 0.1426345341439758, 0.11307810513036591, 0.23883425710456713, 0.1292309569461005, 0.07717846613377333, 0.12803498469293118, 0.1359048102583204, 0.0969635226896831, 0.12359106886599745, 0.15351199332092488, 0.1707949587809188, 0.17828754601734026, 0.11591431365481444, 0.06804635508784226, 0.13512312434613705, 0.24187792092561722, 0.08456145639398269, 0.10744345534060683, 0.085582230905337, 0.23140934695090565, 0.06170374221567597, 0.06549415418079921, 0.178194098174572, 0.13284240530005523, 0.13462886586785316, 0.2006854848670108, 0.0850818520411849, 0.1685922984033823, 0.14925053556050571, 0.15803384568010057, 0.10655536156679903, 0.1423697154968977, 0.19739163161388465, 0.20506853610277176, 0.09840396432472126, 0.20647417567670345, 0.12553437958870614, 0.13033150003424712, 0.09069246133523327, 0.1672213048275028, 0.18306792021862098, 0.12012549197035176, 0.12230878695845604, 0.15808141098490783, 0.28584240323730875, 0.14792447457356112, 0.08482018179659333, 0.09938425065151282, 0.12509519101253577, 0.12125603987702302, 0.2081740823175226, 0.06692211755684443, 0.08398622833192348, 0.1270862841712577, 0.18109490323279584, 0.0913414800805705, 0.10553570663822548, 0.09639309865555593, 0.08948817702808551, 0.24563339512263024, 0.16206009606165545, 0.1700919693601983, 0.12543812261096068, 0.16577385392572197, 0.14310489461890288, 0.08557368814945221, 0.14795590431562491, 0.1744535653186696, 0.09841637473021235, 0.12519690341183118, 0.14193659302379402, 0.08306394317852599, 0.15996640840811388, 0.1190737219793456, 0.054062973109206984, 0.31836157398564474, 0.10274798622620956, 0.08150525324578796, 0.10845658954765115, 0.07922120937811476, 0.12208029707627636, 0.203980505200369, 0.09182725008577108, 0.09637878156666245, 0.1039911030924746, 0.14559097907372884, 0.14543108908193453, 0.20521762381706918, 0.1675206609070301, 0.10911962682647364, 0.13161067425140313, 0.16156483335154398, 0.12945629842579365, 0.1508543345012835, 0.13511579616793565, 0.0963681082108191, 0.13341519742139749, 0.1413112822920084, 0.15681257764143602, 0.1061764879684363, 0.08673158780272518], [0.016990747568862777, 0.053319006958710294, 0.08284719195216894, 0.037147366508309326, 0.0499684519267508, 0.02516420228805925, 0.043133795993136506, 0.015424125561756747, 0.009422537604612964, 0.05903836166752236, 0.04324577123458896, 0.013324441354987877, 0.04223353269376925, 0.04528204804020269, 0.0724843880161643, 0.016924181587195823, 0.04354018757918051, 0.02187848636614425, 0.06333057742033686, 0.0022114843013696373, 0.04459065478295088, 0.05703348746257169, 0.02364385297654995, 0.03702283836901188, 0.03292212216183543, 0.0822076251996415, 0.03322622459381819, 0.030623846022146087, 0.01650566458036857, 0.09139300124453646, 0.05357385453368936, 0.07189572496073586, 0.04021842957341245, 0.004680990873436842, 0.04089985175856522, 0.034208271718983135, 0.04985704665471401, 0.027702523761295846, 0.0077939967325489435, 0.017179303968857442, 0.06644748231129986, 0.015675663582182357, 0.021495056405131305, 0.012123682885430753, 0.01212764044092702, 0.024838814212541496, 0.011303592739360673, 0.022496453652690564, 0.07206979633441993, 0.029258043239159242, 0.012657106404991021, 0.0182342681634639, 0.027625235229996697, 0.029167733620852232, 0.010605288602943932, 0.03550748986059001, 0.02802479057572782, 0.03573262777977756, 0.05383671221456357, 0.03914823057129979, 0.0707647360063025, 0.013763715596204358, 0.04154762199946812, 0.02950569155759045, 0.023683077389640466, 0.010679228563926049, 0.06842195814741509, 0.02969335059502295, 0.03429553132238133, 0.04233680233093245, 0.02732633037625679, 0.09963130525180272, 0.010369077840420817, 0.03229773763035025, 0.03581580599503858, 0.028684335095541816, 0.036193339486739466, 0.048243157898208926, 0.03464605912034001, 0.014322734304836817, 0.030824926482247453, 0.06615580046283347, 0.01932571379334799, 0.022199168801307678, 0.031148764105247598, 0.017075717116573026, 0.016875790166003362, 0.02459101322373109, 0.04773355435047831, 0.01114321080967784, 0.042692894116044044, 0.02125429521713938, 0.05181104091129132, 0.017146876780316234, 0.0540529748957072, 0.03164811498884644, 0.01841271948069334, 0.0025847182135164204, 0.009377345476033432, 0.03748406236991286, 0.032515445591083596, 0.0316976344745074, 0.053978475143334696, 0.03462757921910711, 0.02719408050844712, 0.023384900264708058, 0.025087353108184676, 0.049251382904393334, 0.03139723345105137, 0.02213661974695112, 0.038960262800433805, 0.08299748745879956, 0.057337980052190166, 0.03757457894140056, 0.06762343778141908, 0.07654273310410124, 0.037484737512256415, 0.01508386739130531, 0.020505843950169425, 0.02955944849444287, 0.04966157089386668, 0.03347318419920547, 0.017900800432211587, 0.08860528761787073, 0.048368571525705714, 0.013126776470536632, 0.08021171444228717, 0.03309533179604581, 0.04913172325385468, 0.02814145110148404, 0.08400067434247051, 0.02648837016230183, 0.09087135030754975, 0.047643706135983975, 0.03230794958238091, 0.06012211101395743, 0.012556590771834766, 0.04708431847393513, 0.04230024286412767, 0.0780028183279293, 0.05760732452784266, 0.03502258838021329, 0.05022488048832331, 0.0316224290457155, 0.012262299108052892, 0.0745879483542272, 0.0218019001185894, 0.022064776459176625, 0.05055747799841421, 0.04061673980738435, 0.0141409199984212, 0.02446168614551425, 0.01723625002029751, 0.006089867907576263, 0.012864269931534571, 0.040535685406731706, 0.020018910257411853, 0.010660207531015788, 0.004630945523136428, 0.05575178909514632, 0.050368807943803925, 0.013895476070631827, 0.025332940376496742, 0.0571173204641257, 0.002621098292625642, 0.027011047383504252, 0.02619608272133129, 0.015504818642511964, 0.024097319625850235, 0.03445730424885239, 0.01459433660576386, 0.030894768091716936, 0.06755834591708013, 0.00798673799727112, 0.045886001882276366, 0.06800348524536405, 0.03687660050179277, 0.04856774190972958, 0.05363510588982275, 0.06218284222164324, 0.07119059815470662, 0.03007563722452947, 0.05200673041066953, 0.036943079970244846, 0.026237688792337264, 0.003318214144590976, 0.06650171761534043, 0.019139523784230863, 0.03932780147131, 0.03346484161115118, 0.0744175546403442, 0.07631432464612381, 0.013021039510411876, 0.08087501634976693, 0.03260425903967448, 0.03956574673897453, 0.03780316721115794, 0.0125538121709334, 0.03538022722516741, 0.016477395115154128, 0.05667454583038177, 0.06554328011614935, 0.029138488761548485, 0.053004624721195014, 0.019187740482656018, 0.0761238666517394, 0.0680076785917793, 0.021055118047765324, 0.025629617939037935, 0.04589029361626931, 0.007795890693419746, 0.028260688363973583, 0.05876251682639122, 0.01701771085416632, 0.03878539754077792, 0.038120555358805826, 0.04932066811514752, 0.041050686700535674, 0.007942203199490905, 0.07156629620918206, 0.03345111145504883, 0.014818521183250206, 0.03399510994287474, 0.029433481860905886, 0.06307417939284019, 0.0563878681776779, 0.057168115595621724, 0.017581663360553126, 0.014886222014735852, 0.07139099668711424, 0.038903242110141685, 0.06609270349144936, 0.021829635237476656, 0.023906446028766886, 0.00913987263837563, 0.05398342166362064, 0.0461265086196363, 0.026303018143932735, 0.024478600327191607, 0.016459318942257335, 0.03511472325772047, 0.03696851146274379, 0.03293128577726228, 0.03957041845257793, 0.052980512979307344, 0.0316320676356554, 0.057510986125894954, 0.0720888360270432, 0.05407489836215973, 0.11075376985328537, 0.0629988145083189, 0.02688168637853648, 0.06057107049439635, 0.04621414141729474, 0.0365260184210326, 0.030435179360210896, 0.02553263832149761, 0.07859899955136435, 0.03646435994388802, 0.027542326732405593, 0.010857178613410463, 0.01938362166817699, 0.009350589992079352, 0.01471447801616575, 0.024825291009619832, 0.03632644770134773, 0.018239721888676286, 0.02350975070813937, 0.023079091317153404, 0.02459061797708273, 0.03885732564542975, 0.018631577558283294, 0.012475956214724906, 0.001991819403234071, 0.00753987773454615, 0.04847280468259539, 0.05282060941681266, 0.05345396078856928, 0.08056776890797274, 0.04704594731863056, 0.01981194520236126, 0.04257972465295877, 0.03936413702155862, 0.03323105237047587, 0.007813827766637717, 0.024067945844892944, 0.0295137491609369, 0.027671236511585966, 0.01931275038181671, 0.008636280062741466, 0.016249040939978192, 0.0384961889524545, 0.06276816688477993, 0.020788949116000106, 0.011593490888896798, 0.054858399355517964, 0.044744950253516436, 0.05762165518743651, 0.021989954402670264, 0.01209526159800589, 0.04441428317555359, 0.01649719476699829, 0.023276763835123608, 0.015983915255804147, 0.018615055230579207, 0.07177282191280808, 0.0364257614793522, 0.030010060207652192, 0.05110890305201922, 0.03169255563989282, 0.07941188450370516, 0.0388218043372035, 0.027029908960685134, 0.005267360056417861, 0.02386805791008685, 0.05250340108094471, 0.03573723503255418, 0.034776724608881135, 0.06800022827727453, 0.019553350417741706, 0.014674130627619368, 0.009284476932537342, 0.04376758841265525, 0.04589098572198834, 0.03291580839348691, 0.03261286625638604, 0.05848489422351122, 0.009372800987746035, 0.015111454928826009, 0.05427617220474141, 0.02760345595223563, 0.00916770868934691, 0.016600369409258877, 0.01323064067400992, 0.024595915639240826, 0.022039816548515643, 0.023065832742889012, 0.03472189558669925, 0.018374336451025944, 0.050767504942736456, 0.005822637916675636, 0.08821561852736132, 0.042831644349332364, 0.016464396080534374, 0.00968619595680918, 0.0215192563565714, 0.04512176789077265, 0.023235376591661146, 0.020612998200314384, 0.014175471849739552, 0.04319699474477342, 0.039062426425516605, 0.09853961026029927, 0.07630019076168537, 0.14812422171235085, 0.21676054942820752, 0.14689008864973271, 0.17418736246015343, 0.14485996615673813, 0.13307971613747732, 0.07644555331873042, 0.11101023573428392, 0.13920532672532968, 0.12222783773073129, 0.1607177366635629, 0.14232836557286127, 0.14962679679904664, 0.17144648810582502, 0.14196302874812058, 0.14867288512842997, 0.12264158124370234, 0.1279095642800842, 0.13785254502935068, 0.10601660476199218, 0.11798387260309287, 0.19126549176871777, 0.14409357442387513, 0.20163138982440743, 0.10233732326222317, 0.08607760218105145, 0.07077753996210438, 0.16033458150923252, 0.13893665399934563, 0.15279882587492466, 0.17240380602223532, 0.19290658299412045, 0.1048995257754411, 0.13925401839826787, 0.0918051027027624, 0.14580637323004858, 0.07851063393588577, 0.13118156870560987, 0.14445934551102774, 0.14625229287360395, 0.06450504011341504, 0.15074289190982068, 0.10328852757811546, 0.05804691343967404, 0.2776493914425373, 0.17103655795965875, 0.20963642027761253, 0.10248959330575806, 0.1317987505878721, 0.05555206570508225, 0.07056389642613274, 0.13852172983544214, 0.13869536694671425, 0.18684642389416695, 0.09111699355500084, 0.09411277994513512, 0.15320719539054803, 0.17888847020055565, 0.14133767730423383, 0.06782185499157224, 0.15579520937587532, 0.14126322844198771, 0.15194855364305632, 0.09948398172855377, 0.11351933609694242, 0.10629677187119212, 0.1753125906522785, 0.09752101384635482, 0.24105333802955492, 0.1647459819380726, 0.2384071871638298, 0.23401467714990887, 0.10578107168631894, 0.1327698699065617, 0.1931023539177009, 0.12070733574884278, 0.06596555281430483, 0.06997356417455844, 0.14235258927302702, 0.17556412358369144, 0.09056600276380777, 0.10451439608420644, 0.07675091443317276, 0.13641601854137012, 0.06110417510249785, 0.10969782008656434, 0.11320001751716648, 0.17632188435111726, 0.10540607930826289, 0.1416593843272754, 0.11129918308662516, 0.10224791948816606, 0.11335142582122769, 0.1260318678936788, 0.0540390174303736, 0.08384367490985564, 0.055902003177574704, 0.13593336301190512, 0.06645565865827457, 0.10573991175208773, 0.20138485091073172, 0.1136185989848205, 0.10569567126887185, 0.09532704550240721, 0.1631885405097689, 0.0767152506325926, 0.12818390955882414, 0.08868257954184498, 0.09018997222717319, 0.14822366780468396, 0.1147457135042974, 0.09427442055727754, 0.17605007679334708, 0.15956890902348927, 0.11795204931071826, 0.0989869073299425, 0.11614340064781052, 0.16791890668017523, 0.19213442371359893, 0.11242779038314309, 0.05633041322497385, 0.16887975297868252, 0.1521552082683359, 0.10447914618998766, 0.1497474131839616, 0.11323823939476695, 0.12362932467034884, 0.18353572940187796, 0.16673178252364906, 0.11651112591581685, 0.1428387596138886, 0.08029077734266009, 0.16094116467450345, 0.1846083847007581, 0.13977274484932423, 0.12894397734531335, 0.07691767798470599, 0.13566716015338898, 0.20508746722979204, 0.09030560816505126, 0.10835639706679753, 0.10621843500328915, 0.06687810099018471, 0.17781846118824823, 0.10869612597993442, 0.08482706214168242, 0.07765664333211524, 0.10871449392288923, 0.16231185969497475, 0.0582848417439631, 0.06526368976171527, 0.07120128508125033, 0.07516961571361337, 0.06930644211492368, 0.07718016925667014, 0.12256813661328383, 0.08367909624108247, 0.08981894249362604, 0.08132884771163974, 0.12817933623279842, 0.10190091667962925, 0.13368194310792855, 0.15795615342046532, 0.13184003265840666, 0.09081004466861486, 0.10255283955484629, 0.07021531941635267, 0.07101474901927368, 0.1368774902075529, 0.12537983645285877, 0.16586010929729256, 0.0991186381184629, 0.16493503536496842, 0.09608769682901246], [0.06538595498672553, 0.016092816733622124, 0.0284530818794987, 0.029180317052773068, 0.04596725645075951, 0.005832415606294359, 0.04227641949962292, 0.0630327480446015, 0.02002043356852872, 0.021303472042615925, 0.04944427005414452, 0.04198245777349387, 0.029638999940029213, 0.023097759511853968, 0.020132061060784117, 0.023395610939977423, 0.042032632045447826, 0.05272478670147913, 0.037104154005646706, 0.02980542422405311, 0.020293842468942915, 0.002220757754652628, 0.010365826809512717, 0.05469775618985295, 0.009450773991245245, 0.026116441369854977, 0.008918029006703623, 0.04286390529679401, 0.04532532500369208, 0.07231068305139031, 0.05768027382769755, 0.02449496489550386, 0.01455010799691081, 0.04271980142220855, 0.01982237258926034, 0.008534181746654212, 0.009926811259772097, 0.03453534595402224, 0.028866060344236236, 0.03362937278247305, 0.03962124751082488, 0.04970753485602992, 0.025317115243524313, 0.017586218026865805, 0.12595893894987448, 0.009881936346313782, 0.04586395967219557, 0.05009510048798152, 0.045220026546823125, 0.020013812763084258, 0.0614942784554192, 0.07618186782513346, 0.024622122357998575, 0.026394376098843556, 0.016784086158233028, 0.01616207989198821, 0.07007969383682523, 0.023412521728979688, 0.008990116567084832, 0.05261319483231221, 0.030139996271048273, 0.011297058447131088, 0.036974811660391946, 0.008727042603173425, 0.016026177809440663, 0.06445150370044367, 0.03749180106180055, 0.07572403310665063, 0.017754291150985018, 0.05180033023602196, 0.07793244746114526, 0.024009047308936715, 0.03839469029168997, 0.03116644672783358, 0.045412581214415174, 0.04598853191626923, 0.02584266775686826, 0.007286096307715135, 0.02606564963103405, 0.03700332370187555, 0.052427927630820444, 0.007633822604215571, 0.0301359148829111, 0.08689475511865956, 0.03470966499298811, 0.028980905788817575, 0.04943827858992985, 0.061989547950880866, 0.07446723018905946, 0.11203924087541443, 0.03590075857937336, 0.03586090821772814, 0.06199944099145276, 0.022461334376462867, 0.05295034870505333, 0.017305935566712703, 0.052089623641222715, 0.045706329202013354, 0.044457824767700264, 0.02568209414104266, 0.011711213321957206, 0.03402060250352536, 0.05370744111548577, 0.04112643835001758, 0.028749572844909768, 0.02361447749925511, 0.04861936824662345, 0.04322977477152433, 0.015532753929229719, 0.056701979001185725, 0.0318480928295425, 0.024024232922654067, 0.03441223934558885, 0.06471254969281809, 0.061570986839277406, 0.0661549794354609, 0.05446115102885025, 0.010741596958333892, 0.02108736033551395, 0.04351976367511919, 0.06844831244753939, 0.023193390541044728, 0.021808196923562458, 0.04911709064617753, 0.06993243138172797, 0.018261463847011328, 0.007176739363265889, 0.056285039588276825, 0.05494783366365092, 0.0065121100716558945, 0.0363975988834032, 0.057417300795870166, 0.004047211176449699, 0.027483840406473194, 0.05798388432179179, 0.027486982023609535, 0.04168477767546262, 0.03268037370539137, 0.018482520378061702, 0.008589378025914942, 0.05076358640300376, 0.017971037288329432, 0.030031752972198383, 0.05324419168755412, 0.009685996637147452, 0.035001190778400214, 0.039058721624314785, 0.03538599477282592, 0.03734914246680481, 0.04475803919402616, 0.040008351738963804, 0.03903322906366416, 0.010130253869907131, 0.03694297479731696, 0.04226992591949446, 0.037057304555284123, 0.03544860319899661, 0.02433782127419753, 0.041168694118303914, 0.03318681867261018, 0.04779046308249235, 0.03988895671708243, 0.04790036200678774, 0.034718072041869164, 0.019875242341575877, 0.02318993170878717, 0.015725893833275353, 0.04664326731913856, 0.06367693562060595, 0.04008587436484439, 0.03888538985380104, 0.014930043502577713, 0.03328423255256244, 0.02659599938695984, 0.03330702454383884, 0.021302533967952644, 0.03922717472804444, 0.025928819651848505, 0.030455572730196372, 0.05932903249881097, 0.05647069355472922, 0.019402627434049333, 0.03175985274304237, 0.027963490025805574, 0.05295807382624064, 0.03804550938574331, 0.06796251530093805, 0.041331169328519275, 0.04973353631794453, 0.008800612762570381, 0.03414037071966699, 0.04112203465774655, 0.04657631626884852, 0.07936694512942008, 0.012979748110020799, 0.049199396943939586, 0.04265509293015514, 0.031422447812344344, 0.023545144791049615, 0.01041826484392264, 0.027746930485591292, 0.036043376462267976, 0.043848690310759206, 0.005593759997282177, 0.051912064597542794, 0.04467043014509337, 0.04935708508959838, 0.06382482232792036, 0.03299385349133185, 0.006037551161300923, 0.010327807644249072, 0.054637254614915164, 0.04390985006466508, 0.032568683448646746, 0.11093503369816712, 0.003367506745105077, 0.031292562639074664, 0.05099800328857132, 0.0337616837184344, 0.039323489381266494, 0.03552894853055477, 0.015848389760191952, 0.004921511181497148, 0.04702128596337778, 0.013481320347636938, 0.022108182344319563, 0.06690050621650048, 0.05399456320862685, 0.016119515390268395, 0.015619950768138682, 0.031211810186505318, 0.028493303739066635, 0.02625758683175913, 0.06459985181157078, 0.031922185460903814, 0.037756897908236296, 0.019545233442581127, 0.0457399404341621, 0.03072533111221024, 0.0321686395577022, 0.028675609135202, 0.02819110290147364, 0.010917049150780907, 0.021633828690807735, 0.045048479323408434, 0.10640173445322684, 0.04197932294170771, 0.03780844960627811, 0.02741030078115208, 0.02863248823476689, 0.04636836564168334, 0.0290288883926613, 0.07855124425675188, 0.034688667726836035, 0.030397547808076655, 0.05842787692589419, 0.04650732622082744, 0.06861115406666483, 0.039019251242280006, 0.015616955036031348, 0.023444618131699305, 0.017316061005528485, 0.061508554832211564, 0.04730346153623291, 0.008213266913246895, 0.04250889577503715, 0.029459367971867323, 0.027696556045806835, 0.06102654391101428, 0.0951561089605093, 0.07700334303081036, 0.009562135158505822, 0.09576018833156143, 0.024485098996332715, 0.015590875542589595, 0.06526825630239078, 0.03944134073598044, 0.01536759002400296, 0.011611722276679106, 0.022367247014439533, 0.05503405850114567, 0.04703008995524474, 0.07510009301560265, 0.06004557904920407, 0.027194097471822585, 0.025327956536784768, 0.06054735569549458, 0.01625427583764706, 0.06477210471140486, 0.07237380037882499, 0.06881345249712467, 0.02307197857382042, 0.04827565633292709, 0.03646752530975001, 0.03150446234004838, 0.10142932805631842, 0.05707642515855176, 0.021977301420910016, 0.0997356367962701, 0.026788708421268632, 0.011543133412487805, 0.04252527221771223, 0.04294233376692448, 0.039313501345791986, 0.04250543524644204, 0.02937832035656486, 0.01618071585627539, 0.10571086366793939, 0.013741864224097558, 0.036665308089660745, 0.024010613028492247, 0.04948637315205165, 0.02382454345934093, 0.009321314598699766, 0.03399606667725103, 0.031358994610075436, 0.037784918011831384, 0.05455190848026957, 0.06631602972213711, 0.00847541043601398, 0.04749761415379388, 0.03549499124554651, 0.036652365034180026, 0.03532656189054251, 0.04900443008435624, 0.03427593183836766, 0.038013343433184285, 0.026022733987442086, 0.023965641423793774, 0.02275608659588865, 0.06657727927501712, 0.022831236045541506, 0.029953836796006987, 0.04058911664677518, 0.02005747309885919, 0.04905271463628326, 0.05130564428067633, 0.04667087012369718, 0.054558741327907355, 0.058650300705007145, 0.05294942589742797, 0.0494243991561234, 0.0020140935874743654, 0.04443724140790956, 0.0812163126787969, 0.05972939530121429, 0.015971760997282605, 0.03533869409667594, 0.054683561237262826, 0.036358220103595934, 0.06363151448645762, 0.0074502610701269335, 0.09826137697590248, 0.12106686431382384, 0.052549002026872974, 0.1557096732514245, 0.1809271422347852, 0.08635953348129988, 0.10903172261480774, 0.11963402905634471, 0.2540720637355532, 0.0944928206237299, 0.14689952028649195, 0.10990470541375023, 0.13538533741874353, 0.07837912706392151, 0.10882160746093307, 0.1472574339381286, 0.15411637803273542, 0.1554029347108943, 0.19475967570074967, 0.12087905939136233, 0.09206999598869256, 0.0799662069018398, 0.14366201258131436, 0.09620702399739198, 0.15262467307703836, 0.07652042965803828, 0.2156696008252246, 0.12467983258622033, 0.1375253147312573, 0.14227671548724174, 0.2404160579400403, 0.10741123849792139, 0.131628207596285, 0.06991282171968903, 0.0803621117291706, 0.16968320629426412, 0.14317744358309678, 0.07586021508489336, 0.14883505499788693, 0.0894926960713097, 0.108339895095144, 0.16960426553019456, 0.063251480593213, 0.08113403352243559, 0.19658378139138222, 0.1043465400912932, 0.09056280686386994, 0.13095628150871821, 0.1299102654946702, 0.084695840254426, 0.24632699361869267, 0.15909677078681334, 0.06068217381834984, 0.08057418784924916, 0.10783748062593596, 0.10733530364398446, 0.13584543844418867, 0.1644753414605345, 0.1477929609162467, 0.1626980546861887, 0.10159535200468131, 0.07886130761887346, 0.150177943653294, 0.08581794718546526, 0.06528754705297095, 0.13329000771045685, 0.21229994163981505, 0.16718451465879167, 0.205485197316323, 0.19070678603436264, 0.18722827626126154, 0.11477888029600893, 0.12418549268373422, 0.11798117203371865, 0.18553472070821694, 0.09442873977656875, 0.16628492650176796, 0.12039900943636894, 0.10315691214054823, 0.08977010154298373, 0.1818545503275735, 0.13433326887232916, 0.11871667685253279, 0.2079190888575145, 0.11502871688987527, 0.07636755571833678, 0.13252656081957476, 0.1842341319258724, 0.3165496954960482, 0.14431229340178625, 0.11834198981523514, 0.13486955580966814, 0.2540045902132988, 0.23922547325491905, 0.19072080456784793, 0.10139402387929813, 0.15406820204641136, 0.10289189671831471, 0.2006627946559872, 0.10620943762894187, 0.08220956580979483, 0.05600322703165667, 0.08719174989632197, 0.10861857621265308, 0.1232971546373197, 0.12162742923413004, 0.16060545268867696, 0.14016979640083654, 0.10069383680820465, 0.08764978138996021, 0.193920707862292, 0.1307013694729124, 0.1844294143042394, 0.15177303020443234, 0.14882252924144268, 0.165512387241636, 0.15981029107102326, 0.13597631427858556, 0.12018357456794806, 0.19850854096668108, 0.19497861180986675, 0.12387388226177011, 0.13558318465948105, 0.09266009075301034, 0.1349344237574509, 0.10229520659361567, 0.10569034476897546, 0.13070033809968404, 0.16526932242725575, 0.0958742636388966, 0.10298144977007594, 0.1295618513332946, 0.029353112780622075, 0.09856944544506924, 0.17055832647851535, 0.13616645336151123, 0.12639153216566357, 0.07698864596230642, 0.12374310142227582, 0.11776267018701349, 0.1377182900905609, 0.07186073969517436, 0.13829060723739012, 0.09836145410580294, 0.1489482210682971, 0.12630268479032175, 0.11377551699323313, 0.07937719779355185, 0.10287218527602297, 0.15235661103257112, 0.1399226060935429, 0.12220653173114572, 0.07731365745088883, 0.09236484659569603, 0.16167660163981573, 0.13541200384497643, 0.15758196849908146, 0.13917703181505203, 0.08701556149337973, 0.1520735669348921, 0.24892515848789895, 0.150106154648321, 0.12750380033893244, 0.15452299692801066, 0.14293551870754787, 0.16637228110006877, 0.07832340576819011, 0.1462774665227958, 0.16585861652025155, 0.1469725849373, 0.10754053334572486, 0.19127533052648815, 0.24430789053440094, 0.10299791102962834, 0.0634383966348001, 0.12764858614121163], [0.02748359104485384, 0.041791748721152544, 0.05698821560612746, 0.037477012391069105, 0.04610974541200059, 0.013542268059349485, 0.014141003967129757, 0.046276519141559086, 0.021342272371319786, 0.02431578584946692, 0.022253590702478374, 0.03826328859265361, 0.0762298402509519, 0.024764797916369777, 0.03597243223339319, 0.019547011204329983, 0.017829467742038623, 0.04597099178603717, 0.010568689272206808, 0.0229984423411744, 0.030672293422477584, 0.054185136553964446, 0.06563540481563125, 0.06972087094826357, 0.02777239420850362, 0.02823193883523345, 0.009681197698228061, 0.00886537044841264, 0.038403670702661784, 0.02784676503922258, 0.03530729488868799, 0.07341660013688461, 0.0207616414741746, 0.034907993993588855, 0.032438292766788175, 0.044475090091249773, 0.02196210902184248, 0.023898351105994413, 0.04277415546987738, 0.019457936519756913, 0.04868344230843442, 0.07794506821249213, 0.033847515005618334, 0.023129216395318508, 0.06300412065216474, 0.04553683454703007, 0.07760246231087617, 0.009240942973909634, 0.03698637389710971, 0.03654812169926507, 0.027345992624759674, 0.03565488123734083, 0.04495474988860743, 0.037319663512919626, 0.042347441760024855, 0.04506149362506611, 0.050809238239058425, 0.02674190646835736, 0.11043419343020235, 0.049308926066649814, 0.03172669952203121, 0.00876082940625825, 0.03226970395605479, 0.014582160294854214, 0.02123788315137582, 0.02773863878766341, 0.04216139085058655, 0.01836395147256553, 0.024099458707496524, 0.030629840879035846, 0.047133288346230984, 0.036101611730243476, 0.02160390529648534, 0.05169504534985338, 0.022500370496085713, 0.08196711846228157, 0.02188480691984296, 0.11761464098734514, 0.0671540747529694, 0.021422061304162656, 0.004780850448046944, 0.028133376534762125, 0.005685262140884463, 0.04507675048496042, 0.024838091572746634, 0.013483326266785818, 0.022286469116806984, 0.022999008917914968, 0.028932451603135893, 0.06850065463887793, 0.019011686090379953, 0.0533769368859274, 0.009803630012486662, 0.028605200948991945, 0.03228584969682353, 0.022601312758134942, 0.10924694713737283, 0.03760647347995213, 0.045930710554655106, 0.05280540005436965, 0.019277707440778613, 0.07534384993570191, 0.05614821978711656, 0.032082248479127884, 0.026280095534665242, 0.03783625936401742, 0.03193226170593074, 0.017277806897514632, 0.06702244574470179, 0.025949104456230998, 0.023380231943779757, 0.05104673906628575, 0.05526982906407543, 0.10334884255592312, 0.024992012152714387, 0.030367732979357243, 0.036638947004186254, 0.023425249349591986, 0.05847086890467575, 0.04723435613725867, 0.027794344816356897, 0.028295933169179728, 0.026008201463680183, 0.0821505943313241, 0.059547941466527324, 0.04206064875636782, 0.05137412542743342, 0.10577984353793518, 0.027661177229934504, 0.08317943662405014, 0.0069056370578307125, 0.024865370376833847, 0.05172690935432911, 0.011264666033509587, 0.04537796575043883, 0.028854996830757176, 0.022745128255337477, 0.04055589896493724, 0.0880101513383644, 0.012747587353390242, 0.055205090037946186, 0.044768332570259056, 0.007499609225695687, 0.023632443410211375, 0.030043247355414287, 0.02804431881356452, 0.025581397847937684, 0.0545397932375116, 0.011630127539059945, 0.028756107137139355, 0.02418555292700018, 0.0776776439909424, 0.04755119467154145, 0.03179855977318116, 0.005642947000784001, 0.01539623607615275, 0.008275284165782588, 0.05758347402193716, 0.06078233915780272, 0.08996439326022353, 0.07114405743777752, 0.05500460668866124, 0.01612119815711464, 0.029597219146255935, 0.022085704175489287, 0.01871377868311746, 0.012266316035363291, 0.018237677801932608, 0.008268601444017674, 0.04763597083677139, 0.04746377221973879, 0.030959510510521274, 0.03617113782092929, 0.035005669109523296, 0.023121596447059085, 0.04004260418670518, 0.04333565676850932, 0.06089067405888012, 0.0188786983157375, 0.029189249966293573, 0.07557076561663832, 0.06885474135300942, 0.015273005635078465, 0.048412177578679154, 0.03137280619038003, 0.09119354587580476, 0.02459724387153983, 0.028639690883989845, 0.042753935126321654, 0.02138731861487031, 0.026432862605101297, 0.03840292092146618, 0.03458823775872588, 0.04468709835782647, 0.00873684064884271, 0.03923103559230055, 0.019963149945916872, 0.03949488393430199, 0.018921780200409036, 0.009441223610857767, 0.044807022637022395, 0.022593752181689655, 0.01286393151219402, 0.04094096080267003, 0.00932112121621945, 0.05992834855403219, 0.051747519855520556, 0.015150022859285985, 0.029912052609558617, 0.005793389240612409, 0.020192496478557587, 0.04537506162055901, 0.01536849417191531, 0.030700808856636286, 0.010491430426814725, 0.04147304421556847, 0.001975020360467689, 0.008571324753575027, 0.05981763878038951, 0.04065274626814893, 0.03676107991486788, 0.054779119323939085, 0.014880644456882561, 0.036717545108071396, 0.025864771035100733, 0.010032035925957774, 0.0317155545843499, 0.06386690506977694, 0.029875225121421472, 0.04703388975134917, 0.020658687355795076, 0.0333909864670464, 0.015618441027722188, 0.03482956213078328, 0.07638181852442877, 0.024956017566312636, 0.026221431093290448, 0.02565056092238852, 0.05516412348619529, 0.05907230877450534, 0.050590488727071455, 0.03451419262481587, 0.02227267449987786, 0.03678055386990309, 0.024291360285133123, 0.0511965697764286, 0.022761806646095853, 0.04711749544367194, 0.04302941695121782, 0.08269545795129878, 0.07949773275426456, 0.030577620824000666, 0.03719572230641331, 0.010609805949830582, 0.0378662370411413, 0.009995853046088346, 0.026720949914306402, 0.049512296582439115, 0.017803954825337445, 0.027743792261130044, 0.00796954391989857, 0.03642651804589799, 0.022314777597784996, 0.13308937847614288, 0.006409811587738139, 0.02428271235632045, 0.07022393681108952, 0.04808279632457665, 0.02675790462775954, 0.031218598929366896, 0.021125689082379853, 0.038705873236592324, 0.05790501141122409, 0.03871802240610123, 0.04355372774547764, 0.02442402914831681, 0.019074940821155906, 0.09817178321204015, 0.08469832369259425, 0.013186351845173963, 0.019970203317435722, 0.01379043291256364, 0.040901867007570605, 0.03156078413927129, 0.03943003294989467, 0.03665373906759279, 0.04959245192419205, 0.04196233581751585, 0.049549897600497515, 0.15328804962337017, 0.057372252855982096, 0.008336883271113038, 0.06757389793970756, 0.028206125666786517, 0.012775135026978595, 0.021360312921128104, 0.06189202889800072, 0.03763405932113528, 0.0199710684495845, 0.03552792394267661, 0.0846184261941484, 0.07019054610282183, 0.05883758994085448, 0.05538494931533933, 0.028393184200727513, 0.0693104454715337, 0.022025041448484575, 0.035021041320370774, 0.024985082613836442, 0.031292155518063476, 0.015273624798282981, 0.013634329146173383, 0.06390562227794103, 0.08431077163134303, 0.05339565427441682, 0.08529780259621994, 0.052688766670014174, 0.07726953910397631, 0.0334326519098665, 0.03600608757031815, 0.005586469986675573, 0.06398093966501099, 0.02243308865997408, 0.010892241062330348, 0.052679606447262425, 0.05949044919439724, 0.01900217811843114, 0.0722927086587463, 0.04338600067421794, 0.009997202482606684, 0.0118484962232677, 0.022456927291516746, 0.035061227556850226, 0.03177322666825993, 0.005600064435774195, 0.06733351333865098, 0.05521039278911693, 0.04191113356500864, 0.01255735582006829, 0.11297476424702577, 0.030629291265670742, 0.060887722431549, 0.08587080506341797, 0.022025704716465304, 0.029951132833957672, 0.01633280948070543, 0.03978157515770622, 0.05400557583197951, 0.002500606164435989, 0.04619639433388199, 0.026271398412063718, 0.01911147145022239, 0.11267810195152249, 0.2103259747049638, 0.16349561831780843, 0.15509644044297083, 0.20769281099949563, 0.16357582115701266, 0.06933300676090376, 0.14101257760609898, 0.08571552910975047, 0.1559383531234094, 0.18348551781049796, 0.15133591794541904, 0.22866407568965638, 0.08216011417763573, 0.11577596036451203, 0.15414554146783693, 0.08945030120334455, 0.1440395630363907, 0.05878665231700454, 0.12044091575912066, 0.09712694784892456, 0.09011905853237424, 0.07480248077107327, 0.11792987478630883, 0.1285965945571661, 0.08237381199640886, 0.06685507151165179, 0.08600048667618207, 0.15159606827156885, 0.2731370250029223, 0.11917314093027796, 0.1358912531286478, 0.14711297383265837, 0.09707271933023419, 0.08449733483472041, 0.14436326495238713, 0.08734432528061525, 0.1009486470637577, 0.07834755482950381, 0.10856953848685537, 0.19146860444119998, 0.10010233747639827, 0.11590264285249369, 0.11760614572891168, 0.1711356919258833, 0.17123204389853136, 0.11027384203459535, 0.130991931738598, 0.15263371116348676, 0.1043893556509699, 0.07182382739015988, 0.15001234039664268, 0.19708269461989403, 0.2633377308292048, 0.10699253489396401, 0.11879211637590613, 0.1502938781465803, 0.1046483592529382, 0.2092778416616576, 0.13367120868393353, 0.0982204545289278, 0.10831613279879093, 0.20076120937509195, 0.14935475853937014, 0.12490076358829226, 0.11645549961498805, 0.09965324907430581, 0.10313818457403354, 0.11984513487134661, 0.23592627314584597, 0.18009546186242784, 0.1906797531992197, 0.0954628000035882, 0.19100344154451573, 0.18291271211845533, 0.1347970204161746, 0.0812727464362979, 0.25417932655130115, 0.17292439165924275, 0.2897124955696719, 0.09348016139119864, 0.09897960629314184, 0.11155974053378616, 0.07193595530199152, 0.05804719842438187, 0.26787311317665236, 0.11633926656629358, 0.3088023183601243, 0.14987165294587612, 0.10940066246049744, 0.13705800766391413, 0.1512421172644411, 0.13131889062268393, 0.13951150886714458, 0.10045240047786917, 0.09808477466659886, 0.27554172596761156, 0.09839161498738186, 0.14277702649789198, 0.12866610368447645, 0.10276234402720417, 0.16632778277354582, 0.163406567381961, 0.0801225888675877, 0.18922890962234565, 0.1274520145463092, 0.15075357205101422, 0.08681678465966668, 0.16051645603563103, 0.10731748531439475, 0.1414887463407857, 0.10632704131837402, 0.19937485376639025, 0.280081179525171, 0.18999211224062101, 0.13431365921029023, 0.1230144090950489, 0.128123832068273, 0.19148849908794674, 0.13386773956673487, 0.15591444154935225, 0.15057278318064554, 0.10752435707088027, 0.16943991077797754, 0.16274024599364825, 0.13906804552035673, 0.10191797504999808, 0.2036890336977584, 0.15613862951951368, 0.255973970251424, 0.08539030727531229, 0.1349225358239242, 0.12947030338857854, 0.07663853546338421, 0.11257501891148941, 0.12453497893043927, 0.12368497811257839, 0.11461832533989634, 0.18336876907518931, 0.1764353218355349, 0.19048231307949337, 0.1429990567266941, 0.10935410138751779, 0.08561195752450398, 0.05509114365226456, 0.2037355133465358, 0.09850370897246258, 0.1278998205172164, 0.12265830034656183, 0.12010449809687478, 0.07482213793056351, 0.2168368167643036, 0.15016270375677518, 0.07415488694927522, 0.12073088091398988, 0.10609836823173932, 0.13862327938633306, 0.21070091958556855, 0.20353136930082524, 0.1578062107520444, 0.11926063123558249, 0.11912945684577737, 0.1144600502614464, 0.14931331362043107, 0.0933765083817499, 0.09999696098800216, 0.1992695587021964, 0.17551552690565586, 0.12637004974697316, 0.10490531367915017, 0.15548267614628586, 0.25097167438694407, 0.09882396393056427, 0.10656482713030917, 0.08284218436373131, 0.14019313800547803], [0.0073189908372504366, 0.05185995989346078, 0.015272371204836028, 0.05110117793083191, 0.004244714484749628, 0.07200728290315185, 0.031172197312116623, 0.05294113080682499, 0.032376668216394525, 0.02811450308321842, 0.028026900819635818, 0.030836247839033604, 0.045974387853805504, 0.022789984509082775, 0.039122734617974074, 0.005501470753058259, 0.010812602255360355, 0.05677580700388976, 0.06136817950755358, 0.0118805010237598, 0.02483558438585273, 0.02429201846410121, 0.017275469344375387, 0.05989651847630739, 0.09020245727151632, 0.08336526022425719, 0.0074526232201606035, 0.06972716775323663, 0.02633507044187614, 0.0434661458379456, 0.050142027969871245, 0.027676040539518, 0.022430445766076446, 0.06344552803784609, 0.025505200061681013, 0.08782551517443997, 0.02055574850445347, 0.1022156144359282, 0.03031678857015712, 0.09060535100953919, 0.017852139293349216, 0.04246861793633018, 0.011582865030504763, 0.016041892680472562, 0.05172494499545012, 0.04950950101816228, 0.004960266133171639, 0.02132837427780032, 0.013528456479044897, 0.021215862993683134, 0.023594735522887537, 0.027958309410938194, 0.08220303151756525, 0.019318831751921346, 0.06218115945479699, 0.025960943195968866, 0.07640084464635168, 0.025852453928174715, 0.025914712908810804, 0.08575292317462818, 0.054099583466138156, 0.021428621041455438, 0.02181089579659913, 0.03151620778122118, 0.02315136886733983, 0.09866654380623784, 0.013027996190690568, 0.046501775804374895, 0.057026803892638, 0.010552236494342131, 0.038456881418824196, 0.09799064150346176, 0.031018705905548165, 0.012305313987391335, 0.011923278415841716, 0.04543790414131113, 0.07361813860812358, 0.03485833201557398, 0.05065967555024794, 0.042739682498254945, 0.02407820020536227, 0.0067536859257545856, 0.011376355442085435, 0.02958622687895383, 0.03303994298247354, 0.046415252411471944, 0.04750500000747187, 0.04487710851909859, 0.030531487228082757, 0.12063767734382834, 0.009768203699163027, 0.01815308484115771, 0.03109441345025386, 0.016678550214107548, 0.014468631208209055, 0.016664127952286174, 0.03964306241167443, 0.07356229517608881, 0.02722701320557722, 0.08750160291258778, 0.04051769405071225, 0.030781825937862908, 0.042710013554564545, 0.03047943002145205, 0.05255009786092809, 0.03849796671420336, 0.03482244090576257, 0.03532231765400086, 0.02035671382743333, 0.01093753073031881, 0.025520160062504665, 0.029348234113837992, 0.030444848484226635, 0.02539313830701368, 0.0174929432105273, 0.038754293495523076, 0.06057874472545726, 0.04486292374453374, 0.02220282780139574, 0.01461010067058461, 0.06685853882559709, 0.03756738307752779, 0.05123581624190722, 0.05407845388565745, 0.026590345493916954, 0.002350891865457275, 0.035213955611522706, 0.026775136024558117, 0.007679333644253867, 0.05442029643537743, 0.026619125556732928, 0.027687541708084087, 0.020633871633825556, 0.03675212325262172, 0.029897894976394515, 0.01900978449599019, 0.03468720209119575, 0.03260140579992107, 0.010029009659774601, 0.018482357529657226, 0.03183800979916539, 0.03856333677789994, 0.031122535334101746, 0.02265840639094157, 0.04383635115144508, 0.039067902203117094, 0.052924449023391516, 0.0189749383301075, 0.062095433340540955, 0.07298778636114937, 0.011512245650270155, 0.03408511761309845, 0.04972592994038548, 0.02529010276443192, 0.010065086518547364, 0.01188394204447312, 0.031181113262261664, 0.05063090905813234, 0.06802129678960357, 0.05828457032995565, 0.060271924760724814, 0.00306705101476317, 0.04638288629108241, 0.011712672172247298, 0.022762223945132325, 0.030626326067639247, 0.06459284933017832, 0.017860814363562634, 0.01324566513566034, 0.021292177827230523, 0.04039826510207994, 0.03690833219193986, 0.01702270996091621, 0.02957653400621244, 0.017402063622804623, 0.03238506169457521, 0.026614542052681957, 0.059434612547712665, 0.0042779181718028015, 0.02695139397733978, 0.027499753748998046, 0.020017710946766392, 0.035039039461740425, 0.04111706099605986, 0.028291914545531784, 0.06592429109982081, 0.022780437521370392, 0.026230165535317998, 0.015058539375396711, 0.0375174293294549, 0.0331676330949579, 0.034413253755441735, 0.04011133299874408, 0.06175527695034232, 0.02228790252203388, 0.0496745614467987, 0.016454179039491073, 0.01795910864270159, 0.028011413257835165, 0.03401781033192362, 0.06044627433376653, 0.016859386581927538, 0.045358535900179825, 0.05408119177445769, 0.03825438282053385, 0.023819907368826013, 0.01918676508856671, 0.01296298744689141, 0.011660387656385345, 0.04139277013018727, 0.02986481300156031, 0.030158866329916885, 0.01875252981803247, 0.025099889042654207, 0.07593904049800974, 0.05910520415220942, 0.04058360354974866, 0.02761218191257545, 0.017081857858491794, 0.01874483692725854, 0.025083585542493632, 0.11469846032559872, 0.04086941607030375, 0.05461515812203288, 0.012621898071042128, 0.03499561661322202, 0.05848346251462187, 0.014501088930826102, 0.07416284616504397, 0.009343249091346349, 0.0860033840207117, 0.030427606909402778, 0.05423892402489271, 0.10731534114373581, 0.02394048304163984, 0.024632944991546016, 0.055011035807962926, 0.020952601584472826, 0.022068532150504843, 0.06948014029434749, 0.022223943811176077, 0.144273969743933, 0.0710702667544995, 0.01282337462596063, 0.033471681244139156, 0.01933313357377691, 0.011108777701987751, 0.05355609727225133, 0.023534900608605573, 0.027927103585430553, 0.009088199652199234, 0.027249739039689302, 0.04252645965399487, 0.026236131554469466, 0.02732333803682455, 0.04395841281594975, 0.045485415163316896, 0.01221553108189255, 0.03913460558812533, 0.07784058739032064, 0.00894445794567998, 0.015007929144693273, 0.044669293598937135, 0.03794084535911679, 0.05386148892076952, 0.09744442759879998, 0.03901161093797002, 0.08497972573552813, 0.050075785988675695, 0.04393616704536336, 0.03857834257983735, 0.0327493366120117, 0.028193922214476124, 0.04803644220477768, 0.06262369999395949, 0.08565239142626524, 0.0465758718284113, 0.03100373063768659, 0.07181544748267957, 0.07224223243870906, 0.005400403386114964, 0.10823613352009229, 0.02190025885855513, 0.017117399522768598, 0.010843150750068682, 0.01881000173411199, 0.0026414598562821212, 0.03546550889898624, 0.02611351858026215, 0.04914352297782898, 0.04137440897258265, 0.10673518013209105, 0.06758449665669884, 0.010436114555756961, 0.04034198401495814, 0.02019276449988995, 0.01899247506766447, 0.039003587261374505, 0.04725505145532744, 0.034007391426712275, 0.022886495937460234, 0.020033223953630244, 0.011220064230396279, 0.006670278280840388, 0.02537354391201266, 0.050282695064587254, 0.04289447669205921, 0.06876062176057271, 0.0703458356271897, 0.02431793510913849, 0.062331129264618666, 0.014192106135721718, 0.04791295561673386, 0.009461264990802323, 0.03675918680216585, 0.02507191474017288, 0.02273668727970549, 0.049561687146446536, 0.06727896590850183, 0.014235995477065444, 0.024314272716375332, 0.05012462015396782, 0.026463030272030404, 0.017074224339532, 0.042519141653818746, 0.044908972523574314, 0.020291031637628163, 0.04964403076363461, 0.012274410109966993, 0.02198079417991851, 0.007786109611125929, 0.01999918694075729, 0.021334759292325804, 0.04492363227265222, 0.05835341449294772, 0.052245116726096184, 0.03869911842048168, 0.008984378705333387, 0.0191703292740775, 0.12089956471962587, 0.02425360320402043, 0.05166823643126658, 0.03028668536405478, 0.043617292906024625, 0.08567946497350931, 0.0810467739190374, 0.03173437714576721, 0.03328929103112646, 0.0278973091127617, 0.024145073224125162, 0.01776517485268414, 0.04034478636458516, 0.06647017252232347, 0.1296308854860919, 0.16334916331938334, 0.17327347078493663, 0.07713854791862623, 0.15539206457989557, 0.16453712885933264, 0.17499595907117638, 0.12341146064656121, 0.18238477116184576, 0.11060394932116781, 0.09095618075558118, 0.11508651450276375, 0.07424935259457145, 0.1262541152536869, 0.05088150900389467, 0.2507227063179016, 0.15152582632643835, 0.08244634738990239, 0.09796948478158031, 0.14974959806672164, 0.09378972263740641, 0.10168042672531945, 0.1521474186863218, 0.21538024635187217, 0.20990942205701554, 0.0735711839848331, 0.26478276614631924, 0.14562684643481458, 0.0831814586584057, 0.13674677722156048, 0.06565303994076592, 0.1379849679235901, 0.2342029299054827, 0.08939695478017841, 0.16011191345751286, 0.10114245702113424, 0.22736261838248797, 0.12795419831361088, 0.2530843067382063, 0.11961161025932857, 0.10972836773310389, 0.08115281537175179, 0.08988417006496872, 0.12172169131892067, 0.18126726469823293, 0.21381699666380882, 0.10293520760855504, 0.11476429179310799, 0.05759263424468892, 0.1247032420443637, 0.10981703190399067, 0.3892504344029086, 0.07981519214808941, 0.2258869811360325, 0.118378807125347, 0.17586133549255983, 0.21087132687015192, 0.06230223045817443, 0.1650334500840732, 0.16651758258896215, 0.1658120418765715, 0.08688577131501266, 0.1872684455343655, 0.1566923005240304, 0.2817099078425339, 0.1696736660919019, 0.09250459088278667, 0.1638071337448699, 0.1004921965567129, 0.10860077145376376, 0.349001799843141, 0.08359792988215174, 0.10578627604991198, 0.08223686327359506, 0.130503454378673, 0.11525209061801434, 0.15475770219096116, 0.11132735586059944, 0.12140443548560143, 0.13974135581936153, 0.08206840338451521, 0.07467395266784088, 0.12488061109823839, 0.12147215328046254, 0.10521343643111841, 0.10225610940584115, 0.1806792462510722, 0.10918737854808569, 0.18684356047638825, 0.13512772481356347, 0.1633991984916585, 0.08903686303113188, 0.14683242674384797, 0.11852812554155077, 0.13376647500055178, 0.1361150068363973, 0.2413940168917179, 0.130126134625503, 0.20017468370497227, 0.1329995132982731, 0.13470632742558206, 0.08429169801196881, 0.14757574828607695, 0.11207248230597802, 0.16432980926973478, 0.08801741844841413, 0.11153499436165605, 0.10755375120788813, 0.08850241492369346, 0.1304532563579934, 0.07108661266309874, 0.08648765446352107, 0.12095574741916996, 0.09051180817186832, 0.2125194612890482, 0.18358200549014977, 0.1199408761624779, 0.10785489861986466, 0.09057490514325243, 0.22427539261324064, 0.18665989461754048, 0.11652070683028017, 0.18425056604402407, 0.13630672012056622, 0.10887141193130187, 0.07876091157751423, 0.09516028873622417, 0.08806601512644972, 0.16123536388788903, 0.1245761795767716, 0.10567583769027676, 0.12155357748270035, 0.12451597994991712, 0.16450711047010763, 0.10734224505722523, 0.11645748093724251, 0.13291156158915587, 0.08215402771851846, 0.09967655675219637, 0.13914648416851247, 0.1137935524540288, 0.17243292874523572, 0.10537802188524178, 0.10843469322259937, 0.15252893178590707, 0.11118647163467747, 0.15721732378005981, 0.11770071993981089, 0.14302595385483333, 0.060684691183269024, 0.0988507049956492, 0.12721249168472631, 0.18816538740481648, 0.08436322917363473, 0.08967463845121008, 0.09447966382971831, 0.0984765472156661, 0.10009806949113097, 0.16210481151938438, 0.1813872568309307, 0.057722811188016615, 0.12727035715111665, 0.17596405212368282, 0.19791209511458874, 0.11534547060728073, 0.16461353190243244, 0.07622099893965892, 0.14969914220273495, 0.1349882994379316, 0.10004372562148742, 0.14154837599822453, 0.11590988960649286, 0.11370380941246237, 0.154201832732984, 0.15698708327753202], [0.06249611505440303, 0.014271157161731805, 0.01279251994232514, 0.037049318198114634, 0.017775634469996606, 0.028269519497241293, 0.062329351502869806, 0.03949363203719258, 0.019384905795699785, 0.03343789359288556, 0.03743621547307287, 0.022769730238776122, 0.02301167886305068, 0.06401340078030314, 0.00896943312337888, 0.011377672648190387, 0.08495485742709466, 0.0482014008531613, 0.08912949663187776, 0.06582006133560624, 0.06627538547452007, 0.028687127267143557, 0.04455709783360362, 0.047023664228618145, 0.01366334075906447, 0.02012017143091985, 0.04594380967319012, 0.05049015375386391, 0.01945339372780706, 0.005933937591700149, 0.02122101646714977, 0.033683228106903176, 0.026851125161296556, 0.05889960804155894, 0.028412871894293597, 0.012066342435511095, 0.02622659644111991, 0.02214913532537009, 0.03376587027949946, 0.01142009296121874, 0.028688860924116204, 0.024825937314225093, 0.03069740261084267, 0.024000236531719565, 0.023867021447845867, 0.010608757613226771, 0.01124926668126136, 0.03465552129117506, 0.024735559842416217, 0.010250207835010119, 0.04245443655444043, 0.04226391749190433, 0.02532154438085854, 0.019020812386380773, 0.008615400692048882, 0.017243964963459542, 0.03329689062333532, 0.012597609061880835, 0.02537050237879157, 0.049460344548736296, 0.031118871245001043, 0.009277326021609562, 0.029045770343925272, 0.050926438200154474, 0.029641849787107537, 0.06205619366041251, 0.05897703567253692, 0.07913274876773357, 0.06950760060655219, 0.03573098233235734, 0.021762689276199256, 0.05737749793167625, 0.04552341312436121, 0.020104141041104282, 0.0736576361315591, 0.012381838318625731, 0.08551315604043858, 0.05164173285343817, 0.031198819633573294, 0.048946544261915345, 0.01123760690513466, 0.06322207967085497, 0.032795924826392105, 0.0034832790261134505, 0.02228051157934325, 0.03851784100489957, 0.021539617496143495, 0.057069673735116205, 0.01108888305524098, 0.02963903725945524, 0.056905929664415975, 0.022516448383352587, 0.041121010069868395, 0.04600599401497415, 0.014881555390145098, 0.042726159295333285, 0.023862499011946574, 0.05406030646658369, 0.02986898259924991, 0.04785880512957062, 0.020158797036856413, 0.0187642871335681, 0.01932004463326718, 0.05904909609151738, 0.0089944871807737, 0.05526051617094448, 0.04864869453012943, 0.04156511802492397, 0.007732317051185029, 0.10339662499193635, 0.039231262901531797, 0.0413373338191637, 0.01766764392544116, 0.02544604877143034, 0.02667932857626251, 0.02958933117666415, 0.019636274182370732, 0.02552168506995908, 0.019411879259028604, 0.041190224034445624, 0.04226180724799633, 0.004660309974237212, 0.04150522713150297, 0.03873563038983515, 0.007499466733341771, 0.0053517358859867924, 0.01887043545554791, 0.018768560207848037, 0.08853769195931298, 0.07733684299247605, 0.011327025098060923, 0.08108980660992009, 0.051142270011561256, 0.025732850256775106, 0.01494308833831123, 0.026189015779112066, 0.035112562123686075, 0.017437466187402606, 0.019900818022766283, 0.017739829873400073, 0.04933087667450309, 0.016095398559368083, 0.03632042231038213, 0.06021658344460385, 0.0083868794276246, 0.0342853024069752, 0.018761591653206518, 0.0247636562812009, 0.07838542386889458, 0.03537467002336468, 0.04618117479341371, 0.0018342756583089276, 0.04079697567171284, 0.013257125592125314, 0.01851703066911016, 0.04330617102927395, 0.026733784404184138, 0.02933235639440162, 0.03798212742965136, 0.0365306867419609, 0.07605034059711865, 0.05380138089614255, 0.07257863653025456, 0.026414986600035002, 0.04138716882360833, 0.032610274252614806, 0.054869795351156166, 0.028446118413869823, 0.03679787686892918, 0.019091736259205, 0.04349689704499074, 0.025582461451579417, 0.02117311698384583, 0.08651703502982855, 0.017505496108372296, 0.02751542621159128, 0.1580939774534532, 0.01277206720052553, 0.022478657375488962, 0.03276390815153718, 0.012290063912847211, 0.045429385134152005, 0.05009583330580166, 0.012278418555589659, 0.0422398328914174, 0.04507077598412122, 0.057583514734038284, 0.01787960808724165, 0.008530944286446487, 0.10484262382877724, 0.05691248092002102, 0.0344237608702055, 0.02731769601814449, 0.01758989059765424, 0.09182860037045819, 0.006421545578632504, 0.05351433004917843, 0.03865133259179337, 0.06914412296776261, 0.05293803668713995, 0.03983349326465811, 0.018990641326776574, 0.020991944741191607, 0.06682092084416322, 0.0590656523459724, 0.048356951613511355, 0.05956981065017836, 0.018206042803025672, 0.05430008717147367, 0.06796145678630897, 0.0389356659060078, 0.058206464163959026, 0.04447841152016606, 0.03388296506766762, 0.038157891748206954, 0.06262640056333371, 0.044224313726382594, 0.01032043875394655, 0.01263594629043447, 0.04032877633082015, 0.023149884571986537, 0.0562734569955085, 0.04318256230492677, 0.0132744774288897, 0.034385674699608765, 0.0384010515574898, 0.026770640730059574, 0.017272709403187037, 0.006225191114936024, 0.012157131269175028, 0.04012562294623681, 0.05757752326982362, 0.02545118358518396, 0.07339383528700896, 0.06542043135102306, 0.025383523465799432, 0.0336122804853533, 0.029307538976094553, 0.016248113043340187, 0.0033307106392125464, 0.038450761032955985, 0.01602810145621853, 0.053221019716667275, 0.038038408516773155, 0.07554934426609959, 0.03444598289206624, 0.06796316669455596, 0.024463404535448978, 0.05345320761469858, 0.026489391357504895, 0.027035525534301996, 0.04900772437187178, 0.04218841690037932, 0.017991277987935712, 0.12917210081858294, 0.030817299748637846, 0.03775727449517165, 0.05519170932737844, 0.043845355311142545, 0.04878830650289144, 0.014809810489948307, 0.005529603239015809, 0.008333272616645055, 0.0636862451210618, 0.029454448592982123, 0.035675023549369404, 0.05086819953950388, 0.02484641210841281, 0.0893224041376795, 0.031042217143944333, 0.05256925290450454, 0.032776491583458016, 0.07394447323999234, 0.025773699761235287, 0.06540902517735958, 0.03717482342783894, 0.0598417946270534, 0.029358096620334045, 0.06144171913287469, 0.027494042180478573, 0.009541656971643013, 0.05448791923533593, 0.03539782503087606, 0.023901859132040824, 0.0711556128891451, 0.04195937401215945, 0.012224719294213822, 0.01789015591410654, 0.03563218084829194, 0.06404749037964003, 0.03483802006979074, 0.045950445745672495, 0.022170921388481344, 0.030510724056512117, 0.057212939618953636, 0.08637851889112166, 0.0650741138628551, 0.0381933621663068, 0.06711798347532749, 0.04792931509603347, 0.040739951588745625, 0.02589300657356424, 0.08072088712028094, 0.0298047762231103, 0.03399338307125228, 0.017125942278653383, 0.024348063760304024, 0.06237818566816194, 0.0055436005682817525, 0.011352817062288523, 0.022557079060269252, 0.042221125680953264, 0.035577389145536084, 0.017252991175545112, 0.01588433006379221, 0.034663731564900706, 0.007344109355472028, 0.04156307224184275, 0.03626572899520397, 0.057868390876267634, 0.03253861416929534, 0.04911254106887749, 0.030142992003155605, 0.0319469452037343, 0.011040383068445538, 0.04080524701359017, 0.0246426921470889, 0.07116477311189685, 0.028033267174448286, 0.019726907801149145, 0.02179493834929807, 0.022905959714470164, 0.05260545953309961, 0.04123827788446631, 0.04514144879898854, 0.04580975490223084, 0.05688133616266506, 0.008585545999397124, 0.03410748891266329, 0.019605551813063875, 0.009162263445822256, 0.014403040620631405, 0.04786556673103145, 0.02418025696117963, 0.028440951369702816, 0.03200558420004589, 0.051955175319952626, 0.06448596649404083, 0.01092170474917761, 0.020638802887073586, 0.06834630827818598, 0.06393975937472922, 0.23194595958505357, 0.06918745421405349, 0.07802687239434038, 0.12476899208767073, 0.09875379662428584, 0.15016435938222067, 0.11798056135220186, 0.12922687216528825, 0.15437504915254457, 0.060398614034056664, 0.15637891234031745, 0.10324767298464264, 0.10076398375843253, 0.17932429324303353, 0.08196365114833627, 0.0958696903128709, 0.12702510745397635, 0.17445361960147107, 0.11557296982833318, 0.07542485344622817, 0.1629376182598727, 0.10909538277025733, 0.2003635335713625, 0.13529357234282152, 0.10056600081069128, 0.09201054953570877, 0.09822558425366879, 0.24166448095015117, 0.09788833877870015, 0.07919011211821012, 0.1051032016319888, 0.13759367034903594, 0.08921664088432278, 0.18133266190333025, 0.27346231469086235, 0.23785743809172086, 0.13199929839798383, 0.08920393870877368, 0.17784978236470902, 0.17989428980009897, 0.08870967344513961, 0.07915191738201038, 0.1732177494892052, 0.10584751383534499, 0.12000396634851183, 0.10256741448704686, 0.16665037189211163, 0.18155994399317674, 0.18875206235264028, 0.10834420379251242, 0.11612924640732152, 0.0907567118161491, 0.058306344518704076, 0.10224799412701811, 0.07292865203427416, 0.136853442926492, 0.14613914037389414, 0.14831585357231752, 0.3332528663533074, 0.1302799449435302, 0.1463047300598451, 0.059823039919137955, 0.04618698644584843, 0.12334340358419077, 0.08371223589139325, 0.13758624717593193, 0.27081209261502537, 0.15348844815577778, 0.2102716647620712, 0.08738126472703048, 0.1550424697675875, 0.16369558258780412, 0.13661264441907406, 0.08887165332479136, 0.2160907539405993, 0.10440053790807724, 0.14018139934965543, 0.15523396592055047, 0.18481258302927017, 0.12406444203640733, 0.10451662167906761, 0.1328281017818621, 0.1263408184583698, 0.161780892472182, 0.16767181136778422, 0.09079465549439192, 0.11067065609885113, 0.12041975903723921, 0.08759909482406718, 0.09887351734297616, 0.16059656387993268, 0.14937637666506426, 0.16182897346360342, 0.13780252342777594, 0.10315030999481678, 0.09682167494403464, 0.18149130339069025, 0.07002948224544525, 0.1415298655629158, 0.1738234098468508, 0.10837802197784185, 0.0710097278601357, 0.14791236950882844, 0.10551849220480237, 0.10918139386922121, 0.16377297629203114, 0.12097020021506719, 0.13242259568401746, 0.12037792056798935, 0.20501050778797694, 0.08626563102006912, 0.10617490019649267, 0.10805244051984378, 0.11349611662860427, 0.06378693293247904, 0.11656416021287441, 0.07098204363137484, 0.10983937606215477, 0.14162753389350005, 0.2199814465961286, 0.10230898085449423, 0.08525134330349309, 0.22140603086778096, 0.14905730235789502, 0.15915011720997946, 0.1127998379192182, 0.20047098637691566, 0.08170958728130374, 0.16063496896198817, 0.10815554391592741, 0.09005443485719816, 0.23475930147937366, 0.09506781798388277, 0.10187942747558866, 0.07421440125576087, 0.10947566772145884, 0.14203493988939694, 0.06123319175094366, 0.16479551499443396, 0.10654925475163118, 0.0879729947607432, 0.15777372249535151, 0.15519651078752109, 0.15217293160302298, 0.18743132108024188, 0.11808949336409569, 0.1374692405973162, 0.08460005825119359, 0.22264001465269498, 0.15663375652262143, 0.14409767277538776, 0.10478146746754646, 0.14673695686672414, 0.0876532554892557, 0.23533402064016887, 0.11334284913859197, 0.1406721972993442, 0.08478373089539153, 0.14503543531256063, 0.2029876999024834, 0.22959953120776586, 0.15076090022921562, 0.2188959534146956, 0.07397983169981412, 0.09411660688264029, 0.1256596100117479, 0.1466397770813533, 0.11051501373627357, 0.09787877822028739, 0.119132754525968, 0.15821759296315058, 0.1335586261536394, 0.0937405356339046, 0.1681472879967519, 0.14492969241525444, 0.1048975648092372], [0.07141570214714323, 0.01616168803801494, 0.10659541548894984, 0.016525121572028314, 0.0372582323450063, 0.04717592070145266, 0.06320586268390928, 0.05169148304100547, 0.06196188407817057, 0.057251100428402424, 0.04165294759773782, 0.01765745402579861, 0.05064303787159068, 0.07011286741388695, 0.025497552972020845, 0.016119623955871378, 0.033138948027044535, 0.01838541862421802, 0.06387487785624606, 0.04692545646269407, 0.07241597133023397, 0.037819794711789916, 0.013648351072333753, 0.014159114066777485, 0.034265981122319183, 0.026543509614254748, 0.0724872989313943, 0.02370273963814335, 0.0235625729630036, 0.001881557038619316, 0.011131685044217323, 0.009388819503198777, 0.00993819029203483, 0.033403810778898854, 0.035582590116454024, 0.07055176421999931, 0.07658094819635153, 0.04747675937999572, 0.04618553777358361, 0.04514278890565038, 0.11157515006405966, 0.029739630075969865, 0.014472091736804162, 0.06586289046598331, 0.04692435723596385, 0.04895751278049179, 0.022592803929001093, 0.021645926970190237, 0.03869723887848003, 0.08803940976836852, 0.04449769548539605, 0.061940720570938926, 0.09198386275342532, 0.023390113109988824, 0.013583375407116753, 0.009790207741649022, 0.014119781936252756, 0.03768275099407349, 0.02663432983016329, 0.014345170065228428, 0.022425521298178604, 0.025388101880837764, 0.0750578474253416, 0.060932906078440804, 0.033303011009203534, 0.025004164714898382, 0.03647618680926306, 0.04788821962262903, 0.05515935677768929, 0.011869875165367765, 0.041807897854596376, 0.029258430004119873, 0.029048328420945575, 0.086237573597048, 0.06945701582091195, 0.03234212399859514, 0.02250864353430058, 0.04760973188760025, 0.03456487240535872, 0.030461730435490608, 0.03753599065489002, 0.03793270293889301, 0.07861936917262417, 0.02467360280986343, 0.06105077439653022, 0.08662661164999008, 0.03486288159287401, 0.07241828513464757, 0.027184608159586787, 0.04227819726137178, 0.06582721988005297, 0.048387967449213774, 0.040696196258068085, 0.01836831445273544, 0.010092705438312675, 0.03929921818364944, 0.05218977540997522, 0.015536446856068713, 0.047717978579125235, 0.036855640555066724, 0.016815936592008387, 0.021096688495682817, 0.06840480478214366, 0.02636597940831312, 0.02738879800641111, 0.014745677056323205, 0.043054210620799234, 0.06184242120278733, 0.030132128657507043, 0.04980512176241193, 0.040130179308887036, 0.015622139043573822, 0.08017779447670494, 0.012969996713634049, 0.020053668213742118, 0.05069587878616793, 0.03831792423235519, 0.023224996702213372, 0.07125316586877618, 0.01103063506473388, 0.04706581821665168, 0.03945558997137206, 0.0232430813567979, 0.03372947366109916, 0.0526461309221174, 0.04205727643732514, 0.01612354758461671, 0.08566577892218318, 0.05006076322336282, 0.0671706377927746, 0.02217492474509137, 0.011445861176720687, 0.03253268716590745, 0.004014321735927037, 0.04999971203505993, 0.028570130866553103, 0.03945106075012258, 0.011759348596180124, 0.03322837215715221, 0.008788681572436221, 0.060330875883144994, 0.033844858541020324, 0.052514006583286185, 0.018433536935065473, 0.04342508429129209, 0.03905073865982039, 0.06919128115155868, 0.022291140830410377, 0.036831976646291356, 0.026534537684970667, 0.04716103025046842, 0.004266559495590627, 0.03722242944474731, 0.024882501689717174, 0.05451969163758414, 0.03498949622735381, 0.021223918900692036, 0.022539396437683275, 0.009876910098163145, 0.028796771740806953, 0.013536515778728893, 0.01144029464506145, 0.041179286049945016, 0.022127225429617932, 0.011524895239355308, 0.024412242995042886, 0.03219523134508303, 0.027867921761104038, 0.009196215641817876, 0.02517339474122439, 0.08838087573115315, 0.03806081374308892, 0.040075906685420444, 0.0394501481205225, 0.017540255761040107, 0.0360942699813417, 0.0783204473555088, 0.028911430588258163, 0.04698657889717391, 0.03429409622081688, 0.02078424008297069, 0.0220630071791155, 0.05871876488838877, 0.043366689567587206, 0.02627492679416069, 0.02388045304854001, 0.014900408485638244, 0.009736665391496249, 0.024792556783982685, 0.11797264963388443, 0.03857487526589206, 0.03553633777690785, 0.05645958932914904, 0.009344366129620798, 0.003554457561611863, 0.021776239620521665, 0.04322082150195326, 0.0196281809559358, 0.008475736980991704, 0.11560838935630662, 0.025773643782096248, 0.036930306548518796, 0.0406049163346844, 0.04779675988746541, 0.06724169397992746, 0.05476583021559885, 0.028365165793469975, 0.08619038148650102, 0.04814734196822558, 0.043358791419970136, 0.04253832044612084, 0.03382331505417824, 0.06571110896766186, 0.028036105147163783, 0.03845866935859833, 0.07901788635977677, 0.03123007295653224, 0.027706511850867952, 0.08394578764481203, 0.03410896472632885, 0.057710393997175355, 0.08065679270241942, 0.047319057663636546, 0.021987959509715438, 0.062058052846363614, 0.004142122534436307, 0.011176212208478578, 0.07042375858873129, 0.014272602441321527, 0.05744792308126177, 0.0071931548217045406, 0.017060260088848214, 0.052233072729515176, 0.04910543680723224, 0.042320049301322014, 0.07050704876227037, 0.03412799084825175, 0.017170084374291555, 0.033234506113720794, 0.008499037025363317, 0.03376682022852557, 0.029966328625700304, 0.015525717521086335, 0.008409303313653384, 0.023015563476032445, 0.0045263599521214405, 0.03625124905790601, 0.012509329111448355, 0.027991572893889885, 0.04489075046564851, 0.01506122637407056, 0.040461884545428414, 0.04020767479336687, 0.027711280255711505, 0.053260717407933304, 0.022925710172525475, 0.04365920601412654, 0.054582971813423295, 0.0463179810238736, 0.016292219515889883, 0.017762979791898812, 0.04721883464870708, 0.011508528126536735, 0.033281725365668535, 0.036272914681051455, 0.04357369703107646, 0.05569684811468635, 0.049664729474378486, 0.07604336525712695, 0.011571885485734259, 0.023588501482403705, 0.043232587299176624, 0.026756791830328957, 0.00837077948796962, 0.037281967499958615, 0.029805447972778763, 0.03518610853435738, 0.030762107710220983, 0.06567582514669214, 0.0433394803133394, 0.060824048705399036, 0.028214927962315933, 0.01123819129341947, 0.020065313570999672, 0.041610284708440304, 0.03238595396812473, 0.04401553189381957, 0.03173551708459854, 0.013417987585333841, 0.012891111080534756, 0.018885495540286814, 0.05710828916302749, 0.05336938818384494, 0.057349406581904204, 0.007482766290195286, 0.012849082621479673, 0.005426864555504705, 0.03307100631562727, 0.03747837285378149, 0.0203632294599499, 0.012644578952209225, 0.03413848439231515, 0.026883847512570874, 0.005228164481065635, 0.05979847016611269, 0.024255392840132117, 0.01171918017124491, 0.019184459765840853, 0.05095619196072221, 0.0062495662132278085, 0.06833487496312175, 0.05870064121804067, 0.03440673642658761, 0.020116673582898717, 0.023626189013676982, 0.00798858530885939, 0.03415023322616305, 0.05152795270883611, 0.03990867155204926, 0.05470734388966646, 0.045111762891922674, 0.03771913404177342, 0.03277234573449407, 0.01887098337257547, 0.020517446898988316, 0.017788141566727842, 0.0802262554477368, 0.042383566964417696, 0.028532950540206263, 0.023959556661014045, 0.03486030315980315, 0.035086967782782655, 0.026615179875599485, 0.03358164802193642, 0.01337935689038464, 0.037689641517187865, 0.03203383839822241, 0.056527527647891214, 0.015186485634850604, 0.028442705382726023, 0.026870953650879006, 0.030593729245343378, 0.005996193179661142, 0.028136716623391424, 0.02515583425494177, 0.07218784107161419, 0.05421182333624788, 0.05568665651870625, 0.036965753217892985, 0.0291721169570727, 0.02406785254632788, 0.03923269461042114, 0.14950060285627842, 0.11870138267321245, 0.24901296091931208, 0.14046681831989968, 0.09915362338402442, 0.10332105654690947, 0.1370151513921363, 0.16424637660384178, 0.0882284292685134, 0.08500844812286751, 0.15388929950339453, 0.10232161517654147, 0.15864840841719083, 0.19153335025267942, 0.11566074511834554, 0.13571601467473166, 0.11186151219797985, 0.09243087483836071, 0.10244257082896573, 0.18217730229454382, 0.14744354252304348, 0.0781037232705525, 0.06807585100510291, 0.1883913395660264, 0.07641533136899982, 0.17650739582521574, 0.15399284394724028, 0.08841697379414525, 0.12431202589401177, 0.12304020699645792, 0.09511724925999131, 0.16073087310152395, 0.202604653313756, 0.1116303556731769, 0.1339663171342441, 0.21055366391582148, 0.08973808147545372, 0.18586860064949307, 0.1757857602621828, 0.1649550792894193, 0.13381200470030308, 0.11749942574117865, 0.2140215342598302, 0.13008779739694937, 0.16348145050661905, 0.09943979552813939, 0.09160728938877583, 0.12578956303851946, 0.09842013381421566, 0.1552078423223325, 0.12169947608241014, 0.2180158527834075, 0.09888267756572791, 0.10138715710490942, 0.05552484627280917, 0.09441459232142993, 0.11448508820363454, 0.10077904045049633, 0.14647717294948442, 0.1490036573793207, 0.11883954597370965, 0.07956919606242861, 0.20009486084537847, 0.15974391677549907, 0.17267754061945847, 0.10924596326159579, 0.10772740867521081, 0.07957779988646507, 0.20537170554910386, 0.09936904468174491, 0.14938409839357647, 0.12941099942794868, 0.11417904176882335, 0.189021997153759, 0.14087992400995322, 0.12257652330611433, 0.15932785267276423, 0.15134851155536516, 0.14189034407692297, 0.1283401490322181, 0.11453819035419396, 0.10869644489139318, 0.10665299597063235, 0.11881104750292641, 0.1945890105728592, 0.14730592205056123, 0.22760288763259137, 0.07813674756991011, 0.2021526675671339, 0.15175409907741205, 0.12700794051800454, 0.16267351885991438, 0.08803487715444394, 0.15205038817865507, 0.09855422590460096, 0.12064404200230326, 0.14195863184119972, 0.12508896206106457, 0.11892323648290974, 0.1283651598330055, 0.14299467339047364, 0.13556957324700697, 0.18643136402325972, 0.1377346563552107, 0.12591425063354628, 0.14814932750804083, 0.14066831607903751, 0.0876125366027866, 0.062443915355418406, 0.17455930821597576, 0.12760786046939238, 0.0770684823926006, 0.2115565115319831, 0.08505205756851605, 0.13450041918882302, 0.12131621236247675, 0.10751193309468882, 0.10827937655683074, 0.14571477100253105, 0.19039041229656764, 0.11483507656625339, 0.11083846459431307, 0.08975060723189797, 0.0926810506997364, 0.09264683217874595, 0.1349459181406668, 0.18305918068758079, 0.13639317905264242, 0.169256434908935, 0.10527892184576818, 0.11916316646550383, 0.11572490738970892, 0.22969270763652666, 0.11886771874768393, 0.11438234443111078, 0.14655919426253863, 0.2203312042568411, 0.11838680026786667, 0.12891013201858315, 0.19055134723229067, 0.11192418847765241, 0.1322250198572874, 0.18324401362666062, 0.1739500787641321, 0.10698713375521557, 0.07168507376419646, 0.18765603830771788, 0.09758461293365274, 0.13469412736594677, 0.10106986055948905, 0.13376819847949914, 0.11019606156540768, 0.11250120787216084, 0.12846284173429012, 0.10182360439960446, 0.08173608407378197, 0.0689843754683222, 0.12440547373678003, 0.10187370064003126, 0.0669819779161896, 0.1539839958505971, 0.14473928191832133, 0.15020781276481493, 0.10041326257799353, 0.11961296732936587, 0.0915530337286847, 0.11213490074234349, 0.10409622173756361, 0.09035290884120123, 0.11925303164337363, 0.17464316157358034, 0.1618040440870183, 0.1211967630577939, 0.10444452733333622, 0.07106494025460311, 0.08860067357974392], [0.02606665895187429, 0.017778994914676462, 0.01348630418734891, 0.07668942558978285, 0.0522776423022151, 0.005771065014414489, 0.04430539866111108, 0.08913782904190676, 0.06848793210727827, 0.026784883180101002, 0.02525377569587103, 0.048969441426119635, 0.04725762649572321, 0.06884150313479559, 0.0703965900465846, 0.02989884831809572, 0.008949403617797154, 0.0268685736893011, 0.009645255698290254, 0.02943906281143427, 0.044231217820197344, 0.02980956668034196, 0.06020805425941944, 0.0214828851832343, 0.010067715841744627, 0.08698908505695206, 0.04586197156459093, 0.025200261335287775, 0.020932250622926012, 0.030144403355994394, 0.039159178733825684, 0.003511313548577683, 0.035843388443546634, 0.03963950688817671, 0.03082136417339955, 0.06285859524671521, 0.017091783129477074, 0.04167126804324133, 0.029853844482983862, 0.014464227515938026, 0.04047045444271394, 0.0362169151859624, 0.03662726602384022, 0.0288774258057986, 0.008959515485912561, 0.03238528221845627, 0.0252099626897169, 0.019621271773108413, 0.05760053239230599, 0.060071322667811594, 0.09401209213371788, 0.04042632931045123, 0.030615924125803367, 0.033118897317243476, 0.024744036441136683, 0.03976978561175721, 0.07972662297210523, 0.04808923222922853, 0.009556068207270332, 0.02543419476465455, 0.0774610216862389, 0.010259094099248094, 0.06187207318310227, 0.04185463873935597, 0.0023829585822698262, 0.03960365309779133, 0.014400177202852709, 0.024258490352492248, 0.029993934822934012, 0.061215929820069244, 0.032446883020124266, 0.01948971570735531, 0.0352206391814564, 0.018668739224917123, 0.02998969397906746, 0.03498810523056558, 0.06698650374476399, 0.06800415699503251, 0.08144486362912826, 0.054965275406305275, 0.05255195365420409, 0.07316682461116995, 0.024323086886267577, 0.018158927027668272, 0.028088610186906796, 0.0704420722488846, 0.02602677296714059, 0.0589769949604358, 0.04407784854993224, 0.020742109843662808, 0.0369870320760778, 0.03662588181240218, 0.027681239814098393, 0.03181211690285376, 0.025855179942612137, 0.039608592832727094, 0.028047468912388598, 0.06087151222995349, 0.05675506418836968, 0.05869890416839293, 0.0037450807368648903, 0.07950943748333625, 0.026846962348957146, 0.01667616855619209, 0.06394277885556221, 0.11803470844669, 0.05412761374775853, 0.01154232765215316, 0.013350594639112907, 0.07779496269566671, 0.03524235908740333, 0.056672683251755576, 0.028191386189843928, 0.019837615878454277, 0.013277383255107062, 0.0060373085850317565, 0.028625041312937225, 0.03383666183799505, 0.09636746360255138, 0.05188278241881302, 0.009150529030843504, 0.07100888647671257, 0.02853950179581131, 0.029047385257269655, 0.02782107570341655, 0.034029630411948474, 0.010132876407754208, 0.038298440099294694, 0.09689099408153977, 0.07809814571269921, 0.05093688763944166, 0.0729062400226082, 0.037914026262504716, 0.04261811616431389, 0.03617332609636443, 0.04330187590260591, 0.055989364561225684, 0.037094121865395985, 0.08216054165469748, 0.04607621221137898, 0.005438723651293133, 0.0801969902323825, 0.008544960275425442, 0.06248301932854312, 0.029824158575917994, 0.016355704948572174, 0.052550990134477615, 0.06583439199520008, 0.06852319557219744, 0.026774840861825005, 0.0311212529029165, 0.043299205867307525, 0.059646200122577805, 0.029097413644194603, 0.024383279727771878, 0.027536798368341157, 0.0323553452534335, 0.08604378399572202, 0.005852805159520358, 0.02469593339732715, 0.03225474565156868, 0.011155326052435806, 0.014152909712200719, 0.02564240662780191, 0.07159151057047503, 0.030678057577461004, 0.0685010753305895, 0.04750921031726258, 0.01158207792988313, 0.033541404109980376, 0.013425043501359011, 0.044003694850419245, 0.047493953457368274, 0.01939695488129343, 0.01894698099100164, 0.033698064275085926, 0.0320591952518693, 0.03302740704800401, 0.010912949102930725, 0.04928244284487196, 0.022868222989408032, 0.05697887896427086, 0.04549407327015485, 0.03357398057622569, 0.015489115645842893, 0.04865991410666278, 0.023733746992158036, 0.0420998171903193, 0.015601535327732563, 0.01882968603500298, 0.03437139153746622, 0.014435337191181523, 0.02525102423637041, 0.025350181951320598, 0.013922737911343575, 0.020828570472076535, 0.045728144102862904, 0.014132752981302994, 0.03917480878798025, 0.04125085113836186, 0.02966529317200184, 0.03788471694237419, 0.014679569085793836, 0.04424574186227151, 0.008686275371084256, 0.01087269077210554, 0.005377802656896944, 0.039799875247159174, 0.024564740347809026, 0.04476842077981148, 0.021365939672770243, 0.033093319939715524, 0.0478644369702254, 0.0870747161763055, 0.03532107932759183, 0.01633416485440518, 0.023013965526063527, 0.027009729329230528, 0.0480589729600719, 0.04514648013615182, 0.016968605274866735, 0.027499697769859006, 0.030779868364334106, 0.01555688602716795, 0.041379806718655994, 0.04893494809844664, 0.057034695254904885, 0.023109247109719684, 0.14752408462975705, 0.0063785116154966605, 0.03349129769152828, 0.015276315189631922, 0.008145528762335224, 0.027228587406820486, 0.025474803389183114, 0.03576022719166108, 0.023844538190002953, 0.07464041946721928, 0.006669815180690161, 0.03760584583505988, 0.09644248921956335, 0.07323895288365227, 0.003696543854727809, 0.022235361859202385, 0.03721900284290314, 0.057020676721419604, 0.01632790536885815, 0.03349558264017105, 0.01612993429547974, 0.01598898900140609, 0.02721466386823782, 0.01877229893580079, 0.05596140891845737, 0.030517214243965488, 0.03692943123834474, 0.04355902371129819, 0.0703763629176787, 0.010616736336877304, 0.07833341415971518, 0.012654879113792308, 0.02693238990780498, 0.05941385616149221, 0.022680769208818674, 0.07574676402977534, 0.06030254704611642, 0.03912757257265704, 0.07914648231651102, 0.008414468661482846, 0.003509426161014874, 0.10444156892065491, 0.023550311835216622, 0.03729945674006428, 0.01313590955188764, 0.04252251736553652, 0.023382973225255097, 0.019573884583743553, 0.023764019832015038, 0.04022660252771207, 0.04569453965606434, 0.05078366086153047, 0.0582743515925748, 0.03493920321177159, 0.05126647923939994, 0.019465632803205932, 0.02395758212410978, 0.10984429544103996, 0.06795645598322153, 0.02168342620799584, 0.013843468057789972, 0.029625432632331337, 0.05845595470496586, 0.06677289413554327, 0.019417818136779324, 0.021676048836005584, 0.06544440399323191, 0.03435298627508538, 0.024925344390794635, 0.10096863670540707, 0.03411016912598695, 0.010091442515009215, 0.02627298279133226, 0.02996172137292368, 0.01825961483908551, 0.06600921654275485, 0.02379485246326242, 0.040195182963673554, 0.022796576476788948, 0.0681709409026163, 0.022883719032896415, 0.020296266535297036, 0.01300392346456647, 0.062351241042571406, 0.029955835081636906, 0.05100609142599361, 0.011798975041269191, 0.11282038395958287, 0.013252465752884746, 0.020136882052091614, 0.026519189222848842, 0.05523639085835644, 0.030932504816779068, 0.012401048493172442, 0.034972193584378274, 0.06268596915262085, 0.01855645694636873, 0.013643420667254498, 0.03484936856797763, 0.06429563063595976, 0.07742887269705534, 0.0169696264700698, 0.04903921518208725, 0.044599893037229776, 0.008131724815549595, 0.04835292450817568, 0.03892098580087934, 0.05234489869326353, 0.021236007002049258, 0.012709023663774133, 0.01791238472131746, 0.018602802584479963, 0.055213731181408675, 0.01087311570466097, 0.02638623028594468, 0.02879763687295573, 0.05672045211706843, 0.01630001588325415, 0.03879628463515213, 0.00788473552425525, 0.03711796558595129, 0.03863305625106607, 0.029291321989148855, 0.018081645281719308, 0.13000219341899666, 0.16936969597424778, 0.1164523105004004, 0.11828687920102052, 0.14277732505330018, 0.14137229616088526, 0.12430519983172417, 0.20557404469166482, 0.11424671885158334, 0.12090786998825413, 0.07855293380894832, 0.14128149460468972, 0.20738801306911878, 0.1421326082199812, 0.10122428155903306, 0.06541447381355933, 0.08087086371545281, 0.11074875547949757, 0.1280734304870878, 0.10666127409785986, 0.11256376201553003, 0.08804599834339959, 0.13480383290776185, 0.13324578079794133, 0.08700492884963751, 0.25939215826136724, 0.21671510115265846, 0.15852183449481214, 0.10136044318122522, 0.1404308152518102, 0.07693545560219459, 0.12301753035613469, 0.1555722834808486, 0.09832724915551287, 0.07580352348408528, 0.16157849904681953, 0.11576048976608685, 0.16235576091068132, 0.12340299252952848, 0.08494049962610006, 0.21785832409347805, 0.10138677033994879, 0.1722356379032135, 0.1586674481098141, 0.0844112898090056, 0.12089166657200881, 0.07960346208087035, 0.12550860882869788, 0.1339063753506967, 0.15651365582432064, 0.19184475711413793, 0.0781791288671749, 0.2530169960643564, 0.1359557682382209, 0.07963728705154997, 0.15641209270272935, 0.20711387135088444, 0.25144971587828224, 0.09342157667768852, 0.1671965111579214, 0.08335214414234672, 0.11590534342186791, 0.19569222708897932, 0.10320058943969862, 0.3215875194541046, 0.13773228148264544, 0.14165022410452366, 0.08544978086969682, 0.10555149614810944, 0.140739467261093, 0.12958547792264394, 0.11806822807661124, 0.10925573416586433, 0.17065889893897943, 0.07808455465627567, 0.12808098936719553, 0.10173063153134924, 0.1643150850598301, 0.15525160783103534, 0.08947495238057204, 0.19702048652938434, 0.117955496268613, 0.11073646721030984, 0.11817481235734054, 0.07940682941781622, 0.1542765258678368, 0.07594835678381578, 0.10002587336514678, 0.17408433370292187, 0.15712960277284893, 0.16627670265734196, 0.09651999827474356, 0.09174482165170567, 0.2096781637519598, 0.06244682627064841, 0.11278199244822774, 0.10019609065992491, 0.13848328404128551, 0.11005696188658476, 0.1119826306988086, 0.1082117266154715, 0.1649959949510438, 0.1609021353402308, 0.17995419087154524, 0.26704568043351173, 0.1781273710408381, 0.13515616900154523, 0.10484295631093637, 0.16500394738146237, 0.26941200345754623, 0.1994632397379194, 0.18202376339052403, 0.09544548378991229, 0.21925009441162857, 0.17309243764196122, 0.1324443630874157, 0.0783866180905274, 0.08674383535981178, 0.14975622056850366, 0.08968209555106503, 0.19468080279018196, 0.19277049601078033, 0.15166263255689824, 0.10842642866607223, 0.11945680928017412, 0.09921250665294272, 0.09842208120971918, 0.19979304846908363, 0.13911365664431027, 0.149874122813344, 0.11490818192916256, 0.131267552663173, 0.09771630301007203, 0.1676991427583354, 0.09890838047223431, 0.17818584718874522, 0.24993137163775309, 0.14566048820103916, 0.1571398622223309, 0.13406437901513918, 0.0805207532165306, 0.15427325532904693, 0.08488379445459161, 0.23570471789155686, 0.1090971062492047, 0.08088288057063307, 0.1286073832639626, 0.14690047023551805, 0.12272698166114943, 0.07644120390926089, 0.12438382846968514, 0.1482603494077921, 0.2128326730536563, 0.1158551996839898, 0.07552402133920363, 0.16372192331722804, 0.11694833316973277, 0.19802840958748544, 0.0667088743565338, 0.09487503939973456, 0.08765055491988148, 0.1200666358428342, 0.07033018182430949, 0.10117388676319804, 0.12482392628278051, 0.12299717430557523, 0.16706844445850166, 0.09095099674803869, 0.1030880001240543, 0.08333330122487885, 0.10888311666037355, 0.08573181395019804, 0.11428029276430607, 0.203305987109031, 0.06131595266716821, 0.08879729267209768], [0.024607705185189843, 0.029629212072385207, 0.060153079352208545, 0.03165207424068025, 0.04323319458801832, 0.036951812715934854, 0.03180417125778539, 0.04595652202676449, 0.03562498837709427, 0.05123578570783138, 0.08206294117761509, 0.0526403599817838, 0.004610909232204514, 0.03164499033508556, 0.010660046378948858, 0.01810525999670582, 0.015462206643340843, 0.018866674675207053, 0.01322192489169538, 0.022310813256938542, 0.026472433071051325, 0.029957884257393222, 0.0423411415623767, 0.1062583192916853, 0.021551856571542363, 0.029441997475389923, 0.031506579369306564, 0.03003414480813912, 0.028718112568770136, 0.04052254557609558, 0.028210525966382453, 0.020814246597832868, 0.030458470074726, 0.040746031262512715, 0.0552150746807456, 0.03484592839543309, 0.0356802957664643, 0.024365103470959833, 0.0173692428839526, 0.03609490441158414, 0.009214014463525797, 0.06255391945264169, 0.017727439823959554, 0.029903031486485685, 0.03550250602087804, 0.03865936305373907, 0.035834041623664756, 0.021840585096340095, 0.03166085109114647, 0.10495559312403202, 0.07844814764601843, 0.02405981529903199, 0.07015803070472819, 0.057266876367586, 0.02932274155318737, 0.030683489250285283, 0.011396782738821847, 0.08200728773538556, 0.03239231523392456, 0.06407425858612571, 0.14593690979693616, 0.02915988297068647, 0.024339560020182813, 0.028215911838092973, 0.03681380208581686, 0.03661809562306319, 0.012829991190561225, 0.01904767898044416, 0.02657404538643147, 0.04019757479961429, 0.03734677777226482, 0.07315944215016705, 0.04225301004147955, 0.02380200761503407, 0.06193473589207445, 0.01228615639930857, 0.01975136898857142, 0.02969517924689821, 0.04113126951935036, 0.03378297953999468, 0.03715206875598856, 0.08470218455685036, 0.016825756690065776, 0.02553102680082832, 0.06660045124590397, 0.02584197565114924, 0.03856523667595216, 0.0025594731061054127, 0.037534450380397696, 0.07175305618771485, 0.027572268786441003, 0.0114874977818025, 0.03209533741963761, 0.06608120232288327, 0.012275035210352923, 0.07036756231848683, 0.058754516898521354, 0.03766190300562552, 0.04720547429418989, 0.017813771530719738, 0.05583255172574094, 0.0421576012325074, 0.03175750161920275, 0.07162999029138259, 0.007003320655452886, 0.02575699083640107, 0.01100273964194847, 0.025634610260437642, 0.05081046978011727, 0.03140305867418647, 0.02861282428992646, 0.030903307454926626, 0.048507026596260924, 0.059011464539383135, 0.04191158479079604, 0.03859908878803253, 0.014586290876780237, 0.08383344260177442, 0.023582169054342166, 0.07673239042716366, 0.04828527456681643, 0.024666206778160164, 0.03815678573612656, 0.039531463757157326, 0.05996360523360116, 0.04430044874815004, 0.03281865914219192, 0.03246256396440523, 0.009501804913660246, 0.03539697686210275, 0.006458682648371905, 0.01565097169285374, 0.08072941630546536, 0.029841352653290545, 0.01641479177799608, 0.05942159824605499, 0.05521062688369836, 0.04601297953299113, 0.0834026610744851, 0.021854832635394165, 0.024929054281009094, 0.010707897516632718, 0.024446276615240743, 0.020714688547221676, 0.03876579127141407, 0.07600584905594587, 0.044707518869212697, 0.03879280375050647, 0.030060685705393553, 0.010369743652907866, 0.04139860213867255, 0.018298074203942503, 0.013696173372279321, 0.010495254819813584, 0.015835114222552096, 0.043049216603061984, 0.04257386550307274, 0.010965482132243258, 0.02827175866280283, 0.030298166176570312, 0.0287958964306329, 0.09485861885228328, 0.02983222296461463, 0.06392040755599737, 0.06468489939080817, 0.041829838284424374, 0.014119848093417074, 0.029096338166190044, 0.027509855439088175, 0.04757860070094466, 0.07659666985273361, 0.02023743076383003, 0.03824052035010286, 0.05422876635566354, 0.10098806994834117, 0.01725028551715825, 0.02077701029234699, 0.0735152048457946, 0.035552079789340496, 0.010645718263861324, 0.02456652150223298, 0.027521120816735283, 0.02829321563643004, 0.022698068459119116, 0.03613642057670014, 0.0211098266299814, 0.05390925100073218, 0.026009612816518972, 0.017986658860796263, 0.010690929052153868, 0.054334631389273066, 0.0142303941704865, 0.05457913809056793, 0.025912641680666378, 0.029154186669204916, 0.023796396130429845, 0.018598543080900396, 0.0692142563472901, 0.02779986639507115, 0.03634561970829964, 0.028954748263848678, 0.016693729042474712, 0.019502336458702172, 0.020373775590477244, 0.0404830751940608, 0.04181643721780606, 0.00942259019107691, 0.03211778675072959, 0.04972983830209289, 0.017198168938713412, 0.050963984935411384, 0.030917797570249865, 0.03493497593860541, 0.05145007045939565, 0.0347029441036284, 0.0337971778852599, 0.012834744328366858, 0.04342081630602479, 0.009891749659020985, 0.05126310692035726, 0.009140741163199502, 0.024802392149077993, 0.022595338257295743, 0.05388689666454281, 0.025936726281153302, 0.03454677587641137, 0.023807863372245004, 0.022717773116060665, 0.004960136787433709, 0.017384883116132448, 0.03535571854029383, 0.008195887935081763, 0.07101532577403954, 0.06328163468944174, 0.010277066795554544, 0.05206787320119994, 0.07009701683585133, 0.11390519860599722, 0.023061956611594985, 0.01281263935379684, 0.055612112661557536, 0.04905268410220742, 0.01847561967692205, 0.06736714831952538, 0.01741529505566827, 0.03508964121075613, 0.05564863820161138, 0.043034536497933526, 0.03674668140177216, 0.02066947945526668, 0.04244387176420007, 0.013344045079845403, 0.03748122609353491, 0.046283833749060116, 0.036526048955108435, 0.05855364339160068, 0.05318851110392383, 0.04440006447423782, 0.018630946520715952, 0.07566864429307835, 0.029254748951643705, 0.01194637150703264, 0.02403453817324979, 0.0452055330388248, 0.024608982527362447, 0.05601227529613035, 0.05382709398067423, 0.048770240508019924, 0.004475223008609776, 0.0585799366235733, 0.03353982651606202, 0.11752340516873769, 0.05665721604600549, 0.05791442947728293, 0.015248541054981095, 0.03401434641065342, 0.049477480950632265, 0.02738770895770618, 0.027737531079245464, 0.013684506810802435, 0.01732016444605376, 0.012745502554545445, 0.03295914303245289, 0.034323096807513914, 0.023629808998001472, 0.045055230746843984, 0.07378944834428174, 0.0232900953519025, 0.05666571808978915, 0.05506254679390362, 0.015021116472780704, 0.04494973212214453, 0.018736718255760412, 0.01832620456947812, 0.023987201874011328, 0.03973912600693958, 0.023080127779394388, 0.03011373696582658, 0.009217377452711974, 0.025321250914462974, 0.06112922661538635, 0.035683908965438604, 0.041501318769795556, 0.022870977841583744, 0.028675802517682314, 0.01670421240851283, 0.01717482054872172, 0.015071531624666281, 0.06220566813967057, 0.01181960929118629, 0.02646714389058096, 0.014147931809670158, 0.06875495599316699, 0.04354191445080297, 0.03594300077695932, 0.03852070442267826, 0.05115683476573654, 0.02318793342315725, 0.020872030640020967, 0.05358672973566821, 0.06326536341969456, 0.03798163549176284, 0.01518514213551368, 0.057264291149164946, 0.022232232116428868, 0.005481244896405509, 0.011563218049039798, 0.003126696151282106, 0.04504390599738274, 0.030023766615028893, 0.04889448705528464, 0.03707634085523231, 0.04424838136349406, 0.011020543552669031, 0.04295982300703015, 0.061323952595038075, 0.004493318265303969, 0.059440827928483486, 0.025140088849834034, 0.05042532991085734, 0.034136774484068155, 0.027891463533576046, 0.01651496729547424, 0.0544353192006903, 0.05049094085448554, 0.03888022620230913, 0.04370560084602662, 0.03314062740121569, 0.07157834699111325, 0.017598618254331604, 0.04653755495590823, 0.04515560643215265, 0.15809718013874122, 0.14558371874902928, 0.2248472754976579, 0.08439966650413615, 0.13812686316668987, 0.12759236272956642, 0.056261691198285134, 0.12198641497109618, 0.21273143562887395, 0.106433978437313, 0.16341939169381345, 0.18419400336486952, 0.1222426840769393, 0.08475338002400738, 0.16814496740698814, 0.09228640794754028, 0.11340725568256207, 0.17200819296496256, 0.06451016305280582, 0.06850251382482903, 0.15808576717972755, 0.09614727898899998, 0.1059960112241762, 0.1431183296122721, 0.09768725492592369, 0.10597001654761178, 0.1322717573493719, 0.18575585527079447, 0.09960463204021965, 0.10074570402503014, 0.11160416422145707, 0.1038772856284465, 0.1295182215315955, 0.14291718469134398, 0.11232751647808722, 0.09753119865698473, 0.1380494830331632, 0.15566095443708555, 0.15995685463505133, 0.09488535991736821, 0.1282426978328398, 0.1307580407176699, 0.08536606321909598, 0.15309734057102883, 0.18970095286411898, 0.16129749055419648, 0.16553772373923234, 0.1836683829980237, 0.09926547988184861, 0.12981957250407763, 0.09266431124082633, 0.1105049035644957, 0.18511852089847836, 0.10963363067380019, 0.09612038186086075, 0.14599037835640566, 0.15260559267231397, 0.1514852906444243, 0.17359888260918005, 0.12339726569397108, 0.19252800116581575, 0.28592754581144875, 0.12097803050918238, 0.14225493451314314, 0.18129110841878823, 0.09627878586096422, 0.11337881827993052, 0.1940297620104892, 0.05713566126567977, 0.10543950394328151, 0.1368763366980212, 0.10064153532896723, 0.1218146506164755, 0.09533175453543663, 0.1488376334309578, 0.06596063343541962, 0.09706279914826155, 0.1500339585223368, 0.13439231498965196, 0.13699820158737047, 0.11859340061034475, 0.10636177552597863, 0.076603305925216, 0.1387600041925907, 0.1726500735219036, 0.13194293927933487, 0.12689040468207427, 0.10163885967007705, 0.11058605635272604, 0.17009169794619083, 0.11050535818295819, 0.2810560172157628, 0.14739375162337506, 0.15384938807359763, 0.09409143323344843, 0.3303655098591532, 0.0991120088313307, 0.1988251454063824, 0.08644591777452401, 0.0970627177240593, 0.1044377623392003, 0.15123716395880493, 0.058289672913295884, 0.12148649751075677, 0.11249484321368591, 0.2029933181724378, 0.1063972357660532, 0.14938084142548697, 0.07427065180880682, 0.15095076789813383, 0.13083208245890482, 0.11016011956546988, 0.1070905832041587, 0.13171655285571301, 0.1199899749564273, 0.15888243514512265, 0.11621084702866417, 0.12034286744892597, 0.13941427479897225, 0.12785871486578668, 0.08684988359787635, 0.1180012295288699, 0.06444222134138856, 0.15098244191280433, 0.16944799891539983, 0.12178790276604039, 0.15867122076451778, 0.13511403197688715, 0.09787385884140219, 0.0762178437518222, 0.10124366730451584, 0.07546866645238229, 0.166758923924395, 0.12888243421912193, 0.09433827748788254, 0.14246513109122003, 0.15796597860753536, 0.1259215245289462, 0.15011034799473627, 0.14001073422176497, 0.0822850867573704, 0.12087820443723883, 0.05320999352261424, 0.10693232169640915, 0.1301224705364023, 0.1861976765628372, 0.15321566350758076, 0.13129734035049165, 0.0996358310803771, 0.08030600366847855, 0.12032164287354265, 0.17730460661862577, 0.1504404688520091, 0.1533084735274315, 0.1458632480353117, 0.1122380109237773, 0.11142494955233165, 0.11114886722394399, 0.11678415483662061, 0.16708497357155594, 0.11522363285933222, 0.19334700650402478, 0.16148142782705172, 0.07815552941922631, 0.1269697118550539, 0.1337666107075555, 0.13944704804037297, 0.14200010390153953, 0.1048303966277412, 0.08190159233553068, 0.15711624920368195, 0.13728207349777222, 0.18967146373220853, 0.13637705706059933, 0.18179272221667425, 0.14602932626647608], [0.043895437980868986, 0.046139600952821117, 0.038968347545181, 0.046777094780866585, 0.06537014512079102, 0.03323612781241536, 0.008319292250754578, 0.05586096537964685, 0.019262710120528936, 0.012806880287826061, 0.025982888714809502, 0.0435227220878005, 0.017776587811697806, 0.03742797127259629, 0.04438277540196266, 0.056178163537489514, 0.05124572624585458, 0.03475192076127444, 0.06277124064841441, 0.04333764487611396, 0.01008506428583392, 0.006991980638953724, 0.058020375935094695, 0.03229824992428933, 0.02972142498141953, 0.02785980817861855, 0.026959202219066874, 0.017554963007569313, 0.07343680690973997, 0.009778533546653177, 0.030801082761692147, 0.021879181864538362, 0.018559973454102874, 0.05756520785923515, 0.052359928243926594, 0.030899178569338152, 0.006057674813616488, 0.025675809210432426, 0.03224902220868638, 0.02712873080080109, 0.04024475673213601, 0.03114724757948092, 0.01328759775164404, 0.045373070120279274, 0.04406543475176607, 0.06188389326312712, 0.037692654212670665, 0.04736309458634683, 0.07758830128503696, 0.09449102929128067, 0.05764625208186252, 0.05396383575030735, 0.03649291269747274, 0.030176599842629263, 0.1437459880752223, 0.06081756191062076, 0.02741645848644631, 0.05881363765469619, 0.039716686853872876, 0.036093024869582484, 0.025412393434505378, 0.07781303208321333, 0.037584543228149414, 0.023126028977068405, 0.012010720375526165, 0.037236990806247504, 0.03740740826885615, 0.03253462777606078, 0.06085036229342222, 0.03130793145724705, 0.02169420982577971, 0.017151268598224436, 0.050998183100351265, 0.05468994625178831, 0.04913331441847341, 0.02957701576607568, 0.03151620778122118, 0.03976343452398266, 0.014947902544268539, 0.028675395396671126, 0.01818114735319146, 0.012189766259065695, 0.02211391257255205, 0.06530336370425564, 0.09205448467816625, 0.06137892071689878, 0.0491342745455248, 0.021141941692414026, 0.006969760737514922, 0.016673530751307095, 0.014045849608789598, 0.006235383559084896, 0.10188605676272086, 0.02509089675731957, 0.04880770921174969, 0.05242563078978232, 0.03464175042297159, 0.015005238753344332, 0.018588967255449722, 0.05848929113043206, 0.017323621581973772, 0.03791616364781346, 0.02042736967892519, 0.03240754834509321, 0.02845932270533272, 0.02373612016838576, 0.027939507205571448, 0.0300439937439348, 0.011327209150684732, 0.020149908228112117, 0.012792016130073794, 0.021225426944770982, 0.04953645582177809, 0.08484721463173628, 0.024844028754159808, 0.05654288289536323, 0.0206384178184505, 0.028316589471484934, 0.015588205507291215, 0.019152855301009755, 0.02635880050781582, 0.04481510738176959, 0.03871028710688863, 0.04375658257465277, 0.04511225822248629, 0.07387685722538403, 0.05979103342230831, 0.03433111709143434, 0.021859365249318734, 0.013186780170404484, 0.029605968855321407, 0.025998537428677082, 0.05564706400036812, 0.09132839792541095, 0.024296936146648865, 0.028785993212035725, 0.03878195058288319, 0.03352104127407074, 0.04504474738080587, 0.01658893609419465, 0.015794559880825024, 0.008278918568976223, 0.07827630865254573, 0.054065446369349957, 0.0765822713396379, 0.017052009103021452, 0.08482744212129287, 0.025988576534603323, 0.02466799132525921, 0.043585208377667835, 0.0140992638854576, 0.01434313106749739, 0.011950272235221096, 0.03742262102397425, 0.015160360340295094, 0.017630221022825156, 0.03772138677803533, 0.0252308734426541, 0.0426903563950743, 0.06259649752506188, 0.037484567878501754, 0.04000883689150214, 0.04438014607876539, 0.047324835389320336, 0.030203917662480047, 0.06749753560870886, 0.022374660009518266, 0.0355529822409153, 0.024149337816717367, 0.05759798110063587, 0.03790447588211723, 0.0180140258744359, 0.031014013835894208, 0.032364111925874434, 0.027767542683120285, 0.038548822913851054, 0.0248723219680999, 0.1138926592788526, 0.010303912185398596, 0.019020094835598553, 0.08444666183952775, 0.05297223145940474, 0.045995218878878016, 0.046337899419346025, 0.07489335018077067, 0.04043519776314497, 0.031501717665897946, 0.04973373309309993, 0.06572852696159057, 0.02677273570692965, 0.035651824437081814, 0.02737391264443951, 0.007722670827726168, 0.0199656978449119, 0.0033706903465956983, 0.08688959825251784, 0.019153898548600928, 0.09574179324720587, 0.003587753911103521, 0.005021523850570832, 0.05050165492243, 0.01675216108560562, 0.04389409787420716, 0.04332097327070577, 0.03291715528549893, 0.014288525961871659, 0.025652917135240774, 0.010599273390003612, 0.04566533550886171, 0.007413630357145199, 0.05484475062361785, 0.016547090839594603, 0.03542925138026476, 0.026324729568191936, 0.022266406532643095, 0.03741504857316613, 0.009179095355128604, 0.03195274667814374, 0.07800739165395498, 0.010677872342057526, 0.02511305092567844, 0.06263832242361136, 0.03330286851684962, 0.027001732794035758, 0.02509706124796399, 0.06983452556388718, 0.016369055125064084, 0.028532326287989105, 0.06281406977879149, 0.015229543770796486, 0.04617720197087952, 0.016309233781482493, 0.035463961839143715, 0.01133708268337484, 0.014711270241865089, 0.04541779575603349, 0.0364416256280882, 0.04029367910698056, 0.0499547930168254, 0.05000839049794844, 0.019274112901517322, 0.03978679309199963, 0.024950506165623665, 0.020375923153811266, 0.05703742975103004, 0.003968781434066061, 0.0446732291020453, 0.040557327281151495, 0.05216680021424379, 0.013730369840881653, 0.031052578373679092, 0.04452290984668902, 0.015016948571428657, 0.004344604169351182, 0.038578030453728776, 0.04320430935227445, 0.04106110221307192, 0.02120965100558741, 0.033833842524992566, 0.029539882937180142, 0.07854403821485383, 0.03310249373316765, 0.035617982503026724, 0.017841469330180968, 0.019397836976817677, 0.09339324784065996, 0.008592609548941255, 0.011031591799110174, 0.03243383139904056, 0.03167768893763423, 0.03752077450709684, 0.05493589823267289, 0.037972091896725554, 0.025447948669482554, 0.01805299922956952, 0.042303649109921286, 0.04321508788104568, 0.011568873638420232, 0.011825554106118423, 0.012968164669083697, 0.03984027182949441, 0.035503788452063284, 0.038142594176211526, 0.016335527013455118, 0.008688593416341713, 0.058144052512943745, 0.042706122156232595, 0.0532999265539859, 0.05943426649485316, 0.02378724099669073, 0.019672107616705552, 0.030419030226767063, 0.03034974162333778, 0.0491023969703487, 0.054452764336019754, 0.057344134364809306, 0.05075903004035354, 0.010715893203658717, 0.04612720411803041, 0.04623814120090433, 0.025912354999621, 0.055353743489831686, 0.020999656291678548, 0.06238743410046611, 0.06480012820767504, 0.03479143864076052, 0.033078487164207866, 0.018985659183402146, 0.046464676902230294, 0.0416715326718986, 0.019033382247601236, 0.06739578928266253, 0.030462001849498068, 0.02185285131313971, 0.012063355185091496, 0.02742327267437109, 0.04828897936801825, 0.02365929982624948, 0.03846032498404384, 0.021918187450085367, 0.00731814606115222, 0.06809585421745266, 0.046382465599370856, 0.015704053487362604, 0.050928144715726376, 0.05726338191223996, 0.01708407497166523, 0.04577270010486245, 0.020693090777578096, 0.09237366755093847, 0.011631997751205094, 0.01753253403252789, 0.03165263403207064, 0.021368831928287233, 0.04626870581081935, 0.044573311427874227, 0.023267257559512342, 0.029954294807144573, 0.05233273256037917, 0.02084960336131709, 0.053477519524416754, 0.02239484981899815, 0.026268151621999483, 0.09616997598537377, 0.02343377174942621, 0.05252889024892023, 0.015991572523489594, 0.02980630292690226, 0.04143889694075499, 0.027811677993408272, 0.032291322081748924, 0.022359713579394987, 0.14874243496784142, 0.2337948318038668, 0.07311780724142279, 0.09936134330928326, 0.11101148423871823, 0.10636891371437482, 0.13424482861799852, 0.2103878435279642, 0.18255194861974033, 0.15062558677579674, 0.10647573548236064, 0.12261829392186233, 0.10938655571745974, 0.1706389364387308, 0.14355187277708734, 0.19284760473029955, 0.08180841590676989, 0.12267020185078893, 0.1585968533264739, 0.15578003733285836, 0.12971289322844573, 0.16698973439633846, 0.1645631438919476, 0.06570883587534938, 0.1414135375193187, 0.1321666929870844, 0.17411208578518458, 0.08506520079182726, 0.2595654289637293, 0.16757919133773871, 0.09097494224884681, 0.06408004648983479, 0.11992664049778666, 0.14792203184749397, 0.1709961308432477, 0.06654085551521607, 0.15076953119465283, 0.07369170537484543, 0.09441896887230021, 0.07619272438543183, 0.10110285093209573, 0.15417143436414854, 0.08253790211996861, 0.12568574718066625, 0.11892920759107385, 0.256219464221171, 0.11236395380858864, 0.1472228965056794, 0.11066864763519593, 0.2561246321669647, 0.22246917310569966, 0.1227725792144026, 0.1135434512315052, 0.05463855740215097, 0.25395294012767927, 0.09979604676898036, 0.06655414123088121, 0.18343605260763848, 0.05038143887317606, 0.10244091520352022, 0.12236316475485053, 0.26676096713968683, 0.09528093904789005, 0.16722951510122844, 0.1089426309668592, 0.08164730455194201, 0.14030828539814266, 0.10738837865314313, 0.11988747545651027, 0.12251734148178782, 0.1943884627627475, 0.11327050373490367, 0.14390277037663118, 0.10685887706599065, 0.102738032117486, 0.12189291284552642, 0.08321332944823162, 0.08324579734887395, 0.12489886369024004, 0.11438420361706189, 0.1728154867887497, 0.08347918625388827, 0.15127301774919033, 0.13644276639180525, 0.13999714995069162, 0.1356882761631693, 0.18155640204037937, 0.07883916023586478, 0.14819104384098733, 0.26158192647354944, 0.0827693979122809, 0.08767846306519848, 0.1618078981659242, 0.10292217295084681, 0.1576911990663835, 0.18224328303975718, 0.209337892010808, 0.12248971153582845, 0.08343085420450994, 0.2079422404723508, 0.10569260429058756, 0.08888675072895628, 0.09053451873894248, 0.13025223357336863, 0.17797030375472137, 0.11313187224524361, 0.21142239230019705, 0.1129803689462798, 0.1116316584604127, 0.19906434257115635, 0.1089169280603528, 0.14612186487231935, 0.10499987431934901, 0.16290396292294773, 0.08344182611576148, 0.13310480836246694, 0.15910789876111917, 0.18099429006023066, 0.08883507350193602, 0.1880794848714556, 0.10891584240432296, 0.11998928285070828, 0.15327458748860018, 0.14020009977476938, 0.1485806450779949, 0.1927407897476639, 0.10922057248119797, 0.10697649432612316, 0.21340234391391277, 0.1655756402760744, 0.13356440727199825, 0.10000551052923713, 0.22653875473354543, 0.18408570917589323, 0.1021127485271011, 0.13936216330954007, 0.09042801588241543, 0.08334496524184942, 0.09767381993255445, 0.08284276790384736, 0.14690155589154788, 0.11727743622447763, 0.27450576584253994, 0.09434259975595133, 0.13330469120826038, 0.1029889407966818, 0.21223406946020468, 0.08411527890712023, 0.17704936888601097, 0.12759439833462238, 0.06359836126544646, 0.11072365646915776, 0.09924119511353117, 0.11930147904370512, 0.06172682597701039, 0.11555454081722669, 0.10095693876168557, 0.1569240880864007, 0.1731757346008505, 0.1609494292310306, 0.19114490252520355, 0.18519311903842858, 0.08994721275355134, 0.07711988142026321, 0.1266594042203256, 0.12556355659450802, 0.10780690583799567, 0.1726076379418373, 0.17259843700698443, 0.1486946525318282, 0.1459732928446361, 0.09344909805804491, 0.07864215437855039, 0.10653902922890016, 0.09221543318458966, 0.10557162149676255], [0.09787031010325466, 0.00527310258309756, 0.0213136008741068, 0.04275314463302493, 0.06794390987072672, 0.08540250733494759, 0.013016231241635978, 0.06830113141664437, 0.07498185828860317, 0.023110100367505635, 0.06643798960638897, 0.026901346930701817, 0.01692664297297597, 0.041996598443282504, 0.020595707431701676, 0.029351877846888134, 0.021221752677645003, 0.04595343129975455, 0.031147997360676527, 0.03430064069107175, 0.03624681143888405, 0.022634038502084355, 0.03666204094354596, 0.02730872917787305, 0.05034559186814087, 0.01875918455022786, 0.012070801258752388, 0.052508914177971225, 0.018846578164292232, 0.02528652858122119, 0.03681567823514342, 0.024827587850657955, 0.04659268253349832, 0.061943807905273776, 0.0435248832218349, 0.0609638337045908, 0.03568582243419119, 0.0373187746320452, 0.015727965061419776, 0.012850235282842602, 0.012010364992810147, 0.041716858811144314, 0.016891191214589135, 0.08407750486263207, 0.034359167729105265, 0.013217929168604314, 0.06702237110584974, 0.08246524459017174, 0.0027317775321924792, 0.012167618876057011, 0.07557611925793545, 0.050076966639608145, 0.06181160892759051, 0.037250052605356486, 0.02595196957034724, 0.07541145237960986, 0.02690976415760815, 0.018399552508656467, 0.02252909118708755, 0.0959289874881506, 0.03129332259829555, 0.024423740770933882, 0.11300982415143933, 0.0833915127441287, 0.0319116478120642, 0.05203626025468111, 0.02324927638151816, 0.035021716462714333, 0.008531383637871062, 0.031950962131044695, 0.03342278601069536, 0.06482338838811431, 0.021215471139709865, 0.027319214240248715, 0.05003832746297121, 0.03437118797696062, 0.03164221512685929, 0.012514380804662193, 0.028102688092206205, 0.04352988741759743, 0.04028826439753175, 0.013257248576597443, 0.049791486601212194, 0.029281201639345715, 0.022056708677804897, 0.019328707829117775, 0.024946611374616623, 0.02020005026965269, 0.07725937464939696, 0.012953230113323246, 0.042352863254823854, 0.035118675724204095, 0.020900897216051817, 0.005006201681680977, 0.05413802247494459, 0.020243008321683322, 0.03650920432327049, 0.009277244597407324, 0.051540661669735394, 0.016533796642241732, 0.05279533059469291, 0.01999961950683168, 0.01799708285502025, 0.03166492230125836, 0.028476621955633163, 0.04002987486975534, 0.061170210130512714, 0.044343871596668444, 0.02383318460280342, 0.02385056358096855, 0.05191786607195224, 0.03471435366996697, 0.024416052969172597, 0.0397011619726462, 0.02016373846812972, 0.04987472927729998, 0.022311105026996562, 0.07363677117973566, 0.01580454791629953, 0.012949705123901367, 0.02461241421821926, 0.04652914112167699, 0.05540749703400901, 0.00437568107320528, 0.07129329442977905, 0.01089187550158905, 0.05795527728540557, 0.009763141827923911, 0.016403414442070892, 0.028105427677344, 0.013643535170038896, 0.0711861401796341, 0.03955653562609639, 0.03143891246457185, 0.04736959834450057, 0.04542919514434678, 0.0385393132455647, 0.12896285418953213, 0.02769272741196411, 0.03323683009615966, 0.02880968086953674, 0.0407517648834203, 0.026129886541249495, 0.07065345626324415, 0.05193628829770854, 0.010351501238931502, 0.032531570975801775, 0.002215548514089148, 0.04099874145218304, 0.057042796963027546, 0.03130654724580901, 0.049533924886158535, 0.036200199475778, 0.04601060805310096, 0.011353343775096749, 0.0696701572409698, 0.03832475029464279, 0.009641412645578384, 0.016090543641309654, 0.01630450608874006, 0.05186395985739572, 0.05223694037912147, 0.09659341576376132, 0.00844067707657814, 0.05486796669928091, 0.012210157084544855, 0.033020228147506714, 0.00590231192264972, 0.02203518893968846, 0.019513235427439213, 0.0310345022007823, 0.05142207410452621, 0.03172140694888575, 0.07877820743513958, 0.015481326063828809, 0.022618103107171397, 0.06215999594756535, 0.04922613122367433, 0.02793332066253892, 0.015924585850111077, 0.01042967610659876, 0.09487305807748012, 0.05623314862272569, 0.002100297432791974, 0.02964280991415892, 0.029705889922167574, 0.0434461629816464, 0.05026685466457691, 0.034041548879551034, 0.013525252945588102, 0.032618460777614794, 0.03020825350124921, 0.015539629185306174, 0.010698888267922615, 0.01428120965803308, 0.030782423048679317, 0.06745447577642542, 0.0174049372186086, 0.03572639882830637, 0.009925499142679785, 0.08772190966244255, 0.04738477038751755, 0.019973757144595896, 0.002825543226208538, 0.0130414600217981, 0.02167482577663447, 0.035871547646820545, 0.008673533331602812, 0.017979524065075175, 0.06766234497938838, 0.06324284284242562, 0.04771523729764989, 0.00992198009043932, 0.03470010104190026, 0.026903777782406126, 0.03030498545350773, 0.039504003444952626, 0.06747331190854311, 0.024367561464064887, 0.02362738493164735, 0.029494000399219136, 0.01595243123093886, 0.024779272764655094, 0.025906799494155815, 0.03530824823038919, 0.004982937260397843, 0.06120835736926113, 0.06089817865618637, 0.015117979043030312, 0.02351715013251773, 0.05258126297433462, 0.033205525883074315, 0.012370387192017265, 0.021216784104970948, 0.03775680969868388, 0.06917418885443892, 0.08485849188374621, 0.031836544163525105, 0.018421126529574394, 0.026286923293290392, 0.03235521633177996, 0.018020093673840165, 0.02492939694119351, 0.030005676871431724, 0.03872944554314017, 0.038529481273144484, 0.04471414815634489, 0.039867749105074575, 0.017637452509786402, 0.06605349773807184, 0.026565919929583157, 0.02561419823073915, 0.0491882927183594, 0.012162290679823076, 0.04588647007143923, 0.04260043014905282, 0.032912731237177334, 0.0354876155698938, 0.027400075258421044, 0.04429367696866393, 0.04977316954838378, 0.02864686639181205, 0.02576892796371664, 0.03414354965622936, 0.062215513682791164, 0.02816573078078883, 0.09075570079897131, 0.05448945611715317, 0.09905973449349403, 0.012739014063429619, 0.03341013133259756, 0.0062533808522857726, 0.055763493824218, 0.029504745001239435, 0.0166061301715672, 0.033673871108996015, 0.040350628551095724, 0.03911475504615477, 0.02714053900646312, 0.03500838324959789, 0.05338831591819014, 0.036585278276886256, 0.016498436486082416, 0.022682804813874618, 0.02609905899901475, 0.033343254921159575, 0.02993929579055735, 0.025497900721217905, 0.025966464774683118, 0.03095492361379521, 0.006390992843080312, 0.060382437759212086, 0.042463837657123804, 0.014698861532711556, 0.018729944779936756, 0.02545801643282175, 0.019902870591197695, 0.03302091686055064, 0.05458045105582901, 0.019323912282873477, 0.04514619854411908, 0.03866555807845933, 0.0870333933936698, 0.022185509891382287, 0.006083854390973491, 0.02798577650849308, 0.06448431765394551, 0.052522308459239345, 0.02595222571731678, 0.033744683023542166, 0.0316614380239376, 0.05963713489472866, 0.018034626197602068, 0.04297957176874791, 0.011069461686669715, 0.023662295558356812, 0.0076634109718725085, 0.050366131123155355, 0.027962775867698447, 0.04179471731185913, 0.022053015750965903, 0.029464416272406067, 0.027346523578411767, 0.011384235778158265, 0.021961639136342064, 0.0317843342865152, 0.03837340125547988, 0.04237702249416283, 0.03957892728171178, 0.024132265875648175, 0.0578528456389904, 0.0110593913788242, 0.03797763213515282, 0.0028230958352131502, 0.025257794319518974, 0.012041785405017436, 0.03296495468488761, 0.02420904380934579, 0.035305232142231295, 0.019375058556241647, 0.0375842514580914, 0.012075657024979591, 0.0759766109819923, 0.039054830225982835, 0.04544213141447731, 0.04210602917841502, 0.007531548717192241, 0.02120769003938351, 0.051238391282302995, 0.05993220263293811, 0.04795699593211923, 0.031711541049714596, 0.2402948715857097, 0.09026957117021084, 0.13833848466830595, 0.06764314243836062, 0.16525556173707756, 0.1781604971204485, 0.08711700926401786, 0.1420882727418627, 0.14752907864749432, 0.11370881021554981, 0.12116660896156516, 0.1457608299595969, 0.07529572144682918, 0.21679120564035007, 0.15077329027865613, 0.08010733540036849, 0.09573335227157388, 0.08963302389851638, 0.16473999725920813, 0.14587088833962167, 0.17918408076678002, 0.08682395677481379, 0.14310405323547976, 0.12628996904407228, 0.22016640167151177, 0.10327813242162977, 0.0729375204869679, 0.11978387672986303, 0.03429059158744557, 0.08610178516911608, 0.1256959116352456, 0.06549608122025218, 0.11755687051585742, 0.12450888247362205, 0.13052412255534104, 0.12851818305041107, 0.10100795102438756, 0.07475659144776207, 0.13576968679470675, 0.09651562172387328, 0.07328396011143923, 0.09810209088027477, 0.1530075432466609, 0.129514855997903, 0.09935151133686304, 0.08092030177691154, 0.10896328557282686, 0.08838394270943743, 0.14900821713464601, 0.12062212532120091, 0.13271036238542624, 0.13657167447464807, 0.15748200672013418, 0.08591569015490157, 0.11920824833214283, 0.1527796776166984, 0.2227605903255088, 0.09364725063954081, 0.11858375184237957, 0.12707991951278277, 0.1565533365522112, 0.061325804995638986, 0.1760997184153114, 0.12803474042032445, 0.18423338553735188, 0.18190981021949224, 0.08295328768768481, 0.10272084482546363, 0.10892511797802788, 0.11062176086540733, 0.09308175955499921, 0.16287283173629216, 0.11425533624632017, 0.15714663400181703, 0.16689054614731244, 0.11789938142257077, 0.16714397897677763, 0.12464693720851626, 0.13499926456383296, 0.16854644300682203, 0.08577072114816733, 0.10600318333932332, 0.1498726571777037, 0.09433254386697497, 0.14122292346188, 0.12191906358514513, 0.09151256590017251, 0.12447942048311234, 0.1785911361553839, 0.09007760004273482, 0.08874751534312963, 0.14258037347878727, 0.14107701129146985, 0.08590770379773208, 0.14913305400737695, 0.10364489416990962, 0.12006854931158678, 0.10503570096833365, 0.1498410917286362, 0.17750533084784234, 0.1443337079669748, 0.13424314585115227, 0.07678189634212426, 0.11831974743732385, 0.1380366858627115, 0.12336370535194874, 0.12447745273155825, 0.16984593256243638, 0.13545153529516288, 0.07868450174906425, 0.2049954171691622, 0.10137610376945563, 0.09013720934412309, 0.15270524232515267, 0.07467593399009534, 0.19888283445366792, 0.06079654089574303, 0.12907616953764642, 0.1720135398209095, 0.11047976384205477, 0.11672749716256346, 0.14108808498297418, 0.19117553159594536, 0.13158662697034224, 0.16695419273206166, 0.09964294212737254, 0.1444434949329921, 0.06253528009567942, 0.2105976872678314, 0.06196843194110053, 0.14323699181633337, 0.15338084607252053, 0.16896845107632025, 0.11782631677176271, 0.11891950454030718, 0.1899524043713297, 0.07529865271810975, 0.1574969616319452, 0.11658708112580435, 0.113186100763934, 0.05976602940687111, 0.11413516769451754, 0.06704903753208262, 0.16331329595829758, 0.1468142827174493, 0.07499160205147096, 0.11564528809062072, 0.05654536633353148, 0.09747635945677757, 0.12225687902952943, 0.11495251740728106, 0.21561651224536554, 0.16540363164884703, 0.19201964272984437, 0.08643841996256794, 0.11857066968722002, 0.10879686807415315, 0.08933870933417763, 0.0834573306409376, 0.061438665725290775, 0.13228827289172582, 0.163718028526221, 0.2275615105671542, 0.07410783733108214, 0.15805516525038651, 0.18369034039122717, 0.12265220710209437, 0.13077082431742124, 0.12206821915294443, 0.07319348425205265, 0.14976173027285508, 0.2345015395964895, 0.20016394928097725, 0.1845733587230955, 0.11386490719658987, 0.14635718081678661], [0.013474007436473454, 0.0034013686111263397, 0.09894424783332006, 0.027076922955789735, 0.03066452080383897, 0.0809688645281962, 0.06520696423415627, 0.06474744674882718, 0.03321962923343692, 0.00957154983188957, 0.030720343879823173, 0.02798009547404945, 0.06422854387866599, 0.04081218842683094, 0.07925781634237085, 0.044841370079666376, 0.017998424658019627, 0.0034185624764566974, 0.042528155991541486, 0.015372578952727574, 0.03301136987283826, 0.028880160301923752, 0.05621910294783967, 0.03672612179070711, 0.07334314193576574, 0.03492031279685242, 0.05447655716644866, 0.07963242195546627, 0.01081852671424193, 0.0038329692574084868, 0.03990770124697259, 0.032046326835240634, 0.010754822454016124, 0.04845274718744414, 0.07161404471844435, 0.02889174289469208, 0.10744245110877923, 0.05662420531734824, 0.028146455297246575, 0.029351158599768366, 0.03993961274889963, 0.024000848909573894, 0.009268743401792432, 0.05159986045743738, 0.027807065651619008, 0.028353478027773753, 0.011641275021247566, 0.03151833498850465, 0.017767164656626325, 0.05634783461157765, 0.023211159676845585, 0.04271993373653718, 0.02127916013289775, 0.021001249152634825, 0.031641668906169276, 0.0009426743885602004, 0.043682822425450595, 0.03389806586450764, 0.036760906888438125, 0.10447981793965612, 0.031385766209236214, 0.04438698571175337, 0.022170522749157887, 0.03416076408965247, 0.026314907773797, 0.05578022989045296, 0.016291033775944794, 0.04657729335927537, 0.037552421380366595, 0.055213018719639094, 0.03726151645449655, 0.11629061560545649, 0.06696617483560528, 0.06082790278430496, 0.02783503825776279, 0.03027825117377298, 0.05081781152901905, 0.05105996032112411, 0.05047227096344743, 0.05280895897054246, 0.015139273168253047, 0.01845013220528407, 0.05240086426160165, 0.05107245893616762, 0.058239291688161235, 0.0488799935472863, 0.109929220883974, 0.04850694177938359, 0.09788136343870844, 0.011598234696845924, 0.0186205310081797, 0.05518057796039751, 0.06379439003233399, 0.021377186390704343, 0.05593025737575122, 0.024396063327523212, 0.06383532605000905, 0.015780846688098142, 0.03405132317649467, 0.04746887480307903, 0.009147048994366611, 0.020011929828407507, 0.03724806789042694, 0.03755343918289457, 0.0769797775096127, 0.04607984237372875, 0.07629994648907866, 0.024017099823270525, 0.011777319596149027, 0.03581421822309494, 0.0168968807307205, 0.07570776183690343, 0.054036818976913176, 0.05525105060743434, 0.05499694602830069, 0.05517492576369217, 0.021787082610119666, 0.038811823087079186, 0.034590585489890406, 0.040786295530519316, 0.016837363031559756, 0.039523585965590816, 0.06038505690438407, 0.047156375500240495, 0.04006501959104623, 0.045614642157618485, 0.0458841257329498, 0.027551678641300117, 0.02383484022824892, 0.03268264679770384, 0.03227519330435565, 0.01795354804822377, 0.022798289777711034, 0.02237166597374848, 0.03727555534403239, 0.041384285049779077, 0.0189061111304909, 0.02279221688929413, 0.05054571220119085, 0.049268220750881095, 0.021494349032374363, 0.02093852707184851, 0.051098270408277, 0.07131956730570112, 0.03467522594811661, 0.01981388750885214, 0.06101201647626502, 0.09568346637700285, 0.049843462383640666, 0.03754771574001227, 0.06591232174209186, 0.0950511870905757, 0.02144617643872542, 0.027112702107323066, 0.029988170667950596, 0.015770015572862964, 0.04551147769338318, 0.06993996312043496, 0.020858607521014552, 0.013026580597007913, 0.028350997982280593, 0.018646130438095758, 0.01797829761302897, 0.020026479315544878, 0.012478443045568253, 0.016368924507072995, 0.04524394151355539, 0.011138395755551755, 0.023036621810336198, 0.036969966920358796, 0.006517721980344504, 0.05239720017250095, 0.05905925376074655, 0.043101823423057795, 0.01117643527686596, 0.01482293674988406, 0.02295022564274924, 0.028660732254918133, 0.026452475659815327, 0.07484068229262318, 0.017281418400151387, 0.03869301839066403, 0.028213881322049668, 0.058872188441455364, 0.05850416461804083, 0.029943322895893028, 0.01519902835467032, 0.035198339128068516, 0.0414576211145946, 0.03747182499085154, 0.0387131640953677, 0.01820566621609032, 0.01930276065000466, 0.007031763995265854, 0.009837393915014607, 0.009573621060033994, 0.027330089460260103, 0.013073263806290925, 0.036936460861137936, 0.04241380248484867, 0.08832061503614698, 0.02230078959837556, 0.01125409360975027, 0.0662295843607613, 0.04527037723788193, 0.034606093407741616, 0.006416460806836507, 0.03675773812990103, 0.03250650249953781, 0.02469012004855488, 0.051868271947439225, 0.015378451673313975, 0.06454161993627038, 0.01228056866343, 0.029565019266945974, 0.05471945573974933, 0.06269785030079739, 0.04141613209087934, 0.02066491630726627, 0.03271992551162839, 0.03650122814412628, 0.029541046624737125, 0.018982543011329005, 0.03573615616187453, 0.019738838143114532, 0.024274195045498864, 0.019303330619420325, 0.033645752617823224, 0.015550022645454322, 0.025302519955273186, 0.06298008694180421, 0.05768005669649158, 0.010919915961234697, 0.013118847788843726, 0.05357383078496371, 0.016683159163221717, 0.036021731195173094, 0.00572418502997607, 0.010957087805893804, 0.041527279519609044, 0.058605734524982314, 0.043920180760324, 0.041604079505694766, 0.016878392347799878, 0.057043726556003094, 0.04471838560753635, 0.021518576125215207, 0.05438207795045205, 0.05633262524913464, 0.049545690683381896, 0.03718518126489861, 0.04096011245357139, 0.025300772727600167, 0.019383494442860996, 0.07574158680758306, 0.020661728889016167, 0.017784329896260585, 0.02955885138362646, 0.07352965764169182, 0.05341321136802435, 0.010856012381347162, 0.04402072947206242, 0.08193215355277061, 0.02527089343805398, 0.02759478088202221, 0.011345092789269984, 0.04637451656162739, 0.02067926393023559, 0.033542360844356675, 0.01917123681466494, 0.0574983110917466, 0.03750214532815984, 0.10333432869187423, 0.024881933416639055, 0.010423434432595968, 0.05776745879224368, 0.022184799125950252, 0.03570903850985425, 0.014857345260679722, 0.06451730124120202, 0.01266310126188078, 0.016916322455342327, 0.025552532968244383, 0.03838567256129213, 0.04019700483019863, 0.01946004676366491, 0.05719725867467267, 0.04301693869222488, 0.06468610039779119, 0.04829743052167552, 0.057287076355091164, 0.02008925567913268, 0.013839561392420104, 0.04483241341742022, 0.034414827956685, 0.08196149340697698, 0.025239168533257077, 0.06831322969602686, 0.10438692649560315, 0.0784734705729144, 0.035417346483362575, 0.037756331331495724, 0.022033224580809474, 0.05360519267352564, 0.04352378060242959, 0.010005740149478828, 0.02772198923464332, 0.021494460990652442, 0.05335275050518768, 0.035836409710879834, 0.03061297589114734, 0.05142742435314825, 0.05589155713096261, 0.025592461361416748, 0.013347567524760962, 0.035067700780928135, 0.025923618680930564, 0.02622828260064125, 0.02613467530214361, 0.01790338395429509, 0.032503357489726374, 0.032695186124848466, 0.028587630284684043, 0.08547129042978797, 0.0423005278488355, 0.03443319589963981, 0.05020518600940704, 0.07139960729650088, 0.026166144059970975, 0.05620705555858357, 0.0770763126867158, 0.006157366874893861, 0.038432481299553595, 0.03171726788527199, 0.01377700555271336, 0.0854873445683292, 0.029909022950700352, 0.016737637043531452, 0.0331823403414871, 0.02296521108863609, 0.030458931478538682, 0.019185592919321995, 0.054768476502171586, 0.01419547336575176, 0.01259576344663011, 0.013254230792102004, 0.005856303855710263, 0.011518722267023154, 0.03574608312919736, 0.017840663569846323, 0.00540721502953342, 0.05115176950182233, 0.08746919608009712, 0.11517336698515074, 0.18636562755065306, 0.13861767468707903, 0.09214076040578739, 0.2021946417433875, 0.15300805893327507, 0.12367758208087512, 0.19428922023091996, 0.0849528828901904, 0.12354605485286031, 0.11151687069130795, 0.11605958800230708, 0.11865963919886521, 0.14745549831007207, 0.11967661391411509, 0.10708995216659137, 0.10694458282419614, 0.11415025831333228, 0.0920552107106362, 0.08583789611501352, 0.15534238224583014, 0.15217441080936364, 0.15692692436277866, 0.19599844994289534, 0.19064863558326448, 0.12361802027693816, 0.15996089870376246, 0.11419964209198952, 0.12435843768928732, 0.12713645505053656, 0.11714115925133228, 0.14524453266390733, 0.11437763539808136, 0.1497985611536673, 0.050498425095741234, 0.15049559303692409, 0.1129107308973159, 0.11885636007147175, 0.10228186659514904, 0.1112895275333098, 0.14056260032313211, 0.10112408907817942, 0.15892773414296762, 0.09192902355321816, 0.20416347895349773, 0.1270193670477186, 0.15272392917956623, 0.1335410520966564, 0.14073650884841168, 0.09652788285166025, 0.106552959552833, 0.08622580779982464, 0.09049835282244853, 0.12457722452070032, 0.11486717127263546, 0.1409460133207696, 0.15680328171168054, 0.13893631473183632, 0.18446859291621617, 0.1552303968263524, 0.07191736344248056, 0.09532766975462437, 0.11351516310657774, 0.16763698895062717, 0.12195388600230217, 0.12696488068572112, 0.13620279569711002, 0.1364199404737779, 0.1615750113768237, 0.11442946190280573, 0.11687252723744937, 0.13126852975359984, 0.21656800833131584, 0.168198449537158, 0.1244576530797141, 0.14737657111670288, 0.3501129416482789, 0.15393918539796556, 0.15694187927458966, 0.08997457807085343, 0.12342465136732374, 0.10117503348737955, 0.11745264753699303, 0.09693332109600306, 0.10833258727299315, 0.1593300782676254, 0.1267537884414196, 0.1914266845477479, 0.07798591602061476, 0.09457899457109825, 0.16352491745991365, 0.1383048157606806, 0.12479773483106069, 0.12023565891597952, 0.19499444881720202, 0.34691454470157623, 0.08901228649275643, 0.10400358135146753, 0.12253221496939659, 0.09906430781951972, 0.09953228663653135, 0.1751879301986524, 0.09120982393090214, 0.12528615790818418, 0.10741262949470963, 0.13533112247075352, 0.13063139894178935, 0.13920306041836739, 0.05616514923583184, 0.23638357860701426, 0.14925820300621645, 0.1101132667224322, 0.14063748344779015, 0.1694386215614421, 0.14606397226452827, 0.07714086850839001, 0.14190823026001453, 0.11746336839028768, 0.14570122744355882, 0.09403932852936642, 0.17642214468547276, 0.21837181225419044, 0.14499506247895105, 0.1381709272308009, 0.1662727128714323, 0.11306468370769705, 0.13064947511468614, 0.20583044950451168, 0.08310500133250441, 0.11553064281386988, 0.07843353200171675, 0.13479729183018208, 0.07440201618841716, 0.09474089981189796, 0.1544790414295026, 0.2751138689262526, 0.12915829941630363, 0.07581841732774462, 0.13381618447601795, 0.07583719239171062, 0.23938264910663876, 0.13253394328057766, 0.1362201390521867, 0.10906600898930005, 0.184359538768019, 0.1496109055089099, 0.19193078178380216, 0.1051198121692453, 0.12705611650432858, 0.1518726527158703, 0.12014542732919965, 0.13492273938442978, 0.11549887380429677, 0.10770577019346611, 0.1139434136982475, 0.15330395448420728, 0.16600451511996134, 0.11478528566658497, 0.2096680807215827, 0.12643376418522426, 0.14251576337431157, 0.1500002217612096, 0.05124542769044638, 0.14335880242288113, 0.11707988753914833, 0.08138279803097248, 0.06267699213432414, 0.11384745527591024, 0.097615404852799, 0.10060097929090261, 0.13790918913270744, 0.1102462528007371, 0.1639111124511276, 0.1065206816419959, 0.11785225038017545], [0.04310530430770346, 0.024261469121224115, 0.03367792196305735, 0.03555560138608728, 0.023525341746530364, 0.01416494692343154, 0.00809755124750414, 0.08542124168681246, 0.0675713127212865, 0.040616315722997696, 0.010122813733427652, 0.030843504771058048, 0.034229340231312175, 0.07032627346260206, 0.030602455205683197, 0.028052730951458216, 0.012359948778924133, 0.03555593386824642, 0.0266704719979316, 0.10825319867581129, 0.029029896017163992, 0.03751012829265424, 0.025447553422834192, 0.1028728298842907, 0.06690059442605291, 0.027630855196288655, 0.05212635952713234, 0.06804829569799559, 0.025942415797284672, 0.02541963679582945, 0.025873980451641337, 0.023557394044473767, 0.012443718167820146, 0.13185192059193337, 0.07306096636291061, 0.021584088681265712, 0.09887311700731516, 0.06281132171196596, 0.01771106168494693, 0.035925983118691614, 0.05035847046279481, 0.010909867705777287, 0.0614543670256223, 0.034680810291320086, 0.010143049344021295, 0.05005510424130729, 0.08241932134010962, 0.019759243387462835, 0.005910573086501765, 0.02137620421126485, 0.05158364007781659, 0.0020670969263717, 0.06869460030325822, 0.039560043652142794, 0.020093806952770268, 0.07429051931415286, 0.026618704865021364, 0.013823417347988911, 0.09278462907033307, 0.025292676108490144, 0.05661946914291807, 0.003819604662047433, 0.07803508945341621, 0.01067892661584275, 0.011701478040777147, 0.036935480378035984, 0.053747861446546655, 0.037806139194539616, 0.018677980871871114, 0.05337551196238824, 0.02588009405215936, 0.06076486009572234, 0.04544564961854901, 0.0667387434680547, 0.024955320371580974, 0.009768151960867857, 0.08238788481269564, 0.019562736253387163, 0.03785871548045959, 0.0426263976842165, 0.08384362741240434, 0.03421325216602002, 0.023363704527063028, 0.04001275882390993, 0.013282348435106022, 0.0328931724652648, 0.008887171778561813, 0.026027000276371837, 0.05825300488088812, 0.007617811722281788, 0.024821733789784566, 0.05686807080305048, 0.010188728321476706, 0.032545396126806736, 0.023429900707144822, 0.0467285422076072, 0.023242808246452893, 0.031214493792504072, 0.021979847623567497, 0.07306447438895702, 0.032632645552179644, 0.02484596936431314, 0.059882845995681624, 0.023011380307642475, 0.035593080267842324, 0.035425207311553616, 0.033862856682389975, 0.03265438920685223, 0.01605468136923654, 0.06825773231685162, 0.06287517864257097, 0.01386043567410005, 0.045081707183271646, 0.039781490340828896, 0.041285931398825984, 0.027141103886866143, 0.042755845202399154, 0.05544021599260824, 0.0332545839649226, 0.02429994714579412, 0.013205112490270818, 0.009463398983435971, 0.05164887782718454, 0.016096134769863317, 0.026621371507644653, 0.035794622131756375, 0.049339215869882276, 0.030791244003921747, 0.04154189855658582, 0.021011712162622383, 0.02785382010707898, 0.03232637180813721, 0.058353258429893425, 0.015038315639165896, 0.01782435498067311, 0.0186376979441515, 0.037212390519146404, 0.011917398061736353, 0.05609131105510252, 0.05176032720399754, 0.0568215266934463, 0.042706417318965705, 0.07344963122159243, 0.0546323691627809, 0.023291175918919698, 0.009772375841358942, 0.02053450357301959, 0.011642585442002331, 0.08299775208745684, 0.0023456014127337505, 0.073129749457751, 0.04896011156961322, 0.02824083951834057, 0.029718649773193256, 0.020641308377629945, 0.039150164396102936, 0.03656358890501516, 0.019928395382261703, 0.0610126271577818, 0.026071552885696292, 0.024603822268545628, 0.02737383122023727, 0.002377790689934045, 0.025520918325388005, 0.0458887431637517, 0.021852057427167892, 0.0252166394743004, 0.003244003405727978, 0.014009493702490414, 0.047189694962331226, 0.01783820557674127, 0.04435767299894776, 0.027626470163730637, 0.04186958008046661, 0.040486688393035104, 0.03340727470016905, 0.02815731185754495, 0.047450832556933165, 0.023218891583383083, 0.04631441192967551, 0.042554286375109635, 0.02878734688939793, 0.031660918944648335, 0.05437390499615243, 0.01085786902279194, 0.009391521768910545, 0.010895496334082313, 0.034625428263098, 0.04896962123789957, 0.0310789326738034, 0.01017776913275676, 0.01968685387899833, 0.029542156029492617, 0.040583759612802944, 0.012308111248005713, 0.0321199410994138, 0.03040056728890964, 0.024032673898286054, 0.0246964592619666, 0.04988889369581427, 0.019676187308505177, 0.06010651827922889, 0.027452904298635464, 0.029574321982051646, 0.04202236241794058, 0.002911126848110663, 0.011907410026261849, 0.05475179132606302, 0.02717125628675733, 0.062444254622927735, 0.03680161898955703, 0.04128810949623585, 0.0742613762351019, 0.07156477629074029, 0.031400962000978846, 0.02750332114685859, 0.020269815543932573, 0.007217199558259121, 0.0819895915420992, 0.07249901723116636, 0.04524498645748411, 0.08220985757985286, 0.03125269192137888, 0.033832081726619175, 0.01954032084904611, 0.032199848775884936, 0.03520336028720651, 0.007251129701866635, 0.06948429292866162, 0.036269868058817725, 0.02774354798852333, 0.032580062480909486, 0.02740425673047347, 0.006031433319939035, 0.02410238149708935, 0.02559834426002843, 0.02133153285831213, 0.00672648727361645, 0.016435970552265644, 0.028978873576436723, 0.021092417117740427, 0.020869872898661664, 0.032774764711835554, 0.043408127701176066, 0.05056964073862348, 0.0285994503647089, 0.02701919150006558, 0.027955980339486684, 0.05131662976262825, 0.08473597560077906, 0.023818529942738156, 0.02581050350064678, 0.016334441357425282, 0.017285747453570366, 0.02820684152123119, 0.02537596458569169, 0.04988571136657681, 0.03332673937880567, 0.019099731098062227, 0.05596106286559786, 0.006677611123970044, 0.11307146905788354, 0.01786688725197954, 0.05515768079619322, 0.033306776878557036, 0.008407658714401935, 0.015312423430649298, 0.013306576376115637, 0.03187082035999213, 0.009802947236624147, 0.03549186319911054, 0.03399202600121498, 0.005626647741467292, 0.043939135636069944, 0.05907655640372208, 0.01339967901419316, 0.04191018361598253, 0.024499651876145175, 0.11710632326347487, 0.07674443442374468, 0.013993921323812433, 0.08444625471851655, 0.026601230891953622, 0.01096908260868596, 0.007053374063356647, 0.04997461981007031, 0.05171121483934777, 0.03216988466946142, 0.050992164494735856, 0.008154052858506995, 0.07170465628483466, 0.0207981144277645, 0.030267740666334118, 0.024413462661738907, 0.059926923630493026, 0.03334296315110155, 0.031058922676103454, 0.021884452385295714, 0.09784246981143951, 0.015329050931281276, 0.017726851194830875, 0.003121656332431095, 0.07626994845590421, 0.011984053101124508, 0.023430774320981333, 0.016335944312491586, 0.03095113399571606, 0.05545805128557341, 0.09983848234904663, 0.017449628927611878, 0.01667155960707792, 0.031204020604491234, 0.04097805631213954, 0.013029840957772518, 0.023032978077286055, 0.027496574812435677, 0.05310365690716675, 0.04624375268550856, 0.07423444518021174, 0.05907949446035283, 0.048934720789215395, 0.029764983536941663, 0.06168348794536931, 0.04217948398685881, 0.019070856040343642, 0.04516956050481115, 0.09295422889824424, 0.045065653044730425, 0.08422140856938702, 0.021101996335866194, 0.03791221118132983, 0.015866845912699188, 0.03819490922614932, 0.03928503340908459, 0.04228557293702449, 0.01538135071418115, 0.012371634000114031, 0.062419895215758255, 0.036489662514733415, 0.0518460974230298, 0.013663706319805766, 0.036690546199679375, 0.026363596054060117, 0.029682955438537256, 0.022531011441190327, 0.047375250541205914, 0.032697808662695546, 0.022526650157357966, 0.1040103734870042, 0.03155848729823317, 0.023914473098037497, 0.008527396396467728, 0.1126808093062469, 0.12047549390367099, 0.07676235453358718, 0.14408252787377152, 0.16608573576169355, 0.0964839273531522, 0.1380701240684305, 0.18429646215268544, 0.16471529858452932, 0.1585035819028105, 0.1308594545615571, 0.21456862347466604, 0.08100209238805942, 0.07056044268288783, 0.11133532864706856, 0.1338638040636267, 0.09261420821504933, 0.1539539774613721, 0.07619111625743763, 0.20404986504997524, 0.09888919150190693, 0.10998999048024416, 0.16073418435241493, 0.12584497220814228, 0.18279860966971942, 0.14950759176697048, 0.13534727160419735, 0.1430195484842573, 0.11952392996421882, 0.16766566384051526, 0.08238538780382701, 0.09573574071483952, 0.10563409421592951, 0.1474581038845437, 0.1291263268462249, 0.12721346877515316, 0.21318415419331618, 0.16838383887495312, 0.14216094384235994, 0.10291230705167566, 0.08177669439464808, 0.140574203271951, 0.17549521156719752, 0.1281808154391391, 0.10700843296945095, 0.1762907938765628, 0.10681781212666205, 0.14166258701256343, 0.12269107358796255, 0.12287929920213563, 0.1450056747666427, 0.1061352262539523, 0.26751688229186193, 0.1662383654287883, 0.19870876307998384, 0.16310623421200685, 0.10144678676234824, 0.22956525161862373, 0.15803159294383867, 0.07415663078427315, 0.11171857201095138, 0.13134094301079, 0.11808082168655736, 0.08043284221951451, 0.10283275560608932, 0.10601608229002782, 0.14877317260418618, 0.12355361373296805, 0.12445168197154999, 0.11906538956931659, 0.11621394114834921, 0.14594520149486406, 0.17628314000155243, 0.18476490915885993, 0.09695419961852686, 0.07728747956986938, 0.15205445938876697, 0.09180643941674914, 0.11033828929066658, 0.09679106622934341, 0.1475048820887293, 0.0760100966851626, 0.12063944153487682, 0.1495785801006215, 0.06978896872273513, 0.12947091407009534, 0.18513521285993711, 0.1548067331314087, 0.1305524581777198, 0.07585418290857758, 0.15116612134235247, 0.15614289071943077, 0.11875710396894387, 0.10155789008630173, 0.15794490330985614, 0.08178324225757803, 0.13227816271994794, 0.1326901013297694, 0.09181561999555145, 0.17040028210197175, 0.07556094721491848, 0.13322504476777144, 0.19728529160576208, 0.1276574478085552, 0.12488565939877715, 0.1788154598325491, 0.09407465984778744, 0.11539965841387, 0.13881176284381322, 0.09036637097597122, 0.15117126463779382, 0.11432660956467901, 0.19721898516373976, 0.16477438541395323, 0.19090232625603676, 0.15717890512730393, 0.11881749358560358, 0.1291715715612684, 0.13604065296905382, 0.09744824096560478, 0.11713279969990253, 0.12477197764175278, 0.19306588944579872, 0.11747737335307257, 0.09580704795994929, 0.06537872858877693, 0.15104393075619424, 0.1139427080218281, 0.16413198917039803, 0.1094586229217904, 0.09353566555572407, 0.11851645473923002, 0.17084700241684914, 0.13204592732446535, 0.10985439204211746, 0.09658894421798842, 0.1035484064902578, 0.09651665309710161, 0.13540033304265567, 0.09153454364942652, 0.17623162562293665, 0.15956885474068777, 0.19193245097994804, 0.1817094116870846, 0.1946136142526354, 0.1135397803570543, 0.19079358423394815, 0.12207117756562573, 0.12966222023325308, 0.15742921669568333, 0.17150340362318925, 0.16988306199865683, 0.2223450554800885, 0.11304696037300996, 0.09235669739012208, 0.14727842781160558, 0.1189344594521182, 0.15211776670600685, 0.11630736184971673, 0.13102574992392743, 0.09063286560454539, 0.14934943882482393, 0.08443461784294673, 0.149603523047907, 0.12448696579251971, 0.10875545708196503, 0.15016472579113074, 0.18978966453245708, 0.1412332643355642, 0.21199835996542657, 0.1299831944384745, 0.2479023076593876, 0.18353800927954061, 0.05740619317761489, 0.13191748064543518, 0.08594373400722231], [0.03115534589492849, 0.014507233065419962, 0.06579946779779025, 0.05868052265473774, 0.06440572972808566, 0.069023737284754, 0.034335558103131394, 0.04996450285294226, 0.010769526307870234, 0.057835509069263935, 0.024709795867758136, 0.03163868674476232, 0.015472764648231012, 0.0947398277265685, 0.05039085015388472, 0.026136529399082065, 0.04169997685988035, 0.05244583756263767, 0.06540957479072468, 0.01831758378206619, 0.05468381908056991, 0.0328329762310854, 0.028097822996122495, 0.0457323103078774, 0.004417731584648469, 0.03674765170684882, 0.006530369449007724, 0.04548323706590703, 0.017129981258351887, 0.015550879295915365, 0.0430723003643964, 0.06201490480452776, 0.051891488023102283, 0.02251564771203058, 0.056155581892068894, 0.01705091666164143, 0.05343530107555645, 0.05151514196768403, 0.03158893655719502, 0.04985536388786776, 0.010841937020554073, 0.026418981474957297, 0.025624208318601762, 0.018832961662805507, 0.010019986840364124, 0.11753985285758972, 0.061600129918328354, 0.08379094595355646, 0.00862216653435358, 0.012935706098297877, 0.037648596933909824, 0.004644716815424285, 0.06258838903158903, 0.08477012626826763, 0.03167188407054969, 0.0015229094029304438, 0.023545171932450364, 0.03515192733279296, 0.05323962853955371, 0.025525486562401056, 0.037224213991846354, 0.043086481746286154, 0.007886745684247996, 0.028919681574084928, 0.05073074870077627, 0.05288741458207369, 0.03237997268193534, 0.033657033262508254, 0.08630772733262607, 0.06920052279851266, 0.03026911469974688, 0.05424813513777085, 0.03949960993070688, 0.03548496249797089, 0.03294475130470736, 0.050738673989794085, 0.027195900678634644, 0.027250158035063317, 0.04294159755642925, 0.09677749552897044, 0.010316165679666613, 0.028810206734176193, 0.0369356228703899, 0.028146239862378155, 0.049829053692519665, 0.02604158708293523, 0.04840283754414745, 0.05402833389650498, 0.07954963389784098, 0.008224414395434516, 0.011945609851474208, 0.0656850803643465, 0.05363466823473573, 0.012639641761779785, 0.018134893317307745, 0.03941043007320591, 0.07656063964324338, 0.011053241307048925, 0.09029250565384116, 0.011118831046457802, 0.03998981076957924, 0.02805977244861424, 0.01909513402331088, 0.03155115572735667, 0.034399781442646465, 0.037544041472886286, 0.026601134200713465, 0.00873607729694673, 0.02213466047708477, 0.08229324274829455, 0.03169730877769845, 0.021354136556120853, 0.026858321025169322, 0.03625183259802205, 0.06396994739770889, 0.045213125845683474, 0.0854946184637291, 0.055826105643063784, 0.02385122175993664, 0.04959024329270635, 0.031549347431531975, 0.024442916170560887, 0.04689789776291166, 0.080833211807268, 0.010798442925858711, 0.04206174459042294, 0.07882239363555398, 0.03426239506474563, 0.033864105186824284, 0.04425881723208087, 0.032017614625926526, 0.002566672150611079, 0.10131200256624392, 0.017575202010838047, 0.048346797336957285, 0.00634991263671379, 0.10917925648391247, 0.04198498192376324, 0.03666249556200845, 0.049818838347813914, 0.016665339137294462, 0.11053393129259348, 0.047903948064361296, 0.035700862162879536, 0.02993814567370074, 0.023238068679347634, 0.09981182270816394, 0.04843332751521042, 0.060678312954093726, 0.03940188053197094, 0.04312502592802048, 0.021771691739559174, 0.029393957196069614, 0.09580803183572632, 0.04488167505977409, 0.0606229512819222, 0.057786118505256515, 0.048592630574213605, 0.02446761823791478, 0.07716399298182555, 0.03417168850345271, 0.056795949315918345, 0.03241278324276209, 0.050751359201967716, 0.03627368821097272, 0.08336817792483739, 0.01609216194732913, 0.033047671496335945, 0.04339609048994524, 0.04219976539856621, 0.018688075776611055, 0.02779546270280012, 0.005211639608855226, 0.08444855495222978, 0.038381319759147506, 0.018194453424907157, 0.03684633444728596, 0.05079324856134398, 0.025911147207287804, 0.03355310544637697, 0.033984684252313206, 0.046038299067212005, 0.02107858518138528, 0.014646515948697925, 0.03408133138769439, 0.020545716364202753, 0.014069061443608786, 0.020178094572786773, 0.017652700887992978, 0.09240654935794217, 0.021423286059871316, 0.022518533182197382, 0.019546347936349254, 0.036590458891753636, 0.04346175232369985, 0.013200646881679339, 0.0320408205235643, 0.026555059976609688, 0.03645123368395226, 0.06338579660015446, 0.03068912448361516, 0.03819977771490812, 0.040898409871650596, 0.04272194220019238, 0.013923572509416511, 0.029855398328176568, 0.019001784568120326, 0.01838178506919316, 0.031374112370290926, 0.026508805940725973, 0.013410377815099699, 0.04354858445003629, 0.021896530308627656, 0.11133380872862679, 0.04951842375365751, 0.05423774337396026, 0.0057839614206126756, 0.021968075040993944, 0.058790492825210094, 0.04485272875587855, 0.026006016580920135, 0.051413514385265965, 0.03152095413367663, 0.023425220511853695, 0.014871842161353146, 0.04818725339802248, 0.005672381425808583, 0.03082852271784629, 0.04367957563538637, 0.0325978231350226, 0.037999962722616534, 0.02727506366292281, 0.010483919044158288, 0.004842822323553264, 0.02416791271285287, 0.04726706491783261, 0.04793482819305999, 0.02115351749983217, 0.04174989668120231, 0.010757746091777725, 0.056026711128652096, 0.01744733039023621, 0.019330945298341767, 0.008712951975342418, 0.02578813220108194, 0.032646151791725836, 0.014573006857452648, 0.039524356102836986, 0.03262122580781579, 0.031542589222746234, 0.013447869419386345, 0.07774538214185409, 0.0020372988489855614, 0.0816171368850129, 0.01646237574251635, 0.08482864991362606, 0.0428773097560874, 0.03913565392472914, 0.06496808598084108, 0.021007987005370002, 0.03451841989798205, 0.07904417959174939, 0.02788732786263738, 0.021416434552520514, 0.065207500276821, 0.025436048861593008, 0.02667211744535182, 0.06509869040123054, 0.04155216818409307, 0.026819669974169562, 0.055736030119338205, 0.016939134802669287, 0.06245872098952532, 0.009525913262872823, 0.09809730042304311, 0.0853587214701942, 0.027840573407177414, 0.06487291465912547, 0.010668964025431445, 0.04209164423601968, 0.02013880739520703, 0.01842818668644343, 0.030876121949404478, 0.05090168524267418, 0.01614876194590969, 0.02856904181784817, 0.07019572332501411, 0.06791961153170892, 0.027465555584058166, 0.028992101616625274, 0.03402601042762399, 0.02654695317947439, 0.1454306412488222, 0.04575000310848866, 0.05709209931748254, 0.060899678218577585, 0.042156563073928864, 0.02266344620979258, 0.00932981918698975, 0.017785327342737998, 0.048464974388480186, 0.08636562672576734, 0.03036205703392625, 0.02861295999693019, 0.06664890543158565, 0.0694401270842978, 0.06185681971588305, 0.0066033335918161485, 0.04553577942507608, 0.03999302024021745, 0.0514503927635295, 0.03666434456993427, 0.08880632397319589, 0.014281379291787744, 0.02035625242362065, 0.04622994449787906, 0.02255264313758484, 0.04528976298336472, 0.09576236642897129, 0.045282417841787846, 0.007381135315102125, 0.022202815927032913, 0.056161118737821064, 0.03538899729028344, 0.010869512683711946, 0.009432319535075553, 0.01945451839960047, 0.02551267242857388, 0.05989625384765012, 0.01650720994387354, 0.02319161108295832, 0.03294356047574963, 0.022868964288915907, 0.04259637250964131, 0.026106853670041476, 0.07653676199593715, 0.027134338892730217, 0.02685038046911359, 0.05017192761546799, 0.03811592774997864, 0.039785958493926694, 0.03219098710854139, 0.02513191589553441, 0.02437474884624992, 0.015383661125919648, 0.017570168977337222, 0.016629753368241445, 0.015509427591626133, 0.027324878311316882, 0.03687905679856028, 0.01374535952761237, 0.022657268148447787, 0.12369610608688422, 0.12192059707428728, 0.06863579167319195, 0.10746941609042031, 0.18175648844667844, 0.11633976868220738, 0.17630990142268793, 0.09168615551399333, 0.1095843758167965, 0.0802722397659506, 0.14305476445172513, 0.07912191934883595, 0.09919337875076703, 0.15978954147015298, 0.14950681823704923, 0.07286509365907737, 0.14257498591073922, 0.1318380106240511, 0.15095277636178903, 0.0710202655089753, 0.21290701335029943, 0.10775978836630072, 0.18962818676871912, 0.15522317721375398, 0.13961726533515112, 0.2131249045154878, 0.07211367719407592, 0.09840462928903954, 0.23694274574518204, 0.06360228319785424, 0.06634070804076535, 0.16268571891954967, 0.1715760747236865, 0.0749602062361581, 0.10427189445389168, 0.12791398832840578, 0.12506602757743426, 0.15543524654848234, 0.0916223121540887, 0.16082027687558106, 0.1258489755647523, 0.09308550506830215, 0.16191696588482174, 0.12904505192169122, 0.10424616440598454, 0.1534355767071247, 0.1371939860816513, 0.1391452220933778, 0.08873273006507329, 0.15008239235196794, 0.11510562204888888, 0.05889647999512298, 0.15578599487032208, 0.1358600269470896, 0.08415434216814381, 0.10829181410372257, 0.051481194860701046, 0.0878433742161308, 0.20388692165059702, 0.06297267733940057, 0.08898372016847134, 0.07019349094480276, 0.10605842966054167, 0.1516055813325303, 0.16721644651676926, 0.11272544333977358, 0.16623919324151107, 0.18167410072471413, 0.23175664831485066, 0.16110965849033423, 0.06478442012199334, 0.182796411216259, 0.10777449900550501, 0.08908143599650689, 0.07976081435169492, 0.16213474848440715, 0.057096801565161774, 0.20017035465155328, 0.1553664430975914, 0.2427798839552062, 0.13895094394683838, 0.12784124937440666, 0.09604433165597064, 0.09414032846689224, 0.15306763430791243, 0.17494672457022326, 0.16123863442667893, 0.10378346459141799, 0.1800553197307246, 0.06880727104310479, 0.06904863951993839, 0.17882527144891874, 0.09096527991018125, 0.18108150895152772, 0.142708440178207, 0.08981638441660575, 0.09805139752903155, 0.12675878245915684, 0.1485776730946132, 0.2830752560070583, 0.14563117548823357, 0.12624640709587506, 0.08657973845090185, 0.107128397960748, 0.11861273885837623, 0.1378239244222641, 0.11719274148344994, 0.08788782504520246, 0.0749835003433483, 0.17992391463901314, 0.14220458721475943, 0.12190296873450279, 0.08641234386180129, 0.1973950242889779, 0.08794696615742785, 0.1225618262376104, 0.460305888737951, 0.0708298889387931, 0.09912583737501077, 0.20909838271992548, 0.10214086701827389, 0.10812068757201944, 0.08674580311136586, 0.18206248059868813, 0.14040364670966352, 0.15292644474123204, 0.14515778874712332, 0.11700565580810819, 0.15220858183290276, 0.09094949718564749, 0.1260554673416274, 0.09545633356486048, 0.2738547793456486, 0.11487751214631967, 0.19078757241368294, 0.14530661861811364, 0.18802784835653646, 0.2179640805614846, 0.1134963541158608, 0.09910098263727767, 0.15304125286638737, 0.13862688919263227, 0.12960059568285942, 0.2005461680569819, 0.1058675916865468, 0.13739701732993126, 0.29295133320348604, 0.1088817392342857, 0.1306344387786729, 0.08343046065419912, 0.09814135091645376, 0.08474844028907162, 0.12349041498133115, 0.16562344985348837, 0.2184084802865982, 0.08890026036117758, 0.060555667749473026, 0.13481071325285093, 0.0825114528249417, 0.2517516368201801, 0.11539167884205069, 0.09513786315385785, 0.09781155575598989, 0.1446904002555779, 0.09368737241519348, 0.15217282303742, 0.10592339440648045, 0.0518184844404459, 0.11758321124528136, 0.10625170357525349, 0.10275371306176696, 0.10477673807846648, 0.1274252531251737, 0.20174148891653332, 0.10582317478422608, 0.10289877027805362], [0.015260423899495175, 0.04997221779610429, 0.04245283521179642, 0.014459330189440931, 0.035892894358507225, 0.040356575910534175, 0.08453320219580616, 0.07957294157573155, 0.04737447022593447, 0.008702831625539278, 0.012383775536103972, 0.027624582140041248, 0.0401847708438124, 0.044038422272673676, 0.028090644095625197, 0.05236029465283666, 0.02232937967138631, 0.05148476056222405, 0.02953266671725682, 0.03074744456846799, 0.02106807637028396, 0.028959399621401514, 0.015186466975137591, 0.03457025318805661, 0.08773292228579521, 0.015381555971024292, 0.03032044248123254, 0.022544351439656954, 0.04117657190987042, 0.06128317942576749, 0.033558652470154424, 0.060203888054404936, 0.028302874582420503, 0.048613471777311394, 0.050450649445078204, 0.0415523004984217, 0.03270426153072289, 0.03237618984920638, 0.0447445125984294, 0.021674157419641103, 0.03055233182385564, 0.013000826800375112, 0.0324460619927517, 0.023190827375011783, 0.04435756104066968, 0.023928148971338357, 0.023040821942101632, 0.047650369349867105, 0.05604993738234043, 0.02894738955157144, 0.025949250341260006, 0.003234803319043879, 0.05537988744410021, 0.03926019224205187, 0.030132149013557603, 0.04129361920058727, 0.08309709639953715, 0.025817824893497994, 0.08723107778600284, 0.05164370060499225, 0.06736419669219426, 0.026170788632173623, 0.018262593607817377, 0.048845554502414804, 0.04310446631695543, 0.054174955136009624, 0.020127251943839446, 0.027517561900562475, 0.02534967305005661, 0.010984594767381037, 0.029225215714957033, 0.03548998026443379, 0.028884757376675094, 0.04056876738156591, 0.0265090179829193, 0.030834269909454242, 0.030570462279553925, 0.03555178123393229, 0.0596933447356735, 0.0511621782290084, 0.007379317689420921, 0.016033628123945425, 0.05048077639990619, 0.08721842310790505, 0.01709368811654193, 0.03245880488040192, 0.012872079869599214, 0.02415302735088127, 0.03586570546030998, 0.03323599210541163, 0.030500949759568487, 0.041948425849633555, 0.0205690630578569, 0.05449585470237902, 0.055819276188101084, 0.08425270260444709, 0.04223741391407592, 0.03422577113711408, 0.0499798988125154, 0.0602799654006958, 0.023245758177446466, 0.04017778193312032, 0.03611586096563509, 0.05615461837234242, 0.013465361203998327, 0.03373242189575519, 0.025129905735541667, 0.0398111083943929, 0.026378260892150656, 0.03695631479578359, 0.051275992300361395, 0.005356414384940373, 0.03856128081679344, 0.044445848624621115, 0.04494773383651461, 0.06428701324122292, 0.037185601956610165, 0.03022926433810166, 0.010313828974696142, 0.019606842725936855, 0.03931533678301743, 0.048221546557864974, 0.04451640948121037, 0.007734589295328728, 0.10081684163638524, 0.026938213434602534, 0.033620762173086405, 0.0448646506161562, 0.01645307811642332, 0.06929451346929584, 0.01770355539130313, 0.017438567110470364, 0.04461566897641335, 0.04030686643506799, 0.05273856435503278, 0.020552362614710416, 0.03029779976766024, 0.06540350190230779, 0.021284488329131688, 0.06771399506500789, 0.02321723595793758, 0.03436965448781848, 0.03691031351419432, 0.06987372453191451, 0.07509016604827982, 0.030913516014282192, 0.012290024048914867, 0.046723314095288515, 0.024532455651621734, 0.02503981833745326, 0.01993997797503003, 0.010320991759986749, 0.02788538046713386, 0.0349796608622585, 0.04431141048137631, 0.0421383715500789, 0.021066451278914298, 0.018568707896130424, 0.056190791074186563, 0.03558210496391569, 0.0326475801079401, 0.028044483358306543, 0.038067110548061986, 0.02557728422938713, 0.030006141667919498, 0.03360858925485185, 0.03084879055885332, 0.04765735826055918, 0.047028695565781424, 0.010261223002869104, 0.04051216059763517, 0.03652147562908275, 0.04447252522887928, 0.014993554380323206, 0.045267598636980565, 0.025806052310924445, 0.035918597265013626, 0.02347972383722663, 0.025466772927237407, 0.042084858885833194, 0.039868668520024846, 0.03459915199450084, 0.026480677271527902, 0.025162974139675498, 0.024336912037272538, 0.030777995607682636, 0.04560092557221651, 0.025757151988468, 0.015751148906669447, 0.018472939463598386, 0.010495583061128855, 0.05841265060007572, 0.09031636973044702, 0.006886830611620098, 0.014509896315368158, 0.02662572600612683, 0.025457266651626145, 0.02060067600437573, 0.02356752796497728, 0.07016061592314925, 0.005361106454594327, 0.03160197800025344, 0.026987279998138547, 0.044369299696492295, 0.018288152325632315, 0.028233572408290844, 0.01749558949710003, 0.04697385975824935, 0.046428538127137084, 0.027613464343760694, 0.05811579831476722, 0.03290347941219807, 0.1433214151433536, 0.035999190261853595, 0.04739445986758385, 0.059918170528752465, 0.02863230842298695, 0.041512165152068646, 0.044793723350656886, 0.06790315027215651, 0.023451953095250895, 0.02360672184399196, 0.068985786821161, 0.03186839798997555, 0.043590277034257136, 0.04216742641957743, 0.024363905856651918, 0.027715183528406278, 0.01850954642785447, 0.04528847376682928, 0.029718510673514435, 0.053676703479141, 0.0452331901261849, 0.044424454415483136, 0.028844940941780806, 0.0313294444100133, 0.03734492537166391, 0.02579882930565093, 0.010210969003050454, 0.0412030381682728, 0.022500699585569755, 0.03888385297198381, 0.06848563865891524, 0.017945772036910057, 0.005323530457514737, 0.05183064039530499, 0.02185215751108314, 0.025621299099709307, 0.04363395433340754, 0.04716114899409669, 0.01327597359860582, 0.021916757437533567, 0.02961971258212413, 0.045942907221615314, 0.02128948743588158, 0.044356933395777426, 0.009470562616895353, 0.014713204066668237, 0.027089068732623543, 0.056400071629988294, 0.03347105359924691, 0.03092846753341811, 0.04000378180561321, 0.02749199979007244, 0.08232438750565052, 0.03755982419742005, 0.09195352545274155, 0.01443707084815417, 0.018510854304102913, 0.05247085514877524, 0.03169318328478506, 0.08004792287413563, 0.003804918619737561, 0.011351925636907774, 0.0016722230481848652, 0.05103269339139972, 0.011255019810050726, 0.06074817491961377, 0.0331658756892596, 0.047107870424432416, 0.004134415224793234, 0.0391226735498224, 0.07965549214610032, 0.055390014579253535, 0.027913583775183985, 0.058856419287621975, 0.028327858241807138, 0.03022977663204074, 0.022276844097567455, 0.02204396409381713, 0.030118703842163086, 0.02403423113615385, 0.03151707291336996, 0.022727852753762687, 0.052299840575350184, 0.04275463741006596, 0.021440042482156838, 0.02665945598190384, 0.004961033301827098, 0.011289554697993611, 0.03994814871943422, 0.029490804499281303, 0.04891525022685528, 0.06128184949713094, 0.027929714248914803, 0.022672455458502685, 0.013277144071512988, 0.0255838507520301, 0.015247319691947528, 0.030387515667825937, 0.03595413214394024, 0.04706879020003336, 0.04557536176538893, 0.023606184104989682, 0.023138091633362428, 0.030768441834620068, 0.023608748967360173, 0.034569272704954655, 0.028778071315693002, 0.0419154694037778, 0.039653678092041185, 0.022114774312025735, 0.04381988989189267, 0.036074989408786805, 0.016727357237998928, 0.03092556679621339, 0.013692843461675304, 0.023746556036972573, 0.025525332195684314, 0.018893612515447394, 0.018355213637862886, 0.01424161035434476, 0.024637073877134492, 0.06772335206291505, 0.015405486204794474, 0.04911630693823099, 0.038363640529236624, 0.02289197680407337, 0.04005610364090119, 0.034074963336544375, 0.01704676742000239, 0.027829783004043356, 0.015039331745356321, 0.08102898951619864, 0.021104245679453015, 0.015236269749168838, 0.06058333840753351, 0.011996538993636412, 0.014588348534224289, 0.014667328314057418, 0.05593102751299739, 0.05778866979692664, 0.10429706131773335, 0.13971779708351406, 0.2045755804117237, 0.11889982702476637, 0.16860110578792437, 0.17628429351108416, 0.19603595935872623, 0.13235970905848912, 0.10399565606244973, 0.10372179932892323, 0.15728553012013435, 0.12665253744593688, 0.12617997851754936, 0.22356921407793248, 0.14870727328317507, 0.14954283487583908, 0.16089035597230705, 0.1240536126175097, 0.07844358789069311, 0.13468389505786554, 0.06413637168173279, 0.09114661839391504, 0.06814032540257488, 0.16891705883400782, 0.1516205905271428, 0.09309929289988109, 0.21498850094420568, 0.11532668875796454, 0.10080146603286266, 0.15376575184719904, 0.11822677456906863, 0.16648478220616067, 0.07633132873369114, 0.13847176251666887, 0.2574812136590481, 0.11430989046181951, 0.2273196806865079, 0.1593523206455367, 0.11843446056757655, 0.08382111362048558, 0.10003948477762085, 0.1000214900289263, 0.16828516631254128, 0.18795823066362313, 0.12919589025633677, 0.08911333392773356, 0.13102471855069908, 0.07815964134143931, 0.21270905754395894, 0.10846161749213934, 0.07322425581514835, 0.05475920771381684, 0.0640927418800337, 0.10559110902249813, 0.09658041503280401, 0.11329510062932968, 0.17443842041705335, 0.2211646759616477, 0.1643119773694447, 0.12641655653715134, 0.15977800637483597, 0.10247765787478004, 0.13280626652496202, 0.0983148387500218, 0.11359634303620883, 0.16583987538303646, 0.12162361586732523, 0.11068802659532853, 0.1078997158578464, 0.12071060628763267, 0.14605762117675372, 0.10533251254154102, 0.08386690116354398, 0.21781135589948722, 0.11348931770771742, 0.12403690708535058, 0.10488448943942785, 0.19033372748110974, 0.1298247700823205, 0.1595523256276335, 0.08182407649500029, 0.09499018000704901, 0.14247628620692662, 0.24632965347596578, 0.08424925564655236, 0.09408548248133489, 0.10418007509516818, 0.09013612368809325, 0.10841013704027448, 0.14646468790514128, 0.1912258653236287, 0.1662874235106366, 0.11498238651880197, 0.11288895670856748, 0.1355753272239651, 0.15322713074939592, 0.1132116543927363, 0.09414553283048527, 0.1519824125404869, 0.19958716737372534, 0.13792951804186615, 0.16506981956107275, 0.12647666116910322, 0.11916185010756765, 0.07609891691910368, 0.0745211262255907, 0.14705632972930158, 0.1721775417349168, 0.0855619969910809, 0.14336199153746876, 0.08996531606784888, 0.10488026895161186, 0.12453717738389969, 0.14679468662611075, 0.17907981707581452, 0.1635593327560595, 0.12846893497875758, 0.09800230552043233, 0.099123007883983, 0.11623494859252657, 0.12069721200636455, 0.15005316106336458, 0.18986925669014454, 0.09397767683757202, 0.1613272103880133, 0.096322877066476, 0.1565553450158664, 0.15639257803559303, 0.08699772280773946, 0.1747939863375255, 0.14019980121936115, 0.06992432288825512, 0.13233057276478835, 0.09731226254786764, 0.11027654938931976, 0.1613293681293726, 0.1578896434179374, 0.15401611769837992, 0.0989843967503735, 0.14000065119138785, 0.17545131035149097, 0.16529165980006966, 0.1369733807763883, 0.16707503981888294, 0.10001098630683762, 0.12613887286611966, 0.11570916537727628, 0.0791732437376465, 0.1526814257459981, 0.12577451313180582, 0.09395743613796574, 0.1886698239083801, 0.16309278564793722, 0.07862535385148865, 0.1626604502754552, 0.10209917782672814, 0.11844971403479576, 0.16270315726952894, 0.06829522816198212, 0.15776738497827733, 0.11396983585187367, 0.06263480761221477, 0.1649856540773596, 0.1141139024070331, 0.11731896256761891, 0.18639914718057427, 0.08440147819263594, 0.1385985128581524, 0.15548700519970485, 0.06334117613732815, 0.16969186440110207, 0.11099634612245218, 0.11215370973306042, 0.0702716853203518, 0.14144690787153585, 0.10808744614145585], [0.03377072859023299, 0.013502757813382362, 0.03468243877536484, 0.09297340429787125, 0.04406393858204995, 0.10488634184002876, 0.06873888149857521, 0.023894093298752393, 0.01486967084929347, 0.026607885624149015, 0.04867459760446634, 0.035642606538853476, 0.020391712663695216, 0.042645953063453944, 0.02291011404512184, 0.03914735186845064, 0.03588739822485617, 0.0789470337331295, 0.036794711503067186, 0.06275578362068959, 0.056406751807246885, 0.04099508754110762, 0.008786368616191404, 0.052191129087337425, 0.022031031216361692, 0.03765850693785718, 0.03912125201895833, 0.051535803359001875, 0.03008410194888711, 0.016237069885911684, 0.03272293820711119, 0.03685107062171612, 0.010891382715531757, 0.022802133678591678, 0.020297075688306774, 0.01014106547726052, 0.07643968399081912, 0.044328499385820966, 0.05572073594001787, 0.02090848154122276, 0.0839244205770748, 0.015401148669687765, 0.031011119884039675, 0.05568795930594206, 0.013107395814066487, 0.006927685629177306, 0.04569781358752932, 0.017268190359962837, 0.031120903457381895, 0.04335762433973806, 0.05781199783086777, 0.04311085133148091, 0.0749037249812058, 0.015653609497738735, 0.045924291613378694, 0.05845588006611381, 0.007593064701982907, 0.03742131484406335, 0.0610640872535961, 0.11075927277228662, 0.03073249983468226, 0.02207536669448018, 0.016394478135875294, 0.01483036670833826, 0.04041320983586567, 0.026867827300780585, 0.039069890310721736, 0.06267854597951684, 0.03254728923950877, 0.05541004154032894, 0.053621365555695126, 0.027061023183965256, 0.08332673979124852, 0.03545369899698666, 0.04485353621255074, 0.04500424901821783, 0.03312218142673373, 0.026684152960245098, 0.06716233252414636, 0.03434821956657937, 0.05004702288923519, 0.04551823590216892, 0.014339870706732784, 0.030156851080911498, 0.004581646561356527, 0.043377868432019434, 0.034908686099307876, 0.04169676399656704, 0.021653282289792384, 0.008379586872511675, 0.07907233200967312, 0.019165506586432457, 0.04395198369664805, 0.04583946455802236, 0.02993539421420012, 0.05755750648677349, 0.010987351315894296, 0.05762131591992719, 0.0312892310321331, 0.024107955662267547, 0.07580794753240687, 0.016003541881218553, 0.026757765528080717, 0.02160396975731211, 0.037161551282874176, 0.01363951400188463, 0.03792577509635261, 0.06257162243127823, 0.02877510611766151, 0.019320882624015212, 0.03524547695581402, 0.05975596673254456, 0.029112660326063633, 0.01584831003232726, 0.0499860191983836, 0.09101660429899182, 0.05012476943167193, 0.04915650674541082, 0.03949803572946361, 0.0552893776579627, 0.058712183098707876, 0.08766913999404226, 0.017718306742608547, 0.07989707096878972, 0.03976071359855788, 0.055656689019607644, 0.009992152485730392, 0.01795329529392932, 0.0060936473476301345, 0.028200407312916856, 0.05585037005533065, 0.014833993478012937, 0.028627521358430386, 0.039342569785990884, 0.028518650414688245, 0.04284331854432821, 0.05860673875680991, 0.023329764205430235, 0.05743759577827794, 0.04245380551687308, 0.05584754395697798, 0.017828351551932946, 0.0250476062231298, 0.03967737592756748, 0.03659750208524721, 0.05491728601711137, 0.049211478259946616, 0.015291075022625071, 0.08399648099605526, 0.02031138090283743, 0.036391821157719405, 0.017655633855611086, 0.004332165774290583, 0.0231341137218156, 0.003970293294904488, 0.046012406170900376, 0.03816091122903994, 0.02440176471801741, 0.0645633941250188, 0.026389185305950896, 0.020021022197657397, 0.043471112714282105, 0.028693919402680228, 0.04712147505155631, 0.005545134481508285, 0.022732351440936327, 0.031508581047611575, 0.03006238882829036, 0.03217801691165992, 0.016696755308657885, 0.05127038420843227, 0.04321248230657407, 0.030937061179429293, 0.04735059936397842, 0.03965373576751777, 0.029641045723110437, 0.040758787720863304, 0.024469972754429494, 0.010124525338012193, 0.06046686787158251, 0.04045795922034553, 0.022387000865169933, 0.09274122997054032, 0.05664561648986169, 0.022305586840957403, 0.054820913688412735, 0.04214820012982402, 0.031086213354553496, 0.03028945378693087, 0.03850804974458047, 0.020163658740265027, 0.035167750769427845, 0.06043891901416438, 0.051319170876273086, 0.020889055083638856, 0.0378896329285843, 0.03290944712768708, 0.03246753762609192, 0.020893752242305448, 0.03284186843250479, 0.04420849368242281, 0.06193633044936827, 0.012799921063041049, 0.07941305158393723, 0.027728409872257283, 0.03315842876742993, 0.011432941021796848, 0.06827496710632529, 0.06023467318820102, 0.01608139698925827, 0.017186068962993364, 0.0413512370016958, 0.032139136855091364, 0.027603678172454238, 0.09160688905311482, 0.05228120121838791, 0.015713695469977598, 0.014698389950873596, 0.026483247222911035, 0.03547368185328586, 0.011157269207095461, 0.020544191356748343, 0.06181739004594939, 0.024846921009676795, 0.08205370631601129, 0.045921882814062495, 0.030570187472871373, 0.016955070197582245, 0.015273215980934245, 0.022732521074690988, 0.028398917821635093, 0.024090849794447422, 0.03598628791847399, 0.01217301153311772, 0.013662348401599696, 0.052033366302826574, 0.032716719433665276, 0.01148246559647045, 0.09350383547799927, 0.019053241271259527, 0.010629760816560259, 0.00896415496910257, 0.005955064203590155, 0.07635601383766957, 0.04000404643427048, 0.04217947720150862, 0.01946225539515061, 0.0273058674564319, 0.05273506650701165, 0.01298665814101696, 0.05862840437995536, 0.019667910877615213, 0.03471692192501255, 0.032088908300335915, 0.052221937969859154, 0.009358123427123895, 0.01971122176785554, 0.029800101116831814, 0.010543177203674401, 0.011542174981773963, 0.07305262716753141, 0.030447640655828372, 0.03913469719035285, 0.046625659335404634, 0.06585633581770317, 0.059812746542905054, 0.09370858341987644, 0.07913426190082516, 0.045139552293611426, 0.0545253845463906, 0.030028899732444967, 0.0463505133853427, 0.02016558069070535, 0.033361154674951515, 0.02934653777629137, 0.02351684309542179, 0.04560563121257084, 0.06450062963579382, 0.038021926901170185, 0.032764613827956576, 0.029598684781896215, 0.057353226734059196, 0.023984533535050492, 0.0364640172837036, 0.012866200363662626, 0.03395569723631654, 0.056573756238711734, 0.05687598591404302, 0.030504946330828325, 0.016764790318640213, 0.028920522957508053, 0.052831208133803945, 0.021710956070039953, 0.04233752157805221, 0.0177296501517828, 0.045200946142098734, 0.05061734175043447, 0.05520468630961009, 0.02502440880717976, 0.03434269968420267, 0.04095934570900031, 0.03600940899923444, 0.010895012029712754, 0.03192349164081471, 0.023386474465951324, 0.0603786651045084, 0.033926408272236586, 0.020417924471465603, 0.07140038761177234, 0.04534537571349314, 0.009479750829216625, 0.05620363913476467, 0.023510424154145376, 0.029520419160170213, 0.006408775125497154, 0.013037386267179889, 0.06300578306296042, 0.0044077376119925505, 0.04756224461432014, 0.02298690046050719, 0.013114981835574975, 0.026629685257960643, 0.012229464798500496, 0.016623166489547918, 0.03413989913782903, 0.02174207877500781, 0.03699256552915488, 0.025816342294482247, 0.015748991165310144, 0.04151946618886931, 0.003655575606639364, 0.03026166438524212, 0.022785967581772378, 0.03130159733284797, 0.08932098599949054, 0.030404574038194757, 0.012084539896542472, 0.0189682869905872, 0.028310185797246437, 0.03774916260902371, 0.038213813211768866, 0.006095394999387541, 0.02911847537117345, 0.03313306512843285, 0.0541877692698368, 0.06835527172578232, 0.019205177136297737, 0.0060403509664216214, 0.04635285433115704, 0.07009760037596736, 0.03417106085856046, 0.023663333716935346, 0.14027414151600429, 0.07382374150412423, 0.08772030153444835, 0.194018403334277, 0.15205872058868408, 0.18544359345521244, 0.16707038506865501, 0.13539738820067473, 0.1355932948312589, 0.12355445511639118, 0.09891849064401217, 0.11958194470831326, 0.0771385682746768, 0.23076349017875536, 0.11622440415833678, 0.11006952156977994, 0.14745954237878323, 0.12495720413114343, 0.12615126291556017, 0.16591243791793073, 0.20179634168744087, 0.178068786327328, 0.10155191219278745, 0.08160527609288692, 0.15484132484665938, 0.10185141076466867, 0.16420478240719863, 0.14624390618077346, 0.09666673825787646, 0.08647624828985759, 0.07654580686773572, 0.14431229340178625, 0.1621337171111788, 0.10723239023770605, 0.12197213859430381, 0.11387914286128112, 0.16103615957711423, 0.1218202281743288, 0.18904413096606731, 0.16372095979750156, 0.08223108215523617, 0.11976236716977187, 0.11106331752879278, 0.1401706106428589, 0.06429604454232113, 0.13508214083101067, 0.13482029416731425, 0.11557793670466968, 0.24750883877277374, 0.13263746058302267, 0.13969471332217964, 0.14674722988690647, 0.19421151440058435, 0.10783743991383485, 0.21385622955858707, 0.07282317376562528, 0.07682532936866794, 0.11438978117491518, 0.08097803153629814, 0.141609484862004, 0.09736014676413365, 0.1199942904391459, 0.2274912279099226, 0.09651544530476842, 0.13941720607025282, 0.0815078452495592, 0.1638462987861463, 0.265926613339356, 0.13987019604870252, 0.18057680103395665, 0.09340715780854225, 0.08557171361254794, 0.15649437185909065, 0.06628652023417608, 0.16041972408337252, 0.16289268567093781, 0.12803710172218935, 0.1765493428600686, 0.231936514377594, 0.1597051452845335, 0.10232938440250498, 0.1468060045902218, 0.12345408621643271, 0.08783165591635875, 0.09039591439068317, 0.12893291722450936, 0.18941223621368408, 0.12407200091651507, 0.08705051283219031, 0.21752155359302247, 0.16223192826977798, 0.26402997225522995, 0.18595633522740432, 0.1294801692877497, 0.07762726276580777, 0.1062556594344122, 0.06377017990286861, 0.1623616505946432, 0.10357548682285206, 0.10877245438418218, 0.1574995672064168, 0.12895870155521802, 0.1031457773808922, 0.15528876440865652, 0.1300391192947115, 0.11122153153909103, 0.10650099734110491, 0.14909342756228788, 0.0981897779607347, 0.09465140782828842, 0.1490059643983841, 0.12892443553677627, 0.12830307387879916, 0.1286780187594039, 0.16240196914545127, 0.14901587100965635, 0.1340174243918487, 0.1658754984715155, 0.11416346260479518, 0.12759354338049889, 0.17711893229612283, 0.31106083574039595, 0.13770778636847222, 0.2810859813221863, 0.13926829477506025, 0.13245217981083052, 0.10941332392394543, 0.11817882928465094, 0.0963735839884196, 0.08532957839114325, 0.12852602691522666, 0.14030349494091102, 0.16129801981151104, 0.09335740083562476, 0.07702367872531925, 0.163878379921828, 0.2043235453643969, 0.11730543257934706, 0.11245156625019652, 0.2026832140982151, 0.14354930791471684, 0.0829052949058158, 0.05030052696487733, 0.07193091378680297, 0.12569850363901683, 0.16488993992762907, 0.1491687178079571, 0.0973260368087462, 0.15137424160327229, 0.09122714014457804, 0.12832235784402915, 0.11766011640429497, 0.15916006453335285, 0.09264605864882469, 0.06818462016859225, 0.11970904788800649, 0.08814828071211066, 0.1592005459325654, 0.1479486439909254, 0.08435480176870312, 0.07559619710913726, 0.09221250869865928, 0.11280126284275736, 0.1925910777811493, 0.13709861119943006, 0.09487073748771634, 0.12484798713454179, 0.17121292278170586, 0.198891424707004, 0.15538399001317366, 0.2285279615649155, 0.1242805825812476, 0.07922421528824738, 0.12971654374684605, 0.12210378795862198, 0.10498343341584716], [0.05693999890770231, 0.09029515194041388, 0.03497280426589506, 0.03503500217837947, 0.021095858986622522, 0.024748845558081354, 0.020810317880074893, 0.017923483857885003, 0.04114380545381989, 0.018768380396068096, 0.03395340718062861, 0.06399967401687588, 0.021524401348350302, 0.015044646370889885, 0.032573263560022624, 0.032514054594295363, 0.06615656720740454, 0.06478904773082052, 0.06604990150247302, 0.01835774626981999, 0.05023172012131129, 0.029335891561848775, 0.016521742467635443, 0.012760724639520049, 0.03609638361792479, 0.05340005796668785, 0.010394905427736896, 0.01599522304188992, 0.015048712491989136, 0.031650947872549295, 0.030318220279046466, 0.048677824038480005, 0.02517646680852132, 0.025649017255221094, 0.08328303535069738, 0.017018173954316547, 0.04921317459749324, 0.03294937552085944, 0.040761970050100765, 0.010713718498923948, 0.042196691634931734, 0.026179557000952106, 0.02133747173606285, 0.020487526897341013, 0.0506488495240254, 0.012400771990152342, 0.0393152519661401, 0.04362828856600182, 0.02300321074601795, 0.02929112860666854, 0.0556736829291497, 0.018365915831444517, 0.004733865714765021, 0.04038490474756275, 0.07689589701060738, 0.0570381489981498, 0.00742126811694886, 0.05426897634086864, 0.050852318427392414, 0.03929391882515379, 0.06125223144356694, 0.029386493310864483, 0.026572150577391897, 0.03248026694304176, 0.06631463193999869, 0.02659676782786846, 0.0375386131927371, 0.06684900540858507, 0.05294802472261446, 0.01753656622687621, 0.034169133819107494, 0.0285563260715987, 0.01746467374531286, 0.03552028363836663, 0.04724786237680486, 0.05192367433171187, 0.03555844784049051, 0.019346108859671012, 0.0916207040260945, 0.029961290503186837, 0.03404132496299488, 0.05987515140857015, 0.02944450805495892, 0.059677833425147195, 0.030940430105796883, 0.018274898840380565, 0.007848578937617796, 0.053198248081441434, 0.03611625112327082, 0.04472632107457944, 0.020310147665441036, 0.049523536515023024, 0.04475023264863661, 0.04585534567013383, 0.010078364600693541, 0.048239035797970634, 0.05286885664931365, 0.06478032855583088, 0.07327043690851756, 0.013482928475631135, 0.0808717729523778, 0.05964716364230428, 0.02394410641863942, 0.011319447558240166, 0.0813236501333969, 0.028364039425339018, 0.0550216922004308, 0.011571321453500007, 0.004471763752267829, 0.009910948807373643, 0.03466613018619163, 0.010018439780521606, 0.06963274282004152, 0.04720964728455458, 0.035086686190749915, 0.024258179922721217, 0.057404992170631886, 0.003392461354711226, 0.025165808719715903, 0.02791905785644693, 0.022545214875468185, 0.022144885999815803, 0.03367634436913899, 0.1128985851204821, 0.056404583887862306, 0.06855136156082153, 0.01563276829464095, 0.06700680551252194, 0.02184325852431357, 0.03210193617269397, 0.014313735234151994, 0.0420353563635477, 0.020009509154728482, 0.07229649488415037, 0.015809657284989953, 0.0701080769566553, 0.1242627099688564, 0.021991835641009466, 0.02547403664461204, 0.007985568372532725, 0.044858316491757116, 0.049829464206205945, 0.065206190704235, 0.012646209980760301, 0.014022355333768895, 0.008580598630942404, 0.018960081805874194, 0.039206811892134805, 0.017850807668375115, 0.040560431578861814, 0.049035388244582076, 0.029969690766717707, 0.02144564887774842, 0.014028411258810332, 0.021038078337109516, 0.0689346252807549, 0.021015118408415998, 0.0731899897967066, 0.037486254038023095, 0.0037403369289157645, 0.028875400378767933, 0.017614753817075064, 0.04209714376234582, 0.043698242133749385, 0.031377328626279316, 0.047127324023417065, 0.03400184440293482, 0.030931337736546993, 0.026184235499905686, 0.040740837076944966, 0.006108114986480879, 0.026083233866042325, 0.04390279669314623, 0.10242799589676516, 0.020003059679376226, 0.11366035602986813, 0.06726104579865932, 0.025988691885556494, 0.02868010103702545, 0.08339469507336617, 0.008926338516175747, 0.027786702815709368, 0.048241882252373865, 0.03678393975964614, 0.020636202401614616, 0.02844042720140091, 0.02964836372328656, 0.022982193123815314, 0.037342469074896405, 0.051599405838974884, 0.03577846621296235, 0.015519254475033708, 0.01632447537433888, 0.04605175780930689, 0.016813215666583607, 0.026337545398356657, 0.006056786780910832, 0.02274023092884038, 0.015435748866626194, 0.018326542140649896, 0.03922414167651108, 0.02882030333525368, 0.01689044143339353, 0.012733112505104924, 0.030746168922632933, 0.025239344952361922, 0.05566730809264949, 0.05020699430523174, 0.064706470019051, 0.016316541603633335, 0.029435534429337298, 0.015602565004623361, 0.03661113724644695, 0.08756215537765197, 0.043263138338391266, 0.03318775165826082, 0.014877972725246633, 0.07397267994071756, 0.025305164545508366, 0.039178822322615554, 0.03315400471910834, 0.00889856438152492, 0.00610015110578388, 0.028165135366309966, 0.0755317702091166, 0.05091904216845121, 0.05837167387029954, 0.05439074284264019, 0.01776309683918953, 0.030413747831646885, 0.041303278146577735, 0.015246332423495395, 0.03707856984276857, 0.012802005861885846, 0.06074858882597514, 0.05968683758484466, 0.050128972956112454, 0.10585079115948506, 0.06154562320028033, 0.006203765523553426, 0.055966528465173075, 0.04606642773641007, 0.016687678206445913, 0.012249594387997473, 0.0559005511126348, 0.007844219350122979, 0.014391685337094324, 0.044201905107391734, 0.03445567237213254, 0.03945510481883373, 0.014854300334783537, 0.04370348042409335, 0.03045354730316571, 0.02953566244936415, 0.05733618871974094, 0.10316307323851756, 0.02526640153623053, 0.02200634271970817, 0.03284341209967222, 0.03154343060616936, 0.04338007027815495, 0.01911207873906408, 0.049483360456568856, 0.051275764991130145, 0.024727699014225175, 0.011337666223490877, 0.11815000511705875, 0.06831971649080515, 0.022525698511994312, 0.012637003108726015, 0.04853131475725344, 0.06963540267731462, 0.03563108501423683, 0.022739720331238847, 0.011448729683512023, 0.03189321880095771, 0.029496042789625268, 0.02343079467703189, 0.009462169138714671, 0.04319960371192012, 0.051210629022014995, 0.012993194977752864, 0.04286713512348277, 0.06041206938347646, 0.027130399996946965, 0.03516835127291935, 0.021274077905608074, 0.0265266140922904, 0.0856108922245247, 0.07578360169593777, 0.04159284296578594, 0.017778158620265976, 0.04363771002473576, 0.07373059221676417, 0.04367702095104115, 0.05085094100130456, 0.06086103564926556, 0.0075184945516022185, 0.005633115452448172, 0.028922653557466607, 0.06170100771955081, 0.06838652504874126, 0.03686547592016203, 0.017939848426197256, 0.04342863642211471, 0.022263605879353623, 0.03972649847024253, 0.03029137404103364, 0.048141143550830226, 0.06930846414927926, 0.011116361178989922, 0.03288460256797927, 0.007645333950806941, 0.02424004437801029, 0.08032458874263934, 0.013242733016211008, 0.03823720570653677, 0.0352484489391957, 0.035165274116609774, 0.02487391482905618, 0.037515570143503804, 0.05013895081356168, 0.02510028428930257, 0.027717950254944817, 0.024564228053869944, 0.03935977743406381, 0.07775845751166344, 0.039551965692745786, 0.05483901361003518, 0.05235982985634889, 0.050485387045357905, 0.023255079552265148, 0.033563907723873854, 0.014964837081996458, 0.04799854602398617, 0.07402262690344028, 0.029505623704088584, 0.028968987321215015, 0.0332241109572351, 0.037748687634510655, 0.008374379964412322, 0.03420956772086876, 0.013736552991239088, 0.022338857109259282, 0.049044120990272076, 0.025322636822238564, 0.021534055205328122, 0.04495783383026719, 0.024131677246519496, 0.024002306063526442, 0.04134217516652175, 0.03450588735618761, 0.14496557334704058, 0.15421353067670548, 0.11688446945377759, 0.3110661283135414, 0.10383127416883196, 0.1360642524170024, 0.2130418653999056, 0.1195214329553502, 0.13479822820850781, 0.12269922957888671, 0.16651295498013496, 0.1488909391420228, 0.08170517680368253, 0.14859399864716188, 0.17625046175505432, 0.09108430173780237, 0.1900894684450967, 0.2287488111427852, 0.21340984851121902, 0.11189497075974941, 0.21856838384909288, 0.14241642584758146, 0.07404352578201465, 0.058404440326350074, 0.11829555087855884, 0.19179111213556357, 0.07714098385934319, 0.05905670925442662, 0.092957967626197, 0.17855567591530935, 0.08078156172164849, 0.1496388611516782, 0.13574002124369144, 0.09687564561941794, 0.1782716547272035, 0.0735063228224005, 0.1744100305118731, 0.2155302975858961, 0.14148405087845667, 0.09000925121030637, 0.1284832249262503, 0.17474226839840412, 0.09694056106465203, 0.11252162499087197, 0.1195786063160215, 0.1269941526864256, 0.12167263323707239, 0.1782715054494994, 0.12308074267847197, 0.16338593991739409, 0.15568065909402712, 0.17628613912633487, 0.12261589190789632, 0.1175034155270883, 0.12302864475974015, 0.15365934398557457, 0.04934399275641356, 0.0949634253712637, 0.10465135159237043, 0.21003959221499308, 0.26917953736015726, 0.20540930995983736, 0.14988373086920806, 0.13602583376424654, 0.16543689343546117, 0.12384466454386711, 0.11051863032792296, 0.1307092947619302, 0.12726769729384355, 0.10403298905917577, 0.11195590320442404, 0.08960062385137592, 0.09387813575033631, 0.14674565568566322, 0.14873544605714933, 0.13458695954510144, 0.09879440694515194, 0.13637122165943893, 0.143904765269586, 0.13649197375135763, 0.06847306540501968, 0.07639084982552699, 0.11989054243479456, 0.12025978762124266, 0.07232698824788843, 0.14343907311558723, 0.14097405038774014, 0.15642294926302774, 0.09163156058639288, 0.09331398137978145, 0.17161123640835285, 0.10584162415138312, 0.13202592411211558, 0.08507460528718573, 0.11984231216566903, 0.21470787243119308, 0.0690540135172861, 0.09797088256371872, 0.1329677850008011, 0.08718118510608162, 0.1322412911270346, 0.10510995984077454, 0.09368110953697137, 0.10998292693070003, 0.1698243280074426, 0.07352123702211039, 0.1432956172419446, 0.07857816852629185, 0.1251985861786774, 0.11536703445017338, 0.12086638435721397, 0.16533716235842022, 0.22083174596939767, 0.1591326245771987, 0.09070945185210023, 0.2168744211750371, 0.1108208294691784, 0.14884512445756368, 0.13760863883154734, 0.12438378775758402, 0.17549595795571804, 0.13770243951252528, 0.14811990622963223, 0.22399043504680904, 0.13108320826930658, 0.13146964753312723, 0.07430844620934554, 0.16816487562443527, 0.10536898379879338, 0.1416160123688834, 0.05997998506895133, 0.16523961616413935, 0.10248907761914389, 0.14059344652507985, 0.11451198533177376, 0.13741178225193704, 0.1904419945286853, 0.10778798828167574, 0.13023600301572255, 0.16491774629269326, 0.16680700491581643, 0.1581833947982107, 0.11400879733264446, 0.12790666015020438, 0.0878539661477719, 0.1175710926098483, 0.062033096328377724, 0.20374271938843386, 0.10015475430658885, 0.11333300359547138, 0.18136789144149848, 0.10701532009989023, 0.13661903621894972, 0.17160791158676147, 0.16732442857963697, 0.1477575549589736, 0.12020212571535792, 0.13875631296208926, 0.22244937345385551, 0.18851277019296372, 0.07505313839231219, 0.09579242553029742, 0.1143295815480607, 0.10114040784537792, 0.09733038621821574, 0.1399315491850887, 0.10061314542378698, 0.13992134401840822, 0.0971705572945731, 0.11095003610742943, 0.10167527664452791, 0.09355055261403322, 0.18880008906126022, 0.14429276516394957, 0.11554653410400663, 0.18644022569060326], [0.020878262984167253, 0.0709716145481382, 0.035181273972349505, 0.039961061240839105, 0.013741427417179304, 0.04028890900579946, 0.052213242543595176, 0.039036251937172244, 0.0165009538510016, 0.04803832174677934, 0.06268345857305185, 0.06762928675327982, 0.02501462433221085, 0.029979973964925324, 0.019874545146844218, 0.01632508435951812, 0.054157818734113655, 0.031312474249196906, 0.06586818982447896, 0.06577759861413922, 0.030188382603228092, 0.029267692007124424, 0.026339007641321847, 0.016020517131047587, 0.02276639693549701, 0.01723520677270634, 0.03584270651585289, 0.01618724166681724, 0.013989702532333987, 0.06194317686770644, 0.02379956828164203, 0.01661480693811817, 0.03798950310530407, 0.0778413066374404, 0.027132905487503325, 0.03410685108974576, 0.06746661476790905, 0.03984532691538334, 0.019636267397020544, 0.047278348955192735, 0.04305323692304747, 0.030559802494410957, 0.022181170659938028, 0.024856440855988433, 0.05340767112959709, 0.029077753092029264, 0.05273856435503278, 0.01630150866029518, 0.032393974252045155, 0.06781013669180018, 0.10437771877540009, 0.03401689091697335, 0.02404269416417394, 0.04216485477185675, 0.059229667830680094, 0.013561272977053054, 0.02447640696274383, 0.018008633217375194, 0.032341445463576486, 0.08378313601549182, 0.026267981988244822, 0.08307219416435276, 0.019262962874823382, 0.046341041036482365, 0.035083246018205366, 0.013175592824284519, 0.025252578081563115, 0.0321690398933632, 0.06801134268088, 0.03456208362643208, 0.04983211727812886, 0.06857711875012942, 0.0386347966933889, 0.0238640681241772, 0.004007492705048727, 0.0530009674174445, 0.08010196818837098, 0.04675800759079201, 0.031938762071409395, 0.024801177571394613, 0.045573773993445296, 0.07856619916856289, 0.03538662241771817, 0.029412593160356795, 0.02061095241723316, 0.012286990997381508, 0.030158964717494588, 0.02157955946001623, 0.021518761026007787, 0.02055761786842985, 0.028505843066211258, 0.059015698597899506, 0.025414345919021537, 0.0597509727148073, 0.025186488770746758, 0.07048967826579298, 0.0283825990544366, 0.011182970417264317, 0.06466320662626199, 0.04912356047758034, 0.019147688256842748, 0.08843289901103292, 0.040732782866273604, 0.02287275729967015, 0.03538575050021921, 0.06982626779271023, 0.026483006342979412, 0.04711267105968935, 0.013785851953018988, 0.02302837252084698, 0.07322088349610567, 0.0016388136802041636, 0.04188612276422126, 0.0958777784502932, 0.028421516430431178, 0.03910183234672461, 0.017297927157155106, 0.0390888858985688, 0.11949570290744305, 0.06994157124842916, 0.0722814110506858, 0.028489035753799335, 0.03149025381675788, 0.02334034426270851, 0.0036374014702492525, 0.03044631072719182, 0.011931253746817154, 0.015902647116620625, 0.009169315121003559, 0.04461702943912574, 0.04275024389582021, 0.003263444282181029, 0.03181032896307962, 0.03803903276899031, 0.031769270809101205, 0.040910504758358, 0.07972827181220055, 0.046846692117729356, 0.014441230267818485, 0.005657990122147436, 0.04341718953635011, 0.028049948957881758, 0.017386852564024072, 0.021311324389119233, 0.07190853570188795, 0.07089644643877234, 0.020905621516119157, 0.050634973482894044, 0.05634035715567214, 0.04564415164557951, 0.06451142512794052, 0.03479829862979906, 0.01044871240654694, 0.0056386056489178115, 0.0345005744269916, 0.013483411931831921, 0.041284360590257814, 0.014733704305919153, 0.040210063236632516, 0.04578941920772195, 0.08824786929679768, 0.08962139380829674, 0.015413537022790738, 0.03713100702900972, 0.041019128036818335, 0.038788288099957366, 0.026582549126552682, 0.045061782002449036, 0.009616012535324054, 0.0265670530830643, 0.09080981396670852, 0.06093475169369152, 0.03978312221754875, 0.04752984117450459, 0.021069163722651343, 0.04494600357221706, 0.03910031582095793, 0.05450335929968527, 0.03675961767190269, 0.017177936720794866, 0.024579490002776896, 0.024128983462495462, 0.02240269198747618, 0.046834624372422695, 0.01937177953576403, 0.04003808853615608, 0.021449172170832753, 0.0643160477546709, 0.029753682536206076, 0.02694331092893013, 0.010882858619359987, 0.027079866101433123, 0.03515520126425794, 0.0065323308392960045, 0.03807967023125716, 0.046005498684410534, 0.011464522586071065, 0.053363535819309096, 0.0454974116624466, 0.02150481373869947, 0.07702227415783064, 0.06777855767203228, 0.04244612789313708, 0.06339907553046942, 0.04032146850866931, 0.0862024322684322, 0.051405334645616155, 0.029891662632248232, 0.03017001805294837, 0.07568876285638128, 0.05227832422990884, 0.014639169110783508, 0.13332849421671458, 0.040165144218397994, 0.04580268456733652, 0.04072758189535566, 0.02247385843656957, 0.03945659759587475, 0.019425930022927265, 0.03071618785283395, 0.03846264896648271, 0.034605401302022595, 0.02547504087643964, 0.057907420210540295, 0.031733725752149305, 0.04369235244978752, 0.08320194363061871, 0.0011402968645727793, 0.009371609310619533, 0.023397135947431837, 0.019306143147072623, 0.02585886269142585, 0.06518175665821348, 0.026279132014938762, 0.015414256269910505, 0.004103859944734722, 0.008035883440503051, 0.04955249299694385, 0.054393294134310315, 0.0318505050215338, 0.0322711526283196, 0.016359930525400808, 0.07815051504543849, 0.023311145204518522, 0.011807914740139884, 0.04680337444213884, 0.08645537655268397, 0.04262407709445272, 0.03233738103881478, 0.04154337776292648, 0.05187851782622082, 0.02700705250858196, 0.021329778845288923, 0.015687246174950684, 0.06053450424224138, 0.00841607678947704, 0.11098000021385294, 0.013761316126744663, 0.03356763627380133, 0.006127065197298569, 0.02956614563507693, 0.05254067640219416, 0.059571798757783005, 0.02836538801368858, 0.0393737857895238, 0.006922556752605098, 0.020376973186752627, 0.05636726106916155, 0.07618585082569293, 0.021180345078131983, 0.006041265716443637, 0.026073334040120244, 0.04516850538285715, 0.02043930341356567, 0.060748894166733534, 0.07336266338825226, 0.027963454402717094, 0.018500401472140635, 0.021204456820019653, 0.04118171859798687, 0.026490490584235107, 0.08571610586451632, 0.04031030321493745, 0.019406025198155215, 0.011335454199330082, 0.056279187223740985, 0.05795778786497457, 0.013048318314499088, 0.019321116718596647, 0.06201585475355387, 0.003343529862052362, 0.045940495029624016, 0.010928088067365544, 0.02243851524378572, 0.03346027846315077, 0.06906808633357286, 0.07129791525325604, 0.006300917319354734, 0.0400947054981121, 0.05116206966340542, 0.04772651794233492, 0.006133152504584619, 0.036613881920597384, 0.02076962952768164, 0.14387427190584795, 0.07590839785656758, 0.019705500021310787, 0.0483859963049846, 0.052942498054887564, 0.054798332042992115, 0.020626699518678442, 0.09129863059414284, 0.052889633391584666, 0.03409708697082741, 0.027273233314710002, 0.020748345580484186, 0.03061519130798323, 0.023503352122913514, 0.024125032692349384, 0.036864227415727716, 0.08715958055108786, 0.04057793778234294, 0.037272033747285604, 0.07223540637642145, 0.028672976419329643, 0.002785658513727997, 0.05929487504597221, 0.050021014641970396, 0.02301070516529892, 0.02921206909897072, 0.011714595819025167, 0.03279834380373359, 0.014673626815368022, 0.02473512218732919, 0.058754645820174894, 0.04973425556506429, 0.08756472024002246, 0.08259155388389315, 0.010130949368301247, 0.0026048113317561467, 0.06532192842236587, 0.017708657974643365, 0.017793707250218307, 0.02051806097318019, 0.05161710203226123, 0.0500231181005282, 0.021050926397687623, 0.08956168951200587, 0.046445990047816715, 0.016511795144262056, 0.028812228768531765, 0.06914351228624582, 0.1477184442004987, 0.16830371745995112, 0.07880873472562858, 0.12474166069711957, 0.08985001261212996, 0.13440417578177793, 0.10463166729147945, 0.1071037874956216, 0.1521810604525464, 0.09666570688464812, 0.1434270901871579, 0.18040085690362112, 0.08945174648293427, 0.12446825179670538, 0.12793027316885336, 0.18027577575828346, 0.16714039631187916, 0.08756247428911072, 0.12331459298729897, 0.1388602645269462, 0.0816026773037655, 0.11625136913997786, 0.14253694723759378, 0.11082450034362928, 0.18971488997340202, 0.1592853492391961, 0.12510342842766217, 0.06501183113349335, 0.09905390587768384, 0.09069432730653457, 0.07963894946234566, 0.16695492554988178, 0.09781809004821948, 0.12056966099355902, 0.08384448915187802, 0.09956607089510985, 0.23923063012106077, 0.07793511410376855, 0.1124903309558119, 0.2777175163584096, 0.12110609720860209, 0.11110711017889635, 0.04039626342377492, 0.1259862296283245, 0.11363202040748936, 0.0867295725537198, 0.07812943974775927, 0.1810584794729948, 0.10410151431070906, 0.136043570669634, 0.3103405029645988, 0.12211700582078525, 0.13992061120058807, 0.15046249409871443, 0.18899089310850414, 0.1082503352580326, 0.10120195097156934, 0.1010147567306246, 0.16721707076898643, 0.12208921302642141, 0.07040477996425969, 0.23878035428268568, 0.16965185797640256, 0.10947607484247003, 0.12318792407001768, 0.12217967531510762, 0.1926852177296366, 0.1475394330918789, 0.16763389483094215, 0.1749385685792991, 0.12923232758683817, 0.1643855712775673, 0.1264328956604004, 0.0895320511023913, 0.11866596314523901, 0.20358257155333245, 0.13123947488410131, 0.1903797864381756, 0.11290643577064786, 0.08729562682232686, 0.1595669955547367, 0.1292088231337922, 0.10620409077299492, 0.15857397312564508, 0.1084679617945637, 0.21410434267350606, 0.06935944248523031, 0.11311542455639158, 0.09620959564511265, 0.11655475571751595, 0.10867321185235466, 0.12571370282343455, 0.1761543269136122, 0.1757624050868409, 0.05634951059307371, 0.18594450157667908, 0.07070409533168588, 0.13256436879081385, 0.13933407195976802, 0.14292901834206923, 0.10878046788275242, 0.13718265454683984, 0.11241556996745722, 0.14761665037700109, 0.1537645169134651, 0.16225567699543067, 0.09050821872161967, 0.15398979053965636, 0.2009461780211755, 0.22256889061204024, 0.19491773364799364, 0.12462943100503512, 0.10162551288626023, 0.1035063441044518, 0.09717720015240566, 0.04289953177794814, 0.08165220357477665, 0.12110360019973346, 0.18069102561899594, 0.1706945084567581, 0.12243826501071453, 0.06230569098676954, 0.11295509351683514, 0.13484800553747586, 0.09841395236019577, 0.09959408760602985, 0.14457655565014907, 0.07675982359796762, 0.1434178485402039, 0.14822054654359818, 0.13028259123010294, 0.10641248923327241, 0.17089835394706043, 0.11405146361461707, 0.10371698851564101, 0.15458114737910883, 0.11647557068083968, 0.1627291858728443, 0.11415218535278525, 0.14364804833063058, 0.155433414503932, 0.06918140168168715, 0.09993247980518, 0.15439741366675921, 0.16998238595468657, 0.1574669296720198, 0.07906583164419446, 0.1299563515931368, 0.1534672507217952, 0.1138119814651353, 0.14544137567281723, 0.1412828652454274, 0.13015229893582209, 0.11306688216115747, 0.09643930689032588, 0.053573773109487126, 0.2213884839521987, 0.08417109519775424, 0.09065087392394032, 0.09330352515514408, 0.20106222108006477, 0.21465029194951057, 0.07854253186711244, 0.10167879145592451, 0.1342893269445215, 0.09487242703991276, 0.08436320203223399, 0.06637667039675371, 0.1183485851756164, 0.15069707722536155, 0.22107206950230257, 0.2177648219679083, 0.08899524169308798, 0.13741434711430753, 0.16691852893148149, 0.1475608612277678], [0.02866984498021858, 0.06292380246200732, 0.044762439493622096, 0.027132532293243066, 0.07459851992981774, 0.017939437912510972, 0.03609579668513366, 0.04801682915006365, 0.022604712218578373, 0.07071557614420142, 0.02019832848704287, 0.018964117392897606, 0.017569578651871, 0.00495342946877437, 0.036802582509283505, 0.024155437846535018, 0.013199441633852465, 0.041522828329886706, 0.021387501819325343, 0.01483398669266275, 0.0639573402170624, 0.045038019706095965, 0.023788002652249167, 0.047963777889630625, 0.018235526845923493, 0.023470719677529166, 0.013391394949784237, 0.06053934219692435, 0.02542913967876562, 0.03423780495566981, 0.028060557852898325, 0.05332333940480437, 0.05795033076511962, 0.015252746275759168, 0.00874487026261964, 0.007572787531119372, 0.03363680613360234, 0.04469683872801917, 0.0396872078999877, 0.050927262620202134, 0.058169796131551266, 0.03852937610021659, 0.025322399334982038, 0.08706957966621433, 0.025539357514519776, 0.06181235531611102, 0.028226817592180202, 0.056021174282899926, 0.037323626157428534, 0.043030529748648405, 0.056963998691311905, 0.006284569714417947, 0.011041622243023344, 0.013061478501185775, 0.026702403855909194, 0.05444293236359954, 0.03529542052586164, 0.009531619742379656, 0.05928462238184043, 0.07826970650681428, 0.0746364975348115, 0.019461434367778044, 0.018919922710795487, 0.026216362436701144, 0.05824389894093786, 0.03405248686405165, 0.032147109641560485, 0.020566622028127313, 0.02492983459628054, 0.02348892646841705, 0.024740299409521476, 0.00594434716705499, 0.05094663140230945, 0.02016404550522566, 0.0331481523545725, 0.027257128286042383, 0.03267461294308305, 0.05106395689238395, 0.058227804090295515, 0.021158102700220685, 0.020308363118341992, 0.03423954200531755, 0.023979654868266413, 0.024354898304279362, 0.022158916407663907, 0.04208722697304828, 0.06276934753571238, 0.03764470214290278, 0.03396031805979354, 0.05704574180500848, 0.015161332341709306, 0.01672355574555695, 0.038722395564296415, 0.02772048967225211, 0.05287804401346615, 0.028562371818614856, 0.019249627965369394, 0.047658450701939206, 0.058390320012612004, 0.052476120580519946, 0.040163383420024595, 0.0030144276554762784, 0.04466206720098853, 0.049056918160723786, 0.04199393180065921, 0.030059304886630604, 0.0500235693263156, 0.034513578550623994, 0.08118820775832448, 0.04491503184129085, 0.0171597197518817, 0.05093544575252703, 0.03443342320887106, 0.0681293670620237, 0.030211839558822767, 0.031938521191477776, 0.03704015119001269, 0.02110753148528082, 0.05698092135467699, 0.05759906675666571, 0.054843831208667586, 0.03233026320646916, 0.02304002975246736, 0.08684556811515774, 0.03992504460204925, 0.05118045796241079, 0.01999917167371937, 0.019919903516503315, 0.033085947656737905, 0.07419490015932492, 0.08596740130867277, 0.009980462175527853, 0.040149839861052375, 0.0682812842673489, 0.028797809899385487, 0.055270266719162464, 0.027489970970366682, 0.021569357686010853, 0.04804584670013615, 0.03903952586863722, 0.02505663243521537, 0.01593367143401078, 0.016453380064506615, 0.07253269970949207, 0.01690289255098573, 0.021005725787420357, 0.023392085950555544, 0.012405343619840485, 0.0407291696672993, 0.07152682582714728, 0.024005658026518564, 0.04816998468179788, 0.07121684388922793, 0.04385407787880727, 0.009510359543907856, 0.018852506864017675, 0.011002005127790784, 0.08570242659854037, 0.06611010791467768, 0.08818302849041564, 0.05371165821062667, 0.07960306853055954, 0.03974594867655209, 0.033341751966093264, 0.020936491466792564, 0.015270028562684144, 0.007281473787900592, 0.050485183484852314, 0.08702115940728358, 0.025936846721119115, 0.02926473698711821, 0.01933149660804442, 0.03243733263973679, 0.022783088896955763, 0.035878360138407776, 0.05487755439909441, 0.043036684061267545, 0.02913066864545856, 0.03055021140192236, 0.047924561958227835, 0.03571566440431135, 0.06253230132694755, 0.007626949892645436, 0.06029981254999127, 0.02704450424893626, 0.018697799183428288, 0.01598266844770738, 0.020816573972946832, 0.04642448388040066, 0.05748850626072713, 0.05756648350507021, 0.02062084885048015, 0.021642541080447178, 0.048452343459108045, 0.03769241672541414, 0.07645647094718047, 0.03493292676284909, 0.01990076882897743, 0.026829006616026163, 0.06525457025106464, 0.021636873616703918, 0.01579623416598354, 0.03897581482306123, 0.05712042815451111, 0.004550917830783874, 0.021503544878214598, 0.0693917814642191, 0.04030667305258768, 0.046363154492740116, 0.03931951316605721, 0.028465324347572665, 0.027882973364155208, 0.01843876504738416, 0.02793087624013424, 0.022810522067759718, 0.03727674278031502, 0.046252726311130185, 0.01491702750458249, 0.010549027871872698, 0.04571586261902537, 0.04188583777951343, 0.052652420941740274, 0.07861411731157984, 0.012920082829493498, 0.044441977582339726, 0.08183270067508731, 0.032868548429438045, 0.013186716557746487, 0.02088763694544988, 0.0438307193107903, 0.029234420042485, 0.06007517674671752, 0.01020048139616847, 0.012144766664797706, 0.02840966751266803, 0.06941417311983449, 0.028535148993666683, 0.1074446699182902, 0.029537949112376997, 0.015239548769646456, 0.040485097228416374, 0.06928048815046038, 0.019245877363053814, 0.06990436717335667, 0.022958561445453336, 0.05699034620608602, 0.015314878031079258, 0.02165808292504932, 0.07141278444656304, 0.008162671101412602, 0.017784855760900036, 0.02299638807640544, 0.09873050930244581, 0.04072598394538675, 0.04212939113910709, 0.03684767455394779, 0.05453405961660402, 0.023464784192453538, 0.034220882292304716, 0.04096532020983951, 0.04763472233233707, 0.06576979546142475, 0.01512283056841365, 0.030198187434247563, 0.02336421173198947, 0.04363547425184931, 0.050185325289411206, 0.08160180199359145, 0.07153272229645934, 0.04288591697279896, 0.011817307361135525, 0.03960278118029237, 0.04097229894250631, 0.027314790191927125, 0.03580039307208998, 0.04723191341119153, 0.0490888941234776, 0.01772671888050224, 0.06490487365850381, 0.026393332851252387, 0.01825433244396533, 0.021522998477199247, 0.052535963976489644, 0.02646028220520488, 0.04167718826127904, 0.054622778070292304, 0.049530125090054104, 0.02158840586032186, 0.02481281105428934, 0.04357142733143909, 0.032903153715389113, 0.02683490647801331, 0.06605400663933583, 0.03774940348895533, 0.03684964909085205, 0.04805524780281952, 0.03345561692757266, 0.06648896794234004, 0.021021852868476083, 0.011658112019566553, 0.047440244017967155, 0.027878243975075226, 0.031735415304345746, 0.007706808375327715, 0.02147848827631346, 0.09805831858622176, 0.03771200942407761, 0.032734320632049015, 0.00987285076241408, 0.01506460887113852, 0.07951867913029023, 0.040074617468885014, 0.039624324667134454, 0.05772353722048657, 0.03830230774890099, 0.01120311442563044, 0.013622220688765603, 0.0012576260653856608, 0.03531558319394078, 0.045363574022693295, 0.024621586315333843, 0.03139005455055407, 0.04986483623672809, 0.006671027637951608, 0.013527733839250036, 0.04711801113028612, 0.025726098833339553, 0.04252523150561111, 0.02692211858396019, 0.042528512222426276, 0.05296675228912916, 0.018764249814142073, 0.020575456554070115, 0.042380048760346005, 0.07122757152787276, 0.07248923275619745, 0.05140122950875333, 0.028351247343899946, 0.01220437342167965, 0.03539482929876872, 0.053684876433440616, 0.0372347346773105, 0.04174417323832001, 0.035376206905181916, 0.04406341611008559, 0.02517068908283753, 0.015937942811953168, 0.048767383875591416, 0.02344716263801924, 0.04641404461913875, 0.047392783886087794, 0.02012618155484753, 0.10529876899506364, 0.0748670840901988, 0.12883056700229645, 0.10927518097949879, 0.13172572664916515, 0.1272855834769351, 0.1414068200226341, 0.1697305544678654, 0.16219171828457288, 0.14693584905139037, 0.1279906356441123, 0.12220753596297332, 0.14353219526154654, 0.10782825254968234, 0.11569122491138321, 0.09227000775613955, 0.08186172840318509, 0.15665047562548093, 0.1725902267332588, 0.07957288050757987, 0.23979959530489786, 0.17937153285103186, 0.135541631174939, 0.15432514968727315, 0.1277469601482153, 0.16568234669310705, 0.07486118762088673, 0.19670426206929342, 0.08314099761524371, 0.09363547127161707, 0.22277485313160078, 0.16149810621781008, 0.1333136207291058, 0.12262001740080969, 0.1842076690601451, 0.19628731587103435, 0.09740572396133627, 0.13386677604700836, 0.11005515698343515, 0.11920511350035667, 0.10824196892125265, 0.1067491104560239, 0.08406242102916751, 0.19336582906544209, 0.15549558188234056, 0.15661226053323063, 0.11395341530442238, 0.1277720523732049, 0.16671754685895784, 0.18119994045368262, 0.09532387674387012, 0.16061857555593761, 0.09150814185185091, 0.1451481535498585, 0.08299072925001383, 0.1265904243503298, 0.057363235125584264, 0.1230665205844811, 0.14150208633925232, 0.14474913424679212, 0.16446498701614992, 0.18285344886992658, 0.09695155333195414, 0.1660450915140765, 0.11459710076451302, 0.124674580725176, 0.10620050132274628, 0.10366605089179107, 0.08055526350757905, 0.15986420746360505, 0.0905995291790792, 0.15559056321425097, 0.16147712591503346, 0.16788626914577826, 0.1261495801487139, 0.09587090489055429, 0.19531805573829583, 0.14812557878238813, 0.16909651777573995, 0.08877025983695473, 0.08558702814791884, 0.0742969178993787, 0.11289323826453515, 0.10348197791193213, 0.07660483262900795, 0.13068984794829572, 0.17831403602446827, 0.05508810381538101, 0.1472302246838808, 0.1276352597134454, 0.11689459319625582, 0.1508512675229992, 0.17903135610478266, 0.09923959377088717, 0.16404102476579802, 0.09511707962623664, 0.12843084202281066, 0.11205952907247202, 0.1519241128116846, 0.14359224561069692, 0.15742187494678156, 0.10699649075312273, 0.1093031909050686, 0.10154148310955081, 0.08570074383169413, 0.08506373515618698, 0.09851704218557902, 0.11354197202516453, 0.16368176761482442, 0.13484244155032293, 0.07556736615619489, 0.12406126649252006, 0.11105081891374928, 0.11896830477884837, 0.11522564132298742, 0.1422871784972293, 0.14111329934426717, 0.15420532040297985, 0.1638667226902076, 0.09036001988819667, 0.08328256716153451, 0.17764570617250033, 0.09456666558980942, 0.18661482632160187, 0.1185305682676179, 0.1900107990950346, 0.12337642109819821, 0.1596872183893408, 0.08337030852479593, 0.12423311227134295, 0.1717134237821613, 0.07478120869823865, 0.08211014685886246, 0.10194850912583725, 0.13226799826536859, 0.14168145028608187, 0.09569225340549435, 0.11326251737773418, 0.19738458842039108, 0.10069303613688264, 0.07042206225118466, 0.08008823463959353, 0.09672742642994438, 0.1356573078249182, 0.09821713649268661, 0.1109597934409976, 0.15028080956212111, 0.12834460022194044, 0.14409095527870314, 0.19022624753415585, 0.10906297593776669, 0.19513665618641035, 0.19630084585930618, 0.11712629933442388, 0.17259633354842663, 0.10776953212916851, 0.06548379973641463, 0.1497439390846661, 0.16822479026658194, 0.16555343861026423, 0.12097094660358769, 0.12719628826848098, 0.09735258109867573, 0.09912984751697097, 0.15891250781714916, 0.09287904043282781, 0.13918544564928326, 0.06188924011907407, 0.14074078361902917, 0.12790051262293542, 0.09082454496196338, 0.17030473080064568, 0.12266869550304753, 0.116571094840765, 0.1390537420021636, 0.08823519426264934], [0.03653752976762397, 0.01634393915134881, 0.018309283602450575, 0.05344313136967165, 0.004713012637304408, 0.06510439009538718, 0.022728326031938195, 0.015913015131705573, 0.023536647836278592, 0.037895950089607916, 0.02906768363235252, 0.059476987059627257, 0.043675433179097514, 0.039848838334104845, 0.054818437035594664, 0.03086371493658849, 0.011569853273353406, 0.029868653509765863, 0.041311563059155426, 0.033698512108198235, 0.051955148178551874, 0.05374476732686162, 0.03908224982608642, 0.007188857150530177, 0.08360821647303444, 0.053972093521484306, 0.046681163499930074, 0.031287215783127716, 0.021921688690781593, 0.07848613882171256, 0.09598351456224918, 0.010339943243057599, 0.05213286328528609, 0.04617268292765532, 0.03005309629120997, 0.035787751964692555, 0.06294546129980258, 0.023522636088143502, 0.017133245011791587, 0.029345160350203514, 0.05888549451317106, 0.02927725256553718, 0.052925534679421356, 0.04672952947605934, 0.05734192234064851, 0.05623154728008168, 0.005211513231708003, 0.0060174313257448375, 0.05690317141956516, 0.03160102805122733, 0.028444008169961826, 0.03368641043614064, 0.0027127895778643763, 0.010584430436470678, 0.036994299186127524, 0.019621768800009574, 0.08546643211905446, 0.003867848077788949, 0.08455460997564451, 0.021624931400375705, 0.03709769435226917, 0.017042346764355898, 0.06038350984454155, 0.0047603446956990016, 0.041978810647768636, 0.029168625894401754, 0.023972774523177316, 0.058166199895952425, 0.01996081239277763, 0.03741606298301901, 0.07392546068876982, 0.014483316402350153, 0.047285531248365126, 0.03190608721758638, 0.00919912994972297, 0.046802614482917955, 0.03560359077528119, 0.03557482428316559, 0.021546094112896493, 0.015369160832571132, 0.019713734043762088, 0.02727126217048083, 0.013336535393526512, 0.04086414046053376, 0.01900801351959152, 0.015011577966756054, 0.05505386833101511, 0.0071471425139212185, 0.013621151996111231, 0.008072493797434228, 0.024349775364888564, 0.009091172483749688, 0.027854997365336333, 0.013967292217005576, 0.016685664653778076, 0.012089629757351108, 0.036182503282491646, 0.04546310493190374, 0.05654124762596829, 0.022988233781818832, 0.011923381044263286, 0.10731088995401349, 0.040307392299707444, 0.017892081257221953, 0.011104326512265419, 0.08434186889124767, 0.017074870644137263, 0.06050975128476109, 0.019978908921724985, 0.009155314399062522, 0.03166878316551447, 0.07433443410055977, 0.03630916880709784, 0.004474295111971774, 0.044723603541829755, 0.01208919973578304, 0.02699113916605711, 0.0032918254936313523, 0.026082304273066775, 0.01959441366073276, 0.04135219712874719, 0.01867393171414733, 0.08078677965594189, 0.01896756435079234, 0.028670170677027533, 0.020987529174557755, 0.10900531403188195, 0.03216778121090361, 0.019183475890063813, 0.0466473656706512, 0.01761952052558107, 0.022482960983844738, 0.04661570183400597, 0.05197268830878394, 0.00813988080647375, 0.09790559392422438, 0.016041198878415992, 0.005229918918173228, 0.03548201087063976, 0.015161700446956923, 0.055699494401259084, 0.047325809087072096, 0.04160234924139721, 0.055900415405631065, 0.022043931863403747, 0.04395033824922783, 0.11801572303686823, 0.0329186243138143, 0.05702427974236863, 0.03586178692057729, 0.08271734070565019, 0.024506213309775506, 0.06590557710400649, 0.00989580136125109, 0.02923028776422143, 0.057453127444854805, 0.022013256991548196, 0.02605027742018657, 0.06959727579461676, 0.014341098855116537, 0.03570620562615139, 0.02316987082096083, 0.038718086866928, 0.04751783110467451, 0.079489780323846, 0.04125913265826447, 0.005384362394189728, 0.06004875459309135, 0.03946844481730035, 0.03933643243674721, 0.020873382621045624, 0.007522887217679194, 0.03743471251800656, 0.030448624531605413, 0.044276696629822254, 0.03929906212059515, 0.02779092499986291, 0.013368147491876568, 0.030203412153891156, 0.01816119333463056, 0.018863008889768804, 0.042276799479233365, 0.06479514097528798, 0.003095118827851755, 0.03188806872016617, 0.06482499651610851, 0.044777329944606335, 0.03827476940516915, 0.02349224959367088, 0.08822668543351547, 0.03361195478854435, 0.016695800270619135, 0.0029660001871109542, 0.024106473063251803, 0.03375222154759935, 0.0068297679369737, 0.03334264423964279, 0.017793602077290416, 0.07722272697303977, 0.019969185514907752, 0.044105186725833585, 0.07810154517314263, 0.018656642641872168, 0.04961626850334661, 0.033102771932525296, 0.03348590333813003, 0.06627094107014792, 0.05056993929403169, 0.04690742439457348, 0.06372562050819397, 0.028093948561166013, 0.04468054710222142, 0.05886940644787891, 0.01937944019612457, 0.011939647224997836, 0.04556633385696581, 0.048431593858237774, 0.02199029875919223, 0.007814411306753755, 0.022466486153591956, 0.01719019445590675, 0.043072605705154796, 0.015113580439771925, 0.03373604527275477, 0.00891518933765058, 0.029730690377099172, 0.02381193288601935, 0.034670167469552586, 0.031641163397580385, 0.02549074387310871, 0.029174909128674438, 0.06796076468058995, 0.04852474653827293, 0.03297284943982959, 0.05903513862618378, 0.04497532646304794, 0.05537729883300407, 0.041614590013133626, 0.029366344213485718, 0.03455556629757796, 0.052254361765725274, 0.033980959095060825, 0.007920608822522419, 0.08828090038150549, 0.012001395608032388, 0.03093959211504885, 0.012614083892133619, 0.007810658159931856, 0.031147315432982783, 0.034944943618029356, 0.11412944085896015, 0.04100116042952452, 0.022000130731612444, 0.016785010662195936, 0.020236826867663434, 0.05964208820036479, 0.041711494991821904, 0.10222874408853905, 0.07138305782739605, 0.056653433213276524, 0.03194078749844006, 0.020368937635794282, 0.009363498272640365, 0.0317415594389396, 0.009082204795309474, 0.027951332374608943, 0.03348933672532439, 0.020235530865777816, 0.008346623641305735, 0.033075528751526556, 0.028933991877628223, 0.041488460531192164, 0.03655726835131645, 0.047109230887144804, 0.020351199034069265, 0.013653477404399641, 0.05856232185448919, 0.05084711067112429, 0.0008124562560364471, 0.03744889050722122, 0.04406730072306735, 0.008770877661715661, 0.06022910241569791, 0.05072820080178125, 0.020017364893906882, 0.038716186968875785, 0.01914858222672982, 0.03325918782502413, 0.03429272218740412, 0.0371485369812165, 0.0867771582145776, 0.019394790354583944, 0.030970540097249404, 0.035614762854363234, 0.05227031412401369, 0.021147188464445726, 0.03317940907020654, 0.03925583943990724, 0.029227675404399633, 0.059767725744417736, 0.021417009610948817, 0.08107285001980406, 0.04219608434609004, 0.036875579306589704, 0.017136683487998586, 0.09053003362246922, 0.023337806541738764, 0.027609318494796753, 0.037267114368400404, 0.04707073759553688, 0.04738566266106708, 0.014593622447656733, 0.04143394363511886, 0.04084168773676668, 0.02359937161340245, 0.03639415871085865, 0.0019598319902018246, 0.08163768971072775, 0.07394553175462143, 0.041108324857694764, 0.04850079085943954, 0.036891687727932415, 0.04885843309706875, 0.01021253302626844, 0.02756251484554793, 0.011660141687441086, 0.023772189393639565, 0.00823044402724398, 0.044807450114084144, 0.02350639535247215, 0.020987196692398617, 0.08370505020554576, 0.018229133349710276, 0.03703973049830113, 0.010944528970867395, 0.013160334268052663, 0.06822983095688478, 0.0229911362153611, 0.03597796568647027, 0.024748725118115544, 0.02231766646062689, 0.09376522073788301, 0.026537301018834114, 0.03595087856852582, 0.03942704061046243, 0.06289004534482956, 0.07326355656342846, 0.06361147734735693, 0.061976452225020955, 0.02142679917493037, 0.03295243910646864, 0.016321929171681404, 0.12646691740623542, 0.06814626936933824, 0.09028132339673382, 0.18439731959785732, 0.048177156796944995, 0.17734658079487936, 0.10451881334717784, 0.08692013232835702, 0.10411252693406173, 0.13893619259553297, 0.09536562700356756, 0.13003306676234516, 0.16828862684113638, 0.14079255584095204, 0.1275920777448586, 0.09286389553121158, 0.13483333561037267, 0.13332415159259522, 0.1798992431057351, 0.08240880404732057, 0.13718990130083902, 0.17621928985629762, 0.11813214607536793, 0.0821146455460361, 0.20005349735064165, 0.14986612967082433, 0.10317166349185364, 0.11964378638991288, 0.11828310654631682, 0.1285745557397604, 0.16179257684520312, 0.10462000327450888, 0.13252090183751924, 0.18103346867220743, 0.13533750069992884, 0.12772136580731186, 0.2110974554504667, 0.15785674804023334, 0.08585699687578849, 0.13485951349139214, 0.11477269205663886, 0.16129175014793873, 0.178649137328778, 0.18551283116851533, 0.14100647079093115, 0.09952259037111487, 0.119941826111504, 0.12034228390880994, 0.11060605277972561, 0.13860775450510637, 0.10513933362173182, 0.13511723466217518, 0.10151078618530716, 0.164832630859954, 0.1238173060119152, 0.12119679019919463, 0.137782004528812, 0.16512360024665082, 0.18535353828753742, 0.07196739182940551, 0.13733603060245514, 0.20564734004437923, 0.1256541817315987, 0.12289463409355708, 0.1545427015849522, 0.0935155673484717, 0.09081248739468199, 0.2891440732138497, 0.09956744832119771, 0.1325414478778839, 0.09971344870116029, 0.1389368168477501, 0.16179506028337137, 0.07046229259244033, 0.1995130442082882, 0.06676270253956318, 0.050784563313105276, 0.09443966419036899, 0.11454036166625363, 0.09289407676884107, 0.22299567556806973, 0.19110771880618163, 0.18336444002177033, 0.11235262905912739, 0.13418784524713243, 0.08231358522815363, 0.12861092521675996, 0.13340231882674353, 0.056298600110624514, 0.12109688270304884, 0.08292299788445234, 0.08947933571679251, 0.08103802081729684, 0.0799550653568336, 0.04684836809922542, 0.0781852967504944, 0.1433067994990519, 0.18623134547046252, 0.11113261631024735, 0.10982339656246559, 0.13304060537900242, 0.16900036936359747, 0.1759359607739108, 0.08650383752371583, 0.14551376178860664, 0.16852403778050626, 0.13435462915471622, 0.1569838398801429, 0.09596790147147008, 0.12513545528054237, 0.1572022195905447, 0.18472269070999964, 0.11035953422210046, 0.09573247017604963, 0.16080510483256408, 0.09745702799409628, 0.07540474166827542, 0.11706140424524035, 0.10556659355227437, 0.08267784996756486, 0.10989259356366736, 0.09833454340696335, 0.18232423226748193, 0.14302176050841808, 0.12940700964203902, 0.15916513997529233, 0.21916189842990466, 0.0915169899484941, 0.0988028614914843, 0.27344901540449684, 0.09666612079100949, 0.13646061186279568, 0.1100360562226602, 0.29721611578549656, 0.0775608274021319, 0.1831920107028314, 0.08097180258482695, 0.10095424497766153, 0.12079995577888829, 0.12467133732778685, 0.14322361110576562, 0.2661717544708933, 0.15230530021446093, 0.1324290010545935, 0.1415762502167906, 0.10464400984346867, 0.20486863968627794, 0.11275662880923067, 0.11695727626127855, 0.08483012233461652, 0.13509816782815115, 0.09215231585715498, 0.15966846368142537, 0.12017146950321538, 0.09404586960694619, 0.19472889735230378, 0.14404467919043132, 0.10799733669097934, 0.0895581136324576, 0.2089977152645588, 0.1805759867919343, 0.09966749830969743, 0.15519617152001175, 0.09063468407839537, 0.16478019367371285, 0.17648250716073172, 0.11752803277756486, 0.2111411802470684, 0.15997716997350964, 0.154165992513299, 0.14458334100033554, 0.13106434499578817, 0.1539090855845383, 0.09489727499229567, 0.09784799987184149, 0.20623040518590383], [0.023656477120571902, 0.05917974800935813, 0.017221351087625538, 0.04548529641968863, 0.051255544647574425, 0.03225156332233122, 0.03315543642799769, 0.03555987276402967, 0.07377452057387147, 0.006426408978378666, 0.02645649089078818, 0.038086693068700175, 0.05337806325405836, 0.025250047145943557, 0.07195737665253026, 0.0293649973214737, 0.007464408525265753, 0.028811540055487837, 0.07412129946585212, 0.021405937615782022, 0.050678243661033254, 0.11315724945494107, 0.013701744992951197, 0.052440969073878865, 0.005196262733079493, 0.05720920767635107, 0.009157312684692442, 0.022890468759994422, 0.04192257705809815, 0.04673144294481192, 0.004426142026204616, 0.09433984490377562, 0.017838371817820838, 0.03607180029419916, 0.03683802239330752, 0.023237078018220406, 0.013487467026737119, 0.05925422401300498, 0.03814725231911455, 0.018649153311603835, 0.030110100018126622, 0.04360529640689492, 0.03791287275297301, 0.012395012924181563, 0.017792453656771352, 0.047878004277923276, 0.013356930459849536, 0.017625413602218032, 0.08014973705368382, 0.034287779059793265, 0.0733797149732709, 0.03856109421966331, 0.06011979042419365, 0.059883707735155306, 0.04006566419931395, 0.014802590877349888, 0.06748669261911086, 0.03224469994061759, 0.031561951219503365, 0.021434076463005373, 0.0846160173948322, 0.020788145052003007, 0.07685801440051623, 0.03214475851772087, 0.054406440750296624, 0.0383169607126287, 0.029599322604813745, 0.044703284810696325, 0.08045978005975485, 0.03281059136082019, 0.022027058393827507, 0.034659273589828184, 0.032525263992803435, 0.008591751202142664, 0.08020412163542849, 0.04924493682171617, 0.026550886986245, 0.02886524610221386, 0.028454625546666126, 0.05668524632762585, 0.04375231458938547, 0.04266932859484639, 0.05512190503733499, 0.044701137247362306, 0.02897662084017481, 0.040568312763103416, 0.03614400999088373, 0.02701384973313127, 0.029055561604244367, 0.05575835392145174, 0.022211937134021094, 0.02145118572350059, 0.07394256655658994, 0.04647364034982664, 0.025047473908801163, 0.009943182613434536, 0.03819463781214186, 0.0048498913861944205, 0.03022416854011161, 0.024196071916126778, 0.014107849897949823, 0.08150711921708924, 0.09974859681512628, 0.015863544839833463, 0.0231587648990431, 0.036734674724617174, 0.033489268871822526, 0.020047630948413695, 0.019648676106174077, 0.012632468798463898, 0.0055837520298415, 0.03460973035544157, 0.13535480334290437, 0.044942726248076985, 0.04630293111715998, 0.05435958790725895, 0.041129406940724166, 0.012390301346645823, 0.012440970100994622, 0.012715375599717455, 0.016324668756819198, 0.022019830299541354, 0.011469664185174873, 0.011390729358286729, 0.025875306987602795, 0.02909431273915938, 0.017838463420048356, 0.04973316651635936, 0.07004939724824258, 0.051814657502940724, 0.12849214087639535, 0.06700489882911954, 0.02998873045934098, 0.040785047026085, 0.022914117401731864, 0.05350867785247309, 0.018082496843167713, 0.03538777592724987, 0.012144513910503259, 0.04603510655994926, 0.03741924870493157, 0.01895628370610731, 0.031457941979169846, 0.08112859167158604, 0.05312378225581987, 0.007102254453846919, 0.0588794012687036, 0.033471925516745875, 0.07803028542548418, 0.02014913809086595, 0.009740087752496558, 0.018267277195783596, 0.03853383407528911, 0.018332331740696515, 0.04950230854696461, 0.03087348584085703, 0.09101813100278378, 0.049415802117437124, 0.0315048524976841, 0.03537528070488146, 0.023922686764438237, 0.0048696511741062355, 0.04335852000596268, 0.02507878660357424, 0.05860765477908509, 0.027823791539828693, 0.0357700082739549, 0.028867034041987996, 0.034111125860363245, 0.02983478782698512, 0.05661590683407017, 0.028372303981866156, 0.06783275904932193, 0.037817212886043956, 0.07054703483091933, 0.016189867597339407, 0.039057300093450716, 0.08440166139709097, 0.006847083726565221, 0.011783182138710149, 0.018655192273269807, 0.04236857134050556, 0.0327443697356752, 0.03816579328849912, 0.01615787636754768, 0.02968708093145064, 0.04557054077408143, 0.04545145448563354, 0.016022829239123633, 0.06923188468707459, 0.0482769557274878, 0.056140314854149304, 0.051252158757831366, 0.02589109819382429, 0.08267423337591545, 0.022914288731824075, 0.038562332546072345, 0.09528355140771184, 0.01075919221953622, 0.04664265324494668, 0.02905999243791614, 0.01848453901974218, 0.07812130411288568, 0.01607304422317871, 0.03829931880214384, 0.019683425580816608, 0.06886847490178687, 0.04777270582105432, 0.02052229842437165, 0.03563807053225381, 0.02103992225602269, 0.051632484421133995, 0.01266311143990606, 0.03907363921669977, 0.02806427961747561, 0.009298783843405545, 0.050914407774273834, 0.01936093484982848, 0.032149545582277436, 0.05222741374745965, 0.015621826917465245, 0.04272752993607095, 0.017151534923219254, 0.06809456500091723, 0.021952428023463914, 0.033207398639725785, 0.005161778735263007, 0.08960276802203485, 0.06552954656737191, 0.08111375889607839, 0.023544004852218286, 0.04660153402281659, 0.022478952538222075, 0.016160105355083942, 0.026598343725449274, 0.0586177920922637, 0.054135579748877456, 0.02076045234155442, 0.0466474131681025, 0.08342050654547555, 0.04671625393841948, 0.04668121099738138, 0.019245585592995797, 0.048031536396592855, 0.040383198231990845, 0.01352615624533168, 0.07357372849115304, 0.08562307192810945, 0.10490701680204698, 0.02454217566576387, 0.06309233020458903, 0.03878331783094576, 0.05228716554120183, 0.019538069809121743, 0.04651874935786639, 0.021290544254173125, 0.076999000406691, 0.04665010016677635, 0.04733580390789679, 0.02744238361317132, 0.0419825934804976, 0.014191679506828743, 0.03705125541559287, 0.019755759110142077, 0.03773705754429102, 0.041901803708502224, 0.04713857752670135, 0.06623011361807585, 0.027854347668055977, 0.028747947753540108, 0.00842640409246087, 0.02073863404802978, 0.025040043950346962, 0.03488925285637379, 0.0294784551619419, 0.07318448009235518, 0.016307014971971512, 0.07394065308783736, 0.020892700513026545, 0.06227761320769787, 0.06217377020844391, 0.08171439130923577, 0.017713587531553845, 0.02212000242434442, 0.046405132061668804, 0.018605706714359776, 0.024426817927243452, 0.02658789767883718, 0.015446079562285116, 0.013515820460660117, 0.05498895627845611, 0.027851477464927093, 0.015108791678877813, 0.0771377133205533, 0.029453926121017764, 0.06816965847143105, 0.06554830806063754, 0.03625966289213725, 0.0485181817119675, 0.015418705763295293, 0.02804790317480053, 0.021663044712373188, 0.018475039529481103, 0.004980368581267872, 0.03781230029250894, 0.014273813626329814, 0.04100396277915154, 0.013385002301739795, 0.029710975542132343, 0.08541542664170265, 0.025570458167099526, 0.035651281609066894, 0.012004385402958308, 0.03204687984128084, 0.012544495036958583, 0.02141451938743038, 0.0539661224133202, 0.04720556589641741, 0.032323613563286405, 0.04784559066008244, 0.06248971646917718, 0.021688440581783652, 0.11456324186708246, 0.04653608253491776, 0.06522755098662206, 0.04951614387599485, 0.028694170460637127, 0.04515359457582235, 0.05074171043400254, 0.013765016687102616, 0.003214746884103598, 0.08741169702261686, 0.008564619979422008, 0.05171100788616708, 0.04549300118482538, 0.06436396589768784, 0.04632965861154454, 0.020910255910296525, 0.026506607487265552, 0.024188119485708218, 0.05645874116037573, 0.03286546788045338, 0.0191350861652089, 0.015982795673023378, 0.010016600950621068, 0.013337935720171248, 0.05046463065913745, 0.030054578890225718, 0.02944005686523659, 0.06687487116349594, 0.03816091462171503, 0.08221878031534807, 0.11227452289313078, 0.17493247533483164, 0.14386973929192337, 0.13161554613283702, 0.1192954672234399, 0.11060964222997427, 0.13741088658571243, 0.08549801792417254, 0.1493208453591381, 0.08574580534228257, 0.08160784095525742, 0.1423614373696702, 0.12282657703118664, 0.16962625006479876, 0.10715386337999787, 0.10194909945130348, 0.11349745334259101, 0.19947123288043908, 0.17844549539898122, 0.09343209397047758, 0.09892853974763836, 0.20155562460422516, 0.09993089203323637, 0.1502045557967254, 0.14926489336150034, 0.12463302724063396, 0.1910267560077565, 0.163785597043378, 0.1050575158691832, 0.1372195804225547, 0.14129096695355006, 0.20700679852494172, 0.12639356777071953, 0.06912111384528023, 0.1608284871493067, 0.1439777756375926, 0.06192282760249717, 0.14701582118868828, 0.06981045114142553, 0.12995887574340614, 0.12180487971220698, 0.17203642002173833, 0.08802051256809916, 0.08514819240995816, 0.09799064828881196, 0.17525351739355496, 0.11864840265895639, 0.18113034990217003, 0.13720695967120783, 0.08998179089810167, 0.1164286160575492, 0.160324009933642, 0.18473436151232037, 0.20353149143712862, 0.12017674850566046, 0.16978711714701994, 0.09333813044109515, 0.13029116791273865, 0.12080798963350908, 0.11015581086810146, 0.19368569047323295, 0.07070732515837465, 0.2016272914728948, 0.16809949199003832, 0.14495999578918728, 0.10837939940392971, 0.12655968671398504, 0.1613005575324808, 0.14540119282901287, 0.12880841961928777, 0.17515306706939424, 0.1535307615995407, 0.12783572609935487, 0.07754277158528566, 0.16058862502021448, 0.1507434347378356, 0.16566437908581325, 0.13481468946806022, 0.16461433257375443, 0.21157732898635523, 0.18890018654721125, 0.14670094022793428, 0.20730201554085526, 0.07607689845774855, 0.12733451942248003, 0.09811857249587774, 0.11202290175216538, 0.08849315970603909, 0.07208652222262961, 0.2337314294917243, 0.17284999707979815, 0.18160646435405525, 0.1262579829032932, 0.11399020547313349, 0.1460923757404089, 0.15598610841802188, 0.08839645489518132, 0.14684915941740784, 0.09836076878543411, 0.1353745079998459, 0.14797134777264936, 0.18591118550726346, 0.13868110414062226, 0.1701979429594108, 0.14550316307161534, 0.13810657496963227, 0.10243849961885385, 0.07759333601487534, 0.12351942913872854, 0.07886833045631647, 0.0775589682161808, 0.13283040880092553, 0.2053223896239485, 0.1769922769495419, 0.14205688371190003, 0.09324518471424069, 0.09742832596280745, 0.16717930350984844, 0.12861874194017478, 0.12456606940499373, 0.16153155799422944, 0.11344543684806142, 0.17641316088182585, 0.10925240934427295, 0.09526278145079102, 0.17640965964112962, 0.09417004830070905, 0.12954559363424778, 0.13553940558007785, 0.12057137090180602, 0.20987458606915815, 0.10327070246317557, 0.12147914219115462, 0.14480518123933248, 0.1438075176307133, 0.09601814020425081, 0.09730433725884982, 0.16625596662717207, 0.06778393166937999, 0.25246298579233034, 0.1183255421263831, 0.11304278059729508, 0.08738101366907358, 0.13920524530112743, 0.1415478331702096, 0.14910337488566125, 0.188668656828148, 0.1109365536166089, 0.12163173114614827, 0.14058674259909562, 0.1061314603845988, 0.11318938487342425, 0.16891842947474547, 0.09887873527726956, 0.12802214681037835, 0.21736056437449797, 0.1928080597094127, 0.0943679701802986, 0.11858422681689262, 0.19415529098893913, 0.15347075196249144, 0.10729909701538937, 0.09470604346798998, 0.12600022102040903, 0.11891533833529268, 0.08489642877663885, 0.07269070337393455, 0.08379985511835132, 0.1438073819237096, 0.07295322857264962, 0.16935559601656028, 0.17129270492919854, 0.12044919388634817, 0.11825876070984773, 0.17972822513963493, 0.15468169269817217], [0.013982044416479766, 0.08640405894922358, 0.02184291586412915, 0.01634766430860119, 0.057192020384328704, 0.03733304761616247, 0.011769094055385461, 0.05459504973675523, 0.029708278365433216, 0.004548391560092568, 0.062059572764805386, 0.004740242671687156, 0.016708824750302092, 0.02528342937252351, 0.0030869728029106875, 0.012005755195527204, 0.018307789129072, 0.00831408703899277, 0.027775542610990148, 0.010043599010844315, 0.02875782722341163, 0.06507171863423926, 0.003339172607021672, 0.02296281246734517, 0.051593309201832326, 0.0548808215452092, 0.013967963966674038, 0.026620603066736033, 0.04995071841403842, 0.06164870624031339, 0.03421532169782689, 0.04891025620911803, 0.03686600857015167, 0.06422267455075469, 0.04576966705332909, 0.03062978998890945, 0.04538353652294193, 0.053684981606368504, 0.04107156183038439, 0.06737794381167207, 0.04012644736628447, 0.01973171013274363, 0.008564960095100105, 0.05531029010723744, 0.02746971500372248, 0.037907719279506376, 0.0039004169105152997, 0.063489442824253, 0.04975761413308127, 0.027857585976432477, 0.0056533714190923744, 0.06180328330291169, 0.00750619695255799, 0.029574155740972077, 0.025766712546880757, 0.044925026662115536, 0.021449319752199308, 0.014741829762767469, 0.04660768833543573, 0.028770217272852148, 0.023565758684916154, 0.02155716441172574, 0.03252624108323029, 0.01950826176575252, 0.04692881181836128, 0.07959444435047251, 0.018742626599435295, 0.0655728303162115, 0.020968686257089888, 0.05409443338534661, 0.03556089395923274, 0.0676835627694215, 0.03219237131997943, 0.04045496688091329, 0.06903436314314604, 0.026142644695937634, 0.03254873451909848, 0.026393801040415252, 0.013978002892274941, 0.03866163953872664, 0.04451907951650875, 0.023370423720085194, 0.03147882728704384, 0.04869196470826864, 0.022832119837403297, 0.027794906304084828, 0.061148917701627524, 0.007247390125745109, 0.03486695280298591, 0.040867088695189784, 0.017113821946882775, 0.022378967010549138, 0.008960710555714155, 0.025462947686069777, 0.003851244749967009, 0.031890514838908396, 0.026121357356065085, 0.02774770062283746, 0.043996156326362064, 0.03189960381548319, 0.029431005208087817, 0.03748294957248228, 0.07496887791369643, 0.06102927840713944, 0.12737995412732872, 0.029638738704047034, 0.04797107553375619, 0.04185065234612141, 0.019207334877657037, 0.0016679128665210946, 0.04275016247161797, 0.07348991584564958, 0.021515193628147244, 0.027210490877873132, 0.06891914789697953, 0.01105432357040367, 0.04081110616347619, 0.009704706392117908, 0.029200469542826926, 0.09322722389229707, 0.025801984493487647, 0.00577663621100198, 0.01907256425225309, 0.050826096441596746, 0.04023197991773486, 0.02032075825679515, 0.03285535770867552, 0.03597826424187847, 0.009066014949764525, 0.012903251768355923, 0.03676791615518076, 0.017563127480181198, 0.02215906568536801, 0.03630083978974393, 0.04729760577902198, 0.018149430930082287, 0.03847361409238406, 0.032207329624465535, 0.01791841859397079, 0.08187913961176362, 0.018909556392048086, 0.021301697673542157, 0.02338196220807731, 0.027245783180530583, 0.10352429135569505, 0.04789914403642927, 0.01893016858957708, 0.008513131045869418, 0.10470380913466215, 0.007889861008152366, 0.06482317804225854, 0.03616926845695291, 0.02840705684918378, 0.020667493043999587, 0.01406932098325342, 0.009016116332661892, 0.062132060660847595, 0.10571488738059998, 0.030732191101248776, 0.017480748239904642, 0.03786326166508453, 0.048940539227000306, 0.06344555517924683, 0.027601771489051834, 0.012982870219275355, 0.05913777383310454, 0.059713205455669334, 0.03284886412854705, 0.031035669281014373, 0.051682821541492424, 0.062422941837991984, 0.01914869248867035, 0.03633267665281892, 0.05270071227901748, 0.05552284798717924, 0.03344416664913297, 0.028369452438450286, 0.04982801214126604, 0.022428634077576653, 0.02370918572082051, 0.03346536408311554, 0.042152858272727044, 0.08104570183370795, 0.166415042376944, 0.008178859250620008, 0.05494564538821578, 0.0576231140377266, 0.020403481853593673, 0.028148579111854945, 0.018919222123388733, 0.004016715268205319, 0.013819845709284502, 0.007703224862260478, 0.05794086520160947, 0.0926144253462553, 0.050221687981060574, 0.04740119772031903, 0.07533593143203429, 0.018209192901849747, 0.041315366247934956, 0.04848097424421992, 0.03462414922458785, 0.031025735528341362, 0.015450447631467665, 0.02248075065602149, 0.026098957218761955, 0.036464054603129625, 0.0033488830792651114, 0.04168413985254509, 0.04969417789418783, 0.09140214789658785, 0.029926118640495197, 0.037176326382905245, 0.03423436139045017, 0.04557175874443991, 0.03772259457036853, 0.012292750063352287, 0.007284185383468866, 0.05911101919731923, 0.03259504453412124, 0.03487186200384583, 0.04790711682289839, 0.0021122568245378454, 0.060328046392117224, 0.04885758492829544, 0.03458624965112124, 0.0759893674403429, 0.00589684462673696, 0.050132511516234705, 0.043210175287510665, 0.10382231072123561, 0.0150872108726097, 0.03573790338954755, 0.016311707041625465, 0.04841560757319842, 0.04911024422783937, 0.02876312318923218, 0.05732728634029627, 0.008794878293494028, 0.01846342470629939, 0.042490310700876374, 0.05044139762009893, 0.05124026743162956, 0.09048191870429687, 0.00871463813486376, 0.05200898993228163, 0.0459426154515573, 0.04815484656553183, 0.015580236113497188, 0.031549883474196704, 0.045773022408996306, 0.07241850905120373, 0.02987143550334232, 0.02428218988435609, 0.015162323002836533, 0.03667826810851693, 0.026281917401190315, 0.04488860968766468, 0.009760130828778659, 0.01366307697857597, 0.04129287959741695, 0.05917460471391678, 0.023200535514791096, 0.02275449543126992, 0.046907733128006966, 0.02968813944607973, 0.032558152585157325, 0.005561741202005318, 0.015521274813051735, 0.07107892486133746, 0.045531209491725476, 0.04967957242791142, 0.021532352082431316, 0.04111143594075527, 0.010093510350478547, 0.06715433938162667, 0.03474833470370088, 0.0891989039789353, 0.018698065508423106, 0.028064547638807977, 0.03567143749179585, 0.03060487757569977, 0.051083719224802086, 0.018372568867302368, 0.07281573702182088, 0.03969170319448624, 0.01423810572097344, 0.016903701703995466, 0.040947569733751674, 0.040853999754680057, 0.01469371484459511, 0.025882280631256954, 0.01462437874371452, 0.01421965126480375, 0.014876530838332005, 0.04869126581719943, 0.016992532115961825, 0.03326149484408753, 0.012452952181255179, 0.054832584490733485, 0.022375185874157717, 0.046971335607979975, 0.029643817538661615, 0.07650644505130393, 0.05007772999150412, 0.03907811754782285, 0.005827585709214742, 0.021316467684560587, 0.020244345035670058, 0.011934812662989965, 0.03757193265482783, 0.029124256489532332, 0.044778551307639906, 0.024471307772078683, 0.02191593810649855, 0.03230679268017411, 0.026835410290264657, 0.06568318725164447, 0.042290963897747655, 0.043300871670778306, 0.030213814095727036, 0.08937028835394553, 0.0402793009499354, 0.024405366042628884, 0.038411718127982955, 0.010235966233137463, 0.03312199143692851, 0.056696516794285605, 0.02147710236853787, 0.044073197192379406, 0.03941859284948025, 0.04422776068427733, 0.0368140293950481, 0.04701979997168694, 0.0192505779143955, 0.006526490349122989, 0.016369536884927323, 0.01437730887638671, 0.047505739610642195, 0.058389872179499695, 0.0639802882713931, 0.06578431611082383, 0.036316917677010806, 0.03903036564588547, 0.03393519190805299, 0.07019800998802696, 0.031561394820788076, 0.09839053611670222, 0.03281249125887241, 0.08661629113235644, 0.010179761481205267, 0.03696302550711802, 0.07235209404357842, 0.15531399234064988, 0.06979046149977616, 0.11506987682410649, 0.11686642042228154, 0.05936697617705379, 0.11475400520222527, 0.20061655927981648, 0.08518606144934893, 0.1356975313808237, 0.1279995787356581, 0.10608080096010651, 0.057175728758530955, 0.14733652397990227, 0.08876233454793692, 0.05590268849794354, 0.10719579005880014, 0.12615970389119216, 0.11270487015800816, 0.14391167275607586, 0.12712791908000196, 0.1405303291976452, 0.06602221048836197, 0.13433294317552022, 0.11732410586306027, 0.11901695573968546, 0.07776932764266219, 0.13388004819197313, 0.15815907610314234, 0.13919479586184025, 0.06776833893465144, 0.1272106867815767, 0.14007424509951047, 0.12673040612467698, 0.1613463857876403, 0.15666481985577516, 0.1126735761229481, 0.1894847580364772, 0.08393053417759282, 0.20309972603406223, 0.1202671972236463, 0.09706531651318073, 0.12677505372890405, 0.10870918099369321, 0.10018924424158675, 0.10910566936114005, 0.07226362664784704, 0.12350922397204808, 0.11761313463960375, 0.14432723474289688, 0.07476738015455858, 0.0983301939974938, 0.18826882328305924, 0.12598576822451182, 0.23094693890639714, 0.16573030554822513, 0.12479214370250702, 0.11838990795825209, 0.16866726295224257, 0.08010465518704482, 0.07353486200528485, 0.18064959427075727, 0.13309876940080098, 0.15043421275913715, 0.1451669353991747, 0.1791254553411688, 0.10399394615420274, 0.2623527151133333, 0.10761809668370656, 0.1338874442236764, 0.08472621826721088, 0.17467186360486917, 0.11591854771333081, 0.12447153590619564, 0.11797263606318406, 0.15607442653604917, 0.09985108274434294, 0.1834637639778001, 0.08975917712918349, 0.09670280917946782, 0.10645490445728813, 0.14970739318856172, 0.15112409288329737, 0.11928132655365126, 0.1526029192443405, 0.13595203629561833, 0.18852893289710793, 0.11589181343359606, 0.14860208678458417, 0.17770072179181234, 0.09739614304687295, 0.09042009059339762, 0.12222243659198284, 0.113137999416462, 0.20772623563451426, 0.1366112194955349, 0.13133294986827032, 0.07101181774799313, 0.11323759478649922, 0.17214407638779708, 0.2854809340621744, 0.14287502052528517, 0.10681226849555969, 0.1219167158539806, 0.19010913238993712, 0.09173312370798417, 0.12180292553135327, 0.14193861505814961, 0.08457408393067972, 0.10374910357807364, 0.10420053292598043, 0.16306649920131477, 0.08407094342900173, 0.20160477768097604, 0.14087845837431295, 0.05845057392226798, 0.10186720027455262, 0.08151995031429188, 0.07412082449133907, 0.12125020447586264, 0.10389549750834703, 0.08009778162730591, 0.12057299938585077, 0.11849109110023294, 0.07476412318646908, 0.1305856928229332, 0.11912862903305463, 0.10830970028681414, 0.14318352325686387, 0.10969043762556144, 0.11629061560545649, 0.10500457656702825, 0.14864746720663138, 0.1236218200730426, 0.08890723570116929, 0.10083140978323561, 0.09429920065615859, 0.09927563076572758, 0.08210642848696027, 0.1773553610380207, 0.09099038570587124, 0.1598364689520427, 0.16065698063799314, 0.17900105273084982, 0.17126519711954252, 0.2323983253112861, 0.06674925397549357, 0.09619994687714747, 0.19689779382731232, 0.13051938638091087, 0.2441478105528014, 0.12426604836114816, 0.07130786936197962, 0.09600852536303656, 0.08270020091107913, 0.1410211000059332, 0.09393753470586878, 0.24908108583518437, 0.10888441944760935, 0.0756156574934721, 0.14086902673755372, 0.1426415094839675, 0.10615749577326433, 0.0845463861312185, 0.154829667615039, 0.12173059369836535, 0.2161194695425885, 0.10928632930985518, 0.1260202649448599, 0.10023873658584696, 0.12795601678746088, 0.14557236007281713, 0.09469701216689178, 0.14805050566792488, 0.10637677793524095, 0.15161152529929364], [0.05388666935531156, 0.031446169396596294, 0.042008082648473125, 0.04332546177985413, 0.07061458977737597, 0.028058179587657963, 0.04556127877107688, 0.07028899474867753, 0.010228822107559868, 0.050569745911551375, 0.014981481546003903, 0.0021784243789235397, 0.011907724696876747, 0.05172250566205808, 0.030323190548058068, 0.02450775697694293, 0.09625581745058298, 0.03787679843870657, 0.07620542656098094, 0.07359359599649906, 0.010497692456868078, 0.021553066060213105, 0.0024572780987780008, 0.02313831724625613, 0.06263261594410453, 0.0644333121765937, 0.07441606186330318, 0.03204261864136372, 0.05908450883414064, 0.052649316644029956, 0.05012521387210914, 0.05584963045216032, 0.022511647748095647, 0.025429519658376063, 0.02316577246944819, 0.029725180672747747, 0.020290000264399817, 0.03590331326371857, 0.01185437064019165, 0.037459183883454115, 0.032569171993860176, 0.05208996630140713, 0.05169108949069466, 0.07724752742797136, 0.023086529757295336, 0.037066681909241846, 0.024593059006812315, 0.0870877169072628, 0.011541683043885444, 0.006624006857496819, 0.06905689050576516, 0.050829404299812656, 0.0474612073573683, 0.10071113266583, 0.025168782399435128, 0.04921543411910534, 0.029727005931947912, 0.025385311405573572, 0.06558279121028525, 0.061791341086583476, 0.024237555850829397, 0.02140113358784999, 0.03575361147522926, 0.019440745835059454, 0.04892905502180968, 0.011046533988389586, 0.08839589171111584, 0.007124297936180872, 0.04016386178721275, 0.012735204937468683, 0.03545757343194314, 0.08265522761004311, 0.07173854232366596, 0.030823281034827232, 0.0194618838972279, 0.059222244657576084, 0.08192818412291152, 0.021617521797972064, 0.011538577898006355, 0.024301818206108043, 0.015681758522987366, 0.00843767455912062, 0.044249497553599734, 0.055985588513846905, 0.031202137669814483, 0.061405777132936885, 0.0675053455467735, 0.02933222408007298, 0.03459647856652737, 0.016924179890858274, 0.009044180541033191, 0.02936847142076918, 0.06486674677580595, 0.021552509661497812, 0.06555263032870633, 0.011079920455813408, 0.01747019532402711, 0.04214593721553683, 0.0955406143995268, 0.03130621137097478, 0.05820332933217287, 0.028813640121370554, 0.040242870404784165, 0.03087915839361293, 0.07040176048342671, 0.03121932496183685, 0.06905982177704573, 0.09336337194378887, 0.02507107674942485, 0.019442145313535417, 0.060290428410683355, 0.005774637501287673, 0.02123748790472746, 0.016298648635191575, 0.038809739984571934, 0.07268961093255452, 0.031727086286991835, 0.02588958166805761, 0.07936433276959828, 0.03109375187861068, 0.03149236406066588, 0.008393675804005137, 0.038271302091223855, 0.039480577023433785, 0.01743286402363862, 0.021953647690159932, 0.01051593741535076, 0.03148607064836791, 0.054323103079306226, 0.023072864062019756, 0.059119874079312594, 0.05205008540568607, 0.03217915006514106, 0.008687002251722982, 0.02551636365907533, 0.07111806954656329, 0.06051209223057542, 0.022261814546904395, 0.016561083928016678, 0.027659818463559662, 0.02194304558049355, 0.014290208728717906, 0.054954951495996544, 0.07088869078350918, 0.016689484805933068, 0.03823959754247751, 0.01914423281726028, 0.04812115051650575, 0.04819982325924294, 0.010989733821978527, 0.007376570470764169, 0.05545633798465133, 0.03112927997218711, 0.05464601110933082, 0.03732975672132202, 0.03419215311961515, 0.07851902062871627, 0.05722841021737882, 0.027627033347796117, 0.03597448819449969, 0.027993226822997843, 0.006042124487326613, 0.05294602982965963, 0.06964680206562791, 0.02533050613211734, 0.0347316088154912, 0.07249090873769351, 0.016656982978539805, 0.007319820346310735, 0.02303718838707677, 0.03653253574988671, 0.026268300899703587, 0.04903205663764051, 0.04866576647119863, 0.07239370181092195, 0.04158293974718877, 0.05025308718904853, 0.018407847599259446, 0.05856422853789159, 0.018071049957403114, 0.05853366732065167, 0.01907151930832437, 0.03832232792462621, 0.057259446409131796, 0.01791876634316785, 0.022056216739916375, 0.026717061908649545, 0.06723296123423747, 0.026025673740410378, 0.03278596393231835, 0.07925445080867835, 0.05137820681557059, 0.07698006249432053, 0.02361643168010882, 0.07596365774848632, 0.04995412126715694, 0.012917073526685792, 0.06913405350808587, 0.0623507932094591, 0.06732940820178815, 0.01801920648930328, 0.018383298202284744, 0.026762058958411217, 0.040017277867134125, 0.048802620199109824, 0.042583639800016365, 0.050917138877723894, 0.043813104541706185, 0.034910236551825485, 0.04365393379703164, 0.018677566965509738, 0.03636727176074471, 0.01929183114719178, 0.04805377198915396, 0.05066688159214599, 0.022449348055358444, 0.059464936277696064, 0.047083449949111254, 0.07812414038926363, 0.03018112906387874, 0.014217218716761895, 0.055015208798327615, 0.04946123003693564, 0.05423470353707671, 0.04724840181214469, 0.05068057103614722, 0.060697488353720734, 0.02749420842155814, 0.0396673777140677, 0.042401544749736786, 0.0465258230854358, 0.036794993095099926, 0.026338069566658566, 0.046513093768485954, 0.09713843544679028, 0.06646108693842377, 0.06401769590697118, 0.0038495526532642543, 0.034804836314703734, 0.009739837542708431, 0.06413054985127278, 0.010075732732989957, 0.019767226351957237, 0.01333484160048621, 0.06004513121609177, 0.028164297375561934, 0.005450675621562238, 0.05222836708916085, 0.018114230229652355, 0.022579677669065337, 0.023284132725426128, 0.02126650545479996, 0.009770834718697836, 0.031841874056096585, 0.01154974743258208, 0.06574750558606215, 0.07340081062700067, 0.039231520744838884, 0.032965735000159056, 0.017596689518541098, 0.03126619816092508, 0.059575089652623446, 0.032065766863524914, 0.04465592306639467, 0.0468521407539291, 0.027241866337135434, 0.038539567696196694, 0.037828266221497736, 0.024034148015614067, 0.01810121423165713, 0.0685470053660018, 0.015498935743900282, 0.03910770506731101, 0.03135100146755576, 0.024132421938702464, 0.014683460484125783, 0.05853781995496579, 0.035448606591671705, 0.016533940830933194, 0.03828846224184547, 0.03112356670733009, 0.054096085618117025, 0.06515064582760845, 0.0663793438247272, 0.04804502906543868, 0.022481122153944204, 0.03327282298622387, 0.020021480208794986, 0.015572685715077179, 0.037136794932718785, 0.016179129780669297, 0.020252438262104988, 0.018410320859402418, 0.02791843021155468, 0.05016421267230596, 0.03719646869493382, 0.01180387067142874, 0.007521853299944529, 0.026096797781065106, 0.07264116353222302, 0.04166238262717213, 0.023518486846504465, 0.051323584746569395, 0.0336493793874979, 0.0050804206901895145, 0.015769981646112034, 0.021552901515471082, 0.08070918917655945, 0.04430942237377167, 0.03587400394358805, 0.019619071623310447, 0.05780021846294403, 0.039328089848692925, 0.030353110549705367, 0.05310107847409589, 0.0817352630464094, 0.012539580747086023, 0.027043993651334728, 0.015904993151447604, 0.003808430038459067, 0.026773792525221194, 0.013588014042137988, 0.056160762506936274, 0.019500514592177103, 0.02669141158860709, 0.054796574637293816, 0.030490809053714787, 0.04342257710439818, 0.04047603539324232, 0.009762177460028656, 0.006494796402486307, 0.017913473770022392, 0.015485373525215047, 0.02450893253886274, 0.07224639185837337, 0.03324593264343483, 0.07306771100099597, 0.06888287341488258, 0.019126940352310027, 0.06006306489663465, 0.022242896990584474, 0.029109430499374866, 0.07056006270327739, 0.02963761572859117, 0.025446152248020684, 0.06904591859451362, 0.01809497001314802, 0.036897713118898015, 0.022419631614216735, 0.015520329953038266, 0.09074070517505918, 0.03887968337429421, 0.12121661699243955, 0.1278748232871294, 0.1660533153585025, 0.16628538790558064, 0.11923650253031935, 0.08750918893409626, 0.10068574867078237, 0.159751882776618, 0.11903522190238748, 0.08104891130434615, 0.07896137796342373, 0.1142989524773189, 0.1181304497378213, 0.10873955222112791, 0.17745518710996422, 0.1910052600183657, 0.1743537935295275, 0.15320019290915557, 0.2356637343764305, 0.17637293732592038, 0.11396094704312937, 0.14896365095462116, 0.14923091232776642, 0.19224882471774304, 0.2084618490189314, 0.12534209633512156, 0.12805259946201528, 0.22690861060151032, 0.15714906315718377, 0.14897043630480766, 0.0688053032915507, 0.17775334896785872, 0.17205541900226048, 0.10145066798265491, 0.1398967539093324, 0.17055426883910382, 0.13945358911795275, 0.1389416480170829, 0.13629485932844027, 0.12804653335894856, 0.18288265301712922, 0.20395914491798195, 0.23619662863867624, 0.20464993427906716, 0.09782660566270351, 0.15169486297028406, 0.18815310592097895, 0.24576921069196292, 0.1807634931589876, 0.08754456774996859, 0.16273483128419944, 0.08217958134732076, 0.1911030233438526, 0.2820640488394669, 0.14389572718313762, 0.1084618821207966, 0.21572996330048355, 0.17232724013073103, 0.22734915624771798, 0.11028831518654313, 0.10087183689964668, 0.08212580066174269, 0.07493726496717759, 0.1572509655462844, 0.14871314939643654, 0.12218401793922697, 0.16581624879368714, 0.04537720239854284, 0.19911334637020314, 0.1408665297286851, 0.11372691352984735, 0.11668036612016813, 0.1841977760195732, 0.11197920409696442, 0.11271335184574127, 0.1109136530597295, 0.13307769410312176, 0.15939064430338995, 0.11644868712340083, 0.17085190143968376, 0.14679058827459812, 0.19563806642379078, 0.16059907445950167, 0.11100361323250191, 0.09501120780727693, 0.168730407421078, 0.07601439859718084, 0.13012966300759995, 0.15599982839609894, 0.09085887883390699, 0.10725744175059454, 0.2013284917920828, 0.2238447671490056, 0.0625832796628986, 0.09903293236025743, 0.07367148503128972, 0.1013808399438858, 0.12205881465758596, 0.25798951781221796, 0.1432446456913437, 0.1420585529080459, 0.07690619717219047, 0.11464719021958963, 0.08245622685977391, 0.09202171822211572, 0.1519229050193514, 0.1255149327750717, 0.14652358474475996, 0.09586908641670432, 0.06542604283562728, 0.12011125630566052, 0.14342783657567842, 0.09910436852702073, 0.13312087607170853, 0.12223181394594056, 0.18476383707353047, 0.08388356598360197, 0.14007463864982128, 0.11961439225290503, 0.1960208008864096, 0.09347784758678504, 0.10731393657624722, 0.09922750227685485, 0.136466881526368, 0.11020163912326097, 0.13346395694783755, 0.1316836303366082, 0.168747764346855, 0.12399597785302571, 0.11889556582484927, 0.09854739305696317, 0.11074665880628995, 0.10522540578884737, 0.12747300841978618, 0.13717748410999775, 0.15508558388267243, 0.12660585423665388, 0.08642847942454474, 0.10080289095640182, 0.15520116553774901, 0.08346451632678509, 0.06188484321215323, 0.08776349028838532, 0.1516710871032306, 0.09397861321589776, 0.12107569883976664, 0.1533932496926614, 0.14131547563842364, 0.11576853719140802, 0.12627220499728406, 0.14079776698989527, 0.19214460173887865, 0.09696701035967895, 0.18555327185562678, 0.10809451647635017, 0.16951343683259829, 0.17395819404295512, 0.3084248628999506, 0.21598465820508345, 0.08066762212131705, 0.15685395470687322, 0.12601060260619434, 0.1608687921294144, 0.12820429275078432, 0.22520269214042596, 0.12544275021978787, 0.15929104893335275, 0.10401394936655249, 0.05058084674445646, 0.14970006501036032, 0.0748793723593865, 0.2031123467854091, 0.06559010581778628, 0.13427194287734373, 0.2389912972492831, 0.24917382800153323], [0.02587824165155845, 0.005947379794503961, 0.010297927506534117, 0.0810271506862981, 0.04273050531212773, 0.03832021089536803, 0.049426780814038854, 0.03018127494890775, 0.031849114024745565, 0.03679002282608833, 0.022471147689170072, 0.02225930566367294, 0.02548384995731924, 0.02248380915261805, 0.039726807203676016, 0.02877551663134779, 0.03432980751884835, 0.018129692346389805, 0.015623619946252023, 0.0855084809341601, 0.04244241291390998, 0.030580833687313964, 0.026892084927697266, 0.03536312475002237, 0.02080846039046134, 0.017321608029305935, 0.08971970674714871, 0.026019570317917635, 0.047726097250623364, 0.09018511391643967, 0.08733856451830693, 0.016102775931358337, 0.07152747043541499, 0.07015605616782393, 0.027168811864352653, 0.04203576687723398, 0.06869133654981852, 0.037865008892757554, 0.035972941134657176, 0.015033742313140204, 0.015254751346739275, 0.11859950742551259, 0.09837096038141421, 0.04004816138850791, 0.06928789096751384, 0.042478595793779404, 0.05017858404400093, 0.03311994565384729, 0.06652086587356669, 0.05128159699961543, 0.014635060581245592, 0.017805613843458037, 0.01659715484960803, 0.0032882977476609604, 0.032982759443776946, 0.038211095679019175, 0.044999092152076106, 0.01269289234187454, 0.08629494373287473, 0.03733688473169293, 0.007010941027796694, 0.012459040336710001, 0.031141079696161405, 0.053513685440910716, 0.016608265860538398, 0.08721752744168043, 0.04661880613171628, 0.06432368127363068, 0.005211067094933242, 0.032413899432867765, 0.039903331481452496, 0.017037518987698213, 0.0129477560320603, 0.018453701299482157, 0.0314679028732436, 0.08693809315030064, 0.026203880785033107, 0.03642363427206874, 0.023970657493919134, 0.017787240811490586, 0.01262771396432072, 0.03193630916731698, 0.0444510801296149, 0.05134751667667713, 0.05981517569827182, 0.02734368390935872, 0.03493655692519886, 0.016547352075576782, 0.05235945666208863, 0.044938271665679555, 0.0587974206677505, 0.012511362171997982, 0.01720840124679463, 0.018898150218384605, 0.04411098141489284, 0.037959277762898376, 0.01817353249394468, 0.018230929771172147, 0.04879374156839081, 0.03111525804602674, 0.03627571363800338, 0.03696238768420049, 0.01858062806007053, 0.05417904330949698, 0.013894594823276358, 0.011905704358858722, 0.004417127264397485, 0.016752498656777397, 0.05661899416840502, 0.01891363608384771, 0.018816943147352765, 0.04679830917822463, 0.030610838505838598, 0.07666929345577955, 0.01827206595667771, 0.06869476315166269, 0.03885636891105345, 0.047621372155845165, 0.04537959423448358, 0.02520821546204388, 0.04461071567077722, 0.02778860610643668, 0.04127615710188236, 0.04223604666601334, 0.03533675009384751, 0.023706844775006175, 0.004282426188832947, 0.0737149180578334, 0.03875934858141201, 0.01527105993591249, 0.04575358238071203, 0.016831865201571157, 0.027900328593594686, 0.00252770515674326, 0.02515600897770907, 0.021869646751188805, 0.05907839523362262, 0.011137795252060252, 0.0342966984026134, 0.03128348044785006, 0.04969643402312483, 0.034225577754633765, 0.06263352518102952, 0.0227395184670708, 0.02441406316523041, 0.05864551703312567, 0.012800445231342954, 0.036333212695483647, 0.03760895352544529, 0.022508131240361502, 0.008442266544859325, 0.03505599944453154, 0.049148863048425744, 0.026306073247854198, 0.01325598989413785, 0.034524245121117146, 0.03701111328388963, 0.03664685193715351, 0.06255687786532299, 0.02531308983452618, 0.036856088388179026, 0.06817315292677709, 0.043095109319048266, 0.026131818669715097, 0.0065116533327714676, 0.023982043311532055, 0.006851394544355571, 0.020126610728246824, 0.038260204650993855, 0.05188947955944708, 0.07501993088849954, 0.04380226494478328, 0.0022560933139175177, 0.033171443069087606, 0.007142912696248719, 0.028430473092677336, 0.05392901672582541, 0.04181755001523665, 0.035212551044034104, 0.04606111141453896, 0.008626356488093734, 0.044127785334629674, 0.04131580051034689, 0.00965195199075554, 0.023574136896058917, 0.048248318157025745, 0.035317408453140936, 0.047318209494863234, 0.05359048881967153, 0.020982136517497044, 0.03852024641154068, 0.024792877391778996, 0.04469751726303782, 0.018483307478683333, 0.0080172593505787, 0.04441577934526971, 0.043979488113628964, 0.03169230118926082, 0.048430284285651784, 0.02402475200194333, 0.011516606085933745, 0.011211493484941977, 0.04133704883445587, 0.04641062819531985, 0.04600389055641634, 0.01834684730108295, 0.0246631262291755, 0.03524883570415633, 0.010073361253099782, 0.04284639909331288, 0.02498527938899185, 0.04231768460678203, 0.026204944388674836, 0.0574736599145191, 0.03320124771978174, 0.012443124449678829, 0.022932973889900104, 0.06844076713813202, 0.04803021325330649, 0.09917016606777906, 0.04379409538315875, 0.034872710172619135, 0.041029268742672036, 0.0007299340463110379, 0.04936279156910522, 0.03180237653266106, 0.03539604048377701, 0.0186306462689702, 0.010377378868205207, 0.05299734743312001, 0.02890486576195274, 0.08972430042922497, 0.05242086408127632, 0.04576867299952677, 0.033580053464642594, 0.015413708352882947, 0.020621040536622916, 0.015763482976970927, 0.050544433162680695, 0.02229258102098746, 0.017561617739764706, 0.03586216350751264, 0.03623966646513768, 0.015039830468595028, 0.012091838388836809, 0.0088680761067995, 0.0539224960042962, 0.04206389554643205, 0.01670647532280002, 0.07732266839593649, 0.03517233766615391, 0.11239461002073117, 0.038516619641866, 0.022349946067801545, 0.04972920047917536, 0.04383984221411603, 0.028193089312740734, 0.015748885992382253, 0.03496383064027343, 0.0526129980571568, 0.006403535562900028, 0.009013780475860196, 0.050646464473434856, 0.006502805236128292, 0.027337877345936637, 0.0539738034297313, 0.021959776557715874, 0.05498693763677563, 0.01576325566773968, 0.04085481060402734, 0.013665735987680299, 0.056728004211825986, 0.03168300186683025, 0.029968561005911658, 0.026613975475941385, 0.043670517192887406, 0.0841041984302657, 0.01442145266836243, 0.023829898796975613, 0.04266899272001215, 0.0053109533868597025, 0.014267057113881623, 0.03129553122978125, 0.007494814527620162, 0.014205285830290189, 0.017905901319214275, 0.020709974425179616, 0.05989527675722327, 0.025076695019379258, 0.0385989021909024, 0.058452277045164786, 0.037255962645368915, 0.027572650462388992, 0.05055388515549047, 0.031433172058314085, 0.06622126552143268, 0.004393971832801721, 0.013003733474761248, 0.04604640416800976, 0.017185692376058017, 0.09207986867321388, 0.049933273278708966, 0.04915500379034451, 0.03180723823606968, 0.05429662325020347, 0.01295945736845689, 0.017099835643810884, 0.06384386880589382, 0.10835117234715394, 0.008034539092997355, 0.011857893085107207, 0.08870341056691748, 0.06250450174723353, 0.01617047337016889, 0.043840751451041014, 0.03331938745187862, 0.01809901068918407, 0.046965632521148236, 0.022449958736875227, 0.03716126290549125, 0.016958395019173622, 0.04663459224892514, 0.03347260405176452, 0.03116989368572831, 0.029437909301902567, 0.008374913462570735, 0.018994921186406697, 0.015049077204561659, 0.015575608504670007, 0.04664918414450117, 0.01891272684692272, 0.05932893750390836, 0.026391385455748866, 0.08831254725477525, 0.09289638378790446, 0.05442092068759458, 0.07812838801848036, 0.04284296909879361, 0.05390208227826016, 0.022691442564662014, 0.005214929231442511, 0.10988807452044316, 0.025258837567110146, 0.0252179965443377, 0.036645705212971995, 0.024054293720317737, 0.10000058436500174, 0.02012488216028682, 0.03332539587946875, 0.017534101448420967, 0.04300133917214615, 0.0342594468300896, 0.13126023805567197, 0.08060758534286704, 0.08258568455598184, 0.1961952250983034, 0.09646497587008135, 0.14932963917297976, 0.17080467540238584, 0.07689555095774786, 0.09567985657070364, 0.1173407571124179, 0.09967009031346866, 0.09663944079407624, 0.10925814296518054, 0.10661018719630581, 0.1685606108180114, 0.09641343435006482, 0.13163575290569238, 0.18563267402350903, 0.10863747341292244, 0.1201079043426684, 0.17026324516960553, 0.1199357600084373, 0.12977283501199313, 0.18217306823602744, 0.056416034166302, 0.07467320627932038, 0.12395462792898927, 0.11827132717839309, 0.16583100014499255, 0.2131679236356701, 0.197590564510652, 0.09723364748060703, 0.06007201477353062, 0.16386560989277704, 0.10113505420408078, 0.1474461480975151, 0.10772550199180841, 0.1157511259828295, 0.1763792477015938, 0.10217873605766467, 0.06490061924393688, 0.2102086560002395, 0.13415178789624146, 0.16613935359886714, 0.20167120625930174, 0.10463380467678819, 0.13986220290618284, 0.12048086790101868, 0.10710661020129919, 0.17114064523151942, 0.13895893708935805, 0.08817074022122792, 0.10545849613845348, 0.13910996541380882, 0.14822752188358987, 0.16768702412290232, 0.14461221945072922, 0.0964320737070271, 0.1564752236008644, 0.1374608539044857, 0.10664158301161868, 0.10076963595513787, 0.11938318823065076, 0.1840104732130255, 0.11310819815844297, 0.19449791046125547, 0.11037260280655962, 0.25128971732088495, 0.10395744097019945, 0.06029517137046371, 0.15993089388523782, 0.11684909063790526, 0.08929764439484902, 0.23667195598993981, 0.1554055538560663, 0.2257789447903633, 0.10581250821373292, 0.10885100159794092, 0.10288285184651613, 0.06717540110860552, 0.11168582591095141, 0.09229640276836497, 0.17650869861245155, 0.10357096777962786, 0.1469319678310837, 0.06803131875182901, 0.27475109696388245, 0.07288429620010511, 0.16785000823438168, 0.09288839743073497, 0.13949375839105674, 0.09936057656471219, 0.1858744224799531, 0.13512373502765382, 0.14795810276908533, 0.24422882763402803, 0.1109544737264514, 0.07058408284293753, 0.1864876010056053, 0.11872224083968572, 0.27647932565637995, 0.10636592816029276, 0.12447415505136762, 0.11325140297412872, 0.12867803233010427, 0.1126787465597902, 0.12455889050449644, 0.09245087805071048, 0.12061101091759545, 0.10180670209228992, 0.0821733388251492, 0.18175636631037506, 0.12038581871560641, 0.11975721030363015, 0.13312232813664845, 0.14739384661827767, 0.10096499975770712, 0.10654234047979116, 0.17071145826152392, 0.12224603603993144, 0.13930409428264412, 0.09716322233102151, 0.09637494784380708, 0.0785609201661178, 0.17450589393930777, 0.11037683686507599, 0.1109427214999284, 0.10676195512392692, 0.12667634045439108, 0.11242925601878337, 0.2144927361181804, 0.21750465807105812, 0.18927851053220884, 0.12822204322687217, 0.1307270995208195, 0.15825538736368927, 0.24107521399855614, 0.07073310948908329, 0.14729210707758153, 0.10601515948240246, 0.06698342319577932, 0.12637718793536934, 0.09442420037729399, 0.09238802535193306, 0.0678256954997778, 0.11034033168107271, 0.17677221447229385, 0.09456809051334858, 0.12001229875854083, 0.10641147821609463, 0.1166329908051661, 0.132673531504614, 0.14684046059846878, 0.07575669099709817, 0.05894238967448473, 0.10877563671341964, 0.13339748765741075, 0.20216414837964944, 0.2545318119227886, 0.16861842200160027, 0.18985926865467004, 0.16947427179132188, 0.1646096778235265, 0.17666116543114185, 0.07440774980932474, 0.21066764422825404, 0.16316129054341996, 0.10463394716914211, 0.08528347872197628, 0.11165267268994025, 0.2230073327996901, 0.19510910766465323, 0.12205691475953374, 0.1499672449593033, 0.10662025665598256, 0.23511881647365435], [0.06689398549497128, 0.044791884520756345, 0.04148334437715156, 0.062002060136624744, 0.045429944925542386, 0.031644267695290704, 0.03065264644101262, 0.031132516584226062, 0.030424173522208418, 0.009130904949935419, 0.028526494279503822, 0.017585417355543802, 0.02308267567838941, 0.025822403308536326, 0.03496273480621832, 0.06367765486772571, 0.026233693917414973, 0.03726380651018449, 0.014790361979976296, 0.06280763726681471, 0.07968736972127642, 0.013995814436514462, 0.04263818723016551, 0.028470179265631095, 0.0494655149855784, 0.02106436139105686, 0.01751374200518642, 0.030233841056802442, 0.00969298554783953, 0.03975082055798598, 0.017014550577316965, 0.06462781423968927, 0.03300284068765385, 0.05017487585012402, 0.05300080456904002, 0.010854630714415439, 0.033045856415161064, 0.032014700318021436, 0.08672616630792618, 0.03910131326743534, 0.034952424466609955, 0.018491125898435712, 0.018949506837608557, 0.05642295183081712, 0.06074417156300374, 0.019557528497119035, 0.04443078514720712, 0.029980197881481478, 0.047841784078627825, 0.0291130776251001, 0.039876729516046386, 0.0677011368264045, 0.06023744839642729, 0.014238578999148948, 0.032269137379314215, 0.0836342925738011, 0.11999472470155784, 0.025277076588411416, 0.009224147535860538, 0.019836954306811094, 0.018520496286717907, 0.02046479088520365, 0.0710491303886686, 0.0678273511252233, 0.07456846761384181, 0.03408221009054354, 0.034951674685414345, 0.02409930434077978, 0.009157080286448556, 0.019458260520228317, 0.02489857279163386, 0.03422635467723012, 0.06188308580645493, 0.052318700456193516, 0.0019495498522051743, 0.07181306582476411, 0.08240178120987755, 0.020851370945040668, 0.03199938917532563, 0.035864643553005796, 0.06628981791436672, 0.049487621656485965, 0.024335166505937065, 0.037290031888655255, 0.02612937255097287, 0.02062287597384836, 0.01345019509816276, 0.023366932657414248, 0.025966832879930735, 0.029977955323244845, 0.03771576511540583, 0.01150871133099177, 0.03496069920116237, 0.03146769592006292, 0.04894830845296383, 0.04134507251105138, 0.0030439988477155566, 0.024015162605792284, 0.022028546081855893, 0.07354285514780454, 0.04535553338272231, 0.05050302556316767, 0.030588507918374877, 0.0240363651287875, 0.020841735747775862, 0.0050918735131355265, 0.06921900609242064, 0.013550026259118957, 0.021930107614025474, 0.049463112971612384, 0.013501404136020159, 0.012881771894171834, 0.033269582981509824, 0.017363629703010832, 0.04576436769483345, 0.04521463219342487, 0.04638489136206252, 0.05037300807556935, 0.02366091643593141, 0.030069177571151937, 0.060010268086833615, 0.029943126120737622, 0.038988608600837846, 0.023640726626451527, 0.05885042103805712, 0.033030389209410975, 0.1168754720794303, 0.03665714192071131, 0.052759975527546236, 0.04750380239316395, 0.044396278248833757, 0.03908453309642417, 0.00882688139764858, 0.023013880709186196, 0.023226504746292318, 0.007832171960866876, 0.022217246670542017, 0.0751738701281803, 0.012728160047637565, 0.023083576433626667, 0.0543277849709349, 0.026791074812146168, 0.03973271045833826, 0.028691551315465143, 0.020158780073480945, 0.06225614435970783, 0.06814596402857985, 0.03962537978908845, 0.013739544482502555, 0.023935478845877305, 0.022492928663268685, 0.04055103047617844, 0.029144765210470984, 0.022587446895028864, 0.033734467678836415, 0.012176139579553689, 0.04837581827970488, 0.06556051490562302, 0.04254149938268321, 0.08168942122054951, 0.024281109317338893, 0.014522484836301633, 0.03202648647129536, 0.022047151512067233, 0.05761420487293175, 0.04460900576253023, 0.018390792621565715, 0.010265822622126766, 0.08190681705517427, 0.009648511818210994, 0.03496126577790294, 0.01638398628814944, 0.03133219586951392, 0.03746773681736418, 0.031562178528734615, 0.01591167502504374, 0.0838618121509041, 0.016707301439185227, 0.06947042367288045, 0.03276852897501417, 0.056594984206770144, 0.05362492786454303, 0.03824792316715632, 0.016739124731559838, 0.034373518744749684, 0.026062765857204795, 0.041728159811879904, 0.05387692219976868, 0.014556224990103925, 0.04520544143659728, 0.093498950025865, 0.01862332657245653, 0.022090157061549168, 0.058033213817647526, 0.014687034667336514, 0.025362473613183414, 0.0525349834933877, 0.041326059959828854, 0.09127811848052911, 0.04009928221681288, 0.03278216413621392, 0.026858918135985732, 0.05450886221868651, 0.02395616568225835, 0.04101832058014614, 0.015838608677898134, 0.030220494272985628, 0.03812179368521486, 0.0060230385695051935, 0.017699870946151868, 0.029675294778176715, 0.09310906380414963, 0.024637906778869883, 0.05812170156942947, 0.009903460325274085, 0.04584588349929877, 0.03264208397428904, 0.03207747498527169, 0.047170499206653664, 0.029872904531657696, 0.03505957532407982, 0.05398536566644907, 0.024793973225834112, 0.02768419144142951, 0.012139918532089462, 0.02738713559561542, 0.054517309979668686, 0.03732170929600086, 0.04990340416718807, 0.047479453164019754, 0.03970187104174069, 0.05335825342418892, 0.04124162306210824, 0.025170388831091777, 0.01583413713212524, 0.04202104266732931, 0.0633852741281901, 0.03739823108272893, 0.022753913587491428, 0.04440169635095766, 0.04228527777429138, 0.05301455508119293, 0.010727614896105868, 0.05429393964420472, 0.008814161410555243, 0.02993639844602772, 0.03101076026047979, 0.034170019307306836, 0.02059615696115153, 0.026473632381696786, 0.021409610186570456, 0.09838662096964461, 0.0700951712206006, 0.07170441201222794, 0.02231228058891637, 0.02333335704835398, 0.025893154154930795, 0.0300635728718979, 0.039419926170791895, 0.03549778002447315, 0.020413697198299424, 0.04649626949269857, 0.003512849794268342, 0.031165866580392634, 0.02483929766874228, 0.01190276799856552, 0.02151723941122847, 0.032599706069699357, 0.006988983634593231, 0.029961684053497653, 0.02845957376328962, 0.06370957994035312, 0.016726222388180237, 0.03834570684869375, 0.03551089949905872, 0.00760432838329247, 0.021391766411917548, 0.04161533640165414, 0.06564049382827111, 0.022597848836864744, 0.056895582005381584, 0.04705183360991733, 0.014769301949334996, 0.03235355392098427, 0.018748112555061067, 0.024494506884366274, 0.014173571951687336, 0.05435894669166633, 0.06508594072823014, 0.010022189534668411, 0.0716043755944286, 0.04185555476163115, 0.04527709473456655, 0.027457738860643337, 0.016088716685771942, 0.029365716568593467, 0.04608575580641627, 0.05411317791523678, 0.015440832790253418, 0.06321442579584462, 0.054470667482486794, 0.053910021137978346, 0.09766167415572063, 0.040621740610471795, 0.00793860781206084, 0.04808781748371465, 0.042353555360542874, 0.07459132067326989, 0.010864027576254947, 0.016951384056093435, 0.0669530112562435, 0.008909399737603962, 0.08219479410243885, 0.023675152100622654, 0.019751162035390735, 0.01334137758905334, 0.045138069694595676, 0.009647034308207887, 0.020391320809721947, 0.012699491094930895, 0.0397881637327373, 0.015032039190243398, 0.0688880370663745, 0.05805166997015476, 0.034395462567252774, 0.017407600468556796, 0.008515352399886718, 0.034604034053960016, 0.06924414581486157, 0.05796817623611007, 0.014429109936047877, 0.012362757913901337, 0.025136758939230015, 0.050682416651397943, 0.015392005410311478, 0.035705330315977335, 0.0262528811914048, 0.05692976659962109, 0.057851990684866905, 0.028306945792532394, 0.005107780070310193, 0.01074837552317019, 0.09855078573205642, 0.051361952509198866, 0.05596568708174995, 0.005309810903522053, 0.051463478311364136, 0.04946960655174085, 0.03165391307058079, 0.05960794431822641, 0.03670262073033622, 0.007877919639992927, 0.16892126575112343, 0.12056531836943966, 0.14903656632772513, 0.19444923235901765, 0.13845595265073435, 0.12247110610561711, 0.12082436946885926, 0.14315104857087135, 0.1057129128436957, 0.11291347217879125, 0.20183398681027548, 0.12848208498741898, 0.06734964890139443, 0.10225420950778893, 0.1634410505316087, 0.12648632350776876, 0.1131782161870173, 0.1701968844447817, 0.10775310479636703, 0.18763098679482937, 0.1496337042855365, 0.14942664253924573, 0.11473223779882703, 0.1341942913298096, 0.10822002509874956, 0.17876269694949898, 0.13082768555198396, 0.12049905263951846, 0.15585126993911608, 0.08971070937280144, 0.127996118207063, 0.20171782161508287, 0.10151288285851479, 0.10141717549413443, 0.10261348701481308, 0.1288959506366934, 0.10754098796418735, 0.13765958324074745, 0.12899306256856236, 0.17175352520176343, 0.10432714756046023, 0.08014151999460799, 0.1382360394511904, 0.15934101625212602, 0.13670671651405947, 0.13098518710051263, 0.09466779444898878, 0.13898211584559508, 0.13191855273076467, 0.08659144317997353, 0.1324491264032466, 0.16087359615734645, 0.2062488884798118, 0.09308656358293124, 0.10464978417647736, 0.13632366992533207, 0.20973837694951467, 0.17483140075845377, 0.09645640597279583, 0.1664794489209141, 0.14824592375329562, 0.1772690513836486, 0.1099942856069122, 0.1462480995271887, 0.1896341714475836, 0.1162187180348805, 0.08854196672993046, 0.20547653920948505, 0.17718650081327983, 0.10996421972023589, 0.17166044376790524, 0.12259196676313877, 0.1307467906070607, 0.12460302242210933, 0.13113666325807571, 0.19857061335018703, 0.12946587934025697, 0.1125747271414314, 0.07796116306313447, 0.16629355746720517, 0.20756243728101254, 0.14042894249515875, 0.1741560005715915, 0.14283383344965322, 0.20004899187811784, 0.10873808658548764, 0.06247789638915232, 0.1979241051844188, 0.09350292624107429, 0.11477440196488585, 0.17733113733785494, 0.09876368287950754, 0.10164683245654617, 0.11667809981320586, 0.13866954190390451, 0.07999961118080787, 0.05019019038549491, 0.08844224243823971, 0.08759394474327564, 0.14337690573717865, 0.10201069686029639, 0.1273726938026292, 0.11615121737122536, 0.16509145125746727, 0.1885368853275265, 0.2565211137490613, 0.12346486135252885, 0.07330923554088388, 0.08700924433235611, 0.21414248991225446, 0.12104690181357519, 0.14120596008641378, 0.1743484738149813, 0.13000580322529587, 0.11430644350392477, 0.11554306000471115, 0.20899578822510584, 0.13380515149661473, 0.1078229464058365, 0.12053306081465312, 0.23505405709147453, 0.1819053047469684, 0.1410823581474168, 0.2914397200303418, 0.1259888352027961, 0.12244690954685211, 0.13024749739893846, 0.12540407372372492, 0.15978533455303737, 0.17351435071655683, 0.0897760930071984, 0.12781798919396742, 0.14271618904811995, 0.11668453232518264, 0.13282032577054842, 0.1347393449395895, 0.1649954385523285, 0.18525914049574307, 0.0954819211204137, 0.08176811771201235, 0.21833437069186143, 0.09300062033746924, 0.09200562337147337, 0.2434132014002119, 0.0733011949009129, 0.10306009876408748, 0.15142999004040444, 0.11180580447294883, 0.06716113151716334, 0.09634123822408062, 0.1028430557676724, 0.07229886975671564, 0.13467139644282206, 0.17419493491096155, 0.07396911763186965, 0.06960258872381278, 0.15140348646257604, 0.24928917895470346, 0.14278963367853845, 0.1631131281277963, 0.0805744117658053, 0.1439710445702076, 0.11083118391356298, 0.10922840956066336, 0.13186640052923135, 0.07845000004661934, 0.162417168329869, 0.12039101629384927, 0.20599297221217835, 0.14259298065943377, 0.23457313861165727, 0.10269531155271189, 0.09446434929434742, 0.11245023632155997, 0.15298893781644957, 0.05728917981364897]]}, {\"colorscale\": [[0.0, \"rgb(0, 0, 0)\"], [0.09090909090909091, \"rgb(16, 16, 16)\"], [0.18181818181818182, \"rgb(38, 38, 38)\"], [0.2727272727272727, \"rgb(59, 59, 59)\"], [0.36363636363636365, \"rgb(81, 80, 80)\"], [0.45454545454545453, \"rgb(102, 101, 101)\"], [0.5454545454545454, \"rgb(124, 123, 122)\"], [0.6363636363636364, \"rgb(146, 146, 145)\"], [0.7272727272727273, \"rgb(171, 171, 170)\"], [0.8181818181818182, \"rgb(197, 197, 195)\"], [0.9090909090909091, \"rgb(224, 224, 223)\"], [1.0, \"rgb(254, 254, 253)\"]], \"hoverinfo\": \"skip\", \"showscale\": false, \"type\": \"heatmap\", \"visible\": false, \"xtype\": \"scaled\", \"ytype\": \"scaled\", \"z\": [[0.06687366337116275, 0.01875253321070756, 0.015442825986870697, 0.02097947835656149, 0.012509721813590398, 0.04238609790003725, 0.019677278053547655, 0.01168874278664589, 0.021675290573122244, 0.01493092390176441, 0.045400309908602915, 0.030862527500305856, 0.016413497472448007, 0.04325406632519194, 0.07303992499198232, 0.03647958626970649, 0.018282199877181222, 0.011408162619253355, 0.03219716516988618, 0.03266378352418542, 0.01819582236930728, 0.04732677599947367, 0.023542992138702954, 0.06107571055846555, 0.02734396210871637, 0.02179191547578999, 0.01897074159101716, 0.01847783848643303, 0.017044306034222245, 0.022362928139045835, 0.004896653051088963, 0.05755733006766864, 0.06507327247943197, 0.051211938594600985, 0.04750982778412955, 0.017357768856787255, 0.034974911117127964, 0.023923921698172177, 0.05140289531222411, 0.015816883682938557, 0.05502682192517178, 0.01469378948344716, 0.0611815620213747, 0.015953416803053448, 0.044525471316384416, 0.005915263459818172, 0.01318971483436014, 0.011948373185337653, 0.10534993053546973, 0.04248298252267497, 0.06106638070195913, 0.06893801117049796, 0.08704034837761096, 0.01878883483420525, 0.05249812547117472, 0.03885210771113634, 0.02666076725082738, 0.02158128802797624, 0.026745579039145793, 0.018656727458749498, 0.03762851569003292, 0.020850924808265905, 0.03256197273731232, 0.03948385434757386, 0.08283742783325058, 0.06371264013328723, 0.006841117283329368, 0.04378634990592088, 0.03788710877831493, 0.06799414181815726, 0.029791368371141807, 0.0098098479377638, 0.01649575966543385, 0.010770231136120856, 0.021744723365242993, 0.04073673194008214, 0.030725378609661545, 0.05022921632709248, 0.022701086243614554, 0.033379173172371726, 0.023946152201720645, 0.05689710531649845, 0.033831874773438485, 0.01847442375895168, 0.051684843575848, 0.0384691289759108, 0.033618892809110026, 0.05887371514524732, 0.015565488154866865, 0.018582775623404553, 0.103948328244899, 0.045037985779345036, 0.036764496338686774, 0.050186465228242536, 0.021384263510948846, 0.08934523005570684, 0.030785133796078817, 0.04686903288321836, 0.026337672623672655, 0.008171598077751696, 0.03353052380095635, 0.06348756328225136, 0.029936605399208407, 0.01964847763468112, 0.01588558535357671, 0.08761189877986908, 0.053590288651841025, 0.016477020224556327, 0.06373611065958228, 0.016888833305399333, 0.00966905870674444, 0.027676749608612487, 0.023048996592738798, 0.04370886120679123, 0.02771951088548771, 0.022261202169050063, 0.06669724426631417, 0.010488447417238993, 0.023217805927353244, 0.03816149137648089, 0.019055046174409132, 0.06246993038803339, 0.027790711261332035, 0.028455972438678145, 0.013793217450646418, 0.03443911951035261, 0.03615217276715806, 0.03012698536206569, 0.043524598237127066, 0.03592024610510894, 0.023865431979564682, 0.013679248164407909, 0.011501434042916765, 0.023861701733299663, 0.021901297017133663, 0.11846099128680569, 0.03715513234159776, 0.04386873762788517, 0.059700096159109046, 0.060773362139506, 0.03477008853639875, 0.06735144023384367, 0.007386923218811197, 0.012103162290129279, 0.019550721094544445, 0.05457321447985513, 0.052907930088362524, 0.042374847789428065, 0.01763207681610116, 0.04863203310274652, 0.04692904930561781, 0.02820217320030289, 0.09772795345634222, 0.004281406265883041, 0.06824786641768046, 0.020843835813658576, 0.014349071641585656, 0.06482904737016984, 0.01943016577778118, 0.02474514754222972, 0.02995703269594482, 0.018804453013996993, 0.06861399034304277, 0.02500213250251753, 0.08110449010772364, 0.05132026331765311, 0.044610647817275355, 0.06305461044290236, 0.012377550825476646, 0.01957404234313539, 0.06388513052037784, 0.06989236388887678, 0.007839069269331438, 0.020996358611487916, 0.029718765124146427, 0.02021880497756813, 0.035541362328720946, 0.007416299544274807, 0.06857114764196531, 0.05951119879526751, 0.03794770874083042, 0.04147326473944953, 0.024158067169732282, 0.012850688204967549, 0.04596210636996797, 0.09336268662342004, 0.04179676648761545, 0.07934741689158337, 0.044961491134017706, 0.02283561259641179, 0.03291014262608119, 0.04635854723996349, 0.031449857234422646, 0.02310390703912292, 0.038216920902154276, 0.0239716786891222, 0.06092215808374541, 0.02496951023515846, 0.0636440741696528, 0.06856216383831841, 0.04817316701103534, 0.016209227897758995, 0.008543395404038685, 0.014617579822827662, 0.05749852143760238, 0.022133454381089126, 0.036787807409252436, 0.04881707978035722, 0.0809043019211718, 0.01186655119194516, 0.04543908818491867, 0.03269520987357412, 0.03533079594905887, 0.10271034110337496, 0.006817719699548823, 0.040929595341107676, 0.06024786390896354, 0.04455154063180089, 0.023126010317355394, 0.06515908680324044, 0.018544826856149093, 0.04109422829268234, 0.026034650758707097, 0.03957861176292811, 0.03766304972980704, 0.0910213269027216, 0.022966588514723947, 0.11567894342754569, 0.012386310712567397, 0.047054116880255084, 0.0014938367218876789, 0.036234119441360235, 0.03531744916524206, 0.023972453915381005, 0.010427291904176985, 0.0211138910547431, 0.039809347596019506, 0.06432117747941188, 0.055715131240763834, 0.036015485280326436, 0.03530671134857195, 0.06243640397276197, 0.031965665984898806, 0.06825245331440653, 0.032484422970030985, 0.012295814497130257, 0.030663564069462673, 0.0055362024161565515, 0.022824348915102224, 0.01530944466191743, 0.03893254803759711, 0.03051894111558795, 0.02932341330285583, 0.04971152124926448, 0.01950009390046554, 0.029394964820572307, 0.029223885786320482, 0.06749423792851822, 0.028688755751188313, 0.013254563274261142, 0.024666222045198083, 0.014151889365166426, 0.02578146898719881, 0.026696454800133194, 0.021877271788460866, 0.02924104254426701, 0.09642592617975813, 0.07621666988623993, 0.025446683201672773, 0.008678445076969053, 0.004369221419827747, 0.05285764725080558, 0.010669318559978689, 0.06116240019244807, 0.025821187034515396, 0.014773344321708595, 0.03698814148083329, 0.08602494107825415, 0.03928999350007091, 0.033328717308385034, 0.012943375240346151, 0.058669774660042355, 0.014094612527904766, 0.037644295021891594, 0.06409335256155048, 0.06283386264528547, 0.006222860771231353, 0.05966234925602164, 0.07895513544125216, 0.035223027624722035, 0.02451041853055358, 0.04283176648563572, 0.05661879060789943, 0.042809513929699144, 0.03846134278657181, 0.03473533736541867, 0.030863942245819738, 0.03772405681333371, 0.03632027981802821, 0.06797478999942541, 0.016231095385072485, 0.027125880953722765, 0.03548296421234097, 0.02799342868716589, 0.030555894132703543, 0.04985909243779523, 0.03129227426169174, 0.05946700580950294, 0.014243291424853461, 0.019851832883432508, 0.03526601281815341, 0.0652743224054575, 0.0276257373459105, 0.0553145784485553, 0.04642969163666878, 0.04601612115012748, 0.01768282105747078, 0.053775532104607136, 0.019668075422357236, 0.02741092672970678, 0.02367985265196434, 0.0207745438175542, 0.019737089219103967, 0.033332907262125185, 0.04107118185077395, 0.018744577387613908, 0.024796919764152596, 0.019950215372123888, 0.035552246030420065, 0.0136423782678321, 0.019606863081987416, 0.021668986982799003, 0.04471156633059893, 0.044231424773378034, 0.05745996029249259, 0.04284261626058391, 0.03268531344032713, 0.03273109759071043, 0.08234190049448184, 0.04174743699175971, 0.015394884095128094, 0.04068226932681032, 0.04773116251453757, 0.021846647806731716, 0.021319020672568252, 0.004404378439565855, 0.03489932570872562, 0.03023504206378545, 0.009444176934526434, 0.021010436516787325, 0.029194528968738656, 0.0667177088824766, 0.2640075534582138, 0.11286300952945437, 0.1804803812078067, 0.20962226603712353, 0.11468102197561945, 0.09305940861148493, 0.1205652505159378, 0.12126137316226959, 0.1146128699183464, 0.134143876177924, 0.18140069182429994, 0.25324384389179094, 0.16786277826343263, 0.1083725258441908, 0.11712665217263357, 0.18326431539441856, 0.12256266762103353, 0.0834419143253139, 0.20120142932449067, 0.13077926529305323, 0.12186324729451112, 0.2235896922647953, 0.1897695798959051, 0.12124744962368693, 0.17928089414324078, 0.0785540466063789, 0.15854155272245407, 0.14428323853228772, 0.13899051610912594, 0.14953503172312463, 0.12858089325683458, 0.1290050319262913, 0.15422731850828442, 0.08193669295204536, 0.13470403397721903, 0.10926129136766706, 0.11781358745481287, 0.16762029698916844, 0.17018236379538262, 0.14897313687418187, 0.16147039484764847, 0.10907402248787028, 0.09903643360095364, 0.14981479171131337, 0.1313989713255848, 0.13344478154821054, 0.09413851677839245, 0.13814043386706285, 0.14263756041015896, 0.17180392678294862, 0.11394851628158774, 0.2525744012423924, 0.16766402178577014, 0.12986018961029394, 0.1024857120854514, 0.21585789429289953, 0.12895467105720723, 0.12219521376703467, 0.07523641070084912, 0.07937934196421079, 0.1127484253208552, 0.15135088642793043, 0.141758301162294, 0.11347778939775058, 0.18596473549093517, 0.1757591888308525, 0.11148427386901208, 0.21468147741896765, 0.26655594099845203, 0.16452553948121412, 0.15150941934968742, 0.09744940804583685, 0.11096449568867683, 0.15847758044089588, 0.07043533439614943, 0.07739318854042462, 0.11387433883334909, 0.18480005727282592, 0.15212494560650416, 0.10241613510463919, 0.12809464149177074, 0.1980795439864908, 0.09418893871562821, 0.12151399174971239, 0.1427320260554552, 0.09723463135638408, 0.08299921093774693, 0.12221289638962064, 0.13239682492400917, 0.12021676850106035, 0.15432103776506015, 0.09472338003771645, 0.1550520235406501, 0.12417336047760077, 0.12738521955907345, 0.1754945194614785, 0.08144375083169766, 0.1520716127540384, 0.1388000784707921, 0.13567140778260572, 0.09361505415290594, 0.18641730477767332, 0.10452157498470374, 0.09094600273030144, 0.14633910464388983, 0.17235207451241358, 0.13038139949951852, 0.11132810903447014, 0.19638266361185483, 0.16362311504781246, 0.12373923377266952, 0.15443143541259424, 0.1517766671521323, 0.093485596456698, 0.14320071733423642, 0.08681740891188383, 0.11782649319086756, 0.20961583352514676, 0.13667075415807112, 0.13863869570195675, 0.10034232852714402, 0.10798630371157612, 0.14854887606842176, 0.12618898946259702, 0.056132945963846784, 0.17650481739214488, 0.13604324497282505, 0.1225877869874239, 0.08071753515728883, 0.17996166832745075, 0.07603470715028898, 0.07175916978823287, 0.06258940004876681, 0.11088101552533251, 0.08209312920059476, 0.19022453762590885, 0.1733057147690228, 0.21627436551664556, 0.12296710163354874, 0.15375899363841328, 0.12198853200035435, 0.17887693510523864, 0.14399205201438495, 0.10990140773355961, 0.04275075279708419, 0.18773219707821096, 0.1308847910591534, 0.14070535052035535, 0.2313365808555058, 0.15405328784670147, 0.17299409077635833, 0.11476285329886846, 0.15090329758822918, 0.04435335073087897, 0.16750867797860078, 0.10245432305548872, 0.1438159178942442, 0.17640737976346696, 0.09465750107275588, 0.10289419695202794, 0.1613870028938566, 0.10951667159263577, 0.14436129720083304, 0.12761566362210683, 0.13538730517029762, 0.14398754654186113, 0.139724053176386, 0.13571194346461976, 0.09332489222288132, 0.0661997627466917, 0.17659363762608596, 0.16988207133752958, 0.0859960015597088, 0.09491799066641501, 0.08004364810351815, 0.23493686052305357], [0.025675166298502257, 0.08320064762873308, 0.015641502736668502, 0.017714834339650612, 0.04775344899722508, 0.03563138696232012, 0.04768895763637764, 0.023910412065950886, 0.03039896594626563, 0.038458862741078646, 0.03512542036228946, 0.011516120085226638, 0.03611477870228035, 0.03947537265984075, 0.02147909895783024, 0.04277186541418944, 0.056327939964830875, 0.04647669375741056, 0.019848119600542953, 0.0473577375523746, 0.013834684421973569, 0.038789682489420683, 0.01855276062685464, 0.03913083293342164, 0.061081851300384314, 0.030319268615650277, 0.03795797836833766, 0.012715209358637887, 0.03316761273890734, 0.03272903145157865, 0.008532648257512068, 0.031013912055641413, 0.021491746850577847, 0.03935775539970823, 0.12139779941311904, 0.011737650742621293, 0.03753286260845406, 0.007515684568456241, 0.05666149081662297, 0.06696147937327623, 0.0291049453829016, 0.02140251610295049, 0.009684000896023852, 0.03280322586319276, 0.04893755367291825, 0.01731457671017519, 0.057549581197755675, 0.014677606423252394, 0.03342219568522913, 0.008106079584519778, 0.023570036848208735, 0.0985673080597605, 0.03849244343915156, 0.05902637195374284, 0.04338942388338702, 0.043568431599331756, 0.051804781425744295, 0.02707269398628601, 0.023400218192754046, 0.039090711157768965, 0.06837017235479184, 0.0050311425085445595, 0.1029047074594668, 0.02973312631781612, 0.04228001234254666, 0.0461607441040022, 0.02804160806616502, 0.045529190850045, 0.06608591135591269, 0.03778366272204688, 0.002722122402961499, 0.005944143606549395, 0.022473575148199285, 0.0507590503964041, 0.022406306882788028, 0.011760653079753476, 0.03868826864553349, 0.018445255234837532, 0.034293353224971464, 0.0551072385029069, 0.01586642861366272, 0.03461614929671798, 0.022003684558772614, 0.04284793597513011, 0.04028839671186038, 0.027086322362135564, 0.006214739555226905, 0.07711152186883347, 0.0427618943420904, 0.01908456753673298, 0.029412084259092808, 0.006887711010806794, 0.04544172429346612, 0.024656412125165974, 0.04022374589528356, 0.03822369946699057, 0.02400710160977074, 0.01528898174209254, 0.034170575706022124, 0.05026907686676298, 0.08873329324913876, 0.0067611154601243985, 0.033918625475572686, 0.014255852804386189, 0.012920552714993911, 0.05047320055642298, 0.014535139514399427, 0.027496966666408947, 0.05834213045558759, 0.01335782018889274, 0.04410459300769227, 0.04622842797211238, 0.013489041227980383, 0.0282008381826537, 0.05419068357774189, 0.04986685148573347, 0.008097414692331637, 0.03232397997219648, 0.015559740963258913, 0.014084065549208649, 0.021383011613839438, 0.024438624436567937, 0.06422080857945339, 0.04143777396529913, 0.030998655195747103, 0.04568168141746095, 0.021463126243491257, 0.040477918327919075, 0.022064058908394406, 0.015136034859876548, 0.06421876618904726, 0.015184750281540411, 0.03172262152656913, 0.004779241471883974, 0.04262301857982363, 0.004057011342540915, 0.02155638240011675, 0.027795778221583793, 0.022209160229457275, 0.006439187913201749, 0.020520457898133566, 0.019841215506728207, 0.01756845398007759, 0.07956893143377133, 0.013156671027120734, 0.05356447717973164, 0.11442377577934947, 0.026002471235447695, 0.0506923266553453, 0.058780728706291745, 0.034088880089776855, 0.015784887364134192, 0.04056451975234917, 0.025797400989436677, 0.024345310604465858, 0.06546056669737611, 0.018680433775963526, 0.06812971990023341, 0.030461852571793964, 0.06206122839025088, 0.0352829388741936, 0.06943304996405329, 0.02567211289091834, 0.04173074842297605, 0.03714761417359114, 0.05299895216843911, 0.03270313176991684, 0.02207936835475266, 0.05007531440683773, 0.02266370235676212, 0.02292987977021507, 0.028827078507414887, 0.015481763718915837, 0.01930087771532791, 0.022135883536455885, 0.07192704613719668, 0.015681566836844598, 0.023323550520996963, 0.03332876480583634, 0.03404786943324974, 0.04398949311247893, 0.08158704385693584, 0.025196546356060674, 0.017022061959973404, 0.01544075645506382, 0.02598284461003329, 0.025405943959153125, 0.023970248676570396, 0.018957499980128238, 0.06342905999294349, 0.07652338807071958, 0.0542573530359992, 0.024621418377916728, 0.08222327221717153, 0.040710805117019584, 0.033232073565678935, 0.010271530797971147, 0.04386358754709363, 0.0330009068628507, 0.0381195646976786, 0.02244306482108576, 0.02494468603150121, 0.012932530554410602, 0.06732567625918559, 0.05405209280018296, 0.0056212724718664375, 0.031100642401725054, 0.04726254248193332, 0.01698413015609341, 0.028385377655337964, 0.02604163288404899, 0.03345060933913503, 0.010584698457803045, 0.024828352898891484, 0.0355935450643301, 0.052589527530861754, 0.05448913381301931, 0.025007260530920963, 0.028403504718361155, 0.017293718543701937, 0.025495958414727023, 0.03557323990389705, 0.0450198824650475, 0.059496366019759855, 0.0714635117245572, 0.03611292290900435, 0.04351446770929864, 0.09944570556815181, 0.03971881406115634, 0.03854724871260779, 0.026955210736819675, 0.025379537072564875, 0.03924447737101998, 0.020349019240321856, 0.027518228561218296, 0.03008303325623274, 0.03887917108035513, 0.03629289075200047, 0.03230895381420851, 0.021506423563031212, 0.06145318637468985, 0.023987442753942947, 0.06488793063908815, 0.010649811526361321, 0.08683688286691904, 0.08795804663428239, 0.04062425797539098, 0.027058242886726345, 0.019865257698776465, 0.16806196900350706, 0.023833953043712035, 0.01591173778953297, 0.02406181358466191, 0.015582264933202947, 0.07376151305756398, 0.014710986953494804, 0.049016731924244335, 0.033705056578453095, 0.008810248808003962, 0.037850383070430586, 0.008100690320134163, 0.05807668755629233, 0.04897925643516438, 0.05237465923918145, 0.056239465783749304, 0.027575848058664372, 0.015519184925194298, 0.009663236876284438, 0.026672220921942165, 0.030597586716924394, 0.030823131757123128, 0.04649447137489915, 0.03668037835242493, 0.07132225430437497, 0.005289770371746272, 0.03157736753512706, 0.0666543540677854, 0.038758371490985155, 0.02076188744311886, 0.034000843563782315, 0.016283914247261624, 0.08901694802833454, 0.021899286857140914, 0.11515693286699907, 0.08862615256969418, 0.05223907097908003, 0.03147305973938533, 0.07842707234833922, 0.06307299195655755, 0.030926004451300417, 0.03138861605631454, 0.001953463090883036, 0.02328758986134614, 0.0188777704190995, 0.04244954092428088, 0.028808344155550003, 0.05317010923421808, 0.04752176660778267, 0.043506745980786424, 0.03363630062501345, 0.03955119555549962, 0.07252534438988992, 0.021745776790859442, 0.04032851170216288, 0.006999142151991171, 0.04655978376311915, 0.0802760599181056, 0.04792436857574752, 0.016094131395220757, 0.005762821238022298, 0.032462370581924915, 0.020205388643911908, 0.009711642716346043, 0.045529038179665804, 0.00833666359540075, 0.049550481140613556, 0.06329607391463858, 0.011743565023477589, 0.0048551750535677585, 0.026724580076656172, 0.012171850390067058, 0.03822275969598975, 0.055672705838722844, 0.04336800592552338, 0.01949841113361929, 0.036065975071064064, 0.03997686092874833, 0.02160158470672156, 0.023424621704699736, 0.033935012096273046, 0.00698196843066918, 0.04209016502967902, 0.028253409379561032, 0.051538493750350814, 0.037908360495099, 0.058313693052956035, 0.02449421850698335, 0.0747634582221508, 0.012318562383630445, 0.06020181852259806, 0.006114606022103024, 0.017742053771923696, 0.07731667693172183, 0.03682057386530297, 0.0697713607390012, 0.06337043456733227, 0.026766004639544656, 0.05114643621657576, 0.0351602936695729, 0.08037388431174414, 0.028616501949727535, 0.0298141637550933, 0.07909112742968968, 0.07246483263692685, 0.05796628312340804, 0.09742321659411703, 0.16970487870275974, 0.15185838990977832, 0.15224917179771832, 0.1404081250407866, 0.10153568163514137, 0.12028736328440053, 0.12618517609579222, 0.08603534302009003, 0.12570960447192192, 0.08914567290672235, 0.14773399622312613, 0.14655679224857263, 0.16276012706969464, 0.17921260637896402, 0.17313925655824797, 0.06759655422398023, 0.0965557231434754, 0.08853273865367685, 0.07384264548974377, 0.10336906968482903, 0.10022701150072472, 0.12428957995559488, 0.14383145634617123, 0.13867788788463387, 0.12917064875364304, 0.06986227764614991, 0.15608697943389416, 0.11890883796981402, 0.09418139340622084, 0.24005287885665894, 0.19367418251931667, 0.20910362101026944, 0.04964741326070257, 0.11438452931387083, 0.07626561940248523, 0.14224763347634248, 0.19198963791131973, 0.07701187221599476, 0.09608297422528267, 0.12491034450275557, 0.15793059979166302, 0.22282558040959494, 0.13123932560639723, 0.1226203159562179, 0.09420202087078776, 0.08938464615494013, 0.2705609532339232, 0.23443593883088656, 0.08530553111008235, 0.16391249666256563, 0.18466842147920812, 0.10937489170048918, 0.1739748724337135, 0.08831922403935875, 0.12105025377656732, 0.09617722273937293, 0.12410368850188595, 0.09353925500597272, 0.14934067215238297, 0.14943722768553666, 0.12411652638443879, 0.08328701835125685, 0.12582560681871005, 0.18472448204244885, 0.1561669244297913, 0.17441554021622452, 0.10768282213913542, 0.06515419456575598, 0.07983430647956473, 0.21845612701560768, 0.06094308410372053, 0.08839996970657792, 0.10339241128947053, 0.0896796053275466, 0.15032608141856535, 0.10881500531520162, 0.11393532556082521, 0.17923256887921266, 0.05920206502612148, 0.14635705868048327, 0.11097368305282933, 0.10177318246236869, 0.14372974394687585, 0.19276071153581142, 0.09555425295340163, 0.04592387431434222, 0.09557742492428847, 0.049924184302134175, 0.15458871982991695, 0.10313840849058968, 0.12307515154991831, 0.13118317004825386, 0.12416022403963975, 0.20085950195789337, 0.1580691295010703, 0.11609886160918645, 0.14299596260700906, 0.09945026532347713, 0.14763225668243, 0.05919514396893127, 0.12063347042671271, 0.12107685234929834, 0.08962070170257773, 0.13832271551447256, 0.1672997163342578, 0.20062390102871827, 0.16034258822245256, 0.19586480568562234, 0.1271706667861768, 0.09723222934241806, 0.20647041659270013, 0.15754197564508232, 0.09367889751281057, 0.20286177737372263, 0.10684324361916099, 0.21607100857155664, 0.10879728876586471, 0.1608908309468201, 0.15884770772286824, 0.16395703570118972, 0.13465623797050544, 0.11925171528543745, 0.0790552736393043, 0.11358121170529298, 0.15371016625847134, 0.09708187955298594, 0.15179846169693129, 0.12621467879840306, 0.10210671635078532, 0.06152986083179712, 0.13897946955902235, 0.09214031935802527, 0.08993071078189782, 0.1256670874676534, 0.09364176129123994, 0.16806844222758496, 0.121448228135705, 0.09815847714032445, 0.13892901369503566, 0.19516387901135854, 0.13336086033710412, 0.15194773940103395, 0.1453756663416113, 0.06348725794149296, 0.1343370686684336, 0.08505606092512608, 0.1318714895418712, 0.13278065861335822, 0.13005076295563153, 0.13880089271281446, 0.11928237149757998, 0.1333736167954547, 0.11390002816915512, 0.18356824479997158, 0.13975335231849126, 0.1408730572355645, 0.10958822989570242, 0.20765584441167967, 0.13722978558923515, 0.09416244192314999, 0.10843880514481238, 0.07659469531582934, 0.1966440353010382, 0.1540772808449609, 0.12665487160640104, 0.11063926706888846, 0.11559612144316946, 0.10763638320245913, 0.12110208028129169, 0.0931099798264248, 0.11274691897311381, 0.17241919519645826], [0.12648506143263408, 0.01922997928756688, 0.038251641539058516, 0.005388868714882327, 0.04345115360670856, 0.05532050545194319, 0.06150710276727166, 0.06817877798208169, 0.01785286532581917, 0.04200014378875494, 0.06273563113063574, 0.0659868520285402, 0.044256289689136405, 0.0404441171059651, 0.07552182967109339, 0.03614036625783358, 0.022227507816361528, 0.005061159625516406, 0.023816587636247277, 0.024175999153937613, 0.012799597062569643, 0.02440524390632553, 0.013285890387903367, 0.023503433547115753, 0.034487879036792686, 0.045532776907618554, 0.016995358214314495, 0.019475666639794196, 0.06941084151289292, 0.03841073764488101, 0.0549361458979547, 0.026590576195823293, 0.03275943660576429, 0.0496454455091485, 0.008366004297775882, 0.008901868847065737, 0.1207406111061573, 0.03274734850440707, 0.04229043124775801, 0.03740265852372561, 0.05035238739635263, 0.03169925617320197, 0.03903902714539852, 0.03311463272465127, 0.04570593565170254, 0.050343362880604606, 0.031286055488245826, 0.07339600659906864, 0.07382053881883621, 0.011112895561382174, 0.059785862985466204, 0.0465769303430404, 0.05439283273049763, 0.05317991067256246, 0.034555281312870126, 0.017174162369753634, 0.05215230670624545, 0.029467045595603328, 0.026993454666808248, 0.03301260819924729, 0.005874260860894407, 0.03997069304542882, 0.06590822339057922, 0.022670504670324068, 0.03052089868911675, 0.046463859267532825, 0.031989387569150755, 0.010330797439174992, 0.034122535426701815, 0.01965831808878907, 0.059370728475706916, 0.061941114121249745, 0.02344556468805032, 0.02431852713094226, 0.026847082788922956, 0.024575116844581704, 0.022960357866915207, 0.0174228607211262, 0.04553893461291279, 0.05767127645335027, 0.03665605965735657, 0.02646671132450657, 0.04744359598095928, 0.01977009485874857, 0.12281460767345768, 0.06159418595156499, 0.04437380177634103, 0.11380059564752237, 0.024626373379890407, 0.07345311210623809, 0.010963119134040815, 0.05321504521582808, 0.06244699590440307, 0.019060949429071376, 0.05494059708767703, 0.0032374052887982024, 0.07567177233951432, 0.058938338820423396, 0.04025604755484632, 0.06788169499486685, 0.037476544201906235, 0.01825246647266405, 0.011628803547604807, 0.05068081191607884, 0.07454333467675106, 0.022543367563879917, 0.04049267985724977, 0.036788737002227984, 0.02344164445198008, 0.010498426122856992, 0.016952203387128453, 0.023495837347581983, 0.11175433759178434, 0.0763221142281379, 0.0028510996115593506, 0.05186614813283086, 0.04777981686804976, 0.06431777123361826, 0.03772455553657242, 0.011207315405564649, 0.029767819813319614, 0.03705263284168073, 0.027929968699546795, 0.051079580161188326, 0.0791172238865069, 0.10098792745598725, 0.053229888169361014, 0.10230816661247186, 0.04455651768616267, 0.04998901153781584, 0.01899042080289551, 0.03120178822427988, 0.015082444164103695, 0.0592960353408541, 0.0713847405942423, 0.08125320462776081, 0.021269865899479816, 0.023385134359289492, 0.01687132370924311, 0.020358201515461718, 0.029843289870768785, 0.020043379926521863, 0.02010934370835977, 0.05462054908275604, 0.05232530938727515, 0.009902993832448763, 0.05519886787182518, 0.03777163229616625, 0.06050259952566453, 0.07142466559473958, 0.03987241403332778, 0.0903073927121503, 0.021220471942797303, 0.028610663155892065, 0.028937394730746746, 0.00841192330699414, 0.04049771797976323, 0.013979879889770277, 0.03549205997426595, 0.02924411970057658, 0.03109213017991611, 0.03361230084140386, 0.022232349163719585, 0.04983719611274345, 0.040753196592309644, 0.03863157704472542, 0.042402437023286305, 0.014919448178261518, 0.02748513810469636, 0.011052304080554416, 0.032965792675635645, 0.06391865015029907, 0.030222889501601458, 0.024156864466411725, 0.016550680289843252, 0.03017021482810378, 0.08887229114770889, 0.030363549810967276, 0.01673161843791604, 0.02378174995205232, 0.024781946192628572, 0.011977696076168545, 0.00893516540859959, 0.007134518369899264, 0.03147260851359793, 0.03486325478713427, 0.029028138611465693, 0.03290186110617859, 0.03360269617821489, 0.024507636536977122, 0.06040463942502226, 0.05280900646799377, 0.029577039514801333, 0.06237889812993152, 0.05702628142067364, 0.03448646089860371, 0.07413572512034859, 0.022423010718609606, 0.023301828918712478, 0.023216967936605215, 0.031227016156273227, 0.030485217925161123, 0.04233556739719851, 0.016657826058300476, 0.06806875352880784, 0.07300111957426582, 0.044945284325097284, 0.025885875170518245, 0.046230260016662736, 0.029954759603632346, 0.011501959059387445, 0.026332481830779995, 0.023089849489874074, 0.031057582569441626, 0.060649692347007136, 0.05162895264636193, 0.015945518655436378, 0.03332349258874144, 0.05170207157997148, 0.03226722051788654, 0.045060692953744104, 0.02140151017478534, 0.06566558605326073, 0.06126482505351305, 0.01709531999326178, 0.037982191890478134, 0.06742420632924352, 0.06394516051347766, 0.018397795102958168, 0.014796857256442308, 0.024984568623559814, 0.05533866644171732, 0.056438927937831194, 0.03581321399126734, 0.07352919623787914, 0.026009053025128584, 0.09346790704876184, 0.04548134056052991, 0.03580656434808459, 0.022151031830747212, 0.021252916094713976, 0.032745998219719956, 0.01697283424437046, 0.02648721495643258, 0.022893198167106936, 0.008900729756403183, 0.04493272464190211, 0.03971579797299845, 0.06981665295149599, 0.011014105103510832, 0.0277478040994278, 0.03524677974304982, 0.04612828638138516, 0.06611854210495949, 0.05467511347628065, 0.03961537139756339, 0.06676798154200826, 0.044780939750905545, 0.04416620059471045, 0.0038805994471268995, 0.03415894561580249, 0.042302437924913, 0.035532436200550625, 0.009021039104222186, 0.07862702304763453, 0.03606386482715607, 0.05219303237806473, 0.04711441828736237, 0.02741003275981971, 0.02843043238057622, 0.033368842476712804, 0.03920893231406808, 0.0090445774840191, 0.09005083183624915, 0.03193602757528424, 0.012013840788443173, 0.04050898505374789, 0.08664208224841527, 0.020045771762462597, 0.07394453430814402, 0.048841758098985465, 0.030961834492960146, 0.016858499397390654, 0.009268998700593199, 0.0045958822260477716, 0.06150168805782284, 0.0482536616202976, 0.0059229758584738845, 0.05439687340653368, 0.05198799605880465, 0.07993565246995006, 0.005812136315008891, 0.05878735799342394, 0.02701904731137412, 0.04493525218484657, 0.027888888493180275, 0.033831986731716564, 0.030137580686381886, 0.05393476391743336, 0.06565964887184755, 0.04305876698344946, 0.03071306659174817, 0.02416428763951574, 0.03997606025742633, 0.008118391602433153, 0.017558801819437315, 0.009128448653167911, 0.023102941823058894, 0.03758958813601306, 0.01589883374981582, 0.015418332569035036, 0.024952107508267676, 0.03405272774398327, 0.048611473491681476, 0.017505808234480873, 0.03507399080055101, 0.02968839728938682, 0.025525245682469437, 0.02931262120338423, 0.0225488976242819, 0.05243153065176947, 0.057546439580619335, 0.0762131754308939, 0.02206114460048931, 0.057347520254552364, 0.022576600512755767, 0.028172646748966405, 0.03884395172021218, 0.04959853159795914, 0.03323644333119903, 0.0014911916015470134, 0.016575804745246257, 0.046940211206674576, 0.07323786722762243, 0.014473114628344774, 0.06069801761103528, 0.029823880376560346, 0.011641781378005232, 0.02950893834765468, 0.039460821476365836, 0.02559392699705703, 0.015003047085234096, 0.07349073008767196, 0.03289579839578696, 0.032859771578971825, 0.012713987147435546, 0.030826337835086242, 0.006634060626051256, 0.03709133987181953, 0.03208884383950915, 0.046151665305452685, 0.062164989965302606, 0.1335363702050277, 0.1644618386136634, 0.06557067936020237, 0.14469358937016555, 0.10635498339044196, 0.11554806759314877, 0.12510820531419345, 0.1709179636090994, 0.11488410750670092, 0.1688392444380692, 0.2395662878240858, 0.1847173845661538, 0.09774190413632564, 0.10503668484411069, 0.16654472398970807, 0.0955448823847941, 0.07228124141693115, 0.1830522053475891, 0.17224785153354916, 0.12675775108592852, 0.14492639473506383, 0.10667857674083539, 0.1682065783866814, 0.07971843305443015, 0.09224385023117065, 0.12972111707287176, 0.13743505600307668, 0.0832801583622183, 0.1375260204076767, 0.15382037391620024, 0.16157628702265875, 0.11496405250259809, 0.10445431180830513, 0.11371731904468366, 0.14980991982987948, 0.08940595215452568, 0.21997962812227861, 0.1079172288466777, 0.09129773492791823, 0.15132694771247251, 0.10555513309580938, 0.14915779339415686, 0.12195660014237676, 0.1292494809521096, 0.10150529005165611, 0.21654301110122884, 0.1520830528544528, 0.1166467514953443, 0.1937117733593498, 0.13108955935708114, 0.14466733006494387, 0.1502606435013669, 0.1442023300166641, 0.1471773125231266, 0.1276655359459775, 0.1321137129728283, 0.1610348160777773, 0.06989374810031482, 0.1119806222351534, 0.10068311595491, 0.08220763198499169, 0.11398154736629554, 0.13006220305604593, 0.09367226144032818, 0.15125213244131633, 0.09474427891629082, 0.08090757245996169, 0.1387208934341158, 0.16122753359377384, 0.0566411924415401, 0.18775922991335392, 0.117401051734175, 0.1615312322974205, 0.079617894520717, 0.10627007830355849, 0.18478834575840405, 0.18954955813075813, 0.13335853974734033, 0.13386604322918824, 0.10956059994974307, 0.14216424152255058, 0.13044125985886368, 0.13932994646685465, 0.17143175032521996, 0.17685524001717567, 0.16182144172489643, 0.08519456349313259, 0.2289987291608538, 0.14598234450178488, 0.13938634629760469, 0.10307466012558766, 0.13652892676847322, 0.09078350037868534, 0.07521836166935307, 0.1369571095066411, 0.12449964082666806, 0.10415133913712842, 0.23019463356052125, 0.13283867335745267, 0.1496792339852878, 0.12228704669645854, 0.11176659871957131, 0.146671166111316, 0.12824580552322523, 0.1589851789176464, 0.07232595687466008, 0.16661689297429153, 0.1472560361559902, 0.09954388958535024, 0.10993383492210082, 0.20179691165685654, 0.06623847995485578, 0.2652990498713085, 0.14352596631007536, 0.130980288077678, 0.06939973389463765, 0.17758119106292725, 0.10704680412475552, 0.16109379434159823, 0.11692032324416296, 0.06478879667286362, 0.11794773382799965, 0.0798237824014255, 0.19156359934381076, 0.17073136647897108, 0.19245469224240097, 0.1491970805717366, 0.21791726164519787, 0.07877775960202728, 0.19254792295396328, 0.10848843319607632, 0.16328711807727814, 0.1655305584094354, 0.13466881800975117, 0.17836283626300947, 0.1441668833472899, 0.08778554946184158, 0.16533370182982512, 0.07454641522573573, 0.11358043139002152, 0.14356190152466297, 0.08115696800606591, 0.1270812630121197, 0.09273740303303514, 0.1371653519038643, 0.10053885940994535, 0.18308241372661932, 0.13625398437891686, 0.13709420072180883, 0.15645777168018477, 0.10777456685900688, 0.1326996008200305, 0.11162035406700202, 0.21704858754362377, 0.08556284515985421, 0.08943333104252815, 0.10398046366338219, 0.2544864857835429, 0.11844283368970666, 0.14821502326854638, 0.07863395089017493, 0.10105002698089395, 0.1018432072762932, 0.1953096283333642, 0.1382715811154672, 0.1576637319688286, 0.10421954547720295, 0.08152407580720526, 0.10300777692879949, 0.12709823995828629, 0.08599462413362094, 0.12528127245604992, 0.10849800053983927, 0.10121169473443713, 0.13336380517908505, 0.18317535945347377], [0.024271068695400442, 0.04330899373495153, 0.03765693612928901, 0.021225372661969492, 0.02790740571383919, 0.04076308963288154, 0.03854329285344907, 0.018533128912427595, 0.027503243115331446, 0.006714446245626147, 0.01805699410449181, 0.04803299863955804, 0.026958657694714408, 0.06081346355910812, 0.08300753656242575, 0.00180802568294374, 0.021124924034146324, 0.04208890295454434, 0.03474007693252393, 0.01272425677494279, 0.05706201986010585, 0.05870798296694245, 0.049408694463116784, 0.03706431382202676, 0.01898125040211848, 0.020578226673283746, 0.046359877168600044, 0.0245788606615471, 0.09805656118052346, 0.0408031706964331, 0.05067943448999098, 0.12272239476442337, 0.0375084896305842, 0.004706883769748467, 0.08494598218905074, 0.11617426042045866, 0.04389452195859381, 0.061099662844623835, 0.032306857141000886, 0.05196419983570065, 0.03868661641276308, 0.022946232464164495, 0.03765824230919991, 0.033883962514145036, 0.024213274475187063, 0.05132329636918647, 0.04631827279393162, 0.013909319881349802, 0.015489756861435515, 0.05829509440809488, 0.03219750104472041, 0.055143187288194895, 0.05301005978669439, 0.08062152245215007, 0.035036830830254724, 0.049634310749492476, 0.03998991594250713, 0.02973095161308135, 0.04817465639540127, 0.028991840380643095, 0.03000682359561324, 0.0193568602470415, 0.013357928754495723, 0.07716772492442812, 0.017804473904626708, 0.027034170160602247, 0.08558904339692422, 0.058630039649350305, 0.038453532848507166, 0.03160007131685104, 0.06463753764650651, 0.028097046073526144, 0.04955443021442209, 0.0292648421600461, 0.06291082208710057, 0.022594518926260725, 0.06955590551452977, 0.04100835629339729, 0.024664563027077487, 0.01796189063627805, 0.03758858051151037, 0.07238648219832353, 0.019506721491260186, 0.026055166264995933, 0.022092881379649043, 0.011002821066150708, 0.08473367536706583, 0.02673506174635674, 0.045407047761338096, 0.04152893853772964, 0.017322997329756618, 0.03503410990482994, 0.07156542768435818, 0.03521288352619324, 0.009415732746544694, 0.008954999835363455, 0.013745900659289743, 0.11097812745720148, 0.007320023058647556, 0.023201159767008254, 0.10124486831149884, 0.015782275004312396, 0.0021748241145230296, 0.04900220788217016, 0.01599837653338909, 0.02312744881159493, 0.047720563797546287, 0.03822603702012982, 0.03561825052435909, 0.02529153786599636, 0.052852161295179806, 0.038848396124584336, 0.01796410435677639, 0.03680673175092254, 0.023912712299664105, 0.019354471803775856, 0.016251308943278024, 0.05565026668565614, 0.021696070708068352, 0.043039435520768166, 0.027015792039622153, 0.029476382237459933, 0.03591309773868748, 0.07469865812786988, 0.05177637455718858, 0.03255469884191241, 0.012043249344320169, 0.06433107051998377, 0.03742834785953164, 0.06397015774356467, 0.044577423350087235, 0.02192907454445958, 0.0258429239038378, 0.05022957255797727, 0.016145513459507908, 0.057425192158137045, 0.019508611211287122, 0.06475417103086199, 0.025845466713820184, 0.02209225882376943, 0.019247478705697825, 0.024978580552020242, 0.03844858972089631, 0.028155249111088257, 0.025975190735022937, 0.026999866822734475, 0.03180688200518489, 0.03746537890817438, 0.02635053764762623, 0.008371575070278985, 0.06300448027572461, 0.023786918692556874, 0.03488935463662658, 0.03661049263817923, 0.034767089411616325, 0.031747286274496994, 0.02141061781107315, 0.025775414758494923, 0.02351883120302643, 0.04425607595060553, 0.03869803954980203, 0.02912115558449711, 0.026415386935696006, 0.03999603972105043, 0.026085461157241037, 0.010838023569834019, 0.004959932802843728, 0.057043896189757755, 0.04181032022461295, 0.01692950469441712, 0.03459689247288874, 0.050986810853438716, 0.0664347190675991, 0.029553915041365793, 0.042594476004264185, 0.04887327265792659, 0.0779227919078299, 0.000128622859587527, 0.01329174020793289, 0.028828941086041074, 0.03741705703682133, 0.012619263658832227, 0.034108771343848536, 0.015653372010482208, 0.04093073188726391, 0.02607043839192816, 0.023010296347950186, 0.027423199731856585, 0.06022326022918735, 0.052838787369962247, 0.026307737354987433, 0.022618321934714913, 0.00925621934168573, 0.005588135366061968, 0.018707429291680455, 0.07381444557436875, 0.04543424005221043, 0.030688615582351173, 0.05328287496896727, 0.03142647152500493, 0.01759070483967662, 0.01764713181182742, 0.05015320344162839, 0.04501337531421866, 0.04121332136648042, 0.031227647193840573, 0.060717077659709115, 0.05298716940784028, 0.0717307391709515, 0.03874046155916793, 0.06764699651726655, 0.04997894547081419, 0.015189311733203275, 0.027115338215870515, 0.08200448538575854, 0.04118131147697568, 0.039931748528033495, 0.04125105469886746, 0.08870353270322084, 0.017264460113697817, 0.050643631589732, 0.023479659376399856, 0.037095472150083096, 0.031540682539343834, 0.024388998081641536, 0.015089743504566806, 0.04585702843698008, 0.0027766259403766264, 0.05360377114266157, 0.0766169580497912, 0.0019135845276261015, 0.060808028493608744, 0.018644220362018262, 0.037375113394643576, 0.025425482375015105, 0.05600468927462186, 0.053832590114325285, 0.021685300660984855, 0.029988381013806378, 0.02739484205708972, 0.03498466505802103, 0.053340825252234936, 0.08234647382050753, 0.06889041193893977, 0.02324363775551319, 0.03411543116505657, 0.04418546759656497, 0.032260102685540915, 0.01818250272689121, 0.06045642521764551, 0.03998478961044124, 0.020092792542917386, 0.014424121007323265, 0.0962282960702266, 0.025158850343099663, 0.004719352274800518, 0.06704499346337148, 0.0671398187322276, 0.03584833496383258, 0.022067307394796183, 0.010679470292026443, 0.027529534650966525, 0.04116706902693425, 0.0462578390724957, 0.03423737408593297, 0.0454576020129025, 0.022869291682062403, 0.07281659197594438, 0.03526617905923298, 0.05013475068179624, 0.008739373280799814, 0.07195932404803378, 0.023188973278073326, 0.054498188862843175, 0.02704802923835814, 0.027619257336482406, 0.07904244932745184, 0.03590298417423453, 0.02771277812176517, 0.04821217938193253, 0.03915580302210791, 0.03257641535518425, 0.019298779345782738, 0.0896339670621923, 0.094519785605371, 0.03446336356656892, 0.048174890489982705, 0.052399364699210436, 0.07110293821564742, 0.10447164159268141, 0.010668687522411346, 0.0730786896975977, 0.025436824087851813, 0.035725011224193234, 0.0511106197456164, 0.018756645132920573, 0.03527963101597769, 0.04653182812035084, 0.02255095019271331, 0.02135616876850171, 0.10261143105370657, 0.026364420474107777, 0.049877599480428865, 0.03762151999399066, 0.05690865058984075, 0.012835655261629393, 0.052134664795760594, 0.021349054328831177, 0.047358158244086165, 0.023776593085910593, 0.023788038275337646, 0.07093178454254355, 0.05575276618557317, 0.10234388469585351, 0.06359593889542989, 0.06112843951476472, 0.022330492468816892, 0.012407827058008738, 0.049860948231071234, 0.07660196242587906, 0.01041691710374185, 0.02474062510633043, 0.022089682087036114, 0.005123156946085925, 0.06554793486637728, 0.032787955432598076, 0.06397505676639931, 0.02312917059420475, 0.012604018673300743, 0.03810782264918089, 0.03649655643052288, 0.04771695059857198, 0.0084435956253271, 0.06321849022060633, 0.03169675237898316, 0.05158063416768398, 0.035646718461066484, 0.028195135095821958, 0.021459894720464945, 0.03684540485431041, 0.027562930448246852, 0.06821229761200291, 0.059442062862217426, 0.05687713263822453, 0.022525846093360866, 0.0123708214544292, 0.054952430738402266, 0.042375387224767885, 0.03598074089469654, 0.0663797916578395, 0.03586469444313219, 0.00830394633313907, 0.13691512175968715, 0.08677446443055357, 0.12044118717312813, 0.08743997836219412, 0.16012141294777393, 0.0947432339723621, 0.07472654591713633, 0.09736661998821156, 0.07215604492064033, 0.0861202006095222, 0.11930170974561147, 0.1720829132412161, 0.12845023455364363, 0.15009227182183946, 0.18098124861717224, 0.12023994725729738, 0.11327211864824806, 0.12032299994357995, 0.14957696518727712, 0.10019151054854904, 0.234439738626991, 0.13639841734298638, 0.09832665204469647, 0.09776468255690166, 0.08498524222522974, 0.11554975035999503, 0.16966099105775356, 0.10769745813948767, 0.19114316547555582, 0.12764957680233888, 0.10815362366182463, 0.2276883694742407, 0.14715496157961233, 0.10289442086858408, 0.10069567563810519, 0.24856295649494442, 0.1873679594802005, 0.23119818685310228, 0.11280930348272834, 0.15178091478134903, 0.2125344162008592, 0.13006445579230785, 0.25782916641661097, 0.13984361104667187, 0.1470904600407396, 0.09901062891419445, 0.060449985920318534, 0.13392639213374682, 0.13506187977535383, 0.0981563940378172, 0.1827305933194501, 0.11906296041394983, 0.17379636344100746, 0.2682826497725078, 0.08740523058388915, 0.10416977493358509, 0.06220596669507878, 0.2404105482356889, 0.15955871742750916, 0.08994314154343945, 0.12572099028953485, 0.0900652574907456, 0.12653478447880062, 0.14503407824252332, 0.23587421593921526, 0.14595905717994484, 0.2157175461096423, 0.15953639362539562, 0.1307526667203222, 0.10708557561572109, 0.11673164979687758, 0.12763812313122408, 0.10785063741994755, 0.16610601038805076, 0.13441531732678413, 0.11111091676035098, 0.11160328212593283, 0.15118977507310255, 0.11196582338639668, 0.07150104149643864, 0.09189226731125798, 0.15644908643194608, 0.05146838411954897, 0.12095311470329762, 0.07233327148216111, 0.13377150973039015, 0.14340658485889435, 0.11659959331154823, 0.1080329529941082, 0.18360614776611328, 0.05824881153447287, 0.11960995463388306, 0.15222923643887043, 0.15157679787703923, 0.1270157979535205, 0.1399193084133523, 0.08032136570130076, 0.1915473009326628, 0.11036127805709839, 0.11935981948460851, 0.20233735122850963, 0.0983813012550984, 0.17403576416628702, 0.12833695991763047, 0.11553681748253958, 0.10827569211167948, 0.10593868858580079, 0.19782889315060206, 0.13419214715915068, 0.1762936572943415, 0.10830293529267822, 0.10901122407189437, 0.12930311235998357, 0.1712553719324725, 0.08139081152954272, 0.12121551776570932, 0.13321684806474618, 0.14115903260452406, 0.2189604685242687, 0.19427167331533773, 0.14380341927920068, 0.17497192536081585, 0.11614375348602023, 0.1589443175388234, 0.12568657499338898, 0.1638278290629387, 0.11669215905879225, 0.1386746580579451, 0.1600561243082796, 0.12744993822915213, 0.10756903181650809, 0.07340803023959909, 0.17259185521730355, 0.1088249051411237, 0.14464549480804376, 0.21411670558154583, 0.19524146270539078, 0.20235861651599407, 0.12555351427623204, 0.09764072777969496, 0.0877266051247716, 0.0944155151290553, 0.1093636890873313, 0.09964999210621629, 0.07383875069873673, 0.11186161397823266, 0.07779471842306, 0.08587513411683695, 0.15339795872569084, 0.08928162418305874, 0.2186604474804231, 0.16881960763462953, 0.16057999405477727, 0.12418588623404503, 0.09483668181513037, 0.1520829578595502, 0.12435265657092844, 0.15560554526746273, 0.1667535634977477, 0.14487451394753798, 0.21656735693769796, 0.08179570016052042, 0.1540720154132162, 0.13022640853055886, 0.10923550025160823, 0.11738746746310166, 0.17843758368066379, 0.10190827878458159, 0.15047397491122994, 0.057802681545061727, 0.12765725781874998, 0.1388737673738173, 0.12266280581908566, 0.18109194482011454, 0.1658930860991989, 0.1809717762683119], [0.045163348516715426, 0.026429056023646678, 0.06486066710203886, 0.0416169139955725, 0.05690458955775414, 0.03371157729998231, 0.03796148978705917, 0.03139240228171859, 0.0660102954134345, 0.026312424335628748, 0.0122950282446774, 0.07162017867501293, 0.05963551319603409, 0.02610246354847082, 0.052226433264357705, 0.020960399648174644, 0.07033342522169862, 0.01613187829830817, 0.07421628758311272, 0.02596664458646306, 0.04888128276382174, 0.03689252571868045, 0.02323309501766094, 0.02255252100128148, 0.035039785850260935, 0.03622292022087744, 0.022670864293883954, 0.019612656074709127, 0.03092582124684538, 0.0165769124536642, 0.04167704237625003, 0.06282115368438618, 0.022075134296236292, 0.03270363388583064, 0.008285385855872716, 0.04128588390137468, 0.029150302056223154, 0.037257675946291, 0.03686100098171404, 0.07147379153008972, 0.028846959583461285, 0.04165292384901217, 0.06274284395788397, 0.07655228687716381, 0.04578212156359639, 0.02669690772225814, 0.0299840519603874, 0.030172345428062335, 0.057908037677407265, 0.03926262139741864, 0.032179998233914375, 0.006003425090706774, 0.005395885615143925, 0.025212413897471767, 0.010330481920391321, 0.046948160244418044, 0.05112160862024341, 0.015227477631664701, 0.07447663468441793, 0.007432751473970711, 0.03714051330462098, 0.043255901762417386, 0.07588492733027254, 0.00394950170967994, 0.03364876192063093, 0.03964848729914852, 0.011097882125925804, 0.05176593868860176, 0.08744898930724178, 0.045145886418010504, 0.011521321056144578, 0.026734352677262256, 0.04167361916708095, 0.031021677888929844, 0.03540406416037253, 0.059217718829001696, 0.01974054635502398, 0.02210594996410821, 0.04430263702358518, 0.03550129822854485, 0.01595852617174387, 0.014773693767243197, 0.015921768233446137, 0.05358498590067029, 0.032021054798471074, 0.03401872974687389, 0.04136934710134353, 0.013996369138892208, 0.027251057093963027, 0.009847597385357534, 0.03150778037628957, 0.028585937339812517, 0.02961626901690449, 0.011618230275676718, 0.02185253918703113, 0.06716613232025079, 0.04926899088812726, 0.01445542013139597, 0.04411196868334498, 0.016891711990215948, 0.06462370910282646, 0.03113454540393182, 0.02375547368345516, 0.03526596532070211, 0.05469836347869464, 0.11656676578734602, 0.024371047437723194, 0.05860932397523096, 0.03860924984993679, 0.05915524610983474, 0.08619399807815041, 0.03985427679227931, 0.024180204374715686, 0.037005539118711434, 0.030049805396369526, 0.09684311665062394, 0.012441478154089834, 0.043850613957537074, 0.011958015167952647, 0.01388877977816654, 0.026881323362301503, 0.06976973225495645, 0.044785655569285154, 0.056864416891975064, 0.03917761453028236, 0.04011615399005158, 0.023413020452218394, 0.02610305557027459, 0.06491002373929534, 0.019526519446766803, 0.05174617296350854, 0.06381167910460915, 0.0403179061998214, 0.05216444230505398, 0.031125453034681932, 0.06254161761275359, 0.04713682012100305, 0.03970921957599265, 0.05628723464906216, 0.0329369956494442, 0.1074633974848049, 0.028576634624706845, 0.05587456661409565, 0.04577048808070166, 0.04783674595611436, 0.00707789250217112, 0.04693655390292406, 0.05534110238243427, 0.022003542066418698, 0.10926406657589333, 0.05513112632823842, 0.008437792454580111, 0.04833971343136259, 0.022154931710766892, 0.038817074948123524, 0.024474188153232847, 0.032182447745331695, 0.022138585802167654, 0.05244163743087223, 0.02957806410267949, 0.06604240369051695, 0.018678642443514297, 0.06254885079605238, 0.03870180541915553, 0.03421142012146967, 0.014895687578245997, 0.034469243072505505, 0.02994249847584537, 0.028404027190325514, 0.08075602166354656, 0.03966474160552025, 0.04445649144638862, 0.015733934473246336, 0.04248659232897418, 0.010852696041443517, 0.02692366055479007, 0.022227896277659705, 0.025830713666177223, 0.04618138853194458, 0.03924707955281649, 0.07759212822254215, 0.0361197252225663, 0.05543957477701562, 0.021656422210591178, 0.014408431581354566, 0.029443693812936544, 0.0194528967009059, 0.062869540016566, 0.028847753469433104, 0.0050422861739727, 0.018157347737412368, 0.008616787447993244, 0.02011806457968695, 0.05072120510573898, 0.06692603948925223, 0.05595304597435253, 0.041728163204555, 0.036305019565458806, 0.04956148697861603, 0.027336886684809412, 0.0875973306330187, 0.025489761693669215, 0.013978188641236296, 0.06614085233637265, 0.03173447892602001, 0.03526293905451894, 0.025246454303019812, 0.04589354040633355, 0.053557437378913164, 0.023735921696892807, 0.05778575888169663, 0.04515430025224175, 0.07033926740820919, 0.015509229120133179, 0.038333598391285965, 0.09331005944737367, 0.018879860306956937, 0.08071492279746703, 0.056935283089322705, 0.07066408212163619, 0.04696939160515155, 0.025425039630915438, 0.034869568555482795, 0.02866378566250205, 0.0550626078620553, 0.043746109386639934, 0.014644500699692538, 0.06287345516362361, 0.06928322943193571, 0.017546391413946236, 0.013906645605207553, 0.05235522260357227, 0.031053837056138685, 0.030908674666924135, 0.0488387284401272, 0.04362534711669598, 0.030336635719452585, 0.030423834254699092, 0.041872680985501835, 0.011966300928699119, 0.015934397466480732, 0.005582092587636518, 0.012139690374689443, 0.025139771634712815, 0.06498211129967656, 0.0181419941862779, 0.040506949448691945, 0.043354581110179424, 0.08921644410916738, 0.058600944067750654, 0.07863408659717866, 0.0552663821061807, 0.058881036538098536, 0.04405109391414693, 0.04276977213365691, 0.008507920745094972, 0.015366831761119621, 0.016181681072339416, 0.022546958710466112, 0.044504161924123764, 0.029063731165868894, 0.03561729718265789, 0.03193991897361619, 0.048702705917613845, 0.01165335888176092, 0.00829546888624983, 0.03329884819686413, 0.04248199186154774, 0.019917011260986328, 0.010365591018593736, 0.023712614019002234, 0.03330214587705476, 0.07587800627308232, 0.02716682036407292, 0.09207849803247622, 0.05757632226284061, 0.07098648125039679, 0.018681424437090755, 0.05459472743262138, 0.06183664008442845, 0.015215216503877724, 0.017146729198949676, 0.007155246766550201, 0.019412527259971415, 0.014491608100278037, 0.02085961853819234, 0.02821217311014022, 0.04230875169326152, 0.043440805947674174, 0.010326599003747106, 0.013790090252379221, 0.04091647247384701, 0.03257168257342918, 0.03746136198086398, 0.018342984740489295, 0.03053241003570812, 0.09161732492170163, 0.03135343062292252, 0.0626865051952856, 0.06466468583260264, 0.01616869051940739, 0.07520950000200953, 0.024393727470721518, 0.03349238334755812, 0.017895862393613373, 0.020649840955489447, 0.05166262494666236, 0.043437158821948936, 0.040406115752245696, 0.04604657380176442, 0.03461953857913613, 0.02585745133858706, 0.041932989177959304, 0.05818863904901913, 0.03504467808774539, 0.035216968307005506, 0.02977881547329681, 0.01996980807078736, 0.02845673239789903, 0.004166617224525128, 0.03515328440283026, 0.03119419202474611, 0.018009255773254802, 0.06741996548537697, 0.011052674730308354, 0.057761087348418574, 0.04658642644062638, 0.018137604064707245, 0.028535006501312767, 0.07980528553681714, 0.05339413774865014, 0.02659537852741778, 0.00873618501438094, 0.04958643331857664, 0.03847046568989754, 0.013052409880661538, 0.009981489307912332, 0.010397763756502951, 0.06155899712549789, 0.03390708698758057, 0.01909281512988465, 0.0639963491952845, 0.06963593193462916, 0.031569347251206636, 0.043207875053797445, 0.010711527678982487, 0.042829981938536675, 0.015669529625613774, 0.03587164603439825, 0.062493529835981984, 0.025740556718249406, 0.0701667091676167, 0.09018885942974261, 0.06709500149424587, 0.22283653196479591, 0.22697133437863418, 0.2183424045464822, 0.11389283569795744, 0.1510638796857425, 0.1158374220665012, 0.09664889278688601, 0.08003631992531673, 0.07852087302931718, 0.08603025400745017, 0.13503828032740525, 0.1330817381718329, 0.14610444009304047, 0.07108942179807595, 0.12315173101212297, 0.1581551270293338, 0.169239552957671, 0.14954766604517186, 0.1630531456321478, 0.1311041478599821, 0.09477402589150838, 0.12028095791382448, 0.10829099307635001, 0.08195617369243077, 0.19136689204190457, 0.13982058156813892, 0.11728270165622234, 0.07679875115198748, 0.13143757996814592, 0.17575655611498014, 0.18479495468948567, 0.12602341334734643, 0.12418205929653985, 0.12792955392173358, 0.19236102726842674, 0.16280956513115338, 0.12336099121187415, 0.12831509751932962, 0.10620546819908278, 0.17176240043980734, 0.10785973657454763, 0.12156166562012263, 0.15622552271400178, 0.11100423069936888, 0.12390668264457158, 0.10709419979580811, 0.123964805954269, 0.16174602934292384, 0.09115919843316078, 0.13292814498501165, 0.14569934111620697, 0.11220772790589503, 0.07462496243949447, 0.10129488312772342, 0.13099883922508784, 0.09046977292746305, 0.1953633954482419, 0.10244506105248417, 0.10180780131902013, 0.13084464892745018, 0.16265525269721234, 0.06817864227507796, 0.09285683198166744, 0.07804104020552975, 0.05613945990002581, 0.09831814321556262, 0.10239503266555922, 0.14187211862632207, 0.12051043845713139, 0.12837437433855875, 0.16905018740466662, 0.09604537659989935, 0.14087199872093542, 0.18175898545554706, 0.0777429665571877, 0.08462330486093249, 0.22772479323404177, 0.13208298890718392, 0.125452724684562, 0.05081979963662369, 0.08885033375450543, 0.11557826240147863, 0.0924902262964419, 0.11566488418195929, 0.1795775360826935, 0.14214784811650003, 0.08818683507187025, 0.13727447390556335, 0.10271371342241764, 0.17986974040312426, 0.07641805907977478, 0.08602993509599141, 0.08705574433718409, 0.10236920083739928, 0.1925844688500677, 0.1610317083873919, 0.14103894547692367, 0.14660236266042503, 0.14126689253108843, 0.12167593091726303, 0.1753152912216527, 0.1509213601904256, 0.11290353842611824, 0.1765709745564631, 0.09190190929387297, 0.1456757416682584, 0.12652688633118356, 0.07818867585488729, 0.10507509671151638, 0.08304524275341205, 0.12362473777362279, 0.12038880426968847, 0.13148772370602402, 0.14149431032793863, 0.10958284911300455, 0.13181886236582482, 0.09440841765276023, 0.11114004626870155, 0.138484247561012, 0.1062366400978395, 0.21546032705477305, 0.15617916520152772, 0.1352691993649517, 0.1585729688938175, 0.09513578683670078, 0.1212355616901602, 0.1768170249249254, 0.06701661034354142, 0.11906179333371775, 0.17670251535517828, 0.13276526943913528, 0.13570086977311543, 0.15671053954533168, 0.19973181746900082, 0.11942996643483639, 0.10266055698905673, 0.09950906038284302, 0.14003322087228298, 0.24658980380211556, 0.10693268810531922, 0.09983327120010342, 0.18039804776864393, 0.1739819020565067, 0.07860516064933368, 0.09776105239455189, 0.19429037374045166, 0.061202725528606346, 0.24494736907737596, 0.17294463914419922, 0.08993463949965579, 0.15883358062377997, 0.25687818601727486, 0.1334022916853428, 0.08008690471095697, 0.12938284022467478, 0.17000183276832104, 0.18404522777668067, 0.09783015440085105, 0.10203179251402617, 0.10669961811176368, 0.11710622826857225, 0.14003860844033106, 0.15003462348665508, 0.22266312555543014, 0.11518256792000361, 0.16191630092050346, 0.10030369274318218, 0.16097294725477695, 0.14218699958707604, 0.12117757408746652, 0.14305333952818597, 0.1258465192679848, 0.061478984276098866, 0.14485499928040163], [0.07065074890851974, 0.061136011965572834, 0.0027370522937936975, 0.09918704123369285, 0.020605776891378418, 0.014035606274514325, 0.06616394966840744, 0.01872593633431409, 0.0514373411424458, 0.039777636261922975, 0.04924029564218862, 0.06727134596024241, 0.007432888029143214, 0.021595829033425877, 0.04062939787815724, 0.06335829557584864, 0.0348521980590054, 0.02643089315720967, 0.11864065378904343, 0.04417575776044812, 0.00927262207759278, 0.040187983707125695, 0.022262294610430087, 0.03318688991878714, 0.01763784436375967, 0.03184268490544387, 0.0055985241612818626, 0.02517320305508162, 0.03799202047022326, 0.06888390478811093, 0.0232463196651744, 0.07484772548611675, 0.05520131738324251, 0.08059169405273028, 0.006534559402747878, 0.053844335555498085, 0.043856622385127206, 0.04706146202183195, 0.018561126963634576, 0.021596275170200636, 0.059183486737310886, 0.03940665741850223, 0.025826847712908472, 0.028867196890392473, 0.046550565864890814, 0.030468224015619074, 0.03638732586322086, 0.06653976307383605, 0.006229756383358368, 0.05646657145449093, 0.028831071685999632, 0.04672472205545221, 0.028482345398515463, 0.011446534622726696, 0.0479363277554512, 0.019838635377319794, 0.011765928689523466, 0.08052503477249827, 0.026700807602277825, 0.07350340512182031, 0.02548354970557349, 0.039840848584260256, 0.05051673197054437, 0.1136087127295988, 0.034620305323707204, 0.03812185475336654, 0.042260202512677224, 0.03067099063524178, 0.030993226915597916, 0.030859854072332382, 0.036171707790344954, 0.05070833329643522, 0.015581106334658605, 0.010315587228563215, 0.061989961857242246, 0.033574272346283705, 0.05716238197471414, 0.02048820543235966, 0.08451176048921687, 0.019154392182826996, 0.022732366707974246, 0.07884765549429826, 0.05932950068797384, 0.06201476909752403, 0.027498276238994937, 0.048735367200736485, 0.034724005830607245, 0.027622812859980122, 0.011069364995429558, 0.06068666572017329, 0.0281504586538566, 0.049905399060142894, 0.035624459119779725, 0.034948366827198436, 0.03536886854895523, 0.01860311471058854, 0.012432257711355175, 0.05314141059560435, 0.028405005977089916, 0.02193278443467404, 0.045697932331157584, 0.05186312186664768, 0.02216396131552756, 0.01141665448501174, 0.01996262068860233, 0.07750619176243033, 0.014829669513606598, 0.07672113353120429, 0.047479609227074046, 0.0024021814793481356, 0.06276218899126564, 0.03047223755025438, 0.06508683639445476, 0.02169289855685617, 0.011652762619113284, 0.020513419793652635, 0.05314798899261015, 0.05995055700519255, 0.017407167902482406, 0.042637040505984, 0.02559004577675036, 0.038825553243181536, 0.006747418806688594, 0.010237816089232053, 0.023792140019525374, 0.030693850480020046, 0.017923232799928104, 0.0224516788231475, 0.016781241400167346, 0.011065567743831446, 0.10526446904987097, 0.03404784907719918, 0.0731946106201836, 0.05891111599547522, 0.06784036542688097, 0.012140975350381007, 0.04732393293774553, 0.03203905972519091, 0.053936470433005264, 0.036267740851534266, 0.03489767008328012, 0.015837638372821466, 0.018087959050067833, 0.05802298829491649, 0.012848693312012723, 0.039082008946154795, 0.039095925699387274, 0.030200677657766, 0.05187361880338617, 0.024320255698902265, 0.012561464349606206, 0.019682322961411307, 0.04144127181332026, 0.02816269942559302, 0.00436783763247409, 0.029250470788351128, 0.07730431402368204, 0.09795619906591517, 0.006707461151693548, 0.04797572689130902, 0.03242076959993158, 0.06466930665607963, 0.03371279187766569, 0.02074414544871875, 0.04788851478536214, 0.045341850724071264, 0.054644124781978984, 0.018874840844156485, 0.01955792204742985, 0.0223195188612278, 0.03195160673931241, 0.02341740718111396, 0.014285660847755415, 0.010275305149012377, 0.05618307613102453, 0.031098800179149424, 0.09031548084957258, 0.05306962837598153, 0.04782077663445047, 0.04473777813836932, 0.017723473786775554, 0.05792037344404629, 0.010901120541218137, 0.04445665429479309, 0.02144144704964544, 0.023252506208206927, 0.060737935826182365, 0.03473181576867189, 0.04037568345665932, 0.03223006733294044, 0.03793169192171522, 0.024334771259288703, 0.08356552304966108, 0.041997775701539855, 0.04379751859232783, 0.056128739046731164, 0.03217364714613982, 0.010185210965573788, 0.027622785718579377, 0.05961002742073365, 0.032798689856593094, 0.022245115800095455, 0.04938318833176579, 0.03027734872219818, 0.02125548434975956, 0.031317709146865776, 0.023898257807429348, 0.0648722971922585, 0.019912293746269176, 0.018905685349766697, 0.028296314845127717, 0.051582435678158484, 0.03770066771124091, 0.03958252012463553, 0.021829184011689255, 0.033870992317263565, 0.008933133196218737, 0.037470501847565174, 0.021113170111285787, 0.04544295583452497, 0.022008376628426567, 0.039421537691461186, 0.0094338530242177, 0.029657975171825716, 0.017108994170225093, 0.044240948012364764, 0.035985307435372045, 0.0275063779471176, 0.018639238218643835, 0.01791786728426814, 0.0214357185177505, 0.02311235649644264, 0.021707264839538505, 0.08887373642729861, 0.009923268458805978, 0.04980869764196021, 0.010249330828498517, 0.08787643244223935, 0.057809894372309954, 0.04441218989502106, 0.0035424330729126397, 0.029267013472105776, 0.016161806781643202, 0.014852866929556643, 0.09234481624194554, 0.01492619451268443, 0.022794218567599143, 0.043526053694742065, 0.04216545866802335, 0.05970324456159558, 0.07832515638853822, 0.0416468339972198, 0.016329296365646378, 0.02590414133322026, 0.05088013157780681, 0.03326814787994538, 0.044668676132070165, 0.034907658118754625, 0.024701083478118693, 0.01460913715085813, 0.03760685006688748, 0.04004971184102552, 0.022086031568635787, 0.03293236464794193, 0.03033855597355536, 0.04195326719699161, 0.023079601914754937, 0.02578133836920772, 0.061925976004983695, 0.013118584008355225, 0.03875357424840331, 0.05269847311345594, 0.02351861576815801, 0.04886755260771938, 0.012755158107860811, 0.021440515760332346, 0.019238315090270977, 0.035001679323613644, 0.04404794551166041, 0.04883856898439782, 0.035738157840179544, 0.03653949751917805, 0.05445873544418386, 0.05908767080732754, 0.025780934640871625, 0.043273516531501494, 0.12260133054639612, 0.04774635491360511, 0.05524397009451475, 0.03861412851672087, 0.02184662745068116, 0.012476359094892229, 0.026763198897242546, 0.040800303885979314, 0.04073768188910825, 0.07892472350171634, 0.027083494567445347, 0.024929861737681285, 0.06063036766967603, 0.01049873824896557, 0.07073851062783174, 0.04828449085886989, 0.02474063358801816, 0.01955591867278729, 0.016460123006254435, 0.021865831688046455, 0.013908029816645597, 0.02389061580678182, 0.023747086990624666, 0.03383344218933156, 0.05199087643995881, 0.03845818420606, 0.029757774102368524, 0.028391155381021754, 0.03485038297783051, 0.01751322971124734, 0.03687890752085617, 0.022813222637133937, 0.029372376389801502, 0.020827374554106166, 0.01920189133046993, 0.059251767716237476, 0.026318064657971263, 0.05761211498507431, 0.03525544124256287, 0.023560712080714957, 0.04197973345539399, 0.03391367556261165, 0.013429842440278401, 0.026291079320279614, 0.02287743240594864, 0.00369155068515933, 0.038194485141762664, 0.08017352649143764, 0.033070232785706005, 0.034733803876276524, 0.0034709093327234897, 0.13866144019578183, 0.0790294621671949, 0.02701710330854569, 0.06045333788331066, 0.031137646308967044, 0.019363133303288902, 0.01832078816369176, 0.04990517853626183, 0.0077760486331369194, 0.024516289554802433, 0.02260002014892442, 0.04395035521260329, 0.06287648142980677, 0.03329703990103943, 0.07695805081831557, 0.26162556984594887, 0.1971941507820572, 0.09717882863645043, 0.1760257716689791, 0.09218324348330498, 0.12057161517441273, 0.13347536990685122, 0.055519394243934324, 0.1007926586483206, 0.16029556574566023, 0.15859827825001307, 0.11975735958133425, 0.06577982420900039, 0.11851592548191547, 0.10364146756806544, 0.1715313456952572, 0.19382043395723614, 0.10155712334173066, 0.15146884295557225, 0.17158328076558454, 0.06772266674254622, 0.08405515391911779, 0.039342047314026525, 0.19139661187572138, 0.10201922604548079, 0.0885274460805314, 0.12603241072169372, 0.0930327150438513, 0.1496908233634063, 0.1258705122662442, 0.12515902758709022, 0.24051002146942274, 0.14575914719275065, 0.10515072622469493, 0.12317617184349469, 0.20024001305656774, 0.16095849445887975, 0.11320079104708773, 0.1801645095859255, 0.12187546092484679, 0.19528828162167752, 0.13601155738745416, 0.1310231172080551, 0.112249206751585, 0.09583938693893806, 0.1515928791569812, 0.1627632619014808, 0.17081231570669583, 0.06232931757611888, 0.13034553213843278, 0.09951184916176967, 0.10045322829059192, 0.09546334283160311, 0.1622434090822935, 0.1086015517690352, 0.16163130264197076, 0.12050168535539083, 0.226952443963715, 0.10858899208584002, 0.2370775570826871, 0.11428247764706612, 0.2666192890277931, 0.19452180846461228, 0.22420122873570236, 0.08871029769735676, 0.10471657916371312, 0.12248869373330049, 0.07848348574978964, 0.16368984218154634, 0.1284796286906515, 0.08941380959004164, 0.10774688263024602, 0.1618615160030978, 0.13642254604824952, 0.22447283273296698, 0.11883703539414064, 0.19481606196079934, 0.1300428919494152, 0.2712240447955472, 0.1299939967159714, 0.13324101748211042, 0.1429833418556622, 0.20888172648847103, 0.121949149827872, 0.1393981392362288, 0.1406404690018722, 0.0643571059086493, 0.1122030731556671, 0.1522912002567734, 0.13133459192301544, 0.11785899501826082, 0.11774515041283198, 0.12624713991369518, 0.09263779409229755, 0.1960489193775824, 0.10701309450502906, 0.07573047918932778, 0.10270842084927218, 0.08026215673557349, 0.09893943023468767, 0.08196603959160191, 0.10350987248654876, 0.08124468222792659, 0.16035951088581765, 0.14744260614471777, 0.09484170297426836, 0.1320177816918918, 0.13997725530394486, 0.11138440708496741, 0.19089294890207903, 0.2229327889425414, 0.15716784500649997, 0.24428357183933258, 0.10752393637916871, 0.09970035976065056, 0.15004372942660535, 0.14901516533323697, 0.16782045124896935, 0.153151379099914, 0.09288885883454766, 0.09590745078665869, 0.13523217849433422, 0.10266909295959131, 0.09584467272673335, 0.1192259852375303, 0.15947584116033145, 0.0965302645095757, 0.14942586900932447, 0.08606524605836187, 0.11892741625862462, 0.1799755104418312, 0.12372073690806117, 0.17120187623160227, 0.15377649984189443, 0.1108487918972969, 0.11906021913247448, 0.11254367737897805, 0.09771026404840605, 0.11564163757222039, 0.07190078683197498, 0.0848829937832696, 0.06778089183249644, 0.11297808228326695, 0.08121057227253914, 0.09264556331826107, 0.12829892124448503, 0.16054386885038444, 0.11084220332226583, 0.11154211219400167, 0.10101444460451603, 0.08591024830405201, 0.17509829572268895, 0.15822151489555836, 0.10576590642865215, 0.08638697343745402, 0.08709280591990266, 0.14800557307898998, 0.19348531908222608, 0.08385075881545033, 0.1526372531162841, 0.15667750846062387, 0.1867520125316722, 0.18059619356478962, 0.10230910299079758, 0.11995669959911279, 0.11411698295601777, 0.08948751884911742, 0.06865250399070126, 0.1327728826020445, 0.14564865455031395, 0.14141455532184669, 0.11560822650790215, 0.12155861221253872, 0.15978794012750897, 0.14202740815068993, 0.16141216297234806], [0.02855960339573877, 0.01163204779316272, 0.006768891895522496, 0.02047094689416034, 0.025608915835618973, 0.011257532085957271, 0.04321601747402123, 0.018329244406361665, 0.052754862766180716, 0.043339388711111884, 0.023792179035288945, 0.034871102044624944, 0.039578228390642574, 0.016891309958217398, 0.031278798556221385, 0.022562588764620677, 0.021492606893713986, 0.011312920899529542, 0.01201201552924301, 0.029592476186475584, 0.00909228528118027, 0.009623187194977487, 0.016883135307580233, 0.04121317208877631, 0.06568120592939002, 0.07702084923429148, 0.07756742954786335, 0.010124659348678375, 0.013839893026410468, 0.013991635508968361, 0.018460730922275355, 0.032955316094947715, 0.022220164371122206, 0.04207182762080005, 0.011640766119983579, 0.022691079548427036, 0.02783950980353568, 0.010282580740749836, 0.048565241508185863, 0.04654004178675158, 0.021757683384099176, 0.017704620691282407, 0.09316926343100411, 0.06428046537829296, 0.011770335774469589, 0.023453230437423502, 0.039531894626894167, 0.07384584138968162, 0.02708126388357154, 0.005503410939127207, 0.017372679663822055, 0.022783864123214568, 0.02454970231545823, 0.05732907088739531, 0.030449727151010717, 0.014217998183864568, 0.08975125184016568, 0.026451688559193696, 0.06737629497157675, 0.0448383438134832, 0.058563176808612685, 0.020022123120725155, 0.07356153521686792, 0.035795161567096195, 0.04664594413978713, 0.0925737607425877, 0.047643343119749, 0.015074624048013772, 0.09514996143324034, 0.03918849144663129, 0.03044726067621793, 0.007490014740531998, 0.04168529336207679, 0.024505139528108493, 0.03326660421277795, 0.05508089438080788, 0.038816776392715316, 0.05037862295284867, 0.016732826230249236, 0.014707255010892237, 0.02022479474544525, 0.014000664265560252, 0.018736738611810973, 0.052578881316419156, 0.032218905431883674, 0.03260747868833797, 0.009803145708117102, 0.06758229141788823, 0.032006391656718085, 0.04081333175833736, 0.030532728947166885, 0.04266323874305401, 0.012292744126170874, 0.052869786242289205, 0.020198175816663673, 0.0065310182981193066, 0.0433800940268806, 0.04570512819503035, 0.039837496621268134, 0.03367179139916386, 0.04826727642544678, 0.03298712242394686, 0.06310894074184553, 0.08904560256217207, 0.020482741529121995, 0.0664735176999654, 0.03362918957801802, 0.06024188601544925, 0.037025260739028454, 0.05014421624530639, 0.08271094212042433, 0.014651023117559296, 0.00900031325207757, 0.02569717288549457, 0.017344564565324357, 0.024175680242478848, 0.009814171054001366, 0.041947211271950176, 0.0505341363937727, 0.01611916085572115, 0.04187793284654617, 0.03077877253027899, 0.009382783934207899, 0.034949184461895905, 0.017019123903342655, 0.040598877373018434, 0.014656359795480967, 0.015015520255214401, 0.008764883652994675, 0.053667061496526, 0.04543402970635465, 0.029270467215350697, 0.026777242875791023, 0.0356462061671274, 0.022255739962149943, 0.026615200231650045, 0.028373323480731676, 0.05888911789017064, 0.049508293225829086, 0.057900030964187214, 0.041900853759476116, 0.03584078965442521, 0.025207017847735966, 0.048631171363272836, 0.03749815893492528, 0.0338477830269507, 0.016760717412190776, 0.06269037284489189, 0.016628764403451766, 0.052039730961301496, 0.0607342038835798, 0.02937869694350021, 0.016203636769205332, 0.027731005268703614, 0.03845421138352581, 0.0379477189188557, 0.04075330176523753, 0.054380758199840784, 0.015165108389088085, 0.02704314378622387, 0.01204871918473925, 0.028929187849696194, 0.017877567393173064, 0.007577725569717586, 0.025678044983318875, 0.01173247436859778, 0.021113441525293247, 0.025937820418870876, 0.019103656423145106, 0.013299676523144757, 0.022340151414807354, 0.013128470263576933, 0.06720995889710528, 0.03873317748574274, 0.054539979834641726, 0.04237571970692702, 0.04423877330762999, 0.014633557626179286, 0.022107347746246626, 0.06988761414374624, 0.0715616075322032, 0.037413182601864846, 0.02446466321790857, 0.046701536513864994, 0.041310501151851246, 0.05431339663586446, 0.032284027830298455, 0.10571906715631485, 0.007146211224608123, 0.04763580459569182, 0.021255662465201955, 0.03853861435449549, 0.023296585539355874, 0.02100773255473801, 0.006262677206125642, 0.0505789197050035, 0.06776683937226023, 0.04067529737949371, 0.07185575924813747, 0.04342573568490999, 0.0585321474022099, 0.016821456474385092, 0.05991521890142134, 0.035315817288522205, 0.0690933685483677, 0.02926833661539214, 0.048515053665531535, 0.01777259463311306, 0.023833181210128323, 0.05840140727481671, 0.01362910951554243, 0.04494121650766049, 0.03440479581643428, 0.035604944452643394, 0.03406855457329324, 0.02830942583802555, 0.028612539305218627, 0.032205405977687666, 0.09239886155618088, 0.009059747830698532, 0.05365231693057077, 0.055511462169566324, 0.02749377246280866, 0.024900995161650435, 0.0062736550545586, 0.06213147033538137, 0.07285081728228501, 0.08008043148687907, 0.016129761269049983, 0.021752943816993917, 0.051136505856577835, 0.027432197106203864, 0.05573774681293538, 0.03076990068491016, 0.026441720879769752, 0.08641184853123766, 0.049575641219105036, 0.011659194282921297, 0.06696033264909472, 0.02491849797245647, 0.022614958097359965, 0.055660190260303874, 0.0467224659265152, 0.05769818036683968, 0.02150398931865181, 0.0486738647866462, 0.02612454816699028, 0.059277375627841265, 0.04046134850276368, 0.016768447622390728, 0.007271249113338334, 0.02546207407223327, 0.05141514286931072, 0.014196187523858888, 0.01655791686581714, 0.01770287685628448, 0.010946339811198413, 0.013728757472043591, 0.01610633484753115, 0.03554136572139604, 0.03722124879381486, 0.030849645512976816, 0.02676210136684988, 0.03433737996965647, 0.047112810159368176, 0.01726145589990275, 0.020507959283090064, 0.09526653374944415, 0.06813227797725371, 0.02799172217159399, 0.014562362339347601, 0.08994476324213402, 0.03552082646638155, 0.037755741006029506, 0.04506818398034998, 0.06621167103626899, 0.04502830308462892, 0.08996517357549497, 0.11264683505786316, 0.04350623707952244, 0.06995880603790283, 0.03738828036668045, 0.02420327626168728, 0.044225820074124, 0.05196503443377359, 0.017623328803373233, 0.010620646394922264, 0.01952854996281011, 0.02925888801525746, 0.050820926004754644, 0.04242746139477406, 0.04474325391596981, 0.05012187547981739, 0.023735526450244442, 0.06533072902155773, 0.041885383161050935, 0.0721537514722773, 0.047614203433373144, 0.058638718112238815, 0.06389199050941638, 0.05102937196248344, 0.031913751270622015, 0.01908637922523277, 0.02113282387810094, 0.062438195305211205, 0.006582407995925418, 0.05845424479671887, 0.04436014965176582, 0.03622033500245639, 0.05950511912150042, 0.006729022450079876, 0.014507507872102516, 0.011448845034465194, 0.020067164275263037, 0.055957354671720944, 0.04990969757948603, 0.02797322700332318, 0.053857058087097745, 0.012603421562484332, 0.06423458284033196, 0.009376325128999139, 0.03651471742029701, 0.04260578039767487, 0.021108617141310657, 0.05176031363329717, 0.06189156070883785, 0.0455024328215846, 0.051149116429899416, 0.037211233616939614, 0.049686330636697154, 0.05852324502276523, 0.019553978062633957, 0.022435030966464962, 0.04269726727423923, 0.008405603601464202, 0.06826808676123619, 0.05545643297955394, 0.062397035370979986, 0.015789811832032034, 0.020831472905618802, 0.09632135036268405, 0.022257587273738215, 0.017098755076793686, 0.03800124515380178, 0.034139712540698905, 0.06615088786929846, 0.033707020937332084, 0.017554917206455554, 0.07411977276206017, 0.07500372068690402, 0.031236963479646614, 0.03891873984996762, 0.13521862136466162, 0.08477908971586398, 0.11239496964429106, 0.1956531299012048, 0.0914122648537159, 0.19683891055839403, 0.10633093610938106, 0.10984859056770802, 0.1452063854251589, 0.2759757712483406, 0.09350876842758485, 0.15461408346891403, 0.13022570285413945, 0.19386248955769197, 0.08095188758202962, 0.16583000948386534, 0.15694562478789262, 0.19005438818463258, 0.0828436432140214, 0.1887886489608458, 0.14795625715383462, 0.1348439207566636, 0.1700492895075253, 0.15765702804284437, 0.1893887860434396, 0.16235922143927642, 0.14522811211645603, 0.16062670440546103, 0.12434412060039383, 0.0906754301062652, 0.14418616731251988, 0.10034049648259367, 0.14529341432665074, 0.15013020192938192, 0.12202373439712183, 0.12125606701842376, 0.11367187076913458, 0.18507656029292516, 0.10596751275339297, 0.19462262519768306, 0.12349696962961129, 0.07436010986566544, 0.2065829448401928, 0.15975896668221268, 0.10056536977312394, 0.11950554166521345, 0.14724691664533957, 0.13507999666035175, 0.07373290602117777, 0.16989774549646036, 0.13969564970050538, 0.27214424684643745, 0.1252156581197466, 0.1393389981240034, 0.14498933564339364, 0.07269537169486284, 0.24919429261769566, 0.09166349244437047, 0.15344522547508987, 0.13420666780854973, 0.15077278816274234, 0.11316425193633352, 0.19880073171641144, 0.1542469553117241, 0.17573279381862708, 0.21922203020325728, 0.13348636217415333, 0.15344152067388805, 0.1062366875952908, 0.16469373474163668, 0.10554216629160301, 0.13429240749350616, 0.0888592836314014, 0.11046426610222884, 0.098394057713449, 0.12885978472019943, 0.07879466190934181, 0.15040551072784833, 0.08446402555065495, 0.11324615111308438, 0.15287308474736555, 0.04770045541226864, 0.10544274055532046, 0.10338471670235906, 0.09219150803983212, 0.0590505413711071, 0.14639378099569253, 0.10704730624066931, 0.19511613728744642, 0.11280287097075156, 0.09668469907982008, 0.179059895287667, 0.1946510693856648, 0.10829906764307193, 0.14452669689697878, 0.18559154123067856, 0.1309846578431981, 0.11415337957441807, 0.1334891305970294, 0.23312082939914294, 0.09243713771658284, 0.15417976677417755, 0.19231397765023367, 0.18212171670581612, 0.13147119459296974, 0.1127577144652605, 0.1207455372703927, 0.14006390422582626, 0.11383862753531762, 0.12238004670611449, 0.14556974092764513, 0.14844326887811932, 0.07484518097979681, 0.12083010987511703, 0.16886410596115248, 0.07195483214621033, 0.11243781234536852, 0.137341920286417, 0.1132974008630429, 0.20056819330368722, 0.13321621024182864, 0.09932063120816435, 0.11053433841360466, 0.10330332642687218, 0.14647555803614004, 0.09168709189231906, 0.06678787618875504, 0.12123101550553526, 0.17243558860250882, 0.10423569461064679, 0.2159646414220333, 0.19403736160269805, 0.08386495376804046, 0.15377991965838841, 0.136491987322058, 0.11833133681544236, 0.11917273380926677, 0.15722196495958737, 0.14318878868860857, 0.13373314536043576, 0.11262932885438204, 0.17453895216541632, 0.0762114655226469, 0.13833898678421974, 0.09748903449092593, 0.12637983422194207, 0.1426036608006273, 0.16749987059405871, 0.15223881735333375, 0.14569103584757873, 0.1848286778799125, 0.07898866864187376, 0.16784187938485826, 0.0804447912211929, 0.22745892964303493, 0.09048525031123843, 0.11295442176716668, 0.11933047963040215, 0.0733637490442821, 0.15197253307061537, 0.12395157452140536, 0.11353824008256197, 0.13204769151551382, 0.12513711090598786, 0.1695576908865145, 0.07022495461361748, 0.06150815449655056, 0.1333609689027071, 0.11581303551793098, 0.22906788544995443, 0.12814226107937948, 0.09386601032955305, 0.22216561010905675, 0.16899719381971018, 0.16005928628146648, 0.15926027058490685], [0.014814483899889248, 0.01748079913003104, 0.05462109869612115, 0.03143631706812552, 0.07164001225360803, 0.025193699901657443, 0.033898364419915845, 0.04167398896866611, 0.0454575511227761, 0.011765865925034242, 0.015932563725592833, 0.015489256441859263, 0.029978857774819647, 0.025000619369425943, 0.028324870991387537, 0.01930931699462235, 0.035106088899608166, 0.014552435372024775, 0.05195798784760492, 0.034074532466807535, 0.018566271955413476, 0.0615238490115319, 0.05910485131399972, 0.06593978205429656, 0.03634917523179736, 0.03747381649113127, 0.006282529444433749, 0.06571882391082388, 0.03201454086229205, 0.06042767568890538, 0.056314203023378334, 0.02370724341432963, 0.023183908014159118, 0.02348078913720591, 0.01780813460105232, 0.07106536773166486, 0.0675024821289948, 0.11292807425239257, 0.004594798690439867, 0.022929438722452948, 0.023671866294794848, 0.036916810486997874, 0.06057666840830019, 0.031183606878455197, 0.031566595791706016, 0.02012139279395342, 0.056855097213493924, 0.025291067980495945, 0.03933857660740614, 0.023279991965474825, 0.05644105514511466, 0.0316400506001498, 0.017811428888567855, 0.03448409281138863, 0.062191459616380076, 0.0281333901054625, 0.03610998824504869, 0.034837263503244946, 0.07365788718951599, 0.027955371354307448, 0.053378256636538675, 0.06111622588442905, 0.014726109802722931, 0.04392562600384865, 0.01096554913757635, 0.013977158964345497, 0.049391055945307016, 0.01916211560767676, 0.051974964793771505, 0.06756436452269554, 0.020612406178510616, 0.04280744779056736, 0.036706430704465935, 0.011385261214205196, 0.04042718765724983, 0.028949323376374583, 0.06270564666816167, 0.016974708697359477, 0.0384345881507865, 0.009529682524901415, 0.0257763053357069, 0.061949134405170164, 0.02527285779693297, 0.042460529798907895, 0.012421642879157193, 0.050704207803521834, 0.023890810885599682, 0.05090980052149721, 0.029217768793127367, 0.0272066147465791, 0.0028886906636346665, 0.01582958925116275, 0.06757988940392222, 0.023650668860812272, 0.025279290308909755, 0.018839713086241057, 0.04723016279084342, 0.04827196170975055, 0.0935438894001501, 0.013024210813455284, 0.008766493477326418, 0.038344858679920435, 0.07132076152733394, 0.014590962590383632, 0.020699392671563795, 0.027607313423816646, 0.06756371312907763, 0.019124940370342562, 0.029799330979585648, 0.035297127041433535, 0.04512709439066904, 0.015919133821236234, 0.01356627293197172, 0.009604942236494805, 0.016879062401130795, 0.05396330649299281, 0.09026510640978813, 0.026490836637094617, 0.05787979704993112, 0.037948129432541985, 0.03271697049162217, 0.011014770067829107, 0.019519879981609325, 0.04031596558966807, 0.048915165409977944, 0.014916245492973497, 0.021941442541511993, 0.01897535054013133, 0.050493244480873854, 0.034582124158207855, 0.022117047404338206, 0.04414053500763007, 0.04652302073580878, 0.03852917932506118, 0.045127104568694315, 0.03418428211339882, 0.05630706822765725, 0.025694502850196192, 0.03471207379230431, 0.03149026060210807, 0.010333347882676338, 0.017885248409584165, 0.03123535535165242, 0.04161207604088953, 0.046691344917884896, 0.0833168128239257, 0.03483312104695609, 0.010784483764187565, 0.00776696898641863, 0.033659974711814096, 0.023842326165842156, 0.07154887142990317, 0.008103871801202851, 0.042748903789158375, 0.029051300404327254, 0.06783313902893237, 0.04031960253736802, 0.024285728444478343, 0.04936383990570903, 0.07902189650173698, 0.007652420400907951, 0.03694679494947195, 0.039302593895367215, 0.06615308632275888, 0.07258086891046592, 0.013858679116570523, 0.017872055992484093, 0.06147341350359576, 0.05520200948896153, 0.04518938051270587, 0.036027020375643454, 0.02822921790980867, 0.03651000838726759, 0.017574445444292257, 0.03796321665868163, 0.08031554387084075, 0.0359714721063418, 0.04978436876886657, 0.06784044006573302, 0.01379731495399028, 0.0540956988531564, 0.06802905244486672, 0.07052082980849914, 0.029251301993748972, 0.031484917138836215, 0.04518510574208839, 0.05076462795425739, 0.04589441232383251, 0.031110532049621855, 0.029697048610874584, 0.058787106935467036, 0.0339233887914036, 0.01091462847710188, 0.05111948141295995, 0.02863133811791028, 0.050799660717270205, 0.080301762824612, 0.012010777202833976, 0.03424317556034241, 0.024278235721534917, 0.025024164534573044, 0.06256706267595291, 0.010593581329365926, 0.03396831798766341, 0.037120184395462275, 0.028169674765584723, 0.033919280261865685, 0.007012645422946662, 0.02804870723879763, 0.016780976771510074, 0.023950749276471988, 0.017771519155108502, 0.038923221573765786, 0.06593980241034712, 0.049921039292322736, 0.04088719029511724, 0.012106888295550431, 0.024119239699627672, 0.05516420830307262, 0.038488965947180986, 0.03451854881963559, 0.022882207596142377, 0.04964355918179665, 0.022948687064594457, 0.03391628452975835, 0.044402167932795625, 0.06684084263231073, 0.04466241325384804, 0.04224513564258814, 0.022688613073634248, 0.06261479082916464, 0.05356912514460938, 0.06844928275261607, 0.007700323276886982, 0.035411059856414795, 0.0320011601517243, 0.009609907416493764, 0.031429972765701156, 0.026812838822869316, 0.030838446292494024, 0.04662089601957372, 0.03033881720953754, 0.08508228630359684, 0.09259934829814093, 0.04614582311894212, 0.021928526627432023, 0.035651244289640865, 0.023333635247711624, 0.03052437278841223, 0.011594933623980199, 0.061028260604611466, 0.008437783972892379, 0.03361686738207936, 0.05079173882092748, 0.02928402434502329, 0.039980033079960516, 0.021473134635016322, 0.08728093653917313, 0.013218565295184297, 0.07503318946276392, 0.02078611623229725, 0.03133708471432328, 0.05105115293658205, 0.043661482499114106, 0.011913398945970195, 0.03763427984501634, 0.017878827771970203, 0.05223599721544555, 0.029064976277628114, 0.017790786156963025, 0.03793911509481924, 0.0008149450482700818, 0.04836393373885325, 0.06514867807605437, 0.03184882564736264, 0.0016615124789365965, 0.04920521877439959, 0.03714555481980954, 0.07602301599191767, 0.0038348339564566103, 0.04376722200374518, 0.05993941546018634, 0.023406643919380646, 0.03753260476514697, 0.037039913702756166, 0.021143473485218625, 0.020363970759457777, 0.02422173071785697, 0.045197092063192806, 0.06167871784418821, 0.054496068440909894, 0.024806643170969825, 0.010254623401643974, 0.020641535686861192, 0.018934981099196842, 0.024526577842022692, 0.048842993032719405, 0.030090951759900366, 0.01628757324734969, 0.028556007160139934, 0.035764949795390875, 0.04713005851954222, 0.019853690373046056, 0.0071179493929126435, 0.01970346102357975, 0.05333789058827928, 0.01396268411606018, 0.06769401220870869, 0.008713697515694159, 0.038931581125195534, 0.026935847043724995, 0.020218849082344344, 0.054968006509755335, 0.0507453948791538, 0.03897518378549388, 0.04484795526202236, 0.03211855349530067, 0.029728600489241735, 0.03922533250546881, 0.019227143011188934, 0.047240686868982654, 0.049940920368369134, 0.01795684063940176, 0.03794924562264766, 0.0337283981830946, 0.020313391062830175, 0.04626316896506718, 0.0183516920411161, 0.014447527072791542, 0.03588206833228469, 0.038122071884572506, 0.038125271177185435, 0.03129547016162958, 0.006605650364820446, 0.05013244366273284, 0.07362591461943728, 0.023340415508885468, 0.009053505308526968, 0.04368108198312776, 0.02279552474751004, 0.019254026568627784, 0.0175363694517208, 0.017525497624384503, 0.03613669877605779, 0.027391812398231456, 0.0234052376555545, 0.024039481300860643, 0.04471052138667021, 0.019035665517938987, 0.04233637146119561, 0.032940741162747145, 0.03665300624977265, 0.13051682151854038, 0.10158734529146127, 0.14598858702395642, 0.09462347254157066, 0.137766248945679, 0.11356828561318771, 0.14706125589353697, 0.12713420231427464, 0.10693171780024256, 0.08559309425098555, 0.16397759531225475, 0.12133472279778548, 0.1079080957653267, 0.12975494882890157, 0.10270380681114537, 0.06348474057657377, 0.1738500762730837, 0.11671060164059911, 0.14646795844393118, 0.10367126204073429, 0.1605319944875581, 0.1311926966799157, 0.1615837509078639, 0.15909411092954023, 0.14159349857696465, 0.11352058460137673, 0.13442082703113556, 0.1338362826832703, 0.12103513601635184, 0.16152865386434964, 0.15770057642034122, 0.10630021204373666, 0.05817668326199055, 0.09464396429913384, 0.06671252487493412, 0.1535210178366729, 0.10994838271290064, 0.1863168544535126, 0.11872927046247891, 0.15972278719501837, 0.06599591725638934, 0.1534401500331504, 0.14779771066137723, 0.06875728336828095, 0.09519534864063774, 0.08529599769307034, 0.13960687017866544, 0.07341465274138109, 0.08419415860303811, 0.15386515722743102, 0.1662806924432516, 0.14520471622901304, 0.15086694168193, 0.09175879947308983, 0.11808394294764314, 0.13238921176109994, 0.12592788918742112, 0.1353261691651174, 0.11080890082355056, 0.13717793194311007, 0.11729995001639638, 0.11315137334167957, 0.11078506388834544, 0.10568865521677903, 0.1221014673688582, 0.12051252834498882, 0.18719337241990225, 0.23632910581571714, 0.13168293823088917, 0.11245918619845595, 0.14232843342636312, 0.1336631884000131, 0.16024349496832915, 0.09948563056864909, 0.13511808961629868, 0.10282772087625094, 0.15101687077965054, 0.11228989171130316, 0.11326930272792067, 0.1323118723396744, 0.08037963828870229, 0.11903759677495275, 0.15459919641060488, 0.1673987145934786, 0.13913038931787014, 0.13429585445140088, 0.11302632612309285, 0.08089073800614902, 0.09803058007465941, 0.12695232778787613, 0.06479235898171153, 0.11565841095788137, 0.18843547148363932, 0.08975665297891412, 0.17831706229065145, 0.06346614871706281, 0.11456302473587648, 0.12122466441776071, 0.19996595276253565, 0.09290331841579505, 0.09393838965999228, 0.12025169948382036, 0.16746207619352, 0.10037750378251076, 0.08539088403007813, 0.10898594864244972, 0.14466899926108973, 0.11560330034366675, 0.1925860159099102, 0.08926236735922949, 0.12298877404204436, 0.12720694126827375, 0.0948316945827433, 0.1934699841908046, 0.10762256822947945, 0.19847035301583155, 0.1403897503124816, 0.10036239959299564, 0.17408790279711994, 0.10052441339939833, 0.111503992096654, 0.07737742617194142, 0.1944559227143015, 0.10616111915026392, 0.22324488790971891, 0.11642084004623549, 0.16688756059323037, 0.159889638956104, 0.14562303306800978, 0.17690448808882916, 0.1434031921838011, 0.2536516977208001, 0.10251526907086372, 0.07636229028659207, 0.20202268739896162, 0.08289474368627582, 0.1193258927336761, 0.10002192429133824, 0.12180992801274572, 0.15007661123360905, 0.09573420722569738, 0.06817737341459308, 0.06559355277568102, 0.08866693930966513, 0.1377536417650325, 0.14848088685955318, 0.07617258546607834, 0.10764515666025025, 0.1929000826286418, 0.11460968080375876, 0.19156566209026746, 0.11038949832852397, 0.1295117890196187, 0.1156382177557264, 0.12497552457664694, 0.07586283423006535, 0.17315624707511493, 0.12928988092711993, 0.199475887630667, 0.3050295008080346, 0.09143548432205405, 0.07631792088172265, 0.1274920209710087, 0.15233146452478, 0.13367963608886513, 0.0791710384988359, 0.10314701909997634, 0.18151319293039186, 0.15838281624019146, 0.13593215521957192, 0.12054037542215415, 0.17197103638734135, 0.13623658674103872, 0.08656346718115465, 0.1229629489992346, 0.1735798700579575], [0.08370841573923826, 0.024699734889769127, 0.04384098554562245, 0.025966407099206532, 0.039596341882965395, 0.1502353884279728, 0.05327727026971323, 0.05107664888990777, 0.013460302725434303, 0.047523642757109234, 0.05246252952409642, 0.022041036215211664, 0.021955416970221058, 0.03848480313484158, 0.04293826934216278, 0.009535261779092252, 0.047074323653110435, 0.033652585465461016, 0.052335887748215876, 0.026067754785929407, 0.05295753439090081, 0.03125847643241286, 0.10988824415419783, 0.016435415849887898, 0.029554596969059536, 0.052791849710047245, 0.03833770352814879, 0.03137382738558309, 0.03621144958638719, 0.027493076964414546, 0.020951125770807266, 0.02137674534294222, 0.03905799898451992, 0.030488339186246907, 0.04032949897061501, 0.028166246467403004, 0.02799535233394376, 0.031019353906490972, 0.02381635014899075, 0.03100963049967374, 0.0833655044968639, 0.06763718490089689, 0.06347380259207316, 0.0211858581751585, 0.023052832011931708, 0.05928799470088311, 0.021904798257829886, 0.007784345420077443, 0.026312609236421328, 0.020259228701304113, 0.0131116061238572, 0.041431609474654706, 0.02909314226625221, 0.05462154313655836, 0.01724394121473389, 0.021079920199034468, 0.020178349023418765, 0.019807047875864164, 0.029479547603321925, 0.017570601543411613, 0.04030396230518818, 0.011363231726656002, 0.026921616468046392, 0.012573779760194677, 0.019625685643404722, 0.02645686747772353, 0.06531612016260624, 0.010590156423859298, 0.030732367520353625, 0.10551717584686619, 0.04120613228795784, 0.030909319275191853, 0.008557087392546237, 0.06665559578686953, 0.026104443174387728, 0.04625526742477502, 0.05718900090349572, 0.0564951547421515, 0.057291323984307904, 0.01642177051066288, 0.03040143581373351, 0.02053606929257512, 0.01579564723319241, 0.017233946393909197, 0.07804115555648293, 0.022283446243298904, 0.02413105808331498, 0.011572983016126921, 0.007221945062545794, 0.061957595736852715, 0.047174373641610146, 0.022678658964910677, 0.019393786122756343, 0.03833961360422628, 0.04088377047862325, 0.022193944081664085, 0.011250044452026486, 0.023662144584315162, 0.006881720394760902, 0.01952274000671293, 0.04019873509449618, 0.04047911933490208, 0.024806807715711848, 0.01258628600875714, 0.01753362817024546, 0.03695714600118143, 0.028882016095199754, 0.06970812806061336, 0.04908183057393346, 0.005703880717711789, 0.06400032541049377, 0.04136044132922377, 0.02561221012313451, 0.021485797794801847, 0.047856090989496024, 0.04447865918544786, 0.047451097185590436, 0.04847435174243791, 0.01983640469344599, 0.06285630179835217, 0.03378958168572613, 0.03956520391095962, 0.05283332855573722, 0.030357955289738517, 0.050033248628356626, 0.01326940707596285, 0.015985031445909823, 0.017681258730590343, 0.03272396958033953, 0.0335133297235838, 0.09465310416583504, 0.06111457704433373, 0.05680523506764855, 0.04763857641124299, 0.05472454475238919, 0.024084357910656502, 0.021168828642527972, 0.021135256426142793, 0.0739303393555539, 0.019660945715648786, 0.011111709821437086, 0.011776295008270867, 0.016942042325224196, 0.03217194402324302, 0.0205159982267235, 0.02862408457856093, 0.011210032090145563, 0.007535505424519735, 0.079484358829047, 0.03124426112377218, 0.030625664495996067, 0.023911979481843964, 0.03440345570977245, 0.10915505992514746, 0.06311300516660724, 0.049282863536583524, 0.03117034151884062, 0.005513176330298717, 0.05473092637423958, 0.05673427726807339, 0.016057251320619668, 0.005724571794936699, 0.0556388910460685, 0.09985203269336905, 0.021172204354245747, 0.01741201094617801, 0.0764157452753612, 0.03529581068349736, 0.02334693623041468, 0.04933062900922128, 0.029390934322561537, 0.013117971630500895, 0.020593741376485144, 0.010440201881075544, 0.025326309393026998, 0.08784833430711712, 0.07162734400480986, 0.034912933728524616, 0.053896718458937745, 0.03723002564428108, 0.047534363610403876, 0.03134873176791838, 0.0464858607655125, 0.02654807106591761, 0.022872474011299864, 0.03945468073444707, 0.03801460550831897, 0.0127903062218268, 0.04861821473709174, 0.02489474246145359, 0.03414415694507105, 0.027723066408985426, 0.019404700358531306, 0.037584156463188786, 0.04367649847907679, 0.015506347042641469, 0.03199064625161035, 0.02595373715407082, 0.06328054224806172, 0.026606419988508736, 0.04047578094261033, 0.045915426553360054, 0.028826216767941202, 0.020295859414285848, 0.02677708681273673, 0.0379605194819825, 0.038451680447906256, 0.009129117858330054, 0.01689683662594429, 0.0032380494729815318, 0.07792134662824017, 0.029344810904668908, 0.07290581254554646, 0.023378557658621242, 0.011732772075837212, 0.06712571877454009, 0.01619814402822937, 0.06637650076299906, 0.01690492476336658, 0.023192103020846844, 0.02431685454212129, 0.05915308836847544, 0.05099456650870187, 0.0394001943724496, 0.04654495438028659, 0.027518857902448093, 0.037500075796352964, 0.03293010851900492, 0.022040948005659238, 0.05286192202142306, 0.02382180217786559, 0.066798135638237, 0.06603948598993675, 0.027039837624345506, 0.04240917148334639, 0.041140368673950434, 0.02670888216899974, 0.06041685305535793, 0.024110663016991954, 0.0444455568545631, 0.003163315838069788, 0.02348332685817565, 0.02602489003246384, 0.02313595255171614, 0.057234075984784534, 0.0480535039678216, 0.05358258049402918, 0.04978302187685456, 0.03265727976603167, 0.10273696681750671, 0.05360762522156749, 0.0040732033085078, 0.047480650778327665, 0.019737492947440063, 0.03735270816832781, 0.017756129980885556, 0.049200350285640786, 0.047653958800115755, 0.12863729308758462, 0.07455442193895578, 0.02876364566119654, 0.048292239728782854, 0.042443651240319014, 0.03362555602299316, 0.031492587977222035, 0.017420852257471, 0.04002171887883118, 0.08679169243467705, 0.02333352328943355, 0.020230777727972184, 0.058228665829769204, 0.03622191598904984, 0.023931996264894093, 0.04017957326556955, 0.05195706503997956, 0.024640013630102788, 0.030803871540618793, 0.02537828347911792, 0.018617263862064908, 0.06965490377375058, 0.014977730943688324, 0.03605692680659039, 0.008128319417924752, 0.014119835370885474, 0.0066783710831909305, 0.02705383240910513, 0.09777768328785896, 0.00829427466461701, 0.04716556625706809, 0.016521033398540955, 0.06089130509644747, 0.01810082237768386, 0.07151304478091852, 0.02258177094959787, 0.0353508636222354, 0.047195906950426955, 0.05499239984367575, 0.05102431348391941, 0.050235011016151736, 0.07345137505659036, 0.006158737091547144, 0.031541581598243544, 0.03435874025204352, 0.04542696276413543, 0.047539544225271256, 0.030425659513899257, 0.03499082615599036, 0.02762408341680254, 0.06881374426718269, 0.02114277289781187, 0.04003538118143167, 0.004907088919675776, 0.018722837125616412, 0.04435322180922542, 0.02838246165109532, 0.02504287344137473, 0.05581709809069123, 0.01967036717438272, 0.049396572435008626, 0.017254195575203215, 0.009614087192208638, 0.03085746562906674, 0.019863089779391885, 0.06050935094910009, 0.02267827219995005, 0.03186446587954249, 0.01787344359659723, 0.06926621177366801, 0.08090138422059161, 0.029684478749654124, 0.0012191698811615684, 0.02277149273348706, 0.057040869923574586, 0.05014246901763337, 0.05168644152581692, 0.01901072426699102, 0.01908856919700546, 0.0006197469566749142, 0.01958818979827421, 0.055290022266230414, 0.03756877746699112, 0.04985450214839407, 0.051850202559892616, 0.03132112217800958, 0.001367645535667959, 0.013795865433556693, 0.02444477196383689, 0.08195358847400971, 0.04939018063513296, 0.023917010819007243, 0.006073637349930192, 0.06328172289899417, 0.25074466371110504, 0.15130454248615674, 0.20628019608557224, 0.1422705136771713, 0.10659365808325154, 0.27741130707519396, 0.13166936753051622, 0.1981843640761716, 0.12122585863939353, 0.11898482032120228, 0.1310380721198661, 0.09692892418908221, 0.10093977182571377, 0.11436795948871545, 0.12580618714647634, 0.12877224013209343, 0.08132888163839068, 0.1078012672119907, 0.11691752767988614, 0.07961269015712397, 0.15122919795768602, 0.08055370287703616, 0.16257479201470101, 0.11334160741950784, 0.08376567052411181, 0.22773966672165052, 0.12044206926865236, 0.14100355309035095, 0.11463344310011182, 0.09085297557924475, 0.11507367662021092, 0.09018003168915, 0.09574768293116774, 0.11665189479078565, 0.10736083691673619, 0.07316738100988524, 0.14672576103891644, 0.07702100529734578, 0.09993275121918746, 0.138982767239213, 0.15998312751097338, 0.19170899582760675, 0.11626568622887135, 0.1271595252411706, 0.08234257902950048, 0.2114082516304084, 0.1136423952079245, 0.1445192601531744, 0.15442979335784912, 0.12522848243159906, 0.08498758317104407, 0.1397477069071361, 0.052542159001209905, 0.23972525500825473, 0.09442394931933709, 0.12676889263093472, 0.12761345159794601, 0.11616945639252663, 0.19703472219407558, 0.10040343060557332, 0.10522798422191824, 0.19983905314334802, 0.10030035435089044, 0.12566461760018552, 0.16573972361428396, 0.12623103149235249, 0.1304577211184161, 0.0990395684327398, 0.1611674561032227, 0.18222631966429098, 0.13660477341285773, 0.15005743583398207, 0.08659343128757817, 0.19332498125731945, 0.13313817871468409, 0.09098800404795579, 0.1438577699341944, 0.15678835394127028, 0.12340194758559976, 0.12457826946462904, 0.13060570960598333, 0.10049622705472366, 0.14404515416494437, 0.16619967536202498, 0.11165221807147775, 0.13924325683287211, 0.13258240425160953, 0.18240334945065634, 0.17240033192293985, 0.1444566585123539, 0.11637043846505028, 0.1687072150941406, 0.1467772889882326, 0.12338422425091267, 0.1408082978533847, 0.09257595919604812, 0.07722974981048278, 0.1241973941879613, 0.08959170790123087, 0.17210363570068563, 0.1646937211709363, 0.08591404131480626, 0.09296946879476309, 0.11733534240296908, 0.08003722237689154, 0.09444410859474114, 0.1657024584710598, 0.10417757808629956, 0.2620646362858159, 0.08168103452771902, 0.11104213366551058, 0.1552891308175666, 0.15848024029816898, 0.09800892123686415, 0.17145334130951337, 0.10452188711081233, 0.14953486887472017, 0.1009251493960619, 0.0504993954008179, 0.12931502743491105, 0.12024393704320703, 0.22362298119281018, 0.18315889819392137, 0.16384861937591008, 0.110365484974214, 0.08716886969549315, 0.10088751105857746, 0.1682296892894166, 0.1031167157260435, 0.06299242949379341, 0.13929802817957743, 0.09667629881628922, 0.13261994080884115, 0.0762548442663891, 0.13966512919536658, 0.12135910934635571, 0.1650048294769866, 0.08161725223596607, 0.15591813277985367, 0.10661778000316449, 0.10737959162465163, 0.07874659448862076, 0.08706364927015134, 0.1366162406546729, 0.046187675158892355, 0.15358247953866208, 0.11018147984785692, 0.15721201763621398, 0.11002942015017782, 0.23184602494750703, 0.07492277145917926, 0.16641682013869286, 0.21804554547582353, 0.16025260090827942, 0.16081355937889644, 0.1253936785672392, 0.2017386933522565, 0.08548853200461183, 0.12690734091613973, 0.17622686230710574, 0.12215195037424564, 0.12201967675771032, 0.15193658428532736, 0.16862644228552068, 0.10531804617494345, 0.07467892632952758, 0.2249551082828215, 0.12820011297506945, 0.08644067948418004, 0.08792376704514027, 0.08141258571829114, 0.12276438251137733, 0.08880046821598496, 0.058929734996386936, 0.09406491608491965, 0.19568975722151144], [0.038323773204215934, 0.013314530502871742, 0.06501389387995005, 0.06744059294994388, 0.03195450747651713, 0.05300955767078059, 0.06705754636121647, 0.03435375301965645, 0.01459822291508317, 0.01786343350873462, 0.014909799410296338, 0.01538668230309018, 0.0609272335256849, 0.11431203463247844, 0.05932989423828466, 0.01903588943449514, 0.02420920496141272, 0.029003836879772798, 0.02082753909884819, 0.039839589901800664, 0.04237310056175504, 0.009357952097031687, 0.04141236961420093, 0.042103043624332974, 0.047501807500209124, 0.029196629034621373, 0.06951154968036072, 0.09885636397770473, 0.08422304383878197, 0.06519496094967638, 0.03385292971506715, 0.009826446600657488, 0.016014473080368977, 0.018651657105822648, 0.024502640822902322, 0.007368248238760445, 0.031404249503144195, 0.040127237859581194, 0.02474313059688679, 0.03575497193794165, 0.0708343129871147, 0.030956694590193883, 0.10420851249779974, 0.03675688656845263, 0.0232804313168994, 0.05277807205649359, 0.025830416807106564, 0.006288705385356609, 0.0464588007889688, 0.07648184137152773, 0.01242713222745806, 0.01105216667721314, 0.03483347388516579, 0.022564397060445378, 0.05929802344845874, 0.05008842709607311, 0.04922557821763413, 0.07279084835733686, 0.016060803451442292, 0.1071467659037028, 0.0486056855879724, 0.03580765339678951, 0.0526933739227908, 0.06304086332342454, 0.0469432612215834, 0.020791941455432346, 0.02999465067737869, 0.048575572203844786, 0.013061189275634075, 0.008990183572417923, 0.015023145292486464, 0.011424269344258522, 0.027448853444574133, 0.05135125540462988, 0.017631768082667674, 0.005327699631119945, 0.0755729301433478, 0.029782133509538004, 0.03725022902446134, 0.050414802440043004, 0.02968465516875897, 0.011881266920162099, 0.04182326667276876, 0.06992191408893891, 0.0430425296404532, 0.08876123532120671, 0.02536339302813368, 0.014449038509545582, 0.05918989210788693, 0.12099952649857317, 0.03540353490305798, 0.034852676426193545, 0.046483804804406, 0.041199808341584036, 0.007852398241604013, 0.03172153926321438, 0.03465778420546225, 0.034275154915771315, 0.00785311239971114, 0.038645565044134855, 0.005430512529398713, 0.01820992402333234, 0.031039197663111345, 0.0339704316242465, 0.05217686967392053, 0.011217206749798996, 0.03373050503432751, 0.04269056674093008, 0.06511843577027321, 0.08914488580610071, 0.0167093743636672, 0.08327829239091702, 0.046729448051857095, 0.08395068666764668, 0.03583404840901494, 0.06305881057466779, 0.0231649141226496, 0.07769006118178368, 0.02909966298778142, 0.062020000602517805, 0.04205536296857255, 0.0363297250254878, 0.013063478483153241, 0.077310970452215, 0.04971349239349365, 0.0318988472489374, 0.07217080984264612, 0.03587013290130666, 0.017059033636802008, 0.06662437639066152, 0.050367793533951044, 0.04423609309430633, 0.03669882093423179, 0.029346480100814785, 0.057393111022455354, 0.06290670337953738, 0.014457211463845201, 0.016512248066387007, 0.06231997414891209, 0.028719150727348666, 0.0170095633449299, 0.03382067894563079, 0.06758510733821563, 0.021057304626862918, 0.039688693891678534, 0.011250920610369315, 0.058239250976060114, 0.0211371122194188, 0.01868668308348528, 0.014005674398504198, 0.03462902789137193, 0.0254598739224353, 0.019339138608691946, 0.025359415116586854, 0.04881606876317944, 0.10589476022869349, 0.02570927795022726, 0.03559201157518795, 0.029913016129285097, 0.04974341918049114, 0.041797943745872805, 0.01112780297574188, 0.04417744391996946, 0.03200866814170565, 0.01444932010157832, 0.027420745131426623, 0.024059114711625234, 0.04963681793638638, 0.03314220838780914, 0.048234601571623764, 0.05420295827622924, 0.04040800886494773, 0.047604870184191635, 0.03880364674010447, 0.06356714186923844, 0.0857525635510683, 0.012504773596966905, 0.04453970019572547, 0.026076424767130187, 0.03011865634471178, 0.03316405721540962, 0.015219233431188124, 0.054923596392784796, 0.06275495580796685, 0.031090715434402227, 0.049970965898994885, 0.009180999494024684, 0.03944439414356436, 0.04044395086488553, 0.1246755849570036, 0.09771379243050303, 0.010793709295934864, 0.023207395503829633, 0.06485792582056352, 0.0068554152884254494, 0.008709681436552532, 0.01054184727503785, 0.06985467126859085, 0.05706588750971215, 0.049806455083723576, 0.08342283392058951, 0.04715812272791352, 0.011233306689453977, 0.08670399856886693, 0.043766115991664786, 0.05953192804008722, 0.03181730091039624, 0.020524015117968832, 0.032461244213793955, 0.015155936291973506, 0.008283164501855416, 0.03849987339760576, 0.052374506568802257, 0.0611644425828542, 0.025016378345234052, 0.04169359863070505, 0.06524735063846622, 0.06228956899472645, 0.03017335305256503, 0.032185178848781755, 0.023142491932958364, 0.03394603829032608, 0.023334827773006897, 0.060159043675022464, 0.030785907326000075, 0.028861412379358495, 0.07153072061815433, 0.024502588236438375, 0.020329024509659836, 0.016220240521111658, 0.010009638333160962, 0.014109245135581918, 0.07064461495195117, 0.08174633673791375, 0.02748791331292263, 0.09152238430189234, 0.044104776212147305, 0.024397629047078744, 0.031073365293975388, 0.02071950614585408, 0.012347965002326029, 0.010932958252461893, 0.03575034432911447, 0.023261423854689513, 0.037467136313872676, 0.10328526382467576, 0.04606565420648881, 0.018810476708625044, 0.025114704854786396, 0.03174903689484511, 0.0351569790260068, 0.04089306980105383, 0.017533970830429877, 0.052616224491170475, 0.04592599134360041, 0.0992206015757152, 0.04478057673467057, 0.06040205420660121, 0.058073376305401325, 0.004350095638073981, 0.009341828408651054, 0.05523185485175677, 0.06062470190227032, 0.03621921202700053, 0.02790472380417798, 0.05508928107363837, 0.05245510295831731, 0.06590840659503426, 0.0073081868634160075, 0.033929139375686646, 0.011343777279502578, 0.13324187243623392, 0.040573252498039176, 0.060553720353969505, 0.005105548962351999, 0.03367157766063299, 0.05030348877023373, 0.030810473686350242, 0.03784775374723332, 0.024579529018540467, 0.02168496308981308, 0.022481471599478806, 0.0019341581334759081, 0.0547577760049275, 0.061602620141846795, 0.011001170529717845, 0.053943303280643055, 0.08458711180303778, 0.046806712834430594, 0.04233539437076875, 0.03645923700449722, 0.041899764710771184, 0.07782521857214825, 0.019735207980764762, 0.012730463674025876, 0.0327702253125608, 0.03602722054347396, 0.0662580489047936, 0.018643652088940144, 0.06803179372634206, 0.028437774129477993, 0.04398041431392942, 0.040475672377007346, 0.03208494565582701, 0.008508366881869733, 0.047013543878815005, 0.026406728828858052, 0.05039296379046781, 0.07881715534521, 0.03924599050411156, 0.05923908589673894, 0.042227598905031166, 0.034257041423448494, 0.005383441282901913, 0.023426353665334836, 0.058983705671770234, 0.019323274459955946, 0.011131378855290157, 0.02216434638415064, 0.03644173080101609, 0.029260156875742332, 0.024098685177575265, 0.04331745167395898, 0.04194801194327218, 0.03825372803424086, 0.0291012812938009, 0.007337776927410492, 0.009464321791061332, 0.013375317910686135, 0.046203522344252894, 0.017764601490593383, 0.09247617383620568, 0.037609367431806665, 0.07993321652923312, 0.05380630027502775, 0.055753088489707024, 0.06389683524944953, 0.008900952824790562, 0.009062958149505513, 0.008183882954264326, 0.03749194694682956, 0.012071808035086309, 0.04116692314190524, 0.03387055126950145, 0.10289714179400887, 0.05605912474649293, 0.03623558168432542, 0.0779084816042866, 0.02597776407908116, 0.043452015346182246, 0.031611660694969554, 0.016778277898473398, 0.08597837321992431, 0.08162641924406801, 0.11591934838465281, 0.132841523204531, 0.08060695430529968, 0.16288713525448525, 0.2006054041641099, 0.1413961263107402, 0.10198653422828231, 0.14454500377178192, 0.04253886666681085, 0.10926795458155018, 0.09468511744801487, 0.2029539631413562, 0.13516585848161153, 0.19777884440762655, 0.1307277102023363, 0.16502563336065837, 0.12000170004154954, 0.07181725238582917, 0.14275102503597736, 0.1825281727526869, 0.10357087957007544, 0.10418345419956104, 0.18055312016180583, 0.07504891111914601, 0.10231522337666579, 0.21676042729190417, 0.2290669083595276, 0.136991199105978, 0.21198341862431594, 0.11639270798436233, 0.12416618157710348, 0.12882900637175354, 0.10292115514831883, 0.11635142591382776, 0.08527786045202188, 0.1756444349884987, 0.0628941911937935, 0.09943122563085385, 0.11928242578038148, 0.1472246471260275, 0.22998312062450818, 0.13772816956043243, 0.13309108838438988, 0.11938815510698728, 0.1321559857044901, 0.10564075742981263, 0.09330519435128995, 0.16094206034072808, 0.2346406935581139, 0.09352404225085463, 0.0882552924699017, 0.09655639489314385, 0.15497517266443797, 0.10238834909562554, 0.21418662182986736, 0.15372499903397902, 0.10366244787084204, 0.24720075673290662, 0.15976351286683763, 0.1818836187677724, 0.1029899043164083, 0.11137349624186754, 0.11109613148229462, 0.08438175996499402, 0.09207903407514095, 0.11015627905726433, 0.15022533253899642, 0.22843334664191517, 0.14077875443867274, 0.1049061550625733, 0.10798018332570791, 0.15080459788441658, 0.08530369228018181, 0.2059938000249011, 0.15022267268172332, 0.14799204309071812, 0.14911159873008728, 0.23775438219308853, 0.21365916941847118, 0.17434733387614998, 0.13255819412214415, 0.16849338156836374, 0.15586237077202114, 0.14200023960854324, 0.15383104048669338, 0.12764665910175868, 0.13947712071239948, 0.1825741638562509, 0.13277191908231803, 0.09832388362182037, 0.07736729564411299, 0.13742746998156818, 0.08180892480803387, 0.1489251780190638, 0.09902457280882768, 0.1371737521673952, 0.05617352235796196, 0.09024882156934057, 0.13690035683768137, 0.1587030440568924, 0.15213078100766453, 0.08336306177079678, 0.10108482904200043, 0.1736365141613143, 0.13522870439503873, 0.14657921104558877, 0.14054299066109316, 0.15347563741462572, 0.1301209099058594, 0.19777874941272394, 0.21286368210400852, 0.1660588522042547, 0.09474513387041432, 0.12080315846417632, 0.10978783454213824, 0.29389881236212595, 0.1153255081070321, 0.11548363390777792, 0.0759997150993773, 0.134001207404903, 0.08023572779659714, 0.15711514997695172, 0.14855876910899365, 0.13951950200966426, 0.1561989648533719, 0.1032920288188117, 0.137185789378626, 0.1424845371927534, 0.08495204150676727, 0.0942426108356033, 0.1812990472785064, 0.12931182474962302, 0.14531370252370834, 0.10122565219977073, 0.0896208170535309, 0.07987029597695385, 0.26663451535361155, 0.17960747304771627, 0.15790147706866264, 0.0789675662027938, 0.10060267562844924, 0.06015388680888074, 0.08303500365998064, 0.07281913648226432, 0.15075672045350075, 0.1671730609876769, 0.1236747322337968, 0.1232355572283268, 0.08938988444528409, 0.08295731818569557, 0.11869378308100359, 0.13211048314613955, 0.10343667891408716, 0.25824806679572376, 0.12541574452604565, 0.11606802897793905, 0.15061718651226588, 0.18188645504415035, 0.09885954630694219, 0.11777359460081373, 0.17390872884009564, 0.12500296453280108, 0.10878770785140139, 0.1037236178027732, 0.08824059540139777, 0.12448792931224618, 0.13202745760125773, 0.15507745503314904, 0.13408225162753037, 0.14997396245598793, 0.1327767502516508, 0.11294885778001376, 0.12590694959674562, 0.14929968863725662], [0.04728580605504768, 0.035546576870339255, 0.029950328769960573, 0.013695688219740987, 0.1076655669936112, 0.06552994011768273, 0.04779233244646873, 0.04194463283887931, 0.09349078724959067, 0.003881980265889849, 0.015875366616195867, 0.04764811661360519, 0.045491308239953857, 0.033008781261742115, 0.05789068753698042, 0.054039553473038335, 0.060082945972681046, 0.009066523002859737, 0.05789642794323819, 0.012134950807584184, 0.05290986391316567, 0.0620830093643495, 0.04377310150968177, 0.014319272079904164, 0.06164094379970005, 0.018404332787862847, 0.04088003853602069, 0.016133822301136594, 0.020956045149692466, 0.027337636466005018, 0.03879664086603692, 0.016088384203612804, 0.03327573050877877, 0.025524738477542996, 0.02597456139379314, 0.03259805722960404, 0.04723089221598847, 0.032198444208396335, 0.041277704161724875, 0.025939330159287368, 0.042198506716106615, 0.040136540574686866, 0.10345649892198187, 0.009248461141916258, 0.0398846548050642, 0.07189343151237283, 0.03962914565844195, 0.10528981233281748, 0.02959291384156261, 0.05023655807599425, 0.03606463157172714, 0.004281988533745919, 0.05508526075365288, 0.032188398497445245, 0.04367822874337435, 0.03952533319326384, 0.046541269935135327, 0.018755629026730145, 0.02401109648469303, 0.017119150143116713, 0.032924368112747154, 0.00910709600429982, 0.026444599564586366, 0.06102893913963011, 0.004896653051088963, 0.01832539202379329, 0.008948876904988927, 0.011419640887262566, 0.03771259296419365, 0.025055752036028674, 0.036513947283050845, 0.04297862521239689, 0.0358200604096055, 0.01974883126760168, 0.07540571875870228, 0.10546308982052974, 0.040160971228033304, 0.0565261298657528, 0.08241337058799607, 0.09051509906670877, 0.08368251605757646, 0.024711583807532276, 0.03464276483282447, 0.039119742278541834, 0.040558565607560534, 0.0032657629635650665, 0.04444429477942841, 0.0797614793160132, 0.020810923472579037, 0.018197803691561733, 0.016073476789253097, 0.03025541847039546, 0.0344872174651495, 0.02699342922174505, 0.06398726361138479, 0.016859903964879255, 0.015397945984399744, 0.030019810755870173, 0.06337489932775497, 0.023083323679332222, 0.05208018182643822, 0.027281450373785834, 0.008792103085267757, 0.01695518215586032, 0.07005156856030226, 0.04823037090578249, 0.024646218832848326, 0.038050754461437464, 0.0641644358901041, 0.04306021565571427, 0.027626889159104655, 0.009039183978789618, 0.02963499997609428, 0.02129790635912546, 0.056849618043218336, 0.009206801636277564, 0.02046003774739802, 0.0420039266214839, 0.011763935492906188, 0.030444071561630284, 0.03688199146251593, 0.0611632890733225, 0.031536641863307784, 0.08572802772479397, 0.0050904218722800055, 0.029809451329388788, 0.020972631938223327, 0.013334882312587329, 0.03182856798438089, 0.01661323952222509, 0.04117209357874734, 0.012156533310189843, 0.03153436877099531, 0.039482449780085256, 0.02098783621165369, 0.02128841874322721, 0.012349001464567013, 0.07977287870432649, 0.06341331119516067, 0.027896579687616656, 0.02635388112893062, 0.05265561344900301, 0.037495868879237344, 0.05788099127156394, 0.05398364558017679, 0.01822145402963672, 0.029030567766832452, 0.04763902085168021, 0.03180447320586868, 0.029577219326581274, 0.04014729196205735, 0.02282426749089999, 0.10514750318335635, 0.07490032552076237, 0.05346815234848431, 0.03955001151189208, 0.056271553704781194, 0.03936802841989057, 0.018457960803061724, 0.02390542483356382, 0.020746625494211912, 0.025117220523368036, 0.03197750642097422, 0.030242142932755605, 0.052651616877743175, 0.05694071815482207, 0.0347461667843163, 0.012371893539758665, 0.015101668757519551, 0.014226271222079439, 0.02009781200571784, 0.05135060740368707, 0.008318632375448942, 0.056140698226434846, 0.04378368665597268, 0.046247881571097035, 0.0021687946947557585, 0.044266294687986374, 0.03754779037886432, 0.020212243543937802, 0.07820318293358598, 0.03435526276007295, 0.06310091367257492, 0.05460163152643612, 0.026459466266844953, 0.0072952997870743275, 0.010916427443070071, 0.021990515890398195, 0.047514658953462324, 0.10061387145625693, 0.060114206080990176, 0.03029136047033327, 0.08363588034574475, 0.044595380779355764, 0.04418155584218247, 0.01654988301119634, 0.06811000845794167, 0.05082451545500329, 0.046886125180338106, 0.03838956056694899, 0.0165198815853468, 0.06184811411159379, 0.05906928250832217, 0.054548264747219424, 0.01165796274186245, 0.008013556245714426, 0.03143386077135801, 0.009956018799649817, 0.02323783967377884, 0.03919995529577136, 0.03622692697016256, 0.04599844870556678, 0.07036582526883908, 0.107887766856168, 0.041321330570748875, 0.0077907830210668695, 0.03961261993806277, 0.04645597129794104, 0.052936082506286244, 0.027217450950826918, 0.02088689394960446, 0.057316877613110204, 0.03229898952745965, 0.08585230819880962, 0.006821466061020536, 0.10462177425090756, 0.04541201124499951, 0.02645860961638391, 0.025811283815918223, 0.024621128304196254, 0.03486200628269996, 0.028084523709756986, 0.08017737378499337, 0.0012845685705542564, 0.048319279349276, 0.019447750012789453, 0.03614237132881369, 0.053331410578851185, 0.03870869254959481, 0.018449362068037902, 0.07758459648383514, 0.03906183270737529, 0.012193103803188672, 0.029992374192391123, 0.03561415556552155, 0.06712848719741617, 0.03855414262839726, 0.0382149022604738, 0.06071234827062913, 0.01765414107857006, 0.03322868767593588, 0.03202860689322863, 0.0372500967101327, 0.03548603119062526, 0.010059028048999608, 0.07766372045235974, 0.044867164588400295, 0.0023501321182785822, 0.009356151434725948, 0.04033581613163863, 0.021148258853437643, 0.01736513096173959, 0.020414701430127025, 0.027723909488746097, 0.028610775114170144, 0.021971111485202397, 0.05448856045092855, 0.056005103180983236, 0.011437040221478258, 0.01348523295018822, 0.04181909028972898, 0.02690660218442125, 0.05787288277809109, 0.02511563614409949, 0.0036136518964277847, 0.03104118916339108, 0.019771575761426772, 0.011836878007410892, 0.042426647152751684, 0.07528534664639405, 0.0469669081669833, 0.03040896076709032, 0.0186386037884014, 0.033213424030691385, 0.046186813419418674, 0.03437975787424615, 0.061057607244168005, 0.04566586815885135, 0.0549440779723227, 0.022403887905446545, 0.026923368784732053, 0.06317513861826488, 0.027076661719807556, 0.011565377486736646, 0.045531959272921085, 0.05848362536302634, 0.02615154198636966, 0.054460791405290365, 0.0064109748512107345, 0.053406392091086934, 0.031317749858966897, 0.019543728791177273, 0.026666297311229364, 0.04461914646838393, 0.01812878141312727, 0.035900585552943606, 0.06627589437578406, 0.021531463201556886, 0.021128413400479724, 0.03816031072554844, 0.02390167592758579, 0.07844371681234666, 0.03032274610762085, 0.0645018442134772, 0.03857750798176442, 0.03397687092157347, 0.024041262455284595, 0.04378340506393995, 0.009168565339807953, 0.04847323215965714, 0.05027469852939248, 0.07691592057900769, 0.03480219002813101, 0.010153838050817805, 0.06931114436260291, 0.05757426630173411, 0.009245213503683252, 0.023207173283611025, 0.10220171803874628, 0.05780128376292331, 0.04782042379624077, 0.031174039534692253, 0.05046349072030612, 0.023751404169680815, 0.030128939542919397, 0.026980650711006353, 0.031148750534547225, 0.028035794717392752, 0.07095787421401058, 0.03057215522442545, 0.0541219513730279, 0.020632646878116896, 0.07499375979283027, 0.018225467564272027, 0.043041922351611514, 0.024794892640784383, 0.029741723356502395, 0.06258919648826122, 0.0865411094522902, 0.010657175327651203, 0.021337045955338647, 0.07731438348335878, 0.13521991058119706, 0.12297870458236762, 0.11943876024867807, 0.09610169500644718, 0.12671401271862642, 0.22187055594154767, 0.22471274914486067, 0.151425498138581, 0.1432862670293876, 0.052705495950898955, 0.12705010468406336, 0.07805372881037848, 0.1724432831896203, 0.19836686285478727, 0.11514303646981716, 0.11748495937458106, 0.1332925454314266, 0.10949748262230839, 0.1946942920663527, 0.11629157912518297, 0.15821994069431508, 0.1503788578723158, 0.08431520925036498, 0.09736716281622648, 0.10043092484452895, 0.09306146457259144, 0.11786383975829397, 0.11400977442307131, 0.09031307883560658, 0.0777920585657869, 0.09620397737515823, 0.1395470912435225, 0.08822553192398377, 0.1960347787077938, 0.10766052547842264, 0.14317820354231767, 0.1634114256926945, 0.24310221523046494, 0.12307215242513589, 0.0756961317466838, 0.1546903643757105, 0.10669683611818723, 0.19436820170709065, 0.12533110406781944, 0.10699157137423754, 0.11117312485086066, 0.11121342983096838, 0.1850183555590255, 0.14474430307745934, 0.1945022123732737, 0.19101743293660028, 0.0665784463552492, 0.1922270166022437, 0.10269563046417066, 0.14273285386817797, 0.09181426292551415, 0.13818234018981457, 0.09714634716510773, 0.15552541028176034, 0.11271210334130696, 0.23182002348559244, 0.0626847885016884, 0.1020798667200974, 0.13137660681137017, 0.15790108351835183, 0.13465836857046398, 0.04591559957978981, 0.0805481049631323, 0.12807144916483335, 0.12910094963652746, 0.10948684319321599, 0.16379638575017452, 0.23428055431161607, 0.06792061576353652, 0.14930077429328645, 0.18802855403295585, 0.13269379256027086, 0.13240451951112064, 0.17275038813906057, 0.24572616443037987, 0.2014614710850375, 0.08953680763287203, 0.19551036613328115, 0.23529024156076567, 0.17295757202165468, 0.11013272032141685, 0.1253492616649185, 0.11130519490689039, 0.08158010244369507, 0.07372095701949936, 0.15347442962229252, 0.13095360808074474, 0.13119220813470228, 0.11371837077396256, 0.23480514330523355, 0.12837987047220978, 0.1719222225780998, 0.13311383287821496, 0.14045892017228262, 0.08253970023776803, 0.10208266906972442, 0.12043715667511735, 0.20031239917235716, 0.1926740761846304, 0.12551721265273436, 0.2119748555123806, 0.10893722304276057, 0.16491500501121792, 0.11088789587042161, 0.14277185606104986, 0.11792626498000962, 0.11190854146012238, 0.07368890302521841, 0.10360138650451388, 0.15743054662431988, 0.1292466718171324, 0.08919582342995064, 0.10033060344202177, 0.07549313442515475, 0.13845500270170824, 0.08683819922485522, 0.2275725571172578, 0.11014441147978817, 0.126192409279091, 0.09492151904851198, 0.18111880123615265, 0.08585969065981251, 0.07080850151500531, 0.11150314392788069, 0.12626243409301552, 0.14429988978164537, 0.11193167271890811, 0.11270426626184157, 0.16533353898142064, 0.1010602932157261, 0.19697483469332966, 0.09195868231888328, 0.17084854947669165, 0.1038651398516127, 0.12118843064776488, 0.08419105091265269, 0.15199316053518228, 0.1110379538897957, 0.08990101130413157, 0.13183661284191267, 0.17000418049948557, 0.11779750617487089, 0.12135423746492181, 0.15645858592220716, 0.09575100775275912, 0.12745133601129055, 0.12969607913068362, 0.21504087027694496, 0.2694628121597426, 0.159295242279768, 0.09373230500412838, 0.1774490802947964, 0.13203968480229378, 0.1350522581487894, 0.08702087442257575, 0.08142903340714318, 0.13722749214087213, 0.1894017324915954, 0.11826256050595216, 0.11130050622991153, 0.07860697912318365, 0.1597131655684539, 0.16876038509820188, 0.13413192039089544, 0.08231935277581215, 0.07544348601784025, 0.1881186363420316, 0.13067367167345115, 0.07579529963965927, 0.12063003703951836, 0.16053784345941885], [0.03149327329759087, 0.022512246555249606, 0.03831964431862746, 0.03472696763596364, 0.02443864818529359, 0.0353404718584248, 0.012642144707829824, 0.006975938374775329, 0.030687414575368166, 0.02202562498860061, 0.01733560111772801, 0.04436018018584166, 0.009860165550240448, 0.06211289204657078, 0.01602070203184017, 0.006929318354065929, 0.030500016773917844, 0.033123531711420844, 0.016443961998447776, 0.040583763005478043, 0.034522277369563065, 0.0037895803356410135, 0.060736191991184435, 0.04275593001927648, 0.08554809380854879, 0.02174483871619616, 0.09478509279766253, 0.0708881818822452, 0.042680286935397556, 0.013338989145787699, 0.02595043777754264, 0.10556792348091092, 0.017631232040002942, 0.06012508299733911, 0.03301711706444621, 0.050423972840820036, 0.06405404502792017, 0.062122371180781295, 0.05765530373901129, 0.0565236667836351, 0.008635229181631334, 0.024157407294426645, 0.04357534247849669, 0.023269807154844915, 0.033579303683446984, 0.024955198235277618, 0.045283537424568615, 0.01549103929262076, 0.04389289686722415, 0.012581270786800554, 0.013137616915628314, 0.060394427472991605, 0.05868001375347376, 0.08399749879858323, 0.03504012172509517, 0.07196271672312703, 0.0691212834790349, 0.025315617377470647, 0.07010965794324875, 0.02727045301747109, 0.1344667909932988, 0.03479235805571079, 0.050472464345927746, 0.03723794075527361, 0.060618316887744834, 0.02318490037162389, 0.017076244677550027, 0.016165652378861393, 0.026616050096760904, 0.1041116380531873, 0.04349609637366874, 0.022312718244003396, 0.037575511927051206, 0.018122576210381727, 0.01398687728215009, 0.08262201332088027, 0.0099158155997949, 0.010093222821264394, 0.021282812347635627, 0.04176676506176591, 0.059250417431550365, 0.027538264003981437, 0.025612221997497336, 0.017377488780766726, 0.05675283859350851, 0.011833973029362304, 0.03273826292050736, 0.032353116265897236, 0.04780474963730999, 0.05214426267359938, 0.038902644999325275, 0.013949474735584642, 0.025499437603035142, 0.03866684729499476, 0.014187635438117598, 0.052095537073910236, 0.0349603327922523, 0.03709860358919416, 0.05938678939959832, 0.05513536038675478, 0.06356213428080082, 0.034904455433466604, 0.04616989414872868, 0.01824343347522829, 0.009534350845829716, 0.016389019321650267, 0.011990972461977174, 0.03756274189800024, 0.017536983525912677, 0.04302523039015276, 0.03261973303077476, 0.028952621056565216, 0.02714590452212308, 0.022067697552431906, 0.07349328137934208, 0.015419893199577928, 0.023768374330497215, 0.04747168733073132, 0.012652108146409904, 0.047972195116536956, 0.03281447258112686, 0.06477763477180686, 0.05857985519937106, 0.021696577912994792, 0.01934636161396546, 0.021410549957571284, 0.009447278687730432, 0.05312114953994751, 0.022239548420267444, 0.07131496683827468, 0.027409886874790703, 0.031246778488691365, 0.004742205334228596, 0.018634373122560124, 0.055771239301455874, 0.05415660754910537, 0.035715355670877864, 0.02068207985056298, 0.034892879626048465, 0.015578254791242736, 0.025540312552558522, 0.026048392789172273, 0.037017291345234425, 0.017305988153176646, 0.028281456624556865, 0.048560959952218194, 0.0938679984371577, 0.006669391520387892, 0.04228960682771035, 0.03323482163250446, 0.0513502376021019, 0.020655052104432668, 0.0677981741194214, 0.028220641227172952, 0.023524227252762233, 0.019142198908541883, 0.09210162929126195, 0.024372099167002097, 0.0027815996020633194, 0.02998096462605255, 0.038626108052475114, 0.02833488447192524, 0.03859866809632097, 0.016843183165682212, 0.03644692498658385, 0.028630418702960014, 0.01394065547667976, 0.038972948012607436, 0.041353113151022365, 0.048697745826627524, 0.04131361562758684, 0.03290397135008659, 0.03140440895887358, 0.04095985121758921, 0.05606171675026417, 0.02557580841572157, 0.034285475433404954, 0.04686702781223825, 0.06605231030178921, 0.029441464825400283, 0.04561626046363797, 0.0531458549999765, 0.015535478247329593, 0.04754430414842708, 0.046642456469791274, 0.036954357222254784, 0.07730480935424566, 0.016949959132554274, 0.026810940621154647, 0.050435647035815885, 0.032285113486328294, 0.03998446391363229, 0.017602433317473958, 0.018810904185686792, 0.04035827564075589, 0.05964502625699554, 0.06884123172078814, 0.026219811090933423, 0.034039119724184275, 0.046020881073283296, 0.007258588498059128, 0.040850118534373384, 0.013383714781541909, 0.03668552504054137, 0.02834333053656987, 0.03648299590817519, 0.021453126333653927, 0.03219309395977429, 0.02624742916252996, 0.052143930191440244, 0.08266136835196189, 0.045983293625925264, 0.05445417908153363, 0.050753808713385036, 0.06537262177360909, 0.017101360651265298, 0.059900040073054175, 0.011596828433019775, 0.02747881076564746, 0.040437138373298306, 0.013961455119507653, 0.016634940768459013, 0.10891723340111119, 0.022163756058684418, 0.011287836308058883, 0.04077847541442939, 0.016793446548815285, 0.06183225674820798, 0.0018331450493341045, 0.1435245413865362, 0.010024175945935505, 0.023211285205824033, 0.028573245342288698, 0.04213624434279544, 0.026357428170740604, 0.014903304133830326, 0.03167616223384227, 0.025133230557133044, 0.038976612101708136, 0.029131625379834856, 0.027529553310679536, 0.0464307365805975, 0.04848915398386972, 0.0630775788532836, 0.05562865873798728, 0.02980142765279327, 0.06594789054776941, 0.03576425429699676, 0.013029565302921193, 0.012183386333552855, 0.03752406540193728, 0.021507541449474435, 0.005054412442924721, 0.03900121578148433, 0.018156752322933505, 0.05156081755246435, 0.07695955716605697, 0.07026323755936963, 0.02731622359715402, 0.0577583664229938, 0.038236649307821474, 0.05338987654873303, 0.016872813093609045, 0.014327507798693009, 0.02525642198244376, 0.021893809383202876, 0.03356801625341177, 0.0442619113517659, 0.055296929752720256, 0.03175996130864535, 0.03701235500297376, 0.016637264750897884, 0.027916520135477185, 0.020067756297066808, 0.02782653451764158, 0.05281014979950019, 0.025072142049404125, 0.014435254070641739, 0.014970648734431182, 0.0988723366920437, 0.04259939877582448, 0.039084611127951314, 0.021268498651417236, 0.061341024536107264, 0.14046457915433816, 0.030116118623742034, 0.04303214466199279, 0.0663137227030737, 0.043832710811070034, 0.01849181461147964, 0.063572984055749, 0.01848871709911951, 0.045417151147765775, 0.007780399738944003, 0.028359379586098448, 0.017099182553855435, 0.02750900896665241, 0.0404463291301259, 0.07571900516216244, 0.013881583066125, 0.04806811961212328, 0.03591252098392163, 0.09574904000120503, 0.011123037963573421, 0.05569057845111404, 0.04867450939491391, 0.02563575019926897, 0.016719752556777427, 0.02881224573190723, 0.010260136498670493, 0.014170046962265457, 0.02188379759900272, 0.024927076351429735, 0.051653098315000534, 0.08415517676621675, 0.05245968646236828, 0.020936611906758378, 0.04136202231581722, 0.01840446679852903, 0.04823691537603736, 0.018849553540349007, 0.04531168984249234, 0.056125373513038666, 0.023654097158993994, 0.08608311188540288, 0.027894196333363652, 0.07035937918616192, 0.011615264229476452, 0.03795445337891579, 0.01595253131485411, 0.043278049145426066, 0.015934441571256945, 0.043624997671161375, 0.05593613348901272, 0.04551985760086349, 0.028261595904561024, 0.027747512329369783, 0.03494348816041436, 0.021448583541704074, 0.03332633225779448, 0.0753739226077284, 0.05579733575827309, 0.034363924259585996, 0.003884234274404922, 0.014813847773309265, 0.014318769963990365, 0.019856879487633705, 0.03688515343570283, 0.017365037663174526, 0.024752204306423664, 0.044534543329583745, 0.034692314852561267, 0.09260115998664073, 0.11285384252135243, 0.1423615730766739, 0.1185012555548123, 0.0579754908436111, 0.08453234724168267, 0.044724726517285616, 0.08570630781884704, 0.12296887939529759, 0.10561904430921588, 0.14040769077837467, 0.13782179382230553, 0.12553746013769082, 0.1287096927740744, 0.09998672867992095, 0.07957167950059686, 0.07594209390559367, 0.14640922445271695, 0.08015148088868175, 0.26829603048307554, 0.11900113230305058, 0.07344200448798281, 0.16482014581561089, 0.1672254574618169, 0.11569799669086933, 0.09041893029851572, 0.15745250401752336, 0.11696121176438672, 0.1513245321278061, 0.13440570927092008, 0.11616667439895016, 0.12935792441879, 0.08800080791115761, 0.1168710073190076, 0.18367439481828893, 0.19039980322122574, 0.15889333241752215, 0.1189438910888774, 0.12577276251145772, 0.10364855825901031, 0.16885828413069248, 0.12022590158241135, 0.0875659483884062, 0.10715678786592824, 0.12032646047217505, 0.09172919499022619, 0.3042212298938206, 0.10498715857309954, 0.07839784105973584, 0.06443876759814364, 0.06159985850432089, 0.20345288994056837, 0.14242090417870454, 0.23797908584986413, 0.05532638156520469, 0.13110797479748726, 0.08680741409105913, 0.07922461562390838, 0.3028963766992092, 0.14093180479747908, 0.27890929526516367, 0.08068238025797264, 0.09740104885505778, 0.15521826462021895, 0.11053958348929882, 0.13379858327763422, 0.15576145904404776, 0.131633920861142, 0.11137855132775647, 0.20218445014740738, 0.1172366834112576, 0.17109118002865994, 0.0858591953292489, 0.07888087656881128, 0.11316170743001358, 0.13643231695251806, 0.08925358711608819, 0.11122965360326426, 0.12798207253217697, 0.16034820649240697, 0.1962508921112333, 0.1074707799458078, 0.15695553139916488, 0.09595758095383644, 0.1673375243054969, 0.18284803416047776, 0.0604348410187023, 0.1044790240536843, 0.1443195944385869, 0.13108774088323116, 0.08919473098857061, 0.11219081881323031, 0.14138431980141572, 0.13157076282160624, 0.10551473990614925, 0.09013384381043059, 0.09395093577248709, 0.13123062678745814, 0.15392583182879857, 0.09951706031071288, 0.14578361516552313, 0.14481928119701998, 0.14009487256407738, 0.1058458514245493, 0.1473810901599271, 0.10903860974524703, 0.14507764019072056, 0.13616554412458623, 0.2167847188455718, 0.17975920704858644, 0.09565465578011104, 0.07667677769703524, 0.1501102801412344, 0.09804119236235108, 0.08052551653236151, 0.1252603328653744, 0.14148417301476002, 0.0996919119996684, 0.10047044272401504, 0.1682962400040456, 0.09260369092226028, 0.11006306870175259, 0.22415120713412762, 0.07738860164369855, 0.13775356034083025, 0.1330657247453928, 0.1619283924145358, 0.1091058389948947, 0.1029809680102127, 0.17620540702981607, 0.09472443176699535, 0.08334957927997623, 0.13685291366917746, 0.15229751063244684, 0.11845189891755581, 0.12764228933623858, 0.07874716445803642, 0.15607297447110924, 0.19935280137828418, 0.11359961357499872, 0.18125756164746626, 0.0677440134542329, 0.1836758740246296, 0.11688030324876308, 0.06888364694480385, 0.17140163694109234, 0.1577344217470714, 0.0687307051516005, 0.13976506383291312, 0.10605019224541527, 0.13490383539881023, 0.08627876067267996, 0.12348854222467967, 0.122392545321158, 0.07925751100161246, 0.026502912864089012, 0.16327509443674768, 0.08866425231099129, 0.07667236721941403, 0.10320895577647857, 0.14421507290431432, 0.21233404480985232, 0.14168767923755304, 0.1047578069514462, 0.1328240441424506, 0.0950094096894775, 0.11782533968133585, 0.10979141042168651, 0.11727126155580793, 0.08742541021534375, 0.16361338485564503, 0.1420950580920492, 0.10890840566051857, 0.19263728601591928, 0.11211153199630124, 0.11454253297831331], [0.044756190186100345, 0.07099599431135825, 0.029640214517712593, 0.05339701134445412, 0.05389644704493029, 0.02441620733588934, 0.025528857185106193, 0.015194290483902608, 0.004417483919366662, 0.047696893103420734, 0.040046461658286195, 0.043951356051755805, 0.04287300784406917, 0.02597057500055858, 0.048876407489712746, 0.054911508291427574, 0.04895547039008566, 0.006473570554849825, 0.03295029493580971, 0.023563675582408905, 0.06405931045966488, 0.0616927295923233, 0.02109630173072219, 0.05009332611890776, 0.02492084400728345, 0.054766376436288865, 0.03634243059371199, 0.03170542744919658, 0.05367731076798268, 0.043483716502253494, 0.04556407433535371, 0.034294482985777516, 0.018505894213116596, 0.020090414277677025, 0.06274784476097141, 0.04726683760860136, 0.028006307281819836, 0.042383845163775344, 0.07810418467436518, 0.06572923942336015, 0.02836036346187549, 0.023897628466199552, 0.024150189378165772, 0.04474642945985709, 0.0139311839759882, 0.012918130344977337, 0.05461757370669927, 0.04329127040026443, 0.028819801219339882, 0.016881995368748903, 0.03971405074532543, 0.023297649142997603, 0.020608918508514762, 0.012991037236393561, 0.04427051517580237, 0.010427438637374766, 0.08742350353194134, 0.020602148425366198, 0.05902515059070928, 0.014216642810164817, 0.07634481122451169, 0.05776992187436138, 0.04064587610108512, 0.016114297455974987, 0.07082704587706498, 0.03497131148885403, 0.014902992007721747, 0.02677924625043358, 0.008341311560278493, 0.06601268385670014, 0.021594061449702297, 0.016979131049343517, 0.10681424303246395, 0.02843338231156979, 0.0487462067976594, 0.029406347245510136, 0.015551903883793523, 0.04394945615370359, 0.11071997880935669, 0.03143114323860832, 0.02421133895404637, 0.03245323071522372, 0.039602591190487146, 0.06461116977568183, 0.027518315074433173, 0.03674408261265073, 0.031670289513255866, 0.032940157622631104, 0.032384976877697876, 0.023355835217184255, 0.05077231914869376, 0.03264504577964544, 0.00676913107911657, 0.032063073079500876, 0.026438306152288402, 0.05889985231416566, 0.07359087507107429, 0.03414659627846309, 0.03536042418064816, 0.08895015982644898, 0.03197027323767543, 0.09077638254633971, 0.05121391313150525, 0.01655834773555398, 0.013067682007593768, 0.04878319034885083, 0.017213917736496245, 0.04488407368106501, 0.04434788173862866, 0.045131243632308075, 0.02754304767586291, 0.03370625080008592, 0.03492640604131988, 0.07664690180016415, 0.038709995336830616, 0.032750615650521855, 0.05566638867769923, 0.025968893930049877, 0.03836391194324408, 0.05620635327483926, 0.07256851278777633, 0.008826406423135527, 0.03626484011432954, 0.07785443629005126, 0.009744700942454594, 0.0337461724079081, 0.036008560830461125, 0.01111079634366823, 0.030076471822602407, 0.013701705129018851, 0.017332123625757437, 0.043441498053393195, 0.05050749032359038, 0.03952637813719256, 0.007812438466187034, 0.03203142959890621, 0.012035772736583437, 0.05572652045105185, 0.058774872949080806, 0.025060968273984532, 0.01109036141341286, 0.0663774778534259, 0.06841759516724519, 0.0198189290240407, 0.05298456383336868, 0.0577540984377265, 0.0010423195885128475, 0.009591095033101737, 0.06988475751131773, 0.027119531562285762, 0.06655528795506273, 0.023023134230503013, 0.020853849294196283, 0.04538307172645416, 0.038174186766679795, 0.0550885143290673, 0.0677611328927534, 0.025358280266768167, 0.04351850838533469, 0.017908279584454637, 0.01246975694916078, 0.05525454506278038, 0.03646678231390459, 0.03077865039397563, 0.03463740101350205, 0.01601631530294461, 0.06637383412037577, 0.02673151470454676, 0.044205101007329564, 0.07442531708095755, 0.03497886358361159, 0.08821318258664437, 0.02405794254238052, 0.0458857847510704, 0.05295122401522739, 0.035298273765615056, 0.011923505725072963, 0.027347653339217817, 0.024533144364665662, 0.016848879467163767, 0.02611098255562995, 0.05969759236489024, 0.0336580137456102, 0.05164900335616299, 0.054813351415629895, 0.042209227569401264, 0.01377454077425812, 0.011041926735612963, 0.02553557637812836, 0.015800775261595845, 0.06086210773459502, 0.06076279056391545, 0.034768419340252876, 0.06228421535342932, 0.015915518925924386, 0.05063945520669222, 0.01897607317992619, 0.040508445618408065, 0.03486782472048487, 0.04598517656060202, 0.0427780604389097, 0.04271854952509914, 0.03645371372944542, 0.06464442477694579, 0.0412205579424543, 0.010447440153386976, 0.06404960062354803, 0.025793234784422175, 0.019365845747025948, 0.04593889029430492, 0.019913998565503528, 0.03490369547424572, 0.051220111548900604, 0.020582888208861862, 0.011991988568167602, 0.011744374176487327, 0.028125223936513066, 0.009567674548764313, 0.024904167312862616, 0.03598439819844706, 0.07203804089554719, 0.016498553533373133, 0.026776498183608055, 0.02426764548623136, 0.014359463405396258, 0.05650390784389206, 0.03895796935207077, 0.013684307491140706, 0.025715018356485025, 0.053490862915558476, 0.016963655361905694, 0.013596558494360318, 0.0465151293735419, 0.027250410789357762, 0.02348707406781614, 0.03289048546659095, 0.018892150272482207, 0.008336953669121223, 0.04281975641580565, 0.016605767155332223, 0.028200675334249223, 0.0010608708419437918, 0.041618386416562965, 0.020320877000423412, 0.0166296244465879, 0.03658669302240014, 0.006940150317469878, 0.016040048761559383, 0.050287441417042694, 0.03512020582067115, 0.019707267605034367, 0.04605125569339309, 0.05282553558104804, 0.061215013797794066, 0.04132313208122339, 0.08155329352510826, 0.022050072605322515, 0.024583255872130394, 0.0391044480992215, 0.010698373429477215, 0.032620635482349565, 0.05583611742726394, 0.04941775969096592, 0.055010476016572545, 0.030030884447374513, 0.050891062776957235, 0.012519921043089457, 0.010567235510929354, 0.030956243364406482, 0.04148235371602433, 0.06788274672414575, 0.04572084306606224, 0.004966091780391122, 0.008031768973783722, 0.034612318966537714, 0.0582275123202375, 0.02484661397258086, 0.07077853062323161, 0.025016734576118842, 0.014318213565275073, 0.08276069909334183, 0.03405716536300523, 0.0436955212083246, 0.04146415201414909, 0.03600699680724314, 0.004456984411392893, 0.059332038408943584, 0.08915680766637836, 0.0314730767027608, 0.07513693068176508, 0.0233602032863668, 0.023482453244339143, 0.08074080890842847, 0.028113169761906778, 0.005052245371708912, 0.012619830235572798, 0.03488907304459384, 0.02177445507342262, 0.015384550006794078, 0.024160199466028383, 0.009306001759666418, 0.09862664594714131, 0.02566430125651615, 0.030930374216820513, 0.029289751180580685, 0.017475679583315338, 0.042006922353591235, 0.041519269413713894, 0.020699060189404657, 0.02963360897930605, 0.018140162141727548, 0.03933732810297182, 0.03874777616666896, 0.0324445556450103, 0.04519390294860516, 0.09573597141674586, 0.04759480750986508, 0.009935272591454642, 0.04850383408899818, 0.07051143209849085, 0.04173484677448869, 0.03603785318721618, 0.030450853519141674, 0.028138049944703068, 0.06829450212951217, 0.06787788841341223, 0.1047413864039949, 0.01975165736595435, 0.029988191024001156, 0.031359554401465824, 0.042899613202150376, 0.018779264097767215, 0.04377420412908707, 0.014699672382058842, 0.07599074486643076, 0.07536255036081586, 0.004974659981339106, 0.056107019140784226, 0.1440764753414052, 0.014907538192346692, 0.05337345600128174, 0.04407056447650705, 0.051255710888653994, 0.025372208894363472, 0.01736732602252492, 0.0233611091306167, 0.051107064222118685, 0.07944457632090364, 0.03149070504254528, 0.07341879180499486, 0.02784323496078806, 0.022306613125173107, 0.15635410510003567, 0.23288744049412863, 0.12721443229487964, 0.10602336975612811, 0.2270928600004741, 0.18253465954746517, 0.11544897433902536, 0.10126093602074043, 0.13845135218330792, 0.09785146718578679, 0.10574813559651375, 0.17537836783698627, 0.24944567627140454, 0.0936069388740829, 0.11846362400267806, 0.2061645465769938, 0.09664985630661249, 0.18002611558352197, 0.13690311168985708, 0.07114805400903736, 0.09739797509142331, 0.14794208934264524, 0.14456845394202641, 0.19025489528264317, 0.15808085458619253, 0.1565460626568113, 0.12332715945584433, 0.1408670318445989, 0.13452699062015328, 0.1458436655146735, 0.08951007335313729, 0.13731475174427032, 0.057493866687374454, 0.1766047113175903, 0.17601133244378225, 0.10491194975163255, 0.07552171432014022, 0.14349737284438951, 0.1721586241785969, 0.09341411279248339, 0.10456918100161211, 0.12019026492323194, 0.11456183051424366, 0.10434677079319954, 0.09905239274459225, 0.06761941406875849, 0.0981364179668682, 0.12255057612700121, 0.13608616909810475, 0.24071993306279182, 0.11685351468622684, 0.06730454667870488, 0.1314032460962023, 0.10210976975836925, 0.10427373328379222, 0.08894038213683025, 0.1569678671658039, 0.10535197292587586, 0.1267188846000603, 0.11975541897118092, 0.1744632005159344, 0.10632256977260113, 0.08550152595021895, 0.10184744812015976, 0.31074132717081476, 0.09262270347348281, 0.13205815452550138, 0.12548591861767427, 0.13738618791103363, 0.10602163949183055, 0.07176646403968334, 0.0665519427774208, 0.19266406100775513, 0.13673354578869684, 0.1098507618797677, 0.14280494142855915, 0.12717593221792153, 0.09926250111311674, 0.18798098872814858, 0.16220522113144398, 0.0984508850212608, 0.16417464188167027, 0.12525814798261437, 0.14033651245491846, 0.1423283384314605, 0.12623667690370763, 0.10216477859233107, 0.3281258557524, 0.14302915654012135, 0.17199258665953363, 0.06731034815311432, 0.14179095226739133, 0.10699795638876301, 0.09574934534196343, 0.12400152826947825, 0.13106454855629376, 0.15400040282734803, 0.09186526161751576, 0.11510121157126767, 0.21752850179161343, 0.12336434317486626, 0.26556945964694023, 0.13728736607091768, 0.09865048288234643, 0.19405298147882732, 0.11278033682278224, 0.08933482132852077, 0.13068884371646813, 0.1661163784031357, 0.13002807274460793, 0.139705787013684, 0.2038512307086161, 0.16411047961030686, 0.24237745840634617, 0.10215162858366966, 0.12634123915008136, 0.1087855976074934, 0.06565850893301622, 0.1213105669511216, 0.2112911364861897, 0.13365051336586475, 0.20283895145569528, 0.12700838835111686, 0.09293375749673162, 0.12875595529164585, 0.18459767741816385, 0.10759232592369829, 0.10505122584956032, 0.1291244812309742, 0.09466554171272687, 0.16221126009310993, 0.19490743348641054, 0.18180618435144424, 0.12918971558766706, 0.13988435028919152, 0.09715136153889553, 0.17124029488435813, 0.1294595825352839, 0.143675936119897, 0.16692880195166382, 0.1106668020199452, 0.1341561440910612, 0.17000114066260202, 0.11199713099215712, 0.15608693872179302, 0.12336278254432337, 0.09850377682596445, 0.11439504660665989, 0.27569265929715975, 0.12843409899090016, 0.12675190211406775, 0.15771295289908135, 0.08226483248706375, 0.12169079083417143, 0.10066586080938578, 0.08090352839125053, 0.15952979826501437, 0.07645391287016017, 0.16117512354893343, 0.0941017401803817, 0.09843707683363132, 0.14374659875673906, 0.2276048825255462, 0.17413921361523016, 0.144802399245756, 0.09630101466817514, 0.1810561181711299, 0.12106102891266346, 0.08279497868248395, 0.13658804073929787, 0.13232027260320528, 0.16726931796542235, 0.14316586777567863, 0.0854075692061867, 0.13939571008086205, 0.12235471020851817], [0.045152101798781326, 0.025016425842685357, 0.02166090902340199, 0.017532966598602276, 0.050006103834935596, 0.03634540596976876, 0.04305050242692232, 0.03190073696896434, 0.03145874265049185, 0.032953165138938596, 0.06455245614051819, 0.009911021749888147, 0.04273387423849531, 0.0800345353782177, 0.05340308762554612, 0.04552285672564592, 0.041975611355155706, 0.04601753928831645, 0.04323556606790849, 0.010666906367987394, 0.015844255785590837, 0.0640876189406429, 0.01062612047618521, 0.029935027805290053, 0.035827809279518466, 0.024344308068975806, 0.01855500657776637, 0.04381447857511895, 0.05884554237127304, 0.014554243667849472, 0.0860604623864804, 0.08314760654632534, 0.05769913710121598, 0.024170102684625556, 0.024454683664121797, 0.01837843989155122, 0.06733903661370277, 0.05652155653972711, 0.07495013677648135, 0.027090949970962744, 0.0190589273947158, 0.02633865819578724, 0.08118520863354206, 0.024564031278714538, 0.05677947448566556, 0.017330669864479984, 0.10951616269137178, 0.050552870745637586, 0.03324422273518784, 0.05360289243981242, 0.0259870074223727, 0.04255367908626795, 0.024926789670384357, 0.02447438153571316, 0.05001568474939891, 0.06058147922158241, 0.012356665517602648, 0.06845241758440222, 0.09646190210644688, 0.04316970406632338, 0.03641453851014376, 0.04632161797157355, 0.05294631142169237, 0.07183734380773135, 0.05375086735667927, 0.02177035332923489, 0.036198632059884925, 0.03887260286137462, 0.03602570741038237, 0.018372509495488236, 0.01944002658793969, 0.015229328335928065, 0.07799771574458905, 0.061084300811801634, 0.04837821011564561, 0.02220943333980228, 0.015990000018583875, 0.025167844324771847, 0.061790404708257744, 0.051751930333141766, 0.03941355472696679, 0.033950316453618665, 0.019452800009665743, 0.014539641594248158, 0.04722798130075846, 0.08682530027415071, 0.02169397403486073, 0.024551788810640574, 0.06072572898119688, 0.03797724537019219, 0.06322585911090885, 0.019556162945394005, 0.014852232499314206, 0.011642688918592674, 0.060506053268909454, 0.02253332524560392, 0.05248014768585563, 0.0761940475287182, 0.005713532454267676, 0.015540784391175424, 0.03446782832699163, 0.09517333017928259, 0.05829254990177495, 0.0660799266770482, 0.04800603026524186, 0.059841394291392395, 0.035089251053120406, 0.09884228437606778, 0.028723483173442737, 0.07949362761740174, 0.022918689031420008, 0.0560135068371892, 0.005645486418091292, 0.02987968988184418, 0.04873175060908709, 0.03144788609019347, 0.05126202804967761, 0.03522648476064205, 0.05450090300291777, 0.0703245499836547, 0.005691376589571259, 0.02872467060972537, 0.02530362766369113, 0.015698190944801484, 0.03814937952639801, 0.07933981051402432, 0.013579190542389239, 0.026453530781769326, 0.022774954958419715, 0.018973962936018194, 0.01833491356644247, 0.037345631048083305, 0.008499021758325398, 0.025253544993964688, 0.011684611356551093, 0.008596143868219639, 0.02092137879558972, 0.009181726374663413, 0.030262129181729894, 0.027152683086959378, 0.009470612658852977, 0.027772239841786877, 0.03673088849921312, 0.025027044915727208, 0.03468949553955879, 0.039979507215321064, 0.02149507506484432, 0.01668972398952714, 0.024660622434956685, 0.05451408354565501, 0.05062035783859236, 0.024503838437210237, 0.027680736001847044, 0.042530456225254705, 0.04650684106828911, 0.047113458160310984, 0.0128998361927058, 0.018015074211039712, 0.04333745149363365, 0.026863927420760905, 0.02320674411021173, 0.026033451448061636, 0.0715310327442629, 0.04530747953270163, 0.024867757123761942, 0.01936133688182703, 0.03687378118879028, 0.0032050234772863662, 0.014272678776511123, 0.06089127795504672, 0.02371033583767712, 0.03889943552868707, 0.050833838526159525, 0.031526243314146996, 0.05130108791802611, 0.040986744953053336, 0.04761636456740754, 0.060884960794023106, 0.029453865052866082, 0.00853942088516695, 0.033907209123883925, 0.0254551801564438, 0.033637074154934714, 0.015625468954177837, 0.024851446838251183, 0.02043128482598279, 0.029177321320665733, 0.010799385241365858, 0.03307030403188296, 0.06486987482224192, 0.06183330847748688, 0.011292313791013189, 0.016178765068096772, 0.13268722434129032, 0.04184279491060546, 0.030478782020509243, 0.03142589477023908, 0.007573444861918688, 0.02129396915967975, 0.019466575966881852, 0.04495212395808526, 0.021152262210047672, 0.044635583979210684, 0.0008711120036813164, 0.0632602744070547, 0.01719391791682158, 0.07916776117469583, 0.0411616203907345, 0.041204110253602266, 0.023133353762594715, 0.030265949333884885, 0.019487837861691202, 0.08974901267460414, 0.051715353902961524, 0.022251146280073693, 0.020829408462824564, 0.03030833402382476, 0.027544601521055614, 0.03770065753321562, 0.061623383313417435, 0.04130532732233405, 0.08891115084822689, 0.02204381481611303, 0.018198034393468072, 0.025814359275890247, 0.10151561735463993, 0.06028744964195149, 0.01290572333216135, 0.00800741380745811, 0.04305726742105825, 0.004167626121280981, 0.06250222186957087, 0.027393357761736428, 0.04204224349398698, 0.045295903725283485, 0.06559880463672535, 0.05511972354725003, 0.02353326533921063, 0.008384855696931481, 0.007915934564412704, 0.009635797768299068, 0.07089327089488506, 0.03414320360336985, 0.04188862995111516, 0.007140903384424746, 0.037286347443503995, 0.03405363019555807, 0.03159423930836575, 0.04370200800310288, 0.03235404925154788, 0.043313444924673865, 0.01399280598187553, 0.02497640415094793, 0.04887222432132278, 0.0634215689663376, 0.021662142260798385, 0.008153732250710683, 0.026069298453096832, 0.012316522537730634, 0.047989199204104285, 0.036826456763914654, 0.05208415464897241, 0.04961765271478465, 0.006155380039542381, 0.08789677492209844, 0.024405254084350805, 0.029678914762501205, 0.022734941748370017, 0.035320753630782874, 0.02776657577071871, 0.025361196271010807, 0.04647015267983079, 0.027360896646444286, 0.01586419453711382, 0.0069923754615177, 0.023705999998907958, 0.05663639519895826, 0.039264707892600975, 0.06899022444018296, 0.031971952611846585, 0.022758721008098552, 0.05033511868012803, 0.04229168653754251, 0.07946852182171174, 0.0466373742425016, 0.057349298016301224, 0.08109788796199219, 0.03730010474100709, 0.03363744056384478, 0.0567112783236163, 0.051250248681753874, 0.021193739359400103, 0.053993565762149434, 0.026683543975065862, 0.04984456839572106, 0.028387852611818483, 0.01230465665659202, 0.018582081821347986, 0.016110689346013323, 0.04289250215515494, 0.02377064911914723, 0.008524362496765596, 0.05396549137575286, 0.02602040152331548, 0.049512425504092655, 0.0457303561270237, 0.052251257468014956, 0.04647701606154442, 0.032851839504603825, 0.03901806380599737, 0.06254160404205322, 0.026853449143735424, 0.04534362509314503, 0.03298490022176078, 0.034757603492055617, 0.059111555239983966, 0.029335053571100746, 0.028747544025204012, 0.03906660620123148, 0.03982052306777664, 0.02009831921064428, 0.015849185342501317, 0.036000438766287904, 0.03248870113332357, 0.020758618600666523, 0.019600187993741462, 0.007574077595823577, 0.04507425347609179, 0.014185606618411839, 0.025040189835375974, 0.024670522260878767, 0.032147411589643786, 0.03672531094135983, 0.02176153237399246, 0.024646193387785127, 0.02129910566977092, 0.01903915997328503, 0.040812802501022816, 0.03144513123801776, 0.0056557674958769765, 0.01670691297788705, 0.0306615929252335, 0.0577222683600017, 0.011283958480427307, 0.05633730035541313, 0.03194496388147984, 0.016601821474198784, 0.04877713442380939, 0.01647086930461228, 0.03231677393029843, 0.04968748753890395, 0.02839470242283174, 0.1752590270979064, 0.09713306144944259, 0.11734845169952937, 0.08375703277332441, 0.2083189631147044, 0.08616127911955118, 0.17325097056371824, 0.0977098908541458, 0.10499710589647293, 0.1201591065951756, 0.12928272916802339, 0.13233720883727074, 0.10174503682979516, 0.23327664818082536, 0.23460587114095688, 0.10969759617000818, 0.10888097927506481, 0.21970381720789842, 0.20602083286004408, 0.09736624679395131, 0.07300331802772624, 0.10001874874745097, 0.1131066307425499, 0.12266945546226841, 0.09161082455622298, 0.1160582173615694, 0.20030842295714787, 0.07936789507844619, 0.09513569862714835, 0.1320515727358205, 0.22513947981808866, 0.20213232508727483, 0.16875121130474977, 0.10664778482168913, 0.1248510405421257, 0.10493149156016962, 0.11517792674047606, 0.19170952508492128, 0.1267596102718796, 0.08244320577276604, 0.12800972961953708, 0.06037643950964723, 0.1105639903939196, 0.12304620524602276, 0.13932446390390396, 0.11215479538909026, 0.22535148129931518, 0.15064742203269685, 0.12044661545327731, 0.17333896298493656, 0.1415248986865793, 0.17401690089276858, 0.11310415408973183, 0.11329894113753523, 0.1058816984295845, 0.18289876143847192, 0.105119764671794, 0.10371796560606786, 0.28403359172599657, 0.10127117511417184, 0.1230183717395578, 0.09185868661318507, 0.10567725582846574, 0.14802189863153867, 0.11724547722509929, 0.14713685826531478, 0.14550696286771977, 0.14933661451297148, 0.16540064609476499, 0.09150477631815843, 0.07900263289255754, 0.07542476523667574, 0.1642087043396064, 0.12320788657026631, 0.12745905773980276, 0.08648981899023056, 0.10307125387979404, 0.14272046381873743, 0.15302826570613043, 0.18538785858878068, 0.09328512328543834, 0.13367405853101186, 0.0863804052184735, 0.10151748332594122, 0.1428226511925459, 0.14385170383112772, 0.11711656914225646, 0.09717620270592825, 0.1622615802500929, 0.10987596267036029, 0.19403007413659776, 0.06870895810425282, 0.081349305542452, 0.06784153250711304, 0.1435820268733161, 0.15111128214214528, 0.0830304506900055, 0.15401771904102393, 0.13506683308098996, 0.1905891823449305, 0.10918394516089133, 0.2771841878337519, 0.1096570740586945, 0.10581303747104746, 0.1024971521858658, 0.12036542195294585, 0.11414359509944916, 0.18513640708156995, 0.11448246905846254, 0.16959270329347678, 0.08768293461097137, 0.17416932699935778, 0.08973647334745952, 0.11473021576447145, 0.16626803097980364, 0.07070174760052136, 0.1101157298045499, 0.18837164847978524, 0.20656564219721726, 0.13616326424692357, 0.14336294148649487, 0.12536265594618662, 0.11673349541212831, 0.12211923141564641, 0.1513281555048057, 0.1895950742598091, 0.13067713220204624, 0.15535481300737175, 0.2346343696117401, 0.1304748880543879, 0.11461078003048897, 0.1326787155121565, 0.10525869471686226, 0.12652318152998174, 0.15107768108802183, 0.14813752099871635, 0.0968167759212, 0.0946713499724865, 0.17266950676483767, 0.11671635561755725, 0.08912130671420268, 0.08971090614795685, 0.10108049320323126, 0.17891794576176576, 0.08245640327887875, 0.09143806275512491, 0.12746619592819894, 0.06471976252006632, 0.09474466568125145, 0.1191893850586244, 0.13594529165753297, 0.15117510514599936, 0.08832697290927172, 0.0820533059803503, 0.10945216326841287, 0.1489886346140078, 0.14242281764745712, 0.08466323664677994, 0.09121833276003599, 0.07375249532716614, 0.07553110524479832, 0.07276904702718769, 0.13063290528953075, 0.13523458050830023, 0.1460419605885233, 0.1016033383618508, 0.12967755512467452, 0.17209428548812866, 0.1759379149547645, 0.17055914072053774, 0.11093942381973777, 0.12377123348414898, 0.15827160435063498, 0.10699860099703074, 0.09410588602934565, 0.10398879607341119], [0.028324435032638054, 0.05186549334653786, 0.06656225650970425, 0.020989878602059822, 0.027201125398278236, 0.05511882109567523, 0.04318900838760393, 0.007704712550288865, 0.03058186506054231, 0.04425662895664573, 0.0758501049131155, 0.0209805775832917, 0.023548919142090848, 0.03291736563135471, 0.045186299963721206, 0.0505552727596036, 0.04018814655553017, 0.008350879752210208, 0.03407028823026589, 0.007953574598234679, 0.049366564223808904, 0.03662611251430852, 0.027221854643097947, 0.040957391528146606, 0.036324493520494015, 0.06882774244461741, 0.03632439174024122, 0.0017625128405468005, 0.05046650002311383, 0.029324007020997148, 0.0397760654533548, 0.021391457678484063, 0.05427059803956321, 0.05632655914606793, 0.018516482752082602, 0.03201306504862649, 0.025305851562214748, 0.031151739481304373, 0.007692418343919728, 0.036653209810278246, 0.024462347717157433, 0.028784245984362702, 0.0604906165972352, 0.01573946453364832, 0.01701268969502832, 0.033529672239507945, 0.030321127801601375, 0.02909546285601599, 0.018782663558210646, 0.02257986256985792, 0.014277754218450614, 0.05418980148221765, 0.022649383571531092, 0.05158729059621692, 0.06398370130253689, 0.04032556346750685, 0.00960449525155127, 0.051801934971341064, 0.013449281620393907, 0.020687740528956056, 0.0217380177429212, 0.01815669464745692, 0.046184384264051914, 0.07558428881955997, 0.045171104171978574, 0.02430267146389399, 0.01143636931997857, 0.00918454399132835, 0.059997715188988616, 0.02959072556612747, 0.029631838002907376, 0.051448625179805925, 0.08722871648413794, 0.03660740530384438, 0.05279614822939038, 0.029220265801995993, 0.006330082026709403, 0.06489967608026095, 0.02474415857744004, 0.05676306411623955, 0.03365027166104742, 0.019023356892700707, 0.04287818845893655, 0.057961261964270046, 0.05712952730911119, 0.04274936180029597, 0.0339703264513186, 0.012187249742315283, 0.043617421827678166, 0.018097938603854606, 0.05017959166850362, 0.024540898323591267, 0.03389670879447034, 0.04367531782814434, 0.08958748741341488, 0.038840647254671366, 0.02646999034498419, 0.030853055151445524, 0.006228847994602152, 0.03965323365160397, 0.040814112073608806, 0.026603096863254905, 0.049139794427901506, 0.03783042735553213, 0.012941154734497624, 0.0542751238681376, 0.023097318464091847, 0.018730251817032695, 0.06018225635801043, 0.03489970229566097, 0.015409277519211173, 0.003641054533155901, 0.03817501457940255, 0.08112215237425906, 0.048039224198354144, 0.02539237156244261, 0.014409418849806701, 0.021552669117227197, 0.015374828296314393, 0.022469203686341643, 0.019955684364374195, 0.04085549253172108, 0.020835031821791614, 0.019124406024015377, 0.021329074865207076, 0.008031457695843918, 0.023095109832606146, 0.03643903362431696, 0.06023674950535808, 0.06445843832833426, 0.048517981544137, 0.01902214570769242, 0.05762644564466817, 0.05525157647207379, 0.039946754329970906, 0.034344860818237066, 0.038822649113301716, 0.027016263621460115, 0.048810087476990054, 0.06393952867282288, 0.02039000784446086, 0.06122537502752883, 0.013060305483772286, 0.029138007001685243, 0.029448287495012795, 0.0809547577851585, 0.05347204374681626, 0.07849717858646597, 0.01901357920308198, 0.02978117677516171, 0.04636117995583585, 0.08405545925987618, 0.049536394753626416, 0.015895843106721128, 0.07908172293433122, 0.01630905905871519, 0.08107902468847376, 0.08572907266872269, 0.049922063880200894, 0.05141741596162319, 0.019873540915016617, 0.05067933949508837, 0.047426795453897545, 0.02342350721093161, 0.07335887037749801, 0.01899007135736091, 0.0057752778687115225, 0.014708354237622448, 0.0036589623445511927, 0.0364806346063103, 0.018005233756931763, 0.03163655275212867, 0.029886770394763777, 0.030905712861567736, 0.022869305252762775, 0.04482229306761708, 0.040257055179349015, 0.03767936171165534, 0.050668333657085896, 0.023895214577870708, 0.03911265158759696, 0.021988868746640425, 0.025802091362753084, 0.07031399197876453, 0.02367125391694052, 0.03141158785937088, 0.04835039017988103, 0.06094917734818799, 0.04002631934625762, 0.012702150952203997, 0.08249796354877097, 0.05752300298107522, 0.057475553027221134, 0.055058441657040796, 0.035704302335424085, 0.006147319891689611, 0.05504575305219207, 0.024646435964054296, 0.014081957001638199, 0.052564068896962066, 0.030400523184133426, 0.05623009521514177, 0.009743097055304264, 0.024715414137712548, 0.022540872251348834, 0.03146526337202106, 0.03610315879008599, 0.02769835077093116, 0.04452144081837364, 0.03663785795548132, 0.03043736085029585, 0.07270578720739909, 0.0236744515132159, 0.04249006982094475, 0.025095514188121473, 0.04503823683730193, 0.06411695879484926, 0.02974097357530679, 0.04343177803925105, 0.05837163994354861, 0.014995371157835637, 0.057675768355173726, 0.014208940589534385, 0.014675099236358489, 0.03194391215220094, 0.006246343595973615, 0.04490318801254034, 0.006004001845472625, 0.06183879104043756, 0.01518015659946416, 0.02973724841805441, 0.054754912587148805, 0.027988902858591506, 0.03616470870162759, 0.055238070232527595, 0.026407127468181506, 0.024664639362267086, 0.02718452673538455, 0.02893055509775877, 0.05025471567309328, 0.047795124618070464, 0.007781643154365676, 0.013488936903221267, 0.05020861600392631, 0.018777464283630252, 0.03427919219913227, 0.02662829086849732, 0.022020310363067046, 0.047969782924545665, 0.049294815930937014, 0.036910174414515495, 0.00877795647829771, 0.0279538124201021, 0.016485696991107295, 0.0442956990030195, 0.026154987247926847, 0.0684823002666235, 0.04152129823341966, 0.02294656664266118, 0.02906513912603259, 0.0910253981128335, 0.035855340837900124, 0.040279731819672246, 0.0187964666568275, 0.027058237797713706, 0.01087618268294526, 0.03153139339493854, 0.03159208156700645, 0.03758945921435952, 0.035117515429322205, 0.006775739586113819, 0.011497336539572902, 0.03503439488953777, 0.023028109588527253, 0.007926589260543031, 0.01333458799802299, 0.03110668475606612, 0.008569231473042496, 0.03130707311044846, 0.07248792318361146, 0.009480773720757237, 0.05368705453085048, 0.019196240830102136, 0.02395310209664915, 0.014788380657721843, 0.06500371585467032, 0.019330865570477078, 0.02969109107341085, 0.03506620800388711, 0.07876670626657349, 0.040536971230592043, 0.053921020190630636, 0.05094455847782748, 0.06098172667303255, 0.03782134855698262, 0.023470578881512796, 0.030226363600896936, 0.05782925297639199, 0.008311138804336744, 0.08110583360706057, 0.013787222593756658, 0.018865779008982436, 0.01642723611023809, 0.012869436127532805, 0.07072057016193867, 0.036199860208268674, 0.06395039880382163, 0.04447914773066129, 0.028635962334062372, 0.019506049741591727, 0.021554833643936684, 0.030943860100316148, 0.04526566481217742, 0.04974283224770001, 0.022789443377405405, 0.06293654534965754, 0.01582327378647668, 0.047652160682316334, 0.01848468490477119, 0.010727253576208438, 0.02206027607566544, 0.08408606797456741, 0.032880314226661406, 0.07512540237179824, 0.037096350852932246, 0.0655646403985364, 0.02757745618665857, 0.02269562234037689, 0.059221776468413215, 0.05234414891206792, 0.03989762160927057, 0.031599409745207856, 0.08364756471876587, 0.03877640016643064, 0.023934571305289865, 0.05066025569768889, 0.020583904315052286, 0.007809841373403157, 0.004994562261604837, 0.025835561798885465, 0.07418906475816454, 0.03628834456737552, 0.07241991361869232, 0.02445010524908347, 0.019159060503755296, 0.04904685548639723, 0.022324195663843836, 0.043600645049342086, 0.029959811296846186, 0.023351440006600957, 0.01709883480465838, 0.026915401087275574, 0.13424511360270636, 0.11003140825778246, 0.13664102075355394, 0.12557332749877656, 0.09462739447397844, 0.15646636193352087, 0.17957506621522562, 0.15545177566153662, 0.14675933495163918, 0.10148561253611531, 0.1519251306142126, 0.1566931554781539, 0.1349178675029959, 0.09374212340584823, 0.1303973315017564, 0.2067141192299979, 0.1407388022967747, 0.14222178129213198, 0.1268894818744489, 0.12798528878816537, 0.10616388757314, 0.168511729155268, 0.0904731113197548, 0.1319998683673995, 0.15774316127811158, 0.17059949998344692, 0.14310455535139355, 0.1486885728580611, 0.13334263488650322, 0.11352843525154249, 0.12434743185128484, 0.10505971432264362, 0.1199795797999416, 0.1525854944650616, 0.08725118956395558, 0.12296129337378911, 0.07156476950539009, 0.09502586416367974, 0.09989965906632797, 0.14853747668010847, 0.12025491573980876, 0.11602487415075302, 0.15184553845652513, 0.15306980561997208, 0.10237352310546807, 0.15667138807475567, 0.10671764000185899, 0.13065012650830404, 0.09656304453632661, 0.0892052347106593, 0.11056626348623208, 0.20320446469954082, 0.12228222909782614, 0.06655703857541084, 0.15987897238561086, 0.10257824390594449, 0.13979056317891392, 0.13553548364767007, 0.1752568557858467, 0.11140833222972495, 0.10896722786128521, 0.15264706473265374, 0.1159004308283329, 0.13133973521845682, 0.1388264870537179, 0.057975253356354575, 0.11379043119294302, 0.11360361014625855, 0.12946226953395776, 0.10116248058953456, 0.09835327097347804, 0.07833424197243792, 0.13859700651041099, 0.15714539906808309, 0.10664572886058263, 0.06732391885348729, 0.09239265974611044, 0.2545338746692453, 0.12850092111953668, 0.13821847896490777, 0.16164993521358284, 0.1152095329016447, 0.08486861562622444, 0.14480258923556122, 0.17381680091576918, 0.16828864041183675, 0.12275458446570806, 0.07955119452838387, 0.08682747837156057, 0.11407993494399957, 0.08185987600258418, 0.10908868562962327, 0.13334581043039048, 0.13427424989640713, 0.16165836261851446, 0.0916659894532391, 0.09637775697878428, 0.1318345908075571, 0.08595142859433379, 0.08352122149829354, 0.07363189929830176, 0.06744268283780132, 0.15768604220024177, 0.16793189384043217, 0.13361596236271517, 0.11795537413230964, 0.07214269813682352, 0.11326436299298491, 0.18090203643909522, 0.2174527230007308, 0.13482991579387868, 0.17120674811303616, 0.10840417271746056, 0.17092827734138283, 0.08263852886323418, 0.0868403162541134, 0.12727396695741586, 0.14342491887509823, 0.12282340148729937, 0.15789755513625486, 0.10378685726651124, 0.16429296481822217, 0.19136363507381507, 0.1318635099700519, 0.09550303034484386, 0.09410201159438916, 0.06270089013768093, 0.12482174140002046, 0.2217056719320161, 0.1994731327784913, 0.18496080221874373, 0.10868824140301772, 0.10229462983884982, 0.110795526898333, 0.12915718661887304, 0.09166589445833649, 0.12175321605588708, 0.1236279404589108, 0.14249861000904016, 0.10283230777297701, 0.03715698474219867, 0.16241041012108326, 0.15315992864114897, 0.09664670111877577, 0.10204619102712188, 0.12931593667183602, 0.11513019858726434, 0.12341103995484964, 0.15671375580132008, 0.12719928739326342, 0.18905306048691273, 0.0853953216491001, 0.13816496969333716, 0.14235272498003074, 0.16434504916625364, 0.057032842854303975, 0.1764446720480919, 0.1887120966400419, 0.176362080765622, 0.15327160193451814, 0.10342933716518538, 0.18099944692637238, 0.09822900407016277, 0.11784355156123638, 0.22557207303387777, 0.10417819555316653, 0.13345084765127727, 0.07686311698385648, 0.10349670890718699, 0.15272589693112032, 0.22948008190308297, 0.11952490705464568, 0.1204628867230245, 0.1517721481089081, 0.09830932904567037, 0.16111155838838645], [0.04820556366550071, 0.012819580767037613, 0.04200978237869484, 0.04396737965622118, 0.013988261493588132, 0.025648228458261917, 0.024488744425720403, 0.034071390849671195, 0.043409864750823805, 0.0395310769921967, 0.021731025439554026, 0.027700233705607907, 0.038021088910422156, 0.023860341270587275, 0.044210973727915964, 0.005187518537111048, 0.04773730325645634, 0.050375423660235744, 0.03526924264484218, 0.07415378093719482, 0.03290505361344133, 0.054564692080020905, 0.033583178118403466, 0.03199983022308775, 0.04641494367803846, 0.049422835132905414, 0.028490155336580107, 0.052197008593274016, 0.030995405013007776, 0.1389508353812354, 0.016473217035776803, 0.02281208100196506, 0.029155095906129906, 0.03849144599267414, 0.004819599462540022, 0.028126967771510993, 0.01726714032702148, 0.05891739244439772, 0.04055372426020248, 0.028487237635999918, 0.02279372323703553, 0.021353334188461304, 0.07919558111046042, 0.017467498147327985, 0.027110593559752618, 0.03099626675248146, 0.019783667255459086, 0.04224167511399303, 0.03988087536501033, 0.02093359751493803, 0.050610434263944626, 0.05856709195567029, 0.03521971298115594, 0.004281808721965977, 0.028372985909559896, 0.009672004396894147, 0.023602338507771492, 0.03755531533222113, 0.043399724044970105, 0.04889223771169782, 0.027031910638990145, 0.023873587970488837, 0.05376047541254333, 0.04697370708787015, 0.013325035921297967, 0.04201076964714697, 0.07056163011917047, 0.0492559155183179, 0.04239944129117897, 0.04235741622479899, 0.06287813026990209, 0.03536323331562536, 0.01960698182561568, 0.01573864689895085, 0.018091867411775247, 0.031521659810096025, 0.10824547694729907, 0.06010265741497278, 0.01302272906260831, 0.041774106810667684, 0.012600586134275156, 0.016294638493231366, 0.06369773271892752, 0.06925718725791999, 0.07014264153050524, 0.039382440503686666, 0.06580857373774052, 0.019990308310038278, 0.025985945515068512, 0.005996833971169378, 0.025488150172999928, 0.08607401273080281, 0.02343374800070056, 0.021832714090123773, 0.012340400185036873, 0.02639039309828409, 0.01615702310976173, 0.0420135686040989, 0.06414085001285587, 0.019706970745963708, 0.08671554723488432, 0.03231395461729594, 0.028885137356285537, 0.027525353178914105, 0.04932567909626024, 0.05625255472425904, 0.025151891966483424, 0.04281404993629881, 0.027315326234591857, 0.05078855309901493, 0.018315163108387163, 0.03971710415290935, 0.005229990164350186, 0.02543245771500681, 0.018176506173663905, 0.0422427438066474, 0.03637035909507956, 0.062432651674108844, 0.021845304307394793, 0.060188383529228826, 0.024123132794297168, 0.08684817368962935, 0.018776770481573682, 0.08878103497305087, 0.030838541287396635, 0.029940964986703227, 0.06172568603817906, 0.016264811790149127, 0.03323288441502622, 0.07557455862739257, 0.00656573851093916, 0.03440079585249935, 0.023356220285807337, 0.04934541767995272, 0.020230426586100032, 0.05045453066538487, 0.012474346390393163, 0.03056742244267038, 0.0903843589393156, 0.06943532305636577, 0.0566850733011961, 0.025089634682184885, 0.024237415054813027, 0.0008567827223617185, 0.027779685067278997, 0.036275652569851706, 0.039773222391626666, 0.057684908221874914, 0.035996364163500924, 0.08876295880015407, 0.0029541398190693663, 0.0672025696507522, 0.024721417476290038, 0.06325699708291463, 0.04438337929812925, 0.050286508431392055, 0.11493131997329847, 0.014390168811327644, 0.04525217553600669, 0.033170991843300204, 0.013782488963832813, 0.05063080388520445, 0.031147261150181293, 0.006028963452471154, 0.011560109510485615, 0.049303487608475347, 0.012796308712235518, 0.09395436915968146, 0.029858360133532966, 0.05390622473454901, 0.011177500576845236, 0.024365086507584368, 0.05731554768447365, 0.01494506626789059, 0.03843633537845952, 0.008848292570162033, 0.046452744863927364, 0.04078784937571202, 0.026940486526915004, 0.020162981901583926, 0.030438802737210478, 0.02527290359804673, 0.053546367080083916, 0.0382390988192388, 0.05718502468828644, 0.02713750086591712, 0.03094152933252709, 0.015733262723577873, 0.07214052003941365, 0.0938650332391262, 0.03902979228379471, 0.022472896613180637, 0.016485997242853045, 0.0579543069803289, 0.07241925543972424, 0.04327633923717907, 0.03430771781131625, 0.038007881226284165, 0.017013047622250657, 0.016680901337947165, 0.02623210784180888, 0.030434894375503063, 0.008135399082675576, 0.03946155768686107, 0.015972488726090108, 0.03521692420222929, 0.042051675130746195, 0.04932124486991337, 0.005550479217033301, 0.019730929817472185, 0.04133753737966929, 0.017147387377917767, 0.029292292294225523, 0.020325998243476664, 0.01460924741279866, 0.024782355009977306, 0.01895566963191543, 0.02802522823081485, 0.07523944375238248, 0.01508165875981961, 0.0085817173655544, 0.052137026097625494, 0.018093122701559747, 0.029165423209113733, 0.007875719490194959, 0.014490330758105432, 0.008133982640824147, 0.06695887379880462, 0.044756733014115264, 0.023329820184569274, 0.029245948352451836, 0.04229983574311648, 0.013529045956342347, 0.029370907361486127, 0.04892866825684905, 0.0748214933222958, 0.019686916643487554, 0.018107816377388578, 0.021053657501137683, 0.024377858232972876, 0.02885032511715378, 0.027869076966973286, 0.0314005345239171, 0.02459799195639789, 0.04267477383837104, 0.020314359671569297, 0.053941766398825815, 0.024288125369431715, 0.029780888397778784, 0.016758793765412908, 0.01262924914980041, 0.013697842568425196, 0.040438010290797265, 0.08627090323716402, 0.03798309773472803, 0.025910529740420834, 0.031025677852864777, 0.042732306822602234, 0.05273490705128227, 0.0422288881215666, 0.03348217139552746, 0.014357432889352952, 0.012241874355822802, 0.00977120706478932, 0.018172014271840453, 0.049130980258009264, 0.04907568304666451, 0.057200515642762184, 0.07543298229575157, 0.05932893071855817, 0.038371345294373374, 0.03364286205864378, 0.00833657368951078, 0.0485463951980429, 0.008598275316346968, 0.005429847565080438, 0.11544364105377879, 0.09855995274015836, 0.057750739689384184, 0.032714154571294785, 0.022544672047453265, 0.05308674102915185, 0.051101300067135265, 0.04818284970575145, 0.020460746816492507, 0.05822014342993498, 0.048720890656113625, 0.06010518835059234, 0.01664566501442875, 0.040546083955892494, 0.017780553848881806, 0.04965823928692511, 0.008390539275881435, 0.058733400888741016, 0.029168866774333373, 0.03795704538268702, 0.027851920209026763, 0.03925012617505022, 0.04077440081164241, 0.023030477675742338, 0.049444222556693215, 0.026291228597983718, 0.014047029411553271, 0.03793968167155981, 0.034497398883104324, 0.06827541493943759, 0.03086219841082181, 0.03852840240246483, 0.032740515656769276, 0.03149147178711636, 0.032475934496947696, 0.024202297474922876, 0.03238346713728138, 0.04846280646909561, 0.033855711708643606, 0.05330213179279651, 0.021497790901256458, 0.030569200204419236, 0.04062395263463259, 0.037411835709852834, 0.06911930894213063, 0.012396687209340078, 0.04677396334175553, 0.0018351971936811293, 0.021355814233954464, 0.04588933348921793, 0.023644841941339628, 0.03576620847785047, 0.03394349378400615, 0.049616875792188306, 0.01645433679888291, 0.07381749219660248, 0.0821557647681662, 0.04531103166352425, 0.009834537282586098, 0.03182154853961297, 0.024867918275828873, 0.06576531034495149, 0.019346202158236077, 0.007782942548926387, 0.0474267649198217, 0.030410297481077056, 0.02591841431733753, 0.06599074003419705, 0.03841827956161328, 0.014311095732929451, 0.038891795224377086, 0.014096155346903418, 0.013216463532964033, 0.03884657086538417, 0.059940955734678676, 0.028091943490185907, 0.14507276830928667, 0.12374151365033217, 0.14427428187004157, 0.130830779671669, 0.0862803009471723, 0.09475780890456267, 0.13371371211750166, 0.10970756384943213, 0.1173744395907436, 0.1861177044255393, 0.10704595595598221, 0.08349381546889033, 0.15796439083559172, 0.135661121191723, 0.11190733366778918, 0.20480516952063355, 0.1607290274862732, 0.11862389397408281, 0.13261445824589047, 0.12186605642948832, 0.12196272052824497, 0.22566382453909942, 0.10746811330318451, 0.13357470743358135, 0.15345494209655694, 0.18323557265102863, 0.11410664208233356, 0.18407451334808553, 0.05560500839991229, 0.224112761339971, 0.11897929704615048, 0.09403787646442652, 0.09284971414932183, 0.126920558778303, 0.11349193006753922, 0.18173017485865525, 0.061597252929849286, 0.13992244324513844, 0.08270659949630499, 0.10078284703195095, 0.04997931866507445, 0.054946235713682005, 0.12413635317768369, 0.11961124385041849, 0.060091027324753146, 0.24666829673307283, 0.1722351357872997, 0.1225037436400141, 0.08298986751054015, 0.14192519363548073, 0.11251846301768507, 0.13355904684535094, 0.15359549384031976, 0.06563283316791058, 0.07907370265041079, 0.11801538376935891, 0.09377739365611758, 0.11281009058334998, 0.1913856603205204, 0.15796283020504884, 0.10832376631775073, 0.1287012110863413, 0.09277066481964928, 0.14312592920448097, 0.18885274337870733, 0.20282253090824398, 0.13923043252101966, 0.10135244325335536, 0.1623156052082777, 0.15882782664682182, 0.22744601033627987, 0.11707101230110441, 0.07149106024631433, 0.06863750836678914, 0.10810181751315083, 0.11559081529932362, 0.12592410296201706, 0.13470150982694967, 0.13845454129789556, 0.10118367802351713, 0.14614778491003172, 0.1345677027212722, 0.15338531083294324, 0.1841677576303482, 0.16208860810313905, 0.07048778515309095, 0.12849864124187402, 0.10283199564686843, 0.07076059694268874, 0.1692674678883382, 0.08998542784580163, 0.2070573086717299, 0.12197392992675304, 0.18271730760378496, 0.13862156947808607, 0.0751640245850597, 0.16996631824544498, 0.2057961563446692, 0.08749969622918538, 0.1965286164943661, 0.1751689447888306, 0.23888235166668892, 0.1003553428288017, 0.1652720637087311, 0.1398565846362284, 0.1252210863998958, 0.15615228164408887, 0.1095428087615541, 0.09486503779355969, 0.1442184927208083, 0.1525021025112697, 0.09993537036435944, 0.08826566048498664, 0.11104954326791422, 0.0737211877214057, 0.14830781971769674, 0.06661886668631009, 0.15993240023297922, 0.07079731247254781, 0.13752192205616406, 0.13270449984286511, 0.13832275622657367, 0.09196801217538969, 0.15906983294657298, 0.16079829234097684, 0.09320814348757267, 0.1157270787017686, 0.09383774934602634, 0.09828297474554606, 0.205297229545457, 0.13171356730163097, 0.06487799688641514, 0.14283873247248785, 0.142891169658729, 0.10625147287334714, 0.16909305724714482, 0.1379173451236316, 0.1513782992426838, 0.0924276721530727, 0.24358820915222168, 0.15066978654691152, 0.15914405110691274, 0.19807122514716216, 0.07410521140055996, 0.1776110737451485, 0.06529241214905467, 0.10148534790745803, 0.17734635009297303, 0.11388846593243734, 0.16328589671424457, 0.08175747828291995, 0.1046828016904848, 0.09779499950153486, 0.09561000817588397, 0.09608236354376588, 0.13792791669922216, 0.296668890863657, 0.11775804257818631, 0.11334729354296412, 0.12282957615596907, 0.10082527582666703, 0.21002535655030183, 0.11458262082721506, 0.09223992151341268, 0.16661481665713446, 0.1814250648021698, 0.08477544598281384, 0.13807494166706288, 0.16701447378311837, 0.18543239762740477, 0.1586129210357155, 0.12331970914133958, 0.08142633962311915, 0.1446097767246621, 0.09775378528450217, 0.0871600623109511], [0.037375320347824266, 0.02303495431052787, 0.027135309197806885, 0.015013279393315315, 0.036237091424741914, 0.022897691765267934, 0.022185116341071467, 0.025803321207474385, 0.05450001412204333, 0.032938793767243624, 0.06860818886863333, 0.029668356757611036, 0.028362965643672005, 0.046713359986564944, 0.01838087074325553, 0.03635436602469001, 0.08645571582019329, 0.018556229637137482, 0.03355377380337034, 0.06000277706022773, 0.0702049649719681, 0.040632257903260846, 0.0453533281439117, 0.016859552823007107, 0.030549563400979553, 0.09777365957519837, 0.03156462464747684, 0.05865602754056454, 0.03638320037030748, 0.019868209326107587, 0.03129674920013972, 0.0038005942312468377, 0.04136331492502775, 0.04233689732583506, 0.08956024423241615, 0.016377404498468553, 0.042440957456294975, 0.06126962908144508, 0.06256692696894918, 0.04322296567261219, 0.01285426238817828, 0.07147451077720948, 0.048391858847545724, 0.05203803801642997, 0.039154408632644584, 0.033256996156913896, 0.031692531891167164, 0.03209380053782037, 0.022378948350836123, 0.06315965444913932, 0.007900866846154844, 0.023882831313780377, 0.052722164163632054, 0.025707391622875417, 0.02598781487904489, 0.05152129288762808, 0.03214932505839637, 0.022328193931441222, 0.02185723973837282, 0.010632009311978306, 0.038804542406329086, 0.0068884798757998, 0.06310030299105815, 0.03153735771775246, 0.08205458162618534, 0.01710119780286082, 0.005772619707775968, 0.026873722073755095, 0.05691022479108401, 0.021837295897837197, 0.08088564220815897, 0.022743296210787127, 0.05435126228258014, 0.03375222494027444, 0.014367161385182823, 0.027616575426821197, 0.03915529412084392, 0.06416123320481606, 0.05776380827384336, 0.018996008538774083, 0.026324985715161477, 0.06914742743330342, 0.03555319597944617, 0.031078294850885868, 0.022571911835776906, 0.06252493922199522, 0.040737858308213096, 0.020159960724413395, 0.03912726044654846, 0.03091084597898381, 0.024350671031113182, 0.036748574514474185, 0.024543863521622758, 0.04382339452526399, 0.03910250748906817, 0.08191203498946768, 0.021529028957177485, 0.05018084356561303, 0.044205440274838886, 0.007669125084898302, 0.022726522825126137, 0.010171741197284843, 0.018843100672321658, 0.035204303450882435, 0.04634626914880105, 0.02759698442449527, 0.017954414876710092, 0.03983958650912557, 0.04670817258634737, 0.011926127414751266, 0.005462530900591186, 0.005960967034168009, 0.062249732203781605, 0.02446749440527388, 0.03512110827224595, 0.012035876213173782, 0.052587919402867556, 0.008945636052106107, 0.009818767280583935, 0.03178480247567807, 0.050734144768544605, 0.06451848189213447, 0.034315300440149646, 0.02217805788053998, 0.046134003038917265, 0.0062625020592739535, 0.012679192719848027, 0.06874356339020388, 0.018076335745198385, 0.08112236272011485, 0.004865005329650427, 0.03516061258103166, 0.033520060790968795, 0.10725656644042049, 0.035549942404031754, 0.02811178724680628, 0.03209491672792605, 0.03236998803913593, 0.037799628651035685, 0.0382976835327489, 0.022220016789755652, 0.05128410079383424, 0.033451979979872704, 0.007767624620880399, 0.019099564856982658, 0.02915124861257417, 0.03446420494999204, 0.01878967961030347, 0.04596087143623403, 0.009143726717281555, 0.11387173325887748, 0.08533290999808482, 0.01823850391831781, 0.04380661096157772, 0.06793789126511131, 0.02956974526335086, 0.02998971094244293, 0.04704797274566122, 0.03527511197275349, 0.03367309757907476, 0.016312375398618833, 0.012797217100991734, 0.08594069417033877, 0.024742307873176675, 0.026511723641306162, 0.09837650401251656, 0.01657488363395844, 0.0570737449452281, 0.038010459659355025, 0.012913940391237182, 0.01335170234753085, 0.06098134669342211, 0.04003525225977812, 0.01100718743899571, 0.03581386199221015, 0.03717669279181531, 0.04964088236114808, 0.018758010684645603, 0.05436536902561784, 0.020297816987814646, 0.052007062892828665, 0.08791911908026252, 0.022359538856627684, 0.04696141203333225, 0.02322375159045415, 0.08212377184203692, 0.026153769277568375, 0.036428506153502634, 0.05778449002121176, 0.07263353001326323, 0.015460820735565253, 0.028598639515361617, 0.010272878538151937, 0.007420789749760712, 0.03364068396123392, 0.03422081783147795, 0.06461131905338593, 0.012772101975445236, 0.012423960924414652, 0.030922842478113513, 0.04240247434271233, 0.08234200227473464, 0.04307223590356963, 0.03014428461236613, 0.03625763746510659, 0.00638535718566605, 0.08077103085815907, 0.04342610887917025, 0.02068736563835825, 0.03502270033849137, 0.10897680877574853, 0.02271087241492101, 0.013066669294078435, 0.09648263813661677, 0.016779962361657193, 0.04623108443671039, 0.07777670331831489, 0.021745171198355298, 0.040510053746402264, 0.048719506444675584, 0.01816439432358103, 0.03840843741116779, 0.016006096565563763, 0.04202359735167452, 0.032963438159120936, 0.08672413070287023, 0.05635291344619223, 0.09000851839248623, 0.02883253392896482, 0.020537819912923232, 0.0066044311222088125, 0.0055967637869928566, 0.05139186911817108, 0.027984760402302657, 0.08759893876101289, 0.07638705002942256, 0.020291598214368736, 0.01624150071958346, 0.06768583586173398, 0.06013572242643152, 0.04973774662773524, 0.0356057451239654, 0.03132254031619855, 0.053004438124064884, 0.024255679521177496, 0.06615256385079452, 0.02981174477775182, 0.06167409023536103, 0.02438859435330544, 0.0308681288068848, 0.019451593913670098, 0.05199318006634712, 0.043874036986380816, 0.0547938197851181, 0.05299321176218135, 0.031442505307495594, 0.05358860927766987, 0.029562735996608223, 0.03500944854957717, 0.07387331527258668, 0.06270895113370248, 0.05459154849605901, 0.03311189483585102, 0.042671676326010904, 0.0714240006304213, 0.041028478249375305, 0.04361275689942496, 0.06122800774340119, 0.008468869358434208, 0.03399490298969405, 0.040576692670583725, 0.03713380598596164, 0.019859464706054757, 0.07216983275221926, 0.057993472021605284, 0.031439621533666334, 0.04119113327137061, 0.041569799916552644, 0.015412626089528203, 0.032054900125201256, 0.03036667446472815, 0.01209528958757541, 0.05140145681798458, 0.05617949685880116, 0.030546051982258047, 0.012989131401159933, 0.03532338634665523, 0.06007171621812241, 0.05218726822308131, 0.03398055536672473, 0.06836533440010888, 0.007850028458051383, 0.016955375538340638, 0.0390043438279203, 0.018412302181656872, 0.039760554142828496, 0.024473431586687053, 0.01193974815708186, 0.05267005606687494, 0.028724684180425744, 0.02344325088363673, 0.04202265079532351, 0.020137151769761528, 0.04580008917089019, 0.03227564113746796, 0.026733599503391554, 0.04417688412857907, 0.07235323398240975, 0.017317672526197772, 0.06003040022083691, 0.040482294878789356, 0.060985940375498364, 0.03292912125055279, 0.041378368224416456, 0.039042521600744555, 0.05967454931565693, 0.03356593315090452, 0.0740377785904067, 0.0405937238995518, 0.014065265040179449, 0.05701368102537734, 0.03641051819015827, 0.032114316044109206, 0.019481692030759792, 0.08090804064912455, 0.04151181231385895, 0.12073047379297869, 0.062071521766483784, 0.03830961896372693, 0.04743909390111055, 0.1467449092971427, 0.06127526770745005, 0.027941047480063777, 0.020931307459250093, 0.041274107926126034, 0.04835282951327307, 0.044022558123937676, 0.024338769526886087, 0.02176971041730472, 0.03643202096489923, 0.04556006758606859, 0.09731191649500813, 0.025423699524253607, 0.06030645540782383, 0.05267385925565447, 0.08094599111271755, 0.04139720096385904, 0.02830720193950193, 0.06027685771031039, 0.010384378805091339, 0.024950149934738874, 0.05159333634323307, 0.06837125801082168, 0.14824160827057703, 0.10172729992440768, 0.08721536970032112, 0.11105730570852757, 0.15561819316021033, 0.0622470723465085, 0.1425481837775026, 0.07029639756573097, 0.2087550847125905, 0.1564081571996212, 0.10122582861887557, 0.1759632243109601, 0.17635574324854783, 0.07382560069007532, 0.09394879160182816, 0.14427976443299226, 0.10612823734326021, 0.11075995130730526, 0.11361835471221379, 0.26050368004611557, 0.09078852832317352, 0.14191953465342522, 0.09449408948421478, 0.10638088307210378, 0.20316078061504023, 0.11012193839997053, 0.1552892800952707, 0.10388041367488247, 0.0741786424602781, 0.1341365479997226, 0.13071665008153233, 0.10941845364868641, 0.12664322794548102, 0.299091993698052, 0.10585307103714772, 0.1703606013740812, 0.19425549704049314, 0.12295437231659889, 0.13679776234286173, 0.1382924664233412, 0.15494788198598794, 0.14172543292599066, 0.22110685120735848, 0.09596311101423842, 0.13115666647042545, 0.17062433436512947, 0.13078370291207517, 0.1468421569360154, 0.20056598127952643, 0.07516126294753381, 0.16334901404167923, 0.07582919246384076, 0.07849101748849664, 0.15038007923534938, 0.13316352878298077, 0.11782209628394671, 0.10711333448333399, 0.10265552225921835, 0.11534220006849084, 0.07799310170646225, 0.10140500936125006, 0.1357797562543835, 0.11943107923226697, 0.0986810644556369, 0.11176627302276236, 0.0940522885482226, 0.2345103605517319, 0.1117358882246273, 0.13858647564692156, 0.16748938044267042, 0.12541859437312397, 0.09148848469236068, 0.09856979149792876, 0.07361853215843439, 0.16313090574528488, 0.08873315075678484, 0.14117936151368277, 0.17192699946463108, 0.1449909641274384, 0.14485533854791097, 0.10837442574224301, 0.17946626991033554, 0.20486421563795634, 0.143985795921513, 0.1287526711821556, 0.20536359027028084, 0.1497056425682136, 0.19488276195313248, 0.12549532311303274, 0.15798926592937537, 0.0888526611296194, 0.1471133402415684, 0.099411873812122, 0.15630734046655043, 0.2101692602570568, 0.06571092576320682, 0.10725651894296918, 0.1565865711974246, 0.10244138339268309, 0.11297289827572447, 0.09535008855164051, 0.1639561943177666, 0.08323148704533066, 0.18901595819209302, 0.12428020260163716, 0.13287589778857573, 0.1943018138408661, 0.17870194092392921, 0.07694872096180916, 0.11157749779522419, 0.06454696679221732, 0.14469247657273496, 0.1103370204301817, 0.21825255293931278, 0.06525598160390343, 0.09399692687605109, 0.18103542285306112, 0.11270309918160949, 0.16571431926318578, 0.14939024592084543, 0.2620094306766987, 0.07051220562841211, 0.12546345910855702, 0.0879988537303039, 0.14570934272238187, 0.07989051632050957, 0.19639917915420874, 0.12130796137665, 0.1304824740758964, 0.12021641566285066, 0.13758353303585732, 0.11806358689708368, 0.1823819755975689, 0.15217891628188746, 0.12350265575306756, 0.05931108524756772, 0.08543678013873951, 0.0759384094604424, 0.1495225466787815, 0.10789583463753973, 0.2293037170810359, 0.08844203209238392, 0.12567202720258916, 0.1554263305983373, 0.1071622297167778, 0.10701804781066519, 0.09911619539239577, 0.2831678624664034, 0.11183641318764005, 0.22416343433516367, 0.15691251227898256, 0.13560291645782335, 0.15768855277981075, 0.1875673130686794, 0.06755371830825295, 0.14746879759643758, 0.10541859827935696, 0.137848772374647, 0.09779630907412086, 0.08927141223102808, 0.06801633669861726, 0.10570815631321498, 0.13114918901451997, 0.12727005859570845, 0.12589453240590437, 0.20178646221756935, 0.19532668670373304, 0.17014082388154098, 0.20873789063521794, 0.1018167036984648, 0.15425321140459605, 0.09257348932858024, 0.10621929674276284, 0.14172949056540216, 0.18039795277374132], [0.031755781532930474, 0.009874932168583785, 0.011347969777749052, 0.03841230845344918, 0.036754990063075504, 0.023119984926389794, 0.026430070433499556, 0.04396720323711634, 0.01634091797417828, 0.07419318346572773, 0.01851569565146097, 0.02898192698402064, 0.07278552864279066, 0.05753915211451905, 0.05479602502392871, 0.03479174058884382, 0.05880641804209777, 0.04433703196368047, 0.03924620084996734, 0.023397683864459395, 0.07963972977761712, 0.010081529118386763, 0.04519541608169675, 0.034831947181373835, 0.04939414667231696, 0.062021330531154356, 0.0616864056459495, 0.10777217841574124, 0.04116359832031386, 0.056063752355320115, 0.05577964974301202, 0.008336792517054294, 0.06387808054153409, 0.047622641016330035, 0.01594991047334458, 0.018109777343592474, 0.09216632081993989, 0.019720532964648943, 0.023516936393986856, 0.012930673064797052, 0.029932652932724783, 0.00709387072960713, 0.024018972579921995, 0.026480108998449783, 0.03528397703277213, 0.06202362397951739, 0.026815159412633096, 0.02935523320255535, 0.02930004455681358, 0.01238962450796472, 0.024625811892162477, 0.045167775957712104, 0.018917066078366976, 0.028717498494578258, 0.059437082415180545, 0.011226043820248117, 0.033993284683674574, 0.073822750842997, 0.053256320501012464, 0.03541624725663236, 0.010862164149459983, 0.03151942403720958, 0.03452183632180095, 0.029935540099229132, 0.04834566079080105, 0.09483969451061317, 0.05330873393852796, 0.017490412274907743, 0.10879402501242501, 0.018652888646881496, 0.021467516365061914, 0.055251600220799446, 0.01745210218775485, 0.0251403314261032, 0.03562086627685598, 0.024405632367623702, 0.03994244223992739, 0.01193015112741185, 0.01359279262500682, 0.007754601837534989, 0.06466959164078746, 0.040490976734352965, 0.031267066685748954, 0.039981939763362916, 0.05883068923971482, 0.0252232908138207, 0.027487786087606634, 0.07305891040180411, 0.023737027708973204, 0.06930520718118974, 0.010737055014552814, 0.03582124784588814, 0.04785130053226437, 0.04441315680742264, 0.03588197673005717, 0.056313476990908384, 0.07174684759229422, 0.006131434962818665, 0.013420479505189827, 0.00719702586398593, 0.018261292516919117, 0.04458241397514939, 0.034204217472246716, 0.015798546274059584, 0.012577545629548175, 0.04028213044096317, 0.0208899117340999, 0.031190812920353243, 0.012794268866335707, 0.013810891591544663, 0.022361567676333443, 0.035846757369914224, 0.10290816120271172, 0.015860616961227994, 0.02002906283762838, 0.03514076882441129, 0.04356151732749172, 0.019458767725154757, 0.024588126057226743, 0.02411257818208209, 0.03332437468426568, 0.02001449977979064, 0.01693215946267758, 0.02018857284981225, 0.07625105804098503, 0.016663354422364916, 0.022591287403234413, 0.11114671626793486, 0.018943705363199115, 0.026436034756313478, 0.030222689333770956, 0.07490448494042669, 0.04147282708436251, 0.02099943407145994, 0.0460411115948643, 0.020162294884877544, 0.03126115325306143, 0.06012904564184802, 0.05457336375755923, 0.01985167682037822, 0.06674468743481807, 0.04158775734582117, 0.06990704738668033, 0.016742759982922246, 0.03260852363226669, 0.02676038128057761, 0.009285958683384317, 0.02519244121919785, 0.04267304018139839, 0.034504211374691555, 0.08326191934091703, 0.06639905526701893, 0.026992447042305554, 0.025753263982811143, 0.023062728445178697, 0.04554059702370848, 0.05951114451246602, 0.017157726555264423, 0.037917876948735545, 0.019174809301538125, 0.03463469705145274, 0.17947348952293396, 0.018649066798388958, 0.04655976679974368, 0.03406765212171844, 0.021762926763455783, 0.09563094098120928, 0.07408784768943276, 0.03258893432627831, 0.04379564244300127, 0.036950116378388236, 0.03447419637814164, 0.05036496404292328, 0.048553533386439085, 0.022255604255146215, 0.013418739911035767, 0.022810211637988687, 0.013134439675403493, 0.010231800028122962, 0.019363479356148412, 0.04353080004719751, 0.06560700812510081, 0.05247719605852451, 0.020965524283902984, 0.07547923124262265, 0.07596561871469021, 0.058921036177447865, 0.048392462743712325, 0.0426955268319164, 0.04313131255496826, 0.032287722453475, 0.025482206206236566, 0.06819294579327106, 0.01826882255928857, 0.03797504352405667, 0.015131707502795117, 0.0021691869728134145, 0.029964208203767027, 0.04862522739650948, 0.03725366580433079, 0.01219473737624607, 0.011136918245548648, 0.06496896807636533, 0.021723627711513212, 0.03478245483711362, 0.05246982716822198, 0.008409642581162708, 0.020404397875868847, 0.03688819666526147, 0.029813902519111122, 0.07480138832969324, 0.09658300703657524, 0.05216710216232708, 0.022013302792661955, 0.010873382029655789, 0.03971766733697482, 0.03875807293557695, 0.023335092401664172, 0.039257132049117766, 0.036121950817427466, 0.027108815798003758, 0.021717320728514875, 0.04718792398593255, 0.012160300027712114, 0.015652781685015986, 0.030211971873151403, 0.059663706326058934, 0.04018222973016756, 0.04502246768346854, 0.04477385923798595, 0.038891377925340614, 0.027255211424614702, 0.0445251286562, 0.04006059215004955, 0.03238759941554495, 0.0487426919862628, 0.05046259166140642, 0.0479976266090359, 0.06381630671343633, 0.05134662101045251, 0.026232419967917458, 0.06946760096720286, 0.03948593405740602, 0.051118880909468443, 0.03231601057840245, 0.018060592036428194, 0.021462975269449607, 0.03880857290433986, 0.010742272948846221, 0.00844105620801981, 0.03867180399330599, 0.0326997390948236, 0.018957645865157247, 0.02250754600390792, 0.015932748626385416, 0.03411349394757833, 0.031759445622031174, 0.023358663011874472, 0.019694109114685228, 0.020810677503634776, 0.048854385635682514, 0.022822934169588343, 0.02856423778991614, 0.03761412396228739, 0.0030382601377953377, 0.06106360549373286, 0.04119231392230306, 0.03975183836051396, 0.01441720503914569, 0.046554962771811655, 0.04640524401994688, 0.05610529566183686, 0.046549517528287, 0.015665426185088496, 0.03018309681543282, 0.0209351683235062, 0.06531737545239073, 0.03575337738064783, 0.02618374695469226, 0.033832624554634094, 0.02970346076680081, 0.04752052149602345, 0.025240579886095862, 0.019916504056059887, 0.02127306179941765, 0.04043865489906498, 0.05859922058880329, 0.08887729195079633, 0.04910306872001716, 0.036660632983382256, 0.006673549667799047, 0.00503164462445836, 0.05375223460474184, 0.04890106884496553, 0.04184473891343389, 0.020740333778251494, 0.040120075922459364, 0.06530972836273057, 0.02921751094982028, 0.016770568044324006, 0.048107016632067304, 0.05198592652699777, 0.037634008431008885, 0.013316582223134381, 0.05736437506441559, 0.006149235056779746, 0.052168194603707106, 0.016470155146505152, 0.03936257639101573, 0.01838906405360571, 0.022761204446266805, 0.014149273612669535, 0.023597307170608213, 0.07402724772691727, 0.02155451473247792, 0.027277762535959482, 0.030014345156294957, 0.03533001224111233, 0.02606649779980736, 0.08782549481838942, 0.01256867463234812, 0.047464881624494276, 0.06614735948720149, 0.017182277648576667, 0.026431028864213398, 0.0257231641693839, 0.042700527635003836, 0.03689973854592868, 0.02426707890949079, 0.014564854259203588, 0.02813767844678036, 0.06405118839549166, 0.038311878485339027, 0.047216890645878654, 0.028772283411983932, 0.0738728063713227, 0.06240469603134053, 0.02464988631462412, 0.05782364149178777, 0.031047421507537365, 0.04472151704664741, 0.02519330465500908, 0.05015875046540584, 0.03252926395673837, 0.06328111221747738, 0.010823452878477318, 0.041074167404856, 0.035263288500053544, 0.04169812106660434, 0.05175363006336348, 0.03813886562628405, 0.016794851116303886, 0.12789532861539296, 0.10580336156168155, 0.13051817858857767, 0.10465610812285117, 0.06508744029062134, 0.1490594329578536, 0.10448876781655209, 0.12343694642186165, 0.0849572526557105, 0.16982098961515085, 0.12111238044287477, 0.12991481167929514, 0.0931208770988243, 0.17724412200706346, 0.15670824609696865, 0.12891152980072157, 0.10409453218536717, 0.1266799909727914, 0.1560923262898411, 0.10275407947067704, 0.11287809336291892, 0.07891166848795754, 0.11571249019886766, 0.12769145598368986, 0.19765149695532663, 0.16672355867922306, 0.1520968542567321, 0.11803472201739039, 0.11562630268079893, 0.1383312786264079, 0.2553144342132977, 0.10088579436498028, 0.1741406521094697, 0.08604521570461136, 0.11008929408022336, 0.12551177080188478, 0.17227366300565855, 0.1341464003281934, 0.057028744502791336, 0.0780857488779085, 0.15703557138996466, 0.13345833867788315, 0.07399667293897697, 0.12069943760122571, 0.1886985395103693, 0.1040312587948782, 0.19166239404252597, 0.12337338126131467, 0.10792959175471749, 0.11128536811364548, 0.16994407586753368, 0.1425169575959444, 0.11391673370131425, 0.15940170442419394, 0.13452746559466633, 0.06629800104669162, 0.09460888403866972, 0.18784821299569948, 0.106635299777346, 0.1426629511905568, 0.09534886718860694, 0.14149485315595353, 0.1785478320504938, 0.14622497505375318, 0.15197414798395975, 0.27490545010992457, 0.09787277318537235, 0.13526409678161144, 0.14869637601077557, 0.08828856104186603, 0.09390829663191523, 0.11829523875245027, 0.08637832890131644, 0.19171536048608168, 0.1590823179909161, 0.15496099128254823, 0.14798018229859217, 0.15700691007077694, 0.0913559328764677, 0.11037137465817587, 0.21376261886741432, 0.0902878644743136, 0.10600777702139956, 0.08044175816965954, 0.18683134684605257, 0.1030083265421646, 0.07818820766572442, 0.16211592592298985, 0.11349965858140162, 0.11872868692236287, 0.07393349454339061, 0.1014150788209268, 0.16214055674416677, 0.1107026490249804, 0.11092151049524546, 0.10075072518416814, 0.14074285993618624, 0.09586926962115935, 0.12632196875555174, 0.1544456710772855, 0.14434571803680488, 0.10532441761876855, 0.17646998140428746, 0.14661073578255518, 0.13666977706764424, 0.122755819399442, 0.11685658166451113, 0.11510813262845788, 0.09068740624934435, 0.04675879808408873, 0.12736417140279496, 0.10688489888395582, 0.20239248898412499, 0.06921744546187775, 0.14417647783245358, 0.06540197519851582, 0.12530761318547384, 0.12972322053142957, 0.1573725047388247, 0.07879286379154239, 0.1324519898210253, 0.1744311736630542, 0.1666642547185932, 0.17594638307179722, 0.1704245058021375, 0.09069893455931119, 0.25443982971566065, 0.2310890241393021, 0.15044626354106835, 0.13663815733577522, 0.20724492360438618, 0.2170685093317713, 0.17105292422430857, 0.07142704046730484, 0.18066977390221187, 0.0896381875500083, 0.09464915509202651, 0.14464473484882287, 0.13391598340656075, 0.15481115717973026, 0.08375278514410768, 0.1059157880289214, 0.08591199213904993, 0.136287246165531, 0.11102688019829136, 0.11582235858908721, 0.1380238886922598, 0.09740729137722935, 0.15054310405892984, 0.09240088359053646, 0.23140470577137812, 0.1589189674705267, 0.08915167794163738, 0.07486477707113538, 0.1075878543779254, 0.1872057488986424, 0.18908978280212196, 0.1239635031670332, 0.23046659039599554, 0.09934455635292189, 0.13671443824257168, 0.2190863231995276, 0.21469462742762907, 0.10106300735580069, 0.13994684336440905, 0.10654786375484296, 0.18491743026035173, 0.2176708448678255, 0.1603165596191372, 0.15102308616042137, 0.16042766294309072, 0.13032467397195951, 0.12822325101920537, 0.17027784724320683, 0.13744306271629675, 0.10425870373312916], [0.03408951452001929, 0.00039170867135648483, 0.03805223706045321, 0.015011603411819254, 0.025020490267447064, 0.10789536644837686, 0.04517869019348707, 0.02734864060766995, 0.03666787634470633, 0.026405656743528585, 0.0040169192527953, 0.04809397179633379, 0.04672537684174521, 0.05490482811416898, 0.021217535582504103, 0.012671723745630255, 0.05470038551305022, 0.025867741322144866, 0.02332807974224644, 0.04233143851161003, 0.03133034346891301, 0.08800881462437765, 0.024635114607268145, 0.030716598366520236, 0.04789763429601278, 0.014932582919885005, 0.015322888136974402, 0.00879753815076713, 0.04326172359287739, 0.022249750194272826, 0.009727556907039667, 0.03125249853889857, 0.016142275151131407, 0.04368541782189693, 0.0413694115621703, 0.042350939608045986, 0.03591581527143717, 0.04367254601259317, 0.03723128432674067, 0.048798881471157074, 0.015060586854815483, 0.03195666182520134, 0.045142056087830236, 0.04027058516762086, 0.025895038785945092, 0.044212792201765945, 0.062276052577154975, 0.018966225940468054, 0.026133601520476595, 0.03043804277798959, 0.014343059821320432, 0.03323066221284015, 0.01908693223127297, 0.009999059972220233, 0.04663288912602833, 0.01176973951182195, 0.012450786806376917, 0.008798302350831884, 0.06883892470172473, 0.0333409309387207, 0.042549760546535254, 0.02482310782319733, 0.02218183732059385, 0.060221957441951544, 0.005516138983823891, 0.01850302061731262, 0.06381534997906003, 0.020083223502816896, 0.009942848434937852, 0.017729044559278657, 0.024907863632376705, 0.08422687756163733, 0.05902384780347347, 0.010910088229658348, 0.025552495648818355, 0.008972685002455754, 0.07731626302536045, 0.04318856055449162, 0.06552670350564377, 0.013121879144039537, 0.04196439856397254, 0.0351052712649107, 0.06009877619466611, 0.017077600051249777, 0.03562736324965954, 0.12661007472446986, 0.015057017760617393, 0.015454981941729784, 0.04667139259566154, 0.02822444780862757, 0.043067401341561756, 0.038660363892891576, 0.03274995068620358, 0.048212416869189055, 0.037628189993223975, 0.05132871786398547, 0.04100450560716646, 0.03794487924980266, 0.014945853368512221, 0.029672658669629266, 0.061546104960143566, 0.030054378722395216, 0.03504520395238485, 0.033458809434835396, 0.04319786326959729, 0.02067694503680936, 0.014042920882015355, 0.025661827996373177, 0.031354672342006645, 0.05209307059911745, 0.06823109981736966, 0.01706590550020337, 0.0335255297832191, 0.022533581392573457, 0.045606506522744894, 0.018761980114504695, 0.012584414948443217, 0.0030143050950885352, 0.029556300091956342, 0.033009361409183056, 0.06593421128179346, 0.05964288208633661, 0.047361730730959346, 0.060171148739755154, 0.03183580456035478, 0.021973398148215244, 0.00838382262736559, 0.04266119635264788, 0.06562137271144561, 0.04048304805266006, 0.046611535628991466, 0.04160507355949708, 0.028008607515533055, 0.042312225792557, 0.0192576838723783, 0.04647843759240849, 0.057717722175376754, 0.044951068836131265, 0.01229943787412984, 0.0800614392917071, 0.04536249515201364, 0.02395446425569909, 0.03040359016241772, 0.07969432470521756, 0.014558613433369567, 0.016648767615801523, 0.05232048161061747, 0.025010965332122784, 0.046776121083114824, 0.0502887950944049, 0.021732355368190577, 0.005953068038382168, 0.030971344161246504, 0.01583530081968222, 0.008603543292598, 0.01272773850775723, 0.05028650164604187, 0.03065130633435079, 0.08516658749431372, 0.024641123034858277, 0.049621513579040766, 0.016845206896375333, 0.029202671388962438, 0.021619538743314997, 0.08241219672241382, 0.04128414685172694, 0.04609836298706276, 0.061878946742841175, 0.034949350702975474, 0.05183550888406379, 0.016373869331021394, 0.04344409005716443, 0.043438559996762445, 0.031001114885189703, 0.040539593768439124, 0.027257067217890705, 0.03928411738680942, 0.05506729314635907, 0.00221411426069348, 0.015720474034813896, 0.03322415166933622, 0.04672714103279369, 0.008569590248433607, 0.06659817136824131, 0.08310351534081356, 0.038564856696341715, 0.041277612559497356, 0.03274739260918327, 0.017537431359024983, 0.059416862071624825, 0.06473897863179445, 0.022515137114429047, 0.0283928890379944, 0.013171054273178535, 0.0220225172982152, 0.015192568701292788, 0.026273422142756835, 0.04382005274029715, 0.01121629327203014, 0.02930415647902659, 0.0418613528433655, 0.07483594611819301, 0.13590130901762418, 0.05550279388470309, 0.02763139463162848, 0.03569527103432587, 0.02018305636011064, 0.007324413180218211, 0.04572012381894248, 0.02514846875731434, 0.04901997532163348, 0.04548381042799779, 0.0070153409033082426, 0.01760870637372136, 0.033840431100023646, 0.016084864303203564, 0.07375807967036963, 0.034372453444770405, 0.03955073415168694, 0.03954273422381707, 0.03425055123599512, 0.05149513875533428, 0.008882708714476653, 0.014995255806882466, 0.01374766230583191, 0.0316279489280922, 0.025698457013017366, 0.036130049132875035, 0.00956013856921345, 0.04486250305282218, 0.04695815506524273, 0.07324611142809902, 0.010058507273372794, 0.04475611893992339, 0.05495504988357425, 0.12110436015895434, 0.043836510607174466, 0.03852923021518758, 0.06389932547296796, 0.008818799197407705, 0.055207040826124806, 0.06872455762433154, 0.009921651000955274, 0.04370326668556247, 0.05206212940226708, 0.02289411418938211, 0.017582513225663985, 0.04586342702220593, 0.03826202651751893, 0.02868652676365205, 0.028411068687481538, 0.05352756826739226, 0.05773575763617243, 0.07464898936450481, 0.06315511504986457, 0.02723600040189922, 0.0116394879296422, 0.04597101214208773, 0.028439502697438, 0.039027013682893345, 0.00805453212732183, 0.055689000857195685, 0.0380203119878258, 0.030126917508563826, 0.048705552372017076, 0.03831559346456613, 0.0662531770233597, 0.0327198712288269, 0.01878466014750302, 0.007294493178570909, 0.08273963736636297, 0.05694915913045406, 0.05966800145272698, 0.054296219521867375, 0.018012115798358406, 0.031210527755320072, 0.02109540776083512, 0.032541185817016025, 0.013135665279280926, 0.08174373116344213, 0.039138062724045346, 0.05821768713316747, 0.06738818969045367, 0.01979834057523736, 0.04473855166829058, 0.02025179535017482, 0.02068137078146849, 0.015454164307032312, 0.04490260786509939, 0.09326612430491618, 0.029157172223286967, 0.01690434631226318, 0.07332517432847194, 0.023285851115360856, 0.021404329487787824, 0.04279025710586991, 0.029732627594577413, 0.045104919866259606, 0.03546598387349929, 0.019128563747342144, 0.02645097440108657, 0.016461916035041213, 0.022460984930928265, 0.005972489831037819, 0.020052691123315265, 0.04062511632218957, 0.040126379512782605, 0.036206391107823165, 0.09160768293908664, 0.05602933366649917, 0.019966910726257732, 0.06952266408396618, 0.06189994740166834, 0.04251789654205952, 0.009601022848593337, 0.029578298197260926, 0.058322072960436344, 0.067555903191013, 0.027803932516170398, 0.07258426158555917, 0.016238013049587607, 0.031443404366395304, 0.052854855079203844, 0.02923388060714517, 0.010452340872559165, 0.0513323140995843, 0.039780981439564905, 0.01589617389254272, 0.004558065349036562, 0.01255095808301121, 0.038774853106588125, 0.033810718051557026, 0.024526128312572837, 0.03531917264418943, 0.045770460939300914, 0.01455382806515055, 0.030467732077730552, 0.025429472160924758, 0.022783255138035332, 0.042278407607227564, 0.021977703452908566, 0.04657314411763634, 0.08723324909806252, 0.024398809698011194, 0.06206716557166406, 0.04702812898904085, 0.02470237439099167, 0.04000320844352245, 0.03871811740100384, 0.016838735368634974, 0.005054213547347379, 0.0074267430463805795, 0.12097693128245217, 0.11753044836223125, 0.08647178352943488, 0.09563128703406878, 0.14189692586660385, 0.13553135815475667, 0.12562252128762857, 0.1320602444133588, 0.1421566555010421, 0.09499503153243236, 0.1750248782336712, 0.10045476177973406, 0.09921691034521375, 0.137540731046881, 0.19251128206295626, 0.10516238345631532, 0.1505707340048892, 0.07452002021351031, 0.06980959618730204, 0.10341247556997196, 0.0855675202661327, 0.12592707494539873, 0.14941193190004143, 0.14919535709278925, 0.12806853146425315, 0.15402675712747232, 0.20290730707347393, 0.11073386842118842, 0.16344314041946614, 0.058860646560788155, 0.117710002298866, 0.123618305261646, 0.10246250618781362, 0.18304844626358577, 0.13891048968902656, 0.06911962106823921, 0.1032310760180865, 0.10416861463870321, 0.0976127924929772, 0.14884774360273564, 0.11290088535419532, 0.0835357014355915, 0.1331074953611408, 0.12362840186272349, 0.14190462045371532, 0.15960826405457088, 0.1437212894005435, 0.1470262570572751, 0.0981179957411119, 0.16627469419368676, 0.06353580033672707, 0.14485639706254005, 0.1311545901532684, 0.07920298392751388, 0.10604905230658394, 0.15826187415846757, 0.09250986988523177, 0.13984682730266026, 0.11647171660193376, 0.1720578210162265, 0.15145517726029667, 0.12057802054498877, 0.1881486547312566, 0.07960059866309166, 0.11696811925087656, 0.20593856727438314, 0.12239554444594042, 0.08264982647129468, 0.0958000590492572, 0.08271688608718769, 0.09737208219511168, 0.1819349295858826, 0.11152589520705597, 0.10057649774742977, 0.1831291105066027, 0.14110066502221993, 0.16669686511158943, 0.18849197987999233, 0.13008253196520464, 0.1412526432956968, 0.12375380870487009, 0.09489075427076646, 0.19528378971985408, 0.1510275373501437, 0.0788584238450442, 0.2555684505828789, 0.16141179656343801, 0.11384007281490735, 0.1650365170623575, 0.15691484643944673, 0.12350963109305926, 0.1061499843906079, 0.10109058301895857, 0.07489696677242007, 0.1479865469570671, 0.1749132727938039, 0.2279278923358236, 0.11042248870113067, 0.12589170970022678, 0.13675842088248047, 0.16617003695241042, 0.21447445638477802, 0.12858957850507327, 0.1438225403960262, 0.10513923862682921, 0.18379783390888146, 0.13957944379321166, 0.1027004277067525, 0.09142443777195045, 0.1309420729854277, 0.17792747462434427, 0.0963549582021577, 0.2074886533830847, 0.1760366146585771, 0.17077028724764073, 0.10595489878739629, 0.17541066610387393, 0.06631832317050014, 0.1048592615074345, 0.14038354850241117, 0.15551321022212505, 0.1393089254519769, 0.17438324194933685, 0.1035239045907344, 0.15686960172440323, 0.15535762214234897, 0.09228478624884572, 0.09683644665139061, 0.17617964984050818, 0.15743288078478404, 0.18180694431066513, 0.18607735873333045, 0.277507984744651, 0.17137070931494236, 0.13120930721717222, 0.1881904932005065, 0.08509873399244887, 0.11697379180363246, 0.15504693452801022, 0.13433766577925, 0.12933085087154592, 0.1596953608095646, 0.1211286788540227, 0.16587102014039243, 0.09440024130578552, 0.13262793395136083, 0.13665320724248886, 0.08830583654344082, 0.07929893556450095, 0.22169797734490462, 0.1496196993227516, 0.11562859612916197, 0.07931727636605501, 0.09082452460591282, 0.11390351583915097, 0.1015484652348927, 0.12284501961299352, 0.1156183909624815, 0.18127398219491753, 0.11425578407943249, 0.09976220822760037, 0.16162545367011003, 0.07354714348912239, 0.19400568758802755, 0.2005454623805625, 0.1618258250611169, 0.1782194482428687, 0.13273043345127786, 0.11940441280603409, 0.11231138770069395, 0.11642443628183433, 0.17155183745282038, 0.10780110436358623, 0.0961781930444496, 0.10182241696332182, 0.06581645152930703], [0.011042935208284428, 0.0221356002480856, 0.02010148796918137, 0.022954731115273068, 0.02377540564962796, 0.03528316618342485, 0.0508848066840853, 0.03705612051167658, 0.020671401405707, 0.028260520426556468, 0.0032942938768038793, 0.03880022692361048, 0.029153012803622654, 0.03625470280115094, 0.09138162899762392, 0.022961899837745086, 0.05034581917737212, 0.10646232763039214, 0.07006186872188534, 0.02925589567582522, 0.03833083675376006, 0.03092227250869785, 0.04780993364485247, 0.05857071533266987, 0.04899334282215152, 0.010503169930806118, 0.07984846072005373, 0.03522296655657036, 0.022350667011258856, 0.014722087786399891, 0.02597946041662778, 0.014539175101422837, 0.019174829657588686, 0.020227751461789012, 0.012873263065037983, 0.03148816732157554, 0.01033841653926564, 0.023555131130186573, 0.03405785746872425, 0.01651446517956044, 0.03866634178640587, 0.051691913910742314, 0.04079603590071201, 0.017249456008097956, 0.038371514928128035, 0.0811235840831484, 0.06231025752744504, 0.1094965258879321, 0.06422424196664776, 0.036009066339050017, 0.029659349205238477, 0.03656665249062436, 0.06484583432653121, 0.028990123687045913, 0.07703259467546429, 0.03939016901754907, 0.03016154993591564, 0.03221386391669512, 0.023792189213314226, 0.05580940689625485, 0.028516777658036778, 0.020169665471517613, 0.02697240311785468, 0.03822979949680822, 0.01944041165656277, 0.02627757308073342, 0.044531004769461494, 0.04976674721443227, 0.01380847261420318, 0.057391801449869356, 0.03648443100973964, 0.012130545418975609, 0.017014788064573492, 0.08829446429652826, 0.061408823755170615, 0.055349085346928666, 0.048954211707626066, 0.02370196780455964, 0.04278952428804977, 0.0232779716274568, 0.015273636672645807, 0.059059396253100464, 0.03483814559876919, 0.00818655129322516, 0.050149077948715, 0.03504750418609806, 0.007138654040837926, 0.04349101414637906, 0.010805838957561978, 0.04636317484879068, 0.031276908836194446, 0.01698951772414148, 0.03471113062862839, 0.0157634711026081, 0.01809363838817392, 0.0405536123019244, 0.0330799765485738, 0.01812996545673481, 0.041752444580197334, 0.03072632516601256, 0.007737783498929015, 0.014618967426940799, 0.04269438689308507, 0.020604925329930017, 0.011708943622319825, 0.053939632406192164, 0.030316774999456744, 0.0484601975019489, 0.00900268049112388, 0.015766502457803915, 0.031933635739343505, 0.02193536965309509, 0.017101723667500273, 0.025182604157764996, 0.03636272218344467, 0.09178839717060328, 0.046123455212052376, 0.10378705404166665, 0.03874926555103489, 0.0028926231981521206, 0.036182801837899854, 0.022703812258051972, 0.018011959735304117, 0.01590182100023542, 0.07218004470424992, 0.012640424621557551, 0.04956208408943244, 0.004810681816057435, 0.0024499308367791984, 0.013514488835686018, 0.03520756381164704, 0.028938650020531247, 0.02592651772179774, 0.03331542480736971, 0.05879074388316699, 0.03703943533556802, 0.09130243717559747, 0.048872081828968864, 0.06032195993299995, 0.03828792280650564, 0.01788717714537467, 0.0142649095505476, 0.0465434921373214, 0.04056096083617636, 0.03028834777485047, 0.0428321803919971, 0.02944037577669535, 0.09152736474892922, 0.023196769645437598, 0.013239040937540787, 0.04485267447307706, 0.055406923671918254, 0.05309728207066655, 0.03131174821672695, 0.18077470255749567, 0.023212353898478404, 0.002308370408302705, 0.03370639668511493, 0.028058140571894388, 0.025661461587463106, 0.005935566923913679, 0.02351259546620505, 0.05355778003909758, 0.05882599377738578, 0.03406681073829532, 0.04594733466261199, 0.03354238120040723, 0.06437867653689214, 0.06099188434226172, 0.017765610811433623, 0.07647747160600764, 0.013084051664918661, 0.039447861457509656, 0.005951738109745617, 0.04291496844962239, 0.032468599533396106, 0.03548212282891784, 0.05865015821265323, 0.06560329653854881, 0.030059159001601592, 0.013476247450203767, 0.027085216350055168, 0.026119454065337777, 0.019643471742581044, 0.057797606103122234, 0.020082678978464434, 0.007039564603473991, 0.016891890105658343, 0.10374271177819797, 0.021406310810042278, 0.03273444276835237, 0.018840863203097667, 0.03506110881322196, 0.05734051777315991, 0.019505001404987912, 0.10519384033977985, 0.041811446592743905, 0.02061521870616291, 0.02652679560040789, 0.07081240309136254, 0.09026651097727673, 0.024773685028776526, 0.10382580517658166, 0.015164648681612951, 0.03105574373954109, 0.02341694916997637, 0.004720269145244467, 0.06421795194702488, 0.020313793094828725, 0.040713685498173745, 0.021688620393563594, 0.020882673461788466, 0.03900351601519755, 0.02152104938535818, 0.06920772205506052, 0.02554335747845471, 0.021356755701292838, 0.037649197437401326, 0.004263152825712625, 0.012626600318721362, 0.02867092385089823, 0.03921509001936231, 0.034642303429011784, 0.028610510485512868, 0.021682951233482788, 0.08672036483351674, 0.032556951578174315, 0.07620024255343846, 0.07702854382140295, 0.022793931886553764, 0.0371359840833715, 0.05257352767512202, 0.023285735764407685, 0.0236456341309739, 0.015054049169910806, 0.1371424581323351, 0.05206985452345439, 0.05090009068538036, 0.039481099495398145, 0.011935987376741, 0.01286105452371495, 0.020404691342264414, 0.04371364827134779, 0.0112789916040908, 0.04456989161138024, 0.10249895030366522, 0.042480845137366226, 0.010132694051467946, 0.008636212209239602, 0.026875864548076476, 0.033201600557991436, 0.03963183944246598, 0.043663725057350736, 0.03830156136038048, 0.024068612505548766, 0.030565722712448666, 0.04477226807336722, 0.025980864984116385, 0.08284394176942961, 0.024435381039178798, 0.03513997493843947, 0.03777367129389729, 0.05469053318457944, 0.03706570481881499, 0.023072933611859168, 0.027093073785571114, 0.035081973765045404, 0.019089861806215982, 0.04677656891622713, 0.02911894695301141, 0.03217095336211579, 0.0538659163617662, 0.04781595225046788, 0.05822201618658645, 0.024734811757558157, 0.052636913023889065, 0.03702850752909269, 0.011881648596110088, 0.0041712940271411625, 0.008738286776601203, 0.034096611996314356, 0.05087906288515244, 0.011054474544445319, 0.02915359634373869, 0.04116955925045269, 0.0374534197284707, 0.032227906198906045, 0.026787858556157777, 0.055124592036008835, 0.05736201376255069, 0.017548008023628166, 0.1376241230006729, 0.03587024485958474, 0.027710247186145613, 0.026694256346672773, 0.02439226013874369, 0.03284002960260425, 0.06461282540112734, 0.04036623485652464, 0.03475573752075434, 0.034838345766599686, 0.02865832345560193, 0.03427764853196485, 0.04298049118369818, 0.0066119501383842105, 0.048582978413573334, 0.02951794250735215, 0.026751767278515866, 0.018490189520109977, 0.06320591696671077, 0.05668503598177007, 0.07027165817895106, 0.07983775343745947, 0.01848838970597301, 0.020143175464389578, 0.04072566503392799, 0.007895358838140965, 0.022135795326903462, 0.05683838150330952, 0.04097945409427796, 0.006773448682257107, 0.054843831208667586, 0.007163080453340496, 0.038205765786447694, 0.0478427475983543, 0.032481417059898376, 0.02424600870082421, 0.02308034321426281, 0.05211780320054718, 0.06551992494080748, 0.10814157966524363, 0.012886747252196074, 0.024052984147731746, 0.02526433709343629, 0.018200617915551578, 0.07517600751348905, 0.01985073535303984, 0.038507561199367046, 0.032262385955878665, 0.02411616763233074, 0.050533915869891644, 0.010340897432927574, 0.026910318859985898, 0.038955753935234885, 0.015218631231359072, 0.06084013677069119, 0.03116564605651157, 0.024577574837686758, 0.04971902584657073, 0.07838027378810303, 0.0472028110442417, 0.04891444955553327, 0.12380066833325795, 0.12412781720714909, 0.156234045113836, 0.10293810495308467, 0.143944025305765, 0.10546291340142488, 0.13205394760838576, 0.12287986917155129, 0.07488934003881045, 0.1278671829828194, 0.08404773074601378, 0.09145383869430848, 0.18344955545450958, 0.15415789080517633, 0.18039105885795184, 0.08058568901781525, 0.15299237120364392, 0.15890338830649853, 0.23218846800071852, 0.183279066745724, 0.1399599662316697, 0.09363706582891089, 0.1016160948202014, 0.14985236898064613, 0.161746762160744, 0.13837110863200255, 0.22496933037681238, 0.14191444564078534, 0.13668370060622692, 0.12914671003818512, 0.09121693497789757, 0.12150005464042936, 0.0695567943954042, 0.09009697221751724, 0.06819190084934235, 0.18207814118691854, 0.1399437085326229, 0.10229638045919792, 0.12174098885485105, 0.10804920390780483, 0.08972966764122248, 0.1234573567552226, 0.08683792781084776, 0.09961522397186075, 0.135327974068267, 0.17576422356069088, 0.18780143479151384, 0.16295391667102063, 0.12141971609422139, 0.1620756752256836, 0.09841820677476269, 0.13072999007999897, 0.1857130532818181, 0.14427641247000011, 0.19005976218198026, 0.0819992810221655, 0.11533217132091522, 0.09504437459898846, 0.12687137856015138, 0.359355484268495, 0.07625630311667919, 0.19413986110261508, 0.12742699017482145, 0.09985159164560692, 0.07794719881245069, 0.18357534227626665, 0.14218819380870887, 0.17577729214515003, 0.08086424799902098, 0.1737682856619358, 0.0762562013364264, 0.07528324997318642, 0.14178441118981155, 0.14643423525350435, 0.15561651039336408, 0.15805447314466747, 0.09706290771386453, 0.11372922733426094, 0.08755452864404235, 0.05248418157654149, 0.09229507283972842, 0.266210349542754, 0.21649379017097609, 0.12697697217975343, 0.12196086134229388, 0.12914840637573174, 0.1342623076800789, 0.14797194488346577, 0.09816064166703395, 0.12934463870312485, 0.11524419247039727, 0.0662811937342797, 0.15329700628561632, 0.09875739285988466, 0.1770948035908597, 0.17287042098385946, 0.13376955554953643, 0.12873709201812744, 0.09230351381536041, 0.09861758750464235, 0.0781741077080369, 0.15161974914371967, 0.20816129871777125, 0.08095737014498029, 0.08217405807226896, 0.18183217224265846, 0.0872945547369974, 0.11951839311846665, 0.10188381081180913, 0.09753879824919359, 0.11170717262263809, 0.11167668604425021, 0.1902774362159627, 0.12162645214370318, 0.13903605937957764, 0.17493851429649762, 0.11473103000649384, 0.18849830382636615, 0.0819745823474867, 0.08814817893185786, 0.09262202493846416, 0.1598423450653042, 0.08036904635706119, 0.12593299177076134, 0.13689602778426238, 0.13302179638828548, 0.10335988232067653, 0.11031234889690365, 0.07306800277105399, 0.11601253838411399, 0.14105850085616112, 0.05987092413540397, 0.08706516240324293, 0.22584358203623975, 0.20049459939556463, 0.15739245366837296, 0.17465483237590107, 0.11166579555720091, 0.1301974215145622, 0.1499202089118106, 0.11862014846077987, 0.17143301240035466, 0.1564862294388669, 0.14595618019146578, 0.0931240865694625, 0.12156030855008534, 0.20227654092013836, 0.20752312296203204, 0.1515279162142958, 0.09656228457710572, 0.10960243841899292, 0.11878815373139721, 0.14311827532947063, 0.1365603157984359, 0.29171762083257946, 0.03878155703257237, 0.07695021373885018, 0.13360134671841348, 0.07825665149305548, 0.12470094859600067, 0.10424779967537948, 0.12493929080665112, 0.15067763041172708, 0.13306762464344501, 0.12558843168829167, 0.13037982529827527, 0.10099590024245636, 0.15746003575623035, 0.13377297536603042, 0.16568692001913274, 0.13378912449947425, 0.13307523780635425, 0.12219571588294846, 0.2211316991597414, 0.18778126873075962, 0.07610622474125453], [0.029612560823027576, 0.056907683677439175, 0.03483364351892045, 0.04355074558407068, 0.008589601942471095, 0.024484466262427822, 0.07588957529515028, 0.03151669632643461, 0.03182828639234815, 0.033207364712974856, 0.05916341567145927, 0.03530886908993125, 0.052058102296931405, 0.04621352395042777, 0.04069891379081777, 0.01327087780061577, 0.03510268943916474, 0.03926988850746836, 0.0284628476947546, 0.025948391994461417, 0.06447333895734378, 0.05223015842161008, 0.023073812314708318, 0.015921895458762134, 0.04078774081010904, 0.022788418789527247, 0.025808148984132067, 0.02943881175347737, 0.03687935535396848, 0.05488952036414828, 0.03934720078749316, 0.045692042647195716, 0.011199781970520104, 0.024668128728600483, 0.025981935373108302, 0.03261761939419167, 0.042271147282528024, 0.04790641114647899, 0.03788378395672355, 0.03652961804930653, 0.02355812007694372, 0.07666855385260922, 0.03980863852692502, 0.04631510742806962, 0.010240609957171338, 0.060989305909190855, 0.02865178577069725, 0.027578584251127074, 0.039404696452298334, 0.08375760274274008, 0.019973249939669455, 0.015593379336808409, 0.05707276785480125, 0.027486137247511318, 0.06885326893201896, 0.06792980991303921, 0.051687537359872034, 0.07386880301471267, 0.015400108814771687, 0.012000777292996645, 0.04394174460321665, 0.03287387153665934, 0.06417499389499426, 0.021478378014372926, 0.06426405840154205, 0.023031917866319418, 0.122669767588377, 0.0163941727951169, 0.05136908730491996, 0.023530537628435662, 0.04669588092448456, 0.020580068895859376, 0.02505340939387679, 0.06925809649484498, 0.01807596255093813, 0.03005281469917723, 0.059005948049681525, 0.04526437898831708, 0.03127040847071579, 0.035794530529528856, 0.03160668703328286, 0.045624776078122, 0.023076216025011878, 0.00354465442692994, 0.02484594052657485, 0.04744286994848933, 0.014485625117751104, 0.05702710923339639, 0.05762799948986087, 0.06206936402512448, 0.03054978053218552, 0.023949906196711317, 0.015659533108451536, 0.04489267750510147, 0.031116370843457322, 0.006427998870744237, 0.07016707557652678, 0.015510296116450002, 0.04083510933976088, 0.02356521416056369, 0.020719629978494983, 0.03201701072975993, 0.03854140991877232, 0.04104471219969647, 0.03707628657243081, 0.08446040895900556, 0.020718330583934273, 0.06373661277549607, 0.03543855409537043, 0.06317160345081772, 0.03516487717362387, 0.011769322212785482, 0.058276651826288016, 0.03196940132017646, 0.04069177560242159, 0.0414011398596423, 0.06680372676679067, 0.031509419038359604, 0.07469424765024867, 0.013154586228275937, 0.024163079847182547, 0.013428180029482713, 0.01900345885327884, 0.05340247355135424, 0.046136720571666956, 0.017041635998923863, 0.057480526688907824, 0.018195101425849965, 0.011019726766140332, 0.032034337121461115, 0.008768437480154847, 0.01151145006796079, 0.08071832225791045, 0.01761056386333491, 0.027607645905975784, 0.05169935743989689, 0.04895530754168119, 0.051795801014772484, 0.01302864758430847, 0.07526003729019846, 0.04855436798451202, 0.007633108446108443, 0.007329095920015658, 0.01658393698744476, 0.04116600711963006, 0.040619535371661186, 0.06331277944679771, 0.03443541470915079, 0.06378953850695065, 0.07440236224127666, 0.09046596634600844, 0.05762368400714227, 0.06462609076074191, 0.0326379381253251, 0.03804222188357796, 0.03546988544985652, 0.028607582606907402, 0.016098837035575082, 0.06723870164049522, 0.014728377806022763, 0.027358496328815818, 0.022654598113149405, 0.06416094143475805, 0.006473179973129715, 0.038315956480801105, 0.012836018277864372, 0.0073968298300834635, 0.04154723523450749, 0.08923090369041477, 0.03427171474322677, 0.03345914530966963, 0.04585981382323163, 0.053582543174603155, 0.017411471510838186, 0.0029616806755906767, 0.01789401168935001, 0.047728584081466706, 0.04913463756175978, 0.016033039494816746, 0.0406801217634763, 0.011530846839637628, 0.019051465205848217, 0.03703675512224436, 0.0106837586333443, 0.03346890942858798, 0.029743938773338283, 0.02796058080691312, 0.06963136539395366, 0.05331656423264316, 0.022326575625421743, 0.01374549777912242, 0.06278001410620553, 0.018688922249046818, 0.040083465565528185, 0.0581836314605815, 0.0730396332219243, 0.029732061017836844, 0.024910515007962073, 0.01374119586710419, 0.017258697655051947, 0.024445012843768512, 0.016404408495873213, 0.02764550476734127, 0.013666342428353215, 0.019348146161064506, 0.053083399244185, 0.019472022906744053, 0.04466262699237891, 0.04427659145689436, 0.04081202218575137, 0.04840911738574505, 0.05622577294707298, 0.03915256641006895, 0.05840598060084241, 0.05482677623097386, 0.04292270374883499, 0.03291094669007829, 0.022604530710460882, 0.054775319527834654, 0.05021054643605437, 0.061348345928958485, 0.09170493057795934, 0.03448283752160413, 0.020798105946076766, 0.014523275329598358, 0.049190545454621315, 0.03638103584359799, 0.020714903982090097, 0.10119583737105131, 0.029077627563050816, 0.06026416910546167, 0.11505941381411892, 0.023878453066572547, 0.012995770018148636, 0.008432153828575142, 0.008793706124249314, 0.006936629568891866, 0.032064419971512895, 0.03890111151018313, 0.02009787137753197, 0.045500095268445354, 0.06173196927245174, 0.064694826358131, 0.019580591902402893, 0.031003082636743784, 0.10578430829835789, 0.04044950806668826, 0.043234856998814006, 0.03482894127124122, 0.018744884424709847, 0.037630076320575814, 0.05517709707575185, 0.022972171161589876, 0.023717197523053204, 0.01458032485762877, 0.05745101720094681, 0.03682167648470827, 0.001218217599671334, 0.02496773756242224, 0.0157925140977438, 0.0151115346566907, 0.017551904510972754, 0.028845412523618767, 0.03680652819041695, 0.05673285234453423, 0.037436191724347215, 0.017168126800762754, 0.057707978412508965, 0.02594891785910087, 0.009323108475655317, 0.03387352325288313, 0.030968348429139172, 0.08095656947365829, 0.07847079714494092, 0.017610580826710378, 0.041792328868593485, 0.016125649346836975, 0.02996264078787395, 0.01572885563863175, 0.011708940229644733, 0.07583418648157801, 0.07693386104490076, 0.03516192215361765, 0.031274995367441855, 0.041278335199292214, 0.01624679159639137, 0.014321436606613653, 0.07974898748631988, 0.017483236767085533, 0.01487289897964469, 0.05720540788024664, 0.05819283239543438, 0.08053618310285465, 0.04073648088212524, 0.03988270401688559, 0.05056565773806401, 0.02482318924739957, 0.061075045594147274, 0.004320209987261998, 0.04442006429391248, 0.03605165798217058, 0.048137645702809095, 0.01645596358659012, 0.04319054866209626, 0.03530875713165317, 0.08351655317736523, 0.017180182671706592, 0.04618834690856082, 0.030644660083843128, 0.022541757739548172, 0.03132761575813804, 0.02474389225244522, 0.044556714461318085, 0.031686696490006785, 0.05094467722145574, 0.03864982285137687, 0.0367325000198824, 0.036628117585288625, 0.04076581055830632, 0.03621554115254964, 0.012771129974031022, 0.021891364960798194, 0.017366220010444522, 0.023502592163692628, 0.062058263192219396, 0.047568222507834435, 0.02141587476113013, 0.041851785499602556, 0.016318136160927157, 0.027178425009229353, 0.038284502990011654, 0.03593295845868332, 0.025870752321290116, 0.008442872985532241, 0.04414873171065535, 0.017215970304927657, 0.008579324681444891, 0.0437649014139814, 0.05380280242700662, 0.03513215821502464, 0.016130726485114013, 0.07282037820134844, 0.033907548391393254, 0.016686884320474098, 0.04801846441945859, 0.03120330475004656, 0.06499557343444654, 0.034913680117045126, 0.044251855462789536, 0.0632012350750821, 0.011766807392372616, 0.03272840041401131, 0.1958411926669734, 0.19495813362300396, 0.12562857381999493, 0.1553608655397381, 0.0848541831863778, 0.09529977518000773, 0.11149820419294493, 0.08644487283059529, 0.14631581732204982, 0.07566219142505101, 0.1185273112995284, 0.1505644100585154, 0.17179769783147744, 0.10670902260712214, 0.16775645182601043, 0.13726673860635075, 0.11591582000255585, 0.1128449197858572, 0.17712695258004324, 0.1700082788509982, 0.103618892707995, 0.10652446108204977, 0.11827501840889454, 0.09349437669983932, 0.12611055081444128, 0.09177457541227341, 0.1099057774990797, 0.14402854362768786, 0.1283046073679413, 0.12624097881572588, 0.20238909630903176, 0.17686122469604015, 0.12347027606197766, 0.1508763733186892, 0.09053324309310742, 0.09397693044905152, 0.1669369443718876, 0.11903243990881102, 0.14091324007936887, 0.17259971265281948, 0.08461609881903444, 0.16703027007835253, 0.15542555706841604, 0.10584766989839928, 0.1506881612752165, 0.17845198219375952, 0.10636388576988663, 0.11690481193363667, 0.07786025812051126, 0.15044857056013175, 0.15204703621566296, 0.10850102680602244, 0.21909266071660177, 0.1342551830623831, 0.1060710164851376, 0.1920545194298029, 0.11562106439045497, 0.16583311717425073, 0.07725309820047446, 0.07635562028735876, 0.12233409631465163, 0.10785204198743616, 0.17863961069711617, 0.11559693568519183, 0.10125050693750381, 0.1258300580084324, 0.16276084631681442, 0.11844332223492009, 0.09012922977230378, 0.214850283360907, 0.1923409697732755, 0.09355275106749364, 0.11600975639053754, 0.15895630046725273, 0.18752091484410421, 0.1334412395954132, 0.1369964238256216, 0.0805124140211514, 0.09484003377812249, 0.17617289163172245, 0.1518890732633216, 0.11481043217437607, 0.13219924909727915, 0.1928530872932502, 0.08911065371440989, 0.10970149774636541, 0.1078059830303703, 0.21302920393645763, 0.1224389299750328, 0.16933745199016162, 0.10937965501632009, 0.10242281867457287, 0.11194983710135732, 0.09286018394465957, 0.10479475996856179, 0.09560941785041775, 0.16890871285327844, 0.16092117503285408, 0.0648736949743969, 0.090075204814119, 0.12772125724170888, 0.10874776928020374, 0.07359326351433992, 0.12675547120826586, 0.14619897359183856, 0.19642075656780175, 0.09025982062199286, 0.1268114096352032, 0.1213992243366582, 0.17341121339372226, 0.12622081275497163, 0.09148006407277924, 0.1539601521300418, 0.10576158416058336, 0.1440615611416953, 0.15186658661280358, 0.11527224310806819, 0.12364683087382998, 0.09799826823707138, 0.09594462772033044, 0.12689492372529848, 0.11445060505398683, 0.1230926306119987, 0.17191459584449018, 0.10206086095422506, 0.12443361936935357, 0.10502742962645632, 0.12298699628029551, 0.09020283725112677, 0.14073667169681617, 0.08230612812829868, 0.0904356154746243, 0.15801674659763063, 0.10753276411976133, 0.13120922579296998, 0.19117749934749945, 0.12949448637664318, 0.12243339312928063, 0.13285972151373113, 0.1759201916200774, 0.17608336572136196, 0.07622437804405179, 0.09511784637080771, 0.1210667828896216, 0.11486778195415225, 0.12363167240151338, 0.12160895951092243, 0.10317716641085488, 0.26203977476273266, 0.17304472305944987, 0.1854236852377653, 0.10718993430158921, 0.13076558602707727, 0.10679388019655432, 0.13513385877013206, 0.16196039212601526, 0.15352492619838032, 0.0780889583485467, 0.1745901137058224, 0.06935701332986355, 0.1320061787430729, 0.10714709160051175, 0.11949619145265647, 0.09967409367007868, 0.13236525947494165, 0.13473706506192684, 0.12384865432977676, 0.1513641042900937, 0.20529831520148686, 0.18801871527518543, 0.10773909983358212, 0.14223790328417504, 0.2107157523610762, 0.14645018082644257, 0.0641650804983718, 0.1679162196815014], [0.025681463103475313, 0.05473221219809992, 0.050901430792042186, 0.028230764969651188, 0.009581002672868115, 0.03556133500699486, 0.0532070520733084, 0.03744657670280763, 0.03449969572414245, 0.03629590344748326, 0.046062916317688565, 0.01942148052954248, 0.012743972458078392, 0.026300767104008367, 0.008828168069677693, 0.04519464933712568, 0.018106885088075484, 0.030233980156481266, 0.014299253600516489, 0.058877725287207534, 0.014721590759498733, 0.027928528508969715, 0.014346104747216617, 0.051192125372056446, 0.021053040034270713, 0.03423900256997772, 0.11921635004026548, 0.03396042662539652, 0.06447588346366372, 0.06012530691389527, 0.08573847037873097, 0.053737700384642394, 0.06094197130628994, 0.030434989370405674, 0.10714896435716323, 0.031525720842182636, 0.028514433319547346, 0.05399550976497786, 0.013948714776363755, 0.03342386148869991, 0.01675089561779584, 0.03616218115868313, 0.03977339541805642, 0.010899274925967413, 0.01969887751952878, 0.010589600873312779, 0.0672790269766535, 0.051460126348372014, 0.028060025202908685, 0.03193803603893944, 0.07586518874658005, 0.027979747724852393, 0.020312391920015216, 0.024317992784615074, 0.08909017552754708, 0.02033355542724686, 0.05450536097799029, 0.04312865948304534, 0.029312699234911373, 0.07370458396949939, 0.008525448152795434, 0.04555650866989579, 0.03225723587508712, 0.04996555118954607, 0.009457223466597497, 0.039580627011933496, 0.017852112151948468, 0.059396336387310705, 0.02818952191488019, 0.05609041199620281, 0.042047800695789714, 0.02110343991911837, 0.002240703715610185, 0.08673605934849807, 0.039241077910576544, 0.040550691208669117, 0.01622031007095107, 0.013213665424180883, 0.02604443353733846, 0.047744003789765496, 0.011831682973674365, 0.0033460796694271266, 0.014762559007587177, 0.03609529796189495, 0.032441756688058376, 0.02132439466991595, 0.056793418380298784, 0.012286710253517543, 0.010677257419696875, 0.0676349660913859, 0.058968106151691506, 0.011230488224620265, 0.005353209155146033, 0.01979330075638635, 0.08369635817195688, 0.05643073802015611, 0.047016441223344634, 0.017121256994349614, 0.022461887382503067, 0.05552689544856548, 0.04872340462835772, 0.03121545391955546, 0.04146919692201274, 0.03257621518735375, 0.04036015857543264, 0.022183006097163473, 0.03719797504267522, 0.015013333676116807, 0.03703377974618759, 0.06881371034043175, 0.03878446116245218, 0.025776639514203583, 0.034025182614901235, 0.017568413267976472, 0.013806490443779953, 0.060156614519655704, 0.008615840043473457, 0.029444653939987932, 0.029510393805269684, 0.04460974536570055, 0.044056922529957125, 0.03712070347475154, 0.03494488594255277, 0.052951593816812546, 0.03563793143257499, 0.009650285339115985, 0.02953606957037534, 0.08764712153268711, 0.048781463477228365, 0.0722416624692934, 0.06499148186828409, 0.01692234954264547, 0.0133329764773537, 0.01200691464224032, 0.04206424159929156, 0.04932083435622709, 0.021099400939419866, 0.027559320641947643, 0.0568167023094637, 0.024112120170944502, 0.02468298694917134, 0.020181041111105254, 0.01975296693854034, 0.03261950572154351, 0.04073500506845968, 0.03797975255708609, 0.014921069876956088, 0.04520984173619321, 0.04738077042358262, 0.02369063287707312, 0.01755196727546198, 0.04605173406058124, 0.03750829964077898, 0.024581873357029896, 0.01340239739511162, 0.06557907962373324, 0.03944952726098044, 0.04357742897367903, 0.04428404177139912, 0.01652710628695786, 0.05488824471831322, 0.05137619835191539, 0.05473815277218819, 0.02683522199679698, 0.07525446651769535, 0.018787808549989547, 0.030387186578341892, 0.02574134212253349, 0.026535899844020605, 0.04990213530670319, 0.03576603884409581, 0.025833268350522434, 0.015813216201162765, 0.02920973833118166, 0.07759417061294828, 0.05300652801192232, 0.05754652779017176, 0.009213798180488604, 0.07993785092341048, 0.016588461119681597, 0.010687196261382528, 0.022195470785456042, 0.038137688368026695, 0.03986810872863446, 0.03065359639003873, 0.030820105490939956, 0.024237993505916426, 0.06379656134439365, 0.023884140886366367, 0.0155562838273389, 0.024881019090701426, 0.049432751922202964, 0.02503414748103491, 0.03667675158275025, 0.006880022784961122, 0.031701417307236364, 0.03287662299615996, 0.01840479758435062, 0.033140929349298985, 0.016903508321515152, 0.0782592570675271, 0.04224968521988817, 0.0341545215674809, 0.0038807266724428958, 0.04079745743157608, 0.03172227208103452, 0.05813025111066444, 0.05002471265782203, 0.08892493867980582, 0.06591000115232808, 0.07264035607555083, 0.030083691435200826, 0.07791775039264134, 0.036006036680191755, 0.025600049079262784, 0.03509659280202218, 0.09645723378551857, 0.0312219610703843, 0.03498904500156641, 0.030624385457485914, 0.038434130139648914, 0.0028299460703107926, 0.046231749401028664, 0.030169780565691844, 0.01562407795738961, 0.03168468802635159, 0.024738302820229104, 0.0417543682269752, 0.025364726349445324, 0.010682384599931538, 0.03655840829014778, 0.008961342441450273, 0.056181868338691335, 0.03840886488822954, 0.06479379069060087, 0.04655312054923602, 0.027777350906814848, 0.04195061751774379, 0.029365061782300472, 0.04321463665525828, 0.03631601183276091, 0.04478624250207629, 0.02218722488864192, 0.02335674106143415, 0.029424467523183142, 0.03546515606077654, 0.029970694998545305, 0.04028772496219192, 0.028186656800763946, 0.07758995012513228, 0.013510409143886395, 0.029581623018852303, 0.03321087613169636, 0.034698465772505314, 0.005678130737838468, 0.057997814645724635, 0.04064974035801632, 0.02296434934916241, 0.025824016525543163, 0.027722706785425544, 0.025489827850833535, 0.03934355705444302, 0.09593955906374113, 0.04302424651437572, 0.05871954520366021, 0.06886415941906826, 0.04218545509502292, 0.05570821696892381, 0.06405546316610915, 0.031722577421792915, 0.015161890436762145, 0.0476821994275919, 0.0408019629040999, 0.01396679349376687, 0.032161609934909005, 0.025556867110676, 0.007798083209698754, 0.05720591678151062, 0.01675841717847756, 0.03664578324449914, 0.04725409472095115, 0.05924849717744759, 0.05004674468987754, 0.06726979890039989, 0.059617559159440656, 0.07332888591502394, 0.028642771432974508, 0.022571635332756808, 0.02936785395390221, 0.02423202239775232, 0.013152033240268273, 0.02876874145918659, 0.04873117046164615, 0.009482930613947766, 0.038158851875258346, 0.03337591959695731, 0.020447347446211746, 0.025069572098020996, 0.0422256752582533, 0.057093883864581585, 0.036345348294292174, 0.007631155113423509, 0.026310507474201064, 0.04473064673532333, 0.05755665831800018, 0.015329181549272366, 0.022292954215247716, 0.03290445989530001, 0.02330644295683929, 0.06622743340475218, 0.0459545610605606, 0.05882197006472519, 0.03788718341716698, 0.03688804738755737, 0.09227899834513664, 0.1448326754782881, 0.04251977947673627, 0.05952389418546643, 0.035291179681995084, 0.056632683612406254, 0.030068655099187578, 0.05480868648737669, 0.0590790059151394, 0.023590937423120652, 0.0301712597720325, 0.034438922735197205, 0.05214109730773738, 0.038491747940757444, 0.0040526377602613396, 0.07683143618383578, 0.014949442818760872, 0.047424379869231155, 0.021635243436321616, 0.02283059143727379, 0.002806822657086221, 0.055938990121441226, 0.016008350998163223, 0.043993520217814615, 0.01403408041889114, 0.03100200037338904, 0.059573237252022536, 0.020556902013985173, 0.04385067841836384, 0.03371370789994087, 0.04670115653425455, 0.021399415197915266, 0.010153330845891364, 0.018109460128471255, 0.058520524097340446, 0.0460312728370939, 0.02976804712255086, 0.057589818324361525, 0.21455004518585546, 0.12174695996301514, 0.14112604223191738, 0.12693646363914013, 0.13134700911385672, 0.13026036242289202, 0.07543545894856964, 0.1254834487502064, 0.08045860619417258, 0.19789462962320872, 0.0867558250735913, 0.1326261426189116, 0.07546386242445026, 0.0506440353180681, 0.08846854924091271, 0.11851778466786657, 0.17164942435920238, 0.074522082959967, 0.1524698720978839, 0.09986894857138395, 0.07728885021060705, 0.07355945889971086, 0.1331603939511946, 0.11376111169478723, 0.12426701188087463, 0.10606706062597887, 0.12088304917727198, 0.14814866254372255, 0.1489163027810199, 0.09202459521059479, 0.16190380230545998, 0.14523419179022312, 0.11688725144735404, 0.1324787919542619, 0.17598035053483077, 0.21731151986335004, 0.13203165094767297, 0.08945743260639054, 0.0664884793971266, 0.11376039244766746, 0.2277593713785921, 0.14596006141177245, 0.11313175689429045, 0.12187433455671583, 0.11319922363119465, 0.0838186369676675, 0.1589576711079904, 0.1727102595780577, 0.16892140145812715, 0.10101964896810905, 0.1344264317303896, 0.10684669736240592, 0.07976088220519678, 0.09394871696297612, 0.1758840392742838, 0.16223209111818246, 0.24753356458885328, 0.11364851559379271, 0.11475749287222113, 0.20834214187094144, 0.0758092367489423, 0.07409508087273155, 0.12639753041522844, 0.09751868647124086, 0.1308462502700942, 0.08476891169058424, 0.06923588125833444, 0.20560732004897936, 0.1242596972733736, 0.1440521702170372, 0.07603094806628567, 0.1356658030833517, 0.13484383933246136, 0.2465950149510588, 0.09819120966962405, 0.10062619365219559, 0.11723158082791738, 0.10328949788319212, 0.12687536834606103, 0.15757250972092152, 0.10717029749814953, 0.11369469668716192, 0.09383783077022859, 0.11463934635477406, 0.11109716285552297, 0.10488533082285098, 0.1794767736324242, 0.14552037071968826, 0.07921584216611725, 0.15461776112871511, 0.1201153817985739, 0.21594861442489283, 0.139538704550692, 0.07192937351231064, 0.12236681527325086, 0.12329005716102463, 0.14828199467488698, 0.13147279593561376, 0.07117220985570125, 0.11349836936486618, 0.14077073415475233, 0.12537697303508008, 0.1552720588764974, 0.1168536911053317, 0.11937317305377551, 0.17313374685389654, 0.21228056267968246, 0.150491114705801, 0.08406487054058484, 0.1334101084087576, 0.14989355605627808, 0.17690644226968288, 0.15921346523932048, 0.1431395270462547, 0.06833325326442719, 0.22620119713246822, 0.07093694819403545, 0.1575023356292929, 0.1292481374527727, 0.13608847611716815, 0.05857685607458864, 0.26292480155825615, 0.09268985129892826, 0.11324606968888215, 0.07074978787984167, 0.14582461225134985, 0.08150165701018912, 0.2595972115440028, 0.13986840471625328, 0.12383926340511867, 0.15815942894135201, 0.0502629904076457, 0.13425286247261933, 0.12465495749243669, 0.10393233517450945, 0.1774776466190815, 0.10426688686545406, 0.15206846435155186, 0.16777131174291882, 0.2053017078765801, 0.13621955551207066, 0.11039886211178132, 0.12209346065563814, 0.14573130011558533, 0.1590085340929883, 0.1139432101377419, 0.1635013451533658, 0.1361471286841801, 0.09430604707449675, 0.11981639212795667, 0.08367225660809449, 0.27128329447337557, 0.12240617030433246, 0.18533968260245665, 0.107276488228568, 0.16004715407533304, 0.11530899256467819, 0.12227680081767694, 0.13333684019744396, 0.22506900717105183, 0.16246526289199079, 0.10758290107228927, 0.12427539857370512, 0.1252308301627636, 0.12386549556893961, 0.1198381595313549, 0.14591371746999876, 0.14363234703029903, 0.1351879515818187, 0.0893238629879696, 0.08204192016273737, 0.10019360043640647, 0.1303136817046574, 0.07598761681999479, 0.10571247858128377, 0.2076275766428028], [0.01822950824030808, 0.02624345294732068, 0.06009000273687499, 0.03279470007068344, 0.02216430736838707, 0.011054221790150871, 0.03244015195273927, 0.04373095430699842, 0.02727282280102372, 0.04834308235773018, 0.016174310485699346, 0.01515325777498739, 0.020908240661291138, 0.020417476638353298, 0.031296196194099526, 0.015366909792646766, 0.05977642456335681, 0.020814326325697557, 0.04803057287686637, 0.07069332019558974, 0.0431330971020673, 0.03614855956818376, 0.03212222097707646, 0.05962162358420236, 0.0786028875570212, 0.08264591810958725, 0.03427608450874686, 0.04819211510143109, 0.024929042406646267, 0.0441563855856657, 0.031237611480589424, 0.053393391360129626, 0.031840754473315816, 0.024911051050626805, 0.03203829298061984, 0.04033518509407129, 0.025602096558681557, 0.06747135094233922, 0.01698023366874882, 0.03180317720398307, 0.02153854371447648, 0.052774865978530476, 0.025641395610624125, 0.033065557679427524, 0.022628038556181958, 0.041230389914874516, 0.038891666302723546, 0.009083659404755702, 0.03572318257231798, 0.01754915983682232, 0.019610403338447213, 0.015283872373402119, 0.018793823762929866, 0.08195377846381494, 0.05881164276174136, 0.025426878460815976, 0.06481699658823864, 0.02639166874411915, 0.04892624249415738, 0.02550451474131218, 0.0330617510979729, 0.0017320976143569819, 0.022882789439920868, 0.021951147288616215, 0.08820625474410397, 0.007624485962358969, 0.05485304232154574, 0.05286898896364229, 0.036657491366245916, 0.041584415560854335, 0.03216508403420448, 0.01565346191637218, 0.036743095344198604, 0.01152653050875025, 0.048460726759263446, 0.008687005644398076, 0.0030103717124023077, 0.018349437608516643, 0.03227825688996485, 0.021020290541595647, 0.036026257023747475, 0.033780262007244995, 0.03840071228998048, 0.027538270789331624, 0.022915196272411516, 0.06575944780239038, 0.06324111936347825, 0.02332858694717288, 0.00933016523984926, 0.036516155914536545, 0.017006336910916225, 0.032973253168165684, 0.04100727063736745, 0.011739132493468267, 0.0123975922054212, 0.035438594807471545, 0.07369078935257026, 0.05345115843894226, 0.013814262214249797, 0.06077017981026854, 0.0171252807070102, 0.034640773332544735, 0.0574347052190985, 0.01002208436174052, 0.009927699292477752, 0.05370440127860222, 0.0039527959971954775, 0.026683942614389316, 0.011943836330569215, 0.02980948525613972, 0.06924685995493617, 0.04475627500297768, 0.03203483245202473, 0.04078087403572031, 0.05629780961732779, 0.021182952348941138, 0.025100265629589558, 0.03680106259084173, 0.049080585462174246, 0.06072954913335187, 0.017420039711786166, 0.013504631418202604, 0.03979797874178205, 0.03531465360096522, 0.03970098555354135, 0.06981215426432234, 0.029260550426053147, 0.03691454757271068, 0.07348304228591067, 0.027996670388217484, 0.07909435725637845, 0.060291927973074574, 0.020244984554925134, 0.04758995598448174, 0.027494232170283794, 0.025837773823046258, 0.03897447471639939, 0.04018238918589694, 0.039645410142838955, 0.022390352828162055, 0.055809288152626584, 0.05182226727317486, 0.10155136936477252, 0.04966380327407803, 0.05147787003910967, 0.04166789572419865, 0.033210801492844305, 0.006574685843328812, 0.04628695161747081, 0.014718506817838975, 0.029482526372053793, 0.06758945674768516, 0.034437521560383696, 0.012846941843495836, 0.06954314905617918, 0.028463180176913738, 0.048943063377269676, 0.0048455860815010965, 0.05084985873794981, 0.04799115677763309, 0.09137024996536118, 0.037644780174429925, 0.028930164940123047, 0.036831881651388745, 0.019058667855071168, 0.019791097213913287, 0.053257915058306286, 0.04900616713400398, 0.007039040435172085, 0.019834202847310474, 0.038650671020150185, 0.041951794776001146, 0.03167035058140755, 0.0771943438532097, 0.029569382247115885, 0.034356307704001665, 0.06792689899780921, 0.0313226692378521, 0.05541516447971974, 0.013987486267329326, 0.00945501568328057, 0.024995801770793538, 0.03824581292324832, 0.021098515451220528, 0.04009425766499979, 0.004455895786772349, 0.02266202467892851, 0.023940347334636108, 0.017441001354849765, 0.046916523549173555, 0.05219527154362627, 0.030878293261464154, 0.03990158425377948, 0.006445176832910095, 0.02283791283012501, 0.012065425565067147, 0.019609765515529683, 0.026746240610788976, 0.0351505024092538, 0.00673861608707479, 0.021222419338300824, 0.05195823212021163, 0.04265653142439468, 0.02361524594016373, 0.036047206792448244, 0.07383661331342799, 0.12636278942227364, 0.04129759202312146, 0.025189126575631753, 0.032486519643238614, 0.01604914282714682, 0.007393246317016227, 0.06082423190985407, 0.05533352653895106, 0.03219337555180703, 0.036413001628326516, 0.013967499170186264, 0.06771751666175467, 0.023365560320339034, 0.06250570275421653, 0.05343584390357137, 0.08078428264707327, 0.009314415593897658, 0.04671703425369092, 0.03184214886277914, 0.06078396764184747, 0.026577392260410955, 0.036580060342592854, 0.028148674106757556, 0.08226326507117067, 0.18020085192152432, 0.029711606579699686, 0.0029280005297290957, 0.03800721965464098, 0.03475431598989027, 0.03500592356015529, 0.028464974902038063, 0.027426375275743858, 0.009416418066913528, 0.028326519831482853, 0.10637837927788496, 0.05690101028553077, 0.034915685188025236, 0.06612276937812567, 0.006053464503825775, 0.05414689092763832, 0.05280029407835432, 0.01344490422135485, 0.0060780936286651665, 0.03794086571516735, 0.07288295948611838, 0.02553208022644477, 0.030669541962976967, 0.03448680355878813, 0.05097891949117184, 0.027975171006151607, 0.03322171572861927, 0.0873074061902506, 0.02447162668353745, 0.045503684718694, 0.045764472867761335, 0.04948212213015982, 0.07188050542026758, 0.02048201549665204, 0.017312193355922188, 0.0880418253530349, 0.042604596354067326, 0.04271687015092798, 0.03900070348754525, 0.0337267425576491, 0.038107812471155605, 0.03418266720005444, 0.04342122681971107, 0.02917335189080664, 0.020220063660027723, 0.04236964003315993, 0.054809181817940304, 0.033514089682804685, 0.06394250744155475, 0.02177832611570401, 0.04999774767618094, 0.027962356872324432, 0.018871342996135354, 0.03429235238581896, 0.00838083537694599, 0.021399762947112322, 0.017093596514314413, 0.09558476667319026, 0.030731655058584044, 0.012830076007438558, 0.00850986220341708, 0.0196480620319822, 0.028240310261026025, 0.032855228787021976, 0.0421068943105638, 0.03016773478261062, 0.030849927105009556, 0.015133671861674105, 0.0979549844882318, 0.02838692980419312, 0.020682352960907986, 0.018991352092208605, 0.017981878581589887, 0.011417710455134511, 0.00475458096479997, 0.04149990063160658, 0.025662304667223777, 0.033518954778888395, 0.007722748011084539, 0.06242409534752369, 0.03981111517974308, 0.09689062088727951, 0.0358906959050468, 0.051220542418637445, 0.01108513499743172, 0.023533687727259736, 0.019435685660157884, 0.007687418389001063, 0.0630276861733624, 0.021632167976349592, 0.10843586708818163, 0.04599258955568075, 0.014889904763549566, 0.023777619370126298, 0.023506444546261003, 0.056075647074197016, 0.048438759188034704, 0.07712359300681523, 0.030870110129139254, 0.01902021697190191, 0.044307396946741004, 0.017280622817842022, 0.0309809352537351, 0.0334069998934865, 0.02254918260898973, 0.04398949311247893, 0.03575522638857365, 0.013942500243761709, 0.042627680115401745, 0.03509756989244904, 0.018076451096151556, 0.03390303274084415, 0.07897336089185306, 0.04971482910748039, 0.043432816197829585, 0.04837523473958884, 0.02537254646553525, 0.03259699871497495, 0.024299792779077376, 0.0030630529592079775, 0.009695681876369884, 0.04148541051628334, 0.09713076800107956, 0.0994668962167842, 0.1737445912190846, 0.08049228867249829, 0.1312031461192029, 0.07803109288215637, 0.11442863409008298, 0.216600469446608, 0.055139014297830205, 0.11786850807922226, 0.18304007314145565, 0.05023472263876881, 0.15528125981135027, 0.11868817838174955, 0.11054557495351348, 0.10332134831696749, 0.2184457861419235, 0.12627156717436655, 0.1556892900594643, 0.1515482044113534, 0.08544173344437565, 0.1318116020411253, 0.12604680923478945, 0.2139924658196313, 0.15690318920782634, 0.12868128929819378, 0.19225504009851388, 0.15819159150123596, 0.0920357842530523, 0.09512566309422255, 0.16478511983794825, 0.1347520471151386, 0.11560008408767836, 0.0862563554463642, 0.12683950098497526, 0.13295112018074307, 0.12461818089442593, 0.19652117975056171, 0.1991017841334854, 0.12882467731833458, 0.08421165802116905, 0.13815161612417015, 0.09849570904459272, 0.1782296398388488, 0.13091295026242733, 0.09926172079784529, 0.1391288015459265, 0.13428136094340257, 0.10401000029274396, 0.1637477483600378, 0.19426544436386653, 0.07802877907774278, 0.09596942817526204, 0.15842540109796183, 0.20448150831673825, 0.11703300076935973, 0.07470681411879403, 0.1519734558782407, 0.1380166012261595, 0.10032252887529985, 0.1308666741741555, 0.07000667668346848, 0.142183104796069, 0.15704589869294847, 0.23624998863254273, 0.09654048324695655, 0.12331460655799933, 0.16407871060073376, 0.09121386799961329, 0.14029509467738016, 0.11120963682021413, 0.09779055509716272, 0.14715867995151452, 0.1333006335688489, 0.14373595932764666, 0.10193390026688576, 0.11688440160027572, 0.14730569134865487, 0.10225977349494185, 0.1213301494717598, 0.06857842832271542, 0.19989619936261857, 0.0866992420383862, 0.11858586887163775, 0.1281577181071043, 0.13014479433851583, 0.1549380567989179, 0.0986761993595532, 0.05548597639426589, 0.1618906930088997, 0.1597672990922417, 0.10148452009473528, 0.13543949808393205, 0.13329498815749372, 0.17018085744764122, 0.183245628540005, 0.1584454993052142, 0.13731127764497483, 0.07944630658520119, 0.10276906152388879, 0.16761287381606443, 0.11684643078063216, 0.14736010985715048, 0.11148651303457362, 0.1294754602547203, 0.10186041492436614, 0.07617995435638086, 0.1038120241303529, 0.13731749302574567, 0.13104199405227387, 0.18042548772479805, 0.13995194594774926, 0.08305270663861718, 0.12190820702484675, 0.14992571861616202, 0.07550996209361724, 0.09512887256486074, 0.14334502816200256, 0.1748495176434517, 0.1764427042965378, 0.09966392921549933, 0.1157908881349223, 0.24803272208997182, 0.15011572199208395, 0.1600180042109319, 0.08561963854091507, 0.08596478216350079, 0.15409874969295093, 0.14530104106026037, 0.09960327497018234, 0.1685277290110077, 0.1311335148555892, 0.071222631792937, 0.15237124024757318, 0.13194246430482182, 0.16894349455833435, 0.15642209430890425, 0.12540606861667974, 0.14041607747120516, 0.08950531003730637, 0.21035725516932352, 0.10828549694269896, 0.16794786655477115, 0.11294982129974024, 0.29306768838848385, 0.10874927562794515, 0.09522823723299162, 0.11596063045518738, 0.12443687633744308, 0.14853777523551667, 0.13468274154833385, 0.12095862440764904, 0.12171030550130776, 0.1687546989747456, 0.15967326770935739, 0.09988728937293802, 0.09447360451200179, 0.11528757799948965, 0.12354918968464647, 0.1869970450976065, 0.16400137117930821, 0.06979086862078734, 0.12202996334859303, 0.14342546170311316, 0.13327854046864168, 0.1899211917604719, 0.12483387360615389, 0.18737217996801647, 0.14334858368550027, 0.11351796545620475, 0.09991301263549499, 0.16420149829770836, 0.060241492465138435, 0.13383968892906392, 0.18310848304203578, 0.0847261097016079], [0.032230596590254984, 0.020952007866331508, 0.021594655167843615, 0.055246840297643623, 0.03335743969572442, 0.04720025975257158, 0.013002019325670387, 0.0019274457258039287, 0.04616408928164414, 0.033531246440751214, 0.02254669917082148, 0.004597225301300308, 0.05735469236969948, 0.03445009820695434, 0.037905344406941106, 0.037366360292903016, 0.058486176654696465, 0.02119842464370387, 0.0189923342716481, 0.03969445465398686, 0.03989736715863858, 0.0067377191485970146, 0.016876753685729842, 0.03343500303370612, 0.02434766342464302, 0.01332420641223767, 0.00585817958095244, 0.07631171907165221, 0.05190342006140521, 0.017374070660610284, 0.027217934407027702, 0.04246666714815157, 0.017294739738905003, 0.018511627834024172, 0.015138355449640324, 0.02454441992033805, 0.04618210099371416, 0.02074502924058054, 0.013240569337670292, 0.07407669935907636, 0.0642224642048989, 0.03396737143131239, 0.03497097222134471, 0.025433373737281988, 0.03392598079517484, 0.03619734623602458, 0.03377510514110327, 0.017664022244779125, 0.02571769348079605, 0.052928903605788946, 0.06638304862592902, 0.03897450864315033, 0.039442789408245256, 0.00648579393912639, 0.04347145876714161, 0.06877218399729047, 0.0785279365788613, 0.01592343234057937, 0.07838494889438152, 0.0144389130707298, 0.05235714285767504, 0.041137939518583674, 0.02593812406329172, 0.048746030378554545, 0.054159674527389665, 0.04391104767897299, 0.020912303389715295, 0.005018218112776854, 0.09159475684698139, 0.059376414599163194, 0.06576150376349688, 0.02084727768254067, 0.03967052272387913, 0.07903460546263627, 0.05791998667908566, 0.018240960215085318, 0.03373083073113646, 0.011053721370574619, 0.058022716880909035, 0.010519835599032896, 0.020146702150149003, 0.009428684283713145, 0.03022827367697443, 0.04886005479576332, 0.0713164664006659, 0.010404223409880484, 0.06043148905571018, 0.022908706084958146, 0.047089102145816596, 0.004467077619795288, 0.0418674257317824, 0.011164244547087167, 0.0296614967685725, 0.04007244954950043, 0.053492148739418814, 0.042542822525969574, 0.025373396330646107, 0.023402272457523004, 0.03985690950815167, 0.016709028310807686, 0.010883806872048547, 0.060511182993650436, 0.014993786778567093, 0.06375757272222213, 0.04486405350533979, 0.015751218456508856, 0.015011908752577645, 0.012153254289712225, 0.02471770080072539, 0.027320961467921734, 0.07005118858069181, 0.044313042358096154, 0.019084133274321045, 0.04437091800251177, 0.01261094566767237, 0.020732228677453737, 0.03042314893433026, 0.05525109810488565, 0.051899650799376626, 0.03836004090096269, 0.028051384059446197, 0.02066353039949068, 0.020755181820797067, 0.021211869815098386, 0.05453520973346063, 0.013248637119042022, 0.0051827064515756706, 0.024414874014577696, 0.028232844679483345, 0.05761759754802499, 0.024970526341348886, 0.06436769784029041, 0.01603363490929561, 0.042072309380663295, 0.030659150199166367, 0.039468302324946435, 0.027478247581581985, 0.053446184777255566, 0.014283784698428852, 0.04068432189524174, 0.06000587117991277, 0.004720886612111437, 0.03919181966089776, 0.05752791557461023, 0.07915853309844222, 0.033939911119107685, 0.011358637196410979, 0.04321650941190975, 0.05221932561003736, 0.036389073090893884, 0.02765685156919062, 0.019195192493498325, 0.057323859738452096, 0.06892824705157961, 0.03944096075637, 0.04254077674288835, 0.06581558978983335, 0.06660216793950115, 0.05052702873945236, 0.022507342443402325, 0.041488541955394406, 0.0596374673768878, 0.10100219704742942, 0.02699871840221541, 0.04890226985194853, 0.008707968135630446, 0.07603905655975852, 0.005346053579289998, 0.0043470753090722215, 0.058923655322619846, 0.035816284362226725, 0.016549728644479598, 0.044276940902428966, 0.08175414667597838, 0.04304183414205909, 0.0681925725990108, 0.05120088865182229, 0.04069037103493299, 0.06079790475113051, 0.07564342993178538, 0.03301238428269114, 0.026733528257214596, 0.01928406022489071, 0.0632100221035736, 0.04277849130864654, 0.04314472719228693, 0.07993610030306236, 0.026195261693958725, 0.042293318414262364, 0.019853900718901838, 0.033280805950718265, 0.047249931908611736, 0.04736433969810605, 0.03214760157944901, 0.01209057037652071, 0.02732000982255808, 0.056784739917410273, 0.01506503634820027, 0.042872977309993336, 0.06739674601703882, 0.01556022950847234, 0.012715411222805935, 0.033879504539072514, 0.023979483538174202, 0.03298928355798125, 0.017837360800643052, 0.020543461931603293, 0.02435779564880899, 0.011670781964702266, 0.031831811381770034, 0.010239123965480497, 0.03805654236514654, 0.022918841701799204, 0.07764525072915213, 0.01282775032866214, 0.09351420349308423, 0.012887647159264555, 0.04681795955236469, 0.011219685947123383, 0.029679396522364447, 0.05745462022189583, 0.0431366628035903, 0.02412948218573417, 0.03239183008138623, 0.024439408144514476, 0.02842796590578343, 0.027643401308783462, 0.01668545600425984, 0.026968423509970307, 0.0507126080670527, 0.05725437096719231, 0.0482539635683809, 0.0660461424184697, 0.024936197558417916, 0.03461033085893307, 0.035509030135082345, 0.07630198887948479, 0.07527026959827968, 0.031597496276455264, 0.023373219284362028, 0.015827212682259933, 0.08262736017682723, 0.010010125182036842, 0.02848586020991206, 0.06193307348127876, 0.02710645110346377, 0.026490200510514633, 0.04234277004642146, 0.04370944813958236, 0.05871217631335769, 0.07910843007266521, 0.012872161293801452, 0.04294712422415614, 0.03612631040492228, 0.04459332821092435, 0.02100211937379624, 0.0014670437064653794, 0.008605103923140891, 0.018282986977802854, 0.056327451419617446, 0.010489209072797425, 0.046881093843174834, 0.06801377862159695, 0.014631779864430428, 0.010503928193689456, 0.03880002336310489, 0.03916721937379666, 0.017175460067976798, 0.03188182619799461, 0.06229245276855571, 0.0347264858761004, 0.029607023977275406, 0.04883505078032613, 0.020372415127764856, 0.06705423511032547, 0.07274008715259177, 0.021901833059798394, 0.05344592354127339, 0.024490116762795618, 0.07772788272372314, 0.0387093507285629, 0.06191541800009353, 0.0547819216735661, 0.03716565981241209, 0.07266943130109992, 0.0515751516047333, 0.02162991863276277, 0.07969224160271031, 0.027519086908016886, 0.0045507197833753055, 0.0422445521024721, 0.026156349406976784, 0.03787581456292953, 0.04913438989647797, 0.06581576620893818, 0.027307753783783743, 0.014590796349304063, 0.03981197352654167, 0.02235066022590867, 0.0477569536305964, 0.04614360770210624, 0.007863297210341054, 0.038091839756816626, 0.023528142399819832, 0.04324004100635648, 0.05695223967943873, 0.007804685355430203, 0.055186834053269455, 0.04145268477233393, 0.028592644658471857, 0.02070554019883275, 0.061510576866567135, 0.022753743953736763, 0.08571664190718106, 0.044493502138980796, 0.045782281019325764, 0.030012669174798896, 0.007857412615391825, 0.07246327200638396, 0.05803845889334168, 0.028971640393137932, 0.0205537010250347, 0.03742472787520715, 0.0708078094092863, 0.05419969791546464, 0.08867706983749356, 0.027006180591083, 0.009335059173671263, 0.0310511704135154, 0.06835198761629206, 0.03733969047399504, 0.011364615938094045, 0.05124583141878247, 0.029453240800648928, 0.058557490685156414, 0.049704986957034895, 0.040935077904058356, 0.05208980006032756, 0.022873371373862028, 0.025876221313540424, 0.015329105214082768, 0.08172220124730042, 0.04565849248319864, 0.022797324561647007, 0.03724871589136975, 0.06868799815752677, 0.026950360907773887, 0.02161662104273481, 0.015554738463833928, 0.12132229203624384, 0.045827200037560294, 0.016394052355151092, 0.10833589852388416, 0.12697484157979488, 0.14617720618844032, 0.18748320186776773, 0.13369159187589372, 0.08803086022713355, 0.07963071204721928, 0.12519698483603342, 0.14039015743349278, 0.1609098706394434, 0.11488631953086172, 0.08670167797910315, 0.14886184356042317, 0.13358940450208528, 0.095684599530484, 0.08953206467309169, 0.12209154718688556, 0.1475259302450078, 0.10435595137200185, 0.1904930475034884, 0.17540882048862322, 0.06484266556799412, 0.07137272373906203, 0.2094966284930706, 0.08236262295395136, 0.2324027493596077, 0.11063940277589218, 0.16236986086836883, 0.09620064576821667, 0.14253132896763937, 0.13130910614771502, 0.16470114434404032, 0.06521070296210901, 0.0777246868237853, 0.08396853213863713, 0.07705497276037931, 0.1381121389567852, 0.13680876818086418, 0.10619999920683247, 0.2807678569640432, 0.11903629398771695, 0.11461406413997922, 0.07391302992722817, 0.07466801548642771, 0.11263499462178775, 0.09367830040199415, 0.08661692895527397, 0.07953952372606311, 0.07574909819023949, 0.11164963963840689, 0.12200252339243889, 0.13323214224406651, 0.21214421785303525, 0.17698313029749052, 0.11036251299083233, 0.2176298342112984, 0.177108604993139, 0.12199020119650023, 0.14301649507667336, 0.06479056764926229, 0.19114571676722594, 0.15943252348474093, 0.09602911211550236, 0.14650143736175128, 0.1458429598382541, 0.13127037536885056, 0.09033578261733055, 0.16624017033193791, 0.26123128671731266, 0.07166711294225284, 0.10461003559508494, 0.12641228176653385, 0.10846239780741078, 0.10171967319079808, 0.12467648062322821, 0.08452719037554093, 0.083143555692264, 0.13201327621936798, 0.11123409122228622, 0.1180453071636813, 0.11574385208742959, 0.10859809124044009, 0.07858544920704194, 0.17506852160607064, 0.22674876132181712, 0.10610790164875132, 0.08222713986677782, 0.09328078066131898, 0.09439228209001677, 0.11602055866803442, 0.2123109203364168, 0.06475884613714047, 0.14076986562992844, 0.1714409784014736, 0.1680834378514971, 0.07078923790582589, 0.16203367390802928, 0.16072449487234863, 0.16328122839331627, 0.15004736637430532, 0.1597953090178115, 0.1336634462433202, 0.18287609836884908, 0.17834990338555404, 0.0861338120219963, 0.13893966669482843, 0.1454822099102395, 0.10411819270146744, 0.12454321634556566, 0.19835030660033226, 0.12800320211265767, 0.14465309440025262, 0.08309483687792506, 0.1837692947259971, 0.18481022172740527, 0.14426464667277678, 0.10456772893667221, 0.24989397078752518, 0.10714798726673637, 0.16091766022145748, 0.056653582490980625, 0.11619620424296175, 0.09715216899556772, 0.10916359589568206, 0.08195216355047055, 0.03258329909294844, 0.08857604954391718, 0.09039245386208807, 0.06961009332111903, 0.15413901396095753, 0.11303165940833942, 0.16127627954951354, 0.10507571417838335, 0.09670129604637623, 0.1313288922288588, 0.1451454936925854, 0.16458716403160775, 0.14917662952627453, 0.16680263515029634, 0.11105087998190097, 0.16564970915871008, 0.08533785651837077, 0.12556127671684536, 0.18719748434211525, 0.15706816821226052, 0.1465509704181126, 0.1198615554187979, 0.19240009731480054, 0.14519290971968854, 0.25398548266717363, 0.12428483021046434, 0.07635348290205002, 0.12061341293156147, 0.22453870491257735, 0.1670018123196704, 0.1385135059910161, 0.15397886612585612, 0.11713726446032524, 0.12711490477834428, 0.11045684971447502, 0.1652653869241476, 0.15589760031018937, 0.24127220628517015, 0.1198994583849396, 0.14228766704244272, 0.17116759664246015, 0.14551988217447484, 0.11949412870619978, 0.12611592481178896, 0.12201324424573354, 0.1098385007519807, 0.11995197699538299, 0.08926658784704548, 0.17510713024863175, 0.1017361276650003, 0.16938838282866137], [0.03364170515643699, 0.02626388194039464, 0.01708233792201749, 0.09503868169018201, 0.03889551020360418, 0.07070590702018567, 0.05929245946130582, 0.032207706211400886, 0.018649378924497535, 0.020611542742699385, 0.020952476055494378, 0.018443058477714658, 0.04735521340210523, 0.021353680241320814, 0.02043461473658681, 0.059057245297091346, 0.0452408745352711, 0.04300390064184155, 0.08436497300863266, 0.022274760995060205, 0.04411543599729027, 0.01800331350282899, 0.04027741462258356, 0.03698444685765675, 0.0918076675651329, 0.03516351331823638, 0.029746523991759335, 0.016855708922126462, 0.058330344302313666, 0.0057785776693240875, 0.013453106861561537, 0.01563720082465027, 0.0525728864595294, 0.025920339660452943, 0.040814573477421484, 0.04545367668781962, 0.013688013988680072, 0.06713397654571704, 0.023586063845349208, 0.021003819104017954, 0.031981007661670446, 0.06404505443892308, 0.03610467192317758, 0.01122871131104018, 0.015663606014900973, 0.03882367709385497, 0.024787493216406022, 0.06998701952397823, 0.028437538338559012, 0.06329389581722872, 0.020210079017228315, 0.09605468610035521, 0.032306443234639506, 0.03016998412619744, 0.05930546697761331, 0.026971110508644154, 0.027201174592067088, 0.026874453195237687, 0.007911718317440577, 0.04246053658425808, 0.029738384964210645, 0.04503975336306861, 0.04120570820357118, 0.034498762738491805, 0.06959454129849162, 0.029231102006243806, 0.07101625536701509, 0.0183239552258913, 0.061910559689360004, 0.03460215451195836, 0.026564936053806117, 0.0753746282841478, 0.0032256562429081115, 0.020950604995180453, 0.02930818697703736, 0.06654237543365785, 0.020585994202909724, 0.013967309180381042, 0.013157713426543134, 0.07004495962922062, 0.016778545919805765, 0.010403114005124994, 0.007864864626234131, 0.009492451308428176, 0.0284402304262455, 0.03213448889021363, 0.05248961324936577, 0.0203805999564273, 0.08833891512559992, 0.032144755125045776, 0.03995093071301069, 0.01745966954955033, 0.05473801367250936, 0.01637897191436163, 0.05421033055920686, 0.014310171228966542, 0.03401092320148434, 0.051361172193927426, 0.01667755107129259, 0.010974615213594266, 0.058361265143113475, 0.05510248875777636, 0.040017874977950535, 0.0043340995990937305, 0.018547722504341176, 0.06144391080098493, 0.022639251347365122, 0.022325023476566588, 0.029941972611205916, 0.021366847213357687, 0.10014997063470737, 0.0824830900611622, 0.06787741343889918, 0.058852117375603745, 0.07136722082006079, 0.0421994193457067, 0.039968542089419704, 0.013003103285362678, 0.057311700390917916, 0.0324776885099709, 0.011153159829388772, 0.060920034269137044, 0.023346105025016835, 0.0708559514688594, 0.05336427202980433, 0.04821299023127981, 0.02804348591182913, 0.034796829601483684, 0.01866868494211563, 0.026392940997279117, 0.04742429165967873, 0.06695337766515357, 0.06416845281741448, 0.029213531341935908, 0.03634978252063904, 0.03468320891261101, 0.059476688504219055, 0.05246037517541221, 0.023549840253378664, 0.018716521660930345, 0.0668113399296999, 0.036997613829693625, 0.036774318133081706, 0.03851613788200276, 0.05618169531226158, 0.02222605575142162, 0.017382028180041482, 0.03430106138278331, 0.08705343731812068, 0.02508370598245944, 0.04594128213024565, 0.03686152684635349, 0.04334547856290426, 0.10021488607994147, 0.006877059707351561, 0.04126628102468593, 0.011028053238987923, 0.04281165810035808, 0.07486529954309974, 0.012307200314743178, 0.03058398548247559, 0.039385619440249035, 0.0735504954521145, 0.030412672353642325, 0.14125026842313154, 0.022480567451566458, 0.046631331888160536, 0.018692616872223358, 0.015048938104882836, 0.06341281586459704, 0.02973764536104032, 0.03244097298011184, 0.05962146752114807, 0.04847925076527255, 0.023953176735501205, 0.013541445335639375, 0.04333910033372896, 0.06098815918500934, 0.024220383825844953, 0.011006428327943598, 0.005586873290927282, 0.060675673452871184, 0.04307349458602922, 0.02988053805061749, 0.003074664813798985, 0.03969602206987994, 0.04005412571132183, 0.0250446444177734, 0.06375019026121923, 0.01262582594063133, 0.01582447479345969, 0.0232147152003433, 0.05098138257328953, 0.061899655631610324, 0.02509339546252574, 0.03692333799387727, 0.01827600654879851, 0.07594879783157792, 0.01498223641621215, 0.01942757547034749, 0.017598860830600773, 0.04368740253682647, 0.03256883272635085, 0.03188297292217612, 0.04034965146066887, 0.04379923189324992, 0.013735335020880615, 0.06421896296420268, 0.032304889389446804, 0.029064199355031763, 0.07711856506232705, 0.05644749444244163, 0.01063775735175503, 0.015629638551867435, 0.01644107143926833, 0.05292005890182086, 0.04946515875469361, 0.011201831146276422, 0.006936222447880677, 0.019410644325294664, 0.024483641842380166, 0.03439599521724241, 0.04022636504045554, 0.052742985010679276, 0.01897232766662325, 0.024379581711920242, 0.012870086672981935, 0.018469375458412936, 0.07791083612080131, 0.018587172530325394, 0.03686960141307541, 0.0366687957596566, 0.01413958243626569, 0.05224680627829262, 0.02295425274808492, 0.030563419086060355, 0.03942537819966674, 0.030808505934796164, 0.023542953122939383, 0.0745465848594904, 0.04915870859154633, 0.004708647112628179, 0.047465665332440815, 0.06967505626380444, 0.021993224941460148, 0.032796376052179506, 0.03260593502117055, 0.028403138309451084, 0.04282039423872318, 0.0271768694676991, 0.04485535807907581, 0.028497968667319844, 0.047963248632316074, 0.07003654579498939, 0.01870509682755385, 0.08407747093588114, 0.08432956026600939, 0.0660877637565136, 0.005339665172089423, 0.04378939652815461, 0.0124201458612723, 0.07209811838609831, 0.02399706098783229, 0.02507946004958025, 0.07384611958903925, 0.03801988111808896, 0.04422997270843812, 0.029251627690557922, 0.03839524329773017, 0.01855673684206392, 0.05398643435910344, 0.017745366719152247, 0.043182938891862116, 0.04522883393136518, 0.04914082580112985, 0.01765711136561419, 0.03646176794011678, 0.035430065622287135, 0.03363264332126294, 0.07877602255237953, 0.04943931335583329, 0.017441693460568786, 0.03166403002770884, 0.04089685941913298, 0.04944742524198123, 0.0688602307013103, 0.017497950798964927, 0.012171328766271472, 0.01396465186761426, 0.02069079054386488, 0.04353842678080712, 0.03067888878285885, 0.0678536986399974, 0.019308631674253514, 0.032570817441280396, 0.010728167902146066, 0.038487842971725125, 0.041528290536786826, 0.041743484525276084, 0.032452660745808055, 0.008606019945416068, 0.07123981229960918, 0.04957025365105697, 0.0565936508854585, 0.06317338121256658, 0.04229637860719647, 0.020878237539104054, 0.057152923196554184, 0.04754110485581415, 0.022552529482969215, 0.018298981744529944, 0.031207593091364418, 0.02350800856947899, 0.018299590729709183, 0.017223702211465155, 0.032838445223335705, 0.060325060838035176, 0.06061174188341413, 0.0322247679744448, 0.052349193819931576, 0.025799589264871817, 0.013508787445191826, 0.04661192239395209, 0.040999877998339276, 0.008806408299798412, 0.03178789320268801, 0.009950040906135525, 0.029967628020261015, 0.08637030183204583, 0.03078565966071827, 0.035472158542168994, 0.05278724924262081, 0.026567656979230896, 0.0478594667012138, 0.007610565816451396, 0.004398754656514419, 0.021052327572501132, 0.013435340270267, 0.07687285396137408, 0.03919444898409503, 0.03362490802205034, 0.02999704929866961, 0.03155674346323524, 0.03482165719781603, 0.0542624216925885, 0.05455428674550993, 0.03964692327593054, 0.04134644654446414, 0.02638374684777643, 0.05293591287253158, 0.036630380499575815, 0.03860179275008185, 0.24690977377550943, 0.19583250741873467, 0.10621970386377402, 0.14508742466568947, 0.0874132847945605, 0.18589142656752042, 0.1572592029614108, 0.16526939028075763, 0.06256740872881242, 0.1020564708326544, 0.10431715273963553, 0.06094298232346773, 0.21650444317076886, 0.08713948912918568, 0.236994667244809, 0.15429939249796526, 0.12935050124568598, 0.11607746061469827, 0.15713393182626792, 0.12212578606392656, 0.12588519576404775, 0.18595581954079016, 0.09714730389948402, 0.11897097820682184, 0.2050407433084079, 0.12087102553674153, 0.11925801209041051, 0.08461152549300875, 0.20045592289950165, 0.10047704486974648, 0.18513826626752103, 0.188571979158691, 0.13774245950792516, 0.10646366434437887, 0.13771530453647884, 0.13104250973888806, 0.08662844369454042, 0.21133635405983242, 0.1355759379054819, 0.10167195182293653, 0.0920918108895421, 0.13465292671961443, 0.1090448929795197, 0.07696558255702257, 0.06709077422107969, 0.13184505381754466, 0.11168870968478066, 0.20099117846361228, 0.09113983304372855, 0.09983856377324887, 0.09217951832605259, 0.15171429621321814, 0.17589090604867252, 0.1082315534087164, 0.11754737102559634, 0.15469820824052605, 0.11991828094635691, 0.1500153938042266, 0.048184434085019996, 0.10828491340258292, 0.17671828450901167, 0.15224227788192884, 0.11252735861177955, 0.16184772817151888, 0.09817047363945416, 0.17171900134001458, 0.29256923656378475, 0.10022051113524608, 0.1779606414160558, 0.05337356456688472, 0.09329604091388838, 0.1159004308283329, 0.11322122173649923, 0.0944355386974556, 0.0964303163013288, 0.13245602031903608, 0.1460422591439315, 0.16434393636882305, 0.09141096206648008, 0.12971982785633632, 0.22909974945443018, 0.11330153314130646, 0.07964377384632826, 0.14254556463233062, 0.18431212274091585, 0.1610499881207943, 0.1587766922478165, 0.09510055729853255, 0.1126468689846141, 0.13957107067108154, 0.15103388843791826, 0.06639542510466916, 0.09928122867963143, 0.09183098202837364, 0.11007996422371694, 0.14991251432469913, 0.16413382121494838, 0.12267083967370646, 0.09272649897528545, 0.12047055416873523, 0.1363330472792898, 0.1738671482141529, 0.1179127214210374, 0.21373888371246202, 0.22135767846235208, 0.10416638225849185, 0.12423613853752613, 0.10673160425254277, 0.14713445625134877, 0.13673528283834457, 0.20065724423953465, 0.12519577704370022, 0.26017898746899193, 0.09122082298355443, 0.13886369791414055, 0.1357824161116566, 0.13219483861965792, 0.08513747155666351, 0.12312045054776327, 0.06838050644312586, 0.0874003315610545, 0.13445571730179445, 0.10602654530001537, 0.13619104347058705, 0.11695838905870914, 0.1815782237265791, 0.14222674816846848, 0.16190346303795064, 0.16530073859861918, 0.15943616043244088, 0.17459092794784478, 0.19124623494488852, 0.0993105142510363, 0.13942947398338998, 0.17093287780880928, 0.17874643925045217, 0.12875028273888997, 0.09515861275472812, 0.09130730905703136, 0.1386316389377628, 0.22453529866678373, 0.1185404070253883, 0.0942403038165399, 0.1628121028521231, 0.14913274188126835, 0.09729508882654564, 0.1523367842393262, 0.08549895430249826, 0.1555180549621582, 0.13956474672470773, 0.14806855469942093, 0.15714005221213612, 0.1649798322468996, 0.23730084938662394, 0.16084517911076546, 0.1297232883849314, 0.10885687771120242, 0.12296042484896523, 0.14342168904840946, 0.1381215705935444, 0.10711276451391832, 0.1448947207203933, 0.13821519485541753, 0.07621708379260131, 0.22036035412124225, 0.1382220752005066, 0.10507384142173187, 0.12873010310743535, 0.11668709718755313, 0.21005218582493917, 0.09274558616536004, 0.11519655931208815, 0.14161720659051621, 0.15014279553932802, 0.16890499448137625, 0.16953539422580174], [0.06961943674832582, 0.04256541434941547, 0.03380221261509827, 0.022416177870971814, 0.0177279436362109, 0.04036618735907333, 0.07779513232942138, 0.03220217275832381, 0.08146280409502131, 0.06422370592398302, 0.08153886108526162, 0.08952747777636562, 0.048271032116775, 0.03837015785809074, 0.03456107260925429, 0.010687052072691066, 0.030231147272778407, 0.02040929180969085, 0.011553527720804726, 0.021389437340466038, 0.013748840412258037, 0.03663549665361643, 0.05444170421521578, 0.02873789525723883, 0.032635943232370276, 0.01329955184233508, 0.025170483825994388, 0.039778121414461305, 0.04240707481013877, 0.046852768398821354, 0.023116700816899538, 0.019411950505205562, 0.05401819319065128, 0.050320221443793604, 0.03371293097734451, 0.04063069388004286, 0.04595608437167747, 0.015756918150665503, 0.048719805000083785, 0.036430419622255225, 0.002189099007020039, 0.03176679754895823, 0.02828690186808152, 0.06049694732895919, 0.07774886981184993, 0.020410944042461257, 0.026731706390689527, 0.019649897469207644, 0.01951707254296967, 0.015362523063751203, 0.09703246184757777, 0.04723648673721722, 0.02798440247508032, 0.02739982759313924, 0.020780477606292282, 0.0653372226016862, 0.03471946303865739, 0.05606203226904784, 0.07524895002799374, 0.07099561433174781, 0.013840072838190411, 0.01699336332135967, 0.042673308202730756, 0.009973279034186686, 0.06136089204145329, 0.00748286722227931, 0.022294385924137065, 0.05684379282008324, 0.022768001670816114, 0.03379314399457403, 0.022910438045593243, 0.0376084955143077, 0.04154261780370559, 0.016875352510916333, 0.034156563957887034, 0.02199811039359442, 0.0267007193927254, 0.032441861860986264, 0.07740299337144409, 0.023330647997292023, 0.02781031753069588, 0.04288378298016531, 0.03566314918654306, 0.035335969778576067, 0.03027304681017995, 0.045536111907235215, 0.017634714620986154, 0.03788574831560254, 0.030210038048348258, 0.03435808207307543, 0.014924533798226287, 0.04950662063700812, 0.018167681825746382, 0.030875233068530048, 0.03250873827242425, 0.04326624602877668, 0.03229702856125576, 0.018146413145586848, 0.10006347099053008, 0.03100851770224316, 0.01095948981985982, 0.030151772246296917, 0.06814765358077628, 0.07826406109545912, 0.031691056077501605, 0.078499472034829, 0.03673126847882356, 0.015204724656151873, 0.06961611192673445, 0.056518849185002704, 0.06568861553179366, 0.02106521464884281, 0.0348372872519706, 0.037889775420938215, 0.04127119701089604, 0.010817270576288658, 0.017130334096561586, 0.02112637270641114, 0.04602928812216435, 0.02230057755618223, 0.04688003532854574, 0.02195022108831576, 0.009352565377152391, 0.07992115896195173, 0.024198935333905474, 0.040090162706162245, 0.012012224178761244, 0.03035869828558394, 0.042448258493095636, 0.014460297101842505, 0.010571696030508195, 0.04104535680796419, 0.04552435628803713, 0.017534659543473805, 0.04343272459560207, 0.05060232237779668, 0.03588391734021051, 0.023988455467458283, 0.07700003856526953, 0.010296334645577838, 0.010199407614501459, 0.027413640869781375, 0.02294077873895211, 0.004856605490203947, 0.003933508639290396, 0.002528937333928687, 0.04093779543680804, 0.019745307974517345, 0.06014668755233288, 0.02658315302271928, 0.07249677806560482, 0.005371067348668086, 0.018739844605858837, 0.02329234978450196, 0.040977710259280035, 0.023678208900881664, 0.027324747693325793, 0.0261310400507812, 0.007883740622284157, 0.017815394925751855, 0.04401522994573627, 0.0231271129367607, 0.053752858856959004, 0.019607846957764456, 0.01773893420717546, 0.038036871634955914, 0.09888895401465041, 0.03708285818408642, 0.08378795361412422, 0.020524868375754783, 0.08977744329188551, 0.020371334560747658, 0.03307791380211711, 0.027521024125495126, 0.025124789581501057, 0.0239729594239699, 0.03865342926500099, 0.01628645875358156, 0.02022011624649167, 0.019123294922922338, 0.022029163548722863, 0.05132058222911187, 0.039433808997273445, 0.0023200575378723443, 0.054606652685574124, 0.020049186489943947, 0.046339972343827994, 0.07130828326834099, 0.022960388400991048, 0.014076661883986421, 0.022483271413615773, 0.028018814378551075, 0.021750741970858405, 0.035106180501835685, 0.03675520380160638, 0.021684421958135705, 0.03638215542637876, 0.04313826075355921, 0.054760334081947803, 0.08393915157232966, 0.04667636625734823, 0.021157461484628062, 0.06704695442957537, 0.01091054454445839, 0.02871181915647217, 0.041251787516687594, 0.013196970070047038, 0.008073037473617919, 0.0166909996353622, 0.04039624985307455, 0.012623630031677229, 0.03710369599450912, 0.07592489982822112, 0.04277299517499549, 0.020878230753753866, 0.06354952031480414, 0.05006116355902382, 0.058907044785363336, 0.04077662301382848, 0.03378739680296608, 0.03465470365647759, 0.0426545602801655, 0.0343097534163722, 0.05514922285718577, 0.015239709921713387, 0.019272832166669623, 0.08865799621811934, 0.002994369948282838, 0.06454444264194795, 0.007872462522105446, 0.04950839500608189, 0.030971089710614512, 0.019019044802657196, 0.03744366918025272, 0.06794967741838523, 0.037360127948756726, 0.017640409226130162, 0.028333934522899132, 0.016940127160134058, 0.02302313592684056, 0.031482369239841185, 0.014059012339982604, 0.036805130408278534, 0.06303899056677308, 0.052383948383586745, 0.014116495282256177, 0.03643189204324569, 0.052856822830757925, 0.08406180356230054, 0.04910290587161269, 0.064192995429039, 0.025614527320223193, 0.023113133419038992, 0.02857209861810718, 0.06040701429758753, 0.06132017994033439, 0.027686483193454996, 0.007231944972383124, 0.020138698829604045, 0.03195654308157308, 0.015393574522542102, 0.04652530400614653, 0.020121881339166845, 0.06610903582934823, 0.030070460002337183, 0.07468807976692915, 0.029947000555694103, 0.03496911642806871, 0.03631975734606385, 0.030306895529585223, 0.03612667342115726, 0.023442384055150405, 0.010996151066917394, 0.028726180350141864, 0.04768861836886831, 0.07658789639494248, 0.04115681975547757, 0.0832006883408342, 0.04553610851456012, 0.03284941713458725, 0.03001779889953988, 0.08301901737494127, 0.04446462708126221, 0.035556324025882144, 0.019102772631283318, 0.01059413094273103, 0.04355593637696334, 0.05596271849104336, 0.008515910494939556, 0.03210710321686097, 0.010552101635507174, 0.019699915678107312, 0.040361858305654356, 0.005003725028862911, 0.047940164870981655, 0.023852020734921098, 0.011602746954719936, 0.045436251908540726, 0.012086133605667522, 0.041405401059559414, 0.07881400015737329, 0.027470612366284643, 0.011725072399713099, 0.019800808746367693, 0.008878459388922368, 0.02051493462308177, 0.0056586203115460065, 0.04622629737215383, 0.04335314600861498, 0.013396517041006258, 0.01975412723342223, 0.05472863971122673, 0.03654467134869524, 0.017201839813164303, 0.06603249029389449, 0.035829641324068816, 0.03479559127507465, 0.020966959385467426, 0.00407010197938819, 0.005488496315332928, 0.044695203458624225, 0.04424555865781648, 0.042079155799001455, 0.042116234345095496, 0.03933699222813759, 0.033749802570257864, 0.006354828622923898, 0.029054062041853155, 0.04103653585272176, 0.010039753413626125, 0.05956260460828032, 0.06539759186229535, 0.02474591598313834, 0.05581526943881597, 0.03032602003908583, 0.028170322766527534, 0.0425204172996538, 0.04900613320725305, 0.0220668714360467, 0.0037494208164779203, 0.008410730781698865, 0.041588602121919394, 0.02599385553704841, 0.031765549044523916, 0.03081453132576176, 0.024449073875855123, 0.019732040918565223, 0.03434585826471448, 0.04845893542681422, 0.05743584515792983, 0.013053400541788765, 0.023284687427803874, 0.2097550689109734, 0.15266780076282366, 0.090755252965859, 0.07909648107098681, 0.09405418166092464, 0.13876940868794918, 0.10923449601978064, 0.12371286590184484, 0.18005233417664254, 0.13180609233677387, 0.26139625215104645, 0.1753312639359917, 0.18518203177622386, 0.0822851410401719, 0.1694867704063654, 0.0584736101861511, 0.1160498849515404, 0.07934211074773755, 0.09501177777669259, 0.13072677382401057, 0.12435235801552023, 0.07570028438099793, 0.15269931192908967, 0.21068743030939782, 0.0852346716980849, 0.0889442226450358, 0.11460179622684206, 0.07104129330920321, 0.15997308519269737, 0.23826559047613824, 0.06658223258065325, 0.18919921692992958, 0.09490547848067113, 0.10708264434444052, 0.11326122816119875, 0.11122154510979142, 0.13330866742346967, 0.09465944168290921, 0.09768301408205714, 0.12142195525978293, 0.1803310356502022, 0.12602778311286653, 0.11185073706188373, 0.1315075640699693, 0.15583159242357525, 0.18563823801066193, 0.13655199695910725, 0.08794484912816967, 0.07084649269069944, 0.06136934658778565, 0.17134563066065311, 0.11587601713836193, 0.17312926852277347, 0.10620908479073218, 0.16150023681776865, 0.15470454575760023, 0.12515705983553613, 0.08561037653791052, 0.16040786329124654, 0.13451856321522168, 0.07677209829645497, 0.07416961794453007, 0.12263269243495804, 0.16621283894138678, 0.13653412434671605, 0.14145213259117945, 0.08278534348521914, 0.194587802780526, 0.13314154424837657, 0.11813313673649516, 0.11292806746704237, 0.12928567401000432, 0.11444563817765031, 0.19434581005147525, 0.13895262671368463, 0.07322449330240488, 0.09186182823032141, 0.12275701362107481, 0.19843325072101184, 0.13203273660370282, 0.09604157001844474, 0.12069171587271349, 0.12379158953470842, 0.07880730301673923, 0.09833904887948718, 0.18573704628007753, 0.10702319110610656, 0.1224385771368231, 0.08909751049109868, 0.12581477739981242, 0.106661097678755, 0.09027273314339773, 0.08155234357608215, 0.1647583855582135, 0.05870420352688857, 0.11119170313967125, 0.10414350884301321, 0.10326368641108274, 0.15859105863741466, 0.15210190255727085, 0.06847237329930067, 0.19319485181144305, 0.20408707591039793, 0.13486966437527112, 0.07471214740404061, 0.22039885419820035, 0.1043812742988978, 0.13641951978206635, 0.10570692137948104, 0.15742150853787149, 0.14676538748400553, 0.13543668894895486, 0.12486363415207181, 0.09064178155469042, 0.12389693888170378, 0.07490201507295881, 0.07509267662784883, 0.09265527315437794, 0.18219304430697644, 0.10299962093787533, 0.14361266951475823, 0.12620508431323937, 0.11756319446223122, 0.15592628877077783, 0.12488005469952311, 0.09459591723446335, 0.06634135264903307, 0.15603972625519547, 0.218373834288546, 0.08115793831114258, 0.06383340579590627, 0.16677230463496276, 0.16885919336761746, 0.08684199902095965, 0.13123197028679506, 0.14467685669660568, 0.15651579999497958, 0.11338778851287705, 0.16247747652232647, 0.07856100159032003, 0.14305623008736543, 0.11624912997441632, 0.07579035311937332, 0.08742540342999355, 0.14385156812412397, 0.10710003519696848, 0.12622601033321448, 0.09080392428274665, 0.12165096082857677, 0.10855783375778369, 0.17530467893396104, 0.14656668528914452, 0.15509789250791073, 0.1200305377798421, 0.19886242412030697, 0.12652001955679484, 0.1434886875961508, 0.17095798360449926, 0.1413142949874912, 0.20117883410836968, 0.09042505068438393, 0.08197758147226912, 0.14025333763233253, 0.08438291347452573, 0.08141733546342168, 0.11067712932292904, 0.20983411824064596, 0.1101710507646203, 0.19951195855225834, 0.12922067035521778, 0.13313080982438155, 0.15708597297114985, 0.1807268794093813, 0.09137544075825385, 0.11625861589397703, 0.09560028476906673], [0.057648396252521446, 0.018253784526937773, 0.05960550159215927, 0.022412328881078532, 0.052003866992890835, 0.01768234438662018, 0.04337294226778405, 0.04669752976457987, 0.04671368568337389, 0.007147043278174741, 0.06458845920860767, 0.06699666819934334, 0.029052932281047106, 0.008509611145460179, 0.047020576894283295, 0.025602490108992373, 0.05241418729669281, 0.06137510056474379, 0.03275911430163043, 0.03056091529184154, 0.01754775018032108, 0.0047281100414693356, 0.039489238522946835, 0.02823566399248583, 0.02640643366612494, 0.0224967352447233, 0.042246004167412005, 0.0007822688691833589, 0.01511867793409952, 0.03329561837017536, 0.009050419670529664, 0.013308530556969345, 0.06089080976588385, 0.001326470122356633, 0.024026589135506322, 0.06102966517210007, 0.023474368499591947, 0.01824517222121358, 0.03970383879329477, 0.0567280992067286, 0.025384470022150447, 0.07668672502040863, 0.03244153277150222, 0.06625916170222418, 0.03418023804468768, 0.0186713108726378, 0.04946839197405747, 0.011084068001114895, 0.010140312303389822, 0.023182364346991693, 0.023644160013645887, 0.05621344396578414, 0.059926720069987435, 0.05695227360618966, 0.05656894203275442, 0.05901944411120244, 0.02182344699810658, 0.029929833619722297, 0.010932892943466348, 0.010343279939011803, 0.030965902310396944, 0.019142261673031107, 0.05959423112549952, 0.02551170381983476, 0.04218426765874028, 0.0290343098874603, 0.014953724374728543, 0.08962604855852467, 0.012001252267509699, 0.11023273638316564, 0.05470437190628477, 0.04492119633193527, 0.023883297806605697, 0.03985851424347077, 0.021316655978028263, 0.03847216881279435, 0.09359332746160881, 0.011395330673881938, 0.04934592318854161, 0.07118601125798055, 0.03883738350123167, 0.011384078018766428, 0.03764372505247593, 0.05140885624236294, 0.04286838362791708, 0.03040303037102733, 0.00795213780033269, 0.03300037760553615, 0.024999961190457855, 0.02665219396086676, 0.01506792351470462, 0.040302829151707034, 0.039718535861798694, 0.02579550109138446, 0.009712536686233111, 0.015929571386160593, 0.030490900655942302, 0.024650166210319315, 0.068580850692732, 0.009974016092850693, 0.03150005525510226, 0.07045391947031021, 0.05800996720790863, 0.039839505084923336, 0.059137074942035336, 0.046490763181022236, 0.035522200499794314, 0.033150154032877514, 0.06058553007564374, 0.05311679673780288, 0.09177335404923984, 0.007622983855461436, 0.032515798429293294, 0.012362342311202415, 0.00345664207374544, 0.009349193058109708, 0.016526400610538464, 0.03512294710214649, 0.030493044826601232, 0.010656779232834066, 0.026582728938332627, 0.012139966029540768, 0.011469636195605355, 0.04077122187508004, 0.009265166674075382, 0.025910092085333805, 0.04725499038717576, 0.020861226666186537, 0.031580115601952584, 0.005273616997458572, 0.023654718018536056, 0.03953419825328248, 0.013035433782663728, 0.052630945308400054, 0.06036427337676287, 0.039281396461384635, 0.0307594376749226, 0.03361783768715603, 0.061067880264350345, 0.04046056818749223, 0.04333301048193659, 0.043489629934941015, 0.024920937305848514, 0.03045483651970114, 0.008709166598107134, 0.06084234879485198, 0.06217638256826571, 0.02178299443663231, 0.060565316517438204, 0.01950502345737602, 0.060911070821540694, 0.02939285457666431, 0.01166198221367917, 0.05276944787640657, 0.04230442942519273, 0.016978569561615586, 0.010187291523574718, 0.04422487012509789, 0.01629744253919593, 0.06014347129634448, 0.043335463386029005, 0.043250008685780425, 0.0370592248093869, 0.019466767653024623, 0.020219722696180855, 0.05753874499350786, 0.019930212159774134, 0.007616090787840741, 0.03454509310956512, 0.04902406010244574, 0.07465660931276423, 0.019715884999771203, 0.05585804767906666, 0.04438843099134309, 0.07246422195541007, 0.04539802324559007, 0.03648504169125642, 0.01132237458867686, 0.07018049021384545, 0.05294763456497874, 0.02136560549427356, 0.020021770282515457, 0.05862427210169179, 0.044015236731086455, 0.03537550462143762, 0.021081720013171434, 0.05048354821545737, 0.03472940696935568, 0.05420972327036517, 0.02704369170325143, 0.040009176159011464, 0.04964507231488824, 0.048798060443784506, 0.03675801293658359, 0.01837740003663514, 0.03499050045918141, 0.09481153530733925, 0.008702262504292386, 0.038558427577040026, 0.0116985145390832, 0.00399151150902201, 0.03116767487621733, 0.03291051921301654, 0.021187222030545984, 0.05361776592742119, 0.01138686849403062, 0.016253437846899033, 0.007104125514160842, 0.03158601885661483, 0.008497216855175793, 0.0502179085410067, 0.03515291799392019, 0.0067252044183468175, 0.030357273362044777, 0.005070081512842859, 0.02397874223866633, 0.02822485492963876, 0.06580936762371234, 0.02825910228836749, 0.05212712287902832, 0.024605533873130168, 0.0149731745810381, 0.03490846896810191, 0.045985410655183453, 0.05004255473613739, 0.035757787858269045, 0.06026886456779071, 0.010230410727672279, 0.0702005544943469, 0.03234750817396811, 0.03212373071749296, 0.021932587659518634, 0.018857941929517046, 0.05376382737553545, 0.028732473762439828, 0.04982042272708245, 0.013095292445671345, 0.04295685441632356, 0.021677178596811633, 0.061799144239297936, 0.03927451611629554, 0.036937655082770755, 0.004474839636324239, 0.027646000097904886, 0.018784482032060623, 0.01032096885942987, 0.038535506664110084, 0.06680493455912385, 0.006602020626555064, 0.032468019385955164, 0.013752147422305174, 0.046007116990430016, 0.051115763041057756, 0.057035217726869245, 0.053581013078136105, 0.0316090279790972, 0.051469781901687384, 0.054670784422861676, 0.030112027057579586, 0.05472392389284713, 0.05869498223598514, 0.024800061381288936, 0.024091765816722597, 0.022450389606612067, 0.038683596931930096, 0.05554658314213157, 0.05681999320430415, 0.03696691012009978, 0.036848068104258606, 0.040908784672085724, 0.03096919659791248, 0.045537536830774376, 0.057437541495476446, 0.012160453546260084, 0.059360177256166935, 0.010855679899188024, 0.06406615687800304, 0.013927798934413918, 0.03696441650390625, 0.013519399732883488, 0.04891670568447028, 0.011542040122939008, 0.06193457982902016, 0.0101560119073838, 0.04812861440171089, 0.07155189769608633, 0.06608253225151982, 0.01491948719402509, 0.028450832535911883, 0.006320856494962105, 0.028792405367961953, 0.019750057719647884, 0.004022224548472357, 0.02295860894290464, 0.020582878030836582, 0.062310115035091124, 0.03407996753230691, 0.021118946140632033, 0.04406771802210382, 0.05748396007610219, 0.06254221472357001, 0.012535704615791994, 0.042348785259361775, 0.029473735950887203, 0.05600229065333094, 0.04029494457479034, 0.03493182075076869, 0.04327227481241737, 0.08234584278294019, 0.050305439558412345, 0.07615142874419689, 0.06752671261451074, 0.042305555793323686, 0.002912018061449219, 0.045386430474796464, 0.015162431568439518, 0.08629091323486396, 0.02214071640212621, 0.018912294280848334, 0.024619141892929162, 0.03644284359844668, 0.02202212544424193, 0.0653795428307993, 0.0512351750263146, 0.02025572576427034, 0.023776455682569315, 0.03695606713050178, 0.0717013178925429, 0.03620875919503825, 0.08250960720969097, 0.013530494628607162, 0.03809801781816142, 0.006211228984674173, 0.01749644784389862, 0.022466923808678985, 0.03857502793627126, 0.045439223891922405, 0.04162694952849831, 0.053021896830094714, 0.022938166379130313, 0.038203862495720387, 0.047362721392086575, 0.02643488803213196, 0.0038178222353703207, 0.023574691598436663, 0.046186606466237984, 0.04968555032142571, 0.020526693634954945, 0.03206374143649425, 0.028306413142542754, 0.0800988944247365, 0.03730145163301911, 0.14333855493792466, 0.10758165935320513, 0.1319194348262889, 0.1296704305069787, 0.139199043491057, 0.07713067691240992, 0.15057001475776943, 0.12009505288941519, 0.2234915896717991, 0.11068082055343048, 0.18535256119711058, 0.1092776372762663, 0.20299831219017506, 0.08493537668670927, 0.16827846238655703, 0.1430107953825167, 0.11913974343666009, 0.2599873963211264, 0.11191810880388532, 0.06540270801633596, 0.16139718091913632, 0.08075759586478982, 0.11812975763210229, 0.07885966556412832, 0.11192698404192924, 0.09240931778081826, 0.10504228954336473, 0.07206606439181737, 0.07611149017299924, 0.1616254672408104, 0.1103981157232608, 0.1107118363891329, 0.1530606589679207, 0.05773773895842688, 0.08506565541028976, 0.19266795579876217, 0.12070668435522489, 0.07334513682872057, 0.1048798957573516, 0.09596257497157369, 0.11447472018854958, 0.15731967400227273, 0.09765833576342889, 0.14853431470692158, 0.17648101438369068, 0.10986374225467443, 0.13044424541294575, 0.1458389429109437, 0.08923486633492367, 0.10699193778314761, 0.1342013209526028, 0.1281319066349949, 0.21421003128801072, 0.2584571641470705, 0.18713873678020068, 0.13399740760879858, 0.1262908104274954, 0.2628600150346756, 0.11471304882849966, 0.10957899503409863, 0.10242107483957495, 0.13564559631049633, 0.1507004699004548, 0.10620981760855232, 0.15836129310939992, 0.10000101862741367, 0.08851744447435651, 0.24922523381454603, 0.08523260216627802, 0.2507002060966832, 0.134779459929892, 0.10696048089968306, 0.14154471190912382, 0.17029155365058354, 0.11314529366791248, 0.12973270645099028, 0.13627142272889614, 0.13145106924431665, 0.16520503801958902, 0.1678257573928152, 0.08516486401536635, 0.13846836984157562, 0.17761092446744442, 0.08964240803782429, 0.1177819948643446, 0.10785737527268273, 0.10142980981618166, 0.09859668862606798, 0.08079027411128793, 0.11323815118521452, 0.06972867410097804, 0.15005962071674211, 0.12529500600482735, 0.06454015430063009, 0.08730055977191244, 0.16070234748933995, 0.17571197636425495, 0.1602471319160291, 0.162817883970482, 0.09891283844730683, 0.1402482214782919, 0.09739061298647098, 0.15453810111752578, 0.15705003775656223, 0.2636368019240243, 0.1144468052578824, 0.21731910588485853, 0.0843914630157607, 0.1700404549815825, 0.12008258141577244, 0.2210386720086847, 0.08666597346642188, 0.13407212788505213, 0.13273949867912702, 0.09300353125269924, 0.12470191211572715, 0.08241753679301057, 0.0932967330196074, 0.12778753654233047, 0.11904393429202692, 0.09856051592422382, 0.13402483399425233, 0.16441487041967257, 0.15541301774127142, 0.16079426184296608, 0.11936903399016176, 0.09101938629256827, 0.14461630423154148, 0.1121877586202962, 0.08061059803834983, 0.0879680821672082, 0.09046104018177305, 0.1546360408621175, 0.13475298349346432, 0.25015137983219965, 0.14184195095939295, 0.11776826131556715, 0.12772614269384316, 0.1489329133182764, 0.20525558106601238, 0.17703832233590738, 0.16862152969198568, 0.12716166941182955, 0.10607473485703979, 0.08921797759830952, 0.1397674929882799, 0.1356238696191992, 0.0818288940936327, 0.12874942778476647, 0.15350329450198583, 0.12591909537357943, 0.0850808478093573, 0.09877598471939564, 0.10599270675863538, 0.15725002916795866, 0.11934850152049746, 0.08923492740307536, 0.0981246657403452, 0.09152777186994042, 0.3459858202508518, 0.11583876556583814, 0.15967967307993344, 0.11003047187945672, 0.10800397276346173, 0.08807826268353633, 0.14212289159851416, 0.11308522296271153, 0.0937958498086248, 0.11196372671318905, 0.09098382427224092, 0.21775271690317563, 0.13042179947452887, 0.12932975164481572, 0.18508789182773658, 0.18272611498832703, 0.15588948503136635], [0.08635120785662107, 0.04014943613271628, 0.07092486348535333, 0.06594625527837447, 0.053972039238682816, 0.03378701682335564, 0.05052118994561689, 0.03464690389643822, 0.046171848329582384, 0.017640297267852083, 0.03201492762725268, 0.06009861334626164, 0.01616691954300872, 0.04961954243481159, 0.0509563989139029, 0.04672691372356244, 0.036626607844872136, 0.032783897793186564, 0.06179324098463569, 0.030906516925564835, 0.08012678221400295, 0.009486635415149587, 0.049944628562246046, 0.013069794796008085, 0.04385466141892331, 0.0793696931962456, 0.03978905600628682, 0.03731613513082266, 0.044460067325936894, 0.04880801794518318, 0.03006498422473669, 0.018697127433759824, 0.06236527314675706, 0.052373868745884726, 0.030836441221513917, 0.04639648074018104, 0.010191726598090358, 0.009429694452722157, 0.06630782623376165, 0.07847072929143906, 0.05562906925167356, 0.036947833108050485, 0.03399510994287474, 0.04564031453004905, 0.016352334325867038, 0.017858834737645726, 0.03948897389428956, 0.0362481956503221, 0.03655284769566996, 0.03199471067637205, 0.02800733526237309, 0.013824708260861891, 0.04053992285792317, 0.04259029283587422, 0.04157542157918215, 0.0831649973988533, 0.008782413605201458, 0.020987970222319876, 0.015270240604877472, 0.029080202603446584, 0.047143975272774696, 0.01007793627546302, 0.04126291209831834, 0.02866083403517093, 0.0109336316984679, 0.0647882538448487, 0.029422699939459562, 0.06426979880779982, 0.03518727561458945, 0.02101748819196863, 0.04271538755191224, 0.06148840912750789, 0.049332759609179835, 0.0683126122291599, 0.04465530899220279, 0.06043475280914988, 0.01852475748663502, 0.039303099403956106, 0.06627353985926934, 0.030573339268032993, 0.005002112660024847, 0.02647718451251941, 0.048918687006724734, 0.04589198316846575, 0.030510754590587955, 0.029375904771898474, 0.05395291133650711, 0.03774796499471579, 0.057661600543984344, 0.027481991398547376, 0.018170928615810614, 0.06113960820117167, 0.03636749567730086, 0.06265987948115383, 0.07171482073941401, 0.008275421569123864, 0.054062993465257544, 0.05276567182902779, 0.1057930410440479, 0.06437833726938282, 0.01740323579204934, 0.035861613894147534, 0.02597954692984266, 0.0070714180058400545, 0.0637639577367476, 0.0678699224122933, 0.04491469935913171, 0.09447939241571085, 0.040742010942527225, 0.04300819576850959, 0.03953743486532143, 0.018859468633309007, 0.013486533192917705, 0.06760668475180864, 0.05696827346192939, 0.024180645422477807, 0.02276987273113004, 0.03926703866039004, 0.05189041593777282, 0.00495724453191672, 0.00363959525878142, 0.04729986530063408, 0.01127263457913484, 0.01802713856367128, 0.04177427305174725, 0.020601687021553516, 0.04180276134450521, 0.0515829785061734, 0.07699179436479296, 0.013155441182399434, 0.046327663718589714, 0.03828923577176673, 0.014114645426161587, 0.010801248668160821, 0.0435423996033413, 0.06718221360019275, 0.02849446403394852, 0.08948753920516797, 0.026845440734177828, 0.016902526142075658, 0.027038931780095612, 0.035694629818733246, 0.03359843158562269, 0.03922635370067187, 0.05967022026223796, 0.02629654491985483, 0.07164190536631004, 0.03901981781902058, 0.02071463087174509, 0.036970407968120914, 0.039975225659353394, 0.026110276879210557, 0.029480592547250644, 0.03137008187228015, 0.036369914654642344, 0.006738368421792984, 0.05198098000671182, 0.04770309830616627, 0.05849514010229281, 0.06553126326096909, 0.03746033739298582, 0.02937721095180937, 0.018661343193213855, 0.027393559625904475, 0.022183874621987343, 0.01405267821558352, 0.0364658730769796, 0.0045119525332536015, 0.0694241068725075, 0.03830636199563742, 0.049655993336013386, 0.04539868820990835, 0.024834386771544814, 0.053282844434891424, 0.066828554363123, 0.009063804621941276, 0.08227748037981135, 0.01594175787509552, 0.043811143575502295, 0.017679901660553048, 0.016736475052312016, 0.05086132937244006, 0.03958591279972877, 0.025063226099259088, 0.010655290696636906, 0.03844786708110145, 0.000592162281723826, 0.02047795446456543, 0.10317550400005919, 0.012719971826300025, 0.013379004052174943, 0.08172673386122499, 0.10021690132894687, 0.03339430789596268, 0.040862583222665956, 0.03609054482408932, 0.009495600559083479, 0.028337788601805056, 0.02982770392139043, 0.0371745927259326, 0.0362258548848331, 0.01537501489344452, 0.018276551073150973, 0.08324096617954117, 0.02324742398091725, 0.03320309333503246, 0.061542230525187085, 0.017994691019079516, 0.0422759275617344, 0.06811298722667353, 0.02186489022070808, 0.021501524540196573, 0.011491421410547835, 0.04890410189649888, 0.021518530324101448, 0.025767045029039894, 0.04211490102378385, 0.04357124073430896, 0.07158631299223218, 0.042855708593768735, 0.03689936874434352, 0.0036093512566627134, 0.016306977652545487, 0.01868777213219021, 0.03601607899846775, 0.027915758479918753, 0.04959168857229607, 0.01242502622439393, 0.014975415442937186, 0.04434686393610068, 0.042723261950803657, 0.02990459550970367, 0.012499661683770162, 0.02767359442077577, 0.023096906254068017, 0.03757466375827789, 0.03156033969883408, 0.03819866831015263, 0.04080246162733861, 0.024669606238603592, 0.023705433422167386, 0.02174066742216902, 0.018353541049041917, 0.05035239078902772, 0.04990802499066506, 0.021803530298971703, 0.048439773597887585, 0.05812589491584471, 0.016780751158616374, 0.07658145709761552, 0.024290822546130846, 0.07877571042627096, 0.03262452348800642, 0.03879071386264903, 0.037810495389359336, 0.04971174177314554, 0.021515600749158433, 0.07546994209821735, 0.015226249483280947, 0.0813479484724147, 0.03301599069631525, 0.04329412703269294, 0.04075992426701954, 0.035412104800343513, 0.03774126785408173, 0.009202126529999077, 0.06196532425071512, 0.049166728875466754, 0.024941223806568553, 0.022049209169511284, 0.07237981898444039, 0.05592317007748144, 0.024468116961153488, 0.10519063765449183, 0.10998099310589687, 0.059699268346386294, 0.028665288617568355, 0.06026868136333568, 0.038649005216679404, 0.005098837402848793, 0.019180687111137167, 0.08156725099044186, 0.007805031408289713, 0.057234299901340685, 0.012878599742959653, 0.05497557556788836, 0.016464197609041418, 0.036417863331735134, 0.041773363814822266, 0.033595524063067775, 0.05909072421491146, 0.014134328878883804, 0.03639386694080063, 0.026452753859172975, 0.05220255561705146, 0.038681198310639174, 0.015057216232110347, 0.020017787281955992, 0.024492883489334157, 0.02083537617831358, 0.029576187953352928, 0.048661437417779646, 0.05014095588454178, 0.039658750141305585, 0.0049385699759503555, 0.03687040547707251, 0.0565659870127482, 0.06434337914522205, 0.040507733156638484, 0.015574731498158403, 0.01821017508128924, 0.062093954134200297, 0.06233572294669492, 0.045559121029717584, 0.012967159589087325, 0.05265519614996655, 0.019286151809085692, 0.022032306862196753, 0.0328643041928964, 0.03924380222867642, 0.025543298106640577, 0.05192532656448228, 0.05453628860414028, 0.0207096572100584, 0.039304724495325766, 0.0520999204101307, 0.03942663348945124, 0.069544743613473, 0.05972745469106095, 0.03404000521238361, 0.047054849698075225, 0.03571747948548623, 0.03171725431457162, 0.04733513215822833, 0.03434131886543972, 0.06585075825984989, 0.031173581523554664, 0.04389640150059547, 0.005008423459782664, 0.07045122568628617, 0.021840344216408472, 0.04807928829853024, 0.0015175987001774566, 0.05114991710122142, 0.049655637105128596, 0.03757861622476152, 0.047057414560445716, 0.019314300834334323, 0.06783411611935922, 0.05400756733225925, 0.03435607700209532, 0.010815325725291456, 0.13105263348136628, 0.13746533223560878, 0.09979481862059661, 0.09979603319828, 0.16949523852339812, 0.08903477992862463, 0.09535263305796043, 0.1363806397254978, 0.16559481567570142, 0.13216515949794225, 0.0824653192290238, 0.16272283478506974, 0.1577207153396947, 0.11566652623670441, 0.12448353240532534, 0.149342164929424, 0.1906077606337411, 0.14115938544273376, 0.08738348353654146, 0.12962118243532522, 0.14978534329150403, 0.08097656590065785, 0.1853812632283994, 0.05856905970722437, 0.10999592766165733, 0.1924017257988453, 0.1367323108549629, 0.23149131398115838, 0.132057340283479, 0.09555628855845757, 0.18406342608588083, 0.12209316210022994, 0.11764275947851793, 0.14884395737733158, 0.13676842248865537, 0.11366671390299286, 0.0979665806517005, 0.16877211018332414, 0.16324635169335774, 0.20483208021947316, 0.08414716326764651, 0.1316215308117015, 0.13458182982036046, 0.173185831201928, 0.08353515860757657, 0.13483466553900922, 0.07420467784894363, 0.09346449401761804, 0.12909298363540853, 0.12437595746346883, 0.1029252874265824, 0.09318816741662365, 0.11618717972721372, 0.18615400604903698, 0.17537618295422622, 0.22550480307212897, 0.07786922835345779, 0.13452350295015744, 0.08565523448799338, 0.07555234339088202, 0.2344733668225152, 0.17651822524411337, 0.11298866064420768, 0.0871844624302217, 0.058209883980453014, 0.1179306890283312, 0.14926513763410704, 0.1893712526985577, 0.10562131740152836, 0.2999667339026928, 0.1656930132636002, 0.13949378553245748, 0.15143506548234395, 0.10911819511758429, 0.09475060286266462, 0.17422647321862833, 0.08426341667239155, 0.1397638696112803, 0.1642835196107626, 0.12694759161344596, 0.1310875101813248, 0.08809307510299341, 0.1456813599382128, 0.10870328452438116, 0.11198883929422923, 0.09415769896336965, 0.15232054011097976, 0.13426897089396203, 0.15177328804773943, 0.09204902247126613, 0.2253116648644209, 0.1498776376247406, 0.11436935727085386, 0.11236635582255465, 0.16652430008564675, 0.1401488703808614, 0.1614239966230733, 0.1963633932173252, 0.2485310924904687, 0.15709520104740346, 0.13758712927145617, 0.1327661108225584, 0.11161402333527803, 0.13106491496520384, 0.13878231442400388, 0.15950580526675495, 0.07856188368584428, 0.22771103254386357, 0.14347878098487854, 0.20259750155465944, 0.13314408196934632, 0.14947002806833812, 0.12525935577494757, 0.1104470652395061, 0.13785540844712937, 0.1581583432853222, 0.18196676644895757, 0.10193258390894958, 0.15714542620948382, 0.1130605378587331, 0.08237799177212374, 0.11359831078776292, 0.11584511665361268, 0.10643578334046261, 0.07475690357387066, 0.07729879074863025, 0.15627854344035896, 0.12219925783574581, 0.14394113474658557, 0.07907415048352309, 0.1690441755844014, 0.14435077990804399, 0.09034359934074537, 0.12268655454473835, 0.14448293138827595, 0.11631331938718047, 0.11510623273040567, 0.18205171903329237, 0.0796867251130087, 0.14983769905354294, 0.12109864689409733, 0.19687418080866337, 0.09713597915002278, 0.20892598054238729, 0.15960210295660154, 0.16158506726580008, 0.23237354521240505, 0.08602472394704819, 0.11067415733954736, 0.1751183939299413, 0.07657359966209956, 0.2022583426109382, 0.10677476586507899, 0.09706600861889975, 0.22358137342546666, 0.1131488016939589, 0.17100580675261362, 0.24323727084057672, 0.16509303902941092, 0.23895416781306267, 0.12898000755480357, 0.13640088721045426, 0.09188481699675322, 0.24355987352984293, 0.08171303423919848, 0.08834295240896088, 0.14317181174244198, 0.11989687995186873, 0.16846865575228417, 0.12414088579160826, 0.18635175829487188, 0.15867882035672665, 0.11804852341966969, 0.12362863256462983, 0.17179809138178825, 0.11777929429497037], [0.010654623187812311, 0.00833001225588045, 0.050496487878263, 0.015082191409809249, 0.0828411937026041, 0.04416927435834493, 0.061871876407946856, 0.023205777197810154, 0.008625683890256499, 0.0364927328856928, 0.012842211606247085, 0.015621475775593092, 0.04300012459446277, 0.06078658000166927, 0.031113086733967066, 0.05830996111035347, 0.015605455563802804, 0.05291755510760205, 0.03116018045693636, 0.06192879871066127, 0.03668761832107391, 0.034930070130420585, 0.08523922466806003, 0.019883157452568412, 0.013194563815237155, 0.02807158574328891, 0.02241677837446332, 0.016377528331109455, 0.04026472941040993, 0.04909192717501095, 0.018650892057589123, 0.038040111639669964, 0.00701867081391226, 0.09794768345143114, 0.0070305841925021794, 0.005349098929270569, 0.026218381078381623, 0.07180231104471854, 0.061063483357429504, 0.04210155763264213, 0.05233594203101737, 0.015700268958296095, 0.017432014158527766, 0.051652782796216865, 0.03272900091750281, 0.020839454173775654, 0.009136843827686139, 0.04893218306824565, 0.004675268702807703, 0.033281800004520586, 0.04978278438959803, 0.04144589263679726, 0.05571155196854046, 0.10670927366507904, 0.01755960418709687, 0.04395161050238779, 0.016182093282363245, 0.018416134208174686, 0.10294862903122391, 0.009431340748311152, 0.028962425887584686, 0.05497507005929947, 0.03601797211116978, 0.03189800925818937, 0.004542140132148883, 0.06759603853736605, 0.012592648122725742, 0.08952445151018244, 0.031233564019203186, 0.06816952276442732, 0.03569144409682069, 0.024087268825886504, 0.02099381580150553, 0.004490518036098885, 0.027212582462068115, 0.05102219984733632, 0.04058503186596291, 0.013457866784717356, 0.09267314576676913, 0.033604205918631384, 0.04857895130823765, 0.048991269897669554, 0.021374217799997756, 0.04499511593686683, 0.034773633881871185, 0.07852576526680163, 0.042411590460687876, 0.026494563490684544, 0.02057184844410845, 0.06058920095009463, 0.017887287407315204, 0.04659457225352526, 0.022456148672582846, 0.03148213514525976, 0.03393545314403517, 0.03534099433038916, 0.04254599467718175, 0.05929792845355613, 0.015579655966056245, 0.033856196861181936, 0.0206010424132858, 0.00627293877602954, 0.02745705862928714, 0.036343295725860765, 0.03340810590556689, 0.030954072052346807, 0.05638628379840936, 0.012346865775595819, 0.030029747901218276, 0.08693371659943036, 0.023374042008072138, 0.022922171612403223, 0.03891278909785407, 0.02902076972116317, 0.03184553814519729, 0.027815186019454683, 0.06241753391389336, 0.009891497752895313, 0.03827572274687035, 0.06956747453659773, 0.025685237454516546, 0.02957802339057837, 0.044486747322870154, 0.03558425252724971, 0.009135852318390139, 0.048558768284107955, 0.0678227845845478, 0.01295864227826574, 0.06220055877098015, 0.037891685497015715, 0.005842583453548806, 0.033150133676826954, 0.0637202329401459, 0.06825659916337047, 0.017013571790552566, 0.032219733244606426, 0.03347672615200281, 0.0554326062223741, 0.03877950785681605, 0.021744268746780496, 0.02361836380857442, 0.017446773991520916, 0.07300662927861724, 0.011500780104792543, 0.06608548387885094, 0.0036359549184063716, 0.012015652476942964, 0.021247862705162594, 0.044029065274766514, 0.03048271413094231, 0.011199379938521555, 0.07552476094237395, 0.02869868271851114, 0.005528639295204941, 0.05533278015043054, 0.04035443173987525, 0.04852858704647847, 0.05262542203334825, 0.03377104750169175, 0.04358289118057915, 0.0219790181145072, 0.0836816882448537, 0.045103908849081824, 0.01736934296786785, 0.02513152064888605, 0.07605284439133746, 0.03613271916817341, 0.06203661113977432, 0.03504089864769152, 0.027457287634855936, 0.035898410848208835, 0.016289719114346162, 0.018878284409376125, 0.013734973700983184, 0.03716517805254885, 0.03679838577019317, 0.037616756678159745, 0.06914597536836352, 0.024213223585060666, 0.04052576861743416, 0.058388223339404376, 0.08712920253830296, 0.05797060539147683, 0.027299669039036547, 0.00600678171862715, 0.0324386320342975, 0.013594462669321468, 0.029597124151353325, 0.08848734466092927, 0.07674876347716365, 0.02612483824071075, 0.015473276942170091, 0.028067590868366615, 0.0754608768703682, 0.04407870689673083, 0.05415567456345473, 0.013712388662887471, 0.03064859558695129, 0.0836169763601252, 0.02353521273471415, 0.008613532176241279, 0.027038680722138712, 0.04336520357589636, 0.03567665881876435, 0.08157896250486374, 0.011625264987482556, 0.02294347421931369, 0.02674015924068434, 0.02077858110091516, 0.04067946358450821, 0.03518959281167813, 0.010535325705339866, 0.07618760823139123, 0.034309783950448036, 0.022113759902172854, 0.043808090167918375, 0.03989556225548897, 0.029988503150109733, 0.05538826395890542, 0.06310804507562093, 0.024756419705227017, 0.03685094848541277, 0.011526444843704147, 0.04461935342156461, 0.02664672496861645, 0.022402591903560927, 0.04122089720996363, 0.052802960720977614, 0.040956529788672924, 0.04717593427215304, 0.021126128433804427, 0.021031588149656142, 0.06026859993913344, 0.008257624443753489, 0.08532374298998288, 0.05625446480033653, 0.005770924642482507, 0.031201194506138563, 0.06853173154273204, 0.03911754382508142, 0.017902245711801306, 0.023144661548680494, 0.058389906106250625, 0.03161336721054145, 0.017793607166303054, 0.07741716118263346, 0.0602211771266801, 0.012461159062305731, 0.026332335945750986, 0.009491512385596122, 0.013328635549571897, 0.07165893659527812, 0.023333200985299687, 0.052094054474894486, 0.047591289305793386, 0.009669134193765265, 0.00938735980473991, 0.040572916623204947, 0.04422418141205396, 0.04285608857337918, 0.04531241587496229, 0.051536173160587034, 0.03625485886420522, 0.0028613756003323942, 0.01275421494418489, 0.0354959004824715, 0.04130150717017906, 0.025512514669182043, 0.02384291649130838, 0.022354548231565526, 0.016580184688791633, 0.028736402480197803, 0.04823219955765775, 0.034963216566081555, 0.037586975776191266, 0.044077363397393904, 0.026985783828422427, 0.028943369231585945, 0.009916111610696783, 0.045891630330256054, 0.04431291004376752, 0.009818746924533375, 0.03960504748725465, 0.04229429550468922, 0.036101516735340865, 0.1291988350983177, 0.008844290061720779, 0.01391480753331312, 0.0417004484417183, 0.023322846540915113, 0.029125352323587452, 0.02401616344494479, 0.09392870696527617, 0.01469921097824616, 0.029298165014811924, 0.061545243220669885, 0.009319392648259444, 0.03557308044816766, 0.029593439706202065, 0.004082928411662579, 0.022919304801949432, 0.023530010067458664, 0.08073383356843676, 0.0106548046959298, 0.049603067604558806, 0.017735699291474054, 0.05220106962536063, 0.02502154708573861, 0.017379098605098467, 0.05863979019756828, 0.030061347277036736, 0.07383078469761781, 0.0519545849944864, 0.04114051116630435, 0.018477402527683547, 0.046789705354188166, 0.056696811957018714, 0.04639709820704801, 0.08891038410365582, 0.09485768925930772, 0.05408479479540672, 0.05562862141856125, 0.0030876405237774763, 0.03377475230289357, 0.043472907439406426, 0.010117389694122332, 0.029447188268282583, 0.018727837928703854, 0.033726308295237165, 0.014177281841901796, 0.058002564390855174, 0.03342597173260791, 0.09944037228290524, 0.04333358384402735, 0.028736609433378493, 0.01917269736129258, 0.02933692293507712, 0.010354822667847787, 0.015507062897086143, 0.08096230987991605, 0.06989055898572717, 0.03387274633028677, 0.05953143270952361, 0.03929525214646544, 0.018225184275901744, 0.010739730138863837, 0.047007464205047915, 0.021574965777939985, 0.0073784076043271595, 0.04185906618035265, 0.06803190229194504, 0.056143704136567454, 0.08597886855048792, 0.07959446470652308, 0.11708014538245541, 0.08744584090475525, 0.2205578756651708, 0.14065014491123812, 0.11023355062518801, 0.12170721138162272, 0.09249474533966609, 0.10431293903716973, 0.09939020140362637, 0.10522571791495595, 0.17039864004722663, 0.12824349850416183, 0.09342421617891107, 0.09821893461048603, 0.10508892525519643, 0.200576335723911, 0.1871080127145563, 0.2343638784119061, 0.10727188776114158, 0.17051473738891737, 0.12944526544639043, 0.15935636471424783, 0.07688811421394348, 0.09781515877693892, 0.15671499073505402, 0.07285391140197005, 0.15261857983257088, 0.1368055519248758, 0.06275318483156817, 0.17538180122418062, 0.09687564561941794, 0.1675517785229853, 0.11473359486886434, 0.05401660881138273, 0.13431067365620816, 0.1879499118242945, 0.07664739713072777, 0.11118779477796384, 0.2308740099625928, 0.15099859104624816, 0.12896229779081686, 0.12879106269351073, 0.15091044934732573, 0.17610346392861434, 0.08821588994136878, 0.10420404095202684, 0.08638042557452406, 0.18461056958351815, 0.17295485788158008, 0.15384239916290554, 0.17159169459981577, 0.13659728238625185, 0.08324184827506542, 0.14235664691243852, 0.14070049220962183, 0.11244687757321767, 0.20469089065279278, 0.12384902073868684, 0.21033825618880136, 0.20544272102415562, 0.1508502225790705, 0.10208327975124121, 0.13734433587108338, 0.1189734616449901, 0.15758891669767244, 0.1485508709613766, 0.14104134749088967, 0.1424651039498193, 0.16167394178254263, 0.08031510282307863, 0.06773498215313468, 0.1120540668655719, 0.11235917692205735, 0.17318511195480824, 0.13319517565625055, 0.18151469927813324, 0.24024153873324394, 0.1117491332281913, 0.11283483675548009, 0.19879068939813546, 0.13703314614083084, 0.1185932241912399, 0.1262111368456057, 0.18018603271671704, 0.1421900258532592, 0.08037282579711505, 0.0934522125337805, 0.19875997890319141, 0.08738643516387258, 0.0804474985759173, 0.06810816284269094, 0.226439770045025, 0.12665039327527794, 0.09277333146227257, 0.1290631688066891, 0.16631284143243516, 0.10296557883598975, 0.08660173655620643, 0.07511485115225826, 0.1063249446451664, 0.12226063811353274, 0.16137712342398508, 0.16509321544851574, 0.13521505227046354, 0.12107263186148234, 0.1633026972413063, 0.1578902948115553, 0.15625700673886708, 0.13192707513059887, 0.08336552485291447, 0.12238308654299804, 0.09513730675514255, 0.10127425566315651, 0.09703875186720065, 0.13429988494941167, 0.10655289848468133, 0.08543815077947718, 0.1975357931639467, 0.1054085356050304, 0.12121911400130816, 0.11105449657355036, 0.15950271114706993, 0.05442093086561986, 0.14875909978789942, 0.13501115249735968, 0.11198558911148991, 0.14516228064894676, 0.11782266625336238, 0.08616885157035929, 0.0809543506641473, 0.0924303320103458, 0.18799156030373915, 0.12596174808485167, 0.17222313928816999, 0.15142738446593285, 0.09117709818695273, 0.0738698954560927, 0.10224644706717559, 0.11249915191105433, 0.1143632640263864, 0.17362442266728195, 0.110430651477405, 0.15272519125470094, 0.15372231203530515, 0.07302317196237189, 0.1326556588922228, 0.1290559491940907, 0.16646267553525312, 0.11966574378311634, 0.1655951820846115, 0.10823878659201519, 0.12786752225032874, 0.15947063001138823, 0.14979343142892632, 0.13743430961455616, 0.16357571259140968, 0.09699112549424171, 0.14492121072752134, 0.09691382678491728, 0.15733343469245092, 0.1176688830767359, 0.1658086356307779, 0.12918367662600108, 0.2169211586671216, 0.17531356774270535, 0.1592016994420971, 0.22488326499504702, 0.07154339565230267, 0.1268040407449007, 0.10400727258196898, 0.0928148849468146, 0.10504682894263949, 0.11194736044853926, 0.146237812936306], [0.03061281643541796, 0.01949197522896741, 0.023956454059641277, 0.02992599311151675, 0.027000837127811143, 0.014506829337083867, 0.038227750321051905, 0.03852634644135833, 0.07798145804554224, 0.025043894636577795, 0.03369350451976061, 0.053414714323090653, 0.01724370542381491, 0.027100647932716777, 0.04703017137944698, 0.013592737494036555, 0.05857190955430269, 0.03201529403616275, 0.015722725074738264, 0.014727633113839796, 0.03713019957233753, 0.010961415162975234, 0.05442046946180718, 0.03325580193528107, 0.03209659270942211, 0.0168282791439976, 0.028400005174002478, 0.08098555648965494, 0.04823953791388443, 0.007497843338309654, 0.020620794567678655, 0.0974856825279338, 0.052282259733017, 0.04206247401556798, 0.03889119132821049, 0.00599762616080365, 0.07989126270903008, 0.033524528944066594, 0.01725123546618436, 0.0035816331011509256, 0.03085057849862746, 0.02804252578477774, 0.02724242103951318, 0.04497569626463311, 0.04192463301920465, 0.030904905404895544, 0.024528387834184935, 0.06739112774708442, 0.021320986727784787, 0.014358823886141181, 0.07692375087312289, 0.056036515959671566, 0.047535744429166825, 0.018220775494618074, 0.05326519573905638, 0.08479785120912961, 0.05262719979509711, 0.014732803550681897, 0.02641188908767487, 0.021764321152919104, 0.021502142007063543, 0.011373657417217535, 0.009434217736790223, 0.03847739353243794, 0.028368514363787005, 0.034783716912248304, 0.028404731170407364, 0.10071369752820049, 0.017468035886330262, 0.052687331568449736, 0.053113926534674, 0.007700067978086216, 0.029990077351353, 0.02084938283743603, 0.01775772962719202, 0.02047910967043468, 0.05300767473610384, 0.04878007587311523, 0.030803776545716182, 0.04853713658771344, 0.03238745013784085, 0.04126198589801788, 0.023367008992603848, 0.05138441201831613, 0.03499948426282831, 0.05416901456192136, 0.08700079657137394, 0.03272717905097774, 0.007932527290124978, 0.09507581112640244, 0.018853631535811082, 0.027769544361425296, 0.01597640896216035, 0.023621532567111508, 0.03687789650367839, 0.022348178484077965, 0.02201541812558259, 0.03331463770674808, 0.029740508778819015, 0.012462723085523715, 0.02812926291621157, 0.049596685982708416, 0.07308191273893629, 0.005692011019813695, 0.06661366910806724, 0.05583556781389883, 0.050486065580376556, 0.05384033219888806, 0.023749772292960967, 0.06228436463113342, 0.017702498573011587, 0.025552565198657767, 0.00651499257323199, 0.012697070421251868, 0.036835321823933294, 0.018842345802113414, 0.028990646159010272, 0.06951874893690858, 0.01667420080463801, 0.03131564640040908, 0.02270935249647924, 0.05378340311082346, 0.02628497589778687, 0.031997312858168564, 0.013668449279586119, 0.04373788893488901, 0.05204602098092437, 0.023945836682936976, 0.028565903593386923, 0.048789487153823884, 0.043221384686018736, 0.025675347806619744, 0.03540923798988972, 0.014498547817181264, 0.038504935268844874, 0.029692695808729956, 0.018207143726093427, 0.0634025971272162, 0.028577554039657116, 0.07291088120213576, 0.046786509454250336, 0.01576474165943052, 0.013272790421199585, 0.028581350443086455, 0.02021573799928384, 0.06512658497584717, 0.013726863511172789, 0.01019266976176628, 0.035519954548882585, 0.02068367101518171, 0.10602338332682848, 0.00625594104972801, 0.01804594076903803, 0.03863718852932964, 0.03412963290299688, 0.03984474676794239, 0.04663955573258655, 0.020527100755966136, 0.028162219362067323, 0.007788823751200522, 0.06793132983148098, 0.005599080559997154, 0.061208058813852925, 0.03151430109781878, 0.02452656766399741, 0.06156352295407227, 0.037593072413333824, 0.008468228142841585, 0.011288749785827739, 0.014637515181675553, 0.04555873087208186, 0.045440031348594596, 0.026991349511912892, 0.0646201739353793, 0.028272443983171667, 0.08785086524273668, 0.02672684468728091, 0.09937996231019497, 0.03413032840139099, 0.0725630573662264, 0.016716524426426207, 0.025907929254961864, 0.02346855684715722, 0.0054627051992741016, 0.046743293558912616, 0.015734348379607712, 0.03669897699728608, 0.020986796356737614, 0.07534182111599616, 0.04441830688821418, 0.05584126411538039, 0.027282268008483306, 0.046141300683042834, 0.02518753201833793, 0.040495366855923615, 0.020502476720139384, 0.03717066061549953, 0.05577068629541567, 0.09512283360319478, 0.06203969847410917, 0.023218894976058176, 0.02580398617179266, 0.022687851418075815, 0.05268582861338343, 0.015380226042387741, 0.019282394421419928, 0.026022879872471094, 0.042605312208512, 0.06588702595659665, 0.011974055735793496, 0.019561830409137265, 0.041667027199374776, 0.04192499264276453, 0.04135501644174967, 0.01586894428224436, 0.024477711446317177, 0.05516016423436148, 0.02782342004190598, 0.023199024078037058, 0.00900798409046339, 0.08923785188900572, 0.024925680265628865, 0.05581606671746288, 0.004299077862274966, 0.06127786649657147, 0.025077505868726542, 0.008951000719597297, 0.059814191822494776, 0.08766316210052796, 0.04932494967111519, 0.03212638718209096, 0.02466509906974222, 0.07718624214508704, 0.011804544117434748, 0.06192243405218635, 0.018705100220228945, 0.009980991432842399, 0.006201006854618234, 0.01258242005548839, 0.024112915753253868, 0.022873744568122283, 0.016948820890060494, 0.03920195697407637, 0.03732678473794034, 0.031111916261059896, 0.016209612966382077, 0.0378346614140485, 0.0038406791115578797, 0.018277999745415788, 0.02941964313920055, 0.028334093978628516, 0.033701741934887, 0.03221120745209711, 0.042370583196835856, 0.00959989648046238, 0.03084881091490388, 0.027904175887150422, 0.02697175511691187, 0.03628697392663785, 0.08499387997601714, 0.02904634370601603, 0.07346873198236738, 0.07917506221149649, 0.030552813583718877, 0.016798360838687847, 0.012025043401601059, 0.010933752138433712, 0.04787017398380807, 0.08587953780910798, 0.053984551424426694, 0.013752170322862054, 0.020722013332747986, 0.03582983131387404, 0.02327312179841101, 0.03393840477136629, 0.03715909837878176, 0.07331543735095433, 0.10953465277062994, 0.020994019362011125, 0.01410017057787627, 0.04758993223575609, 0.00409763989903565, 0.038585680936064036, 0.033861245161720684, 0.017666410688044767, 0.0679352314078382, 0.05137243926791208, 0.03843110726614084, 0.051600047054567506, 0.04312329227104783, 0.024335012139220322, 0.028089802712202072, 0.058370825701526234, 0.03823174010696156, 0.03916342297036733, 0.03828748515141862, 0.014053711285149413, 0.06147846858948469, 0.01748792883673949, 0.023320125615490333, 0.013540850769329284, 0.06118827951805932, 0.02555073145776987, 0.062431477808526585, 0.028207852538408976, 0.020442816528624723, 0.029099082840340476, 0.022307040602234856, 0.04366965206073863, 0.05484621286658304, 0.032737801516694684, 0.009354016593923526, 0.03605760534160903, 0.04290250036865473, 0.04941984618614827, 0.05094236680971725, 0.03601392464978354, 0.05804499318557126, 0.055165371990629604, 0.008250791596115699, 0.015856766274997165, 0.07586700722043004, 0.04724767577967473, 0.02816187500554536, 0.020240728444020663, 0.011050996204305972, 0.10908725392073393, 0.014949176493766052, 0.033112997455256324, 0.015683269959741404, 0.08129268179514579, 0.03274920429768307, 0.05541434684502227, 0.03864490347249167, 0.022198005113750696, 0.015704955938937407, 0.05325321281062705, 0.04776017327925988, 0.039502839757395644, 0.06021417464528765, 0.011609203215422375, 0.07112285321844475, 0.017787552937599163, 0.04393324255943298, 0.01852284910689507, 0.024918207898736, 0.023323903359206657, 0.017102973868272135, 0.03853246682722654, 0.008652394421265593, 0.062366243451833725, 0.07830529566854239, 0.1718231700360775, 0.21143375097640923, 0.10153686228607382, 0.12592877128294536, 0.08363054706049816, 0.09819758789879934, 0.08429322471576077, 0.14590746137712682, 0.16055874233799322, 0.07131772847580058, 0.09308367980910198, 0.10770439276737825, 0.1624709354447467, 0.12140242702194623, 0.09722372729863439, 0.1914089476423604, 0.1429217851587704, 0.17519949243537017, 0.11246764074478831, 0.11232443592910256, 0.17692118005028792, 0.09710898024163075, 0.2254124680267913, 0.2023572458752564, 0.13386959875268595, 0.11580593804163591, 0.21933299782020704, 0.25816137716174126, 0.1126195579501135, 0.09051751465137516, 0.1016572140423315, 0.20378047307687147, 0.13300023254539284, 0.11597965657711029, 0.12565517239272594, 0.09521456475236587, 0.10746982999678169, 0.10893052590212651, 0.06959049722978047, 0.10915093443223409, 0.17854233591684274, 0.09096026553639344, 0.08773666779909815, 0.11176066832350832, 0.19481646908181055, 0.08873973254646574, 0.15812630286174162, 0.14516982595835412, 0.12875868300242083, 0.05201512049617512, 0.1294006856956652, 0.22911006318671362, 0.12921921829027788, 0.15326808712312154, 0.14067493858081953, 0.218560092151165, 0.1849663933472974, 0.09826603851148061, 0.09657303935715131, 0.11560290679335594, 0.07560992387256452, 0.08977875964982168, 0.09380558000079223, 0.10032489696251494, 0.10690216760018043, 0.1028289015271834, 0.1478213101093258, 0.14418010120945318, 0.16157558134623937, 0.11614101220454488, 0.14432830682822637, 0.07093651393162352, 0.12780998248074735, 0.12184655533305236, 0.13302609830030374, 0.09921898666237082, 0.10843552782067231, 0.09326483508838074, 0.09424788983804838, 0.09388922301254102, 0.12871601672044822, 0.119300637660282, 0.10302126620497022, 0.10602702705987863, 0.09157745420400586, 0.15594808331557683, 0.16080627191279614, 0.10845367863242115, 0.0875382370182446, 0.13332157315952436, 0.09049251063593797, 0.12431961191552025, 0.16024325069572243, 0.09503510581063372, 0.17812989519110747, 0.1260688751935959, 0.11289490746068102, 0.11698272132447787, 0.10353427939116955, 0.14726553564625128, 0.1668580307492188, 0.22031376590686186, 0.14768128762287752, 0.1367275882512331, 0.13521875707166536, 0.15546255079763277, 0.1114661909107651, 0.09593178305242743, 0.12072352559438773, 0.17473063830818447, 0.11228478234261274, 0.13663830661347934, 0.08200337258832795, 0.1407802336450134, 0.10174641425588302, 0.10367289731012923, 0.1046728543671114, 0.1282488860722099, 0.1509733766849552, 0.11421815252729825, 0.0894181454288108, 0.12479477641837937, 0.1081445516486253, 0.10641466733068228, 0.07982387061097793, 0.10827098986400024, 0.12051811947354249, 0.15261739918163844, 0.11917544794934136, 0.09510424174368382, 0.11214089220655815, 0.11559104600122996, 0.1294863439564194, 0.16188915951975755, 0.15279315332216875, 0.09465591330081224, 0.1356434521398374, 0.1410822495818138, 0.16994218954018184, 0.2374867136989321, 0.1278353596904448, 0.10834583227655717, 0.10203412667449031, 0.09059351057346378, 0.11621164769998618, 0.1727907338312694, 0.09550902859440871, 0.08665836030351264, 0.14337203385574476, 0.06922201200255326, 0.18441363157970564, 0.10665742680430412, 0.1588816209031003, 0.11810790880450181, 0.11714007359530244, 0.13546526884394033, 0.16305458412638732, 0.08099823830915348, 0.11198267141090971, 0.12134864633636815, 0.12449525749044758, 0.11546002088912896, 0.15802138777715818, 0.10006520804017782, 0.12817138380237988, 0.11360867880284786, 0.11312437443328754, 0.08728616125881672, 0.06843645844076361, 0.0801262054592371, 0.12269614902990204, 0.14954758462096962, 0.11933756353599684, 0.14467562176287174, 0.15188844901110443, 0.29878402022378786], [0.046417535681809695, 0.052186491300484965, 0.017554523656144738, 0.08619403200490133, 0.07419846246817283, 0.037483407583619864, 0.05088731387097921, 0.03569263153310333, 0.048155864368059804, 0.03944124234840274, 0.018662433938256333, 0.01341428532863834, 0.06274731550365686, 0.035637822866972, 0.03179349111659186, 0.050032441171684434, 0.04319677082821727, 0.01624224710810397, 0.08251870636429105, 0.004552132408467254, 0.049342730681278875, 0.040832235743956904, 0.030320520512759686, 0.06678243433790547, 0.024962750330035175, 0.016948356093572717, 0.056489685749901195, 0.01587405873994742, 0.03802433909316148, 0.015954492281058004, 0.015899052577359334, 0.014816629766885723, 0.039493781314896684, 0.026549887843430042, 0.026787051099485586, 0.055507122938122065, 0.01130974620381104, 0.016677568034668053, 0.017975658111806427, 0.043176340138805766, 0.013946316155072833, 0.08018314133265189, 0.06372050435415336, 0.02051297535321542, 0.020800791248413067, 0.06820091857974019, 0.012718591855705848, 0.037616254562245946, 0.042308582059506855, 0.036622024340821166, 0.03226104245654174, 0.08307062674845968, 0.044396349495010715, 0.07067665537553174, 0.02418021794541606, 0.03391116837571774, 0.037727656441607645, 0.059187659727675576, 0.015578108906213726, 0.023813113536951796, 0.07336499076336622, 0.01594046696222254, 0.029714439463402544, 0.04705062921025923, 0.02131315813000713, 0.04546234497268285, 0.024401869890945296, 0.003788983224824603, 0.027771946375391314, 0.025135081261396408, 0.02011845643366022, 0.012611315469257534, 0.014090826302500708, 0.019827232596331408, 0.033164688252976963, 0.049086997618100474, 0.03874592037339296, 0.0403659023743655, 0.021098101544859152, 0.02275368627826018, 0.015223950945905276, 0.04127415881625243, 0.02090712107851037, 0.0732139895803162, 0.09067519261900868, 0.014640666976837175, 0.05315183289349079, 0.10060783927994114, 0.08204181159713439, 0.04339739327718105, 0.02668168648545231, 0.04034074568854911, 0.05823095927813223, 0.020197712716513445, 0.01286425975350929, 0.07084694730916194, 0.04259102565369435, 0.01928252843208611, 0.019724437933681265, 0.045890734664031436, 0.07189765200018883, 0.044997969176620245, 0.06226352682071073, 0.07506732655955212, 0.07916816151035683, 0.011159086832776666, 0.008690687545043017, 0.045189163381499906, 0.03372812337641205, 0.025819431325154643, 0.0867948340518134, 0.0049374088328996936, 0.013438788076330508, 0.04010078177920409, 0.034752762144697566, 0.02776351218510951, 0.016226367692330053, 0.026747729995154908, 0.06521821434476546, 0.02188942435064486, 0.03418360357838018, 0.040575047223163505, 0.045425439453018565, 0.02959978740130152, 0.04745406238362193, 0.012488049405094768, 0.0291116221674851, 0.052485436866325993, 0.0013894746433444588, 0.03532002081296273, 0.015195238736591168, 0.06443815691662685, 0.0223091525424804, 0.035488117685807605, 0.02198183742750968, 0.0301722131137337, 0.04771168516682727, 0.07332706065582377, 0.024901441298425198, 0.016859152487346103, 0.05424190618629966, 0.015913898923567364, 0.04061267538262265, 0.02745606966449746, 0.022435505940978016, 0.030059376132807562, 0.041240513657352755, 0.030681816661464315, 0.020916115060182552, 0.036855396282460005, 0.033594496082514524, 0.0332046811069761, 0.012907312800442534, 0.018305884142007147, 0.049455445525901656, 0.03579043557069131, 0.05788416003010102, 0.022605071842138256, 0.01755751429923943, 0.0895322003800954, 0.010554072779736348, 0.023846779051902037, 0.012093054662857736, 0.029797739814966917, 0.067264017782041, 0.02445854283204036, 0.03161819498719914, 0.030498289902295386, 0.020313050098983303, 0.06183998526207038, 0.01624748370211039, 0.05057775941012161, 0.022748122291107262, 0.005448214235782091, 0.024649609811604023, 0.013499701861292124, 0.052353193783866506, 0.029230660958481685, 0.025417440038706576, 0.02290679600888065, 0.032751548636172495, 0.027769440884834955, 0.04431013822821634, 0.06375544212226357, 0.06330382278455154, 0.04563392273017338, 0.048395098852259774, 0.032224350675408325, 0.04925933872748699, 0.048050226643681526, 0.016082329974908913, 0.030251978297850916, 0.019012368018073694, 0.038219126140964885, 0.06823227368295193, 0.02436452162718134, 0.0366294882260263, 0.06830509406115327, 0.02531812117168946, 0.02303595345334283, 0.018547347613743374, 0.02098355465568602, 0.05973926120038543, 0.05071554273100836, 0.05282230914703437, 0.01609248255512544, 0.0077369387228307974, 0.021485183720609972, 0.018253764170887213, 0.013793518550560942, 0.06849300076386758, 0.08214127126016788, 0.0275877580445792, 0.029235193572406257, 0.05374555782015834, 0.01659146194080157, 0.009651220021104174, 0.06991015507706574, 0.05171213764697313, 0.008992416800798049, 0.031549883474196704, 0.06479757691600493, 0.01755971784171249, 0.08674436461712633, 0.026640085503458977, 0.021598829854545847, 0.0111979134547125, 0.06284009159675666, 0.1067679805148925, 0.03266337640317423, 0.027559668391144702, 0.0180242429154792, 0.031969123120818815, 0.011344298055129392, 0.03921628424099513, 0.017892708902114203, 0.04211509779893926, 0.05142324797010847, 0.04091113918860044, 0.002509836573153734, 0.027702554295371686, 0.048187036266816516, 0.037248498760163784, 0.03614982842866864, 0.0455020799833749, 0.03475968659456287, 0.053985521729503355, 0.050309727899730206, 0.05354879962812577, 0.04091001282046948, 0.01245080546608993, 0.0314946134042527, 0.07138078473508358, 0.050748868978449276, 0.018857195540996533, 0.04530049062200955, 0.023371180286630988, 0.008772161789238453, 0.06834387912281922, 0.05790608349655356, 0.0652881713051881, 0.013990601591233696, 0.06557203643023968, 0.05665696838072368, 0.02916464628651738, 0.047890726809522936, 0.0065968540064724425, 0.05780967724110399, 0.03749840999288218, 0.01727562371109213, 0.045428635352956395, 0.10503724124282598, 0.028796184808015823, 0.012912087990636272, 0.00918267123467688, 0.01650996818872435, 0.05234983842819929, 0.09650574225400176, 0.021532820271594182, 0.022492416369329606, 0.04126456093841365, 0.04305408848449588, 0.026142885575869253, 0.06937939141477857, 0.00578889182569193, 0.020990965954427208, 0.015450052384819304, 0.035917453933507204, 0.017266385456813232, 0.006697311540067728, 0.05659026160304036, 0.01391456410887518, 0.01391646994410881, 0.040356765900339396, 0.031090993633759872, 0.023199738236144185, 0.06730966961809567, 0.051784347343657694, 0.02977449999057821, 0.0313666450924107, 0.001180672348709777, 0.009261543297075799, 0.00500150113033929, 0.02909905569893973, 0.02215885873218732, 0.011314337341380971, 0.061075215227901936, 0.06822482336844717, 0.03420783406389611, 0.022270538810906664, 0.019063188594632914, 0.019443420959370475, 0.056844138872942755, 0.03216517224375691, 0.048265810789806504, 0.015853517788595388, 0.020740730721237402, 0.0068668375772956225, 0.0436185108763831, 0.03555959795734712, 0.0277675104527069, 0.04360070272481867, 0.018110128485464623, 0.055706398495073826, 0.053587913779275756, 0.01306102897173592, 0.030100369825959206, 0.05040762014687061, 0.02157143230683037, 0.026946040336042643, 0.011974632490559347, 0.035746144197349033, 0.028432186393599426, 0.03299447095819882, 0.03368100590471711, 0.027538571041077375, 0.018949961456071054, 0.003997297716393534, 0.04231139458715916, 0.009866354637779295, 0.018403795048860565, 0.046451269050261805, 0.07438701377915484, 0.04666191006877592, 0.01932458912155458, 0.0677308566602213, 0.022580461377011876, 0.024566039742369736, 0.008181614950964493, 0.05251019321648138, 0.05529957603929298, 0.033494300208985806, 0.13490048343581812, 0.0679391465548958, 0.11732049605676106, 0.18678333370813302, 0.15840431222958223, 0.1103126203109111, 0.12327445085559573, 0.13850369437464646, 0.10667318917278733, 0.1454795907650675, 0.13688073360494205, 0.2085935662367514, 0.10282459961516516, 0.11650434056563036, 0.16354124301246234, 0.12504160031676292, 0.10429820804191486, 0.10786643371518169, 0.1178647761366197, 0.07164515554904938, 0.08357559250933783, 0.22090576056923183, 0.09992532126073327, 0.14248083239155157, 0.13985165847199305, 0.11549510114959308, 0.1528672764876059, 0.12219351742948804, 0.06688218577099697, 0.11335151403078012, 0.0564449499361217, 0.17296902569276945, 0.1088012039129223, 0.050464287998953035, 0.16187043195324285, 0.14602178095706872, 0.18974232992955617, 0.08593494019338063, 0.09163165558129549, 0.0859659288876823, 0.11979504541626998, 0.1470373986022813, 0.19209293808255876, 0.16389423049986362, 0.07310339515762669, 0.10749072209000587, 0.12438697687217168, 0.13634133897721767, 0.1157245681221996, 0.09286637218402964, 0.14154882383133682, 0.21391785410898073, 0.15726881101727486, 0.096183410978743, 0.10214039204376084, 0.12309336342981883, 0.1505706797220877, 0.11576791293919086, 0.06364882391478334, 0.1281315673674856, 0.2007202258599656, 0.10612551641783544, 0.08297183883509465, 0.19578643489096845, 0.16267909641776765, 0.14296066521533898, 0.10330690909177065, 0.09425117394753865, 0.09023771395108529, 0.09114359212773186, 0.11137486009725503, 0.12547990679740906, 0.11713365465402603, 0.10963108616748027, 0.1380212288349867, 0.1596375631966761, 0.12517137692442962, 0.10134370372231517, 0.06692327106637613, 0.11942794440048081, 0.10414660974804844, 0.16796116584113666, 0.15133119534168923, 0.16283776504652842, 0.1418162751942873, 0.09519892452018601, 0.18305567944688456, 0.17166520708373614, 0.17793583417577402, 0.1257471138877528, 0.11121203883418015, 0.19978113339415618, 0.13132389821112156, 0.1340169765587364, 0.12006082758307457, 0.19921545231980936, 0.12931174332542078, 0.0827152779591935, 0.09282905275800399, 0.09213131519832782, 0.21101723904056208, 0.14921392181089946, 0.21652173224304402, 0.17547803106052534, 0.23007323007498467, 0.11140796582081489, 0.13288252029035771, 0.13791393887783798, 0.09921498330576078, 0.1425315189574446, 0.19912437934960636, 0.07048931185688291, 0.10657984311027185, 0.10118405800312757, 0.09152701191071953, 0.08080811958227839, 0.08883685804903507, 0.11690410625721727, 0.1547498990382467, 0.09713156867240157, 0.15918690737869057, 0.1836853599441903, 0.12598263339272567, 0.08958173343645674, 0.12701183530901158, 0.08719823669110026, 0.13501282169350556, 0.11784336157143116, 0.1557209233620337, 0.1520277386797326, 0.18939717273627008, 0.17149270991129534, 0.09309249397899423, 0.12555587557809694, 0.12184413974838597, 0.07575135092650141, 0.1704583375581673, 0.1926482240004199, 0.14273536444774695, 0.07530521415174007, 0.11370477971753903, 0.18170472979545593, 0.12009947693773679, 0.08900394729737725, 0.09464465640485287, 0.12663640188319342, 0.12433657529098646, 0.22090373853487627, 0.204755446474467, 0.06626245938241482, 0.12237018080694334, 0.11668856282319341, 0.11858721237097468, 0.07338527896042381, 0.0921445262751409, 0.09266401947076831, 0.15957433730363846, 0.07321650694523539, 0.12282109446823597, 0.16092219283538206, 0.09026425145566463, 0.1571374059255634, 0.09137421939522028, 0.08336654265544244, 0.14110827818512917, 0.15020226234836237, 0.12651319349450724, 0.14692231906311853, 0.12261640759451048, 0.10315751603671483, 0.10376608052424022, 0.1209826852594103, 0.09268668932574135, 0.12254502571054868, 0.1617971501712288, 0.07637767946081502], [0.03288404616926398, 0.015321179925064956, 0.01295578055682459, 0.01975709921680391, 0.01812607405840286, 0.07682027428277902, 0.007205830704021666, 0.006622880489365863, 0.04726685796465192, 0.026243422413244843, 0.04987908547211971, 0.017770136640008007, 0.05336802772113255, 0.02363777669545795, 0.023607586976140738, 0.031678523535707166, 0.023519652230398994, 0.041091449691780975, 0.036169930028596094, 0.08092334161379508, 0.039685294431235106, 0.03969656489789486, 0.04403723483639104, 0.06052235846540757, 0.005953391190684799, 0.041155167522707155, 0.04921355118442859, 0.05928825932954039, 0.017320844677409956, 0.021573459430198585, 0.04123461040269051, 0.04659072835264461, 0.01563625087562416, 0.037969584709831646, 0.0645170501832451, 0.007505146071447858, 0.026227380149066448, 0.04010679359946932, 0.006350411784036883, 0.022053565364331007, 0.017139099072664976, 0.007317029871046543, 0.11214420345744916, 0.037515139273766956, 0.046840717616890154, 0.039048950720046244, 0.009811044703902943, 0.07088267896324396, 0.02393465781850474, 0.046520893528525314, 0.050822798761406114, 0.04091718493561659, 0.014302133981670653, 0.03784066305628844, 0.017718227014743855, 0.025648930742006217, 0.1037799429946712, 0.014040480700454541, 0.021904046780296733, 0.0025854720235137002, 0.018262315408459733, 0.04206889634951949, 0.03211535081001265, 0.01770907866635493, 0.06333926266857556, 0.021870637412316034, 0.021591002953105738, 0.05289506845708404, 0.016638474239568626, 0.01625821982244296, 0.023348807290728604, 0.022623792623302767, 0.04962287064907806, 0.038521009763436656, 0.026482614489006143, 0.0647137506998011, 0.0033400691214150614, 0.02278928561801357, 0.050423094137970886, 0.024703636466126357, 0.03869999373065574, 0.01690349305447723, 0.030412003996648958, 0.040446956775018146, 0.01673182030208409, 0.05427604328308787, 0.03971545531281403, 0.04338103040520634, 0.040123312534498315, 0.056831602938473225, 0.013806318265518971, 0.007378044588092182, 0.07518363424709865, 0.022046634129115512, 0.033312178017305474, 0.025492781174502203, 0.013053420049670552, 0.033603958253349574, 0.01158380480150559, 0.020054680927257453, 0.04743606424225228, 0.07397041363375527, 0.09663072840443679, 0.054735699868095775, 0.03900572803935834, 0.024026226119271347, 0.038355728810919185, 0.0221277445089072, 0.0844451215650354, 0.027622767058866363, 0.024213771502088224, 0.039945872234446664, 0.021862204918371778, 0.009841599983961453, 0.02593545911700598, 0.059768709620194774, 0.04030480708128639, 0.040629017898546796, 0.040314150508493185, 0.07087229737745863, 0.04900107812136412, 0.0009863278329638498, 0.03049648499914578, 0.018941625653366958, 0.048175036375011714, 0.004437420126383326, 0.023362802075488225, 0.047143825995070596, 0.02732832696554916, 0.03591284668073058, 0.01910006018754627, 0.022469414032197425, 0.028510375680135827, 0.043998164790017266, 0.011908917222172022, 0.05780017775084291, 0.02296893115687583, 0.017820336357025162, 0.01575783247660313, 0.022687807313299606, 0.028366814633565288, 0.01717677981858807, 0.09756765634353672, 0.09012327223484005, 0.03876279214663165, 0.0532685510947236, 0.030073811965329305, 0.018023213238588402, 0.029968425298907926, 0.01767820871568152, 0.039376449039472, 0.0948443492608411, 0.014800799544900656, 0.08416866604238749, 0.03847398728664432, 0.06367734952696733, 0.06347868125885725, 0.043212706223130226, 0.015616602197821652, 0.022328931838274002, 0.01995027474393802, 0.021641794691926668, 0.03273516880082233, 0.0596184412549649, 0.01370383148813354, 0.04578610795683094, 0.018257908323513608, 0.01120381586120597, 0.07694223416703087, 0.03094849788716861, 0.09951023424842528, 0.05470427351870707, 0.028127081426126615, 0.061394642373280864, 0.05790296902081796, 0.07036442070135049, 0.023693112922566276, 0.020651121690337147, 0.03627941504653011, 0.03375521727970668, 0.06711662640529019, 0.05255826742255262, 0.009701485047116876, 0.0020649642059912105, 0.048210418583559136, 0.01393295664872442, 0.011121142306365073, 0.040205666329711676, 0.0467923007506345, 0.021388848711337363, 0.022738838235714605, 0.04242643002154572, 0.018466164291437184, 0.014076083432883024, 0.029700169871960367, 0.08348505558179957, 0.028723513707518578, 0.03178481265370335, 0.025330051513654844, 0.04296235054997461, 0.037380653633070846, 0.04190825657652957, 0.04978297437940325, 0.025599808199331164, 0.021018799460892166, 0.019229390658438206, 0.050354233011603355, 0.0074576791542183074, 0.020684561592393687, 0.007279499250996325, 0.06116264446505478, 0.0142170787689143, 0.05964267174048083, 0.007937154050783386, 0.07862039376050234, 0.05696838202753237, 0.02595930453389883, 0.03328262103189315, 0.05957834662071296, 0.004378339658225221, 0.01144626660139433, 0.048952545904155285, 0.01739283385021346, 0.12497620311166559, 0.0461057725894664, 0.03457548808572548, 0.03590352021689926, 0.042281946167349815, 0.027637501446796314, 0.005759990474741373, 0.025525959840576564, 0.00691438973548689, 0.04884788527020386, 0.03181666308747871, 0.07441594651235, 0.025629804536168064, 0.04636273380102856, 0.020867572664948444, 0.023168744452829872, 0.04374184479404773, 0.05569837481847831, 0.020684113759281378, 0.04913888858365161, 0.01861540467611381, 0.013833212849151875, 0.021170781127044132, 0.01882356225645968, 0.03348464804834553, 0.009249961552476245, 0.0633750893175602, 0.054579636813806634, 0.04337152412959507, 0.024902893363365104, 0.0673619168145316, 0.006615719824497188, 0.027263487855504667, 0.025085175010774816, 0.001739328571212744, 0.05706845237208264, 0.03511714902041214, 0.06114287195461137, 0.016981812959004725, 0.0365476535101022, 0.024289056658744812, 0.057220837766570706, 0.016639939875208905, 0.01325921293547643, 0.007110355313800807, 0.05678099440410733, 0.026407941710203886, 0.01770407786326749, 0.023577351455709765, 0.031919739342161586, 0.010402436318275119, 0.014816234520237361, 0.018988889010090913, 0.03959083557128906, 0.06606866978108883, 0.05370246066844889, 0.013871008097859365, 0.04524111880787781, 0.08533453848212957, 0.04989150266296097, 0.013645111067619706, 0.030574228148907423, 0.030704249029180834, 0.036669219844043255, 0.022950675172199096, 0.0385064789360123, 0.020355039542274814, 0.011620594122047936, 0.022082493008513535, 0.050874638836830854, 0.024506444011681845, 0.03195807317804013, 0.03156521836561816, 0.005843365889242185, 0.028199046850204468, 0.06256391427346639, 0.007385286253078708, 0.03473190397822431, 0.03034760763070413, 0.05301752367189952, 0.09081466549209186, 0.04295611820582833, 0.028879983882818903, 0.04727837609659348, 0.05548374401405454, 0.03531030758417078, 0.05169475357979536, 0.05443313092525516, 0.016874772363475392, 0.011251071584410965, 0.016086813395044634, 0.031337759856666834, 0.021221925704074756, 0.05573983670079282, 0.013939399338726486, 0.016822333480896692, 0.04824892205319234, 0.07360504966761384, 0.029259851534983942, 0.040400283743760416, 0.04734462486313922, 0.012609651362124299, 0.051089306960680654, 0.04597758375374334, 0.05091666051053575, 0.04005710787272879, 0.0962109798565507, 0.05789568155471768, 0.033890727508280954, 0.08729572181722947, 0.04846212114872677, 0.001458050891025258, 0.028179600036570003, 0.06717694816844803, 0.03527183125593832, 0.07628970061029706, 0.019358308919306313, 0.018667855433055332, 0.03423751997096198, 0.05339334386267832, 0.030927124034081186, 0.08488157564508063, 0.023020939169717685, 0.06392260600945779, 0.036202520065541775, 0.005850719936591173, 0.0383183686727924, 0.009967510638359402, 0.007759873206461114, 0.09367107400404555, 0.08304717657821518, 0.21169098360197885, 0.12584282803748334, 0.1413785929658583, 0.08845193191830601, 0.0829196594921606, 0.11642938958747046, 0.0874694607087544, 0.1443384848535061, 0.09425880746649844, 0.1511389935123069, 0.15646275212722166, 0.10089415391641003, 0.09931792385343995, 0.09326025497700487, 0.0576733188437564, 0.08110704818474394, 0.09192136289285761, 0.19776231529457228, 0.19990001272942337, 0.128534590027162, 0.12099373180951391, 0.1588860313807215, 0.0917846652280007, 0.11769086761134011, 0.18480369422052587, 0.08695045605834041, 0.12836819966988905, 0.09086255649370806, 0.1447985451668501, 0.08000402165842907, 0.13740315128649983, 0.15641480684280396, 0.21647795316364082, 0.10213438022349562, 0.1263896051262106, 0.061353692784905434, 0.15224105651889527, 0.183997974597982, 0.0867658673918673, 0.077230340135949, 0.14958939594881876, 0.15180669911205769, 0.1282327097973653, 0.16050526020782335, 0.11407203679638249, 0.21812395698257855, 0.11775481275149755, 0.1562598972980465, 0.1357040046049016, 0.14390435814857483, 0.14363321555512293, 0.12862959850047315, 0.08929470633821827, 0.08145263285509177, 0.1912784653582743, 0.08212632991905723, 0.2458993537085397, 0.11399021904383387, 0.13295599206217698, 0.09397971244262797, 0.1380263857011284, 0.14444236856486115, 0.14888741075992584, 0.10894431373370544, 0.12688101375741617, 0.10433687096727745, 0.09279447461345366, 0.11386937195701258, 0.111813451562609, 0.25042165390082766, 0.1542428433895111, 0.14129935364638055, 0.13107115748737538, 0.1513526506189789, 0.07661486816193376, 0.046862498590988774, 0.19694925392312662, 0.08654157764145307, 0.13200490309723786, 0.0933597960642406, 0.12384475953876972, 0.09745722476925169, 0.16632481079016412, 0.10298575168209416, 0.08657185387398515, 0.12347927343632494, 0.12787494542343275, 0.17099234461784363, 0.07491504973066704, 0.12153600342571735, 0.17736956956131117, 0.11179363155471427, 0.12459713273814746, 0.14220347441732883, 0.13627345833395207, 0.10557491917695318, 0.12020652262227875, 0.06873305288276502, 0.11765333105410848, 0.17806375159748963, 0.17118994758597442, 0.2255218478717974, 0.08068403588341815, 0.1798794163124902, 0.1271009405276605, 0.056613077343042405, 0.15112310222217015, 0.12151232255356652, 0.07679166724639279, 0.08121458919984953, 0.0820776993142707, 0.1283936175916876, 0.15687416147972855, 0.141157865524292, 0.14675428665110044, 0.10620799913470234, 0.14994334695594652, 0.12005861555891377, 0.12421977227287632, 0.2087672304894243, 0.12319936417043209, 0.11647307367197104, 0.09375231500182833, 0.10875033414257423, 0.1232586952724627, 0.16889596996562822, 0.07854931721729891, 0.14583977072366647, 0.11091028752603702, 0.07081008250159876, 0.08280477672815323, 0.17630235611328057, 0.07846663093992642, 0.18485690493668827, 0.05686703264447195, 0.11779255286923476, 0.08156277265931879, 0.15354342306298868, 0.11239750057991062, 0.14799342730215617, 0.16191700659692287, 0.11094974433737141, 0.12818932426827295, 0.1855614414172513, 0.175436029742871, 0.13046587710934027, 0.08455883046346051, 0.11195308049874646, 0.1244672339941774, 0.26100351608225275, 0.11884964257478714, 0.17004314198025636, 0.11909377947449684, 0.11837191320955753, 0.19462713067020687, 0.1309077391134841, 0.06780130216585738, 0.11391674727201462, 0.20039751460509642, 0.08098185847380332, 0.1160666990493025, 0.16087233408221177, 0.10255782000188317, 0.12158882059156895, 0.12045418790408544, 0.06991330347955227, 0.17453021263437613, 0.10395117809197732, 0.2367494718304702, 0.10849743735577379, 0.12387538860951151, 0.12465468607842922, 0.15679705276020936, 0.16262186877429485], [0.05027486137779696, 0.026674237867285098, 0.023986165411770344, 0.024874915668208684, 0.009151815702872617, 0.01879538778614785, 0.03159462946600147, 0.029946583256657635, 0.015826579948355044, 0.017883319673793655, 0.032036023280982456, 0.023235873618562306, 0.021588701023054973, 0.03137170696364982, 0.04571682274607675, 0.00488586731288316, 0.019747974617140632, 0.039019868709146976, 0.035200021894914765, 0.013486533192917705, 0.07056766229548625, 0.030696873353528123, 0.052096677012741566, 0.006629213341511786, 0.026330327482095787, 0.008381105094615902, 0.031227182397352796, 0.02062989881129137, 0.027795192985130206, 0.0986293125897646, 0.08038285454469067, 0.05201275580163513, 0.043654293420591524, 0.009197582889880453, 0.014377288520336151, 0.029228126630187035, 0.06180483036275421, 0.03331910585984588, 0.08352513664535113, 0.015534546958016498, 0.03446610824071935, 0.028724935238382647, 0.03226370570648994, 0.01911030606632786, 0.0298070357447224, 0.030608575591551404, 0.04427185867513929, 0.03376734270048993, 0.05038744051541601, 0.017237237288749645, 0.01524029515816697, 0.1100587464336838, 0.06655718785311494, 0.038962230551987886, 0.07735387422144413, 0.046657818502613475, 0.013623006093049688, 0.036092875591878376, 0.02987433284787195, 0.049381006841680834, 0.029030262426074063, 0.07012943723904234, 0.05547232426969068, 0.029688611027917693, 0.08031521138868161, 0.09989318584225007, 0.04065702782411661, 0.06545356421598367, 0.05720550287514925, 0.06908790634146758, 0.07973740489355155, 0.03552578995004296, 0.0696254214271903, 0.0498321478122047, 0.019408932720710124, 0.034055099223873446, 0.053137939888983965, 0.022555723686569502, 0.006328459903930447, 0.045174863255981884, 0.024475253453212123, 0.027262724503608685, 0.07033174245485238, 0.04823485941493085, 0.015686910300116454, 0.008136081010369318, 0.023693847436723963, 0.02712195223596479, 0.012837551767006516, 0.037889795776988776, 0.024554648835744177, 0.021126002904825976, 0.05771692150405475, 0.035869562931890996, 0.05931755168629544, 0.017510054167360067, 0.028625838591584137, 0.009688006797140198, 0.03385457855516246, 0.07814631491367306, 0.030392923591924564, 0.03177098750269838, 0.015603647267978107, 0.040691857026623826, 0.05153597638543163, 0.06518908483641488, 0.054443349662636004, 0.025246849549668174, 0.053614105230995586, 0.01427727415492492, 0.019454040032412325, 0.03878662229648658, 0.09765705333224364, 0.038224269436406236, 0.007282485653247152, 0.03417402605659195, 0.028148032891164933, 0.03058189559461815, 0.021988892495366077, 0.032464765810540745, 0.010496956246372844, 0.03333363329459514, 0.011870641061770064, 0.04858502419665456, 0.014910679809483034, 0.04875860023977501, 0.00930194666476122, 0.02021924263265516, 0.02784382867892938, 0.01996110755551074, 0.052977198335741243, 0.05835610827697175, 0.0414356806847666, 0.029670629849923507, 0.03223763299839837, 0.04667057835363916, 0.03147680186001318, 0.04696272499859333, 0.07620225780244384, 0.04686624410429171, 0.014134259329044392, 0.05822257258530174, 0.00208617330229442, 0.055979997385293245, 0.06074732675084046, 0.01392528326583228, 0.0030133286407882614, 0.034236763404416184, 0.0187144606108112, 0.09689568954386882, 0.05457944003865123, 0.01569018592791898, 0.02360673202201724, 0.02776662157183247, 0.021678796902831112, 0.021709829701908996, 0.03570062467562301, 0.039956800040921996, 0.022249127638393214, 0.02679769222491554, 0.03394396536584411, 0.03693501218887312, 0.021228848457602516, 0.03471648087725043, 0.007724925260325628, 0.03244025034031697, 0.04947718918057425, 0.04238231845998338, 0.038715830737990994, 0.03953977581113577, 0.08956202877951519, 0.009657815381485437, 0.0413037938331919, 0.009686726062292499, 0.00946555842113282, 0.03835807314940861, 0.031483007062758715, 0.025365360779687762, 0.009573117247782648, 0.018084535840898752, 0.013299718931583422, 0.019504300817581158, 0.07520015657480274, 0.015644754615745375, 0.02116117307118007, 0.03433865900816662, 0.030472359686557735, 0.026277486567518542, 0.010575836790459496, 0.028431764005550315, 0.009594575917747403, 0.04062663284795625, 0.024424948563267077, 0.022230043840993727, 0.037610100249626806, 0.025479792317907726, 0.012207959479253207, 0.027214294066652656, 0.010430930548214486, 0.04130363777013762, 0.01925071871041187, 0.049485318030097654, 0.0375648691052837, 0.02832997527106532, 0.02662243171861129, 0.01633091127899076, 0.08612600886928183, 0.06745736633560487, 0.03059851630989994, 0.028008872144190327, 0.052086193646703444, 0.01596531830728054, 0.016612771333062222, 0.03436053836984294, 0.06324925499835185, 0.04285599357847657, 0.10336117832256214, 0.044018327458096404, 0.045735553705266545, 0.011712803638407161, 0.03171667416713067, 0.07775558730853455, 0.03177774231880903, 0.019801675574854016, 0.04213398482118334, 0.0129078318797318, 0.021200517924236398, 0.040709519293159246, 0.035672217807067294, 0.04165785340592265, 0.05587927225444998, 0.042638190622840605, 0.023527141560667326, 0.02364767312870494, 0.034821653805140934, 0.05664870382419654, 0.035126258353037496, 0.040209310062761815, 0.04792874173394271, 0.007707543737654175, 0.04004834120028785, 0.04829614130514009, 0.03256990820435541, 0.04273092939651438, 0.04526332386636308, 0.018379355913826396, 0.05369290689538632, 0.04098641586356929, 0.03749747361455645, 0.03494976460933685, 0.01257188240664878, 0.043077263848057816, 0.015540107552494322, 0.055737037743840895, 0.025634591600724628, 0.005062231286761484, 0.02714427943075342, 0.03961198890049543, 0.0046791066665069336, 0.07904658160571541, 0.0174129456281662, 0.04369293938257864, 0.023882529365697076, 0.04028950272394078, 0.05722032207995653, 0.03514903677361352, 0.02169295962500785, 0.029452955815941095, 0.04935368223647986, 0.02514516089909843, 0.08194206694939307, 0.019892185360991528, 0.007010876991054309, 0.01379423525317439, 0.024536048494545475, 0.03658725620646562, 0.02097780746407807, 0.023249803942495158, 0.07101758529565164, 0.0522281431726047, 0.056739749652998786, 0.02792401794743325, 0.0575216051989368, 0.07480932040406124, 0.018087395866002356, 0.02614447843682553, 0.024634486962375895, 0.040677787603012154, 0.014610390744305082, 0.02865513094833919, 0.034896601390625746, 0.024423471053263972, 0.000838821158270418, 0.02304315610256578, 0.04386475123465061, 0.04685459026534643, 0.029611848361257995, 0.02249875558274133, 0.023974694777280092, 0.015021065582654305, 0.013070143393373914, 0.020939076685213616, 0.014385285055530923, 0.010889477728466903, 0.015431379101106098, 0.025585920283836976, 0.05074498775814261, 0.0604737007192203, 0.029323392946805273, 0.03340564960879939, 0.05218429284702454, 0.048739621615303416, 0.0785856256261468, 0.016430447277213846, 0.021461901487782598, 0.04307112989148923, 0.02322757343894669, 0.04174389164628727, 0.05988067468362195, 0.027545485312917402, 0.10055257260267224, 0.019854319714275852, 0.05206501317609634, 0.03477444812389357, 0.039080760441720486, 0.05711618052529437, 0.060970395138221126, 0.012880890646816363, 0.044476569297590425, 0.03128948209009, 0.045145832135209014, 0.03720887231507471, 0.029234718597893204, 0.04902677084984524, 0.03438725907887731, 0.042186364331947904, 0.02257847157306969, 0.010468217743826764, 0.05959353223443031, 0.023383979153420244, 0.02205785540198641, 0.029563207578446184, 0.0314506850471454, 0.08779177162796259, 0.04604699110080089, 0.025775492790022066, 0.02777260116168431, 0.07182319635259253, 0.03730705972494824, 0.05725234893283673, 0.05789480624454362, 0.0274735215851771, 0.1469086805092437, 0.08239294668393475, 0.08373337225722415, 0.1311037271682705, 0.08106839204473154, 0.17945444983031067, 0.12344922790569918, 0.1371500984366451, 0.11775630552853857, 0.16773828065821103, 0.15256006297256264, 0.08801435147012983, 0.08213481160679034, 0.09952364210039377, 0.09952391351440124, 0.10661096072622708, 0.12945058516093663, 0.09897477512380906, 0.18017669607486042, 0.13628255070320197, 0.11623452790081501, 0.11959411762654781, 0.0985544566065073, 0.10261566511222295, 0.03827620789940868, 0.1845874993928841, 0.144762447103858, 0.0955894621355193, 0.13247656635940075, 0.22704418189823627, 0.24408774663295063, 0.12164171918162278, 0.10401546249964408, 0.08347307265337024, 0.1301868227975709, 0.0643442544553961, 0.11572203040122986, 0.15288965457252093, 0.19633382266121252, 0.11836934834718704, 0.1504544195319925, 0.06701830668108803, 0.1447193601301738, 0.14028069616428443, 0.12308610310511929, 0.16172114067843982, 0.0946375046457563, 0.07194117323628493, 0.11814894660242967, 0.10823807413024561, 0.12620283157697745, 0.1683872586914471, 0.18627606092819146, 0.11351248289325408, 0.1625275116946016, 0.12086532584258489, 0.08204583530979496, 0.1414435151964426, 0.0774008763421859, 0.12880616688302585, 0.06712751010698931, 0.14382273038583143, 0.15169041178056172, 0.10874981845596007, 0.19300034296299728, 0.15034058849726403, 0.08530684068266835, 0.16889058239758015, 0.18085007422736712, 0.13774578432951654, 0.17474642103271826, 0.10085262757326875, 0.17308477019625051, 0.08883404212870769, 0.09444827479975564, 0.191950242168137, 0.12639059578733786, 0.13428920480821813, 0.10604185983538628, 0.11127736818577562, 0.23024717931236538, 0.14996417798101902, 0.16944608544664724, 0.10636187730623142, 0.10603382598076548, 0.12039660742240292, 0.09055476622389895, 0.21138683706521988, 0.16268079275531427, 0.08418563620320388, 0.14167189651301929, 0.17366765891867025, 0.17978585990411894, 0.26022420504263466, 0.21964174482439244, 0.09346321837178298, 0.10167485595281635, 0.09306202775665692, 0.13668005008782658, 0.16368746730898107, 0.10959133758608784, 0.14610249948288712, 0.2022359645260232, 0.14342280184584005, 0.12446838750370912, 0.14187096511679037, 0.10222554140325103, 0.123977358852114, 0.10669717538569655, 0.12331399587648255, 0.07208751288375684, 0.12861097949956143, 0.14104338309594563, 0.18811079247721604, 0.07369211249585662, 0.1331385179821934, 0.10261557011732034, 0.1842028514615127, 0.11538994179240294, 0.10807409935763904, 0.142658228586827, 0.08173338350440774, 0.11992507986724377, 0.2275581450334617, 0.06544211733021907, 0.16092979242759092, 0.09429145857159581, 0.13506809515612467, 0.13888845087162086, 0.0963849765913827, 0.2208364007196256, 0.11593156201498848, 0.11374555288680963, 0.09793021117470094, 0.14561981681202138, 0.09291188152773039, 0.15739989041217736, 0.10579704440065793, 0.1969950007540839, 0.1211544903261321, 0.09360286766397101, 0.1298066396266222, 0.20164097073887075, 0.13023288175463676, 0.18444411137274333, 0.14930439767028603, 0.1173657136304038, 0.17980301326939038, 0.13570000124829157, 0.12037515214511327, 0.1408486571162939, 0.09866513923874923, 0.15792802135859216, 0.10800711438059807, 0.1234542897769383, 0.1247391365468502, 0.12263189176363604, 0.14407829381525517, 0.0978640607957329, 0.0920755939025964, 0.11334189918956586, 0.0958027256918805, 0.21831605024635792, 0.10968013746397835, 0.07064949361873524, 0.09236699076635496, 0.11932833545974322, 0.14027434507650988, 0.10162769776902028, 0.06618525566799299, 0.18335698970726558, 0.19906685315072536, 0.12636288441717625, 0.14202149132532732, 0.13193428117249692, 0.1084840770012566], [0.050025777957801304, 0.045208691619336605, 0.033919280261865685, 0.028620685118117502, 0.04779114840286119, 0.059258145945412774, 0.014647996851376124, 0.018139985722622702, 0.03444734674745372, 0.019651997535090362, 0.03264539183250495, 0.01988038733335478, 0.04335452004202774, 0.03415385999583772, 0.06739988084882498, 0.052836653377328596, 0.01517411254878555, 0.03792998879881842, 0.026898112015000412, 0.053279166775090356, 0.02363604473482285, 0.026470992880474244, 0.05562620583389487, 0.035114750399121215, 0.023454794460641484, 0.06530433400933232, 0.036624826690448184, 0.04603816336020827, 0.02382078267900007, 0.03702296729066542, 0.018694744079506824, 0.023535426473245025, 0.01322078749737037, 0.03433232827644263, 0.023569996136107614, 0.017298349545204213, 0.038917443848081996, 0.06282353534230165, 0.01500231766008905, 0.0851188050583005, 0.05127914070284792, 0.05887835632477488, 0.06640759123755352, 0.045893048468445025, 0.04196297024775829, 0.08386707079729863, 0.01753178934034492, 0.08309586146580321, 0.03276072242962463, 0.019728839929614748, 0.006245919511586959, 0.03918585194540875, 0.02328511660120317, 0.0680803225508758, 0.015449339923049723, 0.019243085191452076, 0.0209672749042511, 0.039259995466896465, 0.03247326106897422, 0.0064944897894747555, 0.03610832244157791, 0.029631939783160175, 0.03609322164473789, 0.0318741485742586, 0.031069107486733367, 0.0391561049701912, 0.024859557028061578, 0.06878518472824778, 0.07485475510890995, 0.029656088844473873, 0.0702284083568624, 0.029054693079420497, 0.05496126526434507, 0.06524837522634439, 0.01685660458835108, 0.05195869691669941, 0.03126728381695492, 0.017018767672457864, 0.036671818633164675, 0.0552177854281451, 0.03102733687098537, 0.032761075267834325, 0.041011921994920285, 0.05395788160551872, 0.03132626886612602, 0.01539971017544823, 0.016136548315574015, 0.014454061365021127, 0.040185235640300174, 0.010881480345103358, 0.038434540653335195, 0.035733750755233426, 0.045620928784566264, 0.05600023469222443, 0.01912244505781148, 0.020483146953795637, 0.021068011909457188, 0.0021002957364544272, 0.03287649068183132, 0.022928985800327997, 0.021180969330349138, 0.04919486093733992, 0.02255087046484862, 0.04104926177699651, 0.045328028965741396, 0.018634904076212218, 0.011319145610156869, 0.08955286855676345, 0.03452456063990082, 0.046561714195247204, 0.04488967838031905, 0.044220052526465485, 0.029011056492371217, 0.05283021068732653, 0.044338640091674666, 0.015764729785067693, 0.010342025497396077, 0.010820441879332066, 0.04648366570472717, 0.04907956765964627, 0.01014058880640992, 0.018872733992923583, 0.011673804838210344, 0.010847241468062358, 0.035518926568329334, 0.029437688778021505, 0.04318009243745889, 0.04995929170399904, 0.05289433224658881, 0.06037140477980886, 0.07001570798456669, 0.010624509803684694, 0.016871780024043152, 0.022509245734129633, 0.007300205595259155, 0.06930359905319554, 0.06689148170075246, 0.035860999819955656, 0.012612788738416774, 0.006117533052539719, 0.02091591149967696, 0.013785749324597418, 0.003172748110955581, 0.028469839998121773, 0.03778969489836267, 0.041830510034092834, 0.05486297607421875, 0.038063063086675744, 0.03211175457441381, 0.07101485758487668, 0.022760687063315084, 0.04291723136390958, 0.0103379729469972, 0.013036774737494332, 0.022671464797375456, 0.026494443050718734, 0.055245554473783286, 0.08342016049261604, 0.03438060265034437, 0.06578736273305756, 0.05536021671390959, 0.014384479295196278, 0.03496466863102146, 0.02526057292042034, 0.03904106953580465, 0.035458927109305344, 0.0682665736281446, 0.022072708533544625, 0.058102051195289404, 0.017726913959320103, 0.01803977118938097, 0.022171157179400325, 0.008961122765737985, 0.022576687025970647, 0.038703142133142264, 0.006151051834292177, 0.08094407764396497, 0.046754723481301746, 0.03238013892301491, 0.043148947680102925, 0.041580371492143185, 0.0793547382844346, 0.0037667128573437886, 0.031340833620301316, 0.02432737353124789, 0.01995047491176852, 0.036477051941411834, 0.011218494269996881, 0.02717535972728261, 0.0367005240571286, 0.03131762093731335, 0.031031903411660875, 0.02658490194672985, 0.020201101998931596, 0.044411487611276765, 0.031965604916747124, 0.01260259120525526, 0.01747775250779731, 0.07835047931543418, 0.02505228472208338, 0.027838300314864943, 0.08704728979085173, 0.016170644700261097, 0.06359540963811533, 0.08765415794083051, 0.04217943309673241, 0.045579307446522374, 0.013262026311297501, 0.015905532586787428, 0.013094179648240762, 0.040091994750712595, 0.04244315251708031, 0.06180069129914045, 0.059696764552167485, 0.014151919051073492, 0.013739796388628227, 0.013091601215169897, 0.005468363333160856, 0.06386256244565759, 0.007426183254990194, 0.014735185208597353, 0.051691282873174975, 0.09540422207542829, 0.03606385804180588, 0.04152264173275658, 0.021515845021765147, 0.030724262419555868, 0.030024648710553135, 0.012091989362878459, 0.0882631227640169, 0.053456885274499655, 0.057272297862385, 0.016911308081554513, 0.0633398937061429, 0.04900014174303838, 0.05352977689887796, 0.02588724241858082, 0.0483667700152312, 0.015764427836984396, 0.04613470192998648, 0.05596354291109102, 0.056116973249507804, 0.01706946611271373, 0.02015155367553234, 0.03812312022117632, 0.02869168362979378, 0.07457124282206808, 0.11686139926314354, 0.02516614120187504, 0.06333168343241725, 0.022280460689216852, 0.012509462273945766, 0.059552752279809544, 0.011893770624218243, 0.10876129248312541, 0.021408064823065485, 0.03763665471758161, 0.03061388512807233, 0.02521352330222726, 0.06191782679940973, 0.027317936898076108, 0.03012940094673208, 0.021421321700992327, 0.03266080814812865, 0.045006667995559316, 0.04207744249807937, 0.021613506566999213, 0.021282596912767206, 0.046224570500531366, 0.037509453150310686, 0.03214182046109012, 0.03437081139002528, 0.05895342265388795, 0.008837384271568485, 0.04795884833272014, 0.04121900748993669, 0.08355294301041535, 0.04480579109596355, 0.006711889016774616, 0.05628735678536551, 0.023079825831311088, 0.020855377694325786, 0.04735021599169288, 0.0029431244391681893, 0.0020650736197629677, 0.011486831121146679, 0.040422000257032256, 0.005375402763352862, 0.06097618982728038, 0.013632156137776161, 0.02155141213110515, 0.04331692920199462, 0.007040126939370696, 0.038903669587203434, 0.1292411892541817, 0.006448678073606321, 0.03445769440648811, 0.053341534321329424, 0.009072316843750221, 0.013519353931769729, 0.022344507609627078, 0.035755487624555826, 0.051752887067518065, 0.04600161746410387, 0.07187476501400981, 0.0431489612508033, 0.026854363469673053, 0.041410320438444614, 0.004036900836841336, 0.05271514471886413, 0.039048394321330955, 0.03625374606677464, 0.04651198436373046, 0.03708092775195837, 0.0419468482557152, 0.028710010860647475, 0.04555157572031021, 0.014094272412226667, 0.035790147193308385, 0.053579309955239296, 0.0395031111714031, 0.023333984693246226, 0.014417405206976193, 0.025360824773088098, 0.05851962164576564, 0.037121605926326344, 0.029713984844940047, 0.03402644129736083, 0.037880238611251116, 0.06446755783898489, 0.11974373459815979, 0.03713590944451945, 0.054920600660677464, 0.021730935533664057, 0.03960637402321611, 0.024678800388106277, 0.017280612639816742, 0.011485994826736194, 0.0519451940698283, 0.058404440326350074, 0.014252972423232027, 0.02187345502898097, 0.02722965270679976, 0.048750451034201045, 0.012913521395863166, 0.060981373834822855, 0.09416874551347323, 0.03672691906935402, 0.019469619196440493, 0.04014075766982777, 0.0449659117896642, 0.028603429972593273, 0.15757390750305994, 0.10177540127187967, 0.0989927766578538, 0.09611325045781476, 0.15090538747608662, 0.20145026168652944, 0.08607346990278789, 0.09166527020611934, 0.1271805733974491, 0.05999443107949836, 0.11745654232800007, 0.08293856347778014, 0.1523199701415641, 0.05850136226841381, 0.14183270931243896, 0.09265073375510317, 0.11528954575104372, 0.1353885672454323, 0.14479887086365903, 0.11082652237798486, 0.10070156532206706, 0.10697363769369465, 0.1400099606918437, 0.08681189242218222, 0.07356129094426121, 0.1407004107854196, 0.11929694642978055, 0.10079156620694057, 0.13463327634547437, 0.0758480964494603, 0.07181867052401815, 0.1086221317361508, 0.19497619622520038, 0.1282342839986086, 0.11463264242878982, 0.13638315030506679, 0.12542985805443355, 0.14699763645018848, 0.13160325107829912, 0.18801331413643702, 0.14807269376303467, 0.12217077293566295, 0.1423047525542123, 0.15984799047665937, 0.1445027038987194, 0.09539077351135866, 0.1318490436034543, 0.19950001633593015, 0.14226466470531055, 0.12604534359914915, 0.10472312024129288, 0.10436640081128903, 0.1599546426108905, 0.1377086684639965, 0.15844783346567834, 0.1862584190177066, 0.09539694139467818, 0.08876859064080886, 0.10481225260134254, 0.08860571509493248, 0.11418674992663519, 0.12113524707300322, 0.09740040424679007, 0.11503238097897597, 0.10626257370625224, 0.14793049996452673, 0.09403102326073817, 0.1364422778465918, 0.12092298774846963, 0.10445965187890188, 0.2422597190099103, 0.1968100999615022, 0.1293805739177125, 0.15007198362478189, 0.08136839273252658, 0.10377503718648638, 0.12431598853852067, 0.06617445339049612, 0.1952884987528835, 0.1270924588399274, 0.17518921941518784, 0.13125259775136197, 0.1448747853615454, 0.1512653095913785, 0.0993302935468299, 0.11705855439816203, 0.07900509597467524, 0.10072937847248145, 0.280326673494918, 0.09564738867006131, 0.09848931724471705, 0.12377050066632883, 0.22132797219923564, 0.12696858548692294, 0.13996810865189346, 0.0971242201381496, 0.0953045045690877, 0.09254258884383099, 0.12448913710457937, 0.20034821225064142, 0.17680428203727516, 0.1308641228824854, 0.1047899830820305, 0.12809865841908114, 0.09301816725305148, 0.11138796939381532, 0.07917464151978493, 0.14133013199482644, 0.052205663307436874, 0.249212205942188, 0.16594325697847775, 0.19843114726245403, 0.1446908073765891, 0.12681693291025503, 0.11556955001183919, 0.17002777994743415, 0.09038938688380377, 0.06848207635006734, 0.15829848790807383, 0.1471138016453811, 0.10514138958283833, 0.07072770835033484, 0.09514538810721465, 0.08393729917172875, 0.09805362312389271, 0.14907776697405747, 0.15382145957223006, 0.1256955045142344, 0.13063351597104753, 0.13407433990921291, 0.12278667917209012, 0.06852369090276104, 0.06150463289980378, 0.18506792932748795, 0.2900289371609688, 0.21149947387831552, 0.1721260952098029, 0.09495178849569388, 0.07851061357983521, 0.12058343525443758, 0.12088693039757864, 0.06872576541666474, 0.1405295149556228, 0.11393007369978086, 0.08043666915701968, 0.08189984850053277, 0.11630827108664171, 0.10946920128273112, 0.15500827160264763, 0.1694177362535681, 0.09315470206950392, 0.12494621186384133, 0.11460786232990877, 0.1868949934308018, 0.20493014210036822, 0.11627427648220744, 0.13238349849624292, 0.1632791520761592, 0.06035163905471563, 0.10846847748117787, 0.15271467396191188, 0.0641993193754128, 0.10930341482162476, 0.11465869817350592, 0.18293931069118635, 0.07942072581499815, 0.12973257074398653, 0.13900328613817692, 0.09251098946801253, 0.1600109338760376, 0.15916767769626208, 0.20272555468337877, 0.11530292646161147, 0.13928311397986753, 0.19254533095019205, 0.1982619749116046], [0.016246733920914785, 0.07903841882944107, 0.030089550585086857, 0.02035440511203238, 0.01941757895318525, 0.011572273947032434, 0.024341241090691516, 0.016718790733388493, 0.003361516977227958, 0.02623396024240979, 0.015853889286518097, 0.03411638450675777, 0.041827833213444264, 0.04619407035144312, 0.037413535440074544, 0.04657502705231309, 0.02213916934228369, 0.048786912113428116, 0.09334257484546729, 0.021209552618009702, 0.026665294775739312, 0.0094509342951434, 0.05520431311534984, 0.03611548777137484, 0.044358857042555294, 0.03313569105895502, 0.03841075800093157, 0.014066228559905929, 0.033087915408291986, 0.08700386354965822, 0.013256714230270257, 0.06276027552251305, 0.025835476982008134, 0.08181450915123735, 0.012216548884420522, 0.028957319911569357, 0.03315031348860689, 0.013457441852161927, 0.050123266476605616, 0.02433838276192546, 0.03323649761400052, 0.050064915857676945, 0.012725867447443306, 0.037123794201761484, 0.0609839115557926, 0.011323193919711878, 0.03965393254267318, 0.015415647266698735, 0.037633316325289864, 0.04291668175054448, 0.03266791919512408, 0.020008336985483766, 0.03518746221171958, 0.041267617738672664, 0.06059490064425128, 0.051454311303262196, 0.020157618082261512, 0.01899643431949828, 0.04872362515223878, 0.04244602272020919, 0.011991316818499138, 0.024107439975653375, 0.05298332889963474, 0.021057245255048786, 0.023133764276281, 0.00836613237126065, 0.03598785872704216, 0.0672232039006693, 0.03916511591523886, 0.04780292098543473, 0.020270717995507375, 0.03553002740123442, 0.03755383612588048, 0.042279866457517655, 0.037416643130459955, 0.010395539009810557, 0.013065877104444163, 0.08599950280040503, 0.03489711029188974, 0.04934723276112761, 0.006032851034043623, 0.024413247226870487, 0.014624741759949496, 0.028378225896241407, 0.060418108345142434, 0.016408128564112952, 0.02475072001107037, 0.03290809005764978, 0.01107488148513117, 0.0340444258680301, 0.03378272848203778, 0.021864237130752633, 0.011892522967952703, 0.05447294736014945, 0.04431187188518899, 0.02245141758716532, 0.023113538843712637, 0.028051490928711634, 0.027964794509378926, 0.04585836175829172, 0.038237911382956166, 0.012068065066289688, 0.01509303439940725, 0.034449528237538676, 0.023253160994499922, 0.05387974151277116, 0.05745399596967867, 0.027313414462176815, 0.11236615904739924, 0.01562504147711609, 0.0649417723928179, 0.022386905870267322, 0.014098370763739305, 0.0631227625001754, 0.014558101139430488, 0.04360519801931722, 0.02418985144634332, 0.0572545745276979, 0.04462928378156253, 0.04425334823983056, 0.021238286879711916, 0.05781724290656192, 0.07220333881144013, 0.06776858320725815, 0.03520354688433664, 0.011135816474312117, 0.006664345764355468, 0.04038283182308078, 0.03775672488180654, 0.02509643360307174, 0.05187922689531531, 0.0503993420196431, 0.03965392575732299, 0.02962624348167862, 0.018880235197554742, 0.10041545424610376, 0.06685262878558465, 0.061341703071125915, 0.0413104740104505, 0.014765483493517553, 0.05650689679064921, 0.04290610338960375, 0.009791727660090795, 0.014034373885286706, 0.03657812312511461, 0.01980462550584759, 0.013961901256282414, 0.049944852478802204, 0.02363073010928929, 0.04037093371152878, 0.03617160601009216, 0.005486513296740928, 0.03937533963471651, 0.046342598274350166, 0.03818952165810125, 0.079451829860253, 0.04187443499852504, 0.00698356595655371, 0.04760079897407975, 0.0027249879411621286, 0.02444242762534746, 0.007278662108417068, 0.00843650832705732, 0.01885941604684506, 0.03367221548355051, 0.05609176567356501, 0.022967122861051133, 0.025890733481251767, 0.040079200972935984, 0.05553715829072254, 0.03756635509697454, 0.03503895803753819, 0.04043130297213793, 0.0876829753230725, 0.014687255191217576, 0.07561905016856534, 0.021219744213989804, 0.07048220759523766, 0.05110669102785843, 0.0466698048237179, 0.014052860571869781, 0.015727359468915632, 0.02897284479279603, 0.011999852789033736, 0.017076729830088358, 0.029432491199778657, 0.022627541529280797, 0.007349909981712699, 0.0075431440324921694, 0.01858933366435979, 0.02765170148839908, 0.044754941681666036, 0.04457438351320369, 0.018574049663064734, 0.0893059428781271, 0.015571376142491187, 0.021694247145205736, 0.047956833083714755, 0.030208192433097532, 0.09082894186888422, 0.0748588466750724, 0.07669794120426689, 0.01778857413280223, 0.03362464678606816, 0.020875996677204967, 0.06599931671683278, 0.01585066454884197, 0.017185024019064646, 0.04617134960634368, 0.01969481648744217, 0.03619169064664415, 0.014045310173449772, 0.017369120747649243, 0.042769375190671, 0.029743955736713748, 0.005043406604922244, 0.06287895808262484, 0.024689465262261883, 0.02904500699202929, 0.04847397854817765, 0.0313748282247356, 0.027206648673330034, 0.04342822930110352, 0.017071294764588987, 0.04985585582575627, 0.044170977481241734, 0.017911733327699558, 0.05097810185647436, 0.02523894631303847, 0.05370188730635813, 0.0570746473968029, 0.00824866778150733, 0.047701327329767604, 0.026063734465943914, 0.05057912326550909, 0.08021228441170283, 0.02801655824961407, 0.0001040171985420914, 0.06353500645075526, 0.020287588072408522, 0.038920846701200516, 0.05463012321186917, 0.01896234811283648, 0.028607009244816642, 0.03846251325947898, 0.11369732940303427, 0.0356829590164125, 0.059402327851525376, 0.06916875378893954, 0.03610251757449337, 0.02665650605091027, 0.017571393733045886, 0.04610894134800349, 0.05009636256311621, 0.04562118323519826, 0.012771591377843703, 0.007890973805582948, 0.021855540008151104, 0.01799504385728921, 0.047728475515863726, 0.025132962535800676, 0.005172144629926021, 0.02193130862100848, 0.012286793374057327, 0.026336512328790765, 0.02011295860367162, 0.06435419499341931, 0.03592251580474632, 0.03036221648965563, 0.04263283358886838, 0.029314836620220115, 0.03849823134286063, 0.044582285053495846, 0.020788024612037197, 0.010650387432958399, 0.08292314716215644, 0.10131553094834089, 0.026301530455904346, 0.008206285636073776, 0.027495724947324822, 0.02321768718372498, 0.07520244323781558, 0.06319032423198223, 0.010386225268510836, 0.0665438546399985, 0.032085339206137826, 0.10422531981021166, 0.0025976816250476986, 0.03978034361664738, 0.018375852976792624, 0.05467348838491099, 0.06688483884291989, 0.06422364485583135, 0.054115389939397573, 0.017550108089510883, 0.03929499091048326, 0.024877280362748673, 0.03605061303824186, 0.04512512663911496, 0.05702025602970805, 0.024703497366447533, 0.061422631942800114, 0.03447411156126431, 0.06168737595102616, 0.024612166552937458, 0.02493155637889036, 0.03056554968601891, 0.0925573469804866, 0.013075221379819726, 0.04132862142952425, 0.00837736891116947, 0.049026906556848965, 0.04194540297612548, 0.09259466640651226, 0.029473539175731794, 0.02921214373782277, 0.06288347034049885, 0.053693989158741066, 0.030024228018841574, 0.06334034832460539, 0.07095622537391526, 0.031016446383936063, 0.04138013920081513, 0.023183397416557585, 0.03433462172480566, 0.022952437666910033, 0.029199807971183742, 0.027357649856380055, 0.040298171008804014, 0.037217781479869566, 0.042202588104243786, 0.05270343320444226, 0.043249034988028665, 0.026546819168808203, 0.05917404831520148, 0.007122854352928698, 0.00961517624091357, 0.015634086348914673, 0.03322753416640418, 0.043998344601797204, 0.028567443867879252, 0.031541730875947645, 0.030120807300720896, 0.032203869095870426, 0.079536063197468, 0.018709921211536442, 0.0753698106855154, 0.00807684744774763, 0.052925158092486005, 0.029211417705352818, 0.026204723864793777, 0.0722829716812287, 0.0904196427602853, 0.20410091802477837, 0.07355192037565367, 0.10425249513770853, 0.11234015758548464, 0.15774401623223508, 0.17143940420023032, 0.15408804241035665, 0.0883280857067023, 0.06660632735916547, 0.14529823192528316, 0.08979357206927878, 0.08709108922630548, 0.10027604244117226, 0.1304264949368579, 0.12342591344245843, 0.07299609841512782, 0.06766564944492919, 0.15696839642311844, 0.07958803897989647, 0.20008909329771996, 0.08959664763616663, 0.16026197826223715, 0.18823960556515626, 0.1430568000567811, 0.2267537960516555, 0.18758475141865866, 0.09752763634813683, 0.09597132807331425, 0.1902792818312134, 0.08649205137044191, 0.1404937697308404, 0.1486833617091179, 0.1605449952185154, 0.16155926936439105, 0.14372351499540464, 0.07545263266989163, 0.09947068922753845, 0.17680430917867593, 0.06469695017273937, 0.09572017512151174, 0.13452555212591374, 0.0915561957018716, 0.17657782776015146, 0.10041834480528321, 0.07277518776910645, 0.16580099532646791, 0.0901576332481844, 0.22177172053073133, 0.09888659271278552, 0.07335507058139358, 0.16731601474540575, 0.09399685902254921, 0.10747827775776386, 0.21499067225626536, 0.07877926594976868, 0.09372239839285612, 0.12412164253847939, 0.16457131345357212, 0.22201654953616007, 0.10558594537100621, 0.09779181038694722, 0.11192823254636355, 0.09816923870572022, 0.1205081178673676, 0.11068172979035548, 0.1595647292477744, 0.24053458443709783, 0.1295763041291918, 0.2560236118733883, 0.13642319744186743, 0.20825204599116529, 0.2189367062279156, 0.1306474802217313, 0.12518265417643956, 0.14344477280974388, 0.09468088338949851, 0.18060019692139967, 0.15311024630708353, 0.1106875923329166, 0.08342512058360235, 0.09380733740649053, 0.07952728973967688, 0.14592675891305718, 0.12888377771845885, 0.10333856275039059, 0.0977395089077098, 0.14276251941919327, 0.0721756342266287, 0.1022394106590322, 0.17945831747991697, 0.14046141718115124, 0.13299982542438166, 0.10315884596535138, 0.17612645269504615, 0.1724089357469763, 0.13031501163329395, 0.13367738335260324, 0.08520551504833357, 0.2735105721013886, 0.17810288949736527, 0.08408904674329928, 0.1755491415304797, 0.11965927055903844, 0.11041482804077012, 0.14397198094853333, 0.1972134890300887, 0.06553012332213776, 0.10750877112150192, 0.10932746888803584, 0.20627270505896636, 0.08104722175214972, 0.12851226622504847, 0.2894055534686361, 0.11629721096583776, 0.22296218307954924, 0.12749663500913552, 0.14669889105217798, 0.1226640407528196, 0.17708086648157664, 0.11507055535912514, 0.1481094839317458, 0.13773910754493304, 0.13612996174820832, 0.06923171505331993, 0.11848020739853382, 0.13239637709089688, 0.12059157767466136, 0.10575730260461569, 0.06887455457555396, 0.15883130074611732, 0.2581448751900877, 0.13423038939280169, 0.09182818646409682, 0.08086165599524975, 0.20210816924061092, 0.17100876516529492, 0.181487218609878, 0.1746040236737047, 0.16341367842895643, 0.12769779350076402, 0.1284121415976967, 0.07246579615665333, 0.1455271424991744, 0.11034755129367113, 0.09686495869287423, 0.1277490093239716, 0.12838646583259106, 0.07704151062560932, 0.07215908475752388, 0.11322328448295593, 0.1518179356519665, 0.13861067220568657, 0.15060022313679966, 0.09494838224990026, 0.15777316609663622, 0.15811484919062682, 0.09419204640601363, 0.18188346949006828, 0.16892176786703722, 0.08043034521064588, 0.1132837487384677, 0.12894576867776258, 0.12602372547345503, 0.11931092425116471, 0.13292266242206097, 0.0773148313164711, 0.14545713125595025, 0.15105883138520376, 0.07923875629369702, 0.1507266206400735, 0.1326109298637935, 0.1274072855178799, 0.14241045473941735, 0.18834338071090834, 0.19407031126320362], [0.024810646527579854, 0.020357041220579828, 0.054780744415308745, 0.03989496175199747, 0.008598313483941768, 0.022855580185673068, 0.017714221961796284, 0.009122754048023905, 0.008770724991336465, 0.03616606916433998, 0.006993510735420776, 0.0596649276890925, 0.05390144106266754, 0.019992250616529157, 0.021189939563295672, 0.05658297074426498, 0.006908059427847287, 0.029018367707197155, 0.03256724834708231, 0.022626769695697085, 0.04033105281580772, 0.034647097278918536, 0.03261458294998322, 0.014942375876541649, 0.019706852002335445, 0.015301604189776948, 0.03334889693983963, 0.0420559872207897, 0.008110674962933575, 0.0796680993267468, 0.008534183442991759, 0.047091646652136526, 0.013223691627250185, 0.02925081684121064, 0.021162854141688774, 0.018935384827532938, 0.04195795587397047, 0.021950375455032502, 0.029043188518179313, 0.019895471166819334, 0.03940699329333646, 0.1071628268275942, 0.01785874313541821, 0.01958533825485834, 0.031591681231345446, 0.046496839462114234, 0.0533090121378856, 0.06110306230506726, 0.05570326366328767, 0.009813610414442207, 0.03636127011850476, 0.023036767695365206, 0.06235021645469325, 0.05842389392533472, 0.015604670159518719, 0.034923783503472805, 0.05676450261047908, 0.02646840935839074, 0.04664141831121274, 0.025612598584432687, 0.02143249038739928, 0.06413063127547503, 0.0656779014638492, 0.033167161513119936, 0.0881609625316092, 0.04066587931343487, 0.012458164178367172, 0.05569863605446049, 0.020890948196340884, 0.03185704270643847, 0.04060523524614317, 0.0037666305849727777, 0.025940694014674852, 0.02020050149544009, 0.02638991133842085, 0.04627314342984131, 0.10601401954357113, 0.01898083310308201, 0.0033653447629019085, 0.03230675196807299, 0.015396541416911142, 0.04715656549004572, 0.025445738341659307, 0.04507649264165333, 0.021781250601634383, 0.03562594171879547, 0.0313150357188923, 0.03191682842693158, 0.03557735861146024, 0.02332847668523235, 0.03716432988377554, 0.014756577721397792, 0.02953626973820584, 0.043741756584495306, 0.029071150946297815, 0.058140252716839314, 0.05949654243886471, 0.018920251800279533, 0.03990268348050969, 0.022255253113274063, 0.03560056111642292, 0.022252052124323587, 0.02403330832852849, 0.05885511650038617, 0.02202565043366381, 0.034597262274473906, 0.023164140592728342, 0.025587528411831175, 0.10317034034856729, 0.021617090928235223, 0.013114550965838134, 0.016782995413190553, 0.04159978777170181, 0.03350972330995968, 0.025105437762769203, 0.030184450492795025, 0.025744726315939, 0.024464700537334596, 0.038050438942653794, 0.022523683262988925, 0.014917422751230853, 0.03295578428411058, 0.03248164776180472, 0.026024270869259323, 0.04992401466837951, 0.002431013704543667, 0.036981169533516677, 0.030395142401435545, 0.05795170140585729, 0.009488973816457604, 0.03643632287691746, 0.03176475855122719, 0.040369875196899684, 0.022724982550633804, 0.06109487238739218, 0.04950745523508106, 0.019324682420119643, 0.030349514314106533, 0.04032432174842272, 0.09677027591637202, 0.048185445102197785, 0.05415197994027819, 0.010900266435263413, 0.019858350212286626, 0.015650099775354778, 0.0457473703926163, 0.029285160891179527, 0.05625139782205224, 0.017816539953595827, 0.05177890210013304, 0.041128056656037054, 0.04528066722143974, 0.05884594949228423, 0.030282145964780023, 0.05727966675268752, 0.025266939275232807, 0.02168170272904847, 0.05264930646600468, 0.024986419327823178, 0.08538073993154935, 0.05125158200306552, 0.019444588039602553, 0.03032741103587406, 0.05862423138959067, 0.02703323378227651, 0.060169527041060586, 0.022925189396898662, 0.07991526927798986, 0.034372317737766674, 0.03792617203933852, 0.015902460519490496, 0.021232213991295015, 0.015071177090119039, 0.02399836547140564, 0.007267603683950645, 0.02293644629285804, 0.018388237937220504, 0.018792156263121536, 0.0631891842931509, 0.034964848442801406, 0.028522864117154052, 0.017845476079466085, 0.01196361393002527, 0.04232916541929756, 0.03984669416344591, 0.012722578248940408, 0.02043699978717736, 0.04979668078677995, 0.019180483550631573, 0.012702890555374324, 0.013840641111268528, 0.08943200789924179, 0.02197659235181553, 0.047167856312756024, 0.011283955935920988, 0.04523754971367972, 0.07551686958010707, 0.031500950921326876, 0.027031444146164825, 0.02332470233419112, 0.020858938306836144, 0.04384886672986405, 0.04641754585983498, 0.05556176197049873, 0.018065010995737145, 0.04987573011645249, 0.041937240199851136, 0.02556897556808378, 0.04032159064497266, 0.021892335265874863, 0.01232138678564557, 0.011086161281647426, 0.10595227964222431, 0.06585489732346364, 0.06587102610085692, 0.04300439597240516, 0.015037961104618651, 0.041481352876871824, 0.01411561488306948, 0.0433779362855213, 0.017941692345110432, 0.05205953061314566, 0.04048198275268078, 0.03510996333456465, 0.018122347204812934, 0.03058088118476527, 0.02472681182968829, 0.06381016597151756, 0.06253591113324676, 0.04337380400725773, 0.016104950636093105, 0.028398225715916072, 0.03884192629318152, 0.06469158296074186, 0.019028240648497428, 0.0568362339399755, 0.018631889684391872, 0.09019042684563569, 0.026911228096910884, 0.01570344789485846, 0.040142861128385575, 0.03899754490703344, 0.023623127124405334, 0.025465166495580758, 0.03495362547359296, 0.016883600104068006, 0.02479549653695098, 0.029228859448007176, 0.040379045597676716, 0.05756389828664916, 0.013115757061833782, 0.04727757542527147, 0.03284990567980068, 0.06777882230068956, 0.030245617032051086, 0.05314559376399432, 0.08579668868333101, 0.06939234464828457, 0.11920074373483658, 0.018658696906641126, 0.01726498767467482, 0.018257323087060025, 0.024462301916043674, 0.026933604485488365, 0.06042618291186435, 0.018531466501631906, 0.021592767144154226, 0.031239769221948724, 0.07613392254071576, 0.024054972255336385, 0.021419089320780973, 0.027136128528841903, 0.010236381835836385, 0.013168055996564882, 0.033921933333788595, 0.02359820114049528, 0.049619325303605626, 0.04360805804442082, 0.012536566355265677, 0.04877692407795361, 0.007540156782072569, 0.020550968225247095, 0.04561727487349084, 0.02722171215074403, 0.034070189842688184, 0.033244419510343244, 0.0043026388988697106, 0.02827508857340685, 0.014631204806002123, 0.04548686044290662, 0.04817808299724545, 0.03284029083858643, 0.04167863693354385, 0.04551226818667991, 0.03160829855395215, 0.034871125793350596, 0.029833953228912184, 0.0330151119934661, 0.04146769057427134, 0.028132289182394743, 0.05897308659872838, 0.017754718628046767, 0.016716473536299806, 0.024402037828362415, 0.07919716888240405, 0.013724769382471485, 0.03433284057038171, 0.04046905326790043, 0.023646366948794042, 0.07287327000605208, 0.034257960838398764, 0.08988453647387878, 0.03844644215756229, 0.06375810197953667, 0.06796136179140636, 0.029888039255248647, 0.05942007154226303, 0.06426608043589763, 0.023431927830513035, 0.046175515811358175, 0.00981744668180389, 0.08843224761741501, 0.03194859404382961, 0.028011867876297662, 0.02986170191849981, 0.023200939243127192, 0.01287867607814925, 0.007770187786913344, 0.05919462828231709, 0.059159744797008376, 0.047687916085124016, 0.05691456402252827, 0.023549153236672282, 0.035485569786812575, 0.09469294095677988, 0.030370111244597604, 0.03244006713586194, 0.06723560752081019, 0.07021273419793163, 0.050584035859044106, 0.056806290189602544, 0.06670943075524909, 0.026784710153671246, 0.017745658489210264, 0.010923784459009767, 0.026013533052589213, 0.021218075017843927, 0.028042970225214958, 0.05168199712144477, 0.022387029702908227, 0.012658170856801527, 0.0032248907705901986, 0.12638163912509168, 0.08328388351947069, 0.1404039588357721, 0.12387134454080037, 0.0689131428620645, 0.13654016330838203, 0.06713231413492135, 0.1117969835177064, 0.10696254364613976, 0.17739348113536835, 0.07464447032128062, 0.2823407011372702, 0.11553361479725156, 0.0932919697037765, 0.13390062137373857, 0.20506325710032666, 0.165617614452328, 0.12646448825086865, 0.11983737243073327, 0.128265808735575, 0.16418604126998357, 0.13711508602968284, 0.096881942424391, 0.05778560960399253, 0.1680021629269634, 0.11129062676004, 0.1419713475874492, 0.18777729251555034, 0.16366453282535076, 0.14416786043771676, 0.07706069281058651, 0.13766133386109555, 0.08613470090287072, 0.11087031502808843, 0.0882594043921147, 0.05699663622570889, 0.17487580409007414, 0.11504924935953957, 0.16530592260616167, 0.19001929435346807, 0.13117002003959247, 0.12580559003565991, 0.11038671633494751, 0.0976214302437646, 0.09502145368605852, 0.10563376851912055, 0.1125755753102047, 0.163575251187597, 0.10972186058227505, 0.11659892834722996, 0.1578169044639383, 0.10398470450724874, 0.16836237002696308, 0.1572247605238642, 0.1801763025245496, 0.1364243645220995, 0.1272421029529401, 0.19442309519009932, 0.12402754330209323, 0.1928873397409916, 0.1010249483266047, 0.16820706693189486, 0.22332981335265295, 0.11187565965311867, 0.1348557136952877, 0.14039013029209205, 0.06084942591509648, 0.10944955769394125, 0.08062392446611609, 0.10042000043072871, 0.1161521537495511, 0.13806983908372267, 0.10135884183858122, 0.11954349891415664, 0.09946110152772494, 0.13254975314651216, 0.1487951571387904, 0.09131602144667081, 0.1721659523567983, 0.14954520974840435, 0.1464060489088297, 0.12173914323960032, 0.16047948944781507, 0.11575704280819211, 0.11759089226169245, 0.0955233456833022, 0.10210383257695607, 0.1329797679292304, 0.1901455425790378, 0.11381230037659407, 0.12043054774403572, 0.0860806895153863, 0.14034016297331878, 0.18331466269280228, 0.1059695483584489, 0.08050807139703206, 0.09128309214221579, 0.08797819233898606, 0.11228145073567118, 0.09240137213574988, 0.18629162652151926, 0.11435592227748462, 0.09097677429339715, 0.11104496994188853, 0.13010370225778647, 0.11420029348560742, 0.14407237698989256, 0.11013021652719804, 0.1660878663616521, 0.09583984155740057, 0.10523572630648102, 0.101101005316845, 0.10481924151203462, 0.15908708130674704, 0.09775380564055272, 0.15279239336294786, 0.15597753173538617, 0.10442356060125998, 0.12383360442306314, 0.11869094680462565, 0.09487897490284272, 0.17698219391916478, 0.15247897803783417, 0.09282694929944617, 0.20038379462701933, 0.1366344661052738, 0.1636962475521224, 0.12384280535791602, 0.12702527030238084, 0.07892074050115687, 0.1022436311468482, 0.08777889981865883, 0.13923777426992143, 0.15143792890012264, 0.19669335122619355, 0.1721224311207022, 0.08793317154049873, 0.11320917773991823, 0.20079498684832028, 0.13632497271256788, 0.19312880321272782, 0.11768339015543461, 0.11628396596227374, 0.10924842634371348, 0.06318726403904812, 0.16098852641880512, 0.11938298467014517, 0.11423143824296338, 0.10618794163955109, 0.12712591061634676, 0.13541702500411443, 0.1555371353668826, 0.11126217578670808, 0.145514684596232, 0.19833354678537163, 0.11608710938266345, 0.09793272853962012, 0.15071058007223265, 0.09795625334871666, 0.13817655907145568, 0.1313879383461816, 0.13596179362918648, 0.13287696987390518, 0.1025014201711331, 0.1482096764125994, 0.1269487315522773, 0.09921481367200613, 0.13064862016056264, 0.09995259158313274, 0.09782029528703008, 0.17129756323993206, 0.13506844799433435, 0.1142028176358768, 0.08511924610606261, 0.12789276375302247, 0.07077891738819224], [0.008098789573913174, 0.010821978761149305, 0.024587893658982854, 0.010694207224462713, 0.04463699193937438, 0.06360127896602664, 0.05849355911569936, 0.09737280822758164, 0.02316291074800704, 0.04959402273276022, 0.042087817298514504, 0.051127773110887835, 0.011979424644128552, 0.007103357921420995, 0.086149119772017, 0.009924250638245471, 0.03774552905399885, 0.09019961420978818, 0.034021606735352955, 0.01286667279366936, 0.02852565628875579, 0.025068839280200855, 0.06539373778338943, 0.008658278168046048, 0.04983038701383131, 0.02834887077499713, 0.023403461590143185, 0.04110607212143285, 0.03690782668335097, 0.048918575048446655, 0.018635328160598874, 0.05181742253314171, 0.018424826241763573, 0.009061629917206509, 0.04445663054606744, 0.04178612705852304, 0.06304151471704245, 0.025985819986090064, 0.021410234438787614, 0.057913995214871, 0.03932207124307752, 0.04374269635549613, 0.008681987029766398, 0.03962974276925836, 0.0052002919588371044, 0.005740078864619136, 0.04043444458927427, 0.06926814559847116, 0.03585848245503647, 0.024606873979792, 0.037554616441151926, 0.0793125673330256, 0.03023834652932627, 0.014591054192611148, 0.028200018851618682, 0.09879967916224684, 0.005296582439249116, 0.06109458740268435, 0.027278778642149906, 0.05197577903579388, 0.014600143169185944, 0.04675577860325575, 0.02258295668954296, 0.04352393327280879, 0.021241260559431145, 0.023881409782916307, 0.05766756486679826, 0.0917004318907857, 0.010007656162737735, 0.0049728720415649665, 0.024939339175554257, 0.015415019621806485, 0.06394702648477894, 0.005535986557203744, 0.04208541189187339, 0.018814603897875974, 0.03529027383774519, 0.029130543116480112, 0.047463273496500084, 0.06038705858268908, 0.01792267300853772, 0.018226056193400706, 0.02314785066326814, 0.02761709111343537, 0.031184716283210685, 0.03411735141915934, 0.05452703677916101, 0.02512957664605762, 0.013040627120062709, 0.03894534520804882, 0.05177408789417573, 0.03689985389688185, 0.022529834182932973, 0.06650634522416762, 0.04643242952546903, 0.005884590708384556, 0.05894242360123566, 0.01986053679138422, 0.07031750679016113, 0.024110142241365144, 0.03186610793428762, 0.04093941035015242, 0.01675584213808179, 0.024545934749767184, 0.03592247169997011, 0.03819217812269926, 0.01910671152706657, 0.019702027618352855, 0.06314754259905644, 0.07305255931402956, 0.019638957788369486, 0.07474348215120179, 0.02131858980283141, 0.043628291958676915, 0.01477596685955567, 0.036151022650301456, 0.022740705903353434, 0.03202849154227546, 0.01101774289937956, 0.0266879663270499, 0.07060670520045928, 0.03253332159614988, 0.053482930841190476, 0.005373092775698751, 0.03785351790221674, 0.03127355008785214, 0.09853924385138921, 0.11178368423134089, 0.05380842748231121, 0.023449798746566688, 0.035381614829280546, 0.04860742263762014, 0.0376322408472853, 0.014723422804049082, 0.014907818088041884, 0.046265503125531335, 0.03276854933106473, 0.032366286630609205, 0.035979604348540306, 0.002329181713451232, 0.03288760169276169, 0.05055004803996001, 0.025551527040079236, 0.038617185316979885, 0.03557585904906903, 0.03522898855486086, 0.036351265119654794, 0.0446074587026877, 0.0294555138929614, 0.09256823068218571, 0.026579894358292222, 0.038037699447678666, 0.02688282462103026, 0.04789022808628423, 0.01510753808543086, 0.053075758939875026, 0.012605217135777431, 0.044651953636535575, 0.024393471323751977, 0.03014875276546393, 0.015379695088735648, 0.020856353088415096, 0.027410896195630943, 0.07474236935377121, 0.04298475916896548, 0.05675330678267138, 0.060919057178710184, 0.04570142000115343, 0.05139116344175168, 0.05541330868644374, 0.0491048023769898, 0.021106924196439128, 0.06624129587518317, 0.015570702696485179, 0.021697137704385177, 0.023444380644442778, 0.04095979014943753, 0.04419858367847545, 0.018945869889908602, 0.008124250752319182, 0.039777442879442654, 0.038863412104547024, 0.02556165587157011, 0.02480255499748247, 0.054424330326063294, 0.05277539184316993, 0.022191981419122646, 0.037771639081516435, 0.011726897658913263, 0.025932210630604198, 0.014728723858882273, 0.02668639212580664, 0.03408632540543165, 0.021469266985410025, 0.03020845027640462, 0.02566463204233774, 0.01214572085466768, 0.04217158583924174, 0.020599949971905777, 0.027168489560218792, 0.04905769508332014, 0.04191492657576289, 0.0521394315042666, 0.03331164875999093, 0.02633824598576341, 0.06268820153283221, 0.021987759341884936, 0.10011892765760422, 0.023093798563682606, 0.036210102694375176, 0.03740984081689801, 0.036771760056061406, 0.005751075372765107, 0.05167418039802994, 0.005929570370686373, 0.05826692841947079, 0.04273134669555085, 0.021453614878867353, 0.07189845267151083, 0.029919492746038095, 0.008090201865083404, 0.05879757673080478, 0.06293911021202803, 0.03900978907144495, 0.04958835018000432, 0.018468807185334817, 0.009662761901771384, 0.05862812618059771, 0.017864731206957783, 0.029898291919380426, 0.028631714704845632, 0.038857186545750926, 0.017638836721224443, 0.02698271006478795, 0.02783393733469503, 0.05515321942844561, 0.015567284576328737, 0.019807468567575728, 0.024115534898425852, 0.009554323524103632, 0.0338536557475371, 0.025973950712276355, 0.0952333737430828, 0.02231458591164223, 0.03793331701308489, 0.04514342672856791, 0.057646224940461774, 0.023437098267355135, 0.03319792289819036, 0.021671531489118934, 0.013558329831409668, 0.03203395374917558, 0.026827347597905567, 0.00897130333552403, 0.027831335152898515, 0.028345355963600532, 0.023627027004425014, 0.03112923926008599, 0.014783088084576386, 0.0611007349299533, 0.040816259636942825, 0.01891888115954186, 0.05105381618653025, 0.05396720128399985, 0.028173815525536026, 0.020761378541854874, 0.02205825743398496, 0.06262336072645017, 0.011626591523444014, 0.11055090145340987, 0.03156339989176818, 0.0633217700357948, 0.03482797435883965, 0.013915156978847725, 0.021616507388119186, 0.013898124053542103, 0.01610401425776737, 0.051596135300184996, 0.016983529652601907, 0.08950389868446759, 0.07366862161351101, 0.027910591435751746, 0.02566915108556194, 0.028927576329026903, 0.050421224773994515, 0.03246730013883539, 0.025311542774683664, 0.04046342481992074, 0.006608556615122194, 0.04414668592757412, 0.02669234966327037, 0.054901469365826676, 0.06488378479012422, 0.035766819159367254, 0.010896719393453427, 0.05552872749311583, 0.013366384148996855, 0.02909388526209763, 0.023307457366692166, 0.01866901572793722, 0.016577117710507343, 0.052084307319351604, 0.08295772530670677, 0.042736724085573635, 0.04018313218174236, 0.019388865047533597, 0.048650981193142276, 0.11298043679978166, 0.05120887500899179, 0.011320751193644745, 0.10455449750380856, 0.042252141516655684, 0.013211390635530864, 0.03263267269358039, 0.05276262859946915, 0.03968984740121024, 0.013271455403550394, 0.019826754229143262, 0.04004676699904459, 0.035675495131207366, 0.041210186534694264, 0.04346150126574295, 0.03570348470072661, 0.025507798850802437, 0.04291528396840606, 0.09576304496398994, 0.02850841132125684, 0.01706303868974958, 0.02493935783526727, 0.04250402728627835, 0.09459998165922505, 0.04071770242548414, 0.035214013286999295, 0.03776895886819277, 0.030810287089220116, 0.031247670762240887, 0.04622773925906845, 0.06010389234870672, 0.004371437684832407, 0.06949020296867404, 0.04036395837153707, 0.005140786134039185, 0.04662915039807558, 0.018047168917421783, 0.02477971211607967, 0.11517914810350963, 0.016581185527944138, 0.05899349693208933, 0.03905480308458209, 0.006045449733002377, 0.04010959594909634, 0.05712029244750738, 0.11944815117333617, 0.1372587318931307, 0.08223593368061952, 0.09935598966798612, 0.1293877392475094, 0.11460326186248235, 0.1123303866812161, 0.15422616499875272, 0.159164217167667, 0.15453641835067952, 0.13236462165202412, 0.1672635775591646, 0.07897288591734, 0.09734547683703047, 0.10598227767539875, 0.11678220065576689, 0.11385966890624591, 0.21255492152912275, 0.15380586683750153, 0.13108409036483082, 0.1125909441283771, 0.11705820155995232, 0.17032261698373727, 0.07410814945719071, 0.14485396790717328, 0.09346302159662757, 0.1526347832488162, 0.11076677736959287, 0.16533363397632325, 0.11315644878361907, 0.09171883376049143, 0.16091827090297425, 0.17763233903263295, 0.0878644088017089, 0.1317956428974867, 0.07058862902756248, 0.15996794189725602, 0.10316283575126103, 0.12362662410097462, 0.1999524092035634, 0.09385089935468775, 0.12210340797901154, 0.1272633953818253, 0.08914248379213469, 0.05112464167177677, 0.11750251986086369, 0.2169697689158576, 0.1481629932033164, 0.12020854465663433, 0.06520834166024413, 0.1165004593453237, 0.1891971541834729, 0.09965515575770821, 0.0655920532132898, 0.09202792003218617, 0.1443950068205595, 0.15298774359481676, 0.10582136309572629, 0.07611503891114678, 0.17645107741866792, 0.07104889968676226, 0.15383049765867846, 0.15404838882386684, 0.13316926918923855, 0.12187680442418371, 0.1553296393581799, 0.16432546664561543, 0.1279398269419159, 0.09812196517097098, 0.1595934041376625, 0.1037342097344143, 0.1743092816323042, 0.20161832123994827, 0.07063281522797686, 0.13273568531232222, 0.14933008700609207, 0.14698631848607743, 0.1073285047230976, 0.1123434416949749, 0.20149528927036695, 0.11510460424636092, 0.12182697281241417, 0.07405432805951152, 0.1596197448670864, 0.10832174428339515, 0.12938780710101128, 0.16285589550222668, 0.14001465615417275, 0.0775146395234125, 0.15578033588826656, 0.09594488556363753, 0.12373210915497371, 0.1090051851102284, 0.19823811762034893, 0.11302889098546334, 0.10058423983199255, 0.20733366241412504, 0.11241077951022557, 0.08637770464909927, 0.13013787328132562, 0.1602838813726391, 0.10696721875241824, 0.13435756042599678, 0.1501426598323243, 0.1833557276321309, 0.13102906117481844, 0.08884769425328289, 0.10253890244556324, 0.2158207105738776, 0.1353282726236752, 0.13595047566507543, 0.1681502464094332, 0.10394817218184471, 0.08919606770255736, 0.09506806225648948, 0.16583045731697763, 0.13603502112839902, 0.1188869077180113, 0.04815733339637518, 0.15670850394027575, 0.1854158549436501, 0.09788377223802464, 0.17899947852960654, 0.07817577011883259, 0.10642230084964208, 0.12372536451688834, 0.17013391639505113, 0.21327350368457182, 0.11322798673063517, 0.07076702945466552, 0.17274371135447705, 0.18637747477207864, 0.10531753727367946, 0.05452421068080834, 0.16151771587984903, 0.09285367000848055, 0.1488147396594286, 0.12079384896372046, 0.14199774259967463, 0.11534560631428446, 0.09450929545398269, 0.11633967368730477, 0.06300673301198653, 0.14125572384468146, 0.20894717797636986, 0.14714525852884563, 0.11025249532290868, 0.094454218766519, 0.11063649864601237, 0.18388963969690458, 0.07967473539922919, 0.07001042219677142, 0.07838773767330817, 0.11654532408075673, 0.1538097480578082, 0.09647313864635569, 0.12570154347590037, 0.19555076610829147, 0.09681151048945529, 0.1262746477233512, 0.08006348168211323, 0.2032356501689979, 0.1605170802878482, 0.17722308742148535, 0.13033586979976722, 0.14692675668214047, 0.19808893491114887, 0.1467551958880254, 0.13927818781563214, 0.20977186943803514, 0.05575272886614714, 0.11068045414452042, 0.20931111701897212, 0.0930609285299267, 0.13823631086519786, 0.14888882211276463], [0.029409621176975112, 0.04183677630499005, 0.04464161615552647, 0.06547652584101472, 0.03089116167809282, 0.014628833326111947, 0.03387089053701077, 0.04469311357076679, 0.03272198147273489, 0.030541831494442055, 0.054816720341997485, 0.02757585484401456, 0.03193469764664769, 0.03581576867561255, 0.026475722269554223, 0.029277747896100794, 0.03716568695381284, 0.006188369139895907, 0.04048274949725185, 0.0421124650830669, 0.04657517972269228, 0.045713012771947045, 0.008193576675174492, 0.07226764357515744, 0.02074587401667876, 0.014206334166894001, 0.03258971803422485, 0.02509196205729885, 0.06066137672002826, 0.021776310866698623, 0.03262385852368815, 0.04615535314327904, 0.06695132848939725, 0.03338926298809903, 0.02475730519342635, 0.015456917462870479, 0.009265980067928987, 0.025285816119451607, 0.06578850945723907, 0.02405534205692155, 0.03937275441629546, 0.015202210683907782, 0.034197591577789614, 0.038119917535888295, 0.05278333070288811, 0.014783846347459724, 0.015866696634995084, 0.05728028421955449, 0.026652585814840028, 0.019609541598973528, 0.015759257400142293, 0.04426209455622094, 0.0326874881450619, 0.03387455801878657, 0.007986935620595301, 0.011562183283136358, 0.015652922481032353, 0.03218710249555962, 0.06848205599401679, 0.04211098248405116, 0.06420387234538794, 0.029020589909383228, 0.009242948044889739, 0.11270457838795014, 0.040519203791128736, 0.03791532565706542, 0.02518763719126582, 0.10361590036856276, 0.039363668832395754, 0.04066640857074942, 0.022951586105461632, 0.03012550276304994, 0.011267173220403492, 0.01510520901397935, 0.02074151442918394, 0.0186018543317914, 0.044309564866125584, 0.02272134899560894, 0.020251069317704866, 0.059808017153825076, 0.03294660709798336, 0.0494607448843973, 0.008661023690365255, 0.024708632180201154, 0.038072029926947186, 0.04851944039442709, 0.038984971653137884, 0.0476194485090673, 0.062186329891639094, 0.029246365651488304, 0.08292354749781744, 0.018644342498321618, 0.024986458343586752, 0.04004159995487758, 0.029573650232383182, 0.029539594559797218, 0.05294673550607903, 0.028974826115050485, 0.025769494540457214, 0.029206803667226007, 0.0435192581665303, 0.02732623029234154, 0.040996732988527844, 0.010075442659269487, 0.008895002072677016, 0.0774609741887876, 0.032370293379894326, 0.018486194645187685, 0.06097783188202551, 0.02771766357389944, 0.030758582720799104, 0.024722577771171927, 0.050905427363302024, 0.007304476125032774, 0.010225649956347687, 0.02515726426749357, 0.031547885188566785, 0.028285785677975843, 0.020773225763280476, 0.018200097139924765, 0.02552179024288697, 0.029101227010999407, 0.019141701881640723, 0.03568221941324217, 0.07825841568410397, 0.03963867907545396, 0.09871989701475416, 0.026584581338933537, 0.047622647801680226, 0.01343477878253907, 0.01587392303294369, 0.008339275955222547, 0.03702018529708896, 0.021763729131115333, 0.0657119367803846, 0.058539774135819504, 0.03670877504295536, 0.05024315343637552, 0.028682598045894077, 0.01619096003871943, 0.08375490895871605, 0.030304116928683858, 0.0590134933590889, 0.02463048869477851, 0.04874750279954501, 0.03817815619653889, 0.07930139186126844, 0.03782185406557151, 0.05226677217121635, 0.04631895811430045, 0.01739748690410384, 0.07573330189500536, 0.0276165245366948, 0.06926965194621257, 0.03858577932364174, 0.07352585784558739, 0.01738900182369564, 0.03560160606035164, 0.014862620870449712, 0.04631139584151762, 0.10146799776703119, 0.051952603672231944, 0.0450468406613384, 0.06310561592025415, 0.050478170825434585, 0.02997390107650842, 0.04402444784396461, 0.05096452097807612, 0.0870904310473374, 0.027195673369403397, 0.10917041517261948, 0.010863834193774631, 0.06119851182614054, 0.04795094679242798, 0.04440782352217606, 0.02714889855789287, 0.021935995601649796, 0.055068222739334614, 0.04215131460555962, 0.06426218564489058, 0.02280326174306018, 0.006865986015847219, 0.030980687588453293, 0.05489569503281798, 0.011696113373285957, 0.04384590831718274, 0.030135009038661207, 0.04605415643059781, 0.014784708086933409, 0.03471228753083518, 0.04057034158280917, 0.06951681511210543, 0.026346598751842976, 0.01987103881713535, 0.02242906833998859, 0.0386961973272264, 0.05199814015733344, 0.06356446844126497, 0.041730500757694244, 0.08319942626569952, 0.034474973300737996, 0.0644341196332659, 0.02342762252581971, 0.06852213027221815, 0.014319728394704205, 0.04728303763217159, 0.05330938193947077, 0.05935139701302562, 0.011171140159214181, 0.011246361703212773, 0.04481788598267095, 0.05495730261983616, 0.005153417911580098, 0.00804860597210271, 0.02974048163741827, 0.0794641791975924, 0.03955534479713865, 0.05428910508219685, 0.06839533921863351, 0.026060701414410557, 0.05918007370616708, 0.034380816388875246, 0.024577391633231725, 0.02231087432509022, 0.026005853732515658, 0.04139203052701695, 0.021941980280514275, 0.07047991414687463, 0.034104652636285336, 0.028060970062922155, 0.021724827022158673, 0.02031748602166772, 0.029256055131554604, 0.004556301582072462, 0.014255038562363811, 0.06730430240609817, 0.04516936372965574, 0.06048120531652655, 0.030692585012210265, 0.02632747933135501, 0.06975325063935348, 0.0056606016338004595, 0.023133681155741215, 0.031882002617099454, 0.09472414678228752, 0.009301259648054838, 0.035960371273436716, 0.036842229310423136, 0.04900125454046896, 0.03846748013581548, 0.022671122137191038, 0.03177343701411571, 0.05105149559676647, 0.010292154021694191, 0.027846751468522207, 0.08676263756517853, 0.0054943571615565035, 0.025906804583168457, 0.012913043876843793, 0.014357668680271931, 0.011064806088273014, 0.04229088247354541, 0.0600320626316326, 0.052940947602369955, 0.03948841071022408, 0.01246971623705966, 0.13119356520473957, 0.06284538416990212, 0.007129148613395435, 0.030270125716924667, 0.03287037368863821, 0.018822193312059556, 0.116561052522489, 0.04337859785716448, 0.016570378161434616, 0.006405348947737366, 0.09324250450091702, 0.0067255852461260346, 0.030991469509899616, 0.02447346381710044, 0.01801449915261141, 0.10379379867975201, 0.029495900297271352, 0.018780085125139782, 0.02589574615870203, 0.01686776988208294, 0.0075285122729837894, 0.001981233196732189, 0.06485506918813501, 0.03705030885924186, 0.09660854030932699, 0.03674170434741037, 0.05878425030303853, 0.052162528836301396, 0.006681839669389384, 0.029299243885491575, 0.01472539734095335, 0.02093283416304205, 0.029243397060781717, 0.012661375238427093, 0.04972813857187118, 0.036058680819613595, 0.028689963543521504, 0.04001289113823857, 0.03897473934505667, 0.032156483602843115, 0.03316066114764128, 0.03245519507410271, 0.03164812516687172, 0.09610461949237756, 0.13590418600610324, 0.052884619017796855, 0.03301780917016523, 0.04575151963425534, 0.024240921384521892, 0.03677630624068635, 0.05094139650464058, 0.055029257865888734, 0.006272956163489393, 0.04337164626589843, 0.004758006294390985, 0.021611009558130587, 0.07260916382074356, 0.024401756236329675, 0.030028784381491796, 0.05456983198278716, 0.03347174909764102, 0.050543832659189186, 0.06453469209372997, 0.02649794259507741, 0.019497622336660112, 0.048290316082004986, 0.023668142833880017, 0.03869657052148666, 0.03638063890061208, 0.05015775641160352, 0.025943033264151642, 0.047521189853016815, 0.05511893305395331, 0.06005929224193096, 0.06349607889673539, 0.050817482439535, 0.02646480464110417, 0.09814502179090466, 0.020708651281893253, 0.04347559783075537, 0.04824883723631501, 0.015411548915186098, 0.04294436937198043, 0.013181055879353412, 0.029509118159434626, 0.09526002659861531, 0.11552511953881808, 0.10573985068393604, 0.10794043474431549, 0.21494390762278012, 0.12476036112223353, 0.10167021477328879, 0.11728101888937609, 0.0939734224230051, 0.1357852659587349, 0.11454360506364278, 0.12859497964382172, 0.17167594150773116, 0.0853970315573471, 0.132528352152024, 0.18798195224787506, 0.11239621814872537, 0.06436025431113583, 0.10309034785521881, 0.11571581502045904, 0.09748548575277839, 0.18885525395827635, 0.15862719741250786, 0.11868011738572802, 0.2110282313078642, 0.07129506540617772, 0.10461139945047242, 0.08397318688886506, 0.19880636355706624, 0.15455810432987555, 0.15893837357206003, 0.1776033113045352, 0.13796576538256236, 0.10610873624682426, 0.06118922946708543, 0.14013824452246937, 0.12330566346645355, 0.1062331252864429, 0.08285252523741551, 0.21723761382911885, 0.12112201564013958, 0.07308860309422016, 0.09806255264473812, 0.15229771419295243, 0.11840247442679745, 0.12974680640867778, 0.06849857832172088, 0.06848307379654475, 0.1388540898582765, 0.12294366503400461, 0.14232687279582024, 0.07725028906549726, 0.16589235328137875, 0.21587677113711834, 0.08024094573089055, 0.0941168036577957, 0.11965570146484034, 0.155466744144048, 0.12410476058721542, 0.15944978541561536, 0.07950451131910086, 0.10090628612254347, 0.15967067570558616, 0.08235508442989417, 0.23703964054584503, 0.16564092891556875, 0.07994855142065457, 0.11214808467775583, 0.2644425758293697, 0.17854423581489495, 0.15913934207388333, 0.10694471853119986, 0.09929921664297581, 0.06587914137967996, 0.11493533690060888, 0.17982434641037667, 0.12180524612111704, 0.15527494943567685, 0.07784436004502432, 0.12303848351751055, 0.17427068656044348, 0.05771163571625948, 0.13373862792338642, 0.05298289802989789, 0.06901509274861642, 0.1082998818850943, 0.11794393403189522, 0.10327086531158004, 0.14291027720485414, 0.06939843110740185, 0.06706210611654179, 0.14829035422631673, 0.15582604200712272, 0.13107896064008984, 0.12689421804887907, 0.05970886283154998, 0.09902598416166646, 0.23086128064564296, 0.10258818444396768, 0.0857481462880969, 0.13013317781899655, 0.16462261070098194, 0.12109598703682423, 0.10033208943371262, 0.15118160551147802, 0.09263717662543058, 0.13885639687733992, 0.16009165240185602, 0.11973552432443414, 0.15315080913049833, 0.1121297710176025, 0.18146963098219462, 0.1306744044912713, 0.20782041629510267, 0.07787996277745281, 0.25146258090223583, 0.17926561353462084, 0.11983544539128031, 0.11157469544559717, 0.08268777014953749, 0.12911044912678854, 0.10762360638805799, 0.11462530067988805, 0.15502934690032685, 0.08068681109164443, 0.2002178385321583, 0.1170997821858951, 0.11139995232224464, 0.06411712164325373, 0.06956433970481157, 0.10766822006553411, 0.10245675899620567, 0.07115363156689064, 0.14278667526585714, 0.13985640821712358, 0.24215682595968246, 0.18831070246441023, 0.17151211601282867, 0.2684929684868881, 0.07413893459098679, 0.11306994913944177, 0.16787324127342018, 0.08929697943053075, 0.21282245431627544, 0.11884737626782485, 0.12464545800217561, 0.12732165439852647, 0.1551342619849103, 0.10470918991736003, 0.14365795494190284, 0.18563994791890892, 0.11075537798127957, 0.19102948371853146, 0.1340403724461794, 0.21410958096385002, 0.10768478989068951, 0.16059693028884275, 0.1252661139837333, 0.124867461089577, 0.09411174178655658, 0.1486570481210947, 0.1399018293512719, 0.15761273327682698, 0.10681699109928948, 0.2707931750587055, 0.17718380024390562, 0.1418159223560776, 0.17597268308912004, 0.14817565466676438, 0.11587033101490565, 0.12058358453214169, 0.1921756922134331, 0.11637089986886297, 0.20622774532863072, 0.09980144112237863, 0.09173623139836959, 0.12076051932360445], [0.01603653734283788, 0.015198904522029417, 0.03506855573505163, 0.02616328912388001, 0.04156286868133715, 0.07660071392144475, 0.027028428058006933, 0.03515840394954596, 0.03497254302991288, 0.02056612160855106, 0.038312733439462524, 0.04428452692393746, 0.05761258995958737, 0.04160948742979339, 0.033830439671874046, 0.02888372939612184, 0.04957831125440342, 0.0701789635100535, 0.017058948819924678, 0.026349870986970406, 0.06171953172555991, 0.023669518563630323, 0.06592753449720995, 0.036840919737837145, 0.02462525379710964, 0.005543141284891005, 0.0680302195250988, 0.06766970708434071, 0.04549211569662605, 0.03538796591705509, 0.03174623793789318, 0.06872259665812765, 0.022229984469179596, 0.030880797055682967, 0.03560301062784024, 0.02287317459870662, 0.08890090496944529, 0.01375941962136754, 0.05142219624082957, 0.034995019502405605, 0.04606954899749585, 0.029531560705176423, 0.03930409685043352, 0.04880048281380108, 0.05211916705593467, 0.01892441461261894, 0.005865460685786924, 0.03075257090053388, 0.09037829962159906, 0.024970763828605413, 0.036194214796913524, 0.07992330991796084, 0.044486072180526595, 0.10416215498532568, 0.0988313735329679, 0.005829948283332799, 0.021794429448034083, 0.05177216085472277, 0.08344043511897326, 0.019053799366312366, 0.05066382818456207, 0.0031173794413916767, 0.006621849540221904, 0.0068543758575937575, 0.012745768031371492, 0.02848404852141227, 0.05078823758023126, 0.09092867294592516, 0.04675450635009578, 0.0435723263903388, 0.04008297362763967, 0.03480303480422922, 0.046776484099349806, 0.03308999851079924, 0.08001503428178174, 0.04652915469237736, 0.030545858599777733, 0.06204277223774365, 0.037355527481330295, 0.03491802952651467, 0.05197171800370727, 0.058944418494190486, 0.060352616145142486, 0.018980600704838122, 0.028464567781026875, 0.03422579149316464, 0.06974236693765436, 0.03977304257984672, 0.0644049019153629, 0.055567736471337933, 0.0044986871736390245, 0.05821639113128185, 0.03676104259544185, 0.03672576555982232, 0.01907803494084094, 0.012077451750103916, 0.018526486054595028, 0.05052509491464921, 0.08193298815084354, 0.04605685021462185, 0.09032567923090287, 0.04243151564151049, 0.017846051137894392, 0.03284304229808705, 0.022363213123753667, 0.03846708658550467, 0.023669357411563396, 0.06871949575309243, 0.02778360360701169, 0.0159068523373987, 0.026384308335504363, 0.02065230573394469, 0.05484940537384578, 0.02163031048673604, 0.0231362239657236, 0.07063692715018988, 0.07349541197930064, 0.008485050722291427, 0.05412304720708302, 0.11285108088382653, 0.012346628288339292, 0.029036189429461956, 0.010623344419790166, 0.014586111065000296, 0.047307213834886036, 0.022123444293226515, 0.022296966053545475, 0.047125037360404215, 0.0312025312201253, 0.06698906860713448, 0.01162153558938631, 0.08245584009481327, 0.03133766146908913, 0.03932914836332202, 0.02361932902463845, 0.0400437475182116, 0.07792744665805783, 0.03501979620861156, 0.07411514515323298, 0.06685292734099285, 0.06358232069760561, 0.022412500211170742, 0.03305554250255227, 0.016771796192707758, 0.06304322462528944, 0.07001241030437605, 0.057516502615596564, 0.03762234102136322, 0.024633067127849375, 0.029751216061413288, 0.03199245794011014, 0.03878365709845509, 0.045967266628784795, 0.01551088983459132, 0.037790254689753056, 0.05883539827274425, 0.0434004263287144, 0.013494782482406922, 0.030113418054367815, 0.008390947245061398, 0.03954763663932681, 0.03519413899630308, 0.006630830375278103, 0.012830208321767194, 0.028470901905425956, 0.01326331467966416, 0.0031829914452308522, 0.04816444105069552, 0.03859434922092727, 0.05693108295755727, 0.029028830717184713, 0.06695523006575448, 0.05525670958948987, 0.028917493298649788, 0.03111124111871634, 0.06147435666727168, 0.06906456473682608, 0.05007810318576438, 0.02970098072130765, 0.02975536530305232, 0.03851507936737367, 0.0264524637854525, 0.055813946295529604, 0.007255661467622433, 0.05748327475573335, 0.03558938564466579, 0.020889977891264216, 0.015792673553473184, 0.020799607204805528, 0.008516476223511356, 0.09532347640820912, 0.08121671979980809, 0.02213990724911647, 0.022016581813139573, 0.0612472781379308, 0.0328853387784745, 0.0665563600403922, 0.008064800906660301, 0.06326714118144341, 0.01789074793591031, 0.03713500699294465, 0.07065532901989562, 0.09894808155617543, 0.02153626722948892, 0.015343432481001531, 0.009716386524295169, 0.0029302416036703755, 0.04440641216933727, 0.047381089335041385, 0.02282759909784155, 0.016587869097877826, 0.06541378849319049, 0.10831597673573665, 0.04580945634682264, 0.017880924445177828, 0.0058554590796120465, 0.09692386910319328, 0.03440354052664978, 0.012635563766317708, 0.0374152148142457, 0.014556333555706909, 0.024675031126077687, 0.02916100255346724, 0.023010956223255823, 0.0358272902002292, 0.01778161066717335, 0.059381130417542796, 0.07086650947374956, 0.03962602439735617, 0.12191249536616461, 0.03567823302000761, 0.05398228172478931, 0.0587909406583224, 0.04097623105293938, 0.09769783328686442, 0.02314968440415604, 0.034196539848510704, 0.02788055608315127, 0.02071005415304431, 0.023015929884942513, 0.06973647725369249, 0.040250391965465884, 0.03817457353164043, 0.03424031214256372, 0.061631335743835995, 0.03667989319988659, 0.051751183944621255, 0.04433391409526978, 0.007673916390298733, 0.054796181086983, 0.037623623452548466, 0.07486750478191034, 0.026767751867217675, 0.04396531690976449, 0.06724881859762327, 0.0174824751115271, 0.029211156469370638, 0.06605613723929439, 0.02327883506326803, 0.039892013517341444, 0.04082132150818195, 0.036415803977953534, 0.04233167939154165, 0.028178193772743856, 0.0035089810844510794, 0.03478791704401374, 0.03616872902161308, 0.003274123363163588, 0.02250214825783457, 0.04214322307546224, 0.04752367329118507, 0.0450865994207561, 0.06873907148838043, 0.05636413980807577, 0.054887135313557725, 0.01995298549133752, 0.10674479497330529, 0.051871098045791895, 0.03219230007380247, 0.02125693641469947, 0.030063555908522437, 0.019399372162297368, 0.014821169166160482, 0.06456837457205568, 0.012846002072495009, 0.025351910519280603, 0.058653537317046096, 0.023930771509185433, 0.04461226612329483, 0.005155788543301502, 0.061491102911531925, 0.020399924633758407, 0.06549331279737608, 0.02325835687640522, 0.04035206025998507, 0.04462444921955466, 0.019855262877951776, 0.02359699334816209, 0.05960568479661431, 0.013795517684359635, 0.03633775209475841, 0.03634539918441858, 0.0400336068123579, 0.02272635997672166, 0.018498623710391775, 0.06303495328341212, 0.039190927387348244, 0.03267484364498939, 0.025505705570269908, 0.022423217671790292, 0.08060694073459931, 0.041350734885782, 0.0644279924620475, 0.034876099455037286, 0.020051286555826664, 0.008694433058345956, 0.027337919754375304, 0.015736599419532076, 0.02659222503591861, 0.04907269749258246, 0.015561020001769066, 0.03222479172317045, 0.07043651504708187, 0.02399789897858032, 0.01766316729065563, 0.04612091409840754, 0.0591055637757693, 0.037817304488271475, 0.052248129421578984, 0.053839752051447115, 0.061132008608962805, 0.06247520260512829, 0.017365721287205815, 0.06062353482203824, 0.020408028038218617, 0.03493363243926849, 0.03291354547919972, 0.07593129162809678, 0.026413278388125554, 0.008568625032369579, 0.024169203625725846, 0.03494145255535841, 0.019230177759059837, 0.03530394971104605, 0.0368104161960738, 0.07335346245339938, 0.03454974785979305, 0.043162246966468434, 0.0639729058103902, 0.03100293335903968, 0.033791396766901016, 0.03755972580984235, 0.17671349405178002, 0.10115866722272975, 0.0911178213677236, 0.15430716850927897, 0.1489311491272279, 0.15419804650757993, 0.09420143054532153, 0.06439875438809395, 0.1328118983656168, 0.08702159366969552, 0.11116459566567626, 0.08641520727957998, 0.1714048803384815, 0.14245669011558804, 0.15002972446382046, 0.16918079182505608, 0.10570953373930284, 0.25312260325465885, 0.09691580132182155, 0.11926738944436822, 0.17503923603466578, 0.2205564236002309, 0.25067358038255144, 0.13082388575587953, 0.08459436534238712, 0.2784309009356158, 0.15139556117355824, 0.1254829873463937, 0.10459320114127227, 0.16759805461125715, 0.06188379826822451, 0.10768354138625519, 0.09174231785748686, 0.10356335461671863, 0.14449263443904264, 0.1694160806281226, 0.25941237860492294, 0.08090962842106819, 0.14386509811239584, 0.14366041123867035, 0.19629141422254698, 0.09866679486419473, 0.09887876241867032, 0.1871555508779628, 0.1678057677511658, 0.15061118826270103, 0.08028965097452913, 0.11876644061080047, 0.11885139319513525, 0.13798655569553375, 0.14545516350439616, 0.21762994277690137, 0.1438984956060137, 0.15894437182162488, 0.2752573112291949, 0.15919871388801507, 0.0714315255837781, 0.12864821750138486, 0.25742294107164654, 0.06036285523857389, 0.11816904480968203, 0.09031947742083243, 0.14088282813983305, 0.1348198734756027, 0.11314487297620092, 0.11509893169360501, 0.10380249749869108, 0.14741726964712143, 0.15321166015097074, 0.10602333582937717, 0.15371248684823513, 0.13716950453817844, 0.05310317175462842, 0.14436641335487366, 0.19082816237849848, 0.14216414652764797, 0.06600180015500103, 0.15141352878085204, 0.15554648557943956, 0.10139279573091439, 0.12484588367598397, 0.18717449557568344, 0.1363804225942918, 0.18676969515425818, 0.07540034476135458, 0.10709994698741607, 0.1600691114685365, 0.17960728305791104, 0.0955691739384617, 0.15793832152017526, 0.09630356595984527, 0.24014334114534513, 0.105777726508677, 0.10571614945573465, 0.10529695052121367, 0.10665435982601983, 0.08147217466362885, 0.1153251552688224, 0.1315987320350749, 0.22700530184166773, 0.17349818801241262, 0.2008181113217558, 0.12022079899907112, 0.15641572965042932, 0.06181409915110894, 0.11604681797325611, 0.16830484382808208, 0.2329441931630884, 0.120154791112457, 0.0784828547122223, 0.1344114632478782, 0.04240467618884785, 0.175054489501885, 0.09251976292580366, 0.11521627753973007, 0.12132272629865579, 0.1513189545699528, 0.08317521613623415, 0.1856224417154278, 0.22074479849210807, 0.10683559652950082, 0.09240213209497077, 0.10914433228650264, 0.045487996989062855, 0.13527386768587998, 0.15510908833571843, 0.12924580329230853, 0.1409094945660659, 0.155810842822705, 0.14235583267041615, 0.10954881379646914, 0.19717011707169668, 0.08072145030434642, 0.15363638236054353, 0.1794978760715042, 0.0895759319620473, 0.12681601010262966, 0.1394172739237547, 0.10093294576342617, 0.14590359372752054, 0.17216091762695993, 0.10573019513062068, 0.18558774143457413, 0.17585225669401033, 0.1090048390573689, 0.14649930676179274, 0.1421260807131018, 0.14336926543286868, 0.149963377309697, 0.13406072849673883, 0.1129997411210622, 0.2006458177098206, 0.1698812163834061, 0.11006946050162826, 0.11512114693011556, 0.12169199862650462, 0.10112494403230292, 0.07548953140420572, 0.15259265979485853, 0.12227701794888292, 0.17453611588903836, 0.12466641116355147, 0.12769874344979013, 0.1560308781585523, 0.23750139719673566, 0.0954228342909898, 0.08485049195587635, 0.15306140535644122, 0.15067986957728863, 0.20000830691839966, 0.1358491839574916, 0.1593642764325653, 0.1291774341038295, 0.12485536959554468, 0.1288442869803735, 0.13441892713308334], [0.06361797771283559, 0.02271748982769038, 0.062175235844084194, 0.11638346633740834, 0.06341377938432352, 0.04940881320674505, 0.042214991724384685, 0.02260729913333697, 0.034969374271375794, 0.022450258988620977, 0.029591488918023448, 0.042766094473855834, 0.005156939084242497, 0.06953215678887707, 0.02118155117412763, 0.11339457386306354, 0.08147851896605321, 0.07319256144442729, 0.06359559284257037, 0.04886785116312759, 0.05887505185923406, 0.04406156710215977, 0.05282315392313259, 0.04871064138465694, 0.036090293766132424, 0.04722599658582892, 0.03157936242808189, 0.022713306659300412, 0.04627912810870579, 0.004941346032345402, 0.03162461053580046, 0.03851761708834341, 0.008003456251961845, 0.026907318038865924, 0.06269711069762707, 0.05956702187125172, 0.04191106231883168, 0.04788015862660749, 0.02258018996300442, 0.006240530247201345, 0.05582921672612429, 0.023036553956834332, 0.08464236490960632, 0.036427946362112246, 0.05920011763061796, 0.03292843593018396, 0.09494202437677554, 0.030263092701456377, 0.013157057792081364, 0.038271600646632056, 0.02646339837727802, 0.012982684470314, 0.0659623026315655, 0.030802497507206032, 0.022148877482063005, 0.0786894957668015, 0.02715945317010794, 0.003179784943183352, 0.02986633631267718, 0.027788930106908083, 0.046639484486409595, 0.049818505865654776, 0.015363264363259077, 0.02277114668062755, 0.037130762756403, 0.02254035317205957, 0.06061170117131301, 0.021636459710342542, 0.02090353671727436, 0.04078738118654915, 0.06001672774021115, 0.028369739119495665, 0.019818630468632494, 0.0359743864142469, 0.011057329480536282, 0.02749812017594065, 0.0034264368753481123, 0.05956186500510999, 0.010615698178298771, 0.036823966540396214, 0.06840134425354855, 0.034352080430835485, 0.028254396648013165, 0.02671487532955195, 0.07748435650553022, 0.015182002214714885, 0.03160306365628328, 0.031020256358065774, 0.009040228074549564, 0.060340843562568934, 0.018662042084283063, 0.03450713246794684, 0.01622909031409238, 0.027690796979836056, 0.06651110853999853, 0.0497701500675508, 0.018601019733718464, 0.013082288322038949, 0.043761641053216796, 0.030304554583770887, 0.0612897001472967, 0.030438819700585942, 0.07460689305194787, 0.06332221108355693, 0.03247309822056975, 0.009215873649476894, 0.049250317604414055, 0.06495773832180671, 0.02311457191327853, 0.025089526116581898, 0.014869438451049584, 0.01957069377281836, 0.05988861354334014, 0.012065737691175724, 0.014677519910037518, 0.03001387696713209, 0.024514099583029747, 0.04110370064154267, 0.03013454084949834, 0.016914861908714687, 0.06669870311660425, 0.030628270070467676, 0.040750842075794935, 0.04593874440927591, 0.0032951982367584215, 0.03781854281468051, 0.04704479041642376, 0.03490955801680684, 0.05565346258559397, 0.08296297038240091, 0.028739530526633774, 0.01252085148423378, 0.031247490950460945, 0.003504314671902518, 0.035325248925281424, 0.040288817403571944, 0.07310544433338301, 0.0541484583435314, 0.07436392323247024, 0.04467122403106519, 0.045213499039943726, 0.03988300257229379, 0.040145860253168006, 0.007172139744008226, 0.05216966023934739, 0.027924698178789446, 0.040657248347997665, 0.019307381473481655, 0.041568269820085595, 0.04891817471278565, 0.0712842834847314, 0.008249634693908905, 0.05833360127040318, 0.028065361880830357, 0.043801172503403256, 0.04886209379349436, 0.030958058445581367, 0.021849034553659812, 0.02984462658475552, 0.03414525277912617, 0.02888715939064111, 0.0174172611108848, 0.025058657862246037, 0.0033585447818040848, 0.036833605130336115, 0.02941797733572977, 0.01941617438569665, 0.052482461490269215, 0.005429763172287494, 0.034388728107192686, 0.08233236707746983, 0.012265878380276263, 0.02371536208582776, 0.045427777006157806, 0.06008839460888079, 0.05437631379546864, 0.020575761894828508, 0.03228289806949241, 0.04994492372497916, 0.06198592457388129, 0.02924429951235652, 0.030789822473057678, 0.025563384439530115, 0.04165789411802377, 0.032024759599672895, 0.029499269223638942, 0.05943117916051831, 0.025554790793518935, 0.03868417029402085, 0.01987868081778288, 0.027210060008136288, 0.038860270487410684, 0.055440714715846946, 0.058531489223241806, 0.03777415644643562, 0.014274975617549248, 0.04531457700899669, 0.04069245074476514, 0.10224851659898247, 0.03277462561215673, 0.0382485372413482, 0.04547249924923692, 0.06489988642611674, 0.06753006457750287, 0.01241060989975397, 0.009777442801610699, 0.01637376076541841, 0.026159641998154775, 0.018570813051025783, 0.01404212021069335, 0.005625045550654509, 0.030472970368074517, 0.011459147740554596, 0.034758092037269046, 0.019110087238784348, 0.022497233967962008, 0.011979514550018524, 0.06111761688121727, 0.044937264041176865, 0.015081073523366025, 0.051381314505956004, 0.038388054219207594, 0.08409182195152555, 0.039310505613684654, 0.029575492454958812, 0.03612927221027868, 0.029515157121100595, 0.02142646160375859, 0.06433660736573593, 0.04824767354875803, 0.012629864072161061, 0.024332983319514563, 0.01991387303652508, 0.012225723526041423, 0.041758317300783734, 0.044201196038297245, 0.042392489699912925, 0.05590399807052953, 0.038319247375641546, 0.07212219280855996, 0.019252231843503456, 0.0589320623715009, 0.040207444091460535, 0.05544752720743418, 0.05685473758993404, 0.08177760363157306, 0.024025483123425926, 0.03782483622697847, 0.00553129830430927, 0.07132455453808818, 0.06347371438252074, 0.027062970579468777, 0.03334234229155949, 0.010613083273970654, 0.046316854655742645, 0.04018042482701795, 0.07242297381162643, 0.022996539050447087, 0.003150937450949901, 0.030227547644504478, 0.040914725246174, 0.021324993477069905, 0.043627430219203234, 0.04339125592793737, 0.049289506394416094, 0.026615812609504377, 0.03866241306864789, 0.017691455415583084, 0.01638037308917514, 0.022930578661284277, 0.015636915839942436, 0.0340771617900048, 0.06045949898127999, 0.03124392864161304, 0.0633660037336605, 0.008782894516895925, 0.06328502057918481, 0.015440608873697264, 0.01962397912783282, 0.03487869145880852, 0.03468534290524466, 0.08143549306052071, 0.06855712910848004, 0.03429892060479947, 0.031115733020539795, 0.06901275858815227, 0.02812224856045629, 0.0723276057147554, 0.033320934511721134, 0.06516381619232041, 0.01891724080113428, 0.00814960166878466, 0.0541326450849218, 0.008807387934731585, 0.04335786182699459, 0.048143820371478796, 0.0615077813022903, 0.043154993427119086, 0.02967268581103001, 0.06853874759482485, 0.03960500677515354, 0.05193029344081879, 0.03758955081658704, 0.04341725738985198, 0.028334183884518485, 0.08467035447912556, 0.03309003922290035, 0.05530066508799791, 0.05618370377591678, 0.022154590746920024, 0.0072201240441894955, 0.0338655538590891, 0.12143392461751189, 0.027599466166325977, 0.012911884430130678, 0.008632721994737429, 0.03292847324960998, 0.006531673084412302, 0.022718315944075584, 0.023163456968697052, 0.027043203158038, 0.023465866455808282, 0.05091170041954943, 0.020044781101335372, 0.0357986729858177, 0.024504086102492044, 0.010301022474387926, 0.024934801472617046, 0.025675508958686675, 0.013571691034095628, 0.04309049867359655, 0.04081235466791051, 0.047062181268951724, 0.010745710576884449, 0.023057366322193826, 0.07450776587107352, 0.0704623604459422, 0.030389602163008282, 0.008854344254359603, 0.013515810282634837, 0.04445688160402434, 0.030150995323700563, 0.04045706694679601, 0.04507015851725425, 0.020054367104811326, 0.03527416541640248, 0.01526683266274631, 0.030628748437655822, 0.016301028596769487, 0.03838368784636259, 0.01811171625740826, 0.030841258820146322, 0.16614802527640546, 0.08934959982122694, 0.145290768040078, 0.17467813326844148, 0.09344901663384267, 0.10001703883920397, 0.12783149204083852, 0.1455099619925022, 0.10976062528789043, 0.15353239008358546, 0.11575861700943538, 0.11171800204153572, 0.04945437344057219, 0.15887947673244135, 0.165952254352825, 0.21970586638365472, 0.1571008057466575, 0.1465138816939933, 0.19994019557322773, 0.1770843948636736, 0.07376835947590214, 0.13561983912118844, 0.14249016903340816, 0.09587288621280875, 0.1366411428898573, 0.16277494627450192, 0.17140056485576288, 0.13360030177448476, 0.13235727990312235, 0.09342192951589823, 0.07455865599747215, 0.06892372122300522, 0.08128325694373675, 0.08051328254597527, 0.19281913340091705, 0.08072269880878073, 0.11630975029298238, 0.1568595322647265, 0.08408232246126447, 0.09616597941411392, 0.09005148322986704, 0.1464814477201019, 0.20893328157918795, 0.07509270376924958, 0.16487277299165726, 0.11614437773823738, 0.1898177694529295, 0.1484984066337347, 0.12114518082567624, 0.11748269306761877, 0.07491190132818051, 0.16811956305588993, 0.17809881828725338, 0.13871117681264877, 0.10026953529034342, 0.1590216162481478, 0.1474207030343158, 0.10904706429157938, 0.09343866897480828, 0.1918145894472088, 0.14772657305002213, 0.11722407623061112, 0.12378871254622936, 0.1651891331587519, 0.1257337603185858, 0.11922928291772093, 0.2171418046844857, 0.07646430124129568, 0.1892379205673933, 0.1330481914005109, 0.1336541503135647, 0.11468398038830076, 0.10321468939738614, 0.11434681633753435, 0.1102097611874342, 0.15933671434010777, 0.11434183589049748, 0.2056246226919549, 0.09969541324036461, 0.14126550831965037, 0.17825834187013762, 0.11315109514232193, 0.1542756709137133, 0.1177867581801755, 0.10268729805414166, 0.09915938414633274, 0.09596010510410581, 0.13133185064154013, 0.10344578485403742, 0.07644439980919872, 0.17606239898928575, 0.09617655777505466, 0.1308107493179185, 0.11174092973981585, 0.23592811876109668, 0.18976423303995812, 0.1546751516205924, 0.28789285463946207, 0.1262679166559662, 0.10301872169865028, 0.14869410970381328, 0.15468078346124717, 0.16541671380400658, 0.16202660357313498, 0.09957069850393704, 0.1494734478848321, 0.1311439914362771, 0.127001697995833, 0.09338828096432344, 0.07821146784616367, 0.13439124290432247, 0.10733323411217757, 0.14124900634799684, 0.14855283871293068, 0.10630377435258456, 0.08578697206186396, 0.20162436020161423, 0.13062237442604133, 0.15171767531761102, 0.1133625130834324, 0.13479459126080784, 0.1520974649382489, 0.1270778974784272, 0.13203583072338784, 0.07280517901693072, 0.11353889826153006, 0.11260943420763526, 0.1696660800703934, 0.15304335632494517, 0.13638758792408875, 0.1210702977010182, 0.1139106811689479, 0.1415803621390036, 0.05743456272674458, 0.09730717353522778, 0.11415846858705793, 0.24426242868815148, 0.12180649462555136, 0.0972630280469145, 0.12148747460118361, 0.1337453725614718, 0.1275199359016759, 0.13463786324220045, 0.09993041705872331, 0.09053909206496817, 0.10251630722944226, 0.1807550521833556, 0.08742755438600268, 0.10835257012929235, 0.07848714305354015, 0.14491836088044302, 0.11063711611287934, 0.1612150485494307, 0.10972416081598826, 0.22224759071000985, 0.1552078423223325, 0.10113371070474386, 0.08956390832151685, 0.20733560302427836, 0.12061603207673345, 0.20683920037533554, 0.11501278488763741, 0.05481080351663487, 0.20211457461118698, 0.07770290584968668, 0.10288324539682694, 0.11582538485527039, 0.1244805875633444, 0.11210968638105051, 0.12434508412012032, 0.14778641983866692, 0.059261321489300044, 0.14220998835350784, 0.1415261471910136, 0.11218503090952124, 0.13862378150224686], [0.020230872722874795, 0.016469256087605442, 0.012965169785145138, 0.05238529188292367, 0.044381781348160336, 0.030349582167608396, 0.05224458407610655, 0.04101863609892981, 0.028766135884714977, 0.04125993332958647, 0.050828396675309966, 0.0455594127997756, 0.03866971071277346, 0.03965126590004989, 0.11101299737180982, 0.03876215432371412, 0.07834622490086726, 0.07145154236682824, 0.052626344840973616, 0.020441568024190407, 0.023516668372654488, 0.05662964038284762, 0.026023987580889037, 0.0407651659500386, 0.03427173509927733, 0.02415256425073104, 0.0017190072955729971, 0.03753181766452534, 0.07983405542160783, 0.04497363351817642, 0.03427116173718657, 0.07266223204455205, 0.011617933416606059, 0.04309659191806402, 0.012125329181019748, 0.06965012688721929, 0.035126499232969115, 0.04612948399569307, 0.07035845637853656, 0.010897159593046775, 0.026815887141440595, 0.06398834248206445, 0.022377579406436, 0.042015902764563046, 0.037002984434366226, 0.026438635241772448, 0.08503098227083683, 0.05821364984980651, 0.035838075514350615, 0.015034515843061464, 0.025973039779013822, 0.03545830285708819, 0.038069498991327624, 0.02590489450709096, 0.015742767302851592, 0.04063669212960771, 0.01853835872108383, 0.02800919784099928, 0.03844504776809897, 0.07462076230772904, 0.0453328974545002, 0.03511377330869436, 0.039248117711395025, 0.016538755036890507, 0.03769371611997485, 0.007814216227935893, 0.07267249149403401, 0.043808819593063424, 0.009453687450981565, 0.033492278174630234, 0.02847863720463855, 0.05489421243380223, 0.03969959116407803, 0.04001987326358046, 0.05885034639920507, 0.03551787144637533, 0.04686831024342349, 0.04018167672412736, 0.04392545637009399, 0.0648995539439576, 0.057573716688369, 0.06393392397356884, 0.03308860072866082, 0.02076983478452478, 0.053202309113528044, 0.02252041102786149, 0.02939728880301118, 0.011398306898107486, 0.05073627536850316, 0.014260731471170272, 0.051994452319507084, 0.05571151804178953, 0.009913185428428863, 0.047659441363066435, 0.018259000764893632, 0.02353751127208982, 0.022048525545479994, 0.02004966824980719, 0.04616439462240253, 0.05583788161831243, 0.05932093079068831, 0.015638488344848156, 0.0493717855507774, 0.03636931415115084, 0.020200163924268315, 0.03272438009402581, 0.05165183623986585, 0.04811333040041583, 0.03314550606799977, 0.04605730822575944, 0.06707253519977842, 0.047756682216588936, 0.03702281801296132, 0.046537453175655434, 0.04145896800660661, 0.002756149449851364, 0.02926800074055791, 0.05534903784947736, 0.08197505053664957, 0.00582520108270858, 0.024919603984536867, 0.045415614265948534, 0.061293588152953556, 0.050968178281826634, 0.025630827427708676, 0.038409940366234095, 0.036013833047556024, 0.015621769241988659, 0.10409294441342354, 0.04573047826332705, 0.02795923900391374, 0.050489526108971665, 0.039886866829224994, 0.04667634929397276, 0.05111785292891519, 0.08965100507651057, 0.00851954659447074, 0.018610844920788492, 0.06723171272980315, 0.04933707169922335, 0.03737188356795481, 0.0286153145134449, 0.024885242971192514, 0.01440747145430318, 0.005635522979511214, 0.028178719637383307, 0.08009671632732664, 0.034134511569780965, 0.06462938844093255, 0.03341109145964895, 0.036087223395173035, 0.03357039112597704, 0.05051547668075987, 0.0059545782028830475, 0.0715275179328663, 0.039882229042372534, 0.058720488367336135, 0.04333898837545088, 0.05616874547143068, 0.05671818241743105, 0.029377896272178208, 0.04397283507777112, 0.02381504905809249, 0.011382757419986385, 0.0609541442245245, 0.05684834239738328, 0.024259043358532444, 0.0475255189064358, 0.0238972773243274, 0.05711722546922309, 0.008597564550914934, 0.027841776110497967, 0.02747304321798895, 0.00127724431513343, 0.01783632094572697, 0.04829025501385331, 0.03871782563094582, 0.02104550151021353, 0.005778297773628894, 0.02994741446205548, 0.03353058147643294, 0.012769889103115668, 0.056570947103734524, 0.023886476743168066, 0.024465033019493734, 0.032067005189933946, 0.05120607265936477, 0.005606738675851375, 0.0007435588174433048, 0.00923471911145108, 0.034283853734710386, 0.002963979000924155, 0.03887060796841979, 0.03591027164033481, 0.037597937509417534, 0.030917597402419363, 0.028807445096650293, 0.05324120952614716, 0.01663827067906303, 0.018985369109681675, 0.06021493460450854, 0.055063605308532715, 0.03528941209827151, 0.021888739030276026, 0.0630884218428816, 0.03646750495369945, 0.031197343819907734, 0.06057020875492266, 0.013795684773607977, 0.04248068228896175, 0.028261341453929032, 0.015078055738870586, 0.08224692594792161, 0.03365562530234456, 0.03141525873382177, 0.022377496285896217, 0.024775135397378887, 0.08350896715585675, 0.028373303124681115, 0.02745191703018333, 0.09320119528898171, 0.039361487342310805, 0.024917422494451915, 0.029821074634258236, 0.09696009608783893, 0.012032168019296867, 0.02079268784395286, 0.06786336097866297, 0.03649796778336167, 0.05123308853113225, 0.06850195742611374, 0.041757835540920496, 0.030507239779191356, 0.03113232659442084, 0.00872161177851792, 0.06103962606617382, 0.04482072904439909, 0.02069870735119496, 0.03362187836319208, 0.00843261692872537, 0.0158163866560374, 0.0022220365811205867, 0.016122823248484304, 0.011104891392668443, 0.01977830513247422, 0.041163961336548836, 0.05745809432119131, 0.0352459383596267, 0.03467137526188578, 0.04355403308623603, 0.02678763972861426, 0.02701956808700093, 0.031519712414592505, 0.05449819225551827, 0.024171324047659124, 0.022784742826063718, 0.047125318952436955, 0.006096579042995083, 0.011943055167128997, 0.019465251127257943, 0.018464384833350778, 0.05940676547054734, 0.037790515925735235, 0.04619601435427155, 0.07852631488016673, 0.03336843874837671, 0.0627270137358989, 0.04988311257745538, 0.10855724343231746, 0.007860940997488797, 0.04225567329142775, 0.02232980714844806, 0.0074837968152548584, 0.02818523526989988, 0.009432798750432474, 0.04763567228136318, 0.03846649286736335, 0.04322851269638964, 0.06879585129874093, 0.05981311973716531, 0.029155526775866747, 0.028614785256130353, 0.036917017440178564, 0.030050137878528664, 0.03949814768774169, 0.06620987291846957, 0.04351210640743375, 0.03436952895884003, 0.0023176481024295625, 0.010781222555254186, 0.015352555384327258, 0.0075847823339115295, 0.0417151115834713, 0.03870549325698188, 0.08911728978689228, 0.029106417803892067, 0.03598350253222244, 0.11649755521544389, 0.015570356643625667, 0.028415949050603167, 0.08457898973886456, 0.03144433395937085, 0.017322783591225743, 0.01695598621985742, 0.01992707732798798, 0.023063540990863527, 0.021941021849800433, 0.030300164462200234, 0.033009680320641825, 0.04365322472793715, 0.028160789349515523, 0.05849119781383446, 0.00707095829836492, 0.02057000622153282, 0.0278592059787895, 0.01929464706751917, 0.035841685320649824, 0.050742453429847956, 0.05078397638031414, 0.015332913491874933, 0.05503011621268732, 0.05966016437326159, 0.06074894166418484, 0.026281584919031178, 0.09512685053050518, 0.04827229758458478, 0.0288111057930759, 0.012706738697098834, 0.030669518214251314, 0.03681542717718652, 0.049865049975258965, 0.07899436833603041, 0.028208800791097537, 0.014713731627645237, 0.02235811054041343, 0.02768396243586072, 0.04812354574512158, 0.019015465530433824, 0.043999806844762394, 0.03144037810021213, 0.04809457229982529, 0.04092110686802438, 0.05294276946889503, 0.06646044911550623, 0.03415193634905985, 0.039017076537545235, 0.032189799672258754, 0.023710980445944836, 0.01999693929350802, 0.031438016798347235, 0.027545872077878033, 0.03844351767163191, 0.15381508134305477, 0.12746931718928473, 0.0930961784241455, 0.18636732388819965, 0.15786551471267427, 0.13804136775434017, 0.11185378368411746, 0.11733038909733295, 0.08097126654216222, 0.11216213713799204, 0.18035018390842847, 0.08251435695482151, 0.07245958077588252, 0.10046223245028939, 0.18385607935488224, 0.1291503741272858, 0.12800929535712513, 0.24769486593348639, 0.1339992939361504, 0.15058522751288755, 0.13302859530917235, 0.1563554485993726, 0.13261270762554236, 0.10373161773064307, 0.10159127400921923, 0.10491807013750076, 0.07453191493238721, 0.07562542839774064, 0.16866247249501093, 0.10508076926427228, 0.1805992741137743, 0.1188533745173897, 0.07631512531744582, 0.11700077035597392, 0.1143660731613636, 0.0653843197173306, 0.2647224850952625, 0.13118201653872216, 0.16332762661789144, 0.09213634314281599, 0.18510352527456625, 0.25140821667654173, 0.09946260787546635, 0.16681305744818278, 0.14597809687256813, 0.13256667580987724, 0.17198946539844784, 0.16363492155713694, 0.16794264183512755, 0.0665736762540681, 0.07325265250567879, 0.16329178639820643, 0.1694436427205801, 0.1474846074623721, 0.12411983763532979, 0.061530722571270804, 0.17434901664299624, 0.15270197178636277, 0.09338613679366452, 0.15444191199328217, 0.10471926616238696, 0.1431929413229227, 0.08832166676542588, 0.10823460003095013, 0.13015532520200523, 0.1550545748323202, 0.16705441235431603, 0.0755065626331738, 0.10015988403132983, 0.23026967953358377, 0.14406705727534636, 0.08200812233345849, 0.1586440929344722, 0.20560973563364573, 0.12296776659786701, 0.09676368055599076, 0.14431466827435152, 0.10167455739740815, 0.09592324029654264, 0.12425972441477434, 0.24205504570688519, 0.09467495299343552, 0.17647289910486766, 0.15854955943567411, 0.18217515812388488, 0.09247693379542657, 0.08523470562483583, 0.10964600036719016, 0.16534624115696975, 0.08285171778074332, 0.1117295032101018, 0.11084819478648049, 0.24422377933348927, 0.0890726964654667, 0.12616138665803842, 0.13121580758265086, 0.16523226084453718, 0.04923079615192754, 0.09479586793375866, 0.1286254051540579, 0.20292321193431104, 0.13910631489540848, 0.14533351574625286, 0.13888851872512273, 0.07390399184077978, 0.09161668709878411, 0.1195363878671612, 0.15284515624599798, 0.13528617631111825, 0.19355321329619202, 0.17480185734374182, 0.08685732712703091, 0.09273764052029167, 0.12794172683996813, 0.11714307272008487, 0.08854262490889855, 0.08353689565722432, 0.12652612637196267, 0.125081226761852, 0.08600502607545682, 0.18150173925927707, 0.1565700149429696, 0.1750765826020922, 0.17601323234183447, 0.18316250800022058, 0.08166132308542728, 0.11225831947688546, 0.1612548107015235, 0.1668936266962971, 0.11876101233065128, 0.08834147320262023, 0.12726931220718793, 0.15742879600397178, 0.148928095719644, 0.09657308685460261, 0.18956177176109382, 0.08439845871180296, 0.11141516507736274, 0.12894883565604687, 0.09455671148108584, 0.07838122373712914, 0.11787802114018373, 0.09151298659188406, 0.12112110640321459, 0.1659132657306535, 0.11447386523442608, 0.14600792527198792, 0.05148255871608853, 0.20288772455283574, 0.11138767762375729, 0.07783290637390954, 0.11982680085514273, 0.10173513700387307, 0.11862383969128132, 0.15992100084466593, 0.18521935120224953, 0.13629249802657536, 0.22103650069662503, 0.13314139497067246, 0.18778972327709198, 0.10119570844939776, 0.10200100738023009, 0.10407965191240821, 0.11648015757756573, 0.2018603411103998, 0.15908556138830526, 0.0776026930127825, 0.17648364709956305, 0.11082970470722232, 0.08801707918090479, 0.10709574007030044, 0.13579138634460314, 0.13820131202893599, 0.2074831843908344, 0.08964191270726067, 0.2720214048666613], [0.03436840259070907, 0.025847434465374266, 0.023721378995105624, 0.024717705889738033, 0.03735901175865105, 0.05994050111621618, 0.040573493377970796, 0.014550683055339115, 0.002650713801683326, 0.07921867165714502, 0.028690876173121587, 0.013950335626889552, 0.052290059493056366, 0.032954661308654716, 0.03746309903051172, 0.0706200926963772, 0.08651546761393547, 0.026881196136985506, 0.05353180232590862, 0.03723371008943234, 0.09119389192866427, 0.03565348006252732, 0.04355320188083819, 0.06151299923658371, 0.059598716241972785, 0.01514929173780339, 0.06401093769818544, 0.007383999581049595, 0.049327429716608355, 0.0012606476666405797, 0.013469317063157047, 0.02830142930283078, 0.011964956581193422, 0.025920762048502053, 0.015387233612792832, 0.06860084711973156, 0.083207120852811, 0.06711995801223175, 0.028164938591154556, 0.050919089665902514, 0.07267623700733696, 0.033668449614197016, 0.015917356059487377, 0.02722746443136462, 0.04055857239291072, 0.08806523481117827, 0.057132865701402934, 0.007088862293000732, 0.05596488980310304, 0.030994814687541554, 0.07620047325534479, 0.045000493326889615, 0.04925896553322673, 0.03479199503947582, 0.020270205701568296, 0.028536709624209573, 0.011565856702093567, 0.01482683832624129, 0.03656242521745818, 0.03280133953584092, 0.024866898776963353, 0.04722797790808337, 0.04337183964837875, 0.05402910064107605, 0.014101232485180455, 0.012095359985583594, 0.02796656378944005, 0.060610344101275714, 0.013058133323543837, 0.04313483075903995, 0.06917960356388773, 0.008879619683804256, 0.042626197516385994, 0.08805976581892797, 0.05587015952914953, 0.024515429511666298, 0.043665370504770956, 0.004569955827069602, 0.029626779524343352, 0.05765951744147709, 0.02254758126634572, 0.02125839187231447, 0.023436328130108968, 0.04536442897681679, 0.006249304977245629, 0.023787626065313816, 0.030910577957651446, 0.030120803908045803, 0.05779056969497885, 0.03816032090357371, 0.047044742918972454, 0.006603776760000203, 0.016758966791842664, 0.02076569402457348, 0.058164537485156736, 0.07901978625782899, 0.01570803139890943, 0.015303346328437328, 0.023068010840298872, 0.03924501341368471, 0.02522917540876993, 0.020863280930955495, 0.02728894309672926, 0.02993586240336299, 0.052061640857053657, 0.06167353383664574, 0.04886557128546493, 0.06661693286150694, 0.041477933060377836, 0.008808398951909371, 0.01243245363834181, 0.04580689826980233, 0.046767873489963155, 0.0442685915290245, 0.04453114726181541, 0.03794221939252956, 0.05015708126925996, 0.04277615036283221, 0.032924595421978405, 0.06663579613502536, 0.028511973630104746, 0.043131339696369, 0.11239805697862591, 0.03973091573321393, 0.07262544187584094, 0.02555049566685089, 0.03527728667748826, 0.007850294783046203, 0.01875662986588265, 0.0300626195301967, 0.02389432060798364, 0.029805190129471675, 0.012411874519394977, 0.009559270892558354, 0.0689197653638465, 0.02092388428614608, 0.008181394427083433, 0.027745349498997842, 0.012714806478470564, 0.05745158717036247, 0.032839490167264423, 0.03999153085585151, 0.06001126553331103, 0.045044849161058664, 0.032406941056251526, 0.04747514785932643, 0.020769787287073474, 0.012100128390427147, 0.04319769024316754, 0.03332411005560841, 0.026440567370238047, 0.05990627580987556, 0.023565551731735468, 0.004512684926989355, 0.032783388891922574, 0.02192702536870326, 0.04723082096981151, 0.046169273289186616, 0.032185253487633805, 0.03239344160205551, 0.04215504994083728, 0.05332590087449976, 0.03975113946944475, 0.006485007262589144, 0.0319550265558064, 0.058488687234265466, 0.03759808000177145, 0.046407059101121764, 0.05345464950161321, 0.07502549487565245, 0.010970454097592404, 0.06350552410419498, 0.04612759427566614, 0.06253621647400515, 0.0137145328335464, 0.057220647776765485, 0.03305032117558377, 0.02273668727970549, 0.017047788615205457, 0.03900708171672054, 0.019206244132614562, 0.019141428771295717, 0.06444230955094099, 0.04524390758680446, 0.0507691911022578, 0.047077427950820754, 0.03208669288350003, 0.057894494118435044, 0.03228061819182975, 0.03705161164647766, 0.01817335607483983, 0.07356444613209792, 0.044522797888410945, 0.028318090730213692, 0.06184879943196263, 0.052134671581110785, 0.016893574568842138, 0.04757781699299812, 0.01947496265971235, 0.0071841998557959285, 0.03183159764323916, 0.024710328517747775, 0.03255273787570851, 0.024579530714878013, 0.05740843912852662, 0.014786360319703817, 0.020712569821625948, 0.01733780126752598, 0.03392322933567422, 0.05632016734619226, 0.05222911687035646, 0.08270668092050723, 0.05278365979237216, 0.06538070991103138, 0.020950241978945475, 0.044789343407111507, 0.0248941351726119, 0.032111581547984054, 0.014154181965360684, 0.01976386081826474, 0.07851112926644938, 0.0816125160615359, 0.058545650249081, 0.028008124059332267, 0.05599883691008602, 0.027608757007068822, 0.046084564977458546, 0.03623176831752062, 0.042529543595654626, 0.038213548583111594, 0.03888183093762823, 0.0020220152717748924, 0.04909445811063051, 0.02926242657537971, 0.04395791070003595, 0.043174199360821924, 0.051584946257727485, 0.04260203488437193, 0.03290068384792123, 0.013960757076607218, 0.047347830941102335, 0.0191664650171463, 0.023480122476550083, 0.009586599738603192, 0.043615009635686874, 0.043308281273181946, 0.08312752869512353, 0.05824277935815709, 0.02863032031538231, 0.04622947970139129, 0.03689251554065517, 0.01638133660890162, 0.025468547296311175, 0.09430264761405331, 0.018383072589391043, 0.022357696634052054, 0.010458000702783465, 0.059414561837911606, 0.07363824360072613, 0.00908128368402166, 0.012232824395011579, 0.028783692978322506, 0.03610480084483113, 0.007652577312131013, 0.049246606017862044, 0.06611925456672907, 0.02385896723717451, 0.04515809665567108, 0.03292828325980476, 0.009482716027248119, 0.04190560689728175, 0.019854207755997777, 0.07706893022571291, 0.011335310858807393, 0.011530648368144674, 0.018829697909365808, 0.06881295038121087, 0.012276436385166432, 0.027660359595237032, 0.021374236459710767, 0.04820746695622802, 0.045198815542140176, 0.02881334156596235, 0.05359201891613858, 0.051686814720077176, 0.034615294342594485, 0.10161136543112141, 0.03545510017180017, 0.011590453596519572, 0.05291829810344747, 0.03576974703797272, 0.022361330189076916, 0.05387545317145331, 0.04207605150129114, 0.04081811882289393, 0.020393398823216558, 0.057161024904676845, 0.03908372563975198, 0.0700569629137005, 0.020124210410618355, 0.066011550703219, 0.04350505642858999, 0.028804116882383823, 0.04664541148979749, 0.03642210417560168, 0.055038292559662035, 0.03905549179762602, 0.033913122556571446, 0.06732406813119139, 0.04085725672276957, 0.056189854695860825, 0.01650287919411702, 0.004612873166999114, 0.09374563821724483, 0.03998413821682334, 0.018628290056117942, 0.017369999450498393, 0.05823713394680193, 0.02319085451641253, 0.003555706490130563, 0.027005435898900032, 0.022935781328539764, 0.049386808316090276, 0.06318159148629222, 0.032576259292129955, 0.004772977321408689, 0.04569085860358817, 0.05407680843823722, 0.024241878118898188, 0.027297657182706252, 0.03414010948368481, 0.02603396204566317, 0.016000150902462856, 0.03784393359507833, 0.03872794937342405, 0.040170382508741956, 0.06562462967953511, 0.0376807900278696, 0.06491535702454192, 0.031988094959940226, 0.022201894815745096, 0.01700127503967711, 0.05403327702411583, 0.025776047492399812, 0.09015592333993741, 0.02593600024868335, 0.008073643066122063, 0.09130306142781462, 0.047747477889060974, 0.04765173659792968, 0.048166860028037, 0.08133570770067827, 0.16922469304076262, 0.1499222716582673, 0.11234786574329649, 0.12659889246736253, 0.08070803566702775, 0.10908076034060546, 0.1164770634578807, 0.08133849647960492, 0.1168531347066164, 0.21803525888494082, 0.09773014512445245, 0.12763034711991036, 0.12104135139712266, 0.14821473828383855, 0.1782104101564203, 0.22274601539330824, 0.1324600236756461, 0.09636166212814194, 0.1489280550075429, 0.10420023437057223, 0.10675823675202471, 0.14675694650837354, 0.18409866919474943, 0.0843069107670869, 0.09080049768090248, 0.17970975541642734, 0.11658873675124985, 0.0866275073162147, 0.1706217559320586, 0.13018208662314074, 0.12314003306840147, 0.15639863056795938, 0.10902911704033613, 0.1616047719227416, 0.10392265247979335, 0.26495942952377455, 0.16891015134751797, 0.16264516966683523, 0.10395641638232128, 0.1346515425081764, 0.2644495783107621, 0.08443830907344818, 0.15331889582531794, 0.07758306978004319, 0.09830970223993063, 0.19492466827588423, 0.16541062055953912, 0.06562266192798104, 0.11819298352513995, 0.12217839966927256, 0.239449606942279, 0.10376708475606782, 0.125683955848217, 0.11709835726235594, 0.10111093906951801, 0.12838588229247502, 0.17345364897378854, 0.09513957984745502, 0.10130361587341342, 0.09834740164556674, 0.1296530600105013, 0.17692640476993152, 0.16149754981909478, 0.13908290543726512, 0.12331145815551281, 0.09075946666832481, 0.11300785639988524, 0.09223365184984036, 0.10428520731095757, 0.11906912151191916, 0.23911213076540402, 0.14042137004435062, 0.11394588356571538, 0.23716264537402562, 0.12076613759355885, 0.16440007835626602, 0.12348770084125654, 0.10224745129900319, 0.1309632568487099, 0.12451093164937836, 0.12042039686015674, 0.09633464964904956, 0.14728863297828607, 0.1606722069638116, 0.08421883692166635, 0.1285948303661176, 0.08857561528150525, 0.06342845609677689, 0.18350400110440596, 0.1817496352429901, 0.18607528241617338, 0.11314308164375168, 0.08368582052311727, 0.10138192559991564, 0.15127176924475602, 0.11910284470234599, 0.15426286017256124, 0.0896329153329134, 0.12269382844013826, 0.14669252639370306, 0.12207921142024653, 0.08151610980608634, 0.11224020937723772, 0.1242526676505804, 0.10610879731497594, 0.13467599691024848, 0.124969268483775, 0.1499706647757973, 0.13207795417734555, 0.14852804504334927, 0.17017548345029354, 0.13180299821708882, 0.12164824668850217, 0.13790305517613888, 0.2596894380237375, 0.12181850469538144, 0.1564541890152863, 0.10625970350312335, 0.09577208305043833, 0.20793404376932553, 0.1407439455922161, 0.07843964560223476, 0.12944359625024454, 0.1465097697717803, 0.12866515373545034, 0.10166631319693156, 0.08888412479843412, 0.09245004345263753, 0.09252930991351604, 0.16394543275237083, 0.1378348624067647, 0.07674028178943054, 0.15559844779116766, 0.08675670716911554, 0.195213344214218, 0.11464586029095308, 0.13427758828869887, 0.21442809887230396, 0.10203479842415877, 0.10617314279079437, 0.05550091095002634, 0.12609665441725934, 0.17495516554585525, 0.09269637202045747, 0.09432271867990494, 0.17625141170408043, 0.23721869236656598, 0.17722991348377296, 0.1216461703713451, 0.07059319556823798, 0.11614208428987435, 0.10334606056234666, 0.11714854171233517, 0.12372854006077562, 0.10737022784139429, 0.10484296988163676, 0.07502735406160355, 0.13474554674965994, 0.12819167199943746, 0.17558502246226582, 0.13331971397357328, 0.22192027898771421, 0.10308031910764319, 0.11020919800336872, 0.08565826753952674, 0.17913362490279333, 0.14957593381404877, 0.07704248771603618, 0.14260599496109144, 0.18821695606623376, 0.12266532996935503, 0.17639645534966672, 0.13485899780477795, 0.20704348012804985, 0.10190940515271255, 0.19245800349329198], [0.008846976212225854, 0.020818909829748527, 0.029368250896888118, 0.06614727127764906, 0.012391482845747044, 0.06795157731643744, 0.048944332237754545, 0.02582670352421701, 0.025768325763887594, 0.044422147396419726, 0.014112476658608233, 0.02549876076435404, 0.016449028958699534, 0.018050044209563305, 0.04900692370054977, 0.04033667787111231, 0.016430196219256947, 0.05555791806961809, 0.04598676772522075, 0.059415925693299086, 0.0486422348767519, 0.024696328643975512, 0.03418340341054967, 0.05996269599667617, 0.030603747814893723, 0.03234366766576256, 0.06630849119807992, 0.041299776905881505, 0.06642409999455724, 0.03031288699379989, 0.04452095227316022, 0.016382695375276462, 0.09092881543827908, 0.056428943295031786, 0.026363300891327004, 0.07405681149767977, 0.021678844400282418, 0.07180862820574216, 0.05840271006205252, 0.05128667244155492, 0.036682237538376024, 0.02640489169529506, 0.058146461312259944, 0.023704313839386617, 0.028813399241438935, 0.041550214003239355, 0.04051409102976322, 0.047928717985217056, 0.03741555408175502, 0.0409538801094251, 0.03289950319698878, 0.04068477312102914, 0.037980454840830395, 0.05915869306772947, 0.019886365226869072, 0.013405272687253143, 0.031101751806480542, 0.020839645859918425, 0.024712716961013417, 0.07736766205302306, 0.027794516146449105, 0.0105695094514106, 0.04552236818043249, 0.032943414590720616, 0.037050030659884214, 0.02810050660212125, 0.05840213330728667, 0.015580405747251851, 0.021797856049878255, 0.031576020643115044, 0.03222740747566734, 0.045737066838358126, 0.0666849220703755, 0.049021502025425434, 0.017847951035946608, 0.03861036604004247, 0.04371467964457614, 0.011883746117486485, 0.02938143483230046, 0.04316410275974444, 0.03246035872559462, 0.020736357563042214, 0.08976494467684201, 0.01647538156248629, 0.02846873059336628, 0.03884750045835972, 0.04415583936497569, 0.005093837023845741, 0.04125267639756203, 0.03735079809225031, 0.021429721964523196, 0.06292764297021286, 0.004983323601274086, 0.016563954131145562, 0.009442293999849685, 0.013103098142892122, 0.08039538030113492, 0.0332477036198335, 0.027372845648122684, 0.05636088962533644, 0.035007331520318985, 0.020370584779552052, 0.028270237048023512, 0.010386640871209758, 0.005586569646506437, 0.09192861643220697, 0.06400470196136407, 0.008829569244491202, 0.00869387072244925, 0.03085638675838709, 0.020829092944040895, 0.015578156403665031, 0.06087841293109315, 0.00783428644561874, 0.0602701266429254, 0.06919649230050189, 0.04295279677691204, 0.07952454167285136, 0.02967739145138434, 0.04682039888575673, 0.0350601860055966, 0.09060803122286286, 0.011072959534690847, 0.06673107602234397, 0.058590528555214405, 0.07117312587797642, 0.015417038263486964, 0.03618116317582982, 0.04721748436401997, 0.05418034948940788, 0.010979956132359803, 0.01743553575527455, 0.026925194043932215, 0.021749091434425542, 0.05521306282441531, 0.024319522881082127, 0.024488583273653473, 0.045588993533913574, 0.02479066706395575, 0.016666597819754055, 0.03162339595811708, 0.020446299109607935, 0.010190802942296224, 0.03479234448501042, 0.08253329486719199, 0.031088618761194602, 0.00906343651669366, 0.04082874807396105, 0.050859595715467415, 0.014218463828521115, 0.007158693724444934, 0.012249338241027934, 0.038900395655738454, 0.07947581607316222, 0.023379999545535872, 0.0183486064031188, 0.03525913247306432, 0.032411242968269756, 0.013163318973965943, 0.03702618354665382, 0.07806150482169219, 0.06781611458531447, 0.036256171829466305, 0.0667159514767783, 0.013512582152283617, 0.021416346342968087, 0.035983790909605365, 0.04285904698606048, 0.06043760944157839, 0.011072718654759228, 0.07170841536883797, 0.02139546612410673, 0.04643857705273798, 0.013839656387322714, 0.06971812288143805, 0.008268169726112058, 0.050124762646321736, 0.03431061854852097, 0.04161455947905779, 0.030020954087376595, 0.009403101817172552, 0.0218526799830475, 0.019463196862488985, 0.026639934529417326, 0.020262875827029347, 0.03637035570240446, 0.036509740365935225, 0.01187299981912864, 0.037718099275869985, 0.04513531144974487, 0.033596046535032134, 0.020570399771843637, 0.020212002664006183, 0.06538882518985442, 0.05477598788482802, 0.03337432164698839, 0.03320009421025004, 0.07074679554040943, 0.013443358857849879, 0.02915839697899563, 0.018042071423094188, 0.06030845030077866, 0.036803447641432285, 0.024628945027611086, 0.04046040873176285, 0.0405776561903102, 0.006228536292577961, 0.034029019730431695, 0.050010008803967915, 0.045616348673190386, 0.027810244588181376, 0.07704065567148582, 0.04347245282094393, 0.04492883663624525, 0.054102918465754817, 0.01408672031746911, 0.03475811917866979, 0.02886692886906011, 0.03200523475451129, 0.07180092683328049, 0.03570744734523552, 0.016297966707497835, 0.054507016603435786, 0.03218307199754885, 0.08209267458213226, 0.08005676418542862, 0.03514400543645024, 0.05621274168203984, 0.008117284742183983, 0.03404984736282911, 0.028098783123173883, 0.0581794177581157, 0.06848393553601843, 0.059549067834658284, 0.049161100427487066, 0.14128012396395206, 0.023796397826767395, 0.022554777130218487, 0.07409955241850444, 0.03789195351834808, 0.03665762707324965, 0.017484446255756275, 0.06692456028291158, 0.02044560870022646, 0.02999726982255067, 0.025696770853496025, 0.01894233811513654, 0.03358144446143082, 0.07013608009687491, 0.0647263510950974, 0.007354757266252169, 0.03502913624314325, 0.03055970071415816, 0.04609031895441668, 0.025927150455702628, 0.043501171815608225, 0.022563918693257228, 0.02776690316386521, 0.06289073066519839, 0.04103127720632723, 0.03366169479808637, 0.03551203943789005, 0.07407139321523053, 0.03351619653403759, 0.020996594402406896, 0.046419483077313216, 0.040961734152265956, 0.07595400219517094, 0.019981991167047193, 0.008591571390362722, 0.027062565154795135, 0.022380098467692733, 0.1250959781131574, 0.03546189230733684, 0.019472063618845174, 0.06021492781915835, 0.02394387571673308, 0.04776455322280526, 0.00942060717248491, 0.010015636582725813, 0.039170143859727044, 0.03876951642866645, 0.005614779315822358, 0.015547817406643714, 0.014186973866474415, 0.020876437724967088, 0.018330932262220552, 0.02070461230219475, 0.03620013162227614, 0.03162881066756589, 0.02722537115083209, 0.011039508606440254, 0.028745016482259547, 0.022441075017143573, 0.08659784176519938, 0.03936014384297388, 0.011672582627008004, 0.06715119776449033, 0.011901434677253877, 0.049442163202911615, 0.011560842328305756, 0.0556046996664788, 0.04390452356476869, 0.03395251490707908, 0.060200746437268596, 0.036574689737920246, 0.01074725594038942, 0.014883916692009993, 0.025614656241876737, 0.03713912230783275, 0.04621304897591472, 0.02464200513038252, 0.01694555883295834, 0.03582733430500541, 0.025742063065990806, 0.01633827168760555, 0.03367935706462179, 0.036674329212733676, 0.03151316115898745, 0.03614066820591688, 0.0909171107092074, 0.01911318475114448, 0.03557459358125925, 0.0043159992533868975, 0.02076482041073697, 0.0072364326333627105, 0.030963466369679997, 0.03622531205681818, 0.054855634325316975, 0.01885223714634776, 0.09168312246245996, 0.06105905930910792, 0.03868788527324796, 0.015868576176996742, 0.044014792290649245, 0.04337409916999085, 0.05402109732053109, 0.029153911862522364, 0.024428309007946934, 0.05261952217136111, 0.034046247734555175, 0.009091451531276107, 0.02254510291719011, 0.04408564152462142, 0.040119366853364875, 0.049850213807076216, 0.05709149542131594, 0.029426292782383304, 0.07305742441011326, 0.011334957172428923, 0.03193377483902233, 0.015964558348059654, 0.10361241269856691, 0.149723813736013, 0.09118807688355446, 0.14387964590319566, 0.12189196289650031, 0.19812328235379287, 0.18843845703772136, 0.1618796328880957, 0.1385454921317952, 0.1563161885631936, 0.07421567011624575, 0.08167028653302363, 0.10273676325700112, 0.09470454390559878, 0.1585100551268884, 0.1297932860574552, 0.132174211155091, 0.09277084802410432, 0.09308287913777999, 0.16627417850707257, 0.12660160660743713, 0.1415428662938731, 0.09813100325741939, 0.2883890265864985, 0.07940602196114403, 0.16770607738622598, 0.18819541936474188, 0.10573933499732188, 0.1098333845979401, 0.10760904502655778, 0.18502476092960152, 0.09798108094504901, 0.24803972457136425, 0.13394982873329095, 0.11403302103281021, 0.13336897561592714, 0.14697752467223577, 0.217396078897374, 0.17695993797055312, 0.11109080498239823, 0.15279164697442735, 0.08816941707794156, 0.11455647008759634, 0.14163170009851456, 0.09655131266585418, 0.08243978595627205, 0.157177561627967, 0.09271119122526475, 0.1361189151981047, 0.28670172712632586, 0.15613142347761563, 0.07910781260579824, 0.10322220756539277, 0.14109482962105954, 0.09952772688120604, 0.11891898885369301, 0.16496669580893858, 0.12022059543856553, 0.1127684081771544, 0.23955279854791506, 0.1590425694095237, 0.10376912714647395, 0.17774319808397973, 0.10724994393863849, 0.12971483383859905, 0.09139370692095586, 0.08376533804195267, 0.11333767870174986, 0.11063676327466965, 0.17380605292107376, 0.08933210718844618, 0.11761104475174632, 0.15083689615130424, 0.14013162202068738, 0.08938534504600934, 0.08991484663316182, 0.15485627975847038, 0.15363722374396666, 0.07344692386686802, 0.14537220581301621, 0.08431030344218016, 0.10153496917337179, 0.20413195421653135, 0.10995941569230386, 0.11044432395803076, 0.09737943751471383, 0.13265990652143955, 0.11091017217508384, 0.07212755323520728, 0.12256965653172561, 0.10105316859803029, 0.1555993434573923, 0.06539305924837079, 0.12972009927034378, 0.08621831677321877, 0.14716037628906115, 0.19014916595603737, 0.12192062421568803, 0.09587726954902921, 0.13051573586251053, 0.09252004112516131, 0.1523455644824675, 0.06004420840846641, 0.046277306242180724, 0.1855496891907283, 0.12482388557067939, 0.13660898032997335, 0.08083557989448309, 0.08300436780388866, 0.0695252153756363, 0.05099058011546731, 0.2016989854829652, 0.15422163238482817, 0.1049665514645832, 0.15994764012949808, 0.13939850564513886, 0.17807477100619248, 0.1631814566041742, 0.16155460104346275, 0.13276680292827742, 0.0886094673935856, 0.2047164849936962, 0.14825604749577387, 0.13849370633917196, 0.06599353559847389, 0.14458414167165756, 0.08698332429464374, 0.14073743165603705, 0.2683435822171824, 0.1885424086025783, 0.0892310868948698, 0.08483393570142132, 0.10810691331114088, 0.08280451209949595, 0.222397614802633, 0.14231845896158898, 0.05289231360490833, 0.25195731435503277, 0.11224107111671142, 0.08270628058484622, 0.12358346927378859, 0.12007525323757104, 0.10814889427274466, 0.06599200889468193, 0.24493045998471125, 0.32734041075621334, 0.09675376037401812, 0.08475319003420216, 0.08259234776986496, 0.16163325682282448, 0.10313059176717486, 0.24538510558860643, 0.16603614842253073, 0.1114829642964261, 0.1631174571812153, 0.18021725889827522, 0.12913845905235835, 0.1720027375434126, 0.13867859356105328, 0.1073608844141875, 0.14436255927596772, 0.10962455187525068, 0.10438379166381699, 0.1262621491083077, 0.10508840956858226, 0.1317223339740719, 0.05794585243399654, 0.0966311762375491, 0.15268643333443574, 0.20191382324056967, 0.17155917920172215, 0.13255267084709235, 0.16773848421871662, 0.0690745459869504, 0.08143618516623974, 0.1241483496768134], [0.006924422299821994, 0.026449976954609156, 0.06721576715686492, 0.04151960189587303, 0.08807473430143935, 0.09545080350445849, 0.05070830615503447, 0.050186573793845515, 0.0318954342177936, 0.008558271436153777, 0.052999990327017646, 0.019701033564550535, 0.05317860449265156, 0.011087819451599248, 0.026032854337245226, 0.028884492748017822, 0.08444478908287627, 0.024436989167172993, 0.03173703021769013, 0.034395913793040175, 0.052906905500484366, 0.03778966097161174, 0.05512751652193921, 0.04193219868466258, 0.03605101337390287, 0.005587654878451888, 0.0766131446829864, 0.02775187530953969, 0.021675634929644208, 0.05517886805215052, 0.012088659452274442, 0.04593643060486231, 0.013632896589115262, 0.033926628796117644, 0.03225317145032542, 0.030317558707403283, 0.04397278418764472, 0.021155498822086623, 0.017645815453891243, 0.02560683273311172, 0.03181876315336142, 0.009586949184137796, 0.017229644481890967, 0.0602012960506337, 0.0254197114346815, 0.029368278038288866, 0.04924697581944721, 0.01306014009086149, 0.03218239006985511, 0.006304295151494443, 0.011096349484952433, 0.03218979288690856, 0.04956084576302341, 0.0040665138013926995, 0.029018187895417213, 0.02140665516656424, 0.010074822647896196, 0.037937520537525415, 0.025269677164033055, 0.055814919993281364, 0.03463147061743906, 0.03949018847197294, 0.0518025694015835, 0.021583315151344453, 0.03738462645560503, 0.03363099108849253, 0.033608711391155205, 0.01661776195812438, 0.060509255954197476, 0.013860893685237637, 0.02612033107184938, 0.05235698000927057, 0.04425822012126446, 0.0452610066692744, 0.04122340778953262, 0.03375492211697357, 0.05351396703294345, 0.023085204917671423, 0.021822018681892326, 0.009963414831353086, 0.018781167388494526, 0.02416838938370347, 0.03630607468741281, 0.01954557610276554, 0.03526606370827981, 0.021857677393459847, 0.048192644358745644, 0.033930072361337285, 0.03136714381564941, 0.033401585184037685, 0.05820187048188277, 0.023923877593395964, 0.024346377600782683, 0.058708295093051026, 0.04747789253347686, 0.061234433470027785, 0.04095514557723488, 0.04375264367886952, 0.021150204552603618, 0.005588669712389154, 0.020975503837689757, 0.014090280081810696, 0.05518335995397397, 0.0395608443234648, 0.035099819236035855, 0.0086100071868194, 0.01284594100434333, 0.018726681026497057, 0.05350989582283156, 0.008952491800300777, 0.030288710791085447, 0.03568629740870424, 0.03015934469710503, 0.04914714974750366, 0.014028805657289922, 0.013733011886610516, 0.0049492191589836565, 0.0396789738775364, 0.01920765039644071, 0.015037467470392585, 0.057960773419056616, 0.05527855841709035, 0.06517178219343935, 0.02488069678656757, 0.007335692128565694, 0.045343967753329446, 0.06127047046486821, 0.009442558628506958, 0.030435053831232444, 0.025896226222227727, 0.039389229246548245, 0.0819350712533508, 0.017148330541593686, 0.04246479778417519, 0.039971914408462386, 0.026478134461545517, 0.07910650981856243, 0.006524021329823881, 0.051747350221765895, 0.07363578051860843, 0.09557227484349694, 0.03948857355862856, 0.012270816418874477, 0.056752156665814776, 0.017254606088889495, 0.04338435861947281, 0.025263723019244413, 0.0398791824201388, 0.035136806179902384, 0.09377432667783328, 0.08398544123130185, 0.05196077662653156, 0.020190793355660777, 0.008776725785407637, 0.05370274904583182, 0.03897551626765302, 0.013387724075333347, 0.04146968885990126, 0.025328083762100766, 0.035403799531715255, 0.03967718933043735, 0.05788412610335009, 0.07016833086631127, 0.0016194851861135767, 0.014715770625376275, 0.017035810775788765, 0.012488893333024212, 0.039172986921455176, 0.01803323350447629, 0.05446922220289707, 0.046795676462352276, 0.022456320002675056, 0.011775297561793454, 0.09162523664001908, 0.016700434664796506, 0.03910784077431474, 0.04557742790452071, 0.023595449680994664, 0.07826706700559173, 0.019319108254941444, 0.012227093318610318, 0.1010222884693316, 0.01917127243775342, 0.019106090667524507, 0.016587333055213094, 0.04928276854168091, 0.012837870678465282, 0.023714710692209855, 0.11991590607379164, 0.036231401908610544, 0.027182075527629683, 0.04455161187797785, 0.022481856668101888, 0.017252468703580753, 0.01846100063994527, 0.027578514701287662, 0.050333819285567315, 0.07256051285990647, 0.04347046471333929, 0.021133003689880882, 0.011587069403114063, 0.04059335070529154, 0.025188171537593007, 0.06783207372895309, 0.018122318367074643, 0.12768074870109558, 0.019523069096196975, 0.020651287931416715, 0.011023353535815008, 0.03487680513145668, 0.043192350172570775, 0.03022291325032711, 0.10788644371288163, 0.03808851832790034, 0.0646584297397307, 0.08226096483745746, 0.04707296997574823, 0.020074967427977493, 0.04220112246860351, 0.0716365585103631, 0.014103542896918952, 0.047659309048737795, 0.04981952027550765, 0.056551815808883736, 0.01933084860710161, 0.043511482155216594, 0.021340906819594756, 0.0558573216465967, 0.03311903641692229, 0.025675437712509717, 0.08225423377007246, 0.030413232145032713, 0.023218703289915408, 0.02617881230876914, 0.03378430607595614, 0.04272038835499968, 0.03669011193726744, 0.030617264232465198, 0.016894594067707658, 0.018924954047958766, 0.035028695195381127, 0.0638462979612606, 0.02193889464251697, 0.04469949519261718, 0.09777524056179182, 0.02761854657105037, 0.043478987113173516, 0.06677497045270034, 0.0329451312843178, 0.014492576709017158, 0.03619953451145973, 0.009683059428685477, 0.04252337231966002, 0.0306914145393031, 0.021189198263787797, 0.02031842918534364, 0.019464978016912937, 0.03078105240794165, 0.01791404713211315, 0.04400489925007735, 0.07758446756218161, 0.051415533026946444, 0.021214621274599006, 0.034145076360021315, 0.04377498444435852, 0.009000409943317729, 0.0409221518119531, 0.030263876409402916, 0.0772113615114774, 0.06116242054849863, 0.03487172968951719, 0.03022361553407141, 0.03299398919833558, 0.024606724702087895, 0.038018503692001104, 0.03766681559916053, 0.03526891355535813, 0.011526031785511544, 0.015827709709161093, 0.03840146207117608, 0.0073547513290707555, 0.05108454364484974, 0.03642086245651756, 0.034293146271790774, 0.031672905265752754, 0.02078869127269302, 0.07441438588180713, 0.029994769421006953, 0.028898684307932854, 0.03667427492993219, 0.06459605880081654, 0.009845273402918662, 0.006705920877201217, 0.051908556571496386, 0.0342440881899425, 0.024088283235739385, 0.02168659327019538, 0.014290746467720186, 0.04096564929932356, 0.013849188956165952, 0.04984512818711145, 0.02862950268068484, 0.052594219600515704, 0.07097335838313613, 0.026991006851728474, 0.03354070182623608, 0.04051994339429906, 0.036368106358817646, 0.0162773019235049, 0.03119542356580496, 0.019097797273259078, 0.0497546828618007, 0.024459876153352003, 0.013804459079567875, 0.025396198499947786, 0.04686412028968334, 0.11437038864408221, 0.02685403438018901, 0.014971520651930144, 0.025261880796668783, 0.033751414090927155, 0.02740068593993783, 0.029193216003477573, 0.0768330782385809, 0.05417450051754713, 0.06950133094297987, 0.06887278359915529, 0.0557730815240315, 0.025998008171362535, 0.020376123321641768, 0.038683949770139794, 0.02760888932139746, 0.02542772832592683, 0.012574545656596976, 0.05120257141866854, 0.04525818396359682, 0.02385703510870891, 0.08781295549124479, 0.027474381628313234, 0.02195076221999313, 0.02441158311973725, 0.005616178794298321, 0.013196702896883445, 0.020527345028572848, 0.034496004493641, 0.06058325019798108, 0.010493671288713813, 0.06533942105514662, 0.03464276822549956, 0.08298322465270758, 0.0034730369640913394, 0.0538925760026489, 0.27068865352443283, 0.08462492655962706, 0.1511624843946525, 0.11894336183156286, 0.2863646580704621, 0.15466065811259405, 0.11276552440332514, 0.2061421549213784, 0.07615004453275885, 0.1291262861341238, 0.09565439115145377, 0.11357907431998424, 0.23180433575596127, 0.08405937440693378, 0.11292200136397566, 0.09666607329355818, 0.17779459032629216, 0.1256130217973675, 0.1201052444853953, 0.1404793169349432, 0.11908162012696266, 0.172182169343744, 0.10583232822162764, 0.14925658809287207, 0.09875912990953241, 0.14095692416386946, 0.15047577981437954, 0.21737094596028328, 0.08857409536306347, 0.16463140451482364, 0.1133909233446632, 0.10815202231918063, 0.08628668596169778, 0.17076793951647623, 0.13785848899611405, 0.15296180998640402, 0.12091601240847792, 0.09733715121235166, 0.1399966206933771, 0.11231049203446933, 0.1514910581920828, 0.198478156168546, 0.11157210344182593, 0.12380707370383398, 0.11347702265317951, 0.1420483070292643, 0.07965048455766269, 0.12821630282061441, 0.1424465120903083, 0.17550498247146606, 0.07697662232177598, 0.16927935582186493, 0.1281043038304363, 0.136631453409791, 0.1481637124504362, 0.12621181538062437, 0.0916798926357712, 0.1623767412134579, 0.07437913598758833, 0.13002488363002027, 0.15012341657919542, 0.08812968885259968, 0.1369851737150124, 0.05791313347539731, 0.15452942943998746, 0.1925774392272745, 0.11269150980349098, 0.12348440316106592, 0.14884333312511444, 0.06727242483092205, 0.13069223639156136, 0.1943384547318731, 0.11692068965307303, 0.07998276994164501, 0.1017858235697661, 0.10209764433758599, 0.1308816290859665, 0.13317146764269897, 0.0662152808425682, 0.0738314360912357, 0.10639929851250989, 0.08902827956314598, 0.06106130526001964, 0.14380830473133496, 0.18857871022607597, 0.14718925473945482, 0.15818043638552937, 0.15103098430803844, 0.13362183847597667, 0.1299026794731617, 0.1528067375932421, 0.10248086734541825, 0.2129820864647627, 0.254058520176581, 0.17282186501792499, 0.18533897692603724, 0.15723848050194128, 0.14880871426846298, 0.15511541228209222, 0.10169316961296967, 0.09582760757101433, 0.08297220524400473, 0.1435826646962336, 0.11867352202534676, 0.09567200592053787, 0.11325189830469233, 0.09502069372683764, 0.12553166544863156, 0.08359695957707507, 0.1085026010072657, 0.11337773940925087, 0.14669042293514523, 0.1806401897753988, 0.09902328359229223, 0.09283781264509473, 0.09500736729907137, 0.11364846131099121, 0.11470245011150837, 0.09539223236164876, 0.0813732985407114, 0.12329141423106194, 0.15463309602013656, 0.11343840722526823, 0.13639296192143643, 0.17360857208924635, 0.13736838315214428, 0.11664141821009771, 0.15617710245507105, 0.11979710816272668, 0.09797057043761015, 0.09607692169291632, 0.16862100043467113, 0.07621087519718067, 0.12597143756491797, 0.11169967481068202, 0.1384978046906846, 0.16815665178000927, 0.09402947620089565, 0.13450888730585575, 0.2461223474570683, 0.23229277240378515, 0.20075844095221587, 0.11450773770255701, 0.1951288123215948, 0.10295557044446468, 0.11961450081850801, 0.16181624414665358, 0.1523320209234953, 0.21351316225315842, 0.16367169815514768, 0.3015258716685431, 0.14792542452258722, 0.08499130832829646, 0.0670671204903296, 0.13629776345832006, 0.1147722170821258, 0.09272355413330452, 0.18642114528587886, 0.13930379572723592, 0.09222418628633022, 0.11602845681565148, 0.2728012858756951, 0.14178704390568392, 0.10553989998464074, 0.06661700750035898, 0.10677577688225678, 0.13377993713532174, 0.10851180194211857, 0.1627672923994916, 0.15600940931056226, 0.16294799984565803, 0.11484813158001218, 0.15041011119527475, 0.24181413863386425, 0.07244524333093848, 0.13320672432226793], [0.02485555876046419, 0.02036743807340307, 0.020838339680007527, 0.025954895752615163, 0.03986188316983836, 0.02882018798430051, 0.01190639307190265, 0.013332698277996054, 0.0628435860521027, 0.026055290097636834, 0.010950819838659039, 0.015912436680602174, 0.012855292913237852, 0.050935625564306974, 0.031755581365099976, 0.02609516929702035, 0.038387189087058814, 0.020772267332566634, 0.02569982935009258, 0.01585176377557218, 0.011799617105030587, 0.018806544598191977, 0.053322637121060064, 0.045695649060819826, 0.01845380138339741, 0.1238113349037511, 0.0550929315920387, 0.05748104916087218, 0.022013167085658227, 0.020826051410819803, 0.06218241474458149, 0.021042271683524762, 0.044603536770279915, 0.029071174695023468, 0.025184305584324256, 0.041621772306306024, 0.031409318159733496, 0.011407475602546973, 0.027988334585513388, 0.020536632476640598, 0.0713085343262979, 0.022215377306565642, 0.043958986178040504, 0.044585966105972014, 0.09169638782207455, 0.0038425137006145504, 0.11699345574847289, 0.07154615050447838, 0.04745899533320751, 0.02805560963627483, 0.032669333940637965, 0.03287311836278864, 0.022415490854265432, 0.015034911089709826, 0.06025219974773271, 0.016462287532963922, 0.03475066886416503, 0.07719886289643389, 0.023684470082766244, 0.02619607254330601, 0.0497681382112205, 0.04598864048187222, 0.013931546144054403, 0.023953799291380813, 0.016673856448116045, 0.04436715891850846, 0.020161229584898268, 0.031155026983469725, 0.05176688524495278, 0.019365986543042318, 0.045013646728226116, 0.04775727932740535, 0.05219466086210949, 0.04283039245222296, 0.04347554694062897, 0.0152258474512824, 0.022851919489247457, 0.07555603462138347, 0.0429053264670074, 0.0459016455071313, 0.05303613588746105, 0.001297463068372703, 0.008064195314156157, 0.03838570309536798, 0.04282843487869416, 0.07143477576651744, 0.04340916585975459, 0.04170040772961719, 0.07282594218850136, 0.062436471826263835, 0.06464825171445097, 0.0234604602280472, 0.03642287092017276, 0.033613301680556366, 0.0329548716545105, 0.04763156035915017, 0.018190919953797544, 0.02562183514237404, 0.045521703216114213, 0.03234842758891838, 0.04439420871702688, 0.015987586130255034, 0.01776520029774734, 0.0038230842744399396, 0.07640186244887964, 0.04975180248064654, 0.06096810847520828, 0.038279532721000056, 0.044519035411732535, 0.019619027518534234, 0.01151291570360107, 0.004160667744664741, 0.05642734195238777, 0.039538347494921515, 0.03778157961953964, 0.032440894948584695, 0.06353831770164625, 0.037411703395524194, 0.020816456925656115, 0.039023230850164375, 0.05590781143733433, 0.03915308888203331, 0.043296193171824725, 0.07344118346061025, 0.0318840382221554, 0.0196918886088367, 0.016394026910087893, 0.030463236783232008, 0.04382791696116328, 0.041856721841863224, 0.017203273218391196, 0.03156880781586681, 0.027855277261031524, 0.0134165397612378, 0.042196956263589006, 0.021751773344086747, 0.035042628911989074, 0.041923560933875184, 0.007390876533463597, 0.04221475084445306, 0.011285098419258637, 0.024151190217318277, 0.03497120292325105, 0.008003044041938015, 0.02113665929729385, 0.0458406011041786, 0.04506320014063801, 0.039651242151324234, 0.007110553785293762, 0.0392254885685231, 0.04183356683435185, 0.027820171555504203, 0.0033364680088457783, 0.007488588968824063, 0.056102140474000146, 0.09263153121407543, 0.07529884949326515, 0.05859096960297652, 0.030551429372280836, 0.009520151652395725, 0.05660075853977885, 0.03797608168263521, 0.023095630608232956, 0.06480405692543302, 0.05273883916171534, 0.03636209453855242, 0.035514604300260544, 0.032441342781697, 0.0657054635563067, 0.017973362967105846, 0.02183401687735958, 0.02843928726256958, 0.045583629714591165, 0.018407988395275812, 0.03205071695681129, 0.07225022558122873, 0.08442436517881495, 0.017399256184164966, 0.08033460391951458, 0.028623192305011407, 0.053514092561921904, 0.026411500626376698, 0.008228622160718908, 0.027124912344983647, 0.060109117068350315, 0.02303188224323094, 0.0170196022705308, 0.011364034942484327, 0.072940580679902, 0.02149101403275771, 0.03459772028561149, 0.04209887741931847, 0.01502759478587125, 0.035192008396344523, 0.03828131387542401, 0.007568766362965107, 0.022236596792936325, 0.036139721649565866, 0.030383013587977205, 0.011940297770446964, 0.029079256047095572, 0.07406576137457575, 0.022433699341490865, 0.03464527880506856, 0.035660655570349524, 0.02246645901219121, 0.012740327028690704, 0.03291109936045749, 0.02304855893765177, 0.014334910615746464, 0.019490889572937573, 0.04862020963004657, 0.02122771360778383, 0.027972592573080744, 0.031919043843767474, 0.055291857703455856, 0.015885280012818317, 0.033250668817864995, 0.026726530864834785, 0.06852211670151778, 0.01356195320840925, 0.027132376230188777, 0.0216197134660823, 0.032484093880546946, 0.028201286015766006, 0.006966913859027305, 0.03176524709644062, 0.01832656080036291, 0.021922184021345208, 0.010503401480881231, 0.006005526004758264, 0.03102128773129412, 0.07811267314744846, 0.02687708251843495, 0.01633562200835773, 0.028243210998230746, 0.05116984906739422, 0.03754129679873586, 0.04754997670118298, 0.0250552617944777, 0.06549812361065831, 0.04352658634473171, 0.0536956278208111, 0.0021918850293981707, 0.06380682757922582, 0.06290580092796258, 0.029505677986890078, 0.026922976930758784, 0.018004390677171092, 0.03710217946874244, 0.027517641628427163, 0.026094087033665607, 0.05550058525321739, 0.017761079893846596, 0.03495892483208861, 0.030403702120695795, 0.020779010274314454, 0.021090310266507522, 0.05314206877457244, 0.010785594865280603, 0.0419146144496543, 0.018821082210966518, 0.03373645578644105, 0.015778422621744018, 0.06359160305666071, 0.07543821380074535, 0.03947920299002102, 0.05839879491499492, 0.03989644774368831, 0.0630866644371833, 0.06616619561931916, 0.022089763511238352, 0.0424167473268296, 0.054905635570841174, 0.04037377338058182, 0.004421834601089358, 0.027209659672475288, 0.06344828967537199, 0.05246662787560906, 0.03286833469090717, 0.07767541161073105, 0.022659305449841276, 0.06978169482733522, 0.022428503459585563, 0.08306703729821102, 0.02877324353903532, 0.026702093426138163, 0.04655741567590407, 0.044972354479666264, 0.04457721300423145, 0.023976197732346397, 0.021383510337078145, 0.03403772533472095, 0.02562334149011544, 0.05271861881815961, 0.028287027397059968, 0.019262214789965322, 0.004896096228289285, 0.04330626602417656, 0.04021626504670296, 0.053798354629959376, 0.04080115544742771, 0.017638850291924815, 0.01932489955132561, 0.04137969136770282, 0.037041087568338425, 0.019050537309210216, 0.03448811313137412, 0.02843700908124447, 0.017560387895043408, 0.030717711163950816, 0.031207840756646225, 0.023929059904600893, 0.01310580040860389, 0.05330132094344922, 0.04616994843153017, 0.008375262059936566, 0.06434761320373841, 0.034634693658777645, 0.03481770133865731, 0.01865432714112103, 0.05204372753256133, 0.0463692409518574, 0.03183311416900583, 0.026051108625584414, 0.055472534615546465, 0.054398868299488506, 0.011647136715639914, 0.038617633150092194, 0.008179637021385133, 0.0429210413380393, 0.04473569842853716, 0.09082097586776529, 0.05514589125024421, 0.007257443470215159, 0.055650734874819, 0.03689674959917154, 0.008494562086915331, 0.009545048798567482, 0.04905121846656714, 0.0071171580514471445, 0.026543190702795982, 0.03918147539453847, 0.0847460450604558, 0.018993587865095054, 0.054546958567308526, 0.06600252618747098, 0.0027702379572604385, 0.05879499829773392, 0.029930990521929095, 0.06088200916669198, 0.050114513374865055, 0.16824023372360639, 0.1315189227461815, 0.1786710132977792, 0.169632153319461, 0.16987603237586363, 0.10864421126565763, 0.10689169780484267, 0.12165111010628087, 0.18380071089736053, 0.08804563193448953, 0.1611820174647229, 0.11111739676977907, 0.17268416312124046, 0.07437259491000857, 0.17229081637093, 0.09100413282534905, 0.1030532591310995, 0.14560487547091075, 0.13751377963594028, 0.07313734904995986, 0.09870960363852126, 0.10506400266396147, 0.12731252131717546, 0.11222935281693935, 0.08920165883111102, 0.15029891287641867, 0.14705223137778894, 0.1602227317967585, 0.07655720625604902, 0.1349762486560004, 0.17581588721701077, 0.07775437951620136, 0.19246569808040345, 0.11041885853878089, 0.10126352802451168, 0.14199145936540195, 0.0909423114998, 0.11695624488805022, 0.1339710940207754, 0.12314019591680594, 0.12625141468431267, 0.13249076131199086, 0.09709945360996894, 0.11937066247420651, 0.18739299742238863, 0.09398039776299681, 0.14624029637447425, 0.10128815206033842, 0.16864345994378838, 0.1312454595629658, 0.13236330529408796, 0.08961247785815171, 0.1237271965614387, 0.05066313947151814, 0.18991579062172345, 0.10387972835451365, 0.1538400650024414, 0.08528007926153285, 0.14320526351886137, 0.10610917729458638, 0.11384144345564501, 0.06314311855073486, 0.10917669162154198, 0.10406437130378825, 0.092192668334714, 0.06446185814482824, 0.10690119050975357, 0.06228283114199128, 0.1324031895824841, 0.141508586704731, 0.19653025854911121, 0.0935068346027817, 0.06941443096314158, 0.09907263344419853, 0.19313386508396693, 0.1377215063465493, 0.17363954042749746, 0.12293816890035357, 0.10084051572318588, 0.14286778734198638, 0.11662193068436214, 0.1304943755801235, 0.19044728710183076, 0.13495640829205513, 0.08887316645788294, 0.12334476065422807, 0.14777639109109128, 0.14594836346805096, 0.20882460741060122, 0.12411640424813543, 0.12987882218190602, 0.0824924809858203, 0.11384527039315019, 0.14257052115031651, 0.13910913760108606, 0.08327161560633353, 0.12595777186964238, 0.12163466241742883, 0.07886197936854192, 0.09757060118551765, 0.16894369811883994, 0.1751117171453578, 0.08237335059259619, 0.11201905445860964, 0.16429407761565276, 0.0927061497100762, 0.18789196493370192, 0.19184896403125354, 0.11783288499074322, 0.22186428627797536, 0.1015354170064841, 0.10685994915132012, 0.207397336140275, 0.10513239899384123, 0.20678233914077282, 0.13792901592595236, 0.13521018038902963, 0.12585026478128775, 0.11062063449727637, 0.07313374602901083, 0.10917859830494438, 0.0892183847193207, 0.10864391949559961, 0.23889749656830514, 0.10049931438905851, 0.07081146671303681, 0.11308244096913508, 0.0941219740946378, 0.11488379538059235, 0.21558145912630217, 0.09632807464471885, 0.23282558524182864, 0.09462833085230418, 0.06289657963705914, 0.15649715385266713, 0.0928796511143446, 0.10273463265704257, 0.13675710452454432, 0.10550479258277587, 0.07285512597965342, 0.10093618237546512, 0.12855158054402896, 0.08739374977137361, 0.137503072353346, 0.06877647233860833, 0.13398766384593078, 0.1761894885982786, 0.09611307403870992, 0.10571756080857345, 0.18986602686345577, 0.12175636445837361, 0.08797851125044481, 0.15842821023293904, 0.11358664677079235, 0.11456983722746372, 0.1574334100420986, 0.14059811484600815, 0.14027292015297071, 0.2837762369641236, 0.10317170420395476, 0.14836545448218072, 0.10170895233750343, 0.11834853089281491, 0.11612598943923201, 0.14399530898247445, 0.09634106859032597, 0.19886420188205584, 0.15164712124637195, 0.1407145243138075, 0.2145984654447862, 0.12004017297710691, 0.05917286766426904, 0.12370572771344866, 0.11765102403504507, 0.07494018945310797, 0.20709768150533947], [0.10817464467670236, 0.036909892822482755, 0.0719208036150251, 0.06890545506030321, 0.005742961366195232, 0.0342712465540639, 0.004519432109581041, 0.015787070550556694, 0.02154522728441017, 0.07379009973789964, 0.017663548966603618, 0.04075098456814885, 0.023216333506362777, 0.019847871935261146, 0.008067858555088086, 0.0391481762884983, 0.05016094891886626, 0.05393543566710182, 0.03230099459843976, 0.03270031584958945, 0.005862940352277032, 0.00715860042587987, 0.018565289775973985, 0.05113778828776308, 0.045541950701070685, 0.0065822107966856235, 0.0383504973059254, 0.03323364098157201, 0.053396254777908325, 0.059934611432254314, 0.06491519417613745, 0.0804828027529376, 0.05185719486325979, 0.07784148305654526, 0.02671311792385365, 0.050329256137566905, 0.020030665876609937, 0.04655462350430233, 0.029508822996701514, 0.06948541929679257, 0.015733571457011358, 0.04756074505192893, 0.020319012725459676, 0.0485710938727217, 0.011469197692349553, 0.06459575346005814, 0.02659767197578081, 0.03809545634846602, 0.024235567743224756, 0.04249561005937202, 0.07203792554459401, 0.015332745554457818, 0.03196675842627883, 0.012714087231350797, 0.03140442592224904, 0.026197395686592375, 0.01106732599769852, 0.031506749003061225, 0.06672496920717613, 0.03414801102397697, 0.03019681679350989, 0.016773818227063333, 0.03457197666700397, 0.022463729605078697, 0.059654858229415755, 0.02698962264029043, 0.02375451016372868, 0.02977984006117497, 0.049520920762526136, 0.007943858824936407, 0.058910281397402287, 0.019664691228951727, 0.020508832896926572, 0.042695679502295594, 0.027716727195573703, 0.02196639566682279, 0.022383552210937654, 0.030205254376466786, 0.018229920450331907, 0.031414522523326535, 0.020811656290399175, 0.019426674715110233, 0.09391118719109467, 0.036677935626357794, 0.10760806793613092, 0.03003888437524438, 0.024463960934164267, 0.030193285018737828, 0.03268878414694752, 0.04677005498004811, 0.04145911389163562, 0.05897332408598491, 0.012010963799964105, 0.031348389107733965, 0.021747593568371873, 0.04328175733930298, 0.07419369236699172, 0.03624717445511903, 0.02388539956882596, 0.042975921250347576, 0.006110472047501909, 0.04569973723430719, 0.03401776283447232, 0.013939088060786682, 0.07655321647013937, 0.025351405010691712, 0.014786568969222052, 0.03399394964799285, 0.0558461767089154, 0.014433800309364284, 0.0766544538949217, 0.06053813440459115, 0.033295923710933754, 0.014744058750303728, 0.032897844178868194, 0.04507972925369229, 0.07343964318611793, 0.01474363636225462, 0.012091870619250196, 0.051879742581929476, 0.07514727155544929, 0.031802810795072994, 0.051311815556670935, 0.03154271475172468, 0.021604711056819985, 0.03035817920629467, 0.05781521408685616, 0.02396937845540898, 0.04656968019636614, 0.02146070556981223, 0.07001883603100266, 0.01717660848849586, 0.015680382793237056, 0.03315630156014647, 0.010241220638688122, 0.03287366458347865, 0.0522812555011894, 0.04542886605486274, 0.024786631476932337, 0.007898973733452814, 0.0260126848838159, 0.045030094417078156, 0.07434218297047274, 0.030453649083418504, 0.04277064744383097, 0.05051039445347019, 0.029834781041634933, 0.013749355250703437, 0.015485056310093828, 0.00968059549839901, 0.06385818589478731, 0.09774265052484614, 0.022567033168992827, 0.017916243889236023, 0.06934029422700405, 0.05034109318096723, 0.00900632846501789, 0.03117992582597903, 0.06730464845895767, 0.02310003769317908, 0.031107247940131595, 0.0434591162151524, 0.06501565128564835, 0.06263596112174646, 0.04484215718028801, 0.04833084158599377, 0.015091707863445793, 0.017810628217245852, 0.05483490168782217, 0.026904184903417314, 0.007004407583735883, 0.017246475543028543, 0.11611927194254738, 0.040085504563259225, 0.039381836607520065, 0.05024190153926611, 0.004561122149295572, 0.028690696361341646, 0.046943033912352154, 0.07405858247407845, 0.004965765659497785, 0.06980116199702024, 0.01728644804097712, 0.017629779975063035, 0.06333282337124858, 0.09592277889272996, 0.056782493966498544, 0.03695310532514538, 0.06980951476309981, 0.05887896700629166, 0.020074789312535098, 0.02153306793687599, 0.020823420391284993, 0.07844425964036159, 0.0051596634023423705, 0.08323405190770115, 0.03873024960713727, 0.06561392918229103, 0.02611156100673335, 0.033138011648718796, 0.0662059374153614, 0.029334123978125196, 0.05256229792056339, 0.020336518928940808, 0.06548153342945234, 0.03047337748908571, 0.026308373481567417, 0.03626998680244599, 0.03835639716791255, 0.0320690882924412, 0.01791401150902467, 0.016345023111041104, 0.04501438633139644, 0.10049068342362132, 0.06269077318055288, 0.026212535499195968, 0.02130204203006412, 0.05088507131274257, 0.03653918539306947, 0.025087712731744562, 0.051329477823206356, 0.022867273040381924, 0.08060858957469463, 0.04196167763854776, 0.011433675535954535, 0.017751164800886596, 0.049692054079579454, 0.0833242359970297, 0.09686145066682782, 0.019855948198320608, 0.032907913638544936, 0.03830971735130463, 0.013577886906984662, 0.02962325792759657, 0.029971980822405646, 0.03906767828656094, 0.015571973253307598, 0.016332611009212475, 0.023298563468935232, 0.009644036031594234, 0.03196404767887933, 0.028650907067848102, 0.0385918759607843, 0.04986518568226269, 0.02928154429953013, 0.02904698152893356, 0.026322916183354597, 0.05484905932098627, 0.06563513340162379, 0.023126809292339852, 0.009922159902219261, 0.03497402223625353, 0.034715137377913506, 0.0636330819023507, 0.03267423974882279, 0.03747077665424772, 0.015743825817480683, 0.008502232925301152, 0.041664258776498694, 0.017709955672866533, 0.07504011730530433, 0.025047243206894824, 0.03554651240951248, 0.03185963471020971, 0.03254724174205746, 0.03159359470009804, 0.02698400437033602, 0.04458837490528822, 0.009214072987171156, 0.04395915241912007, 0.016536999327529753, 0.038209972703563314, 0.014212873548136225, 0.018623240059241652, 0.03947706899738737, 0.06053109121109758, 0.03798171691596508, 0.04090084581236754, 0.042523423209786415, 0.06603536728237357, 0.050602892347212346, 0.020216860974739705, 0.04010439837085349, 0.04377928974905184, 0.010574975050985813, 0.02880081920219319, 0.06684658982391868, 0.03643407014065555, 0.02574780856126121, 0.017424465456445302, 0.03152766823768616, 0.1010689309665135, 0.04381633097571986, 0.023074674054182003, 0.01211754129534321, 0.05337361545701112, 0.05567913156534944, 0.03742712649649807, 0.02492368537267404, 0.061808982997068336, 0.015602773654141595, 0.010364237341231533, 0.04153254155867866, 0.02879738581499883, 0.03686775919049978, 0.06797113948102508, 0.03066760813817382, 0.03808299844552364, 0.02150077815167606, 0.026824648724868894, 0.03150646401835339, 0.019369553940902864, 0.0906510842697961, 0.008103674177878668, 0.06395733343171221, 0.03293738241440483, 0.023233751500291482, 0.031499112091426335, 0.026610311386840682, 0.03659066245225923, 0.03289490272956235, 0.054036802013537714, 0.03766126518270799, 0.028862718559269394, 0.05798921760703836, 0.025654291168653538, 0.03982105911044138, 0.06449081123407398, 0.01565913955814072, 0.018919240783101747, 0.019157932439286793, 0.0163694232303117, 0.048423851773674996, 0.004530591042047101, 0.02811088309889393, 0.035129318545971594, 0.027104149173413004, 0.024650929562215294, 0.0483148111961782, 0.024799128395638297, 0.05522514074774725, 0.02552989704002227, 0.02087190850371761, 0.026915472333452532, 0.006448117858131549, 0.022447806084528565, 0.04264014480369432, 0.028365360872287835, 0.05263439905164497, 0.0410278302484325, 0.045883097752396546, 0.04041364070560251, 0.25774272105523516, 0.14741189564977372, 0.13451977100755486, 0.24639156301106724, 0.09197411899055753, 0.12789258733391762, 0.10621815001858131, 0.16524231673351356, 0.12217738186674458, 0.18272699708385126, 0.1360314656049013, 0.11599575142775263, 0.12066602653690747, 0.12669216389102594, 0.12352933575000082, 0.09733267966657877, 0.09167953301221132, 0.17734341882169247, 0.10952823382935353, 0.153000160785658, 0.07714707710381065, 0.12882558655525955, 0.10969871575278894, 0.1934629138559103, 0.22656899025397642, 0.0890377586973565, 0.20946678652295045, 0.12857271012450966, 0.20241131154554232, 0.10172027030161448, 0.13712193923337118, 0.1089067364643727, 0.13839398883283138, 0.16107803875846521, 0.1176361505474363, 0.12729306093284062, 0.13239001243242196, 0.15071074292063713, 0.12469838373363018, 0.13007069831447943, 0.07540179682629448, 0.14986497616129263, 0.15499742861304963, 0.19562727771699429, 0.13292507800672734, 0.29222766203539713, 0.15023811613874777, 0.18907744703548296, 0.10581816041043826, 0.08553346459354673, 0.17598492386085646, 0.1232659284557615, 0.15725969150662422, 0.11730342411569186, 0.07138208752231938, 0.1903683870498623, 0.09435263528887715, 0.08300476813954966, 0.18984472086387022, 0.1308456938713789, 0.1021412198564836, 0.08045582420059613, 0.10250249904181276, 0.09314722461359841, 0.10110880168420927, 0.14591535952474388, 0.14498462661036424, 0.10978098133844988, 0.09541512613317796, 0.13745253506515706, 0.11652935136641775, 0.08018088181103979, 0.12888362844075474, 0.12188250411834035, 0.08022024362747159, 0.11812806129455566, 0.09848789910652808, 0.15367448888719082, 0.09889050107449293, 0.10287457371928863, 0.12520759712372506, 0.13551215561372892, 0.1766368874481746, 0.10631183534860611, 0.1831190139055252, 0.18271685977067265, 0.10795624461025, 0.1337189775492464, 0.1257754766515323, 0.1493755081402404, 0.09182100756359951, 0.13648669474891253, 0.13017071437622818, 0.1476610672793218, 0.10773275553115777, 0.23966730811766215, 0.2509484684893063, 0.11597946658730507, 0.1072273962199688, 0.22598497516342572, 0.10627337598374911, 0.12505077411021503, 0.1329729961497443, 0.11796270231051104, 0.11690148711204529, 0.12767156133694307, 0.12328703089484147, 0.14305073395371437, 0.15619977909539426, 0.08105311143611159, 0.19594211796564714, 0.1860417356448514, 0.11051606546555247, 0.11288177780807018, 0.1527196815503495, 0.13510639167257718, 0.14638266659208707, 0.12296399394316332, 0.14640997084123747, 0.1340078841894865, 0.1186448335647583, 0.1146320996007749, 0.10795520645167146, 0.11724656288112913, 0.10638848944966282, 0.09938874933868647, 0.2917277988578592, 0.08483954718602554, 0.08160298942987408, 0.09105021892381565, 0.11730178206094674, 0.09911498081471239, 0.0992988638047661, 0.06360269031886544, 0.09503364017499344, 0.05823306952204023, 0.13828230196876184, 0.18396551348268986, 0.12476732289152485, 0.09311004767992667, 0.12615181931427547, 0.11561982945672103, 0.12630439469856874, 0.11611981477056231, 0.15322232672146388, 0.08042284061333962, 0.2893853874078819, 0.09132290179175989, 0.07494190614670515, 0.10861451857324157, 0.15305164802287305, 0.17393402462559088, 0.12891779946429388, 0.09281449818185397, 0.1267441939562559, 0.14961760943489416, 0.12372381745704583, 0.10617196213986192, 0.2307119486587388, 0.10815884159611804, 0.12784006872347423, 0.0977450321827616, 0.1578210842396532, 0.1384679220084633, 0.16204959233956678, 0.14962545329970972, 0.0674231613853148, 0.07472355357770409, 0.13862870766648225, 0.07168714329600334, 0.11915627254971436, 0.13804664675678524, 0.18017985804804734, 0.1666263924645526, 0.1300913800618478, 0.14152607933751174], [0.023508977178218107, 0.06843876545982701, 0.038171214783298116, 0.04217193528477635, 0.034509049329374514, 0.040801335259207656, 0.0038686250003853013, 0.02653661909114037, 0.048939585885299106, 0.030191368157310144, 0.03576693790299552, 0.06603204246078219, 0.015147727714585406, 0.0064886946763311115, 0.030674797216696397, 0.02773373806849122, 0.029237313994339535, 0.019886869039120417, 0.048407502472400665, 0.03912918748600142, 0.01675871403754822, 0.009963983952599977, 0.046771557935114415, 0.0203558758366853, 0.05775835285229342, 0.09210233496768133, 0.08450769606445517, 0.018210424442908595, 0.06216904760471412, 0.06513810650046382, 0.01766482800511377, 0.02001133611026619, 0.0334495202904301, 0.03517952674467649, 0.039056984574667046, 0.022354025759601166, 0.04065185399459941, 0.03189587526555572, 0.02268350709761892, 0.025912397408059666, 0.044288893296782456, 0.03663654499022024, 0.028373844256358485, 0.017728818946384957, 0.024358864341463362, 0.049488351081631014, 0.02285301193062748, 0.04584934063521879, 0.013316717930138111, 0.025550069886126688, 0.013374973554164171, 0.029637883749923537, 0.06508753528552395, 0.0029095235970869127, 0.02239047157179032, 0.07990303529160363, 0.05910980461963585, 0.03819069891635861, 0.0645591736372028, 0.00844654131547681, 0.03604235526706491, 0.02901438470663769, 0.03529827715829015, 0.012571320070752075, 0.0487541388720274, 0.05127950032640781, 0.023691574344411492, 0.02620826581759112, 0.04311730419950826, 0.011967347568965383, 0.046670374793133566, 0.07442404143512249, 0.0055554142870408085, 0.0252342864737979, 0.09613359972302403, 0.021979296313864843, 0.008581287343986332, 0.06383721916271107, 0.007907666615210474, 0.0439165675613497, 0.0355954008576061, 0.03432994322585208, 0.03521912604836481, 0.04508009226992726, 0.05751257389783859, 0.057178028992244175, 0.010088357725180686, 0.013630986513037766, 0.021495763777888248, 0.015403666034606951, 0.026932001446506808, 0.03491097276232072, 0.016012525684865456, 0.04809599043801427, 0.043113680822508674, 0.0730225612808551, 0.03143419325351715, 0.07199378684163094, 0.06774739255862576, 0.029256614922944988, 0.06672806332686118, 0.059300350823572705, 0.03611812048724719, 0.01772697163479669, 0.034048005140253475, 0.03184467301304851, 0.03461127741528409, 0.01895256872688021, 0.032148490460323434, 0.013757102424278855, 0.047670158823685985, 0.03973210316949657, 0.018596069820757424, 0.03380958489807589, 0.03965090288381491, 0.04922562910776053, 0.05999905190297535, 0.07711868041328021, 0.015809273912704418, 0.053144691312419515, 0.04716265534183808, 0.015171054052188993, 0.052880693692713976, 0.03851131349802017, 0.015485911264217325, 0.06743920195315566, 0.05022518243640661, 0.06095947750977107, 0.013531335163861513, 0.09021367345537458, 0.010687069036066532, 0.034354696183332374, 0.024354681173073392, 0.09759870610599007, 0.052756888193211386, 0.049591766603823216, 0.041700231310512335, 0.03151053522846528, 0.01912002099145736, 0.025086750908355628, 0.03237586754507252, 0.03888239412169371, 0.026017256513504044, 0.023952467666406716, 0.11169758492282458, 0.059565216968102117, 0.04552521463483572, 0.027533353106783967, 0.04537635762244463, 0.037875176740012, 0.02506149753129908, 0.06471057515591383, 0.034245312945651155, 0.01968561385625175, 0.011202651325480213, 0.03673883753695658, 0.007266165189711111, 0.003993688758263099, 0.023569668742961118, 0.008919666820604886, 0.013502045351612781, 0.04266151187143155, 0.023195020721427033, 0.019782508656914746, 0.036747085130108256, 0.018049935643960322, 0.06352507948343243, 0.05180562620184251, 0.0676187558897904, 0.03910256516454475, 0.022235120979270766, 0.04553112467484815, 0.05071250628679991, 0.019471802382862995, 0.05347799449892981, 0.042343360371887684, 0.04441185062751174, 0.06748818539615188, 0.032810554041394165, 0.015833891163180982, 0.013659837822030698, 0.04461741620408637, 0.08281455441777195, 0.026007561944425106, 0.04573309062314885, 0.03202370108504381, 0.017147462016769817, 0.07704124599695206, 0.06554874910839967, 0.018938273690374832, 0.1024353512163673, 0.0664581081696919, 0.044567560843591175, 0.019305398454889655, 0.046366167188222916, 0.04662175097369722, 0.013906568421849182, 0.04686828988737293, 0.020397848316601346, 0.020956097736156414, 0.0026384984750101076, 0.10449362612728562, 0.03181362325059516, 0.02474728662387601, 0.03230792583365526, 0.04879767707149897, 0.017133943902860795, 0.02923901372456125, 0.03636337696973767, 0.03108326851257256, 0.05262161884456873, 0.05911420152655669, 0.035862421350819726, 0.061053284976099215, 0.009976582651558732, 0.03181905492341944, 0.05368928012571164, 0.018008256630439843, 0.04190768660711391, 0.009866528512377824, 0.046799771421189816, 0.032213986052998474, 0.014879502821713686, 0.005142727168276906, 0.013920759133595442, 0.03185951935925654, 0.030845302888857465, 0.07287306644554649, 0.03376182621078832, 0.04052080174109765, 0.02400371741636523, 0.04574375040829182, 0.1304355330233063, 0.016963606168116842, 0.06802568012582404, 0.020459898647719195, 0.025958815988685404, 0.03415859956294298, 0.004637185076717287, 0.04272836453414389, 0.007544326379762164, 0.06594002632690327, 0.04195885154019509, 0.05571091075294784, 0.04194404590608818, 0.0036236272093706895, 0.02591960514629526, 0.048616840703678985, 0.004287263295347137, 0.03225489492927279, 0.059393045492470264, 0.027085443659286414, 0.04017615684175065, 0.12554648465343884, 0.01746240065300039, 0.015582709373640162, 0.01061033520714513, 0.007264309396435107, 0.03444326196664146, 0.09384471790066787, 0.03671816596761346, 0.04399596294388175, 0.033559344575873444, 0.03854464653081127, 0.02390384893598301, 0.0350010957834976, 0.02683934579337282, 0.030157468547778468, 0.05628554170419063, 0.045004795238907845, 0.03880321926304272, 0.01963369405296232, 0.03046157437243632, 0.07693725371999399, 0.06383381970226765, 0.011903662816621363, 0.010280233009585311, 0.012258925092672663, 0.023758579677503024, 0.05685682747779148, 0.03895150969869324, 0.043437779681491, 0.05496121098154357, 0.011320700303518345, 0.053230129049292634, 0.10418971707778317, 0.04234931112400123, 0.04342369329450386, 0.039669430282499106, 0.033745765286896906, 0.06878018392516033, 0.022371294475825768, 0.017121392701353346, 0.11826239765754767, 0.01457947668885546, 0.038008437624999454, 0.03193837869912386, 0.029792335283543383, 0.023191427878503288, 0.0778499443882278, 0.028197801738445247, 0.02224418111810727, 0.07531930053872721, 0.03751239459961653, 0.02797783595243735, 0.07329704905194895, 0.015125614258327653, 0.055473728837179284, 0.002960045194153541, 0.03502009815669485, 0.004132347813408289, 0.041420759699706516, 0.03014436942924346, 0.03242640822593655, 0.04871850899819817, 0.0431434888658779, 0.015233160362445881, 0.01578776435261326, 0.0219812013009297, 0.04442904470488429, 0.07465071284345218, 0.02435269985081894, 0.036010433587112596, 0.024184280673840215, 0.0344278795777687, 0.02153043861367873, 0.026913898132209266, 0.004047005071437785, 0.006823883342024471, 0.02025244165478008, 0.016271449558969055, 0.01653380851660456, 0.019039336392389875, 0.04523310870198267, 0.03453467759702887, 0.041448498211268864, 0.06689635358218636, 0.03817687376535364, 0.02507788754467453, 0.0249317870807967, 0.02703372572016503, 0.028570962071950947, 0.07287866435945034, 0.012923331315895277, 0.02651280420832336, 0.047710657186274014, 0.030268059577792883, 0.029834068579865352, 0.025473190172176276, 0.033904199821076224, 0.05597819248214364, 0.06471911112644843, 0.11551741138100624, 0.17397274183375494, 0.09166807255574635, 0.0892482538308416, 0.1161950235920293, 0.12146075389214925, 0.126291013988001, 0.0937914868284549, 0.13931644361998352, 0.11352795349167925, 0.08436563118760075, 0.12558170062090668, 0.16929895191320352, 0.03890727939350264, 0.17091018759778567, 0.15054866804608277, 0.07716595394802944, 0.12909168084817274, 0.236744152115924, 0.14229939212756498, 0.080134788927223, 0.09132372960448265, 0.07563376080776964, 0.11591823558722224, 0.08636124338954687, 0.14969447388180665, 0.16045724706990377, 0.10598740061478955, 0.12857808412185737, 0.22509240305849484, 0.1453028188220092, 0.14971629556800636, 0.13171221023159368, 0.11279555636325053, 0.11567968981606619, 0.19146024488977023, 0.1592973864504269, 0.1550892208303724, 0.06594109841223274, 0.1173360887914896, 0.06613807712814637, 0.13652790896594524, 0.1058765754901937, 0.13297847871269497, 0.22595727736396448, 0.1989562926547868, 0.13463475555181503, 0.09668366092124156, 0.09489354983504329, 0.09527153455253158, 0.09147891056324754, 0.20511512431715215, 0.1412237784160035, 0.10163996568215744, 0.10972769598343543, 0.1697161559547697, 0.13841955603233405, 0.09728653249996048, 0.19657277555337974, 0.16387854277023248, 0.10183276462235621, 0.09835549656833921, 0.144900094717741, 0.13407162576913834, 0.0692452789683427, 0.16364837012120656, 0.15933824782924993, 0.10751051495649985, 0.15267833162631306, 0.07659528564129557, 0.09175668244383164, 0.17115017186318124, 0.10111007054469415, 0.10042129643261433, 0.11276116142315523, 0.08716845578913178, 0.10438588155167443, 0.3351955935359001, 0.11711508993591581, 0.09778001744832311, 0.08549340388604573, 0.14580167776771955, 0.1581723346774067, 0.205901777105672, 0.10502886812069587, 0.14637037153754914, 0.17366114498249122, 0.12002926213400704, 0.13500439428857394, 0.18122305135641778, 0.05605564046917217, 0.13794042888496602, 0.12059707380831242, 0.1375627698642867, 0.14540192564683302, 0.2061975776617016, 0.09888962576431887, 0.2507096513041428, 0.09086582703249795, 0.09994372991578919, 0.15058135986328125, 0.13294772750564984, 0.1458407478140933, 0.11722750961780548, 0.1477538501577718, 0.05830650058175836, 0.09010345901229552, 0.1065198334732226, 0.1952173611415284, 0.19865291964794907, 0.12737323663064412, 0.1320909277669021, 0.16774418391287327, 0.08819928618946246, 0.1522281372121402, 0.1688524487295321, 0.09500774049333163, 0.17973441337900503, 0.07677922291415078, 0.10494327092809336, 0.12373970874718257, 0.06115431884037597, 0.13246911604489597, 0.1976118976516383, 0.13587766885757446, 0.15656169610364096, 0.18209483314837727, 0.11343676517052309, 0.1702831398163523, 0.25525257896099773, 0.05900875718465873, 0.14658940264156886, 0.14123067233179296, 0.18097938943122113, 0.1149936094880104, 0.14900899066456727, 0.12682037986814976, 0.1556984367115157, 0.08995272924325295, 0.16013419654752525, 0.0694953462641154, 0.08994143842054264, 0.14368304716689245, 0.174500044967447, 0.18596701536859783, 0.16180792530732496, 0.14478532730468682, 0.11813184751995973, 0.15377189937446797, 0.18185165976839407, 0.11678739823400974, 0.13226674976093428, 0.09362730170999255, 0.071503165311047, 0.12137843402368681, 0.11529420050127165, 0.16149296292236873, 0.11954277966703687, 0.11319647556436913, 0.1318496000021696, 0.08665916097483464, 0.14055630351815904, 0.11536383176488535, 0.1293074685548033, 0.1326081207288163, 0.14220266017530644, 0.15475584300501005, 0.09179490432143211, 0.13085137999483518, 0.09910041945321219, 0.1577215702938182, 0.09954144007393292, 0.05653395337451782, 0.12303548439272813, 0.18512142502835818, 0.10519318894616195], [0.028772924627576555, 0.027880109946376512, 0.03216893472043531, 0.08865786051111561, 0.07412746734917164, 0.018678864663732902, 0.054811987560242414, 0.010871716226185007, 0.04447833009596382, 0.0201594806608877, 0.027041355846449733, 0.02199560829571315, 0.04843372445819633, 0.04141103629288929, 0.05044577756364431, 0.0311428404945348, 0.09361663513949939, 0.004090960145861442, 0.07304128884736981, 0.031536380627325604, 0.0017538295006878407, 0.08562337726886783, 0.011311231347333108, 0.051481103258473535, 0.006064120896293649, 0.02489263391388314, 0.022339919016563466, 0.04218331092436399, 0.09229873014347893, 0.042349497721131356, 0.018824636038126688, 0.0384393582519676, 0.05981800518929958, 0.04793901136144996, 0.04784994346222707, 0.04252960127113121, 0.046301441732794046, 0.011894698520856244, 0.06140477290110929, 0.05339459575978773, 0.035640750745577474, 0.039332201770905934, 0.009047953195736876, 0.0680012528651527, 0.01037052396817931, 0.05449750693514943, 0.01583506672510079, 0.028826851198183637, 0.03294506682349103, 0.006871594531860734, 0.06081030158592122, 0.0436681626763727, 0.010596710223970669, 0.04382723503346954, 0.012220551392861774, 0.010667135373556187, 0.033148691789912324, 0.02833170214268778, 0.04814854636788368, 0.04862219773765121, 0.030002698102699857, 0.058565083492015085, 0.09604714079094784, 0.031945520280195136, 0.028586605696805885, 0.03187866083213261, 0.04198193530152951, 0.01376394460177315, 0.020408536939482604, 0.02980800944247416, 0.021919637818687727, 0.013744917631681477, 0.018277519681890095, 0.00624258366380153, 0.003356677962334028, 0.008712473608154272, 0.051326485483774116, 0.007013807414166097, 0.03520202696589487, 0.0157234103951071, 0.06346979245011296, 0.0115997893902074, 0.025343983533925245, 0.030454731346773248, 0.04927739454433322, 0.020449959806033542, 0.03115312030006732, 0.038742391991295984, 0.04013975683067526, 0.03170246903651527, 0.06576775307101862, 0.02972444106957742, 0.06483839079737663, 0.04069113438682897, 0.023258696143914546, 0.05021928257441946, 0.012366266788116522, 0.02988497566963945, 0.017248830059543252, 0.009883720045244055, 0.07813406057123627, 0.04689788079953619, 0.0941801584724869, 0.032811921289456744, 0.039717470561819415, 0.02659164828115276, 0.03327915371794786, 0.07367191250835146, 0.03464447134839637, 0.01349894783925265, 0.00349272253723549, 0.022834683003436242, 0.008153416731927012, 0.022391160284834247, 0.030341867224446366, 0.030130232152129923, 0.05120175039129598, 0.03957319026812911, 0.015544646951769079, 0.04501352459192276, 0.022739778006715432, 0.04203075250344617, 0.053658549274717054, 0.03434817885447826, 0.03308033277945859, 0.04101107382614698, 0.05322585767135024, 0.05843532724039895, 0.06561884856117622, 0.06437929400375911, 0.04110631639403956, 0.031091397362095968, 0.04703633247741631, 0.019476094116855944, 0.019692575625543083, 0.02059357343906803, 0.037325183395296335, 0.05095498077571392, 0.0393239881045052, 0.06659379481737103, 0.05966120253184012, 0.03311189144317593, 0.038506003961499245, 0.020340128735240017, 0.030833604945135967, 0.032106160053185055, 0.021083726780489087, 0.00994757782401783, 0.04557194534157004, 0.04179268849215337, 0.016281208588874767, 0.02308217016980052, 0.013136683929977673, 0.007643961613731725, 0.040367971906172376, 0.0650792300168957, 0.0459091263557119, 0.04330928211233445, 0.04378696058743766, 0.01839621750903981, 0.041818727273494005, 0.015425669228924173, 0.022229567170143127, 0.023442143175218786, 0.05444677287180509, 0.025216050845171725, 0.0602040101907083, 0.02840810009677495, 0.02238278546636658, 0.02247117822324591, 0.014902627295149224, 0.0023180902104026502, 0.03954082754041467, 0.03531216337744679, 0.02645845864234226, 0.03849867917597294, 0.036490279981600385, 0.009575213920990271, 0.07837464873279844, 0.09030069557151624, 0.039033052644559314, 0.028344344946422746, 0.015527885440470917, 0.02050764376430639, 0.06350785147930894, 0.04145006901983704, 0.08143851932670389, 0.06485761369445495, 0.031014190254999057, 0.016975955505456244, 0.089477279755686, 0.05852821868445192, 0.05756921800119536, 0.04182378575205803, 0.0461321302822658, 0.050507914407977035, 0.033929851837456226, 0.029844053222664764, 0.03357758020449962, 0.02187744651122817, 0.034907271353794, 0.01303364584288959, 0.042634054951901944, 0.04751285065763763, 0.10927320644259453, 0.04211687895336321, 0.044228259407516034, 0.052721563660140545, 0.047372058033943176, 0.07255469102944646, 0.01473503084188061, 0.014463779682825719, 0.03165152801999024, 0.05364329580749784, 0.03928441254954253, 0.03183898010424205, 0.023698580218479037, 0.037625574240727086, 0.037612621007221084, 0.04775259743577667, 0.033813187919024906, 0.01572099481044071, 0.05165841124419655, 0.055083228541272025, 0.03602326807699033, 0.024949542645897185, 0.03860773332417011, 0.023667240382305214, 0.02489303085686905, 0.058850807803017754, 0.03331780307261007, 0.05468162741245968, 0.04362933011725545, 0.036442412728709836, 0.0032365257377802792, 0.06357078560228858, 0.043521979091955085, 0.03101104185251253, 0.0417325804675264, 0.019066801793607216, 0.05009997236941542, 0.04448598736364927, 0.049676695439432345, 0.04718166450038552, 0.052701699547469616, 0.05596526299736329, 0.0710466265944498, 0.010950119251252284, 0.008200017668839012, 0.047564517706632614, 0.035364909297121425, 0.03403876010062439, 0.021477258431592157, 0.01718365677100207, 0.034484194591641426, 0.029541433389697756, 0.031344402714499404, 0.02087913659800376, 0.06121896965695279, 0.019121975172311068, 0.055230066911982637, 0.027115404373034835, 0.059715770318039825, 0.06281470760170903, 0.039455691751624854, 0.026265356057722653, 0.028634215106389353, 0.008040531405380793, 0.023416565797690834, 0.03838754192526851, 0.013253056078350969, 0.037060693837702274, 0.04014151423637356, 0.011211985422830497, 0.028120028054607765, 0.049044365262878795, 0.05453077211443867, 0.017863689655704156, 0.03216074819543532, 0.015533357825396317, 0.014356455798926098, 0.03271212575158902, 0.049778709786811044, 0.04514371171327574, 0.08638862906289951, 0.03351392683440021, 0.0573749127132552, 0.07650065036224467, 0.028115695608513694, 0.012568122474476695, 0.03642170044726559, 0.03419735748320818, 0.023365416131647568, 0.015315668524375983, 0.015691246138885617, 0.002931164199253544, 0.006277655018493533, 0.09436828909175736, 0.03905720170587301, 0.054585119376757314, 0.02709449701277273, 0.0339158604453717, 0.04261017391192062, 0.013470743683033755, 0.07013527264020272, 0.03987368628648775, 0.05223424659509744, 0.02707232757737594, 0.03781357254566891, 0.016662504557254057, 0.016953143158129284, 0.0086538592087371, 0.039079209989202876, 0.06236696269895349, 0.07535724421697003, 0.0643138832279614, 0.0407722464629582, 0.027919692286689366, 0.017891317905325974, 0.010608176617617053, 0.027847048327592865, 0.019629032517384206, 0.05928191502711602, 0.03891812577577574, 0.03365843104464667, 0.02629681463752474, 0.04397934562127505, 0.021644927827375274, 0.018559349201885716, 0.03112784826329776, 0.07008056914699928, 0.025133152525605898, 0.002102967256048162, 0.002597223189825724, 0.047887201820101054, 0.13902369647153787, 0.015055340082783784, 0.02304978878237307, 0.01657938741014472, 0.017025625965158855, 0.03604014663557921, 0.05538920033723116, 0.06485109975827591, 0.041014432574489286, 0.04263501847162843, 0.04871053960440414, 0.02285037582208003, 0.03290272963100246, 0.07369641440787486, 0.03596259347562279, 0.017857384369043366, 0.013303333826895272, 0.09125319588929415, 0.09128473419696093, 0.09519117565027305, 0.18616620610867227, 0.18509496216263088, 0.1105301518525396, 0.10535531131816761, 0.1056590439485652, 0.1534940121429307, 0.11782357549028737, 0.13994155079126358, 0.09680536296218634, 0.14588346837886743, 0.11345540452748537, 0.21236624808183738, 0.14101206191948482, 0.14989150688052177, 0.1559214304600443, 0.14095792839569704, 0.13607734814286232, 0.09104025124439172, 0.15691552497446537, 0.13164138474634715, 0.1352891754359007, 0.08077244899634804, 0.10928776780409472, 0.0990489593573979, 0.10096310664500509, 0.31556932095970425, 0.10118917415716819, 0.1593634079077414, 0.1231084947607347, 0.19245941484613077, 0.1392456724175385, 0.08151784007038389, 0.10003506751464945, 0.1407974005809852, 0.13908252545765468, 0.17356268955128534, 0.11401086007910115, 0.17177697537200792, 0.09801879392138549, 0.1612669021955558, 0.16377851313778333, 0.08611752718154873, 0.13280067539640836, 0.1946399278406586, 0.09708107209631375, 0.10096240096858569, 0.07761293210621391, 0.11250376594918114, 0.09407870391649858, 0.09461835638753005, 0.16092447271304472, 0.09969850736004965, 0.08889205687280212, 0.1163820278431688, 0.12704152800142765, 0.19997015967965126, 0.1436012022729431, 0.19259257055819035, 0.1528990590678794, 0.3841239937714168, 0.18836061550038202, 0.11477190495601722, 0.1287667711398431, 0.10995577874460391, 0.1396524134491171, 0.15781956432121141, 0.06990263012370893, 0.14203044798757347, 0.08997072399194751, 0.06917804971869503, 0.10288588489804949, 0.11293110051857573, 0.12453007990760462, 0.0966518579849175, 0.1578325650521687, 0.1268376825111253, 0.14959506850157464, 0.10470104071178607, 0.0882179866145764, 0.09288102175508227, 0.08374622371047735, 0.12525719803358826, 0.11270695326051541, 0.1824625584163836, 0.12454918745372977, 0.11618926961507116, 0.10932360123842955, 0.1212188018751996, 0.12092448052551065, 0.17585146959338868, 0.0941925553072776, 0.09381275211593934, 0.1239157614431211, 0.07152639835008553, 0.0791133087394493, 0.05081025943426149, 0.12964627466031484, 0.162857944677983, 0.1320528212402548, 0.12582384262766155, 0.16922576512609208, 0.14170237630605698, 0.11046702773975474, 0.16869428221668514, 0.19453170150518417, 0.17627978803856031, 0.05330631835386157, 0.16439816488751344, 0.11527396658701555, 0.08024795499763318, 0.0859047318143504, 0.13483976812234946, 0.09127815240728003, 0.12090945776019778, 0.09781962353736162, 0.0602730375581554, 0.18417261594108172, 0.16036386708063738, 0.1712871002299445, 0.12484475730785302, 0.0935868610228811, 0.06276028230786324, 0.10503970432494368, 0.1498641347778695, 0.09621465073100158, 0.22858805262616702, 0.15496884871806416, 0.23692038123096737, 0.12101754838866846, 0.1493744903377124, 0.13964807082499775, 0.11148987178291593, 0.126062184838312, 0.1463663817516395, 0.1531063515160765, 0.10861233369048152, 0.21917914679007872, 0.19616596666829927, 0.11810661958796637, 0.09798411399658237, 0.1281797026417085, 0.1454507258853742, 0.06963609478303365, 0.2114558440766164, 0.08908307805125203, 0.16942334095282213, 0.2046840103077037, 0.06274229434451886, 0.108783690924091, 0.09392446612140962, 0.08147665978010211, 0.312301116330283, 0.0966586908325553, 0.0644011360460094, 0.13589489007634775, 0.10857533996126481, 0.2095785140991211, 0.0935583421960473, 0.11586407492203371, 0.0960021335631609, 0.07354004601282732, 0.10750831650303942, 0.12558491687689508, 0.08292453137359448, 0.08016372166041817, 0.21267008249248776, 0.13913044360067162, 0.028021861000784805, 0.10758647695183754, 0.11569760314055852, 0.05209165924627866, 0.14390367961355618, 0.11523329519799777], [0.035275637837392945, 0.0214307991388653, 0.029139486208025898, 0.01645326810622854, 0.021913147631234357, 0.03199377429804631, 0.034841677373541255, 0.009322334945734059, 0.020550559407898357, 0.053366860640900474, 0.007607262199079352, 0.00335649899872286, 0.05565989509757076, 0.08691163706992354, 0.027792558572920303, 0.06653058249503374, 0.03912695171311498, 0.02327356454251068, 0.055478166456201246, 0.05675754423386284, 0.021728828682431152, 0.03474108794970172, 0.04169131875304239, 0.01391797629185021, 0.03940349883799042, 0.029885786518986737, 0.05009685450100473, 0.03253429190122655, 0.04228573239275387, 0.028834355795489888, 0.013469903147779405, 0.07628052681684494, 0.027801876555063894, 0.01408803413089897, 0.022108487685077956, 0.014935938275552221, 0.042215185106865, 0.02660637249105743, 0.039062161796859333, 0.0016122285721524218, 0.016766033734061887, 0.041622613689729145, 0.04208775283768773, 0.08898045641503163, 0.053656798654368947, 0.04205420606636575, 0.04072101028370006, 0.14737653040460177, 0.038371050131640265, 0.011023959128319152, 0.028559661071215357, 0.06847659378711667, 0.029039979047541107, 0.00280029621041779, 0.07629887440374919, 0.055343959014862776, 0.03734182785930378, 0.051725423362638266, 0.06615964097103902, 0.07497844525745936, 0.02668509103490838, 0.040537924572293244, 0.09106622556490557, 0.04692393993692739, 0.012048017749163722, 0.03283931374815958, 0.07193469322685685, 0.0512435074363436, 0.0051463649641456345, 0.08550004674387829, 0.06273145135492086, 0.06739068669932229, 0.023820996417530944, 0.006306098358306501, 0.049721468572637866, 0.08304670838905232, 0.02239251396219645, 0.04711686779877969, 0.030956267113132135, 0.02371627980444048, 0.0031319075122675194, 0.06732562876173429, 0.03741878730111888, 0.042969688906201293, 0.06598928118390696, 0.03096673351579479, 0.01109717390500009, 0.0994591609175716, 0.030421503486910036, 0.014760447067341633, 0.011742745692442571, 0.031743944489530156, 0.01392198134479778, 0.04221870670361178, 0.0238531742444528, 0.00844318765614714, 0.059730365606290955, 0.03872820721673114, 0.007882374222390354, 0.052215692055012496, 0.023347621550783515, 0.036967663293970485, 0.02916159966428365, 0.03196563205814787, 0.030817313319338218, 0.013266072076346194, 0.021232057928240726, 0.022495403619749204, 0.01331995623851461, 0.028596766758710146, 0.029073888835098063, 0.019126599388463155, 0.013055433602338391, 0.03199153173980968, 0.029266606351094585, 0.020316893999863948, 0.06606992507087332, 0.011785446749334889, 0.031956875563732216, 0.0220604711544833, 0.04173877549224666, 0.06326425740761416, 0.02716229283916099, 0.01613776119691985, 0.07070518098771572, 0.025157252393130745, 0.037479987767125876, 0.0592446770252926, 0.03027430549263954, 0.06292930538100855, 0.04082609500203814, 0.0317686228081584, 0.035508114112807174, 0.0651021780712264, 0.024356087436899543, 0.015145298559218645, 0.005219386782430644, 0.04125918015571577, 0.02128577245665448, 0.0070157297886908054, 0.03555273796830859, 0.02967526763677597, 0.043343249575368, 0.003187111213005015, 0.018992013663851788, 0.027096822691549147, 0.010881283569947948, 0.072932248269873, 0.025347995372223, 0.0034945711210769203, 0.018792609185246483, 0.06751791201531887, 0.019994978327304125, 0.025278230097943118, 0.04012310218864253, 0.029617676977068186, 0.025482526814032878, 0.007756355002389422, 0.00808581174351275, 0.02276319425020899, 0.03420241256909711, 0.027010716597682664, 0.02473058957340462, 0.03570058735619698, 0.04964723005624754, 0.04205144442883985, 0.02087881090119481, 0.025897944612162452, 0.024204087111034563, 0.022620749393744127, 0.01764715725689062, 0.014867156877049377, 0.05229293308886034, 0.028527091390320232, 0.0817234158249838, 0.04070235735603741, 0.04978394807715501, 0.04719830557171788, 0.04105642032144325, 0.03715179055663092, 0.029993442885045494, 0.04186105428795729, 0.0059457084779361525, 0.03921432327479124, 0.07967169556234564, 0.03749079343729785, 0.03355731575616768, 0.05403759589950953, 0.023836640042385886, 0.02618103620729276, 0.03002671824236001, 0.07030390216303722, 0.04709696636668273, 0.0212203990002828, 0.06048267095216683, 0.06574034025626523, 0.029612207984817878, 0.07239611739558832, 0.060349040265594206, 0.02922549730698977, 0.04188694039891873, 0.03412889329982655, 0.011439069889352789, 0.024882228579372168, 0.025997977637286698, 0.004080296968043382, 0.025385460683277676, 0.05896474740334919, 0.02791230982568647, 0.031988865097186396, 0.024880800263157914, 0.05728869805378573, 0.02819698240741023, 0.031989611485706906, 0.02620399443964873, 0.009219398638898773, 0.029129511743251766, 0.023877570971048305, 0.00486736832785287, 0.02722469431215099, 0.03719015831926039, 0.016254640550219586, 0.02603123603122575, 0.07934821077755519, 0.08390694151499442, 0.0248512619374586, 0.03822352644056082, 0.021397817247946347, 0.019260934055117623, 0.03674581626962338, 0.06634504387953452, 0.04558419289865664, 0.03723409006904278, 0.029462553693779876, 0.053908596214439185, 0.02683873680819358, 0.011081785578945917, 0.03280988907707589, 0.10486369234110628, 0.08261621184647083, 0.004412529341477368, 0.02795669110491872, 0.018307375222710625, 0.07665768372161047, 0.055466339590826204, 0.0548180706266846, 0.04348812019452453, 0.013354593754879065, 0.043892014771699905, 0.07713671587407589, 0.04773377826703446, 0.04855580308607646, 0.05828947613814047, 0.008732496328385813, 0.09500468708574772, 0.01184072784547295, 0.06395499927124806, 0.04308416794187256, 0.014893005668584789, 0.024520834043089832, 0.05189887387678027, 0.04631014055173312, 0.04515394741403205, 0.018749188033065627, 0.01526264101266861, 0.01761861128865608, 0.01655577269515821, 0.021711327567962662, 0.08052626970623221, 0.03377631971878665, 0.03919475432485342, 0.04255317697035415, 0.028991585930011103, 0.04946308583021164, 0.008877202402800322, 0.07207097698535238, 0.029111598418759446, 0.03490158862301281, 0.024020271974482706, 0.03722696205867188, 0.015315585403836198, 0.021348552212917378, 0.029610006138682365, 0.06218295757259641, 0.02263593500746148, 0.04721791184108172, 0.033294332546315024, 0.06077726371586323, 0.047702297634844265, 0.04526668940005558, 0.04944193928635546, 0.021935936229835664, 0.045426413150770326, 0.05312266606571419, 0.054429996093469005, 0.05855607933231762, 0.02566115285402962, 0.030588789510407617, 0.049208282360008786, 0.04821225741345968, 0.0376600573903748, 0.058119808456727436, 0.04163147535707269, 0.02689849877996104, 0.04874355372573648, 0.013711541342282934, 0.011689984505730016, 0.04226042303655829, 0.04876173507156117, 0.03642535435834101, 0.014765466530142086, 0.012014626192727258, 0.030927928098078285, 0.027955025301447937, 0.03730966190674475, 0.024171444487624934, 0.12452058041734354, 0.02151597903243133, 0.013921854119481785, 0.034567050502768586, 0.009707024437375367, 0.018772180192172527, 0.0427729917823204, 0.022337349065180336, 0.01600615424104035, 0.019305786916187832, 0.018410814493628483, 0.022403126249888113, 0.03278453561610409, 0.013668048095756342, 0.036112295264112096, 0.03593576080831034, 0.03843617592273014, 0.07444882831935372, 0.010295742623774069, 0.03216146744255509, 0.023994694596954753, 0.05584901977064354, 0.013162149349227548, 0.049197229024555, 0.03586312024188893, 0.030082202050834894, 0.024863935275269405, 0.022382201926250542, 0.05368241335132292, 0.006979557935015431, 0.0075081409553864175, 0.05286238342523575, 0.031215786401714598, 0.014746284345164895, 0.02104066694820566, 0.06514766027352639, 0.14858768827148847, 0.1390368871923004, 0.13005889180515492, 0.11151685712060758, 0.13409024477005005, 0.11549468045788151, 0.10535690587546144, 0.21203939776335443, 0.20008390929017747, 0.12490772535758358, 0.11725205901478018, 0.11894062055008751, 0.07927628606557846, 0.16786758229136467, 0.1258894841053656, 0.21344693723533834, 0.15485417629991258, 0.07660554509077754, 0.12663675472140312, 0.16936585546604224, 0.08524071744510106, 0.13695880584418774, 0.23606797839914048, 0.13435324494327816, 0.10579787899873086, 0.08839986792632512, 0.10457114196781601, 0.11015229605670486, 0.1319156621715852, 0.09329813758709601, 0.09389084471123559, 0.07921815597053085, 0.0980692904974733, 0.10093739016779832, 0.08241566403635911, 0.0669034103463803, 0.1227270495146513, 0.09229532389768533, 0.12722275113420828, 0.0639003636315465, 0.05307944677770138, 0.11434277226882321, 0.1215928103774786, 0.2004414836743048, 0.15034734670604977, 0.10138492472469807, 0.12579106938626083, 0.2800841922206538, 0.12732561704303536, 0.06889580629233803, 0.11752799206546374, 0.11105037786598716, 0.15938039842460835, 0.14177549523966654, 0.16121850907802582, 0.12979492811220034, 0.11902006343007088, 0.16746146551200322, 0.11156560307634728, 0.15943548189742224, 0.126185895342912, 0.12750339321792126, 0.20175188407301903, 0.15543850351657185, 0.12772273644804955, 0.09164200324032988, 0.13566957573805535, 0.27592960372567177, 0.13327746838331223, 0.1467011302177395, 0.10957224361066308, 0.20825790853372642, 0.1216843311807939, 0.16556924847619875, 0.08924871523465429, 0.17543381771871022, 0.1332245155104569, 0.09740522863077265, 0.17744156212678977, 0.159069032275251, 0.16589290968009404, 0.14225192181766033, 0.14603826935802186, 0.14080571942031384, 0.17762058680610998, 0.12482317989425999, 0.08822393058133976, 0.16596374873604092, 0.18668091563241823, 0.12227114183562142, 0.08621892066938536, 0.08473543277276413, 0.17256480881146022, 0.0797033424356154, 0.13941755890846252, 0.15490114449390344, 0.11691763624548912, 0.13352271808045252, 0.0847950963569539, 0.20315362885594368, 0.15029846504330635, 0.09897187777927943, 0.1402057180447238, 0.11317251649286066, 0.09627462644129992, 0.09515351695673806, 0.07958598301878997, 0.21727656173918927, 0.06819333255823169, 0.13199049101344176, 0.16510074718722276, 0.20343317171292646, 0.15579961985349655, 0.0978386157325336, 0.12220672172095094, 0.08402128145098686, 0.19063339568674564, 0.12233207428029605, 0.0683767677151731, 0.1735328340104648, 0.1546443732721465, 0.1801392545125314, 0.11730313913098403, 0.13398110919765063, 0.1457556188106537, 0.1226939098643405, 0.11748413156185832, 0.1418811431420701, 0.1953250039368868, 0.08806706685572863, 0.20339220176850045, 0.13827691440071377, 0.11558913253247738, 0.1582717536283391, 0.1543532003249441, 0.06517885252833366, 0.1328167159642492, 0.07867190813911812, 0.14488176070153713, 0.06932350727064268, 0.3000940813549927, 0.14537535421550274, 0.1411515822900193, 0.22429745857204708, 0.06469814439437219, 0.0694365579900997, 0.10838701256683894, 0.16351554010595593, 0.11913734142269407, 0.11623279085116726, 0.05680382710748485, 0.12967839650809765, 0.07972605978803975, 0.17296768219343253, 0.10827855552945818, 0.17280135968966143, 0.07456204867256538, 0.1856415628322533, 0.12003551822687898, 0.0875924044687833, 0.09414844374571528, 0.12299528797822339, 0.13985064066946507, 0.12615849609885896, 0.10000634512731008, 0.12103702234370367, 0.17023185613964284, 0.11975384476993765, 0.16777758140649113, 0.11695528136832373, 0.10865258438778774, 0.26265740447810715, 0.10748818436903612, 0.1020009530974286, 0.10068791998284203, 0.15260485985449382], [0.019409940345212817, 0.02169433026574552, 0.06555311208856957, 0.04639066569507122, 0.03564190086243408, 0.009779223107865878, 0.031341895527605496, 0.08527210647506372, 0.048232603285993846, 0.024669708018856387, 0.061886430984096866, 0.019161409931257367, 0.009915603557601571, 0.018461031174021106, 0.04697606160438486, 0.036892603750207593, 0.0647167633952839, 0.02319236595316657, 0.06631077786109277, 0.021453781119946922, 0.015629250090569258, 0.029907455534807274, 0.03301543429759996, 0.018233265627973845, 0.05917396689099925, 0.04495153023994394, 0.011161933287179895, 0.02684633809673999, 0.06886687355914287, 0.004711101713058139, 0.05711406349603619, 0.04457394925079175, 0.038145342243037055, 0.03174408698188407, 0.033228480722755194, 0.04401044288117971, 0.024060792389458845, 0.04247000893311841, 0.04203604168391653, 0.04590785749522703, 0.022115301873002733, 0.0248113759527249, 0.014436070009001663, 0.0807031434295433, 0.0196366405912808, 0.02419715078680643, 0.033297704865357707, 0.05001159318323646, 0.03952516016683408, 0.032623481936752796, 0.013519377680495381, 0.01836521863671286, 0.05547128611111215, 0.050848318463457484, 0.03094177021245871, 0.049003788868763616, 0.07556670119187661, 0.004214343257314924, 0.047756794174867015, 0.04848007518532021, 0.018031089333817363, 0.04375536121161921, 0.022492809919640422, 0.019460726995021105, 0.06813779446695532, 0.016188720873157893, 0.07833171103681837, 0.01825627644679376, 0.04735064686142972, 0.01073759953890528, 0.047084182766931396, 0.041446238689656766, 0.02020106298316802, 0.06420782820454665, 0.050017571076750755, 0.014139746981007712, 0.02411254425533116, 0.029360451136848757, 0.030649593033428704, 0.01660618445436869, 0.02354802517220378, 0.036709236446768045, 0.03291297211710896, 0.007642512093298137, 0.04689705977216363, 0.008094586049472647, 0.008717303929318274, 0.06461408747626202, 0.017108595530901636, 0.030542815370219092, 0.03789420625460999, 0.03746727202087641, 0.05191509425640106, 0.040274859938238344, 0.034314476020101986, 0.046227111614176204, 0.07856936792709998, 0.005444696455794785, 0.032997293663876395, 0.04326638852113059, 0.026335085708914057, 0.0198465640590127, 0.011834519250052316, 0.046212797917957814, 0.004428717490684773, 0.05391523228692157, 0.06016756607485669, 0.007323540414550475, 0.027656712469511797, 0.051755451929888556, 0.03575965722224542, 0.035499581534947665, 0.07192677472318922, 0.015420381744791354, 0.03932853428913014, 0.03642884881368705, 0.041669388501239676, 0.0483880047686398, 0.03929242265543767, 0.04711891358186092, 0.011566902494191058, 0.03778341505676508, 0.039327472381825955, 0.028162752012056962, 0.021702981587233286, 0.03737916424870491, 0.08956836629658937, 0.024374390919027582, 0.07575597853532859, 0.03296307853556105, 0.015150455425360372, 0.035696122595774274, 0.07235149014741182, 0.04095062992668577, 0.05079740119565811, 0.02894287050834724, 0.013042847625911236, 0.04449578540931855, 0.02705026331490704, 0.025306552149621502, 0.03121381186481033, 0.05626822549051472, 0.01914335411441113, 0.044972208594637256, 0.06261574077819075, 0.0359216744213232, 0.033382647271667204, 0.031546185458345075, 0.03372912421556456, 0.02791451506449708, 0.020102672012788907, 0.055339188913681676, 0.015690187624256526, 0.05041629860975912, 0.022659695607477, 0.08115998070154871, 0.05087157525122166, 0.04205769034368651, 0.026198941050097346, 0.02455025871417352, 0.03940036061352917, 0.020329843840694854, 0.007275793601625732, 0.08172925122614418, 0.014250288817233272, 0.03084801702893206, 0.05030343109475715, 0.047169830849660296, 0.014434226090088487, 0.0169402815268508, 0.0267361372243613, 0.04883742904556649, 0.01860980167319732, 0.018875454918348362, 0.052096470059560876, 0.03841972144852791, 0.05134282121434808, 0.014015627659058996, 0.03229227203077503, 0.05026360448183758, 0.0969812935218215, 0.05819328701389687, 0.021614670254556195, 0.04369687149301171, 0.034460900484451225, 0.02135605172121099, 0.017369778926617334, 0.01524973866928901, 0.008392327215655573, 0.028000439650246074, 0.05014816192643983, 0.02119728809754763, 0.07576994278601237, 0.0177031940714057, 0.01674442409005548, 0.02991276846400329, 0.028383906930685043, 0.03653414387788091, 0.014992981018232448, 0.05239919845813087, 0.019829749961250594, 0.013362355347323631, 0.01577414445845144, 0.015605569218418427, 0.06234408928347485, 0.04187044860529048, 0.06363690205450569, 0.04822788746761424, 0.06413824443838426, 0.02809276112488338, 0.03435248415917158, 0.02980500353234155, 0.06778686294066054, 0.03370747555579458, 0.01394728900465582, 0.03952031542680093, 0.01188364009638982, 0.018718321475067308, 0.02190539876132139, 0.020780294401837245, 0.028626466236476387, 0.04207942721300891, 0.06587918209178106, 0.027673487551510334, 0.026353451955531324, 0.0554102654568851, 0.012093856182348515, 0.017630517881895815, 0.03228484885767102, 0.07576352384473596, 0.03259080708292978, 0.03766471553327782, 0.03894256321447236, 0.0165737504804773, 0.052958925387689045, 0.06024525833449193, 0.01423665535237108, 0.07950713724962302, 0.0509492675108569, 0.03946165607443877, 0.01845969954904701, 0.03333903104066849, 0.03667611715250781, 0.05870431209249156, 0.042099114906574996, 0.023837544190298234, 0.016311216800074493, 0.07863971843783345, 0.04517414400886212, 0.06345286300139767, 0.06625313631125859, 0.027161631267517805, 0.04135073149310691, 0.023163095648799623, 0.06259371553148542, 0.050181915650942495, 0.041467883956751654, 0.021206885975386416, 0.04909804077552898, 0.016090351955166886, 0.045323350466787815, 0.014003011148556002, 0.01412182517482766, 0.08464898062603814, 0.02263720895695899, 0.051830616646579335, 0.04982954902308328, 0.012636216856273157, 0.012081959767134061, 0.009335331435847496, 0.027753183185788136, 0.040186843768294365, 0.07808441216392176, 0.03576713467815092, 0.10350160793002162, 0.024201364489272237, 0.03967307062287416, 0.04360147286206484, 0.05120664941413062, 0.06974979011075837, 0.06879111512431077, 0.03778534548889313, 0.022900112438946962, 0.039475006250930686, 0.048609393781849315, 0.09239059021430356, 0.07142459095588752, 0.035560398628669124, 0.05088290339335799, 0.03733050989519272, 0.016139516906280602, 0.03713055580322232, 0.031178450012313466, 0.09149595536291599, 0.027661377397765006, 0.027987584804317782, 0.0635808143498642, 0.021499183594382236, 0.047900952332253964, 0.02543800643512181, 0.01557450249258961, 0.02641127840615809, 0.06022965202906302, 0.03022913880912321, 0.07623767054506711, 0.01348912519668894, 0.021567128698474596, 0.025990396704790846, 0.03260792312877519, 0.01667078777349421, 0.040907234219568114, 0.029598352299737077, 0.025299215489732366, 0.019965207603360926, 0.021008373770330633, 0.051422002858349254, 0.010744436627386935, 0.030273850874177048, 0.01901718052769346, 0.053704777865537574, 0.0694673363385456, 0.08352899072425705, 0.09107237987752471, 0.01707435495752309, 0.0343292816542089, 0.0008492465837792094, 0.05748063525451081, 0.028680189246577874, 0.05359840393066406, 0.0957956960690873, 0.05362888711637684, 0.05834903794207743, 0.01605866945880864, 0.07694472439054932, 0.025631572119891644, 0.012243136430957487, 0.018014755299580947, 0.011958526613722955, 0.045322023930826356, 0.052801298310181925, 0.04705456471336739, 0.05078909931970494, 0.03347877872043422, 0.05097961838224104, 0.03998008397008691, 0.027747301983514, 0.04138001027916159, 0.012954749183596244, 0.0069847071676382, 0.06184339829321418, 0.03152825517047729, 0.028373554182638015, 0.10168835201433726, 0.07311537130070583, 0.12160304268555981, 0.10107959075165646, 0.17746497158493313, 0.13467767967709474, 0.11934217757412366, 0.16749559582344123, 0.11367451027035713, 0.1575674478496824, 0.09418641456535884, 0.06347462361944572, 0.07973350331719432, 0.10316559060343675, 0.13287025237722055, 0.09533962554165296, 0.19317205303481647, 0.13947568221815995, 0.08969766114439283, 0.1062030933265175, 0.07875993448708739, 0.10111165831663779, 0.09900314467293875, 0.08726720977574587, 0.11800998263061047, 0.12587737904063293, 0.09359389064567429, 0.11699192225933075, 0.21051904505917005, 0.11568714013057095, 0.2612658105790615, 0.09656468659107174, 0.07727962891970362, 0.07603444252163172, 0.0855317682560001, 0.09960224359695401, 0.0971305440845234, 0.11659352720848151, 0.12336181902459689, 0.11007007118314505, 0.06879997679165431, 0.08890207204967737, 0.10191217357558863, 0.2294773134802069, 0.08946649783423968, 0.08992049882986716, 0.19863510131835938, 0.14618732993091854, 0.1776571734143155, 0.0698990746002112, 0.1273594487990652, 0.07232531226639237, 0.1391153529818569, 0.14464374418769563, 0.10414330528250762, 0.1168786883354187, 0.18506536446511745, 0.1565337676022734, 0.17780535189168795, 0.1842879397528512, 0.08210463715451104, 0.11398692136364323, 0.16639944964221545, 0.12131873651274613, 0.09955644926854543, 0.12198684923350811, 0.16212024140570844, 0.09196293673345021, 0.13711191048579557, 0.08739794990313904, 0.12788544914552144, 0.21244104978229317, 0.09753630802567516, 0.1467907918351037, 0.1583305419023548, 0.11156813401196684, 0.21901887681867394, 0.09120064335209982, 0.12537101549761637, 0.18039918770747526, 0.08476612291165761, 0.1413985826075077, 0.10010653082281351, 0.1162511520087719, 0.17761713984821523, 0.05649613183257835, 0.10406895820051432, 0.17275372653135232, 0.05411325594676392, 0.20659160294703074, 0.15401450278503553, 0.09786102774419955, 0.14542741142213345, 0.15955964023513453, 0.17722827142902783, 0.1572671825332301, 0.2422851233610085, 0.1110169735870191, 0.12998284160026483, 0.12973582771207604, 0.11376241448202304, 0.09034524818084069, 0.10356151578681809, 0.13947123102843761, 0.11575959409986224, 0.11760702782443591, 0.20523616139377865, 0.09476237544523818, 0.12310706983719553, 0.26745627554399626, 0.11961294018796512, 0.11615494931382792, 0.1781691416565861, 0.14380218434546674, 0.08963303746921675, 0.09666591044515371, 0.06552536679165703, 0.1631760826068265, 0.08274358644017152, 0.12316786657486643, 0.1469434215021985, 0.1858651265501976, 0.1308900293494974, 0.1705125660768577, 0.1742681081273726, 0.10194846841373614, 0.1746927217713424, 0.10760466169033732, 0.2632637433707714, 0.08471975182848317, 0.09609606995114259, 0.07861271274409123, 0.15178471457745346, 0.19801061839929648, 0.11921683858547892, 0.15631012246012688, 0.10166070171232734, 0.14786297215947083, 0.1276529694774321, 0.1505369022488594, 0.10080273489334754, 0.1884708231581109, 0.11939989376280989, 0.1073112835043243, 0.1395791723792042, 0.10674396716058254, 0.20595453998872212, 0.11654073718403067, 0.14711313668106282, 0.09293333001966987, 0.15258626799498284, 0.24795146073613847, 0.05843346805444785, 0.1256638847823654, 0.1293076178325074, 0.24018264189362526, 0.12186665354030472, 0.18992653861641884, 0.08431436108159167, 0.07944499022726502, 0.17080227338841983, 0.1168061393712248, 0.11437504339431014, 0.17667355548058236, 0.11171086385313954, 0.12640397649790558, 0.12096836817051683, 0.17619631466056618, 0.14089175766067846, 0.11314093068774257, 0.07246801496616431, 0.1504836372498955, 0.10538686319653477, 0.09805700901363577, 0.1570732029420989, 0.08019369255219187], [0.04034137672611645, 0.026694817834400704, 0.022981660473825674, 0.014416891216699566, 0.030763274790453057, 0.016394160920754075, 0.08978429649557386, 0.04656835366040468, 0.023016501550695727, 0.05807198530861309, 0.09790238445358616, 0.05326425936073065, 0.02792793987984104, 0.03714215535936611, 0.007629066921903619, 0.03515651762219412, 0.024821308009060364, 0.011803773980188583, 0.03529727631913764, 0.03459326570321407, 0.03523647618879165, 0.013781078459162797, 0.07683702052703925, 0.043401053973606656, 0.044683566583054404, 0.05249028839170933, 0.10972658997135502, 0.0785674951704485, 0.021018412695931535, 0.04817364537822349, 0.06551940246884312, 0.05035493868802275, 0.028070506872609258, 0.011563399557157286, 0.008787002198265066, 0.03519831198666777, 0.010256169613317719, 0.01170282154011407, 0.02514996492703046, 0.006620737590960094, 0.04309601855597325, 0.029218769632279873, 0.0411342109686562, 0.028847281887595142, 0.07923711423895188, 0.03326494858733245, 0.02548617563609566, 0.0016218509408645332, 0.007354385768329459, 0.08487513634775366, 0.022221409482881427, 0.025677507244316593, 0.04275102421109166, 0.03619678983730929, 0.030193271448037455, 0.032078150127615244, 0.026836750396926488, 0.03249100475971188, 0.008837712512883757, 0.018918558855408003, 0.01676145871169865, 0.03492607016648565, 0.014263379454080547, 0.04783975525892206, 0.042889886402658055, 0.035175964435828586, 0.01968481657760484, 0.0466462087684444, 0.025461677129247358, 0.016663571553570882, 0.03410305807899151, 0.023758920641349893, 0.05463308501722557, 0.04865773940192802, 0.033579137442367415, 0.03207510689805661, 0.028896397644920007, 0.026915321359410882, 0.011435010553603726, 0.09253515210002661, 0.008918187614264233, 0.03117365955508181, 0.04057473170437983, 0.048544963489153554, 0.034449653766517124, 0.03146057130236711, 0.017047137221587554, 0.05301017513764756, 0.034401525277644396, 0.027344610109659176, 0.06802555798952069, 0.02371854950407786, 0.015347927775500076, 0.010493393089356167, 0.028736243024468422, 0.027724930683949163, 0.03761210871328201, 0.05727609765848943, 0.08379015206758465, 0.0451093405219061, 0.038416081108152866, 0.0032636505992351367, 0.012591434393211134, 0.022124090597831776, 0.04516537394374609, 0.0275602213971849, 0.07026771589049272, 0.013754245791850346, 0.11136403746370759, 0.05974962921547038, 0.020403738000563214, 0.0026707483962776935, 0.052808813085513454, 0.03337354472439204, 0.018504834002149955, 0.04837342644376414, 0.06134919409773179, 0.03442038515848773, 0.052936197857239416, 0.031113700808158944, 0.030080281796732118, 0.03610491958845939, 0.022475668428731815, 0.044136840384453535, 0.02307725587992796, 0.021471421334094236, 0.019773636811545918, 0.022657437782202448, 0.08896206811602626, 0.027869026076846888, 0.009262730733358433, 0.042685878063951216, 0.028409691261393682, 0.021135032509586642, 0.032424355657505136, 0.053742942067661455, 0.021708369155281355, 0.031447068455496004, 0.052251949573733976, 0.04820046786751066, 0.0019190361324165548, 0.008784655315269316, 0.025931208095114146, 0.07299162008400474, 0.050375216707055054, 0.02469246947605695, 0.02532159866366003, 0.032914756664208004, 0.033530367737902064, 0.07604844748441662, 0.07136743116591658, 0.01791217946447432, 0.06629521226776497, 0.039846151335431, 0.07868695126048156, 0.0565046915518386, 0.09856747090816498, 0.018028236094063947, 0.015345434159306543, 0.01686216687916645, 0.02665542039488043, 0.03373740912814226, 0.03223005036956497, 0.04763478340048875, 0.04202271525615028, 0.039883056855095286, 0.008029588331867541, 0.03460516381476607, 0.026336502150765488, 0.045766196346708705, 0.042654858835573704, 0.11981176451912948, 0.011601338146387466, 0.017502887141225592, 0.02302669484301337, 0.00251965645916893, 0.019912163128278086, 0.04076254341219153, 0.019011138173352395, 0.022341511877519742, 0.047298871246831756, 0.01935676864481398, 0.07456679163234574, 0.03607810049184731, 0.10165451347295727, 0.03577909046517951, 0.010912586934864521, 0.05173622903281024, 0.03021412282916052, 0.04238725819491914, 0.030777289931263243, 0.07918980677745172, 0.060158507632357736, 0.028828008100390434, 0.023229754929031645, 0.015036909375339746, 0.06348822146121945, 0.01649383262598089, 0.01983630800220583, 0.06389839587999241, 0.07405037898570299, 0.06828260741063527, 0.0252461845853499, 0.050526105931827, 0.01964772615714797, 0.04217001163799848, 0.05474764208442398, 0.04390968043091042, 0.017418041426156248, 0.0933853971904942, 0.0516682771433677, 0.040956438186445406, 0.027073554029422145, 0.02322433004155755, 0.11863867246678897, 0.05527265176975301, 0.05777395237237215, 0.028727103157767227, 0.05103482399135828, 0.029575539952410117, 0.06652502529323101, 0.01998577399977616, 0.005689703152581517, 0.011521944460192961, 0.014237411918916872, 0.06750706224037067, 0.028027234998132502, 0.008667865019690777, 0.04094662657007575, 0.05102988086374743, 0.01322187400156898, 0.05606593723808016, 0.04977518479738917, 0.041699691875172515, 0.03298972121306828, 0.04818803032061883, 0.028835383776043142, 0.020029346125998666, 0.029485165873276334, 0.018888696529237286, 0.12372688443533011, 0.00134008980447626, 0.029096955633057014, 0.025141262715416293, 0.018777869708303894, 0.002021294752401965, 0.07046877260186843, 0.024001926083916, 0.02684168504284961, 0.0684269250237516, 0.02279461211790996, 0.02390379804585661, 0.028507335843252282, 0.06728387850203685, 0.0030921016794828965, 0.055632614597145996, 0.044912456800895076, 0.004721024439537099, 0.07835159211286477, 0.04778419681159513, 0.031082841035510813, 0.022820086018847566, 0.10330019159508602, 0.015712290902488997, 0.028024739685601423, 0.04229041767705764, 0.05081237646351967, 0.04057808706004705, 0.05632763123139739, 0.0561196839969073, 0.056737337461007495, 0.029702263152492896, 0.04450914576383574, 0.05205768499789493, 0.08593228712145771, 0.00932696764357388, 0.052110817682530196, 0.028341142261134725, 0.010578979255764611, 0.004644898323541773, 0.07292977840240512, 0.05559479644788163, 0.02498201054653951, 0.023360381401809197, 0.03236972001780357, 0.03327659224825246, 0.003927307677388723, 0.07221964400793825, 0.01324507565836289, 0.08486534508743457, 0.031049273908138275, 0.030141943666551794, 0.0512466694095305, 0.052742438789989264, 0.02188126666338316, 0.034149853246552606, 0.02800755578625415, 0.0011043362049219596, 0.014380092566300715, 0.020483172398858836, 0.07164668225284133, 0.029107157407062392, 0.08501860579209668, 0.04941083524110062, 0.017550372718168155, 0.05879436047481639, 0.015215993426474077, 0.029158590361475945, 0.043257211335003376, 0.014753015412549888, 0.027550229969035302, 0.013786831587952162, 0.09103651930178915, 0.01882153343675392, 0.0315406486125929, 0.007114545691625348, 0.031214500577854257, 0.010991894107844149, 0.02217120976586427, 0.06333994798894439, 0.061084402592054436, 0.04765097663870879, 0.043297618095363886, 0.040820809214242866, 0.016217246485341872, 0.06827772874385118, 0.03979676755677376, 0.028472577886922017, 0.07175745309463569, 0.05949357045548303, 0.0332331456510084, 0.06310796365141869, 0.04808599900986467, 0.01655721288573529, 0.01725399031836007, 0.023315711745194027, 0.0658671652366008, 0.04181657631748489, 0.0028140191570855677, 0.018551052414945195, 0.017139336559921503, 0.006294780818279833, 0.019972993792699914, 0.03229483010779534, 0.06222420571638005, 0.019025462047596062, 0.028187888341822794, 0.07654544724417583, 0.024488600237028937, 0.030279594673109905, 0.021006470479603325, 0.019952400254883935, 0.19037277038608277, 0.06827487211142268, 0.13157039641269616, 0.07671605130391461, 0.14522633435470717, 0.059384516307285855, 0.157703005575708, 0.10238383005240134, 0.1774147464228528, 0.20388388181371347, 0.11217107344418764, 0.22560308208423002, 0.1535532618207591, 0.07866476995072194, 0.12464472518435546, 0.16693048471851007, 0.11321947111615113, 0.04277197058711733, 0.07512405887246132, 0.16215165757707187, 0.18339516408741474, 0.07233414679233517, 0.12083287829799311, 0.1719639389110463, 0.11021566444209643, 0.10158161845590387, 0.21567844892186777, 0.13424516788550786, 0.11455670078950268, 0.1278635731765202, 0.24112835686121667, 0.12020302138158254, 0.11264946098838534, 0.12335180384772164, 0.16220504471233912, 0.13474623885537895, 0.04291819827631116, 0.1907222294913871, 0.20663729549518653, 0.11673166336757795, 0.17900919515107358, 0.08539450062172753, 0.09876653272658587, 0.24246466372694286, 0.1897118365658181, 0.11470827194196836, 0.08705837705305644, 0.07898708086993013, 0.07323078332202775, 0.19809491959001335, 0.10125976894050837, 0.09242586724992309, 0.14020695297845773, 0.20777384165142262, 0.14379746174173696, 0.14652845662619385, 0.1644240849252258, 0.16060959175229073, 0.0918514873566372, 0.14874266566974775, 0.20603907188134535, 0.11223379043596131, 0.07802457894597735, 0.09033742467207567, 0.16586508974432945, 0.08485910935061318, 0.14308171586266585, 0.14755555508392199, 0.06441152441714491, 0.11319758836179972, 0.11184845039887087, 0.07871321735105344, 0.15226567376937183, 0.12943506027970994, 0.10369779275996344, 0.16954507013516767, 0.1592245932136263, 0.11784201807209424, 0.08636159622775656, 0.1598854727510895, 0.10163037119699375, 0.1137834694236517, 0.2096601418618645, 0.15008379013410636, 0.09971139952540398, 0.14360895114285605, 0.1436505046273981, 0.1561724612755435, 0.14087103520120892, 0.133947793128235, 0.16062675868826254, 0.09123723674565554, 0.16342788695224694, 0.23308112152985164, 0.14550799424094812, 0.12759646108107908, 0.11805316459919725, 0.14317010183419498, 0.2286205408828599, 0.10758152364620141, 0.1762715099113328, 0.07770756059991461, 0.09730267484805413, 0.1151966814483915, 0.180956169962883, 0.18937525605516775, 0.18796276327754768, 0.0740197499149612, 0.23308253288269043, 0.1065198334732226, 0.08222426966364894, 0.1448868361434766, 0.18451268412172794, 0.14281971992126533, 0.0627417243751032, 0.0968863596873624, 0.18415483832359314, 0.18595914436238153, 0.16324123553931713, 0.10063033950115953, 0.13627401473266737, 0.0803241001974259, 0.12522195492471966, 0.15490062880728925, 0.1086448287325246, 0.09914130118808576, 0.12046532944909163, 0.10112765817237751, 0.15279335688267434, 0.09868058948112385, 0.11743558916662421, 0.1260316643331732, 0.08553151041269302, 0.04819626773574522, 0.10928744210728578, 0.1147310978599957, 0.12950804350631578, 0.10244471499962465, 0.14667103040431226, 0.12200415187648364, 0.100365032308868, 0.07155066276235239, 0.11378887734775033, 0.17012453904109343, 0.20560014114848205, 0.12074791214295796, 0.1616434891309057, 0.13109220564365387, 0.09887001610227994, 0.14386268252772944, 0.24789354098694666, 0.09746768777923924, 0.2062242440879345, 0.16004211934549467, 0.1396875615630831, 0.09626385809055396, 0.15672052758080618, 0.1418405260358538, 0.07624212852013962, 0.07044139371386596, 0.17173953380967888, 0.1378384857837643, 0.07278005286519017, 0.13457995706370898, 0.1145240632551057, 0.19661012212080614, 0.10624936262943915, 0.17951882923288004, 0.07651231437921524, 0.10543309857270547, 0.08930050102727753, 0.2330263773245471, 0.1002656812114375, 0.11140365033809628, 0.16123969294130802, 0.11581522040069103], [0.012206613435409963, 0.0347912486509553, 0.022050693464864577, 0.018608122299026166, 0.022114930375080024, 0.007214121553780777, 0.06779266441506998, 0.053899429206337245, 0.03588520994942103, 0.09621199087372848, 0.02249843836762011, 0.03984501478927476, 0.036731967369892767, 0.024071871169975827, 0.04210537099944694, 0.017097535410097668, 0.04882553093401449, 0.010984224117627102, 0.022324957319402268, 0.04263981571421027, 0.07913908628480774, 0.03535075844930751, 0.038199614866503646, 0.03853650750326259, 0.00849445945849376, 0.028981343443904604, 0.02518637850880623, 0.029242046776094606, 0.007025612227153033, 0.01194345295828368, 0.0659806773598705, 0.041618257494909425, 0.04763023382318871, 0.012786726101434656, 0.039560494877930195, 0.057618296439094205, 0.02793763784159507, 0.010927373909258416, 0.035046751012227366, 0.046496727503836155, 0.015386987643848573, 0.07730942339237247, 0.028635568783751557, 0.039876237578157864, 0.054895722174218724, 0.06838614506913082, 0.026822126270937066, 0.04409254561843617, 0.06354862464857952, 0.03858684462362102, 0.0223070202461843, 0.08014398986207587, 0.023197349792878543, 0.018442675105429122, 0.05148898444271513, 0.017608643609232137, 0.031301112180309634, 0.07489898880677563, 0.030491636866437535, 0.03130179750067847, 0.023078945432124392, 0.009504747211134859, 0.05707140399941376, 0.029832284032766308, 0.027041715470009615, 0.028270220084648048, 0.03614741962935243, 0.018357634311541915, 0.01506265638662236, 0.006469454391792948, 0.029175258574209044, 0.012177305811616992, 0.011283810050891978, 0.0166212157013693, 0.027380180611674274, 0.018998912668653896, 0.04963375435077718, 0.0345853166654706, 0.0829125755865659, 0.037983745735670836, 0.04195561832083123, 0.037911369797906706, 0.022212976988937174, 0.046498467946158986, 0.05226355930790305, 0.05448749854362436, 0.043992566876113415, 0.04601666737081749, 0.06075857686144965, 0.0241672698009227, 0.01684429426677525, 0.05619879100205643, 0.023785970439868312, 0.03833240756232824, 0.03910725723419871, 0.08741388190537691, 0.07799436378159694, 0.06439108015703303, 0.050227689623300514, 0.033508518910301585, 0.02885134970503194, 0.041026364612792215, 0.05915279659841742, 0.010981896742513137, 0.025476177422595874, 0.027268719360498444, 0.10657491016068629, 0.04817194564800177, 0.0568284511433116, 0.049771167870078764, 0.08462865171687943, 0.07811723290277378, 0.03573365915300591, 0.029885389576000825, 0.020382547351930822, 0.029990755886371647, 0.02081771391177816, 0.02109578943678311, 0.02240971482491919, 0.02608515920915774, 0.03034081549516746, 0.06269703605877501, 0.04882493043052299, 0.017590586096048355, 0.02975677665589111, 0.013819742232694157, 0.05784559209964105, 0.020185154729655812, 0.02513437219230192, 0.05791418520467622, 0.04106684601200478, 0.040436646435409784, 0.029096694397074834, 0.04122072757620897, 0.05219898313017828, 0.0475928906484374, 0.01977534163078027, 0.0654578118452004, 0.020505677709089856, 0.054325159040412734, 0.06100520398467779, 0.028252388184357966, 0.020144247549719045, 0.03626542365444558, 0.06228687521070242, 0.004348333143363041, 0.008425484677510602, 0.03644207346120051, 0.07002376898058824, 0.04416586811255131, 0.02556641579472593, 0.020931858768952743, 0.01523212220386735, 0.012024918720791382, 0.0165565801518304, 0.035226101388356516, 0.04415368840896657, 0.021388962365952984, 0.013522845842609448, 0.013545452933093267, 0.005277354029073779, 0.045698458195797036, 0.019324044597202113, 0.08052228670567274, 0.03759518265724182, 0.014630728135151523, 0.036167521229279895, 0.04211662450273122, 0.030548969682838236, 0.020925957210628048, 0.05688959393384201, 0.0405685706064105, 0.05110200574355466, 0.027280212047376802, 0.01737560754242752, 0.007692627841606736, 0.010643491820831383, 0.05409456569967525, 0.044064908887126615, 0.017570666004238383, 0.0467395378675844, 0.04281308641657233, 0.06884205953351089, 0.054888146330735514, 0.0500959147300039, 0.07814883906394243, 0.00947460753377527, 0.05381303134241274, 0.03740306903741189, 0.030512983578124216, 0.0607367619606001, 0.024654047430625985, 0.05539279657282999, 0.03390646612803851, 0.054443841600524526, 0.07406087592244148, 0.05958262139133044, 0.06491109582462481, 0.039488695694931915, 0.026954187845279063, 0.020279347264607037, 0.03796637184651835, 0.02860243252611586, 0.06871486135891505, 0.041817773931792805, 0.03919120219403079, 0.03270712494850159, 0.02066255670173892, 0.03181910242087074, 0.032413597484784465, 0.03239686820389969, 0.026828406112534658, 0.03167699004656502, 0.013007093071272331, 0.04181020826633487, 0.005688285014392542, 0.012079559449505593, 0.027093407964067798, 0.01203280160137053, 0.017534754538376416, 0.03619384838800345, 0.04752914906878557, 0.02677684254013002, 0.014868398596133505, 0.021092624070921114, 0.023272991180419922, 0.03170281848204987, 0.11047915994588818, 0.044224819234971485, 0.0515588362302099, 0.021985840784119706, 0.023466003859149556, 0.027252800928960954, 0.015541525690683296, 0.017971055948042443, 0.017277949389868548, 0.022440096230379174, 0.07713489740022592, 0.04318644352523344, 0.030307312828621695, 0.002718993296314563, 0.049545782285609415, 0.081239057172622, 0.030118734376238923, 0.030436916409858635, 0.03207651146554521, 0.05196887494197913, 0.0053836270318632674, 0.022088380996137857, 0.023403598993484463, 0.02376045243415449, 0.022273605789190958, 0.06910087314567395, 0.06078436119215829, 0.04422567758177008, 0.039261752872594764, 0.04468701354094914, 0.03676482542817082, 0.04225954772638423, 0.07081180598054614, 0.043299266935459206, 0.03680340014398098, 0.03823664591514638, 0.05664972162672451, 0.07499542898897614, 0.042035563316728385, 0.04683745725612555, 0.019237906272922243, 0.032384284771978855, 0.022363392935533608, 0.05076144223234483, 0.029066170499260937, 0.02275792881846428, 0.05408880154469183, 0.03784507014123457, 0.0730269853291767, 0.03220535848023636, 0.0228118095879576, 0.0375912742955344, 0.036332130432128906, 0.0278879470258419, 0.020013039233163, 0.043613476146544726, 0.05207523191347718, 0.010805173993243702, 0.029149060337139026, 0.05541901516595057, 0.011136304171356772, 0.02207770085494433, 0.04801579099148512, 0.06200009238507066, 0.01963806721115751, 0.02006956628922905, 0.07103243164185967, 0.02936687007812517, 0.0466235694475472, 0.03609624791092106, 0.019335369346663356, 0.04128108326611774, 0.02774688129180244, 0.027167841559275985, 0.0035543072236967938, 0.012822605336883237, 0.01599705169376518, 0.039445089641958475, 0.026670539851433465, 0.013061654072121849, 0.031529086375875134, 0.04731208910899503, 0.02829427584739668, 0.010270643613434263, 0.08423614634999207, 0.03493433811568788, 0.04169681488669344, 0.03194928275687354, 0.013631051822033311, 0.025639592403812066, 0.018411342054605484, 0.04829788174746292, 0.016431987551706176, 0.014438955479168465, 0.06369737309536763, 0.008938865968957543, 0.016785809637180397, 0.04219654914257782, 0.01585309031153364, 0.0479532470261412, 0.019836265593767166, 0.011599272855424454, 0.023359368688293865, 0.028101227545578564, 0.05345147056505084, 0.016129971614905765, 0.034660193004778454, 0.03563620116827743, 0.017113616690039635, 0.08524414404694523, 0.04100097383239439, 0.033013385121843646, 0.02904236749080675, 0.048825819311397414, 0.010350025425265943, 0.0543364702191736, 0.03809585668412702, 0.043197364546358585, 0.029853325403694595, 0.035891211591660976, 0.021575824124738574, 0.01129637736760612, 0.009860002701835973, 0.04163865425756999, 0.01963246420824102, 0.1145192456564733, 0.10589242606822934, 0.1689353385674102, 0.12625438666769437, 0.14552339698587144, 0.11534434423914977, 0.20058659517339297, 0.13940786942839622, 0.10471050627529621, 0.2722227397773947, 0.08314865827560425, 0.18651124116565498, 0.13258184785289423, 0.11890974720673901, 0.16416381246277265, 0.05288312963343092, 0.14608256412403925, 0.08514332731387445, 0.12877850979566574, 0.18589553848973342, 0.19690960033663682, 0.14165052265993186, 0.09456173942557403, 0.1274424200611455, 0.14169878007045814, 0.08986280978258167, 0.14855643494852952, 0.20126188679465226, 0.05378852944288935, 0.12145144439169339, 0.12411690636404923, 0.10733219595359904, 0.11324023428772177, 0.09117941877671651, 0.09288821422627994, 0.22910743047084126, 0.08500105887651443, 0.11759918395962034, 0.15292303849543842, 0.12354405995990549, 0.10355209772075925, 0.16839063779584, 0.15449272069547856, 0.09373938890972308, 0.09618928030665432, 0.18550399664257253, 0.09972934677664723, 0.08251063179756914, 0.1452646715832608, 0.15660657440977438, 0.13061428628861904, 0.19017344393900462, 0.11429469127740179, 0.13550976717046329, 0.07735296498451914, 0.09141706209629774, 0.13363135153693811, 0.11676177675170557, 0.0957958996295929, 0.11664333167885031, 0.0757999543898872, 0.20693780508424553, 0.11409478129020759, 0.1217458335948842, 0.09323119332215615, 0.27663319025720867, 0.17199870704540185, 0.12166508792766503, 0.1261703297495842, 0.06834776034312588, 0.06724045904619352, 0.08446450731051819, 0.11167937982827425, 0.0972252336463758, 0.15817312177802834, 0.07925120741128922, 0.19475769437849522, 0.19356294348835945, 0.2271107868956668, 0.10268695878663234, 0.09753847255238465, 0.1328774177070175, 0.0877870422388826, 0.18378187476524285, 0.16730658310864652, 0.1426752055329936, 0.09039354630346809, 0.12757648501013005, 0.17848780884274415, 0.1230704425168889, 0.12817592998700483, 0.15471484591918333, 0.12417797451572758, 0.1255710476211139, 0.12163132402513709, 0.19299002923071384, 0.11029622690486056, 0.20695710262017591, 0.11837126181593963, 0.14509098018918717, 0.09489541580634457, 0.07383155144218888, 0.160254514377032, 0.08498237202210085, 0.11680334380694798, 0.1394732937748943, 0.187017984688282, 0.10400909105581896, 0.12426542410893099, 0.08749539431716714, 0.17282478271850518, 0.128001139366201, 0.12782009265252522, 0.14527157906975063, 0.1282137922410454, 0.10828318313828536, 0.08022950563047614, 0.16333948741001741, 0.2297577927155154, 0.08239941990801267, 0.12682104483246803, 0.12203191752944674, 0.10129766512129988, 0.05763346169676099, 0.07108737940766982, 0.09682456550321408, 0.10702147441250937, 0.09784477683050291, 0.07730609178543091, 0.1422068535217217, 0.1340697801538876, 0.14005207057510102, 0.11984143007014479, 0.07604517016027655, 0.11932722266231265, 0.13342281058430672, 0.06678921968809196, 0.17933858319052629, 0.1307161615363189, 0.13714209172342504, 0.17034803490553582, 0.10722985930208649, 0.11337848579777138, 0.14479907442416462, 0.12209601194730826, 0.15681124771279947, 0.06928963480251175, 0.15410286161516393, 0.16196469403803349, 0.11654369559671197, 0.1588491326464074, 0.14965062694890158, 0.11505538331610815, 0.0730622759354966, 0.04141580639407039, 0.11278530369911875, 0.14572693035006523, 0.1170266361108848, 0.12001390010118484, 0.15569690322237356, 0.21150145520056995, 0.1247782473053251, 0.10969037655740976, 0.10870470944792032, 0.12371254020503589, 0.10957033692726068, 0.11566614625709397, 0.2027402381811823, 0.08798270459686007, 0.12163121545953409, 0.12124500689761979, 0.12752076371439866, 0.10298672877252102, 0.061774859470980506, 0.05433751855577741, 0.0872154850512743], [0.01618103137505906, 0.06307638463165079, 0.027199988852122, 0.022941971264247383, 0.0197177441857223, 0.023803103449089185, 0.03256664445091571, 0.02240544853598944, 0.019329028436914086, 0.04188125766813755, 0.06426095071115664, 0.020856171580297605, 0.047187672927975655, 0.023800533497706056, 0.028281617776623795, 0.030826107133179903, 0.06268662054623876, 0.054804092805300436, 0.03928927086027605, 0.016297664759414535, 0.022361642315185497, 0.031575084264789305, 0.013647245060253357, 0.03479083813726902, 0.03312791504764131, 0.02111904792088483, 0.035863819132958136, 0.04815318415473614, 0.005710079559191529, 0.03540673419567091, 0.020613866725138257, 0.020003868832385967, 0.06265337911567517, 0.04298312050689544, 0.01550063377778445, 0.06841058590050254, 0.019941346919430152, 0.039327197575143406, 0.01705538311840168, 0.03492487255217774, 0.015198763726013047, 0.022590106752301966, 0.016481137235781977, 0.012067683390341699, 0.028336611343547702, 0.0107587002816477, 0.013667653697276754, 0.026360288195844208, 0.04379126589213099, 0.005732565361540765, 0.007863488896483821, 0.0278835297628705, 0.04368662561423012, 0.0680916676563876, 0.009956389449403753, 0.01276659990461277, 0.015081802948511072, 0.05502409760707191, 0.03985325559707625, 0.03571246171902333, 0.024474159315494553, 0.025271431177056262, 0.07349966639386755, 0.021400824854416505, 0.01608714078819113, 0.03304169360282166, 0.0955003501315202, 0.04615073571247714, 0.06607221851923636, 0.0272780288609543, 0.008964615524746478, 0.01608879810997418, 0.007413901771152658, 0.025230666489473412, 0.02786692601096417, 0.053345554641314914, 0.03904740705287882, 0.025338070101237724, 0.034907807396458726, 0.03476548467629722, 0.07242816460451909, 0.06900909449905157, 0.034673326050064394, 0.023723026138863394, 0.024431045200409632, 0.020184649221066917, 0.09201046132615634, 0.059503646700509956, 0.004330568672490439, 0.007520358826565955, 0.054004530888050795, 0.047120793123862574, 0.03371618455275893, 0.07965403329581022, 0.03112598229199648, 0.02137266395480505, 0.05474670231342316, 0.0016588373546255752, 0.02563949062355927, 0.03541861195117235, 0.03512990887143782, 0.01754163657980306, 0.030278821143188646, 0.1032331387645432, 0.04006178976435747, 0.055993693614644666, 0.030150157332952534, 0.07309431635907718, 0.018426510704947368, 0.07198161392339639, 0.045723374001681805, 0.01792136173961418, 0.011114021929513131, 0.04910930784951363, 0.0561222420739276, 0.033851145167968104, 0.023263286433315704, 0.06324254428701741, 0.05679458885320595, 0.02616456137703998, 0.045578611948128255, 0.02859722137717264, 0.05947280728391238, 0.020875559022117938, 0.07038365716912917, 0.044298830442130566, 0.02524129574054054, 0.049473477594022236, 0.010853556932748427, 0.041444291294153245, 0.003914320517131793, 0.04482199790488396, 0.03625752550682851, 0.04601200583523937, 0.05007112445309758, 0.021520976442843676, 0.011552840704098344, 0.03351770966712918, 0.00823230660587017, 0.043803771292524676, 0.022967587657538906, 0.00904968600454075, 0.027498277935332487, 0.0881327490455338, 0.06955080971653972, 0.0383130455655711, 0.012634484047469283, 0.05442659663302558, 0.01296541151324553, 0.01541281268665833, 0.05992448090442589, 0.020051702158525586, 0.01188874352789883, 0.06974742880889348, 0.030919785677854503, 0.060409205965697765, 0.02616406774281391, 0.0022598742382667425, 0.006148946255312434, 0.069847872347704, 0.027993340477613465, 0.03256813044260655, 0.06209512121443238, 0.02236049559100398, 0.04857490384685142, 0.06344045938125678, 0.02131815723675702, 0.022971884480544498, 0.015280060702934861, 0.035361072181590965, 0.017712934441598396, 0.10829087772539683, 0.013796412502415478, 0.06255847242261682, 0.03934476484677621, 0.09170101543090173, 0.036128922764744074, 0.03919144307396241, 0.028016151128602878, 0.019704468648082445, 0.0582018094137311, 0.015203016444242426, 0.014395546201350433, 0.03674740743424211, 0.02528049810124295, 0.059704303076224666, 0.03813379018434456, 0.07713608483650855, 0.027402037920962487, 0.028794339192765098, 0.02402364938253803, 0.020576152052464228, 0.03536860392029796, 0.028687154408544302, 0.034830074424722364, 0.03969784393640501, 0.0730557959260685, 0.03952594387478062, 0.024128647587661232, 0.017250046333564178, 0.0250402017097388, 0.10650656811360802, 0.08460512012243271, 0.0472016032519085, 0.052012881330613575, 0.03842694106112633, 0.0038808013112949474, 0.022460642270743847, 0.05210498567404492, 0.06773722131869622, 0.01071796952081578, 0.02487419472475137, 0.03174037539533206, 0.016248148666428666, 0.02009469922631979, 0.035693561126078875, 0.029227322566189935, 0.07118848791079861, 0.028008358153913702, 0.060316585935652256, 0.05518626408385379, 0.015422057726287415, 0.048456604659025154, 0.021484834275075367, 0.01320741866116545, 0.021743227195526873, 0.06441024877130985, 0.013530839833297899, 0.05390191603718059, 0.008185957575083842, 0.017213342678067938, 0.005032281599207116, 0.04764205051053848, 0.04515562000285302, 0.021975169124613916, 0.0389476115150111, 0.02285632148518094, 0.05127049955938544, 0.03030520597738879, 0.02149371799480702, 0.040514847596309016, 0.04780783357896975, 0.022038313593449335, 0.02614089407558952, 0.05578831124252506, 0.021913839736953378, 0.04595145337017519, 0.08632264831768614, 0.062074928012277396, 0.07510437457157032, 0.06415827479213476, 0.058427245888326845, 0.05656701838597655, 0.017535477178171277, 0.03603661486080714, 0.017892340796866586, 0.02341401620235826, 0.08372575230896473, 0.016722785608310784, 0.030804051352398734, 0.04092533753386565, 0.023680040945432017, 0.05001613597518631, 0.06494677998125553, 0.01968192432208785, 0.029923390929720232, 0.05077384924516082, 0.02275189833848604, 0.026938742691917077, 0.10810075899852173, 0.0035672884467723115, 0.047991292484636815, 0.012760859498355006, 0.03582293400540948, 0.02338281037685062, 0.012891622526305062, 0.05288270215636917, 0.0611175558130656, 0.05569783877581358, 0.03333831179354872, 0.020258704533002207, 0.06003811516399894, 0.04454550167013492, 0.08445177799356834, 0.015628652979752848, 0.06904209844235863, 0.02279562483142529, 0.05630368573058929, 0.03787561100242393, 0.04145311903474586, 0.032875150575169494, 0.04105269516419087, 0.03790322059233274, 0.06680057836430413, 0.058208221569657326, 0.030634770435946326, 0.05748037741120372, 0.07171052561274596, 0.07641581312886306, 0.08217735575245959, 0.028458186159176484, 0.048901065452290435, 0.03325634815597108, 0.06452351662197284, 0.03202525493023651, 0.08927442492651087, 0.024928536898057376, 0.0317167623766831, 0.06762003832097564, 0.021737519019682492, 0.08923860506287642, 0.028078951240916337, 0.04224296433052846, 0.03156396646850875, 0.015478420237611448, 0.06819586349385125, 0.028128918559689606, 0.020990338309534957, 0.06548255123198032, 0.034140947474432845, 0.016219519577654343, 0.047429896358932765, 0.09389511269650289, 0.036904803809842894, 0.01658720922257219, 0.008565856609493494, 0.04126110380249364, 0.05244608183524438, 0.027115648645641546, 0.0362147099471518, 0.07699703265513692, 0.08211803822112934, 0.02375654237610953, 0.0251742938001241, 0.04666904825717211, 0.04703446311343994, 0.064395918111716, 0.026699662574433854, 0.08886668644845486, 0.07757994173360722, 0.02105997296582375, 0.04645803065172263, 0.05508950159751943, 0.029646538464086394, 0.0060618537411625895, 0.008553800738549657, 0.06763671671173402, 0.08022850139864854, 0.009328592734943544, 0.051039468563560925, 0.019626306502946785, 0.04231521473931415, 0.06041961469288383, 0.11811890107180391, 0.20123678099896225, 0.07447100284376315, 0.12891353826437676, 0.18673591768102987, 0.09315903790827308, 0.07281017303466797, 0.11005493985222918, 0.13740840314754418, 0.12581404458199227, 0.15298141964844295, 0.12876263207622937, 0.1058761208717312, 0.14948167172925814, 0.09749531772519861, 0.11580642658684935, 0.09480206295847893, 0.11276433696704251, 0.0885487317240664, 0.12417808308133058, 0.11656103895178863, 0.10591039367552314, 0.09626769181340933, 0.09513815492391586, 0.17048486827739648, 0.25292175688913887, 0.13125995307096414, 0.2099630263234888, 0.09868430106767587, 0.0812870974519423, 0.1264910732528993, 0.12917033662753447, 0.13343049160071782, 0.0655657464106168, 0.11317117299352374, 0.09230635009173836, 0.1177455982459443, 0.11485475408179419, 0.10206157341599464, 0.10206870481904064, 0.10430168892656054, 0.10632399469614029, 0.10396875214896031, 0.11780738564474241, 0.07637069055012294, 0.17815706373325416, 0.1113358104069318, 0.1355512256601027, 0.12159792653151921, 0.15224497845130308, 0.11807520341660295, 0.19681339764169284, 0.13743775657245091, 0.14545525849929877, 0.08110993874392339, 0.10155778152069875, 0.13211787917784282, 0.16556297881262644, 0.11516966218394892, 0.17179388446467264, 0.08730515345398869, 0.09598846786788531, 0.1054013092070818, 0.12397692458970205, 0.12025571641113077, 0.18829662964812346, 0.15013898217252322, 0.0819131884989994, 0.11332287985299315, 0.08274663984775543, 0.14362805868898118, 0.1001893731632403, 0.1182253360748291, 0.13699419823076042, 0.18707414024642535, 0.1716268291430814, 0.15061322386775697, 0.17309247835406236, 0.14762304217687675, 0.11318734248301812, 0.2756671735218593, 0.1395181313689266, 0.05708719350929771, 0.10049802517252308, 0.1543525489313262, 0.1029122324128236, 0.1672776232340506, 0.11962704014565263, 0.09196371026337147, 0.2433717836226736, 0.15310420734541758, 0.1458293619964804, 0.1549212427011558, 0.09095643859888826, 0.10422033257782459, 0.21904635748692922, 0.10089131764003209, 0.10349272590662752, 0.0959973566766296, 0.15214359174881661, 0.12881349506122725, 0.11300823637949568, 0.1826637169080121, 0.08177315244185072, 0.14997705657567295, 0.05855398265911, 0.2164370510727167, 0.07895295055849211, 0.16137195298714296, 0.05934511377875294, 0.14578398157443317, 0.1234732209039586, 0.11989550931113106, 0.13479212139333996, 0.08124622250241892, 0.0900775593306337, 0.14533590418951853, 0.1428126088742699, 0.10065847834838287, 0.1880889300789152, 0.15268631119813236, 0.1326366870531014, 0.14513322577944823, 0.08477140869945288, 0.1360359982188259, 0.16182613718722547, 0.18377823781754288, 0.11076366967920746, 0.15781211400670664, 0.12403811487768378, 0.10868705396673509, 0.16425367764064244, 0.09134662337601185, 0.1445036945598466, 0.1277235099779708, 0.18072666227817535, 0.0717147257445114, 0.12502040288278035, 0.16619255074432918, 0.11817971138017518, 0.051724259675081284, 0.18750457572085516, 0.11364742993776288, 0.15407257181193146, 0.18542711862495967, 0.20081075600215367, 0.12941478565335274, 0.07490236112581831, 0.11117556079157762, 0.17093242997569696, 0.11544632805245263, 0.11784553288349084, 0.22304862844092505, 0.1275633621428694, 0.22175980545580387, 0.15054197769079888, 0.07123732886144094, 0.0701903086155653, 0.2036463674157858, 0.06514325658125536, 0.12910166888364724, 0.1773274868194546, 0.20221706054040364, 0.12746714587722505, 0.1919279047953231, 0.14458199750099862, 0.160204302785652, 0.06168726738542318, 0.08052654112023966, 0.0782975535839796, 0.1441260762512684, 0.12909499209906372, 0.1504815337913377, 0.1439591294952801, 0.16800537918295178], [0.02797750855929085, 0.03796119123165097, 0.040580417827836106, 0.016059789041589414, 0.03456184613917555, 0.027668099983462265, 0.055321041494607925, 0.03192408535895603, 0.01610436031062688, 0.020140703900584152, 0.01340298178339643, 0.027688057394698262, 0.04471608537382313, 0.02656425242977483, 0.00688181199698842, 0.00502739572298846, 0.04851385605122362, 0.022369177446567585, 0.05984323312129293, 0.02487330584387694, 0.03130764986521431, 0.007871024027865912, 0.054670482474778376, 0.028123989002779126, 0.045508794087384424, 0.02689610524768276, 0.006570160438838814, 0.028688060252794197, 0.02380792104772159, 0.014277533694569553, 0.012553621332959404, 0.04022484172933868, 0.05794705344097955, 0.049731588922441006, 0.01807090576871165, 0.020702188235840628, 0.01336371581003602, 0.02408288718600358, 0.009157436517333346, 0.032311118340917995, 0.005766300850414804, 0.016269955085590482, 0.11459502444735595, 0.02716403328148382, 0.04329523643744843, 0.008192949030282242, 0.040656535886228085, 0.040657994736518176, 0.044066595046647956, 0.04385584546253085, 0.0263027840493513, 0.020210961112752557, 0.047253131201224666, 0.041627326115433655, 0.04779014417103358, 0.0891848515186991, 0.044090235206697664, 0.036921716295182705, 0.06689992267638445, 0.00840407604950347, 0.04247941342847688, 0.027623484609648585, 0.01543084136210382, 0.013340639682220561, 0.03713180430765663, 0.03876930608281067, 0.0350041084789804, 0.034606575167604854, 0.038690182114286084, 0.025348395707884004, 0.057172641424196105, 0.0339749472747956, 0.052222891311560354, 0.04984522996736424, 0.006504701317421028, 0.026734954877091304, 0.020942396417792355, 0.05120092597124832, 0.022625166656715528, 0.052493016102484295, 0.03743756915043507, 0.0343476020997124, 0.03266467919041004, 0.03909610890384231, 0.02233139661672924, 0.05899549861039434, 0.05580865032970905, 0.012128856714947947, 0.02898729419601815, 0.018206343054771423, 0.07338240875729493, 0.08106333017349243, 0.02284059813246131, 0.0466830091151808, 0.024744333300207342, 0.014885613029556615, 0.03488117828965187, 0.04548542534134217, 0.023863477798710977, 0.012785158685541578, 0.004920913222511964, 0.018447523238137364, 0.014360150422102638, 0.02720776147076062, 0.04112363600039056, 0.05359963207904782, 0.021610064698117118, 0.025693267916462252, 0.050822496813322814, 0.050751450804195235, 0.05417394072615674, 0.03198262596768992, 0.04999081304829035, 0.049799703660288026, 0.010613783013208635, 0.03539624065160751, 0.034549537513937266, 0.01640398780416165, 0.013362089870497584, 0.026250635240493075, 0.02554309624247253, 0.020360099717176387, 0.030719919795436517, 0.04181772982701659, 0.021240487029509883, 0.032120287152273316, 0.009066107400160815, 0.020902106704722558, 0.028599382511207035, 0.008921416592784226, 0.009462454971591277, 0.040866135353488584, 0.010024785779283514, 0.02528732077085546, 0.06787223621670689, 0.03981071145140699, 0.007308678801304528, 0.052502888787005625, 0.04827848582395485, 0.022841210510315638, 0.04358910995402506, 0.03401018359831401, 0.08725733709122453, 0.037841992984924994, 0.014012442785315216, 0.017888805629419427, 0.005438472593336233, 0.029700953579906906, 0.03797900956124067, 0.04025378464055913, 0.0546420552501721, 0.01791648816184274, 0.03272498399019241, 0.024021327096436704, 0.05769136108990226, 0.03421203758833664, 0.019695179503677145, 0.005020692221088601, 0.02192291005381516, 0.029959438102585927, 0.011107608077249356, 0.04893153167462774, 0.04912495147436857, 0.027850142447277904, 0.035031012392469814, 0.058154468025479994, 0.09056864226503031, 0.035960724111646414, 0.042813391757330725, 0.00980556383728981, 0.028452196391299367, 0.03472728654742241, 0.013958790173221911, 0.01353728082696242, 0.013557254353405108, 0.027718849313844527, 0.04778438001605017, 0.029577941966376135, 0.04468142241239548, 0.0404282563499042, 0.02335432038775512, 0.07748760668826954, 0.018801006056102257, 0.04153148304404957, 0.04706438311508723, 0.04321820914213147, 0.046119329719139, 0.02294730454949396, 0.03086847485974431, 0.04093897948041558, 0.04953189267377768, 0.01047068421861955, 0.004817213563780699, 0.0864398991689086, 0.051312639976718595, 0.038720692441399605, 0.023075177866433347, 0.022652106193293418, 0.025883434140788655, 0.049760263812329085, 0.07370032276958227, 0.06332465380962406, 0.05089242323966963, 0.04171966794612152, 0.05420120765588113, 0.02440745593048632, 0.05855134994323764, 0.024858759749414663, 0.05712767490851028, 0.030534184404781888, 0.027745688766507164, 0.02475829076554094, 0.06655946094542742, 0.03399428552282708, 0.05252104638410466, 0.049910596638385735, 0.05313379404002002, 0.07563334690140826, 0.042718186508864164, 0.09404669741966895, 0.03890442615374923, 0.03090070527313011, 0.05004025789509926, 0.02902061026543379, 0.06030392447220428, 0.0190211262088269, 0.019326724810525775, 0.02394520055635699, 0.013086453678884676, 0.008326215004282338, 0.04370444733649492, 0.08981588230069194, 0.022913805275623287, 0.029523791479212896, 0.024942909966089895, 0.016953183870230402, 0.020148544372724633, 0.028356142974059497, 0.05045699035482747, 0.0482117417268455, 0.049572967791131566, 0.05903489435357707, 0.06115183540220771, 0.030136630737355778, 0.03230257219235812, 0.006204215053003281, 0.023043030573587333, 0.06961048008607966, 0.10863617741103683, 0.02881088187651975, 0.03070683085492679, 0.04371310205065778, 0.06177099182137421, 0.0070231826477018845, 0.008799963913458799, 0.055782984742628675, 0.016886765469930003, 0.05113442275407059, 0.02557580841572157, 0.029009458542402302, 0.02957594028807112, 0.04747058131865092, 0.10544075244771582, 0.04023126745596528, 0.024875185385878597, 0.07049397339246102, 0.03443664625020964, 0.11664747074246407, 0.04250911629891821, 0.03959279653749295, 0.016143576242029667, 0.03560688506279673, 0.013701862040241914, 0.04217934827985508, 0.022852533563439335, 0.03400166459115488, 0.0401801534130105, 0.010663789347745478, 0.06536498146929912, 0.02389477183377104, 0.034150019487632174, 0.007481218382183994, 0.0153155090686466, 0.015566531402458037, 0.027650485214378153, 0.018850461080936447, 0.09043018040912491, 0.0696138252637216, 0.03598632523790002, 0.01706806493790022, 0.0647835855239204, 0.0692908154534442, 0.02989661254520927, 0.03193712680201445, 0.02298766720507826, 0.015321963633011495, 0.014126769998776061, 0.07425171389643635, 0.02659038620601807, 0.1353970625038658, 0.021610339504799674, 0.05743017939052411, 0.02111968065478972, 0.028971653963838304, 0.0051466580064568135, 0.018706686295835034, 0.06554543785750866, 0.03507023850189788, 0.058554572984576225, 0.02394258989287274, 0.03616150601633957, 0.043883220957858224, 0.026277603614809256, 0.05688394173713667, 0.039538534092051644, 0.01993269899061748, 0.01451589456493301, 0.01379249820352665, 0.0037875964688802405, 0.04252839347879801, 0.04186251653092248, 0.04602079625640597, 0.027661981293931603, 0.018337447894737124, 0.03585015004500747, 0.023129031494525925, 0.032657825986721685, 0.00419341808550858, 0.03224634199536272, 0.025421124483857836, 0.009719113386901361, 0.031195026622819047, 0.0365681350896401, 0.02648747279973967, 0.04048169098262276, 0.021761048917791674, 0.026342742976599505, 0.07637916545250586, 0.06572484930178948, 0.06784931530377694, 0.029113131907901595, 0.025261283685852374, 0.09350184737039463, 0.01066270369171564, 0.07635487389883824, 0.009691871902240174, 0.029751005715557506, 0.01536554254458419, 0.04187382770968335, 0.01983309513889253, 0.02510417908030961, 0.036373582136418135, 0.12629693081336363, 0.09842179622501135, 0.1322645377367735, 0.10108408265347991, 0.09249203798494168, 0.14718544137265, 0.13616558483668736, 0.16535137088171073, 0.09215859909142766, 0.12299211243433611, 0.1674079562404326, 0.14921352826058865, 0.11284905206412077, 0.14120902706469807, 0.07450805085578135, 0.06175438806946788, 0.16843167559376784, 0.13049926103225776, 0.121833880298904, 0.06393568816461734, 0.1373033116438559, 0.16696195517267498, 0.2018662036529609, 0.09896908900035278, 0.15826418117753097, 0.17749208584427834, 0.1064842307407941, 0.16914313313152107, 0.15517292491027287, 0.1265022283686059, 0.09946143400988408, 0.3048254246158259, 0.15348652111632483, 0.1382475881172078, 0.09406798306320395, 0.15033761651388236, 0.14742885902523994, 0.14267097147447722, 0.1233816458178418, 0.12984242556350573, 0.07462760194071702, 0.16611686694834912, 0.2965955547988415, 0.22770937691841805, 0.16246083884366921, 0.09855164068617991, 0.08551169040479831, 0.08096970591161932, 0.1446364295801946, 0.1494737464402403, 0.08679230311619383, 0.11633169411548547, 0.0768412613709058, 0.20295342031334127, 0.08818475196936301, 0.14562269380050047, 0.10087719732629401, 0.21102779704545224, 0.126633294192808, 0.11734731176069804, 0.09050650202802249, 0.10372504272631236, 0.20531903766095638, 0.07715220004320145, 0.10987522985254015, 0.1767690796405077, 0.11615037598780223, 0.2050783070070403, 0.14329914562404156, 0.07038822370980467, 0.10491961041199309, 0.11856319223131452, 0.1728913877159357, 0.11271609312721662, 0.17954004023756298, 0.11672053539327212, 0.2050173067088638, 0.09055921741362129, 0.10305488082979407, 0.1642405412026814, 0.07132811684693609, 0.09087706357240677, 0.10128503758460283, 0.13172656803258828, 0.10221683579896178, 0.1313027957720416, 0.2126854309546096, 0.12252553818481308, 0.09535713174513408, 0.17103134681071552, 0.17105592334909098, 0.23008058539458684, 0.10139614769390651, 0.1958935891411134, 0.09384192912174122, 0.15121402591466904, 0.10514546079295022, 0.21357132627495698, 0.0936753216332623, 0.1000061279961041, 0.17459571840507643, 0.13224600016006402, 0.17478892446628638, 0.1611115312469857, 0.24387278673904283, 0.13984039479068347, 0.13922007807663508, 0.10388158754046474, 0.0785231189802289, 0.12017098095800195, 0.0865923659875989, 0.11859622331602232, 0.21549616727445806, 0.10310034267604351, 0.10698961040803365, 0.21940036277685845, 0.08523955715021916, 0.09417828571583543, 0.08222681416996888, 0.05312457614179168, 0.09276271917458091, 0.1417851032955306, 0.15796448583049433, 0.2564586071031434, 0.09929401906473295, 0.12902715216789926, 0.07820646704307624, 0.2098381623093571, 0.11298933239387614, 0.11773001908191613, 0.08587039794240679, 0.11362781349037375, 0.10051711914794785, 0.24150879787547247, 0.10612640529870987, 0.15937039681843349, 0.1008896009464349, 0.1192286450948034, 0.09817360168589012, 0.12836349063685962, 0.12355536435331617, 0.0915412340047104, 0.11839802323707513, 0.10956132598221302, 0.10857652739754745, 0.12949057801493577, 0.10991138898368392, 0.05940142539995057, 0.12310275435447693, 0.09607422790889229, 0.1877705343067646, 0.07746955765677349, 0.08940842202199356, 0.10094058606773615, 0.14090158284774848, 0.11542305430131299, 0.06450459906565291, 0.08563096329037632, 0.050716282334178686, 0.10824616226766791, 0.10190865197884184, 0.2005202615899699, 0.17930437145488604, 0.11598946819347994, 0.17053429276815482, 0.1543608677706548, 0.15454211804483617, 0.10255617116178785, 0.13589761778712273, 0.05564622261694499, 0.14523514173924923, 0.07845194744212286, 0.10495551848517996, 0.1348748348121132, 0.11149570039872612, 0.12077540638191359], [0.025834147053371583, 0.03604779711791447, 0.05735484843275376, 0.03387197280036552, 0.04191487907831158, 0.043011259354118786, 0.06504376299147095, 0.02240600323836718, 0.022926587179037075, 0.05035309646544712, 0.04210575437173247, 0.0755767027980515, 0.02808539053824331, 0.07917346765420266, 0.0660220951374088, 0.06091440921383245, 0.015322245225044233, 0.008393450191111436, 0.05790540496153491, 0.044716299112354, 0.05858299003115722, 0.0914475554600358, 0.030971795387033905, 0.07735711083348308, 0.04715850610019905, 0.026010650975097502, 0.025875480014032552, 0.00805082732612001, 0.008005703899211116, 0.04711572785994836, 0.017928298063842312, 0.05831335378544671, 0.026256328149299537, 0.06326608945216451, 0.0071551059705338305, 0.005663385323714465, 0.004640266897955111, 0.0398047301652176, 0.013806538789400032, 0.04497635105092611, 0.07523771348808493, 0.02924121217802167, 0.04046220684956227, 0.03985354058178408, 0.015934444963932037, 0.06675875346575465, 0.023324447883559123, 0.010025018177527403, 0.016796281128855686, 0.028879037326467887, 0.057133842791829786, 0.06822111178189516, 0.030476994080735103, 0.04512579160343323, 0.02346714210164334, 0.027864792018330524, 0.004137266768209104, 0.02115113244924162, 0.008087377463068281, 0.018790385286722864, 0.03335755843935268, 0.034235005998717885, 0.08878475334495306, 0.04888996461938534, 0.06740112935325929, 0.03382666701717036, 0.03824233203860266, 0.024202787716473852, 0.0296749012278659, 0.013928525815052646, 0.05292177898809314, 0.014160677241826696, 0.04327289567195943, 0.00946642440145037, 0.02665908618031868, 0.039354657887348106, 0.006984666455537081, 0.05251669358196003, 0.055561283603310585, 0.013466899782153112, 0.09849430447710411, 0.06115486166839089, 0.1605946368404797, 0.03767415056271212, 0.026228360632168393, 0.021511166522811567, 0.002231807485389124, 0.05152141163125634, 0.033726684882172515, 0.015622608929074236, 0.04098356601649097, 0.028855363239667246, 0.05562867230868765, 0.060609713063708374, 0.06263508581157241, 0.04182331756289516, 0.051999975594558885, 0.036428468834076605, 0.024895885792960013, 0.06494759422327791, 0.040471421355115514, 0.04654669142993433, 0.014719275258747595, 0.03393656933414085, 0.04275538379858647, 0.03969302633777261, 0.01927946654281446, 0.0313154903373548, 0.06797516319368567, 0.027450078200282793, 0.053373768127390316, 0.012760113109834492, 0.029303148854523897, 0.034167101606726646, 0.03950827143021992, 0.05502674728631973, 0.055617927706667354, 0.018040702478694062, 0.12388811792646136, 0.04983147606253624, 0.03752156160771847, 0.02458594287080424, 0.010445496150558549, 0.03226421121507883, 0.04863375658169389, 0.05457280735884394, 0.02377388233851109, 0.03765953152573534, 0.06032618720616613, 0.10580698493868113, 0.08499192579516343, 0.011024205945432186, 0.03627834974655083, 0.050332173838147094, 0.0553913377225399, 0.06826586116637502, 0.04486597715211766, 0.0383646549390895, 0.009207512401709599, 0.04562042327597737, 0.06819321720727853, 0.03189360895859344, 0.017394114585061158, 0.06630840977387768, 0.055472646573824544, 0.0647782115265727, 0.030352092747177397, 0.015382572077214718, 0.06921679406825985, 0.04205435873674495, 0.03474175291401999, 0.08457116623009954, 0.08521643267678362, 0.016671054098489027, 0.10616069845855236, 0.007636295016189771, 0.044032919353672435, 0.02168491728869932, 0.07212902565619775, 0.034095824895692725, 0.018361815783594335, 0.02411850688180753, 0.030264524410345724, 0.03623286075890064, 0.04062804080811994, 0.0153222367433565, 0.024873489048331976, 0.029824881215712855, 0.025324830186686347, 0.018146440286987593, 0.023457937774115374, 0.06466723712427275, 0.010208912193775177, 0.0113893256389669, 0.03556459876043456, 0.07170002189065729, 0.01409990425288145, 0.03350150964355894, 0.012397576938383281, 0.02522842732391187, 0.04817905669499721, 0.03907881643889206, 0.06891935145748512, 0.03694239464987602, 0.06025578919798136, 0.029155838901975324, 0.027873506104307513, 0.01844706861967487, 0.004404959011091185, 0.033876922713326554, 0.0777957294402378, 0.03292729599135263, 0.037078841256776025, 0.039854911222521744, 0.025846911993409907, 0.054759869285460026, 0.026362459507903883, 0.013596315918091153, 0.045452546927013567, 0.04753346794417926, 0.04995518995981131, 0.017275616925741945, 0.026043417431148033, 0.03032696320276175, 0.17415316429521355, 0.028510558884590864, 0.01625788734028382, 0.04699816148994224, 0.01987896240981562, 0.03127295636971082, 0.014011227359463061, 0.034705244337341616, 0.006183387844690255, 0.02494504565506109, 0.06251038464584521, 0.010285155781145607, 0.031708470678755214, 0.011929663430367197, 0.02907428238540888, 0.018453014282775775, 0.057291154350553236, 0.023195183569831506, 0.037083981159542284, 0.046077338579509936, 0.021156998384477835, 0.03822930416624461, 0.05577347168166723, 0.0425754905944424, 0.0004894448554426033, 0.045732205134949515, 0.009362628051478947, 0.038584222085773945, 0.01781149165305708, 0.08287460476692234, 0.05950971280357667, 0.027387669941942607, 0.029591231074716364, 0.07120678800025157, 0.01378961612603494, 0.03444388621885862, 0.0038603040406347384, 0.05290064262226224, 0.006551247547447149, 0.022408642739589726, 0.03231073836130755, 0.005258190503809601, 0.04011857296739306, 0.08901814903531756, 0.027926219793568765, 0.0042751679845553425, 0.018572468676471283, 0.05647047981619835, 0.04177162337249943, 0.0433241182805172, 0.029740620737097094, 0.019226118423310772, 0.09842951116817338, 0.10519597093973841, 0.2636636719107628, 0.1310571525245905, 0.014284346186156784, 0.03754919155367783, 0.02881441025861672, 0.018612992484122515, 0.062470724274005206, 0.024396244835640703, 0.03044360676514251, 0.07179164447422538, 0.04819270881957241, 0.05196959079642381, 0.03616400981055839, 0.041556069760450294, 0.037270228844136, 0.06205624794321401, 0.05152114700259907, 0.028672179140682732, 0.013111564563587308, 0.07968761399388313, 0.012433236498119575, 0.02875769490908299, 0.01617181856584336, 0.03783391841820308, 0.04215074124346886, 0.010985378475327576, 0.04215898205127035, 0.03081790025212935, 0.013106538315436669, 0.04261707800573536, 0.019187207832666378, 0.030031043903103898, 0.03775692165696195, 0.02797769515642098, 0.04984827319692288, 0.02075992478057742, 0.062154452316462994, 0.03285383779023375, 0.03228903881141117, 0.0051469302686330464, 0.05349580943584442, 0.011053695077342647, 0.018286299925031405, 0.04684065654873848, 0.02784170995333365, 0.07442583276757173, 0.045479729039860625, 0.059537614163543494, 0.04288510951612677, 0.017072565321411406, 0.02220887694108699, 0.03283690494884338, 0.03285164612212351, 0.012417873617128601, 0.014371644805318542, 0.03050007444939443, 0.04205089481547475, 0.056135643140545914, 0.0400844121218792, 0.056096098119659085, 0.06142273372305291, 0.07119388904954706, 0.0344594552048615, 0.012739095487631857, 0.014225088874809444, 0.06541122363082, 0.05046875275937574, 0.028914195618459156, 0.023672414211822406, 0.021424722857773304, 0.05704570109290736, 0.04961654331002917, 0.03186113427260092, 0.06318967283836432, 0.025962218841803924, 0.08651913848838635, 0.029788270858781676, 0.02470984336520944, 0.045285430537270646, 0.010433994981992458, 0.045295231975615025, 0.05348355848608272, 0.0383118920560394, 0.04810880117916635, 0.05395346094987222, 0.007364759720595819, 0.06482698462371315, 0.011219083747294332, 0.032839405350387096, 0.027064714414466704, 0.010328274985243167, 0.031136407982558012, 0.017601695410641174, 0.034129982348531485, 0.1100870142025607, 0.15053701081446239, 0.1927881786333663, 0.06509526379938636, 0.11494579991059643, 0.08696961788726704, 0.20407301666481154, 0.18010443209537438, 0.16523724129157408, 0.11932235078087874, 0.0880573366635612, 0.1743687077292374, 0.10878248991710798, 0.18521304082657608, 0.16594909237963812, 0.1256009710154363, 0.07982259496514287, 0.11050613171287946, 0.07748351512210709, 0.18368899689189025, 0.10712792977158513, 0.16993967896061285, 0.10811290477535554, 0.12899330684116908, 0.15001633018255234, 0.13675653455512865, 0.13764666393399239, 0.11109758354723454, 0.22375331419919217, 0.1288387637053217, 0.07610642151640994, 0.1456443119261946, 0.10997323066528354, 0.17626723514071532, 0.10466318524309567, 0.14443741525922502, 0.07611421109842402, 0.09556723332830838, 0.1388244785900627, 0.17175501797880444, 0.15121953561902046, 0.06800995168409177, 0.15560412034392357, 0.16442717904491083, 0.11892703627901417, 0.1073783024081162, 0.1445880771747657, 0.12313467264175415, 0.10848686578018324, 0.09229579208684818, 0.14580403906958445, 0.2285937794617244, 0.08837180371795382, 0.10571068724883453, 0.15021192468702793, 0.09546361424561058, 0.09629737093512501, 0.1760039228413786, 0.0820543577096292, 0.09703841259969131, 0.12094643791871411, 0.12745307306093828, 0.13258609548211098, 0.1151814686932734, 0.13173255271145276, 0.15238350816071033, 0.07379734649189881, 0.05729436382119145, 0.14482316241732665, 0.09108696838042565, 0.1684841534921101, 0.17792486904987267, 0.1565179577363389, 0.10518021535660539, 0.16918026256774152, 0.1276591441461018, 0.13599610035972937, 0.0952500385631408, 0.1540787871927023, 0.1956973025309188, 0.24948068867836679, 0.25253406912088394, 0.3588907149221216, 0.27080829281892094, 0.16859860877905572, 0.15575301806841577, 0.0956249088048935, 0.1156339565558093, 0.12080538405903749, 0.09826873908085482, 0.20036425281848225, 0.15103702326970442, 0.251059069697346, 0.1294925729078906, 0.1446710348661457, 0.1463412352438484, 0.14657359277563436, 0.12072857389492647, 0.24999781378677913, 0.20546478698296206, 0.15312666685453483, 0.1314315545771803, 0.20318064812038625, 0.12988677461232456, 0.09576303817863975, 0.11372426724327461, 0.09030507212238652, 0.06569109896996192, 0.12695928955716745, 0.09563894090907914, 0.1429812383971044, 0.10379959336881127, 0.13603735528886318, 0.07799836035285677, 0.11421577765473298, 0.08711160812526941, 0.15274906211665698, 0.08736286285732474, 0.22954893963677542, 0.18545340507158212, 0.0881081453657576, 0.09370323656392948, 0.15477883177144186, 0.08346757651971919, 0.06386394665709563, 0.10202050847666604, 0.12557473885161535, 0.16783149779907294, 0.17783319896885327, 0.268575451203755, 0.16435591929725238, 0.08958017959126405, 0.135985827339547, 0.08757380582392216, 0.1434066120002951, 0.14498324239892618, 0.09663821943104267, 0.1275193387908595, 0.0936987582328064, 0.16983574096645626, 0.11846578174403735, 0.09618991134422165, 0.18288263944642885, 0.15849257606480802, 0.17053250143570559, 0.19223230917538914, 0.07887244916387967, 0.17271932480590685, 0.16372037625738553, 0.21245029142924718, 0.09067323165280478, 0.1959860191813537, 0.13926473925156252, 0.14619982854596206, 0.2522823597703661, 0.09029304848185607, 0.12513841369322368, 0.1312743244426591, 0.17491036866392407, 0.16098012615527424, 0.08377683242516858, 0.10527284895735127, 0.15764564222523145, 0.1264240611344576, 0.15781751514545508, 0.08666292684418814, 0.13970474206975528, 0.12871242048484938, 0.16580369589584215, 0.103856963504638, 0.20002753660082817, 0.12608353154999868, 0.09750985194529806, 0.13240432952131542, 0.11929876490363053, 0.13032528465347631], [0.023749441507139375, 0.05510230894599642, 0.050476915535650084, 0.013286155864729412, 0.02075089856849185, 0.08340759402407066, 0.02934967939342771, 0.018799311414893185, 0.03595886153302022, 0.02683492683406387, 0.013897873843753976, 0.04294472221019013, 0.10234576423785516, 0.008860172022001019, 0.03600987379572221, 0.044380807650408576, 0.04690340407458799, 0.044076511835945506, 0.04782015238223331, 0.03751150911141719, 0.06429651951683418, 0.005632033189093428, 0.03936439486486571, 0.0299684388696083, 0.04509119988818254, 0.10449781268835068, 0.015295307384803891, 0.043463570797549825, 0.03276386743943606, 0.02283880171099944, 0.04227274862517204, 0.04830459585147245, 0.04937903230477657, 0.005204613378737122, 0.02816152386367321, 0.05828282649495772, 0.021691015622179424, 0.015356558740937283, 0.10511623628969703, 0.06987265244658504, 0.024873297362189208, 0.026640397629567554, 0.020574727128925066, 0.029918634399239506, 0.0064204255717673474, 0.000717358618983001, 0.010068538565454739, 0.007548093945453209, 0.057536132633686066, 0.02201831547011222, 0.029925840441137552, 0.008054016440707659, 0.05388174319107618, 0.047967401266630204, 0.02036472562966602, 0.023121942499918596, 0.02531200587483389, 0.0007993101171450689, 0.03612997788669808, 0.042478205636143684, 0.013489728244686765, 0.016684127771960836, 0.04061836489875402, 0.059007162627364905, 0.04848044498690537, 0.07470456138253212, 0.04986360130299415, 0.04176232065739376, 0.023548769864386747, 0.017680359671690633, 0.04162720058645521, 0.04344389667468412, 0.03582555315058146, 0.12763920878725393, 0.1008160545357636, 0.2387993261218071, 0.5814049020409584, 0.6825160107442311, 1.1647343465260096, 1.4538161030837466, 1.5319648810795374, 1.0832941851445606, 1.5798644593783786, 1.5945568595613753, 3.199170150927135, 2.0611179726464406, 0.6513988833342279, 0.2768094465136528, 0.12641077541879245, 0.06105593126267195, 0.03119011063660894, 0.07214540549154792, 0.03326550837872284, 0.017565102017085468, 0.03540514303105218, 0.07765019724943809, 0.043595966550388505, 0.033619978465139866, 0.05851126887968608, 0.048404974929456196, 0.044507439248263836, 0.0019702494111178176, 0.015997073746153286, 0.023692434387547628, 0.050624446012079716, 0.05720721956874643, 0.019616732373833656, 0.040090461261570454, 0.04837823725704636, 0.048881001171789, 0.037315473559179475, 0.07540358815874372, 0.06037224616323199, 0.0498582035569208, 0.08840676184211459, 0.025312979572585652, 0.022936673602089286, 0.06628381287945168, 0.03886610928124615, 0.05550634262285062, 0.037586867210588286, 0.06513603018330676, 0.039015753394258876, 0.014342374500951596, 0.03514454147911497, 0.015567226900852152, 0.029942450978394066, 0.023864436229424815, 0.0217812913137355, 0.07368305405335766, 0.0663978678307363, 0.02522186589028154, 0.021719944962699498, 0.03419316413679293, 0.06151592372251408, 0.01736564834469131, 0.02679505611636809, 0.11321719802383866, 0.02625802448684616, 0.012225840573332139, 0.030865794646420648, 0.04655422995399151, 0.01095382490062288, 0.02013953003500189, 0.014106810891202517, 0.02135123751525368, 0.037060863471456935, 0.01595973057140197, 0.021705819559948783, 0.0556206147053412, 0.02763885003514588, 0.08314232754388026, 0.022864988073706627, 0.06875928504658596, 0.008991592380750393, 0.011117683474107512, 0.02193313048753355, 0.0691227898267763, 0.06759199446865491, 0.03932542320606964, 0.0375625111960939, 0.054436879831233194, 0.035612557615552626, 0.04556907174576606, 0.04855700409305947, 0.01357384623094861, 0.026257695397362113, 0.04165743610688618, 0.02964590403384396, 0.041262063929545026, 0.04927031063873853, 0.01924526328886194, 0.006062408867624721, 0.06218809408268758, 0.053046252844589095, 0.00789200687514884, 0.042563232859330516, 0.06577798537909985, 0.027964143115761023, 0.030659937299787998, 0.039171918228800805, 0.019560040773025582, 0.019693554412307482, 0.0797980252121176, 0.022011545386963656, 0.04660180204414895, 0.03239136189222336, 0.008617544014539038, 0.017259304943893636, 0.03901401973728623, 0.06528790667653084, 0.09761936749730792, 0.038829705877495665, 0.05999787125204291, 0.010485753633214958, 0.07897028034286839, 0.060496479139796326, 0.0034665667086041397, 0.011163722075122808, 0.029435028920748403, 0.03307962031768901, 0.021832566508757215, 0.028779268930000917, 0.01653584072898541, 0.029870977492204735, 0.019730887409033518, 0.019098204394270266, 0.018693217375714864, 0.030950723482029777, 0.05172306206077337, 0.03982293186709285, 0.07293973929647889, 0.017845793294587305, 0.0247610473140542, 0.04396823121766959, 0.04737665171601942, 0.032137474444295676, 0.09771507486168828, 0.024310114993048564, 0.05253303609788418, 0.06791288724967412, 0.0379717661999166, 0.034924831840076616, 0.06990130698042256, 0.09175325584198747, 0.03667706370885883, 0.038591723290405104, 0.023425843067733303, 0.07924947036164147, 0.035071551467158964, 0.041125515542392216, 0.03815425819318209, 0.05662138261167066, 0.036098490469157696, 0.0628751107890691, 0.032186559667544704, 0.03352135340017932, 0.030691550246306827, 0.013619526904741568, 0.04890669390027012, 0.05088282196915575, 0.030398365442774126, 0.01924934976601175, 0.04025194581065859, 0.0597756238920348, 0.047876467396106036, 0.03537773360897388, 0.05495816096663475, 0.01902041713973241, 0.10505913078252758, 0.16176323699099676, 0.6460573471018246, 1.274782087121691, 1.0278374637876238, 2.1646378806659152, 2.625482363360269, 3.2376336412770406, 2.9083348427500044, 3.4511226883956363, 2.915185332298279, 4.149177151066916, 2.8917271281991686, 0.9772336248840604, 0.5184164419770241, 0.1367762934948717, 0.12266922476036207, 0.029892700790826763, 0.11724760782505785, 0.05690207897818514, 0.013779567870577531, 0.0309951912744769, 0.011153486374366497, 0.037945411899792295, 0.07423243671655655, 0.04336856571691377, 0.06616616847791842, 0.07106593770108052, 0.027152771296511804, 0.04057757476610797, 0.05035072837823203, 0.07844421892826046, 0.06433375073330742, 0.047427151684782336, 0.055936275981366634, 0.019966247458277003, 0.010455960856883653, 0.02892628711249147, 0.03768253047019243, 0.013292009925602801, 0.019734234283013, 0.06339684315025806, 0.048112295634512386, 0.028901635935263972, 0.07328725779162985, 0.03986568296594279, 0.045109856208520274, 0.004169022631166237, 0.014349514385685325, 0.02375596053233104, 0.03608860760661108, 0.030759963539562056, 0.07208268849977426, 0.01907471690459975, 0.00803399711315121, 0.06323798453169209, 0.030710362629698854, 0.007972526929474302, 0.015948850262377943, 0.05471900112128683, 0.024092931200617125, 0.032564605453184674, 0.023482336197048426, 0.01655001362918743, 0.04481162649712392, 0.031106901887272085, 0.05016981737156, 0.01011818358009415, 0.01303593420223998, 0.005723018797912768, 0.00997143257076719, 0.06678776083780186, 0.0578338195170675, 0.035532636368381124, 0.0197487193093236, 0.04582435019048197, 0.019027925129713755, 0.013130544036227678, 0.07539353905511753, 0.03859655445973788, 0.0131260020924466, 0.031484581264001985, 0.016746218815179806, 0.042389270051249435, 0.052322306869817634, 0.03696702207837786, 0.01992785425058433, 0.033686800593776364, 0.0188035946671984, 0.052514847966709306, 0.0781111464436565, 0.0311101079652352, 0.020155020989477634, 0.043086895652647526, 0.07139259124440805, 0.04441862240699785, 0.019183855869674256, 0.0765642901616437, 0.053223282630954466, 0.051423984180603705, 0.028431117700945054, 0.04497984550627215, 0.026061605562322905, 0.1638796827090638, 0.2212485700313534, 0.17135479088340486, 0.13777228790734494, 0.11555167739944798, 0.15887997884835514, 0.1541541860039745, 0.1793118624814919, 0.10570138453372888, 0.1283979466451066, 0.12279687076807022, 0.14927922402109417, 0.19094033778778144, 0.09307552381817784, 0.15954093981002057, 0.21627201778548105, 0.18650132098368236, 0.12194730421262127, 0.09457013290375471, 0.15201172525329248, 0.12166428725634303, 0.11136078049561807, 0.16121327078768186, 0.10939068799572331, 0.08072759783161537, 0.14270784306739057, 0.09693990967103414, 0.08450133819133043, 0.1305603834667376, 0.13870786556175776, 0.09801418666860887, 0.10535263110484396, 0.10858213888215167, 0.08220430037805013, 0.09147242376846926, 0.23655893919723375, 0.17942667060664722, 0.15577900595963, 0.2783829692218985, 0.1651317426668746, 0.10745647642761469, 0.12971811794808932, 0.08785206624971968, 0.102030767926148, 0.18412108799176558, 0.10899023019841739, 0.10972681388791118, 0.11684047324316842, 0.15029786793248995, 0.14232046742524418, 0.082448152293052, 0.11157846131495067, 0.21530646245394433, 0.21094607428780623, 0.1481459212622472, 0.10561691370925733, 0.1364540843559163, 0.09423822749938283, 0.14893288617687567, 0.1089319915377668, 0.0916543932897704, 0.09681739338806697, 0.14020959926503046, 0.18372535279818944, 0.09316267485597304, 0.16072552624557698, 0.21370767110160419, 0.18389954630817684, 0.22332678708646977, 0.0930557105956333, 0.09855891458157982, 0.13621099240013532, 0.10670235939323902, 0.2969805012856211, 0.4835687833172934, 0.7103192816887582, 1.5414503663778305, 1.3424460334437234, 2.6633576452732086, 3.187626587493079, 3.5451887037072862, 3.630444403205599, 4.12431606224605, 3.5430432302611212, 4.756424954959324, 3.423950672149658, 1.4308178914444787, 0.596467130950519, 0.4269542912287371, 0.22655607094722136, 0.09242117857294423, 0.24296156849179948, 0.16897164019090788, 0.1490085699728557, 0.10332096833735704, 0.1258269367473466, 0.1718798005687339, 0.17680987316582883, 0.1535785168941532, 0.1450113473193986, 0.16417905235929148, 0.060592261143028736, 0.1929608386542116, 0.1160899456590414, 0.13716290917779717, 0.1370734375502382, 0.17465646085994585, 0.20220480619796685, 0.14126392054770673, 0.15187182490314755, 0.16391008107789926, 0.13112260401248932, 0.09505030499505145, 0.06863249399300132, 0.15142507744686945, 0.13535888812371663, 0.17124275118112564, 0.22821963525244168, 0.1436890047043562, 0.1470629522310836, 0.09117597181882177, 0.13524862618318625, 0.10795042956514017, 0.131730924227408, 0.15625292195805482, 0.17676545626350812, 0.10758526237415415, 0.13906321435102395, 0.19150054986987794, 0.14833847592983926, 0.16144167924565928, 0.14917767447020325, 0.10212431754916906, 0.11982647515833378, 0.10273328237235546, 0.09257881582847663, 0.08883992502731936, 0.14626419437783106, 0.14516169710883073, 0.1034251641748207, 0.09845626580395869, 0.15111305990389415, 0.11141969090593712, 0.15274550659315927, 0.13500508639429296, 0.10967229359916278, 0.09306157313819442, 0.09827219282409974, 0.09483273952667202, 0.11038084022168602, 0.10597781970032624, 0.22857127924050602, 0.130910901086671, 0.12249205926699297, 0.07055464120847837, 0.12159618948187147, 0.16058800076799734, 0.10670505317726306, 0.14379188418388367, 0.15772135316261224, 0.09658249134996108, 0.1701711951089757, 0.0921536593564919, 0.17814053462019988, 0.20115565535213265, 0.11440643242427281, 0.07933019567281008, 0.10056479301835809, 0.1252884106444461, 0.10222550069114991, 0.19387848941343172, 0.16215728941772664, 0.1287090006683554, 0.24463347877774919, 0.15747709412659916, 0.1302038947386401], [0.042068974381046634, 0.01322959827458752, 0.03496292818869863, 0.029996082386268035, 0.0886657993708338, 0.07038918044418097, 0.015553333896345325, 0.01906897989101708, 0.0810799610667995, 0.073511798600001, 0.022469337697007825, 0.013625475112348795, 0.03900505628968988, 0.06923909072897264, 0.051358006828065426, 0.06642623737986598, 0.03104568106521453, 0.020299869556246058, 0.08737214521637984, 0.0491169549391738, 0.029076226388237307, 0.02846855078158634, 0.03784711931699088, 0.037605832264359505, 0.05389203656730907, 0.007492338722970868, 0.05550753005913325, 0.08268110015030418, 0.05754038704825299, 0.010513591380523784, 0.10204512572714261, 0.020608160245631422, 0.02582894777879119, 0.039581638029111285, 0.027138060657307506, 0.050777414946683815, 0.05960499269089528, 0.05887159811598914, 0.050336886263851605, 0.015937893618164316, 0.01530773305733289, 0.0484151631327612, 0.014952604791947773, 0.02520538597101612, 0.04000555617468698, 0.02933806965925864, 0.06209665470357452, 0.07899559648441416, 0.05814647488296032, 0.02030966929825289, 0.08939371138278927, 0.05796688701957464, 0.04558075951146228, 0.04691964141758425, 0.04201342271906989, 0.03224855741219861, 0.013861641770095696, 0.059049143588968685, 0.031066444236785173, 0.01715137716382742, 0.03448752619858299, 0.06152507037456546, 0.011580794650529112, 0.011039524721646947, 0.07359380634235484, 0.02611087229368942, 0.08135427920413868, 0.06218983791768551, 0.0852651922032237, 0.11528702160077435, 0.12472604082099029, 0.13578283680336817, 0.7681901220764432, 0.9432415174586433, 4.550132938793727, 10.405053326061793, 11.673812627792358, 7.644676463944571, 14.459631187575203, 16.960142816816056, 23.323707818984985, 24.159682069505962, 23.50686059679304, 19.25828034537179, 12.010378156389509, 14.494010005678449, 9.11664799281529, 8.52153652054923, 6.990150077002389, 3.3930624553135464, 1.6368580354111535, 0.41093190812638825, 0.5838834004742759, 0.39932274392672945, 0.5694528062428746, 0.4736994100468499, 1.1957498022488184, 0.41213047238332884, 1.4530921876430511, 1.8087992433990752, 0.8858078164713723, 1.8027913314955575, 1.670266711286136, 0.6505280786326954, 0.2324567607470921, 0.0419212946269129, 0.07300070566790444, 0.011787181254476309, 0.02310980181209743, 0.03976915796686496, 0.03157999685832432, 0.050429004177983315, 0.03539688865255032, 0.04007877688854933, 0.05598855710455349, 0.011996604302631957, 0.011001691305344658, 0.06453290754663092, 0.05272150259198887, 0.035331776432160816, 0.040227796749344895, 0.07102253860128777, 0.04991865424173219, 0.05002197476902178, 0.025457410840317607, 0.024036699307284186, 0.03154971044776695, 0.02396433354754533, 0.013702207244932652, 0.04667902611462133, 0.021995386075494543, 0.048851542573954375, 0.023973673582077026, 0.06185099110007286, 0.036349731630512645, 0.042499474316303215, 0.07460497958319527, 0.029784165721918856, 0.045807183254510164, 0.038952632674149106, 0.018275921731921177, 0.038905040227941105, 0.07912160043737718, 0.04349553658227835, 0.027653921994247606, 0.07784371543675661, 0.05053020089066454, 0.029750405212066004, 0.03884230627279196, 0.05193179300321, 0.020500853325107267, 0.022988457698374987, 0.049244950392416546, 0.03421648877805897, 0.021728143362062316, 0.06006807927042246, 0.04357865372938769, 0.02339122590741941, 0.020136831161965216, 0.01859245662178312, 0.015554830066061445, 0.08990911301225424, 0.018481168397037045, 0.03257124831101724, 0.04345834268523114, 0.029632882946836095, 0.019484016013198664, 0.01837590047424393, 0.024502413513671075, 0.15107213067156927, 0.03610848528998239, 0.06038579650755439, 0.01942835408928139, 0.04600840959964054, 0.0485897230516587, 0.026887196082887903, 0.03210882330313325, 0.014242687528686864, 0.04916512753282275, 0.06946713956339018, 0.06752935890108347, 0.035475792097193856, 0.040887013876012394, 0.03639253701216408, 0.11270399484783411, 0.0362109915752496, 0.05083234914179359, 0.06115957748677049, 0.03196862439758011, 0.03218483958127243, 0.021320406580343843, 0.05623288738674351, 0.04282517112525446, 0.03285922196560672, 0.054977366900337596, 0.033027746315513334, 0.02645060120682631, 0.01801512510116611, 0.02164997612791402, 0.034901707366641076, 0.023462300754285285, 0.03083604427852801, 0.018382931793374673, 0.06834266454513584, 0.02734963466147227, 0.0211365083232522, 0.00840781647379377, 0.04675637910674725, 0.034142813445734124, 0.06148768988038812, 0.024219913940344538, 0.05694094207137823, 0.04282711173540779, 0.0381307096353599, 0.08609092182346753, 0.031108669470995665, 0.07409254315176181, 0.03621003144819822, 0.016044547448733022, 0.038114211056381464, 0.02627722024252372, 0.05344727721863559, 0.06510915341121809, 0.058753302320837975, 0.07233882868396384, 0.043397403455206325, 0.016171893204695413, 0.01604547704170857, 0.032551360449620655, 0.03442718068669949, 0.03631144189941032, 0.06484193953552417, 0.03704704510580216, 0.045912824371563535, 0.03955487660797579, 0.08078573471201317, 0.06046097818762064, 0.10284696412937981, 0.043810766988566945, 0.002458125419382538, 0.052764555638922114, 0.04258999428046601, 0.06958599854260683, 0.06364567551229681, 0.21902629999177797, 0.19645789957472257, 0.1489400379359722, 0.4663130949650492, 1.250153980084828, 2.6083726414612363, 7.888369764600482, 14.807054144995552, 17.169992310660227, 12.98200295652662, 21.25916177885873, 23.6051915032523, 32.249817098890034, 34.0999938419887, 34.4562349319458, 30.916172913142614, 21.037562881197246, 23.323605333055767, 14.39873456954956, 13.306430850710187, 10.774284073284694, 5.368678501674107, 2.489633138690676, 0.6846866714102882, 0.7197436445525714, 0.35927237729941097, 0.44982219700302395, 0.2152052657412631, 1.3539012244769504, 0.6701168417930603, 1.9227350439344133, 2.5072633240904127, 1.3878225471292223, 2.3474297864096503, 2.2645336517265866, 1.0988677037613732, 0.45683200657367706, 0.20376819159303391, 0.12793530789869173, 0.11037377667214189, 0.049568180726575, 0.08452106320432254, 0.029792956143085445, 0.059461740377758227, 0.03049736370199493, 0.05299210235742586, 0.07739259821495839, 0.035375402841184816, 0.03307549482477563, 0.017348556047571555, 0.029018075937139134, 0.04024131655959146, 0.058390523573117595, 0.02457396503138755, 0.014308985489021455, 0.03371461374419076, 0.07189507356711797, 0.02678390608967415, 0.021011298256261007, 0.019233984340514456, 0.03309122665918299, 0.07909561933151313, 0.02756364630269153, 0.0008707514789421111, 0.013081629294902086, 0.02047490275331906, 0.04934165859594941, 0.03977522746260677, 0.027835984814113805, 0.05100093795252698, 0.013481780055112072, 0.003846235465191837, 0.04225754265540412, 0.04053206202973213, 0.023194096217464124, 0.036527321208268404, 0.02540026801372213, 0.06375463466559138, 0.020183295543704714, 0.014563132476593767, 0.0367076520674995, 0.035255298750208955, 0.026958013086446693, 0.11152885361973729, 0.01140346291608044, 0.02400258256654654, 0.08165109756269626, 0.026971236037622606, 0.03243044211662241, 0.056184565515390465, 0.00045921643842510614, 0.010192990369562591, 0.0325477743920471, 0.022392503784171174, 0.06272966002247163, 0.04013121407479048, 0.023696973786822388, 0.015963182618309344, 0.010254765045829117, 0.016814808527539884, 0.014626894412296159, 0.06583823928875582, 0.014392944019553917, 0.019583621561261158, 0.013805549824610353, 0.023973770273317183, 0.022518166773287312, 0.05726030136325529, 0.07466097907828433, 0.1117804611900023, 0.05278950537155781, 0.14190014212259225, 0.19028119529996598, 0.14826488202171667, 0.14192378228264196, 0.10983737438384976, 0.18478617444634438, 0.12820643692144326, 0.1394961875464235, 0.11719559133052826, 0.13735492101737432, 0.1470215751656464, 0.08528584680919137, 0.13284860711012567, 0.1531322986951896, 0.11709865581776414, 0.17838026104228838, 0.07217594635273729, 0.09757450954722506, 0.13772225273506983, 0.11032688990235329, 0.0964628995529243, 0.13559220917522907, 0.07814650490347828, 0.1051956723843302, 0.1899408149932112, 0.14200758135744504, 0.14181744227451937, 0.17416638215737684, 0.1722752914897033, 0.1410400447036539, 0.11462322436273098, 0.150634000610028, 0.21932786809546606, 0.1069579499640635, 0.1820053072380168, 0.12500934276197637, 0.08024491516074964, 0.14985129689531668, 0.1553267352283001, 0.09431574333991323, 0.1447768456169537, 0.15622172291789735, 0.12587516701647214, 0.18547556602529117, 0.21099662514669554, 0.16753159889153071, 0.1153892632573843, 0.20532552445573465, 0.16024591055299553, 0.18054975462811335, 0.06668427067675761, 0.19412952022893087, 0.1706075474087681, 0.10886427374290568, 0.1311676044549261, 0.1539829916187695, 0.19990108481475286, 0.10162188272391047, 0.1592010073363781, 0.09933441903974329, 0.11937537150723593, 0.1532882396131754, 0.08773878482835633, 0.16642064707619802, 0.09946260109011616, 0.22970695687191828, 0.257072708436421, 0.4053827130368778, 0.727835473205362, 1.699331785951342, 3.623069976057325, 9.309245109558105, 16.49468125615801, 20.525939226150513, 16.213103771209717, 25.697240250451223, 28.1232385294778, 36.60320397785732, 38.39519650595528, 39.43179825374058, 36.978861808776855, 24.78101430620466, 27.296529701777867, 18.301839964730398, 15.704247236251831, 12.1810302564076, 6.457608870097569, 3.3814956588404517, 1.2641980264868056, 1.1560126202447074, 0.7565364731209618, 1.2076130913836616, 0.8581412296210016, 1.8384340703487396, 1.1858562188489097, 2.941543540784291, 3.5319050507886067, 2.0914136384214674, 2.8330593620027815, 2.940551902566637, 1.495537430047989, 0.7333109251090458, 0.4171179490430014, 0.21160588173993997, 0.15142156263547285, 0.1297428301934685, 0.15222375387591974, 0.10624643135815859, 0.1562809861664261, 0.13235547499997274, 0.18212363017456873, 0.1620481267039265, 0.09163805416652135, 0.10332006588578224, 0.21769341294254574, 0.16906502018017427, 0.13957542686590127, 0.11583105740802628, 0.17661753562944277, 0.10805011314472981, 0.3400587625801563, 0.19262565592569963, 0.08779517108840601, 0.14941756374069623, 0.09693594702652522, 0.1288298341844763, 0.191942818995033, 0.1664798017591238, 0.11626310779580049, 0.09952663443982601, 0.1907126350062234, 0.14578046676303658, 0.09405602727617536, 0.1712073859359537, 0.1036227603576013, 0.11823904248220579, 0.16278923622199468, 0.16869956121913024, 0.1524741875806025, 0.13578468241861888, 0.1811442734407527, 0.12373121348874909, 0.1206425085131611, 0.18032904075724737, 0.12222646708999362, 0.14007106955562318, 0.13247868338865892, 0.10848683185343232, 0.10531041944133383, 0.16316510391022476, 0.1884124827172075, 0.21374980812626226, 0.19986934294658049, 0.10579808934458665, 0.11710704251059464, 0.12666908012969152, 0.0662263681047729, 0.09593478896256004, 0.1773027881447758, 0.14303562976419926, 0.1130668210930058, 0.10170520682420049, 0.060197733741785796, 0.139554568699428, 0.12995236180722713, 0.08449631703219243, 0.2167013268917799, 0.10613771647747074, 0.11440816947392055, 0.06106630606310708, 0.12125556490250997, 0.12882999703288078, 0.10197146396551814], [0.011909005431724446, 0.0417784663981625, 0.05104893412707107, 0.0299660775677434, 0.041172493914408345, 0.029071473250431672, 0.04405288863927126, 0.05151898926123977, 0.041366884019225836, 0.0080812053389049, 0.013629453872064394, 0.04717990370201213, 0.009797751354718847, 0.015330453802432333, 0.030969678357775723, 0.0670090853901846, 0.03711172645645482, 0.023865657592458383, 0.0405661651997694, 0.007121594822300332, 0.03506879661498325, 0.06430618185549974, 0.014448281942999788, 0.039639832584985664, 0.06559953066919531, 0.06885337749762194, 0.021363503732053295, 0.04576204710506967, 0.10128748031066996, 0.024958177004009485, 0.027440298814326525, 0.025669509012784277, 0.06799515283533505, 0.033375448015119345, 0.023970129932942133, 0.0719280910811254, 0.024441063769959977, 0.06775393363620553, 0.07910840293126446, 0.03228226024657488, 0.03675917323146548, 0.04681728780269623, 0.050811782745378356, 0.024639704896669303, 0.02700883535934346, 0.016224048798903823, 0.07943454078797783, 0.013570995535701513, 0.09597792343369552, 0.018295833342043415, 0.08570238588643925, 0.03612545545079878, 0.014000080725444215, 0.03214678394475153, 0.042678563456450186, 0.04660822098542537, 0.01897342858969101, 0.005620471800544432, 0.08106889416064535, 0.007796179918971444, 0.08381429434354816, 0.04377593778605972, 0.04626354555200253, 0.03591273132977741, 0.07598453627101012, 0.04457368801480957, 0.11088891367294959, 0.02799034644184368, 0.5808203848344939, 2.9076256922313144, 3.794196290629251, 9.21769390787397, 13.516969953264509, 23.006809166499547, 38.658929279872346, 48.12477288927351, 50.074371406010215, 46.985737323760986, 48.98976802825928, 49.85504109518868, 56.49346467426845, 56.090962478092735, 57.56318848473685, 59.45350497109549, 56.27436712809971, 55.764994689396445, 49.7331349509103, 43.10936859675816, 39.6894930430821, 20.27878659112113, 15.287186826978411, 11.801272988319397, 8.755942685263497, 4.962533712387085, 4.237202141966138, 5.431000368935721, 10.504052996635437, 5.173092356749943, 8.69444157396044, 12.725987894194466, 10.246166263307844, 14.013771363667079, 12.611393860408239, 10.159315517970494, 5.885813815253122, 3.594846393380846, 0.7437313230974334, 0.3847256914845535, 0.020530905641083206, 0.04711827575894339, 0.07069827350122587, 0.014416903091062392, 0.024600821447425654, 0.021254768495314887, 0.03225780923717788, 0.03641009071309652, 0.04177596599661878, 0.04130577176277127, 0.04032123441408787, 0.03614601845453892, 0.04079116401927812, 0.06071320322475263, 0.06186525390616485, 0.07123928982764482, 0.02387231571732887, 0.07532371101634842, 0.047569365839340856, 0.02169039306629981, 0.03717985815767731, 0.038729805166700056, 0.020395408983209302, 0.046797121741942, 0.07719129044562578, 0.05347648475851331, 0.013326887473730105, 0.03918086810569678, 0.015819665676515018, 0.03104395419359207, 0.014837023136871201, 0.004714841713264052, 0.056353527520384104, 0.031613811650978665, 0.008507178597418326, 0.059767216843153746, 0.03260266108970557, 0.04114051116630435, 0.01815549872948655, 0.03456511328529034, 0.029320475246225084, 0.05045760782169444, 0.020806012575381568, 0.021495850291103125, 0.03760558120640261, 0.05057059408032468, 0.07079090710197176, 0.06433216974671398, 0.009190991770343056, 0.03945950172575457, 0.012714598677121103, 0.006848809750018907, 0.02535480447113514, 0.01558965417955603, 0.009649393913735236, 0.026002520429236547, 0.050947113162172694, 0.064110763770129, 0.009062920830079486, 0.017329197443489517, 0.029341014501239573, 0.03635067818686366, 0.013674333874535347, 0.07444619560348135, 0.08026344595210892, 0.039020632061042955, 0.02469980443960854, 0.03767199621402791, 0.011044520435721746, 0.04423602863347956, 0.016356127336621284, 0.04451635180573378, 0.027135341428220272, 0.06046884919383696, 0.07047976486917053, 0.05542102702228086, 0.022418647738439695, 0.06612463534942695, 0.01901624584570527, 0.016567219580922807, 0.004934992824148918, 0.02901278675666877, 0.04694613142471228, 0.05275904254189559, 0.060477337666920254, 0.0158473108895123, 0.08145215788057872, 0.0265933598857373, 0.010341914387286773, 0.10398414132318326, 0.02749901414582772, 0.06660950290305273, 0.03522482234984636, 0.04409341075058494, 0.033023522435022254, 0.047544541635683606, 0.05544006671490414, 0.0752078036644629, 0.022483797278255224, 0.02200919765579913, 0.034669655175613504, 0.025868368967037116, 0.033482754935643504, 0.05469742031501872, 0.025008878836940442, 0.05850305860596044, 0.031729725788214376, 0.041811687472675524, 0.02822708391717502, 0.03635784012398549, 0.04353962778779013, 0.01442619223546769, 0.10141004409108843, 0.02773511888725417, 0.02679912563014243, 0.016278165359316126, 0.016975536510082226, 0.06319269231919732, 0.022336260016475405, 0.004696058591694704, 0.04479974874162248, 0.04307949962094426, 0.03099414293787309, 0.0242186535615474, 0.030717762054077218, 0.08588721882551908, 0.05950663225459201, 0.02504120085255376, 0.08740970891501222, 0.07618424948304892, 0.053852549221898825, 0.07430233939417771, 0.012064472223365945, 0.03875563360218491, 0.06806947956127779, 0.38249040714332033, 1.3984512282269341, 4.460646220615931, 6.2776500923292975, 13.083385859216962, 21.401559897831508, 32.23685870851789, 48.60227394104004, 58.31228419712612, 61.29938425336565, 58.375144549778526, 59.93121446881975, 64.4378091267177, 68.48004872458321, 67.57691492353166, 70.25912802559989, 73.0094404220581, 72.5429105758667, 71.5544251033238, 61.90000738416399, 55.55273764474051, 49.65951183864048, 27.904856647763932, 18.634544031960623, 15.257987022399902, 11.54807368346623, 6.2931910412652154, 5.776504755020142, 6.270324953964778, 12.059566191264562, 7.544916834150042, 12.986069389751979, 16.1952851159232, 12.27492994921548, 20.142711332866124, 16.16305763380868, 12.378019503184728, 7.784972752843585, 4.680875888892582, 1.274340876511165, 0.3105942207787718, 0.060057222710124085, 0.0715386119804212, 0.0270033171733043, 0.045503895064549785, 0.022251190384849906, 0.013656818341197712, 0.01919962671984519, 0.07326338692967381, 0.09800315368920565, 0.06703330909035035, 0.04707527020946145, 0.04141499215204801, 0.022644311522266695, 0.017657411617359946, 0.01379299523042781, 0.02058755144077752, 0.10618359223008156, 0.047013974748551846, 0.03313485985355718, 0.043140303143965344, 0.06279095209070615, 0.08016249351203442, 0.01477897446602583, 0.016901167375700812, 0.054582035435097556, 0.013352581898548772, 0.03499171842953988, 0.028123625986544148, 0.05239896097087434, 0.019261434474693875, 0.03629219186093126, 0.026838706274117743, 0.015840123507327268, 0.037002458569726775, 0.05125868287203567, 0.04137020205546703, 0.02678439293855003, 0.03679486417344638, 0.01837799375477646, 0.03191684199763196, 0.021952215981270586, 0.03455891826057008, 0.020169940278200165, 0.01062660223604845, 0.0019201156392227858, 0.022036110050976276, 0.06071882828005722, 0.02441778832248279, 0.06175640331847327, 0.04232081265321799, 0.023674980770530443, 0.01476280836920653, 0.07806187801595245, 0.03555479392941509, 0.031208200380206108, 0.005609893015519316, 0.02473979220459504, 0.021987177498106445, 0.038619051288281164, 0.015910099127462933, 0.034482006316206286, 0.019563789679003612, 0.03660886754680957, 0.06428731858198132, 0.03640232827248318, 0.03647426316248519, 0.01247877043871475, 0.034453511238098145, 0.06611987881894622, 0.17724459698157652, 0.0729344060112323, 0.12648457288742065, 0.13961955878351415, 0.15778958664408751, 0.13801727976117814, 0.10628290940076113, 0.09174612443894148, 0.19398747570812702, 0.09306687249669007, 0.11049872211047582, 0.13903205602296762, 0.2052445209452084, 0.1076625068006771, 0.11437448699559484, 0.1174322779157332, 0.16286329153392995, 0.12304499745368958, 0.11511115889464106, 0.15919863246381283, 0.1396339437259095, 0.15469709544309548, 0.14890769895698341, 0.1768193319439888, 0.1462562419474125, 0.06998039023684603, 0.14092302455433778, 0.1591878980398178, 0.14998267484562738, 0.14048123040369578, 0.09364993763821465, 0.15440467399145874, 0.09167645246322666, 0.0794816514743226, 0.19264210361455167, 0.15942484246832983, 0.23511042978082383, 0.14535366823630674, 0.19641934521496296, 0.14209030834691866, 0.1692582398120846, 0.18284559143441065, 0.08562102275235312, 0.1087651194206306, 0.11346770636737347, 0.10332632197865418, 0.1631413009017706, 0.21405124052294663, 0.13756272915218556, 0.19096784559743746, 0.09556841397924082, 0.08497363249106066, 0.1435774942593915, 0.10300008234168802, 0.09303173116807427, 0.19546703488699027, 0.10583848931959697, 0.18369466944464616, 0.049660125614276955, 0.17293410828070982, 0.15915467696530478, 0.17507652831929071, 0.1656750456563064, 0.12633889141891683, 0.16595320430185112, 0.12348915290619646, 0.6323340577738625, 2.7915369272232056, 6.74571201631001, 9.124152047293526, 15.550355059759957, 25.744661705834524, 37.5520465033395, 56.20438139779227, 67.83281012943813, 70.39936351776123, 67.5601280757359, 71.71347631726945, 75.94290733337402, 80.02369553702218, 80.3681594303676, 80.73676136561802, 84.42491381508964, 84.53634902409145, 83.52544171469552, 71.63922786712646, 65.3372881753104, 59.102287428719656, 35.63383994783674, 23.556993586676462, 19.971467767442974, 14.420745594160897, 8.813778621809822, 8.786856089319501, 8.628041982650757, 14.232682176998683, 11.236715350832258, 16.76463614191328, 19.754553692681448, 16.633382933480398, 23.690049852643693, 18.982561928885325, 14.38450813293457, 9.52620608466012, 6.0584322554724555, 1.9971519878932407, 0.5476960965565273, 0.2463821992278099, 0.17375877260097436, 0.13713629703436578, 0.16285520339650766, 0.08234326434986931, 0.13899419376892702, 0.09815035507615123, 0.12904934026300907, 0.16563265078834125, 0.19349354292665208, 0.16742741662476743, 0.1588504354336432, 0.11916607059538364, 0.11288396269083023, 0.12101568920271737, 0.10727530079228537, 0.23294055621538842, 0.20667333927537712, 0.12442729542297976, 0.2575823968010289, 0.14626557858926909, 0.1708454146449055, 0.09195505215653352, 0.10454296919384173, 0.16372406748788698, 0.11816244944930077, 0.0788986881130508, 0.09144782008869307, 0.12354384282869951, 0.19265928412122385, 0.09334315160023314, 0.08808867819607258, 0.12691983953118324, 0.11500173833753381, 0.15513009577989578, 0.15723526424595288, 0.10029293117778641, 0.17714838071593217, 0.08247163639004741, 0.09655735162752015, 0.20165135232465609, 0.11177400832197495, 0.08319646106766802, 0.10567893859531198, 0.09536129795014858, 0.24207355614219392, 0.11697429391954627, 0.2771026822073119, 0.08217071967997722, 0.14093351470572607, 0.15452655245150837, 0.10436173249036074, 0.1584936888622386, 0.09720138992582049, 0.10037851479968854, 0.14814795686730317, 0.1921173789139305, 0.13358656822570733, 0.08475557169211761, 0.07490970966007028, 0.14947221295109817, 0.10862872709653207, 0.08059802478445427, 0.14423895733697073, 0.14319641542221817, 0.16165579775614397, 0.0900932742016656, 0.18320901479039872], [0.022971804752679806, 0.014850590444569076, 0.01815101700568838, 0.06645109890294926, 0.02224917004683188, 0.019994416839576194, 0.02233526765901063, 0.021053233416751027, 0.057277665074382506, 0.0353419273160398, 0.03503242035263351, 0.03943963082773345, 0.05577452001827104, 0.003953104306544576, 0.01763407001271844, 0.05726870841213635, 0.06688321714422532, 0.044187350531241724, 0.014767605611788375, 0.025134957428755503, 0.027749088226950595, 0.01703045204547899, 0.03003145780946527, 0.03007914185790079, 0.04135207159976874, 0.08696766370641333, 0.03282060653769544, 0.026248854086069123, 0.010984740652410048, 0.04720344886715923, 0.03579021504681025, 0.04582801088690758, 0.060141964948603084, 0.038761082238384655, 0.0327273486847324, 0.038853759943906746, 0.01347467240079173, 0.03990103803308947, 0.020249347535095046, 0.025752180023118854, 0.031397942520145855, 0.0559467355986791, 0.06481534774814333, 0.047735969935144694, 0.02612886534604643, 0.04418740820671831, 0.008525591493318123, 0.03989148765270199, 0.0365299844582166, 0.015416386869869061, 0.012097376082757754, 0.03045839543587395, 0.028554884184684073, 0.07340668674026217, 0.07323817256838083, 0.02039473892987839, 0.03778634632804564, 0.049683507931019576, 0.038572005062763176, 0.01434752288540559, 0.09392060525715351, 0.0348116318429155, 0.06426132390541689, 0.04837667662650347, 0.5511273667216301, 2.5081125242369513, 5.580407917499542, 8.204459820474897, 14.979777676718575, 26.894736221858434, 32.61024447849819, 42.554190158843994, 58.75594752175467, 65.44725036621094, 70.10302284785679, 69.0419703892299, 72.12939548492432, 69.84422329493931, 68.40971905844552, 64.89601503099713, 71.26037039075578, 69.32754829951695, 72.22200107574463, 74.24307918548584, 65.33983816419328, 68.46103150503976, 67.59714807782854, 66.7133024760655, 65.36788804190499, 58.05501324789864, 40.023840359279085, 34.6858103615897, 36.708107880183626, 31.40071596418108, 27.133380787713186, 17.102466242653982, 20.25981800896781, 32.3298533984593, 39.326043197086875, 37.47535228729248, 30.93784781864711, 37.23702212742397, 34.962147167750764, 28.038619892937795, 26.059145859309606, 15.299033505575997, 9.135240503719874, 4.328195316450937, 1.2864553864513124, 0.3651755776788507, 0.05577482196635433, 0.018718643779201165, 0.030777585093996356, 0.03582505103466766, 0.03996733429708651, 0.09998522911752973, 0.013849195741516138, 0.08371300942131452, 0.02963359880128077, 0.06930394510605506, 0.019083305461598293, 0.03287398688761251, 0.0165736995903509, 0.10295266631458487, 0.00831881388356643, 0.08766863109277827, 0.018611514974119406, 0.06619958632758685, 0.009945916261390915, 0.03984598509435143, 0.0438727375918201, 0.06071661625589643, 0.06229447480291128, 0.01952335238456726, 0.044454686543239016, 0.03481399653745549, 0.06573373811053378, 0.016489245729254823, 0.007347463014801698, 0.059662525675126483, 0.03553669400779264, 0.07686688963856016, 0.049716077611914704, 0.006970260308922401, 0.056712659142379246, 0.07342861699206488, 0.0346427987595754, 0.03604179208299943, 0.045918588526546955, 0.020946934120729566, 0.008553356298112443, 0.0346148363314569, 0.04239720891096762, 0.015191459296537297, 0.01141899118998221, 0.04446856936972056, 0.029020186181047132, 0.014849828789010644, 0.04151440431763019, 0.025016493696187223, 0.034283904624836783, 0.03150613832154444, 0.04692816721009357, 0.05154430201011045, 0.03945801234138863, 0.059633959350841384, 0.03158942510240844, 0.0394329269017492, 0.010268258562843715, 0.0722747410514525, 0.03538141126877495, 0.02236874827316829, 0.04701081616804004, 0.018218095281294415, 0.03261298160733921, 0.012341678375378251, 0.014845296175086072, 0.034940994544220824, 0.03558233227314694, 0.02326991911312299, 0.06656958468790565, 0.027941546203302484, 0.01754563145472535, 0.003095760043444378, 0.060849615904901705, 0.015784783887543848, 0.005169223960755127, 0.0701297629358513, 0.04410217742302588, 0.02521496858181698, 0.018522620101326277, 0.07118191290646791, 0.022967591050214002, 0.026621286690767323, 0.03837148778672729, 0.030804699353341545, 0.03025850580473031, 0.030114066055310622, 0.06763528500284467, 0.041860104338931184, 0.021319777239114046, 0.056472433997052054, 0.02606630781000214, 0.054872465386454544, 0.03336035739630461, 0.04440056659015162, 0.07348097953945398, 0.01678332789534969, 0.03341422289876001, 0.03903517645916768, 0.05096270250422614, 0.005324829427991062, 0.015199450742719429, 0.041450075805187225, 0.028871003471847092, 0.019691471309800233, 0.045258679294160435, 0.02587034859295402, 0.03544919352446284, 0.04541439290291496, 0.011607293139344879, 0.019750485196709633, 0.031030400456594567, 0.09174388527337994, 0.018873246286862662, 0.028244113449805548, 0.043783174362033606, 0.036222441853689294, 0.058028457287166796, 0.04821021841572864, 0.075608376812722, 0.042783682101539204, 0.06478659821940319, 0.038482468974377425, 0.041690758961652, 0.07899974233337811, 0.004059295036963054, 0.09856351504900626, 0.03967611724510789, 0.16970383375883102, 1.356737066592489, 4.3314149379730225, 8.79310165132795, 13.217861294746399, 21.56361620766776, 32.546373162950786, 39.714242526463096, 49.915612016405376, 71.75795868464878, 77.0113387789045, 79.1686988558088, 79.09319972991943, 80.46588584354946, 79.24585860116142, 80.38980306897844, 74.81087902614048, 82.75108582632882, 82.09667669023786, 81.7197299684797, 84.35075569152832, 73.90280505589077, 77.99020794459751, 78.15906306675502, 77.13990824563163, 75.98500646863664, 68.72939872741699, 53.431223324366975, 48.23566613878523, 46.12717969076974, 39.522750173296245, 35.68623978751046, 24.451551573617117, 28.942841087068828, 42.224209785461426, 47.00419521331787, 44.655214241572786, 40.42410176140921, 47.68417372022356, 45.729548181806294, 36.61040578569685, 35.60714149475098, 20.312593051365443, 12.63464948109218, 6.954382487705775, 1.9933515403951918, 0.7909346701843398, 0.0406183241866529, 0.024454515726704682, 0.05493166417415653, 0.030015461346400634, 0.03497547430119344, 0.029987407316054617, 0.047814537504954, 0.006774524584346051, 0.05980868890349354, 0.06949537340551615, 0.029856500947581868, 0.047537152389330525, 0.03252897218668035, 0.044390738010406494, 0.05631717161408492, 0.022487244236149957, 0.04812219885310956, 0.0291960149604295, 0.039773442915507724, 0.07912085404885666, 0.07827553512262446, 0.005951033281494996, 0.030543307308107615, 0.030239778238215616, 0.02940368399556194, 0.01785167619319899, 0.07585921763841595, 0.01541558450220951, 0.007253649611292141, 0.011287486862524279, 0.04070008426372494, 0.023429140747923936, 0.021697817935741374, 0.019961267011240125, 0.015483219176530838, 0.07189669526581254, 0.08006342061396156, 0.024347697351393954, 0.07144742365926504, 0.02979149729279535, 0.038594281367425404, 0.02324233327193984, 0.028978666623256037, 0.07957408151456288, 0.01978523636768971, 0.02234131170968924, 0.033167775587311814, 0.042611045829419575, 0.061478176819426675, 0.016187217918091586, 0.03416704393125006, 0.017228144919499755, 0.05918278106089149, 0.051409131049045494, 0.049517684150487185, 0.022349040223551647, 0.0033956419876111405, 0.02921406738460064, 0.04062266681077225, 0.01984878795753632, 0.009269197172086154, 0.006746876826842448, 0.09359517307685954, 0.08334455812083823, 0.020926153985783458, 0.050956711040011475, 0.1259657514414617, 0.08464156423828431, 0.17699562891253404, 0.18172381020018033, 0.15465098220322812, 0.06620019022375345, 0.112003312446177, 0.17908333188721112, 0.17599622825426714, 0.09865229457084622, 0.14828407099204405, 0.14416304283908435, 0.16328550316393375, 0.12699622900358268, 0.0799972295228924, 0.1180720685848168, 0.09679639951458999, 0.13295829908124038, 0.16710709381316388, 0.18282866877104553, 0.12635079292314394, 0.11278928669967822, 0.18827122529702528, 0.1628568997340543, 0.1495467568082469, 0.19211478691015924, 0.07657012556280408, 0.2872377969324589, 0.18256002318646225, 0.22036958219749586, 0.1629776789673737, 0.1235902410532747, 0.1163325762110097, 0.08586479324315276, 0.1342466063797474, 0.128611400191273, 0.06142818235925265, 0.09873807496790375, 0.07968068615134273, 0.10470930526831321, 0.16953996755182743, 0.1257197553558009, 0.11115177813917398, 0.11980248216007437, 0.09075760748237371, 0.12050799573106424, 0.10804340243339539, 0.19430659072739737, 0.1604491996445826, 0.11639752558299474, 0.11254221174333777, 0.12544044320072445, 0.09748391155153513, 0.15016628642167362, 0.18209089764526912, 0.14540336414107255, 0.13367551059595176, 0.12159637947167669, 0.1544984203896352, 0.15232580554272446, 0.141868440966521, 0.21664091013371944, 0.19253474580390112, 0.3305429331958294, 1.625311215009008, 4.930974560124533, 10.900284443582807, 17.38363378388541, 26.24283364840916, 38.505245549338206, 48.25092090879168, 60.40121841430664, 82.41226387023926, 88.13371631077358, 89.48726708548409, 90.06707341330392, 91.71196910313198, 90.76683344159807, 91.98238604409354, 89.06959002358573, 93.59849534715924, 92.56225490570068, 93.9902903693063, 96.84278297424316, 86.94242681775773, 89.23204585484096, 90.0366541998727, 88.58867740631104, 88.23240852355957, 80.97159658159528, 63.61637919289725, 60.24181284223284, 53.70625386919294, 45.82114628383091, 41.12600530896868, 32.84210239137922, 37.78754179818289, 50.17885494232178, 55.61553198950631, 52.12369394302368, 49.94088608877999, 58.38840171269008, 56.17153031485421, 44.458559376852854, 41.000503471919465, 24.29643825122288, 16.489027159554617, 8.271166001047407, 2.831800652401788, 0.9754607485873359, 0.16097278440637247, 0.12727613826947554, 0.18199925470565045, 0.15643057599663734, 0.09189472360802547, 0.1666550673544407, 0.159426267391869, 0.19940014955188545, 0.08010411914438009, 0.17710852356893675, 0.09894782371286835, 0.1245728140430791, 0.08318018979792084, 0.13115271739661694, 0.1864070724695921, 0.11095470442835774, 0.11045271743621145, 0.13991617358156613, 0.08111405745148659, 0.15414186380803585, 0.12751023285090923, 0.13860349330518926, 0.16043143559779438, 0.10931293466793639, 0.16991381320570195, 0.10202365687915257, 0.15509728182639393, 0.1194822679140738, 0.06119781293507133, 0.06934629926191908, 0.13795041692044052, 0.11301918114934649, 0.12931090194199765, 0.11218157716627632, 0.1545700736876045, 0.2766784621136529, 0.12630865589848586, 0.20228636610720838, 0.09932762690420661, 0.07518204647515501, 0.15622016228735447, 0.14811286303613866, 0.06773285833852631, 0.07674860062875918, 0.11229470930993557, 0.1196571263883795, 0.11528592237404414, 0.10549460098679576, 0.2299943028816155, 0.064015979213374, 0.11248337597187076, 0.07508939930370875, 0.09322822133877448, 0.18607520099197114, 0.09090246113815478, 0.1404333801141807, 0.09422108770481177, 0.12912993665252412, 0.12730669948671544, 0.15014107206038066, 0.059909261363957605, 0.1171583668994052, 0.16869160878871167, 0.26428892835974693, 0.12807729813669408, 0.1124074954007353], [0.02782997808286122, 0.07003706148160355, 0.014578862614663584, 0.019464867754972408, 0.03797701466828585, 0.06271378908838544, 0.07650046715778963, 0.05381384897711022, 0.022927727117868404, 0.06245450728705951, 0.022021165317190543, 0.027943288341962864, 0.018772507585319023, 0.024818003543519547, 0.05355118128604122, 0.025370996013017635, 0.047887072898447514, 0.021781264172334756, 0.020313903356769254, 0.01934853631870023, 0.02164564877083259, 0.062443467522306104, 0.03347565406667335, 0.04046712622844747, 0.0798247866332531, 0.007254744597178484, 0.039961322476821284, 0.02658362121188215, 0.010764313462589468, 0.012901457043231597, 0.015349320468625851, 0.02269140863791108, 0.03994711395353079, 0.08615913494889225, 0.03744546051270195, 0.04399195958727172, 0.05381832052288311, 0.016326117429084012, 0.02460756099649838, 0.041306569041418176, 0.0189843767522169, 0.038379392719694545, 0.04819967398153884, 0.031203257252595255, 0.045292931741901805, 0.017247598518484404, 0.024096133885905147, 0.07344484754971095, 0.045847308422837935, 0.03174514888918825, 0.05643304164654442, 0.013044478654462312, 0.055309947447053025, 0.02604190769073154, 0.012644696847668715, 0.012170337256975472, 0.05321944212274892, 0.03384518423782928, 0.02075819960529251, 0.035464243431176455, 0.07435245599065508, 0.38842015181268963, 2.631278029509953, 8.252404996326991, 13.404827765056066, 27.62578919955662, 31.437954834529332, 41.500214440482004, 52.460546084812705, 56.888577461242676, 59.554712431771414, 68.17452948434013, 66.90960298265729, 67.20071860722133, 67.08032022203717, 67.5075649533953, 62.939708028520855, 65.17201137542725, 69.9699717930385, 60.86505235944475, 59.32342079707554, 52.55791466576712, 57.7927256992885, 55.19492973600115, 58.74689401899065, 63.38416344778878, 70.90813841138566, 67.27969183240617, 67.90790625980922, 71.61275523049491, 77.21788787841797, 65.47241674150739, 62.0390408379691, 61.045260838099885, 56.27613197054182, 58.30243859972273, 58.548286710466655, 56.57180561338152, 51.463872160230366, 48.31258269718715, 59.36979307447161, 59.842180252075195, 67.68599469321114, 53.80564090183803, 55.45064081464495, 45.09381232942854, 40.507129260471885, 33.46791969026838, 18.092761720929825, 5.948147841862269, 1.9067813285759516, 0.31616293053541866, 0.24961555429867335, 0.011143653553777506, 0.014531916473060846, 0.02723773575520941, 0.026874388734410917, 0.07541819701769523, 0.011807286247078861, 0.027776601125619242, 0.09386676350342375, 0.061604567537350316, 0.015711739592786347, 0.011424428799987903, 0.014900221888508116, 0.03443781333044171, 0.07170512447399752, 0.02376003852779312, 0.0458430574009461, 0.02477361378259957, 0.03659847917567406, 0.07043853708143745, 0.029050669366759912, 0.06399218299027, 0.05791322847029992, 0.0711126344810639, 0.02753225388005376, 0.03243119529049311, 0.00793986055733902, 0.08506855954016958, 0.015753001307270358, 0.017188735605616654, 0.056371301745197604, 0.03134536962690098, 0.03176670255405562, 0.01626315955737872, 0.018738339954454983, 0.03989442910200783, 0.011607231223024428, 0.021951539142589484, 0.04358499124646187, 0.04986814070226891, 0.006140507824186767, 0.03772167854809335, 0.06766400739018406, 0.0232610523567668, 0.010069290891156664, 0.019090928802532808, 0.034119224175810814, 0.0784346108723964, 0.03401343717372843, 0.07333305212003843, 0.021903181648147956, 0.0036941592282216463, 0.029900402163288424, 0.057828398022268496, 0.028532414497541528, 0.03908852627500892, 0.022256652591750026, 0.04164265422150493, 0.03876514666314636, 0.052912194680954726, 0.05218690520684634, 0.009058852164473916, 0.0331832936831883, 0.016210120171308517, 0.02890138148463198, 0.04106771792950375, 0.024709990946576, 0.08487716516745941, 0.01676938060804137, 0.02835244156553277, 0.0344275776296854, 0.054745056866002936, 0.029365957448525087, 0.04502978568364467, 0.02266371083844985, 0.06674171545143638, 0.007615512336737343, 0.05240236382399287, 0.029763443262449334, 0.016684911479907374, 0.029289303347468376, 0.04043035302311182, 0.03679129507924829, 0.04193352861329913, 0.014201948286167212, 0.037656172777393034, 0.029212594963610172, 0.09003530695502247, 0.045443020295351744, 0.003326394520367363, 0.07993183910314526, 0.007276623110686029, 0.031370631485645256, 0.016593846991392117, 0.04261812634233918, 0.07143113203346729, 0.03071905466328774, 0.05917636890496526, 0.03867339176524963, 0.01961456784712417, 0.05339678403522287, 0.04433074872940779, 0.04955722577869892, 0.04941246711782046, 0.04415164941123553, 0.024066593863868287, 0.005662894233994718, 0.04550949637112873, 0.035288523217397075, 0.034378902920122655, 0.016272146753700714, 0.03325803092281733, 0.01109493728394487, 0.019170593902734772, 0.008229448277104114, 0.04215773354683604, 0.06438429480684654, 0.012041911782164658, 0.06100485114646809, 0.005404293512193752, 0.041636686506015916, 0.041782449398721964, 0.04109737330249377, 0.04536400828510523, 0.25152964730347904, 0.9710831663438252, 5.02732913834708, 12.74000414780208, 19.261688436780656, 34.167116914476665, 39.683201449257986, 49.95158978870937, 60.466573170253206, 66.46532821655273, 69.35310377393449, 76.54563576834542, 74.64004366738456, 76.56313133239746, 75.01101493835449, 76.17355973379952, 71.88364464896065, 76.4867775780814, 77.58351598467145, 68.83694989340646, 65.54100240979875, 61.858137539454866, 68.00789778573173, 64.06731033325195, 71.16071237836564, 70.47935117994035, 80.1961567742484, 73.56956945146833, 76.13302394321987, 79.13871043069022, 88.24756949288505, 78.0902133669172, 71.43057346343994, 71.96764142172677, 67.59414645603725, 72.72441836765834, 74.73540769304547, 70.02136066981724, 63.0724116734096, 60.991023199898855, 73.10145541599819, 69.16232013702393, 78.96921607426235, 66.32596819741386, 66.06402805873326, 57.021645886557444, 51.79919222423008, 40.45471552440098, 23.114143201283046, 8.781141195978437, 3.413589822394507, 0.8848049959966114, 0.2649372007165636, 0.016433546485911523, 0.026978715189865658, 0.018025732299845134, 0.018837180454283953, 0.02643985321213092, 0.03228248416313103, 0.04472105564283473, 0.04228477565837758, 0.0673841591924429, 0.01016741044752832, 0.07089964233871017, 0.0526792162896267, 0.014819194629256214, 0.029343212954699993, 0.04531299941507833, 0.07178746469851051, 0.025116206113515154, 0.0065490995600287405, 0.022562412345515828, 0.03982381396261709, 0.08758046903780528, 0.041353845968842506, 0.0338354811870626, 0.06044569079365049, 0.02134868791992111, 0.0646715797483921, 0.06228003557771444, 0.02044366978641067, 0.09691552990781409, 0.0011616519519260951, 0.05069306965119072, 0.050371016575289626, 0.08391089737415314, 0.009085555061964052, 0.010497904499061406, 0.041388620888548236, 0.014859638709042753, 0.028532831796578, 0.05010486121422478, 0.018324099414582764, 0.023195592387180244, 0.05727472023240157, 0.040132259018719196, 0.023036228260025382, 0.01680916141984718, 0.05543270121727671, 0.036646699266774316, 0.026437205229220644, 0.042156098277441094, 0.032305225264281034, 0.0651914868503809, 0.08704817188637597, 0.019702590802418332, 0.04218626933704529, 0.016540027290050472, 0.06312679978353636, 0.015935912295909863, 0.018774750143555657, 0.034044374977903705, 0.06736505164631776, 0.07630748501313583, 0.036923137826046774, 0.04053373461855309, 0.10597755507166896, 0.20553002133965492, 0.15315502961831434, 0.22754188733441488, 0.11097627505660057, 0.1517925855836698, 0.29577298036643435, 0.13290177711418696, 0.08617450376706463, 0.1820633898356131, 0.0743845235556364, 0.20360227621027402, 0.1443467629807336, 0.10053449642977544, 0.09423522158925023, 0.1254905326558011, 0.14544332985367092, 0.09148231002369098, 0.117553871391075, 0.1458126971764224, 0.07201941510928528, 0.15173843848918164, 0.0974764001688787, 0.1607494242489338, 0.19065322247999056, 0.18686091740216526, 0.18219198579234736, 0.2423677146434784, 0.16048924678138324, 0.12323577435953276, 0.08171068650803395, 0.1091768816113472, 0.10312201508453914, 0.19012859277427197, 0.18553766555019788, 0.10857325685875756, 0.14795165668640817, 0.1118537565427167, 0.10064815104539905, 0.1286876675273691, 0.1512048521212169, 0.24123149418405124, 0.08248038949178797, 0.1290930514889104, 0.1257731696324689, 0.14080246245222433, 0.11604847359870162, 0.10598575856004443, 0.11750777172190802, 0.11369843541511468, 0.1826850093368973, 0.09785068008516516, 0.13705153443983623, 0.09293704160622188, 0.1666042043694428, 0.14933528458433493, 0.15833546806659016, 0.12466437555849552, 0.13021867323134625, 0.19904877697782858, 0.6515634145055498, 1.9468435559953963, 6.507836094924381, 15.753662824630737, 25.232900823865617, 43.82680484226772, 49.002156666346956, 60.28707340785435, 70.60945619855607, 75.57420117514474, 79.10884707314628, 87.16183703286308, 85.98192868913922, 88.9126649584089, 89.20236315046037, 87.82123497554234, 84.86609663282121, 87.03995868137905, 88.98462050301688, 81.58757523127964, 79.33319745744977, 73.7616662979126, 81.14371040889195, 75.64915139334542, 80.25345161982945, 82.0944185256958, 89.45750795091901, 85.84112344469342, 88.10684067862374, 91.83102648598808, 101.00709547315324, 95.10202298845563, 81.56774507250104, 82.19083172934396, 80.00462273189, 83.82283851078579, 86.71155207497733, 81.99100153786796, 76.94426781790597, 73.01637472425188, 85.51683017185756, 77.92824390956334, 88.81218705858502, 77.11593001229423, 78.86758477347237, 67.03193991524833, 61.53267002105713, 46.4817601612636, 27.72757683481489, 11.399433476584298, 4.468139852796282, 1.34929478594235, 0.4504922910460404, 0.16049025101321085, 0.17748897815389292, 0.13149847170071943, 0.1260692280318056, 0.18810807833714144, 0.11700186958270413, 0.1329438734267439, 0.24034907296299934, 0.1360152079058545, 0.10949093475937843, 0.09987039385097367, 0.1127768966502377, 0.11019545766924109, 0.12135513313114643, 0.12192869878240994, 0.15309343220932142, 0.11097502655216626, 0.1125671954027244, 0.14507678523659706, 0.09048851406467812, 0.1588790560407298, 0.1773445044777223, 0.1761524405862604, 0.12459418789616653, 0.13911512227995054, 0.1218424162694386, 0.2029997913965157, 0.06161739184920277, 0.2898936372782503, 0.08499316751424756, 0.2125483668808426, 0.1607850201960121, 0.13839899642126902, 0.13408374440457138, 0.08462361698704106, 0.10130727996251412, 0.080592338660998, 0.15814766314412865, 0.12628607425306523, 0.05026061214240534, 0.11685873940587044, 0.12782781438103744, 0.17695174126752786, 0.11032586531447512, 0.12056176284594194, 0.10497873795351811, 0.13924465461501054, 0.11319192937974419, 0.19139752111264638, 0.08999775682709046, 0.17480161307113512, 0.2289579084941319, 0.1553563600672143, 0.18055153238986218, 0.08358134648629598, 0.1416352963341134, 0.19255546826337064, 0.10881608418588128, 0.13321950792201928, 0.16146587580442429, 0.12541430603180612, 0.09079342734600816, 0.18649072226669106], [0.06659210526517459, 0.025051921705848405, 0.10283610756908144, 0.024775947943063717, 0.06337200876857553, 0.03301067098176905, 0.021098376351541707, 0.021990103680374365, 0.04374043683388403, 0.04775755752676299, 0.021675402531400323, 0.026048552244901657, 0.038378117073859484, 0.017619020106004815, 0.017482483593214835, 0.02356278500519693, 0.09613615780004434, 0.034364986166890175, 0.029407395582113947, 0.042099993609424145, 0.03952748414927295, 0.031956085070435486, 0.07971702848694154, 0.051079858360545974, 0.04930056990789516, 0.06306006586445229, 0.054271564951964786, 0.023109133455104063, 0.013794301410338708, 0.0051593415222928995, 0.05680146241294486, 0.01676765543275646, 0.064820029639772, 0.06016829889267683, 0.0665542497964842, 0.039382752629795244, 0.023928954731673002, 0.026628572460530058, 0.028102019735212837, 0.0329976939995374, 0.05520884572927441, 0.04423926863819361, 0.021437564133001224, 0.01091554110670196, 0.08125199683542762, 0.026769402403650538, 0.06409591063857079, 0.03362465017874326, 0.01381218759343028, 0.08479525242000818, 0.05807061466787543, 0.037933595212442536, 0.02935453431148614, 0.03075228930850114, 0.059313989377447536, 0.028111400481845652, 0.05470368658591594, 0.139442718986954, 0.4815826841763088, 3.7468386718205045, 10.655129415648323, 19.119552612304688, 30.016290869031632, 44.76453372410366, 51.46185023444039, 53.31268358230591, 56.16603428976876, 63.180275508335654, 68.55010046277727, 69.24646977015904, 63.840986660548616, 59.50803443363735, 61.10133974892752, 58.91866738455636, 47.258871010371614, 46.72245270865304, 35.00299910136631, 33.38891519818987, 44.744936329977854, 34.50398642676217, 31.077291216169083, 28.112922191619873, 35.76200294494629, 55.58160046168736, 41.82027973447527, 44.04718433107649, 49.55533749716622, 43.91444247109549, 42.52433374949864, 51.83019161224365, 54.534996782030376, 60.65211091722761, 63.275014196123394, 64.85587528773716, 54.399816104343955, 62.875395502362935, 51.931878498622346, 60.481803621564595, 60.278200558253694, 60.624596050807405, 62.933551924569265, 61.68624605451311, 59.93270138331822, 57.59985065460205, 64.16546753474644, 63.31175627027239, 55.78349426814488, 54.87731715611049, 44.02070127214704, 29.840928758893693, 20.146246228899273, 11.516870192119054, 4.505756531442914, 1.811885763491903, 0.16886326457772935, 0.03244300179981759, 0.04529255854764155, 0.039963415757353814, 0.028907101534839188, 0.07609684738729681, 0.03725006617605686, 0.013355741327229356, 0.06146765952663762, 0.046937198511191776, 0.026041273260489106, 0.06971532053181104, 0.056432532745280435, 0.012737084479470338, 0.03517791861668229, 0.029298310899840932, 0.06039165226476533, 0.020238584273361733, 0.024245535422648703, 0.021853638413761343, 0.07223632918404681, 0.03189632649134312, 0.03467697996113982, 0.04939219927681344, 0.04059771368546145, 0.02128126528779311, 0.06997092467333589, 0.008800978323311677, 0.021430339431390166, 0.03386604240430253, 0.030191724388194934, 0.024144767883366773, 0.021445019536518624, 0.03424537740647793, 0.04491202253848314, 0.1076253027256046, 0.027620768773236444, 0.052212906668760946, 0.01769780819969518, 0.020231980431292738, 0.021401823997231464, 0.016218286340257952, 0.01379482218596552, 0.028944553275193487, 0.0059884252259507775, 0.04045816617352622, 0.04613654075988701, 0.019428427031795894, 0.01611126440444163, 0.02193283532480044, 0.04277297142626984, 0.03725304833746382, 0.030034568892525773, 0.07743901001023394, 0.03504639138866748, 0.03680996157761131, 0.03031367070174643, 0.01396801061595657, 0.0345268778369895, 0.047910831802125485, 0.021976750111207366, 0.07108048549188034, 0.05319411919585296, 0.031422132293560674, 0.03896144684404135, 0.0096604065370879, 0.029763110780290196, 0.026726656393813233, 0.06060038320720196, 0.017089657618531158, 0.029007904697209597, 0.031391825526952744, 0.03530247050470539, 0.019307573159624423, 0.05501615874735372, 0.035141559317708015, 0.061675277671643665, 0.007248114461877516, 0.03733989064182554, 0.06249548401683569, 0.04405341450391071, 0.029872487232621227, 0.017390626915065304, 0.022682207703058208, 0.07476515455969743, 0.02474273874291352, 0.05619937454217246, 0.048444190860858986, 0.033880440917398245, 0.019390357824574624, 0.02117801770301802, 0.04852551667551909, 0.04251237665968282, 0.032192439173481295, 0.023943385475182107, 0.08491297824574368, 0.03438203775190881, 0.052518844537969143, 0.04467963447262134, 0.009017418271728923, 0.01707512339843171, 0.03427892078512481, 0.04065375389265163, 0.062412003853491375, 0.0659602941679103, 0.02762745743218277, 0.043211355938443115, 0.01398810458236507, 0.020494076456608515, 0.020778201121304716, 0.016199533328680054, 0.10370999960494892, 0.01602716847056789, 0.03854746584381376, 0.03338948351198009, 0.011484742929626788, 0.08025357326758759, 0.016911986616573164, 0.023305716924369335, 0.13018539787403174, 0.8023044743708202, 5.023446832384382, 13.359004395348684, 24.406138147626603, 35.201481342315674, 53.976323400224956, 60.97378471919468, 60.31773580823626, 64.52507850102016, 71.3000932421003, 79.08935042790004, 77.82726573944092, 73.22370897020612, 68.3494017464774, 70.67700658525739, 68.50566673278809, 58.2088428906032, 58.16516998835972, 43.30572468893868, 43.033845152173726, 53.52947780064174, 42.67702041353498, 41.329584053584504, 40.893258026668, 45.46081965310233, 66.35415009089878, 55.24772562299456, 55.20244073867798, 59.814971106392996, 50.69752059664045, 50.07745293208531, 61.07973085130964, 62.22061811174665, 69.3963702065604, 74.1885427747454, 75.91120965140206, 68.10201113564628, 73.3831284386771, 61.18674005780901, 69.60095991407121, 72.51942566462925, 74.33595575605119, 71.87753718239921, 71.55313273838588, 68.84524604252407, 66.64571040017265, 73.22043636866978, 72.86954539162772, 67.06332492828369, 65.33607224055699, 53.43691042491368, 38.91491133826119, 25.821583475385392, 14.826201643262591, 6.5172096490859985, 2.8397973775863647, 0.38966724489416393, 0.07484844473323651, 0.04304612926872713, 0.04303514378677521, 0.026841099806396023, 0.07471805065870285, 0.03913956907178674, 0.024860357699383582, 0.036391800801668844, 0.05096416813986642, 0.01990680948698095, 0.01461884698697499, 0.03263741565336074, 0.02908477253679718, 0.039712978659995964, 0.0477254729984062, 0.02094990780044879, 0.03673988926623549, 0.03867252663310085, 0.03896098883290376, 0.05124920034515006, 0.005189988404578928, 0.013568384872217263, 0.03992018289864063, 0.014710781696651663, 0.00935536009326045, 0.06493052228220872, 0.06755869875528983, 0.04315178734915597, 0.02760754751839808, 0.037332698170627863, 0.03448875095429165, 0.08589150716683694, 0.044774503846253665, 0.0021015293979352073, 0.06836033359702144, 0.034544597779001505, 0.037609984898673635, 0.01617196275453482, 0.028585109527089765, 0.06915278785995074, 0.04038670286536217, 0.023797654812889438, 0.0381704717874527, 0.03334629136536803, 0.016531761037185788, 0.047961664253047535, 0.0419403716389622, 0.040832914278975556, 0.06974010741604225, 0.019200323914576854, 0.08395557890513114, 0.09084028697439603, 0.033169872260519435, 0.04128449968993664, 0.04618548009810703, 0.0379928516756211, 0.023190818893324052, 0.04511869073446308, 0.03039880988321134, 0.008318790983009552, 0.03339149536831038, 0.10318983465965305, 0.14393428154289722, 0.1685006283223629, 0.12490117070930344, 0.14056197607091495, 0.10425307189247437, 0.17885463844452584, 0.08750265464186668, 0.1263161604957921, 0.13141575828194618, 0.08119158686271735, 0.07303067655967814, 0.10869873155440603, 0.1268172450363636, 0.14173649304679461, 0.18267294498426573, 0.12192248340163912, 0.16353983165962355, 0.12336070622716631, 0.17919377024684632, 0.15518583064632757, 0.09579960443079472, 0.1609475700450795, 0.13187980838119984, 0.19442865917725222, 0.10518667500998292, 0.1760000144796712, 0.14716615740742, 0.10116992411868912, 0.11959782242774963, 0.12768619055194513, 0.09671031377677407, 0.0984795056283474, 0.10744556558451482, 0.1275649092027119, 0.15349583061678068, 0.1378152934568269, 0.046601059048303535, 0.0983030390260475, 0.21670066192746162, 0.3444754827235426, 0.15945895920906747, 0.22537698064531597, 0.10075126122683287, 0.17729799768754415, 0.1353979988821915, 0.08218374755233526, 0.13698426447808743, 0.11596916642572198, 0.1848060826637915, 0.1360031978360244, 0.10769673210701772, 0.10768261857862983, 0.11777337746960775, 0.21177586833281176, 0.1227752390716757, 0.10607656690159015, 0.36855310787047657, 1.3957046270370483, 7.055653350693839, 17.18663498333522, 30.420658656529017, 45.184055532727925, 64.09783376966203, 72.33823054177421, 71.30629103524345, 75.75520869663784, 80.90490082332066, 86.83283982958112, 86.131975037711, 83.7705602645874, 76.61832087380546, 81.09823444911412, 77.00090953281948, 66.8512659072876, 65.46545464651925, 51.83381509780884, 51.92506231580462, 63.567429133823936, 52.97387204851423, 49.42431879043579, 45.42966045652117, 54.908910615103586, 75.6936615535191, 57.1268172945295, 62.134550775800435, 68.3519378389631, 63.301910672869, 62.41513293130057, 73.37108026232038, 72.93902737753731, 80.26089314052037, 85.4226473399571, 87.50390379769462, 80.7631506238665, 83.04152747562954, 74.49817534855434, 83.29293414524624, 84.40533379146031, 85.6357069015503, 81.92777987888881, 82.48059245518276, 79.71321528298515, 77.31243896484375, 82.33375617436, 83.60729149409703, 79.56777559007917, 76.93130247933524, 64.74012524741036, 46.7380826813834, 32.57133804048811, 18.636178595679148, 8.602918165070669, 3.852613704545157, 0.7476010354501861, 0.2229138035327196, 0.10264258259641272, 0.13031000404485635, 0.1435891514910119, 0.2580734118819237, 0.1339834297874144, 0.10817516036331654, 0.14135606560323918, 0.2106259007539068, 0.10436392415847097, 0.10041819552757911, 0.1262649582432849, 0.12331183813512325, 0.1294180154800415, 0.1351900143282754, 0.1423765415591853, 0.13961026285375866, 0.11244872318846838, 0.1574937996587583, 0.2534000969358853, 0.14284645420100006, 0.08323853702417441, 0.161443633426513, 0.0907739330349224, 0.12139915648315634, 0.1502427166061742, 0.176853869376438, 0.10239835070180041, 0.10487466425235782, 0.14925474247762135, 0.0983846667887909, 0.2626634570104735, 0.09413391631096601, 0.13041292423648493, 0.19072155095636845, 0.12760518704141888, 0.1570488978177309, 0.09500633592584304, 0.18090184644929, 0.12650330045393535, 0.09547093563846179, 0.11673968365149838, 0.10216470395347901, 0.11069840139576367, 0.21595457196235657, 0.21732385562998907, 0.17268619872629642, 0.22704600037208625, 0.11939057069165365, 0.15691925691706793, 0.1997108914490257, 0.21823214260595186, 0.2566198270235743, 0.10058898957712309, 0.1638810804912022, 0.0993232164265854, 0.13853451343519346, 0.15735792980662414, 0.0724356963432261, 0.10019892693630286, 0.14535963934447083], [0.05756516714713403, 0.029194003104099205, 0.02978300881971206, 0.026834197408918823, 0.010582115783888315, 0.01954221396174814, 0.03413016555298652, 0.10228913370519876, 0.039497696461954286, 0.06329498825860874, 0.013115614569479865, 0.03242636412116034, 0.008405523025430739, 0.031099407467991114, 0.03744025614910892, 0.045906035628701956, 0.041746588822986395, 0.014826611017010041, 0.03386671415397099, 0.0504807221171047, 0.03737733220415456, 0.051706451523516855, 0.04991538031026721, 0.02676950757657843, 0.04569208335929683, 0.052008711732923985, 0.020358829160353968, 0.03458731495110052, 0.05782296295676913, 0.03359421788315688, 0.04195449873805046, 0.034413905149059634, 0.05873367230274847, 0.03207070320578558, 0.02199082971284432, 0.04173616313242486, 0.005442238462689731, 0.01980719545723072, 0.05972035721476589, 0.03098980031375374, 0.04541239122460995, 0.08071518064077411, 0.018931055774113963, 0.035850591092769585, 0.01737102403837655, 0.05079788634819644, 0.11841030472091266, 0.027437713595905473, 0.05992448768977608, 0.06928504112043551, 0.03496990692136543, 0.052918935926365, 0.02823522124838616, 0.042085944541863034, 0.00908243888989091, 0.18553797767630645, 0.582372492977551, 3.9509667583874295, 12.79082761492048, 22.01461509295872, 32.82857077462332, 35.891965525490896, 49.247150148664204, 50.305593558720176, 55.88275970731463, 57.98547567640032, 56.34020478384835, 60.37103543962751, 51.57308741978237, 51.12573460170201, 50.05981840406145, 55.23480544771467, 35.241082600184846, 32.84708424976894, 34.27528647014073, 45.928621019635884, 43.31563976832798, 24.63070218903678, 32.51071848188128, 33.014431612832205, 26.264675310679845, 21.96734128679548, 33.95001002720424, 24.06475404330662, 15.359397717884608, 17.238006489617483, 21.033906391688756, 21.725394589560374, 28.746095895767212, 39.197623116629465, 43.30996656417847, 47.3490377834865, 40.47740486689976, 53.72531277792794, 41.95499835695539, 48.22313853672573, 49.48729726246425, 50.230646814618794, 49.1665996823992, 42.90495606831142, 43.19757597787039, 51.249885014125276, 44.823492663247244, 42.70814139502389, 50.22035305840628, 48.909311362675254, 54.897442613329204, 58.56494154248919, 59.97803143092564, 57.94323410306658, 43.70763281413487, 42.764651094164165, 31.45103829247611, 16.628034557615006, 7.141591710703714, 2.8077805127416338, 1.0546391627618243, 0.5131019385797637, 0.2021772169641086, 0.05029819280441318, 0.014639842556789517, 0.03587794962472149, 0.0400785394012928, 0.0326740361883172, 0.1183698233217001, 0.02050057682208717, 0.05251913291535207, 0.04549234979120748, 0.0063493715050364176, 0.06802873353340796, 0.0818947594878929, 0.05312056260715638, 0.04981929975162659, 0.0440552770825369, 0.037094742724938054, 0.06338382884860039, 0.04319274372288159, 0.02762677550448903, 0.01831067629557635, 0.04518255784309336, 0.02267238081965063, 0.027051030059478114, 0.016784834243091087, 0.018204500832195793, 0.09907756639378411, 0.050022900969322236, 0.05788079449640853, 0.021251411443310123, 0.03634569773982678, 0.05522332566657236, 0.07911655892218862, 0.07837874708431107, 0.022881749585004788, 0.036720330494322946, 0.010252368120875741, 0.06851343145327908, 0.03825333109125495, 0.11375100152300936, 0.050551842765084336, 0.07977616959916693, 0.054323421990764995, 0.05961326403277261, 0.06409481819719076, 0.037579807053719244, 0.0498712076805532, 0.036770559049078395, 0.034807832046811066, 0.010689942631870508, 0.012925729089017426, 0.050125064594405036, 0.07259559990572077, 0.024802912924704806, 0.01169624483944582, 0.042097001269991906, 0.0421343546227685, 0.0522613269276917, 0.030341175118727342, 0.032662450202873776, 0.022335635764258246, 0.008141527102062745, 0.02761565092285829, 0.01685780898800918, 0.0485840504989028, 0.07909893736775432, 0.07919270412198134, 0.011321897069657487, 0.035780498425343206, 0.04585476552269288, 0.06237090498741184, 0.029241992493293116, 0.034959979954042604, 0.01128915012148874, 0.0032086457940749824, 0.010786350583657622, 0.0466216084813433, 0.034931023472121785, 0.01886307165425803, 0.01049702409987471, 0.03204763980050172, 0.017011449672281742, 0.010261050824608122, 0.032828959303775, 0.02552674524486065, 0.09621994330414704, 0.02787440177053213, 0.045520787193839035, 0.10406336028661047, 0.01714205918168383, 0.02610646011973066, 0.016942605509289672, 0.027655007650277445, 0.03018401962305818, 0.02972980828157493, 0.003363378707685375, 0.049293173876191886, 0.03531908104196191, 0.011268790678254195, 0.01816764280998281, 0.03844931236069117, 0.060290204494127204, 0.06978212908974715, 0.040808782181037326, 0.025863088268254484, 0.05899408047220536, 0.006333166816537934, 0.03838776923449976, 0.035895096204642735, 0.06187788822821208, 0.04202580937583532, 0.05403871887496539, 0.016840372334367464, 0.30545499654752867, 0.9066825391990798, 5.6695563452584405, 17.252385786601476, 27.199178491319927, 41.25400849751064, 46.800175258091514, 60.19002096993582, 60.86699785505022, 67.48726231711251, 69.70647525787354, 68.55049651009696, 69.2109922681536, 61.657751492091585, 58.30855996268136, 59.22893224443708, 64.62172794342041, 44.72541536603655, 43.718263557979036, 43.10538727896554, 54.59841646466936, 56.36151838302612, 35.272304330553325, 40.75521469116211, 42.237105642046245, 32.29270485469273, 23.323245763778687, 45.15528999056135, 40.27639348166329, 27.22856937135969, 27.308082818984985, 31.993581431252615, 33.75456414903913, 42.52883618218558, 52.62829991749355, 51.61606897626604, 57.813959394182476, 49.008715765816824, 62.88660989488874, 50.00166545595442, 58.91906343187605, 58.68626403808594, 62.824680600847515, 59.50847217014858, 52.294195788247244, 52.1170723097665, 62.00569643293108, 55.338962418692454, 52.596188817705425, 60.20493180411202, 57.70917361123221, 62.79046767098563, 65.92943450382778, 68.48471096583775, 64.79465470995221, 52.12861326762608, 51.832369872501914, 39.239110810416086, 23.10939931869507, 10.595810907227651, 4.929607936314174, 1.9981831439903803, 0.786804617515632, 0.3779407212776797, 0.033162516940917285, 0.07522414957306214, 0.03585246724209615, 0.04550907228674207, 0.058311168902686665, 0.03783187263512185, 0.017306471609377434, 0.0642697038128972, 0.046676654634731155, 0.031466881678040536, 0.06525817327201366, 0.008831232503455664, 0.01946050307846495, 0.018272612177367722, 0.012736373714038303, 0.014849849145061203, 0.037546959173466475, 0.05529927748388477, 0.023997583459796648, 0.0489734753168055, 0.0543437508999237, 0.020811154174485376, 0.0016963561003129663, 0.06609365344047546, 0.022897388120847087, 0.07841833281729903, 0.0644093191783343, 0.02300711232237518, 0.04533599157418523, 0.050216748246124814, 0.06277479617191212, 0.047356957237103155, 0.04857357391821487, 0.03182371985167265, 0.045988158722008975, 0.029441044133688723, 0.019470116223341653, 0.04473556950688362, 0.02180969139694103, 0.04567000722246511, 0.05880470134850059, 0.04916997905820608, 0.030180033229823624, 0.017778396107522503, 0.035318887659481595, 0.06926077670816864, 0.004812022346803653, 0.02108018652402929, 0.0224479383988572, 0.022710287178467427, 0.015750914812088013, 0.020903579125713025, 0.07383081183901855, 0.014475097646936774, 0.043968994569565566, 0.05812446999230555, 0.0525692732605551, 0.11691553278693131, 0.17559876958174364, 0.1546959283628634, 0.0974429144657084, 0.10898193850048951, 0.12570747387196335, 0.21346771397760936, 0.16119804446186337, 0.1866381000727415, 0.1973344311118126, 0.09714434548680272, 0.21827090052621706, 0.11383342995707478, 0.10886649933776685, 0.12670763448945113, 0.08778619407010929, 0.13336459227970668, 0.12982981838285923, 0.12297086071755205, 0.10826854713793312, 0.08560151487056698, 0.17225569539836474, 0.10238162481359073, 0.14932917776916707, 0.17391673555331572, 0.1549437293516738, 0.151667572291834, 0.18210878382836068, 0.16739507764577866, 0.14629143077347959, 0.176893129412617, 0.05970122252724, 0.11221859803689377, 0.27274192763226374, 0.10109626914241485, 0.11741869364465986, 0.12146665714681149, 0.15665715241006442, 0.11429033508258206, 0.056541491898575, 0.12798902073076793, 0.1215974244156054, 0.12943622735994204, 0.13087523728609085, 0.1488267904413598, 0.1519836610449212, 0.19275227056017943, 0.10670555529317685, 0.11547352373600006, 0.12897544779947825, 0.18640002927609853, 0.10550990873681647, 0.06787893335734095, 0.1575805978583438, 0.16291545730616364, 0.5078306442924908, 1.5821948200464249, 8.108223795890808, 21.397708858762467, 34.074924741472515, 51.10635607583182, 61.917058263506206, 71.88060828617641, 72.16347639901298, 78.036878994533, 79.82273278917584, 76.54483672550747, 79.46615818568638, 70.22349071502686, 68.09067167554582, 66.13823481968471, 72.44693510872978, 52.089790207999094, 50.51011725834438, 50.75067431586129, 61.45034776415144, 60.03028188432966, 39.28168589728219, 47.67252506528582, 47.5949136870248, 39.87897736685616, 34.92594010489327, 50.98517949240548, 39.11557878766741, 27.314591544015066, 30.518801961626323, 37.20147166933332, 37.25985390799386, 46.792323793683735, 57.64998885563442, 61.78730065482003, 67.91050488608224, 59.22319998059954, 74.57441793169293, 59.716786112104145, 67.21097414834159, 70.57499313354492, 72.41320160457066, 67.69283866882324, 61.56561837877546, 62.637947763715474, 69.05613776615688, 63.80869838169643, 63.26638453347342, 69.0890930720738, 66.32717718396867, 70.6375755582537, 75.69845581054688, 78.97530964442662, 76.19363307952881, 60.80171952928816, 60.326351574489046, 45.44478668485369, 28.407904488699778, 14.089986154011317, 6.391976620469775, 2.4026744791439603, 1.1432720124721527, 0.46517310185091837, 0.11973631142505578, 0.33522664329835344, 0.13491176068782806, 0.08704048408461468, 0.10852909779974393, 0.24597638100385666, 0.18884314889354364, 0.11180674085127455, 0.1282724855201585, 0.0900168711585658, 0.2802011173750673, 0.14907316650663102, 0.14336892616535934, 0.09504596915628229, 0.12346328715128557, 0.15958663235817636, 0.13255796342023782, 0.12684875620262964, 0.06613375486007758, 0.1835336530847209, 0.10423346901578562, 0.10064934526703187, 0.10870655506317105, 0.1705502247703927, 0.12569546380213328, 0.20243537239730358, 0.27138613324080196, 0.1297834880117859, 0.14432604052126408, 0.07252975486751113, 0.19012989556150778, 0.15680486948362418, 0.15144183726183005, 0.081987182742783, 0.1488726186965193, 0.09717300002064024, 0.12233149074018002, 0.11492505030972616, 0.20046330536050455, 0.13295927617166722, 0.16155686735042504, 0.18852484811629566, 0.14859754059995922, 0.12821898981928825, 0.09516888577491045, 0.14664794664297784, 0.06349960727883236, 0.13282109930046967, 0.09095891525170632, 0.07947986014187336, 0.14269079826772213, 0.12221130861767701, 0.14438523591629096, 0.10025785770267248, 0.12852137216499873, 0.1310178924884115, 0.22174972242542676], [0.04594866119857345, 0.07675676340503351, 0.038361448861126385, 0.06989674043974706, 0.03719200732718621, 0.03874774563259312, 0.020780660810747316, 0.024774589176688875, 0.014209982988956784, 0.01575864332595042, 0.015686381042801907, 0.045990818579282076, 0.04162187747923391, 0.05839053714381797, 0.09262657112308911, 0.02662678960976856, 0.060262947742428095, 0.02743518096394837, 0.02157322024660451, 0.03360267582216433, 0.034631680963294845, 0.019146629742213657, 0.06524416830922876, 0.058128995820879936, 0.024466865064044083, 0.04293322782697422, 0.06652725767344236, 0.10230353900364467, 0.024657962577683584, 0.06743808915572506, 0.007365933586178082, 0.02528435387648642, 0.03709482414914029, 0.022073751781135798, 0.03647299769467541, 0.023279630645577396, 0.03154693863221577, 0.06315029066588197, 0.0157986633213503, 0.026186951336317828, 0.014610243162938526, 0.024730701531682695, 0.05666990465085421, 0.028768595574157577, 0.022112178915579404, 0.05592741431402309, 0.05995637883565255, 0.04655557006065335, 0.03275707530389939, 0.018735973563577448, 0.024304069246032407, 0.09597370294587952, 0.07807725361947503, 0.8696000033191272, 3.534929254225322, 8.323729991912842, 14.168303642954145, 29.79786729812622, 44.46571602140154, 50.152003628867014, 55.29157223020281, 56.09296008518764, 61.547441891261506, 54.46361793790545, 47.69669784818377, 43.844369888305664, 53.66212933404105, 39.857389313834055, 41.193437576293945, 43.71633890696934, 29.066696201051982, 14.493760739053998, 20.531786135264806, 16.514407191957744, 17.62431764602661, 19.93649227278573, 15.035509177616664, 18.271806376320974, 29.703653199332102, 17.672345331736974, 19.742621898651123, 35.13463619777134, 17.455215862819127, 18.979652370725358, 19.652218886784144, 21.756298439843313, 17.45935525212969, 19.842234747750418, 16.20680522918701, 21.825141191482544, 22.784426859446935, 24.490576131003245, 27.068835496902466, 21.926610946655273, 27.276729072843278, 28.44983513014657, 32.228722367967876, 28.05849174090794, 35.891920362200054, 35.989309787750244, 29.444926602499827, 32.15142365864345, 33.18299491064889, 34.3191157068525, 44.15817832946777, 37.38170099258423, 44.99539109638759, 52.45511954171317, 53.40318039485386, 52.67496401923043, 61.78338187081473, 59.073841503688264, 52.763904435294016, 45.760325227464946, 33.50649956294468, 22.70945927074977, 13.154585787228175, 5.101613632270268, 4.072690078190394, 0.9347614582095827, 0.1268211126859699, 0.024915944984448806, 0.04852936736174992, 0.0020720114282864544, 0.045188708763037405, 0.025559106276237538, 0.017136798838951757, 0.04058812937832304, 0.02761082993155079, 0.038333462684282234, 0.01151941267640463, 0.061304471854652674, 0.02335649509248989, 0.026699869527614543, 0.01603071720871542, 0.06912358371274811, 0.06581514874207121, 0.015018336175541793, 0.024948361994964734, 0.0539355476253799, 0.04103387938812375, 0.0409048830957285, 0.03368533495813608, 0.019642269039260488, 0.14588169061711856, 0.02606067936202245, 0.06390870961227588, 0.04106631675469024, 0.024081272272659198, 0.02700167172588408, 0.030229573071535145, 0.029112036073846475, 0.06169406630631004, 0.09240120250199522, 0.03994304613609399, 0.01831323267625911, 0.04958317295781203, 0.015501890763906496, 0.03899932945413249, 0.03829743926014219, 0.06727736456585781, 0.031838094616042714, 0.02563102250652654, 0.005859647337014654, 0.05320437864533492, 0.012635675724595785, 0.019161184318363667, 0.03417358161615474, 0.06430603936314583, 0.05578758521005511, 0.01584541947314782, 0.0338258968799242, 0.04860465760741915, 0.06230853404849768, 0.042272382216261964, 0.06476844740765435, 0.10329165562455143, 0.026769840058737567, 0.021106108258079206, 0.0357090622585799, 0.008880985235529286, 0.014816578876759325, 0.024671884419928704, 0.03099544911778399, 0.01622953645086714, 0.012589181656949222, 0.05467785815043109, 0.03826331573405436, 0.030488566495478153, 0.05198280526591199, 0.008780148146407945, 0.0481888513479914, 0.019779726663338285, 0.034767574564154656, 0.02510381436773709, 0.034026173276028464, 0.017030082243893827, 0.025014765128227215, 0.04028417622404439, 0.03751916977177773, 0.013586852899087327, 0.06891486634101186, 0.010294725669414868, 0.03724973030122263, 0.037711415705936294, 0.05003513156303337, 0.03992152639797755, 0.04818401339330843, 0.041182010368044884, 0.02856656177235501, 0.01439798214206738, 0.02483784221112728, 0.028202207127053822, 0.014901120947407824, 0.028493849959756647, 0.01015681681954967, 0.037540523268814595, 0.029209907964936326, 0.07362252872969423, 0.0325060546664255, 0.0304605294285076, 0.006005054422920304, 0.06006978239331927, 0.04229224972160799, 0.01576336762601776, 0.03611125032018338, 0.04078649230567472, 0.07022447963910443, 0.046043031848967075, 1.2539124126945222, 5.309447714260646, 9.883121149880544, 17.60497386114938, 36.752166407448904, 52.50785984311785, 59.357022285461426, 63.67723846435547, 64.68051665169853, 69.91472666604179, 65.89451285770961, 58.88430854252407, 53.4203702381679, 61.06478527614048, 49.16548797062465, 49.35297468730381, 55.15793057850429, 35.44116292681013, 24.180794170924596, 32.670884881700786, 27.665041310446604, 28.427699906485422, 30.500066144125803, 23.949417420795985, 25.523493596485682, 35.94042226246425, 29.450947216578893, 33.63613210405622, 43.5778682572501, 28.01370538984026, 28.468570947647095, 25.676659686224802, 28.694194589342388, 27.541627407073975, 28.749203477587017, 28.944520814078196, 32.15458508900234, 35.75748661586216, 36.711734839848106, 33.94782829284668, 35.390666893550325, 37.81603636060442, 36.216098989759175, 43.701174463544575, 38.59397751944405, 45.80192061832973, 48.1001832144601, 40.2869165284293, 40.55075352532523, 41.46105439322335, 43.22815152576992, 52.385505540030344, 46.24752596446446, 54.432316303253174, 60.614305768694194, 60.42344570159912, 59.959556170872276, 70.81933348519462, 67.81749629974365, 59.808815002441406, 55.03177561078753, 41.85105678013393, 29.79825292314802, 18.91941670009068, 7.890731283596583, 5.610174868788038, 2.1195998745305196, 0.22220753000250884, 0.016471288299986293, 0.04369009632085051, 0.02064208360388875, 0.027244682257462825, 0.06673127279749938, 0.015121588849329522, 0.0032047601208822535, 0.08097231827144112, 0.03819964200790439, 0.06025399786553212, 0.041100857579814534, 0.01464765249485416, 0.03197095516536917, 0.02227630975124027, 0.035754527497504435, 0.03129856088863952, 0.010119640734046698, 0.05617697270853179, 0.031753779854625463, 0.03650136385113001, 0.08097088656255177, 0.035113797057420015, 0.04962162892999394, 0.04517127041305814, 0.021766081951292496, 0.037836089730262756, 0.055317726851041825, 0.032394629038338146, 0.019697684994233505, 0.06012442481837102, 0.016200335696339607, 0.0359362323901483, 0.05456024767564876, 0.06031491673950638, 0.019440630484106283, 0.05092725244217685, 0.030624314211308956, 0.03313794040254184, 0.044982763206852336, 0.04529073328844138, 0.015270651118563754, 0.02441104198805988, 0.03625993769881981, 0.01897510796386216, 0.01434739735642714, 0.05986274778842926, 0.07821976632944175, 0.0297673753728824, 0.04757514695769974, 0.05051191097923687, 0.014405284875205584, 0.025455402376662408, 0.038783216050692966, 0.05538597729589258, 0.03573476855776139, 0.12645295315555163, 0.16233316569456033, 0.20002364180982113, 0.14561038517526217, 0.07951740348445517, 0.14132139246378625, 0.11278020790112869, 0.20932756470782415, 0.07647926972380706, 0.1441210958042315, 0.17484646423586778, 0.14438374313924993, 0.20075804740190506, 0.12461801804602146, 0.14916214958897658, 0.13131346234253474, 0.12055575102567673, 0.10195881607277052, 0.08859453283782516, 0.09841635437416178, 0.13775505311787128, 0.14582838490605354, 0.1403142972184079, 0.18511786950486048, 0.10255716182291508, 0.2049557092998709, 0.19219868097986492, 0.10471121195171561, 0.13761291360216482, 0.17623268413756574, 0.20078356031860622, 0.12430669260876519, 0.09519946734820094, 0.12528792209923267, 0.16847761241453035, 0.07005808249648128, 0.1106448242706912, 0.15012254805437156, 0.12682797946035862, 0.10154377655791384, 0.17253401689231396, 0.16298135662717478, 0.11232436807560069, 0.16344634310475417, 0.15795870471213544, 0.11692390590906143, 0.1961695086210966, 0.1549057721027306, 0.11629755023334708, 0.1617501548358372, 0.11538839473256043, 0.2651268648249762, 0.20152819821877138, 1.479824947459357, 7.421355281557355, 13.77242134298597, 23.813729524612427, 44.988592284066335, 61.59173665727888, 68.57578100476945, 74.40409673963273, 74.0388994216919, 78.34433678218296, 76.08668640681675, 66.44888877868652, 59.59098202841622, 70.16109589168003, 57.591099398476736, 55.887296880994526, 60.348287037440706, 44.5013359614781, 29.276005472455704, 35.31742940630232, 29.153140476771764, 30.27777590070452, 31.686092376708984, 25.544782876968384, 27.894203322274343, 43.49649442945208, 29.79367753437587, 34.44184521266392, 50.27970804486956, 30.47946126120431, 29.85164635522025, 28.70093434197562, 32.67084319250924, 30.49185684749058, 30.969882488250732, 27.190762485776627, 34.698417867933, 37.36880513599941, 39.77954517092024, 40.99368034090315, 37.598443099430625, 43.474461691720144, 42.00046736853463, 49.332276003701345, 43.023631300245015, 52.72257307597569, 53.51220110484532, 44.37599045889718, 46.5201871735709, 47.95459066118513, 48.42019292286464, 59.695955412728445, 53.562047481536865, 63.71252836499895, 69.44256183079311, 71.53176702771867, 70.98208114079067, 79.47908183506557, 76.91560649871826, 70.162353515625, 65.7677082334246, 51.62873554229736, 36.01066855021885, 23.41893982887268, 10.789584875106812, 7.0713245783533365, 2.5887203131403242, 0.45194251037069727, 0.10018371418118477, 0.15240684976535185, 0.06013124409530844, 0.11553164704569749, 0.12133067872907434, 0.12370399066380092, 0.11013045401445457, 0.20437138208321162, 0.20396679879299232, 0.11331059158380542, 0.21106921482299054, 0.11840113092746053, 0.0642147831884878, 0.10217529588512012, 0.12196638461734567, 0.14506246814770357, 0.1521176038576024, 0.15467668510973454, 0.1196490925337587, 0.17611429334751197, 0.20292317122220993, 0.10435455358986344, 0.19414929273937429, 0.19248635268637113, 0.10900845564901829, 0.09610616655222007, 0.1508891297770398, 0.1746366476374013, 0.12565956929964678, 0.09812423826328345, 0.1389704179018736, 0.09433272028607981, 0.16810489312878676, 0.1378769858607224, 0.08134582465780632, 0.20253082870372704, 0.1054957409256271, 0.09219042916915246, 0.2297723133649145, 0.14012518950871058, 0.08963498486472027, 0.16196124708013876, 0.11589383546795164, 0.16154571223471845, 0.08100775137011494, 0.12045448645949364, 0.22408144016351017, 0.11963668891361781, 0.1222085537655013, 0.14437756847058023, 0.12451110806848321, 0.16721857711672783, 0.2107978958104338, 0.12075088412633964, 0.17077956960669585], [0.04830560347597514, 0.015154794656804629, 0.06695734030966248, 0.029329031572810242, 0.016911754218329276, 0.03740538962717567, 0.031360585774694166, 0.04763992330325501, 0.03522898516218577, 0.018347653061417595, 0.0884746289146798, 0.052697112650743554, 0.05942368134856224, 0.026632760717932667, 0.037889161346746345, 0.04013666949634041, 0.04815468032445226, 0.014888786877106343, 0.060241411040936194, 0.10660635347345046, 0.03735199570655823, 0.053971964599830766, 0.03655776707455516, 0.01187798789968448, 0.06276830937713385, 0.01595390704460442, 0.04019772407731839, 0.01852212137808757, 0.023247200064361095, 0.019213582488841245, 0.05598912707396916, 0.06248122799609389, 0.008450983175342637, 0.013061570103413292, 0.01904091059363314, 0.027395166057561125, 0.056928097403475215, 0.016360508976504207, 0.05218378733843565, 0.03803665789642504, 0.0651537806593946, 0.024240639792489152, 0.07597856516284601, 0.026429547961535196, 0.023723489239013622, 0.05019585615290063, 0.017690629299197878, 0.010520749924970525, 0.04692672532317894, 0.03871873486787081, 0.054899857845157385, 0.7073402958256858, 3.10142354454313, 16.06693278040205, 19.122767891202653, 31.17264829363142, 42.554610524858745, 47.05115113939558, 56.11983571733747, 57.94248022351946, 57.910782541547505, 58.849706513541086, 59.42336368560791, 59.518519265311106, 49.10074118205479, 44.58738592692784, 35.69571713038853, 39.485250745500835, 29.676131384713308, 22.77424774851118, 31.017661775861466, 19.189923967633927, 9.43826447214399, 18.856670992715017, 11.71707819189344, 18.935236011232647, 35.16407918930054, 30.63430186680385, 27.36283462388175, 25.629774979182653, 19.98756500652858, 21.080735513142177, 28.71637671334403, 30.859228951590403, 32.01270634787423, 26.321025201252528, 25.681551218032837, 26.991406508854457, 25.279156718935283, 21.37904599734715, 16.869420187813894, 20.23659191812788, 20.22549911907741, 9.904757840292794, 20.15405774116516, 16.431431804384502, 21.408742598124913, 19.94260495049613, 18.363090072359356, 28.20536276272365, 18.901375702449254, 28.183861562183925, 39.30190168108259, 23.78166879926409, 33.55104793821062, 28.733149664742605, 33.450934818812776, 46.186889035361155, 43.48827123641968, 49.737668650490896, 50.1552414894104, 57.08542340142386, 58.41425595964704, 52.62678173610142, 53.65837383270264, 50.24369553157261, 49.05400759833199, 26.701098612376622, 18.225899628230504, 13.147056545530047, 4.57542872428894, 0.7313003987073898, 0.08168703956263405, 0.045044978082712205, 0.01903998608967023, 0.03739402416561331, 0.03192613114203725, 0.02186579945763307, 0.0163470570197595, 0.06463951218341078, 0.06289547362497874, 0.06252033875456878, 0.07968209071883134, 0.1486122648098639, 0.055765142664313316, 0.021885115653276443, 0.03894871074174132, 0.018891286836670976, 0.08904053390558277, 0.013322148754793619, 0.0372524546193225, 0.027108023608369485, 0.07692788993673665, 0.022621906295950924, 0.050132246887577434, 0.04129515608240451, 0.02383050269314221, 0.03817508243290441, 0.06889458492930446, 0.03388921437518937, 0.09561229483889681, 0.04669608109231506, 0.043811906927398274, 0.03318266603829605, 0.03464948911485927, 0.02283399598672986, 0.025053850441638912, 0.01761984622239002, 0.04863476420619658, 0.05330342100933194, 0.03931095344679696, 0.011560232494957745, 0.0161737557833216, 0.02997455925547651, 0.02686431588205908, 0.007473424559326044, 0.025569460720622113, 0.004660557215434632, 0.04589861924094813, 0.07241669736270394, 0.06603731467787709, 0.04897770258997168, 0.031488476055009026, 0.03147507838106581, 0.032388752925076654, 0.056317633017897606, 0.016357825370505452, 0.04463149919839842, 0.02797229741034763, 0.004237493175813662, 0.03141683293506503, 0.024667855618255477, 0.02020528686365911, 0.06467350000249487, 0.01042348871539746, 0.020868020498060753, 0.05619126604869962, 0.039476777227329354, 0.04359648562967777, 0.04227355268916913, 0.04456176954720702, 0.03629607647391302, 0.013963865615161402, 0.02298906837989177, 0.004153098262447331, 0.13082677631505898, 0.024623099448425428, 0.07711429707705975, 0.06774072934474264, 0.04187644346218024, 0.007403617724776268, 0.01789997092315129, 0.007179251639172435, 0.07312656712851354, 0.031070233854864324, 0.03801918222701975, 0.01705177331210247, 0.040131746724780114, 0.046009675067450316, 0.04343855321141226, 0.08219575762216534, 0.031237523271036998, 0.04050474420988134, 0.04865788189428193, 0.044760580307671, 0.05810853799006768, 0.01657354522363416, 0.020840628039357916, 0.010396415168153388, 0.018446032157433883, 0.017212350320603167, 0.0387154236169798, 0.024395174446648786, 0.057968556215720515, 0.06600092484482697, 0.04925779166764446, 0.1426126446042742, 0.708076642027923, 4.343767966542925, 20.55018322808402, 26.331772327423096, 40.83328117643084, 52.27218736921038, 58.20274237224034, 68.26300784519741, 69.38871329171317, 68.28067016601562, 68.28961944580078, 68.86177580697196, 66.57897295270647, 56.1852981703622, 48.867868832179475, 44.951454162597656, 46.55878789084298, 39.32601193019322, 36.612743854522705, 36.356841700417654, 20.31250098773411, 11.553226641246251, 20.175407818385533, 14.988716534205846, 20.624247550964355, 28.58378423963274, 23.444208690098353, 36.81573895045689, 30.023381505693706, 25.935379334858485, 30.884235518319265, 29.447504384177073, 31.405180181775773, 32.423608916146414, 29.501349449157715, 30.858103343418666, 31.350285938807897, 28.02893931525094, 29.585103034973145, 21.84590588297163, 32.69497428621565, 33.9432772227696, 18.66253658703395, 29.447956017085485, 29.903167247772217, 32.03972789219448, 33.538513387952534, 30.045212745666504, 33.89430979319981, 26.1952280657632, 41.242821897779194, 47.95877695083618, 27.659644297191075, 39.56504038402012, 33.49363497325352, 38.04986408778599, 52.443234648023335, 51.95450183323452, 57.50346524374825, 58.693087169102256, 63.99801594870431, 65.17653465270996, 61.543008940560476, 63.73542962755476, 60.78872639792306, 60.09891619001116, 36.77379962376186, 25.005958761487687, 17.734460490090505, 7.212122874600547, 2.0976255450929915, 0.46057469717093874, 0.03458912663960031, 0.041215723380446434, 0.03515385776492102, 0.09410771128854581, 0.06295798027089664, 0.018758205763463463, 0.058075710465865474, 0.026209785736032894, 0.012677858550367611, 0.057977702867771895, 0.032138767053506205, 0.020384918831821, 0.027357812704784528, 0.09107535864625659, 0.05173055987272944, 0.03868171399725335, 0.02948691649362445, 0.003147496854320967, 0.04219767551070877, 0.011774616482268487, 0.013965485617518425, 0.05723412348223584, 0.08947398886084557, 0.03667171346023679, 0.06683601824832813, 0.08412840177438088, 0.04178655453558479, 0.040260308754763434, 0.019141121734199778, 0.06884423084557056, 0.038276350391762595, 0.03475970695061343, 0.014695356899340237, 0.03678951731749943, 0.0035683804640679485, 0.03354683578280466, 0.01103964600978153, 0.024306474652673517, 0.02165614570757108, 0.03338222997263074, 0.0644759377464652, 0.017342539138293693, 0.0156564898788929, 0.0667405076591032, 0.0321360054159803, 0.01457478292286396, 0.012213556544988282, 0.028035514821697558, 0.07021333130874804, 0.026039125697155083, 0.008535932367002326, 0.013501821435056627, 0.08907884399273566, 0.16483746202928679, 0.11610476486384869, 0.17656893895140716, 0.0969401268022401, 0.09209279476531915, 0.1062256885426385, 0.16822169614689692, 0.13628242856689862, 0.10478867350944451, 0.0939642350588526, 0.1597369685769081, 0.23765200482947485, 0.23055374143379076, 0.14426551519760064, 0.09446232725999185, 0.11475157604685851, 0.11087845066296202, 0.1277102106916053, 0.16520708719534533, 0.26082335146410124, 0.18501557356544904, 0.1596340619559799, 0.1343230094228472, 0.1528848505445889, 0.1346319057047367, 0.045923372198428423, 0.14643369242548943, 0.18793969308691366, 0.05158063077500888, 0.17381353037697927, 0.15949186815747193, 0.193209331748741, 0.174615205930812, 0.13022260873445443, 0.15127149783074856, 0.1244539347078119, 0.15389761834272317, 0.11219691205769777, 0.13051416166126728, 0.13581106386014394, 0.1438008001340287, 0.13548854259507997, 0.19197104605180876, 0.10699640254357032, 0.06957157288811036, 0.1312127134629658, 0.10761034781379358, 0.23342329316905566, 0.12974375300109386, 0.14050656690129212, 0.22564075434846537, 1.163229193006243, 6.369416688169752, 28.36276204245431, 36.31071955817086, 52.670614446912495, 66.13558060782296, 70.08171967097691, 76.65632057189941, 77.02774347577775, 75.44845962524414, 75.64692102159772, 76.1994765145438, 74.76529884338379, 64.09135804857526, 60.674504961286274, 50.48074722290039, 57.50730759756905, 44.51466955457415, 36.479331493377686, 46.03067963463919, 33.16002069200788, 18.74773713520595, 27.155057430267334, 26.573408092771256, 33.16743789400373, 50.13244097573416, 46.021653924669536, 43.448822838919504, 37.49963971546718, 30.261187076568604, 30.824071066720144, 42.636571475437705, 42.551351819719585, 46.107790742601665, 36.995249135153635, 36.30024514879499, 38.524658816201345, 38.83455542155674, 33.35318061283657, 27.20537281036377, 34.01153979982649, 34.33416550500052, 19.22141146659851, 31.183411053248815, 28.37393127168928, 34.36458124433245, 33.97200107574463, 30.406522546495708, 41.744992528642925, 32.42432458060128, 41.11437055042812, 52.3401893888201, 35.87323318208967, 47.08731998716082, 42.76188571112496, 46.78431946890694, 58.571431159973145, 60.28204986027309, 67.00632885524205, 65.7064459664481, 72.51752880641392, 75.48681368146623, 69.9970350265503, 74.25892802647182, 72.11130932399205, 71.2075501850673, 44.87988771711077, 30.6617785181318, 21.84331246784755, 9.70904619353158, 3.3010114175932745, 0.6551820146186011, 0.14432191502835068, 0.104753179342619, 0.1652285831847361, 0.15268024509506567, 0.07028001773038081, 0.12132606469094753, 0.10323336268109934, 0.2447960286268166, 0.2028844675847462, 0.1689019546444927, 0.2109965980052948, 0.09254074322858027, 0.07421633508056402, 0.2349508654858385, 0.18999230223042624, 0.15241307871682302, 0.08306608734918491, 0.1234382763504982, 0.13376446653689655, 0.14567461530012743, 0.10922630610210554, 0.18754686202321733, 0.20591245724686555, 0.15102114555026802, 0.12130412086844444, 0.19154169623340878, 0.1281980773700135, 0.19806210563651153, 0.1515106000006199, 0.14169811510613986, 0.14284752628632955, 0.13409871288708278, 0.08535178684230361, 0.1321151786084686, 0.20026701875030994, 0.14821502326854638, 0.12272486463189125, 0.15232550698731626, 0.14393983195934976, 0.14342979075653212, 0.13957849384418555, 0.10834058720086302, 0.09494009733732257, 0.14408316569668905, 0.0828867234023554, 0.08644853013434581, 0.12111656021858964, 0.1898887577865805, 0.1899200246802398, 0.10646940475063664, 0.09362124239227601, 0.1218824769769396, 0.19506287228848251], [0.04531677546245711, 0.03357124947277563, 0.06746771399463926, 0.00873754802159965, 0.04794287222570606, 0.019645308876144033, 0.020010564276682477, 0.06046472370092358, 0.0959946968193565, 0.009011772012204995, 0.03460658873830523, 0.0071913753636181355, 0.017052309354767203, 0.054748514001922946, 0.043196821718343666, 0.06384830642491579, 0.030397093189614158, 0.03038066246413759, 0.03235888381355575, 0.042446216102689505, 0.02724576452081757, 0.0574523267735328, 0.03404742499281253, 0.07684580755553075, 0.04374060986031379, 0.007329756643490067, 0.05969979760370084, 0.002821581853952791, 0.016739994952721254, 0.051388028609965525, 0.032652720010706356, 0.04417552366586668, 0.01583127710702164, 0.013287141436843999, 0.02432754825401519, 0.02225195543308343, 0.04075963928231171, 0.10286518957998071, 0.08879551491034882, 0.020730472968092988, 0.028640986885875463, 0.057321912342948575, 0.03847685409709811, 0.07055160815694503, 0.06756387597748212, 0.04059808687972171, 0.04915660174031343, 0.1375526868339096, 0.04123111255466938, 0.5888316035270691, 1.4528364070824213, 5.809824841363089, 22.65481516293117, 30.631136962345668, 39.49538469314575, 38.31577164786202, 45.38709231785366, 52.241177558898926, 55.05299193518502, 60.12953690120152, 54.99317141941616, 48.30926840645926, 44.082237992967876, 38.840249470302034, 39.2590069770813, 38.41456460952759, 36.518519333430696, 24.513524293899536, 12.846674629620143, 19.460860286440166, 28.29690875325884, 19.135927779333933, 32.968743732997346, 40.92652947562081, 28.68645429611206, 30.44584240232195, 34.314953735896516, 41.776342800685335, 31.53391293116978, 45.7198554447719, 50.32709475925991, 40.15347637448992, 38.670744691576274, 42.27375738961356, 43.31561892373221, 33.86512041091919, 34.225752762385774, 30.03747592653547, 38.56140783854893, 27.84613742147173, 29.59886394228254, 28.5787832736969, 19.134781326566422, 25.092465570994786, 18.73590956415449, 18.275994403021677, 20.614341156823293, 13.8050057888031, 24.747272116797312, 34.33650009972708, 32.67242738178798, 12.30534221444811, 30.767693383353098, 46.171470982687815, 36.819834913526265, 27.291167429515294, 24.05204231398446, 24.15320634841919, 28.314100333622523, 41.349615710122244, 42.46661158970424, 56.970924036843435, 41.08800213677542, 48.950517654418945, 48.03999444416591, 52.720530305589946, 57.19567741666521, 61.39364351545061, 52.10651452200753, 37.780694348471506, 30.511416026524135, 16.33341704096113, 9.8256847347532, 2.7498473014150346, 0.8707076981663704, 0.033824336249381304, 0.023488448101228902, 0.03255691425874829, 0.005935050813215119, 0.053257457047168694, 0.03679118312097021, 0.07975139628563609, 0.013823173075382198, 0.06111375601696117, 0.06234038448227303, 0.0382407035545579, 0.007885423389130404, 0.02738192953568484, 0.042490697465837, 0.048773310878979306, 0.010401857867171722, 0.08268795335399252, 0.06904179988695042, 0.10160407796502113, 0.04202063215364303, 0.017329370469919274, 0.028539274486580064, 0.05626314665590014, 0.02523700231021004, 0.03617462549092514, 0.03475925911750112, 0.0164220622807209, 0.06286246968167168, 0.016844830309439982, 0.053329283371567726, 0.03527684902240123, 0.021146581175604036, 0.02372187262933169, 0.0508886234435652, 0.047098231834492514, 0.04331936175003648, 0.020733511108638983, 0.022884594343070472, 0.024345507379621267, 0.07674298235880476, 0.04157214764771717, 0.011397366278937884, 0.019826555757650306, 0.00968263449613005, 0.04241562095869865, 0.020238462137058377, 0.029643064364790916, 0.04244981912363853, 0.012215978066836084, 0.027912148673619543, 0.03641590915088143, 0.021455138189984218, 0.011072923911602368, 0.01433938555419445, 0.04076033817338092, 0.07349376313920532, 0.039030470818813355, 0.03495310978697879, 0.03310574730858207, 0.062311336398124695, 0.042390389634030204, 0.03787331076871071, 0.06770992385489599, 0.019104463879817297, 0.04117543197103909, 0.033488892284887176, 0.079096888191998, 0.05935264551745994, 0.009996007412805088, 0.042099807012294016, 0.05895980088306325, 0.03937486805287855, 0.010677836718969047, 0.02105282459940229, 0.03305692332131522, 0.007053589498225067, 0.024117979320830533, 0.021509263232084255, 0.024399511981755495, 0.013118534814566374, 0.0494463395859514, 0.02605834011254566, 0.03492513718083501, 0.030619985157889978, 0.024289959110319614, 0.016909720309610878, 0.041228520550898144, 0.02400755283555814, 0.031973428425512145, 0.018225866203595485, 0.04636727659297841, 0.006748629991696882, 0.0032642621289206935, 0.09897238668054342, 0.07658404231603656, 0.043388629997415204, 0.00813537957479379, 0.06416797784290143, 0.007356788630464247, 0.054582520587635894, 0.7813835569790432, 1.865685339484896, 8.508234194346837, 26.513622317995342, 40.991012232644216, 51.808190141405376, 50.328522614070344, 60.105273791721885, 64.51519816262382, 65.59125873020717, 67.988783291408, 64.79162529536656, 55.20874622889927, 52.328120367867605, 47.71168163844517, 47.74953889846802, 46.4296486718314, 39.700488567352295, 36.25038487570626, 22.813525915145874, 26.072658368519374, 35.29495198386056, 29.55035161972046, 27.74156355857849, 35.91602713721139, 30.4095276423863, 38.49000467572893, 41.620849064418245, 43.130845478602815, 38.16777154377529, 35.60307332447597, 41.18282767704555, 33.57537358147757, 31.422012192862375, 31.760584013802664, 35.458120005471365, 25.254669530051096, 25.76334367479597, 25.024468762534006, 28.579021249498638, 24.184077194758824, 25.37644018445696, 30.095879009791783, 26.15048166683742, 26.37553381919861, 27.462482213974, 23.560042108808243, 23.59817729677473, 16.985111168452672, 24.042716094425746, 43.57446016584124, 34.50694983346121, 19.050558737346105, 35.72945063454764, 48.928120136260986, 46.53216239384243, 34.23719991956438, 34.2529410634722, 36.01222842080252, 39.249519211905344, 53.6854544367109, 52.049230098724365, 61.71679728371756, 50.858729226248606, 54.08301993778774, 56.19729423522949, 57.17313746043614, 64.53973225184849, 70.22401877811977, 63.022287368774414, 50.20972578866141, 39.52543912615095, 21.782359395708355, 13.211506298610143, 4.81853620495115, 1.1169331286634718, 0.09383043473852531, 0.06744623836129904, 0.012207669405532735, 0.019522877410054207, 0.07867276309324162, 0.04794861263196383, 0.016536314007160918, 0.05104804185352155, 0.06702909538788454, 0.04455736246226089, 0.011603986129297741, 0.052364338721547804, 0.03295709724937167, 0.02443752351350018, 0.04311454934733255, 0.04465877291347299, 0.02639032354844468, 0.006815297753616635, 0.07096095476299524, 0.04564603797293135, 0.03603261150419712, 0.010621945789482976, 0.03942169714719057, 0.042963219074798484, 0.007758915623916047, 0.0361866457387805, 0.041034317043210776, 0.006902172712476126, 0.0715018150263599, 0.021621175709047487, 0.05507488934589284, 0.06967044901102781, 0.02125413915408509, 0.06564031740916626, 0.022002103572179164, 0.06447823119482823, 0.036286213967416964, 0.014961966878867574, 0.045967843383550644, 0.007237639577527131, 0.025467963756195137, 0.098520170232015, 0.0161363803781569, 0.01571770221926272, 0.03071778580280287, 0.00022463384188345766, 0.09027233280773674, 0.0510698567543711, 0.016351494638781463, 0.04272824579051562, 0.05046334144260202, 0.1066692333136286, 0.11855590476521424, 0.10869461284684283, 0.09602082041757447, 0.16116092859634332, 0.1713746448180505, 0.15550974969352993, 0.1631616298109293, 0.2321650449718748, 0.1242037181343351, 0.157553497169699, 0.27411606961062973, 0.12663109573934758, 0.13595874022160256, 0.10749815883381025, 0.2002382217241185, 0.13685171944754465, 0.13502787160021917, 0.09240053075232676, 0.13424071669578552, 0.187204242550901, 0.16157959827354976, 0.10907032447201864, 0.14961922434823854, 0.15497685543128423, 0.10341657392148461, 0.16119816659816674, 0.0968658272176981, 0.10951995570212603, 0.15568732230791024, 0.15021155827811786, 0.15489088504442147, 0.09741265858922686, 0.12903146765061788, 0.12397635462028639, 0.13036503323486873, 0.12876930886081286, 0.23909440743071692, 0.1522633396089077, 0.105962274463049, 0.0982814005443028, 0.1615455358156136, 0.21492631999509676, 0.2040262520313263, 0.14202876522072724, 0.1506426315754652, 0.12406615194465433, 0.12408470309206418, 0.2728434093296528, 1.2342636670385088, 3.18956926039287, 11.962678773062569, 34.01997143881661, 52.347405093056814, 66.90735871451241, 64.36623573303223, 68.83104392460415, 71.06646701267788, 73.03833103179932, 75.4018302645002, 70.4960685457502, 60.74422318594796, 59.27425534384591, 54.452004023960654, 51.86821910313198, 51.7879569871085, 48.442541803632466, 38.91751691273281, 25.19892760685512, 29.00797697475978, 40.524829796382356, 30.623292446136475, 49.400840827396934, 53.825134072984966, 46.600588253566194, 47.058762890951975, 49.94982494626726, 58.78292737688337, 44.796043804713655, 59.87307889120919, 66.36705984388078, 57.587573187691824, 55.74010624204363, 58.532938139779226, 57.35495444706508, 49.046114444732666, 51.289114543369834, 45.2365665435791, 54.79358441489083, 40.595215048108784, 44.63280977521624, 42.841817787715364, 31.400761127471924, 37.87575265339443, 31.80883230481829, 28.243624755314418, 33.599799973624094, 22.789136001041957, 38.554209504808696, 49.34684290204729, 46.202376570020405, 21.141554832458496, 41.79839638301304, 58.496835299900596, 49.78034448623657, 41.634707246507915, 38.64224318095616, 40.19428314481463, 42.94427245003836, 58.135838168007986, 59.68388639177595, 72.49360615866524, 58.53393868037632, 65.59123788561139, 64.26273536682129, 67.63275064740861, 74.2788485118321, 80.27160031454903, 74.54952948434013, 60.35424164363316, 48.88428742544991, 29.002871785845073, 16.336029563631328, 6.537609125886645, 1.7094688819987434, 0.1939190115247454, 0.20736910908349923, 0.20712886697479657, 0.08577120969338076, 0.12709621792393072, 0.16532127106828348, 0.22102404279368265, 0.16351178102195263, 0.1803543772548437, 0.1432534395051854, 0.11193938087671995, 0.12645274959504604, 0.17861578054726124, 0.11694833316973277, 0.09492215008607932, 0.09547088814101048, 0.2322648981852191, 0.21274854828204426, 0.22249507957271167, 0.16240268839257105, 0.16480337242994988, 0.0948509242651718, 0.17396682500839233, 0.19929006403045996, 0.17564759696168558, 0.10617278316723448, 0.12237726471253804, 0.13250777897025856, 0.14153297325330122, 0.13292752073279449, 0.1662996778530734, 0.1325080639549664, 0.09693371464631387, 0.2031241397240332, 0.13222653977572918, 0.1451168188026973, 0.08379164484462567, 0.08481961861252785, 0.10223418593938861, 0.13563520115401062, 0.1359108763613871, 0.15281204373708793, 0.09832511177020413, 0.1272357382944652, 0.10959202290645667, 0.10107018625629799, 0.16383659573537962, 0.10633591655641794, 0.08098846740488495, 0.13217045207108769, 0.10332775368754353], [0.024941474864525453, 0.019780961597072225, 0.004733335185197315, 0.06847511458077601, 0.06532001495361328, 0.010661646025255322, 0.03163944670398321, 0.0020634678242328975, 0.05560110343087997, 0.06229572330734559, 0.03982093358146293, 0.028610021940299442, 0.01948854184177305, 0.0172819391757782, 0.00779673971036183, 0.04503646586090326, 0.034383958006011586, 0.02597707536603723, 0.059950665570795536, 0.11132544917719704, 0.0327753414666014, 0.04535736542727266, 0.03148187051660248, 0.03855118082304086, 0.0337076655455998, 0.037468707122440846, 0.025197238461779695, 0.017804015893489122, 0.08451180120131799, 0.024790280298995118, 0.00700326552448262, 0.11223331546144825, 0.027915336091869643, 0.00659259662331481, 0.01934158812010927, 0.021340939050008143, 0.06471401532845837, 0.07420642168394156, 0.05567476858517953, 0.03507603658363223, 0.09622547336454902, 0.050123775377869606, 0.019103997386991978, 0.06530922624681677, 0.03162932296150497, 0.034033280930348804, 0.010472058252032315, 0.06349182448216847, 0.9614632768290383, 3.98238651241575, 12.903511762619019, 27.17362822805132, 34.89804308755057, 45.094211850847515, 50.13745410101754, 56.528177874428884, 54.04049001421247, 55.4104767526899, 61.24793284279959, 52.53273091997419, 32.55871663774763, 40.791706630161826, 47.63302803039551, 33.10459838594709, 22.238644123077393, 20.63522744178772, 29.15183421543666, 12.952917797224861, 17.82820037433079, 22.296665055411204, 18.748577867235454, 19.13709681374686, 23.25202672822135, 31.140047345842632, 24.138391051973613, 27.02429406983512, 23.215956892286027, 16.515558855874197, 34.04270594460623, 40.891274315970286, 35.220880712781636, 31.364015579223633, 24.376168830054148, 30.134556157248362, 28.037197249276296, 26.759053536823817, 26.249988555908203, 30.356829030173166, 25.753232308796473, 38.58214126314436, 26.267609187534877, 34.23029688426426, 35.59192493983677, 29.848161833626882, 31.438142435891287, 31.069422381264822, 32.251703534807476, 50.829682282039094, 40.862442765917095, 31.03222520010812, 55.1928174836295, 51.93874331883022, 71.87529291425432, 37.76485940388271, 18.627178941454204, 22.78173095839364, 11.209800635065351, 16.693311146327428, 16.35704960141863, 25.335838385990687, 37.25826277051653, 32.79219695499965, 27.558106797082083, 36.03875316892351, 41.76428420203072, 48.802680832999094, 55.335001945495605, 53.08038098471505, 54.916035992758616, 58.221658842904226, 50.79437501089913, 48.85310391017369, 34.64099448067801, 24.358079195022583, 9.089444058282034, 3.6183232707636694, 0.6170660970466477, 0.053879863649074516, 0.01804442424327135, 0.021363534266129136, 0.03801123318927629, 0.013883105529073094, 0.03954329062253237, 0.09560238822762455, 0.04261169383036239, 0.03947497232417975, 0.0727349981399519, 0.05699166934937239, 0.020991274687860693, 0.13166716907705578, 0.013645141601695545, 0.023053240829280446, 0.0510142304535423, 0.014740012985255038, 0.06378191177334104, 0.06323222376938377, 0.050992103426584175, 0.041213999901499064, 0.03579014380063329, 0.1115234728370394, 0.028598473274282048, 0.047429641908300776, 0.04270582360082439, 0.06635312523160662, 0.023826126142271926, 0.06268251540937594, 0.05582919976274882, 0.04293689870142511, 0.06118082241820438, 0.031117541316364492, 0.023545526466997604, 0.017274522788024375, 0.02681085410793977, 0.04331896480705057, 0.06576250799532447, 0.02078168879130057, 0.031604006819959195, 0.03365174408203789, 0.048108424592231, 0.017363992719245807, 0.02699726803361305, 0.036869051799710305, 0.13140719517001084, 0.06752768291958741, 0.02030226308852434, 0.05073572575513806, 0.02623573291514601, 0.00548903617475714, 0.0015271380543708801, 0.07677753336195435, 0.06258902006915637, 0.051062647319797955, 0.038047609451626024, 0.021689629714403833, 0.019787655345031192, 0.04052919182660324, 0.05903226163770471, 0.027247399790212512, 0.025435456839789237, 0.050477305693285804, 0.03228910666491304, 0.05705519379781825, 0.025301697231563072, 0.01901083792160664, 0.016727284295484424, 0.04433087765106133, 0.023976766005424515, 0.029941623165671314, 0.009488689679918545, 0.04581331381840365, 0.013008799586844231, 0.02793655388190278, 0.045676378666290214, 0.05620509119970458, 0.10329966233777148, 0.058461878315678666, 0.05957313547176974, 0.02595910436606833, 0.01986078106399093, 0.011622814627896463, 0.00975411816034466, 0.028049326402002146, 0.03572771857891764, 0.04815392715058156, 0.050256262732935805, 0.020743682348568524, 0.06243922667843955, 0.036576056985982826, 0.022237219348815934, 0.033207456315202374, 0.04516821700547423, 0.07020173514527933, 0.03605333396366664, 0.07203527925802128, 1.2349187518869127, 5.59212475163596, 17.78943463734218, 34.81768022264753, 42.06141001837594, 55.75486421585083, 64.1504316329956, 66.74882166726249, 62.59156158992222, 64.47020857674735, 70.34660584586007, 60.25370121002197, 45.284314564296174, 46.06122044154576, 54.25556802749634, 41.6035133089338, 28.986578260149273, 29.115368332181657, 39.84231172289167, 18.057108776909963, 19.154017414365494, 15.16788625717163, 28.559217146464757, 24.297134808131627, 31.345745291028702, 42.22631161553519, 28.534934929439, 23.573691844940186, 23.726270811898367, 21.555017811911448, 26.30424009050642, 31.447411332811626, 29.70575155530657, 24.967500482286724, 22.66996223585946, 24.420802320752824, 20.466735363006592, 19.843733821596416, 17.39874611582075, 21.324794462748937, 21.359813383647374, 26.737564495631627, 21.723511627742223, 25.106867449624197, 28.65434319632394, 24.73411222866603, 23.17172118595668, 24.885247707366943, 36.41970900126866, 43.5366723878043, 45.15944153921944, 43.44396604810442, 60.623852593558176, 40.74001203264509, 65.03680637904576, 50.985339300973074, 25.504429476601736, 33.09628486633301, 16.89484190940857, 25.47698061806815, 29.497989995138987, 31.665164402553014, 43.820249216897146, 42.829873834337505, 34.895305497305735, 43.558816296713694, 49.694850376674104, 58.31789139338902, 63.63402761731829, 61.33000496455601, 62.103276933942524, 67.36618995666504, 59.72720840999058, 59.21693270547049, 42.48862000874111, 32.013425486428396, 12.954476799283709, 5.0969843949590405, 1.3596904852560587, 0.04033252862947328, 0.023561395704746246, 0.04566282492929271, 0.07046105765870639, 0.03447082745177405, 0.040782624656068425, 0.01635208326791014, 0.11918846225099904, 0.037967355722295384, 0.09040641811277185, 0.01116920803074858, 0.012465228576080074, 0.06304789973156792, 0.08120361728859798, 0.03024617682344147, 0.05976725076990468, 0.028156173615051166, 0.04781365540942975, 0.006420934048946947, 0.06147275532462767, 0.051810111318315775, 0.034892353761409006, 0.04737953548984868, 0.04252223238082869, 0.01049067301210016, 0.020513636924858605, 0.054394322114863565, 0.0363990034508918, 0.017792718285428624, 0.04806877100574119, 0.020947573639984642, 0.05457549435751779, 0.016626530326902866, 0.06841443997940846, 0.061813692030097754, 0.057963677548936436, 0.031686883087136915, 0.06094877701252699, 0.062547235882708, 0.031118861066975763, 0.08386110647448472, 0.021968197177297304, 0.006807043375114777, 0.016094185678022246, 0.005125149718618819, 0.10429190445159163, 0.026001943674470698, 0.02155255206993648, 0.05370710524065154, 0.08064677752554417, 0.07816470999802862, 0.13292918992894037, 0.16953684629074164, 0.1578132946576391, 0.1555435135960579, 0.13847389311662742, 0.09117026533931494, 0.12318990539227213, 0.20617150834628514, 0.16582519188523293, 0.09158733367387738, 0.12345613539218903, 0.14535817370883056, 0.09711778084082262, 0.12766565808228084, 0.1200502152953829, 0.1237320141600711, 0.10666126052715949, 0.25469485031706945, 0.11335424852690526, 0.17660745259906563, 0.09473883706544127, 0.09966196146394525, 0.13330387696623802, 0.12102176887648446, 0.19488958801542008, 0.22331100436193602, 0.14085213121558937, 0.17706735006400517, 0.1176301794392722, 0.19225942343473434, 0.12215832860342093, 0.10110556507217032, 0.11382927053741046, 0.10419310296752624, 0.18077015637287072, 0.1233492661267519, 0.2168998255261353, 0.17899246247751371, 0.19937200391931192, 0.15766793888594421, 0.12192422045128685, 0.10887242294847965, 0.09955737207617078, 0.20941582854304994, 0.07371598335781268, 0.11578292213380337, 1.5725511546645845, 7.196175456047058, 24.296952417918614, 45.158628599984304, 57.115099157605854, 67.92949431283134, 73.26328590938023, 79.23699964795793, 72.75959014892578, 74.48463330950055, 78.33095455169678, 66.28359113420758, 46.80390991483416, 52.853633471897666, 60.04090567997524, 45.69781575884138, 34.02472400665283, 33.80803401129586, 41.133040360042024, 23.778443098068237, 27.924426249095372, 32.879740783146445, 30.513767991747173, 30.817091601235525, 38.35288545063564, 44.51824787684849, 38.246796880449565, 38.58997883115496, 36.40828268868582, 28.269602332796367, 45.47455276761736, 52.065891878945486, 44.3350864137922, 42.901982239314485, 37.03670556204659, 42.76235818862915, 40.396107469286235, 40.018361704690115, 37.35955013547625, 41.01656423296247, 37.025466850825715, 50.04559544154576, 36.932013579777305, 47.08066708700997, 48.743982451302664, 43.44254861559187, 44.35799809864589, 45.53872632980347, 44.623436655317036, 64.34439754486084, 53.91720117841448, 42.48558017185756, 70.36289242335728, 66.41033322470528, 84.09861946105957, 47.29235437938145, 28.96137366976057, 34.53580570220947, 20.578563145228795, 26.33720408167158, 27.838044507162913, 37.308901241847444, 50.53580127443586, 46.46525124141148, 41.00397409711565, 50.55433212007795, 57.747277532305034, 66.74821717398507, 73.00595937456403, 69.63358865465436, 71.52204649788993, 76.8144337790353, 70.23339884621757, 68.56050191606793, 50.86660153525216, 38.86375175203596, 17.048730611801147, 6.216616681643894, 2.173244744539261, 0.2421362799193178, 0.14601381495594978, 0.14036027475127152, 0.17102093808352947, 0.13454833733183996, 0.11348724139056035, 0.19986523102436746, 0.2291672501180853, 0.1481754511062588, 0.2602672784456185, 0.18577389073159012, 0.20264464616775513, 0.23797808161803655, 0.11037387845239469, 0.1366302999002593, 0.12403997406363487, 0.09222479018249682, 0.10949573878731046, 0.09979757347277232, 0.14029694029263087, 0.1420012302696705, 0.07411193568259478, 0.2618828974664211, 0.23261325806379318, 0.1600147065307413, 0.15105549299291202, 0.15411711085055554, 0.16901764486517223, 0.2395634108356067, 0.13526443604912075, 0.15466504144881452, 0.17395913042128086, 0.09929163062146731, 0.10521874936031443, 0.16846678299563272, 0.0973556005795087, 0.12170905699687344, 0.13923827638583525, 0.12033076238419328, 0.08590929156967572, 0.1291811524757317, 0.17417600378394127, 0.07540810720196792, 0.10853728771741901, 0.14285043041620935, 0.24780812699879917, 0.15029926571462834, 0.0996540090335267, 0.15638454418097222], [0.049006516579538584, 0.011072550717342113, 0.0298805821553937, 0.05244114549298372, 0.03693016405616488, 0.02813054365105927, 0.06859571739499058, 0.022831105427550416, 0.036335685955626626, 0.06277548149228096, 0.011220252523863954, 0.020721738526065434, 0.015114566011886512, 0.019714190358562127, 0.012224448728375137, 0.035928347813231606, 0.04223530027749283, 0.017208609896312867, 0.025070886759619628, 0.0758912241352456, 0.08316067513078451, 0.0356242691299745, 0.06700943144304411, 0.0414319148154131, 0.07093743673924889, 0.005255854222923517, 0.03848311697532024, 0.023302127474120686, 0.048741246706673076, 0.028671921297375644, 0.013502722190293883, 0.032481885249061246, 0.037672186203833134, 0.02597682091540524, 0.045484458428940604, 0.020094712797020162, 0.014995847828686237, 0.02450990114760186, 0.045724944810249975, 0.06015622775469508, 0.05604040396532842, 0.030617196378963332, 0.0268685482442379, 0.046929117159119675, 0.03049026961837496, 0.11188879609107971, 0.5268061203616006, 1.792281638298716, 7.697751147406442, 21.78279365812029, 44.23763792855399, 50.31858321598598, 55.55484989711216, 62.81671101706368, 63.43858173915318, 60.64582974570138, 61.14767033713204, 48.84939009802682, 48.18152577536446, 48.52084800175258, 22.033137253352574, 35.85400056838989, 27.34820692879813, 16.864693675722393, 20.464034250804357, 15.546545709882464, 13.058306336402893, 18.513053042548044, 25.741679191589355, 36.09636415754046, 25.45037422861372, 42.78670467649187, 20.1713969707489, 23.45434090069362, 27.40227086203439, 30.371767657143728, 25.543704169137136, 18.748631715774536, 26.213444505419048, 15.233600582395281, 17.75899284226554, 18.552874905722483, 13.364206859043666, 15.264494010380336, 20.948233366012573, 15.935954025813512, 15.540375709533691, 14.910844598497663, 15.3332724911826, 17.967252935682023, 16.186886480876378, 21.06394692829677, 29.22068738937378, 22.585185527801514, 32.21128586360386, 30.995608193533762, 23.29278486115592, 25.437909160341533, 17.967030593327113, 29.707314899989537, 28.63851519993373, 65.86971473693848, 70.4692554473877, 32.186557224818635, 37.678434235709055, 24.758377075195312, 24.35213327407837, 23.15534601892744, 11.147992065974645, 26.662275552749634, 20.419034242630005, 15.090419054031372, 17.972886187689646, 17.602571521486553, 24.519128016063146, 25.074005944388254, 40.91136850629534, 43.65889467511858, 53.07897744859968, 52.04071855545044, 51.64217683247158, 53.589996610369, 48.81100477491106, 47.44399881362915, 39.49301535742623, 23.35202693939209, 11.623621446745735, 0.9874910116195679, 0.2578037620655128, 0.03258409297892025, 0.06420177567218031, 0.006805639231710562, 0.01683731553410845, 0.08533405672226634, 0.06229703287993159, 0.04581461660563946, 0.07945467970733132, 0.08817965617137295, 0.031891244264053445, 0.04208872653543949, 0.0568562134035996, 0.08791016920336656, 0.0506435298094792, 0.01821276538872293, 0.023960135112117444, 0.024731122223394256, 0.02489349395701928, 0.02684108623569565, 0.02660147686089788, 0.04591824925903763, 0.01608994822683079, 0.060435390632067404, 0.08185674117079803, 0.10046092966305357, 0.032113976776599884, 0.04093106776209814, 0.012709400250709482, 0.03883993818557688, 0.030890384755496467, 0.02578109409660101, 0.030861272210521356, 0.050236150954983065, 0.028341367874028425, 0.08552927124713149, 0.030554954361702715, 0.022121279766517024, 0.03551607672125101, 0.016586001430238997, 0.0440740521465029, 0.03257841703348926, 0.03794296578105007, 0.027679060020350983, 0.026667406715984856, 0.015852023315216814, 0.007666851144417056, 0.028932604273515086, 0.04297843861526676, 0.0419183328215565, 0.016325825659025992, 0.03129136502476675, 0.04017910507640668, 0.0658522035394396, 0.05943249551845448, 0.032894366686897616, 0.016515650919505527, 0.03585834335535765, 0.021619981487414668, 0.014586462206872446, 0.035466845612972975, 0.03831107781401702, 0.008699646751795496, 0.020565722969227603, 0.08454175173704113, 0.05703386744218213, 0.0705365107527801, 0.00391764915548265, 0.07787398488393851, 0.01775531404252563, 0.009320370586855071, 0.03555474643196378, 0.03296972139339362, 0.011699153210169502, 0.04452723211475781, 0.03682052297517657, 0.02532957653914179, 0.019808233615809252, 0.04668946876855833, 0.018989752445902144, 0.012706977880692907, 0.016462367260828614, 0.012475860371653522, 0.025007540426616157, 0.00903447749026652, 0.0059672981899763855, 0.05343431041442922, 0.06424151746822254, 0.0505866482188659, 0.02010633610188961, 0.019906639853226285, 0.07623106161398546, 0.02380220269385193, 0.0639320919290185, 0.41824450716376305, 2.8662044405937195, 11.090035404477801, 25.97863187108721, 48.99006332669939, 57.43873235157558, 66.25615964617047, 73.64622892652238, 74.92549651009696, 70.15406431470598, 69.4556244441441, 57.9585131917681, 59.02592672620501, 55.57894277572632, 24.94398604120527, 40.82031236376081, 39.10533366884504, 28.442468302590505, 27.310235023498535, 23.73692066328866, 15.766291175569807, 23.831661088126047, 24.43866092818124, 36.66382353646414, 32.037230014801025, 33.57153122765677, 21.504546097346715, 21.629943711417063, 25.02372704233442, 25.531690733773367, 22.92753890582493, 16.67127319744655, 18.495904888425553, 13.53546953201294, 14.90787250655038, 14.164183361189705, 12.244999715260096, 11.539779271398272, 13.84550770691463, 11.668373925345284, 10.82807355267661, 9.745069129126412, 9.758275049073355, 14.537536127226693, 15.359693016324725, 19.359974179949077, 23.711243595395768, 21.543567180633545, 28.792268412453787, 27.730561086109706, 25.828083515167236, 33.890248571123394, 23.499076877321514, 28.322036913463048, 37.56528282165527, 63.019911084856304, 72.03350339617047, 35.53552293777466, 38.53581067493984, 33.64732565198626, 26.114107847213745, 28.238634211676462, 13.820678319249835, 34.53556598935808, 28.358799832207815, 24.28012388093131, 28.049142939703806, 25.791013138634817, 34.83304616383144, 37.84165089470999, 50.433311871119905, 52.01107406616211, 60.23910999298096, 59.57881573268345, 59.107130323137554, 60.98079545157296, 56.44646011080061, 55.40508147648403, 47.791210719517295, 29.80054930278233, 15.424097606113978, 2.0719343636717116, 0.28231654529060635, 0.020068672319341983, 0.044295105284878185, 0.03760696881051574, 0.07545487862080336, 0.04411857422175152, 0.05956815502473286, 0.0524203687507127, 0.03576623901192631, 0.06977111646639449, 0.12757406942546368, 0.05812026307518993, 0.103157631387668, 0.01931530167348683, 0.08840249385684729, 0.009019693060378944, 0.043049294634589126, 0.036179697540189536, 0.020540937781333923, 0.03035331071753587, 0.01633337096843336, 0.06693944734122072, 0.002495425125484222, 0.01990694349764713, 0.06667055069868054, 0.021849346679768393, 0.016201504472909228, 0.054791689185159545, 0.039139779417642524, 0.018215452387396778, 0.029793529505176202, 0.03530457057058811, 0.007125320827721485, 0.06177267458822046, 0.09806696990770952, 0.028176972409710288, 0.07132598624697753, 0.015910847212320993, 0.03333609298403774, 0.020475186041689346, 0.02017335670201906, 0.03666240395978093, 0.026628506303365742, 0.06814758572727442, 0.10778845647083861, 0.020780187532571808, 0.006889907343845282, 0.03917900552707059, 0.09510411960738045, 0.099588489692126, 0.10603379883936473, 0.16396053694188595, 0.18201081694236823, 0.12427389222596373, 0.11829971708357334, 0.10227077254759413, 0.11429313064685889, 0.1367363684943744, 0.1232305360691888, 0.11695286578365735, 0.21001217940023967, 0.0996942190187318, 0.18090643334601605, 0.12485128481473241, 0.11057631258985826, 0.1628380093191351, 0.15829521736928395, 0.1376937542642866, 0.2106731810740062, 0.12195224394755703, 0.1980645212211779, 0.1513142455369234, 0.16733582796795027, 0.1365839016756841, 0.12606978443052086, 0.13553720712661743, 0.1286321362214429, 0.11193055992147752, 0.14090668543108872, 0.12944328412413597, 0.1273091829248837, 0.14259239711931773, 0.10254210513085127, 0.07006876263767481, 0.14652852447969572, 0.06686417745160204, 0.15624339532639298, 0.19094932159142836, 0.18214741961232253, 0.11935534115348544, 0.08592087416244404, 0.13907990631248268, 0.11856088521225111, 0.25445592456630295, 0.7670891040137836, 4.371833477701459, 16.366056203842163, 33.69430242265974, 61.43433911459786, 66.75966780526298, 76.70156029292515, 82.30995164598737, 82.50144399915422, 74.41830580575126, 78.02881908416748, 62.33281762259347, 62.53294658660889, 60.39544446127755, 32.868095602308, 46.8536034311567, 39.1302672794887, 28.695867368153163, 32.35655532564436, 24.60913498061044, 23.009571075439453, 30.11204399381365, 38.801937103271484, 49.52962916237967, 36.44365249361311, 55.97133534295218, 32.64658008302961, 33.71918739591326, 38.43396050589425, 40.75476653235299, 34.157021181924, 25.532816341945104, 31.892290592193604, 19.30149814060756, 23.188230105808803, 23.770798342568533, 17.78626799583435, 20.270817007337296, 25.743160894938878, 20.381639037813457, 19.76043881688799, 18.48756010191781, 20.130659682410105, 23.554676362446376, 22.564710923603602, 29.069769041878835, 37.24047538212368, 31.99237244469779, 42.28465563910348, 39.47009325027466, 32.352574007851736, 34.562740394047324, 27.098674535751343, 40.155908243996755, 43.30572121483939, 76.65579945700509, 79.42836693355015, 42.427138873508994, 49.92106635229928, 36.21739482879639, 37.86497252328055, 35.18520518711635, 18.095514944621495, 39.574708802359446, 31.867725236075266, 26.435272693634033, 30.84157705307007, 30.09768554142543, 36.7833742414202, 38.2795089994158, 54.30041517530169, 57.74611370904105, 67.94675363813127, 67.08096640450614, 66.60427134377616, 70.55162634168352, 65.81847872052873, 66.49849196842739, 57.72506414140974, 38.28616884776524, 21.113555329186575, 4.512561423437936, 0.6272423852767263, 0.16286003456584044, 0.11031555158219167, 0.0699590706665601, 0.1317487968397992, 0.10205880499311856, 0.15638503272618565, 0.1719727191541876, 0.20273789045001778, 0.26059682933347567, 0.17405435602579797, 0.14689941172088894, 0.31972925631063326, 0.16715353274984018, 0.1958273776939937, 0.1465708107820579, 0.07045903562435082, 0.11449532051171575, 0.12138984698270049, 0.09097194312406437, 0.09200492448040418, 0.1370005357478346, 0.1412008846444743, 0.16708190659327166, 0.1816169409347432, 0.1532488302992923, 0.09618397416280848, 0.13402416902993405, 0.10338561236858368, 0.11448537318834237, 0.1408403789890664, 0.13351948825376375, 0.16210021105195793, 0.1096189675320472, 0.15469416417181492, 0.17443470204515116, 0.16653671727648803, 0.09391344671270677, 0.24614188926560537, 0.2016966784639018, 0.0798477753996849, 0.09864227260862078, 0.11547619716397353, 0.13773298715906485, 0.18588639183768205, 0.13391022942960262, 0.0679444255573409, 0.1216784550675324], [0.0060246912263599885, 0.02503697357938758, 0.0032135530865551637, 0.04421308057914887, 0.07693515704678637, 0.06136578427893775, 0.06108789026205029, 0.016894047847017646, 0.0920191126476441, 0.07745596660034997, 0.019428676393415247, 0.02475754776969552, 0.015492498142910855, 0.03396020610151546, 0.003186594254137682, 0.061749848670193126, 0.10790954783026661, 0.022360987528892498, 0.026473625596346598, 0.029616316514355794, 0.04371957866741078, 0.025511797118399824, 0.030082347935863903, 0.0403538007023079, 0.09388049026685101, 0.05313765490427613, 0.021914469078183174, 0.02577463274688593, 0.005818771963406886, 0.050673551591379304, 0.04021781210654548, 0.01831721398048103, 0.037115414294281175, 0.04241139029285737, 0.01354000938590616, 0.012107066410992826, 0.02161815283553941, 0.02927168857838426, 0.04210571365963135, 0.005453133190582905, 0.045848227837788205, 0.019666701388944472, 0.020302140952220986, 0.06601547263562679, 0.03173576135720525, 0.2073041054287127, 2.8030266421181813, 14.521206992013113, 28.543717452457972, 39.86110312598092, 63.592519078935894, 67.75161348070417, 67.8895491191319, 62.120237486703054, 54.52810764312744, 53.64329971585955, 46.489479609898154, 43.08149242401123, 40.465697152274, 28.99847878728594, 39.21038695744106, 24.88141577584403, 20.171588046210154, 17.27222810472761, 22.44867253303528, 19.440576757703507, 26.482883487428936, 24.205105917794363, 27.246978623526438, 21.4693534714835, 30.763653005872452, 30.416017259870255, 24.320065600531443, 20.86435992377145, 13.762398566518511, 6.745480988706861, 3.7132753985268727, 4.047832897731236, 3.692419946193695, 2.7488891014031003, 2.9827487468719482, 3.2635339200496674, 3.080674920763288, 3.167598622185843, 3.022241004875728, 3.097422033548355, 4.007326636995588, 4.224420062133244, 4.907801015036447, 6.988421712602888, 6.705159289496286, 7.01843489067895, 10.112872890063695, 8.59119655404772, 6.273644890104022, 9.76111512524741, 17.209161043167114, 15.302672624588013, 24.42869894845145, 30.48010049547468, 17.59555036681039, 25.217540093830653, 30.437779017857142, 42.820997510637554, 33.57610314232962, 30.00569486618042, 27.40100281579154, 38.96613693237305, 49.5133912222726, 21.615835394178117, 23.21502583367484, 16.05880686214992, 12.099303807531085, 19.3940064566476, 18.132521050316946, 27.078149557113647, 26.17868266786848, 27.585281201771327, 33.33330181666783, 39.13726758956909, 45.896419593266074, 44.29694775172642, 51.45755277361189, 48.602673462459016, 54.100935867854524, 40.104644434792654, 25.929461206708634, 17.428263800484793, 5.0422199964523315, 1.3538429247481483, 0.07873576506972313, 0.06105256572897945, 0.044946190169347186, 0.05412383770037975, 0.02354677327509437, 0.048897007812878916, 0.06798108680439846, 0.034008195490709374, 0.00823319039773196, 0.08862815424799919, 0.06465663162193128, 0.04785842175728508, 0.045388954625065835, 0.01544034933405263, 0.04553615940468652, 0.039480895934892554, 0.037343327421694994, 0.029137789870479276, 0.032936157658696175, 0.02672848674202604, 0.053371277903871875, 0.010925541016539293, 0.04331012010308249, 0.09191402114395585, 0.03883727154295359, 0.04475090100562998, 0.016479617317340205, 0.029028287889169793, 0.018406867116157497, 0.019667927840990678, 0.07695874970938478, 0.03056503739207983, 0.021565980277955532, 0.021564667312694446, 0.013422037591226399, 0.031662452433790476, 0.022104570841682807, 0.0505496002068477, 0.02397001118931387, 0.04150639081905995, 0.09760327264666557, 0.03648574736767581, 0.03301144111901522, 0.015098628920636006, 0.04522224535633411, 0.07545457328004496, 0.010471098124980927, 0.03168720199859568, 0.02358693067383553, 0.027820848394185305, 0.027407701992030655, 0.049719222621726136, 0.04370608939124005, 0.05583600886166096, 0.010448528353923132, 0.04011139067422066, 0.031246391723730733, 0.035324835018920045, 0.023310410690360835, 0.02100086917302438, 0.03301766328513622, 0.053195350736911805, 0.02818925558988537, 0.03245547327346035, 0.036923999565520456, 0.074530015034335, 0.061226481039609225, 0.011930084122078759, 0.016462053438382487, 0.05662155903077551, 0.05461661357964788, 0.06259072319205318, 0.04149969707110098, 0.07215177015002285, 0.02357989765836724, 0.029617575196815387, 0.01603250514848956, 0.06315737457147666, 0.006250321931604828, 0.022057400783523917, 0.05377075521807585, 0.015322360575997403, 0.029593056333916526, 0.048787190312785764, 0.09143887699714728, 0.044797536717461686, 0.046802241288657696, 0.04556902764098985, 0.041153315122106245, 0.04217231187171169, 0.1091071010700294, 0.3153801182551043, 4.091304736477988, 18.206336975097656, 35.285877636500764, 47.77919033595494, 76.21563107626778, 78.46915422167096, 76.88791792733329, 69.8884972163609, 63.37189987727574, 61.294138363429475, 54.93548400061471, 52.52259349822998, 48.713344369615825, 39.02084009987967, 40.417528765542166, 34.7700503213065, 27.932164805276052, 15.902983086449758, 22.523240600313457, 16.072769267218455, 28.037254571914673, 26.654132264001028, 31.000829764774867, 29.714343002864293, 26.85371232032776, 27.56125954219273, 24.638168028422765, 15.945037058421544, 13.49376036439623, 6.8674362046378, 4.06626603433064, 3.537201532295772, 3.523634740284511, 2.501128064734595, 2.6320310405322482, 3.4423438566071645, 3.4022735953330994, 3.3505108186176846, 2.67067996093205, 2.0944662860461642, 2.915738365479878, 2.9098167632307326, 3.8300342304365973, 5.377588697842189, 5.669247150421143, 6.332205176353455, 8.69393174988883, 7.907601509775434, 7.5378652811050415, 10.301081350871495, 12.300767694200788, 10.023699709347316, 17.82258449281965, 22.578569105693273, 18.39097319330488, 26.902544260025024, 36.63666650227138, 36.80184950147356, 33.33780424935477, 27.077161175864084, 30.192121982574463, 33.15361097880772, 37.600749901362825, 30.769440855298722, 33.207949365888325, 24.077257326671056, 20.14883269582476, 31.380138874053955, 25.67435983249119, 36.88584280014038, 36.691456522260395, 40.897652762276785, 45.781968866075786, 51.36917168753487, 54.42600039073399, 54.020079680851524, 59.873530524117605, 59.127558026994976, 62.29329626900809, 47.298215184892925, 32.54633147375924, 21.03093777384077, 6.561797542231424, 2.020624739783151, 0.06374465341546706, 0.05529582713331495, 0.057926222415907044, 0.0261743899567851, 0.07980329064386231, 0.028068740985223224, 0.06638006307184696, 0.027098020305857062, 0.04452948824369481, 0.005135728503643934, 0.02172608400828072, 0.021264196739399006, 0.01936602725514344, 0.08740269964826958, 0.033061048814228604, 0.07708030247262546, 0.03655585360580257, 0.044643268388296874, 0.02268817711488477, 0.02279557563763644, 0.021270788707105175, 0.047511442697473934, 0.032953626542751274, 0.021012014110705683, 0.0037700737261080314, 0.0462868023397667, 0.023171930174742426, 0.04074334765651396, 0.02448045103145497, 0.042271432267235856, 0.07586944994649716, 0.02988906384312681, 0.051475376422916136, 0.04790197692013212, 0.03607964415901473, 0.0744943240923541, 0.056416366648461135, 0.04080012068152428, 0.016975008949105228, 0.01566460176504084, 0.01792016751798136, 0.03052771118070398, 0.02888664709670203, 0.04008121282926627, 0.014644885768315621, 0.05592842872387596, 0.08064218384346791, 0.10739133706582443, 0.06736123827951294, 0.1975074711122683, 0.08334746225071804, 0.14215493202209473, 0.26606845429965426, 0.1780760195106268, 0.1794394813477993, 0.16404430887528829, 0.15967481476919992, 0.09168677976621048, 0.045754522151712856, 0.09681254186268363, 0.16773796853210243, 0.15234679941620144, 0.19190433248877525, 0.09451091715267726, 0.12521730017449173, 0.13293130695819855, 0.24045801854559354, 0.20002126693725586, 0.08141665692840304, 0.1027011808806232, 0.19229877846581594, 0.14622876127915724, 0.14130893456084387, 0.214350270905665, 0.12295730358787946, 0.1379027430500303, 0.1352743019482919, 0.12057024453367506, 0.08718203327485494, 0.13213469327560493, 0.16640844701656274, 0.10975252357976777, 0.15160992395664963, 0.16426039513732704, 0.13836820450212273, 0.15308303705283574, 0.13570029980369977, 0.16286646707781724, 0.12570972660822527, 0.143629361476217, 0.16795546614698, 0.6813459449580738, 6.46527316740581, 24.244139160428727, 44.04423482077462, 60.35606207166399, 85.20638465881348, 86.62674931117466, 83.04930250985282, 78.4660483769008, 70.03727204459054, 69.31673690250942, 61.133113861083984, 54.03435475485665, 53.74283960887364, 39.228063174656455, 52.005352224622456, 36.56225824356079, 29.047095332826885, 27.38393109185355, 34.27809354237148, 30.726730278560094, 39.60320683888027, 33.60774523871285, 36.45937974112374, 30.53324726649693, 40.68452024459839, 39.7522109576634, 31.947157042367117, 28.095334563936504, 18.731408868517192, 10.30927848815918, 5.8456675580569675, 6.364854761532374, 4.818095428603036, 3.7920436518532887, 4.283832371234894, 4.332652585847037, 4.850062353270395, 4.970089878354754, 4.534545958042145, 4.480562797614506, 5.3043568560055325, 5.769809297152928, 6.767227981771741, 8.755435466766357, 8.73137732914516, 10.346888218607221, 12.68997711794717, 12.403808610779897, 9.060189536639623, 13.860380325998578, 22.042979376656668, 19.549920558929443, 31.889247281210764, 36.175306115831646, 26.250231742858887, 33.28157942635672, 41.57850326810564, 54.65547854559762, 46.31134516852242, 41.726923738207134, 39.87927613939558, 50.97012274605887, 64.59640870775495, 33.2823680468968, 32.82547187805176, 26.30979691232954, 22.69098401069641, 31.367677279881068, 28.39398898397173, 39.51078884942191, 37.68642118998936, 39.54356002807617, 47.53579146521432, 55.4207045010158, 61.738614627293174, 61.32714925493513, 67.40414101736886, 66.30324063982282, 72.81317465645927, 56.973428862435476, 41.05057566506522, 28.445369175502233, 10.982952373368398, 3.5169327684811185, 0.2126278504729271, 0.09866793480302606, 0.15773238614201546, 0.13742326306445257, 0.24625303330165998, 0.12923387464668068, 0.12653095754129545, 0.25366448132055147, 0.17328280742679322, 0.17147810783769402, 0.21049146939601215, 0.1284593947763954, 0.08240830871675696, 0.1314717238502843, 0.10905623129968132, 0.1293970351772649, 0.10712048624243055, 0.20008122229150363, 0.15565510546522482, 0.1088301773582186, 0.1063600384763309, 0.10525953610028539, 0.1918664566640343, 0.1299414373934269, 0.10743595074330058, 0.12735338269599847, 0.15426698566547462, 0.07675380499235221, 0.07014608848839998, 0.09740318624036652, 0.1677968789424215, 0.1862592196890286, 0.1732743393097605, 0.1991292240896395, 0.12792778973068508, 0.12092519977263042, 0.09002071845212153, 0.09079500154725142, 0.1222183925232717, 0.10350168256887368, 0.2439491083579404, 0.12973357497581414, 0.15783020375030382, 0.16828845042203153, 0.06494749244302511, 0.2045920416712761], [0.049365010378616195, 0.08837364254785435, 0.033189118906323395, 0.01007588964421302, 0.03590242438284414, 0.05442914113934551, 0.037292522112173696, 0.04411176173016429, 0.05774750307734523, 0.025810915710670606, 0.05817825746323381, 0.03242845740169287, 0.01302163492489074, 0.034248926144625456, 0.03641469796587314, 0.034822423942387104, 0.023103759457756366, 0.019209406105801463, 0.04445376034293856, 0.009031809999474456, 0.027421418577432632, 0.09709183366170951, 0.11024382364537035, 0.0513943186295884, 0.012643600165444826, 0.0336340173546757, 0.03554456162133387, 0.06401983329227992, 0.08113978749939374, 0.03159221048866, 0.027432877337560058, 0.0482917647542698, 0.033030949000801356, 0.022248164118666734, 0.09143448687557663, 0.029815897412065948, 0.021411971488435353, 0.03867484722286463, 0.049982358501957994, 0.04885617018278156, 0.03117225498759321, 0.0897489312504019, 0.039840678950505595, 0.14152697500373634, 0.3339335726840155, 5.693312670503344, 15.75419088772365, 44.43877438136509, 58.44343144553048, 65.17711135319301, 68.75955390930176, 71.15795394352504, 57.90753773280552, 61.224767548697336, 52.68711641856602, 44.28009489604405, 38.92484378814697, 18.002330916268484, 20.12133172580174, 24.404812778745377, 26.92993232182094, 21.364640644618444, 26.322303669793264, 31.45053107397897, 28.563881124768937, 38.287332671029226, 23.823788779122488, 35.407672609601704, 28.374440227236065, 25.775834798812866, 21.457263605935232, 14.077020815440587, 6.79513281583786, 7.316321100507464, 4.12075901882989, 4.491332505430494, 2.3159555324486325, 1.3167970840420042, 0.24772298442465918, 0.20687023656708853, 0.26461831639919964, 0.3743885633136545, 0.38497927359172274, 0.26074401714972084, 0.16315365023911, 0.28004033171704834, 0.2605182278369154, 0.40431421037231174, 0.2610331273504666, 0.7087490430900029, 1.7424109429121017, 1.2382353224924632, 2.0985602949346815, 3.0675211123057773, 2.906010453190122, 2.7862467425210133, 4.406345180102757, 8.3619989327022, 6.752070486545563, 8.999570846557617, 11.634030716759817, 12.015501584325518, 15.49081768308367, 23.15308438028608, 23.045746871403285, 38.520010471343994, 27.500631298337662, 29.333362851824077, 40.796490464891704, 29.581152984074183, 22.661028589521134, 26.62968155315944, 21.39265751838684, 11.33129596710205, 15.548135110310145, 18.153449024472916, 15.027918270656041, 21.335409573146276, 33.16163614818028, 26.708797216415405, 35.708765847342356, 35.61113323484148, 35.71830224990845, 40.61262723377773, 44.38783713749477, 44.3207939692906, 50.054888657161165, 37.5144567489624, 17.895260913031443, 6.10853875534875, 1.610115287559373, 0.3432752356997558, 0.019802028413063714, 0.08297848169292722, 0.06330858610038247, 0.057005972867565494, 0.022129422186740806, 0.06606427287416798, 0.053375712130218744, 0.038989687471517494, 0.0558115408888885, 0.029516317415982485, 0.010003461968153715, 0.04204227742073791, 0.010647788643836975, 0.013780355819367936, 0.06028255061911685, 0.06979567264871937, 0.028832968191376755, 0.04238064247848732, 0.012960294511036148, 0.009404520803530301, 0.023331796417811086, 0.019171050217534815, 0.048289997170546224, 0.07064616879714386, 0.045649121914591105, 0.052956496232322285, 0.11249915869640452, 0.04407501905890448, 0.06091708264180592, 0.03581726484532867, 0.06313596000628811, 0.013926921927902316, 0.056086045623357804, 0.01978000995170857, 0.12391246376293046, 0.023784783003585677, 0.08160832950047084, 0.04041080103654947, 0.01979850003096674, 0.06620260580841984, 0.024244297096239667, 0.04443772656044789, 0.00912454877314823, 0.023950089401166354, 0.014015297721406179, 0.02403221758348601, 0.017599427407341342, 0.03218174885426249, 0.04507462667035205, 0.05089963606691786, 0.019657809187525084, 0.005134521135395127, 0.03160401699798448, 0.01294733364401119, 0.029891747449125563, 0.02588851806441588, 0.032252211323274035, 0.03030184722904648, 0.03278667300141283, 0.04281083707298551, 0.007994123850949109, 0.051093557982572486, 0.040685122566563744, 0.05385882567082133, 0.05689207737201026, 0.05199356343863266, 0.01575601739542825, 0.02746888210198709, 0.03933961476598467, 0.03937567890222583, 0.07186525873839855, 0.04121668350749782, 0.06461800262331963, 0.010897348734683223, 0.0075079653844503415, 0.029128744998680692, 0.037633648807449, 0.023273919077057923, 0.06916984623031956, 0.05688268305467708, 0.028092091071552465, 0.036676106974482536, 0.061637428988303454, 0.0475862613613052, 0.007132548073838864, 0.01994492449531598, 0.0479936096817255, 0.08035265973636083, 0.5883846932223865, 7.955447673797607, 19.960407972335815, 50.29395185198103, 67.71152932303292, 77.45033291407994, 75.87300150735038, 77.66467094421387, 66.00403731209892, 71.96407004765102, 60.80895955221993, 53.3464275087629, 46.05172572817121, 28.238959039960587, 29.65522425515311, 27.44135969025748, 40.026807240077424, 31.281651633126394, 26.11810827255249, 26.68909386226109, 30.973116874694824, 36.71783535821097, 28.562545333589824, 32.05433300563267, 25.698746272495814, 19.39386054447719, 17.78378575188773, 13.078113913536072, 6.932010156767709, 5.477358315672193, 2.6533789464405606, 2.9997051741395677, 1.4405000976153781, 0.7683587787406785, 0.3137422704270908, 0.16887010421071733, 0.18895875769002096, 0.12284416465887002, 0.2455313163144248, 0.1171610810394798, 0.16055350404764923, 0.30472787842154503, 0.19642398639449052, 0.32131561690143173, 0.34218504705599373, 0.5936782977410725, 1.2849857338837214, 1.2822153568267822, 1.5590854372297014, 1.9616180317742484, 1.750624147909028, 1.623321641768728, 2.9209180303982327, 6.064660012722015, 6.366511906896319, 6.607742071151733, 9.334416696003505, 11.196877854210989, 15.962372813905988, 19.39472906930106, 20.296787636620657, 28.792294468198502, 24.994061708450317, 27.825567279543193, 42.65726668494088, 32.65057182312012, 28.574298211506434, 30.109045846121653, 26.021630798067363, 15.753579446247645, 18.18285206386021, 27.68252124105181, 24.590338366372244, 27.10503387451172, 40.74617508479527, 37.332750933510916, 43.677025999341694, 43.65041092463902, 44.074991021837505, 50.078839097704204, 54.64822115216936, 54.3905611038208, 56.332725048065186, 44.54443563733782, 20.720231703349523, 7.94978836604527, 2.3130018966538564, 0.26468049734830856, 0.07066060123699051, 0.059853546853576384, 0.05593001988849469, 0.03888216341978737, 0.06801911190684352, 0.045762430477355204, 0.0361821233028812, 0.043637832161039114, 0.039642251562327147, 0.034554816516382356, 0.0543164907555495, 0.02230246049085898, 0.04058256199849503, 0.012755282788670488, 0.08125429028379065, 0.03551581209259374, 0.022779523195432763, 0.07167676171021801, 0.04110281176066824, 0.02842323312402836, 0.019370870298839042, 0.02551919484644064, 0.022199686184259396, 0.02279174530745617, 0.03811498458630272, 0.038178434395896535, 0.10096900989966733, 0.05610641185194254, 0.030965871776321104, 0.02030371854613934, 0.024038811247529726, 0.02026463662540274, 0.04513162700459361, 0.030717059770332913, 0.0479083653273327, 0.04022984592510121, 0.007033862364811024, 0.03628010375957404, 0.09204284101724625, 0.0514353869615921, 0.08023525282208409, 0.015638406920645918, 0.03203985021848764, 0.04963779163413814, 0.11463562798287187, 0.12891694451017038, 0.10272657844637122, 0.17213311126189573, 0.11224356134022985, 0.1801129002124071, 0.15516873156385763, 0.10019647742488555, 0.2328962885907718, 0.12495271222931997, 0.14218091991330895, 0.10800919069775514, 0.1477625761181116, 0.1021246025338769, 0.1833230900977339, 0.0881072429141828, 0.04377692844718695, 0.14565754335905823, 0.0836277718522719, 0.14661431844745362, 0.15693019490156854, 0.21983986347913742, 0.15080816697861466, 0.14376668339329107, 0.11386634569082942, 0.14311235850410803, 0.22698897628911904, 0.13675000704824924, 0.22630898920553072, 0.22638784854539803, 0.10445003025233746, 0.11093804639364992, 0.20112208143940993, 0.1709209220217807, 0.13686993132744515, 0.18644615608666623, 0.08288136297570807, 0.13074744200067862, 0.24230710789561272, 0.09540631874863591, 0.13578694872558117, 0.20123041634048733, 0.11475281098059245, 0.24744956195354462, 1.4434645899704523, 11.871653028896876, 28.406287295477732, 62.517681394304546, 82.19866929735456, 93.09299305507115, 87.14912182944161, 85.85653454916817, 74.4088909966605, 77.23505687713623, 67.31466211591447, 55.742392199380056, 50.12235219138009, 27.412416969026836, 31.071558952331543, 35.768662793295725, 39.34630414417812, 30.708821296691895, 36.76317235401699, 44.3743611063276, 42.22974749973842, 51.94039004189627, 31.861478805541992, 46.58130700247628, 38.65550034386771, 34.68537957327706, 27.663342475891113, 16.93757506779262, 9.860792245183672, 8.896071348871503, 4.542026562350137, 5.8770482284682135, 3.1242980999605994, 1.627783145223345, 0.4241224931819098, 0.3949048024203096, 0.473248048552445, 0.6825434778417859, 0.6217229100210326, 0.4215770369129521, 0.3915336775992598, 0.3799818088965756, 0.3948918016893523, 0.6421381288341114, 0.5166321120091847, 1.0699739456176758, 2.4210192433425357, 1.5800853903804506, 2.7516603469848633, 3.8582708409854343, 4.18813396351678, 3.3821075345788683, 5.9435741901397705, 9.386232018470764, 8.726880976131984, 11.699648635728018, 14.568480798176356, 14.745223862784249, 19.456908498491558, 29.460400240761892, 30.667357921600342, 47.494307245527, 39.68513304846627, 44.77483095441546, 53.14925847734724, 40.590302671704976, 33.573706013815745, 37.67209053039551, 31.359756333487375, 20.05185842514038, 24.929394824164255, 26.513573680605205, 24.152532373155864, 30.26389687401908, 43.25349508013044, 38.41133369718279, 47.0968668120248, 49.551825182778494, 50.44926493508475, 57.10435724258423, 63.1206043788365, 64.12213856833321, 68.03054891313825, 54.80908932004656, 30.170916080474854, 12.75737030165536, 4.353337373052325, 0.7633816429546901, 0.13262421557945864, 0.1332192500787122, 0.16736584635717527, 0.19706324780625956, 0.15863357564168318, 0.27029646028365406, 0.17138445643442018, 0.2006494817989213, 0.1546706868601697, 0.11124813689717225, 0.11320064855473382, 0.09835555763649088, 0.13706762929047855, 0.10650941796068635, 0.1895999868533441, 0.1996170093438455, 0.12058723505054202, 0.1699037437460252, 0.10459649203611271, 0.17992410462881836, 0.12488873994776181, 0.09045654827994959, 0.07232379913330078, 0.13496703415044717, 0.11649936011859349, 0.19583496371550219, 0.15606590413621493, 0.09219165731753622, 0.1608219596424273, 0.06038211884775332, 0.0961620235549552, 0.11989545502832957, 0.1910996035273586, 0.09793094399252109, 0.24399033614567348, 0.176628460043243, 0.15459089114197663, 0.05991008239133017, 0.16124064289033413, 0.20533130557409354, 0.1781885748995202, 0.1014100101643375, 0.17260644372020448, 0.1019975875637361], [0.05780322437307664, 0.009412808260614318, 0.05785656401089259, 0.044766106975397894, 0.0404679133290691, 0.06220880297145673, 0.07092596271208354, 0.01576873823069036, 0.0571870535079922, 0.043655402825347016, 0.035621795869831524, 0.03188938168542726, 0.039362640851842504, 0.02048628348191934, 0.08148647818182196, 0.030612948749746596, 0.02631068050063082, 0.01868370092207832, 0.032195278842534335, 0.04664413584396243, 0.026518955128267407, 0.022392949920945933, 0.02575460578581052, 0.01587832672521472, 0.028948078264615366, 0.03580435910927398, 0.018069550395011902, 0.023894474974700382, 0.02246417404551591, 0.04317547839933208, 0.04382374397079859, 0.037650941272399256, 0.12390683192227568, 0.10293018644941704, 0.03224687125267727, 0.04840270183714373, 0.03192879439198545, 0.02037478151864239, 0.09219006276024239, 0.04969517534066524, 0.025513970126797045, 0.025598512197445546, 0.1749631179762738, 0.6195272792662893, 7.517370700836182, 27.289223670959473, 47.108042989458355, 64.43870544433594, 78.51699951716832, 69.70901135035923, 70.19564928327287, 56.41451924187796, 51.541681562151226, 35.56816904885428, 32.98129217965262, 31.27666630063738, 37.45679017475673, 33.769777229854036, 29.984680039542063, 37.73249469484602, 23.803718907492502, 24.198770897729055, 36.694027355739046, 33.94498995372227, 29.460636479513987, 22.685557467596873, 28.13153120449611, 19.93514779635838, 14.966572625296456, 11.935184751238141, 8.176467265401568, 3.317575705902917, 2.2710389026573727, 0.8611088703785623, 0.31091704059924397, 0.10025202908686229, 0.0334519324824214, 0.043911152851900885, 0.08479331180985485, 0.03674752278519528, 0.06250269005873374, 0.027813213178887963, 0.054806203049208434, 0.03959013668021985, 0.06408192603183643, 0.10075202797140394, 0.03502741276419588, 0.06751425471156836, 0.07207249690379415, 0.09346712673349039, 0.13701591135135718, 0.17545658935393604, 0.23501673766544887, 0.1319415143557957, 0.31680561176368166, 0.31006604912025587, 0.5232201984950474, 0.05275319017735975, 0.8591686944876398, 1.7149174639156886, 1.5134322983878, 2.9629845959799628, 4.199818227972303, 8.012142368725367, 10.471644861357552, 14.583900587899343, 19.058167014803203, 17.793740783418926, 25.475240094321116, 36.99139983313424, 40.846562658037456, 38.221679142543245, 39.1271927016122, 45.20178038733346, 42.3731062071664, 41.58834886550903, 39.348673479897634, 38.191093172345845, 34.01847757611956, 20.404304061617168, 28.15445852279663, 31.095346110207693, 27.284710815974645, 35.70214073998587, 40.33401836667742, 48.356547423771445, 50.18841913768223, 42.95202316556658, 35.99604606628418, 15.362208264214651, 7.310194526399885, 2.617532104253769, 0.1551818544311183, 0.049151611115251265, 0.02080353761890105, 0.03372903261333704, 0.07182511660669531, 0.013431618505689715, 0.015304968027131898, 0.023974401310884526, 0.042993203537272554, 0.0730333092755505, 0.018895583659676567, 0.0495201370545796, 0.06153522804379463, 0.05320173914411238, 0.03928200714290142, 0.022814338827239614, 0.008185950789733656, 0.023215264813708406, 0.04145729202511055, 0.034521585263844044, 0.07315910966800791, 0.02827593674218016, 0.011316782611954426, 0.023979436040722897, 0.0458756440452167, 0.017119942332750986, 0.014675938923444067, 0.0218647053199155, 0.010743166070564516, 0.06295277590730361, 0.01883876652989004, 0.043720911988722425, 0.011463309704725231, 0.028297743161341975, 0.018409976502880454, 0.017051032012594596, 0.009041697102864938, 0.01834743932288672, 0.027555207023397088, 0.06942395080945321, 0.0397461454517075, 0.02096187206916511, 0.07339196931570768, 0.017303815144779425, 0.05029867456427642, 0.027049834141507745, 0.021729363028758338, 0.06571156358612434, 0.02350905181707016, 0.05378311812611563, 0.03538231372034975, 0.02202716695943049, 0.03685643783371363, 0.052814295648464134, 0.038518967373030524, 0.04313176717343075, 0.09308692999184132, 0.03731549730790513, 0.015703809214755893, 0.06748332030006818, 0.04061795438506773, 0.015793762602178112, 0.008345311524213424, 0.0240731654755239, 0.037393915600010326, 0.040098057461104224, 0.032289140591663976, 0.024785418595586504, 0.02900317870080471, 0.025541929162240455, 0.024194809840992093, 0.01878165254103286, 0.022477459761181047, 0.06500690496925797, 0.02721645011167441, 0.024282583434666907, 0.07221642096659966, 0.07371146431458847, 0.018637933735070483, 0.0537513016190912, 0.03145014221913048, 0.0530634706706873, 0.0076684694504365325, 0.0381789534751858, 0.032672343243445666, 0.020616436676521386, 0.1935000025800296, 0.9791678296668189, 10.718847870826721, 35.053946767534526, 54.37076916013445, 73.58487633296421, 89.86565903254917, 79.9080844606672, 80.73860958644322, 68.92776979718889, 60.20511940547398, 47.37804651260376, 42.76691620690482, 39.324257510049, 42.58073227746146, 30.157071794782365, 31.18263632910592, 45.41323491505214, 26.442212206976755, 23.5180732522692, 27.867166144507273, 37.556667055402485, 34.897688729422434, 27.082401854651316, 24.249423265457153, 16.145862579345703, 13.451943499701363, 10.595986349242073, 6.195905838693891, 3.0084418824740817, 2.4470593546118056, 1.2045729288033076, 0.5217184647917747, 0.08277198991605214, 0.07004149910062551, 0.04621359519660473, 0.08509790617972612, 0.033421618930463276, 0.05659695535099932, 0.045421829646719356, 0.02505336020008794, 0.033334196478660615, 0.02351507211902312, 0.055536978478942595, 0.03746403540883746, 0.06060613039880991, 0.06857739694948707, 0.07269089336373977, 0.13525144888886384, 0.15802353194781713, 0.2000469427023615, 0.14734982326626778, 0.23670428139822824, 0.2445433150444712, 0.33385925952877316, 0.001628174357132853, 0.7077911687748772, 1.2926488369703293, 1.610114527600152, 2.417134766067777, 4.331586905888148, 6.63728494303567, 9.314978241920471, 11.928682105881826, 15.876376696995326, 16.68102499416896, 22.150367259979248, 28.06395649909973, 27.838103566850933, 31.57030064719064, 27.562338250023977, 31.508023943219865, 33.77412680217198, 27.510423047201975, 29.135851621627808, 34.9183109828404, 43.24377802440098, 25.472288846969604, 37.190333706992014, 40.060610226222444, 36.67573274884905, 45.93877928597586, 51.12247589656285, 57.70035287312099, 61.2005808694022, 51.56669160297939, 41.79358128138951, 18.588779721941265, 8.96483506475176, 2.569871804543904, 0.12622728597904953, 0.04025519260072282, 0.054032534028270414, 0.01573826013399022, 0.12398626123155866, 0.07078222863908325, 0.04430190420576504, 0.039479823849563084, 0.07888614878590618, 0.044741432049444745, 0.02391713804432324, 0.042155874360884936, 0.04470063513144851, 0.0101483054459095, 0.04114067740738392, 0.016707684811470763, 0.023762057169473598, 0.043481965881905386, 0.0168358363277678, 0.03627732176599758, 0.028362253181902424, 0.0761972095019051, 0.050906126254371235, 0.042451247439852784, 0.028065612938787256, 0.04665076173841953, 0.035896069902394495, 0.025725128528262888, 0.0311661854918514, 0.06478135992905923, 0.045146059444440265, 0.021049818689269677, 0.07481744246823446, 0.028943525294640234, 0.0205031976635967, 0.022357223355876546, 0.06753492967358657, 0.0396456883421966, 0.09290819029722895, 0.03575201013258525, 0.030964514706283808, 0.015401391245956932, 0.05722368761364903, 0.04757677883441959, 0.11971675604581833, 0.09740326087921858, 0.1291703637689352, 0.17899350742144243, 0.0625816783202546, 0.08258257008024625, 0.1813821813889912, 0.052347110717424324, 0.15677466110459395, 0.14642660851989472, 0.07210843890373196, 0.10194391544376101, 0.18563898439918244, 0.08934070422713246, 0.1592334277395691, 0.16600140742957592, 0.12980269055281365, 0.09813795145601034, 0.1045570895075798, 0.15145835280418396, 0.10708324145525694, 0.22385654651692935, 0.13729862975222723, 0.08173955138772726, 0.13823044832263673, 0.08082822457488094, 0.10735779029450246, 0.10846875568053552, 0.12192830523209912, 0.11640071469758238, 0.177900794627411, 0.12149811403027602, 0.19819508492946625, 0.26331240790230886, 0.113970975790705, 0.1620511801115104, 0.19485828040965966, 0.08538219199648925, 0.16821776064378874, 0.23402159820709909, 0.10337261842297656, 0.08949767651834659, 0.3904878651457173, 1.6819483701671873, 14.619094950812203, 45.29808241980416, 66.30535289219448, 82.51620892116001, 99.0984114238194, 87.35259287697929, 85.65992137363979, 71.80097498212541, 65.7021380833217, 49.65018735613142, 46.06025811604091, 43.33700895309448, 49.35138354982649, 44.99224008832659, 41.16562393733433, 49.72896603175572, 34.57275969641549, 34.61551891054426, 52.99457768031529, 46.47765030179705, 38.990754399980815, 32.07719605309622, 37.70538977214268, 27.163796527045115, 19.547108275549753, 15.362694638116018, 9.975704159055438, 4.760804057121277, 3.017626532486507, 1.4088356367179324, 0.5849618368915149, 0.2948417589068413, 0.07937379833310843, 0.13221637532114983, 0.23838756393109048, 0.14897521319133894, 0.15741792587297304, 0.14867445932967321, 0.16755432981465543, 0.2411503413958209, 0.22326555608638696, 0.22117178700864315, 0.16060239928109304, 0.1385762161974396, 0.16854447525526794, 0.2013069008077894, 0.2607862220278808, 0.3020458737654345, 0.29990249020712717, 0.21370140143803187, 0.3826450859861714, 0.46685049469981876, 0.8612253612705639, 0.19811539777687617, 1.3306091257504054, 1.906198114156723, 2.55486803821155, 3.964875314916883, 5.528430180890219, 10.13572551522936, 13.80839216709137, 18.28157901763916, 24.71566649845668, 24.7644202709198, 33.28818368911743, 45.61667816979544, 51.961324964250835, 50.57439851760864, 55.00705739430019, 60.61878735678536, 54.47728851863316, 52.64137642724173, 48.843661308288574, 49.3180183001927, 44.79140240805489, 30.5681654385158, 42.53116730281285, 42.17599276133946, 39.45432431357247, 50.203934465135845, 57.47850036621094, 65.13387271336147, 68.73718765803746, 61.17458765847342, 52.60487754004342, 26.42927118710109, 13.95809371130807, 4.374529378754752, 0.5990348160266876, 0.1396142526396683, 0.14536164780812605, 0.1591731874006135, 0.21265921236148902, 0.11906366609036922, 0.14384934252926282, 0.14504553191363811, 0.1515637021511793, 0.23176997474261693, 0.0335839143288987, 0.17889391205140523, 0.22078608056264265, 0.1553667009408985, 0.11680589509861809, 0.09964174112038952, 0.12704625060515745, 0.07284754674349513, 0.127428211537855, 0.16108514980546065, 0.24612761288881302, 0.1763499349887882, 0.267518157937697, 0.12126505082207066, 0.10369752813130617, 0.10602735275668757, 0.11049313776727233, 0.13261899085981504, 0.09665832442364522, 0.23395721880452974, 0.09091659502259322, 0.15517086216381618, 0.09436980222484895, 0.10830158500799111, 0.15036455435412271, 0.07234159032148973, 0.11441272922924586, 0.07266654074192047, 0.1675249356776476, 0.1616416842277561, 0.101459658571652, 0.12157336356384413, 0.15711535353745731, 0.13344981627804892], [0.028346049765657102, 0.05398783214124186, 0.024672720714339187, 0.0248088399280927, 0.06783727130719594, 0.005750256465814475, 0.0123668808623084, 0.030024407830621515, 0.049896028491535356, 0.04559695614235742, 0.04375876406473773, 0.014915529638528824, 0.03859241878879922, 0.048404639054621966, 0.012205366627313197, 0.04073360050097108, 0.04418248882783311, 0.019001072106350745, 0.017591985574524318, 0.0699267452582717, 0.013170893121111606, 0.044836074113845825, 0.03433517812352095, 0.048273088077881506, 0.04505936981045774, 0.061186936018722396, 0.03522732275139008, 0.04202715287517224, 0.048569940363190005, 0.042297545687428544, 0.06823335933898177, 0.02600013028963336, 0.01500115227619452, 0.09063844316239868, 0.01740497793070972, 0.017662902661998357, 0.05637159351525562, 0.028411487682855556, 0.04460749941478882, 0.0583257099081363, 0.08757042671952929, 0.12183949856885842, 1.0799173606293542, 11.660608444895063, 37.35825777053833, 60.780471937997, 69.05877113342285, 74.92765739985875, 67.26097338540214, 63.26582867758614, 52.83801392146519, 40.973481927599224, 36.05915307998657, 32.06167377744402, 36.529212611062185, 36.192423003060476, 28.24957936150687, 40.37170886993408, 38.01459503173828, 33.16226496015276, 42.036042145320344, 58.43024376460484, 39.4729767526899, 31.58952283859253, 30.44425126484462, 20.77013192858015, 14.729371547698975, 11.453467011451721, 6.99726459809712, 1.9860148940767561, 1.2254293582269122, 0.7208034619688988, 0.010700801736675203, 0.139228953314679, 0.08806074969470501, 0.09791493735143117, 0.022067220881581306, 0.07124809721218688, 0.07707854506692716, 0.08876950666308403, 0.06163581407495907, 0.08763365261256695, 0.11968407779932022, 0.10287551688296454, 0.02779061796276697, 0.035326578853917975, 0.07429131320012466, 0.030491151713899205, 0.02016459681492831, 0.03658101707696915, 0.13615856878459454, 0.06740467809140682, 0.10993154147373778, 0.12443458288908005, 0.12932897811489447, 0.08026554941066674, 0.023164244069318687, 0.18671296962669917, 0.07611556816846132, 0.13769838187311376, 0.31174127065709656, 0.6598499555672918, 0.6497676851493972, 0.922722727060318, 1.4151932384286607, 4.318629818303244, 5.169445855276925, 10.47966742515564, 18.386248418263026, 29.712543419429235, 38.94551815305437, 40.771424838474815, 59.241786411830354, 72.272750718253, 81.70159517015729, 105.78520488739014, 104.484849521092, 71.9237288066319, 40.64169154848371, 29.97928476333618, 25.42297053337097, 19.50861178125654, 24.78678478513445, 33.540615218026296, 38.58219337463379, 42.38604722704206, 51.20766428538731, 52.5456337247576, 44.07091590336391, 36.985671043395996, 18.984627280916484, 7.8789419276373724, 2.5795280635356903, 0.5437329635024071, 0.017501757380419543, 0.04553490072222693, 0.017261097972680415, 0.1072199119787131, 0.02851758511470897, 0.018923853124891008, 0.012236129708721169, 0.03483639158574598, 0.04894739921603884, 0.028432376383404647, 0.04657575987013323, 0.041508331429213285, 0.011046990303189626, 0.07042703591287136, 0.0385504072931196, 0.04106526841808643, 0.024112976821405546, 0.04107577892552529, 0.07181390720818724, 0.03553652098136289, 0.021187032040740763, 0.017441376245447567, 0.12357570683317524, 0.031121656631252596, 0.02500997806367065, 0.009981813308383738, 0.044781482578920465, 0.0598856212039079, 0.030300273027803217, 0.012032457244848567, 0.034916971011885574, 0.030690610475306, 0.061563875792281966, 0.045590007943766456, 0.02391051214986614, 0.10093638593597071, 0.017043629195541143, 0.05736300442367792, 0.020125143396269, 0.04283255358625736, 0.02707881946116686, 0.02823017803686006, 0.03533005973856364, 0.04411000432446599, 0.05889447831681796, 0.029961321037262678, 0.036149523087910244, 0.036913797791515074, 0.028785603054400002, 0.006414519772598786, 0.0419749599615378, 0.07703371425824505, 0.03583636560610362, 0.01187055794123028, 0.038713639069880755, 0.04139733327818768, 0.06212826765009335, 0.0024773693086379872, 0.03021884543289031, 0.039639293149645836, 0.035364213798727305, 0.04675782099366188, 0.03735596513641732, 0.07043705108974661, 0.04911149273227368, 0.021880574557664137, 0.012596213824248739, 0.05182431644893118, 0.07165149985147373, 0.02484079553479595, 0.033521295724702735, 0.05002861423417926, 0.057437989328588755, 0.02064538637309202, 0.036297369083123546, 0.0630489175340959, 0.055969072971493006, 0.0563689404433327, 0.050530662294477224, 0.02507004707253405, 0.053255275557083745, 0.043689689199839316, 0.021121253159695437, 0.3042240525994982, 1.738827952316829, 13.824941039085388, 43.37589454650879, 68.28242806025914, 76.55190304347447, 82.55143628801618, 75.39863409314836, 71.72511454990932, 60.215020588466096, 49.35070262636457, 46.13046618870327, 36.44191891806466, 38.38344015393938, 43.70876884460449, 40.616695404052734, 50.51416458402361, 38.67037296295166, 29.22792046410697, 27.752656357628958, 39.09207303183419, 42.694231101444785, 37.366623401641846, 22.626254592623027, 16.54380328314645, 12.118075234549385, 8.123270988464355, 4.495206126144954, 1.3266394244773048, 0.8004146186368806, 0.7221628661666597, 0.14666375650891236, 0.21203908563724586, 0.24075866384165628, 0.13107715573694023, 0.26508189152394024, 0.27123652983989033, 0.29388730440820965, 0.3336578703352383, 0.09589448398245232, 0.11261588707566261, 0.024971791809158664, 0.05191466338666422, 0.015959409963605658, 0.16718740521797112, 0.11665444608245577, 0.1337600832006761, 0.04114900981741292, 0.07973847697888102, 0.3373970054090023, 0.2782335558107921, 0.15037667298955576, 0.36957541587097303, 0.3594985737332276, 0.13750741497746535, 0.0648156598742519, 0.33203036338090897, 0.12076966597565583, 0.14371843955346517, 0.2152176829321044, 0.6190392225980759, 0.6815496683120728, 0.9124208284275872, 1.385253667831421, 3.5035349045481, 4.713997951575688, 8.928685324532644, 15.049344778060913, 22.979368993214198, 28.167614936828613, 29.385008811950684, 48.893955843789236, 65.75057397569928, 81.46576636178153, 94.30227143423897, 89.10461589268276, 66.28486265454973, 43.543311391557964, 33.2928910936628, 32.0649950163705, 27.388692344938004, 30.909731933048793, 38.259779589516775, 46.406757831573486, 50.27680022375924, 59.34606497628348, 60.05207143511091, 52.77453170503889, 40.996087891714915, 20.915159940719604, 9.243521230561392, 2.40494675721441, 0.5776687253798757, 0.02646084369293281, 0.02049699585352625, 0.012815518886782229, 0.02769572992942163, 0.07284688856452703, 0.045031960388379436, 0.027303981129080057, 0.009960868628695607, 0.03713761256741626, 0.051321695026542456, 0.04242980573326349, 0.009721235505172184, 0.018397616987515773, 0.010867360879534056, 0.032908168089176924, 0.030408947196389948, 0.029103771517319337, 0.023132626033787216, 0.027147212398371527, 0.03027674482603158, 0.06581303849816322, 0.022852275720132247, 0.07594522873737983, 0.005788478767499328, 0.04448514598022614, 0.022038418766377226, 0.0879824331828526, 0.05353921532098736, 0.017631958072472895, 0.05434885009058884, 0.021643908328509757, 0.01791637111455202, 0.017245444169800197, 0.08029680273362569, 0.07680744997092656, 0.049624444850321324, 0.08385615995419876, 0.03281735635495611, 0.054670916737190316, 0.04587305882679565, 0.008991132673275257, 0.03106825253260987, 0.09967530146241188, 0.11248796286859683, 0.12425103916653565, 0.12701262240963324, 0.18515441540096486, 0.16380167832332, 0.08879187117729868, 0.11928166582116059, 0.1220103536865541, 0.15663644352129527, 0.0871588002358164, 0.13029418060822145, 0.11252627295574971, 0.14506503301007406, 0.14490734147174017, 0.10516460905117647, 0.11777333675750665, 0.10757380870303937, 0.15579006608043397, 0.36603609578950064, 0.15684053328420433, 0.1477753868592637, 0.11776359299463884, 0.10561268643609115, 0.13481196175728524, 0.1362245495298079, 0.18498453737369605, 0.11662197139646326, 0.11028745344706944, 0.2171516434422561, 0.21693455294838973, 0.10165983318750348, 0.1087959384811776, 0.16451252517955645, 0.14023322585437978, 0.14256335582051957, 0.11220097648245947, 0.12573780438729695, 0.10598757024854422, 0.13264595584145614, 0.1404284675206457, 0.6563270017504692, 3.18502904687609, 18.818167550223215, 54.30833612169538, 80.57559095110211, 88.8681617464338, 92.81781659807477, 82.44615718296596, 77.3742015021188, 67.63726697649274, 52.25840214320591, 48.7550231388637, 43.17626237869263, 49.67812606266567, 48.28779847281319, 39.76815012523106, 51.652123178754536, 48.98246199744088, 44.544140338897705, 57.18648842402867, 76.32452324458531, 53.27793216705322, 41.86755527768816, 38.360778604234966, 25.547946044376918, 18.18135472706386, 14.038716265133449, 8.983819280351911, 2.7073592841625214, 1.6842444241046906, 0.9115935585328511, 0.2289418407848903, 0.4438913123948233, 0.3262859401958329, 0.37537311762571335, 0.2910952413720744, 0.3548329126621996, 0.31581381069762365, 0.3892502715545041, 0.2647136098572186, 0.19420463405549526, 0.2438973497067179, 0.3085108468575137, 0.16961480996438436, 0.18197281898132392, 0.17276048474013805, 0.2461589883480753, 0.16711793680276188, 0.24843026218669756, 0.34259290088500294, 0.359639546168702, 0.21066377657864774, 0.3262404783495835, 0.4308943269508225, 0.16958198244018213, 0.2241702332560505, 0.41235080627458437, 0.22931096383503505, 0.4724452059183802, 0.5416312419942447, 0.7872802977051053, 1.1023604763405663, 1.1559028604200907, 2.068559927599771, 6.025696686335972, 7.249130283083234, 14.308579087257385, 21.784914595740183, 38.167358125959126, 49.397481373378206, 51.70918525968279, 72.60480512891496, 82.57292706625802, 91.98203863416398, 111.78546074458531, 109.65018204280308, 79.04347842080253, 51.86212205886841, 41.460835524967735, 38.81072310038975, 31.19780077253069, 36.79467896052769, 47.08927937916347, 54.198710918426514, 58.09740768160139, 68.58207607269287, 70.02805178506034, 63.09366621289934, 53.4435772214617, 29.731011731284006, 12.71293830871582, 4.185106285980769, 1.089971512556076, 0.21703508469675267, 0.10822021508855478, 0.12750956788659096, 0.29692806409937994, 0.15582921755100998, 0.11311648985637085, 0.10800872250859227, 0.20210503440882477, 0.12281211066458907, 0.1878096857773406, 0.18942997311907156, 0.09677366180611507, 0.07153953478804656, 0.2119666180972542, 0.15031925535627774, 0.1282805193747793, 0.07927524112164974, 0.13336463299180779, 0.2190867710326399, 0.1100335456430912, 0.11559852345713548, 0.23538244089909963, 0.15972687197583063, 0.14157448602574213, 0.14589760904865606, 0.12358855828642845, 0.1414451708218881, 0.15633168630301952, 0.14728106052747794, 0.1683602122856038, 0.141146805403488, 0.06443247079317059, 0.16236774383911065, 0.23642078946743691, 0.22391137214643614, 0.17217558755406312, 0.133182894172413, 0.15687227515237673, 0.15056232017065796, 0.14340228294687613, 0.060679283259170394, 0.1565944150622402], [0.042298217437097003, 0.049028073637081046, 0.03883936482348612, 0.04060560504772833, 0.05477864095675094, 0.038912297159965546, 0.008497199891800327, 0.020218643825501204, 0.050531262797968726, 0.00587466374106173, 0.025116111118612543, 0.028843858678426062, 0.010345635303695287, 0.007482960520844374, 0.005409146309830248, 0.0515343852208129, 0.040718153651271544, 0.037049185883785994, 0.015551381411829164, 0.02832294225559703, 0.042090656967567544, 0.055163668867732794, 0.09595901266272579, 0.03360975633508392, 0.020615613952811276, 0.028018332618687834, 0.03466049834553685, 0.027777140560959066, 0.01603773665348334, 0.04587890101330621, 0.01545572663391275, 0.03240228969869869, 0.026012401595445614, 0.07858382072299719, 0.07148623586233173, 0.06985507160425186, 0.019388050805511217, 0.02435649455791073, 0.06389314401894808, 0.008733190978611154, 0.45402129739522934, 3.106104676212583, 20.111880438668386, 44.102912357875276, 66.91014494214738, 72.09668336595807, 72.53144604819161, 64.8915125983102, 52.13154888153076, 45.258505480630056, 41.68209743499756, 33.989739826747346, 28.26560538155692, 38.783527851104736, 30.74545567376273, 26.16367977006095, 26.974411215100968, 32.04574850627354, 54.386319228581016, 62.91372871398926, 46.67680304391043, 39.84556695393154, 27.401763643537247, 16.809530190059117, 14.755541937691824, 5.624639715467181, 3.193195568663733, 1.4167259676115853, 0.6164888537355832, 0.3778333498963288, 0.23970457326088632, 0.10612382008028881, 0.19245813920029572, 0.02872265875339508, 0.3690656189407621, 0.057929513310747485, 0.09089544508606195, 0.30270236996667726, 0.24464916650738033, 0.14892063183443888, 0.04165726647313152, 0.06021015771797725, 0.027353134205830947, 0.023724093135180216, 0.039404194336384535, 0.06477430995021548, 0.04860988911241293, 0.005129384625303958, 0.1440014022269419, 0.18412837545786584, 0.1119824814211045, 0.3135546419237341, 0.5395259921039853, 0.10946427511849574, 0.30421588303787367, 0.1831464267202786, 0.22186321419264587, 0.04951042043311255, 0.1223828015582902, 0.17190871973122868, 0.2088813872209617, 0.03611920614327703, 0.24419954206262315, 0.37188172925795826, 0.35623710017119137, 0.43026513499873026, 1.8237720685345786, 2.105021685361862, 3.438508233853749, 7.187898414475577, 12.535124353000096, 19.452593667166575, 27.674376215253556, 43.213313647678916, 49.99443238122122, 49.31259870529175, 55.18323244367327, 47.15534632546561, 38.20925228936331, 19.39042639732361, 17.978356157030376, 26.0866641998291, 23.02984939302717, 27.26655864715576, 27.781703301838466, 38.811998094831196, 50.45928423745291, 49.50682864870344, 53.61924852643694, 50.64927577972412, 33.63380445752825, 20.23560701097761, 5.589275121688843, 1.134712266070502, 0.1676926559635571, 0.05655739675941212, 0.10693240990596158, 0.04011673413749252, 0.01963526995054313, 0.016302711363615732, 0.03912349457719496, 0.005730343159354691, 0.03591428856764521, 0.032913911888109784, 0.025964619159432392, 0.02667262125760317, 0.018321653295840536, 0.05079997962872897, 0.03672912430816463, 0.037366099056920836, 0.028590758331120014, 0.006981491759818579, 0.042267517120178254, 0.0409859103549804, 0.022709223574825695, 0.08138548502964632, 0.06170570318187986, 0.034692837324525626, 0.014145858037019414, 0.04637737658673099, 0.019279115400942307, 0.025677096730630313, 0.004717211920901069, 0.030090887299073592, 0.016204011659803133, 0.014582497866025992, 0.10254644775497061, 0.007214784821761506, 0.02437921699934772, 0.04204072018287011, 0.04171640080000673, 0.01875737455806562, 0.053727301835481606, 0.01962154488345342, 0.07584787931825433, 0.044776658194937875, 0.016305922530591488, 0.07550095114856958, 0.01574438900154616, 0.007654772372916341, 0.05756756237574986, 0.020405257919004986, 0.03359573440892356, 0.043701926578900645, 0.015633489238098264, 0.04237259844584124, 0.012131600540929606, 0.024147799238562584, 0.03527418916512813, 0.01857255688602371, 0.04830542705687029, 0.044182003675294776, 0.047273558497961075, 0.019945489375719, 0.04836105335769909, 0.019993643309654932, 0.035264184166278155, 0.03720701312912362, 0.06492255628108978, 0.01986628907200481, 0.023645691806450486, 0.039732513683182855, 0.05292125990880387, 0.04378013791782515, 0.022117174629654204, 0.02733448297450585, 0.036772262171975205, 0.0325453113099294, 0.023405229173866764, 0.06375099093254123, 0.03451360569202474, 0.03681475203484297, 0.014684464715953385, 0.03148550067895225, 0.056623855871813636, 0.08222685488206999, 0.30562620450343403, 3.5743639724595204, 23.706226996013097, 49.88476548876081, 73.07164764404297, 81.39932073865617, 83.72214521680559, 75.74115249088833, 63.491325514657156, 55.92253814424787, 56.2743740762983, 42.16592134748186, 34.94063901901245, 42.138844217572895, 37.74538360323225, 30.165225505828857, 27.58830714225769, 27.419960975646973, 40.09835631506783, 54.5972317968096, 53.906976904187886, 54.081067493983674, 30.064289024897985, 16.576494557516916, 12.255280443600245, 5.907594680786133, 2.4120504217488423, 1.1971475843872343, 0.8764548897743225, 0.4820604813950402, 0.3610303801085268, 0.14770864615482943, 0.21585334810827458, 0.17187692358025483, 0.37604969846350805, 0.15519306382962636, 0.27110931809459415, 0.31085323116609026, 0.8175884485244751, 0.5099849658352988, 0.15759807692042418, 0.376392412930727, 0.0879087374944772, 0.07779538338737828, 0.1160420003746237, 0.06195668649992772, 0.08459189547491924, 0.3208111939685685, 0.5129617261035102, 0.6489711936031068, 0.469891688653401, 0.8122168939028467, 1.3902805809463774, 0.9003455106701169, 0.7691509276628494, 0.5933253509657723, 0.47874385650668827, 0.20944683759340219, 0.1944581890212638, 0.28413320066673414, 0.43285274186304634, 0.1477642317435571, 0.21133141432489666, 0.20799564117831842, 0.26347387209534645, 0.4129349977842399, 1.3950349943978446, 1.9417301160948617, 3.7209392615727017, 6.996387388025012, 11.344557472637721, 20.16423511505127, 32.00997570582798, 49.587146350315635, 59.81729875292097, 62.378043447222026, 66.13788740975517, 61.786584990365164, 48.06687702451433, 28.44825267791748, 26.63057439667838, 29.46675784247262, 28.655385426112584, 35.29148483276367, 34.466966424669536, 46.55195433752877, 58.42092623029436, 57.836641788482666, 60.777122906276155, 57.49323749542236, 37.42497784750802, 23.751567465918406, 7.2114189352308, 1.3809760745082582, 0.20871737173625401, 0.06297637535525219, 0.019993779016658664, 0.026161545288882086, 0.049059703546975336, 0.081684054008552, 0.023599028953218033, 0.019669849791431, 0.02134046746817018, 0.03674649141196694, 0.03373788410265531, 0.037975046916731765, 0.03733419094766889, 0.10268581884780101, 0.03655746851914695, 0.07750153022685222, 0.009142894663714936, 0.025327834400481412, 0.036003526100622754, 0.020112812718642608, 0.09909109638205596, 0.06804950349032879, 0.0587939058563539, 0.019983600991378938, 0.015986815993008868, 0.010732340044341981, 0.010723917728423007, 0.024333217414095998, 0.030257871374487877, 0.02797797165944108, 0.07016830372491054, 0.049859655621860705, 0.03219343661995871, 0.0479124840348959, 0.044004922998803, 0.053951530517744165, 0.03813639236614108, 0.051641746424138546, 0.05190318596682378, 0.038649961951055696, 0.06176410469093493, 0.021746292477473617, 0.09654751965509993, 0.1219443322292396, 0.08446261419781617, 0.16151154121117933, 0.1687556624944721, 0.0812975943886808, 0.15188501562391007, 0.0696030840543764, 0.08604703417846135, 0.1439883200717824, 0.05750238908720868, 0.12793870057378495, 0.0583686815308673, 0.05623964898820434, 0.08407942511673484, 0.13438263908028603, 0.1809205740158047, 0.1138408463448286, 0.13234581266130718, 0.09713557202901159, 0.16553144050495966, 0.12372167328638689, 0.20406106087778295, 0.09276472085288592, 0.10830880462058953, 0.16699185142559664, 0.16088352991001947, 0.14893827374492372, 0.18701700759785517, 0.10825229622423649, 0.1617508198001555, 0.08868546331567423, 0.14184775921915257, 0.20404203475586005, 0.14742332217948778, 0.16752992969538483, 0.16682789022369043, 0.1294923557766846, 0.1360478318695511, 0.22752740739711694, 1.0803515144756861, 6.777946012360709, 31.969492026737758, 62.0903810773577, 85.4140385219029, 92.25003760201591, 89.34915079389299, 78.9923049381801, 67.09102044786725, 57.53744888305664, 55.49628005708967, 46.06788723809378, 38.60963528496878, 50.1150426864624, 40.773887974875315, 38.62088441848755, 36.35386092322213, 42.737289088112966, 72.86846147264752, 78.93814373016357, 58.29025840759277, 48.901748248508994, 32.776118823460166, 22.046912057059153, 18.5185421194349, 7.6920866285051614, 4.416533844811576, 2.1711222870009284, 0.9463192437376294, 0.6295366478817803, 0.4070168696343899, 0.5282098736081804, 0.4773575280393873, 0.304323851530041, 0.7900428037558282, 0.35881642890827997, 0.30586537452680723, 0.765229592365878, 0.549120151570865, 0.331861462444067, 0.31796967930027414, 0.42263671862227575, 0.2169649920293263, 0.2963720996465002, 0.1637943908572197, 0.15483753862125532, 0.30080488749912804, 0.3655381867928164, 0.4331508901502405, 0.6316804928439004, 0.32846031923379215, 1.009105120386396, 1.3168818737779344, 0.8749572815639632, 0.5740635874015945, 0.5905656676207269, 0.3135183538709368, 0.23604091842259678, 0.30632905821715084, 0.24548466024654253, 0.4672183692455292, 0.2161460816860199, 0.33422680837767466, 0.5378922426274845, 0.6093277037143707, 0.5884877762624195, 2.4556570989745, 2.424230831010001, 4.868663549423218, 8.912608061517988, 14.80018585068839, 24.07975172996521, 33.99608700616019, 50.44084371839251, 60.02807930537632, 59.22907815660749, 65.50166170937675, 58.06451490947178, 50.49779462814331, 31.542841366359166, 28.506707872663224, 37.58990723746163, 35.272613525390625, 40.959008829934255, 40.73843479156494, 54.23002644947597, 65.4427409853254, 65.74935804094586, 71.87909357888358, 68.29992362431118, 47.46511786324637, 31.55599430629185, 9.937986731529236, 2.0321283510753085, 0.3307850887732846, 0.22768076988203184, 0.19936084880360536, 0.146959923473852, 0.15155546473605291, 0.15104272296386106, 0.17103319242596626, 0.10673094607357468, 0.13198591768741608, 0.13172523810395173, 0.15047183074057102, 0.10225973956819091, 0.11817838145153862, 0.1172882385019745, 0.07304632357720818, 0.14395862737936632, 0.139436788590891, 0.12859369042728627, 0.10442579976682152, 0.10424602191363062, 0.16771521046757698, 0.18779216600315912, 0.1680528630635568, 0.08530112741781132, 0.1103004745340773, 0.11565524898469448, 0.1159995783652578, 0.2246999248330082, 0.20364691024380072, 0.09535686033112661, 0.11280261991279465, 0.11179912768836532, 0.11038193944841623, 0.11698360342000212, 0.09581993333995342, 0.2091545925608703, 0.12357707747391292, 0.15852268944893563, 0.15139329486659595, 0.11870223762733595, 0.1125140864668148, 0.15006109992308275], [0.02735513249146087, 0.017912488197907805, 0.005301969583212797, 0.05056576969634209, 0.04030991984265191, 0.029011667173888003, 0.009943084225856831, 0.03828674554824829, 0.005921303269652916, 0.009610647867832865, 0.04005309773076858, 0.03618688661871212, 0.011811987646589322, 0.06276765798351594, 0.03392465765188847, 0.036702556269509454, 0.003687061327842197, 0.06582288404128381, 0.036706264463386366, 0.005754867959434965, 0.005867458547332457, 0.016995999429907118, 0.06379831875009195, 0.004597480600101075, 0.03931371847699795, 0.022924960391329866, 0.015328408019351107, 0.062060800913189135, 0.04582371576023953, 0.04128563962876797, 0.03626862294705851, 0.05633501708507538, 0.08246183155902795, 0.014677072076925209, 0.017966370663738677, 0.025154489059267298, 0.04846188026879515, 0.07825437161539282, 0.1038188026951892, 0.6685429662466049, 5.008011409214564, 12.096345611980983, 42.42007602964129, 73.51516505650112, 70.41555282047817, 67.36102744511196, 56.33402783530099, 50.07222441264561, 44.705929143088206, 38.739740303584504, 27.6834488255637, 38.1765992300851, 50.97018527984619, 51.093449796949116, 57.08621897016253, 74.68494987487793, 79.42014026641846, 78.87512356894356, 57.294671876089915, 37.594295024871826, 24.3886547429221, 12.50110684122358, 11.625628607613699, 6.412753471306392, 2.2143950164318085, 1.0778805613517761, 0.5842748880386353, 0.23886481832180703, 0.2711355909705162, 0.11841174321515219, 0.12927240186503955, 0.36469666766268866, 0.12319131674511091, 0.09247759875974484, 0.4614041383777346, 0.3000361616058009, 0.43002401079450336, 0.5442531555891037, 1.3304900292839323, 1.1419979951211383, 0.5716657532112939, 0.3699804741357054, 0.007839782579269792, 0.07855505083820649, 0.05433429890711393, 0.23517087368028505, 0.20013338806373732, 0.3131319688899176, 0.3373536877334118, 0.6027543821505138, 0.9346423617431096, 0.7373374604753086, 0.8692389684064048, 1.185726917215756, 1.052204579114914, 0.6932505975876535, 0.4978058050785746, 0.5358983267630849, 0.1645944650684084, 0.13586164186043398, 0.40379846947533743, 0.5302515583378928, 0.08092050533741713, 0.08744173576789242, 0.030993498329605376, 0.09572492486664227, 0.0632829103352768, 0.3051708803645202, 0.8005543425679207, 1.398192082132612, 2.938584476709366, 5.268126342977796, 11.937335218702044, 20.114932434899465, 25.19601457459586, 30.21758713041033, 28.72911102431161, 25.355995110103063, 22.81015603882926, 22.37948410851615, 22.64223371233259, 24.423807416643413, 22.361234664916992, 16.63249703816005, 28.607437644686016, 39.44160911015102, 42.93797043391636, 46.182942458561485, 56.25526653017317, 59.921542576381135, 47.272944586617605, 30.84100730078561, 12.414451513971601, 3.9744125860077992, 0.35356231512767927, 0.04604864672624639, 0.06252175689275775, 0.023247542724545513, 0.03569959330239466, 0.04443389962294272, 0.011329503447216536, 0.028209146843957048, 0.023298907825457196, 0.028095465086932694, 0.00989496082599674, 0.02379369386471808, 0.05715150505836521, 0.0433462079880493, 0.06251290879611458, 0.04038594629881637, 0.04297695940892611, 0.04554573692647474, 0.003230952632813049, 0.048205268502767594, 0.10542582467730556, 0.060109117068350315, 0.03635144153875964, 0.04662564915737935, 0.027797337155789137, 0.005510200530157557, 0.03494668406035219, 0.11033730541488954, 0.041598179643707614, 0.03496986620926431, 0.03301776845806411, 0.005782830387553466, 0.01872019423171878, 0.021984395504529988, 0.025261178512924483, 0.01985459282462086, 0.029047314011092697, 0.021469996410555074, 0.018083769096327678, 0.05601416501615729, 0.03231250594503113, 0.03683066368103027, 0.02386785265324371, 0.08816684543022088, 0.022358860321609036, 0.008066718616256756, 0.04614555849028485, 0.027949047407933643, 0.04986869031563401, 0.018710894909288203, 0.07135084777006082, 0.01994692617362099, 0.04150126109431897, 0.043653027952781746, 0.03536288047741566, 0.04897927339853985, 0.033163266722112894, 0.048886263210858615, 0.04657815170607396, 0.008188949914516082, 0.12712897759463104, 0.061229995851005824, 0.02166323979119105, 0.06572585353361708, 0.009892423953195768, 0.020528356045750634, 0.010341757476063711, 0.05001241421060903, 0.03182746875765068, 0.03617930059720363, 0.06747696921229362, 0.02431117690035275, 0.03655763136755143, 0.048355374019593, 0.047078866445060284, 0.05825580723051514, 0.03747002687305212, 0.08894695035581078, 0.01780827370073114, 0.042712988930621316, 0.08157389384827443, 0.45008734134691103, 5.341672156538282, 15.108458314623151, 48.739591189793174, 79.21449443272182, 80.04169831957135, 76.76598399026054, 65.32196739741734, 57.51059409550258, 51.691780022212434, 43.09575012751988, 30.929207733699254, 36.243513107299805, 50.05246026175362, 45.806416102818076, 47.89126130512783, 58.67607797895159, 52.64427730015346, 61.42365973336356, 63.963226318359375, 48.49688713891165, 28.384185075759888, 16.433222702571324, 13.510840773582458, 7.439268606049674, 2.9626491282667433, 1.4773303270339966, 0.6109498909541539, 0.2677663931889193, 0.20430766764496053, 0.21931327959256514, 0.5939389637538365, 0.5398779617888587, 0.5368839938725743, 0.6653848471386092, 0.8707864082285336, 1.6570229019437517, 0.7793243931872504, 0.9980805005346025, 1.6850049261535918, 1.717425980738231, 1.2815418158258711, 2.0101670495101382, 0.11687810479530267, 0.04266104707494378, 0.061754598415323665, 0.1476159854126828, 0.6091941680227007, 1.353544152208737, 1.192786829812186, 1.1301745495625903, 2.4964519270828793, 2.7786106722695485, 2.3942280752318243, 2.666600282703127, 3.203562932355063, 2.671944098813193, 2.9007593521050046, 2.542449653148651, 1.1420419641903468, 1.119241776210921, 1.3141835842813765, 0.8805961247001375, 0.6746150947042874, 0.38898140883871485, 0.12026134825178555, 0.20422445211027349, 0.27427587817822185, 0.42752586198704584, 0.9131472408771515, 1.8365634850093295, 3.5045512957232337, 6.430717604500907, 13.930575370788574, 23.279998438698904, 29.84756428854806, 32.794100761413574, 37.87998758043562, 32.21846335274832, 25.420172146388463, 24.651972361973353, 24.87095352581569, 28.982841866356985, 24.84678421701704, 20.101574523108347, 34.08537483215332, 45.81463234765189, 48.74450009209769, 54.09642996106829, 62.648932865687776, 68.86147703443254, 53.25115728378296, 36.11887632097517, 13.578257407460894, 4.094978596482958, 0.4419321375233786, 0.02986835495435766, 0.006556223329555775, 0.0588226214583431, 0.02568522049114108, 0.05680262270782675, 0.018878716975450516, 0.05017144585560475, 0.07760810772223131, 0.022538587284673537, 0.044871802375252755, 0.0130280682850363, 0.03724981172542487, 0.005413588593780462, 0.006528136644711984, 0.031010543129273822, 0.08287500510258333, 0.03899650674845491, 0.00423656655142882, 0.08284983823874167, 0.11956112725394112, 0.02897490414657763, 0.03770579404330679, 0.014942903437518647, 0.03210496922422733, 0.03351225424557924, 0.005693881231958845, 0.03827675751277378, 0.029982803455953087, 0.05346970619367702, 0.056681907935334105, 0.061102119141391346, 0.013858488278596528, 0.04448460654488631, 0.017915299029222558, 0.017607880257336155, 0.01701656073730971, 0.09637165016361646, 0.057176929765513966, 0.0111042349100379, 0.05298172416431563, 0.02227334285687123, 0.1292972769588232, 0.15193342231214046, 0.08435760411833014, 0.10979639086872339, 0.20938937924802303, 0.11369225396109478, 0.1319761196417468, 0.11892422714403697, 0.2067361037646021, 0.08148315336023058, 0.1425983817981822, 0.13681350435529435, 0.12821744275944574, 0.11022294512284653, 0.13297466534589017, 0.11792783918125288, 0.17397147975862026, 0.236595661512443, 0.2326322299029146, 0.15127365557210787, 0.08249537154499974, 0.13831719223942074, 0.18780594026403769, 0.1294120443718774, 0.0846937842933195, 0.07836538672979389, 0.11594769757773195, 0.2183487013514553, 0.13101916813424655, 0.07651817013642617, 0.1578678217317377, 0.1625537709998233, 0.2159786463848182, 0.1329768095165491, 0.16959878296724387, 0.16809220452393803, 0.11972772117171969, 0.17181105140064443, 0.226284439808556, 1.54322378550257, 7.470576320375715, 22.225716999598912, 62.58805274963379, 92.71244716644287, 92.32761423928397, 83.97879082815987, 73.55193492344448, 64.36814648764474, 58.36224174499512, 49.154992716653005, 37.723632267543245, 47.80581930705479, 61.704443386622835, 62.22558607373919, 69.05943121228898, 86.31745025089809, 92.9122565133231, 92.39920847756522, 66.91491835457938, 45.81924942561558, 30.70175497872489, 16.860651561192103, 15.173493453434535, 9.171385032790047, 3.457278140953609, 1.77757870725223, 1.091675015432494, 0.3445424677005836, 0.5837962765778814, 0.2366466059216431, 0.4180564986807959, 0.6312112180250031, 0.7901904529758862, 0.5905979658876146, 1.3124335067612785, 1.8220882160323006, 1.4107379232134138, 1.4351622526134764, 2.732696975980486, 3.0520559421607425, 2.417361233915601, 1.8815995369638716, 0.13263926548617228, 0.39977928942867685, 0.2084665580519608, 0.5935726091265678, 1.823569050856999, 1.3629664523260934, 1.682872480579785, 1.8903329883302962, 3.9667083365576605, 3.040148901087897, 2.6040871228490556, 3.665686752114977, 3.5908896114145006, 4.025081021445138, 3.047257125377655, 1.9871515759399958, 1.1861251358475005, 1.2549660418714796, 0.9596440430198396, 1.1220980286598206, 0.7460967504552433, 0.27992468220846994, 0.19417545704969338, 0.33295338813747677, 0.41407832929066246, 0.7772556756223951, 1.24861712540899, 2.3669144894395555, 4.46129674570901, 7.099611563341958, 16.138452325548442, 25.93163251876831, 35.188877310071675, 39.189768178122385, 44.0493243762425, 37.27606405530657, 33.924722058432444, 32.58675261906215, 33.62035969325474, 35.38062674658639, 33.233803612845286, 28.122898067746842, 42.49697521754673, 51.7383850642613, 57.072385106767925, 62.61119025094168, 70.2931603022984, 76.7265043258667, 63.320927892412456, 43.63880743299212, 22.481002501079015, 6.874492534569331, 1.1816410507474626, 0.11717303682650838, 0.1422828630145107, 0.1610543036035129, 0.11945379658469132, 0.1824315765074321, 0.11599275230297021, 0.18398661592176982, 0.12358568129794938, 0.07586814037391118, 0.13464813626238278, 0.10753691675407545, 0.2600443661212921, 0.10032651866120951, 0.13199059957904474, 0.18161953293851443, 0.18846923538616725, 0.121945037905659, 0.1301078548921006, 0.16236052422651223, 0.35531070988093105, 0.14363660823021615, 0.09627413789608649, 0.11745895791266646, 0.08500493331147091, 0.06935762401138033, 0.10355065922651972, 0.21243897346513613, 0.16827093064785004, 0.1282221246510744, 0.1487475104097809, 0.1524669136852026, 0.12849191017448902, 0.10025797305362565, 0.096910759806633, 0.0898050596671445, 0.08956936374306679, 0.13765863329172134, 0.1838686051113265, 0.10499544348567724, 0.1752409373543092, 0.1378072053194046], [0.00495924027304032, 0.025708054890856147, 0.017136629205197096, 0.059509556740522385, 0.02724203427455255, 0.060997841879725456, 0.045104977541736195, 0.012839188732739006, 0.0363270108854132, 0.06631182959037167, 0.013068284207422818, 0.028711239009031227, 0.054077524292681894, 0.046350815333426, 0.02946054862279977, 0.04445797065272927, 0.06176941083478076, 0.02007019054144621, 0.03869138651394418, 0.03253294161653944, 0.03010041393073542, 0.022662163778607334, 0.03605075892327087, 0.03964326936485512, 0.01118074482240315, 0.054743109470499415, 0.03397829584511263, 0.02570325425559921, 0.04784107840220843, 0.030417954748762504, 0.05828822763370616, 0.04826763944168176, 0.010729194186361772, 0.029820613230445554, 0.048999330893691094, 0.09533629393471138, 0.02686509789366807, 0.032905308064073324, 0.9209996823753629, 3.744828905378069, 15.773209844316755, 44.78646918705532, 65.88258974892753, 64.55291298457554, 69.0099183491298, 50.85218054907662, 54.89142199925014, 43.034727573394775, 36.84655768530709, 37.16143267495291, 44.9465000970023, 59.34246580941336, 84.1689213344029, 92.12178080422538, 91.85161399841309, 84.0730778830392, 87.11866092681885, 56.19050931930542, 28.868620429720195, 21.84696548325675, 17.435185943331035, 16.88909748622349, 3.4449023136070798, 0.7735374665686062, 0.45850456825324465, 0.3073323672371251, 0.08436647257102386, 0.09905079140194825, 0.18310788593121938, 0.46919768303632736, 0.7846527386988912, 0.4189659527369908, 0.8390733099409512, 0.29484398450170246, 0.32939072645136286, 0.37266139313578606, 0.9682887962886265, 0.4232938662171364, 2.3819299808570316, 1.4339905040604728, 0.1885587612965277, 0.9657103632177625, 0.42063091482434956, 0.0449938233276563, 0.06148439898554768, 0.09171613997646741, 0.12588173523545265, 0.5708054793732507, 1.4543514400720596, 1.8361924077783311, 1.839921201978411, 1.8940248702253615, 3.1085741094180515, 1.6282807013818195, 2.6562038234301975, 1.9521587107862746, 1.9561673871108463, 2.254489379269736, 0.9557528346776962, 1.5188904340778078, 1.4745900226490838, 0.5893593409231731, 0.5820994504860469, 0.4957332877176148, 0.1701689288020134, 0.044579235038587024, 0.21528161450156144, 0.0766861414802926, 0.05759089719504118, 0.1462833426360573, 0.40580978297761505, 1.0092898990426744, 3.0512558136667525, 6.241489929812295, 13.495141318866185, 19.756895235606603, 26.609418869018555, 38.71616506576538, 43.911367893218994, 44.11973394666399, 39.36950765337263, 41.227806840624126, 40.436848231724326, 26.456040859222412, 24.172527551651, 28.48971779005868, 44.193353584834504, 51.36711849485125, 49.90156970705305, 50.240325655256, 55.29386166163853, 48.280537605285645, 32.796174798692974, 11.012603810855321, 2.812547194106238, 0.3818156176379749, 0.04383359969194446, 0.04432791584570493, 0.07899980340152979, 0.07549956693713154, 0.07234279811382294, 0.023626765768442835, 0.03569789696484804, 0.012654275217625712, 0.028821314352431467, 0.010716533571082567, 0.03695933088394148, 0.0399890270616327, 0.010113555971266968, 0.05270467831620148, 0.026662994542026093, 0.02945243673665183, 0.018296859626259123, 0.026807507233960286, 0.06458180956542492, 0.027240700953240906, 0.0321895248655762, 0.014114157729116934, 0.07422129517155034, 0.012913962443625289, 0.0317644023203424, 0.024085789619545852, 0.05452614789828658, 0.025517559577045695, 0.03703363725383367, 0.04259117153872337, 0.08264691555606467, 0.02920182661286422, 0.04402716876938939, 0.02844508195162884, 0.026233563299423883, 0.05150336938511048, 0.05026483263022133, 0.03022595987256084, 0.0488648859650961, 0.057863532565534115, 0.010578255767800977, 0.024592278691540872, 0.02833459779087986, 0.03450339034731899, 0.05129018725295152, 0.0779561215479459, 0.06634317112288304, 0.05819269668843065, 0.03378984292170831, 0.04481429313974721, 0.021202239706846218, 0.02334257325024477, 0.04143635243443506, 0.018670966516115835, 0.023142943158745766, 0.053645850491843054, 0.07072946575603314, 0.03252440903867994, 0.030030803023172275, 0.034445433278701136, 0.004793167554972959, 0.013050930674320884, 0.012277266742395503, 0.03393847601754325, 0.04993530549108982, 0.06442067785454647, 0.011401390839767243, 0.08725000891302313, 0.056142021369721205, 0.03533659063811813, 0.04610399482771754, 0.00485202028981543, 0.049862413866711516, 0.10644571030778543, 0.05605938598247511, 0.0053021315834484994, 0.07335702476224729, 0.021489212522283196, 0.8946224206260273, 4.812172523566654, 17.54566056387765, 46.380757672446116, 71.59602396828788, 74.92865794045585, 79.33018888745988, 65.37867859431675, 65.70113754272461, 53.42811400549752, 48.78919437953404, 45.919796807425364, 55.28593029294695, 66.47300597599575, 80.10093171255929, 91.71644374302456, 95.08980805533272, 89.8090659550258, 84.36472157069615, 58.271703243255615, 32.56382008961269, 20.876347303390503, 15.427917378289358, 11.570000461169652, 4.355752740587507, 1.0994694828987122, 0.5562832014901298, 0.4318880279149328, 0.2719892423067774, 0.7015394728098596, 0.3754467251045363, 1.0749477701527732, 1.8266019395419528, 1.3042111822537013, 2.21906008039202, 2.263414123228618, 2.7556787942137038, 2.1056044655186787, 3.2575447899954657, 2.5457815315042223, 1.5016672611236572, 3.1937627153737203, 0.39367369562387466, 2.0144964286259244, 0.173529929880585, 0.0566040935393955, 0.04462737709816013, 0.08217240923217364, 1.2347932500498635, 2.1993832162448337, 3.2630985719817023, 2.482972638947623, 2.927716842719487, 3.3240512098584856, 5.2957141654832025, 3.677937294755663, 5.14491480588913, 3.6341612551893507, 4.931006261280604, 3.6524595533098494, 3.21818476489612, 2.917092178549085, 2.5463855905192236, 1.5430271731955665, 2.1369801419121877, 1.3464968332222529, 0.6452948365892682, 0.4197554960846901, 0.2726206327123301, 0.2274013084492513, 0.12350549202944551, 0.32652972425733295, 0.38034430944493836, 1.4976893088647296, 3.816832653113774, 6.866511225700378, 13.46191590172904, 20.337024654660905, 26.448015689849854, 34.84221431187221, 35.95751135689871, 33.916696889059885, 30.910638672964915, 38.24152667181832, 38.024697712489534, 29.83099283490862, 31.05673497063773, 35.249194622039795, 51.13037947246006, 58.29460103171212, 57.71787622996739, 60.15326499938965, 63.095778465270996, 53.22620977674212, 37.106434209006174, 12.483135325568062, 3.428647003003529, 0.499409481883049, 0.053269226237067153, 0.139812507001417, 0.033027749708188434, 0.09603482538035937, 0.005118478023047958, 0.0244078443917845, 0.01515909656882286, 0.040815475928996287, 0.0518949417663472, 0.03388323648167508, 0.04253561309139643, 0.027445932351318852, 0.023519195915598954, 0.02497150682445083, 0.07896341356847968, 0.031465812985386164, 0.034698900034917254, 0.04698327782430819, 0.08289044177425758, 0.06165188856955085, 0.03132637403905392, 0.016827590430953672, 0.020280833256297877, 0.028912665521992103, 0.014061426228311445, 0.02049032585429294, 0.04238209454342723, 0.03345831410427179, 0.036016248632222414, 0.029851374615515982, 0.05533680386309113, 0.04338525767837252, 0.025409567336152707, 0.0443505721299776, 0.022012568278504268, 0.04324861090364201, 0.04234538919159344, 0.045276263529168706, 0.06556231302342244, 0.004018407364908073, 0.1362217811069318, 0.12836317851075105, 0.10737849239792142, 0.2347075156867504, 0.14248687135321753, 0.1451830981033189, 0.11973498149641923, 0.13257871302110807, 0.17001894542149135, 0.181347752522145, 0.09222487160669905, 0.12745761924556323, 0.16288371543799127, 0.1298536349620138, 0.09862066126827683, 0.10123011017484324, 0.17227955268962042, 0.11712414159306458, 0.18290477325873716, 0.09941722745341913, 0.15915678042386258, 0.09708954021334648, 0.10342158150992223, 0.1551600056035178, 0.13880995794066361, 0.1828292387404612, 0.10841878157641206, 0.23259485619408743, 0.14622565358877182, 0.13289671524294785, 0.12150192739708082, 0.0753947129206998, 0.20752353008304322, 0.18796348252466746, 0.10526596861226217, 0.22829541404332432, 0.16222134312348707, 0.1372260129345315, 1.6818945216281074, 8.083588089261736, 26.393352474485123, 59.58599322182791, 82.82862077440534, 83.90409769330705, 85.11719063350132, 70.0385296685355, 70.23494134630475, 55.70111295155117, 49.35543434960501, 50.47495242527553, 58.47953428540911, 71.14448833465576, 93.98808084215436, 99.78111362457275, 98.7982839856829, 90.60057694571358, 92.87340218680245, 63.13015120370047, 37.35523183005196, 27.409623793193273, 23.813627038683208, 20.097110305513652, 5.066665930407388, 1.3986355726208006, 0.5395060703158379, 0.5006066347871507, 0.33734616956540514, 0.6662392041512898, 0.4872831925749779, 1.0845760192189897, 2.496006808110646, 1.4355438607079642, 2.877133305583681, 2.438826390675136, 3.409245026963098, 2.648102875266756, 4.6790116003581455, 4.459828504494258, 6.587499797344208, 5.634238651820591, 1.4797490601028715, 3.426738202571869, 0.839455135166645, 0.226823128759861, 0.1173745888684477, 0.4228118077984878, 1.9680913644177573, 5.608362691743033, 6.30913324866976, 5.014676902975355, 5.691549130848475, 5.701173688684191, 9.024054561342512, 6.035444574696677, 10.101001024246216, 7.372009175164359, 5.446505274091448, 5.701683512755802, 2.67073598078319, 3.8351624352591376, 4.109327929360526, 2.347565927675792, 2.325368170227323, 1.9461278915405273, 0.5107436765517507, 0.290596816688776, 0.3815237661557538, 0.18502811289259366, 0.324488853769643, 0.2831829802266189, 0.5277872277157647, 1.732903635927609, 3.9084481256348744, 8.48547797543662, 17.041269983564103, 26.7988406590053, 35.634732791355674, 52.160700048719136, 58.583812849862234, 59.861996514456614, 51.15286036900112, 53.92943695613316, 51.789082595280235, 40.726758343832834, 36.34451559611729, 41.40474271774292, 59.171067646571565, 65.62775761740548, 66.38743196214948, 66.51003987448556, 71.32801805223737, 63.66054194314139, 45.09588984080723, 17.683156728744507, 5.928561738559178, 1.002633959054947, 0.2019103355705738, 0.2306271589228085, 0.16037717993770326, 0.17643367978078978, 0.1541354177253587, 0.11381903822932925, 0.23367994225450925, 0.11655212300164358, 0.16956301060106072, 0.10934138564126832, 0.21529124969882624, 0.1481260537569012, 0.15696964492755278, 0.10664580349943467, 0.18112056542720112, 0.17641792419765676, 0.08550783632589237, 0.14588873381061213, 0.29046471949134556, 0.14314498246780463, 0.1443362728293453, 0.11163561431957142, 0.29206798917480875, 0.19760716147720814, 0.1366899431283985, 0.08942021496061768, 0.12212703456836087, 0.09282473727528538, 0.14327877600278172, 0.24023627330149921, 0.16824372139360222, 0.12363665284855024, 0.16500881926289626, 0.12365732102521829, 0.08271660788783006, 0.1809129879942962, 0.2509400003722736, 0.18175350289259637, 0.17888082989624568, 0.102837328932115], [0.061442967637309005, 0.043865019255982976, 0.0744113799716745, 0.014764348643698862, 0.03420607665819781, 0.020312527627018944, 0.018117146233894994, 0.008808968921325036, 0.0994726230523416, 0.032341947579490285, 0.055595105181315115, 0.017083041902099336, 0.04412027055929814, 0.04697982408106327, 0.015955476156835045, 0.03586572242368545, 0.035044555951442034, 0.020638036142502512, 0.028359903754400353, 0.006938250419417662, 0.049661340191960335, 0.020094229340819374, 0.010261216217518916, 0.03125458503408091, 0.02253955419707511, 0.004262529421664242, 0.036297650675156286, 0.0730123221874237, 0.037452452816069126, 0.05982779644961868, 0.051388330558048825, 0.027180872824309126, 0.04076355442936931, 0.03210012787686927, 0.024037055538168976, 0.04219729892377343, 0.10223210283688136, 0.4476345458201, 3.1895946647439684, 14.215859719685145, 27.405738013131277, 60.785057749067036, 59.73013360159737, 57.32153013774327, 53.924604484013145, 42.029378822871614, 38.57670777184622, 38.61246320179531, 32.32415240151541, 25.941988808768137, 21.216161114828928, 16.841279983520508, 34.08874818256923, 30.922273431505474, 29.03770136833191, 33.73589433942522, 32.54304150172642, 32.19451291220528, 22.859269380569458, 12.558268802506582, 4.182716105665479, 1.4748274556228091, 0.8510191089340619, 0.42242637276649475, 0.3132573350199631, 0.08553942213101046, 0.29338071016328676, 0.5923510289617947, 0.2940245856131826, 0.7917124341641153, 0.7128579254661287, 1.0310796669551303, 1.2743784402097975, 1.994933124099459, 2.02064363019807, 3.516454645565578, 2.0796931130545477, 1.9556773219789778, 1.707694485783577, 1.394604857478823, 1.1531107702425547, 3.210785150527954, 0.44078443625143593, 0.1298573940460171, 0.07822537102869578, 0.1317132551755224, 0.4070984295436314, 2.223009697028569, 0.8822182576571191, 0.6611139306000301, 2.3660550841263364, 4.727229927267347, 2.8609780924660817, 2.479252312864576, 4.777160116604396, 2.178038784435817, 4.286161754812513, 4.1689938477107455, 3.6445894156183516, 1.087412404162543, 1.44871167412826, 1.1122010797262192, 1.4424628551517213, 0.4836362568395478, 0.42686738446354866, 0.1586176436394453, 0.35134423843451906, 0.45817132613488604, 0.17791477244879517, 0.12051699310541153, 0.02435648098721036, 0.17945431412330695, 0.5621063347373689, 1.3866974817855018, 3.6691899469920566, 9.952791605676923, 21.933178731373378, 30.313934326171875, 46.518686362675254, 66.4583661215646, 77.52392823355538, 75.8425406047276, 33.98352813720703, 20.58867277417864, 18.49949015889849, 27.93492671421596, 35.47082131249564, 38.87483065468924, 42.51957423346383, 54.94154977798462, 52.059166022709434, 51.94727570669991, 39.710632937295095, 25.176587411335536, 9.170881288392202, 0.9251424372196198, 0.07561286871454545, 0.05038070944803102, 0.06455228650676352, 0.09234328953815357, 0.014968446888295668, 0.03989874119205134, 0.02672957579073097, 0.05177658490304436, 0.04989996738731861, 0.005675375885662756, 0.021960655260565023, 0.08629805820861033, 0.07263735016541821, 0.04184962097289307, 0.055273469404450486, 0.038068138528615236, 0.01674396438258035, 0.030119412911257575, 0.029229341207870414, 0.03059613804465958, 0.05541252837117229, 0.010642554594336875, 0.01700513081492058, 0.03264680318534374, 0.009262190449849834, 0.008969013279836093, 0.009270821415287043, 0.02942618421678032, 0.0024165840212455286, 0.07096180971711874, 0.0642164388139333, 0.06782642831759793, 0.05242182081565261, 0.014666627726650663, 0.04056747477235539, 0.022617421179477657, 0.0359476758832378, 0.041426503498639376, 0.083502208947071, 0.010385922472258764, 0.02876491452168141, 0.076547672839037, 0.07303382496216468, 0.0263343885141824, 0.012861671142413147, 0.041354161487626176, 0.034129083289631774, 0.014272726273962429, 0.04439458869663732, 0.012529378973080643, 0.036404167102383714, 0.040240756768201075, 0.03665824454011662, 0.0340670210841511, 0.01282207777590624, 0.06712793079870087, 0.011378010219362165, 0.032322884138141356, 0.008845974524904574, 0.017319791251793504, 0.022401614813134074, 0.021925015208710517, 0.02915830198409302, 0.03589628364092537, 0.02580364520794579, 0.04219493083655834, 0.010593013056287808, 0.03552776448694723, 0.0501136855621423, 0.04113510663488081, 0.031558663717338016, 0.032068803307733366, 0.03438866364636591, 0.020774499712777988, 0.04279480668316994, 0.06770594763968672, 0.02289499289223126, 0.273944373109511, 4.134713172912598, 13.960581166403633, 32.31761414664132, 66.86853912898472, 70.1021682194301, 70.5096800667899, 66.37102726527623, 50.83053691046578, 47.081896918160574, 44.86013051441738, 37.11783272879464, 31.496528148651123, 28.293943609510148, 29.7400860786438, 48.58660922731672, 53.72681706292288, 42.30718517303467, 47.78365455354963, 47.75307900565011, 37.865191391536165, 22.925676788602555, 14.390728507723127, 5.610967831952231, 2.013235547712871, 0.8583266596708978, 0.7397047877311707, 0.43342200560229166, 0.5589867564184325, 0.6379235578434808, 1.2288957493645805, 1.6427641127790724, 2.098189434834889, 2.4841703346797397, 3.2493255053247725, 2.774611766849245, 3.2674255626542226, 4.602064209324973, 5.3156381249427795, 4.570505491324833, 3.43134029848235, 2.7081854684012274, 2.2426639795303345, 2.344234049320221, 2.9914029453481947, 0.4760140287024634, 0.004959573603368231, 0.26031046041420525, 0.11438885836728982, 1.014335811138153, 1.6870104585375105, 2.715309977531433, 4.8673981087548395, 5.9357670204980035, 6.417354047298431, 6.051248252391815, 5.421607272965567, 4.885415656226022, 4.799256256648472, 7.690900223595755, 7.8235057251794, 6.08275876726423, 4.596784446920667, 5.348363271781376, 4.738531172275543, 3.6000138989516666, 3.3934209389345984, 3.342279157468251, 2.204479068517685, 1.3605383826153619, 1.0189143483127867, 0.6658686697483063, 0.4391618418906416, 0.22275143010275705, 0.1702768565820796, 0.5598372593522072, 1.3191730422633035, 4.20544844014304, 9.24843100139073, 20.30846061025347, 26.14147159031459, 39.704973629542756, 57.562226159232004, 68.12561416625977, 68.56884670257568, 40.77362394332886, 27.334628411701747, 25.08746460505894, 32.541561535426546, 44.977607182094026, 49.866192953927175, 49.976641518729075, 58.792661803109304, 59.175597872052876, 60.108456066676546, 45.81110961096627, 26.573223965508596, 10.924528445516314, 1.344987011381558, 0.06393885692315442, 0.045017181895673275, 0.026994028028899004, 0.057596237265637944, 0.02408726543321141, 0.02961502390514527, 0.05875841847487858, 0.03665884504360812, 0.023069564685491577, 0.042851084377616644, 0.0317460275920374, 0.03909711313566991, 0.04254769101472838, 0.0201771276603852, 0.06532085633703641, 0.057276396213897636, 0.038836884777992964, 0.02172091187510107, 0.01593188858324928, 0.06090138812682458, 0.03374222333409956, 0.06153345028204577, 0.0347733794312392, 0.023256774193474224, 0.024715850096462027, 0.03169596188568643, 0.027733677000339543, 0.039722169416823556, 0.05445984145626426, 0.037131780558930974, 0.10073752089270524, 0.018172709770234566, 0.03568010916933417, 0.07301521274660315, 0.10558734993849482, 0.051585081964731216, 0.024056829744949937, 0.04325227499274271, 0.025669790604817014, 0.04293632873200944, 0.13104715091841562, 0.15561773175639765, 0.17005781190735952, 0.062074812661324225, 0.10666735377162695, 0.17861561769885675, 0.10960204486868211, 0.07423298632992165, 0.21103838219174317, 0.10653672899518694, 0.16400822438299656, 0.1332930882594415, 0.15550753766936914, 0.1662525875227792, 0.11493982880243234, 0.11776106884436947, 0.10654301222945962, 0.07799365810517754, 0.13627822164978298, 0.1081738236493298, 0.12916435194867, 0.10809744774763073, 0.06842313879834754, 0.10170283873698541, 0.14606102742254734, 0.11494312648262296, 0.11165972945413419, 0.23958040135247366, 0.09101171884685755, 0.16629975927727564, 0.13381543808749743, 0.12214159592986107, 0.09901425907654421, 0.1100645682641438, 0.10835586780948298, 0.23738677906138556, 0.2569153154534953, 0.7880219636218888, 6.308666850839343, 20.23087181363787, 42.17064264842442, 79.01763112204415, 82.07731206076485, 78.17269543239048, 74.03029755183628, 56.2594632421221, 54.27032252720424, 52.70041874476841, 45.77347469329834, 38.437716007232666, 32.7094578061785, 26.891020672661917, 45.56256559916905, 40.659374713897705, 39.32476472854614, 43.438282421657014, 40.93573236465454, 37.88101591382708, 26.731608152389526, 14.901652131761823, 5.548418845449175, 1.8638058517660414, 1.0887684971094131, 0.7492480842130524, 0.6444159437503133, 0.4115170495850699, 0.9452592091900962, 1.3232710680791309, 2.0918109885283878, 2.2457359518323625, 4.060007010187421, 4.502711049148014, 5.233387955597468, 6.134521543979645, 6.893895813396998, 9.811756202152797, 7.052649991852896, 5.9639202526637485, 5.855991278375898, 4.771172506468637, 4.115476650851114, 5.419499363218035, 0.7870241914476667, 0.17211058389927658, 0.515567517706326, 0.28113923275044983, 2.4029200545379092, 5.077182463237217, 6.305378181593759, 6.119984609740121, 8.099100811140877, 12.430884003639221, 10.931844898632594, 10.497045738356453, 12.516283443995885, 10.260901655469622, 10.63167837687901, 10.006035651479449, 8.432465825762067, 6.733478844165802, 6.494554613317762, 6.17568701505661, 4.5820177878652295, 3.242734487567629, 2.780264777796609, 2.7815150192805698, 1.4965281997408186, 1.4053837933710642, 0.4093945377639362, 0.6304389366081783, 0.3321395532361099, 0.5061869067805154, 0.6717614478298596, 1.9784328894955772, 4.891058896269117, 13.049157295908246, 28.27946182659694, 36.66249990463257, 56.69384377343314, 77.50891317640031, 84.77693040030343, 83.00229099818638, 46.642155851636616, 31.775901317596436, 28.713243075779506, 41.00730923243931, 46.837674685886924, 53.4643349647522, 56.1562442779541, 70.54610252380371, 67.68414647238595, 69.32990373883928, 56.43111848831177, 37.40558195114136, 16.57428503036499, 2.8111610284873416, 0.2644291679774012, 0.23033495460237774, 0.10339512542954513, 0.22161449039621012, 0.1237547043710947, 0.12177720905414649, 0.16822051549596445, 0.13020511610167368, 0.18359735395227159, 0.10665359986679894, 0.08539571519941092, 0.31910503123487743, 0.16921337507665157, 0.155123554702316, 0.16862891215298856, 0.1432590034923383, 0.11791782400437764, 0.07735646622521536, 0.15966479959232466, 0.13104472176304885, 0.16626888593392714, 0.1340168815638338, 0.096471584801163, 0.13034640066325665, 0.06818928848952055, 0.07283820331628833, 0.09006358829459973, 0.13109342700668744, 0.17965182209653513, 0.1057742659800819, 0.25334057584404945, 0.09237993721451078, 0.07616247529430048, 0.17433099475290093, 0.21178255868809565, 0.13562408675040516, 0.05564449913799763, 0.0625937765996371, 0.2529660516551563, 0.1393843378339495], [0.058256092215222974, 0.024691259987386208, 0.049452772097928185, 0.06554438612822976, 0.02520041061299188, 0.03569819552025624, 0.027585427276790142, 0.04050053050741553, 0.021516241964751055, 0.01500391900273306, 0.04069083922409585, 0.043925815993653874, 0.07309859112969466, 0.03757684524836285, 0.04298919000263725, 0.013029717125131615, 0.05471541167103818, 0.03899697493761778, 0.01583058839397771, 0.008564005057061357, 0.019584174567301358, 0.03299697135974254, 0.0583685322531632, 0.06357639030154262, 0.025727011462939636, 0.020102617729987417, 0.07299707550555468, 0.006498294674591827, 0.02288954595236906, 0.06558342903320279, 0.03304156128849302, 0.00608103465388662, 0.03466490882315806, 0.019513238820114305, 0.04377354255744389, 0.04737592568354947, 0.22045600041747093, 0.6959830852491515, 6.380749634334019, 23.689570426940918, 51.48607165472848, 66.92900235312325, 58.85366003853934, 51.9759578704834, 43.74829714638846, 42.179616246904644, 41.859721183776855, 27.849677528653825, 27.345907075064524, 20.881419488361903, 33.8091596194676, 34.309885025024414, 29.57715776988438, 38.79813296454293, 40.856877258845735, 33.6947158404759, 15.929945571081978, 11.149496350969587, 4.539794887815203, 2.104700982570648, 0.5725155504686492, 0.24225342220493726, 0.06718925000833613, 0.15214304892080172, 0.4458820255739348, 0.7365006910903114, 0.11328494296010051, 1.3092011830636432, 1.0252317807504108, 2.0084688663482666, 1.9241385800497872, 2.9974296391010284, 3.1410647545542036, 2.6404648508344377, 2.7410506648676733, 2.4671389971460616, 2.666189036199025, 1.0775919939790453, 0.6328219515936715, 1.9651032047612327, 0.38654033839702606, 0.6378160778965268, 0.26507315199290005, 0.12182799061494214, 0.057075624487229755, 0.1208789236843586, 0.4279345843408789, 1.1888545836721147, 2.5258823250021254, 3.852208971977234, 2.6195507730756487, 1.4833842707531792, 4.454066710812705, 3.7898215310914174, 2.789189304624285, 1.7042696752718516, 7.5896588904517035, 4.439702613013131, 6.549203932285309, 3.7008055533681596, 3.9149889860834395, 2.3313156110899786, 2.899786170039858, 2.965046908174242, 2.856990477868489, 1.6890353155987603, 1.640575647354126, 0.7676527223416737, 0.36245400086045265, 0.6376917702811105, 0.12941143369036062, 0.1442881646965231, 0.012536485779232212, 0.10228951368480921, 0.5912406742572784, 1.7813486478158405, 5.134013516562326, 14.464672105652944, 32.8726293018886, 40.698965549468994, 50.911132540021626, 52.63206236703055, 27.647908789770945, 19.859768526894705, 22.25563767978123, 24.504097325461252, 26.42429106576102, 27.145746844155447, 44.48810659136091, 48.864714350019185, 49.501499380384175, 53.778674943106516, 49.70554712840489, 39.90571403503418, 22.575475420270646, 7.819420184407916, 0.9648168683052063, 0.01024192716327629, 0.03183320577123335, 0.08406996633857489, 0.01667070634929197, 0.06179548693554742, 0.0470155014523438, 0.026499788210328137, 0.04752866391624723, 0.07077765531305756, 0.03772913904062339, 0.0398524243916784, 0.1701616956187146, 0.007412369978348059, 0.01606663885260267, 0.04254315500812871, 0.05033797870523163, 0.041864803193935325, 0.008401842821123344, 0.022102944053975598, 0.035237205613936694, 0.04121504484542778, 0.005866121409261333, 0.04398455677021827, 0.05421000146972282, 0.039944562661860666, 0.023892922825845223, 0.018948098877444863, 0.02963357505255512, 0.036914662923663855, 0.0209574581988688, 0.06319107740585293, 0.021011866529339125, 0.054252426871763806, 0.043556808294462304, 0.07148808147758245, 0.0643003803810903, 0.06109190718936069, 0.046100710718227286, 0.04417490280632462, 0.04168119840323925, 0.017258351602192436, 0.03808321218405451, 0.03071050512205277, 0.023413017059543302, 0.034698598086833954, 0.03501191163169486, 0.021070734531219517, 0.049853742189173184, 0.017970979612852846, 0.018548170337453485, 0.007262866661351706, 0.03734801609867385, 0.027363632838906984, 0.02763483819684812, 0.023704761672498922, 0.014665567515684026, 0.06405035379741873, 0.01981987727672926, 0.021108701958187988, 0.011727754309374307, 0.04037687089294195, 0.041914957109838724, 0.0388472052956266, 0.0358017365714269, 0.12419218303901808, 0.02292893999921424, 0.0463854036560016, 0.016144434588828256, 0.022581416415050626, 0.04567184605236564, 0.029923309505517994, 0.013404963953819658, 0.018794517564986433, 0.03618044053603496, 0.11497237134192671, 0.16996790601738862, 1.2351659557649066, 6.91933707680021, 27.72602912357875, 54.39208970751081, 75.84421512058803, 69.91881220681327, 64.86711052485875, 54.01889501299177, 53.58145032610212, 48.71670729773385, 38.86644765308925, 38.45892538343157, 30.805515902382986, 39.95463630131313, 33.10529667990548, 30.009474686213903, 32.21457930973598, 36.785361426217214, 33.95823322023664, 18.605679477964127, 15.665408543178014, 7.859421832220895, 3.244339087179729, 0.7629458063415119, 0.3879103548824787, 0.4062965911413942, 0.44924492655055864, 0.7446813806891441, 1.1011369419949395, 2.3464572557381222, 3.148975278650011, 4.08681229182652, 5.318970220429557, 5.761122311864581, 5.993484403405871, 6.450897778783526, 6.847492703369685, 7.636474984032767, 7.809933287756784, 5.186345177037375, 5.815608782427652, 3.268617178712572, 4.63139602967671, 2.3179131874016354, 2.000831493309566, 0.07420596028012888, 0.1049153899241771, 0.15124791195350035, 0.08901261897491557, 0.13238569694970334, 0.6269512666123254, 2.391981852906091, 5.115069687366486, 5.462006705147879, 7.597780466079712, 6.195571890899113, 7.1464806369372775, 7.939800330570765, 7.549016271318708, 5.69424546616418, 9.140571509088788, 9.080991574696132, 4.907505716596331, 4.810964405536652, 4.7764648624828885, 4.446500991071973, 5.762993114335196, 5.6594328199114114, 3.634499328477042, 3.4728173528398787, 2.115051192896707, 1.4369002793516432, 0.6590388076645988, 0.3311614314360278, 0.30705940616982325, 0.44095583419714657, 0.2444116249680519, 0.6253491097262928, 2.0153232642582486, 5.854553869792393, 14.22737635884966, 35.375328745160786, 48.81841502870832, 63.413283348083496, 65.07744639260429, 34.050116198403494, 26.054674693516322, 25.619335310799734, 32.035770893096924, 32.83430651256016, 31.36448458262852, 48.70022964477539, 58.70098727090018, 55.89241075515747, 60.47669669560024, 56.70605870655605, 47.53322063173567, 26.026418106896536, 9.096040504319326, 1.2813639853681837, 0.02228500517750425, 0.0373493460273104, 0.03618080015959484, 0.05214066304532545, 0.0670187748702509, 0.05419257329776883, 0.011984539950000388, 0.06168114699955497, 0.03518029348924756, 0.006880594026629946, 0.020741858785705905, 0.0328816237992474, 0.027206870893548642, 0.027686523905556117, 0.06251453728015934, 0.04410495602392724, 0.026662139587902596, 0.012121012001963598, 0.006033048657367804, 0.03177025129220315, 0.03452144616416522, 0.01816004661044904, 0.03180515852623752, 0.04195993041087474, 0.021320491397221173, 0.03763124340080789, 0.011870084663054772, 0.02056920385387327, 0.047785998322069645, 0.03027085174939462, 0.024954711386401738, 0.033696452754416635, 0.017705005759905492, 0.007427231591594006, 0.08077356179377862, 0.006014346111831921, 0.07319562842271157, 0.0471076261518257, 0.039921271947345564, 0.2575794383883476, 0.07779990243060247, 0.09360577857920102, 0.16152897956115858, 0.1203825074647154, 0.09435979383332388, 0.13688276920999798, 0.1071368253656796, 0.1812081371567079, 0.10488266418022768, 0.11210804432630539, 0.11911630683711597, 0.17409512240971836, 0.13205253625554697, 0.127556726070387, 0.11096189011420522, 0.1465774875666414, 0.11803557697151389, 0.07259819190949202, 0.10298467281141452, 0.10753412797514882, 0.145689081666725, 0.1072721795311996, 0.13881360845906393, 0.21871904576463358, 0.15970999002456665, 0.14916802570223808, 0.2050853773419346, 0.10314127190836839, 0.12794602875198635, 0.18588407124791825, 0.11531614432377474, 0.12862598869417394, 0.1365735743727003, 0.14509617776743003, 0.16120951170367853, 0.5963946634105274, 1.9506876468658447, 10.952827589852468, 35.86251558576311, 69.54312310900006, 85.309891973223, 78.84753227233887, 74.5271006992885, 60.93160220554897, 57.60039956229073, 54.78862687519619, 42.138121604919434, 43.38283927100045, 33.75377900259835, 48.60747119358608, 47.173043387276785, 43.61918919427054, 50.77219288689749, 52.18245833260672, 44.594320229121614, 22.825482027871267, 15.96786710194179, 7.0639959658895215, 3.1008338161877225, 1.1893419346639087, 0.817983084491321, 0.5813128384096282, 0.6624336540699005, 0.6650536677667073, 2.284463256597519, 1.98652298109872, 2.6008212523800984, 4.127390205860138, 5.691033227103097, 5.690375753811427, 7.8727163416998724, 9.344771248953682, 9.18618209021432, 8.259046605655126, 10.86527247088296, 8.318651727267675, 9.25146996974945, 4.7884361743927, 4.227806006159101, 3.039808873619352, 4.356803221361978, 1.429907894560269, 0.1606589483895472, 0.3577805502074105, 0.2316553294658661, 2.521803081035614, 7.465960110936846, 9.489926065717425, 12.595538939748492, 10.64293532712119, 8.741371444293431, 12.070394090243749, 9.288622856140137, 13.92190488747188, 10.481156945228577, 18.736342089516775, 11.317213705607823, 14.297685180391584, 13.405186465808324, 7.761358431407383, 8.548295770372663, 10.210705263274056, 10.570471695491246, 8.445749044418335, 6.08938387462071, 5.906873805182321, 1.8769505407129015, 1.660987826330321, 0.949555150100163, 0.2407516342188631, 0.23465963825583458, 0.36364450412137167, 0.53089839220047, 0.7119708359241486, 2.3264546947819844, 6.215301735060556, 17.529695340565272, 37.1262400490897, 47.03821011951992, 60.50698389325823, 62.47071852002825, 39.76951892035348, 29.292774949754985, 32.865232944488525, 34.632628849574495, 37.45055416652134, 38.88540581294468, 57.66179731913975, 63.19709014892578, 62.2418657030378, 70.0060954775129, 63.726501192365376, 53.41208798544747, 33.007563318525044, 15.043089662279401, 2.6286959052085876, 0.09201329081718411, 0.12406655906566552, 0.24036587349006108, 0.1282865990485464, 0.16193806832390173, 0.21082650284682, 0.161634695317064, 0.18342572530465467, 0.1316276647682701, 0.14263088362557547, 0.11168371566704341, 0.23434346807854517, 0.08426277206412383, 0.06705388905746595, 0.15360956665660652, 0.1781751127647502, 0.17718413951141493, 0.1833576818129846, 0.09827642009726592, 0.10806968888001782, 0.13034188162003243, 0.12993462490183966, 0.11462505640728132, 0.16223404529903615, 0.08366398526621716, 0.08347599713930062, 0.07574321529162781, 0.09880912436970643, 0.15166960789688996, 0.09805746363209826, 0.10982383082487754, 0.12817356868513993, 0.07358320762536355, 0.07553739526442119, 0.10934948734939098, 0.06708611947085176, 0.16473747310893877, 0.09311430887984377, 0.11689396894403867], [0.05598832979532225, 0.05081744512010898, 0.039199687274438996, 0.06514829131109373, 0.008956456989316004, 0.022823093625317727, 0.040711632929742336, 0.042839074307786565, 0.042369982693344355, 0.016225519523556744, 0.03252666856029204, 0.04860363980489118, 0.0635453744658402, 0.06548116702054228, 0.04181965686646955, 0.05917134774582727, 0.020418521582282016, 0.052873392655913315, 0.039165804628282785, 0.011603191395157149, 0.02714653216701533, 0.03338045560355697, 0.023669070730518018, 0.031132173924041644, 0.04684909073902028, 0.010685150478301304, 0.06453370821795293, 0.028539827492620264, 0.04863661660679749, 0.024948536717732037, 0.026037458197346756, 0.05848030732678516, 0.09272027002381426, 0.04158171499148011, 0.013354809189747487, 0.1158999287124191, 0.6743535601666996, 2.792582631111145, 18.068024396896362, 34.91741813932146, 56.3295636177063, 59.399218695504324, 54.683396407536094, 47.64537845339094, 39.33010789326259, 31.36268847329276, 26.918083906173706, 30.26207992008754, 23.351891449519567, 35.242232527051655, 26.090688943862915, 41.75609574999128, 48.28752054486956, 47.28210578645979, 37.12582663127354, 24.8709066254752, 13.994980829102651, 5.680144531386239, 2.1001292850290025, 0.8846081665584019, 0.13880790876490728, 0.17535461911133357, 0.29363279949341503, 0.8027130610176495, 0.7180114260741642, 0.855226351746491, 2.2182610375540595, 4.064183311803, 4.1332427603857855, 4.7403377039091925, 4.652426489761897, 3.863327826772417, 4.2554459401539395, 2.976075219256537, 6.509894498756953, 6.27843393598284, 3.9587617686816623, 4.575515576771327, 2.4272854328155518, 3.9968834945133755, 1.684535162789481, 2.706730906452451, 0.30827732224549564, 0.04316534447882857, 0.07687146296458584, 0.08155492879450321, 0.41300393694213455, 0.023323781222903302, 0.2982603811791965, 3.097429198878152, 6.064690411090851, 6.261491187981196, 3.331760887588773, 5.4457800558635165, 3.224064460822514, 5.173815837928227, 6.35751485824585, 12.020807402474539, 6.359705712114062, 1.543945963893618, 4.37898143700191, 4.47476669720241, 4.354529423373086, 4.2461284058434625, 4.929746900285993, 3.3885919409138814, 1.488750125680651, 1.5250938726322991, 2.746304154396057, 0.5205424278974533, 0.911567394222532, 0.33890929711716516, 0.3534542923527104, 0.06826266526643719, 0.21653557435742446, 0.19593421981803008, 1.2375857744898116, 2.9547670483589172, 10.430028625896998, 14.530830247061592, 21.757349354880198, 24.570812191282, 30.46473455429077, 33.319408893585205, 39.24733052934919, 18.65092441013881, 23.182708024978638, 33.893423897879465, 31.03668941770281, 38.34541961124965, 51.24470165797642, 50.01184804098946, 51.36784110750471, 48.98026636668614, 41.161930969783235, 19.229561703545706, 4.661224211965289, 0.3512486464210919, 0.034716263746044466, 0.03154661972075701, 0.022351817128115466, 0.10192980870072331, 0.02857342854674373, 0.011842225711526615, 0.0643789954483509, 0.03484432366011398, 0.011999862118890243, 0.032134068198502064, 0.021623314790693775, 0.048624009426151, 0.08391680741416556, 0.018800485280475447, 0.02541168775808598, 0.02647134741502149, 0.008741628561568047, 0.05869806278496981, 0.027703253186440895, 0.060014644637703896, 0.029676485607134442, 0.026825459574216177, 0.040119217575660775, 0.028477700826312815, 0.014582346891984344, 0.017035951571805135, 0.01132178002236677, 0.08336963677512747, 0.03851590718009642, 0.026201661975522126, 0.023722461258460368, 0.007564930943772197, 0.019191867671906948, 0.03499236982315779, 0.060630964780492444, 0.028780656534114053, 0.028263694274106195, 0.048784537240862846, 0.022831699145691733, 0.03576631365077836, 0.012994407010929925, 0.06457243899681739, 0.039496848293180974, 0.0338147994396942, 0.12292326827134405, 0.008390752166243536, 0.034064934588968754, 0.03524968048025455, 0.04036821617877909, 0.026256965972217064, 0.029876819678715298, 0.06454922631382942, 0.055239230527409484, 0.0316931629287345, 0.02268139855004847, 0.04329549767343061, 0.02737640286795795, 0.03898644068145326, 0.04403914151979344, 0.007460165985061654, 0.01715316340726401, 0.06681309055004801, 0.05671219095321638, 0.019596690145720328, 0.07707943394780159, 0.05291374513347234, 0.04301732545718551, 0.00828089056137417, 0.051124383828469684, 0.070971716328391, 0.07272665894457273, 0.02783503825776279, 0.020214772783219814, 0.08588327653706074, 0.8458796675716127, 2.4777263147490363, 18.227641889027186, 38.63096972874233, 66.51612649645124, 70.13784721919468, 66.1028893334525, 58.436920983450754, 47.811013085501536, 38.29933568409511, 36.7026743888855, 33.956982544490266, 25.673498255865915, 32.01720878056118, 30.675101688929967, 41.7311760357448, 53.078063760484966, 47.4358937399728, 34.95778717313494, 24.034197602953228, 13.035895790372576, 5.843766791479928, 1.8767253756523132, 0.9876650422811508, 0.21863511098282679, 0.43681421929172104, 0.6549480557441711, 1.0996168064219611, 1.420562458889825, 3.8030878135136197, 2.5848028319222585, 6.1293724945613315, 4.539429673126765, 7.70780953339168, 8.036945700645447, 8.054692268371582, 7.08126962184906, 8.917098334857396, 9.679579751832144, 8.35832941532135, 9.323543633733477, 7.769275035176959, 4.313741326332092, 4.906553813389369, 2.6141483315399716, 1.1280657712902342, 0.20327983636941227, 0.0226818362051355, 0.0932803667549576, 0.14392266502337797, 0.22472892541970524, 0.6118209670696939, 2.799541251999991, 5.516665143626077, 5.066022787775312, 5.639013367039817, 8.915508934429713, 7.293200969696045, 7.9762531859534125, 7.731509838785444, 5.703202562672751, 10.045679467064993, 8.737876500402178, 6.812558897903987, 9.44563911642347, 8.661472371646337, 5.163207241467067, 6.597314127853938, 9.231133460998535, 4.87051567861012, 4.114717560155051, 4.344941343579974, 4.166385667664664, 2.583116590976715, 1.8353599267346519, 0.5746226459741592, 0.5903475593243326, 0.19888466649821826, 0.5762344651988575, 0.2108589368207114, 1.2347991125924247, 3.84914915902274, 12.10895311832428, 17.671323946544103, 27.442191737038748, 30.213011741638184, 34.776202951158794, 29.97392075402396, 34.48939520972115, 21.760264124189103, 24.80879841532026, 35.72757462092808, 39.65266759055001, 46.74943256378174, 54.93020336968558, 56.972921643938335, 59.46683161599295, 55.3068756375994, 45.526452336992534, 23.24955838067191, 5.374628330980029, 0.3876886639211859, 0.08412973170301744, 0.05619215153689895, 0.033815976697951555, 0.07892422138580255, 0.005651876945713801, 0.06443260650017432, 0.039075237166668685, 0.027415096327396374, 0.03177326398768595, 0.03233976269673024, 0.040620166409228525, 0.013218597525597682, 0.0653609713273389, 0.032624489561255486, 0.052593697128551345, 0.01071610439768327, 0.012896271339351577, 0.003754080655718488, 0.05819205208016293, 0.016020849613206725, 0.034267110883125236, 0.022538570321298072, 0.021456213667988777, 0.021839584257187586, 0.013110331326190914, 0.07592175142573458, 0.05493470401104007, 0.03871306570779, 0.06779824875827346, 0.05506142042577267, 0.00607941931645785, 0.03911418168406401, 0.033323869175676785, 0.07645400786506278, 0.004921470469396029, 0.057765911732401164, 0.013697201352832573, 0.06960471253842115, 0.19001151834215435, 0.10511347465217113, 0.13863397309822695, 0.13340060891849653, 0.11228824965655804, 0.11807513556310109, 0.21371115877160005, 0.10783510575337069, 0.11286789498158864, 0.1061904454337699, 0.1003279300140483, 0.14431609319789068, 0.10652883084756987, 0.13273791090718337, 0.19195629470050335, 0.08542429509439639, 0.07819290991340365, 0.10259106821779694, 0.2129022093223674, 0.11467076252613749, 0.0917413950498615, 0.12091693521610328, 0.07924351960952793, 0.14183709264865943, 0.14718873905284063, 0.05988957027771643, 0.2224809524736234, 0.141196216323546, 0.13622020690568856, 0.09281440318695136, 0.16422509774565697, 0.32137440517544746, 0.1973939114915473, 0.1407252587378025, 0.14941598953945295, 0.2922440825828484, 1.0879956185817719, 6.4848471113613675, 26.43678740092686, 50.17163923808506, 75.44467285701207, 82.20704882485526, 76.73977538517543, 67.31835855756486, 57.26213346208845, 43.939786025456016, 40.682414940425325, 43.25592000143868, 33.586653981889995, 47.7663813318525, 37.74632508414132, 54.72562061037336, 62.460490771702354, 60.98390129634312, 46.30547741481236, 31.048525674002512, 17.880772181919642, 7.480109248842512, 2.619871041604451, 1.467447817325592, 0.44807619069303783, 0.5281972257154328, 0.6624780574015209, 2.813111735241754, 2.885015602622713, 4.712839339460645, 5.681168956415994, 11.935253364699227, 8.745954649788992, 13.728778839111328, 13.605945110321045, 12.16919834273202, 11.569015554019384, 13.84022273336138, 17.977249656404766, 13.058947307722908, 14.838934217180524, 12.655356849942889, 7.627429297992161, 12.30538216659001, 9.999884758676801, 4.913301382746015, 1.6169761994055338, 0.06493447135601725, 0.39039213742528645, 0.26892492387975964, 0.9526097519057137, 1.7247436280761446, 8.771383319582258, 9.71117581639971, 14.517466255596705, 15.966946465628487, 16.878390312194824, 16.27621599606105, 13.296133620398384, 15.491736582347325, 15.221277952194214, 25.421521833964757, 16.278571435383387, 10.882269501686096, 15.251483508518763, 15.368063858577184, 10.204413669449941, 13.611577493803841, 15.131536756243024, 7.812466774668012, 7.399275643484933, 8.263806121689932, 6.107170828751155, 2.82064271398953, 2.973324166876929, 0.8064359383923667, 0.9229640683957508, 0.23505815544298717, 0.6951356764350618, 0.2330129694725786, 1.7543776950665881, 3.4981470108032227, 12.753802401678902, 19.821661131722585, 31.967497893742152, 36.050245489392964, 41.36844880240304, 44.71444763456072, 52.72405651637486, 28.460891451154435, 33.71386160169329, 44.86335447856358, 42.493007796151296, 52.01589264188494, 65.57655634198869, 64.01856872013637, 66.84312956673759, 66.28946931021554, 57.24509647914341, 30.653874942234584, 7.944742236818586, 1.0576917018209184, 0.17479444774133818, 0.28106638523084776, 0.13562024624219962, 0.23362362384796143, 0.11155081779829093, 0.24655167013406754, 0.12333889811166696, 0.11471942705767495, 0.13780882023274899, 0.14482004115624086, 0.11940993608108588, 0.1617153731307813, 0.15579689214272158, 0.10726196757916893, 0.19952215014823846, 0.10664564743638039, 0.17466442686106476, 0.09222542122006416, 0.11785999925008842, 0.1178569458425045, 0.13044219623718942, 0.11379782722464629, 0.06867750800613846, 0.14757132423775537, 0.1542910329465355, 0.15491215033190592, 0.13601311801799706, 0.16937941259571485, 0.19327495965574468, 0.1448368823954037, 0.07533886948866503, 0.12605858860271318, 0.18715917425496237, 0.22757499984332494, 0.1401036392365183, 0.19787754411143915, 0.11966277179973465, 0.14836107114596025], [0.06187005793409688, 0.06601647686745439, 0.04222833172285131, 0.03460396959313324, 0.051270675978490284, 0.039875212990279706, 0.010666111633846802, 0.024132467739816223, 0.13757233720804962, 0.0201763744865145, 0.043290527404419014, 0.06647874920495919, 0.01749752162556563, 0.03934742809672441, 0.03439553381342973, 0.010912393552384205, 0.029532724392733405, 0.07318642070250851, 0.05827422945627144, 0.0344125684350729, 0.013005957373284867, 0.03225216382582273, 0.0033117271377705038, 0.09594291102673326, 0.031236698850989342, 0.038300373924097846, 0.020037524169310927, 0.027064936634685312, 0.04633146012201905, 0.04400613757648638, 0.028924254900110618, 0.049024236521550586, 0.04102659870737365, 0.03356361934649093, 0.05384273760552917, 0.3503447292106492, 1.1410963577883584, 14.61128864969526, 25.582888535090856, 41.40240117481777, 56.790802410670686, 60.35404709407261, 53.28685712814331, 48.751889501299175, 43.31074128832136, 46.06676162992205, 28.61276865005493, 22.682072946003505, 29.995102337428502, 77.15823759351457, 80.17437417166573, 62.58976200648716, 40.0260603087289, 24.795675005231583, 17.554962464741298, 10.635596292359487, 3.067282919372831, 0.9954665665115628, 0.06063336679445846, 0.10415979368346077, 0.133377484445061, 0.5484620268855775, 0.9838444015809468, 0.24183167197874614, 1.7380987171615874, 2.0119627245834897, 2.1399791581290106, 4.315373718738556, 3.7695236716951643, 6.062739270074027, 8.764247519629341, 7.570110133716038, 6.971343908991132, 7.764622347695487, 9.659758278301783, 5.684850633144379, 6.3293286221367975, 6.328176089695521, 2.0865088616098677, 3.296800374984741, 0.7156277054122516, 1.0584249539034707, 0.10179354529827833, 0.25286953683410374, 0.06727640783148152, 0.07374981511384249, 0.06711604965052434, 0.17830756280039037, 1.1627632294382368, 3.1441182707037245, 2.391227973358972, 6.489235767296382, 4.438635630267007, 7.215497962066105, 7.1401590790067395, 6.63179977451052, 1.745763014469828, 5.318030910832541, 7.318453328950064, 3.950342289039067, 4.643293516976493, 3.4770583595548357, 3.360682329961232, 2.971432085548128, 6.5285786390304565, 4.573190535817828, 3.7629541499274115, 4.261230315480914, 2.1223793710981096, 2.655880297933306, 1.1122865208557673, 1.0658254367964608, 0.4388666520161288, 0.3149229756423405, 0.1273666548409632, 0.11641041774834905, 0.03118257550522685, 0.39552237785288263, 3.0416833673204695, 11.891751561846052, 24.321715797696793, 39.369038649967735, 39.988401072365896, 46.643722670418875, 27.5114027432033, 25.36098391669137, 25.63134353501456, 18.879155363355363, 24.84922824587141, 39.131524903433665, 44.27414376395089, 47.482290336063926, 57.11552994591849, 54.20167779922485, 48.57384538650513, 35.55804552350725, 11.122935993330819, 3.6671467423439026, 0.16135819229696477, 0.06044505975608315, 0.04372148535081318, 0.02139592413524432, 0.011979455178204392, 0.03189850798142808, 0.05094064672344497, 0.010685105525356318, 0.03196099087862032, 0.032539496264819584, 0.09514202935887234, 0.04050363141245075, 0.06779322759913546, 0.025908692606857846, 0.03716067936537521, 0.06664353821958814, 0.01578973380050489, 0.024377496913075447, 0.08083141368946858, 0.02190579740064485, 0.07702371943742037, 0.026172040529283028, 0.0264859240435596, 0.04648730604510222, 0.034533558014248095, 0.04487285749720676, 0.0410055403730699, 0.08646102196403913, 0.02251994453503617, 0.008706079263772284, 0.05406472372955509, 0.03581896457555039, 0.03768718182774527, 0.05052905077380793, 0.04055272342104997, 0.09142650730375733, 0.004298274222362254, 0.05099147238901683, 0.01574343057083232, 0.034921595228037665, 0.04401086696556636, 0.04633303771593741, 0.04454052122309804, 0.04683455651892083, 0.02038132429255971, 0.02427816447535796, 0.020885063601391654, 0.030483223032206297, 0.0809623302359666, 0.04500052046829036, 0.02489252365194261, 0.009608683508953877, 0.045488292151795964, 0.05709508487156459, 0.03321763773315719, 0.0583650174417666, 0.028334421371775012, 0.024255284274529134, 0.04192886707772102, 0.03186515459258642, 0.05962544373635735, 0.07626165675797633, 0.03153456893882581, 0.04834669216402939, 0.014843034957136427, 0.058480212331882546, 0.032904900943062136, 0.0512625844483929, 0.023934391493509923, 0.05683350283652544, 0.014301236619108489, 0.036416669110102315, 0.005327273426311356, 0.507655745106084, 1.7898851611784525, 14.176849927221026, 28.835739816938126, 47.6132048198155, 65.24920586177281, 72.59535557883126, 64.65104239327567, 57.00351108823504, 52.04019396645682, 49.92629139763968, 35.65759931291853, 32.180255208696636, 36.47006607055664, 80.8872662952968, 67.9772423335484, 53.28275074277605, 37.99208981650216, 24.819955485207693, 21.067169155393326, 11.634627393313817, 4.154229359967368, 0.9953080607312066, 0.47331307934863226, 0.2430887259542942, 0.5003363607185227, 1.4268852110419954, 2.52352797133582, 2.9805889427661896, 4.5854271820613315, 4.596879116126469, 7.012556280408587, 7.104781891618456, 8.534211771828787, 9.926365869385855, 9.017140235219683, 7.9878957612173895, 6.2891068032809665, 7.75580768925803, 10.63319742679596, 7.734697324889047, 5.974712107862745, 5.327265501022339, 4.679929631096976, 5.190252235957554, 1.6601800982441222, 1.085569937314306, 0.17327691774283135, 0.3006362036934921, 0.14890288135835103, 0.015661212482622693, 0.07096643732594592, 0.38071280824286596, 1.8804652435438973, 2.763138336794717, 2.0282688438892365, 6.247423257146563, 6.444136313029698, 7.439752374376569, 4.403737434319087, 3.7977802583149503, 5.455824545451573, 5.672289592879159, 7.798966424805777, 6.8136167611394605, 7.908054879733494, 8.845623084477015, 7.011495811598642, 6.6825889348983765, 8.950903058052063, 6.528360639299665, 6.847536563873291, 5.817024477890559, 4.599232384136744, 4.450438448360988, 4.2291231240544995, 3.4255706880773817, 1.496638719524656, 0.8023107168929917, 0.37202612150992664, 0.1604078361498458, 0.10921372606285981, 0.6967185629265649, 3.901410903249468, 11.072977576936994, 22.02481852258955, 32.35465151923043, 33.84187173843384, 43.47737298692976, 30.759550094604492, 25.89902809688023, 31.112216336386545, 28.245102984564646, 32.31730147770473, 43.73580428532192, 52.11572783333914, 56.5043386050633, 63.29999297005789, 62.956154414585654, 57.21587930406843, 41.51442003250122, 13.549823641777039, 4.099069782665797, 0.24912711765084947, 0.08702816867402621, 0.01748171684864376, 0.05156723310106567, 0.02182643933753882, 0.005925634867578212, 0.021698158899588243, 0.015093053059120263, 0.021285896289295385, 0.03526094416156411, 0.05306516022288373, 0.01990692992694676, 0.07693145224558455, 0.00882064990167107, 0.06467736765210118, 0.04198042216843792, 0.05399066163226962, 0.08533700156424727, 0.03821164868505938, 0.023426485979663472, 0.08340786543807813, 0.03233778137447579, 0.01607124780171684, 0.019861452813659395, 0.024471010913008025, 0.05171048541420272, 0.04113266390881368, 0.03814574257869806, 0.015370399158980166, 0.026060452052791203, 0.053889872040599585, 0.023035096802881787, 0.04604429731677685, 0.017864056064614227, 0.07143618711935622, 0.07138429276113, 0.03221105817439301, 0.0772122639630522, 0.10296597917165075, 0.06399335007050208, 0.10553402387137924, 0.1928824542888573, 0.12383148739380495, 0.11071923920618636, 0.15520793731723512, 0.11875072573976857, 0.11344160312520606, 0.09484641879264798, 0.1875439171812364, 0.1012960502079555, 0.12401436615203108, 0.11008438827203852, 0.13231791130134038, 0.15083906746336392, 0.09421837356473718, 0.19785345611827715, 0.1745073731456484, 0.18974067430411065, 0.10694052518478461, 0.087422872494374, 0.120755226750459, 0.21887919359973498, 0.17440770992210933, 0.18342698737978935, 0.0782095000946096, 0.14334357609706266, 0.20193744982991899, 0.1976791133305856, 0.12687122928244726, 0.14459248765238694, 0.13966450494314941, 0.11920416355133057, 0.17753689629690989, 0.8967766878860337, 3.1036778007234846, 21.503694943019322, 37.96594027110508, 60.04248986925398, 76.10786451612199, 82.96303367614746, 72.75301020486015, 65.36659567696708, 57.97311135700771, 61.58969388689314, 42.30804327556065, 37.34404523032052, 41.732319014413015, 88.19630568368095, 90.24195262363979, 73.81957953316825, 50.220047337668284, 32.298489230019705, 23.093105792999268, 14.663111788885933, 4.170909379209791, 1.3540633129222053, 0.48583927005529404, 0.4330142874802862, 0.43388563500983374, 1.4748760930129459, 3.803611533982413, 2.134299657174519, 6.227975249290466, 6.457228890487126, 10.145885518618993, 12.484087228775024, 14.860923528671265, 16.669793231146677, 19.65952491760254, 17.626867634909495, 16.14618567058018, 17.259087324142456, 20.24600499016898, 16.196792875017437, 15.047906500952584, 18.873435258865356, 8.822502085140773, 10.991457836968557, 8.483231101717267, 2.627662794930594, 0.7383974950228418, 0.6324779614806175, 0.24049012682267598, 0.2980218896908419, 0.3538671944822584, 0.6815325149468013, 4.470717634473528, 11.995716588837759, 10.198419979640416, 13.007245762007576, 12.778326068605695, 16.486789839608328, 16.12571280343192, 17.468266316822596, 12.43455352102007, 18.156349897384644, 21.452227899006434, 11.334940297263008, 14.562619124140058, 12.597340260233198, 13.96171806539808, 13.02776118687221, 16.64653066226414, 15.176465545381818, 10.924176692962646, 11.188359362738472, 8.214111736842565, 5.455318629741669, 4.811569333076477, 4.2824292693819315, 1.7254102208784647, 1.3492989114352634, 0.2661078907549381, 0.328745466790029, 0.1541700501527105, 0.9046150158558572, 4.157390790326255, 14.826095683234078, 28.467045818056377, 49.36023555483137, 51.94389540808541, 62.49225793566023, 39.512220178331646, 35.68281085150582, 36.641582352774485, 28.61255325589861, 35.139430454799104, 50.60513734817505, 56.415356499808176, 61.26181534358433, 73.42689514160156, 71.21665927342006, 65.50282900674003, 50.30735492706299, 19.71671380315508, 6.377568227904184, 0.4553453634892191, 0.14401115956051008, 0.1286043162856783, 0.07758374152971165, 0.08919719407068831, 0.12005824915000371, 0.13149403408169746, 0.10530642965542418, 0.15064145092453274, 0.12550404907337256, 0.22871021607092448, 0.12876103073358536, 0.14532173637832912, 0.11390347512704985, 0.24521338194608688, 0.18024251397166932, 0.1401064076593944, 0.16627398851726735, 0.10992822343749659, 0.16577959433197975, 0.12872911244630814, 0.1296638080051967, 0.07366453683269875, 0.19015705053295406, 0.16764667843069347, 0.19090703528906616, 0.08122243306466512, 0.13323811335223062, 0.11783615552953311, 0.13311204154576572, 0.16798015125095844, 0.09819756754274879, 0.16363881634814398, 0.17548690629856928, 0.10556664104972567, 0.20700876627649578, 0.1156838560210807, 0.21678264252841473], [0.01712588290683925, 0.04844980234546321, 0.041984232142567635, 0.032256862680826864, 0.023529519825907688, 0.045938323717564344, 0.03635804368449109, 0.0755157974947776, 0.02254603081382811, 0.0920264001137444, 0.05017193779349327, 0.017594913453129784, 0.043381861610604186, 0.034198473673313856, 0.04047843401453324, 0.08493106120399066, 0.02662881334046168, 0.02275425285500075, 0.030095172247716358, 0.03861910896375775, 0.03445181150787643, 0.04819775033476097, 0.05444470333999821, 0.04693436562748892, 0.07897825312933751, 0.022880236451913203, 0.01686441113374063, 0.023789600602218082, 0.037085148239774365, 0.020553897800190107, 0.04865538488541331, 0.002363617789732026, 0.014598360318424446, 0.04921560036018491, 0.0399505744821259, 0.7163516208529472, 4.774214080401829, 20.470426593508037, 32.890666825430735, 57.04210833140782, 63.02135631016323, 52.18959413255964, 47.62139327185494, 47.45077330725533, 37.02558149610247, 28.006437574114116, 26.7555707522801, 14.735774312700544, 16.529919045312063, 21.383023841040476, 27.60334825515747, 40.333816868918284, 43.4106251171657, 23.52777120045253, 6.412796897547586, 2.702124467917851, 0.6669034085103444, 0.1581700819411448, 0.3570154612617833, 0.10390253391649042, 0.9382522766079221, 0.6676283553242683, 1.4292777798005512, 2.902506172657013, 2.637672109263284, 6.703688876969474, 4.05869597196579, 6.666986754962376, 5.587338311331613, 6.098214166504996, 4.905353077820369, 4.942035223756518, 4.223243645259312, 7.389390093939645, 8.393656662532262, 6.660015540463584, 6.277400825704847, 3.309625881058829, 2.785575807094574, 2.524180884872164, 1.5392136978251594, 0.32217556504266603, 0.14142581900315626, 0.054726736420499425, 0.07637556921690702, 0.15824833059949533, 0.4720663662467684, 1.0797623289482934, 3.5483004110200063, 2.7258406238896504, 1.9116059839725494, 3.271785340138844, 6.5131692716053555, 3.5614733270236423, 3.2560982619013106, 2.555402398109436, 3.043903751032693, 4.951050511428288, 4.128999148096357, 6.879252484866551, 9.142635124070303, 9.26706520148686, 3.512931691748755, 3.8579890046800887, 6.46462698493685, 2.784853845834732, 4.583437391689845, 0.818697880421366, 4.47590663603374, 2.500873152698789, 2.299651150192533, 2.2655331066676547, 0.9913684321301324, 0.6338440967457635, 1.0574486234358378, 0.1155505646020174, 0.10209771219108786, 0.1950803513505629, 0.7153137879712241, 1.7499223798513412, 8.456031509808131, 17.901764426912578, 35.096514906202046, 29.351688725607737, 30.853868416377477, 25.045914377485, 14.793932471956525, 19.786154099873134, 23.63777334349496, 30.395606926509313, 32.84391587121146, 38.356936250414165, 45.58881936754499, 48.42140885761806, 52.541197299957275, 49.664761202675955, 26.987654481615337, 6.911659317357199, 1.4574917001383645, 0.06611131570701088, 0.04303227358364633, 0.03375936991402081, 0.0248000308472131, 0.04749819090855973, 0.0014750384393015078, 0.03992717180933271, 0.017689431684889963, 0.020096624569435204, 0.032475805575294156, 0.08308413638068096, 0.015591672821236508, 0.011615472878994686, 0.014694880228489637, 0.0042304682179487175, 0.023185215890407562, 0.06454292950885636, 0.025213650527543256, 0.008968272828496993, 0.08399466252220528, 0.05977871122636965, 0.0022712984355166554, 0.010091688483953476, 0.027138432155230215, 0.008997844232778465, 0.10309405265642063, 0.022543900213869553, 0.057431461821709356, 0.026845635812995688, 0.0731208606490067, 0.02919512607955507, 0.026813597085752656, 0.03386331469352756, 0.04330521768757275, 0.07481012107538325, 0.05366707845990147, 0.00843226578685322, 0.01355063948514206, 0.019450991713841046, 0.07452980468847922, 0.05207559832238725, 0.015172438263627035, 0.06271615717560053, 0.0489312059778188, 0.01574162227500762, 0.04324818342658026, 0.04124486306682229, 0.031393623644752164, 0.040977781505456994, 0.028783557271318774, 0.016555769302483116, 0.03587442124262452, 0.05073400906154087, 0.020077869861519763, 0.051380418839731386, 0.05471528274938464, 0.03106921605233635, 0.04199683932321412, 0.04187513728226934, 0.06831500067242555, 0.019516336332474436, 0.029266382434538434, 0.024277859134599566, 0.0024499863918338504, 0.02460675353982619, 0.05087254894897342, 0.024581813985215764, 0.15277495501296862, 0.03504274765561734, 0.016167687983917337, 0.031731595152190754, 0.04369937189455543, 0.7533615263445037, 4.35140403679439, 23.160357407161168, 37.735030787331716, 62.04125731331961, 72.29822976248605, 64.2170023236956, 57.48051186970302, 58.2704108783177, 48.50516939163208, 38.183144433157786, 31.3359865461077, 21.570352486201696, 24.8990763596126, 35.717072418757844, 44.005439553942, 47.7409474509103, 41.81433555058071, 22.328433956418717, 8.127171533448355, 3.5446506525788988, 0.8432535199182374, 0.34944390611989157, 0.4310155947293554, 0.7020665588123458, 0.8227066653115409, 1.7958838450057166, 3.4515704129423415, 4.182082516806466, 5.840792528220585, 5.0458217688969205, 7.126340849058969, 5.515992905412402, 7.420200143541608, 7.516731466565814, 7.779639141900199, 10.290488822119576, 5.416320996625083, 7.289347325052534, 6.818630754947662, 8.129467913082667, 7.0021704605647495, 6.878606736660004, 6.98093980550766, 4.180447953087943, 1.155694631593568, 0.7707134038209915, 0.2960880377462932, 0.0508089498616755, 0.021906893234699965, 0.09969330978180681, 0.15664503377463135, 0.9321148459400449, 1.7429519253117698, 1.1813531347683497, 1.3991383399282182, 4.230479759829385, 5.105062544345856, 6.75650691134589, 6.021735344614301, 5.433855210031782, 5.239975716386523, 7.520667621067592, 7.591242211205619, 9.106978705951146, 11.352393303598676, 9.776930962290082, 8.511845520564489, 8.378620760781423, 7.749397107533046, 8.479264548846654, 9.26710341657911, 8.453908835138593, 7.391322561672755, 7.732326252119882, 5.667603032929557, 4.791723540851048, 3.619062819651195, 2.1572078679289137, 1.738781594804355, 0.7459145773734365, 0.3726439412151064, 0.1779738999903202, 0.5920231065579823, 2.5887915321758816, 9.219310232571193, 20.181336368833268, 34.5619170325143, 31.519776821136475, 29.83217750276838, 28.738979203360422, 21.530310017721995, 22.959464141300746, 25.381385564804077, 33.69021340778896, 38.662889753069194, 45.63821758542742, 54.24213021142142, 55.45589017868042, 60.166640281677246, 56.966275691986084, 31.31191451208932, 9.182376214436122, 1.369007368172918, 0.1277422375444855, 0.011785858111189944, 0.04447822153036084, 0.031059041419731717, 0.0593521094747952, 0.021014862261446457, 0.08640036771872214, 0.03200001682021788, 0.04350277315825224, 0.012632409426649767, 0.006009335554803589, 0.06172269369874682, 0.020062460331246257, 0.05803529013480459, 0.02578936543847833, 0.018747074396482537, 0.05036623290340815, 0.022886872524395585, 0.02090950952177601, 0.04707216251907604, 0.06546792880232845, 0.02500616808954094, 0.013651759862633688, 0.048404510132968426, 0.011426237943981375, 0.04337363437350307, 0.015102628884570939, 0.06210161479456084, 0.02928438736125827, 0.07326096455965724, 0.054667602093624215, 0.03377946472859808, 0.036581967025995255, 0.014388721835400377, 0.018077971014593328, 0.019212547722937803, 0.03041397174820304, 0.1582918789769922, 0.10337632322417838, 0.13633436363722595, 0.0985626397388322, 0.11063527049762861, 0.14971320144832134, 0.132789601704904, 0.1472003555723599, 0.12516263739338943, 0.12444549373217992, 0.09487974843276398, 0.1037186509264367, 0.18471144059939043, 0.14184018676834448, 0.12559307286781923, 0.26571016066840714, 0.10790083544062716, 0.13691935581820353, 0.12159009623740401, 0.15125373378396034, 0.10284342217658247, 0.2018912008830479, 0.18190900954817021, 0.1364737618714571, 0.20571019952850683, 0.18048092403582164, 0.0938122228586248, 0.14422755794865744, 0.09735975999917303, 0.08466086855956487, 0.340982655861548, 0.19419879865433487, 0.16370057660554135, 0.12427184305020741, 0.1332072535795825, 1.196788015110152, 7.616495438984462, 28.556528193610056, 47.79542827606201, 76.05754566192627, 80.85326875959123, 73.3071985244751, 65.73810195922852, 65.97620282854352, 53.20477458408901, 41.55544567108154, 40.00591400691441, 27.09544883455549, 26.699773243495397, 32.89628791809082, 38.860892568315776, 49.20182704925537, 47.63137435913086, 28.295347145625524, 9.636421884809222, 3.512637261833463, 1.0690668800047465, 0.5473448868308748, 0.5068826494472367, 1.1108953612191337, 1.9448854667799813, 2.520147889852524, 4.120805050645556, 9.882355110985891, 9.889881747109548, 15.62635793004717, 11.571849550519671, 15.048191377094813, 13.732176508222308, 16.33161572047642, 15.035757575716291, 16.979503972189768, 13.905975273677281, 13.368621570723397, 16.83914167540414, 20.45892037664141, 15.312143019267491, 12.985748035567147, 12.662054913384573, 11.727738465581622, 3.9499488472938538, 1.3189280096973692, 0.466985713158335, 0.14968447227563175, 0.2027202078274318, 0.8958666367190224, 0.3953996444387095, 1.781546454344477, 5.450110520635333, 6.530369537217276, 5.628390874181475, 10.533760888235909, 17.335779803139822, 13.737939170428685, 10.310525689806257, 11.745026452200753, 9.15078101839338, 9.682623931339808, 10.271076423781258, 16.080645050321305, 22.83791756629944, 17.36617817197527, 13.80178529875619, 16.181982789720806, 15.915029525756836, 13.157888787133352, 16.482235295431956, 11.003848212105886, 11.945153679166522, 12.31578014578138, 9.493051886558533, 4.834991276264191, 3.7326352511133467, 2.3222010944570814, 2.375843793153763, 0.9348472250359399, 0.7659561133810452, 0.4960916627730642, 0.967143429177148, 2.5779773124626706, 10.198027406420026, 22.06535083906991, 44.26535081863403, 41.27395330156599, 42.195517199380056, 36.644848006112234, 23.81825280189514, 30.463893822261266, 33.36878626687186, 42.00314589909145, 44.930838857378276, 51.12671429770333, 59.88977541242327, 62.66395487104143, 70.06867095402309, 66.90724754333496, 41.66066224234444, 12.130186813218252, 2.1073677880423407, 0.19815870188176632, 0.13169508400772298, 0.16813985125294753, 0.12682791160685675, 0.10427547711879015, 0.16157526922013077, 0.19957210389631136, 0.12500562439007418, 0.1871055428470884, 0.09288831600653273, 0.12233982315020901, 0.12269686827702181, 0.08828953813229289, 0.1855107955634594, 0.12914958702666418, 0.08204875979572535, 0.12668647776756967, 0.1045770248664277, 0.11010504966335637, 0.11171356442251376, 0.11825558516596045, 0.08618299224014793, 0.148260783670204, 0.1546364886952298, 0.10017793984817606, 0.11935392980064664, 0.05626870385770287, 0.15289330509092125, 0.07701402317200388, 0.19893335817115648, 0.1556381828018597, 0.15728592367044517, 0.11526594630309514, 0.12606780310826643, 0.1626791778419699, 0.22757063007780484, 0.11054625348853213], [0.09177702492369072, 0.0198153887675809, 0.037833619862794876, 0.04155503160187176, 0.005109673183012221, 0.04690398761470403, 0.06333968336028711, 0.04662077049059527, 0.05704682746103831, 0.04571112983727029, 0.058656658578131876, 0.04068363318219781, 0.0649174740538001, 0.013456908354003514, 0.011911454943141766, 0.02088703983463347, 0.04704136381457959, 0.020488375066114322, 0.021496089474697198, 0.03218608469303165, 0.03759165766781994, 0.08564039492713553, 0.04420443943568638, 0.009596163689691042, 0.030759797298482487, 0.01222655557960804, 0.02108175054724727, 0.024472340841644576, 0.07034878046917063, 0.04127800610980817, 0.04142494286809649, 0.044220503752252886, 0.06918395297335726, 0.05621196815211858, 0.22210150212049484, 1.7815306037664413, 9.215428795133318, 18.62496941430228, 40.137908935546875, 61.734765325273784, 53.91477973120553, 51.13609089170183, 42.50472245897566, 33.18062904902867, 30.41137933731079, 31.928105081830704, 30.257744244166783, 19.927688905170985, 31.66126298904419, 34.84654998779297, 35.94548749923706, 25.21315404347011, 14.032907571111407, 5.746416015284402, 2.17322107723781, 0.48627678943531855, 0.16999869793653488, 0.20212864742747375, 0.4182030079620225, 0.6113455582942281, 1.053679985659463, 2.038811215332576, 2.9596216678619385, 4.737299169812884, 3.6092916982514516, 1.4252536871603556, 6.64595455782754, 3.346639369215284, 6.869475935186658, 8.032119308199201, 4.9846837009702405, 6.48763507604599, 2.441152951547078, 4.794954453195844, 5.998045895780836, 3.041322712387357, 2.9275513887405396, 2.799891918897629, 3.920764676162175, 2.6078552177974155, 0.4483452433986323, 0.409527449203389, 0.04899200950083988, 0.04546637207801853, 0.23054399767092296, 1.4393415940659386, 4.4936310563768656, 6.285830293382917, 7.8763971499034335, 2.1890182409967696, 0.7422598791973931, 3.7827808346067155, 2.841399154492787, 4.224631982190268, 2.2699254538331712, 1.5686622262001038, 2.569241689784186, 3.1806896797248294, 6.1505288907459805, 5.233654592718397, 6.050076178142002, 7.825624057224818, 5.37193546976362, 5.717432907649449, 5.94483311687197, 5.044508125100817, 6.801668465137482, 9.078504119600568, 3.8728069067001343, 4.10387533051627, 3.987948111125401, 5.464972717421396, 2.1357446653502326, 1.470259883574077, 0.5438506486160415, 0.31931667987789425, 0.11585838879857745, 0.08417644883905138, 0.16230862986828598, 0.8745893527354512, 2.850930345909936, 7.0458811436380655, 20.268320866993495, 38.15518488202776, 38.5759608404977, 35.28862912314278, 39.77433402197701, 27.55169187273298, 26.486131770270212, 29.265107222965785, 30.80681868961879, 35.478992394038606, 36.41335834775652, 46.58357211521694, 48.688237054007395, 49.55496229444231, 38.29053579057966, 14.889831508908953, 4.270837502820151, 0.37663581701261656, 0.01867692744625466, 0.015541464622531618, 0.07515021639743022, 0.011714438059633332, 0.014847284282690712, 0.04134166965793286, 0.04641687411016651, 0.005201947584282607, 0.020050877738477926, 0.1178316907691104, 0.01719017749253128, 0.03317466950310128, 0.08757541395191636, 0.036215469906372685, 0.0461672207207552, 0.025176217446901968, 0.021549089845003824, 0.014657626959628292, 0.03364025987684727, 0.05987673918051379, 0.05856399105063506, 0.017328020185232162, 0.02269302524759301, 0.0417141582417701, 0.07018072770110198, 0.040793420148215125, 0.022585619939491153, 0.08291315912668194, 0.028380285250023007, 0.06336691975593567, 0.02909170716468777, 0.05897715102349009, 0.05857057962566614, 0.03671921091154218, 0.03827533258923462, 0.0392352289387158, 0.03261409779744489, 0.02364740171469748, 0.0954581248973097, 0.034926870837807655, 0.04049579772566046, 0.03942150715738535, 0.014679748897573777, 0.01230667784277882, 0.08950174772845847, 0.026773032566000308, 0.025733131848807846, 0.011219966690987349, 0.07353258212762219, 0.031213170649217706, 0.045759204043341536, 0.0194316619474973, 0.040415615242506774, 0.01644017407670617, 0.04839643556624651, 0.03126803359815052, 0.09481646147157465, 0.07524699584714004, 0.01703086934451546, 0.028459229406767657, 0.04583199728014214, 0.04831371196944799, 0.03309432077886803, 0.03310601532991443, 0.07026590420199291, 0.028471519372292926, 0.02265053877740034, 0.03917593176343611, 0.028199825469138365, 0.09260468158338751, 0.16473199054598808, 1.9881475567817688, 9.678131920950753, 23.30477397782462, 45.84588187081473, 71.44515078408378, 67.84552533285958, 63.595847266060964, 51.72122996194022, 41.73299993787493, 34.79993452344622, 34.49375173023769, 33.90551028932844, 26.098536934171403, 28.554551431110927, 33.95907047816685, 23.11278656550816, 26.48544042451041, 18.861470460891724, 7.835613829748971, 2.53711473941803, 0.4835692175797054, 0.32224151864647865, 0.3071906348424298, 1.291615400995527, 1.2741847591740745, 2.7625870406627655, 5.334565017904554, 6.790359837668283, 7.904284613473075, 7.492482253483363, 7.670157245227268, 5.173925706318446, 8.91124882016863, 9.96944991179875, 6.579902810709817, 9.171215670449392, 7.371186682156154, 7.263532595975058, 6.334766890321459, 5.069629771368844, 5.983483340059008, 4.849070497921534, 5.996272802352905, 6.238509152616773, 3.5660161461148943, 1.7339932003191538, 1.4350629150867462, 0.3124652946633952, 0.08539842255413532, 0.34180324897170067, 1.06716111940997, 3.3344235675675526, 4.811167640345437, 5.139916445527758, 1.9593583473137446, 1.1573196415390288, 2.3290594007287706, 5.106704924787794, 6.518726961953299, 5.267124933855874, 5.30677569764001, 5.220612823963165, 5.979683109692164, 7.689383779253278, 7.75299106325422, 8.999781029564993, 8.556503329958234, 8.602455241339547, 7.351039511816842, 9.573049971035548, 8.852609498160225, 9.32353060586112, 7.731356978416443, 9.10137150968824, 8.745154738426208, 8.256817102432251, 8.883981483323232, 6.0965335709708075, 3.4866373198372975, 2.4953534603118896, 1.3888311215809412, 1.5782563856669833, 0.5554812816636903, 0.2508255993681294, 0.885185029889856, 3.045118600130081, 8.388867616653442, 21.158840213503154, 34.853129931858604, 41.41759688513619, 32.66623306274414, 29.008036034447805, 29.288612978799, 29.19997133527483, 37.5209950038365, 39.52265289851597, 41.66135358810425, 42.715669768197195, 53.07144560132708, 57.09557124546596, 58.47645623343331, 43.38084166390555, 16.935278688158306, 5.3793900183268955, 0.24548012763261795, 0.03421097228835736, 0.0452415293215641, 0.009098163938948085, 0.03661086583243949, 0.009312498732469976, 0.06171176928494658, 0.06140473218900817, 0.016307023453659246, 0.05089121205466134, 0.08412421521331583, 0.019158214031319534, 0.09330108921442713, 0.040888886632663865, 0.012284190344092037, 0.016070092595847588, 0.05479783331975341, 0.03767718022157039, 0.060101218920733245, 0.05377149482124618, 0.02402730329361345, 0.08409106199230466, 0.050325968635401556, 0.054887603502720594, 0.017571670236065984, 0.006130714019361351, 0.013984287822885173, 0.035938105146799765, 0.014355609326490333, 0.021042972270931517, 0.04591199655884078, 0.04713401777137603, 0.041993623067225726, 0.028443002241796682, 0.03923089649262173, 0.051960165945014784, 0.0512019403811012, 0.13791811865355286, 0.12577341390507563, 0.12233876463557992, 0.1485048255750111, 0.08174212303544794, 0.1288632723901953, 0.19518013671040535, 0.1130236459097692, 0.12295841638531003, 0.07352291978895664, 0.12156265628124986, 0.09325553915862526, 0.16996192133852414, 0.14710778982511588, 0.16956040502658912, 0.11816707705812794, 0.17837285143988474, 0.1105847264240895, 0.10113792440720967, 0.19387867940323694, 0.10531088084514652, 0.16867517467056, 0.1312265284359455, 0.13533019966312818, 0.10987735366714851, 0.09964140863823039, 0.13165192918053695, 0.11061570833304099, 0.1938824520579406, 0.25986808272344725, 0.1851929969021252, 0.1278125609138182, 0.1258287823625973, 0.22067341660814627, 0.41705812939575737, 2.9240840205124448, 13.44353791645595, 28.68492569242205, 58.456980432782856, 81.94872174944196, 75.33033330099923, 72.5438346862793, 58.60112081255232, 47.38228838784354, 42.2519018309457, 45.56566449574062, 42.01381138392857, 33.340795448848176, 48.62786415645054, 48.670220375061035, 48.13176277705601, 32.799801758357454, 17.903949635369436, 8.356943249702454, 2.851786059992654, 1.1928228735923767, 0.3054633560989584, 0.6613016948103905, 1.5650044339043754, 2.033420281750815, 2.9249078163078854, 8.562355450221471, 9.814023051943098, 12.314064809254237, 13.48997185911451, 10.929763044629778, 17.760233095714025, 13.359657526016235, 14.505968723978315, 17.02297363962446, 18.00016134125846, 15.720446961266653, 11.881613271577017, 14.274109074047633, 14.142366017614092, 9.530250804764883, 11.599388735634939, 9.835346204893929, 12.47951010295323, 7.848859701837812, 1.9017868765762873, 1.5225194564887454, 0.8753896983606475, 0.18366140765803202, 0.7357262926442283, 0.9898310346262795, 2.4221908833299364, 3.9812305058751787, 6.3137103744915555, 2.5279363862105777, 3.4504042012350897, 8.97719591004508, 8.950183050973074, 11.736920510019575, 9.157757009778704, 9.792517508779254, 10.34672841003963, 12.192462648664202, 15.758151360920497, 15.127107279641287, 13.620708295277186, 17.346283742359706, 15.445569276809692, 16.13888485091073, 18.01702461923872, 13.57325644152505, 15.318677800042288, 17.293390580586024, 13.025244201932635, 14.910660471235003, 14.866916349955968, 14.641112055097308, 8.147084202085223, 4.844859455313001, 3.997260000024523, 1.4621859682457787, 1.4939817935228348, 0.3721458965114185, 0.4125030152499676, 1.305836300764765, 3.812862191881452, 9.19108578136989, 24.847937617983135, 46.55045005253383, 49.29546792166573, 45.38235364641462, 51.65131023951939, 38.49078982216971, 38.152916295187815, 39.531702927180696, 41.94971077782767, 45.72245059694563, 48.123338086264475, 61.05779538835798, 62.98792157854353, 65.95502471923828, 53.62177767072405, 23.706725529262, 7.0883676409721375, 0.8524813790406499, 0.12783516970063957, 0.09484857653400727, 0.13120073053453649, 0.16636381298303604, 0.08593024473105158, 0.07975096880857434, 0.14366479457489081, 0.07964751257428102, 0.0878946307514395, 0.2280741844858442, 0.15845205395349435, 0.10391761774995498, 0.1503311704312052, 0.15023099152105196, 0.09670379305524485, 0.11823309851544243, 0.08743504541260855, 0.1621695166187627, 0.17442935518920422, 0.1674141851919038, 0.15547830638076576, 0.0938689483861838, 0.1907038547630821, 0.17258144649011747, 0.1144754665770701, 0.05528964228661997, 0.12778077833354473, 0.15447939426771232, 0.1647356410643884, 0.13656796967344625, 0.08144888734178883, 0.20937141164072923, 0.15254795790782996, 0.1161938157996961, 0.20473081565329007, 0.15537571188594612], [0.04870367622269051, 0.06555531732738018, 0.08874282666615077, 0.06458682393921272, 0.016554583562538028, 0.018955813820606897, 0.04019487423024007, 0.06803245869066034, 0.01822823768348566, 0.03596065965081964, 0.040742496095065556, 0.03742227157843964, 0.02495718464654471, 0.03141119430906006, 0.025859403823103224, 0.04513310621093426, 0.057642092662198205, 0.0886473296476262, 0.06233067464615617, 0.01309547056111374, 0.023629193227472048, 0.04702762687312705, 0.1403755417891911, 0.027673687719340836, 0.03288544395140239, 0.03344446859721627, 0.03935648314654827, 0.06751335904534374, 0.01188258412626705, 0.059799372617687495, 0.010089735151268542, 0.02663986837225301, 0.021039671198065792, 0.014351914703313793, 0.6340428260820252, 2.424930210624422, 11.227550676890782, 27.761873143059866, 46.884967599596294, 48.87667219979422, 45.72917297908238, 42.97823871885027, 36.73426089968, 40.00947495869228, 37.543684346335276, 27.07387294088091, 22.32971589905875, 28.61196092196873, 38.23767042160034, 40.62597819737026, 37.96712841306414, 17.08346118245806, 9.509791834013802, 3.6611243912151883, 0.3235674574971199, 0.08877054482166256, 0.16387723998299666, 0.4449527582951954, 0.6312872139470918, 1.1450724644320351, 2.118215663092477, 2.7758170621735707, 3.3260275380952016, 2.7003025199685777, 5.248098594801767, 5.458268140043531, 2.8620214079107558, 6.0283361332757135, 7.404525007520403, 3.633902434791837, 5.251579642295837, 6.857473356383188, 4.108506739139557, 3.8668527347700934, 1.5166421490056174, 5.213186502456665, 3.2263573663575307, 6.421750954219273, 3.940434157848358, 1.6528912207909991, 1.187096689428602, 1.4127297763313567, 0.13072024631713117, 0.3478078224829265, 4.7179840462548395, 8.398009708949498, 20.45478446143014, 24.160324777875626, 19.067420278276714, 8.756570628711156, 2.448786416224071, 2.722111178295953, 3.6027805847781043, 4.865283250808716, 4.351553423064096, 4.028172969818115, 4.485122552939823, 7.627074071339198, 6.696565236364092, 8.695735675948006, 9.627746190343585, 7.825436455862863, 6.883086153439113, 4.654967359134129, 6.271867888314383, 8.015521798815046, 7.962386318615504, 5.686249392373221, 8.739516275269644, 6.8246157595089505, 6.1279164126941135, 7.765351040022714, 6.980356591088431, 4.031215412276132, 2.509731237377439, 1.3389963614089149, 1.2573380917310715, 0.7043078956859452, 0.01283768832217902, 0.1979152299463749, 0.5591127468006951, 2.1422136553696225, 6.949252545833588, 16.1132390499115, 26.11895595278059, 40.06538711275373, 40.80232000350952, 31.907406398228236, 19.086812700544083, 17.979193414960587, 20.921743358884537, 29.851250307900564, 40.82630865914481, 44.21778692517962, 46.52477298464094, 47.626027720315115, 47.287608759743826, 32.69330671855381, 10.265069706099373, 0.8328195512294769, 0.05325276158483965, 0.02032405593698578, 0.056545044029397626, 0.05405272723042539, 0.08156298300517456, 0.07094545702316932, 0.03152969027204173, 0.03583576510261212, 0.01369642951924886, 0.04377833640735064, 0.02522526535072497, 0.11475464302514281, 0.01576687056305153, 0.031412032299808094, 0.024578657101041505, 0.05676503186779363, 0.0313181468019528, 0.016241558395060043, 0.04009718893628035, 0.05607089732906648, 0.0787810572822179, 0.05587299919820257, 0.04980563066367592, 0.02335327205115131, 0.031266377972705026, 0.008439884038775094, 0.028349493330876743, 0.05957608709910086, 0.03497125042070236, 0.0349227283815188, 0.03368368611804076, 0.031142060179263353, 0.01278846145474485, 0.06713296552853924, 0.0504671174899808, 0.10302256220685584, 0.04849266879526632, 0.04923981727500047, 0.020904137220765864, 0.10794405812131506, 0.05748295584427459, 0.037704813560204845, 0.03492226019235594, 0.06323161987321717, 0.03546638420916029, 0.05525924391778452, 0.014042869991888958, 0.012907144014856644, 0.03493389706792576, 0.013509343843907118, 0.02171583304048649, 0.04270450724288821, 0.04918763114671622, 0.10219790467194148, 0.04426573828927108, 0.02457682166381606, 0.0333989185414144, 0.02855034139273422, 0.045199015709970675, 0.009774995834699698, 0.06311044708958694, 0.06599998846650124, 0.04587199691949146, 0.02961293401728783, 0.018477738402517777, 0.012029840644182903, 0.05501327836619956, 0.026961035959954773, 0.040507943502494266, 0.018919902354744927, 0.6208858149392265, 2.989918419292995, 12.56567210810525, 28.300063235419138, 56.70378317151751, 61.171822275434224, 58.39528042929513, 53.15119702475411, 43.972484248025076, 44.06647253036499, 40.239342212677, 33.66017287118094, 30.819627693721227, 31.37284673963274, 39.60278647286551, 41.144515310014995, 36.71461486816406, 19.821265084402903, 8.323347840990339, 3.777567514351436, 0.5292802218879972, 0.21330772899091244, 0.6090951561927795, 1.4652868189982005, 2.8069063425064087, 5.17044335603714, 6.947380440575736, 7.653736914907183, 8.099178109850202, 8.372241445950099, 9.550970332963125, 7.260567452226367, 9.959405422210693, 8.093259981700353, 8.116716231618609, 7.773806129183088, 7.700855255126953, 6.942086781774249, 6.322988825184958, 5.084451147488185, 4.918957216399057, 6.978131864752088, 4.478939958981105, 5.331885618822915, 3.465668959277017, 2.7379239755017415, 2.8417228971208846, 1.514427627835955, 0.5593927917735917, 0.5068414488009044, 5.012413961546762, 9.356051649366107, 18.262535742350988, 22.3956230367933, 17.416022811617168, 7.679340158190046, 2.2440998681953976, 1.0913120806217194, 3.200579115322658, 4.867336009229932, 5.917561437402453, 5.3093478339059015, 6.332170435360499, 10.79795571735927, 8.745187742369515, 8.456454481397357, 7.433912413460868, 7.343387808118548, 9.197222777775355, 7.85834138734, 10.928422042301722, 7.422691072736468, 10.770623241152082, 7.384581940514701, 9.87425090585436, 9.420647314616613, 7.5082312141145975, 9.856027517999921, 7.2647124869482855, 6.208403476646968, 4.148347275597708, 3.632395327091217, 1.7843288821833474, 1.0994267080511366, 0.40405207872390747, 0.27804894000291824, 0.8818637366805757, 2.466078528336116, 8.934232592582703, 19.012487820216588, 24.98816442489624, 34.75266940253121, 39.13775743756975, 29.533842699868337, 24.586740936551774, 23.07844683102199, 26.661368812833512, 35.460788113730295, 45.19316462108067, 50.93998493467058, 54.65755605697632, 56.92007711955479, 52.656394958496094, 36.76204674584525, 11.655254857880728, 1.093478072966848, 0.07659531278269631, 0.049590233114681075, 0.05804607205625091, 0.04241682875103184, 0.03523137699812651, 0.06412858209971871, 0.021450123816196407, 0.03190839423664978, 0.011464360585835363, 0.0653317536094359, 0.04381460749677249, 0.056270247524870295, 0.02461243457426982, 0.011753656535542436, 0.006631818491899009, 0.03885856057916369, 0.028921259168003286, 0.00971879786811769, 0.04159440698900393, 0.05694937626166003, 0.01644774483117674, 0.08185959101787635, 0.028727642593107054, 0.017892729258164763, 0.008362074731849134, 0.015843901251043593, 0.01508973671921662, 0.039511392691305706, 0.07007618581077882, 0.026740473063130463, 0.027538594789803028, 0.019879966641643217, 0.020884018657462936, 0.040885083443884335, 0.05483063370255487, 0.02668174246459135, 0.14612970873713493, 0.12093978827553135, 0.3270949167864663, 0.15162288397550583, 0.09178695867636374, 0.07662334306431667, 0.10199160288487162, 0.1683565481965031, 0.13887084967323712, 0.15131652541458607, 0.12897639774850436, 0.09352995229086705, 0.18605496707771504, 0.12292127337838922, 0.17622251968298638, 0.15134273043700627, 0.301767321569579, 0.1403225210628339, 0.11646894817905766, 0.16425460044826778, 0.16899986724768365, 0.13077884460134165, 0.20266691568706716, 0.14324479496904782, 0.1431539934128523, 0.1276213904576642, 0.09787732615534749, 0.18031698997531617, 0.07992717756756715, 0.11956308143479483, 0.10354370424257857, 0.155228781913008, 0.1475629239742245, 0.11889518584523882, 0.9771353730133602, 4.636734417506626, 16.915853261947632, 40.833965573992046, 66.73585632869175, 68.70135579790387, 69.30484158652169, 62.996016229902, 53.1205415725708, 55.152246952056885, 49.556490898132324, 37.99248586382185, 33.64613403592791, 43.352548599243164, 51.09359918321882, 54.269551277160645, 46.60238436290196, 21.030816180365427, 11.596703256879534, 4.697160295077732, 0.9964437655040196, 0.3348090728478772, 1.000856957265309, 0.9475545031683785, 3.6346039857183183, 5.812463854040418, 10.488207629748754, 10.735237802777972, 14.341881803103856, 13.527912497520447, 16.20024960381644, 14.321493182863508, 15.481361184801374, 15.992434195109777, 17.872642789568218, 11.181817633765084, 13.124360254832677, 14.692370653152466, 13.438378010477338, 13.96383900301797, 9.181552852903094, 13.925021154539925, 11.727156553949628, 15.046447379248482, 10.452275020735604, 8.595033696719579, 4.621699818543025, 4.171143880912235, 1.1641483094011034, 0.9644797721079418, 7.456799779619489, 8.836379374776568, 15.1491938659123, 18.550344024385723, 14.539553710392543, 6.852486286844526, 3.144606815917151, 5.808096476963588, 7.950988667351859, 11.840701409748622, 9.890386360032217, 10.784726347242083, 10.244988543646675, 11.891121012823922, 19.0363027708871, 17.670691660472325, 18.538257632936748, 19.704208782741002, 15.46206430026463, 13.590567878314427, 14.93674053464617, 19.617153065545217, 20.456448554992676, 15.599424975258962, 16.87943254198347, 16.79633903503418, 13.354756440435137, 14.996847663606916, 12.663567883627755, 9.26914358139038, 6.195081174373627, 3.5049920720713477, 3.2013746840613226, 1.6802876421383448, 0.5714030244520732, 0.49799650056021555, 0.9233395968164716, 2.655331607375826, 8.752271430832998, 19.877554178237915, 32.86808170591082, 53.737194197518484, 55.09927041190011, 43.42720351900373, 27.60086601121085, 25.44449257850647, 31.2171619279044, 40.986388206481934, 52.58801426206316, 57.11428969247, 63.2839287349156, 64.03574466705322, 64.29666342054094, 45.03033011300223, 15.458178520202637, 2.1334207100527625, 0.21417595525937422, 0.13013415490942343, 0.15296961313911847, 0.11026217801762478, 0.16704145233545983, 0.10903658771089145, 0.1559983491897583, 0.15110528389258043, 0.10469405180109398, 0.09383363063846316, 0.13552363642624446, 0.23426600652081625, 0.12491641060582229, 0.14209146185645036, 0.13612643336611135, 0.1521563617778676, 0.13429561017879418, 0.12686250332210744, 0.14161964931658336, 0.16186152957379818, 0.1988117511251143, 0.22194140856819494, 0.08820883317717484, 0.07179342223597424, 0.1113091032685978, 0.13471539265343122, 0.11951528542808124, 0.08151287997939757, 0.17298292208995136, 0.08830909351153032, 0.15160757622548512, 0.1205033545515367, 0.15379715444786207, 0.13743246399930545, 0.11909234098025731, 0.1879234625292676], [0.0417382021301559, 0.12569452742380754, 0.14814328854637487, 0.16185402497649193, 0.051613102068326304, 0.08335880057087966, 0.08277664466628007, 0.12680794910660811, 0.053783074021339417, 0.011199712420680692, 0.034651236342532296, 0.04420386268092053, 0.03700016512136374, 0.013037900257456516, 0.14508480552051747, 0.06510507541575603, 0.02694299880282155, 0.051693281158804893, 0.08673170315367834, 0.03937509875478489, 0.03765219656218376, 0.026495739052604352, 0.03911078900897077, 0.053986498819930215, 0.12161166008029665, 0.07540786971471139, 0.04390232850398336, 0.06214173657021352, 0.049384748962308676, 0.017923285386392047, 0.051290095650724, 0.06891407245504004, 0.03352995043886559, 0.09651762340217829, 1.5848963665110725, 8.092217751911708, 19.62588174002511, 33.41993890489851, 37.49932009833199, 48.03712831224714, 47.93059158325195, 47.67912237984793, 42.34278079441616, 33.64676284790039, 23.634532008852275, 18.919844014304026, 21.122615780149186, 29.682721751076834, 31.61809035709926, 33.596954686301096, 15.02904908997672, 7.114556704248701, 2.694649943283626, 0.17133879102766514, 0.17196365392633847, 0.1236495314432042, 0.3381326730762209, 1.7347353547811508, 2.6845917744295935, 3.8520361355372836, 4.075214445590973, 6.589489153453282, 8.506854108401708, 10.435154659407479, 6.532765797206333, 4.078305525439126, 5.637403556278773, 7.641081639698573, 9.145057439804077, 4.624116488865443, 5.346241465636662, 3.675719950880323, 5.282012752124241, 2.749977797269821, 3.4495797540460313, 5.0015052897589545, 1.9481259328978402, 4.607739150524139, 4.373389874185834, 4.430652584348406, 4.883927873202732, 1.8048159714256014, 2.4866719033036913, 4.277210737977709, 13.402606078556605, 26.629983799798147, 45.30131333214896, 47.16162749699184, 38.34180654798235, 26.283920083727153, 8.599384137562343, 2.54634433559009, 4.305253667490823, 4.321314428533826, 4.997048020362854, 4.5290668691907605, 6.106928076062884, 9.346876553126744, 6.004903333527701, 5.424227178096771, 4.721844204834529, 4.2487296376909525, 7.9842566422053745, 5.865407824516296, 8.15566349029541, 6.420611015387943, 8.295720066343035, 6.858851705278669, 10.364935295922415, 6.2045454893793375, 8.465679952076503, 10.018095118658882, 7.563578827040536, 4.649964656148638, 3.1538687646389008, 3.868980186326163, 2.740912135158266, 1.3628738458667482, 0.07838140694158417, 0.12627569266727992, 0.3689386786094734, 0.4664287716150284, 2.6994285668645586, 6.740455704075949, 21.683281557900564, 29.01075972829546, 31.696358340127126, 35.54113360813686, 31.55652584348406, 27.7010520866939, 22.04695895739964, 23.843328850609915, 30.774610315050396, 36.62498658043997, 41.3327385357448, 53.67867646898542, 55.952081884656636, 44.55374274935041, 17.93736525944301, 6.350578819002424, 0.5927726434809821, 0.07754777917372328, 0.08364956639707088, 0.06598286224263054, 0.03141647670418024, 0.027766407833301594, 0.03969139785372785, 0.07438105624169111, 0.022162600852815167, 0.07326907305313007, 0.097879673886512, 0.01864596758969128, 0.06514991300978831, 0.04907308765021818, 0.03456266377387302, 0.045593522755163055, 0.024039109802937934, 0.006236168115200209, 0.1503379964934928, 0.16324282331126078, 0.11757428172443594, 0.07185907049902848, 0.0637544175343854, 0.0967335400304624, 0.0775204138564212, 0.0359007891134492, 0.04774859407916665, 0.16135455534926482, 0.1174186665032591, 0.03742664473663483, 0.04909816969718252, 0.05710945624325957, 0.04220402320580823, 0.027907890866377523, 0.04372451161699636, 0.02291500797894384, 0.043618975672870874, 0.047411603054830005, 0.0811949795378106, 0.12367022676127297, 0.013880505043614124, 0.04256550934431808, 0.05693009229643004, 0.03296176217762487, 0.055657649146659036, 0.028678818605840206, 0.022693425583254014, 0.055829939365919144, 0.028060518837134753, 0.04676402958908251, 0.07293720836085932, 0.10605916247836181, 0.08199698757380247, 0.01534919154697231, 0.03805755338232432, 0.05414650755535279, 0.04393849442047732, 0.028718238097748587, 0.076670874442373, 0.05706744135490485, 0.1031087361542242, 0.026152213736038123, 0.04919967853597232, 0.021527958568185568, 0.037303124221840074, 0.08323047602815287, 0.03644513026145952, 0.09169185520814997, 0.028167391495246972, 0.05127298639022878, 1.4110686140401023, 7.7264984505517145, 21.530033826828003, 41.99878937857491, 48.64333084651402, 57.0731772014073, 55.751789637974326, 55.393696853092735, 46.607192516326904, 40.75407518659319, 31.99868835721697, 28.146916253226145, 23.962853499821254, 39.68668597085135, 37.92971583775112, 32.509790897369385, 17.61119076183864, 7.532768777438572, 2.819295414856502, 0.4994784210409437, 0.45413233286568094, 0.3720614053308964, 1.6543920316866465, 4.142012689794813, 4.082845304693494, 6.194017231464386, 9.119316969599042, 8.870191046169825, 9.026734828948975, 6.959450764315469, 10.220860055514745, 9.689530440739222, 8.00578042439052, 8.287216339792524, 8.905008469309125, 5.423125888620104, 6.107675875936236, 5.501928882939475, 5.691444473607199, 4.099379846027919, 4.4460263422557285, 6.039535760879517, 3.589952038867133, 3.3031955403941016, 3.2460780910083225, 3.452706877674375, 3.3081333211490085, 2.9305651698793684, 3.0313794059412817, 4.905157225472586, 14.840824127197266, 27.399607964924403, 43.98116602216448, 45.30584008353097, 38.633922713143484, 25.327834061213903, 8.270274894578115, 2.5440570754664282, 3.627176578555788, 4.118972897529602, 5.037181683949061, 4.912081973893302, 5.384434844766345, 6.6631035804748535, 5.737750308854239, 13.376522541046143, 10.327700768198286, 5.418212643691471, 8.346572194780622, 8.838452543531146, 7.995428477014814, 7.825884614671979, 13.855654682431902, 14.67017810685294, 6.900408446788788, 13.114215884889875, 12.623360395431519, 11.402884125709534, 9.249215279306684, 8.97980409009116, 7.3476652928761075, 6.027440249919891, 3.8536485518727983, 3.906915179320744, 1.7614250140530723, 0.40474768568362507, 0.4713926081146513, 0.6726247072219849, 2.6785290368965695, 7.821989280836923, 20.588071755000524, 28.972766978400095, 30.916780880519322, 34.265517302921836, 28.38462802342006, 24.998480762754166, 22.972782100949967, 29.457916259765625, 41.318265438079834, 48.01722867148263, 50.67310462679182, 60.09028652736119, 63.07092475891113, 52.012501920972554, 22.27305681364877, 7.335691809654236, 0.8135021477937698, 0.05636653842936669, 0.059012143074401786, 0.0737140631037099, 0.015585588058456779, 0.03112172448475446, 0.02203576230177922, 0.046984115815056224, 0.05991034023463726, 0.07371132860758475, 0.04325517912262252, 0.044464616903236935, 0.03459223093731063, 0.034079431489642174, 0.13657892122864723, 0.05204732037548508, 0.024917458117540394, 0.022340853698551655, 0.09357281534799508, 0.04142813876803432, 0.04083945196388023, 0.07883120780544621, 0.06045183153556926, 0.05687062888007079, 0.030538890045136213, 0.027983776526525617, 0.07135405045534883, 0.1046842062579734, 0.05051574130941715, 0.012444604504188257, 0.025280065535168563, 0.061707996630242894, 0.04336684563064149, 0.03172620419146759, 0.05915150738188198, 0.09032685309648514, 0.14710061092461857, 0.17400179670325347, 0.21595157283757413, 0.40503752870219095, 0.12116394910429205, 0.1535365834300007, 0.2492881475814751, 0.21119547661926064, 0.23076064033167704, 0.15979954307632788, 0.09889273345470428, 0.1410897406084197, 0.10282265900501183, 0.2550765126943588, 0.20182501657732896, 0.22092835578535283, 0.25066435230629786, 0.09953265983079161, 0.28690507050071445, 0.1845875943877867, 0.12797696994883673, 0.1426411159336567, 0.13194230145641736, 0.1391905075205224, 0.23378807359508105, 0.1665528528392315, 0.14184747423444474, 0.10987832397222519, 0.15512398896472795, 0.12660034453230246, 0.1454804050070899, 0.169883577685271, 0.0841931611565607, 0.2948506341448852, 2.1453049523489813, 11.400175196783882, 29.526258741106304, 50.21931082861764, 58.91681221553257, 70.54676955086845, 66.65251963479179, 68.24508844103131, 55.41623680932181, 47.15783725466047, 33.152065004621235, 31.768730776650564, 32.69902856009347, 41.27205296925136, 43.87745720999581, 43.001310212271555, 19.273516007832118, 9.92557464327131, 3.421340972185135, 0.4053517718400274, 0.5776304017220224, 0.46082320383616854, 2.1163865498134067, 4.560076679502215, 7.782256875719343, 9.921687126159668, 13.185538274901253, 18.66289094516209, 18.6918215070452, 22.163704327174596, 19.445105246135167, 16.351913145610265, 17.602430820465088, 17.019219875335693, 18.854765449251445, 15.668625559125628, 11.739166515214102, 14.43062332698277, 15.220617873328072, 9.722517013549805, 9.4771101134164, 10.118878739220754, 6.8386333159038, 10.144405552319117, 9.031523874827794, 9.760336927005223, 11.422630906105042, 8.715506775038582, 5.198222254003797, 6.006186578954969, 17.92848719869341, 29.643186501094274, 40.37074654442923, 42.53269590650286, 33.69190182004656, 24.33034372329712, 9.376009481293814, 4.258050646100726, 6.451973446777888, 9.907409446580068, 10.998593636921473, 9.42969821180616, 14.048274380820137, 19.273224183491298, 12.703043205397469, 15.19012917791094, 12.176480054855347, 14.488726769174848, 19.62916476385934, 15.349866526467459, 16.248421464647564, 17.37805438041687, 17.433216129030498, 14.315410903521947, 22.272766726357595, 19.65961524418422, 21.75461002758571, 21.795392479215348, 19.16908805710929, 14.154586161885943, 13.337453688894, 9.91491871220725, 5.554877196039472, 5.610954804079873, 1.9404746634619576, 0.5718576971973691, 0.8368325701781681, 0.7424972036055156, 3.1364439853600095, 8.656895245824542, 27.12425259181431, 36.10609858376639, 42.34602560315813, 46.254015581948416, 43.919212409428184, 38.616395882197786, 30.245188849312918, 33.709630148751394, 42.28086192267281, 49.57480982371739, 56.43512412479946, 68.4440084184919, 70.85497774396623, 61.671884128025596, 30.26127392905099, 10.341262783323016, 1.0975477631602968, 0.2024887323911701, 0.2322611255305154, 0.292024698640619, 0.13437533804348537, 0.08241807962102549, 0.12041453431759562, 0.12280504032969475, 0.23393729701638222, 0.17749116303665297, 0.16039621963032655, 0.11312336341610976, 0.138050785820399, 0.1747663835329669, 0.2147154855941023, 0.13254291351352418, 0.17288743864212716, 0.11165784312678234, 0.20174212673945086, 0.21661374159157276, 0.23203191640121595, 0.2399388306907245, 0.1446062619132655, 0.29019878804683685, 0.15112652203866414, 0.13261288404464722, 0.12177874254328863, 0.28130202687212397, 0.2028351245181901, 0.182276314124465, 0.15428294480911323, 0.14218378333108767, 0.11771494203380176, 0.1054859021678567, 0.18909743667713233, 0.17587086212422165], [0.04001957131549716, 0.18500938532607897, 0.21817560706819805, 0.10244738164224795, 0.0363513635072325, 0.047361425390200954, 0.12293719180992671, 0.09046414108680827, 0.041910577166293345, 0.028845402345593487, 0.02462161854574723, 0.041482007663164816, 0.003409706534252369, 0.17014821991324425, 0.1706706104534013, 0.10508670644568545, 0.03786531084084085, 0.07985463538872344, 0.057643062967274866, 0.036982723378709385, 0.08252725590552602, 0.0356275328834142, 0.02969303846891437, 0.0702340401975172, 0.06935915750052248, 0.0443277292485748, 0.0723496920296124, 0.09376436578375952, 0.017846856898229038, 0.047813143115490675, 0.0659210884145328, 0.012984284116620464, 0.025363952819524065, 0.07146389170416764, 3.452515802213124, 8.190933414867946, 21.89547954286848, 39.61493192400251, 51.45344986234392, 56.91056850978306, 52.25334732873099, 44.170570441654746, 37.976591859545024, 34.54395941325596, 30.564031260354177, 24.42053828920637, 28.383377347673687, 25.658608266285487, 27.476686068943568, 22.376640558242798, 7.13432389497757, 4.959744879177638, 0.4072372849498476, 0.15994724657918724, 0.09005744076733078, 0.4517372399568558, 2.0008814334869385, 4.451528012752533, 3.5005508703844885, 7.578973429543631, 7.8349615676062445, 6.731325771127429, 3.623283416032791, 2.688403295619147, 8.79168335029057, 8.81869968346187, 7.158980446202414, 5.774208809648242, 4.482106600488935, 5.49055164200919, 5.201390632561274, 4.466388038226536, 2.861038237810135, 3.6996282679694037, 4.535865681512015, 7.628984825951712, 6.214413234165736, 7.2950674295425415, 8.052777171134949, 7.5456307615552625, 11.537712182317462, 9.241778101239886, 12.772569486073085, 19.491003308977398, 29.715934140341624, 50.865948404584614, 66.2068065915789, 59.209956714085166, 59.449537549700054, 48.3261525290353, 26.05575861249651, 10.28248883996691, 5.6236856409481595, 6.127456963062286, 7.282974524157388, 8.180124623434883, 8.017288378306798, 13.504167897360665, 4.851821550301143, 11.963063529559545, 8.91651121207646, 1.5843122835670198, 3.74430388212204, 7.0625689796039035, 11.457658512251717, 6.7371609551565985, 10.163196086883545, 9.003432307924543, 7.576555456433978, 12.530121650014605, 6.298924173627581, 8.354452320507594, 5.690526877130781, 7.508311118398394, 4.312158005578177, 6.528609905924116, 1.8850886183125632, 2.9097579206739153, 1.4717644942658288, 0.09201165554778916, 0.21602842371378625, 0.2084250995623214, 0.2572145493967192, 2.2932624987193515, 6.065364820616586, 17.69963959285191, 37.03661870956421, 35.739059993198936, 26.46675498144967, 26.841907330921718, 21.515889031546457, 14.816899742398943, 21.60808641569955, 20.947522912706646, 38.21808344977242, 45.57578454698835, 47.519223485674175, 44.8512715612139, 31.222185475485666, 14.4358857188906, 1.1011366162981306, 0.0875738329653229, 0.012465617885547025, 0.028281901064994078, 0.044133848045021296, 0.07160286246133701, 0.023798565746151974, 0.03518580997894917, 0.029378720692225864, 0.045909007612083635, 0.027839698097003356, 0.09978992638311215, 0.03264568360256297, 0.12355069603238787, 0.04341175786352583, 0.05769444842423711, 0.05000773910433054, 0.09255345897482974, 0.19910877304417746, 0.17865122721663543, 0.1338003474686827, 0.09854543209075928, 0.02793370233848691, 0.0746249488687941, 0.043271891440131834, 0.05517558394266026, 0.06260941683181695, 0.14929595669465406, 0.09672067500650883, 0.04243578023410269, 0.051765287294983864, 0.029498098750731776, 0.0534785000075187, 0.07099699175783566, 0.10996375153107302, 0.028404519128214036, 0.0946402730686324, 0.06272849294223956, 0.060491118713149, 0.08701419085264206, 0.044954905951661725, 0.054641617595085075, 0.040824646329773326, 0.09447000149105277, 0.044509827691529474, 0.018723598781174848, 0.04564103377716882, 0.028484272437968423, 0.0898692219385079, 0.06617981381714344, 0.0905007684071149, 0.0332199413595455, 0.02881188950102244, 0.023209907779736177, 0.03850932539041553, 0.044555231862302334, 0.035783450052674325, 0.03223372802936605, 0.0014855086587236396, 0.13897747466606752, 0.026487313344010284, 0.027843133180535266, 0.01973659897755299, 0.068693501076528, 0.03328026651537844, 0.04389990952664188, 0.06601917743682861, 0.017872325710154006, 0.01481560178633247, 0.0770127068140677, 2.987933188676834, 11.374385220663887, 26.548061064311437, 43.07618400028774, 54.11420692716326, 64.7028203691755, 59.976697376796174, 51.277830668858115, 43.044382095336914, 35.858496052878245, 30.748148100716726, 26.058845349720546, 28.414307253701345, 23.801109858921595, 27.115494387490408, 21.081904547555105, 10.93667823927743, 4.5626870308603555, 0.7191826317991529, 0.27601371492658344, 0.22165845946541854, 1.160136810370854, 3.17190802523068, 6.848673897130149, 7.117822791848864, 8.741663268634252, 8.996666499546595, 8.404037271227155, 10.868598052433558, 11.055167606898717, 9.925367934363228, 7.452301689556666, 9.072555593081884, 7.056602214063917, 6.859539142676762, 4.526522959981646, 5.654593399592808, 6.626305052212306, 4.308750782694135, 4.122496502740042, 5.722536359514509, 6.672065453869956, 5.303197809628077, 7.4307831185204645, 8.224862337112427, 9.438120297023229, 11.005826711654663, 9.502069779804774, 12.245933379445757, 21.770285163606914, 30.413467270987375, 52.914808886391775, 64.76534720829555, 62.80976281847273, 58.29335035596575, 49.62254047393799, 26.35244495528085, 10.547367198126656, 5.287837079593113, 5.155584633350372, 6.375332645007542, 7.020917134625571, 8.690930128097534, 12.457347086497716, 8.345080069133214, 14.058999793870107, 13.336781450680324, 5.469268441200256, 6.749648605074201, 11.912944436073303, 14.308996847697667, 8.67863963331495, 11.782793385641915, 14.915602377482823, 10.284113849912371, 11.926184228488378, 13.029296738760811, 9.546845708574567, 9.360763396535601, 11.571558594703674, 9.745037862232753, 7.881424171583993, 6.736459621361323, 4.822446737970624, 2.056534550019673, 1.0912630089691706, 1.0640493035316467, 0.3694786839187145, 0.769427552819252, 2.752583588872637, 7.627199138913836, 18.277517795562744, 36.81812913077218, 34.63816656385149, 30.06491436277117, 32.352942262377056, 22.95768713951111, 18.253305060522898, 25.631510291780742, 26.483460187911987, 44.33346748352051, 53.95763622011457, 56.69242286682129, 52.86662312916347, 36.31719527925764, 17.427878175462993, 1.563429798398699, 0.1528793272695371, 0.08235530834645033, 0.03854143027482288, 0.024587076024285386, 0.02550814999267459, 0.08660542778670788, 0.02073265445817794, 0.020280246323506747, 0.039573539713663716, 0.04949539088244949, 0.04209734732285142, 0.04012966701494796, 0.02254578484488385, 0.007995340124970036, 0.03944545265819345, 0.05756535713693925, 0.03936618280463985, 0.07321937714836427, 0.05628082249313593, 0.055743962193706205, 0.054631721161838086, 0.058952574485114644, 0.03755792769204293, 0.03956806054338813, 0.050584802603615184, 0.05050784994715026, 0.05171134376100131, 0.021169876979131783, 0.04891096188553742, 0.02931612583675555, 0.07331340174589838, 0.03020238078066281, 0.08829732092895679, 0.029551920148410966, 0.04451592093599694, 0.22984505231891358, 0.3593323869364602, 0.24569430042590412, 0.1818388897393431, 0.10384404419788293, 0.13168102476213658, 0.21664287788527353, 0.2926785349845886, 0.16217369639447757, 0.09888081837977682, 0.10906569686319147, 0.1829471681267023, 0.1900146667446409, 0.19514505644994123, 0.2579236456326076, 0.24439748429826327, 0.18879033172769205, 0.13387542058314594, 0.2288521927382265, 0.1282434713627611, 0.1842276451310941, 0.13357634948832647, 0.12994838559201785, 0.193957565884505, 0.14034698903560638, 0.17801805904933385, 0.22129895804183825, 0.17107455592070306, 0.16713074754391397, 0.08033286686986685, 0.13491205924323627, 0.07487022570733513, 0.10791791416704655, 0.28496405322636875, 4.892893220697131, 14.68874021938869, 33.587862968444824, 52.865740707942415, 69.27695846557617, 75.32233592442104, 69.46953473772321, 57.88612685884748, 50.74435840334211, 46.50491155896868, 42.4674071584429, 33.622430256434846, 41.1818653515407, 38.26630742209298, 36.584266662597656, 28.63582624707903, 10.363576054573059, 6.246617266110011, 0.5792212677853448, 0.5246519073843956, 0.1828948123646634, 1.4453503744942802, 5.232866406440735, 9.234028254236494, 9.628539153507777, 18.106673751558574, 16.443113463265554, 18.13808482033866, 15.604104587009974, 15.087347950254168, 17.95305950301034, 17.812073605401174, 23.856863941465104, 16.27741629736764, 12.51040961061205, 11.603276252746582, 11.288189343043737, 10.700244069099426, 7.916150399616786, 9.970122150012426, 10.89582109451294, 12.734639269965035, 10.450343421527318, 10.927536146981375, 11.815802540097918, 12.363143410001483, 16.377331393105642, 12.803300499916077, 16.39145186969212, 23.81411862373352, 38.03782980782645, 55.68612568719046, 63.90255464826311, 58.8791321345738, 57.122703960963655, 47.67541551589966, 27.6702698298863, 12.426965219633919, 8.34127332483019, 9.498330780438014, 10.996642930167061, 12.269787413733345, 14.298463378633771, 22.325352430343628, 10.248819606644766, 19.941753796168737, 19.18903112411499, 7.706926243645804, 13.110590662275042, 16.172578402927943, 25.894108772277832, 11.495711190359932, 21.0062803540911, 23.61209453855242, 18.90505129950387, 22.683473008019583, 14.859740597861153, 19.229401894978114, 16.686600923538208, 19.016861711229595, 13.30895825794765, 14.694394315992083, 9.339376841272626, 5.230887906891959, 2.424816216741289, 0.5901077379073415, 0.9311819417136056, 0.6310360474245889, 0.6486375715051378, 2.95138001867703, 7.593205945832389, 22.984052079064504, 46.26331227166312, 47.71172332763672, 38.91040890557425, 38.6522798538208, 31.16452932357788, 23.659597635269165, 30.501824038369314, 30.409948008401052, 52.559728145599365, 59.087425231933594, 63.05453395843506, 62.968959944588796, 46.32068354742867, 22.416561433247157, 3.0803253395216803, 0.34825630698885235, 0.1923736480197736, 0.16236182701374802, 0.16556863779468195, 0.0876614386215806, 0.22169176196413382, 0.21780007864747727, 0.12251941779894487, 0.11629027633794717, 0.1454759809587683, 0.25779534823128153, 0.13937156780489854, 0.18296664208173752, 0.16606482331241879, 0.1308222437011344, 0.1579636444470712, 0.197673888610942, 0.2532774992287159, 0.24862402464662278, 0.30609262947525295, 0.25612037096704754, 0.17952433893723146, 0.1825296248176268, 0.1508782325046403, 0.22348177805542946, 0.13652026866163525, 0.25346895466957775, 0.2557439197387014, 0.22408252581954002, 0.08556110132485628, 0.14518199887658867, 0.15661778380828245, 0.30704192710774286, 0.25682181332792553, 0.1586230719195945], [0.04099898572478976, 0.17373448104730674, 0.15492880158126354, 0.12322276005787508, 0.017389220651239157, 0.04660507597561393, 0.058161097312612195, 0.046291487624070475, 0.004226244337457631, 0.07841542868741921, 0.021989957795345356, 0.02744990517385304, 0.06178764985608203, 0.18557963972645147, 0.14349826851061412, 0.013271144973779363, 0.19723590782710484, 0.08130188272999865, 0.050886068759219985, 0.016738748144624487, 0.12557414174079895, 0.007750331307761371, 0.10823456610419921, 0.061658986045845916, 0.010970599134452641, 0.0774877288245729, 0.07783444664840188, 0.08110428654721805, 0.077712995665414, 0.12011625032339777, 0.021967447396101694, 0.013250026419492704, 0.08755817916244268, 0.8125948650496346, 6.030702429158347, 18.791086946214946, 31.708274500710623, 46.962710993630544, 62.45764895847866, 57.04837213243757, 44.4029529435294, 52.2013817514692, 46.04240124566214, 30.650654452187673, 30.110056809016637, 34.248469897678916, 30.638133798326763, 33.67572293962751, 32.979006222316194, 13.525247863360814, 3.263308103595461, 0.5394374025719506, 0.006357842590659857, 0.05651662698281663, 1.1051792736564363, 0.7273812890052795, 1.4454025945493152, 6.204396971634456, 4.567559455122266, 4.288786002567836, 8.101016776902334, 5.969494010720934, 9.106643455369131, 7.397777438163757, 8.143922771726336, 4.87304265158517, 4.685451711927142, 4.881343577589307, 6.488173561436789, 3.5060568835054124, 3.579804629087448, 4.998805480343955, 6.241568531308856, 8.079282811709813, 12.411891102790833, 17.689139127731323, 14.578995159694127, 16.389285768781388, 17.897109133856638, 19.461925097874232, 20.733351639338903, 22.633030823298864, 31.21829101017543, 39.343830585479736, 42.83537333352225, 59.006103515625, 70.22176756177629, 64.30286816188267, 68.58705793108258, 59.243030139378135, 40.74393081665039, 27.74476146697998, 20.375967570713588, 10.321366616657802, 9.505887814930507, 11.42379994051797, 10.175935609000069, 12.575105156217303, 15.301680769239153, 23.05119252204895, 19.582029921667917, 4.798401628221784, 4.649073549679347, 10.656980242047991, 5.598236560821533, 9.27670669555664, 16.141978536333355, 12.317895003727504, 5.691171756812504, 10.872202430452619, 15.494642666407994, 7.538521885871887, 6.239735509668078, 9.838962742260524, 6.683745375701359, 6.202979973384312, 6.695586843150003, 4.394876744065966, 4.17032790184021, 1.5516363169465746, 0.840784955237593, 0.05865844991058111, 0.08413121090935809, 0.4520250473703657, 3.1084095239639282, 9.096266320773534, 16.561792169298442, 30.425925391060964, 33.22100155694144, 26.471707309995377, 23.028200932911464, 22.941711493900844, 22.349280289241246, 33.338728359767366, 39.41850287573678, 33.83475678307669, 43.89393138885498, 48.39074993133545, 45.26710735048567, 21.232435532978602, 4.524617850780487, 0.42842171820146696, 0.04660070960276893, 0.044697693682142665, 0.060553231808756075, 0.07023932598531246, 0.07549295800604991, 0.05952454557908433, 0.09133736815835748, 0.03355000114866665, 0.15201396441885404, 0.11158839506762368, 0.02708588301071099, 0.04918024190036314, 0.055700149187552075, 0.06490131813500609, 0.04933781469506877, 0.06547550803848676, 0.19415143691003323, 0.2694527969828674, 0.1693959959915706, 0.11017694723393236, 0.03834546257608703, 0.04292179451190999, 0.06659650217209544, 0.05453858205250331, 0.1085533554266606, 0.11936706623860768, 0.03451229611943875, 0.017813313519582152, 0.024561463023668954, 0.07202782215816633, 0.043213805449860435, 0.040796884069485326, 0.0630097592781697, 0.07020751626363822, 0.03433085924812725, 0.07365486770868301, 0.06492416440908398, 0.0807430005765387, 0.05147536963756595, 0.009073332949940647, 0.02086661084155951, 0.026901672627510767, 0.029546088139925684, 0.0524479308431702, 0.08027692844292947, 0.05101939410503421, 0.04429031143497143, 0.10818364205104963, 0.05111270624079874, 0.02919447807861226, 0.05935740204794066, 0.004256709711626172, 0.07298403406249625, 0.044875829480588436, 0.04016376679231014, 0.06846229705427374, 0.04807873868516513, 0.04847476904147437, 0.05807686397539718, 0.029755114245095422, 0.048099179552601914, 0.07203905191272497, 0.09351841719555003, 0.05362605083999889, 0.029910179852907146, 0.037484903753335984, 0.05657034660024302, 0.8157960847020149, 6.381457482065473, 17.31588884762355, 34.705682209559846, 54.601282596588135, 71.36737959725517, 64.17798818860734, 51.01089130129133, 51.628728594098774, 45.62223672866821, 35.842681952885215, 35.046553884233745, 34.02033969334194, 31.45129884992327, 33.164429324013845, 27.525394678115845, 15.07108916555132, 4.18633177450725, 0.9188367298671177, 0.3168578861015183, 0.3283239336950438, 1.127005628177098, 2.8374341215406145, 4.568076227392469, 7.127812564373016, 8.374968613897051, 7.479205983025687, 9.141572918210711, 8.677563531058174, 9.3945620400565, 12.220707075936453, 11.988937752587454, 11.852863362857274, 9.326775414603096, 7.947297436850412, 6.607194031987872, 6.480800654206957, 5.688133222716195, 6.274547287396022, 7.618292416845049, 7.495046138763428, 10.331690771239144, 15.14034012385777, 13.340560402188983, 16.729212488446915, 16.059279339654104, 19.005515302930558, 20.35385319164821, 25.172877073287964, 33.4992595400129, 43.494684423719136, 46.21288224628994, 63.1250581741333, 74.20755304609025, 68.28241416386196, 70.28933879307338, 62.597953932625906, 42.19486059461321, 28.1401469707489, 19.072817291532242, 12.050307716642108, 11.027974094663348, 12.348290766988482, 11.729254041399274, 13.366292187145778, 15.578179121017456, 18.329212393079484, 18.064187254224503, 7.837184122630528, 6.388987158026014, 8.87611699104309, 9.404438035828726, 9.39238725389753, 6.827238270214625, 16.821955306189402, 8.435304164886475, 11.415662731443133, 14.25732135772705, 12.138799973896571, 12.58306518622807, 13.355575459344045, 10.303226607186453, 8.504744461604528, 8.820410677364894, 9.056516545159475, 5.481396087578364, 1.7136938210044588, 0.8001339765531676, 0.22273771012467997, 0.2328636646270752, 0.5407714024186134, 3.2750620671680997, 10.986816440309797, 20.882864713668823, 33.21299723216465, 30.653781141553605, 30.18841164452689, 24.849283831460134, 24.523163182394846, 24.24103852680751, 33.68551295144217, 48.50150421687535, 41.64974314825875, 51.311703136989046, 55.70237752369472, 50.37689249856131, 25.587882552828106, 5.75113080229078, 0.39933398046663826, 0.05771614797413349, 0.06525862789047615, 0.07205512640731675, 0.01849892226579998, 0.007829431527560311, 0.026045649811359387, 0.06792612546788794, 0.05035543741126146, 0.07662404874073607, 0.026275130354666283, 0.04486604839829462, 0.09503533651254006, 0.04348260370482292, 0.03388592687302402, 0.06712283500071083, 0.01859463471919298, 0.039587324152567556, 0.032703264084245474, 0.08482428014810596, 0.07222856674343348, 0.030128562955984046, 0.03433652162285788, 0.0199303529557905, 0.06914905591734818, 0.11587493148233209, 0.023798280761444142, 0.03867013140448502, 0.004561450390610844, 0.02345258922183088, 0.09609118449900832, 0.031933971614177735, 0.027796166682881967, 0.03927346777969173, 0.02131332946009934, 0.14112145533519133, 0.2224527932703495, 0.3497411315994603, 0.24406038810099873, 0.10850473839257445, 0.10097008877034698, 0.1805359667965344, 0.3050998513187681, 0.1079638781292098, 0.18816164189151355, 0.10940813991640295, 0.09783427989376442, 0.17553023754486016, 0.2819674254528114, 0.1840394330876214, 0.22188860497304372, 0.29240166555557934, 0.2268410963671548, 0.2351977436670235, 0.15903008436518057, 0.20686947660786764, 0.24962109114442552, 0.1887824742921761, 0.13930640130170754, 0.14255990886262485, 0.10331491580499069, 0.13606342460427964, 0.15426533004002912, 0.157743758388928, 0.2223857268691063, 0.16865462863019534, 0.12407510860690049, 0.23761986941099167, 1.444970286318234, 8.286680459976196, 25.71341391972133, 44.40598235811506, 63.66001388004848, 78.81751605442592, 71.7572569165911, 57.72091606685093, 65.71277577536446, 56.514020919799805, 42.097554547446116, 40.40568208694458, 47.581496715545654, 42.25638689313616, 46.813418524605886, 40.809817109789165, 17.78098562785557, 4.57335946389607, 1.0624688054834093, 0.4048144263880593, 0.2983819203717368, 1.6915054001978465, 4.3438834803445, 7.023130135876792, 12.246772374425616, 14.31511299950736, 14.035983886037554, 19.30789222036089, 19.80992909840175, 23.05516341754368, 18.03048849105835, 19.405069725854055, 15.891499451228551, 10.658596566745214, 12.557503632136754, 12.927374482154846, 12.116420694759913, 11.216016667229788, 9.875139406749181, 12.717411211558751, 12.027128526142665, 17.58811058316912, 24.92154857090541, 17.301754474639893, 21.42669153213501, 23.526522261755808, 23.358839648110525, 23.92869094439915, 30.330703803471156, 37.52780423845564, 46.156626156398225, 54.513248920440674, 65.30829334259033, 74.60187721252441, 69.43612779889787, 70.80850124359131, 60.89564527784075, 48.49643203190395, 31.16312231336321, 23.125826597213745, 15.663572481700353, 15.849207503455025, 18.24417339052473, 18.600317205701554, 17.162939889090403, 26.34547938619341, 33.214602266039165, 29.858910696847097, 10.673821806907654, 10.266309091023036, 19.50046328135899, 11.348431961877004, 21.85421245438712, 29.56395271846226, 31.929543358939036, 15.909219094685145, 25.24156870160784, 26.37914514541626, 17.675362586975098, 16.876516035624913, 18.03078900064741, 19.42287274769374, 14.7761207648686, 14.703737906047277, 13.052746040480477, 10.484134248324803, 3.6967482396534512, 1.4681111531598228, 0.47464105380432947, 0.3882649030004229, 0.7591253284897123, 3.717783042362758, 11.530828254563467, 22.028148446764263, 40.488591466631206, 43.2341582434518, 36.03309038707188, 35.23195614133562, 34.07165213993618, 31.320328780582972, 46.55265610558646, 54.50310802459717, 47.209556170872276, 59.423822266714915, 63.93267508915493, 60.13472720554897, 32.069181306021555, 8.192946655409676, 0.7755529869879995, 0.1834370975515672, 0.14014960319868155, 0.12779722602239676, 0.21650740158345017, 0.21737281871693476, 0.1281591294599431, 0.26461052681718555, 0.14393303303846292, 0.39057200348802973, 0.14726729983729975, 0.4234963139253003, 0.22090124152600765, 0.1788538106318031, 0.1810031517275742, 0.21229984664491244, 0.2103944117469447, 0.3476437527154173, 0.3397565973656518, 0.29556434441890034, 0.2605513132044247, 0.18415669750954422, 0.13732615113258362, 0.08856532869062253, 0.2425803675183228, 0.35882310569286346, 0.35613594417061123, 0.2108941256467785, 0.15040921552905015, 0.22054776549339294, 0.26103052177599495, 0.14590132742055825, 0.1445597279816866, 0.12049867265990802, 0.2172386452023472], [0.08903771798525538, 0.10589368814336401, 0.04075760028458067, 0.045065802322434526, 0.03637149903391089, 0.012955100325468396, 0.09560685298804726, 0.03996122069656849, 0.07271323073655367, 0.03048022390742387, 0.02021013160369226, 0.01777130372024008, 0.04231291111292584, 0.05141885106318763, 0.1599843760154077, 0.12157492419438702, 0.10025114020598785, 0.04111621621996164, 0.06914383798305478, 0.08846966203834329, 0.021690532165978636, 0.04839072569406458, 0.14404394637261117, 0.11579323586608682, 0.08578808485929455, 0.04422268524233784, 0.026031744932489734, 0.1473292772259031, 0.029129552455352883, 0.07326764812959091, 0.06613085751554795, 0.05462570255622268, 0.0863646903474416, 1.307292056935174, 6.356674126216343, 23.915515422821045, 37.81481695175171, 45.164941038404194, 53.98472377232143, 48.14938340868269, 43.33949988228934, 36.16077743257795, 38.195164816720144, 31.68108967372349, 23.445408991404943, 23.248531784330094, 28.29169586726597, 28.34310037749154, 14.428963576044355, 5.016280199800219, 1.51828214100429, 0.14257968137306826, 0.21612157300114632, 0.5757700215492929, 0.5290959860597337, 1.4517865777015686, 3.553130928959165, 7.1129230090550015, 6.382329480988639, 5.874822633607047, 4.911071445260729, 6.283794905458178, 9.342143961361476, 9.99057069846562, 6.561284678322928, 4.839743409837995, 7.035946522440229, 3.5893147587776184, 5.607440752642495, 5.690730546201978, 7.433109896523612, 14.05383380821773, 15.731336525508336, 16.690585715430124, 21.56851989882333, 24.731129714420863, 29.801779133932932, 32.13200691768101, 32.828171253204346, 35.55169834409441, 35.16517005647932, 36.71573352813721, 50.05382210867745, 50.374564852033345, 43.453634466443745, 57.05236734662737, 60.93620886121477, 58.73187896183559, 62.5538398197719, 69.81838989257812, 52.57961041586739, 36.88855259759085, 35.28130572182791, 26.94630401475089, 17.431162936346873, 18.59110563141959, 19.964311122894287, 26.234494073050364, 23.584034238542827, 26.491669484547206, 25.14587984766279, 16.359966107777186, 10.98508025918688, 14.883086545126778, 17.726536069597515, 5.727021421704974, 5.055551852498736, 17.96568611689976, 9.396247846739632, 10.144624420574733, 12.90670793397086, 9.104163816996984, 10.064324957983834, 11.72090925489153, 9.683642710958209, 4.949867580618177, 6.72482920544488, 7.400136351585388, 2.4638805091381073, 1.4722703014101302, 1.5175503002745765, 0.28977945340531214, 0.2211425828614405, 0.12368188399289336, 0.4439476308013712, 2.939476885965892, 10.8826516526086, 22.433982304164342, 35.11740813936506, 29.987646920340403, 19.862681559153966, 17.271184137889318, 35.306399141039165, 45.789712633405415, 44.92496068137032, 30.464751924787247, 34.74644729069301, 45.07225554330008, 45.90426410947527, 33.366667066301616, 8.884092654500689, 1.2818471023014613, 0.08363452327570745, 0.014653384419424193, 0.011384005924420697, 0.09429575369826385, 0.07207497355661222, 0.0772241111844778, 0.02567854370655758, 0.03601358877494931, 0.12487542709069592, 0.08382253854402474, 0.08289639931172132, 0.07682825385459832, 0.07236122712492943, 0.014776002482644148, 0.08756864895778042, 0.10147614018725497, 0.1295026559382677, 0.1518425393317427, 0.10134198024336781, 0.1684663351625204, 0.014866800646164587, 0.032303501785333665, 0.0633819085944976, 0.06447810905852489, 0.03893207984843424, 0.04517243749329022, 0.06313988193869591, 0.05152889247983694, 0.07830724984939609, 0.10332712264997618, 0.00926053143172924, 0.1045388165595276, 0.12129565275141171, 0.10181527877492563, 0.07527744171342679, 0.08909941717450108, 0.04843955307400652, 0.0362913165507572, 0.020454599289223552, 0.05517711403912731, 0.03228924237191677, 0.06492411012628249, 0.03674714619825993, 0.08854572581393377, 0.025266050394358378, 0.04493432937722121, 0.040915838043604574, 0.04776391879256282, 0.05287909235006996, 0.03770718504009502, 0.0567171544368778, 0.08499838544854096, 0.027742788029302443, 0.10894352663308382, 0.030204742082527707, 0.08321222343615123, 0.07482561881520919, 0.06992074022335665, 0.08061099158866064, 0.04758480929636529, 0.012816594364786786, 0.08514281841261045, 0.06552764666931969, 0.030830707600606338, 0.06823104553456817, 0.07707617697971207, 0.05596781428903341, 1.5317782568080085, 8.162574342318944, 27.603504589625768, 43.58254786900112, 51.783458028520855, 64.00213623046875, 55.08783367701939, 49.09811128888811, 46.17007439477103, 45.03441217967442, 33.99999189376831, 26.66210011073521, 31.97177103587559, 30.869272572653635, 24.544544526508876, 16.57333139010838, 6.061565024512155, 2.211704977921077, 0.3166683577001095, 0.29730169262204853, 0.8116524070501328, 3.03644420845168, 4.892719949994769, 4.614966145583561, 7.745863948549543, 10.80786645412445, 8.79770917551858, 13.041701010295323, 8.128535985946655, 13.906027385166713, 13.43352208818708, 12.123714566230774, 9.330057569912501, 9.454207982335772, 8.70024505683354, 6.004169864313943, 8.298343011311122, 9.61049381324223, 12.326459527015686, 14.633387395313807, 17.55373784473964, 20.519185577120098, 26.779477766581945, 28.010849680219376, 31.393899781363352, 32.316207136426655, 36.32912533623831, 34.77813107626778, 41.79912941796439, 52.76129191262381, 56.96949618203299, 51.80844027655465, 64.08318696703229, 67.7177757535662, 66.69375024523053, 69.6753681727818, 71.97952978951591, 58.008168492998394, 41.53465666089739, 37.204740796770366, 26.770483323505946, 19.714834315436228, 20.01617247717721, 20.007160663604736, 23.735173191343033, 22.768407787595475, 23.36208619390215, 18.629117488861084, 11.715441022600446, 10.273860914366585, 10.478965657097952, 8.068949103355408, 10.004866617066519, 8.643400975636073, 8.345145208495003, 10.16307188783373, 10.077176519802638, 14.805212872368948, 16.186396632875713, 10.994698303086416, 14.335254090172903, 10.274061543600899, 9.18867301940918, 11.35373864855085, 8.24926962171282, 5.65661141702107, 5.033963365214212, 2.5881440469196866, 0.6151755899190903, 0.22133933087544783, 0.25259847566485405, 0.6480459975344794, 3.983192069189889, 11.824849094663348, 26.90873510496957, 40.652308395930696, 35.93456145695278, 26.868187155042374, 18.690449237823486, 33.117754799979075, 49.93174225943429, 49.18645763397217, 37.60286910193307, 43.26219422476632, 52.82568434306553, 54.51857124056135, 39.726196902138845, 12.364817925861903, 1.4666018741471427, 0.073390306904912, 0.013440681189032537, 0.03636670518400414, 0.13138715124555997, 0.04896914626338652, 0.04233955718310816, 0.03546476251046572, 0.016362558152260523, 0.06067494063505104, 0.08447426464408636, 0.040906542113849094, 0.12371719495526382, 0.05023040376337511, 0.02681762758376343, 0.020032504706510475, 0.027681058305980902, 0.07912358854498182, 0.05972274565803153, 0.06448923024748053, 0.04897306141044412, 0.035681998889361105, 0.06976633279451303, 0.038237198921186585, 0.06420914456248283, 0.09070992682661329, 0.016825892397069504, 0.05077413083719356, 0.04906415134402258, 0.0692373536793249, 0.10727200311209474, 0.03369956723015223, 0.03898463917097875, 0.06612874727163996, 0.08263303951493331, 0.24024164729884692, 0.23803244584373065, 0.1597097593226603, 0.20121844698275837, 0.07159616532070295, 0.12033906765282154, 0.15936726198664733, 0.15871707616107805, 0.1470859409975154, 0.13886471571666853, 0.13191971981099673, 0.09585516287812165, 0.11604288247014795, 0.34356920421123505, 0.2913315344069685, 0.28878827659147127, 0.29365801385470797, 0.2169103699603251, 0.15235956944525242, 0.24817518730248722, 0.11975406190114361, 0.13076227477618627, 0.23129016906023026, 0.25106919343982426, 0.19684817934674875, 0.17372989415058068, 0.14533232152462006, 0.23888178169727325, 0.14147835118430002, 0.13241457540009702, 0.12686201477689402, 0.3009465384696211, 0.13671374613685267, 2.8002343348094394, 11.55172061920166, 31.1816531590053, 50.56950003760201, 62.11720807211739, 70.18937505994523, 62.72487667628697, 57.00157254082816, 48.31324972425188, 50.15088496889387, 43.27137279510498, 35.36909621102469, 32.992881774902344, 41.57789877482823, 37.38820798056466, 18.47729066440037, 6.804337876183646, 2.0568860854421342, 0.4447327229593481, 0.5246765517762729, 1.0199294367006846, 3.4922768686498915, 6.449712676661355, 10.941308345113482, 18.231326171330043, 15.690918854304723, 16.582635028021677, 20.350914103644236, 17.20846622330802, 18.45588673864092, 22.428852796554565, 16.86364449773516, 14.274952411651611, 17.56501477105277, 10.483012114252363, 13.250258139201573, 10.558406148638044, 12.200528638703481, 18.435333967208862, 21.653706550598145, 23.56500138555254, 27.281750883374894, 34.53957509994507, 33.1721522467477, 39.01273850032261, 38.831470421382356, 41.4507919039045, 36.598670278276714, 44.99314682824271, 55.46172319139753, 60.83320876530239, 56.93130193437849, 68.625321660723, 69.47049358912876, 68.51408794948033, 72.21216242653983, 75.44508280072893, 62.728851045881, 46.636871746608186, 40.18996136529105, 35.3105263710022, 21.76208107812064, 24.381974049976893, 27.008158615657262, 34.27688455581665, 33.59944908959525, 36.2834826196943, 35.25197042737688, 26.641465697969707, 19.59219513620649, 21.65486863681248, 26.65503552981785, 18.31102548326765, 17.622921058109828, 25.3438982963562, 19.40336046900068, 20.302592856543406, 26.264473812920706, 25.274761983326503, 23.736081668308803, 22.76041735921587, 21.908655064446585, 18.708439861025127, 20.113501105989727, 15.349513905388967, 8.08270479951586, 5.532900043896266, 4.912200961794172, 1.0459067970514297, 0.5392171772462981, 0.25162002816796303, 0.8781295684831483, 4.11377477645874, 13.458017093794686, 28.703076124191284, 43.8632481438773, 39.791221618652344, 31.086907523018972, 28.248137610299246, 48.08345890045166, 57.84903737476894, 55.45004326956612, 43.11499316351754, 50.788899830409456, 60.87391826084682, 62.59204796382359, 47.971092632838655, 18.220315013613018, 2.3317005847181593, 0.16360845869140966, 0.08893415318535906, 0.06886576076171227, 0.27203850394913126, 0.18636543756084784, 0.23219340773565428, 0.13814663567713328, 0.11743405567748205, 0.18141363827245577, 0.15128922116543564, 0.18733625832412923, 0.3173354390476431, 0.1331721054656165, 0.10078864850636039, 0.29167210470352856, 0.2398239682827677, 0.29732519707509447, 0.2882736213505268, 0.19298993423581123, 0.2683824215616499, 0.1419987604022026, 0.23448012503130095, 0.15890648242618355, 0.21573499803032192, 0.21544324154300348, 0.20034905363406452, 0.19709207197385176, 0.16361517618809426, 0.21520601212978363, 0.21153319706874235, 0.2131543800766979, 0.18647673087460653, 0.2602281948285443, 0.2640583621604102], [0.037425925489515066, 0.03721377473058445, 0.04011728035818253, 0.050766375181930404, 0.019056401548108885, 0.06920432937996727, 0.08574013957487685, 0.08268577525658266, 0.07398574852517673, 0.044091738161763976, 0.05873478510017906, 0.04903002781793475, 0.0228108562462564, 0.03847582272386976, 0.08593228033610753, 0.06292741226830653, 0.08490932094199316, 0.15323207048433168, 0.06760130396911077, 0.05588828659217272, 0.06024114641227892, 0.05755922318037067, 0.08143387814717633, 0.07321284285613469, 0.09000980082367148, 0.05958246532827616, 0.05094011068078024, 0.02343388201136674, 0.08951434812375478, 0.016092102575514997, 0.03348353185823985, 0.031666398114923916, 0.4273593766348702, 2.824097488607679, 11.417790617261614, 31.60936689376831, 41.46966321127755, 49.387559345790315, 50.80404690333775, 44.747055530548096, 38.439404419490266, 30.431574276515416, 32.903983048030305, 30.21157693862915, 37.05432619367327, 39.66885689326695, 41.26481989451817, 24.33861207962036, 5.546153732708522, 1.816594579390117, 0.28858585602470804, 0.0627270137358989, 0.5258860811591148, 0.7231149865048272, 1.2259317998375212, 3.183538875409535, 3.993879267147609, 4.118581192834037, 7.286142468452454, 4.609790171895709, 8.377414379801069, 4.411395651953561, 11.579124314444405, 11.263300895690918, 10.617764609200613, 11.521652289799281, 11.12152898311615, 11.159997684614998, 6.406425399439676, 16.8259904725211, 19.174406903130667, 24.008907897131785, 27.855348995753697, 32.024400166102815, 36.21708215985979, 42.439805439540315, 41.60957561220442, 48.59841769082205, 42.882037435259136, 47.07605348314558, 51.146304743630544, 49.90965741021292, 53.63289131437029, 50.37852185113089, 40.98868111201695, 47.46962029593331, 52.52062020983015, 55.036771365574424, 56.217259883880615, 69.09989057268415, 46.773139817374094, 40.39030919756208, 50.45559126990182, 44.19622319085257, 32.977772917066304, 30.517523493085587, 27.78439572879246, 28.124235595975602, 28.746637855257305, 31.38445370537894, 28.680046319961548, 19.187102999005997, 17.580005509512766, 13.424137677465167, 12.300064189093453, 11.597057615007673, 5.121626615524292, 8.155489785330635, 5.569689886910575, 6.221156895160675, 10.682028497968401, 16.088630267551967, 11.70269455228533, 14.671333244868688, 8.06136167049408, 9.307928425925118, 8.685023290770394, 7.118906710829053, 4.413574346474238, 2.3175158372947147, 0.86399671541793, 0.1550790292343923, 0.18028006409960134, 0.1767515055835247, 0.41715564844863756, 1.3904736105884825, 4.67660665512085, 12.39462309224265, 21.795663458960398, 27.04280754498073, 28.56469406400408, 48.661917277744834, 65.44770199911935, 62.02859769548689, 42.33311237607683, 31.51596573420933, 35.85510533196585, 42.862624168395996, 49.776606355394634, 43.88326937811715, 16.721069199698313, 3.9287811602864946, 0.03339506785518356, 0.051000483334064484, 0.047582495491951704, 0.05875623359211853, 0.09008246513881854, 0.057291771817420206, 0.06965809288833823, 0.10876734501549176, 0.11778742314449378, 0.15245098168296473, 0.04134136770984956, 0.017752813640981913, 0.07915547969085829, 0.1571105902216264, 0.07493417084749256, 0.1039451187742608, 0.1431886258402041, 0.049423398316970894, 0.0963403018457549, 0.11910526028701238, 0.0929482306486794, 0.018057942357180373, 0.1449173702193158, 0.028319006752488867, 0.010581731563434005, 0.054098684407238445, 0.059806151182523797, 0.10742202041936771, 0.032518264904086075, 0.02606190411773111, 0.02806116683807756, 0.08380430630807366, 0.1557713792260204, 0.07956505021346466, 0.018548506212287715, 0.041972167789936066, 0.02696349734573492, 0.023507062013127973, 0.01181300460094852, 0.006760794852328087, 0.03296508699921625, 0.028797569019453864, 0.02676341263577342, 0.025291559918384467, 0.019672151721481766, 0.02716947682867093, 0.06790447341544287, 0.017126474928643023, 0.03574198138500963, 0.0742811080334442, 0.07225672594670739, 0.056532789686960835, 0.006527491612359881, 0.10323288770658628, 0.034542541817895005, 0.05532078704397593, 0.10256877155708415, 0.02596921453784619, 0.025234371290675232, 0.05745276103594473, 0.030922038414116417, 0.03750951082578727, 0.044775012747517655, 0.05282705210681472, 0.011251123322706138, 0.03292777096586568, 0.42121776619127815, 3.5746319123676846, 12.398042474474225, 35.03095865249634, 45.589215414864675, 57.7053416797093, 57.85964379991804, 50.05193567276001, 41.9674425806318, 31.588709899357386, 33.32180254799979, 35.94564035960606, 34.0670975957598, 29.664395877293178, 35.34045573643276, 25.496260132108414, 7.104968624455588, 2.6309946732861653, 0.36000910348125864, 0.15720763429999352, 0.8684076273015567, 1.7542025787489754, 2.648132622241974, 4.141308316162654, 7.564787813595363, 8.259336692946297, 13.320007630756923, 12.21585202217102, 12.060861161776952, 10.692333545003619, 7.947815077645438, 9.465808868408203, 10.645093611308507, 10.26023462840489, 12.500958323478699, 8.405004807880946, 10.32351187297276, 14.923613650458199, 17.48890594073704, 21.77689811161586, 26.962109429495676, 31.272792679922922, 36.775182315281455, 40.654410226004465, 43.33335420063564, 46.88089942932129, 44.72431755065918, 48.235596656799316, 51.25958817345755, 52.490346908569336, 56.26302419389997, 57.18296568734305, 48.3020144871303, 55.61637272153582, 60.25254086085728, 62.35583700452532, 62.750960213797434, 74.90528420039585, 55.56563350132534, 45.038987568446565, 55.26086466653006, 43.879854338509695, 34.29870884759085, 30.21290057046073, 28.739328350339616, 28.973972490855626, 29.75956187929426, 32.87117712838309, 28.150129795074463, 20.79425607408796, 16.614575896944316, 13.762382064546857, 12.26424969945635, 6.863088803631919, 8.51604049546378, 6.630701090608325, 9.619397929736547, 8.230737907545906, 8.009276236806597, 10.651938455445425, 14.601184231894356, 11.422808953693934, 11.231840320995875, 15.98913380077907, 11.03628761427743, 10.393878885677882, 8.265105434826442, 5.099906546728952, 3.0877177885600497, 0.698471300303936, 0.27491755517465727, 0.3540013815675463, 0.2755490812872137, 1.719690007822854, 5.5460121631622314, 14.193636775016785, 23.087972811290197, 27.91781156403678, 27.55349145616804, 40.2799266406468, 60.747342927115305, 70.93798092433384, 51.5367101260594, 38.42075892857143, 41.7476224218096, 51.78250959941319, 57.52978502001081, 51.27195249285017, 20.41963873590742, 4.506463944911957, 0.11786911876073905, 0.10018218747739281, 0.0329093385620841, 0.09373266462768827, 0.01865363503540201, 0.051494249874459844, 0.0366220073774457, 0.0694435808275427, 0.07236486407262938, 0.03842882399580308, 0.04430987359955907, 0.07783491483756474, 0.024696934236479656, 0.03820066320310746, 0.03482823559482183, 0.04694555127727134, 0.035552975455565114, 0.006002677429933101, 0.05358174928863134, 0.0811958752040352, 0.043624383596969504, 0.046464140859565566, 0.08845562314880745, 0.035085790524525304, 0.059122255737228055, 0.013104239778060998, 0.04059979339529361, 0.05853489546903542, 0.058833199819283824, 0.014677502946662051, 0.018428334267809987, 0.055247834351445944, 0.02110463583708874, 0.03552492142521909, 0.18484758186553205, 0.349642988294363, 0.11380524361240012, 0.2541373388043472, 0.14478539515818867, 0.12129962896662098, 0.1687661526458604, 0.2089897764048406, 0.16844823184822286, 0.13452173875910894, 0.14453504287770816, 0.0980606052492346, 0.1719885833029236, 0.23356947675347328, 0.15091175213456154, 0.19839088299444743, 0.3248568911637579, 0.2430285806102412, 0.16543716484946863, 0.20646622324628489, 0.10108946343617779, 0.18655514238136156, 0.14970533044210502, 0.21708270428436144, 0.17108581960201263, 0.11203204840421677, 0.1821613431509052, 0.14587827080062457, 0.20673572378499167, 0.17582135620926106, 0.10014025401324034, 0.24039461623345101, 0.7608969019992011, 4.701141178607941, 17.635804755347117, 44.48515360695975, 55.12684086390904, 65.95086274828229, 67.86651584080288, 57.58949783870152, 50.63777651105608, 41.654704162052695, 42.65390723092215, 42.20166635513306, 49.89154693058559, 51.959257875170024, 52.34513998031616, 31.2260799407959, 8.323517203330994, 2.502532035112381, 0.4129420816898346, 0.19378464802035264, 1.189842856356076, 2.3007756727082387, 6.2995191131319315, 11.080642308507647, 11.700205360140119, 11.28838128702981, 18.965726443699428, 17.327322108404978, 19.413419723510742, 17.997112819126674, 24.49363681248256, 26.28610529218401, 24.16747100012643, 21.932904277529033, 15.731051649366107, 18.83940645626613, 12.205798847334725, 24.280400071825298, 25.79528280666896, 27.76874664851597, 35.34455517360142, 36.013979366847444, 44.013558523995535, 48.78696053368704, 47.88664770126343, 50.186098439352854, 46.8667494228908, 51.1980688231332, 53.956104142325266, 53.67356954302107, 58.67416027614048, 59.56460666656494, 55.010396003723145, 58.70651108877999, 64.24496882302421, 64.60747023991176, 67.57286412375313, 76.09543418884277, 59.6199768611363, 50.98805604662214, 58.68108068193708, 47.499792848314556, 43.8012250491551, 34.853407859802246, 34.94113234111241, 32.40322984967913, 37.109296866825645, 42.98339428220476, 34.81276437214443, 23.690503222601755, 23.249336038316997, 20.468406404767716, 17.98923703602382, 20.134515932628087, 13.17878462587084, 19.124517100197927, 17.933211973735265, 17.459780829293386, 21.51501876967294, 27.025470052446636, 21.70625925064087, 25.905813012804302, 15.448628221239362, 16.80049753189087, 14.532982451575142, 17.306562628064835, 12.579307079315186, 7.917146597589765, 3.426304591553552, 0.38991233174289974, 0.7466855017202241, 0.8796817851918084, 0.8006072140165738, 1.7968445420265198, 5.584290223462241, 17.328313963753835, 29.02581821169172, 36.05082218987601, 37.86028248923165, 61.69113063812256, 75.29279218401227, 69.03507777622768, 53.006622382572715, 44.395035471235005, 47.378849029541016, 58.92293357849121, 64.47413430895124, 60.749802589416504, 25.802649634225027, 5.8935354351997375, 0.39096245967916077, 0.17290983029774257, 0.1470727367060525, 0.29821983192648205, 0.14903345863733972, 0.1452460525823491, 0.14601977249341352, 0.2240693758108786, 0.20000966398843698, 0.18580525262015207, 0.13934762908944062, 0.26286495476961136, 0.2036521213927439, 0.3098338815782751, 0.12524290808609553, 0.23030091928584234, 0.2822562913809504, 0.1472257599234581, 0.3194545581936836, 0.24556296318769455, 0.15410284804446356, 0.10292656307241746, 0.22865954307573183, 0.10754309820809535, 0.10968483971165759, 0.2024111079850367, 0.19596688449382782, 0.2647193909755775, 0.07948504414941583, 0.10048273777855293, 0.17038654855319432, 0.2046605194253581, 0.3288627990654537, 0.21627691680831568], [0.0803701455837914, 0.10137270430901221, 0.02638684436013656, 0.02835801912338606, 0.05073963750952056, 0.0675408939964005, 0.08192018419504166, 0.07807024435273238, 0.12298980541527271, 0.04227512010506221, 0.0466666394578559, 0.03587891992979816, 0.008826594716603202, 0.06308367888310126, 0.06938872805663518, 0.0721563163346478, 0.10835336401526417, 0.11039328455392804, 0.004023029460638229, 0.03598371966342841, 0.056777259068829675, 0.05701453597950084, 0.061831673208091936, 0.0198873049978699, 0.15535555939589227, 0.02567693727490093, 0.02142989499095295, 0.03872952696734241, 0.12247622225965772, 0.03327316903908338, 0.010676982613014323, 0.04581149534455367, 0.34486713313630646, 4.687307749475751, 19.269484315599712, 36.92540236881801, 47.951894760131836, 49.24314103807722, 55.213241713387625, 40.098557812826975, 36.197474343436106, 32.4297684941973, 33.849629402160645, 33.547601631709504, 29.93985721043178, 40.63644565854754, 26.082349368504115, 5.845029192311423, 3.832228124141693, 0.559244382594313, 0.21146355223442825, 0.13138677126594953, 0.07919923162886075, 1.1858508991343635, 2.8292775877884457, 3.0199270376137326, 4.142651924065181, 5.695219082491739, 13.791502833366394, 10.340742536953517, 12.642905678067889, 8.496397938047137, 9.437825867107936, 6.997746195111956, 11.54999920300075, 6.488159665039607, 12.901115502629962, 10.86210322380066, 14.9953225340162, 20.91456934383937, 30.176648344312394, 32.514970779418945, 36.42717136655535, 45.79857506070818, 48.698072229112896, 52.06654500961304, 54.83395344870431, 59.449016434805735, 58.44486277444022, 55.89523867198399, 58.90875230516706, 57.669002601078574, 59.45112868717739, 50.7120075907026, 43.37991407939366, 38.428745882851736, 47.2971590587071, 53.40553930827549, 52.9193252154759, 60.43113040924072, 44.87549992970058, 56.02342251368931, 59.79370961870466, 56.34268181664603, 50.1211154120309, 40.64343554633004, 36.68104117257254, 41.044339656829834, 38.128271034785676, 35.667389324733186, 30.425956657954625, 30.04951020649501, 23.611424037388392, 24.884954145976476, 18.53990261895316, 13.431752034596034, 13.183663998331342, 7.018133946827479, 11.820886884416852, 9.802507281303406, 7.651469196592059, 9.06626226220812, 11.184923478535243, 11.856380019869123, 8.737922532217842, 11.6226886510849, 10.344334755625043, 5.824858571801867, 7.653179321970258, 7.118285281317575, 2.452653523002352, 0.16101653634437493, 0.1234108635357448, 0.6112607142754963, 0.07232197387410061, 0.26987441150205477, 2.341975233384541, 7.738502332142421, 22.408732550484793, 36.53670971734183, 49.00078092302595, 35.79724768229893, 35.95707014628819, 18.68075476373945, 17.419967651367188, 23.47483287538801, 32.5567364011492, 42.67620400020054, 47.455390385219026, 43.80432047162737, 23.87923887797764, 5.016237207821437, 0.6484191917947361, 0.03233146760612726, 0.015811363800561855, 0.07929563109896012, 0.04360148982544031, 0.08898359124681779, 0.06920974408941609, 0.1589750416044678, 0.0990491561325533, 0.08017732628754207, 0.08042756321706943, 0.08209513766424996, 0.05927468862916742, 0.03674301052732127, 0.05143930550132479, 0.03592223082003849, 0.07710808169628892, 0.012209889063212489, 0.11079963203519583, 0.07942686655691691, 0.03514815807076437, 0.018115544891250984, 0.04361507070383855, 0.04916751258341329, 0.07321177077080522, 0.007538133899548224, 0.032629446259566715, 0.05990883388689586, 0.004533292883674481, 0.025028245922710215, 0.05425563294972692, 0.08303210631545101, 0.09981182949351412, 0.03299412490533931, 0.03894101954730494, 0.023887394461780787, 0.05816080554255417, 0.03144204729635801, 0.05963547248393297, 0.029159628520054475, 0.026676706038415432, 0.046812266643558226, 0.07566381990909576, 0.03339192623804722, 0.02517798842330064, 0.08651938276099307, 0.014803099778613873, 0.03206220116200192, 0.03199892098616276, 0.043096266221255064, 0.037315826397389174, 0.05230426123099668, 0.010869095384675478, 0.023190761217847466, 0.0371206763333508, 0.05551845786560859, 0.012888587778434157, 0.031205336962427412, 0.0502999909222126, 0.03537324849250061, 0.056459826816405566, 0.02891759168622749, 0.059722861008984704, 0.036426433229020665, 0.02898740615429623, 0.037404446463499746, 0.3458903639444283, 5.050447532108851, 23.134518793651036, 43.43924127306257, 54.95863192422049, 55.970918451036724, 60.64818518502371, 46.72811549050467, 41.40693834849766, 36.772309235164094, 39.958242416381836, 32.70198501859392, 32.50943653924124, 38.38108124051775, 27.894562891551427, 9.775814039366585, 3.5369481401784078, 0.8357331263167518, 0.2826988590615136, 0.33247409814170426, 1.465163271342005, 3.6929293360028947, 4.105432595525469, 6.916445757661547, 10.133533358573914, 10.320318307195391, 15.992847612925939, 14.166892290115356, 10.518814444541931, 7.689856256757464, 15.951689958572388, 14.044161915779114, 13.100438475608826, 14.030660697392054, 17.297140870775493, 11.549683928489685, 15.97321547780718, 25.520163672310964, 29.186825343540736, 35.63428463254656, 38.82838542120797, 44.54047516414097, 48.813613823481965, 52.60037510735648, 53.87194756099156, 60.095198903764995, 57.48066473007202, 55.95954772404262, 58.81745992388044, 57.92282029560634, 60.47197192055838, 57.49030188151768, 49.917943137032644, 47.264446939740864, 54.465038844517295, 60.034006118774414, 60.456942967006135, 65.66330460139683, 53.52268941061837, 57.98750107628958, 62.79446983337402, 56.34873717171805, 51.565024035317556, 40.85324682508196, 39.33016695295061, 39.67154237202236, 39.621261732918875, 35.12497820172991, 31.964551857539586, 28.87846950122288, 25.690868752343313, 23.225243159702845, 19.003847735268728, 15.301270825522286, 11.039178933416094, 7.728939873831613, 10.00721423966544, 8.226720111710684, 10.700443829808917, 9.954587715012686, 12.922228472573416, 12.887391073363167, 11.7047164780753, 17.57911092894418, 17.663121598107473, 11.178043024880544, 9.55569076538086, 7.329790183476039, 7.38694953918457, 2.2980776003428867, 0.5166056762848581, 1.086591322507177, 0.3262260934071881, 0.31951915472745895, 2.8845798202923367, 8.241495456014361, 19.950621434620448, 31.226799079350062, 40.419828619275776, 41.392003195626394, 49.92146239961897, 32.34047719410488, 24.683901071548462, 28.087128741400583, 38.88634034565517, 50.27023070199149, 55.358872481754844, 51.938284737723215, 28.482139042445592, 6.3871806263923645, 0.7977100323353494, 0.0524185129574367, 0.0262136720453522, 0.09967172558286361, 0.05685138223426683, 0.11732618218021733, 0.007417223200068942, 0.07922852398561579, 0.08452079857566527, 0.037679972393172126, 0.052746350544371774, 0.01326085753472788, 0.025564765258293067, 0.04235287682552423, 0.10514064319431782, 0.03434141386034233, 0.09886954791311707, 0.0115822696160259, 0.09004640100257737, 0.046614337978618484, 0.014169484626368752, 0.02770123115208532, 0.03437257897374885, 0.046544282630618126, 0.041717235398079665, 0.016453261320878352, 0.008871617211428071, 0.03974124303619776, 0.00919468978619469, 0.027695093802841644, 0.03100859234109521, 0.028407250231664096, 0.08895270433276892, 0.10491885723812239, 0.16046737081238202, 0.1933708909366812, 0.2040031954113926, 0.1484650769936187, 0.21339179947972298, 0.20040128725980008, 0.1849932497633355, 0.2188465424946376, 0.2006326269890581, 0.09668787462370736, 0.10482357056545359, 0.18506772576698235, 0.18292751775256225, 0.11679612419434957, 0.16594712462808403, 0.22351491770574025, 0.22309425313557896, 0.17981049072529587, 0.09692351626498358, 0.2055730947426387, 0.1316450216940471, 0.11956027229981762, 0.1149526938263859, 0.12190911626177174, 0.25195546873978203, 0.11514630700860705, 0.09963469114154577, 0.15404720817293438, 0.19464912877551147, 0.13645614710237297, 0.05591434572956391, 0.2817752371941294, 0.6138853962932314, 9.298431975500923, 29.247069699423655, 50.968628883361816, 64.28925664084298, 65.71563843318394, 70.23648384639195, 54.64437532424927, 47.214315686907085, 45.158750193459646, 46.012023721422466, 45.0096036366054, 41.817093985421316, 52.52320146560669, 36.06908205577305, 9.480778762272426, 5.047430711133139, 0.8327279218605587, 0.536485666675227, 0.48035448150975363, 1.7200570681265421, 5.253640651702881, 7.653039489473615, 12.00952787058694, 15.83726007597787, 16.690783739089966, 26.095623901912145, 20.505622693470546, 19.558755193437847, 19.181441954204015, 24.797003848212107, 17.642400332859584, 18.9097170148577, 14.725051505225045, 23.01562295641218, 17.998156785964966, 20.010468006134033, 31.39798879623413, 39.29055527278355, 38.633075032915386, 44.62718173435756, 51.20239060265677, 54.95297261646816, 56.41031558173043, 57.83439752033779, 64.95294857025146, 59.6985262462071, 57.91340201241629, 58.39819867270333, 58.721790177481516, 60.829748562404085, 60.98627758026123, 55.78267090661185, 50.25204726627895, 57.7964186668396, 64.37046023777553, 62.99599538530622, 68.2114313670567, 57.24466221673148, 63.35833699362618, 65.66104643685478, 59.468283789498464, 54.89318684169224, 51.629447732652935, 43.613130365099224, 44.32470580509731, 43.30378614153181, 38.49184594835554, 35.74460118157523, 34.77217647007534, 28.1908757686615, 30.055305004119873, 25.568684680121287, 18.915565661021642, 19.409414087023052, 12.814738971846444, 19.508059399468557, 18.459920167922974, 16.628849233899796, 18.547569956098283, 20.067087139402116, 25.156135388783046, 18.781809364046367, 24.923113652638026, 24.19889943940299, 15.734770672661917, 18.734438283102854, 14.295387932232448, 8.893459694726126, 1.5677083688122886, 0.479503544313567, 1.1503624320030212, 0.480592457311494, 0.6086910207356725, 3.0126520565577914, 10.532996586390905, 26.838641677583965, 46.15678596496582, 59.61491857256208, 43.647885254451204, 41.81813621520996, 27.012006180627004, 27.396255459104264, 34.31376906803676, 45.5793593951634, 57.80545479910714, 63.01612431662423, 62.537129402160645, 37.988004275730674, 10.01312107699258, 1.489324546286038, 0.13462104914443834, 0.10862727503159217, 0.18256475936089242, 0.15026869092668804, 0.27806997458849636, 0.15491113252937794, 0.23106481400983675, 0.18278467256043637, 0.16516868211328983, 0.17326041577117784, 0.11277161764779262, 0.11506134085357189, 0.1097003985196352, 0.22629539136375698, 0.18793285345392569, 0.2591723400567259, 0.1409880282091243, 0.2265300830560071, 0.1751750244625977, 0.07447290274181537, 0.12140402836459023, 0.14582364873162337, 0.20884325355291367, 0.2502081867839609, 0.0742784413908209, 0.18971626061413968, 0.13569944484957627, 0.05756019348544734, 0.08530363799738032, 0.2024670328412737, 0.16486539053065435, 0.2509516440331936, 0.21216309469725403], [0.030682233960500786, 0.08615298063627311, 0.08334948428507362, 0.01875895554465907, 0.06417430857462542, 0.01633740994813187, 0.0650877659874303, 0.12932296629462922, 0.09843856282532215, 0.021300293106053556, 0.05659937093566571, 0.0556950669602624, 0.02915449200996331, 0.008353229179712278, 0.12002762007926192, 0.0532599642340626, 0.03798371859427009, 0.022492314589076808, 0.06066744960844517, 0.06197711040398904, 0.04010294291323849, 0.07442883867770433, 0.0403017943858036, 0.0019217309766515556, 0.0670378552749753, 0.01574440935759672, 0.051475396778966696, 0.1025350144399064, 0.02335836784914136, 0.024909268199865307, 0.03636852365785411, 0.2578899088714804, 0.6269479553614343, 10.306017177445547, 26.57756311552865, 40.10292475564139, 52.31370632989066, 56.703585147857666, 51.64142990112305, 40.62410218375069, 33.34465169906616, 20.06100572858538, 15.720169033323016, 39.0386518069676, 33.64640154157366, 29.52861418042864, 18.69525739124843, 7.698062079293387, 1.6292782021420342, 0.1473583320954016, 0.16533292829990387, 0.3383740686944553, 1.039551583783967, 1.8309491234166282, 1.2127967732293266, 3.128598383494786, 5.501673970903669, 11.401012454714094, 11.842819741794042, 10.118561727660042, 9.30642935207912, 5.638930422919137, 6.036914552961077, 7.445116383688791, 5.373044575963702, 12.814855354172842, 19.25971688543047, 13.520455343382698, 30.71408108302525, 34.71396446228027, 39.89168562207903, 48.903301170894075, 51.235245159694124, 56.44851677758353, 58.17330632890974, 58.066620213644846, 60.667799949645996, 58.153278146471294, 63.67675903865269, 63.92947196960449, 63.80880955287388, 63.741960934230256, 59.48752335139683, 50.38924639565604, 42.162714753832134, 33.660471643720356, 39.93126603535244, 52.95228052139282, 51.755897998809814, 53.57031236376081, 44.79742997033255, 56.51743943350655, 64.87428801400321, 62.72311183384487, 54.218607085091726, 48.64977877480643, 41.995919772556846, 42.4936956678118, 45.30177886145455, 44.784707818712505, 41.987866810389924, 40.4062032018389, 36.33107083184378, 34.57254082815987, 32.92523758752005, 24.68810646874564, 19.50748269898551, 8.815395815031868, 11.516635690416608, 6.571085980960301, 6.064070284366608, 5.119493952819279, 14.654438699994769, 7.579696042197091, 11.653887799807958, 19.100248779569352, 13.195933648518153, 11.56982501915523, 5.860965754304614, 5.148901769093104, 4.022162778036935, 3.661064463002341, 0.4574951252767018, 0.2998538256755897, 0.43118170010192053, 0.07062032339828354, 0.5685195763196264, 3.8864866069384982, 9.891508494104658, 19.54016181400844, 32.20868723733084, 30.204722540719168, 16.280753169740947, 25.959244659968785, 21.244999613080704, 26.415918486458914, 32.15290709904262, 39.77903100422451, 48.16463123049055, 44.26179681505476, 33.23860134397234, 11.070466671671186, 1.895284231219973, 0.0930534035765699, 0.0313485248147377, 0.00961018052683877, 0.06186853123030492, 0.04349002009257674, 0.07565773344997849, 0.018083677494100163, 0.047242936212569475, 0.05302555413384523, 0.0901013555537377, 0.03196514690560954, 0.0224987945985049, 0.04697322193533182, 0.04690070689788886, 0.047285443038812706, 0.06530389296157019, 0.0707834092900157, 0.056499378622642586, 0.07063713749604565, 0.0656810634370361, 0.029630443613444055, 0.06652966647275857, 0.009542448313108512, 0.058029434377593656, 0.02188854055878307, 0.09400553070008755, 0.09824508535010473, 0.04070299178627985, 0.012449830072000623, 0.07041866279074124, 0.1331892181187868, 0.04723710420408419, 0.02617392346395978, 0.015959995200059245, 0.030848492003445114, 0.018515811002414142, 0.018056128972343037, 0.025017859247912253, 0.07924780795084578, 0.057173143540109904, 0.03900673905653613, 0.04324446505467806, 0.020713088900915215, 0.037297624695513926, 0.025799365348315666, 0.08130199129560164, 0.08250208225633417, 0.1200674365141562, 0.03849103547898786, 0.016983349840821962, 0.032210773189685175, 0.0404191673733294, 0.07839554761137281, 0.0565827061156077, 0.033434412708239894, 0.028125666680612733, 0.0642495716788939, 0.07486008839415652, 0.08126188309064933, 0.03740194945463112, 0.0050679258919054905, 0.04131469789094158, 0.031126738858542273, 0.030663547106087208, 0.11819915819380965, 0.7976481499416488, 13.49527941431318, 29.923237119402202, 43.70165736334664, 58.75852530343192, 63.80734348297119, 59.872502190726145, 45.7915678024292, 33.02553483418056, 21.13569402694702, 20.97941514423915, 41.002845014844624, 30.382971627371653, 28.03284420285906, 20.843864474977764, 7.597600681441171, 2.153872515474047, 0.3290752348090921, 0.4039094778043883, 0.7780083609478814, 2.3050129881926944, 5.850909973893847, 4.919103128569467, 9.02274135180882, 12.052707450730459, 7.788426876068115, 12.789294668606349, 10.039389610290527, 13.077710918017797, 14.291013172694615, 9.832579953329903, 12.046891808509827, 9.526512673922948, 12.308243955884661, 16.03066144670759, 15.854571512767247, 26.411518539701188, 34.003921100071494, 40.22487258911133, 49.2561411176409, 50.357715470450266, 58.00881814956665, 58.75165353502546, 60.51247297014509, 62.425214767456055, 61.25298418317522, 64.64165537697929, 63.09975283486502, 62.996947288513184, 64.37864521571568, 60.92425101143973, 57.50738402775356, 48.53309767586844, 40.846277781895225, 47.42833062580654, 59.457076345171245, 59.364720889500205, 60.66050434112549, 52.176552363804404, 59.82985414777483, 68.18598011561802, 63.19811848231724, 56.690032686506, 52.17215067999703, 44.49596152986799, 42.509822436741416, 45.49317741394043, 44.5788848059518, 41.19971527372088, 39.95850992202759, 33.913497243608745, 33.11449956893921, 30.61025067738124, 22.317763260432653, 18.214874574116298, 10.873856970242091, 12.02936932018825, 8.724971958569117, 8.435948610305786, 9.45547776562827, 11.180071030344282, 13.183422548430306, 18.48534188951765, 15.211475781032018, 15.912022692816597, 12.891120518956866, 13.19733805315835, 7.495712297303336, 7.107771788324628, 7.236711246626718, 1.3186235917466027, 1.6891744967017854, 0.6743395552039146, 0.500728716807706, 1.0024873954909188, 3.8831045712743486, 10.770319257463727, 21.140651566641672, 33.34180988584246, 34.24208797727312, 25.50805296216692, 27.033418791634695, 25.987727063042776, 30.313916955675396, 36.77667965207781, 46.42230442592076, 54.36101041521345, 53.09300933565412, 42.12590319769723, 12.853464756693159, 2.0009276824338094, 0.22922109865716525, 0.04394053002553327, 0.010321509991107243, 0.0450670236854681, 0.037260396871715784, 0.03782467677124909, 0.023455481477347866, 0.06855887972882815, 0.06565781004194703, 0.032826048388545, 0.021617642237937877, 0.04467273037880659, 0.022945922034393464, 0.0418995543649154, 0.04156538265358124, 0.019728509143793156, 0.050449492542871406, 0.0671029199979135, 0.053341846447438, 0.019523917264970284, 0.06365712239806141, 0.024243494728580117, 0.024928467348217964, 0.104293119029275, 0.035639254575861354, 0.022377375845930407, 0.027274938133944358, 0.03586150872121964, 0.046457253729126284, 0.043216261746627946, 0.013822547974996269, 0.0023024586719527307, 0.05906209682247468, 0.1425821240991354, 0.31885139484490665, 0.1674251774592059, 0.11218410810189587, 0.12044704971568924, 0.08210433859910284, 0.1638033203780651, 0.2595940631415163, 0.25994397007993286, 0.14145910793117114, 0.17658369030271256, 0.1671233108001096, 0.11078175263745443, 0.13676888389246805, 0.21875035337039403, 0.145457049831748, 0.1314124741724559, 0.13141195848584175, 0.08896709606051445, 0.29053349580083576, 0.21288701013794967, 0.14408309784318718, 0.13393868718828472, 0.24284999019333295, 0.14247696474194527, 0.17122344007449491, 0.1641778309962579, 0.17336280670549187, 0.06981740612536669, 0.1228880523038762, 0.08859510280724082, 0.3720986976155213, 2.6273481718131473, 18.355804886136735, 37.16412162780762, 53.46680504935128, 65.2006310054234, 72.87905052730015, 64.63986274174282, 52.89821311405727, 42.49991430555071, 28.553205217633927, 23.646543707166398, 50.74888515472412, 45.339403356824604, 40.09415265492031, 25.431704418999807, 10.54040857723781, 2.4053367248603275, 0.4931025260261127, 0.5433650346738952, 1.014743366411754, 2.5602943641798834, 8.612333842686244, 8.413589307240077, 11.790407742772784, 18.294136149542673, 24.451645374298096, 18.540319510868617, 22.7414105619703, 19.93324225289481, 18.038753373282297, 13.316004599843707, 18.60243466922215, 14.03643204484667, 22.24861478805542, 25.343255587986537, 19.387053046907695, 38.26208291734968, 48.83288812637329, 49.29217447553362, 56.09041357040405, 57.56250408717564, 62.249251638139995, 63.00435406821114, 63.534404345921104, 63.73484597887312, 61.30507482801165, 66.51991326468331, 63.675313813345774, 65.14208548409599, 63.25876930781773, 62.245110511779785, 57.759721755981445, 54.485122612544465, 44.15819569996425, 50.29333346230643, 62.59998975481306, 61.70404733930315, 63.465394837515696, 54.57952431270054, 64.12297235216413, 68.15781906672886, 63.66406467982701, 57.902583667210166, 55.158917222704204, 52.308526447841096, 45.48370354516165, 48.931688036237446, 47.09585932322911, 44.97094733374459, 46.77848298209054, 40.16682733808245, 40.30807031903948, 39.56788567134312, 30.7213454246521, 26.404342787606375, 15.659558159964424, 17.235340118408203, 15.029703957693917, 13.779976640428815, 10.810295718056814, 23.429165840148926, 18.47006627491542, 20.752354962485178, 35.87437963485718, 25.286935227257864, 22.779167073113577, 17.97523467881339, 12.42057808807918, 11.850761532783508, 10.61293647970472, 0.9190273710659572, 1.6217751247542245, 1.0301490426063538, 0.514231726527214, 0.9757310769387654, 4.559554261820657, 13.279750636645726, 24.931091921670095, 41.185798031943186, 37.90631430489676, 26.12461699758257, 37.49571050916399, 33.41000298091343, 36.38934884752546, 43.98371948514666, 52.28301266261509, 61.888320514133994, 60.300650187901084, 51.00859144755772, 18.765818084989274, 3.0345749258995056, 0.298163540661335, 0.10325208346226386, 0.2223146435405527, 0.16349298560193606, 0.15193222809050763, 0.2127644938549825, 0.18150134570896626, 0.2321465073951653, 0.13635908945330552, 0.14281568942325457, 0.21423177155000822, 0.14348669270319597, 0.13550321252218314, 0.11678840246583734, 0.10952449510140078, 0.19768726932150976, 0.1363000569066831, 0.27058141785008566, 0.14759948344102927, 0.12403652710574013, 0.299265698662826, 0.15711885477815354, 0.07716660534164735, 0.2711950034967491, 0.10494375268795661, 0.1840720163392169, 0.1893193447696311, 0.18116499590022223, 0.11902804300189018, 0.16326695201652391, 0.25956952731524197, 0.16322900833828108, 0.21020317343728884], [0.07623267652732985, 0.007838238063933594, 0.060343876614102294, 0.06446360876517636, 0.032409797688680034, 0.027584585893367018, 0.027139716282753006, 0.09061060965593372, 0.01852398056403867, 0.04379195121249982, 0.024772360189152614, 0.109147256772433, 0.05718271088387285, 0.030527809568281685, 0.08575259747781924, 0.027814987547961727, 0.021225430337446075, 0.015310055343434215, 0.03689865967524903, 0.037092015014163086, 0.06966257800481149, 0.08656337897160224, 0.028732165029006343, 0.052719938568770885, 0.029323738999664783, 0.1022584910637566, 0.018633070335324322, 0.03144060880211847, 0.051451824472418854, 0.022183443752250502, 0.08193824679723807, 0.12904558117900575, 2.710861610514777, 19.356677259717667, 37.66320031029837, 56.760591643197195, 52.16801650183541, 48.60534504481724, 37.037268366132466, 47.25544554846627, 70.21624374389648, 36.33882849557059, 34.014590059007915, 25.975722312927246, 47.83007894243513, 31.342785358428955, 9.081417151859828, 3.540038134370531, 0.18791819709752286, 0.19527156251881803, 0.23235527904970305, 0.7720286761011396, 2.186603090592793, 4.597452776772635, 1.8203648456505366, 5.47566556079047, 10.191840035574776, 5.336197844573429, 14.087050540106636, 10.936031188283648, 9.130936094692775, 7.234952483858381, 14.434573377881732, 17.717044830322266, 11.113410881587438, 20.843626499176025, 32.28176491601126, 35.97115067073277, 37.824659075055806, 48.91176755087716, 53.68451990400042, 61.342914717538015, 57.8390736579895, 61.05787876674107, 59.371710777282715, 58.957855224609375, 61.242499351501465, 62.353398186819895, 61.968287331717356, 67.43134321485246, 65.585859979902, 62.027736118861604, 60.713178634643555, 50.06101696831839, 49.00230605261666, 33.00246681485857, 33.850376333509175, 50.64738239560808, 49.11640589577811, 52.62802198954991, 45.08402579171317, 62.6068754196167, 65.64446803501674, 63.903423173086985, 60.808980396815706, 54.28447253363473, 49.75466047014509, 46.44508409500122, 48.04441349846976, 49.31433228084019, 51.1378105708531, 51.238111291612896, 46.07821226119995, 43.58789103371756, 40.416010584150044, 38.04406581606184, 29.480428423200333, 22.312977688653127, 22.468589544296265, 11.148227436201912, 10.215555105890546, 10.649155701909747, 6.261335722037724, 9.7797805922372, 15.289726393563406, 11.856788226536342, 18.502653326307023, 8.996001209531512, 9.149334056036812, 7.298901966639927, 8.004486322402954, 5.05077018908092, 2.534961883510862, 1.996869717325483, 0.3348515491400446, 0.19341054452317102, 0.5781296406473432, 1.2581511395318168, 6.210508346557617, 17.25596410887582, 18.79675841331482, 30.049392087118967, 42.02244452067784, 34.08131013597761, 28.316787549427577, 20.20261696406773, 34.66483722414289, 38.41043390546526, 41.69847433907645, 45.55515881947109, 40.4054354258946, 25.62067457607814, 4.186208009719849, 0.4494967444666794, 0.07589404684092317, 0.06526679745210068, 0.03780737752094865, 0.03987800516188145, 0.06196235226733344, 0.014015656496797289, 0.036360991919147115, 0.07099445403686591, 0.043317519527460845, 0.0645488870463201, 0.0369276907960219, 0.04295697994530201, 0.028823329601436853, 0.00998196767510048, 0.03696375832493816, 0.026568437294502343, 0.03100700117647648, 0.05231264792382717, 0.018961891798036437, 0.014226351798112904, 0.006894603654343102, 0.031861500681510994, 0.013097615579941442, 0.05926165397145918, 0.09942361246794462, 0.05801221315882035, 0.023993951601109335, 0.00913087441585958, 0.035387202565159113, 0.014161796824607466, 0.060786892127777846, 0.11528474172311169, 0.08299949592245476, 0.011545627876850111, 0.042216973046639135, 0.06444803638649838, 0.050308360651667626, 0.05819798247622592, 0.08015441215996232, 0.10850849069122757, 0.0495409680796521, 0.011422999635604876, 0.04564323562330433, 0.04835681929918272, 0.10590022922094379, 0.014514089661783405, 0.05532378277608326, 0.05455341822068606, 0.025489916060385958, 0.10087626094796828, 0.019467429224667803, 0.03665179506476436, 0.02676330067749534, 0.10142208130231925, 0.01912729488685727, 0.013056110441019493, 0.04781010667128222, 0.06000772358051368, 0.012171081949158438, 0.030496437501694475, 0.06552495967064585, 0.053504888234393935, 0.09765984211117029, 0.200815207191876, 3.5595091581344604, 19.945683002471924, 44.825844628470286, 62.751286779131206, 61.67436463492257, 56.054126603262766, 43.40148476191929, 47.720210552215576, 66.86352252960205, 33.61905690601894, 30.219595159803117, 31.288870811462402, 40.545153277260916, 32.32029962539673, 12.846904788698469, 3.7902154070990424, 0.3739326149225235, 0.15308884531259537, 1.2189239987305232, 2.73921959740775, 4.949721234185355, 7.950013313974653, 8.633339984076363, 12.786485859325953, 8.70445305960519, 8.27355704988752, 13.93888281072889, 11.841946874346052, 12.040210247039795, 12.681250180516924, 10.201579672949654, 11.561792033059255, 12.505771688052587, 18.87220890181405, 18.31300745691572, 27.502368347985403, 34.60544054848807, 49.58169201442173, 54.038235323769705, 60.45242663792202, 61.135385922023225, 62.168617793491904, 63.36317988804409, 60.57127557482038, 62.35458632877895, 61.2500034059797, 63.57385621752058, 68.28963334219796, 65.37951237814767, 63.49675900595528, 62.286382811410085, 55.51141670772007, 55.71287972586495, 41.85129301888602, 42.28080981118338, 55.656654902866904, 55.80597516468593, 58.08038459505354, 51.12492513656616, 65.01129954201835, 67.48235688890729, 65.84618813650948, 61.73199994223458, 56.5250129699707, 52.69421400342669, 50.86582681110927, 50.21366194316319, 49.549313408987864, 51.86296626499721, 49.72092696598598, 46.31457608086722, 44.659810474940706, 37.30406876972744, 33.781901836395264, 28.002211332321167, 19.630041973931448, 16.775006328310283, 10.464513404028756, 10.828796165330068, 10.407457402774266, 7.5179135288511, 13.809174707957677, 20.21559793608529, 14.231640815734863, 20.288818052836827, 11.33516524519239, 12.077200719288417, 10.086969137191772, 7.713666864803859, 8.23136671951839, 4.015670554978507, 4.204933839184897, 1.9382966203348977, 0.386281925120524, 0.8536481335759163, 1.4927792123385837, 6.585878261498042, 14.680001122610909, 23.503466401781353, 35.1112242426191, 37.37618064880371, 32.30298471450806, 27.892504487718853, 24.72804992539542, 39.268161228724885, 42.25957611628941, 47.946159022195, 52.135940143040244, 46.59416464396885, 28.819298642022268, 5.679108815533774, 0.5535232467310769, 0.02793598560882466, 0.05977998008685453, 0.04124685795977712, 0.02311029883899859, 0.021670009874339615, 0.053497183469257185, 0.03024491135563169, 0.03862704782347594, 0.06400365701743535, 0.02935887693560549, 0.005885417248854148, 0.03327220891203199, 0.031202809419482946, 0.025644002881433283, 0.019678385761965598, 0.015351892116346529, 0.10592331298227821, 0.06000574904360941, 0.06612492033413478, 0.07071295699902944, 0.08603940744485174, 0.03893176093697548, 0.0271233534107783, 0.056084440888038704, 0.0522851231507957, 0.025240500158231174, 0.025899322038250308, 0.016987777281818644, 0.07808407968176262, 0.10251192389322178, 0.05498459669096129, 0.07141259445675782, 0.19709080989871705, 0.13095862923988275, 0.18105504608580045, 0.125688977007355, 0.10746208791221891, 0.13277100984539303, 0.14059176375823362, 0.18160440160759858, 0.24867654325706617, 0.1447858972741025, 0.1701813731342554, 0.14737864743385995, 0.199002473748156, 0.1617593557706901, 0.13802591072661535, 0.11952853043164526, 0.17126173659094743, 0.21213132568768092, 0.1289643741079739, 0.13635123201778956, 0.21424678074462072, 0.16734771590147698, 0.09292114353073494, 0.20664477295109204, 0.18254543468356133, 0.23227162925260408, 0.08859077375382185, 0.13244715865169251, 0.2481594452900546, 0.11660025827586651, 0.2145432462649686, 0.48850488130535397, 5.122176826000214, 27.24169451849801, 52.04494653429304, 73.9783250263759, 65.9815320968628, 63.71816335405622, 48.94690806525094, 58.50424902779715, 78.79542078290666, 46.55874272755214, 45.699740409851074, 36.351029532296316, 58.511669703892295, 37.916257177080425, 12.721196242741176, 4.538609351430621, 0.3417581942464624, 0.6018929683736393, 1.557276842849595, 2.9978804034846167, 9.433800254549299, 11.678511347089495, 10.876965420586721, 17.024535247257777, 22.668016740253993, 15.92164421081543, 32.689304556165425, 21.242555584226334, 23.12455333982195, 20.064936671938213, 27.020373548780167, 28.655352422169276, 23.39383598736354, 29.02962929861886, 43.283775329589844, 42.51404694148472, 44.92720147541591, 60.612457547869, 58.999565260750906, 68.35065937042236, 65.41518442971366, 66.4937185559954, 64.5584854398455, 62.405551365443635, 62.55830751146589, 62.12808895111084, 65.14212717328752, 68.40867682865688, 63.551163400922505, 63.0506568636213, 60.5604224886213, 57.70510196685791, 60.2168618610927, 41.69218969345093, 44.15850836890084, 58.91664545876639, 58.843453134809224, 59.65471090589251, 54.705126898629324, 66.57102421351841, 68.79385716574532, 66.36271027156285, 61.239643641880576, 57.46789394106184, 54.05124235153198, 53.90852287837437, 52.53669834136963, 52.98639270237514, 54.7371963092259, 52.38480724607195, 49.00578710011074, 48.282827036721365, 46.07401554925101, 39.265614713941304, 36.37151282174246, 31.928365639277867, 30.61085864475795, 15.464075803756714, 18.054701226098196, 18.136335611343384, 15.296354975019183, 15.609539815357753, 29.97010271889823, 20.5544251033238, 29.12625789642334, 23.223084006990703, 20.309492417744227, 20.301170212881907, 15.550659043448311, 12.708924855504717, 4.217750225748334, 5.633040521826063, 1.851344040461949, 0.3715947632278715, 1.2012205315487725, 2.0539724017892564, 8.228845391954694, 21.404175894601003, 26.357112407684326, 39.10220350537981, 51.97854607445853, 47.86233595439366, 39.802515915461946, 29.766457966395787, 47.047631876809255, 50.673976625714985, 55.708092417035786, 60.167710304260254, 53.09136608668736, 36.20933491843087, 7.031563511916569, 0.832261686878545, 0.1398353600608451, 0.17347738412874086, 0.14411649533680507, 0.19468518612640245, 0.0987575285668884, 0.13300393734659466, 0.2128544540277549, 0.1924951057881117, 0.11672475588108812, 0.1615063300622361, 0.07144907249936036, 0.12459349579044751, 0.14037206768989563, 0.10316481028816529, 0.13337654806673527, 0.15349243794168743, 0.22320515289902687, 0.16541511246136256, 0.12566813241158212, 0.19028252522860253, 0.18321589513548783, 0.10259038968277828, 0.060424486574317725, 0.13303823050643715, 0.15785619164151804, 0.1830818708986044, 0.09865508334977285, 0.19070890306362084, 0.1653492267110518, 0.1645724262510027, 0.19507113684500965, 0.26337963715195656], [0.08963136148772069, 0.011872521451940494, 0.014465881445045983, 0.0419483037133302, 0.025112567469477654, 0.05631004699638911, 0.021577259226303016, 0.08694914648575441, 0.05746017063834837, 0.05893004712249551, 0.02726440387777984, 0.01825097539196057, 0.035427650037620745, 0.023081077728420496, 0.09499762353620358, 0.0899426122861249, 0.02447439171373844, 0.06589876461241927, 0.022431835066527128, 0.01983355823904276, 0.0200702193791845, 0.054140295567257066, 0.03747025757495846, 0.001310949694016017, 0.02829229282880468, 0.02499797477919076, 0.03944257227703929, 0.0569239379838109, 0.06362003367394209, 0.007382667107906724, 0.04046458172212754, 0.8795087316206524, 7.167762969221387, 24.923553126198904, 35.55799688611712, 45.68892206464495, 48.398233141217915, 43.45425633021763, 37.80841418675014, 45.73489134652274, 27.376856088638306, 22.130641324179514, 26.643610954284668, 35.383788176945274, 45.98974779673985, 16.870021206992014, 7.822532108851841, 1.7844692575080054, 0.2233928492558854, 0.20978961991412298, 0.6535297547067914, 1.2125222108193805, 2.494677313736507, 6.010814947741372, 5.3414493799209595, 15.320025750568934, 6.140986842768533, 4.69044486113957, 6.307139549936567, 5.696578758103507, 12.77039556843894, 15.912766150065831, 6.029151678085327, 8.869365947587148, 8.600010343960353, 26.17369212423052, 27.026380266462052, 35.14948449816023, 48.67976025172642, 54.61120115007673, 56.55675234113421, 61.64403574807303, 59.02211911337716, 58.46210820334298, 59.5949980872018, 61.96143640790667, 61.25067738124302, 60.64020865304129, 62.781240463256836, 59.207622119358604, 64.73118986402238, 60.414093426295686, 58.336324964250835, 54.38249771935599, 47.14490665708269, 35.70183154514858, 29.982126576559885, 49.533801555633545, 45.34259952817644, 55.135998589651926, 43.34988396508353, 62.323666845049175, 61.289156505039756, 64.54059382847377, 61.01616178240095, 58.74938147408621, 56.72712911878313, 56.19485541752407, 54.68368475777762, 51.59778479167393, 50.21791424070086, 52.295672280447825, 52.43763787405831, 51.520809173583984, 49.56832020623343, 44.854450362069265, 39.383035796029226, 30.131707395826066, 26.6270203930991, 21.12018391064235, 18.327682052339824, 17.34972483771188, 10.683012536593846, 18.294353280748638, 22.673917497907365, 11.1905289377485, 14.552664092608861, 10.651617969785418, 12.885397808892385, 4.516367299216134, 2.731247190918241, 5.371686203139169, 4.415980160236359, 2.3919840242181505, 1.9931843493665968, 0.574898076908929, 0.359213724732399, 0.7618344745465687, 2.5367556044033597, 10.947134409632001, 12.370631831032888, 27.633336680276052, 44.845118931361604, 51.62011282784598, 40.71175023487636, 26.727665049689158, 28.29454115458897, 36.22929014478411, 44.95992054258074, 49.89497239249093, 43.666846888405935, 26.465900353022985, 8.964610985347203, 0.5257340350321361, 0.06305714137852192, 0.027509383857250214, 0.054781246531222544, 0.027102637736658965, 0.015722764090501835, 0.051383034592228274, 0.0060408119461499155, 0.022022649612543837, 0.06094657177371638, 0.06963070042963539, 0.0285786159469613, 0.007502196988623057, 0.03550012097028749, 0.0613743948883244, 0.06028471514582634, 0.055154322047850916, 0.038708495774439404, 0.05172892799600959, 0.0389374708091574, 0.030698735932154313, 0.01862020870404584, 0.05412913705887539, 0.026971336121537855, 0.016182412193822007, 0.12845765772674764, 0.04234098889199751, 0.031246605462261608, 0.022339890178825175, 0.03468229967568602, 0.1471410651824304, 0.04690280357109649, 0.0466716131195426, 0.05438327217208488, 0.023400696559942195, 0.042056896457714696, 0.015020950231701136, 0.13602989140365804, 0.03593112641413297, 0.026285013217212896, 0.02634165053521948, 0.045158086477645805, 0.018946909744824682, 0.0012326671089145488, 0.06335752204592739, 0.022893754565822225, 0.038660401212317605, 0.018877405706526976, 0.025111507258511016, 0.025408705596679022, 0.06266333322439875, 0.040957988638963015, 0.018635815009474754, 0.017894841198410307, 0.03508655387642128, 0.04543630279866712, 0.05711976319019284, 0.03952025096597416, 0.061001356691122055, 0.07644534297287464, 0.019031631627253125, 0.044548124207981994, 0.05172521640945758, 0.058519893059773107, 0.8285398408770561, 7.943176286561148, 30.90822069985526, 43.04127277646746, 55.00655712400164, 54.62979800360543, 49.465045656476704, 39.899922711508616, 45.254885469164165, 38.715293066842214, 26.122171231678553, 25.90833694594247, 33.33256878171648, 47.306584290095735, 20.361187015260967, 7.242177307605743, 2.0311134798186163, 0.5020969691021102, 0.4955818387014525, 2.4833089751856665, 5.2144723534584045, 6.835651670183454, 12.546786035810198, 9.353798695972987, 11.199210711887904, 10.146526489939008, 9.3305196251188, 11.136868000030518, 13.821657146726336, 8.871720518384661, 14.211853214672633, 11.24867754323142, 11.348733339990888, 13.788973689079285, 21.08557493346078, 28.65650408608573, 33.214584895542686, 44.43380989347185, 51.53625501905169, 58.767676080976216, 62.77165194920131, 60.68607371194022, 62.327946935381206, 62.75527504512242, 64.64512252807617, 63.55176094600132, 61.934970719473704, 62.50919764382498, 60.058213642665315, 64.84899657113212, 60.304117338997976, 60.506525312151226, 56.03781918116978, 52.66590009416853, 41.97443246841431, 38.81835222244263, 54.48120035443987, 52.12431580679757, 58.92506667545864, 51.10842316491263, 65.02156897953579, 65.26520756312779, 66.31474685668945, 62.10284614562988, 57.32208251953125, 54.592434065682546, 56.941946574619834, 55.01817103794643, 53.86345338821411, 53.1971697807312, 54.22161218098232, 52.65149647848946, 53.18993323189871, 51.41098942075457, 46.63446419579642, 40.11428506033761, 32.412728037152974, 26.924688168934413, 21.231040682111466, 17.129432201385498, 10.622558866228376, 6.318587575639997, 11.686733671597072, 13.11556817804064, 12.853307553700038, 17.654615265982493, 6.522864179951804, 12.421566469328743, 14.363634875842504, 11.434157967567444, 10.709024855068751, 6.803174921444484, 6.533147513866425, 7.053637070315225, 2.495424027953829, 0.6975732456360544, 0.9183281000171388, 2.8470510797841206, 10.598359159060887, 17.075225830078125, 34.92697886058262, 43.320864813668386, 45.39464153562273, 40.466079303196494, 29.499688829694474, 36.357331548418315, 41.67125824519566, 48.56442710331508, 56.63503074645996, 49.91337122235979, 31.008080210004533, 10.992441007069178, 0.6194569287555558, 0.12049888979111399, 0.023099125063578998, 0.038917029941720624, 0.027750046657664434, 0.03436182080102818, 0.03818652253331883, 0.04834255310041564, 0.024488863169348667, 0.01600394900222974, 0.022213636864242808, 0.040859173584197245, 0.010213949468119867, 0.004402615096686142, 0.040551491879991124, 0.04312589106016925, 0.05455181009269186, 0.04954181285575032, 0.031540590937116315, 0.06050028572125094, 0.013799554967720593, 0.06759404364441123, 0.03511722705193928, 0.026389368510405933, 0.1059220644778439, 0.05339053472770112, 0.014878749647842986, 0.028151296644604633, 0.026019605941006115, 0.015599202863605959, 0.09610340491469417, 0.05235490708478859, 0.0349720782334251, 0.2188686898776463, 0.2363735091473375, 0.10404033759342772, 0.08590494216020618, 0.1692941343145711, 0.1647139008023909, 0.09381999208458833, 0.18527079772736343, 0.11496659022356782, 0.19311687456709997, 0.10012494626321963, 0.20664250664412975, 0.1714964418538979, 0.15799721835979394, 0.163537701059665, 0.22325590731842176, 0.14439279479639872, 0.11071976167815072, 0.15766105854085513, 0.09932385424950294, 0.16512635509882653, 0.14492087146001204, 0.1326341221907309, 0.19894303408052239, 0.1547350934041398, 0.18093263836843626, 0.22451540402003697, 0.11158954179180519, 0.14760666234152658, 0.08429726199912173, 0.23394706792065076, 1.6036348981516702, 13.441740070070539, 38.03025279726301, 50.51009293964931, 61.67553193228585, 63.02450384412493, 57.04864311218262, 49.44481945037842, 56.763172898973735, 37.659903390066965, 32.43613304410662, 34.77978474753243, 47.92405680247715, 55.35473830359322, 22.83261087962559, 11.037206513541085, 2.5617836671216145, 0.8743607135755675, 0.5861455819436482, 3.041685104370117, 5.855247821126666, 5.710658848285675, 19.796065705163137, 16.06956614766802, 22.094514165605815, 16.710398503712245, 13.211098091942922, 20.944257259368896, 16.104187284197124, 22.677629573004587, 28.891910791397095, 12.875652960368566, 19.21839247431074, 16.77597733906337, 32.08981398173741, 33.532791546412874, 38.00515937805176, 52.51251861027309, 57.36902107511248, 59.959875788007466, 66.16459628513881, 64.12723159790039, 63.72554928915841, 65.24589157104492, 66.5565024784633, 63.43081365312849, 61.81147343771798, 62.56696496691023, 59.68121133531843, 62.90467521122524, 59.669552258082796, 59.25698907034737, 57.01723378045218, 55.61334678104946, 43.21121876580374, 39.58375188282558, 58.66809449877058, 55.514592034476145, 62.086066246032715, 54.01565020424979, 68.12309891836983, 65.27770042419434, 66.97720200674874, 64.57320172446114, 60.241653033665244, 56.96442747116089, 56.14845882143293, 56.442683764866416, 54.271420342581614, 54.55078656332833, 56.787654876708984, 56.326291016169954, 55.71626002447945, 55.921113763536724, 53.27857487542288, 43.380528994968955, 36.519505977630615, 31.56155981336321, 29.38533190318516, 25.1507123197828, 25.990226677485875, 17.332672221320017, 29.396268367767334, 40.307021141052246, 25.637595176696777, 29.45850338254656, 21.903971978596278, 22.26993359838213, 13.141094991139003, 13.706376109804426, 17.2431446824755, 9.627376198768616, 7.160436962332044, 4.495260408946446, 2.151403082268579, 1.062458600316729, 0.9154653336320604, 3.3934289727892195, 13.353158354759216, 17.686479704720632, 36.82560886655535, 59.895459038870676, 62.89746298108782, 50.33582517078945, 37.47380978720528, 39.52120072501046, 47.46019853864397, 59.174110957554404, 64.05367101941789, 61.106926100594656, 37.68579585211617, 15.413878543036324, 1.1826313861778803, 0.19169600866734982, 0.11709443532994815, 0.2411105249609266, 0.1594666673668793, 0.14320204726287297, 0.11564246538494315, 0.13357584737241268, 0.12641453450279577, 0.09826324294720377, 0.19899187503116472, 0.1663025819829532, 0.09722212595599038, 0.10472957310932023, 0.1723993005497115, 0.14990191560770783, 0.13281986436673573, 0.17147033182638033, 0.10385366582444736, 0.1155611090362072, 0.1481057112770421, 0.15596432744392327, 0.13172968929367407, 0.12394746259919234, 0.20420511386224202, 0.20477971088673386, 0.11140165544514145, 0.15219330122428282, 0.15490007240857395, 0.13368946127593517, 0.21486014926007815, 0.19063989605222428, 0.14461922193212168], [0.07415619652186121, 0.05880489133830581, 0.06617721502802201, 0.01966391091368028, 0.005595203156449965, 0.03680330175640328, 0.002924724901926571, 0.06254461673753602, 0.07582573193524565, 0.02256592206789979, 0.026420737184318047, 0.030613549253238097, 0.08183728757181338, 0.05554462896127786, 0.07660502261881318, 0.07025633685822998, 0.05717471095600298, 0.037474919110536575, 0.027604473754763603, 0.04732908980388727, 0.01735143982140081, 0.020624156708696058, 0.028937917202711105, 0.09036247618496418, 0.016640983122800077, 0.060492563992738724, 0.02994920579450471, 0.021051090942429643, 0.04081445473379322, 0.008924375853634306, 0.02810843358747661, 1.1822313219308853, 6.858308443001338, 19.257672377995082, 37.98254993983677, 48.54512848172869, 46.04964126859392, 44.55909286226545, 39.01501750946045, 27.162512847355433, 22.966388021196636, 17.83475947380066, 24.10073181561061, 35.64313663755144, 24.156614439828054, 18.254190955843242, 6.934271361146655, 0.4772351203220231, 0.16968191707772867, 0.03869682836479374, 1.6644985122340066, 4.202125898429325, 7.851230774606977, 5.964010144983019, 7.405342289379664, 10.57813903263637, 5.43215594121388, 9.642669183867318, 10.343755449567523, 16.539309535707744, 4.807551537241254, 8.141934718404498, 13.267051935195923, 14.167204090527125, 27.202801976885112, 28.164892980030604, 36.77226407187325, 44.44040373393467, 53.644918646131245, 60.9459502356393, 64.23412963322231, 63.19413716452462, 58.63103975568499, 55.60250759124756, 59.06200177328927, 55.80612455095564, 61.604972975594656, 60.64603819165911, 63.8171751839774, 61.200976916721885, 60.425773348127095, 60.494477135794504, 59.3375186920166, 59.38862269265311, 48.55817025048392, 38.27148035594395, 29.04703974723816, 41.79022182737078, 44.28637259347098, 47.16935736792428, 45.48714290346418, 56.01844760349819, 59.075592449733186, 60.414093426295686, 59.222074372427805, 59.319300515311106, 60.92793355669294, 60.46245288848877, 62.1750796181815, 59.92439133780343, 58.121670791081016, 54.507280417851035, 54.92678485597883, 54.62527820042202, 54.22672952924456, 57.427775042397634, 51.15031385421753, 40.72820009504046, 34.71834877559117, 29.025050435747417, 24.87105601174491, 14.61350338799613, 6.57831905569349, 11.96169126033783, 10.529764805521284, 8.970752324376788, 17.63217953273228, 2.4494558317320685, 8.025668774332319, 12.78394889831543, 8.47364171913692, 6.819041567189353, 4.4383068936211725, 4.992672826562609, 9.484456964901515, 1.023996195622853, 0.6086853753243173, 0.18789773248136044, 2.0209417513438632, 6.114985815116337, 13.174178838729858, 19.366441215787614, 43.92741475786482, 32.93302651814052, 22.50976630619594, 24.01491287776402, 20.503084863935197, 28.925467116492136, 34.1313475881304, 42.65453951699393, 49.06039299283709, 38.86660746165684, 15.209719623838152, 1.8012854180165698, 0.03254659374111465, 0.05261123047343322, 0.07633057555982045, 0.07867156208625861, 0.06980608816125564, 0.020577147802604095, 0.04798832389393023, 0.035774866584688425, 0.012211273274650531, 0.03272123847688947, 0.06764873356691428, 0.03522743470966816, 0.00444382634512814, 0.08593399024435452, 0.06242631415703467, 0.061840053115572245, 0.052569208799728324, 0.05548222070293767, 0.061952228524855206, 0.021636312128975987, 0.061665533908775876, 0.10048756216253553, 0.02892427864883627, 0.02814752738257604, 0.12315234169363976, 0.05222367501950689, 0.04128263371863535, 0.06657329627445766, 0.009416862507350743, 0.0036150789403888795, 0.025995763916788355, 0.1026097618575607, 0.04854526204456176, 0.023089749405958822, 0.034707093345267434, 0.008911496410811586, 0.010018969037836152, 0.06467681125338588, 0.09363960354988064, 0.08284175688666956, 0.0286808813522969, 0.0726939874834248, 0.021334767774013535, 0.028027849072324376, 0.06808929278382234, 0.038268513312297206, 0.10911266505718231, 0.06692757976374455, 0.03395470996786441, 0.016888933389314582, 0.0524598764521735, 0.012082451705022581, 0.03493802595351424, 0.018387379590421915, 0.013072907575406134, 0.03653104297284569, 0.03223444727648582, 0.023314702424353788, 0.039855284416782, 0.07317699585109949, 0.049649777955242565, 0.046037959799702675, 0.036801018486065526, 1.5283303218228477, 9.3479483127594, 25.182121651513235, 44.17070245742798, 53.267600195748464, 51.92726142065865, 47.67467553274972, 40.21466221128191, 34.41407673699515, 25.555608170373098, 28.584741353988647, 27.640797308513097, 35.264313902173726, 32.12479816164289, 16.922627755573817, 7.277181463582175, 0.6742779442242214, 0.1805847127522741, 1.5860098153352737, 4.985490126269204, 5.709000834396907, 8.128544671194893, 10.420990756579808, 9.458289180483137, 9.181512032236371, 12.84353404385703, 11.824203780719213, 13.019371237073626, 12.478953378541128, 10.562104327338082, 10.471003021512713, 14.240004709788732, 11.627424716949463, 20.60018072809492, 28.91062923840114, 34.11902495792934, 42.40027366365705, 52.911619663238525, 59.75846835545131, 64.66652992793492, 66.1421605518886, 60.52035222734724, 58.37333106994629, 61.586483819144114, 60.10793495178223, 62.084857259477886, 61.22214807782854, 63.76918397630964, 60.706376348223, 61.28771822793143, 60.47863524300711, 60.465774127415244, 60.389232771737234, 53.38126230239868, 45.71190323148455, 36.79562738963536, 48.63593448911394, 49.89802959987095, 54.030310903276714, 52.61407348087856, 59.231774057660786, 61.978911127362935, 60.2520614351545, 59.121256010872976, 59.23084994724819, 60.779568672180176, 60.92545304979597, 60.621622221810476, 60.412703786577495, 59.68360151563372, 55.991276672908235, 56.42147786276681, 55.28050722394671, 55.29622752325875, 55.560321603502544, 48.82690225328718, 42.13693346296038, 34.51682669775826, 27.78466670853751, 22.97570902960641, 16.333133901868546, 8.263240712029592, 7.023348569869995, 8.718708157539368, 10.985253095626831, 13.703330193247114, 9.356070756912231, 15.13286907332284, 14.10161396435329, 11.4544632094247, 10.567137428692408, 8.644498791013445, 6.9079007761819025, 7.902856758662632, 2.2354033291339874, 0.8949583768844604, 0.6472166106104851, 2.2220032938889096, 6.78308116538184, 15.762627737862722, 21.900847026279994, 43.32286589486258, 45.76608528409685, 31.844486985887798, 27.404857328959874, 25.005098921912058, 33.896234444209504, 41.43197618212019, 48.30047198704311, 54.40623276574271, 43.84399815968105, 17.718656812395366, 2.3447199889591763, 0.05100947392306157, 0.020390472640948634, 0.011353650812192686, 0.052025488511260064, 0.047684513232005496, 0.020172405056655407, 0.023435656380440508, 0.07311866898089647, 0.0068135950548042145, 0.04038790047967008, 0.036426823386656385, 0.02397655905224383, 0.035178149318588633, 0.021595182728820612, 0.07232292382312672, 0.04870998999103904, 0.04289093134658677, 0.04389298168410148, 0.05991834694785731, 0.04265036014840007, 0.053631336627794166, 0.025333466241136193, 0.0378418403145458, 0.023409159587962285, 0.025092771210308586, 0.018903963567156876, 0.021964762093765394, 0.05306634087381618, 0.012966526007013661, 0.10595557732241494, 0.02935174892523459, 0.08765936908977372, 0.1266122188951288, 0.1341075881251267, 0.2009725866041013, 0.09725190007260867, 0.09036760590970516, 0.12984390476984636, 0.16872446345431463, 0.18746557352798326, 0.24112550701413835, 0.21392796428075858, 0.09578943319086518, 0.10748573485761881, 0.128512211942247, 0.13222037867775985, 0.20319853430347784, 0.3705594816378185, 0.10220965689846448, 0.1410938118185316, 0.22309114544519357, 0.14779289306274482, 0.14513064734637737, 0.09496576631707804, 0.09281916650278227, 0.12274798910532679, 0.17025977107031004, 0.25177956532154766, 0.14310260117053986, 0.1719007808715105, 0.08376410310821873, 0.10282027734709637, 0.1387260231588568, 2.2907266233648573, 13.482286282948085, 31.051259790148052, 52.98101132256644, 63.42078740256173, 59.0340769631522, 57.857538495744976, 52.08530861990792, 38.088259833199636, 34.36335488728115, 29.1675614629473, 33.4173298563276, 46.050749506269185, 35.41270310538155, 23.26996350288391, 9.262456808771406, 0.9680246561765671, 0.5335200886641229, 1.3199280074664523, 6.166380337306431, 11.965976561818804, 16.952904530933925, 16.74482682773045, 18.425394569124492, 21.606090545654297, 17.767773628234863, 18.432585954666138, 20.087801456451416, 24.77191390310015, 13.693788579532079, 18.932005098887853, 22.3060816015516, 18.678336790629796, 36.134103298187256, 39.785333020346506, 39.99168757029942, 48.46833004270281, 56.05653762817383, 63.66939394814627, 66.278810773577, 69.06771346500942, 64.13083076477051, 61.302851404462544, 64.28889533451625, 62.48469829559326, 64.41447707584926, 63.96398367200579, 63.621625082833425, 61.40142549787249, 60.73951230730329, 59.161868231637136, 58.712021010262625, 62.243165016174316, 57.57120323181152, 46.73825986044747, 38.63232462746756, 52.26255716596331, 54.19968714032854, 55.2377792767116, 56.65696620941162, 63.29995822906494, 62.29051004137312, 63.83162743704659, 59.85443687438965, 61.85518455505371, 62.69235910688128, 63.872371673583984, 61.66629082815987, 61.88254656110491, 60.028503145490376, 57.894926752362935, 56.92086574009487, 58.175206661224365, 57.39029993329729, 59.39050565447126, 51.71937479291643, 48.28053413118635, 40.94146810259138, 35.41991186141968, 31.790544646126882, 20.256305694580078, 12.226630415235247, 19.321072953087942, 17.440437044416154, 19.980644600731985, 35.511242457798545, 18.591324499675206, 22.081927503858292, 24.44097294126238, 17.279756477900914, 15.545929057257515, 10.127417206764221, 10.59949084690639, 14.868352890014648, 3.7755164929798672, 1.5382429042032786, 1.1841529331036975, 2.547982156276703, 8.308245062828064, 17.260056597845896, 26.587928090776714, 55.79365253448486, 43.215853214263916, 32.75409303392683, 33.877720969063894, 31.766538619995117, 38.85279791695731, 45.99086645671299, 54.32248265402657, 62.385700362069265, 52.34664079121181, 23.109531334468297, 3.763859587056296, 0.1839175953396729, 0.17312821000814438, 0.18675202610237257, 0.13264550800834382, 0.2281376953635897, 0.09162841896925654, 0.16207243182829448, 0.18765267277402536, 0.08448064287326165, 0.26672633471233503, 0.14074361989540712, 0.11416555249265262, 0.13485209031828813, 0.1409334061401231, 0.1512498797050544, 0.16599329215075287, 0.13662316171186312, 0.18255264072545938, 0.26673998683691025, 0.10716533062181302, 0.184038944542408, 0.1749886716050761, 0.09852941187896899, 0.0823052188913737, 0.2397331531558718, 0.1270209683903626, 0.12485066056251526, 0.11698114712323461, 0.16351326022829327, 0.20021040178835392, 0.09909976127424411, 0.19313051312097482], [0.04041375605655568, 0.03487398921112929, 0.03213913006974118, 0.048559480745877535, 0.06258106085338763, 0.031118562511567558, 0.031478013045021465, 0.032346849995000024, 0.017104234247069274, 0.04617976683325001, 0.07956029368298394, 0.09063414125038044, 0.08183248354388134, 0.07903875131160021, 0.006046920881739685, 0.014154948709931756, 0.01381375840199845, 0.05395825819245406, 0.027509322789098536, 0.054779550193675926, 0.01680786202528647, 0.07503693497606687, 0.046987036908311505, 0.0487935956833618, 0.0446984807827643, 0.0440343442772116, 0.04532578640750476, 0.01715210828531001, 0.02580651032206203, 0.0047000572833764765, 0.25090713213597027, 2.300473208938326, 9.764408571379525, 28.97531349318368, 43.903787408556255, 59.168211936950684, 49.3117927142552, 44.45467185974121, 32.76469251087734, 24.84878008706229, 21.393413134983607, 13.946636131831578, 26.423349584851945, 35.412098612104145, 25.103567055293492, 11.411941971097674, 2.8157893972737447, 0.23587763575570925, 0.23907036014965602, 0.25953006371855736, 4.5740247539111545, 6.862961564745222, 8.052365490368434, 8.822502085140773, 7.218658523900168, 4.584265964371817, 12.366990974971227, 8.39988659109388, 8.997402140072413, 12.247856293405805, 7.325864451272147, 10.202949336596898, 22.96061406816755, 20.799628768648418, 29.469297409057617, 32.59454154968262, 46.655204568590435, 51.84077024459839, 59.086250986371724, 59.80393041883196, 62.04810128893171, 60.70961420876639, 59.72772257668631, 54.6594147000994, 54.755351952144075, 56.07692016874041, 58.23231043134417, 60.0380916595459, 61.73730836595808, 60.26881354195731, 57.460087639944895, 58.925817080906455, 58.76149913242885, 51.16161509922573, 47.928027697971885, 41.71527508326939, 34.63495997020176, 37.77599736622402, 43.44414670126778, 45.98176431655884, 45.80668360846383, 54.25239964893886, 58.93886579786028, 59.832105364118306, 55.05206782477242, 60.624922616141184, 62.07294109889439, 60.30786936623709, 62.03086975642613, 60.548422949654714, 61.11140768868582, 60.11795425415039, 59.80456270490374, 52.8549918447222, 53.87315307344709, 52.62442282267979, 51.102947984422954, 48.98665870938982, 44.654432569231304, 37.084026268550325, 29.323697907584055, 24.2499634878976, 14.282657963888985, 7.862525071416583, 6.713660844734736, 9.458477650369916, 11.632634128843035, 6.100633442401886, 10.714533908026558, 14.709784575871058, 11.27945111479078, 8.181086080414907, 10.897370542798724, 6.710466844694955, 11.24003745828356, 3.708646595478058, 0.6552841748510088, 0.26018623422299114, 0.46120036074093407, 3.9401592697416032, 11.86921421119145, 36.38756316048758, 35.37264674050467, 15.706243106297084, 18.81013195855277, 24.15415825162615, 30.35991403034755, 30.298332146235875, 31.893040997641428, 42.94882352011544, 51.14510270527431, 41.565034185137065, 14.18443214893341, 4.018210990088327, 0.23519527379955563, 0.061633893820856295, 0.025947314820119312, 0.02339444725242044, 0.006270936249555754, 0.04143553479973759, 0.03658514596255762, 0.05043848670486893, 0.017332520568743348, 0.04718863305502704, 0.03947815126074212, 0.02903377723747066, 0.015485504143206137, 0.05849374232015439, 0.016901091040511216, 0.04789997524182711, 0.052082325997097154, 0.014747936577935303, 0.01932208702367331, 0.027351836507607783, 0.02723189696137394, 0.022969818341412714, 0.042339625036610026, 0.01140836363525263, 0.008321959741546639, 0.05740733990179641, 0.05239840117948396, 0.07859271631709167, 0.02119601414805012, 0.08095893077552319, 0.04467897290097816, 0.039504244324884245, 0.06480119350765433, 0.028013221553659866, 0.013923690404876002, 0.04567548978541579, 0.016935541959745542, 0.04111305424677474, 0.03026590183643358, 0.05931462041501488, 0.025211467341120754, 0.03543063219902771, 0.03383016486519149, 0.031040727759578397, 0.06648849296782698, 0.07907527006630387, 0.02345276394459818, 0.051673586679888625, 0.03642316269023078, 0.0769448804536036, 0.0808759391573923, 0.06588416253881794, 0.03243334285382714, 0.07231649131114994, 0.03169110018227782, 0.0573548823595047, 0.06109608696507556, 0.06944471398102385, 0.03348401701077819, 0.018673622980713844, 0.05029638111591339, 0.009818294002408428, 0.3100131776716028, 2.9409968044076646, 11.494026252201625, 31.78127227510725, 49.91277715138027, 66.18983214242118, 54.389313902173726, 51.24952023369925, 39.212124007088796, 31.23713799885341, 28.679056201662334, 19.41820182119097, 28.89967540332249, 32.9892270224435, 27.526379585266113, 12.844040393829346, 3.845652912344251, 0.7573947384953499, 0.8888172007032803, 1.9821236857346125, 3.8014845166887556, 5.020160334450858, 9.410422171865191, 10.536248343331472, 7.580477714538574, 10.1095837865557, 12.833439179829188, 10.494283829416547, 14.056714705058507, 13.137445449829102, 10.90832872050149, 8.52240765094757, 13.383455974715096, 19.019644464765275, 25.748809780393326, 32.149360043661936, 46.80508416039603, 52.530212197984966, 58.17927483149937, 58.71325084141323, 62.01880768367222, 61.90747669764927, 59.387385913303916, 57.82705327442714, 58.21269914082119, 59.182344572884695, 61.62056473323277, 61.955113547188894, 62.99104131971087, 60.41606671469552, 58.07362747192383, 59.91706793648856, 60.383806228637695, 53.032956055232454, 51.67951645169939, 48.096000398908345, 41.725784233638215, 44.62133135114397, 49.14876018251692, 51.989486013139995, 52.92353234972273, 57.228789057050435, 59.67099748338972, 61.781227929251536, 56.829663685389924, 61.67006369999477, 60.730354581560405, 61.417038100106375, 62.1312712260655, 61.317129952566965, 60.49561664036342, 60.73400933401925, 59.48382690974644, 55.826659951891216, 56.51474700655256, 55.30915117263794, 54.477333681924, 51.95144462585449, 44.60027830941336, 36.112157412937705, 28.24348405429295, 20.87998989650181, 12.863830600466047, 8.674644419125148, 7.969545568738665, 10.303696479116168, 17.55383685656956, 13.604940227099828, 11.428102612495422, 13.330541099820818, 11.887339455740792, 13.747190696852547, 10.347750663757324, 6.901676493031638, 7.1174710392951965, 2.7970338208334784, 0.8483121884720666, 0.5226977808134896, 0.8980782809002059, 4.546075625079019, 11.63097437790462, 31.910276004246303, 40.49828767776489, 19.001506192343577, 22.241782971790858, 28.14160782950265, 33.27905723026821, 35.7322542326791, 36.428644384656636, 47.67351518358503, 57.25491428375244, 48.99645219530378, 19.01077856336321, 4.397695975644248, 0.3609111207936491, 0.04054035372766001, 0.031010597412075316, 0.032254189252853394, 0.018161770089396408, 0.02984421607106924, 0.020093018155811087, 0.03059817025704043, 0.022553615138999054, 0.045724025395299704, 0.035687593410589864, 0.029934834422809736, 0.0476612157321402, 0.06491665981177773, 0.006508290767669678, 0.03723274656970586, 0.05139555695599743, 0.005562141537666321, 0.052077389654836485, 0.03997685414339815, 0.022752554821116582, 0.06266313644924335, 0.05484873362417732, 0.018412792423207845, 0.026727243326604366, 0.05721389635332993, 0.024384395917877555, 0.0710137380020959, 0.05976438735212598, 0.09143184737435409, 0.06886307376303843, 0.08757307300610201, 0.1279638742229768, 0.09328731495354857, 0.1644102699522461, 0.15363254185233796, 0.11707492066281182, 0.13870831339487008, 0.19775451214185782, 0.20134955351906164, 0.1041600311707173, 0.06734137077416692, 0.1559546651052577, 0.13299109946404183, 0.14847862055259092, 0.23185009615761892, 0.0814500612073711, 0.16788177724395478, 0.17691116487341269, 0.10414976493588515, 0.11558335141411849, 0.10879242366978101, 0.18444991963250296, 0.16626386477478913, 0.12444902211427689, 0.17441777938178607, 0.16013164525585516, 0.12569703800337656, 0.08190351937498365, 0.12824744757797035, 0.17256683084581578, 0.07488427138222115, 0.4347942205412047, 4.921880670956202, 16.277511835098267, 40.66148001807076, 58.17942074366978, 73.61921433040074, 62.33506189073835, 57.49658652714321, 44.29970966066633, 36.37435463496617, 29.768118585859025, 21.636872802461895, 36.76088292258126, 45.588694299970356, 32.31279904501778, 15.30847089631217, 4.098381042480469, 0.8826067053845951, 1.0934474574668067, 4.137851587363651, 10.181435108184814, 10.769614015306745, 16.67983337811061, 21.22173704419817, 16.645293882914952, 17.190803902489797, 22.11348795890808, 18.281019687652588, 19.76967297281538, 23.664148705346243, 12.595580628940038, 20.105540207454137, 29.844194412231445, 27.61651509148734, 36.89367689405169, 37.150357246398926, 52.16762045451573, 54.187847409929546, 61.914091382707866, 60.51774665287563, 65.08190713609967, 63.74513626098633, 63.87544277736119, 60.06349427359444, 60.70755059378487, 62.43843024117606, 63.82259477887835, 62.888583183288574, 63.472732135227744, 61.388578278677805, 58.87511607578823, 57.73830393382481, 59.06119578225272, 55.90232236044747, 55.046550955091206, 51.74227952957153, 42.769521781376426, 49.43091263089861, 55.30483981541225, 55.08946997778756, 55.1062707219805, 59.3601142338344, 63.004048347473145, 63.65437889099121, 59.16295215061733, 65.09509481702531, 63.4901373726981, 62.9646520614624, 64.77100304194859, 62.52750614711216, 62.94046538216727, 60.9338812146868, 61.87943376813616, 60.022249766758506, 61.762259347098215, 63.23708398001534, 62.59047072274344, 59.776151520865305, 51.64639438901629, 44.98166840417044, 35.821441309792654, 30.434426512037003, 18.239485093525477, 13.277795587267194, 16.113162619727, 16.62218417440142, 16.078640495027813, 12.889389548982892, 22.995897020612443, 30.69340671811785, 22.274882452828543, 20.305754286902292, 25.30233243533543, 15.143551928656441, 19.311531339372905, 8.300486530576434, 1.6749260212693895, 0.7184988856315613, 1.0315086096525192, 5.313043841293879, 15.98562843458993, 45.59280415943691, 42.4437381199428, 25.463419471468242, 31.480067866189138, 36.30418130329677, 42.428188051496235, 41.96626833506993, 43.942711217062815, 57.34962865284511, 64.69533715929303, 57.55614995956421, 25.164497545787267, 6.138711741992405, 0.6441784564937864, 0.1518086940050125, 0.1095951713089432, 0.16829290161175386, 0.08417712737407003, 0.08952649390058857, 0.14834678119846753, 0.12091507603015218, 0.11260129857276167, 0.14949210759784493, 0.07262411194720439, 0.1742224291499172, 0.11816563856388841, 0.17435287072190217, 0.10824028615440641, 0.19210323824414186, 0.17073344279612812, 0.15939772820898465, 0.14443126773195608, 0.1677899036024298, 0.16075196196990355, 0.1136167940816709, 0.20419427087264402, 0.10737932699599437, 0.08713986232344594, 0.12858757004141808, 0.13090783410838672, 0.15280018294496195, 0.12990072529230798, 0.272010005478348, 0.09712900381003108, 0.15492406540683337], [0.06443888294909682, 0.015661733258249502, 0.01315933682157525, 0.021904306319941367, 0.04829643986054829, 0.07182920138750758, 0.10588334048432962, 0.006308685697149485, 0.07124061975628138, 0.12491056163396154, 0.03567093537588205, 0.03544708667322993, 0.029823717528155873, 0.035908249605979235, 0.0697390828281641, 0.0099985239295555, 0.13878247727240833, 0.016773818227063333, 0.06034173244344337, 0.01172488325807665, 0.06853537527578217, 0.10355211129145962, 0.04278232503150191, 0.05757909747106688, 0.01286368808775608, 0.006737743321407054, 0.034003371106726785, 0.00554120576375031, 0.03253473973433886, 0.070161844071533, 0.5589749770505088, 5.0402310746056695, 17.276770489556448, 37.41433668136597, 49.92714255196707, 57.18827411106655, 49.86120762143816, 34.734982763017925, 25.40254282951355, 22.578697647367203, 22.711802550724574, 31.319776398794993, 32.36653988701956, 40.59114687783377, 18.165066412517003, 5.554408626896994, 1.4033869462353843, 0.2588402921600001, 0.5875410842044013, 2.396334682192121, 3.0993879394871846, 3.5137891428811208, 5.565454959869385, 5.783386945724487, 4.424476070063455, 6.930855453014374, 8.95012833390917, 9.435366204806737, 11.300537160464696, 8.658677458763123, 12.037664600781032, 8.598982010568891, 20.487338508878434, 25.113796540669032, 33.53735998698643, 42.30197402409145, 52.90437616620745, 55.7790196282523, 58.338784626552034, 57.345633438655305, 58.61463505881173, 59.86271912711007, 56.009807518550325, 51.95378964287894, 50.92196478162493, 55.122619833265034, 57.69892154421125, 60.276915141514365, 61.81182084764753, 62.20764582497733, 57.074177742004395, 59.24419048854283, 57.62754270008632, 51.745969023023335, 53.54904045377459, 47.346998487200054, 41.21010977881295, 37.94359833853585, 41.87230437142508, 44.819917815072195, 49.46344062260219, 51.08482013429914, 57.068751198904856, 55.02448347636631, 57.44074732916695, 60.48124776567732, 63.38067545209612, 59.62251990182059, 62.45475155966622, 59.16837174551827, 59.94595854622977, 56.35767255510603, 52.27912514550345, 47.872171129499165, 50.22269112723214, 48.53971583502633, 48.06995160239083, 40.6926600592477, 34.759867736271445, 29.422536032540457, 24.755017621176584, 21.158569233758108, 14.09902228627886, 11.295244370188032, 9.380610925810677, 9.06032850061144, 16.68823548725673, 13.233558143888201, 10.828162142208644, 11.76898123536791, 9.548488089016505, 11.237721102578298, 7.002628173146929, 5.55336422579629, 3.412181292261396, 0.6489503490073341, 1.0167177404676164, 0.5252317019871303, 1.0630677619150706, 3.0129208649907793, 13.748407500130789, 23.28910752705165, 18.95607192175729, 34.406433718545095, 22.910673890795024, 18.02770573752267, 20.48334676878793, 19.525827680315288, 33.44217314038958, 38.778681482587544, 46.60602521896362, 42.44153206689017, 19.55713973726545, 5.327240748064859, 0.6321753891451019, 0.01946687452229006, 0.024324764564101185, 0.07334137774471726, 0.10171973425894976, 0.0471119925246707, 0.02411308029799589, 0.038095615804195404, 0.08082667751503841, 0.03324271299477134, 0.04412579044167485, 0.09415361418255738, 0.02337388933769294, 0.012807002424129417, 0.026676921473283852, 0.024490323715976307, 0.033866938070527146, 0.03860804545027869, 0.031229608160044466, 0.07195647420095545, 0.0477433965009238, 0.008924867791522826, 0.02596430024797363, 0.028287531209311316, 0.07442269793578557, 0.034493039295609505, 0.06966261193156242, 0.06513803186161177, 0.05424603846456323, 0.10758186291371073, 0.12649811644639286, 0.033105214658592425, 0.009112792305781372, 0.03464221861213446, 0.050777733858142576, 0.05048575345426798, 0.01012239304171609, 0.06893799759979759, 0.11481975524553231, 0.10040226352534123, 0.02111360946271036, 0.030251133521752696, 0.0627701889191355, 0.06768109968730382, 0.09495113710207598, 0.04835700589631285, 0.013012444168063146, 0.02009439727823649, 0.06551938211279255, 0.022655685465516787, 0.02945159196055361, 0.024270459710221206, 0.040486036999417205, 0.03330627476264324, 0.008500857195550842, 0.031033039957817112, 0.041825631367308755, 0.04230165760964155, 0.04609831888228655, 0.08893162224973951, 0.03223322930612734, 0.03473618892686708, 0.7138311075312751, 5.6320986066545755, 20.87586440358843, 43.09695911407471, 57.70448705128261, 63.87921564919608, 55.43424654006958, 41.535851751055034, 30.849227019718715, 26.133078166416713, 23.84885093144008, 26.934547662734985, 28.308720690863474, 37.26490177427019, 21.332772731781006, 7.179960097585406, 1.7766475400754382, 0.19663693782474312, 0.6449708225471633, 2.081081449985504, 4.414281325680869, 5.413419255188533, 10.28308377947126, 9.318348118237086, 12.139707582337515, 7.354155778884888, 11.838240878922598, 14.0244186094829, 12.177787184715271, 8.718015943254743, 12.980381420680455, 10.90821841784886, 14.078572869300842, 25.07347093309675, 32.46925858088902, 43.60517120361328, 50.69491154806954, 55.76239953722273, 58.99247809818813, 59.11436339787075, 60.01409258161272, 62.49445356641497, 57.73055321829659, 54.893301486968994, 52.788084166390554, 56.460724762507844, 58.86973817007882, 62.194541522434776, 63.37822273799351, 62.44175148010254, 58.196336133139475, 59.28853389195034, 60.51987974984305, 54.50878470284598, 55.96468244280134, 51.58706372124808, 46.45706973757063, 44.450808661324636, 46.64043269838606, 49.695246423993794, 53.596236092703684, 53.98209040505545, 59.99445697239467, 57.8795816557748, 57.882294927324565, 61.48861149379185, 63.68561104365757, 61.28832966940743, 62.53587177821568, 59.26527827126639, 60.52862058367048, 59.63180269513811, 54.99675668988909, 51.97174726213728, 55.080642291477744, 54.80938809258597, 51.7133333342416, 44.73432295663016, 39.10494456972395, 33.45773015703474, 25.25678699357169, 22.096570832388743, 15.591523136411395, 11.372441462108068, 9.077018073626927, 10.61294342790331, 13.068138905933925, 14.762594359261648, 11.56210035937173, 18.82910575185503, 9.010350108146667, 11.073466556412832, 12.19749401296888, 7.067310690879822, 3.2436783569199696, 4.102513483592442, 1.8272329228264945, 0.6841998632465089, 1.4346532970666885, 2.8131853427205766, 12.991931063788277, 26.22442787034171, 22.91778016090393, 35.888644286564414, 28.105178424290248, 26.699057579040527, 24.767718928200857, 25.53397842815944, 39.12697730745588, 44.479893820626394, 52.37108107975551, 48.83560139792306, 24.191956451960973, 6.436159781047276, 0.7635783095444951, 0.05679140652396849, 0.03191081999934145, 0.06258361893040792, 0.07976296530770403, 0.03852655339453902, 0.016067671922168562, 0.03073160756113274, 0.15631363727152348, 0.020383504086307118, 0.04492510130096759, 0.014709129463881254, 0.02836758816348655, 0.03014737194670098, 0.06654083515916552, 0.05926046653517655, 0.02304677608689027, 0.052933317476085255, 0.030654274925057377, 0.08142313015248094, 0.039503762565021, 0.02641824017544942, 0.04291011013888887, 0.05000607669353485, 0.027535712712311318, 0.05692279125962939, 0.01048581809404173, 0.08334845969719545, 0.09522962822977986, 0.1550935905958925, 0.061922868314598284, 0.02064298096645091, 0.12954266236296721, 0.08922023711992161, 0.10945504704224211, 0.10691493084388119, 0.08765807987323829, 0.1592106018215418, 0.2857321820088795, 0.2625385522842407, 0.1369057579764298, 0.2424174105482442, 0.12564632429608277, 0.18711565301886626, 0.1364583998386349, 0.12342576416475431, 0.1251609953386443, 0.10765032709709235, 0.1142152619681188, 0.09476445854774543, 0.12507803764726433, 0.09646598688725914, 0.19416308057095322, 0.2881813948707921, 0.1505870595574379, 0.125366672873497, 0.10314499706562076, 0.22695100546947547, 0.15446087026170321, 0.1388970139835562, 0.09822762664407492, 0.1437446174344846, 1.4399829996483666, 8.509078400475637, 26.954409088407242, 51.47862318583897, 67.12105056217739, 70.51124341147286, 62.292469433375764, 46.506881373269216, 35.14622926712036, 32.90692908423287, 33.52606569017683, 43.13755396434239, 45.603302887507844, 49.23827382496425, 22.469035966055735, 8.097596526145935, 2.187097932611193, 0.7721235624381474, 0.9703483943428312, 3.485727974346706, 6.672004657132285, 10.390229344367981, 17.894336802618845, 18.887111050742014, 15.633549315588814, 15.837004729679652, 20.7607136453901, 23.07424317087446, 25.428478717803955, 15.795185259410314, 19.915097032274517, 14.426529100963048, 27.539753130504064, 30.573102133614675, 37.447111334119526, 48.431435108184814, 55.933050768715994, 59.30896854400635, 60.238832065037315, 56.94631699153355, 62.88493537902832, 65.1868874686105, 60.578744888305664, 57.52120746885027, 55.93406173161098, 59.27973747253418, 61.793095452444895, 65.69605146135602, 66.092043195452, 64.27515179770333, 59.261269160679404, 60.02999005998884, 62.23928792136056, 57.49984523228237, 58.890249252319336, 55.77473258972168, 47.82040357589722, 48.69775261197771, 53.503505434308735, 53.726594720567974, 59.09463051387242, 58.739966664995464, 63.13100583212716, 60.58875029427664, 60.673372404915945, 63.65591444287981, 66.11068521227155, 62.61576911381313, 63.027019092014854, 61.169876779828755, 64.14717987605503, 63.225640296936035, 60.982525553022114, 57.9714993749346, 60.23719229016985, 57.83675295966012, 55.0493198122297, 48.20527124404907, 43.8437306540353, 39.32373986925398, 29.9115571975708, 27.89712503978184, 18.94397337096078, 17.058188847133092, 12.995364342417036, 14.340970720563616, 23.650003910064697, 22.784902811050415, 20.37292425973075, 15.783131871904645, 15.598632880619594, 21.975792033331736, 15.512671504701887, 12.53703945023673, 9.456619007246834, 5.508673846721649, 2.06662745986666, 1.5531428818191801, 1.705294860260827, 3.7302620070321217, 16.15229834829058, 24.72980260848999, 27.691663333347865, 49.302760056086946, 34.340832301548545, 30.387463637760707, 32.35904278073992, 30.023450987679617, 47.432280676705496, 50.67214230128697, 58.22956241880144, 56.33562592097691, 31.398016589028494, 9.20123188836234, 1.2221449230398451, 0.11266700790396758, 0.17647249198385648, 0.12842913211456367, 0.18367448981319154, 0.1498938410409859, 0.10445933296744313, 0.10301901346870831, 0.2442751851465021, 0.11724044249526092, 0.16582929023674556, 0.15963556830372128, 0.10903418569692544, 0.12409118988684245, 0.12606392188795976, 0.1368629424167531, 0.06219367842589106, 0.12970023176499776, 0.13887585726167473, 0.18123126163014344, 0.23827612133962767, 0.04530974244698882, 0.15313578636518546, 0.11322738961981875, 0.17389025911688805, 0.16519936546683311, 0.1398216536534684, 0.17822358730648244, 0.08312539809516498, 0.19854716317994253, 0.20420252185847076, 0.07663100372467722], [0.006706353019191218, 0.04858020659802215, 0.030297694594732354, 0.02911658225847142, 0.024448631131755452, 0.06387533926005874, 0.028400542913004756, 0.07413484981017453, 0.01808446629105934, 0.10048615759504692, 0.027462695558954562, 0.026750201558960334, 0.03028325197686042, 0.008116657945460506, 0.03558407950081995, 0.06609507836401463, 0.035634633752384355, 0.09827709863228457, 0.031272552641374726, 0.04616629112777965, 0.020897670782038143, 0.03034568398392626, 0.07835136819630861, 0.054689148973141394, 0.045588060548262935, 0.05857430478291852, 0.015270038740709424, 0.017036865897742764, 0.058078329611037455, 0.011868811561726034, 1.1127263201134545, 7.130250513553619, 19.329648767198833, 44.296006270817344, 47.906067916325156, 49.47736481257847, 45.24370581763131, 29.649672644478933, 22.906107187271118, 24.052921261106217, 36.879544258117676, 35.40650531223842, 40.32759823117937, 20.74937071119036, 8.073729463985988, 2.8711133428982327, 1.2210388566766466, 0.6502737637077058, 1.2523237722260612, 1.080706849694252, 1.6044098394257682, 2.514239315475736, 9.219629849706378, 6.590792374951499, 7.9130653994424005, 6.005935575280871, 8.040246094976153, 10.164565750530787, 10.568238718169075, 11.10850371633257, 23.76980996131897, 17.27180426461356, 17.379895653043473, 34.291475772857666, 40.57373816626412, 48.97006293705532, 52.88350030354091, 56.489709172930034, 58.891722270420615, 59.40879331316267, 56.7668901852199, 58.56708853585379, 54.95386545998709, 52.511045592171804, 49.95887844903128, 54.64993388312203, 55.53679847717285, 56.54150104522705, 58.41072627476284, 61.486179624285015, 58.408905846732004, 59.9449371610369, 56.401599066598074, 57.71684094837734, 54.091076374053955, 47.816929476601736, 47.39914124352591, 41.82106835501534, 38.692826066698345, 41.58233172552926, 45.621173654283794, 55.90505647659302, 53.47550766808646, 54.807790006910054, 60.96299416678292, 60.35856342315674, 59.959625652858186, 56.47253670011248, 58.25888729095459, 58.61042445046561, 55.36617851257324, 50.28131307874407, 46.879336084638325, 52.30415603092739, 56.116090638296946, 57.1927661214556, 51.759045532771516, 45.70815120424543, 38.83847420556204, 33.6136268888201, 26.054735490253993, 16.314858402524674, 14.233186789921351, 11.536214845521108, 8.607854860169546, 13.788302319390432, 18.987701858792985, 17.623892068862915, 7.348203778266907, 20.732563018798828, 7.702566249029977, 9.811850002833776, 9.345256754330226, 5.260085540158408, 3.641079272542681, 3.5432953195912495, 1.6662295907735825, 1.0808558017015457, 0.4651433548757008, 2.0475411925997054, 6.640045114925929, 11.191564219338552, 21.118674414498464, 18.8161803654262, 26.074810573032924, 23.587551764079503, 31.09501259667533, 28.825734410967144, 32.655713490077424, 41.04507269178118, 42.95480939320156, 47.22909797940935, 27.218088013785227, 10.390148571559362, 2.024629507746015, 0.047693860051887374, 0.02100023813545704, 0.04779827980590718, 0.04109855395342622, 0.07134712939815861, 0.007055042411333748, 0.06430879421532154, 0.0674788894663964, 0.06336532519864184, 0.02529426388043378, 0.08873213973960706, 0.03249791903155191, 0.029797234306378022, 0.053547578265092204, 0.04717811915491309, 0.02909647048051868, 0.03322619405974235, 0.025530282108645354, 0.02832573781987386, 0.06956759667290108, 0.052282799168356826, 0.028634228677089726, 0.019321181179423417, 0.04944257710927299, 0.05179700541443058, 0.05466345285198518, 0.05856924969702959, 0.056066463102719614, 0.05438183367784534, 0.025812245639307157, 0.029997629446110556, 0.011453500632861895, 0.052461786528251, 0.062393140579972944, 0.056715916110468764, 0.02271930660520281, 0.055192591422902684, 0.04109334958983319, 0.029419636353850365, 0.04275820989693914, 0.05023225277130093, 0.022904010622629097, 0.024201730898182307, 0.07040223545793976, 0.04562587869752731, 0.044627913140824864, 0.1264814787677356, 0.03726572337161217, 0.07738951088062354, 0.019763034701879536, 0.06468878061111484, 0.05679988142635141, 0.04257294608812247, 0.06433565741670982, 0.027463141695729325, 0.01440789214601474, 0.052548594905861785, 0.07235974791858878, 0.03650626287396465, 0.05826753231563738, 0.047871564980596304, 1.1368590423039027, 8.444503579820905, 22.957704510007584, 51.038986342293875, 56.98052644729614, 57.52579327992031, 51.084479672568186, 34.85996001107352, 25.00258367402213, 25.540429830551147, 34.20139932632446, 28.83872754233224, 37.44350869315011, 29.277148451123917, 10.066640445164271, 3.4468130682195937, 0.95614812203816, 0.6087424265486854, 1.4446988723107745, 4.503123164176941, 5.023690453597477, 8.877111451966421, 9.565180267606463, 8.972157597541809, 8.093763726098196, 8.326405916895185, 11.69647330897195, 11.981300813811165, 9.40617595400129, 7.857327818870544, 15.162656000682286, 16.52832964488438, 20.275913511003765, 30.36844641821725, 41.52214642933437, 48.24735300881522, 55.74500124795096, 57.8012580871582, 58.611821038382395, 58.24356998716082, 57.99628012520926, 59.80012975420271, 57.65470320837838, 55.69474145344326, 51.80543170656477, 56.10511595862252, 57.42419672012329, 57.697455474308555, 59.998271533421104, 62.31254277910505, 61.222467694963726, 61.66080869947161, 58.18135929107666, 61.43258816855294, 55.90357303619385, 51.4136505808149, 50.291273321424214, 46.25937264306204, 43.87427840914045, 47.9917357308524, 52.18986858640398, 58.68273435320173, 56.632067339760916, 57.26875856944493, 62.070391110011506, 60.44292150224958, 61.401626995631624, 58.72591045924595, 59.70530768803188, 59.63379682813372, 58.07849815913609, 53.88986349105835, 52.98478766850063, 57.47425154277256, 59.6424959727696, 59.67694514138358, 57.12347521100725, 50.85008914130074, 43.78472307750157, 38.733163833618164, 29.03655665261405, 18.600992918014526, 14.834212916237966, 10.366499509130206, 8.40764251777104, 8.69881112234933, 8.933723637035914, 8.613016503197805, 8.548931530543737, 15.159664801188878, 11.667699081557137, 8.558532203946795, 11.154429571969168, 8.689579571996417, 6.394583931991032, 5.270775777953012, 2.499564068658011, 1.0932944885322025, 0.964050286582538, 2.5087936648300717, 8.849540999957494, 13.690707921981812, 19.720976522990636, 20.268923623221262, 24.352013417652675, 25.023037433624268, 31.996819291796, 29.35449579783848, 37.95758853639875, 47.06638159070696, 50.35434559413365, 54.13794892174857, 31.911634377070836, 11.996570348739624, 2.7517602273396085, 0.019204439229464958, 0.05670963966154626, 0.034744056540408304, 0.013587051370580281, 0.04148467430578811, 0.03682494702349816, 0.0450225389296455, 0.013179388379545083, 0.036779871942209344, 0.04535452575821962, 0.09260774177632161, 0.07175573640103851, 0.12877248440470013, 0.05672546649085624, 0.01632550505122968, 0.01083237222129745, 0.05581286403217486, 0.020837525437985147, 0.05901583430490323, 0.04097195967499699, 0.04305440400327955, 0.04526967495413763, 0.04056203631418092, 0.0050836543336377615, 0.07301146723330021, 0.08354604230927569, 0.020942666135462265, 0.055422546940722635, 0.04288704673360501, 0.01601579283098025, 0.017074577177741697, 0.11197068848248039, 0.17631591324295315, 0.10735612109835659, 0.229688609285014, 0.09156530164182186, 0.18124662366296562, 0.15507303098482744, 0.20420674234628677, 0.14167990322623933, 0.1585837168885129, 0.16158181029771054, 0.09662942561720099, 0.26621200516819954, 0.13355454137282713, 0.17519305992339337, 0.18419620181832994, 0.19947565692876065, 0.270844716578722, 0.21341690527541296, 0.15279278691325868, 0.11043844784476928, 0.15730470551976136, 0.148519631209118, 0.14143366286797182, 0.1257305983453989, 0.149527622120721, 0.16248671816928045, 0.20805882635925496, 0.25276493387562887, 0.2301543014390128, 1.5976756236382892, 11.493685790470668, 30.849987847464426, 59.35655675615583, 64.70864295959473, 64.32195486341203, 57.500460147857666, 39.51559700284685, 34.51638548714774, 33.91079439435686, 46.92909908294678, 46.59577662604195, 48.588471344539094, 26.887404135295323, 11.928019421441213, 3.8261701634952, 1.7904533935444695, 2.0699634637151445, 3.382823850427355, 4.932337275573185, 7.153446640287127, 12.486962045942034, 17.259092535291398, 15.198788370404925, 15.147507190704346, 16.260787521089824, 18.14895006588527, 20.239716870444163, 19.483346394130162, 19.311831848961965, 33.51290232794625, 22.511614527021134, 23.01896503993443, 40.545222759246826, 44.05176666804722, 50.7204600742885, 56.189776284354075, 58.271171706063406, 59.05117647988455, 61.84402574811663, 57.86218336650303, 61.81787967681885, 59.202445711408345, 57.19390910012381, 52.89225850786482, 58.85024152483259, 59.51773411887032, 59.926149232046946, 61.973123277936665, 64.85906451089042, 60.49080848693848, 61.00935254778181, 59.184026036943706, 60.84052521841866, 58.29184259687151, 53.1109356880188, 52.57110929489136, 50.39948456627982, 49.80865839549473, 52.45941700254168, 57.94551311220442, 62.596925599234446, 59.12044307163784, 60.375204358782085, 64.93260424477714, 62.18615504673549, 64.07805919647217, 60.393075125558035, 61.98533821105957, 63.003242356436594, 61.368254797799246, 57.48301669529506, 54.65157018389021, 60.19532939365932, 60.16370119367327, 61.24007443019322, 58.250737054007395, 54.87700796127319, 47.59962803976876, 45.552977085113525, 37.518917492457796, 25.402584518705094, 19.321046897343226, 17.039762224469865, 12.897994024412972, 19.285093443734304, 25.762961523873464, 28.518212352480205, 14.919583695275442, 32.86072703770229, 24.573181527001516, 21.37050666127886, 18.943724972861155, 16.040762390409196, 11.302495683942523, 10.635025671550206, 6.451661646366119, 1.8620442662920271, 1.2738756729023797, 3.136704977069582, 7.876292058399745, 15.538423265729632, 27.642348493848527, 28.72239559037345, 38.280172552381245, 37.41981533595494, 45.48416212626866, 40.85583850315639, 44.735785552433555, 52.09704760142735, 55.88937439237322, 60.40779141017369, 39.36250039509365, 16.11044761112758, 3.5546543215002333, 0.11951406406504766, 0.21865435423595564, 0.10205785504409245, 0.13477720719363007, 0.22264047605650766, 0.06166634815079825, 0.1670196442199605, 0.21759311189608915, 0.15040266088077, 0.14528033217149122, 0.17706171822335037, 0.1819456640098776, 0.2385982626250812, 0.1710540641631399, 0.1065211362604584, 0.1611542653824602, 0.10644507248486791, 0.09991874625640255, 0.10608881445867674, 0.14804766939154693, 0.08308388532272407, 0.13919118605554104, 0.11599900839584214, 0.12181750046355383, 0.2857878490218094, 0.18492711974041803, 0.12880178354680538, 0.1165508609265089, 0.20249680695789202, 0.12972498472247804, 0.08036003541201353], [0.025752617678205882, 0.011538264923729002, 0.02549221459776163, 0.04472919127770832, 0.07633339826549802, 0.021543150967253104, 0.06746748329273292, 0.05951450326080833, 0.061656902943338664, 0.06432635470160417, 0.01866923625181828, 0.054532872180321386, 0.023098292161843607, 0.0719341571841921, 0.07351352207894836, 0.043274066144866605, 0.01799253497405776, 0.05100545021040099, 0.032095982027905326, 0.0603256511635014, 0.04073341390384095, 0.083054701531572, 0.016862930231062428, 0.07365357849214758, 0.03611150137814028, 0.037716229911893606, 0.02003891855877425, 0.03199225098692945, 0.050361411912100654, 0.2222460029380662, 1.4573189722640174, 11.024395772389003, 27.71682276044573, 43.981325830732075, 49.77949333190918, 49.67222009386335, 35.82159764426095, 26.03447801726205, 28.351024797984532, 28.526273999895366, 33.861719267708914, 50.20418460028512, 27.66964101791382, 12.459961346217565, 8.122607435498919, 1.13359697163105, 0.3373236964855875, 0.10435432967330728, 0.8144740270716804, 3.7341043608529225, 6.607001219476972, 4.757166675158909, 6.744643296514239, 5.265235892363957, 10.31526436124529, 3.2083984443119595, 10.975844366209847, 14.876596927642822, 8.24537341935294, 6.8496831229754855, 18.446966988699778, 29.797200271061488, 29.139624493462698, 38.513614654541016, 49.90695456096104, 53.50677456174578, 58.43876920427595, 57.55809892926897, 57.54165254320417, 58.39988708496094, 60.23679624285017, 58.25047649656023, 56.34675693511963, 51.87908261162894, 49.988046986716135, 51.808593136923655, 53.812561307634624, 56.487857478005544, 57.19433988843645, 57.18878480366298, 59.95506763458252, 55.422827175685335, 55.2825152533395, 56.864276136670796, 53.471481187003, 50.24056536810738, 46.606059959956575, 46.41422367095947, 41.26074825014387, 39.55800880704607, 48.53286491121565, 53.398611954280305, 49.55410419191633, 58.89294515337263, 58.861101559230256, 56.451653889247346, 55.3171763420105, 54.99480077198574, 56.35368776321411, 55.144777638571604, 50.845829895564485, 48.84171233858381, 53.54850196838379, 56.685936723436626, 55.206717354910715, 56.62113434927804, 55.428531646728516, 50.70292282104492, 47.91504846300398, 42.29888554981777, 35.230139187404085, 31.46479572568621, 26.611956698553904, 19.934058666229248, 17.030839000429424, 10.74200882230486, 8.705802747181483, 7.036221410546984, 6.561944322926657, 12.506958092961993, 3.803245885031564, 5.409122662884848, 8.494613119534083, 5.464566247803824, 2.322762595755713, 2.9001839544091905, 2.426791025059564, 0.603754922747612, 1.065497242978641, 0.8939507795231683, 3.5221072222505296, 11.600897363254003, 17.431451286588395, 37.12240811756679, 43.45008741106306, 33.96706438064575, 17.679531506129674, 18.43608784675598, 26.200423581259592, 30.504613740103586, 41.65634741101946, 46.2932242665972, 36.274425642830984, 15.206667627607073, 1.7884801051446368, 0.16241264928664478, 0.05288994891036834, 0.041431103966065815, 0.025165876573217765, 0.025953749028433646, 0.06030662504157849, 0.05206005308511002, 0.06788074504584074, 0.04037309484556317, 0.010600037590068365, 0.01961513272752719, 0.05562500482691186, 0.025835851872605935, 0.06453654449433088, 0.043113066748316796, 0.03534515714272857, 0.05613023182377219, 0.04927612907652344, 0.007142276569668735, 0.02650347604815449, 0.01748108072206378, 0.02450457464770547, 0.014318032057157584, 0.034345960044967275, 0.04644095192530325, 0.018463367030822804, 0.048647140684936724, 0.010515375079454055, 0.10033183837575571, 0.04497679549136332, 0.019143035202952366, 0.03629587630608252, 0.03223324626950281, 0.03436973930469581, 0.01995080739392766, 0.0028648793855349398, 0.03546073540513005, 0.012106467603838869, 0.028850813662367206, 0.0996408454541649, 0.031409280840307474, 0.009555842594376631, 0.01998074944796307, 0.04724618300263371, 0.015922377218625376, 0.08137097795094762, 0.07059077319822141, 0.04724461558674063, 0.055018387734889984, 0.021356455449547087, 0.01901488538299288, 0.014214925268398864, 0.049245116633496115, 0.014997310071651424, 0.07621896333460297, 0.06493204220065049, 0.07978608978113957, 0.06326667977763073, 0.004541446754176701, 0.06074001892868962, 0.24683345215661184, 1.627515965274402, 13.778473223958697, 32.97786324364798, 50.97478151321411, 56.79023265838623, 57.792350496564595, 40.81582382747105, 26.620688847133092, 31.830694811684744, 30.209249292101177, 33.895265170506065, 46.484636715480256, 30.697943891797745, 13.098451290811811, 7.544625878334045, 2.0080100681100572, 0.38799099198409487, 0.5569408376302037, 2.0107216026101793, 5.920166143349238, 10.618866767202105, 10.421332955360413, 9.499642252922058, 12.396277632032122, 8.644312926701136, 11.89769835131509, 10.717374852725438, 10.108577166284833, 7.783473678997584, 10.145468626703535, 20.40271118709019, 25.76779399599348, 32.08337647574288, 40.04909011295864, 48.96152707508632, 53.85360084261213, 58.37066296168736, 56.42387499128069, 57.65657574789864, 57.580746582576204, 60.878816740853445, 60.173317500523154, 58.547487667628694, 54.116989680698936, 53.45566013881138, 52.52530329568045, 56.86907039369856, 58.50581237248012, 59.028462818690706, 58.50557613372803, 60.773864201136995, 57.073330061776296, 57.260431153433665, 58.833454677036826, 54.5004677091326, 51.494055134909495, 49.29233775820051, 49.60707030977522, 45.995216029030935, 46.13276604243687, 53.110178334372385, 56.28166273662022, 51.78422927856445, 59.607553482055664, 60.266659600394114, 57.82607357842581, 57.819858414786204, 56.959226744515554, 58.44777406964983, 57.58151435852051, 55.27560526984078, 54.51174463544573, 57.37085887363979, 59.2848721912929, 58.18845340183803, 60.71639565059117, 56.264827251434326, 52.107462951115195, 50.88149847303118, 46.203988552093506, 41.46124199458531, 35.35823965072632, 27.756679364613124, 20.050128323691233, 13.916758009365626, 9.404921804155622, 8.010600737163, 8.73564612865448, 4.381686457565852, 10.36061612197331, 9.821112820080348, 10.77840348652431, 14.67430533681597, 9.442301375525338, 6.80518729346139, 4.820804791791098, 3.4268393857138495, 1.8680920217718398, 1.0144620729344231, 1.5730999537876673, 4.204181696687426, 12.172886967658997, 19.622435433523997, 35.18053599766323, 41.826053687504356, 34.66497966221401, 25.222358669553483, 25.11107979501997, 32.776761531829834, 37.040061541966026, 46.951976026807515, 52.02119411740984, 41.72646515710013, 18.24698567390442, 2.4913858217852454, 0.09873681289276906, 0.054328073348317824, 0.056838825943746736, 0.016491820769650594, 0.04717678583360144, 0.030097893173141137, 0.07256292165922267, 0.030957301879035573, 0.0225535659452102, 0.009952735538328332, 0.01956670398690871, 0.03388459694438747, 0.042973583697208335, 0.024156121470566307, 0.08217504873339619, 0.010301207375180508, 0.021829424891620874, 0.05251965538731643, 0.005939952380556081, 0.02679509173945657, 0.050910092291555235, 0.056331811007112265, 0.06491917717669692, 0.08080782102687017, 0.04417031930227365, 0.015730585902929306, 0.07271511706390552, 0.03829754443307008, 0.02574665505172951, 0.00748151439308588, 0.02547253538588328, 0.19355576458786214, 0.13210536699209893, 0.08847770946366446, 0.1455723736435175, 0.12353745102882385, 0.1188178328531129, 0.1251209346311433, 0.19651531720800058, 0.17525963777942316, 0.13507222064903804, 0.1640638235424246, 0.09895923667188201, 0.1178191921540669, 0.17998404641236576, 0.15319557887102875, 0.14140536795769418, 0.08135717654866831, 0.23506111385566847, 0.059560182238263745, 0.07048857903906278, 0.09385695867240429, 0.20770049201590673, 0.09728423905159746, 0.2556888498365879, 0.16884730543409074, 0.17200064765555517, 0.14523079911512987, 0.10958920698612928, 0.07481670965041433, 0.4116323191140379, 2.8428437284060886, 18.606678281511577, 38.83826575960432, 57.92790985107422, 65.67200374603271, 62.34217684609549, 47.24133028302874, 35.27535458973476, 39.23753009523664, 37.935663495744976, 44.49413415363857, 62.64395100729806, 36.03452519008091, 16.100951160703385, 10.065449697630745, 2.033514082431793, 1.0678536593914032, 0.425544159752982, 3.6988357390676225, 10.803886873381478, 18.638582672391617, 17.015513011387416, 17.209965297154017, 18.233176129204885, 18.617296866008214, 13.310986263411385, 21.5924060685294, 24.500274079186575, 12.93485334941319, 11.253386684826442, 24.26512793132237, 35.53027357373919, 35.519493443625315, 40.82030888966152, 52.31987633023943, 56.94977024623326, 61.043391772678916, 57.66175215584891, 58.601565497262136, 58.430299350193565, 63.357558795383994, 61.992133549281526, 61.81174441746303, 57.3487149647304, 55.700355597904746, 55.81842633656093, 59.24920013972691, 61.93221228463309, 61.139012881687705, 61.256923811776296, 61.6977870123727, 56.48194456100464, 57.388184206826345, 59.22980076926095, 56.40798446110317, 54.18813228607178, 48.662605149405344, 50.192511626652305, 52.102866717747276, 50.12063946042742, 58.92683151790074, 60.42483534131731, 54.5986179624285, 60.83433437347412, 60.58381012507847, 60.6123811176845, 59.77679075513567, 58.856230872017996, 60.78369590214321, 60.08895942143032, 58.72006702423096, 55.05643824168614, 59.074821199689595, 57.703837394714355, 56.06854411533901, 58.698284421648296, 58.472183091299875, 53.030135086604524, 52.39331531524658, 48.824143818446565, 43.78501837594168, 39.485028403145925, 33.32086106709072, 24.656514746802195, 23.379845789500646, 16.9777113369533, 16.62114715576172, 15.134993485042028, 15.741876942770821, 26.18215503011431, 17.10159945487976, 14.11043643951416, 17.261039767946514, 17.128733907427105, 7.4576370375497, 8.830979755946569, 6.606930434703827, 1.694160480584417, 2.1368168592453003, 1.4504663114036833, 5.64387059211731, 15.333993366786412, 24.289688076291764, 48.32685429709298, 56.58126558576311, 46.46678679330008, 30.874622685568674, 30.09824139731271, 38.40198837007795, 41.63858781542097, 53.839179856436594, 59.22726467677525, 50.80214309692383, 22.51923496382577, 4.127485743590763, 0.3053219494010721, 0.21092794383210794, 0.1610454147947686, 0.13689016524170125, 0.15125481943999017, 0.08905662875622511, 0.12858657938029083, 0.12128991234515395, 0.11261877763484206, 0.18634548863129957, 0.12764184150312627, 0.13200947642326355, 0.10314177402428218, 0.13673927262425423, 0.12791761170540536, 0.09106180830193417, 0.12730454174535616, 0.06719746706741196, 0.10273173531251294, 0.1229245981999806, 0.1273277205015932, 0.12719911097415856, 0.09127731102385692, 0.13621013744601182, 0.20209416427782603, 0.09390035098684685, 0.14275193427290234, 0.12001225804643971, 0.14599059548761162, 0.14709766608263763, 0.0891821848760758], [0.06719798275402614, 0.05191509086372597, 0.023461488208600452, 0.029899849157248224, 0.08967932034283876, 0.06456040857093674, 0.08041074233395712, 0.03280791454017162, 0.012733141342843217, 0.043821484449186494, 0.010125182668811508, 0.05120908874752266, 0.026482409232163003, 0.024452919473073313, 0.04562945118440049, 0.046278184945029874, 0.025930057978257537, 0.01842944197622793, 0.07426510817770447, 0.020916364421801906, 0.023245066071727445, 0.05533133487084082, 0.03730102415595736, 0.023902006713407378, 0.16387173027864524, 0.02900890214368701, 0.0028085192066750354, 0.02397180930711329, 0.06623976917139121, 0.17295522429049015, 4.235131578786032, 16.12422067778451, 33.995399134499685, 50.792467730385916, 47.99259730747768, 43.6616461617606, 38.04689025878906, 31.523355143410818, 19.43289726121085, 25.268963711602346, 40.220050539289204, 25.181484154292516, 15.04373584474836, 15.078676598412649, 3.0048018949372426, 1.1256919843809945, 0.047344068464423926, 0.7911207516278539, 1.0624762965100152, 5.947011811392648, 4.656747400760651, 11.031316178185598, 7.129952609539032, 9.759313804762703, 3.950406559876033, 10.20813182422093, 6.829200267791748, 6.509530586855752, 10.841599089758736, 22.109226976122173, 30.65658473968506, 33.07693413325718, 43.459276403699604, 45.07653563363211, 49.51330784388951, 56.386782033102854, 57.401184286390034, 56.22476741245815, 58.63088689531599, 55.79926667894636, 60.45424011775425, 56.40615708487374, 54.38982459477016, 48.60244764600481, 48.56770665305001, 51.01006099155971, 51.88597869873047, 53.275107724326, 58.46272659301758, 57.83458859579903, 59.486891065325054, 56.432702677590505, 52.921687602996826, 58.6060540335519, 54.370619773864746, 52.06098992483956, 49.41287858145577, 45.7575181552342, 39.15551355906895, 39.18599183218819, 47.14049455097744, 44.61300046103341, 54.90835475921631, 59.869681222098215, 57.96499238695417, 55.364201750074116, 51.24644218172346, 51.78853021349226, 53.567602566310335, 53.11571952274868, 52.25036307743618, 56.96968725749424, 55.315672057015554, 55.16273873192923, 55.60563080651419, 58.8526942389352, 57.95893703188215, 56.883303778512136, 54.68365349088396, 50.75419357844761, 47.710021018981934, 40.65719992773873, 32.80892126900809, 26.339003665106638, 14.989062207085745, 11.990581001554217, 8.205672281129019, 6.779352588312967, 4.545083769730159, 7.139220637934549, 8.485549194472176, 6.0657461030142645, 12.8180775812694, 5.434332030160086, 7.465957505362375, 3.652575501373836, 1.181571243064744, 1.8404197352273124, 0.647330278796809, 1.3843428024223872, 4.173994813646589, 7.952578936304365, 11.962407793317523, 15.072447538375854, 28.511809587478638, 27.031831128256663, 22.936733109610422, 19.378301790782384, 23.96061965397426, 31.795001915522985, 39.89812660217285, 43.22624771935599, 44.355983121054514, 26.8117538860866, 7.191866270133427, 0.23909324035048485, 0.054285522417298386, 0.06622089232717242, 0.042253339130963595, 0.00939723418559879, 0.02989073303927268, 0.026066294239301766, 0.011832125717774034, 0.10135329142212868, 0.011577861682911004, 0.024277092390028492, 0.033802690982286415, 0.018475860556853668, 0.060307283220546584, 0.013504802748294813, 0.011882186335112368, 0.05810417500989778, 0.04615051179592099, 0.028268019934850078, 0.044164806205247126, 0.059237830606954436, 0.0068949183249580005, 0.05359406130654471, 0.024005551157253127, 0.019351732218638062, 0.02106036651613457, 0.024782088684982488, 0.05290457134002021, 0.026743283894445215, 0.023921584145032933, 0.05304434955386179, 0.06052057391830853, 0.06861335252012525, 0.012645438147176589, 0.04411466246736901, 0.05337194286819015, 0.02940123787681971, 0.0417648617710386, 0.05147873517125845, 0.07220650756997721, 0.026276219403371215, 0.017101839018453444, 0.021700638945081403, 0.04558369417541793, 0.049626392245824845, 0.034417609950261455, 0.015842349102188433, 0.007278694338830454, 0.10619014009301152, 0.03462824757610049, 0.03204638111804213, 0.03153483696015818, 0.07194109859743289, 0.03298186377755233, 0.04583085055596062, 0.0734531596036894, 0.02923831483349204, 0.02619950762683792, 0.03748320063043918, 0.03584076590569956, 0.20738122771893228, 5.079465380736759, 19.609647274017334, 38.729741845812114, 58.125898769923616, 53.80240651539394, 49.059920515332905, 40.837557792663574, 31.24433285849435, 23.131914956229075, 28.355263199125016, 37.18345499038696, 33.493277141026084, 17.837366785321915, 14.824829374040876, 3.2460793937955583, 1.3243026584386826, 0.1163668693708522, 2.2368722217423573, 2.2797167684350694, 8.768232311521258, 7.301985229764666, 9.28134548664093, 9.9562292269298, 8.853493656430926, 6.94737001827785, 7.287990689277649, 7.704908660479954, 8.727457676615034, 9.691142422812325, 16.923760311944143, 27.533211401530675, 32.85222244262695, 42.66213389805385, 46.7991156578064, 51.54417249134609, 56.30672141483852, 59.33814402988979, 55.846090589250835, 57.69576358795166, 55.994347776685444, 61.51897512163435, 58.46599224635533, 56.25906024660383, 51.31560455049787, 50.673973151615684, 52.81147180284773, 54.117451735905235, 55.40372657775879, 58.82498482295445, 60.08149010794503, 60.73840754372733, 58.995173999241416, 55.13037749699184, 60.935062408447266, 54.12364258084978, 55.58186101913452, 50.60323701586042, 48.29537548337664, 43.92027200971331, 43.358603954315186, 50.91577393668038, 47.36117628642491, 56.381063665662495, 61.924124581473215, 59.008403369358604, 56.82074567249843, 53.55911534173148, 53.834625312260215, 55.13459505353655, 57.28043154307774, 56.25753511701311, 59.72094113486153, 58.209530762263704, 58.149206502096995, 56.47600037711007, 58.00285312107631, 58.467069217136924, 57.229800019945415, 54.50450461251395, 51.37115887233189, 49.02908788408552, 41.587431703295024, 35.764862128666465, 29.307616301945277, 18.989114080156597, 11.611816457339696, 8.907591462135315, 5.281066494328635, 4.670151778629847, 7.6602630104337415, 10.695284792355128, 12.767719643456594, 14.462746586118426, 7.870427778788975, 9.084393586431231, 5.516303403036935, 3.5924863943031857, 3.117456295660564, 1.6020036999668394, 1.8361572325229645, 4.317318345819201, 8.140817795481, 14.534022944314138, 19.466354574475968, 34.14058174405779, 29.54920516695295, 26.956512655530656, 24.128422124045237, 29.11657558168684, 35.2623336655753, 44.78659078053066, 49.03391688210623, 49.32049880708967, 30.674844605582102, 8.431365404810224, 0.5133861633283752, 0.07863725535571575, 0.03241556862901364, 0.006034907843318901, 0.025180241159562553, 0.039964369099055014, 0.09587774452354227, 0.09661189227231912, 0.07235955114343337, 0.013104774972556956, 0.026094117567741444, 0.03142709916989718, 0.05390101358560579, 0.04398110302697335, 0.01875057054816612, 0.011006447835825384, 0.03208953255255308, 0.023888022106673037, 0.023869323377896632, 0.022105525879721557, 0.05305492452212742, 0.06646175868809223, 0.018026035944265977, 0.04791748483798333, 0.034518148483974595, 0.02476411938135113, 0.031328185727553706, 0.016496590870831693, 0.07266382660184588, 0.021753530749785047, 0.050510438558246405, 0.1754393952765635, 0.18974650970527104, 0.14076434235487664, 0.15908321365714073, 0.17442783527076244, 0.15775988038097108, 0.21900065136807306, 0.22717451490461826, 0.17951122964067118, 0.18565469927021436, 0.08137417385088545, 0.1365592572838068, 0.158917813960995, 0.11545448404337678, 0.1582122053951025, 0.12014242820441723, 0.1351749508508614, 0.2648487468915326, 0.19490256160497665, 0.219049370182412, 0.10509468601750475, 0.17521706649235316, 0.14637949104819978, 0.15581232202904566, 0.199494954464691, 0.13396656140685081, 0.09389639512768813, 0.1403685257370983, 0.1578944067337683, 0.3999113052019051, 7.181989405836378, 25.271345206669398, 47.77940920421055, 66.70982837677002, 61.388585226876394, 56.501097270420615, 48.51669645309448, 41.86742326191494, 27.83332668031965, 35.37675659997122, 54.10681751796177, 38.151953969682964, 21.920873471668788, 18.919548715863908, 4.0480756504195075, 1.7603811557803835, 0.16068569623998233, 2.653094070298331, 3.7847979835101535, 17.97264126368931, 16.857726369585308, 20.242438827242168, 17.82451261792864, 19.522271939686366, 14.329791069030762, 17.634689569473267, 16.616116659981863, 14.491856932640076, 17.146787064416067, 32.48269639696394, 42.580423082624165, 42.567252772195, 46.04618453979492, 48.216926847185405, 53.00675439834595, 57.898449489048545, 57.448817661830354, 56.23671136583601, 58.34779644012451, 57.172355788094656, 63.50709792545864, 61.63339805603027, 59.15740748814174, 54.11667353766305, 51.51081418991089, 55.313959326062886, 55.57032700947353, 57.09513003485543, 62.339744976588655, 62.76268182482038, 60.65951769692557, 59.13017054966518, 56.858950342450825, 59.960167612348286, 56.105744770595, 57.36199992043631, 54.109245913369314, 51.91122497831072, 49.67595822470528, 49.27012089320591, 54.498174803597585, 49.06341545922415, 60.328957148960654, 63.785032817295615, 61.974450383867534, 59.09953594207764, 54.84695700236729, 55.576563017708914, 57.55313444137573, 58.70826203482491, 58.02319049835205, 61.6575847353254, 58.16755322047642, 58.10379307610648, 60.58756215231759, 63.4131235395159, 63.79622636522566, 62.11816692352295, 58.88379437582833, 54.75434446334839, 50.95606654030936, 45.16649743488857, 38.37292752947126, 31.21776989528111, 20.32192621912275, 15.64618808882577, 12.511886971337454, 11.76925482068743, 10.135447587285723, 12.27301572050367, 15.562893084117345, 13.366685628890991, 19.78908450262887, 12.543979832104274, 15.804205758231026, 11.650291238512311, 5.842490494251251, 5.303229510784149, 2.297331754650388, 2.9095310185636793, 5.46382018498012, 10.208375879696437, 16.405754736491613, 23.08504240853446, 39.464232444763184, 39.253695079258506, 35.46555805206299, 32.18088749476841, 36.609210695539204, 42.74403231484549, 53.23794528416225, 55.32813017708914, 56.519739287240164, 36.17069946016584, 12.359819565500532, 1.0434572313513075, 0.14372713837240422, 0.10306275183601038, 0.1344884362603937, 0.130494321297322, 0.098357308256839, 0.10266551029469285, 0.1770229060202837, 0.16912770324519702, 0.08343026387904372, 0.2121552779738392, 0.17266243642994336, 0.09052083947296653, 0.21877007159803594, 0.06747525251869645, 0.08870657254010439, 0.10696346645376512, 0.10726422710078103, 0.08629819391561405, 0.05137745364169989, 0.1258232183754444, 0.15140062304479734, 0.1255291277276618, 0.15755839619253362, 0.04640731015907867, 0.153026175818273, 0.10855053950633321, 0.25233436269419535, 0.1970453073403665, 0.09333266144884483, 0.19976654489125523], [0.012668329374199467, 0.023235588633854474, 0.013259979680047503, 0.03517673796574984, 0.02631252950855664, 0.009485228303154665, 0.08754545663084302, 0.019675725904692496, 0.05855663573103292, 0.014806385584441679, 0.0658731906275664, 0.05534913623705506, 0.04833292808117611, 0.009476356457785835, 0.03823720909921186, 0.06941615444208894, 0.029746744515640394, 0.06123973282852343, 0.037029267488313575, 0.08875643807862486, 0.017352966525192772, 0.028276075841858983, 0.026890028966590762, 0.038015362074864764, 0.0296565773896873, 0.03256861220246979, 0.05451346607878804, 0.038322857181940756, 0.008261937381965774, 0.4213315158018044, 7.600516319274902, 25.21802646773202, 39.58032294682094, 53.26878138950893, 51.81351593562535, 45.94979565484183, 29.056484086172922, 30.297463621412003, 26.681011370250157, 29.45197207587106, 33.53682844979422, 25.580180474690028, 19.329806838716777, 6.253616273403168, 1.5010864351476942, 0.6067733722073692, 0.8052384597914559, 1.9888551873820168, 1.8493800887039729, 4.503751976149423, 6.159423887729645, 6.358389028481074, 8.361339722360883, 6.288114513669695, 6.735091694763728, 9.708756974765233, 8.394732764789037, 12.151727097375051, 16.119867631367274, 20.32787561416626, 34.809005396706716, 40.22361843926566, 49.180857385907856, 51.561911242348806, 56.367274965558735, 56.18824420656477, 58.866298811776296, 58.85460499354771, 55.79691471372332, 57.859810556684224, 58.082267556871685, 54.30641147068569, 49.10724122183663, 45.194335392543245, 48.546361786978586, 49.225635051727295, 54.18480409894671, 54.971034458705354, 58.17020395823887, 57.77167613165719, 58.273975304194856, 50.07414558955601, 55.54293373652867, 59.34352193559919, 54.91630697250366, 51.34849384852818, 43.804032121385845, 40.874199117933, 36.67462798527309, 38.45792484283447, 41.755359240940635, 52.67865351268223, 60.43445859636579, 57.03191532407488, 55.6063152040754, 49.08415583201817, 51.53943729400635, 53.49255854742867, 52.725314140319824, 50.75884539740426, 53.860747064862935, 53.56215865271432, 54.73506668635777, 52.85536009924752, 54.4080844606672, 52.3202862739563, 54.40500293459211, 53.587085315159385, 55.911639894757954, 53.66782338278634, 50.466385296412874, 47.28339467729841, 39.900273595537456, 28.405486515590123, 26.553947925567627, 19.053695849009923, 7.820221832820347, 8.133320689201355, 5.144239093576159, 6.305304356983729, 6.951622750077929, 13.502522042819432, 18.137025220053538, 9.390175121171133, 7.488955174173627, 2.2566774104322707, 2.9284379354545047, 1.9504435913903373, 1.2143122404813766, 1.0671420118638446, 1.9951715341636111, 4.848716139793396, 9.547967842647008, 18.875724690301077, 24.95196952138628, 23.094557966504777, 15.843727111816406, 16.123369523457118, 24.32553209577288, 33.495285170418875, 39.03651871000017, 45.63284315381731, 44.52876744951521, 33.334500380924766, 12.498795696667262, 0.975405922957829, 0.04497055975454194, 0.022960135646696602, 0.05823930525886161, 0.046842933033726046, 0.037716881305511506, 0.03555952671117016, 0.06091510810490165, 0.04972860336835895, 0.030715081840753555, 0.03334804537839123, 0.010830919308188771, 0.07147613247590405, 0.027922426782814518, 0.028643561926271235, 0.06963787933013268, 0.08876974415034056, 0.06774004402437381, 0.04046536882274917, 0.037589184407676966, 0.07054468709975481, 0.039708194988114495, 0.05533384884308491, 0.050437499436416795, 0.029094343273235217, 0.054073297019515715, 0.023259449317785244, 0.03745672080133643, 0.003215994540369138, 0.06166568997183016, 0.0373279111060713, 0.010480280400120785, 0.015774534616087164, 0.0018792508677246847, 0.033988721535674164, 0.060987813132149835, 0.031221462347145592, 0.03771882870101503, 0.07114059690918241, 0.03163615580914276, 0.024351453042722175, 0.05034195492044091, 0.020739007242290036, 0.049565276596695185, 0.031660169163452725, 0.048246428436998806, 0.017353115802896873, 0.03781016629987529, 0.027554291001121913, 0.03615908703899809, 0.025930032533194338, 0.04367888352966734, 0.022371548926457763, 0.018097104005781666, 0.0280359456914344, 0.017380645664940988, 0.02932926227471658, 0.050272907196943245, 0.007208219995456082, 0.0897818673402071, 0.4559866605060441, 9.539273040635244, 29.362517493111746, 45.43854372841971, 58.118978364127024, 57.963706970214844, 52.45687396185738, 33.776079245976035, 34.29051692145211, 26.447437252317155, 30.295375687735422, 42.60030535289219, 27.403062956673757, 18.442143201828003, 7.589928133147104, 1.4536514090640205, 0.4566706238048417, 0.7558439331395286, 2.9881980887481143, 5.780590295791626, 5.645173379353114, 11.331878747258868, 11.594355634280614, 12.330585019929067, 7.258928545883723, 10.764135360717773, 7.545835733413696, 5.733786361558097, 9.424493142536708, 15.815645967211042, 23.182855674198695, 33.47612203870501, 40.90642833709717, 45.915964875902446, 53.17917047228132, 56.756311552865164, 57.99809013094221, 57.589994634900776, 58.23008353369576, 56.174149785723, 59.543720381600515, 60.109658105032786, 56.691880907331196, 52.362969057900564, 48.806196621486116, 49.99718039376395, 51.5877411706107, 55.4519053867885, 56.19463654926845, 60.07225595201765, 59.81536020551409, 59.266091210501536, 52.957401343754356, 56.80540752410889, 59.09033652714321, 55.32727902276175, 52.90580749511719, 47.48672676086426, 45.33875717435564, 42.02072484152657, 44.34436920710972, 45.75502027784075, 52.54251398359026, 62.959955079214915, 57.55255774089268, 56.795791217258994, 50.45689058303833, 51.65544441768101, 52.73076152801514, 55.70867606571743, 53.56210306712559, 57.419235706329346, 55.54861388887678, 58.72504193442208, 54.12156159537179, 56.34460646765572, 54.472327504839214, 55.563667161124094, 54.817309038979666, 57.68533434186663, 55.11306606020246, 52.46641731262207, 47.49599913188389, 41.099984305245535, 31.331973961421422, 25.960425853729248, 18.79766689028059, 7.438915984971183, 8.184945804732186, 5.730400851794651, 10.236063582556588, 16.0555168901171, 21.178189209529332, 21.455054078783306, 9.385897636413574, 10.41999021598271, 7.766833611897059, 3.3320268733160834, 3.1682890994208197, 0.974557482770511, 0.9040594313825879, 2.6660359586988176, 5.4970681837626865, 10.967786192893982, 19.302903413772583, 25.280695744923182, 27.73681272779192, 23.93325764792306, 23.50868797302246, 29.38271243231637, 41.06443384715489, 43.38983263288225, 52.29723562513079, 50.125833238874165, 37.744077341897146, 15.480930396488734, 1.217483333178929, 0.04033800440707377, 0.02375785364503307, 0.09489564650825091, 0.06108814810535737, 0.04915594016867025, 0.052088147827557156, 0.05850001876907689, 0.021182872621076446, 0.017635593323835304, 0.05938669440469571, 0.004921078191338373, 0.030378881309713637, 0.048978347198239396, 0.024286373052746058, 0.013163588691635855, 0.04356248763256839, 0.015989674321774925, 0.03835386962496808, 0.03314464432852609, 0.028274684845070754, 0.07045157173914568, 0.050238841346332004, 0.06767681813133614, 0.023988262084977965, 0.04231853616823043, 0.03676905948668718, 0.047009150364569256, 0.06203866031553064, 0.0724314283579588, 0.02229789734285857, 0.08226374683103391, 0.08515066906277623, 0.08680880508784737, 0.15956947899290494, 0.11236338383917298, 0.18779840852533067, 0.24871125710862024, 0.16491367508258137, 0.17239107670528547, 0.13562806296561444, 0.15582689696124621, 0.1460633480123111, 0.22398913225957326, 0.08225563155221087, 0.18071225019437925, 0.1601584745304925, 0.18854158078985556, 0.15059616549738816, 0.08899893970893961, 0.19664008622722967, 0.27801609890801565, 0.12289696825402123, 0.056374894588121345, 0.13370780886283942, 0.04671268823689648, 0.04504282712670309, 0.1877866427281073, 0.17822370944278582, 0.18470943213573524, 1.1310245096683502, 12.601501362664358, 33.69061640330723, 53.095343930380686, 67.34232289450509, 65.52381951468331, 57.956803934914724, 39.23138093948364, 41.69323539733887, 35.582246099199565, 40.95890808105469, 44.658695289066856, 36.21642208099365, 24.144946677344187, 9.261350308145795, 2.120585867336818, 1.6542990995304925, 1.0917531826666422, 7.273504129477909, 7.717869656426566, 9.776466301509313, 19.221477474485123, 18.305098669869558, 16.341935532433645, 16.916794742856705, 16.424728529793875, 19.186078139713832, 14.512378437178475, 17.560944863728114, 22.881354229790823, 26.29029505593436, 37.78296293531145, 42.5311290877206, 52.25981610161917, 54.84677634920393, 59.235692841666086, 57.37213386808123, 61.175636836460654, 59.617544991629465, 56.59670795713152, 60.864718845912385, 62.846977370125906, 58.780134201049805, 54.85974516187395, 50.835866178785054, 52.872480460575645, 53.25354746409825, 59.663430895124165, 58.538357734680176, 62.5641370500837, 60.74826008932931, 60.616675104413716, 54.216487884521484, 56.83341571262905, 58.204430784497944, 57.40092372894287, 55.28406122752598, 53.045289107731406, 52.05708851133074, 46.65003858293806, 46.78296457018171, 48.756134850638254, 55.69092689241682, 63.64010034288679, 59.29772635868618, 59.428838866097585, 52.76589856828962, 55.603431701660156, 57.44164712088448, 57.772103445870535, 55.5630452973502, 57.04366472789219, 56.37769031524658, 60.19924817766462, 57.05132859093802, 59.01719978877476, 55.51189265932356, 57.97558838980538, 56.998150553022114, 58.40121419089181, 55.94138165882656, 54.235678809029714, 49.224023069654194, 41.338057381766184, 31.44759546007429, 30.809868948800222, 21.180289302553447, 11.160868815013341, 13.318888102258954, 11.787630200386047, 14.65824110167367, 13.45119569982801, 21.953780140195573, 30.799599511282786, 15.772676570074898, 18.05289122036525, 10.277803148542132, 7.949334127562387, 5.202471511704581, 3.2682869221482957, 2.5593318215438297, 3.261211484670639, 6.4372402259281705, 12.581591299601964, 26.22652448926653, 35.03193487439837, 34.60378687722342, 26.91880825587681, 26.47709390095302, 35.81312084197998, 44.886040346963064, 50.02120379039219, 58.772150720868794, 56.91548783438546, 43.616666998182026, 19.059174503598893, 2.1650578124182562, 0.147919412702322, 0.11292699538171291, 0.21176114412290709, 0.1315158964799983, 0.1565123258956841, 0.1909344752452203, 0.13174912253660814, 0.08577680760728461, 0.1660421738134963, 0.28744863133345333, 0.08171680010855198, 0.23529914394021034, 0.17811443816338265, 0.10950523149222136, 0.08175378026706831, 0.1541912475866931, 0.15272493341139384, 0.13253504250730785, 0.16295801502253326, 0.13828741812280246, 0.1933495577956949, 0.09593094845435449, 0.14241874643734523, 0.17391218936869077, 0.12095733519111361, 0.09848164301365614, 0.11003467879657235, 0.20148623761321816, 0.13866631207721575, 0.08767777774482965], [0.022672742139548063, 0.01764939472611461, 0.09791139539863382, 0.04768437073965158, 0.05903351014213903, 0.044410924427211285, 0.02908598372180547, 0.008849943954763668, 0.018058890609868934, 0.04080899931224329, 0.030463491233864, 0.029540741283978735, 0.04312031010964087, 0.0010524743951724044, 0.07789697365037032, 0.020360342293445553, 0.06374535230653626, 0.005637025086408747, 0.014838889108172484, 0.09719910326280765, 0.03387939936614462, 0.05430038911955697, 0.053572103913341246, 0.05298916430079511, 0.04198678682691284, 0.03838620860395687, 0.052531383865113766, 0.04447014357096382, 0.05690376853038158, 1.6925806339297975, 10.104686175073896, 26.360258204596384, 43.88718121392386, 51.859648500170024, 39.50815895625523, 30.909367152622767, 27.886450869696482, 22.384858540126256, 21.927654913493566, 30.936093398502894, 18.83531744139535, 20.04025145939418, 11.395915951047625, 3.6432410308292935, 0.38134504003184183, 0.30090775340795517, 1.5619149825402667, 2.5033645161560605, 4.0013333814484735, 5.074318936892918, 4.592120034354074, 7.414077912058149, 9.581507665770394, 4.252472111157008, 4.309093849999564, 1.6763830802270343, 5.891977301665714, 8.71716913155147, 18.148802416665212, 28.78470877238682, 41.73488984789167, 46.63739633560181, 51.58814069202968, 53.16285957608904, 54.584596497671946, 55.97699812480381, 58.031563077654155, 55.820458684648784, 57.56886168888637, 59.443895612444194, 53.7684645652771, 51.23532158987862, 44.72795493262154, 45.31278828212193, 50.23842184884207, 54.409234387534006, 53.8962037222726, 55.969556604112896, 56.699294635227744, 58.97152927943638, 53.586237634931294, 56.74462815693447, 50.916694572993684, 55.56531041009085, 53.943917001996724, 48.419001306806294, 43.92874533789498, 34.88621377944946, 38.11098391669137, 28.191615751811437, 47.97652612413679, 60.81556728907994, 57.68595273154122, 54.741879395076204, 49.404985427856445, 49.298479965754915, 51.14721495764596, 52.21164076668875, 49.47379343850272, 50.43453475407192, 50.69628381729126, 47.78217111315046, 50.20372601917812, 47.41110256740025, 50.058380126953125, 50.00826971871512, 51.84472376959664, 52.301786695207866, 53.46206290381295, 53.175494875226704, 52.23787716456822, 44.336184229169575, 42.365494455610005, 33.249287673405235, 25.748012474605016, 17.852496487753733, 11.496926256588527, 6.4822419711521695, 6.823088024343763, 9.278884955814906, 15.863402673176356, 23.34540183203561, 17.45439771243504, 4.564968645572662, 9.080229009900775, 6.660475424357823, 2.0239438073975697, 3.982063855443682, 0.2304745428264141, 0.6789272661720003, 1.1698130454335893, 3.658331649644034, 9.457450185503278, 10.696719595364161, 15.96014244215829, 28.737872702734812, 24.59089595930917, 25.039987564086914, 16.00544122287205, 18.338634150368826, 33.67024775913784, 40.2670134135655, 39.421417645045686, 30.485891819000244, 17.872067826134817, 3.5899090468883514, 0.0725540735625795, 0.05195222029994641, 0.04036451816292746, 0.01488887339032122, 0.053665945306420326, 0.004771710157261363, 0.008627068949863315, 0.04833361679422004, 0.008287783628994865, 0.01835175819828042, 0.028147780136870484, 0.01874461809971503, 0.02168184013238975, 0.018253857469452277, 0.03798432249043669, 0.06588200479745865, 0.0442950476094016, 0.0353976520044463, 0.04664538434839674, 0.041136534951095066, 0.03157567459025553, 0.003421207278734073, 0.018781610132594193, 0.01908395515887865, 0.04807769713391151, 0.06949804004813943, 0.015188980947381683, 0.023790436896628568, 0.03514159663713404, 0.07897279092243739, 0.08689301128366164, 0.05291365013856973, 0.05449684536350625, 0.034415011161140034, 0.08694499385144029, 0.025172398991084526, 0.0559339316428772, 0.005934436314938856, 0.057921621948480606, 0.05138377080272351, 0.08554284873285464, 0.06554262193718127, 0.04992804177371519, 0.03886886752609696, 0.055328732689044306, 0.02430477661878935, 0.02762908421988998, 0.032628231681883335, 0.026816384168341756, 0.06166737273867641, 0.05440218972840479, 0.0488333544427795, 0.0513010404205748, 0.026053517424900616, 0.017619223666510413, 0.06716765223869256, 0.014483847356002246, 0.020813663057716827, 0.06624221189745835, 2.1959102026053836, 12.03999832698277, 31.253612177712576, 48.888081141880576, 59.53754343305315, 47.01775114876883, 38.46967077255249, 31.639376163482666, 28.073076009750366, 26.34128267424447, 35.81807490757534, 21.99673216683524, 23.459532942090714, 11.1909328017916, 3.9535514882632663, 0.7792917149407523, 0.638379153396402, 1.6493715239422662, 2.2653131527560095, 5.978933138506753, 7.7719535657337735, 11.330756613186427, 13.603864993367877, 16.5120986529759, 8.370830961636134, 10.123263921056475, 7.74635466507503, 10.193141954285757, 10.524655273982457, 15.89727861540658, 26.122501271111624, 39.320324829646516, 46.32046120507376, 53.824637276785715, 53.255645820072715, 56.25353990282331, 56.44964585985456, 58.505180086408345, 57.223953110831125, 56.579604966299875, 59.9490852355957, 54.585339954921174, 54.82834277834211, 47.7467804636274, 47.95187738963536, 50.59663275309971, 56.49225916181292, 56.99221331732613, 57.80228294645037, 58.18077564239502, 59.59646415710449, 54.95728744779314, 58.09579569952828, 52.375249998910085, 55.921971866062705, 55.34555278505598, 51.65428754261562, 46.79314020701817, 40.64376211166382, 41.15564285005842, 32.01126459666661, 49.50651250566755, 61.297397068568635, 59.45556858607701, 55.74165569032942, 51.544141224452424, 50.54034539631435, 52.10105671201433, 53.44114187785557, 52.0684939793178, 52.48693881716047, 51.958375453948975, 49.28260333197457, 51.60365949358259, 50.6506793158395, 53.30372388022286, 52.1190699168614, 53.18207481929234, 53.97808824266706, 55.19687870570591, 55.06099625996181, 53.31834636415754, 45.7102495602199, 42.8753011567252, 34.85606901986258, 28.683994633810862, 22.699273211615427, 13.297485045024327, 8.294420753206525, 6.842678904533386, 8.604062012263707, 13.249787398747035, 17.994911977222987, 14.876428433826991, 10.97748327255249, 10.58759639944349, 8.554609077317373, 5.29021075793675, 4.975637146404811, 1.9188010607446944, 0.7145629482609885, 1.6733978518417902, 3.831789084843227, 9.234951496124268, 14.280521392822266, 20.157465832574026, 29.912738391331263, 24.49533043588911, 22.627407993589127, 19.322137764522008, 23.284193413598196, 40.98630482809884, 44.577943325042725, 45.753456933157786, 36.83387722287859, 20.219405548913137, 3.921678798539298, 0.05219818585153137, 0.0821467809645193, 0.08568981941789389, 0.02735045399250729, 0.02888431293623788, 0.05357053989012327, 0.016793361731937954, 0.05693362067852702, 0.06204625312238932, 0.021751995564305356, 0.010615198606891292, 0.042756021621504, 0.04913879019607391, 0.06118833380086081, 0.06229540439588683, 0.04642279093552913, 0.02562150774922754, 0.06714933857853923, 0.018756677363333956, 0.018022556755957857, 0.029625368171504567, 0.02617148752324283, 0.030944375786930323, 0.06455426782901798, 0.07928548700043134, 0.03754812625369855, 0.012386616901494563, 0.014331202421869551, 0.0330151153861412, 0.034431513132793565, 0.20689393100993975, 0.12607263427759918, 0.12657903853271688, 0.1504927296191454, 0.10177211716238942, 0.13310676254332066, 0.13705100518252167, 0.09547257090785674, 0.16432747510927065, 0.16582850313612393, 0.18232051389557974, 0.1383298672735691, 0.16431315802037716, 0.08816063683480024, 0.17729346507361957, 0.20486663122262272, 0.21766328598771775, 0.08163853787950107, 0.11384079206202712, 0.16383890275444302, 0.12563563058418886, 0.16154089463608606, 0.09925742567117725, 0.15367385106427328, 0.15076399434890064, 0.20500821433961391, 0.14099195014153207, 0.1373596436211041, 0.17195889061050756, 3.2952884903975894, 15.179526226861135, 39.35528121675764, 58.5742312840053, 66.16447121756417, 51.186555658067974, 41.98574760981968, 37.61485821860177, 33.48302854810442, 32.57139710017613, 43.35872554779053, 28.944380113056727, 28.648095028741018, 14.121225254876272, 4.959533393383026, 0.9108586779662541, 1.0018090776034763, 1.7075926512479782, 6.811986540045057, 8.393437794276647, 16.62107593672616, 14.580365691866193, 19.39791308130537, 20.77139128957476, 10.57223219530923, 13.342596224376134, 7.38263383933476, 12.087460603032794, 13.728203007153102, 22.73202701977321, 35.19726378577096, 47.31616933005196, 50.43080357142857, 55.01616300855364, 55.61571959086827, 57.41921138763428, 55.86949559620449, 59.306786809648784, 56.42562593732561, 58.16161251068115, 63.09040750776018, 58.97700445992606, 55.732546601976665, 48.764358043670654, 50.089181491306846, 54.1258590562003, 58.44898305620466, 59.45153863089425, 59.69419057028634, 59.67465223584856, 60.43321486881801, 58.68679210117885, 59.570193018232075, 54.23013762065342, 58.741425786699565, 56.95255994796753, 55.146851675851, 53.13850266592843, 43.39279951368059, 47.84209932599749, 36.14102370398385, 51.582481384277344, 63.054151807512554, 61.800898279462544, 58.045799936567036, 54.01497622898647, 53.48337302889143, 53.893066610608784, 56.19884368351528, 55.05991234098162, 54.38151107515608, 54.86367784227644, 50.99173511777605, 54.326978138514924, 52.00628675733294, 55.681473868233816, 56.01956973757063, 56.50692680903843, 57.945426259722026, 59.002386229378835, 59.15594836643764, 56.393865721566335, 46.65925536836897, 44.53916195460728, 36.638605049678254, 29.754635606493267, 22.194679396493093, 16.340346132005962, 10.4405768598829, 11.019468631063189, 12.69736305304936, 23.615773609706334, 32.808876105717246, 24.175084488732473, 14.03471757684435, 19.795289243970597, 13.451120138168335, 8.414265888077871, 6.5377980300358365, 2.9374703764915466, 1.4905418923922946, 2.1677550162587846, 5.295734575816563, 11.343045370919363, 14.961364950452532, 25.440054416656494, 38.871825558798655, 36.49696602140154, 37.137777532849995, 26.447854144232615, 29.94232382093157, 46.82333707809448, 51.22720609392439, 52.47540133340018, 44.42394692557198, 26.236073051180156, 6.005404472351074, 0.22876905862774166, 0.20005861350468226, 0.255340679947819, 0.10269020896937166, 0.15807667481047766, 0.10471626025225435, 0.07646652005080666, 0.1158994265965053, 0.2141572276928595, 0.08829755163086311, 0.13207871413656644, 0.14005236913050922, 0.11188800899045807, 0.15552555955946445, 0.18755944206246308, 0.1213987765035459, 0.1441839010055576, 0.14143903686531953, 0.1112921398931316, 0.09785994208816971, 0.1320592944643327, 0.14195617554443224, 0.13182405994406768, 0.13958591701728956, 0.13597525576395647, 0.189130427049739, 0.13607791811227798, 0.08868616899209363, 0.11489971381212984, 0.08337657140301806], [0.02852595823683909, 0.023077242309227586, 0.028967345266469886, 0.06805905047804117, 0.05202946811914444, 0.04566566799102085, 0.025467738143301437, 0.07809032898928438, 0.00707320128068594, 0.022302692889102867, 0.05632965326575296, 0.013755816600418516, 0.005771563313568809, 0.030603500149611915, 0.0480305118087147, 0.01831894594111613, 0.02576934695909066, 0.03617366536387375, 0.028486426786652634, 0.12145608557122094, 0.01289223914500326, 0.023504356354741112, 0.019849071245906607, 0.04095828719437122, 0.08251059108546802, 0.004010113546558256, 0.07953803094902209, 0.02372950954096658, 0.15401845185884408, 1.3417714067867823, 11.705205457551138, 37.65215962273734, 53.84866067341396, 47.14071341923305, 38.290118898664204, 33.591052191598074, 27.211073807307653, 24.26673470224653, 25.419253247124807, 29.07902751650129, 31.24963433401925, 20.005244697843278, 6.771372582231249, 1.622079759836197, 0.20994317238884314, 0.32313452501382145, 1.2941621329103197, 1.2817039042711258, 5.3469375882829935, 4.4795692052159986, 11.048011830874852, 14.285604000091553, 16.62557315826416, 4.8771103875977655, 11.764182635716029, 7.787838016237531, 8.941133890833173, 12.227558868271963, 12.528637341090612, 13.796315329415457, 26.01104348046439, 46.51019218989781, 53.41388062068394, 56.088735580444336, 58.081162793295725, 54.33988789149693, 54.29601001739502, 54.806400367191856, 58.83917304447719, 57.55495834350586, 55.12277616773333, 47.02498769760132, 42.43125220707485, 45.590254170554026, 54.63324778420584, 54.469728878566194, 56.32542249134609, 57.97985110964094, 56.80784634181431, 56.26064443588257, 58.11426053728376, 63.17341763632638, 53.479409081595286, 53.50332130704607, 52.20544992174421, 49.15694168635777, 38.541122572762625, 30.97833844593593, 39.427205494471956, 34.63920184544155, 54.506936482020784, 56.76511492047991, 55.98341826030186, 49.31331089564732, 48.518214634486604, 50.94297613416399, 50.672354221343994, 52.66137681688581, 49.848853724343435, 49.945864473070415, 49.0749876839774, 50.132579939705984, 48.72346442086356, 45.84670870644705, 45.54549387523106, 45.12960597446987, 46.27177170344761, 48.47404146194458, 50.83655057634626, 54.17825542177473, 52.716903345925466, 49.07394198008946, 44.62510074887957, 37.03380468913487, 31.79078435897827, 26.816652366093226, 15.946803637913295, 13.51893629346575, 3.794212792600904, 12.05775965963091, 25.07380792072841, 23.463455200195312, 19.846711124692643, 9.193497674805776, 9.05289305959429, 6.730004744870322, 2.730143730129514, 4.621129197733743, 1.8332772042070116, 0.6014816675867353, 1.033446831362588, 1.6818867049046924, 7.2230576021330695, 12.423289622579302, 21.088463647024973, 31.519915785108292, 24.41163764681135, 21.94703343936375, 19.224220275878906, 22.846588918140956, 27.15253870827811, 38.6628862789699, 46.68486295427595, 36.22808115822928, 24.300127744674683, 6.1869674154690335, 0.44814225286245346, 0.032165124746305604, 0.1012495094910264, 0.006258958410139063, 0.03455588181636163, 0.05869017820805311, 0.018129651634288684, 0.0885142350037183, 0.051476441722895415, 0.04799070215917059, 0.008843116196138518, 0.027777807221614888, 0.046173758405659876, 0.04134666706834521, 0.034683632996997664, 0.06475234577166182, 0.06906938233545848, 0.02853358836312379, 0.08490728533693723, 0.024130103045276234, 0.0673815468326211, 0.01630110662829663, 0.03630557257149901, 0.03385633935353585, 0.038372169714421034, 0.01872148853726685, 0.05458756210282445, 0.030435586481222084, 0.04756386970568981, 0.051239307304578166, 0.0047054948933821705, 0.03224181277411325, 0.022170941744531904, 0.047468097880482674, 0.00915599802309381, 0.0369103711896709, 0.012269962312919753, 0.09759173076599836, 0.03381743894091674, 0.02370566242773618, 0.016677359385149818, 0.05048775852524808, 0.026748574771253125, 0.04726918533976589, 0.1475773767701217, 0.028920804549540793, 0.02031125537385898, 0.016076961066573858, 0.02278785390912422, 0.0676316073430436, 0.058086709518517764, 0.05317319656855293, 0.023982681134449582, 0.06142585498413869, 0.04285033120374594, 0.031137853262147734, 0.045027471879231076, 0.0395686271201287, 0.2028606781469924, 1.8221550924437386, 14.107372283935547, 43.589120864868164, 60.677728925432476, 53.4228299004691, 41.14277826036726, 36.07641935348511, 33.34314741407122, 30.553664548056467, 25.141466004507883, 29.427952153342112, 33.8966999735151, 19.052476440157207, 7.274604116167341, 1.8000230171850748, 0.358006230954613, 0.7260428379688944, 1.4639609072889601, 2.47274489062173, 8.891645346369062, 8.23439005443028, 13.41428165776389, 12.176007577351161, 14.91406682559422, 11.899943487984793, 8.872119171278817, 9.090102400098528, 12.391822968210493, 11.183041385241918, 14.917709418705531, 17.964986085891724, 31.54668024608067, 49.82495886938912, 56.97531182425362, 57.421542508261545, 58.35958753313337, 54.60517011369978, 54.52674232210432, 54.84075573512486, 60.00314222063337, 59.87677533285958, 57.14375352859497, 48.99802596228463, 45.51595708302089, 47.75353063855852, 56.242763246808735, 55.995247568402974, 57.87971019744873, 59.006895610264365, 56.25827510016305, 56.584003176007954, 57.74575587681362, 63.83573382241385, 53.820322445460725, 54.45812538691929, 53.29906163896833, 53.44014481135777, 43.78457716533116, 36.80658122471401, 44.18023191179548, 38.6023987361363, 55.52909639903477, 58.08786085673741, 57.46222768511091, 51.66865989140102, 49.76761886051723, 52.35358204160418, 53.120750018528526, 53.93074321746826, 52.52412905011858, 51.70345994404384, 51.21312209538051, 51.27877909796578, 50.18472964423043, 47.745119844164165, 47.66602155140468, 47.11119747161865, 49.71323183604649, 51.83057723726545, 53.55192048209054, 55.07583066395351, 55.69920219693865, 51.368549823760986, 45.43152257374355, 38.76119286673409, 31.982214178357804, 23.991836173193796, 19.222075019563945, 10.915970001901899, 4.837999411991664, 8.111943687711443, 13.669594952038356, 11.374820351600647, 12.632690957614354, 9.392752034323555, 11.107015933309283, 12.127941676548549, 8.932360053062439, 6.4700122731072565, 1.7826789021492004, 1.1393612623214722, 0.7203031916703496, 2.5737011304923465, 6.81140375988824, 12.00881654875619, 18.838204417909893, 31.596634319850377, 26.325763872691564, 30.143474170139857, 22.76979742731367, 24.882341623306274, 33.136035510471885, 43.01994528089251, 52.49759040560041, 42.83594308580671, 28.436096804482595, 8.134513173784528, 0.46386803473745075, 0.12219176680913993, 0.056967024957495074, 0.055356321922902546, 0.04043497723926391, 0.06417374539055995, 0.06278573415641274, 0.01861302980354854, 0.04640172242320009, 0.020381726324558258, 0.09205305975462709, 0.11047808107520853, 0.04401523333841136, 0.02697663039102086, 0.05726845735417945, 0.07861233276448079, 0.046224064991942475, 0.011625804422822381, 0.044105743124548874, 0.05461481546184846, 0.01853093215530472, 0.03320516286683934, 0.01257906130714608, 0.036382504871913364, 0.03001022305605667, 0.035913993404912095, 0.04733581408592207, 0.03240468831998961, 0.06968420291585581, 0.01602308199341808, 0.08813411290092127, 0.13417666299002512, 0.09693582489022187, 0.10441462429506437, 0.13968438601919583, 0.11289758767400469, 0.16753743429269108, 0.2502547342862402, 0.0729422973734992, 0.1274779210133212, 0.14408760331571102, 0.142260715631502, 0.09969698744160788, 0.09930887219629117, 0.29717084392905235, 0.10088251704084021, 0.13115528225898743, 0.11545707604714803, 0.09388902623738561, 0.14879217158470834, 0.15018489185188497, 0.15228731903646672, 0.09283954969474248, 0.19043530417340143, 0.2585990051073687, 0.13704587545778069, 0.18679576446967466, 0.06713973052267518, 0.41958230680653025, 2.8057266686643874, 19.562284878322057, 52.613107681274414, 68.92059230804443, 60.47907297951834, 50.095431395939414, 45.46717725481306, 38.11660153525216, 35.39262975965227, 36.348156452178955, 40.34167875562395, 41.50540821892874, 26.137512854167394, 9.43305766582489, 2.5142575544970374, 0.604379554944379, 0.8040899985602924, 2.6162833826882497, 4.001545735767909, 16.0507139478411, 14.143360478537423, 20.121957063674927, 23.92898450578962, 35.66396038872855, 18.226116759436472, 24.462352548326763, 15.142787626811437, 13.872405052185059, 16.5034134047372, 17.581558431897843, 17.88078955241612, 32.89231354849679, 57.17065347943987, 57.950262205941335, 57.74765273502895, 57.94958823067801, 55.187842573438374, 54.8928359576634, 55.78446354184832, 59.37270436968122, 61.89130129132952, 59.19374656677246, 51.87431614739554, 47.84361055919102, 50.721703801836284, 58.1803309576852, 58.57481493268694, 60.52713366917202, 62.39275278363909, 56.58275597436087, 57.90921572276524, 58.8995737348284, 64.57040854862758, 55.495314257485525, 57.47513396399361, 55.385817595890586, 57.85427631650652, 46.19841957092285, 39.1981338092259, 50.129144055502756, 44.85725048610142, 55.6302170072283, 59.72271292550223, 59.5033791405814, 53.13258974892752, 51.242426122937886, 54.55809259414673, 53.88158471243722, 57.120782784053254, 54.73033843721662, 54.09310524804251, 53.831453459603445, 54.52246223177229, 53.30752107075283, 50.321063722882954, 49.59523752757481, 48.543408802577424, 51.77072198050362, 53.15252413068499, 54.35905449731009, 57.90004757472447, 56.63594790867397, 52.802671909332275, 50.158573150634766, 41.04101841790335, 34.25711693082537, 29.084066697529384, 21.547312259674072, 18.71741345950535, 7.376310110092163, 21.239604336874827, 36.23015866960798, 33.051340443747385, 31.643496445247106, 18.048024007252284, 15.985564163752965, 16.6857237134661, 13.09547746181488, 11.386573229517255, 3.4620888999530246, 1.867375488792147, 1.8959362762314933, 2.9261498068060194, 9.040770190102712, 16.736087730952672, 27.458427940096172, 42.45643942696707, 36.018130915505544, 33.50166014262608, 30.12270600455148, 33.191200733184814, 37.90658528464181, 49.589307240077424, 61.013174057006836, 50.37768111910139, 34.375066076006206, 11.71979580606733, 0.7470432253820556, 0.1589923578181437, 0.18563565957759107, 0.11152655338602406, 0.24956108150737627, 0.270332151225635, 0.14605353639594146, 0.15298409307641642, 0.12891470534460886, 0.08266402142388479, 0.21933805969144615, 0.2013262661972216, 0.16374355501362256, 0.12489263473876885, 0.12354927110884871, 0.1553181992577655, 0.20213417070252554, 0.08574657887220383, 0.17344656506819384, 0.11965868701892239, 0.12265646830201149, 0.12475780983056341, 0.12127057409712247, 0.14168861561587878, 0.1971159835479089, 0.08897493313997984, 0.26338544541171616, 0.09058477104242359, 0.09221911762974092, 0.13164639233478478], [0.027028572246698395, 0.06137375028005668, 0.037430166333381615, 0.03369556387354221, 0.0585325952353222, 0.10080783069133759, 0.03910191377092685, 0.1042069790086576, 0.010249711656277733, 0.0311916373404009, 0.025293904256873896, 0.022606764787009785, 0.026843204961291382, 0.11417483485170773, 0.05315117810719779, 0.02998162280502064, 0.06757421006581613, 0.030206102545240095, 0.02695167387303497, 0.03960171927298818, 0.030891823249736, 0.0642636309244803, 0.030141173529305627, 0.10470610936837536, 0.025576027243265083, 0.10059690129544054, 0.005835154343263379, 0.038957572409084866, 0.2977135090955666, 4.417128350053515, 21.35090753010341, 42.839813232421875, 49.58885908126831, 49.79357385635376, 43.05529076712472, 27.499568223953247, 19.320044619696482, 18.656213726316178, 27.263232197080338, 31.546117441994802, 23.135646138872417, 15.513397591454641, 4.255304370607648, 0.8951339274644852, 0.2532944083213806, 0.7442095002957753, 3.072360532624381, 2.038428847278867, 6.633714871747153, 5.067512307848249, 13.15514772278922, 9.283330934388296, 12.124769823891775, 10.039545944758824, 8.97164603642055, 11.585030283246722, 23.30092293875558, 21.83931725365775, 24.919754198619298, 29.713609967912944, 25.902936458587646, 29.468105792999268, 45.47149556023734, 52.95477145058768, 56.728793212345664, 53.739553110940115, 52.882343428475515, 49.34144762584141, 53.64465114048549, 56.60490335736956, 52.122161865234375, 42.645037855420796, 46.188292571476524, 51.81483956745693, 53.06986141204834, 57.57904774802071, 57.989227703639436, 52.40022529874529, 55.35532890047346, 57.756101744515554, 62.92257377079555, 59.69718524387905, 59.07582868848528, 60.053412437438965, 49.92606210708618, 45.068579946245464, 35.48373801367623, 37.98351226534162, 38.15059559685843, 43.67178705760411, 59.04556928362165, 56.059045927865164, 53.18232842854091, 51.51983642578125, 49.032933712005615, 53.25010463169643, 56.127579484667095, 52.59445524215698, 51.91143689836775, 54.15619489124843, 51.24711615698678, 50.674782616751536, 50.00047731399536, 51.112870012010845, 50.07962771824428, 46.65590286254883, 45.11192280905587, 47.75642108917236, 49.467550482068745, 51.545173031943186, 52.913179533822195, 51.64681822913033, 43.6461968421936, 32.589684758867534, 30.771591322762625, 29.102356093270437, 24.113810062408447, 16.29330509049552, 5.301101190703256, 3.1562576421669553, 3.71022036245891, 7.141859650611877, 6.971189311572483, 10.224989891052246, 12.02290575844901, 9.473302500588552, 6.653773886816842, 5.384378390652793, 1.0724244884082248, 1.0263776906899043, 0.6052898232425962, 1.2402850410767963, 3.348455671753202, 8.542779769216265, 15.317835330963135, 25.802046877997263, 30.24404239654541, 22.32780167034694, 21.047573498317174, 18.62979667527335, 29.461018630436488, 37.67481769834246, 47.406933648245676, 46.78557709285191, 30.181696210588726, 10.633896589279175, 0.4923956553850855, 0.012635140530099826, 0.0638351971283555, 0.029790520202368498, 0.025956212110551338, 0.05256464904440301, 0.030479660723358393, 0.025903958128765225, 0.03741334205759423, 0.07917436332042728, 0.05282025318592787, 0.09739663837743656, 0.06783421111426183, 0.03115056561572211, 0.03925725418542113, 0.0641849140769669, 0.01762274356691965, 0.05117787274398974, 0.04954982974699565, 0.05097927572205663, 0.008052750972897878, 0.06465211936405726, 0.09840591172022478, 0.014289330025868756, 0.06761429112936769, 0.10808266925492457, 0.06582156089799744, 0.08021888655743428, 0.02491701198076563, 0.025642691612509743, 0.00587340590677091, 0.03491130524447986, 0.0235587341511356, 0.07474566703396184, 0.013801459954785449, 0.007203399852317358, 0.017071547518883432, 0.036567917958434136, 0.027732664286824207, 0.05211806443652936, 0.03796105891732233, 0.04532018510092582, 0.030968178795384507, 0.021010305898796235, 0.03257087850943208, 0.027635715203359723, 0.03229623128260885, 0.06630628595926932, 0.04564396844112447, 0.019902765418269804, 0.03010650717520288, 0.02127859355615718, 0.06214267973388944, 0.05771958814667804, 0.04658513722409095, 0.04159314491386924, 0.04733887767153127, 0.05178675953564899, 0.23676005697676114, 5.51349242244448, 26.153511081423076, 49.62870352608817, 55.92654378073556, 55.26279279163906, 47.94512721470424, 33.4327062198094, 23.632190465927124, 23.74111216408866, 28.434457029615128, 32.43337113516671, 24.926754508699688, 15.155316965920584, 5.164090965475355, 0.9436268167836326, 0.6193170419761113, 0.5428997224995068, 2.2065989204815457, 5.099557399749756, 7.908750568117414, 8.646689210619245, 7.982234716415405, 10.432837435177394, 13.678684064320155, 9.197795135634285, 8.161568590572902, 9.705269847597394, 15.533606427056448, 22.759505408150808, 26.776618582861765, 27.230410643986293, 28.0156752041408, 34.00946923664638, 49.607299600328716, 55.16051878247942, 59.39160346984863, 54.03457014901297, 53.499121120997835, 50.45682804925101, 54.566371372767854, 57.63562345504761, 54.8170519556318, 44.61088820866176, 47.949382986341206, 54.2692003931318, 55.763837814331055, 58.430771827697754, 58.24295507158552, 53.54133490153721, 54.797961780003135, 57.85112878254482, 62.82600770677839, 60.17137895311628, 60.17711121695382, 60.29843371255057, 51.43908446175711, 50.35012108939034, 41.023192814418245, 43.12885134560721, 43.6950044631958, 46.11160182952881, 58.2000082560948, 58.80006858280727, 53.68267515727452, 52.85828529085432, 50.64527014323643, 53.54479857853481, 56.98267691476004, 54.19897147587368, 54.252854755946565, 56.09295661108834, 54.076842989240376, 53.16951942443848, 51.97082315172468, 54.26025458744594, 52.13270228249686, 48.14243868419102, 46.91358028139387, 50.43626485552107, 52.24694108963013, 53.8005895614624, 54.90176786695208, 53.41498538425991, 47.65397684914725, 40.04551179068429, 36.23901762281145, 28.661779505865915, 23.95395633152553, 14.775069849831716, 7.710160630089896, 5.040184608527592, 9.052544781139918, 13.163773042815071, 12.684634821755544, 12.792707102639334, 9.016674705914088, 13.197713255882263, 8.533944266183035, 8.181529028075081, 3.8915739910943166, 1.4947110286780765, 0.9107643344572612, 1.2715817902769362, 4.56675910949707, 10.240246398108345, 18.549772535051616, 27.42860800879342, 31.343104975564138, 21.58584349496024, 24.417818069458008, 24.429664748055593, 33.01712056568691, 43.15277051925659, 52.57793590000698, 51.544193335941856, 35.372532095227925, 13.826657244137355, 0.6794685742684773, 0.013597141186307584, 0.06988444538520915, 0.05485778867400118, 0.03501287854409643, 0.034840683319738934, 0.035963251654590876, 0.058379653442118845, 0.020530084613710642, 0.04042212239333561, 0.04735016170889139, 0.028153378050774336, 0.024075742212257216, 0.07945539895445108, 0.042516746425202916, 0.03256645106843539, 0.041796797021691284, 0.030002860951104333, 0.03124699222722224, 0.0462814826252205, 0.030319964114044393, 0.06053567810782364, 0.03879371977278164, 0.05244695714541844, 0.020727472146973014, 0.05194759608379432, 0.06925648158150059, 0.06446824994470392, 0.01809627958573401, 0.02946341543325356, 0.09482543848987136, 0.0977096872936402, 0.17353899510843412, 0.15636747223990305, 0.11714422622961657, 0.2208985545273338, 0.15263277478516102, 0.19171689397522382, 0.10646531996982438, 0.15357729553111962, 0.14259425630526884, 0.09644935599395207, 0.11923720820673875, 0.17463164004896367, 0.11831498412149292, 0.03665560843156917, 0.2311914557857173, 0.1901471439216818, 0.1558867030377899, 0.08059447604630675, 0.10858590475150517, 0.16313157070960316, 0.19710481486150197, 0.18735106395823614, 0.19903881608375482, 0.231719220323222, 0.12134024607283728, 0.1402674647314208, 0.7432955407670566, 7.680234738758632, 32.43677922657558, 56.378635270254954, 62.81773240225655, 61.21407427106585, 54.48400395257132, 38.030092988695415, 30.039084434509277, 29.50799192701067, 39.453170912606375, 41.082061426980154, 30.760700021471294, 19.337389060429164, 5.551746598311833, 1.1916164926120212, 0.792566682611193, 1.7132901740925652, 8.13639874117715, 6.835404140608651, 13.82447898387909, 13.667678117752075, 23.672323260988506, 19.461852141789027, 19.541709525244578, 22.398423160825455, 15.466516358511788, 16.208504063742502, 27.00987482070923, 24.01449077469962, 28.953421456473215, 35.91493627003261, 34.18252454485212, 37.19958175931658, 54.629950863974436, 59.95839582170759, 59.34733649662563, 54.056971141270225, 54.59388971328735, 48.54577466419765, 55.60932724816458, 60.24540506090437, 56.39958756310599, 46.899649143218994, 52.328558104378835, 56.86378976276943, 56.51176970345633, 61.63100092751639, 60.65377153669085, 52.16872174399239, 54.983992849077495, 60.36058534894671, 64.41325419289726, 62.43249647957938, 60.92443861280169, 62.19477776118687, 52.88165208271572, 54.72732291902815, 43.947213649749756, 46.578697953905376, 47.95898192269461, 50.13457407270159, 59.25903878893171, 59.333405358450754, 55.003569398607524, 55.305666651044575, 53.14866440636771, 55.544622148786274, 57.98974881853376, 55.727127007075715, 57.24785838808332, 59.15339837755476, 56.121124608176096, 54.59125634602138, 55.009993008204866, 55.654719829559326, 55.01720871244158, 51.73327466419765, 50.74773522785732, 53.73846919195992, 54.04569074085781, 56.11424241747175, 57.89123378481184, 57.06474903651646, 47.73563207898821, 39.81021451950073, 37.346626486097065, 32.701147760663716, 28.645668370383127, 21.522201469966344, 11.234384230204991, 9.540999667985098, 10.17543968132564, 19.02165249415806, 11.27339141709464, 17.233908789498464, 24.025277853012085, 21.291868686676025, 12.725595320974078, 13.780395269393921, 5.105752153056009, 1.72093351823943, 1.2534963893038886, 1.7627196588686533, 5.099256455898285, 11.45036290373121, 21.727697917393275, 34.53826189041138, 39.541864667619976, 32.680403913770405, 32.60787514277867, 28.76810778890337, 40.47106810978481, 49.14720031193325, 59.2458233152117, 58.938414164951865, 43.379243578229634, 17.516747372491018, 1.7587373639856065, 0.07406651454844645, 0.17617509008518287, 0.15439974782722338, 0.19537427914994104, 0.1391162079359804, 0.08144121311072793, 0.16823176560657366, 0.20837230953787053, 0.1448053169463362, 0.10818556230515242, 0.2090422271617821, 0.21494906448892184, 0.1503615416586399, 0.08376151788979769, 0.14407251269689628, 0.08593916068119661, 0.10706163011491299, 0.2517334520816803, 0.14758846403232642, 0.16953894974929945, 0.16427943482995033, 0.13947857277733938, 0.12111955934337207, 0.177653007209301, 0.2053888996264764, 0.15823083796671458, 0.24785063043236732, 0.08687674679926463, 0.15522906689771584], [0.02410035946273378, 0.04327111791021057, 0.051234761119953225, 0.01932767136687679, 0.006841214398653912, 0.07117319373147828, 0.028040215373039246, 0.011390050823268081, 0.049534949474036694, 0.020860375104738132, 0.02666995461497988, 0.048639663229031224, 0.02137959179734545, 0.10503128370536224, 0.07792646956763097, 0.02580761463780488, 0.02411110406475408, 0.040921978785523346, 0.03230796993843146, 0.02106583720472242, 0.02320206900393324, 0.041799629905394146, 0.10237356381756918, 0.052153792697936296, 0.051692887608494074, 0.0104971038277394, 0.0155973996567939, 0.02054672738138054, 0.3919985555112362, 4.122647191796984, 22.094807726996287, 40.64717020307268, 46.10543877737862, 48.05446754183088, 31.913187299455913, 28.78239675930568, 26.657111304146902, 25.11080707822527, 26.760516132627213, 36.106327874319895, 29.365130015781947, 10.080925941467285, 2.806670755147934, 0.2806711792945862, 0.2610900971506323, 0.6224671815122876, 1.6393317026751382, 3.6587298682757785, 7.276977360248566, 7.623328123773847, 6.915341862610408, 5.824161580630711, 6.842018825667245, 7.161085316113063, 4.982842428343637, 10.20392382144928, 21.979038579123362, 26.46628597804478, 35.68867860521589, 44.691376141139436, 56.32983112335205, 51.47938748768398, 45.69287558964321, 45.51149633952549, 53.74361433301653, 56.406556606292725, 54.0914237839835, 51.22229371752058, 55.71724666867937, 53.62020737784249, 48.070410183497835, 42.40442521231515, 51.088999475751606, 53.141108240400044, 55.318288053785054, 54.71445485523769, 45.88539627620152, 53.18728944233486, 58.10703788484846, 54.42602123532976, 56.25005538122994, 54.39577225276402, 51.40584427969796, 54.707065446036204, 50.06834036963326, 41.16219847542899, 39.79047121320452, 40.4181923185076, 27.735539470400127, 48.84741333552769, 58.25289446966988, 55.988549504961284, 52.66414567402431, 52.11880241121565, 52.04792036328997, 55.42488384246826, 53.136192389896934, 52.66253021785191, 55.66766779763358, 54.115798064640586, 51.35751608439854, 51.42287084034511, 53.14533274514334, 53.30054160526821, 50.47426107951573, 50.16074793679373, 48.04133892059326, 44.693922655923025, 49.154898915972026, 49.4506003516061, 51.906100681849885, 50.230751037597656, 47.34768288476126, 45.18459749221802, 43.2099472454616, 33.62258311680385, 26.970449004854473, 16.597446850367955, 10.908498951366969, 3.964145754064832, 7.798024943896702, 7.6699791976383755, 14.500825319971357, 7.694681780678885, 4.338331001145499, 12.286248564720154, 10.126581685883657, 7.152160355022975, 2.5090418457984924, 0.8105754905513355, 0.17162784694560937, 0.27165914859090534, 1.6116599589586258, 4.2925801532609125, 10.247885073934283, 19.67998388835362, 30.768068586077007, 32.53219536372593, 31.73872150693621, 32.087017331804546, 24.728883709226334, 33.016078335898264, 39.00407409667969, 42.64514207839966, 28.452492816107615, 13.605158226830618, 2.2300445309707095, 0.015415835560166409, 0.07677417461361204, 0.06391650597964015, 0.04735373080308948, 0.024337828059547713, 0.09872829727828503, 0.0766491341803755, 0.0282382135878184, 0.05505440437367984, 0.007267624888169978, 0.051257264733846696, 0.03692828790683832, 0.031089015704180514, 0.06291500864816563, 0.06995197319026504, 0.02113175518544657, 0.02982158014284713, 0.060034227158342085, 0.07418433536908456, 0.06553410632269722, 0.0697702072294695, 0.04125736168186579, 0.016716675400467854, 0.01730712130665779, 0.03861857970644321, 0.01977669191546738, 0.0707227618300489, 0.051731031454567394, 0.011514237998718662, 0.04110768024942704, 0.051393548492342234, 0.022825748393578187, 0.029782879898058515, 0.025315982090043168, 0.018655126116105487, 0.023523482560579265, 0.022345623799732754, 0.10851467214524746, 0.016444530271525894, 0.012866074834684176, 0.06573181785643101, 0.03703851252794266, 0.06012345451329436, 0.027914014644920826, 0.034000097175261805, 0.008112618965762002, 0.025520019266488295, 0.02588582767306694, 0.04062698907884104, 0.022072469349950552, 0.04657137314123767, 0.08194330188312701, 0.02212353759179158, 0.03610872616991401, 0.020376019845051423, 0.09651823408369507, 0.06117594375142029, 0.6216738383684839, 5.514880325113024, 26.64119471822466, 46.13780696051461, 53.32538488933018, 52.48796715055193, 37.96207707268851, 31.843882492610387, 28.1310396194458, 24.149758304868424, 30.445981366293772, 32.335363319941926, 21.206556967326573, 11.631496361323766, 3.480776080063411, 0.38567319778459414, 0.33897915908268517, 1.6088677602154868, 3.242813523326601, 6.5949000631059915, 8.062743493488856, 9.509914296013967, 11.20782995223999, 10.601393784795489, 13.827538796833583, 11.054177488599505, 4.185412006718772, 6.834607269082751, 21.15175305094038, 29.041616678237915, 37.781892912728445, 50.818631172180176, 57.27050256729126, 52.41693224225725, 49.37744276864188, 50.35550594329834, 53.873528276171, 56.291213035583496, 54.28221089499337, 50.755927153996055, 57.04515511648995, 55.67602300643921, 50.789191654750276, 44.71502086094448, 52.37971421650478, 56.47447177342006, 58.034384046282085, 56.53476129259382, 49.47122260502407, 53.42858648300171, 57.9119359425136, 56.52353647777012, 58.19441843032837, 55.9703243800572, 52.89910248347691, 56.64435175486973, 50.44695118495396, 45.532080377851216, 45.17855255944388, 43.92695965085711, 32.75458288192749, 50.49687399183001, 57.657882009233745, 56.88375541142055, 55.3493013381958, 54.868673597063335, 54.530091353825156, 55.291791098458425, 52.561871664864675, 53.40536560331072, 56.55070046016148, 55.43300976072039, 51.878453799656455, 53.41302946635655, 55.253596850803916, 54.51160567147391, 53.282486711229595, 52.53602089200701, 50.494890281132285, 46.921327522822786, 51.12890992845808, 52.3625556400844, 55.051616191864014, 53.65250607899257, 48.85583107812064, 45.22148200443813, 40.892017773219514, 31.370592049189977, 27.203960589000157, 16.122862304959977, 13.780969364302498, 7.245396060603006, 12.335018839154925, 12.682245509965078, 17.319038118634904, 15.368159396307808, 11.752447996820722, 11.25826518876212, 13.897290025438581, 9.4034982919693, 4.616345797266279, 2.233240485191345, 0.6729079005973679, 0.7116976848670414, 1.5732540083783013, 4.853236811501639, 11.72470383984702, 23.420437165669032, 30.338715076446533, 34.74356031417847, 31.66772481373378, 30.102382523672922, 29.396636622292654, 39.0597048486982, 45.10130943570818, 48.763819558279856, 34.19341584614345, 15.348039150238037, 3.0182095297745297, 0.06932317478848354, 0.034603301236139875, 0.03830299985462001, 0.05647874437272549, 0.03289228697706546, 0.028591586143842766, 0.05512784221874816, 0.03363636169316513, 0.07080698838191372, 0.008773222848373865, 0.07713356068623917, 0.03405362680288298, 0.009655150435199695, 0.08824423234909773, 0.023331675977845277, 0.009242916662645127, 0.030341232794203928, 0.05470808010016169, 0.032068443684173484, 0.07095621858856507, 0.046857633494905064, 0.0354496617136257, 0.08043339861822979, 0.023684675339609385, 0.04634591631059136, 0.06976025312074594, 0.04543396524552788, 0.0674216075401221, 0.06985030150307076, 0.099365190602839, 0.13280385094029562, 0.09691865116889987, 0.08609564442719732, 0.07681930397770234, 0.22948722009147915, 0.0879735986569098, 0.13014879769512586, 0.22444148441510542, 0.09218809500868831, 0.15741002772535595, 0.14096946349101408, 0.1135520279141409, 0.1820202621498278, 0.1560347050960575, 0.07346078633729901, 0.09185846269662891, 0.12023575391088213, 0.14064671152404376, 0.1552152790661369, 0.12532278522849083, 0.11726994519787175, 0.27764154757772175, 0.07996451734964337, 0.16269364420856747, 0.11978684871324471, 0.13396519076611313, 0.1888699917388814, 0.8943747282028198, 8.74124550819397, 34.281432151794434, 54.89219672339303, 58.53655815124512, 58.061044284275596, 41.88383838108608, 38.96650518689837, 38.002908161708284, 37.24125705446516, 38.623170375823975, 46.68037094388689, 35.283417974199565, 13.366724712508065, 3.9844249401773726, 0.6137369871139526, 0.900091792855944, 1.583249752010618, 2.9133308146681105, 11.884530646460396, 15.619043213980538, 18.918515171323502, 20.568047046661377, 14.23269954749516, 19.104356901986257, 13.694439104625157, 15.876649413790021, 15.66421171597072, 26.074384995869227, 29.831805774143763, 41.605667250497, 48.757034642355784, 59.23307337079729, 54.81589160646711, 53.52787971496582, 55.026981353759766, 58.883155141557964, 57.711126055036274, 55.88035215650286, 53.306815828595845, 59.41717978886196, 58.82570743560791, 51.86029468263899, 46.74685478210449, 56.02560772214617, 58.24316004344395, 60.68191868918282, 57.35535396848406, 51.27558640071324, 54.86820111955915, 60.91161223820278, 58.66790689740862, 60.57529163360596, 58.45887729099819, 55.28244229725429, 58.324096134730745, 52.88216972351074, 49.88765941347395, 48.43004894256592, 47.66787672042847, 37.28702483858381, 51.735866342272075, 59.34454332079206, 58.41219234466553, 56.750600133623394, 55.7780190876552, 55.46672589438302, 57.05558436257498, 53.036440576825825, 53.41159118924822, 57.02366433824812, 55.76415395736694, 53.837679045540945, 53.49583462306431, 56.34590230669294, 57.85773999350411, 55.564462729862754, 55.049740178244456, 54.35747725622994, 49.515399251665386, 54.58944981438773, 54.56164312362671, 55.00872496196202, 55.65204129900251, 52.658958843776155, 51.46070725577218, 47.39331865310669, 37.74885770252773, 30.411865711212158, 20.011465072631836, 14.707283224378314, 8.174057977540151, 16.472151722226823, 15.457337788173131, 25.546374014445714, 14.496435795511518, 15.251737117767334, 19.11282328196934, 22.7739611353193, 15.446766104016985, 6.874137307916369, 4.326829126902989, 0.8969309053250721, 0.7928534586514745, 2.4915078495229994, 5.564589474882398, 13.791083335876465, 27.51713674409049, 40.92917326518467, 45.44920573915754, 44.092931270599365, 44.24106339045933, 35.28732981000628, 43.51477861404419, 50.73262984412057, 54.75583137784685, 40.40327453613281, 20.965411049979075, 4.296383857727051, 0.1500031937445913, 0.16616694283272537, 0.3272025052990232, 0.16452179396791117, 0.11873919064445154, 0.13849129075450556, 0.11848000383802823, 0.12545853294432163, 0.1836540251970291, 0.08066697751304933, 0.167296703638775, 0.15104754056249345, 0.08415094949305058, 0.15265129879117012, 0.11386508361569472, 0.1328337336225169, 0.05220089999160596, 0.11918981932103634, 0.13178326641874655, 0.12771714531949588, 0.3028229863515922, 0.15746722822742804, 0.19878361906324113, 0.08331310123737369, 0.12543010232704027, 0.16348231903144292, 0.16996880168361322, 0.13602686513747486, 0.08691824600100517], [0.03188877100391047, 0.050387627112546136, 0.02443552013885762, 0.04595249152875372, 0.03230174098696027, 0.03147693756701691, 0.024327621196529696, 0.01069444216721292, 0.03856994570898158, 0.009129352801080261, 0.07720877629305635, 0.02854772224756224, 0.004528364174932773, 0.06350197536604744, 0.013048062167529548, 0.0011150661760309178, 0.02166516343796892, 0.025179501556392227, 0.03213668395099895, 0.01986470808541136, 0.047854842485061715, 0.08445316899035658, 0.06741752275930983, 0.00818100426944771, 0.01191009532859815, 0.07616602403244802, 0.034113198784845214, 0.035841240880212615, 2.211707583495549, 11.028642858777728, 35.88341576712472, 42.55302286148071, 45.534540040152415, 37.37908499581473, 27.282574244907924, 21.509661708559307, 20.66414758137294, 22.213378735951014, 38.764618328639436, 34.0381965637207, 16.63973879814148, 6.152021016393389, 0.7559864797762462, 0.2325787070606436, 0.28168463919843945, 1.5621277711221149, 1.9428444334438868, 6.042847011770521, 6.432512411049434, 6.464925757476261, 5.513921473707471, 10.459727832249232, 13.080258301326207, 4.77334121295384, 3.2055783442088535, 14.690180233546666, 27.5123233795166, 41.13091768537249, 41.667183126722065, 48.62070056370327, 55.431446416037424, 62.001874923706055, 60.71807016645159, 54.62227657863072, 48.91272292818342, 54.729000908987864, 54.83186204092843, 55.549458095005576, 54.95245844977242, 51.882938861846924, 46.18076419830322, 42.131340163094656, 50.75864389964512, 53.84040968758719, 55.69099290030343, 51.7834997177124, 48.61890098026821, 54.36440461022513, 53.24212115151541, 53.597222736903596, 52.750817503247944, 50.50024734224592, 50.05936329705374, 54.445823601314, 52.99465063640049, 44.92985568727766, 40.81830780846732, 37.965846470424104, 26.0265622820173, 44.467949867248535, 58.104401043483186, 56.92465598242623, 50.48019136701311, 51.77399805613926, 49.934736933027, 52.34540401186262, 51.508656774248394, 53.573786463056294, 52.89000729152134, 54.02022211892264, 50.75710834775652, 52.08429070881435, 48.740466662815635, 52.523180621010916, 53.4334328515189, 51.757450921194895, 50.235069343021934, 49.7904680115836, 45.408843653542654, 47.088845116751536, 49.46584469931466, 51.68039192472185, 53.80551930836269, 52.63840954644339, 45.7462203843253, 37.479326656886506, 29.406280721936906, 11.567321930612836, 10.92368163381304, 6.983374714851379, 10.578249335289001, 12.81398161820003, 17.556763785226003, 17.68356840951102, 6.865516764777047, 7.800272686140878, 5.230449301855905, 6.545943055834089, 5.577350275857108, 1.8446883176054274, 1.3001485488244464, 0.610120775444167, 0.747981340757438, 2.578321248292923, 10.748225722994123, 19.286137410572596, 34.81737102781023, 21.873676095690044, 25.426988329206193, 26.682126556124004, 20.436964069093975, 33.19640145983015, 35.35042987551008, 46.72336639676775, 32.958377020699636, 16.223671981266566, 2.950119572026389, 0.08406001901520149, 0.047791494455720694, 0.021846788602748086, 0.018747037077056508, 0.02310643288572984, 0.007137034038480903, 0.047680184178586514, 0.025994447558852177, 0.030087698184485947, 0.03460834953667862, 0.03436292342043348, 0.02183702278749219, 0.007820966803202671, 0.02161483819197331, 0.012578405672684312, 0.05417659719075475, 0.05586579994165471, 0.06223696217473064, 0.0642185490578413, 0.02110147725657693, 0.022091741440817714, 0.035169884762061496, 0.052488809185368676, 0.024126628945980753, 0.048857605284346003, 0.02217205284562494, 0.023147903249732087, 0.03670849684359772, 0.05383223727611559, 0.028927997020738463, 0.05036158493853041, 0.006828865061314511, 0.07554557839674608, 0.031974290164985826, 0.010841708863154054, 0.03242486795144422, 0.04358910656134997, 0.06708728655108384, 0.03238081406535847, 0.07162983422832829, 0.0012093636718678422, 0.02309882141915815, 0.04792281133787973, 0.04570325204570379, 0.02959523782400148, 0.10838968599481241, 0.03225711713145886, 0.022569938995210186, 0.023232967792344943, 0.022551496413403323, 0.006384081115746605, 0.039813177926199775, 0.058776576071977615, 0.04254021016614778, 0.04782375879585743, 0.019951772609991685, 0.009093492225344692, 2.2937510439327786, 13.118062581334796, 39.0252799987793, 48.63162660598755, 50.66606262751988, 44.19906152997698, 32.293868677956716, 28.31169625691005, 26.68702851022993, 25.013690369469778, 35.587366921561106, 31.124928065708705, 19.538704429353984, 8.145704984664917, 1.0377825072833469, 0.4698933171374457, 0.6132819886718477, 2.4329056569508145, 3.963720176901136, 7.960867268698556, 8.46041408606938, 7.993584598813738, 10.832295451845441, 7.453914540154593, 10.781216638428823, 7.5714355025972635, 5.7749422788619995, 7.942085419382368, 24.35791938645499, 33.45944288798741, 41.0136216708592, 47.39771686281477, 57.96173715591431, 64.23640864236015, 64.91144003186906, 57.206784112112864, 54.168510573250906, 54.24485043116978, 55.81269754682268, 55.33555780138288, 56.508087158203125, 55.35582569667271, 49.427282197134836, 44.128141266959055, 52.7015061378479, 56.580942494528635, 56.921060289655415, 52.03537539073399, 50.567241873059956, 54.623124258858816, 56.191978863307405, 56.010613509586875, 55.54538992473057, 52.26514884403774, 51.318547112601145, 56.13442693437849, 53.323255266462056, 47.66750151770455, 44.475606782095774, 42.21952322551182, 30.978988102504186, 45.5254031590053, 58.72708470480782, 56.389894826071604, 53.96559190750122, 52.875405652182444, 52.42515543528965, 51.600379943847656, 51.853131089891704, 52.02274703979492, 53.59138625008719, 53.66190351758684, 51.35384396144322, 51.41046830586025, 50.6020245552063, 52.40177127293178, 55.36743613651821, 52.926137924194336, 53.0369929586138, 51.809750011989046, 47.69219888959612, 49.786212239946636, 52.14908266067505, 51.87877689089094, 54.70071826662336, 50.45824548176357, 47.16963529586792, 37.9027533531189, 30.85597719464983, 20.416656221662247, 18.60802275793893, 13.412813850811549, 13.343037434986659, 16.969535044261388, 18.056632825306483, 16.109113556998118, 11.115857516016279, 10.991331032344274, 9.82388515131814, 9.217428139277867, 6.18250276361193, 2.772832376616342, 1.3342995962926318, 0.5849157507930483, 0.9084990588682038, 2.733499927180154, 10.554272839001246, 19.109929357256206, 33.71086345400129, 26.87649893760681, 31.674749442509242, 34.43084274019514, 26.326269354139054, 36.37214510781424, 40.40088782991682, 53.37615190233503, 38.33617155892508, 19.5069511617933, 3.817605205944606, 0.12564104529363768, 0.019554673561028073, 0.00525835928939549, 0.040756585874727795, 0.07099612323301178, 0.02713935835553067, 0.042891236687345166, 0.04009608970955014, 0.027716211508959532, 0.03750590441216316, 0.016607655179021612, 0.016078659100458026, 0.007592210596028183, 0.01228817249648273, 0.05477340266640697, 0.019139859659065093, 0.03607632612277355, 0.02373568251329873, 0.028101814478369694, 0.04773391397403819, 0.04174484159531338, 0.028634846143956696, 0.02327695212859128, 0.04904745938256383, 0.034081416204571724, 0.009018642179268812, 0.05538640816562942, 0.028400522556954196, 0.030341741695467914, 0.08486231203590121, 0.15466312798006193, 0.14803974410252912, 0.13520454854837485, 0.1776832291590316, 0.17336895423276083, 0.06653763247387749, 0.28285722913486616, 0.1995883480246578, 0.06366310029157571, 0.20666257770998137, 0.054116048118365664, 0.10915094121758427, 0.12462719183947359, 0.1535400982413973, 0.10584298800677061, 0.19003922971231596, 0.15659619282398904, 0.06415833586028644, 0.06519259286246129, 0.13280761002429894, 0.21615977452269622, 0.16400090977549553, 0.13680378773382731, 0.11762944662145206, 0.1123841537960938, 0.1698862782546452, 0.1534490252711943, 3.4034558747495924, 16.578332356044225, 47.28820630482265, 56.01263196127755, 59.710894039699006, 48.37237889426095, 36.129958697727744, 29.856708117893763, 29.912908622196742, 31.787483964647564, 50.6897212437221, 42.005574294498985, 21.323990208762034, 8.075142553874425, 1.4653830081224442, 0.6334876758711678, 1.1203617389713014, 4.282067963055201, 8.57429940359933, 13.250162601470947, 12.718788691929408, 17.193065541131155, 10.665361506598336, 18.85582504953657, 26.622792414256505, 14.879098279135567, 10.632145643234253, 20.277898958751134, 32.91787944521223, 44.00289303915841, 45.13100256238665, 52.33213642665318, 55.73238679340908, 61.298814501081196, 60.40227454049246, 60.196489742824006, 55.1377078465053, 56.60056420734951, 55.50494793483189, 53.6450263432094, 55.699712889535085, 59.00226811000279, 51.65992947987148, 46.9293075289045, 55.08442905970982, 57.551369598933626, 57.24674667630877, 54.1303892816816, 51.23563078471592, 56.809051854269846, 58.09293304170881, 58.901748520987375, 58.11611223220825, 54.40683031082153, 53.72615698405674, 61.25413758414132, 56.301673548562185, 53.63625076838902, 47.17659739085606, 45.613895416259766, 36.77747174671718, 47.87135819026402, 59.57538332257952, 58.40420886448452, 53.2410546030317, 54.98238434110369, 54.4771842956543, 53.2816390310015, 52.59183924538748, 55.049222537449424, 54.13741738455636, 54.651104654584614, 52.26526001521519, 53.182012285505024, 50.087708473205566, 53.2345232963562, 56.39971610477993, 56.764958586011616, 55.73111874716622, 55.427353927067344, 49.713443756103516, 54.232652868543354, 54.942282812935964, 55.95120988573347, 57.64420795440674, 55.878778389522004, 51.068835803440635, 41.30657509395054, 31.482343401227677, 15.862980570111956, 18.039654902049474, 12.623184084892273, 18.639046464647564, 21.07596036366054, 25.43242355755397, 26.07362243107387, 16.671215874808176, 21.593748807907104, 13.386914440563746, 15.723597969327654, 11.191337534359523, 3.3755731880664825, 2.5363426208496094, 0.7606101259589195, 0.98638787652765, 3.2769122421741486, 13.885202765464783, 25.30460102217538, 44.8112290927342, 32.755486147744314, 37.921308517456055, 37.11779798780169, 29.43594605582101, 43.96084254128592, 47.340303897857666, 60.14637933458601, 48.055652209690635, 25.133746555873326, 5.666309799466815, 0.2572060812796865, 0.12439663921083723, 0.07718219807637589, 0.15970933863094874, 0.14996215594666346, 0.05463764816522598, 0.11297538849924292, 0.19444928664181912, 0.12807113703872475, 0.1612807171685355, 0.07806775412921395, 0.08354667334684304, 0.15094463394156524, 0.12609468666570528, 0.1702746581286192, 0.15606253860252245, 0.07950789720884391, 0.20271311035113676, 0.23060330163155282, 0.15325026879353182, 0.10638826553310667, 0.1018409002572298, 0.08288071836744036, 0.18280947980071816, 0.1029051620779293, 0.09256789820002657, 0.21409495174884796, 0.15750838816165924, 0.09070728054004056], [0.10606191733053752, 0.07305105296628815, 0.04188739162470613, 0.04347175732254982, 0.018967842550149987, 0.025063400822026387, 0.08577798147286687, 0.1078192348192845, 0.024771430596177067, 0.028196059599784867, 0.020715602873159305, 0.0487707561946341, 0.018072356137314012, 0.014581812545657158, 0.024153512503419603, 0.05620715733883636, 0.02243737700129194, 0.07589716131665877, 0.032919530158064196, 0.023714795509087186, 0.0013778193201038188, 0.03096309317541974, 0.008558106043242981, 0.032024128562105555, 0.04018143584419574, 0.04427976021543145, 0.025079617808972086, 0.05171458037304027, 1.4710430758340018, 11.61698591709137, 34.599065576280864, 46.981095927102224, 43.85362836292812, 33.64176361901419, 22.704414878572734, 20.746777296066284, 18.629824468067714, 33.10496316637312, 42.89684404645647, 25.66886728150504, 14.810959032603673, 3.6617215020315985, 0.5588141913924898, 0.09978128184697457, 0.4709154080067362, 2.324159835066114, 3.0793217590876987, 6.490818653787885, 6.609143435955048, 4.782979232924325, 11.177728618894305, 6.143899875027793, 7.5780328171593805, 11.552967820848737, 6.430762333529336, 9.439944199153356, 33.32528706959316, 38.599303313664024, 48.19490800585066, 52.14042520523071, 56.33025843756539, 55.11544929231916, 56.94960348946707, 58.75562790461949, 57.942928382328574, 51.36664949144636, 54.709931577954976, 53.3234498160226, 57.27387591770717, 53.01351152147566, 49.48457704271589, 39.066514083317344, 48.61366898672921, 56.70170566013881, 53.884002685546875, 52.881117071424214, 53.967377594539094, 49.459087576184956, 49.527850423540386, 50.280597414289204, 47.83735718045916, 44.25127376828875, 48.09044878823416, 48.08744716644287, 51.97101770128523, 44.91315916606358, 43.783128465924946, 34.910699231284006, 29.62977647781372, 47.394576277051655, 55.61314875738961, 54.0868171283177, 51.58091456549508, 51.22714008603777, 48.951160362788606, 49.24588210242135, 54.09446014676775, 53.37868104662214, 53.34145607267107, 52.67028440747942, 55.15990386690412, 53.82833024433681, 51.08403846195766, 51.05440786906651, 51.914890153067454, 52.10541670663016, 51.90222358703613, 49.462266377040315, 48.840711797986714, 47.10505526406424, 49.83464813232422, 52.171518393925254, 53.54344367980957, 50.106093406677246, 49.748386246817454, 39.53313773018973, 35.014835357666016, 24.708341360092163, 22.90150053160531, 17.285096168518066, 15.36114171573094, 16.10126904078892, 16.50558819089617, 23.309580394199916, 12.963365282331194, 9.948541045188904, 12.851005094391958, 7.518845455987113, 4.17572317804609, 2.5136949675423756, 0.8696559146046638, 0.4203405561191695, 0.19509746400373323, 1.7174284777470996, 4.811113791806357, 14.475650259426661, 20.344516549791607, 35.63336747033255, 18.582510709762573, 14.159363048417227, 18.840592861175537, 32.15543624332973, 42.689190183367046, 45.53243473597935, 40.66273069381714, 22.551927975245885, 5.162294856139591, 0.4517981724015304, 0.0575621205249003, 0.010596423542925289, 0.09268899634480476, 0.06688546988048724, 0.0643248279978122, 0.045427027224962196, 0.026236894906365445, 0.008694863079914024, 0.05787667578884533, 0.03633873936321054, 0.07517826703510114, 0.02003442496061325, 0.03668889396690896, 0.021603265777230263, 0.039605994043605666, 0.018216800975746343, 0.03145950939506292, 0.06699219665357045, 0.06509402886565242, 0.040256678592413664, 0.0703720949324114, 0.04499150273789253, 0.04467927824173655, 0.0021324129193089902, 0.03134845017588564, 0.06352721008339099, 0.014432600998718823, 0.033994556936834536, 0.009423859899730554, 0.042365100633885176, 0.019566841390249983, 0.004184328260765011, 0.027317076854939972, 0.040849993005394936, 0.07111392369759933, 0.05243823457775371, 0.03496965586340853, 0.016248225001618266, 0.08853941543826035, 0.08191168893660818, 0.017545185317950587, 0.02152597894226866, 0.03161147749051452, 0.07828158086964063, 0.028325695411435196, 0.09674570616334677, 0.03491829415517194, 0.04047135350161365, 0.01643054566479155, 0.03702708260555353, 0.02599393017590046, 0.07658174208232335, 0.07229546351092202, 0.044230769987085035, 0.026612689652081047, 0.08890159707516432, 2.126684865781239, 14.307796546391078, 40.966280119759695, 52.020544460841585, 49.154607091631206, 37.97368403843471, 25.932778971535818, 22.524086543491908, 22.19947017942156, 29.029066494532994, 37.706689085279194, 25.831239734377178, 16.728258848190308, 4.214482835360935, 0.7609714865684509, 0.20006393321922847, 0.8966937437653542, 1.9674364967005593, 6.086251105581011, 6.632008654730661, 9.123278311320714, 8.083520344325475, 13.077553715024676, 10.609972204480853, 9.322748933519636, 6.199530627046313, 3.6285158438341956, 11.207072598593575, 27.86570528575352, 41.80771391732352, 48.50105953216553, 56.128249985831125, 56.09415864944458, 56.79738582883562, 57.83774307795933, 62.19757093702044, 58.34505884987967, 55.126528194972444, 53.27023008891514, 54.738467829568044, 58.62751007080078, 56.88263675144741, 51.788835934230256, 42.78844172613961, 50.24040903363909, 57.76770871026175, 54.52451542445591, 55.32619857788086, 53.67856182370867, 53.760606152670725, 51.58309282575335, 53.173163754599436, 47.871121951511924, 45.943552698407856, 49.567621912275044, 51.14010695048741, 54.03515379769461, 49.1814340863909, 45.43726525987898, 38.34718445369175, 33.88339417321341, 47.04066630772182, 54.21480642046247, 54.624030998774934, 52.57821382795061, 51.97020476205008, 50.286503383091514, 52.79321888514927, 54.84566811152867, 54.61984470912388, 54.441553933279856, 54.42712252480643, 54.673915590558735, 55.36987842832293, 52.17877231325422, 53.14058712550572, 51.75781570162092, 55.837447030203684, 55.160171372549875, 53.2873261315482, 50.214749336242676, 49.11721188681466, 51.08593532017299, 55.76652676718575, 54.220983369009836, 52.88632127216884, 48.646037169865195, 41.74152190344674, 34.48806462969099, 25.180146626063756, 20.352465288979666, 18.95092156955174, 8.117509194782802, 11.888448561940875, 15.42243698665074, 24.81270330292838, 19.3330968107496, 10.265141793659755, 10.861494387899127, 8.957674077578954, 9.648276380130223, 3.626678479569299, 1.3758658915758133, 0.7596739647643906, 0.44630380294152666, 1.9652860292366572, 6.168199028287615, 15.116466113499232, 26.11362668446132, 37.269157545907156, 24.31351866040911, 18.52453146662031, 22.54112352643694, 36.75599833897182, 48.17273283004761, 51.608516284397666, 47.163190841674805, 26.915080547332764, 6.4871764949389865, 0.4461809881031513, 0.021879290430141345, 0.043250829713152986, 0.05221478281808751, 0.024971238803118467, 0.0471947771896209, 0.024976851984060237, 0.03278274767632995, 0.06296901325029985, 0.0434764358215034, 0.04485327836924365, 0.06023440855954375, 0.032198372962219377, 0.052268804383597205, 0.06237749356244292, 0.03411109532628741, 0.019766349345445633, 0.02684468586396958, 0.025360056332179477, 0.05977777484804392, 0.029195349996111224, 0.03786671880100455, 0.02874011067407472, 0.031794529275170395, 0.05167953064665198, 0.018345780304766128, 0.05564130663073488, 0.0022446398548449254, 0.023669264112998332, 0.1695665389831577, 0.12135247327387333, 0.07396119912820202, 0.1447977852076292, 0.16154450444238527, 0.10597399954817124, 0.23145087329404695, 0.1997448317706585, 0.11524640449455806, 0.16295417451432773, 0.23791812626378878, 0.15016701923949377, 0.08875432783471686, 0.11866514890321664, 0.13877172927771295, 0.1886979423995529, 0.11126721730189663, 0.17180874438158103, 0.1078184816454138, 0.0811532564195139, 0.09979205019772053, 0.15106003917753696, 0.15296760467546328, 0.10828591084906034, 0.15755177369075163, 0.10418852964150054, 0.07431010862014123, 0.2170397394469806, 2.7494330150740485, 18.638626098632812, 47.05168267658779, 58.52877616882324, 55.57546520233154, 44.109839711870464, 31.589988367898123, 28.262212923594884, 26.97422535078866, 44.65664209638323, 54.003626346588135, 31.428053651537212, 17.763905218669347, 4.659898843084063, 1.2362200192042758, 0.3989899903535843, 1.043533444404602, 6.5725820149694165, 10.548538838114057, 13.18554609162467, 14.604350873402186, 15.745523009981428, 21.153578690120153, 15.582858732768468, 17.770837783813477, 20.182545355388097, 9.309536065374102, 13.35977738244193, 38.79605892726353, 41.82901014600481, 52.18950380597796, 56.30417142595564, 60.71377617972237, 59.03745378766741, 57.81846530096871, 59.13562488555908, 59.439351490565706, 56.57296943664551, 56.951576777866904, 54.66042913709368, 59.131949288504465, 59.88710035596575, 55.77117511204311, 44.89518070220947, 52.48884957177298, 61.48931326184954, 57.48117194856916, 56.39620726449149, 56.87900979178292, 55.60191699436733, 54.343202182224815, 55.762406485421316, 51.15115806034633, 47.18517146791731, 52.33861909593855, 52.917570795331685, 57.24896662575858, 51.3802227973938, 48.20620925085885, 43.47278370176043, 40.559765338897705, 49.50267710004534, 55.284151554107666, 55.075986998421804, 52.99073880059378, 52.86901330947876, 52.54098537990025, 52.28983579363142, 58.34792150769915, 56.14748954772949, 56.26151990890503, 56.06025838851929, 57.39881495067051, 57.766426767621724, 53.251806940351216, 53.430983611515586, 52.48716115951538, 55.89464112690517, 57.52516099384853, 54.26503842217581, 53.09206438064575, 52.11788872310093, 54.14859356198992, 59.392402512686594, 56.36767101287842, 55.178229740687776, 55.34565353393555, 44.27489416939871, 38.377423013959614, 28.068134103502544, 26.002123730523245, 20.8509863785335, 22.592734745570592, 22.174682480948313, 27.22194947515215, 37.27792617252895, 20.38512703350612, 16.708453008106776, 22.971010310309275, 18.31772702080863, 14.458827802113124, 9.365108626229421, 1.5672094013009752, 0.655263330255236, 0.735727703997067, 2.4688955886023383, 7.072659935270037, 18.50147213254656, 29.458798680986675, 46.57773910249983, 28.470314945493424, 22.073318685804093, 26.87539938517979, 42.409261158534456, 55.104877608163015, 57.27776690891811, 54.36538430622646, 32.959808349609375, 8.797319207872663, 0.9301326551607677, 0.12012082364942346, 0.13506316899188928, 0.1760266266231026, 0.11981945910624095, 0.09326999195452247, 0.08250874547021729, 0.12140056783599512, 0.13430133701435157, 0.14747554223452294, 0.11277497639613492, 0.15608883861984524, 0.11486148514917918, 0.13326199778488704, 0.1482894585600921, 0.08657292595931462, 0.07636070929999862, 0.14566706999072007, 0.1897942649998835, 0.15560436461653027, 0.16037393654031412, 0.1468250307121447, 0.13927642362458365, 0.09757465882492916, 0.16245243858013833, 0.17331453572426522, 0.18105390614696912, 0.10374927999717848, 0.1639736190970455], [0.047030195128172636, 0.04172888923702495, 0.02179231750778854, 0.027768938768921152, 0.047181481295930486, 0.029164748066770177, 0.03371647293014186, 0.07367948495915957, 0.04937857090096388, 0.0399668355738478, 0.024612426092582088, 0.007123524406259614, 0.0882492195814848, 0.04893555199461324, 0.07055639861417667, 0.0659593917163355, 0.0662417844203966, 0.03702031082606741, 0.049555064644664526, 0.08088043784456593, 0.042648684166904004, 0.01690776612875717, 0.024351135827600956, 0.01350590367136257, 0.06731129131679024, 0.027466381700443368, 0.03564693898494754, 0.2738378702529839, 1.6246989050081797, 17.139847551073345, 43.64213909421648, 47.67534255981445, 39.45651299612862, 34.90080499649048, 24.12487506866455, 21.655026708330425, 25.782235826764786, 41.35090807506016, 44.18078081948416, 29.485611779349192, 10.51312734399523, 2.3351914031164984, 0.20055327910397733, 0.28597865306905335, 1.029018223285675, 1.2492097850356783, 3.5560150827680315, 5.450889153139932, 8.308333652360098, 4.641343678746905, 11.64663735457829, 5.354528060981205, 6.389419683388301, 2.695765129157475, 6.670380515711648, 11.929121579442706, 22.51913595199585, 40.93225826535906, 50.303766182490754, 55.71949093682425, 57.06820576531546, 56.68887233734131, 56.381584780556814, 53.5285849571228, 57.11415420259748, 55.406227929251536, 50.48399550574166, 51.497671672276084, 54.25230932235718, 55.386741706303184, 50.50034809112549, 45.51306663240705, 38.38369723728725, 48.08856930051531, 50.65168333053589, 51.75280952453613, 48.75473131452288, 47.55852944510323, 44.26209558759417, 44.65731259754726, 42.36953135899135, 41.760539122990195, 44.97545324053083, 47.82876920700073, 49.06095927102225, 54.765798568725586, 39.59281928198678, 44.452146189553396, 31.172141075134277, 53.559285572596956, 56.476306097848074, 53.39956038338797, 53.97388110842024, 48.51828064237322, 49.82140139171055, 48.64364351545061, 52.53598615101406, 52.14621305465698, 50.025331020355225, 50.41501726422991, 49.81868117196219, 47.66741813932146, 50.8954678262983, 54.16049582617623, 52.42420700618199, 47.03346102578299, 54.44968332563128, 51.82025221415928, 50.56654705320086, 49.67006615230015, 49.214222635541645, 48.01268802370344, 51.750940459115164, 51.92794929231916, 50.20730781555176, 47.70365646907261, 40.683394636426655, 34.159126486097065, 26.19996326310294, 27.274081809180124, 10.72299073423658, 16.43122683252607, 16.668514762605938, 16.78093487875802, 13.929406336375646, 5.775935002735682, 7.02624249458313, 6.411047254289899, 6.117189262594495, 1.4713114500045776, 2.090681254863739, 0.3846604435571602, 0.36060526434864315, 0.9025880960481507, 4.538262375763484, 11.348387667110988, 24.77325143132891, 27.386701686041697, 26.919628143310547, 23.55211421421596, 20.8266589982169, 26.927552563803538, 35.81059169769287, 41.306106090545654, 39.69772318431309, 23.874963998794556, 6.897891027586801, 0.6063163110188076, 0.03318383990387831, 0.043844819268477817, 0.06511515844613314, 0.009043311168040549, 0.005865271968234862, 0.0291004772298038, 0.04367449001542159, 0.0534873345334615, 0.062832790559956, 0.02394107336710606, 0.0920233806329114, 0.11149597181273357, 0.03081401903182268, 0.0025677751941007693, 0.07502911825265203, 0.005024274461902678, 0.11200376027928931, 0.018473792721384337, 0.060879532513873916, 0.05895101385457175, 0.040071794763207436, 0.02136473188043705, 0.014787495169522507, 0.06013996327029807, 0.08608691168150731, 0.03297568232353244, 0.03469709852444274, 0.023454036197758148, 0.020392170674832802, 0.04944400203281215, 0.0014703112766645582, 0.05553024401888251, 0.03418128638129149, 0.03244559380358883, 0.010664112500048109, 0.100277379155159, 0.03060734405049256, 0.06632455212197133, 0.07504271609442574, 0.02708453611869897, 0.0499277839304081, 0.03634939236300332, 0.07834210619330406, 0.07651724054345063, 0.01553160381237311, 0.03795427017446075, 0.01367099887491869, 0.030943860100316148, 0.037124527019581625, 0.033239649409162145, 0.014112374878355434, 0.030646990851632187, 0.030311862405921732, 0.04746942102376904, 0.028238949798313633, 0.22339298496288912, 1.8565499782562256, 20.68214167867388, 49.54809400013515, 53.49139819826399, 44.26304749080113, 37.98271322250366, 26.584129163197108, 24.816670724323817, 22.768008266176494, 39.40813963753836, 45.098234857831685, 30.05080951963152, 12.61170392377036, 2.3145585102694373, 0.27845744522554533, 0.20133070381624357, 1.5784380159207752, 2.3110857137611935, 6.236281820705958, 9.714925238064357, 12.340221302849905, 8.648323774337769, 9.67464131968362, 10.973422919000898, 7.579515389033726, 8.195956093924385, 8.234445640019008, 15.072864430291311, 29.48702573776245, 41.92527396338326, 51.28670699255807, 55.89524562018258, 58.22161020551409, 57.40595422472273, 57.404734815870015, 55.19061490467617, 58.52057729448591, 55.92433425358364, 51.42854751859392, 51.958392824445454, 54.708010401044575, 56.710581983838765, 52.34902054922921, 46.104386125292095, 40.41785880497524, 51.12172201701573, 54.68613052368164, 53.74603230612618, 53.0198587008885, 49.91590731484549, 47.09977463313511, 46.21154819216047, 43.84932047980172, 43.833746092660085, 47.93752588544573, 48.178989682878765, 51.118032523563926, 55.00008487701416, 43.607026372637065, 47.22095816476004, 34.53481558391026, 52.13480063847133, 56.686492579323904, 54.35604592732021, 54.587236813136506, 50.62024968011038, 51.05529029028756, 50.84084456307547, 54.55107143947056, 54.333717891148154, 51.683497769492014, 51.89844376700265, 51.2840701511928, 49.70325769696917, 52.25438608442034, 54.29676737104143, 51.19079405920846, 48.79572568620954, 55.27684899738857, 53.03972707475935, 52.67202493122646, 51.163036005837576, 51.47761222294399, 50.56894418171474, 54.865192549569265, 52.744498116629465, 51.382988180433, 46.12461233139038, 40.27415268761771, 32.510655948093955, 25.657256841659546, 21.338039466312953, 13.359143359320504, 13.357895289148603, 13.286847352981567, 17.62886003085545, 18.966482060296194, 11.038106305258614, 7.867709296090262, 11.529559339795794, 7.928647603307452, 5.040524201733725, 2.7768349732671465, 0.9878233309303011, 0.3374955558351108, 1.1991556137800217, 4.7214186276708325, 12.018447620528084, 22.75689114843096, 29.96124029159546, 26.083971772875103, 23.467634541647776, 23.183762414114817, 32.040068353925435, 41.904877526419504, 46.139828886304585, 46.07501261574881, 28.048500231334142, 9.541450432368688, 1.0224419704505374, 0.02471271526467587, 0.022224649487595474, 0.04391376521172268, 0.07152508199214935, 0.03724453950832997, 0.027587608766875098, 0.05370266762162958, 0.023411464910688143, 0.004002218367531896, 0.033733850211969445, 0.02979581956086414, 0.04173475517226117, 0.010772316783134426, 0.018184163441349353, 0.026020599994808435, 0.02446238842925855, 0.09628898424229451, 0.01979768239626927, 0.04247456868844373, 0.024313850328326225, 0.02489752445503005, 0.055421179692660055, 0.07542914178754602, 0.05659572041726538, 0.009350347415810185, 0.011412443327052253, 0.05005632221166577, 0.018489536430154527, 0.1175012035029275, 0.11760970125240938, 0.09725619519927672, 0.14380564487406186, 0.1514884526176112, 0.12384762295654841, 0.12172471758510385, 0.15227042351450237, 0.1145671366580895, 0.16694178911192076, 0.11944835473384176, 0.08488669858447143, 0.16667194930570467, 0.06503830078457083, 0.17608301288315228, 0.18049746671957628, 0.15061093041939394, 0.12019662958170686, 0.1430504625397069, 0.11353996356150933, 0.1284191712204899, 0.2656092760818345, 0.11514831547226224, 0.1153440321130412, 0.1588319657104356, 0.1353380706693445, 0.10803542964692626, 0.3861804705645357, 3.6295680616583144, 26.790674788611277, 58.16831404822213, 61.11030292510986, 51.761598995753694, 44.370407581329346, 33.48078427995954, 28.553483145577566, 35.01761811120169, 53.01872614451817, 49.83209119524275, 32.876662731170654, 13.050447055271693, 3.199769215924399, 0.4696584354553904, 0.7910331934690475, 2.819336018392018, 4.844382635184696, 10.782332692827497, 16.085819721221924, 20.484434161867412, 15.219950846263341, 22.24120453425816, 13.899228572845459, 15.58977392741612, 9.743909648486547, 14.627757617405482, 15.03846389906747, 24.2212952205113, 43.297393798828125, 52.543340819222585, 59.41136414664132, 59.318647384643555, 58.464748518807546, 59.89921801430838, 55.59611177444458, 57.05686630521502, 55.451290471213206, 50.90020997183663, 52.067691462380544, 53.9675269808088, 59.27658993857247, 55.142616748809814, 49.49039963313511, 42.15852846418108, 51.910644803728374, 55.16073070253645, 57.03319031851632, 53.07895312990461, 51.489820207868306, 48.84157337461199, 50.62055540084839, 45.31606435775757, 45.4237961769104, 49.3397661617824, 50.62292126246861, 53.48563814163208, 57.70492131369454, 46.522983823503765, 50.78455720629011, 40.62331008911133, 52.15553753716605, 55.65408754348755, 53.09233883449009, 56.23635005950928, 51.6262446131025, 53.37260137285505, 52.366578647068565, 56.26097794941494, 55.26219524656023, 54.24111924852644, 54.001927512032644, 54.22630916322981, 51.870084694453645, 55.8398893220084, 57.057060854775564, 52.44822692871094, 47.90679400307791, 58.17527266911098, 55.45296846117292, 55.54879106794085, 53.71823951176235, 54.63376889910017, 52.70331266948155, 56.441433089120046, 56.663469723292756, 54.07763160978045, 51.91479982648577, 44.15710135868618, 38.198486055646626, 30.976907117026194, 31.705418791089738, 16.244553055082047, 24.081452301570348, 24.702129670551844, 20.04112866946629, 24.24933988707406, 15.967849731445312, 15.368265356336321, 17.463001319340297, 14.996154580797468, 7.034034465040479, 5.402025078024183, 2.230103373527527, 0.6569692215749195, 1.5812437853642871, 5.840514166014535, 14.873405967439924, 31.260046209607804, 36.94127900259835, 38.520757402692524, 34.02015209197998, 29.816141060420446, 37.794559478759766, 45.591966901506694, 52.97142628261021, 53.353122098105295, 34.74641949789864, 12.558830738067627, 1.8467308708599635, 0.08804090254540954, 0.137676085212401, 0.10313707856195313, 0.1332254790301834, 0.10149923751928977, 0.07815890852361917, 0.16606920664863928, 0.15825751796364784, 0.08221599832177162, 0.09064792908195939, 0.17457948784743035, 0.18455634106482777, 0.1374702855412449, 0.11250605261219399, 0.4694915701236044, 0.06488881273461239, 0.3034029709441321, 0.14927330719573156, 0.17118954046496324, 0.16069458504872663, 0.1004260801044958, 0.14446252105491503, 0.14909063199801104, 0.11918779728668076, 0.21538773737847805, 0.10416461806744337, 0.13896600742425236, 0.12848737756056444], [0.011985386422436153, 0.03863164150555219, 0.04576715647376009, 0.043678167675222666, 0.022194858407601714, 0.05053243666355099, 0.06385854551834719, 0.017074782434584837, 0.04082946053573063, 0.03168504764991147, 0.05173317901790142, 0.026788213090705018, 0.033825177632804425, 0.03252129456294434, 0.023870617683444704, 0.033175039304686446, 0.027121445031038353, 0.06882965591337, 0.06641289059604917, 0.02959663899881499, 0.05876061014298882, 0.024791084362992218, 0.009110453904473355, 0.006226469305277402, 0.05127927640985165, 0.09149808596287455, 0.13783434672015055, 0.17817929254046508, 6.466537739549365, 23.272579499653407, 42.522447313581196, 41.80338518960135, 38.948933192661826, 34.14944069726126, 20.03653938429696, 21.83383686201913, 50.546042919158936, 51.347444670540945, 39.729361806597026, 20.78313548224313, 8.493682929447719, 1.1597485797745841, 0.2864519990980625, 0.07921392869736467, 0.9747489924941743, 1.105289793440274, 5.726779103279114, 7.396818586758204, 8.693106651306152, 5.893307447433472, 8.76496318408421, 14.602183035441808, 6.661634036472865, 7.059060139315469, 5.022380283900669, 14.748288018362862, 28.18609193393162, 43.820197105407715, 49.269137723105295, 55.8900032043457, 54.744290419987266, 55.609132698604036, 53.878753321511404, 55.654136180877686, 53.64039536884853, 54.18610341208321, 51.23808002471924, 52.67056233542306, 51.190974712371826, 53.87715523583548, 51.291275433131624, 52.156631878444124, 48.4217597416469, 40.35983787264143, 38.068064893995015, 46.27019446236746, 44.47833047594343, 42.944334983825684, 37.910597869328086, 39.696330070495605, 37.85961198806763, 38.99492679323469, 41.74296712875366, 45.649994782039094, 47.08722966057913, 51.92628867285592, 45.957570689065115, 43.26034252984183, 34.3511642728533, 35.47271122251238, 48.06833267211914, 54.587632860456196, 50.14376653943743, 48.60433060782296, 51.35038375854492, 47.34408024379185, 52.9601389339992, 53.30933107648577, 52.037602288382395, 50.152003628867014, 48.11819641930716, 43.27202592577253, 50.628090722220286, 51.77941070284162, 52.17534337724958, 50.73864698410034, 50.42610658918108, 52.64257846559797, 51.98227725710188, 48.74793250220162, 49.31969976425171, 49.17827960423061, 51.37993097305298, 50.782323360443115, 52.28582320894514, 44.77594266619001, 38.917676721300396, 32.492083413260325, 28.757711546761648, 24.149568966456822, 12.198853254318237, 8.79914571557726, 12.745546204703194, 28.059754576001847, 26.21129924910409, 8.658521992819649, 6.211844571999141, 6.654079607554844, 6.997968103204455, 1.3399025584970201, 2.4181298783847263, 1.5049559303692408, 0.22318919375538826, 0.5202859416604042, 2.961180669920785, 8.429621406963893, 19.121880258832658, 33.72756344931466, 25.21508911677769, 22.834971530096873, 22.74561595916748, 23.126358134405955, 34.75739765167236, 44.06659064974104, 44.62753956658499, 32.01981088093349, 10.053008948053632, 1.768962289605822, 0.027488403554473604, 0.0289993178365486, 0.02922807234738554, 0.021487395744770765, 0.04638461655537997, 0.024737851594441702, 0.11992461846343108, 0.06029824513409819, 0.039449747784861496, 0.01140989373171968, 0.01621222702254142, 0.028006744936906865, 0.06394842426691737, 0.06096008140593767, 0.058180028439632485, 0.09646675363183022, 0.06194226763078144, 0.05135067864986403, 0.007114353581398193, 0.012566116555327815, 0.008871572258483087, 0.018383467836039405, 0.02793772435480995, 0.034847475455275605, 0.06062863740537848, 0.0763950567426426, 0.06455242899911744, 0.03859434582825218, 0.01192982797510922, 0.05083806240665061, 0.06722459489745752, 0.03992863744497299, 0.02512130869685539, 0.01560630542891366, 0.06652612451996122, 0.032578698625522, 0.04961525070081864, 0.0427562251820096, 0.060265234405440946, 0.022805007274395654, 0.036223174671509435, 0.04072938679850527, 0.02892889268696308, 0.05774094842906509, 0.043391880180154524, 0.04082345550081559, 0.040089022767330916, 0.01642573145883424, 0.014495899834270989, 0.06148657708295754, 0.03778975596651435, 0.021172385862363235, 0.007184345740824938, 0.009526847944861012, 0.06127254678202527, 0.2291172013751098, 7.6374286242893765, 27.097142457962036, 48.626957416534424, 49.92614548546927, 44.63881301879883, 36.52923692975725, 24.56822051320757, 21.98319707598005, 38.562321526663645, 48.82505750656128, 45.90098803383963, 24.843952826091222, 8.979822329112462, 1.5423784937177385, 0.19792987273207732, 0.2004380909992116, 1.504748352936336, 4.636482979570117, 6.997463056019374, 6.984534629753657, 10.271904127938406, 11.753574473517281, 9.823526450565883, 11.102283341544014, 14.429018293108259, 15.338780675615583, 8.786778790610176, 19.810610021863663, 31.670927933284215, 43.20220347813198, 53.07431173324585, 58.08388648714338, 55.78903545652117, 56.47994695390974, 55.334255014147075, 56.370971407209126, 54.334072249276296, 55.40188183103289, 52.456939969744, 53.92252697263445, 50.82753528867449, 55.16682774680001, 53.437011173793245, 53.63122027260916, 49.013416222163606, 42.65807267597744, 40.899212632860454, 48.759925092969624, 47.67629793712071, 43.8596385547093, 40.56321164539882, 40.650533131190706, 39.519724232809885, 41.6940552847726, 43.43748337881905, 46.17353112357003, 49.308624335697715, 55.169457639966694, 45.98658636638096, 46.14970922470093, 38.0409426007952, 39.00326463154384, 50.184590680258616, 53.55096163068499, 50.86507640566145, 48.64352887017386, 52.72351803098406, 47.63020706176758, 56.19504649298531, 54.741657052721294, 54.79928541183472, 52.748201506478445, 50.38319798878261, 45.80766677856445, 51.8808057648795, 54.38499559674944, 52.52104752404349, 50.82610048566546, 51.38602801731655, 53.71137816565377, 54.09056568145752, 51.88969598497663, 51.036526679992676, 52.21296787261963, 53.67852708271572, 53.455885955265586, 53.684193338666645, 46.77378599984305, 41.57710668018886, 34.89675767081124, 29.546127114977153, 23.826911994389125, 11.42844567980085, 13.23445098740714, 12.006485428128924, 14.216883710452489, 19.37629897253854, 13.939680985042028, 9.193831188338143, 10.345555901527405, 8.852137889180865, 6.366793743201664, 2.974152956690107, 1.689585960337094, 0.22386654812310422, 0.4329847576362746, 3.5857981017657687, 9.365263223648071, 22.67758788381304, 35.60240282331194, 29.755090713500977, 24.942285469600133, 24.116163764681133, 27.528500522886002, 39.26983574458531, 50.21975551332746, 49.89851597377232, 36.100751944950645, 11.985694680895124, 1.7124454251357486, 0.022859661573810235, 0.04855702784178512, 0.024580841983801553, 0.005320397746150515, 0.03175249742344022, 0.007930291517238532, 0.044987153328422985, 0.04912624747625419, 0.041264062215174944, 0.050897651351988316, 0.03246909825663481, 0.05730790738016367, 0.025852840693135346, 0.012439205909946134, 0.03384552011266351, 0.038512344871248515, 0.04410404000165207, 0.06128159843917404, 0.07248592150530644, 0.02019393158012203, 0.01444253814406693, 0.021763858052768877, 0.03851461796356099, 0.02220185749631907, 0.03130082041025162, 0.062025184610060284, 0.010486617917194963, 0.037059156955885034, 0.16039672174624034, 0.15335613382714136, 0.26215121735419544, 0.0950629800291998, 0.1630434561520815, 0.14251826038318022, 0.14743894205561706, 0.17081060579844884, 0.16668906195887498, 0.21249122066157206, 0.19550709559449128, 0.07828880048223905, 0.22968727935637745, 0.16703392059675284, 0.14739818924239703, 0.08387931835438524, 0.11247414789561715, 0.11664566583931446, 0.17676656906093868, 0.11318630432443959, 0.05208037520891853, 0.1094781986570784, 0.1898583322763443, 0.09605721025062458, 0.08775053705487933, 0.10021420075957264, 0.21312613944922174, 0.6054407294307436, 10.326706307274954, 32.23456232888358, 55.517479010990684, 55.76204170499529, 51.10948971339634, 43.07272727148873, 28.513395513807023, 32.9278952734811, 61.70533970424107, 56.59911898204258, 46.11822346278599, 24.353156396320887, 10.351664236613683, 2.030254291636603, 0.742818612073149, 0.3993855762694563, 2.454716920852661, 5.078533453600747, 12.555614590644836, 14.771090269088745, 17.88216703278678, 13.924773624965123, 19.731437035969325, 24.233610902513774, 12.662677645683289, 13.923720104353768, 9.323638302939278, 18.33386073793684, 31.517185143062047, 47.00781869888306, 52.98278658730643, 58.35807977403913, 57.1249760219029, 58.59829289572579, 55.078036717006135, 57.804631437574116, 53.949190684727256, 54.68936143602644, 52.59822811399187, 54.352550983428955, 51.54599986757551, 54.91320807593209, 55.72893006461007, 57.93928752626692, 52.91641044616699, 44.64999961853027, 42.30467687334333, 50.91182735988072, 48.93932410648891, 46.50901794433594, 42.67100327355521, 43.79270655768258, 40.14595147541591, 43.59667008263724, 45.28580147879464, 47.320571013859336, 52.232155323028564, 57.652917521340505, 49.68958364214216, 48.13270425796509, 42.89626734597342, 43.76184613364083, 54.78132779257638, 54.529087339128765, 49.23598786762783, 48.41463783809117, 54.05931963239397, 48.228196825299946, 57.0611846106393, 56.3714508329119, 56.36440535954067, 54.7557167325701, 51.26121405192784, 47.55758101599557, 52.914200919015066, 56.31737995147705, 53.04230833053589, 51.00851501737322, 51.506290912628174, 55.261347566332134, 55.10363040651594, 53.54303026199341, 52.19875185830252, 54.51357201167515, 55.49844094685146, 56.71838133675711, 56.363776547568186, 48.8975202696664, 43.3706590788705, 38.19198254176548, 32.439141614096506, 28.24699636868068, 18.26966633115496, 16.71769063813346, 20.828218868800572, 38.97575671332223, 40.86922768184117, 18.71338697842189, 15.281329495566231, 18.002786023276194, 17.289556912013463, 8.332411766052246, 4.568525688988822, 2.25296642099108, 0.4879918002656528, 1.065411041889872, 4.495565695422036, 10.848205958093915, 25.197110652923584, 42.96449170793806, 35.36107104165213, 33.930621079036165, 30.79613583428519, 32.42702742985317, 44.732975006103516, 54.98808881214687, 57.28698369434902, 43.46979597636631, 16.485603434698923, 3.1609363853931427, 0.1690870047147785, 0.12632321725998605, 0.20752414076456002, 0.15112038808209555, 0.29017001816204613, 0.08547160934124674, 0.1916917067553316, 0.1751159512038742, 0.13837091864219733, 0.14660903944500855, 0.1249805185943842, 0.14183216648442404, 0.14864163180547102, 0.17067305317946843, 0.1743445654532739, 0.17409474243010792, 0.137041519262961, 0.10353970088596855, 0.13040486324046338, 0.09224284599934306, 0.08234915403383118, 0.1353444488985198, 0.14087932689913682, 0.0911668183814202, 0.16703563050499984, 0.1415904044572796, 0.16770353966525622, 0.1705295973058258], [0.047061546838709285, 0.05771808858428683, 0.010919334965624979, 0.08741709137601511, 0.024217072574953948, 0.05583374255469867, 0.02350887030895267, 0.049962867583547316, 0.016932780322219645, 0.1224616744688579, 0.046216058278722424, 0.020526400168559382, 0.040684579738548825, 0.024983801878988743, 0.10625830572098494, 0.0920691206785185, 0.05840623165879931, 0.042844933457672596, 0.08139552056257214, 0.011470084876886435, 0.04752838910956468, 0.0590372895821929, 0.016127712093293667, 0.03974562297974314, 0.01942969249960567, 0.030541088498596634, 0.02475395323043423, 0.22775741719773837, 7.834433504513331, 29.74416814531599, 38.25004516329084, 38.65101180757795, 33.137821197509766, 27.542379549571447, 22.24187329837254, 33.38644163949149, 44.35562528882708, 39.60078886577061, 24.448711497443064, 14.053325721195765, 4.934980196612222, 0.5145939556615693, 0.15543433731155737, 0.20797690004110336, 1.6710094085761478, 4.713948445660727, 5.021268137863704, 6.373045384883881, 8.574508718081884, 9.539782864706856, 4.802204029900687, 6.7444643804005215, 12.244119899613516, 18.452761786324636, 10.481931669371468, 18.94498954500471, 34.67328970772879, 38.878933565957205, 50.89680535452706, 53.41152170726231, 56.830994265420095, 52.81390714645386, 54.634203161512104, 52.37672996520996, 55.440836906433105, 52.48938805716378, 52.359557492392405, 52.377032211848665, 53.192344256809776, 51.33740452357701, 52.78561755589077, 52.07492801121303, 52.058592796325684, 48.79457228524344, 41.48926407950265, 37.68073756354195, 36.6932943207877, 37.163416385650635, 37.77740785053798, 37.08600650514875, 37.95202997752598, 40.93120561327253, 43.08818006515503, 40.63844673974173, 47.81409808567592, 50.007752077920095, 55.12226894923619, 34.9934036391122, 32.4608199937003, 46.013979639325825, 48.13426065444946, 55.86130714416504, 48.862991196768625, 51.44517455782209, 50.656626973833355, 50.61768579483032, 52.312247208186555, 50.680851868220735, 49.85673645564488, 50.71786144801548, 47.79437214987618, 38.804004192352295, 46.49523966653006, 51.44205134255545, 51.929536955697195, 51.087460449763704, 51.06799507141113, 50.02995504651751, 52.448456219264436, 52.602647168295725, 51.30331318719046, 49.361715521131245, 51.096705027988975, 51.996173654283794, 50.990435804639546, 49.79021092823574, 46.633863176618306, 40.81603227342878, 33.101426533290315, 25.850152730941772, 17.669428825378418, 19.89433581488473, 7.292137895311628, 7.752877286502293, 13.349403721945626, 10.70359570639474, 4.621480081762586, 8.923104184014456, 5.1498949272292, 5.832046048981803, 2.161578501973833, 0.8906820320657322, 0.10670877154916525, 0.2542605607637337, 1.9534495558057512, 6.125494965485164, 13.46503824847085, 20.883715867996216, 30.051129136766704, 33.4365485736302, 23.283680983952113, 25.49164652824402, 31.97907359259469, 33.94995444161551, 46.20896693638393, 34.27435193743025, 17.690504448754446, 2.8306752613612582, 0.05841998556362731, 0.057264046876558235, 0.04117553375129189, 0.05488079101113336, 0.03475427867046424, 0.03330119592802865, 0.01568913589497762, 0.009681000923072653, 0.02069436472707561, 0.07873438085828509, 0.03196365073589342, 0.04793415305071643, 0.049851163756102324, 0.012887611536176076, 0.07806406968406268, 0.07434530423155852, 0.053349822626582215, 0.019920929800719023, 0.018151213780843785, 0.012194915491688465, 0.042125191007341654, 0.015975978092423508, 0.0387778284826449, 0.013212177736152495, 0.02280338218302599, 0.011242144608071871, 0.018398224276357462, 0.03972587421802538, 0.029536534366863113, 0.029398669621774128, 0.01416658388916403, 0.0199445869241442, 0.05526556447148323, 0.06307894949402128, 0.049221018462308815, 0.07345348530049835, 0.029872952029109, 0.07665649628532784, 0.05198363307863474, 0.0064868740820592, 0.035378283222338984, 0.041380485253674645, 0.027050100466502563, 0.027088987308421304, 0.06588257476687431, 0.00831836011327271, 0.04077603608103735, 0.01466008834540844, 0.07980569944317852, 0.026116205578935996, 0.01588049973361194, 0.012710226367094686, 0.027676719074536647, 0.04377410913418446, 0.03126077327345099, 0.34213440120220184, 9.614192860467092, 33.10432045800345, 45.12439482552664, 45.73294932501656, 36.30333709716797, 33.847235747746055, 20.952572516032628, 31.655801704951696, 50.5649767603193, 48.31426763534546, 32.78484576089041, 17.10082299368722, 6.107094832829066, 0.7395388994898114, 0.10900017752179078, 0.42039139196276665, 2.5472410874707356, 4.2771885905947, 8.02118718624115, 10.640283720833914, 10.82552182674408, 8.851351874215261, 10.172029852867126, 11.548411539622716, 15.275129965373448, 16.485198702130997, 13.861023034368243, 21.410255568368093, 38.69633838108608, 41.78442702974592, 51.94174494062151, 54.70318487712315, 57.81497383117676, 54.83123670305525, 55.54005370821272, 53.73812525612967, 55.67807272502354, 53.5707049369812, 53.07578822544643, 52.52954169682094, 53.17402533122471, 51.27318579810006, 53.34397826875959, 53.177245821271626, 54.47977944782802, 50.09273896898542, 42.79412882668631, 39.34610612051827, 39.78426994596209, 38.9704760823931, 39.02672869818551, 38.56387792314802, 40.311839716775076, 42.53049332754952, 43.97177900586809, 43.99449961526053, 48.55471004758562, 50.43077577863421, 54.487422466278076, 39.60142462594168, 36.63769136156355, 47.38052007130214, 51.36962679454258, 52.851601123809814, 49.84592505863735, 50.97574036461966, 50.93587507520403, 49.46298551559448, 52.970616817474365, 52.05791882106236, 53.54953377587454, 53.06501851763044, 49.92012139729091, 41.19524758202689, 48.982159750802175, 52.15910196304321, 52.96923760005406, 50.491718428475515, 51.67089026314871, 51.2081298146929, 54.39569929667881, 53.30659696034023, 55.11213500159127, 51.85188388824463, 51.89442770821707, 52.57064029148647, 54.78765760149275, 50.6725800377982, 48.30081592287336, 39.87698323386056, 33.57941048485892, 24.05431263787406, 16.436371973582677, 15.945342779159546, 13.928490911211286, 11.049178259713308, 9.341520360537938, 11.869369677134923, 10.158064842224121, 10.865490470613752, 10.386950663157872, 8.114587477275304, 6.228412985801697, 2.4138441426413397, 0.18076988495886326, 0.4142457645918642, 2.368983098438808, 7.2894393886838635, 15.148658854620797, 25.85405935559954, 32.21996068954468, 35.1321313721793, 24.372437647410802, 28.207120656967163, 35.69423368998936, 38.11025435583932, 50.95496525083269, 40.33251755578177, 20.804544619151525, 3.743046692439488, 0.03131356669057693, 0.023175545070054274, 0.04785776697099209, 0.05452077729361398, 0.04584764429767217, 0.05922634979443891, 0.0213252733727651, 0.035171004344842265, 0.1053113422489592, 0.04307062438290034, 0.014078194524959793, 0.040576543392879624, 0.08928072173148394, 0.0512797038869134, 0.045139827100293975, 0.029878536372312477, 0.04287097902436342, 0.011292243393005004, 0.04359430753226791, 0.019473592018974677, 0.04935753292271069, 0.007116397244057485, 0.03980983614123293, 0.03242711729503103, 0.06071184615471533, 0.04238017089664936, 0.06729677066739116, 0.05726558715105057, 0.11669762805104256, 0.15553450265101024, 0.1381989914391722, 0.10935303608753852, 0.11893861208643232, 0.13417447810726507, 0.1680494025349617, 0.1921476958585637, 0.11735454494399683, 0.2326753033058984, 0.18289131112396717, 0.0849238144499915, 0.11833706365099975, 0.15316817962697574, 0.2273821873324258, 0.2250084818473884, 0.17178092444581644, 0.1295197278793369, 0.17141804391784327, 0.10124150956315653, 0.22758718633225986, 0.20913321870778287, 0.07425290811806917, 0.2063642530036824, 0.09781574231705495, 0.12811150987233433, 0.11943783744105271, 1.1624430694750376, 11.962383474622454, 38.18089321681431, 51.57672480174473, 53.93599605560303, 43.19862862995693, 37.68981191090175, 31.464490004948207, 41.96462856020246, 54.7883802141462, 47.88604320798601, 31.680975028446742, 19.125059059688024, 6.95823700087411, 1.050413680928094, 0.4475901424884796, 0.6029681478227887, 3.9073602982929776, 10.518990755081177, 13.736573849405561, 16.46949577331543, 19.27887828009469, 21.329807588032313, 12.778409446988787, 18.894463981900895, 24.573105096817017, 28.358398573739187, 18.1897029876709, 23.607453141893657, 39.39035224914551, 43.23522131783621, 52.794368812016074, 56.55350753239223, 60.01585047585623, 54.970419543130056, 55.91423504693167, 52.221677439553396, 55.40937198911394, 53.66399839946202, 52.88815907069615, 53.12273025512695, 52.59258617673601, 51.62252732685634, 53.658113275255474, 54.960212639399934, 57.4895202091762, 53.71572773797171, 46.119446345738, 41.79314701897757, 42.15718746185303, 41.728692054748535, 41.80121735164097, 41.032319273267476, 43.2947986466544, 46.379368032727925, 45.11831167766026, 44.9734000478472, 51.05471011570522, 55.10975871767317, 56.77170181274414, 42.11836092812674, 42.644204071589876, 49.785937786102295, 51.69623381750924, 54.024891308375764, 50.91428354808262, 52.669026783534456, 52.34581395557949, 51.33511161804199, 55.00218323298863, 53.048144817352295, 55.14815098898751, 54.66141925539289, 51.88598564692906, 43.470793042864116, 50.752831731523784, 54.7358900478908, 54.70827095849173, 52.22607912336077, 52.533797468457905, 51.668406282152446, 55.696763379233225, 55.73228257043021, 57.231978280203684, 54.58218199866158, 53.774290629795615, 56.168862206595286, 54.201267855507986, 55.511847496032715, 52.02433817727225, 43.85322189331055, 34.993438380105154, 29.65997682298933, 25.557280949183873, 29.225165503365652, 13.370016421590533, 15.097160543714251, 18.95843083517892, 24.509494338716777, 15.423930849347796, 16.786114760807582, 13.535479954310826, 13.618247764451162, 8.075120840753828, 3.610310260738645, 0.5244492696864265, 0.579189403780869, 2.8132932569299425, 8.47119769028255, 17.69335147312709, 29.451482227870397, 40.57234852654593, 45.34383978162493, 32.61125544139317, 35.72639342716762, 42.372286319732666, 44.7512800352914, 58.708387102399556, 45.359348160879954, 24.79779941695077, 5.071167494569506, 0.2502109009240355, 0.13630410097539425, 0.1681195359144892, 0.10475104874266045, 0.19224817332412514, 0.11527502510164465, 0.07215183121817452, 0.1204729290413005, 0.15194265038839408, 0.15475673867123468, 0.17924852802285127, 0.17493713008505957, 0.18985947221517563, 0.10723794743950878, 0.178755165210792, 0.12839059132550443, 0.2280978789286954, 0.1092722157814673, 0.09749560270990644, 0.1055955398561699, 0.1298751173807042, 0.12832055294087955, 0.1782383115163871, 0.0980374604197485, 0.15994082763791084, 0.08058087820453302, 0.14716896654239722, 0.19525463985545294], [0.022279006927939396, 0.055698001624218056, 0.09388494145657335, 0.07146589338247265, 0.018306240372891937, 0.0246621474424111, 0.024335402296856046, 0.08953654978956495, 0.028588118829897473, 0.0609337610325643, 0.04759044452969517, 0.05234547884070447, 0.014723841799423099, 0.0353845019957849, 0.049232227860816886, 0.03508638763534171, 0.023027519263061028, 0.027218806324526668, 0.026254170407940234, 0.04242787530113544, 0.017823574665401663, 0.003922401445119509, 0.004340812006765711, 0.0101185219994347, 0.051346984026687484, 0.023519904984693443, 0.03413008752145937, 0.5415867300970214, 10.904476812907628, 27.967972346714564, 37.464832714625764, 46.08374302727835, 36.82041161400931, 27.003961903708323, 31.176007747650146, 43.273700441632954, 39.88501535143171, 20.3599728175572, 21.20597505569458, 12.276172808238439, 3.9964149253708974, 0.9834450972931725, 0.5778343964900289, 0.3169145573462759, 1.869739613362721, 4.906530363219125, 5.870104806763785, 4.827811181545258, 8.802958539554051, 9.14572707244328, 8.018158640180316, 9.869421907833644, 24.378836938313075, 17.402743067060197, 14.710488080978394, 29.43436881474086, 35.70030294145857, 43.07739298684256, 51.738722051892964, 53.646006039210725, 54.68704421179635, 53.25413111277989, 52.63612706320626, 53.33572033473423, 51.756499017987935, 53.58732155391148, 53.09528834479195, 52.329913003104075, 53.53323677607945, 53.041780267442974, 51.88807705470494, 52.44222021102905, 53.66540540967669, 50.682328360421316, 50.98992511204311, 46.81650699887957, 41.589936528887065, 37.04737799508231, 36.40150472096035, 36.15757083892822, 44.21888821465628, 47.59240538733346, 49.47550964355469, 45.91314043317522, 46.71928085599627, 47.83803462982178, 54.617739404950825, 29.703507287161692, 36.70080532346453, 58.51871517726353, 50.3693710735866, 52.31585679735456, 52.357320172446116, 51.14402573449271, 49.33765390941075, 52.390143462589805, 52.8443854195731, 52.75263793127877, 50.443918296269004, 50.48330415998186, 47.92641224179949, 39.22892822538103, 44.55973209653582, 50.226933002471924, 51.46889918191092, 50.17558928898403, 49.26338114057268, 50.58987562997, 51.05310508183071, 53.422701358795166, 53.760991777692524, 51.23360538482666, 50.559675284794395, 50.39756338936942, 50.83323975971767, 48.869362694876536, 50.08893483025687, 42.200130803244456, 36.12540067945208, 29.374506609780447, 15.574814455849783, 13.22322530405862, 15.153939485549927, 9.093611240386963, 9.330709832055227, 11.05094483920506, 11.114476561546326, 6.242928206920624, 8.598626783915929, 6.651328989437648, 2.642733654805592, 2.045907063143594, 0.20516191609203815, 0.3462277858385018, 1.0384864466530936, 5.97059269462313, 15.508224657603673, 25.154721430369786, 22.97035370554243, 29.65911177226475, 25.70076298713684, 28.445483820778982, 31.055282797132218, 34.870472635541645, 41.46168320519583, 42.60280670438494, 19.179779597691127, 2.9273707355771745, 0.23961810075810977, 0.04949875980881708, 0.03920141414606145, 0.009525864917252744, 0.04540711222216487, 0.03893171004684908, 0.06566967083407299, 0.062142632236438136, 0.043922976324600835, 0.027976735029369593, 0.016199884470552206, 0.021919011870133023, 0.028467434591480663, 0.030064539784299474, 0.022557328421888605, 0.010773238742591014, 0.0799642459356359, 0.06932516289608819, 0.01101745112932154, 0.03264444188347884, 0.0038455480244010687, 0.007915272992769522, 0.017742625437676907, 0.015760543224002634, 0.03105612371915153, 0.08433660345950297, 0.03484470024704933, 0.067744963403259, 0.006693629639422787, 0.010895436114099408, 0.030167582112231424, 0.010612724498579544, 0.06978617994380848, 0.026227902621030807, 0.06334234321756022, 0.062146113121083806, 0.05955203981803996, 0.0423732226980584, 0.05370347847097686, 0.04178582171776465, 0.0350109888240695, 0.11870596956993852, 0.02193072677722999, 0.05391346809587308, 0.026249123803739036, 0.01749740118559982, 0.033800563775002956, 0.014041665592230856, 0.028147971823013256, 0.06514047458767891, 0.03456822776102594, 0.02474773784966341, 0.044089712734733305, 0.05965681919561965, 0.05746958191905703, 0.9450079883847917, 12.571442587035042, 32.91940457480294, 44.32226003919329, 51.30114534923008, 41.73810338973999, 28.848039865493774, 30.840010234287806, 41.77486283438546, 40.326066153390066, 26.196016686303274, 21.410361528396606, 13.544349329812185, 4.218496288572039, 0.9946625296558652, 0.209976569882461, 0.42401414471013205, 3.496834018400737, 6.388843417167664, 6.64257903609957, 11.088225398744855, 10.79596940108708, 14.138401201793126, 7.871425713811602, 8.020147562026978, 12.399429508617946, 15.075485638209752, 16.884574208940776, 22.917208671569824, 35.63429158074515, 42.658062253679546, 52.2415041242327, 55.48457581656319, 57.03646639415196, 54.570884227752686, 54.310729776109966, 53.63638278416225, 51.61914702824184, 54.20333841868809, 54.130479608263286, 52.59970808029175, 54.119956561497276, 53.487555844443186, 50.48384264537266, 51.56790753773281, 56.094617230551584, 53.413154533931184, 53.367209570748464, 48.6351979800633, 42.59710223334176, 37.537827014923096, 37.10184492383684, 37.2884909084865, 45.118968282427105, 48.14202526637486, 50.950070244925364, 46.40822042737688, 49.33186605998448, 49.13637849262783, 54.14478594916207, 34.23802328109741, 38.11529179981777, 57.30420133045742, 51.02725430897304, 53.12742723737444, 54.18172604697091, 52.227010181971956, 51.66136428288051, 53.180973529815674, 54.105028356824604, 53.988715512411936, 52.4140556880406, 53.479912825993125, 50.249872480119976, 40.24329226357596, 46.69346482413155, 52.414170333317344, 53.897061824798584, 51.06475373676845, 49.746225357055664, 49.86847196306501, 51.76933928898403, 56.067460196358816, 55.05281475612095, 54.56809452601841, 52.214559010096956, 53.77462414332798, 50.99164131709507, 51.246806962149485, 49.25788164138794, 43.444080693381174, 34.3413290977478, 26.976519993373326, 17.26334830692836, 16.580545357295446, 13.654842189380101, 14.921195677348546, 13.808458174977984, 11.71606375489916, 6.1083098990576605, 11.545539328030177, 10.169356533459254, 10.180022018296377, 4.906968533992767, 2.7377370255334035, 0.5041825143354279, 0.21641437443239347, 1.3958979823759623, 5.626980824129922, 16.130505323410034, 27.574153661727905, 27.423332589013235, 33.15998247691563, 27.327174731663295, 30.643358843667166, 36.86641911097935, 39.625069345746724, 47.643016065870015, 47.157823358263286, 24.21512869426182, 4.035357841423579, 0.3136053149189268, 0.030379386818302528, 0.03396410767787269, 0.02618777914904058, 0.029831642817173685, 0.062336476120565615, 0.00303927921257647, 0.02706154735226716, 0.03836140475635018, 0.05078088226062911, 0.022737365814724138, 0.053893875397209606, 0.02857264823147229, 0.0592273065288152, 0.05018586811742612, 0.020588004362902472, 0.06601312490446226, 0.01137835203137781, 0.04302441614813038, 0.08934392726847104, 0.01196563766071839, 0.08377004707498209, 0.030771797190287282, 0.023552269408745424, 0.03376925277656742, 0.031594917843384404, 0.03607687573613865, 0.047726229564952, 0.07721336318978242, 0.11706215063376085, 0.21524706349841186, 0.1655414013990334, 0.12280660096023764, 0.08345107454806566, 0.09443872102669307, 0.18674293373312267, 0.11645365399973732, 0.14621411849345478, 0.13602135543312344, 0.09684409374105078, 0.1393262959484543, 0.20010419748723507, 0.09709116191204105, 0.10715378874114581, 0.10021267405578069, 0.1402311495372227, 0.1341514621994325, 0.10805248801729508, 0.11308987092758928, 0.13047712721994945, 0.10034800786525011, 0.11106819619557687, 0.18716192910713808, 0.23088226094841957, 0.11496690234967641, 1.4645077522311891, 16.3646057673863, 38.611601625170024, 50.56963552747454, 58.55771541595459, 48.502497809273855, 38.189147676740376, 41.96361064910889, 53.557725702013286, 47.53125776563372, 30.191263880048478, 28.42419801439558, 16.62529523032052, 5.65958046913147, 1.6004870384931564, 1.1524659991264343, 1.2736030646732874, 5.558948406151362, 11.152055893625532, 14.891983713422503, 15.647245952061244, 16.90213578087943, 18.569173642567225, 15.199589150292532, 18.534095661980764, 35.206987789699006, 24.572615248816355, 19.366858107703074, 34.26084463936942, 40.42838532584054, 46.22746998923165, 53.45225552150181, 56.06166539873396, 56.272987910679404, 56.284164088112966, 54.6887013571603, 55.666893073490684, 52.56568622589111, 55.390431199754985, 55.645395347050254, 55.347314153398784, 55.222031184605186, 54.51640340260097, 51.183401175907676, 52.62856394904, 55.493761335100444, 56.013358048030305, 56.34298406328474, 51.544228076934814, 45.119954926627024, 40.48134102140154, 40.158413069588796, 39.13333490916661, 48.91586351394653, 51.03247240611485, 53.67097439084734, 49.109860692705425, 52.755180971963064, 52.20706537791661, 56.71780463627407, 37.94051333836147, 42.25397934232439, 56.446397577013286, 52.98366206032889, 52.840299878801616, 55.45710958753313, 52.80969653810774, 54.43263939448765, 56.1682333946228, 56.66271584374564, 56.06298903056553, 54.16306665965489, 54.632521697453086, 52.844458375658306, 43.00236286435808, 49.23213856560843, 55.11955567768642, 56.17117943082537, 50.887942927224294, 49.92057303019932, 49.9049847466605, 52.51082672391619, 55.21492665154593, 56.21722166878836, 55.7256053515843, 54.198387827192036, 54.82982274464199, 54.0920421736581, 52.78166055679321, 55.499740259987966, 47.124663080487935, 40.999020031520296, 35.116091455732075, 20.344308103833878, 21.216199329921178, 23.84320204598563, 24.762655428477697, 23.818798235484532, 30.55152450289045, 21.289971828460693, 17.564118453434535, 17.610782555171422, 16.704772199903214, 7.879430038588388, 4.66444947889873, 0.9376603769404548, 0.8080961235931942, 1.7722016700676508, 7.158721191542489, 19.685035228729248, 32.469838755471365, 33.38113668986729, 37.82372454234532, 35.71947996956961, 36.642311913626536, 42.09659569604056, 45.911691733769004, 53.16280051640102, 54.13958869661604, 30.041328702654155, 5.4034881080899915, 0.7180281994598252, 0.12977542701576436, 0.14206870379192488, 0.06398205924779177, 0.10129502562007733, 0.16860694118908473, 0.10168996692768165, 0.15388944878109864, 0.08487810833113534, 0.1861503283892359, 0.10993572124945265, 0.1034516202551978, 0.3072225802711078, 0.14280762842723302, 0.1237473219100918, 0.12226677207010132, 0.2176358053194625, 0.1899648079914706, 0.1342619548418692, 0.18923306225665978, 0.11563813633152417, 0.16903891015265668, 0.0992851641827396, 0.1624347966696535, 0.1407104938157967, 0.1538333882178579, 0.15792248451284, 0.16946085036865302], [0.028326660627499223, 0.04943532696259873, 0.06287753994443587, 0.03648026141205004, 0.02726101459536169, 0.04496925018195595, 0.0491633938758501, 0.029645283174301897, 0.030334508512169123, 0.057076208027345796, 0.022146757060129727, 0.056025791713701825, 0.039361351635307074, 0.032414628858012814, 0.0449411113347326, 0.020075735868886113, 0.018268171165670668, 0.0565261773632041, 0.0492738390208355, 0.07029709645680018, 0.008815430271040117, 0.05588480231485196, 0.05249104495825512, 0.025913888488763144, 0.05989136839551585, 0.03348604922315904, 0.060881154212568483, 1.1398329798664366, 11.625634687287466, 33.425191743033274, 36.73982293265206, 36.78012595857893, 31.6999922479902, 28.59008972985404, 31.906503132411412, 53.07256773539952, 39.34005076544625, 25.319951329912456, 20.5856294631958, 9.744303958756582, 2.413209685257503, 0.6772040586386407, 0.25070395160998615, 0.5133000165224075, 3.3697082570620944, 2.7868670863764624, 5.505497217178345, 13.920400602476937, 7.024452030658722, 5.97072080203465, 10.914083565984454, 6.089465515954154, 5.525913630213056, 14.745043209620885, 20.022450174604142, 19.120054619652883, 41.83849791118077, 41.14622804096767, 51.21571377345494, 52.01145274298531, 55.571282386779785, 51.13352353232247, 52.24162571770804, 52.70669296809605, 52.810957636152, 51.679252420152935, 51.63671554837908, 49.45414740698678, 51.70632260186331, 52.994633265904014, 52.10063982009888, 49.53327349254063, 54.01484768731253, 52.92023195539202, 52.65558896745954, 50.343787806374685, 47.62570462908064, 40.05040332249233, 36.67564589636666, 39.17391586303711, 50.38299649102347, 50.76931285858154, 52.206926413944785, 48.29006358555385, 53.48018380573818, 47.90525497709002, 55.00433717455183, 32.69144460133144, 38.13769279207502, 55.090265546526226, 47.78024993624006, 48.82431752341134, 45.144541127341135, 48.832651887621196, 46.743985176086426, 47.56959792545864, 47.38705137797764, 50.35829564503261, 48.78166600636074, 50.08185461589268, 44.31293208258492, 35.70289461953299, 42.71302945273263, 49.44760915211269, 50.27557386670794, 51.75577987943377, 52.305222579411094, 50.256622655051096, 50.23390899385725, 52.58970267432076, 52.33038895470755, 52.46469415937151, 50.624891076769146, 52.26530170440674, 55.15035356794085, 53.79139362062727, 50.744379247937886, 43.76701211929321, 36.87165110451834, 26.274206502096995, 20.801635060991558, 18.515279940196447, 15.708449159349714, 10.114677684647695, 6.0546402760914395, 6.038731941155024, 4.741924064499991, 11.147686345236641, 9.623667597770691, 7.674888968467712, 7.12743649312428, 1.7370015531778336, 0.5606250113674572, 0.08991226141474076, 0.793742339525904, 3.0371266518320357, 10.877809626715523, 24.549510751451763, 41.14176729747227, 40.90680006572178, 34.15601716722761, 29.559116772242955, 27.52155579839434, 28.982895714896067, 40.29135642732893, 40.551858288901194, 25.128691741398402, 6.035647809505463, 0.15394732781818934, 0.061621585195618014, 0.027009880303272178, 0.012619807335015918, 0.021385140517460446, 0.018057479257030145, 0.044220181448119025, 0.051001070266855617, 0.04149067934070315, 0.04626814601942897, 0.01516393621984337, 0.11133742532027618, 0.10108005894081933, 0.011137291439808905, 0.012503436034811395, 0.05671818920278123, 0.012530614754983356, 0.05163249459915927, 0.03252427333167621, 0.03286908447210278, 0.025554795882531574, 0.03057778367240514, 0.05142369919589587, 0.00959493893398238, 0.019728224159085324, 0.020079510219927345, 0.04175779822149447, 0.04198247134419424, 0.0318334330804646, 0.035344295403254886, 0.03573708914752517, 0.04005833602111254, 0.008483355232913579, 0.1102129774434226, 0.03464986909446972, 0.07022547708558184, 0.023181887676141093, 0.023273347411304712, 0.02998042179803763, 0.03437179865847741, 0.03906033653765917, 0.06577063684484788, 0.029019422829151154, 0.03593153353514416, 0.06808098751519408, 0.02261379949881562, 0.035748525855264494, 0.016237714494179403, 0.013335043464654257, 0.009959871182218194, 0.032931594510695765, 0.05786137482417481, 0.04216336538749082, 0.038021631738437076, 0.022204773500561714, 1.2799339592456818, 14.03112188407353, 37.001756123134065, 42.98909180504935, 43.567074230739046, 36.87671981539045, 32.05269323076521, 33.391003131866455, 53.954697132110596, 48.94191925866263, 26.71009131840297, 23.2904554775783, 11.520034228052412, 3.286627560853958, 0.7317456262452262, 0.8466680166976792, 1.4863478945834296, 2.459580876997539, 5.915820045130594, 8.069438082831246, 11.737062948090689, 13.82815979208265, 10.923307299613953, 8.675449541636876, 9.992857524326869, 11.265276789665222, 13.309437683650426, 19.389422382627213, 24.982004846845353, 39.536841120038716, 46.45835862840925, 51.281346457345144, 53.45252650124686, 54.6991479737418, 53.22166912896292, 53.61430140904018, 53.01460238865444, 54.17149829864502, 53.013605322156636, 53.56470169339861, 51.97131299972534, 53.67671707698277, 54.02108369554792, 52.98897048405239, 49.95207616261074, 53.74483721596854, 53.65697029658726, 53.94518157414028, 52.049459389277864, 50.84006289073399, 41.34555448804583, 37.92830187933785, 41.698498657771516, 51.075381006513325, 53.692253249032156, 54.804291588919504, 50.45324625287737, 55.0410201890128, 49.41518538338797, 55.49526562009539, 35.06827047892979, 39.594497271946494, 54.61078078406197, 49.16574157987322, 51.19359418324062, 49.22979702268328, 50.10384913853237, 49.386214869362966, 50.35819489615304, 49.15802213123867, 52.49894183022635, 49.99243824822562, 52.217456408909385, 45.19512053898403, 38.3638288634164, 44.49622556141445, 52.162687233516145, 52.74652699061802, 50.91704545702253, 49.87450647354126, 50.03922394343785, 49.477100781032014, 52.84431593758719, 53.1821790422712, 53.525739669799805, 53.53669350487845, 52.52309029442923, 54.54698589869908, 54.75829104014805, 51.14154870169503, 45.843606335776194, 36.59335838045393, 26.53543097632272, 23.41244500023978, 19.019913707460674, 18.292367833001272, 13.923234598977224, 12.131077919687543, 8.656656401497976, 13.47877744265965, 12.049629398754664, 11.874037998063223, 8.859570724623543, 5.035260072776249, 3.333462110587529, 1.0347865309034074, 0.19220450281032495, 1.1327775184597288, 3.5656342123235976, 11.741601858820234, 22.772559336253575, 34.939826079777305, 38.15071371623448, 34.432124682835166, 31.019412721906388, 32.21244968686785, 34.051078523908345, 46.629781109946116, 46.06092514310564, 30.13084234510149, 7.968791689191546, 0.24642899100269589, 0.045795749939445934, 0.07099383656999894, 0.05043172849608319, 0.021512355655431747, 0.04769278796655791, 0.05317573428952268, 0.03324160698269095, 0.05195882244567786, 0.025338891128610288, 0.020554496607344066, 0.04956142930313945, 0.03272260233227696, 0.0885031952389649, 0.015426751492278916, 0.058472354896366596, 0.010752250806295445, 0.04159394558519125, 0.019151664472052028, 0.029645961709320545, 0.035772376361169984, 0.01529089012183249, 0.007582514330611697, 0.01299089559220842, 0.07300783707095043, 0.030711712914385965, 0.00774835592268833, 0.012447844508902302, 0.10106657644999878, 0.15587978198059968, 0.09354346870843853, 0.12125545633690697, 0.11944395782692091, 0.16685671439128263, 0.16692452718104633, 0.15534467569419316, 0.11410585498171193, 0.2685064034802573, 0.11009229999035597, 0.10575322460915361, 0.11780913626509053, 0.1470671591481992, 0.07755258320165531, 0.09922917825835091, 0.13767670946461813, 0.2642884398145335, 0.177552000486425, 0.10204547178000212, 0.09053257812878915, 0.09777291318667786, 0.20937962191445486, 0.15089895496410982, 0.15597523828702314, 0.11508394964039326, 0.09694666787981987, 2.1061807317393164, 17.23274670328413, 45.022020067487446, 51.20104612622942, 49.49367223467146, 42.67087820598057, 39.481908661978586, 41.541691711970735, 61.547441891261506, 48.15108571733747, 35.96795449938093, 26.780019726072037, 13.36590656212398, 3.493274369410106, 1.2473643869161606, 1.0092719857181822, 2.2485134942190985, 5.7374259148325235, 8.22520887851715, 17.708595820835658, 23.085542678833008, 16.199308122907365, 15.36575184549604, 27.11910571370806, 12.629434858049665, 10.735609531402588, 18.567139557429723, 24.821147101266043, 23.048746756144933, 45.02985416139875, 44.02700328826904, 53.315483706338064, 54.55831841060093, 56.42068229402815, 53.29014015197754, 53.43168190547398, 54.85167482921055, 54.72347709110805, 54.30766214643206, 54.962057386125835, 54.75009216581072, 54.911293847220286, 57.434438364846365, 54.370491232190815, 49.59366028649466, 54.91182191031319, 54.80873843601772, 56.33351714270455, 54.32291691643851, 52.64230401175362, 43.171346528189524, 40.61352355139596, 43.34761190414429, 54.84002617427281, 55.560022830963135, 56.35340288707188, 52.91698019845145, 57.74293143408639, 51.84032208578927, 56.300652163369314, 38.509911264692036, 41.8683751651219, 56.55581086022513, 53.36081722804478, 53.35828460965838, 51.52353981563023, 52.9628244127546, 52.164024761744905, 52.503628390175955, 52.09487976346697, 54.49859516961234, 52.65079123633248, 54.75145748683384, 47.71154614857265, 39.84460462842669, 47.054208346775596, 53.60669313158308, 53.23910215922764, 51.88803536551339, 51.9734982081822, 50.93001774379185, 50.78305639539446, 52.67143780844552, 54.40751123428345, 53.98818050112043, 54.10324961798531, 53.77658353533064, 58.2698654447283, 57.49741336277553, 53.88203981944493, 49.29467930112566, 43.25593042373657, 31.940785544259207, 28.449901138033184, 23.35175769669669, 21.18450164794922, 19.573909214564733, 11.509122950690132, 15.692452669143677, 18.725242342267716, 21.88087442943028, 17.062229224613734, 16.028575250080653, 12.924811465399605, 5.248065156596048, 0.8238720627767699, 0.5456388326627868, 1.6078257475580489, 4.284727386065891, 14.558461495808192, 30.958310263497488, 49.47282763889858, 52.16413593292236, 44.749358858381, 39.740079402923584, 37.187075001852854, 39.49957793099539, 53.15091562271118, 51.36014250346592, 36.57748522077288, 10.270063723836627, 0.46446965102638516, 0.09342473186552525, 0.10510339162179402, 0.11232073112790074, 0.18370365324829305, 0.1307701457824026, 0.12232794878738266, 0.10814221070281096, 0.10530590718345982, 0.11366127883749348, 0.1202843641596181, 0.19111701473593712, 0.18749789893627167, 0.17391791620424815, 0.16589346607880934, 0.23429922759532928, 0.06857378035783768, 0.12513913294034346, 0.1294106873018401, 0.12267766573599406, 0.06137579267046281, 0.07884866651147604, 0.13301240546362741, 0.11000285550419774, 0.16430863897715295, 0.09377008583396673, 0.13187199165778501, 0.10787331406027079], [0.03553310455754399, 0.03314341278746724, 0.04306902304025633, 0.025105943271358098, 0.058664197102189064, 0.020708807344947542, 0.009715487465395458, 0.0138015727612323, 0.0025967361289076507, 0.03307802236772009, 0.012074445839971304, 0.02981097124783056, 0.02246602305344173, 0.05806311685591936, 0.05187493176864726, 0.05177623885018485, 0.04227784103048699, 0.03338814679799335, 0.07203373898352895, 0.04066151294058987, 0.0324419466778636, 0.08140011424464838, 0.017867601410086666, 0.03445076656394771, 0.04755310814029404, 0.02273714529084308, 0.03468773474118539, 2.184265890291759, 11.852201546941485, 30.74475043160575, 46.078455448150635, 41.603013038635254, 38.57048218590872, 27.131958144051687, 39.167738914489746, 29.020711285727366, 20.46150163241795, 25.441956486020768, 13.321680409567696, 6.509381200586047, 2.1795791132109503, 0.2113045850502593, 0.3729460521468094, 0.8274286719305175, 3.581194920199258, 5.190018168517521, 4.50161931344441, 7.734739882605417, 14.739760841642108, 14.689488887786865, 2.9183011651039124, 5.204272397926875, 10.552750314985003, 15.852667706353323, 22.275789192744664, 30.44606821877616, 37.22909075873238, 47.89441578728812, 51.26096739087786, 53.91700315475464, 52.17454086031233, 50.763208866119385, 52.57726539884295, 50.93243571690151, 53.50994641440255, 51.40802948815482, 49.700332505362375, 46.06366968154907, 46.18561404091971, 48.65453481674194, 51.39898988178798, 52.79662350245884, 51.49672324316842, 49.976339272090364, 50.654004028865266, 53.3080734525408, 48.87761715480259, 41.524790218898225, 40.09783172607422, 43.35901389803205, 51.595919200352256, 51.755460262298584, 52.22937951769148, 51.62361471993582, 52.04172951834542, 49.44809900011335, 54.42890821184431, 37.70968723297119, 41.9324688230242, 57.96806696483067, 45.571292536599294, 44.030536447252544, 43.87353147779192, 43.43366881779262, 43.21213245391846, 46.466310841696604, 43.70283855710711, 45.188186236790244, 45.00149508884975, 44.64977032797677, 38.16451283863613, 38.00224460874285, 40.791810853140696, 46.50940009525844, 48.898201193128315, 51.74705989020211, 52.264947346278596, 48.247085503169465, 50.23842184884207, 50.6960197857448, 49.12995835712978, 50.952137334006174, 52.42719125747681, 52.53240088054112, 52.50948224748884, 53.52932841437203, 48.23436335154942, 43.42107173374721, 34.94223363058907, 29.824635233197892, 22.877251318522863, 17.1372298172542, 15.665740319660731, 14.615551369530813, 16.170407090868267, 5.281315760953086, 5.1413425632885525, 9.120043924876622, 8.954164368765694, 7.155155897140503, 1.2102248540946414, 2.901998519897461, 1.196401304432324, 0.07118775509297848, 0.6478981854660171, 3.28360835143498, 11.301718354225159, 24.986877271107264, 54.14947598321097, 61.94893659864153, 55.19956418446132, 42.49337952477591, 33.40500375202724, 31.677483558654785, 37.01365838732038, 39.72988986968994, 23.971698556627544, 10.21795310292925, 0.2115200199186802, 0.07040262222290039, 0.0028858005285396105, 0.02434493401753051, 0.04417494012575064, 0.07801420414554221, 0.03331459699464696, 0.036543656938842366, 0.0216078407995935, 0.027660780286948596, 0.06416273955255747, 0.03215587631400142, 0.03940627404621669, 0.0049602797038720125, 0.02995512940521751, 0.0505068253592721, 0.012289097000445639, 0.03058355800541384, 0.040749922660844665, 0.05864269432744809, 0.1128317154943943, 0.04331899194845131, 0.08586830805454936, 0.0543039378577045, 0.03211544241224017, 0.09569452649780683, 0.041975309407072406, 0.02922000117333872, 0.010975990943344576, 0.08262212188648325, 0.06852770783007145, 0.023148052527436187, 0.04188851460016199, 0.04798778445859041, 0.0058129509811156565, 0.04338673009936299, 0.033704425540885756, 0.09076813834586314, 0.05871879202978952, 0.001409792632330209, 0.026949076780251095, 0.059845078736543655, 0.011008380812459757, 0.08334245466228042, 0.024281433317810297, 0.02550575815673385, 0.04057554594640221, 0.006785194123429912, 0.02431390800380281, 0.04213026984195624, 0.008698910541300262, 0.04428348198000874, 0.036592121302549324, 0.04344784914116774, 0.027245401504582593, 2.5002708307334354, 14.319482547896248, 35.56833233152117, 50.591310432979036, 47.674143995557515, 44.614970275333945, 30.27085202080863, 43.87304857798985, 38.22259283065796, 24.719654764447892, 29.08638392175947, 16.312803472791398, 8.783293400491987, 2.4978991065706526, 0.392597783356905, 0.4220816498356206, 0.5971470230392047, 8.114123685019356, 7.015335125582559, 11.116633108683995, 10.7669198513031, 12.648209759167262, 13.461401735033308, 8.42134175981794, 10.601769856044225, 10.488360490117755, 17.3434454032353, 18.683909245899745, 31.205798149108887, 39.47999790736607, 48.336095401218955, 51.353145667484824, 55.188005856105256, 52.384536266326904, 52.30593129566738, 51.17912803377424, 51.797100816454204, 53.279794284275596, 53.720139844076975, 50.35328251974923, 48.05484274455479, 48.521765163966585, 51.404597078050884, 53.716287067958284, 54.24934244155884, 51.74515955788748, 51.27255003792899, 51.51927014759609, 54.184012004307334, 50.75911290305001, 43.93408850261143, 40.49835021155221, 45.11254467282976, 52.259131704057964, 52.114296504429404, 51.425135953085764, 53.18551765169416, 53.388811520167756, 51.09943914413452, 53.75288322993687, 39.99529021126883, 43.45815426962716, 59.72014904022217, 49.00214971814837, 47.5747708593096, 45.941047872815815, 47.395389216286794, 46.09855311257498, 49.66701936721802, 45.89334501538958, 49.212805203029085, 46.79128156389509, 46.74862657274519, 40.98965038572039, 39.729823861803325, 41.908042430877686, 49.315065315791536, 51.177877358027864, 52.59678636278425, 52.20096485955374, 48.94192968096052, 50.137683391571045, 51.14954260417393, 49.73089763096401, 53.24207598822457, 53.17424767357962, 54.48057849066598, 55.047301360539024, 55.39490931374686, 50.54116528374808, 45.58725602286202, 33.85890872137887, 29.54146487372262, 20.622088398252213, 18.090298584529332, 17.24791635785784, 12.695476617131915, 12.434320756367274, 12.540609087262835, 12.570406436920166, 13.404740912573677, 9.297791004180908, 12.383087345532008, 5.546204541410718, 3.569016247987747, 1.469913776431765, 0.32408276413168224, 1.0952122999089104, 3.4378974437713623, 13.841643639973231, 24.47465259688241, 50.00766175133841, 55.21805681501116, 52.53662191118513, 43.67699473244803, 35.29795707975115, 36.24694204330444, 42.64210571561541, 44.68075581959316, 28.266809156962804, 12.699540444782802, 0.35761075360434397, 0.014583605574443936, 0.042779817844608, 0.00752602204946535, 0.03380592420165028, 0.0858887658853616, 0.009182007118527378, 0.01768237492069602, 0.01567462711994137, 0.02707374910824001, 0.02276750125123986, 0.042968063814831634, 0.08131273250494685, 0.023524096634771143, 0.02687643451749214, 0.008735253725067844, 0.046324203189994605, 0.04742673099307077, 0.022207708164517368, 0.052968784501510005, 0.06429529815380063, 0.04658748495525547, 0.043324386301849566, 0.02962245386359947, 0.04984461928584746, 0.05790481463606868, 0.01381867693271488, 0.029469708845551525, 0.16769433873040335, 0.2016433048993349, 0.11947565898299217, 0.17680018368576253, 0.2509660832583904, 0.07299767940172128, 0.07596261958990778, 0.09873386126543794, 0.07578085362911224, 0.190775494490351, 0.19120624209088938, 0.12419040527726923, 0.19981221029801027, 0.12075277045369148, 0.1833848367844309, 0.19847028516232967, 0.11893633220876966, 0.11150367318519525, 0.11162499524652958, 0.09291719445692641, 0.15440072491765022, 0.10977332746343953, 0.060631867232067246, 0.10504691715219192, 0.14806817471981049, 0.07515931555203029, 0.1309140766305583, 3.460710551057543, 17.616412333079747, 41.26658821105957, 58.812359946114675, 54.63857010432652, 50.18968023572649, 37.71711833136422, 50.304811886378694, 39.72750316347395, 31.60834550857544, 35.447385038648335, 19.09947579247611, 9.733204211507525, 3.0023500493594577, 0.6831679471901485, 0.7878485300711223, 2.7191212815897803, 10.482874018805367, 14.665283100945608, 12.18487000465393, 17.575169563293457, 27.466390575681412, 29.16407346725464, 11.425863555499486, 15.165841749736241, 18.34003594943455, 23.623944691249303, 27.54351905414036, 37.62362684522356, 43.199997425079346, 51.4750657081604, 51.585055691855295, 54.3047056879316, 53.6272736958095, 51.501514026096885, 52.298031193869456, 51.93311875207083, 55.07269355228969, 54.61688825062343, 53.27346100125994, 49.68825306211199, 50.24022143227713, 53.270765100206646, 55.43450014931815, 55.53544705254691, 53.36123759405953, 52.01260266985212, 53.751927852630615, 57.80430139814104, 52.18137093952724, 46.47074726649693, 43.20908219473702, 48.64132629122053, 54.623002665383474, 53.35713815689087, 53.17706169400896, 55.78346994944981, 54.95035661969866, 53.110598700387136, 54.54938302721296, 43.07219573429653, 46.39495284216744, 61.92162322998047, 51.28116233008248, 48.815097263881135, 47.980201721191406, 47.78957789284842, 48.34222023827689, 52.05031401770455, 48.47926650728498, 51.317716802869526, 49.45066635949271, 48.48499182292393, 42.29861109597342, 42.290589400700156, 44.21886737006051, 51.517310755593435, 52.888072218213765, 55.721287046160015, 55.09413569314139, 47.60993569237845, 49.88971260615757, 51.98129408700125, 49.16080488477434, 53.98669706072126, 55.36343397412981, 55.68044206074306, 55.305854252406526, 56.71237461907523, 52.19888039997646, 49.50118671144758, 37.7524916103908, 34.082189083099365, 27.318129914147512, 21.68444538116455, 21.792905024119786, 23.083722250802175, 27.093730892453873, 18.59042991910662, 15.629152842930385, 19.35480645724705, 17.874299934932164, 13.576262405940465, 7.863383173942566, 6.030592560768127, 2.8089786427361623, 0.5776602029800415, 1.383362346461841, 4.14905903169087, 14.7698951789311, 30.075468676430837, 58.319260188511436, 65.56410517011369, 61.431497301374165, 49.53938443320138, 45.15457780020577, 43.23914705004011, 50.10893521990095, 52.08120570863996, 34.633229868752615, 15.778671128409249, 0.8034749744193894, 0.22248279808887414, 0.15230341388710908, 0.15724234815154756, 0.07852545992604323, 0.19469255501670496, 0.1253587340137788, 0.08832510693797044, 0.0839855158701539, 0.08699675928801298, 0.11228020901658706, 0.0993337065779737, 0.17289297548787935, 0.11895883242998805, 0.09713163652590343, 0.12929786049893924, 0.0680475357387747, 0.12009997905365058, 0.17172844654747418, 0.13367921539715358, 0.2324274480342865, 0.11612350600106375, 0.16718838230839797, 0.10301515938980238, 0.18279196002653667, 0.16777040250599384, 0.08148788953466074, 0.1667059710515397], [0.03695633515183415, 0.0318961365015379, 0.04930628317275217, 0.04341319635776537, 0.02213992251615439, 0.050587587989866734, 0.02813008563992168, 0.02442920976318419, 0.05966285815728562, 0.04468289822606104, 0.02389351824032409, 0.005539118844483579, 0.01370213006157428, 0.06344757042825222, 0.017595987234796797, 0.012487147801688738, 0.019035770690866878, 0.04131996671536139, 0.023570881624306952, 0.0535009391605854, 0.037157039025000164, 0.05888553522527218, 0.024980828199269514, 0.026356946410877363, 0.025837193675605313, 0.009682497092788773, 0.10488541903240339, 1.9020424400057112, 9.544716085706439, 26.900289569582256, 50.26688167027065, 38.95751769202096, 27.33590861729213, 22.336797850472585, 14.662410020828247, 13.9871814761843, 28.402111428124563, 20.33308502605983, 18.353293112346105, 6.758210522787912, 1.562876113823482, 0.09146914644432919, 0.18555506318807602, 0.47524294150727137, 3.0513524370534078, 4.378825102533613, 8.777236308370318, 8.492115242140633, 11.37166326386588, 7.369450501033238, 7.075940787792206, 11.99770985330854, 16.4539543901171, 20.672313451766968, 26.111000265393937, 38.85759217398507, 41.716532707214355, 51.17984369822911, 51.20386362075806, 53.27834211077009, 52.176802498953684, 52.05219350542341, 51.422203813280376, 50.557403223855154, 50.86535433360508, 50.22175312042236, 49.53439562661307, 43.22456625529698, 39.316593647003174, 46.12198938642229, 45.49104084287371, 47.89351599557059, 51.258365290505544, 51.98159633363996, 49.36887216567993, 47.136120659964426, 44.10474668230329, 40.112954480307444, 40.7157107080732, 48.49582059042794, 47.92359127317156, 47.179157802036826, 50.43068892615182, 49.24055630820138, 52.70113788332258, 47.45305579049246, 54.930939878736226, 40.06265994480678, 45.471624101911274, 54.52912902832031, 42.69191040311541, 43.056207929338726, 38.60052272251674, 41.5701584815979, 37.23213406971523, 38.27965491158621, 37.19429765428816, 36.57858998434884, 37.79255492346627, 37.85762480327061, 35.31792620250157, 35.98098931993757, 37.43333305631365, 39.617787633623394, 45.37958826337542, 47.98286982945034, 51.03105844770159, 53.27449280875069, 47.03908559254238, 49.02859108788626, 50.03438452311924, 49.556817463466096, 50.338257040296284, 54.49113975252424, 51.9561311858041, 52.871459075382774, 48.681789125714985, 45.15387603214809, 34.528339862823486, 28.351231506892614, 23.841845410210745, 23.446373053959437, 22.70050825391497, 10.89185106754303, 9.08744124003819, 10.316051244735718, 14.939274890082222, 12.822334221431188, 6.455316833087376, 12.116923570632935, 6.318119440759931, 2.1390333345958163, 1.3206481231110436, 0.3162091794822897, 0.3916080450373036, 1.8447341322898865, 8.431749292782374, 20.398259128843033, 42.56236818858555, 45.538913931165425, 34.75750534875052, 31.909674985068186, 29.34457724434989, 31.756064210619243, 43.75529745646885, 44.060455390385215, 29.94163247517177, 10.458478893552508, 0.49120588494198664, 0.024157442917515124, 0.051430647394486835, 0.009329654642247727, 0.06125303890023913, 0.08218692309622254, 0.033592643681913614, 0.07000906512673412, 0.036944969690271785, 0.024136106383853724, 0.028041772610907043, 0.03919048294691103, 0.011271684630108731, 0.028176046209409833, 0.03510726276519043, 0.00851083590116884, 0.017590119603223035, 0.061486176747296534, 0.0055201660891595694, 0.05354042989867074, 0.03555016292791281, 0.007673738274856338, 0.07236168852874211, 0.06622668023088149, 0.04324990690552762, 0.04067218629643321, 0.01456358709505626, 0.014702372951433063, 0.09728186417903219, 0.01877476541059358, 0.02018027606287173, 0.028645166661590338, 0.02586140380507069, 0.03221414890140295, 0.013632253677185093, 0.03175093000754714, 0.022109748063875095, 0.04602358164265752, 0.021623827084632855, 0.05191870067002518, 0.024779891927859614, 0.028033935531441654, 0.02613840894108372, 0.04580506622525198, 0.02786779453578804, 0.013230042715024735, 0.06563993064420563, 0.04066529577331884, 0.08670023948486362, 0.030909007149083272, 0.017807072693748132, 0.01582609479581671, 0.040880689929638586, 0.03280526825359889, 0.01719868801800268, 2.4228450996535162, 11.978428602218628, 31.731658663068497, 55.40623140335083, 46.58125836508614, 33.380532196589876, 28.823679481233867, 24.571777990886144, 22.0598235470908, 34.390595299857004, 24.34939568383353, 19.589992557253154, 7.287904705320086, 1.9120943120547702, 0.08723937626928091, 0.6295960332666124, 0.706320159137249, 4.371201191629682, 8.54049381187984, 10.803725327764239, 8.239360621997289, 17.926963806152344, 12.558197583471026, 9.197294865335737, 10.952450650078909, 11.866967337472097, 19.518328836985997, 25.974831206457957, 38.95684371675764, 42.98717410223824, 50.87680149078369, 52.727346488407676, 53.34035478319441, 50.85884039742606, 52.91843237195696, 52.54878125871931, 52.40681219100952, 50.350767271859304, 52.05482687268938, 51.667975493839805, 46.18624980109078, 42.00434446334839, 47.81512294496809, 49.26188380377633, 50.64073991775513, 53.510227816445486, 54.41102007457188, 50.77834204265049, 49.83432504108974, 45.66257796968733, 41.7871333530971, 42.45686674118042, 49.253942012786865, 50.022972106933594, 49.59210736410958, 51.9068615095956, 50.625276701790945, 53.34061534064156, 48.837616375514436, 56.36456169400896, 42.35232414518084, 46.978146416800364, 55.50272103718349, 46.47274834769112, 44.94867140906197, 41.31669861929757, 43.90465245928083, 40.46144485473633, 40.91517959322248, 38.766504764556885, 39.98360334123884, 38.13674783706665, 38.68296309879848, 37.09878771645682, 36.76326962879726, 40.47725895472935, 42.11245148522513, 48.184753213609966, 49.71963112694876, 53.559612137930735, 53.10900061471121, 47.36177730560303, 49.216140338352744, 50.30082014628819, 49.61355297906058, 49.605173451559885, 54.288655349186485, 52.92889983313424, 53.92216566630772, 51.43828889301845, 46.26792934962681, 36.68369538443429, 32.3556763785226, 24.032345908028738, 16.194011858531407, 19.321102482931956, 14.450806975364685, 13.884386352130345, 12.312788946287972, 12.07477753502982, 15.043572562081472, 10.422819869858877, 14.143152901104518, 6.925616077014378, 5.40849906206131, 2.3195264722619737, 0.4625811523624829, 0.4412002425108637, 2.30092744742121, 9.744199735777718, 21.66825086729867, 46.61099318095616, 52.3866936819894, 45.3627736227853, 40.4755288532802, 35.132235595158164, 37.16294043404715, 48.436357906886506, 49.58639594486782, 33.044135161808555, 12.137672628675189, 0.8587237383638109, 0.03137583924191339, 0.01631474178949637, 0.01131387593756829, 0.05210779480902212, 0.06702716834843159, 0.030849268926041465, 0.01605730560342116, 0.09365300461649895, 0.018601871295166866, 0.08536224985229117, 0.04068097332492471, 0.024241136819390312, 0.029083768304969584, 0.07158215357256786, 0.02480742009356618, 0.05970767539526735, 0.05883543898484536, 0.03438134564618979, 0.03471797704696655, 0.026562942857188836, 0.07022033379014049, 0.0334289403233145, 0.037228783925196955, 0.04047388104455812, 0.048123203084937165, 0.01198671804741025, 0.01725591396513794, 0.16046324531946862, 0.08409795590809413, 0.13687370398214885, 0.14373564720153809, 0.15805576236120292, 0.12850649867738995, 0.14314766946647847, 0.10584057242210422, 0.1710190246147769, 0.09997612996292965, 0.11173067707568407, 0.1407425342393773, 0.10278987219291073, 0.15478636351014885, 0.14916961347418173, 0.07407705219728605, 0.07515250306044306, 0.08412194890635354, 0.15910690809999192, 0.12134313663201672, 0.18904480950108596, 0.19894950730460031, 0.13528397785765783, 0.09735252681587424, 0.12436142324336938, 0.10479237152529614, 0.2379910552075931, 3.078530967235565, 14.538592253412519, 36.5616363797869, 61.53285762241909, 53.140343938555034, 38.64727367673601, 32.78040933609009, 24.8801303591047, 25.12839296885899, 39.9679525239127, 29.2828494480678, 23.71805109296526, 9.266556245940071, 2.1324655498777116, 0.4014184129025255, 0.6465899699500629, 1.4564551157610757, 5.239183187484741, 10.361233643123082, 19.299649919782365, 19.585328578948975, 19.60975670814514, 17.103586639676774, 18.343287706375122, 21.57627582550049, 22.918367283684866, 26.060750893184117, 31.787814004080637, 43.128531728472026, 46.35097074508667, 54.26194647380284, 52.081042425973074, 54.20835154397147, 52.03978054864066, 53.40904120036534, 52.618965012686594, 51.526812417166575, 51.44782529558454, 52.53292546953474, 53.91504028865269, 48.33154085704258, 42.76819467544556, 50.45836707523891, 50.438971178872244, 53.19802440915789, 55.48800127846854, 56.872422899518696, 52.66255106244768, 53.024340288979666, 46.65036167417254, 44.00796175003052, 46.00594057355608, 51.785327093941824, 53.7073586327689, 51.77247640064785, 52.20808328901018, 51.53885364532471, 54.776790618896484, 51.68099294389997, 57.12859255926949, 45.73739964621407, 50.088399818965364, 58.095601149967735, 48.142435210091726, 46.99662515095302, 43.74456596374512, 46.3327317237854, 42.111857414245605, 42.67091989517212, 41.4837680544172, 41.291236945560996, 39.94261244365147, 40.488598414829795, 38.92761264528547, 39.57428496224539, 41.49557999202183, 43.594585623059956, 50.19098997116089, 52.55451004845755, 54.72440120152065, 55.17378289358956, 47.983099120003835, 50.06003032411848, 49.45029810496739, 50.880671637398855, 49.3306223324367, 55.11832584653582, 52.97453212738037, 54.995130811418804, 51.801912443978445, 48.24276372364589, 36.969460896083284, 34.17033740452358, 27.95598496709551, 32.000467096056255, 29.594695023127965, 21.125959600721085, 23.69632407597133, 18.09140682220459, 26.838580880846294, 22.796044247491018, 20.35800474030631, 24.52616306713649, 12.231583612305776, 7.002459245068686, 3.7949301941054205, 0.3638105280697346, 1.1731325473104204, 2.6020282847540717, 10.996919989585876, 23.714969566890172, 48.259536675044465, 51.2258095060076, 45.89720821380615, 40.048666272844585, 41.09050348826817, 43.40405559539795, 57.0651033946446, 55.614861488342285, 40.65577207292829, 15.250976290021624, 1.419059476682118, 0.10120127922190086, 0.15751860689904007, 0.1087161631190351, 0.11135692641671215, 0.31690576353243416, 0.17618191614747047, 0.12997635480548653, 0.14067603780754975, 0.15068554213004454, 0.238903603383473, 0.09731920396110841, 0.09737359532820326, 0.15637500397861004, 0.14815039959337029, 0.12997912322836264, 0.1701346356421709, 0.1335097716322967, 0.10906071641615459, 0.11431278102099895, 0.1241113016647952, 0.10037970902132136, 0.15876645993973526, 0.11130546632089786, 0.1478191523679665, 0.12231367241059031, 0.09264681860804558, 0.12359949627092906], [0.012548559461720288, 0.03069340603958283, 0.05026259685733488, 0.07718059673373188, 0.06328425383461372, 0.04271829168179205, 0.022667318948411515, 0.011036810581572354, 0.01730072102509439, 0.04562490839245064, 0.058518990608198304, 0.03222124298502292, 0.014790000660078866, 0.011099592034172798, 0.09424771341894354, 0.07388932869902679, 0.023614462232217193, 0.02418467422415103, 0.031173255826745714, 0.0446223220122712, 0.027639056988326565, 0.0531342079463814, 0.04811682485576187, 0.016949331487662027, 0.0401723706163466, 0.08215828891843557, 0.03284586839643972, 2.206089964934758, 8.383621726717267, 29.471319334847585, 44.89899526323591, 33.39332730429513, 33.36999525342669, 18.137362207685197, 14.66081714630127, 23.190847839627946, 20.780071326664515, 22.220095906938823, 15.089569636753627, 5.106805239404951, 1.6940779707261493, 0.10714251148913588, 1.3978319700275148, 0.27356143508638653, 5.983237113271441, 5.387294897011348, 11.062319908823286, 5.366370831217084, 15.75064035824367, 12.74672566141401, 5.668190155710493, 9.113549964768545, 14.093701703207833, 32.31016567775181, 29.87488807950701, 42.50093221664429, 46.25822271619524, 52.69525623321533, 53.02813400541033, 55.87465115955898, 50.30363416671753, 51.431576933179585, 52.22617292404175, 51.95681210926601, 50.391508034297395, 50.71824707303728, 49.14337532860892, 45.22808626719883, 37.99232258115496, 38.68489817210606, 40.06568241119385, 41.95781237738473, 43.244184494018555, 44.00846896852766, 45.26422037397112, 42.286156449999126, 38.236291204180034, 39.48529938289097, 44.60502392905099, 48.619154589516775, 49.08143561226981, 50.477405139378135, 53.34306458064488, 50.06153460911342, 50.024233204977854, 46.59027017865862, 52.53491612843105, 41.4899936403547, 42.12520490373884, 53.87429257801601, 45.369304929460796, 40.18286030633109, 37.180147647857666, 37.18994460787092, 35.854910782405305, 36.526700837271555, 36.32202775137765, 37.02959755488804, 35.52655976159232, 36.91124888828823, 38.669751099177766, 44.747500215257915, 37.34055028642927, 38.35626574925014, 39.89966562816075, 47.265440532139365, 47.1243782043457, 50.86392995289394, 48.15608147212437, 48.741470677512034, 48.46598155157906, 50.18834270749773, 49.03150585719517, 52.14588301522391, 49.91867617198399, 52.405655315944124, 49.621234212602886, 47.00951753343855, 37.09360783440726, 30.680007117135183, 19.44215747288295, 11.132951821599688, 17.44907018116542, 16.13061649458749, 9.282555341720581, 11.9449200459889, 8.91507293496813, 11.887402858052935, 6.2938011799539835, 12.574337380273, 4.566055604389735, 4.058598697185516, 1.3951341147933687, 0.745099629674639, 0.3337731398642063, 1.1262656450271606, 8.45648922239031, 21.610163927078247, 33.02863373075213, 27.17056233542306, 14.904162168502808, 17.386366162981304, 26.423278365816387, 37.451123918805806, 41.768102237156455, 46.42185279301235, 27.661273649760656, 7.391448497772217, 0.16385136065738543, 0.057291025428899696, 0.054437782282807996, 0.06733921303280763, 0.0726190365052649, 0.017684895678290298, 0.0046139270166999525, 0.0616708400526217, 0.029520222385014807, 0.013345124798693826, 0.02882701065391302, 0.0034098481784375118, 0.01401711449891861, 0.01793211991233485, 0.043068225761609416, 0.02793980236830456, 0.028976006765982935, 0.11776665997292314, 0.014692176266440322, 0.018214018982169882, 0.04524917980389936, 0.03721546767545598, 0.0031892895224570695, 0.03983052806662662, 0.03990191673593862, 0.08343490505857126, 0.030555710928248506, 0.04069796384179166, 0.055707294161298444, 0.042703336769981046, 0.022515008192775503, 0.012848744202139122, 0.03161284473857709, 0.016760230563314896, 0.03461556914927704, 0.04774538800120354, 0.1141200770757028, 0.019206542688022767, 0.041262908705643246, 0.0917325537385685, 0.02175365967143859, 0.046611030120402575, 0.019766020255961587, 0.005976757816305118, 0.010343354577863855, 0.033277606658105335, 0.03923443844541907, 0.02983061144394534, 0.04623441265097686, 0.051688290533742735, 0.023498390335589647, 0.02722631092183292, 0.029224136844277382, 0.03897271052535091, 0.047009686407233985, 2.7811745575496127, 10.332438571112496, 34.59286083493914, 49.59549461092268, 39.15659052985055, 37.77587924684797, 21.49273589679173, 16.986693620681763, 25.56800201960972, 25.331796271460398, 24.986029590879166, 15.968280519757952, 5.854216882160731, 1.6858692169189453, 0.10238478678677763, 0.8317420376198632, 1.2153720578977039, 4.451329554830279, 9.242639677865164, 12.621541704450335, 7.8915789638246805, 14.29182003225599, 14.095522131238665, 10.633469275065831, 6.719145144735064, 14.055444053241185, 26.15516127858843, 29.59798846926008, 41.14372321537563, 45.9523595401219, 52.50200598580496, 54.16320562362671, 55.180244718279155, 51.751121112278526, 50.447461877550396, 50.89087854112898, 52.338726793016704, 49.944533893040244, 51.992289611271445, 50.421239376068115, 46.17133896691458, 40.832833017621724, 40.87013094765799, 42.13708979742867, 44.494009086063926, 46.241797174726216, 47.309363569532124, 47.65182638168335, 43.9344220161438, 40.00775180544172, 41.2491134916033, 45.69249691282, 51.342469760349815, 50.92665481567383, 50.788479464394705, 53.6447970526559, 50.29786368778774, 50.85729789733887, 47.32726560320173, 53.12638848168509, 42.32444102423531, 44.27253873007638, 54.82266957419259, 46.85179342542376, 42.60158034733364, 39.325341429029194, 38.795162609645296, 37.4296817779541, 38.63887677873884, 38.821249621255056, 38.34258474622454, 37.81255531311035, 39.05677965709141, 39.848693643297466, 45.789941923958914, 38.496848651341026, 40.552518367767334, 41.855423722948345, 48.99938086100987, 49.33327307019915, 51.90008006777082, 48.90494441986084, 48.70190416063581, 48.63342271532331, 51.27492979594639, 49.5209994997297, 52.974500860486714, 50.05049392155239, 52.44355773925781, 48.73047515324184, 47.27554668698992, 39.112615380968364, 31.461662088121685, 21.195148025240215, 17.915600027356827, 21.003171035221644, 13.88479369027274, 12.004984617233276, 13.747110792568751, 10.7037798336574, 11.77542655808585, 11.368906566074916, 12.672881075314113, 9.459941114698138, 3.745698298726763, 3.564755482333047, 0.6677592311586652, 0.26298934380923, 1.6307209304400851, 7.823535255023411, 22.107696635382517, 38.59553739002773, 33.44534151894705, 21.94648974282401, 21.982142686843872, 30.781568935939244, 40.17284447806222, 47.11411224092756, 51.16923032488142, 32.743757588522776, 9.476420504706246, 0.4477511724191052, 0.11975627392530441, 0.03274676496429103, 0.03841650179986443, 0.06330488808453083, 0.022622667951509356, 0.025842460803687572, 0.03185598758448448, 0.04994747840932437, 0.09591652958520822, 0.039142513913767676, 0.054227975862366815, 0.05308979443673577, 0.0544073092751205, 0.03127594531646796, 0.02571269098137106, 0.015543715662455984, 0.021047080800469433, 0.09894314860658986, 0.016140726394951344, 0.04162809286000473, 0.02353941456281713, 0.015521592028172953, 0.03230596147477627, 0.055588723559464724, 0.03738444325114999, 0.013341639673204293, 0.03959791608420866, 0.1737847062093871, 0.13766160527510302, 0.12378367781639099, 0.12941075515534195, 0.13518776159201348, 0.0746227368446333, 0.09083024465612002, 0.1115784952417016, 0.21164791019899504, 0.07473043392279319, 0.15940018450575216, 0.18387144138770445, 0.10769416724464723, 0.18230273627809115, 0.1506992078253201, 0.11102075302707297, 0.1080734683200717, 0.13948941576693738, 0.1300149363066469, 0.16413673891552857, 0.09999676421284676, 0.07933385976191078, 0.09002937655895948, 0.15167276987007686, 0.15811858113322938, 0.13687218406370708, 0.17987640361700738, 3.549879172018596, 13.380047883306231, 40.40596696308681, 54.73217970984322, 46.6570006779262, 45.806895528520855, 26.987157685416086, 23.923269612448557, 33.710359709603445, 30.11050844192505, 31.917324951716832, 19.749665634972708, 7.185255493436541, 2.5550584622791837, 0.27803743204900194, 1.8935037553310394, 1.7474902932132994, 10.767074448721749, 10.983439615794591, 21.5923296383449, 16.348004783902848, 26.65022563934326, 24.707884516034806, 15.629310914448329, 16.89139560290745, 18.730010543550762, 38.56831782204764, 35.67924989972796, 43.74600076675415, 48.62632860456194, 53.15319810594831, 54.619365283421104, 54.09908069883074, 51.44893700735909, 50.50347825459072, 51.68701008387974, 52.39382948194231, 50.020220620291575, 52.759391580309185, 52.63162463051932, 48.73492547443935, 42.21751172201974, 43.17357342583792, 43.55445282799857, 46.02489873341152, 47.245332445417134, 49.05966343198504, 50.375301361083984, 46.136254038129536, 40.78481749125889, 43.30064902986799, 47.965544496263774, 52.88460854121617, 52.15530824661255, 53.39014210019793, 54.76784133911133, 53.76848540987287, 52.56282704217093, 48.127708503178184, 55.32532657895769, 45.22608518600464, 47.16653639929635, 55.81117589133126, 49.413893018450054, 43.63836622238159, 41.69978754861014, 40.78641905103411, 39.705605915614534, 40.11099508830479, 40.03138262884957, 40.77035481589181, 39.286598273685996, 41.936811447143555, 43.29496192932129, 48.6880008152553, 40.654399803706575, 42.89159120832171, 43.15409067698887, 51.567132813589915, 52.15808057785034, 53.30667339052473, 48.66596460342407, 48.45491654532296, 48.754849433898926, 51.98947559084211, 49.95314965929304, 53.34809855052403, 49.70135041645595, 52.46580587114607, 49.3829596383231, 49.15012897763933, 39.50540746961321, 34.43460866383144, 22.769668885639735, 17.752609184810094, 27.425582068307058, 25.763892582484655, 17.32054935182844, 24.93496206828526, 19.73968975884574, 24.19124252455575, 14.152365343911306, 25.48308287348066, 13.528933882713318, 9.692107353891645, 4.386901080608368, 1.7716917374304362, 0.6848285666533879, 1.747532416667257, 10.804604274885994, 23.857673406600952, 38.7072296823774, 35.667107922690256, 26.493378741400583, 26.61854706491743, 37.42439072472708, 48.11875922339303, 53.688317094530376, 57.484465394701274, 37.834640162331716, 12.458494407790047, 1.1567108056374957, 0.2541360631585121, 0.13016843449856552, 0.11474694843803133, 0.1763608729732888, 0.0795510248946292, 0.11615169234573841, 0.13160778369222367, 0.1583799799638135, 0.22392312437295914, 0.09214435664138623, 0.06385224871337414, 0.13331134085144314, 0.137721750619156, 0.0814445379323193, 0.11047696149242775, 0.1452227652605091, 0.26085703394242693, 0.13543807316039289, 0.12388917644109045, 0.1529675775340625, 0.19357036666146346, 0.0608461553763066, 0.13882679917982646, 0.12371787349028246, 0.22344447220010416, 0.09115660642938954, 0.1909520085901022], [0.054584763145872524, 0.03349741807739649, 0.017910798645711372, 0.0163059920804309, 0.007920227146574428, 0.00697999940686194, 0.07611924582826239, 0.04524436899061714, 0.0943946773186326, 0.03595680217923863, 0.027330050444496528, 0.032840243341135125, 0.06070266557591302, 0.054383720005197186, 0.0038938652308258626, 0.03667242592200637, 0.011730913738054889, 0.03494041778945497, 0.046482695399650505, 0.01407932852660971, 0.044240252513970645, 0.03582623168560011, 0.059012027723448615, 0.058360349120838304, 0.03896509396976658, 0.09160039547298636, 0.08282487493540559, 0.8247463958603996, 7.640744652066912, 25.553728682654246, 37.17582239423479, 42.00923599515642, 32.913905075618196, 30.375950472695486, 25.3615779876709, 18.603836468287877, 25.909486872809275, 23.000924042293004, 14.115677986826215, 5.825328877993992, 1.041147606713431, 0.05204411769019706, 0.37279072191034046, 1.432424662368638, 4.027693109852927, 14.071879148483276, 8.049224904605321, 2.414731775011335, 13.430569103785924, 10.800731522696358, 9.517905592918396, 8.310720358576093, 18.89228572164263, 28.27425762585231, 33.926059586661204, 48.4810973576137, 50.00624431882586, 54.599945068359375, 52.13339362825666, 51.85440608433315, 52.118166651044575, 51.00371033804757, 50.56585570744106, 52.395830563136506, 51.01553269795009, 52.461765493665425, 48.295656885419575, 44.26267228807722, 35.90561178752354, 35.08475508008684, 35.143814768110005, 33.19479295185634, 35.746501513889854, 33.6788044657026, 34.89933892658779, 36.08103295734951, 39.011977672576904, 41.806477137974326, 47.308213642665315, 50.03282812663487, 52.45678016117641, 51.21776001793997, 50.84120239530291, 49.679057121276855, 45.33157273701259, 44.14546660014561, 52.92033270427159, 42.781031472342356, 43.10391078676496, 51.235460553850444, 43.81660488673619, 40.72308274677822, 34.6401606968471, 35.75103521347046, 33.7231513432094, 34.645302363804404, 33.934421743665425, 35.84147991452898, 35.289480277470176, 35.072682585035054, 34.57004989896502, 39.1530191557748, 36.55980205535889, 38.783253397260395, 37.54536233629499, 42.058613368443076, 46.44096033913748, 49.87535415376936, 48.77642706462315, 50.57972083772932, 49.801706722804475, 50.65902410234724, 49.92259495598929, 53.19700302396502, 51.05197947365897, 49.07669346673148, 47.31109019688198, 46.79063885552542, 41.97546427590506, 29.973080021994456, 27.913003410611832, 20.945035457611084, 26.251480681555613, 10.559387581689016, 16.17025944164821, 10.703739881515503, 8.455166459083557, 9.610589350972857, 8.666681783539907, 8.753944209643773, 9.01009910447257, 5.2760368670736035, 2.9336236800466264, 0.5390878756131444, 0.32920928618737627, 1.1549446604081561, 6.657466420105525, 16.298224415097916, 24.905929020472936, 33.97755963461739, 32.81392049789429, 29.082666635513306, 25.953950132642472, 30.564993585859025, 38.235863889966694, 41.22379773003714, 20.579654012407573, 7.408079011099679, 0.7581385214413915, 0.012031009420752525, 0.03618195027645145, 0.043971762992441654, 0.016459846503234336, 0.059224958797650676, 0.04777163373572486, 0.03706606783504997, 0.00628360958736656, 0.015210799240906323, 0.07528266643307038, 0.041968744580766985, 0.03952036631692733, 0.02302764479203948, 0.06252445746213198, 0.025472104516146437, 0.015283222676121762, 0.05422211671248078, 0.07781583443284035, 0.03389908027436052, 0.02437627894271697, 0.0066112830536440015, 0.09241086484066077, 0.027677351808441535, 0.02317778253927827, 0.04274098528549075, 0.016035845237118856, 0.04658612449254308, 0.060608607051627975, 0.007025948101987264, 0.040230975685907264, 0.020750555908307433, 0.0073179051812206, 0.07222043110855988, 0.019579999880599122, 0.034464700280555656, 0.04299515432545117, 0.048586571256497076, 0.009787064428175134, 0.006065737930059965, 0.006134252155399216, 0.01790098363666662, 0.016656784507046853, 0.00977384571784309, 0.023150649620220065, 0.014913818033944284, 0.023090368569163338, 0.015507429305996214, 0.05512464971148542, 0.04533158788191421, 0.052645462565124035, 0.051362159462379556, 0.02767635096928903, 0.02785353851504624, 0.09218905852841479, 1.073485717177391, 9.281123144286019, 30.233397756304058, 44.31475598471505, 46.354729720524375, 39.084294523511616, 30.657196181161062, 28.94703085081918, 24.24033154760088, 26.918108224868774, 29.484072753361293, 16.434935433523997, 6.936475242887225, 1.1827238840716225, 0.05619988005076136, 0.5276008748582431, 1.910231543438775, 6.642860003880092, 11.696343898773193, 11.044784392629351, 13.205936448914663, 15.156875099454608, 9.776785918644496, 7.959478497505188, 7.448492339679173, 15.972956657409668, 25.147957359041484, 32.7972343989781, 46.78825562340872, 52.18774243763515, 54.78956488200596, 53.04150928769793, 51.523373058864046, 51.13594150543213, 51.581400939396445, 51.21642943790981, 50.973412718091694, 52.55420085362026, 53.38042851856777, 51.44255856105259, 46.141440868377686, 38.44703006744385, 38.03873654774257, 37.470766476222444, 35.233269350869314, 37.36170407703945, 37.12983921595982, 36.71247482299805, 37.16439608165196, 40.8446102142334, 43.41691671098982, 48.9171141896929, 50.676248686654226, 52.84897123064314, 53.255930696214946, 52.62845625196184, 50.581131322043284, 47.21071652003697, 46.55510881968907, 53.32243537902832, 45.754130908421104, 46.12153080531529, 54.186475140707834, 46.88927548272269, 42.631249155317036, 35.4722352709089, 37.565352303641184, 34.19799470901489, 37.22151027406965, 35.58502190453665, 38.079220226832796, 35.33275713239397, 35.788506848471506, 37.11112771715437, 42.63062381744385, 39.34452887943813, 39.517271518707275, 39.66992344175066, 44.23957300186157, 48.137092045375276, 52.23144660677229, 49.6274493762425, 49.72462688173567, 50.62824010848999, 50.67778076444353, 50.13912166867937, 52.712821279253276, 50.74395193372454, 51.458115577697754, 47.87608296530587, 47.54394170216152, 43.203270026615684, 33.16703837258475, 26.17881120954241, 20.298958948680333, 21.847559554236277, 13.075964314596993, 13.262891701289586, 17.92170054571969, 13.336669410978045, 13.492236971855164, 13.554651771272932, 10.220242534364973, 8.343263115201678, 4.421826200825827, 2.8343278425080434, 1.3564574015992028, 0.36311006279928343, 1.1279600283929279, 7.145086220332554, 18.54017880984715, 29.223126207079204, 36.17317301886422, 32.13615499223982, 28.08071381705148, 27.708370276859828, 37.03464889526367, 43.913633005959646, 47.405012471335276, 24.964740310396465, 8.739088092531476, 1.238831021956035, 0.04687204897137625, 0.010544522399348872, 0.048400333749928644, 0.04391593313110726, 0.07064310181885958, 0.01076176217091935, 0.0437426115386188, 0.0381905496386545, 0.021502440562471747, 0.051035957144839425, 0.031372205686888525, 0.046855014349733076, 0.07837679968880755, 0.041386449576488564, 0.03907103703490325, 0.06788772038583245, 0.010493907079632794, 0.05364881568987455, 0.027900630541677986, 0.017545760376378894, 0.01714570970008416, 0.08824776751654488, 0.08125267537044627, 0.08144871092268399, 0.04762574531404035, 0.011141003874529685, 0.06118335335382393, 0.26464849763682907, 0.09742657534245934, 0.1501366344413587, 0.09984001583818879, 0.08456905598619155, 0.07597884336220366, 0.22526167040424688, 0.1814783162304333, 0.19297552215201513, 0.17464485791112694, 0.10351885629019567, 0.10506679144288812, 0.19256605340966157, 0.11529285700193473, 0.08662669307419232, 0.12645213891352924, 0.12319648718195302, 0.09245013844754014, 0.1210895273834467, 0.12159370604370322, 0.1476849652826786, 0.1386717539280653, 0.11961793420570237, 0.12298757982041154, 0.16060831610645565, 0.15927266063434736, 0.20594082001064504, 1.6215557136705943, 12.652141571044922, 35.31113086427961, 51.18685095650809, 53.11641781670706, 44.59378521783011, 38.349380084446494, 35.8025734765189, 27.817573377064296, 38.495681353977744, 32.415378774915425, 18.88165671484811, 8.029759526252747, 1.8000870708908354, 0.10083373715834958, 1.203721774475915, 3.746914667742593, 9.511528883661542, 26.654524837221416, 19.68572657448905, 14.562103220394679, 24.634242296218872, 23.020834105355398, 20.863185678209575, 15.641287871769496, 21.470228944505962, 33.18562132971627, 38.183787141527446, 54.318591662815635, 55.24295221056257, 58.21631220408848, 54.376244340624126, 52.93018524987357, 51.92896372931344, 51.7017228943961, 50.17736107962472, 52.88382339477539, 52.98923104149954, 55.461219446999685, 52.877583912440706, 48.68690299987793, 39.26401662826538, 40.41992241995675, 38.17464331218174, 37.02437250954764, 39.677736691066194, 37.71937302180699, 37.56201022011893, 39.06000362123762, 43.59100035258702, 44.91054664339338, 50.783574036189485, 53.89886140823364, 52.87906040464129, 53.25329385484968, 53.5374230657305, 54.34500176565987, 48.29956872122628, 49.159741810389924, 55.81172827311924, 47.19287354605538, 48.286301136016846, 56.69911745616368, 49.97398730686733, 43.977542536599294, 37.716447830200195, 39.92989029203142, 36.86404630116054, 38.96403510229928, 39.28732088633946, 39.35827241625105, 38.737607206617085, 37.75249855858939, 38.75483179092407, 43.57416139330183, 41.06099796295166, 42.65143714632307, 41.42692484174456, 46.37545619692121, 50.44387660707746, 53.60196140834263, 50.254288060324534, 50.62755223682949, 51.42189114434378, 51.293926170894075, 49.453667981284006, 53.4741701398577, 52.40486322130476, 51.10762412207467, 48.99302673339844, 48.83198138645717, 45.620138372693745, 35.402913093566895, 30.0630452973502, 25.199634586061748, 36.52937936782837, 16.045546225139073, 27.95457795688084, 20.592496020453318, 19.01643787111555, 24.117402281079972, 21.810939073562622, 18.742030927113124, 16.990119082587107, 8.917515226772853, 4.855916210583278, 2.0632226254258836, 0.7422750783818108, 1.8507404157093592, 8.358939119747706, 19.44600851195199, 32.901950699942454, 44.42109816414969, 43.00091069085257, 40.34257507324219, 35.43527085440499, 41.56872020448957, 50.1732998575483, 53.04359027317592, 32.185553210122244, 11.643209287098475, 1.7822654843330383, 0.16358886260007108, 0.12227243105215685, 0.1583795321307012, 0.18992347163813456, 0.15367169332291397, 0.09696726141763584, 0.10313190812511103, 0.08595018687524966, 0.09996156860142946, 0.15285730202283176, 0.09962091009531703, 0.07697103119322232, 0.13990128652325698, 0.17001591915530817, 0.11412823306662695, 0.10901153619800295, 0.1947756755564894, 0.242594128208501, 0.10456633793988399, 0.12369607894548348, 0.06341287014739853, 0.2761212762977396, 0.2018920694078718, 0.1969238631427288, 0.1795896411474262, 0.08934942340212208, 0.19660305178591184], [0.014160752728847521, 0.06165465020707675, 0.052752691454121044, 0.0687940599662917, 0.03806290023827127, 0.025928636447393467, 0.06076192882444177, 0.014102846550356065, 0.014785215291859848, 0.029855154055569853, 0.010413529517661248, 0.013962958922742732, 0.012660726389315511, 0.09418376149343592, 0.04569894674101046, 0.05150819716176816, 0.011851795599795878, 0.0498903321900538, 0.03446657642988222, 0.01852015362653349, 0.015152669145858713, 0.008075078167686505, 0.0891602953363742, 0.0318086835156594, 0.00659917586848938, 0.05292900199336665, 0.052227681768792014, 0.9614472091197968, 7.947551914623805, 25.860647984913417, 40.34701149804251, 41.06192207336426, 39.23391008377075, 29.97929518563407, 24.375486169542583, 18.130236830030167, 17.37137716157096, 14.937226908547537, 11.411935022899083, 4.8526991946356635, 0.8660091417176383, 0.24713092190878733, 0.6986007105026926, 1.244048033441816, 3.748924434185028, 4.584512625421796, 7.087698876857758, 10.909099970545087, 11.403076069695608, 9.90297736440386, 7.924256341797965, 2.9165391453674863, 21.79991054534912, 30.091637134552002, 34.36147539956229, 44.87464877537319, 48.17494583129883, 48.91767004558018, 51.99270302908761, 50.56986829212734, 50.68689680099487, 50.6508287021092, 52.24154233932495, 51.39895861489432, 52.69829259599958, 52.22824348722185, 49.43630790710449, 44.413472516196116, 39.14589030402047, 35.928648539951865, 35.73933097294399, 40.55452987125942, 38.71978507723127, 38.586991105760845, 41.361090660095215, 41.41798251015799, 46.74745927538191, 47.32348230906895, 48.74841887610299, 49.36880268369402, 49.56733356203352, 51.8978670665196, 48.46237196241106, 45.03302948815482, 44.33049712862287, 44.43612016950335, 49.583595820835654, 45.68232822418213, 42.690604141780305, 53.9436217035566, 42.63046400887625, 38.27337374005999, 34.8794983455113, 37.127845082964214, 38.274881499154226, 41.05049228668213, 42.263953481401714, 43.975534507206504, 41.22504840578352, 39.75817251205444, 34.282821791512625, 37.11458444595337, 34.52051271711077, 35.95436034883772, 35.37773282187325, 40.948854037693565, 44.569410937173025, 50.836276122501914, 47.63524450574602, 44.01922477994646, 46.462426798684255, 49.74466896057129, 47.441163948604036, 51.38597937992641, 48.952824456351145, 49.6830974987575, 45.9804094178336, 44.57627575738089, 37.81481000355312, 35.31816938945225, 23.817841121128627, 27.851701191493444, 22.40687390736171, 19.484002998897008, 8.954616870198931, 16.790426118033274, 8.45610967704228, 6.5146917956216, 10.249656864574977, 7.300408857209342, 7.994940366063799, 2.8875004521438052, 3.7759364247322083, 0.7372015363403729, 0.22281680016645364, 0.9797269425221852, 5.025108754634857, 13.19820397240775, 22.557151283536637, 27.22791450364249, 27.692372049604142, 24.310595205851964, 21.26454315866743, 33.62030063356672, 43.73032215663365, 41.41934435708182, 30.25470440728324, 6.111331496919904, 0.6950777024030685, 0.015174212632700801, 0.006869071653844523, 0.05500315801639642, 0.035111551106508286, 0.0447593250178865, 0.038910295481660535, 0.046064130895371945, 0.03767902583682111, 0.03505161950098617, 0.045812686173511405, 0.04718208858477218, 0.024227342202461193, 0.027752370640103306, 0.05241578185398664, 0.009836463473870285, 0.015435385850391217, 0.0365811901033989, 0.03868146972464664, 0.04622552723490766, 0.02966039754184229, 0.056465380625533204, 0.10951842899833407, 0.016799293824338486, 0.07096321428460733, 0.07995680240648133, 0.07275371892111641, 0.04800436446177108, 0.12827259408576147, 0.07391762360930443, 0.05492878718567746, 0.08943434884505612, 0.04250963877088257, 0.0402305549941957, 0.0554449555597135, 0.014882990491709538, 0.03169604670256376, 0.04392486604462777, 0.054960596907351694, 0.026235714255432998, 0.01997612862448607, 0.06507585769785301, 0.05908475989209754, 0.04508021101355553, 0.039718759778354845, 0.036941203820918284, 0.07653258222022227, 0.0356618226505816, 0.058764396368392875, 0.012585236823984554, 0.03440243451456938, 0.04650450351514986, 0.041479429230093956, 0.03744739094483001, 0.05914891537811075, 1.405185661145619, 9.969217147145953, 29.677743366786412, 44.24685818808419, 46.14407423564366, 42.03405843462263, 32.791349274771555, 26.143689802714757, 18.685646295547485, 23.92513520377023, 19.166598864964076, 13.225439173834664, 6.170824144567762, 1.0201291974101747, 0.20594688611371176, 1.0005234437329429, 2.538855480296271, 3.972517899104527, 8.187063268252782, 11.442792841366359, 10.937287943703787, 12.01274141243526, 9.899106349263873, 14.544418317931038, 8.264915227890015, 18.736001627785818, 28.4981198992048, 36.058659757886616, 45.32831055777413, 49.80094936915806, 50.89910173416138, 53.25837646211897, 52.83651658466884, 51.61656577246529, 51.088120528629844, 50.89106961659023, 52.27403906413487, 51.151859828404014, 53.7839868409293, 50.331246307918, 44.857212271009175, 39.597088950020925, 37.4437484060015, 36.320860454014365, 41.34034333910261, 38.80172865731375, 39.53552096230643, 41.2039988381522, 43.536203384399414, 47.93468059812273, 49.02369260787964, 50.6855662209647, 50.079721518925254, 49.64329126902989, 52.31522103718349, 49.79690899167742, 46.48572063446045, 46.66852079119001, 46.63760130746024, 51.47623300552368, 48.81019530977522, 46.54869910648891, 55.37795570918492, 43.96471963609968, 38.253005095890586, 35.95134483064924, 36.80941261563982, 39.25960799625942, 43.15904474258423, 44.23090165002005, 46.54114294052124, 42.22564806256975, 39.3629971912929, 36.34533200945173, 37.30701480593, 36.87247794015067, 37.77038322176252, 37.58313969203404, 41.464848109654014, 46.62878056934902, 51.628700801304404, 47.72430304118565, 47.79753358023507, 49.64264508656093, 50.16922473907471, 49.24258518218994, 51.52393238885062, 49.71050814219883, 49.99443238122122, 47.9948867389134, 44.85471439361572, 42.43231528145926, 36.725926535470144, 26.059866734913417, 24.785591432026454, 14.770913090024676, 11.02483698299953, 7.698769927024841, 15.7209107535226, 16.77878267424447, 13.10955364363534, 15.25748154095241, 9.84912187712533, 8.454639264515468, 5.877044754368918, 2.8350867160729, 0.9494608065911702, 0.2599641904234886, 1.5814132562705447, 5.483352874006544, 15.944482939583914, 26.538714000156947, 31.820203031812394, 34.654866559164866, 31.58622591836112, 26.92424522127424, 37.678503717694966, 48.329390389578684, 46.41006864820208, 35.13264553887503, 9.010714888572693, 0.9512822117124284, 0.038078465831599066, 0.028901730930166583, 0.025772727759821073, 0.04553661063047392, 0.04229721999061959, 0.024051152103181397, 0.04639026875208531, 0.015294221728774053, 0.060255090306912146, 0.04014882884387459, 0.021862155724582926, 0.028119335948888744, 0.053479351568967104, 0.03191276739484497, 0.05496450187638402, 0.025467249598088007, 0.056430741412831206, 0.028999059993241514, 0.03622475226542779, 0.03912067865686757, 0.019233499187976122, 0.022995653562247753, 0.03160568280145526, 0.11971459830445902, 0.027576339996552894, 0.038709391440664015, 0.028552068264356682, 0.24251748089279446, 0.217883063480258, 0.12674507605178015, 0.19840228238276073, 0.1923409290611744, 0.1273233507360731, 0.142179793545178, 0.12873669846781663, 0.10992039992873158, 0.17602335608431272, 0.11954064906707831, 0.07117008604109287, 0.08394682580339057, 0.15846167558005878, 0.16069938907665865, 0.14036047831177711, 0.10312793190990176, 0.11744892916509084, 0.20140100004417555, 0.094223279372922, 0.09998385847679206, 0.10540167561599187, 0.18083596069897923, 0.1369356678000518, 0.08211048612637178, 0.18207796476781368, 0.14422705583274364, 1.9767481684684753, 13.172163861138479, 35.65866586140224, 52.37425293241228, 52.34171104431152, 49.23148890904018, 39.904904569898335, 33.15682452065604, 29.38273675101144, 28.764314072472708, 22.74822153363909, 14.919875519616262, 6.877792494637625, 1.6615334770509174, 0.5475798770785332, 2.316659688949585, 3.8148128986358643, 7.738043751035418, 10.10147784437452, 17.533654076712473, 18.87187886238098, 16.459379196166992, 17.907481057303293, 17.88880603654044, 8.324489951133728, 25.71080834524972, 34.057825224740164, 39.16127014160156, 48.58822815758841, 52.59415299551827, 53.465387616838726, 55.30136571611677, 53.37239292689732, 52.30146707807268, 51.72329357692173, 51.96780068533761, 52.07624816894531, 51.76421499252319, 56.833429609026226, 54.19939184188843, 48.451293059757774, 42.357295581272666, 39.51552404676165, 39.656016622270855, 44.64667837960379, 42.33519683565412, 42.408010482788086, 45.54121725899832, 46.68993861334664, 50.28143119812012, 50.933846201215474, 52.037515435900005, 50.589399678366526, 50.56025545937674, 55.486934729984824, 50.64330380303519, 50.566776343754356, 48.215221064431326, 51.09666681289673, 52.03645583561489, 50.959168910980225, 48.953210081372944, 57.654237679072786, 46.134940828595845, 40.9335332598005, 38.91303879874093, 39.997635228293284, 43.19915669304984, 45.97113357271467, 48.58927386147635, 48.15466056551252, 44.54235117776053, 43.70987013408116, 38.52497843333653, 40.28994941711426, 38.76539305278233, 40.19710758754185, 39.33411005565098, 43.49362134933472, 49.06455148969378, 53.65499005998884, 50.814135687691824, 50.249066489083425, 48.25973817280361, 53.19297306878226, 49.591520241328645, 52.21717848096575, 48.74024084636143, 50.64006246839251, 47.9038062776838, 47.81998668398176, 43.93479721886771, 43.54693487712315, 30.66882746560233, 33.204305035727366, 28.00321708406721, 30.33469901766096, 18.23288083076477, 28.16307602609907, 19.62083387374878, 17.050731692995342, 22.22231933048793, 19.248439959117345, 17.106279066630773, 8.26301576410021, 7.8269685336521695, 1.3093443810939789, 0.7381317807095391, 1.826975405216217, 7.03285196849278, 16.967676401138306, 30.222996303013392, 36.429228033338276, 37.933975083487375, 35.14880704879761, 32.79058149882725, 42.80094848360334, 55.61012976510184, 53.47522626604353, 42.35961627960205, 11.271783777645656, 1.2417017136301314, 0.12563685194722243, 0.08388845822108643, 0.14043449291161128, 0.25299026178462164, 0.1275051845503705, 0.2266295970018421, 0.1221939924040011, 0.1386183396513973, 0.2154240525726761, 0.11298019252717495, 0.1198882625571319, 0.12367435225418635, 0.13436530929590973, 0.20787784749908106, 0.16788413854581968, 0.06709128312234368, 0.15227986872196198, 0.09875384412173714, 0.1373176830155509, 0.15159072141562188, 0.1447411003921713, 0.18521857767232827, 0.12040000009749617, 0.24813841070447648, 0.16816263645887375, 0.11591834415282522, 0.11685123480856419], [0.04678689282653587, 0.0363209346043212, 0.0442682895809412, 0.04448680839102183, 0.04836926023874964, 0.06343406758138112, 0.006594948171238814, 0.04527290817350149, 0.09209333759333406, 0.03929971351421305, 0.010349755707596029, 0.03911292639427951, 0.048650570679455996, 0.04490211931988597, 0.025705398426258137, 0.046890505123883486, 0.023571035991023694, 0.05205457730750952, 0.033068190395299873, 0.016830492864495943, 0.03776460945872324, 0.006028290854633919, 0.07054071766989571, 0.0497148732122566, 0.00831149164254644, 0.03477152703063829, 0.05995810231459992, 0.3466396565948214, 7.393684949193682, 18.56378357751029, 37.889416285923545, 44.54006174632481, 39.09780182157244, 27.797843967165264, 20.472120216914586, 29.48311390195574, 27.274255514144897, 13.893419878823416, 12.412274990762983, 5.587208901132856, 0.7317615853888648, 0.032474082096346786, 0.06153619156352111, 2.8489090715135847, 4.821043636117663, 6.730866755758013, 8.698696477072579, 14.448752045631409, 15.111393928527832, 4.117201975413731, 11.09561654499599, 13.110849482672554, 17.49500298500061, 26.191437823431833, 37.18881899969918, 43.94201292310442, 48.61218902042934, 48.93815333502633, 50.81195395333426, 52.765026569366455, 52.85857711519514, 50.891955511910574, 50.26457486833845, 50.6771172114781, 54.05541821888515, 49.139522552490234, 48.354257992335725, 41.873357023511616, 35.809410503932405, 36.426730155944824, 45.189141614096506, 48.04168285642351, 48.74159574508667, 48.99730682373047, 48.26914603369576, 46.147975649152485, 47.444644996098106, 51.578725882938926, 49.24880034582955, 50.869790758405415, 53.95122650691441, 48.6614065851484, 45.57366534641811, 43.645581926618306, 43.839388029915945, 44.153721060071675, 51.39516837256295, 47.52820403235299, 43.075510025024414, 50.34221403939383, 41.97529404503958, 38.551114082336426, 37.82662888935634, 43.19205215999058, 47.420927320207866, 49.99847970690046, 49.67685801642281, 51.221894196101594, 49.38329315185547, 48.17185040882656, 45.0368127822876, 42.05150883538382, 39.1051321710859, 37.28418302536011, 34.95254823139736, 34.625451360430034, 39.816193444388254, 49.40288012368338, 46.68289313997541, 50.777435302734375, 48.88851193019322, 50.056080273219514, 47.22117703301566, 48.721088136945454, 50.78862885066441, 50.01667356491089, 51.05296611785889, 50.08114242553711, 45.39329011099679, 34.11824328558785, 29.01395763669695, 21.52572246960231, 15.619626862662178, 8.02310402052743, 6.622734546661377, 17.103395564215525, 13.624063406671796, 16.680641106196813, 14.302362186568123, 4.588441831724984, 3.257149611200605, 5.6490873864718845, 0.9108016810246876, 0.8691308913486344, 0.22219252080789634, 0.807312117091247, 2.632613386426653, 10.199982455798558, 19.16181329318455, 32.24365752083914, 27.08754873275757, 18.57963936669486, 19.605626004082815, 28.626885652542114, 40.002498967306956, 36.73930876595633, 24.63796305656433, 4.2798032845769605, 0.42155263679368155, 0.01734771466414843, 0.020128612406551838, 0.06823950686625072, 0.03826974146068096, 0.026974051957949996, 0.017570581187361052, 0.036852064675518444, 0.03005148477054068, 0.07248892063008887, 0.06355796807578631, 0.024283300985449126, 0.02759693523070642, 0.05939195305109024, 0.027952606324106455, 0.05303823256066867, 0.026731316233053803, 0.021189084609172175, 0.02887962425925902, 0.029811456400368894, 0.038885128617818863, 0.06191023399255105, 0.009839379478112927, 0.05449202437219875, 0.0372468838468194, 0.04338698794267007, 0.031127695592918565, 0.00926124389349882, 0.017458588982533132, 0.0220356961446149, 0.029586776492318938, 0.027233030114855086, 0.05450278254491942, 0.0428901137118893, 0.026477844387825047, 0.009194526089621442, 0.029842638477150882, 0.04480891914239951, 0.056645253473626714, 0.048673688367541344, 0.06406081680740629, 0.057975850467170985, 0.03518525018755879, 0.027800544930089797, 0.018370931901569878, 0.029020355814801793, 0.02876730975029724, 0.004625715714480195, 0.02813645199473415, 0.02636220505727189, 0.02596074133180082, 0.02755340720926012, 0.03877899895555206, 0.024376986315473914, 0.028354122636041472, 0.594987653195858, 9.120241948536464, 24.800392832074845, 45.69890662602016, 49.93081814902169, 46.38174084254673, 31.910557406289236, 22.975611754826136, 32.54140520095825, 31.45389747619629, 16.983580827713013, 13.246675474303109, 6.157956515039716, 1.0999748557806015, 0.04850902148921575, 0.19125506947083132, 3.2433678592954363, 5.976330169609614, 8.406680192266192, 8.413179363523211, 8.419989466667175, 12.644383038793292, 10.021395512989589, 15.372180666242327, 10.579548648425511, 19.04645582607814, 28.88839500291007, 39.891345160348074, 46.29769195829119, 50.25942277908325, 50.719261510031565, 52.62109463555472, 53.139162744794575, 54.15085520063128, 50.90693582807268, 52.38465438570295, 50.88083839416504, 54.64436142785208, 50.813534668513704, 51.21947274889265, 43.81569119862148, 38.50528376443045, 37.88743952342442, 46.79693044934954, 50.07243633270264, 50.34290885925293, 48.48500224522182, 50.45273903438023, 49.349316460745676, 50.05469063350132, 50.90236043930054, 50.40158987045288, 50.42022493907383, 54.40877233232771, 50.236889771052766, 48.18770619801113, 44.62280436924526, 46.02545806339809, 46.844313689640586, 52.24959530149187, 48.584562982831685, 45.16206448418753, 51.57125309535435, 43.871916021619526, 40.2170523915972, 38.887629236493794, 46.01926721845354, 49.57211739676339, 52.79237815311977, 51.129556110927034, 51.33920063291277, 51.579045500074116, 50.11194726399013, 45.69344881602696, 42.64812632969448, 40.36552497318813, 38.8640262058803, 35.690241949898855, 37.23373562949044, 42.575979709625244, 50.67517866407122, 49.447508403233115, 50.713987827301025, 49.65146235057286, 51.15380532400948, 48.81128965105329, 49.78797360828945, 49.92198004041399, 50.14152227129255, 51.114784240722656, 49.516882692064556, 45.32414163861956, 36.01936422075544, 30.06350040435791, 19.38027160508292, 12.075838872364589, 9.301199964114598, 4.247165424483163, 8.263310194015503, 13.122168966702052, 14.834176438195364, 14.8359933921269, 12.757541401045662, 10.013809817177908, 6.728207332747323, 3.0880143897874013, 1.318480936544282, 0.44079963543585365, 1.0239236738000597, 3.761290056364877, 12.1302467414311, 21.024955374853953, 31.81441170828683, 27.459702934537614, 23.034539427076066, 23.17339222771781, 32.768281255449565, 46.280898162296836, 43.56511831283569, 30.167240483420237, 5.867967801434653, 0.7297339599047388, 0.08213937136211566, 0.04396657898489918, 0.03284530181969915, 0.08040850995374577, 0.09153640962072782, 0.032257856734629185, 0.047390242772442956, 0.020497535288866078, 0.009926266735419631, 0.0943601398861834, 0.011651059496216476, 0.051785195512431006, 0.021024488977023532, 0.05908657158059733, 0.0366445483107652, 0.04236686143225857, 0.03179876333368676, 0.03985043967674885, 0.030231710456843888, 0.12717846993889126, 0.02032732986845076, 0.03787193673529795, 0.045037643119160614, 0.05084139062091708, 0.03271292303023594, 0.013880934217013419, 0.011847392755693622, 0.11707112086670739, 0.1311270416315113, 0.08359141594597272, 0.14843984906162533, 0.16116004650081905, 0.20906791649758816, 0.13279413431882858, 0.11244743397193295, 0.16707759111055306, 0.09831796679645777, 0.09952677014682974, 0.21295759135058948, 0.16679549696190016, 0.21185126714408398, 0.12667344989521162, 0.08772344993693487, 0.10317880846560001, 0.1026551965624094, 0.17194625628846033, 0.1008061682805419, 0.11415373241262776, 0.12137259862252645, 0.13780204845326288, 0.12993940178837093, 0.10917887650430202, 0.06503026014459984, 0.13101410626300744, 1.1668793857097626, 11.128222703933716, 29.642901624952042, 52.2631825038365, 56.49190827778408, 51.08850267955235, 37.799798420497346, 30.273513180868967, 40.38090133666992, 37.441267899104524, 21.66220072337559, 16.414936780929565, 7.733915652547564, 1.3172284151826585, 0.09595477860420942, 0.43113479976143154, 6.823844509465354, 9.910941737038748, 14.922144106456212, 18.31615846497672, 22.021271467208862, 31.425069400242396, 12.253844772066389, 20.49277547427586, 19.17229986190796, 20.240781681878225, 29.34424373081752, 42.390369006565635, 48.87203427723476, 54.12927062170846, 52.43373646054949, 54.96552106312343, 55.53562075751168, 55.61802986689976, 51.5094176019941, 52.30908925192696, 50.99203389031546, 55.53570760999407, 53.113975524902344, 54.13198389325823, 46.06283589771816, 40.03071212768555, 40.0568026133946, 50.59774446487427, 52.98122671672276, 51.947664805821006, 53.24944455283028, 52.65619693483625, 50.742791584559846, 51.52772263118199, 52.2660208429609, 50.42884070532662, 52.341384478977744, 56.60775211879185, 52.48823813029698, 50.57451663698469, 46.73651238850185, 49.43811443873814, 49.81177813666207, 54.80428811482021, 52.136839934757774, 47.276717458452495, 53.485711097717285, 46.67577471051897, 41.78012262071882, 41.91089119229998, 47.31293841770717, 53.174595083509175, 53.57932070323399, 54.34357738494873, 55.09003625597273, 54.63460963112967, 52.34597029004778, 49.20115654809134, 45.238105569567, 42.27630043029785, 41.44282579421997, 39.01539618628365, 37.96709714617048, 42.718285764966694, 53.88590996606009, 51.01231568200247, 53.09383964538574, 50.90590749468122, 52.98842505046299, 50.49537318093436, 51.37526178359985, 51.26783915928432, 50.75797687258039, 51.611656870160786, 49.50577252251761, 49.40073660441807, 40.822407245635986, 36.40165410723005, 26.707183497292654, 23.82805323600769, 15.797365256718226, 14.30472891671317, 31.246740409306117, 24.970446518489293, 27.741820641926356, 24.36300025667463, 16.14300513267517, 13.203193647520882, 14.727386099951607, 4.04011127778462, 3.065759526831763, 1.2268486363547189, 1.6152260133198328, 4.381928775991712, 13.057539428983416, 25.4744827406747, 40.98645421436855, 36.39636652810233, 28.89952428000314, 30.928193296704972, 39.57104710170201, 53.63094234466553, 50.89986603600638, 35.65478181838989, 8.536370056016104, 0.8412466847470829, 0.22025322701249803, 0.10459149801837546, 0.10886514226772956, 0.24168480985930987, 0.21820664325995104, 0.14114855602383614, 0.17665207306189196, 0.10181130255971636, 0.11282641613589865, 0.14884117538375513, 0.17728172641779694, 0.19039422566337244, 0.1489404043448823, 0.10164200807256357, 0.2162316720932722, 0.17477866501680442, 0.10427416754620415, 0.11203552250351224, 0.16603339357035501, 0.17374562259231294, 0.20137589424848557, 0.10924640430935792, 0.14675664795296534, 0.09831574798694678, 0.17565545439720154, 0.059265311275209696, 0.09661996005369083], [0.038608598456318886, 0.03800483799672552, 0.07132878859660455, 0.0446867319489164, 0.05627321611557688, 0.03339422307908535, 0.03101433614002807, 0.02547457268727677, 0.06742297818085977, 0.022782088057803254, 0.028493503906897137, 0.009982993111147411, 0.052655094369713745, 0.05932614193963153, 0.04394741037062236, 0.05865275700177465, 0.022836618524576937, 0.013953937799669802, 0.021944414524893676, 0.06490631215274334, 0.07013610723827567, 0.008869088820314832, 0.05635724249961121, 0.04813428356179169, 0.04865366479914103, 0.03185112927375095, 0.11516674448336874, 0.45806493184396196, 5.940113118716648, 16.354508297783987, 31.033409867967876, 44.75252723693848, 32.77413163866316, 24.333039624350413, 21.183391673224314, 18.119017226355417, 17.355193070002965, 18.00600825037275, 10.443941525050572, 5.298976344721658, 1.8035793006420135, 2.2669370770454407, 4.871907489640372, 3.4181052829538072, 4.197221773011344, 7.626506924629211, 6.726625749043055, 4.086287268570491, 4.4668735436030795, 10.118347202028547, 16.43059628350394, 8.995364580835615, 24.40673221860613, 34.107296398707796, 36.161996841430664, 45.76165928159441, 47.6959787096296, 48.187042645045686, 45.924907207489014, 48.342400891440256, 50.81591442653111, 51.16880301066807, 50.042513915470664, 49.47868149621146, 51.485137122017996, 49.71116474696568, 46.83266156060355, 41.267397676195415, 35.027269159044536, 39.49190017155239, 49.39691856929234, 48.85190534591675, 48.16111544200352, 49.633094787597656, 50.474875995091026, 49.97086756569998, 49.78403050558907, 50.247308594839915, 50.78508526938302, 51.783148833683555, 47.919022832598, 43.79551362991333, 43.65100152151925, 40.41519069671631, 43.7484256880624, 43.47639676502773, 48.95922722135271, 48.9217277935573, 43.299134322575156, 51.39434501102993, 41.211753027779714, 39.363431453704834, 46.58117151260376, 48.797692026410786, 49.56174373626709, 48.24403176988874, 49.89054986408779, 51.97880663190569, 50.97980853489467, 50.158211844308035, 49.96665348325457, 49.458410126822336, 47.274883134024485, 47.2842458316258, 45.69873986925398, 38.801200594220845, 34.51965114048549, 38.90146309988839, 46.139158385140554, 46.8861210005624, 46.89339229038784, 47.02250024250576, 48.33255876813616, 46.9217791557312, 49.67107016699654, 49.26687608446394, 49.28116158076695, 48.29844658715384, 45.90718930108206, 37.56283705575125, 29.85181311198643, 22.220088958740234, 10.719486236572266, 7.292303783552987, 1.1362324016434806, 5.247495838574, 13.836799877030508, 12.546019128390721, 10.001863258225576, 9.264320663043431, 8.42997055394309, 4.226506693022592, 3.090088861329215, 1.4233018947499139, 0.2859887768115316, 0.5915865642683846, 2.3512152518544878, 10.212867890085493, 22.63824544634138, 30.234363555908203, 29.51667717524937, 23.98156326157706, 22.736206361225673, 34.27744388580322, 40.28594030652727, 36.97161831174578, 24.242926699774607, 6.991696919713702, 0.2679361626505852, 0.021471655428675667, 0.03933672081413014, 0.05361076005335365, 0.034534311188118796, 0.043021739327481816, 0.025964865128376653, 0.07181165447192532, 0.031490694864520004, 0.08152677637657949, 0.05418851226568222, 0.04067688515143735, 0.022629020735621452, 0.023622986328388964, 0.04502414366496461, 0.009879531787841447, 0.06590402325881378, 0.039592484411384375, 0.06117363673235689, 0.03169611455606563, 0.05543120165488549, 0.06109490631414311, 0.023719901485102515, 0.047823558628026924, 0.01915668393485248, 0.029393570431108986, 0.02216102834790945, 0.09634877674813781, 0.03151467768475413, 0.019296440096305947, 0.03062431760398405, 0.06112740135618618, 0.0520085013870682, 0.07057298201003245, 0.031174412728952508, 0.026297740837825195, 0.044900799569274695, 0.04276028282142111, 0.028138838741662245, 0.05204214993864298, 0.024762302603838698, 0.07822871620633773, 0.01588088649857257, 0.021329822950065136, 0.03692609623872808, 0.0029857900850142217, 0.007158198393881321, 0.08329995122871228, 0.15325709485581943, 0.03070330247282982, 0.036090853557522805, 0.01115987732607339, 0.01946271849530084, 0.018169695378414223, 0.09446128910141331, 0.5738052012664931, 7.094433418342045, 20.499796628952026, 37.16796398162842, 50.29255526406424, 37.85641929081508, 28.627861874444143, 24.969301802771433, 22.95370408466884, 23.413414273943218, 18.29422995022365, 12.862284626279559, 5.670574690614428, 1.9686194275106703, 1.2019003693546568, 2.8995225727558136, 1.2423335654394967, 3.836925106389182, 8.422463025365557, 10.291905386107308, 9.977852020944868, 10.27959404672895, 9.75526647908347, 15.422539472579956, 12.795575840132576, 21.105154957090104, 30.73055178778512, 38.81417635508946, 47.87195226124355, 49.913701261792866, 49.96702868597848, 48.25663580213274, 52.60448496682303, 53.17817687988281, 51.2891458102635, 51.06684514454433, 49.19791521344866, 52.19979061399187, 52.64013964789254, 46.22444404874529, 43.057691369737896, 35.70529522214617, 42.107886518750874, 52.18762084415981, 51.4246495791844, 49.510598046439036, 51.23567942210606, 52.63633550916399, 49.85732705252511, 50.44626331329346, 51.30110713413784, 52.376424244471956, 52.519466808864046, 49.1998815536499, 46.58772018977574, 45.559629985264365, 42.16191223689488, 45.29005377633231, 46.38463476725987, 51.498720850263325, 50.24334117344448, 46.22462470190865, 52.484635489327566, 43.80754790987287, 42.61215203148978, 45.70747375488281, 51.15816879272461, 51.34118781770979, 51.16550261633736, 50.84075076239449, 53.52071959631783, 51.83034099851336, 52.12995079585484, 51.20971747807094, 51.29580218451363, 49.40239027568272, 50.05385684967041, 46.711380754198345, 40.24970545087542, 36.16828843525478, 42.78176103319441, 48.500715596335276, 49.31729916163853, 50.123241560799734, 49.66702631541661, 50.310797759464805, 50.76867709841047, 49.98709160940987, 48.48456103461129, 49.612632342747276, 49.31540925162179, 46.65702499662127, 39.172265665871755, 30.976743834359304, 22.049828563417705, 12.143541250910078, 7.049800361905779, 5.256613612174988, 9.679355672427587, 14.120961223329816, 16.029242277145386, 14.824759892054967, 9.461540937423706, 8.01467672416142, 4.400663290704999, 3.2050780739103044, 1.584157143320356, 0.34826770637716564, 0.6433594918676785, 2.7067897490092685, 11.989984325000218, 23.554615565708705, 37.09102657863072, 30.446106433868408, 24.75405008452279, 26.921912363597325, 36.63160821369716, 47.11643293925694, 43.23192439760481, 28.169643810817174, 8.902508854866028, 0.37461820670536583, 0.06079541452761207, 0.07118866432990346, 0.076575289214296, 0.042061473176415475, 0.03390617435798049, 0.05874140081661088, 0.07739231323025056, 0.04194235296121665, 0.10308369142668587, 0.0739252164161631, 0.06249409302004746, 0.04600443338443126, 0.016477347617702823, 0.028776700674955333, 0.04084944339202983, 0.04955798573791981, 0.027387844664709907, 0.0015206425658626749, 0.017371777212247252, 0.03973895976586001, 0.0032891069006706986, 0.018959372736779705, 0.06900018533425671, 0.01901109067590109, 0.03428298860256161, 0.02537173391985042, 0.04516771488956042, 0.09597729918147836, 0.12564226665667125, 0.16858222894370556, 0.1238004919141531, 0.10298008591468845, 0.16187208757868835, 0.11060633097908326, 0.091216622851789, 0.14641366207173892, 0.11728230810591153, 0.15456009922283037, 0.09731496990259204, 0.18003211383308682, 0.10970845951565675, 0.16589706231440815, 0.192190823544349, 0.12624002886669977, 0.1272040642797947, 0.09402978832700423, 0.22031369805335999, 0.20831091568938323, 0.10076331200876407, 0.10620958012129579, 0.12666540246989044, 0.17511973742927822, 0.10878375199224267, 0.3624702314180987, 1.2004706689289637, 9.034496835299901, 24.883896282741002, 42.74281985419137, 56.997216020311626, 44.046684060777935, 34.058606897081646, 30.913723673139298, 27.62833571434021, 28.243497950690134, 25.213927030563354, 15.021591935838972, 6.959972747734614, 3.044440282242639, 3.3527835309505463, 9.620611258915492, 7.373232926641192, 11.47389384678432, 17.854306493486675, 17.77750631741115, 14.38792838369097, 11.888202769415718, 20.12563439777919, 25.018649646214076, 11.906143018177577, 29.33480112893241, 37.44198703765869, 41.860989230019705, 50.95868601117815, 50.63128341947283, 52.96712187358311, 50.05583708626883, 53.11036246163504, 54.479300022125244, 53.191906520298545, 50.416736943381174, 48.8022118295942, 51.68685722351074, 54.34563405173165, 49.94983884266445, 46.06805746895926, 37.717750617435996, 45.51555061340332, 53.42942721503121, 53.490359442574636, 50.41476712908064, 51.83337388719831, 54.8341896874564, 51.00325175694057, 51.238847800663535, 50.933665548052105, 53.153962407793315, 54.959913866860525, 51.53846107210432, 47.72009938103812, 47.18622064590454, 45.6038761138916, 48.31706428527832, 48.24462584086827, 54.03392744064331, 52.20977170126778, 49.255057198660715, 55.30978345870972, 46.40711218970162, 43.0890485899789, 51.33290556498936, 54.41043642589024, 52.02482107707432, 54.801144054957796, 53.05280705860683, 53.68909876687186, 52.98754610334124, 52.70151308604649, 53.753067357199534, 52.639048780713765, 51.00431483132498, 52.52144357136318, 50.398136615753174, 41.54397766930716, 38.17244073322841, 43.17624153409685, 49.92418609346662, 51.785542488098145, 51.33687993458339, 51.26718602861677, 53.15572725023542, 51.585920742579866, 50.95838376453945, 48.97581257138933, 50.89698600769043, 49.4108566556658, 48.84508568899972, 41.70956366402762, 37.6238283429827, 30.06436892918178, 16.82602173941476, 12.783137696129934, 8.971954362733022, 10.866157497678484, 25.05918891089303, 17.61872434616089, 18.177178859710693, 18.472244535173687, 17.808868748801096, 10.263303995132446, 4.489373113427844, 3.134269199201039, 0.612117839711053, 1.0893471517733164, 3.7196356058120728, 14.005384019442968, 28.540272883006505, 40.75754581178938, 39.42711169379098, 34.23906898498535, 32.913321426936555, 44.69522891725813, 50.4266277040754, 51.9967086655753, 33.60242986679077, 12.038067596299307, 0.7846492645995957, 0.18439152490879807, 0.13360491581261158, 0.1910187221531357, 0.10761346907487937, 0.11736070604196616, 0.17771411607308046, 0.16495802413140023, 0.15587245380239828, 0.21700275928846427, 0.1687717709158148, 0.14009808882006577, 0.12555200792849064, 0.09564573982996599, 0.10656025380428348, 0.16057424007781915, 0.11054978187062911, 0.18752551531153067, 0.12618901660399778, 0.0755254462627428, 0.12529447674751282, 0.10666879226586648, 0.09738137133951698, 0.16505079343914986, 0.1106888951201524, 0.14821228198707104, 0.08001177052834205, 0.13057847321033478], [0.06406177354178258, 0.02295292112311082, 0.009880046626286847, 0.008984477941079863, 0.023789235889645557, 0.015761369340387837, 0.031161225400865078, 0.07784450932272843, 0.0536723337136209, 0.023774557480854646, 0.04002929811498948, 0.0068650572710404435, 0.033323780966124365, 0.02312434621022216, 0.026043381808059554, 0.02311703160272113, 0.013441177367764925, 0.018496946032558168, 0.05011071018608553, 0.11778400332799979, 0.03745820000767708, 0.03589733876287937, 0.04538464253502233, 0.0461322795599699, 0.02318678330630064, 0.042361375476632795, 0.0411051934185837, 0.3828920455915587, 3.2937653149877275, 14.045183300971985, 33.96972206660679, 39.997739451272146, 33.86976180757795, 25.257641621998378, 19.07273391314915, 26.666335037776403, 26.072649683271134, 15.56972142628261, 11.169750349862234, 4.140134070600782, 1.6095377185514994, 1.6010754640613283, 4.169069843632834, 12.205744130270821, 4.665602879864829, 6.539293195520129, 6.343860345227378, 8.595123154776436, 12.443568808691841, 8.19139199597495, 11.964064938681465, 12.823146292141505, 15.83994208063398, 25.330800942012242, 39.65635708400181, 44.98397520610264, 49.76045874186924, 50.715992382594514, 46.67456224986485, 45.65180131367275, 48.63616377966744, 51.342487130846294, 50.286711829049246, 49.20010389600481, 52.419781003679546, 50.652030740465435, 46.52258777618408, 42.79981940133231, 35.674695355551584, 38.93810442515782, 47.66857154028756, 51.34349461964199, 49.70881278174264, 49.101467268807546, 51.52596473693848, 51.35465342657906, 51.144942896706716, 48.98861115319388, 49.94845962524414, 45.873678139277864, 46.19563681738717, 42.946968351091655, 40.19278580801827, 36.83459636143276, 42.031154087611604, 44.158154010772705, 49.0731429372515, 48.133388655526296, 44.84176295144217, 50.439443656376426, 40.28042343684605, 40.564497062138145, 45.07445464815412, 50.51725305829729, 47.75284971509661, 48.097758293151855, 47.78385952540806, 50.47025544302804, 49.533794607434956, 52.24251856122698, 49.910456453050884, 49.092813287462505, 47.83503648212978, 47.495881012507844, 50.23654930932181, 48.37707240240914, 41.83471461704799, 34.38570029394967, 34.77454580579485, 38.201803820473806, 39.574587208884104, 43.38316583633423, 47.004438400268555, 49.95672450746809, 48.59798690250942, 49.2290153503418, 50.44105216435024, 47.954885959625244, 45.27916247504098, 38.81697300502232, 30.03054162434169, 21.89595549447196, 14.112524373190743, 6.313557079860142, 2.186824998685292, 6.982148792062487, 8.119239296231951, 15.237363031932286, 15.22629281452724, 10.737674014908926, 8.200781617845808, 3.1375248645033156, 3.8658912777900696, 1.0128622502088547, 0.3575436600617, 0.6965301473225866, 2.4145020501954213, 8.409190229007176, 15.487908124923706, 26.110418353761943, 24.452376672199794, 25.7484085219247, 26.800763572965348, 32.73545796530587, 41.520485809871126, 41.69516699654715, 22.331353936876567, 4.351229897567204, 0.2352142184972763, 0.024170219731916274, 0.020263198131163205, 0.020474785706028342, 0.03282597374969295, 0.018312089344752685, 0.02649275180218475, 0.02361354960261711, 0.02145141812174448, 0.031779933986919265, 0.05712458757417543, 0.04163391808313983, 0.05647956879277315, 0.07665892544069461, 0.008431703450956514, 0.022278727032244205, 0.042563137864427905, 0.06007355504802295, 0.04329816770872899, 0.0404730837659112, 0.05207988327103002, 0.03844801296613046, 0.041899483118738444, 0.01956244109065405, 0.0393416096589395, 0.01726205470705671, 0.026692261453717947, 0.041485193385077376, 0.028176098795873777, 0.05841290165803262, 0.018590605917519758, 0.04885013122111559, 0.027438862016424537, 0.053307074920407364, 0.02147511934994587, 0.04056282341480255, 0.01881393214820751, 0.01844770135357976, 0.026782698297340955, 0.011752827874650913, 0.07258451264351606, 0.03927944228053093, 0.03330949780398181, 0.020632702857255936, 0.0715987573244742, 0.028209065419754813, 0.05945365224033594, 0.022977638457502638, 0.05676657214228596, 0.008823009507198418, 0.05172672614987407, 0.03719174948387912, 0.0180064720833408, 0.06294214326356139, 0.04369456108127322, 0.495357867862497, 4.7517171161515375, 17.887147154126847, 39.063324860164094, 46.285167830330984, 38.81174101148333, 30.77290105819702, 22.853545801980154, 29.006491797310964, 26.148362466267177, 20.02585826601301, 12.35880252293178, 4.800910362175532, 2.1896038438592638, 2.5845029737268175, 6.238050137247358, 10.570666245051793, 5.661020483289446, 4.404949460710798, 7.551937988826206, 12.637197732925415, 11.584331120763506, 12.1478282894407, 10.33959434713636, 14.440283060073853, 23.681955201285227, 30.440012863704137, 39.11613116945539, 47.35799053737095, 51.587480613163535, 51.81246675763811, 48.08072478430611, 47.300171102796284, 50.84572219848633, 51.54257093157087, 51.56221696308681, 49.40487773077828, 51.00308847427368, 52.48515313012259, 49.161305155072895, 44.391029834747314, 37.37444359915597, 41.32087448665074, 49.941671235220774, 50.95367635999407, 50.16733135495867, 49.350574084690635, 50.527880328042166, 51.64045715332031, 52.42367199489048, 50.91470043999808, 52.31365769250052, 47.98035110746111, 50.36807870864868, 45.01476614815848, 42.29088817323957, 39.94784096309117, 44.87269285746983, 46.66688796452114, 51.487864289964946, 49.30937474114554, 47.081083978925435, 53.123074190957205, 42.39637919834682, 43.60477863039289, 46.733024392809185, 51.70612110410418, 50.163614068712505, 50.383524554116384, 49.34581456865583, 51.95373405729021, 49.393802302224294, 52.17916488647461, 50.55628456388201, 50.59770277568272, 50.537802355630056, 50.65804440634591, 52.50100197110857, 50.329210485730854, 43.15065826688494, 36.021757875170024, 38.13490309034075, 41.085295813424246, 40.886778831481934, 44.990162576947895, 48.39135789871216, 52.24693414143154, 50.00667858123779, 50.14384644372122, 51.22745622907366, 48.44536624635969, 45.39770221710205, 39.3224127633231, 31.90585000174386, 25.059216703687394, 19.054878779820033, 7.349048852920532, 6.9563349315098355, 13.325925758906774, 12.342502917562213, 16.35484528541565, 14.431117517607552, 18.872889825275966, 10.265471833092825, 8.44159836428506, 6.178757684571402, 2.455955220120294, 0.5874364812459264, 0.8778938725590706, 2.9222420964922224, 9.311764700072152, 19.15396009172712, 29.47178486415318, 30.26275736945016, 29.024982690811157, 29.536274569375173, 38.422141620091026, 45.932525907244, 46.16287606103079, 27.564453976494924, 6.652405525956835, 0.35440543560045107, 0.0502055558109922, 0.0764347713972841, 0.04016404499166778, 0.07628879815872226, 0.025254349057961787, 0.03649040890325393, 0.02162481435308499, 0.02724551685553576, 0.0484396141421582, 0.013059885640229498, 0.003252135223842093, 0.03628312663308211, 0.047437587553369145, 0.057034708825605254, 0.03302702706839357, 0.0476225087020014, 0.06279081638370242, 0.04176102465550814, 0.011528645841670888, 0.04782341613567301, 0.02765067690052092, 0.04030469851568341, 0.03570391896313854, 0.034619687856840234, 0.06792249530553818, 0.03492445186046617, 0.019163961222927486, 0.1065447289230568, 0.1605255619755813, 0.08247893064149789, 0.19502610926117214, 0.12113669913794313, 0.10088253739689078, 0.062240510912878175, 0.14048623799213342, 0.23172988689371518, 0.11989595714424338, 0.07953423115291766, 0.13974139653146267, 0.16702001062887056, 0.1376863718032837, 0.1317504524652447, 0.09821531801883664, 0.11399392384503569, 0.08577477200222866, 0.11554110582385745, 0.18302556606275694, 0.15483141823538712, 0.16343711502850056, 0.12175464097942625, 0.10097017019454922, 0.09109481224524123, 0.16027066351047584, 0.13700894958206586, 0.8704725450703076, 5.815292639391763, 22.88759892327445, 46.105570793151855, 51.20526020867484, 43.548050062997, 35.255840573992046, 28.72409095082964, 38.64281293324062, 37.463634150368826, 23.55693105288914, 15.277245691844396, 5.36267569235393, 2.4983338032449995, 2.411244864974703, 6.488661672387805, 15.938471010753087, 16.27451021330697, 14.841143744332449, 14.450431772640773, 19.065860407693044, 25.40971337045942, 14.514562777110509, 19.916775022234233, 17.045282568250382, 20.327243328094482, 29.286552837916783, 42.67113528932844, 48.68785490308489, 54.158536434173584, 54.60045576095581, 51.015035901750835, 49.1307122366769, 52.48348903656006, 52.81677327837263, 51.90408917835781, 48.59737893513271, 52.27215262821743, 54.02190358298165, 49.96830368041992, 46.411576407296316, 39.25260421207973, 43.800387791224885, 53.083045618874685, 53.43234198434012, 50.68620892933437, 48.62422330038888, 50.099763597760884, 52.190789222717285, 54.044752734048025, 53.98968826021467, 55.587061745779856, 49.936904770987375, 52.26908499853951, 46.36505821772984, 44.72359146390642, 42.013283320835654, 46.32756921223232, 49.02065624509539, 53.41846990585327, 51.24752957480294, 49.30786003385271, 55.34959316253662, 44.55637959071568, 45.18114423751831, 49.17695597239903, 54.28428840637207, 52.368357385907856, 52.6095814704895, 49.32298278808594, 52.513411453792024, 49.092667375292095, 52.441355160304475, 49.614577838352744, 51.50195523670742, 51.81288364955357, 50.5173225402832, 53.41958161762783, 51.98603623253958, 46.33822774887085, 38.86111838476998, 39.09377186638968, 41.43115282058716, 42.628219740731375, 47.92023876735142, 51.84540121895926, 54.29339402062552, 51.440425464085166, 50.425404821123394, 50.869325229099815, 49.571172441755024, 47.221757207598, 40.39779588154384, 34.67684718540737, 25.563812255859375, 18.718978541237966, 9.273806691169739, 6.290847327028002, 12.734277963638306, 15.013474702835083, 25.73315896306719, 24.88727137020656, 17.181222336632864, 14.986244712557111, 6.331107795238495, 9.736791219030108, 3.6108578656400954, 0.5905633877430643, 1.4640114988599504, 3.5261975399085452, 11.270035437175206, 20.998989956719534, 34.77778019223894, 35.48416880198887, 36.74136890683855, 37.0437718800136, 44.43329572677612, 54.36952543258667, 52.88380602427891, 31.67230715070452, 9.413514120238167, 0.8828845247626305, 0.0835286650274481, 0.14454463736287185, 0.2458851858973503, 0.17906631422894342, 0.07111036817410163, 0.06945870537310839, 0.09627587494573422, 0.08088082460952656, 0.13558260111936501, 0.13880070272300923, 0.14283642545342445, 0.15614606626331806, 0.16048452417765344, 0.21774742433003016, 0.13786678069404193, 0.1551006609307868, 0.15671129950455256, 0.11049816571176052, 0.10709336519773517, 0.13435552482094082, 0.15842929588896887, 0.17005878899778637, 0.08779166306235961, 0.13941540116710321, 0.1100720525053995, 0.1495292777461665, 0.11521983306322779], [0.027273996666605984, 0.03845320375902312, 0.02587499825416931, 0.03338215872645378, 0.05835561973175832, 0.04021787317469716, 0.02260697174019047, 0.07868716160633735, 0.03055459473814283, 0.01869655237533152, 0.010654707156520869, 0.07986013152237449, 0.015277231211907097, 0.05379551835358143, 0.020963269851303527, 0.03184586384200624, 0.019297710653128367, 0.05354693026414939, 0.0427284086389201, 0.021828917686694434, 0.04032717838085123, 0.03521428809368184, 0.03989442231665764, 0.04295773311917271, 0.034462885199380774, 0.04892936036256807, 0.015913924368630563, 0.25485023483633995, 3.679942284311567, 12.902982831001282, 35.26707928521292, 40.168359415871755, 25.787438290459768, 21.163175889423915, 20.770939656666346, 22.685663427625382, 16.04772969654628, 10.574847323553902, 12.340657302311488, 4.383172069277082, 0.769393571785518, 0.12222171734486308, 0.1803493153836046, 0.4421740488282272, 5.022044599056244, 3.765227947916303, 7.987332957131522, 8.880222507885524, 5.795123755931854, 8.839147363390241, 10.53151227746691, 15.327387366976057, 20.535835197993688, 25.12496403285435, 34.27033587864467, 45.11856181280953, 47.293104784829275, 50.351899828229634, 47.64224828992571, 47.13488735471453, 46.42086614881243, 48.23195580073765, 50.86191150120327, 49.17320394515991, 49.043335165296284, 51.391082831791465, 48.325308322906494, 43.76016814368111, 36.094074726104736, 40.97218261446272, 47.32567793982369, 50.33242402757917, 50.04308714185442, 50.80536011287144, 53.34921721049717, 49.91611576080322, 46.942095688411165, 44.374058859688894, 44.137615135737825, 44.26155015400478, 41.23226063592093, 36.80756092071533, 36.66053703853062, 36.12098509924752, 42.545581340789795, 43.87706811087472, 50.67036008834839, 43.981016635894775, 42.7397244317191, 49.78757756096976, 41.06963457380022, 40.91176802771432, 41.51656355176653, 47.4430364881243, 46.95090600422451, 51.22782448359898, 50.97332239151001, 51.00817802974156, 50.219960485185894, 51.04653903416225, 50.17289686203003, 50.03226184844971, 48.6420384815761, 50.74470928737095, 50.74678332465035, 49.10973909923008, 47.43269062042236, 43.2502224785941, 36.69762652260916, 35.971619674137656, 39.76448147637503, 45.536666188921245, 47.91506930759975, 52.458333083561485, 47.428643294743125, 48.617441858564106, 46.41377898624965, 47.85024608884539, 44.53086927958897, 40.72005680629185, 26.792575120925903, 22.0056380203792, 13.864544034004211, 5.939300613743918, 10.593546663011823, 18.08041477203369, 12.834540469305855, 16.862044675009592, 13.273267098835536, 18.835239274161204, 7.145475319453648, 9.018150329589844, 3.1009866765567233, 1.7728900845561708, 0.6582346622432981, 0.2381966241768428, 2.0783149812902724, 7.956285800252642, 16.183005911963328, 30.820009844643728, 26.79073211124965, 22.824024643216813, 31.011012349809917, 29.447264671325684, 40.8478376524789, 38.069701194763184, 24.937555483409337, 7.142496279307774, 0.4386830675814833, 0.05853428478751864, 0.03134203462728432, 0.05508374083521111, 0.016624922198908668, 0.018367600294628313, 0.009084490610153546, 0.02007236354984343, 0.006123992281832865, 0.04408383322879672, 0.06301159132272005, 0.026454555369647484, 0.03970588457637599, 0.044427083738680394, 0.02698040983107473, 0.0646894523607833, 0.0870256716651576, 0.023929696031180874, 0.006743386612340275, 0.03555303991639188, 0.0841381862493498, 0.01134567124037338, 0.03774264867284468, 0.040432941634207964, 0.03656710371641176, 0.008031028522444623, 0.025593239980350648, 0.022812506782689264, 0.06431477210883584, 0.047623601143381426, 0.029041597353560582, 0.04134568997791835, 0.02193706259796662, 0.06483291501977614, 0.02579453757165798, 0.04946701115529452, 0.05765902211091348, 0.03347821892904384, 0.02376967542139547, 0.03505315299012831, 0.09722279770565884, 0.08058298166309084, 0.03423963360754507, 0.07757765507059437, 0.0331471481227449, 0.042908515581595044, 0.07707232290080615, 0.03340524588046329, 0.07224323667053666, 0.0369607286660799, 0.04226405659158315, 0.06927250857864108, 0.044748783976371796, 0.06468937093658106, 0.09335490382675614, 0.3876356839069298, 4.161904513835907, 15.705006326947894, 41.52794122695923, 44.22234494345528, 30.894939218248638, 23.473238263811382, 23.436812332698278, 30.013716561453684, 23.226426090512955, 13.359379598072596, 13.037339278629847, 5.094976365566254, 0.9768900147506169, 0.02810342430270144, 0.34837472492030686, 2.4019674999373297, 8.975524868283953, 4.897973656654358, 8.711487242153712, 10.284263236182076, 13.928084441593715, 8.484061411448888, 10.704538055828639, 16.712201561246598, 20.243764196123394, 28.955128976276942, 35.7619925226484, 45.71103123256138, 48.83055353164673, 50.853841168539866, 49.94429765428816, 49.29379687990461, 48.65320423671177, 51.31785576684134, 51.095086097717285, 51.037356989724294, 49.31613186427525, 51.8849538394383, 49.33720575060163, 45.75794199534825, 38.37567554201399, 42.486643246241975, 49.15539223807198, 52.092131750924246, 50.51107610974993, 51.168146405901226, 53.20694589614868, 50.2040456363133, 49.27991785321917, 45.57115009852818, 47.618815490177695, 46.363091877528596, 43.52854299545288, 38.62635612487793, 39.20507853371756, 39.28599725450788, 43.4097809110369, 46.98135648454939, 52.211102281297954, 46.022414752415244, 44.45855242865426, 52.0528883252825, 44.16655785696847, 42.0877228464399, 44.95643949508667, 48.81355128969465, 48.60866975784302, 52.25020326886858, 51.43886906760079, 52.77118962151663, 50.881488050733296, 51.46858998707363, 50.28822306224278, 49.202205726078574, 48.52556235449654, 50.98062147412981, 51.05278546469552, 52.379682949611116, 49.60469402585711, 43.65185267584664, 37.80927923747471, 37.5245246887207, 41.5625502041408, 46.459689208439414, 49.93639407839094, 53.23250831876482, 48.53995902197701, 48.432310581207275, 47.713109493255615, 49.78623308454241, 45.51914978027344, 40.62966769082205, 29.143826416560582, 26.8368855203901, 17.420221260615758, 5.8149804047175815, 11.495987381253924, 12.450107063565936, 12.24301426751273, 16.701351949146815, 13.84814020565578, 13.235566173280988, 11.26552518776485, 11.158127750669207, 5.170647459370749, 1.7491655690329415, 0.7366052940487862, 1.134840047785214, 1.9806593528815677, 10.365631852831159, 17.52904220989772, 32.970244543892996, 28.21663621493748, 30.137536934443883, 36.08744267054966, 35.342029503413606, 45.424786295209614, 43.781273296901155, 26.468976667949132, 8.016758578164236, 0.5714621384228978, 0.04501936338575823, 0.016930369826565896, 0.031866755935230424, 0.009770218099999641, 0.03888742885153208, 0.06521769865815129, 0.02483956908274974, 0.0857495033581342, 0.07788907550275326, 0.07944868145776646, 0.011743514981519963, 0.04641399712168744, 0.016532471802617823, 0.046679721613015444, 0.05935242838625397, 0.06806591725242989, 0.052650907808648686, 0.03377522049205644, 0.10014952958694526, 0.022495992248877883, 0.07428009701626641, 0.02341440466365644, 0.0276139885120626, 0.018826590218980397, 0.03542149233232651, 0.08071906186108078, 0.026482996164954135, 0.10624826340270893, 0.12315965630114079, 0.11534903970147882, 0.175211312515395, 0.1529008232589279, 0.1191458095397268, 0.10307596969817366, 0.24805926637990133, 0.14441233660493577, 0.11726116495473043, 0.0952686575640525, 0.10982533038726874, 0.1497262700327805, 0.19888888698603424, 0.1099575429356524, 0.20308741740882397, 0.09607117450130837, 0.17812198347279004, 0.17369531600603036, 0.10896645433136395, 0.11438401362725667, 0.14092523657849856, 0.1165916273104293, 0.20898376458457538, 0.10818846643503223, 0.14870857607041085, 0.11352496115224701, 0.5732222039784703, 5.7253903320857455, 20.27307517187936, 47.16664409637451, 50.871496541159495, 35.43633392878941, 30.900716645377024, 30.09007031576974, 34.543268067496165, 26.340325559888566, 17.891606160572596, 16.83254783494132, 6.450118277754102, 1.513819660459246, 0.20091307908296585, 0.38028619970594135, 1.894607650382178, 9.235098276819501, 11.966554130826678, 18.855324779238018, 19.584944690976823, 16.402820859636577, 16.510401555470057, 18.11261793545314, 18.451104640960693, 24.97502190726144, 28.292522702898296, 37.47946562085833, 47.407902921949116, 48.32511029924665, 53.43891498020717, 51.61080918993269, 51.62549768175398, 50.71344239371163, 52.224189213344026, 53.36316919326782, 50.28594405310494, 48.79220642362322, 54.81211873463222, 53.18341929571969, 49.36898333685738, 39.8930926322937, 44.81849690846035, 51.54454074587141, 53.45508691242763, 50.03969989504133, 53.40659543446132, 56.218736376081196, 53.23494366237095, 51.02432911736624, 48.26502922603062, 49.82192598070417, 48.90734154837472, 44.39722415379116, 40.5533104624067, 40.74664061410086, 40.41005597795759, 44.87449244090489, 49.67643765040806, 53.85697419302804, 49.02637808663504, 47.00406319754464, 53.44664832523891, 46.09468991415841, 45.00134917667934, 46.466953550066265, 53.04526478903634, 51.91910423551287, 55.165486744471956, 54.33948837007795, 55.96023212160383, 53.55264656884329, 53.23673282350813, 51.19510541643415, 51.00901876177107, 50.340692383902415, 52.03757796968733, 52.67239318575178, 54.0165638923645, 51.71469865526472, 47.02856254577637, 40.28331388745989, 39.71859557288033, 44.56714929853167, 50.2470897265843, 51.792264870234895, 54.60127912248884, 49.70831945964268, 48.11983272007534, 47.35102844238281, 50.223580496651785, 45.543541431427, 42.661578042166575, 28.890178952898296, 24.937730925423757, 16.90873830659049, 9.800673825400215, 16.588970048086985, 23.284273317881993, 18.665272440229142, 23.818836450576782, 19.454827513013566, 29.50316640308925, 15.00542868886675, 19.143317188535416, 8.231141771589007, 3.5633586772850583, 1.2832339193139757, 1.1240982413291931, 2.9092895686626434, 11.045762351581029, 20.770350796835764, 38.933188574654714, 35.752574239458355, 35.29250969205584, 40.64406435830252, 42.415941851479666, 52.84186669758388, 50.6248493875776, 33.93118040902274, 10.863181063107081, 1.1800245089190347, 0.1592215805181435, 0.08580850197800569, 0.12352474885327475, 0.11971230485609599, 0.1403674536517688, 0.13863789503063473, 0.10090674752635614, 0.12257706613412925, 0.14402523237679685, 0.16951825443123067, 0.13239322868841036, 0.21673965054963315, 0.19525913175727638, 0.08966992263283048, 0.20726175127284868, 0.1511323574398245, 0.11095510476401874, 0.09966472310147115, 0.2912473146404539, 0.16300316474267415, 0.15012256162507193, 0.10030570120683738, 0.1173452218728406, 0.13435608121965611, 0.09935201345277683, 0.14312293007969856, 0.1134945967101625], [0.02928677580452391, 0.03289822755115373, 0.030585854846451963, 0.037696942553988526, 0.006694365001749247, 0.0702517024640526, 0.035001984664372036, 0.03739991724225027, 0.053907602160636864, 0.013819694735242851, 0.024423425252150213, 0.038774608833981414, 0.04704782007528203, 0.10893066839448043, 0.022905457598556365, 0.06428027538848774, 0.02098833323855485, 0.02020902050259922, 0.02787979782026793, 0.036801106695617945, 0.018170180530952554, 0.021252697267170464, 0.058203858589487414, 0.04815771337598562, 0.06434363698852913, 0.059997036653969965, 0.070692892718528, 0.02927515928500465, 2.261029371193477, 11.427568469728742, 35.08128098079136, 44.81949397495815, 41.3167542048863, 32.24497767857143, 17.584914411817277, 14.989967209952217, 20.236315727233887, 20.58885169029236, 9.924553258078438, 4.377619590078082, 1.0684751974684852, 0.29195057547518183, 0.3318077496119908, 1.9656314849853516, 3.362435881580625, 2.714483141899109, 6.060128918715885, 12.715376257896423, 13.064022966793605, 10.355926956449236, 7.354872311864581, 13.367368289402553, 22.547196252005442, 25.93842438289097, 32.74492488588606, 41.42474658148629, 46.570790903908865, 50.392126423971995, 50.77798073632376, 47.620194707598, 44.8633371080671, 46.796096665518625, 47.377657413482666, 50.150871072496685, 49.84685264314924, 51.290597983769004, 49.63460602079119, 44.14421592439924, 39.05431652069092, 42.92921570369175, 46.50390059607369, 49.46966620853969, 50.33807986123221, 50.20117950439453, 46.49600396837507, 44.589022227696006, 42.93346105303083, 42.120629514966694, 42.54677990504673, 38.611584254673545, 37.27293389184134, 35.27146012442452, 36.18207713535854, 35.96416425704956, 42.18146794182913, 44.070627553122385, 50.788170269557405, 42.437800884246826, 40.715370246342246, 50.107420512608115, 41.58331142153059, 40.63372891289847, 38.136084284101216, 42.648619651794434, 43.91592591149466, 44.782984665461946, 45.33993141991751, 46.273807525634766, 46.58843238013131, 49.22866446631295, 49.247122355869834, 48.87220450810024, 47.70685264042446, 47.775594643184114, 47.56130525044033, 49.839299951280864, 48.78146798270089, 46.45107691628592, 43.384534631456646, 40.977112361363, 43.92485087258475, 44.73482322692871, 51.81898764201573, 48.44498756953648, 47.460090841565815, 48.77768816266741, 48.66368212018694, 47.34124885286604, 46.48274333136422, 39.88964285169329, 33.03928184509277, 34.374840259552, 24.1111958026886, 8.514254808425903, 12.674167360578265, 14.56975405556815, 15.740396976470947, 14.437347446169172, 11.463071158954076, 15.159643956593104, 10.305471743856158, 13.411610943930489, 5.3068282433918545, 1.3297021687030792, 0.9024025574326515, 0.8519771460975919, 1.5120872791324342, 6.853227138519287, 17.268328428268433, 26.671405485698156, 28.19458784375872, 20.36907843181065, 17.159971271242412, 28.792862483433314, 38.69334370749337, 40.371222496032715, 21.463181734085083, 7.398620775767735, 0.4231791395161833, 0.06601178140512534, 0.028857093503964797, 0.030309667345136404, 0.038865678411509307, 0.008505576406605542, 0.04077392922980445, 0.0051144721219316125, 0.059105733409523964, 0.03852287573473794, 0.06770603584923915, 0.014150329582792307, 0.035630345411066494, 0.046455906837114265, 0.06283804920635053, 0.02362246555276215, 0.03878373512998223, 0.017588036500715783, 0.022325793613812754, 0.05490010551043919, 0.05927325013492789, 0.010843677462876906, 0.01173377885217113, 0.007382502563164702, 0.03002313557746155, 0.05417353021247046, 0.04092526968036379, 0.047406890629125495, 0.05335610925352999, 0.05782920547894069, 0.03457386299435582, 0.009585843172057398, 0.012717504503338464, 0.03275215931768928, 0.035607282005782635, 0.06978671598647322, 0.018861650123393962, 0.1125516840921981, 0.015415068815595337, 0.011074206342787614, 0.058930257468351295, 0.06356482806482486, 0.03376140212640166, 0.03625182920534696, 0.007969577846649503, 0.036251720639743974, 0.03342638224629419, 0.03516362188383937, 0.02336580628928329, 0.01892462495847472, 0.06795389790620122, 0.060427404274897914, 0.037617540386106284, 0.012194133480079472, 0.09609237193529095, 0.09349034620182854, 2.9371844146932875, 14.748880352292742, 38.440554346357075, 51.56513868059431, 41.73196465628487, 33.84507138388497, 23.244772808892385, 19.67670260156904, 19.92693328857422, 22.810256787708827, 12.494030100958687, 4.74660324198859, 1.027956017426082, 0.1750099097511598, 0.6040357819625309, 1.8938292350087846, 4.944715925625392, 5.519104395593915, 8.254293169294085, 12.918823855263845, 13.150426421846662, 11.392441851752144, 10.658671259880066, 13.11932281085423, 18.525368724550518, 30.466700894492014, 34.402257851191926, 44.08650071280343, 48.31012303488595, 51.49410377229963, 52.55551406315395, 48.470966884068076, 46.872148173195974, 49.57799557277134, 50.55273750850132, 51.17236396244594, 50.65192304338728, 51.41477966308594, 52.1547315461295, 46.87938124792916, 40.89834063393729, 45.12165723528181, 47.83854879651751, 51.62297548566546, 49.27843788691929, 51.23139238357544, 50.52690063204084, 46.87662628718785, 45.74079384122576, 44.252722467694966, 44.49623250961304, 40.63360037122454, 39.804787976401194, 36.05704777581351, 37.81275681086949, 37.988382952553884, 44.205266271318706, 45.67672102791922, 52.02740233285086, 43.82406725202288, 44.53829342978341, 51.363738196236746, 42.067402839660645, 43.304449694497244, 39.042813777923584, 45.1617865562439, 46.07659680502755, 48.34210211890084, 47.81509862627302, 48.70809153148106, 49.122742652893066, 51.64603655678885, 51.229533740452354, 50.01336622238159, 49.86565446853638, 47.786117689950125, 47.72570310320173, 50.14067459106445, 51.65650054386684, 48.201105798993794, 45.290248325892854, 43.160705362047466, 44.587486675807405, 47.323332922799246, 53.05260903494698, 49.78456204278128, 48.25625017711094, 49.580750533512656, 47.98917531967163, 47.995942865099224, 47.31130559103829, 40.879472800663535, 33.28861795152937, 28.782370703560964, 20.14548019000462, 14.242251583508082, 14.76392320224217, 14.594100543430873, 7.641874602862766, 13.085763011659894, 13.207315666334969, 13.112026333808899, 8.778764912060328, 10.179372361728124, 5.552500477858952, 2.2264249537672316, 0.9093145493950162, 0.44976251306278364, 1.6743894900594438, 8.194678493908473, 18.83805329459054, 30.65196418762207, 33.36812271390642, 23.316422632762364, 21.873575346810476, 33.971910749162944, 44.0884427343096, 44.82101215635027, 26.18093041011265, 9.427535584994725, 0.8246840249214853, 0.05705700548631804, 0.0237106479637857, 0.035897606784211736, 0.023229381734771386, 0.026095020019316247, 0.0037705113811950597, 0.026718910916575363, 0.009530775814450212, 0.017054672352969646, 0.096511245173003, 0.032545165424900394, 0.05551082434664879, 0.035249897611460516, 0.032864826664860756, 0.07644273739840303, 0.0186611447217209, 0.009545205709790545, 0.011564218888192304, 0.06176366364317281, 0.07919543183275632, 0.023154520662501454, 0.04081751831940242, 0.03273693299187081, 0.04592211012329374, 0.043008806450026374, 0.019364525996414677, 0.05564216158485838, 0.16401925736239978, 0.12376381031104497, 0.13552742265164852, 0.07764789023037467, 0.15825416600065573, 0.13925086999578135, 0.177603012749127, 0.17415693694991724, 0.14687335597617285, 0.27751441725662773, 0.08213441805647952, 0.12987070690308297, 0.12850872427225113, 0.2808918117412499, 0.10731688141822815, 0.18694832628326757, 0.12887549959123135, 0.11490031092294625, 0.0758624542504549, 0.09301224364233868, 0.10464453231543303, 0.0961222681882126, 0.1851468700915575, 0.14171647626374448, 0.08360324281134776, 0.1702273235257183, 0.16940791106649808, 0.20180874530758175, 4.074540036065238, 20.398507526942662, 47.02879531042916, 56.116886207035606, 51.73610258102417, 41.605215617588584, 28.21674738611494, 24.72609053339277, 31.242713928222656, 29.245846816471644, 13.993401850972857, 5.896229599203382, 1.660707835640226, 0.5808799873505319, 1.3336616648094994, 3.92532616853714, 6.18827280827931, 7.122326527323041, 8.925782714571271, 17.041282142911637, 18.89155616079058, 15.563758134841919, 13.351227624075753, 17.17838052340916, 26.079914024897985, 29.655349322727748, 35.88112980978829, 43.15373631886074, 48.29845353535244, 52.22844845908028, 54.084260191236226, 50.99313170569283, 48.40373958860125, 50.37891789845058, 52.75273173195975, 52.64432941164289, 52.79163122177124, 53.882425444466726, 52.448866162981304, 47.14513594763619, 42.824857234954834, 48.349147592272075, 51.078914165496826, 51.60606357029506, 50.439763273511616, 53.138408865247456, 51.89946167809622, 48.46911518914359, 47.91216148648943, 46.91502203260149, 46.019819600241526, 42.315995488848, 40.544423716408865, 38.6151556287493, 40.05883148738316, 40.25257158279419, 46.29692765644619, 48.305575438908164, 55.04636335372925, 46.79762526920864, 46.61260863712856, 52.956706523895264, 44.750536578042166, 46.05268457957676, 41.865793909345356, 48.04816205160958, 48.55091980525425, 49.52307006290981, 49.06662205287388, 51.10556745529175, 51.46631792613438, 53.71333408355713, 53.960839339665, 51.482006958552766, 50.63800927570888, 48.961836269923616, 47.257543904440745, 51.324487822396414, 53.33640820639474, 50.845701353890554, 47.926478249686106, 45.24313259124756, 47.620153018406455, 49.26651477813721, 55.72309357779366, 50.99166216169085, 49.42641019821167, 48.93558250154768, 48.759737491607666, 47.24156304768154, 47.73153264181954, 42.50882189614432, 38.072737557547434, 37.18794700077602, 28.047381571360997, 13.000767435346331, 19.940916538238525, 25.835148096084595, 27.808125564030238, 20.212535517556326, 22.76092110361372, 23.24110589708601, 18.29901899610247, 22.911896773747035, 10.10562070778438, 2.305602499416896, 1.8326236392770494, 1.7342546262911387, 2.198747890336173, 10.14392786366599, 22.13478418758937, 35.91622863497053, 38.336640562329976, 30.296348435538157, 25.85269750867571, 40.05453402655465, 50.47883994238717, 51.64251382010323, 31.10686274937221, 11.410896267209734, 1.201624395591872, 0.22167113449956688, 0.15298441877322538, 0.10417250942971025, 0.1980994657746383, 0.09164009655692748, 0.07700328196265868, 0.12435090595058032, 0.1351220929729087, 0.11710732749530248, 0.13125778175890446, 0.1603897056941475, 0.09348174916314227, 0.15440357476472855, 0.15844095312058926, 0.10262862513107912, 0.12146695570221969, 0.10097838046827487, 0.12385796383023262, 0.20245462922113283, 0.1487248744815588, 0.150168919137546, 0.1122069408052734, 0.1006799064842718, 0.10876935347914696, 0.15395616234413215, 0.14383913736258233, 0.13861114718019962], [0.0403680126182735, 0.039885672607592175, 0.04344158287027052, 0.0877281046871628, 0.04049244576266833, 0.014063539016725761, 0.023551741847768426, 0.03291860056508865, 0.028626703723732914, 0.024100566415914466, 0.055553558482123275, 0.06661140280110495, 0.028506416428302015, 0.016617232700809836, 0.059840077933456214, 0.02563115142818008, 0.04371662364740457, 0.04579576351014631, 0.03510503377765417, 0.024969647638499737, 0.03478094509669712, 0.04221072034644229, 0.037296650997762165, 0.016545640470992242, 0.06032041287315743, 0.037150189213986905, 0.05431504886863487, 0.013133326877972909, 2.229595720767975, 12.637587700571332, 34.22288315636771, 42.9063526562282, 36.14410523005894, 19.950532845088414, 17.116253205708094, 15.62098697253636, 19.825442688805715, 13.102661899157933, 8.847750970295497, 4.258929593222482, 0.6105736025742122, 0.1938408442905971, 0.13610003835388593, 2.087354804788317, 3.1360640057495663, 3.722920366695949, 10.05019405909947, 9.737793496676854, 14.691620247704641, 8.936755657196045, 10.699898396219526, 10.45160104547228, 8.51802681173597, 28.550841093063354, 28.724704129355295, 41.60032408578055, 46.48255920410156, 52.246211528778076, 48.21483891350882, 50.512754099709646, 47.295088495527, 47.411543778010774, 45.73135123934065, 46.87306186131069, 47.33709035600935, 49.337334292275564, 48.28605100086757, 44.86636652265276, 43.170728138514924, 46.06327363422939, 48.91452598571777, 51.8912593296596, 49.703486987522666, 48.85743611199515, 43.494100775037495, 43.078674929482595, 40.74233967917306, 38.37238209588187, 35.835584368024556, 35.885156290871755, 35.099599906376426, 34.30630670275007, 35.98577315466744, 35.674445220402305, 41.46984386444092, 46.1573418208531, 49.60038266863142, 45.65986122403826, 41.327002797807964, 51.46090875353132, 44.80500003269741, 41.16492216927664, 37.87063877923148, 40.77422843660627, 38.80512285232544, 44.83840349742344, 42.07706083570208, 43.36590651103428, 43.99201216016497, 45.9993953704834, 43.247262545994346, 46.56682000841413, 47.156082834516255, 49.396616322653635, 45.955708571842735, 47.14950636454991, 49.550411224365234, 49.76796974454607, 46.1361254964556, 46.055422169821604, 45.47839164733887, 49.055348600660054, 49.67342560631888, 45.71759033203125, 47.599412645612446, 47.92513377325875, 46.99978310721261, 49.14228098733084, 47.121814319065635, 43.182821478162495, 32.43492405755179, 26.692347356251307, 22.15307010923113, 12.625880854470388, 14.847195625305176, 8.34451379094805, 4.42921951838902, 15.891831227711268, 13.044315270015172, 7.2645266226359775, 8.043792281832014, 5.421979001590183, 3.6550043310437883, 3.4173950467790877, 0.7020217212183135, 0.5697568442140306, 1.4489125204937798, 6.2442930936813354, 13.703310217176165, 26.01119112968445, 28.572851249149867, 25.7884909425463, 27.5567466872079, 33.71814169202532, 43.34526341302054, 37.662467275347026, 21.910760368619645, 5.153222245829446, 0.46060026437044144, 0.039278390551252026, 0.0333128192328981, 0.022108643748132244, 0.016013090565268482, 0.03829322216500129, 0.05266112654602953, 0.038870244952184815, 0.01496395668280976, 0.013279258556264852, 0.009135979543706136, 0.015991560649126768, 0.02190689493103751, 0.032956754589187245, 0.030975971770073687, 0.04386308882385492, 0.06467756442725658, 0.029009974229016473, 0.012353904728245522, 0.01805721632471042, 0.031393416691571474, 0.08016945528132574, 0.08610411932958023, 0.054281661553042274, 0.020873285929805467, 0.01673941480528031, 0.008876009877505047, 0.0830339180039508, 0.0262926178984344, 0.06136126523571355, 0.052641771334622584, 0.11660692148974963, 0.037693139365209, 0.015207844220900109, 0.07155890696282897, 0.05341116219226803, 0.02405367116443813, 0.03320584479453308, 0.044411765810634406, 0.024473236507869194, 0.041827371809631586, 0.03586004308557936, 0.03421826993248292, 0.0383715827816299, 0.02738266913885517, 0.029569551880870546, 0.01969162737285452, 0.0407566842623055, 0.022879685142210553, 0.0373582857261811, 0.022368354722857475, 0.05474199667306883, 0.018165330701906766, 0.03139097396550434, 0.02677852361063872, 0.009787928712155138, 2.679185207401003, 15.322382926940918, 40.60114533560616, 47.026391233716694, 43.25627088546753, 26.915156977517263, 20.040110758372716, 16.859402622495377, 28.469387360981532, 19.3074631690979, 10.32702852998461, 5.428728307996478, 0.5295174377305167, 0.1217115947178432, 0.46194132098129814, 3.767334989139012, 7.729048439434596, 8.180602312088013, 12.470569508416311, 12.084747331483022, 10.539376769747053, 9.718812755176, 10.546384028026036, 13.290139062064034, 15.972065550940377, 30.345336709703716, 32.719306877681184, 40.17262213570731, 47.14369419642857, 50.91256734303066, 50.518402985164094, 51.8213152885437, 48.26096452985491, 48.26841647284371, 46.9552903175354, 48.72746310915266, 49.749560492379324, 50.52214806420462, 49.841231550489155, 45.067978927067344, 44.8747147832598, 47.30370773587908, 50.32716424124581, 50.98340770176479, 51.016536712646484, 51.95916060038975, 45.16397871289934, 46.09712873186384, 42.96555478232247, 40.06078045708792, 38.18738978249686, 37.11504997525896, 35.26452929633004, 36.68973684310913, 37.01358543123518, 37.47040516989571, 44.1181879724775, 47.85778488431658, 51.344022682734895, 47.55069882529122, 43.68577378136771, 52.20371982029506, 45.696165561676025, 42.86404160090855, 39.59815549850464, 41.69370787484305, 41.149052483694895, 46.83567360469273, 45.79174845559256, 45.73588841302054, 46.43781975337437, 47.36712047031948, 45.073408944266184, 48.00145626068115, 48.397159644535606, 49.77366379329136, 46.50140271868025, 48.218316486903596, 50.79731062480381, 50.94057553155081, 47.339574337005615, 48.56188753673008, 47.85187891551426, 51.28308698109218, 50.909843649183, 47.48157467160906, 47.191025325230186, 48.670810971941265, 47.991999762398855, 49.61197921207973, 47.04294531685965, 43.85833576747349, 34.15314756120954, 27.90182375907898, 20.574927500316075, 14.731367417744227, 9.863352656364441, 11.866024119513375, 11.861496499606542, 12.898309298924037, 6.902697009699685, 9.412965212549482, 11.302675468581063, 8.30757108756474, 6.795989615576608, 1.7514757364988327, 0.8442495550428117, 0.5878181436232158, 1.942536324262619, 6.589173010417393, 16.804718562534877, 28.37333025251116, 30.949934210096085, 30.12250450679234, 30.516825199127197, 36.2877870287214, 48.97402688435146, 43.248402050563264, 25.818647861480713, 6.883985076631818, 0.6492332166859082, 0.0021659798346393344, 0.02060896430962852, 0.044295872029449256, 0.03774259439004319, 0.02208227587730757, 0.04467018247981157, 0.017471800059346215, 0.028604352780218636, 0.009417162759096494, 0.0178012898790517, 0.03133816697767802, 0.012020002734581274, 0.015628865021946173, 0.03191852476447821, 0.07287335143025432, 0.051905313174107244, 0.05795755037771804, 0.046036897892398496, 0.022538980834984353, 0.07578351348638535, 0.038945165396268876, 0.028168505989015102, 0.02245655240091894, 0.019913567695766687, 0.07496625876852445, 0.014972604611622435, 0.04401717734123979, 0.09955884449716125, 0.14015571001384938, 0.1433460595352309, 0.3166073166898319, 0.1669920278447015, 0.08405076379754714, 0.1961576206875699, 0.10785941087773868, 0.07195312223796334, 0.1346314171595233, 0.12011287121900491, 0.1837123249258314, 0.1235615254512855, 0.09472131729125977, 0.13836854376963206, 0.09347056690603495, 0.1673754679837397, 0.1189074944704771, 0.2537896031779902, 0.07817194996667759, 0.11795377278966562, 0.10497318753706557, 0.14593309643013136, 0.13267146875815733, 0.11497712108705725, 0.1184299143829516, 0.18585831405861036, 0.29305216350725716, 3.950874694756099, 19.693383489336284, 46.16572134835379, 55.66917208262852, 47.41232892445156, 30.654409953526088, 26.140378986086162, 26.21173003741673, 30.584448541913712, 21.337869235447474, 12.207484654017858, 6.408581512314933, 0.9265552014112473, 0.5918353423476219, 0.5333866615380559, 4.360482726778303, 8.731934053557259, 9.392983061926705, 17.793556656156266, 16.781252758843557, 22.41742648397173, 15.551616157804217, 18.12237320627485, 16.636533941541398, 11.571323224476405, 33.80367749077933, 32.9897655078343, 42.44808074406215, 46.88672201974051, 51.511634077344624, 50.60457454408918, 52.75575419834682, 50.34597648893084, 50.07885994229998, 48.898131711142405, 50.0650886126927, 51.4991968018668, 52.18907996586391, 51.920935085841585, 48.81907163347517, 47.48951298849923, 50.181467464991975, 51.79266439165388, 52.46775484085083, 51.265681743621826, 55.236455644880024, 47.99021407536098, 48.89542538779122, 46.350734506334575, 41.412910325186594, 39.44208853585379, 39.922823974064414, 37.50934287479946, 38.90010472706386, 39.401573589869905, 39.26004225867135, 46.658386843545095, 50.998141356876914, 53.65738371440342, 50.9326684815543, 46.55095032283238, 55.28856018611363, 50.55724341528756, 45.79506969451904, 43.24126625061035, 43.67096369607108, 43.24555328914097, 49.45105198451451, 46.92058753967285, 47.45835379191807, 48.14343227658953, 49.79449796676636, 48.21579776491438, 50.46026045935494, 51.55817658560616, 51.13209220341274, 47.28020545414516, 47.80642032623291, 51.01232263020107, 53.49346876144409, 49.797582966940745, 51.42617470877511, 50.38934019633702, 51.82157237189156, 52.3312783241272, 47.771797452654155, 48.408384459359304, 47.88010597229004, 48.35966716493879, 49.56009006500244, 48.859638690948486, 44.241282258714946, 37.37756334032331, 29.86740834372384, 25.87531736918858, 15.6054299558912, 22.31309233392988, 14.53431042603084, 13.822626420429774, 26.542129039764404, 24.97173193522862, 12.095074960163661, 21.018410171781266, 12.907046658652169, 7.746098450251988, 7.78896883555821, 1.4118544118744987, 1.4385008620364326, 1.8914579451084137, 8.565535988126483, 19.08977610724313, 35.15862832750593, 37.552428654261995, 37.301869664873394, 38.95718765258789, 43.685693877083914, 54.458385944366455, 50.996866362435476, 31.437784603663854, 9.716930661882673, 0.9170691732849393, 0.12769175453909806, 0.0828033789460148, 0.1072016390306609, 0.14709223780248845, 0.19500736812395708, 0.24141374869006021, 0.10836458698447261, 0.0810493862788592, 0.1769646741449833, 0.08902872739625828, 0.16988686179476126, 0.168911644124559, 0.09455927634345633, 0.137227559994374, 0.2686850210385663, 0.11665520604167666, 0.17270401705588612, 0.10326681445751872, 0.11670549905725888, 0.10022316420716898, 0.28917981843863216, 0.17312270030379295, 0.12324006270085062, 0.07451596257409879, 0.1386584546416998, 0.08047272650791065, 0.15442325228026935], [0.01088272884953767, 0.031983847330723486, 0.019583669058712463, 0.015734280526105846, 0.027417427095185434, 0.033365046073283465, 0.017559465087418045, 0.027789174379514794, 0.037000117623912435, 0.04985555048499789, 0.03737480805388518, 0.04966273797409875, 0.015332787962896484, 0.07614866032132081, 0.03520700062758156, 0.022700190577389937, 0.013558244166363562, 0.026174452721274326, 0.013004845424023057, 0.04402076339881335, 0.042726152509983094, 0.04424121942637222, 0.04066187595682485, 0.017426321249721304, 0.031755052107785425, 0.02532512365308191, 0.06683322268405131, 0.04970655437292797, 1.393260923879487, 10.854112795421056, 29.24322039740426, 44.592836788722444, 35.73180954796927, 23.601819889886038, 16.694725104740687, 13.085744772638593, 12.062296833310809, 14.095795716558184, 8.902317779404775, 4.461959430149623, 0.8043721605624471, 0.23972427791782788, 1.298635578581265, 3.2339689007827213, 8.578032323292323, 7.998192123004368, 11.008524349757604, 16.198995453970774, 9.680552499634878, 8.555733816964285, 7.166338588510241, 9.0147830588477, 16.1393712248121, 25.918821777616227, 28.902732610702515, 38.12768043790545, 47.753395148685996, 48.246442794799805, 48.76718248639788, 49.1389354297093, 48.48577349526541, 48.635041645595, 48.52972779955183, 47.506188665117534, 46.790906361171174, 47.93966245651245, 47.476238455091206, 47.418533665793284, 48.123174803597585, 48.964299406324116, 50.84144558225359, 49.45690931592669, 50.58259391784668, 45.821875844682964, 42.70198876517159, 39.692727429526194, 37.39776175362723, 34.78962687083653, 36.06233882904053, 33.94348914282662, 35.17859050205776, 35.673399516514365, 35.30509982790266, 35.47447953905378, 41.93023845127651, 44.74404696055821, 46.9264691897801, 47.20233004433768, 41.12254858016968, 49.26334639957973, 43.561473982674734, 41.5906035559518, 37.33746528625488, 38.142042364392964, 37.41378429957798, 39.96087578364781, 40.12581212180001, 42.29398012161255, 42.08177866254534, 44.55387823922293, 42.55635452270508, 43.395648275102886, 44.65185131345476, 46.68055854524885, 48.07648638316563, 46.639102118355886, 44.220479352133616, 48.42177711214338, 48.26812812260219, 49.32536949430193, 48.691502707345144, 51.24676874705723, 44.91825219563076, 48.97718831471035, 48.416684082576204, 48.3017851965768, 47.940187045506065, 48.88911294937134, 47.51246983664376, 44.4323855127607, 33.32314355032784, 30.270963191986084, 22.132699728012085, 25.82113184247698, 13.148813571248736, 17.18305492401123, 9.589099441255842, 8.16569755758558, 4.166924587317875, 11.342371395656041, 5.342968429837908, 5.0510759098189215, 6.867739319801331, 0.8760972203952926, 0.9240541756153107, 0.12055150339645998, 1.71953085064888, 5.912671642644065, 19.513166325432913, 27.331025770732335, 35.325822830200195, 25.39728304318019, 22.585774387632096, 36.18922683170864, 39.537216322762625, 37.69771201269967, 23.355424608503068, 7.849804656846183, 0.7024710742490632, 0.04060132009908557, 0.04873715853318572, 0.03988858352282217, 0.050956470160079856, 0.014104313034165119, 0.022760807503280894, 0.030435454166893448, 0.04205587186983653, 0.07537876056241137, 0.057525839257453165, 0.03954729397914239, 0.011067348050086625, 0.043890895188919136, 0.02853799544806991, 0.03324419559378709, 0.05687051692179271, 0.03221821332616465, 0.07188517374119588, 0.006766950013116002, 0.04269623929368598, 0.022037728356995752, 0.01435515979704048, 0.08161539983536516, 0.04003511994544949, 0.021673791010731032, 0.03999988701460617, 0.10688035948468105, 0.02147897512518934, 0.03433031642011233, 0.028031138270827274, 0.018269794560702782, 0.04140969279355236, 0.014384472509846091, 0.03620691018711243, 0.08611456876886742, 0.02186228464623647, 0.03343962385718312, 0.027540352195501328, 0.02656551280857197, 0.026729412942326496, 0.0436116848140955, 0.05489369674718805, 0.021747817484928027, 0.02576781007727342, 0.09230719147516148, 0.03289891626419766, 0.018839728353278976, 0.029853847875658954, 0.056107802848730765, 0.02216089772991836, 0.018245570860537033, 0.03909262462652155, 0.028406105203820125, 0.03714995851208057, 0.03036910362009491, 2.072350387062345, 13.376964620181493, 33.93315369742257, 49.877966676439556, 39.03218303407942, 26.53293136187962, 21.009170804704937, 17.522307668413433, 19.261380978993007, 18.038630042757305, 12.583396094185964, 4.944281663213458, 0.8732608354517392, 0.2008427692843335, 0.6598667289529527, 1.9338628011090415, 5.249791783945901, 8.463440895080566, 11.26683839729854, 11.41268629687173, 10.202701807022095, 9.063947643552508, 13.02516950879778, 11.316772494997297, 16.559200491224015, 28.464103255953106, 32.266690799168174, 37.99627958025251, 48.76305873053414, 51.113050665174214, 49.5023227419172, 49.610214369637625, 48.34080975396292, 50.48115716661726, 49.510021345955984, 49.03287812641689, 47.75242934908186, 48.65504898343767, 48.557711669376914, 49.002406801496235, 49.961935656411306, 49.30213124411446, 51.02863700049264, 49.366686957223074, 52.16674498149327, 48.257563386644634, 45.43319361550467, 42.84444420678275, 39.85468993868147, 37.202784878867014, 38.02205392292568, 35.490647997174946, 37.781969342912944, 37.26503379004342, 37.37423167909895, 36.640151023864746, 44.091600690569194, 46.347458430698936, 48.51155478613717, 49.00643675667899, 44.50570290429251, 51.330525806971956, 46.21758617673601, 43.14307083402361, 39.72709321975708, 39.41782890047346, 40.431300095149446, 42.401354108537944, 42.57649735042027, 45.155654770987375, 44.74575274331229, 46.40165090560913, 44.762702873774934, 45.602121693747385, 47.741715226854595, 49.868628297533306, 48.88207789829799, 46.33231830596924, 44.40598235811506, 49.90305314745222, 49.705724307468955, 50.8461286681039, 49.9258189201355, 51.83528116771153, 46.541361808776855, 49.31659391948155, 47.40436281476702, 49.69056681224278, 48.27919660295759, 49.474589007241384, 47.006967544555664, 44.50282635007586, 34.81943811689104, 29.285111086709158, 19.80621181215559, 16.906926563807897, 10.915563532284327, 11.871072854314532, 10.929154208728246, 12.678249427250453, 10.04213501725878, 13.291015403611318, 8.577889885221209, 7.602021472794669, 7.956357019288199, 2.14641101871218, 0.7434062233992985, 0.25986175877707346, 2.0017543009349277, 6.360550786767687, 18.898775339126587, 30.68318244389125, 39.22316469464983, 29.638868195669993, 30.427318504878453, 42.68546942302159, 45.79098415374756, 45.4328670501709, 27.472324337278092, 8.886969208717346, 0.9088841410619872, 0.058980801541890414, 0.05411956971511245, 0.037747781790260754, 0.026858029255111302, 0.01256294610045318, 0.02977093428905521, 0.05412352218159607, 0.010978830612397619, 0.09129375192735877, 0.04681102153179901, 0.04319239088467189, 0.048037449829280376, 0.030113482515194585, 0.07760255052042858, 0.04434653823929174, 0.00965033792557993, 0.04833881437246289, 0.03361837033714567, 0.03209601256198116, 0.05725356351052012, 0.02137554433595921, 0.083073876931199, 0.05572368756734899, 0.04465314107281821, 0.031924360165638585, 0.07202274671622685, 0.05244935576670936, 0.06775164697319269, 0.11133823277694838, 0.10735881488238062, 0.10000735614448786, 0.18238353622811182, 0.12732031089918955, 0.11712733070765223, 0.19850505329668522, 0.07836595669920955, 0.1073677104764751, 0.10647229530981608, 0.10091843189937727, 0.12711362913250923, 0.13954215150858673, 0.14245939068496227, 0.18398500100842544, 0.14961769085909638, 0.22805087002260344, 0.21442003787628242, 0.1742018831095525, 0.08448035788855382, 0.1513765486223357, 0.10686701948621444, 0.12918559009475367, 0.11843485411788736, 0.12412100471556187, 0.2093341193561043, 0.17739527246781758, 2.5706536940165927, 17.246997458594187, 40.743128299713135, 57.154999188014436, 46.73188141414097, 33.56787300109863, 27.15021800994873, 23.059882981436594, 21.727791718074254, 20.972824777875626, 13.392203756741115, 6.111725807189941, 1.2627003639936447, 0.5742479860782623, 1.9921766434397017, 6.098629755633218, 13.5643219266619, 15.438065222331456, 19.769341196332658, 26.318923371178762, 16.372488498687744, 19.54062213216509, 13.310023069381714, 13.07252756186894, 19.509746074676514, 28.685830695288523, 33.13829020091465, 38.45102180753435, 49.33581958498274, 48.804063524518696, 50.21732364382063, 49.75774547031948, 50.442830903189524, 50.833979742867605, 51.855337142944336, 51.71707493918282, 50.28269577026367, 52.21689360482352, 50.298416069575715, 51.33115461894444, 51.715553283691406, 51.94870008741106, 51.19019998822893, 49.809123924800325, 53.46008266721453, 51.54563856124878, 48.03510291235787, 43.67234986168997, 42.10707705361502, 38.7167660849435, 39.425353799547466, 37.712914671216694, 38.75402232578823, 40.36236701692854, 40.07506595339094, 38.430434295109336, 46.73410483769008, 50.2623028073992, 50.15730857849121, 50.717236110142295, 47.391248089926584, 52.30999599184309, 48.493972369602744, 45.9954765864781, 41.69638640539986, 41.96884959084647, 42.323662825993125, 44.69796650750296, 44.02702413286482, 46.89937816347395, 46.99427318572998, 49.45580802645002, 47.04233734948294, 47.16637659072876, 51.01054389136178, 51.095402240753174, 51.378572600228445, 47.36084624699184, 44.67083379200527, 49.1802841595241, 49.432726110730854, 51.53920452935355, 50.5752010345459, 52.605450766427175, 47.75429146630423, 49.254087924957275, 47.41668544496809, 49.636746065957205, 49.13838652202061, 49.689441204071045, 49.8942289352417, 46.08841916493007, 37.27660254069737, 32.80327933175223, 26.028116941452026, 31.36211177280971, 22.953386204583303, 27.843085425240652, 19.536861419677734, 17.971941232681274, 13.572037032672338, 20.779586689812795, 10.291641354560852, 15.219393253326416, 14.498376948492867, 3.7783331189836775, 1.7799557511295592, 0.527701623737812, 2.9920243748596738, 7.609312738691058, 24.358692373548234, 36.198586055210654, 46.840669359479634, 35.955027375902446, 34.239009925297324, 48.18455171585083, 51.307287556784495, 53.58068255015782, 33.43688556126186, 12.081684912954058, 1.2887784732239587, 0.1302062017577035, 0.13881545407431467, 0.12178220307188374, 0.0819422501538481, 0.14670799699212822, 0.14373707212507725, 0.13852703597928795, 0.08074422872492246, 0.1489232645503112, 0.08934418511177812, 0.11132626341921942, 0.15725363897425787, 0.09783969460321323, 0.12895487461771282, 0.10360377494777952, 0.12452134037656443, 0.22755032831004687, 0.0996067626401782, 0.11598568196807589, 0.09038621812526669, 0.18795667003308023, 0.13568896826888832, 0.17682067544332572, 0.21371641063264438, 0.10530335589178971, 0.16693765004830702, 0.1944370051579816], [0.028659158053674867, 0.01975951310513275, 0.028612746258399317, 0.03477288410067558, 0.024244303881589855, 0.005463282378124339, 0.05006451891469104, 0.06057513491915805, 0.031259392454688034, 0.0285449809660869, 0.04826422980321305, 0.01783278238560472, 0.03680489292102201, 0.0387987646806453, 0.02925759201337184, 0.024181062721514275, 0.0810381429536002, 0.028064132036109055, 0.0020329946045032038, 0.020922595069610646, 0.014656833073656474, 0.043176764223192415, 0.01002195374374943, 0.04772287420928478, 0.06544438363718134, 0.01940369782304125, 0.026812472413959246, 0.01206276485962527, 1.3011219480207987, 11.753865429333278, 34.94602039882115, 43.34136199951172, 39.20026690619332, 28.347217185156687, 18.871022496904644, 21.835544381822857, 22.56643581390381, 19.598947048187256, 9.61889852796282, 3.774172450814928, 0.7256789260676929, 0.14923216083220073, 0.5887919770819801, 2.5381259194442203, 5.897096386977604, 7.628045082092285, 10.51026555470058, 6.030213449682508, 6.57193626676287, 6.284286490508488, 10.97847947052547, 9.940556696483068, 16.556360415049962, 26.79651996067592, 28.99516797065735, 35.76989957264492, 44.020958355494905, 47.44876527786255, 44.42963055201939, 47.660268442971365, 49.783714362553184, 51.04681348800659, 48.49335050582886, 48.0920399257115, 48.308955737522666, 50.580804756709504, 48.97723000390189, 47.38873979023525, 51.32286194392613, 50.401822635105674, 49.51148394175938, 50.44987637656075, 47.92798948287964, 42.87478004183088, 42.74761758531843, 38.1731390271868, 35.481118542807444, 33.507111004420686, 35.012261050088064, 35.552910804748535, 34.283120564052034, 36.177064010075156, 34.92424474443708, 37.50733137130737, 43.263222558157786, 43.648694719587056, 49.36332055500576, 47.27824606214251, 38.54461056845528, 52.16569580350603, 43.90269306727818, 44.5697409766061, 39.28720971516201, 37.74033226285662, 36.883932045527864, 38.10771826335362, 39.27974387577602, 39.68351411819458, 38.74954073769705, 38.831692763737266, 41.243148463112966, 43.27663605553763, 43.78487246377127, 46.26883956364223, 47.20386907032558, 49.396331446511404, 48.80486604145595, 48.52737236022949, 46.77833359582083, 49.26970052719116, 49.51994684764317, 47.85650988987514, 46.62615762438093, 48.2030964578901, 46.37790891102382, 49.560701506478445, 47.13211154937744, 49.60706683567592, 46.367583887917654, 43.606974261147634, 35.844200134277344, 33.299213954380576, 22.522373812539236, 13.711166892732892, 6.685027752603803, 11.005371604646955, 11.091282606124878, 11.702055318014962, 3.3379254596573964, 8.783497503825597, 8.38154855796269, 7.368871194975717, 7.352091295378549, 1.0182210483721323, 0.709803540791784, 0.2685394345649651, 1.6647089123725891, 5.560253364699228, 15.356436048235212, 21.398756299700054, 25.14349661554609, 31.58573259626116, 27.8670653956277, 28.134989670344762, 41.70810454232352, 36.775526251111714, 25.602810757500784, 6.538283535412379, 0.45690631972891943, 0.0516049698261278, 0.017501667474529574, 0.05492383388004132, 0.018048045923933387, 0.08705941521163497, 0.016644969516034638, 0.06445876402514321, 0.027470167925847427, 0.020355824946558902, 0.057079478566135676, 0.029949653627617017, 0.041290335091097016, 0.11565713531204633, 0.05425453033032162, 0.0128830187022686, 0.024615615207169737, 0.012211322468439383, 0.019106855715758035, 0.12115051411092281, 0.07588980599705662, 0.04914335673674941, 0.07236162746059042, 0.02421037882699498, 0.03207269809874041, 0.008064522707302655, 0.027453465786363398, 0.021373764877872806, 0.032099646117006025, 0.03283290498490844, 0.08033426465200526, 0.015314682952261396, 0.018754438197772418, 0.011141118377314081, 0.03828731212498886, 0.05598490658615317, 0.021307468613875762, 0.032758378091135194, 0.01960027450695634, 0.05726594677461045, 0.041238159140838046, 0.029370011695261513, 0.03246039943769574, 0.06599116072590862, 0.01842109938817365, 0.016186781959342103, 0.04165758538459029, 0.038232120086572, 0.06270129725869213, 0.014822093670123389, 0.007195963956681746, 0.04279224182079945, 0.029065451252141168, 0.06348841145102467, 0.008902527026033826, 0.015709415610347475, 1.7738702148199081, 13.473782556397573, 39.793031624385286, 48.66928236825125, 45.03917864390782, 32.61117901120867, 22.07395965712411, 25.836633273533412, 25.427417380469187, 19.14496217455183, 9.711399895804268, 4.8666229503495355, 1.0112137900931495, 0.08188102593911545, 0.42154731707913534, 2.609474148069109, 4.314176023006439, 7.670958893639701, 6.92476144858769, 7.350401146071298, 7.64659937790462, 9.96384618963514, 15.104572534561157, 16.368112870625087, 18.262759821755544, 27.71074308667864, 29.608299595969065, 38.16200106484549, 44.41546317509243, 48.537673064640586, 44.803144863673616, 48.10939999989101, 50.784991468702046, 49.87476008278983, 49.70733628954206, 48.14686468669346, 49.219906261989046, 52.49271624428885, 50.0339572089059, 48.87049177714756, 52.39971113204956, 50.70487526484898, 49.045238971710205, 50.92278119495937, 50.3518511908395, 45.65478556496756, 45.24714865003313, 39.26148400987898, 37.09464659009661, 35.52247074672154, 36.68050268718174, 36.49199111121041, 35.446988991328645, 36.37896476473127, 37.99064459119524, 39.477698053632466, 45.18932574135916, 46.83740023204258, 50.65795407976423, 48.27666745867048, 41.4806170463562, 52.327745165143696, 46.656114782605854, 45.58886105673653, 41.28145735604422, 38.505919524601524, 39.22671869822911, 39.45654426302229, 39.87321383612496, 41.44796746117728, 40.40216282435826, 40.95588908876692, 43.53600536073957, 44.34873962402344, 45.06431027821132, 48.03607218606131, 50.684412819998606, 51.19340658187866, 50.017552512032644, 49.008476052965435, 47.47087097167969, 49.43206255776541, 49.667488370622905, 49.98720278058733, 46.655298369271414, 48.737440722329275, 47.39774465560913, 47.86411469323294, 47.6856050491333, 49.47906017303467, 48.09928342274257, 45.83411162240164, 38.61698647907802, 34.226148809705464, 19.69882913998195, 17.22621018545968, 10.81782409123012, 10.048226850373403, 11.561709523200989, 9.924054724829537, 11.459273099899292, 10.272926381656102, 12.561803698539734, 7.959305661065238, 5.358332633972168, 1.8445827918393272, 0.7596929637449128, 0.3053271062672138, 2.128240610871996, 6.621254580361502, 19.578043392726354, 28.3706465108054, 31.99925810950143, 36.12096078055245, 30.356606687818253, 33.10930926459176, 45.62129872185843, 44.18411595480782, 30.58040816443307, 7.761135220527649, 0.5122150661689895, 0.025676497923476354, 0.011507982754015496, 0.04033292557245918, 0.006589877818311963, 0.017721327919779078, 0.026207295512514453, 0.03652184543066791, 0.01962945660177086, 0.05242223472201398, 0.06611183139362506, 0.08469657985759632, 0.0368316543421575, 0.058023313991725445, 0.06601675506681204, 0.0018313197901339404, 0.003081763138262821, 0.018081385742074678, 0.04198039163436208, 0.01060368980480624, 0.02926035365089774, 0.03959318330245359, 0.05790860764682293, 0.0431456974973636, 0.04633306146466306, 0.030412020960024426, 0.03293111275083252, 0.011533678027002938, 0.17524287796446256, 0.08057144656777382, 0.20679445777620586, 0.07678446120449475, 0.12322413069861275, 0.11457724682986736, 0.08995335349547011, 0.1617576458624431, 0.11086452712437936, 0.2013980144900935, 0.12736225793404238, 0.11705160619957106, 0.15188770262258394, 0.10213486876870904, 0.11443683079310826, 0.11398073312427316, 0.20963367899613722, 0.0991693382550563, 0.0999333822567548, 0.15304491695548805, 0.12391110669289317, 0.07516521880669252, 0.13543291629425117, 0.12671892531216145, 0.1636448281684092, 0.08832515443542174, 0.07831047289073467, 0.15758564615888254, 2.4362427464553287, 17.05670714378357, 47.00886787687029, 54.83610044206892, 50.27551480701992, 38.40475375311715, 29.21876621246338, 31.758916446140834, 33.96297189167568, 27.00394974436079, 14.91100093296596, 5.5368596485682895, 1.3498983021293367, 0.3933301397732326, 0.9963533303567341, 5.228778260094779, 11.580380201339722, 14.699582883289882, 18.587673221315654, 14.325303401265826, 17.13702310834612, 12.585987772260394, 18.547437940325054, 16.904531172343663, 19.307452746800013, 31.490792410714285, 31.307127203260148, 36.938395500183105, 44.8478877885001, 48.14092397689819, 44.643242495400564, 49.23738445554461, 52.6691483770098, 51.77929605756487, 50.31223256247384, 49.44053588594709, 50.535057817186626, 53.77182054519653, 51.66756207602364, 49.05010618482317, 54.47351564679827, 51.924666268484934, 49.37333638327462, 51.51186684199742, 52.39799492699759, 48.72142859867641, 46.87285688945225, 41.57696424211775, 39.39336429323469, 37.14947829927717, 38.30483170918056, 39.609797205243794, 37.87937266486031, 39.518609046936035, 39.36597102028983, 41.94114712306431, 47.54624155589512, 48.90632363728115, 53.5758500780378, 49.75513642174857, 44.20725693021502, 56.48786442620413, 49.605086599077495, 48.61603137425014, 43.57799679892403, 41.62461151395525, 41.65498208999634, 41.7026606287275, 42.95009504045759, 44.31831693649292, 42.24735770906721, 42.810974734170095, 45.355773312704905, 47.442834990365164, 47.77680362973894, 51.07950823647635, 52.38398041043963, 53.14216436658587, 50.88262408120291, 51.74514218739101, 47.496690477643696, 51.25992863518851, 50.51680837358747, 50.975042070661274, 46.628304617745535, 49.361038071768625, 47.156597001211985, 48.55097539084298, 47.86831487928118, 52.2090699332101, 48.1728891645159, 48.12736804144723, 39.46480219704764, 36.41730839865548, 27.07732445853097, 20.858532122203282, 10.39619437285832, 20.638225589479717, 20.733085870742798, 23.006803955350602, 14.838166441236224, 17.970132963997976, 20.03298016956874, 11.492967520441328, 13.00872312273298, 3.500182181596756, 1.4686214114938463, 0.7724054530262947, 2.4700637544904436, 8.161560773849487, 19.856468132564, 30.312496049063547, 36.9065796988351, 40.64850425720215, 38.6293751171657, 38.2110345023019, 54.301502568381174, 51.47116429465157, 35.61506938934326, 10.266719903264727, 0.8885132170149258, 0.16423881772373403, 0.11284790533993926, 0.10144498185919863, 0.0685784893908671, 0.11676620080002717, 0.13298081287315913, 0.11184338852763176, 0.10252526389168841, 0.14227419133697236, 0.1313260288110801, 0.12047461180814675, 0.13821667406175817, 0.2617992205279214, 0.13956524884062155, 0.12007515824266843, 0.09130433028829948, 0.0861293879736747, 0.14792811152126106, 0.2804066320615155, 0.18997463317854063, 0.12770968143429073, 0.17617545649409294, 0.22484557916011128, 0.15447545876460417, 0.13187752850353718, 0.1470486894249916, 0.11143810634634324], [0.03332760111827936, 0.032485308458230326, 0.03977474570274353, 0.03310274139844945, 0.051272589447242875, 0.05121029653985586, 0.05553658492863178, 0.046427394795630655, 0.049891892820596695, 0.001690217902900518, 0.02665180549956858, 0.04280665729727064, 0.01637893120226051, 0.02101445005142263, 0.03414476762658783, 0.025368636407490288, 0.0212247653731278, 0.01869107999040612, 0.006230870028957725, 0.011005114514513739, 0.06720015406608582, 0.007946561938816947, 0.04822679163355913, 0.04053094923230154, 0.03772658096360309, 0.06713506220174686, 0.07050235329994134, 0.021659767388233116, 1.2137988337448664, 13.629797407558986, 28.231857981000626, 45.623994622911724, 37.26657976422991, 29.10447355679103, 22.7414105619703, 19.664947986602783, 22.04469210760934, 25.12226118360247, 9.093500069209508, 3.1376193165779114, 1.4354485401085444, 0.26880941007818493, 0.5010361203125545, 1.0257810141359056, 2.1174765484673634, 5.505459002086094, 6.1554447412490845, 4.3134360398565015, 4.491861437048231, 8.472041896411351, 20.359013966151647, 15.751793759209768, 13.16393198285784, 24.69283298083714, 27.960034029824392, 33.80981275013515, 44.249102456229075, 49.567740031651084, 50.79899556296212, 53.18575736454555, 53.21042346954346, 52.447667598724365, 52.712168148585725, 51.32356023788452, 50.8188396181379, 51.25315414156233, 49.97778102329799, 49.00869492122105, 51.64303493499756, 49.423686504364014, 49.3299309866769, 47.80070890699114, 44.788112436022075, 42.95591763087681, 39.60778570175171, 35.23181370326451, 37.02975388935634, 33.76324244907924, 33.9298220361982, 33.843539306095664, 35.08130529948643, 32.88706418446132, 35.55017668860299, 36.84648820332119, 41.610635212489534, 43.79257454190935, 47.37022631508963, 47.98786905833653, 37.131079469408306, 48.858155250549316, 43.17803764343262, 42.76737478801182, 40.8419177872794, 36.50249678747994, 35.452408586229595, 35.46215690885271, 36.544123445238384, 37.12890815734863, 36.94652836663382, 37.22154154096331, 37.95050137383597, 39.8143903868539, 42.20430319649832, 42.32117884499686, 42.76683630262102, 47.398286615099224, 47.24385942731585, 48.9394839150565, 46.60732453210013, 46.97962290900094, 46.971611636025564, 49.582866259983604, 49.353600025177, 46.267220633370535, 47.6733067376273, 48.00803967884609, 48.76514319011143, 49.58383205958775, 47.549100739615305, 43.17602266584124, 36.58075087411063, 30.108236380985804, 18.30573616709028, 14.06249908038548, 14.404624036380223, 6.570391161101205, 6.922438144683838, 9.479420389447894, 12.36665051324027, 12.095300776617867, 12.024708815983363, 4.317977556160518, 3.3942215016910007, 1.8077000166688646, 0.8779688913907323, 0.23802864604762622, 2.2009422183036804, 6.361361554690769, 18.14085715157645, 24.889229025159562, 24.72009597505842, 17.68263735089983, 25.26314285823277, 36.12181888307844, 38.10194083622524, 36.708872182028635, 22.29936616761344, 6.8951634253774365, 0.6664067208766937, 0.020242228006411876, 0.014714138748656427, 0.033953081483819654, 0.036733931728771756, 0.01386195728887937, 0.02612226320031498, 0.060182765259274414, 0.06976551855249064, 0.05530921123655779, 0.03650864113920501, 0.005355949588452599, 0.09349773544818163, 0.06689741209681545, 0.03787895957274096, 0.030357605844203914, 0.028356236272624562, 0.08836595474609307, 0.00950470904354006, 0.06088287090616567, 0.010638044880969184, 0.03796178834246738, 0.035866607911884785, 0.014495192461514046, 0.0012223268713569269, 0.05781853212309735, 0.0425000341076936, 0.03101370849513582, 0.04136784414627722, 0.04133752041629382, 0.022652715178472654, 0.013575277091669185, 0.049481596265520365, 0.032557650469243526, 0.061890000078294954, 0.010310762844580625, 0.028678611652659516, 0.03464145865291357, 0.014481845677697232, 0.04087253054603934, 0.04310704814270139, 0.06540638567613703, 0.041713981822665246, 0.0004809116414565194, 0.06353758488382612, 0.06780493911355734, 0.018067124632320235, 0.028337296663916538, 0.04639347143737333, 0.02941938190321837, 0.01261009240988642, 0.02428684802725911, 0.03753426378326757, 0.0027153904874077333, 0.04910071759617754, 0.05529188145218151, 1.7087100084338869, 15.968061651502337, 33.74365200315203, 50.413228103092735, 40.71690232413155, 33.88533966881888, 29.388236250196183, 26.58490388734, 25.583597251347133, 25.96866294315883, 12.63219850403922, 3.980514407157898, 1.4557059045348848, 0.2665281210626875, 0.5867496952414513, 1.2409511996167046, 3.2467003890446255, 6.626899991716657, 7.978116171700614, 8.989045194217137, 14.442423973764692, 13.770157967294965, 13.676980887140546, 12.07352077960968, 15.136207682745797, 25.18051140648978, 29.907450812203543, 36.24207483019148, 45.91202177320208, 48.22688708986555, 50.964355741228374, 52.24812923158918, 53.273679869515554, 52.62071248463222, 52.74945913042341, 51.2521779196603, 51.810597692217144, 51.18157727377755, 49.31350197110857, 50.44883762087141, 52.06060429981777, 50.312138761792866, 50.46164662497384, 49.24190425872803, 46.41530758993966, 45.11122104099819, 41.182709557669504, 36.12888867514474, 38.94931186948504, 35.72024427141462, 35.5642363684518, 35.052282673971995, 36.39464684895107, 35.166684763772146, 37.09092582975115, 38.87921496800014, 44.215883118765696, 46.317608969552175, 50.48302623203823, 50.400408676692415, 39.25345189230782, 51.20285265786307, 44.91768939154488, 44.32056815283639, 41.90514155796596, 38.95499897003174, 38.35130820955549, 37.64828600202288, 39.65971653802054, 38.91542203085763, 38.084358419690815, 39.75887428011213, 39.34821489879063, 42.24056931904384, 44.23889555249895, 45.25848463603428, 46.00504078183855, 50.51644359316145, 50.038372789110454, 51.0131390435355, 48.32356432506016, 48.60294444220406, 48.61937345777239, 49.562674794878276, 48.78978497641427, 47.510083130427766, 47.636720997946604, 48.134434359414236, 47.27816615785871, 50.18847819737026, 47.207739216940745, 45.50494418825422, 37.856367179325645, 32.73324496405465, 20.9582040309906, 20.397520882742747, 16.204552275793894, 6.983999618462153, 5.055203574044364, 11.72901085444859, 13.316031524113246, 12.310479538781301, 7.223870541368212, 7.5318255594798496, 7.247880910124097, 1.046505970614297, 0.8723033953990255, 0.11517522617110185, 1.9644626677036285, 7.313546163695199, 18.87968168939863, 25.98873107773917, 31.119647434779576, 22.762005022593907, 32.380526610783164, 39.506578241075786, 45.385014806474956, 43.43103892462594, 26.37100533076695, 8.173365763255529, 0.7991338702184814, 0.04313903089080538, 0.02555701299570501, 0.024679736766432012, 0.0164465607875692, 0.0324093125361417, 0.010989800827311618, 0.11516815583620753, 0.042370338924229145, 0.026938135403075388, 0.1025698979252151, 0.033976545224764516, 0.12745498652969087, 0.041203601352338276, 0.039434538422418494, 0.025352438080257604, 0.05155343169878636, 0.029759643466344902, 0.031066115147301128, 0.043000860804958005, 0.01139069627970457, 0.015247501200065017, 0.027995655978364602, 0.024792997831744806, 0.05487784956182752, 0.04146692382970026, 0.04442453923236046, 0.05004223582467862, 0.23185207747987338, 0.07239148300141096, 0.11767891182431153, 0.10661515407264233, 0.17284519305186613, 0.11249798483082227, 0.19872415225420678, 0.07335539627820253, 0.1390442560826029, 0.06639311808560576, 0.1277066958802087, 0.172471835943205, 0.14503023773431778, 0.08541669550218753, 0.16022372245788574, 0.0997580691639866, 0.11827720329165459, 0.08713223558983632, 0.19814973164881977, 0.08638288865664176, 0.11307803049151387, 0.09429486481738941, 0.18237132259777614, 0.16273848180259975, 0.11409624692584787, 0.10676133087170975, 0.19964584708213806, 0.13436073596988404, 2.5065617731639316, 18.902167797088623, 39.12738377707345, 57.71828964778355, 48.92097043991089, 39.14689084461757, 34.134206771850586, 29.971829346248082, 32.707088470458984, 33.20382213592529, 15.532849073410034, 5.127178226198469, 2.4255229788167134, 0.4686441070267132, 1.0306535469634193, 2.482873409986496, 7.605887276785714, 11.499279958861214, 12.412289755684988, 14.384367431913104, 18.43139260155814, 15.932587623596191, 27.75419017246791, 22.69278359413147, 16.425645692007883, 27.02727484703064, 29.821289675576345, 36.57872200012207, 45.488414423806326, 50.015030315944124, 51.466519423893516, 54.85372454779488, 51.943565368652344, 54.410585812159944, 52.840598651341026, 53.99687269755772, 51.380500725337434, 52.18682527542114, 49.683747155325754, 51.51898179735456, 51.82915980475289, 51.91457053593227, 52.58142042160034, 52.0648843901498, 47.68810640062605, 47.547676358904155, 43.47644887651716, 37.92713805607387, 39.913770471300396, 37.269772461482454, 36.455784048352925, 35.65641117095947, 37.2568279675075, 37.33701712744576, 39.23293386186872, 40.81107473373413, 45.66881397792271, 49.587653568812776, 51.85010167530605, 52.79988915579659, 43.18025759288243, 52.247788769858225, 47.93165465763637, 47.01220996039254, 44.46507331303188, 41.01324299403599, 40.53630474635533, 39.9786353792463, 42.144889150347026, 41.865251949855256, 40.69277123042515, 40.947071824754985, 40.28788580213274, 44.07688440595354, 47.22271258490426, 47.56755862917219, 48.24180487224034, 53.7983591897147, 51.57715906415667, 53.487159797123496, 50.18861716134207, 49.29392194747925, 48.525826386043, 49.524452754429404, 50.88361767360142, 46.599810055324006, 46.87640741893223, 49.250888279506135, 48.58292668206351, 51.10784993852888, 49.975071225847515, 48.35217353275844, 40.76235396521432, 34.81357383728027, 22.14855030604771, 20.469844681876047, 21.528248139790126, 14.590277297156197, 18.65059437070574, 21.54169464111328, 23.92532627923148, 23.77227657181876, 21.83721194948469, 11.131460564477102, 10.042522379330226, 4.693543757711138, 1.7302479041474206, 0.4624257949846131, 3.4636059956891194, 8.024419835635594, 23.612690346581594, 33.308208397456575, 36.60899182728359, 28.6474940095629, 36.483232906886506, 46.32644707815987, 50.555989265441895, 49.38851472309658, 32.10455805914742, 10.42358330317906, 1.2136971077748706, 0.160199390192117, 0.19246746227145195, 0.07827487694365637, 0.09499919773744685, 0.1027279355164085, 0.09955181487436805, 0.23548850949321473, 0.15436028423053877, 0.17160156049898692, 0.15342994486646994, 0.11766466258891992, 0.21679571111287388, 0.1037380231012191, 0.1367671468428203, 0.12789733707904816, 0.11688773999256746, 0.2010834999382496, 0.12532297521829605, 0.1723984863076891, 0.19041973858007363, 0.09850130695849657, 0.12890816426702909, 0.07166934532246419, 0.06736781328384366, 0.13868539248194012, 0.16384791369949067, 0.24269050732254982], [0.05033621112150805, 0.03332374364669834, 0.013941546053891736, 0.02132868131489626, 0.0504677213861474, 0.03606182922210012, 0.04633950415466513, 0.03582841656836016, 0.0215925042118345, 0.0783744655283434, 0.060900241402643066, 0.0346301474741527, 0.014005641319922038, 0.023402289420898472, 0.020514583481209617, 0.0801419678277203, 0.030310637650213072, 0.05199710539143, 0.02846864577648895, 0.06397919583001307, 0.009965173085220158, 0.00784503189580781, 0.014332986968968595, 0.026855432162327424, 0.03885963266449315, 0.04958356650812285, 0.023982253657387834, 0.032605032569595745, 0.7358941350664411, 10.990806443350655, 31.14214222771781, 38.101388454437256, 42.87143101011004, 36.30913189479283, 20.3470231124333, 17.552935327802384, 26.983099937438965, 18.549652678625925, 6.922592307840075, 4.748192642416273, 1.4331559602703368, 0.2535784159387861, 0.2994111765708242, 1.4976010450295039, 2.9444352941853658, 7.48614810194288, 5.090394462857928, 6.531535966055734, 10.451077325003487, 11.390671798161097, 9.12724312714168, 15.75814093862261, 20.05570251601083, 22.438846043178014, 28.216750860214233, 35.9008765901838, 42.748298508780344, 50.076904024396626, 51.264507498059956, 50.386894430433, 47.10276583262852, 46.73747818810599, 47.187252453395296, 47.938147749219624, 47.38365370886666, 47.79171446391514, 49.06112255368914, 48.68133054460798, 48.312541007995605, 46.637267793927876, 45.383736337934224, 43.5979311806815, 43.12014872687203, 39.680387428828645, 36.15647997174944, 34.21831471579415, 34.96284546170916, 34.35029227393014, 34.663294724055696, 35.040585381644114, 34.537831102098735, 35.42298991339547, 34.97614083971296, 36.60626813343593, 42.17761516571045, 45.168026038578574, 46.678470611572266, 47.13185099193028, 38.397034304482595, 49.11570760181972, 46.72726433617728, 43.7699407849993, 40.72736631120954, 36.915883336748394, 35.02679320744106, 36.314061641693115, 35.15909733091082, 35.27784551892962, 34.92379658562796, 34.30346488952637, 35.01791688374111, 34.936946051461355, 37.720005307878765, 41.949460642678396, 41.47812611716134, 44.95738097599575, 45.15511628559658, 46.81557594026838, 46.40324551718575, 46.53110974175589, 47.91844960621425, 50.11006430217198, 48.98277466637747, 49.17381886073521, 46.37142276763916, 47.15010738372803, 46.25516898291451, 49.39705753326416, 45.6371614592416, 46.18639918736049, 35.85046740940639, 31.090465000697545, 18.25855268750872, 22.46331933566502, 11.568420614515032, 3.5378359896796088, 5.492048110280718, 5.694136900561197, 8.974739721843175, 6.2065300686018805, 5.618990395750318, 7.778114880834307, 5.9166916097913465, 0.850437088736466, 0.7925983294844627, 0.16547858262700693, 2.1322701317923407, 6.250008421284812, 18.62594042505537, 26.441498279571533, 22.650915486471995, 26.629292454038346, 27.919717107500347, 35.71537011010306, 39.62879358019148, 40.17677368436541, 25.981258290154592, 8.685381122997828, 0.7977632294808115, 0.0581196252522724, 0.03327344045309084, 0.006095479816264872, 0.04412710001426084, 0.05298588019130485, 0.018485736634050096, 0.024551295176414505, 0.040485453459301164, 0.05657536097403083, 0.04429724606286202, 0.03693886626777904, 0.003999424923676997, 0.054871159206543646, 0.05224981897377542, 0.059837092379374165, 0.019536320885111178, 0.03846859971859625, 0.024398833446736847, 0.04542398060272847, 0.01695549937098154, 0.021664778369345834, 0.05600392931540098, 0.003629626307104315, 0.013589196389407983, 0.03762374219617673, 0.10810005332210235, 0.04648559274418013, 0.027535985822656324, 0.04273688693397811, 0.0644612813900624, 0.025399080577439496, 0.04703803899298821, 0.030832549823181968, 0.06066493224352598, 0.015385179348023874, 0.009979157691954501, 0.02820165072833853, 0.06192195229232311, 0.02132761262224189, 0.03499786595680884, 0.031330336683562825, 0.04474419029429555, 0.0554525856859982, 0.05750103880252157, 0.03475312516093254, 0.06585018150508404, 0.013177327329425939, 0.03855448189590659, 0.020266395727438585, 0.04084196932879942, 0.02227022159578545, 0.02110083434464676, 0.004806997370906174, 0.053220534564128945, 0.05906415956893137, 1.0780135542154312, 13.884328160967145, 34.804072175707134, 44.35357557024275, 47.83365726470947, 41.25227492196219, 25.408592973436626, 24.049579177583965, 29.996665682111466, 24.932033402579172, 10.835422141211373, 5.179907671042851, 1.7231925513063158, 0.2627347031874316, 0.25966590642929077, 0.7692242094448635, 2.5047343969345093, 7.449781230517796, 6.935271467481341, 8.795670747756958, 9.807021004813057, 14.369156088147845, 12.953675150871277, 12.386630926813398, 13.033865179334368, 20.560805286679948, 28.494289704731532, 35.259279932294575, 45.462799889700754, 49.418027196611675, 52.64444405691964, 51.69877338409424, 49.52943113871983, 47.62628132956368, 47.82263394764492, 49.84590073994228, 49.949432373046875, 49.54228183201381, 51.19861078262329, 50.03144890921456, 50.3366242136274, 49.58444002696446, 47.398588861737935, 46.38348136629377, 46.18305362973894, 42.71163286481585, 37.363715580531526, 36.35218988146101, 37.459493024008616, 36.57537644250052, 35.27479178564889, 35.806401933942524, 35.14100422177996, 36.40213005883353, 35.19965744018555, 39.12643882206508, 44.04168483189174, 46.345023087092805, 49.753910064697266, 48.494291986737935, 41.89414255959647, 51.982395376477925, 48.445369720458984, 47.48471525737217, 43.91714184624808, 39.76558971405029, 37.7663254737854, 36.8206513268607, 37.93965176173619, 37.883961950029644, 37.06285163334438, 36.97991098676409, 36.56892156600952, 37.04665190832955, 40.37454720905849, 44.175038133348735, 44.88103069577898, 46.440807478768484, 46.89416354043143, 48.693295342581614, 47.59444120952061, 47.712369510105674, 48.33616835730416, 50.62689563206264, 50.458610262189595, 48.068482058388845, 45.83186388015747, 48.39530447551182, 48.4918601172311, 48.11156088965279, 46.971809659685405, 45.51062086650303, 37.86498989377703, 31.909671510968888, 21.785824809755596, 16.64874713761466, 18.728534051350184, 14.633052144731794, 9.988753744534083, 8.794156908988953, 11.211189406258718, 10.404646856444222, 8.611945612089974, 8.893437113080706, 6.7904210686683655, 1.3872200080326624, 0.21255915558763913, 0.27126570684569223, 2.0807779005595615, 6.93464960370745, 20.62425102506365, 30.595037596566335, 28.315220730645315, 29.330190999167307, 28.63233825138637, 40.91577019010271, 43.68129914147513, 45.343683447156636, 29.78154945373535, 10.533623661313738, 0.6984968675034386, 0.04196800497759666, 0.023165604532031075, 0.04497117722140891, 0.030828475220394985, 0.012975051799522979, 0.04500327532046607, 0.011363967937151236, 0.06260780191847257, 0.08683446728225265, 0.04359931851338063, 0.01910845366572695, 0.08650281972118787, 0.0269530139796968, 0.04086556877674801, 0.026902519099946533, 0.056057726964354515, 0.005832988120216344, 0.01950823123167668, 0.04935242694669536, 0.03925189036609871, 0.06732623265790087, 0.012330477458557912, 0.04021623790530222, 0.0788277947743024, 0.0069417185815317285, 0.08029532352728502, 0.045494056306779385, 0.11091859279466526, 0.1498047493930374, 0.14000883432371275, 0.15102558316929, 0.1212175398000649, 0.14950848743319511, 0.1152616986738784, 0.18091464361974172, 0.10959865897893906, 0.29232946942959515, 0.14022979246718542, 0.11642856177474771, 0.11360214451061827, 0.1742801589093038, 0.1700135985655444, 0.13419387063809804, 0.0932301212368267, 0.11361958286059753, 0.1347404034542186, 0.17931533658078738, 0.0896585707419685, 0.12308652379683085, 0.16217505346451486, 0.10213652439415455, 0.14646468790514128, 0.09049817640334368, 0.17328455804714135, 0.18432145938277245, 1.399266664470945, 15.765433073043823, 41.146196774074006, 50.42385537283761, 54.079875877925325, 48.15423672539847, 32.138691084725515, 28.567117248262676, 37.206755774361746, 28.429475171225413, 12.436785629817418, 7.03721239737102, 2.4185637065342496, 0.6213206201791763, 1.071569208587919, 3.247545463698251, 8.014636772019522, 14.008026071957179, 13.466400963919503, 15.009229353496007, 16.098093714032853, 18.76058782849993, 13.698423896517072, 23.540267535618373, 25.26658395358494, 25.5638713155474, 27.595957108906337, 38.64325761795044, 43.801975454602925, 52.71882799693516, 52.97629696982247, 56.00481523786272, 50.5951840536935, 52.00036341803414, 49.07751682826451, 52.524278436388286, 52.27888890675136, 52.34443473815918, 52.17826509475708, 52.78132356916155, 51.943172795431956, 52.355440684727256, 48.2835670198713, 49.084993089948384, 48.308750765664236, 43.78889199665615, 38.8215206010001, 38.07602058138166, 39.544755118233816, 38.782291071755544, 36.787977422986714, 38.790086950574604, 36.01350341524397, 38.63074043818882, 37.019953455243794, 40.82680198124477, 44.3028815133231, 50.0497157233102, 51.05459199632917, 51.1173654964992, 45.478499344417024, 54.36992147990635, 50.766432830265586, 50.62242794036865, 46.44024120058332, 41.08062662397112, 38.97388417380196, 39.98481232779366, 40.045185225350515, 39.37193604878017, 39.3066577230181, 38.93393898010254, 37.78197281701224, 39.18025609425136, 41.0632769720895, 47.19733428955078, 45.69617598397391, 50.217705794743125, 48.5994599206107, 52.58687128339495, 48.887976918901714, 50.50444752829415, 49.443082400730674, 53.03664207458496, 49.60672984804426, 50.044574056352886, 45.92773165021624, 49.463544845581055, 47.89706999914986, 50.890534605298726, 46.894514424460276, 49.44806425912039, 38.24255847930908, 36.62597322463989, 22.13501000404358, 28.12008057321821, 14.689502784184047, 11.931642907006399, 20.059093236923218, 9.807172128132411, 19.755670615604945, 14.120308092662267, 11.595280613218035, 16.0614332812173, 10.34441465990884, 1.7143516199929374, 1.866372125489371, 0.36658948180930956, 3.5012094293321883, 8.942748478480748, 24.007269859313965, 34.05089092254639, 33.92709139415196, 38.93838235310146, 38.399393217904226, 46.83753572191511, 49.95511947359358, 52.82533345903669, 35.54948534284319, 12.88006159237453, 1.2454370217663902, 0.28220404418451445, 0.12837867625057697, 0.06615582081888403, 0.13013042296682084, 0.13950190081128053, 0.07127340656838246, 0.08191955315747432, 0.12604824772902898, 0.24808540354881967, 0.0904470623603889, 0.1052429119923285, 0.10524967020111424, 0.12896845888878616, 0.14589801616966724, 0.11676580724971634, 0.06632092195962157, 0.11046568424041782, 0.1352517610149724, 0.20669091333236012, 0.19901499950460025, 0.15828733279236726, 0.15393723121711186, 0.15386970341205597, 0.16542979595916613, 0.12321558115737778, 0.257342982505049, 0.1200634195868458], [0.04715907606961472, 0.035566895601472685, 0.04152320830949715, 0.02880758758900421, 0.03955339061628495, 0.057921058764415126, 0.048610951019717116, 0.05609943651195083, 0.0420077942710902, 0.021165644616952965, 0.024554855788924863, 0.02911463825564299, 0.05321389509897147, 0.01743210236808019, 0.03189786337316036, 0.01277171605865338, 0.05696775098996503, 0.045864078415823836, 0.06326738545405013, 0.06731777132621833, 0.04045119083353451, 0.030145044571587017, 0.00984041509218514, 0.02775547493781362, 0.022253597487828562, 0.07558963567550693, 0.05826010914253337, 0.026716164546087384, 0.3545532748103142, 8.341909085001264, 22.68628008025033, 40.0335921560015, 42.01428386143276, 35.105714321136475, 19.854303768702916, 17.078724248068674, 21.76939579418727, 20.260610103607178, 16.600672551563807, 7.0014369913509915, 2.1604685272489275, 0.6898789299385888, 0.4266240618058613, 0.3415030650794506, 0.6029684192367962, 5.172001923833575, 6.402008516447885, 12.523027539253235, 13.94756805896759, 18.567476545061382, 13.764552508081708, 5.180916462625776, 9.496144703456334, 18.571039233888897, 29.74375820159912, 29.177080495016916, 46.00189324787685, 49.62172406060355, 49.564731461661204, 45.49361515045166, 44.620407240731375, 41.64559159960066, 41.81977946417672, 40.334091322762625, 41.71136672156197, 41.00537068503243, 42.97471945626395, 41.885307925088064, 44.55453136989048, 41.59656163624355, 42.20983048847744, 38.165871211460654, 36.54428325380598, 35.259450163160054, 34.06019456045968, 32.86509050641741, 34.81873982293265, 36.50497382027762, 35.53090238571167, 35.15112427302769, 34.64426013401577, 34.15232072557722, 35.80496713093349, 37.838197640010286, 42.39983245304653, 43.4393698147365, 47.187276772090364, 48.73444952283587, 36.48171125139509, 45.64840364456177, 45.26476928165981, 42.855616910117014, 41.54555491038731, 38.95700352532523, 35.888491426195415, 33.38524307523455, 33.330453055245535, 34.22802134922573, 34.22593688964844, 37.276130063193186, 35.623553139822825, 34.379978452410015, 35.41367585318429, 35.14333186830793, 38.11555930546352, 41.387615408216206, 42.55752876826695, 44.11193459374564, 42.74411221912929, 41.627592291150776, 45.54547650473458, 47.185195786612375, 49.67353677749634, 47.65507813862392, 49.00537715639387, 47.50533403669085, 49.386152335575645, 48.334167276109966, 45.98607219968523, 38.40478849411011, 35.59479801995413, 29.727812085832866, 21.593767915453228, 16.03445863723755, 24.719621760504587, 15.245035580226354, 2.1730015575885773, 14.187974861689977, 11.991771749087743, 10.677226424217224, 5.034890081201281, 7.35749351978302, 7.909084950174604, 0.8668931914227349, 0.3323225677013397, 0.07114372495561838, 1.354391398174422, 7.826232024601527, 14.227616940225873, 26.907239505222865, 33.78347212927682, 23.55516447339739, 26.552434955324443, 36.94207457133702, 39.817284311567036, 41.54603086199079, 25.225874458040508, 8.739884529794965, 0.7929108355726514, 0.033232562110892365, 0.030004767634506737, 0.08422653150877782, 0.01881242580046611, 0.051917024688529115, 0.051847583414720635, 0.03149992633344872, 0.012249528230833156, 0.003683189437392035, 0.1213204599916935, 0.05733894357191665, 0.020524566427671483, 0.03690142470545002, 0.02878624087731753, 0.015172100692455257, 0.06088607359145369, 0.06958320976368018, 0.017920405005237887, 0.004278164140747062, 0.03949434110628707, 0.04899552770491157, 0.02667439732301448, 0.0679789154923388, 0.007701061183719763, 0.0485160748607346, 0.015194068263684, 0.012714256865105458, 0.04355433164164424, 0.04853051408593144, 0.013676420369717692, 0.005046309462548899, 0.030141061571027552, 0.03478450062019484, 0.02170958712563983, 0.016019499328519617, 0.04634980092357312, 0.0175422676173704, 0.02209207392297685, 0.04234367249799626, 0.04486909502052835, 0.04346773360988923, 0.009806570613623729, 0.02605715097992548, 0.03868752225701298, 0.043129751924425364, 0.031397416655506404, 0.01282773760613054, 0.004174224874337337, 0.020855513401329517, 0.02294038688497884, 0.020793675112404993, 0.004329100492343838, 0.04810132372326084, 0.04692187040512051, 0.05032619933730789, 0.827639180634703, 10.163390636444092, 29.077879326684133, 43.83536502293178, 47.00451135635376, 40.91403661455427, 26.689467327935354, 22.45196771621704, 27.80725530215672, 24.124548503330775, 16.053296940667288, 8.087169017110552, 2.429538820471082, 0.5751731821468898, 0.24303031765988894, 0.8355801573821476, 1.9496473712580544, 3.771382314818246, 7.824251788003104, 9.308376584734235, 12.60356410912105, 11.301764386040823, 9.00755432673863, 9.218614544187274, 14.633363076618739, 16.97553481374468, 28.34811176572527, 32.97444125584194, 45.98053795950753, 51.08232225690569, 52.14578921454293, 47.14563274383545, 46.65510034561157, 44.687895093645366, 44.375156675066265, 42.98473528453282, 44.7357542855399, 43.75284821646554, 44.50197172164917, 44.049223627362935, 46.00313697542463, 44.12592131750924, 43.97503423690796, 40.99999277932303, 39.30465316772461, 36.84580380575997, 35.396746567317415, 35.298391342163086, 37.45968409946987, 37.4864798273359, 38.226935454777305, 36.94701821463448, 36.04145949227469, 35.834562982831685, 37.32649408067976, 39.26839746747698, 43.67639371326992, 44.57475062779018, 49.19831126076834, 50.203128474099294, 38.654357365199495, 48.1851110458374, 47.40634305136544, 44.53471163340977, 44.319428648267476, 40.32568400246756, 37.46723331723894, 34.70328508104597, 36.10784605571202, 35.53931318010603, 36.57190234320504, 38.091928482055664, 37.791144439152305, 35.27382598604475, 36.96444777079991, 38.36862659454346, 40.39466224397932, 43.65090077263968, 45.769844259534565, 46.136122022356304, 45.849060671670095, 44.04436683654785, 46.26056773321969, 48.84582914624895, 51.2310380254473, 49.746715205056326, 49.32207604816982, 47.77551473890032, 49.72673218590872, 49.171824727739605, 46.20224455424717, 42.37806722096035, 36.95980984824044, 29.393694060189382, 22.54463584082467, 20.116992575781687, 19.480254445757183, 13.37284173284258, 10.130189538002014, 10.034346955163137, 9.377787351608276, 13.413714511053902, 8.428282141685486, 7.87918598311288, 7.635189567293439, 2.162006901843207, 0.3744388020464352, 0.3302790644977774, 1.8514719307422638, 7.723060829298837, 18.238116298403057, 28.976018735340663, 33.93990734645298, 29.188208035060338, 33.166597161974224, 43.23155961717878, 46.305894306727815, 47.78759070805141, 30.64112847191947, 10.681357128279549, 0.8722221340451921, 0.02830757513376219, 0.0770915322271841, 0.017199800815433264, 0.042294275148638656, 0.03493438222046409, 0.04398652452177235, 0.08381838590971061, 0.029761031070458036, 0.005473341659775802, 0.03383299774889435, 0.04672850149550608, 0.025008459841566424, 0.026968399761244655, 0.017155969149566123, 0.030086866979088103, 0.03420157118567398, 0.053562641742506197, 0.00742932572029531, 0.049769617417561154, 0.06114986086530345, 0.020687857576246773, 0.0510984230786562, 0.03276694120307054, 0.027111479047951952, 0.008699498322260166, 0.01599460218234786, 0.031335364628051005, 0.24023326060601644, 0.11453263993774142, 0.12419283443263598, 0.1343229687107461, 0.12132184420313154, 0.1058225641027093, 0.08785997118268694, 0.10831445003194468, 0.052224648717258654, 0.10309662430414132, 0.13788743530000958, 0.07040617774639811, 0.0957994144409895, 0.12051425182393619, 0.11207269265183381, 0.11069454731685774, 0.16026614446725163, 0.15389168794666017, 0.12949371284672193, 0.12758954002388886, 0.13949888811579772, 0.15440945087799005, 0.1539282202720642, 0.0920245341424431, 0.06051919649222067, 0.15866837091743946, 0.20785485873264925, 0.14072724006005696, 1.1908619616712843, 13.21887573174068, 32.354040077754426, 52.25619609015328, 54.5402843611581, 45.56771421432495, 29.943206242152623, 27.80126248087202, 31.234952790396555, 30.22741883141654, 23.319813353674753, 10.138882602964129, 3.2577391224248067, 1.2828811896698815, 1.0479393622704913, 1.2155814809458596, 4.213738943849291, 11.067416412489754, 15.778997693743024, 21.79594659805298, 19.506299768175396, 29.70990310396467, 21.374298640659877, 9.609657423836843, 13.041591576167516, 22.37328805242266, 35.19545725413731, 32.09747437068394, 49.23375054768154, 52.80605220794678, 54.527287755693706, 50.35951852798462, 50.14074754714966, 46.111487184252056, 45.94655432019915, 43.84660373415266, 46.237225260053364, 45.29856531960623, 46.624893052237375, 46.695851530347554, 47.39322485242571, 47.16153022221157, 45.720011779240195, 41.43692677361624, 41.27190358298165, 37.791290351322715, 37.761715344020296, 36.92999165398734, 38.55279554639544, 39.99794094903128, 39.7427579334804, 38.88842827933175, 37.837700843811035, 37.8401083946228, 39.419812611171174, 40.988010610852925, 45.98849017279488, 46.896237577710835, 51.5636830329895, 52.76868827002389, 42.074434416634695, 49.489638805389404, 50.23613936560494, 46.50559248243059, 45.91617332186018, 44.239180428641184, 40.26697172437395, 36.229356152670725, 38.63746282032558, 37.034273692539756, 38.882279123578755, 41.062700271606445, 40.2667806489127, 37.92377512795584, 37.9450991494315, 39.82598693030221, 41.66517162322998, 45.70814773014614, 47.92952503476824, 48.79516635622297, 48.76125914709908, 46.94824831826346, 50.37350525174822, 51.79873364312308, 53.6264260155814, 50.74087735584804, 49.99793079921177, 48.235714776175364, 49.53330475943429, 48.628955023629324, 46.709813935416086, 41.59338630948748, 39.591172558920725, 33.53136716570173, 25.73613974026271, 19.257255486079625, 28.18916824885777, 22.38717576435634, 8.835802674293518, 21.20194857461112, 21.4655510698046, 22.440496240343364, 18.554730074746267, 10.880020022392273, 14.12879010609218, 3.7008207525525774, 0.9487320056983403, 0.9511145864214215, 2.06033239194325, 10.193597929818289, 19.017421041216167, 37.09506695611136, 45.07143565586635, 36.266855580466135, 38.43875476292202, 49.080045972551616, 50.803494521549766, 54.490552629743306, 35.205914293016704, 13.373090130942208, 1.3844263979366846, 0.11635206373674528, 0.1549528217209237, 0.1449170716639076, 0.11569270411772387, 0.13701361790299416, 0.13847755720572813, 0.17865037226251193, 0.12106518154697758, 0.17446366191974708, 0.16624266734080656, 0.17730148535753998, 0.08548821309315306, 0.1541852629078286, 0.10983927428190197, 0.17371616060180323, 0.22399660971547874, 0.2024972547910043, 0.08265474585017987, 0.16099007347864763, 0.13388551718422345, 0.13285907012011322, 0.10037623492202588, 0.13905261563403265, 0.1388561526047332, 0.09148369423512902, 0.1089514179953507, 0.11236299707421235], [0.06069668768239873, 0.06260850080954176, 0.053285205736756325, 0.023204772965982556, 0.059185108436005454, 0.016939507996929542, 0.05642488565562027, 0.08419725272272315, 0.05313796363770962, 0.04626222580139126, 0.0124865769841043, 0.034421630270246945, 0.027077642202909504, 0.02956308883481792, 0.015366816494081701, 0.08732785045036248, 0.002906974213796535, 0.07021845424813883, 0.009916969957495374, 0.020497309675972377, 0.08886379588927541, 0.016348249545054774, 0.035553233298872194, 0.06359756737947464, 0.03944530677316444, 0.017739614438531653, 0.06669078461293663, 0.03049087690721665, 0.15723810052233084, 7.076100162097386, 18.59351144518171, 36.427160944257466, 44.07666553769793, 36.81393241882324, 25.632943357740128, 23.68650279726301, 26.63520015989031, 21.680667298180715, 17.24688628741673, 6.606681602341788, 2.778554218155997, 0.4389466105827263, 0.12909543993217604, 0.5728017293981144, 1.836394122668675, 3.0402261997972215, 3.5473969280719757, 3.532204691852842, 9.934107899665833, 9.41714802810124, 9.817012514386859, 9.857496193477086, 10.985581398010254, 12.454552173614502, 23.330002886908396, 31.60094220297677, 46.564419405800955, 45.55250113351004, 44.292792728969026, 41.577203954969136, 41.80764443533761, 38.61245277949742, 38.212952205113, 35.827420234680176, 35.44381366457258, 35.821562903267996, 36.56765699386597, 36.94492333275931, 36.67629902703421, 34.71562508174351, 35.2088360105242, 33.555536474500386, 34.53503792626517, 35.13803734098162, 39.73956176212856, 41.6746107510158, 34.3267309325082, 34.60828583581107, 34.103224754333496, 34.15431833267212, 34.198467186519075, 34.67730924061367, 37.54805128914969, 39.177101612091064, 44.59577587672642, 43.99979414258684, 50.390194824763704, 44.589022227696006, 37.53212601797921, 43.312450545174734, 47.36603307723999, 44.83949089050293, 42.168103081839426, 40.490547384534565, 35.10695110048567, 33.64088467189244, 34.36635998317173, 35.225021839141846, 35.1289838382176, 37.64035810743059, 40.12192113058907, 34.107904366084504, 35.80745458602905, 34.46139396939959, 35.65210676193237, 36.7839891569955, 36.85511091777256, 35.491982051304404, 37.99177367346627, 39.01421846662249, 42.607097217014854, 45.58914940697806, 44.64479889188494, 47.195562498910085, 48.33945485523769, 49.60373517445156, 50.87071139471871, 47.942761353084016, 46.54412719181606, 40.176780632564, 34.398269585200715, 27.700777632849558, 24.258452449526104, 13.89828622341156, 20.87799228940691, 17.011531693594797, 13.820696558271136, 5.8859623329980035, 4.841103519712176, 8.389548540115356, 8.436454091753278, 8.393489037241254, 6.050460934638977, 1.9955788723060062, 0.08539439884147473, 0.4101898622299944, 1.9125715664454868, 5.888398545128958, 12.822852730751038, 22.903637102672032, 32.805137974875315, 24.534476586750575, 24.290096282958984, 32.91225487845284, 44.44144943782261, 36.617690971919465, 24.864232880728586, 7.421963248934064, 0.9233087641852242, 0.03465531773066946, 0.0519179339254541, 0.02566217744190778, 0.07716549254421677, 0.025857678647818308, 0.073507978447846, 0.031138857493975332, 0.02645660115272871, 0.056349666656128, 0.032379589309649806, 0.05041267184008445, 0.016876850376970003, 0.034087068401277065, 0.020938299762617265, 0.017704105004668236, 0.029123934185398475, 0.017679133219644427, 0.031533686843301566, 0.06315728636192423, 0.04488154953079564, 0.03030732979199716, 0.016913818661123514, 0.03849529667890497, 0.008048823103308678, 0.006512987078167498, 0.026309197901615074, 0.04774529979165111, 0.020773973848138536, 0.014807315177417226, 0.03233507741242647, 0.021114908857271075, 0.054657274790640385, 0.036804010825497765, 0.021903578591133867, 0.03579959240076797, 0.04308864288032055, 0.08610706417156117, 0.04717056366748043, 0.06136092596820422, 0.014945520886353083, 0.02217156599674906, 0.0353613062761724, 0.07395786752126046, 0.04717879768993173, 0.03378449606576136, 0.060764927949224196, 0.02859495167753526, 0.054730159629668505, 0.022977996384724975, 0.03001754105623279, 0.05253907505955015, 0.04891006282663771, 0.04716457898861595, 0.0671665733680129, 0.08082279629473176, 0.4607655012181827, 8.879354851586477, 22.881960460117885, 45.118593079703196, 48.96524783543178, 40.98305654525757, 27.413150003978185, 25.23002600669861, 28.045022657939366, 28.959992715290614, 20.93536009107317, 8.604517119271414, 3.5605728839124953, 0.502345584332943, 0.23910835811070033, 0.3030134918434279, 2.2934715960706984, 3.248572928564889, 5.059511457170759, 12.263025947979518, 14.622984204973493, 8.054425631250654, 6.308448851108551, 8.130068932260786, 13.995468071528844, 14.768809522901263, 25.06003659112113, 32.62464462007795, 47.27364982877459, 48.12833384105137, 47.10204321997506, 45.17771530151367, 43.691877773829866, 40.17151737213135, 40.728662150246755, 38.06834282193865, 38.27396781103951, 39.02139595576695, 38.5430645942688, 39.7586658341544, 39.86409085137503, 38.22761985233852, 38.27568054199219, 34.84843642371041, 35.37851449421474, 36.45746898651123, 40.68592030661446, 41.83454091208321, 35.78406694957188, 35.43458298274449, 35.738014289310996, 35.372153418404714, 36.13421446936471, 37.15603045054844, 37.21495812279837, 39.986101218632285, 45.51897260120937, 45.65830135345459, 52.575858388628276, 46.79271984100342, 41.20270299911499, 46.164797237941194, 47.57165111814226, 47.29104811804635, 43.77539512089321, 42.71710804530552, 37.30569812229702, 35.64277533122471, 36.114547593253, 36.64626891272408, 36.62232889447893, 39.080966336386545, 42.16644941057478, 36.09935188293457, 38.00008371898106, 36.70815651757376, 37.35882404872349, 39.43968793324062, 38.632817949567524, 39.154995918273926, 40.785644326891216, 41.6514767238072, 44.824653012411936, 48.176331996917725, 47.30978046144758, 49.204008783612935, 49.426945209503174, 49.22217832292829, 49.93351405007498, 48.80646760123116, 47.40219497680664, 41.89783205304827, 36.26346138545445, 27.265466042927333, 21.034312861306326, 17.438838958740234, 19.73436917577471, 14.659243379320417, 9.196632180895124, 14.46428734915597, 11.140667796134949, 9.69964701788766, 7.897118415151324, 5.46726736000606, 3.935166120529175, 1.357438508953367, 0.8863836484295982, 0.5593893719570977, 2.170960089990071, 7.435105766568865, 16.976493665150233, 28.247633865901403, 35.8901173046657, 29.300977298191615, 27.42654960496085, 38.406355312892366, 48.98262528010777, 42.60275459289551, 27.85840446608407, 9.215751017842974, 0.9151859943355832, 0.05137708044743963, 0.026593887446714298, 0.03732806716912559, 0.07665259470897061, 0.024105769083169953, 0.09806656278669834, 0.02291080615084086, 0.028853470126965215, 0.042913516384682486, 0.02186253061518073, 0.01655631552317313, 0.01866087330771344, 0.055063920827316384, 0.013608346343971789, 0.04470500150429351, 0.016542620990159254, 0.04593573171379311, 0.03379400912672281, 0.057746444562716145, 0.04537504465718355, 0.0213450272234955, 0.041460060447986634, 0.043216370312230926, 0.05093763063528708, 0.0326887434348464, 0.018401776407180086, 0.009477196993040187, 0.12952983805111476, 0.12676225655845233, 0.10319969377347402, 0.10243834355579955, 0.18233778939715453, 0.07882397462214742, 0.16462433417992933, 0.1688578227268798, 0.09513921343854495, 0.15859662262456758, 0.10788465916578259, 0.08935543522238731, 0.04874508042952844, 0.07739775508110013, 0.10440207818256957, 0.15928642132452556, 0.09386216982134751, 0.15094295117471898, 0.11628244604383196, 0.06513724476099014, 0.23648419177957944, 0.0993825543139662, 0.09484029162142958, 0.18452029728463717, 0.18416296717311653, 0.13168406459902013, 0.17841557200465882, 0.14263209141790867, 0.7209392775382314, 10.290493164743696, 29.208899770464214, 51.02039296286446, 54.370327949523926, 46.93304565974644, 34.31218487875802, 35.150537150246755, 36.2578889301845, 31.59664821624756, 23.656745399747575, 9.99633422919682, 4.159704540457044, 1.2764017773526055, 0.6252629629203251, 2.0894933300358907, 4.884764262608119, 8.90686103275844, 10.959225143705096, 11.721149836267744, 18.51816691671099, 13.7369282075337, 18.561580998556956, 14.742960487093244, 16.0167007786887, 15.980299166270665, 26.91156996999468, 35.79464905602591, 51.32728794642857, 48.95335946764265, 49.58335610798427, 46.889247689928325, 45.27205099378313, 42.17459964752197, 42.735100405556814, 39.61827400752476, 39.170111724308555, 39.625197887420654, 40.044431345803396, 41.48810025623867, 41.87902675356184, 39.64992305210659, 39.03429528645107, 36.661058153424946, 38.43405430657523, 39.86756495067051, 43.14228916168213, 44.260573932102744, 37.87419973100935, 37.10346038000924, 37.220030307769775, 36.84403548921858, 36.675274167742046, 38.995729310171946, 40.53938627243042, 41.943165574754985, 48.451647417885916, 47.43938520976475, 54.96099083764212, 49.42165763037545, 44.54390410014561, 49.38256359100342, 50.940217699323384, 48.713660512651714, 46.94724082946777, 46.02592011860439, 38.81021588189261, 37.731316975184846, 38.8700225012643, 39.48679671968733, 40.20248549325125, 40.369002546582905, 45.13359076636178, 37.17013529368809, 38.16138614927019, 37.41917610168457, 39.75931896482195, 40.46730218614851, 40.35577317646572, 39.48032099860055, 43.278647559029714, 43.40682792663574, 47.933773858206614, 51.33438900538853, 49.99494654791695, 51.01802362714495, 51.05320930480957, 50.28075722285679, 51.57735013961792, 48.45068161828177, 47.72707884652274, 43.00245319093977, 37.25800221306937, 31.48608500616891, 26.758346557617188, 17.060377529689244, 28.328304188592092, 22.190651178359985, 24.636913878577097, 17.348694767270768, 10.264876893588475, 16.797754730497086, 17.7715517112187, 15.797726563044957, 13.567602344921657, 2.655064970254898, 1.0180842557123728, 1.0186415229524886, 3.1583564324038367, 8.496588144983564, 19.21609956877572, 31.571711131504603, 42.47162471498762, 35.81730365753174, 35.29277719770159, 44.15018442698887, 57.30150890350342, 49.39094659260341, 33.797962597438264, 11.061546053205218, 1.5778822685991014, 0.07825714682361909, 0.17515791180942739, 0.07620630865650517, 0.11702294488038335, 0.10761101956346206, 0.18148407020739146, 0.10603058936872653, 0.08794932745929275, 0.14274490465010914, 0.0878175695293716, 0.21146591353629315, 0.12585722655057907, 0.10728289359914404, 0.06894776171871594, 0.197670577360051, 0.14019780632640633, 0.1848182962941272, 0.14978575041251524, 0.12540039606392384, 0.11372331050889832, 0.09164373350462743, 0.14001705816813878, 0.14036541804671288, 0.09912075514772109, 0.07327348353075129, 0.07541028529937778, 0.11470999542091574], [0.03854449386043208, 0.006840106266151581, 0.03467434724526746, 0.007588604182404066, 0.0226041456418378, 0.04560181784576603, 0.06395038523312126, 0.012883804954721459, 0.010070857458880969, 0.006622879217112703, 0.021640027108203088, 0.025088981592229435, 0.0218866932471948, 0.018088942925844873, 0.06216450820543936, 0.020569887477904558, 0.0447691128855305, 0.061516052644167624, 0.037206914741545916, 0.050314104450600486, 0.02872314051325832, 0.024236953651000346, 0.029777906236371825, 0.06739192841840641, 0.019231573844860708, 0.08702492527663708, 0.002347512761064406, 0.015089066665885704, 0.15148640344185488, 6.441903335707528, 21.75373455456325, 35.421204226357595, 40.62421335492815, 36.41233001436506, 31.511762074061803, 20.068777288709367, 27.80261390549796, 20.41260542188372, 15.590430532182966, 9.52686790057591, 3.8572303482464383, 1.2282197113548006, 0.4484756306878158, 0.11797507878925119, 1.1713442546980721, 1.3674468461956297, 4.181776361806052, 14.841247967311315, 14.075374960899353, 4.683154029505594, 2.766897963626044, 5.659312963485718, 11.875637820788793, 11.569731218474251, 20.674010549272808, 30.742561749049596, 44.23476832253592, 47.263981410435264, 44.298434666224885, 41.99576343808855, 39.77944789613996, 39.54924365452358, 42.30475330352783, 40.2923013823373, 39.367985997881206, 35.932900837489534, 34.406812395368306, 32.42598867416382, 33.974655287606375, 32.36100564684187, 33.436374868665425, 34.21026175362723, 35.14547191347395, 37.36580351420811, 41.97982774462019, 35.834674154009136, 32.9872259412493, 34.70929527282715, 33.54992927823748, 37.255667618342805, 36.9637633732387, 39.13574940817696, 40.196579524448936, 44.067420959472656, 43.37870856693813, 45.31172520773751, 47.77810294287545, 46.253807135990684, 28.83948142187936, 41.9248640196664, 50.38591473443167, 45.18574741908482, 44.357570784432546, 40.15298305238996, 35.18431234359741, 32.831634930201936, 33.680253165108816, 33.03874683380127, 37.016798973083496, 34.76234824316842, 35.81288112912859, 34.238454069410054, 33.95592294420515, 33.728744643075125, 34.17134836741856, 35.52937725612095, 35.283744539533345, 34.27665179116385, 33.945219244275776, 37.44721903119768, 38.08473014831543, 41.79918152945382, 43.12533903121948, 47.25651209694998, 47.71364450454712, 51.55797856194632, 50.48002461024693, 50.35778842653547, 44.002000195639475, 39.17879697254726, 33.522855622427805, 24.200570481164114, 18.313307966504777, 25.997159242630005, 14.852359873907906, 9.380058544022695, 7.327943699700492, 10.39086423601423, 14.815626485007149, 11.141703077725001, 2.1908870892865315, 2.052092045545578, 3.5403436379773274, 1.986369903598513, 0.985332618866648, 0.1024087458582861, 1.962461369378226, 7.571685637746539, 17.69668139730181, 17.699080262865337, 35.31471960885184, 26.551387514386857, 32.38552583966936, 35.07276943751744, 43.49336774008614, 44.75918708528791, 21.70920181274414, 7.397126913070679, 0.8345070406794548, 0.03511655869494591, 0.020019195242119685, 0.016441873806927885, 0.010046547245500343, 0.03899691726214119, 0.045656609548521895, 0.029014659513320242, 0.026566554359825592, 0.035856467206031084, 0.06101129722914525, 0.016803683945909142, 0.020924131951427886, 0.015688389506457106, 0.057855960114726, 0.01915831581157233, 0.055788372310676744, 0.07643644059342997, 0.04304853128269315, 0.005308654001315257, 0.02014719239169998, 0.007181381390962217, 0.025219357007050087, 0.017460317550493137, 0.081160136764603, 0.040023679845035076, 0.06116985050695283, 0.06230999289878777, 0.016268908445324217, 0.044077122517462285, 0.05048007411616189, 0.06792189140937158, 0.03586340522659676, 0.06373575782137257, 0.0629820479080081, 0.011233187945825713, 0.016493372918505753, 0.01109694065858743, 0.04062273805694921, 0.02918583693514977, 0.0386007104867271, 0.015445552001308118, 0.07761525269597769, 0.07311305749629225, 0.034625828598759005, 0.046658958441444805, 0.04251458189849343, 0.09609372221997806, 0.013916625158994325, 0.02176902848961098, 0.05035833475579109, 0.036493146792054176, 0.06144510502261775, 0.02706495868707342, 0.024135843451534, 0.02918775040390236, 0.1890528704971075, 7.534782017980303, 25.745170661381312, 40.59793874195644, 46.09145552771432, 42.253322737557546, 39.674693380083355, 28.198949575424194, 34.972249848502024, 26.19198499407087, 20.548986400876725, 10.48747285774776, 3.6906129802976335, 0.9718068646533149, 0.1405785187546696, 0.35336515999266077, 1.5512935753379549, 3.2170611109052385, 4.22908708027431, 8.724384835788182, 9.151759845869881, 8.092747552054268, 4.3574724197387695, 7.621337464877537, 13.693205799375262, 14.334350824356079, 22.117542232785905, 32.56786046709333, 46.520753451756065, 48.59050369262695, 47.17965807233538, 44.37836674281529, 41.87125866753714, 41.40865455354963, 44.34340688160488, 41.901240144457134, 39.6736615725926, 37.21665348325457, 35.08972304207938, 34.72041586467198, 35.507539067949565, 34.1338107245309, 35.67100933619908, 36.59672825677054, 37.719980989183696, 38.34035784857613, 43.9969801221575, 38.670067242213655, 34.909677846091135, 36.2531988961356, 35.33193029676165, 38.46069022587368, 37.55068118231637, 40.437626429966514, 41.142166818891255, 47.33221966879708, 45.06408098765782, 47.72193023136684, 48.65188755307879, 48.727681977408274, 34.14269399642944, 44.34401484898159, 52.14494848251343, 47.9605313709804, 46.181153297424316, 43.140475681849885, 37.271770068577354, 34.362861565181184, 34.72580419267927, 35.83965948649815, 37.897194794246126, 37.03911658695766, 37.33504383904593, 36.21453217097691, 36.75798552376883, 36.32432413101196, 36.194076674325125, 36.16780553545271, 36.073612281254356, 35.685808999197825, 35.61964477811541, 39.01477779660906, 40.54839808600289, 43.5067013331822, 45.75592701775687, 48.082937785557334, 49.256908893585205, 51.919528075626914, 51.16007259913853, 49.16809701919556, 45.51090921674456, 40.30227552141462, 33.677164690835134, 26.71010521480015, 22.030133894511632, 15.906358173915319, 14.573898656027657, 10.404903071267263, 9.794654948370797, 14.222356285367693, 8.719140682901655, 9.497489179883685, 8.9288729258946, 4.916215283530099, 2.1154122820922305, 1.4829912632703781, 0.539368137717247, 0.6135107363973344, 1.8440306271825517, 8.915382129805428, 17.082924434116908, 24.996861832482473, 37.36554643086025, 32.07580641337803, 36.23435538155692, 39.90172924314226, 48.220192500523154, 50.84700066702706, 26.92770889827183, 8.938780188560486, 1.0381746462413242, 0.027734945860824416, 0.02159635829074042, 0.043189863341727426, 0.04838854420397963, 0.04763075629515307, 0.027058945170470645, 0.016816959483549, 0.07372732846332447, 0.024731564967493926, 0.0394093308464757, 0.07451263096715723, 0.019098075472616723, 0.017035369728026644, 0.02222255620706294, 0.015010639892092772, 0.06331617212189095, 0.030916891725999967, 0.0017378289028004343, 0.019298463826999068, 0.02268990737918232, 0.05249821368072714, 0.03137791216639536, 0.020627230472330536, 0.04151902174843209, 0.018829814956656525, 0.025482241829325045, 0.010290452595134931, 0.09129590966871806, 0.10335496294179133, 0.12196137702890805, 0.07663842011243105, 0.08568802808544465, 0.11959413119724818, 0.17265380546450615, 0.058206464163959026, 0.10552448366901704, 0.08599568943360023, 0.1577480738716466, 0.08770050188260418, 0.12049660991345133, 0.0878279104030558, 0.22082418708928994, 0.16184380623911107, 0.1562011633068323, 0.09996788576245308, 0.16237416278038705, 0.24440071412495204, 0.09203803020396403, 0.06725506111979485, 0.18031096458435059, 0.15726887887077673, 0.1532167355929102, 0.20419998413750104, 0.11078043627951827, 0.10677572938480548, 0.44808365457824295, 8.760235803467886, 30.429385593959264, 47.048274585178916, 52.24356426511492, 48.48945256641933, 43.40118598937988, 30.436514445713588, 39.11723940713065, 29.973222460065568, 23.62370671544756, 13.933874896594457, 5.347199882779803, 1.8407790873731886, 1.0249618866613932, 1.4440404219286782, 3.7233250992638722, 6.0327838488987515, 11.104152406964984, 25.067983593259537, 23.655777863093785, 10.461056675229754, 8.084945593561445, 9.823398777416774, 16.85159284727914, 15.81796840259007, 23.779626028878347, 34.79601226534162, 48.20580278124128, 52.842613628932405, 49.203692640577046, 46.344088554382324, 45.058418205806184, 43.62655428477696, 47.998749937329976, 46.302781513759065, 43.7087653705052, 40.68753228868757, 37.79966293062483, 35.64039209910801, 37.06850399289812, 35.88828992843628, 36.33712271281651, 38.16206707273211, 39.82186664853777, 40.43914113725935, 44.62324905395508, 38.91802065713065, 36.370161397116526, 38.416972160339355, 37.12664304460798, 41.40215451376778, 39.69522530691964, 43.120985984802246, 45.458384309496196, 48.71064846856253, 47.33491209575108, 49.84505305971418, 50.89397048950195, 48.650831426892964, 39.52146475655692, 46.43309497833252, 53.82722895486014, 51.97803885596139, 49.529514517102925, 45.69321952547346, 38.32904270717076, 39.08057376316616, 36.821102959769114, 37.47430658340454, 40.125596727643696, 39.12753316334316, 39.182566370282856, 38.244045393807546, 38.00633709771292, 37.96061100278582, 37.63276025227138, 38.89239570072719, 38.82702704838344, 39.02739919934954, 36.87247099195208, 41.25114236559187, 40.83624110903059, 46.460880824497764, 47.4620224407741, 52.30924906049456, 51.58922808510916, 54.58228622164045, 50.4121858733041, 51.19421257291521, 45.623362336839946, 42.37671232223511, 35.65029328210013, 29.115905080522808, 22.50527776990618, 32.53878573008946, 17.265465770448955, 13.595381242888314, 16.201642717633927, 23.12487816810608, 22.627833570752824, 21.878350496292114, 11.281879510198321, 12.784252882003784, 10.3263258934021, 4.091620010989053, 1.7274107592446464, 0.8899123562233788, 2.651466020515987, 10.955587761742727, 22.998697144644602, 27.65014784676688, 46.72850806372506, 37.504194259643555, 42.65388638632638, 46.56857442855835, 54.46056073052542, 59.13006632668631, 32.693813937050955, 11.481915542057582, 1.3161189832857676, 0.09279117693326303, 0.14002328711960996, 0.12231102612401758, 0.20308291193630013, 0.1284726397799594, 0.20684983980442795, 0.0809657500524606, 0.16035666103873933, 0.09220308384725026, 0.23365527072123118, 0.08937750118119375, 0.09728814741330487, 0.11018825162734304, 0.14338483102619648, 0.10742860220904861, 0.13319921972496168, 0.14807935697691782, 0.1794828668768917, 0.1109960407816938, 0.11442762985825539, 0.07363364313329969, 0.0863053999575121, 0.1130055697368724, 0.12817641853221826, 0.09606830429817949, 0.11907555402389594, 0.1302307647253786], [0.05097583554951208, 0.025895849635292376, 0.07734777419162647, 0.05548917907955391, 0.022787685971707106, 0.040500140349779806, 0.0530601085296699, 0.03261903413970556, 0.025118309572072964, 0.02816395810805261, 0.023902481687920432, 0.05702516183789287, 0.057208712345787456, 0.049473966139235666, 0.06312951392361096, 0.02633353864907154, 0.0173426086881331, 0.013558670795256538, 0.036758627010775466, 0.027215283031442335, 0.041325462849012444, 0.01152683754584619, 0.022928894198100482, 0.04351974331906863, 0.03706197966156261, 0.07220536763114588, 0.017994870830859457, 0.08927373960614204, 0.12783540040254593, 3.797941369669778, 16.97507449558803, 35.87642935344151, 44.91111986977713, 33.30855928148542, 18.756771530423844, 18.099260023662023, 20.823259592056274, 24.91555748667036, 17.316441229411534, 9.836833119392395, 4.445391450609479, 1.0409335153443473, 0.3786611354776791, 0.29673617439610617, 0.7952357679605484, 2.555731786148889, 2.933306234223502, 7.056923568248749, 7.6988698073795865, 7.265889338084629, 2.095990547112056, 6.092412420681544, 11.510396208081927, 10.412496583802358, 19.39608744212559, 30.164044312068395, 43.528699329921174, 43.58533409663609, 42.616557189396445, 40.36390951701573, 40.31369488579886, 44.392513275146484, 47.1739501271929, 45.63217960085188, 45.74758570534842, 43.07325186048235, 40.0723283631461, 36.99000324521746, 35.29270771571568, 33.33566420418875, 34.72213554382324, 35.878475597926546, 38.24886744362967, 37.991804940359934, 35.938553197043284, 34.51656266621181, 33.50560671942574, 34.98242201123919, 37.06894172940935, 40.70670584269932, 41.15255784988403, 44.30123479025704, 44.17630965369088, 45.31608172825405, 48.056159428187776, 47.5090582711356, 51.83705643245152, 43.88434634889875, 30.149908202035085, 42.67928900037493, 50.11208970206124, 43.48530782972063, 42.51664556775774, 39.080365317208425, 33.880600997379844, 32.78927523749215, 35.51799610682896, 36.28229447773525, 36.47618395941598, 34.64969709941319, 35.86475985390799, 35.04800258363996, 34.634334632328574, 34.05427816935948, 36.17875937053135, 37.48290497916085, 35.81208903448922, 33.70435994012015, 34.91151564461844, 33.55831227983747, 37.486049039023264, 36.42242922101702, 43.337019375392366, 44.13526317051479, 46.27916806084769, 47.069344997406006, 51.19162089484078, 46.055602822984966, 45.40538345064436, 37.36035960061209, 31.50659956250872, 21.603295632771083, 19.43467947414943, 8.134778942380633, 12.611104641641889, 11.481761813163757, 6.3116441539355685, 14.363719122750418, 8.949245912688118, 4.2550051638058255, 11.520401614052908, 3.5172721445560455, 0.9815409651824406, 0.8753915439758981, 0.7623040750622749, 0.6315492913126945, 1.4338723846844263, 6.8968409810747415, 19.963751792907715, 33.66228512355259, 22.161274194717407, 25.266731602805002, 25.657470498766216, 42.05814783913748, 47.25477852140154, 38.246300084250315, 20.801885196140834, 4.684852864061083, 0.5479486201490674, 0.013842971030888813, 0.018140479356848767, 0.032642769294657877, 0.04018169708017792, 0.059685724787414074, 0.032055480272642205, 0.027258534549868534, 0.04973293920712812, 0.053360054934663434, 0.03846893559343048, 0.023972226606149758, 0.05656176991760731, 0.02995015574353082, 0.07595330330410174, 0.045318858564964364, 0.030845849109547477, 0.057901299824672084, 0.00955842696462891, 0.010493337110217129, 0.027028426361669387, 0.018840201631454483, 0.04569945564227445, 0.07353635478232588, 0.050877780453967195, 0.0374644662785743, 0.024222271849534342, 0.061103591562381813, 0.030895110751901354, 0.03775088608797107, 0.05960658046283892, 0.009013209658275758, 0.06886088888027839, 0.04551004598449383, 0.04322482825123838, 0.030398209379719834, 0.031716908261712105, 0.07140308818114655, 0.004411391523067972, 0.03114823145525796, 0.015436849789693952, 0.09044660095657621, 0.03738675366288849, 0.040944499362792285, 0.039566197964761934, 0.05175504820155246, 0.0415149505383202, 0.0240795912021505, 0.00981621683708259, 0.04513983049296907, 0.006691816254585449, 0.0139467970667673, 0.07156816896583353, 0.02224283422609525, 0.007792257138394884, 0.07810660025903157, 0.28987577823655947, 4.922679279531751, 20.59539863041469, 41.89406612941197, 50.03619800295149, 40.559053148542134, 24.465590408870153, 20.72433114051819, 24.3474953515189, 25.50644098009382, 20.44138659749712, 12.333605749266487, 5.4854568753923685, 1.4971522348267692, 0.22754095095608914, 0.34938110091856545, 1.0378172482763017, 3.1424672050135474, 4.927344126360757, 4.759764867169516, 7.828343408448355, 9.204504489898682, 4.5055433085986545, 5.407927138464792, 9.533114331109182, 13.723871673856463, 20.807134560176305, 31.313988549368723, 45.087256704057964, 46.47313049861363, 44.41550139018467, 42.84614651543753, 42.941111019679475, 45.53642995016915, 48.7439546585083, 47.057432310921804, 47.00846835545131, 45.31963920593262, 42.41610166004726, 37.84661538260323, 37.85989339011056, 36.074942861284526, 36.62951333182198, 37.58205924715315, 40.04114832196917, 39.80389165878296, 37.66377353668213, 36.360315799713135, 35.405202525002615, 35.975503717150005, 38.724707875932964, 41.14430338995797, 42.9071239062718, 45.73539856501988, 46.52073608125959, 47.38309785297939, 49.36024250302996, 51.29944998877389, 49.892029830387656, 45.70455551147461, 34.110339709690635, 43.14788940974644, 51.97821256092617, 45.431209904806956, 44.63584961209978, 42.047166211264475, 36.59834371294294, 35.25011873245239, 36.63092381613595, 36.28738750730242, 38.313047954014365, 35.88028907775879, 37.151402950286865, 37.19386339187622, 35.838370595659526, 35.299600328717915, 38.95388725825718, 38.788131032671245, 37.772495474134175, 36.05249670573643, 36.09924765995571, 34.88927446092878, 38.71732888902937, 39.15210894175938, 45.095069953373496, 46.00659717832293, 47.412926469530376, 49.56072582517351, 50.9037709236145, 46.66560254778181, 47.25271838051932, 39.00906637736729, 32.101559911455425, 25.42200994491577, 20.48262241908482, 12.73050161770412, 17.46409218651908, 17.171458380562918, 11.713183726583209, 13.943552868706838, 12.557416779654366, 9.74657688822065, 13.748467428343636, 4.0367544293403625, 3.2920938389641896, 1.835071142230715, 0.5172060440693582, 0.7731744774750301, 2.050194753067834, 8.812756368092128, 21.281793798719132, 28.983356033052715, 31.108787400381907, 30.522206578935894, 33.10849632535662, 45.32005957194737, 52.7586099079677, 45.01023244857788, 25.515690769468033, 6.309773785727365, 0.7594282808048385, 0.05263726586209876, 0.04968575048925621, 0.010521402166757201, 0.031476214927222045, 0.024366160289251378, 0.05023445461743644, 0.008621355685006295, 0.030429354137075797, 0.01686243150782372, 0.007106341779165502, 0.03657068298863513, 0.039676015464855094, 0.03259789438119956, 0.06879584451339074, 0.13879171891936234, 0.024096144063930427, 0.021802459909979786, 0.010821955012423652, 0.10923562917326178, 0.027533711034006307, 0.02143877192533442, 0.10097785121096031, 0.02515650261193514, 0.007352658048538225, 0.05213208297001464, 0.02281275953698371, 0.011599674887423004, 0.09295062587729522, 0.1390687511967761, 0.14987026873443807, 0.12744697981647082, 0.14972274165068353, 0.09217085343386446, 0.10623746791056224, 0.09613761665033442, 0.14538402589304106, 0.21456077960985048, 0.09342621785721608, 0.1372951827943325, 0.1962646935135126, 0.16042702512017318, 0.13505514870796884, 0.13428954407572746, 0.12035771379513399, 0.139562100438135, 0.14015500433743, 0.09431168570050172, 0.11293570098600217, 0.06450610541339431, 0.14056513804410184, 0.15404044996414865, 0.13369807867067202, 0.12678649382931845, 0.0896799038829548, 0.2598978296986648, 0.46103376682315556, 5.678799186434064, 24.248108318873815, 47.5916862487793, 57.12095648901803, 45.793245792388916, 27.85476187297276, 28.990097522735596, 31.529938561575754, 34.171438694000244, 25.383921657289775, 14.145231281008039, 6.754449376038142, 1.6622073437486375, 0.7730686802949224, 1.3007445739848273, 4.777419371264322, 7.852674262864249, 9.610502498490469, 14.160329716546194, 12.581607801573616, 12.025213428906032, 6.68013231243406, 12.507466179983956, 15.016641344342913, 13.901613542011805, 22.393679278237478, 33.334208556583945, 47.512706075395855, 48.7433362688337, 46.963878290993826, 44.934775011880056, 45.42464733123779, 49.10807500566755, 51.54910223824637, 50.29364613124302, 50.09612274169922, 47.25513635362898, 44.96654217583792, 41.0724208014352, 40.279169287000386, 37.613030842372346, 39.02906329291207, 40.15253141948155, 42.860702991485596, 41.428363118852886, 39.86432014192854, 39.18304927008492, 37.507984501974924, 37.63270814078194, 41.24052899224417, 43.27787283488682, 45.97196735654558, 48.03884104319981, 48.15665469850813, 50.375054700034006, 52.66024773461478, 52.511827264513286, 51.40854018075125, 46.67278698512486, 39.151066711970735, 44.86937856674194, 55.20140893118722, 48.39137526920864, 48.45602478299822, 42.963449478149414, 38.16788271495274, 36.92053862980434, 38.85222816467285, 38.531124114990234, 40.587547710963655, 38.33674825940813, 39.642818519047324, 38.766647202628, 37.597595419202534, 38.02614641189575, 41.79206657409668, 41.33916909354073, 40.03715658187866, 37.06400850840977, 39.67529787336077, 37.54833269119263, 40.94021395274571, 40.37443603788103, 48.19816671098982, 47.592162200382774, 51.114277022225515, 50.236323492867605, 54.188757623944966, 46.30610622678484, 48.941307817186626, 38.38936349323818, 35.07585791179112, 23.031235558646067, 24.798980610711233, 11.996482627732412, 19.024985892432078, 21.385398387908936, 13.203960554940359, 21.269792522702897, 18.05961881365095, 13.971649646759033, 14.993955475943428, 6.94744427715029, 3.2321111261844635, 2.9896229037216733, 1.4366040038211005, 1.634642320019858, 2.4492819096360887, 10.480014835085187, 27.149250473294938, 43.51793309620449, 32.62342521122524, 35.63715771266392, 37.32475355693272, 53.32528414045061, 59.296308926173616, 52.70111009052822, 29.6856677872794, 8.55515364238194, 0.9154896523271288, 0.21856207347341947, 0.06528705850775753, 0.0921644548486386, 0.16208620608917304, 0.22680639608630113, 0.1400569560272353, 0.11843530195099966, 0.15002893736319883, 0.11465241493923323, 0.06796919208552156, 0.17484465933271817, 0.19709261480186666, 0.1504124996385404, 0.17056144773960114, 0.19921797647007874, 0.10590349297438349, 0.14141477245305265, 0.09035419127238647, 0.2526100107601711, 0.0672353564628533, 0.087264231007014, 0.21428536224578107, 0.09951817310814347, 0.09294035964246307, 0.1264623983630112, 0.07498513561274324, 0.12176127705190863], [0.036478157953492234, 0.02727428504398891, 0.016517074146707143, 0.03328963369131088, 0.05845205991395882, 0.03388675468574677, 0.03702940658799239, 0.042256202548742294, 0.04673800098576716, 0.013820023824726897, 0.03281605356772031, 0.033312703881944926, 0.0494006538231458, 0.01818874355272523, 0.012185119990525501, 0.02307051802719278, 0.0332267199243818, 0.04157430538907647, 0.08757730027926819, 0.025951998408085535, 0.03986261259498341, 0.043067774535822015, 0.03912968620924013, 0.08428861067763396, 0.03047258360311389, 0.02846708514594606, 0.05698928769145693, 0.07749085687100887, 0.06897017373038189, 1.9243418148585727, 13.814530032021658, 33.02514573505947, 40.3345707484654, 36.52689191273281, 31.996378081185476, 28.211468492235454, 30.002519539424352, 28.84987071582249, 18.305579832621984, 11.328496711594717, 4.876582324504852, 1.870333467211042, 0.4983434219445501, 0.40507783368229866, 0.31852187109845026, 1.422825726015227, 1.054935438292367, 1.5652255820376533, 6.710281848907471, 10.915570480482918, 4.259982679571424, 3.366158596106938, 6.58037702526365, 11.467306085995265, 17.585070746285574, 26.060596295765468, 43.925010681152344, 44.629429476601736, 42.52579981940133, 38.99971757616316, 42.2269195829119, 43.685179710388184, 50.776910713740754, 50.44105216435024, 48.03530788421631, 44.83729873384748, 43.495059626443044, 42.6781564440046, 38.64283377783639, 38.182790075029644, 37.01552745274135, 38.15671695981707, 40.62507493155343, 38.92974574225289, 37.2724266733442, 34.890341009412495, 34.97667237690517, 35.97416966302054, 40.29523352214268, 44.58423491886684, 44.52964987073626, 47.45911809376308, 45.98960535866873, 48.38769619805472, 47.87911932809012, 50.73366859980992, 45.01958819798061, 38.29899869646345, 31.403463976723806, 42.29685320172991, 48.95901182719639, 44.62658071517944, 41.227188450949534, 39.095783369881765, 34.83521400179182, 33.19230897086007, 33.965747697012766, 33.49050828388759, 35.26944167273385, 34.75086634499686, 35.31393446241106, 36.32763147354126, 35.3379613331386, 36.56810515267508, 43.27438136509487, 43.54973152705601, 41.06622300829206, 38.86007615498134, 35.69709287370954, 34.651854515075684, 35.56180797304426, 35.65213108062744, 39.55628565379551, 42.65270519256592, 43.34046220779419, 43.59098645618984, 49.93995155606951, 50.39022261755807, 42.59220722743443, 37.608545780181885, 27.284908839634486, 25.47541379928589, 18.988129173006328, 11.212865659168788, 14.611074992588588, 10.266044190951757, 10.750731417110988, 12.457617197717939, 6.232225375516074, 10.146888664790563, 15.284202575683594, 1.8699762863772256, 3.9256944230624606, 1.415239378809929, 0.18632984161376953, 0.4351348994033677, 2.029160167489733, 8.6657281432833, 15.118349075317383, 31.178905146462576, 30.374800545828684, 26.305938925061906, 27.258382354463848, 32.028621196746826, 45.55653803689139, 39.01473958151681, 21.69878125190735, 6.298433891364506, 0.30213131489498274, 0.02496396321138101, 0.015984437727768506, 0.03376728163233825, 0.07755712260093008, 0.013297603598662784, 0.02098492529642369, 0.019152536389550993, 0.03247354944635715, 0.017623237201145718, 0.0553396265687687, 0.02605025197512337, 0.08077942433633975, 0.02529464046736913, 0.10430061005588089, 0.06668014518384423, 0.04525626031681895, 0.022312597804037586, 0.01857107598334551, 0.024775910623637692, 0.03579509032091924, 0.025639225994901996, 0.039682095138622184, 0.02852064530764307, 0.021677819812404256, 0.01726663312209504, 0.019331472859318768, 0.04879818258008786, 0.051410576328635216, 0.027117652020284107, 0.03844970591100199, 0.06421521745089974, 0.06819143944552966, 0.0330517630624984, 0.026686186868963496, 0.02818847188193883, 0.07871492047395025, 0.04114258069811123, 0.02958520907642586, 0.043346893308418136, 0.051725928871227164, 0.014328880135768225, 0.04214924168107765, 0.01493752095848322, 0.04184459302840488, 0.028030661599976674, 0.021502974908798933, 0.030642051116696427, 0.024715850096462027, 0.0022025537203132573, 0.01783461612649262, 0.13360229666743959, 0.01616201882383653, 0.011334537328886134, 0.028740673858140196, 0.09655735841287033, 0.059920715035072396, 2.966823692832674, 17.64283980642046, 38.58385051999773, 45.64758028302874, 40.55289009639195, 34.0245954649789, 32.35112878254482, 33.04803310121809, 33.21198974336897, 22.519024780818395, 13.231837596212115, 6.0631222895213535, 2.041969822985785, 0.543283013360841, 0.32108714058995247, 1.234622259225164, 3.2879737743309567, 5.373954789979117, 5.522630172116416, 5.288825026580265, 10.073558245386396, 5.034379388604846, 5.3357961518423895, 7.094160267284938, 11.944102764129639, 21.938829353877477, 30.945959840502056, 44.64355516433716, 48.093804768153596, 44.87703895568848, 41.505977971213206, 42.8671543938773, 47.54202747344971, 52.25179788044521, 51.01266656603132, 49.36030156271798, 46.98036636625017, 45.34653220857893, 44.092552593776155, 40.62899718965803, 38.97316156114851, 37.66799109322684, 39.874822344098774, 41.977569580078125, 42.21506248201643, 38.70323099408831, 36.89186341421944, 35.62535619735718, 36.365794454302105, 42.679792744772776, 45.644498756953645, 47.05548334121704, 49.87748030253819, 47.30519812447684, 49.81042323793684, 49.66200624193464, 51.18028143474034, 46.92524283272879, 39.44451693126133, 34.027340003422324, 44.25795446123396, 50.783504554203574, 46.734559944697786, 43.66012103216988, 42.138618401118684, 36.00869526181902, 35.433224609919954, 37.2209335735866, 35.670168604169575, 36.06774452754429, 37.003746782030376, 35.348647662571494, 38.47455188206264, 36.96489245550973, 38.599810532161165, 43.384027412959504, 44.67101444516863, 42.19369329724993, 39.84706081662859, 37.630832127162385, 36.64352437428066, 37.850221497671946, 38.12050642286028, 41.114572048187256, 43.895873410361155, 45.89424133300781, 46.98147807802473, 52.440823623112266, 50.467629023960654, 43.45845651626587, 39.33595132827759, 29.029570238930837, 23.976918390819005, 18.624399662017822, 13.767227564539228, 12.963122963905334, 11.7039669411523, 15.801633187702723, 9.219137396131243, 9.564029472214834, 9.275188514164515, 10.328280074255806, 5.1774910007204324, 2.892804967505591, 1.2705485714333398, 0.279824041894504, 0.2844132456396307, 2.3394291528633664, 8.57348472731454, 18.84207456452506, 35.852947916303364, 31.99038178580148, 29.350629125322612, 32.682168756212505, 40.75210884639195, 53.56328773498535, 43.72998864310128, 25.85894046510969, 7.249347848551614, 0.48294735380581444, 0.12363256806773798, 0.011010481726511248, 0.07381638618452208, 0.013019809665690576, 0.02229403138958982, 0.05461508348318083, 0.0233392195909151, 0.07651748481605734, 0.01609416871464678, 0.036772764287889004, 0.045536990610084364, 0.01659047806502453, 0.01726644652496491, 0.051017880971942625, 0.09605849268180983, 0.059972195486937246, 0.00999486492946744, 0.01733272582558649, 0.03134669955553753, 0.03863812830033047, 0.051399685841585906, 0.022447324324665324, 0.061619094972099574, 0.02270329317876271, 0.04750696775902595, 0.018635597878268788, 0.06814994702913932, 0.11459184890346867, 0.08884088854704585, 0.15235187485814095, 0.08131714298256806, 0.2784334250858852, 0.05406313595761146, 0.12150217166968755, 0.08699972448604447, 0.18624548614025116, 0.10503762800778661, 0.10780340459729944, 0.17190749836819513, 0.20679506845772266, 0.1596400873469455, 0.07746983585613114, 0.07999504464013235, 0.17992240829127176, 0.07814878478114094, 0.16101794769721373, 0.10468421982867376, 0.09216658544859715, 0.18380626131381306, 0.16224103420972824, 0.24883377339158738, 0.10187762935778924, 0.07653403428516217, 0.12607571482658386, 0.234743559466941, 0.11692150389509541, 3.3774038212639943, 21.297972679138184, 45.71533564158848, 51.54333870751517, 47.42762885774885, 43.93384878976004, 40.04320846285139, 41.444965839385986, 38.46349729810442, 26.679515770503453, 16.392033781324113, 7.840551393372672, 2.6534979343414307, 1.0311366638966968, 1.4252669321639198, 3.5241406559944153, 6.798450146402631, 8.319604498999459, 7.8879563467843195, 15.841767719813756, 20.39577862194606, 10.21595983845847, 9.500648873192922, 10.343019809041705, 14.78784932409014, 21.41942024230957, 31.9711491721017, 48.795298371996196, 49.92087180273873, 46.27985940660749, 45.0498753956386, 44.91090794972011, 49.74818474905831, 55.40147188731602, 54.369914531707764, 51.81140715735299, 49.876722948891775, 46.90234157017299, 47.96579463141305, 43.49426058360508, 42.36256231580462, 40.71585314614432, 42.375826426914756, 45.301525252205984, 44.93016140801566, 40.41860226222447, 38.88405091421944, 38.15885353088379, 38.96117244447981, 43.640151909419465, 47.75827278409685, 49.01406240463257, 51.34192432676043, 49.39522320883614, 51.219441481998985, 51.48979588917324, 50.52580976486206, 47.935472692762104, 43.208314418792725, 38.21409518378121, 45.355394635881694, 54.23285436630249, 49.3384599004473, 44.574677671704976, 45.285867486681255, 38.30553347723824, 37.00071389334542, 38.4040276663644, 36.54755238124302, 37.22722864151001, 38.341879504067556, 37.90243721008301, 40.3059024810791, 37.971078463963096, 41.32253163201468, 46.624771458762034, 48.4018531526838, 44.3081100327628, 42.50873851776123, 38.431257656642366, 38.27271018709455, 39.09653377532959, 40.983612401144846, 42.963373047964915, 47.68217611312866, 47.66270726067679, 49.311316762651714, 53.69840587888445, 53.23518337522234, 43.85335738318307, 42.12018830435616, 28.419212681906565, 28.283964259283884, 21.650539909090313, 13.904972127505712, 20.320249966212682, 15.108423573630196, 20.20334652491978, 22.628915752683366, 15.764545440673828, 20.373401948383876, 22.218242474964686, 9.523134112358093, 9.22455438545772, 3.491803739752088, 1.3772251329251697, 0.7645488317523683, 3.137868583202362, 11.539410148348127, 23.034070423671178, 39.752950940813335, 41.72217117037092, 36.62671320778983, 38.628127915518625, 44.925367150987896, 59.740597588675364, 50.99808924538748, 31.701201234545024, 9.698080199105398, 0.8726576449615615, 0.17152754589915276, 0.1177954434284142, 0.13799566163548402, 0.13938857189246587, 0.09405381525201456, 0.15085380524396896, 0.09385076364768402, 0.21909878110247, 0.12644586924995693, 0.18447835024978432, 0.10250396467745304, 0.14307620615831443, 0.11969536862203053, 0.1873732384826456, 0.17584581061133317, 0.14824411885014602, 0.13637278228998184, 0.08684951718896627, 0.10147348032998187, 0.20926138040210518, 0.15958668664097786, 0.07371824287942477, 0.11429515268121447, 0.112983578416918, 0.14405472150870732, 0.11917468799012047, 0.15480344902191842], [0.046872432343661785, 0.05411774445591228, 0.012796776053229613, 0.01596787299162575, 0.020477640642119304, 0.056201328723026175, 0.045772126742771695, 0.05452101478087051, 0.028097526137051836, 0.02978201476590974, 0.037114084365644624, 0.07253990575139012, 0.027195834521470324, 0.02331224612758628, 0.05637904043708529, 0.02935003223163741, 0.029551143225814615, 0.01999926836495953, 0.04483026585408619, 0.03498266677239111, 0.016196786958192076, 0.030951544509402344, 0.006295082342278744, 0.03132430111457195, 0.05930236607257809, 0.03845071692817977, 0.04912159272602626, 0.03869337122887373, 0.04088849986770323, 1.5872730846915926, 9.986664942332677, 27.246917826788767, 36.6265811920166, 40.223635809762136, 27.860415969576152, 26.08987774167742, 24.496829509735107, 24.309394904545375, 18.683730329786027, 10.569982716015407, 7.315523794719151, 2.3366928654057637, 0.7697036351476396, 0.056248900813183615, 0.94341022840568, 2.5525588478360857, 5.511122218200138, 4.295377237456186, 2.4059108197689056, 7.977095655032566, 2.322190020765577, 2.477508097887039, 3.5279523943151747, 8.871300152369908, 15.72468536240714, 26.218709502901348, 42.352285930088584, 45.699139390672954, 42.035340377262656, 38.890509264809744, 38.963107517787385, 44.56131975991385, 48.25062908445086, 50.040714332035606, 47.96804237365723, 47.82708426884243, 46.70259475708008, 44.6096271106175, 43.81371791022164, 41.64257608141218, 40.704128061022075, 40.65836722510201, 41.44661603655134, 40.51935461589268, 36.63904973438808, 33.3011976650783, 33.40787335804531, 38.31007065091814, 45.881071022578645, 47.027120794568745, 49.74904979978289, 49.21474027633667, 47.641206060137065, 51.48766279220581, 48.77461705889021, 45.52745982578823, 46.166360582624165, 40.97931146621704, 33.59678445543562, 42.03265142440796, 49.054070132119314, 43.23183754512242, 41.67136246817452, 38.12353583744594, 33.45745570319039, 32.86759533200945, 34.62279714856829, 34.8042528288705, 35.11025844301496, 34.83885485785348, 33.65816484178816, 33.35362182344709, 35.173587799072266, 41.56595829554966, 44.9650239944458, 46.33356203351702, 44.007325989859446, 40.9918668610709, 38.70917170388358, 35.65552180153983, 34.280601842062815, 36.6863044330052, 37.810352734157014, 39.52472346169608, 43.02243621008736, 43.69898230688912, 45.214367049080984, 48.16685465403965, 43.358458042144775, 36.64680044991629, 26.155204704829625, 20.165381567818777, 13.8536388363157, 14.095879094941274, 14.003903184618268, 18.002145051956177, 14.948462145669119, 7.9675436190196445, 10.843546322413854, 7.394553474017552, 13.551117743764605, 3.6743007813181197, 3.0460857025214603, 0.8562407887407711, 0.22568404488265514, 0.6331222983343261, 2.1619573959282468, 7.844950471605573, 15.174740655081612, 23.5759847504752, 25.937686136790685, 27.835107156208583, 27.48669147491455, 37.838746547698975, 40.408027103969026, 36.2749537059239, 25.5813182422093, 6.947398245334625, 0.6251520631568772, 0.04866360194448914, 0.007036159629933536, 0.041102058586797545, 0.060998995389257155, 0.008023736815500473, 0.03536355222708412, 0.010104377936970974, 0.05314685244645391, 0.02592245668971113, 0.032870682422071695, 0.02085475344210863, 0.036301294408206425, 0.013942268693686595, 0.044836128396647315, 0.030578479170799255, 0.035566373129508326, 0.054470426602555175, 0.014526825764083436, 0.03658654035202094, 0.07731753867119551, 0.0989912703101124, 0.016759686038962433, 0.008584844563821597, 0.01903431862592697, 0.0288834986942155, 0.06283777779234306, 0.010862840139972312, 0.13217782096139022, 0.09570770364786897, 0.04254425423485892, 0.007997439342683979, 0.020085148845932314, 0.03325144234778626, 0.021699156346065656, 0.05614674736612609, 0.03126752469688654, 0.041664241813123226, 0.03462084475904703, 0.03429646430803197, 0.012657952877426786, 0.031361820708428106, 0.046428555090512545, 0.023222223190324645, 0.04214277524234993, 0.03332159947603941, 0.03912673458190901, 0.023646782551492964, 0.014912421948143413, 0.0662852106615901, 0.031522141569959264, 0.027975203236564994, 0.055507027943219454, 0.05757835108254637, 0.04858348731483732, 0.09678320200847727, 0.050061492648507865, 2.1076704689434598, 13.360166481563024, 34.32582766669137, 42.882826055799214, 45.92018938064575, 35.25345734187535, 30.22738061632429, 31.168812888009207, 29.42928273337228, 23.47707540648324, 14.852936574390956, 7.849867190633502, 2.897508029426847, 0.8817174988133567, 0.15809580949800356, 0.782747140952519, 3.331917004925864, 4.096199742385319, 5.896632594721658, 6.857810344014849, 7.844508392470224, 7.126631370612553, 4.4753095252173285, 5.740523074354444, 10.235295806612287, 18.84687055860247, 29.288227353777202, 45.6010308265686, 45.9849396433149, 44.10060903004238, 40.880980559757774, 42.21618461608887, 45.20027610233852, 50.84615993499756, 49.824757371629985, 48.40074838910784, 49.44264466421944, 46.743999072483604, 46.1640225137983, 44.952055181775776, 43.57891396113804, 42.52071026393345, 41.54157359259469, 44.36950084141323, 42.16872494561331, 37.19592005865914, 34.953058923993794, 35.6068184035165, 40.829265117645264, 47.98310954230172, 48.6011518069676, 51.47220999853951, 51.833617074149, 49.27017995289394, 52.06556183951241, 48.52514198848179, 45.6083333832877, 46.33318335669381, 42.033401829855784, 37.22586679458618, 45.60090228489467, 50.89463056836809, 45.88398926598685, 43.38398919786726, 39.15403011866978, 36.121652126312256, 34.31098631450108, 35.11457674843924, 36.47833442687988, 36.67355101449149, 34.739648478371755, 35.12130260467529, 35.94340303965977, 36.23612717219761, 42.71053852353777, 46.55081830705915, 47.915020670209614, 46.83637537275042, 43.92049782616751, 40.06459501811436, 38.04929086140224, 36.564481667109895, 38.847110816410606, 40.24032538277762, 42.97822134835379, 45.696471282414024, 47.94360555921282, 47.545223644801546, 49.14182588032314, 43.32540546144758, 38.323671749659944, 28.34869020325797, 22.793671437672206, 14.669881071363177, 13.279014127595083, 6.7089851413454324, 9.5941082239151, 10.17231820310865, 10.812827467918396, 10.205031190599714, 8.909468344279698, 7.212719985416957, 3.7923189742224555, 2.3536636233329773, 0.7655724425401006, 0.3942274073404925, 0.727104555283274, 2.780345984867641, 10.233733330454145, 19.63977987425668, 30.650001321520122, 35.847219126565115, 32.136547565460205, 30.41076442173549, 40.87840972627912, 46.83898442132132, 43.6895431791033, 27.814344201769146, 8.925402300698416, 0.6242824526769775, 0.04862307644050036, 0.04232934183840241, 0.04353089164942503, 0.02767009487641709, 0.07747585446174655, 0.07063428086361714, 0.022729520253571014, 0.006206670077517629, 0.02415472877744053, 0.002869566578218447, 0.018992768534060036, 0.018190056517986313, 0.039588501410824914, 0.030007393565028906, 0.03690909215116075, 0.02849965143416609, 0.08190376364759036, 0.015869158020775233, 0.03731243032962084, 0.08076620647417647, 0.06325251875179154, 0.03238996071740985, 0.04122845269739628, 0.02429087852526988, 0.04070533273209419, 0.02492987021936902, 0.032655617355235984, 0.19455827293651445, 0.24538098009569304, 0.11608466665659632, 0.10551357282591717, 0.05640425479837826, 0.17932821517544134, 0.11486681843442575, 0.14823632926813193, 0.09538170149815933, 0.1453573051840067, 0.09728603038404669, 0.11919332056173257, 0.1040448702073523, 0.06385480000504426, 0.14466562015669687, 0.07731650729796716, 0.087111811685775, 0.12974208380494798, 0.11588277534714767, 0.1192454591925655, 0.07156776863017253, 0.13899713861090796, 0.12352561737809863, 0.10948546576712813, 0.10305646181638752, 0.09051630007369177, 0.12022758434925761, 0.14654517572905335, 0.11982253965522562, 2.517580530473164, 16.02833206312997, 41.61525923865182, 49.083603450230186, 53.726862226213726, 38.38942950112479, 35.896054540361675, 35.09838744572231, 33.328712531498496, 28.03635130609785, 17.290923970086233, 10.83754915850503, 3.6587307368006026, 1.749375426343509, 0.4246352756662028, 2.194002922092165, 6.491605971540723, 11.820418749536787, 12.199756520135061, 10.145266260419573, 16.549518176487513, 8.140686648232595, 5.446479218346732, 6.516084040914263, 12.79817533493042, 20.125815050942556, 29.07749022756304, 47.05562925338745, 50.8329861504691, 46.640234674726216, 43.128854819706504, 44.060524872371126, 48.61080980300903, 53.16508994783674, 51.68914665494646, 47.54785006386893, 50.834358419690815, 49.74501289640154, 48.93810817173549, 48.21420662743704, 45.60200704847063, 45.76591157913208, 44.68048831394741, 46.788884435381206, 43.573310238974436, 39.66303082874843, 36.538953985486714, 36.57002285548619, 44.87523589815412, 50.63030024937221, 49.77637359074184, 53.65004989079067, 52.47945213317871, 50.96398401260376, 52.3462621143886, 47.568111010960166, 46.87508031300136, 47.06748982838222, 41.72244562421526, 41.374486786978586, 46.59137494223458, 51.97834457669939, 46.52168798446655, 46.00297021865845, 41.588890824999126, 38.37514400482178, 36.775998728615896, 37.44811187471662, 38.59392193385533, 39.169076442718506, 37.114733832223074, 36.79458515984671, 37.424765927451, 38.59089251926967, 46.43558938162667, 48.82517215183803, 50.53136484963553, 48.55638108934675, 45.782955510275706, 43.19847229548863, 40.80172940662929, 37.935722555433, 42.00491768973214, 41.07200390951974, 43.85091161727905, 48.081628050122944, 48.86437388828823, 49.48916980198452, 51.86754860196795, 44.56218481063843, 39.48594903945923, 29.35969305038452, 23.167722497667583, 15.336128200803484, 18.301930291312082, 20.302367040089198, 23.561339684895106, 24.175280775342667, 16.741516011101858, 21.19231837136405, 18.657424449920654, 22.868901320866176, 9.438846383775983, 5.18092862197331, 2.8304976480347768, 0.8400145194360188, 2.024075823170798, 3.6949134809630255, 10.836450474602835, 21.4390732220241, 34.26663943699428, 37.249150208064485, 41.53210667201451, 39.20096172605242, 48.229179995400564, 54.40563522066389, 50.048312187194824, 33.21129839760916, 10.807438271386282, 1.0571188011339732, 0.14259785254086765, 0.14581496348338469, 0.11682893814785139, 0.1054217873939446, 0.10947030050946133, 0.13793998105185373, 0.13034429720469884, 0.11135928093322686, 0.1577057604278837, 0.14772099549216883, 0.13081047790391104, 0.19401011163634913, 0.092901133533035, 0.07226679540638413, 0.07858718625668969, 0.16963007700230393, 0.23887268932802336, 0.09889745605843407, 0.09019686614296266, 0.18119349437100546, 0.2244026179292372, 0.0762349089075412, 0.07452287684593882, 0.12019006136272635, 0.13416653924754687, 0.10254429001361132, 0.10597634049398558], [0.03950730791049344, 0.045232151967606375, 0.07251323253980704, 0.1017960219510964, 0.11514595417039734, 0.05120448828009622, 0.10056982096284628, 0.04566328972578049, 0.03406433069280215, 0.09310404943036181, 0.04717036010697484, 0.023074317823297212, 0.04549034132755228, 0.017995581596291492, 0.024344269053212235, 0.00361716331514929, 0.012649562791921198, 0.02806097684827234, 0.08833388039576155, 0.02747319928104324, 0.03159850050828286, 0.01390360067931137, 0.10002065543085337, 0.017073267605155706, 0.023356186359056404, 0.04838081569011722, 0.019278472489012138, 0.04691875932206001, 0.004320476312256817, 0.5621539407542774, 10.057804073606219, 22.044071980885096, 35.252418586185996, 43.714216232299805, 30.220543588910783, 43.088388511112754, 35.12625319617135, 25.25980772290911, 26.93590256146022, 19.18252761023385, 9.93000933102199, 4.318785284246717, 1.1102859824895859, 0.48203898540564943, 0.3410406027521406, 2.177940206868308, 2.97894395674978, 5.550994455814362, 4.222853243350983, 4.829840489796229, 6.510434286934989, 2.461858800479344, 5.232142491000039, 6.920375832489558, 16.2140782560621, 25.55535282407488, 39.32087026323591, 47.90747840063912, 45.72699819292341, 40.31886781964983, 38.98156540734427, 40.56526831218174, 46.048817907060894, 48.10177435193743, 48.33851684842791, 46.62663010188511, 48.01701327732631, 47.11295536586216, 45.68124083110264, 43.66857698985508, 43.04758868898664, 43.054175581250874, 41.34809405463082, 39.01297126497541, 36.618684564317974, 33.863477161952424, 33.30920198985508, 39.3840537071228, 47.010226249694824, 49.87730312347412, 48.27344349452427, 48.992776598249165, 47.948649951389854, 51.71834298542568, 45.91402285439627, 44.90660006659371, 49.07127387183053, 47.589421136038645, 34.46444075448172, 39.37832491738455, 48.0691317149571, 40.75350890840803, 42.162860666002544, 36.76074048451015, 35.66464131219046, 34.6839656148638, 35.655264718191965, 33.09182064873831, 35.14957135064261, 33.70653820037842, 34.46658427374703, 33.39051675796509, 36.821756090436665, 43.87221132005964, 50.370851039886475, 49.62666422980172, 48.0429995400565, 44.19366972787039, 42.34676211220877, 38.41374124799456, 38.334160055433, 36.55050883974348, 38.21462672097342, 40.94368805204119, 42.867373262132915, 44.275377069200786, 50.453447750636506, 48.61991889136178, 41.15128632954189, 33.28942741666521, 25.15833101953779, 16.26891691344125, 14.264833228928701, 10.278726390429906, 4.525473347731999, 3.788903500352587, 8.531471576009478, 6.3194743394851685, 4.876672651086535, 3.647480300494603, 3.265826391322272, 2.478985675743648, 2.5279372547354018, 0.7682625896164349, 0.3974305811737265, 0.45859701186418533, 2.519537534032549, 8.038509913853236, 18.233514853886195, 29.693828446524485, 27.20294267790658, 30.83392013822283, 37.127681800297324, 42.50858565739223, 40.1050682749067, 39.743098395211355, 18.67799632889884, 5.471362020288195, 0.3199289355959211, 0.040457039805395265, 0.016595882596448064, 0.022775884551395262, 0.07420470499034439, 0.01222005860680448, 0.05504857575786965, 0.026564651069098284, 0.017079966442127312, 0.11918217901672636, 0.07426349326436009, 0.024620797518374662, 0.018743836088106036, 0.05017326093677964, 0.013966341419810695, 0.05413677057783518, 0.0631777374073863, 0.005988785697679434, 0.04400689075035708, 0.030196959285863807, 0.050250963374440155, 0.022941119702798978, 0.048616745708776374, 0.02876205449657781, 0.01522832240776292, 0.04528609210891383, 0.04079520808798926, 0.0325346684881619, 0.015003221808001399, 0.02560219494625926, 0.03480472435642566, 0.05420814906912191, 0.060305641165801456, 0.02562500050823603, 0.05040078390655773, 0.04304892144032887, 0.05410154103966696, 0.04138695169240236, 0.04097439900838903, 0.09018523605274302, 0.01854619410421167, 0.01897768470059548, 0.012260747807366508, 0.04151676222681999, 0.04227530670219234, 0.059457099198230674, 0.09692091069051198, 0.014366889971175363, 0.02486244080189083, 0.027447528604950224, 0.032996845830764086, 0.021999285955514227, 0.05483826043616448, 0.01234925167435514, 0.06012532726994582, 0.014696333989767092, 0.058608265460601876, 0.8639397727591651, 12.050464919635228, 28.32739050047738, 41.528125354221885, 47.89865418842861, 33.07519013541085, 43.55325773784092, 36.32224314553397, 27.276468515396118, 28.471553461892263, 19.573162283216202, 11.930557250976562, 4.464790386813028, 0.9897559072290147, 0.2515437879732677, 0.6061990601675851, 0.6734873695032937, 4.77578524180821, 6.925233926091876, 8.552099909101214, 7.216500673975263, 6.333604369844709, 4.237665934222085, 5.996454324041094, 8.036467143467494, 16.94365300451006, 26.943403141839163, 42.07679680415562, 50.42815283366612, 47.66264125279018, 43.7192189352853, 40.734679290226524, 42.699539525168284, 48.42834315981184, 49.85869584764753, 49.50483798980713, 47.38098560060774, 49.8457270349775, 49.11500930786133, 47.87264708110264, 45.10492597307478, 44.49740675517491, 45.02627583912441, 42.55670888083321, 41.22018119267055, 38.9274354662214, 35.125600065503804, 35.89392491749355, 41.488416399274556, 49.052767344883506, 51.53829084123884, 49.66531358446394, 49.32090875080654, 49.193391936165945, 50.72610201154436, 46.25235496248518, 45.18391309465681, 49.28416667665754, 48.09773744855608, 36.82781491960798, 43.000983646937776, 49.46296467099871, 44.03611237662179, 44.30091517312186, 38.80340664727347, 35.830456597464426, 36.16762835638863, 35.70566347667149, 36.214073589869905, 36.89187036241804, 36.080650806427, 35.26384489876883, 35.24284744262695, 37.432197025844026, 45.7605163029262, 51.173058782305034, 52.4991363797869, 48.99952677318028, 46.86612408501761, 44.84539338520595, 40.063219274793354, 39.16053710665022, 39.32934359141758, 40.24098893574306, 42.49603721073696, 44.63098587308611, 47.263460295540945, 51.19619280951363, 52.01736913408552, 41.52913284301758, 35.43830721718924, 27.192287615367345, 20.87618749482291, 16.294359479631694, 12.509771244866506, 6.396608463355473, 7.902677842548915, 11.682769724300929, 8.98466522353036, 11.191398331097194, 4.814563138144357, 5.424172895295279, 2.350592953818185, 1.419847011566162, 0.7960920791540826, 0.4987049996852875, 0.42128681391477585, 2.7831817184175764, 9.37084870679038, 21.315179892948695, 29.283061368124827, 28.455409322466167, 37.41832842145647, 40.15777383531843, 47.35793495178223, 46.03791618347168, 43.62248611450195, 24.38798597880772, 7.041479025568281, 0.5560351290873119, 0.034756782464683056, 0.002495828641778124, 0.04277179416801248, 0.01273898352935378, 0.06750727258622646, 0.003245170061875667, 0.007417100215596812, 0.03298918177772846, 0.02627786824346653, 0.015306063861187016, 0.018736244977584908, 0.017034346836486032, 0.02793952586528446, 0.07663882723344223, 0.06059984716453722, 0.012565472795228873, 0.034805433425520144, 0.044157308393291066, 0.03317848286990609, 0.034246944822371006, 0.07220468231077705, 0.011420708731748164, 0.01719404853481267, 0.01984511877942298, 0.051460523291357925, 0.04316193823303495, 0.022330607819770063, 0.15535342879593372, 0.20282862415271147, 0.14248635566660336, 0.14020626087273869, 0.1876368357666901, 0.23978860303759575, 0.14242937229573727, 0.13614155112632684, 0.15376671536692552, 0.18958212781165326, 0.1834304207669837, 0.16767434908875398, 0.15811498489763054, 0.11540237255394459, 0.11340113529669386, 0.12269129071916852, 0.12728025019168854, 0.11688172817230225, 0.16885278799704143, 0.10573343174265963, 0.09610744898340531, 0.11019688259278025, 0.09372387081384659, 0.14771294806684765, 0.1179733688810042, 0.1922275187181575, 0.12587243930569716, 0.18367605044373445, 0.20493063064558165, 1.0064589423792702, 14.48556273324149, 32.652823039463584, 48.91674940926688, 54.481589453560964, 41.796256337847026, 54.1488367489406, 45.15910107748849, 35.85696744918823, 36.01838452475411, 26.60275033542088, 14.399417230061122, 6.1098224350384305, 1.6494213555540358, 1.2782169942344939, 1.3779195185218538, 6.429532502378736, 8.501728074891226, 10.431930695261274, 10.119749001094274, 12.594626120158605, 13.187627077102661, 7.939687422343662, 10.030560186931066, 11.605459724153791, 20.74996825626918, 32.60468244552612, 46.20858131136213, 51.897894859313965, 50.539695739746094, 45.78014496394566, 42.33119467326573, 43.704784052712576, 50.046759264809744, 51.417694432394846, 50.54958997453962, 47.575913837977815, 49.837371826171875, 51.44421223231724, 49.710483823503765, 47.82444742747715, 47.611071722848074, 48.09566341127668, 45.288466112954275, 44.17700447354998, 40.706375803266255, 36.491661071777344, 36.13888365881783, 42.10470424379621, 50.95794602802822, 53.36859573636736, 51.398645945957725, 48.961339473724365, 49.42151171820504, 51.04194280079433, 46.44928775514875, 46.56293249130249, 49.45277166366577, 49.47538457598005, 39.46853337969099, 44.13900130135672, 52.26431506020682, 45.464814867292134, 45.76921892166138, 40.19647530147007, 38.31917973927089, 39.35370397567749, 38.984219619206016, 36.888212135859895, 39.035681452069966, 36.576436042785645, 38.05740635735648, 37.73023305620466, 40.479294776916504, 47.616922106061665, 55.25687640053885, 54.44982576370239, 52.07566452026367, 50.07975278581892, 47.51734052385603, 42.8076673916408, 43.34248413358416, 41.55379894801548, 43.48438719340733, 44.889514446258545, 47.20823948723929, 49.52266706739153, 53.14150081362043, 53.28433493205479, 43.544256346566335, 37.959930079323904, 30.338253021240234, 21.053482941218785, 17.248913424355642, 16.124924182891846, 10.17680413382394, 9.773000018937246, 20.25818518229893, 11.1478339944567, 14.663803134645734, 11.821203027452741, 7.142263080392565, 6.274941597666059, 6.74092036485672, 1.928542218038014, 1.1156185077769416, 0.7118104302457401, 3.835615805217198, 11.766995787620544, 26.05405456679208, 39.85477679116385, 37.009131635938374, 43.07206719262259, 48.777900082724436, 53.69474765232631, 53.656466552189414, 50.19855308532715, 27.577455793108257, 8.100171702248709, 0.8093334457703999, 0.12925097372915062, 0.18209458887577057, 0.12633688295526163, 0.14321582152375154, 0.08407355578882353, 0.13032771380884306, 0.10142966053847756, 0.1164174202297415, 0.17101887533707277, 0.1378144385027034, 0.10496693144419364, 0.08659847280276672, 0.0963032538337367, 0.2870927261454718, 0.11934900363641125, 0.1496222506144217, 0.11345333499567849, 0.2186674771032163, 0.17006298234420164, 0.08904793672263622, 0.10338411280619246, 0.13540464852537426, 0.07517323909061295, 0.07389314206583159, 0.13435553839164122, 0.13397106687937463, 0.2989804153995854], [0.04566879603745682, 0.03868474704878671, 0.03406202028106366, 0.04565042470182691, 0.04467345301860145, 0.03404559294826218, 0.020587865263223648, 0.03790190762707165, 0.024902482849678824, 0.05345749595601644, 0.05502391440261688, 0.011388904947255338, 0.04176655810858522, 0.036564681346395185, 0.040934026174779446, 0.0028942067292518914, 0.024880647592778717, 0.03823770782245057, 0.10802546196750232, 0.04468004498630762, 0.04057555951710258, 0.0036288557457737625, 0.042900980450212955, 0.01936288733434464, 0.050804519028003724, 0.06539454524006162, 0.02743016489382301, 0.043961303375129185, 0.03497685511995639, 0.17182657628187112, 5.472089409828186, 18.91285412652152, 29.878709588732036, 43.18313067299979, 40.83267668315342, 33.648756980895996, 23.613409485135758, 27.73988730566842, 19.86054846218654, 21.73352571896144, 8.276945165225438, 4.3963072044508795, 1.5903203040361404, 0.40250181619610104, 0.22720209056777613, 0.47879672795534134, 2.433876233441489, 3.941535447325025, 7.29896971157619, 5.002679969583239, 5.41644389288766, 1.9517096834523338, 4.13488210099084, 5.691432314259665, 13.09936671597617, 25.324425969805034, 36.41841663633074, 43.364461285727366, 44.68023817879813, 43.667652879442485, 40.45236703327724, 40.997244766780305, 42.554089409964426, 45.610911164964946, 47.34239877973284, 49.791555404663086, 47.085068770817344, 47.75990561076573, 48.129483767918174, 47.53846304757254, 43.85647017615182, 43.881191866738455, 40.30046204158238, 36.99839319501604, 33.61077117919922, 32.00141205106463, 32.6530419077192, 40.976209095546174, 46.688844272068565, 48.486659390585764, 48.506124768938335, 51.07741335460118, 50.437265396118164, 51.51521587371826, 48.285946777888704, 51.409471239362446, 46.1486565726144, 50.723274094717844, 36.59404277801514, 41.99624286379133, 48.60270472935268, 42.777258600507466, 42.569754123687744, 38.75377566473824, 37.74246188572475, 36.53331899642944, 38.90157774516514, 39.244502612522666, 36.44371502740042, 34.05212770189558, 35.22872870309012, 33.970871993473594, 35.22891283035278, 45.19215018408639, 47.05146380833217, 50.562867982046946, 49.651649951934814, 47.86898538044521, 44.73146724700928, 43.30858734675816, 39.453900473458425, 39.90307371956961, 39.189604895455496, 41.441766193934846, 43.537731988089426, 45.55862249646868, 47.404720646994456, 50.310808181762695, 43.68146937234061, 35.53827442441668, 20.727172953741892, 17.099721704210552, 10.253410628863744, 8.907528928347997, 3.3660146381173814, 6.576027887208121, 6.8184027671813965, 9.575940421649388, 9.812867045402527, 4.021987336022513, 5.126165526253836, 1.519537593637194, 0.5067463996154922, 0.49774609399693354, 0.5369088553956577, 0.7185790070465633, 3.4413357164178575, 10.90377504484994, 20.116384608404978, 29.016521521977015, 37.525143078395296, 31.79667295728411, 33.452932425907676, 43.267096178872244, 43.42893362045288, 33.64207281385149, 13.461311408451625, 3.3994554494108473, 0.16747476479836873, 0.023090456778715764, 0.04344155912154487, 0.034548024380845685, 0.03541395041559424, 0.008960940409451723, 0.04219556526680078, 0.03402090784428375, 0.02554677559861115, 0.006497966433276555, 0.0823399123868772, 0.038739453934665234, 0.04359360185584851, 0.04716466041281819, 0.05434805281194193, 0.013197999746937836, 0.050280133594891856, 0.06983259852443423, 0.023121024781305875, 0.03480341139116457, 0.06698009837418795, 0.00898400551107313, 0.05167743397344436, 0.03264074386762721, 0.06311668961175851, 0.019299549483028904, 0.04777652258053422, 0.022161572872261916, 0.03818613916103329, 0.009911985269614627, 0.023627150837065916, 0.07622891744332654, 0.030072312402938093, 0.07737965855215277, 0.01498731694716428, 0.012520257766092462, 0.033063667959400585, 0.034299697527395825, 0.054162307243262015, 0.07164301816374063, 0.03194205296624984, 0.020431768282183578, 0.03813818369859031, 0.005886806125220443, 0.015101329490010227, 0.0030597385276840733, 0.0684379172910537, 0.04070256091654301, 0.048307601761605055, 0.03640285074444754, 0.032819137509380064, 0.022062818885647824, 0.007724557155078011, 0.05254695624379175, 0.05808168835937977, 0.0766595768343125, 0.07081104602132525, 0.18578081178878034, 7.497162733759199, 24.544059889657156, 39.87102862766811, 48.28721135003226, 44.32060636792864, 40.32975564684187, 30.428044591631206, 28.471221685409546, 25.92002555302211, 25.05796602794102, 11.333951047488622, 5.270576885768345, 1.7375279877867018, 0.35084206823791775, 0.3590991608798504, 1.377638659306935, 2.869870049612863, 5.7091767106737406, 7.680893080575125, 7.891902055059161, 8.757600699152265, 6.232710446630206, 4.9990525756563455, 7.668955206871033, 17.122162648609706, 27.223957504544938, 38.77429716927664, 46.75827414648873, 47.140355587005615, 45.461820193699424, 42.4309777532305, 41.915303298405235, 44.41910750525338, 47.719977787562776, 49.36381735120501, 50.43901981626238, 46.95424461364746, 49.77967051097325, 50.8426684652056, 49.30328117098127, 45.609691756112234, 45.62494305201939, 43.41262967245919, 41.15179007393973, 35.86617728642055, 34.72250379834856, 33.49160609926496, 42.42909826551165, 48.94054004124233, 50.64335938862392, 50.86448928288051, 51.586751052311485, 51.4949688230242, 52.066628387996126, 49.59264932359968, 52.49174697058541, 46.67881802150181, 49.97421312332153, 39.04732663290841, 44.87547908510481, 51.477230072021484, 45.11247866494315, 45.5106451851981, 40.409534863063264, 38.13737664903913, 36.91312142780849, 39.715889249529155, 40.30632632119315, 38.20781748635428, 34.53444732938494, 36.4930750301906, 35.454955101013184, 36.29665987832205, 46.778681005750386, 49.874569007328574, 51.58077907562256, 51.17895432880947, 49.64514643805367, 46.96956191744123, 45.516050883701865, 41.948293345315115, 41.47128561564854, 41.26368038994925, 43.73206615447998, 45.235600743974956, 46.90539877755301, 50.740245069776265, 51.75486271721976, 42.848043373652864, 37.60784748622349, 24.004492316927227, 21.185135671070643, 12.830115335328237, 8.522428495543343, 6.842252893107278, 9.695009095328194, 13.494705319404602, 10.990642292158944, 10.09446450642177, 6.669029091085706, 6.063599978174482, 4.413696374211993, 1.332676106265613, 0.68839152689491, 0.6320755087903568, 0.707736071731363, 3.445507892540523, 11.926825199808393, 24.353220667157853, 35.730041231427876, 39.844705377306255, 34.33472483498709, 40.09234612328665, 49.46554592677525, 48.892993518284385, 38.9630241394043, 16.006877762930735, 4.38061078957149, 0.42431310723934856, 0.03114209071333919, 0.04763895978352853, 0.01850971606160913, 0.018174453605232493, 0.037823774319674285, 0.027648380059482794, 0.046209937892854214, 0.03399849922529288, 0.045546530812446556, 0.037930093971746306, 0.020161597690145885, 0.04063993552699685, 0.04476440045982599, 0.027586930231856446, 0.04561000097809093, 0.06988718666668449, 0.09485884276883942, 0.005807949753943831, 0.048372384892510514, 0.04121887517560806, 0.01926028266149972, 0.03504847109849964, 0.035173589563263316, 0.038828409875610044, 0.057119573200387616, 0.06394602903830153, 0.034279436471738985, 0.15464680242751325, 0.12232173340661184, 0.1323284421648298, 0.1186855999486787, 0.10448728861021143, 0.15609561039933137, 0.08852995666010038, 0.11826847733131476, 0.11009016260504723, 0.18350572458335332, 0.09776473683970315, 0.19288714975118637, 0.11594168575746672, 0.10490266060722725, 0.0728733107181532, 0.08263850172183343, 0.11116832082292863, 0.11148394817220313, 0.1749961490609816, 0.10639553264315639, 0.1018908065078514, 0.12741644574063166, 0.08260842904980693, 0.1570496577769518, 0.12572207594556467, 0.13844365759619645, 0.11179330585790531, 0.12276663524763924, 0.24673571597252572, 0.3655188892568861, 8.798253740583148, 28.809909888676234, 46.2011467388698, 55.97760609218052, 51.0274384362357, 43.848212242126465, 32.54964229038784, 38.132155077798025, 30.471467358725413, 28.983765976769583, 13.648898005485535, 7.002267301082611, 2.5693205084119524, 0.6757803836039135, 1.7479210815259387, 4.023936739989689, 6.542736462184361, 11.713843805449349, 14.999329907553536, 12.065135172435216, 12.514146872929164, 7.75348264830453, 6.8817051989691596, 11.123479689870562, 18.10020671572004, 30.852068832942418, 42.06571442740304, 50.51876776559012, 49.828863756997244, 48.52151502881731, 45.488344941820415, 44.456638199942454, 45.22237137385777, 49.19743578774588, 51.55273267201015, 50.674344880240305, 46.92044857570103, 49.370049885341096, 52.62505163465227, 51.508719308035715, 46.81228249413626, 47.50067874363491, 45.863811697278706, 42.55790744509016, 36.81633996963501, 35.741012437003, 35.20691135951451, 44.216636998312815, 51.289201395852224, 51.32344906670706, 50.95131744657244, 53.47642830439976, 53.90497234889439, 53.958622864314485, 49.863886151994976, 52.09134660448347, 48.61772673470633, 49.957502705710276, 42.65453951699393, 48.46965020043509, 52.0528883252825, 48.89692619868687, 47.13651670728411, 42.29826021194458, 41.338238034929546, 39.79650919778006, 42.49308770043509, 44.04147291183472, 39.48545224325997, 36.369765349796836, 39.12992681775774, 38.702140126909526, 38.535619599478586, 48.60354893548148, 52.02293116705758, 54.99870218549456, 52.224411555698936, 52.88718979699271, 49.6830940246582, 48.79970700400216, 43.31137010029384, 44.66009187698364, 43.619922229221885, 45.75812612261091, 47.10999195916312, 48.46677712031773, 52.866703033447266, 53.95970330919538, 44.690740380968364, 39.33728190830776, 25.110141788210186, 19.107141392571585, 14.757909536361694, 16.44267920085362, 7.464469722339085, 12.903120926448278, 11.808334963662283, 17.354331493377686, 19.385128395898, 10.751793622970581, 10.552745972360883, 7.294231040137155, 1.5162946305104663, 1.452218125973429, 1.2640771929706847, 1.1688306352921893, 4.50083156142916, 14.810521296092443, 27.794798919132777, 38.974009241376606, 48.954881123134065, 40.761495862688335, 44.97597088132586, 56.311321122305735, 56.19661678586687, 43.71108954293387, 20.37225202151707, 5.741826295852661, 0.646565814103399, 0.08742921001144818, 0.09569843485951424, 0.11390537502510206, 0.12728757836988994, 0.0882583526628358, 0.11470965615340642, 0.11020818698619093, 0.12667007079081877, 0.10318324608462197, 0.1766619932438646, 0.13952026196888515, 0.14031288586556911, 0.12483377861125128, 0.06723335478454828, 0.12421251194817678, 0.15359841154089995, 0.16468628442713193, 0.10074453015944787, 0.12837806556906017, 0.14807145882930073, 0.12591757545513765, 0.12411261802273137, 0.15501184069684573, 0.20186908064144, 0.0784274319718991, 0.09501823743007012, 0.1318782748920577], [0.05159242371363299, 0.09494832796709878, 0.029294935188123157, 0.049070889196757755, 0.019581652113369534, 0.008217445840792996, 0.025761226591254984, 0.029536670073866844, 0.05132733365254743, 0.02978698842759643, 0.03027983216036643, 0.06199499658708062, 0.03177466176982437, 0.039833550940134695, 0.03050728727664266, 0.019201219580801468, 0.05497840166624103, 0.011847419048925596, 0.05945237659450088, 0.005383966723456979, 0.04152089450508356, 0.00528327509528026, 0.05097701620044453, 0.04989823033767087, 0.027403859787487557, 0.011263096073110188, 0.031689539551734924, 0.0644447590623583, 0.009119505561622126, 0.07156934961676598, 3.6244624384811948, 14.033076933452062, 25.42282462120056, 41.3338919367109, 37.04688467298235, 33.22385726656233, 24.277865716389247, 21.32254672050476, 24.373848131724767, 20.96245459147862, 11.211188537733895, 5.881424290793283, 1.9932916121823447, 0.6016187316605023, 0.284000424934285, 0.21972273476421833, 3.5535289304597035, 6.056937089988163, 6.014870524406433, 5.9561091746602735, 5.485067776271275, 4.646278636796134, 4.1650120956557135, 5.625169949872153, 16.09175000871931, 24.969322647367203, 36.93450450897217, 44.71824482509068, 45.91282081604004, 43.88549280166626, 41.881872040884836, 39.401788984026226, 40.78930950164795, 44.86912843159267, 45.98710400717599, 48.71731526511056, 48.33334044047764, 47.64638941628592, 47.345146792275564, 49.400910309382844, 45.746279444013325, 43.75302192143032, 40.32303326470511, 36.52186836515154, 34.00770092010498, 34.34666531426566, 32.637404986790244, 37.47722830091204, 43.67350673675537, 47.34232234954834, 46.93623488289969, 49.339179039001465, 46.524046897888184, 49.785260336739675, 50.63223532267979, 51.29307154246739, 47.244561195373535, 50.94356325694493, 35.091539996010916, 37.90510879244123, 50.22392790658133, 44.24343967437744, 43.39471026829311, 42.69396359579903, 41.91757883344378, 42.814507893153596, 44.81944533756801, 42.27175283432007, 42.539216790880474, 36.7585448537554, 33.663650444575715, 33.349928855895996, 34.99834380831037, 40.53856985909598, 48.140309061322895, 48.09254714420864, 49.52555404390608, 49.99555104119437, 47.23964187077114, 45.05043472562517, 42.16544539587838, 43.02712971823556, 41.7818284034729, 42.84980821609497, 45.36391312735421, 47.84157821110317, 52.50339215142386, 51.31837688173567, 41.336059774671284, 32.52485111781529, 20.590677329472133, 18.38643601962498, 10.513744865145002, 5.172773173877171, 4.70414844581059, 7.9035767657416205, 17.323748997279576, 11.937310031482152, 10.957520229475838, 6.634460500308445, 3.946762663977487, 2.5883711661611284, 1.0875022964818137, 0.3049020176487309, 0.44635472020932604, 0.7330331600138119, 3.335134889398302, 9.208558763776507, 23.625742537634714, 26.101555926459177, 35.00265169143677, 37.172129426683696, 34.4065831048148, 42.16529253550938, 42.65465068817139, 33.77622863224575, 17.13361327988761, 3.7803376742771695, 0.07018808302070413, 0.007204228513208883, 0.045491695004914484, 0.034503217320889235, 0.018316435361547128, 0.0533623789171023, 0.047350762212382894, 0.056206078468156714, 0.12439038311796528, 0.03419951183189239, 0.009152148185031754, 0.04288280928241355, 0.029523289363299097, 0.08759857235210282, 0.06388145286057677, 0.013103576510080268, 0.04803392823253359, 0.08212896942027978, 0.07993401041520493, 0.007264828475724373, 0.05228473299315997, 0.03695285087451339, 0.04372490177463208, 0.02563209628819355, 0.045356032105961015, 0.04179153158994658, 0.01542277358073209, 0.07341641693242959, 0.06466567649372987, 0.05325799987518361, 0.01400779651677502, 0.08519392567021505, 0.03436252308477249, 0.05153708918286221, 0.04531820717134646, 0.02687570678868464, 0.05526091989928058, 0.018867337943187783, 0.06658624950796366, 0.02953079396060535, 0.032564978647444925, 0.026729421424014226, 0.05156931281089783, 0.03529013813074146, 0.03006745409220457, 0.036922333762049675, 0.03172723217202084, 0.07581159126545702, 0.02861917537770101, 0.05079094832763076, 0.015214675372200353, 0.02223003875198109, 0.03059074708393642, 0.010965251430336918, 0.01721773449597614, 0.037973998580127954, 0.0226130565029702, 0.06364850500332457, 4.629140470709119, 18.12235062462943, 32.04610981260027, 46.66259397779192, 43.52643769127982, 36.33266544342041, 27.98975842339652, 29.33224766595023, 24.921944618225098, 25.480173315320695, 12.332325543676104, 6.308826659406934, 1.9414024651050568, 0.5773518223847661, 0.2541517237467425, 1.0156139539820808, 2.3652380193982805, 4.04578925882067, 6.329778083733149, 6.039244370801108, 4.571602438177381, 6.4198397653443475, 7.0118744884218485, 7.0653960279056, 16.820282527378627, 28.087976421628678, 39.763533047267366, 48.593335083552766, 48.25493696757725, 46.01912825448172, 43.82147904804775, 41.95634978158133, 43.859600339617046, 47.588212149483816, 47.894672870635986, 49.56251151221139, 48.67902374267578, 48.861893381391255, 49.99483190264021, 51.38515601839338, 47.24178886413574, 45.23275893075125, 42.56516136441912, 38.09837293624878, 35.758584431239534, 36.08307920183454, 34.99814925874983, 39.025467600141255, 45.76331990105765, 49.41644648143223, 49.41888877323696, 50.43587923049927, 49.17445462090628, 52.31357431411743, 51.584909779684885, 51.573424407414024, 48.830053261348176, 49.78076485225132, 36.810632024492534, 41.34955317633492, 52.290113721575054, 45.233106340680806, 45.20990630558559, 43.30652720587594, 43.587123257773264, 44.942129680088584, 46.037912709372385, 44.68243728365217, 44.544293199266704, 37.80711487361363, 35.88695240020752, 35.78410169056484, 36.39152710778372, 42.53292172295706, 50.77799463272095, 50.55385269437517, 50.85899325779506, 51.67342288153512, 48.88002470561436, 46.078233105795725, 43.999901839665, 43.6528879574367, 42.39020572389875, 44.166999067579, 46.83797345842634, 49.933045046670095, 54.04655231748308, 52.00706842967442, 42.56223617281233, 34.82690743037632, 22.12251193182809, 19.67545018877302, 12.256128992353167, 9.27281483582088, 7.3901622125080655, 7.148315395627703, 13.26491015298026, 6.0795052732740125, 9.396773304258074, 7.214306346007755, 7.941616415977478, 4.616638055869511, 3.977261347430093, 0.3730599374643394, 0.32985853563461986, 0.7393094460879053, 4.3767988341195245, 10.890929562704903, 23.56299683025905, 28.536769253867014, 36.16015209470476, 39.79303857258388, 39.3480099269322, 48.34392949513027, 47.791992391858784, 36.78955118996756, 19.586671318326676, 4.341834630284991, 0.11179961623357874, 0.04995837228904877, 0.026599442952179482, 0.05364479197721396, 0.018813913488494496, 0.0630962046395455, 0.01299521531577089, 0.040429236833006144, 0.048743621579238346, 0.010705020528153648, 0.031148947309702635, 0.04386873084253498, 0.030057055543043783, 0.062099362058298926, 0.01751437473909131, 0.04287973551877907, 0.004715276823844761, 0.039700873595263274, 0.06542421757642712, 0.02586317138879427, 0.025329909021300927, 0.013376768279288496, 0.013859656206997377, 0.045114907901734114, 0.059248639669801505, 0.04873080066006098, 0.04061458206602505, 0.0845685742263283, 0.1290850176342896, 0.17846220093114035, 0.10189274711800472, 0.14345017394849233, 0.14393330445247038, 0.14233877430004732, 0.17288182037217276, 0.09445219673216343, 0.13705732912889548, 0.10814963387591497, 0.07689258575971637, 0.22680303055260861, 0.13888915654804024, 0.09838314008499895, 0.1092624788039497, 0.1406513662742717, 0.08688917756080627, 0.09366471613092081, 0.1552667391619512, 0.10887992076043572, 0.13991521006183966, 0.11444285618407385, 0.13279333364750656, 0.145432052601661, 0.2386269239442689, 0.1640788327370371, 0.1615559309720993, 0.1413750917251621, 0.10219584871083498, 0.24560967353837831, 5.758217096328735, 22.511631897517614, 37.89761863436018, 52.95953444072178, 48.768217767987935, 44.31806680134365, 34.0864656993321, 30.54609101159232, 34.13378987993513, 31.10833924157279, 17.278040272848948, 8.851443937846593, 2.967805560146059, 1.678356802889279, 0.8759409402097974, 1.3963072746992111, 8.097529649734497, 12.917967489787511, 11.759691493851797, 12.913032531738281, 12.577253886631556, 8.586603794779096, 9.55618235043117, 9.757436054093496, 21.959967511040823, 28.80052982057844, 39.788977350507466, 49.00748940876552, 51.92125817707607, 48.526225907461985, 46.68986218316214, 43.47004958561489, 44.93083190917969, 49.3222393308367, 49.52196182523455, 51.09173011779785, 49.68598100117275, 47.38064513887678, 49.82844339098249, 52.83023541314261, 49.36662442343575, 47.3121463230678, 44.306237493242534, 39.64292969022478, 37.102240971156526, 38.21947308949062, 36.67690699441092, 41.81105252674648, 46.40963438579014, 51.90556219645909, 51.03460897718157, 52.264148303440635, 51.78529930114746, 53.73372704642159, 53.2495869909014, 52.16250658035278, 49.13849074499947, 51.04989153998238, 39.882729394095286, 42.75453104291643, 52.90372650963919, 48.74015746797834, 47.53959212984358, 48.25232444490705, 45.11491400854928, 47.14978429249355, 49.192551204136436, 46.92127888543265, 45.930542196546284, 40.29727629252842, 37.50225223813738, 36.982266426086426, 38.505936895098, 44.43278156008039, 53.50578791754586, 53.60880538395473, 51.62907600402832, 54.190084729875835, 52.37903676714216, 48.96616847174508, 47.30790792192732, 47.21795654296875, 45.88715417044503, 45.95048352650234, 50.629789556775776, 51.56890460423061, 55.692389488220215, 52.57743910380772, 47.6151259967259, 38.53613029207502, 27.202768972941808, 22.94208322252546, 14.47014033794403, 9.185168521744863, 8.644460575921194, 16.313107456479752, 30.731239659445627, 18.745650938579015, 15.58292647770473, 17.122065373829432, 12.473142078944615, 7.401367051260812, 5.587938461984907, 0.9965701358658927, 0.8058836108871869, 1.6713594240801675, 5.212750502995082, 13.821757895605904, 32.01688916342599, 36.02867828096662, 44.45238242830549, 48.298297200884136, 46.849330289023264, 54.82034192766462, 54.990809031895225, 44.01106759480068, 23.62885011945452, 5.5625788399151395, 0.24587959476879664, 0.12938689786408628, 0.09424322830247027, 0.1373075321316719, 0.14824627659150533, 0.13578464170651777, 0.17457031405397824, 0.1876927606229271, 0.192112194906388, 0.10710447281599045, 0.1633690715368305, 0.151034607685038, 0.07799072683389698, 0.1468896001045193, 0.14407363906502724, 0.0967305273349796, 0.11173108419669525, 0.24257743624704226, 0.16126376736376966, 0.09927945091788258, 0.13203243804829462, 0.11753280966409616, 0.13690195818032536, 0.14751086676759378, 0.1252158209681511, 0.11167907448751585, 0.08400431129017047, 0.22719508808638367], [0.018197829136624932, 0.009753320033528974, 0.011876569761495506, 0.04284419385450227, 0.017780518225793327, 0.03740216997851219, 0.05956816181008305, 0.02522103807755879, 0.013048842482800995, 0.029849946299301724, 0.07072873293821301, 0.04364163534981864, 0.11935226060450077, 0.052936889962958436, 0.06515964320195572, 0.0337002830845969, 0.017591637825327258, 0.024007715683962618, 0.077354742746268, 0.053950146306306124, 0.09083377982356719, 0.02797348315029272, 0.07505823419030223, 0.06067119512174811, 0.02540772850625217, 0.015298372666750635, 0.006469924277293363, 0.03024770352723343, 0.05282313356708203, 0.06516644212284259, 1.8612612911633082, 11.365101558821541, 27.03545982497079, 44.44876936503819, 47.31323719024658, 34.937255246298655, 21.315374442509242, 17.625405039106095, 28.083269017083303, 22.992676530565532, 18.819274050848826, 8.790115662983485, 2.1412298338753835, 0.5020771558795656, 0.2817815611405032, 0.9407423372779573, 0.8720722592302731, 1.8277520835399628, 3.9433497956820895, 5.850990746702466, 5.935562917164393, 7.341319850512913, 4.981802369867053, 4.326003594057901, 12.463459764208112, 24.5853773525783, 30.570597308022634, 45.0388833454677, 48.08647094454084, 44.90168421609061, 41.96184580666678, 40.14249127251761, 37.74114520209176, 41.721900190625874, 44.512866497039795, 50.22708933694022, 48.850255148751394, 47.50599411555699, 47.34124885286604, 48.06215224947248, 46.27827869142805, 42.61854437419346, 42.82445076533726, 37.834723540714805, 34.21625110081264, 33.39044032778059, 32.390160288129536, 34.24289049421038, 38.19726317269461, 44.34358058656965, 43.831276008060996, 46.23190641403198, 44.945544719696045, 47.98461730139596, 45.828900473458425, 49.58262654713222, 46.45359911237444, 50.02954510280064, 36.729563917432515, 37.06501252310616, 53.534383228846956, 45.320382663181846, 44.973174231392996, 41.9957252229963, 42.89626734597342, 43.99737964357649, 46.847092969076975, 46.33629614966256, 44.792187554495676, 38.8348194531032, 33.43081283569336, 33.87314558029175, 32.90692561013358, 40.70019885471889, 45.94914599827358, 47.26801831381661, 47.35150439398629, 47.8989633832659, 48.80812474659511, 46.117257663181846, 46.239299297332764, 46.58840111323765, 42.87439094270979, 42.77331897190639, 46.11158445903233, 52.19986009597778, 46.46743992396763, 43.01897600718907, 39.40322378703526, 35.57508250645229, 18.876197167805262, 15.486348254340035, 4.81171133688518, 3.640633067914418, 5.52771885905947, 7.278231944356646, 10.942446112632751, 4.636889449187687, 9.529274582862854, 2.748876290661948, 6.67248147726059, 4.468027378831591, 3.018186730997903, 0.532200962305069, 0.23835738269346102, 0.6418864194835935, 4.034232233251844, 13.71126937866211, 30.330304282052175, 34.88705103737967, 33.61605528422764, 30.438237598964147, 43.242794854300364, 40.803445611681255, 46.796249525887625, 28.54999167578561, 13.881749510765076, 2.1571155871663774, 0.07006332078682524, 0.004599976336716541, 0.047662213178617616, 0.052186318274055205, 0.026708386838436127, 0.030136535742453167, 0.022380860123251165, 0.022932858538946936, 0.010128113091923296, 0.01582364019538675, 0.03400718108085649, 0.018743795376004915, 0.08005882014653512, 0.020208771140979867, 0.03608930649768029, 0.008594734211718398, 0.0030638559629941092, 0.025610125324289714, 0.025629453394295912, 0.02359457267448306, 0.15962319182498114, 0.047557111496904066, 0.018008967395871878, 0.05005665130114981, 0.050027375907770226, 0.07769081435565438, 0.10161866646792207, 0.021144072292372584, 0.050177725697202344, 0.033479165485394854, 0.04425779264420271, 0.05679886701649853, 0.04300460971093603, 0.03234953020832368, 0.05593483070177691, 0.03935805056244135, 0.02540661740515913, 0.008378200964736087, 0.04206318987001266, 0.07133607606270484, 0.06729634319032941, 0.030277928869639124, 0.011130947985553315, 0.0509914384622659, 0.05201571421431644, 0.028553954591708522, 0.05971609601484878, 0.04366563852610333, 0.0752534419298172, 0.021883778939289705, 0.08201446663588285, 0.06849129085562058, 0.01694385571006153, 0.030936667629118477, 0.03678374298449073, 0.024938764117125953, 0.03914218821695872, 0.039782514928707054, 2.5600429262433733, 14.48646252495902, 31.357647555215017, 50.27219009399414, 51.23625264848982, 41.01338543210711, 26.39417236191886, 21.74039053916931, 33.104591437748496, 25.90189596584865, 20.9164297240121, 11.010506323405675, 3.4502248508589606, 0.6464637624365943, 0.4089572626565184, 0.8809989573700088, 2.5596407992499213, 4.351435303688049, 5.913336932659149, 8.346465366227285, 6.817318848201206, 6.610968206609998, 5.229208614145007, 7.290576287678309, 15.686565807887487, 25.512499809265137, 32.3216232572283, 47.264259338378906, 50.79446881158011, 47.2481985773359, 43.915436063494, 41.38605553763253, 41.14089182444981, 43.92685890197754, 47.13339696611677, 51.93489749091012, 49.648238386426655, 48.10260813576834, 47.66762311117989, 49.96283197402954, 48.297258445194785, 44.81947660446167, 43.43901893070766, 39.66840526035854, 35.718924113682334, 35.739164216177805, 33.10955939974104, 35.63429158074515, 41.83022608075823, 46.09109769548689, 45.88336740221296, 47.98708043779646, 46.37289578574044, 51.93000943320138, 47.08739989144461, 50.70105722972325, 48.59211220060076, 49.99776404244559, 38.06114101409912, 39.387510435921804, 52.909399713788716, 47.73308556420462, 48.06142616271973, 43.18700081961495, 45.14940486635481, 45.802521637507844, 48.82137148720877, 47.81759302956717, 47.146727085113525, 41.08163063866751, 34.63108287538801, 36.19512932641165, 34.4463198525565, 43.48972340992519, 48.70658377238682, 49.41824606486729, 48.00737959997994, 48.559549467904226, 51.24513939448765, 47.99714142935616, 47.71521132332938, 47.05513245718819, 44.10326324190412, 45.521136965070454, 48.42409781047276, 54.07600573131016, 49.1818961415972, 45.04070029939924, 43.501010758536204, 35.759897640773225, 23.665456703730992, 17.369596685682023, 8.190321973391942, 9.344990117209298, 9.733755724770681, 8.969557234219142, 11.958027822630745, 8.894693868500845, 10.191985947745186, 6.316254283700671, 5.063747252736773, 2.5638238319328854, 3.121321882520403, 0.8445322598729814, 0.13049029079931124, 0.7845602950879506, 3.805688176836286, 15.477305173873901, 30.15316343307495, 34.20623527254377, 40.33403921127319, 37.692813532693044, 44.207375049591064, 47.36551891054426, 50.921516622815815, 35.829212869916645, 16.410979781832012, 3.3134773543902805, 0.07482619556997504, 0.027580273803323507, 0.028925968201032708, 0.027395001512819102, 0.07046418570514236, 0.0024486884815684918, 0.03998653005276408, 0.015528726823894041, 0.05070416369874563, 0.06877475564501115, 0.04199517351974334, 0.020191768749750087, 0.027551773636202728, 0.01461937794062708, 0.05092489453298705, 0.033331095573625395, 0.019979002220290046, 0.03321634851662176, 0.015581683089424456, 0.02433139894024602, 0.03663977142423391, 0.0054545967058012524, 0.004627422230052096, 0.04144804698548146, 0.00974805884262813, 0.04964931655142989, 0.0035174089134670794, 0.038885379675775766, 0.2091429488999503, 0.12531912113939012, 0.09442433608429772, 0.12530635111033916, 0.15502750128507614, 0.14518506585487298, 0.15966250614396163, 0.14183603413403034, 0.1332353042172534, 0.09010358114859887, 0.17581219598650932, 0.24472600381289208, 0.12009639638875212, 0.11910994217864104, 0.13696176425686904, 0.15654195073459828, 0.1608599168913705, 0.12155260039227349, 0.18846437707543373, 0.12332554454249994, 0.1412700680749757, 0.08874900133482047, 0.13879074182893547, 0.20832137869937079, 0.15584749728441238, 0.10122048854827881, 0.1081705598958901, 0.1056697919432606, 0.12644015598509992, 0.20633647378001893, 3.5403779447078705, 16.560968807765416, 37.21705995287214, 55.20782559258597, 59.841895375932964, 46.241494928087505, 29.954000268663677, 27.310118641172135, 38.81119557789394, 32.89031246730259, 25.071558441434586, 12.44885812486921, 4.163479583603995, 0.7973076882106918, 0.9936686115605491, 3.445060819387436, 5.85247722693852, 6.274661932672773, 10.564736826079232, 13.750280908175878, 11.838150552340917, 14.454744866916112, 8.595414110592433, 7.205926384244647, 15.376342637198311, 27.98327054296221, 34.13661084856306, 49.35880422592163, 50.61720984322684, 48.95605189459664, 46.15698398862566, 44.18798262732369, 42.85046829496111, 46.80621671676636, 48.644887242998394, 53.63247789655413, 51.589735303606304, 49.624930654253276, 49.40295307976859, 50.7103157043457, 49.84709235600063, 46.1630254473005, 47.112423828669954, 41.75342416763306, 37.972204072134836, 38.2159538269043, 35.05170597348894, 36.76754624502999, 41.84191642488752, 46.45738935470581, 47.16759252548218, 48.88762603487287, 48.092727797372, 52.45775638307844, 49.12077283859253, 52.93099818910871, 50.28300149100167, 50.70010532651629, 39.775324140276226, 42.9258770942688, 53.16574307850429, 50.4185608455113, 50.573689801352366, 46.46196126937866, 47.5953757422311, 49.24652133669172, 49.87980794906616, 50.963584491184776, 49.910175051007954, 43.26030084065029, 36.97819478171212, 38.48033625738961, 36.71983643940517, 45.61352021353585, 50.34756415230887, 51.84694719314575, 48.72780009678432, 48.78099550519671, 52.40589502879551, 51.64756863457816, 51.096868310655864, 50.85875007084438, 46.816253389631, 47.80362367630005, 51.00366170065743, 55.60176760809762, 50.27200596673148, 51.31655297960554, 44.291719232286724, 38.499464648110525, 22.0004129750388, 19.984033584594727, 7.585739237921579, 7.848366379737854, 12.201068861143929, 16.99423589025225, 20.015713896070206, 11.671927060399737, 21.914616618837627, 9.547990424292427, 13.566151908465795, 9.57279462473733, 5.608292775494712, 1.3972755713122231, 1.282764915909086, 0.9256034067698887, 6.277538921151843, 18.69619713510786, 38.478644371032715, 42.290203775678364, 44.89649738584246, 40.02107497623989, 53.899042061397004, 52.555124964032856, 59.31910596575056, 39.58024304253714, 19.756834438868932, 3.852307115282331, 0.3806207446115357, 0.1084737361275724, 0.08696963145796742, 0.14879289083182812, 0.10835607136998858, 0.10529840937150375, 0.1577876867460353, 0.14552531045462402, 0.15327127623770917, 0.12121178582310677, 0.19685892734144414, 0.07267492743475096, 0.1461229505283492, 0.14269043185881206, 0.1521015361483608, 0.0901095929688641, 0.14454262889921665, 0.08200618850865535, 0.08759304229170084, 0.04609532654285431, 0.19271708173411234, 0.1530394343925374, 0.19211633397000177, 0.18289113470486232, 0.08547128364443779, 0.12582476543528692, 0.21318445274872438, 0.11151153740606137], [0.05039794423750468, 0.026048693040918027, 0.05451033803235207, 0.02186711072655661, 0.05350640815283571, 0.05853287343467985, 0.039884827831493955, 0.03469084921692099, 0.029958243880953108, 0.047999244915055375, 0.0336109268079911, 0.03998314416302102, 0.04210922168567777, 0.057657841459981034, 0.04599228760759745, 0.0008226411726874565, 0.015648539144811884, 0.020186257349061112, 0.06487787475011178, 0.022772880337600197, 0.040627592975007634, 0.04250072282073753, 0.014385315589606762, 0.038041906364794285, 0.00918676280083933, 0.015605379228613206, 0.04439277361546244, 0.029769085281129395, 0.02715747184785349, 0.03734841304165976, 0.829893273966653, 8.336413059915815, 25.257457494735718, 40.34332200459072, 40.831179346357075, 33.87983322143555, 28.43739264351981, 22.975029843194143, 22.5725519657135, 24.489943844931467, 17.875402961458477, 7.86171213218144, 2.2657087658132826, 1.7730744289500373, 0.40293016178267343, 0.858890169433185, 1.8902359306812286, 3.5110178972993578, 4.612812204020364, 4.990391646112714, 2.6558520708765303, 4.32817143201828, 4.242027231625148, 5.696450650691986, 13.330050383295331, 19.37126326560974, 29.23840876988002, 42.210434981754844, 45.367383752550396, 46.328997067042756, 43.757169995989116, 41.779181139809744, 39.670399393354145, 41.739864758082796, 44.386423179081504, 47.50910343442644, 49.15408597673689, 46.56235579081944, 46.69385739735195, 48.66547475542341, 46.7460800579616, 44.96491282326834, 42.62836912700108, 40.161525862557546, 35.39025000163487, 35.55588115964617, 33.92808151245117, 34.80960294178554, 33.4984952381679, 34.708444118499756, 37.1251665524074, 41.890095233917236, 40.70018495832171, 42.99917016710554, 43.28777401787894, 46.753768239702495, 46.29120928900582, 53.99929414476667, 37.452089718409944, 36.46871812002999, 48.55793053763253, 49.117868491581504, 51.47760527474539, 45.213449886866975, 47.88560547147478, 48.36806753703526, 52.015288148607524, 47.57581308909825, 45.96082592010498, 41.75229508536202, 34.423620087759836, 33.80763448987688, 34.12911374228341, 37.17054523740496, 43.570426736559185, 46.22729975836617, 50.85074922016689, 50.249802998134065, 50.85681847163609, 51.434328419821604, 48.17553295407976, 45.81891243798392, 43.156126499176025, 43.23620448793684, 47.328898429870605, 48.71080827713013, 46.59219830376761, 51.06150892802647, 45.18474340438843, 31.576911858149938, 17.675807271684917, 15.039957761764526, 8.206684112548828, 12.184657216072083, 7.264623028891427, 2.955424738781793, 6.701368612902505, 5.55422797373363, 3.5209859567029134, 5.258392351014273, 4.858430155685969, 2.3893949517181943, 4.902172974177769, 0.5302153517092977, 0.12562229058572225, 0.7669151276350021, 5.395362189837864, 12.468434674399239, 18.45760120664324, 22.873087610517228, 18.56522880281721, 21.890384776251658, 39.181072507585796, 43.3152437210083, 44.7727951322283, 26.19783190318516, 11.676670942987714, 2.0139866045543124, 0.03453464027760284, 0.028269041130053144, 0.02179274837752538, 0.058346527362508435, 0.07760848770184176, 0.043744019498782497, 0.06369818733739001, 0.014860554731317928, 0.02398300513492099, 0.027238726416336637, 0.013083211977833083, 0.031203518488577435, 0.024190813269732252, 0.030630203895270824, 0.01850478141568601, 0.022174622797008072, 0.03671036620757409, 0.042273338950638256, 0.025652905260877948, 0.0103009597098987, 0.02818502831671919, 0.029670029346432005, 0.04337115093533482, 0.04211330985916512, 0.035495072669748745, 0.025169986799093227, 0.016481530786092793, 0.04307151326377477, 0.03474700138238924, 0.04856991322178926, 0.05171092306928975, 0.022216720805902566, 0.05511616123840213, 0.036763264797627926, 0.03996772784739733, 0.034935756253876855, 0.030656792289976562, 0.05208241420664957, 0.049358499835112264, 0.07045760391546146, 0.0013003683644845815, 0.026327869488990734, 0.005305117561614939, 0.03561102751908558, 0.030343991039054732, 0.06145620585552283, 0.02214566970776234, 0.036366790000881465, 0.036405873617955616, 0.06263357946383101, 0.07057337556034327, 0.08927920181304216, 0.07981332617678813, 0.028532407712191343, 0.06212632025458983, 0.08059206724699054, 0.009992720758808511, 0.04501191646392856, 1.13245518718447, 11.098176956176758, 30.330019405909947, 45.18145343235561, 47.39819976261684, 39.285809653145925, 30.987517016274587, 23.99638376917158, 27.78838746888297, 27.874658039637975, 23.07745671272278, 11.041429281234741, 3.193453086274011, 1.4377034476825168, 0.515564423586641, 0.10018597370279686, 1.8892499378749301, 3.5837290585041046, 5.722797351224082, 6.399796383721488, 5.085489903177534, 4.524883185114179, 5.53518556697028, 7.243275122983115, 13.765751940863472, 25.102279901504517, 32.17864670072283, 44.64718559810093, 48.3867894581386, 48.562703950064524, 44.59224271774292, 43.827023710523335, 41.688996996198384, 44.48612635476248, 46.171523094177246, 49.1534606388637, 49.87113312312535, 48.38535812922886, 46.92759132385254, 49.04837608337402, 47.30483334405081, 47.776709829057964, 44.80928012302944, 41.398725577763145, 37.129005432128906, 36.47291483197893, 35.286127771650044, 36.356654099055696, 35.95766421726772, 39.0408022744315, 39.64283241544451, 44.568740436008994, 44.064676421029226, 45.17324413572039, 45.64902203423636, 49.41925355366298, 47.93751893724714, 53.695571013859336, 39.27797555923462, 38.61625691822597, 49.19323560169765, 48.82723229272025, 51.43492596490042, 46.29073681150164, 48.92623370034354, 51.04046630859375, 52.82992969240461, 50.38869401386806, 47.51847308022635, 43.52963038853237, 34.84517077037266, 35.22420195170811, 35.58676937648228, 39.15849086216518, 45.693205629076274, 48.42739820480347, 51.642944608415874, 49.055466720036094, 51.02027136938912, 51.39374051775251, 50.08702754974365, 48.35496323449271, 45.643185547419954, 46.34574222564697, 48.547567299434114, 50.78636721202305, 49.37601491383144, 51.88767753328596, 47.78422083173479, 37.138076305389404, 26.930833850588115, 19.7955185345241, 10.67114588192531, 11.061070970126561, 11.070507492337908, 8.674035583223615, 11.102134823799133, 8.901091422353472, 9.855235423360552, 7.01662358215877, 4.214447225843157, 1.8598692630018507, 2.5450272176946913, 0.7716616157974515, 0.2699533115540232, 1.0383928631033217, 5.3454437255859375, 15.056520530155726, 22.870560203279766, 27.03965653691973, 23.74232462474278, 29.82153981072562, 45.827656745910645, 49.417374065944124, 49.81969213485718, 29.994852202279226, 14.230209486825125, 2.673883080482483, 0.06495885790458747, 0.03366620705596038, 0.022762995778716037, 0.06195234387580838, 0.07755404205194541, 0.010894303808787038, 0.0007187503049083586, 0.014231620622532708, 0.031355557830205986, 0.029074150071080242, 0.02997628951977406, 0.013902816123196056, 0.01401117816567421, 0.050001181063375304, 0.03847965305405004, 0.029452925281865255, 0.013667393309463347, 0.06965561623552016, 0.052240180383835516, 0.05513494308771832, 0.01529820472933352, 0.02315224757018898, 0.03281499505309122, 0.03857177096818175, 0.027229422004893422, 0.037395713717809746, 0.028794546145945787, 0.024658636023689593, 0.14092016113655909, 0.08841311292988913, 0.14000792508678778, 0.1713451421154397, 0.19027146510779858, 0.09582498842584235, 0.08937177434563637, 0.16071279692862714, 0.10433138161897659, 0.14531948364206723, 0.09202723471181733, 0.15093683078885078, 0.16636322944292, 0.13069359346159867, 0.1282762988869633, 0.11326681250440222, 0.2036520399685417, 0.22301102403019155, 0.1164084364260946, 0.13783845864236355, 0.11098869903279202, 0.17282271997204848, 0.14333856850862503, 0.18123762628861836, 0.20957669562527112, 0.12834977065878256, 0.1882869265973568, 0.13324107176491193, 0.10707959772220679, 0.18818662555090018, 1.3134883301598685, 12.058306830269949, 33.10819060461861, 52.21216535568237, 52.73503814424787, 46.04786600385393, 40.13500806263515, 33.32661764962332, 33.24855463845389, 33.722355774470735, 26.00398758479527, 13.689647453171865, 4.861497785363879, 2.8842332788876126, 0.9789698060069765, 2.24170252255031, 4.697461673191615, 8.345019272395543, 12.903383220945086, 12.913070746830531, 8.231890439987183, 9.295624903270177, 9.721644146101815, 9.35551403250013, 17.737548964364187, 23.612375940595353, 32.55550309589931, 46.037534032549175, 48.86955377033779, 51.16557904652187, 46.92396783828735, 44.887652329036165, 43.89493192945208, 47.36146463666643, 48.63748393739973, 49.988123416900635, 51.28343786512102, 48.217253412519185, 46.681889125279014, 47.992017132895334, 49.657284940992085, 50.960259778159006, 47.91094207763672, 44.00008944102696, 39.67085797446114, 39.002965859004426, 37.35125746045794, 38.64008229119437, 37.82941164289202, 38.89599486759731, 40.71842745372227, 45.09851973397391, 45.15303182601929, 45.2278847694397, 46.94971786226545, 50.13073519298008, 51.75856263296944, 55.902780941554475, 40.69781909670149, 42.153334685734336, 49.26999929973057, 49.896129267556326, 53.33663402284895, 49.22890417916434, 51.3354103905814, 51.39875364303589, 53.58862086704799, 53.0360723223005, 49.96540628160749, 46.576992171151296, 37.05794620513916, 37.47455324445452, 37.75043494360787, 41.13193907056536, 48.376718044281006, 51.3603891645159, 53.639488628932405, 50.99904114859444, 52.104443958827424, 53.180355140141074, 52.72051988329206, 52.21958603177752, 47.67861516135079, 47.59077603476388, 50.98128850119454, 55.26788929530552, 51.05741991315569, 53.73582540239607, 46.89849921635219, 35.255256925310405, 22.2797201360975, 20.761997325079783, 12.047226190567017, 20.012594154902867, 16.608496223177227, 7.672094924109323, 15.976250103541783, 16.53390383720398, 16.635701894760132, 13.825336217880249, 10.399193389075142, 5.665779565061841, 8.358027168682643, 1.841998930488314, 0.4714869516236441, 1.4438188395329883, 6.644032946654728, 17.998792546136038, 25.85405240740095, 32.31254890986851, 28.108405862535747, 34.345508439200266, 51.16271638870239, 54.251756940569194, 55.00753682000296, 36.400559765951975, 16.436295543398174, 3.346445253917149, 0.13797766688678945, 0.13658262602984905, 0.09902441674577338, 0.14115235581994057, 0.12781877629458904, 0.20182570868304797, 0.11264301490570817, 0.120372668706945, 0.12318932185215609, 0.11949421013040201, 0.07850828620472125, 0.11360162203865391, 0.15122614455010208, 0.13209586750183785, 0.11372114598218884, 0.07820843479463033, 0.07399381630654846, 0.14717857459826128, 0.16330619848200253, 0.16718382255307265, 0.09442739627723183, 0.12090382591954299, 0.0716994112091405, 0.11990001478365489, 0.08898360481751816, 0.08733927019472633, 0.1103025304951838, 0.10794355600540127], [0.07100229790168149, 0.03551333543977567, 0.03941658099314996, 0.03311433756191816, 0.055951000191271305, 0.047421899823738, 0.021055019660187618, 0.03814746945032051, 0.03405054625389831, 0.0399088547565043, 0.06808872281440667, 0.022461471779804145, 0.04723716866491096, 0.03252326570717352, 0.02637897844293288, 0.1274550679538931, 0.03940934780985117, 0.02265623677521944, 0.033021412191114256, 0.01895737784382488, 0.01078675770466881, 0.023634531601731266, 0.019371777839426483, 0.033421622323138375, 0.04202156513929367, 0.0419914280064404, 0.006436804983033133, 0.01759664371742734, 0.02845036095407392, 0.06219059109155621, 0.23756477236747742, 6.17261460849217, 19.508714267185756, 40.7596823828561, 48.81988457271031, 50.10932779312134, 38.17112752369472, 33.33654662540981, 28.400862489427837, 25.817728962217057, 14.25404875619071, 8.5250757592065, 7.194417127541133, 2.012554624250957, 0.8627184097255979, 0.0687324625572988, 1.1499472771372115, 2.6826219601290564, 4.009254327842167, 5.020680580820356, 5.442428852830615, 2.1952837790761675, 3.6895503401756287, 6.601054430007935, 9.638492447989327, 19.42490335873195, 25.552955695561, 38.1909750529698, 46.546090057918, 47.04097897665841, 45.45193985530308, 44.04198707853045, 41.751370974949424, 43.33720350265503, 44.32597732543945, 47.67443929399763, 47.75388152258736, 50.0604750088283, 46.68782288687569, 44.622154712677, 47.325167247227256, 45.23111915588379, 42.81464685712542, 41.718075207301546, 39.76263672964913, 36.661047731127056, 33.25066341672625, 32.03901917593819, 32.91001408440726, 34.342864649636404, 33.11876228877476, 36.097819805145264, 37.81998641150338, 41.306390966687886, 42.43270785467965, 49.583967549460276, 45.07753964832851, 50.70738703863961, 41.5080554825919, 34.04361963272095, 51.69862747192383, 42.95197452817644, 51.02323825018746, 49.07076665333339, 48.88915811266218, 46.567917823791504, 45.01560688018799, 47.41450718470982, 47.22540848595755, 42.71000698634556, 35.96285104751587, 32.582774775368826, 32.79655694961548, 33.623277936662944, 42.05758156095232, 46.449854033333914, 47.78712865284511, 49.393743242536274, 49.150465965270996, 48.1632068497794, 46.99265078135899, 47.29767322540283, 45.680952480861116, 45.437564032418386, 46.544860226767405, 48.56831462042672, 50.96527637754168, 48.92251641409737, 44.407458850315635, 33.6761919430324, 27.775003501347133, 17.1705481665475, 7.462633660861424, 8.409640993390765, 10.116197603089468, 11.906804834093366, 12.207145060811724, 9.085566094943456, 8.299221958432879, 5.0452702556337625, 2.091455544744219, 0.7333685734442302, 0.23474564935479844, 0.6717264897056988, 0.23078134922044619, 1.7373229073626655, 5.3591881309236795, 15.07209665434701, 22.79592960221427, 33.845616817474365, 29.43836750302996, 26.559575966426305, 32.879303046635215, 43.79711518968855, 42.96492944444929, 24.296737023762294, 6.127397034849439, 1.4075381691966737, 0.07892230791704995, 0.006311088559284274, 0.017082466843671033, 0.021236222436917678, 0.03537663098956857, 0.02226476787057306, 0.03406105336866208, 0.04024694161489606, 0.043056870478072336, 0.034743384790739844, 0.1549002488276788, 0.026319472618134956, 0.023037627738501345, 0.022254067373328974, 0.03811597864010504, 0.0557698686607182, 0.05455501956333007, 0.026791719420413886, 0.00798724011318492, 0.013800917126770531, 0.03628369999517288, 0.0594046755826899, 0.04685363353097013, 0.05295559038807239, 0.009614895497049605, 0.030130249115505388, 0.016223823186010122, 0.04092120186292699, 0.017153495889423147, 0.07695845793932676, 0.03830384123804314, 0.045046660849558454, 0.0666163018239396, 0.014976750460586377, 0.023744332138448954, 0.03105789130287511, 0.015196217523355569, 0.045117828994989395, 0.005468656375472034, 0.034433457135621987, 0.015064020242009844, 0.04776838355298553, 0.012858493054019553, 0.03812629576506359, 0.015591839062316077, 0.02363889797457627, 0.008491940397237028, 0.02708228338243706, 0.017509195820561478, 0.012015118978784552, 0.012145894729266209, 0.024424526175217967, 0.03293335870174425, 0.018265431580532874, 0.03183501406705805, 0.01718781958334148, 0.02019565336273185, 0.062429116506661685, 0.4116134558405195, 7.453446405274527, 23.664247717176163, 45.608038084847585, 52.54749584197998, 52.310471943446565, 41.25266749518258, 32.23211656297956, 35.07541670118059, 31.128596714564733, 21.169545650482178, 12.28135963848659, 6.187707832881382, 2.2916993711675917, 0.7118439227342606, 0.2652731298335961, 1.2554273371185576, 3.2469175202505927, 5.579701806817736, 5.105416468211582, 5.973285121577127, 6.192902479852949, 4.884285705430167, 7.744615878377642, 11.995707035064697, 21.672185284750803, 28.37416751044137, 41.329309599740164, 48.09796673910958, 49.25736747469221, 48.6783949307033, 45.79175887789045, 43.269361291612896, 43.883488246372764, 46.37904494149344, 49.35083811623709, 49.52123573848179, 51.852231298174175, 47.23527840205601, 45.70820331573486, 46.734792709350586, 46.34537744522095, 45.16589641571045, 42.26475599833897, 42.14604255131313, 38.1151875768389, 34.52491440091814, 33.02395411900112, 35.211841106414795, 36.36838960647583, 35.451456683022634, 37.86902679715838, 39.36070775985718, 42.7939829145159, 44.43517868859427, 49.993140016283306, 47.25352437155587, 51.35526139395577, 42.54759979248047, 36.72480092729841, 51.64645692280361, 45.100711890629356, 52.794636317661826, 48.89940323148455, 50.41762978690011, 47.236421380724224, 47.36677653448922, 50.221787861415315, 49.475096225738525, 42.94341434751238, 37.63435138974871, 35.22759962081909, 35.43868589401245, 35.24485199792044, 44.196250983646934, 47.90822185788836, 49.68452187946865, 50.038873059409006, 50.419165338788716, 50.448069844927105, 49.47582926068987, 48.69064113071987, 48.009887899671284, 47.095498016902376, 49.33683402197701, 51.950072356632774, 52.34622389929635, 50.50683423451015, 43.31001172746931, 36.403363364083425, 28.657132898058208, 17.768056767327444, 9.64988923072815, 9.91610859121595, 9.46800536768777, 9.070564934185573, 10.662418944495064, 9.519561869757515, 6.8217348626681735, 7.3329411915370395, 4.6255278417042325, 1.595907415662493, 1.265918248466083, 0.3756095463676112, 0.30337816370385035, 1.4513473212718964, 6.783926674297877, 16.39756281035287, 24.513361011232647, 34.71145268848964, 27.772349289485387, 28.044845478875295, 38.05572141919817, 48.84122943878174, 48.79231759480068, 29.37779310771397, 9.510503155844551, 2.0455366373062134, 0.06730522521372352, 0.07554976495781116, 0.020116787237514342, 0.0339999478975577, 0.04418863635510206, 0.06658550990479332, 0.0677166481369308, 0.01786003913730383, 0.030642417525606494, 0.007483801056098725, 0.05231346555852464, 0.019530504143663814, 0.02365762723742851, 0.015178472136280366, 0.03049514489248395, 0.05940684689474957, 0.016497669741511345, 0.04067538558904614, 0.05868430209479161, 0.004747932169785989, 0.022084532006244575, 0.02598625933751464, 0.008100926111053144, 0.04284959499325071, 0.04965309599148376, 0.03976733610033989, 0.017409591968836527, 0.014074503294458347, 0.20400107838213444, 0.11012015385287148, 0.075516503171197, 0.15043250285089016, 0.16232058565531457, 0.19152385076241835, 0.1287067343613931, 0.1394027125622545, 0.08098497294953891, 0.09101707927350487, 0.13645550927945546, 0.12339163385331631, 0.09762466685580355, 0.1453181944255318, 0.09596731793135405, 0.19554186372884683, 0.10483136014746768, 0.1421140299311706, 0.10239502588020903, 0.08230398395763976, 0.07174331242484705, 0.09441850068313734, 0.19981382521135466, 0.1306309646793774, 0.07158066079552684, 0.1346761461879526, 0.04986233583518437, 0.1815344039350748, 0.07616609867130007, 0.19394755070762976, 0.4894048901540892, 8.80536869594029, 27.245884282248362, 50.37122971670968, 60.49968133653913, 59.7142778124128, 50.26269538061959, 42.583765166146414, 38.87420531681606, 36.281509331294465, 24.714824029377528, 14.77522097315107, 9.635170340538025, 3.0574223399162292, 1.3144755171877998, 0.7659926457064492, 3.4733447645391737, 8.455992426191058, 12.013692447117396, 13.331702317510333, 13.43902245589665, 9.317701935768127, 8.986237253461566, 10.643928919519697, 13.201412303107125, 23.695398228509085, 29.438207694462367, 41.498852593558176, 51.382182189396445, 49.56464113507952, 50.57286296572004, 48.70766074316842, 45.87991762161255, 46.75895159585135, 47.2083089692252, 50.639416285923545, 50.75713266645159, 52.352723939078196, 47.099604402269634, 44.87252957480294, 49.07672473362514, 49.079847948891775, 46.46814864022391, 45.447621549878804, 44.34338256290981, 40.897027424403596, 37.037865911211284, 34.47390767506191, 36.280119691576274, 38.13610165459769, 36.945305483681814, 39.76302235467093, 42.152202129364014, 44.40852887289864, 48.03527661732265, 52.646354811532156, 48.280759947640554, 52.044126646859304, 45.66548579079764, 40.685458251408164, 51.75972645623343, 46.39887857437134, 51.128357546670095, 50.20013380050659, 49.98064368111746, 48.4487430708749, 47.51472452708653, 52.09632151467459, 51.90623617172241, 45.960478510175435, 39.70881945746285, 36.74298088891165, 36.46907595225743, 36.95585979734148, 45.881209986550466, 50.04909038543701, 51.23786115646362, 51.74033055986677, 51.142976556505474, 50.74506711959839, 51.10088784354073, 50.647264276232036, 50.22275366101946, 49.37144647325788, 51.35956232888358, 52.662155015128, 53.25924498694283, 52.49232019696917, 48.363530363355366, 38.702088015420095, 32.68769257409232, 20.77920627593994, 11.653981600488935, 13.115291118621826, 16.99297479220799, 21.370409386498586, 18.724236590521677, 16.75317508833749, 16.693905217306956, 12.751199432781764, 8.907656601497106, 4.3843510917254855, 2.5910156071186066, 2.66062222634043, 0.852978880916323, 2.2278662707124437, 8.168603641646248, 20.46682221548898, 32.058213574545725, 46.60230793271746, 40.27597311564854, 37.869996070861816, 44.94866793496268, 56.46536615916661, 55.73657308306013, 32.56101996558053, 10.472874692508153, 2.631625873701913, 0.189622324226158, 0.1861705215913909, 0.19271994515189103, 0.11375917786998407, 0.1266676823475531, 0.13451422059110232, 0.16661500664693968, 0.1332895734480449, 0.11461189282791955, 0.1145046842949731, 0.18426075764000416, 0.1272641417703458, 0.088742616320295, 0.05818844905921391, 0.09922005874770028, 0.17681645495550974, 0.15343812799879483, 0.16499550640583038, 0.10249017006052391, 0.13941525188939913, 0.13955003608550343, 0.107207718704428, 0.11264690969671522, 0.1452793279396636, 0.18468903537307466, 0.13334905382777962, 0.09738905235592808, 0.07386697775551251], [0.03304049598851374, 0.02319890363807125, 0.010983689771299916, 0.022387452090957334, 0.05595057949955974, 0.022061950360823954, 0.07849946524947882, 0.08268504243876253, 0.06740344994302307, 0.05466798207323466, 0.02222057997382113, 0.04747373311381255, 0.05842238757759333, 0.06176693418196269, 0.030550530313381126, 0.014326717305396284, 0.01997146539257041, 0.042943090333470275, 0.007099370680017663, 0.08059594168194703, 0.07430584742022411, 0.03976859139012439, 0.024842770071700215, 0.02479611400381795, 0.009172805335505732, 0.022793957331616963, 0.055191492196172476, 0.0042796446193408754, 0.03982639578836305, 0.03344244656286069, 0.08094467475478138, 3.19006301675524, 13.921850170407977, 31.235442638397217, 44.61759669440133, 42.03606298991612, 38.77771915708269, 36.804760796683176, 24.013382537024363, 26.789448431559972, 17.071972336087907, 10.944163186209542, 6.286132540021624, 2.007515226091657, 1.1121517909424645, 0.15733743804906095, 1.1934790440968104, 1.9377542265823908, 3.2711969145706723, 2.6285547699247087, 3.8400852339608327, 3.663124603884561, 4.478428832122257, 4.5432120987347195, 9.617097207478114, 17.676003558295115, 25.059022154126847, 32.0417081287929, 41.59248651776995, 50.325093678065706, 46.448509556906565, 44.358453205653596, 43.54624700546265, 44.02130576542446, 44.94988734381539, 47.33384207316807, 49.66262810570853, 47.93891552516392, 46.03126328332083, 46.647565024239675, 44.829051222120015, 46.985751220158164, 43.843900884900776, 44.48335402352469, 42.845635822841096, 42.04373380116054, 39.51695537567139, 34.85197305679321, 34.716399805886404, 36.327610628945486, 34.18716246741158, 37.224032470158164, 40.865625040871755, 42.507678917476106, 44.53345053536551, 48.12968873977661, 45.96447025026594, 53.115966183798655, 38.607144355773926, 31.914132254464285, 39.67523533957345, 37.869617394038606, 47.025175298963276, 43.51048810141427, 50.38342727933611, 44.799087115696494, 49.64557722636631, 46.12656477519444, 46.09227194104876, 43.45773390361241, 35.110008307865684, 31.520026956285747, 33.049804891858784, 33.809051922389436, 40.541078158787315, 43.67256872994559, 46.974647998809814, 49.48860699789864, 50.16648020063128, 48.943760531289236, 48.42549787248884, 49.24846683229719, 47.82365880693708, 46.069339411599294, 49.35838385990688, 50.42829874583653, 49.03039067132132, 47.96019785744803, 42.407280921936035, 37.30026463099888, 33.501416955675396, 18.66934929575239, 10.725704005786351, 7.734660846846444, 8.107376984187535, 8.552150283540998, 8.0129440171378, 5.741220065525599, 4.342043076242719, 5.25729193006243, 2.591425116573061, 1.3639269322156906, 0.7171858932290758, 0.15982710516878537, 0.2828284592500755, 1.2856105289288928, 6.292752001966749, 14.412009971482412, 27.076961415154592, 27.970454590661184, 27.47314075061253, 29.854095595223562, 37.240635190691265, 44.698261805943076, 39.41674150739397, 15.89443506513323, 5.10920193365642, 0.8426487009440149, 0.06257718641843114, 0.09015639152910028, 0.034278350815709145, 0.019375095875667672, 0.05398955562018922, 0.06495393174035208, 0.03832829564011522, 0.026872410804831555, 0.04118703152718289, 0.021026351555649723, 0.047660767899027894, 0.03704251927722778, 0.039400509891233275, 0.032062808450843604, 0.07441361235188586, 0.032964069196688275, 0.05807248063917671, 0.034237927091973167, 0.012962976420697356, 0.03602149370791657, 0.0158844352367201, 0.014139599399641156, 0.05345324493412461, 0.02120507598322417, 0.02916956227272749, 0.04916813683563045, 0.08516246200140033, 0.012875034041436655, 0.02900150611198374, 0.02513546633001949, 0.026604129932820797, 0.01190672894673688, 0.03213549990739141, 0.00911963448327567, 0.06008302739688328, 0.006433499245239156, 0.0460376476735941, 0.0477365704386362, 0.02020719863607415, 0.018321449735334942, 0.011800871546646314, 0.01845171319187752, 0.010802749078720808, 0.031090118323585818, 0.0035468832024240066, 0.03533522678273065, 0.08482856170407363, 0.07930190754788262, 0.10507697625351803, 0.029072569084486792, 0.018278931034728885, 0.022228026895650795, 0.03900745151830571, 0.029558264450835328, 0.017226082173043063, 0.046751619183591435, 0.04428204009309411, 0.020032631931826472, 0.015016828131462847, 4.411766077790942, 16.90741467475891, 37.9394085747855, 51.80940955025809, 49.745488848005024, 43.18671594347273, 43.173267705099924, 30.690120220184326, 30.167118889944895, 22.795917442866735, 14.905871425356183, 8.456303358078003, 2.5473292427403584, 0.9025080289159502, 0.2676713711449078, 0.4549174793064594, 3.1286313874380927, 4.36753123998642, 6.7436371105057855, 6.174678657736097, 5.66489280121667, 6.117682150432041, 6.560283703463418, 9.306633455412728, 18.463489804949077, 25.946286269596644, 35.84583296094622, 45.670894963400706, 51.159433364868164, 47.85197966439383, 46.608342443193706, 45.14331824438912, 45.09194673810686, 47.44825458526611, 48.83346135275704, 50.78111089978899, 48.27662924357823, 46.93225703920637, 46.426112038748606, 47.69766017368862, 47.91852603639875, 44.9603339603969, 45.29804767881121, 44.372901984623496, 43.39524875368391, 39.63849326542446, 35.97103949955532, 35.48268188749041, 37.02666194098336, 35.723138196127756, 38.84123958860125, 41.63715648651123, 43.752750941685264, 45.79482650756836, 49.816832951136995, 46.79722922188895, 53.0993287222726, 40.92718260628836, 34.00104801995413, 41.850056239536826, 40.583243301936555, 47.43479592459542, 45.118798051561626, 50.06682218824114, 45.55690629141671, 50.09189476285662, 49.38776084354946, 48.76806838171822, 44.347982270377024, 38.05751058033535, 33.702445711408345, 35.3666330746242, 35.76548399244036, 43.17969478879656, 45.67773199081421, 48.26576573508126, 50.01754208973476, 51.73147160666329, 50.239436285836355, 49.77711009979248, 50.805269786289756, 48.94289895466396, 46.96216903414045, 50.77077545438494, 52.15590231759207, 50.44800731113979, 48.473231996808735, 43.77882405689785, 37.02603660311018, 27.749625205993652, 14.553789700780596, 9.58806415966579, 7.387246574674334, 10.052735362734113, 9.599136114120483, 10.989928364753723, 7.286173735346113, 6.205181683812823, 8.746361119406563, 6.066737958363124, 2.1072635650634766, 0.6514121283377919, 0.307979228241103, 0.40123493703348295, 1.6973589318139213, 7.4504751818520685, 16.230561120169504, 28.709770713533672, 36.14656489236014, 31.774139949253627, 34.45910453796387, 43.06748138155256, 50.40589427947998, 46.039969376155305, 21.213124752044678, 6.622336328029633, 1.0854068717786243, 0.058188822253474166, 0.05390329346326845, 0.02618885801972023, 0.010312694124877453, 0.1207312744643007, 0.009747871397329229, 0.018475797792364444, 0.026781300515202538, 0.014971381552251322, 0.04532253961744053, 0.04199073929339647, 0.03217532991298607, 0.009412092406169643, 0.012157199122676892, 0.029497097911579267, 0.04802123962768486, 0.0074660921402807745, 0.051421782334468195, 0.034380103927105665, 0.050032607412764, 0.05927934337939535, 0.05180340399965644, 0.034341882049505196, 0.02917618816718459, 0.0350711307754474, 0.049385773550186834, 0.06358233426830598, 0.043809454023305855, 0.11161335158560957, 0.16364917079252855, 0.06482724246702024, 0.16329515193189892, 0.09519412727760417, 0.08173166002546038, 0.1701436194458178, 0.1506066827901772, 0.14213138685694762, 0.12010949211461203, 0.07783835501010929, 0.11346613895148039, 0.195495479074972, 0.10406648154769625, 0.08711719925382308, 0.1556774971208402, 0.09168940569673266, 0.14546726856912884, 0.17669871555907385, 0.20112916534500463, 0.25569620515619007, 0.15430102098201, 0.052932700009218285, 0.1038913516593831, 0.09497097068067108, 0.11602505056985787, 0.12137726694345474, 0.09863492407436882, 0.12604146237884248, 0.10546134598553181, 0.21702014335564204, 5.062518724373408, 20.121481112071447, 42.73855018615723, 56.92679255349295, 55.52264152254377, 49.880197048187256, 47.86959682192121, 34.7024895123073, 36.106842041015625, 29.161148275647843, 16.985441207885742, 10.456932050841194, 3.3733760373932973, 2.014591097831726, 0.88089712283441, 2.6622487562043324, 5.389700710773468, 9.493262938090734, 8.303742630141121, 12.178979669298444, 11.603809526988439, 8.406778335571289, 7.121886619499751, 11.648653200694493, 21.33253649302891, 26.924121890749248, 38.073328154427664, 45.59262350627354, 54.03704023361206, 50.02218696049282, 49.37628241947719, 48.25506550925118, 48.329373019082205, 48.88939087731497, 52.248740673065186, 52.680612904684885, 48.83197791235787, 46.044207777295796, 47.05736977713448, 47.23111643110003, 52.29193067550659, 49.18127775192261, 47.76738882064819, 46.60763372693743, 47.64442307608468, 42.55924497331892, 38.84867068699428, 37.825419902801514, 39.84875617708479, 37.53320298876081, 40.84282800129482, 45.292040961129324, 45.86332879747663, 47.67979982921055, 50.58565807342529, 48.952661173684255, 55.16542073658535, 43.37044021061489, 38.003509180886404, 45.44347694941929, 44.813546316964285, 48.89721802302769, 46.14824662889753, 50.60820845195225, 45.324343136378694, 51.37553971154349, 50.27371869768415, 50.83192655018398, 47.04233040128435, 38.666276999882285, 34.71265472684588, 37.16675846917288, 38.01533154078892, 44.297920499529155, 47.66575057165963, 50.24389702933175, 51.56032010487148, 51.41520350319998, 53.1902563231332, 51.411604336329866, 53.67428868157523, 52.07130799974714, 51.003758975437705, 53.69788476399013, 52.823259421757285, 51.71766553606306, 50.88953406470162, 46.51108503341675, 40.371041842869346, 37.86414916174752, 23.35821952138628, 14.768291882106237, 12.069208553859166, 18.404167822429113, 16.24852568762643, 13.570777671677725, 13.351415225437709, 15.381093467984881, 17.193333046776907, 8.37527346611023, 4.920349895954132, 1.490099704691342, 0.7325641566089222, 0.7272682722125734, 2.506884430135999, 9.415670667375837, 20.347717932292394, 36.35073075975691, 40.30488804408482, 40.8032614844186, 43.94914524895804, 51.306919302259175, 59.66733578273228, 50.80536011287144, 24.11057046481541, 7.693228738648551, 1.4914055317640305, 0.12118332806442465, 0.20203069411218166, 0.1674891361700637, 0.11410875911159174, 0.18045942804643086, 0.10538399299340588, 0.10583969032657997, 0.17007538596434252, 0.22110507344560965, 0.12109920329281262, 0.1844452377408743, 0.13957773388496467, 0.1583798849689109, 0.11918611451983452, 0.12343634931104523, 0.10384804755449295, 0.06733613248382296, 0.1623378882982901, 0.1019762544227498, 0.11762760100620133, 0.1454031877219677, 0.1457826787871974, 0.13004526682198048, 0.11162903931524072, 0.13257335259446076, 0.16368673449116095, 0.19011002805616173, 0.14415085635014943], [0.06463530526629516, 0.035644000928316794, 0.09747593876506601, 0.014193476776459386, 0.01523109252697655, 0.11427311386380877, 0.026794504806665436, 0.07705882005393505, 0.02664885387223746, 0.030845608229615858, 0.05069090512448123, 0.01946913743657725, 0.04556165875068732, 0.05485008390886443, 0.030088095127471855, 0.03438956949061581, 0.03832386141376836, 0.0677350228652358, 0.03776742537905063, 0.03653834740232144, 0.04600328326757465, 0.009565627069345542, 0.021942480700090528, 0.0416752985412521, 0.01544087689502963, 0.032752956596336195, 0.011650425914142813, 0.019258543915514435, 0.016282397721494948, 0.0741048382062997, 0.0485188839957118, 0.7937932025109018, 9.570890818323408, 28.70928955078125, 46.92101485388619, 43.68094825744629, 42.70871114730835, 30.63256481715611, 22.47408730643136, 29.33330031803676, 24.09065866470337, 18.852467332567485, 11.444950257028852, 4.87181064912251, 1.051822536758014, 0.5859708998884473, 0.1301123739353248, 3.608995748417718, 2.5708271818501607, 5.64514558655875, 4.149227525506701, 3.7812774181365967, 4.865516449723925, 6.5715310999325345, 7.436376418386187, 13.864879284586225, 21.172583750316075, 29.755337374550955, 39.94322735922677, 47.435761724199565, 47.39081382751465, 46.086595262799946, 44.59488303320748, 44.33716739927019, 45.99210671016148, 49.648554529462544, 48.15924637658255, 47.2110778263637, 47.46522208622524, 45.479597159794395, 46.17696005957467, 47.3570316859654, 47.316746030535015, 47.06685059411185, 43.04779713494437, 44.85853590284075, 44.129030636378694, 38.729870387486045, 37.546585219247, 37.25930152620588, 35.73142392294747, 38.926879610334126, 39.29073245184762, 40.366032191685264, 42.46778236116682, 44.90438706534249, 45.55601692199707, 50.68473243713379, 42.27047783987862, 27.539935520717076, 40.02899592263358, 42.15777805873326, 46.72496100834438, 44.86844055993216, 47.65811102730887, 45.82420349121094, 47.76566219329834, 48.696307386670796, 44.4902640070234, 41.27366842542376, 35.68755647114345, 33.001209190913606, 33.89559868403843, 34.332539626530235, 38.76104348046439, 43.39341442925589, 46.37319803237915, 49.02192776543753, 49.75661986214774, 48.42465714045933, 47.85817745753697, 49.08577128819057, 49.141151905059814, 49.32338925770351, 52.2833913394383, 49.71347849709647, 49.29195213317871, 48.43120581763131, 40.51754808425903, 37.044247831617085, 24.782709666660853, 13.856818505695887, 7.042740557874952, 9.166803564344134, 6.904173067637852, 5.708616512162345, 14.64368462562561, 8.277343818119594, 2.6031719148159027, 5.19562406199319, 6.284929633140564, 0.5248917288013867, 0.9109085095780236, 0.730681086225169, 0.299913401050227, 1.8178960638386863, 7.407759393964495, 19.74531258855547, 31.950533866882324, 27.770483698163712, 28.41397374016898, 35.90244688306536, 42.93728951045445, 43.140124797821045, 36.18985564368111, 17.952055488313945, 4.764420594487872, 0.5319678719554628, 0.0661097007936665, 0.04228440585679241, 0.038579879461654594, 0.025707474743415202, 0.0858824419389878, 0.02706261265224644, 0.01460836870994951, 0.10159920608358723, 0.017652597411402633, 0.054530683904886246, 0.017226389210139, 0.020886731101199985, 0.029406350638185228, 0.015380539864833866, 0.046861915050872734, 0.014835905250427979, 0.05460954663742866, 0.044966502115130424, 0.023118046012574008, 0.05123968728418861, 0.06491676837738071, 0.028063178694407855, 0.045185960696211884, 0.0082857073118378, 0.03655608091503382, 0.058254674077034, 0.009174278604664972, 0.019930412327604632, 0.014896610385871359, 0.030625484684216123, 0.07118672371975013, 0.017519755521789193, 0.044078547441001446, 0.04094537128029125, 0.03967973383675728, 0.06506096385419369, 0.011898793479693788, 0.04224742230560098, 0.0006746716628965389, 0.01194826207522835, 0.08147664620940175, 0.012205884010264916, 0.06544745740081583, 0.02265183817196105, 0.0235519810313625, 0.03816865670627781, 0.049700939495648654, 0.026496957022962824, 0.019995965595756258, 0.019646126510841504, 0.04180621848042522, 0.02089524671568402, 0.029467323794960976, 0.024335527825834494, 0.057442589796015193, 0.02258526540494391, 0.0498728599133236, 0.022170465073681304, 0.09345219896308013, 1.2964461360658919, 11.729966231754847, 33.017315115247456, 50.27412516730172, 48.530651909964426, 48.58984361376081, 37.384271826062886, 26.01894358226231, 35.571278367723735, 23.581248010907853, 19.77594198499407, 12.344949551991053, 4.780235997268131, 1.2839451325791222, 0.36904515432459967, 0.09662722716374056, 2.3145997651985715, 4.096439889499119, 6.187447275434222, 7.750389831406729, 5.014551401138306, 5.5179427436419894, 5.486153866563525, 8.893921749932424, 14.699942452566964, 23.7075697353908, 31.487047331673757, 41.64365652629307, 49.70234053475516, 50.095330647059846, 47.74456051417759, 46.123507567814414, 46.65989112854004, 47.58911541530064, 51.50142369951521, 50.44859790802002, 48.461232457842144, 47.22966773169381, 46.871693066188264, 46.129364899226594, 48.325735637119834, 49.65616628101894, 48.36238043648856, 44.821102482931956, 47.28223432813372, 44.12739086151123, 40.173108509608674, 37.59005314963204, 38.96556370598929, 37.3643548148019, 39.57319756916591, 40.80216366904122, 44.02137177331107, 45.14176879610334, 46.37197862352644, 47.07732500348772, 52.91906813212803, 42.76760755266462, 30.683672291891916, 44.40531880514962, 43.98409816196987, 47.20925045013428, 45.131996154785156, 49.45501593181065, 44.635234696524485, 47.33945969172886, 49.41830859865461, 47.43048456736973, 44.829756464277, 37.310165813991, 34.652351311274934, 35.86557626724243, 36.20199762071882, 40.87205212456839, 45.22151674543108, 49.165394169943674, 51.184540680476594, 50.5874194417681, 48.778035572596956, 49.27202122552054, 48.990761620657786, 51.63603115081787, 50.97269357953753, 52.489290782383506, 50.96527985164097, 50.75786917550223, 50.40735340118408, 42.262556893484934, 36.01535511016846, 23.78034864153181, 15.725885663713727, 10.649354594094412, 7.32439751284463, 7.942290391240801, 6.524940822805677, 12.779892018863134, 7.881249598094395, 6.230048418045044, 5.856076828071049, 5.965619955744062, 1.480553748352187, 0.8837011009454727, 0.24751133578164236, 0.49861293605395723, 1.7265792552913939, 8.163729480334691, 19.169711657932826, 34.11285843167986, 31.706982135772705, 32.27446583339146, 40.52917242050171, 47.01646225793021, 49.87746640614101, 42.01945679528372, 19.901464666639054, 6.367818602493831, 0.5474259310535022, 0.03841627449063318, 0.023862151262749518, 0.01948153766404305, 0.023249035501586537, 0.006030816277156451, 0.004501786382336701, 0.018889592195461904, 0.04561682364770344, 0.04141516178580267, 0.004843130208817976, 0.07537914054202181, 0.07267472387424537, 0.059998027315097194, 0.015289441449567676, 0.011244807009851294, 0.026530904129945805, 0.033189101942947934, 0.020278772206178734, 0.01621467823029629, 0.008969132023464357, 0.04930627638740199, 0.023234614936102713, 0.06385799590498209, 0.03890871788774218, 0.03187700520668711, 0.012065955670550466, 0.03940803145191499, 0.01780582418931382, 0.13294510836047785, 0.1885682607867888, 0.17722607297556742, 0.08456489656652723, 0.18274780096752302, 0.2785307541489601, 0.11241373792290688, 0.21676421351730824, 0.051549401200775585, 0.08737481864435331, 0.08891657912837607, 0.07183317760271685, 0.2064934732126338, 0.16465171985328197, 0.11109140209321465, 0.12855193338223866, 0.07915468580488648, 0.15330145747533866, 0.13947542437485286, 0.1171167998441628, 0.15046891303999083, 0.15375797583588532, 0.10213315886046205, 0.07841258562569108, 0.15235006995499134, 0.14165854294385227, 0.1540091966411897, 0.08949870789157492, 0.1188039771680321, 0.165174911064761, 0.21623073571494647, 1.6562203850064958, 13.552275487354823, 36.65716021401541, 58.76154082162039, 55.67185756138393, 56.165447166987825, 43.67464624132429, 32.674932207380024, 40.19713538033621, 33.682542596544536, 26.6960802759443, 15.690600974219185, 6.398025895868029, 1.972743183374405, 1.5892637435879027, 1.1259728435959135, 6.640142389706202, 10.185262697083608, 11.904680422374181, 13.130827290671212, 8.58655515738896, 10.32225251197815, 11.474802323750087, 10.096718328339712, 17.826117651803152, 24.76611042022705, 33.89733573368618, 43.80722829273769, 52.01511444364275, 51.35441371372768, 50.17347356251308, 47.71482917240688, 47.590140274592805, 49.85448523930141, 52.644819259643555, 50.63820382526943, 51.85116474969046, 48.846739360264365, 47.96648597717285, 46.33103288922991, 47.73138672964913, 50.036170210157124, 51.38170971189226, 47.793236119406565, 49.84174919128418, 46.87396860122681, 42.42080559049334, 40.106548241206575, 41.17023754119873, 40.008870465414866, 41.412139075142996, 42.3223739351545, 43.98549127578735, 47.12447200502668, 47.86619915281023, 48.9586956841605, 52.0577312197004, 45.50313418252127, 34.999698707035606, 44.74973406110491, 47.172529220581055, 47.23948553630284, 46.58858176640102, 49.10755736487252, 45.37650326320103, 48.576697622026714, 53.22461516516549, 49.1678329876491, 46.56305061067854, 39.00280605043684, 36.82522324153355, 37.974361487797324, 38.931913580213276, 42.68406588690621, 46.853026730673655, 50.130933216639924, 52.736486843654085, 51.361823967524934, 49.861958026885986, 50.847073623112266, 51.933837890625, 51.49749449321202, 51.68337617601667, 54.25914634977068, 53.02125876290457, 51.05214275632586, 52.50469493865967, 44.583046776907786, 40.015926361083984, 27.453232424599783, 17.35298180580139, 10.988015004566737, 15.6790999685015, 15.137837035315377, 13.225248966898237, 27.19692553792681, 18.707713774272374, 11.164795415742056, 10.179515668324061, 14.560126457895551, 3.5420528948307037, 2.791899319205965, 1.341813855937549, 0.7376536577939987, 2.5779814379555837, 10.30629597391401, 27.048461641584122, 40.070678165980745, 37.821278776441304, 39.485483510153635, 48.8416428565979, 55.147417954036165, 56.32320254189627, 47.640306268419536, 25.055301393781388, 7.593756590570722, 0.8933519316571099, 0.16045057028532028, 0.1210963534457343, 0.06068645537431751, 0.1451855951121875, 0.08989900962582656, 0.16542165353894234, 0.08047138300857373, 0.16302930191159248, 0.12438362490917955, 0.22162568622401782, 0.15669166270111287, 0.16551871118800981, 0.09693648306918995, 0.1049658457881638, 0.13951613647597177, 0.12404920213988849, 0.12362153508833476, 0.14122653326817922, 0.09797729471964495, 0.10833906049707107, 0.12419590141092028, 0.12363985553383827, 0.11679084519190447, 0.13011521021170275, 0.11538397068423883, 0.14383070995765074, 0.113116021667208, 0.09905960557184049], [0.02182396098838321, 0.028749328572303057, 0.00877870456315577, 0.07906914289508547, 0.043125545007309744, 0.04128729186153837, 0.012476667828325714, 0.008556431758084466, 0.01671453801515911, 0.03013403873358454, 0.029857210016676357, 0.008370921132154763, 0.05610727698409131, 0.04450746299698949, 0.028572224147085632, 0.014331509458965488, 0.058464137837290764, 0.03285372583195567, 0.0247542941942811, 0.07882930112204381, 0.0375782260671258, 0.05236890526222331, 0.027883606098060097, 0.04213096534035035, 0.01593105398517634, 0.04876764850424869, 0.013620878885766225, 0.07743720510708434, 0.059303451728607924, 0.02702922872932894, 0.021009054001686827, 0.32138822014842716, 5.299051906381335, 21.004074301038468, 38.78386831283569, 43.87132542473929, 35.296803678785054, 30.473902702331543, 22.823600803102764, 22.014651571001323, 19.341123717171804, 14.202451433454241, 11.266678588730947, 5.560087042195456, 1.4148842607225691, 0.38586595601269175, 0.12574137348149503, 0.9437016184840883, 2.0229061373642514, 5.134274074009486, 5.660309161458697, 4.117713536534991, 4.0211301020213535, 3.2551819682121277, 5.845135586602347, 10.403949431010656, 21.5448317527771, 25.991116046905518, 34.22148309435163, 43.90279381615775, 48.55880601065499, 48.019056047712056, 46.82535900388445, 47.12487152644566, 49.286133016858784, 50.03029203414917, 47.326977252960205, 46.35471929822649, 45.82992533275059, 46.435971532549175, 46.363366331372944, 46.08219705309187, 45.947419370923726, 47.131524426596506, 47.931227343423025, 45.92692565917969, 44.2470075743539, 44.4104118347168, 44.210546902247835, 42.16433368410383, 43.65693180901663, 41.992602007729666, 41.84433439799717, 42.328867026737754, 41.193215233939036, 43.97283860615322, 44.37849528448922, 49.954455920628135, 43.949888706207275, 30.929377964564733, 49.242366313934326, 42.00521993637085, 46.880423477717805, 45.2766124861581, 49.94902242933001, 47.02587359292166, 47.361732142312185, 47.48685877663748, 44.475433077131, 41.23431035450527, 36.78072697775704, 32.68725483758109, 34.53077868052891, 32.855199745723176, 36.05272947038923, 41.80858244214739, 45.698316029139924, 46.32039519718715, 49.629613740103586, 47.52806159428188, 47.019394397735596, 47.94823653357369, 48.743812220437185, 50.56061676570347, 49.02104187011719, 50.26332419259207, 50.55963706970215, 47.28041737420218, 40.989775453295024, 33.45525312423706, 23.22318822996957, 13.629243288721357, 11.786096385547093, 4.779382237366267, 6.030616879463196, 5.648633147989001, 8.032267825944082, 3.8330857924052646, 2.2986065319606235, 4.508936200823102, 3.9431999751499722, 1.8820123033864158, 0.7084808317678315, 0.17268908928547586, 0.4886830917426518, 2.5226418588842665, 10.540385127067566, 18.086814062935964, 25.25694853918893, 29.75072029658726, 30.528925486973353, 26.743277651923044, 40.28320966448103, 39.03906522478376, 38.60611949648176, 16.81205412319728, 3.1434607974120548, 0.3622004458946841, 0.021154453878157904, 0.006364691977588726, 0.017684486860941564, 0.03845825205956187, 0.013104026887698897, 0.05087594501674175, 0.03363423787855676, 0.05348484430994306, 0.04658893023484519, 0.027931145957804153, 0.07091320625373296, 0.000800335818244743, 0.07035836816898414, 0.10404567766402449, 0.028555596646453654, 0.046804392244666815, 0.021297923322500925, 0.013294483185745776, 0.05016868082540376, 0.04438289414559092, 0.03873579323823963, 0.06785519141703844, 0.047265382150986364, 0.04702038351180298, 0.04062561843810337, 0.037173785269260406, 0.013206423759194357, 0.012216832172790808, 0.011918375152163208, 0.029302134444671016, 0.024039067394499267, 0.025537645909935236, 0.04309435275250247, 0.04453517775982618, 0.0424577647687069, 0.026519799904365624, 0.011562955116720071, 0.040121650123702626, 0.022954990654917698, 0.04232369642704725, 0.05484151740425399, 0.012712172066260661, 0.012659331999852188, 0.04159328401354807, 0.01663405867293477, 0.005161714274436235, 0.03606415320453899, 0.055439418713961325, 0.04438307735004595, 0.010612857661076953, 0.04342242782669408, 0.040956397474344285, 0.01377380286742534, 0.05155294993892312, 0.013463150028006306, 0.11311027447560004, 0.006023670031156923, 0.036264202291412015, 0.027667457071532096, 0.35811656074864523, 7.432513219969613, 26.189803259713308, 46.84688104901995, 50.56870099476406, 41.61228888375418, 36.11442599977766, 25.179616825921194, 28.82900701250349, 26.220324959073746, 16.545144285474503, 15.962734120232717, 6.22319358587265, 1.5542062819004059, 0.385580482759646, 0.4688879996538162, 1.5553500205278397, 4.432420032364981, 6.3917204056467325, 6.588497732366834, 3.9155648180416653, 5.372999846935272, 6.435549642358508, 7.423137494495936, 12.9527736221041, 21.483031000409806, 29.59628963470459, 36.91110297611782, 46.05231979915074, 49.70747872761318, 49.16405316761562, 48.92483711242676, 48.97559370313372, 49.79179859161377, 50.12987361635481, 46.94369377408709, 49.12360422951834, 47.56597791399275, 46.35581711360386, 44.69789007731846, 45.862283093588694, 46.81443990979876, 49.78896025248936, 49.368455273764475, 48.439442907060894, 47.02794763020107, 45.75473887579781, 44.63109357016427, 43.69474390574864, 45.23404434749058, 45.55681596483503, 43.5635792868478, 43.155490739004954, 42.611370359148296, 46.379882199423655, 46.468951157161165, 51.86330325262887, 44.80867215565273, 32.817742007119314, 50.85213885988508, 44.959736415318076, 47.18177032470703, 46.67531265531267, 49.96626091003418, 46.958781787327354, 47.020586013793945, 48.76181500298636, 45.82316126142229, 42.30997487476894, 38.139846733638215, 34.284072467258994, 36.037776947021484, 35.09245021002633, 37.29835040228707, 44.00095796585083, 48.06830487932478, 48.778869356427876, 51.373684542519705, 49.07350771767752, 47.585022926330566, 48.39952898025513, 48.35295173100063, 52.40279613222395, 50.393762724740164, 52.056647300720215, 50.7684964452471, 49.7850102015904, 43.17684255327497, 34.487880502428325, 24.00787261554173, 14.234230756759644, 9.960297397204808, 6.877148049218314, 9.215354101998464, 8.768148064613342, 8.375485386167254, 4.723182167325701, 6.589618129389627, 4.072039118834904, 5.2231341515268594, 2.4199255534580777, 0.32937571725675036, 0.19663616429482186, 0.25717557434524807, 2.561554810830525, 10.404106634003774, 23.601408209119523, 30.731149332863943, 34.23359727859497, 35.91534273965018, 35.493760790143696, 47.50494146347046, 47.65118019921439, 43.91195501599993, 20.771556309291295, 4.694609871932438, 0.4944345716919218, 0.040790013902421506, 0.04404029163665005, 0.05342857340084655, 0.12042130609708172, 0.025313249290255562, 0.0209601689462683, 0.03292963693716696, 0.0133578150998801, 0.052743694079773765, 0.012230336715999459, 0.025530886004811952, 0.03256265466500606, 0.008424093680722373, 0.08482379160289254, 0.023636842013469765, 0.04554685650925551, 0.02594856162821608, 0.02162422233128122, 0.010578355851716228, 0.053064010106027126, 0.09316943985010896, 0.05092024317543421, 0.061730150798601766, 0.017628127742292624, 0.02655603876337409, 0.07911811276738133, 0.025178207250844156, 0.012996369673471366, 0.094316862922694, 0.1549593356571027, 0.15784787280218943, 0.11316226382872888, 0.09407325528029885, 0.12869570138198988, 0.17417003267577716, 0.17311645778162138, 0.11903191065149647, 0.0951958711126021, 0.0723526504422937, 0.1120000486927373, 0.15854077919253282, 0.13853091719959462, 0.0923025638663343, 0.09487918524869851, 0.1635356790253094, 0.08276174403727055, 0.14819826345358575, 0.09726396442524024, 0.1484726494444268, 0.10897885795150485, 0.12073212941842419, 0.0896282470119851, 0.11648943993662085, 0.11736685356923512, 0.09965155273675919, 0.20938975922763348, 0.2372725951884474, 0.09955433223928724, 0.15530639274844102, 0.6687564605048725, 8.071049196379525, 29.97777005604335, 51.55272224971226, 56.97428349086216, 46.748529297964915, 41.74221672330584, 33.29899508612496, 31.981269223349436, 31.191012382507324, 21.8154901436397, 16.46912751879011, 8.091886843953814, 2.0368583372661044, 0.6904276747788701, 0.839675849037511, 3.450703190905707, 5.224211556570871, 14.614062717982701, 14.32727495261601, 10.095411198479788, 9.571001989500862, 8.149081809180123, 8.98534093584333, 11.437850935118538, 24.521823917116436, 31.081269059862407, 38.29333244051252, 48.778205803462434, 52.2249813079834, 50.66886622565133, 51.45850467681885, 52.27949340002877, 51.201529026031494, 52.087104729243684, 49.01414925711495, 48.99331508363996, 50.21828249522618, 46.135051999773296, 46.11336667197091, 46.31521184103829, 46.72190727506365, 49.444183690207346, 51.399153164454866, 49.712387629917686, 47.63046761921474, 47.60877186911446, 48.024541650499614, 45.771393707820344, 47.20010314668928, 46.969819000789094, 45.07624380929129, 46.171839237213135, 44.96278667449951, 46.71749169485909, 47.91824810845511, 53.8959709576198, 46.886187008449006, 36.73998621531895, 51.640776770455496, 43.07138279506138, 46.85301978247506, 46.010575022016255, 50.2363269669669, 47.28029578072684, 48.92912762505667, 51.29746280397688, 49.6850951058524, 45.552841595241, 41.00662136077881, 36.22520112991333, 38.63539573124477, 37.20372288567679, 39.2354108946664, 45.11269753319876, 50.702693530491416, 50.823904854910715, 53.46402924401419, 49.767622334616526, 49.24982867922102, 49.48968744277954, 49.11044086728777, 52.98029218401228, 52.032036781311035, 53.37441485268729, 54.656430448804585, 52.844131810324534, 45.028544425964355, 36.792959281376426, 27.38128730228969, 16.352043424333843, 16.418535947799683, 8.526579175676618, 12.6501213823046, 17.331845385687693, 15.669681685311453, 11.237271206719534, 10.975359729358129, 10.924628325871058, 10.482644728251866, 5.9823651143482754, 1.7937487938574381, 0.8616138089980397, 1.2836324636425291, 3.46775906426566, 13.025464807237897, 26.714836938040598, 35.240509373801096, 41.008521693093435, 43.331120354788645, 39.912742137908936, 52.95305177143642, 53.93952921458653, 49.408115591321675, 23.622237171445573, 5.713681314672742, 0.5503684931567737, 0.12165733905775206, 0.10923430602997541, 0.11537639823343072, 0.18533434931721005, 0.11559819776032652, 0.2386549881526402, 0.10707294129367385, 0.11527127958834171, 0.18297310173511505, 0.10570442437061242, 0.14230577035674027, 0.18906648190958159, 0.12032097790922437, 0.20338343509605952, 0.11047611332365445, 0.109988965892366, 0.08081105085355894, 0.11613029135125023, 0.09335398780448095, 0.18892859002309187, 0.20253171079925128, 0.09548278964523758, 0.12367994338274002, 0.098514239835952, 0.20033427514135838, 0.11817820503243379, 0.07031399197876453, 0.0511907445532935], [0.012963513311530863, 0.03242065424897841, 0.018635820098487393, 0.01914109968181167, 0.03769283402445061, 0.05253128547753606, 0.041756821131067615, 0.025478116336411664, 0.035755694577736516, 0.05109809398917215, 0.019610664574429393, 0.019886244786903262, 0.04047880042344332, 0.03154975115986807, 0.06218546815216541, 0.02231620082498661, 0.019359070574864745, 0.02242199800509427, 0.07734978944063187, 0.07448709769440548, 0.015737564635596106, 0.04185388556548527, 0.056684486368404965, 0.07509032889668431, 0.037705471739172935, 0.06701266126973288, 0.02867725458262222, 0.056711071370435615, 0.0779753512303744, 0.02326267066278628, 0.06828082286353622, 0.070822316487985, 2.9089742941515784, 17.086516652788433, 31.011700221470424, 39.26310988834926, 37.985690525599885, 30.101642540522985, 28.734940562929424, 22.258401325770787, 17.297455276761735, 20.395700454711914, 16.675874641963414, 8.219090989657811, 2.457200901848929, 0.4835458759750639, 0.33245268357651575, 1.6129240968397685, 5.384026203836713, 3.341055405991418, 5.916904832635607, 2.2940869459084103, 2.746297423328672, 3.2955219064440047, 5.195720033986228, 8.220757688794817, 15.356677498136248, 24.346668515886577, 29.673473698752268, 39.63602665492466, 46.827585901532856, 47.0683479309082, 49.70111417770386, 49.982703821999685, 51.27490895135062, 49.62602846963065, 49.55513252530779, 45.15663794108799, 45.259026595524375, 48.208245073046, 46.562310627528596, 47.854515756879536, 47.80892167772566, 47.462772846221924, 45.19085087094988, 48.125026498522075, 46.84513357707432, 45.60881975718907, 44.46623018809727, 45.58590112413679, 45.375898769923616, 47.42877183641706, 45.89756604603359, 46.66746813910348, 41.51839440209525, 43.438497815813335, 44.461578369140625, 49.06634759902954, 47.21728604180472, 29.550341197422572, 43.64413322721209, 48.06965282985142, 47.93374606541225, 48.067821979522705, 50.348985058920725, 47.66556297029768, 49.15916510990688, 47.28573274612427, 45.840021065303254, 41.0561238016401, 35.158923625946045, 35.24468871525356, 34.606319495609824, 35.731958934238975, 36.7500124658857, 43.374157496861045, 44.10088348388672, 46.40509721211025, 49.45677730015346, 47.16982637132917, 45.4682993888855, 49.924839224134175, 50.10200439180647, 49.979452065059114, 49.726905890873496, 50.022499629429404, 48.182112898145405, 45.42916366032192, 38.77298048564366, 31.3340653691973, 20.353465829576763, 16.97406874384199, 10.358189463615417, 6.970374635287693, 6.13013071673257, 4.887232175895146, 6.077112487384251, 3.544248525585447, 6.978303832667215, 3.8269223059926714, 2.455998646361487, 1.0865805745124817, 0.5722789860197476, 0.036395753268152475, 0.4310997873544693, 3.589972014938082, 8.185582433428083, 17.287418603897095, 34.9718086378915, 28.709659542356217, 28.666773523603165, 33.0043671471732, 41.030095849718364, 42.981285503932405, 31.49012885774885, 15.910471507481166, 2.4543415009975433, 0.09964539842414004, 0.014320722448506525, 0.04089271357016904, 0.0417941778765193, 0.03459297054048095, 0.023434920169945275, 0.028052300081721375, 0.008692890239347304, 0.060991158309791765, 0.019464114581101706, 0.04535729757377079, 0.08997345848807267, 0.08205905995730843, 0.004919098565421466, 0.030380428369556154, 0.01966628069723291, 0.030972212686070373, 0.062359037409935675, 0.008843766741587647, 0.0310306854413024, 0.035199550313076804, 0.05895236413925886, 0.05470509793875473, 0.015269221106011952, 0.041096335143915246, 0.021099536646423594, 0.032490485680422614, 0.028545723961932317, 0.06273326982877084, 0.016415210773370097, 0.04527040098660758, 0.03107088864115732, 0.04496781508039151, 0.058045366379831514, 0.01592109309110258, 0.06629837424095188, 0.013051481135854763, 0.04439521294885448, 0.05423142282026155, 0.015130301238968968, 0.021791184354307394, 0.02078043350151607, 0.03664056191753064, 0.011211401034545685, 0.032272095791995525, 0.030622648407838175, 0.03723862607564245, 0.022229136300406287, 0.11883441624896866, 0.016790459298395684, 0.04185238939576915, 0.1576091641826289, 0.04245776816138199, 0.015924585850111077, 0.010732428253894406, 0.030198733654937575, 0.048994808457791805, 0.03960168534623725, 0.020646002143621445, 0.010240633705896991, 0.08442847031567778, 4.023476421833038, 20.2934125491551, 36.11231027330671, 45.94164889199393, 41.32630797794887, 34.42619439533779, 29.898133277893066, 24.43499575342451, 22.47255175454276, 19.53146266937256, 20.057922465460642, 8.533199940408979, 2.596662538392203, 0.481561079621315, 0.20490986747401102, 1.710086620279721, 3.5509832842009406, 4.5053717749459405, 7.315113851002284, 6.493864136082785, 6.417404856000628, 5.602465408188956, 5.474853490080152, 10.499067664146423, 18.289946385792323, 26.561028139931814, 32.52429526192801, 41.83954014096941, 50.01125397000994, 49.224964550563264, 52.10989829472133, 50.90619931902204, 52.73734842027937, 50.30159139633179, 49.33464881352016, 46.97116000311715, 47.61713750021798, 47.81556068147932, 47.078843184879844, 47.150517327444895, 47.15538106645857, 47.44761535099575, 47.63397298540388, 49.21458741596767, 49.399753434317454, 48.08460882731846, 47.62530163356236, 46.74418667384556, 46.96664367403303, 48.54031685420445, 47.73182446616036, 48.07394681658064, 42.725925309317454, 45.79357235772269, 46.712565422058105, 50.626169545309885, 47.83572782788958, 32.86079651968819, 45.794743129185264, 47.12591028213501, 48.84904963629586, 48.57131276811872, 50.52568817138672, 49.32567521503994, 52.559505803244456, 49.461908544812886, 47.84552131380354, 43.131533350263325, 37.17600999559675, 36.00416156223842, 36.910835470472065, 36.97568300792149, 37.96499184199742, 45.64228922980172, 45.49360820225307, 47.77263123648507, 51.4752185685294, 48.05926527295794, 46.83771290097918, 49.869013922555105, 51.54989433288574, 51.61880309241158, 50.96408128738403, 51.68599912098476, 50.84526014328003, 49.03992012568882, 40.495553561619346, 32.60467897142683, 22.619518314089092, 16.19872621127537, 9.47485021182469, 6.393636805670602, 7.892127002988543, 7.641349145344325, 7.375715170587812, 6.2573939221245904, 7.235164838177817, 5.056094680513654, 3.032874571425574, 2.195513721023287, 0.6105477639607021, 0.20741321385971137, 0.7970301945294652, 3.4904510123389105, 11.198870250156947, 19.91943791934422, 34.134300572531565, 30.02994407926287, 33.43089968817574, 34.924401078905376, 47.50460794993809, 47.76941769463675, 37.9109001159668, 17.988603012902395, 3.21840124470847, 0.23388567407216343, 0.02545985865539738, 0.04182242189667054, 0.03019185670252357, 0.0644225234697972, 0.06026099356157439, 0.030696160891758542, 0.0077782801651795, 0.06182493535535676, 0.04720324869932873, 0.03180961989398513, 0.11306712643376418, 0.04949483787640929, 0.05322037850107465, 0.004775457790986235, 0.04503410455903836, 0.04843435210308858, 0.057133096403309276, 0.047137559724173377, 0.034580088553151915, 0.01403101852961949, 0.037191308436117, 0.016591750318184495, 0.008260122300790889, 0.03353837784379721, 0.06783453681107078, 0.028520614773567234, 0.03512587837342705, 0.027569597054805075, 0.08685932880533592, 0.08747961159263339, 0.1714125070720911, 0.23022747465542384, 0.1735754595803363, 0.1609382876860244, 0.17049420491925307, 0.1292000293199505, 0.09498169153396573, 0.18867309444716998, 0.07504565415105649, 0.1226578660841499, 0.11044514498540334, 0.1351859024060624, 0.1349761943731989, 0.09504081907549075, 0.10676752589643002, 0.099754662918193, 0.12924287202102797, 0.14304816909134388, 0.10243244030113731, 0.1725914752376931, 0.2640560551413468, 0.09351980819233827, 0.10938166347997529, 0.16660157165357045, 0.08794626726635865, 0.11868337435381753, 0.1945025244993823, 0.06033238223088639, 0.23338222822972707, 0.25996386472667965, 4.9350462044988355, 23.280729736600602, 41.55027968542916, 51.62116200583321, 52.41072750091553, 41.20425592150007, 38.83726174490792, 32.480445180620464, 26.958037785121373, 29.033916337149485, 22.771299975258962, 10.807606765202113, 3.799088256699698, 0.9713275475161416, 1.009879735963685, 3.190918513706752, 9.377482499395098, 10.028340237481252, 14.310113770621163, 10.129640630313329, 5.668646131243024, 6.686952837875911, 9.179246050970894, 14.142650893756322, 19.394326073782786, 28.156575986317225, 33.77191727502005, 43.58623388835362, 51.041859422411235, 51.57861818586077, 52.291023935590474, 53.42979894365583, 54.22605555398123, 50.67872224535261, 48.85509456907, 50.37263672692435, 48.93929631369454, 48.31863110406058, 47.49880967821394, 47.868217604500906, 48.71384811401367, 47.56416096006121, 48.03896958487374, 51.360048702784944, 51.699489048549104, 50.93156371797834, 49.05928128106253, 49.732044083731516, 50.35931355612618, 51.199051993233816, 49.99667664936611, 51.13712269919259, 44.972006934029714, 48.778431619916645, 49.02828189304897, 52.311458587646484, 49.50068991524832, 36.424107210976736, 46.37353154591152, 48.207939352308, 50.23102896554129, 49.82138402121407, 52.76715966633388, 50.42712450027466, 53.3110750743321, 51.39847918919155, 51.10487610953194, 46.45702804837908, 38.81172711508614, 38.396572249276296, 38.87541082927159, 39.41534491947719, 40.52201925005232, 47.531726769038606, 47.7514704976763, 50.3416998726981, 53.60594620023455, 48.39431783131191, 47.2242238180978, 51.99964427947998, 52.271805218287874, 53.99162680762154, 52.13184417997088, 53.8827520098005, 53.59794534955706, 49.81471375056675, 42.355975423540386, 35.383850710732595, 23.860338040760585, 20.908557415008545, 15.525395393371582, 12.061628069196429, 13.091853976249695, 10.966773492949349, 12.973348106656756, 10.40932559967041, 17.6150643825531, 15.695925031389509, 7.0105812549591064, 5.122206790106637, 1.8226586197103773, 0.8968691314969743, 1.069056349141257, 5.11785591500146, 12.38287889957428, 24.220574344907487, 44.60823399680001, 41.06661558151245, 41.81736496516636, 45.39746250425066, 55.58546366010393, 55.26934494291033, 42.50965220587594, 21.496722425733292, 4.256984097617013, 0.4527210885924952, 0.06728260964155197, 0.16914546729198524, 0.07630581581698996, 0.1457144995885236, 0.13433914498559066, 0.13911932919706615, 0.07162654333348785, 0.22336520573922566, 0.1764865240880421, 0.10930657679481165, 0.30365598308188574, 0.15372541972569057, 0.18791564580585274, 0.12211830860802106, 0.0969343524692314, 0.19658402566398891, 0.09489963629416057, 0.07856184975909335, 0.14519402251711913, 0.0724780640697905, 0.1962846288723605, 0.0913190341421536, 0.11054542567580938, 0.16716023667582444, 0.15651330298611096, 0.10552363550024373, 0.09822545533201524, 0.11450262154851641], [0.04795040735708816, 0.021396081894636154, 0.007919105019287338, 0.023630158443536078, 0.003844057791866362, 0.041330738458782434, 0.03843115476359214, 0.020753716185156788, 0.007375718909315765, 0.0017520331852470658, 0.05843822458492858, 0.01861904332015131, 0.045848489073770385, 0.02133893737170313, 0.018013147171586752, 0.022721082670614123, 0.07490741621170725, 0.03800807460876448, 0.022373560782788054, 0.05099622213414737, 0.012096461756820125, 0.06800473374979836, 0.03701094025745988, 0.05974561907351017, 0.04638757836073637, 0.026839283028883592, 0.06301617143409592, 0.030134988682610647, 0.009466138568573763, 0.01718337008995669, 0.07437682896852493, 0.02960121911019087, 1.3783409701926368, 9.480189902441841, 25.164082390921457, 37.842672279902864, 44.419618197849815, 41.1052371433803, 26.397041967936925, 24.563631228038243, 19.83190972464425, 19.65681164605277, 15.87187773840768, 11.401603920119149, 3.0903255343437195, 0.6749812864831516, 0.1873225654874529, 1.8561154987130846, 2.7029758393764496, 3.35914460676057, 4.211690962314606, 5.259850604193551, 8.828645161220006, 7.3462070396968295, 2.0497153273650577, 6.046226007597787, 10.605668663978577, 19.11639986719404, 27.667217833655222, 35.23468678338187, 43.39496387754168, 48.92591060910906, 48.98338958195278, 49.97259419304984, 49.04317883082798, 47.99056148529053, 49.609981604984824, 48.707890033721924, 51.68441145760672, 47.72909729821341, 47.2143816947937, 48.21325125013079, 45.90023415429251, 45.05023322786604, 47.92463002886091, 47.4295083454677, 46.988426276615684, 48.78470584324428, 47.465124811444966, 47.39415938513619, 46.6227946962629, 48.33126292909895, 48.08286830357143, 48.18037237439837, 44.536646706717356, 40.95287357057844, 45.14173752920968, 46.99529457092285, 47.947604247501914, 30.824661663600377, 51.30341741016933, 48.84496062142508, 47.88498360770089, 46.085049288613455, 43.72254364831107, 43.8519468988691, 45.3973513330732, 45.11855833871024, 44.420243535723, 38.30333437238421, 34.71160207475935, 33.95402261189052, 34.488418987819124, 35.485318728855674, 38.088805266789024, 41.41779490879604, 45.038098199026926, 46.7191036769322, 50.04514728273664, 48.35748890468052, 47.859772069113596, 48.655986990247456, 50.15621076311384, 48.95344284602574, 51.23348726545061, 51.95840324674334, 47.752467564174104, 43.33425051825387, 35.92706782477242, 27.002382925578527, 20.138841186250957, 13.940299374716622, 7.7794515405382425, 7.687651072229658, 8.706230061394827, 6.145247391292027, 6.636823322091784, 3.2045971282890866, 3.764781960419246, 2.439740513052259, 2.9480047140802657, 1.0934152134827204, 0.20507452078163624, 0.26172805577516556, 0.609676904976368, 3.2280164659023285, 11.49457255431584, 24.42021519797189, 33.79128885269165, 30.77389117649623, 29.884393215179443, 43.83741474151611, 45.874546664101736, 39.3971962247576, 27.676653487341746, 11.524947472981044, 3.468873381614685, 0.030655499680766037, 0.05339978655268039, 0.054748999154461284, 0.017028774367645383, 0.05552702097754393, 0.028401499647381048, 0.03087531788540738, 0.06356896034308843, 0.04232696018048695, 0.044103113801351616, 0.04828396838690553, 0.027927463208990436, 0.014653379330411553, 0.07095619823251452, 0.02717000269331038, 0.016336668648623993, 0.04019458246018205, 0.0748797794803977, 0.040612292010337114, 0.1475118167166199, 0.011469277420214244, 0.04510078758799604, 0.02144302294722625, 0.011342197989246674, 0.03818641396771584, 0.00023861881969163993, 0.016395957342215946, 0.03771953437743442, 0.011953028783734356, 0.013237671993140663, 0.02868028763415558, 0.0385745563544333, 0.004616658120150012, 0.023154503699125986, 0.027407571374039565, 0.042888481835169454, 0.025010563300124238, 0.10019648421023573, 0.012828225303175194, 0.01818754424207977, 0.048701304742800336, 0.08370925712266139, 0.04071795009076595, 0.03431126315678869, 0.010320621958401586, 0.016872701135330966, 0.007919976936786302, 0.07279141154140234, 0.029080847211714302, 0.014990214291693909, 0.1144181846507958, 0.03857234093759741, 0.049077939175601513, 0.05535195894273264, 0.024975262515779053, 0.09860542137175798, 0.06651440622018916, 0.07861609863383429, 0.049213965090789964, 0.024336065564836775, 0.03914611014936652, 2.037654774529593, 12.896395070212227, 31.515364715031215, 43.29974923815046, 50.78094066892351, 43.48627015522548, 32.93225874219622, 28.04520157405308, 22.960518530436925, 24.615978956222534, 19.056261471339635, 12.399242775780813, 3.570532040936606, 0.47950848404850277, 0.08006359024771623, 0.5614060865981239, 2.538275957107544, 3.6987228308405196, 6.15439556326185, 4.670041041714804, 6.822763630322047, 4.951332347733634, 2.6307797133922577, 8.234152947153364, 14.113774180412292, 22.688769272395543, 30.56486851828439, 38.23349455424717, 45.359230041503906, 50.93513856615339, 51.440887519291465, 51.286911964416504, 50.39407191957746, 49.40270641871861, 49.52712433678763, 48.97348492486136, 50.12218543461391, 47.24301869528634, 46.83379411697388, 48.46069049835205, 45.42301797866821, 44.28019911902291, 47.541905879974365, 48.19209745952061, 49.711512156895225, 50.27623741967337, 50.6200829233442, 48.449434416634695, 49.00826413290841, 48.50653123855591, 49.704386779240195, 49.73295777184622, 46.28763444083077, 42.58203853879656, 46.47034774507795, 49.038273402622764, 48.53133283342634, 33.969795022692, 51.53270448957171, 48.161890166146414, 50.43340914590018, 47.58958789280483, 47.56725638253348, 46.65111207962036, 46.685971191951204, 47.16401767730713, 45.6174042565482, 40.40146453039986, 35.9506048474993, 36.38950170789446, 35.46371677943638, 37.561846937452046, 39.23913860321045, 41.64987516403198, 45.865121432713096, 48.36051137106759, 51.829034737178254, 49.22137580599104, 48.05593361173357, 49.33088288988386, 48.666246005467, 49.28949594497681, 52.163732937404085, 53.87187807900565, 49.604787826538086, 46.834975310734336, 37.80642352785383, 30.274145466940745, 21.438138689313615, 15.897259507860456, 9.13762547288622, 5.239220968314579, 7.968505944524493, 6.406191766262054, 7.109504929610661, 6.108645149639674, 7.84546376977648, 3.4081365721566335, 2.949524849653244, 1.9006430293832506, 0.24783695116639137, 0.2991314030119351, 0.487145259976387, 3.837490516049521, 11.350304501397268, 26.253137826919556, 37.15387650898525, 34.787608419145855, 35.23425599506923, 47.51532554626465, 50.64478724343436, 47.1424435206822, 33.12994194030762, 14.97229620388576, 3.542880816119058, 0.03930838519175138, 0.01597811038871961, 0.08468252061200993, 0.04789593795846615, 0.03738974600232073, 0.0038943117916850106, 0.051262201076107364, 0.035707294674856324, 0.05023927560874394, 0.005277188636162984, 0.03772636043972202, 0.021473684248381426, 0.02210641815327108, 0.0023780941223126967, 0.052749512517558675, 0.03435432977442231, 0.025194834751476134, 0.06960923836699554, 0.019107622460329106, 0.03708154861150043, 0.06999645116073744, 0.04926257533952594, 0.014647340368745583, 0.03488444882844176, 0.053440573292651346, 0.0424808587080666, 0.04716755436467273, 0.026661849514182125, 0.0673040309920907, 0.1423240229487419, 0.15328834817877837, 0.06134540108697755, 0.12946687000138418, 0.05761622012193714, 0.30424058171255247, 0.14288164302706718, 0.07223870405661208, 0.1989701890519687, 0.12834229320287704, 0.24141765705176763, 0.10651535514209952, 0.13413586946470396, 0.06768232105033738, 0.11622791896973338, 0.09809199427919728, 0.19699778274766036, 0.10489144442336899, 0.17129235209098884, 0.16881943121552467, 0.06697758100926876, 0.1742492855659553, 0.1089791361508625, 0.12500132247805595, 0.0838762242347002, 0.1259592239345823, 0.15817677229642868, 0.16848367851759705, 0.15490985688354286, 0.17619486259562628, 0.2082565650343895, 0.20479113741644792, 2.686052198920931, 13.66951765332903, 36.500235148838584, 50.045800413404194, 56.2705351965768, 52.42064258030483, 36.58257130214146, 35.001911708286826, 31.384818485804967, 28.175753014428274, 22.13444025175912, 14.905932222093854, 4.658851836408887, 1.1957842175449644, 0.7312527384076799, 3.513495364359447, 7.450563771384103, 9.6784029006958, 11.291702525956289, 13.177115321159363, 16.443275008882793, 13.447570477213178, 4.485693608011518, 9.771366323743548, 14.85653921536037, 21.569025380270823, 31.150521755218506, 38.87689079557146, 47.55002137592861, 51.36695173808506, 52.65826054981777, 52.323326110839844, 50.02612311499459, 48.24430274963379, 50.58566502162388, 49.76078183310372, 50.99230139596121, 47.39050463267735, 47.41787706102644, 49.12716170719692, 45.656804016658235, 44.134203570229666, 48.952522209712434, 48.28108303887503, 49.68737064089094, 51.403996058872764, 52.48380170549665, 52.42698628561837, 50.199904509953086, 50.8391318321228, 52.02405677522932, 51.988155433109824, 48.430688176836284, 43.97318254198347, 48.541564055851524, 51.42135613305228, 50.055566106523784, 35.76002965654646, 51.34814643859863, 50.15552289145333, 52.46933208193098, 49.76182753699166, 48.42750242778233, 47.808181694575715, 48.911552156720845, 50.0755352292742, 48.93485294069563, 42.755990164620535, 37.91024003710066, 38.013507638658794, 37.242299284253804, 38.68854597636631, 41.1606559753418, 44.116624627794536, 47.42137547901699, 51.202394076756065, 53.175922189440044, 50.96886164801461, 48.827496324266704, 50.750313009534565, 51.75984457560948, 49.717602252960205, 53.96458094460623, 55.216576848711284, 50.18722057342529, 50.16744947433472, 38.76431608200073, 31.01803697858538, 22.529075350080216, 18.151555640356882, 12.219733459608895, 14.450304968016487, 17.060499123164586, 12.956714987754822, 16.461715527943202, 12.271157945905413, 11.585722497531346, 8.179085867745535, 7.248915757451739, 3.88305332830974, 0.7756957507559231, 0.5967439732381276, 1.0222421011754443, 4.634144910744258, 15.704106535230364, 32.31637041909354, 44.12413215637207, 41.66183648790632, 43.49656738553728, 56.31685536248343, 60.70377772194998, 54.17069230760847, 38.49110943930489, 17.111726454326085, 4.533471592835017, 0.13182252645492554, 0.0960754764133266, 0.18642618001571723, 0.09345850255340338, 0.1449766063264438, 0.09910461279962744, 0.1427913164453847, 0.11653950225029673, 0.13790232235831873, 0.15864623710513115, 0.12941927755517618, 0.07767820717500788, 0.08568931730198008, 0.12505209046815122, 0.18695988851998532, 0.157344644090959, 0.11713719660682337, 0.10746182328356163, 0.11590866824345929, 0.18510556087962218, 0.16433606536260673, 0.12711661468659127, 0.056187859802906, 0.07337615266442299, 0.09909159171261958, 0.1310883651354483, 0.09548886253365449, 0.10784552805125713, 0.1388745137623378], [0.035514217535299916, 0.032244876359722445, 0.018158562315095748, 0.10004487234566893, 0.04028441371130092, 0.011404535849578679, 0.09170871680336339, 0.06559229748589651, 0.02505005064553448, 0.048330180014350584, 0.027221990350101675, 0.03985155586685453, 0.030420702815588032, 0.034662232002509494, 0.011921280130211796, 0.016294572336067046, 0.02253963053226471, 0.05830740981868335, 0.023509014497644136, 0.033659744009907754, 0.017707161804927245, 0.05953129021716969, 0.035058065583663325, 0.015842859699789966, 0.017288419185206294, 0.03219425764733127, 0.025118316357423152, 0.020447647697957497, 0.016025117598474026, 0.026023549925802008, 0.027421778200992515, 0.045273138875407834, 0.39122695262942997, 7.110865039484842, 21.379554952893937, 35.87560599190848, 43.18914781297956, 36.11693777356829, 26.89502109800066, 16.927156244005474, 19.675976514816284, 22.125386748995098, 20.874709265572683, 12.818348561014448, 5.383767817701612, 1.1117761539561408, 0.03381033807194658, 0.2984938243670123, 0.8841615819505283, 2.098255225590297, 3.991648026875087, 3.6403058511870245, 5.618840140955789, 2.7538145056792667, 1.3176596377577101, 3.3700645693710873, 6.825337937899998, 12.931494763919286, 20.680715560913086, 28.847602128982544, 40.3218103817531, 46.36397429874965, 52.076269013541086, 49.88298327582223, 50.18000486918858, 53.963226045881, 50.680045877184185, 49.01709181921822, 46.274912289210725, 46.45502001898629, 48.633474826812744, 48.163589000701904, 47.915423665727886, 45.95243944440569, 45.900254998888286, 45.71044063568115, 44.915747370038716, 46.50131934029715, 49.06597934450422, 47.7801387650626, 49.41601916721889, 50.60196896961757, 50.54125908442906, 49.026614325387136, 44.91162708827427, 41.215164593287874, 46.585548877716064, 45.94019671848842, 48.96934379850115, 32.88455588476998, 47.790859835488455, 48.746994495391846, 44.98453801018851, 43.50502681732178, 42.92105851854597, 41.756870474134175, 43.555026054382324, 42.22965022495815, 40.839023862566265, 37.0802047593253, 34.02094766071865, 35.29562248502459, 36.93701975686209, 37.001311438424246, 39.706790583474294, 43.5717191014971, 45.618575028010774, 45.97078963688442, 49.99317823137556, 49.779104232788086, 50.02407339641026, 48.61432211739676, 51.11118854795183, 49.427125862666536, 49.39203398568289, 51.37187801088606, 48.29374613080706, 43.32742738723755, 33.33463587079729, 26.86203452519008, 15.697908742087227, 14.133015479360308, 7.116046224321638, 2.4005817685808455, 5.869390879358564, 5.633893847465515, 4.976759714739663, 3.680911558015006, 6.854096531867981, 1.6691941916942596, 1.4371937321765083, 0.8477393420679229, 0.42302139369504793, 0.21562800662858145, 0.9261715305703027, 3.948872310774667, 11.955867801393781, 23.047695841108048, 29.761990274701798, 24.77433361325945, 23.097441468920024, 34.49431800842285, 40.01142045429775, 37.332966327667236, 30.59586443219866, 10.305982436452593, 1.0090400895902087, 0.011174320792114096, 0.03880778241104313, 0.06086079816200903, 0.03816264149333749, 0.019933484394901564, 0.017781709054751054, 0.04471616340535028, 0.019850888023419038, 0.017752421787008643, 0.038977005652018955, 0.03794374270364642, 0.012194812863266893, 0.050775172388447185, 0.047512491034077745, 0.013391658730272735, 0.042892447872353454, 0.06308325140603951, 0.0178018683301551, 0.018937064201704094, 0.02899720419996551, 0.04720192216336727, 0.0686276356822678, 0.03832391908924494, 0.008518203943302589, 0.02922348545065948, 0.025021002561386143, 0.05072182257260595, 0.04344966082966753, 0.006584605601217065, 0.0328996456893427, 0.03032071728791509, 0.04782204210226025, 0.019979058199429085, 0.01523284993267485, 0.032459167896636894, 0.03154443144532187, 0.03835394087114504, 0.014486663276329637, 0.04234605076323662, 0.06789407825895719, 0.06149106898478099, 0.08840275848550455, 0.03591988308887396, 0.04484231663601739, 0.039790993223765066, 0.033996070069926124, 0.04572951135092548, 0.020091208163648844, 0.01935666856089873, 0.01791213366336056, 0.02896845806390047, 0.009028089931234717, 0.04700092991281833, 0.013925484281831553, 0.019396897205816846, 0.07129681602652584, 0.029059554782829115, 0.014788195756929261, 0.025616595155692527, 0.022712558574442352, 0.020023870348398174, 0.5642672787819589, 8.114868010793414, 25.596255132130214, 41.92454787663051, 49.78559037617275, 42.35452325003487, 32.092068672180176, 23.92528111594064, 24.340753861836024, 24.634638343538555, 19.06813246863229, 14.7035277230399, 5.648181515080588, 1.258035408599036, 0.09525178918348891, 0.36647874489426613, 1.6596203339951379, 3.045013725757599, 5.424429978643145, 6.2757866723196845, 6.426321131842477, 3.1380598757948195, 4.026391625404358, 3.8616507053375244, 10.438990933554512, 16.89677177156721, 23.234235865729197, 31.810520717075892, 43.6099967275347, 47.53243548529488, 52.6039708001273, 51.606414454323904, 51.07532542092459, 51.748334884643555, 49.97110727855137, 49.321009499686106, 47.09530694144112, 46.738357135227744, 49.040812969207764, 47.85564831324986, 47.26187610626221, 45.58359432220459, 45.55275126865932, 46.688118185315815, 45.12930025373186, 46.68783678327288, 50.317308221544536, 48.90526403699602, 49.09891727992466, 52.422900744846885, 50.4776656968253, 50.8372106552124, 47.317621503557476, 42.05796718597412, 48.188362802777974, 47.339230401175364, 50.78199332101004, 34.8067124911717, 48.507462297167095, 48.721147196633474, 47.44954000200544, 45.02306924547468, 45.25766822269985, 44.00649915422712, 46.41451549530029, 45.25490631375994, 43.99699401855469, 38.71919100625174, 36.94542360305786, 36.56862626756941, 38.58646304266793, 37.93422174453735, 41.56879316057478, 45.30548572540283, 47.316686970846995, 48.406522342136924, 51.64720385415213, 49.80159902572632, 50.37466212681362, 49.08208179473877, 51.162289074489046, 50.48523923328945, 52.19934245518276, 52.6926645551409, 50.3038113457816, 45.912456035614014, 36.84112071990967, 27.989117452076503, 19.168191739491053, 13.30455310004098, 8.41681500843593, 5.1333768878664285, 7.767974853515625, 8.83633508001055, 7.822646754128592, 5.398673440728869, 6.184301044259753, 4.093626303332193, 2.688786097935268, 2.0878489954130988, 0.25806849928838865, 0.1614091909889664, 1.0284923315048218, 4.684166295187814, 14.57219808442252, 30.213550227028982, 34.964909076690674, 29.296551295689174, 28.53959369659424, 40.098745414188926, 49.17842551640102, 42.471527440207346, 35.28808716365269, 11.596751025744847, 1.7346313489334924, 0.01358150943581547, 0.04342913514535342, 0.08312676873590265, 0.011500900544758354, 0.03479448865566935, 0.017444835077705126, 0.0343430355590369, 0.014140434845882868, 0.01404957561421075, 0.01724965447959091, 0.06240152048745325, 0.03829926112666726, 0.023896497009055953, 0.07480569024171148, 0.017074943586651768, 0.035079486934202056, 0.03680393618664571, 0.033426724906478605, 0.014723354950547218, 0.043444995901414325, 0.03881294945521014, 0.026689330182437385, 0.06219766142645052, 0.03535426647535392, 0.07332513361637082, 0.016126992846173898, 0.051513333671859333, 0.0315082180313766, 0.04121250712445804, 0.11864334078771727, 0.10836192034184933, 0.10237811000219413, 0.18103394364672049, 0.07894509312297616, 0.09120460599660873, 0.17465993495924131, 0.24485443692122186, 0.13615372404456139, 0.14078046434691974, 0.11687536351382732, 0.11152564414909907, 0.13941439693527563, 0.12466114573180676, 0.13404597714543343, 0.16111227763550623, 0.13635329476424626, 0.15432281552680902, 0.11979222271059241, 0.12540244523968014, 0.08863802693252053, 0.11636055899517876, 0.07984739542007446, 0.15825597090380533, 0.1043542686051556, 0.13399721761899336, 0.12012526126844542, 0.1459886141653572, 0.08584320904420954, 0.11804320370512349, 0.08615483303687402, 0.1284076361251729, 0.7492843994072506, 10.10530890737261, 29.32997907911028, 48.56321464266096, 57.52798196247646, 49.43829509190151, 39.66162034443447, 27.18724843433925, 28.889282635280065, 30.87218734196254, 28.898280552455358, 17.298593044281006, 7.121878368513925, 2.1876609538282668, 0.5131114923528263, 1.0952395498752594, 3.9959524359021867, 5.343256345817021, 9.657437579972402, 11.539295503071376, 12.91005175454276, 7.849650059427534, 5.606322526931763, 5.990603506565094, 10.62677902834756, 16.47618862560817, 22.904571635382517, 32.43364558901106, 44.42794908796038, 49.02472788946969, 52.978933811187744, 51.2147410256522, 50.80005168914795, 52.80943250656128, 51.33073077883039, 51.14010347638811, 47.917647089277, 47.262421539851594, 50.15687779017857, 49.545516218457905, 48.19990028653826, 46.916456835610525, 46.25214304242815, 47.41104698181152, 46.32444599696568, 46.99620131083897, 51.64477545874459, 48.2456750188555, 49.86296898978097, 52.364633151463096, 52.83727741241455, 50.77466991969517, 48.07955401284354, 45.27315923145839, 50.23561825071062, 49.08068520682198, 51.88845920562744, 38.919622216905864, 48.86007642745972, 50.42233371734619, 48.666291168757844, 47.91532986504691, 47.49702051707676, 45.07545518875122, 48.405862263270784, 47.57589646748134, 44.86732884815761, 40.32011154719761, 38.25198023659842, 39.93671342304775, 40.98806619644165, 40.131238664899556, 43.24675185339791, 47.4584059034075, 49.68509857995169, 51.473054204668315, 53.47883585521153, 51.107391357421875, 51.94447905676705, 51.27281754357474, 51.82314961297171, 50.7758024760655, 52.062931946345735, 54.181621823992046, 53.05018411363874, 48.27144588742937, 38.00342927660261, 30.031774929591588, 19.24968716076442, 16.528628417423793, 10.325404388563973, 7.170230882508414, 11.591856019837515, 14.482176354953221, 12.425423588071551, 11.694817900657654, 14.70006057194301, 7.44713830947876, 7.847509145736694, 3.2601399421691895, 1.4929533515657698, 0.6038643025926181, 1.635618867618697, 5.972005350249154, 17.43287914139884, 30.791591712406703, 39.0598646572658, 35.948242459978374, 33.62170764378139, 46.45808070046561, 54.590321813310894, 50.090407848358154, 40.10710062299456, 13.760284577097211, 1.8349499830177851, 0.0872164892831019, 0.12218241659658295, 0.16256948587085518, 0.11272745858877897, 0.08470349412943635, 0.11727697482066494, 0.1052846893934267, 0.0996056023452963, 0.10506926809570619, 0.20152860533978256, 0.09918484956558261, 0.11761945858597755, 0.0848933889397553, 0.14451508037745953, 0.11322764746312584, 0.13578704372048378, 0.1208261608013085, 0.13662791145699366, 0.08935129615877356, 0.17765512423855917, 0.10478799497442585, 0.2097154153244836, 0.16618675605526992, 0.1532133293471166, 0.1343386157282761, 0.10952326695301703, 0.08795475573944193, 0.12219756149819919, 0.12458909888352666], [0.0971352124054517, 0.023406028148851225, 0.039343041367828846, 0.028296893296231116, 0.046397013390170674, 0.013092354389040597, 0.00399398392099621, 0.056990095148129125, 0.016286641958036592, 0.03677609250215547, 0.036734172608703375, 0.035926193464547396, 0.008266508163485144, 0.04059995285102299, 0.06095272608633552, 0.030167215703321353, 0.018652196541162472, 0.0069246627556692275, 0.04131333064287901, 0.06090404798409768, 0.04965937244040625, 0.03574841728966151, 0.02593128103762865, 0.016586447567013756, 0.03502686654350587, 0.025625668865229403, 0.022884692730648176, 0.030208385815577846, 0.046103903225490024, 0.02189858118072152, 0.0486813931326781, 0.10608318261802197, 0.13210580125451088, 3.615868602480207, 19.065438304628643, 33.94608082090105, 45.261583532605854, 35.9957994052342, 29.352449553353445, 19.857062203543528, 23.08872147968837, 25.51339612688337, 22.336104767663137, 18.308854171207972, 7.443745851516724, 1.354866046990667, 0.36227497618113247, 0.24953041172453336, 1.1671091105256761, 2.3940815116677965, 4.832714004176004, 1.955575704574585, 3.919574362891061, 1.8267867181982314, 1.738327790583883, 1.7907649768250329, 5.895057959215982, 11.526417016983032, 17.777596643992833, 27.64573574066162, 35.42316361836025, 43.55991063799177, 45.77095944540841, 51.60533053534371, 56.84042297090803, 54.84075920922415, 51.0239817074367, 47.466976506369456, 49.11044086728777, 49.89918647493635, 48.847375120435444, 47.181714739118306, 44.761445249829976, 46.341260637555806, 47.759363651275635, 49.648297446114675, 49.68622766222273, 47.32204055786133, 49.63910845347813, 48.355279377528596, 50.61771706172398, 47.424064431871685, 48.384409700121196, 46.61945261274065, 43.498102937425884, 42.07142237254551, 45.829268727983745, 46.160141944885254, 47.05776235035488, 31.642711298806326, 49.42068140847342, 47.944432394845144, 44.052398954119, 44.32784291676113, 39.92650651931763, 38.2333972794669, 37.418099130902974, 37.77334662846157, 37.1612138066973, 36.58334255218506, 34.58456815992083, 35.82597153527396, 38.81944308962141, 41.18582929883684, 43.386320318494526, 44.99394934517996, 46.8531413759504, 48.507771492004395, 50.19944592884609, 48.579647132328574, 50.04552943365914, 48.42389631271362, 50.21969297954014, 52.972176688058035, 50.652638707842144, 51.7139447757176, 48.65933949606759, 40.23746967315674, 33.440825189862935, 22.14497024672372, 15.062125989368983, 8.442988004003253, 6.749739800180707, 3.330720829112189, 6.985703664166587, 4.486830072743552, 4.688913217612675, 3.2774114268166676, 5.361344678061349, 2.743994312626975, 0.9228371552058628, 1.867194618497576, 0.1418908733342375, 0.3288329435246331, 0.9781430789402553, 4.549303931849344, 12.239390781947545, 21.729280369622366, 28.41612594468253, 25.335920027324132, 23.581194162368774, 39.42109455381121, 47.206467696598594, 39.86359058107649, 25.554545095988683, 8.466279234204974, 0.6388209611177444, 0.04616619613287704, 0.03157615974279387, 0.030847162074808563, 0.0653416398646576, 0.018427542078175714, 0.01443543388242168, 0.037788778876087496, 0.034000545008374114, 0.03233658715284296, 0.021269482527194277, 0.10223687293806247, 0.03309561338807855, 0.02234426503335791, 0.021066639572381973, 0.0739089519317661, 0.04941815663395183, 0.03969150302665574, 0.032086479144969156, 0.0248810072163386, 0.041456450641687424, 0.0405424130814416, 0.05645741123173918, 0.07376640529504844, 0.039615985471755266, 0.002405389889775376, 0.02089477513384606, 0.03873671943854008, 0.05203462837796126, 0.01402130869350263, 0.081588869116136, 0.05199224368802138, 0.02751764502110226, 0.032305167588804445, 0.038964717382831235, 0.021842907382441417, 0.026559307605826428, 0.029869125091603825, 0.06736943498253822, 0.007176977698691189, 0.0533083607442677, 0.011718252274606909, 0.04031377052888274, 0.03209402445437653, 0.0631500260372247, 0.024653555492737463, 0.06934179378939526, 0.04784260171332529, 0.10116981555308614, 0.024209632438474467, 0.058932259146656306, 0.04642147457759295, 0.03439586968826396, 0.03919793326141579, 0.08741478435695171, 0.05346514304567661, 0.04192542690517647, 0.0339772067964077, 0.07223316721085991, 0.05705589947423764, 0.006566883538783128, 0.03661683015525341, 0.1787561151598181, 5.2576315232685635, 22.971906627927506, 40.8227025440761, 50.548863887786865, 41.83054222379412, 35.06698506219046, 22.829018660954066, 26.41674358504159, 29.36681842803955, 25.411478212901525, 19.490690640040807, 8.470997929573059, 1.3606723525694437, 0.09054291221712317, 0.2987738421985081, 1.8317813873291016, 1.5500065301145827, 4.511073640414646, 5.963838177067893, 4.728580049106053, 4.824257177965982, 4.8599318351064404, 4.585243489061083, 8.394600749015808, 14.140727111271449, 22.60609265736171, 30.18132448196411, 36.66480670656477, 45.393769536699565, 48.14723988941738, 50.92177718026297, 52.9765054157802, 53.11793599809919, 51.49439559664045, 49.46567446844918, 48.83924920218331, 50.55705581392561, 50.601788316454204, 48.86150080817086, 46.91690846851894, 47.14241920198713, 47.30508000510079, 50.71826791763306, 49.51225519180298, 48.822566577366416, 49.927573340279714, 49.43841321127755, 51.12204163415091, 49.62788711275373, 49.767097745622905, 49.419288294655935, 44.808342116219656, 43.56639330727713, 46.9668173789978, 49.00409173965454, 48.169137137276785, 34.639076777866904, 50.56678329195295, 50.34917613438198, 46.660009247916086, 46.33821732657296, 42.576347964150564, 40.58867679323469, 40.464005265917095, 40.276209354400635, 38.40789433888027, 38.11298499788557, 37.74570322036743, 38.02168566840035, 39.049167905535015, 41.95559590203421, 45.4950395311628, 45.487813404628206, 47.079291343688965, 50.7275333404541, 51.25875786372593, 49.41914585658482, 50.00031403132847, 49.29883084978376, 50.59135907036917, 52.59607417242867, 51.90842832837786, 53.085661615644185, 50.571622712271555, 43.75893483843122, 34.57423618861607, 25.600606441497803, 15.738072804042272, 9.965305311339241, 7.850542902946472, 4.264807334968022, 6.93542389358793, 7.368839928082057, 6.869122879845755, 4.865430900028773, 6.020820353712354, 2.948434199605669, 2.7187806027276173, 0.1779273660587413, 0.38715457543730736, 0.22399461482252392, 1.2502650426966804, 4.645791394369943, 13.92653238773346, 24.32775378227234, 31.447161197662354, 28.135628904615128, 26.26397701672145, 44.2495436668396, 52.72105489458357, 47.13126386914934, 30.895074708121165, 11.001404183251516, 0.8335187137126923, 0.03217750122504575, 0.017204930540174246, 0.019317942871046916, 0.06986201301749263, 0.020632607862353325, 0.06520547145711524, 0.07466421569032328, 0.030902700166084936, 0.05174446305526154, 0.032271848126713715, 0.050448464562318156, 0.03472223824688366, 0.01781017699145845, 0.07433442731520959, 0.08194957833204951, 0.03067159453140838, 0.057092893203454356, 0.019782016719026223, 0.0177766675395625, 0.03828625021768468, 0.01619503803418151, 0.04192615633032151, 0.01095987149580781, 0.038231824923838885, 0.013633186662835734, 0.05601163747321282, 0.024305105708273392, 0.053611017896660736, 0.010348662418047232, 0.1624659685684102, 0.15789078335676873, 0.08692554703780583, 0.0812497508845159, 0.11484826728701591, 0.1633803080767393, 0.09226307991359915, 0.14578806635524544, 0.12456552657697882, 0.12768943394933427, 0.1255914308130741, 0.11343717229153429, 0.13360733139727796, 0.17760403055165494, 0.15370699071458407, 0.13972231612673827, 0.1301902019019638, 0.17400664144328662, 0.1803578920662403, 0.10698959683733326, 0.14515510174844945, 0.1302510393517358, 0.17156946579260485, 0.1369582630161728, 0.08539402564721447, 0.12145877256989479, 0.10942673177591392, 0.11055499301957232, 0.14767906202801637, 0.06309412153703825, 0.19660865648516587, 0.14253846715603555, 0.3730117886194161, 5.588760954993112, 24.71547368594578, 46.285021918160574, 57.389160428728374, 49.25723545891898, 40.852211543491904, 30.684658936091832, 33.7721118245806, 35.20128331865583, 30.017079489571707, 22.476420164108276, 9.986130799565997, 2.1645573249885013, 0.7198745203869683, 0.4462808684578964, 3.0432970864432196, 6.482719659805298, 11.803154213087899, 9.271878566060748, 10.083798153059822, 7.445748669760568, 5.894331003938403, 4.123418007578168, 8.423374107905797, 16.75673082896641, 23.042901584080287, 30.995305946895055, 37.25051552908761, 46.1205997467041, 47.657464844839915, 51.71206528799874, 56.566757747105186, 55.1952736718314, 52.77099854605538, 49.21459436416626, 50.76691573006766, 52.565463883536204, 52.35384954724993, 49.16415044239589, 48.97951248713902, 48.95560720988682, 49.60269641876221, 51.058031354631694, 50.468428066798616, 48.31724841254098, 51.879294531685964, 50.66718476159232, 53.52942221505301, 50.899640219552175, 51.54473182133266, 51.034157344273154, 46.57152393886021, 45.09833560671125, 48.64596421377999, 50.842237676892964, 48.61565269742693, 37.20747838701521, 51.84746135984148, 51.49495840072632, 48.681643213544575, 48.84069095339094, 44.123253209250315, 42.75729295185634, 42.092590059552876, 41.45270265851702, 40.20774875368391, 40.092398234776084, 39.313817841666086, 40.298367159707205, 41.49369355610439, 44.31767422812325, 48.99447890690395, 48.02892943790981, 50.76107576915196, 52.18298292160034, 51.75666924885341, 49.08223812920706, 51.759000369480674, 52.10517699377877, 50.46503734588623, 53.44083268301827, 53.095402990068706, 53.40258979797363, 51.82409456798008, 44.20415455954415, 37.959836278642925, 25.698741061346873, 18.551387991224015, 11.2020377601896, 9.887373447418213, 7.405099970953805, 12.330474717276436, 11.612615500177656, 11.982085960251943, 9.641543575695582, 11.678098797798157, 9.110080208097186, 4.543645058359418, 3.557073597397123, 0.7440406807831356, 0.6124946709190096, 1.9033843108585902, 6.842646334852491, 17.194088663373673, 30.57598216193063, 39.49961614608765, 36.55523361478533, 35.88259935379028, 52.655793939317974, 61.809764180864605, 52.021489415849956, 34.44123377118792, 12.62241804599762, 1.1395064145326614, 0.1270803130630936, 0.1468694204730647, 0.09235590350415025, 0.1413320726049798, 0.14964788566742623, 0.12087029271892138, 0.12867268547415733, 0.1284887617720025, 0.23711251520684787, 0.11976958678237029, 0.17198083443301065, 0.16705951493765625, 0.0925076442903706, 0.12331220454403333, 0.24665157763021334, 0.10465259331145457, 0.21625063036169323, 0.10043520640049662, 0.06670510170183011, 0.21017977754984582, 0.29331035965255325, 0.14246035420468875, 0.10231675686580793, 0.1040705256164074, 0.09277267328330449, 0.13746618718973228, 0.15086897728698595, 0.16619559058121272, 0.10938154812902212], [0.043261604849249125, 0.022417080322546617, 0.022677183151245117, 0.012476806079835763, 0.10863530210086278, 0.05131156110603895, 0.0344196964454438, 0.04978437555421676, 0.04845014161297253, 0.013036206464416214, 0.0310917841270566, 0.033245355888668976, 0.013834278997299927, 0.010421767780956413, 0.0286993035780532, 0.021265633537300994, 0.03583360057590263, 0.05257217060508473, 0.03784855441855533, 0.03897428133391908, 0.026084555312991142, 0.0206777287447559, 0.03773151730586376, 0.02411998948082328, 0.024603231943079402, 0.032543201066021404, 0.06036140317363398, 0.08275526402784245, 0.04861450993588992, 0.027637058702696646, 0.022656689697344388, 0.01209567635253604, 0.08925054727920465, 1.8716082445212772, 13.167418241500854, 30.729870864323207, 37.35910545076643, 38.55303873334612, 29.537243843078613, 26.77956461906433, 23.081611735480173, 15.143188885280065, 23.41362271990095, 19.867764166423253, 5.786440679005214, 2.21375686781747, 0.2849243996398789, 0.39798768556543757, 1.624330107654844, 0.6364026080284799, 3.317494933094297, 5.671836222921099, 3.1632271196160997, 3.1025241826261793, 5.1384013039725165, 2.0241036159651618, 4.683572658470698, 7.2740864753723145, 13.694340092795235, 21.822047506059917, 32.744261332920615, 37.30010134833199, 50.520549978528706, 60.18321173531668, 60.11622415270124, 51.68938289369856, 47.96965435573033, 50.28869901384626, 50.46235534123012, 50.15477596010481, 45.48607982907976, 47.40151752744402, 48.83401720864432, 47.64209542955671, 46.93624530519758, 47.848818234034944, 47.28584739140102, 46.59139231273106, 47.5660856110709, 46.65937696184431, 46.743460587092805, 45.692760944366455, 45.21229648590088, 43.65206112180437, 40.824720995766775, 43.57675307137625, 47.15499891553606, 48.31700522559029, 46.87790128162929, 32.195106983184814, 47.92292424610683, 47.35346031188965, 46.7430853843689, 42.97438941683088, 43.89900357382638, 41.468502862112864, 41.931683676583425, 38.93105895178658, 39.1461751801627, 38.39911181586129, 38.242860725947786, 41.677643639700754, 45.0103679384504, 45.68241160256522, 46.888142926352366, 48.68553420475551, 47.43555327824184, 49.846821376255576, 49.07803099496024, 49.32919795172555, 46.64054386956351, 46.70531497682844, 48.655754225594656, 53.95925167628697, 56.15161330359322, 50.62968185969761, 44.92358146395002, 37.49064179829189, 29.20135055269514, 20.63004755973816, 12.594653912952968, 6.492049787725721, 6.112457105091639, 2.992482738835471, 4.12373024225235, 7.6579084396362305, 7.08457088470459, 1.9514717076505934, 3.637786477804184, 1.7984165719577243, 1.5139236663069044, 0.4045587543930326, 0.4834246624793325, 0.1650034859776497, 1.8348920089857919, 5.859105808394296, 16.57035756111145, 26.833870002201625, 28.43280335835048, 33.96834979738508, 39.8389105796814, 51.79660749435425, 45.70815120424543, 35.9762784412929, 21.00979093142918, 4.919614689690726, 0.7228119799068996, 0.14602516006146157, 0.04877782652952841, 0.009080485557205975, 0.032418052067181895, 0.02689338262592043, 0.021363778538735848, 0.0159698322614921, 0.07052665842430932, 0.018900998369125382, 0.008070805093406566, 0.024438198655843735, 0.03856700086700065, 0.04924776292006884, 0.028864428467516388, 0.04446213007239359, 0.05872010838772569, 0.045484648418745825, 0.012039161170832813, 0.00742090679705143, 0.02164838496329529, 0.030146371107548475, 0.07015912314610821, 0.041656516691935916, 0.035009635146707296, 0.08908542578241654, 0.03200536367616483, 0.013788669569683927, 0.018999618345073292, 0.07485550149743046, 0.05154619173013738, 0.05189025308936834, 0.010239487829884248, 0.04598094250208565, 0.02098103559442929, 0.024253260543836013, 0.030285704880952835, 0.03097192430868745, 0.0676219721457788, 0.12692471141261713, 0.03124855285776513, 0.0177702418129359, 0.07421854710472481, 0.03214356090341296, 0.02218810359149107, 0.013759969234732645, 0.10074655897915363, 0.015968398856265203, 0.03382157461185541, 0.05015056733308094, 0.02315808636402445, 0.042924434013132534, 0.0952801044498171, 0.0288726557046175, 0.03662290643634541, 0.049119828534977775, 0.07062766514718533, 0.10512235667556524, 0.022401472320780158, 0.055001682202730856, 0.05975628564400332, 0.07345639621572835, 0.04752843321434089, 2.4561775624752045, 17.019605500357493, 36.52015216009957, 45.596264362335205, 44.645472867148264, 36.28016138076782, 29.65648535319737, 27.854372773851665, 23.385803869792394, 25.376381124768937, 22.37713040624346, 8.106658714158193, 2.2667416589600697, 0.44161349747862133, 0.31339363913450924, 0.42148293767656597, 2.4207406640052795, 3.286890072481973, 5.19118937424251, 6.056427700178964, 10.51873801435743, 6.9769315634455, 4.054628235953195, 7.015073265348162, 9.184809820992605, 15.94088898386274, 25.46157819884164, 36.45914350237165, 38.70453725542341, 51.94971105030605, 55.7211446080889, 60.68690054757254, 53.64321286337716, 49.473904609680176, 51.227150508335654, 51.59614501680647, 51.13381535666329, 49.594865798950195, 49.41672788347517, 49.84926019396101, 49.849215030670166, 49.38128512246268, 50.51029096330915, 50.557472705841064, 49.214076723371235, 49.66993066242763, 48.55969190597534, 48.61387048448835, 48.58798497063773, 47.20284421103341, 45.56672757012503, 43.564791747501914, 45.87199667521885, 49.292271750313894, 49.96576411383492, 47.5225099836077, 35.201585565294536, 49.58678504398891, 48.37343154634748, 48.12625632967268, 43.90152924401419, 44.80297115870884, 42.870176860264365, 43.63186270850045, 40.96945544651577, 40.554783480507986, 39.08244282858712, 38.656518254961284, 41.678004946027485, 45.986134733472554, 46.82064812523978, 48.44603327342442, 49.364536489759175, 49.44059841973441, 51.55106163024902, 49.467018944876536, 48.949273926871165, 49.16924694606236, 48.09189748764038, 51.14418206896101, 54.33288410731724, 53.011246408735005, 50.05842876434326, 48.875192233494346, 41.064729145595, 33.34996359688895, 22.53323037283761, 15.865737267902919, 9.846281800951276, 7.315449970109122, 4.5865384595734735, 6.778511422021048, 7.7055235760552545, 8.14041827406202, 6.307699748447963, 6.115906885692051, 4.7232633743967325, 2.5477422262941087, 0.6553854122757912, 0.1321495667632137, 0.3028270847031048, 1.8479674330779483, 7.104929975100926, 19.326136452811106, 25.990087713514054, 31.685136999402726, 36.019822801862446, 39.85679176875523, 55.355401856558665, 53.93999126979283, 43.01452916009085, 24.87166224207197, 6.527525118419102, 0.8304089062980243, 0.046711209030555825, 0.041147103134010515, 0.025232708879879544, 0.024851207654657106, 0.05039483993979437, 0.04455259236107979, 0.042702715910438976, 0.04677581913503153, 0.04693290338452373, 0.020864159633804644, 0.011434527097402938, 0.022142682457342744, 0.06466395301478249, 0.05690374138898083, 0.037920102543596707, 0.07333626159067665, 0.0604666235989758, 0.054156488805477104, 0.0518225488652076, 0.01367523378160383, 0.017815154045820236, 0.0533591151636626, 0.00464501664308565, 0.02142568807383733, 0.04536496501948152, 0.04828587507030793, 0.041814615351281, 0.02779084357566067, 0.053839582417692454, 0.15846527181565762, 0.09886843511568648, 0.1567357810480254, 0.10409785700695855, 0.21265712247363158, 0.15585748531988688, 0.10170693030314785, 0.17687852733901568, 0.1616093452487673, 0.22005060288522924, 0.10146366871361222, 0.16535736913127558, 0.17597040321145738, 0.10852651936667305, 0.13512838977788175, 0.12298014307660715, 0.15487206248300417, 0.1252663175442389, 0.12486344416226659, 0.17931031542164938, 0.06151017653090613, 0.1145594556416784, 0.20018966575818403, 0.09973348584026098, 0.13661947048136167, 0.1110393652426345, 0.16411958555025713, 0.15032602713576385, 0.14089154052947248, 0.10936102244470801, 0.23698790903602326, 0.12656160018273763, 0.18497946193175657, 3.1623247223240987, 18.14827609062195, 41.19753701346261, 53.48792062486921, 51.95706919261387, 43.31454195295061, 38.43182740892683, 34.136513573782786, 25.35987741606576, 34.82066099984305, 25.704250982829503, 9.317400557654244, 3.5190936582429067, 0.9834068822009223, 0.8426043518951961, 3.474912017583847, 4.232652374676295, 10.111504094941274, 11.137899807521276, 10.24951355797904, 10.744393791471209, 13.001331107957022, 6.821466488497598, 7.776695711272104, 9.735305173056465, 17.896216290337698, 24.263524634497507, 36.394521781376426, 39.602807317461284, 52.28333575384957, 59.42482280731201, 60.930851800101145, 53.75722585405622, 50.046741894313264, 52.289592606680735, 52.49884802954537, 52.6597717830113, 50.10079540525164, 52.55327326910836, 52.91767154421125, 51.570005893707275, 50.85306644439697, 52.704021385737825, 50.29091201509748, 50.25119958605085, 50.694289684295654, 50.71704503468105, 50.64878593172346, 49.60461412157331, 49.07704087666103, 46.79114954812186, 44.71118198122297, 47.18603304454258, 51.81469712938581, 50.66930396216256, 49.32635266440255, 38.59399141584124, 49.908837522779194, 50.00587606430054, 49.894378321511404, 48.87178066798619, 46.95263263157436, 45.71104165485927, 46.49871723992484, 43.548765727451865, 42.318090370723176, 42.47324364525931, 42.1711950302124, 46.20757382256644, 49.26923847198486, 49.7570332799639, 50.372101715632844, 53.175922189440044, 51.81483956745693, 53.30629471370152, 49.430839674813406, 49.674975054604666, 47.804665906088694, 49.482332774571006, 51.0405079977853, 54.943064485277446, 53.804313795907156, 52.717889990125386, 48.08075605119978, 42.884292125701904, 32.860105173928396, 23.14897973196847, 14.208963632583618, 9.536149825368609, 10.111961807523455, 6.414543500968388, 9.562366247177124, 16.12773472922189, 11.151296802929469, 11.49983320917402, 12.13883992603847, 7.8877913270677835, 5.221550830772944, 1.133122431380408, 1.3460662620408195, 0.5832732075027057, 2.829976967402867, 8.844832726887294, 22.269983972821915, 35.99082449504307, 39.27095787865775, 46.253268650599885, 51.85262734549386, 64.8427848815918, 59.126599175589426, 49.707655906677246, 29.05397752353123, 7.539224522454398, 1.0063850092036384, 0.1574201921799353, 0.14351957451019967, 0.11931709891983441, 0.07116900038506303, 0.10561107152274676, 0.1662211577807154, 0.07911905593105725, 0.1608769888324397, 0.08282450852649552, 0.10798869215484176, 0.09647192406867232, 0.11207322869449854, 0.1493815199605056, 0.11307558776544673, 0.11463557370007038, 0.16768956184387207, 0.11461229994893074, 0.05397141159379056, 0.11908365573201861, 0.10928896881107773, 0.08554559679968016, 0.2142336443066597, 0.11354770564607211, 0.14265289530158043, 0.16409591824880668, 0.1355697496661118, 0.1661300848105124, 0.11791002085166317, 0.140856338132705], [0.020144327277583734, 0.06253447942435741, 0.043875421197818856, 0.04952919549707856, 0.07743198717279093, 0.08356093615293503, 0.045412194449454546, 0.036515853966453245, 0.009080050446625267, 0.0336164466903678, 0.03178970149851271, 0.029458770861050913, 0.011924674501642585, 0.02937056470130171, 0.013482675721336688, 0.0190359606806721, 0.02939824553738747, 0.12225781540785517, 0.027426010563171337, 0.03188949364370533, 0.05417352342712028, 0.027260023934234465, 0.020230265434033105, 0.034856394798095734, 0.06266724158610616, 0.032290986206914694, 0.017209983929725628, 0.049609459404434474, 0.046188614929893186, 0.0630311399166073, 0.03536452592483588, 0.052520045544952154, 0.04484463044043098, 0.6918069464819772, 7.31149731363569, 23.816435847963604, 34.97737761906215, 37.16791187013899, 33.94275263377598, 26.526815210069927, 19.35295649937221, 19.840318781988962, 28.13945041384016, 17.82727105276925, 9.630315286772591, 4.782164556639535, 0.5178171598485538, 0.286201755383185, 0.3327303129647459, 1.9962910626615797, 1.3075608653681619, 3.5959930632795607, 2.447622592960085, 9.906369822365896, 3.0680011894021715, 2.89914476445743, 5.538542415414538, 6.222982968602862, 11.42466846534184, 18.84541491099766, 26.968163047518047, 35.367720467703684, 49.512150968824116, 49.76840053285871, 48.9889794077192, 43.31511170523507, 48.31480612073626, 52.29976824351719, 49.26501744134085, 46.541969776153564, 44.85863665172032, 45.97213063921247, 46.5527776990618, 45.10279287610735, 46.246167591639924, 44.82164791652134, 46.50478996549334, 44.52003008978707, 44.7914718900408, 43.74437836238316, 43.58266598837716, 42.36862809317452, 42.434385844639365, 39.89869288035801, 42.62093802860805, 44.58833088193621, 46.83048677444458, 48.37151384353638, 48.4677985055106, 30.39620099748884, 48.35799959727696, 47.476089068821494, 45.459447383880615, 46.342358452933176, 44.91931527001517, 45.11900302342006, 44.115902015141074, 45.53110763004848, 42.6103698185512, 43.77409928185599, 45.30711855207171, 45.599648135049, 44.909504413604736, 45.10593693596976, 45.82134778159005, 48.88359260559082, 50.0107432774135, 47.9563798223223, 47.88110998698643, 49.26945039204189, 48.264612334115164, 48.525419916425435, 47.231502056121826, 42.3391329901559, 51.46502903529576, 56.533350808279856, 49.66938870293753, 37.19466938291277, 23.58777063233512, 17.39251184463501, 11.340375525610787, 6.791062039988382, 3.8270408596311296, 2.992489687034062, 5.448053419589996, 4.616271538393838, 7.266410452978952, 3.3692066839763095, 4.5839667575699945, 1.530926559652601, 2.4608395865985324, 0.19677518254944257, 0.19708106613584928, 0.4961023564849581, 1.6349938554423196, 5.471649067742484, 15.270360027040754, 24.606565884181432, 26.234553132738384, 31.878091948372976, 48.98632172175816, 48.641468729291645, 41.99574606759207, 35.60555035727364, 17.761966671262467, 3.243358305522374, 0.27553244360855644, 0.019938960172502056, 0.07181343223367419, 0.012837910542397626, 0.05697098760200398, 0.07248613863651242, 0.046975919112030945, 0.04492753724168454, 0.031125914438494613, 0.02589374448039702, 0.07610402628779411, 0.04928562517410942, 0.07536185146974665, 0.009691486833617091, 0.049732952777828486, 0.007977381847532732, 0.015422514041087456, 0.05129547643342188, 0.016121708754716173, 0.031386553309857845, 0.03074100866381611, 0.08562422543764114, 0.02936389809474349, 0.046538352234555144, 0.03867237057004656, 0.06129039903836591, 0.09090369607188872, 0.09695005376956292, 0.02022774637277637, 0.06227038002439907, 0.0395259540528059, 0.03132662170433572, 0.04432207705186946, 0.04242444530661617, 0.03418092675773161, 0.08378582979951586, 0.042605566659143994, 0.027761732727023106, 0.028361801956115023, 0.05197993167010801, 0.037602334416338375, 0.05739488199885402, 0.036647123351160965, 0.033980565544750006, 0.025336297428501502, 0.011046922449687762, 0.05812778124319656, 0.04256177061636533, 0.06260230578482151, 0.055412351952067444, 0.006293220187736941, 0.050292218303573985, 0.062377921039504666, 0.05767913388886622, 0.04130421452490347, 0.038492087208266766, 0.029613965390516177, 0.06713674496859312, 0.037505561751978736, 0.014652385276609232, 0.02904663886874914, 0.0679576230634536, 0.02396597560229046, 1.1439946251256126, 9.0671238388334, 28.880659920828684, 41.91715499332973, 46.04940502984183, 39.28525032315935, 30.45457281385149, 24.75902325766427, 21.78215789794922, 30.61063630240304, 20.068469830921718, 9.314889652388436, 4.144021153450012, 0.6143887607114655, 0.0888969355395862, 0.3074678842510496, 1.7067675526653017, 2.9821783431938718, 5.214983480317252, 7.0069208570889066, 10.71072542667389, 5.402022038187299, 4.127312472888401, 6.013968127114432, 7.869101541382926, 16.478300877979823, 20.964268071310862, 29.456606524331228, 38.16536051886422, 51.596982274736675, 53.652155194963726, 53.46244158063616, 48.201331615448, 50.39374882834298, 53.04385430472237, 50.79858214514596, 47.9784368787493, 45.96259423664638, 48.44426843098232, 48.99065392357962, 47.415010929107666, 47.05878373554775, 47.85096870149885, 48.869713578905376, 45.98130226135254, 47.32294382367815, 47.20805883407593, 45.66557959147862, 45.06477928161621, 44.532898153577534, 41.163320609501426, 44.49025011062622, 45.36929798126221, 48.596996784210205, 50.21087571552822, 48.38462162017822, 32.906564303806846, 49.936672006334575, 48.604320185525076, 47.03725126811436, 48.024541650499614, 47.99750620978219, 47.31884091241019, 46.65849454062325, 45.91464124407087, 44.270728724343435, 46.72462749481201, 46.13946063177926, 47.77684531893049, 46.99699340547834, 47.31517573765346, 48.69460160391671, 51.06710570199149, 51.15672704151699, 48.36920356750488, 47.07109246935163, 49.74884482792446, 48.88451324190412, 51.010241644723074, 48.36460733413696, 46.710189138139995, 54.973351682935444, 56.02154997416905, 50.337187017713276, 39.91083485739571, 27.20291141101292, 22.303780010768346, 12.927120872906276, 7.169982484408787, 5.558447701590402, 3.8562979868480136, 6.169145286083221, 8.835871287754603, 9.804006355149404, 4.606834581920078, 3.8212391138076782, 4.312214025429316, 2.7150114221232275, 0.7868626458304269, 0.27720169403723305, 0.37863119851265636, 2.1898776463099887, 7.085101119109562, 18.47806191444397, 29.133728946958268, 29.862186772482737, 37.45562982559204, 56.701243604932515, 55.91788632529122, 47.85997356687273, 41.23170130593436, 20.93172444616045, 4.975701417241778, 0.4087744653224945, 0.030983757959412675, 0.0211000353696623, 0.09997158377830472, 0.015110698362280215, 0.06809643097221851, 0.03738259085054908, 0.05349277299163597, 0.027572382441056625, 0.034241594573748965, 0.03524329546572907, 0.03066359121086342, 0.059025985188782215, 0.035489858128130436, 0.01415553140187902, 0.04416423623583146, 0.04220633361754673, 0.026137531934572116, 0.04656653179387961, 0.027725322537922432, 0.022971071934859668, 0.08280284968870026, 0.02572851950701858, 0.02992887349267091, 0.05134902302441852, 0.01465062447823584, 0.04639920505828091, 0.03282689655731831, 0.009277957907345678, 0.008461832950290824, 0.13549266808799335, 0.14269280673137733, 0.11587938267205443, 0.13170010516686098, 0.14317147247493267, 0.20128256854202065, 0.10476900277925388, 0.12314561062625476, 0.12653804144689015, 0.2168003658631018, 0.11617343260773591, 0.1321344490029982, 0.1368371716567448, 0.1244380705590759, 0.14425350512777055, 0.09149512755019323, 0.17405291753155844, 0.1405190655163356, 0.12194467149674892, 0.10680574777403049, 0.13713054305740766, 0.0932332289272121, 0.13632376492023468, 0.13987936984215463, 0.10643223460231509, 0.130925964564085, 0.10889092659843819, 0.11355146473007542, 0.1377555959458862, 0.0682667771886502, 0.1447495820799044, 0.12984226271510124, 0.09628478411052908, 1.4576037398406436, 11.271329539162771, 32.954611097063335, 48.94492435455322, 52.898369448525564, 48.2923321723938, 39.410286630902974, 30.423027992248535, 30.083587646484375, 38.66724279948643, 25.492763451167516, 14.610136985778809, 6.581213848931449, 0.9184457851307732, 0.7299184128642082, 1.4230448114020484, 4.673023555959974, 8.092892595699855, 9.598241533551898, 12.702288457325526, 21.733669894082205, 8.985411286354065, 6.602932180677142, 10.637420194489614, 10.998386059488569, 17.07260114806039, 24.50242975779942, 31.06299877166748, 40.6197178704398, 54.98963131223406, 56.03719731739589, 54.43404293060303, 49.3581337247576, 50.58496672766549, 54.2069445337568, 52.36022104535784, 49.867693764822825, 49.26626811708723, 51.538857119424, 50.42446334021432, 49.36725670950753, 50.282216344560894, 49.13812596457345, 50.68019526345389, 47.97420195170811, 48.738854680742534, 49.03322901044573, 46.83573613848005, 45.9316851752145, 45.04884706224714, 43.41037845611572, 47.02165603637695, 47.15146228245327, 51.12994521004813, 52.57623706545149, 49.57010241917202, 36.38607972008841, 50.68445103509085, 49.7437344278608, 49.67880698612758, 50.712563446589876, 48.86063575744629, 50.37994623184204, 49.14513669695173, 48.6928437096732, 46.83564928599766, 49.12306921822684, 49.15009423664638, 49.66419839859009, 49.020284516470774, 48.75028794152396, 50.76689835957119, 52.70887470245361, 53.04544544219971, 49.024863379342214, 48.19791310174124, 48.7523307119097, 49.56686108452933, 51.84988975524902, 54.952719007219585, 50.13967057636806, 55.048496450696675, 60.33603736332485, 52.79810694285801, 41.774730818612234, 28.12586842264448, 22.641377346856252, 15.239831379481725, 9.270976168768746, 6.686702702726636, 7.369737982749939, 10.612691555704389, 13.155126009668622, 18.011893374579294, 11.324806349618093, 11.999795181410652, 7.269277887684958, 6.275789712156568, 2.187758445739746, 0.6517941164118903, 1.0662811951977866, 3.0833321724619185, 8.16532930306026, 22.17078106743949, 34.637002740587505, 38.46567208426339, 43.839808395930696, 62.76068769182478, 59.08110237121582, 54.52960497992379, 48.20396498271397, 23.729215111051285, 5.873674009527479, 0.42828310706785744, 0.14918540976941586, 0.1246637784476791, 0.18351462696279797, 0.10474154246704918, 0.12700234938945087, 0.1998798195272684, 0.2031152237738882, 0.10154813275273357, 0.10864870995283127, 0.13142839260399342, 0.07480978180787393, 0.12526103854179382, 0.17537984704332693, 0.11171969837908234, 0.10436113537954432, 0.09948048727320773, 0.14864274460290158, 0.17005175937499317, 0.09038903404559408, 0.07776955834456853, 0.17343739127474173, 0.15659514788006032, 0.19087335281074047, 0.10697304058287825, 0.09625370720667498, 0.17150220940155642, 0.25309008785656517, 0.10026155571852412, 0.08540271089545318], [0.03193541010841727, 0.013454710748711867, 0.02944815518068416, 0.014894452644512057, 0.027102812459426265, 0.06338780506380967, 0.020243919254945855, 0.03259163489565253, 0.04601121873461774, 0.062378979554133754, 0.038398998989058394, 0.054085381728197844, 0.014297514854531203, 0.006807774072512984, 0.027167168113269975, 0.041479429230093956, 0.03278595714696816, 0.064917324776096, 0.02162758107962353, 0.09198670581515346, 0.020028474208499705, 0.017255600142691816, 0.09214979170688561, 0.012662711104245057, 0.03677876593012895, 0.05306672424610172, 0.01732875469938985, 0.043194446845778396, 0.02779533208480903, 0.028925547509321144, 0.027420241319175278, 0.014399329034079398, 0.04110747329624636, 0.10565880646130868, 4.354935024465833, 18.82984573500497, 28.446757078170776, 37.051810945783345, 38.46231957844326, 32.584275586264475, 26.863900116511754, 24.699699538094656, 29.648686000279017, 22.251369748796733, 13.924764939716884, 5.97163188457489, 1.0345116427966525, 0.26073212921619415, 0.261080733367375, 1.2648477916206633, 2.117693462542125, 4.82324013539723, 5.554594056946891, 8.566973396709987, 5.927608532564981, 1.8899089310850417, 3.403078934976033, 3.115029203040259, 8.118235281535558, 13.678399188177925, 20.791223185403005, 28.497155836650304, 39.34774242128645, 39.648901666913716, 40.05138996669224, 47.08531890596662, 53.18432256153652, 50.00410427365984, 48.05149023873465, 45.1098244530814, 44.69395392281668, 43.790896551949636, 47.1005528313773, 45.34440605981009, 43.60926021848406, 42.851441042763845, 43.3793443271092, 41.8971962928772, 41.41116632734026, 39.15459987095424, 38.09999534061977, 38.784743785858154, 41.477566787174766, 41.37335423060826, 46.0369017464774, 46.84525169645037, 48.709495067596436, 47.998885427202495, 47.28129284722464, 30.1263016973223, 47.35171283994402, 48.431323937007356, 44.89000082015991, 47.438815457480295, 47.038078103746685, 44.77039452961513, 45.56405946186611, 46.58941902433123, 46.79167413711548, 45.23646926879883, 47.82292577198574, 47.430616583142964, 48.3274553162711, 48.052428245544434, 49.52762460708618, 48.82229559762137, 48.59151118142264, 47.82126515252249, 47.92303889138358, 49.04488461358206, 48.89391762869698, 45.4107300894601, 41.59690209797451, 44.02778148651123, 40.94995880126953, 46.26116875239781, 44.00043337685721, 34.97501523154122, 25.229275601250784, 17.31187799998692, 9.948090280805316, 5.2491330078669955, 4.03899131502424, 2.666551862444196, 4.8559748360088895, 8.356259720666067, 6.026217366967883, 3.9836884311267307, 2.1356169922011237, 3.961235761642456, 1.4285956621170044, 0.6335599262799535, 0.19454616787178175, 0.4672566386205809, 2.957044320447104, 10.90182694367, 21.209666286196025, 27.71779898234776, 37.48327670778547, 31.85418667112078, 44.089081968579976, 39.85313354219709, 42.22610664367676, 27.834266424179077, 13.43882703781128, 2.4964295625686646, 0.07442203975681748, 0.06472948592688356, 0.018597192796213285, 0.04555196587794593, 0.01784036331810057, 0.012106445551450764, 0.013355980510823429, 0.024756709778947488, 0.013493168417231312, 0.033328659632908444, 0.026708152743854692, 0.0683302812810455, 0.033256378690046925, 0.07265392677592379, 0.026653725753671358, 0.012621262792630919, 0.03847758012956806, 0.08943848790866987, 0.039809625795377154, 0.0704555343836546, 0.04881284911451595, 0.012993802266594554, 0.008380790424001004, 0.008472482557408512, 0.007884823733807673, 0.03057330534128206, 0.05841815351907696, 0.01980698511137494, 0.06657778817628111, 0.01806580488170896, 0.092863583405103, 0.021055894970361675, 0.02142534202097782, 0.02639527346140572, 0.03206240472250751, 0.0362677238881588, 0.038611947026635916, 0.013266626778723938, 0.08152022172829934, 0.058613666599350314, 0.00862603503212865, 0.0341246015658336, 0.02393945675742413, 0.017239289857181053, 0.029486977561776127, 0.08569788041391543, 0.04965496874813523, 0.09400306761796985, 0.08419773448258638, 0.056673205723719935, 0.016306053148582578, 0.05769262316503695, 0.026014097932992235, 0.08762287069112062, 0.031108323418136154, 0.08730912966919796, 0.0820153419460569, 0.06308562627860478, 0.047249989584088326, 0.04163465429363506, 0.05839509689914329, 0.030238041188567877, 0.04734224320522376, 0.22527302908045904, 5.8344926834106445, 23.6497711454119, 35.349592617579866, 42.99236788068499, 42.92522743770054, 35.988333565848215, 30.058285781315394, 24.529282808303833, 30.1439779145377, 23.499891553606304, 14.694899797439575, 6.626185195786612, 0.81116983294487, 0.2544424081487315, 0.1909426719482456, 0.9201556933777673, 1.8257405800478799, 3.934182950428554, 7.964318786348615, 9.92070916720799, 6.983194495950427, 6.060017313276019, 4.666655097688947, 4.8273621542113165, 11.286791018077306, 17.468474762780325, 25.010101624897548, 32.87399114881243, 42.99496303285871, 45.241843700408936, 46.95689187731062, 48.30919197627476, 52.97277423313686, 51.31991590772356, 49.66405248641968, 46.89854785374233, 47.10172012874058, 46.487999643598286, 48.3615779195513, 48.48339721134731, 46.650111539023264, 45.080124378204346, 45.00420488630022, 45.210628918239046, 44.44012928009033, 41.88725689479283, 41.990010329655235, 42.42495366505214, 43.591281754629954, 42.766787665230886, 48.034602642059326, 48.78772483553205, 49.380468709128245, 49.09663479668753, 47.845319816044395, 33.13867582593645, 47.239398683820454, 48.55401175362723, 47.49531126022339, 49.132567405700684, 48.2818786076137, 48.01821184158325, 47.87225450788225, 48.31778342383248, 49.35045249121529, 47.96332802091326, 48.5738662311009, 48.83728633608137, 49.92448139190674, 49.151202474321636, 50.6736604826791, 49.08724430629185, 49.457746573856895, 47.87609338760376, 48.36615330832345, 50.114264488220215, 49.40991864885603, 48.48138223375593, 46.40672656467983, 46.16282394954136, 44.91282217843192, 52.86084917613438, 46.591628551483154, 38.12040219988142, 26.954002618789673, 19.271129301616124, 11.676761269569397, 7.247962985719953, 5.788318429674421, 5.75134185382298, 9.292369672230311, 7.878438183239528, 7.353672010557992, 4.259053358009883, 5.454340236527579, 2.4871135481766293, 0.889463654586247, 0.7425312932048524, 0.10372047618563686, 0.6806795692869595, 3.182021345411028, 10.193256599562508, 21.62401863506862, 30.347997869764054, 37.782184737069265, 36.952184200286865, 50.64725732803345, 46.97072574070522, 49.3146345274789, 34.348190443856375, 16.498337745666504, 3.8037153226988654, 0.12664048666400568, 0.008142067385571343, 0.041222814071391306, 0.030207585144255842, 0.03924057240198765, 0.043459960991250615, 0.054092757403850555, 0.04449064889922738, 0.030125553653176342, 0.042689491262925525, 0.024967428828988756, 0.14179296073104652, 0.006696096962384347, 0.057228206656873226, 0.04404198118884649, 0.006409127963706851, 0.03440178990630167, 0.047643577214330435, 0.03944330509485943, 0.04683604251061167, 0.08687354411397662, 0.0021051915786561687, 0.04519224732315966, 0.03170444357341953, 0.007745238902446414, 0.007633119472302496, 0.017612339928746223, 0.009913802895295833, 0.03880275446655495, 0.01428458876242595, 0.14354002555566175, 0.11127978377044201, 0.08436497979398284, 0.11701200689588274, 0.09452336827026946, 0.10218452396137373, 0.10590812736856085, 0.12125989395592894, 0.09853410734129803, 0.17643332694258007, 0.11363760475069284, 0.15079523410115922, 0.1576901405517544, 0.07236001254724604, 0.1062498918867537, 0.11556021336998258, 0.18559456749686173, 0.2582277650279658, 0.1418275660169976, 0.13564946396010263, 0.0867118424336825, 0.1237116309681109, 0.17923848570457526, 0.13148464315703937, 0.15760221598403795, 0.13861132359930448, 0.22382080129214696, 0.1595286718968834, 0.07948197717113153, 0.09805770111935479, 0.11930154689720698, 0.09482300254915442, 0.13448740488716535, 0.4058997838624886, 6.41774879183088, 26.998069831303187, 41.38459294182913, 50.621281487601145, 50.86605262756348, 45.379414558410645, 37.49911860057286, 34.62620176587786, 41.38927950177874, 30.930104051317485, 19.0202020577022, 7.915535484041486, 1.7424805334636142, 0.9055109534944806, 0.6197901165911129, 5.315582973616464, 5.8656353780201504, 10.27710051195962, 11.630244817052569, 15.749400104795184, 15.2841591494424, 8.024510162217275, 7.609570690563746, 4.878289410046168, 13.409520404679434, 20.241695369992936, 28.51036262512207, 35.838634627205984, 46.2258232661656, 49.73315232140677, 50.451696804591585, 49.05149582454136, 53.4125326701573, 52.5809896332877, 51.53737367902483, 48.602930545806885, 49.25926085880825, 47.73621572766985, 50.07495158059256, 49.55669934409005, 49.1936594418117, 47.02980279922485, 47.67803151266915, 47.08139664786202, 46.21441432407924, 43.8771584374564, 43.100575651441304, 43.711756569998606, 45.17111798695156, 44.36592251913888, 49.12478542327881, 50.74621704646519, 52.10741778782436, 50.263591698237825, 48.41832038334438, 36.88722201756069, 49.530414308820454, 49.81063168389456, 49.12539686475481, 50.72110973085676, 50.79412487574986, 49.09348726272583, 48.843053340911865, 50.590410641261506, 54.22832761492048, 49.860808100019185, 51.35679694584438, 51.74984264373779, 52.66128649030413, 51.787428924015586, 52.24098300933838, 49.96745947429112, 48.17877776282174, 46.985313483646934, 48.607578890664236, 50.01161527633667, 49.40145574297224, 49.84207575661795, 47.96249076298305, 47.753815514700754, 45.89508901323591, 52.88282285417829, 49.17038645063128, 42.57183510916573, 33.648249762398855, 24.01140056337629, 15.31546425819397, 10.142658080373492, 9.566001892089844, 9.079874651772634, 13.161062376839773, 14.245161141668047, 12.902509484972272, 11.10816412312644, 8.034274118287222, 8.720003996576581, 4.598569699696132, 1.799447076661246, 0.5824723733322961, 0.9993187998022351, 4.537751683167048, 13.963869401386805, 29.05665257998875, 38.19864933831351, 48.076132025037495, 43.53486238207136, 56.85975980758667, 51.78045640672956, 55.97558069229126, 38.925660201481406, 18.131077562059673, 4.441094858305795, 0.2544741635876042, 0.09805936353015048, 0.09948196647954838, 0.11598846396165234, 0.08670703840575048, 0.09571233125669615, 0.13276153749653272, 0.1668092847934791, 0.10908680608762161, 0.1441264155187777, 0.1137991300118821, 0.17894222374473298, 0.12158441011394773, 0.12972668106002466, 0.16000151580997876, 0.08513682694839579, 0.06493601163050958, 0.10468858959419386, 0.15611272305250168, 0.11833527231855051, 0.15932256009961876, 0.1056917764778648, 0.16033190808125905, 0.14083022810518742, 0.07509884451116834, 0.18401311949959823, 0.1686211632830756, 0.06608053735856499, 0.12190195093197481, 0.12619589694908687], [0.042251880280673504, 0.04476952000654169, 0.010077645353573774, 0.061353923486811776, 0.07485686535281794, 0.0339822245628706, 0.05730564107320138, 0.011747134965844452, 0.02510274906775781, 0.020232809940353036, 0.03670138240392719, 0.03440907737240195, 0.06797061022371054, 0.031726221154843054, 0.025782486789726784, 0.08442693682653563, 0.0615010570202555, 0.033571503923407624, 0.014939398804147328, 0.023704279912635684, 0.02696355671754905, 0.064464796201459, 0.0331920807116798, 0.062396173631506305, 0.037401060573756695, 0.05894304785345282, 0.09461784748626606, 0.10097055695950985, 0.027840766789657728, 0.014285241852381399, 0.040486335554825406, 0.029619600623846054, 0.012402024735430521, 0.03515840055687087, 1.7435867083924157, 12.317626629556928, 29.607566561017716, 38.88332830156599, 38.634009565625874, 36.80027573449271, 27.596433060509817, 31.997465474264963, 29.01735356875828, 14.962969984327044, 13.299509576388768, 5.66439687354224, 2.9548984127385274, 0.18370909509914263, 0.31799000820943285, 0.339935513479369, 1.0973470253603799, 2.0134948023727963, 4.400935573237283, 4.903015443256923, 1.9576145665986198, 4.906007945537567, 2.8713272171361104, 4.4158468416758945, 9.98095178604126, 12.634287306240626, 18.937480279377528, 31.638101169041224, 36.78132104873657, 34.54947975703648, 44.79806573050362, 53.708664894104004, 50.58378553390503, 49.597634656088694, 45.874254839760916, 44.77675213132586, 43.87690135410854, 43.7581844329834, 42.39183160236904, 40.884927136557444, 39.09620720999581, 38.12181615829468, 39.50435829162598, 37.12557302202497, 37.30116094861712, 37.03605243137905, 38.67314529418945, 40.94872897011893, 42.78320625850132, 44.66348607199532, 46.48275375366211, 48.488646575382774, 47.95726571764265, 50.87179183959961, 45.425779887608115, 30.675438676561626, 47.56388998031616, 50.82692732129778, 46.93674210139683, 48.86553771155221, 46.49869292122977, 49.117656571524485, 47.330510411943706, 46.38235923222133, 47.70306587219238, 48.74734190532139, 48.40306561333792, 49.78646584919521, 49.41394165584019, 47.264651911599294, 49.43160397665841, 48.047498498644146, 46.923874037606375, 49.33642407826015, 47.86644581386021, 47.17490203039986, 49.102144718170166, 48.877217633383616, 48.09858512878418, 52.85390445164272, 52.85472433907645, 44.66646684919085, 34.91481256484985, 28.32941242626735, 20.390134947640554, 15.020475012915474, 7.292230827467782, 5.996896837438856, 5.810085833072662, 3.4492379895278384, 4.903081016881125, 5.76815128326416, 5.643982197557177, 2.8496056284223283, 3.907963488783155, 1.7236689371722085, 0.9442891755274364, 0.43551105207630564, 0.07227963328893695, 0.9629029652902058, 3.520332391772951, 12.874939032963344, 21.90600085258484, 41.268863746098106, 33.778712613242014, 37.8760027885437, 44.3914988381522, 39.536170618874685, 38.38098743983677, 31.22305747440883, 9.077917865344457, 1.239352679678372, 0.1948882309453828, 0.04604744911193848, 0.04637532401829958, 0.03186719359031745, 0.04353015883160489, 0.017653635569981167, 0.03909047367051244, 0.03236336214467883, 0.042014559265226126, 0.03946012258529663, 0.046709214137601, 0.02839233772829175, 0.03090135327407292, 0.022034512101007358, 0.0033314470617499736, 0.017420762351581028, 0.042186968228114505, 0.04014793996300016, 0.01814265575792108, 0.03171226029683437, 0.010621653171256185, 0.03243202988856605, 0.0352983009070158, 0.021697938375707184, 0.03346685686015657, 0.008499462806087519, 0.10846718147929225, 0.03644604967640979, 0.06055981359843697, 0.016387258523276875, 0.03326530142554215, 0.06586983866457428, 0.05799455089228494, 0.08620915655046701, 0.01340686554820942, 0.05388336828244584, 0.02947061468980142, 0.038163564300962856, 0.012944927389201309, 0.057316484062799385, 0.09045648042644773, 0.034041766010757, 0.06757351796009711, 0.0161671044438013, 0.033427430582898, 0.040269326485161266, 0.05316055885383061, 0.02829357186731483, 0.027370314712503126, 0.012330884579569101, 0.08945233002305031, 0.04846071997391326, 0.03060849416734917, 0.05712231448186295, 0.009138870951054352, 0.03519910926531468, 0.016847834523235048, 0.10842891888959066, 0.02253783750347793, 0.031222887270684754, 0.018033275912914957, 0.04797207637290869, 0.01901781665427344, 0.03458821401000023, 2.6092971861362457, 15.544193744659424, 33.0187394959586, 46.403558186122346, 44.612548828125, 41.71505968911307, 32.64107363564627, 31.238833359309606, 33.82533155168806, 23.04885619027274, 13.471425380025591, 6.983928833689008, 2.016420862504414, 0.280842550098896, 0.16348846655871185, 0.5669151938387326, 1.2307669860976083, 3.861545179571424, 8.976689560072762, 8.023170028414045, 6.743109481675284, 6.412346133163997, 5.961870534079416, 6.9419994950294495, 9.04198786190578, 16.11356040409633, 24.43214178085327, 33.957187516348704, 41.80973584311349, 40.57166065488543, 47.01879685265677, 52.98422833851406, 51.94025802612305, 50.88088355745588, 47.694199970790315, 45.820368085588726, 44.70412261145455, 46.406858580453054, 44.893193517412456, 43.582200459071565, 41.9822804587228, 41.175334044865195, 41.68292427062988, 39.994265351976665, 38.597222328186035, 39.825462341308594, 39.673140457698274, 41.772323267800466, 45.11950329371861, 45.76624856676374, 48.24110657828194, 49.681165899549214, 49.363490785871235, 50.68189409800938, 46.10667903082711, 33.50239665167672, 49.13886942182268, 51.8674304825919, 48.16299492972237, 49.727069173540386, 47.41758871078491, 48.207157679966514, 49.05490391595023, 47.20159700938633, 47.91546188082014, 49.39931222370693, 49.87454121453421, 52.45757572991507, 49.97227457591465, 48.06444862910679, 50.23767491749355, 48.10829871041434, 47.68453502655029, 48.73475524357387, 47.863388606480186, 47.24633993421282, 48.846225193568635, 50.35335200173514, 49.22665991101946, 53.659951073782786, 52.83286183220999, 46.804705483572825, 40.65935039520264, 33.55070052828108, 23.51820179394313, 16.054938452584402, 8.673927017620631, 6.502050416810172, 5.234834917954036, 6.641402184963226, 7.176916786602565, 6.532185622623988, 7.5029036828449795, 4.781598712716784, 5.0262278488704135, 1.8326505635465895, 1.0950919006552016, 0.3883739842900208, 0.29945970539535793, 0.8419384647692952, 3.74653251682009, 13.961526121412005, 25.43898265702384, 43.276358127593994, 38.85722391945975, 39.80448572976248, 51.599441937037874, 45.61527115958077, 45.50497892924717, 33.70502001898629, 11.94127745287759, 2.195341318845749, 0.12066253886691161, 0.03363167301618627, 0.006752370415987181, 0.00811402014057551, 0.05867067711161716, 0.0413711689678686, 0.031246154236474206, 0.038508344907313585, 0.01781148656404444, 0.041822055487760475, 0.07144671119749546, 0.02694245258213154, 0.023310297035745213, 0.015193349016564233, 0.06980714667588472, 0.036381816158869436, 0.016841736189754944, 0.03144928726500698, 0.0669530112562435, 0.040839139837771654, 0.06810348773641245, 0.10675265919417143, 0.03497272623436792, 0.014741134264373353, 0.032118241369192085, 0.0555753326708717, 0.005562357396619129, 0.06247397445674453, 0.04270796437880822, 0.015474505090553845, 0.09530618733593396, 0.1644395012408495, 0.12384262893881116, 0.13197625534875052, 0.1792993638664484, 0.11801903428775923, 0.16588301663952215, 0.08803241407232625, 0.10802293781723295, 0.16546347843749182, 0.16946003612663063, 0.08977323637476989, 0.1474294289946556, 0.08410849355693374, 0.09041800749089036, 0.10828496768538441, 0.23515192898256437, 0.12765029604945863, 0.13765576987394265, 0.11966942144291741, 0.299120519310236, 0.18364764696785382, 0.12461497820913792, 0.188601088310991, 0.05122488843543189, 0.19584370324654238, 0.11318041464047772, 0.21644356500889572, 0.12601588160863944, 0.07099568218524967, 0.12288114481738635, 0.14399065423224652, 0.11262244172394276, 0.18809095211327076, 3.0436262573514665, 17.628510883876256, 38.33482360839844, 53.1376028742109, 52.25250312260219, 50.13177047457014, 40.40561955315726, 41.56372792380196, 39.05733551297869, 24.7422867843083, 18.884180647986277, 8.802829129355294, 4.268446019717625, 0.4793943815997669, 0.8434448125106948, 1.163789717214448, 4.901574994836535, 7.199270444256919, 14.251316377094813, 13.340521318571907, 10.091538446290151, 12.133967501776558, 6.516151351588113, 9.280259830611092, 14.845435994012014, 19.26974139894758, 26.12949637004307, 38.35169036047799, 48.132367270333425, 47.21444075448172, 48.914175101688926, 53.91092695508684, 52.78297029222761, 52.56410551071167, 48.70973130634853, 48.90653903143746, 47.863388606480186, 47.297701018197195, 46.20090355191912, 46.58142164775303, 42.75869648797171, 43.03148971285139, 44.42210217884609, 41.48017236164638, 41.20034408569336, 41.00548880440848, 41.015278816223145, 44.7218405178615, 46.57974713189261, 48.12376887457711, 50.50210945946829, 52.74681534085955, 49.63960524967739, 52.19948489325387, 45.782215527125764, 38.13700144631522, 50.19278608049665, 52.52912480490548, 50.2098126411438, 51.590371063777376, 48.33842304774693, 49.31210538319179, 49.24605928148542, 49.350139822278706, 49.85460683277675, 49.9384194782802, 50.84211955751692, 52.14756795338222, 51.20094190325056, 49.61794424057007, 50.37953976222447, 47.70288174492972, 48.842959540230886, 51.57850701468331, 49.911342348371235, 48.68855667114258, 49.27621446337019, 51.330164500645225, 49.98936367034912, 54.01417023794991, 54.862295150756836, 48.409885270254954, 43.13497270856585, 37.0403151512146, 28.533885751451763, 17.847118582044327, 11.939284188406807, 10.97771430015564, 9.64878967830113, 8.388586214610509, 11.743473529815674, 12.631293501172747, 12.335772718702044, 9.755730271339417, 11.120430299213954, 5.606253044945853, 3.2234660472188676, 1.9381802380084991, 0.4157091746372836, 1.7358179709741046, 5.348777558122363, 17.33568252835955, 30.052695955548966, 50.75232451302664, 45.42424780981881, 49.690796102796284, 58.43241160256522, 53.16423879350935, 52.658006940569194, 37.52380207606724, 13.443993891988482, 2.3848519154957364, 0.253161469740527, 0.108318609451609, 0.1571406086108514, 0.08325824168111597, 0.13243513501116208, 0.1368328154619251, 0.1253248072628464, 0.12174409654523645, 0.11542998892920357, 0.25755004425133976, 0.16460168468100683, 0.16167833868946346, 0.09589396829583816, 0.08094310055353812, 0.18422921933233738, 0.08243955525436572, 0.10723098567021744, 0.07620392021323953, 0.14227998602603162, 0.11513231561652251, 0.13432499074510165, 0.22909841952579363, 0.15632746581520351, 0.08067762372749192, 0.13917487407369272, 0.13687280831592424, 0.20384101197123528, 0.1952375000608819, 0.109040027883436, 0.13729785622230598], [0.02471713422398482, 0.07095657142677478, 0.05847791888351951, 0.05039579328149557, 0.033461262338927815, 0.03596028306388429, 0.07386430432753903, 0.01727157624970589, 0.028156943752297332, 0.016335387913776294, 0.02116650126741401, 0.02441612251901201, 0.013255512375118477, 0.028619741954441582, 0.03334750594305141, 0.0038764875249138898, 0.03804919383089457, 0.028379272536507676, 0.06402515300682612, 0.04244975805548685, 0.024405043738495027, 0.054657054266759326, 0.02378943605747606, 0.029856843607766286, 0.012469364247018737, 0.034879743188087425, 0.02420212105581803, 0.03388642898893782, 0.059804197001670084, 0.022477900808943168, 0.030515198994960104, 0.038303233949201446, 0.08909049443900585, 0.13378335695181573, 0.626806874360357, 8.942124009132385, 20.09463153566633, 34.95100225721087, 41.232264110020225, 46.207417488098145, 30.21126774379185, 25.976404973438807, 22.350577865328106, 20.827056782586233, 19.519376277923584, 9.41269075870514, 2.815105651106153, 0.6521637822900499, 0.1897268457604306, 0.2455989255436829, 0.7031548204166549, 3.0541671088763644, 8.896953770092555, 8.114295652934484, 5.856465492929731, 5.482618102005549, 5.330462106636592, 4.067541463034494, 5.870630698544638, 14.05846391405378, 23.42922489983695, 26.028818709509714, 30.841542312077113, 39.07226024355207, 50.21775790623256, 51.00012854167393, 52.31970262527466, 48.26857280731201, 47.839823790958945, 44.30848176138741, 43.45609065464565, 43.03915010179792, 41.739315850394114, 39.30331563949585, 39.7895644732884, 37.23811994280134, 38.454263142177034, 36.73523364748274, 39.13420343399048, 38.52890069144112, 41.65440886361258, 43.78560897282192, 45.37830979483468, 46.16927882603237, 47.303686891283306, 48.70927619934082, 49.91134582247053, 47.204602105276926, 46.264698437282014, 27.935183797563823, 47.01604536601475, 50.39948456627982, 47.17038917541504, 48.354369163513184, 49.8485757963998, 49.3593670300075, 46.85592760358538, 48.35739510399954, 47.89826856340681, 47.69750383922032, 49.353276933942524, 46.62428855895996, 46.11759465081351, 45.56770379202706, 49.253657136644634, 49.98481607437134, 49.84318052019392, 47.9583774294172, 46.228470529828755, 47.70246832711356, 46.51232181276594, 49.606048924582346, 45.545351437159944, 48.35319491795131, 50.861633573259624, 51.32635341371809, 45.305075781685964, 33.29253326143537, 20.4876320702689, 13.389790994780403, 6.834952073437827, 3.775944241455623, 1.7814596018620898, 7.566835795130048, 9.153423070907593, 5.378631361893245, 6.649399127279009, 2.7796735295227597, 3.1681377589702606, 1.6007540013108934, 0.36505897822124617, 0.2169898399817092, 0.28114604524203707, 1.0789539494684763, 4.861498653888702, 13.366482394082205, 23.405816418784006, 30.698937484196254, 36.94911309650966, 43.13353443145752, 34.90203135354178, 40.04462936946324, 34.397387163979666, 20.95869561604091, 8.082678743771144, 0.590699203312397, 0.0691828333905765, 0.04890501452609897, 0.06011379895997899, 0.060770111956766674, 0.05522661656141281, 0.03524949727579951, 0.024932231521233916, 0.020739870678101267, 0.06771274656057358, 0.01379662030376494, 0.02369616972282529, 0.06517364137939044, 0.05584738789392369, 0.06825296221567051, 0.05655381748718875, 0.07499483866350991, 0.08774116648627178, 0.053811636952949424, 0.03532202249126775, 0.024521860327305536, 0.0359116829931736, 0.0444559995085001, 0.03350697863580925, 0.003875669890216419, 0.011854603038435536, 0.04254453243421657, 0.021752697848049656, 0.03700446364070688, 0.014982662196936352, 0.023117036691733768, 0.01499565614254347, 0.049503842036106756, 0.022779416326167326, 0.09782206626342875, 0.037912377422409396, 0.018331168053139533, 0.034944024203079085, 0.033292649779468775, 0.03508701188755887, 0.02769726002588868, 0.023361848733787025, 0.03039760548355324, 0.011361788991572601, 0.041996615406657965, 0.04990553476714662, 0.03693860503179686, 0.04725141450762749, 0.020100283569523265, 0.04844501867358174, 0.02902687314365591, 0.02800123523255544, 0.057140254947756014, 0.010424135020002723, 0.007638811532940183, 0.01494876598007977, 0.04466760065406561, 0.04564348668126123, 0.02808286978064903, 0.0388131699790912, 0.023149017743500214, 0.05946125861789499, 0.024141032548089112, 0.03553652437403798, 0.16956842531050953, 1.091942412512643, 11.605193087032863, 26.467743362699235, 43.10336882727486, 45.31098175048828, 51.83510398864746, 33.864241463797434, 30.574401446751185, 28.180656705583843, 20.98937886101859, 22.55369802883693, 11.246853641101293, 3.6297176650592258, 0.6221202601279531, 0.21102364441113813, 0.3596455715596676, 1.7812953421047755, 3.1372456337724413, 4.898666739463806, 6.883832650525229, 6.577258586883545, 5.120195720876966, 5.6143681066376825, 5.205536535808018, 9.083635364259992, 15.349288088934761, 24.245473214558192, 29.19340876170567, 35.42352492468697, 42.56620706830706, 50.50403758457729, 50.40296908787319, 52.39923170634678, 51.43692357199532, 49.97799294335501, 46.964479310171946, 45.069653442927766, 46.14115946633475, 43.246783120291575, 42.265131201062886, 42.10135521207537, 40.331923484802246, 40.69023861203875, 38.55273648670742, 40.32714659827096, 40.7288566998073, 42.37724733352661, 44.68766580309187, 46.422912393297466, 47.228799206869944, 49.249620233263286, 49.274616377694265, 51.26779399599348, 48.17482771192278, 46.068439619881765, 32.30837999071394, 47.90582125527518, 50.21667398725237, 48.384135246276855, 49.42868920734951, 50.88664708818708, 50.18151610238211, 48.718086515154155, 48.71077353613717, 47.91607332229614, 48.55590166364397, 48.84915385927473, 46.713687556130544, 47.441351549965994, 47.318100929260254, 50.259818826402935, 50.23005969183785, 50.52045270374843, 50.04178088051932, 47.053881781441824, 48.70755999428885, 47.19932494844709, 50.23669522149222, 47.50392702647618, 50.20379202706473, 51.86213248116629, 50.92646721431187, 45.71164614813668, 35.94644635064261, 22.10558785711016, 14.712987695421491, 7.792064258030482, 5.995591878890991, 5.480039886065891, 6.280816299574716, 10.014542852129255, 7.463143484933036, 7.113511434623173, 4.87561218227659, 3.0421528049877713, 1.926986690078463, 0.8652440799134118, 0.2213241181203297, 0.2347059143441064, 1.5911638587713242, 5.0860583526747565, 16.70104796545846, 25.817492723464966, 39.60722984586443, 40.993927001953125, 46.833811487470356, 42.333543164389475, 44.586955138615195, 40.37182004111153, 27.067282574517385, 10.437599556786672, 0.8167145497032574, 0.03390502424112388, 0.06654481137437479, 0.03458236503813948, 0.11041978813175644, 0.017517255120245472, 0.02494132049780871, 0.025711656215467622, 0.02861082600429654, 0.006993308023083955, 0.05025705661890762, 0.04070176363789609, 0.028498460605208362, 0.0476728118956089, 0.02717901363835803, 0.02361854531669191, 0.027793873234518936, 0.03257994373728122, 0.06867364714188234, 0.047002185202602825, 0.07077519901629005, 0.06250626593828201, 0.01035421877168119, 0.030958435032516718, 0.03192228384848152, 0.037138688045420816, 0.07818743413580315, 0.021545003367854015, 0.03948844463697501, 0.010083519770497722, 0.013280003248447818, 0.08023909333028964, 0.12290205726666109, 0.12383450008928776, 0.1816606114485434, 0.09751062547521931, 0.11957762922559466, 0.1604564871106829, 0.14549527849469865, 0.07642340593572174, 0.10322764941624232, 0.08625542585338865, 0.0827967089467815, 0.15558805263468198, 0.09948885360998766, 0.2684526906481811, 0.0926643790943282, 0.1961555579411132, 0.08283132101808276, 0.15774320199021272, 0.12312072196177073, 0.15087292636079447, 0.12651493054415497, 0.12690974293010576, 0.10857977758028678, 0.12735681608319283, 0.14115112088620663, 0.06857166332857949, 0.11438049881586007, 0.10717862312282835, 0.11287793051451445, 0.08817829910133566, 0.12568348087370396, 0.1657183226197958, 0.21342417917081288, 1.247474146740777, 12.435815487589155, 29.133334636688232, 48.94752298082624, 52.48283243179321, 59.2440584727696, 41.161409854888916, 37.056612151009695, 32.050890173230854, 31.084937708718435, 27.8362101827349, 14.137043697493416, 4.691464509282794, 1.093298722590719, 0.5029182136058807, 0.8779188426477569, 3.2854428929941992, 7.356922898973737, 14.919995376041957, 15.04728811127799, 12.724275163241796, 13.002772859164647, 11.040049195289612, 7.7623728684016635, 9.681494849068777, 16.918776716504777, 31.07762472970145, 35.47314201082502, 42.857836859566824, 46.158943380628315, 51.931166308266775, 50.001835686819895, 53.765098163059776, 51.99481528145926, 53.423146043504985, 47.77543136051723, 46.591903005327495, 48.83528872898647, 45.598098686763215, 43.760025705610005, 45.27265548706055, 41.845192500523154, 42.95789091927664, 40.89337267194475, 42.51332432883126, 42.84147732598441, 46.33973898206438, 47.0134710584368, 48.66092715944563, 49.53410727637154, 50.94524819510323, 51.973630223955425, 52.548194135938374, 47.731494426727295, 46.982947622026714, 35.64321306773594, 48.84478344236101, 49.61589799608503, 50.134622710091726, 51.408637455531526, 51.98780107498169, 50.49402175630842, 49.47974457059588, 50.046064444950645, 48.35618264334542, 49.50812448774065, 49.99721513475691, 46.84954915727888, 48.04618181501116, 47.314432280404226, 52.7602218900408, 51.512370586395264, 52.72361877986363, 51.94520166942051, 48.06349672589983, 49.95814888817923, 47.27473027365548, 50.38304165431431, 49.18427242551531, 50.704211711883545, 51.78522981916155, 52.67665590558733, 48.14825780051095, 37.67156594140189, 26.460890701838903, 19.2048955985478, 11.354251078196935, 7.74424501827785, 6.9797038946832926, 13.61980242388589, 16.026935475213186, 13.932318500110082, 14.863082681383405, 9.348498088972908, 9.98142513207027, 5.915225105626242, 2.2829085971627916, 1.3418889833348138, 0.7230940876262528, 2.1732740572520663, 7.4890758991241455, 19.815803800310405, 31.50543573924473, 42.037073952811106, 48.88849455969674, 54.3937155859811, 46.79515518460955, 52.73416267122541, 47.668509006500244, 29.559217521122523, 10.913043941770281, 1.2422531183276857, 0.13693013095429965, 0.1909307704440185, 0.08717264913554702, 0.3254747651517391, 0.09259067662060261, 0.13143816350826196, 0.08705203275063209, 0.11853491089173726, 0.15483958779701165, 0.11090238937841994, 0.09756958338298968, 0.0934394628607801, 0.10557008122227021, 0.12497001487229552, 0.11409646405705384, 0.17368850351444312, 0.11207174948815789, 0.13095446303486824, 0.10213103504585368, 0.14907742770654814, 0.11299676235233035, 0.1075163164309093, 0.08755676102425371, 0.054857239060636075, 0.1002960999363235, 0.11499485799244472, 0.13791103474795818, 0.18010576202401093, 0.09468335325696639, 0.06872417085937091], [0.038062710248466046, 0.0371041573983218, 0.06479145653013672, 0.006990641380460667, 0.015871792432985136, 0.030347421033574, 0.057107468135654926, 0.08517001409615789, 0.02706885347808046, 0.0507770180036979, 0.014872452842869928, 0.08307848418397562, 0.07360615567969424, 0.03717225517279335, 0.05910140435610499, 0.019374865173761333, 0.018238144294757928, 0.036869126438562355, 0.027153373496340852, 0.09063008361096893, 0.05759821180254221, 0.030944986468447105, 0.01726529131909566, 0.03920814521344645, 0.08530798062149968, 0.10340826865285635, 0.046668702204312594, 0.06535875930317811, 0.03579521584989769, 0.04801321255841425, 0.0451327364093491, 0.027300664789176414, 0.04267318267375231, 0.015320453892595001, 0.08805077522993088, 4.516181434903826, 16.88415731702532, 32.53311947413853, 43.35113116673061, 40.81211001532418, 35.744135652269634, 26.679355961935862, 24.974120378494263, 32.7747118132455, 13.20801135471889, 12.89396493775504, 6.498323142528534, 1.023212569100516, 0.21968586317130498, 0.2856147140264511, 0.6668244270341737, 1.369916387966701, 2.790865340403148, 3.9974793025425504, 5.638685933181217, 2.6119807107107977, 4.560141818864005, 5.353677340916224, 8.240264756338936, 15.45802913393293, 17.913805655070714, 23.884140832083567, 26.320326907294138, 40.101885999952046, 48.878537791115896, 50.049562862941194, 52.80550677435738, 48.609044960566926, 47.552220480782644, 45.78129836491176, 43.56320408412388, 41.641071796417236, 41.846703733716694, 39.659508092062815, 39.553516796657014, 40.37632247379848, 39.504903725215364, 39.747986452920095, 41.82937840053013, 43.60970490319388, 45.77225181034633, 46.08377429417202, 46.31925916671753, 48.63644518171038, 47.93563250132969, 49.834867000579834, 48.22823851449149, 51.24555628640311, 44.947542326790945, 27.20226522854396, 47.405877522059846, 48.119485310145784, 45.581308364868164, 47.253006730760845, 47.86639717647007, 46.67663976124355, 46.42540679659162, 47.106740202222554, 48.797021525246755, 49.422922202519004, 48.23497479302542, 49.028858593532014, 47.89729234150478, 47.7344126701355, 48.47012962613787, 45.74478905541556, 45.71205609185355, 47.14103651046753, 46.182060037340435, 48.985213484082905, 49.099323749542236, 47.96558618545532, 46.97460630961827, 49.36529384340559, 50.2539302280971, 46.75982012067522, 40.45030689239502, 33.472957134246826, 22.768447739737375, 14.078003985541207, 6.249953269958496, 4.065099171229771, 6.373867877892085, 4.9451970883778165, 6.206547439098358, 3.799909446920667, 5.063211372920445, 2.5908733861786977, 2.223536023071834, 0.838032925767558, 0.37010442891291206, 0.07987054024956056, 0.2553111229624067, 1.4831965608256203, 5.347804810319628, 12.120828458241053, 30.09943996156965, 21.00551778929574, 37.09455278941563, 36.977069173540386, 33.313096455165315, 41.808561597551616, 33.84052031380789, 16.68755282674517, 3.330801167658397, 0.09530066406088215, 0.04859347195763673, 0.0099963661881962, 0.023261293236698424, 0.01382448519247451, 0.04787527317447322, 0.01456451159901917, 0.03999501174049718, 0.016665995619925003, 0.040760680833565335, 0.04680462633924825, 0.023181302439687506, 0.041995546714003594, 0.016708882425778677, 0.05127563267680151, 0.031196217451776777, 0.008265279166932617, 0.05695928965828248, 0.056378151556210856, 0.04729848787454622, 0.027613452469397868, 0.019993275204407315, 0.03370946366339922, 0.019560551370627115, 0.054939945694059134, 0.012630564659567816, 0.02721006509714893, 0.029909474176487753, 0.04358354935954724, 0.05856444566909756, 0.08108715353799717, 0.04146890175927963, 0.021745610549779873, 0.019254608412406275, 0.018836074442203556, 0.03142946386443717, 0.050878197753003666, 0.03751299510310803, 0.029525382643831626, 0.03808821637981704, 0.008530374317030822, 0.020483859415565218, 0.0807186004572681, 0.01187018135429493, 0.026196727329599004, 0.043565228914043734, 0.026665569582421864, 0.027420465235731432, 0.04114448059616344, 0.008086297744219857, 0.034082162593092234, 0.009024391915383083, 0.01495466414572937, 0.04030734480225614, 0.027690092999754206, 0.042090436443686485, 0.020881046674081256, 0.047994030373437066, 0.048173641985548396, 0.04833596791805966, 0.039866945041077476, 0.03005599702841469, 0.013001363691208618, 0.027651387665952955, 0.05460757210052439, 0.16657464738403047, 5.967799953051975, 19.843435049057007, 37.82205350058419, 49.86126320702689, 47.648838656289236, 38.75993176868984, 30.60860742841448, 30.00020578929356, 33.4361629486084, 17.817058937890188, 12.980699300765991, 6.112699423517499, 1.3620229086705615, 0.10070276632905006, 0.4244381748139858, 1.0609118661710193, 2.1459183480058397, 4.849902544702802, 9.209968379565648, 8.487423471042089, 4.670218655041285, 4.722635430949075, 2.2728228526456014, 8.134431532451085, 12.17839775766645, 21.032598393304006, 28.16435275759016, 34.096988746098106, 43.95399856567383, 48.80895505632673, 50.61859948294503, 54.29180288314819, 49.987230573381694, 50.12836585726057, 47.92722518103463, 45.439287185668945, 43.333555698394775, 45.15598481042044, 41.48925365720476, 41.96001843043736, 41.68566880907331, 42.17474903379168, 41.71742902483259, 43.246268953595845, 44.57656410762242, 47.221142292022705, 47.675231388636995, 48.76669263839722, 49.27686759403774, 49.187079497746055, 50.84463480540684, 49.61544983727591, 49.85808788027082, 45.06948321206229, 30.62215641566685, 49.13586432593209, 49.40881041118077, 47.40333448137556, 49.21228061403547, 51.339367389678955, 48.80144057955061, 48.22511529922485, 48.009578704833984, 50.063011101314, 51.034508228302, 50.04165233884539, 49.79266711643764, 49.344195638384136, 48.58049133845738, 50.16035188947405, 47.01751491001674, 48.87479966027396, 48.135094438280376, 48.67348255429949, 49.80856459481375, 49.95500135421753, 49.1452374458313, 48.40878050667899, 50.59611511230469, 50.14656318937029, 47.08767434528896, 41.74641343525478, 34.83009665352957, 25.46203851699829, 15.583480596542358, 8.218091317585536, 5.170772961207798, 3.199572277920587, 6.265202828816005, 7.286193711417062, 7.197770936148507, 5.979326580251966, 4.0906225102288385, 2.631449346031461, 1.7131605467626025, 0.9551623463630676, 0.24024794410381997, 0.41441705397197176, 1.5800131942544664, 5.8198293788092474, 15.498943601335798, 30.379817145211355, 25.18038633891514, 41.54572861535208, 43.551152433667866, 37.79773480551583, 47.03415584564209, 38.97332831791469, 20.17025225503104, 4.719873522009168, 0.3402375158454691, 0.06120299015726362, 0.052571173158607314, 0.02354227119524564, 0.017107084094147598, 0.026521014482049004, 0.042127572665257115, 0.03211823119116681, 0.029819022065826824, 0.02178790363749223, 0.08350026155156748, 0.0368893874942192, 0.012095669567185854, 0.028596240894070694, 0.015590522704379899, 0.03288889769464731, 0.06226216296532324, 0.035895825629787784, 0.04723400669172406, 0.01766313166756715, 0.007145374930197639, 0.04956440807187131, 0.02714529214426875, 0.046365420799702406, 0.04006800514512828, 0.07220553726490055, 0.05355148323412452, 0.024657943917970573, 0.07048522029072046, 0.012531345876465951, 0.02578066661953926, 0.07753399134214435, 0.10592915516878877, 0.1529396761740957, 0.07319460383483342, 0.10698268935084343, 0.16000028087624482, 0.15922813516642365, 0.16369351984134742, 0.0709034421348146, 0.09352718386799097, 0.05648236096437488, 0.25030755145209177, 0.1369454658457211, 0.1632779985666275, 0.23795487572039875, 0.12481655739247799, 0.16058422811329365, 0.14805615107928002, 0.14166729604559286, 0.15862799808382988, 0.12788995461804525, 0.13956410890179022, 0.1913604595299278, 0.11036701167800597, 0.1247296506272895, 0.1421494223177433, 0.17178481923682348, 0.12377918591456753, 0.11999127774366311, 0.1167799886316061, 0.1470721803073372, 0.08130192344209977, 0.12856926316661493, 0.20703289498175892, 0.39843334736568586, 6.308605185576847, 24.171612126486643, 43.74500370025635, 56.89833968026297, 52.89663239887783, 46.90268898010254, 38.4605964251927, 34.567802156720845, 42.266836983816965, 20.119721480778285, 17.87579206057957, 8.431579061916896, 1.9159147356237685, 0.44305326736399103, 0.8903453158480781, 2.0702511625630513, 5.174300474779947, 9.908414329801287, 13.274575097220284, 13.880517942564827, 8.525767973491124, 10.047315767833165, 11.439174566950117, 14.44598753111703, 18.86222607748849, 26.51415385518755, 36.959233147757395, 39.30557727813721, 46.56734807150704, 50.94102021626064, 50.90201302937099, 55.909117698669434, 52.00238881792341, 51.58680663790022, 50.878750460488455, 48.47890172685896, 45.03910568782261, 47.048694951193674, 43.82122891289847, 42.7205091885158, 44.44686903272356, 44.256519658224924, 42.884000301361084, 45.715519768851145, 46.92510386875698, 49.99043369293213, 49.157796314784456, 50.6539032799857, 52.5756881577628, 49.23812791279384, 50.435139247349326, 49.62870700018746, 51.74156733921596, 46.249822344098774, 34.0154481615339, 48.92601135798863, 50.380644525800435, 49.011383874075754, 49.441018785749165, 53.57312985828945, 51.032468932015554, 51.57955271857125, 49.82464272635323, 51.801165512629915, 52.442171573638916, 51.83405828475952, 52.25347934450422, 50.943844658987864, 51.353044918605256, 51.1617888041905, 48.184975555964876, 50.71679489953177, 51.72610412325178, 49.35468394415719, 52.20023529870169, 50.55622203009469, 49.67160517828805, 48.837189061301096, 51.66521011080061, 49.65590919767107, 48.76474714279175, 42.29627650124686, 37.57488523210798, 26.27905113356454, 17.725617170333862, 10.388373306819371, 7.46332848072052, 11.363283736365181, 12.580499563898359, 15.951523201806204, 11.298433593341283, 12.799687436648778, 8.47325348854065, 8.050844703401838, 2.974956125020981, 2.3449527536119734, 0.5901069779481206, 0.7325257243854659, 2.3401773869991302, 7.879076548985072, 19.014247451509746, 39.06617014748709, 31.217498915536062, 48.03368547984532, 48.74130392074585, 46.449023723602295, 53.99669204439436, 44.622783524649485, 23.233917985643657, 5.410029402800968, 0.40699008107185364, 0.1632511421505894, 0.15184954181313515, 0.1263247507491282, 0.13199942053428718, 0.14292429573833942, 0.11311614380351134, 0.11851800179907254, 0.14976736211350986, 0.1510735691658088, 0.14454954995640687, 0.13296831425811562, 0.1305693265582834, 0.12934275237577303, 0.10615282745233603, 0.15360016216124805, 0.10413283548716988, 0.14798837900161743, 0.17559928526835783, 0.10397867233093296, 0.14265972136386804, 0.11936600772397858, 0.13340872419731958, 0.1224897386772292, 0.16732791624963284, 0.11735214293003082, 0.1944520550646952, 0.11324395944497415, 0.14136438444256783, 0.1609578159238611, 0.18504732900432178], [0.026868634757452776, 0.03561068485890116, 0.03282330371439457, 0.041987526430083175, 0.04277950232582433, 0.05736544714974506, 0.0403370341019971, 0.05517913946615798, 0.12524997842098984, 0.020923151468325938, 0.009702632619467164, 0.08109668695500918, 0.011215374705248644, 0.034332474161471636, 0.010811695562941688, 0.01391556579619646, 0.035837142528699975, 0.03748893425134676, 0.023138410544821193, 0.07418618776968547, 0.03447614038097007, 0.005218407571581858, 0.03511758328282407, 0.022114694584161043, 0.024117855488189628, 0.06960338939513479, 0.038538597391120026, 0.018968339577051144, 0.010999474192171224, 0.012677557450453085, 0.042081378001187525, 0.03313008975237608, 0.01921813715515392, 0.020779140892305543, 0.032679807128650804, 2.662960295166288, 14.453844206673757, 27.846851348876953, 41.07815306527274, 43.940866470336914, 37.06088529314314, 27.010958739689418, 20.124955211366924, 26.695769344057354, 40.796115262167795, 27.73022930962699, 8.882205350058419, 1.9807010420731135, 0.19017869580004895, 0.3083897147859846, 0.9679699391126633, 2.326766929456166, 1.2793345685516084, 6.322740861347743, 6.296356814248221, 3.240842406238828, 2.1429002242428914, 1.7329585701227188, 6.233831712177821, 5.308729878493717, 11.090353284563337, 14.494809048516409, 24.521995885031565, 42.88565744672503, 47.74190282821655, 51.420067242213655, 51.77949060712542, 50.442299365997314, 47.660765239170615, 45.786203793116975, 43.749700682503835, 42.7299622126988, 42.79443107332502, 42.350288322993684, 40.94132913861956, 41.612351417541504, 41.4470294543675, 43.715664931706016, 43.51393788201468, 43.30119793755667, 44.905505725315635, 47.03857489994594, 48.18561479023525, 50.40734297888619, 51.55884708677019, 50.264852796282085, 48.14633314950125, 45.262448583330425, 45.91665274756295, 26.54625974382673, 44.96795960835048, 48.80918434688023, 47.18691199166434, 44.813185010637554, 45.484933376312256, 44.096551282065256, 44.44925226484026, 46.12189211164202, 44.85825450079781, 45.22271530968802, 46.577068601335796, 46.530008452279226, 45.823171683720176, 46.14643314906529, 45.22882277624947, 45.70645236968994, 44.1254940032959, 44.39282594408308, 45.365059580121724, 47.93510443823678, 48.10644006729126, 47.954191139766145, 46.46380601610456, 46.32737813677107, 51.060768944876536, 46.72396394184658, 41.77517897742135, 30.930951731545584, 22.0284298488072, 13.075151375361852, 7.290464247976031, 5.312950909137726, 2.328048654964992, 2.3396884075232913, 7.385111740657261, 6.267287722655705, 4.6614691359656195, 3.8159723792757307, 1.4117204419204166, 1.8037663591759545, 0.3736047739429133, 0.15906800090202264, 0.6058804744056293, 1.9399752616882324, 6.919492108481271, 18.920401607240947, 24.021366017205374, 37.10699006489345, 44.10802970613752, 36.506384304591585, 44.856378487178254, 39.97462279456002, 31.476958547319683, 10.849828362464905, 1.4403515798704964, 0.2006055670125144, 0.01997662565138723, 0.031212342836494957, 0.07394403219223022, 0.022223168584917272, 0.019153861229174902, 0.03070092081491436, 0.049008650572172234, 0.09028816981507198, 0.035259868683559556, 0.022815030932958637, 0.023412179068795273, 0.05049995858488338, 0.04393113910087517, 0.01677361805923283, 0.03943801252171397, 0.08613487732197557, 0.023497567611879537, 0.03112952085211873, 0.013400625570544174, 0.006397136553589786, 0.023697007713573318, 0.03397688449227384, 0.03779110964387655, 0.02243599109351635, 0.0040615448046342605, 0.07241013592907361, 0.06509630874331508, 0.04199475282803178, 0.03066833077796868, 0.057369389438203404, 0.030534829013049603, 0.04475054816742029, 0.019913949371714677, 0.02644715764160667, 0.02942773127662284, 0.0867910681824599, 0.062204032870275636, 0.042797768488526344, 0.03322318475693464, 0.03743813233450055, 0.036113455558993986, 0.013139766175299883, 0.05569144019058772, 0.02949183587250965, 0.0006097240932701555, 0.05020006646269134, 0.01431073441303202, 0.024029442375259738, 0.03843838116154075, 0.01803038874641061, 0.021590261653597866, 0.09779666869768075, 0.025836884942171828, 0.04181749912511025, 0.04260614002123475, 0.02478369850931423, 0.051242340356111526, 0.03160968276539019, 0.0031365332127149615, 0.02898097364231944, 0.007503163052855858, 0.07450379644121442, 0.041489960093583376, 0.0627681804554803, 0.04951683258903878, 3.5579920623983656, 18.274438006537302, 32.97566066469465, 48.570909772600444, 47.83253165653774, 41.82285056795393, 30.578719752175466, 23.798825638634817, 28.009157793862478, 28.14086958340236, 25.77720011983599, 10.139824083873204, 2.195211257253374, 0.17118286368037972, 0.14188353158533573, 0.40744917786547113, 2.0676983509744917, 4.392916917800903, 7.359965341431754, 5.627621795449938, 3.330848719392504, 4.003753960132599, 3.5341436735221317, 7.093700383390699, 11.063833747591291, 16.37708125795637, 22.633789913994924, 32.15186486925398, 42.59760250364031, 49.14395897729056, 52.21366269247872, 53.88181747709002, 53.53285115105765, 49.419562748500276, 46.72698640823364, 47.121849060058594, 44.108700207301546, 43.3645099231175, 43.639217376708984, 42.37098353249686, 42.50743225642613, 43.00977659225464, 44.344928537096294, 45.57281419209072, 45.408520562308176, 48.22275638580322, 47.97373642240252, 50.040304388318745, 51.0705554825919, 52.24265405109951, 50.60351494380406, 47.94298716953823, 47.872136388506206, 48.34868901116507, 31.430443831852504, 45.94772161756243, 51.049036911555696, 48.757079805646626, 47.2349796295166, 47.275543212890625, 46.88978270121983, 46.5745290347508, 46.91869068145752, 46.71899250575474, 47.83780533926827, 48.44737774985177, 48.72177600860596, 47.682273387908936, 48.78916311264038, 47.44409261431013, 47.335339409964426, 47.7452518599374, 47.06901843207223, 47.74377189363752, 50.20406648090908, 49.27034670966012, 49.37390960965838, 48.16814007077898, 48.969503607068745, 51.79805619376046, 47.65148939405169, 41.377453667776926, 33.1429454939706, 23.37917528833662, 14.162483658109393, 9.198690584727697, 6.374696450574057, 4.377328634262085, 5.879804491996765, 6.650136070592063, 8.110830238887242, 6.119928155626569, 5.703611203602382, 3.54202184506825, 1.4531387622867311, 0.42803641887647764, 0.014289857586845756, 0.6717669303928102, 2.1617582866123746, 9.082731229918343, 21.98155208996364, 31.482850619724818, 32.19573926925659, 46.025468485695974, 41.40012911387852, 50.1301862852914, 46.66286843163626, 36.149913924080984, 14.537483147212438, 2.408866192613329, 0.1260628905147314, 0.04357981063159449, 0.01083364277811987, 0.07724266911723784, 0.04477165399917534, 0.009839482954703271, 0.025263151353491203, 0.03484437455024038, 0.023391775520784513, 0.02346825150639883, 0.0293209705767887, 0.025428968348673413, 0.020901619855846678, 0.006365140658869807, 0.030763634414012943, 0.02579831701171185, 0.019006403695259775, 0.04396554421899574, 0.011375584456670498, 0.03288925053285701, 0.03790665737220219, 0.025490899936163, 0.05586228173758302, 0.004575264939506139, 0.03509599229853068, 0.009077254882348436, 0.03694452524983457, 0.016832560699965273, 0.0467779904470912, 0.04071095100204859, 0.027721515956467817, 0.15572401748171874, 0.17800538401518548, 0.141427447487201, 0.10512282486472811, 0.10931904148310423, 0.15524109053824628, 0.09688814423446145, 0.10609945388776915, 0.2397014791412013, 0.10905739159456321, 0.11166335283113377, 0.21619215421378613, 0.15482855481760843, 0.10348492953926325, 0.07160354778170586, 0.14203933679631778, 0.06668474565127067, 0.16037127668304102, 0.13360091245600156, 0.11842939869633742, 0.14788456314376422, 0.21815267258456775, 0.09524386389447109, 0.11531949628676687, 0.0739565918754254, 0.19770329631865025, 0.10380797327629157, 0.08137740367757422, 0.11146179400384426, 0.1276992048536028, 0.17780069714146002, 0.17651853737022194, 0.11876280366310052, 0.16560947203210422, 0.16135769018105098, 3.8349952442305426, 20.586353812898906, 38.424990381513325, 53.232973848070415, 54.874155725751606, 48.11193609237671, 36.79331711360386, 30.31754391533988, 37.22643654687064, 49.91218308040074, 33.67515318734305, 11.910846948623657, 3.17702493923051, 0.47431448847055435, 0.8923032964978899, 2.1212044741426195, 4.211463408810752, 5.745465849127088, 13.406230432646614, 15.625555413109915, 8.189407416752406, 6.880275172846658, 5.333210553441729, 8.839889083589826, 13.789704118456159, 25.681096111025127, 34.216414383479524, 38.379986899239675, 47.11503635134016, 49.001215185437886, 51.61427981512887, 55.56100947516305, 54.849107469831196, 51.350342069353374, 48.66144132614136, 48.11635514668056, 47.36243738446917, 46.13506242207119, 46.11317907060896, 44.64432641438076, 44.37848833629063, 44.84065818786621, 46.99115344456264, 47.39849158695766, 47.261410576956614, 49.49708380017962, 50.29237808500017, 51.60934659412929, 51.559423787253245, 52.79399013519287, 50.38575839996338, 49.13377639225551, 50.499142578669954, 48.767762660980225, 34.844607966286794, 46.93275383540562, 51.29375941412789, 51.053410802568706, 47.57443734577724, 48.759838240487234, 48.43181378500802, 48.15473004749843, 49.904602595738, 48.21272666113717, 48.84028795787266, 49.911932945251465, 51.042939867292134, 49.67900153568813, 51.767414637974326, 50.215187072753906, 49.39368765694754, 48.524374212537495, 48.4403600692749, 49.01468079430716, 50.48796987533569, 50.489422048841206, 49.20044435773577, 49.001976013183594, 51.1248209135873, 51.796791621616904, 48.41501304081508, 43.416510241372244, 34.908510548727854, 26.990393808909825, 16.739337750843593, 10.478780661310468, 9.407148701804024, 6.5227126223700385, 8.381102136203221, 15.099691425051008, 14.837362187249319, 9.711194923945836, 12.510444351605006, 7.344053966658456, 3.594500720500946, 1.2253481511558806, 0.6915252730250359, 1.075576582125255, 3.695317345006125, 10.135932224137441, 27.748452697481426, 34.58524908338274, 45.51590149743216, 55.626933983394075, 49.03647034508841, 58.51363604409354, 51.76960332053048, 39.98213379723685, 16.551078047071183, 3.0357152989932468, 0.28295857512525147, 0.09824543818831444, 0.1285959974463497, 0.16934079038245337, 0.11802200627114091, 0.10244329686143569, 0.1488021324787821, 0.12270954331117016, 0.20933088952941553, 0.07876401248254947, 0.07475536329937832, 0.1645481482680355, 0.15702198711889132, 0.11015761577125106, 0.153564756203975, 0.07770377437451056, 0.15863680546837194, 0.18033650464245252, 0.13093212566205434, 0.10618279834410974, 0.15635273445929798, 0.08250979041414601, 0.16378380571092876, 0.14392147080174514, 0.13737292933676923, 0.13773568772843905, 0.11540747513728482, 0.1283536654497896, 0.18736787805599825, 0.13889602332242898, 0.13352464511990547], [0.043473260277616124, 0.04151763075164386, 0.08865377573030335, 0.024516289554802433, 0.02904293406754732, 0.05698409689856427, 0.03682982908295734, 0.019626518545140113, 0.10748512417610202, 0.0340223870506244, 0.05830302648246288, 0.03978559887036681, 0.034161127105887444, 0.01130281072775168, 0.011012439300040049, 0.019403596042788455, 0.038406707146870236, 0.03235863954094904, 0.044875157730919976, 0.06501255716596331, 0.034395496494003704, 0.061374550951378684, 0.06265707713152681, 0.11910345538386277, 0.035686694351690154, 0.027138729014300873, 0.05629917008004018, 0.025208076362365057, 0.024107818258926272, 0.03291687708614128, 0.016000954966459955, 0.03326769665415798, 0.037956563622823784, 0.08334605089787926, 0.04987289384007454, 1.8093171013253075, 9.714689867837087, 29.278736114501953, 39.799583775656565, 41.3454259463719, 35.72420127051217, 28.33772768293108, 39.84837402616228, 62.508231844220845, 58.69482421875, 34.93219348362514, 15.970154796327863, 3.922337140355791, 0.3464431257120201, 0.18315785324999265, 0.04787963615464313, 1.6996737676007407, 4.815004348754883, 6.5097516264234265, 3.6851265089852467, 2.1303819588252475, 2.558255502155849, 2.7068494600909094, 8.844968216759817, 7.340678010668073, 16.989429473876953, 18.269991159439087, 34.59598057610648, 45.92566803523472, 51.90051085608346, 50.35641615731375, 54.96217203140259, 48.48515510559082, 48.73079129627773, 45.124964577811106, 45.75668437140328, 43.61941501072475, 45.21759101322719, 43.049579347882954, 44.407038484300884, 45.82761853081839, 44.576004777635845, 44.39091171537127, 46.70769126074654, 46.67776536941528, 49.2417757170541, 49.515632016318186, 50.1953638621739, 47.21506609235491, 48.236649308885845, 47.78110456466675, 41.885016100747244, 28.00442259652274, 41.843128885541645, 28.83111231667655, 42.47091599873134, 52.68642159870693, 45.23905747277396, 45.3924354825701, 42.968320165361675, 41.05954578944615, 39.401292187826975, 42.130961486271445, 42.18476138796125, 45.17405360085623, 44.64725855418614, 45.29978125435965, 44.49562801633562, 45.42378575461251, 44.35281821659633, 42.92563738141741, 43.76066146578108, 43.66029126303536, 46.06887040819441, 49.593465736934114, 48.410503659929546, 48.73162855420794, 50.86817182813372, 43.644404206957134, 46.61179917199271, 45.12949480329241, 38.452824865068706, 29.173290252685547, 21.51873779296875, 13.482567684991018, 7.60594459942409, 5.222803243568965, 2.9008029954774037, 4.910983289991107, 2.539766779967717, 4.7679871916770935, 3.275584484849657, 2.280939434255872, 1.7457327246665955, 1.4147471423660005, 0.15115434197442873, 0.2836306776319231, 0.5670372758592878, 3.0209351778030396, 6.2000139611107965, 16.21470706803458, 20.7705522945949, 39.984027181352886, 43.82576608657837, 31.37077965055193, 44.25920513698033, 39.377633571624756, 23.756241866520472, 7.533052785055978, 0.521379360130855, 0.07141189556568861, 0.057555647300822396, 0.05680288394380893, 0.014167735702358186, 0.061578274305377684, 0.005053551975704197, 0.030995025033397332, 0.04111065223280873, 0.03078615838395698, 0.03254627143698079, 0.046269374167812724, 0.03447503436888967, 0.04651647626555391, 0.017807062515722852, 0.0318341353642089, 0.060345824009605815, 0.018648971803486347, 0.01515341892705432, 0.020013821244771992, 0.03440555916833026, 0.026663311757147312, 0.03368426626548171, 0.011821747524663806, 0.028354979286502515, 0.08556810380624873, 0.07962169431682144, 0.037048741443348784, 0.02975582331418991, 0.05002986613128867, 0.05337538982608488, 0.016172398713284304, 0.07564649012471948, 0.02143853952709053, 0.07940556055733136, 0.020399012004158328, 0.04074104063745056, 0.029807775347892727, 0.003952023315442992, 0.07069787995091506, 0.04244141546743257, 0.04468292197478669, 0.0637476457548993, 0.04683555396539824, 0.04837330091478569, 0.02633601360555206, 0.042069517209061554, 0.03540716167273266, 0.1019499951175281, 0.014924496478800262, 0.06121487809079034, 0.029264479143811122, 0.03224396712279745, 0.059000859037041664, 0.07242011717919793, 0.06251043214329652, 0.033253569555069716, 0.023397593958569423, 0.04272987088188529, 0.03849922539666295, 0.0165538948494941, 0.0415119887329638, 0.039254794495978525, 0.0184687664732337, 0.09011620189994574, 0.005419394309033773, 0.011599954783118196, 1.9513108134269714, 11.95057761669159, 32.463442938668386, 45.50308207103184, 48.539191246032715, 40.45390258516584, 29.664253439222062, 33.445258140563965, 49.120536599840435, 58.16650056838989, 33.55181571415493, 16.08194957460676, 4.16261887550354, 0.47682544801916393, 0.03504301228427461, 0.5096276221530778, 2.1898667897496904, 3.1881494394370486, 4.278589521135602, 5.029907354286738, 4.619931502001626, 2.109143052782331, 2.2152958938053677, 8.251041412353516, 11.404222522463117, 21.66222677912031, 22.239457062312535, 37.44786868776594, 47.90014805112566, 52.02180903298514, 51.5037339755467, 54.457673754010884, 48.96896859577724, 50.670624119894846, 47.39995070866176, 47.952579157693044, 45.353671482631135, 46.10330220631191, 45.24804496765137, 45.33557489940098, 48.24871138163975, 47.27165569577898, 45.58590807233538, 47.94449840273176, 47.96089615140642, 51.187448501586914, 50.78181961604527, 50.41497210093907, 48.857818262917654, 49.092719486781526, 48.59679181235177, 46.629548345293315, 28.6434223651886, 42.7906026159014, 34.12078980037144, 45.36495188304356, 53.04565736225673, 46.4540125301906, 48.077657154628206, 44.97303179332188, 42.90689808981759, 41.41707577024187, 44.64741488865444, 45.0179032598223, 46.12309067589896, 45.860115255628315, 47.40565170560564, 45.86872059958321, 46.73380259105137, 46.61758354731968, 44.63243804659162, 45.18993370873587, 46.230620997292654, 49.00413342884609, 50.18213449205671, 49.88781574794224, 49.86285434450422, 51.83226217542376, 46.85979080200195, 49.1559932572501, 46.67520495823452, 41.089541162763325, 31.99744462966919, 23.988662583487375, 15.491785219737462, 7.217717042991093, 5.7785153899874, 3.3796194280896867, 6.845040857791901, 5.065776560987745, 7.848091057368687, 8.24926267351423, 3.8131944026265825, 3.1177993629659926, 1.611625760793686, 0.3919100745448044, 0.22845028287598065, 0.8685039792742048, 2.9789804347923825, 8.810377478599548, 22.2390992300851, 23.86734356198992, 42.95667151042393, 47.96845926557268, 35.88801200049264, 49.12486185346331, 43.86313002450125, 27.97594714164734, 8.581098215920584, 0.9712960634912763, 0.09976421669125557, 0.06447148655674287, 0.016976340574079325, 0.08459429748888526, 0.06026522083474057, 0.029769726496722018, 0.06425657416028635, 0.008700946146356208, 0.0842788533440658, 0.06606432037161929, 0.023324408867795552, 0.06177495446588312, 0.01976748419526432, 0.01774114283866116, 0.038464759210390706, 0.02019209783923413, 0.02133903745561838, 0.129167446068355, 0.05242753068783453, 0.031393437047622035, 0.0393261967359909, 0.06399275974503585, 0.04871060067255582, 0.004594179103150964, 0.037712053528853824, 0.03550466036956225, 0.02270668076484331, 0.023111521898369704, 0.11326882096805743, 0.007926161783481283, 0.017835762850674133, 0.22958807753665106, 0.11778195415224348, 0.176707780786923, 0.12895575671323709, 0.13339143512504442, 0.06096256484410592, 0.08744096902332135, 0.27632926085165566, 0.2438792192510196, 0.1513409526752574, 0.11470605991780758, 0.07409609867525951, 0.1017662478344781, 0.15273558641118662, 0.15067769826522895, 0.10129061514245612, 0.19001047339822563, 0.12335217025663171, 0.09566217394811766, 0.1580466292798519, 0.21580104662903718, 0.20237701838569983, 0.19808859564363956, 0.33332023130995886, 0.12837837769516877, 0.08442971882011209, 0.16384560668042727, 0.0946148212200829, 0.07558321673423052, 0.10960687603801489, 0.09912008339805262, 0.10055343434214592, 0.16781186099563325, 0.12760757548468454, 0.12371677426355225, 2.599469827754157, 13.459601283073425, 37.071206842150005, 51.44038030079433, 54.693988936288015, 46.12450116021292, 37.92375428336007, 48.07546847207205, 69.33754675728935, 65.03648676191057, 39.24726104736328, 20.246170009885514, 5.528127934251513, 0.6044288437281335, 0.46861267728464945, 0.9643924853631428, 4.191222872052874, 9.387770175933838, 12.637944664273943, 12.8130236353193, 7.858634948730469, 7.813045212200709, 6.229404841150556, 14.000296201024737, 17.630855900900706, 30.298846312931605, 30.83274589266096, 40.231893743787495, 47.21421146392822, 51.806585107530864, 52.20765944889614, 56.55359091077532, 51.91266672951834, 51.71133572714669, 49.99842759541103, 50.03068460736956, 47.50919376100813, 48.54792513166155, 47.34412540708269, 48.28301463808332, 50.148411410195486, 49.12823172977993, 48.839228357587544, 49.52301100322178, 50.06334114074707, 52.534697260175435, 52.952898911067415, 51.9887112889971, 47.360849721091135, 48.11271776471819, 48.59286955424717, 48.71821158272879, 31.796530519212993, 44.09593289239066, 39.410700048719136, 46.24902677536011, 53.873000213078086, 49.02897323880877, 48.76142937796456, 46.499349525996614, 44.96323135920933, 42.22743374960763, 46.32425144740513, 45.838409083230154, 47.95257568359375, 47.78185497011457, 49.23857954570225, 48.16139336994716, 48.034831932612825, 48.927168233054026, 46.90482555116926, 47.971332345690044, 48.537117208753315, 50.55134786878313, 53.45352356774466, 51.56812640598842, 49.7817063331604, 52.262949739183696, 48.209888322012766, 49.70533868244716, 47.855533667973106, 43.32527344567435, 34.89340516499111, 27.41279217175075, 18.9041462966374, 10.091369083949498, 8.743362971714564, 5.699480499540057, 10.471128957612173, 8.302504982267108, 11.659478494099208, 12.625318918909345, 10.434705632073538, 6.060362117631095, 2.6266433639185767, 0.9704526173216956, 0.7861790625112397, 1.299544815506254, 4.420995891094208, 10.406184145382472, 24.562252010617936, 30.804463250296457, 50.232369967869346, 54.44629260471889, 42.736851351601736, 56.90507595879691, 50.182898793901714, 30.332687514168875, 10.844750097819738, 1.3969378237213408, 0.19261686211185797, 0.2100272700190544, 0.138238753591265, 0.264508665140186, 0.11409160574632031, 0.14133870867746218, 0.11064334506435053, 0.13501667577241147, 0.1297737578196185, 0.12183052833591189, 0.11691321219716753, 0.16185456780450685, 0.1073989909408348, 0.14021837950817176, 0.09473453515342303, 0.24939299481255667, 0.11323563382029533, 0.22667284682393074, 0.10713991270001445, 0.16649520450404712, 0.1512444649956056, 0.22425989487341472, 0.10653392664555993, 0.1298096387514046, 0.191111844299095, 0.14909771590360574, 0.20314716920256615, 0.12225359492003918, 0.2017805046801056, 0.1157628782093525, 0.07741655050111668], [0.04699780525905745, 0.0843286510290844, 0.03472845362765448, 0.004812688583375088, 0.02078738509278212, 0.0254374568217567, 0.05386509872706873, 0.01813904595162187, 0.10636280011385679, 0.02247538514036153, 0.06573174321757895, 0.039051708964897056, 0.03129809269947665, 0.010323821251014513, 0.02422735407682402, 0.018719593728227273, 0.05134426310126271, 0.015020261518657207, 0.032736301954303465, 0.0869832903678928, 0.09027901637767043, 0.03105725347995758, 0.0852134335520012, 0.033679821861109564, 0.005253981890356434, 0.035537711810320616, 0.033026697978909524, 0.059163184969552925, 0.02375029306858778, 0.03971156391448208, 0.05007677664980292, 0.039124834683856795, 0.0559627524177943, 0.022199560655280948, 0.023362864839977453, 0.7104469548378671, 7.101440242358616, 24.07437035015651, 42.446100507463726, 43.38512175423758, 42.067128385816304, 50.61356551306588, 67.8632640838623, 75.92741979871477, 65.98277582441057, 43.410336766924175, 12.709613595690046, 3.542218131678445, 0.7101184896060398, 0.1520371296043907, 0.3303981066814491, 1.7868081948586871, 2.272083955151694, 3.093662189585822, 2.546572974749974, 2.399594690118517, 0.9449279755353928, 1.896752255303519, 3.732617880616869, 7.998220784323556, 13.739546809877668, 19.287499257496425, 30.502584866115026, 40.70305456433977, 52.63692263194493, 52.3785469191415, 52.74554034641811, 51.10877752304077, 48.711405822208945, 47.17695869718279, 47.88999325888497, 46.935536588941304, 46.75172199521746, 45.551500592912944, 46.94372156688145, 45.453520570482524, 48.02817555836269, 44.63000965118408, 49.23806190490723, 49.490934644426616, 49.96412781306675, 47.341339179447715, 49.445073059626985, 49.21363203866141, 50.15413325173514, 47.784325054713655, 46.63135140282767, 41.07046488353184, 47.825632095336914, 28.71446074758257, 36.95106554031372, 51.98026922770909, 46.366409642355784, 47.592009340013774, 43.69029358455113, 43.773762294224326, 38.93088524682181, 36.31792484010969, 36.76222045081002, 39.20672525678362, 43.05465848105294, 41.37836388179234, 42.75317961829049, 44.8308230127607, 43.674323150089805, 43.66812883104597, 43.45673336301531, 44.436589172908235, 44.11028439658028, 46.71914536612374, 48.886066164289204, 49.90449142456055, 47.48486116954258, 46.42847095217024, 44.242404392787385, 44.17332192829677, 35.28257029397147, 27.472169739859446, 18.42926124164036, 11.087486284119741, 8.049684354237147, 4.89322977406638, 2.586372039147786, 7.191068095820291, 3.614439227751323, 8.271357076508657, 7.7671045916421075, 3.3649457011904036, 3.236978122166225, 1.4033651245491845, 0.09681089302258832, 0.1178158266203744, 1.1586819227252687, 3.4373144464833394, 8.875550712857928, 16.679025650024414, 27.880588327135357, 40.643432072230745, 38.70972408567156, 37.95218283789498, 42.123485224587576, 32.777473722185405, 18.68436782700675, 3.13184123805591, 0.34986587347728865, 0.051085731081132374, 0.03192334236311061, 0.08846523120467152, 0.08410045970231295, 0.037485073387090645, 0.0845595904226814, 0.021651850580903034, 0.011766684407900487, 0.0476773309388331, 0.05144760059192777, 0.015633925196847746, 0.032725380933178325, 0.018994332557278018, 0.04225409909018448, 0.026169380672009926, 0.03952206265447395, 0.019593650308836783, 0.041321907325514724, 0.06062655430287123, 0.04563116109264748, 0.025051273704905595, 0.04082712298259139, 0.01599007805011102, 0.04730471682601741, 0.022366546427032778, 0.022882723282756548, 0.02781200877922986, 0.021911692173619355, 0.03852865006774664, 0.012874959402584603, 0.038636862832520685, 0.024573525679962974, 0.05328377063519188, 0.01863652577490679, 0.005764925120664495, 0.037139302119612694, 0.03591043109606419, 0.0782660288470132, 0.06763116629528147, 0.026624392684815184, 0.04670863399016006, 0.03495125738637788, 0.009854071457604212, 0.017889658887205378, 0.05425278988799878, 0.03426206597526159, 0.021544579283467362, 0.05281221593863197, 0.03344116752435054, 0.0593296703217285, 0.02550818900843816, 0.057890511117875576, 0.019137537372963767, 0.029467439145914147, 0.03325176125924502, 0.018665404225300466, 0.01080125630167978, 0.035021906452519555, 0.010273373020546777, 0.041716322768479586, 0.04841026071725147, 0.05568009847775102, 0.0658253471234015, 0.022838833941412822, 0.017814003928963627, 0.06270746514201164, 1.0000319672482354, 9.266010812350682, 28.632195813315256, 47.70070695877075, 49.01969739368984, 45.249167101723806, 50.32446486609322, 63.80666255950928, 74.62421567099435, 66.478182383946, 50.42988640921456, 20.013533898762294, 5.09775390795299, 0.5663660690188408, 0.057847797338451655, 0.10574593035770313, 0.7303603291511536, 1.8191582475389754, 3.546250041042055, 2.589676124708993, 2.5770351801599776, 1.421857863664627, 4.136644772120884, 5.9792501500674655, 10.274277806282043, 16.554015398025513, 23.272857427597046, 33.32700327464512, 44.48799194608416, 54.174819537571494, 51.84425824029105, 54.67928307397025, 52.12050471987043, 50.706956250326975, 49.029258114951, 49.278622014181956, 48.29366970062256, 47.46383592060634, 47.57834223338536, 47.954962389809744, 47.960124901362825, 48.884985719408306, 47.153105531420024, 50.52334662846157, 50.841337885175435, 49.32298278808594, 48.05719470977783, 50.04450804846627, 49.297218867710654, 49.994922229221885, 46.97762530190604, 47.65570000239781, 42.39917237418038, 46.34851803098406, 32.4631997517177, 37.94998720714024, 52.41963856560843, 48.065598555973594, 50.10711479187012, 45.22056136812483, 45.76678010395595, 40.52832474027361, 39.467345237731934, 39.61964280264718, 42.16649109976632, 44.36133323396955, 44.279691900525776, 45.698392459324424, 47.03658424104963, 45.46599953515189, 45.56223555973598, 45.75234522138323, 45.800284317561555, 47.14924233300345, 49.54500205176217, 49.753788471221924, 49.95652648380825, 49.857024805886404, 47.10208143506731, 46.97045823505947, 45.054019996098106, 38.472109590257915, 30.158346789223806, 22.28411487170628, 14.367000409534999, 5.456683082239969, 5.397050167833056, 6.279833997998919, 7.751039487974984, 7.855265072413853, 8.28582148892539, 6.284773298672267, 5.579266675880977, 1.7739827973502023, 0.5198304003902844, 0.09912930468895606, 0.18240862845310143, 0.9639425895043782, 4.658413665635245, 10.717520764895848, 18.721031733921595, 27.985382795333862, 42.860254832676475, 46.38648646218436, 41.38207769393921, 47.45469903945923, 38.723328658512656, 22.49025402750288, 4.550376994269235, 0.33047480827995707, 0.03855420708922403, 0.026665706985763142, 0.05915753277284758, 0.018901096756703088, 0.08238893654197454, 0.03686135721259883, 0.03432500009824123, 0.0312875245165612, 0.028884401145790304, 0.013137089354651315, 0.005977138219999948, 0.039540644335959635, 0.006550681394790965, 0.05654173617118171, 0.019763250136747956, 0.054851668288132975, 0.03470397886953183, 0.08861060733241694, 0.03547837392293981, 0.042891399535749636, 0.09329291286745242, 0.008929191755929163, 0.03206223848142794, 0.011019658064469695, 0.0409240109979042, 0.047580751656953774, 0.08701284735330514, 0.024595148894669752, 0.07707750012299844, 0.04799202869513205, 0.012256571424326726, 0.11045772502464907, 0.19550199301115104, 0.1178143745554345, 0.08315739102129426, 0.13458368900631154, 0.07617249725652592, 0.1133998189387577, 0.11785496452025004, 0.11425194357122694, 0.10090449479009424, 0.15187825741512434, 0.06841739839208977, 0.08845387931380953, 0.09618443556662117, 0.12789439223706722, 0.14894364774227142, 0.12588818131812982, 0.10086435944374118, 0.15240196431321756, 0.16231375959302696, 0.2450071344418185, 0.10407235766095774, 0.1698335560836962, 0.13736190992806638, 0.10130034533462354, 0.21090103313326836, 0.13923155888915062, 0.11137425620108843, 0.08188243729195424, 0.1323034313640424, 0.17561803997627326, 0.11681331827172212, 0.20181534066796303, 0.1055134099775127, 0.28330023107784136, 0.997008740901947, 9.999502607754298, 31.311202321733745, 54.394354820251465, 55.76611334936959, 51.71712357657296, 61.06517437526158, 75.85045460292271, 79.20528806958879, 70.13613101414272, 48.751976353781565, 17.813513619559153, 5.361984780856541, 1.4211877967630113, 0.38074084530983654, 0.739792671586786, 3.302065155335835, 5.991481150899615, 8.918553113937378, 5.791102485997336, 7.309905307633536, 2.5018676136221205, 4.240110831601279, 6.3045244216918945, 11.911024127687726, 17.53456255367824, 24.794337477002824, 32.42768056052071, 45.67418840953282, 52.618502957480295, 53.97026457105364, 55.51358107158116, 53.62001282828194, 52.66934987476894, 51.251556055886404, 52.603599071502686, 50.4061096736363, 48.992842606135774, 48.89943102427891, 50.53534616742815, 51.103910309927805, 50.89226123264858, 48.69190917696272, 52.9054913520813, 50.44003425325666, 49.054869174957275, 48.30995280402047, 50.40141616548811, 51.76789058957781, 50.38242326463972, 48.96114839826311, 47.46810906273978, 43.750739438193186, 47.47482797077724, 37.24824694224766, 41.14180898666382, 52.906293869018555, 49.19970784868513, 51.78656734739031, 48.032525130680625, 48.592126096997944, 43.208759103502544, 40.67246164594378, 41.48267371313912, 43.80578654153006, 46.87959316798619, 44.87758091517857, 47.56026996885027, 47.24742385319301, 48.29426724570138, 47.203942026410786, 47.19565282549177, 48.0446914264134, 48.764118330819265, 50.3981157711574, 50.2472425869533, 51.1305844443185, 51.300530433654785, 50.625842979976106, 47.18698842184884, 47.573607036045615, 39.05803728103638, 31.667203698839458, 23.676691940852574, 16.315256186894008, 11.796530842781067, 11.320144976888384, 11.185957891600472, 14.574761969702584, 12.251681276730128, 16.76073820250375, 11.847204055104937, 8.689645579883031, 8.1116110427039, 3.1155338159629276, 0.6985123923846653, 0.3740609937480518, 1.9581851874079024, 5.221323277269091, 13.148041452680316, 24.7100419316973, 36.81591265542166, 51.31732075554984, 50.40539400918143, 49.89263432366507, 54.671445505959646, 42.897524969918386, 24.31012099129813, 4.951611144202096, 0.5046818075435502, 0.13017950819006988, 0.15831777187330381, 0.17089048294084414, 0.11161943125937666, 0.10145089868456125, 0.10613690223544836, 0.09933234272258622, 0.10602711526943104, 0.13836384830730303, 0.15041004334177288, 0.12145761906036309, 0.10810774790921382, 0.15791449137032032, 0.15214484025325092, 0.11958184971341065, 0.11232196606163468, 0.2211329069520746, 0.14730094160352433, 0.1205178616302354, 0.12571310571261815, 0.23723296874335834, 0.10823786378438983, 0.08514961054814713, 0.1454038798276867, 0.09671352324741227, 0.18405195884406567, 0.1370055161948715, 0.09472101873585156, 0.1733420571046216, 0.13566064621720994, 0.08070663109953914], [0.024113804634128298, 0.012088494059363646, 0.047623319551348686, 0.09371509735605546, 0.008883876642877502, 0.02156967150845698, 0.04835739605394857, 0.009390815244322377, 0.012935198045202663, 0.057422729076019356, 0.018109975815085427, 0.014574681142611163, 0.042486941774508784, 0.05464591611442821, 0.03587888939572232, 0.022125898893656473, 0.03869729655395661, 0.04215115175715514, 0.01644803660123476, 0.0460209285707346, 0.010217862070671149, 0.041464162192174366, 0.020249367891145603, 0.0234344553734575, 0.03945040935650468, 0.038988527176635604, 0.007947631479640092, 0.04845032821010266, 0.026688013824501207, 0.014741940024707998, 0.051350281706878116, 0.031322910117783716, 0.07127527253968374, 0.026214452360623648, 0.014455991797149181, 0.386141549795866, 4.252901596682412, 17.494229997907365, 35.50558315004621, 42.889169761112754, 38.081158774239675, 48.56069592067173, 61.85413537706648, 71.05784429822648, 55.01948424748012, 18.88507001740592, 12.279327290398733, 5.351745741707938, 1.5711142889090945, 0.1257367187312671, 0.1864575690456799, 0.5848393748913492, 1.2748199765171324, 1.7037445434502192, 3.417937223400388, 2.974606543779373, 3.0239142179489136, 1.5617030624832426, 2.0288833252021243, 5.427394688129425, 8.94060582774026, 14.075973374502999, 26.492937530790055, 34.74228531973702, 42.315363202776226, 52.271874700273784, 53.538989884512766, 50.478513377053396, 50.35498135430472, 49.93806859425136, 47.81423357554844, 49.51501362664359, 49.44097014835903, 47.06392887660435, 48.37957375390189, 48.251278741019114, 48.02190828323364, 48.15161030633109, 48.02838053022112, 48.45484011513846, 48.88280051095145, 48.77611092158726, 49.669708320072715, 49.569636889866416, 50.22007165636335, 49.73376028878348, 51.37075240271432, 47.435581071036204, 52.13213947841099, 29.13972176824297, 35.73598888942173, 51.62277398790632, 46.543720722198486, 48.89720760072981, 44.967626094818115, 46.30163853509085, 42.55628156661987, 39.31554446901594, 34.4010523387364, 38.6120845249721, 40.11131817953927, 43.34937327248709, 45.83647400992257, 47.87130260467529, 47.055264472961426, 47.35232775551932, 44.66637304850987, 46.39606802804129, 45.97654274531773, 48.7687041418893, 48.32151460647583, 49.07096815109253, 48.90215819222586, 47.083321298871724, 45.90972191946847, 41.857216358184814, 33.17223562513079, 24.508234977722168, 15.569676262991768, 11.650258234569005, 2.4077811879771094, 2.9767287841864993, 3.6697054164750234, 4.834028950759342, 4.681431310517447, 5.2023095318249295, 5.7022702012743265, 2.3642296620777676, 1.0864753744431903, 0.8293836127434457, 0.30575015928064075, 0.2471196853688785, 1.4917193949222565, 4.657602029187339, 14.61597694669451, 24.81665509087699, 23.344835553850444, 43.09502404076712, 30.51906599317278, 36.450739656175884, 38.08119004113333, 26.259260926927837, 11.023031319890704, 2.1989506908825467, 0.031025118061474392, 0.04539466110457267, 0.06466326090906348, 0.03194554742159588, 0.03628059569746256, 0.03678582947967308, 0.015730324666947126, 0.036505116149783134, 0.07677567417600326, 0.007449057518637606, 0.015586780583752053, 0.013556070309797568, 0.08990898409060069, 0.04357233317568898, 0.022671134011553865, 0.03729492073346462, 0.07440434356353112, 0.01732970804109105, 0.019167832265208875, 0.024231265831206526, 0.0262504469470254, 0.07901105351213898, 0.030267007848513976, 0.042915830189096074, 0.030781958252191544, 0.049621096280004294, 0.030062541498669555, 0.06744032153593642, 0.03796113355617438, 0.027110659716916934, 0.02096092381647655, 0.022523143827649098, 0.016870300817702497, 0.026727860793471336, 0.12303563367043223, 0.022722538128229122, 0.04721798987260886, 0.01752586572963212, 0.02576077706180513, 0.015304562602458256, 0.06329584321273224, 0.03476366959512234, 0.02321602646926684, 0.011751030605020267, 0.04521279675619943, 0.05318669602274895, 0.050842238789690394, 0.05881296590502773, 0.033460417562829595, 0.0562409755241658, 0.024872873277802552, 0.02065596473403275, 0.02825658322711076, 0.022083928110077977, 0.03353308866332684, 0.06812212709337473, 0.036877957571830065, 0.04568262458113687, 0.037178809821073494, 0.042909214472664256, 0.0675704102697117, 0.00798451918776014, 0.042248494390930445, 0.008042084402404726, 0.02048728771374694, 0.015918853925541043, 0.012822121880682451, 0.5521577085767473, 5.2171695572989325, 20.75080030305045, 42.79725899015154, 49.11196599687849, 43.006403241838726, 53.386230264391216, 67.48904800415039, 73.45566763196672, 65.35889707292829, 29.673560551234655, 12.801724995885577, 5.351322770118713, 1.5407893104212624, 0.10143001337668725, 0.138652931366648, 0.2800971658102104, 1.0419737909521376, 1.8919727631977625, 3.399391395705087, 3.942852999482836, 1.8427784315177371, 3.3882777520588467, 3.189040328775133, 5.421626814774104, 11.36988626207624, 16.779371534075054, 28.274434804916382, 36.23278856277466, 45.248642512730186, 52.835804394313264, 53.038712637765066, 51.117518356868196, 51.68509585516793, 51.21336875643049, 49.947441714150564, 50.23005274363926, 50.20241280964443, 49.98451382773263, 49.657729625701904, 48.79934917177473, 50.21232441493443, 50.27325316837856, 50.40815244402204, 49.43785735539028, 50.15315008163452, 50.506528513772146, 52.577126434871126, 49.96421813964844, 51.0153694152832, 50.21527739933559, 51.35950326919556, 47.99433783122471, 52.428681646074565, 32.15347337722778, 39.501346247536794, 52.50833579472133, 48.958098139081685, 49.50897911616734, 46.86646107264927, 47.40443229675293, 44.76486028943743, 40.019862515585764, 36.91392741884504, 39.87873765400478, 42.16873189381191, 43.81016043254307, 47.09666184016636, 49.706915923527305, 47.93497242246355, 49.799288749694824, 46.838286127362935, 47.464447362082346, 48.6617157799857, 49.64424317223685, 50.24968835285732, 50.25697701317923, 51.53594929831368, 49.32354211807251, 46.67308923176357, 42.966169697897776, 35.27122041157314, 26.476958411080496, 18.871904918125697, 12.654304197856359, 5.344305523804255, 2.473208248615265, 6.253536803381784, 8.872838309832982, 6.325850180217198, 7.8536487477166315, 5.083659487111228, 3.104908283267702, 1.5360718092748096, 0.3538605719804764, 0.22763734364083835, 0.2766824790409633, 1.8015269764832087, 5.863610412393298, 14.502954942839485, 25.92977213859558, 28.344832215990337, 48.39967836652483, 36.594838346753804, 41.77911513192313, 43.56714023862566, 31.83665289197649, 14.28225062574659, 2.5647831176008498, 0.021537663315289786, 0.07045140889074121, 0.06980255299380847, 0.014208156033419073, 0.01762827193098409, 0.021410855298329676, 0.015830140560865402, 0.03787389091615166, 0.015201832400634885, 0.03251885862222739, 0.03455867738063846, 0.03883560573948281, 0.042756021621504, 0.04789925938738244, 0.022685152545039142, 0.0523139371403626, 0.02790758722195668, 0.03724248693989856, 0.03094557679391333, 0.019108991404729228, 0.03167266777849623, 0.07116866111755371, 0.044318864188556156, 0.017198302949379598, 0.0893739660137466, 0.04877972982025572, 0.09420062308864934, 0.05582240762721215, 0.009358330380304583, 0.054255921327109845, 0.06458429300359317, 0.007836880993896296, 0.12260890299720423, 0.04493445151352456, 0.20779887959361076, 0.1393117888697556, 0.19959354560290063, 0.12089260295033455, 0.1122386148199439, 0.1318187266588211, 0.10004280959921223, 0.1282962885286127, 0.08143557448472295, 0.0572898176365665, 0.07946008084607975, 0.08695732961807932, 0.13603279553353786, 0.27513835046972546, 0.14911393289055141, 0.143864813127688, 0.06742761257503714, 0.11147918485637222, 0.10289437337113277, 0.10528796671756677, 0.12768061299409184, 0.1918116310345275, 0.11341132010732378, 0.10161587768899542, 0.10402606800198555, 0.15912227013281413, 0.1791903640010527, 0.11325866329882826, 0.12091650095369134, 0.1283874972058194, 0.12915502887751373, 0.13998737904642308, 0.10906317949827228, 0.5659552567771503, 6.474815649645669, 24.05828353336879, 45.25633069447109, 55.45509113584246, 49.107150895254954, 58.10040930339268, 70.06176444462368, 75.13046836853027, 60.57286671229771, 26.424796547208512, 17.297740152903966, 8.20853841304779, 2.88473202926772, 0.41327089975987163, 0.7282206639647484, 1.4043187648057938, 4.339734971523285, 5.9548428654670715, 10.971555590629578, 10.148754256112234, 7.169984221458435, 3.2755964270659854, 3.7674505029405867, 6.362313892160143, 12.276044266564504, 18.474620819091797, 30.36649397441319, 37.1413836479187, 46.2670191356114, 54.04259531838553, 53.49211386271885, 53.554793562207905, 51.91193716866629, 53.97631645202637, 50.978061062949045, 54.92653819492885, 54.450308663504465, 51.94392320087978, 50.35121890476772, 52.02555063792637, 52.46341569083077, 51.71369811466762, 50.22897924695696, 50.21641342980521, 51.03898286819458, 52.33983850479126, 53.762819153921946, 53.49943378993443, 51.65988779067993, 52.38059663772583, 52.292257240840364, 47.57552126475743, 52.260983398982454, 37.34078652518136, 42.634334155491416, 52.39441660472325, 50.11165196555001, 51.44079719270979, 49.16607856750488, 50.72705044065203, 47.81255211148943, 41.746965817042756, 38.399014541081016, 41.70234448569161, 44.034507342747276, 46.68718017850603, 50.41978372846331, 52.4560922895159, 49.766753809792654, 51.50109713418143, 48.998144081660676, 49.37292296545846, 50.735766955784385, 51.554956095559255, 50.34309646061489, 49.469614097050254, 51.282899379730225, 51.32070105416434, 48.77320310047695, 44.995880944388254, 37.63222871507917, 28.158083745411464, 20.14632092203413, 14.870888982500349, 4.9093687023435315, 5.743334489209311, 10.540636130741664, 10.757030827658516, 9.727516242436, 11.389672126088824, 14.026342391967773, 5.713004299572535, 4.473351436001914, 2.4766452184745242, 1.2343655015741075, 0.5485659241676331, 2.448306121996471, 7.23762971162796, 20.152742794581822, 33.10976784569876, 32.64071927751814, 53.711537974221365, 40.01852151325771, 46.410409109933035, 51.78331906454903, 36.58413117272513, 15.716703619275775, 3.2771919071674347, 0.22762073310358183, 0.21607110356645925, 0.22287161222526006, 0.09604999063802616, 0.11798392688589436, 0.16845846415630408, 0.09238292955394302, 0.13323644415608474, 0.12014995994312422, 0.1368751831884895, 0.0854213231110147, 0.1371156967111996, 0.16827473044395447, 0.1403359424855028, 0.11223353259265423, 0.16826342605054379, 0.1950382957501071, 0.094101896243436, 0.13814278159822735, 0.10760452598333359, 0.09112161437847785, 0.1628789928342615, 0.16140000362481388, 0.07896805474800722, 0.177993577505861, 0.11989139738891806, 0.10943205149046012, 0.20323080542896474, 0.1298490073531866, 0.0944438303953835, 0.061395843380263875, 0.13590281536536558], [0.03603054875774043, 0.025168112346104214, 0.012928449166273432, 0.0615790206938982, 0.03592276007735303, 0.02377987719540085, 0.06683037962232317, 0.014080004517122038, 0.06960013921239547, 0.08300193186317172, 0.04620511011619653, 0.04021876205557159, 0.02014955708623997, 0.08490059498165335, 0.015530375663989356, 0.012433870080193239, 0.026583527913317084, 0.04575965187645384, 0.03035386372357607, 0.04962391220033169, 0.00972671467544777, 0.03947435146463769, 0.026636492660535232, 0.06493794545531273, 0.05374463161985789, 0.041302959235118966, 0.04739108415586608, 0.023643091320991516, 0.009264176861116928, 0.020656022409509336, 0.03201058839580842, 0.04911428490387542, 0.07024016736873559, 0.05915317657802786, 0.12831002207739012, 0.09983035349952323, 3.247297065598624, 11.981819323131017, 34.50283302579607, 45.09683132171631, 40.16897433144705, 36.13967227935791, 39.184880120413645, 35.852614402770996, 31.83062185559954, 26.654528311320714, 21.66564529282706, 10.429594363485064, 2.2591045030525754, 0.3289417805416243, 0.011742934834079018, 0.23471402962292942, 3.042796164751053, 9.184253965105329, 5.964425299848829, 1.3403155420507704, 2.7862721468721117, 5.507644210542951, 3.236594234194074, 2.598433894770486, 6.967237957886287, 12.91197293145316, 21.49285922731672, 31.71953058242798, 41.434599127088276, 43.22450372150966, 52.35234873635428, 52.62431859970093, 51.97936943599156, 48.957556179591585, 51.590919971466064, 50.124176093510215, 51.40454844066075, 49.195903709956575, 50.440430300576345, 49.57601186207363, 50.616160665239605, 47.68136664799282, 48.8884493964059, 48.59196628843035, 50.62273366110665, 46.78796032496861, 49.1899664742606, 45.78827783039638, 50.01307092394148, 47.38281992503575, 51.41939326695034, 45.56008161817278, 52.42354692731585, 28.684352466038295, 33.92681694030762, 52.52875655038016, 47.599266733442036, 50.293785095214844, 45.413648332868306, 47.525980608803884, 43.71162108012608, 43.168515137263704, 35.59035117285592, 37.90407003675188, 39.792809282030376, 45.28382471629551, 47.84989520481655, 48.36417307172503, 49.101112910679404, 49.02480779375349, 47.80580888475691, 47.020731925964355, 46.196373326437815, 49.137139320373535, 48.41226850237165, 51.62092924118042, 46.59219135556902, 44.18448420933315, 41.921469824654714, 37.09876339776175, 29.819431032453263, 21.099952493395122, 15.023221288408552, 8.038256304604666, 5.805620312690735, 2.6612417016710554, 4.847360806805747, 8.243149995803833, 8.164407798222133, 6.515779622963496, 4.403875529766083, 4.309674458844321, 0.6574467473796436, 0.25245473480650354, 0.20407833637935774, 0.34378476121595924, 3.205022922583989, 6.870863837855203, 16.097876582826885, 25.918962478637695, 31.990809100014822, 37.29424054282052, 30.939084597996303, 39.22456128256661, 39.825198309762136, 26.751566852842057, 6.940488261835916, 0.4454667078597205, 0.04117810200633747, 0.009152420447207987, 0.006424361923044282, 0.05852713981377227, 0.02022304921410978, 0.01820707247991647, 0.01692012225144676, 0.030855966066675525, 0.0209775648878089, 0.020258078584447503, 0.020954610048128024, 0.04872849703367267, 0.007491721256103898, 0.02048530469515494, 0.06721715815365314, 0.01509230158158711, 0.06774416951728718, 0.023930695173995833, 0.07760291692933866, 0.026137297839990685, 0.04365379809002791, 0.021688118277649795, 0.029396121722779105, 0.04589083305160914, 0.030150829082620994, 0.04897186379613621, 0.046244862090264044, 0.025636087770440748, 0.01668033985021923, 0.02014403890020081, 0.020624538384644047, 0.03582174317645175, 0.025002093486753956, 0.04513581695833376, 0.04146267959315862, 0.05078366764688066, 0.023527358691873293, 0.013772343168966472, 0.03036761423572898, 0.021927756490185857, 0.040117850327598195, 0.021551342581265738, 0.04795039039371269, 0.01678577740676701, 0.023913244949653745, 0.02309705383543457, 0.039594055219952545, 0.07202751681740795, 0.015269204142636486, 0.03099932355274047, 0.06944726527269397, 0.021385332203603218, 0.050023650750517845, 0.022565431826348816, 0.039520390065652986, 0.04427151262227978, 0.03721071453765035, 0.0782432843531881, 0.021146228337394338, 0.032417173364332745, 0.05335957656747528, 0.006643577503772187, 0.02072786908995892, 0.01928058442925768, 0.056591099593788385, 0.05753550159611872, 0.06793441716581583, 0.3319146324481283, 4.1498242020606995, 15.865494080952235, 40.75027799606323, 50.580565043858115, 43.924968991960796, 41.368893487112864, 46.36663198471069, 52.95426075799124, 37.31333071844918, 24.34542826243809, 21.033798694610596, 10.73759150505066, 2.472010552883148, 0.3090601073844092, 0.13739643378981523, 0.39067571078027996, 2.4181031712463925, 8.379328608512878, 10.799478241375514, 6.077519391264234, 5.804364860057831, 6.361679869038718, 4.1941511034965515, 4.560924359730311, 9.098562700407845, 15.605718306132726, 24.560968330928258, 33.796017101832796, 41.12002290998186, 46.13384301321847, 53.76428869792393, 52.849311692374094, 52.27719007219587, 52.59890556335449, 53.36536829812186, 51.15554237365723, 51.78043556213379, 49.99857350758144, 50.418571267809185, 50.4678305217198, 50.628733430589946, 50.21020174026489, 50.03018781117031, 49.69167504991804, 51.606741019657676, 50.35524191175188, 51.28505679539272, 48.55404302052089, 51.502313068934846, 48.338711397988455, 51.35131481715611, 45.97303043093, 53.05062185014997, 31.438472475324357, 36.42904738017491, 51.027247360774446, 47.78911236354283, 51.92547920772007, 46.35247155598232, 49.86206572396414, 48.072647503444124, 44.160613673073904, 37.69987637656075, 39.73281158719744, 40.71369573048183, 46.435405254364014, 50.94831929888044, 51.03916699545724, 50.847097941807334, 51.07452985218593, 48.39528363091605, 47.72988591875349, 47.473389693668906, 49.99869162695748, 49.90549891335623, 50.21000371660505, 49.36922999790737, 47.8202611378261, 44.59252759388515, 38.84175028119768, 32.10348456246512, 23.75982539994376, 15.369715792792183, 10.503672582762581, 4.902628515447889, 3.010188485894884, 6.406577825546265, 7.047501810959407, 4.413445804800306, 5.901302652699607, 5.191203270639692, 1.6717870639903205, 1.3989145862204688, 0.5060479970914977, 0.06909167899617127, 0.42624302368078915, 3.1502033727509633, 7.883459993771144, 18.18446057183402, 26.841031857899257, 28.578300373894827, 41.960720198495046, 32.98715993336269, 41.351477827344624, 44.28624752589634, 30.837244851248606, 9.042550665991646, 1.0212251671722956, 0.09545881700302873, 0.0038810583064332604, 0.06213399448565074, 0.031136265490204096, 0.04308097543460982, 0.019714979155521308, 0.06756414060613938, 0.06650667770632676, 0.04481581984353917, 0.009312041569501162, 0.003449933058748554, 0.05564248388899224, 0.023513721834336008, 0.01398724623556648, 0.05711134935596159, 0.042819298404668055, 0.08831667953303882, 0.038614562779132805, 0.021477034515036002, 0.025161184503563812, 0.03638908666159425, 0.03532033293907132, 0.046125029413295646, 0.013162748156381505, 0.008767354368631328, 0.039763458272708316, 0.08268780407628842, 0.05853258166462183, 0.06635143567941018, 0.03704014101198741, 0.07800832803228072, 0.02301771443204156, 0.0640274735965899, 0.1704988053866795, 0.11705235258809157, 0.15278559444206102, 0.07531078492424317, 0.18820141761430673, 0.11291719055069344, 0.052121199268315516, 0.12675564762737068, 0.1334203135754381, 0.11714748319770608, 0.11959385978324072, 0.06536530038075787, 0.18545588850975037, 0.07733855968607323, 0.09893111139535904, 0.062436600747917376, 0.11858411825128964, 0.12188209699732916, 0.15181006464575017, 0.11094527279159852, 0.1255340538918972, 0.11295725125819445, 0.14252952406448977, 0.13527871242591313, 0.14675501946892056, 0.13631826878658362, 0.12271193175443582, 0.07010600063949823, 0.0930267439356872, 0.13378555540527615, 0.10075432820511715, 0.15508882728006157, 0.1512045535658087, 0.1806874700954982, 0.42266177013516426, 4.787621932370322, 19.34466208730425, 46.40495477403913, 56.73312888826643, 51.27889721734183, 47.05922147205898, 49.46111645017351, 44.393604142325266, 39.61715882165091, 37.35660409927368, 27.33134365081787, 13.481642706053597, 3.3880762542997087, 1.0379031236682619, 0.2986074925533363, 1.0123034630502974, 5.406881868839264, 16.34511433328901, 10.400879195758275, 5.1636940496308465, 6.164799622126988, 8.372612306049891, 6.143000951835087, 3.5218086668423245, 10.015351448740278, 16.126935686383927, 25.919860533305577, 35.14101116997855, 42.80241107940674, 46.78433683940342, 55.55914388384138, 54.71997519901821, 55.3818119594029, 53.88460717882429, 55.58377177374703, 52.58274057933262, 53.07478421075003, 50.550441128867014, 51.24858570098877, 50.72649458476475, 51.12920522689819, 49.62056718553816, 49.64868654523577, 49.941198757716585, 53.24343088694981, 49.53756053107125, 52.380634852818076, 49.85546840940203, 52.83487680980137, 49.7252904347011, 53.148129395076204, 46.06419774464199, 51.63395711353847, 36.604485920497346, 40.35030147007534, 50.92095034463065, 49.05729409626552, 52.34255872453962, 48.34630577904837, 51.079153878348215, 49.140252113342285, 46.932534967150005, 40.1305125781468, 42.47012390409197, 43.08226367405483, 47.48136969975063, 52.425930159432546, 52.3213597706386, 51.44112375804356, 52.527141094207764, 50.64397430419922, 49.70533868244716, 49.40054900305611, 50.95711571829659, 50.14660835266113, 52.336937631879536, 51.13186291285923, 50.00514302934919, 45.54256520952497, 39.82931859152657, 33.808544703892295, 25.766741343906947, 17.555830989565166, 12.380330647741046, 8.795243433543614, 6.311051820005689, 10.034328716141836, 17.305040972573416, 16.713888236454554, 16.726639917918614, 9.817808951650347, 9.115547571863447, 3.915111013821193, 1.1368252784013748, 0.5025734092508043, 0.770038940012455, 4.497475581509726, 10.38561052935464, 22.473899705069407, 34.480703013283865, 40.43550375529698, 47.77039391653878, 41.117889813014436, 50.38613707678658, 50.64312662397112, 35.420999254499165, 10.93652537890843, 1.063880484019007, 0.23615154677203723, 0.10055465570517949, 0.10026513159807239, 0.09058570063539914, 0.15922938367085798, 0.09513664857617446, 0.20419070177844592, 0.14189632875578745, 0.1326424546007599, 0.06043534991996629, 0.10506160743534565, 0.17725717702082225, 0.11511474155953952, 0.07963290371532951, 0.1428233432982649, 0.09453927991645676, 0.287074975669384, 0.07165906551693167, 0.13029850966164044, 0.10292625094630889, 0.17861883395484515, 0.11967457830905914, 0.08426199174885239, 0.10683267882892064, 0.18608156565044606, 0.13605730421841145, 0.18149989364402636, 0.15182067693344184, 0.09712550256933485, 0.1380271999431508, 0.13890544138848782, 0.11000905052891799], [0.05081807955035141, 0.044486292704407654, 0.034240522488419495, 0.017750820444364632, 0.045881340346698246, 0.05932724116636174, 0.06911537343902246, 0.035153739021292756, 0.020908181289477006, 0.034121639760477204, 0.02602486967641328, 0.03601886099204421, 0.0036537601013800925, 0.02968563904453601, 0.019391952381868447, 0.05231374715055738, 0.05384047129856689, 0.008739613312562662, 0.04652023195688214, 0.04543597710185817, 0.03316001653937357, 0.02658153641303735, 0.03457609198189207, 0.04436435656888144, 0.08155319174485547, 0.020688911001863222, 0.09115066246262618, 0.01604755505520318, 0.060106009377964904, 0.07049077070717301, 0.059915327467024326, 0.009319743790131594, 0.05517562126208629, 0.0288612088188529, 0.08681896275707654, 0.03416674876851695, 1.0829950869083405, 9.606152057647705, 25.54486104420253, 38.85805075509207, 49.816294465746196, 37.188721724918906, 27.859476225716726, 15.713891335896083, 26.939235959734233, 26.622778517859324, 11.528548376900808, 12.219349571636744, 3.826851955481938, 0.7126529536076954, 0.18088659298207077, 0.06314383779785462, 0.28384121347750935, 1.539322371993746, 2.27510273030826, 5.910850346088409, 1.4837414515869958, 3.0474718681403568, 1.1313545491014207, 1.7592734609331404, 3.6142748594284058, 7.686739121164594, 16.854627473013743, 24.815763984407695, 35.09541709082467, 40.762010029384065, 46.59262909208025, 45.96220513752529, 51.80954851422991, 50.63944755281721, 50.389048371996196, 49.4382256099156, 47.386797768729075, 47.38736752101353, 47.96494000298636, 46.092021805899485, 52.0710300718035, 48.446818419865195, 49.677434716905864, 48.5802446774074, 47.547985553741455, 46.493040561676025, 48.30542605263846, 45.43613617760794, 48.11589309147426, 45.57837969916207, 53.05962324142456, 48.00538894108364, 54.05642918178013, 30.669345106397355, 33.553511074611116, 52.70713765280587, 47.140407698495046, 49.50257287706648, 49.02932412283761, 46.975009305136545, 45.04067250660488, 44.285625662122456, 36.992428166525706, 36.729098388126914, 41.99928617477417, 46.93210417883736, 47.152976989746094, 49.88451535361153, 50.51720789500645, 49.837097372327534, 48.01291036605835, 47.64013951165335, 48.683956963675364, 48.930836881910054, 50.46984897341047, 48.40868670599801, 47.41194677352905, 43.908289841243196, 38.612949575696675, 32.694543497903005, 26.683966091700963, 18.892004319599696, 11.805474042892456, 6.680103651114872, 3.5204062163829803, 1.8958861189229148, 4.4173697999545505, 5.957242165293012, 2.5272087795393805, 3.9055424758366177, 3.3118922965867177, 0.625670843890735, 1.214856805545943, 0.2655886486172676, 0.18996073678135872, 0.6427219403641564, 3.051010455404009, 7.636202267238072, 13.193856137139456, 24.838439430509293, 33.037791456495015, 38.242224965776714, 34.99600921358381, 46.17111662455967, 39.52976090567452, 19.178065129688807, 3.2857355858598436, 0.21157802109207424, 0.04821137871061053, 0.034124706738761494, 0.0725076821233545, 0.03027791190626366, 0.06436430516519717, 0.03955833035122071, 0.06735245125102145, 0.0683190379557865, 0.05959059417779956, 0.04099621390923858, 0.02944053862509983, 0.05723520235291549, 0.07476202651326146, 0.005680614600091108, 0.0233730072421687, 0.02869771241343447, 0.030902961402067115, 0.045668314277593575, 0.06753497717103787, 0.014796689319025193, 0.05268291091280324, 0.003092118218773976, 0.045265037167285166, 0.0322734664327332, 0.06413766089826822, 0.008795390587433108, 0.034431492776743004, 0.03122988296672702, 0.09706133351262126, 0.06831736197429043, 0.015710653936756507, 0.05720510932483843, 0.020160737647009746, 0.05997848550656012, 0.039256012466337, 0.030367308894970586, 0.027438675419294407, 0.05678533363555159, 0.06438112604830946, 0.03348146571910807, 0.028071909743760313, 0.08469666806714875, 0.013748317092124904, 0.03821167243378503, 0.02043837890960276, 0.047351644307907136, 0.0015276355053564267, 0.05695287750235625, 0.022617753661636795, 0.025836304794730883, 0.0529354039712676, 0.03291905179087605, 0.02185991995169648, 0.057660704877759726, 0.001366353456562917, 0.038647417444735765, 0.05280901325334396, 0.024374501180968115, 0.03228289806949241, 0.06038401196045535, 0.038829342861260684, 0.002979705322234492, 0.07685403818530695, 0.03608689769836409, 0.10126966198108026, 0.04567289438896945, 0.08380679653159209, 0.001799239926705403, 1.5916882306337357, 11.701914616993495, 30.78947946003505, 48.01432432447161, 54.02558612823486, 41.69110230037144, 31.984534876687185, 17.720664841788157, 30.602923801967076, 29.55583027430943, 17.381924527032034, 13.567441667829241, 4.310632875987461, 0.6427367052861622, 0.08739172095166785, 0.08758689476443188, 0.5425149117197309, 3.424672416278294, 4.83350088766643, 4.4944400872503, 4.001760261399405, 2.4323710799217224, 3.2632071375846863, 2.393870025873184, 4.353833734989166, 10.187810948916844, 18.699903999056133, 27.614274297441753, 38.71162789208548, 42.57658767700195, 46.83889409473964, 49.85528080804007, 52.99738475254604, 50.490398270743235, 52.07452848979405, 49.955063888004844, 47.75751543045044, 47.64263391494751, 49.361475808279856, 48.326183795928955, 52.40744795118059, 48.533771651131765, 50.0496358190264, 49.417255946568076, 49.01581335067749, 49.12741879054478, 49.84786360604422, 47.04112488882882, 51.18307113647461, 48.54608038493565, 53.92465312140328, 48.85808229446411, 52.86184971673148, 32.87969214575631, 35.358382088797434, 52.63283709117344, 48.644220215933665, 51.035376753125874, 50.13124588557652, 49.768195561000276, 47.25371544701712, 47.14936392647879, 39.70943784713745, 37.62611082621983, 43.73862177985055, 48.39230285372053, 49.108300822121755, 51.220428126198904, 49.525998728615896, 51.7969514301845, 49.35286699022566, 49.7345871244158, 49.38373783656529, 50.12412050792149, 51.19716208321707, 49.524428435734336, 48.6012282371521, 46.71871110371181, 41.69868278503418, 35.36045265197754, 28.473314830235072, 21.790045840399607, 15.187098026275635, 8.489703348704747, 4.21457142489297, 2.5841117032936642, 3.626890833888735, 4.317905468600137, 6.498690094266619, 4.742558087621417, 4.472202811922346, 1.3417562076023646, 1.7023291736841202, 0.22133485254432472, 0.22075645572372846, 0.45847601549965994, 3.9174951144627164, 8.91373974936349, 16.7080500125885, 28.849365234375, 36.124188218797954, 42.36947577340262, 39.54786096300398, 50.81644596372332, 44.9970760345459, 22.523634910583496, 4.1956427948815485, 0.5052412460957254, 0.04348758415185979, 0.057292633556893895, 0.021382429770060947, 0.04348471394873091, 0.058717306038098674, 0.10455402931464569, 0.004118872107937932, 0.07131394903574671, 0.0711886507592031, 0.035820715195898495, 0.014744995128629463, 0.0762631291789668, 0.017800706338935664, 0.06929770258388349, 0.06772003402667386, 0.06962151985083308, 0.04716728973601546, 0.04561819428844111, 0.08616929261812142, 0.02045275197763528, 0.04972102752487574, 0.0311368151035692, 0.012395224118206118, 0.026197580587384955, 0.019865023604195033, 0.01767803229657667, 0.03014839653457914, 0.04074224164443357, 0.040718347033751864, 0.03263791098392435, 0.07754704635590315, 0.0430681341593819, 0.13934564776718616, 0.21164504678121634, 0.07846846976982695, 0.15206078333514078, 0.11747558202062335, 0.1456176997827632, 0.15137421446187155, 0.06867147582982268, 0.12556529364415578, 0.10686032913093056, 0.07535262339349304, 0.10724630699093853, 0.11038003276501383, 0.19472037495246955, 0.1577709133603743, 0.13081501051783562, 0.1511003305869443, 0.09586398383336407, 0.13213287480175495, 0.18011423014104366, 0.15263571962714195, 0.08419914583542518, 0.07589434539633137, 0.10385247838816472, 0.16662090990160192, 0.09988118255777018, 0.22222479193338326, 0.2047536008592163, 0.12031200767627784, 0.09426256655050175, 0.1436739955097437, 0.1033647677728108, 0.1122821428413902, 0.10358414492969002, 0.21359412505158357, 0.17288796789944172, 2.013393836362021, 13.151467783110482, 36.23559216090611, 55.658680302756174, 61.691026415143696, 47.603630202157156, 37.132726192474365, 24.38258375440325, 37.58272280011858, 36.94423198699951, 18.007463897977555, 17.45806462424142, 5.606798478535243, 1.3521118462085724, 0.2794436008802482, 0.7805916251880782, 0.85146840768201, 4.5883914572852, 6.305792033672333, 13.863282067435128, 6.92373137814658, 5.960873467581613, 3.144308477640152, 2.97573475752558, 6.355619737080165, 11.405146632875715, 21.225947652544292, 28.959198883601598, 40.116539750780376, 43.92099462236677, 49.632302692958284, 50.24913944516863, 53.456803117479595, 49.63031203406197, 52.16082511629377, 49.06088631493704, 47.98314775739397, 46.95141322272164, 49.647043296269004, 47.94631535666329, 51.868094035557334, 49.33835915156773, 50.65737737928118, 50.95824827466692, 50.37631927217756, 51.631789275578086, 50.953311579568044, 48.433776651109966, 52.55611508233206, 49.126171588897705, 54.94881064551217, 50.479816164289204, 53.264556884765625, 37.68266568865095, 37.782097884586875, 51.34200075694493, 49.45362976619175, 51.07503359658377, 50.78450162070138, 52.36986167090279, 49.47061116354806, 48.79408243724278, 41.51633078711373, 39.652775287628174, 44.60553114754813, 50.696870940072195, 51.1829252243042, 51.45345681054251, 49.501933642796104, 52.416084562029155, 50.22158636365618, 50.95392649514334, 51.68293843950544, 50.13585254124233, 53.06004013334002, 49.44973530088152, 48.39638144629342, 51.0108322416033, 45.6824289730617, 36.07348026548113, 30.559591361454554, 22.959412029811315, 16.161831276757376, 9.120519007955279, 5.613302426678794, 5.6803929294858655, 12.172709788594927, 12.327044912746974, 9.973142879349844, 10.441869224820818, 10.944512333188738, 3.0643672815390994, 1.9777695536613464, 1.0640583144766944, 0.4857113797749792, 1.2702028985534395, 4.771230697631836, 11.463259628840856, 21.965506962367467, 34.45326805114746, 43.47342988422939, 48.48346321923392, 47.84827627454485, 58.428173201424734, 50.47841262817383, 27.249010971614293, 4.922974143709455, 0.7562643534370831, 0.11928625271788665, 0.15784453440989765, 0.16778647021523543, 0.12078040039965085, 0.1777136003864663, 0.18125399255326816, 0.16168071356202873, 0.19008009109113896, 0.10859538388571569, 0.23107691907456943, 0.06327728527997221, 0.21949922532907554, 0.14536485049341405, 0.12765223665961198, 0.1430556465472494, 0.1142328360251018, 0.1624653171747923, 0.12432894855737686, 0.18617263862064906, 0.059425018062548976, 0.18205389034535202, 0.11643711131598268, 0.13586614733295782, 0.12454986598874841, 0.1942663128886904, 0.12089196512741701, 0.15219517398093427, 0.14131466139640125, 0.1532955135085753, 0.07594696578702756, 0.15466805414429732, 0.2795816149030413], [0.01840511310313429, 0.02312231230150376, 0.02261813703392233, 0.012549169295068299, 0.00955158902797848, 0.02123334544843861, 0.022854647200022424, 0.021447136565776806, 0.11542964966169425, 0.025347437277170162, 0.05035765961344753, 0.048782569489308765, 0.0276804832475526, 0.03832299628161958, 0.04607713841167944, 0.00832900293504021, 0.04156482286219086, 0.031356134584971836, 0.010968681424856186, 0.021470025248293365, 0.06127056545977082, 0.014700266100200159, 0.05707350067262139, 0.018132718612572978, 0.020806339968528067, 0.06384000794163772, 0.013052385283767112, 0.030838449685169116, 0.029871805304927484, 0.03912223589473537, 0.0514027019297438, 0.01573087088763714, 0.04352833017972963, 0.048667072651109526, 0.04095538306449141, 0.021124562714248896, 0.08106260414102248, 4.232296279498509, 17.16238750730242, 37.2120954649789, 53.07164362498692, 37.43217618124825, 30.62297282900129, 29.50817605427333, 19.925880636487687, 24.26370702471052, 24.791325432913645, 16.36984818322318, 7.394230382783072, 1.4809188544750214, 0.18724989438695566, 0.08745232769953352, 0.32161096962434904, 0.29623981245926445, 4.677608064242771, 1.7334403842687607, 4.623232330594744, 2.798833187137331, 3.1197993585041592, 3.229193534169878, 2.797993323632649, 6.25958434173039, 10.901977198464529, 20.58174889428275, 28.33061272757394, 34.13767392294747, 43.398691586085725, 47.17784806660244, 48.494917324611116, 55.70353439876011, 52.08071238654, 48.96848569597517, 50.573276383536204, 47.765804631369456, 49.20652403150286, 49.96072666985648, 47.43944079535348, 48.92055354799543, 52.88000883374895, 48.704881463732036, 49.28291252681187, 48.01063483101981, 47.9445470401219, 47.67442192350115, 48.20254407610212, 48.16133778435843, 50.854577677590505, 45.71679476329258, 52.44497864586966, 31.644118309020996, 31.017640931265696, 54.026597091129844, 47.395132132938926, 50.235482760838096, 47.19244623184204, 48.436177253723145, 44.55565002986363, 43.709182262420654, 36.28149543489729, 40.783740520477295, 43.04919024876186, 48.43197706767491, 48.98218059539795, 51.435203892844065, 50.487497397831504, 51.64333718163626, 49.35233545303345, 50.23074408939907, 47.890563011169434, 49.63292455673218, 49.71270029885428, 50.627875328063965, 45.58061007090977, 39.49275827407837, 33.68370989390782, 30.04059566770281, 21.49032834597996, 14.070794360978262, 9.003949948719569, 5.375235864094325, 1.5026468485593796, 2.373592359679086, 3.3946047382695332, 2.3566083567483083, 3.91909841128758, 2.3579966936792647, 2.482145586184093, 0.6260439295853887, 1.2432961080755507, 0.3925562570137637, 0.05409804319164582, 1.138287982770375, 3.827992762838091, 9.627493449619838, 20.64408118384225, 23.1408486025674, 25.57791015080043, 36.13572570255825, 34.064558029174805, 39.807334491184776, 27.22353192738124, 12.965337702206202, 1.7109483054706027, 0.2364830518407481, 0.04603341022240264, 0.01947194487521691, 0.050559303257614374, 0.07818572422755615, 0.05111659763913069, 0.08077496636126723, 0.03903704921581915, 0.03349904656144125, 0.10400297745530095, 0.06311068457684346, 0.04455026159329074, 0.03095499485997217, 0.0494019566103816, 0.012547198150839125, 0.07764985798192875, 0.03779551672882267, 0.0358478735600199, 0.06091758475771972, 0.02494034680005695, 0.045692453160881996, 0.06392297241836786, 0.03298935480415821, 0.04503894590639642, 0.023225999237703424, 0.048745002398001294, 0.011346128403342195, 0.010666505184157618, 0.07787664474121161, 0.07852081196116549, 0.05129389205415334, 0.04225746801655207, 0.022580040685300316, 0.038838289345481565, 0.058305611700883934, 0.011372776169862066, 0.07622815069875546, 0.023601588726575886, 0.051746223853634934, 0.008685438228504998, 0.018299570373658623, 0.05490575431446944, 0.009066289756447077, 0.03605234330253942, 0.10621318314224482, 0.04277396208739706, 0.03800177780379142, 0.027857898102541055, 0.030280486946659427, 0.051567436661571264, 0.05827372055500746, 0.006091619800177536, 0.01810901568803404, 0.011472169675731232, 0.044343125208147934, 0.008163867867551744, 0.024689534812101295, 0.012073956446589103, 0.03457166454089539, 0.062402232949222834, 0.03561180104900684, 0.016884544964081476, 0.04897074082068034, 0.05615431642425912, 0.05332700688658016, 0.03385749286306756, 0.0157993910501578, 0.01042996533215046, 0.1025880283809134, 0.2564697079360485, 5.826335498264857, 21.512986421585083, 43.23070151465279, 58.21398455756051, 42.59293678828648, 31.871640545981272, 29.88120746612549, 24.30379639353071, 26.251346928732737, 20.636620555605205, 21.00557163783482, 7.592944519860404, 1.8961210548877716, 0.09681674199444906, 0.10992815558399473, 0.359889627035175, 0.6712499409914017, 3.136164103235517, 4.023526796272822, 4.742198084081922, 3.445887003626142, 4.718695368085589, 4.169292185987745, 3.3873564643519263, 6.881733860288348, 14.188096455165319, 21.90091824531555, 31.21179791859218, 36.97997352055141, 45.52334301812308, 48.97087935038975, 51.41976499557495, 55.17027752740042, 50.78745807920183, 48.89444916588919, 50.13425098146711, 48.83831466947283, 48.99259941918509, 49.84190552575247, 49.31866795676095, 50.506295749119346, 52.85764953068325, 50.04796825136457, 51.218319347926546, 48.08205883843558, 48.7315799168178, 49.93369122913906, 51.35536214283535, 49.48437901905605, 51.23189960207258, 47.66025802067348, 51.9001738684518, 34.089144229888916, 34.26634413855416, 53.1706554549081, 47.18039458138602, 51.01055083956037, 49.72030857631138, 50.90706784384591, 47.147831848689485, 46.00852877753121, 38.71634224482945, 41.07968166896275, 45.502519266945974, 50.8544282913208, 51.39892039980207, 52.03630992344448, 50.29688399178641, 52.193825585501536, 50.31292390823364, 51.87618521281651, 49.25347300938198, 51.166603905814036, 51.526735986982075, 51.49292605263846, 46.91101292201451, 45.01967505046299, 38.720243658338276, 32.003204686301096, 24.825144052505493, 16.161638464246476, 10.500196746417455, 6.597910804407937, 4.3195048570632935, 5.364425769874027, 6.03428943668093, 4.603178092411586, 5.514292333807264, 4.367089160851069, 2.5329264955861226, 1.0427705539124352, 1.2268834859132767, 0.31916601796235355, 0.12660776770540647, 1.0082697080714362, 4.330804365021842, 11.329049961907522, 22.315623215266637, 26.087998253958567, 30.49781492778233, 43.512176513671875, 38.72532973970686, 47.13945926938738, 33.41009678159441, 16.114250012806483, 2.179066466433661, 0.324136422680957, 0.023872710963977233, 0.03531749666269336, 0.03577970114669629, 0.05713374101157699, 0.0663303400256804, 0.015071540106354015, 0.026892648111762743, 0.043512903686080656, 0.028485096858016083, 0.019494589285126755, 0.010036455733435494, 0.02429584031259375, 0.05661841741363917, 0.0783556904643774, 0.05977970188749688, 0.018230449707646455, 0.03449511561276657, 0.028786183201840947, 0.05262885202786752, 0.025938599037804773, 0.022528909678970064, 0.04068095636154924, 0.05477749423256942, 0.034578551671334674, 0.009561072403032864, 0.009094707651196845, 0.04662381032747882, 0.076208703885121, 0.04793766446943794, 0.008246270008385181, 0.013048850116319954, 0.009479305540610636, 0.10199516519371953, 0.13735182689768927, 0.1481969335249492, 0.08605546158339296, 0.1162943746894598, 0.09350744528429848, 0.1061166479651417, 0.09254748786666564, 0.2460144061063017, 0.1386254642690931, 0.15725153551570006, 0.1570133561534541, 0.1165530186678682, 0.16655377564685686, 0.06065920540796859, 0.09285628915365253, 0.170087993144989, 0.22291076369583607, 0.10447504783847503, 0.09827775681125266, 0.13742733427456447, 0.10312130262276956, 0.16610776100839886, 0.11154781188815832, 0.10550481293882642, 0.15950676878648146, 0.10333227273076773, 0.13154218292662076, 0.06171459199062415, 0.09730094458375659, 0.2400434607906001, 0.08954081098948206, 0.1563145193670477, 0.11884326434561185, 0.16873902481581482, 0.17275486647018365, 0.45664223389966146, 6.199478949819293, 25.569789443697246, 50.99781479154314, 64.98133196149553, 49.19777972357613, 41.655451093401226, 38.95384904316494, 30.1500506401062, 34.795789922986714, 32.916896275111604, 21.12520224707467, 10.33897682598659, 2.3559341643537794, 0.39090966965470997, 0.3943322817129748, 1.137679364000048, 2.7324205679552893, 11.207845585686819, 7.29038781779153, 10.05602707181658, 8.304678899901253, 8.075175557817731, 5.883491379874093, 4.9690359234809875, 8.585842098508563, 13.254348022597176, 23.252374138150895, 31.550995077405656, 38.0667655808585, 45.80508204868862, 49.82022019795009, 53.03870221546718, 56.17470564161028, 51.04900564466204, 49.269634519304546, 50.1996613230024, 48.81204700469971, 49.19142212186541, 50.286857741219656, 48.7653238432748, 51.81997081211635, 54.07867383956909, 50.97804021835327, 52.585151604243684, 50.325409821101594, 50.73617689950125, 52.52537972586495, 53.685582978384836, 50.776320116860525, 52.76573528562273, 48.673847334725515, 50.967444215502056, 37.51586723327637, 37.634313174656455, 52.39719935825893, 48.39286913190569, 53.1320686340332, 51.34978968756539, 52.573061738695415, 48.580557346343994, 48.87755114691598, 39.91880096708025, 43.382759366716655, 47.837054933820454, 52.4544038772583, 52.19040707179478, 52.172077723911826, 48.62423372268677, 53.38842242104666, 50.66272749219622, 53.042509828295024, 49.53860970905849, 51.41101721354893, 52.398085253579275, 52.39182145254952, 48.312471526009695, 47.634726864951, 41.050412382398335, 33.99809850965227, 26.049501759665354, 17.69352170399257, 11.005645189966474, 7.610691956111363, 4.371943346091679, 6.442635936396463, 7.250984149319785, 8.33393429006849, 13.031506265912737, 9.718664237431117, 8.125483121190753, 3.7602213365691046, 4.060157264981951, 0.9125431818621499, 0.22447587256985052, 1.651275981749807, 5.573365918227604, 14.188242367335729, 27.47748511178153, 33.45253985268729, 36.33130707059588, 50.05657359531948, 43.72446829932076, 53.13877017157418, 37.97595957347325, 19.657159055982316, 2.629166211400713, 0.5117045907037598, 0.15249583284769738, 0.13196450312222752, 0.12891636097005435, 0.3019745190228735, 0.2535074140344347, 0.1243668379528182, 0.1442242195563657, 0.19400472406830105, 0.23688374033996037, 0.1255822027368205, 0.16531586992953504, 0.07414662239274808, 0.1513777021318674, 0.1134938910337431, 0.12389436044863292, 0.08919114153832197, 0.18564024647431715, 0.1454820063497339, 0.07404677596475397, 0.20240947950099195, 0.14927002308624132, 0.17127260672194616, 0.15775978538606847, 0.16467170949493135, 0.04469502364684429, 0.11431462663624968, 0.1306269070399659, 0.1980845108628273, 0.14389065174119814, 0.12542048070047582, 0.13127827351646765, 0.13110048377088138], [0.027347381925210357, 0.021950516251048872, 0.07897498259054762, 0.029713886457362344, 0.04303114043016519, 0.0333461047682379, 0.08721121028065681, 0.03481992354084339, 0.029377635036196028, 0.07304424726005111, 0.06410229565309626, 0.06992179195263556, 0.06180077272334269, 0.029296180299882377, 0.0427026548422873, 0.06121974318687405, 0.028959338553249836, 0.026055887208453248, 0.024311426261972104, 0.04251377444182124, 0.016376534277307134, 0.00751908657340599, 0.022859266327161874, 0.024763766543141434, 0.04247683499540601, 0.010494937604692365, 0.05478470705981765, 0.01076372737796711, 0.013985563468720232, 0.00746068506435092, 0.034409942504550727, 0.06624641202922378, 0.02646015497988888, 0.047518275545111725, 0.048964851136718474, 0.06651691679975816, 0.04415059428928154, 0.8903602979012898, 9.278586183275495, 26.352234772273473, 43.54655967439924, 41.13092810767037, 35.41365500858852, 16.707614013126918, 18.674829687391007, 20.060545410428727, 23.729885612215313, 13.831243923732213, 7.555043833596366, 3.3994267880916595, 0.35188815210546764, 0.17168578026550158, 0.104400456483875, 0.4441965717290129, 0.9293365435940879, 2.981134593486786, 2.7085391751357486, 1.7971088992697852, 3.5540522166660855, 1.8399233732904707, 0.7720133140683174, 2.812072762421199, 8.161331483295985, 14.02911819730486, 25.76268880707877, 29.263363225119456, 37.86010183606829, 45.358705452510286, 49.13931063243321, 48.87251022883824, 54.76333195822579, 51.260286467415945, 49.41004719052996, 47.79272542681013, 50.10524225234985, 47.16822133745466, 51.61800404957363, 49.38150746481759, 51.77561003821236, 47.517733097076416, 46.59173624856131, 45.98332071304321, 47.598999227796284, 46.18254293714251, 46.1393529347011, 46.80724157605852, 50.487473079136436, 49.47535330908639, 52.19466284343174, 33.06840869358608, 32.79616437639509, 52.96710797718593, 49.287296840122764, 48.68657990864345, 43.30669396264212, 44.18686744144985, 41.74174771990095, 39.68592514310564, 37.7771646635873, 42.187019552503315, 46.96885667528425, 48.60969809123448, 48.89458812986101, 51.45539883204869, 49.63909803118025, 48.7726229258946, 47.04187876837594, 50.38572365897042, 49.954834597451345, 50.48815747669765, 48.68319961002895, 49.02927895954677, 46.467398234776084, 35.65376738139561, 31.147794587271555, 25.243632316589355, 17.859484638486588, 10.390251057488577, 5.684751621314457, 4.094021916389465, 3.6130754266466414, 2.2747060315949574, 4.477483442851475, 2.74552269918578, 4.104924074241093, 3.1356679584298814, 1.8932838014193942, 0.4492791789983, 0.8224038215620177, 0.18485241303486483, 0.21294027513691358, 0.77574693943773, 4.734608045646122, 10.61854020186833, 18.882975135530742, 23.353706666401454, 29.290516785212926, 34.915413584027974, 32.01881728853498, 38.10593952451433, 25.59624818393162, 8.523026040622167, 0.8605789073875972, 0.0388114634635193, 0.021645903221464584, 0.026170198306707398, 0.01836644339242152, 0.029224411650959934, 0.037544679295803816, 0.07295506061719996, 0.0496954467546727, 0.01775104775359588, 0.03339358525616782, 0.006182535435073078, 0.04337782093456813, 0.040537799043314796, 0.037379191390105655, 0.08001991294856582, 0.02357459151452141, 0.041824766235159974, 0.04493499094886439, 0.02670683977859361, 0.007487201364710927, 0.017834192042105963, 0.042017663562936444, 0.04998858406075409, 0.041523954698017666, 0.04884717620110937, 0.042571181897073984, 0.03419147797727159, 0.0680573812818953, 0.01962631837730961, 0.03661963929023061, 0.011524918139912188, 0.03152208050180759, 0.0218924675802035, 0.06292777189186641, 0.056306332017162015, 0.06213247456720897, 0.03518277353474072, 0.016823261377534697, 0.019107400240110498, 0.027933931344055703, 0.022287251128415977, 0.06346407918525593, 0.07553990584399019, 0.05504166487870472, 0.03177759304110493, 0.01696454593911767, 0.03420771532026785, 0.03999275900423527, 0.03032815403171948, 0.008770628300096308, 0.021290018389533674, 0.06440285952495677, 0.051200919185898135, 0.04996544601661818, 0.024847423125590597, 0.08832146320492029, 0.038077807652630975, 0.045537736998604875, 0.011145313420066876, 0.16372226258473738, 0.016628935733543973, 0.0403178587023701, 0.03268565610051155, 0.007441026208523128, 0.0644911505015833, 0.029772155652088777, 0.04372942421053137, 0.04515342494206769, 0.04077198861965111, 0.05725373314427478, 1.4121193119457789, 11.912473695618765, 32.16802985327584, 50.57596186229161, 46.72162239892142, 40.62368876593453, 22.280991656439646, 23.459023986543926, 28.661571059908184, 25.999236754008702, 15.7898542540414, 10.029394626617432, 2.833831480571202, 0.27316340644444737, 0.027582994728748287, 0.10742318071424961, 0.44901954435876434, 1.2962168455123901, 2.0878876447677612, 3.5408773464815955, 2.5818396423544203, 4.111149225916181, 2.5648519481931413, 2.385743021965027, 4.845784434250422, 8.389646683420453, 18.29343785558428, 28.138646159853252, 31.164397307804652, 40.15750980377197, 46.87042849404471, 49.641786984034944, 50.67751325879778, 54.491605281829834, 50.99326719556536, 49.863834040505544, 48.150401319776265, 49.23988928113665, 49.69461413792202, 53.14697599411011, 49.79211820874895, 52.563997813633506, 50.301674774714876, 49.98813383919852, 48.18671955381121, 51.25540535790579, 48.362936292375835, 48.21543993268694, 48.76388209206717, 52.31957755770002, 50.95954063960484, 51.10709605898176, 36.04787615367344, 35.016256264277864, 52.36951426097325, 50.29748848506382, 51.005690574645996, 45.43752234322684, 46.74145950589861, 44.64639697756086, 41.67200517654419, 37.912991523742676, 43.76457330158779, 47.795518602643696, 51.41760063171387, 50.22672803061349, 51.17623063496181, 51.291362285614014, 49.81065252849034, 47.22389725276402, 50.876759801592144, 49.8569518498012, 50.78424106325422, 49.44541699545724, 50.77571562358311, 47.29698187964303, 40.71075316837856, 34.53091417040144, 28.523347071238927, 20.172878674098424, 12.71241979939597, 7.4861845799854825, 5.377839267253876, 5.091162238802228, 5.6890586359160285, 7.092788432325635, 5.7591234019824435, 6.581147841044834, 3.695425042084285, 2.311007980789457, 1.186975421650069, 0.528990731707641, 0.3901604584285191, 0.3978821055165359, 1.1003093464033944, 4.590136757918766, 12.093590651239667, 27.33968322617667, 26.571716206414358, 30.459349700382777, 39.936324323926655, 36.43082959311349, 43.452262197222026, 28.776282344545635, 10.678864462035042, 1.2990675611155373, 0.011688774168890501, 0.04644613254017063, 0.08292726586971964, 0.06963037473282643, 0.06503352389803954, 0.06559283352856125, 0.04488823988607951, 0.019345486303791404, 0.03007942684260862, 0.02247252511525793, 0.0077973317321656, 0.013272957510447927, 0.03369310079142451, 0.03792157835726227, 0.02832913558397974, 0.039759115648588965, 0.030443973174052577, 0.04878678319177457, 0.014998361800930329, 0.0462444312205272, 0.03122645297220775, 0.045098992862871716, 0.03738455181675298, 0.01163120980241469, 0.017583911007802402, 0.03399610738935215, 0.04189535423314997, 0.020347307635737315, 0.025293804172958647, 0.044399531824248176, 0.03995515798617687, 0.04012299023036446, 0.016011380657021488, 0.10102346912026405, 0.1528952864131757, 0.15824484292949947, 0.19839293217020376, 0.10577485630554812, 0.11300280131399632, 0.21802022254892758, 0.12553291395306587, 0.20702468470803329, 0.17081828681485994, 0.16217440207089695, 0.07093282948647227, 0.12098245455750398, 0.14859558641910553, 0.10911230543362242, 0.14427018351852894, 0.11224185143198286, 0.13789928252143518, 0.13672192926917756, 0.1871360633522272, 0.09146142471581697, 0.07559676707855292, 0.22017714966620716, 0.13712522334286145, 0.19753215621624673, 0.14709157283817018, 0.23360818039093698, 0.11826382258108684, 0.09442160837352276, 0.09227449287261281, 0.09942103403487376, 0.1782197467982769, 0.08204874622502498, 0.17208319822592394, 0.12372692514743124, 0.21138754274163926, 0.21536624138908728, 1.7527793922594614, 14.360676680292402, 37.36429575511387, 56.45334924970354, 55.38564389092581, 47.249765396118164, 27.369914838245936, 29.11937049457005, 29.256074564797537, 32.31684637069702, 20.60712718963623, 11.21380627155304, 4.478416672774723, 0.5754792828645025, 0.5919263746057237, 0.2644142402069909, 2.359709858894348, 3.7583127532686507, 8.457429834774562, 10.136366486549377, 3.728075930050441, 9.261105384145464, 6.060510635375977, 2.1789162116391316, 5.544429276670728, 11.250557030950274, 16.999363660812378, 29.532303673880442, 32.08514479228428, 41.20951223373413, 48.176769733428955, 51.862153325762065, 51.93574169703892, 55.54941293171474, 50.727262360709055, 50.62462704522269, 48.610340799604145, 48.74704313278198, 49.152178696223665, 52.898807185036794, 49.339185987200054, 53.799870422908235, 52.04247644969395, 51.19656801223755, 49.1772061075483, 52.60244567053658, 50.48051445824759, 47.80705608640398, 50.78493240901402, 52.636227812085835, 51.50393894740513, 49.827071121760774, 39.30791882106236, 39.60920313426426, 51.78530624934605, 52.21111617769514, 53.29756430217198, 48.691589559827534, 47.34454924719674, 47.883573123386924, 42.71967887878418, 40.5259484563555, 46.287106377737864, 50.52346474783761, 51.780355657849995, 52.05414942332676, 51.32472406114851, 50.15782274518694, 50.60988296781267, 48.53086730412075, 52.75455910818917, 51.13226590837751, 52.020759854997905, 49.67796972819737, 50.99534123284476, 48.38195351191929, 43.63387768609183, 36.63692358561924, 30.14776815686907, 20.912344183240617, 14.435738938195364, 7.809933287756784, 6.611045939581735, 7.181441800934928, 4.699877040726798, 12.833833490099225, 9.71895432472229, 12.508646505219595, 7.442469120025635, 5.134635814598628, 2.8274949405874525, 2.142136573791504, 0.7345775599990572, 0.8117794288056237, 1.7036558453525816, 6.82559198141098, 15.479935067040579, 28.629293203353882, 33.762901987348286, 37.960572787693565, 46.77657222747803, 44.36177791867937, 49.98210975102016, 33.834555285317556, 12.4315345287323, 1.845572475876127, 0.09044825658202171, 0.10594041206474815, 0.13793369781758102, 0.2199607648487602, 0.14069890443767818, 0.11629133485257626, 0.19473627981330666, 0.1821080781519413, 0.08334877860865422, 0.22301824364278997, 0.06757887160139424, 0.2656140529683658, 0.10400630227689232, 0.1122896270826459, 0.1291819667177541, 0.12359663285315037, 0.1363526705120291, 0.18538906638111385, 0.07652766962668725, 0.12668246084025928, 0.15213082171976566, 0.1558678669056722, 0.1394154690206051, 0.07869905632521425, 0.12693408876657486, 0.08726190363190003, 0.14259166430149758, 0.16430692906890595, 0.09332703639354024, 0.0910680711801563, 0.16116411771093095, 0.11237483751028776, 0.10459140980882303], [0.028812228768531765, 0.07460687948124749, 0.009830633161722549, 0.04020960183281984, 0.028220932997230972, 0.05908840362514768, 0.015002192131110599, 0.05070369550958276, 0.06647140067070723, 0.037278673212443075, 0.08760828897356987, 0.07998775038868189, 0.06226212903857231, 0.01896365429274738, 0.02702365456415074, 0.015260267836440886, 0.078656912515206, 0.018789511672886353, 0.025743236931573068, 0.0613964337057301, 0.01896663475781679, 0.06669317984155246, 0.044198200306189914, 0.05891872237303427, 0.06523072653050933, 0.04759384059746351, 0.03891009192115494, 0.03548659098201564, 0.03012206937585558, 0.03631023071440203, 0.046798326141600094, 0.056485848634370735, 0.021026963933504055, 0.040511624554970434, 0.0280684271627771, 0.0609164380335382, 0.06948844556297575, 0.031186999553548436, 3.6387850642204285, 19.00960431780134, 37.055403164454866, 44.355048588344026, 40.02291972296578, 33.160201345171245, 20.333404643195017, 14.84945900099618, 18.241493122918264, 21.576138598578318, 9.084800056048802, 5.120040689195905, 1.4500588646956851, 0.09391692081200224, 0.05170455841081483, 0.1222686448267528, 0.8354963447366441, 1.2154110329491752, 1.7148972707135337, 3.0045832438128333, 4.1409474440983365, 2.0247081092425754, 2.739776973213468, 1.246846854686737, 4.879117548465729, 10.854547926357814, 16.96455144882202, 23.384971823011124, 33.257014070238384, 39.835829053606304, 45.089692047664094, 44.43235771996634, 47.214385168892996, 49.391179357256206, 52.966458320617676, 50.987587043217246, 51.23498460224697, 45.96263939993722, 44.79546710423061, 49.724102292742046, 52.277499267033164, 49.50185373851231, 49.732825756073, 48.09599345070975, 46.6275646345956, 45.58903823580061, 47.62363059180123, 47.49666963304792, 50.75790044239589, 48.5353593145098, 50.346042496817454, 33.344894886016846, 33.259237493787495, 51.977205072130474, 47.99301767349243, 48.33249623434884, 45.02185331072126, 45.360901083265034, 40.390319619859966, 42.6908403805324, 43.27336345400129, 47.124663080487935, 46.98217984608242, 50.31668635777065, 50.08120148522513, 49.31379379544939, 50.1106618472508, 50.93878289631435, 48.65068204062325, 49.43206603186471, 49.99958447047642, 49.899096148354666, 50.7867146219526, 47.59564324787685, 41.282079219818115, 32.92018624714443, 27.02510527202061, 21.25154307910374, 16.523055962153844, 8.68287021773202, 4.5589601908411295, 2.8476275631359647, 5.060456412179129, 9.103849411010742, 6.756404859679086, 4.672303114618574, 6.0851185492106845, 2.429656505584717, 1.4902552792004176, 0.517177871295384, 0.3750795562352453, 0.4076559139149529, 0.24308071924107416, 2.0595652673925673, 5.5354765227862766, 15.224458490099225, 21.210859639304026, 19.041833536965505, 33.23660026277815, 35.02636241912842, 38.84680509567261, 36.7271911076137, 21.61887870516096, 6.033006191253662, 0.22261398604937963, 0.05342429523755397, 0.059762148186564445, 0.01667887930359159, 0.019687093062592403, 0.02066336076573602, 0.005846373495712344, 0.018858695103387748, 0.020888340925531726, 0.02414330903307668, 0.08734943464930568, 0.07802678418478795, 0.01225490986169981, 0.052032752228634696, 0.055673788102077584, 0.03450582628803594, 0.0523485797457397, 0.046526603400707245, 0.018915753113105893, 0.036061656195670366, 0.05022535885551146, 0.012951783137395978, 0.00910140055098704, 0.024993062185655748, 0.07465451942490679, 0.022283134117190326, 0.07780599567506995, 0.0721721194152321, 0.06041778264833348, 0.058883418196014, 0.01821774583575981, 0.026347251841798425, 0.04443940593461905, 0.036493628551917415, 0.018019276039142693, 0.05722000316849776, 0.03298833700163024, 0.1292135321668216, 0.021984526122521077, 0.05900662658470018, 0.015262021849464093, 0.07696389979017632, 0.07839497764195714, 0.04661439565409507, 0.07064181260232415, 0.038411830086261034, 0.08650891296565533, 0.04152951529249549, 0.05700810346752405, 0.04092851647042802, 0.07710237521678209, 0.017133779358118773, 0.009467048653667527, 0.04582002792241318, 0.0245415327538337, 0.03636673232540488, 0.05698048709226506, 0.08309396835310118, 0.07960587766553674, 0.032227085171533484, 0.03392413517992411, 0.009586059455094593, 0.009905802119257194, 0.06031566991337708, 0.03454069280996919, 0.011244677240028977, 0.021412197101329054, 0.02285683886813266, 0.01431760288375829, 0.0515424156827586, 0.02097008573556585, 0.16164552473596164, 4.776335886546543, 21.698675291878835, 43.048533643995015, 49.26095274516514, 43.54633385794503, 31.803860868726456, 23.629668269838604, 19.039615324565343, 23.453321252550396, 20.91390926497323, 9.721276760101318, 6.371986653123583, 1.160884827375412, 0.18045391834207944, 0.1268066463193723, 0.11058835658643927, 0.7655187025666237, 1.5848309014524733, 2.1670886405876706, 3.1805641778877805, 3.6268932223320007, 4.205318161419459, 3.268723790134702, 5.036996253899165, 5.053531663758414, 11.553975309644427, 18.509314911706106, 25.867938382284983, 34.41349308831351, 41.798622199467246, 47.45582117353167, 45.474194935389924, 47.949021680014475, 50.70594528743199, 52.38447720663888, 49.764936855861116, 51.784264019557405, 46.99382850102016, 46.10735648018973, 50.05751507622855, 51.911082540239605, 52.536156381879536, 50.847389766148154, 49.59919452667236, 49.49477699824742, 48.97507953643799, 49.471983432769775, 49.727360997881206, 51.414810929979595, 49.54547800336565, 50.18405219486782, 36.925308568137034, 36.538651738848, 51.33142212459019, 49.45971291405814, 49.53628206253052, 46.27037164143154, 46.552843706948416, 42.523354053497314, 44.53571564810616, 43.62087760652815, 48.96924652372088, 48.00387075969151, 52.143496309007915, 51.032993521009175, 48.63098042351859, 49.66061660221645, 50.781277656555176, 48.872003010341096, 49.51145614896502, 51.19075584411621, 50.59178638458252, 50.509728159223286, 48.85530301502773, 42.98825454711914, 36.96159553527832, 31.061334678104945, 23.53289028576442, 16.857345955712454, 9.124189393860952, 5.569700743470873, 4.422478028706141, 4.630172278199877, 7.72775433744703, 6.048359973090036, 6.400056941168649, 3.4223050347396304, 3.5783930591174533, 2.26030285017831, 1.2291309024606432, 0.20534806538905415, 0.19631463369088514, 0.396082657788481, 1.7310144858700889, 6.475135266780853, 13.835861870220729, 21.225737469536917, 24.30058111463274, 35.865329606192454, 39.96256072180611, 42.64129625047956, 41.0512809072222, 26.39414804322379, 7.341584750584193, 0.26424178374665125, 0.04310059527467404, 0.05177571637822049, 0.01606559899768659, 0.05863274700407471, 0.004503078991547227, 0.09537267698241131, 0.10432097289179053, 0.002327516334064837, 0.046599858041320524, 0.06968100701591798, 0.07916204112448863, 0.06531303961362157, 0.0666939669421741, 0.029104999665703093, 0.0266340499344681, 0.03804005057151828, 0.04071881861558982, 0.021027564436995556, 0.021408080090103403, 0.057943565770983696, 0.02038118858555598, 0.06362724650119032, 0.03386851905712059, 0.060147596789257865, 0.023578608441831808, 0.046535356502447806, 0.04799869869436536, 0.03553199854546359, 0.04054199917508023, 0.020542281280670847, 0.018889261409640312, 0.03297223536563771, 0.02636536194144615, 0.19612285255321435, 0.15234187325196608, 0.12591894609587534, 0.15450992834355148, 0.12930090033582278, 0.13379268002297195, 0.1343405834798302, 0.1616800350270101, 0.17904765451593058, 0.12225450415696416, 0.199143541178533, 0.09485635933067117, 0.14667997349585804, 0.12288790302617209, 0.1381397417613438, 0.14531835727393627, 0.09449434054217168, 0.08003691703613315, 0.08247728180140257, 0.181777794446264, 0.1741148813494614, 0.10151191255343811, 0.099844826651471, 0.17255468506898197, 0.11139907701207058, 0.23221854067274503, 0.13159451154725893, 0.13116388608302387, 0.13806513005069324, 0.18691589230937616, 0.18430841793971403, 0.15300457126327924, 0.0734755444739546, 0.1372967977076769, 0.1261940241924354, 0.2158235197088548, 0.1280262858739921, 0.27699066964643343, 5.704101485865457, 26.63198835509164, 48.07605906895229, 57.02592945098877, 54.73517785753523, 44.34883342470442, 31.32288224356515, 24.404885734830582, 29.19428423472813, 29.544740949358257, 13.630975995744977, 7.625429953847613, 2.075051933526993, 0.34479154433522907, 0.27930623825107304, 1.1571235720600401, 2.070135214499065, 5.403293558529445, 7.557176930563791, 9.484400510787964, 7.899175950459071, 6.796574132783072, 6.098113851887839, 4.680051224572318, 6.489895411900111, 12.59927533354078, 18.73360276222229, 25.88405646596636, 35.22554990223476, 43.254620688302175, 49.25805534635271, 46.03108263015747, 50.28934172221592, 50.24637753622872, 52.02177776609148, 50.32874148232596, 52.33319255283901, 47.98825120925903, 47.08242498125349, 49.50775623321533, 53.4667147227696, 52.081806727818076, 52.884118693215505, 51.24554933820452, 50.71631894792829, 49.232882022857666, 49.393645967756, 51.46985803331648, 51.83117478234427, 50.57560403006417, 49.688788073403494, 39.760496684483115, 39.616495268685476, 51.23943492344448, 51.69285699299404, 51.25489466530936, 48.85317686625889, 48.5387396131243, 45.40476506096976, 47.33003446034023, 47.08439826965332, 51.51683480398995, 49.50243043899536, 53.92336423056466, 51.36572885513306, 49.5147704396929, 49.52900382450649, 50.49619654246739, 51.112244674137656, 49.655294282095774, 51.96847813470023, 51.30283376148769, 51.510501520974294, 49.79768371582031, 46.22030292238508, 40.18174164635794, 36.33154330934797, 26.011767830167496, 19.39666587965829, 10.28734997340611, 6.4529774614742825, 5.74135034424918, 9.929527299744741, 16.99111614908491, 14.040900605065481, 11.501250641686575, 10.870351604052953, 7.878072534288679, 4.712578347751072, 1.5400682176862444, 0.6359552634613854, 1.1785508394241333, 0.7677520598684038, 2.7452979683876038, 8.593661427497864, 20.754545382090978, 29.90261139188494, 31.606149877820695, 43.858853408268516, 45.95531947272164, 50.37662499291556, 46.3088264465332, 28.766165767397197, 8.423230801309858, 0.5176538228988647, 0.1282052562705108, 0.1482722373413188, 0.08764289425952093, 0.10971021692135505, 0.10441615099885634, 0.2061020535017763, 0.16034774508859428, 0.14051594425524983, 0.1394407648061003, 0.19567548084471906, 0.16299692222050258, 0.21682293393782207, 0.18451015997145856, 0.14992486366203853, 0.12761931414050715, 0.09101745925311532, 0.09302109852433205, 0.17274582838373526, 0.1529036866767066, 0.11300012110067265, 0.10038577512438808, 0.14978625252842903, 0.08081286932740893, 0.20575395146650927, 0.13078827623810085, 0.20053309947252274, 0.18148875209902013, 0.1613487878016063, 0.11435622083289282, 0.16308043631059782, 0.10459879226982594, 0.1208020049546446, 0.0939835122387324], [0.04600590241274663, 0.043046186944203715, 0.021184092287772467, 0.055150125308760574, 0.028047027864626477, 0.055309760849922895, 0.03572329792327114, 0.033853313087352684, 0.03385953864614878, 0.09930921824915068, 0.0343775254940348, 0.04425243561023048, 0.026460097304412296, 0.009532537460992379, 0.04505629604682326, 0.056402005454791446, 0.01745720307475754, 0.06501103724752154, 0.006415240291971713, 0.1204432634902852, 0.034549690184316466, 0.009531797009653278, 0.04252610681578517, 0.01920036462667797, 0.039503715067569695, 0.03565584136439221, 0.03372879173340542, 0.08088887203484774, 0.03227339518655624, 0.07193339722497122, 0.014913298954655017, 0.028925218419837098, 0.06167484340923173, 0.038087290179516585, 0.04208310487280999, 0.03092637425288558, 0.03249309464756932, 0.06278008874505758, 0.8154598570295742, 9.865705490112305, 26.695644276482717, 43.72104631151472, 44.75925309317452, 35.390392439705984, 21.326722587857926, 27.595618384225027, 36.355135917663574, 17.27159755570548, 17.91703830446516, 8.16741897378649, 2.6587110374655043, 0.3560885010021073, 0.008176470807354366, 0.09418564782078777, 1.0215388131993157, 0.9197051461253847, 1.800302465047155, 1.9307903945446014, 1.5444380917719431, 2.093714794942311, 2.436401469366891, 4.157604881695338, 1.2420090628521783, 6.6531112023762295, 13.79273613861629, 19.428526844297135, 26.14717606135777, 33.88722957883562, 37.902416365487234, 41.59340367998396, 46.84889950071062, 46.148840699877056, 49.4429156439645, 50.126020840236116, 52.511038643973215, 54.70691953386579, 51.79736137390137, 50.89858409336635, 52.243553842817036, 48.20236689703805, 50.0750731740679, 48.72138690948486, 49.94829634257725, 47.67875412532261, 47.63338238852364, 48.722846031188965, 50.85905231748308, 48.80165597370693, 52.54956293106079, 34.9665766443525, 32.97863449369158, 50.39462430136544, 48.01130533218384, 49.34001977103097, 43.29386758804321, 46.2391151700701, 44.68207597732544, 46.9399174281529, 45.48252929959978, 47.606298310416086, 47.129380907331196, 50.605641092572895, 49.9275837625776, 50.57445410319737, 48.034310817718506, 48.46622821262905, 47.73035839625767, 50.6955577305385, 50.413186413901194, 50.03202213559832, 49.756154332842144, 48.39372376033238, 42.53539180755615, 30.846892424992152, 22.290046896253312, 17.992822306496755, 11.94929393700191, 5.802922674587794, 3.6451530882290433, 3.8517312833241055, 2.139669963291713, 5.583983199937003, 4.781374633312225, 4.217508775847299, 2.8429386147430966, 2.3706141880580356, 1.4801390277487891, 1.3100086940186364, 0.26655735235129085, 0.14133750088512897, 0.7293526775070599, 2.2123841643333435, 8.448248658861433, 15.437622274671282, 24.567346777234757, 22.733239480427333, 37.022096974509104, 36.65220267432076, 37.10052824020386, 35.267346790858674, 15.660266876220703, 2.474291516201837, 0.13818491862288543, 0.012275254037896437, 0.050649344854589017, 0.07558503520808049, 0.019839493724118386, 0.04030707338824868, 0.056703044301165004, 0.0397712987448488, 0.07354519609361887, 0.04251581683222737, 0.007635186459603054, 0.016864063384543573, 0.036505153469209156, 0.004885852469929627, 0.03931651743394988, 0.017710372971903, 0.06852654074983937, 0.02208161260932684, 0.05975252656000001, 0.028672820356275355, 0.03461359800504787, 0.06515889002808503, 0.01684708983105208, 0.03917161288804241, 0.023894268021519696, 0.029804447133626257, 0.08192586353314774, 0.08870372947837625, 0.044522329699248075, 0.03920739543225084, 0.037109836736427884, 0.06471574559275593, 0.011336980903122042, 0.05885858381433146, 0.026352914216529046, 0.017906013277492354, 0.017938262350591164, 0.03998284221493772, 0.06117029834006514, 0.04045452244047608, 0.02666230752531971, 0.04182352112340076, 0.0074992869215618286, 0.007641866636861647, 0.05311639979481697, 0.03468355157279542, 0.0317560699103134, 0.015952373555462276, 0.022298653909404362, 0.017793736087956598, 0.04812107927032879, 0.05248135208551373, 0.07419569404529673, 0.037051676107304435, 0.012053524060840053, 0.019478567376998917, 0.032841288285063844, 0.024085516509200846, 0.01687243820301124, 0.023287384604503, 0.023966012921716486, 0.012302606632666928, 0.024207345775461624, 0.1140045632741281, 0.016397183794262152, 0.047090482964579544, 0.04078409707705889, 0.02883560090724911, 0.027202446845227053, 0.01664763785499547, 0.006593143268089209, 0.05604567278974822, 1.531354308128357, 12.6122693334307, 31.917422226497106, 49.393434047698975, 51.183640888759065, 41.835128034864155, 24.938179084232875, 23.422401768820627, 35.94527210508074, 23.978587695530482, 15.86676733834403, 8.21236513342176, 2.279686370066234, 0.2444064138191087, 0.08057293255946466, 0.16686750309807913, 0.4723937458225659, 1.1397915078060967, 2.403731039592198, 3.4913414674145833, 4.520343840122223, 3.1186290213039944, 3.887009024620056, 7.208289206027985, 3.8594242419515337, 8.33039939403534, 14.436419861657278, 21.229942866734095, 30.102479798453196, 36.91991329193115, 39.615251541137695, 43.93309491021292, 48.10490451540266, 47.689829553876606, 51.30997998373849, 50.732192107609336, 53.135431562151226, 54.05472687312535, 51.17813096727644, 52.140786511557444, 53.47315222876412, 51.023474488939556, 51.89250653130667, 50.223201819828574, 51.34821592058454, 50.322005203792024, 49.29266779763358, 50.52135944366455, 52.11457095827375, 49.99338320323399, 52.286042077200754, 37.474893706185476, 35.7541549546378, 51.03459855488369, 50.04947253635952, 50.502178941454204, 46.91852045059204, 48.41132354736328, 46.913437843322754, 48.27410704748971, 47.618113722120015, 49.30297545024327, 49.373781067984446, 51.17165872028896, 50.29185002190726, 50.837005683353965, 49.013812269483296, 48.7446460042681, 47.95362833568028, 51.12523085730416, 50.889033794403076, 49.86462960924421, 50.20618915557861, 49.07650933946882, 42.75841161182949, 33.47708089011056, 25.489004475729807, 20.88539559500558, 13.453150749206543, 9.639511227607727, 6.459687684263502, 5.134615404265268, 3.9086730735642568, 6.8819935492106845, 4.4051796197891235, 5.580024463789804, 5.022259558950152, 4.036814791815622, 1.5430864500147956, 1.5274959951639175, 0.38684934324451853, 0.09882008949560778, 0.542825463627066, 2.8284492322376797, 9.924042565482003, 18.734328848975046, 24.07696376528059, 23.598599399839127, 39.52308368682861, 42.22047165461949, 42.57135568346296, 39.553801672799246, 17.753858123506816, 3.3061669809477667, 0.19740375024931772, 0.008228656087469841, 0.07545173700366702, 0.04360566620848008, 0.05222393625548907, 0.03369859353240047, 0.002921921492088586, 0.03740829036438039, 0.020449245647926415, 0.04012888330700142, 0.06294982427997248, 0.03607851779088378, 0.020301956051428403, 0.013663724979518779, 0.04869635822251439, 0.00031317751979388826, 0.04325809343052762, 0.06676764227449894, 0.0661642210824149, 0.04455191382606115, 0.04368184194234865, 0.01668075884559325, 0.008261353841849735, 0.08743332871901137, 0.06383988580533437, 0.045995083171874285, 0.03836254469518151, 0.04918817736740623, 0.02312398319398718, 0.01768200851178595, 0.03483607606696231, 0.050304655850465806, 0.02561489712180836, 0.04328520768987281, 0.16839924161987646, 0.1373504562569516, 0.09685574418732099, 0.1230840946414641, 0.1092816542035767, 0.11787730189306395, 0.16197768119829042, 0.088873241096735, 0.0960776409400361, 0.19589991308748722, 0.12631489842065743, 0.12777560789670261, 0.10770893216665302, 0.09085055999457836, 0.08886870169746024, 0.13006138881402357, 0.1382888023342405, 0.1405882625175374, 0.17127320383276257, 0.21684995320226463, 0.1698886395565101, 0.1263365572584527, 0.15706309277032102, 0.0874867837077805, 0.10555264287229095, 0.13375750476760523, 0.1302766472633396, 0.13748327270150185, 0.1400696582027844, 0.21344752077545437, 0.15817226682390484, 0.08747186950807061, 0.21357440682394163, 0.10405398971800293, 0.12917770551783697, 0.13010934766914162, 0.1266303900629282, 0.16563218938452856, 1.6166392117738724, 14.835031066622053, 36.80061967032296, 57.59152323859078, 57.893794195992605, 48.87719331468855, 33.14119107382638, 37.594079630715505, 47.46626779011318, 26.77908171926226, 22.67964107649667, 10.955475722040449, 3.4009065372603278, 0.8610588216355869, 0.44697232278329985, 0.9011040042553629, 2.752517580986023, 4.815755188465118, 4.492899324212756, 4.838362455368042, 8.237370831625801, 7.68536250931876, 5.736708947590419, 7.982975568090167, 2.7126010486057828, 8.622220260756356, 16.21445345878601, 23.529206003461564, 30.9197963987078, 39.740499768938335, 41.51637595040457, 45.00682783126831, 49.32414313725063, 47.519369397844585, 51.96028273446219, 51.42130402156285, 54.67948109763009, 55.228677136557444, 53.284414836338584, 52.176493304116384, 54.1638240133013, 51.83756365094866, 52.95612982341221, 52.16021367481777, 51.988002572740825, 51.106654848371235, 50.06323691776821, 53.2319142477853, 53.53431722096035, 51.650775228227886, 51.72463110515049, 40.920102391924175, 41.01577908652169, 49.777575629098074, 51.791038513183594, 51.492957319532124, 48.44038438796997, 50.3183330808367, 48.97122328622, 50.57019485746111, 49.96753937857491, 51.463663714272634, 51.54266125815255, 53.65407289777483, 51.370255606515066, 50.67459154129028, 49.95665502548218, 49.4213866506304, 48.41151809692383, 53.06659575871059, 50.49690178462437, 50.13733945574079, 50.23480183737618, 50.90582064219883, 45.276358876909526, 35.901765959603445, 28.47063456262861, 23.448681592941284, 13.88785263470241, 10.808255553245544, 7.0980569039072305, 7.893367256437029, 7.244396822793143, 13.997809614453997, 11.653998102460589, 9.591276832989283, 7.833142876625061, 5.289178081921168, 4.531413623264857, 3.481619634798595, 0.8081976867147854, 0.34206676483154297, 1.200350052544049, 3.756251309599195, 12.375378319195338, 22.939571448734828, 34.03932564599173, 32.13640512738909, 46.94089017595564, 47.51579107557024, 49.52865988867623, 45.09902695247105, 20.675335918154033, 4.3590457524572095, 0.30745119228959084, 0.14250026563448565, 0.15748847994421208, 0.2281613898064409, 0.1111898710951209, 0.14015765062400273, 0.13577267234878881, 0.1490747814199754, 0.22225646594805376, 0.13689511854733738, 0.15076674920107636, 0.09572233964822122, 0.10059257902737175, 0.059901329289589605, 0.06532555179936544, 0.09751342782484633, 0.22781625975455555, 0.10154689103364944, 0.0955343379506043, 0.11623721489948885, 0.06394952349364758, 0.1613535511174372, 0.09265575491424118, 0.1358884439936706, 0.12232117700789656, 0.12897244867469582, 0.16277109219559602, 0.12353029926972729, 0.09014073772622005, 0.1447971745261124, 0.10448380094021559, 0.18077168986201286, 0.11706181136625153, 0.1189589002834899], [0.0550408201026065, 0.04546303368572678, 0.03781656149242606, 0.004085654850184385, 0.042978482720042975, 0.04901330192972507, 0.033669179039342065, 0.055727334693074226, 0.04851991876161524, 0.06481971072831325, 0.009090995216476066, 0.04588127927854657, 0.07410645990499429, 0.035607811263097186, 0.031193934181439023, 0.005273434641172311, 0.023739165094281946, 0.05629814549216202, 0.02954280742311052, 0.020227188277723532, 0.06858990913523094, 0.02846696979499289, 0.025396184929247414, 0.05507830237703664, 0.0604525643533894, 0.009804733480060739, 0.019690641800739934, 0.014450848501707827, 0.04077554414314883, 0.08176374794649226, 0.023439739464915225, 0.05225429391222341, 0.028894256866936172, 0.02235858212225139, 0.08264717339937176, 0.026384367707318494, 0.052471910270729234, 0.05261458922177553, 0.06103678300444569, 3.7438522492136275, 16.941052641187394, 37.88088389805385, 41.27948406764439, 34.95165886197771, 26.71319890022278, 29.320765767778667, 24.903570107051305, 17.936699969427927, 11.553713883672442, 10.661588634763445, 4.3133604781968256, 0.667153000831604, 0.015242502093315125, 0.03448144991749099, 0.10707847135407583, 0.41917502294693676, 0.8934353100402015, 2.864389657974243, 3.4515098333358765, 3.041644935097013, 3.8537284561565945, 7.552685788699558, 3.9895600931985036, 4.1236433897699625, 6.504152246883937, 12.504200526646205, 19.84296257155282, 25.323010274342128, 34.10558019365583, 37.76804862703596, 40.853389263153076, 45.184559277125764, 47.120633125305176, 49.60406173978533, 50.90588665008545, 50.494546345302034, 52.69810846873692, 49.84584515435355, 52.4351921081543, 51.27757011141096, 49.29572153091431, 49.50641523088728, 51.19718292781285, 47.841908250536235, 49.65697922025408, 50.08723599570138, 52.67159414291382, 47.795584610530305, 47.54554326193673, 35.810028893607004, 32.36492095674787, 49.913579668317524, 49.649343150002615, 51.21069369997297, 48.780599457877024, 48.32711485454014, 47.24214669636318, 47.581420285361155, 47.6277300289699, 48.87998301642281, 49.18586703709194, 47.22615194320679, 47.932863644191194, 48.31292315891811, 45.688602447509766, 45.850801195417134, 45.879201957157676, 45.80112157549177, 46.26895768301827, 46.332888058253694, 46.03571707861764, 42.79542119162423, 35.76289231436593, 28.870187248502457, 20.736460958208355, 13.07088691847665, 7.216838530131748, 5.032552446637835, 4.673613718577793, 2.5457793601921628, 3.237188522304807, 3.8257076740264893, 3.615802160331181, 4.924145783696856, 2.731703383581979, 3.210606885807855, 1.2089479054723467, 0.785388704921518, 0.06118584357734237, 0.17892288549670152, 0.9892928749322891, 3.953361281326839, 8.882518887519836, 16.991642475128174, 19.06329652241298, 25.997484070914133, 42.59887054988316, 37.27153035572597, 41.94725111552647, 29.132815258843557, 9.434403879301888, 0.6822046445948737, 0.012394322514800089, 0.05582654329815081, 0.037493378655718904, 0.026814528375065753, 0.018801940738090446, 0.0427863453514874, 0.02342686426293637, 0.031626700423657894, 0.01725383595164333, 0.02270738304858761, 0.06987122752304588, 0.01850276447034308, 0.01530302911331611, 0.040989530339304886, 0.024647716698901992, 0.04471503703721932, 0.013581957268927778, 0.038079470063426664, 0.011800754499355597, 0.059806035831570625, 0.08386128289358956, 0.01340082913104977, 0.057220233870404105, 0.03914118059245603, 0.006276344173654381, 0.008093119565663593, 0.012910071045293339, 0.0266539055654513, 0.08291436013366495, 0.0893664342750396, 0.05208663808714066, 0.028981869308544055, 0.0325541492285473, 0.011819267479170645, 0.061233239248394966, 0.06269827777785913, 0.019082637104604925, 0.00894834510316806, 0.032203322875180414, 0.016570541009839092, 0.01837734236115856, 0.08872133746211018, 0.01618194400465914, 0.05199539548318301, 0.012919992923603525, 0.01772234232963196, 0.043208438237862926, 0.018945763020643165, 0.010310613566876521, 0.04948700758229409, 0.021238951844030192, 0.037146671009915214, 0.08643221136714731, 0.12241130002907344, 0.018158241707299436, 0.05034850278337087, 0.03760782715731433, 0.04635836064283337, 0.12840931889201912, 0.07069316413253546, 0.02143288224137255, 0.049271114702735624, 0.048335811855005364, 0.036040360374110084, 0.037889385263302496, 0.021573206675904136, 0.04856989625841379, 0.02266173460520804, 0.023239032199074115, 0.07210823534322636, 0.051859895432634015, 0.037049077318183014, 0.11243924405425787, 5.216496450560434, 20.535795245851787, 45.45836693899972, 47.757289613996235, 40.48748322895595, 28.783329554966517, 33.885225023542134, 35.881452901022776, 23.50794972692217, 19.512796333857946, 11.232368384088788, 4.128649132592337, 0.6054917009813445, 0.0226628575806639, 0.2056094099368368, 0.3283037676342896, 1.6162469642502921, 4.073026197297232, 3.0519714781216214, 4.7937502435275485, 5.477976271084376, 5.075052406106677, 4.962465533188411, 4.0731677668435236, 4.83557231937136, 8.81614100933075, 18.44381250653948, 24.32750712122236, 28.475817918777466, 35.55377238137381, 40.601044586726594, 42.880269118717735, 46.16608612877982, 48.19409506661551, 48.457067012786865, 51.673037256513325, 51.81111533301217, 53.32336643763951, 50.86202962057931, 54.23935093198504, 52.63816635949271, 51.72272382463728, 50.76606804983956, 52.93380873543875, 50.28534998212542, 51.67011553900582, 51.95913628169468, 52.787681170872276, 50.04521329062325, 48.93030881881714, 40.202068601335796, 36.052441120147705, 50.21232788903372, 49.16319506508963, 52.318507535117014, 50.280031136104036, 51.20631286076137, 48.61707360403878, 49.33115039552961, 49.42215442657471, 50.72503546306065, 49.182698658534456, 49.54192052568708, 47.71408918925694, 48.18083095550537, 46.94169964109148, 45.74317012514387, 47.56041588102068, 47.219373975481304, 46.635989325387136, 47.46455158506121, 47.35004179818289, 46.019388811928884, 37.90142624718802, 32.69498470851353, 22.92570284434727, 15.813608407974243, 8.78266111442021, 8.52240765094757, 5.451449351651328, 4.98689409664699, 2.882360739367349, 6.3928108385631015, 5.160911296095167, 4.740263879299164, 4.01691688810076, 3.3421549584184373, 2.229973529066358, 0.31607648517404285, 0.06720237966094698, 0.15832889984760964, 0.8055448862058776, 4.222277411392756, 9.943343792642866, 17.929260185786656, 21.001241173063004, 26.536740711757115, 44.67128542491368, 40.68596199580601, 46.685665471213206, 34.87784120014736, 11.622469782829285, 1.162140931401934, 0.03553619189187884, 0.04847017875207322, 0.1103523349655526, 0.0240372675803623, 0.016199282270723155, 0.02653063610861344, 0.04099535895511508, 0.03351286153442093, 0.0214987747770335, 0.0030157546155221227, 0.018787625345534513, 0.023431961757263968, 0.042063681807901175, 0.036686654801347425, 0.02352651221943753, 0.03424463101795741, 0.0258490985725075, 0.036113944104207416, 0.02467932116373309, 0.026022905317534293, 0.04983493319845625, 0.04083088545926979, 0.035383653827011585, 0.04345308403883662, 0.01159700654846217, 0.016936115321836302, 0.06961670225220067, 0.031558660324662924, 0.07283529918640852, 0.032390476404024024, 0.017015458117904406, 0.0351259055148278, 0.03235013749716537, 0.03173790552786418, 0.1378382822232587, 0.14536285560045922, 0.08941456276391234, 0.07963959407061338, 0.17880539037287235, 0.1401531994342804, 0.10490904562175274, 0.19132402219942637, 0.16583406712327683, 0.20607717840799264, 0.08922979767833437, 0.175904531031847, 0.1887704370809453, 0.14382129189159187, 0.1559951329337699, 0.22131000459194183, 0.1299023809177535, 0.15166765371603624, 0.15960816905966826, 0.23246487602591515, 0.10772891502295222, 0.1812096977872508, 0.11117347768907036, 0.11634464056364127, 0.1742825202111687, 0.21615057358784334, 0.12821573285119875, 0.12039936227457863, 0.14651998850916112, 0.1304619416062321, 0.14423150702246598, 0.14555812440812588, 0.26590560589517864, 0.18202440121344157, 0.10503154833401952, 0.187944035711033, 0.1798770550106253, 0.14976285664098604, 0.3028721665697438, 6.642779665333884, 24.92879033088684, 52.75624057224819, 54.62238080160958, 47.79102659225464, 38.12151738575527, 42.208378314971924, 36.054018361227854, 27.693867649350846, 17.882966075624736, 14.588559355054583, 5.550961017608643, 1.0030284864561898, 0.29121314361691475, 0.5830214438693864, 0.828013189136982, 1.976008836712156, 5.430644273757935, 6.948008818285806, 8.543585760252816, 9.083840336118426, 9.704114709581647, 10.941742607525416, 6.78377685376576, 6.265948023114886, 9.5763920545578, 17.910246440342494, 24.988968678883143, 29.185651097978862, 38.781888076237266, 41.22725098473685, 42.152382782527376, 46.13391249520438, 48.85439280101231, 50.39567000525338, 50.43187011991228, 50.04738807678223, 55.711955615452354, 51.93590497970581, 55.62174367904663, 52.8158734866551, 51.965028354099815, 52.30311032703945, 54.630833285195486, 50.87373038700649, 53.12640585218157, 53.53896903991699, 52.91187327248709, 50.17755215508597, 48.604552950177876, 43.043645586286274, 40.43668147495815, 49.600337505340576, 52.17426988056728, 52.847303662981304, 51.83609063284737, 51.857574462890625, 51.62162058694022, 50.80125025340489, 52.33223370143345, 52.464266845158164, 51.76002522877285, 48.60011305127825, 48.66211877550398, 48.407623631613596, 48.839923177446636, 47.84731394904, 47.758915492466514, 46.40455872671944, 48.00414521353585, 48.91714545658657, 49.6508161681039, 48.30806984220232, 41.93185043334961, 35.679718903132844, 27.2552296093532, 18.44409043448312, 9.864466105188642, 8.432015061378479, 8.208649584225245, 7.5031251566750665, 9.385855947222028, 11.122466989925929, 12.152717215674263, 10.552458490644183, 8.345086148806981, 8.392562321254186, 2.9735994892460957, 1.7908432526247842, 0.435388481510537, 0.5122044810226986, 1.5639828315802982, 5.6153669101851325, 12.816106898444039, 24.771879162107194, 29.098053421292985, 35.164249420166016, 51.62502520424979, 46.078590938023154, 52.91950239453997, 38.79259525026594, 13.69503925527845, 1.5054649944816316, 0.1835171782544681, 0.1211619677820376, 0.21956429683736392, 0.12159458813922745, 0.14925810801131384, 0.1502190628754241, 0.08760138148708002, 0.09829227067530155, 0.07818298294608082, 0.09104677875127111, 0.1516899232353483, 0.08198488250906978, 0.0989024636468717, 0.18894781970552035, 0.10722920790846859, 0.15117108821868896, 0.06116431366120066, 0.1494972916053874, 0.1360038085175412, 0.09491494404418127, 0.21534698456525803, 0.10239336346941334, 0.22004456392356328, 0.13650208392313548, 0.0861135781077402, 0.07162825324173484, 0.23724379816225596, 0.09880641701498202, 0.10742746905556746, 0.19701052563531057, 0.13410313693540438, 0.12197800113686494, 0.12633739864187582, 0.08448974202786173], [0.03197416802868247, 0.022134258445086222, 0.10403585926230464, 0.016607801064050624, 0.029439897409507206, 0.10278389429939644, 0.01059364409385515, 0.021331393758633306, 0.034926718167428455, 0.023567936782326018, 0.01656326202542654, 0.05135498056188226, 0.05210188476900969, 0.09469987558467047, 0.03393527672493032, 0.07514352604214634, 0.0966756542080215, 0.02981591098276632, 0.027246851873184954, 0.020691167130800228, 0.030737622774073055, 0.042394657619297504, 0.01888910025757338, 0.08743762384567942, 0.03670380477394376, 0.03714344796857663, 0.015439263678022792, 0.04409952435110297, 0.07409454483006682, 0.012465985990794641, 0.04866430422823344, 0.02276662763740335, 0.013248990805420493, 0.04611646969403539, 0.01645436733295875, 0.04540876784761037, 0.04865989714328732, 0.0709986745246819, 0.006625297346285411, 1.5333283564874103, 12.158555439540319, 30.69014801297869, 45.22594969613211, 39.59324312210083, 33.198652676173616, 14.71178913116455, 23.039521285465785, 21.69320705958775, 16.379634720938547, 11.060436947005135, 5.842389745371682, 1.5323332441704614, 0.39223346433469225, 0.16595745193106787, 0.08131322105016027, 1.3839820389236723, 3.4477803877421787, 3.098205008677074, 3.7389555062566484, 2.1736883435930525, 2.627104767731258, 5.020595899650028, 2.161381781101227, 1.9746656630720412, 3.4764208623341153, 8.26508285318102, 11.191559876714434, 17.031368800571986, 21.450183391571045, 29.901256493159703, 34.84089762823922, 38.64540808541434, 42.140772342681885, 45.31010627746582, 47.88264553887503, 48.86244576317923, 51.3188146182469, 50.79267617634365, 50.82455798557827, 49.555875982557026, 51.683549880981445, 51.33528879710606, 51.81714289528983, 52.778954233442036, 50.80360221862793, 50.223142760140554, 52.19144582748413, 56.109347411564414, 53.87972954341343, 34.81565829685756, 30.411535671779088, 48.82678413391113, 46.921643665858674, 50.79797765186855, 48.041092259543284, 47.72423703329903, 45.76642574582781, 52.131423813956125, 47.59389577593122, 46.82584885188511, 47.212901728493826, 46.474989141736714, 46.289816175188335, 47.586086000714985, 45.975431033543174, 44.36826753616333, 46.67996447426932, 44.87910604476929, 42.120243889944895, 42.609542982918875, 36.761265073503765, 32.17695828846523, 27.084845883505686, 25.890023231506348, 21.38560857091631, 12.823716044425964, 6.055238689695086, 5.1670535036495755, 4.600561661379678, 3.8671124236924306, 1.7880993655749728, 6.53145215341023, 2.5805016798632483, 2.707333879811423, 4.475474110671452, 1.9372713267803192, 1.1798207312822342, 0.5829964194978986, 0.0959902320589338, 0.42508658287780626, 1.495890485388892, 6.032627080168043, 14.801129068647112, 20.12655677114214, 23.618994099753245, 32.663047313690186, 39.683003425598145, 41.324098450796946, 35.01052747453962, 17.841085808617727, 5.184962919780186, 0.15066946085010255, 0.01651618187315762, 0.10000776326549904, 0.04399534547701478, 0.020877279108390212, 0.053281405940651894, 0.034607117995619774, 0.01419919088948518, 0.03201820834406784, 0.06521007870989186, 0.013267441020746316, 0.046669058435197384, 0.06204972043633461, 0.015569593291729689, 0.052717974209891896, 0.02712482413543122, 0.026008555998227427, 0.08512089494615793, 0.02475509656194065, 0.05021563544869423, 0.021187473088502884, 0.01927129698118993, 0.058879726965512545, 0.01816461993647473, 0.051935104254101, 0.062274932994374206, 0.04872600341747914, 0.06542075026248183, 0.08191909853901182, 0.051252440349864106, 0.06553798075765371, 0.10126945842057467, 0.009623529006993132, 0.04733970209157892, 0.016388451048572148, 0.02880510754351105, 0.07882115870182003, 0.04103810326861484, 0.0292396413694535, 0.010984780516342392, 0.10131054371595383, 0.039718410332820246, 0.024723758422104374, 0.021159688775826777, 0.01554594125731715, 0.0405226880684495, 0.07126368316156523, 0.01438546147463577, 0.1165013142994472, 0.04045960806044085, 0.049682781898549626, 0.01720089156047574, 0.10786356351205281, 0.03584159371842231, 0.03339950886688062, 0.009851493024533349, 0.05415708930896861, 0.06358734185674361, 0.04149198891328914, 0.058985632711223195, 0.0349017955761935, 0.03967965580523014, 0.0070833534368180805, 0.05113930481352976, 0.023174340670396174, 0.02845936341743384, 0.008078916979554509, 0.02165577929866101, 0.06804942206612655, 0.022648521832057407, 0.04400449552174125, 0.03746221014963729, 0.042091484780290296, 0.049351164871560674, 2.2684745831148962, 15.508431366511754, 36.31224468776158, 50.691871711185996, 44.665963104793, 38.899830273219514, 21.070777007511683, 24.739007234573364, 24.64856427056449, 17.7333505153656, 14.839639459337507, 5.958140654223306, 1.6246992307049888, 0.254914858511516, 0.0936173340305686, 0.10122301948389836, 1.1088674643210001, 1.8398792956556593, 4.074825346469879, 4.699817546776362, 6.471542613846915, 5.733623078891209, 3.56421417423657, 3.3746851214340756, 3.578268425805228, 4.625432303973606, 8.395832317216055, 15.865549666540963, 19.139219488416398, 24.012996912002563, 31.890160969325475, 37.12002141135079, 41.29968595504761, 44.18555423191616, 46.962926387786865, 48.25046580178397, 49.837569849831716, 51.48775659288679, 52.26323808942522, 51.4593836239406, 52.60528400966099, 53.292332308632986, 52.216497557503835, 55.39168187550136, 52.97459118706839, 52.94233417510986, 52.536906787327354, 54.82776607785906, 55.423317023685996, 51.34789630344936, 37.87240709577288, 37.19959218161446, 50.1857579776219, 48.781679902757915, 51.473297391619, 49.5814870425633, 49.64607402256557, 47.754176821027485, 53.47991977419172, 48.91931676864624, 48.58647721154349, 48.560946055821006, 47.11053391865322, 48.195592403411865, 48.46866703033447, 47.83150332314627, 45.4505432673863, 47.756157057625906, 46.50507484163557, 44.54189607075283, 44.08316905157906, 40.64373084477016, 38.026063033512656, 32.952064582279746, 29.761208602360316, 22.565862587520055, 13.62229595865522, 7.150753779070718, 6.064214025224958, 5.031993116651263, 5.8884276407105585, 4.998259612492152, 5.316126235893794, 6.198099298136575, 5.862011458192553, 3.159539580345154, 4.636665369783129, 1.6419425968612944, 0.4558751093489783, 0.34811028625283924, 0.39505033461110933, 1.3619819794382368, 5.512216993740626, 15.13242438861302, 22.432721206120082, 24.844301973070415, 34.35131365912301, 44.0865215573992, 42.778870582580566, 41.87218625204903, 20.6294013772692, 6.515158627714429, 0.16276520251163415, 0.034843007302177806, 0.09720521686332566, 0.03312468522095254, 0.007506980660504529, 0.1601930255336421, 0.04907928606761353, 0.0016043673198769934, 0.029713791462459734, 0.0179064661996173, 0.011306798817323787, 0.0059384990433630136, 0.03939475252160004, 0.02789178753404745, 0.011195614069168056, 0.06254433853817837, 0.03661935091284769, 0.0420567912847868, 0.09811900675828968, 0.10654601813959223, 0.09189394329275404, 0.024072909328554357, 0.02752126839810184, 0.020497190932344114, 0.015262391651049256, 0.051189563902361054, 0.015723517264372537, 0.08771526001925979, 0.017258595874799148, 0.05255667965060898, 0.028005599909062897, 0.038268177437462976, 0.01611185133723276, 0.044360359997621605, 0.021093911591119, 0.1229902125362839, 0.10122920772326843, 0.20791602187923022, 0.14303780107625894, 0.10620177696858134, 0.18885435829205172, 0.1891462504863739, 0.07986689651651041, 0.09298280879322972, 0.07723682693072728, 0.12098709573703152, 0.19591120391019753, 0.09909184955592666, 0.218960115686059, 0.17745828122964927, 0.23706387781671115, 0.13969835026987962, 0.25043948580111774, 0.2023350034973451, 0.1287891763661589, 0.130078433613692, 0.15616315177508763, 0.11560473883790628, 0.23789996866668972, 0.11243974617017166, 0.1146711560764483, 0.16983033982770784, 0.17771201261452266, 0.1659187211522034, 0.14143681127045835, 0.14253858929233892, 0.16312697024217673, 0.14500975954745496, 0.17094538999455317, 0.154741105224405, 0.1866667206798281, 0.10863245225378446, 0.21731637817408356, 0.10967681264238698, 2.6599069961479733, 18.37730434962681, 41.58435365131923, 59.19876316615513, 51.34687144415719, 45.13589409419468, 24.112291881016322, 32.95636551720755, 32.39173752920968, 25.03099833215986, 16.504056113106863, 8.155839800834656, 2.6268796026706696, 0.8507552402360099, 0.25863092339464594, 0.90498115335192, 3.914675448622022, 6.630178238664355, 7.161106594971248, 9.741204193660192, 10.35827284199851, 9.131132381302969, 10.116967984608241, 5.861060423510415, 5.077040025166102, 5.969920890671866, 11.885250653539385, 15.0283716406141, 19.56584061895098, 23.025994879858835, 32.37041350773403, 39.12428488050188, 42.092426776885986, 44.28169298171997, 47.15772955758231, 48.014174938201904, 50.621802602495464, 52.2544138772147, 53.342977728162495, 53.32396050861904, 53.52457584653582, 54.60555573872158, 54.398787770952495, 57.01477411815098, 55.510416167122976, 54.1083356993539, 54.02188968658447, 55.157100268772666, 54.523018087659565, 51.58577830450875, 41.61425174985613, 41.85359634671892, 52.004765101841514, 49.24971055984497, 52.17556919370379, 50.449073859623496, 50.92082527705601, 47.791829109191895, 53.48876483099801, 49.69068840571812, 48.255746432713096, 49.30872161047799, 47.841084889003206, 49.649985858372276, 49.72564131872994, 47.98577070236206, 45.20644957678658, 48.50005899156843, 46.828989437648225, 45.15026991707938, 45.17543281827654, 44.74229254041399, 42.868557929992676, 38.6990898677281, 38.35342046192714, 28.671355860573904, 18.034554924283707, 9.968412893159048, 9.98996012551444, 9.482408114842006, 8.886272651808602, 8.200155411447797, 10.701601573399135, 8.699940204620361, 9.235114778791155, 9.141335810933795, 6.915425675255912, 3.319665159497942, 1.6553081082446235, 0.6650735352720533, 0.9911939672061375, 2.1388861196381703, 8.61846215384347, 18.961587054388865, 26.77124067715236, 34.79160015923636, 42.92773921149117, 49.71950953347342, 50.06761775697981, 46.56282826832363, 25.922900370189122, 7.826104351452418, 0.4665361429963793, 0.11463243886828423, 0.1510968700583492, 0.0864458702770727, 0.10184142272919416, 0.2752050911741597, 0.18550957420042583, 0.07080274753804718, 0.15841185753898962, 0.15029697226626532, 0.07726325586970363, 0.1292914008455617, 0.15829863718577794, 0.10617846250534058, 0.08546969587249414, 0.12132838528071131, 0.12593468810830796, 0.16861490719020367, 0.17161008289882115, 0.22396394503968103, 0.1271656999098403, 0.14741650968790054, 0.0963749885559082, 0.08912876381405763, 0.09229713558618512, 0.12886585082326615, 0.11883923384760108, 0.18816213043672697, 0.13251297654850142, 0.1246180994702237, 0.13875290671629564, 0.1332284781549658, 0.12397973372467927, 0.20751147930111202, 0.07615290795053754], [0.04643731837027839, 0.024132072493167858, 0.07691088584916932, 0.01981196046939918, 0.04932796236659799, 0.0353415744778301, 0.010680887582046645, 0.094728530118508, 0.013686990248970687, 0.019449731335043907, 0.06765433148081813, 0.04311804719535368, 0.0021325730111649527, 0.05735123184110437, 0.020526583373014416, 0.04149872676602431, 0.06415528245270252, 0.042892973736992905, 0.022072913790387765, 0.007144331682606467, 0.0057461084964286, 0.012370366835966706, 0.03268584269764168, 0.025824040274268815, 0.045776991838855405, 0.020858044336949075, 0.10650141803281647, 0.05513408134824463, 0.05444956843608192, 0.058335392602852414, 0.045301762875169516, 0.05367163821522679, 0.018985949257122617, 0.01748518755526415, 0.0731246740158115, 0.06345489182110343, 0.022841831369857703, 0.048042515093194585, 0.029808392814759697, 0.3257546201348305, 5.101626660142626, 21.27571759905134, 42.27968767711094, 39.306174823216026, 28.82974178450448, 25.41982126235962, 28.00141750063215, 26.038662569863455, 20.678509507860454, 16.82514452934265, 8.880244221006121, 2.7466813113008226, 0.382327205900635, 0.05995831944580589, 0.3852898526404585, 1.05861668075834, 1.541126298052924, 3.122178247996739, 3.5907754004001617, 6.165422788688114, 4.655820250511169, 1.5068411720650536, 2.14606534583228, 1.2122927031346729, 1.9122465210301536, 5.478665879794529, 8.225940176418849, 7.921361548560006, 15.69933659689767, 17.720135041645594, 21.820628336497716, 28.257790395191737, 35.652836322784424, 36.10198177610125, 42.05383995601109, 43.44801337378365, 44.26328372955322, 49.36352552686419, 50.09257221221924, 51.39566516876221, 53.25908865247454, 53.359243461063926, 54.25493574142456, 51.499585900987896, 53.279012611934114, 50.40129804611206, 49.89707769666399, 47.797575269426616, 56.01735673631941, 42.56326798030308, 33.79339068276541, 47.68741158076695, 50.728950772966655, 49.37847457613264, 47.97646011625017, 48.48027399608067, 47.58401543753487, 48.49554961068289, 47.45889227730887, 48.16695192881993, 46.2426518031529, 45.31652293886457, 44.912262848445344, 46.24271086284092, 43.3011770929609, 46.28548049926758, 47.10857800074986, 42.33430746623448, 41.56189707347325, 38.63416242599487, 30.64199004854475, 28.611269576208933, 24.129235063280376, 24.827277149472916, 23.66155355317252, 12.223621845245361, 4.203500338963099, 5.652875891753605, 4.211013947214399, 4.515663794108799, 2.474168619939259, 3.454250246286392, 5.135728418827057, 3.121548350368227, 1.9413032361439295, 3.158156454563141, 1.9924636908939906, 0.3135114870965481, 0.31628954516989843, 0.67809147387743, 3.5169499218463898, 6.335477777889796, 12.3203763791493, 21.21744132041931, 30.049944468906947, 29.459660257611954, 34.41693939481463, 41.719558647700715, 35.136817932128906, 18.48794572693961, 2.614118367433548, 0.09268707609070198, 0.0091814439344619, 0.06880431941577367, 0.057708650162177424, 0.08355704136192799, 0.035165274116609774, 0.04760682775772043, 0.06771124699818236, 0.0733378900747214, 0.025724451689581786, 0.05240930862990873, 0.020222840564591543, 0.12529381178319454, 0.013058693114934223, 0.017240514612889717, 0.009005558327771723, 0.032172697197113714, 0.017922004651544348, 0.034208834903048616, 0.014027305246729935, 0.023728632534454976, 0.06935869609670979, 0.038039758801460266, 0.04695952231330531, 0.02513276067163263, 0.025170963889520084, 0.02598475298977324, 0.0551960485588227, 0.008509945323956864, 0.011751452993069376, 0.014972351857327988, 0.025796880213809863, 0.008381591943491782, 0.037754560355097055, 0.039398301259747574, 0.01497813467202442, 0.03818718071228691, 0.05488654838076659, 0.031886192570839605, 0.05626580651317324, 0.08220557602388517, 0.06088741709079061, 0.013593869799348925, 0.016059945104643703, 0.014510249153577855, 0.05086069154952254, 0.02459916073296751, 0.056804665098232884, 0.02324476751631924, 0.0873868762116347, 0.03310021724818008, 0.011282681986423475, 0.04444741604051419, 0.06372287922671863, 0.03732814180797764, 0.026522100138078843, 0.09860989291753088, 0.04771222460216709, 0.036113604836698086, 0.06426806854350225, 0.04043891274237207, 0.03715025367481368, 0.052177772125495334, 0.06673984269478492, 0.07471878347652298, 0.042151348532310555, 0.05010082053818873, 0.028390264803809778, 0.052343114146164486, 0.06848484477294342, 0.03203335663835917, 0.055453790085656304, 0.051666984534157176, 0.024620648240670562, 0.28903127355234964, 7.046805688313075, 26.92348439352853, 46.97098282405308, 47.095310415540425, 33.39123589651925, 26.77006643159049, 32.319087164742605, 28.549272537231445, 23.478385141917638, 19.188459634780884, 10.502725890704564, 2.7771504649094174, 0.3652345288012709, 0.15667175448366574, 0.27779424509831835, 0.8093733979122979, 2.1464483652796065, 3.264820856707437, 3.884792115007128, 3.505499290568488, 4.421832714762006, 3.4100414642265866, 2.7949456700256894, 2.7291835759367262, 4.92944552217211, 5.279808001858847, 7.818095684051514, 10.559216482298714, 18.013345548084803, 20.873825107301982, 25.14770027569362, 32.84450994219099, 37.245901925223215, 39.130555629730225, 43.523710523332866, 46.22502074922834, 46.58985676084246, 51.67337424414498, 52.086076395852224, 53.29794297899519, 55.50069563729422, 56.38183144160679, 55.2985760143825, 52.53216116768973, 54.76499605178833, 50.404792990003315, 50.8172276360648, 51.697467122759136, 56.40952696119036, 45.75914403370449, 37.23844998223441, 48.4654917035784, 51.68854216166905, 52.69337327139718, 48.79249824796404, 48.45986018862043, 49.01124838420323, 49.98703949792044, 49.08431216648647, 48.726525102342876, 47.33807700020926, 46.22214766911098, 46.27421746935163, 47.06196253640311, 45.9307541166033, 48.57958459854126, 48.02299567631313, 47.1011677469526, 43.96875306538173, 44.04175431387765, 38.24903072629656, 36.501180103846956, 31.692522934504918, 31.89896433694022, 27.905080727168492, 15.545154333114624, 7.230676736150469, 4.446895735604422, 3.276715738432748, 3.717803018433707, 4.125420825822013, 6.604820353644235, 7.3917646408081055, 4.125531996999468, 1.9263459358896529, 1.1314982899597712, 0.1912802295493228, 0.24084236792155675, 0.08722033657665763, 0.507014773786068, 2.890365932668958, 7.71871907370431, 14.944958516529628, 20.439852782658168, 31.597475051879883, 34.417015824999126, 39.738585540226524, 46.06467022214617, 39.583609444754465, 20.77930007662092, 4.144531411784036, 0.09270631934383086, 0.01657884118945471, 0.036422596113490205, 0.035165708379021714, 0.05433212759505425, 0.05909830345106976, 0.024433715235708014, 0.01886776033123689, 0.04788130195811391, 0.05128419239606176, 0.04882497792797429, 0.02255610536251749, 0.09694256952830724, 0.04454728960990906, 0.06156070024839469, 0.018138728736500655, 0.04928154039329716, 0.07129908233348813, 0.034998554669852765, 0.0543773858807981, 0.035392932793391604, 0.00720322343321251, 0.058247264474630356, 0.07356197626463004, 0.030277467465826442, 0.08228286116250924, 0.05644991002710802, 0.05561609226944191, 0.02054117017957781, 0.07428348969135966, 0.030655150235231434, 0.053943523804524114, 0.04418494173192552, 0.0793539851105639, 0.043030360114893744, 0.07947739705975566, 0.15920739913625376, 0.23043459068451608, 0.11100655807448284, 0.1845580916851759, 0.11809374099331242, 0.11899684396173273, 0.17331944831780025, 0.061738774978688786, 0.11400849877723626, 0.1347591174500329, 0.08177157145525728, 0.10467634882245745, 0.11310962308198214, 0.24973557357277187, 0.10732968537403004, 0.1339370994163411, 0.13710123034460203, 0.13947015894310816, 0.1442066862114838, 0.17251037673226424, 0.19274950213730335, 0.1910586878657341, 0.10371245590171643, 0.2120279305215393, 0.12915669807365962, 0.28145773708820343, 0.20590838603675365, 0.18557337006287916, 0.1775829145418746, 0.2117172157657998, 0.16517936225448335, 0.11496097195361342, 0.0956020625308156, 0.2813232514475073, 0.14599219683025563, 0.1364176334547145, 0.13548820332757064, 0.09621078308139529, 0.737210818699428, 8.433123299053737, 29.053861141204834, 53.48607587814331, 53.56431259427752, 39.46002878461565, 36.33771330969674, 42.20367785862514, 36.599597862788606, 29.494474206651958, 23.571225234440394, 12.816407408033099, 4.075001222746713, 0.7211528260793004, 0.2762890915785517, 1.026052428143365, 3.118084021977016, 5.176826144967761, 7.615734611238752, 8.404324752943856, 14.98986646107265, 11.735484838485718, 6.410928266389029, 5.990481913089752, 3.437485328742436, 2.3559135368892123, 6.966631727559226, 9.502333811351232, 10.260511687823705, 19.64262342453003, 20.294560738972255, 25.77201155253819, 32.28962680271694, 38.76173482622419, 39.479032107761924, 44.63814946583339, 46.813366413116455, 46.13386385781424, 52.71436030524117, 53.374001434871126, 53.35781560625349, 56.815815925598145, 56.38394021987915, 55.96036761147635, 53.34995024544852, 55.090286391122, 50.90317685263497, 49.70142337254116, 51.835896083286826, 56.22507660729544, 47.93953044073922, 42.14502811431885, 51.02332510266985, 52.66074800491333, 53.5289705821446, 50.425029618399485, 50.64278963633946, 49.91478170667376, 50.77050447463989, 48.78337526321411, 49.07294143949236, 47.60548537118094, 46.48246192932129, 46.33223145348685, 46.771621635981965, 45.17250762666975, 49.447612626211985, 48.823046003069194, 47.91123390197754, 45.781513759068076, 45.883721760341096, 39.49017701830183, 42.946805068424766, 37.87573528289795, 37.48761238370623, 31.812292507716588, 20.544582980019705, 8.853638700076512, 10.295465469360352, 8.271338837487356, 12.172307661601476, 8.262289677347455, 11.415300556591578, 9.254177161625453, 9.10601898602077, 6.2484442080770215, 6.356278947421482, 3.484613222735269, 0.4311939680150577, 0.4769079035946301, 1.187531168971743, 4.829504804951804, 8.650991882596697, 17.55013346672058, 28.161589111600602, 39.867095947265625, 39.69890437807356, 45.670377322605674, 50.83704737254551, 46.389734745025635, 24.043562037604197, 5.427887575966971, 0.22726545216781752, 0.06324866467288562, 0.10751145133482558, 0.20908891037106514, 0.13068904727697372, 0.148976597402777, 0.14486044113125118, 0.18758651560970716, 0.2016612725066287, 0.1727158778480121, 0.143297123589686, 0.10440239709402833, 0.29321859457663124, 0.08682422818882124, 0.06343048491648265, 0.13455945173544542, 0.13779044550444397, 0.16023105063608714, 0.14424511843494006, 0.10202010814100504, 0.09168738366237708, 0.1480093185922929, 0.10412033008677618, 0.15790125993745668, 0.1761110635208232, 0.13310566331659043, 0.11472634811486516, 0.14027019244219574, 0.1395719934787069, 0.1671074466513736, 0.0869337437408311, 0.09542311927569763, 0.06725609927837338, 0.1398165782115289, 0.16876761828150066], [0.03191735768424613, 0.060192699011947425, 0.011425513607848967, 0.011314282210410705, 0.05301055172458291, 0.04217293273125376, 0.05003437160381249, 0.013676602726003953, 0.011407365340606442, 0.056520779617130756, 0.009842350613325834, 0.030919348022767475, 0.03491990567584123, 0.017848390387371182, 0.054154395524944575, 0.02080100159426885, 0.028573021425732543, 0.058812565569366725, 0.009635225254377084, 0.017162308362977843, 0.029812243500990526, 0.04542207391932607, 0.05953126307576895, 0.030876159268830503, 0.023161299227337753, 0.014214336639270186, 0.126917247527412, 0.07861972201083388, 0.0764548492484859, 0.04359117270048175, 0.02575063635595143, 0.11522636057010718, 0.03282431812424745, 0.025623417825305035, 0.04128987368728433, 0.011812664485270423, 0.024822322418913245, 0.04441332983385239, 0.02630258897053344, 0.1979295877473695, 2.594832990850721, 11.124516708510262, 32.49237871170044, 32.51119095938546, 36.37775577817644, 26.49150620188032, 15.141328505107335, 24.255756548472814, 18.776893513543264, 21.01246772493635, 9.67283044542585, 4.291388537202563, 1.0031434574297495, 0.14357387088239193, 0.03586762571441276, 0.4051860464470727, 0.5314114732401711, 3.5845524200371335, 3.1828179998057227, 2.5494592998709, 2.6519489203180586, 1.7567333515201295, 2.221830891711371, 2.2681593086038316, 5.47686151947294, 0.6488248471702848, 2.94598257115909, 4.494069227150508, 7.142002088682992, 12.930222375052315, 16.72719751085554, 20.297781229019165, 25.199969836643763, 29.085916655404226, 33.27074718475342, 35.88639654432024, 38.86381775992257, 43.73641920089722, 46.07807329722813, 45.79247106824602, 51.483747482299805, 51.99026421138218, 52.2353514943804, 53.82369579587664, 53.214717456272666, 52.95322895050049, 52.119108131953645, 49.63227142606463, 37.39619493484497, 41.884984833853586, 40.85182244437081, 50.17259461539132, 47.545029095241, 50.368544237954275, 50.597108704703196, 50.31141267504011, 48.832505975450786, 47.34177344185965, 47.71070541654314, 47.57447556086949, 48.27128260476248, 46.62298229762486, 47.550111702510286, 48.62138843536377, 46.37513310568673, 47.107587882450645, 45.25114039012364, 43.58896105630057, 37.52731786455427, 31.675809042794363, 25.205493654523575, 18.50478642327445, 18.390714372907365, 17.863415581839426, 11.410395996911184, 9.873159170150757, 8.946886999266487, 3.887023789542062, 0.6131519813622747, 1.6954101792403629, 4.518906431538718, 5.088871504579272, 8.752994912011282, 3.387219454560961, 1.5684152394533157, 1.2053933590650558, 0.4149361332612378, 0.3167289101651737, 0.34980708520327297, 1.4748460203409195, 3.6733006749834334, 8.117812309946332, 17.130057539258683, 30.745976788657053, 23.589108160563878, 30.353816986083984, 37.66307176862444, 39.17514916828701, 27.614972591400146, 9.503571459225245, 1.6032898766653878, 0.05337942371677075, 0.0543404362563576, 0.029756057408771346, 0.04389797230916364, 0.01613952199529324, 0.043753600413245816, 0.017877277319452593, 0.03379367325188858, 0.032411188685468266, 0.05726871519748654, 0.055080310840691836, 0.0503352340310812, 0.03003948148606079, 0.059480596865926466, 0.0951885429344007, 0.009817390702664852, 0.027023325474666696, 0.031882392774735174, 0.005187325154630733, 0.03059227378772838, 0.03047283805374588, 0.028089700931949273, 0.02747815428301692, 0.07559917587786913, 0.010659324587322772, 0.022473268111103346, 0.019207828511883105, 0.041105386801064014, 0.06371423469058105, 0.012350285592089807, 0.056704017998916764, 0.01004241157456168, 0.0590237324525203, 0.020875623482944708, 0.011242504231631756, 0.02221749263948628, 0.06757818628102541, 0.016389962485326186, 0.007159775139630905, 0.012500603151108538, 0.018778765374528508, 0.04474723691652928, 0.02114159394321697, 0.05226579847346459, 0.033039423903184276, 0.05501603661105037, 0.03783871226810983, 0.009030103483902556, 0.04394223314843007, 0.03033986554614135, 0.09115347159760338, 0.066261265160782, 0.06059726873146636, 0.05147834501362272, 0.022085288572790365, 0.00593838157198791, 0.05174462929634111, 0.057467587026102204, 0.01856654167308339, 0.04255334321143372, 0.029618708350296532, 0.05956907783235822, 0.02040098145204995, 0.05524326781077044, 0.039058117728148184, 0.09552319640559809, 0.05420622881501913, 0.01265031935846699, 0.009857305525136846, 0.02240492606402508, 0.024497623056439415, 0.10493689948426825, 0.021263952466792295, 0.01513058113466416, 0.28483057181750027, 3.6105223979268755, 15.965951136180333, 38.69686297007969, 39.625996930258616, 38.7253749029977, 30.933223792484828, 19.695306403296335, 26.495973893574305, 20.86031607219151, 22.78862009729658, 10.713657566479274, 4.196822251592364, 0.888832074190889, 0.1442128744508539, 0.09880396071821451, 0.293160077716623, 0.6278846051011766, 1.5610204019716807, 2.3460573000567297, 2.0180910357407162, 4.872588847364698, 6.143518158367701, 4.4052339025906155, 4.68345844745636, 4.299004631383078, 3.70391617502485, 3.8633608307157243, 5.665908106735774, 9.67407330444881, 15.97510712487357, 19.49715941292899, 25.177980525153025, 27.62284663745335, 31.6222106388637, 35.78409821646554, 37.216702120644705, 40.12343236378261, 45.7444485936846, 48.29374960490635, 49.40242501667568, 52.18235758372715, 53.12680537360055, 54.53188051496233, 55.97835302352905, 54.58183111463274, 54.484632764543804, 53.15556049346924, 50.58968455450875, 39.95149571555001, 45.25899880273001, 45.029892376491, 52.264613832746235, 48.891089711870464, 51.20035130637032, 51.69236714499337, 52.54072829655239, 49.47820554460798, 49.85602079119001, 48.91059330531529, 48.02349247251238, 48.047627040318076, 47.97340638296944, 48.555981567927766, 50.002992561885286, 48.075461523873464, 50.80327912739345, 47.062980447496685, 46.23060710089547, 41.405020645686555, 35.914526326315745, 27.95194285256522, 25.512770789010183, 26.35234420640128, 23.9131269795554, 18.82451820373535, 13.705548405647278, 9.06650197505951, 4.378822062696729, 2.575455333505358, 4.651785084179469, 6.187108550752912, 4.7285235949925015, 4.824025281838008, 1.3317934679133552, 1.962442696094513, 0.611610621213913, 0.5883092401283128, 0.16369964022721561, 0.37786146838750156, 0.9876055483307157, 3.8417706063815524, 8.24211037158966, 16.67140347617013, 29.625413009098597, 29.94315413066319, 32.19506876809256, 41.55645315987723, 43.79093476704189, 32.45433732441494, 11.94838980266026, 2.128408019031797, 0.04458842918808971, 0.029252082309020416, 0.014829798435260142, 0.040212041166211875, 0.024209357631791915, 0.08481991716793605, 0.05470470438844391, 0.023075605343495096, 0.002537640817796013, 0.03867691336199641, 0.030457455664873123, 0.04158017132431269, 0.026114860383261527, 0.042969336067991595, 0.03310099756345153, 0.04514831557337727, 0.06425562421126024, 0.03799885331786104, 0.03879602000649486, 0.01994188635476998, 0.032998080764498026, 0.0248968968101378, 0.03687826969793864, 0.09929234986858708, 0.014786631733711277, 0.041877485013433864, 0.08242181156362806, 0.11234960957829442, 0.04390113428235054, 0.03201034412320171, 0.028760565112211874, 0.04475910449400544, 0.036756357311138084, 0.027622906158545187, 0.03810090159199067, 0.08553868931319032, 0.21446908238743032, 0.2347825345184122, 0.08292301145515271, 0.1413065189761775, 0.13655731667365345, 0.12651540551866802, 0.10972732278917517, 0.1297921325479235, 0.11299020091870002, 0.09712884096162659, 0.17343070091945784, 0.13104320184460708, 0.12021047169608728, 0.13546757586300373, 0.1588506389941488, 0.1755189195807491, 0.15701818732278688, 0.14134097498442444, 0.12116966236914907, 0.1283551582268306, 0.17306301636355265, 0.21169280207582883, 0.16457492325987133, 0.07693828509322234, 0.08347559680363961, 0.35414172975080355, 0.11615991619016443, 0.18769881315529346, 0.14175494919930184, 0.12272673738854271, 0.1779655675802912, 0.1915083530225924, 0.1947539352944919, 0.17524409932749613, 0.08547895109014851, 0.13059990134622368, 0.09834917262196541, 0.12138502938406807, 0.4067647803042616, 4.463112831115723, 19.253218582698278, 43.34134462901524, 46.99839346749442, 48.282458782196045, 37.92936495372227, 24.124532869883947, 34.84517771857125, 28.514618396759033, 28.935298817498342, 14.343102949006216, 6.3496955292565485, 1.5689978024789264, 0.4377375697450978, 0.29987537594778196, 0.7403291485139302, 2.432788188968386, 7.594072733606611, 7.856903978756495, 4.688285274165017, 9.528963650975909, 7.726199678012303, 5.631141058036259, 5.304334274360111, 9.536565848759242, 1.9834108395235879, 4.582489396844592, 6.483893036842346, 8.235091822487966, 16.490953547613962, 20.84032784189497, 26.313665321895055, 27.738853761128016, 32.17002051217215, 35.64542606898716, 38.22683123179844, 39.932162352970664, 45.75801842553275, 47.82267563683646, 49.913947922842844, 52.44571515492031, 52.84527478899275, 55.18414265768868, 55.65877062933785, 54.3426775932312, 53.52323137010847, 52.888937268938335, 51.13038294655936, 43.15148510251726, 46.09196274621146, 48.15056460244315, 52.38240664345877, 49.096895354134695, 53.132687023707796, 52.95724153518677, 52.38983774185181, 51.84730849947248, 50.08549894605364, 48.867851461683, 47.108105523245676, 48.40812390191214, 48.38021298817226, 48.587074756622314, 48.5389723777771, 50.14834540230887, 48.99654599598476, 46.88750369208199, 47.258777209690635, 42.00296524592808, 36.515844276973176, 29.876482691083634, 26.31971546581813, 28.138432502746582, 26.528091941561016, 19.290311540876115, 15.120897327150617, 12.058168734822955, 6.392683599676404, 3.85096481016704, 5.9426175100462775, 10.484307084764753, 14.410401463508606, 17.60770971434457, 9.745204618998937, 4.423317023686, 3.6380895929677144, 1.3591161732162749, 0.8855813486235482, 0.7565863047327314, 1.717846998146602, 4.98387553862163, 11.351288540022713, 23.96329297338213, 40.57595116751534, 35.71797568457467, 40.72225591114589, 49.10047367640904, 50.14123044695173, 37.07081774302891, 13.885301777294703, 2.5747767984867096, 0.18896201465811047, 0.1500708708273513, 0.14223623408802918, 0.07587092236748763, 0.2583530768752098, 0.18772129980581148, 0.1519985209618296, 0.1234247192208256, 0.12175578091825758, 0.14266825733440264, 0.15189102744417532, 0.17751934938132763, 0.1416811788720744, 0.10793643817305565, 0.1593257627849068, 0.13377041050365993, 0.13282431555645807, 0.3007269916789872, 0.09436454357845442, 0.11301828548312187, 0.10503874080521719, 0.08186847982662064, 0.10368975890534264, 0.17919386524174893, 0.1074560693066035, 0.11738445476761886, 0.11647312795477253, 0.14799399727157184, 0.12081873762820448, 0.16406595414238317, 0.1315244324505329, 0.09878600668162107, 0.15758047572204045, 0.1361554746649095, 0.11186442311320986], [0.03724795253947377, 0.03403671431754317, 0.021576858890642012, 0.015972795763186047, 0.06801631634256669, 0.04047304305381008, 0.01059239643758961, 0.044454998669347594, 0.01590816699899733, 0.029876422735729387, 0.05926698725670576, 0.01730857676427279, 0.03719530161470175, 0.0559800686314702, 0.024629506515339017, 0.00190061963179947, 0.031408870326621194, 0.04330063757619687, 0.016365294344723225, 0.06597430591604539, 0.05224896062697683, 0.033620443261627636, 0.037633051696632586, 0.03181975720716374, 0.02362696932894843, 0.00853127592043685, 0.07664126317415919, 0.031281471984194856, 0.06722617588405098, 0.055601144142981083, 0.03609810031152197, 0.030878194873886447, 0.022719932553757514, 0.01528378586018724, 0.04670530238321849, 0.01292927358632109, 0.0538052214043481, 0.00954203271040959, 0.01996602863073349, 0.11071067609425102, 0.4419547463102, 7.3768503325326105, 22.902120658329554, 37.92970194135393, 39.94217470714024, 28.313341242926462, 26.587914194379533, 24.585596220833914, 21.93632279123579, 16.718477521623882, 13.017692378589086, 6.862571162836892, 2.0937970876693726, 0.6470117473176548, 0.04202545314495053, 0.16300286618726595, 0.7314454423529761, 0.48338112767253605, 1.587931643639292, 2.2949124787534987, 4.0994367344038825, 2.997070069823946, 2.5823014804295132, 4.10373158965792, 3.765563198498317, 4.195913340364184, 1.9692658271108354, 2.235278044428144, 4.766949738774981, 6.73139351606369, 11.286764962332589, 15.05189824104309, 17.971489599772863, 21.758973496300833, 25.432635477610997, 28.39461258479527, 30.60886103766305, 35.70729977743966, 40.83240222930908, 46.54373114449637, 47.69901507241385, 51.15583419799805, 50.64880330221993, 53.65462875366211, 53.964994362422395, 51.56566326958792, 52.983213901519775, 50.71891757420131, 49.23257630211966, 44.4983343396868, 43.22818974086216, 46.76150853293282, 49.47582231249128, 53.359792368752615, 48.451946190425325, 49.48492792674473, 48.52701800210135, 49.9983720098223, 48.60881219591413, 49.10098089490618, 47.360839298793245, 48.01170832770211, 49.78321409225464, 48.191965443747385, 45.72506659371512, 45.78443200247628, 42.98905011585781, 36.915508134024485, 30.24256590434483, 25.627721786499023, 21.02110607283456, 16.831389222826274, 11.06842998095921, 8.843958122389656, 6.633140776838575, 5.535156037126269, 3.1469090580940247, 1.8447254470416476, 2.8778111892087117, 1.1791949591466357, 1.7649607786110468, 3.6744692751339505, 3.925298375742776, 0.6595451033541134, 0.17497444951108523, 0.1761942926262106, 0.24075825672064508, 0.15099076075213297, 0.8260390322123254, 2.3905288108757565, 4.316468494279044, 11.979723572731018, 20.421678032193864, 25.993598290852137, 26.47363543510437, 28.53052282333374, 36.86826038360596, 38.45124762398856, 20.348199095044816, 8.071183817727224, 0.3620903603732586, 0.06945961461003337, 0.005491497560537287, 0.05936779720442636, 0.014712897029572299, 0.042374807077326944, 0.027145941841549108, 0.016000493562647274, 0.022363489626773765, 0.029408925678581, 0.050879242696932385, 0.047257660422474146, 0.04761977759855134, 0.02810381106766207, 0.02546424199161785, 0.01145293575245887, 0.03321532053606851, 0.07700332267475979, 0.07270402980170079, 0.0593311766694699, 0.08989716401057583, 0.006070147983596793, 0.06097038156752076, 0.020152435771056583, 0.03783241207046168, 0.011866572396164494, 0.014828358244683062, 0.033919711131602526, 0.05063234415969678, 0.04468791259984885, 0.0715142661439521, 0.055435924258615286, 0.022566405524100577, 0.041855246028197665, 0.06075510276215417, 0.062069859355688095, 0.025561255535909107, 0.04573218817157405, 0.007557521341368556, 0.038355986654226265, 0.025296194312561835, 0.01672881099927638, 0.02068235126457044, 0.00528362878165873, 0.015423089099515761, 0.019782946312001774, 0.04981707415676542, 0.038782367881919654, 0.030691241512873342, 0.042229095074747286, 0.014941037466217364, 0.019297695386090448, 0.02977723448670336, 0.08615025971084833, 0.05791788322052785, 0.016336127516946623, 0.03548507445624896, 0.053281972517392466, 0.021905432688072324, 0.035843860025384595, 0.0331860044305878, 0.044099235973720036, 0.06605893958892141, 0.023219880548172762, 0.039574601620967896, 0.03525811127786126, 0.08721123742205755, 0.05448575810130153, 0.049414509508226595, 0.04630589970786657, 0.07316174238388028, 0.06787023453840188, 0.03604598542941468, 0.03501321781160576, 0.011663497043108302, 0.0724909155230437, 0.8490129251565252, 9.794275403022766, 29.42009026663644, 41.48920501981463, 45.088225977761404, 33.73524815695626, 27.45997565133231, 29.45115566253662, 23.84256454876491, 21.654536860329763, 13.232306599617004, 7.3273235729762485, 1.96423858829907, 0.44566459581255913, 0.04735526429223163, 0.2001532827104841, 0.6932981493217605, 0.9880653236593518, 1.4730330833366938, 3.2174000527177538, 2.448974451848439, 5.776412257126399, 3.87219546522413, 1.9401565662452152, 4.8795817749840875, 6.323974166597639, 3.472079975264413, 3.030196692262377, 8.155810270990644, 10.155860526221138, 14.187694328171865, 18.56675045830863, 22.073841537748063, 24.52605537005833, 26.724856240408762, 31.591155665261404, 32.85754476274763, 37.894484996795654, 43.208974497658865, 48.02901976449149, 50.264064175742014, 52.852167401994976, 51.9197747366769, 54.93245806012835, 54.89792898723057, 53.09096309116909, 52.557504722050254, 51.71579647064209, 49.169768060956685, 46.916779926845, 45.255288464682444, 50.2347914150783, 50.09525074277605, 53.20087317058018, 49.714850766318186, 50.432891505105154, 50.495567730494905, 52.154179164341514, 49.77810716629028, 50.38466058458601, 49.21255159378052, 50.15674924850464, 50.34767532348633, 49.649565492357524, 48.21496745518276, 47.49544675009591, 45.31117977414812, 39.4607583454677, 34.23454918180193, 29.85259825842721, 24.042907169887, 19.35128024646214, 14.198670744895935, 14.082865118980408, 10.221325584820338, 8.253825902938843, 4.891930460929871, 4.828535531248365, 3.1731148404734473, 4.513577597481864, 6.022719817502158, 4.302992463111877, 5.551177714552198, 0.9597413178001131, 1.031436630657741, 0.342303709260055, 0.05635921364384038, 0.2164959479123354, 0.6099776859794344, 2.5116745616708482, 4.623489413942609, 12.225914750780378, 20.682582889284404, 30.699990136282786, 28.515752690179006, 33.019997119903564, 41.86056538990566, 43.94392715181623, 24.692952837262833, 9.50713414805276, 0.547804770725114, 0.026046268974563906, 0.011881644355266221, 0.028557934199592898, 0.01006674553666796, 0.06561145931482315, 0.023569755256175995, 0.01904585541758154, 0.07545115346355097, 0.03355837766347187, 0.057127294928899834, 0.05196691058310015, 0.07392537247921739, 0.032966800300138335, 0.029324590561113188, 0.05857856598283563, 0.03391699020617774, 0.02341694916997637, 0.06031889295471566, 0.016882901212998798, 0.029894580332828418, 0.07215530531747, 0.05433094355144671, 0.031183627234505754, 0.03929001385612147, 0.030756659074021236, 0.040400317670511346, 0.061553887756807465, 0.034047051798552275, 0.039090019052049944, 0.04650615914059537, 0.030778548613722836, 0.011725643217297537, 0.03371464088559151, 0.031107417573886256, 0.024686277844011784, 0.08258602382349116, 0.13418408616312913, 0.12635451129504613, 0.055170111557734866, 0.16496581371341432, 0.17311636278671877, 0.1375316386776311, 0.14073162339627743, 0.15829072546746048, 0.1385841550571578, 0.06773314332323414, 0.07958793719964367, 0.15230923571756907, 0.2176823935338429, 0.20168127571897848, 0.21629652647035463, 0.1461180243641138, 0.2013007668512208, 0.08414167391934566, 0.14286149053701333, 0.09334098028817348, 0.17400836492223398, 0.10998137987085752, 0.11375841791076319, 0.10781844771866288, 0.1332545474703823, 0.1353272683918476, 0.21261537899928434, 0.1205994893929788, 0.12009818772120134, 0.1449157688766718, 0.15959066285618714, 0.11729669304830687, 0.12400467667196478, 0.1475372074970177, 0.16204835740583284, 0.1698807142674923, 0.10539453064224549, 0.10058314060526234, 0.2058305580701147, 1.3255117535591125, 11.920191407203674, 34.72474806649344, 50.6679699080331, 51.822972433907644, 41.225982938494, 38.132703985486714, 37.565988063812256, 34.225822244371685, 26.714930738721574, 17.5753276348114, 8.807999457631793, 2.6707411919321333, 0.833162455686501, 0.3274065543498312, 0.6761343074696404, 1.6300662798540932, 1.6786063952105386, 2.9837827256747653, 5.377551785537174, 8.344070843287877, 8.713050586836678, 8.637684345245361, 8.450551118169512, 11.22129556110927, 8.257183619907924, 2.5457667665822163, 4.719891761030469, 7.181385346821376, 10.686516165733337, 14.433904613767352, 20.135346242359706, 20.90750128882272, 24.329926831381663, 26.861468247004918, 31.097159590039933, 32.01012856619698, 39.30800914764404, 43.16237987790789, 48.748665537152974, 50.900738034929546, 55.48390531539917, 53.008199623652864, 55.93826191765921, 55.16184936250959, 53.157023089272634, 51.81869581767491, 51.760984080178396, 48.04953779493059, 50.81148842402867, 46.93319157191685, 51.659453528267996, 51.56102534702846, 55.62462370736258, 50.542252676827566, 52.38359825951712, 50.56046737943377, 53.05115338734218, 50.84378712517874, 52.56197241374424, 49.02793448311942, 49.873669215611045, 51.34099326814924, 50.46334545952933, 48.426897934504915, 47.10222039903913, 44.24535737718855, 39.1650047983442, 33.81626067842756, 27.977341992514475, 24.94157154219491, 19.269923789160593, 14.004264490944998, 11.73292008468083, 9.570446133613586, 7.767365149089268, 4.526287589754377, 3.5854198592049733, 5.871688996042524, 7.953045334134783, 6.729605223451342, 7.814118708883013, 9.198180760656085, 5.43498125246593, 4.351980737277439, 1.3861385860613413, 0.415529552847147, 0.8189635404518673, 0.9121426833527428, 3.474418478352683, 6.27989045211247, 16.981715236391338, 26.85211944580078, 36.78021281106131, 37.13809714998518, 40.18859951836722, 49.21924270902361, 50.045098645346506, 28.351820366723196, 11.003591997282845, 0.7688446098140308, 0.16152280489248888, 0.08414961956441402, 0.19451674659337315, 0.04602658076743994, 0.14655878714152745, 0.15303761591868742, 0.08903950253235442, 0.13180136973304407, 0.06569473591766187, 0.11188617694590773, 0.1241486482322216, 0.09535631071776152, 0.12459914120180265, 0.10314922433878694, 0.10224228764751128, 0.07135926838964224, 0.12191473453172616, 0.17267201734440668, 0.1463067385235003, 0.14689031935163907, 0.1251923300858055, 0.12411401580486979, 0.11252863425761461, 0.1375317336725337, 0.2084407601505518, 0.07583416612552744, 0.14281273101057324, 0.2328087847147669, 0.12965856971485273, 0.2608522299144949, 0.11844925263098308, 0.1384810855878251, 0.122797481449587, 0.11002017171787364, 0.14847302942403726], [0.050554648507386446, 0.01865194209053048, 0.02797129826753267, 0.06324263928192002, 0.03027639538049698, 0.030421320282455002, 0.06400355523718254, 0.05277416030211108, 0.019059565217633332, 0.0760034741833806, 0.050060949820492945, 0.04655046747731311, 0.0073791913122736984, 0.06599218531378678, 0.04446168902463146, 0.0417798234681998, 0.11305809513266597, 0.014538158995232411, 0.032708393808986456, 0.045142653198646646, 0.02544633036346308, 0.049672169610857964, 0.008107758958690932, 0.03053716995886394, 0.03461965053741421, 0.03150452680087515, 0.04382616973349026, 0.08490350589688335, 0.025818310046036328, 0.05140964673565967, 0.02939860855362245, 0.037182629973228486, 0.018964232743850777, 0.03972430340945721, 0.07937206128346068, 0.016812669445893595, 0.025352977515597428, 0.05651254898735455, 0.0534033929663045, 0.02561117196455598, 0.06994293510381665, 5.4485523871013095, 16.913199050085886, 31.30285406112671, 42.156850474221365, 35.023951394217356, 29.189625467572892, 14.543802533830915, 19.463915756770543, 16.579402378627233, 15.306692157472883, 8.752749988010951, 3.331604770251683, 1.0720548225300652, 0.12145699480814592, 0.1056839936812009, 0.8335156738758087, 0.8833408802747726, 0.5752239365662847, 2.536341969455991, 2.145327751125608, 6.3232763069016595, 3.632100680044719, 1.8337779087679726, 1.2688021851437432, 3.688450787748609, 1.2461304302726472, 0.32862409044589314, 4.454932630062103, 3.7757058313914706, 5.272930153778621, 8.387424996920995, 13.160535182271685, 15.293612173625402, 18.230556658336095, 19.86567623274667, 24.573973621640885, 31.496079989842006, 35.55180604117257, 40.48042038508824, 44.73152978079659, 46.545006138937815, 51.20833478655134, 51.2627808707101, 51.6750487600054, 51.73361165182931, 53.93351207460676, 48.017141819000244, 49.69790063585554, 48.69995519093105, 43.77157013756888, 54.005015986306326, 52.247135639190674, 50.09226996558053, 48.38600083759853, 47.22126735959734, 50.17396688461304, 49.055803707667756, 47.68718923841204, 50.77715737479073, 50.11180135181972, 50.00223868233817, 49.79599877766201, 48.699187414986746, 44.503945010049, 41.94642775399344, 33.833919525146484, 27.564447028296335, 20.55306499344962, 15.55265838759286, 11.057814002037048, 8.373191612107412, 5.623549716813224, 4.047786865915571, 2.131429834025247, 3.195282199553081, 1.1031727641820908, 1.9788958132266998, 2.3917577735015323, 6.516630777290889, 6.406919590064457, 2.4242948847157613, 3.557976646082742, 0.9031897666198867, 0.5914152477468763, 0.3670476829367024, 0.3382033221423626, 0.3848438651434013, 1.0666000523737498, 4.9663995163781305, 10.312647495950971, 15.956029108592443, 30.95817129952567, 25.76986629622323, 27.411756890160696, 33.40343345914568, 37.111502919878276, 33.73347289221627, 14.84525534084865, 3.0169818699359894, 0.15260780469647475, 0.022875069407746196, 0.011928181679520224, 0.03851693855332477, 0.08900837134569883, 0.014736630488187075, 0.06279530150017568, 0.027064312382468154, 0.004132634070369282, 0.019293424008148055, 0.07053857349923678, 0.009528953947925141, 0.03926272317767143, 0.049094390257128646, 0.0020802053747632143, 0.04215721446754677, 0.029300112410315444, 0.01827585218208177, 0.06394476017781667, 0.008349123194680681, 0.03908141522801348, 0.019401300898087875, 0.006452496529423765, 0.02755730878561735, 0.035758720843919685, 0.010949645124908005, 0.00705941641769771, 0.020559417682566812, 0.01155351075742926, 0.11349471206111567, 0.04908299086881535, 0.029825739562511444, 0.0216060833938952, 0.049553568474948406, 0.056100881791540554, 0.04647766745516232, 0.060535406693816185, 0.09354999621531793, 0.03630119602062872, 0.05296986676486475, 0.018106500019452403, 0.02045044326223433, 0.017489989886858633, 0.03968317061662674, 0.013557271316780575, 0.10098402587963001, 0.03373554315684097, 0.04083313819553171, 0.08037344326398202, 0.06688323750027589, 0.03052266627284033, 0.04387095983007124, 0.05189772375992366, 0.02422471627193902, 0.04589354040633355, 0.06408060967390027, 0.009726674811515425, 0.1025404834321567, 0.01771898358128965, 0.06539490486362151, 0.014143701143828886, 0.03332407952153257, 0.025379286014607975, 0.018121834910873855, 0.027881392377561758, 0.014211960918536144, 0.026581093668937683, 0.03495348298123904, 0.04910498897411993, 0.017731587369261042, 0.03715305941711579, 0.0005011792704213544, 0.01125452617582466, 0.03276364352287991, 0.03128291726378458, 0.08082245024187223, 0.19149273314646312, 6.825699244226728, 21.20735948426383, 39.009208815438406, 46.830087253025596, 39.61382368632725, 33.73767307826451, 19.690063987459453, 23.602497339248657, 18.519627775464738, 17.13643077441624, 10.344068987028939, 3.90392050572804, 1.1043710027422224, 0.19348497981471674, 0.048247232500995905, 0.05740683100053242, 1.496665535228593, 1.3441290174211775, 3.5784188977309634, 3.0693441459110806, 4.591313174792698, 5.20417468888419, 0.7947442371930394, 1.602988172854696, 3.5529960904802596, 4.34545464175088, 1.7336107236998421, 5.684587470122746, 6.338856773717063, 6.263741101537432, 9.63096581186567, 17.19616096360343, 19.48107954433986, 20.10190282549177, 22.6493729863848, 27.332863569259644, 33.190293993268696, 37.4396767616272, 43.08740186691284, 45.70708465576172, 49.15785884857178, 52.6740642275129, 53.462608337402344, 53.731013774871826, 53.26489734649658, 54.55982269559588, 48.94700881413051, 49.91238457815987, 51.738697733197895, 46.11562136241368, 52.4267326763698, 53.645714214869905, 52.989508969443186, 51.78729690824236, 49.254233837127686, 51.08854784284319, 50.36983660289219, 50.53171573366438, 52.24547849382673, 52.10755327769688, 51.93024219785418, 50.45332963126046, 50.67447689601353, 46.5090457371303, 43.309424604688374, 34.72847230093819, 30.428590025220597, 24.051241534096853, 18.87630660193307, 14.320285064833504, 10.707192267690386, 7.739506346838815, 6.379470297268458, 4.402949248041425, 3.9679412075451443, 2.1270648453916823, 2.3761106474058966, 1.7851019778421946, 3.4056864636284963, 7.5696263653891425, 3.0561247638293674, 5.778711676597595, 1.206400413598333, 0.5396327120917184, 0.6426272168755531, 0.2813475430011749, 0.31899166160396164, 1.1334185983453477, 4.826889676707132, 10.261316810335432, 15.643763167517525, 26.34484362602234, 27.94092127255031, 30.271116052355083, 36.11816413061959, 41.5260408946446, 37.77831111635481, 17.791942937033518, 3.8655820829527716, 0.18731291671948774, 0.1079865615548832, 0.016729087502296482, 0.05950855250869479, 0.12729947987411702, 0.017418244986661842, 0.04199898349387305, 0.08664505423179694, 0.01595324886563633, 0.019768162730282972, 0.03791078286511557, 0.006954155280254781, 0.03787364325086985, 0.019993083518264548, 0.034068418866289515, 0.02775013486721686, 0.07620560298008577, 0.10407583176025323, 0.02230153089788343, 0.018320021419120685, 0.023419164586812258, 0.008925804169848561, 0.027836846553587487, 0.019516587390431335, 0.050866971391120126, 0.03336529713124037, 0.02646377496421337, 0.025540678961468593, 0.03932859535728182, 0.05805325095674821, 0.005350703240505287, 0.01116211140262229, 0.04084934839712722, 0.029674650169909, 0.010714838929873492, 0.054551599746836085, 0.245261015104396, 0.16458394777561935, 0.14371014785553726, 0.08450890385678836, 0.09144387780023472, 0.16892768469239983, 0.14870860321181162, 0.1742126311042479, 0.15622434206306934, 0.20741982279079302, 0.12330642342567444, 0.1544803577874388, 0.1997823818985905, 0.2027817645243236, 0.13188943000776426, 0.14450226963630744, 0.1657180647764887, 0.14151900900261744, 0.12009349225887231, 0.11466115447027342, 0.13738819637468883, 0.14098346845379897, 0.11201007065496274, 0.15184040873178414, 0.12435556070080825, 0.13778166526130267, 0.0993266769551805, 0.18176110248480523, 0.07728041602032525, 0.08674058517707245, 0.1170158881161894, 0.10614465110536132, 0.12794881074556283, 0.0967856515198946, 0.2277910453932626, 0.08829189943415777, 0.10365737242890255, 0.14214338335607732, 0.08729571503187929, 0.19223412764923914, 0.38654006698301857, 8.554504854338509, 25.550108671188354, 43.85618530000959, 54.27394253867013, 47.23957238878523, 41.585451466696604, 24.753716570990427, 31.65911599567958, 26.34308746882847, 21.663597311292374, 13.264719946043831, 5.499817064830235, 1.467274112360818, 0.3856455949800355, 0.5593745527522904, 1.4598180438791002, 3.70113559280123, 3.408833997590201, 5.616960653236934, 6.721422851085663, 9.567390663283211, 7.525916116578238, 5.2330657328878125, 3.2474208303860257, 6.358501068183354, 4.587069562503269, 2.0737695566245486, 6.087124407291412, 6.937046732221331, 7.731039966855731, 11.68942870412554, 19.348483596529277, 19.728715079171316, 19.83254201071603, 23.595924343381608, 28.49565155165536, 35.06133617673601, 37.04829863139561, 45.178027970450266, 46.75427198410034, 50.284745488848, 53.45310320172991, 53.96194062914167, 53.86927945273263, 53.716075147901265, 54.74183075768607, 48.800356660570415, 51.78509085518973, 54.51102202279227, 48.51974671227591, 56.58223138536726, 54.54067693437849, 54.2698153087071, 51.486790793282644, 51.58691086087908, 51.6516889163426, 51.32823984963553, 50.832273960113525, 53.38690423965454, 51.76331867490496, 51.567198821476524, 50.18446561268398, 51.35741880961827, 47.389076777866904, 42.53669459479195, 34.172553879874094, 29.48540333339146, 23.781072991234915, 19.221237761633738, 13.385556936264038, 10.491194486618042, 7.004348720823016, 6.258356247629438, 4.3572426949228555, 5.515952953270503, 2.1638053996222357, 5.146654895373753, 6.2282444919858655, 12.51859198297773, 15.403834921973091, 6.912274232932499, 7.146003382546561, 1.8732217465128218, 2.0423977885927473, 1.339309681739126, 0.6939183303288051, 0.6189032984631402, 1.5042197470154082, 5.970585746424539, 13.699195146560669, 21.45654967853001, 40.368967805589946, 35.33261122022356, 39.3988881111145, 43.827899183545796, 49.390765939440044, 41.98755414145333, 21.2107241494315, 4.429917812347412, 0.29721541010907715, 0.18062398635915347, 0.11532082621540342, 0.22213874012231827, 0.2260507523481335, 0.12574848452849047, 0.1457313679690872, 0.1613779512367078, 0.12024091077702385, 0.1996082291007042, 0.2015339657664299, 0.040394363525722704, 0.151068045890757, 0.19784733573240892, 0.15960922757429735, 0.09647688415965863, 0.17833382210561208, 0.11397877894341946, 0.19787865690886974, 0.12002475666148321, 0.11118968110531569, 0.10743795920695577, 0.18565598848674977, 0.1101333513589842, 0.11106424033641815, 0.08823748771101236, 0.09644149177308593, 0.14768905006349087, 0.05482575503577079, 0.31934097143156187, 0.05600780375035746, 0.11210084506975752, 0.11006427649408579, 0.10705741641244718, 0.14045844519776957, 0.11153992052589144], [0.06434788461774588, 0.03231758477964571, 0.028040200106001327, 0.03680506594745176, 0.07578071792210851, 0.019447968840332966, 0.03195235991318311, 0.05111676048753517, 0.03489328674705965, 0.018951481374512826, 0.01833720871114305, 0.035548575155969174, 0.014679350258250321, 0.008693000501287835, 0.0601543075005923, 0.09801033258970294, 0.06286194720970732, 0.022342840109818747, 0.03351069700771144, 0.038326921606702466, 0.038966247479298284, 0.06706543093813316, 0.05998957955411502, 0.02812567346596292, 0.010359443491324782, 0.0639419781842402, 0.07701743620314769, 0.007278912318205195, 0.05883914378604718, 0.027485012575717907, 0.04114154253953269, 0.05154795252851077, 0.013402070850133896, 0.018266637676528523, 0.08573393097945622, 0.009317666624805756, 0.03275328568582024, 0.06900534220039845, 0.021394926688766906, 0.05919704386698348, 0.10310965217649937, 1.7400662515844618, 11.485242860657827, 25.35086907659258, 38.72000394548689, 42.18738085883004, 33.040379660470144, 35.999429838997976, 19.377355098724365, 20.94041316849845, 22.363560574395315, 14.492078406470162, 5.319927334785461, 2.4772714248725345, 0.3819657638669014, 0.30743439176252907, 0.09699643163808755, 0.6831364631652832, 0.732578595834119, 4.981342051710401, 1.2800420905862535, 4.165042059762137, 4.968773194721766, 0.3480397457523005, 1.5250060430594852, 3.45609673006194, 3.8413224475724355, 0.6600206749779838, 2.8196182889597754, 1.0630700417927332, 1.6873129223074232, 2.4832358019692555, 6.723737035478864, 7.316270726067679, 8.376100301742554, 13.131767903055463, 17.24897595814296, 20.067608254296438, 23.743266105651855, 30.547769001552037, 38.418848173958914, 43.4539749281747, 46.429447174072266, 50.692934785570415, 51.14838225500924, 51.42781448364258, 51.05881997517177, 48.9027418409075, 53.74730382646833, 53.582728794642854, 51.71058184759957, 52.20289298466274, 48.68279314041138, 49.68529312951224, 49.50619288853237, 48.48526975086757, 49.02331393105643, 49.843604360307964, 48.47214807782854, 50.33974742889404, 50.89866747174944, 49.26975263868059, 48.105905055999756, 44.65075349807739, 38.12676327569144, 33.139947346278596, 26.89077922276088, 17.60637739726475, 14.305897082601275, 11.107882721083504, 7.404388649123056, 3.3719540451254164, 1.9069776151861464, 1.3777626412255424, 1.303137685571398, 1.2164420804807117, 0.9515239873102733, 1.413762018084526, 0.5946240127086639, 2.029981140579496, 6.581295924527304, 3.6422409244946072, 7.34840875012534, 1.217242426105908, 0.2798239876117025, 0.45208777114748955, 0.12403949908912182, 0.52964527372803, 2.206956318446568, 6.624339146273477, 14.81843182018825, 22.077161039624894, 23.96259467942374, 23.660731928689138, 24.493310247148784, 33.71931593758719, 36.168479510716026, 23.671788249697002, 9.865328550338745, 0.7400208222014564, 0.09925986839724438, 0.04313951604334371, 0.03338584317160504, 0.07130056153982878, 0.007730295016829456, 0.03883250822712268, 0.044697768320994716, 0.033275866215782504, 0.01468541975399213, 0.04759621547002878, 0.014167217471237694, 0.03223625557231052, 0.01136999502445438, 0.013484327954107096, 0.05554629476474864, 0.09276609827897378, 0.031620359513908625, 0.01910230953113309, 0.01214550796430558, 0.01411761062419308, 0.057858708181551526, 0.0056648110954224, 0.02013687526674143, 0.02435563281843705, 0.039864885687295876, 0.018262442633775727, 0.009833489794151058, 0.012827901302703788, 0.014526593365839549, 0.051861072690891366, 0.01567672209681145, 0.024412124251414622, 0.060921323485672474, 0.051974140373723846, 0.0652265263987439, 0.012005666137806006, 0.05022233258932829, 0.00864275498315692, 0.020388382753091197, 0.01058285538705864, 0.021643667448578135, 0.03168955312243529, 0.03807610792240926, 0.04423160119248288, 0.05087013336430703, 0.03277475792648537, 0.08070853778294154, 0.029325058750276054, 0.025848348791311895, 0.03831257737640824, 0.036591117070721726, 0.03920037938015802, 0.08916805777698755, 0.03848476581541555, 0.026313384462680136, 0.05333174306101032, 0.04182870513094323, 0.03140874479764274, 0.04259927324684603, 0.03798837673717311, 0.06551405561289617, 0.012007054590087916, 0.02662358692448054, 0.011610580641510231, 0.0503919120611889, 0.01696969771624676, 0.04025560989975929, 0.03581707824819854, 0.047375420174960575, 0.029089858156761954, 0.11746373479919774, 0.025590790468933325, 0.040001827624759505, 0.008788098880488957, 0.06720643051500831, 0.04508985299617052, 0.09466109052300453, 2.968943761927741, 13.697851538658142, 29.313056741441997, 46.41747890199934, 47.27600874219622, 37.73796987533569, 32.918681962149485, 22.447190829685756, 22.770606892449514, 22.966014555522374, 14.01096168586186, 5.584295434611184, 2.323573580810002, 0.4194451341671603, 0.08744287570672375, 0.07252539867269141, 0.3103603704699448, 0.5426914393901825, 1.1802207955292292, 1.808767325111798, 2.1094800404139926, 3.9654133660452704, 0.5043464483959335, 0.2557228851531233, 1.2906907477549143, 4.619950609547751, 2.00240786586489, 1.8861336708068848, 2.233795472553798, 2.2638716186795915, 2.654349522931235, 7.885097163064139, 10.941805141312734, 11.56666532584599, 14.709499699728829, 18.099242653165543, 22.010076182229177, 27.79893830844334, 33.11553137642996, 39.82497596740723, 46.312797342027935, 48.35113477706909, 52.74556119101388, 53.323630469185964, 51.467797892434255, 51.73856919152396, 50.06644351141793, 53.84959173202515, 54.19667509623936, 51.823351110730854, 55.23848451886858, 50.29518863133022, 51.19192661557879, 51.52764272689819, 50.53236539023263, 51.23054122924805, 50.90329497201102, 50.81987837382725, 52.70353501183646, 54.02798673084804, 52.61624131883894, 50.09583786555699, 47.456738335745676, 43.40539312362671, 34.16041885103498, 29.083891255514963, 21.197548627853394, 18.510586432048253, 13.612117716244288, 9.618102959224156, 6.218087528433118, 5.312127113342285, 2.9156623695577895, 1.268676140478679, 1.2569636489663805, 0.10967751153345619, 0.27568937518766945, 0.2090331483632326, 1.2607963404485156, 6.146475485392979, 3.0491229338305335, 2.9179876276424954, 0.38294730548347744, 0.18712805663900717, 0.32663082597511156, 0.12340857008738176, 0.5771551015121597, 1.8433312475681305, 7.978662473814828, 15.566106625965663, 26.52025089945112, 31.72045816693987, 24.9343158858163, 29.350959164755686, 37.45159639630999, 42.114059993198936, 28.32677037375314, 12.298711027417864, 1.0354454155479158, 0.003029452541211088, 0.03550487071541803, 0.013652467235390629, 0.014954119621376907, 0.03095045206802232, 0.043912757587219985, 0.03413335806024926, 0.027882583206519485, 0.07679035088845662, 0.04638638074642845, 0.02298082926842783, 0.008174354626264955, 0.03463840524532965, 0.03373701557783144, 0.032129257385219843, 0.0390629794315568, 0.0382318690286151, 0.05623126568804894, 0.01751100581272372, 0.011729035892390778, 0.056858520422663004, 0.016156254668853114, 0.05794028166149344, 0.1104978264442512, 0.009525708006029683, 0.03270838363096118, 0.00936229302481349, 0.007236987335740456, 0.008486574881577065, 0.04038933218855943, 0.015881821180560758, 0.07486174401960202, 0.06855934791799102, 0.051116285513022115, 0.05012681182207806, 0.04443761120949473, 0.12333564114357744, 0.12520299665629864, 0.11178044761930193, 0.1375969408878258, 0.13855630797999247, 0.14488638831036432, 0.16567059446658405, 0.14409798490149633, 0.12999622231083258, 0.06837259472480842, 0.07340830165360655, 0.13635550678840705, 0.1415740924754313, 0.1482507006398269, 0.12197203002870083, 0.14863853768578597, 0.1384507686431919, 0.10979263857007027, 0.1782954577356577, 0.11204232820974928, 0.0945297261433942, 0.13426012279731886, 0.1019153016220246, 0.206316172012261, 0.15843608123915537, 0.13871038971202715, 0.1608787937355893, 0.0884395893663168, 0.19554623349436692, 0.1226498322295291, 0.14839440078607627, 0.12154206952878407, 0.08825595743421998, 0.09448955008494002, 0.2696179524064064, 0.1857317808483328, 0.11346681070114885, 0.16562703251838684, 0.15700182105813706, 0.09719412960112095, 0.25931741084371296, 3.352484758411135, 16.952011687414988, 36.164157731192454, 52.982741424015586, 54.56858784811837, 44.70159346716744, 47.22573505129133, 30.347959654671804, 32.330749716077534, 30.517405373709543, 18.078378949846538, 7.438886455127171, 3.236917108297348, 0.8801435689840997, 0.32777489029935425, 0.23181597941688128, 2.2790603807994296, 2.9623403676918576, 9.06390769141061, 5.40287058694022, 7.193638060774122, 9.885871767997742, 0.5245267855269569, 6.036716963563647, 8.868391462734767, 9.306768076760427, 2.783132863896234, 5.075641700199672, 3.2056193820067813, 2.5203083498137335, 3.9327889680862427, 10.457563468388148, 13.525158405303955, 12.456904138837542, 16.67939043045044, 18.219172034944805, 22.888510874339513, 29.25023112978254, 33.224385329655235, 41.24219308580671, 46.787873472486226, 50.37424176079886, 53.5955308505467, 54.29136167253767, 51.858165059770855, 52.4955233165196, 50.76082910810198, 54.560361180986675, 55.789862292153494, 56.93600239072527, 57.08251905441284, 52.62754603794643, 52.014937264578684, 51.83931459699358, 51.870942796979634, 54.00298363821847, 53.77910573141915, 51.83921732221331, 53.212146622794016, 54.40935598100935, 51.571944441114155, 50.85092639923096, 48.967109952654155, 44.00953204291207, 35.130394322531565, 30.62409496307373, 20.788013117653982, 18.253298112324305, 14.743983609335762, 9.72259431225913, 6.553665978567941, 5.570689993245261, 5.187155076435634, 4.579308858939579, 3.22183495759964, 3.442226388624736, 3.557975560426712, 3.753753432205745, 5.984290199620383, 11.29844662121364, 9.622862475258962, 12.942900231906346, 2.8399849789483205, 0.28198485023209025, 0.7254493641001838, 0.28200108078973635, 1.0563032563243593, 2.715202931846891, 8.731074213981628, 18.13569290297372, 30.01587745121547, 33.59180607114519, 32.92893750326974, 35.645874227796284, 46.06443050929478, 48.33654703412737, 33.25294589996338, 14.564345751489912, 1.5364324642079217, 0.1415647558335747, 0.10073791444301605, 0.15170574667198317, 0.09804026955472571, 0.09954640016491924, 0.1399710670645748, 0.11694320344499179, 0.078611722082964, 0.19041226112416812, 0.11410797201097012, 0.09828392469457217, 0.09545533611838307, 0.09595980654869761, 0.1256106604955026, 0.10917634556868247, 0.1324661033494132, 0.10971167577164513, 0.11283307934978179, 0.14363098996026175, 0.11563140526413918, 0.1061408988067082, 0.11757513667855944, 0.2139784608568464, 0.14654342510870524, 0.16143144693757805, 0.13271475929234708, 0.10519318894616195, 0.0634749425309045, 0.16826513595879078, 0.17083975566284998, 0.06984319724142551, 0.1330412296312196, 0.1524059133870261, 0.1645077211516244, 0.11360325730804886, 0.1071054974038686], [0.019157264082293426, 0.04442544846928545, 0.03314931604212948, 0.1067705928747143, 0.013032236186388348, 0.07841124212635414, 0.08535226860216685, 0.02529871167748102, 0.008876408516828502, 0.05216571116553886, 0.012718014252771224, 0.07056941291583435, 0.0329359439201653, 0.05568527230726821, 0.10723294663642134, 0.03468258466039385, 0.02959346006225262, 0.040886416765195985, 0.01982835726812482, 0.04464346855612738, 0.05102760098608477, 0.017268612748011947, 0.04043640894815326, 0.027979513630270958, 0.03148173141692366, 0.03862454402925713, 0.014396565700215953, 0.035543360614350865, 0.03946397666420255, 0.0061240372347778505, 0.04498587768258793, 0.02585985674522817, 0.032490092130111795, 0.06768575443753175, 0.030716496586267437, 0.0356602145225874, 0.07507457331355129, 0.04889306213174548, 0.039105917127536874, 0.03524027598489608, 0.04457623930647969, 0.45955412622009006, 5.568173008305686, 22.940841232027324, 40.71556479590279, 40.36595228740147, 36.50724935531616, 30.72039352144514, 25.531167881829397, 23.715471574238368, 27.722202403204783, 16.735439811434063, 8.40069431918008, 3.901021804128374, 1.061434609549386, 0.2441835557775838, 0.15272453986108303, 0.26231973831142696, 0.14012732010866913, 0.08175548338996512, 1.4501363805362155, 1.450420605284827, 2.889205800635474, 0.3270666354468891, 0.2992599175444671, 0.6134388659681592, 2.9415528774261475, 2.3489136610712325, 1.209219319479806, 0.9450148280177797, 0.4347588824374335, 0.9116955016340528, 2.460583371775491, 3.674638637474605, 4.885353556701115, 5.809815721852439, 7.980971012796674, 10.641084500721522, 13.949695076261248, 19.835404668535503, 26.35141314779009, 36.25759015764509, 41.01353134427752, 45.12864712306431, 48.027122906276155, 48.912323406764436, 50.40885421207973, 45.596340792519705, 46.69261714390346, 50.96224001475743, 49.187183720724924, 48.235992704119, 50.60813896996634, 48.06105443409511, 49.627296515873496, 49.29355716705322, 48.965567452566965, 50.28673267364502, 48.94141204016549, 50.20953123910086, 50.2460926600865, 43.460148402622764, 39.397175380161826, 32.16645956039429, 26.068051712853567, 17.864339692252024, 13.87222787312099, 7.962489673069545, 6.411958771092551, 3.7676563433238437, 2.2616258306162695, 2.1001618547098975, 1.3583492657967975, 1.1234401166439056, 0.1413600825305496, 0.19976389860468252, 0.19994228546108517, 0.18703964352607727, 0.27804473308580263, 0.5784159281424114, 6.126314852918897, 1.4603055034364973, 1.8719332899366106, 0.11387649657470839, 0.38703594037464684, 0.3133229629269668, 0.7251705676317215, 1.4015508847577232, 4.1975166371890476, 9.31717734677451, 19.384079217910767, 15.37320031438555, 16.009043863841466, 25.157144614628383, 27.936213868004934, 34.714461258479524, 35.82209096636091, 17.523466280528478, 3.323367029428482, 0.27829180125679287, 0.048633230717054436, 0.02311421907506883, 0.04504994156637362, 0.025601804788623537, 0.05164487107789942, 0.005730825767386705, 0.0482472867837974, 0.034823957431529245, 0.01779297612873571, 0.09397501019494874, 0.03488488648352878, 0.07159495752836977, 0.03838596433135016, 0.03197695341493402, 0.08361378724553756, 0.078898586332798, 0.010869895207828708, 0.0943890997607793, 0.0371580737909036, 0.06609411484428815, 0.030880210122891834, 0.027293781051412225, 0.05383062914812139, 0.044103313969182115, 0.005324394317410354, 0.02279844753710287, 0.03020045713388494, 0.04662653464557869, 0.042923110869846175, 0.10141033586114645, 0.09194453486374446, 0.0386606522702745, 0.016763684306559817, 0.04147309849836996, 0.04789411269926599, 0.023834368646410958, 0.09287219401448965, 0.024068427604756186, 0.038037489101822884, 0.0658713314416153, 0.05391989042982459, 0.011911987593131406, 0.03557031541796667, 0.02358008425549737, 0.06561405810394458, 0.01728278225553887, 0.0367606694011816, 0.028705342539719174, 0.02770027272137148, 0.07626623008400202, 0.026745014158742766, 0.0665078651426094, 0.03447329392656684, 0.09106328750827483, 0.02143022577677454, 0.021373513819915906, 0.020866946716393744, 0.028572678765548126, 0.06266082943017993, 0.006065931736624667, 0.0684573912460889, 0.038477441029889245, 0.0436257406670068, 0.03195483656600118, 0.04983804088884166, 0.012561793439090252, 0.04297650818313871, 0.040763914052929194, 0.0628634128453476, 0.027651699792061533, 0.016849568180207695, 0.02299522438884846, 0.09548536129295826, 0.05903679425162928, 0.06007580778428486, 0.09764716029167175, 0.05293850148362773, 0.7546327752726418, 7.871534279414585, 27.343315396990093, 46.07990762165615, 45.64572858810425, 42.09332309450422, 38.00381490162441, 28.112414973122732, 27.016508613313945, 31.360135010310582, 20.279222590582712, 9.777411256517683, 4.123510939734323, 1.072263919881412, 0.19635705570025103, 0.10431931726634502, 0.1540844597454582, 0.12170721138162272, 0.6905550765139716, 0.3468124930347715, 1.29975716982569, 2.703468292951584, 0.44778748761330334, 0.1428244560956955, 0.2650408808674131, 0.45350466083203045, 0.7514590227178165, 0.9276852607727051, 0.34286990602101597, 0.7022766332541193, 1.1420975497790744, 2.393752775021962, 4.029983409813472, 4.575039625167847, 6.6256102323532104, 8.566661596298218, 12.027283992086138, 14.920106547219412, 22.698567969458445, 29.585210732051305, 38.299870695386616, 44.3768242427281, 49.29082652500698, 50.87394230706351, 51.57558529717581, 51.51198843547276, 49.48305191312517, 48.83892611094883, 51.00456496647426, 51.62753350394112, 49.97734328678676, 51.63526337487357, 51.178085803985596, 52.277071952819824, 51.18674325942993, 51.671390533447266, 52.761819975716726, 51.59783342906407, 52.3430346761431, 52.34916993549892, 47.06123297555106, 42.60959162030901, 35.64113903045654, 29.74598162514823, 21.864645174571447, 17.77429277556283, 12.819613133158002, 7.845314383506775, 6.4635191815240045, 3.5790140543665205, 2.420202830008098, 2.0592866880553107, 0.4273156246968678, 0.3979628240423543, 0.23394394665956497, 0.0665737780343209, 0.17886145093611308, 0.13726097105869225, 0.051089025368647914, 1.3696099072694778, 1.8348266524927956, 1.7705063096114566, 0.5938537397554943, 0.186656529083848, 0.1932660165641989, 0.5056391933134624, 1.9241487852164676, 5.767736996923174, 8.531206675938197, 19.69978972843715, 20.019189732415335, 19.470700672694615, 28.30132954461234, 31.53283248628889, 39.44903326034546, 39.729076930454795, 21.238635063171387, 4.639747330120631, 0.3832088128796646, 0.03573658363893628, 0.02954756056091615, 0.12024120933243207, 0.020714037153603773, 0.06087370389806373, 0.0563372630359871, 0.020129657350480556, 0.021110674798754708, 0.021518416669485823, 0.039972009403365, 0.03989759446786983, 0.04262920342651861, 0.004841442352959088, 0.013521277578547597, 0.05925495683082512, 0.0420967536047101, 0.05380053272736924, 0.032588517027241845, 0.0743480319423335, 0.048226187737392526, 0.033179073195372305, 0.03639492206275463, 0.02295588462480477, 0.029118492334548916, 0.02902195037209562, 0.03180129426930632, 0.022523079366822327, 0.09300372124250446, 0.03596269525587559, 0.04369192158005067, 0.02822655805253557, 0.05405631668067404, 0.02124733684052314, 0.01348336273804307, 0.06820424340133156, 0.02320976528738226, 0.16746305328394684, 0.055585113753165515, 0.16164655610919, 0.2103882777903761, 0.1513782992426838, 0.14228293086801255, 0.32307538390159607, 0.09504133476210491, 0.10091111050652606, 0.055287158848451715, 0.14895153231918812, 0.1544213659529175, 0.2465421977852072, 0.18634765994335922, 0.1598482211785657, 0.17283356296164648, 0.20180866388337954, 0.17976657593888895, 0.10557192683752094, 0.19217528509242193, 0.11220689330782209, 0.14657277853361197, 0.14978025427886418, 0.10859526853476252, 0.15249647067061492, 0.20635684340127877, 0.1965302721198116, 0.12750757299363613, 0.20948178214686258, 0.15964558348059654, 0.20059274270066194, 0.13815597231898988, 0.23413293223295892, 0.14226615748235158, 0.09812015348247119, 0.0967752088659576, 0.18689331066395554, 0.1319328426782574, 0.06729250946747405, 0.13285198621451855, 0.15879015438258648, 1.2248383270842689, 9.882380298205785, 31.06073365892683, 51.56019156319754, 51.85064710889544, 50.09466361999512, 42.811506271362305, 36.39245121819632, 33.43133742468697, 36.35753652027675, 22.828735521861486, 12.351468699319021, 4.800896900040763, 1.5384436420031955, 0.4817961784345763, 0.5495474657842091, 0.6390166506171227, 1.6786143204995563, 1.5514364476714815, 4.46605669600623, 5.060405603476933, 8.28591181550707, 1.4272519456488746, 0.4301483455513205, 2.0254426641123633, 9.846701298441205, 5.821768360478537, 4.100215366908482, 4.020894297531672, 1.9578023850917816, 2.030756950378418, 3.461739318711417, 5.107534800257001, 5.501233628817967, 6.852100227560316, 9.413151945386614, 12.672927107129778, 16.1065514087677, 23.319809879575455, 28.816545418330602, 39.10668509347098, 44.644934381757466, 49.44238410677229, 50.4960367338998, 50.5051770891462, 52.00935091291155, 51.10913535526821, 49.92279645374843, 53.61322791235787, 54.02666309901646, 54.16633578709194, 52.93265880857195, 51.85049077442714, 53.49804067611694, 52.754771028246196, 51.72810173034668, 54.961234024592805, 51.23559256962368, 52.53626407895769, 52.55768537521362, 47.882176535470144, 42.3352176802499, 37.196774687085835, 30.203239100319998, 21.258828265326365, 18.245213883263723, 16.428265162876674, 10.501384019851685, 7.014970779418945, 4.743114377771105, 4.819076861654009, 4.231200635433197, 1.531006898198809, 0.9860716249261583, 0.6416097400443894, 0.500404594199998, 0.38467238577348845, 1.710165873169899, 2.9591468019144873, 14.106398667607989, 6.912187814712524, 3.3603168981415883, 1.301174168075834, 1.3787426629236765, 0.6706005558371544, 1.1175744256802966, 2.0481393890721455, 6.29652487380164, 11.409801057406835, 24.619741405759537, 23.088954244341167, 25.36336193765913, 37.02908686229161, 38.50983830860683, 45.58486236844744, 46.33739396503994, 25.561734744480678, 5.41105990750449, 0.6240294405392238, 0.2339808861059802, 0.11129171241606985, 0.21888483901109013, 0.14930457408939088, 0.17537296669823782, 0.138881651950734, 0.16506364489240305, 0.059691600900675566, 0.22299638124448912, 0.15233290301901953, 0.17667546894933495, 0.17071354814938136, 0.08268496779991047, 0.08408081611352307, 0.19466455866183552, 0.1600351304348026, 0.1336963823331254, 0.23609327418463572, 0.14411820524505206, 0.14672745737646306, 0.11805195680686406, 0.0943653103230255, 0.11949786064880234, 0.11093309987336397, 0.1791458928159305, 0.11551400513521262, 0.0610680024006537, 0.16349432910127298, 0.1613061215196337, 0.22271818188684328, 0.19561538978346757, 0.16601051336952619, 0.16165982825415476, 0.14732720090874604, 0.26068368181586266, 0.18083817272314004], [0.05415396126253264, 0.06426479121936218, 0.07416851193244968, 0.04960369524945106, 0.017173689091578126, 0.06931421134088721, 0.10913469030388764, 0.03047371336391994, 0.01840514363721013, 0.1169658393732139, 0.0217860614149166, 0.03896853414231113, 0.020432764032323445, 0.03297860680946282, 0.07232693396508694, 0.017990845421861325, 0.044722232901092084, 0.025476633737395917, 0.015327346112046922, 0.025326928556231514, 0.006116457998619548, 0.01594715053215623, 0.02262379601597786, 0.025342855469456742, 0.05049518848370228, 0.08286271004804543, 0.012165942046392177, 0.060197211269821436, 0.0649434280182634, 0.06627072393894196, 0.0984623794044767, 0.04225798709584134, 0.09340202808380127, 0.00780615268740803, 0.13738993342433656, 0.04207428391756756, 0.009127398620226553, 0.0389727682008275, 0.05393330167446818, 0.02441542023526771, 0.08630913190011467, 0.3503129466303757, 3.4160051899296895, 13.700715933527265, 32.83021054949079, 41.10515376499721, 39.95426457268851, 31.89327723639352, 22.368943691253662, 20.1291276046208, 28.782532249178203, 21.647546972547257, 12.444264497075762, 7.331995368003845, 1.6951603697878974, 0.3664501649992806, 0.16223530737417086, 0.027129431388207843, 0.0401802518005882, 0.709636458328792, 0.2910138985940388, 0.8867430548582758, 1.4066161215305328, 0.21536625495978765, 0.08486433407025677, 0.1319249581013407, 0.13641639852098056, 0.292986698448658, 0.03272632748952933, 0.13022966549864837, 0.11119066498109273, 0.13499902029122623, 0.8271706657750266, 0.7965011543461255, 0.9808750237737383, 1.8193018798317229, 1.9904404623167855, 4.418454587459564, 6.003465924944196, 11.040110860552106, 16.90112829208374, 24.277705907821655, 31.734027998788015, 37.43797097887312, 44.0529339654105, 47.2687200818743, 48.3894054549081, 43.82394218444824, 46.284688404628206, 40.763295446123394, 46.050388199942454, 44.52582836151123, 48.30252865382603, 45.93841797964913, 49.0421643938337, 51.322309562138145, 50.17909465517317, 49.748969895499094, 47.77176965985979, 48.2366875239781, 44.73251295089722, 37.87811851501465, 29.818260260990687, 18.42021468707493, 11.81044808455876, 7.747497643743243, 4.2319575548172, 1.8451002155031477, 1.236626488821847, 0.8701963541763169, 1.4348340587956565, 0.5587357527443341, 1.0778837097542626, 0.16281949888382638, 0.2251515170293195, 0.17398340840424809, 0.09806933799492461, 0.039894181436726024, 0.0742078058953796, 0.13830309228173324, 1.2487796481166566, 0.9166820283446993, 0.9966328867844173, 0.4057403824159077, 0.17050260518278393, 0.14002032870692865, 0.6022572059716497, 1.9334535087857927, 4.011535508292062, 11.616599423544747, 18.898686749594553, 20.362604447773524, 21.899578980037145, 26.212362323488506, 37.292051860264365, 37.36124202183315, 31.601814201899938, 11.905839034489222, 0.8395944248352731, 0.10289387804056917, 0.06930116989782878, 0.04440279557768788, 0.030209807346441915, 0.0798324133668627, 0.04762742468821151, 0.030743973861847605, 0.04017641129238265, 0.03862085958410587, 0.025482643861323595, 0.026046262189213718, 0.06883980679724898, 0.10242146160453558, 0.019764067771445428, 0.017815155742157782, 0.008789474610239267, 0.04907043118562017, 0.05954202464116471, 0.036261145491153, 0.0570050161331892, 0.057259147853723595, 0.019197431659059863, 0.03856810687908104, 0.05168404629720109, 0.06196235905268362, 0.05778204729514463, 0.014323326326640589, 0.04330265621787735, 0.020131433415891867, 0.07039513119629451, 0.026959914680836455, 0.019946457984458123, 0.06779591459780931, 0.016610442261610712, 0.033669623479779275, 0.04731377187584128, 0.031020297070166895, 0.05516124310504113, 0.013877756128619825, 0.028517004967268025, 0.002947468547582892, 0.02320094093946474, 0.03947343544236251, 0.03983336773567966, 0.04309739258938602, 0.06797834552292313, 0.010139392888439553, 0.046064809430390596, 0.039544464488114626, 0.04815755392025624, 0.02782388823106885, 0.04155602226299899, 0.02146119241868811, 0.09572457202843257, 0.005231654695567808, 0.035886909679642746, 0.028325941380379454, 0.01676727206047092, 0.035789421160838435, 0.052851713462067504, 0.04051511561764138, 0.07441429088690452, 0.029398951213806868, 0.04059149491201554, 0.05786041130444833, 0.0027483764071283595, 0.0687750813418201, 0.03528005849303944, 0.05419849690848163, 0.08454040145235402, 0.013422638942886676, 0.12932501547038555, 0.0739491144195199, 0.049811357499233315, 0.03438086388632655, 0.07158722222915717, 0.028256554389372468, 0.12257881675447736, 0.2635249522115503, 4.228309750556946, 17.426434687205724, 39.53273473467146, 45.80954279218401, 44.8106906073434, 34.585999488830566, 26.39747796739851, 24.38135392325265, 31.79097890853882, 24.73607162066868, 15.291908127920967, 7.2025695358003885, 1.9196263764585768, 0.31675502019269125, 0.08415569245283093, 0.07663566526025534, 0.18713945602732046, 0.19720377240862164, 0.11205352403755699, 0.26708213133471354, 0.1880569439381361, 0.20166154392063618, 0.11189884519470589, 0.09540790652057954, 0.28405286212052616, 0.01674556063621172, 0.1483130580080407, 0.06955176645091601, 0.21905428277594702, 0.3716708948569638, 1.4123312320028032, 1.72345213166305, 1.5137804682765688, 2.097072511911392, 2.539662774120058, 5.290494331291743, 7.919581941195896, 12.326544642448425, 17.984213488442556, 25.739322015217372, 34.09390722002302, 40.747054031917024, 45.95971768242972, 49.76998472213745, 50.37324469430106, 48.01960495540074, 48.51364619391305, 41.680131094796316, 48.18333230699812, 47.109074796949116, 51.869108472551616, 49.165369851248606, 50.32810919625418, 52.93086269923619, 52.489985602242605, 51.007128851754324, 51.60253388541085, 50.4340865952628, 47.39186995370047, 42.03614289419991, 32.46444347926548, 22.863174268177577, 16.022679703576223, 9.289820551872253, 4.709878104073661, 2.0766074614865437, 1.8318024490560805, 1.3167049118450709, 1.2474668728453773, 1.074982619711331, 0.8725448453000614, 0.1918727263276066, 0.19659680926374026, 0.1724822310996907, 0.037983820374522886, 0.05331854894757271, 0.02847182810572641, 0.10865537995206458, 0.4324509677078043, 0.2931972071528435, 0.25853644417864935, 0.14288308152130672, 0.031286784913390875, 0.09277782336409603, 0.5468455936227525, 2.3217863738536835, 5.188820907047816, 12.811324800763812, 23.234317507062638, 20.26940999712263, 25.001949650900706, 30.540699209485734, 39.55707427433559, 42.30332197461809, 36.29736164637974, 14.478391323770795, 1.661235247339521, 0.1071494257609759, 0.10467143622892243, 0.06474827456154994, 0.025614535801910927, 0.06521705404988357, 0.061312403929020674, 0.025076050411111543, 0.03499618318996259, 0.055860001859920363, 0.04786396538838744, 0.036627052285309346, 0.011712414328940213, 0.019906685654340044, 0.021595521996329938, 0.02279740259317415, 0.043270792213401625, 0.04117065169183271, 0.052299728617072105, 0.04050298001883285, 0.017533254975985204, 0.03235510776617697, 0.011859061013508056, 0.01002097241247871, 0.04980831087699958, 0.009904298316022115, 0.04525524929964116, 0.019904130969994833, 0.027529314127085463, 0.024712331892390336, 0.07811772144798722, 0.04726522948060717, 0.055990548604833226, 0.024432225851342082, 0.04043478385678359, 0.022059974127582142, 0.024751817541463033, 0.03379866387695074, 0.14879310796303408, 0.0977664196065494, 0.09993074275553226, 0.09669663451079812, 0.14198227200124944, 0.11253686488739081, 0.16914777431104863, 0.08649374770798854, 0.13219789202724183, 0.1491035513047661, 0.08060261846653052, 0.1605656769658838, 0.13167782207684858, 0.16853683495095798, 0.14876441950244562, 0.09649053628423385, 0.2566687086863177, 0.10178177271570478, 0.11638596334627696, 0.1347604338079691, 0.1194310656615666, 0.07881039035107408, 0.12102811996425901, 0.1273232964532716, 0.1875961779483727, 0.17477042760167802, 0.15748147746281965, 0.1772059476269143, 0.1935790247683014, 0.30721639203173773, 0.16269627692443983, 0.137589924835733, 0.1786064031933035, 0.09102187651608672, 0.20386480140898908, 0.14496338846428053, 0.1373457336532218, 0.12390107794531754, 0.14974026142486505, 0.1324067586766822, 0.2770882158407143, 0.59849421360663, 4.701472520828247, 20.496716839926584, 44.196535859789165, 53.26354592187064, 50.9026175226484, 42.975660937173025, 34.6441524369376, 31.565982341766357, 38.406327520098, 30.24287509918213, 17.738773584365845, 9.199681571551732, 2.7054541749613623, 0.5997951552271843, 0.2962007017007896, 0.26725105941295624, 0.42131286965949194, 2.43777135014534, 1.6770835454974855, 2.6014648292745863, 5.92557965857642, 1.8207078043903624, 0.6079050057700702, 0.8987741321325302, 0.9312624973910195, 1.0099156711782729, 0.2973174617758819, 0.5061201389346803, 0.7335593774914742, 0.40247242205909317, 1.845164486340114, 1.9446663813931602, 1.5663747489452362, 2.316685527563095, 2.3640353296484267, 5.113122454711369, 6.662136043821063, 11.695763724190847, 17.615872110639298, 26.287675585065568, 33.37623126166207, 39.62346431187221, 44.90325798307146, 50.27755410330636, 50.748589856284006, 49.93077645983015, 51.95618329729353, 46.39412253243582, 53.29581683022635, 51.72711508614676, 53.628350666591096, 51.61057642527989, 51.84753779002598, 53.604004178728374, 52.73849139894758, 51.89828743253435, 51.60002211162022, 51.34508923121861, 48.17445250919887, 41.25780916213989, 31.30590432030814, 21.851318529673986, 15.055000611713954, 8.770658101354327, 5.215511109147753, 2.994785415274756, 3.2020527848175595, 2.376736202410289, 3.229274958372116, 2.4028121403285434, 2.7927281090191434, 0.6401610949209758, 0.6723208320992333, 1.0214441439935138, 0.254893281097923, 0.4812453165650368, 0.27308029947536333, 1.3303893889699663, 2.817658028432301, 2.5427809953689575, 4.304045549460819, 1.2801039729799544, 0.5852556154131889, 0.1910801295723234, 0.9270322386707578, 2.965361314160483, 5.947058711733137, 14.900792292186193, 26.485985858099802, 29.650200707571848, 33.22400317873274, 36.27036094665527, 45.58588375364031, 48.99254730769566, 41.411683968135286, 18.496401684624807, 2.6412013598850796, 0.14382161758840084, 0.20884789473244122, 0.14708979507642134, 0.1521781020398651, 0.16779267202530587, 0.16484747720616205, 0.10185178395892892, 0.14432059867041452, 0.11082287864493472, 0.09852563243891511, 0.12258041809712138, 0.1854806143258299, 0.16012567414769105, 0.05570916352527482, 0.10027925869716064, 0.13504908260490212, 0.14922221350882733, 0.20624473584549768, 0.13489453946905477, 0.18109976154352936, 0.1827842654394252, 0.1714494058064052, 0.14338166905300959, 0.12229710258543491, 0.12723641682948383, 0.08717986874814544, 0.08340492738144738, 0.1725758553615638, 0.06711002425955874, 0.17879088329417364, 0.17491404632372515, 0.15221371155764374, 0.16772460139223508, 0.1353774664125272, 0.11185533752931015, 0.08004633510219199, 0.10981505736708641], [0.01683019770176283, 0.024752480809443762, 0.04044615949637123, 0.051969034397708516, 0.0432091032021812, 0.04738661939544337, 0.03648635126384241, 0.029567529846514975, 0.0328328778435077, 0.008318142133897968, 0.03876004747248121, 0.04140724667481013, 0.03153901334319796, 0.026655118446797132, 0.012027712588730668, 0.03620499332568475, 0.09307256540549652, 0.024964478897995183, 0.02393904624373785, 0.0312833108140954, 0.05498972302302718, 0.029565765655466487, 0.06677535043231078, 0.03991657309234142, 0.026611090005774583, 0.036780384236148427, 0.01222652250102588, 0.034396059678069184, 0.05847320985049009, 0.03525681866865073, 0.05429216527513095, 0.045674848569823165, 0.047982366356466494, 0.029719006004078046, 0.0297717417457274, 0.006604093126952648, 0.06893701372402054, 0.1059518385944622, 0.03340256227446454, 0.027851988062528626, 0.016656406223773956, 0.009889153414405882, 1.3447552238191878, 8.982338445527212, 21.885244846343994, 39.44680288859776, 44.424447195870535, 39.287345205034526, 22.662336587905884, 22.70733138493129, 20.730145045689174, 25.7721574647086, 24.120320524488175, 11.80639033658164, 4.647795081138611, 1.3272073311465127, 0.08236918438758169, 0.04653397568368486, 0.30988002195954323, 0.18689023011497088, 0.056082676696990214, 0.04106295122099774, 0.016902794163408022, 0.12164815169359956, 0.11040502320975065, 0.04323269247210451, 0.07849375876997199, 0.0693007559914674, 0.13273449109068938, 0.16445383190044335, 0.12261150857167584, 0.20535308654819215, 0.034720582621438165, 0.4522720883999552, 0.4194240995815822, 0.7361189744302205, 0.8886147801365171, 1.8475016866411482, 3.389075492109571, 5.734914141041892, 9.991127422877721, 16.24221498625619, 21.980848584856304, 30.168171542031423, 36.16608933040074, 39.12359006064278, 43.02893277576992, 39.95391368865967, 41.091076714651926, 34.51444346564156, 36.86472027642386, 38.94538961138044, 45.43569496699742, 45.81997551236834, 44.295169012887136, 51.08850267955235, 48.50525624411446, 49.312623023986816, 44.21302393504551, 43.45078917912075, 35.59478759765625, 26.654123578752788, 19.12422353880746, 10.033858844212123, 5.0425543785095215, 1.763731490288462, 0.9180689539228166, 0.5455871554357665, 0.11157853595380272, 0.16142501442560128, 0.11689662880131177, 0.6631720630185944, 0.20187570314322198, 0.2657287525279181, 0.17527189212185995, 0.12583395279943943, 0.21711105347744056, 0.09735458956233092, 0.07129878377807991, 0.17477618157863617, 0.12283507228962012, 0.11203009422336306, 0.18222729675471783, 0.15429458847003324, 0.2362340566303049, 0.4414505405085427, 1.4932513641459602, 6.167534172534943, 11.679113234792437, 18.657485246658325, 17.041054589407786, 24.942144768578665, 21.269146340233938, 22.65840564455305, 39.18651989528111, 39.67775753566197, 18.149007388523646, 5.7055375916617255, 0.5134587937167713, 0.1101358619385532, 0.06245030036994389, 0.1319557907325881, 0.014217567314127726, 0.025563260606889213, 0.029452643689832518, 0.0199715451204351, 0.05814431714160102, 0.06332907785794564, 0.043035428771483045, 0.03979623829945922, 0.05152946923460279, 0.02220880739124758, 0.03010076337627002, 0.05428968522963779, 0.03655152455238359, 0.016033600982544676, 0.05617203297359603, 0.028320886294490526, 0.030017242500824586, 0.02214196490656052, 0.06930064742586442, 0.038740203715860844, 0.029209897786911045, 0.03103276515113456, 0.06576578531946455, 0.04071610447551523, 0.018806805834174156, 0.006718051386997104, 0.045535267131136994, 0.018640965090266297, 0.05237977200054696, 0.025828552532142827, 0.024683063284360936, 0.023364113344411765, 0.01768711788047637, 0.022886363623131598, 0.06629711216581718, 0.03684012245919023, 0.017668291926383972, 0.05446615183193769, 0.07443512191197701, 0.04562303902847426, 0.046335388839777024, 0.031877734631832154, 0.022009346933503236, 0.021701912894578915, 0.0090405732792403, 0.07985373293714863, 0.007401336998944836, 0.01905543972471995, 0.03282538681690182, 0.018244351193841015, 0.029921470675617456, 0.05005943329472627, 0.02630434637623174, 0.018504784808361104, 0.05814876154597316, 0.024624938278325965, 0.04341928281688264, 0.0699547551838415, 0.02459031602899943, 0.05224884866869875, 0.010127795028633304, 0.048007960697369914, 0.039351329673081636, 0.01496784299212907, 0.03335561104384916, 0.02650647856561201, 0.07416549923696689, 0.01516137644648552, 0.06163461985332625, 0.0031384856972311225, 0.03631264969174351, 0.05648430496720331, 0.05764807055571249, 0.04098061438915985, 0.007360314468054899, 0.04780669703281351, 1.7768593515668596, 10.749242765562874, 26.36767888069153, 44.286431653159006, 50.136721066066194, 44.13389090129307, 25.742469549179077, 28.706197602408274, 25.492841618401663, 27.778489759990148, 22.98504219736372, 13.732272914477758, 4.503989083426339, 1.2691649028233118, 0.32252381635563715, 0.1846156721668584, 0.05400608812591859, 0.15406297732676777, 0.11715880116181714, 0.04288304676967008, 0.13990868255496025, 0.029169681016355753, 0.11562922038137913, 0.1267379242926836, 0.08375561463513545, 0.06732298247516155, 0.0866695222045694, 0.10584771739585058, 0.12433345402990069, 0.12330590773906026, 0.38298511345471653, 0.8066910675593785, 0.6364048879061426, 1.772301007594381, 0.997175606233733, 2.3247764876910617, 4.118631567273821, 7.483242886407035, 10.998267071587698, 17.866043737956456, 23.912308829171316, 31.943540505000524, 37.67322308676583, 42.716364588056294, 46.12484162194388, 45.51785741533552, 45.38106822967529, 35.73905304500035, 39.004852294921875, 41.7296404838562, 49.724595614842, 49.80538579395839, 48.8952898979187, 53.21149696622576, 51.02215780530657, 50.840702125004356, 47.96564177104405, 46.256381443568635, 39.10255091530936, 29.10138508251735, 21.25837663241795, 13.166872807911464, 7.531251464571271, 3.6974791032927374, 1.7402951078755515, 1.0894407353230884, 0.20485862450940268, 0.40637920956526485, 0.32384636253118515, 0.30930763695921215, 0.45378950983285904, 0.3099875290478979, 0.21198987827769347, 0.09649300615170173, 0.23309254805956567, 0.18081830521779402, 0.014950521689440523, 0.06511435777481113, 0.1244701516947576, 0.34451016943369595, 0.12257363274693489, 0.13200404814311437, 0.11694598543856825, 0.4747462538736207, 1.2558477031333106, 5.518578938075474, 10.007212502615792, 17.467300517218455, 19.760275534221105, 26.009012869426183, 22.664118800844463, 28.12220672198704, 44.35560097013201, 42.22665555136544, 22.529499190194265, 7.212705654757364, 0.5680127378020967, 0.1650188480104719, 0.01055137560303722, 0.035169470855700116, 0.07203531318477222, 0.035316343153161664, 0.036255910593484125, 0.018791986629366875, 0.03473407529028399, 0.02763899422383734, 0.041799439915588925, 0.04165046415956957, 0.025797292423833693, 0.04340421933946865, 0.0225410418851035, 0.029238521786672727, 0.03317998582497239, 0.04994895083031484, 0.02438578861100333, 0.04413435694628528, 0.012508555581527097, 0.11819624049322945, 0.01751666479477925, 0.07854725447084222, 0.036372231851731024, 0.061068423092365265, 0.042454297454761605, 0.02255006809718907, 0.027972324551748376, 0.0581744983792305, 0.027887187066621015, 0.07751041225024632, 0.1088769148503031, 0.007800920334245477, 0.042641464554305585, 0.030920060484537056, 0.011812310798891952, 0.04582893708720803, 0.2054780184158257, 0.16445755027234554, 0.08186105665351663, 0.13796758385641233, 0.15123288918818745, 0.1419488066541297, 0.11037707435233252, 0.09640067110636405, 0.1407243495008775, 0.10417462645896844, 0.17124956367271288, 0.16622256913355418, 0.09883192314633302, 0.13846860054348195, 0.12339204097432749, 0.13114453426429204, 0.20593043842485972, 0.2111485084252698, 0.1500163980360542, 0.16581520384975842, 0.16020990748490604, 0.08451924473047256, 0.1385742484458855, 0.27998727027859005, 0.08113686301346336, 0.07509356550872326, 0.14080707649035112, 0.16584655216761998, 0.188659523746797, 0.10421085344361407, 0.1300221694899457, 0.12257614332650389, 0.17020753744457448, 0.09643637561904532, 0.12926472084862844, 0.053994990685688596, 0.12224803093288626, 0.1919452752918005, 0.1861207035503217, 0.1274653681154762, 0.11622979172638484, 0.1543814545231206, 2.1071506568363736, 13.063762409346444, 30.2913179397583, 52.57836321422032, 56.785563468933105, 51.98154074805123, 33.885714871542795, 34.33890765053885, 31.726565633501323, 36.37487922395979, 30.11931528363909, 16.44756552151271, 6.392013532774789, 1.961072598184858, 0.6346875429153442, 0.4255874774285725, 0.8406237353171621, 0.6711096742323467, 0.22106486346040452, 0.30960374964135035, 0.4117572238402707, 0.36966392397880554, 0.41162352530019625, 0.37179476820996826, 0.19408988021314144, 0.34381032841546194, 0.6492675776992525, 0.5130987358944756, 0.5578248873353004, 0.5961332374385425, 0.5137348760451589, 1.3991294375487735, 0.8476250767707825, 1.606721743941307, 1.7852472386189868, 2.860636762210301, 4.43660979611533, 8.285367250442505, 10.805091517312185, 17.49505509649004, 23.633118050439016, 32.1555300440107, 38.38199840273176, 42.48007719857352, 46.04841838564192, 48.83067512512207, 49.209768840244834, 39.59739467075893, 41.68386575153896, 46.647648402622764, 54.17203678403582, 52.129450525556294, 50.05535418646676, 53.948787689208984, 50.824366910117014, 51.007455417088096, 46.35921130861555, 45.80327899115426, 38.95152487073626, 28.237188986369542, 20.338063410350255, 12.503564766475133, 7.265192781175886, 2.833876643862043, 1.6090909710952213, 1.7917297993387495, 0.3629148347037179, 0.9049896214689527, 0.4605096663747515, 1.56246052469526, 1.0095784664154053, 0.4273613579571247, 0.7540873416832515, 0.5745572351983615, 0.42655419984034126, 0.27401982620358467, 0.222001920321158, 0.7674997534070696, 0.4430113067584378, 1.5216056598084313, 1.7274675390550067, 0.7431480543954032, 0.3270220421254635, 0.7032748396907533, 2.0597472233431677, 7.876956479890006, 13.728688512529645, 23.871550696236746, 26.629433155059814, 35.37807675770351, 31.103228841509136, 35.44254561832973, 51.3293446132115, 48.974176270621165, 27.61168783051627, 9.617241382598877, 1.0173203881297792, 0.3070604646844523, 0.12125500850379467, 0.19336282994065965, 0.16331953848046915, 0.08633812570146152, 0.15304913744330406, 0.09780226661158459, 0.09179474825837783, 0.1498161894934518, 0.09488358894096953, 0.148674961445587, 0.11519023536571435, 0.20534102219556058, 0.10160204235996519, 0.10343623108097486, 0.09733759904546396, 0.09060959863875594, 0.1567619860704456, 0.1793084019528968, 0.14955640557621205, 0.18758906690137728, 0.1454391772193568, 0.18731816858053207, 0.14268169232777186, 0.15518633276224136, 0.18888662941753864, 0.11112935255680766, 0.11245433467307261, 0.08750684120293174, 0.1190198462988649, 0.12527201723839554, 0.1991953405418566, 0.1062594253037657, 0.11275608598121575, 0.10619478805788926, 0.12271147035062313, 0.10672206405018057], [0.052574806713632176, 0.05794619848685605, 0.05374937118696315, 0.027232154804681028, 0.014996450028515287, 0.022880121100960032, 0.03147688328421541, 0.08354672762964453, 0.06086229093905006, 0.04303006834483572, 0.01597449040439512, 0.07373126396643263, 0.08377833877290998, 0.052597493531980684, 0.05527223786339164, 0.06343511252530984, 0.012641143020508545, 0.06983392845307078, 0.041904986037739685, 0.025976279783727865, 0.013703638105653226, 0.04518395223255668, 0.0406171672844461, 0.07205415610224009, 0.01528490035395537, 0.015296654276815909, 0.020571490516886115, 0.035122024294521124, 0.03680447222931044, 0.03278945838766439, 0.0232328897608178, 0.03835954896307417, 0.03429506991856864, 0.045874022346522124, 0.06373687740415335, 0.015940592491200993, 0.011867352711435939, 0.07189190480858088, 0.06506219200257744, 0.07069852455918278, 0.029844599443354776, 0.011944824447190123, 0.2692378099475588, 4.918586356299264, 16.295389550072805, 34.44985301154, 45.299204553876606, 42.092027255467, 21.317094121660503, 18.277425731931412, 19.256331375667028, 25.19281840324402, 25.783797434398107, 12.99564140183585, 8.240159664835248, 3.884317900453295, 0.764831536582538, 0.18654450295226915, 0.04083895663331662, 0.044966522471180985, 0.01297726043100868, 0.048895691454942734, 0.040558565607560534, 0.03344423110995974, 0.03175876369433744, 0.021109656996226737, 0.10562359049384083, 0.04717593766482813, 0.01875454337070031, 0.16542457123952253, 0.15121448731848172, 0.11884721341942038, 0.8347675981266158, 0.6268709280661174, 0.37461500402007786, 0.41684194813881603, 0.20114216607596191, 0.5856241413525173, 1.7878031986100333, 4.272252764020648, 6.267546108790806, 9.569911990846906, 16.792152745383127, 22.86508502279009, 27.48074381692069, 29.91484716960362, 34.6077994619097, 34.00861808231899, 33.92695937837873, 26.273537737982615, 28.86897131374904, 32.31944152287075, 41.957520553043906, 42.16305521556309, 42.35030916758946, 46.40830727985927, 44.53563574382237, 44.350598267146516, 38.96103000640869, 32.447674001966206, 25.35260091509138, 18.206455094473704, 12.576666763850621, 5.201991651739393, 1.3618476837873459, 0.8808008794273648, 0.2670800957296576, 0.1609462265457426, 0.14923176728188992, 0.19681696673589094, 0.06864066355462585, 0.1066936809303505, 0.29264398398143904, 0.3890205738799912, 0.13629747847361223, 0.012741875784870769, 0.08523575735411473, 0.12372775296015398, 0.03727034758776426, 0.016603663696774414, 0.09491385838815145, 0.03939216730317899, 0.08986677921244077, 0.37599576850022587, 0.14805478043854237, 1.1041444263287952, 2.2716143003531863, 6.988763042858668, 13.31656219278063, 33.996135643550325, 44.04475940976824, 24.08118305887495, 36.21439320700509, 34.41507032939366, 34.99967091424124, 33.183877331869944, 12.529954024723597, 2.145811519452504, 0.14044701866805553, 0.15728859709841864, 0.04385651042684913, 0.03395275239433561, 0.03581629114757691, 0.05296463865254607, 0.01981565509257572, 0.02615160135818379, 0.011209041429018336, 0.021795572779540504, 0.033703485769884925, 0.0905581588989922, 0.017257072563682283, 0.04025059213329639, 0.015677465092656866, 0.012868328419114863, 0.06422700360417366, 0.020769471768289804, 0.004003371452979211, 0.040665892884135246, 0.022874794601063644, 0.01445588153520865, 0.02089108051066952, 0.07496215363166162, 0.06505298428237438, 0.041195726953446865, 0.031244376474725347, 0.03451035211661032, 0.03215308753507478, 0.04427811476801123, 0.02467906501676355, 0.021426196975101317, 0.019682655443570445, 0.02372683780933065, 0.020219154423102736, 0.0358533934423966, 0.06305592001548835, 0.026462502711053406, 0.02513699303381145, 0.03205365501344204, 0.03295653745798128, 0.022035131264211874, 0.009627606154286435, 0.02966133731284312, 0.017575108712272983, 0.020150021882727742, 0.08933041085089956, 0.04697457222001893, 0.05297392440427627, 0.07558331172913313, 0.041018269690019746, 0.03598008950107864, 0.03390832192131451, 0.006699384040465313, 0.02630591718479991, 0.005070380068251065, 0.046310361075614176, 0.031496628653258085, 0.04536064275141273, 0.04893559609938945, 0.018763691719089235, 0.04840983324018972, 0.010044050236631717, 0.003469391322661457, 0.09028283652982541, 0.026846495856131827, 0.0360147999599576, 0.04243483707042677, 0.03381913188578827, 0.04917132934289319, 0.02441516748097326, 0.0943308746708291, 0.05905539968184062, 0.020134746363120418, 0.08972985084567751, 0.040213693398982286, 0.025468560867011547, 0.03309316387666123, 0.047339033734585555, 0.011011069507471152, 0.545971369104726, 6.339792609214783, 19.60013692719596, 39.24467979158674, 50.945619923727854, 46.220445360456196, 27.06173096384321, 22.250674928937638, 23.020722934177943, 32.077480929238455, 31.57917697089059, 16.415075744901383, 8.760333946772985, 3.6345484001295905, 1.0872420647314616, 0.2550638105188097, 0.11383993710790362, 0.04197095660492778, 0.07613059771912438, 0.032346775356147967, 0.0835313791675227, 0.003519327047147921, 0.026058017808411802, 0.01657430179017995, 0.11591294301407677, 0.05746758024075201, 0.06578688097319432, 0.1948269728038992, 0.11773092831884112, 0.23308538272976875, 0.4605654148118836, 1.1404015379292625, 0.9118018959249768, 0.38239405517067226, 0.6447682391319955, 1.554366416164807, 3.3066920042037964, 4.942663167204175, 6.727620644228799, 11.858981251716614, 16.905337163380214, 25.421947411128453, 29.19497905458723, 32.81879465920584, 35.42778417042324, 38.15771402631487, 37.78059012549264, 28.977924278804235, 30.71553325653076, 34.35304028647286, 45.3930538722447, 46.70429706573486, 45.41536801201956, 48.58280161448887, 46.28740515027727, 45.69844109671456, 41.80359363555908, 34.86802339553833, 27.94738483428955, 21.24921022142683, 14.222175632204328, 8.286571025848389, 4.2555297527994425, 1.8097199882779802, 0.4920029735990933, 0.759047595517976, 0.5842931270599365, 1.4664173126220703, 0.29817982550178257, 0.48664824664592743, 0.3690217041543552, 0.4145699686237744, 0.1336172515792506, 0.2918395400047302, 0.13637287728488445, 0.08819237870297261, 0.018288990316380347, 0.030573030534599508, 0.0730710154665368, 0.03573271259665489, 0.018691466755366752, 0.10918007751128503, 0.15593586968524115, 1.1252866004194533, 2.1505037248134613, 7.393823913165501, 13.72865377153669, 35.94830846786499, 41.79770156315395, 26.663552284240723, 37.59898158482143, 36.79814958572388, 40.11587272371565, 37.58386925288609, 15.29461966242109, 2.8946034652846198, 0.25335718638130594, 0.10373942766870771, 0.07871324449245419, 0.02983307113338794, 0.027432029168786745, 0.02766756902981017, 0.07337441561477524, 0.0723475885710546, 0.008311890281869896, 0.019753243441560438, 0.06174171982066972, 0.028620959924800054, 0.07106789188193423, 0.026873871351459196, 0.014837374278743352, 0.03502124148820128, 0.03191327290343387, 0.051228284503200223, 0.014387768493699176, 0.021467601181939244, 0.025829892638804655, 0.013063328357280364, 0.005092669095444892, 0.03863419279722231, 0.07745899286653314, 0.0245628947325583, 0.05384521086567214, 0.06318389172000544, 0.030930119766188518, 0.05879216202135597, 0.00835414944283132, 0.013915440267218011, 0.042394437095416446, 0.06130546930113009, 0.014675233247024673, 0.023558791826612184, 0.03788954132635679, 0.033727343061140606, 0.13419093936681747, 0.11372445723307983, 0.1496122625789472, 0.16850928642920085, 0.13959906702595098, 0.10373173986694642, 0.15081978349813394, 0.17816595254199846, 0.14016877859830856, 0.13943522796034813, 0.2418590033692973, 0.20834045910409518, 0.14657524840107986, 0.17733922547527722, 0.1436057077454669, 0.16058308817446232, 0.09349928929337434, 0.16916705827627862, 0.16799355910292693, 0.08431591492678438, 0.10251756251922675, 0.19358135892876557, 0.09167793845491749, 0.13600995604481014, 0.10313154171620097, 0.07197863515466452, 0.20360526176435606, 0.15524300400699886, 0.2754411942192486, 0.25424775002258165, 0.13466010562011174, 0.11366892592715365, 0.14964819779353483, 0.18110599049500056, 0.13957458548247814, 0.1314261398677315, 0.21505912286894663, 0.14537775622946875, 0.11790029065949575, 0.18155751483780996, 0.20593171407069477, 0.10284748660134417, 0.6958311476877758, 6.817718369620187, 22.14939103807722, 46.400987352643696, 56.11717108317784, 53.69185025351388, 32.84692791530064, 31.42118535723005, 31.05038779122489, 35.714501585279194, 32.861296789986746, 19.094104834965297, 11.359505653381348, 4.858645115579877, 1.4196620157786777, 0.7373695416109902, 0.31011379084416796, 0.17504728345998696, 0.22231780551373959, 0.40808941636766705, 0.2789120094052383, 0.16536270241652215, 0.24800224229693413, 0.16349340629364761, 0.2350372565644128, 0.2683484676693167, 0.2598794549703598, 0.2559095365660531, 0.3984638543001243, 0.7403394622462136, 1.7882809958287647, 2.5735337223325456, 1.091741023319108, 1.0719870775938034, 0.8477665377514703, 1.8942302763462067, 2.8348157363278523, 4.947326276983533, 8.21398319516863, 11.372605613299779, 18.629810571670532, 25.70230722427368, 29.494165011814662, 32.9856139591762, 37.06695801871163, 40.59249135426113, 40.85953841890608, 33.52837249210903, 34.415549755096436, 39.86906576156616, 50.05483307157244, 50.73825788497925, 48.52156714030674, 48.427731718335835, 47.1040095601763, 46.76914112908499, 42.272607462746755, 35.352938175201416, 27.940341097967966, 20.646004097802297, 15.840129681995936, 10.04520525251116, 3.90321352652141, 3.646570086479187, 0.6944716349244118, 0.5376776084303856, 0.7244294445429529, 0.8300047165581158, 0.4144812976675374, 0.47664180930171696, 0.8637566225869315, 0.7502941137978009, 0.27132948913744515, 0.3059258998504707, 0.2703492231667042, 0.23614022880792618, 0.1376871181918042, 0.12470628188124724, 0.20670627536518232, 0.3316938371530601, 0.21510336335216249, 0.5069887723241533, 0.18379336914845876, 1.2322472780942917, 3.1192608731133595, 9.422425184931074, 18.40550708770752, 42.670162541525706, 49.93710626874651, 33.74170650754656, 46.5326418195452, 43.95585720879691, 46.904168946402415, 42.654518672398154, 18.233851841517858, 4.302889108657837, 0.5574083211166518, 0.29372092762163704, 0.215286038549883, 0.11020502501300403, 0.08725496221865926, 0.12241018723164286, 0.1477030414555754, 0.15644588374665805, 0.0729923393311245, 0.10922069461750132, 0.11476300257657256, 0.16343867565904344, 0.14731368449117455, 0.0923399647165622, 0.13386783456163748, 0.06914060137101583, 0.10871695700500693, 0.12299443302409989, 0.0944974482325571, 0.14149399820183003, 0.13730312165405067, 0.07192254745002304, 0.18216226595853055, 0.14206676318177155, 0.20065634857331002, 0.15068885338093552, 0.11362885843430247, 0.21552569711846964, 0.11743766548378126, 0.14247908177120344, 0.12431155091949872, 0.09823127716247525, 0.13763016196233885, 0.12780682050756045, 0.08379964477249555, 0.1887737890439374, 0.20159453180219444, 0.15773052695606435], [0.022071097012875334, 0.03554963367059827, 0.026683808603723134, 0.013733226473310163, 0.022464777941682508, 0.018365138908848166, 0.10878334487123148, 0.062333802692592144, 0.03555437663037862, 0.0180229876256947, 0.0204527163545468, 0.020639873276065503, 0.0438175150193274, 0.02192217045064483, 0.04953270691580006, 0.02730364864692092, 0.05313764133357576, 0.01938061406170683, 0.07767203929168837, 0.05880867077835968, 0.047365025018474886, 0.06444964451449257, 0.007158552928428564, 0.08877898579729454, 0.06846325378865004, 0.03522779094055295, 0.05599986489063927, 0.010153735422396233, 0.06239455193281174, 0.0949909942490714, 0.03575446982202785, 0.0643127840012312, 0.012516449488300298, 0.01024351832789502, 0.02691261230834893, 0.01771094124498112, 0.026935188864756907, 0.06632624167416777, 0.06645711072321449, 0.03833470779604145, 0.0363268616077091, 0.033457184343465736, 0.2336718269756862, 1.2826070615223475, 9.497221674237933, 22.332538604736328, 34.26142481395176, 37.43344422749111, 26.917614902768815, 21.91949772834778, 16.0978296824864, 18.29615807533264, 24.5738468170166, 19.094481774738856, 13.467939121382576, 8.259290661130633, 2.5813899636268616, 1.1591434351035526, 0.20694768455411705, 0.14796396531164646, 0.04741925692984036, 0.02970819015588079, 0.01986308808305434, 0.06009909510612488, 0.041860050056129694, 0.04224951219345842, 0.0673877215012908, 0.07517408725938626, 0.1693813396351678, 0.20050598521317753, 0.09262492906834398, 0.24947471757020268, 0.43447389772960116, 0.5471848611320768, 0.6335092261433601, 0.6829818657466343, 0.4866984039545059, 0.5220925818596567, 1.3674501031637192, 1.3413348644971848, 3.480824283191136, 7.071849601609366, 9.297514813286917, 13.934145876339503, 17.16068693569728, 20.51313717024667, 23.208280869892665, 24.863864626203263, 25.94206350190299, 20.715649366378784, 21.70968644959586, 25.20139421735491, 33.23749310629708, 34.91840478352138, 35.77802896499634, 38.30798271724156, 35.82374811172485, 35.94915962219238, 30.950535229274205, 24.499685219355992, 17.506238222122192, 11.555617690086365, 5.647973069122859, 1.9349931861673082, 1.7466634575809752, 0.7834990663187844, 0.43886876904538696, 0.38351662350552423, 0.5814068562218121, 1.1120962053537369, 0.46542177136455265, 0.3345178727592741, 0.1916048407022442, 0.27757575682231356, 0.3866809851356915, 0.6022065601178578, 0.030727003701031208, 0.17624529131821223, 0.0752584630889552, 0.04504396028018423, 0.01543137401209346, 0.04941815324127674, 0.09981071669608355, 0.13274275564721652, 1.1536715115819658, 2.6611059946673254, 6.580101702894483, 10.858877522604805, 24.61799567086356, 20.698532479149954, 31.53653587613787, 30.836907863616943, 27.13620001929147, 38.180785519736155, 29.91520152773176, 19.885480335780553, 7.473971383912223, 0.5199918917247227, 0.04205089481547475, 0.011972315293470663, 0.0457837704036917, 0.07602060719260148, 0.036780699754932096, 0.06624470890632697, 0.06735195592045784, 0.056714362265276055, 0.021469970965491872, 0.018947218478258167, 0.029285320346908908, 0.1082287917711905, 0.030894686667514697, 0.06096390834344285, 0.022705844470432827, 0.03085320782182472, 0.04012709875990238, 0.028076530567237308, 0.07540510807718549, 0.05300455686769315, 0.03904364796887551, 0.02437541720324329, 0.019373769339706217, 0.0159705345452364, 0.014801825829116362, 0.02110383516576673, 0.09156412099088941, 0.023429532601897205, 0.1063199234860284, 0.0660359508224896, 0.06385720201901027, 0.03765479874398027, 0.010829510499856301, 0.02398769890091249, 0.015692355543641106, 0.039498157865766964, 0.04864057246595621, 0.0521386783303959, 0.06473946717700788, 0.03786927009267466, 0.042418657402907095, 0.03324201410370214, 0.014817973266222646, 0.02473356494946139, 0.008078149386814662, 0.04870797813470874, 0.033871104275541644, 0.04453678249514528, 0.01379823436894055, 0.03658278466069272, 0.04897986033133098, 0.009121675177344253, 0.01703894730391247, 0.060218815824815204, 0.023642107445214475, 0.019253402316410626, 0.049209853168576956, 0.05139212356880307, 0.009541759600064583, 0.07735146542212792, 0.0671344447348799, 0.02352288375342531, 0.05222507280164531, 0.060678665792303424, 0.044227346777915955, 0.020175022505489842, 0.021283580788544247, 0.05534797254949808, 0.04998272491086807, 0.03204385018242257, 0.019511047152004073, 0.03553449894700732, 0.040792375204286406, 0.017766749053927403, 0.10859088519854204, 0.038928045957748375, 0.05387074074574879, 0.04073066244434033, 0.06255122566861765, 0.012875069664525134, 0.20462812616356782, 2.0278480436120714, 12.43594229221344, 27.53102445602417, 39.965718678065706, 44.25390713555472, 29.87419673374721, 27.998131002698624, 19.79607786451067, 23.706944397517614, 28.539386987686157, 22.413966281073435, 15.128859962735858, 8.181989346231733, 2.867965591805322, 1.191799859915461, 0.08873780550701277, 0.214578190818429, 0.06685976697398083, 0.028836116593863283, 0.10837232906903539, 0.04362532676064542, 0.07756123452314309, 0.0610323589561241, 0.10188589391431638, 0.25452391377517153, 0.16413650821362222, 0.20592950204653399, 0.17002889274486474, 0.1814408339560032, 0.6023071461490223, 1.1794103533029556, 0.6702692678996495, 1.1092921729598726, 1.5804798092160905, 1.6953505767243249, 2.411165394953319, 2.3547256120613644, 3.8492590274129594, 8.118484548160009, 12.398086769240242, 15.500062261308942, 20.20738169125148, 22.7073643888746, 27.862135648727417, 29.68775919505528, 29.59044619968959, 22.036934443882533, 25.110555206026348, 27.321831566946848, 37.09643227713448, 40.01931708199637, 39.64330489294869, 41.24923855917794, 36.71859271185738, 36.974595614842, 32.42036410740444, 27.191763026373728, 18.999055215290614, 13.686673624174935, 6.618335468428476, 4.094444019453866, 2.6558846405574252, 0.6521360980612891, 0.6569777982575553, 0.47177551899637493, 0.4246227634804589, 2.3769146842615942, 0.7916725905878204, 0.1107286097747939, 0.5802042207547596, 0.18623370677232742, 0.45110316255262917, 0.6988428660801479, 0.06858091176088367, 0.18250400333532266, 0.04976109501772693, 0.058530532488865514, 0.05675613966637424, 0.04529322011928473, 0.07486251076417309, 0.20205707555370672, 1.3826724120548792, 3.061376516308103, 8.676418815340314, 11.659522788865225, 26.799577168055944, 31.092288902827672, 41.253754888262065, 32.58654069900513, 31.107686110905238, 43.026785782405305, 34.21302366256714, 24.74746666635786, 9.183039767401558, 0.8311004149062293, 0.06993790715932846, 0.01770440356007644, 0.01307020615786314, 0.029159377462097576, 0.06283360480197839, 0.01523316714779607, 0.03317362795184765, 0.058975210413336754, 0.05919528646128518, 0.10631724327270474, 0.013482035353912838, 0.06337702314236335, 0.0028917243512946045, 0.01583305826144559, 0.05047243041917682, 0.017028267162718942, 0.06398423734520163, 0.0967025581215109, 0.059050005328442366, 0.025379129951553683, 0.02867169738081949, 0.047531143961740394, 0.07959090239767518, 0.04694988372336541, 0.02914211553122316, 0.06504036353102752, 0.04541869820760829, 0.04898009103323732, 0.08699314269636359, 0.01895669930880623, 0.05331370420753956, 0.025181501538359692, 0.036168077627995183, 0.05893958732485771, 0.07930627731340271, 0.045432044991425106, 0.06317282481385128, 0.07024165336042643, 0.11874797088759285, 0.1099785775212305, 0.14004718512296677, 0.23628054984978267, 0.12549707373338087, 0.15278919067765984, 0.16488988564482757, 0.2028559555432626, 0.2079465016722679, 0.15004914413605416, 0.13190804900867598, 0.17057550698518753, 0.2386312394269875, 0.10534817991512162, 0.11279718484729528, 0.12727567686566285, 0.2154678859348808, 0.1556443167584283, 0.15005588877413953, 0.1352804766169616, 0.09505674429237843, 0.13137144994522842, 0.07757957532469716, 0.26515967877847807, 0.14813863379614695, 0.15326115249523095, 0.12137246291552271, 0.058070947150034566, 0.21202498567955835, 0.16332360969058105, 0.12268299902124064, 0.251294521348817, 0.14066429915172712, 0.11061676684767008, 0.07925665604748897, 0.1303168979606458, 0.18707792647182941, 0.1699259861239365, 0.10088146531156131, 0.10663398341940981, 0.08889112727982657, 0.10400273318269423, 0.3507324984031064, 2.4464366223130907, 14.431340728487287, 31.20366505214146, 45.84758765356881, 48.86840384347098, 37.99156175340925, 37.323436873299734, 27.274224247251237, 29.40441860471453, 33.50245223726545, 27.488654341016495, 17.498018503189087, 11.251583627292089, 3.440069624355861, 1.8888656156403678, 0.3868471990738596, 0.5679719714181763, 0.20655604771205358, 0.1909915671816894, 0.23049115336367063, 0.12382486489202295, 0.22454186688576425, 0.15925759715693338, 0.21449481243533747, 0.29421126416751314, 0.48000766869102207, 0.9555355949061257, 0.9091591920171465, 0.40889977716973847, 1.5437617280653544, 0.9831338397094181, 1.278690448829106, 2.435513402734484, 1.4238213811601912, 1.964078779731478, 2.7806688589709143, 1.806133849280221, 4.1613873073032925, 7.202600368431636, 11.128486735480172, 15.972979239055089, 19.335813556398662, 22.05804828235081, 27.24553860936846, 33.23582206453596, 34.0062244279044, 26.089196818215505, 28.619897501809255, 30.00902305330549, 41.66114166804722, 42.452190603528706, 41.43668358666556, 41.59085716520037, 38.58759559903826, 37.27269417898995, 34.07507412774222, 25.258513620921544, 19.67938460622515, 13.530131578445435, 7.882358704294477, 3.0381690987518857, 5.547790033476693, 3.8187625152724127, 1.2506980023213794, 0.8427122118217605, 2.3299965390137265, 4.1738132919584, 2.6942664895738875, 0.7031079743589673, 0.9262677196945462, 1.098522465143885, 1.6328212405954088, 2.3958187784467424, 0.09542418457567692, 0.37917465077979223, 0.19193922275943415, 0.1397660273526396, 0.29125241722379414, 0.20960572335336888, 0.27440458270055906, 0.3362988643348217, 1.4263703929526466, 4.417058868067605, 9.164936235972814, 16.736839873450144, 33.077038356236045, 28.374565294810704, 41.43492569242205, 40.8090215410505, 38.134159633091514, 50.12141418457031, 40.85173211778913, 30.05335603441511, 10.85387829371861, 1.2758083577666963, 0.1474085979695831, 0.11467023326882295, 0.10201096827430384, 0.1356186991823571, 0.10776148470384733, 0.11865558155945369, 0.1638515099350895, 0.19270922429859638, 0.2808757440320083, 0.2568741962313652, 0.08060098998248577, 0.18585049733519554, 0.09003944601863623, 0.14464013438139642, 0.09347583912312984, 0.13608896466238157, 0.15663104238254683, 0.11630158073135785, 0.12833208803619656, 0.09873555081763438, 0.06962297191577298, 0.12625790147909097, 0.18664093634911946, 0.13850300226892742, 0.13966218435338565, 0.11556665945265975, 0.153451088017651, 0.13756093781973633, 0.22163329938692705, 0.12656721845269203, 0.14329559010054382, 0.06741202662565879, 0.10489203474883523, 0.08539473132363387, 0.08341159059533051, 0.1419566912310464, 0.12797264089541777, 0.25506017357110977], [0.08318964179073061, 0.032222535594233444, 0.008667555438088519, 0.035104368813335896, 0.024731103563681245, 0.034565293097070286, 0.043527549864458184, 0.06792049362723317, 0.03334506321698427, 0.021898781348552023, 0.05659810546785593, 0.017697570712438652, 0.02013670393664922, 0.08790082577615976, 0.015170428103634288, 0.07994379489017384, 0.030971201668892587, 0.1115433064156345, 0.012259685900062323, 0.030910449035997902, 0.025532718049362302, 0.020545061577909758, 0.06683896309030907, 0.02159848719436143, 0.027333490617041076, 0.01748287714352565, 0.02760171890258789, 0.02139820740558207, 0.051813276684177775, 0.026357182201796343, 0.04030036606958934, 0.013038737400035774, 0.059478486622018475, 0.051431397175682445, 0.0776529928137149, 0.09250404805477176, 0.09439412091991731, 0.07557226517902953, 0.0309586453783725, 0.01916670928975301, 0.022485790474872504, 0.017279170752902116, 0.017909555230289698, 0.38636625345264164, 3.2036652011530737, 14.894533702305385, 32.77568803514753, 36.68561656134469, 31.497240339006694, 18.652748312268937, 14.99068113735744, 19.21218078477042, 27.576368400028773, 21.186540944235666, 20.6154910836901, 16.49568005970546, 8.198011023657662, 3.185588593993868, 0.5589317679405212, 0.5232245411191667, 0.08562472076820475, 0.13008418759065016, 0.05570554693362542, 0.05450528973181333, 0.029402466025203466, 0.08010419378323214, 0.012203582928382924, 0.06224824621209076, 0.09542171470820904, 0.06434997450560331, 0.11576765509588377, 0.32132191370640484, 0.40625012506331715, 0.7558892049959728, 0.722244561782905, 0.19163020434124128, 0.9369225651025772, 1.7479630964142936, 1.5897434949874878, 1.5011586312736784, 1.5913333296775818, 3.9761743886130194, 3.7073394656181335, 5.780475650514875, 10.61207229750497, 13.051346846989222, 16.20349267550877, 18.384895256587438, 18.10068961552211, 15.605794736317225, 15.298640932355609, 18.467827217919485, 26.493578502110072, 27.449278899601527, 29.37756381716047, 32.1004308291844, 28.57776188850403, 26.42676636150905, 21.08712785584586, 16.556058168411255, 9.903367332049779, 6.419377275875636, 1.5922064142567771, 2.017471126147679, 1.7497344527925764, 0.49142024772507803, 0.16715497124407971, 1.1782971216099603, 1.2360521767820631, 2.8844056810651506, 0.12447389720806054, 0.39082601985761095, 0.20688730850815773, 0.259460446025644, 0.036629501796726666, 0.09041403806103127, 0.07460937649011612, 0.10585394634732179, 0.024550231572772776, 0.0649647679445999, 0.05929043064160006, 0.14124973916581698, 0.21416462372456277, 1.0556118019989558, 1.849647377218519, 5.797634661197662, 7.841973168509347, 19.79856010845729, 17.784298181533813, 16.646951028278895, 17.24947449139186, 26.92748655591692, 37.34294046674456, 35.69263907841274, 27.90843497003828, 16.0110536302839, 2.9595560942377364, 0.040460910847676654, 0.044022296887955496, 0.00818792447846915, 0.04226956290325948, 0.07276954914310149, 0.021702691513512815, 0.02454288812753345, 0.06425436213612556, 0.0638136604268636, 0.012776252065253044, 0.05879254200096641, 0.021976317545132976, 0.02761281973549298, 0.031893900728651454, 0.028730353340506554, 0.05467633483931422, 0.011295661513161446, 0.029526186707828726, 0.02105258371947067, 0.017329239851928184, 0.04198051377066544, 0.018124230139489685, 0.032451130649341006, 0.023201892584828392, 0.03449280180835298, 0.04858716497463839, 0.02762961686987962, 0.02769443053486092, 0.025772295193746686, 0.07524070582751717, 0.0744414594290512, 0.01187604813769992, 0.015294525373194898, 0.043639874551445246, 0.016274296013372283, 0.0686512758423175, 0.01856574439443648, 0.00506277326660763, 0.008648212949213172, 0.079158343108637, 0.033589498672102175, 0.008378577551671436, 0.025728560219119703, 0.01440062842864011, 0.02583851681889168, 0.011466311374013978, 0.0751300910487771, 0.02324384301235633, 0.043549944912748675, 0.021857005643791387, 0.024347668513655663, 0.03034382819065026, 0.016911652438076477, 0.04949077345164759, 0.09844300722969429, 0.018087594337495308, 0.050515290083629746, 0.033536837569304874, 0.06577606512499706, 0.011748969554901123, 0.1075498496315309, 0.041937311446028094, 0.0346018830979509, 0.056701008696109056, 0.013776568745795106, 0.004982354992534965, 0.04188873512404306, 0.0008679249565050538, 0.08263956702181272, 0.04464010641510997, 0.05569443253001996, 0.0063251855483810815, 0.06012169710759606, 0.056355156004428864, 0.04091332067868539, 0.030114150872187953, 0.12075625812368733, 0.05731026189667838, 0.014065273521867181, 0.015137841459363699, 0.05229833762028387, 0.07352066026734454, 0.4904995028461729, 5.0153413244656155, 18.494351966040476, 37.2507517678397, 42.3177672794887, 35.89770821162632, 24.790328366415842, 21.70301444189889, 22.74702991758074, 32.16063696997506, 25.066524471555436, 22.071689333234513, 18.48634590421404, 8.327818138258797, 3.4816024814333235, 0.5791435348136085, 0.16517917226467813, 0.03343459252001984, 0.06570743809321097, 0.0790402101618903, 0.07167552677648407, 0.028371499917869056, 0.1720172989049128, 0.04605570009776524, 0.12371446724448885, 0.13780013498451027, 0.30614194540040834, 0.38786014329109875, 0.5635445032800946, 0.8205007208245141, 1.6805778379951204, 0.727908863552979, 1.3179980367422104, 2.50141532932009, 1.8609601301806313, 2.366417476109096, 3.7043482661247253, 3.571153904710497, 4.4996286545481, 5.327213389532907, 8.287377885409764, 11.931784476552691, 15.698808533804756, 18.363190821238927, 21.982646431241715, 22.296279430389404, 16.205523286546978, 16.998128618512833, 21.34070757457188, 29.125328574861797, 31.590210710253032, 31.67918586730957, 33.65780006136213, 29.98566320964268, 27.3350122996739, 22.51138002531869, 18.059837681906565, 11.78301920209612, 8.169563361576625, 3.493086116654532, 5.0215795040130615, 1.744721110377993, 0.19152710773050785, 0.541288283254419, 1.7547776507479804, 1.9873964999403273, 0.7290131928665298, 0.6128520688840321, 0.5331335408346993, 0.8074355561818395, 0.23591422236391477, 0.8693649045058659, 0.18317792431584426, 0.05336631102753537, 0.3258555590042046, 0.02795343074415411, 0.03905487772343414, 0.11272116178380591, 0.06434914669288055, 0.20550938030438765, 0.8592903422457832, 2.2298708260059357, 6.757537850311824, 10.520427295139857, 20.85622184617179, 25.765252692358835, 16.456500904900686, 21.414752789906093, 32.495703424726216, 39.348364285060335, 38.44717597961426, 33.226164068494526, 17.689854792186193, 4.18967342376709, 0.21136740382228578, 0.03984032950497099, 0.07890017410474164, 0.037938809754060845, 0.025666328379884362, 0.02910054847598076, 0.020372333703562617, 0.038137932640633414, 0.04032751086301037, 0.09389925176011664, 0.014215720002539456, 0.05926045974982636, 0.028371868023116673, 0.054340405722281764, 0.05245004787242838, 0.018259421456605196, 0.06595922208258084, 0.010615458994704698, 0.07995860730963093, 0.02029889416215675, 0.041151673067361116, 0.009922554300698851, 0.023389169946312904, 0.008413953823037446, 0.04916594856019531, 0.047118306293019226, 0.018756266849647676, 0.017848061297887137, 0.012717600346409848, 0.02360799579348947, 0.05370852677151561, 0.03533775093300002, 0.07538458917822156, 0.10900777711399964, 0.02546019453023161, 0.010348437653322305, 0.031055896409920285, 0.05853755532630852, 0.02493461487548692, 0.15939307345875672, 0.1729365781481777, 0.13071399022425922, 0.12455270226512637, 0.06905293464660645, 0.13226508056478842, 0.18300142378679343, 0.2848184124699661, 0.12246053453002657, 0.0839557485388858, 0.11723717195647103, 0.08564102596470288, 0.08350754223231759, 0.2577661712254797, 0.07773040008864232, 0.22667178830930165, 0.15774588898888656, 0.17034690853740486, 0.15505933814815112, 0.1756897611277444, 0.06876596861651965, 0.2081835139542818, 0.16923506105584757, 0.1471678808863674, 0.07909601966717414, 0.07185886693852288, 0.13364671356976032, 0.18257947000009672, 0.16684935907168047, 0.12590654247573443, 0.08143718261271715, 0.10217202534633023, 0.09098957824919905, 0.2133308398936476, 0.15813557165009634, 0.22397328168153763, 0.18862460633473738, 0.2751157416829041, 0.100560022917177, 0.13680452055164746, 0.13433326887232916, 0.12810868716665677, 0.1531251740774938, 0.8372721523046494, 6.25058468750545, 21.393439190728323, 42.91031660352434, 50.372018337249756, 43.79527044296265, 31.872991970607213, 27.983525889260427, 31.579552173614502, 37.43994426727295, 29.25438962663923, 27.0228853225708, 20.746570587158203, 9.605317405291967, 3.9820243375641957, 1.1735729979617255, 0.9816244521311351, 0.2855104096233845, 0.3325415716639587, 0.1510087555008275, 0.24175765737891197, 0.14198794455400535, 0.44555890719805447, 0.11460499891213008, 0.43550779510821613, 0.3061078286596707, 0.3925842397979328, 0.36083805614284103, 0.6221395305224827, 2.380665191582271, 2.4720274891172136, 1.3024580648967197, 1.35387136893613, 2.0136695929936, 3.5543926783970425, 2.718956913266863, 1.8864374373640334, 3.0407846612589697, 4.1746053865977695, 4.489765686648233, 6.852928800242288, 11.773372496877398, 16.327286992754253, 19.43970823287964, 22.83190737451826, 25.46651315689087, 20.75958456311907, 19.989625147410802, 25.083144562585012, 33.189116273607524, 34.79173564910889, 34.90015533992222, 35.556384904044016, 30.768530641283306, 29.5048965045384, 23.4386397089277, 19.5992979322161, 11.532362937927246, 8.904085227421351, 2.6732125793184554, 4.3889095442635675, 4.728413292339869, 0.9054081418684551, 0.5106730546270097, 1.7247760891914368, 1.8953984422343118, 11.29066116469247, 1.7748556647981917, 1.2068236023187637, 2.1137223499161855, 1.276771877493177, 0.6089062520435878, 1.3185089464698518, 0.25959995282547815, 0.2524356815431799, 0.2566358675914151, 0.2008451712982995, 0.2738079604293619, 0.33433499400104794, 0.3512282632291317, 1.3563633837870188, 2.5245519621031622, 7.497711641447885, 12.565193550927297, 27.682489974158152, 24.22424473081316, 23.187750680106028, 27.818773678370885, 41.08300290788923, 47.07844713756016, 45.60292421068464, 38.57882349831717, 21.444233996527537, 5.2998422639710565, 0.47852933087519234, 0.15872696920164994, 0.17925011579479488, 0.1325763381485428, 0.18443961947091989, 0.17025599841560635, 0.10606742024953876, 0.24197128734418324, 0.16667536912219866, 0.17069136005427155, 0.25071217545441216, 0.10195530126137392, 0.06675183919391461, 0.16535724699497223, 0.09473358520439693, 0.15604169400674955, 0.08069105872086116, 0.1757677248013871, 0.15461056865751743, 0.07448537421545812, 0.16608099958726338, 0.10264290829322167, 0.14486061755035604, 0.0941658481689436, 0.17695338332227298, 0.11703275649675302, 0.15549372269638947, 0.12117248507482664, 0.05879509329263653, 0.14309240957455976, 0.19483336460377487, 0.16433435545435973, 0.2625976119722639, 0.14428262785077095, 0.115259391654815, 0.14026089651244028, 0.10826809251947062, 0.1818400432488748, 0.11346881916480404], [0.026977154559322765, 0.06305115669965744, 0.015512735449842044, 0.06860692679349865, 0.024543508987075517, 0.029792202969214747, 0.018990614185375825, 0.036150812304445674, 0.033000696516994915, 0.012663053764429475, 0.01384876317544175, 0.029765380479927574, 0.04650872739564095, 0.028168473758601716, 0.051454219701034684, 0.055720481489385874, 0.05575944297015667, 0.047400760065232, 0.04073001444339752, 0.02711615924324308, 0.07165975762265069, 0.0468877841984587, 0.022819202226985778, 0.019391791229801517, 0.03356269993154066, 0.06579334062657186, 0.03034132778910654, 0.052307189109602144, 0.01943413690397782, 0.027763188184638108, 0.02885719867689269, 0.03911073472616928, 0.030807535629719496, 0.026001120950760584, 0.01699986707951341, 0.04544953762420586, 0.01608957503257053, 0.1355603180293526, 0.034029912003981214, 0.04113697939153228, 0.00957303327907409, 0.03324151538046343, 0.07908754476479121, 0.149593589295234, 1.8055177394832884, 8.299158556120735, 23.149415731430054, 38.32283101763044, 33.58005666732788, 27.57067608833313, 13.142469865935189, 12.51791192804064, 23.184170620782034, 23.510862759181432, 30.218271527971538, 24.27340497289385, 11.989246078899928, 5.8543645313807895, 2.2627683750220706, 0.7724702124084745, 0.15915116215390818, 0.13112443605703966, 0.022778452806440846, 0.03119127093149083, 0.055786092433014085, 0.19648964144289494, 0.03671010157891682, 0.09200107718684844, 0.19781228261334555, 0.04593221690239651, 0.502622915165765, 0.9963914368833814, 1.0258422451359885, 3.7678977932248796, 0.7563949578574726, 1.3307062919650758, 2.8759831615856717, 0.5532673576048442, 1.2740348300763538, 4.208638531821115, 1.536737750683512, 0.8887041296277727, 3.052485861948558, 2.488130807876587, 4.040369663919721, 6.489319145679474, 9.445361188479833, 11.585675597190857, 13.31538360459464, 10.528207540512085, 10.937796030725751, 13.332674196788243, 18.063624450138636, 17.915565286363872, 19.950282709939138, 23.296352761132376, 19.591008731297084, 17.077991213117325, 13.302788257598877, 10.069429278373718, 6.125327774456569, 3.7770168696131026, 1.4035375267267227, 6.2585303868566236, 0.5780717751809529, 0.09035828283854894, 0.4199903506253447, 1.8060386372464043, 1.2745077418429511, 0.8048282446605819, 0.34220507740974426, 0.18723303957709245, 0.42080119997262955, 0.13398659176060132, 1.241315545780318, 0.1820660496928862, 0.27159208218966213, 0.4155916523720537, 0.05228379661483424, 0.019019767442452054, 0.18879897626382963, 0.08798832286681448, 0.6665810772350856, 1.8659613132476807, 4.325832060405186, 6.177744550364358, 15.44461911065238, 24.51126265525818, 18.44703299658639, 24.708532435553415, 23.67393003191267, 24.852678026471818, 34.485215868268696, 32.10340813228062, 19.366397789546422, 8.993211507797241, 1.015417667371886, 0.044318680984101126, 0.01851017746542181, 0.07973749988845416, 0.01746263135490673, 0.05640379339456558, 0.10120194418621914, 0.0138957534218207, 0.050214838170047314, 0.03618578399930682, 0.024036102196467773, 0.0026635518962783472, 0.013912431812579078, 0.062405808828771114, 0.02679483050347439, 0.03410007591758456, 0.014998271895040358, 0.08579331636428833, 0.0021674531037985745, 0.076404094829091, 0.024703617806413343, 0.03493180378739323, 0.04434347126100745, 0.03416388874341335, 0.031694333401641676, 0.04904033137219293, 0.02682099481379347, 0.027943956698956232, 0.020074385584199002, 0.02450871540765677, 0.05623264650681189, 0.0298742582090199, 0.04914113114188824, 0.010733891345028366, 0.09323520346411637, 0.01110341473083411, 0.019469025478299175, 0.04397508102868285, 0.04135242443797844, 0.03441905522985118, 0.027685955632478, 0.03312376580600228, 0.018711223998772245, 0.05459317019475358, 0.028247402648308446, 0.05275167704426816, 0.02772811470952417, 0.052945330938590426, 0.02538563370970743, 0.010670688352547586, 0.027002209464886358, 0.09654325845518283, 0.020515072026423047, 0.06812348416341202, 0.03676637588068843, 0.019927774522719637, 0.009020051835770053, 0.158700628472226, 0.05517537359680448, 0.03371259170983519, 0.06519703048148326, 0.0788867391113724, 0.03958222156922732, 0.020353187141673904, 0.04638616700789758, 0.023847893545670167, 0.025598020259557024, 0.00902943851958428, 0.08865675449903522, 0.047618359460362365, 0.03271668889958944, 0.011760386754758656, 0.015942919866314957, 0.02729410505188363, 0.02829417915615652, 0.031504506444824595, 0.02624922219131674, 0.1312230679073504, 0.018904596301061765, 0.03411293076351285, 0.04134798342628138, 0.04044093816940274, 0.051490975942994864, 0.13987038603850774, 2.362270487206323, 11.451650057520185, 27.535099574497767, 44.018953800201416, 38.378656319209504, 35.31001567840576, 19.390358652387345, 17.99219696862357, 27.90329156603132, 26.471224410193308, 38.30955995832171, 29.554996490478516, 15.764573233468191, 6.400238462856837, 2.3178384942667822, 0.9831017042909349, 0.23388616261737688, 0.14292304723390512, 0.011839348723047545, 0.18677926249802113, 0.09306368338210241, 0.12310309362198625, 0.3471170738339424, 0.28587329015135765, 0.3033106358987944, 0.5588845419032233, 1.1456459079469954, 2.693939272846494, 3.210559985467366, 4.725190196718488, 2.3127888909408023, 3.2293576853615895, 6.984300996576037, 5.468807688781193, 4.120595301900591, 5.182794213294983, 2.527448275259563, 2.519351452589035, 4.7173239673886975, 2.827477135828563, 5.521484153611319, 9.62427990777152, 11.36807712486812, 14.945120062146868, 17.3529748576028, 11.669317143304006, 12.844584958893911, 15.115211963653564, 21.078979355948313, 20.46448414666312, 22.6446464742933, 24.68201810973031, 21.973077024732316, 19.548358951296123, 16.041656970977783, 10.74642961365836, 9.102427635874067, 4.323147884437016, 4.3258285863058905, 5.723855648721967, 2.4914077520370483, 0.5324934380395072, 0.44081445464066094, 2.2588880232402255, 5.848025168691363, 0.6152795414839471, 0.30744674109986847, 0.4962110849363463, 0.7122190711753709, 0.5182223809616906, 2.123069848333086, 0.16139589170260088, 0.05879885237663984, 0.2005086722118514, 0.1052010395963277, 0.08350643622023718, 0.08664383286876337, 0.11334407050162554, 0.6262297396148954, 3.2051518985203336, 5.718082129955292, 9.634483337402344, 14.640022924968175, 31.879415580204554, 20.08023660523551, 25.397802421024867, 25.120359114238195, 29.83888946260725, 40.49416044780186, 35.814368043627056, 23.74710672242301, 10.501321486064366, 1.3341670376913888, 0.06277994625270367, 0.040418295455830436, 0.07764069775917701, 0.061337530080761225, 0.08091352999742542, 0.07088673660265547, 0.04017037233071668, 0.059632344437497, 0.04224216365920646, 0.05953654207821403, 0.008071372518315911, 0.02910158663455929, 0.02035299375919359, 0.022431019128167203, 0.0630351093464664, 0.04037916434130498, 0.02362355629780463, 0.11148986499756575, 0.06768990707184587, 0.03289678227156401, 0.06498815026134253, 0.017098324207056845, 0.09337006229907274, 0.02255955062407468, 0.03315178930227246, 0.03465965696211372, 0.03783946204930544, 0.0350973391905427, 0.041306494402566125, 0.05869317054748535, 0.02535368997736701, 0.06528245804033109, 0.0793292321530836, 0.06320003406809908, 0.014960424908037697, 0.008842868530856711, 0.012570024068866457, 0.04620144941977092, 0.010788447256865246, 0.14460961387625762, 0.20144313706883363, 0.1551858035049268, 0.19452590681612492, 0.13206674477883748, 0.13073586619326047, 0.15505963670355932, 0.09959500362830502, 0.1045679324971778, 0.0836490574958069, 0.13810010174555437, 0.12296517459409577, 0.11912853403815202, 0.09473886420684201, 0.13897135428019933, 0.13222523698849337, 0.1572099006069558, 0.28970226326159065, 0.1443847609417779, 0.10158332157880068, 0.20491771133882658, 0.12662660383752414, 0.08399296618465867, 0.15128896332212857, 0.09019657437290464, 0.08070038179201738, 0.08654028163956744, 0.12420279532670975, 0.10693632505301919, 0.10827917978167534, 0.14234197698533535, 0.14798941037484578, 0.10826706793159246, 0.13178315785314354, 0.11523777352912085, 0.15286400594881602, 0.24919556826353073, 0.282130273857287, 0.1560580331299986, 0.07103765636150326, 0.1133096959175808, 0.12255386023649148, 0.14980575362486498, 0.3271503123853888, 2.6784608576978957, 12.672502398490906, 31.408160958971294, 52.07927063533238, 46.127676486968994, 43.78393793106079, 26.397901807512554, 22.923634018216813, 35.63833890642439, 32.9889178276062, 41.3040702683585, 31.239618505750382, 15.140781334468297, 6.784722243036542, 2.8434797057083676, 1.602020419069699, 0.4839344322681427, 0.4658101105264255, 0.1763841738658292, 0.23438355592744692, 0.3684679652963366, 0.9570316289152417, 0.573425113090447, 0.5656282028981617, 0.7025006040930748, 0.9394749424287251, 1.2298880389758517, 4.366360902786255, 5.681611904076167, 11.442312547138759, 1.6312568102564131, 1.909136985029493, 8.972920162337166, 3.087444854634149, 3.8342834881373813, 6.724132648536137, 2.7357016376086642, 3.007612007004874, 4.427938010011401, 3.3186077305248807, 5.147969841957092, 7.640689935003008, 12.075898800577436, 15.636517933436803, 18.87493085861206, 15.215014151164464, 15.432768957955496, 18.466359410967144, 22.65522336959839, 23.928456442696707, 24.924426862171718, 26.22044481549944, 23.482368196759904, 18.69009140559605, 15.25162594658988, 10.835537655012947, 8.578796625137329, 5.304373357977186, 4.34675612619945, 11.670658145632062, 4.215288826397487, 0.7434712541954858, 0.32040135881730486, 3.284031323024205, 14.423520530973162, 4.021554810660226, 0.8851242331521851, 0.6780117324420384, 1.2425470054149628, 0.40510570790086475, 5.456464213984353, 0.27267469838261604, 1.3880820189203535, 1.9014868012496402, 0.1435162089765072, 0.46511425929410116, 0.39447442122868126, 0.33470729259508, 1.109856714095388, 3.077796629496983, 6.178210513932364, 10.51918704169137, 22.811064515795024, 33.44860369818551, 27.76264786720276, 36.58344330106463, 33.015838623046875, 36.54581185749599, 47.27328852244786, 41.511234283447266, 27.26308454786028, 12.589701584407262, 1.4822879752942493, 0.27104420587420464, 0.2304090777678149, 0.2871863368366446, 0.10345115885138512, 0.16682099630790098, 0.1514750583363431, 0.11030667634414774, 0.10640987687345062, 0.1080870186643941, 0.1055313300873552, 0.11748367015804563, 0.1795549001544714, 0.11535089888742991, 0.10351122955658607, 0.17130567851875508, 0.12967408102537903, 0.14875937120190688, 0.15698283564831528, 0.17239225735621794, 0.12750358320772648, 0.15853338316082954, 0.10832184606364795, 0.18480209287788185, 0.08014344703406096, 0.11028815233813864, 0.09097359874950987, 0.11882168693201882, 0.12674234834100517, 0.10090801638684102, 0.14854271497045243, 0.17232064477034978, 0.12721072749367782, 0.14988242808197225, 0.24498840687530382, 0.08416359738579818, 0.09287710660802466, 0.07909751244421516, 0.10348568949848413, 0.12130588505949293], [0.05257973287786756, 0.029881861193903854, 0.03978832318846669, 0.03300993477127381, 0.03294019494205713, 0.058210406452417374, 0.04889126740662115, 0.036361775627093654, 0.037236580292561224, 0.024032846924715807, 0.07698207095797573, 0.03026148457346218, 0.00980914310951318, 0.020344858124319996, 0.06103690514074905, 0.061718473210930824, 0.02822192196202065, 0.02575246331148914, 0.026387261659173027, 0.032002948091498444, 0.0062998846738732284, 0.017601749693442668, 0.03647881952513542, 0.038527425312037976, 0.04610979290945189, 0.059853139732565196, 0.024945590179413557, 0.05561013812465327, 0.003986374998930842, 0.08360893572015421, 0.010065296864403146, 0.0228188137656876, 0.03212571203974741, 0.032713425146149736, 0.02114818591092314, 0.07128680763500077, 0.03836176098723497, 0.03464918038142579, 0.062113875922347815, 0.015182874132213848, 0.02364762223857854, 0.04656243683504207, 0.06927075795829296, 0.02348743029870093, 0.2843227833509445, 3.8311902369771684, 14.674744810376849, 28.225312777927943, 36.91350357873099, 32.82170942851475, 24.549793890544347, 19.314854315349034, 22.64453877721514, 16.88135024479457, 22.21600862911769, 21.9192111151559, 14.66035509109497, 11.994026439530508, 6.19150676046099, 3.4123982063361575, 0.7249791664736611, 0.11950330249965191, 0.03980736627376505, 0.08693392694528614, 0.01861556582818074, 0.032597833313047886, 0.1993409948689597, 0.10329869203269482, 0.48084259246076855, 0.32394781708717346, 2.6908597009522572, 1.7413123675755091, 0.3476731739938259, 2.7436141158853258, 1.933405957051686, 4.629227323191507, 4.6510568261146545, 5.549757676465171, 3.565521304096494, 7.454969797815595, 2.3421391674450467, 2.081918490784509, 1.0508819243737628, 0.7258730956486293, 1.5360051499945777, 4.175037477697645, 5.11373997586114, 7.46387825693403, 8.585099509784154, 6.583278766700199, 6.808610584054675, 7.486772571291242, 10.380492312567574, 12.329509786197118, 13.513309121131897, 13.228329624448504, 13.49702775478363, 11.286326357296534, 8.250491636140005, 5.483065392289843, 4.982211879321507, 1.3066214472055435, 3.890575621809278, 3.3049408410276686, 0.7292301069412912, 0.11958407530827181, 0.876291498541832, 2.594379403761455, 3.7885912656784058, 0.3572307468525001, 0.3722621702722141, 0.20957601709025248, 0.5913741556661469, 1.762181282043457, 1.8359824419021606, 0.20600310952535697, 0.24154017333473476, 0.2920268699526787, 0.031722485819565396, 0.020370588172227144, 0.12429956799106938, 0.589607413325991, 2.06470194033214, 3.9076616764068604, 7.83729442528316, 14.31267591885158, 23.40289122717721, 15.858332225254603, 21.55681392124721, 21.744896445955547, 24.72540439878191, 31.240844862801687, 32.13784687859671, 25.11613460949489, 11.840987154415675, 3.2726490880761827, 0.21978737201009477, 0.05305133167920368, 0.06513386565659728, 0.06304447991507393, 0.05143017241997378, 0.017604986305481622, 0.05652200098016432, 0.008384447727751519, 0.006690398540480861, 0.022935655799561312, 0.020687285910493562, 0.00723435716437442, 0.03763503980423723, 0.060891447588801384, 0.08736194683504955, 0.0445285925774702, 0.023610993221934353, 0.020892329015103833, 0.021615442088139907, 0.07360608782619238, 0.020505021226459315, 0.03733206034771033, 0.029119296398546015, 0.017124257815469588, 0.05586011042552335, 0.007886546364586269, 0.035147282760590315, 0.006007128619655434, 0.02483701779107962, 0.006259307855673666, 0.015241497861487525, 0.03139940815578614, 0.019988211636830653, 0.04986973186688764, 0.030255231873265336, 0.09811275066541773, 0.03468751760997942, 0.11126714266304459, 0.0428287164707269, 0.040884934166180234, 0.10368785900729043, 0.028421728472624506, 0.05068587039464286, 0.040092354374272485, 0.033482622621314864, 0.01722809742204845, 0.027701309183612466, 0.0756808714941144, 0.010652624054013618, 0.022675290038543086, 0.02490351931191981, 0.04628584560539041, 0.004960288609644132, 0.08126683639628546, 0.013057235112812902, 0.03059832632009472, 0.03759409700121198, 0.00886195826543761, 0.005408373203993375, 0.030317714770457575, 0.06924149274293866, 0.04504018084013036, 0.08200316224247217, 0.03844061014907701, 0.03259862380634461, 0.05683112457128508, 0.03523486466812236, 0.04087507165968418, 0.05469212095652308, 0.005738734093029052, 0.015001060673967004, 0.028120725249339427, 0.07190805394202471, 0.020555100503510663, 0.045660348276474645, 0.028925581436072077, 0.022718567002032484, 0.03993497496204717, 0.05543789879551955, 0.0203350159738745, 0.031917696951755455, 0.03614679876981037, 0.02297746543107288, 0.039952179217445, 0.3958657165723187, 5.243859325136457, 17.20674307005746, 34.56603384017944, 42.81731496538435, 38.57029458454677, 26.642730270113262, 22.841056415012904, 27.757117101124354, 21.879627227783203, 27.457333598818096, 25.385575328554424, 17.223868642534526, 14.406554767063685, 7.422713654381888, 3.3084548924650465, 0.7014999549303735, 0.0941511443150895, 0.13332398874419077, 0.09611576782273394, 0.1905292948441846, 0.06336924034569945, 0.31582265879426685, 0.22333970639322484, 0.7369563952088356, 1.222685579742704, 1.1225921107189996, 2.9306533251489912, 4.037172189780644, 6.296636913503919, 7.873147998537336, 8.534162265913826, 11.252935920442853, 9.910649912697927, 5.484908836228507, 5.517216222626822, 4.120074621268681, 4.447581001690455, 2.7674916003431593, 1.8178763048989433, 2.5420670679637363, 5.8072987369128635, 8.074956689562116, 9.727060266903468, 12.893020851271492, 8.911186286381312, 9.402312755584717, 11.138949854033333, 14.809765679495674, 14.655211687088013, 14.032787714685712, 15.878386463437762, 15.83191864831107, 12.524778485298157, 10.587638957159859, 7.49304245199476, 5.2915443778038025, 2.637048291308539, 4.054383311952863, 4.271787668977465, 4.884389928409031, 0.8292002454400063, 1.092989744884627, 3.1535908366952623, 2.868145593575069, 1.2599091423409325, 0.6675621845892498, 0.6878059240324157, 0.8856633699366024, 1.0755719138043267, 0.8318916410207748, 0.09382884696658168, 0.359943475574255, 0.1576185958193881, 0.07433789462915488, 0.021605052020666853, 0.1255409885197878, 0.5817020460963249, 2.289505043200084, 4.0445637702941895, 8.06044624532972, 14.37732630116599, 30.21262959071568, 23.713553871427262, 27.602021149226598, 27.76299180303301, 29.661001682281494, 36.29504789624895, 37.79229089191982, 29.494182382311138, 14.356257625988551, 4.161954454013279, 0.2870700902172497, 0.039712106742497, 0.021192562101142745, 0.04925543375845466, 0.05277388210275343, 0.02356442536360451, 0.027478632650205066, 0.04711396706157497, 0.059611343778669834, 0.0076544526132888025, 0.024297775833734443, 0.028087738269407834, 0.027437001134135892, 0.0342340967617929, 0.04602927115878888, 0.02854586984696133, 0.04306302818336657, 0.03922778880223632, 0.055701699640069685, 0.013121938515853668, 0.009562952793203294, 0.023112583805673888, 0.055776457235749276, 0.09368678208972726, 0.019178939883464148, 0.006842836521432868, 0.020395005254873207, 0.03939789074606129, 0.032694378668176274, 0.04202407571886267, 0.04565543229026454, 0.050404142654900036, 0.05500485096126795, 0.054959650351000686, 0.03454915753432682, 0.04471878933587244, 0.02273476363292762, 0.11998799363417284, 0.04575720915038671, 0.034151946527085135, 0.14569753621305737, 0.10200990297432456, 0.1437305581888982, 0.1443570088595152, 0.12269358416753155, 0.18257097474166326, 0.14496378201459134, 0.1341632144259555, 0.12436763862414019, 0.07496106119028159, 0.1367149403584855, 0.12221810753856387, 0.050584368341203244, 0.1600483211555651, 0.1202821114233562, 0.09580584695296628, 0.16810687445104122, 0.10591341994170632, 0.09238912457866327, 0.09226288313844375, 0.10705517046153545, 0.09431285278073379, 0.1836657231407506, 0.16239751795572893, 0.11504595167934895, 0.22590292670897075, 0.10865357504891497, 0.19356252279664787, 0.08814495589051928, 0.14895742200315, 0.08378948031791619, 0.09091930916266781, 0.20198635863406317, 0.12302909259285245, 0.10333045425691775, 0.14604622178844043, 0.081139251456729, 0.09577867162546941, 0.15668996636356625, 0.15078489322747501, 0.14442531019449234, 0.12006726009505135, 0.12773843774838106, 0.10327180168990578, 0.652711278625897, 5.780948128019061, 21.0214204788208, 38.7827843938555, 53.264932087489534, 47.21534054619925, 36.59879534585135, 33.43541601725987, 36.25769090652466, 27.488188811710902, 31.27936567578997, 30.95652805055891, 21.612543685095652, 17.425927468708583, 8.995501807757787, 4.479709471975054, 1.2914452786956514, 0.5431729821222169, 0.4152642456548554, 0.4850147143006325, 0.3188505263200828, 0.3252402091664927, 1.333397090435028, 1.1710229005132402, 1.5869250233684267, 3.4745483228138516, 5.168301139559064, 6.131399631500244, 6.475452278341566, 6.166116740022387, 7.247856157166617, 8.074372172355652, 9.998262354305812, 10.816906929016113, 9.90338557107108, 13.891466566494532, 6.863594285079411, 5.72808883871351, 3.368444336312158, 1.7128524375813348, 2.4225237454686845, 5.65611548934664, 7.695856026240757, 11.24841959135873, 13.01122968537467, 10.481044905526296, 11.493540746825081, 13.348857419831411, 16.714920043945312, 19.196611608777726, 16.29452623639788, 14.699171202523367, 15.105988230024066, 13.971595798219953, 9.475748266492571, 7.4655796970639905, 5.98034188577107, 2.716152012348175, 7.269607927118029, 7.304419704845973, 4.966258815356663, 0.35376492568424767, 0.7683613300323486, 6.347432587827955, 10.750676700047084, 2.0506935034479414, 1.7063483808721815, 1.102054429905755, 1.9063097195965903, 4.32922842672893, 5.551529032843454, 1.334974222949573, 0.8308138559971536, 0.7589264363050461, 0.5790983172399657, 0.15392568255109446, 0.46601334533521105, 0.7833674305251667, 2.4239207676478793, 5.780543829713549, 12.07322027002062, 21.287133489336284, 30.98238229751587, 24.203573840005056, 32.64134808949062, 32.479451588221956, 36.51904739652361, 42.63908672332764, 44.837111132485525, 34.087136200496126, 16.727782896586827, 5.038372431482587, 0.4425175775374685, 0.17135736931647572, 0.13932717804397854, 0.16692778414913587, 0.10453553923538753, 0.1816385862018381, 0.1543992321406092, 0.12271122607801642, 0.22122142863060745, 0.10161001514643431, 0.10162360620285783, 0.07260501118642942, 0.1627697351255587, 0.172000932640263, 0.3568950891494751, 0.14658370294741221, 0.0998558257041233, 0.13419502414762974, 0.10872658541692154, 0.09434136482221739, 0.06853897151138101, 0.1304129378071853, 0.09879408803369318, 0.15397152437695436, 0.14462896569498948, 0.12779772813831056, 0.07819955277123622, 0.09655523459826197, 0.10963529986994607, 0.10490204992571048, 0.08041217404284648, 0.10645765252411366, 0.13207901269197464, 0.18114671616681985, 0.11261612456291914, 0.14946168208760874, 0.11150072834321431, 0.26044003346136635, 0.09892463817128114, 0.14803850916879518], [0.027037367756877626, 0.008549163799865969, 0.05275997892022133, 0.05121431685984135, 0.07118787722928183, 0.01730884308926761, 0.04919415865359562, 0.023348267855388776, 0.031699266351227245, 0.02224229309441788, 0.03615147726876395, 0.021902182505332997, 0.010967254804979478, 0.014651761024392076, 0.06186036166868039, 0.020798436731898358, 0.026952835864254406, 0.009169782461997653, 0.0455367700862033, 0.08037552636648927, 0.03975409448945096, 0.003016754818548049, 0.019761066950325454, 0.08314453956804105, 0.028108401357063224, 0.019535842517923032, 0.02705067891760596, 0.035168571796800406, 0.011066384530360145, 0.058656604295330386, 0.027240977456261004, 0.015567289665341377, 0.040671351698360274, 0.00874643852668149, 0.024864070982273136, 0.026429871962006603, 0.07559367974421807, 0.006307336260631148, 0.08316075655498675, 0.028657030846391405, 0.016783751979736344, 0.067360512247043, 0.053751454289470396, 0.026791303817714964, 0.0660531245438116, 1.1899470793349403, 5.877020001411438, 18.165964467184885, 33.406713008880615, 37.90327099391392, 34.41468470437186, 27.578588349478586, 17.949436017445155, 16.71315520150321, 28.28891658782959, 25.229730708258494, 22.465544496263774, 17.491096360342844, 12.063529270035879, 6.762727720396859, 2.8157375029155185, 1.1665628084114619, 0.21754325314291886, 0.13525836994605406, 0.0900672252422997, 0.14182335909988197, 0.052666266448795795, 0.22341868786939553, 0.3205590774970395, 0.07299824258578674, 0.5898855584008353, 2.6092120707035065, 3.403491484267371, 5.829219000680106, 9.02597747530256, 10.47702363559178, 15.495792593274798, 16.96997104372297, 6.342948394162314, 2.5712284403187886, 2.8689698236329213, 3.0054847725800107, 3.8378214240074158, 1.8958624516214644, 0.7120485688958849, 4.505337468215397, 3.818990068776267, 3.7420209646224976, 4.4034582035882135, 4.2020776953016, 4.328271746635437, 4.542500342641558, 7.863102640424456, 5.863039791584015, 6.1406099029949734, 7.060758973870959, 7.63651841027396, 6.275382808276585, 6.030540449278695, 2.9098091636385237, 2.5054939218929837, 1.5901920880590166, 2.070339317832674, 2.6301257141998837, 4.1921956198556085, 3.4000347554683685, 2.669146146093096, 1.88070039663996, 1.3885409257241657, 0.4725320584007672, 0.1804449481091329, 0.8469205402902195, 0.5297578019755227, 1.0258817630154746, 0.5705084981662887, 0.14127731482897485, 0.41851643685783657, 0.019832194383655275, 0.04456003928290946, 0.2544463165104389, 0.565258645585605, 1.7025470648493086, 5.809492630617959, 14.472335968698774, 20.58575279372079, 27.164272478648595, 19.03050102506365, 18.48566324370248, 14.564427392823355, 19.54734104020255, 30.808260440826416, 34.11177451269967, 26.47643382208688, 11.62801444530487, 4.69487737757819, 0.7808344321591514, 0.08216780197939702, 0.059774870718164105, 0.05945857161922114, 0.02811049124492066, 0.09215072808521134, 0.03330300761652844, 0.01332259489156838, 0.03663089618618999, 0.030492512176611593, 0.03245779047054904, 0.10749826739941325, 0.02064610562021179, 0.006944064616358706, 0.010508001100138893, 0.04107960925570556, 0.05911627784371376, 0.056181854767990966, 0.04330612692449774, 0.017431622304554497, 0.03100248213325228, 0.042140515720737834, 0.041118292537118704, 0.03472511184268764, 0.046520900313875506, 0.05355383775063923, 0.03541548051206129, 0.025656319988359298, 0.01940993355986263, 0.0520451999535518, 0.01580259543178337, 0.011810161539220383, 0.027001147557582175, 0.06804873674575772, 0.04332621834639992, 0.02788994531147182, 0.06355789343693427, 0.023765748399975042, 0.010295561963825353, 0.020561032595911195, 0.06887652232710804, 0.024159671905051385, 0.06265358946153096, 0.038362385239452124, 0.06728657907141106, 0.02622378391346761, 0.034708721829312186, 0.0730982722182359, 0.03890957623454077, 0.01422338405557509, 0.0154804015598659, 0.028182305694956864, 0.04991560761949845, 0.013511239501115466, 0.03753444020237241, 0.04365351989067026, 0.008186480895216976, 0.049572550492095094, 0.031304742342659404, 0.008243805229929941, 0.038927581161260605, 0.016546692200271145, 0.021007221957136477, 0.04948772004406367, 0.05750770880175488, 0.03170197709862675, 0.014409690263814159, 0.009563671192154288, 0.024994482020182267, 0.03546770056709647, 0.05886036836143051, 0.036711590963282754, 0.003851315996143967, 0.04005651076191238, 0.0473415714555553, 0.07371865000043597, 0.04879348033240863, 0.06909439313624587, 0.02963567851111293, 0.046750326574380906, 0.054277885505663495, 0.031160886133355752, 0.035173925438097546, 0.020261074316554835, 0.0347176004600312, 0.09826554996626717, 2.094181627035141, 7.821449926921299, 22.643651144845144, 37.53454746518816, 44.334315163748606, 40.37956033434187, 33.09628486633301, 23.617182356970652, 18.608710629599436, 27.866179500307354, 30.25083773476737, 27.731669323784963, 21.207461970193044, 12.923863904816763, 7.892595137868609, 3.2784692900521413, 1.2716605003390993, 0.3092139448438372, 0.09708856312291962, 0.042367550145302496, 0.0745832800332989, 0.08663005860788481, 0.09182422381958791, 0.0390346166677773, 1.1457981169223785, 1.2461601772478648, 2.19893918292863, 2.611439402614321, 7.383770738329206, 10.243619748524257, 9.044499635696411, 8.184510673795428, 7.9309587478637695, 4.484925832067217, 6.645614096096583, 5.303500056266785, 5.19237664767674, 2.6031204547200884, 1.6965884417295456, 3.0776748188904355, 3.0905921714646474, 4.661088287830353, 7.6849647249494275, 6.1056274601391385, 6.498437787805285, 6.437686213425227, 7.726834569658552, 10.916733435222081, 9.673307265554156, 9.838941029139928, 10.548112392425537, 8.871795211519514, 9.791424904550825, 6.546744704246521, 4.843834161758423, 4.062316851956504, 2.6522437844957625, 1.6706387656075614, 3.504429050854274, 4.509985813072749, 3.173660056931632, 2.9183194041252136, 3.1377135515213013, 2.7207921062197005, 1.5002424461500985, 0.5632135953222002, 1.4074864919696535, 1.2262813810791289, 0.35465624928474426, 0.2564515774803502, 0.10656639454620224, 0.3165930403130395, 0.008008389201547419, 0.0697385264294488, 0.34341115983469145, 0.5493704495685441, 2.0093430365834917, 5.719465255737305, 12.889135939734322, 22.767827613013132, 30.79479135785784, 25.82256143433707, 18.963544709341868, 17.284555946077617, 23.775120122092112, 34.57612609863281, 38.26434803009033, 30.758209092276438, 15.841960532324654, 6.252089841025216, 1.1403425868068422, 0.053531228963817866, 0.03615344502031803, 0.04508100489952734, 0.02826408443174192, 0.07402187372956957, 0.08351155237427779, 0.03742942673021129, 0.05296834684642298, 0.05062176240608096, 0.049725916369685104, 0.04887280107608863, 0.015503839855747563, 0.03663201576897076, 0.033955571707338095, 0.007259079587778875, 0.028180432938305394, 0.07197483535856009, 0.013346045909981643, 0.046653255354613066, 0.06336608515786273, 0.02765144534142954, 0.049627684855035374, 0.05317412616152849, 0.013461125449144414, 0.00866253936796316, 0.007126436169658388, 0.02125788466738803, 0.015101802768185735, 0.06222086053873811, 0.009639633187491978, 0.02622154983691871, 0.024829060271648423, 0.04307903143178139, 0.09975836093404464, 0.0399065952348922, 0.07949894733194794, 0.0024344687200417475, 0.02909483521112374, 0.02172422651866717, 0.034152767554457696, 0.13279475857104572, 0.1959151936961072, 0.10406461557639496, 0.25217254566294806, 0.12631766684353352, 0.14985281681375845, 0.18956259957381658, 0.12785515934228897, 0.16293586763952458, 0.1374197889651571, 0.12121665770454065, 0.11260412806378943, 0.09275288041681051, 0.13657273298927716, 0.1589855317558561, 0.13292613652135643, 0.12310229295066424, 0.12095956078597478, 0.15645967157823698, 0.18079915695956775, 0.12390419920640332, 0.08171410632452794, 0.13007770079587186, 0.20261271430977754, 0.08911668589072567, 0.09879188279488257, 0.09680513904563018, 0.094702223315835, 0.10395897445934159, 0.09047875673110996, 0.12059133340205465, 0.1651330997369119, 0.13775385889623845, 0.25827352542962345, 0.11916073731013707, 0.11110368357705218, 0.15368271273161682, 0.1087297202487077, 0.19016292664621556, 0.1478825139680079, 0.16467944479414395, 0.16798424960247108, 0.1158407876001937, 0.12372114402907235, 0.2275659753275769, 2.4402171160493578, 9.465484040124075, 25.57515345300947, 42.810450145176475, 51.845105920519146, 48.694024903433665, 41.41788176127842, 29.00128585951669, 26.42032711846488, 39.430182797568186, 37.30976281847273, 31.38038206100464, 25.61014805521284, 17.29013534954616, 9.937423927443367, 4.1900303874697, 1.948955374104636, 0.5631284798894609, 0.1858294356082167, 0.3146364710160664, 0.6618850177952221, 0.48040458453553064, 1.0365283574376787, 1.3770374229976108, 2.0639421982424597, 3.8337020107678006, 4.996977235589709, 7.350116269929068, 14.541897858892169, 18.760132721492223, 21.679704972675868, 25.455594062805176, 27.248977967670985, 13.609443528311592, 8.397064753941127, 7.776435153824942, 7.961374487195696, 8.220630884170532, 3.4311550855636597, 3.7436702932630266, 5.616674474307469, 6.546834162303379, 8.43556559085846, 6.546437246458871, 6.79446622303554, 7.4508512531008035, 9.921821747507368, 12.685078637940542, 9.66809959071023, 8.035311136926923, 9.462857621056692, 10.483710408210754, 8.966362799916949, 7.390356762068612, 4.692059883049556, 3.6961476547377448, 2.950854561158589, 3.640993288585118, 7.3442641496658325, 11.405386345727102, 9.737807393074036, 7.122457674571446, 8.371468458856855, 8.957831280572073, 3.0142078016485487, 0.39489006463970455, 3.326410774673734, 4.3758664727211, 2.871850286211286, 2.0865813834326605, 0.36567147821187973, 1.331347480416298, 0.20248048140534333, 0.31836081402642386, 0.49301138520240784, 0.850463578743594, 2.8451379367283414, 7.31044031892504, 16.100890363965714, 25.27603350366865, 33.30355657849993, 28.034332854407175, 27.04318274770464, 23.15474499974932, 30.1688038281032, 42.21585805075509, 44.2781355040414, 36.963940552302766, 19.306943791253225, 6.978988664490836, 1.4635029775755746, 0.21978073593761238, 0.18669802828558854, 0.1480344379586833, 0.15851000084408692, 0.22742625139653683, 0.11316527652421168, 0.07680741604417562, 0.11270550119557551, 0.11833049543201923, 0.11876299365290574, 0.2070303572607892, 0.10674621989684445, 0.08064884705735104, 0.16296611673065595, 0.12143659804548536, 0.13364162455712045, 0.17160245616521153, 0.10246237048080989, 0.10652019988213267, 0.1220763208610671, 0.1401076697345291, 0.11809815147093364, 0.14558663644960948, 0.11242718648697649, 0.10187347672347512, 0.17439492632235798, 0.07351526591394629, 0.1500049443649394, 0.12173053941556386, 0.0767940217629075, 0.11081020361078636, 0.10305819208068506, 0.17457894501941545, 0.19624222043369496, 0.1208449833627258, 0.14399080350995064, 0.08425131839300905, 0.10401010207299675, 0.11609704313533646, 0.2326965278812817], [0.023346832753824334, 0.02898474290434803, 0.013652261978547488, 0.025505240773782134, 0.016184320573561957, 0.062132562776761394, 0.01799175126611122, 0.027034657009478127, 0.03541318027834807, 0.04342283155503018, 0.01397890704018729, 0.06327549394752298, 0.047968436032533646, 0.01789806254341134, 0.06148405293268817, 0.005518282730398434, 0.02827927513447191, 0.026325458993336985, 0.019856835382857492, 0.026081903937405775, 0.06191515337143626, 0.049531729825373204, 0.03482680727860757, 0.050772604133401594, 0.06658932327159814, 0.014355059713125229, 0.01136237507619496, 0.03455180721357465, 0.007321660872548819, 0.04457174401198115, 0.02445858863315412, 0.04206505244863885, 0.038008156032966714, 0.0323886307887733, 0.026267951454168985, 0.059813350439071655, 0.05940801397498165, 0.019247363354744654, 0.10917424889547483, 0.009203002688341906, 0.011072599911130965, 0.039305192684488635, 0.06096668355166912, 0.0361873989126512, 0.014095393691344984, 0.10753268269555909, 2.4996480984347205, 9.763410636356898, 22.826876878738403, 30.870533670697892, 32.09731108801705, 26.732155323028564, 20.330606256212505, 20.45130341393607, 20.41637829371861, 19.91269642966134, 20.789480924606323, 19.841378382274083, 19.86023579324995, 14.464655603681292, 8.293804100581578, 4.208183424813407, 1.472804769873619, 0.4503347080733095, 0.05572038310180817, 0.06084000106368746, 0.06358276174536773, 0.055118325765111616, 0.052268224236156256, 0.7148641635264669, 0.4567155156816755, 1.8870781915528434, 2.7624880288328444, 9.143425481660024, 10.32411549772535, 9.530877879687718, 6.61913103716714, 4.610484557492392, 2.1887433528900146, 5.563736149242946, 3.370975000517709, 3.6551168050084795, 1.1273800709417887, 2.0109033414295743, 1.875137278011867, 1.5002944490739276, 2.225693872996739, 3.103793748787471, 4.371706238814762, 3.3297578522137234, 2.3777690955570767, 4.495355078152247, 4.296317849840436, 4.582491133894239, 3.997426756790706, 5.892605679375785, 4.8418921402522495, 3.933413003172193, 2.1011993076120103, 2.177578683410372, 1.3929123197283064, 2.113345627273832, 0.36848140028970583, 1.6493982310806001, 3.8294848884854997, 1.7321717951978957, 2.4985591854367937, 1.6766343010323388, 0.6928843515259879, 0.7295479870268277, 0.8185542481286185, 0.6614625347512109, 0.42414382632289616, 0.2097700373934848, 0.23738588339516095, 0.08779750524887017, 0.21839796299380915, 0.056307587306946516, 0.22828173477734837, 0.6624463019626481, 1.3924653551408221, 4.507163975919996, 9.373300552368164, 14.250688433647156, 15.402837855475289, 21.70552795273917, 21.79890479360308, 27.741513184138707, 25.759204285485403, 30.550680296761648, 33.249374525887625, 30.832877908434185, 19.209795815604075, 6.584783485957554, 1.2160213887691498, 0.10678822799984898, 0.03746820500652705, 0.03308926908565419, 0.03717070132760065, 0.04176662935476218, 0.03496652781697256, 0.03634461208379694, 0.04574444929936102, 0.02924376686236688, 0.04094934071015034, 0.08655056823045015, 0.058986962639859745, 0.048507345507719686, 0.04570292974156993, 0.010807775326871445, 0.007878736426521624, 0.02660972106137446, 0.02738253682452653, 0.029448904961879765, 0.016483174537175467, 0.02927973261103034, 0.046594456902572086, 0.05016271650258984, 0.038706758724791665, 0.021055207953655293, 0.0628513688487666, 0.021063314750790596, 0.027200426507209028, 0.039823729145739756, 0.04522647262950029, 0.01425136938425047, 0.007405499811284244, 0.008572925248050263, 0.029768868149923425, 0.035249185149690936, 0.028492204512336423, 0.129901308832424, 0.04248433620003717, 0.01750828488729894, 0.029677595011889935, 0.09687795263848134, 0.024469207706195966, 0.002848698233719915, 0.030248317601425306, 0.018175108391525488, 0.02786892938560673, 0.028097181780529872, 0.012506720992470426, 0.058727864042988846, 0.03783547565607088, 0.01813542257462229, 0.01427266520581075, 0.0090520328875365, 0.025059958953144293, 0.005656333224448774, 0.06999755038746766, 0.038118197449616024, 0.01405130503033953, 0.032539669291249344, 0.028474257261093174, 0.06083735477711473, 0.04290385065334184, 0.033610319519149404, 0.009390833055866616, 0.041595770844391415, 0.02951002061100943, 0.03277536860800215, 0.015300844230556061, 0.029101562885833637, 0.02084450756332704, 0.027940106012725403, 0.015540511280830418, 0.06468390872968094, 0.0461097386266504, 0.03916577070153185, 0.07330528646707535, 0.04214381340092846, 0.028966232469039302, 0.08793750737926789, 0.03964482321004782, 0.019998162352879132, 0.06287658999540977, 0.025148455186613967, 0.07444616846208062, 0.02929357811808586, 0.041626620439014266, 0.11844184302857944, 3.5303907777581895, 12.924523115158081, 28.757621220179967, 37.63498020172119, 38.75150012969971, 35.28005504608154, 27.632205860955374, 26.249997241156443, 31.119293076651438, 28.292915276118688, 25.56292462348938, 26.11328101158142, 22.537970781326294, 15.387444121497017, 8.098736030714852, 4.516056367329188, 1.369181290268898, 0.4969092160463333, 0.09601404863808836, 0.05714807167117085, 0.07227103625025068, 0.0737610991512026, 0.15191044711640903, 0.31482344812580515, 0.6080396814005715, 0.8524597744856561, 1.0009194910526276, 4.2372698869024, 4.407902445111956, 3.738042252404349, 4.700128044400897, 4.3173300709043225, 4.775727919169834, 3.993793283190046, 4.982298297541482, 6.655390645776476, 4.291973922933851, 3.9203073978424072, 3.6618908643722534, 2.8792709623064314, 2.403269635779517, 3.850065452711923, 3.0591908735888342, 4.867729016712733, 4.3748811313084195, 6.657159396580287, 7.370790634836469, 6.805707974093301, 5.506864275251116, 6.6363899282046726, 7.265471577644348, 5.617542564868927, 3.395061582326889, 3.9950713174683705, 4.036988062517984, 2.661403681550707, 2.9307547254221777, 2.8819659948349, 2.587526091507503, 2.9250241986342838, 2.2972431651183536, 2.788079329899379, 0.8864592100892748, 1.3187803604773112, 0.619920015335083, 0.4674223097307341, 0.5653602629899979, 0.285526911595038, 0.0951872333618147, 0.057239762108240805, 0.07437556689339024, 0.22625774624092237, 0.1124291881652815, 0.6657978306923593, 1.3770525136164256, 4.698562962668283, 12.016886881419591, 19.759575503213064, 23.074194533484324, 29.10327672958374, 26.165840659822734, 27.311772312436783, 28.748661518096924, 34.14528567450387, 38.68365791865757, 34.655627386910574, 22.28635219165257, 8.58987205369132, 1.9532005063125064, 0.165738597246153, 0.035302368724452596, 0.017701338278129697, 0.044269120786339045, 0.0684901305607387, 0.018801425051476275, 0.009397782950795122, 0.026997020368331244, 0.06419611669012479, 0.041365160540278466, 0.049494895551885874, 0.017562055394851735, 0.06899693515151739, 0.012758895987644792, 0.03589291810723288, 0.026272504424144114, 0.011166038424042719, 0.02933692972042731, 0.03213712499876108, 0.031139122122632604, 0.03837172866665891, 0.02657943973982973, 0.06738854931401354, 0.07855298130639962, 0.06496678997895547, 0.04664675498913441, 0.06846699930195298, 0.04884797687243138, 0.028303492049287473, 0.032793359964021614, 0.027920861063258987, 0.06248007448656218, 0.028590161220303605, 0.05791862960904837, 0.03209317967827831, 0.01954482971424503, 0.08240819336580378, 0.06893638947180339, 0.03289991710335016, 0.0371217789527561, 0.07294919807463884, 0.08800677223397152, 0.11642065005643026, 0.07329534592905215, 0.09336519041763884, 0.11520641164055892, 0.09942893896784101, 0.12976096064916678, 0.11049649651561465, 0.0916978195309639, 0.17399839045745985, 0.07614551191883427, 0.15416323766112328, 0.17543524264224938, 0.07672279594199997, 0.15730155711727484, 0.14025276766291686, 0.1019717285941754, 0.12909936186458382, 0.16857890412211418, 0.10447637098176138, 0.11450190230139665, 0.17427124295915875, 0.13821010584277765, 0.09120619376855237, 0.13213419115969113, 0.10293997092438595, 0.14007942910705293, 0.13841302852545465, 0.17575519904494286, 0.199147653100746, 0.1620683063353811, 0.14960893775735581, 0.11839304279003825, 0.11860794840114457, 0.14141463674604893, 0.13869913960141794, 0.1499610295785325, 0.12072501837142877, 0.1677273019616093, 0.1790019619677748, 0.2046280311686652, 0.1491189133375883, 0.22456029589687074, 0.12969345998551163, 0.13827983210129396, 0.40684267612440245, 4.52292856999806, 14.940219845090594, 32.88933277130127, 41.82454940250942, 46.29267883300781, 41.536720275878906, 35.88193580082485, 32.72211047581264, 33.91966029575893, 33.29776872907366, 30.196700845445903, 31.491223199026926, 27.958178860800608, 19.56965865407671, 11.290092280932836, 5.969022836003985, 2.583894354956491, 0.9297199973038265, 0.2319918828351157, 0.20660996410463536, 0.3682018167206219, 0.31529123016766136, 0.5960697808435985, 2.1942176648548672, 3.0283230670860837, 7.072325987475259, 7.014080107212067, 18.768513986042567, 20.1644800390516, 15.829457248960223, 18.027730056217738, 12.646978190967015, 7.132796594074794, 10.414777329989843, 11.887058922222682, 9.801531927926199, 4.677220267908914, 4.227651408740452, 5.589913487434387, 3.8782573342323303, 2.7324277332850864, 3.936259159020015, 5.626301637717655, 6.248191901615687, 5.2178526520729065, 8.068408012390137, 7.448541845594134, 6.41441148519516, 6.054210356303623, 7.729581713676453, 7.904291561671665, 6.413960286549159, 3.0453698209353854, 6.57831905569349, 4.8005586096218655, 3.507637598684856, 3.903540526117597, 4.532515781266349, 9.598832130432129, 6.7480453082493375, 7.105896643229893, 6.652121952601841, 6.526215382984706, 5.1497659512928555, 2.8418108352593014, 2.9446658875261034, 1.3920212132590157, 1.091749057173729, 0.8111433972205434, 0.5341658368706703, 0.6256366457257951, 0.5220231541565487, 0.3905838914215565, 1.3336559108325412, 2.1219833237784247, 6.026918266500745, 12.963220238685608, 20.73714014462062, 24.172253097806657, 32.93432583127703, 33.742158140454976, 37.63645321982247, 35.7387820652553, 42.28887319564819, 43.84036772591727, 40.439686570848735, 25.2148528780256, 10.09168175288609, 2.113795740263803, 0.27390987638916287, 0.055613493480320485, 0.1065410173365048, 0.1970580637987171, 0.2364341158952032, 0.15520552173256874, 0.1921666812683855, 0.13325335324874946, 0.1186006066522428, 0.10397837377552475, 0.11745916147317205, 0.14189562307936804, 0.08582282585224935, 0.10912493297031947, 0.09909232453043972, 0.08891934076590197, 0.16215552522667817, 0.09551564431084053, 0.11685123480856419, 0.1030825786292553, 0.15783647341387613, 0.12988996372691222, 0.15747333504259586, 0.1487515409077917, 0.13306318702442305, 0.1438903124736888, 0.2020065789776189, 0.12836533625211033, 0.16525287473840372, 0.08103917432682854, 0.05195131106302142, 0.10897473245859146, 0.17007235969815934, 0.1254009660333395, 0.11955371765153748, 0.11598832825464861, 0.20838806512100355, 0.29521175048180986, 0.07111119598682437, 0.08407292475125619, 0.28788338229060173], [0.03821855277887412, 0.02671145890573306, 0.03489691012405923, 0.02448100403749517, 0.012604253616050949, 0.011529404952723001, 0.03220238649685468, 0.034599806780793836, 0.04567832945446883, 0.06853420141019992, 0.020336415452350463, 0.018287019172151173, 0.03351995222536581, 0.014765831242714609, 0.0124806915409863, 0.009279097846177007, 0.037544563944850645, 0.007324857620655426, 0.03420418693817087, 0.07936584590268986, 0.05146485573745199, 0.03970379129584346, 0.0488770860247314, 0.05174961992140327, 0.03357810606913907, 0.020642802851008515, 0.0496964475938252, 0.03710688171642167, 0.07213997042604856, 0.039552264248153994, 0.017261225197996413, 0.04547250603458711, 0.01974730795648481, 0.030535728071949313, 0.02722455351613462, 0.01430458010041288, 0.06595069968274661, 0.04304833111486264, 0.09846656596554176, 0.026367478970704333, 0.041549172451985736, 0.037424951791763306, 0.024433428554662635, 0.03224291878619364, 0.019015765782179575, 0.039839505084923336, 0.08260730268167597, 4.281788732324328, 13.261490770748683, 27.06710192135402, 32.23360347747803, 34.19848803111485, 33.32014192853655, 19.976493052073888, 16.072359323501587, 19.37125631741115, 32.254764216286794, 29.545018877301896, 25.767948593412125, 21.79026297160557, 15.761981555393763, 10.672260199274335, 5.161009439400264, 2.418467083147594, 0.5485317802854947, 0.145994028874806, 0.04945206642150879, 0.08805803555463042, 0.08082115423998662, 0.17717229228998932, 0.1424468242164169, 0.2709982011999403, 0.24140924321753637, 1.1112689354590006, 2.0061872516359602, 2.089565634727478, 2.504210025072098, 1.6218493836266654, 2.3509407980101447, 4.611728719302586, 2.958015331200191, 5.255991314138685, 4.324379886899676, 2.0762752507414137, 2.522636864866529, 1.3132131163563048, 1.4649582994835717, 2.1406639899526323, 0.8510255143046379, 1.7523912702287947, 1.8384490524019514, 2.584954389504024, 3.389122609581266, 3.5214052370616367, 2.8645944127014706, 3.5534470719950537, 1.910346622977938, 3.6968537654195512, 2.4980728115354265, 1.5801991671323776, 2.6515804486615315, 2.672545552253723, 1.711048077259745, 2.215121103184564, 1.4101409209626061, 1.2881844022444315, 1.167576702577727, 1.426706837756293, 0.8395530613405364, 0.42899540598903385, 0.4884946761386735, 0.25367433364902225, 0.19480113419038908, 0.1738869614366974, 0.03012270719877311, 0.03778272634372115, 0.028152351766558628, 0.21145838179758616, 0.6511517880218369, 2.2183494099548886, 4.089597216674259, 6.215827626841409, 13.210929598127093, 13.448680451938085, 19.694514308656963, 20.771438189915248, 20.704572200775146, 25.646950926099503, 26.71916913986206, 35.74743604660034, 30.038205487387522, 20.748797484806605, 12.47171596118382, 2.731207021645137, 0.09785600658506155, 0.046641204572681866, 0.01672201886373971, 0.0681488478024091, 0.02551076065615884, 0.024230765411630273, 0.023331419830875735, 0.07460508814879827, 0.05164860641317708, 0.007391332848263639, 0.05443636414461902, 0.017573035787791014, 0.01984335289203695, 0.05733023796762739, 0.04796091786452702, 0.033274878947330375, 0.05481713764103396, 0.006650057937284666, 0.028501968631254773, 0.0613452246678727, 0.0348556585876005, 0.02526103093155793, 0.015931863138186078, 0.0681623031518289, 0.04765131590621812, 0.02784486853384546, 0.034879950141268115, 0.05112991049619658, 0.06130853627941438, 0.05660557274573615, 0.008464494503901472, 0.04342029383406043, 0.04884177506236093, 0.03195667200322662, 0.017359936776171838, 0.009601043204643896, 0.01233626451409821, 0.031136808318219016, 0.012872973839486284, 0.01769118569791317, 0.027508052232276117, 0.01295058721942561, 0.03005737784717764, 0.026070055019642626, 0.028238905693537424, 0.03137030239616122, 0.021979908691719174, 0.04308608141062515, 0.03170850799818124, 0.009066247348008412, 0.0315625856497458, 0.018420392015416707, 0.04480407779504146, 0.03603249954591904, 0.013536034018865653, 0.023275089549965093, 0.03348826463999493, 0.040058753320149014, 0.04100864467078021, 0.004467221808486751, 0.06401388932551656, 0.06594919333500521, 0.04695319836693151, 0.011189061965394233, 0.056244463194161654, 0.0207901823533965, 0.025214766717648933, 0.10812610906681844, 0.011893827451526054, 0.06843612595860447, 0.050875392010701556, 0.0257113169479583, 0.11690215207636356, 0.013951939514039882, 0.027813428613756384, 0.03686126900304641, 0.005341069739578026, 0.018074931177709783, 0.03851609716990164, 0.0222306104177343, 0.030980592593550682, 0.07418237440288067, 0.03877255965822509, 0.012493014585093727, 0.014648051134177616, 0.012393751697215651, 0.044524032822144885, 0.0527093398517796, 0.3937091422932488, 5.7052136319024225, 16.760937963213237, 31.384926182883127, 37.712758336748394, 37.62054531914847, 36.71641097749983, 25.983123881476267, 19.385837112154277, 25.66629818507603, 32.15216711589268, 32.238352571214946, 30.09100832257952, 25.270301239831106, 19.113884619304113, 12.103886144501821, 5.797065777438028, 1.687593238694327, 0.3748016825744084, 0.11803846753069333, 0.031022173219493458, 0.12371445367378847, 0.09744146918611866, 0.24508763583643095, 0.28595943695732523, 0.40620941296219826, 0.838573039642402, 2.1851428832326616, 2.3678976595401764, 2.578842146056039, 1.8718866067273277, 2.1898070786680495, 3.3495686863149916, 4.12828608921596, 2.2747314359460558, 4.723354569503239, 4.456086465290614, 3.506144170250211, 4.571548155375889, 3.830980053969792, 2.990953266620636, 3.570506419454302, 2.6779933742114475, 2.1751730867794583, 3.2288632776056017, 3.7516272834369113, 4.029591270855494, 5.311225584575108, 4.344746794019427, 4.6263016973223, 3.470925054379872, 3.2187831784997667, 3.210784499134336, 2.3707900643348694, 2.8775317413466315, 2.6062208712100983, 2.3689031941550116, 3.2348005133015767, 2.4068203823907033, 2.23347390123776, 1.2372569292783737, 0.9637856036424637, 1.2429452240467072, 0.535303387258734, 0.44324811547994614, 1.328132961477552, 0.3167413952095168, 0.13236226035015924, 0.06151814253202506, 0.044962217166487656, 0.07345263713172503, 0.2389762337718691, 0.918280548283032, 2.8924896929945265, 4.853999810559409, 8.888777477400643, 15.412541014807564, 18.45838287898472, 23.183187450681412, 26.965284756251744, 25.270362036568777, 32.002249308994834, 31.468641553606304, 40.332093715667725, 36.065937995910645, 25.24576367650713, 15.368930646351405, 3.7747474142483304, 0.22584538693938935, 0.07580635297511305, 0.005777347824602787, 0.06950042849140507, 0.16268934229654924, 0.018835234755117978, 0.055832226028931994, 0.026980470899226408, 0.013953677411856396, 0.008735816909133323, 0.023367908051503555, 0.05404241689081703, 0.03742705185764602, 0.07370588675673519, 0.04343277209305337, 0.03030893113464117, 0.024168458933542882, 0.006372082496194967, 0.0181117467914841, 0.024025895333449756, 0.03693375350641353, 0.01497466057272894, 0.02231839418943439, 0.035337184356259446, 0.017263337138241956, 0.037578202318400145, 0.052329227927007844, 0.027529583844755377, 0.023036362270691564, 0.03517686349472829, 0.03432967181184462, 0.03411409105839474, 0.06181731540709734, 0.029076531728995696, 0.021948053168931177, 0.010118784083585654, 0.03878218467746462, 0.04518537715609584, 0.026553526487467543, 0.0491196147964469, 0.012618453657653714, 0.012165242307154196, 0.13490061914282186, 0.08680332931024687, 0.13315103016793728, 0.15148556205843175, 0.15656477665262564, 0.15722131356596947, 0.11374008389455931, 0.11798518896102905, 0.07596785788025175, 0.10910461084651095, 0.0999531140550971, 0.09695141762495041, 0.13965098852557795, 0.10828458770577397, 0.14192669998322213, 0.09059175995311566, 0.14371271271790775, 0.08054330772055046, 0.16357423338506902, 0.2105227227189711, 0.13884631384696278, 0.09165480719613177, 0.1808756957096713, 0.11146727656679493, 0.09907673858106136, 0.19377083304737294, 0.11667443572410516, 0.11467555298336915, 0.17840783670544624, 0.14720786016966614, 0.1532454647655998, 0.07615336935435023, 0.1635850899453674, 0.07940823398530483, 0.1264053335679429, 0.1843939269227641, 0.19323199481836387, 0.10049191835735526, 0.2392980493605137, 0.1900372076779604, 0.16766467317938805, 0.08338924643716641, 0.1254041280065264, 0.23206426895090512, 0.08893272147646972, 0.15610045513936452, 0.6119765958615712, 6.800967131342206, 18.92215255328587, 36.885245255061555, 45.883026940482004, 47.21009465626308, 46.14110388074602, 32.535190037318635, 26.770523275647843, 31.649735927581787, 44.07032183238438, 41.68477249145508, 37.268282072884695, 32.264078276497976, 23.182631594794138, 15.065327371869769, 7.427978651864188, 3.1027165608746663, 1.0185447910002299, 0.48208577718053547, 0.25647611330662456, 0.34067218537841526, 0.6367456753339086, 0.8230894676276616, 1.0883454169545854, 1.5393530960593904, 3.5522163723196303, 4.986123715128217, 5.442410179546901, 5.496091961860657, 6.086760495390211, 6.8348565357072015, 6.646998090403421, 10.87072593825204, 10.712075982775007, 10.54214562688555, 12.392844353403364, 8.810846482004438, 6.922430327960423, 5.54893170935767, 4.498419667993273, 5.071651262896402, 2.6897855528763364, 4.321807750633784, 3.361614908490862, 5.376420097691672, 6.744172556059701, 7.086286221231733, 4.198266174112048, 4.6967334151268005, 3.1850255727767944, 5.368069665772574, 4.57400564636503, 3.609770255429404, 5.855290813105447, 5.690249817711966, 5.013470521994999, 6.030659002917154, 4.593728976590293, 4.427927153451102, 4.171121733529227, 5.974395964826856, 2.9840202672140936, 3.7268048439707075, 2.088976340634482, 2.6236949392727444, 1.8754338792392184, 1.060593117560659, 0.15825370459684304, 0.34854213308010784, 0.27188045957258766, 0.3645074649580887, 1.2267222659928458, 3.1899212300777435, 6.205363639763423, 9.68694223676409, 19.819203206471034, 21.35955630029951, 30.040522711617605, 31.49917541231428, 30.43128592627389, 36.86429991040911, 38.94473648071289, 45.72976010186331, 40.94587673459734, 28.570549658366613, 16.342750208718435, 4.103561793054853, 0.3288362819169249, 0.201528985319393, 0.10887215831982237, 0.2918515093624592, 0.1509332074118512, 0.09364457042621714, 0.11972147864954812, 0.20642442548913614, 0.11659295723906585, 0.11085740929203373, 0.11765156686306, 0.12125036732426711, 0.11689904438597815, 0.20443938486278057, 0.149483340925404, 0.09308315733713762, 0.1186914760619402, 0.06758071043129478, 0.113153863565198, 0.16799562184938363, 0.12898896421704972, 0.09486604881073747, 0.12431513358439718, 0.11697250258709703, 0.13222735401775154, 0.06457531598529645, 0.1433006384010826, 0.14701421984604426, 0.14366119833929197, 0.12996560681079114, 0.09844363826726164, 0.16864236071705818, 0.22286759529794964, 0.09090834403676645, 0.13158301716404303, 0.12531427639935697, 0.17115672651146138, 0.10464596402432237, 0.10852038541010448, 0.12090493871697358, 0.11372892199350254, 0.1263877595109599], [0.04442415586007493, 0.01835932725641344, 0.08256603418184177, 0.028741216686155115, 0.03744793038016983, 0.06812245957553387, 0.055656407427574904, 0.007904948234292013, 0.03853460081986018, 0.01838311499782971, 0.026056078894596015, 0.01646246395206877, 0.019190427481329868, 0.020793693772118007, 0.03991631185635924, 0.05976427200117281, 0.09469411482236215, 0.020215797371097972, 0.027566769260114858, 0.05344908551446029, 0.07214480159538132, 0.03142794733867049, 0.041030744556337595, 0.009238817462963718, 0.05751756791557584, 0.04437031749902027, 0.020039919397926757, 0.03559556031333549, 0.0348990373313427, 0.031563019912157736, 0.02089228999934026, 0.0339122947438487, 0.03244240129632609, 0.02201723659943257, 0.03119399185691561, 0.038498244913561006, 0.026089018377076303, 0.02719981243301715, 0.05958072149327823, 0.01293536089360714, 0.01566261874644884, 0.0043397746963559514, 0.02482535716678415, 0.031092462662075247, 0.02587716108454125, 0.014830599106582147, 0.04939885570534638, 0.5634572165352958, 5.026446282863617, 14.024352601596288, 26.18575245993478, 36.657719544001985, 34.846442290714805, 25.764799322400773, 24.48262218066624, 30.737503460475377, 28.906373466764176, 36.49750450679234, 33.73798227310181, 25.905920709882462, 19.94493954522269, 14.060462389673505, 10.72796390737806, 5.273894216333117, 2.0125035984175543, 0.8602336687701089, 0.39410003274679184, 0.2222069464623928, 0.0756753414337124, 0.09509095602801867, 0.16474054008722305, 0.3547989044870649, 0.20934812431888922, 1.6210641286202838, 1.2020441102130073, 1.604937793953078, 0.8230925074645451, 0.9563279066767011, 3.46058635200773, 2.2196647908006395, 1.518008447119168, 4.970282690865653, 2.7451001618589674, 1.8358430436679294, 2.8386439766202654, 2.037768985543932, 1.72294382750988, 2.2063112216336385, 0.18062708047883852, 0.8705179254923547, 1.9659113671098436, 1.7259269931486674, 1.2987556521381651, 2.606160725866045, 3.1150059700012207, 2.8251911784921373, 2.7860936650208066, 1.2170937997954232, 1.765393846801349, 0.868666122002261, 1.474034383893013, 2.432466617652348, 2.5232960752078464, 3.659340875489371, 2.3295968004635403, 1.36606784590653, 0.7286478696124894, 0.14387759672743933, 0.4759085572191647, 0.2870325265186173, 0.3492035147334848, 0.4274143651127815, 0.03881072386034897, 0.07274335090603147, 0.09332393548850502, 0.1097746506067259, 0.4501671642065048, 0.9805070949452264, 1.8645443149975367, 4.799397391932351, 10.678681203297206, 14.011604394231524, 17.82201647758484, 24.487346955708094, 18.400407109941753, 17.864397014890397, 25.917597157614573, 24.273033244269236, 34.26565974099295, 29.536205087389263, 22.665397269385203, 13.39688857964107, 3.3578895883900777, 0.22930336424282619, 0.011795708743323172, 0.05474046996927687, 0.057123250860188685, 0.047925274419997416, 0.004562152250270758, 0.04431691340037754, 0.008717307321993368, 0.02147393869901342, 0.06231757892029626, 0.02968884851517422, 0.03162025773365583, 0.059541339320795875, 0.028143527418641106, 0.04588909260928631, 0.05146240283335958, 0.04193395609036088, 0.028089777267138873, 0.048285434022545815, 0.07174219962741647, 0.03903397545218468, 0.038159893426511965, 0.005242293276491442, 0.008816187685754682, 0.015774473547935486, 0.016615359944158366, 0.015036230840321099, 0.05095527933112212, 0.04200263061959829, 0.04023210205403822, 0.039646587401096306, 0.04188498282538993, 0.055749237803476195, 0.060646048613957, 0.01134274760261178, 0.017314770092655505, 0.04996763429205332, 0.023256458674690554, 0.035018215222018104, 0.04427728016993829, 0.022051738408793296, 0.012814177083782852, 0.028305005182379057, 0.014043420453422835, 0.025732392245637517, 0.07460219758961882, 0.0166214667593262, 0.03228721355221101, 0.053263543506285975, 0.011524174295897995, 0.03842055943927594, 0.011237479679818665, 0.0026422825799922323, 0.03248864685052207, 0.02294769131445459, 0.04236074783174055, 0.008741961043727185, 0.04312841860311372, 0.009971489398075002, 0.006373752964594002, 0.029461203409092765, 0.03572583564424089, 0.026767441437446644, 0.030953536009682075, 0.030671380792877505, 0.03257494293419378, 0.0028263443216149297, 0.10372815041669778, 0.09312745888850518, 0.048881048669240305, 0.03689987086025732, 0.016916934833196656, 0.06257224668349538, 0.004461435601115227, 0.021533166324453692, 0.07185641742710557, 0.03929102148062416, 0.032986857795289586, 0.05742823878037078, 0.020621875134695853, 0.06689961055027586, 0.0634809679218701, 0.07536748331040144, 0.026391622943005393, 0.01801359500469906, 0.01304791628250054, 0.045276334775345664, 0.011487833656636732, 0.0062137611925468916, 0.07917404440896851, 1.0081465946776527, 7.292870930262974, 18.221371139798844, 30.86515576498849, 42.334741728646414, 40.65555667877197, 31.233597891671316, 29.88821472440447, 35.32482576370239, 36.089287417275564, 44.15641696112496, 41.363817828042166, 32.715388093675884, 23.988593101501465, 16.407457045146398, 9.778720123427254, 6.40612358706338, 2.6658379350389754, 0.9003336770193917, 0.40993085184267586, 0.25187238891209873, 0.09492308646440506, 0.17326986097863742, 0.27893003129533356, 0.37860383998070446, 0.1703466506940978, 0.6287352166005543, 1.069204758320536, 1.4087669146912438, 1.650809149656977, 1.01031616968768, 0.883154418851648, 1.757631623319217, 1.8937621414661407, 3.980334622519357, 2.923502108880452, 3.6666330099105835, 3.534697575228555, 3.064745524099895, 3.318652242422104, 1.6713585555553436, 2.440617940255574, 2.112839928695134, 3.3468858131340573, 3.3863739456449236, 2.6735730171203613, 3.853719336645944, 3.5026073200362067, 3.2917201561587195, 3.7118605715887885, 2.013346936021532, 2.267457974808557, 2.2758029784475053, 2.3025266187531606, 3.287863905940737, 3.7350419334002902, 3.112618178129196, 2.0649998443467275, 2.1337885303156714, 0.5113514267972538, 0.8120897092989513, 0.8117933794856071, 0.6192439230425018, 0.33454327711037224, 0.2425132468342781, 0.1429814283869096, 0.10542293411812612, 0.11954215541481972, 0.12857123091816902, 0.24714115421686852, 0.9978653235094888, 2.2171376006943837, 5.380455264023372, 11.63987762587411, 16.759343351636613, 24.930397101811, 25.222890206745692, 23.578070947102137, 23.301572595323833, 29.952805178506033, 28.42853195326669, 38.05526631219046, 34.78209154946463, 26.40383904320853, 15.122674328940255, 5.023402103355952, 0.4971890981708254, 0.027338766226811067, 0.08124886200364147, 0.030099772715142796, 0.012458763833689903, 0.03298937855288386, 0.06685353802250964, 0.0213910878768989, 0.013223108087134148, 0.02068454971803086, 0.022122870931135755, 0.03580137694786702, 0.052900537449334345, 0.015897446145702685, 0.0320875614083239, 0.028739740872489553, 0.0698532395597015, 0.017389296986428753, 0.028788985551467965, 0.05645664109449301, 0.026725518151319454, 0.031439380653734715, 0.02192284389665084, 0.06625310916985784, 0.030886551032641103, 0.05447836885494845, 0.019808728946372867, 0.015599691408819385, 0.05221209242673857, 0.012092208190421973, 0.06343566892402512, 0.04264656713764582, 0.05047443549015692, 0.03381527441420725, 0.02085693832486868, 0.035623465065977404, 0.028452608601323197, 0.03922376508957573, 0.0444917447332825, 0.040217842640621324, 0.040083638591957946, 0.03296093775757721, 0.023626258563516394, 0.1281669054712568, 0.12802486095045293, 0.16335218958556652, 0.30373615877968924, 0.13748872812305177, 0.15407463455838816, 0.16248297265597753, 0.08866971451789141, 0.11311445425131492, 0.09411305135914258, 0.08192548355353729, 0.11872924332107816, 0.23033411321895464, 0.08102950520281281, 0.14644583820232324, 0.1521319073757955, 0.09180917391287428, 0.0901621047939573, 0.1313771360686847, 0.0906597695180348, 0.11995522039277212, 0.12158074602484703, 0.09956974855491094, 0.12864611404282705, 0.1896307516310896, 0.11937154456973076, 0.15311049057969026, 0.15139898099005222, 0.10032719719622817, 0.16317951599402086, 0.07520886217909199, 0.1976592322545392, 0.16881192661821842, 0.12914353449429783, 0.11113012608672891, 0.20669684372842312, 0.08519904860960585, 0.1829996867371457, 0.17995569721928664, 0.08427090091364724, 0.1450597404369286, 0.17099458378340515, 0.07520974427461624, 0.1049493302458099, 0.1231201384216547, 0.07722662176404681, 0.26493809638278826, 1.549174700464521, 7.811488815716334, 19.924006359917776, 34.9453637940543, 49.18868105752127, 48.01498787743704, 39.601591382707866, 36.76867185320173, 45.29073469979422, 42.449307101113455, 50.969837869916645, 46.044857433864046, 39.59044647216797, 30.737579890659877, 20.823264803205216, 15.934189183371407, 8.220820222582136, 3.4844996631145477, 1.330879345536232, 0.8590819505708558, 0.4579079459820475, 0.19515598086374147, 0.5069490373134613, 0.5467236744506019, 1.142307949917657, 1.1446767428091593, 3.934754874025072, 3.989271742956979, 6.86175822360175, 5.621564703328269, 5.447297368730817, 8.353987659726824, 5.653677540166037, 5.400251984596252, 13.116020679473877, 8.565729669162206, 7.54578709602356, 10.814804230417524, 7.137099266052246, 5.234040652002607, 5.453977627413614, 2.5355266417775835, 3.046270481177739, 5.180059662887028, 5.235880187579563, 4.201941771166665, 5.446898281574249, 4.938088646956852, 5.305093365056174, 6.78406650679452, 3.611214177949088, 4.500914939812251, 5.657492969717298, 6.185338931424277, 7.33570396900177, 9.25221950667245, 10.014839019094195, 7.22713098355702, 7.027018955775669, 4.473486925874438, 3.6592991862978255, 2.5764148363045285, 2.746798127889633, 1.4438624829053879, 2.4228385857173373, 0.7982400496091161, 0.3589835927954742, 0.5221685777817453, 0.28675223727311405, 0.5965959983212608, 1.6485998396362578, 3.093830249139241, 6.797183402947017, 15.37057910646711, 20.681393010275706, 24.984837974820817, 34.061806542532786, 27.044280563082012, 28.101061616625103, 35.11582395008632, 33.80737393242972, 44.02694770268032, 40.43811975206648, 30.954721518925258, 18.076410872595652, 5.728175691195896, 0.9374291322060994, 0.1369685631777559, 0.2123212069272995, 0.11711631129894938, 0.11822160413222653, 0.1245783916009324, 0.08705198525318078, 0.12102913776678698, 0.09411305814449276, 0.15396844382796968, 0.20946179250521318, 0.1724005490541458, 0.18002402569566453, 0.06861697589712483, 0.18924508589719022, 0.11800501575427395, 0.17741873620876245, 0.12862844499094145, 0.14648338833025523, 0.14823567787451403, 0.06165258067526987, 0.16829832989190305, 0.12819551250764302, 0.1149271401975836, 0.10190618889672415, 0.09997875589345183, 0.1047930975577661, 0.10622376828853573, 0.11870869728071348, 0.14273680294198648, 0.1283596908407552, 0.12345593183168344, 0.13261770164327963, 0.2054461815527507, 0.09423827499683414, 0.09502053087843315, 0.10738987821553435, 0.08343300516051905, 0.16472909998680862, 0.14201876361455235, 0.09439661792878594, 0.12459166374589715, 0.13752146065235138], [0.04126852697559765, 0.011662312151331986, 0.03828390248652015, 0.04196339433214494, 0.030707780803952898, 0.025826174266902462, 0.01190215562071119, 0.04218950934175934, 0.05594936492187636, 0.0053412597293832475, 0.024193881944354092, 0.00684598958884765, 0.07690619717219047, 0.016069351296339716, 0.03707602872912373, 0.01184957763845367, 0.04453439065920455, 0.07164458557963371, 0.01331552879751793, 0.06869586916374308, 0.03181699896231294, 0.04940226534381509, 0.021766104003680602, 0.020965680346957276, 0.002385146645662774, 0.020855672857058898, 0.08926882701260702, 0.031100666150450706, 0.04124158574268222, 0.01820536087533193, 0.03237787940140281, 0.05575781109343682, 0.013115897857850152, 0.018730657241706337, 0.02465401350387505, 0.043361841434878964, 0.04551243442775948, 0.028430327207648327, 0.005071827044178332, 0.030412875914147923, 0.047829960605927875, 0.0656690669379064, 0.027364928840792606, 0.012389543931931257, 0.019265208825735108, 0.008535335256185914, 0.035688380511211495, 0.011584982059762945, 1.0731669685670306, 5.324688587869916, 16.348334823335918, 25.204736300877162, 32.82755981172834, 32.594076020377024, 33.04345771244594, 29.929209096091135, 25.708914961133683, 28.256225313459122, 27.189048017774308, 25.00946065357753, 29.575511046818324, 20.032893317086355, 10.447786484445844, 6.145007678440638, 3.6861179300716946, 2.991531704153333, 1.795813928757395, 1.060921202812876, 0.4153094089456967, 0.22146716687296117, 0.24484966003469058, 0.12902825139462948, 0.08523749440376248, 0.47077552122729166, 1.0405437648296356, 1.0634095264332635, 0.637027023094041, 0.623457028397492, 0.7478792348078319, 1.3846526486533028, 1.3453206334795271, 2.060835702078683, 1.467453462736947, 2.671532852309091, 3.531047599656241, 2.835786312818527, 1.919590984072004, 1.3462216194186891, 2.735803037881851, 0.874988277043615, 1.010875933936664, 1.7518956682511737, 0.5219427070447377, 2.0919189027377536, 2.259211765868323, 2.2550675996712277, 1.4927202612161636, 0.8483467123338154, 1.5330872322831834, 1.6547240253005708, 1.2587144864456994, 1.7394726148673465, 1.7991528638771601, 1.5620764195919037, 1.0316268375941684, 0.9226745239325932, 0.15317238654409135, 0.6701611908418792, 0.7468609980174473, 0.3895307236484119, 0.0974852821922728, 0.12287119749401297, 0.08031750483704464, 0.09337112081370183, 0.13270816393196583, 0.465021761400359, 1.3860825662102019, 3.2010413876601627, 5.011722615786961, 10.350557735988072, 16.26516314915248, 13.661741750580923, 13.663688114711217, 23.104299340929302, 16.453421115875244, 14.67991600717817, 27.029199498040335, 30.18131058556693, 28.254762717655726, 22.211440188544138, 15.245851993560791, 5.025200818266187, 0.7935396475451333, 0.04977313222895775, 0.13064625885869774, 0.02944269297378404, 0.005370689913563962, 0.0365513175992029, 0.0216900724585035, 0.014485389326832123, 0.05873688177338668, 0.0541597050614655, 0.037454359499471526, 0.008926054379636688, 0.021398629793631177, 0.018066115311479995, 0.00578427651531196, 0.05961077380925417, 0.05584549138854657, 0.060842749130512984, 0.033058768936565945, 0.03403871938852327, 0.03790409590250679, 0.05473514007670539, 0.021613199529903274, 0.011271631195476013, 0.006867156912838774, 0.02699063196113067, 0.02316096335250352, 0.015915783554581658, 0.015996410478172556, 0.047505122143775225, 0.023585152912086675, 0.04831986967474222, 0.021143249568662474, 0.0217919086904398, 0.07857886063201086, 0.016078253675784384, 0.024702706873150806, 0.033145774089332135, 0.02304010439131941, 0.04348148072936705, 0.009253908081778457, 0.045884163052375825, 0.02047126241294401, 0.034872615177716525, 0.06466129315750939, 0.04230228864720889, 0.008080738846079578, 0.04970291063987783, 0.08780156967363187, 0.02053765536818121, 0.044353934270995, 0.048321786536169906, 0.023099476205451146, 0.03933634761986988, 0.10134687248085227, 0.07255272327789239, 0.03356135303952864, 0.013266195908987095, 0.03252772028957095, 0.06813214905560017, 0.08344351566795792, 0.041073641540216546, 0.038840664218046834, 0.011975822471348303, 0.04620158512677465, 0.023424119588785937, 0.01579325200457658, 0.038617205673030446, 0.06581911138658013, 0.021747557945283394, 0.08372421881982259, 0.03900776364441429, 0.02730274958802121, 0.013036187804703201, 0.05938596158687558, 0.029818882966148, 0.0835051266476512, 0.022054927523380945, 0.04671703086101583, 0.023376447414713244, 0.01936096029489168, 0.05112292497817959, 0.005431938301106649, 0.017701653796913366, 0.056528891503278694, 0.029852507768997123, 0.017340556119701693, 0.05685218969093902, 0.06707096778388534, 0.0554633777854698, 0.043879383842327764, 0.15169848634728364, 1.5951813289097376, 7.3987423692430765, 20.86196279525757, 30.238313606807164, 41.18779911313738, 37.87768772670201, 38.17031111036028, 36.14881610870361, 32.265586035592214, 36.541448388780864, 33.43891096115112, 32.819930689675466, 32.06538758959089, 24.3808536529541, 16.662176268441335, 9.525794403893606, 4.7819361346108575, 3.0148292311600278, 1.132722150002207, 0.47120831800358637, 0.16954702431602137, 0.07911292875983886, 0.09990014082619122, 0.10955690871924162, 0.1823194825223514, 0.5237055410231862, 0.7354588412812778, 0.3153344935604504, 0.7665603352444512, 1.0364166434322084, 1.5968018876654761, 1.526623779109546, 0.900709259722914, 2.935389825275966, 2.234704600913184, 3.729198932647705, 2.7735858219010487, 2.266941853931972, 3.9536109822137013, 2.0633696232523238, 2.5188998196806227, 2.1557769732815877, 3.142957487276622, 2.3394391408988406, 1.8798201467309679, 3.043717018195561, 5.051370339734214, 3.2416798813002448, 2.5753404710974013, 3.0181700118950436, 2.311344099896295, 2.8944330172879353, 2.467028477362224, 2.378153417791639, 2.8266594197068895, 3.1964132360049655, 2.1410170452935353, 2.7338538510458807, 0.8986849997724805, 0.5509827573384557, 0.4187900764601571, 0.3180957782481398, 0.0723915169281619, 0.12789254662181648, 0.22855871277196066, 0.14906277135014534, 0.12538985162973404, 0.3023878282734326, 1.6029618999787738, 3.7353289808545793, 5.940863524164472, 11.84450033732823, 19.87630350249154, 16.95517485482352, 19.200285468782695, 29.56798962184361, 18.02950358390808, 19.226900543485367, 31.27636057989938, 32.84623656954084, 34.43751301084246, 28.05819296836853, 18.764671632221766, 6.957265555858612, 1.2592407039233615, 0.05878712050616741, 0.021313064831442068, 0.039072675696973286, 0.02032944350503385, 0.051301193090953996, 0.023037300345354846, 0.05959696562162467, 0.03522945335134864, 0.007064826886302659, 0.020798443517248546, 0.018912730239597813, 0.027459080663642714, 0.03301742919055479, 0.055400793108024766, 0.031752901151776314, 0.0756832802934306, 0.09718779208404676, 0.018721529249367968, 0.007261576596647501, 0.058370900340378284, 0.030609226985169307, 0.019481376511976123, 0.011825675394253006, 0.012240826019218989, 0.0037249664144058314, 0.013012246544738966, 0.03474407011110868, 0.054219667201063464, 0.06997401879302093, 0.026175726670771837, 0.016316938546619246, 0.052370343756462844, 0.04863097119544234, 0.019220739336950437, 0.021926151754866754, 0.030117190709071498, 0.015063351885016476, 0.04238823528534599, 0.030652171466499567, 0.044046238996088505, 0.06120748205908707, 0.06842786140207734, 0.029799096885004213, 0.12771504186093807, 0.10380470952285187, 0.1699140439076083, 0.1691398625927312, 0.17764409125915595, 0.15420678603862012, 0.09895190170833043, 0.1884393934160471, 0.17585943559450762, 0.09857899921813182, 0.13937793246337346, 0.19171076001865522, 0.1117172556530152, 0.0607240122875997, 0.13500471998538288, 0.2078649824751275, 0.17249638534017972, 0.09373231178947858, 0.10734636376478843, 0.14927922402109417, 0.16267613800508635, 0.1134958994973983, 0.10227220425648348, 0.10942781743194376, 0.16162115175809177, 0.0772805449419788, 0.2303746353302683, 0.16465926516268933, 0.11327037481325013, 0.13037359634680407, 0.24232559118952068, 0.13960102120680468, 0.12191181683114596, 0.19990787016493933, 0.19082913946892532, 0.15306639937417849, 0.10954301910740988, 0.1510915910559041, 0.11826026705758912, 0.06563923175313643, 0.1365021789180381, 0.2106571812182665, 0.1575159877538681, 0.1151970885694027, 0.14605688835893357, 0.12562960519322328, 0.13092314185840742, 0.1887216911252056, 1.8323363746915544, 8.605424727712359, 23.886286088398524, 34.5028886113848, 47.05196060453142, 46.146492208753315, 47.359331539699006, 43.16324840273176, 38.97213322775704, 42.359602383204866, 41.50043330873762, 38.961238452366416, 41.82775599615914, 31.139672143118723, 19.25459953716823, 12.108742066792079, 6.465785597051893, 4.578968397208622, 2.4016418031283786, 1.487901359796524, 0.5309995210596493, 0.5444904257144246, 0.3967995164649827, 0.5787048754947526, 0.5961351373365947, 2.192123217242105, 3.224498723234449, 3.354789389031274, 3.0232285176004683, 3.2675217517784665, 5.608389616012573, 4.666329835142408, 6.168993294239044, 5.5019149865422925, 6.289091604096549, 7.382794516427176, 8.048865335328237, 9.289012823786054, 8.86042274747576, 5.631064627851758, 7.166384620325906, 3.3214821134294783, 4.48409378528595, 3.711069345474243, 2.66766248856272, 5.167844729764121, 6.855907840388162, 6.075292059353419, 4.083732068538666, 3.427777175392423, 5.059613943099976, 5.037511723382132, 5.457048296928406, 5.043756416865757, 5.403073821749006, 5.248334399291447, 4.193452375275748, 4.788208186626434, 3.617698150021689, 2.770958751440048, 1.667974891407149, 1.6711574920586176, 1.1019099290881837, 0.6666641299213681, 0.6710562599556786, 0.7749894229429108, 0.5550539674503463, 0.9488491479839597, 2.428933024406433, 4.4232631751469205, 7.015453679221017, 13.282291071755544, 23.86123088427952, 20.113881519862584, 22.957680191312516, 33.15580660956246, 25.02542413984026, 23.8607497215271, 37.34628255026681, 39.987723623003276, 39.367412771497456, 33.694351060049875, 21.93427654675075, 7.655348028455462, 1.5134897295917784, 0.11958191756691251, 0.23579599442226545, 0.09079613470073257, 0.09274809674492904, 0.2126533498189279, 0.14273460448852607, 0.08853801087077175, 0.12352198043039866, 0.13575986160763673, 0.0936241600928562, 0.1294020020536014, 0.12036067220781531, 0.10909983395997967, 0.12515944827880177, 0.13750088747058595, 0.16850047904465879, 0.1770987526646682, 0.15450648138565676, 0.15588221113596643, 0.1926304463829313, 0.10802542804075138, 0.10688230009483439, 0.06779119877942971, 0.11603986977466516, 0.15351743517177446, 0.08648750518581697, 0.08834287098475865, 0.110002719797194, 0.1708393892539399, 0.10814387989895684, 0.16187352607292788, 0.12844316421874932, 0.15400606180940354, 0.15993565720106873, 0.13349804654717445, 0.11894945507603032, 0.13726800068148545, 0.13299351504870824, 0.13539924738662584, 0.08651974916990314, 0.15871577337384224, 0.09708262594150645, 0.11210875678807497], [0.022363172411652546, 0.042474636541945596, 0.042751655248658996, 0.04469345283827611, 0.01478189555928111, 0.02957010149423565, 0.023056553776508996, 0.03057746815362147, 0.04296072885128004, 0.008615642420149274, 0.03763062932661601, 0.09530810759003673, 0.01664239786831396, 0.03587610400947077, 0.04478334515754666, 0.05399812551747475, 0.024840062716975808, 0.012017886553491865, 0.021335271586264883, 0.06367464217224292, 0.041583893088889975, 0.0460623972383993, 0.03129396381388817, 0.028465253101395707, 0.021816276579297016, 0.03989348254565682, 0.01749396779840546, 0.05360824268843446, 0.06578808198017733, 0.059440054398562224, 0.021934319620153735, 0.008383412113679307, 0.017234163525115167, 0.05395360344222613, 0.07148425454007727, 0.054867196562034745, 0.04891315694632275, 0.015469014045915433, 0.0410292348159211, 0.06343052562858377, 0.04092771919178111, 0.02650322499019759, 0.024441526870110204, 0.03406419837847352, 0.018388458461101567, 0.07938881431307111, 0.056845462016229115, 0.04386506336075919, 0.08641976024955511, 1.6901370393378394, 6.195125903402056, 16.45828311783927, 19.987651859010967, 32.678916999271934, 37.03495461600167, 36.31550686700003, 34.512105396815706, 28.48729634284973, 33.361348220280235, 26.28636758668082, 26.62229561805725, 20.069364411490305, 4.000770577362605, 4.894539509500776, 5.772923827171326, 7.221418261528015, 4.426499732903071, 2.218645576919828, 1.4399829996483666, 0.5486151586685861, 0.3891536753092493, 0.21253485046327114, 0.07143081312200852, 0.07336330799651997, 0.24167308477418764, 0.3330702047262873, 0.31644786096044947, 0.5883575518216405, 0.692543238401413, 1.1238354040043694, 0.9026000925472805, 1.347571306994983, 0.9896781742572784, 2.9494670927524567, 0.3694489912262985, 1.0982583250318254, 2.210477100951331, 1.1854159853288104, 1.4902481138706207, 1.7717817383153098, 1.8264716608183724, 1.959689689534051, 0.7551022129399436, 2.3607681563922336, 2.2535476812294553, 1.116297259926796, 2.607785084417888, 2.2101186173302785, 0.6962753438523838, 0.950410647051675, 0.5263336428574154, 2.7013395386082784, 1.4505439358098167, 1.912803245442254, 1.3361035223518098, 2.9841750817639485, 0.14266582817903586, 0.3540705107152462, 0.12920131853648595, 0.27618907551680294, 0.04983852604138, 0.07491454761475325, 0.040237129998526404, 0.26416141805904253, 0.5053430263485227, 2.0887937332902635, 3.251933251108442, 6.760225934641702, 15.2715551171984, 11.155463985034398, 17.714093582970754, 16.077348130089895, 20.16072106361389, 16.286257880074636, 18.516058138438634, 20.767467294420513, 30.66728843961443, 35.054269858769004, 23.666709116527013, 13.559696163449969, 6.1298467091151645, 1.235330975481442, 0.07771507198257105, 0.03701041439282043, 0.0167712991658066, 0.030755288433283567, 0.04790707611079727, 0.10235471411475114, 0.02548243521180536, 0.050096013117581606, 0.024812578656045452, 0.046559865187321386, 0.02650197987843837, 0.06032970201756273, 0.03345776788358178, 0.030994360069079057, 0.035970718932471106, 0.02860965553138937, 0.035803300594644885, 0.018416166438588073, 0.024438812730035613, 0.029065590351819992, 0.034382628077375035, 0.030807260823036944, 0.028133005036839416, 0.019384532601439526, 0.03487681870215705, 0.03350458340719342, 0.03246749352131571, 0.05841567686625889, 0.018274539216820682, 0.04540970083326101, 0.05504976658682738, 0.026594642316922545, 0.012542647725370313, 0.09844422859272786, 0.020595145943973745, 0.040335029031016996, 0.048353623399244886, 0.0373428219131061, 0.018955057254061103, 0.06119750080896275, 0.08711409834878785, 0.03516473128859486, 0.03825575685394662, 0.051262224824833016, 0.013637254480272532, 0.038700712977775505, 0.030657959370208637, 0.04298471167151417, 0.03921161252739174, 0.04960412272651281, 0.046853144985756705, 0.03253574396616646, 0.06463586845036064, 0.021283504453354647, 0.012058597806441997, 0.012520296781856035, 0.037099363548415046, 0.005510047859778362, 0.07203998150570051, 0.049212825151958635, 0.019233519544026682, 0.00857422040176711, 0.037763740933899365, 0.015600609127432108, 0.01641253904173417, 0.02441461617127061, 0.0497098045556673, 0.04630232382831829, 0.07653110301388161, 0.007067529576098812, 0.07490748406520911, 0.048305399915469546, 0.014391150990767139, 0.01792844055619623, 0.01545894967525133, 0.0077729095605068976, 0.07673800869711808, 0.029722120479813645, 0.04699667210557631, 0.037831451943410296, 0.02776781070445265, 0.04901619248890451, 0.017158418660983443, 0.022806357559082762, 0.0213961090360369, 0.14681979242180074, 0.006166255259553769, 0.02601456442581756, 0.05727640978459801, 0.028900390823504755, 0.018760860531723926, 0.04451977162222777, 0.17663686030677386, 2.4199457466602325, 8.690710391317095, 20.613710607801163, 27.469696181161062, 40.23247044427054, 42.23561872754778, 41.54540205001831, 39.31460646220616, 33.19027662277222, 38.747966970716206, 32.270696435655864, 32.458877972194124, 29.149853978838237, 9.751793248312813, 7.856587835720607, 6.984357884952, 6.996804279940469, 4.604346692562103, 2.6002543228013173, 1.459124092544828, 0.45074733878885, 0.31240227233086315, 0.1315536637391363, 0.1365127233522279, 0.06967003510466643, 0.3943524749151298, 0.2996106115835053, 0.4184824015413012, 0.4820393653852599, 0.571895640875612, 0.8174775487610272, 1.1208486557006836, 1.04138916518007, 2.7582411595753262, 2.9003524482250214, 2.117973344666617, 2.0370166259152547, 3.1970694065093994, 2.995804412024362, 2.373832723924092, 3.4277713128498624, 2.564976147242955, 3.2208040186337064, 2.6427909774439673, 3.2442257446902136, 3.11231050321034, 2.7566752093178883, 2.717353182179587, 1.7031840192420142, 2.3827850435461317, 2.342040155615125, 2.1529664269515445, 1.1970815765006202, 2.3042489034788947, 1.2612009644508362, 0.8805327223879951, 0.7761229564036641, 0.4720030725002289, 0.3690081877367837, 0.2723541312984058, 0.09329714692596879, 0.01779718983120152, 0.10046826462660517, 0.0634527001529932, 0.17603311341788086, 0.5916350930929184, 1.789068422147206, 3.724448101861136, 8.718888810702733, 14.928732735770089, 11.517077769551959, 21.375830718449183, 16.21243327004569, 17.764052867889404, 21.927053894315446, 22.49541653905596, 23.42639524596078, 34.892404624394004, 38.99717800957816, 28.393011025020055, 16.897051436560496, 7.849987915584019, 1.6878786576645715, 0.0984172975378377, 0.021457680999966602, 0.06607605224209172, 0.11560104760740485, 0.009532290643879344, 0.034585303094770224, 0.008474512225283044, 0.05676280966560755, 0.06837226902799946, 0.019872684264555573, 0.04474235146439501, 0.07618388307413884, 0.04963504695998771, 0.03950882443626012, 0.037342150163437636, 0.020399430999532342, 0.0630866644371833, 0.0351240972190031, 0.018723907514608333, 0.030039657905165638, 0.02866976355601634, 0.026951823150739074, 0.021664688463455865, 0.030661050097218583, 0.030591201702398912, 0.040893504063465765, 0.04525195840480072, 0.04453281645796128, 0.044035535106169324, 0.04373329186013766, 0.004533297548602734, 0.028000912928421582, 0.04535879035081182, 0.06978691276162863, 0.024898038445306674, 0.007166373892687261, 0.04156691953539848, 0.052644790815455575, 0.05396415466176612, 0.024897042695166807, 0.015020744974857994, 0.06232223367052419, 0.015275940299034119, 0.05137477003570114, 0.08549533092549869, 0.15166814226124967, 0.21301110062216008, 0.10610422398895025, 0.16075819092137472, 0.11441219997193132, 0.10162430509392704, 0.07406308116125208, 0.10633740254810878, 0.07961234410426446, 0.12135266326367855, 0.17095247390014784, 0.14399330051881926, 0.13792285482798303, 0.11433689615556172, 0.13472847480859074, 0.09932926217360155, 0.09625648241490126, 0.11542168366057531, 0.13749620557895728, 0.06905687014971461, 0.09597060882619449, 0.07525211878653083, 0.17820374694253716, 0.18056446526731762, 0.10883606704218046, 0.1224608737975359, 0.13294726610183716, 0.1752845807267087, 0.13257203623652458, 0.09830448430563722, 0.0853630912357143, 0.10038859104471547, 0.16938702575862408, 0.15537567117384501, 0.12517779586570604, 0.17446333622293814, 0.09433466768158333, 0.11021714364843709, 0.15250637728188718, 0.124464126303792, 0.15312423769916805, 0.13699513460908616, 0.10509646377925362, 0.13351555275065558, 0.11265732520925147, 0.13379695479358944, 0.11389259142535073, 0.2948336436280182, 2.66716981785638, 9.44976374081203, 21.950853211539133, 32.0583872795105, 45.5127991267613, 50.512840952192036, 50.3997347014291, 46.944676944187705, 41.64911781038557, 47.54467126301357, 38.51031078611101, 39.56875767026629, 32.96729850769043, 13.168619411332266, 14.86324770109994, 13.281492028917585, 11.959989820207868, 6.849154191357749, 3.591795482805797, 1.9755315823214394, 1.1153908457074846, 0.7156100635017667, 0.5450275540351868, 0.38556634208985735, 0.6110002653939384, 0.8931643845779556, 1.4306306157793318, 2.0258445739746094, 1.6365824959107806, 2.7517502393041338, 5.182680002280644, 3.3775362712996344, 6.683918646403721, 5.705606639385223, 7.658735275268555, 5.854204288550785, 4.510801357882364, 9.502615213394165, 4.538699678012303, 4.743939476353781, 7.249534581388746, 5.3482807619231085, 6.433646270206996, 4.890523450715201, 5.872545795781272, 5.922789522579738, 5.536283816610064, 7.6339336803981235, 6.200715294906071, 5.127906484263284, 5.641136041709355, 5.744229504040309, 5.875507031168256, 6.898205433573041, 6.166802874633244, 5.352831832000187, 6.889594878469195, 2.1130166734967912, 1.5659925980227334, 0.8987766291413988, 0.8920363879629544, 0.39858913900596754, 0.44310472745980534, 0.413001114236457, 0.4583981739623206, 0.8810230046510696, 3.0328856451170783, 5.112005966050284, 9.967218671526227, 18.77912562234061, 16.04823865209307, 26.68748709133693, 25.65543120247977, 29.059468337467738, 28.77914673941476, 29.976981435503276, 30.991623401641846, 41.53183569226946, 45.9376745223999, 32.94573824746268, 20.34960436820984, 9.422842945371356, 2.3440829260008673, 0.2024836162371295, 0.159076455448355, 0.14200360514223576, 0.20790393038519792, 0.11566138294126306, 0.19631087460688182, 0.20657856150397233, 0.1569212789514235, 0.19462470151484013, 0.25561377672212465, 0.11672565154731274, 0.21159715577960014, 0.19702328209366116, 0.1113455541697996, 0.1318847481161356, 0.10766817256808281, 0.13484179015670503, 0.1281545561339174, 0.0960820582030075, 0.10971670371613332, 0.08687176635222775, 0.08644082197653395, 0.08111633054379906, 0.08942274589623724, 0.09029171176786933, 0.13599840737879276, 0.20242922487003462, 0.13064089843205043, 0.10113029088824987, 0.22081850096583366, 0.15007420921964304, 0.16267258248158864, 0.11008240694978408, 0.20659720764628478, 0.09245887797858034, 0.056712119707039425, 0.10761830024421215, 0.09036330399768693, 0.24100079227771076, 0.10385386259960276, 0.17611765888120445, 0.1343087059046541, 0.10179607623389789, 0.15958777229700769], [0.01908954119841967, 0.05207750161311456, 0.05214395733284099, 0.0009895162054038207, 0.06785923548574958, 0.025263470264949968, 0.0472078322033797, 0.018811117924217666, 0.028241699561476707, 0.07969597354531288, 0.021186394217823232, 0.02219069729159985, 0.025110798189416528, 0.038636794979018826, 0.03577805909195116, 0.03375211976734655, 0.06449606309511832, 0.019590953132137656, 0.05625592704330172, 0.025686653896367977, 0.03496020047792366, 0.03398735768028668, 0.04054684730778847, 0.04509694368711539, 0.057713739174817286, 0.06659855134785175, 0.05629758570077164, 0.03302201947995594, 0.031843913053827624, 0.06917250608759266, 0.010700177484458047, 0.059600568642573695, 0.01270612292656941, 0.08027162229908363, 0.04600663183789168, 0.055350540804543664, 0.021414943471817032, 0.0013922584392795606, 0.03979703557810613, 0.05057044480262058, 0.0672921294878636, 0.042838080253984244, 0.031294303081397495, 0.024829440251258866, 0.032684801146388054, 0.017960145104942576, 0.001976895661625479, 0.06305220164358616, 0.03270001729418125, 0.22580524480768613, 2.0140597777707234, 6.008973240852356, 14.061871136937823, 23.259357077734812, 39.85223722457886, 41.75365693228585, 39.42598608561924, 35.589843954358784, 23.31153631210327, 16.912613664354595, 14.564525536128453, 18.796440533229283, 24.33843837465559, 12.738289679799761, 15.264146600450788, 9.73117012637002, 6.724002369812556, 4.287113658019474, 3.105545780488423, 2.5910368859767914, 1.141059771180153, 0.3855919364307608, 0.20745066899274076, 0.08001594351870672, 0.17583629755037172, 0.16225293571395533, 0.1675033446933542, 0.279448432049581, 0.627044035920075, 0.13931115104683808, 0.3979595670742648, 0.6844800167850086, 1.0812572773013795, 1.3093278791223253, 1.0031955689191818, 1.1220760984080178, 1.2207461638110024, 2.625225714274815, 1.7705893622977393, 1.873266475541251, 2.535889685153961, 1.267507866024971, 1.4658993461302348, 1.275102355650493, 2.7527053994791846, 1.6071005293301173, 1.156308461512838, 1.987450782741819, 1.025619468518666, 1.9490847843033927, 1.8095520372901643, 1.0941566079854965, 1.0220497229269572, 1.2730663163321358, 0.29878589298043934, 0.24493776102151188, 0.20091481613261358, 0.14163159153291158, 0.14750235793845995, 0.19669310695358685, 0.1362360439130238, 0.1646216878933566, 0.2965627951281411, 0.8983065400804792, 2.9616983107158115, 2.965642499072211, 4.773488427911486, 11.978445104190282, 22.791684252875193, 32.591453075408936, 27.927321910858154, 16.234832525253296, 18.366902896336146, 21.49373643738883, 24.96914025715419, 27.931527308055333, 32.48087249483381, 26.74483404840742, 18.03564579146249, 8.908015302249364, 1.9639035548482622, 0.2699251930628504, 0.0249695153241711, 0.015108856139704585, 0.11891882600528852, 0.029775341374001334, 0.03582119356308665, 0.07076899042086941, 0.03412325128114649, 0.05052996001073292, 0.025352600928662077, 0.04205527815169521, 0.04761642224288412, 0.08101336964006935, 0.027902857832876698, 0.06897372925387961, 0.021922396063538532, 0.020143821768994843, 0.03436926093750766, 0.04606868386534708, 0.04069575860298105, 0.030505187210759947, 0.011776044798482741, 0.023096762065376555, 0.05730030100260462, 0.08345093884106193, 0.016858019333864962, 0.04743400149579559, 0.06711465186838593, 0.021877253128747855, 0.07018728913473231, 0.011868542692224895, 0.03469152096658945, 0.07030097089175667, 0.07535419080938612, 0.08827171301735298, 0.0644367862758892, 0.05730526109359094, 0.011357252136804163, 0.013123293889553418, 0.04052525293081999, 0.039403369916336875, 0.021894554075385844, 0.08394586906901427, 0.00913256311988724, 0.037766553461551666, 0.09014189123575177, 0.04488000586362822, 0.05336232124162572, 0.028574517595448663, 0.013800264884983855, 0.02140313356981746, 0.010055927992133158, 0.06387606529252869, 0.04828023983697806, 0.02047364067818437, 0.009050576581752725, 0.04653781279921532, 0.03366974900875773, 0.04435356446940984, 0.048482124361076524, 0.018911644583567977, 0.07637134872909103, 0.03253639875245946, 0.021440809226727912, 0.024569900606625845, 0.037234246132097075, 0.045977607502468994, 0.1626560262271336, 0.03630699749503817, 0.029434791433491876, 0.03196273132094315, 0.08303569576569966, 0.05383083949397717, 0.015511230798438191, 0.07172300387173891, 0.04644491117713707, 0.05310347370271172, 0.1075302671108927, 0.028862844088247845, 0.010974401475063391, 0.027062278473749757, 0.06539331030632768, 0.07269279326179198, 0.011860993141973657, 0.06620502139308623, 0.04129226213054998, 0.00872145317095731, 0.017660015495494008, 0.04562821285799146, 0.030536413392318145, 0.05976964599852051, 0.07450055982917547, 0.032965718036783595, 0.02949087235278317, 0.3607141285070351, 2.9423210876328603, 9.153841699872698, 17.877494369234356, 29.27160378864833, 43.75824349267142, 45.53587409428188, 43.450160367148264, 41.95013461794172, 31.74974134990147, 25.865560361317225, 22.836685998099192, 20.402155331202916, 21.418207781655447, 15.761272839137487, 16.813264846801758, 12.157503655978612, 7.885963950838361, 4.793305558817727, 3.310387577329363, 2.381277935845511, 1.0251760865960802, 0.34144281116979464, 0.08625010613884244, 0.05870623913194452, 0.06276919147265808, 0.11934111905949456, 0.1357145897511925, 0.5033327170780727, 0.7360272907785007, 0.5099495191659246, 0.39569947549274986, 1.2258670947381427, 1.3026219989572252, 2.1199813740594045, 1.5529241221291679, 2.091107049158641, 2.1759801634720395, 1.4643460980483463, 2.1697797647544315, 2.356206012623651, 2.453176809208734, 3.1896960650171553, 3.469687406505857, 3.427591745342527, 1.6251769193581171, 2.640476358788354, 1.8738642377512795, 2.2549913866179327, 1.5066825577190943, 1.9794054201671054, 1.0643569784505027, 1.2596568358795983, 0.8620542053665433, 0.748579374381474, 0.29037895266498837, 0.2899529683802809, 0.5119876212307385, 0.20943413541785308, 0.05027093266003898, 0.12582923019570963, 0.03222598933747836, 0.2064911119107689, 0.3209736081106322, 1.053901350923947, 2.768818272011621, 3.346820456641061, 6.31784759249006, 11.909422567912511, 29.85969931738717, 33.225938252040315, 30.706691673823766, 22.98944561822074, 20.578410284859793, 24.747207845960343, 27.94310474395752, 32.06763533183506, 36.9601468358721, 33.363877364567344, 21.520184755325317, 10.716253587177821, 2.998823404312134, 0.3906290547123977, 0.017941551549094062, 0.015806427458301187, 0.05159953136795333, 0.017136554566345046, 0.024760584213903973, 0.03783339594623872, 0.03510536625981331, 0.026776608445548584, 0.03311851733763303, 0.04113428560750825, 0.027398109203204513, 0.06530560965516738, 0.05607920599036983, 0.1052459246878113, 0.02255805445435856, 0.048145649023354053, 0.034465969141040526, 0.004614468572461712, 0.05570547908012356, 0.0606638669435467, 0.032242423455630026, 0.013109120141182627, 0.06521962569760424, 0.009146791151059526, 0.03675101724054132, 0.031047265444483076, 0.010703279237662042, 0.03873881271907261, 0.020816987879308205, 0.03122355562767812, 0.03659451313849006, 0.024517953661935668, 0.07003748217331511, 0.09987778309732676, 0.03255799991477813, 0.09855181710528475, 0.03540485126099416, 0.031797630180205615, 0.046717570296355655, 0.017250509433714405, 0.016690499215785946, 0.013845620710136635, 0.009991771657951176, 0.03521744328151856, 0.10614097344556025, 0.22809804177709989, 0.18176620506814548, 0.12196538038551807, 0.09142744368208305, 0.0937270260016833, 0.13083339881684097, 0.1175822341548545, 0.10396329672741038, 0.18210868883345807, 0.0875530494377017, 0.09563138881432158, 0.09291589166969061, 0.1030294154105442, 0.10525088477879763, 0.10057672844933611, 0.21491342782974243, 0.10101007483899593, 0.10548660784427609, 0.17841588413076742, 0.10089013698909964, 0.13768434976892813, 0.21486651391855308, 0.15669790522328444, 0.14035088382661343, 0.19635312019714288, 0.16671438488577092, 0.10891067196748086, 0.1464569933180298, 0.1981567069888115, 0.16945356290255273, 0.14752441032656602, 0.1700261514633894, 0.18067520218236105, 0.11175973873053278, 0.1737357024103403, 0.1205868957830327, 0.16666764739368642, 0.13111991701381548, 0.17057176147188458, 0.09786505824221031, 0.16620963625609875, 0.07031064680112259, 0.13781760047589028, 0.1459062128726925, 0.21235757640429906, 0.15793791439916405, 0.19141143108052866, 0.13470182195305824, 0.37789376665438923, 3.1780593522957394, 9.148647921425955, 20.66819143295288, 34.55990900312151, 49.08398560115269, 53.37145144598824, 52.22224719183785, 48.21084369931902, 34.74846921648298, 28.06603053637913, 25.696218865258352, 30.07351623262678, 38.235408782958984, 25.282050643648418, 25.896234921046666, 17.380006824220928, 12.256431238991873, 7.214445744241987, 5.126738318375178, 3.7465603096144537, 1.970631582396371, 0.6687002235225269, 0.5178677514195442, 0.3279899316174643, 0.48998457619122093, 0.6892643943428993, 1.1560982785054614, 0.9790388537304742, 2.249945257391248, 2.507869554417474, 2.6105272344180515, 4.381976110594613, 4.837685874530247, 6.702580639294215, 4.928735503128596, 3.7033707414354597, 7.264824960912977, 7.094736533505576, 6.062767497130802, 4.315807546888079, 5.847879690783365, 5.40280110495431, 4.450362452438899, 4.8651816334043225, 7.7069714069366455, 4.307079306670597, 3.970602801867894, 5.76994001013892, 4.195649308817727, 5.476931435721261, 5.5367363180433, 2.8260924901281084, 4.093591128076826, 3.1938947311469486, 1.7995740984167372, 1.1789030262402125, 1.635751751916749, 1.1554189835275923, 0.4444441555866173, 0.6258228900177139, 0.3595370330980846, 0.4291550245668207, 0.6873885978545461, 1.2990077414682932, 3.714278978960855, 4.7367003219468256, 7.627608214105878, 16.339052030018397, 29.055556501661027, 41.430541379111155, 35.969003677368164, 23.898744208472117, 28.31916035924639, 30.403774533952983, 34.82459020614624, 39.3868225642613, 43.18365526199341, 38.12063149043492, 25.78239737238203, 12.10415712424687, 3.73684629372188, 0.3872852069990975, 0.16015143133699894, 0.058497304629002295, 0.1754527081336294, 0.08438903386039392, 0.106422334776393, 0.1596697528979608, 0.0919694642403296, 0.1710955226527793, 0.09671198975827013, 0.11915007073964391, 0.15265840983816556, 0.16106530944151537, 0.1772895838533129, 0.1834510075194495, 0.08427874477846281, 0.2128734937203782, 0.20300825951354845, 0.10339899307915143, 0.11169206843312297, 0.10791646210210663, 0.2208970481795924, 0.08117015872682844, 0.1661153198885066, 0.1391449642500707, 0.13570944645575114, 0.12282644132418291, 0.1538675728120974, 0.09215011061834437, 0.2420324640614646, 0.09070441712226186, 0.09012882943664279, 0.10065900082034723, 0.20218267238565854, 0.15313874477786676, 0.10821583175233432, 0.19121103254812105, 0.2091688010841608, 0.10296325824622597, 0.12021478717880589, 0.10994771096323218, 0.08961564661668879, 0.15927416698208877, 0.14528181137783186, 0.1510843171605042], [0.04174273135140538, 0.007109950737295938, 0.028462287903364216, 0.031016137650502578, 0.04249906040994184, 0.026447980365316783, 0.0062924178200773895, 0.11568923001842839, 0.06884865489389215, 0.004846590313328696, 0.05247995091070022, 0.014459338671128665, 0.02112045757738607, 0.005855060440288591, 0.023512332533885325, 0.048915711630667956, 0.06523567305079528, 0.06327110382595233, 0.05811331487659897, 0.009546439795355712, 0.00989675470295229, 0.00731997810570257, 0.05423518190426486, 0.026057349451418434, 0.01975717385565596, 0.029750540919069732, 0.04032627932195153, 0.0734981871875269, 0.030676771753600666, 0.05250336376151868, 0.01201482381605144, 0.051810002752712796, 0.043260556512645314, 0.010002644333456243, 0.03723035812644022, 0.018662371173767105, 0.04010682413354516, 0.07704421119498354, 0.023049675127757446, 0.026354513862835507, 0.09575243946164846, 0.040082922737513266, 0.06219572760164738, 0.08279487690223114, 0.04147786859955106, 0.011449507454277148, 0.024464206903108528, 0.04984577279537916, 0.021475238093574132, 0.05765658617019653, 0.25327179953455925, 1.7895905141319548, 6.830709763935634, 15.27438303402492, 26.223515919276647, 39.19706726074219, 39.241570472717285, 32.58119058609009, 24.425028562545776, 21.912361928394862, 17.35953048297337, 23.333819184984478, 16.47239317212786, 19.818072387150355, 20.557805401938303, 16.081928730010986, 14.622739280973162, 14.764211552483694, 8.707997509411403, 5.420152928147997, 3.468478854213442, 1.843714918409075, 0.9472297834498542, 0.3483276074486119, 0.12735966593027115, 0.24418298580816813, 0.06296988856047392, 0.23038967166628155, 0.1153614976044212, 0.36089247465133667, 0.6969267917530877, 0.3418544376535075, 1.2079480162688663, 1.820695970739637, 1.0522742782320296, 2.1139705308846066, 1.2741162542785918, 0.9472522565296718, 1.272570280092103, 1.339763160262789, 1.4518664819853646, 3.512145893914359, 3.247464039496013, 3.3242294745785848, 0.9731464556285313, 2.0458399696009497, 1.2378346068518502, 0.6400814620511872, 1.3037782226290022, 0.8728969778333391, 0.7818528317979404, 0.82810954110963, 0.4633831264717238, 0.2154096540595804, 0.2800167186983994, 0.28665792090552195, 0.10941789046462093, 0.08934153882520539, 0.11307749444884913, 0.04365460893937519, 0.2642863227852753, 0.4468695654400757, 1.0629128387996127, 1.850681790283748, 5.201098373958042, 8.007032837186541, 9.173733523913793, 12.182805521147591, 7.215313400541033, 26.18981715611049, 42.5287458556039, 13.948182106018066, 25.669602053506033, 26.32925534248352, 32.439937182835166, 31.509385790143693, 29.367714745657786, 20.793021031788417, 10.305814811161586, 3.1464287638664246, 0.5648631953767368, 0.037176794572068114, 0.062358162099761624, 0.022234632434057336, 0.03838398640177079, 0.0020983653043263723, 0.031517018630568466, 0.02950496891779559, 0.03278704619567309, 0.040908509865403175, 0.08499255683273077, 0.06678157938378197, 0.012029786361381412, 0.06899519131651946, 0.038919408206960986, 0.030044784237231528, 0.050348523139421425, 0.03284001263922878, 0.0121412425235446, 0.08835557316030775, 0.016014344158715436, 0.02187675779818424, 0.0777984910777637, 0.027372674318030477, 0.044456365917410166, 0.03778861602768302, 0.027340386229168092, 0.03454694551016603, 0.022514287249318192, 0.024917291876460825, 0.08418882531779152, 0.037169669954372306, 0.021712721957425987, 0.01168338575267366, 0.07890775334089994, 0.02284403151965567, 0.038217236420937946, 0.055796867569110224, 0.04819772319336023, 0.05681063620639699, 0.07365154288709164, 0.02551190398766526, 0.022616493282839656, 0.0213318229320326, 0.017031042370945215, 0.027723806012155752, 0.015620391815900803, 0.08587510697543621, 0.03559008453573499, 0.04748810787818261, 0.0621903943164008, 0.02316794547784541, 0.006036028274268444, 0.040150403045117855, 0.022561922103964856, 0.061584286125642915, 0.03166767376075898, 0.025978249231619493, 0.028466789983212948, 0.07130674977919885, 0.01249453195902918, 0.008334411707307612, 0.02422053988889924, 0.033368767837860754, 0.04843962432018348, 0.07154892571270466, 0.024715353069560866, 0.09257148086492505, 0.03742315028128879, 0.03725631209090352, 0.013023703608528843, 0.048172535973467996, 0.03263001283630729, 0.029784230182745626, 0.047261996261243305, 0.04494047011913998, 0.025609952297859957, 0.058292441336171966, 0.03353297670504876, 0.024746760759236555, 0.021779796840356927, 0.029474896245769093, 0.0329988000116178, 0.0390330594299095, 0.05021021395389523, 0.006308841760203774, 0.029740132191883664, 0.010030590646368052, 0.07849297845470053, 0.06127867395324366, 0.03690057314400162, 0.010721932165324688, 0.009247594313429934, 0.03795893171003886, 0.056649836977677684, 0.054679052372063906, 0.3898944727012089, 2.4156504571437836, 9.865861824580602, 18.418976170676096, 35.25454126085554, 44.478677885872976, 45.05697992869786, 37.11483458110264, 27.18696529524667, 22.093492780412944, 20.716929571969168, 25.703563111168997, 22.284959077835083, 24.94946469579424, 24.680274111883982, 22.735037326812744, 20.955480337142944, 14.899114302226476, 9.726504411016192, 6.833581107003348, 3.2915659930024828, 1.4826835883515221, 0.8591440500957626, 0.2361882690872465, 0.18388936828289712, 0.049966870940157344, 0.07543791524533715, 0.21784342346446856, 0.154812093558056, 0.06367440468498639, 0.4331139235624245, 0.16259244749588625, 1.0266424821955817, 0.6008873251932008, 0.6131767886025565, 1.492068541901452, 2.3151434617383138, 1.239344862954957, 1.1173246162278312, 1.1620769862617766, 1.27202365228108, 1.9441207306725639, 1.8658731579780579, 2.6809463586126054, 1.6187009811401367, 1.6161749852555138, 1.2549612649849482, 0.9997166927371706, 0.6089132002421788, 1.1029618212154932, 0.8840717439140592, 1.313312019620623, 0.40804311313799446, 0.9598597628729684, 0.16164065285452775, 0.10196045134216547, 0.06333760704313006, 0.06785693525203637, 0.10550277054842029, 0.10446805892778294, 0.18434727085488184, 0.6477523818612099, 1.1120794862508774, 1.9431492856570651, 6.199964455195835, 8.86027683530535, 10.172071542058672, 17.933404786246165, 13.663566521235875, 32.91450262069702, 45.58168704169137, 16.23257088661194, 27.695411886487687, 29.505313396453857, 35.0843312399728, 36.41626269476754, 33.63854660306658, 24.65102914401463, 12.671985626220703, 4.202960550785065, 0.6314583676201957, 0.03566876406382237, 0.02770919376052916, 0.0066282595757261985, 0.04634808762265103, 0.0304598271447633, 0.02952669221641762, 0.03601933257388217, 0.007800536113791168, 0.02148408449387976, 0.022401911672204733, 0.09226261850978647, 0.018362984560163956, 0.011591342477394002, 0.12255766003259591, 0.011282955944937254, 0.007725507104104119, 0.04823198921180197, 0.04063073119946888, 0.06292665230908565, 0.03592730626197798, 0.009598766719656331, 0.035546312241681984, 0.039354413614741394, 0.0916135251255972, 0.02770717172617359, 0.03648559469729662, 0.06475409639200994, 0.06009469819920404, 0.037253452065799914, 0.05520123256636517, 0.08807028311171702, 0.11407947354018688, 0.029647376454834427, 0.03879793008257236, 0.04975028595487986, 0.04694592447153159, 0.024669317861220667, 0.028066174426515187, 0.05571843231362956, 0.04511211233745728, 0.05400471069983073, 0.004462578508537263, 0.016042443990175213, 0.042366352530994585, 0.03599939042968409, 0.13999311945268086, 0.2360610030591488, 0.12463096449417727, 0.13350332554961952, 0.24423889709370478, 0.09162484987505845, 0.04454519632937653, 0.14668242979262555, 0.14808185398578644, 0.19982880726456642, 0.19291933945247106, 0.15824957910392964, 0.11383110258196082, 0.08226663739021335, 0.09521805242236171, 0.1186920731727566, 0.09613946905093533, 0.11095030073608671, 0.14539402749921593, 0.13881835820419447, 0.11769561735647065, 0.1849690532045705, 0.16900891890483244, 0.081519590690732, 0.10395889303513936, 0.1320085400449378, 0.12836001653756413, 0.21366788180811064, 0.14107684844306537, 0.18310526678604738, 0.14827987764562878, 0.13443751899259432, 0.09316294626998049, 0.09813307278922626, 0.09997688313680035, 0.1304664063666548, 0.19368924599673065, 0.15398377871939115, 0.13740509189665318, 0.08176391079489674, 0.23785773664712906, 0.1362705406333719, 0.21791210477905615, 0.08126469901097672, 0.11773603090218135, 0.11324410193732806, 0.09807122432227645, 0.1734239834227732, 0.17334270849823952, 0.12855308689177036, 0.4300551691225597, 2.732671788760594, 9.74706847327096, 20.688994339534215, 37.47192335128784, 48.120079381125315, 51.451789242880686, 43.70252936226981, 34.55759872709002, 32.349315302712576, 27.734521559306554, 32.403139523097444, 25.785808937890188, 32.204212597438264, 33.588978154318674, 29.364393506731304, 24.516642298017228, 21.35573479107448, 13.459768039839608, 8.528580256870814, 4.911177405289241, 2.65978279709816, 1.5568480087178094, 0.619265147617885, 0.5557015069893428, 0.48689713329076767, 0.45851146216903416, 1.2152728289365768, 1.215098146881376, 1.2134554407426288, 1.5935678269181932, 2.3077712059020996, 2.9868473155157904, 3.7097517933164323, 4.6935268214770725, 5.19587767124176, 6.093779913016728, 4.414084604808262, 4.570678327764783, 6.887298498834882, 6.004421302250453, 7.447054931095668, 7.27027929680688, 7.345112698418753, 2.709293706076486, 5.210662569318499, 6.128667252404349, 3.810093334742955, 3.9368354252406528, 4.0835040807724, 3.5368925545896803, 3.986980140209198, 2.671378254890442, 1.8107677549123764, 0.7874183931521007, 0.6691958255001477, 0.4474969117769173, 0.21128003565328463, 0.3705134769635541, 0.2747042237647942, 0.6397371462413243, 0.8265045072351183, 1.5916842137064253, 2.704376118523734, 7.982095752443586, 12.076856783458165, 15.034856046949114, 19.233555180685862, 14.541148321969168, 34.007902417864116, 49.70451532091413, 21.884343317576818, 34.145268304007395, 36.75102342878069, 41.69687277930123, 42.938682624271934, 37.827393191201345, 27.295530898230417, 14.746837581907, 4.813168287277222, 1.185172472681318, 0.06814175711146422, 0.1847461408802441, 0.09616420843771525, 0.15157085391027586, 0.13066649277295384, 0.22669914684125356, 0.10326990857720375, 0.1662826466241053, 0.15708279742726258, 0.1405853855290583, 0.17863465739148005, 0.10909196973911353, 0.16820139437913895, 0.1423062046191522, 0.09108064443405185, 0.10123544346008982, 0.16316834730761393, 0.07919664641043969, 0.22592545407158987, 0.1442867126315832, 0.10755957982369832, 0.16428152471780777, 0.11940046373222556, 0.16844874753483705, 0.1627158187329769, 0.1442881646965231, 0.21700349210628442, 0.257451303835426, 0.1853933140103306, 0.261833554399865, 0.18454921644713196, 0.15934972864176544, 0.10122671749975, 0.1619627805692809, 0.10290252936205693, 0.07878761871584825, 0.11515164029385362, 0.12427903552140508, 0.16575549276811735, 0.12703152639525278, 0.18564310989209584, 0.07093947234430484, 0.16905731202236243, 0.07562515698373318, 0.08265097998082638], [0.04681852952178035, 0.043925724391426356, 0.030786623180444752, 0.03430004697293043, 0.028038853213989308, 0.010757224467982138, 0.054633047697799544, 0.043678055716944594, 0.016963448408725004, 0.015100270975381136, 0.012670047764134194, 0.013131231901102831, 0.08761381224862166, 0.01521624278809343, 0.03992649666698916, 0.05009803854461227, 0.025237361933769922, 0.04765586887619325, 0.03128714792962585, 0.005925438940591578, 0.015320219798013568, 0.008435654221102595, 0.049788063392043114, 0.02708320110104978, 0.07661653057272945, 0.020017899240234067, 0.030902896941240345, 0.030939008574932814, 0.034745515390698395, 0.028680043361548866, 0.037918253535670896, 0.029143007804772685, 0.08973269390740565, 0.0268672675093902, 0.11191205627151898, 0.060687459606145105, 0.04571278885539089, 0.030620378708200793, 0.00774637290409633, 0.046250351438564916, 0.04297357351918306, 0.011433974939531513, 0.01860383226137076, 0.02098364965058863, 0.041098109512989006, 0.026499250471325855, 0.03719982744327613, 0.03525665242757116, 0.03996861333559666, 0.050286138629806895, 0.06243759819439479, 0.10126433548118387, 1.8599895536899567, 7.003434598445892, 14.478819506508962, 27.28791046142578, 36.78872088023594, 40.253134386880056, 39.86812775475638, 35.924267700740266, 26.9121310370309, 22.851426601409912, 21.999447175434657, 20.367075613566808, 15.22201098714556, 13.275780609675817, 12.88165099280221, 14.428636142185756, 13.949205228260585, 8.531066843441554, 6.871907804693494, 4.4507915037018915, 3.1976217882973805, 1.5300003864935465, 0.5654599804963384, 0.2734564521483013, 0.20163187836962088, 0.19647882559469768, 0.07448220545692102, 0.3452837536377566, 0.11788260803690978, 0.4099223294428417, 0.22095848274018082, 0.171726220952613, 0.3753989833806242, 0.692810092653547, 0.5596577461276735, 0.09835837355681828, 0.15060946478375367, 0.4583800977894238, 0.5653856673410961, 1.234764154468264, 1.632399246096611, 2.7413264214992523, 0.9020787605217525, 2.189729779958725, 0.23551038546221598, 0.6522724564586366, 0.34628182436738697, 0.8243112649236406, 0.3489228997911726, 0.5894375081573213, 0.12227609514125756, 0.3312643787690571, 0.09626270458102226, 0.18376963399350643, 0.07557071133383683, 0.14655463450721332, 0.12616393794970854, 0.2931590734847954, 0.4396257698535919, 1.60124471783638, 2.5107647819178442, 5.6665065203394205, 10.958096061434064, 10.790922403335571, 10.601920979363577, 9.352449008396693, 14.39427295752934, 23.357264144080027, 48.1815744127546, 25.209693840571813, 22.277793748038157, 32.57963766370501, 32.04945189612252, 29.353516101837158, 20.970672573362076, 10.946584633418492, 4.67560350894928, 0.6614340905632291, 0.03186482550310237, 0.043348973018250296, 0.044836274281676324, 0.009832885897984462, 0.07127641926386527, 0.013835930381901562, 0.005762598593719304, 0.02247481856362096, 0.028213084043402756, 0.018122247120897685, 0.0522741783809449, 0.11895883242998805, 0.03199742481644664, 0.06284376247120754, 0.061720624166939936, 0.06597619902874742, 0.022528736652540307, 0.0553188430411475, 0.02780645666643977, 0.007202426154565598, 0.03954215068370104, 0.01572975130485637, 0.07802060951611825, 0.04162370613110917, 0.021360487643895403, 0.07592271494546107, 0.046942338413958035, 0.05203962578837361, 0.023158742846654992, 0.022580052559663142, 0.04664525203406811, 0.041196208713310103, 0.030549465013401847, 0.04962213443858283, 0.03381558654031583, 0.027729329287207553, 0.12360637661601816, 0.01914956101349422, 0.05671272021053093, 0.05677801563537546, 0.051871807114886384, 0.04143802163058093, 0.02563629811629653, 0.012158400977828672, 0.02526906817885382, 0.10613806931568043, 0.015481460074494992, 0.023664346430450678, 0.03924386668950319, 0.07103280483611993, 0.012165431448790644, 0.030248127611620084, 0.04972280189394951, 0.11606365921241896, 0.026790128255795156, 0.026021302278552736, 0.0787695154015507, 0.05511604588744896, 0.03706763185826795, 0.03336240317938583, 0.05207730144528406, 0.028732643396194493, 0.002830352767237595, 0.0768667675022568, 0.050502228284520764, 0.052412216152463637, 0.03908324048721364, 0.025517264414312582, 0.03162715504212039, 0.05016031448862382, 0.003538988235439839, 0.031539997218975, 0.0304060091397592, 0.04062115028500557, 0.04654653197420495, 0.013351551373489201, 0.03291790167401944, 0.07843297560300146, 0.04882474722606795, 0.03330821537279657, 0.028537177813372443, 0.06431562706295933, 0.02645891665347985, 0.015019983319299561, 0.032498757022299936, 0.05814597276704652, 0.04489886913714664, 0.06370041971760136, 0.026619191713897244, 0.04439813404210976, 0.061335623397358825, 0.04245848062315157, 0.032033835005547316, 0.024768911534920335, 0.054247429461351464, 0.08163548447191715, 0.022320487469966923, 0.25384185037442614, 3.0904966337340216, 10.043528131076268, 18.50160935946873, 34.61163139343262, 42.54709257398333, 44.5887964112418, 42.2547401700701, 36.272942202431814, 27.562892368861608, 25.339939560209, 17.368799379893712, 22.976964916501725, 22.915900673185075, 21.679069212504796, 18.683124099458965, 22.418710163661412, 16.70049384662083, 11.80395325592586, 8.648722427231924, 5.051308240209307, 2.880114951304027, 1.1595600013222014, 0.27035305010420935, 0.20105437721524919, 0.1418708022683859, 0.20679159435842717, 0.05190057360700198, 0.1841727245066847, 0.1300384271889925, 0.07478640627648149, 0.27808940783143044, 0.3235980729971613, 0.634515140737806, 0.2960676002715315, 1.567057192325592, 0.8658180119735854, 1.0323558556182044, 1.0813630201986857, 1.6499847024679184, 1.6716842523642947, 1.3213482626846857, 1.9696475437709262, 1.5074112500463213, 1.7857630337987627, 0.9515220331294196, 0.7838969592537198, 0.7027821689844131, 0.3900562897324562, 0.25230469714318005, 0.49156046020133154, 0.2810518374400479, 0.11871025791125638, 0.11152901646814176, 0.062130432176802836, 0.03314474271610379, 0.0896116771868297, 0.14568338197256836, 0.3452207584466253, 0.5661115369626454, 2.0599293964249745, 3.7174260786601474, 6.939404342855726, 11.314076593944005, 13.515452640397207, 15.441488947187151, 13.482984576906476, 14.590754985809326, 24.42377962384905, 52.40494659968785, 23.339638301304408, 25.536943571908132, 36.11988033567156, 34.555392674037385, 34.07476840700422, 25.406902824129375, 14.370612604277474, 5.806580032621111, 1.0811633680547987, 0.060446932512734614, 0.01907339206497584, 0.005520668205073369, 0.04429189242156489, 0.009094072372785636, 0.019842039926775863, 0.009190424345433712, 0.007994630207706774, 0.07043920204575572, 0.028333948093599508, 0.005728407638213996, 0.03115522036595004, 0.03681878253285374, 0.04602931865624019, 0.014565629485462393, 0.0335404405902539, 0.025184341207412735, 0.05299386654847434, 0.02878451400569507, 0.04399646166712046, 0.011420565391225474, 0.12641654296645097, 0.01872542404037501, 0.04079425135361297, 0.015206185202779514, 0.06828690253730331, 0.0594651194821511, 0.02609588175878993, 0.06341870554855891, 0.04677325087998595, 0.035280217948768816, 0.030725076661578248, 0.05991903226822615, 0.05919224662440164, 0.041132022693221054, 0.051714034152350256, 0.09572106400238616, 0.03512508109478014, 0.09134527987667493, 0.030169977340847254, 0.03180426964536309, 0.05715893501681941, 0.0322640755080751, 0.04521082900464535, 0.054256766103208065, 0.03588615989844714, 0.12317755605493273, 0.10372466274670192, 0.1705818987850632, 0.14849058991031988, 0.08934527076780796, 0.18279482344431536, 0.13088255189359188, 0.12737436299877508, 0.09008849052978413, 0.15470659493335656, 0.19364257635814802, 0.1353039267872061, 0.18634243522371563, 0.09088122977742127, 0.11590026797992842, 0.11012547356741768, 0.08554529824427196, 0.22857594756143435, 0.13926788765404904, 0.11101214241768632, 0.1880882786852973, 0.10274693449693066, 0.09068734518119267, 0.08124584930815867, 0.1083892449470503, 0.12096177281013556, 0.141058568709663, 0.1793681808880397, 0.15861024760774203, 0.10098811744579247, 0.09789033367165498, 0.1362002986882414, 0.13389266894332, 0.07037896170680012, 0.304238708955901, 0.13145670108497143, 0.12130649574100971, 0.1206253958599908, 0.08688964574996914, 0.16910685864942415, 0.19370076752134732, 0.1370475310832262, 0.07577693848205463, 0.12375071458518505, 0.13601885842425482, 0.1623935145991189, 0.1606825885495969, 0.27389684851680485, 0.10356403315173728, 0.18234761458422455, 0.12435074310217585, 0.257603757083416, 3.0954745837620328, 10.063920225415911, 21.473411219460623, 37.941024030957905, 47.65108987263271, 53.16599668775286, 50.95785570144653, 46.80015441349575, 35.76661307471139, 32.32748753683907, 30.15553276879447, 29.58800390788487, 24.035417011805944, 23.201171125684464, 22.763521466936382, 23.82680603436061, 21.44698027202061, 14.27566373348236, 10.814962301935468, 7.18955078295299, 4.213957377842494, 2.58023829971041, 0.9581395408936909, 0.5496697106531688, 0.35320619280849186, 0.5117698929139546, 0.400686680738415, 0.6021472832986287, 0.3893732763826847, 0.9171254102672849, 1.6624766950096403, 1.6066041673932756, 2.3853969148227145, 2.846034688608987, 3.379196456500462, 2.2700513899326324, 2.050835507256644, 2.834064679486411, 4.665412672928401, 5.570904518876757, 6.536850903715406, 6.354212726865496, 2.881764279944556, 5.304755074637277, 2.7660802475043704, 3.4743081757000516, 3.5796061711651936, 3.3205063257898604, 1.7725840381213596, 1.6953208297491074, 0.9653373318059104, 1.102910469685282, 0.4769948103598186, 0.5240894289953368, 0.3494038182709898, 0.654461573277201, 0.31957889295050074, 0.667944824056966, 0.779627399785178, 2.4796240414891924, 4.448651892798288, 8.65030574798584, 15.371015105928693, 16.68673815046038, 18.069811820983887, 16.12312981060573, 22.5110638822828, 33.7282270022801, 57.37659461157662, 35.84370681217739, 32.32009465353829, 45.3858277457101, 42.031438963753835, 38.17056124550955, 29.251252514975413, 15.485293865203857, 6.601428764207022, 1.4083132190363747, 0.24283840081521443, 0.10182279015758208, 0.10449303580181939, 0.1812309766454356, 0.12403970264962741, 0.0710574153012463, 0.10173450596630573, 0.11877435232911791, 0.16528482016708168, 0.09331989141979388, 0.11586491630545684, 0.2300089049552168, 0.11067535156118018, 0.1442437477942024, 0.2472558266350201, 0.1345590174730335, 0.11211288906633854, 0.19485833469246114, 0.15685654671064445, 0.15909157320857048, 0.1041063658360924, 0.2464922033250332, 0.13627339048045023, 0.23436336272529193, 0.1065159658236163, 0.14281996419387205, 0.12984881736338139, 0.11888966257018702, 0.14358214900961944, 0.210554410304342, 0.16324589028954506, 0.07874482351222209, 0.12796194718352386, 0.08566001815987484, 0.1178857157272952, 0.10555522130536181, 0.17502475609736784, 0.0937853664425867, 0.15757028412606033, 0.12727571757776396, 0.10980493362460818, 0.11353913574878659, 0.07116447455648865, 0.14356732980481215, 0.1711766482996089, 0.13492450357547828], [0.06371414648102862, 0.03463362157344818, 0.018919722542964985, 0.01723875381451632, 0.04809715073289616, 0.03337555658072233, 0.026142312213778496, 0.03193059590245996, 0.02008665180099862, 0.02886390599555203, 0.021891436206975153, 0.029061950011444942, 0.015421048405447176, 0.025318820062758665, 0.059238970545785766, 0.011446407397410699, 0.09646365951214518, 0.011649629483664674, 0.02777510665224067, 0.04445253897990499, 0.006737209399164255, 0.01864069028358374, 0.05444219276042921, 0.03786264080554247, 0.02201726034815822, 0.07983558212539979, 0.04680700121181352, 0.016177681108404483, 0.019900424472455467, 0.05114487558603287, 0.015395067299583128, 0.0411465128085443, 0.029867598387811865, 0.062111799605190754, 0.033625868149101734, 0.023817330632092695, 0.034966626204550266, 0.04484684246459177, 0.0128882781968319, 0.018646347569301724, 0.055278049515826364, 0.022269722872546742, 0.028839193750172853, 0.02946592601282256, 0.0401630814719413, 0.08782873143042837, 0.024780051383588995, 0.06252462709588663, 0.001805948093533516, 0.008509630653341966, 0.02941948707614626, 0.032317259082836766, 0.17847233824431896, 1.2556320918457848, 7.219371148518153, 17.68518386568342, 29.447570392063685, 37.900755746024, 41.34586368288313, 39.575539112091064, 32.46230690819876, 38.75633955001831, 30.347921439579554, 20.90731542451041, 17.690959555762156, 17.84387377330235, 18.255564962114605, 14.325928739139012, 17.988245180674962, 12.428047401564461, 12.410738570349556, 9.759590864181519, 5.5050525324685236, 3.8154317225728716, 1.7606664661850249, 1.0387377760240009, 0.6937025561928749, 0.3420189145420279, 0.15586695766874722, 0.1948313425694193, 0.16209502704441547, 0.04697648908144661, 0.13822120667568275, 0.32021079904266764, 0.07728853808449847, 0.15009603090584278, 1.0749699175357819, 0.5014846591012818, 0.8585641469274248, 0.6502084072147096, 0.5526308374745506, 0.8372492449624198, 0.5839113018342427, 1.2672582737037112, 1.4313406348228455, 0.8079299639378275, 0.5939459119524274, 0.16459834628871509, 0.45049940209303585, 0.013497460999393036, 0.23870004287787847, 0.17615562970084803, 0.16145074447350843, 0.04471168846690229, 0.11879297133002963, 0.10539868327655963, 0.1661975040499653, 0.1547469813376665, 0.4802257769874164, 0.9845211995499474, 1.3008356605257307, 2.329157761165074, 4.241938207830701, 6.865123323031834, 9.853626915386744, 19.337152821677073, 19.701269694737025, 19.564546516963414, 17.43539960043771, 18.860141617911204, 32.64512096132551, 25.738229410988943, 31.814168521336146, 36.73821095057896, 27.661390032087052, 19.59388702256339, 11.582713059016637, 3.8719101548194885, 0.7997650706342289, 0.20544485162411416, 0.022251538134046962, 0.07477943772183997, 0.02969196977626, 0.029575597627886703, 0.0059794024065403, 0.018500342100326504, 0.055835723876953125, 0.04976664204150438, 0.08081697446427175, 0.00762331294494548, 0.053917542698660066, 0.07009971061987536, 0.04357355793139764, 0.02928896407995905, 0.05225704537172403, 0.05448974449453609, 0.020290975658489124, 0.04103573518139975, 0.03671039334897484, 0.039269311752702506, 0.024166355474985073, 0.012748975805672151, 0.04096038726025394, 0.0625140012374946, 0.08151030833167688, 0.05101252054529531, 0.0218500201257744, 0.026532145849029933, 0.03533391721014466, 0.05935503396072558, 0.029274121126426116, 0.008134582296146877, 0.06459099692957741, 0.03468399262055755, 0.056110890183065615, 0.02321540391338723, 0.012701653925302838, 0.027025815698185136, 0.032074336760810444, 0.03791002290589469, 0.05316882001768265, 0.00817057179353599, 0.05300987318956426, 0.084083869521107, 0.052109212947211096, 0.01973198663576373, 0.03234954038634896, 0.06402621152145521, 0.053710616659373045, 0.04981805124719228, 0.028366963911269392, 0.009190552418918481, 0.04209527100569435, 0.01454036932305566, 0.05772563389369419, 0.06538182270846196, 0.03408923971333674, 0.013590676443917411, 0.0355546378663608, 0.039530941285192966, 0.033901041240564415, 0.03164933295920491, 0.0579823711887002, 0.042285745963454247, 0.07670308449970824, 0.07853003325206892, 0.0017057482972242205, 0.028636701937232698, 0.017039873504212925, 0.054366373257445436, 0.12835338046508177, 0.08286554632442338, 0.027411997118698697, 0.013363476626441946, 0.02708802548503237, 0.05592034397912877, 0.04933842198391046, 0.022888502704777887, 0.04956493054383567, 0.017700446004580175, 0.0145335704021688, 0.011001113702410033, 0.05708939196275813, 0.053365968367350955, 0.021577250744615282, 0.01198198102481131, 0.051571606259260855, 0.012186610223060208, 0.03262548361505781, 0.06760918176067726, 0.05276694408218775, 0.020277627178334763, 0.042081571383667846, 0.03347198319222246, 0.03143030524786029, 0.0190544846866812, 0.051369270509374995, 0.027635499768491303, 0.3713764378002712, 2.019168875047139, 9.845949155943734, 22.44475027493068, 35.31517471585955, 43.583642210279194, 46.2820793560573, 42.955226285117014, 33.497223717825754, 37.229994024549214, 32.42606857844761, 17.51234221458435, 14.998756681169782, 15.69543170928955, 19.98001057761056, 20.96714288847787, 22.829918452671595, 15.854102509362356, 15.856925215039935, 14.104102287973676, 7.044881037303379, 4.199886841433389, 1.817009408559118, 1.203301951289177, 0.651165250156607, 0.29082928278616493, 0.13623525681240217, 0.08027292508631945, 0.07695782011640923, 0.12557119689881802, 0.3388027399778366, 0.16091215051710606, 0.16024076725755418, 0.23643840423652104, 0.4299679366605622, 0.8584635066134589, 1.0501968754189355, 0.8810171421085085, 0.8624695230807576, 0.8941130308168275, 0.8254301963107926, 0.676320877458368, 0.6768723364387239, 0.5230917653867176, 0.2887995945555823, 0.4071959214551108, 0.5321406541126115, 0.17089720043752873, 0.27640946369085995, 0.22209684737026691, 0.13199028745293617, 0.06304566056600638, 0.052497765847614834, 0.0925361563318542, 0.15203414405030863, 0.10112277950559344, 0.5551952655826295, 1.2343192526272364, 1.9269387040819441, 3.419730944292886, 6.024509412901742, 11.21901307787214, 17.495631796973093, 22.351185832704815, 21.29862059865679, 18.830144507544382, 16.540645326886857, 21.516182592936925, 37.972158908843994, 27.974729469844274, 33.88034391403198, 40.219585009983604, 32.83106517791748, 24.63337550844465, 14.862836020333425, 5.4200252549988885, 1.4694171973637171, 0.18420784547924995, 0.019861266216529266, 0.10062510121081557, 0.02086207822763494, 0.06689004999186311, 0.06358489234532629, 0.02106407131733639, 0.0649146174213716, 0.04157774556162102, 0.04123223213745015, 0.0720870786213449, 0.009881501235733075, 0.053292890145842514, 0.02597444095382733, 0.09699367000056164, 0.04534771326663239, 0.07270677108317614, 0.004836678613043789, 0.039158208428749015, 0.01215042734319078, 0.01090676340806697, 0.022991707881114314, 0.054574476554989815, 0.03383957953857524, 0.08020137356860296, 0.020846178455810462, 0.05545216499428664, 0.030975303413080316, 0.013537831288496298, 0.0542843112322901, 0.03607938292303255, 0.045214194538337846, 0.029892470088920424, 0.06465013125645262, 0.015241506343175257, 0.05197282401578767, 0.11440306689058032, 0.027471847300018584, 0.030811990212116922, 0.07491887666817222, 0.07603051380387374, 0.0444588086434773, 0.047839745080896785, 0.04311157736395087, 0.035828311395432265, 0.05556196553100433, 0.05072732549160719, 0.1318721952182906, 0.08951460596706186, 0.15122967293219908, 0.11358849238604307, 0.24716218880244664, 0.09418859944811889, 0.09919446440679686, 0.08583911069269691, 0.18428636555160793, 0.12452104182115623, 0.10131071334970848, 0.14258166269532271, 0.10135832615196705, 0.08842728074107851, 0.1628570897238595, 0.10402476521474974, 0.14012251608073711, 0.11352648785603897, 0.1977426242083311, 0.19698195931102547, 0.10295357555150986, 0.11834721453487873, 0.1357327609189919, 0.12583240573959692, 0.15545998593526228, 0.16437148489058018, 0.1155117116868496, 0.12389445544353553, 0.09310674999973603, 0.10308221222034522, 0.15355267828064306, 0.14592522542391503, 0.10596981298710619, 0.10126403692577567, 0.09947370870837144, 0.12072165283773627, 0.15079888461955956, 0.15649890447301523, 0.08719847417835679, 0.0961051487496921, 0.12281637186450617, 0.08343947838459696, 0.12199457096202032, 0.10339575646711247, 0.0598258761955159, 0.2396021687558719, 0.1573803350329399, 0.0787862820018615, 0.13151736211563858, 0.0882801404222846, 0.1766483818313905, 0.09149093420377799, 0.43901858957750456, 2.3355772452695027, 10.233265195574079, 24.211691073008947, 39.21849203109741, 49.16859034129551, 54.4827880178179, 50.80114950452532, 42.641862528664724, 48.48399475642613, 40.41354744774954, 29.19982542310442, 24.995185579572404, 28.157366343906947, 29.841456821986608, 25.37557339668274, 29.47571407045637, 20.72892737388611, 19.385871853147233, 15.975508383342198, 9.147545763424464, 5.963254528386252, 3.032982268503734, 1.560509817940848, 1.134425978575434, 0.6017454277191843, 0.4638782941869327, 0.43029048506702694, 0.6887510418891907, 0.4073271501277174, 1.0005782693624496, 0.8160268408911568, 0.9495045585291726, 1.247769988008908, 2.9256942655358995, 1.6911428996494837, 3.1956836751529147, 3.2294923067092896, 2.040336562054498, 2.215597923312868, 2.233246999127524, 3.8576937062399725, 3.668432593345642, 2.145454555749893, 1.9722131661006381, 1.370063602924347, 1.4679631782429559, 0.7209583850843566, 0.5720315107277462, 1.079665162733623, 0.7498847129089492, 0.6518974708659309, 0.505612214761121, 0.4050281106361321, 0.33900592050382067, 0.47594650089740753, 0.8474871441721916, 1.8238745544637953, 2.2392815096037726, 4.362499875681741, 7.615599121366229, 12.581341164452688, 16.701800107955933, 28.42353446143014, 29.045306171689713, 28.768524680818828, 26.268171991620743, 29.007408959524973, 41.56532948357718, 34.716434546879356, 41.64008167811802, 46.58815445218767, 38.29677527291434, 27.774711677006312, 15.431617294039045, 6.616317885262625, 1.5962696990796497, 0.4082746835691588, 0.10713047427790505, 0.16791471333375999, 0.12397703315530505, 0.13273882014410837, 0.09003104575510536, 0.10745562825884138, 0.16319409092622145, 0.15590524061449937, 0.10839073772409133, 0.10799279729170458, 0.1174526611076934, 0.1243748582367386, 0.11089206207543612, 0.12995268750403607, 0.15740978345274925, 0.1536691148898431, 0.18366865441203117, 0.1292654536664486, 0.08266809941934687, 0.11868938617408276, 0.07822437358221837, 0.22111301230532782, 0.0948623643655862, 0.16992396408958094, 0.16568179029439176, 0.171049083716103, 0.11565310481403555, 0.0843370377219149, 0.09638619116906609, 0.17992045411041804, 0.07787453449730362, 0.09754229948988982, 0.1463799388813121, 0.12504671647080354, 0.1487798358180693, 0.41335482097097803, 0.0679755499586463, 0.07910593306379658, 0.14179365283676557, 0.2239701739911522, 0.13509130105376244, 0.12465962581336498, 0.2555382693452494, 0.1850202011742762, 0.16660301014780998, 0.272852148860693], [0.03243860489289675, 0.04464341088065079, 0.08421806339174509, 0.006384225728522454, 0.03400492495191949, 0.04442623217723199, 0.03943517963801112, 0.024050103766577582, 0.03820025608209627, 0.018673702708578536, 0.06568938227636473, 0.05542474878685815, 0.05710014674280371, 0.06802553763347012, 0.02938373845868877, 0.03989860548504761, 0.06283566076308489, 0.06385532247700862, 0.03938671188162906, 0.004295966355130076, 0.011155008837314588, 0.011385188271690692, 0.023545197377513562, 0.056158991530537605, 0.005009238125889429, 0.0891756166570953, 0.019962406950071454, 0.08922924127961908, 0.015345413803255983, 0.019716290424444845, 0.030510734234537398, 0.020216928828241568, 0.02627401246822306, 0.04734056383105261, 0.03191127801047904, 0.033623547559337955, 0.02478653478569218, 0.009462541484806155, 0.03261960071644612, 0.03675728351143854, 0.02525632698754115, 0.016119808856663958, 0.011055983436693038, 0.034818963413791995, 0.01448500425820904, 0.007331929651887289, 0.01592730338286076, 0.03797585776607905, 0.09249104053846427, 0.030077900138816664, 0.02546323267077761, 0.06610696629754134, 0.02755193818094475, 0.1816335107598986, 1.2144654265471866, 7.551657455308097, 17.52162674495152, 26.25205217088972, 39.067247118268696, 41.257347106933594, 46.04802581242153, 35.63790464401245, 26.96318813732692, 37.82767111914498, 29.74357407433646, 25.199014459337505, 16.194974184036255, 24.69679171698434, 22.373538187571935, 23.524802582604543, 14.922503675733294, 9.417091573987689, 8.26848486491612, 5.493138108934675, 4.76707306929997, 2.7998020265783583, 1.6198424398899078, 0.9749193319252559, 0.6973513918263572, 0.3167783075145313, 0.04791426179664476, 0.02628145769371518, 0.09939900878816843, 0.100766657186406, 0.2827808532331671, 0.14698536853705133, 0.23743319085666112, 0.46561262969459805, 0.5593482255935669, 0.8248881825378963, 1.1982756895678384, 0.8324805008513587, 0.639024630188942, 0.7586843350103923, 0.3829885061298098, 0.2053785587527922, 0.4081842755632741, 0.4805005022457668, 0.38662151832665714, 0.1378284298947879, 0.2868977966053145, 0.17404658001448425, 0.15602435065167292, 0.14709256349929742, 0.14502486373697007, 0.1541398824857814, 0.48650048886026653, 1.351139098405838, 1.3753460794687271, 2.003460083689008, 2.789469403879983, 4.829896509647369, 10.96713306222643, 11.824783955301557, 13.896099277905055, 15.60898917061942, 19.60396191052028, 20.0411981514522, 26.80819293430873, 20.274034023284912, 30.323613166809082, 31.576105867113384, 33.326919896262034, 34.78928640910557, 19.041503497532435, 12.46256865773882, 3.886921737875257, 1.5130420050450732, 0.14023463720721857, 0.010098015823002373, 0.019850935520870343, 0.03474053155098643, 0.0485884677618742, 0.05074438386197601, 0.015980951754110198, 0.07951924231435571, 0.016013182167496, 0.036645291306610615, 0.07134095472948891, 0.03910647352625217, 0.016523912083357573, 0.0630572499441249, 0.033497407899371216, 0.011034833500161767, 0.008504077692383101, 0.0722541068015354, 0.05245759318183575, 0.03156687059838857, 0.07939259375312499, 0.0017345486100696559, 0.07337674977523939, 0.020498122221657207, 0.007140895750905786, 0.033830042728888135, 0.0477464091964066, 0.05418349449921932, 0.005087845135546688, 0.0272262193196054, 0.06760185358247586, 0.007539488425079201, 0.06321369976337467, 0.042296514314200194, 0.05313338013365865, 0.09290285701198236, 0.0353385617823473, 0.06643814566944327, 0.04118185091231551, 0.022926197021401355, 0.037055757495441606, 0.018596370072503175, 0.04571306026939835, 0.03453687605048929, 0.024401048863572732, 0.030352486297488213, 0.01084132888354361, 0.05684772493051631, 0.03498093990076866, 0.012360180328999246, 0.06582458037883043, 0.024196747058470334, 0.049749661702662706, 0.029381010747913803, 0.036200928900923045, 0.007464466200742338, 0.03639536311051675, 0.027749373211658428, 0.05600740002202136, 0.029375080351850817, 0.008958227117545903, 0.058670934954924245, 0.019301983727408305, 0.05076270770015461, 0.09392580962074654, 0.09666251777006046, 0.04037339000829628, 0.052376766090414355, 0.029654697847685645, 0.02721733051086111, 0.02708638851929988, 0.008512301536809121, 0.03182699378313763, 0.029124867171049118, 0.05225318790014301, 0.034681186878255436, 0.06347645566399608, 0.01596605621411332, 0.004481171216217003, 0.0299607069630708, 0.0641354081620063, 0.018760268509920155, 0.02378579062808837, 0.014216309479836906, 0.03368097537064126, 0.05602548298026834, 0.019419845260147537, 0.0635566245764494, 0.026162761562903012, 0.018883617694622705, 0.03165051021746226, 0.02342491177842021, 0.06800687792045729, 0.06616889618869339, 0.023028006111936908, 0.028338594362139702, 0.03903141737516437, 0.10027121127183948, 0.02149785536208323, 0.019213601148554256, 0.028223387597660934, 0.39476787405354635, 2.436142214706966, 10.95631992816925, 22.516594648361206, 31.39597381864275, 44.41195433480399, 46.73444182532174, 47.62584359305245, 41.78726536887032, 29.219620840890066, 33.88359219687325, 29.391255242483957, 26.64855112348284, 21.566275630678447, 24.158773592540197, 28.646066154752457, 23.49271580151149, 21.89119597843715, 14.271058814866201, 10.74516591003963, 8.116093499319893, 6.5498939752578735, 3.5166752508708408, 2.0660620502063205, 1.144605306642396, 0.5352706547294344, 0.24360202412520135, 0.0991723577358893, 0.05345700401812792, 0.09303298645785876, 0.11332739889621735, 0.19621024786361627, 0.22648255846330098, 0.20410163727189812, 0.3560442876602922, 0.3573232176048415, 0.4877089868698801, 0.3171266945345061, 0.4499479431126799, 0.5146653918283326, 0.3261837256806237, 0.42848506623080795, 0.28207558393478394, 0.3476344160735607, 0.19988923759332725, 0.2584648723048823, 0.0863202123769692, 0.1853942232472556, 0.052148958135928423, 0.09619321580976248, 0.10417061631700822, 0.20214741570608957, 0.1413111872971058, 0.48946975810187204, 1.3021526698555266, 2.3702131467206136, 3.4405225600515092, 4.61297070980072, 5.829347542354038, 11.01360695702689, 13.349290813718524, 13.751236285482134, 20.503977707454137, 24.991482189723424, 21.05965641566685, 24.09632318360465, 23.408767666135514, 34.78815732683454, 35.54661226272583, 38.33599090576172, 38.822156361171174, 24.657721996307373, 15.057389054979597, 5.48873816217695, 2.081434939588819, 0.24589199838893755, 0.01760804819475327, 0.03553653794473835, 0.0780119989067316, 0.006641916789314044, 0.052724332083016634, 0.0242857488005289, 0.004926218942273408, 0.023572186107880304, 0.06339925194957427, 0.09252848888614348, 0.03309524358649339, 0.08120871308658804, 0.06688038086784737, 0.052346778235265186, 0.054299866647592614, 0.08985156645732266, 0.0076730877294072086, 0.08449582848697901, 0.03707361653713243, 0.10176640389753239, 0.03884493559598923, 0.03122036312041538, 0.0168693440833262, 0.056244039109775, 0.007279151501799268, 0.08893903185214315, 0.02652064128778875, 0.027173800793077265, 0.022543718705752065, 0.12419556214341096, 0.048870008904486895, 0.08804020365434033, 0.06475533132574388, 0.03953863926497953, 0.00971142728147762, 0.029678694238620143, 0.07628663363201277, 0.03399395304066794, 0.058130671802375994, 0.03849104904968824, 0.05317693868918078, 0.02744291117414832, 0.010685146237457437, 0.03374957865370171, 0.005178964330947825, 0.029168174668614353, 0.05202561743291361, 0.16003179204251083, 0.0906634811045868, 0.21265182990048612, 0.10333242200847183, 0.07446935400366783, 0.12138200311788491, 0.1170768884143659, 0.08185634762048721, 0.07377956208906003, 0.28178669086524416, 0.1555256409836667, 0.14932376305971826, 0.1583804413676262, 0.21487998962402344, 0.10185886107917343, 0.15906896442174911, 0.12505313541207994, 0.25801188232643263, 0.19074384761708124, 0.11776690424552985, 0.12362028658390045, 0.12083974507238184, 0.2393199253295149, 0.11783223359712533, 0.11258669649916035, 0.19304860037352356, 0.12834907855306352, 0.10929056336837155, 0.1127423592177885, 0.08007899977798973, 0.14996044603841646, 0.13392370513507298, 0.1604077818670443, 0.1511311632181917, 0.12386326997407845, 0.18865197843738965, 0.14692572530891213, 0.0864520449457424, 0.10530725746814694, 0.1352823900857142, 0.08744529129139014, 0.06798124286745276, 0.15766336555991853, 0.14835927981351102, 0.13461140037647315, 0.23234382537858828, 0.13702967204153538, 0.12352573951440197, 0.20950402452477387, 0.15817787152315888, 0.10204615031502076, 0.11971581966749259, 0.212841466867498, 0.5327907449432782, 2.240093146051679, 11.769118462290082, 24.0884439264025, 34.49645457948957, 51.40047332218715, 53.807193824223106, 55.926561151232036, 47.82394020898001, 36.30459124701363, 48.09683765683855, 39.95623091288975, 33.78876665660313, 25.454765490123204, 34.033027103969026, 35.28948722566877, 34.007763453892295, 24.027192081723893, 17.471877643040248, 14.9785669531141, 10.16997492313385, 7.698352166584559, 4.611728285040174, 2.522557394845145, 1.3527267617838723, 1.1237630993127823, 0.5459322312048503, 0.7830128552658218, 0.4803326598235539, 0.5332874868597303, 0.602559506893158, 0.36016272380948067, 0.669086717069149, 0.8435249882084983, 1.4903112990515572, 1.067674851843289, 2.2244547052042822, 2.69483928169523, 2.543704237256731, 2.6771737039089203, 2.0182345594678606, 1.2421293535402842, 0.7245009349925178, 1.1527280764920371, 1.0336975093398775, 1.41048963367939, 0.5389958119818142, 0.8641307396548135, 0.5328767289008413, 0.737889190869672, 0.5093555567520005, 0.5456401354500225, 0.4753708860703877, 0.9079781068222863, 1.8930082619190216, 2.5353998371532986, 3.8449463674000333, 5.539563800607409, 9.406501650810242, 16.251273700169154, 18.875234842300415, 21.624843733651296, 25.727506603513444, 29.997044358934673, 29.912540367671422, 36.56174407686506, 30.420297350202286, 41.32266364778791, 40.513201986040386, 44.87783105032784, 44.15486751283918, 29.669780731201172, 16.832933459963115, 5.937479751450675, 2.1257954963615964, 0.3544707920934473, 0.10985752008855343, 0.08060884063265153, 0.13351595987166676, 0.19507520805512155, 0.10778204431491238, 0.14661490198756966, 0.1372604960841792, 0.07410215120762587, 0.1493544192718608, 0.18738353864422866, 0.08773052027182919, 0.1645552593150309, 0.15759769694081374, 0.15981048106082849, 0.09973015423331942, 0.14885646956307547, 0.14104712860924856, 0.12869361149413244, 0.15788173169961997, 0.20342671205954893, 0.13355432424162114, 0.14183998320783886, 0.16708102449774742, 0.06765835519347872, 0.15889348169522627, 0.20135240336613996, 0.12274459643023354, 0.1493632537978036, 0.0822939280686634, 0.222238064078348, 0.18326785734721593, 0.12390181076313768, 0.182428115978837, 0.09039186353662185, 0.1761785913258791, 0.12380392530134746, 0.15218609518238477, 0.08948108633714062, 0.17149509835456098, 0.09250620579613106, 0.12444709507482392, 0.11614827252924442, 0.08763992227613926, 0.1438276158379657, 0.11851292635713305, 0.21704264357686043, 0.14228317514061928], [0.025948222360706756, 0.042306373428021155, 0.04304586124739476, 0.040615362381296496, 0.016045840057943548, 0.04901775651212249, 0.019996008004194925, 0.03813429908560855, 0.029407164880207608, 0.05546133878773876, 0.04618420784494706, 0.009624926789131547, 0.03901426061721785, 0.0644114294222423, 0.009897186420857906, 0.03697292194036501, 0.09621540390487228, 0.06593447591045073, 0.02549622643605939, 0.019429270111556565, 0.07620888030422585, 0.025642252261085168, 0.030960935434060435, 0.050980432624263425, 0.0730002239080412, 0.04845129851517933, 0.09354992836181607, 0.016925043326669505, 0.07305589092097112, 0.010644153392474567, 0.016272876178845763, 0.0901420744402068, 0.028505340950297456, 0.057633482052811554, 0.021399381271164333, 0.024723833060956428, 0.0553343102468976, 0.031081507714199166, 0.06450014787593059, 0.11146422315921102, 0.03527152252250484, 0.054095145847116194, 0.06349223160317966, 0.03730716150520103, 0.03406951130766954, 0.014660101916108812, 0.03948573388957551, 0.04072548522214804, 0.03634433727711439, 0.05242962057569197, 0.013693491462618113, 0.040703544792320044, 0.02879580482840538, 0.024928808312064836, 0.12082591652870178, 1.8964378493172782, 7.144615479878016, 13.841354421206884, 24.837263447897776, 34.600309303828645, 43.86420004708426, 41.23268795013428, 35.43148061207363, 33.440335341862266, 18.129932846341813, 25.64247281210763, 31.18578733716692, 23.258363485336304, 17.574903794697352, 26.41552938733782, 19.38036366871425, 17.145859479904175, 13.719297153609139, 11.735179117747716, 10.251297507967267, 6.67011387859072, 3.346053332090378, 2.287353490080152, 1.903973604951586, 1.034128949046135, 0.7158364227839878, 0.24799977242946625, 0.1888293610619647, 0.15104796125420503, 0.04399977631068655, 0.06823000059063945, 0.0959541339959417, 0.5833814474088805, 0.16409688176853315, 0.09187244051801306, 0.09250978167567935, 0.16577842725174768, 0.15373034588992596, 0.04538455093279481, 0.4015848711133003, 0.13012491326246942, 0.0735361444364701, 0.1272693257778883, 0.08144434794251408, 0.08193292029734169, 0.06079795224858182, 0.26641969116670744, 0.24035509835396493, 0.5163539669343403, 0.5816191562584468, 1.0340312400034495, 1.182460829615593, 2.509640693664551, 2.6302594670227597, 4.263316946370261, 5.89749721118382, 15.447860445295062, 14.575378622327532, 18.17595250265939, 22.341665063585552, 24.155097995485576, 15.778474841799055, 18.67319859777178, 29.786190850394114, 27.177791936056956, 34.76580844606672, 31.080803530556814, 33.47931473595755, 24.67083498409816, 9.570506061826434, 4.735351068632943, 0.8061266892722675, 0.15547652861901692, 0.01680070348083973, 0.045165757316031625, 0.06517099509281771, 0.00922311531446342, 0.08512337838432618, 0.053163099967475445, 0.04053496615961194, 0.02495980209537915, 0.014927253027313521, 0.010439003418598856, 0.004526440528154905, 0.040094953163393905, 0.01754795034815158, 0.016475610568055084, 0.03770085770104613, 0.03693493076467088, 0.05999876691826752, 0.024928977945819497, 0.033869513110922914, 0.04432816690366183, 0.029852015831108605, 0.02960405538656882, 0.0058687227428890765, 0.06308675943208591, 0.011638120681579624, 0.05474790671308126, 0.012464840962950672, 0.021317911267812763, 0.03993993505303349, 0.02927608209263001, 0.021145196964165995, 0.02743780010912035, 0.009832381237564343, 0.04887005979461329, 0.005741534746318523, 0.02702189376577735, 0.010282070991317076, 0.07867696322500706, 0.019789097231945822, 0.0462667244885649, 0.02614784227418048, 0.012774827989882656, 0.041784213589770455, 0.018135147767939737, 0.01045819154075746, 0.03718644334003329, 0.02813036723195442, 0.006912793057771134, 0.039365711222801886, 0.05723365529307297, 0.050370392323072465, 0.047779416532388756, 0.07701837258147341, 0.02953914672668491, 0.03016065087701593, 0.06376923673919269, 0.04484302231243678, 0.05565209873020649, 0.05703015585563012, 0.022374081558414867, 0.00986271769007934, 0.02406051927911384, 0.0671948886343411, 0.05402473426823105, 0.04195190334160413, 0.027124113369999186, 0.013726542055207704, 0.059028936816113334, 0.016514061451224343, 0.007889112923294306, 0.0590154475399426, 0.044136334875864644, 0.032345743982919624, 0.021146284316533377, 0.09045989345759153, 0.0418482978296067, 0.053570499178022146, 0.02231032301538757, 0.09698840456881694, 0.013064457269917642, 0.06619940312313181, 0.029895296187273095, 0.07912246896220104, 0.022678353624152284, 0.05639402927564723, 0.02800091971377177, 0.08949346281588078, 0.052283487881400754, 0.022491849792589034, 0.037408897653222084, 0.020965354650148323, 0.02773742251364248, 0.05207451266635742, 0.003948690012163881, 0.02556930635390537, 0.06409975793212652, 0.022776541034025804, 0.013880030917269843, 0.024058005306869745, 0.0392167015400316, 0.05837081213082586, 0.056213993579149246, 0.14950314057724817, 3.299823058503015, 9.682232226644244, 18.60765450341361, 29.95394468307495, 40.25097697121756, 49.32578638621739, 44.106872831072124, 36.039225646427695, 39.63466828210013, 19.90709444454738, 29.96650355202811, 27.152425800051006, 23.33688507761274, 23.900304079055786, 31.03925677708217, 25.114161321095057, 19.95305677822658, 17.353223255702428, 14.5490414755685, 12.649024435452052, 8.304957696369716, 4.85485965013504, 2.344045579433441, 2.572096748011453, 1.3090401802744185, 0.8493556124823434, 0.297999769449234, 0.204869915332113, 0.08316758940262453, 0.2299013707254614, 0.09853268241775887, 0.05137548249747072, 0.13235619424709252, 0.06593877782246896, 0.10446146356740169, 0.20055547755743774, 0.14586849989635603, 0.19312904748533452, 0.08530815025525433, 0.3739529438316822, 0.1295113954693079, 0.07550422847270966, 0.05973137662346874, 0.04779230869774308, 0.134272607841662, 0.08731153168316398, 0.14197178184986115, 0.20881334372929164, 0.4208190861557211, 0.5643488115497998, 1.004897443311555, 1.633099602801459, 3.0401480325630734, 4.133056461811066, 6.115004054137638, 7.097230502537318, 14.928496497017996, 17.82082486152649, 20.037875175476074, 23.808643443243845, 23.878283500671387, 17.197948387690953, 21.001135213034495, 33.99445417949131, 31.687165873391287, 39.28465277808053, 36.241904599326, 36.75398336138044, 31.067445618765696, 13.739425216402326, 6.127780488559178, 1.4787217038018363, 0.19146504891770227, 0.02375678325604115, 0.036818735035402436, 0.050042039049523215, 0.003391082232285823, 0.022894327927912985, 0.05256319358678801, 0.057667293452790806, 0.04765335151127406, 0.03104144361402307, 0.028849761933088303, 0.06016768142580986, 0.038425265079630275, 0.012916618060054523, 0.01403593536399837, 0.04166898138022848, 0.07209972651409251, 0.04332501394674182, 0.026118214042591195, 0.03777761697503073, 0.08584921407912459, 0.02105207651454423, 0.05382631705807788, 0.006447818878638957, 0.022531106436092938, 0.039586496339844804, 0.010718018714604633, 0.018050661676430275, 0.0688855739842568, 0.03305997333622404, 0.028532265219837427, 0.03724594068314348, 0.02316902604486261, 0.015102425324065345, 0.015533188191641654, 0.11039632439081158, 0.0825856981266822, 0.01747895690745541, 0.031160126174134866, 0.04372197389602661, 0.029435710848442147, 0.03329864463635853, 0.01666849771780627, 0.06731465685048274, 0.07134142970400197, 0.0399750695962991, 0.041848905118448396, 0.08002781109618289, 0.026853510211887102, 0.08589405845850706, 0.10168774133282048, 0.07731624945466008, 0.15044683351048402, 0.233841922134161, 0.08505703123020274, 0.0893334031903318, 0.1253377672817026, 0.13449732506913797, 0.08582202518092734, 0.2560614198446274, 0.1234803998044559, 0.05782783483820302, 0.15934088054512227, 0.12577440456620284, 0.16208873023944242, 0.1686618753841945, 0.1750952965979065, 0.1258057121719633, 0.14027210591094835, 0.18693501342620167, 0.11203302549464361, 0.1419445997370141, 0.12361807455973965, 0.1576256254421813, 0.1097855953765767, 0.1771050901817424, 0.11939564613359314, 0.12709221456732067, 0.13493788428604603, 0.1391887026173728, 0.12350744621029922, 0.16773479298821517, 0.1075007983350328, 0.16085637493857316, 0.16874821217996733, 0.11249772020216499, 0.10158779990992375, 0.21867359748908452, 0.18488087079354695, 0.17201712248580797, 0.1418561866240842, 0.15179224631616048, 0.0597271764917033, 0.08698509527104241, 0.0740787892469338, 0.0933778111689857, 0.1664973215333053, 0.11528069765440055, 0.19373510139329092, 0.12791963373976095, 0.12467863836458751, 0.15475877427629062, 0.1254305365894522, 0.5087729937263897, 3.592998606818063, 9.941823874201093, 19.570970126560756, 32.53856338773455, 46.21395574297224, 54.96663277489798, 53.728224073137554, 45.115317004067556, 46.64455645424979, 25.930807420185634, 35.91034003666469, 38.57170854296003, 34.02667645045689, 27.677966696875437, 38.080370153699604, 30.046644074576243, 28.50442886352539, 23.230337926319667, 19.44549434525626, 16.64899900981358, 10.991201622145516, 6.084441968372889, 3.798911077635629, 3.0631956415516988, 2.0192372713770186, 1.026179449898856, 0.7633204119546073, 0.8536322287150792, 0.24775558124695504, 0.43480722127216204, 0.8567116377609116, 0.5246381738356182, 1.3972984786544527, 0.7182044014334679, 0.8682173660823277, 0.7024626061320305, 0.5904396772384644, 0.7347581588796207, 0.8603863662907055, 1.4601814129522868, 1.0765268568481718, 0.509045384824276, 0.5992906508701188, 0.19203501833336695, 0.43192529305815697, 0.5241949004786355, 0.4173564133899552, 0.62216053796666, 1.0359296181372233, 1.094954782298633, 1.467482015490532, 2.1767459852354865, 3.7326109324182783, 6.070843040943146, 8.28183582850865, 11.684177603040423, 21.83285369191851, 22.823645966393606, 29.444843224116735, 31.77667256764003, 34.15836565835135, 25.79722309112549, 27.320132732391357, 41.88368204661778, 37.325271197727744, 46.61371687480381, 41.84648139136178, 43.42385448728289, 33.746983664376394, 15.67756962776184, 6.295483946800232, 1.7144924295800072, 0.2587748813842024, 0.14092721790075302, 0.10372235572763852, 0.12549817296011107, 0.11735335072236401, 0.18511480252657617, 0.12854730577341147, 0.12648621494216578, 0.1337058682526861, 0.24057554081082344, 0.11962827507938657, 0.18575570599309035, 0.16140932669597013, 0.110427340226514, 0.10809387186808245, 0.11582079795854432, 0.14993840722101076, 0.19653887594384806, 0.13869097003979342, 0.12204415830118315, 0.12357563897967339, 0.08017763841365065, 0.2306459950549262, 0.10848554263689689, 0.12457159268004553, 0.087223369628191, 0.08614204943712268, 0.06803783268800803, 0.12227222749165126, 0.16856309425617966, 0.12400876145277705, 0.21142326082502091, 0.0961389330082706, 0.09004256049437181, 0.09987611390118088, 0.13508600848061697, 0.1912679209240845, 0.076244652670409, 0.1604049727320671, 0.17753852478095464, 0.14483815804123878, 0.11754942020135266, 0.0901816873145955, 0.12432589514979295, 0.12181121722928115, 0.0781966961388077, 0.12314479638423238, 0.1407017542847565, 0.06627157889306545], [0.024284858223316923, 0.01668875029177538, 0.018791910294177275, 0.033044007407235246, 0.023084560309403708, 0.0385797776814018, 0.033883864126567326, 0.026703311396496635, 0.039736910590103695, 0.06519097794911691, 0.041200968636465926, 0.05293568895597543, 0.047206023907555, 0.0456671471973615, 0.030555259702461104, 0.027614232784669315, 0.0291996281594038, 0.03730885445007256, 0.03722080774605274, 0.015949094534984658, 0.03444116868610893, 0.01967750027376626, 0.019333035186199204, 0.014714249010596956, 0.032869389812861166, 0.07023337523319892, 0.026288392321605767, 0.027476525798972164, 0.05085805544097509, 0.05069286948336022, 0.009570463327690959, 0.04150722880980798, 0.026801430952868292, 0.013784523720719984, 0.08071569632738829, 0.01440026201973004, 0.01697169430553913, 0.016793711177472557, 0.010989572669911598, 0.028535060784114257, 0.0708125727251172, 0.016868796166298643, 0.06734654799635921, 0.06930275766977242, 0.051973207388073206, 0.06997531479490654, 0.044805261838648996, 0.004037693874644381, 0.031103376897850206, 0.08167289889284543, 0.01859657702568386, 0.040788144538445134, 0.04169955277549369, 0.026032859426257864, 0.04749742416398866, 0.38434267203722683, 1.3691850900650024, 5.397107056209019, 11.933373876980372, 23.495972769601003, 33.63667058944702, 42.47037751334054, 37.77401712962559, 40.01665244783674, 37.74688788822719, 36.385732310158865, 38.47061225346157, 17.798578466687882, 20.783482892172678, 25.70365343775068, 19.320631742477417, 18.16776752471924, 20.0853522164481, 13.064794216837202, 15.150701625006539, 6.370375973837716, 6.939969752516065, 5.105312245232718, 3.7828364201954434, 2.869808167219162, 1.3021326937845774, 1.3762294777802058, 0.8874734842351505, 0.3974597310381276, 0.4295234690819468, 0.2264506673174245, 0.2396837558065142, 0.1916027915264879, 0.1461279581167868, 0.15713758234466824, 0.10496480762958527, 0.15761296397873334, 0.0569290609232017, 0.12172669890735831, 0.2236895997609411, 0.04252185579389334, 0.0859266145687018, 0.11953627930155822, 0.11666596760707242, 0.2357185057231358, 0.4154208515371595, 0.4790301982845579, 0.7689245140978268, 1.1837243161031177, 2.426695487328938, 1.8689032239573342, 3.4217294199126105, 6.972516417503357, 10.676426512854439, 11.248045257159642, 18.13988787787301, 18.357800756181987, 13.039970908846174, 15.709639038358416, 11.510041849953787, 18.885294096810476, 19.978832857949392, 22.322420290538243, 33.258188315800254, 26.686392750058854, 35.61232137680054, 29.996419021061488, 23.321890865053447, 12.373444982937404, 4.623257083552224, 0.6279242858290672, 0.2277973150568349, 0.0341179247812501, 0.053127948460834365, 0.029483340614076172, 0.03312101773917675, 0.01539844979665109, 0.022546846752188036, 0.06543660084051744, 0.08713100744145257, 0.02679079830912607, 0.017332215227984955, 0.02182400000414678, 0.003613500074217362, 0.04007161834410258, 0.022996807071779455, 0.008419739182240196, 0.032667892053723335, 0.04870909432481442, 0.036901865753212144, 0.03722804771470172, 0.015801621734031608, 0.024759849699746286, 0.048739055038562844, 0.04926385437803609, 0.01726056701902832, 0.009779168825064386, 0.024922433475564634, 0.03475188683452351, 0.04455958466444697, 0.0189828958495387, 0.04436539472745998, 0.05573063576593995, 0.0791200805189354, 0.06869352143257856, 0.0204537714765008, 0.032033363423709355, 0.014843962853774428, 0.02613308244118733, 0.06445055375141756, 0.060853639617562294, 0.02900782666568245, 0.019808557616280656, 0.05788343399763107, 0.014197719316663486, 0.054080710014594455, 0.029201996246618882, 0.04298737831413746, 0.004351068911741355, 0.017857698191489493, 0.04614254918747714, 0.04312808272827949, 0.033295306244066784, 0.02411096326873771, 0.028235194106985415, 0.028202068027375, 0.02014825599534171, 0.03175130659448249, 0.025737700085820894, 0.059784465203327794, 0.04995293043819921, 0.02712715999223292, 0.04707939909504993, 0.027878796981115426, 0.05325440024690969, 0.014211569064562874, 0.015194237897438663, 0.05377812750105347, 0.03126687330326863, 0.02197712330546762, 0.02512288629077375, 0.047870163805782795, 0.05635645879166467, 0.10500313807278872, 0.005924021650571376, 0.018629358748772314, 0.02835357471901391, 0.05063601164147258, 0.06778812501579523, 0.04615840994353805, 0.03150801107819591, 0.031107773804771047, 0.024795564390452843, 0.018466203307200755, 0.03712715973545398, 0.06842841101544243, 0.044691685254552534, 0.05378836320180978, 0.010387895312825484, 0.037606225814670324, 0.025995999707707336, 0.057567243464291096, 0.009598375713851835, 0.08707547613552638, 0.0789384977625949, 0.028452176035248807, 0.06100167560258082, 0.03608033287205866, 0.0243355498782226, 0.01938410851705287, 0.030382399513785328, 0.008264789773550416, 0.05172156589105725, 0.05698078564767327, 0.04674341569521597, 0.04571339953690767, 0.38609910064509934, 2.0581202592168535, 7.265870664800916, 15.624037231717791, 27.795514583587646, 39.29816355024065, 48.66520030157906, 42.93664332798549, 43.755933216639924, 36.6188200541905, 38.97532592500959, 43.44831562042236, 21.624659606388636, 20.82131235940116, 24.13320074762617, 19.95567798614502, 22.13638401031494, 23.875433002199443, 19.510730981826782, 20.452797276633127, 10.100216746330261, 9.605078560965401, 6.790495327540806, 4.7671651329313, 3.935283805642809, 1.8750054793698447, 1.7595648510115487, 1.134218726839338, 0.6354559159704617, 0.35054391995072365, 0.20133919907467707, 0.03832174777718527, 0.07343369243400437, 0.09729360962020499, 0.013462803126978022, 0.0842548603458064, 0.040124862987015925, 0.008650447025762072, 0.13375067870531762, 0.08349142702562468, 0.040819089127970595, 0.1665969304740429, 0.03131075416292463, 0.19346648295010838, 0.36812975630164146, 0.3555236613111836, 0.545773833990097, 1.1124178852353777, 1.4532445051840372, 2.5540160153593336, 2.8338371259825568, 4.913489852632795, 7.360479508127485, 12.172917366027832, 11.59841685635703, 17.919544867106847, 25.16639961515154, 16.932829448154994, 20.75793089185442, 15.51155458177839, 24.78341838291713, 21.61443533216204, 25.95707334790911, 36.27238287244524, 30.960526738848003, 38.619251591818674, 34.66671323776245, 28.453790392194474, 16.11890356881278, 6.436668736594064, 1.1734876653977802, 0.20458844543567725, 0.019489624105127792, 0.05835562651710851, 0.05981732665428093, 0.06760412667478834, 0.026958179327526262, 0.02608982753008604, 0.05348897998088172, 0.05889457331172057, 0.014857825324205416, 0.05384829820000699, 0.027959759779540554, 0.025204252817534974, 0.04147962261257427, 0.07096635590174369, 0.07896768155374698, 0.016373390963833247, 0.039807305205613375, 0.042722695374063084, 0.08657451373125825, 0.048642747170690975, 0.019374956775988852, 0.044184096955827305, 0.020690814292590533, 0.03941925102844834, 0.014978930254333785, 0.024043155567986623, 0.020236358678500568, 0.049941690505615303, 0.04020831940163459, 0.08610806840338878, 0.045830060062663894, 0.013089219557254441, 0.049445552485329766, 0.01442481141670474, 0.03285583268318858, 0.06329166343701736, 0.018588999485863105, 0.01980521243863872, 0.029029746739459888, 0.021922570786305835, 0.06405272188463382, 0.0543798964603671, 0.019040747745228664, 0.04032497653471572, 0.01508029829710722, 0.028427767434290478, 0.03270592733419367, 0.05967264263225453, 0.06986065594745533, 0.15799685195088387, 0.16642474542771066, 0.18860111545239175, 0.12425615532057625, 0.14350144405450138, 0.09903230132269007, 0.08606954118502991, 0.07396877157901015, 0.13767831080726214, 0.23373360080378397, 0.14189432029213223, 0.18224995982434067, 0.15061126968690328, 0.2092889289238623, 0.10121655983052083, 0.11311353144368955, 0.1423841682927949, 0.07009912707975932, 0.08921154508633272, 0.11910718732646533, 0.19347010632710798, 0.1589307061263493, 0.17312400309102877, 0.10748243039207798, 0.11385928892663547, 0.18107698990830354, 0.10335938020476274, 0.12358644125717026, 0.15976721766803945, 0.10571965748178107, 0.10911349286990506, 0.08932213950902224, 0.11580397029008184, 0.15895193070173264, 0.2450731966112341, 0.11594252714088985, 0.08589893033994095, 0.08532854701791491, 0.09266232991857187, 0.08144423937691109, 0.20222741498478822, 0.11412150199924197, 0.21525198966264725, 0.21703686245850154, 0.21583117358386517, 0.16049729420670442, 0.09451146676604237, 0.1494169666298798, 0.15398897629763397, 0.17800285986491612, 0.1651880746441228, 0.13578042121870176, 0.1524615396878549, 0.17601563435580048, 0.10654415895364114, 0.46293898458991734, 2.2760096873555864, 7.381393585886274, 17.112848588398524, 29.62652472087315, 43.666030475071494, 55.45922531400408, 51.10980585643223, 51.86545372009277, 47.931467056274414, 48.158478600638254, 51.384138107299805, 27.901311329432897, 30.210725784301758, 36.8626184463501, 28.226945604596818, 28.016528095517838, 31.378325394221715, 22.061343465532573, 25.002401283809117, 12.290948152542114, 12.370572771344866, 9.174966829163687, 7.254092599664416, 3.843697428703308, 2.663755646773747, 2.2910983519894734, 1.4840902728693826, 1.0856613495520182, 0.7562969774007797, 0.667677426976817, 0.5989998036197254, 0.29148588755301064, 0.4078898456479822, 0.7032698999558176, 0.46158869990280693, 0.3775899458144392, 0.24317107296415738, 0.2860414854117802, 0.32936836193714825, 0.1887713870299714, 0.7211889241422925, 0.4942912108131817, 0.5510323718190193, 0.47957861742803026, 0.772460007241794, 0.7570276239088604, 1.667067391531808, 1.9044254549912043, 3.0743987432547977, 3.2990598423140387, 5.913944465773446, 10.621672102383204, 15.314729486192975, 16.033023834228516, 26.978835480553762, 26.672671794891357, 21.977244206837245, 26.01517939567566, 20.70464689391, 31.62976333073207, 27.518231085368566, 31.89191538946969, 44.07302468163626, 37.546804087502615, 45.71151760646275, 39.587458746773855, 31.502114500318253, 18.68085377556937, 7.895414369446891, 1.3046191717897142, 0.32690840108054026, 0.0778724310387458, 0.12087019772401877, 0.15978766871350153, 0.1706151334302766, 0.13025082222052983, 0.10530186311474868, 0.14042687974870205, 0.20391114535076277, 0.11937429942190647, 0.091411104558834, 0.14015326728778227, 0.15114853371466908, 0.10229553229042462, 0.1496406253427267, 0.16720526425966195, 0.08847498853823968, 0.21496230949248585, 0.15232522200260842, 0.18716158983962877, 0.10364139292921339, 0.12301096213715416, 0.13184582734746592, 0.09357700190906014, 0.09476280292229992, 0.07928358031702892, 0.125536265916058, 0.11682398484221526, 0.17080973727362497, 0.07632331523512091, 0.1370011464293514, 0.16964699966566904, 0.2016240887876068, 0.15345452140484536, 0.06936504718448434, 0.125618897910629, 0.1164172709520374, 0.13764523901045322, 0.15956395571785315, 0.09806489359055247, 0.10654405038803816, 0.15094740236444132, 0.2082801509116377, 0.06318459061107465, 0.1233559971941369, 0.1161303592047521, 0.19579598866403103, 0.11349461028086287, 0.1266492126243455, 0.14965525455772877], [0.04850370516734464, 0.009110928878986409, 0.03462766403598445, 0.013096696164991175, 0.036337439968649826, 0.0797375813126564, 0.01707446521946362, 0.02020815876312554, 0.03897135345531361, 0.047637443257761855, 0.015718044879447137, 0.007178400077724031, 0.013227118229094361, 0.01809509045311383, 0.031426400278827975, 0.009049165228913938, 0.01915585103311709, 0.028486250367547785, 0.11442807769136769, 0.048214720495577366, 0.043165972123720815, 0.018957120000517795, 0.02318741943288062, 0.021923707332462072, 0.04068677140665906, 0.04359354757304702, 0.05510827326881034, 0.03790187709299581, 0.051437510776200464, 0.015416176524013281, 0.0680884039029479, 0.027447898406535387, 0.040816636223878176, 0.007093257079499641, 0.031167983609650816, 0.04128610781793084, 0.04121284299929227, 0.031780422532132695, 0.05201346826340471, 0.006452640718115228, 0.00709176854330248, 0.04474959482571908, 0.059322294646075795, 0.013054627842003745, 0.038194729414369376, 0.05762713096503701, 0.01196583273953625, 0.02092556026764214, 0.06644080552671637, 0.05369016222123589, 0.06442148531121866, 0.031273485627025366, 0.03866431296670011, 0.03443943502913628, 0.024671821655439477, 0.03582029450418694, 0.09349877360676016, 0.872132838836738, 3.246701257569449, 8.852223873138428, 17.801590510777064, 24.58785264832633, 35.25207117625645, 40.27571255820138, 41.98603596006121, 37.94184739249093, 32.20676606042044, 26.540405886513845, 29.94178533554077, 32.88564675194876, 20.955886806760514, 21.25761580467224, 23.337051834378922, 15.112564699990408, 12.732368077550616, 12.828267983027867, 7.6317232847213745, 10.81373507635934, 6.632016471454075, 5.012724893433707, 4.303097988877978, 3.6316792283739363, 2.7277711374419074, 2.235380096094949, 1.2957575044461658, 0.7562096363731793, 0.7803698256611824, 0.6939815697925431, 0.5344313883355686, 0.4397901381765093, 0.36430930559124264, 0.2990712576678821, 0.3610105668859822, 0.27766578484858784, 0.3613552898168564, 0.49418291662420544, 0.5655201801231929, 0.6403115125639098, 0.8053198297108922, 0.7982588857412338, 1.3777170436722892, 2.364050094570432, 3.917891161782401, 3.1172973556177954, 4.850828392165048, 5.461700550147465, 7.423206976481846, 10.187130893979754, 10.661546077047076, 20.702998433794292, 13.275225622313362, 13.312588691711426, 14.096386313438416, 9.80408365385873, 23.0670257295881, 19.050633430480957, 19.372237750462123, 26.779163360595703, 28.484504904065812, 30.339392525809153, 26.27698925563267, 19.82790756225586, 12.51358493736812, 6.3451414193425855, 1.126317105122975, 0.04558261191206319, 0.09403584085937057, 0.03249750512519053, 0.06648964647735868, 0.03899863734841347, 0.053757401648908854, 0.01750431885011494, 0.09720215667039156, 0.021808183352862085, 0.051036723889410496, 0.02040219263705824, 0.04902173272733178, 0.05182235548272729, 0.018073479112769877, 0.06734732831163065, 0.07141884376427957, 0.01135134294496051, 0.0902890654812966, 0.03860727870570762, 0.015641260160399333, 0.033931439609399865, 0.036303340191287656, 0.024360857538080642, 0.07143150522772755, 0.016475189876343523, 0.044208436006946225, 0.04984414091865931, 0.04202325129881501, 0.0065045562805607915, 0.027750643768480847, 0.020252845383116176, 0.027154762796791534, 0.032547865994274616, 0.057697786816528866, 0.020066480651231747, 0.019481198396533728, 0.024306917396773185, 0.006276280136911997, 0.040906002678509266, 0.05153502304373043, 0.03842608949967793, 0.03743667687688555, 0.025454364218083874, 0.03974851353892258, 0.041417468804866076, 0.012959169839242739, 0.021892264019697905, 0.06620633096567222, 0.02072277498830642, 0.0522928516646581, 0.01753430500892656, 0.0391595213940101, 0.02988827334983008, 0.05409000933702503, 0.030854653101414442, 0.02181248865755541, 0.004666751816070506, 0.034934558639568944, 0.06057122655745063, 0.048639907501637936, 0.020274453330785036, 0.021413004558001245, 0.019410539152366773, 0.05812733341008425, 0.016608567808621695, 0.03765002525012408, 0.02898256141426308, 0.04521386884152889, 0.023025341165651168, 0.0248531431757978, 0.09605074381189686, 0.007531262884315635, 0.03207267095733966, 0.02153151748435838, 0.03498879394360951, 0.02540470563274409, 0.05255747014390571, 0.02690325870311686, 0.023876656645110676, 0.06667788566223212, 0.024291017624948705, 0.034687426007751904, 0.03591348111097302, 0.05890450706439359, 0.034655463615698476, 0.06068883703223296, 0.006123095767439476, 0.0340907155270023, 0.023666024108284285, 0.029213521163910627, 0.04856242898053356, 0.04260949198422687, 0.028763482812792063, 0.072062230668962, 0.025215747200750878, 0.0673235592299274, 0.06101861862199647, 0.012966297849613641, 0.02158193093990641, 0.03614403034693428, 0.03606933721208146, 0.02185899544773357, 0.03293635104117649, 0.04636660484330995, 0.0523839721323124, 0.028630415310284922, 0.01890860135400934, 0.21430062928370067, 1.740110872047288, 5.658782729080745, 12.328324249812535, 23.55520268848964, 30.39621489388602, 41.094866956983296, 46.382977621895925, 45.65549428122384, 42.56805181503296, 35.197392327444895, 26.2820041179657, 30.423003673553467, 36.80399649483817, 20.030456236430577, 20.32282427379063, 26.34375970704215, 18.134087869099208, 19.018961804253713, 15.722606113978795, 14.482029574257986, 17.420405387878418, 9.713899510247366, 6.490595442908151, 5.544761487415858, 4.469968097550528, 3.4019785140241896, 2.1777499999318803, 1.9783223697117396, 1.4596295739923204, 0.7415795528462955, 0.7887609153985977, 0.9028605414288384, 0.5623435505798885, 0.26749451777764727, 0.2733149097434112, 0.3328036761709622, 0.2141554227897099, 0.46675777967487064, 0.5348780815090451, 0.3619597559528691, 0.7062489943844932, 0.7531508005091122, 0.9479319857699531, 1.442553073167801, 2.1739187198025838, 4.268170263086047, 4.046735082353864, 5.920016322817121, 5.578663485390799, 8.59129730292729, 15.02463003567287, 16.190933806555613, 23.880406175340923, 18.9409978049142, 14.959139789853777, 16.025273118700298, 14.0601019518716, 21.83800057002476, 21.504400185176305, 21.7859776701246, 29.71811240059989, 35.34145975112915, 34.82188388279506, 31.88302516937256, 26.185919216700963, 14.895301478249685, 7.573250719479152, 1.550958433321544, 0.12530584899442537, 0.05702102277427912, 0.032288122789136, 0.09811340205903564, 0.061626918480864594, 0.01686187680544598, 0.06357571176652398, 0.030606271965163093, 0.042757283696638684, 0.024763620658112422, 0.03705404758719461, 0.018026897683739662, 0.04268256342038512, 0.05131618532219103, 0.017409108512635742, 0.053971547300794294, 0.023215758447934474, 0.057567243464291096, 0.05186963580282671, 0.08970592570091997, 0.05388507140534265, 0.04245441619838987, 0.016226947839770998, 0.05393229065729039, 0.04943467217630573, 0.0431961533613503, 0.046361193526536226, 0.0783322470794831, 0.040549883751996925, 0.01617196953988501, 0.04012481548956462, 0.13064834874655518, 0.05944576087806906, 0.02228970403250839, 0.039058029518595765, 0.08249691860484225, 0.0069818522315472364, 0.06745385830955845, 0.03484658657440117, 0.029616988264024258, 0.027845754022044793, 0.031799991482070515, 0.018359871780765907, 0.06521920500589268, 0.03329550641189728, 0.03177587974018284, 0.0181279128883034, 0.027403249105970775, 0.03242851507716945, 0.03993639649291124, 0.016759121158559407, 0.20701572804578713, 0.08312089940799133, 0.14115356361227377, 0.15816263162664004, 0.10057624668947288, 0.09584759042731353, 0.13749537776623452, 0.09863322773682219, 0.09626748825290374, 0.12626991154892103, 0.07768200697111231, 0.07651166977094752, 0.08295750139015061, 0.1350502496851342, 0.11268588474818639, 0.11195654781269175, 0.12803829594382218, 0.17965270419205936, 0.14159024160887512, 0.1786936085139002, 0.09805040008255414, 0.11098251757877213, 0.1120685264468193, 0.14016135542520455, 0.09999669635934488, 0.13069425842591695, 0.1437479965388775, 0.19130334045205796, 0.14647280318396433, 0.13170389139226504, 0.1479610883231674, 0.13689146802893706, 0.15672415095780576, 0.13772103137203626, 0.16091732095394815, 0.14418753795325756, 0.12638169340789318, 0.12046828786177294, 0.23850489620651516, 0.07036687699811799, 0.0961259322773133, 0.1094784497150353, 0.1229165643453598, 0.09191514072673661, 0.11333945646349873, 0.1689839216747454, 0.14795012319726603, 0.1630249728581735, 0.2244853720601116, 0.11565915734640189, 0.21485637660537446, 0.1562251698757921, 0.1556292532810143, 0.12262475357523986, 0.08030210887747151, 0.30535069214446203, 0.2289746275969914, 1.6447201392480304, 5.909610092639923, 13.427056789398193, 26.114045313426427, 35.3583334514073, 46.700569357190815, 53.055322306496755, 52.98966530391148, 50.27287449155535, 43.249353953770225, 36.10211379187447, 39.98696626935686, 44.625639234270366, 30.37479359763009, 30.469111919403076, 34.41995143890381, 25.870425837380544, 22.109834943498882, 22.590497425624303, 16.413336958203995, 19.004549503326416, 12.39318915775844, 10.080270205225263, 7.500583853040423, 5.654146109308515, 4.188473122460501, 3.5142655287470137, 2.0235516684395924, 1.587992006114551, 1.517144916313035, 1.2576316531215395, 1.126249903014728, 0.6436945796012878, 0.5358021376388413, 0.6514723279646465, 0.7035330086946487, 0.6928192664469991, 0.7689487242272922, 0.8964166300637382, 0.6612117482083184, 0.8042044809886387, 1.245403692126274, 1.4202390419585365, 2.149569409234183, 3.0212749881403784, 4.9889746478625705, 4.89654015643256, 7.352199860981532, 8.736078654016767, 11.915520480700902, 15.74641932759966, 18.491947889328003, 30.16382196971348, 22.13808110782078, 23.558134828295024, 23.0797826222011, 19.272711753845215, 32.42417172023228, 29.44076463154384, 28.17094486100333, 37.4836345400129, 40.48163979394095, 41.67893600463867, 35.77224111557007, 28.76396492549351, 17.144249234880718, 8.581865123340062, 2.0162065540041243, 0.2391867424760546, 0.18068285605737142, 0.10470319845314537, 0.19438577576407365, 0.1515306303543704, 0.15004625357687473, 0.13808475328343256, 0.1357584231133972, 0.14656847662159375, 0.1763864266020911, 0.20389841603381292, 0.13083316811493464, 0.11181587393262557, 0.08036223386547395, 0.13440455576138838, 0.25364078687770025, 0.11791373922356538, 0.2647647442562239, 0.1593644664223705, 0.22131364153964178, 0.21870468796363898, 0.09868734090455941, 0.0977186710972871, 0.24237580278090068, 0.10531930146472794, 0.1246503298836095, 0.08193282530243907, 0.1927147340029478, 0.1488540539784091, 0.13788740815860884, 0.1254433337599039, 0.2155908364802599, 0.2519201306360108, 0.1189718060195446, 0.158077014077987, 0.18477484291153295, 0.10250360505389315, 0.18007692428571836, 0.1539711443973439, 0.1276036671229771, 0.17623750173619815, 0.09830145803945405, 0.15070464967616967, 0.14599697371678694, 0.13673809197332176, 0.067755806392857, 0.11387967211859566, 0.15483106539717742, 0.15225062386265822, 0.1551413866026061, 0.10121465993246861], [0.03669147579265492, 0.04288091616971152, 0.03738252638972231, 0.02138911164365709, 0.04972086128379617, 0.05221252329647541, 0.03738864677559052, 0.013068565799455558, 0.04420294326597026, 0.002947730207649459, 0.019716438005811403, 0.09838831052184105, 0.036953329241701534, 0.032325839158147573, 0.04109260320131268, 0.04015181779063173, 0.040063150227069855, 0.029465284797229936, 0.03840742639399, 0.04063111457175442, 0.07666830279465232, 0.06641892277236496, 0.08513979214642729, 0.007900977956264146, 0.07271884900650807, 0.012839546659961343, 0.09759331175259181, 0.009718733407290918, 0.03708703117445111, 0.037857623039079566, 0.061142186634242535, 0.08242828478770596, 0.027090186619066765, 0.015157651289233139, 0.041484555562159846, 0.01720955814900143, 0.04476332837449653, 0.029286080306129794, 0.023211958651830043, 0.02332375747417765, 0.06103694585285016, 0.03472517630351441, 0.03590768642191376, 0.021042585505970886, 0.012934758693778088, 0.04017212295106479, 0.021995759269754802, 0.029124802710222344, 0.03739138127171567, 0.04818717875917043, 0.028759364105228866, 0.05027670020769749, 0.04306047689169645, 0.01416173406011824, 0.05996237029986722, 0.03866877094177263, 0.02988097570570452, 0.10848200068409954, 0.478585242160729, 2.365100358213697, 7.383851511137826, 16.275743518556865, 21.649374348776682, 33.85815831593105, 37.81261089869908, 43.48278215953282, 38.27687563214983, 36.339839458465576, 32.42872279030936, 21.741602999823435, 26.221264702933176, 28.644415957587107, 23.75188534600394, 21.10917275292533, 22.334555319377355, 17.16351658957345, 17.281345878328594, 10.078540972300939, 12.818700313568115, 13.890737005642482, 12.345886690276009, 10.29410535948617, 6.6249770777566095, 6.174790263175964, 3.0871599784919193, 2.4022423880440846, 2.310800620487758, 3.068933767931802, 2.501503267458507, 1.4548251117978777, 1.2057440259626933, 1.0578788689204623, 1.6572475241763251, 1.2553748999323164, 1.2632738075086047, 1.247849349464689, 1.8140868225267954, 2.245745722736631, 2.5255205844129835, 3.0286105488027846, 3.892946694578443, 4.480422096593039, 5.254937793527331, 7.703894223485674, 8.824016792433602, 12.625129580497742, 8.092347162110464, 11.319395439965383, 13.676028983933584, 20.206381150654384, 12.485130327088491, 23.591083186013357, 18.90541434288025, 18.65990843091692, 15.732175520488195, 28.14914836202349, 30.143105915614537, 31.899019922528947, 30.23243890489851, 26.006686959947857, 19.710906846182688, 11.13613496507917, 6.015552316393171, 0.9165124488728387, 0.07436114123889379, 0.09182321958776031, 0.029363348481378386, 0.045622312996004305, 0.07084176330161945, 0.03677481346364532, 0.041930241111133776, 0.049154121694820266, 0.04534857161343098, 0.05529130809009075, 0.044802775007805655, 0.09963707958481141, 0.04894110919641597, 0.06380945350974798, 0.04523821807067309, 0.06443861153508935, 0.04140799645600574, 0.06052969342895916, 0.039381819644144604, 0.048567579061325104, 0.03006088248054896, 0.03087445953860879, 0.06549971138260194, 0.11456430038171155, 0.022884950573955263, 0.04792904368202601, 0.018982378466586982, 0.029230766131409576, 0.02781471104494163, 0.05086428778512137, 0.05485718138515949, 0.03383927759049194, 0.012310687136570258, 0.024882384642426456, 0.034081324602344205, 0.03668084993426289, 0.0594329908490181, 0.08128741636340107, 0.011612929220843528, 0.04981651436537504, 0.03276102437770792, 0.054236203099467924, 0.029185881039925983, 0.05725983317409243, 0.050098930818161795, 0.012814824236556888, 0.015477875713258982, 0.030392424868685857, 0.009056071867235005, 0.029958511902285472, 0.010483271043215479, 0.03666058887860604, 0.037517738062888384, 0.04135914193466306, 0.03905590909666248, 0.0648276156612805, 0.05493614250527961, 0.08210657097931419, 0.011761628473842782, 0.03500553679519466, 0.044425668993166516, 0.01967345450871757, 0.0067954026827854765, 0.005325068187500749, 0.016147085964413624, 0.021706040083829845, 0.016700604298551167, 0.013939088908955455, 0.035321988564516814, 0.033186764389808686, 0.03454932377540639, 0.06480690677251134, 0.037939277943223715, 0.02703224990649947, 0.049264590588531325, 0.021779728986855065, 0.03376450303143688, 0.0625620957996164, 0.04435548811618771, 0.024823738860764673, 0.055191604154450555, 0.05418333165081484, 0.035797448230109045, 0.05767118145844766, 0.027778577358861054, 0.05691193469933101, 0.031841670495590994, 0.059031576317335875, 0.03651378782732146, 0.03871164756960102, 0.024782008957117796, 0.033360523637384176, 0.06693665177694388, 0.01342087984085083, 0.06043853224920375, 0.04405977576971054, 0.04287082974665931, 0.0494009048811027, 0.030721667023109536, 0.03753983455577067, 0.03941262174131615, 0.047831195539661815, 0.06205859567437853, 0.03789367021194526, 0.016031504309337054, 0.07605785197977509, 0.0693693830232535, 0.10743928913559232, 0.04320861126429268, 0.1968121627079589, 1.0420618376561572, 3.7385538135256087, 10.086777193205696, 20.580743142536708, 27.72836024420602, 39.4166442326137, 42.749695096697124, 46.4656994002206, 42.72060298919678, 41.37692560468401, 37.7776232446943, 29.478020872388566, 28.418981654303415, 29.697233063834055, 28.15327385493687, 22.067744493484497, 24.664091757365636, 22.054172924586705, 18.79225598062788, 14.997634547097341, 15.718395505632673, 19.40579581260681, 15.952666180474417, 11.985648649079458, 8.38418105670384, 8.386638113430568, 4.602672176701682, 3.0951026380062103, 3.680190682411194, 3.2857025819165364, 2.7091545249734605, 1.7545135106359209, 1.8702722362109592, 1.1772888728550501, 1.8785688195909773, 1.6405635965721947, 1.3844887145927973, 1.421056540949004, 2.4210149007184163, 2.92394266809736, 3.306462062256677, 4.6254631366048535, 5.021390165601458, 5.392974615097046, 7.328130432537623, 9.618717874799456, 11.268726570265633, 16.905189514160156, 14.455609917640686, 16.624464920588903, 17.389392103467667, 25.5281297819955, 17.626803364072526, 25.60514187812805, 20.252128090177262, 20.299893481390818, 20.820867674691335, 30.592591830662318, 31.658212729862758, 35.10321991784232, 33.36659063611712, 30.55380698612758, 22.844813653400966, 13.691472223826818, 7.935372591018677, 1.7684818868126189, 0.15596368962100574, 0.01954028013694499, 0.054831872028963904, 0.08826287170606, 0.0424258871935308, 0.04717031600219863, 0.018805857581485595, 0.028678265599800006, 0.011462531933960105, 0.04615776872794543, 0.06436887849122286, 0.06918344407209329, 0.06593553442507982, 0.09987709099160773, 0.027621964691206813, 0.016887120004477243, 0.024863475567794273, 0.044457485500190935, 0.03682640587378826, 0.03876294481701084, 0.07033656005348478, 0.045993400405028036, 0.036228691161211045, 0.028941035071121793, 0.06201963419360774, 0.018202658609620163, 0.042462660398866446, 0.018962159819368805, 0.01370271444985909, 0.005634406789405537, 0.02284158200823835, 0.08606903906911612, 0.02648352542226868, 0.023164627441604222, 0.0183968502429447, 0.027789520432374308, 0.03265455884060689, 0.019334203962768828, 0.028918789300535406, 0.02507919372458543, 0.06048674216227872, 0.026472044609753147, 0.01676521440302687, 0.032055629550346305, 0.0070771626529416865, 0.08051851405096905, 0.011006531804533941, 0.0316206241425659, 0.01888121398431914, 0.01765238706554685, 0.014498446036928465, 0.04124471039644309, 0.09316909379724946, 0.14866246283054352, 0.2070782889745065, 0.15712212531694345, 0.0731908990336316, 0.16523633205464908, 0.13064986866499695, 0.14305666434977735, 0.2092278879135847, 0.15370776424450533, 0.09084512492907898, 0.12028653547167778, 0.06106137311352151, 0.10494705036814723, 0.08342046583337442, 0.15716473731611455, 0.0797592672918524, 0.1306283591049058, 0.15108340792357922, 0.18888498736279352, 0.36442682785647257, 0.13754045963287354, 0.17002079103674206, 0.18015173955687455, 0.17466810452086584, 0.1702435812247651, 0.2390343706522669, 0.07508268859237432, 0.10094975986118827, 0.12382384708949498, 0.15508095627384527, 0.13311827049723693, 0.08204194730413811, 0.12470390700868197, 0.13465432450175285, 0.25046375021338463, 0.1389195006340742, 0.11031916138849088, 0.1200008722288268, 0.08111139759421349, 0.1113415847399405, 0.1322782305734498, 0.15064320154488087, 0.2438411127243723, 0.1790707925600665, 0.17022806991423878, 0.09239856300077268, 0.09321868792176247, 0.12614269980362483, 0.13158913754991122, 0.07801671472511121, 0.11753180543226854, 0.09999656065234117, 0.1352192863289799, 0.16013845774744237, 0.159812028120671, 0.15414607072515146, 0.303981462759631, 1.1297611317464282, 3.6347698739596774, 10.390802570751735, 22.142232656478882, 31.620685509272985, 45.49510901314871, 50.98617655890328, 53.97980792181832, 49.875764097486226, 48.123105321611675, 43.94755411148071, 33.24519518443516, 36.15850189753941, 39.95234339577811, 34.295849663870676, 29.366752420152935, 34.02849340438843, 28.27770393235343, 27.58914613723755, 20.076508896691458, 23.06444273676191, 21.061634915215627, 18.898308072771343, 15.20794609614781, 9.650518911225454, 9.910768900598798, 5.311853528022766, 4.010825054986136, 3.2457324181284224, 4.244884244033268, 3.232764256852014, 2.342442065477371, 2.133166015148163, 1.4006053869213377, 2.40149741087641, 2.0870551637240817, 1.8048482154096877, 1.8772751518658228, 2.79873417530741, 3.2454497132982527, 3.935960820743016, 4.885730496474674, 5.753722046102796, 6.572997169835227, 9.03400525024959, 11.524363824299403, 13.715547731944493, 19.914131232670375, 15.302894966942922, 19.94607036454337, 21.981143883296422, 30.158346789223806, 23.03200159754072, 33.423614501953125, 27.790418079921178, 28.35470039503915, 26.510370561054774, 38.25473519733974, 39.38263280051095, 42.12122706004551, 40.51874317441668, 35.114965847560335, 24.45082548686436, 15.705789736339025, 8.163065927369253, 1.904934627669198, 0.1485207440065486, 0.10813969333789178, 0.17113339847752027, 0.2493082865008286, 0.15147053929311888, 0.08921143652072974, 0.15894369328660624, 0.10125621341701065, 0.16520085824387415, 0.09559534503413097, 0.1578983422368765, 0.1491315205182348, 0.09376281193856682, 0.23797536747796194, 0.12850324170930044, 0.143242582944887, 0.1227926095681531, 0.12746589737279074, 0.19628523955387728, 0.16099130841238157, 0.1458219795354775, 0.0916513805942876, 0.3142423778772354, 0.20945302583277225, 0.145781063873853, 0.1397474083517279, 0.09730070709650006, 0.15055269854409353, 0.1241889125002282, 0.10692738196147339, 0.09192259782659155, 0.12115309254399367, 0.08256600025509085, 0.09751683407063995, 0.10845137839870793, 0.08154614176601171, 0.14030327780970506, 0.16376050481838839, 0.08014085503028971, 0.13074517569371633, 0.17156430892646313, 0.12255961421344962, 0.08368164074740239, 0.18843731709889003, 0.2660628360296999, 0.16109010311109678, 0.0792473533323833, 0.19259181059896946, 0.16964231777404035, 0.21042916631059988, 0.1013056311224188, 0.10319194490356104], [0.03448452368112547, 0.01859909947961569, 0.028934263291635683, 0.03523381293884345, 0.05498886467622859, 0.05272011838055082, 0.050371016575289626, 0.012098963006532617, 0.03933630690776876, 0.061557477207056115, 0.05524023475923708, 0.04051315804411258, 0.09666736251009361, 0.019951426557132175, 0.008028562047651835, 0.06702389102429152, 0.06135463594858136, 0.03570112679153681, 0.00997681844247771, 0.04005563205906323, 0.0885863293494497, 0.06435976576592241, 0.17801640342388833, 0.03465401494343366, 0.01401969462832702, 0.025729893540431346, 0.032694063149392605, 0.017347185406833887, 0.018628946538748484, 0.03254912467673421, 0.03390171638290797, 0.06251899525523186, 0.028148417959788015, 0.05002069573051163, 0.012051948163259243, 0.030616738367825747, 0.14332862118525164, 0.09303214507443563, 0.022703505220956037, 0.017551689076104333, 0.011098435980134776, 0.03718655190563627, 0.017375534599913017, 0.05371509159782103, 0.01511114789173007, 0.05280159008023994, 0.03992237117407577, 0.12579642981290817, 0.03627828528572406, 0.034307181768651517, 0.015197710300396596, 0.07143219054809638, 0.03417591577661889, 0.061452772468328476, 0.0382677126409752, 0.017730963117043887, 0.08680826904518263, 0.027430141145097356, 0.15525185210364206, 0.4124754395868097, 2.100413292646408, 5.7227039848055155, 11.247653552464076, 20.477386951446533, 34.11301129204886, 39.48000832966396, 39.55623354230608, 35.603889737810405, 37.060788018362864, 35.26921238218035, 30.025980131966726, 30.319180216108048, 20.760427032198223, 24.25438949040004, 17.68906443459647, 14.229765670640127, 21.396373067583355, 16.278712136404856, 18.311678613935197, 9.591533916337148, 19.220430033547537, 10.965668729373387, 9.172983118465968, 10.035928538867406, 9.140392592975072, 7.856282983507429, 3.652790895530156, 6.627857106072562, 10.564281719071523, 6.982470146247318, 3.3001913130283356, 4.59024315220969, 4.178731748035975, 3.3732229598930905, 4.570399097033909, 5.367086495671954, 6.679523042270115, 4.31926167011261, 4.357343443802424, 3.326179312808173, 8.208111098834447, 9.445992606026785, 10.766081724848066, 15.353502171380178, 18.431514195033483, 19.4142587184906, 16.252649443490164, 21.442248548780167, 17.12193509510585, 17.87638439450945, 18.005410705293926, 12.833054423332214, 19.012619835989817, 24.614816870008195, 24.742703676223755, 35.677346093314036, 33.92809888294765, 32.15331704275948, 24.195790120533534, 16.72525896344866, 10.457801444189888, 4.528634778090885, 1.3278894488300597, 0.15281889694077627, 0.03428103781438299, 0.07348439935594797, 0.0535560633455004, 0.042868841639054675, 0.017690815896328007, 0.020375919761136174, 0.12534695464585507, 0.027046432984726768, 0.00737043481785804, 0.036424207634159496, 0.0463859566620418, 0.03681956284812518, 0.02778475033119321, 0.07822955080441066, 0.020879436849749515, 0.038357208017259836, 0.0624647056683898, 0.003989171835460833, 0.011455992552717882, 0.04532598318266017, 0.10127282395426716, 0.02749784367292055, 0.0262383232225797, 0.027984151417123418, 0.013772954698652029, 0.034638642732586176, 0.06857831975711243, 0.07851135996835572, 0.05972087290138006, 0.020003553313602294, 0.029277751288775886, 0.08530588394829206, 0.03384299596239414, 0.002333027946796002, 0.02567415188864938, 0.07945615891367197, 0.04980250940259014, 0.041697201651654074, 0.06814466124134404, 0.015637752134352922, 0.018932212676320757, 0.024330281053802798, 0.027509036108053157, 0.004578973133383053, 0.07628684397786856, 0.037085331444229395, 0.024165717652067542, 0.052171621205551286, 0.05620358145928808, 0.050870706726397784, 0.005616291176660785, 0.0877444234543613, 0.004279754033112633, 0.039031933061778545, 0.028515810745635202, 0.054819302167743444, 0.011102217964694967, 0.018801640486344695, 0.06282130974744048, 0.01648054351764066, 0.03004463156685233, 0.012969573477416165, 0.07367719829614673, 0.06500374299607106, 0.08137169719806739, 0.00973338891552495, 0.02734156688010054, 0.0594416218144553, 0.052128439236964495, 0.08060426730662584, 0.006714240564698619, 0.004015639790200761, 0.02545904102069991, 0.02415318171759801, 0.01900159627465265, 0.01591381580302758, 0.045077795428889136, 0.022905593305560093, 0.026365947177899734, 0.022617260027410727, 0.04417557794866817, 0.026282293988125663, 0.05516685798232045, 0.041355165719453774, 0.025294552257816707, 0.049292125539588075, 0.035807588935962746, 0.01780406678361552, 0.0881383673154882, 0.05528577124433858, 0.0359919570785548, 0.013352535249266242, 0.02905904588156513, 0.06682719729308571, 0.028530704589294534, 0.046623545698821545, 0.030270648188889027, 0.009914584058736051, 0.018751544245917882, 0.06457532955599682, 0.06496049317398242, 0.03964236691328032, 0.004188747644158346, 0.0502908544481865, 0.019440591468342712, 0.03719008028773325, 0.060772602180285115, 0.01191279589797237, 0.06635410232203347, 0.0180403072320457, 0.0640918869259102, 0.7242012939282826, 3.040229891027723, 8.687220658574786, 15.18461925642831, 26.840003524507793, 40.36481278283255, 44.982821805136545, 42.68882540294102, 41.00515529087612, 42.9219583102635, 37.04136432920183, 32.81305544716971, 33.292071206229075, 23.40395951271057, 23.871667078563146, 21.135299716676982, 15.868990761893135, 22.19980021885463, 17.759038005556377, 26.483965669359478, 14.731577600751605, 23.195576088769094, 14.957114389964513, 12.30357129233224, 14.454602428844996, 10.784739375114441, 10.983694093567983, 5.5681838648659845, 8.794333219528198, 10.90905133315495, 7.3287879058292935, 3.602771899529866, 5.475913090365274, 5.31332003218787, 4.549253557409559, 5.500979585306985, 6.87936669588089, 7.124189078807831, 5.323299382414136, 6.255234769412449, 4.8683152709688455, 10.649228657994952, 12.853904230254036, 13.088620458330427, 20.58577537536621, 21.412496362413677, 23.690857580729894, 19.030686889375957, 23.226198537009104, 17.876533780779155, 20.727390084947857, 20.2711626802172, 18.575930765696935, 23.321762323379517, 28.717332090650284, 27.124249117715017, 40.433075359889436, 39.33415869304112, 36.407726832798545, 29.808699539729528, 21.504620790481567, 13.393492647579738, 5.824158975056239, 1.907587319612503, 0.27085375466517037, 0.017368698359600136, 0.08824638330510684, 0.022074445583192364, 0.06739881554884569, 0.07034623596285071, 0.05952653368668897, 0.05618611257523298, 0.04234214240152921, 0.026371714725558246, 0.03544330044782587, 0.011333885087099458, 0.005539545897460941, 0.031301600725523064, 0.025010327509205257, 0.04310759775606649, 0.013407442302975272, 0.05465090334681528, 0.022673929575830698, 0.013292886083945632, 0.046708440607679744, 0.06926648997302566, 0.010976215708069503, 0.06630927151335136, 0.018476018316245506, 0.12938089961452143, 0.03571093501523137, 0.06642097873347146, 0.05235549062490463, 0.02465626284746187, 0.044613436596202, 0.03867240449679749, 0.05297196004539728, 0.03256278697933469, 0.044136935379356146, 0.028297395412144915, 0.03184521584106343, 0.03296381813873138, 0.01821250415274075, 0.04980326936181102, 0.0051743150938169235, 0.06396062432655267, 0.04611745696248753, 0.07652026002428361, 0.06618632775332246, 0.04579561423244221, 0.08188367901103837, 0.022856574239475385, 0.05876139045826026, 0.05186268760423575, 0.07045348520789828, 0.02284835378772446, 0.12389429259513106, 0.17852537254137651, 0.07377576907830578, 0.07054940291813441, 0.19149589511965, 0.10548979017351355, 0.13445891998708248, 0.12758234755269118, 0.08778248926890747, 0.16822753154805728, 0.1548407141651426, 0.1204059576349599, 0.18173525030059473, 0.23774678260087967, 0.15295826803360665, 0.11819666118494102, 0.21498308623475687, 0.11958932716931615, 0.1441934954907213, 0.12903966435364314, 0.07501621930194752, 0.18889783881604671, 0.11409100863550391, 0.24706602681960377, 0.19145060969250544, 0.08285433014056512, 0.123297602470432, 0.14600236128483499, 0.07222982203321797, 0.10464989274208035, 0.05963516714317458, 0.11410911194980145, 0.16090149751731328, 0.08275013430310146, 0.15273262799850532, 0.087852514082832, 0.12082548226628985, 0.24617196193763188, 0.22400838908340248, 0.14661389775574207, 0.12317613113139357, 0.1578544003090688, 0.13778980768152646, 0.08227435911872558, 0.10522300377488136, 0.07325757188456399, 0.0925108062635575, 0.20765329312000955, 0.15313468713845524, 0.16112735468362058, 0.1637401216264282, 0.15305490499096258, 0.251797261514834, 0.1719558643443244, 0.08443191727357251, 0.12355602931763444, 0.052498647943139076, 0.17827610591692583, 0.1339512536568301, 0.2207187156059912, 0.8717833118779319, 2.9720854333468845, 9.265171817370824, 16.485301188060216, 30.80474465233939, 43.849876335689, 50.405664988926475, 50.19693415505545, 48.61650037765503, 48.52747310910906, 45.38709231785366, 41.17628247397286, 41.629252910614014, 30.889630794525146, 34.89614970343453, 27.60767698287964, 23.609424693243845, 34.274650709969656, 26.66778721128191, 30.604014669145855, 17.789505856377737, 29.36090898513794, 19.33942835671561, 16.864756209509714, 16.880792651857647, 16.181654487337383, 12.668891940798078, 6.779921472072601, 10.963145664760045, 14.36303733076368, 8.498729058674403, 5.279275596141815, 6.706327021121979, 6.2581082837922235, 5.130379608699253, 6.694737425872257, 7.986931698662894, 8.796356013842992, 6.5261532834597995, 7.489522320883615, 6.072836739676339, 12.435092006410871, 15.641934054238455, 16.008790254592896, 22.342227867671422, 27.468733855656215, 29.435494422912598, 25.443054301398142, 32.640597684042795, 26.288931471960886, 28.2633524281638, 27.856333902903966, 22.61020772797721, 28.997162103652954, 37.73240436826433, 35.233328410557334, 47.56649208068848, 44.235313756125315, 40.977452823093955, 32.89002759116036, 23.565069130488805, 13.64719135420663, 5.904523577008929, 1.9064497692244393, 0.3908398619719914, 0.11631858481892518, 0.14407035495553697, 0.10871627168463809, 0.1110083901190332, 0.1395381074398756, 0.1417159741478307, 0.15102680453232356, 0.11916452353554112, 0.1275874637067318, 0.18792095194969857, 0.14917372539639473, 0.08195879283760275, 0.1261051089635917, 0.16616459510156087, 0.10925132368824311, 0.12430179358593055, 0.19031456565218313, 0.11358394620141812, 0.08573101327887603, 0.15588025695511273, 0.20458071013646467, 0.1620885809617383, 0.1352392623999289, 0.10325802064367703, 0.20147528605801718, 0.06479567701795272, 0.14861621388367244, 0.2207045613655022, 0.10662341862916946, 0.11303444818726607, 0.1550056388867753, 0.1197980988238539, 0.08273877562688929, 0.11257024202495813, 0.14323126498077596, 0.15195593610405922, 0.22075801635427134, 0.10557638481259346, 0.15135468622403486, 0.08512825705111027, 0.09577423400644745, 0.2524303618286337, 0.22307251287358149, 0.1422937060041087, 0.17941991239786148, 0.11903227706040655, 0.09699074551463127, 0.21846968414528029, 0.1716178860515356, 0.14752058338906082, 0.06919990533164569, 0.22833460622600146], [0.04587236672107663, 0.028226569926898395, 0.03773116786032915, 0.03634724819234439, 0.07614202424883842, 0.020272594144833938, 0.024380719954414026, 0.02866640141499894, 0.0798481757353459, 0.034585981629788876, 0.0077014241999547395, 0.09565009602478572, 0.02494019752235285, 0.0026990380055004998, 0.05855981127492019, 0.043637421647352834, 0.09395393489726953, 0.022837332682684064, 0.0383933196509523, 0.07508106010832957, 0.02159410385814096, 0.0647696280585868, 0.03884524093674762, 0.025097787280433943, 0.025949196058458517, 0.05176866300670164, 0.014858042455411382, 0.026701009466445873, 0.007554500164198024, 0.009475184288541121, 0.025157513629112924, 0.03609266863869769, 0.009811951396321612, 0.023600492892520766, 0.026151307891788225, 0.017926433788878576, 0.02078803818273757, 0.03572445482547794, 0.024405240513650433, 0.06746742222458124, 0.006298149320563036, 0.037108065760029216, 0.06714350317737885, 0.013636122174960161, 0.02929823626098888, 0.028935817136828388, 0.008260577767422157, 0.009022364792014872, 0.03943176660686731, 0.04161155017625008, 0.041293547954410315, 0.038088280840643814, 0.040928696282207966, 0.15022610606891768, 0.04791846192841019, 0.04954098165035248, 0.0554317003781242, 0.03906479451273169, 0.03950385755992361, 0.0461208326742053, 0.3522016352840832, 1.2227955566985267, 4.725549331733158, 9.87943252495357, 20.216341393334524, 30.568985325949534, 39.51250852857317, 39.69183458600725, 38.5671192577907, 38.99506228310721, 38.6058589390346, 35.167817320142476, 29.77575465611049, 25.72907168524606, 22.182412351880753, 19.891480105263845, 20.530709164483206, 21.922014713287354, 12.002485002790179, 20.458545173917496, 15.544423035212926, 16.94479772022792, 14.595076765332903, 15.700140850884573, 16.384567941938126, 11.259280494281224, 13.679427521569387, 8.269283039229256, 16.048044102532522, 21.6309129851205, 12.426398941448756, 6.871311562401908, 6.021658480167389, 7.357685463769095, 7.894787294524057, 8.921023198536464, 10.818490249770027, 8.582274198532104, 8.875687071255275, 11.690800104822431, 11.223388705934797, 13.296674711363655, 19.860338279179164, 16.225624425070627, 25.097315413611277, 22.882453782217844, 21.89443036488124, 21.964049577713013, 22.786156960896083, 18.048098700387136, 18.198118993214198, 24.422614063535416, 21.252274377005442, 30.406932490212576, 33.99437427520752, 29.69956418446132, 26.889837741851807, 21.193357127053396, 12.906482986041478, 7.889870575496128, 3.6858699662344794, 1.104133135506085, 0.1903658900409937, 0.010293328735445226, 0.01534108305349946, 0.00863581950709756, 0.043363130651414394, 0.012989249296619423, 0.02569865039549768, 0.05414444820157119, 0.07722581430737462, 0.054636888206005096, 0.018940416164696217, 0.02694385714962014, 0.007293805313695754, 0.012302596454641648, 0.07236114570072719, 0.08320172649941274, 0.02503236463027341, 0.03155790036544204, 0.024259304594514624, 0.022838701627084186, 0.017544499997581755, 0.02375971113464662, 0.041069298916097195, 0.04944134896088924, 0.03890471453113215, 0.005235732266945499, 0.06602766590991191, 0.10477875332747187, 0.03699819736980966, 0.08830874067332063, 0.09149888663419656, 0.04471180721053055, 0.11237223872116633, 0.040339717707995854, 0.02377096124525581, 0.054583155017878325, 0.07054606452584267, 0.04494862950273922, 0.05592677988378065, 0.017778882956398383, 0.013124440613734936, 0.07756505467529808, 0.012068530710946237, 0.0471341840124556, 0.012457006427991604, 0.05703329068741628, 0.07874134262757641, 0.03595297524173345, 0.052994192245283296, 0.03810421623555677, 0.039603856658296924, 0.011779741966165602, 0.012065831837909562, 0.029918498692235777, 0.11198256284530674, 0.07950166825737272, 0.02340075932443142, 0.01632189524493047, 0.07580305529492241, 0.016914410682927285, 0.01673034279208098, 0.01732892942215715, 0.029591716227254698, 0.04636939701491168, 0.012520189064421823, 0.07730297052434512, 0.037983260583132505, 0.03893388814425894, 0.07378779950418643, 0.02612087898887694, 0.026355840398796966, 0.061175618054611344, 0.020317723508924246, 0.057969526520797184, 0.005572493013460189, 0.05317580553569964, 0.06268305145204067, 0.044635767183665714, 0.01571713055350951, 0.0413974248804152, 0.016662692850721732, 0.019424489832350185, 0.03446897505117314, 0.04180784017911979, 0.04232320788183382, 0.01850314953896616, 0.009734813839064112, 0.046811048673199754, 0.02355685630547149, 0.01046373347552227, 0.026614392774977853, 0.01643448286423726, 0.09200493805110455, 0.04881755814754537, 0.014601050709773387, 0.043356080672570636, 0.04672590270638466, 0.08389395435473748, 0.05623045823137675, 0.047797217898602994, 0.03463732298197491, 0.013055800859417235, 0.06394290777721576, 0.012117979798599013, 0.04087132953905633, 0.0038142522930034567, 0.0333019762433001, 0.08250290328370673, 0.06011395502303328, 0.012072159176958459, 0.03141123162848609, 0.039434836977826696, 0.04837228650493281, 0.02603107487915882, 0.36664064334971563, 1.9683217406272888, 6.115823941571372, 12.67447829246521, 25.027866431644984, 37.1349252973284, 44.82347181865147, 43.53716223580496, 43.68134430476597, 43.19744048799787, 41.05636698859078, 39.2977431842259, 32.38500125067574, 29.837308747427805, 21.943489858082362, 22.533767121178762, 21.081911495753697, 24.652734926768712, 19.65599696976798, 19.43747786113194, 20.924234288079397, 20.640219722475322, 19.374624456678117, 21.49466402190072, 21.278660161154612, 16.692420039858135, 15.72665170260838, 12.012896009853907, 19.391737869807653, 23.22084321294512, 14.871229444231306, 9.817126291138784, 9.123043809618268, 10.70997415270124, 11.33218012537275, 10.771039264542715, 13.655200021607534, 9.905841759272985, 11.218373843601771, 12.519146101815359, 15.906347751617432, 20.83086439541408, 23.272117444447108, 19.224543367113384, 30.756902830941335, 29.175736018589564, 22.676747151783534, 23.644957780838013, 22.744061299732753, 21.88209731238229, 22.13050409725734, 24.426348720278057, 23.064859628677368, 33.94892610822405, 38.476966381073, 35.21655545915876, 31.205308301108225, 25.685348408562795, 16.534419740949357, 10.227031792913165, 4.813748896121979, 1.6421278097799845, 0.22572018365774835, 0.023737117614863173, 0.013565310260414012, 0.024452882153647285, 0.018292343975710015, 0.029637493592287813, 0.05138087685086897, 0.012185736609223698, 0.021266096637451222, 0.005703652136227382, 0.02243143303452858, 0.053153128895376406, 0.021742692849199687, 0.0196705520751753, 0.01691195777883487, 0.029509810265153646, 0.07348756132913487, 0.06550372152456216, 0.016601826563211422, 0.08154453363801752, 0.08431940938213042, 0.02910823967041714, 0.019276570894622376, 0.028936577096049274, 0.05004842745672379, 0.013733428337478211, 0.02791474407006587, 0.005161511138015027, 0.026808577622952204, 0.08225593010761909, 0.021225094462611845, 0.0492847329005599, 0.029482017470789806, 0.031610273090856414, 0.038798863068223, 0.03713089167805655, 0.11308003216981888, 0.03849604306742549, 0.0611448668475662, 0.021925152612051794, 0.033771244276847155, 0.016484682581254413, 0.021453116155628647, 0.04779756395146251, 0.0240437696421785, 0.02333036301258419, 0.051699757775557895, 0.00437961657631344, 0.05251726694405079, 0.006825305721057313, 0.03600765159353614, 0.03244745298953993, 0.03939892551196473, 0.00648081603659583, 0.1317688136228493, 0.1821150127798319, 0.1454115201319967, 0.15997095459273883, 0.234994183161429, 0.07095347052173955, 0.07752738241106272, 0.09607375293437924, 0.10335710032710008, 0.1362197319311755, 0.11311555347804512, 0.21877317928842135, 0.10525788726019007, 0.1089211485481688, 0.18352789910776274, 0.11775683478585311, 0.20354663633874484, 0.15202680230140686, 0.1521350150661809, 0.1500760955469949, 0.12270718200930528, 0.20122557160045418, 0.10079276042857341, 0.14450687010373386, 0.12020646833947726, 0.1298410277813673, 0.06454704821641956, 0.08941414885755096, 0.08586867446345942, 0.06500180238591773, 0.07895895559340715, 0.12371249949293477, 0.11405689189476625, 0.17272187609757694, 0.19508416471736773, 0.13710568153432437, 0.08697339732732091, 0.08494826885206358, 0.17493883999330656, 0.15510239798043454, 0.10368078188704592, 0.07921352836170367, 0.15724181889423303, 0.15414000462208474, 0.1800000462681055, 0.12354175294084208, 0.07237505566860948, 0.1326852294483355, 0.17705877338136944, 0.11918865224080426, 0.16189929683293613, 0.1824803224631718, 0.155241334810853, 0.19092256017029285, 0.10164749063551426, 0.09456946115408625, 0.1949123732213463, 0.14913218548255308, 0.1078180813097528, 0.16084709257951804, 0.5394536874123982, 2.0024234993117194, 6.948961590017591, 14.48397854396275, 28.03413830484663, 40.98831980569022, 50.32724067143032, 50.558056354522705, 50.450352328164236, 51.283483028411865, 50.041923318590435, 45.75579152788435, 40.64375168936593, 38.60914543696812, 33.682764938899446, 31.04654196330479, 30.77162606375558, 34.04251834324428, 21.797178166253225, 31.052510465894425, 27.193314211709158, 28.251580442701066, 24.63822708811079, 23.978695392608643, 24.147870131901332, 19.587487731661113, 21.050291981015885, 13.402179632868085, 22.734731606074742, 29.104833126068115, 17.722393206187657, 12.503391930035182, 11.765287399291992, 13.158043384552002, 12.942697865622383, 13.51664251940591, 17.478051117488317, 14.514636601720538, 16.07016542979649, 18.418170179639542, 18.53351375034877, 23.31194625582014, 28.3436336517334, 23.251502139227732, 35.932053157261436, 32.08532197134835, 32.17747245516096, 30.48178890773228, 31.837059361594065, 27.85388466290065, 29.33075032915388, 36.34959820338658, 30.542057582310267, 43.01478624343872, 43.93497787203108, 40.14332158224923, 36.56704207829067, 28.5593387399401, 18.21371943610055, 10.944325600351606, 4.823559318270002, 1.7614913476364953, 0.39962222214256016, 0.10066106356680393, 0.10373992299927132, 0.09050123659627778, 0.16262745990284852, 0.15952861761408194, 0.16387133672833443, 0.16856777614780835, 0.1404397447726556, 0.19454285662089074, 0.10813532357237168, 0.08367503860167094, 0.12504208886197635, 0.068709765560925, 0.10526504580463682, 0.1510816573032311, 0.18149982579052448, 0.11084797086992434, 0.15631848201155663, 0.09079519153705665, 0.08491991287363426, 0.09746882771807057, 0.11615226231515408, 0.10380210394838027, 0.13603738243026392, 0.16848697619778769, 0.18342297045247896, 0.27043873550636427, 0.1354232132434845, 0.17074257587747915, 0.15669935728822434, 0.1549554272953953, 0.23241062036582402, 0.11999237697039332, 0.15628839576882975, 0.1723313249115433, 0.3029951713979244, 0.16450700190450462, 0.11734097424362387, 0.08792794003550496, 0.1368021863911833, 0.10511432282094445, 0.1794971025415829, 0.14109139623386519, 0.10992835235915013, 0.10418221248047692, 0.15106264475200856, 0.09485492083643164, 0.13821975461074285, 0.1497475488909653, 0.1233524823827403, 0.08819634813283171, 0.10138515542660441, 0.13134664270494664], [0.08639333131057875, 0.024467182279165302, 0.04876901914498635, 0.03358330364738192, 0.09237203228154353, 0.023142030529145683, 0.09248958168817417, 0.053187289740890265, 0.014791009980919105, 0.039955096918025186, 0.011810909624078443, 0.028930310825152055, 0.03869312695626702, 0.02725510625168681, 0.04466195185003536, 0.0715801790356636, 0.018427866078647118, 0.04947442075769816, 0.06179828928517444, 0.037041145243815014, 0.06084316982222455, 0.016911733862278715, 0.06496387227837529, 0.030906415145312036, 0.023555421203907047, 0.035111347546002696, 0.03437775280326605, 0.022262238631291047, 0.07161242980509996, 0.02942143447164978, 0.05888277358774628, 0.013869176901477789, 0.043162012871887, 0.015611038210668733, 0.014564788102039268, 0.037543522393597026, 0.04554197784247143, 0.033587161118962934, 0.01293557123946292, 0.04438537758375917, 0.05982268029557807, 0.061357533293110986, 0.05327199126726814, 0.032970369394336424, 0.048731869352715354, 0.08550989228699889, 0.10781189307038273, 0.010260692897385784, 0.016143552493304014, 0.05889966232436044, 0.019010664895176888, 0.04639040445908904, 0.04423736195479121, 0.03849696248237576, 0.0442682895809412, 0.027765849738248756, 0.02674598616015698, 0.03662438564268606, 0.08477366822106497, 0.027992644979219352, 0.06502162917916264, 0.09024113376757928, 0.8324447827679771, 2.894674684320177, 7.09553644486836, 15.088881765093122, 24.88672419956752, 33.5939495904105, 36.730411597660606, 44.822130816323416, 44.34737777709961, 41.26050158909389, 38.98226717540196, 32.997325147901265, 34.260670934404644, 21.40357140132359, 25.99429484776088, 21.90844314438956, 19.188933849334717, 23.717818328312465, 28.637214149747575, 22.97693886075701, 18.357034717287334, 18.83960795402527, 14.287765758378164, 14.194010240691048, 11.853964652333941, 10.867592300687518, 12.212388345173427, 27.7267621585301, 37.30716071810041, 16.094986132213048, 9.527376856122698, 10.977522356169564, 14.187878455434527, 21.164304971694946, 16.4590265750885, 16.357678413391113, 20.36177240099226, 12.844257525035314, 16.300286293029785, 17.64820555278233, 33.04950264522007, 30.21445001874651, 31.948796817234584, 23.27179261616298, 21.434539522443497, 19.339263336999075, 18.036710602896555, 17.86898456301008, 22.218675000326975, 25.094794954572404, 35.524166107177734, 31.196511881692068, 29.662905488695415, 27.22196684564863, 17.99533408028739, 10.614854182515826, 5.025335005351475, 1.6648853314774377, 0.4713935852050781, 0.0718871686341507, 0.030009395243333917, 0.05201254206310425, 0.03335696132853627, 0.008443973908599998, 0.09829615868095841, 0.03603943756648472, 0.08300977572798729, 0.07363013510725328, 0.05708205021385636, 0.016745782856430327, 0.10593982173928193, 0.10434459269578968, 0.01237875098429088, 0.025995850430003235, 0.00372067468041288, 0.02631008338981441, 0.028396646425660168, 0.04533840037350144, 0.057358783935861926, 0.04504439114992108, 0.020717099042875425, 0.04979508962216122, 0.0013999447567454937, 0.032538878797952614, 0.03316271710874779, 0.02567641480293657, 0.03762828159545149, 0.03245813652340855, 0.07717440170901162, 0.05943776773554938, 0.010768651845864952, 0.07142523556415524, 0.052492001692631414, 0.04183073055797389, 0.05178109037556818, 0.07457932417414018, 0.08502326732767479, 0.012880694719829729, 0.04117027171222227, 0.056990956887602806, 0.019428767995642762, 0.0716975045257381, 0.054062559202845605, 0.14517528137990407, 0.011092306264410061, 0.024534421706838266, 0.031311239315462966, 0.0251904598969434, 0.05384444072842598, 0.0065602114191278815, 0.06936944409140519, 0.02314813225530088, 0.04290852575962033, 0.06958317583692925, 0.040621157070355754, 0.019144285403724228, 0.04002398857846856, 0.03368303472442286, 0.03397292184776493, 0.027903458336368203, 0.08180757452334676, 0.03927249747461506, 0.03565884388184973, 0.016315844408901672, 0.017697947299374, 0.017508298457999314, 0.005105192731467209, 0.008409241397332932, 0.028041876087497388, 0.050679990888706276, 0.018641762368913208, 0.03723705526707428, 0.03954530247886266, 0.06794555871082203, 0.07488267682492733, 0.01807425942804132, 0.07485245487519673, 0.03399905562400818, 0.021088422242818133, 0.032566943006323915, 0.04470685729756951, 0.011076675362086721, 0.01400410698261112, 0.016741172210978608, 0.04422845957534654, 0.02607121192184942, 0.05904776616288083, 0.04390217922627926, 0.04806141568613904, 0.024710289501984204, 0.009540243922466678, 0.014362650823646357, 0.03277698012867144, 0.016518083467547382, 0.012291602491001998, 0.08093898184597492, 0.03303492860868573, 0.021335595586736287, 0.00994884583633393, 0.06434864457696676, 0.030406005747084106, 0.06491394567170314, 0.027850201819092035, 0.035052413386957984, 0.036732072542820654, 0.029108768927731683, 0.023674675429772054, 0.031047055098627294, 0.005087432925522859, 0.05263691980923925, 0.02963257421340261, 0.02006835171154567, 0.07773661546941314, 0.03475021763837763, 0.11459674792630331, 0.1917527477656092, 1.2631940117904117, 4.385611755507333, 10.311955281666346, 19.234135355268204, 29.718008177621023, 39.11805234636579, 42.28598621913365, 47.872539384024485, 48.83991970334734, 44.27875736781529, 41.13476003919329, 35.178920541490825, 36.89878382001604, 24.412907430103846, 27.461886405944824, 23.18972396850586, 19.748414959226334, 26.148522274834768, 30.61948135920933, 26.657026188714163, 21.664679493222916, 19.959400483540126, 18.75578488622393, 16.495171104158672, 18.767296314239502, 16.93680555479867, 20.92420996938433, 35.44769423348563, 42.253128187997, 19.296822002955846, 15.826188121523176, 17.068830013275146, 19.279058933258057, 23.665010281971522, 19.235236644744873, 23.190594230379375, 23.037659168243408, 20.428320510046824, 19.848932811192103, 22.40419363975525, 39.34478596278599, 27.908045870917185, 32.28517300742013, 26.808682782309397, 22.814632415771484, 22.74382332393101, 22.853177547454834, 21.90835108075823, 24.833139692034038, 30.364322662353516, 35.938740798405235, 35.1910069329398, 33.34045498711722, 31.306870119912283, 21.685032503945486, 13.35440903050559, 6.752136928694589, 2.877201267651149, 0.7636791669896671, 0.14855199732950755, 0.04539758898317814, 0.057324904682380814, 0.05299681817580547, 0.037062325714422126, 0.021527788934430907, 0.05912663907344852, 0.033248198950397115, 0.013307959739384907, 0.01992453621434314, 0.05714479434703078, 0.050798700590218814, 0.0595631135095443, 0.041637921439749856, 0.026722890524459735, 0.017401982198602388, 0.03591900099334972, 0.02497314039750823, 0.03639048444373267, 0.029123924007373195, 0.040482406837067435, 0.025242020076672946, 0.02159579680301249, 0.012727685921293284, 0.04275880700775555, 0.062041123397648335, 0.01669927267357707, 0.05607324166755591, 0.01412036462820002, 0.0775540963347469, 0.01870784319804183, 0.008967568000246371, 0.05120248660179121, 0.02370526209207518, 0.041377136683357615, 0.036367970651813915, 0.02439711844947721, 0.01589556660370103, 0.06984195552234139, 0.051356849925858636, 0.04324655833521059, 0.030552928934672048, 0.013375848864338227, 0.047299641384077926, 0.09597420506179333, 0.024679153226315975, 0.014660758398739355, 0.05449297432122486, 0.037323012083236656, 0.032841800579002926, 0.03603571240923234, 0.05346612013610346, 0.04471296750541244, 0.026972079117383276, 0.06597693184656755, 0.18254973659557955, 0.19883852611695016, 0.13758033035056932, 0.20996548262025627, 0.30944353395274704, 0.11943092995456286, 0.29065959474870134, 0.30180778939809116, 0.06808421734188284, 0.07825286526765142, 0.06560618709772825, 0.12225660761552197, 0.08492739711488996, 0.16634285982166017, 0.19722449486809118, 0.2196384064321007, 0.08213137821959597, 0.19911376706191472, 0.15121739144836152, 0.17546849085816316, 0.15751404714371475, 0.09513075889221259, 0.1379352720188243, 0.11936538347176143, 0.08071414248219558, 0.09399508804615055, 0.12087539530226163, 0.08136276767722198, 0.12021104166550295, 0.09486055267708642, 0.20434918041740144, 0.06912321051848785, 0.2684083958821637, 0.09749279357492924, 0.18770323720361504, 0.14775196383041994, 0.13520096588347638, 0.13575694390705653, 0.11044719416115965, 0.2007565681955644, 0.1611989808401891, 0.17847780723656925, 0.08911167151693787, 0.13474892585405282, 0.05533482254083667, 0.23958591105682508, 0.24278115960104124, 0.12767580896615982, 0.08799926763666527, 0.1228071709296533, 0.1468853796167033, 0.10775027530533926, 0.12288826943508216, 0.14425297587045602, 0.13597948982247285, 0.11730351911059447, 0.11754975946886198, 0.1266480998269149, 0.18368713770593914, 0.16386945040098258, 0.25940458902290886, 0.2345664889684745, 1.1997467534882682, 4.338826928819929, 11.963943345206124, 21.404914140701294, 33.458362443106516, 44.221156801496235, 48.537989207676475, 56.07071542739868, 56.56207466125488, 53.07506561279297, 49.59848233631679, 44.49113948004586, 47.87596832002912, 31.907468932015554, 37.606530802590505, 32.75544098445347, 29.99124608721052, 36.620734282902305, 40.58799239567348, 34.27483136313302, 30.355050291333878, 30.118002074105398, 26.401327269417898, 24.501168659755162, 22.74044476236616, 22.431911740984233, 21.71831611224583, 38.325276783534456, 48.817848750523154, 26.020817858832224, 19.48760563986642, 20.53251917021615, 23.345280238560267, 29.845670904432023, 24.846532344818115, 25.328433343342372, 31.095752579825266, 22.76259388242449, 24.933435201644897, 29.19849831717355, 45.16761956896101, 40.4974365234375, 42.79003633771624, 33.23498828070504, 33.92676135471889, 28.461051259722026, 29.2255893434797, 29.327481201716832, 31.83314405168806, 36.952319690159385, 45.225011689322336, 41.57603318350655, 37.92510223388672, 37.18767602103097, 24.347170523234777, 14.84138172013419, 7.285915783473423, 3.242245290960584, 0.8549362644553185, 0.16508784145116806, 0.10966939625463315, 0.11085970952574696, 0.12667882389255933, 0.17454794953976357, 0.21008869100894245, 0.16667773042406353, 0.18741074789847645, 0.190742056284632, 0.13665331580809184, 0.18389552938086645, 0.2520471523915018, 0.28415157539503916, 0.10348553343542985, 0.09003774289573942, 0.07349606337291853, 0.07851631327399186, 0.20303096329527243, 0.12515488852347645, 0.11573722958564758, 0.10738976964993135, 0.15022134275308677, 0.11041682293372494, 0.09143818489142827, 0.15703832624214037, 0.1452263614961079, 0.12304818656827722, 0.09733814865882907, 0.10290316039962427, 0.17360697074660233, 0.10895774872707469, 0.16541879012116364, 0.18517027954970086, 0.10664637346885034, 0.20658602538917745, 0.13674675008015974, 0.16211978000189575, 0.22957887660179818, 0.16646718100777694, 0.09549569538129227, 0.16348742161478313, 0.07433050538280181, 0.16236679389008454, 0.16110534300761564, 0.3271486296185425, 0.09295089729130268, 0.0932594882324338, 0.1537741113986288, 0.09504378427352224, 0.12797667139342853, 0.09829674900642463, 0.23778803753001349, 0.14724382252565452, 0.1316304060497454, 0.1792296783200332], [0.023249876885009662, 0.02424815117514559, 0.02596514841674694, 0.021929116952898245, 0.029556859883346727, 0.02597805584913918, 0.003475060694784458, 0.07035610864737205, 0.06895770904208932, 0.027047623813684498, 0.041932392067142894, 0.12193287855812482, 0.020324703937928592, 0.06872729890580688, 0.04447706123547895, 0.0538556263782084, 0.041938305499830415, 0.01768232572690717, 0.03399620916960495, 0.0058366059841189, 0.05277294911710279, 0.012824279622041752, 0.03495634639901774, 0.026020304832075323, 0.07593713381460734, 0.04690537861149226, 0.016452053528545157, 0.03346968635118433, 0.07591721202645983, 0.014375746549506272, 0.055828219279646873, 0.019878071832603643, 0.04323071454252515, 0.056800098557557376, 0.043146820472819467, 0.04155635813783322, 0.0471837340321924, 0.03384882118552923, 0.027773118544636027, 0.03671259180243526, 0.0430768194076206, 0.04259781100388084, 0.029265276422458034, 0.03555869889844741, 0.048267961745815616, 0.003988129011954048, 0.056056230794638395, 0.017362087732180953, 0.02856903842517308, 0.08028707254145827, 0.06860787674252476, 0.013404472015931137, 0.016988328591521298, 0.022404948116413186, 0.11311091908386775, 0.032765210938772986, 0.040662466282291074, 0.0565708622868572, 0.06511375387864453, 0.03005255007051996, 0.1087281189060637, 0.030850212089717388, 0.08434705289879016, 0.3117313097630228, 1.6959280371665955, 6.480668204171317, 12.070708496229988, 17.394135986055645, 29.566002437046595, 32.66192517961775, 41.83597918919155, 44.821786880493164, 48.15646014894758, 39.25581080572945, 37.546057156154085, 32.361175877707346, 34.42111873626709, 27.217924731118337, 25.176919187818253, 28.60798134122576, 24.203037091663905, 20.50148504120963, 22.22636318206787, 23.00455447605678, 20.835022892270768, 17.32686526434762, 21.382476670401438, 14.058226806776863, 12.101642744881765, 15.511526788984026, 50.51300423485892, 47.16701235089983, 23.7142174243927, 15.708414418356758, 23.759894881929668, 22.1792665549687, 20.22400525638035, 14.49402563912528, 17.054407290049962, 18.504037754876272, 23.73594617843628, 22.08698752948216, 19.023127249308995, 22.74910569190979, 39.03090109143938, 27.769373723438807, 21.602995123182023, 22.455085720334733, 21.80725131716047, 30.437237058367046, 28.570900542395457, 30.563840184892925, 35.96557126726423, 29.365936006818497, 23.16488936969212, 14.696935619626727, 7.69026620047433, 1.8859132826328278, 0.679146514407226, 0.0847623095448528, 0.011589959114124733, 0.07786196124340806, 0.029618229983108382, 0.020509491075894663, 0.0666989338185106, 0.061218867876699994, 0.054739662512604675, 0.013638726053094226, 0.10119285181696926, 0.08860240384404149, 0.04635375339005675, 0.028525944666138718, 0.0065682575721958915, 0.10847856729690518, 0.037845232989639044, 0.04384154872968793, 0.07136708511305706, 0.07491881560002055, 0.015659687475168278, 0.06363547034561634, 0.05175506855760302, 0.03546580406171935, 0.0445630825124681, 0.05241201598463314, 0.027659574190952947, 0.05338710473318185, 0.015696370774613957, 0.028863074790154184, 0.036817459389567375, 0.019759329900677716, 0.04656530025282076, 0.03649328928440809, 0.02207776701210865, 0.042673138568976095, 0.03166427430031555, 0.005315357927299503, 0.030619537324777672, 0.07445644826761313, 0.031915773304977586, 0.008647242644136506, 0.026798521733975837, 0.030163700891924754, 0.024895137708101953, 0.030897746860448803, 0.029056416558367864, 0.04666465135025127, 0.08689804601350001, 0.006645435417470123, 0.05014884724680867, 0.0476636754215828, 0.011931280040049126, 0.05773017329296895, 0.031997465528547764, 0.023977900855243206, 0.047156657092273235, 0.0569447215114321, 0.015042125613295605, 0.00768304947164974, 0.02574503335303494, 0.014172328536265662, 0.0261024737264961, 0.05624931811222008, 0.03847915433081133, 0.03625096407319818, 0.04902192610981209, 0.046177816045071395, 0.0061661191284656525, 0.009361302363686264, 0.04859829634161932, 0.10216522642544337, 0.0807071060740522, 0.01758707467732685, 0.07205438001879624, 0.1187099457851478, 0.024478600327191607, 0.04258679159517799, 0.030921387020498514, 0.06658743015889611, 0.029397068279130117, 0.01883671565779618, 0.10779953016234295, 0.08896037856382982, 0.032487415309463225, 0.04709500879315393, 0.005341063802396613, 0.018750171908842664, 0.024257587900917445, 0.02661670827572899, 0.027845628493066345, 0.07090191543102264, 0.014166253951511212, 0.058720902273697514, 0.009569712698326578, 0.03780506371653505, 0.02905638941696712, 0.07021754501121384, 0.04492752706365926, 0.04149290493556431, 0.0667475847793477, 0.00984264153521508, 0.024076632789469192, 0.013925898188192929, 0.044694830264363966, 0.06437641701528005, 0.028497039074344293, 0.022553789861766354, 0.07263489386865071, 0.005956529415146048, 0.025972961747486676, 0.018408444710075855, 0.06495885111923728, 0.030470076416219984, 0.05131439059706671, 0.06737737384225641, 0.005175902017591787, 0.09402210731059313, 0.07205657847225666, 0.04554259191666331, 0.11398175092680113, 0.5960435079676765, 2.473459686551775, 8.72491897855486, 15.357476540974208, 22.82776277405875, 33.988197326660156, 40.90359347207205, 45.36134924207415, 49.78899151938302, 52.175954818725586, 43.79034764426095, 40.559817450387136, 36.81957088197981, 38.20862695149013, 29.809998852866038, 23.662217106137955, 32.29318428039551, 28.035807609558105, 23.882579224450247, 24.893552541732788, 25.04046698978969, 26.80994040625436, 17.576722485678538, 23.113219090870448, 20.676313877105713, 15.768705674580165, 26.0664119379861, 60.84156744820731, 50.24425138745989, 25.922184705734253, 18.995414359228953, 25.927203042166575, 28.59739749772208, 29.375246592930385, 21.797563791275024, 26.805299009595597, 22.112044470650808, 25.61215434755598, 23.973736115864344, 26.392853941236222, 28.328278132847377, 40.75186913354056, 28.920486995152064, 26.717927149363927, 26.762209756033762, 24.44393287386213, 34.12192235674177, 32.85365377153669, 33.20890474319458, 41.32993493761335, 33.39304937635149, 27.835251331329346, 18.574739149638585, 10.677446160997663, 3.493970057794026, 1.1339692430836814, 0.150132061115333, 0.036432495939412286, 0.04848107263179762, 0.03132520356614675, 0.01594928282845233, 0.012523131361896438, 0.0344796382289912, 0.09410504464592252, 0.1138435604849032, 0.1128426602642451, 0.08465735374816827, 0.03223257451983435, 0.01858607499993273, 0.015496867908430951, 0.01584648646946464, 0.04385814230356898, 0.057206262834370136, 0.13002709565418108, 0.0591560671372073, 0.03619611469496574, 0.0821453221142292, 0.026119805207209926, 0.03094546144296016, 0.032076209517461915, 0.026184238892580782, 0.022899700228923132, 0.007661307513314698, 0.014798485740487064, 0.0455284885663007, 0.020302542984219532, 0.0557364338476743, 0.04361224799816098, 0.013836083052280759, 0.02558799320831895, 0.0370734299400023, 0.022717525450778858, 0.03590171531374965, 0.026576589892751405, 0.043182379100471735, 0.052087153773754835, 0.03844113940639155, 0.023845805354150276, 0.026940225290932825, 0.020459511882758567, 0.0548693746594446, 0.05275656249640243, 0.03354412164273007, 0.06348043187920537, 0.02293976941811187, 0.008445921304103519, 0.10195259390664951, 0.00395248259883374, 0.04334645565333111, 0.027634839893185666, 0.009898170296634947, 0.032244628694440634, 0.03055614179798535, 0.08866617256509406, 0.11842421468879495, 0.10313504295689718, 0.11659070450280394, 0.12464944778808526, 0.23288260932479585, 0.1438204776495695, 0.11799890893910613, 0.16890917425709112, 0.15246149897575378, 0.09712711748267923, 0.18933233192988805, 0.11516161475862775, 0.2727501786180905, 0.14971724551703247, 0.14921514317393303, 0.15764436657939637, 0.17396515581224645, 0.258533485765968, 0.12475014238485269, 0.18210669394050324, 0.12925115014825547, 0.10100221740347998, 0.08701650465705565, 0.2380311159150941, 0.18236353301576205, 0.19775289722851344, 0.26914514920541216, 0.16809685927416596, 0.17494912658418926, 0.2858918820108686, 0.11236100896660771, 0.12944204919040203, 0.18784893224281923, 0.17011688516608306, 0.28589155631405966, 0.1846021150371858, 0.12107459961303643, 0.1084700245410204, 0.20126821074102605, 0.09687420033982821, 0.10841870693756, 0.18956667078392847, 0.12592320729579243, 0.11424156198544161, 0.09512754942157439, 0.1053338831822787, 0.17531381201531204, 0.12926727214029857, 0.11875384700085435, 0.17467406205832958, 0.11027586406895093, 0.08138336121503796, 0.10719885703708444, 0.15686193427869252, 0.08437946651663099, 0.1235121281019279, 0.15254932854856762, 0.15684042471860135, 0.17807162260370596, 0.1694163249007293, 0.14466012402304582, 0.19300411561770098, 0.7093545677406448, 2.364806362560817, 9.380384240831647, 15.39595913887024, 26.428840398788452, 37.98609699521746, 44.97637735094343, 52.23082821709769, 57.14416694641113, 60.2154027393886, 52.33540555409023, 50.48368283680507, 47.17928286961147, 47.766763482775005, 37.37230702808925, 35.06194067001343, 41.87812001364571, 34.462575163160054, 31.9076634815761, 33.514014039720806, 35.331249373299734, 31.86299351283482, 28.179732595171245, 35.91588469914028, 26.44126204081944, 22.408174957547867, 26.725681338991436, 66.97258145468575, 60.75069890703474, 34.29793759754726, 25.58615071432931, 36.05319847379412, 33.007830824170796, 31.262196677071707, 24.986090387616837, 28.544792686189922, 30.215891769954137, 34.86726604189192, 32.35602378845215, 29.932721410478862, 36.4936968939645, 49.816756520952495, 37.31590502602713, 34.66650479180472, 34.880898407527376, 31.627230712345668, 43.173840931483674, 39.52028356279646, 41.12187113080706, 48.68157025745937, 38.75099638530186, 30.900872979845317, 20.438541310174124, 11.502006258283343, 3.677903422287532, 1.3314720051629203, 0.23247909811990602, 0.09874766266771726, 0.185050138139299, 0.11808645352721214, 0.0984645439311862, 0.17137925885617733, 0.1729225596146924, 0.15599923128528254, 0.20145357293742044, 0.1732072186257158, 0.20893096098942415, 0.16600615717470646, 0.10866723395884037, 0.09782147593796253, 0.2778603344091347, 0.11061087716370821, 0.08323038103325026, 0.2762599688555513, 0.1838669901979821, 0.1280364774699722, 0.22316250018775463, 0.14935209868209703, 0.0665097175432103, 0.10679979023656674, 0.14537388857986244, 0.1459560173430613, 0.12654261477291584, 0.15763654985598155, 0.2165750650955098, 0.12069407717457839, 0.13737020162599428, 0.15830158202775887, 0.13256352740739072, 0.09993611675287996, 0.11635511714432921, 0.14326847584119864, 0.0836590523166316, 0.08683837564396006, 0.15863500056522234, 0.11096040412251439, 0.10261341916131121, 0.05371056916192174, 0.16329323846314633, 0.08144064992666245, 0.17010784707963467, 0.1848145236394235, 0.11969433724880219, 0.14649002440273762, 0.07866889544363533, 0.07717502596122877, 0.20615913186754498, 0.07349838396268231, 0.09998693902577672, 0.11822501037802015, 0.09403485698359353, 0.16500933494951042, 0.19912900695843355], [0.024001169517370205, 0.06522972908403192, 0.05077087047642895, 0.07907287483768803, 0.011835658340714872, 0.046049396507442, 0.028414267980094467, 0.0817406370437571, 0.05669081031477877, 0.00779387798892068, 0.008590626530349255, 0.03891081116827471, 0.052835845920656405, 0.02196935238316655, 0.05560393292190773, 0.02500103666846241, 0.034084768167563846, 0.043928526741053374, 0.021401615347713232, 0.030372679499643188, 0.05674198203321014, 0.012667384514186, 0.024102254271773354, 0.05651981609740427, 0.028455539872603755, 0.026545660570263863, 0.05819703931255, 0.07896941860339471, 0.05779787751712969, 0.07203407825103827, 0.018915534285562377, 0.008870657084376683, 0.05760199124259608, 0.03828630450048617, 0.03894584732396262, 0.07637257687747478, 0.08574228374553577, 0.08069673805896725, 0.016628608340397477, 0.04841612325981259, 0.06046082212456635, 0.007630172085815242, 0.06318725725369793, 0.04914027279508965, 0.05159989438418831, 0.018239742244726846, 0.04976273707247206, 0.01679990959486791, 0.06784345276121583, 0.07202984419252191, 0.05153439539883818, 0.030469564122280905, 0.05764780592705522, 0.045512258008654626, 0.02873663996745433, 0.008486199142810489, 0.033979554527572224, 0.12536946843777383, 0.05736744204269988, 0.028906626560326134, 0.01390528174982007, 0.009297105317403163, 0.016239044422815953, 0.05094497577686395, 0.10815677884966135, 1.0838357103722436, 2.779930830001831, 7.519765223775591, 13.729615228516714, 18.5016336781638, 25.275137186050415, 34.88487277712141, 40.7419992174421, 43.79792465482439, 41.05601263046265, 40.82381425585066, 44.21912445340838, 34.14883272988455, 35.55930314745222, 28.24925627027239, 28.39632531574794, 29.0605366230011, 27.840830734797887, 22.078133787427628, 16.934959071023123, 25.681144748415264, 24.5420275415693, 21.611101933888026, 32.384542669568745, 22.70673383985247, 33.870338508060996, 77.1863569532122, 53.632151331220356, 20.524323769978114, 23.424548762185232, 29.11723566055298, 18.77273154258728, 20.703721046447754, 14.814669370651245, 21.292768478393555, 19.58324064527239, 21.829443863459996, 19.3952362877982, 19.86250959123884, 31.476312364850724, 22.549968583243235, 18.642572675432476, 26.4842939717429, 30.001539843423025, 39.24767793927874, 28.989836965288433, 34.194249629974365, 28.240176711763652, 21.112151793071202, 12.260640978813171, 4.845895605427878, 2.101435546364103, 0.25853709557226723, 0.017044628338356103, 0.06936497933098248, 0.07308524434587785, 0.01185273367445916, 0.07996978278138808, 0.007814147526265254, 0.08310458742614303, 0.05692078958132437, 0.027005172966580306, 0.06136270372995308, 0.044791043137333224, 0.04530199018440076, 0.015635265303509574, 0.07059371125485216, 0.023926062476156012, 0.06370887426393372, 0.05218022842226284, 0.026195256604946086, 0.05283099778794816, 0.11877326667308807, 0.06822413126272814, 0.034110260728214464, 0.10358627552964858, 0.07123640605381557, 0.03106444255848016, 0.06716025620698929, 0.044782269679542096, 0.06428725072847945, 0.007623644578935844, 0.0010539585845046012, 0.03081806649320892, 0.027193607230271612, 0.034974483640066216, 0.033770793051059754, 0.028780938126146793, 0.05327470201466765, 0.06569504804377045, 0.05749584800962891, 0.02123107235612614, 0.03616732445412448, 0.10090448800474405, 0.06166007848722594, 0.03654363319011671, 0.03276785383267062, 0.031008273429636444, 0.05058782547712326, 0.03573373718453305, 0.016923134946929555, 0.05714346441839423, 0.10194348118134908, 0.049681472325963635, 0.02083507423023028, 0.026448652114985243, 0.06464429585529224, 0.04722101953146713, 0.012601109454408288, 0.026872882386669517, 0.023260816565847824, 0.01806385748620544, 0.052178087644279, 0.005754653372735317, 0.030987242236733437, 0.025892441693161215, 0.015865626246003166, 0.04181731252798012, 0.050735338990177424, 0.05343289227624025, 0.003496920336536797, 0.040902725354369195, 0.03811560205316969, 0.04330752470663615, 0.0239394737207996, 0.09217050059565476, 0.04743195232003927, 0.02110043740166085, 0.047642342280596495, 0.03714192805013486, 0.09075682716710226, 0.029215264998908554, 0.017647443937936, 0.029635695474488393, 0.07051459407167775, 0.007719659828580916, 0.044021804950066974, 0.030427399956222092, 0.07442509316440139, 0.04231381695717573, 0.023323465704119632, 0.041440233654741726, 0.020705959194206765, 0.003911118255928159, 0.03205192814181958, 0.04647636466792651, 0.0072834025236911005, 0.04743579622091992, 0.10061319292123828, 0.017184637254104018, 0.00602809026271903, 0.04268216308472412, 0.055766262247094085, 0.009723299099797649, 0.01392687443045101, 0.04764890032155173, 0.04171721164935401, 0.022476392764864222, 0.04868767636695078, 0.030848190055361817, 0.008243932455245937, 0.0581346344468849, 0.027645497981991087, 0.04113192769831844, 0.05337647548211472, 0.010506094416736491, 0.024251138425565193, 0.05416172370314598, 0.07201023453048297, 0.02495216009473162, 0.048746895510703325, 0.08332585769572429, 0.05478587414004973, 0.04784891887434891, 0.06362642547381775, 0.16725099751991884, 1.4469889551401138, 4.32122540473938, 9.724342652729579, 18.30113298552377, 23.44879797526768, 30.58253083910261, 39.71171685627529, 47.43525103160313, 46.96183204650879, 46.70467574255807, 44.7443596294948, 50.877857616969514, 38.487089906420024, 37.49719047546387, 33.58239126205444, 29.153077942984446, 30.541998522622244, 28.94395627294268, 24.681686333247594, 17.49060651234218, 27.393912179129465, 28.479853085109166, 22.67693475314549, 30.760957104819163, 22.092771904809133, 42.3567327771868, 83.44242463793073, 50.3069623538426, 20.93277015004839, 29.930616106305802, 31.625253949846538, 24.293280294963292, 20.818077972957067, 18.589531864438737, 24.400251286370413, 22.29625337464469, 24.22839801652091, 20.023417711257935, 25.26976796558925, 39.41408729553223, 28.242365394319805, 24.32041301046099, 31.468325410570415, 33.86671849659511, 42.454469612666536, 34.18612718582153, 38.82279906954084, 32.40723548616682, 25.734678881508962, 15.181610686438423, 6.308703763144357, 2.7248633163315907, 0.3139475408409323, 0.025002422576238, 0.0027467362607629703, 0.01562268696060138, 0.03748937529910888, 0.04387900386271732, 0.06310748867690563, 0.17747494604970726, 0.0265751598801996, 0.047767698232616694, 0.06640853440122944, 0.03638513419511063, 0.019226554382060255, 0.014278987455847008, 0.023051625915936062, 0.05088170917172517, 0.016030922465558563, 0.032027677300253084, 0.04615543456748128, 0.020140069470341717, 0.11485374984996659, 0.07209651025810412, 0.05535574856081179, 0.05385154499007123, 0.06276129332504102, 0.021732256980612874, 0.0685316976159811, 0.010492070794238575, 0.044003084168902466, 0.0044624873303941315, 0.052275067261819325, 0.019741226586380174, 0.04181003863258021, 0.046911061342273436, 0.05382795911282301, 0.022420135426468084, 0.021315599159736718, 0.04944165090897253, 0.07892769548509802, 0.04810773927186217, 0.06796841177025012, 0.10340866898851735, 0.015423092492190855, 0.008760322201331812, 0.03414790924372418, 0.035900093615055084, 0.004111063866210836, 0.08244846441916057, 0.04473858220236642, 0.04295751938064184, 0.031776249541768005, 0.03120854982574071, 0.02156331024265715, 0.031263453486774645, 0.02155947482346424, 0.04513095864760024, 0.01567595704857792, 0.013303735010725046, 0.041205993188279014, 0.11727455923599855, 0.09000621815877301, 0.18715394953531878, 0.11586334210421358, 0.2058555010174002, 0.17291145878178732, 0.05775162178490843, 0.2123150322586298, 0.16325137285249575, 0.10562759385045085, 0.14657085149415902, 0.12120475620031357, 0.09813191249434437, 0.13725820263581617, 0.1753505886133228, 0.1371541560760566, 0.132357849872538, 0.19762236066162586, 0.13847985065409116, 0.17610335536301136, 0.1304149598415409, 0.17488382437399455, 0.12444386524813515, 0.21624890688274587, 0.08951118615056787, 0.12808651264224732, 0.1567469633051327, 0.23044677717345102, 0.16631110438278743, 0.2672818106200014, 0.06853389606944152, 0.13083585511360848, 0.09585921373218298, 0.12568372514631065, 0.11941270450396196, 0.11532591522804328, 0.18162378056773118, 0.19974399038723537, 0.08716611484331743, 0.1141929788781064, 0.1682317384651729, 0.1166939368205411, 0.15328309631773404, 0.16255662084690162, 0.12575084583035537, 0.09752412153674023, 0.16869084882949079, 0.1036697014101914, 0.22127082597996506, 0.1559023500553199, 0.09593147092631885, 0.15036051028541156, 0.1548326803105218, 0.13225149629371508, 0.12467855694038527, 0.1435013354888984, 0.11707581632903644, 0.1825200303324631, 0.15795980393886566, 0.1821284070611, 0.15131562974836144, 0.14821001568010875, 0.16128258992518696, 0.13847913140697138, 0.335341641413314, 1.6590764203241892, 4.488588401249476, 10.001315219061715, 19.335150003433228, 26.28303245135716, 34.31726401192801, 44.66435807091849, 54.09175729751587, 58.193952901022776, 53.631539889744346, 54.26547268458775, 59.30317374638149, 47.037418024880544, 48.10690907069615, 42.089105537959504, 39.07224287305559, 40.05923448290144, 38.74504177910941, 33.316115447453086, 27.644330467496598, 39.24124738148281, 35.51314279011318, 33.4494583266122, 47.01622254507882, 32.3678218296596, 45.80659328188215, 85.87800448281425, 66.14137540544782, 29.762813636234828, 36.476646014622276, 42.08154937199184, 28.58388672556196, 31.632719789232524, 24.110721588134766, 33.66200719560896, 32.36419486999512, 34.80380119596209, 28.601660217557633, 32.86122383390154, 45.16805730547224, 33.20735876900809, 31.60748393195016, 40.941874572208945, 41.376001494271414, 51.570450578417095, 40.22997604097639, 46.04429462977818, 36.967977455684114, 28.811844961983816, 17.203072684151785, 7.495730536324637, 3.0645392494542256, 0.4895295777491161, 0.10971141792833805, 0.15448771310704096, 0.15554393428776944, 0.16111491035137857, 0.2022775180105652, 0.13514170263494762, 0.28021780933652607, 0.0751482622165765, 0.11538934468158654, 0.2513025552034378, 0.1053262021658676, 0.08563314817313637, 0.10419719453368868, 0.16105927047984941, 0.1554848745997463, 0.117466109671763, 0.11258206210498299, 0.09262427767472607, 0.15056139736303262, 0.19426458940974303, 0.18506566302052566, 0.18385731428861618, 0.2557168597621577, 0.28643329867294853, 0.18633422494999, 0.16950051752584322, 0.14501407503017358, 0.13291826551514013, 0.11967938233699117, 0.1152122470417193, 0.10950301946806056, 0.16923749021121434, 0.11168670800647565, 0.12338811904191971, 0.15019094438425132, 0.11784594000450202, 0.10113362249519144, 0.12255851498671941, 0.13952744086938246, 0.1579375887023551, 0.2815122370209013, 0.13590945143784794, 0.09780694850321327, 0.13724151067435741, 0.11179172487131186, 0.12454850891871111, 0.15828874414520605, 0.11219982975827796, 0.15753896294959954, 0.13608908679868492, 0.0902513185782092, 0.13075276171522482, 0.2220980008797986, 0.10914679536862032, 0.19804544081645353, 0.1370416549699647, 0.13119532939578804, 0.1085943728685379], [0.013523090963384934, 0.0157771520649216, 0.022264774655923247, 0.04788621794432402, 0.020962706667238047, 0.01775083571140255, 0.025218003329687884, 0.029320644879979745, 0.04039417692859258, 0.027264995899583613, 0.037140028152082644, 0.008296906532320594, 0.045761948717491965, 0.03532783414370247, 0.047953301308942695, 0.007482650939242116, 0.029804165541593517, 0.06559362741453306, 0.029056616726198366, 0.040028334595263004, 0.029135750872748237, 0.03980737645179033, 0.0357098154324506, 0.04163852533591645, 0.12068524264863559, 0.005030045826320669, 0.02329029212705791, 0.03296561625653079, 0.027452327543869615, 0.014223365395862077, 0.045169071959597726, 0.05519915624920811, 0.03381809711988483, 0.051309437291430574, 0.007413384388200939, 0.04072118331012981, 0.13246315850743226, 0.00725281670955675, 0.02576875493728689, 0.022275539613994103, 0.022502677515149117, 0.034791421677385054, 0.02844992669166199, 0.03953912441751786, 0.013318917231767305, 0.013792814570479095, 0.045837113434182744, 0.03770572958248002, 0.008958437463401683, 0.02265031655718173, 0.022705306731430546, 0.023522675103907074, 0.031500537014965496, 0.06135652906128338, 0.045976189364280017, 0.01540341497665005, 0.05366604030132294, 0.00652322786793645, 0.06467731336929969, 0.03177403412493212, 0.026809637833918844, 0.044403850699641874, 0.0368459103628993, 0.02466466311099274, 0.14583758584090642, 0.021566906478255987, 0.11594784685543605, 1.3003947756120136, 3.755249031952449, 5.608277142047882, 10.593583141054426, 18.4209703036717, 20.93508563722883, 31.03066532952445, 34.03491701398577, 41.184081826891216, 42.77613994053432, 46.10533455439976, 43.61590269633702, 43.418466159275596, 36.57432379041399, 35.041207245418, 37.02977473395211, 25.675358636038645, 32.06764228003365, 18.933585814067296, 15.666621003832136, 35.168133463178364, 28.160720586776733, 32.38286815370832, 29.271853923797607, 42.87869187763759, 81.79030976976667, 51.16775730678013, 20.395893267222814, 27.857763494764054, 25.586425168173655, 25.570657968521118, 21.253148112978252, 18.75607671056475, 23.497840097972325, 25.90155029296875, 26.427214520318167, 31.85374893460955, 38.83372163772583, 28.75097700527736, 28.964026144572667, 31.50251749583653, 37.00432348251343, 30.971074104309082, 25.617921352386475, 21.558637823377335, 15.631344999585833, 9.123550159590584, 3.305927268096379, 0.6023531779646873, 0.1458526493183204, 0.02076112069854779, 0.16310338436492852, 0.07582142323787723, 0.05629396910912224, 0.009559993532353213, 0.03939649974927306, 0.05464345303231052, 0.06226442927228553, 0.03023927951497691, 0.04611954345766987, 0.04644577970196094, 0.08616115019789763, 0.010669217627894665, 0.022595105859051858, 0.03342681311603103, 0.049958972792540274, 0.03075783633227859, 0.001490009148255922, 0.0452534749305674, 0.02936850195484502, 0.01816778190966163, 0.013927312085538037, 0.03035569916080151, 0.07309375996036188, 0.01818751710067902, 0.025181506627372334, 0.07682984841189214, 0.02954375397946153, 0.019147759503019706, 0.03361967312438147, 0.007944608606132013, 0.05979916227183171, 0.08721471830670323, 0.040369057562202215, 0.05194821355066129, 0.05814766910459314, 0.009256023414699095, 0.03418520831369928, 0.028703608882746527, 0.032606698373066526, 0.0203281390214605, 0.03214175600026335, 0.008912900978300189, 0.09039860138935701, 0.0354503673900451, 0.014500021934509277, 0.06827175763568707, 0.02624787699564227, 0.07926553807088307, 0.008335661059910697, 0.04351759236305952, 0.03687916197148817, 0.01263348660099187, 0.05577667775963034, 0.09744573038603578, 0.03994717502168246, 0.0033465824214675066, 0.05244588166741388, 0.0588684564988528, 0.014176692364604344, 0.02324855713439839, 0.007600684650242329, 0.02786701252417905, 0.06483081156121832, 0.027475499514756457, 0.00858966470696032, 0.041007263852017264, 0.02729754861710327, 0.019564899083759104, 0.01759699316296194, 0.012714403598303241, 0.015910709808979715, 0.03993689860882504, 0.016322305758616755, 0.04592003719881177, 0.061097566171416214, 0.05359202909416386, 0.0543022313421326, 0.0569290609232017, 0.022520405938848853, 0.03079693012737802, 0.03892319443236504, 0.013473109225742519, 0.0357172453909048, 0.05424333450251392, 0.0209888370508062, 0.007080442097503692, 0.11806221625634603, 0.013684003846719861, 0.011792694351502826, 0.06424770570759263, 0.028497028896319013, 0.03446554166397878, 0.044542567006179264, 0.03492406170283045, 0.0835084921813437, 0.07249788407768522, 0.011180151952430606, 0.046118942954178364, 0.02716293235841606, 0.027776105795055628, 0.0206493880333645, 0.012391418384920274, 0.04522794844316585, 0.05245460084240351, 0.06442269988890205, 0.08315175918063947, 0.01375219491975648, 0.04390449981604304, 0.04490056208201817, 0.017116132358621274, 0.03646395282287683, 0.033718396576919725, 0.06322036297725779, 0.019402335663991313, 0.027662746342165128, 0.03618550579994917, 0.052688077956970246, 0.05727117827960423, 0.009654342978527504, 0.030784875952771733, 0.05015757999249867, 0.05138444594506707, 0.04977841801675303, 0.0383543140654053, 0.38416842424443787, 2.076307386159897, 4.979269317218235, 8.902523619788033, 14.998332841055733, 23.20261982509068, 28.094983679907664, 39.79122856685093, 40.06161076681954, 47.16945464270455, 48.35672460283552, 49.789331981113975, 48.476344789777485, 46.09012147358486, 40.078619956970215, 37.91891833714077, 40.79045595441546, 25.769034249441965, 31.66353852408273, 22.730124950408936, 15.700946841921125, 32.188513142721995, 29.274073873247417, 30.110213143484934, 31.709778785705566, 52.83318839754377, 80.09333733149937, 44.82462521961757, 22.569519077028545, 32.66923121043614, 27.335293701716832, 28.024737392153057, 24.106354645320348, 21.890891994748795, 27.741021599088395, 30.92878041948591, 30.517964703696116, 34.71204328536987, 44.50013392312186, 31.313953808375768, 30.5899167742048, 35.67382335662842, 41.335271154131206, 36.459622928074424, 30.845613956451416, 26.45935688699995, 19.788474798202515, 11.373220528875079, 5.068552800587245, 1.3266206426279885, 0.22616418983255113, 0.046137317682483366, 0.03874876343512109, 0.08650438035173075, 0.05570565549922841, 0.038047514456723414, 0.005741079703771642, 0.03812642129404204, 0.04338638743917857, 0.026651432305308323, 0.06302719084279877, 0.00832748640927353, 0.03891661942803434, 0.06661602362458195, 0.0325832685588726, 0.031015594822487662, 0.030970190651714802, 0.04603371895583613, 0.005472409522293934, 0.06558399221726827, 0.0473191797999399, 0.029871228550161635, 0.04101685155183077, 0.023591163036014353, 0.04957846053210752, 0.05472511472180486, 0.025600288262856857, 0.06564384579126324, 0.049839140115571876, 0.03514085364128862, 0.03710013707833631, 0.06655478583914892, 0.0483155609773738, 0.05114441757489528, 0.050629721621849706, 0.04984527746481555, 0.0710320652329496, 0.02822511616562094, 0.021166346900697266, 0.0037246173929556137, 0.055304950036640675, 0.030885696078517606, 0.01592962906163718, 0.020280583894678524, 0.03263676765241793, 0.01240666676312685, 0.07417351273553711, 0.08894527437431471, 0.045268758931862454, 0.04581624508968421, 0.03657364818666663, 0.05036043142899871, 0.028272756109280244, 0.049322154106838365, 0.05781648973269122, 0.06531804041670901, 0.032370907454086204, 0.007010874446547989, 0.029086085502058268, 0.02347730994889779, 0.09686924703419209, 0.12393438044403281, 0.053987299491252215, 0.1295225370143141, 0.24512158972876413, 0.10898006574383803, 0.09829860140702554, 0.13696479052305222, 0.14147014091057436, 0.12102445587515831, 0.0919581666322691, 0.07638755214533635, 0.24269194581678935, 0.1191962654037135, 0.07980308708335672, 0.15791542774864606, 0.0827354643759983, 0.1852899866976908, 0.17034015032861913, 0.24533633249146597, 0.1003816496314747, 0.1447554581931659, 0.10591515699135405, 0.12650108842977456, 0.1991406777607543, 0.09508995179619108, 0.11111651467425482, 0.1750071006161826, 0.21068451260881765, 0.08246930222958326, 0.09870260115712881, 0.18895942265433924, 0.16072720901242324, 0.2646999577326434, 0.09715982287057809, 0.14869248121976852, 0.2804245725274086, 0.13878276225711617, 0.10389855091593095, 0.13689183443784714, 0.1780060896916049, 0.2341628149151802, 0.08326854184269905, 0.1360521609229701, 0.12302739625530583, 0.08764068223536015, 0.1764694114348718, 0.16860699547188623, 0.20360845087894372, 0.0799085721373558, 0.076903014842953, 0.11730792958821569, 0.13468211729611668, 0.14061981439590454, 0.19678810185619763, 0.1037630813994578, 0.1269981289016349, 0.14662867624844822, 0.09545211307704449, 0.11937481510852065, 0.07535088634384529, 0.07031413447111845, 0.13275293367249624, 0.11038976295718125, 0.17857832541423185, 0.1852367759815284, 0.5838600045868328, 2.250054040125438, 5.170457252434321, 8.750969512122017, 15.7508088520595, 24.81015157699585, 30.91723598752703, 43.39090265546526, 47.12920372826712, 54.54514810017177, 56.544051034109934, 60.20230538504464, 55.412238121032715, 55.21934570584978, 48.59914377757481, 46.77670771735055, 50.10150064740862, 35.192709241594585, 43.21344913755144, 30.108135632106237, 25.306734119142803, 45.92172840663365, 38.99487815584455, 43.21874019077846, 40.037191322871614, 52.52026237760271, 89.14329651423863, 62.75384371621268, 29.296957765306743, 39.556615693228586, 36.8251120703561, 37.94021456582205, 34.096561431884766, 32.59160940987723, 37.03768873214722, 40.88086591448103, 38.55294145856585, 44.29697207042149, 54.109513419015066, 39.45165967941284, 39.79920857293265, 43.64211824962071, 48.15266295841762, 41.42579228537423, 36.650868620191304, 29.295696667262487, 21.302150283540996, 13.26708493913923, 5.45147671018328, 1.5587195711476463, 0.32909700221249033, 0.18154124356806278, 0.28606607552085606, 0.2948036795215947, 0.17210267218095915, 0.14037856805537427, 0.14395892593477452, 0.12452538444527558, 0.13393460240747246, 0.16239837290985243, 0.12945403211883136, 0.11763207933732442, 0.1849339458027056, 0.12313024859343256, 0.10317036070461784, 0.2930709996393749, 0.18308301083743572, 0.1390863795365606, 0.10223549551197461, 0.14625734117414269, 0.1795920974441937, 0.0981591081778918, 0.13003945856222085, 0.12758370462272847, 0.17100843946848596, 0.20209723125611032, 0.12782624017979416, 0.1456297912767955, 0.05178651865571737, 0.08844241207199437, 0.1194838285446167, 0.18568403912442072, 0.15775742408420357, 0.1350832943405424, 0.1550736009542431, 0.18511461253677094, 0.18196721428206988, 0.16001942913447106, 0.0782970039706145, 0.12835191482944147, 0.18042076512106828, 0.10703201884669916, 0.10137625983250992, 0.12036048221801009, 0.11593745169895035, 0.08819306402334146, 0.10386944854898111, 0.15488723452602113, 0.08898189490927116, 0.1570731486592974, 0.1292381358465978, 0.1263390135552202, 0.10071616061031818, 0.12136847312961306, 0.15424890949257783, 0.2031509554279702, 0.13083858282438346, 0.05270300233470542, 0.14958373696676322, 0.09774610426809106], [0.01851541066675314, 0.07012230583599635, 0.03622977342456579, 0.0411366706580988, 0.006034958309360913, 0.03596784872934222, 0.109693769232503, 0.01939563513068216, 0.004729024367406964, 0.10510721855929919, 0.0366848600762231, 0.0513912041538528, 0.010819895658642054, 0.018352877781061188, 0.04005183904830899, 0.03336910032001989, 0.020962567567559223, 0.029529179047260965, 0.10564990408186402, 0.03795227188883083, 0.014856127290321248, 0.02948903013020754, 0.03566910333133169, 0.07689523883163929, 0.07003516836890153, 0.08828537871262856, 0.02188118693551847, 0.007129136739032609, 0.042341287447405715, 0.04553631207506571, 0.004934305807442537, 0.034117280172982385, 0.02023345115594566, 0.026268587580748966, 0.037489527969488075, 0.07897150849125215, 0.05757207463362387, 0.03522896480613521, 0.011595190619118512, 0.03755701845511794, 0.026781483719657575, 0.018580183619633317, 0.049006048390375714, 0.03309115202033094, 0.05149583425372839, 0.036454419405864816, 0.023455713875591755, 0.012455653598798173, 0.05635160726628133, 0.03181015593664987, 0.024384258514536277, 0.03849175472610763, 0.04259076102503708, 0.018877346334712844, 0.0863700100619878, 0.01538614965310054, 0.03170013487605112, 0.021160530159249902, 0.02195872143576188, 0.05697921144643, 0.03996645898691245, 0.05726186877914837, 0.03661336284130812, 0.009792976164525109, 0.051221214168305905, 0.10991096829197236, 0.011954527497956795, 0.01794415373089058, 0.23164677992463112, 0.8296648519379752, 2.6844871171883176, 5.26347712959562, 7.423792362213135, 13.820629681859698, 21.40562285695757, 28.362260035106114, 40.424876485552105, 40.271012101854595, 46.063568932669504, 46.833603041512625, 43.530252252306255, 45.11990628923689, 39.334947313581196, 37.837023394448416, 39.87729242869786, 35.29719625200544, 42.520147459847585, 33.34834814071655, 41.558464663369314, 34.55292953763689, 33.11540283475603, 25.043651001793997, 50.23011875152588, 56.301871572222026, 33.07477324349539, 26.506620270865305, 25.280640159334453, 23.732326166970388, 21.132122652871267, 24.627822160720825, 23.069318635123118, 28.272425038473948, 26.17339335169111, 35.95716394696917, 37.80346359525408, 33.78626877920968, 35.90494476045881, 35.07208503995623, 24.70284707205636, 18.402871983391897, 14.669224466596331, 8.7497718163899, 3.2857071416718617, 2.212928078004292, 0.27376966391290936, 0.004662303594938878, 0.1367772298731974, 0.025891079534111277, 0.016854546930907027, 0.04165236745029688, 0.025891810655593872, 0.04678356121959431, 0.053598688915371895, 0.0823569775425962, 0.05900978177253689, 0.023552152361454706, 0.02808803682481604, 0.025467034163219587, 0.013580327088545476, 0.03482374369299837, 0.018249938929719583, 0.03268172399007848, 0.07952699796961886, 0.03680766812924828, 0.02230007035125579, 0.02540564031473228, 0.05412350521822061, 0.05375606493492212, 0.029867788377617086, 0.08659218278314386, 0.06221453659236431, 0.03856644107561026, 0.059728173938180716, 0.04997594973870686, 0.06154812699449914, 0.028061387361958623, 0.04575797589495778, 0.0135710023210517, 0.04494147774364267, 0.011422186241751271, 0.018443279001595717, 0.05471449564876301, 0.03454409566308771, 0.009108521776007754, 0.026133577771750943, 0.0359629395284823, 0.05783927493861743, 0.05032064213550516, 0.03769295276807887, 0.015718131392662014, 0.0706113056678857, 0.056275726695145876, 0.09319242183119059, 0.07920396101794072, 0.017719120984630923, 0.017692413846296922, 0.048626458937568326, 0.034396524474556954, 0.13672477911625588, 0.004770057076322181, 0.058198640655194006, 0.06198641311909471, 0.016316511069557497, 0.0493677177333406, 0.010487233687724386, 0.019313081167638302, 0.03525314100884965, 0.07375706865319184, 0.05723821504839829, 0.04944484341623528, 0.06719845772853919, 0.056453146639146974, 0.11267542173819882, 0.028096808586269617, 0.033110870247972865, 0.08624230977147818, 0.017788029608449767, 0.06188331650836127, 0.023249605471002202, 0.020265416940674186, 0.029902268134589707, 0.04306093151015895, 0.02137968339957297, 0.04418112157977053, 0.04987911261352045, 0.033038229681551456, 0.020597507245838642, 0.02311087559376444, 0.026688892527350357, 0.08079273040805544, 0.033004496313099346, 0.025725530560261438, 0.020678366567673426, 0.028215664172811166, 0.057897242185260565, 0.01348916845329638, 0.023362296566899334, 0.061135530205709596, 0.0058647749413337025, 0.08025421787585531, 0.041587852340723784, 0.09453990416867392, 0.011291274784265884, 0.029267871818904365, 0.045220705081841776, 0.03158838694382991, 0.03231249576700585, 0.04009819316810795, 0.002707590939410563, 0.06402841676026583, 0.020710512164181898, 0.030897098859505992, 0.030973607075533698, 0.011711923239220465, 0.02198875000301216, 0.010186746999222254, 0.022700789384543896, 0.0165674231414284, 0.04046862918351378, 0.10045297723263502, 0.03071881378335612, 0.002538509978746463, 0.04984234619353499, 0.044291495478578975, 0.01380515966697463, 0.051612016412296464, 0.01832404513178127, 0.08257821388542652, 0.055445610346006494, 0.05013651826551982, 0.02090689037660403, 0.05421155531491552, 0.03806303255259991, 0.00807813327160797, 0.45191786597882, 1.1611872911453247, 4.650717232908521, 7.919919797352382, 11.329611897468567, 18.31289107458932, 27.062125274113246, 34.32059219905308, 46.01372603007725, 46.209845883505686, 51.492606435503276, 51.31475339617048, 47.317836897713796, 49.253247192927766, 45.43183524268014, 39.58606563295637, 41.42052207674299, 38.42723117555891, 42.156843526022776, 38.52191775185721, 42.17885194505964, 36.295701026916504, 35.55469649178641, 26.777923107147217, 59.23673507145473, 61.14081941332136, 35.14168167114258, 30.305096217564174, 27.86210090773446, 28.82595154217311, 23.15649594579424, 28.67360881396702, 27.61801937648228, 33.022595746176584, 30.56696687425886, 41.38848393304007, 45.51182637895857, 38.85884632383074, 41.17578567777361, 38.931371620723176, 31.165088653564453, 23.289553948811122, 18.791997160230363, 11.821358493396215, 5.335441359451838, 3.120647690125874, 0.5768736994692257, 0.04580316632719977, 0.12114642933011055, 0.036337870838386674, 0.032691087773335833, 0.019059471919068267, 0.03698127470644457, 0.02495924908933895, 0.048452377385858975, 0.043602514413318465, 0.07300309411117009, 0.019424662858779942, 0.04807559706802879, 0.046450383562062464, 0.04918627407667892, 0.004893231538257429, 0.027987186164994324, 0.03309911462877478, 0.013953759684227407, 0.017934257297643592, 0.04346900247037411, 0.03439311144341316, 0.03705723670178226, 0.045808011067232916, 0.03803731946806822, 0.03974689184022801, 0.005216023369160081, 0.04017044696956873, 0.019387745464752828, 0.02917702615793262, 0.039774718561342785, 0.01712733836445425, 0.03045470081269741, 0.003919998158900333, 0.07804885692894459, 0.045885123179427216, 0.010707205410913696, 0.022369389488760914, 0.00529269697809858, 0.03072852361947298, 0.008858746250293084, 0.023864195349493196, 0.06653267916824136, 0.08180856518447399, 0.022444834101146886, 0.05033356144226023, 0.031087909692100117, 0.049195838027766774, 0.023364902141370943, 0.07010868085282189, 0.013741003332792648, 0.01674822558249746, 0.033448129293641875, 0.03848803635420544, 0.04287713672965765, 0.04736719972320965, 0.04502051350261484, 0.03309974905901721, 0.03322661475145391, 0.009336561280568796, 0.01914248219691217, 0.02611385445509638, 0.1436386438352721, 0.19798710037555012, 0.16019677104694502, 0.1025659895635077, 0.17141233065298625, 0.1604995605136667, 0.21098878128187998, 0.06845624452190739, 0.2983241634709494, 0.14112273098102637, 0.10242391111595289, 0.18788762230958256, 0.21902724994080408, 0.1126423499413899, 0.1901436833930867, 0.09697592630982399, 0.08354858003024544, 0.1595023718795606, 0.2597362297986235, 0.18631342106631824, 0.14500737110418932, 0.11235017954771008, 0.0995926083996892, 0.16710752807557583, 0.18112200392144068, 0.14523041913551943, 0.08539690942104373, 0.05026898526453546, 0.13823359672512325, 0.07122131543500082, 0.0793429860579116, 0.16974930917578085, 0.1145806395049606, 0.1772329940327576, 0.11967031710914203, 0.2173194315816675, 0.11885736430329935, 0.08852108820740666, 0.10018566157668829, 0.1482700388878584, 0.13329525957150118, 0.13795733797763074, 0.09972482094807283, 0.15743103516953333, 0.18870067011032784, 0.16637173827205384, 0.19639524365110056, 0.0693091426842979, 0.1928547564893961, 0.08610154089650937, 0.08018722611346416, 0.20118252533887113, 0.16764415428042412, 0.11641695882592883, 0.22195837194366114, 0.1233743176396404, 0.19719056811715874, 0.10001030777181898, 0.12860027221696718, 0.20057930770729268, 0.09845126500087124, 0.15911391058138438, 0.14609517130468572, 0.09720955948744502, 0.10406129075480358, 0.20805115891354425, 0.11972607911697455, 0.17608251076723846, 0.5250070254717554, 1.237756222486496, 4.4309031537600925, 7.970603431974139, 11.287789821624756, 20.415492398398264, 30.014675412859233, 39.75860677446638, 51.822826521737234, 52.8629857472011, 59.647095680236816, 60.00632449558803, 55.31237861088344, 58.52224486214774, 53.38669579369681, 49.900013310568674, 52.024258272988455, 47.584678990500315, 53.777222769601, 45.67538349969046, 52.80768503461565, 46.41134711674282, 44.65154906681606, 33.31185967581612, 59.38541957310268, 65.36468492235456, 43.92392676217215, 40.48456845964704, 37.55874456678118, 36.522181034088135, 31.709101336342947, 36.99092388153076, 35.62493930544172, 40.765706471034456, 37.48316553660801, 51.30506760733468, 52.17752511160714, 45.64959873471941, 48.13948222569057, 45.217601435525076, 36.01460470472063, 25.351054940904888, 22.344538143702916, 13.312599982534136, 6.483665483338492, 3.3239756481988088, 0.7971525479640279, 0.1003086528341685, 0.21150351794702665, 0.17004335911146232, 0.15219822738851818, 0.12224594104502882, 0.11898809085999217, 0.12735924523855957, 0.14615154399403504, 0.16949654131063394, 0.23203593332852634, 0.0837521744625909, 0.15961476442004952, 0.08791958726942539, 0.1091844608475055, 0.0655750830524734, 0.14834621122905187, 0.10703927238604852, 0.1303482869906085, 0.10785892911787544, 0.116664569824934, 0.15219355906758988, 0.12174320087901183, 0.08738891181669065, 0.15305125447256224, 0.1046284306794405, 0.1314121349049466, 0.14488055290920393, 0.13148034124502114, 0.1064439257606864, 0.18199781621141092, 0.08563136362603732, 0.10066689218261413, 0.0960533900984696, 0.2543223617332322, 0.10339877594794546, 0.15188597914363655, 0.07476615200617484, 0.2090256709073271, 0.19310118683746882, 0.10504540401910033, 0.14189422529722961, 0.19453391352934496, 0.1323857240911041, 0.2328389116695949, 0.12711391411721706, 0.12750741014523165, 0.14639821861471447, 0.17829028729881558, 0.18336885049939156, 0.11348356373075928, 0.0698992306632655, 0.15967197849282197, 0.14117466605135373, 0.21967351383396558, 0.06636431427406413, 0.11888111302895205, 0.1516846849450043, 0.07862457353621721, 0.1254286231206996, 0.1809531029845987, 0.06663571471082312], [0.03939486447987812, 0.01747091457114688, 0.056098635840628824, 0.06648381786154849, 0.10404892106141363, 0.023008900262149315, 0.05216195208153554, 0.021510951087943146, 0.02553078083188406, 0.018650308517473083, 0.012056986285772706, 0.035896619515759606, 0.04590806105573263, 0.03062696728323187, 0.009224910039587744, 0.04621613970292466, 0.04720799844445927, 0.027436356525868177, 0.025667020485603383, 0.038019552028604915, 0.03416259613420282, 0.021527407258482914, 0.10558454080351762, 0.017137151677161455, 0.04457623252112951, 0.037115488933133226, 0.017037042316847613, 0.03613643754007561, 0.05178414039047701, 0.046984997910580466, 0.017535502623234476, 0.03437760013288685, 0.025680536903174858, 0.048925546995763264, 0.04834837493087564, 0.0831471790692636, 0.028295069733368497, 0.033784418034234216, 0.04451945271076901, 0.05638543902231114, 0.02579089892762048, 0.02540248682323311, 0.021810578581477915, 0.05304194075454559, 0.05762230658105441, 0.016010030372334377, 0.0483001480544252, 0.052386604848184755, 0.013840577498610531, 0.03215778639007892, 0.1113572521135211, 0.02542612189427018, 0.02194530001309301, 0.054765820037573576, 0.043318438942411115, 0.03626488082643066, 0.011919894222436207, 0.056399756111204624, 0.04378242797351309, 0.01043764125954892, 0.01228818267450801, 0.05581668757700494, 0.07645970077386924, 0.021790802678359405, 0.029046221569712673, 0.04568071789773447, 0.044767922056572776, 0.005311098847804325, 0.05310311747182693, 0.026661757911954607, 0.12122484083686556, 0.7730068521840232, 2.3937792650290897, 4.125017396041325, 8.1757116488048, 14.70285895892552, 21.34287714958191, 27.65733575820923, 38.0622318812779, 39.97561986105782, 45.93562480381557, 47.84521559306553, 53.23433222089495, 48.387025696890696, 51.5556127003261, 42.23619195393154, 41.037804876055034, 35.54261357443673, 42.2722670010158, 33.13036230632237, 35.235544885907856, 41.266213008335654, 32.21335642678397, 24.104228496551514, 43.22834954942976, 40.87394898278372, 36.214598178863525, 40.26472050803048, 29.38886158806937, 31.87644522530692, 32.25093923296247, 39.62079620361328, 37.267587253025596, 35.2040730203901, 32.65910768508911, 30.290598801204137, 27.5298102583204, 20.720051050186157, 15.824834959847585, 10.651213237217494, 5.0347932406834195, 1.6885190861565726, 0.6443557984062603, 0.10947454813867807, 0.024051386197762828, 0.03943026365180101, 0.04974927833037717, 0.09756701852061919, 0.03522817092016339, 0.034469524664538245, 0.021053681249863336, 0.05562182589034949, 0.02555058048372822, 0.03414529009855219, 0.0741071520107133, 0.014247878321579524, 0.00909645572703864, 0.04485602304339409, 0.05082915324185576, 0.03682940160589559, 0.07290204667619296, 0.028888380753674676, 0.05531103310308286, 0.08476422979895558, 0.01593338305662785, 0.050824349213923724, 0.02583851681889168, 0.0331408241763711, 0.014729283650272658, 0.06200371576207025, 0.031881907622196844, 0.01140260202477553, 0.026076214421274405, 0.010505328520334192, 0.014236414472439458, 0.05209815961175731, 0.08454809603946549, 0.024308103136718273, 0.01017276493699423, 0.015356248311166252, 0.07048609560089451, 0.019415197295269797, 0.02817381382919848, 0.0137234182496156, 0.05698467365333012, 0.0371135924277561, 0.035405651932316165, 0.10666348612202065, 0.03455523042274373, 0.02396260667592287, 0.036167629794882875, 0.06029926972197635, 0.03304447220372302, 0.04379399021023086, 0.0249517190469695, 0.045505862816103866, 0.03155287242095385, 0.061198477899389606, 0.033863026316144636, 0.031903128804905076, 0.05242753068783453, 0.0343406776498471, 0.023932757920452526, 0.032493688365710635, 0.020560379505955746, 0.018136574387816445, 0.027580368798226118, 0.04900411117289748, 0.06976730988493987, 0.03355831659532019, 0.04926748114771076, 0.06315783597528934, 0.042755733244121075, 0.05686096654140523, 0.0029021663691050237, 0.021967237050245916, 0.00975572968101395, 0.09540038156722273, 0.030251530464738607, 0.01952314712772412, 0.014839011244475842, 0.03130466431113226, 0.06007446428494794, 0.053990142552980354, 0.02384821415346648, 0.03193585115617939, 0.027825360652059317, 0.0443809976402138, 0.021984727986689125, 0.041602749577058215, 0.025242086233837262, 0.07813999775264945, 0.02821666161928858, 0.033378681234483204, 0.007609207898245326, 0.03171345791114228, 0.01506711945070752, 0.034899841395339797, 0.027371113687487583, 0.06067967680948121, 0.027199615657861744, 0.07019660542053835, 0.04410526475736073, 0.05379774734111769, 0.056062459746109586, 0.028909534082881043, 0.04314308174486671, 0.012277796847878822, 0.021930955782798783, 0.007393793385875012, 0.03727576229721308, 0.04711728170514107, 0.046937866868185144, 0.019466012782816376, 0.017509792931377888, 0.05290862558675664, 0.12472182033317429, 0.05234080712710108, 0.047365415176110606, 0.03357782447710633, 0.029755053176943744, 0.0723709301756961, 0.014778173794703824, 0.04829118799950395, 0.01602620325450386, 0.04985124857297965, 0.016664261962952356, 0.02921011152544192, 0.06140121737761157, 0.10263941383787564, 0.04527527286804148, 0.06898114564163343, 0.04996961561430778, 0.04291540610470942, 0.04426509368100336, 0.020068319481132284, 0.37224436551332474, 1.2737280236823219, 3.4089047823633467, 6.406768032482692, 11.998969214303152, 18.829322883061, 27.299972534179688, 34.188486099243164, 42.86589329583304, 46.008344650268555, 52.59539672306606, 53.98655462265015, 56.06431613649641, 51.96141529083252, 56.29185226985386, 47.49236869812012, 45.79040745326451, 39.624537808554514, 47.62475272587368, 37.19424901689802, 38.316324029650005, 39.866383756910054, 35.39865384783064, 29.805618013654435, 46.86766311100551, 43.87913172585623, 39.510451861790244, 43.76822805404663, 34.57363516943795, 36.09605148860386, 36.1196996825082, 43.53717613220215, 41.564818790980745, 39.460073947906494, 37.73962354660034, 35.16288757324219, 33.18827901567732, 27.241946390696935, 18.221987792423793, 13.245177268981934, 6.675781003066471, 2.416744364159448, 1.1303203531673975, 0.1922824936253684, 0.045864224300852845, 0.04603175798963223, 0.0782192370721272, 0.037386560280408175, 0.026364220306277275, 0.03336631493376834, 0.01722977849255715, 0.02892012262184705, 0.03372447964336191, 0.054158361562128575, 0.08794849964657, 0.023389398951881697, 0.03725351652662669, 0.024502372801569954, 0.054508068332714696, 0.03185161103361419, 0.0014360571325856394, 0.0440588393913848, 0.015654569624790123, 0.03709832199716142, 0.04935558891988226, 0.010785008780658245, 0.06773618316011769, 0.037431462335267236, 0.05083775706589222, 0.011154446501417883, 0.05601161711716226, 0.058645971651588163, 0.016830591252073646, 0.034380232848759205, 0.0481008419633976, 0.05292402493900486, 0.012565639036308442, 0.02713869508754994, 0.022899574699944684, 0.018049302910055433, 0.0763106741277235, 0.031823767349123955, 0.005484244869356709, 0.012279142891722066, 0.05974054363157068, 0.027829292762492384, 0.039910758047231605, 0.02469017093868128, 0.008267799924526895, 0.09300968556531838, 0.03109336511365005, 0.06242884509265423, 0.022690479044935534, 0.047121936455368996, 0.033641640695610216, 0.04571311115952475, 0.05357861445684518, 0.054046935934041224, 0.03075800257335816, 0.06182900656546865, 0.02720998367294669, 0.02847155669171895, 0.026624338402013694, 0.056700947627957375, 0.03207464888691902, 0.05328755346792085, 0.08754546341619321, 0.15275238693824836, 0.1496251683150019, 0.17058136952774866, 0.19555438948529108, 0.17394340197954858, 0.23255669538463863, 0.1089104073388236, 0.11146306964967932, 0.12465317973068782, 0.12779362978679792, 0.24283498099872045, 0.11758452760321753, 0.11164163971053702, 0.07595506749515023, 0.10666782196078982, 0.1114225136116147, 0.11623409363840308, 0.08527968571122203, 0.10557027799742562, 0.146715447306633, 0.08133473061025143, 0.15530530709241117, 0.06508792205048458, 0.10272765053170067, 0.16599831330989087, 0.16435468436351844, 0.17710164322384767, 0.08062722214630672, 0.16170447585838182, 0.10208124414618526, 0.14703099323170526, 0.12406046582119805, 0.1421096601656505, 0.12425369902380876, 0.14211675764194556, 0.12967436601008686, 0.205422541392701, 0.17522568388709, 0.09057891528521266, 0.16967325897089072, 0.052437335518854, 0.11435132181005818, 0.10781795238809926, 0.11175628498728786, 0.15764419016029152, 0.10280530886458498, 0.1268507239541837, 0.10555222896592957, 0.11826146127922194, 0.24999751523137093, 0.12476866639086179, 0.17218366212078504, 0.0957418746714081, 0.10829373435782534, 0.1700761052114623, 0.12318998681647436, 0.20773443233753952, 0.15019316997911247, 0.18012957860316547, 0.11408678814768791, 0.14499279617198876, 0.24373678117990494, 0.1702561748347112, 0.08996480716658489, 0.31985706516674584, 0.1356044906590666, 0.13482052486922058, 0.1971132829785347, 0.1616048397762435, 0.46602897878204075, 1.5299861643995558, 3.470076071364539, 6.145140562738691, 12.048052157674517, 20.798716817583355, 30.215725013187953, 37.032498427799766, 49.14488656180245, 53.36637578691755, 59.174180439540315, 62.4449337550572, 67.17909581320626, 61.232542582920615, 64.59410190582275, 54.61603362219674, 53.71401500701904, 48.32746226446969, 54.68498754501343, 45.61611883980887, 46.971663747514995, 51.081519739968435, 44.02893488747733, 33.32573175430298, 55.34463562284197, 54.48538316999163, 49.430186544145855, 55.56916318620954, 40.852152483803884, 44.52832623890468, 44.952301842825754, 51.184189796447754, 48.96097469329834, 48.2680412701198, 44.61791631153652, 40.38239172526768, 36.31926236833845, 30.638540267944336, 21.354430266789027, 15.505992548806326, 7.73906774180276, 3.0559445449284146, 1.2603461188929421, 0.31964297379766193, 0.1451312851692949, 0.13540106586047582, 0.2608884094016892, 0.25065447283642633, 0.1177290827035904, 0.20365436055830546, 0.126682596547263, 0.08612590708902904, 0.13802745778645786, 0.1297410252903189, 0.2373472883233002, 0.1687200665473938, 0.22089817454772337, 0.1578941081783601, 0.12598697601684503, 0.27392580839140074, 0.17618461671684468, 0.12056729969169412, 0.11924440067793642, 0.14895149160708698, 0.173147480402674, 0.10362775437533855, 0.23671576221074375, 0.15797310322523117, 0.15665523894131184, 0.24147166843925202, 0.14753694965371064, 0.13813436776399612, 0.12057595779853207, 0.13442440969603403, 0.13633121523473943, 0.14763138815760612, 0.13289037772587367, 0.12506473836089882, 0.04482124133833817, 0.11659725915108408, 0.1394027125622545, 0.18218159063586167, 0.12018635656152453, 0.0880700931219118, 0.13784079280282768, 0.10871986113488674, 0.10883692199630396, 0.1214066610804626, 0.06435483960168702, 0.17373438605240413, 0.10320037909384285, 0.12936909310519695, 0.1881651295615094, 0.11580125615000725, 0.1320736115532262, 0.20323647798172065, 0.11337184293993882, 0.18248927912541799, 0.10581401456147432, 0.12616758846810885, 0.09747564020965781, 0.08344960891242538, 0.14252581926328795, 0.10092386017952647, 0.09847421984055213, 0.10457299436841692], [0.056649650380547555, 0.02986604793529425, 0.047590335964092186, 0.012067921725767, 0.026327813509851694, 0.03802442391003881, 0.05646785727835127, 0.035262413189879487, 0.021867695963010192, 0.029979461670986245, 0.03449599092294063, 0.06815767554300171, 0.04536518893603768, 0.041708556935191154, 0.0160391106868961, 0.05607268526884062, 0.04692143275003348, 0.012746212471808707, 0.02077245562603431, 0.03269249573349953, 0.022113374833549772, 0.027888483068506633, 0.022268180901716863, 0.05441158404573798, 0.0186516554094851, 0.04264275377084102, 0.056614746539188285, 0.06673902166741234, 0.08745593072048255, 0.041282436943479946, 0.06778960422213588, 0.05283732173432197, 0.049314238995845826, 0.01778298130791102, 0.036790986345814805, 0.044903588348201344, 0.028832296441708292, 0.044450713720704825, 0.06923537235707045, 0.003151569760770404, 0.05544050097731607, 0.0733785003955875, 0.0022677117418165183, 0.06032290988202606, 0.09385344386100769, 0.02764341318314629, 0.03418495386306729, 0.05886340819831405, 0.005023987356772912, 0.03574655471103532, 0.043805077472435575, 0.01742421100581331, 0.016861159254663756, 0.09753488988748618, 0.03145632706582546, 0.04783523282302277, 0.01750005256118519, 0.043117310984858444, 0.05102762473481042, 0.0435017383923488, 0.05764471859272037, 0.035800274328461716, 0.011030279682017863, 0.07489928057683365, 0.03708038492394345, 0.02829259816956307, 0.054297603733305416, 0.017859000978725295, 0.04460882255807519, 0.036633620504289865, 0.05514253928725209, 0.03430441673845053, 0.14317850209772587, 0.6445778693471635, 1.4836554676294327, 4.661117817674365, 7.955369506563459, 12.520745924540929, 19.38599865777152, 27.59026653426034, 32.58673177446638, 39.24085480826241, 45.70759187425886, 48.01603705542428, 49.83399847575596, 46.46553611755371, 46.00416530881609, 50.83771092551095, 46.68733303887503, 53.033258301871165, 45.06858689444405, 44.87807076317923, 47.36798899514334, 45.32123381750924, 44.09601974487305, 40.661810057503835, 40.51456730706351, 43.108156136104036, 34.90723555428641, 39.26579884120396, 38.18104607718331, 40.3080598967416, 30.492909499577113, 29.700891290392192, 23.340760435376847, 15.846456016813006, 10.34944428716387, 8.827994636126927, 5.4545334833008905, 2.571913706404822, 0.68636411854199, 0.15359459817409515, 0.08579829681132521, 0.031839349905827215, 0.06389957653092486, 0.06419085804373026, 0.026900337609861578, 0.051267663283007484, 0.03952922798427088, 0.025581555607329522, 0.03526821805696402, 0.056261209438421896, 0.014319336540730936, 0.03897686994501522, 0.07086319143750838, 0.03340933744662574, 0.023795975438718284, 0.0018103013197625323, 0.05431205313652754, 0.03889335924759507, 0.043968417814799717, 0.02580002861629639, 0.017118651419878006, 0.041266386197613816, 0.044586773562644205, 0.019600671449942247, 0.05214585383821811, 0.021065028051712682, 0.03428011161408254, 0.01859205967879721, 0.020472897682338953, 0.050606821064970324, 0.01693547240990613, 0.04141244425305298, 0.04683503149343388, 0.02602724963799119, 0.07752459363213607, 0.022288782921220576, 0.03066320444590279, 0.08265254061136927, 0.009318667463958263, 0.021230605863300816, 0.020161512873268554, 0.03157829373542752, 0.03036064568108746, 0.036541556872959645, 0.04451027552464178, 0.02311495698190161, 0.012297147818441902, 0.001537830918096006, 0.04751052328252366, 0.010816741318974112, 0.05317505914717913, 0.015728441732270376, 0.016216751154778258, 0.025611204194969366, 0.0695750673434564, 0.06272974144667387, 0.03481432223426444, 0.08222114840256316, 0.01969287757362638, 0.03708523305665169, 0.030573485153062, 0.07209124482635941, 0.030972406068550687, 0.021568947172324573, 0.02508534973354212, 0.051949879354132075, 0.03330399149230548, 0.059402117505669594, 0.013009531556495597, 0.038225643469819, 0.03385608829557896, 0.05879345802324159, 0.02269621266584311, 0.0353085908905736, 0.026441488481525863, 0.058544299964393885, 0.024199517177683965, 0.033553040985550196, 0.03261076619050332, 0.053824861600462875, 0.03896756722990956, 0.03563939367554017, 0.03674970766795533, 0.023998088968385543, 0.05030870331185205, 0.01659836433827877, 0.023562554303290587, 0.06722578911909036, 0.01866140595770308, 0.0634314145094582, 0.025602613941633275, 0.05148101504892111, 0.0545460187963077, 0.011195796425454319, 0.05418415946353759, 0.021900565895651068, 0.06603508908301592, 0.021227779764948145, 0.01587930042296648, 0.017695725097187927, 0.05222330182524664, 0.029411880698587214, 0.023177341491516148, 0.10077682164098535, 0.04200697324371763, 0.01650259760208428, 0.040542273981762786, 0.05493001194138612, 0.03808811799223934, 0.04032500706879156, 0.08413223549723625, 0.010474830067583492, 0.013308691709036273, 0.029526553116738796, 0.02831374810609434, 0.023097779867904525, 0.02404770514528666, 0.039683869507695944, 0.059740652197173665, 0.07733000335948807, 0.02271907081428383, 0.021783167463062064, 0.06483336963823863, 0.07126187825841562, 0.02876440222774233, 0.10996630960809332, 0.05314144112968019, 0.07111290589507137, 0.008343541395983525, 0.019220008215467845, 0.03801733321909394, 0.05083300732076168, 0.023309440385284166, 0.06910314623798643, 0.015464299923873373, 0.05651808922578182, 0.36357903906277245, 1.1960702879088265, 2.751414120197296, 6.4099854826927185, 11.185197932379586, 16.751969575881958, 23.89200966698783, 32.33872972215925, 38.58422572272164, 45.23134844643729, 52.45573445728847, 52.54679407392229, 56.72571863446917, 51.387706007276265, 52.167078495025635, 55.51271949495588, 51.0222932951791, 55.621080126081196, 49.350490706307546, 48.89922257832119, 50.71016979217529, 46.84324714115688, 49.22348805836269, 45.496106079646516, 44.43766961778913, 49.644663538251606, 39.25340672901699, 43.00875520706177, 42.971811635153635, 46.0380516733442, 35.37317827769688, 34.959326199122835, 28.115748371396744, 20.187351771763392, 14.867192540849958, 11.26705379145486, 7.634164708001273, 3.9956332530294145, 1.254354166133063, 0.40189838143331663, 0.09403542695300919, 0.03268139150791934, 0.025009601476735303, 0.08052635113043444, 0.03556207800284028, 0.0293089706849839, 0.03494175450344171, 0.058047612330743244, 0.07710903164531503, 0.04684525701616492, 0.03571352701900261, 0.049173914561314244, 0.025893827600936805, 0.06051167832421405, 0.03150059129776699, 0.007724112714640796, 0.05410571063735655, 0.028497792248214995, 0.06561726078923259, 0.022203041539926614, 0.01204511446745268, 0.03559190300958497, 0.04039081818025027, 0.019467313873714635, 0.04767685935699514, 0.018518036597275307, 0.0788105803408793, 0.051249861916793246, 0.04313054241772209, 0.06510014246617045, 0.015412034067724432, 0.03402728268078395, 0.014827004567320858, 0.04652402836031147, 0.022742303853322352, 0.043452961902533255, 0.04175609849127276, 0.07519096921065024, 0.029635301924177578, 0.06012679969093629, 0.04316177199195538, 0.03802238830498286, 0.0389268279873899, 0.0657772593466299, 0.011923277567672943, 0.0240197223611176, 0.028237097397712723, 0.044006164717887125, 0.06617173925042152, 0.043238816250647814, 0.02293798147833773, 0.039982764183410575, 0.021796592278406024, 0.027878511996407594, 0.11135091459644691, 0.02479990871090974, 0.021044346304344277, 0.04112189216539264, 0.031236827772642885, 0.01838237709099693, 0.01964262018113264, 0.0630740165444357, 0.01899422568801258, 0.053026904418532333, 0.11775479918079716, 0.11278801783919334, 0.11052217906607048, 0.10016502732677118, 0.08382097791348185, 0.07757079508155584, 0.12102664075791836, 0.14510719717613288, 0.0871692428897534, 0.12194897340876715, 0.12277184639658247, 0.22076651161270483, 0.10329941806516477, 0.1467433079544987, 0.15136612632444926, 0.1312622736607279, 0.19766748324036598, 0.11563589716596262, 0.22094658123595373, 0.14715831354260445, 0.10741001713488783, 0.1567468818809305, 0.10694943434957947, 0.11075168675077812, 0.10596768238714763, 0.13191460365695612, 0.16631048013057026, 0.1745644515114171, 0.19938504536237034, 0.10629631725272962, 0.12353542899446827, 0.13235649280250072, 0.1091246683416622, 0.12330256934676852, 0.11502741410263947, 0.11609037992145334, 0.11458955545510564, 0.10998131880270583, 0.1267646857138191, 0.19556547674749578, 0.09886050304131848, 0.23992821840303286, 0.06587578941668783, 0.13030533572392805, 0.14246870018541813, 0.1550008077174425, 0.1930819707257407, 0.16617098690143653, 0.10659183282405138, 0.1196227382336344, 0.1442286843167884, 0.13179383799433708, 0.1324713687811579, 0.31266079417296816, 0.1518239610429321, 0.1159279386379889, 0.10565630266708986, 0.1322140275899853, 0.21049826831689902, 0.23050787246653012, 0.16106570299182618, 0.2906502852482455, 0.1527349350175687, 0.16571039733077797, 0.09476390214903013, 0.2207166121474334, 0.10345655999013356, 0.15549590757914952, 0.059757262734430175, 0.12847190696213925, 0.1323466540447303, 0.11201353118355785, 0.3880356667297227, 1.2815473526716232, 2.601887366601399, 6.775103764874594, 11.682548250470843, 18.542754854474747, 25.3312942641122, 36.58003520965576, 44.1823684828622, 50.093082904815674, 57.746002537863596, 60.46209853036063, 63.86791787828718, 58.75239699227469, 60.3223146711077, 64.35147081102643, 60.46137591770717, 66.47134535653251, 57.80634069442749, 58.96204498835972, 60.156204087393625, 57.585575580596924, 57.649728298187256, 53.21372733797346, 51.79210158756801, 57.26393304552351, 47.72117287772042, 51.437340463910786, 49.39628628322056, 52.16855846132551, 41.38685458047049, 40.273089613233296, 31.929741382598877, 22.790798357554845, 16.688530785696848, 13.548178655760628, 8.654838579041616, 4.448483833244868, 1.487107745238713, 0.43705946898886133, 0.17074543929525784, 0.12194625926869256, 0.08775799415473427, 0.22329286033553736, 0.1215696180505412, 0.2357315607368946, 0.08786934175129447, 0.14942191993551596, 0.19456208630331925, 0.12032606692186423, 0.08368591551801988, 0.10867842300129787, 0.1824768076517752, 0.1265176718256303, 0.12218283728829452, 0.06806967633643321, 0.10933698873434748, 0.08039101053561483, 0.1413333211094141, 0.10054305275636059, 0.07920991177005426, 0.19324715329068048, 0.1651423278131655, 0.11180111579596996, 0.1513374378638608, 0.10598337690212897, 0.14662294941289084, 0.11717093336795058, 0.12255664223006793, 0.14628707457865986, 0.07854713911988906, 0.10521087156874792, 0.09962722047099046, 0.10156118098114218, 0.1334591529199055, 0.11600426025688648, 0.13016724027693272, 0.11844454359795366, 0.12733884847589902, 0.10921139190239565, 0.11770837381482124, 0.07538648907627378, 0.18161991291812488, 0.1869151730622564, 0.18893107346126012, 0.10701911311064448, 0.10295561794191599, 0.0938210573845676, 0.14941147049622877, 0.14198364264198712, 0.12566776600267204, 0.11433306921805654, 0.08407926905368056, 0.1395075869347368, 0.13628269998090609, 0.19952977688184806, 0.14856575801968575, 0.11248815285840205, 0.12196550252182142, 0.1379630376717874, 0.12655295564660005, 0.20563317223318986, 0.145648220287902, 0.17157272276069435], [0.028980061012719358, 0.021606266598350236, 0.08492144636277642, 0.013016853797515588, 0.04101795417123607, 0.03857332481337445, 0.05461400800517627, 0.01247817587240466, 0.02965492515691689, 0.032758961631251235, 0.028832961406026567, 0.05192967936662691, 0.04451582254841924, 0.08055581990629435, 0.009254445820780737, 0.02076350405280079, 0.055510532576590776, 0.008045677245328469, 0.04897979587050421, 0.022289609037605778, 0.06388536122228418, 0.002343495197627427, 0.024578144807102423, 0.06232429641698088, 0.05354750362624015, 0.00935956955488239, 0.015376670518890023, 0.03327795610363994, 0.010429510713687964, 0.03420248042259898, 0.026716108566948345, 0.05579584637390716, 0.01078659315992679, 0.005919972492847592, 0.013150735542045107, 0.039560983423143625, 0.0407930299905794, 0.06288341605769736, 0.012456159955555839, 0.09563934124474015, 0.040151186753064394, 0.048001304268836975, 0.006451815025814409, 0.05901937625770058, 0.05849112317498241, 0.025845610902511647, 0.05270060032073941, 0.05358176285933171, 0.08326077261673552, 0.03847904237253325, 0.07624323453222003, 0.0337587728032044, 0.05094290624505707, 0.043131292198917696, 0.020024995020191585, 0.015675802681861178, 0.06309676782361098, 0.05147390060925058, 0.0328339838555881, 0.04604951864374535, 0.04961999366059899, 0.04734929318406752, 0.04933504966486778, 0.017171380376177173, 0.015568687447479792, 0.02186337030226631, 0.07453576901129313, 0.06069132047040122, 0.009651689058435815, 0.07440880153860364, 0.043056812802595754, 0.020028450459774052, 0.018894616747274995, 0.017424278859315172, 0.28477007363523754, 0.5971246585249901, 1.8745401671954562, 2.94265546969005, 5.791705676487513, 11.276557190077645, 14.0058000428336, 21.40066531726292, 25.817185265677317, 29.259534767695836, 32.33178847176688, 37.84352690832955, 41.820394379752024, 45.618738310677664, 46.92265462875366, 44.24421787261963, 44.13018751144409, 47.61517463411604, 44.2360954284668, 47.370667525700156, 39.89114713668823, 40.07634789603097, 37.051230771201, 35.37457486561367, 34.17904002325875, 32.925849028996055, 29.36290659223284, 26.013930456978933, 23.580900600978307, 16.61851726259504, 12.101429956299917, 6.360503886427198, 3.627052596637181, 2.9773812634604315, 0.5934258827141353, 0.1744921196784292, 0.07692047354898282, 0.052092989174915214, 0.045088458606707196, 0.04050731925027711, 0.0037376011605374515, 0.026169843772160153, 0.039565882445978265, 0.022800813927980404, 0.050363006469394477, 0.06103526308600392, 0.024511668731325438, 0.06158741417207888, 0.05675888434052467, 0.05619848566129804, 0.0502155981292682, 0.006599252627763365, 0.04523353957171951, 0.020963417432670082, 0.06655598006078176, 0.04466846578621438, 0.0569142485037446, 0.0546321656022753, 0.06942258016871554, 0.0360296089867396, 0.04700279588411961, 0.034286880000893555, 0.042098307449902804, 0.02879119079027857, 0.06809773375945431, 0.04280218914417284, 0.056414103734173944, 0.029408074117132595, 0.025354500826714293, 0.044545114905174286, 0.006185387826657721, 0.02829204177084778, 0.0227207942932312, 0.026891979754769375, 0.04325533179300172, 0.03884851826088769, 0.029899065449301685, 0.009282082552090287, 0.03329127574605601, 0.0620436000504664, 0.03111229624067034, 0.01716613699682057, 0.05159080880028861, 0.02694306326364832, 0.022788625742707933, 0.04645782709121704, 0.04128405185682433, 0.03516211214342287, 0.017145887815526555, 0.021926017744200568, 0.0857656185648271, 0.11897162960043975, 0.03784820497302072, 0.04182116660688605, 0.03253941823329244, 0.06965405560497727, 0.01475302898325026, 0.09256679897329637, 0.05777423735707998, 0.03762829177347677, 0.06581387309623615, 0.028558409174105952, 0.035877756242241175, 0.057430579726185114, 0.05697706049042089, 0.015276534017175436, 0.07200372059430395, 0.010039650785204555, 0.007491643224576754, 0.04710944801835077, 0.017823657785941447, 0.00865529855114541, 0.02845068834722042, 0.020726717276764766, 0.0011943543712342425, 0.05841146994914327, 0.046047462682638846, 0.009731854578214032, 0.027537972233923416, 0.055449525493064096, 0.00432322353091357, 0.035763022755937915, 0.0837307870388031, 0.03687127400189638, 0.0018211731470988265, 0.057492713177842755, 0.027009052490549426, 0.02286132737728102, 0.022565190946417193, 0.01638828480749258, 0.033865475827561956, 0.00046807953705345947, 0.07778616888182503, 0.01967362923148487, 0.034397762800965986, 0.0369496787233012, 0.02198902141701962, 0.0632990255419697, 0.0136314843881077, 0.0741647324923958, 0.04376468428277543, 0.06684791975255523, 0.04110916284844279, 0.03603964451966541, 0.021033588131623607, 0.08990046169076647, 0.05261392765013235, 0.03787535655179194, 0.009657046092408044, 0.053039406426250935, 0.05363373864176018, 0.027153955340119343, 0.06941230036318302, 0.02049064646208925, 0.09254484158009291, 0.014907392307317682, 0.027094561473599503, 0.034066264517605305, 0.06766109647495405, 0.036723811378968615, 0.025325637643358538, 0.017944331846332977, 0.054455698999975405, 0.03869623125397733, 0.05121536519644516, 0.012510982192387539, 0.014613929304427333, 0.02904781951968159, 0.05577556835487485, 0.08253096749207803, 0.03404949113194432, 0.03870010568893381, 0.06220057234168053, 0.017490480128409605, 0.044454679757888825, 0.07305172471595661, 0.39471136565719334, 0.9538556507655552, 2.6970121136733463, 4.275974827153342, 7.558583072253636, 14.859141315732684, 17.546096563339233, 26.71163034439087, 30.442257131849015, 34.320116247449604, 38.60509811128889, 44.37206820079258, 46.433452810559956, 50.127907276153564, 52.78493315832955, 51.671116079602925, 49.910251481192454, 53.51569604873657, 49.07601254326956, 52.63262864521572, 44.45332738331386, 45.775889192308696, 43.25649322782244, 40.265627247946604, 39.31770188467843, 37.521008900233674, 35.272168840680806, 31.664511271885463, 27.859260831560405, 21.189448765345983, 15.177083935056414, 8.87609440939767, 5.242990366050175, 3.8595445326396396, 1.0447672924825122, 0.22686578147113323, 0.12074066538895879, 0.016885501698457768, 0.04085161131141441, 0.029514285203601633, 0.018986953488950218, 0.04738697562632816, 0.012078824935347905, 0.11086127015628985, 0.04725142129297767, 0.04511208858873163, 0.04215305504788246, 0.030018060135522058, 0.020057931109996777, 0.03942767843337996, 0.08562869698341403, 0.0728057829130973, 0.06085941395057099, 0.06946358403989247, 0.08632724878511258, 0.06739225411521536, 0.025865508941933513, 0.07110078725963831, 0.050272832558091195, 0.026803863500910144, 0.07191773663674082, 0.09117356301950556, 0.05282317767185824, 0.042362858075648546, 0.051772344059177806, 0.008701102209410496, 0.04376704219196524, 0.08344936463981867, 0.034851349890232086, 0.08085531169282538, 0.02875925214695079, 0.01898262443553124, 0.05132063651191337, 0.048475281335413456, 0.026069708966783116, 0.05280745940815125, 0.03603838583720582, 0.054975059881274185, 0.019570517353713512, 0.02346737789256232, 0.024380796289603626, 0.02092849662793534, 0.07037422553236995, 0.010961633990518749, 0.025398592032226067, 0.07452767408852067, 0.035692499218774695, 0.018673019084547247, 0.0028398123935663272, 0.012507061108148523, 0.047525681754840274, 0.025037602920617377, 0.017060300800949335, 0.025148372066074183, 0.059442680329084396, 0.05469819723761507, 0.031163892043488364, 0.08058815209993295, 0.07718606572598219, 0.017664439543815594, 0.060960963501461914, 0.05502861665029611, 0.14826615766755172, 0.21362878462033613, 0.15285384149423667, 0.06681330768125397, 0.14306408752288136, 0.11745238969368593, 0.19646973322544778, 0.0975591271583523, 0.06455308039273534, 0.08407704345881939, 0.11003381027174847, 0.16301255566733225, 0.16428551450371742, 0.11888743697532586, 0.10827235371938773, 0.1380824191229684, 0.11670138713504587, 0.15516533888876438, 0.11315350394163813, 0.08084604290447064, 0.19563782215118408, 0.10298153119427816, 0.12511484138667583, 0.15734590616609367, 0.15560212545096874, 0.15986067908150808, 0.0574546337925962, 0.11644142679870129, 0.08780605479010514, 0.08893220578985554, 0.10220350258584533, 0.08897518419793674, 0.17282611264714173, 0.14801902164305958, 0.07462217366056782, 0.1059695483584489, 0.1736162259642567, 0.2149962362434183, 0.19022050712789806, 0.1996417623013258, 0.14477783627808094, 0.09904475244028227, 0.1295659225434065, 0.29167576879262924, 0.21203847495572908, 0.0756995922752789, 0.10589395955737148, 0.15027497416096075, 0.1380698662251234, 0.14845465469573224, 0.12244714024875845, 0.09793363777654511, 0.14519988505968026, 0.1053263039461204, 0.08553617873362132, 0.19153136893042497, 0.20607986540666648, 0.17386974021792412, 0.1050769423267671, 0.10162534325250558, 0.18532727898231574, 0.08887346501329116, 0.15623745135962963, 0.12965593699898037, 0.08535258072827544, 0.15329948972378457, 0.17888974584639072, 0.12537321395107678, 0.07205501105636358, 0.13868090058011667, 0.14976527222565242, 0.09231268760881253, 0.08497562738401548, 0.26509988627263475, 0.4047730357519218, 1.002527347632817, 2.456092881304877, 4.294212111404963, 8.307744792529515, 16.092788764408656, 19.196206876209803, 29.158320358821324, 34.78778212411063, 37.92620699746268, 43.145064967019216, 49.47763579232352, 52.95732143947056, 57.58643020902361, 59.22805677141462, 58.914859771728516, 56.60505274363926, 60.858270917619976, 57.657642296382356, 60.62266445159912, 51.65193557739258, 51.201605456215994, 50.92526865005493, 47.222531931740896, 46.230836391448975, 43.28467859540667, 41.128729002816335, 35.98820155007498, 31.543279102870397, 24.25963364328657, 16.60036509377616, 9.827359250613622, 5.512317742620196, 4.1352503555161615, 1.4494359152657645, 0.41006590745278765, 0.16923085413873196, 0.12760480706180843, 0.13334828029785836, 0.1626693255134991, 0.0551547800589885, 0.1447015960833856, 0.07896248397550412, 0.17929426128310816, 0.13729590204145226, 0.16097248585096427, 0.13751745729574136, 0.17379382572003774, 0.1738943438977003, 0.09472414678228752, 0.2027495883937393, 0.13611081348998205, 0.14678197087986128, 0.13862923692379678, 0.13259855338505336, 0.19116645279739583, 0.20301959104835987, 0.10865459963679314, 0.14468434772321156, 0.15433075438652719, 0.193142455337303, 0.33018404245376587, 0.1228455760117088, 0.10804794183267014, 0.1886185130902699, 0.09895346233887331, 0.15331135051591055, 0.1550090451325689, 0.10106679358120475, 0.16458481630044325, 0.12365348051701273, 0.08371250052005053, 0.08426056682531323, 0.09984795469790697, 0.17197590826877526, 0.1054985500606043, 0.1365584023296833, 0.19152234441467694, 0.13101680683238165, 0.14576743889067853, 0.12743415550461837, 0.08192630458090987, 0.1252441701612302, 0.10522269164877278, 0.09469462372362614, 0.15863151289522648, 0.14610671997070312, 0.1047284331704889, 0.07154607586562634, 0.19657352194190025, 0.10866834675627095, 0.21393670381179877, 0.13803756795823574, 0.10313217953911849, 0.11715973754014287, 0.14226444757410459, 0.06315434830529348, 0.22346375616533415, 0.15221577430410044, 0.16874302817242487, 0.14257603085466794, 0.11200304103216954], [0.0180906613157796, 0.0555541996977159, 0.040854725787150006, 0.0650179854461125, 0.05130151878776295, 0.061541124513106685, 0.0444313483312726, 0.041997480538806746, 0.023690816081528152, 0.01880285336769053, 0.0654247264776911, 0.05587371505264725, 0.029189443348773887, 0.05187992239370942, 0.03603672681908522, 0.05554733292332717, 0.059459630133850236, 0.03501255963263767, 0.029965063157890524, 0.046932743928794346, 0.016152046055399945, 0.01414145010390452, 0.02850248771054404, 0.03419080962027822, 0.02008692660768117, 0.04021119639011366, 0.025509120297751257, 0.05842033840183701, 0.0687175008601376, 0.04456093834180917, 0.05699620196329696, 0.022267456565584456, 0.0697946073487401, 0.06991734076291323, 0.05452019375349794, 0.006486801987713469, 0.03418440424970218, 0.020917343208566308, 0.053972392076892514, 0.01991630219189184, 0.01852577698550054, 0.04057202774233051, 0.08823578458811555, 0.03532828197681478, 0.05727690511516162, 0.07283931611371891, 0.060065134428441525, 0.010170916777237185, 0.021058838116005063, 0.028351221898836747, 0.021854629074888568, 0.048043505754321814, 0.029676132768924748, 0.06843041269374744, 0.0637808736147625, 0.06909654409225498, 0.026460268634504507, 0.03181596758908459, 0.03503274604944246, 0.08503050051097359, 0.014938470907509327, 0.10779625962355308, 0.014188052737154067, 0.0057659950855720255, 0.07468577953321592, 0.07963584855731044, 0.05928121613604682, 0.07463986985385418, 0.0636278639680573, 0.0645761980808207, 0.021517863663445626, 0.060524312646261284, 0.02741467733202236, 0.04342442271964891, 0.010370993853679724, 0.02106131985783577, 0.1135467081995947, 0.15818783241723264, 0.5842754851494516, 2.1800939313002994, 2.489821174315044, 5.560557348387582, 8.324441313743591, 11.514084833008901, 14.20194855758122, 14.883399214063372, 21.8397376196725, 24.090460641043528, 25.21939526285444, 26.46252700260707, 28.69955686160496, 30.38095317568098, 28.1014871937888, 24.676402228219168, 27.04836436680385, 25.90917420387268, 21.994592121669225, 19.52657982281276, 17.76588545526777, 18.986664840153285, 16.16096796308245, 11.58108457497188, 9.115914957863943, 5.676812435899462, 3.099628737994603, 1.0109372735023499, 0.5835971672620092, 0.28454884407775743, 0.10074827567275081, 0.0989821372287614, 0.036712378063904386, 0.048140841602746925, 0.0490225741107549, 0.02220573532395065, 0.019768564762281518, 0.03813612434480872, 0.08355407616389648, 0.06760407239198685, 0.04912638657593301, 0.032847222073801925, 0.014386155276692339, 0.02404796638126884, 0.08984415006956883, 0.09492064373833792, 0.07897997660828487, 0.03544605190732649, 0.02315332644086863, 0.1007540092936584, 0.07490035266216312, 0.022442041929545145, 0.01903402685586895, 0.058595875411161354, 0.07540669584912912, 0.076771080493927, 0.03253343355442796, 0.06694372889718839, 0.017385592185226933, 0.027587776704292213, 0.030928888225129673, 0.02448183693923056, 0.019550799126071588, 0.03927362384274602, 0.0272993653946157, 0.04409397732732551, 0.025611188927931443, 0.07998112788689987, 0.0336639882464494, 0.053814049144940715, 0.0446899448122297, 0.019573336666715995, 0.041326565468417745, 0.030224992960159267, 0.025366711064374874, 0.035584408590304, 0.0017858386480449034, 0.03901638782450131, 0.07982198428362608, 0.051260820257344415, 0.03280839630003486, 0.023680149511035, 0.03209117121462311, 0.05734560678579977, 0.041426225299281735, 0.022795222799426744, 0.04798198976953115, 0.09227909334003925, 0.033481275729302845, 0.024969179449336867, 0.03948408844215529, 0.006985694012005946, 0.05395510978996754, 0.038351314940622876, 0.013105259276926517, 0.019888889377138445, 0.030547327628093104, 0.025103687142421092, 0.027544179133006504, 0.05940274175788675, 0.06541372742503881, 0.06183317955583334, 0.043197493468012126, 0.046949337502675395, 0.045139772817492485, 0.04337781075654285, 0.035320607745753865, 0.016561830316537192, 0.03503760775285108, 0.019785770714016895, 0.02681096606621785, 0.008941385878383048, 0.03764295830790486, 0.043975114955433776, 0.04983248707971402, 0.013761126985108214, 0.02236641920171678, 0.02740061130108578, 0.02014841036205845, 0.028569642321339676, 0.021267219612907087, 0.049516764735536914, 0.04852242934118424, 0.04525540875537055, 0.07033769320696592, 0.05110239250851529, 0.04381936402725322, 0.036674831328647475, 0.002264155582192221, 0.01536219397426716, 0.06129739473440817, 0.07120774473462786, 0.012284076689476413, 0.02819046507855611, 0.021402064877163087, 0.01768131979874202, 0.07059778925031424, 0.021571223657312136, 0.025792318762147, 0.03363534049796207, 0.023571044472711425, 0.035191224688397985, 0.01399728431299861, 0.04054528328457049, 0.0747623047126191, 0.015088878372418029, 0.04605686717799731, 0.01331450929865241, 0.03161707540441837, 0.019015831939343895, 0.08446135212268148, 0.03577443910762668, 0.026604993368632028, 0.04850944218092731, 0.007552198234147259, 0.10704543348401785, 0.028157861470910053, 0.03716162592172623, 0.015834184629576545, 0.055677492903279405, 0.04297969051237617, 0.030283866051052297, 0.042785286836858304, 0.13410848379135132, 0.04194642756400364, 0.1333701562668596, 0.014805172703095844, 0.030229193091924702, 0.02165726529035185, 0.09201962833425828, 0.023500624412138547, 0.08033581171184778, 0.039713541844061444, 0.045132213937384744, 0.16324185979153427, 0.3076579011976719, 0.9994501641818455, 2.783951665673937, 3.821809300354549, 7.320886066981724, 10.775991593088422, 14.087036643709455, 16.93275649206979, 19.24851812635149, 26.338268893105642, 28.871813126972743, 29.50732489994594, 30.45778635569981, 33.94325985227312, 35.1604904447283, 32.43555981772286, 30.165472166878835, 31.516622338976177, 31.387740203312465, 27.32988452911377, 26.23581770488194, 21.98614832333156, 23.08943019594465, 20.21045626912798, 15.625718695776802, 12.112815448216029, 8.049415111541748, 4.656528966767447, 1.7842420297009605, 0.9388130179473332, 0.3584338165819645, 0.04701994924939104, 0.02238115358964673, 0.0636234942025372, 0.029986850917339325, 0.05243399712656226, 0.04173709611807551, 0.02638690373195069, 0.00923585650577609, 0.09426087699830532, 0.08172262872436217, 0.07014509782727275, 0.021979642366724353, 0.03928022938115256, 0.02315321787526565, 0.028782281625483717, 0.08533980391387429, 0.04284960177860089, 0.02900689368003181, 0.03743791859596968, 0.03508818575314113, 0.0437717817590705, 0.05125759043065565, 0.05009284775171961, 0.02694499708845147, 0.020932133575635295, 0.06005087162234953, 0.031901384969907146, 0.017781301933739866, 0.012345019312176322, 0.026477740911234702, 0.030987479723989964, 0.03252465670396175, 0.020257651107385755, 0.01227977138478309, 0.03412858456639307, 0.027178967837244272, 0.006352002948655614, 0.07178603977497135, 0.02545785528075482, 0.04441883275285363, 0.033767000040305514, 0.039019773714244366, 0.059836379917604585, 0.023099818865635564, 0.012385792481446905, 0.09735338855534792, 0.0630813922200884, 0.01901576917485467, 0.024362245142193775, 0.05004161835781165, 0.02539273288234004, 0.0417849905123668, 0.01660199280429099, 0.03116787165137274, 0.030378063675016165, 0.025105968716421297, 0.037707174862069745, 0.04424505654190268, 0.025960990693420172, 0.03346959814163191, 0.040837328149271865, 0.02039652856599007, 0.09511365302439247, 0.04122315673157573, 0.037473290626491816, 0.037801735502268584, 0.01560048699112875, 0.009915177776877369, 0.06938484005097832, 0.1357035432010889, 0.11167298124304839, 0.11052651490483965, 0.15146748588553496, 0.18425859989864485, 0.20513093418308667, 0.22935900411435536, 0.08343827059226376, 0.09082524385303259, 0.1382289691162961, 0.17604642627494677, 0.17800463762666496, 0.20170536371214048, 0.1013217531144619, 0.10564393297369991, 0.13650019759578363, 0.06674875185957976, 0.1040770463379366, 0.14491965009697846, 0.09686092140951327, 0.10936643715415682, 0.15307285902755602, 0.1376211510172912, 0.08078169064330203, 0.19270089188856737, 0.14277644295777592, 0.08682281005063228, 0.17415517275886877, 0.16432913073471614, 0.11783430991428238, 0.14679167393062795, 0.24154701296772274, 0.21162230228739126, 0.15783023089170456, 0.13712260419768946, 0.08813914084540946, 0.12291367378618036, 0.15650905535689422, 0.10972200985997915, 0.1534565705806017, 0.10992573321397815, 0.15823812543281487, 0.17290878535381385, 0.08484443263815981, 0.24320584109851293, 0.14517814479768276, 0.07596905888723475, 0.0760171805907573, 0.1145493183284998, 0.06957071114863668, 0.07780972083232232, 0.1374707469450576, 0.18273241179330008, 0.1463665310293436, 0.14829340763390064, 0.08077673055231571, 0.18530449377638952, 0.10770091866808278, 0.1837227065116167, 0.1133733560730304, 0.17896624388439314, 0.13215822487005166, 0.14959726695503506, 0.09186577730412994, 0.20990239243422235, 0.15986557810434274, 0.16784726695290633, 0.12396944713379655, 0.16690565033682755, 0.11120994216097252, 0.13653995974787644, 0.1231066355747836, 0.07011235172727279, 0.12189151506338801, 0.12631268639649662, 0.1943497048424823, 0.4152748036597456, 1.1653708666563034, 3.313733786344528, 4.471208785261426, 8.54423975944519, 11.464835132871356, 16.072951657431467, 19.692608765193395, 21.573981182915823, 28.54975196293422, 31.82695320674351, 33.70258814947945, 35.496435846601216, 38.52667726789202, 40.04078006744385, 36.694961888449534, 34.34762763977051, 36.42614303316389, 33.65781395775931, 30.816132749829972, 28.033563341413224, 25.468529871531896, 26.314509528023855, 22.567870616912842, 17.037021160125732, 12.70877981185913, 8.809844204357692, 5.061288893222809, 1.9861050035272325, 0.8505762698394912, 0.4750602798802512, 0.16472696938685008, 0.18164165318012238, 0.15161805280617305, 0.07610884388642651, 0.14887013525835105, 0.06566734345895903, 0.07094255967863969, 0.125188163880791, 0.18886142862694605, 0.13708175638956682, 0.13916188691343578, 0.07593013811856508, 0.13471556907253607, 0.12611897821937287, 0.2129810686622347, 0.16971078195742198, 0.1709536545510803, 0.15068195946514606, 0.11420775737081255, 0.14562719927302428, 0.18928313814103603, 0.22039970915232385, 0.10314403354589428, 0.15224237287683146, 0.14130604400166444, 0.15446890411632402, 0.1578018409865243, 0.1339243022458894, 0.1244915391185454, 0.10481288363890988, 0.20833869491304668, 0.10216095844017607, 0.11844670133931295, 0.08991854464901344, 0.12458756539438452, 0.11600261820214135, 0.11843294064913477, 0.19808236669216836, 0.1231141130306891, 0.1379232755196946, 0.0757738443623696, 0.11113104889435427, 0.15825967570500715, 0.1335440512214388, 0.14101383968123368, 0.20770159124263696, 0.1202824099787644, 0.1270290022449834, 0.20792573850069726, 0.1571257622646434, 0.07146387813346726, 0.12889770125704153, 0.12118487512426716, 0.12810993567109108, 0.10977031476795673, 0.10751447081565857, 0.15468570962548256, 0.17329127554382595, 0.07832625561526843, 0.08045094553381205, 0.14812530736838067, 0.08406783573861633, 0.2042615001222917, 0.17732896602579526, 0.07059529902679579, 0.11086086982062884, 0.15208188577422074, 0.12471346078174454], [0.028066773233669143, 0.013108389019700033, 0.054001647114221535, 0.038228106551936696, 0.00721414784701275, 0.010970239510892757, 0.03493445685931614, 0.04537487163075379, 0.024914555683998123, 0.02277028833382896, 0.05899399904800313, 0.015836001407088976, 0.06712715726877962, 0.04071499167808464, 0.07771085828010525, 0.048629953392914364, 0.03289313514583877, 0.03952975045623524, 0.06262142011629683, 0.038488270448786874, 0.010203489002638629, 0.07124892502490963, 0.07759522912757737, 0.057610303296574523, 0.01672248705290258, 0.01886912588296192, 0.021945915783622434, 0.06257370553378548, 0.009297034071226205, 0.0096177843598915, 0.020075718905510645, 0.014298449536519391, 0.04702655139512249, 0.05107654371697988, 0.030421452596783638, 0.04803514281021697, 0.07647907294865165, 0.032962383037166934, 0.023153641959652305, 0.07558155432343483, 0.049371934828481505, 0.04678534237401826, 0.017998482333496213, 0.08526538219302893, 0.03612895329881992, 0.040319460045014105, 0.0574736124170678, 0.024497833402295197, 0.04143105646861451, 0.0037917232340467827, 0.017897075274959207, 0.02150586716431592, 0.030907449911215475, 0.03838617806988103, 0.03393494763544627, 0.0795722087579114, 0.09261500210102115, 0.011733510830838765, 0.005429572334313499, 0.013202923366666904, 0.03311354706862143, 0.03055727495146649, 0.07162906069840703, 0.021549133949780037, 0.03942302368315203, 0.02511039106840534, 0.01869850485984768, 0.025024374880428826, 0.01262440440976726, 0.13744019929851803, 0.02405859054332333, 0.024492919112422636, 0.02625067425625665, 0.023028447159699032, 0.01680917838322265, 0.0065528603403695995, 0.04106321245697992, 0.03570526246247547, 0.16079278263662541, 0.07171690384192125, 0.21731351475630487, 0.650196193584374, 1.1938839937959398, 1.884388587304524, 2.755302505833762, 3.9091894115720476, 5.5359112194606235, 6.719360104628971, 7.803232618740626, 7.080745032855442, 11.215604986463275, 9.369528549058096, 11.094489199774605, 10.055667502539498, 10.741025652204241, 11.378043447222028, 8.851243308612279, 6.13191944360733, 6.38199770450592, 6.353257349559239, 5.073193328721183, 3.1105426209313527, 2.124706583363669, 1.263774837766375, 0.10971609303461653, 0.08073198795318604, 0.02501429015371416, 0.012398189316237611, 0.03699429579345243, 0.026365936999874454, 0.06081981464688267, 0.047002860344946384, 0.0955007029697299, 0.018783313255491, 0.014334444122921144, 0.025096270754667263, 0.04405356038893972, 0.01639680890366435, 0.05788556459758963, 0.03920341582436647, 0.08713487509105887, 0.0342295268284423, 0.01214718394580164, 0.038782262708991766, 0.06003737556082862, 0.04487183969467878, 0.037838369607925415, 0.08418687113693782, 0.03495494183152914, 0.045022382866591215, 0.029744508742753948, 0.017058131185227206, 0.026972440437280705, 0.049840073101222515, 0.03801328915038279, 0.020112073115472282, 0.015911444323137403, 0.05628969433850475, 0.03139227336006505, 0.09213760521795068, 0.040236278437078, 0.010721191713985587, 0.019901917249496495, 0.016809582111558745, 0.03566799392657621, 0.027233074219631295, 0.01839178497903049, 0.019167511657412564, 0.05277709496606674, 0.04411817388609052, 0.06112582715494292, 0.029595950285771062, 0.03467154489564044, 0.006150131571173135, 0.007914770028686948, 0.030370223202875683, 0.0580629472221647, 0.10978130024990865, 0.004748389332754803, 0.07617619527237755, 0.03522848643894706, 0.00586846362732883, 0.08088388480246067, 0.027904158923774958, 0.08904435405773775, 0.013827547929914934, 0.016287362901493907, 0.04115185627181615, 0.007983355500203158, 0.023758406651073267, 0.04173120304143854, 0.021191016737637774, 0.05282487740207996, 0.030546842475554774, 0.03269994265532919, 0.022330314353374497, 0.06286198792180844, 0.048598058854362795, 0.012460690873142864, 0.05969503428786993, 0.02719877427443862, 0.05526682315394282, 0.05321971692943147, 0.02893623782853995, 0.009954230859875679, 0.03967888227530888, 0.03941438253968954, 0.04639425853799496, 0.04766404183049287, 0.024546903358506303, 0.04697431098403675, 0.05803033682916846, 0.03401316575972097, 0.03457356443894761, 0.04334993653797677, 0.0518229525935437, 0.023186825714739304, 0.047823847005409856, 0.05046442370595677, 0.029020712045686584, 0.022567258781886528, 0.0395878534098821, 0.06162024848163128, 0.06099898860390697, 0.03144452394917607, 0.032234494773937125, 0.016643778687076907, 0.03201463585719466, 0.016556508905653442, 0.02631191543436476, 0.015598967072686978, 0.025902215990104845, 0.04033782798796892, 0.042131796545748196, 0.0475776270031929, 0.10572814595486436, 0.028540936897375753, 0.04974379916010158, 0.0718615200104458, 0.022110865950318317, 0.04460536542215517, 0.06464425514319114, 0.037352792985205135, 0.0295378473321242, 0.02063479783412601, 0.02215211239776441, 0.02719134940499706, 0.055077135296804566, 0.03172494890168309, 0.044902071822434664, 0.02729908380258296, 0.020964118020076836, 0.08754186039524418, 0.033088885713368654, 0.016213219380006194, 0.03989583027682134, 0.03012170296694551, 0.03800422731520874, 0.018475902965292335, 0.08982901195330278, 0.005810031160113535, 0.010628770155433034, 0.01335256069432944, 0.03566890994885138, 0.026797522591160874, 0.05292339050876243, 0.02596852752113981, 0.040103407709726265, 0.04176294830228601, 0.05431128978463156, 0.032546892296522856, 0.021472199953028133, 0.07472631521522999, 0.040257988164999654, 0.11409263711954866, 0.1748587050076042, 0.4939519433038575, 0.9042824251311166, 1.434441702706473, 2.7741853211607252, 3.9507709060396468, 5.092519743101938, 7.0347879103251865, 8.24142597402845, 9.509519985743932, 9.830828138760157, 13.478433506829397, 11.56166696548462, 14.186171804155622, 12.556979043143135, 13.993209906986781, 14.478340949331011, 11.934270194598607, 8.913799677576337, 8.830721804073878, 8.769799130303518, 6.578777202538081, 4.413589979921069, 3.125852542264121, 1.9525074235030582, 0.3581284758235727, 0.0911746486755354, 0.0493772070455764, 0.03841906326955982, 0.04224904061162046, 0.038942773560328145, 0.050460281249667914, 0.03112405864521861, 0.0381327655964664, 0.04738347099295684, 0.04511136934161186, 0.030665090773254633, 0.041606301707880836, 0.04406157728018505, 0.010161268009272004, 0.04950865624206407, 0.053649534936994314, 0.08575883321464062, 0.023859411677611724, 0.008993561828642018, 0.025336029407169138, 0.02095977709229503, 0.031588739782039604, 0.11462698344673429, 0.05333402293867298, 0.07135297158466918, 0.03145608279321875, 0.013397449178488126, 0.026300717910219516, 0.03454590056623731, 0.01566273918641465, 0.03962897602468729, 0.0502695688046515, 0.0718200004526547, 0.03487519361078739, 0.0019178851673911724, 0.08282540419272014, 0.09458374431622879, 0.016809780583051697, 0.02168566876623247, 0.014614460258079427, 0.04093536288876619, 0.024502192989790013, 0.025628167570435574, 0.02955681917124561, 0.042501364036330154, 0.024454992397555282, 0.02253388164431921, 0.02009917246843023, 0.018288966567654694, 0.06185619546366589, 0.03681668585964611, 0.06155643904847758, 0.04254393193072506, 0.02376551939440625, 0.06269278842955828, 0.02108845786590661, 0.029184232199830667, 0.012181010612818812, 0.054385833641780276, 0.03214472119829484, 0.05291478329205087, 0.05143638440806951, 0.007022174175030419, 0.019093812576362064, 0.03393507655709982, 0.016104692792786018, 0.028119776996650865, 0.05897917305784566, 0.0714638102799654, 0.028298540439988886, 0.02160298079252243, 0.18017024999218328, 0.12968828954866954, 0.06574213158871446, 0.10831259084599358, 0.11932711409670965, 0.1297365062470947, 0.17964239045977592, 0.1545929674591337, 0.05002450231196625, 0.11318270130349056, 0.11849475518933364, 0.1503397064017398, 0.10521442709224564, 0.0929997857393963, 0.12658703167523655, 0.137271040518369, 0.08920908200421504, 0.09885946488273994, 0.19850179632859571, 0.178217385496412, 0.11605272122791835, 0.1870592124760151, 0.1781871635466814, 0.07760847413114139, 0.10572909590389047, 0.1140531599521637, 0.1040318151935935, 0.17352207244506904, 0.07304752458419118, 0.11614345493061201, 0.06462014679397855, 0.07626475087766137, 0.11233790484922272, 0.07538425669606243, 0.1487730640385832, 0.1185185174856867, 0.17906544570411953, 0.1524110838238682, 0.1332668968077217, 0.2845851592719555, 0.17538921082658426, 0.12570940091141633, 0.16614430690450327, 0.16279809788933822, 0.142306598169463, 0.17756551690399647, 0.07347561911280666, 0.12192606606653758, 0.07136051010872636, 0.08822478553546326, 0.08930760528892279, 0.10179710082177605, 0.10735010927809135, 0.12283090608460562, 0.11499651361789022, 0.11879488479878221, 0.2279917560517788, 0.13764120851244244, 0.14116923777120455, 0.0732706201129726, 0.17091352599007742, 0.16307500803044864, 0.167193987007652, 0.15272881463170052, 0.07733249358300652, 0.12220358688916479, 0.07267017090427023, 0.17317200265824795, 0.10755900985428266, 0.31341833780918804, 0.15186790297073977, 0.1428676244935819, 0.09588100149163178, 0.12787402261580738, 0.0781244050179209, 0.0779158640652895, 0.15752636933965342, 0.2348903130207743, 0.3560814442379134, 0.17803732944386347, 0.5714320657508714, 0.9084730574062893, 1.7723851459366935, 2.666278277124677, 3.8448043635913303, 5.706394391400473, 7.723844238689967, 9.389062540871755, 11.30787706375122, 11.322708862168447, 14.5674854687282, 13.338604484285627, 15.817834649767194, 13.801937290600367, 15.456543956484113, 15.233650956835065, 13.004164235932485, 9.547560504504613, 9.323677386556353, 9.364263551575796, 6.8318106191498895, 4.975661899362292, 3.4863769795213426, 1.8626415942396437, 0.47902390147958485, 0.20987071841955185, 0.12624393722840718, 0.11840161947267396, 0.16690326189356192, 0.20568868996841566, 0.10595571981476885, 0.2078940916274275, 0.1634522056473153, 0.10454463838998761, 0.09973091419254031, 0.15861092614276068, 0.1342196413981063, 0.1223084069788456, 0.1258361241114991, 0.11769024335912295, 0.1748605099107538, 0.1568308709455388, 0.11759243932153497, 0.11002286550189767, 0.20255607020642075, 0.10691003860639674, 0.1320484514747347, 0.30136682306017193, 0.10251152355756078, 0.15344343414264067, 0.14303438125976495, 0.13470718237970555, 0.16237110937280314, 0.1559738947876862, 0.15018943803650991, 0.11228996635015522, 0.2044994623533317, 0.14265224390796252, 0.0846168180661542, 0.20350038739187376, 0.1607200979654278, 0.13121652682977064, 0.1446497831493616, 0.10222644385482584, 0.11125761603138276, 0.10312696839017527, 0.10539657303265162, 0.09018950403801032, 0.13574869292122976, 0.09681389214737074, 0.16087660885282926, 0.10210367651390177, 0.13706230957593235, 0.08998088844652687, 0.08847923616745643, 0.09905711534832205, 0.1900243019419057, 0.16133499997002737, 0.08515310500349317, 0.20947292047951901, 0.08976757739271436, 0.13260236675185816, 0.12079828658274241, 0.0933931799871581, 0.12123675591179303, 0.17546079627105168, 0.11308896169066429, 0.1124311423461352, 0.07379778075431075, 0.08102135599723884, 0.13731001556984015, 0.0873631817687835, 0.1539061814546585, 0.14095376219068254, 0.18847627857966082, 0.06508790847978421], [0.009796948138890522, 0.09750766027718782, 0.06426921526768378, 0.0177380843420646, 0.015834586661575095, 0.08527345675975084, 0.02363347139076463, 0.05781251351748194, 0.04386238654011062, 0.021059628609301786, 0.017415541024612527, 0.023448202492935315, 0.013731931319593318, 0.02511462682325925, 0.02792245053154017, 0.015659499181700603, 0.035519598317997794, 0.0009596059576974117, 0.04189361718350223, 0.02131372131407261, 0.052968224710119624, 0.036332669867468734, 0.09610611226941858, 0.08169968067003147, 0.03097776649519801, 0.004309716867282987, 0.016916010329233747, 0.05896562271352325, 0.04698319300743086, 0.03929461093087282, 0.044233575729387145, 0.034673770490501604, 0.024833608152610914, 0.04942432790994644, 0.1071401434019208, 0.03722868214494415, 0.011793868217085089, 0.008332595777963954, 0.056193620565214326, 0.04635313592318978, 0.05693752904023443, 0.027292359520548155, 0.019385967703003968, 0.035598528904042075, 0.03969816624053887, 0.011071014683693647, 0.05349681027499693, 0.04461285305608596, 0.07239866868725844, 0.03467135829851031, 0.02065611401173685, 0.06843072481985603, 0.03664166792961104, 0.07252252846956253, 0.02178601561380284, 0.014110243430228105, 0.01494753104634583, 0.04498382850683161, 0.027964360246966993, 0.03753617385934506, 0.022179102824468697, 0.021063601431835974, 0.054498860612511635, 0.039086036051490476, 0.09416819590010814, 0.027035873283499053, 0.06428997843925442, 0.03544418593602521, 0.03169952419453433, 0.05299799882673791, 0.033879131344812255, 0.03285030601546168, 0.0014327328410997453, 0.021522355565269078, 0.03004204634843128, 0.02516920309114669, 0.03933741291984916, 0.04012736678123474, 0.06705719352300678, 0.02117189731714981, 0.03725256657760058, 0.0385799778492323, 0.04663964394213898, 0.1284471811460597, 0.33912013151815956, 0.07462099979498557, 0.258051047367709, 0.36875547415443827, 0.7869925445743969, 0.7973335268242019, 0.9547413289546967, 1.4514797713075365, 1.2977681394134248, 1.4022968390158244, 1.1846433239323753, 1.619493618607521, 1.3348688057490756, 1.4911266267299652, 1.280774365578379, 0.4714699068239757, 0.5342849333371434, 0.4772786551288196, 0.11532971502414771, 0.12426762256239142, 0.033968779391476085, 0.03490912036171981, 0.027072846656665206, 0.022591451947976435, 0.03894813398697546, 0.025660413250859295, 0.04381634793909533, 0.07355058366166693, 0.008217450081636863, 0.04063178971409798, 0.04877054584877832, 0.05733810897384371, 0.06163341884634324, 0.025718044622668197, 0.036871633625456264, 0.04690766188183001, 0.02971756411716342, 0.03592574563143509, 0.06141750900340932, 0.059202248230576515, 0.0337175043033702, 0.03865084404657994, 0.020277279429137707, 0.0168724585590618, 0.023469254041888883, 0.01813810278794595, 0.029001658782362938, 0.09636486481342997, 0.04228464673672404, 0.03403728428695883, 0.036736360884138515, 0.018328019650653005, 0.005109165978085781, 0.0776105233068977, 0.005455075921158173, 0.023046185761424046, 0.011551169811614921, 0.043491312701787264, 0.030131707965795482, 0.041761781222053936, 0.058021034114062786, 0.01868258642831019, 0.030758572542773824, 0.06539098293121372, 0.025096280932692543, 0.01805593050085008, 0.044272092769720724, 0.059469373896718025, 0.010305071632111711, 0.01184315954534603, 0.017481038313625113, 0.0022768295561296065, 0.038697944554899416, 0.029866363454077925, 0.06464830599725246, 0.012152887880802155, 0.026846897888130376, 0.02774520361396883, 0.06052288772272212, 0.02683856038908873, 0.11387522092887334, 0.017790719999798706, 0.021705739832084094, 0.022455826368448988, 0.027638524338336926, 0.008179544570988842, 0.04310239678514855, 0.03671325337407844, 0.03427440174190061, 0.04944283155990498, 0.05094654658543212, 0.0031262336872584584, 0.03215349804876106, 0.05932204358811889, 0.03441855311393738, 0.042603212142629285, 0.047937640720712285, 0.03743232746741601, 0.06408746287758861, 0.032335063841726096, 0.035270599714879475, 0.08640491390334708, 0.034290415168340714, 0.02558981507484402, 0.022858131477343183, 0.02389241392458124, 0.06527650728821754, 0.009505291735487325, 0.049024569003709724, 0.020809914151738797, 0.0377216039092413, 0.011390932918792325, 0.05271750602072903, 0.05237601970189384, 0.0493119455474828, 0.060591528325208595, 0.03862714281837855, 0.027891232831669704, 0.01728901290334761, 0.06114234269729682, 0.020824709607820426, 0.018787754267188053, 0.03733531392312475, 0.040317346408431015, 0.03583460480773023, 0.044841200445911715, 0.1260415030909436, 0.013409455007474338, 0.006657055329664477, 0.04952463234907814, 0.059836006723344326, 0.023797318938055208, 0.07703246575381074, 0.04952298690165792, 0.02980526816099882, 0.04946303154741015, 0.03539060202560254, 0.04949820680277688, 0.04312177235260606, 0.005564443043632699, 0.04971288510465196, 0.07026709163827555, 0.0228597294273121, 0.028971949126571417, 0.03376324774165239, 0.024627850889893513, 0.013851003189172064, 0.0760560877887266, 0.04118201376071998, 0.04266514542645641, 0.03138688239934189, 0.059168708244604726, 0.01230923761613667, 0.023841187923348377, 0.0159841900624867, 0.0378319031691977, 0.012827006484647947, 0.05606874976573246, 0.0070491802928570125, 0.015815814990284185, 0.011980358477947968, 0.045629909195538075, 0.04069330909156373, 0.02203462745196053, 0.033039349264332225, 0.03127644064703158, 0.01643338703018214, 0.023158345903669084, 0.016374814191034863, 0.023410194353865724, 0.014354333680655276, 0.02645683185463505, 0.07151900231838226, 0.016091150930151343, 0.02250459268023925, 0.12713150174490043, 0.3243531196245125, 0.23132670138563427, 0.4426871570093291, 0.7318769906248365, 0.9725450021880013, 0.8513710243361337, 1.68051269863333, 2.050828993320465, 1.879458623273032, 2.0949806698731015, 1.9605260789394379, 2.2570938680853163, 1.8098640548331397, 2.0782861028398787, 1.9833107420376368, 0.953897448522704, 0.7834619911653655, 0.6585555821657181, 0.23319378548434802, 0.05111432454681822, 0.03295563839908157, 0.04338871142161744, 0.029141606629959176, 0.024454631077657853, 0.018000327948746935, 0.01820012937033815, 0.026974267392818416, 0.03781132320208209, 0.04820806745971952, 0.012371737476704376, 0.01688982735920165, 0.061744929291307926, 0.015205482919035214, 0.010012707855951573, 0.0367728151780154, 0.04020001752568143, 0.039149920123496225, 0.029361831955611706, 0.006649616889522544, 0.03894027655145951, 0.01683793300097542, 0.06391314723129783, 0.047303861871893914, 0.016688823234289885, 0.023989592013614516, 0.03410109032743743, 0.03981558672551598, 0.01920490402595273, 0.010454337461851537, 0.08705209381878376, 0.05387304097946201, 0.06239151888127838, 0.007292929155352924, 0.04003579169511795, 0.030277983152440617, 0.0064933417930400795, 0.012230491930884975, 0.06859970718090024, 0.09519784564950637, 0.010151997524579721, 0.015047133201733232, 0.0355848598160914, 0.0548192750263427, 0.03387721787605967, 0.048807600646146705, 0.06796722433396749, 0.015465999654095088, 0.055195811071566174, 0.04425275112901415, 0.036813099802072556, 0.015754171780177524, 0.031011442188173532, 0.06154418470604079, 0.01836845015973917, 0.025302686196352755, 0.036180481248136075, 0.009052102437375911, 0.08351821558816092, 0.013181861639688057, 0.0050064807292073965, 0.028487414055104767, 0.006824963909041668, 0.07361239141651563, 0.03032458493752139, 0.039816753805748055, 0.00951902273975845, 0.022075468474732976, 0.03802511940843292, 0.022155057239745344, 0.11180649657866784, 0.06839461318616356, 0.028922473745686666, 0.0842587212100625, 0.13234422488936357, 0.16130845568009786, 0.10831025668552943, 0.14916281455329486, 0.13737202009984426, 0.22997277975082397, 0.1703237026397671, 0.13588187577469008, 0.153019444750888, 0.06946079526096582, 0.09481124353728124, 0.12376186970089163, 0.07073699749474015, 0.09970168290393693, 0.1409058847597667, 0.15196094369249685, 0.15912925904350622, 0.10454461124858686, 0.09062468247222048, 0.1358910495681422, 0.10973828791507653, 0.2845867877560002, 0.13443578194294656, 0.12143254040607385, 0.16637606732547283, 0.07167581854654209, 0.12218126308705125, 0.18648580967315606, 0.07171600139034645, 0.1399463548191956, 0.12549175401883467, 0.08042038431657211, 0.07991812591041837, 0.21265835740736552, 0.13699746876955032, 0.10085258686116763, 0.23841437963502748, 0.30539501405188013, 0.09438030594693762, 0.16902854213757174, 0.0962483264239771, 0.10998528823256493, 0.06419712770730257, 0.1323143286364419, 0.21831955148705415, 0.09636969598276274, 0.10779943516744034, 0.1339499508695943, 0.10227753754173007, 0.12764807045459747, 0.1716702011014734, 0.15265454218855926, 0.28356871381402016, 0.1443723708923374, 0.10900571436754294, 0.10818605763571602, 0.11673546316368238, 0.10651649508093085, 0.08135670835950545, 0.06102198415568896, 0.17968774374042237, 0.12976761029234954, 0.11104444746992417, 0.1601079236716032, 0.20430578131760868, 0.13948862866631576, 0.11509699108345167, 0.0706796341442636, 0.20654524543455668, 0.09199097380042076, 0.0872663344655718, 0.08499940325106893, 0.11501016574246542, 0.10856076502906424, 0.07095578432615314, 0.0783516260396157, 0.2328296293105398, 0.12505931008074964, 0.10256149766168424, 0.20676289232713835, 0.06105563949261393, 0.07401778216340713, 0.2596843082989965, 0.49803200151239124, 0.2560782746544906, 0.49143457838467186, 0.7521528112036842, 1.1866831630468369, 1.26285810981478, 1.8375929040568215, 2.424532860517502, 2.001958187137331, 2.3839694942746843, 2.268417477607727, 2.5484789524759566, 2.3408702526773726, 1.9718705330576216, 1.9453781374863215, 0.8795469467129026, 0.8680914299828666, 0.7622301961694444, 0.2539292999676296, 0.2402047078524317, 0.18166214493768557, 0.10374733938702516, 0.12362339427428586, 0.07281478028744459, 0.13697119589362824, 0.09526567200997046, 0.13725162084613526, 0.10071318184158631, 0.07406330507780824, 0.10945884683834654, 0.0820602270375405, 0.22514326604349272, 0.11092060125832047, 0.10158745385706425, 0.22422809872244084, 0.15646170718329294, 0.13804594108036586, 0.1012198371546609, 0.12864637188613415, 0.11223914407725845, 0.12734540312417916, 0.09714463047151055, 0.11673356326563017, 0.04709715635648795, 0.08674837475908653, 0.07244867671813283, 0.1078762656876019, 0.2675078713468143, 0.11569255484001977, 0.17251155738319668, 0.12149552202650479, 0.13718984701803752, 0.09879167244902679, 0.1539718093616622, 0.11741006267922265, 0.16262363296534332, 0.11082195583730936, 0.14621922107679503, 0.18659269250929356, 0.06258022625531469, 0.10793177663747754, 0.1352902203798294, 0.10428697150200605, 0.17281360046139785, 0.18553656632346766, 0.1323560449693884, 0.16843376548162528, 0.1925937376384224, 0.14014307569180215, 0.13127264167581285, 0.16656398081353732, 0.11452759163720266, 0.13849191500672273, 0.08737327836986099, 0.09403700793960265, 0.16160657682589122, 0.10576642890061651, 0.10981212609580585, 0.09877020360103675, 0.11867030576935836, 0.10418867891920464, 0.13056152340556892, 0.12347153813711234, 0.07771681581756898, 0.11659454501100949, 0.1476880865437644, 0.13963079532342298, 0.11580593804163591, 0.12449875873114381, 0.19898639246821404, 0.13636896892317704, 0.1268086683537279], [0.04656657589865582, 0.0279697529040277, 0.09018390612410647, 0.005984316696412861, 0.014156577193976512, 0.02637782832607627, 0.026931719854474068, 0.024838692076238136, 0.032733011059463024, 0.016053561786455766, 0.017614799618188823, 0.025235272045912485, 0.060380151096199236, 0.031653041153081825, 0.06710331354822431, 0.015429306176624127, 0.010093584989330598, 0.010619416550200964, 0.026195032688389932, 0.03837698731305344, 0.057060527083064826, 0.007086075634496021, 0.03508873875918133, 0.042729898023286035, 0.06396925529198987, 0.03447443386539817, 0.03429980270032372, 0.023634065108905946, 0.03030664786430342, 0.017477060402078286, 0.026214141930852617, 0.040649631792413335, 0.05695951357483864, 0.02679402643947729, 0.038655013644269536, 0.028002884072650756, 0.030588660588754073, 0.05035457227911268, 0.04625982718010034, 0.04011584525661809, 0.04573767073452473, 0.023945319299985255, 0.012444865740170436, 0.10262397038085119, 0.07537393617842879, 0.01730021721284304, 0.03606897758852158, 0.0637881067980613, 0.06138571285243545, 0.04039095049457891, 0.029920938025627817, 0.06708129508686916, 0.03137535748205014, 0.020448531489819288, 0.031016948499849865, 0.011101154361053236, 0.029570328803466897, 0.053971024828829935, 0.04522623174956866, 0.05498162131490452, 0.02441155258566141, 0.0386586471992944, 0.06262252612837724, 0.039907409476914575, 0.032915462340627394, 0.009803236462175846, 0.040852330558534176, 0.025451076715918522, 0.03522573158677135, 0.018122828964676176, 0.025564580357500484, 0.03686064814350434, 0.01226258070008563, 0.03471724083647132, 0.06775240693241358, 0.01656077858725829, 0.03008002056074994, 0.032279576640576124, 0.03185645577364734, 0.04048057818519218, 0.014030122863394874, 0.07737145506377731, 0.025069144620959247, 0.019546252941446643, 0.018653962428548505, 0.09642028755375318, 0.04629296683041113, 0.07800058594771794, 0.017792494368872473, 0.027444073165367757, 0.034406967128493955, 0.03409373840051038, 0.005618012959270605, 0.03395856065409524, 0.07242480585617678, 0.11130144260823727, 0.09721945931336709, 0.021070668374055197, 0.02337113787819232, 0.046273248602769206, 0.027507198974490166, 0.01061476519264813, 0.052512975210057836, 0.02031859033741057, 0.02164087866965149, 0.05103306658565998, 0.024780860536598733, 0.014360776370657342, 0.02636697346211544, 0.03023199544155172, 0.03509825521281787, 0.07243972005588667, 0.032084307832909484, 0.02236700104549527, 0.013976387978930558, 0.04348295654303261, 0.03582884404542191, 0.014264549926987715, 0.00731007573527417, 0.077498829657478, 0.023309591359325817, 0.054576980349208624, 0.016650453775322864, 0.02785021030077977, 0.028180276875251105, 0.036870232450642755, 0.045639357795672755, 0.010620458949623364, 0.018651881022378802, 0.08692680911294051, 0.03352142803903137, 0.03691536860008325, 0.011695989540645053, 0.021352465663637434, 0.025934934948704073, 0.03613444264712078, 0.05471121832462294, 0.017916525481268764, 0.054746291799736876, 0.03175853638510619, 0.030521991130496775, 0.02335883773464177, 0.017477257177233696, 0.0474350498323994, 0.043285960863743506, 0.038162631315312216, 0.023062843796131865, 0.04263483526717339, 0.0127826506504789, 0.01834132063335606, 0.024879261685003127, 0.04406513958903296, 0.02417840964959136, 0.0220782928767481, 0.04333788236337049, 0.024700896880988563, 0.04319591248141868, 0.04194460230480347, 0.05186794964330537, 0.05342556070536375, 0.031827024317213466, 0.08280044767473425, 0.03299228946811386, 0.014048914042567568, 0.03979086769478662, 0.04237596397953374, 0.027573586840714728, 0.02266592625528574, 0.03114587693874325, 0.027940538578799794, 0.059559374781591554, 0.01943840828192021, 0.08690473636878387, 0.00829677761066705, 0.02488906481968505, 0.020041466457769275, 0.012954465047057186, 0.020234655555603758, 0.017557365021535327, 0.04851595950978143, 0.052308966871351004, 0.018815390998497605, 0.03555515016029988, 0.006688615265634975, 0.01452466971906168, 0.0375278177005904, 0.019136278690504174, 0.028523294986890893, 0.020661876470382725, 0.025579569196062427, 0.04060921824670263, 0.06414581688919238, 0.04894351799573217, 0.035703365957098346, 0.039183836696403365, 0.007889235059597662, 0.03147239816774215, 0.010898401312130903, 0.02970929616796119, 0.03334734309464693, 0.05648045767364757, 0.03698340191372803, 0.02838865837215313, 0.05311795024733458, 0.01623766530039055, 0.042073710555476804, 0.024118912306481173, 0.02457905065135232, 0.029495527103011097, 0.02835582066992564, 0.02761767295721386, 0.026090838547263826, 0.02250258082390896, 0.13079379951315268, 0.038574644563985724, 0.040551339209611924, 0.02682225010357797, 0.05696067386972053, 0.009580845761645054, 0.0453066890394049, 0.03028318751603365, 0.0140321050338181, 0.023383897729218006, 0.024659943899938037, 0.059024580621293614, 0.006288559924411986, 0.05298349514071431, 0.0309119044936129, 0.036419976968318224, 0.022304692871070335, 0.07690952877913203, 0.05093082832172513, 0.034804707393050194, 0.06680946717304842, 0.013170459706868445, 0.019532974011131694, 0.020388453999268155, 0.01604376034811139, 0.03314000654167362, 0.015602890701432313, 0.022432298166677356, 0.010163340085585202, 0.03149765324113624, 0.055133518164179156, 0.016150210618174503, 0.03597136693341391, 0.048081184803907356, 0.030794046353548765, 0.051636725265000544, 0.010938392469792493, 0.028562918039304868, 0.015554580704442092, 0.07590913067438773, 0.023013948562688062, 0.04023734373705728, 0.017718303349933455, 0.09742053638079337, 0.04706296497689826, 0.035139371042272875, 0.00844975417879011, 0.013770517061597534, 0.013577190560421773, 0.09015644581190177, 0.018487187002652457, 0.03160058021811502, 0.052079947731856785, 0.05656821939295956, 0.08652062448007719, 0.10785350762307644, 0.09383739650781665, 0.06191543835614409, 0.01969063501538975, 0.13581350658621105, 0.0374255556879299, 0.052567281760275364, 0.03062127098175032, 0.0621570103934833, 0.006540980040361839, 0.05103401653468609, 0.04244353588936584, 0.04001887920977814, 0.06453359965234995, 0.024707929896456853, 0.03213768479015146, 0.10736420923577887, 0.02296213393232652, 0.01684102033531027, 0.05747494913105454, 0.034206795905317576, 0.029316784015723636, 0.04793218529916235, 0.07763036367084299, 0.01110179812115218, 0.02061353763565421, 0.024785004689225128, 0.0299954479560256, 0.022887664714029858, 0.030452478610511338, 0.021028125924723487, 0.07561588141002826, 0.03569130838981696, 0.026774116525692598, 0.07894514740577765, 0.008234466043567019, 0.02872273339224713, 0.08298934503857579, 0.010968637320079973, 0.026464300828852823, 0.01571997531157519, 0.01681025555756475, 0.062023074366152287, 0.019778885279915163, 0.027992200538782135, 0.01034525447591607, 0.015683968850810612, 0.0317358359960573, 0.08094236773571797, 0.0544656429306737, 0.0512217196768948, 0.040775968227535486, 0.024037968167769055, 0.03673445759341121, 0.023083174401628118, 0.028690231564853872, 0.04786621473197426, 0.04859988411356296, 0.021041326823511293, 0.04803087482494967, 0.02889420258413468, 0.06346425560436078, 0.025335593448419656, 0.01896544562519661, 0.018156971150477017, 0.02376261865720153, 0.04389056949211018, 0.015321488658498441, 0.03001591596486313, 0.034972383574183495, 0.03354353131726384, 0.01286430046561041, 0.01777196189920817, 0.04720476183242031, 0.016552763392350504, 0.019525496555226188, 0.04923802933522633, 0.033659072260239294, 0.06850324664264917, 0.03866387191893799, 0.04567725397646427, 0.0216841234027275, 0.06281285520110812, 0.025553486309945583, 0.16729918707694325, 0.1047037344958101, 0.06871066801249981, 0.08580483110355479, 0.13907700218260288, 0.10307131494794573, 0.10092024358787707, 0.13516233009951456, 0.09213233978620597, 0.07201204621898276, 0.15231471828051976, 0.08615048362740449, 0.14897948796195642, 0.079016766776996, 0.14339462907186576, 0.13369771226176194, 0.11565075708287102, 0.1109327334644539, 0.15778254345059395, 0.13561135743345532, 0.1373298152216843, 0.1271025011582034, 0.14654628852648394, 0.13916381395288877, 0.246602044573852, 0.060248915638242445, 0.15435567019241198, 0.1314545569143125, 0.13591447259698594, 0.139622354347791, 0.13412429365728581, 0.09978143112467867, 0.11942115905029432, 0.13495216066283838, 0.11378950159996748, 0.10837438503014189, 0.20531070525092737, 0.2371770574578217, 0.09584417739616972, 0.12211412883230618, 0.12590700387954712, 0.09393590622182403, 0.11089438945055008, 0.16465089204055922, 0.23260685269321713, 0.11631648136036736, 0.10221028793603182, 0.13789228004004273, 0.10742975571858031, 0.12112181207963399, 0.13724924597357, 0.21196851799530642, 0.10727792672280755, 0.14117670165640966, 0.10474267562053033, 0.09276218313191618, 0.17453843647880213, 0.14536831102200917, 0.10485812156860318, 0.11329398783189909, 0.10792061473642077, 0.11159283268664565, 0.1552750715719802, 0.2451476183320795, 0.1267188438879592, 0.1324376863028322, 0.16697373454059872, 0.13474181480705738, 0.13778827419238432, 0.10240722593984433, 0.15534517781010695, 0.12943767942488194, 0.13811531450067246, 0.0775333128071257, 0.13961997947522573, 0.06158056775374072, 0.12191279392157282, 0.11141656964485135, 0.14881387113460473, 0.1497422834592206, 0.17953739395099028, 0.15852007030376367, 0.07505307053881032, 0.21566323616674968, 0.11597376689314842, 0.18856838292309216, 0.18638883344829082, 0.16464435096297944, 0.10623198534761157, 0.08297373194779668, 0.1520168821194342, 0.1781052236578294, 0.14597019872495107, 0.16565771587193012, 0.17861135649893964, 0.20290578715503216, 0.22369524517229625, 0.11762021854519844, 0.14737473907215254, 0.13699691237083503, 0.12768488776470932, 0.10215569979378156, 0.15120646703456128, 0.10130512222115483, 0.1361041638467993, 0.19478650497538702, 0.09337082225829363, 0.12213787755795888, 0.20385755465498992, 0.12911439820059709, 0.17586239400718892, 0.15818777813443116, 0.1464462046112333, 0.13178978035492556, 0.08404704542564494, 0.22024873511067458, 0.1063199234860284, 0.11073819068925721, 0.08086884168109723, 0.18438373532678398, 0.136409355327487, 0.12302780337631702, 0.07791675973151412, 0.2806424908339977, 0.14636032921927317, 0.21117797041577951, 0.34280642228467123, 0.09905836385275636, 0.08966019922601325, 0.18629834401820386, 0.08573375456035137, 0.11448605172336102, 0.14140901847609452, 0.07553294407469885, 0.12217968888580799, 0.10941388032266072, 0.20650545614106314, 0.05706072385822024, 0.0939086087580238, 0.15557410195469856, 0.13934270292520523, 0.142074674900089, 0.21226882402385983, 0.1828712671995163, 0.2710397004016808, 0.0995405444077083, 0.08516578682299171, 0.10518178277249847, 0.18648388263370308, 0.11237502750009298, 0.17244964784809522, 0.18707420809992722, 0.15294256673327514, 0.11908624773578984, 0.12148257557834898, 0.11139954520123345, 0.15727654631648744, 0.20730061775871686, 0.11093784283314433, 0.23499988285558565, 0.08258622738399676, 0.18371750893337385, 0.08160115738532372, 0.08542516361922026, 0.10410369919346911, 0.11698266704167638, 0.05419659022507923, 0.11466853693127632, 0.1388789378106594, 0.15320965168731554, 0.1473738976887294, 0.13966860329466207, 0.19386601793978894, 0.12589861718671663, 0.11597520538738795, 0.14217729653630937], [0.049201673428927145, 0.03189889135371361, 0.039753500771309645, 0.031563840939530304, 0.016797453298100402, 0.043765210147414885, 0.023726359442142502, 0.019743691364835416, 0.037931942979672124, 0.010093374643474817, 0.06115833576768637, 0.055586589566831074, 0.01400006715474384, 0.0114349477891145, 0.049850288445928266, 0.06236619595438242, 0.05688183827857886, 0.024363532662391663, 0.05174843927047082, 0.027020431522812163, 0.0420072921551764, 0.046689584119511504, 0.017979502012687068, 0.06312008907220193, 0.06960144199963127, 0.03997186691101108, 0.03233168813000832, 0.024444843210013847, 0.00791588197794876, 0.028501313844961778, 0.07077363838574716, 0.016286718293226192, 0.05227644129523209, 0.05611472051324589, 0.03780027665197849, 0.05678611395082303, 0.02863903609769685, 0.013917864333572132, 0.05508524039760232, 0.02923671349084803, 0.029423069741044725, 0.07064894400537014, 0.042072662218872986, 0.05883847203637872, 0.026770274321149503, 0.010909364741694714, 0.02408098050260118, 0.04404695824320827, 0.001707964138144494, 0.05670962609084589, 0.0512531969164099, 0.03181273776239582, 0.04317645548975893, 0.014429688387151276, 0.022778780199587345, 0.06452631218624966, 0.017700188161273087, 0.042516834634755335, 0.042253678398472924, 0.03658409423327871, 0.058665547386876175, 0.034977062073137076, 0.04485684746344175, 0.006577184124450598, 0.029036735650151968, 0.021906094259715507, 0.024305424619732157, 0.05068819437708173, 0.02100092006315078, 0.034999789603586705, 0.02189752775510507, 0.04411511030048132, 0.03535277709098799, 0.02980878297239542, 0.017537214227819016, 0.024978809557589035, 0.08392142823764256, 0.03496736580772059, 0.01860675335462604, 0.048081391757088046, 0.05835376054580722, 0.0482794188096055, 0.0298384620941111, 0.03747500053473881, 0.023644753731787205, 0.029782550808574473, 0.01461508111762149, 0.02012811368331313, 0.04233614415196436, 0.0140612973066579, 0.03662374781976853, 0.03096700492980225, 0.05630952452442475, 0.031480109718229086, 0.011263371727961515, 0.051581597687410455, 0.04925634299537965, 0.017193485350747193, 0.03056941394295011, 0.01836456554675741, 0.03136841606880937, 0.04884904556508575, 0.06549053080379963, 0.03454755279900772, 0.029818414776985134, 0.027857893013528416, 0.02632021900665547, 0.05786936796669449, 0.01608189062348434, 0.021959810484466807, 0.014305811641471726, 0.04309211019426584, 0.02088925355513181, 0.033666539538119516, 0.026398408293191875, 0.07624041182654244, 0.024698776459055286, 0.03348799661866256, 0.0384882059879601, 0.034757752769759724, 0.031196553326611007, 0.04239483403840235, 0.028052462930125848, 0.023189748504332135, 0.01918296020344964, 0.022602411984865154, 0.0443717593859349, 0.018446659802326133, 0.01904767389143152, 0.025835293777553097, 0.04610614917640175, 0.02412309547487114, 0.018686028297192285, 0.012055656357136155, 0.03394109516271523, 0.039469449049127955, 0.04768147000244685, 0.05585483142307826, 0.06927156541496515, 0.03301329351961613, 0.013594019077053028, 0.05100379119228039, 0.017623337285060967, 0.02156922028266958, 0.08629647043666669, 0.03916298192260521, 0.03410864581487008, 0.04653543114129986, 0.027608794326494848, 0.044818601837115626, 0.011587038869038224, 0.049693010813955746, 0.04829367822302239, 0.01244158502335527, 0.052010879652308564, 0.009064813094612743, 0.05627223223979984, 0.050011956199471436, 0.06173872069588729, 0.06896815848137651, 0.006439940662988062, 0.04714040278590151, 0.06099825578608683, 0.009888940524043781, 0.1030611437080162, 0.02590104382086013, 0.06736725688512836, 0.023910157615318894, 0.05229387285986117, 0.05345777415537408, 0.04256547541756715, 0.03652489544557674, 0.04314016065161143, 0.019119747881112353, 0.01779346976296178, 0.03176563725407634, 0.01682016047249947, 0.07650990557989903, 0.006286766895625208, 0.023026990005746484, 0.0901430786720344, 0.0536424137119736, 0.07246498191463095, 0.0767643019290907, 0.05777581834367343, 0.014813540736213326, 0.048439994121768644, 0.06583377452833311, 0.024917207059583495, 0.033229508703308444, 0.018304047008444155, 0.014039033724527274, 0.031130654005599872, 0.03204690019733139, 0.029429997583585124, 0.016298750415444374, 0.010303430425535356, 0.020367366827226112, 0.013401975855231285, 0.06043298861810139, 0.051864770706743, 0.028214826182063137, 0.016115384808342372, 0.02977934812328645, 0.019656499614939094, 0.05202699825167656, 0.04530193929427436, 0.03065640213234084, 0.045489547441580465, 0.07106465526989528, 0.022553930657782724, 0.008307864872871764, 0.041205979617578645, 0.028893612258668457, 0.05704531432794673, 0.018727715792400495, 0.02070796426518687, 0.01659458320188735, 0.02709272434003651, 0.02166929401989494, 0.026254823497895683, 0.07152399633611951, 0.03213565257777061, 0.03462770814076066, 0.03453398209863475, 0.036501709903989515, 0.09614858177623578, 0.03441932664385863, 0.015326072162549411, 0.033672822772392204, 0.03616696822323969, 0.058949901057141166, 0.017827038586671864, 0.057383421542389054, 0.03940953779965639, 0.04610141300197158, 0.041165925695427825, 0.01872791935290609, 0.007394281082919666, 0.0015950320562946477, 0.04831318949748363, 0.02286252668792648, 0.012384872218327863, 0.021413873082825115, 0.017065666316609298, 0.054493601966117106, 0.05402990131239806, 0.05063835597996201, 0.08804495339947087, 0.010982687235809863, 0.03364911136616554, 0.06038175243884325, 0.06290841328778438, 0.01996167582858886, 0.008276508073322475, 0.011093166307546198, 0.03321935781942947, 0.04391546494194439, 0.02290701653276171, 0.05487822275608778, 0.05890901253691741, 0.024996315761070167, 0.04832424283293741, 0.003542697913612106, 0.009111985697277954, 0.022701878433248827, 0.03552564067233886, 0.036253708747348616, 0.032874176877417734, 0.056644717430961986, 0.08069478387811355, 0.023129440311874663, 0.02448021524053599, 0.03207780407475574, 0.032023039513400624, 0.04370874924851315, 0.018848079423020993, 0.08037461712956429, 0.04498320425461445, 0.016281900694593787, 0.020077232038602233, 0.04923547465088112, 0.023161648672872355, 0.018117899407765696, 0.031234076313142265, 0.027104695394103016, 0.040387255871402364, 0.0719473207635539, 0.0453824949716883, 0.01722950877488724, 0.05823629256337881, 0.009992903963263546, 0.0455275318319244, 0.05119896500504442, 0.0535106286406517, 0.0343350050970912, 0.031953506637364626, 0.044156087030257495, 0.019710200572652475, 0.06590194694165673, 0.04788232993866716, 0.010761585751814502, 0.054195365469370566, 0.03386542493743556, 0.012849902800683464, 0.0314687578273671, 0.04746261531753199, 0.04703143684725676, 0.06520195664571864, 0.04720875501100506, 0.020455617091751525, 0.0190290837282581, 0.046613856218755245, 0.018525492000792707, 0.032692064863762686, 0.07820420752146415, 0.02740773422244404, 0.08485072944313288, 0.023300251324794123, 0.05394110143450754, 0.027986555127426982, 0.02600691224714475, 0.0356028817061867, 0.03300789916621787, 0.006989245294659797, 0.07239811228854315, 0.03415007716310876, 0.029628849056150233, 0.062266946637204716, 0.01064292439592204, 0.033499982939766984, 0.01407921063115022, 0.024180458825347678, 0.06175097503832408, 0.05308943820585098, 0.051443651518119235, 0.011366695647926202, 0.049585215348218165, 0.07328340371272393, 0.027143105565171157, 0.00752526378658201, 0.02337990455063326, 0.07697217791740384, 0.0270299259240606, 0.058522600414497514, 0.029376624019018242, 0.031154840386339595, 0.04352712917274662, 0.02962535460080419, 0.01527069352700242, 0.005194582086655178, 0.004318435618188232, 0.1164448330444949, 0.1479232667812279, 0.11627400506819997, 0.11544146974171911, 0.14314692307795795, 0.09259365538933448, 0.08826357738247939, 0.2087201401591301, 0.1346725770937545, 0.09793760720640421, 0.09500938933342695, 0.17142352648079395, 0.12628597925816262, 0.08934539968946151, 0.10011047311127186, 0.1470942734075444, 0.1884329609040703, 0.10850012435444764, 0.14816775651914732, 0.14125815300004824, 0.09605594139013972, 0.14293892495334148, 0.13708757822002682, 0.13342747890523501, 0.1959414801427296, 0.2878256253898144, 0.09822086164993898, 0.10803843555705887, 0.1281924455293587, 0.21386783250740596, 0.2041095354195152, 0.14087106234260968, 0.16451785846480302, 0.13921167781310423, 0.09917144849896431, 0.1513409526752574, 0.09385811218193599, 0.12225762541804995, 0.17300011616732391, 0.13190158935529844, 0.12992648248161587, 0.11591176236314432, 0.09131066102002348, 0.14734757053000586, 0.0744841799938253, 0.2485648835343974, 0.16011917378221238, 0.132282858182277, 0.10272993719471352, 0.09806565354977335, 0.3187682335930211, 0.06619566439517907, 0.16615538059600762, 0.13532706483134202, 0.11500476460371699, 0.1590458806604147, 0.10167701369417564, 0.12752714194357395, 0.1639033364398139, 0.13973180204629898, 0.1713876048369067, 0.09113512401069913, 0.07671873830258846, 0.057218272904200215, 0.13438609960888112, 0.17285550678414957, 0.06337976442383868, 0.11781696655920573, 0.0663236700264471, 0.10006613763315336, 0.1258078156305211, 0.2088697435600417, 0.10935548559895583, 0.06585809322340147, 0.09790275764784642, 0.15257034956344537, 0.16747346201113292, 0.13376141312931264, 0.05335911177098751, 0.10396450451974358, 0.21263178597603524, 0.15635968265788897, 0.05811131998364415, 0.12368087976106576, 0.12486241278903824, 0.0728156827390194, 0.13460072023527964, 0.1075113902666739, 0.09929002249347312, 0.09041270134704453, 0.10340720335287706, 0.14455925300717354, 0.20499243161508016, 0.20207147406680243, 0.17332793000553334, 0.13180892861315183, 0.1568348878728492, 0.08253735250660352, 0.11723339930176735, 0.10078300988035542, 0.10541490026350532, 0.15294245816767216, 0.16701177321374416, 0.08268910007817404, 0.10123908719313995, 0.09057814175529139, 0.13616428204945155, 0.07197085235800062, 0.1030663073595081, 0.10108031678412642, 0.1304991388959544, 0.10774381565196173, 0.13348225025194033, 0.250845412590674, 0.1272848913712161, 0.20238558149763516, 0.07796916977635451, 0.21565037114279612, 0.19011836046619074, 0.18472045154443809, 0.12447064023997102, 0.14748474316937582, 0.07284830670271601, 0.14816186683518545, 0.12217514270118304, 0.08245760428586177, 0.12099754517631871, 0.13704892886536463, 0.10568779347730534, 0.18894083079482826, 0.16542391984590463, 0.10077405321810927, 0.11286318594855921, 0.0750654809443014, 0.07045500512634005, 0.07386834161089999, 0.09770684423191206, 0.1521228692893471, 0.12337875525866236, 0.1459784632814782, 0.07850076125136443, 0.2734375617333821, 0.12702204047569207, 0.19480095777128423, 0.13851398096552917, 0.061017797594623904, 0.13279490784874984, 0.09258338915450232, 0.07842729626489536, 0.09133366335715566, 0.0793218496920807, 0.16443650211606706, 0.1861725164843457, 0.161359182958092, 0.13412859556930407, 0.12004889893744673, 0.1265824040664094, 0.10558885628623621, 0.23326742010457174, 0.09430362470448017, 0.05366851356146591, 0.14481652634484427, 0.19379473105072975, 0.10098699107766151, 0.17272468523255416, 0.06040134174483163, 0.1660281281386103, 0.1444089032177414, 0.20041080032076153, 0.13663761450776032, 0.16136155783065728, 0.17522652527051313, 0.1224389299750328, 0.10955267466072525, 0.11407004190342766, 0.09098351893148252], [0.0479064586439303, 0.03528125950002244, 0.02698182457658861, 0.012226218008436263, 0.06246925185301474, 0.03864422833014812, 0.020405763427593877, 0.020052938788597072, 0.012675609206780791, 0.021535471647179553, 0.06448503690106527, 0.03819374893126743, 0.017771975469908545, 0.04929829681558268, 0.035893939302435944, 0.031725830997207334, 0.026533815045175806, 0.0339581297843584, 0.02027158991300634, 0.019293500343337655, 0.02122507749923638, 0.0318141559005848, 0.0370148927239435, 0.09589852805116347, 0.03529681491532496, 0.015121220744081905, 0.0373077314746167, 0.029052691401115487, 0.09160051760928971, 0.010548340855166316, 0.04648102281082954, 0.03850074192242963, 0.015276014937886169, 0.037553361151367426, 0.056890903506428, 0.02276637657944645, 0.01282648231634604, 0.035181535208331685, 0.03138050417016659, 0.021339890713404332, 0.036986126231827905, 0.010218132636509836, 0.05923539466623749, 0.004331619553600571, 0.06408348666237933, 0.02209767692589334, 0.02314396435394883, 0.010594549089936274, 0.013666856418629842, 0.01707091648131609, 0.015117383628551449, 0.021414963827867593, 0.03306475022275533, 0.05845171386109931, 0.039901268734995804, 0.03498495343540396, 0.039156657976231406, 0.021797454017879705, 0.02301610291137227, 0.022756605675177913, 0.017555784034941877, 0.043461236637085676, 0.0258073788468859, 0.029618766025773118, 0.06212245260498353, 0.03497847681865096, 0.02014322465817843, 0.034292980030711205, 0.016014987070645605, 0.02593918257792081, 0.020724981923454573, 0.022375986545479724, 0.002569150075682306, 0.04673468294952597, 0.04309002709175859, 0.02017996902577579, 0.021208505977743437, 0.02174064197710582, 0.032797068157898526, 0.010451719164848328, 0.001885636942461133, 0.02991698895181928, 0.03546202801434057, 0.02079066920227238, 0.048187558738780875, 0.06595762073993683, 0.06511922287089483, 0.010997085748905582, 0.021553878605897938, 0.02548424181129251, 0.023536625783890486, 0.010828138162781085, 0.049290500448218415, 0.02388270408846438, 0.054223131122333665, 0.019302165235525796, 0.038250647485256195, 0.036401100124099424, 0.012289057984682066, 0.051427264897418876, 0.03986079412113343, 0.02490773471072316, 0.04373985668644309, 0.10411353795123951, 0.03330532481361713, 0.06174030846783093, 0.04150516267067619, 0.03726538410410285, 0.08380267103867871, 0.07739773472504956, 0.012938111504938985, 0.04690806221749101, 0.027948804831664478, 0.05612502406750407, 0.08194723060088498, 0.029895431894276823, 0.05751257389783859, 0.011310187251573163, 0.04460763172911746, 0.05896005194102015, 0.02201633245152022, 0.011309510412892061, 0.021962724792371904, 0.0447660560852715, 0.02309896730418716, 0.029681686578052383, 0.06120652532471078, 0.039474816261125464, 0.017829235343794738, 0.021754553641325662, 0.027312164261404957, 0.04047890220369611, 0.0026497627924462514, 0.053326382634363005, 0.051095647870429924, 0.038923805113881826, 0.012294952757656574, 0.017769524262153676, 0.025707859812038283, 0.009296271567499, 0.026017617833401476, 0.04229080783469336, 0.07752105167933873, 0.023269104871100614, 0.03586819229115333, 0.030534472782164812, 0.04087263911164232, 0.03608225651883653, 0.011235600137817008, 0.023182091236646687, 0.04625793406739831, 0.05769619225923504, 0.03725322814924376, 0.020455976715311408, 0.06864816136658192, 0.10031717523400273, 0.03509680314787796, 0.036073530558496714, 0.03374485604997192, 0.034513486948396475, 0.021253891488803283, 0.010377737643596317, 0.018967912099989395, 0.014455817074381878, 0.02828168054111302, 0.036057198220597844, 0.05254754317658288, 0.0390922514322613, 0.0323873754989888, 0.03951323152120624, 0.052882335747459104, 0.02289710143980171, 0.031120862745280777, 0.05266753191660557, 0.09655950258352927, 0.03339919334809695, 0.1041947789490223, 0.019017679250932167, 0.017470039260972823, 0.03265122723366533, 0.02791464907516326, 0.007607137518269675, 0.04667992178084595, 0.02619498858361372, 0.02582516664239977, 0.03131552765678082, 0.03875284482325826, 0.006058884726371616, 0.02720936281340463, 0.027432349776583057, 0.05122829128855041, 0.0901587935430663, 0.04781385896993535, 0.011721975735521742, 0.00742611285698201, 0.009267825683179711, 0.03615770282756005, 0.016843819292262197, 0.04362319955336196, 0.022057663715843643, 0.023920444206201603, 0.08164678207997765, 0.05773911638451474, 0.016948909099612917, 0.04070493918178337, 0.04055602788659079, 0.011403700403336967, 0.08770358921693903, 0.0560498016753367, 0.04624791210517287, 0.036101910285651684, 0.0318011042795011, 0.05941719455378396, 0.03830811261598553, 0.007420934786620949, 0.044695393448429446, 0.04818605239103947, 0.014372935718191522, 0.08101509311901671, 0.03579848299601248, 0.061625195001917224, 0.03539704132292952, 0.01656618481501937, 0.027097991468118768, 0.002063158666715026, 0.03469250823504158, 0.013427786479171897, 0.011319979360061032, 0.06014498442943607, 0.025674654004563178, 0.04577449143731168, 0.02378034538456372, 0.04847199044057301, 0.026060572492757013, 0.02806375714551125, 0.018731997348368168, 0.022343479629073824, 0.019826079086799706, 0.056549084705433676, 0.015327349504722016, 0.034055642051888366, 0.07288255915045738, 0.03711040331316846, 0.05157688865438104, 0.019446671142109802, 0.004262196515420718, 0.05485087440216115, 0.06716492452791759, 0.01636878031838153, 0.00968790247238108, 0.00740777375176549, 0.04995784303173423, 0.0053177255904302, 0.0505527621800346, 0.04437561685751591, 0.06767262478492089, 0.05982658865728548, 0.052193955185690095, 0.044014028938753266, 0.02349804767540523, 0.005694726008057062, 0.07831329559641224, 0.03105343332780259, 0.01807991332108421, 0.0331098999428962, 0.02802419176857386, 0.05997174086847475, 0.0302067030487316, 0.005792527925223112, 0.054389677542660914, 0.008924493749093796, 0.021675928396039774, 0.06201461303446974, 0.023717502863811593, 0.04403935186564922, 0.03298251177849514, 0.02828992813426469, 0.012560037729729499, 0.03296920231410435, 0.01357359517299171, 0.022748880553990602, 0.024943829381040165, 0.07935184093990497, 0.08153014869562217, 0.029570233808564286, 0.025515261039670025, 0.015578695839004857, 0.02365072992896395, 0.015431285802541035, 0.03733537159860134, 0.010154501318798533, 0.027532186026551893, 0.04763439663552812, 0.013158753281459212, 0.033405751389052184, 0.031692962760904005, 0.009470435391579355, 0.012190258196954216, 0.029337438621691296, 0.008725617679634264, 0.006168020298771028, 0.0312762269085007, 0.06124162594122546, 0.022288280805306773, 0.04226026018815381, 0.03311727222587381, 0.016277809128431336, 0.016321270992713313, 0.03705157771972673, 0.013671883514949253, 0.022340753614636402, 0.01674317897829626, 0.02101599032591496, 0.031151451103921448, 0.04981377986924989, 0.04854508562545691, 0.02901610140023487, 0.019923233427107334, 0.008900312457366713, 0.05728322906153543, 0.04773502677146878, 0.06516595357762915, 0.05923944552029882, 0.02089411186586533, 0.026463028575692858, 0.014905724807509353, 0.040391109950308285, 0.04531577123062951, 0.010226785654335149, 0.05159966368228197, 0.04813397143568311, 0.01753204039830182, 0.01601277674282236, 0.02858516380989126, 0.05695076725844826, 0.037625998325113735, 0.06627579938088145, 0.013603309069627097, 0.039223870262503624, 0.04587878226967795, 0.08296507384095873, 0.01618081933286573, 0.06157178072524922, 0.04992370932762112, 0.0478459638543427, 0.028571898450276682, 0.049084476860506196, 0.02646066388115287, 0.05015769534345184, 0.013209809648937412, 0.05850510099636657, 0.022436805335538726, 0.1601969746074506, 0.12538548186421394, 0.09830775484442711, 0.07488860043564013, 0.08795411113117423, 0.040502420227442465, 0.11789142899215221, 0.09877831887985979, 0.19237731210887432, 0.0876134390543614, 0.09523180632718972, 0.0798169020563364, 0.11707745838378157, 0.11793067545763083, 0.15436667603041443, 0.1077858983938183, 0.25308626091906, 0.1284832792090518, 0.07908213684069258, 0.08825312115784202, 0.09905129351786204, 0.1330084835312196, 0.1855751071125269, 0.11295708840978996, 0.1112528255741511, 0.11728225382311003, 0.14595943715955528, 0.07831721752882004, 0.16465777238564833, 0.11517187420810972, 0.12974018390689576, 0.11053798893200499, 0.1394591259637049, 0.14184191024729184, 0.1265493051281997, 0.11444596387445927, 0.11966296178953988, 0.14256837697965757, 0.12380239181220531, 0.1390675026923418, 0.15248554625681468, 0.13245634601584502, 0.1989205881421055, 0.16187776013144425, 0.1383424744542156, 0.14303413698715822, 0.1348509503794568, 0.131988170423678, 0.12093744054436684, 0.11492946078734738, 0.11866706237196922, 0.037391595010246546, 0.08901711087673903, 0.14629376493394375, 0.103133835164564, 0.1437848409903901, 0.11806246052895274, 0.07596766110509634, 0.07266901739473854, 0.054309142221297534, 0.08679366697158132, 0.1176680824054139, 0.16263613158038684, 0.09612243103661708, 0.12545245327055454, 0.16136026861412184, 0.1074446699182902, 0.20424912364355155, 0.08133549056947231, 0.0659280162570732, 0.20502867895577634, 0.1904922875442675, 0.16135333398623125, 0.16602027070309433, 0.21178812267524855, 0.1313817636775119, 0.11938309323574815, 0.1454721675919635, 0.10897843725979328, 0.18768631454024995, 0.07949962586696659, 0.11457873960690838, 0.11164348532578774, 0.09398420434445143, 0.17613759424005235, 0.1985547627721514, 0.10912307378436838, 0.05940001404711178, 0.11222175322473049, 0.1336366848221847, 0.13275047737572873, 0.11333995179406234, 0.19147156285388128, 0.09315042051353625, 0.1660481042095593, 0.13885921958301747, 0.13939283309238298, 0.06456376731927906, 0.11174162184553486, 0.1331868025341204, 0.19674943893083505, 0.09184759935098034, 0.11848811911685125, 0.1317098896418299, 0.08013677703482763, 0.07300761993974447, 0.16682577319443226, 0.12720889544912747, 0.1329003114785467, 0.12080755537109715, 0.08148759776460272, 0.10241141250090939, 0.08932106063834258, 0.11420988797077111, 0.15011817828885146, 0.15776336805096694, 0.10321298627448933, 0.09027689934841224, 0.1983832698315382, 0.1845284261341606, 0.08369590355349438, 0.10507663020065852, 0.10785675102046557, 0.1395432778767177, 0.09705319109239749, 0.08897004090249538, 0.186904533633164, 0.11372845380433969, 0.11473246850073338, 0.08204483786331755, 0.14041147700377873, 0.12777342301394257, 0.11150889790483884, 0.10914239846169949, 0.1617680817310299, 0.08316540451986448, 0.1240851916372776, 0.1523920577019453, 0.0873725659080914, 0.14820127614906856, 0.1044508105676089, 0.11499375876571451, 0.15239127060132368, 0.07350628211029939, 0.13944639664675507, 0.1712220830044576, 0.12714390536504133, 0.08635683291192565, 0.12199948355555534, 0.17625291805182183, 0.1209568873580013, 0.22502450884452888, 0.14993373890008244, 0.16412141759480747, 0.1318485007754394, 0.12321932667068072, 0.1219838908208268, 0.11138197792960064, 0.11511763211871896, 0.09183287514107567, 0.12768984107034548, 0.15400987517620834, 0.1181924542678254, 0.13782380228596075, 0.15581016428768635, 0.18967515496270998, 0.14131848833390645, 0.0930267982184887, 0.09829437413385936, 0.08121769010488476, 0.11582948320678302, 0.09263781444834811, 0.18239463706101688, 0.10823313439530985, 0.2094177691532033, 0.1475979228104864], [0.014081982446701398, 0.01824317393558366, 0.006412482895289681, 0.03609324200078845, 0.05413863315646138, 0.018812680251098106, 0.05592567047902516, 0.03344798001593777, 0.028400132399318472, 0.04984370665624738, 0.006422256768148924, 0.021342489502525756, 0.05311492058847632, 0.032920313866010735, 0.014838252981592501, 0.01605425219583724, 0.03367084823548794, 0.05241847563801067, 0.0663285351225308, 0.03660755118887339, 0.03597979433834553, 0.008573954924941063, 0.04989293437185032, 0.09308549149760179, 0.012124211294576526, 0.04381032594080482, 0.03551143214904836, 0.04308930445196373, 0.0425496384102319, 0.039465086068958044, 0.03284480309646044, 0.06181237567216158, 0.036432964128575156, 0.014301686148558344, 0.005899928144312331, 0.014468999313456672, 0.03733954798164112, 0.04779059878949608, 0.02480999513396195, 0.024907235987484455, 0.027409357617476156, 0.03080018370279244, 0.007587200463084238, 0.01467453605229301, 0.038415385609758754, 0.035070299570049555, 0.08721021961952959, 0.07483422263924565, 0.02564332604275218, 0.010517265647649765, 0.05353541552488293, 0.009236652936254228, 0.03519139092947755, 0.017825944448954294, 0.0465193464686828, 0.05073516596374767, 0.050958750037742515, 0.03721672975059066, 0.03381831764376589, 0.021271536791963235, 0.03456090636817472, 0.039345358564917526, 0.05546936924968447, 0.06476559077522584, 0.023838076840287874, 0.09230114572814532, 0.046160269129489145, 0.01797597871960274, 0.03621031643290605, 0.02315788110718131, 0.03600469318085483, 0.06369923906666891, 0.0750274219151054, 0.021824513994423405, 0.053179842819060595, 0.07052443282944815, 0.09567241304154907, 0.039954530341284614, 0.01894909462758473, 0.047224093295101605, 0.10727350945983614, 0.07812513783574104, 0.03460997123537319, 0.01929642482926803, 0.05367869497942073, 0.008593229560314544, 0.06440062035939523, 0.054510721404637606, 0.0171788476540574, 0.005509147104541106, 0.026020935869642665, 0.02636236620933882, 0.03750500874593854, 0.02999826387635299, 0.06046287130032267, 0.0874176477747304, 0.03220593184232712, 0.034665488970599005, 0.01457586688255625, 0.022541628817894628, 0.0213894576965166, 0.0324378313629755, 0.008032320283486374, 0.041074143656130345, 0.06993642116763762, 0.010734166999879693, 0.022883096477016807, 0.06381118377404553, 0.052857793135834594, 0.04645844116540892, 0.007649105757341853, 0.05875607752906425, 0.03326616995036602, 0.04063298732840589, 0.02132697819199945, 0.007265582497763846, 0.02306117459998599, 0.051502653530665805, 0.02287148674284773, 0.036838276843939505, 0.05705350424562182, 0.04585186478548816, 0.04397966792540891, 0.06929265428334475, 0.03674795026225703, 0.09384578998599734, 0.020076256644512926, 0.02361904743260571, 0.03185805033094116, 0.013936437533370085, 0.021935619014714445, 0.05981993901410273, 0.01807979118478085, 0.048259921105844636, 0.03779368468427232, 0.019205207670373575, 0.023618533442329084, 0.009445288035619472, 0.07913792598992586, 0.04012008610048464, 0.07300397620669433, 0.017273021529295614, 0.03556892102850335, 0.015143481781706214, 0.07795054399009262, 0.03345391719735094, 0.047459422810269256, 0.03897804381059749, 0.03878805400537593, 0.03466164506971836, 0.037597248796373606, 0.05839446586157594, 0.019860655535012484, 0.037242643002952845, 0.00926738717992391, 0.030238489021680186, 0.0617066870576569, 0.01394433992183102, 0.020948822144418955, 0.017570243616189276, 0.03915307531133294, 0.051007645271186314, 0.04361197319147842, 0.05043505331767457, 0.01349306239613465, 0.0770781718726669, 0.01999256104630019, 0.003924761898815632, 0.0187540192023984, 0.0662138219922781, 0.06673363409936428, 0.03515474325312035, 0.020656495687684844, 0.013270128019420164, 0.010718736265386854, 0.029550766638879265, 0.034096065775624344, 0.032152721126164706, 0.03248149169875043, 0.011700880081791962, 0.09082081301936082, 0.03963215156857457, 0.027581956570169756, 0.008106941323993462, 0.028925170922385793, 0.036703343370131085, 0.05701393886868443, 0.03393335647082754, 0.04825877777433821, 0.07251127835895334, 0.016058080829679966, 0.03973717861143606, 0.02968743716233543, 0.03484950427498136, 0.06214644560324294, 0.0816775265016726, 0.009076787541354341, 0.024929284982915436, 0.08082325091319424, 0.015324421626116549, 0.04826442997104355, 0.019665515648999383, 0.008735659997910261, 0.03585236206916826, 0.022269385301374962, 0.006850295741709748, 0.04547393435080137, 0.0474961485181536, 0.024435813605253185, 0.0075528190936893225, 0.0034868994345223264, 0.01269532913076026, 0.020126390204365765, 0.06441902222910098, 0.02244816910076354, 0.01090774473933769, 0.047878465681735954, 0.021612096910497973, 0.029202813881316354, 0.04680020229092666, 0.014887022686057856, 0.06416185745703322, 0.01756279499802206, 0.017087520233222415, 0.025216344311567288, 0.02771824541767793, 0.002420452519020598, 0.020562759467533658, 0.015164972682084357, 0.021796636383182237, 0.01938618313787239, 0.03618632343464664, 0.026028744111369764, 0.05168560353506889, 0.06162634172609874, 0.029099927616438696, 0.03580899689612644, 0.02101969512711678, 0.05814623739570379, 0.06984393005924565, 0.05475478366549526, 0.04906882305762597, 0.02631263298514698, 0.05172825285366603, 0.005865042538581682, 0.035463249377374134, 0.009107765209461962, 0.06144627888820001, 0.03610614773684314, 0.05431894026696682, 0.018253928715629236, 0.07976029866508075, 0.04217246454209089, 0.0720590686957751, 0.05454496028167861, 0.03426699213949697, 0.01642258814536035, 0.05304194075454559, 0.05978147964924574, 0.024861248276595558, 0.0221979762760124, 0.03164000649537359, 0.029784532130828927, 0.035399999735610824, 0.010329804233541446, 0.047858170699328184, 0.02963085751980543, 0.008955857333993273, 0.03488264392529215, 0.03508818575314113, 0.05466824330921684, 0.020411150995641947, 0.02722056203388742, 0.014694602029131991, 0.038701364371393404, 0.028666886567537273, 0.12125994823873043, 0.023562946157263856, 0.051403261721134186, 0.011284264669354473, 0.006235391616688243, 0.05290778759600861, 0.03527951905769961, 0.012382959597744048, 0.03373935991632087, 0.05185090145096183, 0.01734051201492548, 0.03964361881038972, 0.033660517539829016, 0.006424430200630533, 0.0011031333955803088, 0.0283280024304986, 0.03901081705199821, 0.03117499966174364, 0.04824511547173772, 0.03547709149175456, 0.012746728158422878, 0.04293368583811181, 0.05575434038681643, 0.06602848015193429, 0.052054356783628464, 0.05162948190367647, 0.01832890683518989, 0.0732675599200385, 0.00982973919183548, 0.04248287395707198, 0.02028976277714329, 0.047962617594748735, 0.036556247156113386, 0.045188861433416605, 0.04327268871877875, 0.047602868505886624, 0.039464858759726794, 0.03537396773962038, 0.05785998382738658, 0.02066315890156797, 0.02065628194915397, 0.02552644329677735, 0.028963640465268066, 0.03879031013431294, 0.03668110777756997, 0.03993794694542885, 0.04404235099043165, 0.015239916874894073, 0.09011869212346417, 0.06600800875042166, 0.028234902336927395, 0.018229952680745294, 0.016545033182150552, 0.03361199550064547, 0.052165870621268234, 0.028460153910730566, 0.030083430199218646, 0.050810171224709065, 0.039135742134281566, 0.028376902752955045, 0.04363193569172706, 0.02648202416353992, 0.03027825117377298, 0.021585542442543165, 0.01449420688939946, 0.00741246242874435, 0.0447331708855927, 0.02292502485215664, 0.03788621650476541, 0.046261214784213474, 0.01902198794830058, 0.02685244321557028, 0.005679930127891046, 0.009035709879494138, 0.05749664868095091, 0.026300536402102028, 0.10811390222183295, 0.09336601144501142, 0.11050334971930299, 0.12077721128506319, 0.2242254660065685, 0.07213219441473484, 0.1213626784405538, 0.13736128567584924, 0.08162135737282888, 0.1700777065541063, 0.10263249956603561, 0.14653206643249306, 0.13996725369776997, 0.3149789140692779, 0.11724772996136121, 0.09831213818064757, 0.1771744228899479, 0.29819830879569054, 0.16038692370057106, 0.16590475690151962, 0.08099791261234454, 0.15627178523157323, 0.19961054969046796, 0.20035792887210846, 0.15335519744881562, 0.14461354937936577, 0.18311950245073863, 0.22348658208336147, 0.12918686574058874, 0.1203616764396429, 0.09130067298454897, 0.11619646208626883, 0.09152100687580449, 0.0927910887237106, 0.1172248904726335, 0.09765689726918936, 0.06899995463235037, 0.10095708803938967, 0.11234947387129068, 0.0906567025397505, 0.1320906834942954, 0.22484332642384938, 0.07806105698857989, 0.10123360463018928, 0.12071170551436287, 0.1888822325106178, 0.1784083523920604, 0.16436556806521757, 0.14689624974770205, 0.12757378444075584, 0.1242256076740367, 0.13417930927659782, 0.15223569609224796, 0.1086861922272614, 0.1516540287328618, 0.09141862951219082, 0.10056621794189725, 0.1534168627113104, 0.15157895561839851, 0.059998855127819946, 0.16780118085443974, 0.21726045331784657, 0.1836848442575761, 0.15846513610865387, 0.07308241485485009, 0.15486335009336472, 0.21195593795606069, 0.19896720349788666, 0.15184316358395986, 0.14426590874791145, 0.10338724763797862, 0.20117122094546044, 0.20516287961176463, 0.07664107996970415, 0.0994867772928306, 0.21681390942207404, 0.17226246717785085, 0.16670758596488408, 0.23764250533921377, 0.1687693146190473, 0.1746361455214875, 0.12441679170089108, 0.11563067244631903, 0.11690175852605275, 0.1777001382516963, 0.1590333684746708, 0.1075557664568935, 0.11027932459754602, 0.09505797244076218, 0.07854843512177467, 0.10553004765616995, 0.14508959597774915, 0.12544346946690763, 0.1035815461405686, 0.15196586985673222, 0.15548610953348024, 0.15145021038396017, 0.10727936521704708, 0.09440837694065911, 0.09555319443877254, 0.19332641975155898, 0.11419379312012877, 0.14473776199987956, 0.15211977516966207, 0.1894973652171237, 0.10833291975515229, 0.09392659672136817, 0.152949365654162, 0.14378581808081695, 0.1816066950559616, 0.1130591332912445, 0.09046880940773658, 0.09134952750589166, 0.11342797135668141, 0.0842363295544471, 0.09822635778359004, 0.10080327093601227, 0.09617311081715993, 0.14748453960887023, 0.10975545485104833, 0.09401664510369301, 0.1538404721234526, 0.18929277333830083, 0.18348239654941217, 0.14881160482764244, 0.2061009407043457, 0.05555472556235535, 0.14255038223096303, 0.12556671856769494, 0.18946322133498533, 0.07088605128228664, 0.10054082716149942, 0.08885796048811503, 0.1349373414580311, 0.09957314801535436, 0.11885979345866612, 0.10072169067072016, 0.09479814102607113, 0.12846780861062662, 0.16163280898971216, 0.08917704836598464, 0.13651739167315619, 0.1751627294080598, 0.1207823817219053, 0.14362271183303424, 0.07315511988209826, 0.14811686639274868, 0.09579541108437947, 0.22565948191498006, 0.11407827931855406, 0.07248611828046185, 0.11082623060792685, 0.11083625257015228, 0.07837466230349881, 0.11911450193396636, 0.09756910840847663, 0.1541916411370039, 0.1493825920458351, 0.11629427969455719, 0.09796260443649121, 0.13005214716706956, 0.13449196464249066, 0.09252584259957075, 0.1700609331684453, 0.14582814063344682, 0.18440216433789047, 0.10387406258710793, 0.10868870959218059, 0.08487128905419793, 0.11452252976596355, 0.12641217320093087, 0.13614455025110925, 0.0882022785288947, 0.10824560586895261, 0.10927948289151702, 0.06543237356735127], [0.007753382170838969, 0.025470184262043664, 0.027758640303675617, 0.07407785965395824, 0.06333924909787518, 0.016666803076597195, 0.013945452719261604, 0.06334551197609731, 0.004163018444419971, 0.04457690766347306, 0.047037845610507896, 0.052778991471443854, 0.04098800024283784, 0.05005461569609387, 0.02747265136401568, 0.11532886007002421, 0.003589557541999966, 0.04336219088041356, 0.01553292865199702, 0.04854079389146396, 0.04083915680114712, 0.010114694213760751, 0.017379694019577334, 0.0671112524079425, 0.010899875429458916, 0.06128121167421341, 0.013557536793606622, 0.052105240124676905, 0.04820271381842239, 0.03670058173260518, 0.033321762324443886, 0.035102557124836106, 0.0644474189196314, 0.03326561015897563, 0.061221487021871974, 0.03527121039639626, 0.01748718075188143, 0.0607669839103307, 0.047291013811315806, 0.03153332382706659, 0.02306673689080136, 0.010549390888107675, 0.07468651235103607, 0.09133628928767783, 0.035818849224597216, 0.04217440854491932, 0.04346023240525808, 0.013961675643388714, 0.03123793039204819, 0.0339811219434653, 0.10442498552479915, 0.001968533141605024, 0.00973506404885224, 0.048666865697928836, 0.03502808451386435, 0.024385379793654596, 0.053602488711476326, 0.026236679471497024, 0.07581391864057098, 0.03163420841363924, 0.03727707865514925, 0.02779302167307053, 0.024989657636199678, 0.03445364355242678, 0.04426141941387739, 0.07672687393746205, 0.025559448936421956, 0.0544452597387135, 0.02376897992300136, 0.01740613652925406, 0.0447931635592665, 0.023821405234879682, 0.034917870070785284, 0.07111648177461964, 0.037944438202040534, 0.028866603172251155, 0.014432921606515135, 0.04442958074754902, 0.06558883695730142, 0.02017584183652486, 0.0202969637300287, 0.02409087523951062, 0.019610839297196696, 0.009400986484251916, 0.004708823531733027, 0.06927689870021173, 0.023059780210522667, 0.0031271232042594677, 0.019444202970979468, 0.045174849685281515, 0.05719195931617703, 0.07412625277148825, 0.014594329820413674, 0.11334063711443118, 0.011578657265220369, 0.03164872906303831, 0.002129211082189743, 0.06371941191277333, 0.029173996499074355, 0.030156440567225218, 0.018596278470275656, 0.027993713671873723, 0.011132535757496953, 0.022255373553239872, 0.045993943233042955, 0.04891448008960911, 0.0414679110981524, 0.06059417461178132, 0.023851189529523253, 0.025944000176553215, 0.03061120830742376, 0.009933641562903566, 0.0473905209718006, 0.04740243265405297, 0.07577480109674589, 0.023567617870867252, 0.007013162805898381, 0.04752951887037073, 0.060700168567044396, 0.11285851084228073, 0.10432067433638231, 0.04851216649902718, 0.04413810585226331, 0.028830603496836762, 0.059496216742055755, 0.05159971796508346, 0.024066254596358964, 0.03578728377552969, 0.12735122495463916, 0.03642328482653413, 0.029369709747178212, 0.02760639740154147, 0.027770088885777762, 0.048474623156445365, 0.039060438317911964, 0.08869425034416573, 0.034179932703929286, 0.04709921231759446, 0.05889449188751834, 0.03705645977918591, 0.026954800223133395, 0.01177134339897228, 0.07883067176278148, 0.017469114757009914, 0.015081590906317745, 0.03587561207158225, 0.041227750413651974, 0.07418377897036926, 0.020087557645248513, 0.020727200732965554, 0.015722323042739714, 0.05504451133310795, 0.023466829975534762, 0.021453221328556538, 0.00816451502032578, 0.047322949061968496, 0.02623380926836814, 0.03191580044637833, 0.030248460093779222, 0.028633692634424994, 0.06409536781055586, 0.04858578754855054, 0.040983060507902076, 0.025857951758163314, 0.02185987075790763, 0.01649819390981325, 0.03053776706968035, 0.021352511464751193, 0.010948577280422407, 0.02006175465482686, 0.020993157622537444, 0.028487851710191796, 0.0061668723023363525, 0.0405209306627512, 0.07144576803381954, 0.049409576558641026, 0.00510315755049565, 0.03860184703288334, 0.018494683118270974, 0.08008578512817621, 0.02882368243964655, 0.05812676344066858, 0.029433746489563158, 0.026098840171471238, 0.03349849694807615, 0.033896847894149165, 0.04468217897894127, 0.052696610534829755, 0.02244753297418356, 0.07840856191303049, 0.017457978301016346, 0.06682119904352085, 0.016228706941806843, 0.06837875582277775, 0.016266542054446678, 0.011643761852090912, 0.02847726995657597, 0.012916267766351146, 0.025534965696611574, 0.00945620481590075, 0.021133086810420667, 0.024211269404206957, 0.02089280907862953, 0.005602354491462133, 0.049971159281475205, 0.08191523088940553, 0.042093296468790085, 0.024410926637106707, 0.03263178042003086, 0.024139398975031715, 0.011815318405362112, 0.015550974290817976, 0.019885800346466045, 0.023514318945152417, 0.02641155830185328, 0.023546149022877216, 0.04968202533200383, 0.05307880895478385, 0.03758681292778679, 0.05379179658900414, 0.040430454803364616, 0.07061703928879329, 0.028218483485813652, 0.04752383613958955, 0.0245676393886762, 0.09912904006029878, 0.03285512700676918, 0.037321699117975574, 0.02076913758979312, 0.0572226969525218, 0.04159892603222813, 0.005753781879320741, 0.0902177853775876, 0.027052823088264892, 0.041869627577917914, 0.010784365868728076, 0.009443833426173245, 0.028638174358223165, 0.0477422429913921, 0.03776344237849116, 0.020673783063622456, 0.04018219580341663, 0.010937980259768665, 0.04108695778995752, 0.036225457941847186, 0.04127752434994493, 0.05181513247745378, 0.02464309078641236, 0.06642439176461526, 0.026257162747372473, 0.014197510667145252, 0.04591972507270319, 0.038445878973496814, 0.010136576119943388, 0.008475199241989424, 0.06755221196051155, 0.021544173858793716, 0.011078375092308437, 0.030673321403030838, 0.0068794184647101375, 0.03384952686194863, 0.03227124083787203, 0.04247787315398455, 0.013865743514283426, 0.040746404456772974, 0.01581775051142488, 0.03901121738765921, 0.036533682474068234, 0.02864119383905615, 0.08074193527655942, 0.01075321771869702, 0.07466182724705764, 0.02570517620603953, 0.008471569079639656, 0.03527117307697024, 0.022125400170417767, 0.006535861341814909, 0.07530065439641476, 0.019966793678967015, 0.05838883402092116, 0.051944301796278784, 0.009787633549422026, 0.018006338072674613, 0.027734231702717285, 0.02201266836241952, 0.04908876180914896, 0.029416528663464954, 0.024523010444162146, 0.026242896548605392, 0.07333404956651585, 0.009045607160909899, 0.03547570049496634, 0.026673357468098402, 0.05062679713591933, 0.02558467856475285, 0.05853098710732801, 0.05884098261594772, 0.031990863382816315, 0.07389521838298865, 0.0367750238095011, 0.06950889660843781, 0.02652898896485567, 0.0142103765392676, 0.032557345128485134, 0.12688372789749078, 0.05627957398870161, 0.019631597379754697, 0.019313327136582563, 0.03365013934671879, 0.034021779761782715, 0.014985948002764156, 0.02000853545697672, 0.02270779525861144, 0.08657842887831585, 0.05702272589717593, 0.014062167527819318, 0.033370138478598425, 0.03734694401334439, 0.049381305397089036, 0.02270355780741998, 0.006176423530892602, 0.0062517727242915756, 0.015737220279074142, 0.07327003657285656, 0.021396584010549953, 0.009224589431791433, 0.020844019018113613, 0.026324648143989698, 0.018653718155941794, 0.07443833138261523, 0.020184886708323444, 0.03502970960523401, 0.006118804457530911, 0.0008904797785882172, 0.011154686533180731, 0.05451907417071717, 0.06485287073467459, 0.050816026981920004, 0.029027388830270087, 0.005436289830998118, 0.020905440008001666, 0.02375094955121832, 0.008217210049874015, 0.011236076808667608, 0.04126136503847582, 0.03485045422400747, 0.0196586539636233, 0.029309384591345276, 0.05427909329799669, 0.018463758884796073, 0.028565635572054555, 0.007510099377083991, 0.07146901464355843, 0.0794727558802281, 0.21434144995042256, 0.1251300677124943, 0.17737160516636713, 0.18650358729064465, 0.12402577911104475, 0.12406457774341106, 0.08758004834609372, 0.19098118559590407, 0.06505092153591768, 0.15769136191478797, 0.11906165762671403, 0.17233650891908578, 0.12093558135841574, 0.15466350795967237, 0.1061351244736995, 0.11329892756683485, 0.09196301137230226, 0.11417266353964806, 0.09285385999828577, 0.13452650207493985, 0.05175940100369709, 0.09998352599463292, 0.1028014412149787, 0.20872647767620428, 0.1330333450543029, 0.14152111246117524, 0.10571645479649305, 0.2975271019552435, 0.16729184532804148, 0.09586453344672918, 0.2759416816490037, 0.10540223201470715, 0.07731838683996882, 0.09785314995263304, 0.09843157391463007, 0.11315353108303887, 0.12450426843549524, 0.15092412861330168, 0.09076282541666712, 0.10810927461300578, 0.20757108181715012, 0.1656236941260951, 0.1776205189526081, 0.11833114682563714, 0.15304170069949968, 0.0781132091901132, 0.13712583402437822, 0.25129769689270426, 0.1605035231581756, 0.10497547420007841, 0.06448418873229197, 0.08275397481130702, 0.07671924720385245, 0.11244970706424542, 0.18874324139739784, 0.08371354546397924, 0.09474404821438448, 0.09369140291320426, 0.10202595711286579, 0.08685908453272921, 0.08528925984033517, 0.1510556558413165, 0.12252105985369001, 0.1260169129818678, 0.11302120318370205, 0.1985682656190225, 0.14060139895549842, 0.13185460759060724, 0.13382462545164994, 0.12818346172571182, 0.2218993936798402, 0.14097673738641398, 0.14475116985184805, 0.1417571883648634, 0.13871253388268606, 0.09460655666355576, 0.09037875424006156, 0.08411926869302988, 0.11928116370524679, 0.07523656676390342, 0.12734137262616838, 0.08711377943732909, 0.11377616160150085, 0.17284853144415788, 0.10220962975706373, 0.08993560980473246, 0.1273213287017175, 0.13610610445695265, 0.22008254831390722, 0.15949270954089506, 0.08337541789348636, 0.14977583023054258, 0.0711228328623942, 0.10965353210589715, 0.20484726583319052, 0.14428140648773738, 0.15539753357214586, 0.1155252145337207, 0.09680655718381916, 0.11581470471407686, 0.07355004083365202, 0.09077872349215405, 0.16910478233226708, 0.1239874961652926, 0.10133218898304872, 0.10890128104282276, 0.10844494588673115, 0.11845966135816914, 0.10898759069719485, 0.09653764018522841, 0.1584422287664243, 0.15680503233202867, 0.11928705338920866, 0.08439605669783694, 0.16642203128763608, 0.10768354138625519, 0.17414770887366363, 0.16018781438469887, 0.17985804245940276, 0.1765184695167201, 0.18803688644298486, 0.09211574281964983, 0.12779243556516512, 0.06957710294851235, 0.09812674884285245, 0.09159413259476423, 0.2915099619754723, 0.13490236976316997, 0.1009927721960204, 0.17549001398895467, 0.16779801888125284, 0.0856017591431737, 0.13084660310830387, 0.1834330806242568, 0.12236876945410456, 0.1834729513419526, 0.1259793492832354, 0.11202623335910694, 0.08760411598320518, 0.13291990756988525, 0.10887428213443075, 0.0994810504572732, 0.1452254115470818, 0.09723243968827383, 0.11621825663106782, 0.2079950983503035, 0.11772806490106241, 0.12596051315111773, 0.11325346572058541, 0.09167819629822459, 0.0896784518180149, 0.22066353713827475, 0.18395407338227543, 0.14275033293025835, 0.1401698099715369, 0.1028882394145642, 0.0931215759898935, 0.1309970478926386, 0.28425403418285505, 0.11868477213595595, 0.13505911135247775, 0.0927190011633294, 0.11491602579397814, 0.09188322922480957, 0.1045290252992085, 0.06344262390796628, 0.13036937585898808, 0.08683836885860988, 0.05069391781996403, 0.13120866939425468, 0.12100310916347162, 0.09034463749932391, 0.14875468931027822, 0.12857815197535924], [0.018266710619043027, 0.053721259481140544, 0.019029160063447695, 0.03571345577282565, 0.08549231144466571, 0.023387468519753644, 0.020682398762021745, 0.036655733960547617, 0.012412050938499826, 0.04265749494412115, 0.020172995382121632, 0.15891851963741438, 0.028097497299313545, 0.09137303195893764, 0.06003051557179008, 0.059168518254799504, 0.015647687583363483, 0.04311173003433006, 0.03888984443619847, 0.03274108901886003, 0.07773862393306834, 0.05757062256868396, 0.023421980507139648, 0.03119039562131677, 0.036808499334646125, 0.03164501069113612, 0.04339316939668996, 0.0447967767582408, 0.06424247420259885, 0.04709709528833628, 0.008853176325958754, 0.010869421081484427, 0.04154777806252241, 0.015534353575536182, 0.03196117069040026, 0.05166962742805481, 0.04365539264732173, 0.054535694885998964, 0.03241012677816408, 0.0708531898313335, 0.04911579125161682, 0.02983830263838172, 0.017568435320364575, 0.0471959849819541, 0.03974782482587865, 0.045106416035975726, 0.046093636990657876, 0.04766167374327779, 0.019860540184059312, 0.0740686994312065, 0.05726484754788024, 0.03533000884843724, 0.05746441148221493, 0.03305992244609764, 0.050145081377455165, 0.017610794565241252, 0.004783235498637493, 0.023569091988195266, 0.07873419086847987, 0.027091380840699588, 0.05002523173711129, 0.035134729862745316, 0.02492328842968813, 0.01953696888605399, 0.030465682901974236, 0.030985003071171895, 0.007614907592401973, 0.0070379013445095295, 0.036464295483061245, 0.036771397039826424, 0.020304453060297028, 0.051226510134126456, 0.006051480637065002, 0.02176018717831799, 0.027671774250588248, 0.10195405275693961, 0.06539562411074128, 0.05973812804690429, 0.019564369826444557, 0.032603743353060315, 0.04676811097721968, 0.09399105076278959, 0.0015649043593189812, 0.03085487023262041, 0.011648505660040038, 0.06902382549430643, 0.02790611649730376, 0.04346053435334137, 0.08569052509431328, 0.028416386705690196, 0.01310580040860389, 0.06255298307431595, 0.029664190552596535, 0.03840146207117608, 0.011594143978852247, 0.08130271054272141, 0.02949293509923986, 0.028284664398857524, 0.03317404864355922, 0.04883514577522874, 0.06702159757592849, 0.04666029854810663, 0.038504674032862694, 0.009639236244506069, 0.07439379234399114, 0.04804841495518174, 0.04064700586189117, 0.04677575467420476, 0.012952812814286776, 0.013011168522228087, 0.033084322565368245, 0.03516068721988371, 0.04150679794007114, 0.052008504779743295, 0.05068989410730345, 0.007832552788646092, 0.08079797548374959, 0.03885788543682013, 0.02725500107875892, 0.0175199014068182, 0.02514326269738376, 0.04740633083773511, 0.04579932921166931, 0.014907801124666418, 0.05082912949313011, 0.057331771456769536, 0.04346273959215198, 0.03311553178355098, 0.04284175452111023, 0.00977369474380144, 0.027340052050671408, 0.08460880456758396, 0.02243689015241606, 0.001653796263521404, 0.003539258165151945, 0.017693852340536456, 0.0944247499906591, 0.025072306594146148, 0.03770104429817625, 0.01314856083731034, 0.05476617966113346, 0.038636879795896154, 0.125711572223476, 0.07709010730364493, 0.06221598865730422, 0.008590888614500207, 0.04785981275407331, 0.014297389325552752, 0.002918752733551498, 0.028567932413092682, 0.025006086665338705, 0.035370164550840855, 0.08835235011896916, 0.034788303808974366, 0.011041999678127468, 0.04478458687663078, 0.05795799142548016, 0.023557891071374928, 0.009881288345370973, 0.004227981387105371, 0.03597517690754362, 0.06644463246422154, 0.060122117799307616, 0.026157945660608153, 0.06403463214103665, 0.023469896953819052, 0.011781198271949376, 0.028750621181513582, 0.053698827113424025, 0.026425558175625544, 0.02423463136489902, 0.0728647815329688, 0.03577636614707964, 0.09044466713177306, 0.051448401263249774, 0.021188451875267283, 0.034389834119273086, 0.029267820928777968, 0.004456120975581663, 0.022099726101649658, 0.03134773771411606, 0.022226591794086353, 0.030489916780165265, 0.038494373871279616, 0.059191785220588954, 0.004036372427695564, 0.018205040267535617, 0.09491360054484435, 0.005979592396345521, 0.05154405773750373, 0.05892943644097873, 0.036145767396582026, 0.030395183113536665, 0.06793094306652035, 0.02141823267031993, 0.007484356606645244, 0.06959556588636977, 0.0071737368458083695, 0.03403549973985978, 0.05790647704686437, 0.03301833164212959, 0.054394281402762444, 0.007347435025232179, 0.03733661671036056, 0.06690495740622282, 0.029498244635760784, 0.047471395560673306, 0.05025387428967016, 0.03022642127637352, 0.04039012607453125, 0.04196126712486148, 0.013676398317329586, 0.05562501839761223, 0.01446235306294901, 0.05303422920405865, 0.027217864857188294, 0.06294499311063971, 0.08528189095003263, 0.021508225073505725, 0.033126992240015946, 0.05222666735893913, 0.034020303948117156, 0.03532243639762912, 0.0890864571556449, 0.02673279883206955, 0.0021053777517019106, 0.07066526955791883, 0.011911193707159587, 0.06451531313359737, 0.03185076965019107, 0.02446622045577637, 0.06287739745208196, 0.046114566403308084, 0.011636038427241147, 0.045595731386648755, 0.0532598149563585, 0.030987917379076992, 0.049881022689597945, 0.03925058079351272, 0.04826486762613058, 0.04947597121021577, 0.0407036669286234, 0.021573478089911596, 0.026510536205023527, 0.0330058737391872, 0.03910944550963385, 0.022876065157886063, 0.05702721101364919, 0.011832744032809777, 0.025889710589711155, 0.05024150798895529, 0.09067030038152422, 0.06373905550156321, 0.029374836079244102, 0.037501487149191756, 0.025150463650269166, 0.04828319146430918, 0.07737836933561734, 0.029514726251363754, 0.018885534556050385, 0.006761185434048197, 0.036759861944509406, 0.027404163431908404, 0.02934601191165192, 0.05427938506805471, 0.05567587120458484, 0.028873402093138014, 0.057365277515990395, 0.06636365609509604, 0.05302007157089455, 0.04631583346053958, 0.06867192366293498, 0.03996955310659749, 0.05769953065152679, 0.021700723761958734, 0.021667548488559465, 0.06867604915584836, 0.03980381414294243, 0.0017433995692824411, 0.0263171672954091, 0.04052908665367535, 0.024983942675005113, 0.038071259789701016, 0.007212445572284716, 0.035845074603067975, 0.032965399125324826, 0.03497341834008694, 0.0072301443100773865, 0.016713347186201384, 0.03503054081063185, 0.044760081584432294, 0.08155004334236894, 0.02133555317829762, 0.01801571712296988, 0.06902721816939966, 0.02207438790771578, 0.03788745483117444, 0.014070689079484769, 0.03581557868580733, 0.03293034939893654, 0.02622727327980101, 0.03151513230321663, 0.019977159997714416, 0.020634363571714078, 0.041789092256554534, 0.004109459130891732, 0.03313698027549045, 0.10542421654931136, 0.021546228123562675, 0.03345953207463026, 0.05500028781326754, 0.03339966153725982, 0.04702711457918797, 0.020070704531722834, 0.05461302752207432, 0.015883459842630794, 0.04726154164278081, 0.047145898919552565, 0.05802161765417882, 0.04569533354203616, 0.011784240653339242, 0.06361156555690936, 0.02156548834006701, 0.009614649528105344, 0.021296052262187004, 0.043710737356117794, 0.017410497813086425, 0.05594872370628374, 0.019303284818306565, 0.030005832934486013, 0.033215873542108705, 0.00961105922968792, 0.011066179273517003, 0.040357756561466625, 0.060412239017231126, 0.049291396114443026, 0.0254642911854067, 0.02413366365778659, 0.01875766972079873, 0.058198898498501093, 0.04544280994949596, 0.047363372785704475, 0.0374199306326253, 0.012215987396692591, 0.012898322211445441, 0.019732828019186854, 0.03526342759973236, 0.023098824811833243, 0.03533069756148117, 0.02032650205572801, 0.010430249468689519, 0.06107020763946431, 0.09122928431523697, 0.15273922335888657, 0.15201901271939278, 0.15934818158192293, 0.20614108283604893, 0.1819028348795005, 0.1333059939954962, 0.1257244643888303, 0.11511483655444213, 0.1412629298865795, 0.1419082438307149, 0.23303185988749775, 0.07057055964001588, 0.21822214099977696, 0.1306503979223115, 0.1609811575285026, 0.1054422723661576, 0.10944378336093255, 0.08379005028733186, 0.12269713969102927, 0.18290892589305127, 0.073718833204891, 0.06893010623753071, 0.18256076957498277, 0.08462996128946543, 0.12648949905165605, 0.11097689252346754, 0.12547719265733445, 0.08844595402479172, 0.15205171810729162, 0.11023739113339356, 0.09078824333846569, 0.23836218672139303, 0.11212660904441561, 0.15125647506543569, 0.10769848272736583, 0.1765365321189165, 0.10459018166043929, 0.18629458493420056, 0.20141737987952574, 0.12641192892832415, 0.11895094785307135, 0.08536073671919958, 0.1228677641068186, 0.08197026686476809, 0.1282303077833993, 0.083150286759649, 0.1280866754906518, 0.1376408828156335, 0.12135619164577552, 0.14756736159324646, 0.05057285699461188, 0.10457192906843764, 0.1306735902492489, 0.18259101866611413, 0.11175775062292814, 0.11403957568109035, 0.10960567503103189, 0.1520476604678801, 0.13940086694700377, 0.0887614388817123, 0.09117856382259301, 0.21384692005813122, 0.19121188750224455, 0.11679942187454019, 0.16524767716016087, 0.16258079026426586, 0.16407801849501474, 0.2359806645129408, 0.16774620594722883, 0.16289041936397552, 0.14047743060759135, 0.09209979046136141, 0.11844742058643273, 0.20039005071989127, 0.26634944922157694, 0.18999158298330648, 0.12401383689471654, 0.08701570398573365, 0.13260589513395513, 0.12230010171021734, 0.18894810469022819, 0.13134098372289113, 0.11432333902588912, 0.09651461070669548, 0.10450476767229182, 0.11156957250620637, 0.15949600722108567, 0.12020371348730155, 0.13976716729147093, 0.10258183335619313, 0.18356881476938725, 0.12509420035140856, 0.08720891683229379, 0.13237083703279495, 0.17260747509343283, 0.1258826173309769, 0.25459358575088636, 0.17128491534718446, 0.14409155238951954, 0.13602689227887563, 0.11783496130790029, 0.1217747934694801, 0.10515578131058387, 0.12930076462881906, 0.11705573169248444, 0.10953014051275593, 0.08400566157485757, 0.08529991962547813, 0.1395242110426937, 0.06837745982089213, 0.08237622079572507, 0.14984987197177752, 0.10412264389118978, 0.15960221152220452, 0.23218575386064394, 0.12001916553292956, 0.07286109708781753, 0.15793887791889055, 0.13358455976205214, 0.1748384168105466, 0.09287235686289412, 0.13115497013287886, 0.23320475061024937, 0.10805788915604353, 0.1181414012930223, 0.18647878005036286, 0.1333620681294373, 0.19003456139138766, 0.11654030292161874, 0.2121481533561434, 0.1689698217170579, 0.10253166247691427, 0.11593739741614886, 0.1305067113467625, 0.11160397423165185, 0.20573735449995312, 0.07580946745084864, 0.09456695057451725, 0.08483850902744702, 0.09675430998738323, 0.13504498425338948, 0.26846962688224657, 0.15415615375552857, 0.13599002068596228, 0.14590553433767386, 0.09506181973431792, 0.07572674724672522, 0.11602475201444966, 0.15930651953177793, 0.1204215232282877, 0.16141527066273348, 0.1663011706301144, 0.18870489059814385, 0.09063456872744219, 0.1324278882571629, 0.1408759613654443, 0.1768433792250497, 0.10426279529929161, 0.17874877341091633, 0.1180286423436233, 0.09504519562636103, 0.1282584669866732, 0.11678255349397659, 0.13031902856060437, 0.12021630709724766, 0.14148622219051632, 0.1083349282188075, 0.23220838978886604, 0.07850280364177056, 0.11351905789758478, 0.10619216212736708, 0.11868131160736084, 0.25346442205565317, 0.14167330786585808, 0.12006036617926188], [0.05135471932590008, 0.023059481655114462, 0.024228816319789206, 0.012704369761714978, 0.015427564037963748, 0.05808167478867939, 0.03616981128496783, 0.03756243994991694, 0.047100460822028775, 0.035666039745722494, 0.01669979514554143, 0.06103483560894217, 0.04379664667482887, 0.01903116174175271, 0.035263081546872854, 0.03965267386021359, 0.06014618543641908, 0.033580168815595765, 0.062235347261386256, 0.028665023988911083, 0.026756265965689505, 0.020655425298692923, 0.016227875736409, 0.0067174254384424, 0.04045680910348892, 0.037039944236832004, 0.10919729194470815, 0.014535000414720603, 0.05139873928523489, 0.06384275600846324, 0.010874451570478933, 0.021851346661735858, 0.01750463606523616, 0.02307071819502328, 0.03248464349391205, 0.0345098635713969, 0.052449820563197136, 0.03560531086155346, 0.08265912918640034, 0.01958175898263497, 0.019739204552024603, 0.007964729713941259, 0.05397397645616105, 0.0343950452682163, 0.06727836879768542, 0.01465322496369481, 0.0244523478073201, 0.03043958983783211, 0.005743573319965175, 0.02291222768170493, 0.0855693251692823, 0.01746851934253105, 0.04454214292179261, 0.034757600099380524, 0.03268858397911702, 0.06719188950955868, 0.03611812727259738, 0.07830009809029953, 0.021668647715289677, 0.04599597205274871, 0.04757542176438229, 0.023152809057916914, 0.030072889157703946, 0.04596695789535131, 0.036999951382832866, 0.047813445063573976, 0.0283549860718527, 0.012202208894970161, 0.018092703706185733, 0.0212399781282459, 0.012266406789422035, 0.023302995998944556, 0.042348154221794436, 0.07944024726748466, 0.045672843498843055, 0.050233925360121896, 0.03399217527891908, 0.007119225038747702, 0.12851712453578198, 0.06652840439762388, 0.03913080918469599, 0.04254284627469523, 0.03392272043441023, 0.007606057799421251, 0.05583917422752295, 0.047659346368163824, 0.018684289551206996, 0.03872311481141618, 0.010140481937144483, 0.028138753924784914, 0.021854574792087078, 0.06704610626080207, 0.03926712686994246, 0.0801080275060875, 0.02362769196874329, 0.010070282400452664, 0.03586938312011106, 0.05058956591944609, 0.00840773165691644, 0.042522490224135776, 0.043328148778527975, 0.07088332357151167, 0.02634643081442586, 0.07549734812762056, 0.0550778681146247, 0.04381975757756403, 0.04064248003331678, 0.022847695608756373, 0.06520269624888897, 0.023543326317199638, 0.020353619707748294, 0.029325991735926697, 0.022804985222007548, 0.026077963345284973, 0.020318632745849233, 0.012711699636253928, 0.025917310001594678, 0.04956055399296539, 0.02380353771150112, 0.021207949579028145, 0.028599548752286603, 0.05782239298735346, 0.03461462937827621, 0.024297794493447458, 0.05569497875070997, 0.014241881768352218, 0.054956186429730484, 0.09566515950219971, 0.022360680491796563, 0.04059358140719788, 0.03012274791087423, 0.02595712134747633, 0.010723784565925598, 0.020900693655546223, 0.04673714603164366, 0.023220764340034554, 0.042902887133615356, 0.04597027932426759, 0.005077489418908954, 0.06554739882371255, 0.013354853294523699, 0.005846627946344337, 0.00853922835085541, 0.025675057732899274, 0.01198685884342662, 0.03941969207621046, 0.011240843517173613, 0.04397069090711219, 0.03421891114807554, 0.03853049907567246, 0.05299986819071429, 0.04169245529919863, 0.051708829788757224, 0.024535788954900842, 0.04753313885469522, 0.017353706128363098, 0.01923508187090712, 0.01566958730109036, 0.03985445999673434, 0.0354217501756336, 0.051893754330064566, 0.024517102100487267, 0.03209576828937445, 0.029953443245696168, 0.01951607340015471, 0.07838685557778392, 0.015632408671081066, 0.06900759493666035, 0.03428376552515796, 0.001910623994522861, 0.041547805203923156, 0.008899664456423904, 0.025144987872668674, 0.02367942008588995, 0.02686781542641776, 0.032393468743456263, 0.040474793674158197, 0.021352138270490935, 0.025899583274232488, 0.03655790278155889, 0.031201716978102922, 0.038932856771030595, 0.03614011859255178, 0.0637924222807799, 0.08643717824348382, 0.03367979811238391, 0.02615992528652506, 0.05333681511027472, 0.04383931974215167, 0.011773518951875823, 0.025216929548020874, 0.04445945664442011, 0.036017412319779396, 0.03382295203794326, 0.04914902928950531, 0.02562962133171303, 0.034790956880897284, 0.010851365264638193, 0.03554916887411049, 0.005044230600885514, 0.018009550935987915, 0.026416567586628453, 0.028279853585575308, 0.034458094742149115, 0.0902293272582548, 0.10983100972537484, 0.04378367308527231, 0.010165210297730352, 0.015199537255934306, 0.028728114174945012, 0.07283918719206538, 0.03094187199271151, 0.04670107850272741, 0.05084019300660916, 0.06107738653996161, 0.018760187085717916, 0.0680993486727987, 0.011384051725534456, 0.0542177401616105, 0.060627524607947895, 0.010662910644896328, 0.028266506801758493, 0.060468299580471854, 0.009232073673047125, 0.05353555801723685, 0.02743429208307394, 0.022514204128778408, 0.07320847987596478, 0.04890419010605131, 0.015958733124924556, 0.04041698249056935, 0.05804860977722066, 0.020855158866782273, 0.03377834514581731, 0.06002094144267695, 0.055676278325596025, 0.05762907157519034, 0.04766420467889734, 0.03581870333956821, 0.039776153662907224, 0.02614164216044758, 0.014583257825246878, 0.02090471736820681, 0.041568907643003125, 0.0173908559206341, 0.01976140621783478, 0.007083679133627031, 0.013058995063017522, 0.013144102862237819, 0.024687487332682525, 0.07853615363793713, 0.020650804475215927, 0.0688073660380074, 0.018216863740235567, 0.04145788235057678, 0.02387813415511378, 0.009707362856715918, 0.033127158481095514, 0.035270189201193194, 0.056149057777864594, 0.07848626095801592, 0.022420199887294854, 0.03295006762657847, 0.03600228438153863, 0.02614127066252487, 0.031726618097828965, 0.02734381622368736, 0.014854115433990955, 0.06949075258203916, 0.057023207657039165, 0.048443217163107226, 0.03315509716048837, 0.023200245441070626, 0.012249021025906717, 0.012650306635935391, 0.037093612964132, 0.05472665499629719, 0.034966958686709404, 0.03889345424249768, 0.02358730386809579, 0.08726168650069407, 0.013275673346860068, 0.011382045806385577, 0.004287718337894018, 0.0551807849135782, 0.06780570585812841, 0.0449283107716058, 0.04361598672611373, 0.07711568128849779, 0.005736882116512528, 0.04631659681243556, 0.034803828690201044, 0.02253611063185547, 0.025309042373139943, 0.008075064596986132, 0.011447699158452451, 0.047393754191164456, 0.024679277058956877, 0.01244941701380802, 0.027227232033120732, 0.047876711668712754, 0.023636014200747013, 0.019099373170839887, 0.04176905851012894, 0.017496620870328376, 0.07424305578959839, 0.013946780951560607, 0.03648273806486811, 0.014683401112311652, 0.05052409068282161, 0.08791839304779257, 0.043992509200636826, 0.05386834890980806, 0.040066665038466454, 0.035214908953223906, 0.02009434638811009, 0.08379456933055605, 0.10239299706050328, 0.00942064109923584, 0.041313042265496085, 0.03173387163717832, 0.010831498607460941, 0.02442048041016928, 0.019723920550729548, 0.08200602566025086, 0.024790007188650112, 0.010109082729156529, 0.05715273999209915, 0.013391599358458604, 0.011823454888404479, 0.0775977736338973, 0.031030939891934395, 0.036152366149638376, 0.008814357337541878, 0.015181335554059063, 0.03183648309537342, 0.02984461301405515, 0.06605986239654676, 0.01704424157339547, 0.04459634090640715, 0.02760948982488896, 0.09439218709511416, 0.06949643192014524, 0.030199242556201558, 0.047598678552146466, 0.03591207654348441, 0.009238004917278886, 0.014211082215686994, 0.03350324330053159, 0.02018625395638602, 0.022809164997722422, 0.04290742314021502, 0.16509857587516308, 0.09611988653029714, 0.057000083183603625, 0.0745278030101742, 0.09816530320261206, 0.16472593801362173, 0.1180750269974981, 0.10758347782705512, 0.12619809540254728, 0.16120719111391477, 0.10728220149342503, 0.13507638685405254, 0.17991456442645617, 0.11881218744175774, 0.1076959925038474, 0.10599044723702328, 0.11740548935319696, 0.096252397634089, 0.22478375104921205, 0.15174113905855588, 0.07741103401141507, 0.08170221839100122, 0.12833064954195703, 0.07841500121035747, 0.08886171278676816, 0.11009101077382054, 0.12016757471220833, 0.0688913008198142, 0.21925466773765429, 0.2342531414968627, 0.07836793123611382, 0.08229922742715903, 0.11990439811987536, 0.15055283425109728, 0.1427918728441, 0.11589830022837434, 0.13261790520378522, 0.13280003757349082, 0.15940973827881472, 0.04946725203522614, 0.14961739230368817, 0.21302553984735692, 0.12411435507237911, 0.13106876904410975, 0.1439009111906801, 0.0731066589110664, 0.10774230930422034, 0.10745950947914805, 0.16256925516894885, 0.06596856550978762, 0.1651961084987436, 0.09918693266808987, 0.10332130081951618, 0.10401430899011237, 0.11900854190545422, 0.14500639401376247, 0.10544525792023965, 0.15360176350389207, 0.2512719397033964, 0.20417592328573975, 0.10681283846497536, 0.15393572486937046, 0.10240700880863837, 0.1562771727996213, 0.07902978107865367, 0.1428133145506893, 0.10502924131495611, 0.15139942882316454, 0.0775858721296702, 0.05374250441257443, 0.11651248298585415, 0.09499997126736812, 0.0747401098321591, 0.1438121452395405, 0.20126650083277906, 0.1321544386446476, 0.08878701965191535, 0.12633918997432503, 0.1894341664654868, 0.17411887113537106, 0.13956300967506, 0.12614701528634342, 0.15339753803397926, 0.0887937710753509, 0.16914031042584352, 0.11586053296923637, 0.08670347609690257, 0.1211819981357881, 0.14770739765039512, 0.12146118815456118, 0.09581139058406864, 0.14138783461281232, 0.301588486880064, 0.19235198918197835, 0.11016117808009897, 0.10343175953520195, 0.14092430020017283, 0.05983671918511391, 0.09055558046592133, 0.12841339010213101, 0.1531777876828398, 0.18535906156258924, 0.12603155576757022, 0.17993642682475702, 0.1584365697843688, 0.11606545054486819, 0.12270456286413328, 0.08470687323382922, 0.13684373987572535, 0.14320868333535536, 0.1572633555957249, 0.09761165933949606, 0.12227821217051574, 0.12023291763450418, 0.12403696136815207, 0.1174673717468977, 0.09658280347606965, 0.11683496353881699, 0.10496334877929517, 0.14060034044086933, 0.1347892036927598, 0.09094987037990775, 0.09226812821413789, 0.1030007948034576, 0.12216697313955852, 0.10241649472819907, 0.12431098095008306, 0.19196768051811627, 0.10098847706935235, 0.12172916877482619, 0.0984351226527776, 0.11341474670916796, 0.12395257875323296, 0.13896786661020347, 0.20550239139369555, 0.12100853744362082, 0.08661198243498802, 0.15496861801615783, 0.1097081338188478, 0.15293059737554618, 0.1255383693746158, 0.24814842588135175, 0.06235923418509109, 0.10693755320140294, 0.09708597111914839, 0.09860483104629175, 0.05530296192903604, 0.07566871214658022, 0.1738574994461877, 0.18077118774609907, 0.17248038548443997, 0.16373220990811074, 0.1089721540255206, 0.09060417714395694, 0.14091902119772776, 0.15629355263497147, 0.1706074524138655, 0.06302369638745274, 0.11370843702128955, 0.12654159697038786, 0.11625987796911172, 0.22179768128054483, 0.09206418094358274, 0.12708089660320962, 0.07440489996224642, 0.18191089587552206, 0.2149887994996139, 0.13970464707485267, 0.1366044477160488, 0.1576082142336028, 0.10991783506636109, 0.12889829836785793, 0.10628579995994057, 0.0723304148497326, 0.12239988707005978, 0.10557049512863159], [0.023746042046695948, 0.006198284656940294, 0.03251481794619134, 0.023326364744986807, 0.015522983024961181, 0.013229970620679004, 0.00919150491245091, 0.001512243362542774, 0.027232117485255003, 0.0077613854913839275, 0.022497446010155336, 0.06901707407087088, 0.06488665499325309, 0.05851415265351534, 0.028860879729368856, 0.03805316326075366, 0.01767201199462371, 0.03391826245933771, 0.021060246076168757, 0.040050875528582504, 0.03371925153104322, 0.03454598199043955, 0.0052329099853523076, 0.022780724202415774, 0.0293252860595073, 0.02081933561047273, 0.058451381378940175, 0.015093275279338871, 0.0688641933458192, 0.06833247294915573, 0.004239015638761754, 0.022147932622049536, 0.031805185667638264, 0.01956526718900672, 0.03576120428208794, 0.02425340812520257, 0.022746532822826078, 0.024710910361526266, 0.01899197295175067, 0.01682029787584075, 0.01935747771390847, 0.028287129177312766, 0.013696669551011707, 0.030966804761971747, 0.021493636570604782, 0.054761080470468314, 0.04930964192109449, 0.05529608836929713, 0.038055466887141974, 0.04347717542467373, 0.04722043599135109, 0.028038488501416783, 0.04464262378002916, 0.0769981454525675, 0.04025373714310782, 0.021584302419796586, 0.04525062847616417, 0.06511694299323217, 0.07493056104119335, 0.072868791674929, 0.06101831328123808, 0.016539428482896516, 0.013566737728459495, 0.03986985256363239, 0.04934518697804638, 0.01688642959509577, 0.03757950849831104, 0.03592986433899828, 0.028523179635937725, 0.05494295499686684, 0.017180055446390594, 0.020746438897081783, 0.012138413032516837, 0.015166819993672627, 0.05647610826417804, 0.05624845976542149, 0.02188778229589973, 0.02110392676799425, 0.043744840526155064, 0.06963234248438052, 0.003631879891535001, 0.05224998521485499, 0.02633598816048886, 0.04315121737974031, 0.06637614113943917, 0.0215203114785254, 0.02331521132561777, 0.05229573543848736, 0.0946154183308993, 0.04720447684771248, 0.0416708812782807, 0.017061003084693636, 0.042315601504274776, 0.04046526364982128, 0.029763171848441874, 0.042335112778736014, 0.03930569140772734, 0.02798789014507617, 0.06268513455454792, 0.058743008944605074, 0.052842919648225815, 0.10826123931578227, 0.013254665902682712, 0.04983016648995025, 0.02558667685038277, 0.10311095496373517, 0.06327445578894444, 0.03374669148719736, 0.017290251229756644, 0.05137038330680557, 0.04036532561959965, 0.08206762306924377, 0.05508694352049913, 0.007736612177853073, 0.06561464164406061, 0.05218026234901377, 0.014922864602080413, 0.04680468401472483, 0.07054878545126744, 0.008353332656302621, 0.030229990370571613, 0.03745435271412134, 0.0603132000459092, 0.020280919769512754, 0.045873520230608325, 0.019037743531433598, 0.05299179023131728, 0.04559158553768482, 0.02729106182232499, 0.023886787172939097, 0.028859675329710757, 0.02330309777919735, 0.046973374605711014, 0.0626866544729897, 0.03459251592201846, 0.02389086686473872, 0.07134130756769862, 0.0454276786185801, 0.038458394551915784, 0.03874612732657364, 0.06856037929121937, 0.059133987607700486, 0.044338395819067955, 0.01769539600770388, 0.07830992327736956, 0.025469551528138772, 0.023674829796488796, 0.01691624103114009, 0.05812312649296863, 0.021399837585964372, 0.046705672184803655, 0.10656473892075674, 0.05099719922457423, 0.006519311024541301, 0.016691311761470776, 0.05958136610154595, 0.008029692656626659, 0.09999002636011158, 0.04870266859818782, 0.03615057820986424, 0.03380771553409951, 0.012739130262551563, 0.050117559997098785, 0.010631670892637755, 0.014977247487487537, 0.020575965455334102, 0.012607916008814104, 0.04919398223449077, 0.06736891251057386, 0.04447453369253448, 0.019637826331225888, 0.04186253688697304, 0.03742875158786774, 0.034765647524701696, 0.006783738241730524, 0.04189156800774591, 0.09829968027770519, 0.0529077909886837, 0.03511524912235992, 0.027637340294729387, 0.015701179891558628, 0.017187363268541436, 0.0033324966706069453, 0.09503381659409829, 0.02887253017563905, 0.06805392753865037, 0.056460556241550615, 0.09903006894247872, 0.010880400626254933, 0.035388362860041, 0.0163328264440809, 0.02757784804063184, 0.06441286113113165, 0.027285982987710407, 0.03839457154806171, 0.03257407780204501, 0.03576441714540124, 0.038700377102941275, 0.06289269163140229, 0.010085206778187836, 0.0974012863423143, 0.08825158766869988, 0.0027378510567359626, 0.03952485143340059, 0.050054836219974926, 0.017414404478456293, 0.0359376369576369, 0.013096445955203047, 0.020045624181096042, 0.043619050311722925, 0.0604478960324611, 0.014635484665632248, 0.01679912588692137, 0.04047511937096715, 0.06793208979070187, 0.021868488152644465, 0.03870824810915759, 0.027256887406110764, 0.022859661573810235, 0.026010233676061034, 0.05422130925580859, 0.04309466148593596, 0.03567895905247756, 0.006914633584009218, 0.05914211645722389, 0.030520484782755375, 0.03898927017248102, 0.055288488777088265, 0.019150370166503956, 0.026820375650588955, 0.06125019583851099, 0.04433046035202486, 0.019194836262613535, 0.055862814387572665, 0.0316744387548949, 0.06783266405441932, 0.0303551020499851, 0.054956803896597455, 0.0033706479381570326, 0.06676603414650474, 0.03199276328086853, 0.01841998828708061, 0.02734493580646813, 0.025643823069653342, 0.07443793104695422, 0.05007431356768523, 0.08687077569110052, 0.033423471331064186, 0.1246280875056982, 0.07805349132312195, 0.020064455224201083, 0.06416155890162502, 0.03967393236234784, 0.059412723008011065, 0.010772868092837078, 0.02598513975473387, 0.04487000425745334, 0.017759498907253146, 0.08723635678844792, 0.016505379595660737, 0.025313354463183453, 0.07624429304684911, 0.023384993563273122, 0.014821888413280249, 0.0421557929366827, 0.027989250607788563, 0.03591207315080932, 0.012807783587569637, 0.010222951083311012, 0.03582433518022299, 0.029798068904450963, 0.07671134905623538, 0.046114325523376465, 0.11026238836348057, 0.013902855987128402, 0.044507530850491354, 0.018724175535940697, 0.024075620075953857, 0.02337086816052241, 0.0300506705285183, 0.05970228782721928, 0.03225724266043731, 0.02034973679110408, 0.0608671899618847, 0.030827874716903483, 0.033937407324888876, 0.014671179000288248, 0.08806444092520646, 0.06554135986204658, 0.018838785189603056, 0.05917039101145097, 0.026733248361519406, 0.03260977213670101, 0.07827507371881179, 0.07430284829544169, 0.02222193025850824, 0.03792770213580557, 0.014043662181523229, 0.012371167507288712, 0.0011000065153764027, 0.13057277351617813, 0.06600085020597492, 0.04644594594304051, 0.08611775788345508, 0.053895839756088595, 0.015502949278535587, 0.0112584591344265, 0.015315118911010879, 0.042031281760760715, 0.013519682173085, 0.0227769193172987, 0.02314740961550602, 0.12513290398887225, 0.03327251086011529, 0.023784648992919495, 0.03938181625146951, 0.042778949319784126, 0.02757733065768012, 0.018137169802295308, 0.017361573741904328, 0.06321175236787115, 0.04970551621434944, 0.022484731960243413, 0.06571256781795196, 0.038797244762203524, 0.039790653956255743, 0.10671941776360784, 0.09422320473406996, 0.03779455999444638, 0.03902644710615277, 0.013179847238851445, 0.029793152918240855, 0.02289720152371696, 0.038036067570958815, 0.06378226461155073, 0.04682095528447202, 0.08609372417309455, 0.03646824794954487, 0.06505918609244482, 0.02869738671662552, 0.0472400626167655, 0.029399626356150423, 0.04932281907115664, 0.05472670588642359, 0.009427469706029763, 0.027890754464481558, 0.0577731245596494, 0.0796656362446291, 0.03427871722461922, 0.036289589679134746, 0.015509442858664053, 0.038937996673796854, 0.1981338539293834, 0.13974170865757124, 0.08013440894761256, 0.0913247066949095, 0.1346062027982303, 0.12839462182351521, 0.07230429803686482, 0.15662760899535247, 0.08137725439987012, 0.12757447654647486, 0.10872013933424439, 0.20612179887081894, 0.14919238510940755, 0.13096835943205015, 0.1211945510336331, 0.18022975751331874, 0.13584025443664619, 0.13691105054957525, 0.1368888895958662, 0.1464407899017845, 0.10574130953422614, 0.10765218628304345, 0.212364633168493, 0.05783963456217732, 0.19352505409291812, 0.20229050517082214, 0.1469364325915064, 0.07591421968702759, 0.11381762009114027, 0.09955921090607132, 0.05044113977679184, 0.08282318538320915, 0.04359249923644321, 0.07637340469019753, 0.10316238113279853, 0.11759546558771815, 0.08890620432794094, 0.16434830613434315, 0.12349777030093329, 0.06681757566652127, 0.12577669801456587, 0.12049822482679572, 0.12989362781601294, 0.08233264527682747, 0.12986168238733495, 0.12410087936690875, 0.18967261724174023, 0.09984943390424762, 0.21874431440872805, 0.19041150116494723, 0.11541468117918287, 0.10819256478654486, 0.10445684952927486, 0.13979363015719823, 0.14918862602540425, 0.08810585870274476, 0.09912321822983877, 0.18205926434269973, 0.16993917684469903, 0.168941553948181, 0.12714951006429537, 0.14142186992934772, 0.06554885767400265, 0.17551824104573044, 0.11699359145547662, 0.05813788462962423, 0.10926663822361402, 0.10540005391729729, 0.1782264235828604, 0.12602862449628965, 0.15252878250820295, 0.07346473541110754, 0.1935531725840909, 0.24634010291525296, 0.10255920421332121, 0.12695850245654583, 0.1483327355235815, 0.17247760349086352, 0.08323329194848027, 0.11947854954217162, 0.10395900838609252, 0.11850487893181187, 0.11377486559961524, 0.10160778276622295, 0.14142060785421304, 0.1290248722902366, 0.11519213526376657, 0.14388734049030713, 0.12691058431352886, 0.12104312915887151, 0.10567674014185156, 0.1623639576137066, 0.13077646972877638, 0.1221061356897865, 0.10184037099991526, 0.13385589234530926, 0.13011820933648519, 0.13890797910945757, 0.1038050487903612, 0.1725978534668684, 0.13696423412433692, 0.2230766655078956, 0.08156805844711405, 0.13399448990821838, 0.10206638422927686, 0.2432944577719484, 0.1557314677962235, 0.15660312745187963, 0.13741619272955827, 0.12949272218559468, 0.10163432705615248, 0.22615840871419224, 0.14900448519204343, 0.11310851028455154, 0.15069542159991606, 0.1294843354927642, 0.13861654831894807, 0.14655429523970398, 0.18377111319984707, 0.13121242847825798, 0.15793054550886154, 0.1487639716693333, 0.12938134744763374, 0.10003054847142526, 0.20266573503613472, 0.18451034996126378, 0.13170811188008102, 0.1266791903014694, 0.08657635934650898, 0.08002035399632794, 0.08116850310138293, 0.07298498401152236, 0.1337261428790433, 0.1079450962798936, 0.07721704084958349, 0.08706118618803364, 0.20848155367587293, 0.09115884559495108, 0.14845074633402483, 0.17419512490076677, 0.2080877319510494, 0.11576787222708974, 0.16401430405676365, 0.14317498728632927, 0.17874448506959847, 0.08014753181487322, 0.14810956535594805, 0.16050374028938158, 0.08252583776733705, 0.1625473384878465, 0.22230059786566667, 0.2338142650468009, 0.13775877148977347, 0.1237768924662045, 0.09329224111778395, 0.1709154937416315, 0.09630290099552699, 0.21908324265054294, 0.15474562426762922, 0.1260587243097169, 0.21563247138900415, 0.10821726346122366, 0.18943510284381254, 0.18213072765086377, 0.11327226114060197, 0.07664968379374061, 0.14217790721782617, 0.12693764429007257, 0.1555021365306207, 0.0850294894937958, 0.06624061734016452, 0.11988621338137559, 0.11417729114847523, 0.11957475223711558, 0.07916626161230461, 0.1113388773852161], [0.048064906748809984, 0.056209946117763004, 0.0346807017257171, 0.03599141085786479, 0.03683181719056197, 0.045683075806924274, 0.052505083847790956, 0.04050264414399862, 0.03834285021626523, 0.041828196229679246, 0.011825689813122153, 0.022873920987227132, 0.01923922771987106, 0.034117018937000206, 0.026830640189083557, 0.050646569646362743, 0.03979525103100708, 0.012320263810189707, 0.06331978871354035, 0.05928851038749729, 0.07477402979774134, 0.042656490712293556, 0.01553593116945454, 0.025032417216737355, 0.04325261086757694, 0.0766004900048886, 0.038754500448703766, 0.009451784160254257, 0.0861715114276324, 0.08590585818248135, 0.07123991407986198, 0.04756424289995006, 0.017761536208646636, 0.08631116750517062, 0.05045153493327754, 0.02886109346789973, 0.035828369070908854, 0.011225473850832453, 0.023252743695463454, 0.04590955722544875, 0.040915247718138356, 0.0021168874019557343, 0.06340298389217683, 0.0387511179516358, 0.05524596498746957, 0.03501384545649801, 0.0919539529298033, 0.004571541478591306, 0.013071575950432037, 0.040222952009311745, 0.11969093100300857, 0.02932792216805475, 0.06150677028511252, 0.06254691697124924, 0.02074878493190876, 0.007986501358183367, 0.03977846068197063, 0.020420345145144632, 0.07233715270246778, 0.02848162954407079, 0.08170120058847324, 0.03179461069937263, 0.03237725514918566, 0.034297173377126455, 0.04789273527317813, 0.017930294653134685, 0.05486673176554697, 0.01322761525599552, 0.05746123593832765, 0.03158400360760944, 0.09245154301502875, 0.04194103321060538, 0.01632727263495326, 0.05735634120979479, 0.03332930084850107, 0.008647615838396763, 0.0275301996152848, 0.038717082635100396, 0.029847076096172844, 0.042549448420426676, 0.04747151769697666, 0.01252774624819202, 0.015033155380349075, 0.022787672401006733, 0.009861376735248735, 0.04991450500009315, 0.08222775733364479, 0.07339730260095426, 0.005989091462522213, 0.06305161131811993, 0.08052120783499309, 0.01086428711589958, 0.04436735569366387, 0.045850433076598814, 0.031077901300575052, 0.03971862407135112, 0.026959042763337493, 0.03532978493188109, 0.014858466539798039, 0.025578736294327036, 0.00623028224799782, 0.02598196590718414, 0.02670474480172353, 0.04001180208953364, 0.005899114750458726, 0.04302763579679387, 0.010440435127488204, 0.04871462099254131, 0.04915297157796366, 0.04001863832984652, 0.030061662795820406, 0.031516082252242734, 0.06280254146882466, 0.04228987145636763, 0.04053685587963887, 0.01355770557919251, 0.0615696297692401, 0.027612127629773955, 0.024609486339613795, 0.005635418654752097, 0.04430209419557026, 0.06680228827255112, 0.05756889230438641, 0.03280302569536226, 0.032963563688099384, 0.01010113284324429, 0.03762908226677349, 0.03161975901041712, 0.017587756605020592, 0.06279096566140652, 0.025620130323139683, 0.04258687641205532, 0.02060138337713267, 0.015207050334928291, 0.06545135219182287, 0.05378908584160464, 0.018915074578087245, 0.024723895825445652, 0.022473356320655773, 0.026673740840383937, 0.03181045109938298, 0.026759986033929244, 0.025599877749170576, 0.08400713399584804, 0.021598336220319782, 0.051030118351003954, 0.043742655643395016, 0.05248584398733718, 0.04190951865166426, 0.02250115929304489, 0.011838381810645972, 0.02454751404002309, 0.06716284821076052, 0.0488965124823153, 0.011399959979046668, 0.0174381209736956, 0.06267835598971162, 0.020700006745755672, 0.0820674534354891, 0.005161952185777149, 0.0869770682017718, 0.01101853424084506, 0.016242874752996222, 0.05282994945134435, 0.031120984881584133, 0.028999680852783576, 0.015670498234352896, 0.004648133663327566, 0.04072825703769922, 0.04810785123014024, 0.11039777645575148, 0.03686673799529672, 0.012571493097181832, 0.01997756372605051, 0.016202746191993356, 0.04532176269484418, 0.03757592922608767, 0.0527766607036548, 0.03358104073309472, 0.047749089409730265, 0.028227005885647874, 0.016511961385341625, 0.0323844103009573, 0.04379543548982058, 0.04650268504129989, 0.030655435219939266, 0.023024603258818388, 0.054677929396608045, 0.044376631267368793, 0.05037291647334184, 0.03376096786398973, 0.015227806721148747, 0.005923086968583188, 0.03773715253919363, 0.023925745261034796, 0.03377264205898557, 0.04812983576474445, 0.030620891002139876, 0.017311613208481243, 0.029837335725980144, 0.028740202276302234, 0.022318246608067836, 0.04478364371295486, 0.023186600101845603, 0.0709606222808361, 0.05964377775256123, 0.03601965827069112, 0.03960305598697492, 0.023925015835889747, 0.06253532080778054, 0.07025563796716076, 0.019879924233204553, 0.019736999313213995, 0.060219474003783295, 0.02050310266869409, 0.029244435219360248, 0.08608753593372447, 0.014222323844608451, 0.015239779471552797, 0.05479866113247616, 0.02362066743496273, 0.02686095204470413, 0.03301261837727257, 0.011594981969600278, 0.05169536086863705, 0.05755473127854722, 0.03772656739290271, 0.018692011279719215, 0.017948593046250086, 0.05135556410199829, 0.020126817681427513, 0.014283862729955996, 0.06709188023316008, 0.022716488988537873, 0.07847501763275691, 0.025657675362059047, 0.023003950349188278, 0.04380665167367884, 0.060371472633310726, 0.052474247823868475, 0.043450532747166495, 0.037970069862369976, 0.04103750276512333, 0.028014308906027248, 0.04054412977503879, 0.030329351646027396, 0.0886625424027443, 0.06021555207137551, 0.03770592635763543, 0.03170806695041912, 0.06373246014118195, 0.049380447050290446, 0.01313071112547602, 0.06599126250616141, 0.03971654096884387, 0.04565828553001795, 0.024813004436769655, 0.015004765475168824, 0.026429123877148544, 0.04545782592945865, 0.03552004275843501, 0.03473259608394333, 0.018581510155594776, 0.0042480231911343124, 0.04094430598031197, 0.05406587045373661, 0.053966159732746224, 0.042461089590298276, 0.009476027368301792, 0.020460556826687286, 0.0076396851467766935, 0.026177624872486507, 0.022476479278079102, 0.09313886506216866, 0.04252548595624311, 0.02032583030605955, 0.030915042718074152, 0.04068635071494749, 0.04394827889544623, 0.02322826554466571, 0.006345276970283261, 0.045244138288710795, 0.034764578832047324, 0.040529137543801746, 0.06746990566274949, 0.023604033148980567, 0.06285700068942138, 0.03930793396596398, 0.03266312873789242, 0.0988231971859932, 0.02099114576620715, 0.040857684199831316, 0.051341260583805184, 0.029968276021203825, 0.05455499581460442, 0.01899530116601714, 0.009889714902133813, 0.03200050536543131, 0.0527080845619951, 0.036084760313055346, 0.03632291931925075, 0.026391013957826153, 0.038523533913706026, 0.03146950760856271, 0.01791619130277208, 0.038426554296165705, 0.02328106913981693, 0.025955153595922247, 0.018198787567338774, 0.03947634296491742, 0.05706615213836942, 0.03429344143452389, 0.011611947041404034, 0.028995456972292492, 0.04876485972532204, 0.023600654044587697, 0.03615939237975648, 0.02707354215505932, 0.02059643516050918, 0.08999685437551566, 0.019742468305464302, 0.025751370870109116, 0.062069391166525226, 0.059360197612217495, 0.07384375150182418, 0.04658254182764462, 0.0677135879439967, 0.04179068681384836, 0.08050020717616592, 0.013764975126832724, 0.05335708295128175, 0.025177053741312454, 0.055983495233314376, 0.021820770177458013, 0.015065981208213737, 0.009943828918039799, 0.04635027589808617, 0.031714404467493296, 0.03907244838774204, 0.01907539883229349, 0.020224899918373142, 0.00915899799604501, 0.017980131353916864, 0.03911057866311499, 0.023384286190516183, 0.03964508444603, 0.06297709460237197, 0.015056892231638943, 0.024601674705211605, 0.04205057929669108, 0.04776469910783427, 0.00997884217317083, 0.14269885926374368, 0.20198892349643366, 0.09928195471210138, 0.13767776797924722, 0.13940006627568177, 0.09892226329871587, 0.22369732148945332, 0.11216930246778897, 0.22301018264676842, 0.09464414750358888, 0.10979441633181912, 0.14846909392092908, 0.07679603701191288, 0.1425354816019535, 0.15816523720111164, 0.10727300734392234, 0.10707191670579569, 0.12433056347072124, 0.1126137361196535, 0.09513592254370451, 0.08406578656286001, 0.10042584261723927, 0.08128287017877613, 0.08225207602871315, 0.10874290418412004, 0.2488056549004146, 0.1391354240477085, 0.061451401827590804, 0.17864142917096615, 0.12935819583279745, 0.18749223995421613, 0.13088191407067434, 0.09126159615282502, 0.25631744467786377, 0.09380937979689666, 0.14774201650704655, 0.08552707957902125, 0.149939981422254, 0.10007745559726443, 0.1309399695268699, 0.1290449569267886, 0.12219381598489625, 0.1651081975017275, 0.1053758505731821, 0.12046546515609537, 0.1171318633215768, 0.17283121523048195, 0.12548857847494738, 0.08048949310822145, 0.11854667668896061, 0.2254451055611883, 0.11870525032281876, 0.18367815390229225, 0.10031104806278433, 0.07726745600146906, 0.14679655938276223, 0.10746814044458525, 0.07557856198400259, 0.15289227371769293, 0.14234498968081816, 0.22939382653151238, 0.10128403335277524, 0.16145518209253037, 0.09833445519741092, 0.09853455517441034, 0.13762062175997666, 0.1725773209972041, 0.09513874524938208, 0.19045621662267617, 0.11382490077189036, 0.18664660890187534, 0.19039854114609106, 0.14534111533846172, 0.16143390323434556, 0.18973722734621593, 0.12016916248415198, 0.08262444247624703, 0.17578737517552717, 0.10710031339632613, 0.12722015913043702, 0.13069123215973377, 0.10407055275780813, 0.14725666040820734, 0.165795431339315, 0.13164313536669525, 0.12445554962115628, 0.17682496378464357, 0.20146326241748674, 0.15122519460107597, 0.1474190881209714, 0.15753433534077235, 0.07998722113136734, 0.07977697705583912, 0.146866665620889, 0.09502224757203034, 0.08683197705873422, 0.1426359862089157, 0.20243647162403378, 0.0824042239359447, 0.0853435629978776, 0.06915405672043562, 0.17258196217673166, 0.14002243216548646, 0.10886685217597655, 0.10634715309632675, 0.13185622250395163, 0.10028344525822572, 0.13027178895260605, 0.1454711497894355, 0.0745486883180482, 0.18756021559238434, 0.15175176491694792, 0.21051523169236525, 0.1855144053697586, 0.11255019810050726, 0.12119467316993646, 0.19749016846929277, 0.13158635555633477, 0.10240521747618914, 0.0801171673727887, 0.10273979630853448, 0.18471382904265607, 0.14398890361189842, 0.10816205785210643, 0.10490807531667606, 0.13278662972152233, 0.11561921877520424, 0.04976168195051806, 0.11247626492487532, 0.1207094799195017, 0.13775821509105818, 0.10423021204769611, 0.06864055498902287, 0.14559281111827918, 0.1544055967990841, 0.16761832923761436, 0.08958835593823876, 0.10617197571056229, 0.09892660592283521, 0.16619918681681156, 0.0880474029108882, 0.10030789287494761, 0.14483491464384965, 0.2321151862187045, 0.06830068358353206, 0.10975525129054274, 0.16662229411303997, 0.21662364820284502, 0.12377501970955304, 0.15321300365030766, 0.09797831930752311, 0.12315890991262027, 0.167672422049301, 0.1241979505866766, 0.1590668609631913, 0.07567788594003234, 0.17322557978332043, 0.11881476587482862, 0.09347613767853805, 0.108910604113979, 0.17663099776421273, 0.11869838354843003, 0.09361276070454291, 0.12043273262679577, 0.07801236531564168, 0.14555161047194684, 0.11987342978162424, 0.14745068071143969, 0.14346903722201074, 0.13470042417091982, 0.23247312701174191, 0.19701695814728737, 0.134659169241786, 0.09855082644415752, 0.1264172215014696, 0.09271162548767668], [0.05965993367135525, 0.024848201744524494, 0.013082723432619656, 0.014300975383126309, 0.08223359952015535, 0.01476220616937748, 0.04924769845924207, 0.05405870512393968, 0.04828224490795817, 0.012947649162794863, 0.03008164225944451, 0.008255258901044726, 0.02067937419217612, 0.021148584550246596, 0.051158320757427385, 0.016361765962626253, 0.024763788595529537, 0.01988135933476899, 0.03613108389877847, 0.028630768148494617, 0.0342388125801725, 0.0321644224625613, 0.003575455039806132, 0.028976020336683308, 0.01377069772154625, 0.06464213811393295, 0.03286377154290676, 0.0019297627108504198, 0.022376417415216565, 0.050829088781028986, 0.0272848837609802, 0.032620520131396394, 0.07487913487212998, 0.07409534550138883, 0.03104438167065382, 0.01926146331243217, 0.028985726780125072, 0.03412047268024512, 0.06827266008726188, 0.061378927502248964, 0.020529487502894232, 0.033688707277178764, 0.02263950410165957, 0.01213466327837003, 0.019589195726439357, 0.08518563397228718, 0.039127732028386424, 0.038216598598020415, 0.03732511214911938, 0.032297181231634955, 0.012589072243177464, 0.11032159732920782, 0.02479514539507883, 0.02486101757468922, 0.01411884046891438, 0.06272009946405888, 0.028706316237470934, 0.036555646652621884, 0.04628849867731333, 0.03104179984490786, 0.06381392505552087, 0.0360661073853927, 0.050721405273569484, 0.03226579220167228, 0.0294436157814094, 0.06111231752272163, 0.06402261528585639, 0.04840465262532234, 0.044448674722973786, 0.021252132386767437, 0.011847452127507754, 0.0051285915875009126, 0.028815282176115682, 0.031334055055465014, 0.015996770101732442, 0.0048317918886563605, 0.005875258731456208, 0.025119127206770436, 0.05422422695638878, 0.08208776877394744, 0.00895137052118246, 0.05324185752708997, 0.058174715510436466, 0.017649108045069233, 0.07575904551361289, 0.03359781072608062, 0.058174396598977704, 0.03861061031264918, 0.0874579663255385, 0.05883022105055196, 0.0407308286854199, 0.0176210608000734, 0.02110700392430382, 0.00587018795444497, 0.011297937149980238, 0.08144780168575899, 0.04928658530116081, 0.013477770761320633, 0.03569267903055463, 0.02217487385496497, 0.013887699211149343, 0.01085636013054422, 0.07135513611137867, 0.005693220932568822, 0.06860588184956994, 0.018360526567058902, 0.03087684798187443, 0.05522494057991675, 0.0019136322371196002, 0.018017934236143316, 0.056839328059660535, 0.003925443402424986, 0.07230025396815368, 0.04092505933450801, 0.035236856168402095, 0.0013181619911587664, 0.07412046486777918, 0.033267825575811524, 0.04838017786719969, 0.05216337021972452, 0.008922316499852707, 0.021090374727334295, 0.015776346304586956, 0.019567487694855248, 0.08234063163399696, 0.036852200382522175, 0.006051389458921871, 0.007178740193402129, 0.06579680794051715, 0.05938011261501482, 0.06643083106194224, 0.0366551402424063, 0.032710134251309295, 0.030438904517463276, 0.011126103245520165, 0.02606266238061445, 0.033382318182183165, 0.04079449223354459, 0.04354797037584441, 0.026331019587814808, 0.008948040610578443, 0.014185358104961259, 0.015008388852168406, 0.05857167885239635, 0.03414523242307561, 0.055700396852833886, 0.038325944516275606, 0.03595334165064352, 0.04661711997219494, 0.05219563116718616, 0.0050804580096155405, 0.04695523397198745, 0.010151622633981918, 0.09804882588131086, 0.03345045327608075, 0.02120574942923018, 0.03941473537789924, 0.05167694203555584, 0.06368230283260345, 0.03872680604191763, 0.0035339592307406876, 0.06261242274194956, 0.01669405643562121, 0.06998760984944445, 0.025270650861784816, 0.044679848211152215, 0.0236005268192717, 0.08751357227031674, 0.10568559502384492, 0.023541809791432958, 0.004012956608286393, 0.05666470028726118, 0.021017472924930707, 0.03737425504784499, 0.03510181073631559, 0.049808100531143804, 0.023310517559626272, 0.02425132502269532, 0.02224567559148584, 0.009812192276253231, 0.09460565421198096, 0.02619065104850701, 0.04343213087746075, 0.039419664934809716, 0.032010191452822516, 0.05247173724429948, 0.04987767072660582, 0.019562575101320232, 0.025067987718752453, 0.036197190172970295, 0.008374790478098606, 0.05763572800372328, 0.036505679333848615, 0.02085784586545612, 0.004745586983127785, 0.0152211027951645, 0.04673297304127898, 0.06322003728044884, 0.027413281246221492, 0.015330562368035316, 0.03906579874455929, 0.038473770155438354, 0.04403762838670185, 0.010414375990097011, 0.05543796664902142, 0.044499897331531556, 0.033819963091186116, 0.05191302133191909, 0.005125746405350843, 0.07649691163429193, 0.03260206737156425, 0.03238841365756733, 0.044350480527750084, 0.023306259752384255, 0.035356373326586824, 0.01191551682339715, 0.01998563659643488, 0.0298278192723436, 0.06240942542042051, 0.02900242552693401, 0.01605440995522908, 0.04778976079874805, 0.04994264045464141, 0.01667604472355119, 0.08151769757802997, 0.08809452716793333, 0.05105636069285018, 0.048130704289568324, 0.03726538410410285, 0.03844409442639776, 0.015525096661544271, 0.02650199005646365, 0.04226791745583926, 0.040027866406100135, 0.011418306717782148, 0.007942625587540013, 0.04295378404536417, 0.01841248708244945, 0.021679212505530034, 0.025879362930676768, 0.038750062829681804, 0.0694666306621262, 0.05036944915939655, 0.044945416639425924, 0.07718341265405927, 0.02767939250251012, 0.005076560250017792, 0.015850445721298456, 0.004360496731741088, 0.057806732399123054, 0.04170242637129767, 0.04193135051588927, 0.016946430750457302, 0.03647434458668743, 0.032803595664777925, 0.09892346430569887, 0.04351720559809889, 0.03850421602172511, 0.05877734960189887, 0.014920951133327824, 0.04804273900975074, 0.1340384996895279, 0.02451620643426265, 0.0037231861081506524, 0.033211737871170044, 0.029236177448183298, 0.01858954401021557, 0.025571703278858746, 0.014036318736283906, 0.017430689318903854, 0.012860780565201171, 0.025157238822430372, 0.1400350257754326, 0.044472715218684504, 0.06753068204436984, 0.029757448405559574, 0.07693069907171385, 0.05044632717700941, 0.031835533146347315, 0.04728718348113554, 0.03917701741946595, 0.05131983244791627, 0.051838379087192674, 0.06343019314642463, 0.03529448075486081, 0.03761686524376273, 0.0448620416490095, 0.0198035161010921, 0.02319415219660316, 0.05263766280508467, 0.01262775298008429, 0.031146124604025056, 0.08427873120776244, 0.03278562805748411, 0.00826492632872292, 0.05682469205930829, 0.013417795051022299, 0.023976433523265377, 0.059497600953493796, 0.02710330778998988, 0.03948535730264016, 0.011263669435200947, 0.023783446289598942, 0.016564269649929235, 0.033567856797682386, 0.08200724702328444, 0.04619374465463417, 0.04201310720028622, 0.01831796545801418, 0.039784859267196486, 0.0366478629543313, 0.013583948769207512, 0.030967503653040955, 0.05549298566100853, 0.028157791921070645, 0.03173441107251814, 0.018515583693182895, 0.02090341118829591, 0.03042083852259176, 0.011834001018931823, 0.031020402243094783, 0.043959172775170634, 0.005890150878777993, 0.053484888414719274, 0.017190593095230203, 0.012265640044850963, 0.005490905538733516, 0.06880346446165017, 0.023752634014402117, 0.06018751500440495, 0.023049515672028065, 0.03353675953777773, 0.06767865017588649, 0.028642537338393073, 0.023403948439019065, 0.015330820211342402, 0.04995553261999573, 0.04460825937400971, 0.04925568142373647, 0.040060361448143206, 0.043123862240463495, 0.00347622756297434, 0.04109355654301388, 0.06977369489946536, 0.03390768749107208, 0.016392096477959837, 0.08849366860730307, 0.03032855436738048, 0.02351122991448002, 0.027547169776101197, 0.046297655507389984, 0.015909023649458374, 0.18614072033337184, 0.08032701111265592, 0.058433230567191324, 0.07292900487248387, 0.21301509040806973, 0.0900248507303851, 0.11889196958925043, 0.15473528339394502, 0.170538920376982, 0.09876708912530116, 0.1113421886361071, 0.12715022931141512, 0.149442479546581, 0.0868468437609928, 0.1817090588488749, 0.10992747704897608, 0.14470547730369226, 0.1786016941602741, 0.10970932125513043, 0.14616339121546063, 0.2051466897662197, 0.14615661943597452, 0.06297922520233051, 0.08210984830345426, 0.19835614200149262, 0.19036291805761202, 0.11831818680678095, 0.08673986592995268, 0.1893214075160878, 0.08911855186202697, 0.1156870179942676, 0.17958860977419785, 0.07693034623350416, 0.1467835179397038, 0.1134139256817954, 0.08676427283457347, 0.14480993098446301, 0.10508700500109366, 0.11671134802911963, 0.09341532737016678, 0.17274466130350316, 0.0947109085640737, 0.12839839447821888, 0.14042561767356737, 0.10154165274330548, 0.2154236997344664, 0.1117763424824391, 0.11670229637197085, 0.10092367697507143, 0.14939582347869873, 0.18198374339512416, 0.20346521213650703, 0.09327934895242963, 0.12286780481891972, 0.08022318846945252, 0.16145048663020134, 0.10010300922606673, 0.11638195998966694, 0.07162139325269631, 0.09414870158902236, 0.19394072464534215, 0.07479746639728546, 0.15712232887744904, 0.16260126845112868, 0.08606290511254754, 0.14160655359072344, 0.1907989853726966, 0.11809364599840981, 0.10379998691912208, 0.08406762539276055, 0.10583796684763261, 0.09834822945828949, 0.13916625667895588, 0.08907777190740619, 0.13449322671762534, 0.10323579183646611, 0.09013339597731829, 0.17027917717184338, 0.0854146531117814, 0.24486008233257703, 0.13006651853876455, 0.1187232993543148, 0.17453482667250292, 0.1420062514288085, 0.17091203321303639, 0.17298172786831856, 0.15860791344727787, 0.19867684479270661, 0.2617286257445812, 0.1967557900186096, 0.08748877860073533, 0.11839187570980617, 0.09807925817689725, 0.059410409203597477, 0.08656710412885461, 0.11466093733906746, 0.19055034300046308, 0.2621531443936484, 0.19915837395404065, 0.08544374869338103, 0.18842443850423607, 0.06396474981946604, 0.1609950132135834, 0.12624253944626876, 0.112571911221104, 0.1435497828892299, 0.15542111944939407, 0.21192444036049501, 0.19282768294215202, 0.12469121840383325, 0.11764989766691412, 0.09474957148943629, 0.17215022391506604, 0.14141410748873437, 0.09116741549223661, 0.16757190387163842, 0.1701186222157308, 0.06467396819165774, 0.09996568052364246, 0.09827344132853405, 0.0812637558473008, 0.08850609258349453, 0.1080873240051525, 0.09754915269357817, 0.15449273426617893, 0.08422851283103228, 0.10544186524514641, 0.09073434051658426, 0.09467167566929545, 0.18578170745500497, 0.14398400458906377, 0.16773893205182894, 0.10881206047322069, 0.11820450504975659, 0.1275020090064832, 0.10322415496089629, 0.14669030079884188, 0.12787219057125704, 0.20020381999867304, 0.17287892981299333, 0.13066107806350502, 0.1639664944793497, 0.097236775527043, 0.1287423845912729, 0.09715225041976996, 0.1094835726544261, 0.06905059370079211, 0.14496296777256898, 0.1463473013469151, 0.19148411575172627, 0.07417330238968134, 0.11269184228565012, 0.09974255785346031, 0.17702693651829446, 0.09046752019120113, 0.10378589374678475, 0.13398455615554536, 0.1764795487480504, 0.1216526028833219, 0.11382195592990943, 0.1005620788782835, 0.115211799208607, 0.14920462588114397, 0.14349870277302607, 0.11730110352592808, 0.0847661771944591, 0.11332575684147221, 0.23113733583262988, 0.15857037689004624, 0.12500258455319063, 0.1977202325527157, 0.11029502589787755, 0.12878368023250783, 0.10730356856116227, 0.13826801202126912, 0.15041756150977953], [0.013087867576229786, 0.026020745879837444, 0.07869699357875756, 0.04752597352489829, 0.05843101854303053, 0.03465071387056794, 0.029453342580901723, 0.0267824489357216, 0.0033087856884646627, 0.055921165006501336, 0.03332777075203402, 0.03754509659484029, 0.00788237846323422, 0.049221937877259085, 0.05966351633625371, 0.05101437633857131, 0.05596150052068489, 0.02717233685377453, 0.02609047044201621, 0.08079142762081963, 0.016598617092573216, 0.045249176411224265, 0.009493298629032714, 0.07744162915540592, 0.003635597415268421, 0.03853325053517308, 0.031678445504180024, 0.008389366258467947, 0.03940257263768997, 0.04573477678267019, 0.046916621936751265, 0.021992682113445232, 0.028051567263901234, 0.020144332366596376, 0.03424928576818534, 0.037389983489577255, 0.009817416995896824, 0.07711087047521557, 0.03518360474013856, 0.04567058736990605, 0.04026269380535398, 0.019350419253376976, 0.030229176128549234, 0.028119861813528196, 0.03740180017692702, 0.014770596254883068, 0.07283027124192033, 0.03312645959002631, 0.018758465303108096, 0.02746464465079563, 0.036188036735568724, 0.009788010136357375, 0.0373716392953481, 0.03495900286361575, 0.053940046312553544, 0.05208759142884186, 0.03221992662708674, 0.044478533656469414, 0.027553817722946405, 0.017326795429523503, 0.03414959879592061, 0.008373491083537894, 0.024793423612469008, 0.03786012344062328, 0.025167362564908605, 0.037127909516649585, 0.016442206289087023, 0.04934661868693573, 0.04075791919603944, 0.05682066495397261, 0.04749396702806864, 0.03147972634594355, 0.025361623748072555, 0.02108382516806679, 0.033448916394263506, 0.1390608259077583, 0.01266770766648863, 0.03922010100047503, 0.009373575365836067, 0.024933045763256292, 0.04575548567143934, 0.07119517826608249, 0.021087859058752656, 0.017592794727534056, 0.005545734560915402, 0.01593689277901181, 0.019735610012763312, 0.06457371464265244, 0.02793715099271919, 0.04978934921590345, 0.057118670748812814, 0.005834066990895995, 0.019826230060841357, 0.025533072583909546, 0.05508090116615806, 0.02952747931703925, 0.048886453200663836, 0.023580328528104082, 0.05933541751333645, 0.03461310267448425, 0.0523873851634562, 0.041740190237760544, 0.05636006859796388, 0.05475645625431623, 0.04463281894900969, 0.03713326994329691, 0.033533940224775245, 0.009932769645404602, 0.05776208479489599, 0.03692437615245581, 0.04178591671266726, 0.023246994807517955, 0.07044684235006571, 0.024190691133428897, 0.045374325410063775, 0.020105750865436027, 0.0146484107577375, 0.06323233233498675, 0.03782760804252965, 0.021085565610389625, 0.058221520856022835, 0.024382633423166614, 0.010508983279578388, 0.043378356977232864, 0.020776240155100822, 0.019382853227268373, 0.025314165312530737, 0.044977782759815454, 0.027254020595656972, 0.056341313890048435, 0.02448808794308986, 0.021822675164522867, 0.05220204332311239, 0.03146211836220963, 0.06461870829973902, 0.0781723503023386, 0.028701512209538902, 0.02078761240201337, 0.014666909318683403, 0.0345556443291051, 0.030694797036371062, 0.11783587054482528, 0.03519496002367564, 0.01741845702885517, 0.04589172193248357, 0.02647728629277221, 0.02351808820718101, 0.070687471223729, 0.0235799689045442, 0.04510126256250909, 0.02563983158740614, 0.020599357950102006, 0.05214923633528607, 0.019868875986763408, 0.039970299495118, 0.022013207797759345, 0.0361901605501771, 0.06259254166590315, 0.017411427406061972, 0.032350402125822644, 0.019775311096704433, 0.029898217280528376, 0.026514493760519793, 0.015366650253002132, 0.019830267344202315, 0.05877998231777123, 0.008501509437337518, 0.01486706018580922, 0.02483120953131999, 0.025201045043234314, 0.07552307139017753, 0.026099267648532987, 0.05485407030209899, 0.12236863374710083, 0.011570580153992134, 0.020297922160742537, 0.024279346822627952, 0.013186577458067663, 0.02248606358521751, 0.04018779371732047, 0.022310762366812145, 0.043800850199269395, 0.014982282217325909, 0.025838028273678253, 0.030995598395488093, 0.04330604889297059, 0.05079482276258724, 0.07319854612329177, 0.02522575728861349, 0.05232644593343139, 0.05353464199496167, 0.013200474703418357, 0.03033431512968881, 0.055921833363494704, 0.015563981807125466, 0.019567608134821057, 0.03515653797824468, 0.02856005122885108, 0.010182301746681333, 0.05298963927530816, 0.06998613742845398, 0.03483141453138419, 0.035212194813149314, 0.008075213874690235, 0.023298639804124832, 0.04209317772516182, 0.013998692273162305, 0.02198993574295725, 0.011010614040839885, 0.031823787705174515, 0.04248021070712379, 0.033221376461109946, 0.04511871787586382, 0.01976462417016072, 0.008916133349495274, 0.005240077435571168, 0.05051729515460985, 0.08326882682740688, 0.023075878453840102, 0.016042376136673347, 0.027059549066637243, 0.02873189700767398, 0.054997342971286604, 0.045485978347382376, 0.005800227601347225, 0.016478375598256077, 0.00777724031026342, 0.036003224152539454, 0.017659323389774988, 0.025567878037691116, 0.02286622979279075, 0.02749806589313916, 0.03202572651207447, 0.025112421584448645, 0.031149462996316806, 0.03567407699301839, 0.020860649911420684, 0.04172939813828894, 0.058614263710166724, 0.036235164385288954, 0.0585614126175642, 0.009216332508783256, 0.0156801843217441, 0.026159467275387475, 0.014773692070905651, 0.015197695033358676, 0.06787459751857178, 0.02346750342154077, 0.02364820408235703, 0.037764416076242924, 0.027925174849640046, 0.03624986484646797, 0.05041767603584698, 0.014719371949987752, 0.027328077603929808, 0.011444186891562172, 0.04299191092806203, 0.07504475169948169, 0.06254983467182942, 0.05452224971460445, 0.05652138012062226, 0.01483808334783784, 0.029500873958958045, 0.017174963041075637, 0.05977192587618317, 0.021445119620433876, 0.08646017379526581, 0.04476591359291758, 0.03333222533443144, 0.048994655787412605, 0.05119185395804899, 0.025124550397906984, 0.04718354404238718, 0.06920700959329094, 0.002855149405409715, 0.034375795229737244, 0.049588852295918126, 0.032319606814001284, 0.0611499830016068, 0.04592034253957016, 0.014390374068170786, 0.0645930121785828, 0.05301119972552572, 0.10808957674141441, 0.04871269056041326, 0.03395766159519553, 0.026331599735255753, 0.06099128723144531, 0.014969803958332964, 0.043853535050792355, 0.061990986445120404, 0.03615533474034496, 0.03544824696811182, 0.044535869865545204, 0.04887875522087727, 0.0717464472566332, 0.0695256224966475, 0.059779002996427674, 0.017165351592536484, 0.052681977927152596, 0.05239593470469117, 0.01410042163583317, 0.01891812968200871, 0.03750898835382291, 0.030037513734506707, 0.022005385985331874, 0.007852655236742325, 0.010573553520121744, 0.008089140805947994, 0.04924509288477046, 0.03348594065755606, 0.04184081358835101, 0.013839976995119026, 0.02957981133035251, 0.014972709784550326, 0.05585679578195725, 0.03220070373000843, 0.052170359130416594, 0.0037762946199758774, 0.03992503781669906, 0.02406752684951893, 0.023875864455476403, 0.08858465336795364, 0.04625845314668758, 0.009177071624435484, 0.023189979206238474, 0.049753980578056405, 0.03674316319770046, 0.046058142823832374, 0.018461877646456872, 0.04472904878535441, 0.028868262190371752, 0.04017235704564622, 0.04572831034394247, 0.04279712727293372, 0.04526148164378745, 0.02786946712460901, 0.02059713744425348, 0.030621433830154792, 0.034645170239465575, 0.02840213747029858, 0.008840933009716017, 0.042206438790474615, 0.012383938384508448, 0.02250334756848003, 0.007212755153886974, 0.04662089941224881, 0.0158316977987332, 0.041214189891304286, 0.053614719305187464, 0.011975741895314838, 0.08996812520282609, 0.15680176179323876, 0.09697156332965408, 0.21017880045941897, 0.17369475960731506, 0.1597883201071194, 0.0902515696361661, 0.12058739789894649, 0.13669777342251369, 0.0636858922828521, 0.118118249678186, 0.08932304196059704, 0.18209906720689364, 0.07582432736775704, 0.13026526144572667, 0.22768196410366467, 0.08171291210289512, 0.12708776337759836, 0.17351884261838027, 0.06569322956992046, 0.14326572098902293, 0.1271241328545979, 0.10774539663855519, 0.15762098426265375, 0.11063029005059175, 0.14782014302909374, 0.11197729741356202, 0.1635805709021432, 0.09072199117924486, 0.12172626464494637, 0.0886518486908504, 0.1999190795634474, 0.0938493726508958, 0.1351777192737375, 0.09430230834654399, 0.13155253737100533, 0.08178253658115864, 0.15443558804690838, 0.105857447588018, 0.10364450061959879, 0.1415795614676816, 0.22828238617096627, 0.1242650712707213, 0.10638920869678259, 0.05295311712792941, 0.14148350805044174, 0.06428488264126436, 0.1767248391572918, 0.16889294369944505, 0.1374202367982694, 0.08339596393385104, 0.09407899568655662, 0.12812309925045284, 0.06726656907371112, 0.13103655220142432, 0.1435218679585627, 0.12988825381866523, 0.14047354938728468, 0.12931985860424383, 0.16200871739004338, 0.08625332918018103, 0.1681489979049989, 0.053099473738776784, 0.09471774141171149, 0.15151768390621456, 0.16128379771752016, 0.1429443803748914, 0.07493925986013242, 0.0930511983377593, 0.10851214799497809, 0.17090849126023905, 0.18807206169835158, 0.18454148114791938, 0.1002339529139655, 0.0994768842522587, 0.1050561113016946, 0.15682736970484257, 0.20820171226348194, 0.12418272426085812, 0.1235611726130758, 0.10723763531340019, 0.18855648141886505, 0.20782792089240892, 0.10717673001012631, 0.09976478666067123, 0.10867883690765925, 0.11349843043301787, 0.08546512254646846, 0.0893399849800127, 0.12487131516848292, 0.10419578996620008, 0.23045915365219116, 0.09917098709515162, 0.20008606703153678, 0.1673090529761144, 0.10343937948346138, 0.11639084879841123, 0.20667358354798385, 0.15667711491031305, 0.17146507996533597, 0.12198484076985291, 0.1321864654975278, 0.14520168996282987, 0.17975600436329842, 0.13700297847390175, 0.10136649571359158, 0.13160597878907407, 0.13305697164365224, 0.1506669774119343, 0.19480531396610395, 0.11235526177499976, 0.11142134653138262, 0.1666542124003172, 0.19633288628288678, 0.09223969759685652, 0.11300788354128599, 0.07914496239806924, 0.12136111781001091, 0.16661548162145273, 0.12697117749069417, 0.10984367118882281, 0.17133450268634728, 0.08992598139281784, 0.08315949447985206, 0.16558896670384066, 0.15591563577098505, 0.0788766967930964, 0.0948896754000868, 0.08627495409122535, 0.10575030690857343, 0.15057207750422613, 0.08569205179810524, 0.10251741324152265, 0.10083225116665874, 0.07259386964142323, 0.12127930005746228, 0.16430725476571492, 0.08916748780757189, 0.08249512727239303, 0.1343297947730337, 0.1390052946018321, 0.0815571476040142, 0.2148198035678693, 0.1066402191562312, 0.06822559689836842, 0.1333976640765156, 0.11845696078879492, 0.10444274957158736, 0.11598395848912851, 0.07749644121421234, 0.144245661262955, 0.13731933864099638, 0.09062696234988314, 0.1598420057977949, 0.06444684216486556, 0.09073061535933188, 0.0768021573977811, 0.09808464574494533, 0.2674258771751608, 0.09081729820796422, 0.10222966011081423, 0.12075240404478141, 0.14530477300286293, 0.06715592036822013, 0.09246883208730391, 0.14149786585143634, 0.07162469093288694, 0.14087484856801374, 0.1159563556845699, 0.08476978021540812, 0.1656572273267167, 0.1555480190685817, 0.05711978354624339, 0.1636075765958854, 0.25773365582738605, 0.10341963411441871, 0.20007417909801006], [0.0181605436373502, 0.06038648861327341, 0.04738706383588059, 0.05135874643123575, 0.009016582825487214, 0.015394164848008325, 0.06754759792238474, 0.01113494370864438, 0.04703087027051619, 0.010381689261911171, 0.04038329661956855, 0.027422402453209673, 0.05053459440491029, 0.02271046020489718, 0.0032407307465161595, 0.023693625216505358, 0.002245869911608419, 0.013499837568295854, 0.06578831268208367, 0.034944960581404824, 0.10026142679687057, 0.028966646375400678, 0.06506705031331096, 0.038035246543586254, 0.013881483830378523, 0.03431780084169336, 0.03688024762751801, 0.009746204745689673, 0.07040920401258127, 0.0029212410486901975, 0.03576159104704857, 0.0921355831835951, 0.026042784697243145, 0.0673623171501926, 0.0796634310058185, 0.0017919178977276065, 0.06261920809213604, 0.05341376098138945, 0.02710465298566435, 0.045223717777324576, 0.023926459419141923, 0.04245435852291329, 0.028501235813434635, 0.005512311198149941, 0.03177791873791388, 0.04239829795967255, 0.036251177811729055, 0.022512677424986447, 0.015715369755136113, 0.011240103914003288, 0.011850706551090946, 0.020160622296056578, 0.007690328456062291, 0.029356295109859536, 0.0021350944048858112, 0.04148227907717228, 0.03329738934657403, 0.011416325395527695, 0.038224174441503625, 0.08487579452672175, 0.008987136102015418, 0.034151515657348294, 0.0379027354397944, 0.011217836091028792, 0.02953213406726718, 0.02542810491286218, 0.03022782245118703, 0.0237053757466908, 0.015456822467967868, 0.036901099008641074, 0.015835280463631664, 0.034055485988834074, 0.01954883985620524, 0.04429588220747454, 0.022436013145904456, 0.032754900599164624, 0.046328600096915445, 0.01037389798355954, 0.07793292243565832, 0.010952734155580401, 0.016901506643210138, 0.058394995118890486, 0.050815881096890995, 0.046185001730918884, 0.028805188967713287, 0.010961605152780456, 0.06691015498446566, 0.052049661321299415, 0.036864804170493565, 0.04013248972062554, 0.025413760682567954, 0.028959314804524183, 0.024746195878833532, 0.012758154688136918, 0.03279019120548453, 0.04147825536451169, 0.033582597970962524, 0.013641346046434981, 0.04903096080358539, 0.04291874449700117, 0.02549133250223739, 0.033611388211803775, 0.05787246887172971, 0.007773413372758243, 0.021252052658902745, 0.09405705864940371, 0.056763342315597196, 0.012678138446062803, 0.07637575920671225, 0.07269836403429508, 0.0487815991842321, 0.019569776054205637, 0.013670271994279963, 0.05103241179936698, 0.04373524264831628, 0.059058683791330883, 0.05062052407967193, 0.08786772683795009, 0.017859162130792226, 0.03660072512658579, 0.049781831047896824, 0.08116334623524121, 0.04737740149721503, 0.00950119168763714, 0.008865527359635701, 0.05830715876072645, 0.004832942429597357, 0.025763811809676032, 0.027898959649194564, 0.05695086225335087, 0.030343366786837578, 0.04454184097370931, 0.05339738453871437, 0.02049529951597963, 0.07797124609351158, 0.006909502587015075, 0.055385953547166925, 0.022712512773328593, 0.03919140914721148, 0.010426424227521887, 0.06755694134959153, 0.04243865722258176, 0.0367216095328331, 0.045749524741300514, 0.025947671051004102, 0.019991704395839145, 0.042175087079937966, 0.02032247495039233, 0.013482545103345598, 0.036726952996104956, 0.06116503290832043, 0.06882246344217233, 0.017536267671468, 0.01814639787854893, 0.02377171441912651, 0.012624333163590302, 0.025459585545052375, 0.04919339869437473, 0.048545509709843566, 0.03868787170254758, 0.037885921342032294, 0.04013875938419785, 0.03711042366921902, 0.024998168161671077, 0.0662364579205002, 0.02579298542280282, 0.06318012585065194, 0.04035432995962245, 0.04029312270826527, 0.012011867947876453, 0.012656508446005839, 0.03720534732565284, 0.0105370661476627, 0.04127979404958231, 0.05350109522363969, 0.04733733061168875, 0.021749278031555668, 0.026460012487534965, 0.019712675529132997, 0.021663521383223788, 0.005909181241544762, 0.09873517762337412, 0.05534435595784869, 0.010841383166345102, 0.11691701199327197, 0.06519347495798554, 0.04386487676362906, 0.01160766463726759, 0.07189638313970395, 0.018890927213111093, 0.03108236606099776, 0.016574064302923422, 0.04336627905390092, 0.014794892897563321, 0.025930395549429313, 0.07042581454983779, 0.008937857496286077, 0.02553144240352724, 0.0847028223797679, 0.01891767167087112, 0.03260457116578307, 0.03282806703022548, 0.09472897116627012, 0.044871883799455, 0.03638676607183047, 0.04444408782624772, 0.0211036010711853, 0.028243713114144545, 0.05287416957850967, 0.03814133210107684, 0.06014907599559852, 0.009268859600914376, 0.05702544003725052, 0.0963841759200607, 0.06760826573840209, 0.037330591319394965, 0.05558840464800596, 0.07535452329154525, 0.05222441801535232, 0.02235130313783884, 0.01982049474359623, 0.07460060981767518, 0.02217517580304827, 0.030241932586899826, 0.03178241063973733, 0.014197741369051593, 0.03839279717898794, 0.0019693794019985944, 0.04076908788244639, 0.05795050039887428, 0.024185332403119122, 0.002007497166882136, 0.018117814590888362, 0.02328765262583537, 0.055526227091572115, 0.0233923098671117, 0.017113274029855217, 0.06067660983119692, 0.07981962298176118, 0.04388611830238785, 0.03439059407849397, 0.046855784486979246, 0.03839670214802027, 0.020845177616657953, 0.012194057144889874, 0.04546018723132355, 0.052232526508825164, 0.036139195784926414, 0.04702005102964384, 0.008105665678158402, 0.017974854047809328, 0.009094478645628052, 0.03178981684946588, 0.07943245768547058, 0.02501657003137682, 0.06749625317752361, 0.03963537460991314, 0.05629097676969, 0.08154096454381943, 0.05287599144503474, 0.02109306851135833, 0.034540031238326004, 0.07216237565236432, 0.041234990382300954, 0.0280848952076797, 0.03937651350029877, 0.029829084740153382, 0.0719697056338191, 0.025310146688882793, 0.034685824665107896, 0.0017396324276757824, 0.01954437848845763, 0.06361024919897318, 0.01055817028308021, 0.035137667919376066, 0.020245410335649337, 0.012455065817838269, 0.019474910073248402, 0.01195642230699637, 0.05850407640848841, 0.017549458392230526, 0.042546713924301524, 0.0802391611837915, 0.004096913866565696, 0.03872946250651564, 0.04182780267936843, 0.019167369165058647, 0.037504211467291625, 0.02791616220825485, 0.03987721466858472, 0.06406057253479958, 0.025958586983116608, 0.030870612245053053, 0.012431161029131284, 0.054904607590287924, 0.041325181256979704, 0.02201183037167149, 0.06384540908038616, 0.02164892609497266, 0.0020664294175471044, 0.040774807932653596, 0.025802227069756815, 0.026892731232302527, 0.026491744177682058, 0.07122638409159013, 0.03915436452786837, 0.006239939073566347, 0.0182639116620911, 0.04002180369570851, 0.07479390408843756, 0.03939095272549561, 0.023374615370162895, 0.04315923766366073, 0.02082235169863062, 0.022716819774359465, 0.0473453373249088, 0.01616317402970578, 0.030480719237987484, 0.01756070850283972, 0.04547573246860078, 0.014035027823410928, 0.03901217072936041, 0.026066183977361237, 0.02760591564167823, 0.05974442485187735, 0.05479798259745751, 0.07080121404890503, 0.06415161836360182, 0.029043829733771936, 0.031013297981449535, 0.032340583724102805, 0.0072471653610201815, 0.038140867304589064, 0.02529210613907448, 0.0790070772969297, 0.028532987859632288, 0.050444593520036766, 0.027879755411829268, 0.03829849777477128, 0.03920434881001711, 0.0586082518899015, 0.027948619930871894, 0.014086155437066086, 0.025234734306910207, 0.04572221709947501, 0.015872983261942863, 0.038738554875765524, 0.014245267658095275, 0.0530685427199517, 0.011042759637348354, 0.02460627517263804, 0.04433780210092664, 0.14381206381533826, 0.13222887393619331, 0.10548512863793544, 0.10666694665061575, 0.12849215444709572, 0.11113682322736297, 0.14754427783191204, 0.09200557587402207, 0.16495009884238243, 0.11664563869791371, 0.19381596919681343, 0.1446490774729422, 0.23262392463428633, 0.08309336445693459, 0.08255400375596114, 0.09838457179388829, 0.167356848982828, 0.10643095895648003, 0.09013277172510113, 0.1618452447333506, 0.25407941905515535, 0.08991366598222937, 0.17755985792194093, 0.14181012766701834, 0.10122464118259293, 0.1714736430772713, 0.23168713918754033, 0.09933281091174909, 0.2748639237667833, 0.10248298437467643, 0.1413130329123565, 0.09278074106467621, 0.13882430217095784, 0.15840223591242517, 0.1826075884912695, 0.07822179514914751, 0.16905866909239972, 0.12848140645240033, 0.2841838736619268, 0.19878116276647362, 0.10284542385488749, 0.17146825550922326, 0.08858968131244183, 0.0672376566965665, 0.13569925485977105, 0.12575387209653854, 0.11422079881387097, 0.11141088352139507, 0.08006687435720648, 0.08942189772746392, 0.19629490189254284, 0.14795608073472977, 0.13423250642205986, 0.08144655996667487, 0.08560554536857776, 0.1068722102791071, 0.1102218119693654, 0.12908347057444708, 0.12454637831875257, 0.21913318282791547, 0.12960666178592614, 0.09686084677066122, 0.17690862715244293, 0.07911442832223006, 0.2091334086975881, 0.10152405833027192, 0.09843377915344068, 0.10999300996107714, 0.1135650354304484, 0.12502337486616202, 0.1739090545369046, 0.12369113921054772, 0.07221928438437836, 0.1883044463715383, 0.08726113688732896, 0.13728818031294004, 0.1361643634736538, 0.11368624214082956, 0.130277244374156, 0.1842435635626316, 0.10912830528936215, 0.15598973179502146, 0.15688851928072317, 0.1754166507827384, 0.13655486037688597, 0.07407648222787039, 0.20238805136510304, 0.1649395272667919, 0.052258025854825974, 0.1291970709072692, 0.11418011385415282, 0.09460158978721925, 0.11047161463648081, 0.16725050897470542, 0.17985269560345582, 0.1352987020675625, 0.1259643400886229, 0.10237970455948796, 0.07316693317677293, 0.12427957834942, 0.0821129424231393, 0.11138653768492596, 0.11011238462690796, 0.1417281199246645, 0.06523705726223332, 0.218908194186432, 0.13464854338339396, 0.05225232616066933, 0.18367339058646134, 0.15529785677790642, 0.12408918142318726, 0.11144305965197937, 0.15091253923518316, 0.15086730809084006, 0.189287467194455, 0.08771603354918105, 0.17913686830018247, 0.1142473431038005, 0.12521689305348055, 0.07775397918054036, 0.10131922217884234, 0.18083686993590423, 0.18334268618907246, 0.1838941994522299, 0.11154167114623956, 0.0874848702390279, 0.11187787167727947, 0.13479917815753392, 0.15483653438942774, 0.1539415738412312, 0.07207730093172618, 0.11391165825937476, 0.13071835998977932, 0.13522964077336447, 0.19530253085706914, 0.05127022475270288, 0.12639842608145305, 0.10855639526354414, 0.07664627076259681, 0.1085221835279039, 0.1854214325015034, 0.08508515650672571, 0.11496038841349737, 0.12763563969305583, 0.1377959552087954, 0.10687755713505404, 0.15634569126580442, 0.2176429299371583, 0.1025487140619329, 0.1635088361799717, 0.1585185503853219, 0.18010806904307433, 0.12096369984958853, 0.11262982418494565, 0.1272326713161809, 0.05403829479057874, 0.153018644079566, 0.14772224399660314, 0.15117825354848588, 0.1071720684745482, 0.09105598647147417, 0.10636942940098898, 0.08581181322889668, 0.19043332285114697, 0.18896850145288877, 0.23995511553117208, 0.1603575295635632, 0.09090945683419704, 0.1165913287550211, 0.09164288533585412, 0.06816352451486246, 0.10030541622212955, 0.09157766454986163, 0.20481123562370027, 0.09398351902408258, 0.08795032490577016], [0.08193222819162266, 0.05795658685799156, 0.05535027617588639, 0.041912432959569354, 0.12546630895563535, 0.04461548577195831, 0.02639670347395752, 0.020898256018491726, 0.062435291175331385, 0.06431652272918395, 0.05775853605674846, 0.03112758363464049, 0.008217811401534294, 0.03955083253926464, 0.0518570896903319, 0.08839342184364796, 0.04169023648968764, 0.0651275756369744, 0.01339447295426258, 0.07460257078387908, 0.07057915667870215, 0.016015663909326707, 0.03883345478347369, 0.03587293864360877, 0.026007058132173758, 0.01745137106627226, 0.06434150638857059, 0.053488725530249734, 0.042213234318686385, 0.06683736174766507, 0.07954477558710746, 0.049216641911438534, 0.026847213406914046, 0.015837960676955323, 0.014494203496724367, 0.0277497616729566, 0.03928084684801953, 0.029767042890723263, 0.010764302436395414, 0.057063560134598186, 0.04579481016844511, 0.053987730360989056, 0.01929570049313562, 0.009867698985284992, 0.0036590005121459918, 0.03346480768440025, 0.01353568711783737, 0.05353473359718919, 0.015834871646282927, 0.04794894511412297, 0.015115412484322275, 0.03151600422071559, 0.047002412511834075, 0.0394393526283758, 0.046551030661378584, 0.019401767390913198, 0.040777254051395824, 0.02515457387614463, 0.02858123169945819, 0.04925688582339457, 0.06774166572306838, 0.02683581062592566, 0.016198313661984036, 0.03088023726429258, 0.11768311874142715, 0.031004426136080707, 0.03162128232153399, 0.05747234355658293, 0.009411826929343598, 0.07316135561891965, 0.0312829070857593, 0.015096589922904968, 0.05274374496990016, 0.052088612624044926, 0.021683775653530444, 0.046834773650126796, 0.053081557021609375, 0.07336511289966957, 0.047540575598499606, 0.029984995124063323, 0.012650228604408247, 0.06339424436113664, 0.020474020657794814, 0.030507406020270925, 0.04283463329608951, 0.0711687154003552, 0.02547340391070715, 0.010362477391026914, 0.03759995615109801, 0.024621143571234176, 0.009432802143107568, 0.037653495956744464, 0.07963837270757981, 0.0310349534265697, 0.0650865106976458, 0.036197621042707136, 0.04493804096377321, 0.023812843819281886, 0.022530551733715192, 0.07850285113922187, 0.052451147099158595, 0.042244494426995516, 0.01700634878527905, 0.029801264804388796, 0.025906312645279934, 0.021840027001287256, 0.023075403479327048, 0.02061011442648513, 0.016054306478638734, 0.027585671549396854, 0.039625956543854306, 0.036374257278761694, 0.03437395300716162, 0.06024912598409823, 0.05040334537625313, 0.01547948214491563, 0.049354574510029385, 0.026174965015213405, 0.05603730645296829, 0.10151068440505437, 0.0432973636447319, 0.031669132611049075, 0.02763009862974286, 0.0597676918176668, 0.04669744155502745, 0.04134663314159427, 0.02848572450290833, 0.022361878106104474, 0.020718378081385578, 0.028567654213735034, 0.07438845227339438, 0.04578227423397558, 0.04699711993868862, 0.03637438280774014, 0.025992834341845343, 0.07971917265760047, 0.04958326456003955, 0.026542797152485167, 0.04762843570538929, 0.04378837194027645, 0.054271039087325335, 0.04634136673329132, 0.05832626630685159, 0.04776843444311193, 0.04500641015225223, 0.027264195228261606, 0.013693228530298387, 0.05510638015610831, 0.04948796431667038, 0.042578164022415876, 0.0231245514670653, 0.03352509891348226, 0.0618440903989332, 0.027859241601877978, 0.05074797331222466, 0.044530336412468126, 0.03608825816107648, 0.013360137385981423, 0.0786730752193502, 0.007086764771624335, 0.010845621465705335, 0.03357992454298905, 0.02126858855730721, 0.054088112831647904, 0.06172008133892502, 0.025940219040161798, 0.020388197852298617, 0.03505425560953362, 0.017293569265997837, 0.11577220128050872, 0.057449456570403915, 0.025638574601284096, 0.03658452510301556, 0.05974044863666807, 0.01907648448832333, 0.05307271910299148, 0.03210111853799649, 0.020837883365207484, 0.012091407519099968, 0.0626918181244816, 0.05049215543216892, 0.01711937066699777, 0.04985853943175503, 0.06775168089994363, 0.011651555674948862, 0.014154875767417252, 0.04510343048189368, 0.03481766741190638, 0.02855763564418469, 0.06639178137161902, 0.04645077711237328, 0.0834138026194913, 0.0598219610484583, 0.06961122647460018, 0.06047684233635664, 0.04134137449519975, 0.03193431766703725, 0.03156181211982455, 0.015282878319599798, 0.05772484000772238, 0.029883231834641526, 0.012155593539189016, 0.0344435435586742, 0.016416274377011826, 0.015832432312890887, 0.006224053720611015, 0.04352731576987675, 0.02423421067318746, 0.02531674544193915, 0.09514749156577246, 0.006454092783055135, 0.013057248683513274, 0.007924808106119079, 0.09241865442267486, 0.016801076675099984, 0.016042255696707537, 0.04262214666232467, 0.02888910678614463, 0.002727122569922358, 0.10332462564110756, 0.02148764510639012, 0.009610125395868505, 0.029680041130632162, 0.02736409254638212, 0.032001414602356296, 0.04106455256364175, 0.00318952086048999, 0.008674033751179065, 0.04828039250735726, 0.04808236545483981, 0.03203185707596796, 0.0042629645322449505, 0.02895036492762821, 0.06010383806590523, 0.036124118736812046, 0.016128356701561382, 0.01627228924605463, 0.033098263067326376, 0.060509459514703066, 0.0470938688543226, 0.07341062224337033, 0.04911184557048338, 0.01501161019716944, 0.02766464793655489, 0.047424210235476494, 0.06340825610927173, 0.03478925036532538, 0.047693934690739424, 0.030368632038256953, 0.08646892689700637, 0.03685571180124368, 0.03264087278928075, 0.01780517109935837, 0.06492299054350172, 0.030330359270530086, 0.022961689491889307, 0.01449391511934144, 0.12858196534216404, 0.04931464950953211, 0.012511748936958611, 0.028638791825090135, 0.010114505920293075, 0.00457412881743429, 0.011835630351145352, 0.06310689156608922, 0.05608977756596037, 0.05454730462016804, 0.0388328983847584, 0.048098487446882894, 0.021807092607819607, 0.05828121158161333, 0.027598994584488015, 0.03767070699749248, 0.05194232386669942, 0.03799680753477982, 0.01490023885188358, 0.0052898975970622686, 0.011728206383330482, 0.04172800714150071, 0.036006263989423, 0.04926439042070082, 0.06698376246328865, 0.014501387486234307, 0.06397448001163346, 0.004332205638222928, 0.054501425474882126, 0.04400806461593934, 0.019255095261282155, 0.029088300918894153, 0.06668848437922341, 0.048127016451741965, 0.009504069524284984, 0.06132181520972933, 0.013234907811108445, 0.04321027706776347, 0.05001801212451287, 0.08259044787181274, 0.04059625822784645, 0.0277600296041263, 0.03459191881120205, 0.06776428129523993, 0.02637636777944863, 0.04815362520249827, 0.13031559517341001, 0.011518070025236478, 0.022832462497587715, 0.030461055293147053, 0.013673830062284, 0.007011770536856992, 0.0442514212003776, 0.011025842062995901, 0.036432757175394466, 0.028451731594811593, 0.030036821628787687, 0.04119351153661098, 0.034695212197090895, 0.05831661753888641, 0.06145979530577149, 0.017082063115334938, 0.04635837082085865, 0.08360677797879491, 0.004724221187643707, 0.018646788617063845, 0.007216826363998864, 0.0359831700500633, 0.01587974655974124, 0.020578789857349226, 0.07576348991798502, 0.026708125602453947, 0.037167366327983994, 0.06551098184926168, 0.10529344249516726, 0.03178235635693584, 0.010615466628223658, 0.04831793924261417, 0.03832718623535974, 0.033686909159379344, 0.043299372108387094, 0.008493308493468379, 0.04562655383987086, 0.03042186311046992, 0.012788339318441493, 0.03880572644993663, 0.02813831966237298, 0.022742945068914975, 0.1138477266899177, 0.013206294837540813, 0.033399732783436775, 0.03707519413105079, 0.04884914055998836, 0.02503337904012629, 0.06119789435927357, 0.18603558811758245, 0.13645517001194613, 0.12294298649898597, 0.13698461731629713, 0.21065023301967553, 0.10616422005529914, 0.17309583031705447, 0.2572317570447922, 0.1194540544279984, 0.13228633228157247, 0.2158237368400608, 0.09140918430473123, 0.08639599795320205, 0.1199186337845666, 0.10341610573232174, 0.19939151858644827, 0.1392871987606798, 0.2022921879376684, 0.1402619821684701, 0.11909193385924612, 0.2086760625243187, 0.12905813407685074, 0.08249602972396783, 0.17244373102273258, 0.1028521413515721, 0.0959250180582915, 0.08947451811816011, 0.17086145521274634, 0.1291477142700127, 0.15833758509584836, 0.20333025152129786, 0.10969805078847067, 0.12920241776321614, 0.2127922052251441, 0.09130922252578394, 0.05878683552145958, 0.09770444221794605, 0.15522023237177304, 0.05963917049978461, 0.12157888683889594, 0.1554751308368785, 0.15724297240376472, 0.10303388695631709, 0.12641388310917787, 0.1158671961831195, 0.07340199127793312, 0.07596602583570139, 0.15193567504840239, 0.11769149186355726, 0.10344389174133539, 0.09684682145182576, 0.12431625995252814, 0.22006481140851974, 0.11846688097076756, 0.18557740056088992, 0.10184683743864298, 0.10182441864162683, 0.1259641365281173, 0.12163278966077737, 0.1939634419977665, 0.10977970569261483, 0.2035348976829222, 0.08215176141155617, 0.08739602964903627, 0.14882959957633699, 0.09587285228605781, 0.09105554542371205, 0.19624527384127888, 0.1239900067448616, 0.18365823211414473, 0.08158037385770253, 0.1609314073409353, 0.10518145707568952, 0.16941876762679645, 0.08289240952581167, 0.13528593203851155, 0.0830554547054427, 0.14764517598918506, 0.11375881146107401, 0.1711871384509972, 0.13253892372761453, 0.1721821150609425, 0.10781139095446893, 0.08409454966230051, 0.2072746298675026, 0.16859326192310878, 0.10039028738226209, 0.17074883197035107, 0.15402314732117312, 0.16657793149352074, 0.10077458247542381, 0.08299703962568726, 0.15949215314217977, 0.09738403119679008, 0.11429032151188169, 0.1050631884219391, 0.15606293215283326, 0.10736319821860109, 0.08840392556573663, 0.12971216041062558, 0.16795043141714164, 0.10819200838782958, 0.10046655471835818, 0.10291164887270757, 0.1153540201485157, 0.2243170818047864, 0.1338615920394659, 0.14161423460713454, 0.07917788491717406, 0.23285717783229692, 0.1160534947578396, 0.0645848765437092, 0.1186841885958399, 0.12701900063880853, 0.10077826013522488, 0.09381520162735667, 0.11441146715411118, 0.09963524754026107, 0.12910641862877778, 0.17287819699517318, 0.09850588028452226, 0.1141227912157774, 0.13182410065616879, 0.1428266138370548, 0.19031529847000325, 0.08841721128140177, 0.2014258344258581, 0.20080916823021003, 0.10207566658833198, 0.061032392882875035, 0.11790457900081362, 0.09045231422143322, 0.09455470301743064, 0.17532450572720595, 0.1054117518610188, 0.11456596957785742, 0.08816901674228055, 0.10641771395291601, 0.11542362427072865, 0.09436827552105699, 0.16712071879633836, 0.18624763031091007, 0.08350810541638307, 0.10042962205729314, 0.17288549803197384, 0.07289915611701352, 0.16076399918113435, 0.09039536477731806, 0.13811572162168367, 0.1543799481753792, 0.08622331079095602, 0.18917660814310822, 0.21801562208150113, 0.11574140936136246, 0.15088739272739204, 0.1798610280134848, 0.10146798419633082, 0.09323350034121956, 0.18874755688011646, 0.12046532944909163, 0.0928279874580247, 0.18926906532474927, 0.07157570070454053, 0.11615193661834512, 0.14830800970750196, 0.16969327575394086, 0.1387443028922592, 0.08583617263606616, 0.07690268914614405, 0.2386039894606386, 0.1623575251017298, 0.06037857010960579, 0.09812349187476294, 0.1785478320504938, 0.07271550382886614, 0.14830582482474192], [0.027971607000966157, 0.036076546646654606, 0.01360856686785285, 0.056751182968063016, 0.024772897928154895, 0.05653066587235246, 0.03488546323829463, 0.053777421824634075, 0.0893711568787694, 0.02332608145661652, 0.07915277233613388, 0.02128285645241184, 0.0633114223767604, 0.004393769544549286, 0.028359445743262768, 0.042156118633491654, 0.02534095896407962, 0.025370470148378184, 0.04546718292736581, 0.06059490742960146, 0.025136670729677593, 0.02661029781614031, 0.024297970912552307, 0.08151266963354178, 0.038361825448061736, 0.03201028644772513, 0.06251883919217757, 0.08312481455504894, 0.02230838579790933, 0.04345149965956807, 0.030147148030144826, 0.03320211285193052, 0.0348873359949461, 0.03323391578825457, 0.04013454568173204, 0.040835550387523005, 0.03174292668700218, 0.04259315625365291, 0.06394812571150915, 0.018615864383588945, 0.039115070564938445, 0.06647959737373249, 0.06322860717773438, 0.04670848810513105, 0.03923461825719901, 0.03329026472887822, 0.075180445132511, 0.06370784967605557, 0.018721003384728516, 0.008098496107517608, 0.04726887321365731, 0.04291947392214622, 0.044609728402325084, 0.08817441788102899, 0.03053576878405043, 0.053454038820096424, 0.02568476926535368, 0.03748574174408402, 0.03362931849967156, 0.05550261068024805, 0.01753439661115408, 0.03231773066467472, 0.02329116404455687, 0.01208581808688385, 0.0401517363664295, 0.04712458274194172, 0.04746068149272885, 0.05454564220937235, 0.02982250295047249, 0.010779610186416124, 0.05476300411724618, 0.017181763658300042, 0.017155969149566123, 0.031763343805713315, 0.012788408020112132, 0.05350095273128577, 0.03173104893150074, 0.018656091332169514, 0.03654887487313577, 0.07743660799626793, 0.01484884660957115, 0.016138758643397262, 0.0347919543273747, 0.015434417241652097, 0.056376411113888025, 0.021167150964694362, 0.035609663663698096, 0.04780150963259595, 0.01794038786153708, 0.060585937196654935, 0.00595771854776623, 0.04354208408455763, 0.026846511123169745, 0.03742473126788225, 0.08718181614364896, 0.017324205122089813, 0.07305813008653265, 0.068148698524705, 0.04330911926392998, 0.013469346749064113, 0.012003752669053418, 0.015005956304126551, 0.035807850171944926, 0.01952172050784741, 0.03325997831832085, 0.020671976464135305, 0.012976752377913466, 0.08730604233486311, 0.07528844076607909, 0.03465392334120614, 0.056755834325615845, 0.009504933808264988, 0.09407014758991343, 0.022516232948484163, 0.022780205123126507, 0.03071819292381406, 0.0488172935188881, 0.019822891668549607, 0.04123125843969839, 0.05397101804347975, 0.042254017665982246, 0.025167552554713826, 0.02946709648572973, 0.040791754344744344, 0.023206199585859264, 0.011477703976977085, 0.018832624091633728, 0.04708486808730023, 0.026197490681494986, 0.04579430126718112, 0.05685671891218849, 0.07061368054045097, 0.012475748413375445, 0.025542550021782517, 0.019792228671056882, 0.0304821170201259, 0.015217023103364875, 0.03393005539796182, 0.03494131684835468, 0.012159352623192328, 0.026296365108074884, 0.01882710590559457, 0.03880264590095196, 0.04125312762334943, 0.059395834271396906, 0.02580289203407509, 0.060117089854819436, 0.01657726359553635, 0.03221862044717584, 0.03507041492100273, 0.06072969162570579, 0.018164518156221936, 0.04286225645669869, 0.03783108214182513, 0.033541682309338024, 0.04496830701828003, 0.012595540378242731, 0.0520917406704809, 0.015078607048573238, 0.012275790080561169, 0.056639516460044045, 0.062374290877154896, 0.00738384436616408, 0.05009357378418956, 0.037418027341897996, 0.010664219369313546, 0.03982888261920639, 0.05385551102725523, 0.026048799910183464, 0.03895654442853161, 0.1000261108524033, 0.04179153498262167, 0.08008482839379992, 0.07898410210119826, 0.04192565082173262, 0.00962034413324935, 0.08511857435639415, 0.013816951757429965, 0.019818401463063698, 0.08755512575485877, 0.05004752500514899, 0.0219182213768363, 0.021065061978463615, 0.021880976589662687, 0.031865110487810204, 0.009518440895979958, 0.04379749484360218, 0.04596739894311343, 0.025427102377372127, 0.040132649176354916, 0.05729374635432448, 0.053566855444972, 0.017515516374260187, 0.006987898402647781, 0.012238531722687185, 0.03158695523494056, 0.05538549553602934, 0.04863941217107432, 0.024400158286360756, 0.023111949375431453, 0.03104243766782539, 0.038824311524097405, 0.00369922661255779, 0.051174707378127744, 0.03463072422891855, 0.06177234210606132, 0.0604858464960541, 0.06684433708765677, 0.008843762500743781, 0.030595523970467702, 0.0228584741375276, 0.046785142206187756, 0.01971715216391853, 0.02529215533286333, 0.02687044644595257, 0.01853223833521562, 0.05867432763001748, 0.05762073237981115, 0.060670944063791206, 0.01645960223062762, 0.03337634028866887, 0.0017158456404493855, 0.08832495766026632, 0.044485213833728006, 0.06157118361443281, 0.024139370137293423, 0.03600889331262026, 0.05175526533275843, 0.0548078790307045, 0.05288402529965554, 0.014194272358768752, 0.009031614072487822, 0.06061377748847008, 0.03458223272381084, 0.03217962843232921, 0.028254040417128375, 0.026480053019310747, 0.024066744837909937, 0.06835818942636251, 0.023881689678611498, 0.03517115701522146, 0.014111708217699612, 0.021078466437757015, 0.062147979092385085, 0.01761267241090536, 0.02141009533910879, 0.025100462404744964, 0.06323775382978575, 0.027128467868481363, 0.006971003728852208, 0.04604092839040926, 0.027506883455706493, 0.02285912722748305, 0.08171791290598256, 0.0606578958353826, 0.003609268136122929, 0.04938011456813131, 0.04796984060002225, 0.017147567189697708, 0.05710197200200387, 0.03226671840197273, 0.011394866725562938, 0.025425263547471592, 0.03037732746452093, 0.0648633133886116, 0.03520442558718579, 0.0477635795250535, 0.021395352469491105, 0.0209228189861668, 0.024274632700585892, 0.03708846288334046, 0.02460668738266187, 0.014882337401754089, 0.029505518531160693, 0.04346350633672305, 0.010054548869707754, 0.07807829177805356, 0.02678803158258753, 0.04853397122185145, 0.02402962727605232, 0.00631979077089844, 0.06060765031725168, 0.03013949076245938, 0.03820725517081363, 0.11106645914592914, 0.00954226850132857, 0.04836347572771566, 0.02000701553853495, 0.07617859728634357, 0.0015277660173264199, 0.0469888452041362, 0.03019943254600678, 0.026817086452086056, 0.020393911117155637, 0.019163789892835275, 0.013738391821139624, 0.06576959190091916, 0.06838500513029949, 0.010027663615931357, 0.040676440711000135, 0.09360632140721593, 0.04560979402491024, 0.018427487795374224, 0.02009683321895344, 0.05511926553611245, 0.07751978281885386, 0.017562221635931304, 0.07233231474778481, 0.0017564976276064823, 0.02328569165963147, 0.01610118307040206, 0.06447807513177395, 0.02824959940543132, 0.012601914366574159, 0.03924638405442238, 0.033366711876754246, 0.017932864604517817, 0.022912093671038747, 0.06727230947996889, 0.0277996645309031, 0.06875386355178696, 0.015150864242709108, 0.02426276681944728, 0.029184931090899875, 0.0393795126250812, 0.052634812958006344, 0.011635100352577865, 0.0342649701051414, 0.04290189647248813, 0.02161811551611338, 0.03328653617895075, 0.024958412794928466, 0.038803378718772104, 0.050601338502019644, 0.033691312851650376, 0.10240251690681491, 0.09942441313926663, 0.07324764491724116, 0.030250292138329575, 0.0400753265379795, 0.054098986355321746, 0.021934606301199113, 0.01794002314896456, 0.03857033247394221, 0.035040481348655055, 0.13925700395234994, 0.09091487832899604, 0.02965068431305034, 0.05210757428514106, 0.04369897834424462, 0.06979338598570653, 0.055357312584029775, 0.1256075392344168, 0.09566627908498049, 0.1316004962261234, 0.22482244111597538, 0.14985854364931583, 0.09770886626626764, 0.13056167268327304, 0.09703805976148162, 0.12208069062658719, 0.18540037077452454, 0.1668146995029279, 0.12399931624531746, 0.1338723943169628, 0.18886642264468329, 0.09211792770240988, 0.08321894771818604, 0.09583059991044657, 0.09617763664573431, 0.105836670845747, 0.10451337828167848, 0.15094200122569287, 0.09346483328512736, 0.10280178048248802, 0.10936225059309176, 0.17556505996201718, 0.20578464839075292, 0.1422783846833876, 0.2206138412335089, 0.0921182194724679, 0.12235537517283644, 0.17333576029964856, 0.13253531392131532, 0.12809937766620091, 0.08633207316909518, 0.06016356271824666, 0.17172349324183805, 0.12944233417510986, 0.09891686894531761, 0.15877977279680117, 0.12371252663433552, 0.1598844685192619, 0.14806016800659044, 0.12842519661145552, 0.16717454019401753, 0.1907875859843833, 0.16317574333931717, 0.18738816625305585, 0.132249419976558, 0.1286663750984839, 0.07106603269598313, 0.22370060559894356, 0.11931073426135949, 0.16750318184494972, 0.11774555753384318, 0.1107029000829373, 0.22891811920063837, 0.11944161009575639, 0.13273963438613073, 0.08044252491423062, 0.09160807648939745, 0.13306505978107452, 0.1163801686572177, 0.09028447858457055, 0.17508138663002423, 0.0986042542915259, 0.11562491846936089, 0.1371678760541337, 0.11393513557101999, 0.13714328594505787, 0.13773243076034955, 0.12118514653827463, 0.11043273457991225, 0.1133380586813603, 0.20625925649489674, 0.10571610874363355, 0.14935706555843353, 0.06957505377275602, 0.16219131116356167, 0.12414961175194808, 0.0954877972336752, 0.1366750696407897, 0.14213442669383117, 0.14563975217086927, 0.1444943036351885, 0.12304274471742765, 0.10321871311004673, 0.12490748108497687, 0.09739849756338767, 0.1337369858686413, 0.15477064863911696, 0.14446907570319517, 0.09603552427142859, 0.11806722384478364, 0.06955336779356003, 0.11595144309103489, 0.10598153807222843, 0.13568995893001556, 0.1825485559446471, 0.15365504207355635, 0.07852275935666901, 0.09847855567932129, 0.08534580894878932, 0.2194792628288269, 0.0672887707395213, 0.09525343802358423, 0.17325502820312977, 0.2826136622045721, 0.16658922231623105, 0.28542969109756605, 0.1424517368099519, 0.1664589707340513, 0.08929455706051417, 0.1499380408121007, 0.08625747502914496, 0.0960329594090581, 0.1449788183506046, 0.1736488634986537, 0.14754748051720007, 0.08358651692313807, 0.1295731421560049, 0.17027516024453299, 0.12255855569882051, 0.11233054952962057, 0.11328001679586512, 0.16447721421718597, 0.09496736765972205, 0.1363386112664427, 0.08725551183202437, 0.1271658627582448, 0.15472563462597982, 0.191159545310906, 0.20514841324516706, 0.08521510274814707, 0.10234028167490448, 0.12794674799910613, 0.1274482418916055, 0.14633520985288279, 0.13269272047494138, 0.09849851139421974, 0.06916336622089148, 0.10182669173393931, 0.08058930560946465, 0.1259985789656639, 0.11327823903411627, 0.14869315975478717, 0.07994077540934086, 0.22698555647262506, 0.16077725775539875, 0.10962198701288019, 0.11966507881879807, 0.18420700409582683, 0.09990417132420198, 0.08690399676561356, 0.08757196020867143, 0.15188372640737466, 0.15350383733000073, 0.12348262539931706, 0.11189832950809173, 0.07047167673174824, 0.21691577109907353, 0.17108852017138684, 0.15952685342303344, 0.09062506923718111, 0.18015480653515883, 0.13541422943983758, 0.0643513315756406, 0.11035211104899645, 0.13910347861903055, 0.1559216340205499, 0.2359073827309268, 0.18160027611468518, 0.08701429263289485, 0.187860494479537, 0.09379471665514366, 0.1353520756321294, 0.1773555510278259], [0.04615606560504862, 0.02950280099841101, 0.07353387812950782, 0.0855991942808032, 0.02294632576272956, 0.03959715612498777, 0.01387788844294846, 0.03879420153264489, 0.04247290967032313, 0.028737427068075964, 0.021421615167387893, 0.011594199109822512, 0.081968007343156, 0.02773559555810477, 0.03971831873059273, 0.0100099453702569, 0.10391613175826413, 0.04509118292480707, 0.017291033241365637, 0.008100528319898461, 0.07130117900669575, 0.048567222830440314, 0.03350940779117601, 0.0960423910458173, 0.04243850455220256, 0.02874112847660269, 0.04348578603406038, 0.0736467931419611, 0.0540818906655269, 0.013141319172323813, 0.02218069738176252, 0.022325043832617145, 0.02388077535267387, 0.017198774531217556, 0.017367775551974773, 0.07010122375296694, 0.003983418706671468, 0.03718905569985509, 0.008009531684885067, 0.029444416452731405, 0.07120684228305306, 0.07742877770215273, 0.03522414381482771, 0.06029215867498091, 0.04518337208511574, 0.020540574765098945, 0.010748049826361239, 0.010389505137157227, 0.011758249369449914, 0.02261294624102967, 0.02486560447141528, 0.09095433514033045, 0.027127073479018042, 0.042526154313236475, 0.022886455225359117, 0.02191251829000456, 0.027060977382851497, 0.041782042277710776, 0.04191745072603226, 0.009858967087763761, 0.0858486576804093, 0.026191662065684795, 0.019301200019461767, 0.011916454898060432, 0.013479399245365389, 0.0220093638968787, 0.029310429535273994, 0.015927501854353716, 0.028435233015833155, 0.017567425999524336, 0.03951513820460864, 0.011062391351775398, 0.04864638072571584, 0.022790186373250823, 0.047282108039196045, 0.09373141612325396, 0.033024418101246865, 0.020026189241824404, 0.01480171556717583, 0.02574298417727862, 0.040223511800702126, 0.009563059662468731, 0.04798283454562936, 0.04560132251520242, 0.02596742150905941, 0.06404510193637439, 0.010854952170380523, 0.030328903812915087, 0.037872340463634045, 0.024692367695804154, 0.006771976685351027, 0.036449571273156574, 0.046476992312818766, 0.028192556662751094, 0.04226113889100296, 0.039979320618190935, 0.02282831325594868, 0.04306617997852819, 0.010977335290850272, 0.03684393921867013, 0.03370920582009213, 0.05361702632425087, 0.040206955546247106, 0.02400669957777219, 0.033205437673521895, 0.06348947675100394, 0.007408364925400487, 0.03760067879089287, 0.025671612471342087, 0.047566668662641726, 0.024441206262313893, 0.015029325050168803, 0.031764571954097064, 0.024189551194597567, 0.038360180000641515, 0.034378889349422286, 0.01968964435426252, 0.06543911142008645, 0.029562759745333875, 0.029327477727617537, 0.04420999663748911, 0.04148559032806328, 0.019219073533479656, 0.029070492767329727, 0.06253243703395128, 0.05258188383387668, 0.03206257435626217, 0.07101867773703166, 0.02257391351408192, 0.06323311943560839, 0.014454683920900737, 0.02641460153141192, 0.046322035270610025, 0.024220280349254608, 0.024240867101720402, 0.021328903535114865, 0.04862643518884267, 0.02141423779539764, 0.03974305472469755, 0.025214622528957467, 0.06805533889148917, 0.005220730705851955, 0.03688008817178862, 0.010836206792321588, 0.014311972739441054, 0.014642763650044799, 0.02643800590054265, 0.06185744396810021, 0.032124358362385204, 0.07005543620990855, 0.058809919282794, 0.02892103525144713, 0.00434777038338195, 0.03626407676243356, 0.0191200515255332, 0.023497045139915178, 0.01958980640795614, 0.021773018275520632, 0.006028017744288913, 0.10175271106085607, 0.00947448200479682, 0.0748124620211976, 0.020202589686959982, 0.04363684828526207, 0.014686807358105267, 0.05773765074887446, 0.02603596881298082, 0.011878671523715769, 0.04352888997112002, 0.01998312771320343, 0.03500168950163892, 0.01552177862530308, 0.04104119060294969, 0.027510055606918674, 0.04725218464487365, 0.05558310868218541, 0.02623526133330805, 0.05526456702500582, 0.030993908843291656, 0.015617153507524302, 0.00645539429803778, 0.027284659844424044, 0.06353809378509011, 0.03445307358301111, 0.12317318628941264, 0.049009006803057024, 0.08199661437954221, 0.010299894409919423, 0.01641246270654457, 0.03839564363339117, 0.011350906138042254, 0.04770897441942777, 0.054054800154907365, 0.02725463975886149, 0.01827525846394045, 0.018916153448766897, 0.055928194629294534, 0.08372073114982673, 0.024784154824114273, 0.051400581507810524, 0.06712302499051605, 0.01076795719563961, 0.0549025618072067, 0.02963964794097202, 0.0904087997706873, 0.015970822922619324, 0.03230773923652513, 0.01597457691761, 0.027736905130690763, 0.011807110676142787, 0.04282632124211107, 0.12065553638551917, 0.005114068393595517, 0.0390098671029721, 0.028406491968780756, 0.031802400281386714, 0.013581047183834016, 0.030122018485729183, 0.03200413552778108, 0.07442465890198946, 0.018168704717286994, 0.009786653914488852, 0.013674273654552442, 0.02825667313300073, 0.05986809464437621, 0.04846784798428416, 0.028446308403675045, 0.028444573050364852, 0.08678717339145285, 0.02862950268068484, 0.03343951868425522, 0.032104382291436195, 0.05794413574039936, 0.013637972031054752, 0.04600372092266168, 0.04961005651525088, 0.05980327419404473, 0.06700910574623517, 0.04076781902196152, 0.025724734977952073, 0.013725575990974903, 0.0054695528898654235, 0.016127467820686952, 0.0579074677079916, 0.06045506814760821, 0.030046992868717228, 0.05153810020004, 0.028471549906368767, 0.019230898702517152, 0.01976510593002396, 0.014543560133980853, 0.037818030520741425, 0.03143565888915743, 0.011151002936198242, 0.025737589823880365, 0.005884560598393104, 0.0744900018242853, 0.03352882407073464, 0.04590623240385737, 0.010636938868888786, 0.03942163607903889, 0.008340036762612206, 0.011802446596058351, 0.0469261926731893, 0.047026765133653364, 0.05560928317052977, 0.03136577996026192, 0.036203514119344096, 0.06263935379683971, 0.0961772363100733, 0.02352327900007367, 0.018152635311707854, 0.061039205374462266, 0.021152822001438056, 0.033279476022081714, 0.10090179422072001, 0.022268569363015037, 0.01426676704016115, 0.03994885778852871, 0.06186589172908238, 0.0819441636226007, 0.06946215233100311, 0.03508349368348718, 0.01021253302626844, 0.037589577957987785, 0.019090182414012294, 0.0382637499964663, 0.0220270617865026, 0.02671995246782899, 0.003423827908201409, 0.03183848816635353, 0.03148076111184699, 0.028220062776069556, 0.01753392333297857, 0.03690608624102814, 0.017123781144618988, 0.03633555364129799, 0.03826629450278623, 0.012167831766419113, 0.011056728128876005, 0.02710445790684649, 0.04837400659120508, 0.0555192551442555, 0.04716171557083726, 0.01563884796840804, 0.028864594708595957, 0.01684616702342672, 0.01901303807140461, 0.017437471276415244, 0.006645021511108747, 0.02880206092127732, 0.014412607964394348, 0.0663347572886518, 0.021795289491170218, 0.013620219858629363, 0.03518218320927449, 0.017352880011977892, 0.05540629602702601, 0.03879098527665649, 0.031152964237013032, 0.036225685251078436, 0.019849018659442663, 0.038497885290001116, 0.025339885182412605, 0.020745860445978384, 0.040360541947718175, 0.021942282228597572, 0.05068962947864618, 0.022414040485663072, 0.027627404845718826, 0.05966359097510576, 0.05193853424862027, 0.03692922767783914, 0.01416992737046842, 0.04380061949736305, 0.04816000343167356, 0.05788271475051131, 0.060861239209771156, 0.033150079394025464, 0.004687572239033345, 0.004640203285297113, 0.0885641412543399, 0.024035106446327906, 0.02400826699366527, 0.028828089524592673, 0.03342595476923244, 0.045755658697869094, 0.037536540268255134, 0.04341924210478153, 0.04805448445092354, 0.03786551779402154, 0.05694082672042506, 0.20897754920380457, 0.1266352076615606, 0.23488143778273038, 0.1364699485046523, 0.11041081789880991, 0.07658144352691514, 0.17304211748497828, 0.08852832817605563, 0.19432151849780763, 0.08677723963877984, 0.11802003851958684, 0.08981614692934922, 0.19318235319639954, 0.08876665003065552, 0.14041743454124245, 0.1817333096904414, 0.15651791702423776, 0.11051466089806386, 0.08980182305510555, 0.11139427298413855, 0.1603792291134596, 0.20034232256667955, 0.12915014342537948, 0.2063055732952697, 0.15289050952664443, 0.11045176748718534, 0.1384076273867062, 0.105137338728777, 0.13213267124124936, 0.11315813155046531, 0.12820526984121117, 0.14745268917509488, 0.08346645693693842, 0.07023714110255241, 0.09171392795230661, 0.20856745620923384, 0.12235875427722931, 0.09611426826034274, 0.09478409535118512, 0.1723837756684848, 0.07946050153779131, 0.12271769930209432, 0.16471236731324876, 0.1181485259107181, 0.12314578704535961, 0.08932047709822655, 0.08851438428142241, 0.10399008528994662, 0.1550732481160334, 0.12788756617477962, 0.10888977987425667, 0.14888428949884006, 0.13506483818803514, 0.09985972728048052, 0.12645942637962954, 0.17101515696517058, 0.12243595799165112, 0.13037734186010702, 0.11358406833772149, 0.0963997415133885, 0.20102735795080662, 0.09456946793943644, 0.14613325068993227, 0.08687871455081872, 0.09798779844173364, 0.28574827685952187, 0.15326858923903533, 0.0977724924949663, 0.07599425967782736, 0.10555072261818818, 0.1092303433854665, 0.08334264465208564, 0.15151041001081467, 0.05869252593921764, 0.12193445275936808, 0.2115253803453275, 0.08923584342535053, 0.12427253515592643, 0.05970314956669297, 0.061640462039836814, 0.11400180842195239, 0.1461922696658543, 0.18380091445786612, 0.1305047028831073, 0.1703464471335922, 0.09120442957750388, 0.09446903797132628, 0.15957160959286348, 0.14785990518118652, 0.15923743109617913, 0.10451077270720686, 0.12073412431137902, 0.12051107628004891, 0.18578210100531578, 0.15199263127786772, 0.10855192371777125, 0.11255500212843929, 0.11409551410802773, 0.06927754330847945, 0.15882987582257815, 0.13412845986230032, 0.09805223212710448, 0.11564819222050053, 0.12379228164042745, 0.14346325610365185, 0.21206054091453552, 0.14464545409594262, 0.10544536648584263, 0.19944744344268525, 0.09266499656119517, 0.16224182131034987, 0.10125361462788922, 0.07049297594598361, 0.10386831539549998, 0.16118930493082317, 0.15104478571031774, 0.09133472865713493, 0.11517912096210889, 0.1792869602463075, 0.10169051654104676, 0.11303139477968216, 0.1365847566298076, 0.140781237876841, 0.08936158953500645, 0.14905694951968534, 0.1221456942813737, 0.20194815711251327, 0.1350027115217277, 0.10477079411170312, 0.1703839429787227, 0.10949919253055539, 0.07793597584324223, 0.12239144609442779, 0.11702279560267925, 0.09746145204241786, 0.09891570865043572, 0.1994179543107748, 0.17244025692343712, 0.17611860883023056, 0.12426413489239556, 0.17317445895501546, 0.12374952036355223, 0.11075719645512955, 0.15705135411449841, 0.12787620749856743, 0.08021227762635265, 0.11359386638339077, 0.1303875877388886, 0.1502631405102355, 0.18036435171961784, 0.12979030050337315, 0.22843847636665615, 0.07694680070770638, 0.13560131511517934, 0.15409713477960654, 0.11921150530023233, 0.07219271973839828, 0.14577817331467355, 0.12378228003425257, 0.22193798875170095, 0.0971641315679465, 0.17034571431577206, 0.16993810475936957, 0.13872849302632467, 0.11837959422596864, 0.21099008406911576, 0.18818368070891925, 0.06928417938096182, 0.11749637233359472, 0.11413280639265265, 0.12024652904697827, 0.1113305381898369, 0.11452399540160384, 0.11817376741341182, 0.13673579852495873, 0.24412655883601733], [0.10417069774121046, 0.03043679766623037, 0.04012549063190818, 0.05400485658485975, 0.016346978988232355, 0.003907562732430441, 0.023890412246276225, 0.05512650211208633, 0.17296357027121953, 0.02296105845432196, 0.06192000489681959, 0.029762513669473783, 0.050433926949543614, 0.08154779739145722, 0.04263797688430973, 0.03651209148977484, 0.03949293993147356, 0.004749671763940049, 0.030037160896297013, 0.07250411302915641, 0.025734858720430305, 0.004652278240038348, 0.04935362456100328, 0.026980659192694083, 0.04562349025426166, 0.05502185504883528, 0.025504485903573886, 0.04071134115968432, 0.022356144485196898, 0.005554407510706889, 0.029335813530321633, 0.060409090614744594, 0.03834355928535972, 0.03829381588314261, 0.06489016301929951, 0.017787091533786485, 0.04577117679374559, 0.06843152549117804, 0.0580729895404407, 0.073026632490967, 0.02940767378147159, 0.03832736265446458, 0.06697524684880461, 0.009806454414501786, 0.0572882637913738, 0.017613191490194628, 0.05969457966940744, 0.05673605842249734, 0.0395189753201391, 0.035312485681580644, 0.046471187445734224, 0.04683949964653168, 0.07879013608076743, 0.012173041219024785, 0.02151028103461223, 0.046254181768745184, 0.0404079715455217, 0.02394111916821982, 0.022727954534015486, 0.025771893161748136, 0.04562389398259776, 0.01284524126510535, 0.05303051083215645, 0.03407992682020579, 0.011803897812829485, 0.031997560523450375, 0.03558117197826505, 0.02887555644182222, 0.020532712240570357, 0.05653696946267571, 0.004533744109461882, 0.01566790114156902, 0.019758374862638966, 0.023482246291158453, 0.013356414773235363, 0.03180879886661257, 0.03293835950483169, 0.06511268179331507, 0.03167282384155052, 0.05369279493710824, 0.017745853568028127, 0.06773092451372317, 0.056476796977221966, 0.05057723354548216, 0.012210989986280245, 0.05294604000768491, 0.023605895727606754, 0.04143680366022246, 0.043023601906108, 0.046255623655659814, 0.09469414874911308, 0.0438256981516523, 0.025322250057277933, 0.033689548660601885, 0.02323937994827117, 0.06812013898577009, 0.027571369727541293, 0.024132807007325546, 0.029472232995820895, 0.04106450167351535, 0.038326283783784935, 0.025724280359489576, 0.027013256014989953, 0.10783404045339141, 0.019766568172989146, 0.04968465804787619, 0.009415019436606338, 0.005249140542998377, 0.002828137350401708, 0.03980336291715503, 0.12688528852803366, 0.03337735469852175, 0.03609379839950374, 0.06473272253892251, 0.026343240003500665, 0.012739280388424439, 0.02233671972395054, 0.015353507029690912, 0.028204185056633184, 0.02280620319236602, 0.07728840916284493, 0.0165221919970853, 0.0528460409093116, 0.0027812739052543683, 0.006103556503408721, 0.02790263052364545, 0.01587466093977647, 0.03030662750825286, 0.009059618909044989, 0.04356039774471095, 0.016431590608720268, 0.041921094459082396, 0.05247998144477606, 0.11668673077864306, 0.02401256381667086, 0.05196594027802348, 0.02060709833832724, 0.04095894876601441, 0.0335603691637516, 0.07340691744216851, 0.025006402184122374, 0.02720430094216551, 0.07466298754193954, 0.009804026955472571, 0.06840192100831441, 0.026027593994513154, 0.02967013791203499, 0.04018696590459772, 0.03818115871399641, 0.07170711258160216, 0.07536404313785688, 0.04415948649070092, 0.05472953877012644, 0.008192411291279962, 0.027894973255960003, 0.024436400538044314, 0.008527388762948769, 0.025782232339094793, 0.02749737209108259, 0.032176856616778035, 0.033106792252510786, 0.03839095834908741, 0.0906649399548769, 0.024636872012966445, 0.07852842512407474, 0.026035275010924255, 0.020638395766062394, 0.005221026292669454, 0.0762411921418139, 0.042089422033833604, 0.00960278619147305, 0.0028199525217392613, 0.04129984815205846, 0.02085396464514945, 0.054867661358522515, 0.013448679420564855, 0.01591421104967594, 0.03129498840176633, 0.006439919882853116, 0.019694249910701598, 0.06914632820657321, 0.021162304528323666, 0.03657428600958415, 0.054223952149706225, 0.055804887853030644, 0.017329014239034483, 0.042896749784371684, 0.05219718161970377, 0.03380580885069711, 0.0756120951846242, 0.03678962588310242, 0.022023991415543214, 0.04593234582405005, 0.008336679710607444, 0.018344255297311714, 0.12882410734891891, 0.07217167836746999, 0.05074809884120311, 0.020728908944875002, 0.04490181737180267, 0.029082343381430422, 0.03579068662864821, 0.01785573043993541, 0.029657574836164713, 0.01785639879692878, 0.050782052733536275, 0.018923934549093246, 0.0672076450926917, 0.06055355750556503, 0.01475983638582485, 0.015720187353768518, 0.0535913573444954, 0.03678124597562211, 0.061279481409915855, 0.05759613548538514, 0.04386777750083378, 0.049088588782719204, 0.07053711464894669, 0.023143384206507887, 0.04391854549092906, 0.030753894043820243, 0.045080377254635096, 0.005470625823363662, 0.05056677392816969, 0.04866109136492014, 0.02790489004525755, 0.016047027494226183, 0.03399812603103263, 0.032979804423770735, 0.010511401408751096, 0.09472918151212589, 0.01828862730014537, 0.05219799925440124, 0.04551704507321119, 0.006560428550333849, 0.014946000949878777, 0.01985470817557403, 0.04470554093963333, 0.030971439156149114, 0.04101999995431729, 0.01108506290308599, 0.05943385937384196, 0.0287595981998103, 0.028941550757735968, 0.02549124090000987, 0.022329551001478518, 0.021617241902276874, 0.056086272932589054, 0.061112500727176666, 0.013569993848380233, 0.046985876613429615, 0.08317322124327932, 0.048016720584460666, 0.038605212566575835, 0.026177248285551156, 0.016340137658906833, 0.018854174363826002, 0.027029886908297027, 0.013975652616604098, 0.04147370578721166, 0.02513841456467552, 0.06260770692356996, 0.03047665481322578, 0.03013932452137981, 0.005201181263795921, 0.03651907700779183, 0.04187233153996723, 0.08368538626070533, 0.02094644896819123, 0.03874225628429225, 0.02463148274858083, 0.012318335922567971, 0.023771485413557718, 0.013034588158396738, 0.015281439825360264, 0.015008258234177316, 0.007542166942065316, 0.042454073538205454, 0.036837662769747634, 0.023733431473374367, 0.04279375495389104, 0.034706397846873314, 0.0518886687100998, 0.020874642999842763, 0.04672780938978706, 0.027920053606586795, 0.04119023081979581, 0.029609327603663717, 0.10353371620710407, 0.05546070096482124, 0.043259606563619206, 0.041954108580414734, 0.025617685900735, 0.04599062519680176, 0.06846759641276938, 0.031899050809443, 0.06137904963855233, 0.051819709196154556, 0.04611336539632507, 0.06943730437862021, 0.036807247437536716, 0.05360025293858988, 0.012721020162903836, 0.035834245184170346, 0.007799098467720407, 0.0094035420167659, 0.053196663702172894, 0.02815572069292622, 0.030453934068126336, 0.04489054351246782, 0.03557300580931561, 0.03450051675151501, 0.03141901442514999, 0.01839865175341921, 0.02390509404774223, 0.07894252826060567, 0.039648025895335844, 0.039935639926365445, 0.038755392722253285, 0.07564555374639374, 0.05623117069314633, 0.03362827355574284, 0.02779343049041927, 0.05125244713521429, 0.014070641582033463, 0.04079326408516083, 0.015542178780638745, 0.009821312635072639, 0.03947607833626015, 0.021088452776893973, 0.030509780892836194, 0.023608808339174305, 0.028238859892423664, 0.07063830457627773, 0.017432913217427473, 0.028735109870987277, 0.02053625588970525, 0.04948214927156057, 0.01370610118777092, 0.020131399489140937, 0.04115746097107019, 0.0799581255497677, 0.030009242572954724, 0.018255309534392188, 0.03088423722822751, 0.02119498616749687, 0.014679219640259231, 0.020025436067953706, 0.01105792828769024, 0.027957641053944826, 0.07107906735369138, 0.02360141909282122, 0.18369447945484094, 0.18480384349822998, 0.12917917115347727, 0.1375458472009216, 0.15126015272523674, 0.1672027672507933, 0.12082477658987045, 0.17551296204328537, 0.21719504254204886, 0.11398006815995489, 0.13088817016354629, 0.10763096170766012, 0.10556388619754996, 0.17229942019496644, 0.12544486724904605, 0.11304631576474224, 0.20995913153248175, 0.09858730448676006, 0.13484138303569385, 0.1858149149588176, 0.08588403649628162, 0.1341206838509866, 0.10460408484297139, 0.0655047528977905, 0.13388124241360597, 0.1552046396370445, 0.0704674291025315, 0.11766167703483786, 0.09225121233612299, 0.17946033951427254, 0.0838134258187243, 0.11914381464677197, 0.15547175173248562, 0.11278322738196168, 0.15443856003029005, 0.12616632639297418, 0.10043654989983354, 0.11541914593960557, 0.113891655047025, 0.17128817231527396, 0.24093486581529888, 0.17986644272293362, 0.11749566665717534, 0.10547946287052971, 0.13665556854435376, 0.09957705637706177, 0.14144734213394777, 0.22362887087677205, 0.11995918303728104, 0.08694329072854348, 0.09911591719303812, 0.08398967528981821, 0.20606624042349203, 0.08588974297578846, 0.17250767616289003, 0.128495438556586, 0.10616246264960084, 0.0951781002804637, 0.14729357271322183, 0.07424951544297592, 0.18904390026416096, 0.13506011558430536, 0.18989399607692445, 0.09408458002976008, 0.08825966902077198, 0.15090538747608662, 0.2353100005005087, 0.14232109167746135, 0.15416764813874448, 0.12065306651805129, 0.060289682022162845, 0.16186332090624742, 0.17416194453835487, 0.08796793967485428, 0.14550100533025606, 0.1178941974150283, 0.09941613501203911, 0.15746474478925976, 0.1847303310143096, 0.16126141963260515, 0.07494073906647307, 0.08454360413764204, 0.2275882177054882, 0.12523089801626547, 0.09290264666612659, 0.11795606623802866, 0.08784368634223938, 0.12158071888344628, 0.08352166933140584, 0.1575064475515059, 0.14695422377969536, 0.1200405800981181, 0.09463538761649813, 0.07222139462828636, 0.13038667850196362, 0.27418359741568565, 0.12691115428294453, 0.09303226042538881, 0.12359770493847982, 0.13956746086478233, 0.0939271327640329, 0.10599320208919899, 0.09706293485526528, 0.16808335642729486, 0.09326401406100818, 0.14471759593912534, 0.10480802532817636, 0.10579357708671264, 0.06717265304178, 0.20602892099746636, 0.15317028308553354, 0.1872354687324592, 0.14196209236979485, 0.13731563383979456, 0.09638215388570513, 0.14914730324276856, 0.11174979140715939, 0.16471409079219612, 0.14927561421479496, 0.06700619483100516, 0.11198256963065692, 0.13800600250916822, 0.12894879494394573, 0.18616607040166855, 0.10993764150355544, 0.19015315574194702, 0.09207727666944265, 0.17487374134361744, 0.11158127723527805, 0.12714248044150217, 0.19404563972992556, 0.13925884956760065, 0.07729787472635508, 0.15128049520509584, 0.12650781949715956, 0.16077424505991594, 0.09296028821596078, 0.0894127714314631, 0.0838436952659062, 0.18946787608521326, 0.10716611093708447, 0.07155666779726744, 0.1893886231950351, 0.1294851361640862, 0.09487664752772876, 0.13131179314638886, 0.08748751652560063, 0.139434386576925, 0.12119246114577566, 0.16871812593724045, 0.17745007095592363, 0.16959993647677557, 0.12975139330540383, 0.15831239787595613, 0.12984642892011575, 0.11787301355174609, 0.15176435852689402, 0.09656991809606552, 0.07975235980536256, 0.10379366975809846, 0.09115554791476045, 0.13218955961721285, 0.1834972564663206, 0.07450372180236237, 0.1299474492136921, 0.12840866749840124, 0.07724257412233523, 0.1299809417022126, 0.18462076117949827, 0.10775609713579927, 0.12703349414680684, 0.06816663220524788, 0.10382239893078804, 0.1403038613498211, 0.14550747855433396, 0.186728209523218], [0.0042812345117064455, 0.04206317290663719, 0.013303596759214997, 0.0299146208646042, 0.03526342420705727, 0.030800387263298035, 0.031238646246492863, 0.03409455942788294, 0.050219241862318346, 0.05780093092471361, 0.08333386440894433, 0.03773409573893462, 0.017367322629849826, 0.010400930818702494, 0.05525486397423914, 0.0450279638171196, 0.02164923652474369, 0.02415684750303626, 0.058731358498334885, 0.01636709246252264, 0.06396335882267781, 0.021570044702717235, 0.07553235374923263, 0.03403214438419257, 0.05187323543110064, 0.05341279746166297, 0.003316773105845121, 0.03309214607413326, 0.01782324387958007, 0.0319989006301122, 0.012512141639100654, 0.019681254268756936, 0.04835551990462201, 0.014079849302236522, 0.01867187405670328, 0.043448544639561854, 0.03361177158408931, 0.03233292306374226, 0.028910653665661812, 0.07231818086334638, 0.03682412938880069, 0.05189844300704343, 0.019372349505179694, 0.06759398257625954, 0.04737808681758387, 0.05431444836514337, 0.054651235828974416, 0.018814737908542156, 0.05694681818463972, 0.06990316616637365, 0.03251555754936167, 0.0312684983946383, 0.010113926621020904, 0.015021442169589656, 0.05018578330054879, 0.011028373846784234, 0.015199757779815366, 0.050180008967540095, 0.04123053240722843, 0.004954899345258517, 0.026441948189001, 0.052253411816699166, 0.027095087338238955, 0.014472054417378135, 0.025957224824066674, 0.05665392854384013, 0.0752759285803352, 0.03660074548263635, 0.027235774789005518, 0.04864207202834742, 0.021333493824516023, 0.024179678510076234, 0.024436649899663668, 0.013288879334660513, 0.05111075545262013, 0.014314417161845734, 0.013464263673605663, 0.033022114474858554, 0.019678160149071897, 0.02434678132911878, 0.004811430749084268, 0.037287548450487, 0.02700119505503348, 0.01982139210615839, 0.036290353031030724, 0.005749094898679427, 0.015269869106954761, 0.008459820245791758, 0.0389641304500401, 0.041137674889926396, 0.011365115509501525, 0.03519013224701796, 0.03468259144574404, 0.0680176123444523, 0.01915557961910963, 0.03346013936347195, 0.051207148137369325, 0.0482521077751049, 0.025202103557863405, 0.08366184109555823, 0.036442928415324004, 0.053530275622116666, 0.023761933336832693, 0.05075630232957857, 0.057742834756416936, 0.04342672973871231, 0.06598596314766578, 0.01863049529492855, 0.04093935267467584, 0.07227083268974509, 0.010020429584463792, 0.015331715877567018, 0.009831759529853505, 0.01506479037925601, 0.01132411927184356, 0.047991950663604906, 0.07397267315536737, 0.03448471367093069, 0.05417040895138468, 0.02977789266567145, 0.0438008976967207, 0.02278705663047731, 0.06858207884111575, 0.014627296444294708, 0.06655085033604077, 0.009017782136132675, 0.049378747320068736, 0.025183345457272868, 0.03590792390917029, 0.009359164978377521, 0.034429660732192655, 0.03647962698180761, 0.031200241164437363, 0.034267928517822704, 0.04245265540001648, 0.04380832426249981, 0.0201960774471185, 0.03283844183066061, 0.057244688272476196, 0.058472409179168086, 0.025549379476745213, 0.02698420114549143, 0.029755039606243372, 0.05252823206995215, 0.018683497361572723, 0.023132432651306902, 0.041420664704803906, 0.06682650518736669, 0.033636304017688544, 0.020079528879640356, 0.04018038072224174, 0.03823739569634199, 0.03846399585849472, 0.03628887043201497, 0.005816482755887721, 0.04182311739506466, 0.0074460227707667005, 0.016983003787962452, 0.04550917745966997, 0.03709101756768567, 0.039130687048392634, 0.060292640434844155, 0.06895881505416972, 0.012316844841864492, 0.015749444087435092, 0.03864039460729275, 0.006127574522646942, 0.006365382811054587, 0.019457303785852025, 0.0014570028724847361, 0.017963449570483396, 0.04545568175879972, 0.035889898626399894, 0.014106024638749659, 0.048217502489153824, 0.04662334553099104, 0.015384192079571741, 0.03827457602268883, 0.01976820683505918, 0.01970896733525608, 0.04070109867357782, 0.010388133648250784, 0.021056470028789978, 0.07459092033760888, 0.028391711779737046, 0.06694298250866787, 0.04500029655173421, 0.01295443536115012, 0.046865921800157855, 0.11747689837855951, 0.03013694964881454, 0.11981968980814729, 0.03418021768863712, 0.015791735478809903, 0.031081107378538166, 0.047550841833331754, 0.04217949416488409, 0.05309310568762677, 0.012159441680913525, 0.036391637953264375, 0.027510276130799736, 0.01636388129554689, 0.019118628298331584, 0.02216011062929673, 0.004908834451011249, 0.03157427680811711, 0.025973404491586343, 0.030416353406118493, 0.08057105980281319, 0.02338304277509451, 0.027746531846267835, 0.0717239606061152, 0.01981385867111385, 0.04840990787904177, 0.037564434842871766, 0.0334807464719883, 0.01568945311009884, 0.030232107399829795, 0.05486564950219222, 0.06196476106664964, 0.03251767797129495, 0.058606508054903576, 0.03621629432642034, 0.010062147613747843, 0.02637720407385911, 0.08674235615347113, 0.08433155515896422, 0.019942717560167824, 0.007159609746720109, 0.014452208964420217, 0.017731757003015707, 0.07050619380814688, 0.01622748388243573, 0.04463566879608801, 0.05145991939519133, 0.031014454883656332, 0.017914079362526536, 0.021325928159058094, 0.018697115559396998, 0.038044186242456944, 0.030127409446452345, 0.03992788427110229, 0.04628608987799712, 0.04090069314198835, 0.03915794380009174, 0.02695907499375088, 0.014993600181436964, 0.027909577025898864, 0.003781574470589736, 0.032026557717472315, 0.006328763124266905, 0.035088518235300264, 0.016536475159227848, 0.04138079737978322, 0.01671911812653499, 0.01372331053218139, 0.04052744799160531, 0.059987048618495464, 0.028027945763564537, 0.01211758200744433, 0.015813662337937524, 0.02728344696307821, 0.03066831381459321, 0.09701637378228561, 0.05204768339172006, 0.02733705971123917, 0.029680587351322174, 0.031492964564157386, 0.029503550779606615, 0.06449837011418172, 0.03532098772536431, 0.020952455699443817, 0.03552239388227463, 0.059180731885135174, 0.012048585174073066, 0.062188263716442246, 0.08248925794448171, 0.031469687420342646, 0.027193676780111024, 0.06818643864244223, 0.030067922281367437, 0.07074126548000745, 0.012798201824937547, 0.03675151935645512, 0.030847026367804835, 0.07201089949480124, 0.04131700151732989, 0.006117558921687305, 0.004602640010749123, 0.01805226132273674, 0.013873283734678157, 0.029447585211268494, 0.047689914370753934, 0.019635870454034636, 0.051516068167984486, 0.011544918807755624, 0.025495851545461586, 0.028904692735522985, 0.035871432295867374, 0.022233957291713784, 0.015749788443957056, 0.024724260538018177, 0.028823594230094125, 0.021735871875924722, 0.025884645325796943, 0.03377437910863331, 0.04545979368101273, 0.041685622451560836, 0.020046445208468607, 0.04741788628910269, 0.029927798014666353, 0.07271574810147285, 0.01648452821453767, 0.056828498640762906, 0.004721687707517828, 0.014846581998946411, 0.035020369570702314, 0.03470348693164332, 0.03251645660826138, 0.04606458890650954, 0.040296057372220924, 0.030395834507154565, 0.07584932459784405, 0.018076164415106177, 0.06762752934758152, 0.019827398837410977, 0.009526845400354691, 0.03680854004674724, 0.029990107885428836, 0.08413753485573189, 0.03702146094292402, 0.034384721357907565, 0.043714326806366444, 0.04085232377318399, 0.006635946105234325, 0.07180600906057016, 0.06419255438127688, 0.03435210757223623, 0.03512487753427454, 0.05892022193542548, 0.0974410959918584, 0.028555956270013536, 0.038329293086592636, 0.010436216336009758, 0.05673914575683219, 0.013679072593471833, 0.057018736111266274, 0.038672635198703835, 0.03487226912485702, 0.07979731275034802, 0.021013177798262665, 0.00998405586662037, 0.0894928996318153, 0.10101946576365403, 0.14882684472416127, 0.12101784694407668, 0.12957652126039776, 0.047986861650965044, 0.13774167240730353, 0.15171059141201632, 0.08407517070216791, 0.10671377235225268, 0.11656479803579194, 0.10527421281273876, 0.10938323089586836, 0.23293081245252065, 0.09296059355671916, 0.20012379357857363, 0.14201044477522373, 0.1252677831798792, 0.08521525202585117, 0.14178551041654178, 0.22467424906790257, 0.12793575573180402, 0.17466882376798562, 0.13182002944605692, 0.10767280017690999, 0.09918514812099082, 0.06865808833390474, 0.11327007625784193, 0.11380026995071343, 0.07050835154950619, 0.1134893787758691, 0.08115631661244802, 0.14167712123266288, 0.1246422960289887, 0.10490188029195581, 0.15579922630318574, 0.10657617902117116, 0.09499872954828398, 0.1585642157920769, 0.10134485723184687, 0.1310081894376448, 0.059722352107720714, 0.11778774884130273, 0.1052677667300616, 0.08734615732516561, 0.20227579453161784, 0.1007698191595929, 0.16005513364715235, 0.15358067463551248, 0.15640426240861416, 0.18493177449064596, 0.0893867699695485, 0.1580714908029352, 0.11073095750595842, 0.10564931375639779, 0.15651919267007283, 0.07379941602370568, 0.10397480468132667, 0.12778638303279877, 0.08189858642539807, 0.1699915054653372, 0.11283013450780086, 0.12334769192550864, 0.10730839973049504, 0.14558157457837037, 0.11538175866007805, 0.23910029711467878, 0.11364429510597672, 0.1014438419203673, 0.08990986618612494, 0.10361670782523495, 0.10323935414531402, 0.11118280754557677, 0.07724309659429959, 0.12531107371406897, 0.0743650496006012, 0.06913585162588529, 0.11291984362261635, 0.12425011635891028, 0.08085006661713123, 0.08942217592682157, 0.21710649372211524, 0.10047494141118866, 0.11923689608063016, 0.2839597671159676, 0.09036158051873956, 0.1414096834404128, 0.23921969213656016, 0.11495894991925784, 0.17774617006736143, 0.06519863182412726, 0.12712952042264597, 0.09326792920806579, 0.13765610914145196, 0.06946897839329072, 0.07235493710530655, 0.10341489115463835, 0.10596002172678709, 0.0578446625066655, 0.22037084427263054, 0.1819726289915187, 0.11103884955602032, 0.10984772882823433, 0.14645977531160626, 0.11521403837416853, 0.17621137813798018, 0.11786073206790856, 0.12378971677805696, 0.140043263190559, 0.1852198668888637, 0.10138639714568853, 0.10485698162977185, 0.10523690695741347, 0.1385783196559974, 0.08502553363463708, 0.09823704471013375, 0.13598144400332654, 0.10101396284465279, 0.130529360845685, 0.14332294863249573, 0.12912845744618348, 0.06879002946828093, 0.16736074377383503, 0.1024108018193926, 0.11411665725920882, 0.07800692346479211, 0.18958128642823013, 0.0682254544060145, 0.10127670517457382, 0.14326648094824382, 0.13047625869512558, 0.1414794096989291, 0.12063509891075747, 0.17663500112082275, 0.0848982608211892, 0.13107297596122536, 0.05390624509059957, 0.10120306376899992, 0.12018567802650587, 0.16805426084569522, 0.11014340046261038, 0.07937209521021162, 0.12469330829169069, 0.10046221209423882, 0.12549155045832905, 0.06650843511202506, 0.1270463184586593, 0.10772566484021288, 0.11559728852340154, 0.07463762390294246, 0.08266463210540158, 0.09554455668798514, 0.11343770154884883, 0.1676429057759898, 0.08051486353256873, 0.14177303894289903, 0.2191017395151513, 0.11611596069165639, 0.2547456590192658, 0.1556050024394478, 0.21687766457242624, 0.12258968688547611, 0.13512764338936123, 0.1294491873787982, 0.1337655521929264, 0.08503924682736397, 0.15567542080368313, 0.13955254666507244, 0.23695487795131548, 0.08991652261465788, 0.1495900202010359, 0.2118460831365415, 0.09623869122671229, 0.10962208879313298, 0.13385448099247046, 0.13387080654501915], [0.06168742344847747, 0.0011227265183281685, 0.039216128177940845, 0.03139722327302609, 0.05401577760598489, 0.006513952718315912, 0.03252743869753821, 0.01865192173447992, 0.0893308383279613, 0.019763167016208172, 0.03504791469978435, 0.05918670299329928, 0.0024304134130943567, 0.046424551733902523, 0.0529477024184806, 0.038217799605003426, 0.030065001188112155, 0.029744227150721208, 0.06916682674948658, 0.04018296594066279, 0.0381205655368311, 0.031772470101714134, 0.0389023328732167, 0.040631765965372324, 0.03752309509686061, 0.0178040769616408, 0.0393789087289146, 0.024046514316328933, 0.037547166126647165, 0.04958021454513073, 0.022261090210771987, 0.02958951098844409, 0.01680332262601171, 0.03788111052875008, 0.01818680463890944, 0.018076384938987236, 0.06989510517035212, 0.06273739532168422, 0.013466351865125554, 0.017977040626906922, 0.06468172384692089, 0.03651470724227173, 0.006997049719627414, 0.03741444806967463, 0.030491053326321498, 0.03439805117834892, 0.03858041889699442, 0.04905868235177227, 0.022003492872629846, 0.0459682131851358, 0.060193825380078385, 0.12066297312932354, 0.024565949836479764, 0.017823542434988276, 0.01312858222185501, 0.02570663166365453, 0.04710393492132425, 0.08256422249334198, 0.033531042880245616, 0.034144540317356586, 0.025094321662826196, 0.05808835157326289, 0.09076272363641433, 0.04758389327409012, 0.04605593079967158, 0.02852794634444373, 0.05928099900484085, 0.0329568767254906, 0.02789900205763323, 0.12004309067768709, 0.014678361293460642, 0.033187364893300195, 0.0314811071647065, 0.01888130897922175, 0.02528306296361344, 0.10434035185192313, 0.008197803948340672, 0.014057814725674689, 0.06691740852381502, 0.02926858767334904, 0.03951284475624561, 0.0727608096120613, 0.02850357336657388, 0.033106018722589524, 0.047227964337382994, 0.020001651719212532, 0.05432495887258223, 0.03567920671775937, 0.01954668041850839, 0.11233859016959157, 0.02944851480424404, 0.009770923776419034, 0.022245241329073906, 0.06943225607808147, 0.012605148434106792, 0.034844221879861186, 0.04119004082999059, 0.039129994942673614, 0.04336862339239035, 0.04530743882060051, 0.04841869151485818, 0.03005710643317018, 0.02353122634147959, 0.02141860586458019, 0.0306204262056521, 0.024213690077885985, 0.03366976597213319, 0.02441031765192747, 0.022395363809274774, 0.01962465257383883, 0.03941326295690877, 0.02358481364457735, 0.04452730675360986, 0.05735830896134887, 0.013995605786996228, 0.007442798033090574, 0.0025834943059765336, 0.06531263927796058, 0.0748058802315167, 0.046439255587756634, 0.029616889876446555, 0.06688929003264223, 0.0637955367565155, 0.023106702603399754, 0.0775776957826955, 0.025563666031562855, 0.05548272621152656, 0.022695825900882483, 0.01883584713297231, 0.02909339332420911, 0.03767154498824051, 0.09624920851950135, 0.03399330843240023, 0.043572265322187116, 0.026751453456069742, 0.013881155589063252, 0.07180949673056602, 0.030246556803051914, 0.029109752803508724, 0.016889231944722787, 0.034673529610569985, 0.05155738416526999, 0.03725307208618947, 0.038102859165519476, 0.00810315679492695, 0.008106206809835774, 0.04846780727218304, 0.027547756708892326, 0.004151664009051663, 0.012750953735251511, 0.04831934720277786, 0.042717307806015015, 0.00830259859295828, 0.01817955109956009, 0.035202915846769295, 0.030539476977927343, 0.11050538532435894, 0.016699520338858877, 0.02028141849275146, 0.07706902522061553, 0.05606468194829566, 0.027645562442817857, 0.08833423323397126, 0.06635842459010226, 0.011179836433646935, 0.061697784678212235, 0.06782531552016735, 0.03545056077252541, 0.030114890475358282, 0.040583834251655, 0.0145733071091984, 0.05145890159266336, 0.07470357750675508, 0.04018112711076226, 0.03243399764012013, 0.05247289075383118, 0.04263516774933253, 0.014222669897467961, 0.00572737499273249, 0.06949058973363467, 0.04042481617735965, 0.02106320109617497, 0.04726433042170746, 0.015828033709632497, 0.03398581401311925, 0.03336288154657398, 0.053610810943480046, 0.03835100959986448, 0.025218362953247767, 0.03939428772511227, 0.06011208226638181, 0.026481876582173363, 0.017341151534180557, 0.0672331444386925, 0.04722070401268346, 0.05096058886764305, 0.018897091703755513, 0.03972486998619778, 0.021320715313777328, 0.04893812703500901, 0.03570679934429271, 0.07660765533468553, 0.03476286553112524, 0.04531670082360506, 0.058906590166900835, 0.022595838676871996, 0.018850011551486592, 0.034950680631612024, 0.001224018119890908, 0.0144897183802511, 0.031728022665317566, 0.031557164154946804, 0.042613892283822806, 0.0261981607348259, 0.03934260032006672, 0.007148214599250683, 0.059271859138139656, 0.010371524807331818, 0.054782936083418984, 0.01336801772205425, 0.02212769870779344, 0.030526279471814632, 0.017344790178218057, 0.04786555316033108, 0.02454877272248268, 0.02424662107867854, 0.06635812603469406, 0.06188723844076906, 0.11182124792997326, 0.013583081092552414, 0.017181912936004143, 0.029271858212138926, 0.027054714504629374, 0.07833287133170025, 0.038545555767736266, 0.03544347008158054, 0.010739286546595395, 0.017103077344862477, 0.11421435273119382, 0.05412627364109669, 0.024042529619431922, 0.03395516458632691, 0.05215228974286999, 0.016650423241247023, 0.014230243196444852, 0.03792026539200118, 0.05890387602682624, 0.07660742463277918, 0.0255251642582672, 0.035956255958548615, 0.04869865506355252, 0.009515104200025755, 0.03651956216033016, 0.014803225307592323, 0.04280549700238875, 0.025333269465980784, 0.05438972504011222, 0.0414008413042341, 0.03122048864939383, 0.04315263551792928, 0.01739210612140596, 0.028524831868708134, 0.04429730034566351, 0.06333147308656148, 0.019525403256661127, 0.04663746923740421, 0.04000758160171764, 0.016805821331217885, 0.013677724853291042, 0.04956591102693762, 0.022575562354177237, 0.05078973714262247, 0.03232889595840659, 0.02195827360264957, 0.02496066383485283, 0.01272965282467859, 0.018931690204356397, 0.04049754495333348, 0.004628743677000914, 0.006761834707244166, 0.018908090756407807, 0.04318423489374774, 0.043449111216302426, 0.022327252464102845, 0.05856496135571173, 0.061680610956890244, 0.017889494342463355, 0.0527805758507124, 0.010824477466355478, 0.0489460116119257, 0.01565776382839041, 0.033867626783571074, 0.052786533388176134, 0.030527429588671242, 0.025243953901476095, 0.021780382076810514, 0.01859222591987678, 0.023787302064842412, 0.05740647816232272, 0.044462703434484344, 0.04575218799124871, 0.05857704606439386, 0.011792654487570482, 0.014350620397765721, 0.006667909345456532, 0.030718901992908547, 0.014238962371434485, 0.053478683211973736, 0.037097643462142775, 0.034001461030649285, 0.026113174223740186, 0.033782826869615486, 0.023525972784097706, 0.016092168732679317, 0.0164394802746496, 0.058290012180805206, 0.02822309243492782, 0.07173398256834064, 0.027496199921837876, 0.02654641035145947, 0.03990729073328631, 0.028791665764791623, 0.07435162817793232, 0.06508960481733084, 0.05031238775700331, 0.0531600601305919, 0.06020016289715256, 0.023317197736884867, 0.04064520774409175, 0.04898329032585025, 0.01989228374856923, 0.004979522957000881, 0.05058259397212948, 0.03328584746590682, 0.02916006278246641, 0.02990800514817238, 0.014375960288037146, 0.03597328718751669, 0.033404356999588866, 0.047440617212227414, 0.009691076319930809, 0.08149119400020156, 0.013559489278122783, 0.06299878736691815, 0.03234348785398262, 0.020972603100485036, 0.03516977280378342, 0.010383419526208724, 0.019660575914063623, 0.02807955683342048, 0.01470715323063944, 0.07252944952675275, 0.128154759694423, 0.09814833304179565, 0.09277277506355729, 0.13482910155185632, 0.11037744076124259, 0.15092985544885906, 0.16107818803616933, 0.10007057525217533, 0.12776481918990612, 0.14416860682623728, 0.14366312537874493, 0.11124498849468571, 0.10715205847684826, 0.11989909197602953, 0.10264759697020054, 0.10417165447558675, 0.12061291081564766, 0.140818788004773, 0.1353676412254572, 0.115503976387637, 0.11040303510214601, 0.10974555502512626, 0.09816986974328756, 0.17141133999185904, 0.14685576834848948, 0.1464833611888545, 0.1599610208400658, 0.1298923793115786, 0.2544223235121795, 0.20127061275499208, 0.09800120629370213, 0.10072273561464888, 0.1859617227954524, 0.14305158890783787, 0.1301623276833977, 0.13887635937758855, 0.10993464237877301, 0.12736949111734117, 0.21320004548345292, 0.06083246932498046, 0.13917540333100728, 0.07169612031430006, 0.09138712513127498, 0.12769616501671927, 0.10314387748283999, 0.09651391860097647, 0.10175724367478065, 0.13759527169167995, 0.1488744235996689, 0.10933154009814773, 0.25054666719266344, 0.22318696816052708, 0.16054678655096463, 0.10708634914564234, 0.06752031402928488, 0.12030082541917052, 0.12234001314001423, 0.19359236476676805, 0.08840766429368939, 0.15194569022527762, 0.06034137960523367, 0.16507645563355514, 0.21564598780657562, 0.093799167844866, 0.1122474018484354, 0.11789195824946676, 0.1473635703857456, 0.08932444652808563, 0.12854949065617152, 0.27902011360440937, 0.13243634280349526, 0.14942443051508494, 0.17379763908684254, 0.0761182415964348, 0.15008089957492693, 0.22725369994129452, 0.06872900881405387, 0.07186770146446568, 0.14050056865172728, 0.087086814455688, 0.10774123721889087, 0.09960727832679238, 0.15066002921334334, 0.18258246912487916, 0.09409010330481188, 0.09937049674668483, 0.09218443091958761, 0.17815607307212694, 0.13792710245719977, 0.19017648377588817, 0.08102778172386543, 0.1315625389771802, 0.12820769899657794, 0.13957064997936997, 0.11712017894855567, 0.10520665108093194, 0.09264680503734521, 0.17780859528907708, 0.16188952592866762, 0.12596708137009824, 0.11301323039723293, 0.1331452897616795, 0.08866685110011271, 0.08922394870647363, 0.0934932299756578, 0.12014668940433434, 0.1687719744763204, 0.12910382662500652, 0.0993319491722754, 0.13651102701468126, 0.08397777378559113, 0.11950649161423955, 0.15761741516845568, 0.09828650312764303, 0.07862996110426528, 0.09057075250893831, 0.09512007875101906, 0.14576747960277966, 0.24409317491309984, 0.13999974195446285, 0.10868869602148022, 0.09583087132445403, 0.24532023764082364, 0.11730993805187089, 0.20569368398615293, 0.10397472325712442, 0.11076166800090245, 0.12739228989396775, 0.08806024079344102, 0.09146177076867648, 0.19048907128827913, 0.1434838157147169, 0.17667686673147337, 0.13835615372019155, 0.14885634742677212, 0.08016027470252343, 0.15491734791014874, 0.07833712574626718, 0.07800551211195332, 0.1603249598826681, 0.09962764116270201, 0.17551115714013577, 0.17670463238443646, 0.09920144653213875, 0.0668307663872838, 0.14201343032930577, 0.21271462153111184, 0.1303818201912301, 0.07457939881299223, 0.12249090575746127, 0.08380700009209768, 0.07099393156490155, 0.10386893964771714, 0.11376613285392523, 0.12288337041224752, 0.11533141136169434, 0.14020328888935701, 0.09428012025143419, 0.15565974664475235, 0.14386606163212232, 0.12079747234072004, 0.13614345102437905, 0.14665136645947183, 0.15527667291462421, 0.09597356723887579, 0.1938246273036514, 0.17401311466736452, 0.15876527928880282, 0.12751749317560876, 0.09779852109828166, 0.11053816535110984, 0.09856185942356076, 0.19596911008868897, 0.09423695863889796, 0.15338394019220555, 0.13880888585533413], [0.002225044823717326, 0.02086417659718011, 0.0146719559228846, 0.016714843355917504, 0.036827888472804, 0.045206231929894, 0.038829906045326164, 0.026884032413363457, 0.04901779043887343, 0.058801437595060894, 0.06122921553573438, 0.05279186667342271, 0.0166129087364035, 0.01877083838917315, 0.026273120194673538, 0.060892797873488495, 0.029257385060191154, 0.043661329828734906, 0.04428969057542937, 0.04026003394808088, 0.0040602627975334015, 0.043969052245042155, 0.04131510501195278, 0.029730832869453088, 0.008051948605238326, 0.006579622609673866, 0.07014427001455001, 0.03354583155097706, 0.014857828716880508, 0.02892524895391294, 0.047235133059855015, 0.006442843520614717, 0.01824316375755838, 0.03856857167556882, 0.009603871847502887, 0.015564687483544861, 0.020541158305214982, 0.015511707469288791, 0.04670909878664783, 0.04511358815112284, 0.04415441783411162, 0.016445310586797338, 0.02228367355253015, 0.08913869078138045, 0.011590146559423633, 0.0669980456254312, 0.012550342312481786, 0.03206687287560531, 0.012617401080206037, 0.01456872869416007, 0.031539166013577154, 0.013888206416075783, 0.0750303396156856, 0.029999444527285438, 0.01135684925663684, 0.07074604236653873, 0.01966996514238417, 0.060182805971375535, 0.06286314143134014, 0.029028501627700667, 0.01917867355846933, 0.048720025523964844, 0.038774442592901845, 0.09479526403759207, 0.019220725766250064, 0.011238630644844046, 0.05432423623278737, 0.021323902732027427, 0.015407209683741842, 0.03023091657087207, 0.02684541528911463, 0.04484715459070035, 0.04141466984791415, 0.006907279536660228, 0.03036574147907751, 0.024781289709998027, 0.07147487040076937, 0.017968436802870462, 0.017043734368469034, 0.006089220754802227, 0.01251773616032941, 0.06224287221474307, 0.01151291061458843, 0.0037274791143967635, 0.060591005853244236, 0.05901307945272752, 0.02066840567359967, 0.02907325779753072, 0.019425607718793408, 0.055245272881750546, 0.03770682880921023, 0.03642812956656728, 0.02561160283429282, 0.042733548541686366, 0.04946772700973919, 0.03159004256927541, 0.030732774641364813, 0.04793828872165509, 0.04065686158303704, 0.03383709949308208, 0.03733638261577912, 0.06355893838086299, 0.012087879137002995, 0.059314661127115996, 0.040745318800743134, 0.0916289414412209, 0.018758840193705897, 0.030503718182444572, 0.048815044175301275, 0.019516210803495984, 0.06690535774188382, 0.02031655642869217, 0.036845275932656865, 0.09017066790589265, 0.06191703291343791, 0.02871954088498439, 0.018955823998632174, 0.027603969942512255, 0.0461924215113478, 0.034508459003908296, 0.058650931742574484, 0.035099368010248454, 0.023673986716728126, 0.015416519184197699, 0.05263213613735778, 0.04041332518681884, 0.02430830500088632, 0.05992589904261487, 0.0612210731155106, 0.03251434636435338, 0.05008957382025463, 0.047804220379995446, 0.04606660415551492, 0.01813036748873336, 0.027573016871299063, 0.033321406093559096, 0.04259695604975734, 0.0566992784318115, 0.028398179914802313, 0.0342729530696358, 0.004420200179863189, 0.012268802866206636, 0.028776782099157572, 0.05274211648585541, 0.010523871186056306, 0.015521329095853227, 0.02057509862684778, 0.043852188158780336, 0.0033467128274164027, 0.04112120005967362, 0.014884137215891054, 0.04353901032092316, 0.01139941206201911, 0.020979308722806827, 0.03248855864096965, 0.04111530359036156, 0.05044785048812628, 0.014290315597983343, 0.025859066251931444, 0.06284740620425769, 0.03460362014759864, 0.05377102323940822, 0.028670099430850575, 0.06131864645119224, 0.007221386119324181, 0.026517740550584028, 0.01387155007770551, 0.025938824650698473, 0.02373324826891933, 0.032108589208551815, 0.026153964356386235, 0.04151403112336993, 0.01810439825723214, 0.042526734460677416, 0.049630114010402133, 0.04473252288464989, 0.008868601123270179, 0.021096091384866407, 0.023609569994732738, 0.04285003604101283, 0.04717990370201213, 0.05486351211688348, 0.045741762300687175, 0.03141045131321464, 0.055031273114894114, 0.07100801116653851, 0.038879486599138806, 0.017863533592649868, 0.05735454987734556, 0.019760500373584882, 0.0389404835046402, 0.00808003232149141, 0.043089182315660376, 0.012389361575644995, 0.011389067795659815, 0.0201028535209064, 0.03783961132700954, 0.0455594127997756, 0.029380135437739745, 0.014646174984851053, 0.006945261382497847, 0.053349731024354696, 0.031564407516270876, 0.024665925186127424, 0.06602657346853189, 0.05951791629195213, 0.029671837642256702, 0.029152931379420415, 0.031248172878154686, 0.06625409304563488, 0.05277094065344759, 0.05860589737338679, 0.06827785766550473, 0.026148001729909862, 0.06560404292706933, 0.00980581998425935, 0.022164514321567755, 0.006522942883228617, 0.03277551449303116, 0.04951443736042295, 0.04151018722248929, 0.0906807566061616, 0.024625406467488835, 0.026575796006779586, 0.01801247033290565, 0.0052343268512881225, 0.028319352805348377, 0.026353645338011638, 0.01647030103153416, 0.03175282651292426, 0.012969771948909121, 0.0725334393126624, 0.017270344708647047, 0.0759066811629704, 0.06329550394522292, 0.014884062577039003, 0.014296975419191378, 0.07203683988856417, 0.05009913777134248, 0.003211264091078192, 0.013600507568168854, 0.027242497374702777, 0.03840950610382216, 0.02998865582048893, 0.030905098787375858, 0.015112840836601598, 0.012189103839253741, 0.03380449249276093, 0.04213690930711372, 0.011445085102293109, 0.037057328304009776, 0.0404550109856895, 0.06990630099815981, 0.03346061094530991, 0.008999696633379375, 0.028684006006057774, 0.04184399591758847, 0.02925734774076513, 0.07207058343504157, 0.05819195708526032, 0.005755973547430975, 0.017188869616282836, 0.04369872050093753, 0.01375588190941406, 0.015116196192268814, 0.03817906204078879, 0.04262641464759197, 0.024862259293773344, 0.03728853911161423, 0.03391021164134145, 0.027597137094874467, 0.020093550805800726, 0.016360168012657335, 0.036697976158133576, 0.023882044213158742, 0.017541553459263275, 0.02955123482804213, 0.026734150813094208, 0.012730702857619949, 0.027041500035141195, 0.03815869581220405, 0.034481161540108066, 0.025661761839208857, 0.019124404327677827, 0.015604374996785606, 0.011611322789186878, 0.005987233548824276, 0.028763767797499895, 0.03502984191956265, 0.014194715951037194, 0.044230003242513964, 0.038706402493906875, 0.03875439188310078, 0.04018820423100676, 0.015403191060093897, 0.024644062787826573, 0.02270544074209673, 0.011912063928321004, 0.008838991551393909, 0.05448674876242876, 0.11460772662290505, 0.03209311182477644, 0.025369209769581045, 0.04015001967283232, 0.05447555971997125, 0.03716241641502295, 0.03905589891863721, 0.041234579868614674, 0.01618136894623084, 0.04315296121473823, 0.015355286487777318, 0.10984084848314524, 0.019716331136545966, 0.035309774934181144, 0.015026512522516506, 0.0011386090087138914, 0.01162596048587667, 0.026433459715917706, 0.05324166753728475, 0.07536077259906701, 0.06612853692578417, 0.061890413984656334, 0.008375396918771523, 0.055161741828279834, 0.02398504752532712, 0.053451721623007736, 0.04034605522507003, 0.019784942901294147, 0.047289253012942414, 0.03189258097804018, 0.024531962017395666, 0.07033712323755026, 0.027173463221905485, 0.0659486505069903, 0.040291494224220514, 0.05133004779262202, 0.04599760392946856, 0.051188722518937926, 0.01732947564284716, 0.01874049599947674, 0.02970757268901382, 0.019929976368855153, 0.04716682833220277, 0.04110118666929858, 0.05374996490510447, 0.030764950771949122, 0.023938586536262716, 0.04932634066790342, 0.05383053415321878, 0.047285863730524264, 0.041588737828923125, 0.007490222541881459, 0.08630827016064099, 0.08497999714953558, 0.09921021998992988, 0.1306777021714619, 0.05805901171905654, 0.15502547925072058, 0.12796086152749403, 0.1167434970183032, 0.13470965224717343, 0.11161173667226519, 0.14802852113332066, 0.10905285219528846, 0.11097862957311527, 0.13357883292649472, 0.14954656681844167, 0.08180566783994436, 0.0879632102857743, 0.06928783668471233, 0.08670397821281638, 0.09561274267200913, 0.108063473499247, 0.13419779257050582, 0.12187884002923965, 0.08923574843044792, 0.1332301473511117, 0.08968168843005385, 0.1895610796553748, 0.1061242814841015, 0.1258281445396798, 0.13233103416860104, 0.10452945956162044, 0.18504141217895917, 0.101267687444176, 0.20072170506630624, 0.18193028840635503, 0.11278310524565832, 0.12982462080461638, 0.15220042584197863, 0.17816771673304693, 0.11653129197657108, 0.13048088630395277, 0.06062042034630265, 0.12153376426015582, 0.11123357553567205, 0.08349220734089613, 0.2361422644129821, 0.11443122609385423, 0.10438035827662263, 0.08224799124790089, 0.12674001418054104, 0.08789646279598985, 0.07419658971152135, 0.15153225883841515, 0.09180130290665797, 0.12644551641174726, 0.11904869760785784, 0.06939028190182787, 0.17674147683594907, 0.17224861149277004, 0.06931338352816445, 0.06751901802739926, 0.09652511442878417, 0.22128058331353323, 0.2247333223266261, 0.09576000512710639, 0.09577331119882208, 0.1066766632720828, 0.09325059263833932, 0.0618437443460737, 0.15507845926497663, 0.13329718661095413, 0.07336604927799531, 0.16885120022509778, 0.14995664624231203, 0.09409106003918818, 0.1892461986946208, 0.09014702096049275, 0.09529054031840392, 0.11628974708063261, 0.057325182881738455, 0.07322008961013385, 0.15892894193530083, 0.10219080719564642, 0.17949537906263555, 0.11494343860873155, 0.1059599674439856, 0.13346068640904768, 0.18523183624659265, 0.1475327563072954, 0.12674540174858911, 0.14344418926962785, 0.08889038089130606, 0.16061636353177683, 0.07568332779088191, 0.0969404796404498, 0.1433974653482437, 0.16780568632696355, 0.11791736260056496, 0.12695352200950893, 0.08577870071998664, 0.12665793858468533, 0.12954648930047238, 0.12220422471208231, 0.16645807506782667, 0.1617731707436698, 0.18851593216615065, 0.24835003220609256, 0.08898516544806105, 0.11620016688747065, 0.17261886091104575, 0.20509864948689938, 0.1439842488616705, 0.19120517000555992, 0.1944739581750972, 0.08452016753809792, 0.08770194716219391, 0.14446286032242434, 0.15491513588598796, 0.11283696735543863, 0.16284084559551307, 0.17426729388535023, 0.14826887180762632, 0.1380042518888201, 0.13390896735446794, 0.15021514094301633, 0.11933262380106108, 0.16536437161266804, 0.114780956613166, 0.16463008815688746, 0.10323675535619259, 0.1662373747676611, 0.17787642164954118, 0.13687822302537306, 0.11981903841452939, 0.13974157295056752, 0.17182596560035432, 0.19576708307223661, 0.17371059661465033, 0.19621403408902033, 0.10759575252554246, 0.06428678253931658, 0.09368334191718272, 0.1620380708149501, 0.2254979091563395, 0.09721608020897422, 0.10625441771532808, 0.10176864984844412, 0.12957462136234554, 0.04766500874289444, 0.07957750811640706, 0.13168908575815813, 0.11441141287130968, 0.061277608653264384, 0.1291245219430753, 0.08966281837118523, 0.16304112199161733, 0.17114691489509173, 0.09476568669612918, 0.09234253636428288, 0.10688263936234371, 0.14617567269929818, 0.13613587857357093, 0.07246986058141504, 0.09269403785999332, 0.08409427824829306, 0.12646474609417574, 0.11404209983135973, 0.13040742810283387, 0.15333602204918861, 0.1469978400106941, 0.10767904269908156, 0.13344052034829343, 0.2736931251628058, 0.09427598118782043, 0.15367144905030727, 0.10771562930728708], [0.006555381946132651, 0.04069683068831052, 0.0379574558963733, 0.05728603819651263, 0.04394440785316484, 0.11727274076214858, 0.043507875741592476, 0.01738741065907691, 0.027105243311130574, 0.038564259585525305, 0.009869220600064312, 0.028453180267076408, 0.04933594872376748, 0.054977400827088525, 0.07838250616831438, 0.025009718524026017, 0.053766161535999606, 0.010923958333608295, 0.04295398421319468, 0.03288857539051345, 0.02295119594782591, 0.03788403162200536, 0.0272394236110683, 0.050497909409127066, 0.03516783219363008, 0.017137784411066344, 0.023726754688790867, 0.04185880494437047, 0.024986456647249203, 0.06063376034476927, 0.03355162624003632, 0.023709689533071857, 0.009560459177009761, 0.034393532135124714, 0.04522888482149158, 0.04441390658861824, 0.03011210848178182, 0.06804193782487086, 0.006862193005092974, 0.023056190760274018, 0.023868704214692116, 0.016646460596738116, 0.01921625591681472, 0.024100914165111523, 0.018208762032112906, 0.009113386872091463, 0.054243728052824736, 0.03717397865174072, 0.01616746067468609, 0.016825168060937097, 0.012945248845166393, 0.051348201997045956, 0.009939359916773225, 0.022966369687180434, 0.08432162819164139, 0.044460403200771124, 0.032151764391788414, 0.057042776606976986, 0.03250818865905915, 0.02910528125773583, 0.008716383666199232, 0.04087313783488103, 0.06897862149136406, 0.04895081224718264, 0.05639391392469406, 0.05124653709520187, 0.03975901386833616, 0.05196483087326799, 0.010613372499522353, 0.0038946820173545605, 0.030174248718789647, 0.02612782040211771, 0.009608520660549402, 0.03217882776100721, 0.03840362999056067, 0.02721453325024673, 0.022362222462626438, 0.03162676827715976, 0.038789702845471244, 0.012219396186992526, 0.06585845284696136, 0.07818404146070991, 0.04310733652008431, 0.05536731079752956, 0.03808214009872504, 0.02394348895177245, 0.028483319096267223, 0.03506647263254438, 0.01189695973880589, 0.03183074947446585, 0.040385559533855746, 0.01715676473187549, 0.016172378357233744, 0.016124726539211612, 0.03940579567902854, 0.07057256131832089, 0.016246140202773467, 0.005122565772450928, 0.03628964056926114, 0.03890136596081512, 0.03490504915160792, 0.014400619946952378, 0.0715393108714904, 0.007737382315099239, 0.05111034154625876, 0.01449443250229316, 0.004109863283312214, 0.0623513428228242, 0.025521836044000726, 0.043853684328496456, 0.014640890893393328, 0.04085728047149522, 0.01959775374936206, 0.02346127277373203, 0.012008131764430021, 0.03200107194217188, 0.03173658238457782, 0.02881204556407673, 0.021839384089357088, 0.03426065801509789, 0.029959170081253563, 0.007527136543233479, 0.05674559862485953, 0.06985760253987142, 0.0154786695992308, 0.008906642340921929, 0.021322396384286027, 0.03486025905502694, 0.018617014500445554, 0.039925743493118455, 0.008285590264547085, 0.02852613465594394, 0.028927498297499757, 0.026668310863897204, 0.05297692692173379, 0.03512608193393264, 0.026994781202769706, 0.013914129846463246, 0.06796287492449794, 0.03263034192579133, 0.02810533607511648, 0.06701418797352485, 0.013145231774875095, 0.032882750167378356, 0.024726755850549256, 0.00889188250792878, 0.015470761273588454, 0.01912811421789229, 0.05079889397269913, 0.034726475698075125, 0.06497786367045981, 0.05045219650492072, 0.0269699332503868, 0.05876711729381766, 0.03260468651673623, 0.006913752760738134, 0.02278353673006807, 0.022071739924805503, 0.024452586990914175, 0.033583103479551416, 0.05729234178683587, 0.05628434408988271, 0.05247854295053652, 0.0019278036530262657, 0.04449427227622696, 0.015337274775707295, 0.06461536990744726, 0.039720703781183274, 0.04921254695260099, 0.048838616481849124, 0.036185044396136484, 0.04419540813458817, 0.010248078083220338, 0.04135426326787897, 0.04850675857492855, 0.030977067604128803, 0.013298317756769913, 0.02015652394454394, 0.039218092536819835, 0.037513626140675375, 0.018177886992426853, 0.017927502481532947, 0.016220296500250697, 0.00894173956476152, 0.006828796783728259, 0.02871418385101216, 0.03809328503640635, 0.026815973654655472, 0.03900362118812544, 0.11688267812132835, 0.0067798209742509895, 0.047880022919603756, 0.03021844509722931, 0.02327285547341619, 0.01739381263697786, 0.02253914707606392, 0.03444469028285571, 0.03805586722280298, 0.06735637996877943, 0.07454439997673035, 0.06372506410947867, 0.04031948718641486, 0.03294522627922041, 0.01357900140075279, 0.05647409640784774, 0.039443895420325656, 0.10685483978262969, 0.012912433195327009, 0.008792263389165913, 0.04500341781281999, 0.03329869552648493, 0.07628030968563897, 0.013674682471901178, 0.055856205456491025, 0.035491483219500096, 0.03909384598955512, 0.03341104396219764, 0.009019365667232444, 0.06425597026411976, 0.007029596924050046, 0.01739517649236534, 0.053681714460253716, 0.010936984509628798, 0.0037598744966089725, 0.07438973470457963, 0.022335632371583154, 0.0302741256808596, 0.006423406885005534, 0.041059701038258414, 0.03126541445297854, 0.07880027339394603, 0.0690589328961713, 0.06521865539252758, 0.03684645319091422, 0.010296402499079704, 0.1219840943813324, 0.05507895716332963, 0.03154797000544412, 0.015954923150794845, 0.0159257291816175, 0.08712625769632203, 0.04703323835773127, 0.03278403689286538, 0.06743944622576237, 0.06629588401743344, 0.03325839054637721, 0.06154455111495086, 0.04310604730354888, 0.025118918557252203, 0.015374561971319574, 0.02765668023909841, 0.03811649093404412, 0.014124535922227162, 0.04463385710758822, 0.028207820307995592, 0.007982839813588985, 0.016351285989263227, 0.09302864383373942, 0.024501068317996602, 0.09118404638554369, 0.06066024356654712, 0.033580989842968326, 0.019259997676791887, 0.05829273310622998, 0.03929717579324331, 0.02194935256349189, 0.01537678756618074, 0.03086397277989558, 0.042177780863962004, 0.027950083870174627, 0.01080464558409793, 0.020559611065047126, 0.05993857407676322, 0.036450507651482306, 0.037914267142436335, 0.02626454520837537, 0.04502332603026714, 0.01470427624216037, 0.02688573214358517, 0.046758353643651517, 0.043434705917856524, 0.026871947704681327, 0.015967650771407143, 0.00047839692706475034, 0.01123380202001759, 0.04737585104469742, 0.053951662832072804, 0.04883418564817735, 0.043843353632837534, 0.018468157488054464, 0.016209148169894303, 0.01650058913842908, 0.029338106978684664, 0.03213789174333215, 0.00818196778917419, 0.0821445214429072, 0.030468675241406475, 0.048965397357408486, 0.015568751908306564, 0.057249919777469974, 0.017466778900208216, 0.021120004655261124, 0.021123644995636175, 0.017238882736169865, 0.019911815379081026, 0.0927903355498399, 0.027007517305069735, 0.015230670138927442, 0.06415528245270252, 0.03448889683932066, 0.036995781785143275, 0.033569593847330124, 0.023004951188340783, 0.045205902840409956, 0.026294436372284378, 0.07866571311439786, 0.023533584250669395, 0.09440638204770428, 0.048694831518722434, 0.026715938933193684, 0.02693790470116905, 0.03535647171416453, 0.013356427495766963, 0.06993867390389953, 0.026611680331240808, 0.02649904351814517, 0.040992000206772766, 0.017525305938241736, 0.044145240647984405, 0.06923726546977248, 0.003263758316669347, 0.07032832263835839, 0.03964586476130145, 0.038868745389793596, 0.030065645796379874, 0.015027598178546344, 0.02637700560236616, 0.006045864911616913, 0.03610522832189288, 0.039003980811685324, 0.0327178627651717, 0.02327523034598146, 0.030978984465556483, 0.026584898554054753, 0.015954678878188133, 0.04961950511538556, 0.013322392179231559, 0.03139312152883836, 0.08412414735981397, 0.02401454174625022, 0.033923690739486895, 0.03564416716939636, 0.09852471641663994, 0.062200864111738544, 0.10785700886377267, 0.09284810602132763, 0.0793805904686451, 0.22722844486790045, 0.09519034105220012, 0.0880791787058115, 0.13851277317319596, 0.11226484019841466, 0.20054344034620694, 0.07762179377355746, 0.17247487578008855, 0.25486182421445847, 0.1678940722984927, 0.09817024293754782, 0.17408734639840467, 0.09384958299675158, 0.15105728432536125, 0.06754960638603993, 0.14668339331235203, 0.22465385230524199, 0.1482055644903864, 0.19754682614334992, 0.12905851405646118, 0.1081974705947297, 0.13980038836598396, 0.1423770843872002, 0.12328484601208142, 0.22798792911427362, 0.3025094488901751, 0.04757306385519249, 0.09965005317436797, 0.15373272076249123, 0.05304624605923891, 0.17660734403346265, 0.09240656971399273, 0.17286691974316323, 0.09021683542856149, 0.14543733160410607, 0.13014111667871475, 0.08832761751753943, 0.14052430380667957, 0.10362658050975629, 0.15474134949701174, 0.18744143125201973, 0.126217406509178, 0.15212675050965377, 0.1719009301492146, 0.13871208604957375, 0.09075760069702353, 0.12910431517021997, 0.09410930584583964, 0.06739170450185027, 0.13836490682193212, 0.1418872092451368, 0.12432816145675522, 0.11062064806797675, 0.1652424931526184, 0.1093641369204436, 0.09136754261063677, 0.13313489460519382, 0.1673304539706026, 0.0779424694233707, 0.16547860976840767, 0.11599660638187613, 0.12323874634291444, 0.15548847083534512, 0.09759646015507834, 0.0959114134311676, 0.09457913706345217, 0.09100452637565987, 0.09255933508809124, 0.11199491896799632, 0.09169547179979937, 0.12299583080623831, 0.07670856706265892, 0.13006541931203433, 0.12560216523706913, 0.0931367887450116, 0.18635156830506666, 0.3642226702400616, 0.09123116385723863, 0.18848596805972712, 0.10535886005631515, 0.09763959462621383, 0.14559940647866043, 0.11188251964215722, 0.12707618757018022, 0.11287803229476724, 0.12972509328808102, 0.17935777216085366, 0.09547007389898811, 0.10951475133853299, 0.10387594891445977, 0.18976928134049686, 0.09234501980245113, 0.09911947271653584, 0.08864571473428182, 0.1325862854719162, 0.13485259243420192, 0.07669756122465644, 0.16139750661594526, 0.21666977501341275, 0.14359619468450546, 0.10799455469740288, 0.06657523688461099, 0.10396159360451357, 0.10899619452123131, 0.14677852392196655, 0.08046499120869807, 0.10579827933439187, 0.09537014604679175, 0.11586384422012738, 0.10136585110532385, 0.11379483488521405, 0.13327962612467154, 0.08154327834823302, 0.11453520480011191, 0.12351571076682635, 0.07068664341100625, 0.12720050875629696, 0.19043366211865628, 0.2040918663676296, 0.16015999444893428, 0.05985149767782007, 0.1013396257268531, 0.15365937112697534, 0.09603701026311942, 0.22625991755298205, 0.08211345810975347, 0.13171275305960858, 0.06444165815732308, 0.14405712352267333, 0.12501372609819683, 0.1590697650930711, 0.05584609867738826, 0.09717675231929336, 0.14768558953489574, 0.21311266374375137, 0.14972849562764168, 0.21056760102510452, 0.09187512751668692, 0.1553936523518392, 0.08328771724232606, 0.045062358757214885, 0.09453160568539586, 0.12954245880246162, 0.15484008991292544, 0.08904674928635359, 0.13045835894133362, 0.12317135424486228, 0.11096059411231961, 0.33036143864904133, 0.07736475113779306, 0.13978182364787373, 0.13749065516250475, 0.09004460967012815, 0.12692464355911526, 0.07731104509106704, 0.12745061676417077, 0.06511031370609999, 0.11637843160756997, 0.1439953904066767, 0.10397331868963582, 0.08979192322918347, 0.17658933571406774, 0.15572764085871832, 0.09599595210914101, 0.14668925585491316, 0.10077392429645572, 0.13614240608045033, 0.16884550053094113, 0.12751035498721258, 0.18262437544763088, 0.1916280873119831], [0.04732380401609199, 0.1161386916147811, 0.025861729501879642, 0.029512873850762844, 0.05492765742487141, 0.02594560321553477, 0.06055524705776146, 0.049826471866773706, 0.098860849094178, 0.06554309012634413, 0.03179831550057445, 0.028615976085088084, 0.00785440331258412, 0.030568494527999843, 0.06474164527441774, 0.07362795022449323, 0.06125839254153626, 0.036412180600953956, 0.04779403556936553, 0.030642210572425808, 0.04812186976362552, 0.045615449614290676, 0.03246760208691869, 0.029768288002482483, 0.0642176941037178, 0.00792563846334815, 0.021019759587943554, 0.05655074372355427, 0.1034492589533329, 0.042688782193831036, 0.04199851869738527, 0.03018462351922478, 0.02753841837069818, 0.02674721770121583, 0.036999052323933156, 0.06644256971776485, 0.03650256146543792, 0.05719476166580405, 0.05556344473734498, 0.04498665799785938, 0.06372825322406632, 0.010626853294005352, 0.034195606862860065, 0.03086487523147038, 0.023507102725229094, 0.008121903869323432, 0.016646506397851875, 0.04875943483784795, 0.032092684347714694, 0.06392691470682621, 0.02372583866651569, 0.04977051308378577, 0.01617196445087237, 0.04977568691330297, 0.0363532701906349, 0.02703175287959831, 0.03660481669274824, 0.022592491802892516, 0.03372209459277136, 0.02172511031052896, 0.018511022241520028, 0.02629756781139544, 0.01691905695146748, 0.04292302605296884, 0.010361895547248423, 0.0611633365707738, 0.0099259181380538, 0.007965340395458043, 0.0676285946475608, 0.05310676120487707, 0.03695379403818931, 0.025015677757827297, 0.011513225285203328, 0.05011060501315764, 0.052986616401800087, 0.03453974625361817, 0.04113265033811331, 0.047787643769489865, 0.04906249911125217, 0.02176285721361637, 0.025798863232401863, 0.006082457881088236, 0.04370060682828937, 0.02694183511526457, 0.0432870193783726, 0.025033928653491393, 0.03369741966681821, 0.041509094781109264, 0.04143442200230701, 0.020084022477801357, 0.04842017072119883, 0.019863987141954045, 0.01647272170521319, 0.04703345209626215, 0.05542131879233888, 0.05773674151194947, 0.006432830040077013, 0.03380786141912852, 0.03810789389535785, 0.038088864380759854, 0.07113981659391097, 0.02682819407034133, 0.043181480041572025, 0.03137877729854413, 0.033575995825231075, 0.02404195286466607, 0.033549017272889614, 0.062335112265178134, 0.017521336508382643, 0.03780641739389726, 0.047708791214972734, 0.019831571827775667, 0.017116888925167065, 0.05517465095700962, 0.030666403738515716, 0.011848213783066188, 0.10409210303000041, 0.06095600341047559, 0.03614474959405405, 0.03201571133519922, 0.01692189831685807, 0.028641275263258388, 0.017550389681543623, 0.04018640272053225, 0.0617634668680174, 0.03993527691013046, 0.07171670706676585, 0.06022451551897185, 0.06816543798361506, 0.06459601130336523, 0.04503992638949837, 0.07104328820215804, 0.031629903108945916, 0.06049862331045525, 0.03502459005851831, 0.018366892921871374, 0.03004964254796505, 0.0495323846116662, 0.06428840423801116, 0.033725205675831864, 0.051282987996403656, 0.02360537664831749, 0.012376885012989598, 0.040075011019195826, 0.0656383903697133, 0.0707748733194811, 0.0163441715495927, 0.07302821347756044, 0.028177194629928896, 0.034931267744728496, 0.07047765462526254, 0.017925807840323875, 0.009271857877528029, 0.04494903323107532, 0.019009557186758945, 0.029493756126612425, 0.04380535567179322, 0.024119575574461902, 0.04750560390363846, 0.013505099607365472, 0.06730160862207413, 0.006710807177504259, 0.024822322418913245, 0.05134132843730705, 0.02335305491994534, 0.027453520069164888, 0.04807823317657624, 0.024872089569856013, 0.03225857258907386, 0.08913152545158352, 0.07499717282397406, 0.015159189867387925, 0.04988288187554904, 0.009033817614960884, 0.027894947810896804, 0.0669493946645941, 0.014797827561518975, 0.00814681628253311, 0.03284601428146873, 0.015325887261756828, 0.036816953880978484, 0.02111272736718612, 0.039712513863508186, 0.009324194979853928, 0.07375090755522251, 0.006455917618170912, 0.08976461898003306, 0.053337530964719396, 0.03001446050724813, 0.015312535388927375, 0.04518631353442158, 0.015392931610611933, 0.024401535712448612, 0.019326757040939162, 0.06046764140150376, 0.07167197803833655, 0.043367025442421436, 0.04505035886541009, 0.06521672835307461, 0.0010227618768112734, 0.03774027040760432, 0.0149837919577424, 0.02149582145336483, 0.05733643977769783, 0.06489150651863643, 0.05355995135115726, 0.0602326240124447, 0.05242809047922492, 0.05696959660521575, 0.03589615811194692, 0.038280804974160025, 0.04363310616463423, 0.0018737487968922193, 0.03351322455065591, 0.019466659087421637, 0.016888102183916738, 0.06512318551540375, 0.019261405636955584, 0.06075967608817986, 0.030001324069287096, 0.04043407478768911, 0.02499680939529623, 0.023498677016635026, 0.014608177023806741, 0.030363539632941996, 0.03892224448333893, 0.03085066670817988, 0.006328266521450132, 0.008566329039500227, 0.02760774259721594, 0.05653069301375321, 0.028132402837010365, 0.03548453502090914, 0.04948591174823897, 0.0642420467255371, 0.03057206022952284, 0.03562610795987504, 0.047819612946893485, 0.00972619220348341, 0.013854511215218475, 0.010330005249540721, 0.07292139170957462, 0.006595728062425873, 0.020804044823827486, 0.03411690019337194, 0.033769147603639534, 0.03393296631319182, 0.07758879661560059, 0.06820496943380151, 0.016100216158000485, 0.013452762505039573, 0.05909518218998398, 0.06886910593935422, 0.09818466180669409, 0.05575226406965937, 0.028063880978152156, 0.005019881371741316, 0.014189207943023315, 0.02673675129855318, 0.0078943249204063, 0.050136511480169635, 0.038949131433452876, 0.02866359567269683, 0.03877099224233201, 0.0951141890670572, 0.008082354607592736, 0.0403114804731948, 0.02321203668335719, 0.019243405799248388, 0.016872132862252847, 0.0509923409138407, 0.028550378712160245, 0.03976183318133865, 0.047700560585196526, 0.01699172974830227, 0.02013868695524122, 0.057395764094378264, 0.008850652175689382, 0.038123327174357007, 0.017051505290770104, 0.010245110340682524, 0.08496671143387045, 0.13229260194514478, 0.053957369311579635, 0.031006546558013985, 0.031164536651756083, 0.02144557423889637, 0.04143953815634761, 0.039434650380696566, 0.03157279760177646, 0.028438259282016327, 0.01798460629236485, 0.02317848821569766, 0.05462209953527365, 0.02107804574604545, 0.026740169418709617, 0.06869090228740658, 0.028654744183378558, 0.07130278034933976, 0.05888656659850052, 0.040763839414077144, 0.056727461383811066, 0.04248958466840642, 0.02388597123457917, 0.044884151712592156, 0.018491867197943584, 0.026970085920765996, 0.02545511399927948, 0.027405769863565053, 0.06348115791167531, 0.03759710969669478, 0.03766985882871917, 0.024698181044576422, 0.017827399906569293, 0.033493367223335166, 0.07417712254183632, 0.02405498582603676, 0.0397251108661294, 0.013691222611149507, 0.03332837125552552, 0.03999044519982167, 0.04079854987295611, 0.03240567898111684, 0.06972313725522586, 0.04231661591412766, 0.03454780046428953, 0.0926908351747053, 0.008735437777691653, 0.017207553078021322, 0.025131926073559692, 0.03943148501483457, 0.00507142416401101, 0.04094301676377654, 0.009662363262447928, 0.0711374349359955, 0.06743933766015939, 0.014403809061540025, 0.02097865393651383, 0.01884872403128871, 0.026014807002086724, 0.05938789541167872, 0.021879867184907198, 0.03677694406360388, 0.07807581512523548, 0.07309853684689317, 0.033786026162228415, 0.03795787998075996, 0.025614123591887097, 0.04249791707843542, 0.01642589091456362, 0.015968293683337312, 0.04257612502468484, 0.195415466225573, 0.19131966600460665, 0.11940954253077507, 0.09269603275294815, 0.1326318151716675, 0.1568511048597949, 0.20057879202067852, 0.1021390553297741, 0.15353194225047315, 0.1904328614473343, 0.15249089311276162, 0.16916579620114394, 0.09393755506191935, 0.1053747513464519, 0.20134370454720088, 0.19793000843908104, 0.09863894100167922, 0.18985690735280514, 0.12310108515833106, 0.22060359535472734, 0.13141294914696897, 0.11215261050633021, 0.16057923409555638, 0.06177713256329298, 0.12293985166719981, 0.09155724064580031, 0.06176491893295731, 0.09852891654840537, 0.2109743556273835, 0.10404284138764654, 0.12521193974784442, 0.16785711928137712, 0.08316641553704228, 0.13622711439217838, 0.16183037124574184, 0.08514859953096934, 0.06750275354300227, 0.23705443260925158, 0.0809820145368576, 0.13000861236027308, 0.13063711220664637, 0.15033771150878497, 0.17494631744921207, 0.10436286564384188, 0.21395961115402834, 0.0963929086657507, 0.1575380265712738, 0.14306153623121126, 0.14102118143013545, 0.13649084738322667, 0.052658239379525185, 0.19495421169059618, 0.17103245960814611, 0.10206335796309368, 0.15410412369029863, 0.12410971389285155, 0.08970921659576041, 0.15109469874628953, 0.13767159331057752, 0.07917764064456735, 0.18363373699997151, 0.10251480088170085, 0.07236114570072719, 0.08282257470169238, 0.12851203552314214, 0.19545613761459077, 0.0730647865150656, 0.08001779591930763, 0.17961547976093634, 0.1348949330193656, 0.14896511659026146, 0.19660184399357863, 0.1341403613665274, 0.11688723787665367, 0.1817129264984812, 0.10108885275466101, 0.11026316189340182, 0.18253999283271177, 0.24932728548135075, 0.12275895423122815, 0.10576124489307404, 0.10136785278362886, 0.09318928699940443, 0.08850616722234658, 0.0988598380770002, 0.07839262991079263, 0.07138777364577566, 0.07397160785538809, 0.203022834445749, 0.09851846710911819, 0.18077867877270493, 0.09844545674111162, 0.12295806354710034, 0.13604561984539032, 0.18826210578637464, 0.12393712172550814, 0.09398261657250778, 0.15838200199816907, 0.07433036289044789, 0.04312412686912077, 0.10919087300343172, 0.10540947876870632, 0.1150183624454907, 0.17510588174419744, 0.14424259428467068, 0.1875204805816923, 0.16786488172199043, 0.11676997345473085, 0.16104048863053322, 0.12415710277855396, 0.20005455586527074, 0.09881266632250377, 0.06492603716573545, 0.0992461077070662, 0.17229519970715046, 0.08108080245022263, 0.1402778870293072, 0.11295630809451852, 0.09552051619227443, 0.10314620485795395, 0.06980130448937416, 0.14149747230112553, 0.16836941322045668, 0.1538187318614551, 0.12986204879624502, 0.1474904835756336, 0.14054814752723488, 0.11295115122837679, 0.10679540690034628, 0.14921602526945726, 0.07340283944670643, 0.1777983494102955, 0.08845244760492019, 0.1423655900039843, 0.11971876450947352, 0.11478725341813904, 0.22502188969935688, 0.10272047163120337, 0.16621948858456953, 0.16212097422352859, 0.09227190086884157, 0.12278180729065623, 0.12834877999765532, 0.12936765461095742, 0.15401827543973923, 0.14890528337231704, 0.06814088180129017, 0.2234859306897436, 0.10820572158055645, 0.1101345523659672, 0.18382004914539202, 0.07306832846786294, 0.1262413180832352, 0.07254129674817834, 0.11148310000342981, 0.10015579246516738, 0.10346865826951605, 0.145799438602158, 0.15066730310874327, 0.16334772482514381, 0.08634343863065753, 0.13575090494539055, 0.11574758403003216, 0.18708366687808717, 0.12670946653400147, 0.10244726629129478, 0.10725242059145655, 0.19307803522263253, 0.15346563580845082, 0.1677830232573407, 0.09345103188284806, 0.12226057026003088, 0.18615597380059107, 0.12955733229007038, 0.0668613343898739, 0.17366660040404114], [0.07525177951902151, 0.047042052527623515, 0.043375625873782804, 0.01930476232830967, 0.017464139398985674, 0.02924209088087082, 0.07771236462784664, 0.039459213348371644, 0.008900761986816568, 0.019329345652035305, 0.02528811296048973, 0.026862090287197913, 0.04332820645400456, 0.03165546013042331, 0.024351844896695445, 0.03546902371038284, 0.03198944863730243, 0.03864654213456171, 0.06432310451886483, 0.042548922555787225, 0.03405248347137656, 0.0170105166866311, 0.01662916473911277, 0.017344511978860413, 0.04241105441802314, 0.050159544351377656, 0.019270616749833738, 0.031149032126579965, 0.026428786305976764, 0.05055551363953522, 0.038416026825351376, 0.048255015297659805, 0.053846642574561496, 0.030110581777989864, 0.010850442457012832, 0.03467903592224632, 0.035943217908165286, 0.03852286894938775, 0.0326732830144465, 0.010430100190985416, 0.009354395725365196, 0.033734040201774666, 0.040534582787326405, 0.0351910686253437, 0.05804433500660317, 0.018689315799357634, 0.00514926400501281, 0.06181291171482631, 0.044291064608842134, 0.019724473556769744, 0.02223106673253434, 0.016117696916418414, 0.03658951572807772, 0.04261059121095708, 0.015972403909212778, 0.030878683419099877, 0.044224035527024946, 0.050898845573621135, 0.03401137442727174, 0.06746150539921862, 0.042552810561444075, 0.006291974651893335, 0.016843030495303016, 0.053673721317734034, 0.014596770850143262, 0.014773832866922021, 0.04711362100871546, 0.023066514670582752, 0.014424183771812489, 0.020316444470414093, 0.04858167901901262, 0.01505050212810082, 0.014077934985315161, 0.05146279977634549, 0.02720995313887085, 0.014053878374397755, 0.030417618873928274, 0.016980457585304976, 0.024585057382604907, 0.0498859658172088, 0.02105375419237784, 0.046221350851867876, 0.09643360041081905, 0.028633519607995237, 0.013621991683196808, 0.010561008255795708, 0.037546582586531124, 0.01892531367151865, 0.08703623645539794, 0.01113314219816987, 0.017841732262500694, 0.04898645569171224, 0.09822744343961988, 0.08908871667725698, 0.046176431833633354, 0.09186437952199153, 0.03213494350867612, 0.01220135563718421, 0.011227981885895133, 0.017905950513003126, 0.035174648077892404, 0.016309306723996997, 0.01571031297290964, 0.03172069448711617, 0.04096400724457843, 0.015697122252147113, 0.07849151960441045, 0.1686724741011858, 0.0035377988907774644, 0.06372080969491176, 0.02632997464388609, 0.04083494309868131, 0.012057664820791354, 0.024594772307734405, 0.06615730002522469, 0.03038859793118068, 0.04009280220738479, 0.015600101922505667, 0.03574815944635442, 0.023146583499120812, 0.031232254446617196, 0.06393603421747684, 0.049220645268048556, 0.04779446304642728, 0.0999379555827805, 0.008492691874770182, 0.053803236689418554, 0.0435258840609874, 0.024645226475383555, 0.028538137940423827, 0.04647262254729867, 0.028762156276830604, 0.024961912339287143, 0.013910777035302349, 0.06550513287740094, 0.06434341985732317, 0.014953727767403637, 0.030492732700492655, 0.02780963390666459, 0.012078811364647533, 0.017393106960558465, 0.04865502865452852, 0.07259393749492508, 0.015682486251794865, 0.015778770370941077, 0.03581142265881811, 0.040611196176282, 0.018444264573710303, 0.014871823501640132, 0.07374746059732777, 0.03091434043432985, 0.03508567178089704, 0.06978788985205547, 0.01827255280555359, 0.02526117512024939, 0.04119663279769676, 0.048370702125664265, 0.015271992921563131, 0.02488308183715812, 0.03504231000053031, 0.0445949091975178, 0.01924422343394586, 0.02993455622345209, 0.0338832263036498, 0.03626882311488901, 0.011966227986184614, 0.044980381548936875, 0.04927546411220517, 0.03328123342778001, 0.032020216807723045, 0.041587350224809985, 0.021447489403986504, 0.014453616924583912, 0.0338968818209001, 0.039809459554297585, 0.014776280682001795, 0.02631664991245738, 0.031160831850554262, 0.0327184123785368, 0.0467411459955786, 0.03407363001523273, 0.02174356815937374, 0.007181883506876017, 0.07630423483039651, 0.03763007292790072, 0.02033573522099427, 0.037405325166348896, 0.011669295124842652, 0.014131319576076098, 0.03699317281799657, 0.04560462698074324, 0.033580036501267126, 0.02174127471101071, 0.008591664688927787, 0.07129531646413462, 0.03041963412293366, 0.003102377456213747, 0.020242684321211915, 0.029789773813847984, 0.0218423645544265, 0.026052553905174136, 0.03594109409355691, 0.026923507884410874, 0.04532326564991048, 0.029713995022965328, 0.026888702430629303, 0.05451093175049339, 0.017161114141345024, 0.021349578497133086, 0.03887590054156525, 0.01990932515556259, 0.04195656148450715, 0.032110366970300674, 0.01773638291550534, 0.06942863948643208, 0.0601454729746495, 0.02490771096199751, 0.03162247654316681, 0.032579363589840274, 0.06903149294001715, 0.0516384046391717, 0.012857750058174133, 0.03558335346835, 0.03344121162912675, 0.009980883715408189, 0.03700258070603013, 0.03609590864341174, 0.026758720566119467, 0.021209610293486288, 0.02277159451373986, 0.00701082991768739, 0.07618185425443308, 0.03665254484595997, 0.04212321986311248, 0.012192217466820563, 0.02340484580158123, 0.057897113263607025, 0.022539286175742745, 0.0393026990682951, 0.03703301300161651, 0.023429373146167824, 0.08335742993014199, 0.03018493903800845, 0.05198563136426466, 0.0385891652133848, 0.006966001229427222, 0.0020585550186556895, 0.04226102354004979, 0.0460762529234801, 0.044386975533728085, 0.04921702528372407, 0.015491588905985867, 0.025253246438556483, 0.051320276888353486, 0.03133535784270082, 0.0230092598857092, 0.014653452272926058, 0.01528595038689673, 0.05846528456147228, 0.028588369887854372, 0.03373436250590852, 0.04081387458635228, 0.0655374311442886, 0.026776128382022892, 0.03396983451343008, 0.059607869679374356, 0.03859545184033258, 0.023041176476648877, 0.06349445041269064, 0.05797590474997248, 0.046944509726017714, 0.04644697053091867, 0.0335146359034947, 0.02560166908161981, 0.02054664765351585, 0.06891663053206035, 0.04422346216493419, 0.00884103648630636, 0.021629626862704754, 0.055905918324632306, 0.03278210646073733, 0.003235219557869381, 0.02577327567684863, 0.03837055140840156, 0.032668455237788815, 0.04158516873472503, 0.022533130166786056, 0.03231868739905102, 0.06027115123080356, 0.002331880374445713, 0.05622522672638297, 0.03608057714466538, 0.045517516655049155, 0.021813279150852134, 0.0520552422718278, 0.05084954321916614, 0.09798137950045721, 0.036580321578575034, 0.09928715229034424, 0.014072417647444775, 0.0237869814570461, 0.006057210017128715, 0.026726647912125503, 0.01877467380836606, 0.05718319942908628, 0.05337587837129831, 0.0187255801034293, 0.01703028580439942, 0.0138147388851004, 0.02198565418698958, 0.05029604863375425, 0.041475123925400634, 0.035045180203659196, 0.025243109125377874, 0.03820923649306808, 0.028724694358451024, 0.05462975001760891, 0.013940776764814342, 0.052253557701728175, 0.04370117340502994, 0.013373706390016844, 0.006323699132605855, 0.037508967997772355, 0.02467510915760483, 0.03915722794564707, 0.024459594561319267, 0.0021951472985425164, 0.07690265521939312, 0.013781323579938283, 0.033208820170589855, 0.06587876140006951, 0.030756336769887378, 0.036101537091391425, 0.012633174474883293, 0.05154963190268193, 0.007423657408383275, 0.02720318135938474, 0.029238155377762656, 0.06407816694783312, 0.01391127151769719, 0.03554970830945032, 0.017816911451518536, 0.057140967409525595, 0.010428022177490805, 0.02489354315080813, 0.008528102921055896, 0.01656942142705832, 0.02776037056797317, 0.018178343307226896, 0.05049520883975284, 0.009393274933764977, 0.00483528379949608, 0.1372295277459281, 0.08973768113979272, 0.1557926173721041, 0.13121355484638894, 0.10666995256074838, 0.11820492574146815, 0.14097931581948484, 0.14714124160153524, 0.12915768873478684, 0.07452328396695, 0.12597735439028057, 0.1026973675138184, 0.08348263999713318, 0.10354383316423212, 0.07720857951790094, 0.17401512313101972, 0.09210777003318071, 0.10012534659888063, 0.1391927059739828, 0.08134788740426302, 0.1536145606743438, 0.10472358164510556, 0.14845164200024946, 0.09459979166941983, 0.17144566029310226, 0.06828779820352793, 0.13271181445036614, 0.1315405001597745, 0.11774312837847642, 0.10598370259893791, 0.09166495808001075, 0.10173673834651709, 0.17986520778919968, 0.078401776562844, 0.09473463014832564, 0.1459322686174086, 0.09733088154877935, 0.1337120293506554, 0.16172736962991102, 0.1567703727632761, 0.12073833122849464, 0.14406931001160825, 0.13247713632881641, 0.13002439508480684, 0.17669999120490892, 0.10087038483470678, 0.10044383736593382, 0.2134607657790184, 0.10258085626576628, 0.14882691257766315, 0.11897882207163743, 0.11848422432584421, 0.13080901226827077, 0.0988070276964988, 0.06718955534909453, 0.15255569320704254, 0.15845570447189467, 0.13727247901260853, 0.09986111149191856, 0.14690227513866766, 0.10519183187612466, 0.1029959229220237, 0.1114465608926756, 0.1474499071815184, 0.06258036196231842, 0.18436417994754656, 0.10290533849703414, 0.09983203626636948, 0.0898785517950143, 0.11727731408817427, 0.12557735799678735, 0.08345779204475028, 0.1646931240601199, 0.13058988616934844, 0.08229716468070235, 0.08222330614392247, 0.11182996710496289, 0.09511568862944841, 0.11101324164441653, 0.22197859228721686, 0.15072796413941042, 0.10978074385119335, 0.21528618782758713, 0.13790894486010075, 0.12505359681589262, 0.10758963213967425, 0.10038599904094424, 0.07582323492637702, 0.1834512110799551, 0.1389440093189478, 0.06828612222203187, 0.12843978511435644, 0.2001963154013668, 0.1232060816671167, 0.11121584541563477, 0.1187216437288693, 0.18759313811148914, 0.1366441013025386, 0.10898322771702494, 0.1441951918282679, 0.15113363308565958, 0.061814200931361744, 0.09060366145734276, 0.12733768139566692, 0.12893603848559515, 0.08249115784253393, 0.15721213977251733, 0.16149506638092653, 0.12191854789853096, 0.1351462352488722, 0.07261793727853469, 0.1204534008034638, 0.13123680145612784, 0.08548511897346803, 0.13497726645852837, 0.12522909311311586, 0.11397230571934155, 0.0894694494615708, 0.0891284788293498, 0.1532832591661385, 0.2193613877253873, 0.0948587002764855, 0.12981483632964746, 0.09487896811749254, 0.18363460552479538, 0.06028597043561084, 0.1610103209636041, 0.11025926710239478, 0.15868214517831802, 0.12418131290801934, 0.09501443763396569, 0.11708539724349976, 0.09873986630035297, 0.14042990601488523, 0.18534122966229916, 0.11708617077342101, 0.06686311893697296, 0.1254826887909855, 0.10611854107784373, 0.07169972333524909, 0.2141973969659635, 0.1280514866645847, 0.1689055101679904, 0.09649546923381941, 0.1864390586103712, 0.08927939180284739, 0.17026705853641033, 0.12723504618874618, 0.14273205319685595, 0.14889775163361005, 0.11328754174922194, 0.1236630342900753, 0.16136007862431662, 0.09240217280707189, 0.12825534572558744, 0.07489856132971388, 0.12229293638042041, 0.20764869265258312, 0.18271491916051932, 0.11641998509211199, 0.1005640873419387, 0.1323820192899023, 0.106900369482381, 0.14817414831902298, 0.1249064632824489, 0.07440121551709515, 0.15850261838308402, 0.08687313699296542, 0.11671559565833636, 0.08437291186835084, 0.07491054425814322, 0.1174175672765289, 0.08143694512546062, 0.1526256501674652, 0.09227703737893275, 0.12756524847022124], [0.033813432191631625, 0.05103011495832886, 0.05770175624638796, 0.0524649010039866, 0.06065339714820896, 0.06290439636047397, 0.049457521843058724, 0.04196114159588303, 0.02534343900957278, 0.04235734497862203, 0.03082464828288981, 0.006897214741911739, 0.08848379592278174, 0.00551531498786062, 0.05036523884960583, 0.05518877127074769, 0.02188786880911461, 0.016193894702675085, 0.01633768984382706, 0.10784637622003045, 0.016727241887045757, 0.047016444616019726, 0.01449418144433626, 0.01733406084323568, 0.016551155264356306, 0.029889793268271854, 0.0508646236599556, 0.03125407952549202, 0.04676673015845673, 0.08083192937608276, 0.020900595267968516, 0.057933930573718886, 0.04877842024766973, 0.06667836063674518, 0.043628051078745296, 0.014155151422268577, 0.008444094348565807, 0.030603869951197078, 0.028197355601670485, 0.06929027941077948, 0.015995579272774712, 0.03561041683756879, 0.034523312135466507, 0.037279402637588124, 0.027122584969869683, 0.015364368679001927, 0.036629182885267904, 0.03591363378135221, 0.02001133780660374, 0.061960737353989055, 0.033741202138896496, 0.020332542713731527, 0.025041694486779825, 0.03857411191399608, 0.035732207088066, 0.045962028338440826, 0.060361016408673356, 0.03559043737394469, 0.052969812482063255, 0.03644438387293901, 0.03493228554725647, 0.053158967689211876, 0.021924959229571477, 0.02278554010471063, 0.05199461516791156, 0.04443269522328462, 0.024214607796498706, 0.03519348081733499, 0.06635854672640562, 0.09127649678183453, 0.027865801339170763, 0.04344979653667126, 0.02166174362147493, 0.07046172262302466, 0.06835800622190748, 0.04987739591992327, 0.014092132482411606, 0.0804163266771606, 0.058685917008135996, 0.09927523043006659, 0.07084851472505502, 0.04029966378584504, 0.02017521588797016, 0.019190218831811632, 0.08702415174671582, 0.03322713722341827, 0.023385108914226294, 0.033415892094905884, 0.04190088090087686, 0.04813496548948543, 0.07295909790056092, 0.023205018934926817, 0.05295211289610181, 0.03199325521875705, 0.021783594940123812, 0.036671703282211504, 0.013364513088682932, 0.024133248055087667, 0.0156765456777066, 0.03987820193703685, 0.020386392949149013, 0.0769682220582451, 0.05267335713974067, 0.024606081790157726, 0.02495264185459486, 0.01985735446214676, 0.010931136385936822, 0.02768197941726872, 0.03286434490499752, 0.03594141639769077, 0.00294632203544357, 0.050585342038955004, 0.022310487560129592, 0.03154716594144702, 0.0540379148109683, 0.06701564682381493, 0.06239461300096341, 0.004965844539193702, 0.027026850464088575, 0.06921612910394158, 0.08127069726054158, 0.039564447344413826, 0.03542921066816364, 0.034184234615947516, 0.07271350893591132, 0.01609408389776945, 0.04502302747485893, 0.041055178602359126, 0.03732792128409658, 0.013568266976757773, 0.04740374222663896, 0.007411102814200733, 0.0472116964603109, 0.0352319300041667, 0.025374787327434336, 0.03870942197473986, 0.02063641105113285, 0.02828072041406163, 0.025212378274383287, 0.023851681467411772, 0.05625128586377416, 0.06154193875512906, 0.04191279258312924, 0.05005063948088458, 0.021918899911854948, 0.04463948216289282, 0.031682730452822785, 0.032605575397610664, 0.016233271786144803, 0.06119723618030548, 0.02072360280102917, 0.05026354002101081, 0.024625511640416722, 0.05548041919246316, 0.026416079041415026, 0.06648832333407231, 0.01772655263942267, 0.046859957477343936, 0.017570533689909747, 0.05918604481433119, 0.007904566558344024, 0.02014368266931602, 0.02514288611044841, 0.028595331657145704, 0.03771700683448996, 0.07902531631823097, 0.05503637909090944, 0.005756252594957394, 0.0338907580423568, 0.05189984757453203, 0.034871577019138, 0.06118239661944764, 0.047197342051991394, 0.035771328024566174, 0.024941934572000588, 0.03255092618720872, 0.04785943277446287, 0.05416847512658153, 0.03111940050231559, 0.028631019206451516, 0.07980349420436791, 0.050844613662255664, 0.014529809621827943, 0.04230273308764611, 0.01880349119060806, 0.02303994832826512, 0.08155956318868057, 0.03207289826657091, 0.09015103110245296, 0.027847803197801113, 0.04706701922363468, 0.08458652147757155, 0.02508787388381149, 0.012304720269250018, 0.043009929425482235, 0.04723907534831336, 0.02110950941486018, 0.0214003261311778, 0.015177111673567976, 0.06316801400056907, 0.03681129150624786, 0.020871189256597842, 0.02729881408491305, 0.015099845194656934, 0.002403321842263852, 0.05323614086955786, 0.05614425714260765, 0.054354773701301644, 0.07896017695644073, 0.0505673744316612, 0.006618774504334266, 0.027295887902645127, 0.02511490332627935, 0.04831452960414546, 0.05560678616166115, 0.029377943769629513, 0.07705632304506642, 0.02956953491749508, 0.044010151111121686, 0.02174521530313151, 0.011752175632864237, 0.014424436526106936, 0.02352265814053161, 0.001851512780246724, 0.01855325256474316, 0.02402012948212879, 0.006976884931126344, 0.059622437826224735, 0.03672185041276472, 0.006232211407872715, 0.02669548619139407, 0.012615746302929307, 0.07416507854525532, 0.006093602394685149, 0.047454873232969215, 0.04340101665418063, 0.05422590293788484, 0.03516624102901135, 0.04746229301339813, 0.07777080006365265, 0.03514005296996661, 0.01471234911254474, 0.005533141375053674, 0.04709234893588083, 0.0383922679216734, 0.10943707264959812, 0.03539222711697221, 0.09064634809536593, 0.02549201782260622, 0.044795891270041466, 0.09129377228340932, 0.04806852334045938, 0.016328514354037385, 0.009937177578519498, 0.10507105942815542, 0.026720941432618668, 0.009039602974163634, 0.06865878722497396, 0.022141274497179047, 0.03726268353472863, 0.032744349379624636, 0.020975251083395312, 0.02812600934079715, 0.027491480710783174, 0.0515796197578311, 0.057935477633561404, 0.027961115153240304, 0.03467409618731056, 0.09252610044287783, 0.015638523967936635, 0.029845939550016607, 0.030853699759713242, 0.02271226341170924, 0.050503887302641354, 0.07738315979284899, 0.020127604782049145, 0.055608143231698444, 0.042806653904595544, 0.03654360944139106, 0.02800674324056932, 0.04008974879980087, 0.031163817404636314, 0.013622459024190903, 0.018474128596218567, 0.05375906405970454, 0.022438798532156006, 0.016299501892977526, 0.017266834986263087, 0.0621271887794137, 0.015346662307690297, 0.012535590113007596, 0.03228894042383347, 0.07570383990449564, 0.028279648328732167, 0.012641660403460264, 0.02095589247931327, 0.03394738178966301, 0.023645355931616256, 0.050251696192260296, 0.04069562289597733, 0.0642182979998844, 0.019426489814317653, 0.013410699271064783, 0.008482033785964762, 0.026953996159136295, 0.01958409823211176, 0.03032390640250274, 0.04298827058768698, 0.06772996777934687, 0.034882738920194764, 0.04251478545899902, 0.016613958769344857, 0.03201042554740395, 0.023495854310957447, 0.07005652186593839, 0.03225141404462712, 0.0788115845727069, 0.046119149907359054, 0.06809503319008009, 0.007651417017249125, 0.02787547215952405, 0.07168564373361212, 0.014971790369600058, 0.012462443189828523, 0.041774089847292216, 0.08477052660392863, 0.057380334208054204, 0.007682023187434035, 0.07556807183261428, 0.025565289426594973, 0.04002847369494183, 0.02964705415070057, 0.03844676446169615, 0.02347146945872477, 0.013197099839869355, 0.0622622851016266, 0.031787940700139315, 0.03865315785099353, 0.03819351822936109, 0.033285894963358126, 0.02987336932814547, 0.03398472496441432, 0.02083151870673256, 0.049510067594902854, 0.013915020423675222, 0.029364898933895996, 0.07829259349299328, 0.019060491417933787, 0.023747650174690143, 0.003387666232551315, 0.011941141698376408, 0.02196385964219059, 0.18545573923204625, 0.10139683979962553, 0.0959619167926056, 0.1594818936926978, 0.16054913428212914, 0.11458951474300452, 0.1217009010059493, 0.07182139823479311, 0.1412514355033636, 0.12133610700922352, 0.16189487278461456, 0.11992212145456246, 0.2340595961681434, 0.06247759783374412, 0.10803040848778826, 0.2475434983415263, 0.09840147410120283, 0.13216161754514488, 0.14081805518695287, 0.1693203393369913, 0.20013245168541158, 0.1539156809449196, 0.08349420223385096, 0.07905896486980574, 0.13061518195484365, 0.07588556515319006, 0.11325337751103298, 0.1023756197786757, 0.08689432764159781, 0.20694313836949213, 0.1271659984652485, 0.10798614764852182, 0.12426375491278512, 0.1896821574441024, 0.15770368411072663, 0.22908438742160797, 0.16898610655750546, 0.0939055485650897, 0.10047441215387412, 0.13437408953905106, 0.15096737843539032, 0.07090343534946442, 0.28342215024999207, 0.16541371467922414, 0.14040382312876837, 0.06821900832333735, 0.0898159094420927, 0.16708296510790074, 0.11044027988931962, 0.15430161809282644, 0.1067237061049257, 0.16912272279816015, 0.10566504219813005, 0.12210130452045373, 0.07877265701868705, 0.09573778310524565, 0.18508463485964707, 0.11967444260205541, 0.21777318151933805, 0.10446786893797771, 0.19047897468720162, 0.09194530160831553, 0.09910315394933734, 0.10804142111114093, 0.12308239830391747, 0.09510101870234523, 0.08552540359752518, 0.12251480376081807, 0.09880965362702097, 0.1910611984453031, 0.10628731987838234, 0.17458301622952732, 0.06478355159716946, 0.10565394136522498, 0.30933599972299164, 0.0718601154429572, 0.10366490416760955, 0.15433361780430588, 0.23616910725831985, 0.22829804675919668, 0.13083803999636853, 0.1402487235942057, 0.07939417473971844, 0.11320165957191161, 0.1349031568637916, 0.14254686741956643, 0.1099747098716242, 0.0700656006644879, 0.13499218065823826, 0.15678386203944683, 0.14719921563352856, 0.11831612406032425, 0.18573486139731749, 0.2159555083406823, 0.06884746067225933, 0.20294995978474617, 0.09741308606628861, 0.10820972493716649, 0.1381909033017499, 0.17346218494432314, 0.11640880283500467, 0.1592433750629425, 0.17572336218186788, 0.19377712985234602, 0.09792451148054429, 0.19924621709755488, 0.12543958824660095, 0.10780309247119085, 0.0963569666658129, 0.1142530156565564, 0.05853256130857127, 0.10572395260844912, 0.19149110466241837, 0.05886802223644086, 0.12606898375919887, 0.08137649444064923, 0.15609999373555183, 0.18189083838037082, 0.0960580584193979, 0.11563683354428836, 0.1830237340182066, 0.07597657026989119, 0.1697200100336756, 0.09373396741492407, 0.1562865094414779, 0.1225716242832797, 0.15235384260969503, 0.156158944857972, 0.06312450633517333, 0.1614663643496377, 0.11617104416447026, 0.14189191827816622, 0.12052160714353834, 0.20251999928482942, 0.1050126375630498, 0.12418025439339024, 0.10861147195100784, 0.1208290649311883, 0.1370425642068897, 0.2716710093830313, 0.1694829027567591, 0.13322333485952445, 0.11901368520089559, 0.15593743031578405, 0.06817526995603528, 0.1638431368129594, 0.08606062523488488, 0.08343860985977308, 0.10110821814409324, 0.1581288541534117, 0.09786822021539722, 0.11722451049302306, 0.11245675704308919, 0.12052506767213345, 0.12930308521858283, 0.12855001991348608, 0.15239509753882885, 0.0658011030671852, 0.2572164221533707, 0.09881374519318342, 0.10386344351406608, 0.09255409679774727, 0.08782512162412916, 0.09885198742683445, 0.1053674163829003, 0.1400562096387148, 0.1588739805987903, 0.08960067134882722, 0.0962154446169734, 0.19328538195363112, 0.15688068898660795, 0.14123498781451158, 0.07731511630117893, 0.0748286247253418, 0.11166979891381093, 0.13342594541609287], [0.031627321283199956, 0.019995992737157003, 0.05553167233509677, 0.01647303722399686, 0.011493323004937597, 0.04091689655823367, 0.02604613157122263, 0.01288129437515246, 0.039681270718574524, 0.01378245249257556, 0.034415662554757934, 0.05078363711280482, 0.0248252570828689, 0.034544509569449086, 0.05612608597480825, 0.029671681579202414, 0.023526770062744617, 0.045577098815036673, 0.0698769882853542, 0.01873129336828632, 0.011576952445986015, 0.02399366831273905, 0.03106917194756014, 0.031221536985997642, 0.06038350984454155, 0.05158983849521194, 0.04881928162649274, 0.026130446332639883, 0.1090045812140618, 0.02530459627243025, 0.02331128091152225, 0.05316675727122596, 0.06599089609725134, 0.042675567724342854, 0.062310230386044295, 0.021189727521102344, 0.04643903845655067, 0.02815895221595253, 0.023604733736387322, 0.029841383187366382, 0.032445064546274285, 0.054115786882383485, 0.03213568650452154, 0.06831448498581137, 0.03144123644701072, 0.06044285451727254, 0.06353594282908098, 0.0448646506161562, 0.029359317983367612, 0.024319792598752037, 0.053367725773049254, 0.021072856649490337, 0.0336496779429061, 0.06222362217626401, 0.022601132946355, 0.015559683287782329, 0.014787096530199051, 0.046876941208860705, 0.03430652358968343, 0.044244666384266954, 0.03253379657066294, 0.07010281152491059, 0.011250347248278558, 0.03072463900649122, 0.04250210024682539, 0.08543504308909178, 0.015511531050183942, 0.046343161458415646, 0.00728079949372581, 0.02467493273849998, 0.04626245989597269, 0.005196272487020386, 0.04834164725616574, 0.03152260297377195, 0.026726429084581987, 0.059373049065470695, 0.02578676495301936, 0.10047504997679166, 0.061270334757864475, 0.06209111785782235, 0.035526315814682415, 0.025769228215462396, 0.09040721878409386, 0.056957376189529896, 0.0469156516316746, 0.07007501873054675, 0.08128103134887558, 0.023946805291676095, 0.05207661612491522, 0.047523642757109234, 0.014205540280922182, 0.024213852926290462, 0.036916681565344334, 0.05721233572278704, 0.025049565492996147, 0.03249223290809563, 0.04104343655386141, 0.019728744934712137, 0.0424316106364131, 0.03775673845250692, 0.036689874450010915, 0.020006323432815925, 0.0050058632623404264, 0.03840692088540111, 0.016164617612957954, 0.011008758247563881, 0.029384342354855368, 0.025778798951900432, 0.046121338182794194, 0.036083786615303585, 0.02682504227517971, 0.028953540471515486, 0.04120987440858569, 0.02621621315899704, 0.028803010870303427, 0.02855433796399406, 0.0457227734981903, 0.05640653467604092, 0.013216300684559559, 0.016940149212522165, 0.03224393319604652, 0.016315980115905404, 0.08786199321704251, 0.028954212221183946, 0.04704894983608808, 0.056583951227366924, 0.023549614640484964, 0.05251210668523397, 0.032168191724589894, 0.011868680943734944, 0.03413824690505862, 0.029888032469898462, 0.06330597374056067, 0.06624170978154455, 0.022427146389548267, 0.09566754794546536, 0.055597931279667785, 0.026776262392689074, 0.04965320455708674, 0.05906671764595168, 0.014551907811047775, 0.02322733764802771, 0.011840511562435754, 0.012828419533824282, 0.0076058745949662155, 0.05176747217774391, 0.027079659148252437, 0.06548620853573084, 0.06984608780060496, 0.019474923643948774, 0.03540941780166967, 0.027824794075318744, 0.02226044560250427, 0.03968019863324506, 0.037794315721839666, 0.041581233231616874, 0.02856293839535543, 0.06680473099861826, 0.04828968843711274, 0.029835211911371777, 0.03399119479581714, 0.030090846586972475, 0.07859814459724085, 0.012603143363126686, 0.021083321355815445, 0.014970350179022976, 0.026582691618906598, 0.028954408996339356, 0.04215424248416509, 0.026838874211534858, 0.04772604296782187, 0.07190225925296545, 0.052501915089253864, 0.08318607948188271, 0.039159178733825684, 0.05789605474897793, 0.01073037738180054, 0.03592831727915576, 0.04654398068253483, 0.0781544776899474, 0.018510962869705896, 0.05653382106018918, 0.03573719432045307, 0.0021707938285544515, 0.022856362197282057, 0.031016008728849034, 0.04155697899737528, 0.0594336897400873, 0.09392420149275235, 0.01612622949427792, 0.07163056704614844, 0.06058747747114726, 0.05261292002562966, 0.054763255175203085, 0.01968362574864711, 0.04638964110719306, 0.025236296633790647, 0.02968276884140713, 0.04271929252094456, 0.03465828632137605, 0.05125738687015005, 0.016239202182207788, 0.02378953105237867, 0.04329844930076173, 0.03920646923195038, 0.02529237585674439, 0.04544076755908983, 0.02503466995299927, 0.12374857041452612, 0.025174336208562766, 0.018043923823695098, 0.007235036547561842, 0.02323975314253143, 0.02915040383647595, 0.057176712634308, 0.08791937013821942, 0.020012343734768883, 0.03141080754409943, 0.051386203350765366, 0.01425199702914272, 0.02082717777895076, 0.024484401801601052, 0.03215667698532343, 0.011988430500163563, 0.06180453859269619, 0.04280249448493123, 0.049115024507045746, 0.025074075874207274, 0.05110317960913692, 0.0883832098916173, 0.019153703469783068, 0.07144601909177643, 0.039715638517269065, 0.014668490305276853, 0.0688330689445138, 0.06539839253361736, 0.061177504381963184, 0.0394848348306758, 0.017768565831439834, 0.03226826546181526, 0.04771458590403199, 0.03274473614458527, 0.00802434834518603, 0.047703271332596026, 0.03198432909058673, 0.036697202628212314, 0.02194504556246102, 0.10157374066433736, 0.03143117716535926, 0.0726244037172624, 0.03265810418607933, 0.023525294249079058, 0.04103864270395466, 0.08131349246416773, 0.048378054052591324, 0.05436858528160623, 0.06271745996283633, 0.019541815322424685, 0.030052987725606987, 0.050463202342923195, 0.026143146811851432, 0.03649289234142218, 0.057049059841249666, 0.04497949266806245, 0.04289969462635262, 0.03553455322980881, 0.013417473595057215, 0.012911637613017644, 0.048290153233600516, 0.049671721777745655, 0.022891266038641334, 0.0722004414669105, 0.022598108376509378, 0.02214278593393309, 0.06977980171463319, 0.0355354590740587, 0.0499489711863654, 0.0636061237060598, 0.02484666316636971, 0.020527243248320053, 0.0240584802813828, 0.010538562317378819, 0.010803804200674807, 0.028161591717175076, 0.031017610071493045, 0.010039019747637212, 0.0038960284852821913, 0.03841445262410811, 0.04160467322383608, 0.06229377591184207, 0.019070688102926527, 0.029446896498224566, 0.04497743670695594, 0.09782773881618466, 0.04323641762935689, 0.04938716454697507, 0.03301356493362358, 0.05448010590459619, 0.07624511407422167, 0.01661428276981626, 0.09023977669754199, 0.031393532042524645, 0.03547461823161159, 0.03874448187915342, 0.02431714122316667, 0.03006992056699736, 0.07555816522134201, 0.009062607007633363, 0.05612189941374319, 0.04588659560041768, 0.013221823111442583, 0.010837175401060708, 0.020177857085530247, 0.020793629311291233, 0.05002523852246148, 0.06459186545440129, 0.01936038184378828, 0.012297187682374247, 0.042559826613536904, 0.01938127393701247, 0.01708894346042403, 0.03670228824817708, 0.05606849531510046, 0.036039671661066155, 0.048316134339464564, 0.057767302729189396, 0.05083068333832281, 0.025825636527900184, 0.04768173123842903, 0.039068390748330524, 0.03935810145256775, 0.058893460514289994, 0.02404645155183971, 0.01603533633585487, 0.017965190012806227, 0.049808419442602565, 0.10720635484904051, 0.008500982724529291, 0.06834301738334553, 0.040860764748815975, 0.02129907174301999, 0.05307696333953312, 0.0668282558077148, 0.0314706679034446, 0.034152557208601914, 0.05073451796280486, 0.03241676624332156, 0.025477352984515683, 0.027275808355105773, 0.05783952599657433, 0.03726327046751976, 0.05546396811093603, 0.13314450266105787, 0.12100624399525778, 0.14856925926038198, 0.11246329133531877, 0.06875402640019145, 0.1572219921009881, 0.0774022334122232, 0.13900788660560334, 0.11956260646028177, 0.13028325619442122, 0.11921390731419836, 0.1488701623997518, 0.14143351359026773, 0.17296888998576573, 0.10611672260399375, 0.12582013782645973, 0.1497571976589305, 0.08467830690954413, 0.13290464053196566, 0.1372802143118211, 0.07762953585812024, 0.07722183130681515, 0.10024131501891784, 0.1725836449435779, 0.10486753284931183, 0.11912215580897671, 0.15296764538756438, 0.16664834985775606, 0.15160088587020124, 0.10430348704435996, 0.15214778509523186, 0.07880714695368495, 0.22883935485567364, 0.16049481076853617, 0.19090901661132062, 0.09040711700384106, 0.1566851759063346, 0.11254747038973228, 0.16279509876455578, 0.15575593576899596, 0.11161566539002316, 0.10222052024411303, 0.10316573988114085, 0.1572230099035161, 0.0709241713796343, 0.10033348721585103, 0.1137060553633741, 0.08520800527185202, 0.11981603928974696, 0.13595213129052094, 0.12621001047747477, 0.10451062342950276, 0.06128613105309861, 0.21008955953376635, 0.1518770224813904, 0.11965872773102351, 0.09762773383408785, 0.08950596143092428, 0.22452862188220024, 0.14731373877397605, 0.1739042776503733, 0.1487626824527979, 0.16303706435220583, 0.1131755088322929, 0.2083147969096899, 0.10707780638975756, 0.0812709347477981, 0.18721741970096314, 0.06476840669555323, 0.11079776606389455, 0.18312385864555836, 0.13832833378442697, 0.19407510172043527, 0.09658084250986576, 0.25456804569278446, 0.1609779955553157, 0.08894989519779171, 0.2326678122792925, 0.10819888194756848, 0.2334554014461381, 0.20053797135395662, 0.13526704162359238, 0.12203144255493369, 0.17448895770524228, 0.0977417684293219, 0.26079265453985756, 0.2279215141066483, 0.14288381433912686, 0.13650570730013506, 0.1645399108529091, 0.12128501332231931, 0.19285323657095432, 0.10601433845502989, 0.14948753427181924, 0.06854226240622145, 0.13694770501128264, 0.10073076946926968, 0.10267467051744461, 0.13261935726872512, 0.1456194504031113, 0.15877958280699594, 0.15235196985304356, 0.121473225365792, 0.10240932261305195, 0.1139517461082765, 0.06472828491990056, 0.0986109378614596, 0.16803254772509846, 0.10146993837718453, 0.0911905128242714, 0.12361454617764268, 0.12224314548075199, 0.13142837903329305, 0.17480059526860714, 0.11359075190765516, 0.15920830837317876, 0.09617981474314417, 0.1678652074187994, 0.10533621055739266, 0.12546921308551515, 0.10890580687139716, 0.10388160111116511, 0.24759821540543012, 0.14956344876970562, 0.21503989318651812, 0.1416209792452199, 0.15396004356443882, 0.09642925100134951, 0.1331250558474234, 0.1146045917911189, 0.17926049738058022, 0.11472841086132185, 0.10828655545732804, 0.15435727153505596, 0.08783149985330445, 0.15081791074148246, 0.10357092028217656, 0.11623996975166456, 0.14118730037340096, 0.10803101916930505, 0.18157852228198731, 0.07961028135780777, 0.1847881693392992, 0.08910523900496108, 0.12660043952720507, 0.08246087482465164, 0.16333731609795774, 0.14554178528487682, 0.10108940236802612, 0.21305297980351107, 0.16116010078362056, 0.12717017824096338, 0.1640764714351722, 0.0768562705655183, 0.09767557055290256, 0.15652265319866793, 0.09305413639439003, 0.11126583987580878, 0.10186217911541462, 0.12200329692236014, 0.2163403055497578, 0.11535486153193883, 0.2160186120974166, 0.17255426437727042, 0.11368660854973964, 0.08318816936974015, 0.13286760609064782, 0.12940513688538754, 0.15014819667807647, 0.10877180977591447, 0.2160194670515401, 0.13905116356909275, 0.10568729136139154, 0.23320667764970235, 0.13217909660722527, 0.2024131707314934], [0.04536327885996018, 0.050852678050952296, 0.05841633504522698, 0.04125606567998018, 0.03585365128570369, 0.045290723110416105, 0.07143320835062436, 0.020663966358240162, 0.020497891519750868, 0.01438252002532993, 0.06400873245937483, 0.028724799531378915, 0.07836582099220582, 0.009332801348396709, 0.04943436683554735, 0.025511111798030988, 0.05557369061612657, 0.08009147125163249, 0.006412676277769995, 0.04022486887073942, 0.027060887476961528, 0.041463524369256835, 0.02584644889325968, 0.016829899146354625, 0.012724493414030542, 0.11913128889032773, 0.02395461522974074, 0.00505716644693166, 0.015909184801525304, 0.016057198734155724, 0.016674786041091596, 0.03588207511763487, 0.019943458859675696, 0.024886365946648375, 0.025495887168550065, 0.0508259166298168, 0.041167004566107473, 0.026576442311384847, 0.023697596342701997, 0.02147719736344048, 0.03035370766052178, 0.006790689832996577, 0.008039280356440161, 0.05319623283243605, 0.022080681320013743, 0.05656569524269019, 0.013851132958994379, 0.05793958277042423, 0.026814743809934174, 0.01385400740296713, 0.02307538821228913, 0.06531039332704884, 0.034468194735901694, 0.019397306023165584, 0.02645412619624819, 0.03866040799766779, 0.06395170159105744, 0.014275355597159691, 0.015546387394091912, 0.06685880345425435, 0.028627511180405105, 0.02829815197869071, 0.012623069392118071, 0.005126274814496615, 0.029585677265588726, 0.016550663326467787, 0.07368031955723252, 0.021855355107358525, 0.02071143327546971, 0.018635667428108196, 0.012315129844604858, 0.028066379683358327, 0.053795864406440935, 0.02507079006837947, 0.02374566885243569, 0.011234376230277121, 0.02882071045626487, 0.04979370880339827, 0.06254087122423307, 0.03329653439245053, 0.018628284967105304, 0.029368678373949866, 0.014845452238140362, 0.033040509559214115, 0.04212054304246392, 0.021433900043900524, 0.06958829877632004, 0.014112102616179203, 0.03140108074460711, 0.013067975473989333, 0.03960669972002506, 0.07742250125323023, 0.024499690891908746, 0.056215279403009584, 0.06330405348645789, 0.02551882334851793, 0.04435447370633483, 0.020669289465461458, 0.005204769017707024, 0.09073036430137497, 0.006223386635870806, 0.040980383687253506, 0.03502118720539978, 0.04879817918741277, 0.019471441062965562, 0.0068322547678170455, 0.04147843178361654, 0.03237324161455035, 0.03011659359825509, 0.015184612878199135, 0.033225803902106624, 0.022615137909139906, 0.02237914003697889, 0.02513574792205223, 0.03742629189842513, 0.028124216312010373, 0.004626122411406998, 0.03157392057723232, 0.0985918031739337, 0.07527645105229956, 0.0459378453503762, 0.03369785053655505, 0.021897975588217378, 0.01727498079916196, 0.017246801239837493, 0.029894410699073757, 0.02158461115323007, 0.05036837028871689, 0.010925305225620312, 0.0256519756679024, 0.021384144767320583, 0.014515785999330027, 0.04667933824072991, 0.00645253639335611, 0.029753126137490784, 0.016223494096526077, 0.03454709139519504, 0.06754541982497488, 0.05703487167400973, 0.030128203332424164, 0.04512638871424964, 0.05420213046350649, 0.01358002344412463, 0.025681425784049288, 0.03243214184684413, 0.03590231242456606, 0.04348517535254359, 0.017177929935444678, 0.01804579997302166, 0.04127338867900627, 0.03647406638732978, 0.06167314028633492, 0.039322719244020324, 0.04298107811648931, 0.020129114522465637, 0.028720969201198647, 0.046436809469014406, 0.07332856700356517, 0.010910534366433109, 0.09472995504204716, 0.006020017392334661, 0.05313349548461182, 0.059615645690688064, 0.04245986822726471, 0.0254199624926384, 0.0868844956691776, 0.05374125590814011, 0.014872066077909299, 0.017548505050529326, 0.027979922447619692, 0.034368148140077076, 0.06552180448280913, 0.04306149469422443, 0.03929551338244762, 0.006378977260153208, 0.04929391687203731, 0.05615259973066194, 0.05407654380957995, 0.08083745265113455, 0.025298246880993247, 0.020776581118947694, 0.019983047985338738, 0.022954805754125118, 0.05339987476223281, 0.046317078572298796, 0.025661984059427465, 0.04555267494704042, 0.04373282027829971, 0.02100038741316114, 0.04839722605954323, 0.03892378815050636, 0.04506117132093225, 0.03876098045813186, 0.014600394227142845, 0.07536172254809312, 0.03476964748863663, 0.02183414071000048, 0.05608902099941458, 0.027152728888073137, 0.050991781122450314, 0.0018655923818836787, 0.01327312968870891, 0.008975081079240357, 0.07948536984622478, 0.025466739000486474, 0.028114993324769393, 0.012501092544490737, 0.05319238893155541, 0.060249845231218, 0.03605236705126507, 0.03310866840183735, 0.02934910263866186, 0.09812566318682261, 0.033052126078733375, 0.01504081264803452, 0.0349672640274678, 0.03778068056063993, 0.026218786503055265, 0.02028597315906414, 0.0792072858395321, 0.03366155230573245, 0.0409056871597256, 0.02676605213699596, 0.07336039029593978, 0.011181112927650767, 0.03082295533801828, 0.0171696857349681, 0.07186417308236871, 0.012457416941677886, 0.05030332931450435, 0.04220357198002083, 0.05612482389967356, 0.04202726483345032, 0.040132164023816586, 0.002898470473675323, 0.026409527785809975, 0.033354365932089944, 0.09395249640302998, 0.04899287124031356, 0.02747024765371212, 0.024636173121897236, 0.08431951116238322, 0.05111932195723057, 0.026588627103982226, 0.028285205530534898, 0.02858772867226175, 0.07007611795727696, 0.11085738893598318, 0.03525071863883308, 0.034764633114848814, 0.020095053760867034, 0.0018482693828575844, 0.06232060518647943, 0.02889185824564525, 0.05867406300136021, 0.029487812159849063, 0.023637167710278715, 0.017579948363293494, 0.02151321230589279, 0.03565170230077846, 0.020152832714042494, 0.03772739859830056, 0.056467389089188406, 0.057686299218663147, 0.02646704889567835, 0.013909710887154298, 0.061338575024689944, 0.04403910759304251, 0.002380477264523506, 0.003165778920187482, 0.03719535589750324, 0.015063185643936907, 0.07422846050134727, 0.02653491766458111, 0.04570577619597316, 0.025948427617549896, 0.04607021396181413, 0.009875483478286436, 0.008170779594885451, 0.020797595348475233, 0.024475173725347434, 0.02025608708416777, 0.053046907630882094, 0.026761996193921993, 0.03150852337213499, 0.040644746340279064, 0.040128605107643774, 0.04809417535683938, 0.0219432728897248, 0.056438201905361245, 0.07166800182312727, 0.05094006996867912, 0.0708245285121458, 0.031541059126279185, 0.1093928050249815, 0.0035458202349088553, 0.019710171734914184, 0.03885099830638085, 0.0130285576784185, 0.035891767990376265, 0.027405768167227507, 0.08374332636594772, 0.005497077662896897, 0.06282352177160126, 0.017017592110538056, 0.050052071189773936, 0.06192284795854773, 0.01018960532798831, 0.023743994567277174, 0.008575103345460125, 0.03410086301820619, 0.02185991655902139, 0.040289139707705805, 0.06474668000425611, 0.007029449766767877, 0.07369549160024949, 0.038396976954702816, 0.10019445539052997, 0.12548119601394447, 0.0188707916864327, 0.016211085387372544, 0.047121875387217314, 0.08014506194740534, 0.03135234496689268, 0.052856727835855315, 0.06293504578726632, 0.006553553294257394, 0.053052729461342096, 0.05927363011453833, 0.013294547646572548, 0.09846047950642449, 0.01047112696271922, 0.026675201387011578, 0.019776990470875586, 0.03337995348764317, 0.023596231692603657, 0.014352391374164393, 0.019503016690058366, 0.03496227679508073, 0.037031961272337606, 0.06999196604426418, 0.03845781779714993, 0.025294808404786245, 0.04952347883954644, 0.012144597879211818, 0.02394250507599541, 0.01881234607260142, 0.008581974360692714, 0.01897034464803125, 0.11425600121063845, 0.044825034349092414, 0.0019210289049494478, 0.1790986939200333, 0.18043026461132936, 0.13727323897182941, 0.09915718569287232, 0.14448951317795686, 0.10798060401741948, 0.12730251971100057, 0.16946694361312048, 0.19308938032814435, 0.17093716615012713, 0.10945827686893088, 0.13887422877762998, 0.15102596314890043, 0.1263198788676943, 0.12702432035335473, 0.10470898635685444, 0.10181385385138647, 0.1361976931137698, 0.106815627243902, 0.11021436165486063, 0.07556566303329808, 0.10009307547339372, 0.1963697714465005, 0.14658484288624354, 0.08395075452114854, 0.12396217323839664, 0.08687928452023438, 0.1285830374274935, 0.07932753581553698, 0.14396569771426065, 0.05577964295766183, 0.13670533230262144, 0.17286835823740276, 0.09982048760035209, 0.09501025785825082, 0.16929497569799423, 0.19799242009009632, 0.15362286594297203, 0.10057692522449152, 0.10171517450362444, 0.12130227525319372, 0.11414041955556188, 0.14980601146817207, 0.16395551578274795, 0.09062298613467387, 0.13585168096636022, 0.09318344481289387, 0.18751602939196996, 0.09411847963929176, 0.06026055929916246, 0.18552976740258081, 0.12983474454709462, 0.16192780887441977, 0.17505952423172338, 0.08954048529267311, 0.17317847588232585, 0.14784710801073483, 0.09030940796115569, 0.08187987242958375, 0.16116962741528237, 0.0998046098809157, 0.2456520955477442, 0.11861728504300117, 0.09026688417153698, 0.11350337016795363, 0.20854400603898934, 0.20001967916531221, 0.11403135183666434, 0.12685855424829892, 0.07049078427787338, 0.15236948962722505, 0.17011710229728902, 0.14466775075665542, 0.11904685199260712, 0.11377195468438522, 0.11754989517586571, 0.11792382225394249, 0.10343396477401257, 0.13918579848749296, 0.10963432277951922, 0.15093969420662948, 0.10285536439291068, 0.08190292904951743, 0.12426348349877767, 0.11475629865058831, 0.14508943312934466, 0.15064928121864796, 0.20369698612817697, 0.13266589120030403, 0.0954554243279355, 0.19376241921314172, 0.16609976786587918, 0.08073975039379937, 0.17674892715045384, 0.11365699728152581, 0.07736677995749883, 0.16225704763616833, 0.20412801871342318, 0.07714023068547249, 0.23809785661952837, 0.16881654065634522, 0.09664816675441605, 0.07815567869693041, 0.15986069265220845, 0.08189501733119998, 0.13071798001016888, 0.15019759402743407, 0.10396764613687992, 0.17692143789359502, 0.18563109982226575, 0.11246238209839378, 0.12964772672525474, 0.07896979179765497, 0.10008523160857813, 0.15090200837169374, 0.16294877337557928, 0.07284121601177113, 0.10065820693437542, 0.29253191713775906, 0.17115642795605318, 0.10829714738896914, 0.14771592005022935, 0.04781017791745918, 0.16306439574275697, 0.15730782678084715, 0.22253484172480448, 0.06436816602945328, 0.12890519228364739, 0.094748105853796, 0.09373137541115284, 0.1462214466716562, 0.12491551493959767, 0.08977801326130118, 0.06306379780705486, 0.12610379260565552, 0.09759453311562538, 0.19721906658794197, 0.26973846022571835, 0.11955932235079152, 0.12135207972356252, 0.22652890240507467, 0.1883116252720356, 0.182296982301133, 0.1828282345086336, 0.1325065033244235, 0.15653076847749098, 0.1817804950156382, 0.11333849972912244, 0.16389858669468335, 0.11455280599849564, 0.08343656068401677, 0.11106725981725113, 0.15318473588143075, 0.12648727345679486, 0.16378540705357278, 0.13525756927473204, 0.09920240326651505, 0.13654498090701445, 0.15907694399356842, 0.15173868276178837, 0.1865272953041962, 0.1246300959693534, 0.21780321347926343, 0.16772291862538882, 0.0999397129884788, 0.164145451305168, 0.10194744382585798, 0.09010780163641487, 0.16770363466015883, 0.08562295657715627, 0.11480177406753812, 0.13907590295587266, 0.06259799708745309, 0.18820102406399591, 0.13071276886122568, 0.12011691528771605], [0.11875415912696294, 0.049966816657355854, 0.07224970310926437, 0.06160789235894169, 0.04892660551039236, 0.03708530769550374, 0.04487750885475959, 0.057003136591187546, 0.009857251242335354, 0.06151458022317716, 0.041270148674292226, 0.018792173226497004, 0.033589671698531935, 0.054844828655145, 0.04931444255635142, 0.057546290302915235, 0.03279678995854088, 0.03533083666115999, 0.003687837826354163, 0.020247881899454763, 0.09458513531301703, 0.018419006107641116, 0.02041612974634128, 0.03857558433498655, 0.028378117330638424, 0.029176920985004733, 0.05143216731292861, 0.012757203042773264, 0.05315919839111822, 0.012597856727162642, 0.01257662451826036, 0.027806665315958004, 0.024123073422483036, 0.015926302543708255, 0.0314415485731193, 0.02302706634093608, 0.003169789698274274, 0.015068693651950784, 0.06912327158663954, 0.009006800895024623, 0.06482110851045166, 0.023625992238521576, 0.019492395920678973, 0.015903758217713664, 0.038175140108380995, 0.03967724361323884, 0.062003315426409245, 0.029055120556482246, 0.027676247492698685, 0.06084276270121336, 0.06063758049692426, 0.04012055428964751, 0.05172705863203321, 0.022486177239833132, 0.042283757855849605, 0.02351191862752395, 0.013283967589294272, 0.018181401803823452, 0.03563881013542414, 0.04765551943065865, 0.06224779837897845, 0.07156846073589154, 0.014801427189792906, 0.04579891191263284, 0.03046820026689342, 0.0601524483146412, 0.004676630437773253, 0.05236279166170529, 0.01987358501979283, 0.05648028464721782, 0.011789531530147153, 0.06077748763241938, 0.049913052935153246, 0.05784620956650802, 0.009361121703737547, 0.03558540264410632, 0.032313008060944934, 0.006404866763789738, 0.07439187208988837, 0.01884709215456886, 0.03409128210374287, 0.028574904360409294, 0.013962285476736724, 0.05361869212772165, 0.05620691306622965, 0.024043778123866235, 0.022727067349478602, 0.04704929928162268, 0.031305023934692144, 0.03302409240443792, 0.06363821841244187, 0.059270529209503105, 0.06479032337665558, 0.03806272042649133, 0.02420493697614542, 0.017428419619266475, 0.06546065490692854, 0.08448879207883563, 0.009898461218524193, 0.010889201225446803, 0.053353673312813044, 0.04819395053865654, 0.04653019963630608, 0.028666713541107516, 0.012795967748388648, 0.0403592764799084, 0.020724259283659712, 0.04316508663552148, 0.05332674225792289, 0.047116715128400495, 0.06977433272238288, 0.036785429144012075, 0.022681683534756303, 0.04460147402382322, 0.07640064108584609, 0.030828946802232946, 0.1295968365988561, 0.05411238402926496, 0.03811141549210463, 0.03739540498437626, 0.03363287063049419, 0.043669937045446465, 0.011991915625653096, 0.007693247852980026, 0.05167946279315012, 0.03471340711361595, 0.025217516480812004, 0.032367226401610036, 0.07331315747329167, 0.032386774995497296, 0.012777017961655344, 0.055807564673679214, 0.004101296354617391, 0.0546539567543992, 0.05192984900038157, 0.022672039855803763, 0.013809134185846363, 0.03810339181550911, 0.008947044012269803, 0.03132650974605765, 0.003793655362512384, 0.03646783743585859, 0.0065126571405146804, 0.028155315268252577, 0.04771170213020273, 0.069547254193042, 0.040290052337305884, 0.018240335962868164, 0.02032731629775039, 0.05955573783389159, 0.02399282862565347, 0.06602860907358782, 0.04677542558472071, 0.038164649956992695, 0.01533746306917497, 0.029866434700254883, 0.011068492229761822, 0.05390754448516028, 0.059488474657492976, 0.08405965939164162, 0.02457716771667557, 0.019620411729972278, 0.04057888773136905, 0.04787056753411889, 0.008110216103627213, 0.01560250054379659, 0.008272705732711723, 0.06787149661353656, 0.03334597584658435, 0.025332606198000054, 0.05568110610225371, 0.060986612125166824, 0.032305747736245394, 0.02018196222239307, 0.012341666501015425, 0.03114257925855262, 0.023330758259232556, 0.04885435849428177, 0.014486853266134858, 0.03438543042700205, 0.10129773976015193, 0.035163072270474265, 0.013780194667301007, 0.02431550934644682, 0.022223297506570816, 0.06952805843736444, 0.025914653536996672, 0.026933964109048247, 0.06301740636782986, 0.04153907245823315, 0.08595477377197572, 0.05801941241536822, 0.02514956289503191, 0.023047532653436065, 0.013143051132958914, 0.0120639302435198, 0.03294921945780516, 0.06683725318206207, 0.03400826673688633, 0.038318538306547065, 0.028403204466615404, 0.06302197969385556, 0.041160307425473414, 0.01594889097447906, 0.03782725181164486, 0.05030825547873974, 0.05952641155038561, 0.01128817387923066, 0.0335722197778523, 0.032504928298294544, 0.04394191423697131, 0.029294840193220546, 0.021624339378571937, 0.02148353318417711, 0.10337215701916388, 0.040606870515538115, 0.013779758708551526, 0.013924191672621029, 0.04961499964286174, 0.03994655076946531, 0.0682891213468143, 0.02077444882265159, 0.04385017290977495, 0.043296023538070064, 0.05109574625800763, 0.050322786306164095, 0.03821746712284429, 0.04649251040869525, 0.042310451423483234, 0.015958465103592192, 0.08135469311050006, 0.026803174787866216, 0.046856473200023174, 0.017261722224897573, 0.033216270485094616, 0.025605786092845455, 0.023493706747623425, 0.009922033525072038, 0.007844400858240468, 0.04010940595929112, 0.04410423677680748, 0.02443016310488539, 0.02531219077562647, 0.01573274194795106, 0.032662803041083474, 0.05628652557996767, 0.037783255601035695, 0.02751457125746778, 0.029456297600907937, 0.04818492602290852, 0.03895146220124193, 0.020945458307064006, 0.03690297855064273, 0.054919911947633536, 0.03256525345412748, 0.0467436022923461, 0.021874169187088097, 0.027726788173562715, 0.0018098180756039384, 0.04929433077839868, 0.05038957790072475, 0.01118370153874691, 0.0195808141226215, 0.06387489821229662, 0.035119931013988595, 0.016747260366433432, 0.042547850470457754, 0.04891766920419676, 0.04024453620825495, 0.03939975332468748, 0.03194926579349807, 0.06762108326490436, 0.0734121353764619, 0.021876379514911344, 0.012901516415045729, 0.04038380552083254, 0.019333942726786648, 0.06304692264114108, 0.04611152995909963, 0.060127410372453075, 0.035900147897856574, 0.05424480353082929, 0.026266424750377024, 0.011927146913616784, 0.013268527524944927, 0.024441582849249244, 0.05007708538323641, 0.04374911529677255, 0.04128534107335976, 0.007935344906789916, 0.02274098410271108, 0.02736081013322941, 0.052278154596154175, 0.03616120746093137, 0.041755138364221366, 0.02576931981768991, 0.009912585773106133, 0.032016196487737555, 0.011839966189914515, 0.036107616765158515, 0.05751621763088873, 0.022125115185709934, 0.10321464189993483, 0.03850515240005084, 0.017671000977445925, 0.05204719484650663, 0.023213168140500784, 0.0248083378121789, 0.02505068846845201, 0.04619703215679952, 0.011817015591077507, 0.06841170548328332, 0.03426889203754919, 0.02248658605718187, 0.05416295863687992, 0.05414619203656912, 0.02838268387131393, 0.02557862433604896, 0.020267092922170247, 0.039060797941471846, 0.03517482788967235, 0.011860458795646471, 0.022039333092314855, 0.030117679254284928, 0.039151188983981094, 0.015616313820438725, 0.01004826817994139, 0.004169973428361118, 0.031117388645985296, 0.03559687327859657, 0.014695743664300867, 0.04223050982026117, 0.07157798736755337, 0.02834704890847206, 0.019877864879422953, 0.08039818943611213, 0.04475383906226073, 0.029447391828788177, 0.0035715437095080104, 0.004504011129029095, 0.01467607293411025, 0.050487093560929806, 0.032803575308727365, 0.06641690073800938, 0.03069687674620322, 0.021665165134306465, 0.017896449326404502, 0.035931764237050495, 0.0022444267524406314, 0.014710106554308107, 0.04699687227340681, 0.02588163602298924, 0.1680593498583351, 0.15815704049808638, 0.11405835753040654, 0.18810906899826868, 0.15252992244703428, 0.10429210122674704, 0.16319046754922184, 0.13468199515981333, 0.10512977984866925, 0.22578744004879678, 0.1506561344223363, 0.09248553761946303, 0.1390010876847165, 0.10605905391275883, 0.11543847061693668, 0.12961217149027757, 0.15960104444197246, 0.20234773281429494, 0.06614876405469008, 0.06919846683740616, 0.153927012479731, 0.11770587680595261, 0.09071576901312385, 0.0794085053993123, 0.1456932071596384, 0.11416689599198954, 0.14475875587335654, 0.12401501754564898, 0.1940625352518899, 0.1293143896119935, 0.08549209431345973, 0.1255744674376079, 0.10412660653569869, 0.12652729345219477, 0.13525117747485638, 0.12013505931411471, 0.15868286442543778, 0.16068794897624425, 0.14540012074368341, 0.11909253097006253, 0.1557350368904216, 0.09914740121790341, 0.20050838722714356, 0.08391365901167903, 0.11254970276994364, 0.08884918024497372, 0.1359246370515653, 0.1445498756532158, 0.15111375200961316, 0.19190007128885814, 0.16539363004267216, 0.20975441751735552, 0.17527166141995362, 0.09792145807296038, 0.1671586896159819, 0.09549636034561054, 0.15568820440343448, 0.07249571276562554, 0.10821281227150134, 0.11650752968021802, 0.08384512018944536, 0.1579657071935279, 0.17136965080031327, 0.12375283161444323, 0.15498939475842885, 0.1760757796998535, 0.11691235724304404, 0.12044753826090268, 0.1782031905438219, 0.18856067476528032, 0.12318613273756844, 0.1567043513059616, 0.18359075859189034, 0.10982494362230812, 0.11592080044959273, 0.08824197961283581, 0.12470518265451704, 0.12576833846313612, 0.10311616611267839, 0.12439521428729806, 0.09032955366585936, 0.10344367461012942, 0.11400513324354376, 0.10740946752152272, 0.14821244483547552, 0.12554370265986237, 0.1338929674987282, 0.1481907588562795, 0.15130779945424624, 0.16464965710682528, 0.1710402491901602, 0.17377740517258644, 0.1653457661824567, 0.17536000667938165, 0.12137973681092262, 0.1980796932641949, 0.12857123091816902, 0.20089547788458212, 0.064515699898558, 0.11624765076807567, 0.14511234047157423, 0.16540196245270117, 0.17047303462667124, 0.1843065723244633, 0.08258569134133202, 0.09833215496369771, 0.08608844517064945, 0.1159895903297833, 0.10970047315848724, 0.1726343043680702, 0.1803839478109564, 0.15767971825386795, 0.19806376126195702, 0.11027151465948139, 0.1503054675246988, 0.14776370248624257, 0.1562116127461195, 0.10750758368521929, 0.09621379577687808, 0.07538965104946069, 0.16741695361477987, 0.12812201359442302, 0.11174470917986971, 0.07859538974506514, 0.13081338203379086, 0.08777373616716691, 0.2333750900413309, 0.11131102352270059, 0.14120110177568027, 0.09237452250506197, 0.06354742364159652, 0.08245974167117051, 0.1105281433888844, 0.09909313877246209, 0.20447804778814316, 0.08072521617369992, 0.11371033013399158, 0.10770260143492903, 0.16883429113243306, 0.08220458536275796, 0.12246779485472611, 0.14136154816618987, 0.1296430719750268, 0.10132197024566786, 0.18539897299238614, 0.11724785209766456, 0.14122452480452402, 0.16225100867450237, 0.18879646568426064, 0.1356114795697587, 0.13616828540606157, 0.1832739913037845, 0.07870328359838043, 0.11725418961473874, 0.1652426560010229, 0.14092149106519564, 0.19305233231612615, 0.11925132173512663, 0.08834004149373088, 0.18811233953705855, 0.04660569004980581, 0.06695536577275821, 0.08432737538324935, 0.16722131839820317, 0.119993639045528, 0.08966705921505179, 0.13056875658886774, 0.12133436995957579, 0.09103526401200465, 0.06718395743519068, 0.12127028911241464, 0.10600523930042982, 0.07468916542295899, 0.1925475565450532, 0.11414396150835923, 0.10784752972956214], [0.06113700262670006, 0.04261318660740342, 0.01937419342409287, 0.032944968435913324, 0.03983045342777457, 0.0454759733485324, 0.041215706417070966, 0.02450990114760186, 0.06195582476045404, 0.047972958468432934, 0.07080848115895476, 0.02881219144910574, 0.044893786909856966, 0.034371703663574796, 0.065474279890103, 0.055925131043685336, 0.013865122654741364, 0.03326110468645181, 0.041313055836196454, 0.032802136814487834, 0.05277921538800001, 0.057545767830950875, 0.014186127394038652, 0.020395595580339432, 0.007507049362175167, 0.06685638786958796, 0.04546189035422035, 0.027562910092196295, 0.01506651725087847, 0.015308418377701725, 0.04607905527310712, 0.04159359274698155, 0.01583198787245367, 0.014311742037534714, 0.016019485757819245, 0.041515103208699396, 0.013541557293917452, 0.04001121176406741, 0.05289048156035798, 0.03060783598838108, 0.047632076045764346, 0.0285157123580575, 0.04979755609695401, 0.06727294051753623, 0.0785477701574564, 0.048117367683776786, 0.02708800003996917, 0.027578757277556827, 0.01744310311707003, 0.021166582691616247, 0.02265164309314319, 0.01091335537577314, 0.07955943194351026, 0.03539105664406504, 0.05153658367427332, 0.04618506619174566, 0.06373182231826441, 0.06416812033525535, 0.045242363919637034, 0.03231423281665359, 0.02538623251686139, 0.010893835619624172, 0.03247945270101939, 0.01843294152058661, 0.1003898802612509, 0.0526563225180975, 0.027865212710042084, 0.027853007561394146, 0.06914227735251188, 0.0340507057096277, 0.0178225025800722, 0.026568091241642833, 0.00591977359727025, 0.04353455234585064, 0.001273791101993993, 0.02661204674015088, 0.04548063827678561, 0.07221020558582884, 0.10726703623575823, 0.04809384287468024, 0.019038725710873092, 0.010529978001224143, 0.001976469668859084, 0.044421757238784006, 0.08639388770929404, 0.10731096459286553, 0.024291981144675186, 0.020511055099112645, 0.060205591177301745, 0.06646544313324348, 0.058966776223054955, 0.045438436791300774, 0.08339386047529322, 0.021925671691341058, 0.04431946808472276, 0.01152660429943353, 0.032981690751122575, 0.03794276561321957, 0.031017705066395656, 0.05234606238082051, 0.0308447329194418, 0.028916743517454182, 0.021539642941206694, 0.040999928888465674, 0.018547108430149298, 0.03512989190806236, 0.01896792058167713, 0.028838118272168294, 0.0208870008188699, 0.03352029488555022, 0.10117615307016031, 0.02994133478828839, 0.023745870716603737, 0.04243713391146489, 0.05356837536341377, 0.027267949223252277, 0.06662660198552267, 0.02865616910691772, 0.013516006209621472, 0.06976954226515122, 0.03305046706061278, 0.020420852350071073, 0.03277923286493335, 0.037658605325434885, 0.060734136030077934, 0.027895108962963735, 0.021391311793455055, 0.04844824171492031, 0.04438771852957351, 0.03961370559409261, 0.06633379376892533, 0.07082840973245245, 0.05985159945807286, 0.023239018628373742, 0.07094727549701929, 0.015115565154701471, 0.02217066184883671, 0.03116946281599147, 0.02293616809350039, 0.015371147243838226, 0.022824615240097046, 0.03421927077163543, 0.013615667736823005, 0.03034692570301039, 0.08476077605571065, 0.04583841622141855, 0.06716012049998556, 0.08664439605282885, 0.023655913936506425, 0.019352275046652982, 0.03880972980654665, 0.03357392968609929, 0.06543864323092358, 0.0559804723598063, 0.04345617476584656, 0.04536638655034559, 0.04883453170103686, 0.03396965130897505, 0.06677054640437875, 0.0025012942413533373, 0.05205900135583111, 0.04592154693922826, 0.029107981827110052, 0.013448131503537297, 0.02358729877908315, 0.020912822469004562, 0.013870527186164898, 0.05057412585509675, 0.020890727672459822, 0.024211813928559422, 0.02757483534514904, 0.026118156367114613, 0.02471915795467794, 0.05021713161841035, 0.025391365634277463, 0.06596794804292065, 0.09217843267002276, 0.03195437855486359, 0.013794520237882222, 0.0678066150950534, 0.04768780412684594, 0.01508757219250713, 0.03749707667157054, 0.030453666046793972, 0.08060069142707757, 0.024450849941266433, 0.018891224072181752, 0.04055853846615978, 0.015265489163409387, 0.02804798459900277, 0.02166790811211935, 0.05046804029760616, 0.010896392848475702, 0.047491761789258034, 0.04502460167610219, 0.08614185266196728, 0.0579814687371254, 0.06597848569176026, 0.05016189547521727, 0.03331765040223088, 0.046779551077634096, 0.042816289101860354, 0.08271701500884124, 0.029750656270022904, 0.04477818150605474, 0.0309402197599411, 0.05529146415314504, 0.007842368645859616, 0.013088848059331732, 0.017128983811874474, 0.04273149936593004, 0.04941801753427301, 0.046509090411875925, 0.007249861689550536, 0.09805983850466353, 0.04873855631532414, 0.03257103117981127, 0.0175031348065074, 0.024885960521974733, 0.03998769713299615, 0.016962941203798567, 0.08357275623295989, 0.028394960266138827, 0.01372944109607488, 0.04028267326897808, 0.033445805311203, 0.014619474631867238, 0.02701040107889899, 0.03354088163801602, 0.03348158107006124, 0.06438847458256142, 0.03036751245547618, 0.06961113826504775, 0.025509542685800364, 0.002762730815447867, 0.024708170776388476, 0.050157166086137295, 0.034073955712041686, 0.02953013578163726, 0.054821229207196405, 0.04925706224249942, 0.05863683857023716, 0.054636993378932984, 0.02054033218882978, 0.07421540548758847, 0.03975609956043107, 0.08593312850488083, 0.019766652989866476, 0.020914076062451516, 0.01795947165893657, 0.013585775724745222, 0.010107281218682016, 0.028087114017190676, 0.06483740692159959, 0.09191507287323475, 0.0017519777362135106, 0.036665810205574544, 0.012641608665165092, 0.0414215739417289, 0.04545523392568741, 0.055153266925896914, 0.010424494643562605, 0.029755399229803255, 0.012231952477512615, 0.03009178296529821, 0.047959957737475634, 0.01634306723384985, 0.02132686793005892, 0.03145280546907868, 0.03671356889286211, 0.014142803781266724, 0.06744152254291944, 0.056525563289012225, 0.0105506707747866, 0.021221036823200326, 0.031153870081262927, 0.03775957812155996, 0.02530038426630199, 0.014003737181025957, 0.033360520244709084, 0.02099283192572849, 0.03804909883599196, 0.047399033193609545, 0.09270169852035386, 0.0182933074954365, 0.013315414294733532, 0.05572158071611609, 0.04420082962938717, 0.01397572725545615, 0.021216999539839368, 0.01804599505183952, 0.04310681404811995, 0.04022924202893462, 0.04553392702447517, 0.037274201666670184, 0.06808781357748167, 0.03672534826078585, 0.041174702545894046, 0.046329651826194355, 0.019438852722357427, 0.013674765592440963, 0.032259580213576555, 0.08523378281721047, 0.03158214442165835, 0.01332358131185174, 0.021579557763678685, 0.0454579039609858, 0.058896452853722234, 0.03609271952882409, 0.04790381235735757, 0.04299546305888465, 0.014971510473904865, 0.020839686572019542, 0.058942267538181374, 0.0051192931132391095, 0.015199974911021335, 0.010933624064948941, 0.01959877155189003, 0.04547234318618264, 0.031710584315338304, 0.04859614199293511, 0.06308003515005112, 0.07678128566060748, 0.02872411421101008, 0.04849145761025803, 0.04799665291128414, 0.014333512833608049, 0.06641792532588754, 0.026573482202365994, 0.08799308618264538, 0.036071416921913624, 0.06971485912799835, 0.0594709413126111, 0.04365745200110333, 0.013551906649289387, 0.01736134134366044, 0.09665660773004804, 0.02047124205689345, 0.051906809343823364, 0.0015075464159183735, 0.026108414300584366, 0.026251166194145168, 0.017441186255642345, 0.02366106740997306, 0.023411705790619766, 0.09475984450961862, 0.03651608466835959, 0.006046736829115876, 0.039482476921486, 0.0234552389010787, 0.02580061724542507, 0.03771198906802705, 0.2958863228559494, 0.1428957972675562, 0.09452585170843772, 0.16114956992013113, 0.18445530720055103, 0.14330897081111157, 0.14350467388119015, 0.14776245398180826, 0.14435810808624538, 0.20806426821010454, 0.10786606730627162, 0.08873965790761368, 0.09397098648228816, 0.0828573564067483, 0.10424277851624147, 0.1524257944630725, 0.12317097426525184, 0.06256568524986506, 0.16707156571958745, 0.13349677090133938, 0.22446641379169055, 0.13219828557755264, 0.12133905185120446, 0.1786160519612687, 0.1228862474007266, 0.22060704231262207, 0.11378049744027001, 0.12410562911203929, 0.10026781859674624, 0.13777684766267026, 0.19602781693850244, 0.16071183340890066, 0.10668224082993609, 0.09221540604318891, 0.10320210935814039, 0.15175499474363668, 0.13913414840187344, 0.10300812976700918, 0.15963650468204701, 0.1618252279503005, 0.11890729090997151, 0.17844663533781255, 0.20705477095076016, 0.13876571745744773, 0.20446480278457912, 0.2544184965746743, 0.11655558353023869, 0.09849268956375973, 0.06538790238222905, 0.09724456510905709, 0.08802243282220193, 0.16711645759642124, 0.13791988284460135, 0.12116367769028459, 0.10716148332825728, 0.1659862082451582, 0.16559477496360028, 0.1696590504476002, 0.10287177136966161, 0.11386724135705403, 0.11808158164577824, 0.19462974981537887, 0.1435390348945345, 0.11971702745982579, 0.22346550678568228, 0.17733775983963693, 0.1381771426115717, 0.11007306352257729, 0.19191787604774746, 0.14424742545400346, 0.13551353982516698, 0.07582571836454527, 0.12057655490934849, 0.10139182542583772, 0.13608373994273798, 0.11048232870442526, 0.09061477586094822, 0.20920618836368832, 0.16473451469625744, 0.14832694083452225, 0.07462973254067556, 0.07985503572438445, 0.06466907595417329, 0.0955898624711803, 0.20683092224810803, 0.22137655530657085, 0.07688690642161028, 0.09133948518761567, 0.07604886139077799, 0.19334073684045247, 0.08927211790744748, 0.09448546530412776, 0.09404460074646132, 0.13954226007418974, 0.09081488262329783, 0.21465521811374597, 0.0780945901892015, 0.09423052612692118, 0.16823608108929225, 0.09450232011399098, 0.12995876717780316, 0.07207117376050778, 0.09825031685509852, 0.10175598838499614, 0.08812690685902323, 0.1632561090269259, 0.11184489487537316, 0.1693294181355408, 0.10260436750416245, 0.10522633538182292, 0.1281412432768515, 0.09543624892830849, 0.09852001416896071, 0.12439657135733537, 0.15713382326066494, 0.07388877908566169, 0.16759459408266203, 0.084465810097754, 0.07342275444950376, 0.1609561060156141, 0.12350937324975218, 0.16095503393028462, 0.08635009505919047, 0.07368692848831415, 0.12333479976015431, 0.12443235729421888, 0.1794494286711727, 0.14093884799097264, 0.14917333184608392, 0.11434460431337357, 0.14983216220779078, 0.15281165018677711, 0.11428220623305865, 0.20186332666448184, 0.2391342238656112, 0.10741197131574154, 0.06281791028699704, 0.19302059044795378, 0.1331562413168805, 0.12799936160445213, 0.0781192888638803, 0.1473585899387087, 0.11037068255245686, 0.14505523496440478, 0.18649396566408022, 0.163050825042384, 0.15769056124346598, 0.1929835152945348, 0.1314811147749424, 0.11074219404586724, 0.12567008659243584, 0.12764435208269528, 0.18859055744750158, 0.12758538738957473, 0.09409070720097848, 0.16173423640429974, 0.11636366668556418, 0.06401649489998817, 0.14541255150522503, 0.1330206971615553, 0.31169263326695984, 0.11579888127744198, 0.10942788528544561, 0.06304219325206109, 0.11010922265372106, 0.19894819094666413, 0.13879492160465035, 0.20828556562108652, 0.1821226395134415, 0.21349021419882774, 0.10930728247123105, 0.17446443544966833, 0.09004904050379992, 0.15584162117115088, 0.15609309981976235, 0.1392008891063077], [0.033191083265202384, 0.014515655381338937, 0.02975032039518867, 0.0024428700437835816, 0.05900990390884025, 0.0424593220065747, 0.03873727244458028, 0.060609129523592334, 0.012305802532604762, 0.030564131547829936, 0.009918374524983977, 0.04814264311322144, 0.031769684715462584, 0.04439462262338825, 0.05675518632467304, 0.019730943388172557, 0.021860288056944097, 0.06735761490251337, 0.04658312536776066, 0.041889929345675876, 0.002064551783925188, 0.018128321705652133, 0.04462558915838599, 0.04763677150809339, 0.01593518117442727, 0.005425501124201608, 0.03099932355274047, 0.021768007294407914, 0.061869012990168164, 0.015917245797546845, 0.07120018585452012, 0.041723484705601416, 0.14376019659851277, 0.029864863891686712, 0.03431538864970207, 0.07064681340541158, 0.07723050976970366, 0.02472302899695933, 0.04349377239122987, 0.040853718162647316, 0.005549885074807597, 0.042012856142329316, 0.009216007660143077, 0.054721420098628314, 0.028743408354265348, 0.04752079291003091, 0.036095080830688984, 0.004292784449977002, 0.04311460363013404, 0.03443331125059298, 0.006330675320766334, 0.017289528589961783, 0.0483033134202872, 0.02545146856989179, 0.03272576769813895, 0.06326515985918896, 0.011008251890806215, 0.01829224219545722, 0.03757569852418133, 0.06754620692559651, 0.03144521266222, 0.015821292464222227, 0.03416616862107601, 0.06024892242359264, 0.04965368631694998, 0.016190149189372147, 0.03270931661661182, 0.038957399382655106, 0.02552593609185091, 0.03975833872599261, 0.008412734156341424, 0.02619407934668873, 0.01978423722487475, 0.02009942861539977, 0.03972068342513271, 0.013990785643857504, 0.04371876103271331, 0.046109124552458525, 0.039556701867175956, 0.04079604607873729, 0.029384735905166184, 0.03032240005476134, 0.031248162700129405, 0.06890024391135999, 0.02067681441881827, 0.022165694972500205, 0.035896521128181896, 0.05678242950567177, 0.023967936568494354, 0.03532980528793164, 0.029211061474468027, 0.025478129907112037, 0.04169405324916754, 0.007259088917635381, 0.03734445718250104, 0.08581488020718098, 0.04335990761007581, 0.04587756429931947, 0.04314167717737811, 0.05957764772964375, 0.045274635045123954, 0.059111290611326694, 0.04089709012103932, 0.039941624605229924, 0.03604063178811755, 0.07979228480585984, 0.03679230609642608, 0.028897137248090336, 0.003697722385238324, 0.03157993918284774, 0.01514992447170828, 0.013098468837727393, 0.03121985761182649, 0.04374058611158814, 0.030880094771938663, 0.03628819189699633, 0.006414046918507665, 0.020546739255743365, 0.04629632557875343, 0.06740723616842713, 0.031645054795912335, 0.05512985407507845, 0.03685898234003356, 0.12589303962886333, 0.03260417083012206, 0.022869337483176162, 0.009495588684720653, 0.0532944032789341, 0.057258062197693756, 0.04564891496141042, 0.04678941019145506, 0.0083539212854313, 0.056623197692845545, 0.02463922313680606, 0.019419563668114797, 0.038652821976159296, 0.022774814162403345, 0.01694813896236675, 0.0045884590529437575, 0.05158221854695252, 0.03424217472118991, 0.025158005567001443, 0.06560575283531632, 0.04610285488888621, 0.08281606755086354, 0.009032730262593498, 0.018021971519504274, 0.03950784395315817, 0.04145615887162941, 0.02239700416768236, 0.03066873111362968, 0.029787996052099124, 0.04793376289308071, 0.02910382580012083, 0.039253484923392534, 0.005143001126790685, 0.026003957227138535, 0.01895055517421237, 0.022757492859714797, 0.026926946360617876, 0.024559763293447237, 0.044153528953237195, 0.034978819478835375, 0.06387617385813169, 0.035392498530979664, 0.004629027389455587, 0.018705841519736817, 0.03150249798116939, 0.016956637613475323, 0.03769148713243859, 0.01632046014336603, 0.02329786797054112, 0.031880883034318686, 0.024171619210392237, 0.027545485312917402, 0.023394348864842738, 0.03381209208496979, 0.017697679278041636, 0.032257218911711655, 0.052062964000340016, 0.07004510212157454, 0.029767012356647422, 0.04294300212391785, 0.03510719830436366, 0.03994022682309151, 0.026506054481225352, 0.018404383677989244, 0.02364851111945297, 0.05503985319020493, 0.048126999488366504, 0.019956902334732667, 0.010411285263087069, 0.004803184852270144, 0.03174021254692759, 0.009521011695531862, 0.009336176211945713, 0.04121772166607635, 0.03222357375281198, 0.01830012507603637, 0.033835471009037325, 0.045813137399298806, 0.01614009026837136, 0.011906081793962844, 0.0198471170650529, 0.06584752843316112, 0.0633351236049618, 0.02691142656840384, 0.06486672641975538, 0.07302019997899022, 0.03023958146306021, 0.09008868051958935, 0.0644023981211441, 0.02600515993045909, 0.032847429026982615, 0.04240002143861992, 0.05495804900835667, 0.019401278845699768, 0.0253998812487615, 0.03747316509751337, 0.03482163344909038, 0.006365615209298474, 0.056581807056708, 0.0629917848855257, 0.01931799715384841, 0.023621578368225267, 0.02573944052814373, 0.04435545758211187, 0.025118475813152533, 0.08121930501822915, 0.03011346555181912, 0.05312812827261431, 0.06899093690195254, 0.014084669445375246, 0.02757992096511381, 0.01941053236701659, 0.015580665286896484, 0.034368260098355155, 0.01742039424633341, 0.05455935540209923, 0.03883714601397514, 0.030560134976570095, 0.04150961046772344, 0.014173688998978053, 0.028523417123194252, 0.021144058721672212, 0.056282837742141316, 0.09620146001023905, 0.015400665213486977, 0.05794198478439024, 0.07185482286981174, 0.05532699563939657, 0.04045085835137537, 0.03067563860011952, 0.1067792306255017, 0.018182224527533566, 0.035815982414143424, 0.046654900802033286, 0.03855983214452863, 0.013095581671223044, 0.11675655203206198, 0.02765769973796393, 0.0017436426756570914, 0.038608187942632606, 0.03779501122023378, 0.0202723379978644, 0.0433926469247256, 0.020046455386493887, 0.011741150286979973, 0.11288109248770134, 0.04204996182982411, 0.06082479509391955, 0.036549003794789314, 0.04684690924893532, 0.06899985285209757, 0.035464636981487274, 0.061983129009604454, 0.07461449264415673, 0.048949960685734234, 0.05635097622871399, 0.022773825197613666, 0.06653708964586258, 0.034103824823562584, 0.09508249469633613, 0.058284549973905087, 0.017876702261024287, 0.044893203369740925, 0.01582223902057324, 0.036787006737930436, 0.013157401300434555, 0.02747738075309566, 0.02600480200323675, 0.024864569705511843, 0.04580498480104974, 0.04882411279582551, 0.05194405073832188, 0.02127970296091267, 0.05799052717962435, 0.037182596046477556, 0.014194129866414835, 0.032523174104946, 0.052557215693273714, 0.12227746578199522, 0.04727906480963741, 0.01578733348287642, 0.048983717802912, 0.09229110340986933, 0.04242526294131364, 0.003235917176685429, 0.0640641280582973, 0.047377031695629866, 0.0586128727133785, 0.032073288424206634, 0.04729914605351431, 0.05460067818473492, 0.02076015548248376, 0.03158958795081292, 0.030170713551342487, 0.029268136447561637, 0.007298348105645606, 0.045906239189207554, 0.05792076699435711, 0.031882324921233315, 0.06541121006011963, 0.048198330482201915, 0.04065722459927201, 0.06069518133465733, 0.04188877244346908, 0.02584210118012769, 0.0020286795458689865, 0.015127235957022225, 0.053611218064491234, 0.02661944955720433, 0.02201707544736564, 0.038022656326315234, 0.06011656738285508, 0.02446015096003456, 0.005405569158028811, 0.03752066933416894, 0.06507522666028567, 0.03091534466615745, 0.03645776119083166, 0.041016766734953435, 0.02979399769433907, 0.0504820282970156, 0.02085127934281315, 0.026147207843938043, 0.05711705583546843, 0.042878900920706134, 0.04632000305822917, 0.05710395332425833, 0.030047047151518718, 0.017536703630217483, 0.09237254796815769, 0.12545053980180196, 0.10579902572291237, 0.15489971957036427, 0.24217210656830243, 0.1604361039187227, 0.19168987471078122, 0.11768216879240104, 0.10242189586694751, 0.1237159464508295, 0.12514694966375828, 0.14786757262689726, 0.12405807737793241, 0.07072433603129216, 0.1010716383212379, 0.13252808073801653, 0.10387586749025754, 0.12303676003856318, 0.09574737759040934, 0.07404206693172455, 0.17683869733342103, 0.08227898672755275, 0.09636373844529901, 0.24154641585690634, 0.1346674473690135, 0.07578393417809691, 0.05591030166085277, 0.09530112546469484, 0.1124845634081534, 0.15725373396916048, 0.12251753147159304, 0.16539558422352585, 0.3378642446228436, 0.16864408419600554, 0.08354124506669384, 0.20817505940794945, 0.19856624358466693, 0.09417118145419018, 0.10008800003145422, 0.17281978870076792, 0.0965170127206615, 0.1888762071196522, 0.07550711224653892, 0.09113892380680357, 0.04961409040593675, 0.144961949970041, 0.1749591553317649, 0.0962727265432477, 0.1422918061060565, 0.1137850232688444, 0.12436272603060518, 0.11961101314851216, 0.14847483432718686, 0.12461444895182337, 0.0799308145152671, 0.20867091922887734, 0.08481227686362607, 0.1104167482948729, 0.07868442711021219, 0.12551889541958058, 0.09395886784685509, 0.1164597472442048, 0.15372005929904325, 0.12568987267357962, 0.11387171968817711, 0.18346486320453032, 0.11697961363409247, 0.07544518235538687, 0.09864983827407871, 0.14369690285197326, 0.17572914330022676, 0.09696972449975354, 0.25376023618238314, 0.22632654969181332, 0.09422762878239155, 0.08507491741329432, 0.10850975955171244, 0.16445007281644003, 0.13125292344817094, 0.10298606380820274, 0.1365387248141425, 0.09513629573796477, 0.08662460997168507, 0.2071382307580539, 0.12066865925277982, 0.09860603205327477, 0.2566615433565208, 0.18925117914165768, 0.13227802701294422, 0.16083595103451184, 0.13593835702964238, 0.06951001619121858, 0.1761762843068157, 0.0839524780000959, 0.13232709866549286, 0.12254399433732033, 0.22287873684295587, 0.21185871745858872, 0.0842229284878288, 0.13411127935562814, 0.1930334690426077, 0.1640480543885912, 0.15620854576783522, 0.09855416483644928, 0.1607219028685774, 0.127540861921651, 0.21598905511200428, 0.1774255894124508, 0.08590629923024348, 0.1234681997448206, 0.11666637472808361, 0.10154654498078994, 0.2102322961602892, 0.11935585684009961, 0.1402178095387561, 0.2361425629683903, 0.10360391065478325, 0.11158258002251387, 0.1303030965583665, 0.12435417648937021, 0.18858807400933333, 0.14530912919768266, 0.10636110377631017, 0.20037258522851126, 0.1065295229532889, 0.18923554569482803, 0.09175432114196674, 0.14720781945756503, 0.09845853211092097, 0.1629560879830803, 0.11390137166849204, 0.09847251671765532, 0.12066951420690332, 0.0885347199759313, 0.13198416706706795, 0.069183579779097, 0.07463125245911734, 0.23008840211800166, 0.09258480050734111, 0.11022811555968863, 0.17305678741208144, 0.07560818003756659, 0.2076885633702789, 0.12114603577979974, 0.21191989417587007, 0.10084767426763262, 0.1097951287935887, 0.16211994285030024, 0.09347619196133954, 0.1479602333690439, 0.12016811754022326, 0.14510316667812212, 0.1369731365037816, 0.08348612766712904, 0.12886690933789524, 0.17231822918568337, 0.0597139247027891, 0.16561316326260567, 0.11201570928096771, 0.10005773736962251, 0.09442546245242868, 0.1381405152912651, 0.1475870255380869, 0.11358055352632489, 0.09125063781227384, 0.09928914718329906, 0.2087704874575138, 0.11068363647375788, 0.056629392717565806, 0.19124632993979113, 0.12364186399749347, 0.0800826231549893, 0.1486117626939501, 0.12047351258141653, 0.08970829378813505, 0.13074780840958866], [0.025934889147590314, 0.04892799311450549, 0.04887820900018726, 0.01361326063384435, 0.028292662630389844, 0.0250822454358318, 0.06729457899928093, 0.018924051596383964, 0.020095309907836572, 0.04425253060513309, 0.034705278264092546, 0.024153324209951928, 0.005515024914140148, 0.04646964038589171, 0.08869941399565764, 0.02810237935877272, 0.022698453527742198, 0.013405563609142388, 0.04170132714456745, 0.04410150906603251, 0.028336752139564072, 0.01918860731114234, 0.052602789497801235, 0.09720737460468497, 0.009025497079294707, 0.06560417863407306, 0.0987585870815175, 0.027078675272475396, 0.019781589241964475, 0.033504491804965904, 0.033371800889394114, 0.053289568716926236, 0.028599090741149018, 0.043671884440949986, 0.012686980605524565, 0.03668031049892306, 0.028754519365195717, 0.06269903773708002, 0.03705597123397248, 0.010861881709258472, 0.023948216644514884, 0.027471148408949375, 0.07906866792057242, 0.03335355508274265, 0.04092425187783582, 0.026482371912736977, 0.010669819827723716, 0.021088055833908062, 0.04503575339913368, 0.014647825521283915, 0.010531765940998281, 0.03346912655979395, 0.10209906247577497, 0.04668484115973115, 0.05696315730788878, 0.050164589259241305, 0.05281544915799584, 0.07071329626653876, 0.009239262751569706, 0.0229182157532445, 0.026702794013544917, 0.030231140487428223, 0.033418456957276375, 0.016955726680212786, 0.02928565622174314, 0.010692309870916818, 0.06411461784903492, 0.07136303425899573, 0.049589931166597774, 0.01833441823587886, 0.029997894074767828, 0.03695693904800074, 0.029485603528363363, 0.017041332354503017, 0.00876570468036724, 0.03537682776472398, 0.04009920418528574, 0.021182092305805002, 0.0006831299199672815, 0.012388369218180222, 0.03410299361816474, 0.02003548856425498, 0.06169372025345053, 0.037165249298725805, 0.014172301394864917, 0.034104201410497935, 0.07701951252030474, 0.02138124403011586, 0.03245491687474506, 0.01378205300508333, 0.02296893115687583, 0.011662353711601878, 0.08153315460575478, 0.017041279768039073, 0.027485864137166312, 0.011800467818310218, 0.03487416223755904, 0.04160553835598486, 0.041198922853384695, 0.02021443351571049, 0.06484420584248644, 0.04494144720956683, 0.05576679150440863, 0.06961083970963955, 0.02493118996998029, 0.013414208145279969, 0.04813605114551527, 0.07042905794722693, 0.025801745309893574, 0.018021847686863372, 0.020260641750480448, 0.025638357470078126, 0.03256900575278061, 0.051656786152826886, 0.02952974901667663, 0.017179493958662664, 0.0285118955985776, 0.04951732113425221, 0.11832649207540921, 0.0019094335896495196, 0.05132436506184084, 0.0320014620998076, 0.02603693911805749, 0.0474016659094819, 0.06804379701082196, 0.07887023713971887, 0.00855480327403971, 0.028589109491024698, 0.033029357836182625, 0.041387328279337714, 0.09322807884642056, 0.028720110854400054, 0.03500869876838156, 0.03425746890051024, 0.05596147337928414, 0.0231543221910085, 0.03304300996075783, 0.018553415413147638, 0.015028266535539712, 0.04314212840316551, 0.035252754243889024, 0.059046694077551365, 0.06265588290989399, 0.03763112126450453, 0.04111001780256629, 0.03639988215374095, 0.036292466667613814, 0.03184344147198966, 0.038465261326304505, 0.026029239441933374, 0.027755422351349677, 0.03399592757757221, 0.053343668313963075, 0.05152273477454271, 0.04344511464504259, 0.031122925491737466, 0.04308093811518379, 0.09848565994096653, 0.036197393733475886, 0.021451555525085757, 0.027538230077230504, 0.014310771732458046, 0.05956692687634911, 0.01931747977089669, 0.03275811006980283, 0.012166271135876221, 0.0124063156212547, 0.006932086352857628, 0.01835205336101353, 0.04991063395781176, 0.015794184990227222, 0.06951596015798193, 0.038733248731919696, 0.03871052798682025, 0.015683303886492337, 0.04596735144566212, 0.022710253251716495, 0.022964997350105217, 0.018512657510914972, 0.03366989828646183, 0.050889118774128814, 0.055380813644400666, 0.060295049234160354, 0.03520395400534783, 0.010162034753843077, 0.04998791231108563, 0.06480445726109402, 0.05121937533840537, 0.02130176722338157, 0.0179995917382517, 0.01994287871223475, 0.03626580024138093, 0.03524417416857822, 0.022933803398960402, 0.02392438649465995, 0.035698049635227234, 0.05872993357479572, 0.01986629925003009, 0.06928272731602192, 0.034841582378638644, 0.05409098642745188, 0.044937640628112216, 0.08006491339100258, 0.014461664349905081, 0.031819631678185294, 0.050096315065664906, 0.02198376107428755, 0.05096421902999282, 0.026282012396092926, 0.010199720588778811, 0.026375019191099063, 0.0066289406552511665, 0.031920818212841234, 0.07183995616755315, 0.030339902865567377, 0.07009015684681279, 0.04841998073139361, 0.0359104277033891, 0.05286116884755237, 0.015970118942537477, 0.07917449902743101, 0.008620696657869433, 0.03081674674259765, 0.04800817443590079, 0.022287558165511916, 0.021860484832099507, 0.03205666092357465, 0.015891296922096183, 0.04621681484526821, 0.04535302280315331, 0.04832839885992663, 0.017662748295281614, 0.048166266309895685, 0.01920831705709653, 0.04906742527548756, 0.061242229837392054, 0.03406031037281666, 0.0663356122427753, 0.06062085460871458, 0.011444810295610555, 0.03694018262571522, 0.016273101791739464, 0.022537226821961145, 0.014645012993631619, 0.0413324619377298, 0.0632638367159026, 0.01361700869165361, 0.03481461400432246, 0.043595576392752786, 0.005949032451358757, 0.034035167257700644, 0.03150980919599533, 0.06963143324745552, 0.029764932646815265, 0.0450801736941295, 0.025513016785095845, 0.01509431513425495, 0.06253008930278675, 0.02166128221766225, 0.05233335681259632, 0.04474598162674478, 0.04425838975501912, 0.07200818535472665, 0.04404641541519335, 0.052148069255054, 0.03421294343258653, 0.04518887161144188, 0.07096352641071592, 0.060839146109563966, 0.023036633684699024, 0.04842549722109522, 0.007125278419282819, 0.021760003973862956, 0.037839791138789484, 0.06626252045056649, 0.021987523550965955, 0.07105774778340544, 0.029575431386807134, 0.08507252897002868, 0.029735491012356112, 0.02409776406628745, 0.0613564204956804, 0.05307578608127577, 0.07012698094227485, 0.0035151585096692933, 0.017244770723794187, 0.032751233117388825, 0.019346253048362475, 0.03886641122932945, 0.05361626636502998, 0.055630914866924286, 0.03382440071020808, 0.08739960552858454, 0.035244072388325415, 0.0778036140171545, 0.04244532722181507, 0.01309039766368057, 0.04321341868489981, 0.04457612395552652, 0.019710426185546175, 0.035527778057647605, 0.09022421110421419, 0.09029087716979639, 0.058928425423800945, 0.03377559368631669, 0.058960302998977046, 0.010707742301747203, 0.0561166713014245, 0.037125500717333386, 0.030689775877233063, 0.03240103780158928, 0.030472352901207547, 0.10839430681828942, 0.07300829847476312, 0.035925667599907944, 0.02527659822122327, 0.020081187897760953, 0.03790482532765184, 0.07514624018222094, 0.028795601267899786, 0.02152868460065552, 0.0563187899201044, 0.02099818387068808, 0.0125389013638986, 0.042259886993893554, 0.04350636939385107, 0.061404582911304066, 0.021145532839000225, 0.03637278485777123, 0.024962709617934058, 0.03868704728249993, 0.03644085209816694, 0.02191912552474865, 0.08426782036466257, 0.020462166651019027, 0.08314700943550893, 0.050740709594850025, 0.065857930374997, 0.028646187856793404, 0.021077126331095184, 0.04581305936777166, 0.03176554225917373, 0.004694086599296757, 0.035331813751586845, 0.009211871141035641, 0.018629267146544795, 0.022073259843247275, 0.013034694179493402, 0.055480259736733775, 0.009613663107821984, 0.011711549196791435, 0.04553010008696999, 0.06441380429480757, 0.16512725076505116, 0.13045127503573895, 0.10147094939436231, 0.07066710838781935, 0.12506241777113505, 0.26360675639339853, 0.0609028876892158, 0.1310207966182913, 0.2531367167830467, 0.1876197231135198, 0.1426035658057247, 0.07842502995793309, 0.07747406312929732, 0.17443451205534594, 0.12335086746939591, 0.0925061379426292, 0.07327596018356936, 0.1298670835260834, 0.13856820948421955, 0.1429209437753473, 0.12255809429500784, 0.14808930430029119, 0.1618110737098115, 0.09534829043384109, 0.09620763467890875, 0.16272815449961595, 0.11350997909903526, 0.14530598079519613, 0.08699976519814559, 0.11970800294407777, 0.1724216379225254, 0.10345029711191144, 0.10670172835567168, 0.1499314997345209, 0.16898168250918388, 0.10666495175766093, 0.19420850170510157, 0.1553029322198459, 0.15169666787343367, 0.17692583480051585, 0.11129718819367033, 0.2516342502619539, 0.1494460486407791, 0.168097334248679, 0.08359222340264491, 0.13870065951985971, 0.13777165008442743, 0.14461866553340638, 0.10220409291131155, 0.11289048341235944, 0.06262509777609791, 0.25889069374118534, 0.12096855816032205, 0.15251609390335424, 0.13564242076660904, 0.13716537904526505, 0.1483033142451729, 0.09013965885554041, 0.14268081023224763, 0.1334849643920149, 0.17909994242446764, 0.12379141311560359, 0.05708008924765246, 0.10883386180336986, 0.07015590689011983, 0.08841480926743575, 0.13238134075488361, 0.13662525159972055, 0.12100818460541111, 0.12859690668327467, 0.11765604519418307, 0.15285887622407504, 0.10165346852902855, 0.15583813350115502, 0.1260736385094268, 0.14728701806494168, 0.1448763595627887, 0.13087635008352144, 0.14105954580008984, 0.12476352309542042, 0.18686405223395142, 0.17758615793926374, 0.11289614239441496, 0.15104849051151956, 0.1247990783303976, 0.13628170931977884, 0.14700689166784286, 0.11636423665497984, 0.13786842274878705, 0.10754121866609369, 0.14226177414613111, 0.19127553408699377, 0.0905399809458426, 0.09815300814807415, 0.08071545884013176, 0.08195298457784311, 0.13872976867215975, 0.1509155790720667, 0.07471404051674263, 0.17718992062977382, 0.1321473547390529, 0.23123018656458172, 0.18712074203150614, 0.11703144013881683, 0.11526971895779882, 0.08522203059068748, 0.19033128475504263, 0.07432773695992571, 0.08474806030946118, 0.11125392480088131, 0.17711453538920197, 0.12845094023006304, 0.17638686086450303, 0.10120237166328089, 0.12346795547221388, 0.20270830632320472, 0.14505432572747978, 0.19523907426212514, 0.11772411582725388, 0.08314483812344925, 0.10651608117456947, 0.12756307715816156, 0.18653397208877973, 0.18203105085662433, 0.2351758134152208, 0.14391146919557027, 0.08424510979758841, 0.1163510052221162, 0.14974195776241167, 0.11129828742040054, 0.11816189305058547, 0.19221721855657442, 0.11411344100322042, 0.055048714857548475, 0.11414065025746822, 0.1649553778448275, 0.13458638957568578, 0.13774593360722065, 0.09816405469817774, 0.12361104493694645, 0.10420154394315821, 0.26211240515112877, 0.10349797776767186, 0.09563721743013177, 0.165148203926427, 0.14218629391065665, 0.08256760159773485, 0.12460161106927053, 0.0923629602683442, 0.1318347943680627, 0.13466938797916683, 0.14975451066025666, 0.13069621260677064, 0.14665621119950498, 0.17046406439372472, 0.12672769198460238, 0.14138821459242276, 0.13363114797643252, 0.17488235873835428, 0.15469632191317423, 0.14938569973622048, 0.099704960228077, 0.10952606251729385, 0.1261785671647106, 0.10338564629533462, 0.08628910154636417, 0.12362913468054362, 0.07004221834774528, 0.14056980636503014, 0.15700058612440312, 0.18617334429706844, 0.16972771819148744, 0.11567355585949761, 0.05831370662365641, 0.18015772423573903], [0.024629930599725673, 0.0010359439038438722, 0.04252931289374828, 0.08383859946791615, 0.05004356914599027, 0.041162051260471344, 0.008219310115756733, 0.028775112903011695, 0.021233333574075784, 0.030999469437769482, 0.04280867933162621, 0.01999253560123699, 0.023679162242582867, 0.01357320077451212, 0.025793653779796193, 0.030358277593872378, 0.03609382214822939, 0.03592490764068706, 0.016718646544697027, 0.062170336821249554, 0.022130287318889583, 0.045346098353288004, 0.02221702614666096, 0.04907387135816472, 0.03630940968702946, 0.020100001977490525, 0.023236226456772004, 0.033634963911026716, 0.015732558743496026, 0.0635334797469633, 0.0117049275431782, 0.060148533167583604, 0.06270919540630919, 0.04066954679521067, 0.04510850253115807, 0.016713828946064626, 0.058071578187601905, 0.0944143548341734, 0.08429175908012049, 0.01112840517557093, 0.024657206011137793, 0.036782999988645315, 0.05628017449219312, 0.018647925163220083, 0.033529692595558505, 0.02518027338997594, 0.06475578594420638, 0.03406005592218467, 0.012502318996536945, 0.058252930242036066, 0.07279827831579105, 0.04825954112623419, 0.04298708654407944, 0.017032799776643515, 0.02859439867149506, 0.024641129820208465, 0.02713893087846892, 0.04834288897524987, 0.06421455927193165, 0.03781488551092999, 0.008976290567911096, 0.01019343311366226, 0.013901645650288888, 0.015162553704742874, 0.03209838404187134, 0.05671306287071534, 0.045500862013016424, 0.0340975924794163, 0.043566558842680285, 0.07294149670217719, 0.029165029658802917, 0.04954561943720494, 0.03291115364325898, 0.03556686167472175, 0.08224499890846865, 0.06274215863751513, 0.045455705507525375, 0.028372146222474318, 0.07007349202675478, 0.014932493013995034, 0.044404960104397366, 0.03102624782228044, 0.07367880642414093, 0.012079493292341275, 0.014339826601956571, 0.02305989556147584, 0.03233219703127231, 0.04377513372206262, 0.05751514554555927, 0.046861507929861546, 0.024370072043633888, 0.0183904754064445, 0.01137049459586186, 0.00761068201557334, 0.04407223367265292, 0.10065228332366262, 0.006534821062814444, 0.03909929123307977, 0.1124827517196536, 0.037707785543586524, 0.043193337441022904, 0.05765560907976968, 0.03646109958312341, 0.06576509321374552, 0.018743720737152865, 0.009707682616343456, 0.07441837566771678, 0.06767651957592793, 0.04548629725884114, 0.03270321658679417, 0.038330789256308756, 0.015916723325582485, 0.03840094977723701, 0.0038083727870668682, 0.05997304365571056, 0.030520861369690726, 0.042035542960677824, 0.024791518625404154, 0.04744607602645244, 0.035714924801141024, 0.05036303021812013, 0.022322904750970856, 0.03406915168410965, 0.038177443734769306, 0.029563024373991147, 0.005442242279449212, 0.039011224173009396, 0.02928387506731919, 0.038385231513530016, 0.029448789610926594, 0.04129655386454292, 0.04845822296504464, 0.03986360325611063, 0.12271703433777605, 0.032635997515171766, 0.015386052961860384, 0.02154320864272969, 0.017471068937863623, 0.03189563099294901, 0.025118731960122074, 0.022158617852255702, 0.02300810467983995, 0.041823816286133866, 0.031742166727781296, 0.04829645003857357, 0.026716188294813037, 0.050785045072968514, 0.06647051178983279, 0.031846535591674704, 0.038464925451470275, 0.026391775613384585, 0.014670927942331349, 0.03220092425388949, 0.04378466035372444, 0.024971182823979428, 0.04980759841523, 0.03205907990091613, 0.01437916636600026, 0.036341738487992964, 0.11023553873279265, 0.033606302591839006, 0.03416576489273991, 0.02932961850560137, 0.01747519103810191, 0.02043987168664379, 0.0088611100966643, 0.06260676375989403, 0.016211543398510133, 0.0348050534459097, 0.020060107511069094, 0.015312330132084233, 0.04532816806542022, 0.03874331479892135, 0.05291012514914785, 0.03337115967380149, 0.027764217861528908, 0.06277182418853045, 0.039467671287379096, 0.08873361216059752, 0.013846182197864567, 0.01050603504492236, 0.028915033609207188, 0.009266704404061394, 0.048343106106455834, 0.02170451168370034, 0.030648968781211545, 0.05366842195923839, 0.007523296883196703, 0.07061043035771165, 0.030260310707879916, 0.014762757479080131, 0.0325802015805883, 0.023275245613019382, 0.0377830045430788, 0.04872206452169588, 0.08450454766196863, 0.03544828089486275, 0.12791511469653674, 0.02784922981767782, 0.05658104031213692, 0.019207948951848915, 0.039057781853313954, 0.033051864842751195, 0.012777394548590695, 0.04037273522200329, 0.02672807113932712, 0.048142188494758945, 0.031185133582247154, 0.04247821920684405, 0.049112910870462656, 0.012904536744047488, 0.07887712427015815, 0.07378889194556645, 0.012269934323350233, 0.038248313324792046, 0.02407399837725929, 0.02662314418038087, 0.038702344854495356, 0.048284389078617096, 0.01496162252234561, 0.023593380149187784, 0.030854700598865747, 0.023382667884496704, 0.014316406965787922, 0.013442013662175407, 0.026958128437399864, 0.06762175501457282, 0.07418276795319148, 0.05307932464139802, 0.017224429940272654, 0.026280312665871212, 0.06559082506490604, 0.007260659726203552, 0.12019543536007404, 0.06071242290948119, 0.007658903803011137, 0.038378975420658074, 0.014858069596812129, 0.05235040161226477, 0.02132710541731545, 0.06362367740699224, 0.03707301603364093, 0.050455867379371605, 0.051626869543854675, 0.013945417096173125, 0.01882806433630841, 0.01949432974548212, 0.047033262106456926, 0.01738154302750315, 0.06228792693998132, 0.08256995611424957, 0.038800627259271483, 0.023279530561662147, 0.046250836591103246, 0.04195500424663935, 0.04794317078111427, 0.04566529479676059, 0.033376126550138, 0.021823725197464228, 0.02388987111459885, 0.049296990635671785, 0.0736281198582479, 0.025021983044488088, 0.029621999245136976, 0.04130146645807794, 0.02725356936986957, 0.017220574165029184, 0.03627973735066397, 0.04924523876979947, 0.011873298374536847, 0.03758335579186678, 0.1290930514889104, 0.04802013022292938, 0.018998310468824844, 0.03025046855743442, 0.042132451332041194, 0.011371710021714014, 0.057228708772787025, 0.014764357125386596, 0.08442926420164959, 0.060882077020193846, 0.015564558561891317, 0.017997907275067906, 0.022367949298183833, 0.04408618435263634, 0.03831275040283799, 0.04501934642238276, 0.04598442338673132, 0.035652496186750274, 0.03241203685424157, 0.02742697069022272, 0.05084014890183296, 0.03826328180730343, 0.01096183670285557, 0.015562763836766993, 0.031675151216664484, 0.07135654067886726, 0.023104597448504398, 0.04642019893175789, 0.026555197379950966, 0.018914580943861177, 0.010886633818569993, 0.06069912362311568, 0.014299918564834764, 0.05151434129636202, 0.033142296597361565, 0.043227515249912224, 0.03830581238227231, 0.011048544148382331, 0.030874856481594697, 0.03824461530894041, 0.019287505486447896, 0.021191171104354516, 0.015221806775246347, 0.025964415598926798, 0.041068179333316426, 0.0395658145924764, 0.02251146115096552, 0.02148185041733086, 0.021297587447666695, 0.014903541621086853, 0.016248113043340187, 0.07550532769943986, 0.03768533621249454, 0.05946777255407401, 0.06987795859043087, 0.028777402958699634, 0.026516356339145983, 0.05134031742012926, 0.011734978162816592, 0.02157631775896464, 0.03052769082465342, 0.01809399631539626, 0.02536205292147185, 0.029129637272230217, 0.04524561410237636, 0.033614027713026316, 0.034977659183953486, 0.001670707794671346, 0.03382730484008789, 0.041156622980322154, 0.04630421694102032, 0.03783732805667179, 0.008673909918538161, 0.05776285832481725, 0.03888342210224696, 0.010148818588017352, 0.02993217117286154, 0.07495535471077476, 0.025684636951025044, 0.017902362759092023, 0.03317500198526042, 0.08963932070348944, 0.11793005120541368, 0.12951914433922085, 0.23710564843245915, 0.11989982479384967, 0.13508163871509687, 0.1072403494534748, 0.15897369810513087, 0.0879518583949123, 0.11198372992553882, 0.13837744614907674, 0.09872742196811096, 0.12263449733810765, 0.08687802923044988, 0.07730950481657471, 0.15339213689523085, 0.0935388682410121, 0.10927967966667243, 0.12543905898928642, 0.1066350487193891, 0.1326712244855506, 0.16564614006451198, 0.06832411339772598, 0.17036274554474012, 0.0660356047696301, 0.12508149817585945, 0.09975260695708649, 0.0784553944000176, 0.22569306939840317, 0.19579912349581718, 0.095317613865648, 0.2162267594997372, 0.2028377436633621, 0.11860762270433561, 0.16010584735444613, 0.12169714192194597, 0.3227296567388943, 0.11998308104063783, 0.09756551895822797, 0.06955795469028608, 0.10411038954875299, 0.10163197932498795, 0.08355938230774232, 0.08377806057355233, 0.12125146655099732, 0.22440320146935328, 0.12130507081747055, 0.10581128685069935, 0.11177060207618134, 0.10764697513410024, 0.16128725824611528, 0.12234597067747797, 0.17303689276533468, 0.12237278638141495, 0.13963274950427668, 0.1551193477852004, 0.15995556541851588, 0.11858866443591458, 0.1411808000079223, 0.08302739728242159, 0.1279726680368185, 0.06947940747652735, 0.1473751054810626, 0.05682186935363071, 0.19493726188583033, 0.11707308861826148, 0.15811974821346148, 0.12889202870428562, 0.10618323939187185, 0.11963622750980513, 0.07226513978093863, 0.1591490858367511, 0.07492196400250707, 0.1239004944052015, 0.19822331198624202, 0.17430903735969747, 0.10695172101259232, 0.11203527144555535, 0.16462182360036032, 0.14234113560191222, 0.1980319379695824, 0.11034412469182696, 0.15328229564641202, 0.1663165326629366, 0.09970850218087435, 0.13688921529267514, 0.1548274013080767, 0.116342265691076, 0.20940715686551162, 0.1512921117246151, 0.09415672187294279, 0.12862803786993027, 0.11940236363027777, 0.21120239767645085, 0.13490268188927854, 0.22963462503893034, 0.12533890722053392, 0.08963207394949027, 0.17373102051871164, 0.15483306029013225, 0.1333278292523963, 0.15020063386431762, 0.10058970203889267, 0.14140093033867224, 0.2425989865192345, 0.06939364065017019, 0.1599283018814666, 0.09871368163398334, 0.15176970538284096, 0.14997138402291707, 0.11970841006508895, 0.08346865539039884, 0.10864258956696306, 0.11026389471122197, 0.21350719114499433, 0.19516282049672945, 0.16608505722667488, 0.158188755224858, 0.08051848690956831, 0.10448593154017415, 0.16257327209625924, 0.12712456711700984, 0.10765333300722496, 0.13598961356495107, 0.14981095120310783, 0.10222225729376078, 0.19829729944467545, 0.11673596527959619, 0.14252125950796263, 0.0833418168393629, 0.07459206706179039, 0.1461021059325763, 0.17062552858676228, 0.2002899260925395, 0.1265511100313493, 0.08019016417009489, 0.05480053049645253, 0.10740058549812861, 0.1444416493177414, 0.11172983569226094, 0.07439362271023647, 0.1244122183748654, 0.09356825559266976, 0.09890873331044402, 0.15036131095673355, 0.09011941815593413, 0.16981717624834605, 0.11879641828792435, 0.12680846479322228, 0.16319523086505278, 0.12947715659226688, 0.08372129433389221, 0.23000206532222883, 0.11344684820090022, 0.10449059986110244, 0.11620782076248101, 0.07765401061624289, 0.06785090307572059, 0.10656532246087279, 0.1611868893461568, 0.06361950441662755, 0.1044752106868795, 0.1292676114078079, 0.08108877523669175, 0.12581598519214562, 0.14840213608528885, 0.11462238297930785, 0.10997374635189772, 0.08357639318065983, 0.07113961981875555, 0.09334571646260363, 0.1647486960781472, 0.1564971674233675, 0.10104715677776507, 0.13080711237021855, 0.1448200275855405], [0.07569457790149109, 0.05309614891718541, 0.014790723299873727, 0.0557084680268807, 0.06756819824555091, 0.018052196861909967, 0.05825818210308041, 0.028232895569609742, 0.04421474298994456, 0.01783531841023692, 0.050474744223590405, 0.028616532483803372, 0.043028789306325574, 0.045960868043558936, 0.07154104113578796, 0.016618182649835944, 0.028108386090025306, 0.04616480852876391, 0.008938074627492045, 0.09232731682381459, 0.023638477282864705, 0.04453966287629945, 0.06428347128842558, 0.01829993169355605, 0.06287230843944208, 0.09465579116450888, 0.021144201214026128, 0.001956686556306002, 0.006818114946197186, 0.02059536307517971, 0.007590135975208665, 0.03666938269244773, 0.018291037795799117, 0.02603383482034717, 0.042558645962604454, 0.04366740271715181, 0.0043175212922506034, 0.03526578550892217, 0.027737822849303484, 0.004463100556417235, 0.04722904660073774, 0.024653886278559054, 0.032591807922082286, 0.0618475577128785, 0.04651333464841757, 0.04391349719039031, 0.051679493327225955, 0.04005748445966414, 0.02748537389561534, 0.03594036127573677, 0.039058762336415906, 0.012814127889994, 0.032241656711058955, 0.01199464248825929, 0.06887989464615073, 0.024925890611484647, 0.020378650864586234, 0.0460224383111511, 0.031117812730371952, 0.06684580272329704, 0.0580119892422642, 0.007486678892746568, 0.032623179988669496, 0.05720395581530673, 0.0024387316162964062, 0.022529484737398367, 0.02899470379842179, 0.0478219640707331, 0.07370708776371819, 0.0039354314378994915, 0.024628916189872792, 0.06720212181763989, 0.03479604928621224, 0.07100845899965082, 0.053334141682301245, 0.04763799287112696, 0.03162084127377186, 0.04506743759182947, 0.009673336021868246, 0.05165699989135776, 0.04044636984222701, 0.014398277304800493, 0.037755025151584826, 0.046829796595765014, 0.011300041456706822, 0.040736698013331206, 0.06101891039205449, 0.11206854680286986, 0.027011196661208357, 0.017212160330797945, 0.01875440257468394, 0.030789408566696302, 0.047270396524774175, 0.018591474442343627, 0.06948433364076273, 0.02321457440432693, 0.061051025454487116, 0.019785500996346985, 0.018460154167509506, 0.08371288049966097, 0.025463381948481714, 0.03292239696851798, 0.02113091040934835, 0.03682063154077955, 0.02416669643883194, 0.05175295152834483, 0.04747983992898038, 0.0446960177006466, 0.05530282622203231, 0.004898533017175006, 0.054956505341189246, 0.02901395722957594, 0.06455025768705777, 0.025358176790177822, 0.04075217539710658, 0.046357468369283845, 0.017401208668681126, 0.018490048724093607, 0.036531551874109676, 0.021732421525354897, 0.016828533594629595, 0.05441008787602186, 0.016093006723427346, 0.05085706138717277, 0.021641484262155633, 0.027188122970983386, 0.02649110465842698, 0.023267864848354032, 0.017466093579839383, 0.04081059047686202, 0.023166934460667626, 0.028014897535155927, 0.06794970455978598, 0.03009953862056136, 0.019275698977123414, 0.03836941146957023, 0.02732166205532849, 0.044117590345974476, 0.07113007961639337, 0.017295988243339316, 0.016844526665019136, 0.008650599696141268, 0.009131037264264055, 0.03382149997300335, 0.08183253782668284, 0.0166727996298245, 0.040986012135233195, 0.026785531181043813, 0.027518615326178924, 0.02777153586170503, 0.008169232535042932, 0.09056522244853632, 0.031214761813836436, 0.03126103790210826, 0.027125675696879625, 0.05537665422473635, 0.011398729286156595, 0.040276020233120234, 0.03648376604542136, 0.04377650436280029, 0.019290981282080923, 0.02557314855844847, 0.04747970761465175, 0.017239775009719387, 0.019535474412675415, 0.07358122630310909, 0.05960772718702044, 0.03252538612910679, 0.07165254479540245, 0.04270648177979248, 0.011418428854085505, 0.03167102233107601, 0.04055095583732639, 0.025708879310903803, 0.044668737200221846, 0.021625674396221126, 0.05813794569777591, 0.05948109219649008, 0.03826427246843066, 0.014489355364016123, 0.04002033806006823, 0.028313856671697328, 0.02584494254551828, 0.021285724959203174, 0.14257091470062733, 0.01864720252342522, 0.04715035689462509, 0.05571311599175845, 0.0310091487398105, 0.022625570385051624, 0.028780561539211443, 0.013686325284652412, 0.043078753232423744, 0.015315142659736531, 0.030228165111371448, 0.022455902703638588, 0.04132754934419479, 0.03586652648768254, 0.05948204893086638, 0.08241841210318462, 0.10313048320157187, 0.05518703082842486, 0.022994406754150987, 0.020174876620460833, 0.03629417657586081, 0.029345224811030284, 0.025209764218223945, 0.026942147241373147, 0.04205926115225468, 0.03840360624183502, 0.04356616868504456, 0.05446104246324726, 0.018138321615489464, 0.01406865771527269, 0.058135150133499076, 0.021718784667817608, 0.04202060840491738, 0.010340850783645042, 0.01792764836656196, 0.056943398368145735, 0.10937783654247012, 0.062167045926409106, 0.052550538908690214, 0.021319890893729668, 0.016263042510088, 0.021395218458824923, 0.038698935216026645, 0.028830461004482846, 0.04310243071189948, 0.05809544226420777, 0.042264887796980996, 0.025175812022228326, 0.0073609361757657355, 0.0947701446712017, 0.05188528960570693, 0.014121288283994156, 0.04690250501568828, 0.03493594963635717, 0.024172543714355146, 0.07380950583943299, 0.047808929413024864, 0.03106454773140805, 0.04269263627273696, 0.05064953484439424, 0.061580303125083447, 0.020283820506717478, 0.024474722499560033, 0.02568442321249417, 0.03785916331357189, 0.08151119042720113, 0.02012101111800543, 0.02161435134309743, 0.0659288169283952, 0.05566992045247129, 0.023608898245064274, 0.03338247424523745, 0.08221938421151467, 0.02052405074105731, 0.03489831469154783, 0.051550568281007667, 0.06420054073844637, 0.012986695460442985, 0.0657736359696303, 0.10142735351941415, 0.020236791244574955, 0.03281902555110199, 0.013849692768417299, 0.025674299470015934, 0.010550268742788051, 0.02862949589533465, 0.012246454467198678, 0.02980991273320147, 0.033452451561710665, 0.016383418015071323, 0.018527680276227847, 0.0580686197749206, 0.025831731468705193, 0.029322663521660224, 0.06323716350431953, 0.023074850473286848, 0.016402746085077524, 0.04170566298333662, 0.04622373250978334, 0.033445191237011125, 0.036749605887702534, 0.02423554060182401, 0.08267640468797513, 0.0757048169949225, 0.031641719796295674, 0.03276007103600672, 0.021180440073034594, 0.05194019665941596, 0.01438824346821223, 0.08336462918668985, 0.014616619695776274, 0.03425058516274605, 0.07277323358825274, 0.047040261195174286, 0.024863736803776453, 0.034052191701318534, 0.07737815220441137, 0.04478848506031292, 0.015761362555037652, 0.016271831234917045, 0.0150911769097937, 0.029232075703995566, 0.010910445308711911, 0.04961191230852689, 0.03641082013824156, 0.022200664971023798, 0.03208743927202054, 0.009808824198054416, 0.03175569671605315, 0.03213823101084147, 0.05266782368666359, 0.022654085819210325, 0.03657679319647806, 0.04557795037648507, 0.031189730656998496, 0.05669059996892299, 0.04346129770523735, 0.03742142001699124, 0.04952466966850417, 0.04938535625115037, 0.0076722641575283235, 0.0652490198346121, 0.014830378582701087, 0.09007030579128436, 0.015290577995723911, 0.019407144780935984, 0.07749580339129482, 0.03862550076363342, 0.0026877234340645373, 0.06257787173879997, 0.0821471813001803, 0.058455662934907844, 0.024778775737753937, 0.030942832119762897, 0.019096672601465668, 0.004867420914316816, 0.03153637384197541, 0.09315016267022916, 0.04881208576261997, 0.025819027596818547, 0.06601808499544859, 0.026219716096030812, 0.029598186058657508, 0.03713661851361394, 0.039810952331338606, 0.06413974400077548, 0.02244420475991709, 0.024795946066400835, 0.2111618077116353, 0.10626503678836993, 0.14653689760182584, 0.1319570392370224, 0.11578826898975031, 0.06785905906664473, 0.13726407874907764, 0.11179121597004787, 0.21809663916272776, 0.12509270757436752, 0.14570266593779835, 0.0978608038276434, 0.09188996707754475, 0.1319512174065624, 0.1860188418733222, 0.07219940330833197, 0.1443852223455906, 0.0933444272460682, 0.1486542389861175, 0.13750533866030829, 0.23798866676432745, 0.08400826714932919, 0.18905344046652317, 0.1986072135290929, 0.17209809885493346, 0.13693615634526524, 0.14255247211882047, 0.0917611743456551, 0.11744778922625951, 0.10111876936363322, 0.13189701602927276, 0.11118026303925685, 0.13196898145335062, 0.13366021641663142, 0.13636716402002744, 0.15292077218847616, 0.0656893483496138, 0.11857015400060586, 0.16607437708548137, 0.07995891265038933, 0.19021600165537425, 0.11542388211403574, 0.09544770938477345, 0.15794256914939198, 0.2014050848249878, 0.17936740735811846, 0.16848650122327463, 0.16176694179219858, 0.14998845596398624, 0.14677319063671998, 0.12922415802521364, 0.0987544140911528, 0.10815678563501153, 0.11729923076927662, 0.20299805434686796, 0.15462574070053442, 0.13484549495790685, 0.11774235484855515, 0.1738787375922714, 0.1900048279868705, 0.12968010641634464, 0.10464709717780352, 0.10873953186507736, 0.21240411033587797, 0.14366472672138894, 0.12421901231365544, 0.15540144193385327, 0.18148747645318508, 0.20842425817889826, 0.11164194505129542, 0.13361877149769238, 0.10373874913368906, 0.125789983730231, 0.13060608958559378, 0.1611139468316521, 0.2012529165617057, 0.11682116213653769, 0.13298200709479197, 0.10462518049670116, 0.1523450623665537, 0.26917961878435953, 0.18856817936258657, 0.1081492742523551, 0.2137004379183054, 0.15526336005755834, 0.12607300068650926, 0.1872839161327907, 0.22263352785791668, 0.12352567166090012, 0.1648421167795147, 0.12325385053242956, 0.11840088665485382, 0.17469547662351811, 0.1480699796229601, 0.17549559154680797, 0.08000749575772456, 0.12889531281377586, 0.12463415360876492, 0.14641387920294488, 0.21386236351515564, 0.07914886397442647, 0.16376304253935814, 0.166464236165796, 0.08972747597311224, 0.06496970089418547, 0.08915110118687153, 0.11384806595742702, 0.13011124756719383, 0.1932718926774604, 0.12281817676765577, 0.1219986014600311, 0.16871994441109045, 0.16795022785663605, 0.17200927862099238, 0.14627864717372827, 0.22679453529417515, 0.0674877239923392, 0.18159767054021358, 0.16067383544785635, 0.09168710546301943, 0.13025764828281744, 0.11581013138805117, 0.11703966398324285, 0.14786609342055662, 0.12432650583130972, 0.15554970183542796, 0.10987700082893882, 0.15754458121955395, 0.11219607745962483, 0.18078611551650933, 0.09484218473413161, 0.16200540613915237, 0.10924208204128913, 0.17222129367291927, 0.09678702894598246, 0.11027694972498076, 0.1001722469393696, 0.1083120751593794, 0.21061036230197974, 0.15300717683775084, 0.16787119209766388, 0.11033729862953935, 0.11673686094582081, 0.09466081910899707, 0.16407624073326588, 0.12479554994830064, 0.20753084469054425, 0.24973861340965542, 0.12539852330727236, 0.12973744262542042, 0.10759926733693906, 0.17284663154610566, 0.08585525982614074, 0.06994771199034792, 0.2121731098741293, 0.06996179837733507, 0.1278236617467233, 0.18425473224903854, 0.13809148435081753, 0.2030625423150403, 0.11980723190520491, 0.07836527816419091, 0.12580898271075316, 0.07466157618910074, 0.061594294517167976, 0.1838708035647869, 0.16451845557561942, 0.13688342060361589, 0.19209805423659937, 0.1704496115978275, 0.060968447742717605, 0.0936890212552888, 0.12275436733450208, 0.13297683665794985, 0.09187015385500022, 0.1547162572720221], [0.037427160423249006, 0.009789934631304016, 0.07797047256359033, 0.09523618966341019, 0.041010500464056215, 0.026885331807924167, 0.034366784284689596, 0.020379760269341723, 0.10471993791205542, 0.02961321221664548, 0.04047899380592363, 0.03527044704450028, 0.018355549512697116, 0.010433229933758932, 0.043605883339686055, 0.05893837274717433, 0.005248192714394203, 0.02629095039862607, 0.019697118417492936, 0.022919238644785116, 0.07353660584028278, 0.06351116273019995, 0.022086876344734004, 0.05419325861813767, 0.0619102136365005, 0.06329751240887813, 0.010247687925584614, 0.04317890500117626, 0.0920376909364547, 0.024017727468162775, 0.03273689227976969, 0.06783088629267045, 0.0643797011247703, 0.028583280875214508, 0.08958311764789478, 0.03787330398336053, 0.05600078430558954, 0.040944896305778196, 0.00632350829463186, 0.032599760352500846, 0.06037240901163646, 0.01892308977299503, 0.04531042776735766, 0.02734632001790617, 0.02085831405461899, 0.0771183343604207, 0.03142080915027431, 0.02550743074555482, 0.044539706981075664, 0.05103559412860444, 0.046564391015895774, 0.03226213150524667, 0.0036791182272801442, 0.06487753548260246, 0.010252013586328497, 0.01944145151147885, 0.015325729502364993, 0.011089857601161515, 0.05583300973687853, 0.05321865162945219, 0.020817289827391505, 0.020750471091430103, 0.020045870150040303, 0.02266528843236821, 0.007316064654982516, 0.006537944020237774, 0.009540530603512056, 0.04548064845481089, 0.024307774047234228, 0.03671873254435403, 0.04021701143522348, 0.031879868624465804, 0.02939492410847119, 0.03650236129760742, 0.05787681149584906, 0.012016014645009168, 0.024591410166717002, 0.0642614256856697, 0.03149782966024109, 0.05077800866482513, 0.07543239197028534, 0.05026148066722921, 0.017044387458424484, 0.016328500783337013, 0.06760351599327155, 0.0041211261164530045, 0.04297280338193689, 0.03300777363723942, 0.013176870166457124, 0.0594270129555038, 0.006489213755620378, 0.08511928003281355, 0.09023093538624899, 0.08209232852927276, 0.05522577857066478, 0.02921150252223015, 0.027488240706069127, 0.06559867571507182, 0.023285656036542993, 0.024153395456128886, 0.029061033989169767, 0.01869557528490467, 0.03236695159492748, 0.04120221035555005, 0.015901161124929786, 0.0380439080430993, 0.03055215540475079, 0.03359098805646811, 0.0753692067893488, 0.0223391997694437, 0.06497903753604208, 0.01827317875410829, 0.031802963465452194, 0.055071907184485874, 0.05661646323278546, 0.04482776205986738, 0.0737091437248247, 0.03833946771919727, 0.044501318862395625, 0.05530153022014669, 0.03639566505860005, 0.015715079681415643, 0.017398297753451124, 0.013096004059272153, 0.022833370038175156, 0.028554510990423814, 0.0929450618901423, 0.07630693539977074, 0.014967296771439058, 0.02789502584242395, 0.027234361739829183, 0.06963089720479079, 0.0348452193263386, 0.024860596882977655, 0.06104852166026831, 0.043394485754626136, 0.032696292136928866, 0.01664831639001412, 0.010116312519780226, 0.01916428522339889, 0.030222587553518157, 0.05151237354480794, 0.049520958081952164, 0.0515957858546504, 0.005860079054920269, 0.04566035845449992, 0.025961389332743626, 0.060287754982709885, 0.004213730031291821, 0.08955121971666813, 0.027081847423687577, 0.044936928166342635, 0.03526765487289854, 0.010591409169137478, 0.038724644907883236, 0.03501414740458131, 0.019286048332495347, 0.1291712594351598, 0.03197046322748065, 0.08879881937588964, 0.09498257362948996, 0.09037574832992894, 0.015019540575199893, 0.06715292124343769, 0.022847067963864123, 0.023229178174265792, 0.04418017502341952, 0.041971675852047544, 0.036690532628979, 0.014178164785594811, 0.039792770985513926, 0.024751675049109117, 0.030376014499259845, 0.06389382255396672, 0.018709581944027116, 0.08969956782779523, 0.03513602925730603, 0.05079733673483133, 0.051418372695999484, 0.030007641230310713, 0.016786091229213134, 0.005806698705003197, 0.024468334092359458, 0.06849975218730313, 0.08490484261087008, 0.040824714183275185, 0.04425345680543354, 0.02559748591322984, 0.05437465138467295, 0.020716769953391383, 0.03724512304844601, 0.02887117989095194, 0.012338435826157885, 0.024488488278750862, 0.020689231609659534, 0.04882370228213923, 0.04005975755197661, 0.030463589621441703, 0.04785829622830663, 0.06014236528426409, 0.017149260134569237, 0.08708775083401374, 0.0322043338923582, 0.03140668205118605, 0.033851972980690856, 0.06079264610473599, 0.04763647973803537, 0.05996113536613328, 0.030684581691665307, 0.04825966326253755, 0.005538023858597236, 0.01488390821032226, 0.04315842002896326, 0.027661043219268322, 0.016906724577503543, 0.05088833845885737, 0.04003842441099031, 0.014410728422392691, 0.047667597353990586, 0.01559965408939336, 0.04546845857320087, 0.04135323868000081, 0.018632848115105714, 0.08194499822067362, 0.020856090156095367, 0.013625001834173287, 0.024261959362775087, 0.06605129249926124, 0.019344646616705825, 0.0403797580594463, 0.020901504504893507, 0.0655941159597465, 0.03850513543667538, 0.03597551278237786, 0.036991642721529515, 0.06266301431293998, 0.04220416569816215, 0.046020375564694405, 0.0512055535800755, 0.016642586161781634, 0.029605778865516186, 0.023855572865743722, 0.038425092053200514, 0.00774701836053282, 0.030850955085562806, 0.02431156875432602, 0.06751690099814109, 0.048393039498478174, 0.01750850541118, 0.01648693362117878, 0.044030880355941396, 0.03248988178425601, 0.0478217639029026, 0.032651725956904035, 0.026759852023263062, 0.04670867130958608, 0.032006652892700264, 0.03073379922924297, 0.039179405862731595, 0.00591269986970084, 0.06616008880415133, 0.023868273344955275, 0.03201217616775206, 0.035992567760071585, 0.05220371251925826, 0.024535134168607847, 0.04712418919163091, 0.03870489275349038, 0.03564700683844941, 0.07235381752252579, 0.0057970181307090175, 0.024699193758091757, 0.04669348908854382, 0.0306159580525543, 0.009773196868731506, 0.0050395007877211484, 0.04595032700204423, 0.01701105272929583, 0.023105937555166225, 0.0460674183975373, 0.01839104707219771, 0.02977998594620398, 0.01985080151020416, 0.018550650382946645, 0.063008605768638, 0.017689472396991084, 0.03417582756706646, 0.024423956205802302, 0.02289483174016433, 0.05168982741555997, 0.030731281864323785, 0.008496075220006918, 0.06645999449704375, 0.05006117034437401, 0.05663445119612983, 0.06684492741312299, 0.030218865788940872, 0.05554769254688706, 0.01702828412609441, 0.026890281720885208, 0.03859716174857957, 0.06374835143131868, 0.003965176292695105, 0.03626398855288114, 0.006480150224108781, 0.01935788822759475, 0.05475615769890802, 0.05435413248570902, 0.03673468829531755, 0.013942031206430068, 0.06858921024416174, 0.01955228002874979, 0.025289729570171664, 0.048062772756176333, 0.020690625999122858, 0.01347719315838601, 0.024056663503870368, 0.040462692002100606, 0.021444095032555715, 0.02106784566837762, 0.015611730316387755, 0.05474473795454417, 0.02041430109446602, 0.036028377445680757, 0.04375779036698597, 0.10506316128053836, 0.008259161325570728, 0.02184790648919131, 0.02072445605881512, 0.031278330367058516, 0.013289893744513392, 0.0070248230061094675, 0.0016354982944903895, 0.10016305278986692, 0.007509481062048248, 0.02626025177804487, 0.039179273548402956, 0.02769505648341562, 0.029851232123162066, 0.02965695397662265, 0.02977714627715094, 0.019952230621129274, 0.042822758933263164, 0.07948027404823474, 0.04513068723359278, 0.03219258166583521, 0.034012799350810904, 0.01874427543953061, 0.02470092911140195, 0.04874387942254543, 0.025507081300020218, 0.06888257485947438, 0.14358199973191532, 0.14613687406693185, 0.14602817275694438, 0.25433392396994997, 0.09375278997634139, 0.1834822337010077, 0.07810839837683098, 0.15264436416327953, 0.22658622504345008, 0.08079441317490169, 0.18336534925869533, 0.10726416603262935, 0.161896270566753, 0.1325662144060646, 0.12357622251978942, 0.11494193226099014, 0.07114101760089397, 0.12169685693723814, 0.08288561060492482, 0.15185798278876714, 0.13079499373478548, 0.1518554857798985, 0.12661866497780594, 0.13635851948388986, 0.1073960732402546, 0.16211148830396788, 0.19747316438172544, 0.07583126199564763, 0.16538566404155322, 0.1082444591447711, 0.17385293969086238, 0.11834390328398772, 0.14788269038711274, 0.12904020718165807, 0.24579741060733795, 0.0949266759146537, 0.1368283914136035, 0.09804567747882434, 0.09084581703479801, 0.12504670290010317, 0.16011142491229943, 0.13286269349711283, 0.13334642111190728, 0.07078644234154906, 0.16494442628962652, 0.08669363733913217, 0.08195637725293636, 0.0979763176292181, 0.1417751559721572, 0.13681027452860559, 0.16528629937342235, 0.15895236496414455, 0.16769965844494955, 0.15175331197679043, 0.11544683016836643, 0.09306257737002202, 0.10107903435294117, 0.06609056610614061, 0.16842265107801982, 0.22132367028721742, 0.1275508499571255, 0.1398119641734021, 0.14495197550526687, 0.12212820164859295, 0.06676428352615663, 0.07443475550306694, 0.12829767274005072, 0.1324449601982321, 0.0748958946870906, 0.14005181273179396, 0.17514936226819242, 0.1597541897956814, 0.08001995366066694, 0.0906018294127924, 0.17197014072111674, 0.1641285286418029, 0.08094173669815063, 0.10675516298839025, 0.09200314671865531, 0.21559945387499674, 0.20245065300592355, 0.17776838530387196, 0.11697752374623503, 0.06468479082520519, 0.16483427291469915, 0.10534066853246518, 0.2141329361391919, 0.07931325943874461, 0.128578070551157, 0.12726397892194136, 0.2272413641746555, 0.11195284301148993, 0.18687347030001028, 0.20698247982987336, 0.15532414322452887, 0.10470861994794436, 0.15090055630675384, 0.13836010279400007, 0.1109664159427796, 0.09877478371241263, 0.10451736128223793, 0.10937432173107352, 0.07075855455228261, 0.1605287782315697, 0.15225607928420815, 0.092569187416562, 0.11175197628991944, 0.10044613759964705, 0.1792931891977787, 0.11413264354424817, 0.10181477665901184, 0.0838882275191801, 0.15139121854943888, 0.11039436342460768, 0.10299043357372284, 0.09667705877551011, 0.1174666660704783, 0.12128904382033007, 0.17694283888808318, 0.12034018045025212, 0.17848912520068033, 0.1268545373209885, 0.09529913057174001, 0.08331555074879102, 0.11589216627180576, 0.12498361271406923, 0.1606166892285858, 0.16583511206720555, 0.06838316630039896, 0.17912949940987996, 0.11761207612497465, 0.17209759673901967, 0.1802990495094231, 0.06038407302860703, 0.12553272396326065, 0.11803017583276544, 0.10293022037616797, 0.07932585983404092, 0.08008798358163663, 0.10484421838607107, 0.09740423796964542, 0.16060174788747514, 0.10643015149980783, 0.11408541750695024, 0.11623284513396875, 0.10179860038416726, 0.07540097579892192, 0.10434527123080832, 0.12160225558493819, 0.2504942842892238, 0.08212324258472238, 0.09238535870930978, 0.1120996033506734, 0.12932321056723595, 0.14741142067526067, 0.0909115399367043, 0.19125033329640115, 0.20867030854736054, 0.11578894752476897, 0.12412499450147152, 0.19263964731778416, 0.09044905725334372, 0.08790209463664464, 0.21447286861283438, 0.1398981652621712, 0.10292403892214809, 0.13240527947034153, 0.19632620949830326, 0.1531169909451689, 0.14469795913568564, 0.09437859603869063, 0.09740595466324262, 0.16150414517947606, 0.13919460587203503, 0.18344458857817308, 0.18652638606727123], [0.09084439889660903, 0.059380173683166504, 0.05309791310823389, 0.06137205394251006, 0.041497742890247276, 0.017968857494582022, 0.023748238803818822, 0.018491687386163642, 0.04620119836181402, 0.048307320169572315, 0.07035750642951046, 0.08413161803036928, 0.03446762476648603, 0.021758434861632328, 0.08120760028915745, 0.023269651091790626, 0.032378934523356814, 0.052120809110679796, 0.037596214030470164, 0.07994323849145855, 0.05114813933947256, 0.017399327430341924, 0.014899947081825562, 0.029564713926187584, 0.04221926310232707, 0.047312024648168256, 0.03223135315680078, 0.03967007149809173, 0.021707790704177957, 0.05029921739229134, 0.05782791626240526, 0.0379570555607123, 0.011104191653430462, 0.06804991061133997, 0.045647456111120324, 0.026544771689389433, 0.04892178451908486, 0.01924912415311805, 0.03319893052269306, 0.026086653682536314, 0.028011240231405412, 0.05579702363216451, 0.022623823157378604, 0.04316491021641663, 0.04958739683830312, 0.015958122443407774, 0.027501589186223488, 0.007753271908898438, 0.08970625139772892, 0.0377862174063921, 0.05739485485745328, 0.0067179792926513725, 0.05897841988397496, 0.09145195236695663, 0.015868187715698565, 0.06465125762458358, 0.01392254707336958, 0.037347819323518446, 0.029277510408844267, 0.0471050680748054, 0.036326027009636164, 0.013206020879027034, 0.047302521765232086, 0.016916609136387706, 0.027459314758224145, 0.0354299841980849, 0.052920856180467775, 0.03902713242652161, 0.016769573990521685, 0.059829289226659706, 0.011231219346102859, 0.008646911858314914, 0.029693272563495805, 0.08874110318720341, 0.0685080506705812, 0.05036183599648731, 0.012527639378926583, 0.04231843438797763, 0.04611657825963838, 0.03333682919453297, 0.023996740380035977, 0.05820605025759765, 0.032509813750428815, 0.06064842348652227, 0.05345271567681006, 0.018178877653554082, 0.03255386085116437, 0.03292318746181471, 0.05587794232581343, 0.08560302121830837, 0.002444438307845433, 0.04118855144562466, 0.05700297374278307, 0.049832046031951904, 0.012158480705693364, 0.01609230613602059, 0.011529941843556506, 0.010558439152581351, 0.06237347663513251, 0.02554794437518077, 0.055109942464956214, 0.035428817117852826, 0.08807881229690143, 0.02126116368786565, 0.025921338803267906, 0.04010500226702009, 0.05615036056510039, 0.027789522128711854, 0.02530125618380095, 0.02245614188723266, 0.05318457560081567, 0.04019991235275354, 0.03387640702671238, 0.05202713735135538, 0.01459662157243916, 0.04177348255845053, 0.025700219507728304, 0.022127853074510182, 0.04760326884154763, 0.012045790457965007, 0.049174532028181214, 0.015513848247272628, 0.05866058051053967, 0.07195550389587879, 0.02201184054969677, 0.07348021279488291, 0.02882036779608045, 0.05278456563662205, 0.027883188799023628, 0.048336673594479046, 0.09868907795420714, 0.053259221238217185, 0.08128707031054155, 0.02632408156724913, 0.043288658040442636, 0.0721230749040842, 0.04196564367573176, 0.0855077752577407, 0.0035473834099580665, 0.041571804987532754, 0.02035466634801456, 0.04364787108664002, 0.0016150295435051832, 0.02988492138683796, 0.07510873755174023, 0.07951397009726081, 0.04324272121968014, 0.06172018311917782, 0.024289282271638513, 0.021506788275603737, 0.03165442197184477, 0.030168209757123674, 0.03285183611192873, 0.010953788429365625, 0.023245778533497026, 0.020213011984846423, 0.011726929041157876, 0.01781237205224378, 0.0458976794699473, 0.021520681280110563, 0.020111092632370334, 0.06797649312232222, 0.05249667001355972, 0.031036473345011473, 0.035036569594272544, 0.04580505943990179, 0.017825932574591467, 0.04206391590248261, 0.10236590315720864, 0.021382918315274373, 0.02680946989650173, 0.043587752883987765, 0.027412597622190202, 0.0626997501988496, 0.027741990750655532, 0.018452252627217343, 0.060604752972722054, 0.004839172229237322, 0.03634105995297432, 0.026310777191870978, 0.018416526062147956, 0.032881566123770814, 0.05256471689790487, 0.0046195317159539884, 0.04492000211030245, 0.027254380219216858, 0.019761497820062295, 0.019652918646378175, 0.04150933566104088, 0.07790464788143124, 0.052591267973184586, 0.027479401091113687, 0.00512026935549719, 0.015338343468361666, 0.019801314254956584, 0.01925618770266218, 0.0546181606394904, 0.008236170862801373, 0.0694196963948863, 0.019666796383847083, 0.032514471893331835, 0.009994694447544004, 0.01734745342816625, 0.02440167311578989, 0.015334207797423005, 0.01887011993676424, 0.015150233205141765, 0.09852050271417413, 0.0663263705958213, 0.03205508332965629, 0.04322570695408753, 0.02702469441906682, 0.04591717717370816, 0.03502391830884984, 0.030888247370187725, 0.007754645094142428, 0.04374232655391097, 0.021776646741532853, 0.02445381344296038, 0.048518456518650055, 0.024326209843690907, 0.03146932779678276, 0.031083621350782256, 0.01816283369303814, 0.06267984876675264, 0.030124837798731666, 0.085349181267832, 0.05767536123416253, 0.01697318708258016, 0.01930110841723425, 0.03828318323940039, 0.11769141043935503, 0.026470494157235538, 0.023159204250467674, 0.0077639130343283924, 0.025293120548927357, 0.03682859754189849, 0.00895899725479207, 0.023968036652409604, 0.01843223245149212, 0.011438317563650864, 0.05211059037329895, 0.04159229674509593, 0.02355743645291243, 0.035528429451265504, 0.006212601321749389, 0.018525524231206094, 0.05529642763680645, 0.03230785798015339, 0.019945516517119746, 0.04692496791748064, 0.035807884098695855, 0.04729870839842728, 0.02489683574198612, 0.07634343379842383, 0.04026101782385792, 0.023794268923146383, 0.036162951295929294, 0.03230063497487988, 0.06887837472770895, 0.0674517344949501, 0.02847879326769284, 0.049841341961707385, 0.027727013786456416, 0.08026261813938618, 0.06485154080603804, 0.025273544813639352, 0.03734008063163076, 0.019965116001133407, 0.053787637169339826, 0.0322487609727042, 0.024993525285805975, 0.013082541924502169, 0.026513443727578436, 0.09571110989366259, 0.02910154252978308, 0.009432649472728372, 0.035542475126151524, 0.03843965680737581, 0.03681072832218238, 0.029064022935926914, 0.012797122954257896, 0.0660927306328501, 0.03540053917095065, 0.007119290347743247, 0.00797510875522026, 0.013639804075605102, 0.03089655263881598, 0.01466091615813119, 0.027926640485280325, 0.048468434917075295, 0.055537989496120384, 0.045874534640461206, 0.04226443996386869, 0.015835828380659223, 0.008945463873845125, 0.08340217931462185, 0.027806924855602638, 0.01897263979273183, 0.05881217201905591, 0.02519751326846225, 0.03110552785385932, 0.019599110819399357, 0.015390054622132863, 0.058423113610063276, 0.0338582765710141, 0.0950793462938496, 0.04065553843975067, 0.08433369932962315, 0.03509468951129487, 0.04583740859691586, 0.0608383250821914, 0.010169950713004385, 0.014070915540547242, 0.022700998034062128, 0.013752818323804863, 0.05118164200601833, 0.02394887482348297, 0.04665378461192761, 0.03285935088726027, 0.027263939081292068, 0.07915877058569874, 0.06467248219996691, 0.04432745444189225, 0.009857467525372548, 0.0437249424867332, 0.011492971014896674, 0.03747004044375249, 0.014382229951609458, 0.014968662323164088, 0.03449044729183827, 0.035672146560890336, 0.038464718498289585, 0.005859469221572259, 0.01068469331533249, 0.019822087604552507, 0.02623168545375977, 0.023434272169002464, 0.03776527103036642, 0.03530617869858231, 0.06652740016579628, 0.010307137771243495, 0.009977306987691139, 0.02086288738064468, 0.030804190452077558, 0.040514057103012285, 0.008355376743046301, 0.022240661217698028, 0.020510373171418905, 0.05035487761987107, 0.035117576497473886, 0.021178122875945907, 0.23504279341016496, 0.21032302986298287, 0.10815149984721627, 0.152618729110275, 0.11221269478223153, 0.0408467462153307, 0.1145410809133734, 0.07632346451282501, 0.09166654585195438, 0.13971892345164502, 0.26681562992078917, 0.17614277824759483, 0.10445605564330306, 0.13733528421393462, 0.12275813998920576, 0.07138674227254731, 0.09660781427685704, 0.10439892978008304, 0.06759514287114143, 0.12058494160217897, 0.19574425715420926, 0.07982646261474916, 0.21039614879659244, 0.08706744228090559, 0.08606266762529101, 0.12054410736475672, 0.10266751197299787, 0.1965648638350623, 0.05055931682831474, 0.257463273193155, 0.13454122628484452, 0.11970394530466624, 0.1545239740184375, 0.18033642321825027, 0.10351249841707093, 0.1459402617599283, 0.10057220262076173, 0.21525766221540316, 0.1290636302105018, 0.11032461002469063, 0.11704845779708453, 0.09893182385712862, 0.08086103852838278, 0.1083364277811987, 0.16784217794026646, 0.12046024043645177, 0.06653527795736279, 0.12953019088932446, 0.25350402135934147, 0.16605441458523273, 0.18049813168389456, 0.2227056154182979, 0.106937519274652, 0.22223848477005959, 0.14171397925487586, 0.1775098770324673, 0.1006227263382503, 0.07822132695998464, 0.07690205132322651, 0.1951544473745993, 0.1608290028359209, 0.07201566281063215, 0.1976358499377966, 0.06070561720324414, 0.28592396314655033, 0.12409163771995477, 0.14071919263473578, 0.14481092164559023, 0.12966076816831315, 0.1370248815843037, 0.11333299002477101, 0.16086963351283753, 0.1561788802168199, 0.11737411389393465, 0.10632768592664174, 0.10075265222362109, 0.10966316730316196, 0.12761402156736168, 0.1468532577689205, 0.06534830986389092, 0.1289809439331293, 0.1053477863648108, 0.09328527934849262, 0.1788790114223957, 0.08776101363556725, 0.16386888043156692, 0.1028309032054884, 0.14119271508284978, 0.11357030764754329, 0.15837452454226358, 0.16977897472679615, 0.09670719930103847, 0.09296264951782567, 0.1732208300381899, 0.09565874734627348, 0.10692991968244314, 0.09017211997083255, 0.096909450234047, 0.12755213917366096, 0.08198024132954222, 0.11873677505978517, 0.06573388060288769, 0.14188518721078122, 0.1364974563143083, 0.09665257723203727, 0.09120894862072808, 0.11298820602574519, 0.09502018482557364, 0.06218079983123711, 0.09219948761165142, 0.1767020132392645, 0.10190816343362842, 0.2096989540649312, 0.13417712439383778, 0.10833811054804496, 0.11283057555556297, 0.21812064573168755, 0.10647377451615674, 0.14399631321430206, 0.11021610548985855, 0.09067405268017735, 0.1853713294757264, 0.1570877507328987, 0.16282373294234276, 0.08488450013101101, 0.11775418849928038, 0.08033707378698246, 0.16520165891519614, 0.09507209275450025, 0.16547893546521664, 0.1638045824531998, 0.13764844169574125, 0.15197459581707204, 0.10494770854711533, 0.10961152400289263, 0.11175046994217805, 0.1311536809163434, 0.16140332844640526, 0.09621654384370361, 0.12782505952886172, 0.13486678738679203, 0.12026387240205492, 0.0693027169576713, 0.12156566897673265, 0.15237058885395527, 0.19708873358155998, 0.12636843483362878, 0.10196165913449866, 0.07902286002146346, 0.12217356849993978, 0.14474127681127616, 0.0712368403162275, 0.1359513441898993, 0.19297250945653233, 0.10022695043257304, 0.08776597372655358, 0.2643676927047116, 0.10719687571482998, 0.06581583406244006, 0.08490132779947349, 0.17275751275675638, 0.1360888560967786, 0.1036034356802702, 0.14687837713531085, 0.17330291920474597, 0.25150815131408827, 0.07825962347643715, 0.12172303481825761, 0.14912776143423148, 0.1789060713989394, 0.0895603731540697, 0.13858605495521, 0.1304938598935093, 0.18465646569217953, 0.12797318372343267, 0.07042286292250667], [0.027797800255939364, 0.01765706217182534, 0.007719599608598011, 0.004627719937291528, 0.03683222770424826, 0.017654814524576068, 0.02382804300369961, 0.029929507922913347, 0.012173539942263492, 0.03626599023118615, 0.05668028962931462, 0.053355583388890536, 0.004661727264257414, 0.05527866019734314, 0.05307368262271796, 0.01864826273439186, 0.036278475275529284, 0.015114560922873872, 0.05683271573590381, 0.02110034240675824, 0.016747513120727878, 0.031111936617110456, 0.012102811148257127, 0.0347402906710548, 0.02876158970009003, 0.03551549318113497, 0.018002702821312205, 0.02673971649658467, 0.03525224873530013, 0.0639322412067226, 0.03844731407506125, 0.007587432013159352, 0.004782882660427796, 0.015772856938253556, 0.05032454710453749, 0.029009302479348013, 0.07147603069565125, 0.01509492751210928, 0.012307132461241313, 0.04284900127510939, 0.03156757966748305, 0.01891127138930772, 0.029711172317287753, 0.08082883525639772, 0.02109383186325431, 0.02852970375014203, 0.0334165367031736, 0.05560921531702791, 0.03620130888053349, 0.03496742687587227, 0.022304362085248743, 0.035037394014320204, 0.013228929069425379, 0.06051384285092354, 0.04536852054297924, 0.044682487712374756, 0.06273007392883301, 0.04347328741901687, 0.03138093164722834, 0.04059575950460775, 0.02724081291151898, 0.018841953948140144, 0.015573842617283975, 0.00842156698594668, 0.07757286461336271, 0.024510394781827927, 0.013947516313887067, 0.05369106467281069, 0.04279689996370247, 0.03999143246827381, 0.023704435975689973, 0.07281214757157223, 0.030487080503787314, 0.017940739003409232, 0.006429652799852192, 0.053241226489522626, 0.03604488620268447, 0.02620866784958967, 0.024757596963484372, 0.05282341855178986, 0.021199328791616217, 0.014734988433441945, 0.013634828717580863, 0.03364990185946226, 0.01648620080335864, 0.05208347950662885, 0.004340040173181998, 0.0291998792173607, 0.08391868017081704, 0.05389618580894811, 0.014177941717207432, 0.009002497286668845, 0.03387366574523704, 0.052552411665341685, 0.035261771974286864, 0.06286795902997255, 0.07904189971408673, 0.05749366991221905, 0.02989548956975341, 0.06365911050566606, 0.04372232673423631, 0.06252958718687296, 0.03285204985045961, 0.05240676751626389, 0.055810733432216306, 0.021292970016864792, 0.018358584260568023, 0.08229640472148146, 0.02272196306980082, 0.024993476092017124, 0.04516124166548252, 0.0905424915254116, 0.021863266825675964, 0.004706459685361811, 0.029471432324498892, 0.021421167334275584, 0.031225007692618028, 0.019519745970943143, 0.011539038453650261, 0.06379375220941645, 0.047139591936554225, 0.05327670030029757, 0.04011211670669062, 0.09912944718130998, 0.045146598879780085, 0.02679210279269942, 0.04064143508938806, 0.025321574914934378, 0.03164068503039224, 0.05540546482162816, 0.012380378620166863, 0.038763216231018305, 0.045581088600946326, 0.06079419316457851, 0.03716305763061557, 0.0680737950439964, 0.06272984322692667, 0.07043855065213782, 0.0856695787182876, 0.07810704809214387, 0.09962548342134271, 0.036789300186293464, 0.04693374137527176, 0.0099527270566406, 0.01656756054476968, 0.030095993275088922, 0.027088892313518693, 0.006811438585698072, 0.063099169837577, 0.02641805527465684, 0.041356424401913366, 0.027738699855815088, 0.04028913631503071, 0.06835048805390086, 0.051911935675889254, 0.005858813163026103, 0.0612156991181629, 0.02406812735301043, 0.024322527094877193, 0.048936101607978344, 0.007269145654780524, 0.08588242158293724, 0.013811348754513477, 0.024686898703553846, 0.004276757876920913, 0.04556283600894468, 0.016457483505031893, 0.026527928753889034, 0.04590585920959711, 0.019666043209976385, 0.04488385654985905, 0.0857109015009233, 0.026920235649283444, 0.07611297616469008, 0.05397436661379678, 0.042793839770768366, 0.011195237482232707, 0.05952635048223393, 0.07480246041502271, 0.0504666662641934, 0.026273483210908513, 0.01115208604772176, 0.023384929102446352, 0.01751864781337125, 0.01839565941398697, 0.01425671115118478, 0.027007686938824396, 0.012943678884766996, 0.013144506590573915, 0.020890103420242667, 0.01927828080286937, 0.022246540723634616, 0.025622545907806073, 0.021341900873397077, 0.014242198983473437, 0.04263806848653725, 0.06996976437845401, 0.003706494570776288, 0.05924288569284337, 0.05063303287274071, 0.013880605975698148, 0.03212399534615023, 0.04940767666058881, 0.049969656326408894, 0.05076412923101868, 0.010623656545898743, 0.019700443239084313, 0.011368724467631961, 0.049554915366960425, 0.04347793199121952, 0.013107131185409213, 0.015382645019729222, 0.02455615179081048, 0.015510155320433634, 0.03168583135785801, 0.08641889172473124, 0.04315489503954138, 0.033835053710000854, 0.068888892020498, 0.04344084665977529, 0.02533113886602223, 0.05023967933708003, 0.06845269578375987, 0.03504068830183574, 0.01553553931548127, 0.022636036787714277, 0.033743838247443945, 0.0508900789011802, 0.027414826609726464, 0.042984185806874714, 0.02343130866730852, 0.031884601406220875, 0.06041138406310763, 0.03155873157083988, 0.013192131267195302, 0.017353909688868692, 0.03942667759422745, 0.061748552668307505, 0.01348604804037937, 0.04725190305284091, 0.029055738023349216, 0.05089315266481467, 0.013368064371336783, 0.03068718726613692, 0.04314995191193052, 0.01942257975627269, 0.009888938827706235, 0.0644070121592709, 0.025080416783956543, 0.012420709893506552, 0.030124909044908624, 0.0677960231634123, 0.03571155587477343, 0.012261420405203742, 0.042850880817111046, 0.03140598316011684, 0.036082344728388956, 0.03045936574095062, 0.02963760894324098, 0.03706223411219461, 0.014349670448739613, 0.034259572359068055, 0.020768879746486033, 0.022773253531860452, 0.054588471339749436, 0.016295741112636666, 0.03862974500017507, 0.009801742836966046, 0.012631056597456336, 0.01446928090548941, 0.015801874488326054, 0.03162040701135993, 0.03154896066657134, 0.05491715031010764, 0.04685106866859964, 0.03266662658591356, 0.06026587901370866, 0.03420084176052894, 0.042122537935418744, 0.029678629777793373, 0.024250285167779242, 0.03634961288688438, 0.022641673717381697, 0.03702195627348764, 0.044064291420259645, 0.02677038119041494, 0.03940730541944504, 0.08346713547195707, 0.04143179267910974, 0.07605875443134989, 0.020954252120905688, 0.03176856513268181, 0.046699202353400845, 0.022100128133648207, 0.02630848713618304, 0.009143190674616821, 0.04167856568736689, 0.03374307489554797, 0.038238131906837225, 0.01473750070934849, 0.03765498873378549, 0.028963901701250246, 0.008876125228458216, 0.020881438528054526, 0.04328498377331665, 0.05324024600642068, 0.03368720092943736, 0.043012847126062424, 0.028481018862554004, 0.06799209942775113, 0.03201983004276242, 0.04508972746719207, 0.054286435046898465, 0.11875040004295961, 0.025942266519580568, 0.029052050185522864, 0.02716877793760172, 0.018145436055159996, 0.047927466088107655, 0.05256005875500185, 0.03490861824580601, 0.01055061734015388, 0.06803186836519412, 0.033627442350344997, 0.04317947157791682, 0.024588597639064704, 0.048158839744116576, 0.011755449564329215, 0.015401701675727963, 0.027010804807235087, 0.016793617878907492, 0.04677364443029676, 0.0470456250144967, 0.059085696270423274, 0.01301531182668571, 0.09245788053210292, 0.01478858761090253, 0.02642129867204598, 0.012373587332798966, 0.04489761045468705, 0.011481058484475528, 0.02264540396364672, 0.014762223132752945, 0.03891858717958842, 0.056545189914426634, 0.0057018955786978555, 0.01171052800158837, 0.05173478714589562, 0.023642263508268764, 0.05048742265041385, 0.022407436643594077, 0.05455466333244528, 0.0895755859091878, 0.19097453595272132, 0.10453377504433904, 0.07473190634378366, 0.11842003491308008, 0.08746099937707186, 0.19568291758852346, 0.07764392758586577, 0.18682502289967878, 0.14536656040166104, 0.10798037331551313, 0.09688239025750331, 0.1097137045913509, 0.1792002163295235, 0.1642754857561418, 0.15573785959609918, 0.09219650884291955, 0.09301744800593172, 0.06577885390392371, 0.07364260658089604, 0.10452192103756325, 0.12164403977138655, 0.13187075672405107, 0.08750585054180451, 0.11929997269596372, 0.1524377909622022, 0.10977482702583075, 0.15986305395407335, 0.12527729624084064, 0.11507260453488145, 0.13070217014423438, 0.13946432354194777, 0.11373570734368903, 0.0997182595144425, 0.17163586722952978, 0.17117667544100965, 0.11393471487930842, 0.1122232595724719, 0.07677952825490918, 0.13629692207489694, 0.10094576328992844, 0.07788581853466374, 0.15192424851868833, 0.1930802065346922, 0.17601382945265087, 0.11522173296128001, 0.07864473281162125, 0.1983270871319941, 0.13454969440187725, 0.13752929094646657, 0.16596001679343836, 0.13578836007841996, 0.11545917950570583, 0.1480552689837558, 0.15715626919908182, 0.10348902789077588, 0.15406182381723607, 0.088120895038758, 0.14042990601488523, 0.06788504017250878, 0.09655986220708915, 0.1266417894512415, 0.16924793965050153, 0.07651063161236898, 0.09387116719569479, 0.17752460124237196, 0.1310950962028333, 0.1591087808566434, 0.1257773765495845, 0.12661950636122907, 0.08662865404039621, 0.240205956356866, 0.1443195537264858, 0.1553297343530825, 0.060779204326016564, 0.19016273665641034, 0.14011697923498495, 0.09290726748960358, 0.19162104411848954, 0.09923894237726927, 0.10624772057469402, 0.08550850807556085, 0.1483048613050154, 0.15121410733887128, 0.07420577707567386, 0.10452700326485292, 0.09299439817134823, 0.12076182211084024, 0.11799808112638337, 0.1723014558000224, 0.06635604971753699, 0.10405991332871573, 0.16072800968374523, 0.08585577551275492, 0.08341200450169188, 0.13013224144067082, 0.16402806474694184, 0.13164369176541055, 0.10680464854730026, 0.09180824431989874, 0.12773457009877476, 0.16939890012145042, 0.14466511804078305, 0.1601173553083624, 0.140730225614139, 0.13354322340871605, 0.14136929703610285, 0.21347454003989697, 0.15079469127314432, 0.1096339292292084, 0.16933059878647327, 0.1854094767144748, 0.1297571879944631, 0.1416699830442667, 0.08196057738470179, 0.10552497899958066, 0.18123561782496317, 0.09353738224932126, 0.1000274611370904, 0.11502096801996231, 0.14035477861762047, 0.14329552224704198, 0.16869599212493214, 0.0925132150628737, 0.12089568349931921, 0.13766339660755225, 0.09919768744813544, 0.09685900115541049, 0.12325178778597287, 0.12433531321585178, 0.11873942134635788, 0.11041258887520858, 0.0806441040975707, 0.12957911326416902, 0.10807718669197389, 0.12720073945820332, 0.18865408189594746, 0.22578741290739604, 0.1967891196587256, 0.12271932778613907, 0.15531880993928227, 0.11558013515813009, 0.09681136121175118, 0.1376506672906024, 0.1385275245245014, 0.11547182739845344, 0.1447511969932488, 0.11949838990611689, 0.19868521791483673, 0.15243443899921008, 0.1520570513925382, 0.09278025251946279, 0.0946245107001492, 0.1542473624327353, 0.15137257240712643, 0.15193749352225236, 0.10283914740596499, 0.19749854159142288, 0.09274654968508653, 0.17942946617092403, 0.11394375296575682, 0.11376568502081291, 0.12410770542919636, 0.11977654855166163, 0.12473752163350582, 0.132696126720735, 0.10443411860615015, 0.1478668533797775, 0.15779405140451022, 0.09327683158751045, 0.16474319994449615, 0.20229464423443588, 0.2024531364440918, 0.22597090234713896, 0.18033582610743387, 0.1422201663787876], [0.02861654605450375, 0.02090264274738729, 0.03996488478566919, 0.0417925222510738, 0.025207918602973223, 0.03747453234557595, 0.01582726526872388, 0.01095651529197182, 0.05495269875973463, 0.03129514107214553, 0.05033841296764357, 0.03094186520736132, 0.05954636047993388, 0.01030375442600676, 0.01823681266978383, 0.07543931981282574, 0.022010044128234898, 0.01657729921862483, 0.04540235229900905, 0.059079338397298536, 0.055617466302854676, 0.08838198174323354, 0.0726081392328654, 0.0422057432920805, 0.03829639431621347, 0.03936963315520968, 0.03227184473403862, 0.030206292535045316, 0.08500496723822185, 0.03476348299799221, 0.03482607785346253, 0.04449760388316853, 0.04244407193203058, 0.03497581356870277, 0.05873296662632908, 0.031830087902822664, 0.035912388669592996, 0.010822415568067558, 0.007198050451864089, 0.014136544295719691, 0.06455771478691272, 0.014346510171890259, 0.05021876688780529, 0.014859908426712667, 0.005800350585819355, 0.016865932748519948, 0.014289599743538668, 0.030001639588070766, 0.06674134225717612, 0.0196582790730255, 0.03704544037048306, 0.0974771940548505, 0.045510330969201665, 0.005699940125590989, 0.043496795264737945, 0.06948458469871964, 0.027742752406213964, 0.03160296866138067, 0.02808176546490618, 0.05348912586591073, 0.02057286794297397, 0.00829055205187095, 0.08221330453774758, 0.015176813118159771, 0.020373110626158968, 0.021538460593936697, 0.05527227179014257, 0.02429279199402247, 0.10496990342757531, 0.07471632717975549, 0.00989893195219338, 0.03898254589044622, 0.06109057726072414, 0.09849302883126906, 0.025779463916218708, 0.09055283239909581, 0.018414726248010993, 0.034007242149008174, 0.006733258204933788, 0.030880583317152092, 0.032457902428827116, 0.07095341623893806, 0.025235543459919945, 0.007949189565676664, 0.057128563789384704, 0.03388901420735887, 0.05886273644864559, 0.04065367925379958, 0.032005757226475647, 0.043670272920280695, 0.03520287852734327, 0.09034216084650584, 0.032156761802200756, 0.019014999037608504, 0.014689742022060921, 0.043376172094472816, 0.033282492110239606, 0.058941242950303216, 0.037939803807863166, 0.04289784901110189, 0.028528913256845305, 0.01759693548748536, 0.02739389719707625, 0.0068047707068866915, 0.009423685176963252, 0.014035867510496505, 0.049930538782583814, 0.03938973814781223, 0.02696774497495166, 0.049898288013147454, 0.05246155921901975, 0.05727398741458144, 0.031169035338929722, 0.047390612574028115, 0.013048345455899835, 0.023679526955155388, 0.08197036864502089, 0.02011709088193519, 0.01474451506510377, 0.044437153198357136, 0.003371909589207332, 0.01602884954107659, 0.01542140293999442, 0.15597468188830785, 0.05036337287830455, 0.03722106558935983, 0.038667522437338314, 0.06289049996329205, 0.015589705069682427, 0.03426837295825992, 0.049324098109666786, 0.04963798162394336, 0.05917003817324128, 0.02050755385841642, 0.03644528293183871, 0.04828276059457234, 0.026283386429505687, 0.028911637541438853, 0.0758607986250094, 0.039034348646444936, 0.02634906692297331, 0.01228616912184017, 0.04813770677096077, 0.028047229728794525, 0.020793178085503832, 0.04605424803282533, 0.04317815521998065, 0.05810186120548418, 0.018235609966463277, 0.04928472611520972, 0.027605425400127257, 0.0523805082110422, 0.049151183638189516, 0.02407526214873152, 0.022837371698447635, 0.045445490162819624, 0.10664095875940152, 0.02127773012034595, 0.036524403507688215, 0.038255641502993445, 0.03130350401625037, 0.05962570836501462, 0.10052838282925741, 0.01695158252758639, 0.04356021454025592, 0.04216682930876102, 0.1059173418741141, 0.022169664402359297, 0.047584405568029196, 0.060978347568639686, 0.07076027803122997, 0.026090850421626652, 0.03224842509786997, 0.03524758041437183, 0.04895863914862275, 0.04335116468636053, 0.0038139019993000795, 0.0440017101354897, 0.03661534416356257, 0.015292315045371652, 0.04592490229489548, 0.12447993616972651, 0.0539554287014263, 0.03685174576405968, 0.06046378732259784, 0.042754237074404955, 0.012026942451484501, 0.02816079613486571, 0.01612270450485604, 0.009104513330385089, 0.009886211116931267, 0.008173878803583128, 0.006589855765923858, 0.03497286872672183, 0.061116069821374755, 0.008411115850321949, 0.03129252531964864, 0.05904695192085845, 0.04246155099411096, 0.03240058318312679, 0.065371162923319, 0.008328450777168785, 0.008579106702070152, 0.03411035233044198, 0.06814334488340787, 0.01715365025613989, 0.05464031480784927, 0.010749389084854295, 0.04111868608742952, 0.07438835049314158, 0.011421883445499199, 0.019950491875143986, 0.08190804520355803, 0.03509012297061937, 0.1027950154883521, 0.01857166800514928, 0.04084846630160298, 0.02562518371269107, 0.029422516735004525, 0.04995294740157468, 0.043818169805620394, 0.05642550312248724, 0.027932737122422883, 0.02561321944397475, 0.03188568027690053, 0.022896996266873818, 0.043914233400885544, 0.007065485489355134, 0.044242885229843, 0.016989202205357806, 0.0544212124576526, 0.01588060660287738, 0.05467163259163499, 0.03714785844619785, 0.029056742255176817, 0.017675553947421055, 0.05057281967518585, 0.025131741172767112, 0.026601110451987812, 0.049904964797730954, 0.0567699139272528, 0.05670843865456326, 0.10147250323955502, 0.03302601944389088, 0.0312173911370337, 0.048673501770411215, 0.019810834101268222, 0.020428377303427885, 0.05119709224839296, 0.02928901497008545, 0.01492311226736222, 0.02860314159521035, 0.035487123632005284, 0.053089075189615996, 0.05061813224373119, 0.04650013714230486, 0.013788628009414034, 0.04502087991152491, 0.010077036368394536, 0.01863451731125159, 0.06480585504323244, 0.04606512834184936, 0.03449499347646322, 0.031399269056107314, 0.018877943445529257, 0.018646418815478683, 0.020531624888202975, 0.044693873529987674, 0.03410937863269022, 0.04564975295215845, 0.022651736391708255, 0.04749923585248845, 0.025500073729615127, 0.014703534942652498, 0.03366491783942495, 0.03044173740116613, 0.022385815125224844, 0.008465587793450271, 0.02163075323083571, 0.03116748488641211, 0.008830220638109105, 0.025991085417834774, 0.01964934785584254, 0.0207611902483872, 0.03941036221970405, 0.03944202944902437, 0.03396398214889424, 0.03355611474918468, 0.04346898550699864, 0.03334878837423665, 0.0567225250415504, 0.041977382331554375, 0.0633281007675188, 0.07719792651810817, 0.025480143459779874, 0.08417827409825154, 0.01947751734405756, 0.047710884495505264, 0.04360257887414523, 0.029414869645344358, 0.02077917821173157, 0.10209850607705967, 0.015561912275318588, 0.041601528214024644, 0.03470179059409669, 0.09010490429188524, 0.06413996791733162, 0.011955514766408928, 0.011773016835962023, 0.04943070274644664, 0.05627311433532408, 0.029004688441221203, 0.036079298106155226, 0.029895713486309563, 0.016510577173903584, 0.029494906243469034, 0.008954290766268969, 0.04544333242146032, 0.06477988750806876, 0.024749980407900045, 0.033616758816476376, 0.013117914803193083, 0.017039819221411432, 0.06740894607667412, 0.006972087264460112, 0.057721949448542934, 0.009323720853509647, 0.06514768062957696, 0.048550581759107966, 0.025323690247855017, 0.053713551323328695, 0.037321722866701226, 0.026354440920321003, 0.0043574679210515955, 0.04485181273360338, 0.01943912752903998, 0.02250026023414518, 0.07237031270882913, 0.028709939614470516, 0.02897193216319595, 0.009606112709401973, 0.0380958702548274, 0.07403225531535489, 0.027338922289865356, 0.052804867404380014, 0.042250499461910555, 0.024985961316685592, 0.013167129796264427, 0.027912036715341464, 0.028590456383036714, 0.00993299949914217, 0.031577035052967925, 0.1126868346972125, 0.07996609155088663, 0.09286577507321324, 0.13615540681140764, 0.135770460324628, 0.19588752303804668, 0.1836291772446462, 0.10553295178604977, 0.16893756416227135, 0.11924668055559907, 0.13122335289205822, 0.07266475619482142, 0.13897357987506048, 0.14782217863414968, 0.07248765855495419, 0.1983466153698308, 0.0946592449077538, 0.10690845761980329, 0.11504611452775342, 0.14108710789254733, 0.12100981308945588, 0.18099595925637654, 0.1326459694121565, 0.18624674821538584, 0.1604356967977115, 0.14381935128143855, 0.10386774542608432, 0.1254276324595724, 0.14116370092545236, 0.0883199500718287, 0.1137535935267806, 0.13548444424356731, 0.17264099472335406, 0.1612856297620705, 0.07942344674042293, 0.08428546906049762, 0.13232146682483809, 0.1221280252294881, 0.19488855664219173, 0.09700293878891639, 0.0940029386963163, 0.10329179133155517, 0.15959947024072918, 0.10115273682666676, 0.19968761769788607, 0.11736282307122435, 0.062145488868866644, 0.12133871258369514, 0.12693957132952555, 0.15131111070513725, 0.18099008314311504, 0.1425907550645726, 0.14504969811865262, 0.0831717691783394, 0.10934074103300061, 0.10104334341096026, 0.13481614153300012, 0.11138455636267151, 0.10721167456358671, 0.10757355764508247, 0.12481224190975938, 0.05581213799970491, 0.17767021485737391, 0.11296722572296858, 0.16530733395900044, 0.14958556901131356, 0.20383498658026966, 0.0881834966795785, 0.16940495265381678, 0.14187112796519483, 0.1120455376803875, 0.1505410141710724, 0.12293998737420354, 0.13296429733080523, 0.13260023615189961, 0.17148764804005623, 0.10186979227832385, 0.15956224580960615, 0.08126889235739197, 0.1156472015593733, 0.11899122569177832, 0.1835235022008419, 0.07435632364026137, 0.11660857711519514, 0.16831966303288937, 0.09279524135802474, 0.14893560031695025, 0.12576063030532428, 0.11607134022883006, 0.15046256195221627, 0.16187320037611894, 0.16787182992058142, 0.11236744147858449, 0.14533994825822966, 0.11989341942327363, 0.11938374462936606, 0.13288424376930508, 0.08238557779363223, 0.12996213271149568, 0.15890680812299252, 0.15503442234226636, 0.15099792608192988, 0.12585029192268848, 0.10265656720314707, 0.08808717184833117, 0.11199935658701829, 0.17377687591527188, 0.07909878809005022, 0.1221622641065291, 0.09989023421491895, 0.16468988066273077, 0.08246241509914398, 0.0970720611512661, 0.09332797277186598, 0.15456699313861982, 0.11109862170581307, 0.1983403457062585, 0.12124417908489704, 0.1381261982023716, 0.21090616285800934, 0.24672768211790494, 0.1638326873736722, 0.0688410485163331, 0.2403207373406206, 0.13949489832988807, 0.23236521280237607, 0.11030546176646437, 0.2381496424121516, 0.18617196008563042, 0.142581418422716, 0.12489644810557365, 0.10036611796489783, 0.1704875145639692, 0.127875718953354, 0.10984979157469102, 0.23381825483271054, 0.08411191337342773, 0.09309259575924703, 0.1302519893007619, 0.06785314224128212, 0.09018418432346412, 0.125398509736572, 0.1352017665547984, 0.13209008638347897, 0.11746748031250068, 0.08119361568242311, 0.089982930836933, 0.1820351899202381, 0.10750151758215257, 0.12763186703835214, 0.17439147936446325, 0.1716455024267946, 0.13748853813324655, 0.07348013137068067, 0.0722768445100103, 0.13275301509669848, 0.1705692508923156, 0.09133629607302801, 0.12796835255409988, 0.10902713571808167, 0.14469851553440094, 0.1998136487922498, 0.14359182491898537, 0.10519892256706953, 0.12179225896086011, 0.1279973667114973, 0.20340270549058914, 0.1129324711593134, 0.14081994151430471, 0.12601607159844466, 0.22707310106073106, 0.12400644086301327, 0.12255394166069371, 0.09114125796726771, 0.128114698986922, 0.09790694420891148], [0.023456034483388066, 0.004633308097254485, 0.06486582396818058, 0.024521826400554607, 0.05667787404464824, 0.027801549161917398, 0.03117191232740879, 0.016447361458891203, 0.059023569604115825, 0.025358119114701237, 0.022703973410118903, 0.04125365688066397, 0.05485129848654781, 0.03522779094055295, 0.0719154839004789, 0.0676014803882156, 0.09042413466210876, 0.03171867923811078, 0.05036975789283003, 0.02777643997355231, 0.013858274540065654, 0.02693638817540237, 0.022690843757508055, 0.012148122868633695, 0.04569064825773239, 0.03057454706036619, 0.0732908540272287, 0.011014511376353247, 0.0483037646460746, 0.05634237579735262, 0.040354669227131774, 0.11819211500031607, 0.021475356837202395, 0.07038791158369609, 0.028478043486497233, 0.040237187674002986, 0.01559547770635358, 0.04534580658322998, 0.044234495144337416, 0.05212380823546222, 0.056296978411929946, 0.09840485999094588, 0.06350597872265748, 0.07915273840938296, 0.05487584449084742, 0.04401835799217224, 0.004911163098378373, 0.06358082792056458, 0.07755330923412528, 0.021154674402038966, 0.04557831339272005, 0.04062606966389077, 0.03771530371159315, 0.03899261195744787, 0.026377212555546845, 0.0023448410294284777, 0.08040676611874785, 0.035596242241029225, 0.06852253060787916, 0.02182151486964098, 0.07565191840486866, 0.06228500923940113, 0.0628540287060397, 0.034971223279301605, 0.033676883804478815, 0.02488438462439392, 0.027241572870739868, 0.03829750032829387, 0.05160311742552689, 0.043661570708666525, 0.03922454879752227, 0.027326428763834492, 0.02755184148970459, 0.04785602992134435, 0.051751818374863694, 0.04122559606496777, 0.04869152705318161, 0.04787350559074964, 0.041303627592112334, 0.09438264010740177, 0.05341915533478771, 0.005634677355244223, 0.044355474545487335, 0.04774726075785501, 0.036955076469374556, 0.0819281976936119, 0.027195094918299998, 0.11142227612435818, 0.0316411566122302, 0.10664245153644256, 0.0690430687474353, 0.02237194247676858, 0.02607579542590039, 0.08248857262411288, 0.027944211149588227, 0.024372268800756762, 0.11213675992829458, 0.035392410321427245, 0.044069753627159765, 0.01785198662297002, 0.013687811276343251, 0.013849319574157042, 0.010396566990363811, 0.030971625753279244, 0.03318684581401093, 0.03869462991133332, 0.020048092352226377, 0.009550845183964287, 0.01594494190067053, 0.008833188380646919, 0.029035029134580066, 0.018217211489432623, 0.034341787054602585, 0.058856439643672535, 0.08463405285562788, 0.05533271908227887, 0.07338232733309269, 0.033497031312435865, 0.030272140965930054, 0.012865763556744372, 0.08839468391878263, 0.0629706010222435, 0.02291713179355221, 0.02745433261484972, 0.03458579842533384, 0.02231715077401272, 0.04036781245044299, 0.05490439724443214, 0.03998714751963105, 0.03833394444414547, 0.03785261545064194, 0.010429530221569751, 0.014419225377163716, 0.01598512304813734, 0.10280053876340389, 0.04305541502045734, 0.0696555415966681, 0.022974340777312006, 0.01679397580612983, 0.1187563304390226, 0.015444512146392038, 0.01488317539250212, 0.03445543488487601, 0.030656989065131972, 0.05753609870693513, 0.014091842408691133, 0.03325040418920772, 0.021429440372490456, 0.06052535759019, 0.02866085439122149, 0.022073778922536542, 0.011664341819206519, 0.01047762987270419, 0.04392192798799702, 0.046065216551401784, 0.018691244535148144, 0.022077694069594145, 0.033273175824433565, 0.025170003762468696, 0.06416072430355207, 0.005643480074858027, 0.034745498427322934, 0.03547987009265593, 0.021979099538709437, 0.01318795742866184, 0.10378447560859577, 0.023829359361635785, 0.02720073693698006, 0.01700445736891457, 0.007191524641322238, 0.037886338641068766, 0.019397358609629527, 0.05064231183912073, 0.031070043865059103, 0.029743144887366464, 0.042442552013588805, 0.04983458714559674, 0.017987155887697424, 0.04192881279491952, 0.03213948969330106, 0.021594293847946183, 0.07925640498953206, 0.020932635691549097, 0.03700040939397045, 0.033217308643673144, 0.06262883650405066, 0.021955690080566064, 0.04871464813394206, 0.03813116764649749, 0.017331938724964857, 0.019711086060851812, 0.05820936829383884, 0.05629049500982676, 0.05509972372757537, 0.013217736634292772, 0.01192065587799464, 0.0686177901391472, 0.01857950508461467, 0.027905853564984033, 0.09619126162890877, 0.059014294030410905, 0.02259173523634672, 0.07708382406937224, 0.0654870295631034, 0.0761926361758794, 0.06033934400017772, 0.02560548414476216, 0.09163557751370327, 0.08852851816586085, 0.017815969984180162, 0.09084213937499694, 0.1102628701233438, 0.033545614419771094, 0.0450989487580955, 0.03296901232429913, 0.022914724690573554, 0.029389577252524238, 0.006620543360311005, 0.0617171297115939, 0.057696545097444735, 0.06965155859610864, 0.021497933393610374, 0.008845814221006418, 0.007369425497017801, 0.04226363589987159, 0.015840932660337006, 0.036259934306144714, 0.024535566734682237, 0.02513086416625551, 0.04808720001684768, 0.05561816180124879, 0.026148393583883132, 0.05163451324083975, 0.05214641362960849, 0.023936861360977803, 0.04211824959410088, 0.06120076456240245, 0.03452192453135337, 0.08092491581503834, 0.03993068662072931, 0.020272047924143926, 0.028556651768407652, 0.013380795384624174, 0.022725774740268077, 0.04685371834784746, 0.020504600534747754, 0.034340874425002506, 0.024889539794198105, 0.034427804938916645, 0.028599884627120833, 0.1018899515537279, 0.021239749122677103, 0.06232276971318892, 0.018451560521498322, 0.015063904891056674, 0.052223698768232546, 0.06777709203639201, 0.013177051674574614, 0.03498822397419384, 0.03017689161268728, 0.0302971178399665, 0.05472322839445301, 0.006124956649728119, 0.08682196866720915, 0.0544592172040471, 0.01151383257404502, 0.020216806691938212, 0.05404804873147181, 0.018766594152631502, 0.027322859669636403, 0.009775464872031339, 0.016091999098924652, 0.08131231859858547, 0.07525014424962656, 0.016535587974690964, 0.041097417407269986, 0.013860683339381856, 0.033893445041030645, 0.023828702879005244, 0.031968115496316125, 0.025688762443938425, 0.04174802053187575, 0.0064078985430699375, 0.01200080443439739, 0.026518027231629406, 0.03552333365327545, 0.036954974689121754, 0.05848338109041963, 0.04549467716632145, 0.0826297350493925, 0.05580925761855074, 0.02102193429267832, 0.05012804336313691, 0.03515966263200555, 0.06026581794555698, 0.042066752178860564, 0.07208697005574193, 0.0288566897756287, 0.05287638160267046, 0.020964430146185414, 0.025303549632163982, 0.03693382814526558, 0.026563312658774, 0.05553252389654517, 0.003569787151978484, 0.028035718382203152, 0.029288160015961955, 0.01177212201790618, 0.01583403704820999, 0.005424868814381105, 0.059238895906933715, 0.026795179949008992, 0.02160399520237531, 0.005814383114089391, 0.01143196308320122, 0.05932570089186941, 0.021830434212461114, 0.06088676569717271, 0.004822837346832135, 0.0613219305606825, 0.017902683366888335, 0.0503854863345623, 0.02376510718438242, 0.0341234480563019, 0.047636893644396744, 0.025989638441907506, 0.0189152984946434, 0.009904950557808791, 0.03199871742565717, 0.027950928646272848, 0.04787185335797923, 0.04486350728464978, 0.02658346514882786, 0.01947682523833854, 0.029484405914055448, 0.04383425447823746, 0.02006444165350071, 0.034761175978928804, 0.032238555806023736, 0.047153681716216464, 0.02938670026404517, 0.02839887371685888, 0.025085156351061802, 0.02223900898492762, 0.06619862280786037, 0.033952782928411446, 0.03983182067583714, 0.025570570125377605, 0.07563576927142483, 0.0605352981282132, 0.026039476839027235, 0.06054115388542414, 0.14211398921906948, 0.06462812636579786, 0.11864860621946198, 0.103062446495252, 0.13026140736682074, 0.1977539693138429, 0.119488496865545, 0.09826001990586519, 0.13432679564825126, 0.11252272421760218, 0.15995863239680017, 0.14930475050849573, 0.13514557028455393, 0.09204136859625578, 0.18761357558625086, 0.1256359698516982, 0.2239943841206176, 0.1447416160787855, 0.06707383120166403, 0.16090151108801365, 0.15073567229722226, 0.05372917798480817, 0.10094173279191766, 0.16187093406915665, 0.12200054207018443, 0.08278507207121168, 0.14777275414339133, 0.1786677970417908, 0.3512092913900103, 0.08601625583001546, 0.09586418060851948, 0.19243192060717515, 0.12544703856110573, 0.11785014692161765, 0.1262035643947976, 0.20946739720446722, 0.10807675921491214, 0.15504039345043047, 0.11256791464984417, 0.11445367203227111, 0.09597517536686999, 0.21573218889534473, 0.17088922086570943, 0.1627127110425915, 0.12680478713342122, 0.085616469782378, 0.04418131156957575, 0.10942947305738926, 0.12353593111038208, 0.0996452695024865, 0.1557121024067913, 0.09812524928046124, 0.09528480669749634, 0.11558899682547365, 0.16088845607425484, 0.1387345048465899, 0.1785089112818241, 0.10523875257266418, 0.24119482615164348, 0.20323187751429422, 0.14359889525387967, 0.17338195496371814, 0.1486150196620396, 0.13238542553569588, 0.13132415605442865, 0.08738024013915233, 0.10839256976864167, 0.10970216949603387, 0.14134333628628934, 0.1576498355716467, 0.1277094507323844, 0.1810935190213578, 0.1442986684186118, 0.08112677319773606, 0.20604683432195867, 0.12113032090876784, 0.20691685192286968, 0.09063871457640614, 0.10461663774081639, 0.12094637006521225, 0.2208693910922323, 0.14345367518918856, 0.11684233242911951, 0.09021127144140856, 0.11842580246073858, 0.15510093234479427, 0.1459936217537948, 0.2638036943972111, 0.17394790745207242, 0.15075430486883434, 0.14210625391985687, 0.11232079219605241, 0.08178873839122908, 0.10036701363112245, 0.1308926892067705, 0.14827386582536356, 0.22906677265252384, 0.19437504134007863, 0.09245099340166364, 0.14925213690314973, 0.11244567656623465, 0.13453468520726475, 0.12951097477759632, 0.08628403288977486, 0.08201036828437022, 0.12712605989405087, 0.10706743158932243, 0.053828885313123465, 0.18063249518828733, 0.08432577404060534, 0.12169944894100938, 0.09588376312915768, 0.11573820667607443, 0.10961376316845417, 0.12413380188601357, 0.17971582151949406, 0.20166917065424578, 0.06426144604172025, 0.13609967194497585, 0.20309732402009623, 0.13562791368791036, 0.14676267334393092, 0.13998302285160336, 0.07891101030898945, 0.15386369159179075, 0.1016990253701806, 0.09157256875187159, 0.14615963213145733, 0.1233357632798808, 0.134217483656747, 0.0951245299407414, 0.09223582994725023, 0.06768192750002656, 0.07159806521875517, 0.20706812451992715, 0.11883628900562014, 0.16142346736575874, 0.07896208363984313, 0.09648065681436233, 0.1095758466316121, 0.08699357695877552, 0.1998971357409443, 0.13689051807991096, 0.17305462967072213, 0.10663408519966261, 0.12621452952069895, 0.07716726352061544, 0.0641240698418447, 0.1687420103698969, 0.07739734796008893, 0.10906609041350228, 0.08668582740106753, 0.05051459458523563, 0.1529387126543692, 0.10338751905198608, 0.12208803237548896, 0.039987103414854834, 0.11058617170367922, 0.09029876174671309, 0.18876870003129753, 0.07895348660115685, 0.1731026428086417, 0.1723687664738723, 0.1457780511783702, 0.18080348601298674, 0.29296246117779184, 0.050366633239069154, 0.10291192707206522, 0.10683899598994426, 0.12934067605861596, 0.1511409341224602, 0.13316690788737365, 0.13300705860768045, 0.09110982143985373, 0.19227619682039532, 0.097833791348551], [0.030256758577057292, 0.005699046579788306, 0.09142555056938104, 0.04905299283564091, 0.055965480128569264, 0.04975082878289478, 0.02335238317027688, 0.021549966851515428, 0.06082308518567255, 0.037385250707822185, 0.03398865707484739, 0.02733195712789893, 0.05182158873815622, 0.0560849938940789, 0.07768602389842272, 0.04917184842218246, 0.04276533451463495, 0.06457423032926661, 0.04897348888750587, 0.03919249480324132, 0.02223996232662882, 0.08523925180946078, 0.03712796040677598, 0.06982043239154986, 0.004905119047699762, 0.06558950870696988, 0.04111942908327494, 0.039654163244579516, 0.045456733488078625, 0.02440385121319975, 0.027262117214766995, 0.037767432164400816, 0.043635643885603974, 0.03288819541090301, 0.03584733412468007, 0.09093212668917008, 0.029360946467412368, 0.0203823828071888, 0.03788449302581804, 0.011572985560633242, 0.028520068552877222, 0.03867829418075936, 0.008355561643838882, 0.02402530500798353, 0.005877904169860163, 0.04371837426775268, 0.04194902974580016, 0.009296814395513917, 0.02271699788980186, 0.06146333047321864, 0.06973232461937837, 0.016304348329348222, 0.011968681738445801, 0.024883529670270424, 0.05564125913328358, 0.02328279092242675, 0.03054007069606866, 0.030204514773296456, 0.06330476594822747, 0.06305602858109133, 0.046459652350417206, 0.023234830370971134, 0.036391559921737225, 0.01027087855618447, 0.02367033959100289, 0.059085852333477566, 0.031487292011401484, 0.0280366988653051, 0.03074328854147877, 0.01864961301907897, 0.038440549080925326, 0.03815584935780082, 0.03480948427958148, 0.01725993598146098, 0.051298628228583505, 0.041872419749519656, 0.03729064257017203, 0.030788936984858344, 0.03296346530052168, 0.04356312884816101, 0.06517431991440908, 0.033179636379437785, 0.013060843222774565, 0.04391377878242305, 0.04147133769999657, 0.0010745993017085961, 0.08488996233791113, 0.0296740971638688, 0.012239551221552705, 0.00808272949819054, 0.07992467377334833, 0.08982863875904254, 0.08031231404415198, 0.06143521876739604, 0.0299141696388168, 0.03756024149645652, 0.04180911921762994, 0.05510604088859899, 0.02534101324688111, 0.020708968497014472, 0.03603476585288133, 0.11107637254255158, 0.03945852802800281, 0.02572259759264333, 0.012211451390092927, 0.01803737596076514, 0.009345308445127947, 0.018263007514178753, 0.03009934863075614, 0.044272676309836764, 0.02886809255661709, 0.052535068310265026, 0.05019504191087825, 0.042084051429161, 0.02336327705000128, 0.00029757569375630865, 0.02381507619949324, 0.046918620222381184, 0.007664404177506055, 0.03367792196305735, 0.02748025095622454, 0.02493028242939285, 0.020657569469351853, 0.06026639470032283, 0.022116311193842973, 0.022106370655819774, 0.07234406697430781, 0.020679367406825935, 0.048483620530792644, 0.024377600389665792, 0.029811636212148836, 0.04985140463603394, 0.012910016762491847, 0.028871593797313314, 0.07035436481237411, 0.025718896184116602, 0.05909138239387955, 0.019172385235184004, 0.04048978590539523, 0.034009091156933985, 0.05231728571067963, 0.06743739026465587, 0.025412110146135092, 0.018389684913147773, 0.028577764385512898, 0.0299586001118379, 0.04221324449671166, 0.01025544697352286, 0.02691058348864317, 0.08878782032323734, 0.06435659022203513, 0.03011193884802716, 0.05280225504455822, 0.06267853240881648, 0.09404332510062627, 0.06936264517051832, 0.048096336490873776, 0.022636499887864505, 0.028550008910575082, 0.060269590600260665, 0.02242443903482386, 0.02723860428003328, 0.019021784387794987, 0.0108803921445672, 0.034693176592034955, 0.03356204853792276, 0.03454550023057631, 0.013797503247457956, 0.020264514489099383, 0.02299210991311286, 0.024308897022690092, 0.06913565485072987, 0.03585687432704227, 0.039716948089855056, 0.029750479850918055, 0.060338244773447514, 0.018387333789308156, 0.07648062679384436, 0.06391613278537989, 0.022136236374665583, 0.016620255574317913, 0.04388203691425068, 0.02721118807260479, 0.012790160336797791, 0.048653939605823586, 0.056801143501486094, 0.05142220302617975, 0.012658201390877366, 0.04497726368052619, 0.023060932023716823, 0.022273286877732192, 0.08491257791008268, 0.06327963301113673, 0.04820428462699056, 0.022590203443542123, 0.010970183531753719, 0.027815084239201884, 0.021680120046117475, 0.0731021398678422, 0.026738927699625492, 0.05452879418485931, 0.026351811597123742, 0.043453867746783156, 0.039362722276044745, 0.03777486212285502, 0.04057428047859243, 0.03989838835384164, 0.05711247572409255, 0.058063082929168425, 0.01852418073186917, 0.06412029040179082, 0.08533255715987512, 0.0417227892072073, 0.03761688559981329, 0.0637767141950982, 0.049350024932729344, 0.022312915019158806, 0.012654361730840589, 0.03871528451730098, 0.054665227221058946, 0.010321784797789795, 0.028117405516760688, 0.03389909723773599, 0.04903952391552074, 0.024493641752217497, 0.05569435789116791, 0.022423835138657262, 0.042096234525420835, 0.050932260030614476, 0.041977219483149905, 0.03584133926779032, 0.022341550893283317, 0.016174904203840663, 0.02733838963987572, 0.03393939882516861, 0.0443722615018487, 0.06300560664385557, 0.011829180027624326, 0.049375337681600025, 0.010055523415628289, 0.0631607197491186, 0.002783786605245301, 0.023546725777643066, 0.040599871426820755, 0.04504386189260653, 0.059779973301504336, 0.08090055640786886, 0.026956013104479228, 0.017205327483160154, 0.008020184684677847, 0.08935382709439312, 0.030281101020851305, 0.049349393895162005, 0.06393135911119835, 0.011006864286693079, 0.03250520310497709, 0.0297515621142728, 0.021211259133581604, 0.0818535452708602, 0.02988837513008288, 0.02784739268411483, 0.08806126538131918, 0.021548341760145764, 0.012244936245094453, 0.029895391182175705, 0.00598993496636727, 0.1005026324252997, 0.03774561047820108, 0.04641524223344667, 0.08530456080500569, 0.05820682378751891, 0.03349724505096674, 0.016781616290765147, 0.06350446558956589, 0.03624628218156951, 0.014549614362684744, 0.03542336169630289, 0.07558293174952269, 0.01475724098937852, 0.0528620543357517, 0.05067981107692633, 0.012169544219172426, 0.02969604777172208, 0.042338685265609195, 0.03252671605774334, 0.06154596246778965, 0.015786661733207957, 0.038741442042269876, 0.06569613369980029, 0.012880248583054968, 0.018393550866416523, 0.023260551937190548, 0.023870371714500443, 0.03553923172876239, 0.017895129575793232, 0.08276716553206954, 0.04162156196045024, 0.03971569619274565, 0.05849222918706281, 0.0684579001473529, 0.028712192350732427, 0.019962792018694536, 0.049010129778512886, 0.07192984170147351, 0.0361871953521456, 0.03909565428537982, 0.02103153895586729, 0.013562434120103717, 0.046789281269801516, 0.025678635308785096, 0.06506950661007847, 0.024882981753242866, 0.033464872145227025, 0.05892587413213082, 0.03811990735786302, 0.02873579179868102, 0.02260371477210096, 0.07095684962613241, 0.03627544900934611, 0.01663353280829532, 0.01626380586198398, 0.0279241434764117, 0.02094257962224739, 0.03553398326039314, 0.012252396737624491, 0.08125301463795559, 0.06139295282108443, 0.026560479775071144, 0.05524537805467844, 0.01758419259983514, 0.05188100465706416, 0.04142367400761161, 0.056743976926164966, 0.06182130519300699, 0.019680083795849766, 0.031403818633407354, 0.028087921473862867, 0.03515445487573743, 0.05856225400098732, 0.04829109639727643, 0.04405724822676607, 0.006101229128294757, 0.031475468538701534, 0.05020299094862171, 0.04027608469394701, 0.060154965679560385, 0.037827591079154184, 0.0645959230938128, 0.0592147536309702, 0.035836545417883565, 0.04479787598497101, 0.06130451935210398, 0.11115967628679105, 0.21454005715038094, 0.1322357271398817, 0.11382536896105323, 0.11741486670715467, 0.19359682952719076, 0.12412494021867003, 0.10230385791510344, 0.17649720422923565, 0.18858199433556624, 0.0929385411686131, 0.09851789035435234, 0.12142681357051645, 0.11140510918838636, 0.1784417905977794, 0.1798091200845582, 0.12022409667926175, 0.1254865564405918, 0.12223055187080588, 0.13703219619180473, 0.17057671477752073, 0.17571618328137056, 0.13944364179457935, 0.14473130234650203, 0.07545528574181454, 0.12942759639450482, 0.17009795403906278, 0.11391970568469592, 0.13211334656391824, 0.09625642134674958, 0.10848571905600173, 0.1614390601004873, 0.13803735082702978, 0.10318000268723283, 0.13974881970456668, 0.27744935931903975, 0.1280160535659109, 0.1168193979454892, 0.15455026046505996, 0.09436340363962309, 0.13648191786238126, 0.07094604056328535, 0.1191164425441197, 0.16897231872592652, 0.09495876383568559, 0.12178186380437442, 0.14188566218529428, 0.10271973202803306, 0.053910431651664634, 0.11650039149182183, 0.11273223547531025, 0.07368294548775468, 0.1992507225700787, 0.10403505859098264, 0.14840950497559138, 0.13054207659193448, 0.09427028149366379, 0.1373345921082156, 0.15845497165407452, 0.10661613794841937, 0.11259246404681887, 0.1186798188303198, 0.16009101457893848, 0.11321732016014201, 0.11152947108660426, 0.13484704201774939, 0.0874992348253727, 0.11802409615899835, 0.16968658539865697, 0.14107634632715157, 0.15048446506261826, 0.1650100541966302, 0.0642404860949942, 0.11595769918390683, 0.1943369483841317, 0.16123365397964204, 0.09208118503115006, 0.11483574153057166, 0.14420885752354348, 0.09814592424247946, 0.10906238561230046, 0.11703279720885412, 0.15293261940990174, 0.11422287513102804, 0.07786175768290247, 0.19568498033498014, 0.15579549436058315, 0.1947191400187356, 0.14872323242681368, 0.08713090566119977, 0.19538776842611177, 0.14616419188678265, 0.1419012684907232, 0.14960169100335666, 0.09159332513809204, 0.1562471001275948, 0.1275448381368603, 0.14171263575553894, 0.09900305646338634, 0.08475124942404882, 0.1351744080228465, 0.2247806162174259, 0.14660737024886267, 0.18609035946428776, 0.11055745610169002, 0.08428751145090375, 0.12411535930420671, 0.12711672325219425, 0.12776609483574117, 0.1463727056980133, 0.16028165577777795, 0.10064080929649727, 0.19256540201604366, 0.11533708391445023, 0.10640227728124176, 0.07030831942600863, 0.12747344268219812, 0.14493989758193493, 0.12152961162584168, 0.10988262588424341, 0.0896740820524948, 0.12016887749944415, 0.10196654458663293, 0.11987045779824257, 0.1303911025502852, 0.11210046509014708, 0.20818701519497804, 0.15466707705387048, 0.13693209870585374, 0.10350922109293086, 0.13722438445048674, 0.11591717707259314, 0.10586249588855676, 0.1635167614689895, 0.1436997391283512, 0.06811842229217291, 0.17209151706525258, 0.21967157322381223, 0.09293267184070178, 0.15946628738726887, 0.20774888513343676, 0.15958835583712372, 0.10345898914550032, 0.05035757818924529, 0.08093581308743783, 0.1542879252561501, 0.07618506372507129, 0.11585135917578425, 0.13321963005832263, 0.21921958747719014, 0.22637594704117092, 0.15336039502705845, 0.1757037796612297, 0.16757471300661564, 0.11941088603011199, 0.17297118343412876, 0.11085064429789782, 0.15360560401209764, 0.14816513737397535, 0.18131018882351263, 0.09725512989929744, 0.11459753502692495, 0.1286065283098391, 0.08911653661302157, 0.11441024579107761, 0.07183215980018888, 0.10161415421004806, 0.09915246308914252, 0.11922758658017431, 0.14640440685408457, 0.13308154818202766, 0.2013312873563596, 0.12716112658381462, 0.12269308205161776, 0.06460484582930803, 0.15127708895930222], [0.07366422470659018, 0.04152304885376777, 0.018641054996156266, 0.10990997084549495, 0.02392589284240135, 0.017601252666541507, 0.039453394910586734, 0.03478739457204938, 0.020179568690114787, 0.051325644100350995, 0.03642632805609277, 0.015010214111368572, 0.046498688470040045, 0.015496038399370653, 0.007564262586778828, 0.05073999034773026, 0.01151740675725575, 0.03932789646621261, 0.011292592838539608, 0.0213053414065923, 0.050704102630593946, 0.050448128687483926, 0.015589699980669787, 0.030912762840411494, 0.02725700954241412, 0.059131551666983535, 0.00784024059040738, 0.020654331160975353, 0.052847129958016534, 0.03920059651136398, 0.05551873606496623, 0.051161445411188264, 0.05952082720718213, 0.062024845342550955, 0.054607382110719166, 0.03983748644324286, 0.027714040196899856, 0.013538712535851767, 0.022021211118304303, 0.017405919398048093, 0.038031222830925665, 0.05096281785517931, 0.02014417291086699, 0.04528101666697434, 0.019265498899455582, 0.015683885730270828, 0.02775712886692158, 0.05759366561791726, 0.01993767434864172, 0.029104070072727542, 0.008096209444504763, 0.03180786927363702, 0.007361589265721185, 0.024220473731734922, 0.03638417406805924, 0.015192560219605054, 0.01814141743151205, 0.012840238765680363, 0.0595068900978991, 0.011604542528013033, 0.04798933830378311, 0.023236272257885764, 0.046163543060954125, 0.030627296372715915, 0.025441385539514676, 0.09217869051332984, 0.0208233406634203, 0.04894823381411178, 0.03445948234626225, 0.04872061584943107, 0.008620979946239718, 0.006208450383772808, 0.06509979641331093, 0.010100639209018221, 0.04989662220967667, 0.02219981510591294, 0.03356879996135831, 0.0409825957114143, 0.045982937395040474, 0.03806328021788171, 0.02609547463777874, 0.037722323156361065, 0.05185148159840277, 0.04540475770565016, 0.07016314007341862, 0.026772420188145976, 0.038315545967114825, 0.02641721219489617, 0.027760053352851952, 0.07017314846494369, 0.01736048299686185, 0.02062945267451661, 0.052374163908617835, 0.01420865984567042, 0.04296263553468244, 0.019016669930091927, 0.04097733027966959, 0.012544139654242566, 0.007400686453495706, 0.0056001768181366575, 0.03644364426976868, 0.017331748735159636, 0.05511355905660561, 0.0024243846294536653, 0.018380144710785577, 0.02727979135566524, 0.01693807459170265, 0.04334744292178324, 0.03596942632326058, 0.053947605192661285, 0.012367466098761984, 0.019819551579920307, 0.06120875770492213, 0.05249076336622238, 0.041109858346836906, 0.047963611648551056, 0.061777180060744286, 0.010758816480769642, 0.04156862944364548, 0.014766998322946685, 0.007716863416135311, 0.09401698437120233, 0.036096556644354544, 0.02652169980241784, 0.045288066645818095, 0.041284340234207254, 0.02054952464199492, 0.10188755632511207, 0.03256933484226465, 0.07599912477391106, 0.03759939296703253, 0.007246030511201492, 0.015851661995319382, 0.05983363863612924, 0.04855277681989329, 0.05822126979806593, 0.02337028462040637, 0.04884481829191957, 0.019440364159111465, 0.04365393379703164, 0.07138929356421743, 0.038612225225993564, 0.019959234798859273, 0.04205356824344822, 0.04840521580938782, 0.01096047624014318, 0.08453816907214266, 0.049349315863634856, 0.08888891525566578, 0.019224028535453335, 0.05569746558155332, 0.024418156427730407, 0.06114758777299097, 0.02029722326967333, 0.014656653261876531, 0.0395618994454188, 0.025718344874413948, 0.0403501875033336, 0.02970821051193135, 0.03401338289092694, 0.05296210432425141, 0.025121770100668073, 0.03392945150179522, 0.010259604696849627, 0.022883915808051825, 0.024318861309438944, 0.05439892258229, 0.049309916727777035, 0.05779497338724988, 0.0084510637513761, 0.05484597537932651, 0.03588818193280271, 0.03736920674730625, 0.024557208609102026, 0.04777497212801661, 0.035681568019624264, 0.03174931848687785, 0.05366536515897938, 0.027890184495065893, 0.05818773659744433, 0.005508149233979306, 0.0380769425204822, 0.05705330068511622, 0.015946573777390376, 0.023374596710449884, 0.05407135301668729, 0.03409605559759906, 0.04003870600302305, 0.004859433284894164, 0.005415690780085112, 0.05216876796579786, 0.02059113240933844, 0.04140418987455113, 0.04626021394506097, 0.008113529899024537, 0.01157295417838863, 0.03066742154104369, 0.010859894449822605, 0.03935908193566969, 0.007584108887905521, 0.025021682792742337, 0.018994188368586556, 0.016382232275126234, 0.02789770775208516, 0.030466517500047172, 0.016642565805731074, 0.0475403754306691, 0.0843329732971532, 0.053773303117070875, 0.05488136098054903, 0.05387466946350677, 0.04110640799626708, 0.009279448988049157, 0.013556885399988719, 0.05125777702778578, 0.05758758594415017, 0.013718587928451598, 0.05029424712327974, 0.014313679255012954, 0.07293334071125303, 0.04960002776767526, 0.0853694151820881, 0.03885968694729464, 0.04129806360495942, 0.05533325851761869, 0.04088538878464273, 0.019823997680630003, 0.03295053242306624, 0.0198104439436325, 0.04152264851810677, 0.037764063238033226, 0.018669321068695614, 0.038416260919932804, 0.0451953414428447, 0.025428595154413154, 0.017346829175949097, 0.052026540240538974, 0.018113215819799473, 0.042864515978310785, 0.06356994421886546, 0.045489150498594554, 0.0276603765586125, 0.03196073642798832, 0.07900184579193592, 0.032529399663742097, 0.04110085079446435, 0.01655181683599949, 0.05513584893196821, 0.04742452236158507, 0.06991919316351414, 0.011071749197851335, 0.06884203239211015, 0.03779898743544306, 0.03344171713771565, 0.06805249582976103, 0.0447747888309615, 0.07851651683449745, 0.03134117967316082, 0.03786048645685826, 0.011880283892553831, 0.05351791949942708, 0.011720385419071784, 0.024620979026492153, 0.014905282063409686, 0.02976304292678833, 0.005021500101845179, 0.056805184177522144, 0.03814157637368355, 0.005619502343636538, 0.03259796562737652, 0.02431497160744454, 0.03006955755076238, 0.03919241677171417, 0.10273950453847647, 0.051485082866357904, 0.011341304019359606, 0.044560863702957115, 0.007690546435437032, 0.053521743044257164, 0.027681168567921435, 0.01518687918516142, 0.008363333414308727, 0.06682134832122497, 0.07620164712092706, 0.06223323701747826, 0.05924657692334481, 0.01732571146983121, 0.024097368819639087, 0.0643329161352345, 0.04527145271588649, 0.06715315873069422, 0.03660064030970846, 0.0516667674029512, 0.0715576855997954, 0.011041999678127468, 0.023067347572318146, 0.0040576805477030575, 0.0428956878770675, 0.028501391876488924, 0.039373008866927454, 0.049235763028264046, 0.007697554854010897, 0.02624934263128255, 0.08187384703861815, 0.04301252821460366, 0.05727588731263365, 0.07925462044243302, 0.009453997880752598, 0.024915468313598206, 0.013044666947929986, 0.03853446850553155, 0.015385957966957773, 0.011269093474506267, 0.013490287187908376, 0.015544745339346784, 0.020501828719196574, 0.029559679196349213, 0.0646874438971281, 0.007649274542927742, 0.04224302200600505, 0.0330864022752004, 0.023630872601643205, 0.06536141237510101, 0.0369100726342627, 0.04542863874563149, 0.028302014539284364, 0.023459065838583877, 0.027448702470532486, 0.04928960817466889, 0.002457529792861481, 0.03730975350897227, 0.06929401135338203, 0.05490599519440106, 0.05464784315388117, 0.06169846321323088, 0.027083062001370957, 0.03569750002186213, 0.02580595392334674, 0.025371218233236244, 0.10273208136537246, 0.0523014894154455, 0.010252743011473544, 0.07779776504529373, 0.013993814454546996, 0.03493012780589717, 0.027587028619434153, 0.06539186502673797, 0.03531077238065856, 0.04570920619049242, 0.03014587577698486, 0.021085178845428994, 0.0527247527747282, 0.1166865136474371, 0.1512554029801062, 0.14196317802582467, 0.1523039431444236, 0.10903923399746418, 0.14295200710850103, 0.13831051545483725, 0.124454083985516, 0.10481522458472423, 0.11833510947014604, 0.15440939659518854, 0.09508599593703236, 0.11061618330755404, 0.07256726428334202, 0.14840615301259927, 0.24028691915529116, 0.08726646338722535, 0.15236802399158478, 0.09832519319440637, 0.08623992132821254, 0.12917374287332806, 0.12752739978688105, 0.10956030139433486, 0.05548294334273253, 0.10760659551514046, 0.2046591487846204, 0.07079984340816736, 0.1305102397288595, 0.1595406819667135, 0.10045116554413523, 0.11471246528838362, 0.13503203780523368, 0.22871786994593485, 0.17538865442786897, 0.2939505438719477, 0.12685906993491308, 0.059787308265055926, 0.0924703927178468, 0.1453444944428546, 0.0767640508711338, 0.07140042832387344, 0.12375511149210588, 0.07105810062161513, 0.15713470535618917, 0.0950867287548525, 0.15168407426348754, 0.09662124927022628, 0.20083248269345078, 0.08798262995800801, 0.12336928290980202, 0.12228530964681081, 0.07022721413522959, 0.07838346968804087, 0.1234090586325952, 0.12711843316044125, 0.06413354219070502, 0.12392671299832207, 0.13921779819897243, 0.08129435777664185, 0.059944450190024715, 0.09091969592762844, 0.1438159586063453, 0.11798052064010076, 0.11134603592966284, 0.11900863690035683, 0.17644539129521164, 0.10618556676698582, 0.17904027205492767, 0.08929197862744331, 0.12810353030051502, 0.13960461744240352, 0.15595922486058303, 0.1688877868333033, 0.10615009974156107, 0.24146227751459393, 0.1475059948861599, 0.0976349398759859, 0.10047559280480657, 0.1819842183696372, 0.15315967079784187, 0.10801423221294369, 0.09301589416073901, 0.1007289509954197, 0.1384229487074273, 0.12504595651158265, 0.09674390804554735, 0.13567718890096458, 0.1350163229342018, 0.08599049864070756, 0.22325395313756807, 0.17478938587009907, 0.13492360790925367, 0.16958597222609179, 0.10486355663410254, 0.13783339677112444, 0.14630190735416754, 0.12648126163652965, 0.17366346557225498, 0.2455508309815611, 0.1143560851258891, 0.136433551886252, 0.09268553581620965, 0.17128672025033406, 0.13136906150196279, 0.08746291284582444, 0.10248862978603158, 0.10185291032705988, 0.12625408811228617, 0.17719430396599428, 0.16764705841030392, 0.11017872499568121, 0.1677761429122516, 0.15390042747770036, 0.1955693851092032, 0.18822897970676422, 0.15873121683086666, 0.10349407619131462, 0.09518405781792742, 0.15048575427915367, 0.10055914760700294, 0.08265928524945464, 0.1942881888576916, 0.1254403210644211, 0.26519634681088583, 0.17882322227316244, 0.1385530781533037, 0.06237321879182543, 0.17177246989948408, 0.12613732580627712, 0.0906884308372225, 0.1808621385799987, 0.07650808710604906, 0.1361847873777151, 0.12950541079044342, 0.13770485509719166, 0.1743632930197886, 0.08909956645220518, 0.16401228202240808, 0.109006990013378, 0.09660690503993205, 0.10425939583884818, 0.1916742141225508, 0.12127813297723021, 0.1249872360910688, 0.13990192434617452, 0.11105592149708952, 0.2460900763315814, 0.20280893306647027, 0.16636145168117114, 0.15494670133505548, 0.13001017299081596, 0.1114338112196752, 0.09715773976807084, 0.15164459709610256, 0.12753939628601074, 0.15753920722220624, 0.12708350217768125, 0.1753970818328006, 0.13002849343631948, 0.13295212441257068, 0.11325609165110759, 0.1211550874369485, 0.07814770591046129, 0.1400960125029087, 0.10510625503957272, 0.0814812806035791, 0.15650156433028833, 0.09663802265588727, 0.11752918628709656, 0.08105482134435858, 0.08642875762390238, 0.09503295485462461, 0.21682205184229783, 0.08819186301635844, 0.13368927128612995, 0.12474328918116433], [0.05816484961126532, 0.02942786019827638, 0.02130262048116752, 0.02307225507684052, 0.011797454274658645, 0.04586617508903146, 0.06570580960916621, 0.07184879747884614, 0.025094011233055165, 0.050206458262567005, 0.06563547266913311, 0.07202883317534413, 0.023524798918515444, 0.018678240411515747, 0.056845465408904214, 0.07887867133000068, 0.047268886784357686, 0.027650644670107534, 0.02289264346472919, 0.021018612863762037, 0.033670865198863406, 0.025523797010204623, 0.03201799121286188, 0.02297963504679501, 0.03754528319197042, 0.07085674535483122, 0.01477444015576371, 0.04546073345201356, 0.0635727872805936, 0.041719328678612194, 0.04166355988542948, 0.038625975738146474, 0.016999626199581792, 0.021019549242087772, 0.06789390862520252, 0.08299980126321316, 0.034594805977706394, 0.05460715140881283, 0.010181440855376422, 0.032781427925718684, 0.015188388925577914, 0.026074372198698775, 0.0602542624941894, 0.06404155319822685, 0.030650838145187924, 0.018200248113966415, 0.03228228060262544, 0.03739863820374012, 0.04299165987010513, 0.026165401064125553, 0.029546329019857303, 0.03955902924228992, 0.046328678128442595, 0.09509222488850355, 0.03162124500210796, 0.02703706580879433, 0.024474786960386803, 0.02183943667582103, 0.07248941596065249, 0.016338388734896268, 0.019604518743497983, 0.0084173906029069, 0.010266266214395208, 0.04819237973008837, 0.06478640144424778, 0.028612230571785142, 0.029040135110595396, 0.05478238647005387, 0.0420373648272029, 0.06829306363527264, 0.023304458241909742, 0.019131556086774384, 0.06359404578272786, 0.02265027754141816, 0.023443279721375023, 0.0387634672889752, 0.09378071847770895, 0.03446370961942843, 0.045496807766280005, 0.042797636174197705, 0.010784442203917673, 0.05116064813254135, 0.039833625578986745, 0.0053164537613546205, 0.025163596695555106, 0.026237207032474022, 0.07258674502372742, 0.07327966498477118, 0.05566298243190561, 0.03007112835933055, 0.034456880164465735, 0.05714034315730844, 0.03490974461393697, 0.04552509589120746, 0.022468323287154948, 0.06408709646867854, 0.01403174625842699, 0.043541486973741224, 0.01886066624761692, 0.009276421873697212, 0.020180459267326763, 0.043838376578475745, 0.021541174734011292, 0.008989043633586593, 0.031068571444068636, 0.04634646253128137, 0.047318921956632815, 0.009224075441514807, 0.017443208289997916, 0.03447973322389381, 0.0207176401745528, 0.038109220431319306, 0.035856609698385, 0.02903553464316896, 0.05424343628276672, 0.008872407704724796, 0.09121702997280018, 0.07949784810521773, 0.09958741082144634, 0.016980973271919147, 0.047294776287994215, 0.019850100922797407, 0.051004527402775626, 0.023180315171235373, 0.020925280371946946, 0.016931318079254458, 0.011830792396462389, 0.052804975969983, 0.04072434189064162, 0.06942204412605081, 0.06506887557251112, 0.061320749909750054, 0.023399582066174065, 0.02808816744280713, 0.01532957679592073, 0.007447933695012969, 0.017282890821141855, 0.04720450059643813, 0.009955990810080298, 0.011022764058517558, 0.04523791612258979, 0.06005423715604203, 0.03126640511410577, 0.0477930483009134, 0.020208321611530015, 0.012330868464362408, 0.06160840126020568, 0.06119945498981646, 0.09479687216558627, 0.037281461991369724, 0.03875227824651769, 0.0322503691006984, 0.05809521834765162, 0.008603164161156331, 0.01191791968553194, 0.0556869347180639, 0.03598325147426554, 0.025776281586981246, 0.06747626353587423, 0.03672220325097442, 0.03382446177835975, 0.020008457425449575, 0.057811278583748, 0.06817094768796648, 0.04019675037956663, 0.05710955123816218, 0.01998688679720674, 0.02740408879305635, 0.03387001522683671, 0.025717128600393022, 0.01871252678600805, 0.007050708268902132, 0.05064153830919947, 0.027255437037508403, 0.052975858229079416, 0.08349773061594792, 0.01924482563377491, 0.06910577216850859, 0.029763439869774238, 0.03948395952050175, 0.02561541959377272, 0.025946595572999546, 0.024734477579061474, 0.01876049073013876, 0.009906870811911566, 0.07261199331177132, 0.024417432091598, 0.03030271575387035, 0.027773992158472538, 0.03126197428043399, 0.031953204689281325, 0.03273728583008051, 0.031740836799144745, 0.07394465644444738, 0.0749527287802526, 0.04666811527152147, 0.050725856463291814, 0.051449503882655075, 0.019066065583111982, 0.031173245648720434, 0.052691053333027024, 0.07954642442720276, 0.049984964076429605, 0.045293233689985106, 0.05242143405069198, 0.03402357787958213, 0.04284716244520886, 0.022177053648712378, 0.023463405070028136, 0.021867729889761125, 0.04470046889036894, 0.057187664189508984, 0.04254822027204292, 0.03565565476726208, 0.0064306154714099, 0.053563873283565044, 0.024856948060914874, 0.04890664979549391, 0.031589455636484284, 0.06199192960879632, 0.06375681276300124, 0.0277733577282301, 0.03802242562440889, 0.02243992659662451, 0.01649397172565971, 0.06947490200400352, 0.03778748965955206, 0.04104743991047144, 0.020695048351106898, 0.05918240108128105, 0.014191957706186389, 0.10907925399286406, 0.03939488822860377, 0.04618794996557491, 0.025141759742317454, 0.03256804223305412, 0.010619414005694645, 0.012000197993724473, 0.03592698395784412, 0.08912566969437258, 0.03850288609308856, 0.03012092943702425, 0.0759548300078937, 0.07454586561237063, 0.02579288703522512, 0.05548318082998906, 0.064195906344269, 0.011152797661322569, 0.03800201529104795, 0.036721436506403346, 0.032566702126392295, 0.034242279894117794, 0.04423281577016626, 0.02151565163928483, 0.050503914444042106, 0.024941283178382685, 0.04290553342018809, 0.014866164519584604, 0.021582836784156303, 0.029085790339325155, 0.02153091528452933, 0.08862013396407876, 0.04816715179809502, 0.03179928580565112, 0.04417682306042739, 0.047504799839641364, 0.04370235405596239, 0.07922366567488227, 0.013283151650934346, 0.07001200996871505, 0.03046235129503267, 0.03513382401849542, 0.06507213254060064, 0.01980792318603822, 0.04238408265103187, 0.031620990551475964, 0.027760587699179138, 0.013892278474356447, 0.0694019187773977, 0.02268193968172584, 0.06080884952098131, 0.028272571208487664, 0.018007310074088827, 0.04986187782404678, 0.028154884398515736, 0.0519282781918134, 0.04631987074390054, 0.055380739005548615, 0.026677623757028153, 0.04221856081858277, 0.0552195428338434, 0.0716636117015566, 0.06289667463196175, 0.06031963934323617, 0.10372886966381754, 0.004483519795550299, 0.032288387417793274, 0.02083963737823069, 0.011091561572227095, 0.02316001340347741, 0.05455948771642787, 0.04505705261336906, 0.02964649096663509, 0.0335270836284118, 0.02715700026601553, 0.024201635903279697, 0.0525232855496662, 0.05494311784527131, 0.04786121392888682, 0.035852426529995034, 0.012535680018897568, 0.0242335643685822, 0.023947412580517784, 0.019312636727201085, 0.010983430231655282, 0.03131571425391095, 0.032054594784442864, 0.02874297069917832, 0.019269863575963036, 0.019671052494751554, 0.04033898828285081, 0.059127677232027054, 0.027090480085462332, 0.051055203790643384, 0.022463987448385785, 0.05195526692218014, 0.04881604501445379, 0.03661608715940799, 0.04233304663960423, 0.03673233038612774, 0.029722727768655335, 0.025133822578936815, 0.01367538221113916, 0.049186881365520616, 0.038899391423910856, 0.03308281621762684, 0.036986743698694875, 0.022443222580477595, 0.012640161689237824, 0.02621970761434308, 0.02848088654822537, 0.07438063554997955, 0.023993127181061676, 0.027342150420216576, 0.05390621455652373, 0.02315168099344841, 0.05905974230595997, 0.02116890837039266, 0.04624061106837221, 0.035982349022690735, 0.04054331214034131, 0.04778076681707587, 0.2050770042198045, 0.16902262531220913, 0.14311946955110344, 0.11813601372497422, 0.18126121216586658, 0.14869618602097034, 0.19066006211297853, 0.09897451728050198, 0.12186285374420029, 0.1604801272707326, 0.16194603432502064, 0.16188244202307292, 0.0975800124662263, 0.12773110957017966, 0.11326539436621325, 0.11820082738995552, 0.13913836888968945, 0.17095117111291203, 0.11559764136161123, 0.08413194372717823, 0.14770264790526458, 0.08779739668326718, 0.09672845101782254, 0.08965065902365105, 0.10220454074442387, 0.20640470726149424, 0.17880122416785785, 0.12053901835211686, 0.1550440982516323, 0.07880243792065553, 0.13824385617460522, 0.08121803615774427, 0.09850351898265736, 0.0721620838823063, 0.14571360392229898, 0.2577269790428025, 0.1178864621158157, 0.08673339270587478, 0.14260492287576199, 0.15435953784201825, 0.09149106312543154, 0.1689379984246833, 0.09005081826554877, 0.16958952774958952, 0.11648348239915711, 0.1024424894047635, 0.17915343812533788, 0.09561542967068297, 0.14081078129155294, 0.14387857381786617, 0.13642207107373647, 0.11045920423098973, 0.06715938089681522, 0.17512469073491438, 0.06031074374914169, 0.21427944542041846, 0.07222271098622254, 0.0947581956695233, 0.17654776865882532, 0.08059181618903365, 0.11129870132676192, 0.11930890221680913, 0.09541855952037231, 0.16797154742692197, 0.19329560069101198, 0.11903127282857895, 0.14357294807476656, 0.1317701299807855, 0.20392573385366372, 0.1210102066397667, 0.11233522463589907, 0.11556733798767839, 0.23580657956855638, 0.11391704582742282, 0.08141437705074038, 0.0982668391828026, 0.26795233892542974, 0.14012928786022322, 0.12740263076765196, 0.14822763044919285, 0.10918252702270236, 0.11413875035941601, 0.07866021698074681, 0.08075206580438785, 0.06479687802493572, 0.20559677561478956, 0.18842013659221785, 0.2200001198798418, 0.10624758486769029, 0.08275926738445248, 0.15049847002540315, 0.20924991316029004, 0.12018508091568947, 0.19265038174177918, 0.08724041442785944, 0.11474347433873586, 0.12546967448932783, 0.10662888083606958, 0.07310697103717498, 0.09705229542617287, 0.09415733255445957, 0.054140390562159676, 0.19471888217542851, 0.10529576308493103, 0.17360851780644485, 0.10280392465314694, 0.15279581317944185, 0.2102455547345536, 0.17066058170582565, 0.18410683875637396, 0.25334269287330763, 0.10142593538122517, 0.0885715712127941, 0.15531977345900877, 0.10017103236168623, 0.10285184958151408, 0.14514206030539104, 0.11760349944233894, 0.15606698979224476, 0.11955506115087441, 0.18133825303188392, 0.19770822248288564, 0.05690539022907615, 0.10498742320175682, 0.13683995365032128, 0.13340728570308003, 0.08290125083710466, 0.1308787792388882, 0.08382257247077567, 0.10256441536226443, 0.16459650067346437, 0.10047018488070794, 0.08476053856845413, 0.13194437777357443, 0.08234625668930155, 0.1050928064755031, 0.18212576077452727, 0.08810270351490804, 0.0965539114549756, 0.13434825092554092, 0.09622630117727177, 0.07579458717788969, 0.14333634291376385, 0.11193592034812484, 0.08856592580143895, 0.18526192248931952, 0.21207735501229763, 0.18376169513378823, 0.1389787503119026, 0.17312705649861268, 0.1516003023300852, 0.07237101838524852, 0.177707113591688, 0.13524672628513404, 0.08206485464636769, 0.1095630426758102, 0.14879120806498186, 0.1697392397161041, 0.19216855402503694, 0.08460205314414841, 0.11812910623848438, 0.10685360484889575, 0.09677014020936829, 0.11073511692562274, 0.11144386710865156, 0.11611863411962986, 0.1451506505587271, 0.17431487276085786, 0.13038746560258524, 0.13769387640058994, 0.07672540830182177, 0.13766696570175035, 0.11272325845701353, 0.13280609010585717, 0.1386707496962377, 0.3357154599257878], [0.03379778856677668, 0.010784060527969683, 0.05809373235596078, 0.01595536419855697, 0.006580214631477637, 0.04875543148123792, 0.043039245530962944, 0.024871640040406158, 0.00908249571719872, 0.05877945984580687, 0.017027673444577625, 0.00884809494683785, 0.07457582971879415, 0.020865781332499216, 0.0244706970905619, 0.03480159630998969, 0.06154723132827452, 0.01992627665666597, 0.01836780894414655, 0.014882021882970418, 0.0037737200036644936, 0.08409934011953217, 0.03171197870480163, 0.018297882517799735, 0.028264880014051284, 0.02418371748977474, 0.01803197991102934, 0.04266745923087001, 0.07468854795609202, 0.029064460591013943, 0.019153203050206815, 0.01751118223182857, 0.05786685738712549, 0.017941994293193732, 0.029062180713351284, 0.04369438126949327, 0.02658781286195985, 0.07156472879328898, 0.036746481233941655, 0.046833202841558626, 0.1008682678054486, 0.05897609929421118, 0.013500173443130084, 0.04432102532259055, 0.014187465804362935, 0.026350600412115455, 0.03277543306882892, 0.0362932266268347, 0.020398089196532965, 0.017154132016003132, 0.09793021117470094, 0.014292768502075757, 0.04103698368583407, 0.025464325112157633, 0.007921624080544072, 0.009965011084984456, 0.019165828890566314, 0.021503751831395284, 0.012546860579667347, 0.009336752966711563, 0.018054922876347388, 0.09453191102615424, 0.03169167693704367, 0.01531248280246343, 0.026585370135892714, 0.031788972073367665, 0.018126991777015582, 0.05390785321859377, 0.011559209603417133, 0.021213908812829425, 0.02585349208675325, 0.02236576102274869, 0.07332510647497006, 0.13840922872935021, 0.07444113373224225, 0.010423907710771476, 0.006634572071821562, 0.032872660351651053, 0.039206286027495346, 0.14872936638338224, 0.038572262906070263, 0.08713613716619355, 0.05126838253012725, 0.018969348897891383, 0.02829590772411653, 0.02104090782813728, 0.0235246954419251, 0.03825851509879742, 0.04308719081538064, 0.022899803705513477, 0.06076690248612847, 0.03682174433821014, 0.029497427001063312, 0.013623622711747885, 0.04288024102736797, 0.045577193809939284, 0.03160091270027416, 0.038315410260111094, 0.09991006779351405, 0.017682371528020928, 0.07138482880379472, 0.019845612413649048, 0.07374238515538828, 0.04039641948682921, 0.01074143495809819, 0.07608758538429226, 0.04039201918723328, 0.026837364471118366, 0.012401327540698861, 0.027003322262316942, 0.013699450696419393, 0.07294267735310964, 0.009443781687878072, 0.05504502701972212, 0.010304654333075243, 0.06910945661365986, 0.09633198979177646, 0.024605561014530913, 0.03591819692935262, 0.020737587407763516, 0.03974764501409871, 0.020304751615705233, 0.024433089287153313, 0.028331045660057237, 0.049517887710992775, 0.06369436718523502, 0.016684585783098425, 0.03922380919435194, 0.008760787845988358, 0.023237486835569143, 0.053781218228063414, 0.01732717201645885, 0.011893373681232333, 0.04436222936159798, 0.03254121295841677, 0.0431712986236172, 0.009432262707767742, 0.04166271850200636, 0.07519707602581807, 0.07011043825852019, 0.027276639560503618, 0.07772770630461828, 0.0382735378641103, 0.05171288064281855, 0.02019295109702008, 0.013932765810750425, 0.04460046300664544, 0.028723378000514846, 0.03826533437573484, 0.03549205658159085, 0.029782625447426523, 0.016224859648251107, 0.03590283828920551, 0.004794707829465291, 0.04199215403891035, 0.05164087111396449, 0.02020514946031783, 0.01829409968507077, 0.05485416868967669, 0.0353269656188786, 0.015164190670475364, 0.011731409068618501, 0.03037072192611439, 0.014929305595744933, 0.07097460010222026, 0.019456168936033334, 0.05497735332963722, 0.021059067121573856, 0.022402027023157904, 0.007364614683735583, 0.03921719687059522, 0.052068388887814114, 0.02375346182712487, 0.0961157949641347, 0.046547441211129935, 0.01964593821737383, 0.01703382097184658, 0.03483816595481975, 0.035889074206352234, 0.01270080914920462, 0.03588305899341192, 0.018125017240111316, 0.03125616602067437, 0.007409200371642197, 0.02954559280936207, 0.01601201169458883, 0.03165417769923806, 0.05225893169907587, 0.08829125482589006, 0.015367227007767983, 0.06000142677554062, 0.08382622977452618, 0.11730594826596123, 0.03047140295218144, 0.015255170342113291, 0.006080266637062388, 0.03376784481640373, 0.009743985088009919, 0.008969923364929855, 0.008747543690593114, 0.04736031259277037, 0.008583561284467578, 0.06126028565423829, 0.0866418108344078, 0.022526734974235296, 0.010091601122569824, 0.0234751199771251, 0.03990030521526933, 0.08543602696486882, 0.08634558280131646, 0.04189687415159174, 0.03512765274250081, 0.06376846320927143, 0.022728711100561277, 0.08248885082347052, 0.06179888639599085, 0.13279896548816136, 0.03563617402687669, 0.02264990095448281, 0.024461301076891165, 0.0115415541222319, 0.034221706712352376, 0.010493227696445371, 0.03152174462697335, 0.048030616981642585, 0.009786009306221135, 0.039618540156100474, 0.011135568809030312, 0.03297061027426805, 0.03436705569869705, 0.010476964908385915, 0.031618469793881686, 0.023659377857776623, 0.051685593357043605, 0.04620283702388406, 0.01631086226552725, 0.07381426236991372, 0.06769304190363203, 0.03926833466227565, 0.04332938031958682, 0.11619722204548971, 0.023501840686159473, 0.04545776146863188, 0.016347487889496342, 0.03215058374085596, 0.04109824861266783, 0.04212823762957539, 0.05602813605219126, 0.03675887467605727, 0.07865376411271946, 0.02241089377951409, 0.032972639093973806, 0.01425770011597446, 0.03772482695057988, 0.03407491923176816, 0.03284414831016745, 0.029168021998235157, 0.007466953031585685, 0.02214535927799131, 0.0220840163196304, 0.010585592427690114, 0.010991300389702831, 0.04122118219467146, 0.03804397589660116, 0.03316130914858409, 0.06797926833054849, 0.07100997891809259, 0.04539518018386193, 0.07533760741353035, 0.0581695790003453, 0.06387911191476242, 0.04019523046112486, 0.018475980996819477, 0.09993010493261473, 0.0484031157435051, 0.020705518146444644, 0.020603866815300922, 0.017540669667401483, 0.010928408675161856, 0.04219951434060931, 0.057100099245352406, 0.049448524468711445, 0.037459706355418475, 0.04384058860263654, 0.06956205304179873, 0.029017299014542784, 0.06333601927118641, 0.03328130128128188, 0.02591106408674802, 0.038600306758391004, 0.07431945204734802, 0.04426576882334692, 0.042561512773058245, 0.030418066707040583, 0.05920545091586454, 0.044034154287406375, 0.04517049688313689, 0.05584824624072228, 0.028401352066014494, 0.04838375035407288, 0.06728324067911931, 0.04647537739947438, 0.06259092675255877, 0.03242038283497095, 0.04371404182165861, 0.04938879642369492, 0.03754565638623067, 0.003938942008452224, 0.026211453235841224, 0.0883833116718701, 0.073792332118111, 0.037670374515333345, 0.032605683963213644, 0.017920781592173234, 0.0053334981369386825, 0.062352170635546954, 0.020257245682712113, 0.025067395696948682, 0.010745943823297108, 0.04388867637940815, 0.008449448838031717, 0.039821371236549954, 0.045383906324527094, 0.008228792642642344, 0.048896933174026866, 0.009069835950088288, 0.016391390801540444, 0.016808873042464256, 0.03749369417450257, 0.02039141410828701, 0.023779578639992645, 0.051522371758307726, 0.08887442853301764, 0.07048437212194715, 0.02446685149334371, 0.023474468583507196, 0.031034122221171856, 0.03182373681504812, 0.025704190633924942, 0.037700345407107046, 0.064767015698765, 0.014214334094763866, 0.05878173972346953, 0.04319839591958693, 0.07410211728087493, 0.054633875510522296, 0.029930786961423497, 0.052852408960461617, 0.038996177658970864, 0.026847622224262783, 0.017679984781092832, 0.01367523632611015, 0.0667064655572176, 0.11336478617574487, 0.1147193049213716, 0.11390779060976845, 0.08380939532071352, 0.1981636280460017, 0.17782376733209404, 0.1307270588087184, 0.15596299751528672, 0.10117787654910769, 0.11670866103044578, 0.08920690390680518, 0.22101334908178874, 0.08401992438094956, 0.17185747676662036, 0.14839509289179528, 0.1375113097684724, 0.08608541890446629, 0.1274262980691024, 0.06154107701565538, 0.14318710592176231, 0.12323652074805327, 0.1075470812086548, 0.08169313959245171, 0.07668893704456942, 0.051739998294838836, 0.12345434405973979, 0.17619255557656288, 0.1678431143185922, 0.09851537298943315, 0.11149471652294908, 0.17940360041601316, 0.1599580624273845, 0.19212781478251728, 0.25028643544231144, 0.16371357733649866, 0.13671745093805449, 0.1349061695592744, 0.22486170115215437, 0.1422871377851282, 0.37366464787295883, 0.1528250580387456, 0.03887144935184291, 0.1453873235732317, 0.11559625715017319, 0.15103558477546486, 0.1373062836272376, 0.1358915109719549, 0.166940961299198, 0.08255616828267064, 0.10867013130337, 0.08050937418426786, 0.12985705477850779, 0.12945025946412766, 0.046833274087735584, 0.11674793463732515, 0.13193900377622672, 0.16385902810309613, 0.07334819702165467, 0.16566393125270093, 0.1999654777880226, 0.2000366968235799, 0.12821171592388833, 0.10475703342152493, 0.24034185335040092, 0.11624987636293684, 0.08385495894721576, 0.09838090770478759, 0.15596246825797216, 0.13848111272922584, 0.1855248955211469, 0.1482280104288033, 0.20059241700385297, 0.18146811106375285, 0.11451563585017409, 0.1282040077660765, 0.14512196209813866, 0.12625070900789329, 0.1902415824255773, 0.15840816630848817, 0.10122200846672058, 0.16047066849257263, 0.09685082480843578, 0.10557004729551928, 0.0494638559674578, 0.10919481529189007, 0.16477006993123464, 0.10784555519265787, 0.1501916636313711, 0.20917009030069622, 0.1408632727605956, 0.13516779909176485, 0.13570422173610755, 0.12182999907859735, 0.13140240471277917, 0.14749649539589882, 0.13097097857722215, 0.20532867285822118, 0.19012336805462837, 0.12035130842455796, 0.11642758468432085, 0.14189167400555952, 0.15670774398105486, 0.10124640858599118, 0.11198478165481772, 0.14710223940866335, 0.10273569117167167, 0.09044677737568106, 0.13047274388372898, 0.10268125230712549, 0.10899747016706637, 0.06450760497578553, 0.14632428543908255, 0.09760780526059014, 0.11630174357976232, 0.2184809342558895, 0.12252384184726647, 0.12066343453313623, 0.13224955568356173, 0.06167005295200007, 0.19772191531956196, 0.13764557827796253, 0.13941926881670952, 0.11679448213960443, 0.19273328515035765, 0.11579563788005284, 0.21417146335755075, 0.0795192965971572, 0.1142151669732162, 0.11861211460615907, 0.16983480458813055, 0.09853853138961963, 0.13824967800506524, 0.2513439729809761, 0.18894490200494016, 0.12566399334796838, 0.07616460589425904, 0.10701369161584548, 0.16796725908560411, 0.19913132754819735, 0.0847738039280687, 0.1545209748936551, 0.11348284448363952, 0.1263463417334216, 0.060806237161159515, 0.1006531925605876, 0.10465913438903433, 0.15328578331640788, 0.1816127747297287, 0.11429622476654393, 0.10524924950940268, 0.09221980973545994, 0.12289395555853844, 0.11202152432607752, 0.1316912027874163, 0.2515463935477393, 0.15954463104052202, 0.09126967071954693, 0.11152993927576713, 0.0972870821133256, 0.11105899526072399, 0.06722457454140697, 0.09888469960008349, 0.09392378758639097, 0.1901433848376785, 0.10145508524562631, 0.11940682839070048, 0.11740380658635072, 0.1780592461249658, 0.12207401384200368, 0.1205724836992366, 0.09308916915740285, 0.1926832499780825, 0.15059826895594597, 0.09494227543473244, 0.132471626624465], [0.06258709302970342, 0.06521887252373354, 0.058699949112321646, 0.027725912863388658, 0.06180543425892081, 0.09218821714499167, 0.02360894065350294, 0.0929589718580246, 0.006825245501074407, 0.10893052590212651, 0.045643028670123646, 0.07031553225325686, 0.01758073376757758, 0.043208068436277766, 0.05788371219698872, 0.016428715316578746, 0.033942472588803084, 0.0844827802585704, 0.023438117766220654, 0.01892020769550332, 0.022044479780431305, 0.016757258579933217, 0.013423625363170036, 0.01278323758327003, 0.06520745277936969, 0.03457133884408644, 0.0522589147357004, 0.050064132149730406, 0.02163508567692978, 0.02777856887717332, 0.05211944864796741, 0.01903937880082854, 0.027517136119838272, 0.04383696861831205, 0.027053147088736296, 0.043229018204978535, 0.015464403400463718, 0.024389225390872786, 0.02387211554949837, 0.028586517487253462, 0.04362858033605984, 0.027071014612114856, 0.003723337930361075, 0.01943319204396435, 0.01676121274275439, 0.0003560556319176352, 0.0545481256475406, 0.016438038387734975, 0.033294892337705405, 0.023195102145629268, 0.03158566941108022, 0.020510359600718533, 0.03759136250508683, 0.06523920821824244, 0.058311352107141695, 0.046097972829427035, 0.018977823800274303, 0.005417256075556257, 0.05984127215508904, 0.018885649907003556, 0.011246177650588964, 0.04998235171660781, 0.034335707380835495, 0.0109926964755037, 0.07251391786017589, 0.034531787037849426, 0.0287166740745306, 0.029853535749550377, 0.012249509571120143, 0.08930900985641138, 0.016727448840226446, 0.043910528599683724, 0.006856235467629241, 0.02434304429750357, 0.02400283532084099, 0.060302424909813065, 0.025206761700766425, 0.06861703017992632, 0.014058470360136457, 0.010219823036875044, 0.016550413964848434, 0.06665150422070708, 0.02265376690775156, 0.06260343215295247, 0.037041202919291596, 0.04651451529935002, 0.06415379646101169, 0.02362328488379717, 0.05447506778208273, 0.005857344558795116, 0.07917130991284337, 0.02186891054069357, 0.03338942244382841, 0.04248352874336498, 0.05216424213722348, 0.06490519935531275, 0.029543160261320214, 0.03560465268258538, 0.02899814736364143, 0.035395490870411904, 0.03604398714378476, 0.04388450678171856, 0.0654843697058303, 0.032894251335944445, 0.030698484874197414, 0.03593113998483334, 0.04458573540406568, 0.026838713059467927, 0.04158718737640551, 0.028660440484860113, 0.03289593749546579, 0.04632728034630418, 0.010612117209737855, 0.08109585914228644, 0.03211690126253026, 0.00336404303587707, 0.018433572558153952, 0.021436347858980298, 0.016298937012574503, 0.02450318873992988, 0.018762205727398396, 0.02995770444561328, 0.047143619041889906, 0.042857805266976357, 0.02190108327860279, 0.01981909865779536, 0.06361047311552934, 0.024643514870799015, 0.0542230632688318, 0.01932393094258649, 0.021093741957364336, 0.01481577311642468, 0.07413421877260719, 0.007779931549781135, 0.05116310782198395, 0.03839014410706503, 0.04621384286188653, 0.01675240875088743, 0.028225460522142903, 0.02603474066459707, 0.02729035444956805, 0.04748991956668241, 0.07128261428858552, 0.04132262996530958, 0.022115089830809405, 0.048343954275229147, 0.0658160579789962, 0.025477341110152856, 0.05565273316044893, 0.039421161104525836, 0.05978012257920844, 0.014314632596714156, 0.028730787602918487, 0.01497431451986943, 0.08112258663667099, 0.032853060867637396, 0.036132613995245526, 0.02300933113188616, 0.04970645259267517, 0.08288849437875406, 0.021260586933099797, 0.038328302425465414, 0.047034232411533594, 0.0338620390476925, 0.03614626611982073, 0.014127085517559732, 0.015308572744418467, 0.028409353690221906, 0.0488535917497107, 0.03800752838807447, 0.015962649968319705, 0.03154291831223028, 0.01809224230237305, 0.04935330564954451, 0.04620709822380117, 0.051783658630613766, 0.058164612124008794, 0.08640603348612785, 0.04252531971516354, 0.025996401739705886, 0.07061218776340995, 0.018974263187763945, 0.019082777900621295, 0.02323971243043031, 0.03097889286332897, 0.046413220199091096, 0.014132931944914162, 0.050749611974294694, 0.05040235810780099, 0.012404941587841936, 0.10557723976671696, 0.04717452631198934, 0.0011405758060781018, 0.032212154008448124, 0.03502324316650629, 0.02548820275946387, 0.05812365575028317, 0.010476706216910055, 0.014710040397143789, 0.03928604442626238, 0.02174778695085219, 0.0287095460641597, 0.0676597190488662, 0.025422127019347887, 0.006772176429097141, 0.10898283416671412, 0.04953655760203089, 0.06727891841105052, 0.0551726051739284, 0.07297790010592767, 0.04784527514129877, 0.016499942833823816, 0.02070907536627991, 0.021614951846588935, 0.04249434459156223, 0.03199840529954859, 0.02292290443022336, 0.057449253009898324, 0.002760694998349728, 0.020718746186633195, 0.03845365159213543, 0.041754466614552906, 0.029217253106513193, 0.0474370582960546, 0.036022253667137454, 0.03955601315413203, 0.053304381136383326, 0.047372444798903804, 0.027468703986544694, 0.030730382805424075, 0.007595133385621011, 0.04817776408578668, 0.0757905634652291, 0.09249737805553845, 0.016733950902042643, 0.05683868684406791, 0.015594319107809236, 0.013096301766511585, 0.025396649725735188, 0.02051954696487103, 0.0674576038228614, 0.03487494255283049, 0.013918265517401909, 0.025898918309914212, 0.0014039955047857283, 0.038025886153004, 0.037841887811997106, 0.027100281523806707, 0.015886906800525527, 0.04192282133070486, 0.020653347285198312, 0.031453843627657206, 0.03200288363067167, 0.04494285856240562, 0.02444619688737605, 0.03634694963693619, 0.03929212410002947, 0.06344603693911008, 0.0067612867902166075, 0.11795039368527276, 0.06954591069370508, 0.029177585949323008, 0.015457811432757547, 0.04286314194489803, 0.033004723622330596, 0.05886616983583995, 0.018736121144944003, 0.03291451917695148, 0.029931160155683756, 0.05333395169249602, 0.018999145066897784, 0.06762025545218162, 0.07900907897523471, 0.08425444643944502, 0.050108935817011764, 0.040999867820314, 0.010649067682347127, 0.05012636738164084, 0.04265539487823844, 0.01901740105157452, 0.03994935651176742, 0.07569130057735102, 0.05573556532285043, 0.029770764655300548, 0.04075600911996194, 0.025988147361204028, 0.03502147558278271, 0.0627175753137895, 0.02156615160804774, 0.04561419093183108, 0.044534865633717606, 0.041586396883108785, 0.027099684412990297, 0.024925648035215478, 0.02804820003387119, 0.010124402353540063, 0.04563526622951031, 0.0642954610022051, 0.06836455408483744, 0.018421408121607134, 0.03619914096114891, 0.049243807060910125, 0.04012942274234124, 0.027724526955613067, 0.03618379249902708, 0.01155189669225365, 0.01014691953813391, 0.05547304690948554, 0.023837259205590402, 0.028916539956948588, 0.06765968512211527, 0.03492288783724819, 0.023938455918271626, 0.007943919893088085, 0.07363203500530549, 0.021287014175738608, 0.009203857642465403, 0.045059848177645884, 0.07001973848257746, 0.03230642966393914, 0.032147408196968694, 0.057117734370487075, 0.04369187747527446, 0.02636158250139228, 0.06601912315402712, 0.06528006281171526, 0.02993823049057807, 0.04019737463178379, 0.05715103686920234, 0.018202480494177768, 0.07035153532134635, 0.08708049729466438, 0.019594508655635372, 0.010515140984872622, 0.01655694147172783, 0.07196714077144861, 0.03974987739431007, 0.037249116227030754, 0.04029990466577666, 0.018985174030863812, 0.02664697602657335, 0.03801586419077856, 0.04851510455565793, 0.04321458576513188, 0.021830778568983078, 0.006984169852720308, 0.033037442580929825, 0.022904974142355577, 0.03185167549444096, 0.012376339640468359, 0.046823418366589716, 0.05284470419532486, 0.09872390037136418, 0.15206129902175494, 0.10475023450063807, 0.13584588627730096, 0.14247194358280726, 0.16323082681213105, 0.08089701445507151, 0.18955468785549912, 0.09240747895091772, 0.1622933085475649, 0.22305132901029928, 0.12950888488973888, 0.11474899761378765, 0.10795971192419529, 0.22297135687300138, 0.22916472596781595, 0.10262671166232654, 0.15162960147219046, 0.07924178255988018, 0.14444350850369247, 0.14675352669187955, 0.14190582824604853, 0.05607478872739843, 0.10809828913105385, 0.19734745898417064, 0.10778639372438192, 0.1951951730464186, 0.13002425937780313, 0.13595631106623582, 0.15143221563526563, 0.1293349220816578, 0.10963622267757143, 0.09821563693029539, 0.19868851559502737, 0.09968555412654366, 0.11322893667966127, 0.06747746454285723, 0.1285154689103365, 0.11327264112021242, 0.10471881832927465, 0.08737500863415854, 0.061741801244871955, 0.11031060506190572, 0.1653682528329747, 0.08866389947278158, 0.08388353205685105, 0.12181530201009341, 0.1118163081950375, 0.1402603808258261, 0.10342006159148046, 0.182288758456707, 0.1003786369359919, 0.10746034407722098, 0.12202070813093867, 0.1408591472676822, 0.13187638856470585, 0.1526916716247797, 0.17803192830511502, 0.14785640394049032, 0.12520143602575573, 0.12300138122269086, 0.05640646003718887, 0.13196157185094698, 0.10093188724879708, 0.2646280601620674, 0.08554947801998683, 0.08500797993370465, 0.15787722622709616, 0.12234879338315555, 0.22491825026060852, 0.11218339564012629, 0.056332723636712344, 0.10695633505071912, 0.09896959111626659, 0.08592740845467363, 0.12418907534863267, 0.21013039377118858, 0.1726748129086835, 0.09328006141419921, 0.15907235709684237, 0.1330171280673572, 0.2182665986141988, 0.15685335759605679, 0.14502889423498086, 0.15281174518167973, 0.13482137982334408, 0.11260613652744464, 0.2860458008944988, 0.13452391007116862, 0.10437431931495667, 0.23183250852993556, 0.15126307042581694, 0.2424841783940792, 0.17239570431411266, 0.1286163263555084, 0.10501284790890557, 0.1383994035422802, 0.14418584161571094, 0.07725511344947986, 0.15400033497384616, 0.07544081937521696, 0.08811614529362746, 0.1496059386325734, 0.1718044424695628, 0.15680819430521556, 0.10763182344713382, 0.11367548736078398, 0.13832958228886127, 0.0833765510469675, 0.08344045547502381, 0.10131063192550625, 0.15689398827297346, 0.17809695910130227, 0.12944230703370913, 0.1497704426624945, 0.08830065253589835, 0.12142077460885048, 0.12616719491779804, 0.07050611238394465, 0.09049479729895081, 0.15092183516493865, 0.15930113196372986, 0.1411987811859165, 0.10314307681151799, 0.0837797840524997, 0.07368714561952011, 0.12416140469057219, 0.17427274930690015, 0.17735795304179192, 0.10399494360068015, 0.09190839608865124, 0.20408706233969756, 0.13794569431671075, 0.059938987983124595, 0.13656763040593692, 0.20039781316050462, 0.10186728169875485, 0.11303002413894449, 0.19241862132080964, 0.11564458241420132, 0.131619766620653, 0.1419936985309635, 0.19330465234816074, 0.11999822594225407, 0.18467053850846632, 0.1711087812270437, 0.15087074147803442, 0.11386147380939551, 0.25473472103476524, 0.1724274597529854, 0.1893262251147202, 0.08943426063550369, 0.08803073130548, 0.14196885057858058, 0.21428606792220048, 0.1169146371207067, 0.13131625790681156, 0.09244304775659527, 0.12053767485277993, 0.135732000959771, 0.0924651272861021, 0.09328317588993482, 0.1285755464008876, 0.062368170491286685, 0.08431935509932892, 0.1281703252877508, 0.05381215942491378, 0.13048526964017323, 0.05800392146089247, 0.15317037808043615, 0.08393664099276066, 0.10042033969823803, 0.053223018002297194, 0.15962559383894714, 0.12941990180739335, 0.14324411643402918], [0.023733679138656174, 0.02393621505637254, 0.050753055539514334, 0.01289765809529594, 0.06438871206981794, 0.048042365815490484, 0.04287476524976747, 0.07127838023006916, 0.01677189288394792, 0.034471712939973385, 0.032111842783966234, 0.03976654221436807, 0.015430637801598226, 0.0817360705030816, 0.007980292762762733, 0.046536218241921494, 0.03580723949042814, 0.02106452254312379, 0.032972846047154496, 0.06695447689188377, 0.04867291483762009, 0.005091935853540365, 0.07821053825318813, 0.02946203461449061, 0.039071349161011834, 0.0854632972872683, 0.03922847072993006, 0.011011843885561185, 0.012746302377698677, 0.054719330210770876, 0.035169528531176705, 0.022122166951053908, 0.03989064966195396, 0.0478869304060936, 0.06832313630729914, 0.02897335708673511, 0.0165078087510275, 0.028813032832528864, 0.03989508728097592, 0.05091148328834346, 0.021727797309202806, 0.028059991276157752, 0.030594495989914452, 0.009683588686000024, 0.03922765309523259, 0.07150009833276272, 0.014486654794641902, 0.03398396161251834, 0.030918258974062543, 0.04557525998513613, 0.033913085237145424, 0.023201943474954793, 0.043581537503216944, 0.0077729757176712155, 0.029315213207155466, 0.007962765355062271, 0.03476617338934115, 0.05598739341699651, 0.023151626710646918, 0.04129868446450148, 0.0396303263093744, 0.022696131241640875, 0.06575605512729712, 0.030996270145156553, 0.003966452362614551, 0.0122681557134326, 0.011489261972850986, 0.04794157622382045, 0.023518442741728256, 0.02943720023280808, 0.06572227765406881, 0.013138315806697522, 0.045696432768766365, 0.030058103879647594, 0.02274869056418538, 0.03174197334530098, 0.07165107237441198, 0.0924616531868066, 0.0258019827971501, 0.03900114114263228, 0.028200819522940686, 0.05247053623731647, 0.029784501596753086, 0.03977372111486537, 0.050701497056122334, 0.05099416956571596, 0.04855573862524969, 0.018208405801228116, 0.01593694366913821, 0.015929722360202243, 0.07533998228609562, 0.07328239269554615, 0.014165482966096272, 0.045819322245993784, 0.044066876638680696, 0.04681816989822047, 0.07842690271458455, 0.01867325826814132, 0.05688275769352913, 0.011681209351601345, 0.08615458197891712, 0.011167403127598976, 0.028042798895122747, 0.01822779493938599, 0.01999838966211038, 0.013293409404078764, 0.06319143702941281, 0.06769986796591963, 0.005286364550037044, 0.005882460956594774, 0.08054422374282565, 0.06051524741841214, 0.011428207391873002, 0.027159373442243253, 0.03259910556620785, 0.05878395174763032, 0.035826309717127254, 0.06774760290448155, 0.018647482419120412, 0.06434720608272723, 0.05724388760115419, 0.03499439864286354, 0.0869147719017097, 0.013553309520440442, 0.032082567390586646, 0.051711991761944125, 0.08664822977568422, 0.031729423840131075, 0.04709508343200598, 0.052781481694962294, 0.06344442881111588, 0.023064691107720137, 0.03867808044222849, 0.025834788268964206, 0.048037561787558455, 0.02024389211354511, 0.05903471114912203, 0.02252439402842096, 0.044793516397476196, 0.016740653131689345, 0.02361284053352262, 0.01865209306457213, 0.03618365000667317, 0.09651672773595367, 0.049656122257666926, 0.017881448613479733, 0.0287930839029806, 0.07126586125897509, 0.028541768102773597, 0.035132202319800854, 0.0036876342658485684, 0.027745751530996392, 0.008605143787073237, 0.05588349274226597, 0.03578534995072654, 0.060627728168453486, 0.029853600210377147, 0.019148146267980337, 0.020354376274294088, 0.02514683179158185, 0.08485474637044327, 0.0512528440782002, 0.08803755058241741, 0.07804133197558777, 0.0457839739641973, 0.01843625107514007, 0.06769446682717119, 0.04190304882026144, 0.0488769333543522, 0.051077113686395545, 0.0340035102064056, 0.011274819461894887, 0.06289753637143544, 0.07409398843135152, 0.03864499846739428, 0.07803382059293133, 0.04823789246646421, 0.013017458541850959, 0.029054397916687385, 0.029118634826902832, 0.0499955085106194, 0.020739667117595673, 0.0075730241702071256, 0.049684780184179544, 0.007952985969106001, 0.06037759980452912, 0.04254260200208851, 0.03612036983083401, 0.03190380394724863, 0.05732090811112097, 0.011119406104886105, 0.01494903230507459, 0.03427738729598267, 0.030670234068695987, 0.01698829296843282, 0.013451183214783669, 0.0930858850479126, 0.021127795933612754, 0.07968259962009532, 0.08111774189663784, 0.0564576521116708, 0.07946649978735618, 0.01627688292813088, 0.005229292545534138, 0.03580376539113266, 0.002066942347612764, 0.030543297130082334, 0.03901426061721785, 0.05930806576673474, 0.03904413990676403, 0.01883929917987968, 0.024245979863085916, 0.02353077511569219, 0.03477197825642569, 0.011892578098922968, 0.03341248245643718, 0.04451421442042504, 0.04584957812247532, 0.03477277892774769, 0.027083313059327856, 0.012754204766159611, 0.03560422181284853, 0.039148027010794194, 0.03450964644019093, 0.03559301580701556, 0.01781430248437183, 0.03010904828884772, 0.02673628819840295, 0.042372466131512604, 0.013056848347852272, 0.025430517104853476, 0.042257213565920076, 0.0414540045229452, 0.014308554619284613, 0.07170488698674099, 0.07652095213000264, 0.029626501324985708, 0.05162211301337395, 0.032067341064768176, 0.05497842541496668, 0.015301414199971726, 0.01706211588212422, 0.006181287778807538, 0.061065390040831904, 0.04753180214070848, 0.023703893147675053, 0.057246181049517224, 0.04187207369666014, 0.024433820408635905, 0.02064826336157109, 0.021155676937529018, 0.03700714724670563, 0.03231797154460635, 0.010091160074807703, 0.07571743774626936, 0.023655189600374018, 0.011057098778629941, 0.03263528844607728, 0.013692728958890905, 0.008397930218572063, 0.061591261465634616, 0.00886612362228334, 0.044650477822870016, 0.01140113893364157, 0.070627325879676, 0.02620844223669597, 0.01733650526564036, 0.046243688224681785, 0.019473424081557562, 0.0685875749747668, 0.027028631618512527, 0.1098829855078033, 0.0917175988267575, 0.012266701103986373, 0.031965611702097316, 0.02944701863452792, 0.0943567743524909, 0.03216625789978674, 0.07051675181303706, 0.05754373222589493, 0.015012561842533094, 0.03147523105144501, 0.016620080851550614, 0.025268637309116975, 0.023803218800042356, 0.01863015772375677, 0.028907708823680878, 0.08658815228513309, 0.0251419870515487, 0.045775007123925855, 0.12547458708286285, 0.0049094107816927135, 0.037420215617333136, 0.09484563169202634, 0.04993605866496052, 0.029736898972519805, 0.0347814098931849, 0.035158838211957893, 0.005364379113806146, 0.020609332414876138, 0.054887813848576376, 0.04294416241879974, 0.08489893935620785, 0.009654906162592982, 0.09103000536561012, 0.008257351333408483, 0.010901950050278433, 0.05231225098084126, 0.034468683281115124, 0.03948062452088509, 0.01224080057415579, 0.06769529463989393, 0.027850016918299452, 0.026559484024931277, 0.01647868093901447, 0.0635770009830594, 0.028717094766242162, 0.014842358118455325, 0.06504596823028155, 0.049449029977300336, 0.022910015657544136, 0.02271113873991583, 0.0494396594086928, 0.0440467920021287, 0.0318446764057236, 0.03664366282256586, 0.019363031523036103, 0.04773682488926819, 0.011531315876969268, 0.04613927525601216, 0.05223665200173855, 0.07277543882706336, 0.008982397383078933, 0.032082397756831985, 0.021614741500733153, 0.0166557819715568, 0.06746489807431187, 0.07417751609214715, 0.07603242727262632, 0.007329123061416405, 0.06867926541183676, 0.015634328925183842, 0.032077383383044174, 0.01313134640388723, 0.02384630747006408, 0.052042777583535225, 0.019284969461815696, 0.03843544649758509, 0.015263407757239682, 0.046245951138968976, 0.024549719278833697, 0.015317744841533048, 0.11443962635738508, 0.1172585729509592, 0.14312624133058957, 0.15051388634102686, 0.17079206822173937, 0.1355917477714164, 0.12935063695268972, 0.28415002833519665, 0.054392659704067876, 0.2012213511126382, 0.1934296249278954, 0.09756122383155993, 0.10376355637397085, 0.12508949131837913, 0.10682700627616473, 0.12828791540648254, 0.16084694330181393, 0.12063655097569738, 0.07367908462349858, 0.09530015515961818, 0.1958339052008731, 0.05469466207016792, 0.20317508413323335, 0.2120399677327701, 0.12460839641945702, 0.22314719243773393, 0.10476361521120582, 0.10538777921880994, 0.13572320714592934, 0.1506705465061324, 0.15257269729460987, 0.09450734805847917, 0.1354936451784202, 0.10529830080590077, 0.16630870236882142, 0.11823539196380548, 0.10861371111656938, 0.12886081609342778, 0.08385849411466292, 0.112895524927548, 0.1327160620795829, 0.07689801403986556, 0.15629438044769423, 0.1678120916975396, 0.1029440692758986, 0.1546397049512182, 0.08232077091400113, 0.06173779110291174, 0.12619044152753695, 0.1335046419075557, 0.15548596025577613, 0.09365703511450972, 0.19310512234057697, 0.14506041897194727, 0.10335408763161727, 0.1092444976259555, 0.08455628595714058, 0.15143541832055363, 0.14304090876664433, 0.17339655703731946, 0.1232940876590354, 0.15337967899228844, 0.07650586829653808, 0.14818683692387172, 0.08912618538098675, 0.2213307541928121, 0.09045361022331885, 0.17532690774117196, 0.12823401258460113, 0.16039760384176457, 0.14034162860895905, 0.15043999387749604, 0.1515312274651868, 0.09480621559279305, 0.09643138160130807, 0.11872321793011256, 0.21810689861220972, 0.14654999332768576, 0.12850409666342394, 0.07692582719027996, 0.12491038521485669, 0.18691107471074375, 0.06875124440661498, 0.09159219876996108, 0.11954978214842932, 0.10549907253256866, 0.16392309537955693, 0.08805405255407095, 0.24217639490962029, 0.12694138980337552, 0.13804556110075542, 0.12288261045302663, 0.1533975244632789, 0.17319637563611778, 0.08242497353681497, 0.26090637700898306, 0.187759596322264, 0.1598955557814666, 0.15500596458358423, 0.10207112718905721, 0.17279089667967387, 0.08567938354930707, 0.16730773661817822, 0.12829434791845934, 0.20136663903083118, 0.12986016246889318, 0.12799085277531827, 0.12684946187904902, 0.0997010450810194, 0.07558847538062505, 0.10764128901064396, 0.14398281036743096, 0.1400094721466303, 0.1029199677120362, 0.17533089752708161, 0.11696203957710948, 0.10052857281906263, 0.18507536607129232, 0.12325963165078845, 0.19789935222693852, 0.21657653073115007, 0.12581295892596245, 0.12335312020565782, 0.11907676181622914, 0.15253304370812007, 0.1278711049152272, 0.2139203782592501, 0.134652546740004, 0.16577130263405188, 0.11659367648618561, 0.0993989748614175, 0.07848684449813195, 0.13003590303872312, 0.21159373596310616, 0.1605661247989961, 0.15808687997715815, 0.18373502870755537, 0.0822262509859034, 0.11333174830568687, 0.12457881229264395, 0.06364919032369341, 0.11781185040516512, 0.1528936850705317, 0.17265034493591103, 0.12047016061842442, 0.11189494361834866, 0.2006058655679226, 0.19911455416253634, 0.0894543384867055, 0.0903262695563691, 0.17572499066591263, 0.106218611422394, 0.13822412437626294, 0.10569447026188884, 0.1302508765033313, 0.14339931096349443, 0.1161577720195055, 0.07732735707291535, 0.11969918198883533, 0.14552830957940646, 0.16504220318581375, 0.11153244306998593, 0.16668074311954634, 0.1536053597394909, 0.16368995074714932, 0.11417335564536707, 0.19138855087969983, 0.1012007635352867, 0.07253566490752356, 0.13827975067709172, 0.08694829831698112, 0.116958565477814, 0.10989386242415224, 0.08558094847415175, 0.14808103974376405, 0.11387797578104905], [0.0817197992333344, 0.01811826242400067, 0.017222597895722305, 0.062113224528729916, 0.029043714382818768, 0.01206622623638915, 0.047774771960186105, 0.0351317273452878, 0.02400178019888699, 0.012962400514100279, 0.02162692290065544, 0.044989104116601605, 0.025656621936442595, 0.01918657000974885, 0.04202852351590991, 0.040859231259673834, 0.015748748589040976, 0.06733527752969946, 0.03150341400344457, 0.03522860857525042, 0.02206468994596175, 0.023193651777026907, 0.0828668966091105, 0.015248259462948357, 0.041762249411216805, 0.032390869954334836, 0.0763466093423111, 0.04896520058225308, 0.05366135501701917, 0.01398737430905125, 0.054771730077586005, 0.049365346253450425, 0.03795502334833145, 0.033412248361855745, 0.019659815954842737, 0.02633279056421348, 0.019746778699170266, 0.005679566687571683, 0.09765353173549686, 0.011947893121811961, 0.06052796316466161, 0.0371087782217988, 0.05379040898489101, 0.03883244376629591, 0.013881957956722804, 0.060496268793940544, 0.012369542415919048, 0.03991310238572104, 0.05773060755538089, 0.03765206424785512, 0.05522569375378745, 0.04188593955976622, 0.037141493787722926, 0.052287694798516374, 0.03026943021853055, 0.06187720290784325, 0.035949467215687037, 0.02427363864678357, 0.0755990876683167, 0.05759724149746554, 0.009742905369161494, 0.06112869057272162, 0.03267842630988785, 0.04903655871748924, 0.024325421046731726, 0.028947406514946903, 0.017218852382419363, 0.013171355373093059, 0.04689589947728174, 0.025502584309184125, 0.030391715799591372, 0.05309890376936112, 0.05201146997777479, 0.058729730014290125, 0.018681429526103393, 0.009552520317291575, 0.055858841565038474, 0.012839777361867684, 0.046972926772598705, 0.03673840327454465, 0.036133156823260446, 0.027265893262145773, 0.009092860339608575, 0.03711689350062183, 0.019289449489276324, 0.029534909275493453, 0.05309216930930104, 0.08998069845672164, 0.07277672804359879, 0.03136439235614879, 0.006758831341617874, 0.03838697534852794, 0.030480166231947284, 0.0965855922549963, 0.0025405517330260147, 0.0373181198457522, 0.043147505793188295, 0.04887348300378237, 0.06210398966712611, 0.02276067349261471, 0.04141498536669782, 0.016795332876167128, 0.029384111652949026, 0.06528665817209653, 0.040061467460223606, 0.08274064159819058, 0.08637329417147807, 0.02957962134054729, 0.05287883450676288, 0.0771665307027953, 0.04372630973479577, 0.11171194272381918, 0.0627269594530974, 0.03375714092648455, 0.009236041406568671, 0.014980397586311613, 0.022950717580637763, 0.03911191876977682, 0.08790825573461396, 0.03942291511754904, 0.01693839519949896, 0.009849780571780034, 0.042295581328549554, 0.03171089304877179, 0.0204262348291065, 0.029406326889459575, 0.010103462762864572, 0.008781883499718137, 0.07374864124826022, 0.038955994815166504, 0.018212938415152684, 0.036654499026813676, 0.05640204955956765, 0.0385596455473985, 0.011891865637153387, 0.07013984596622841, 0.064534074626863, 0.035993745018328936, 0.04349648992397955, 0.012115917052142322, 0.025231619831174612, 0.03611984735886965, 0.029720244330487082, 0.011403338235270764, 0.020663618609043102, 0.028720426373183727, 0.04638078961787479, 0.012333934594477926, 0.049061725581330914, 0.015874029902209128, 0.009745639017117875, 0.03113275746415768, 0.04684753689382758, 0.022485809134585515, 0.040554036386311054, 0.04440633413781013, 0.039717361996216435, 0.044428942924631495, 0.027909751748666167, 0.04297718671815736, 0.025553927357707704, 0.0057490384954560015, 0.026189161664141074, 0.04975958866998553, 0.07222216137285743, 0.03488018762852464, 0.07027488800563983, 0.017209105226876478, 0.00879850167049361, 0.013355973725473242, 0.02799953380599618, 0.016788501724866883, 0.028026439415823137, 0.03355929707842214, 0.019417244774688567, 0.014144841082660215, 0.07809540443122387, 0.008919438663204866, 0.042209712721939595, 0.002343002623612327, 0.03461047674396208, 0.042644684202969074, 0.051364459696092775, 0.015203179292646902, 0.027467302811731185, 0.03002970718911716, 0.008547858468123844, 0.03288066027952092, 0.09407855463879448, 0.04304819880053401, 0.037202086964888234, 0.02046786804151322, 0.025810615458924855, 0.1364708034587758, 0.03454554772802761, 0.023612983025876538, 0.053247940593532155, 0.017735979187169244, 0.041924670338630676, 0.0157198955837105, 0.08758426883390971, 0.01105494358177696, 0.019754963527832712, 0.029066899924405983, 0.11772928626409598, 0.0073124616340334925, 0.0413057547993958, 0.029235254640557935, 0.0362131018191576, 0.04468682694381901, 0.019595165138265917, 0.020582445464762192, 0.031090284564665387, 0.0315880408909704, 0.07108586627457823, 0.02069376252724656, 0.07448160156075444, 0.034619877846645455, 0.022490277287683318, 0.017537309222721627, 0.020562333686809455, 0.07846439855971507, 0.02195163244115455, 0.022501909074240496, 0.02383549331820437, 0.058220245210187774, 0.08849463891237974, 0.045465713899050436, 0.01222472607956401, 0.027082391948040043, 0.03523810128016131, 0.02780643631038921, 0.044226054168705425, 0.016110146517998407, 0.007875169876829853, 0.055536106561443636, 0.02552062485899244, 0.0705903253651091, 0.02178290283440479, 0.062070551461407115, 0.021263399460752095, 0.016609134385362267, 0.05917084562991347, 0.036534147270556004, 0.023378352401778102, 0.006046582038314747, 0.03198756570262568, 0.052867184060492685, 0.029275451055062667, 0.0639895231329969, 0.05719976925424167, 0.04209641772987587, 0.024261369037308862, 0.016436810239351222, 0.033113713309701, 0.04386999970301986, 0.06030836209122624, 0.006300682800688914, 0.009065102320164442, 0.03787921741604805, 0.07676808136914458, 0.037311005406081676, 0.06067400425672531, 0.02900854930547731, 0.057442874780723026, 0.04968415593196239, 0.03586972238762038, 0.06746005333427872, 0.006557487949196781, 0.05209119784246598, 0.04298573625939233, 0.06203367308314357, 0.07289420959672757, 0.01233377937959241, 0.05445801619706409, 0.04617029448438968, 0.007301336204233978, 0.01548018612499748, 0.01635190175979265, 0.03289792560307043, 0.012282889253193778, 0.05119185735072408, 0.07197256226624761, 0.03694187557058675, 0.010242077289149165, 0.05991496105811425, 0.037179091413106234, 0.09297073086989777, 0.03177819015192134, 0.07285139403705086, 0.018360219529962966, 0.02878712975819196, 0.05800577386149338, 0.01603786218246179, 0.02985224314033985, 0.035488076973706484, 0.04641597165859171, 0.05249363017667617, 0.028670465839760642, 0.014298181515187025, 0.045788038388959, 0.06075842758374555, 0.03184729894357068, 0.06051559347127165, 0.06567001688693251, 0.04397827014327049, 0.021852186348821436, 0.012196705975968922, 0.016728052736393044, 0.034761606848665645, 0.016265032314030186, 0.018577964810122336, 0.025630150589027574, 0.012439314475549119, 0.030826609249093702, 0.042485367573265514, 0.005321460925707859, 0.022158948638077294, 0.018081954015152793, 0.03169994827892099, 0.03162014577537775, 0.037453552042799335, 0.05719608480909041, 0.029248082345085483, 0.011074883181468716, 0.021124220054064478, 0.03767098180417504, 0.07218925242445298, 0.03523191982614143, 0.03933642225872193, 0.035697452524410825, 0.031074454342680316, 0.03690196414078985, 0.02545576878557248, 0.01594801227162991, 0.00347994572283434, 0.01846641026038144, 0.04746062720992735, 0.04692633177286812, 0.0654254321541105, 0.002925201996861558, 0.024953824201864854, 0.009129143303393253, 0.007056187863262104, 0.0155443602707237, 0.0917630335316062, 0.07608174998313189, 0.02189138362051121, 0.029708980649177517, 0.03412047268024512, 0.02502153012236314, 0.06596523390284606, 0.16158977629882948, 0.06054516402738435, 0.11672595010272094, 0.12819134630262852, 0.11080567778221198, 0.1438366403537137, 0.12265737753893648, 0.09226454554923944, 0.07522905538124697, 0.10267699789255857, 0.1691381119723831, 0.2076249032148293, 0.16390245434428963, 0.09543630999646016, 0.1360204326254981, 0.1780137164252145, 0.10936305804976396, 0.18255914109093802, 0.12068771251610347, 0.10688114658530269, 0.1597511771001986, 0.08728588984480926, 0.17809351214340755, 0.06844486548964467, 0.20718833378383092, 0.09040018237595047, 0.1744928796376501, 0.0680447266037975, 0.17674054045762333, 0.05811282633138554, 0.13645753131381103, 0.1124950535595417, 0.07975192554295063, 0.11421553338212626, 0.16658265409725054, 0.13148984073528222, 0.08343886091772999, 0.06724852004221507, 0.20404506102204323, 0.08528872379767043, 0.1750358705009733, 0.15416622321520532, 0.18166800748024667, 0.07561749632337264, 0.12006428811166968, 0.15469567051955632, 0.09361347995166268, 0.09839436983955757, 0.1795146358864648, 0.331639364361763, 0.17772498620407923, 0.1585943563176053, 0.13802486578268663, 0.10227291671825306, 0.12483113232467856, 0.1195197773299047, 0.09594582194196326, 0.09463097713887691, 0.09313760977238417, 0.11540181615522929, 0.12799155845173768, 0.10435551032423973, 0.10298906971833535, 0.16757550010723726, 0.10107277826006923, 0.08611410057970456, 0.17433626018464565, 0.08100363266255174, 0.11938107120139257, 0.11689377895423345, 0.11232284137180873, 0.1167153242443289, 0.22662553936243057, 0.12363982839243752, 0.1322727208690984, 0.08085900970867702, 0.1458291584359748, 0.07734151809875454, 0.08731681747095925, 0.17436958982476167, 0.17849163578024932, 0.09705410711467266, 0.09152985497244767, 0.14597500275288308, 0.16996977877404007, 0.19476705816175255, 0.19733516392963274, 0.1797954272478819, 0.11278729859207358, 0.14942718536726066, 0.11124583666345902, 0.16745280740516527, 0.0628595044836402, 0.13590704942388193, 0.14444612764886447, 0.11826285906136036, 0.17068475112318993, 0.1066855995782784, 0.26817280852368897, 0.14905749234770024, 0.10496909597090312, 0.13330492191016674, 0.08572492003440857, 0.10753902699798346, 0.12309424552534308, 0.1426744862858738, 0.09283851832151413, 0.2550678274461201, 0.15046154414968832, 0.20578787821744168, 0.12980657177312033, 0.3308497667312622, 0.10119550488889217, 0.1441413297184876, 0.048540620865034204, 0.06672733050904103, 0.11830518607582365, 0.08642138194824968, 0.17764038645795413, 0.1523565160376685, 0.11256108180220638, 0.15360911882349423, 0.10230641599212374, 0.08770571981689759, 0.15520366254661763, 0.19045598592076982, 0.14728004272494996, 0.1653960184859378, 0.16409895808569022, 0.1198782202388559, 0.07400490356875317, 0.10315586719661951, 0.13770921129201139, 0.09583765667464052, 0.1232008705181735, 0.1224239207804203, 0.1590835800660508, 0.08820063647414957, 0.13124651807759488, 0.18283778828169617, 0.10506582792316164, 0.19939728613410676, 0.11918292540524687, 0.08557337602334363, 0.11854460037180356, 0.12528284665729317, 0.11102012877485581, 0.15982285753956862, 0.08795318832354886, 0.11857681721448898, 0.14013540824609144, 0.15864306156124386, 0.14953431247600488, 0.1612401000623192, 0.15166492600526127, 0.1741652422185455, 0.1221106004502092, 0.16333138570189476, 0.09076387036059584, 0.08769603712218148, 0.18686007601874216, 0.08364932890981436, 0.16389290057122707, 0.11519953129546982, 0.1103119214198419, 0.1293688216911895, 0.12144212132053715, 0.06558722882930722, 0.12785737136644976, 0.16374793834984303, 0.18373167674456323, 0.1176269631832838, 0.1055341935051339, 0.09174499128546033, 0.0946636146732739, 0.1124747721478343], [0.02229108994028398, 0.02567687620674925, 0.0283548367941486, 0.05795816105923482, 0.009267987683415413, 0.006290186288034809, 0.01709374239934342, 0.03454589378088713, 0.006181010427618665, 0.042027817839490514, 0.0036018246069683558, 0.03890467381903103, 0.03933715846921716, 0.04030088175620351, 0.05134996618809445, 0.016236264125577042, 0.006695742427837104, 0.03700031439906784, 0.06484936949397836, 0.02081391920468637, 0.013027948693239262, 0.08226847622011389, 0.0691909622400999, 0.020354125216337185, 0.0506145156520818, 0.04540722078776785, 0.018152835479538356, 0.06044070356126342, 0.05472567451319524, 0.03536874641265188, 0.0353840982674488, 0.04891399832974587, 0.016213180364242623, 0.016485033723126565, 0.0026583725536641267, 0.016101481625810266, 0.1169157363474369, 0.06086153097982917, 0.03923284049545016, 0.02025376819074154, 0.017761336040816138, 0.030058147984423807, 0.04233359286029424, 0.008773555330533003, 0.01669558313941317, 0.06814550262476717, 0.03720162556107555, 0.0414030499357198, 0.006976294181575733, 0.029589246359786818, 0.019236720532977154, 0.052306083097521744, 0.022704395798168013, 0.07189653241740805, 0.026061938044482043, 0.07158452844513313, 0.07506837828883103, 0.040600529605788846, 0.02901760774797627, 0.04638526116364768, 0.0075322382784049425, 0.015443672459306461, 0.03976939206144639, 0.01945283224007913, 0.0337643944658339, 0.012713295889885297, 0.07943639997392893, 0.04851569488112416, 0.0391293503344059, 0.03842287663636463, 0.02507836591186268, 0.03418570703693798, 0.03430069836654833, 0.04647155724731939, 0.047492229978420904, 0.014068392238446643, 0.03948864819748061, 0.06628203511770282, 0.03954008115189416, 0.03429387230426073, 0.06169925031385251, 0.04660230076738766, 0.013682849489019384, 0.08774079329201154, 0.057012785359152725, 0.024613040166773965, 0.06002985739282199, 0.055425406965826235, 0.11884363075452191, 0.07478329180074589, 0.01643652525464339, 0.02112692571245134, 0.00786391637354557, 0.031983945718301196, 0.03732234372624329, 0.022936481915946518, 0.025444664559992294, 0.020029564953542182, 0.025981836985530596, 0.027848795555265884, 0.0398115087300539, 0.050255285642508946, 0.03127416416204401, 0.05362447663875563, 0.0139520565613306, 0.10897898687315838, 0.04105657299182244, 0.006423956498370639, 0.014584250182711651, 0.02669409858728094, 0.01189669341381107, 0.01700508501380682, 0.03561381969068732, 0.04652883917359369, 0.031232776918581555, 0.035659403673240116, 0.05642493993842176, 0.009392609121277928, 0.05411249938021813, 0.035756420610206466, 0.0483294200551297, 0.05268279216917498, 0.05032469977491668, 0.03478998996849571, 0.02668261607842786, 0.021559776771547537, 0.05312799595828567, 0.0012682028360099398, 0.006889147384624396, 0.06447000735040222, 0.03350723308644124, 0.04051658803863185, 0.09711875793124948, 0.05901774098830564, 0.058315511526806016, 0.10968015103467874, 0.03018077283299395, 0.03714572784623929, 0.022931969658072506, 0.0579543069803289, 0.026981461560353637, 0.007038967916741967, 0.047797764119293006, 0.08627691505742924, 0.05433941166847944, 0.062226478808692524, 0.016782059034864818, 0.06845884331102882, 0.04154673990394388, 0.04992616901706372, 0.05135644619752254, 0.022113252697246413, 0.04154639724375946, 0.029540761640029292, 0.04029168760670083, 0.014967703892450248, 0.021317607623391917, 0.00748038717678615, 0.005193349697427558, 0.01594074346524264, 0.03166784339451364, 0.022709997104746953, 0.02951056683169944, 0.03693322424909898, 0.02296152664348483, 0.02596891937511308, 0.021947140539331094, 0.028170175185160976, 0.02807527358111526, 0.11463573654847485, 0.06258817190038306, 0.03172431107876556, 0.06240342038550547, 0.04507655031712992, 0.031702258690659485, 0.0186090077872255, 0.03893787793016859, 0.04292552645451256, 0.04786218762663858, 0.05322582035192421, 0.07822305722428219, 0.054542822896369865, 0.060996396600135734, 0.04593807265960744, 0.056441665826631446, 0.015939213368775587, 0.03091426918815289, 0.021057976376531378, 0.05663098388218454, 0.003922726717844073, 0.02537365417395319, 0.042911979502865245, 0.05449225507410509, 0.029952540794121366, 0.1062092747805374, 0.06217941561979907, 0.07726147132260458, 0.02115188562311232, 0.0560166688103761, 0.03947486036590167, 0.030708445768271173, 0.021980093592511754, 0.05441715481824108, 0.03954664597819958, 0.014206087349780967, 0.02585029279414032, 0.02708380499721638, 0.026339940626972487, 0.021439521706530025, 0.02063637542804437, 0.035800213260310035, 0.020534069310607653, 0.05752969333635909, 0.04697909126324313, 0.014368206329111542, 0.021024607720651796, 0.02081089633117829, 0.0031552086168500993, 0.04530823949192252, 0.08436449124876942, 0.05037042964249849, 0.035640733782202005, 0.00845740975013801, 0.033478999244315286, 0.009520904826266425, 0.012370845203154852, 0.0436624867309417, 0.022909766295924783, 0.039937041101178954, 0.06263121137661593, 0.016930698916049938, 0.01309285226411053, 0.03780666845185416, 0.020708729313420396, 0.03735563943960837, 0.02057008764573506, 0.03340484893747738, 0.02338773145207337, 0.045426691350127966, 0.05174227138715131, 0.03919632513342159, 0.0033367714412244304, 0.06724752259573766, 0.009275953684534346, 0.014860149306644286, 0.0427994444700224, 0.01904735328363521, 0.05247025125260864, 0.023911874308916073, 0.047748231062931676, 0.023818577440189462, 0.04188318470759051, 0.04147227407832231, 0.0847256618684956, 0.023347370492826616, 0.01977088365570775, 0.046757868491113186, 0.038365245264555724, 0.021528367385534302, 0.06335272480334554, 0.026741351765979613, 0.017940011274601732, 0.035673120258642096, 0.011401859877098883, 0.03917017100112779, 0.040989381061600785, 0.05145862339330571, 0.033855409760560305, 0.04744926853371518, 0.00883980409707874, 0.06804424484393426, 0.05557685598198857, 0.017819148920742527, 0.030659452147249664, 0.01885682065039873, 0.040196105771298916, 0.022511116794443557, 0.028157561219164302, 0.041533301517899544, 0.0036901266097889413, 0.031346390822104046, 0.016742534370028546, 0.018945135375750915, 0.019236751067052995, 0.03240205899679235, 0.018346714986754314, 0.05510830380288618, 0.05447611951136163, 0.011905849395718957, 0.04398224635847977, 0.015645546805379645, 0.011004234963495816, 0.002993689292842256, 0.028747269218521457, 0.014547756873071194, 0.02379586348044021, 0.0885891452697771, 0.003964042291045189, 0.029534420730280023, 0.05260255879589489, 0.06129009369760752, 0.02402762390140976, 0.037223827226885726, 0.03771644365042448, 0.059871826586978774, 0.022397436733756746, 0.019837139207603674, 0.05455528758466244, 0.012625088881967323, 0.04779464625088232, 0.041583122951643806, 0.010666481435431965, 0.05094188165717891, 0.02233258744568697, 0.0105419982490795, 0.013475551951809652, 0.019209214419658695, 0.017600044874208312, 0.06244892294385603, 0.08176386329744544, 0.03487352441464152, 0.025121776886018257, 0.003106257404267256, 0.02836288930848241, 0.03897626944152372, 0.053339254443666766, 0.05891900057239192, 0.027872286437611495, 0.04538847965055278, 0.03256879879959992, 0.016651737902845656, 0.03934351294966681, 0.016375384160450528, 0.024980349832081368, 0.011824379392367388, 0.05246672287051167, 0.053766958814646514, 0.019393862457945943, 0.01846881227434746, 0.02472330380364188, 0.018911001671637808, 0.031173717230558395, 0.057608545890876224, 0.05252374016812869, 0.020439581612923315, 0.018716760844524418, 0.11229588317551784, 0.046671307778784206, 0.07608920029763665, 0.01734912601698722, 0.025143547682091594, 0.07002729057733502, 0.21343575497823103, 0.10358615339334522, 0.11689380609563418, 0.17710891711924756, 0.16319409092622145, 0.1230402612792594, 0.11898484746260302, 0.06276290145303522, 0.08050762356391974, 0.13219223304518632, 0.08861342325274434, 0.0722064668578761, 0.13961634252752575, 0.08585413345800978, 0.11201811129493372, 0.1186783667653799, 0.19586278365126678, 0.15065441094338894, 0.16843364334532193, 0.18258473543184145, 0.17880966514348984, 0.111777502777321, 0.174251239746809, 0.10434570549322025, 0.1416201242910964, 0.08004628760474068, 0.10086684966725962, 0.15059138861085686, 0.14013835308807238, 0.10074226385248558, 0.0979245589779956, 0.09533421083220414, 0.15765298397413322, 0.16059801594487258, 0.11139954520123345, 0.09820523498845951, 0.15111003363771097, 0.18727888140295232, 0.09750818953450237, 0.14789476831044468, 0.0674969113564917, 0.15086857016597474, 0.1423835711819785, 0.20268177560397557, 0.16837876343301364, 0.14253768005541392, 0.1252870535744088, 0.12177483418158122, 0.08271011430770159, 0.18612662037568434, 0.16513639741710254, 0.08829751770411219, 0.10605221427977085, 0.11484836228191853, 0.10994743276387453, 0.1651855097817523, 0.22399886245174067, 0.09687323003475155, 0.1561385073832103, 0.08417098663215127, 0.09497243631631136, 0.10074911705617394, 0.10734174294131142, 0.19640893648777688, 0.20230742783418723, 0.09226227245692696, 0.20204378983804158, 0.15574233792722225, 0.13860791735351086, 0.16076707973011903, 0.07378004384892327, 0.08354971996907677, 0.1348334713173764, 0.14168839848467282, 0.07061516653214182, 0.06798511730240923, 0.11688489014548914, 0.12893934973648616, 0.10031216086021491, 0.09583826057080712, 0.1790827483470951, 0.11257038451731205, 0.06533123792282172, 0.2641949648303645, 0.13434477682624543, 0.12087889654295784, 0.14369383587368897, 0.12584624785397733, 0.2562904932669231, 0.11337742728314229, 0.09583331405052117, 0.08122788170086485, 0.06904559968305485, 0.08797866052814893, 0.19945477162088665, 0.10764946535761867, 0.09220425092748233, 0.101307239250413, 0.17072078133268015, 0.1686413971973317, 0.12257554621568748, 0.12832617121083395, 0.14336470567754336, 0.14033998655421392, 0.13954261291239942, 0.14310606169913495, 0.08276381356907742, 0.1091675924669419, 0.11331630484866244, 0.14173109190804617, 0.09954036120325327, 0.12824130005070142, 0.11320440085338694, 0.11203836556524038, 0.11954877791660172, 0.13183145597577095, 0.11528445673840386, 0.05265682124133621, 0.17736581047730787, 0.13911201458956513, 0.16318845908556665, 0.11035859784377472, 0.13552350071924074, 0.09930294858557837, 0.13210432204817021, 0.1579571712229933, 0.12887483462691307, 0.10278994683176279, 0.08161242785198347, 0.17880373474742683, 0.09236906029816185, 0.15946840441652707, 0.20544566586613655, 0.1939035952091217, 0.18327035435608455, 0.1419861532215561, 0.13198840112558433, 0.14670182232345852, 0.1234432432268347, 0.23341091669031552, 0.03484891734219023, 0.1170530446938106, 0.14319969953170844, 0.16437813453376293, 0.18703535518475942, 0.11022213766617434, 0.09008501643048865, 0.16784308717719146, 0.1282852284078087, 0.15699411290032522, 0.130602859758905, 0.09990590837384973, 0.17809590058667318, 0.08550226555338927, 0.08786818824176278, 0.08960164843925408, 0.10585155111870595, 0.08150448650121689, 0.06064627253051315, 0.12813029172165052, 0.1143714471587113, 0.07176586014351674, 0.13195916983698094, 0.17123710576977047, 0.11270052074853863, 0.13094154372811317, 0.11391920356878213, 0.2035685530198472, 0.12137168938560144, 0.24443021682756289, 0.13556274718471936, 0.09941245056688786, 0.1651510809149061, 0.11680746929986136, 0.09148835577070713, 0.13769676695976937], [0.060669539496302605, 0.02419267245568335, 0.014727633113839796, 0.02141968303892229, 0.046164143564445634, 0.01441111009834068, 0.02908470807597041, 0.030699475535324643, 0.020726299977728298, 0.026805933032717024, 0.07691018017274992, 0.052838057944817204, 0.03669847488137228, 0.04575968241052968, 0.014243454273257936, 0.023493776297462837, 0.029678086949778453, 0.017863218073866198, 0.03566969704947301, 0.03776442964694329, 0.03831216347004686, 0.06772994742329631, 0.021971613601116196, 0.013542048383637198, 0.05805490658219371, 0.00726233994854348, 0.031898989741291316, 0.02676652541517147, 0.01873233831221504, 0.0132370638561302, 0.03324550177369799, 0.032257405508841784, 0.02414799771005554, 0.015400103725759047, 0.01541123678907752, 0.02742635322335575, 0.12134940629558903, 0.014891648598547493, 0.03722392900713852, 0.03795315059167998, 0.04506466577627829, 0.05521275409098182, 0.037099227841411314, 0.003598478581157646, 0.02198551847998585, 0.03181093964459641, 0.02755758528863745, 0.049646615982055664, 0.022957601318401948, 0.015006115759855934, 0.013363279003117765, 0.05098945714001145, 0.047705907441143475, 0.01607350053797875, 0.0649677806400827, 0.028319715821583356, 0.042723628359713724, 0.04519050348816173, 0.11786503397992679, 0.0689650032935398, 0.0396350964105555, 0.03835058890815292, 0.03861513274854847, 0.026212219980412295, 0.07016154551612479, 0.024921346123197248, 0.017051705458600606, 0.02264608080232782, 0.09266777176942144, 0.04352696293166705, 0.007069484181036907, 0.07075170134859425, 0.017341209209657142, 0.03966620045581034, 0.019439231005630324, 0.052921361689056666, 0.052431018357830386, 0.032256346994212697, 0.011006661574356258, 0.006256572087295353, 0.03434150206989475, 0.05281587324238249, 0.008594902997304286, 0.006687445216812193, 0.06682679017207452, 0.040669217705726624, 0.0350751985928842, 0.008700735800500427, 0.02749164355918765, 0.01780704894502248, 0.03653024569419878, 0.03381839906796813, 0.015471626405737229, 0.06153043758656297, 0.01656255804534469, 0.036339288976575644, 0.03444558594908033, 0.026146960178656236, 0.048697243710713725, 0.04620694216074688, 0.07112159114331007, 0.060776510541992526, 0.02598112791643611, 0.05364093789830804, 0.023321976319753697, 0.08278503814446074, 0.028745868043707948, 0.05512643765125956, 0.02555368817411363, 0.029262491036206484, 0.019398876831733754, 0.04106233375413077, 0.020742532231711915, 0.05038551686863814, 0.07158270997128316, 0.06806841426129852, 0.03076436383915799, 0.03549857730312007, 0.03961705416440964, 0.018130951028849398, 0.03544509856562529, 0.07850766873785428, 0.034579566081187556, 0.041151988586144786, 0.020869861024298837, 0.05404973149831806, 0.030412512897912945, 0.02816154421972377, 0.0437904550427837, 0.034858192915895155, 0.04213390678965619, 0.03450860149626221, 0.07379923281925065, 0.00996004929766059, 0.06794433056243829, 0.006336883916186967, 0.03274415260446923, 0.018938975974119136, 0.027814351421381747, 0.009261511914831187, 0.048713443734283955, 0.020536393293046525, 0.004931727374371673, 0.04187923902645707, 0.03286603106451886, 0.05574741593695112, 0.06365986367953674, 0.04150035525006907, 0.03941711703581469, 0.04311756882816553, 0.013242431068127709, 0.050133067914949994, 0.016628177470660636, 0.014484229031950235, 0.05444009269454649, 0.06300673979733672, 0.025596897284101163, 0.0375094972550869, 0.033140318667782206, 0.044248917406158786, 0.02427147072739899, 0.042613366419183354, 0.016585819922121506, 0.03502602855275784, 0.025293688822005476, 0.0771980079423104, 0.046662100058581145, 0.021083889628893564, 0.09589091488825423, 0.025183192786893675, 0.016746429161035588, 0.044659040934805355, 0.028543583183948482, 0.011637702534374381, 0.03047646821609565, 0.033754674451691766, 0.044139144010841846, 0.014867740417165416, 0.023207047754632573, 0.05267325196681278, 0.045430301156427176, 0.03000674895676119, 0.04312386902581368, 0.05156860713447843, 0.01925341927978609, 0.05339575605466962, 0.05963256156870297, 0.007502949314324984, 0.014482619207618492, 0.043915604041623216, 0.020093667853091444, 0.019077721118394817, 0.025958483506526266, 0.0173893241278295, 0.08013613242655993, 0.06257523902292762, 0.03341367328539491, 0.055180940976632495, 0.07333816148872886, 0.00620341268534373, 0.05464197043329477, 0.06112586786704404, 0.007811854926070997, 0.027675036307690398, 0.03296748222783208, 0.006561163912660309, 0.0566685543661671, 0.037852235471031496, 0.02917406435257622, 0.022501557932368348, 0.07600377952413899, 0.01957434768389378, 0.0462162177344518, 0.047146102480058155, 0.012830535714913691, 0.04213025287858077, 0.03139479751033442, 0.041551320015319755, 0.06619443624679532, 0.023246075392567685, 0.023870931505890827, 0.07722945804042475, 0.029271909102265323, 0.005518616060726345, 0.017368091070758443, 0.010459201709766473, 0.015974074801696197, 0.03203427605330944, 0.022169906978628466, 0.07921460723238331, 0.04364304670265742, 0.05176178944696273, 0.033304232372237105, 0.042028886532144885, 0.04505020619503089, 0.016682562052405307, 0.03270110634288617, 0.028175213307674443, 0.040789206445749314, 0.025794853090441654, 0.04312146361917257, 0.02482928249186703, 0.05337684189102479, 0.03917610139719077, 0.09634545192654644, 0.027559946590502347, 0.004069810209330171, 0.016034213360399008, 0.043674147355237176, 0.029130329377949238, 0.042075389929647954, 0.02469491389846163, 0.02419127128086984, 0.047689089950706275, 0.012396340308311795, 0.024137548270768354, 0.030558849152709757, 0.0538156131681587, 0.05123510378013764, 0.042188145486371856, 0.06847127407257046, 0.041077197063714266, 0.03879972480769668, 0.02897618997043797, 0.05615043520395245, 0.029802676157227585, 0.07232759892940521, 0.04178537727732744, 0.0048585940218929735, 0.04196134176371353, 0.026709170546382666, 0.05089020782283374, 0.06848629683788333, 0.04983886870156441, 0.08307138670768056, 0.08275786960231406, 0.008072707535965102, 0.09839601867965289, 0.05586379487067461, 0.03965728111299021, 0.035056009622556825, 0.07321037298866681, 0.01393993029237858, 0.044141457815255435, 0.026108097085463147, 0.015828573144972324, 0.019108533393591642, 0.03668047674000263, 0.015653894482446567, 0.03209061481590782, 0.0434783425049058, 0.051552902441471815, 0.027773054083809257, 0.03413746319711208, 0.014088437011066293, 0.021047788173226372, 0.022433100534336906, 0.031786726122455936, 0.017886983762894357, 0.0745232364694987, 0.023455544241837094, 0.01639681399267699, 0.046445901838264296, 0.02916382865181991, 0.06930950909320797, 0.031922524728413136, 0.053035406462316, 0.1284571284694331, 0.053193108178675175, 0.012911807246772307, 0.03134713721062456, 0.04528074525296688, 0.033043461186545234, 0.060178653337061405, 0.010260403671834086, 0.06437916508210556, 0.05051388551614114, 0.03376093393723879, 0.06187304348817893, 0.0032780908846429414, 0.03370578261092305, 0.05359821054818375, 0.02926940530804651, 0.014899051415600946, 0.07620941634689059, 0.026881408179178834, 0.027125411068222353, 0.014961500386042255, 0.019881766455780183, 0.013408335424693567, 0.03753391094505787, 0.05685649160295725, 0.050867527789835415, 0.03522273924733911, 0.041094632021018436, 0.01289408391208521, 0.018579949525051882, 0.033531341435653825, 0.03830397355237177, 0.021448754871796285, 0.05061146563717297, 0.043220037794006724, 0.036797615632947, 0.015097504248842597, 0.020110751668523465, 0.04341318617974009, 0.02486488183162042, 0.023756956282470907, 0.03058520345283406, 0.01584340083146734, 0.04150755789929202, 0.05673188543213265, 0.1334628848625081, 0.20458023516195162, 0.11644484661519527, 0.1490166445395776, 0.1785338542291096, 0.08550219769988741, 0.13181166989462717, 0.08570182270237378, 0.10471579884844166, 0.158314067072102, 0.25380662083625793, 0.2073692719319037, 0.14183687551745347, 0.15220034441777638, 0.0825483515592558, 0.106111273967794, 0.08845319399344069, 0.07648453515555177, 0.11845886068684713, 0.15994719229638577, 0.12322780835841383, 0.162534039201481, 0.19497124291956425, 0.08580312798065798, 0.12832915676491602, 0.15561214062784398, 0.10947289929858275, 0.1346312543111188, 0.08797294047794171, 0.09795253497681447, 0.21104201913944312, 0.1622895494635616, 0.0825715913836445, 0.10260615205126149, 0.2037665902503899, 0.0989841931898679, 0.1490194672452552, 0.09405553873096194, 0.11784383654594421, 0.11600392098937716, 0.10275652898209435, 0.12567901611328125, 0.2131774774087327, 0.1175570333642619, 0.15235073491930962, 0.1514654095683779, 0.17829708621970244, 0.10803847626916, 0.06839402964604752, 0.08050465158053807, 0.0816223548193063, 0.13507139283631528, 0.13292335452777998, 0.15775241649576596, 0.09606711007654667, 0.1022203913224595, 0.13518734090030193, 0.1305104840014662, 0.1791002002677747, 0.12972258270851203, 0.1106933598805751, 0.13031205322061265, 0.12623312138020992, 0.12577725441328116, 0.31266440397926737, 0.08594895194151572, 0.13316207671804087, 0.110732070303389, 0.2493620536157063, 0.14173824366714272, 0.09027428698859044, 0.14238898589142732, 0.21834640790309223, 0.12308876296239239, 0.11551878202174391, 0.1542716132743018, 0.15863329065697535, 0.16601690516940185, 0.11175374726631812, 0.1309447871255023, 0.1018515464716724, 0.13685950902955873, 0.07140514414225306, 0.1312878815723317, 0.1797674037516117, 0.11759311785655362, 0.0886299048683473, 0.07984118003930364, 0.21136170412812913, 0.10037416539021901, 0.25062369448798044, 0.12256056416247572, 0.08337300909417016, 0.169995535963348, 0.09544878147010293, 0.17710936495235988, 0.13943872920104436, 0.12985841184854507, 0.17396063676902226, 0.18300231945301804, 0.0731677542041455, 0.2065515693809305, 0.1207652147859335, 0.170928100922278, 0.11973352943147932, 0.19375034128980978, 0.18261259607970715, 0.19558104234082357, 0.07699427780296121, 0.1113399766119463, 0.19966940581798553, 0.10724367427506618, 0.15522514496530804, 0.10717455191271645, 0.14248855412006378, 0.09519251914960997, 0.1126836659386754, 0.08859206975570746, 0.07219317435686078, 0.10373537681464638, 0.1610979741173131, 0.17318619761083806, 0.11994065903127193, 0.17309600673615932, 0.1167128679475614, 0.10936302412301302, 0.09984997673226254, 0.09836908762476274, 0.15982762085539953, 0.13346648109810694, 0.15661044205938066, 0.2088779674044677, 0.10454126607094492, 0.09885106461920909, 0.13100859655865602, 0.12279726431838103, 0.11081958096474409, 0.10704260399299008, 0.18177761802715914, 0.11365991498210601, 0.13775628805160522, 0.07511965518019029, 0.1935628077813557, 0.12721448657768114, 0.10825131913380963, 0.12140372980918203, 0.17932326186980518, 0.25636768341064453, 0.15991561327661785, 0.17338833319289343, 0.09573738276958466, 0.09480541492147104, 0.10762723655040775, 0.11407852359116077, 0.14343455407236302, 0.1869365604860442, 0.09300639467047793, 0.09832760199372258, 0.1772320576544319, 0.11015105433762074, 0.13678178962852272, 0.12292192477200713, 0.1468745366271053, 0.09526100368904215, 0.09628160178129162, 0.16558870886053356, 0.1010149127936789, 0.17428777207221302, 0.2173088871474777, 0.14436410633581026, 0.0957849480743919, 0.12163124260093484, 0.14129024770643028, 0.08246209618768521, 0.1507144748632397, 0.12340690089123589], [0.03111749721158828, 0.047623037959315946, 0.022868087282404304, 0.04377758323347994, 0.05996541692210095, 0.05486406173024859, 0.027008828573993275, 0.015468540767739927, 0.02858982534546937, 0.015382051301587905, 0.02965894208422729, 0.06111761009586709, 0.036432004001523764, 0.04508988692292145, 0.03664734048236694, 0.0401615242340735, 0.06409136445394584, 0.032004576575543196, 0.036260385531932116, 0.007222688058391213, 0.014750211366585322, 0.04516351815047009, 0.018757344023989778, 0.05844794799174581, 0.04799588955938816, 0.01589929684996605, 0.038181090860494545, 0.0232995083289487, 0.025485283362546136, 0.04510299961215683, 0.0523334687708744, 0.02231950529052743, 0.06485136438693319, 0.05046882739822779, 0.05838784335979393, 0.004254555362941963, 0.021282973499702554, 0.02306170555363808, 0.033078276818352084, 0.01759156827548785, 0.01865260535851121, 0.029164418977286135, 0.05871286163372653, 0.037046665126191716, 0.0702554751187563, 0.03671954678637641, 0.013723646407015622, 0.0539786719184901, 0.04446472207616482, 0.021915897394397428, 0.04586887565840568, 0.05587050218933395, 0.041076986717858484, 0.06265485153666564, 0.04438283647011433, 0.03383338451385498, 0.03168195013755134, 0.04831100122204848, 0.047653130987393, 0.030444977405880178, 0.03342450609696763, 0.0708076058487807, 0.0655116807403309, 0.04431422979437879, 0.021773688328851546, 0.09387662261724472, 0.04830433800816536, 0.05247993055464966, 0.032253239303827286, 0.023245513904839754, 0.02628964082604008, 0.022337233714227165, 0.02204562650461282, 0.02386039385705122, 0.025736354890146425, 0.018415328447840044, 0.07511411833443812, 0.0382474821193942, 0.025200583639421632, 0.02644801089939262, 0.023411113768815994, 0.02648116581674133, 0.04072162096521684, 0.02167752125699605, 0.02399265220654862, 0.10955261359257357, 0.07267372642776795, 0.07203729450702667, 0.01612693177802222, 0.06883741156863314, 0.03191931865045002, 0.08078470333878483, 0.029721889777907302, 0.04420687537640333, 0.005641271019287939, 0.07827510086021253, 0.0029019636567682028, 0.04586964240297675, 0.029246704918997626, 0.05434703840208905, 0.03401754231059125, 0.08532522898167372, 0.07868634057896477, 0.06610769233001129, 0.0814144177628415, 0.022274520115128586, 0.07121268446956362, 0.06720301069851432, 0.007351730151900223, 0.05717979318329266, 0.014506719075143337, 0.025436125196782605, 0.008190094094191278, 0.029246701526322534, 0.01704283700590687, 0.03438302841303604, 0.020089988496952822, 0.03784704128546374, 0.020377052914617316, 0.09434654204440968, 0.014406857380111302, 0.0357847189131592, 0.01183182037701564, 0.013250848295034041, 0.02846690533416612, 0.03814693680033088, 0.05946600157767534, 0.04943949316761323, 0.044950844919575114, 0.05828537778662784, 0.05341728597081133, 0.012893669157555061, 0.016557009325229695, 0.04336001956835389, 0.04446195704596383, 0.04335058793159468, 0.0380857295489737, 0.028239362008337463, 0.020622782675283294, 0.00811627202866865, 0.022661254541682344, 0.030047888534941843, 0.038214878511748145, 0.052646996054266176, 0.04336410095649106, 0.045827050759856186, 0.009482494655198284, 0.025284833940012113, 0.038046025072357485, 0.08364193966346127, 0.008611368497700563, 0.029116097105933086, 0.02728300930799118, 0.01436792643341635, 0.011724597425200045, 0.04448454886940973, 0.009197450575551816, 0.052495767561984916, 0.03352981133918677, 0.02602883062458464, 0.03294498539928879, 0.0501225234807602, 0.02238230201016579, 0.02378688137313085, 0.013356600522196718, 0.021591080984632884, 0.0635627449623176, 0.05961555748113564, 0.0373636054407273, 0.049557568438883336, 0.06075529953730958, 0.02635964358757649, 0.10551655837999922, 0.042062874351228983, 0.012787999202763396, 0.008864316174627414, 0.046525555064103434, 0.0937448986140745, 0.0406320780914809, 0.020799549529328942, 0.044336207543632815, 0.04473499953746796, 0.02622152608819306, 0.06751941157771008, 0.04732999225546207, 0.04746081041438239, 0.01349996988262449, 0.039850348074521334, 0.029733770926083838, 0.0465978665410408, 0.02356024389155209, 0.021451959253421853, 0.02978546850915466, 0.0150557081880314, 0.054428333682673316, 0.03813298612034746, 0.043491635005921125, 0.04012236258547221, 0.04332364330600415, 0.09650749965970006, 0.011951268833529736, 0.024001976974042397, 0.05977824303720679, 0.06113248358347586, 0.04071215879438179, 0.016635541271950518, 0.08542234769889287, 0.015502694827903594, 0.051068988229547224, 0.04532216642318027, 0.07013299276254006, 0.007294398183668298, 0.024201946333050728, 0.034834471331643205, 0.019981614580111842, 0.02168613356272025, 0.03146646098632898, 0.06371029918747288, 0.017686590319499373, 0.03829166831980858, 0.01721312554686197, 0.0360341280299638, 0.03192633809521794, 0.0563383181579411, 0.03892640729567834, 0.03073229966685176, 0.031959243650947294, 0.005596279482623296, 0.05829265846737793, 0.039423179746206315, 0.03154050612023898, 0.04154775431379676, 0.05029904775853668, 0.0028835916850117166, 0.056234811033521376, 0.05409796855279377, 0.002790855455844264, 0.0378804489571069, 0.03886473864050848, 0.022867831135434762, 0.043451767680900436, 0.06537226215004921, 0.011025330617225595, 0.10585780721157789, 0.02821781512882028, 0.031657756971461434, 0.03411297147561397, 0.020834845224661485, 0.007830523120771562, 0.016552948293143084, 0.02120009044717465, 0.026956075868968452, 0.014722347326044525, 0.0541788329636412, 0.025825409218668938, 0.031623131329459805, 0.005866619284331266, 0.06448638718575239, 0.03788001469469496, 0.04749448271468282, 0.010527556479376341, 0.0455926949424403, 0.016577784371163164, 0.06892647607518093, 0.03627834974655083, 0.05076888236882431, 0.028337237292102406, 0.04964685686198728, 0.004489638485080961, 0.03632361142496977, 0.09354791311281067, 0.05765689829630511, 0.014141428051516414, 0.13896490819752216, 0.055504578431802135, 0.04196417125474129, 0.04380905368764486, 0.046060426094170125, 0.05687568735863481, 0.0631901410275272, 0.015820215289880122, 0.07431576081684657, 0.021709855146972195, 0.02504959263439689, 0.013306527182326784, 0.011632253898174634, 0.023355268640443683, 0.08582902087696961, 0.016177533527037928, 0.0170814032400293, 0.0140730206954426, 0.017755609205258743, 0.028615982870438268, 0.0817368643890534, 0.014301591153655733, 0.055511954107454846, 0.0289408824007426, 0.01715276307160301, 0.06122832665485995, 0.03614330770713942, 0.026158664907727922, 0.039502873684146574, 0.02150664578324982, 0.055247298308781216, 0.019977594260126352, 0.050417648894446235, 0.04331922943570784, 0.02450917681146945, 0.02245675426508699, 0.006461838684377393, 0.015140682824754288, 0.015789725318817154, 0.08794953101979834, 0.04128764130707298, 0.026759921573102474, 0.036133513054145236, 0.022949660762346218, 0.05751027366412537, 0.05799103608088834, 0.02876073813864163, 0.01806194401745285, 0.017587851599923203, 0.014330486567424876, 0.018695422614525472, 0.020663834043911526, 0.031099834945052862, 0.025389326636546423, 0.03958230299342956, 0.04797330791396754, 0.02175361047764974, 0.02308498609012791, 0.028703368002814904, 0.014510715646403176, 0.02784835111482867, 0.036632867330419164, 0.018405501564432467, 0.06699250199432884, 0.05802706629037857, 0.025608422201392905, 0.016154073178768158, 0.028831984315599715, 0.039699272252619267, 0.036897618123995404, 0.049121494338448556, 0.03969767090997525, 0.04400024449984942, 0.01975454792513379, 0.033677894821656604, 0.018673889305708662, 0.08723379192607743, 0.04475760153893914, 0.01523562683723867, 0.17081968459699834, 0.2394603006541729, 0.15975689036505564, 0.11280907956617219, 0.14632165272321018, 0.13536219937460764, 0.1319405644067696, 0.10471027557338987, 0.11253066986267056, 0.10945558987025704, 0.12435660564473697, 0.13798821132097924, 0.11411969709609236, 0.14968056391392434, 0.24926477883543285, 0.14330025842147215, 0.12614649959972926, 0.09348933518465076, 0.1550636672015701, 0.060277651596282206, 0.0994290950308953, 0.16450694762170315, 0.07413287527327027, 0.15574054659477302, 0.13125848743532384, 0.09369142326925482, 0.12855745665729046, 0.11869773215481214, 0.07897707247840506, 0.14014513843825885, 0.11289089731872082, 0.0749607558495232, 0.11291370966604777, 0.14638391509652138, 0.13493071895624908, 0.10708814726344176, 0.06452082962329898, 0.1155460998415947, 0.08020002328391586, 0.05346707008512957, 0.18813065998256207, 0.13041356205940247, 0.10306056695325033, 0.14848916498678072, 0.15996878328067915, 0.17665001031543526, 0.09644886744873864, 0.10008064471185207, 0.11362556075411183, 0.09849323917712484, 0.13901285348193987, 0.13284669364137308, 0.18619850437555993, 0.16431873557823046, 0.09649722663951771, 0.12906832567283086, 0.11777782865933009, 0.09072540421038866, 0.1297950909606048, 0.1539415874119316, 0.14489900906171116, 0.17754634150436946, 0.17039922358734266, 0.0832367864038263, 0.10841668490320444, 0.2395091823169163, 0.14892380737832614, 0.18959347291716508, 0.1292232216468879, 0.14277614440236772, 0.10335064067372254, 0.10656178050807544, 0.11998987996152469, 0.09246284740843944, 0.09356489684432745, 0.1488228142261505, 0.12493103982082435, 0.12215051188000611, 0.10439023774649415, 0.1412807075040681, 0.08448421875280993, 0.13461316456752165, 0.10125938896089792, 0.1353380706693445, 0.13376598645533833, 0.24677165118711336, 0.1047049422881433, 0.20688375298466, 0.09542990462588412, 0.17477429525128432, 0.09116519668272563, 0.12613344458597048, 0.1057929392637951, 0.11376309980239187, 0.2226246797612735, 0.1882886772177049, 0.10879677986460072, 0.21186292437570436, 0.11188229572560106, 0.16014554165303707, 0.18181324111563818, 0.13038785915289605, 0.22349135896989278, 0.11342609860002995, 0.19971361915980065, 0.1257203524666173, 0.1689008418470621, 0.10101557097264699, 0.16031460543828352, 0.13532307504543237, 0.09913723676332406, 0.1427426112017461, 0.08700606200311865, 0.11697601739849363, 0.04743629494415862, 0.07833117499415364, 0.08602825911449534, 0.18061737742807182, 0.09617353829422168, 0.166039215400815, 0.12607826611825398, 0.06844577472656965, 0.17085747899753706, 0.07368184626102448, 0.10002013295888901, 0.15976022875734738, 0.1931617935853345, 0.2235767458166395, 0.21320237964391708, 0.15551101176866464, 0.2004175992416484, 0.11466582279120173, 0.09335529059171677, 0.11314055070813213, 0.11519001823450838, 0.11753985285758972, 0.18950858818633215, 0.11038810733173575, 0.12813491933047771, 0.12220459112099238, 0.07073011036430087, 0.1163866011691945, 0.12715223777507031, 0.14061719525073255, 0.13747188688388892, 0.07240493835083076, 0.12766374461352825, 0.06020701610084091, 0.1232060816671167, 0.2416242573942457, 0.09649871263120856, 0.08645101357251406, 0.14759918488562107, 0.0973363776824304, 0.12237410273935113, 0.09379000083676406, 0.0761468011353697, 0.07268258130976132, 0.22102082653769425, 0.09583794844469853, 0.1585235579737595, 0.17420131314013684, 0.08980708170150008, 0.11715411927018847, 0.14364886257265294, 0.11134492313223225, 0.11313003341534308, 0.1486587987414428, 0.12402192503213882, 0.13762971412922653, 0.23355742597154208, 0.16565464889364584, 0.20903622891221726, 0.17837131795074257, 0.1609290867511715, 0.12147123047283717], [0.022458240256777832, 0.019616902007588317, 0.05358328277777348, 0.025598926103806922, 0.03575750287356121, 0.0210231488703617, 0.043522766192576716, 0.017590706536014165, 0.030001615839345113, 0.06352702687893595, 0.030564416532537768, 0.01340833627286234, 0.005564236938620785, 0.06197279492127044, 0.02450823025511844, 0.01783639388824148, 0.06034471121217523, 0.03000037412026099, 0.029085373040288687, 0.02627218551268535, 0.024534406439800347, 0.02230245540184634, 0.02964344434440136, 0.017133597850001285, 0.027169203718325922, 0.07302611001900264, 0.045886802553598366, 0.011337975805093135, 0.07217943402273314, 0.018257786187210252, 0.0367685980828745, 0.02671525700549994, 0.051383954007178545, 0.03522483592054673, 0.015034880555633987, 0.048803763530616245, 0.04830013448372483, 0.0011561101231823809, 0.06268108370048658, 0.021023854546781098, 0.04128725793478744, 0.03604467924950378, 0.0397776226912226, 0.047705910833818574, 0.04287489417142101, 0.02975926687940955, 0.10820633904742342, 0.03626804279961756, 0.07645527672554765, 0.04419767104887536, 0.028294023093102232, 0.018711223998772245, 0.040444259598319016, 0.02613012402850602, 0.06381670704909734, 0.050429156848362515, 0.029406482952513864, 0.04555952475805368, 0.02160736752141799, 0.03458946590710964, 0.03272722654842904, 0.046992855346096415, 0.01833615867820169, 0.023693630305517997, 0.03361869264127953, 0.036839959610785754, 0.08148813380726747, 0.05995131017906325, 0.05351139199254768, 0.04327528750790017, 0.04481442206140075, 0.027113265291388546, 0.014528193012146013, 0.02952746913901397, 0.0012502172051296967, 0.017001478600182703, 0.03616634736369763, 0.0697254239182387, 0.07837128998445612, 0.00921033850006227, 0.012532003207265266, 0.02807025581465236, 0.033657260571739504, 0.015191530542714255, 0.07006606206830059, 0.04961888764851859, 0.012536046427807637, 0.03438061622104474, 0.060259168302374225, 0.05796611348965338, 0.03975028790799635, 0.04616068982120071, 0.0315329167060554, 0.055271691642701626, 0.022225005718480264, 0.022439468585486923, 0.0614405113405415, 0.02447677676432899, 0.050680438721818585, 0.043779059047145505, 0.07471703285617487, 0.061870498981859, 0.0393949764381562, 0.045403061368103535, 0.023197673793349947, 0.04501906143767493, 0.026669983452718173, 0.06993815143193517, 0.06671199561761958, 0.07522410207561084, 0.013526039198040962, 0.07212708504604441, 0.05569064291194081, 0.04871289412091885, 0.05732316763273307, 0.018720209498756697, 0.014024880332207041, 0.06868152493344885, 0.07077156885394029, 0.025618788520140306, 0.03607868742463844, 0.0549850445240736, 0.03300955479166337, 0.01285118268736239, 0.019711571213390146, 0.026564973373232142, 0.03399386822379061, 0.02082863662924085, 0.0338790600986353, 0.027093501262632862, 0.048732018630419455, 0.05379663115101201, 0.017148800427094102, 0.03322202446205275, 0.0461830339793648, 0.06752966424184186, 0.044830873142927885, 0.06107683014124632, 0.0433611187950841, 0.07410050236753055, 0.032066743953951767, 0.037654659644301446, 0.032378747926226685, 0.08506404728229557, 0.06001421716064215, 0.07318848344896521, 0.02782307398904647, 0.07139668281057052, 0.07098263395684105, 0.0374500066973269, 0.023336915964526788, 0.02383427874052099, 0.0346127769776753, 0.03887821434597884, 0.008639266464992293, 0.014260030883763517, 0.03368895833513566, 0.018625896523839662, 0.031620678425367386, 0.026836938690394163, 0.03706008994153567, 0.022596317044060146, 0.04127404007262417, 0.032270745507308414, 0.018720653939193914, 0.06283804242100034, 0.004949619494644659, 0.03875984051930053, 0.03390916669741273, 0.0030419653630815446, 0.02189294934006674, 0.015389080924381102, 0.008333474480813103, 0.026920130476355553, 0.018072812452114055, 0.0349237868961479, 0.03579843889123627, 0.04721989994868636, 0.04159053594672254, 0.0437437684408256, 0.020912534091621637, 0.021188638472397412, 0.08186284798596587, 0.0028849112235807945, 0.015971693143780743, 0.05952879999365125, 0.03804482067269938, 0.02651478044156517, 0.009283141066719378, 0.05350481020286679, 0.003105667502885418, 0.006885059635221426, 0.010239619296044111, 0.051143725469176254, 0.03969392539667232, 0.03377493550734861, 0.07617186621895858, 0.00953869431811784, 0.034819285717925856, 0.07629081340772764, 0.01877898589840957, 0.061136222311428616, 0.07813525479286909, 0.051688850325133116, 0.11698219206716333, 0.04244201936359916, 0.002107963606249541, 0.029431188412542855, 0.06321666496140615, 0.048363126282181056, 0.008268233338770057, 0.056965342190648825, 0.05004402037177767, 0.08908413656588111, 0.019220125262758563, 0.05267874810046383, 0.018242583610117435, 0.025748795829713345, 0.016091778575043594, 0.02998773640553866, 0.05940322351774999, 0.029642066918313503, 0.022723611909896135, 0.03044624626636505, 0.0252169668674469, 0.05216402161334242, 0.016333616937377622, 0.004559390612744859, 0.030518852906035523, 0.03613047321726169, 0.02266006880173726, 0.023993144144437144, 0.03533345241365688, 0.03710008279553481, 0.05403920402750373, 0.022252852795645595, 0.0332980102061161, 0.05131204625857728, 0.038702680729329586, 0.036799233938966475, 0.05305896859083857, 0.027493507834151387, 0.019235499169943587, 0.012628629138427121, 0.012167499284259975, 0.08177932032517024, 0.04110216375972543, 0.02520059042477182, 0.027767015122143284, 0.015687341169853295, 0.030628209002315998, 0.011784962444965328, 0.044084623722093444, 0.025374912856412784, 0.04353779574323978, 0.030459236819297075, 0.03815646003931761, 0.08411707023956946, 0.05289774527773261, 0.0014759402547497302, 0.035910278425685, 0.03604027216455766, 0.02610640414059162, 0.04434654502464192, 0.056919245914156945, 0.0037666233755382045, 0.09415856748819351, 0.09290929630930934, 0.037682669569871256, 0.0045141564998110485, 0.03669936376224671, 0.030184952608708824, 0.034329814304198535, 0.03313847644520657, 0.09996477807206766, 0.020456142956390977, 0.08237971525107111, 0.04823261685669422, 0.07544869716678347, 0.0470618894988937, 0.05156002366649253, 0.026233899174258113, 0.027049633973677243, 0.02719771575980953, 0.05185810410018478, 0.05905678389327867, 0.013198137998447886, 0.07508673944643565, 0.07574553588139159, 0.044231502804905176, 0.027373537753841708, 0.025813265138172677, 0.06830356057201113, 0.025010875426232815, 0.043355683729584725, 0.04139981332368084, 0.021997811838186214, 0.02503250033727714, 0.025956561556085944, 0.003626982565037906, 0.025348198932728598, 0.03787589937980686, 0.04442519062597837, 0.009217571683361061, 0.04037339000829628, 0.030918469319918325, 0.010478292292516147, 0.07948637407805238, 0.07081695606133767, 0.024546572572684715, 0.028043519838580062, 0.017336968365790587, 0.05486504560602563, 0.01723471992383046, 0.02008610388397106, 0.010254701433171119, 0.041416305117309093, 0.15452687814831734, 0.025674470800108144, 0.09844880870410375, 0.056265490994389565, 0.040720402994858365, 0.044608629175594876, 0.01794287469238043, 0.014562457334250212, 0.03908802415909512, 0.07193221657403878, 0.014650319137477448, 0.03289581875183752, 0.035321879998913834, 0.014754411498350757, 0.025954425867114748, 0.054394603706896305, 0.01891425355071468, 0.01913455351521926, 0.0556907480848687, 0.00989739507037614, 0.026828256834830557, 0.02891951872568045, 0.031086026757423366, 0.022420820746836916, 0.020616458728909492, 0.019661429171849574, 0.03362685881022896, 0.03135475715888398, 0.020152549425672208, 0.017419698747939298, 0.024600511017654623, 0.01359518785362265, 0.033991547634026835, 0.026877165638974736, 0.04292509897745081, 0.13259157804506166, 0.09296463084008012, 0.14449924337012426, 0.19614227222544806, 0.077932583168149, 0.11777244109128203, 0.10143204219639301, 0.1733297620500837, 0.13652098790875503, 0.21830337521220955, 0.06346397061965295, 0.09628106573862688, 0.13242165930569172, 0.1715852485171386, 0.12263113180441515, 0.12398128078452178, 0.10273845280919756, 0.08185049186327628, 0.17620491848460265, 0.10559908859431744, 0.16313911601901054, 0.08401995152235031, 0.09836523354585681, 0.18891808630100318, 0.07196732397590365, 0.13949502046619142, 0.17146598920226097, 0.15959706822676317, 0.31029805381383213, 0.10193751685853515, 0.10490955452301673, 0.07988276066524641, 0.12994632284556115, 0.1429819847856249, 0.13729815477771418, 0.16750300542584487, 0.15892748987036093, 0.11476896011403628, 0.1391333613012518, 0.09560570626386575, 0.0984707660973072, 0.11556550594312803, 0.1223360640662057, 0.08432633722467081, 0.17903402953275613, 0.09765008477760212, 0.2772827925426619, 0.10537417459168605, 0.10844580762620483, 0.13466778663652285, 0.18790860261235917, 0.11024764379752533, 0.09581487825406448, 0.16934465803205967, 0.1451382197971855, 0.10945437529257365, 0.09885682538151741, 0.11926908578191485, 0.22761751684759343, 0.15208177720861776, 0.06450767961463758, 0.1925498228520155, 0.12612143451614038, 0.09883163137627499, 0.11412683528448854, 0.2209623639604875, 0.15404752029904298, 0.2238289708537715, 0.10593089221843652, 0.15506495641810553, 0.1127068582656128, 0.11317683876092945, 0.12750686731721672, 0.11352131741919688, 0.12539023160934448, 0.10172670959894146, 0.17342105215149267, 0.12699297203549317, 0.1220794285514525, 0.17934428288468293, 0.09421817000423159, 0.14589842329067843, 0.11995505754436765, 0.16406022730682576, 0.16383644645767553, 0.10569366280521665, 0.1342120553765978, 0.14026867252375397, 0.10559648980519601, 0.10681254669491734, 0.25798248818942476, 0.2242221547556775, 0.12535262719861098, 0.13403733260929585, 0.10972281053130116, 0.09833106252231769, 0.14530607579009874, 0.1764650416693517, 0.1582119475517954, 0.1604480054229498, 0.20806386108909333, 0.09164236964923994, 0.12664907691734179, 0.13648445558335098, 0.11059238708445004, 0.10057863513273851, 0.1302210209625108, 0.22050079729940208, 0.1590550137417657, 0.1790599359997681, 0.15395173829581055, 0.1553127166948148, 0.14522121820066655, 0.1835938934236765, 0.14795724781496183, 0.09587548500193016, 0.17008920093732222, 0.14142813959292003, 0.1464510222098657, 0.11594529556376593, 0.12285256492240088, 0.12009567714163236, 0.14500210567244462, 0.108071005237954, 0.12169609697801725, 0.08808310742356948, 0.14902849176100322, 0.13386251484709127, 0.11990732939115592, 0.1504945752343961, 0.12251219818634645, 0.1424046057675566, 0.1843575303043638, 0.10116307091500078, 0.06602024273680789, 0.15514671988785267, 0.12197724117764405, 0.266409268868821, 0.16152668611279555, 0.15038295622382844, 0.09882140585354396, 0.15809977214251245, 0.13312565295823983, 0.20122367170240196, 0.17755822943789618, 0.17006562863077435, 0.15552539671105997, 0.1941602850066764, 0.14514245385570185, 0.11958172757710729, 0.20763495910380567, 0.08085172902792692, 0.1830970836537225, 0.09527165668883494, 0.13078823552599975, 0.16582288486616953, 0.1177438883376973, 0.11264573583113295, 0.07753687511597361, 0.11617454540516649, 0.16145706841988222, 0.1394072858882802, 0.13649289655898297, 0.09355400635727815, 0.11568921644772802, 0.09707470743783883, 0.11948392353951931, 0.11597386188805103, 0.2196569847209113, 0.0980024276567357, 0.1054015059822372, 0.08217501480664526, 0.07085169026894228, 0.10162260197103024, 0.07233986684254237, 0.12159593163856439], [0.06201219066445317, 0.042671937561993084, 0.04090926982462406, 0.05918708975825991, 0.028691205262605633, 0.03656179757256593, 0.029330310611320392, 0.05602476712582367, 0.03613918899957623, 0.03316110219540341, 0.0026220946788920885, 0.012808925222738512, 0.042591476879481754, 0.020775883924216032, 0.02835395809129945, 0.043233333687697134, 0.05218984326347709, 0.03491632979629295, 0.0911091361194849, 0.02321122244133481, 0.034674167433487516, 0.09028916047619921, 0.04347170643242342, 0.06572943619851555, 0.028964179900607893, 0.019277451293809072, 0.030302345952285186, 0.051583321166357825, 0.03864848953006523, 0.04193055662991745, 0.006650223754279847, 0.035892008870307884, 0.05072669445403984, 0.033247883431613445, 0.020564703470362083, 0.023890225649146096, 0.005673158348404935, 0.0036669168953916854, 0.0011872592274033064, 0.027673497729535614, 0.07083031641585485, 0.022183803375810385, 0.07590413665665047, 0.002715814783836582, 0.008800854490670775, 0.02610680617259017, 0.048306271832968505, 0.06289557540523154, 0.04361771359773619, 0.030574217970882143, 0.015551440783643296, 0.022745998476498892, 0.017621259271566356, 0.06815706486148493, 0.031934829960976324, 0.06867475315396275, 0.041968161040650945, 0.022405494337103198, 0.06583106038825852, 0.023036211296649914, 0.052722489860441, 0.01600060043191271, 0.018065988086163998, 0.05383761466613837, 0.07000975723245315, 0.030847782934350625, 0.028648247210575, 0.028538687553788935, 0.02668768134234207, 0.01803233953458922, 0.030940107801663022, 0.0035986274347773618, 0.06610769911536149, 0.027860132179089954, 0.02999896616009729, 0.008501100619988782, 0.03480004925014717, 0.021151432700987374, 0.020586294454655478, 0.02060213655100337, 0.054100031299250465, 0.03582615704674806, 0.017005278396287134, 0.018688377724694352, 0.04799654434568115, 0.01378110220788845, 0.015753488156146238, 0.06432715537292616, 0.02040945296175778, 0.006270031677559018, 0.11865152392004218, 0.058295474387705326, 0.03847972769290209, 0.019680721618767296, 0.008668643638624676, 0.010106353322044015, 0.02294043098975505, 0.05355179196755801, 0.09028407824890954, 0.008486030357224601, 0.05603914189019373, 0.016614060549597656, 0.035760407003441026, 0.02249336292568062, 0.03333588942353215, 0.021098227073837603, 0.05883991053061826, 0.014747149477313672, 0.025986551107572656, 0.014803344051220586, 0.03256773349962064, 0.052495614891605716, 0.04522081704011985, 0.09760584429438625, 0.05175732807921512, 0.03553874318354896, 0.06003272759595087, 0.024560358707926104, 0.03639369730704597, 0.03213293165234583, 0.05069460653300796, 0.05503284053078719, 0.028104705037549138, 0.06141157182199614, 0.01616915361955762, 0.04036534597565021, 0.04162732272275856, 0.0549470906678055, 0.03640016035309859, 0.017697260282667618, 0.03694242179127676, 0.016264643852732012, 0.0809780451069985, 0.06677989661693573, 0.02351186773739755, 0.03193878582013505, 0.004180740082769522, 0.035700600926897356, 0.0162816428512867, 0.058109969698957036, 0.006345907583766217, 0.020865109582830752, 0.04541007063484617, 0.016569112693624835, 0.05392650275358132, 0.06470821385404893, 0.029597504130963768, 0.034355337398925, 0.022438277756529193, 0.08364381242011275, 0.006665268147896443, 0.03620642164189901, 0.04804806550964713, 0.028057411146749343, 0.04950173857754894, 0.0217993895390204, 0.012612774319547628, 0.03224753621699555, 0.03905418901039021, 0.05876903076257024, 0.013741322244251413, 0.07511261198669672, 0.03510725597984024, 0.029306863833750998, 0.03316307333963258, 0.013190752144769897, 0.035404864831694534, 0.017638193809294274, 0.02899286157584616, 0.03190674878922956, 0.11948540274585996, 0.012361448341315346, 0.02359302731097809, 0.025762251179133142, 0.01991026831923851, 0.05993068949984653, 0.0200405758805573, 0.018847324552812746, 0.07743624837270804, 0.028949187669370855, 0.06769241765141487, 0.015949588169210722, 0.05062838151518788, 0.016904700846810426, 0.0221232763558094, 0.09292737926755633, 0.03813919810844319, 0.015197832436699952, 0.06213921241994415, 0.002974183107393661, 0.02988606471834438, 0.042001466932041306, 0.043203478146876605, 0.0398451946010547, 0.013461808225006928, 0.08823663275688887, 0.0563988129475287, 0.07430829014629126, 0.016432053708870496, 0.05912304962319987, 0.02930465859494039, 0.02774591268306332, 0.01762954248780651, 0.009645402431488037, 0.07439438266945736, 0.05072444511045303, 0.04363973205909133, 0.025295174813696315, 0.06206455321184226, 0.018577929187033857, 0.005783960996528289, 0.02780774249030011, 0.007824047352187335, 0.09536365246666328, 0.03497276694646903, 0.03169736306049994, 0.026046825373279195, 0.05363502446562052, 0.05740928051194974, 0.04132096076916371, 0.051059712655842304, 0.026702342787757516, 0.07886195222714118, 0.02523983858658799, 0.06281976947294814, 0.041644839104264975, 0.024557366368493865, 0.021322582981416156, 0.053612290149820704, 0.02631233782241387, 0.07196769038481371, 0.0071202369040942615, 0.028475441304700713, 0.020312597176858356, 0.044618749525398016, 0.033349806176764626, 0.02752209621082459, 0.020434065123221705, 0.08541839862508432, 0.03330898890271783, 0.004362046336089926, 0.019750230746077638, 0.015164053267134088, 0.00688787894822391, 0.06546240552727665, 0.061857505036251884, 0.025992461147585084, 0.031651765507246764, 0.06808225637567894, 0.05837989092937537, 0.05147117289847561, 0.026113778119906783, 0.05857499688863754, 0.017252979301182286, 0.03031289717182517, 0.016760478228596703, 0.008547932258807123, 0.03309587801673582, 0.03523697491203036, 0.004217897084475095, 0.03360056557825633, 0.014384949180696691, 0.0343137160608811, 0.02638470527849027, 0.07202615296202046, 0.02440290804952383, 0.04376056218253715, 0.1041184641154749, 0.05233798102874841, 0.02498458219426019, 0.03754846552120788, 0.013008970068767667, 0.06731137952634267, 0.02409906515718571, 0.0514749421605042, 0.01350335153152368, 0.044905834299113066, 0.01655436643133206, 0.05668309197894164, 0.018114654314039007, 0.00512237535856132, 0.015958729732249464, 0.03241173829883337, 0.06342870036938361, 0.07380584175033228, 0.030186520024601902, 0.0507642683306975, 0.03099180877740894, 0.03495890786871314, 0.04440370142193777, 0.030282882175275257, 0.0034830977300381555, 0.05696730315685272, 0.022481938092304126, 0.016654584357248883, 0.039280497402484925, 0.01854671657617603, 0.024575788594250168, 0.04771294045661177, 0.03470075582819326, 0.060100587883165905, 0.007273328823170492, 0.05601422608430896, 0.05090886414317148, 0.03134641117815461, 0.02640160928214235, 0.08742216003260442, 0.06358099755431924, 0.1457929653780801, 0.02629537783962275, 0.03979322899665151, 0.009538617134759468, 0.023025517584756017, 0.01936899245317493, 0.040624037451509915, 0.01113163076141583, 0.0344178881496191, 0.039836081875754256, 0.07487564041678395, 0.04475948786629098, 0.02742314205638, 0.03536252424653087, 0.015327310488958443, 0.06028966845146247, 0.05921467220676797, 0.025793487538716624, 0.01113162821690951, 0.03761388308235577, 0.03158220209713493, 0.03297522770506995, 0.05977904370852879, 0.0971303948068193, 0.026621169643476605, 0.06704775510089737, 0.021804714342579246, 0.006519199914431998, 0.006619721484769667, 0.024575432363365377, 0.03623752907982894, 0.03046974054138575, 0.019835587058748518, 0.037180292420089245, 0.01619081076101533, 0.022238067517589246, 0.013779940216669014, 0.06561131003711905, 0.08799850767744438, 0.0035968174426151173, 0.024749357852020433, 0.021067282484312142, 0.03929049222330962, 0.0383832332279001, 0.13192634231277875, 0.12123500529144492, 0.125513670699937, 0.15099937814686978, 0.17036554110901697, 0.16326995114130632, 0.17447766688253197, 0.19569552476916993, 0.10423505000237908, 0.14025388046034745, 0.13496361433395318, 0.0916601133399776, 0.11997002602687903, 0.15588903719825403, 0.10329095673348222, 0.11225424826677356, 0.1453775390982628, 0.1702262514403888, 0.15379464386829308, 0.16413886951548712, 0.17717906406947545, 0.14965981431305408, 0.14413417795939104, 0.17490532036338532, 0.1807590148278645, 0.06878960877656937, 0.08147137399230685, 0.1537245512008667, 0.12461904941924981, 0.13962779619864055, 0.1632041468151978, 0.09988544375768729, 0.2082686158163207, 0.11647733487188816, 0.09601271870945181, 0.12006888857909612, 0.11659818195870944, 0.2210454980709723, 0.08987746613898448, 0.1190073476838214, 0.15216104366949626, 0.12785411439836025, 0.11452246191246168, 0.10795634639050279, 0.17211848204689367, 0.07570256425866059, 0.13343502421464237, 0.12844685544925077, 0.12808556269322122, 0.14815372441496166, 0.10607339814305305, 0.0763921458274126, 0.18775787284331663, 0.21361419611743518, 0.1670318849916969, 0.08852182781057698, 0.09456675379936184, 0.09652109071612358, 0.15839452775461332, 0.0906309521357928, 0.2256669865122863, 0.21496974623629025, 0.16050291247665882, 0.10638167695807559, 0.09872674343309232, 0.16731821319886617, 0.11956779046782426, 0.08712494133838586, 0.17009861900338105, 0.13120864225285395, 0.09489297308027744, 0.09566675405949354, 0.12125297289873872, 0.19742512410240515, 0.11055305919476918, 0.14926212493862423, 0.10131128331912415, 0.14211757188396795, 0.1120425792677062, 0.13127178672168935, 0.17982402071356773, 0.18664085492491722, 0.14262887516192027, 0.05655766138806939, 0.1671912321554763, 0.07435473586831774, 0.1137867806745427, 0.18481893411704473, 0.15300618617662362, 0.11242459448320524, 0.19566363362329348, 0.16427838988602161, 0.14218728457178387, 0.09256240206637553, 0.07923169274415288, 0.07895871810615063, 0.17502764665654727, 0.12069263868033886, 0.11423952638038568, 0.10985401206250701, 0.17502764665654727, 0.1053301173129252, 0.11409928676273141, 0.06786633974739484, 0.11782365691448961, 0.13812102776552948, 0.14965118334761687, 0.12148043140769005, 0.1433306567903076, 0.12425812307213034, 0.10506109174873147, 0.15814129848565373, 0.16389626610491956, 0.20044517490480626, 0.13321105337568692, 0.10358536629272358, 0.12389415688812733, 0.1046908830425569, 0.21019257472029754, 0.11440595744975976, 0.13454100915363856, 0.0868869044684938, 0.15318293097828115, 0.15880664278353962, 0.2848741337656975, 0.08818467054516077, 0.15508634384189332, 0.12758645947490418, 0.10895940435252019, 0.06546018671776567, 0.13456437789968081, 0.12042863427528314, 0.30332559081060545, 0.14336211367377213, 0.09127295482903719, 0.09891657717525959, 0.07092753012797662, 0.08511846579079117, 0.09837248708520617, 0.11620042473077774, 0.16074502734201296, 0.12207072973251343, 0.1304555633770568, 0.10247957812888281, 0.14388875184314592, 0.1451100877353123, 0.2087293682353837, 0.13214644550212792, 0.12589970284274646, 0.15423527093870298, 0.06710032120879207, 0.1572112983890942, 0.09287398534693889, 0.11005615442991257, 0.1538258564791509, 0.20342669848884853, 0.055391307188464065, 0.15131492407194205, 0.07269682375980274, 0.1272769117993968, 0.05437073623761535, 0.17403060730014527, 0.15122119124446595, 0.1167926365243537, 0.17098085023462772, 0.14802858898682253, 0.08153525127896241, 0.12471575423010758, 0.06857061838465077, 0.08661170423563037, 0.16429254412651062, 0.11902679449745587, 0.07203741664333002, 0.09953466150909662, 0.14074782681252274, 0.1428263017109462], [0.01846564860482301, 0.13580350498003618, 0.013818999236848737, 0.0453708004206419, 0.05103659496775695, 0.03018157689699105, 0.006345394441658365, 0.07596998169486012, 0.032387779227324894, 0.03793792087318642, 0.06498799419828824, 0.041525878344795535, 0.013943175386105264, 0.024010704630719762, 0.040151207109114954, 0.01353322233938213, 0.04308993548953107, 0.03710042206304414, 0.04513521306216717, 0.03259359586185642, 0.05097757938451, 0.06304390316030808, 0.03577614901587367, 0.06405240297317505, 0.03997680325327175, 0.013951132905536463, 0.024033969900171672, 0.04948311618396214, 0.0496850007080606, 0.04504306122128453, 0.03716559874426041, 0.058410391078463623, 0.026100288843736053, 0.05836178082972765, 0.024931188273642744, 0.00744545619402613, 0.06095358104045902, 0.013793088528992874, 0.046443411614745855, 0.049928764413510046, 0.01929543586447835, 0.019749606493860483, 0.03071152970993093, 0.047477302208010635, 0.020532015045838695, 0.04450370730566127, 0.022692255110346844, 0.005436620192735323, 0.012014530349655874, 0.034140251976038725, 0.04239876954151051, 0.0406011029678796, 0.02682652826687055, 0.04853040552032845, 0.010862686621424342, 0.04818022716790438, 0.023920327158910886, 0.10354031156748533, 0.050880104436406066, 0.07398547711116926, 0.04190094196902854, 0.04147423843720129, 0.047458337154239416, 0.048936942991401465, 0.025390223999108587, 0.01946485588060958, 0.021741844680426375, 0.015627312873091017, 0.031116235136453594, 0.020065707121310488, 0.026749256698946868, 0.09370645960526806, 0.0425074165686965, 0.07794523784624678, 0.009885241660023374, 0.013891855238138564, 0.04011396571461644, 0.03041610913351178, 0.045022773024226935, 0.040362937176334004, 0.05650667626676815, 0.02278052912359791, 0.0036001889134890264, 0.028596441061901193, 0.04344499250873923, 0.0037548673322557336, 0.051005915006888766, 0.042664629739842246, 0.015636751295200417, 0.020638205776257173, 0.04626438015007547, 0.014710082805582454, 0.015450970103432025, 0.05178711237385869, 0.030497889566634382, 0.016149194511984075, 0.024706097851906503, 0.04705850360915065, 0.02480613426970584, 0.06123229608471904, 0.031133500460003103, 0.03823886811733246, 0.01830650500154921, 0.05724806737686906, 0.03316486467208181, 0.04197471908160618, 0.021913547966895357, 0.007136738875747791, 0.027784585786451186, 0.010555579975646521, 0.008725682140461035, 0.049848737993410656, 0.04867928967412029, 0.004858327696898154, 0.035953463786946874, 0.05117554536887577, 0.03595619149772184, 0.006280786457604596, 0.03433891685147371, 0.08895650412887335, 0.022262345500556485, 0.05016441623281155, 0.006484093360735902, 0.04530406989423292, 0.04843300521107657, 0.004881776594889483, 0.03160655811162932, 0.006795002771208861, 0.01910075738227793, 0.0319219411882971, 0.03507761757022568, 0.028234897247914757, 0.032458292586462836, 0.044605107578848086, 0.020374639026288475, 0.06929350923746824, 0.08886256095554147, 0.03890289605728217, 0.047132670879364014, 0.0406557250368808, 0.03340687097183295, 0.008926232495079083, 0.024187739506097775, 0.06835455247866255, 0.04422438157988446, 0.028541130279856067, 0.030902499998254434, 0.02329395112714597, 0.05096699423821909, 0.046122199922267876, 0.028427367098629475, 0.05509514361619949, 0.04356794983946851, 0.06290076619812421, 0.055673808458128145, 0.030729897652885745, 0.041248611972800324, 0.01859309953371329, 0.051320928281971386, 0.037284508613603454, 0.07443557653043952, 0.005435682118072042, 0.041815378703176975, 0.019355557459805692, 0.017257386386128407, 0.07100594842008182, 0.08088986948132515, 0.01493127504363656, 0.04839095639597092, 0.05864121512110744, 0.048343703217272244, 0.03148154481979353, 0.03288470095555697, 0.009092922255929028, 0.02580208288106535, 0.026336427511913434, 0.03356023006407278, 0.044336523062416484, 0.009733877460738378, 0.021848540919433748, 0.1135675460100174, 0.052537555141108375, 0.010297999600879848, 0.03276120758216296, 0.039708303553717475, 0.034049796472702704, 0.03442023927345872, 0.047263757059616704, 0.046146410051733255, 0.007169060043192336, 0.020301533663379293, 0.022041470477623597, 0.034849327855876515, 0.03277121936636312, 0.013613721189488257, 0.021906759224033782, 0.03829708642193249, 0.03227618057280779, 0.06616738984095198, 0.028476038415517126, 0.027877253313948, 0.0029854747782727437, 0.046749949987445555, 0.05815904813685587, 0.04884167328210814, 0.02816600558747138, 0.026836436574480364, 0.011293890536762774, 0.004020902677439153, 0.05835233562226806, 0.006250858398353947, 0.04622076052640166, 0.02754183309817953, 0.08286890507276569, 0.019860697943451147, 0.0352135586685368, 0.021088666515424848, 0.04172564244696072, 0.049845704941877296, 0.03891830558755568, 0.06308862540338721, 0.033381921239197254, 0.012913194002716668, 0.052271016407758, 0.0484075838966029, 0.07783532195857593, 0.038716804435742755, 0.035204171136553795, 0.027769875147246888, 0.024741871914427196, 0.006971152582471924, 0.08633059396275453, 0.03503853056047644, 0.04573664953932166, 0.039132257856960805, 0.03927210731697934, 0.034312111325562, 0.04346714328442301, 0.04291984033105629, 0.027971150686166117, 0.03423498224999223, 0.02982778873826776, 0.008686011590595757, 0.032689951227179596, 0.01094645176947649, 0.03342050952570779, 0.029306477068790367, 0.08791003349636282, 0.007259846332349947, 0.052672736280198605, 0.02798474852793983, 0.02108604906659041, 0.01444046521958496, 0.034071991353162696, 0.01720334785724325, 0.02606563945300877, 0.0297854481531041, 0.021349346098889197, 0.016735906779233898, 0.026642090574439083, 0.044052695256790945, 0.02047572547702917, 0.06932036565350634, 0.016719508284170712, 0.03927317600963371, 0.06820197709436927, 0.04739647511658924, 0.026911287468725016, 0.09249596670269966, 0.039926038655851565, 0.022212150872551968, 0.006272528262343258, 0.028878711629658937, 0.03740842267870903, 0.032177643717399666, 0.052645611842828136, 0.07350666208990983, 0.014951880455815365, 0.03970648847254259, 0.08773595533732857, 0.02246871174845312, 0.05204697432262557, 0.00694340855781255, 0.0778863410066281, 0.018184879295794026, 0.015109785732680132, 0.038063663590167246, 0.04083982515814049, 0.11940381569521767, 0.018215725497741784, 0.028779709977763038, 0.015916306026546017, 0.11838567389973573, 0.024501353302704434, 0.03004294540733099, 0.04636708999584828, 0.07559670601040125, 0.07832839978592736, 0.02954968437552452, 0.053915374779275486, 0.029692746698856354, 0.02156362067242818, 0.019030527311510274, 0.039177848624863794, 0.013443625182844698, 0.04902068778340306, 0.013064361426846256, 0.051502802808369906, 0.026857415180919424, 0.025899864866265228, 0.07609113412243979, 0.08445464141134705, 0.05967561461563621, 0.053536938835999796, 0.028316635272598693, 0.04081032245552965, 0.046795486472547054, 0.038213395912732394, 0.029600377726767744, 0.01974461756513587, 0.013276664007987295, 0.02585343610761421, 0.10585756293897118, 0.07911900843360595, 0.04661690623366407, 0.010297803673893213, 0.016948256009657468, 0.04540808931259172, 0.07966774648853711, 0.0164229392872325, 0.03452761744015983, 0.03733069649232285, 0.043953825919223685, 0.0747885572324906, 0.08071069552430085, 0.05830098409205675, 0.07386489465300526, 0.03381338130150523, 0.039865930631224594, 0.04503851842933467, 0.03459096207682576, 0.023118207164640938, 0.10014197070683752, 0.05955698633832591, 0.012379989310699915, 0.05654594987364752, 0.04107879162100809, 0.08098340553364583, 0.05921770525830133, 0.004530762372139309, 0.015123997648645724, 0.016912001883611083, 0.10132383621696915, 0.14271871319838933, 0.10485294434641089, 0.08915907397334065, 0.2214602186743702, 0.1305190742548023, 0.06838480835514409, 0.17432397870080812, 0.0884384833542364, 0.10484558902680874, 0.18414463315691265, 0.11970064762447562, 0.1263326896088464, 0.17473287747374602, 0.20291236894471304, 0.08253165959779706, 0.090291881401624, 0.11424760094710759, 0.08188023883849382, 0.11348876130900212, 0.1191627322030919, 0.1795372311025858, 0.19741134984152658, 0.14901838158922537, 0.0761729111628873, 0.10993657620357615, 0.09979292550789458, 0.18427774815687112, 0.2021412138960191, 0.12741005394075597, 0.11257119197398424, 0.12303586437233857, 0.08256840905440704, 0.11016514750995807, 0.05092177666457636, 0.15366958986435617, 0.15750236277069363, 0.17863792793026992, 0.14102210423776082, 0.18602983414062432, 0.13106140015380724, 0.17931066825985909, 0.13934203796088696, 0.15149184529270443, 0.11426147020288877, 0.1267519292554685, 0.08264591132423707, 0.10075280828667538, 0.1420389296753066, 0.09489242346691233, 0.1667910050600767, 0.11257579244141068, 0.09103344553815466, 0.141156847721764, 0.07179777843079396, 0.1573515244360481, 0.16689735863889965, 0.15936202369630337, 0.1497523800602981, 0.11243840945618493, 0.14587485098413058, 0.12783590251845972, 0.17984729446470737, 0.1318640120859657, 0.18671628087759018, 0.1925398755286421, 0.08219956420361996, 0.16200547399265425, 0.09142781687634331, 0.08870314593826022, 0.13026366010308266, 0.22546535304614476, 0.160384847383414, 0.1339614452528102, 0.10204892552324704, 0.09953231377793209, 0.1344051935843059, 0.1385865027883223, 0.0975704247664128, 0.14292947974588188, 0.22581759414502553, 0.07038235438189336, 0.13266020507684775, 0.17582607881299087, 0.21588614849107607, 0.08525154686399869, 0.15543855779937335, 0.0795054409120764, 0.07944623194634914, 0.11513637325593404, 0.08408220711031131, 0.11270485658730779, 0.22362414827304228, 0.10245850961655378, 0.11981348799807684, 0.12953867257705756, 0.10516481261168208, 0.09963195664542061, 0.1178248647068228, 0.13261876015790872, 0.22220003897590296, 0.12478535835232053, 0.1597389363284622, 0.19569044932723045, 0.10375782953841345, 0.15109224244952202, 0.15953579651457922, 0.2593164066118853, 0.060884241546903334, 0.06141461844422987, 0.13864427325981005, 0.2026023870067937, 0.24618919672710554, 0.06162329510386501, 0.09998450308505978, 0.12565901290093148, 0.16008986106940679, 0.12904848530888557, 0.15856068740997994, 0.14285971277526446, 0.14770542989884103, 0.1421314547104495, 0.0658504461337413, 0.14513678130294594, 0.14741716108151845, 0.13625946694186755, 0.11186814148511205, 0.11937756996069636, 0.2596418862896306, 0.1545401502932821, 0.10093426212136235, 0.09281882723527295, 0.08908013999462128, 0.11359156614967755, 0.18597979896834918, 0.19111234641500882, 0.21710472953106674, 0.09637687488326005, 0.15439186325030668, 0.10164161452225276, 0.1839248285229717, 0.11840497143566608, 0.10208520679069416, 0.10626070094960076, 0.16579300218394824, 0.1333434355578252, 0.1522874411727701, 0.1372637123401676, 0.14565101585217885, 0.0945560804435185, 0.07899248879402876, 0.09675887652805873, 0.20193169585296086, 0.12547443780515874, 0.11415261961519718, 0.20270749208118233, 0.19152326722230228, 0.13978704836751732, 0.1930929222809417, 0.23573367776615278, 0.14236710992242607, 0.19323221194956983, 0.09683628380298615, 0.06742662191390991, 0.08748387957790069, 0.13106391073337623, 0.18521342080618652, 0.10583638586103916, 0.12290877476334572, 0.107140041621668, 0.06668777870280401, 0.1610192097723484, 0.1174308665628944, 0.05335809396845954, 0.10066121284450803, 0.2080104603831257], [0.05562188017315098, 0.05846706910857132, 0.05300054333305784, 0.03910724027082324, 0.02433169919199177, 0.01010538640964244, 0.013595058083800333, 0.06104025710374117, 0.04607420714039888, 0.02833819741915379, 0.025377152021974325, 0.032250579446554184, 0.04789639936227884, 0.039728998871786256, 0.029021363439304487, 0.04728946675147329, 0.03438122011721134, 0.08916696533560753, 0.07109733351639339, 0.07873529009521008, 0.041102146796349964, 0.03921638602124793, 0.06185710470059088, 0.05150475359654852, 0.0376318405116243, 0.032934186514467, 0.12714272471410887, 0.11209607496857643, 0.03886202789310898, 0.015088975063658186, 0.03798058036980884, 0.10892509762197733, 0.03071712762383478, 0.03855424440865006, 0.06021882939551558, 0.004628087618454758, 0.04797268705442548, 0.08935627660581044, 0.023741254982139384, 0.0736460399680904, 0.022638432016330104, 0.012867487035691738, 0.039833757893315384, 0.03779729788324662, 0.07313996140978166, 0.034030417512570105, 0.01803838019259274, 0.05623126229537385, 0.01900058356113732, 0.10627693829259702, 0.022330551840631024, 0.02594042768968003, 0.028461887567703213, 0.04658535774797201, 0.050315821144197664, 0.01732960286816316, 0.03507805522531271, 0.057151220073657374, 0.045347910041787794, 0.058293452353349755, 0.06659136566200427, 0.058750907092222145, 0.014842168128650104, 0.08065527278397765, 0.03753280832565256, 0.03096427382635219, 0.028202985745987723, 0.053933664690703154, 0.021447379142045975, 0.03973360612456288, 0.013006635060134743, 0.06703871701444898, 0.046538596507161856, 0.06998682274882283, 0.031404470027025254, 0.03370152819635613, 0.05207857709111912, 0.01734048148084964, 0.005625782185234129, 0.04753721006480711, 0.05248916880892856, 0.035145691595971584, 0.003013840934727341, 0.05848678733621325, 0.06070550863764115, 0.013275260288667465, 0.03952974367088505, 0.03372881208945598, 0.057267018859939914, 0.04709971782618335, 0.04456818509580834, 0.03433104245258229, 0.014424563751422932, 0.030225020101560012, 0.01161444405027266, 0.07082266932619469, 0.01826859185738223, 0.03777982560651643, 0.021322272551645125, 0.055283681356481144, 0.06154156556086881, 0.054301668158067126, 0.05617927294224501, 0.06534062884747982, 0.0823751554957458, 0.04592873941042593, 0.0496307823673955, 0.0459259472388242, 0.0019116129593125411, 0.01983017404563725, 0.04126351260180984, 0.048621386888303926, 0.05674349516630173, 0.01572210930420884, 0.08452830317297153, 0.0534592703250902, 0.039304595573672226, 0.0103853143352483, 0.045897920349878926, 0.010540920226568622, 0.011423851197053279, 0.050677470131112, 0.029239271567868333, 0.03328687544646008, 0.020992562208058577, 0.023355762274669747, 0.040187837822096686, 0.016804808617702553, 0.025769791399527873, 0.07596472304846559, 0.011460769439249166, 0.04812067893466779, 0.04205479299915688, 0.052160825713404586, 0.03903977692659412, 0.055664339501942904, 0.021351692133716176, 0.0469008392122175, 0.014413403546703714, 0.016637926322541068, 0.040897863650960584, 0.042985386813857725, 0.007109956674477351, 0.036389934830367565, 0.02598979789763689, 0.0398593522342188, 0.01255008192466838, 0.05938539161745991, 0.030193593752171313, 0.02846715978479811, 0.023318680335900614, 0.025050354289955327, 0.03640911362266966, 0.053579103002058606, 0.05328692921570369, 0.08264019805938005, 0.018131454841100743, 0.04980352381244302, 0.020401100195678215, 0.01900458352507225, 0.045715329969035726, 0.037527783773839474, 0.06446335092186928, 0.02026879265239196, 0.010286555259621568, 0.060456214871789725, 0.06864422586347375, 0.04584408877417445, 0.023478176777384112, 0.02856173738837242, 0.008900769620335527, 0.021273160186995353, 0.016548754946727837, 0.02477965104792799, 0.025072969862126877, 0.04981572387207832, 0.04287079581990838, 0.03587128301816327, 0.0345070985411959, 0.05786585994064808, 0.015838427169780647, 0.046940265489476066, 0.03672501577862671, 0.022071724657767584, 0.03786748893825071, 0.037992441161934815, 0.07674944879753248, 0.06172828482730048, 0.033689026188637526, 0.1236753836274147, 0.013305401662364602, 0.01892216018001948, 0.028253724898344705, 0.02770118535097156, 0.024692637413474064, 0.06423462355243308, 0.02942558371328882, 0.05056186472730977, 0.02272086214673306, 0.051277335799698315, 0.09665889439306088, 0.007720542772273932, 0.07819943063493286, 0.028891814140869037, 0.05852209151323352, 0.06186793411948851, 0.024096322179372822, 0.046765128815812726, 0.07960150111466646, 0.04890297892104302, 0.02077291702984699, 0.045607368262218576, 0.02708739784014012, 0.050358891154506376, 0.08950512683285133, 0.011453027354686387, 0.01783460594846734, 0.01932355435565114, 0.02940171624400786, 0.00894040200260601, 0.0339760498942009, 0.03788849638242807, 0.00200734195199662, 0.009803579122360264, 0.01190889347344637, 0.016225879147116627, 0.01789709902368486, 0.015804972000686184, 0.011413723213731177, 0.04203281524990286, 0.07506094154502664, 0.02067746750877372, 0.05041954539982336, 0.039579673670232296, 0.025408569889675294, 0.029762737586029937, 0.030517651899052516, 0.016489756326856356, 0.04711949033662677, 0.03347813071949141, 0.032387236399309974, 0.02228587879134076, 0.032124232833406756, 0.034282913963709555, 0.0706988163292408, 0.05674580218536513, 0.040402261673339775, 0.06916334586484091, 0.062493679113686085, 0.03262124955654144, 0.02276599490349846, 0.006443414338199156, 0.030724354021783386, 0.029766062407621315, 0.015271823287808468, 0.021365568174847534, 0.06316836683877877, 0.04591486676196967, 0.04837271398199456, 0.023654891044965813, 0.05600259599408933, 0.01140742895326444, 0.02279608623523797, 0.012027777049557438, 0.03869685550619449, 0.011703019163438251, 0.05344468182218926, 0.04612562313143696, 0.041467375055487664, 0.06480352088276829, 0.04107870001878057, 0.08216332364827394, 0.016838718405259506, 0.06745259623442378, 0.003579200553109071, 0.0015708127029938623, 0.023072930219184076, 0.00926475107137646, 0.02644180060763444, 0.06107094045728445, 0.055513633481625996, 0.04749534106148141, 0.03743265316422496, 0.026334697247615883, 0.04957928495215518, 0.044341798672186475, 0.03610412230981248, 0.05464257432946137, 0.03409567901066371, 0.01800326430904014, 0.03323361723284636, 0.020863954376961504, 0.058158871717751026, 0.023883545471887504, 0.024022551852145364, 0.03623138155255999, 0.034701017064175436, 0.03104281086208565, 0.05755454807409218, 0.03549729487193482, 0.014821835826816303, 0.029363555434559072, 0.08824791679424898, 0.005087019867330257, 0.04052578897348472, 0.05323866501982723, 0.03981067752465606, 0.05409515941781657, 0.016849127132445574, 0.022787937029664005, 0.04742210677691868, 0.020398369092228155, 0.03137490625626274, 0.007181740166353328, 0.030357229257268564, 0.03413521046085017, 0.006446404557209462, 0.007749026824188019, 0.04872819508558937, 0.05459055783493178, 0.040738010978592296, 0.049285408042903454, 0.03613112461087959, 0.04668218469513314, 0.021549301887197152, 0.040374088899365494, 0.025035192424963628, 0.031677414130951674, 0.03511210411254849, 0.005524027377500066, 0.019830034945958426, 0.03124173018815262, 0.051544220585908206, 0.04905917428966079, 0.0640050344435232, 0.020408055179619362, 0.023865299665236046, 0.04801722609304956, 0.08692667340593678, 0.04857821849041751, 0.058758798454489024, 0.09413034043141774, 0.008512303233146667, 0.012748089469304042, 0.08074407266186816, 0.05211120444749083, 0.0028193708900029636, 0.02339193836918899, 0.037775774752455096, 0.02215855339142893, 0.025582091649994254, 0.014341631505106176, 0.16082687223596231, 0.12100252562335559, 0.10938439119075026, 0.10232356935739517, 0.12441067131502287, 0.1338765469512769, 0.09668416303715535, 0.17722118752343313, 0.12230930264507021, 0.13002930767834187, 0.18848478740879468, 0.17544855549931526, 0.1223415873412575, 0.19241655857435294, 0.08886449478034462, 0.11362812561648232, 0.1581047118774482, 0.16134113392659596, 0.1107138991355896, 0.14748092980257102, 0.12496879350926195, 0.09261298685201577, 0.15958999789186887, 0.13458515464195184, 0.178882770506399, 0.12057492642530374, 0.21595890101577553, 0.10274983184146029, 0.12096435124320642, 0.1328719894268683, 0.13751915363328798, 0.15206812508404255, 0.14812202325889043, 0.15965854349945272, 0.11922861795340266, 0.07315609697252512, 0.14996462581413134, 0.18232564362032072, 0.1526962449508054, 0.16666817665100098, 0.08846799284219742, 0.054936566589666266, 0.11316388552742344, 0.09870283185903515, 0.12295524084142276, 0.12850546730416162, 0.06477418102856193, 0.20738247622336659, 0.1346988228282758, 0.2497686046574797, 0.1913312960948263, 0.13309357182255813, 0.13201209556843552, 0.10975936999810593, 0.18078687547573022, 0.05629988254180976, 0.16993631342692034, 0.21070047175245626, 0.14236435507025036, 0.1236448088394744, 0.25077845475503374, 0.15314406449241297, 0.1781580951064825, 0.14282974866884096, 0.16199923147048267, 0.11008945692862783, 0.20428674162498542, 0.12563217005559377, 0.14661657118371554, 0.13141468619661673, 0.0898255921368088, 0.22444353359086172, 0.11167927804802145, 0.11528299110276358, 0.10046245636684553, 0.1797488254628011, 0.10617535481495516, 0.09430578923118965, 0.0950032960889595, 0.11515016108751297, 0.10944253485649824, 0.1397863155496972, 0.16897230515522615, 0.12267670221626759, 0.0900459328134145, 0.08846097679010459, 0.10660129838756152, 0.1312962682651622, 0.1008571262604424, 0.10062588831143719, 0.1196625003857272, 0.1097286120057106, 0.18268097883888654, 0.09600774504776512, 0.08119200076907873, 0.22993136197328568, 0.17837775046271936, 0.09913945557283503, 0.09050650202802249, 0.10853950652693, 0.1294137542801244, 0.0715911713029657, 0.149401618167758, 0.14102329845939363, 0.15979818600629056, 0.1288205382547208, 0.1841021432940449, 0.07867199634867054, 0.1539831951792751, 0.14476978885275976, 0.09314192525510277, 0.1618392871958869, 0.09236597974917718, 0.04664396621020777, 0.13143334590962955, 0.1338175551167556, 0.12850724506591046, 0.09288820065557957, 0.16843031852373055, 0.09538405601467405, 0.06701067994747843, 0.2244527345257146, 0.10693554473774773, 0.0830236721251692, 0.09006690633084093, 0.12466048076748848, 0.1342819444835186, 0.1300223051969494, 0.10869325577680554, 0.11178571983639683, 0.16272810021681444, 0.12755420192011765, 0.09224365345601525, 0.12330826904092516, 0.1476770264229604, 0.10992558393627405, 0.08221395593136549, 0.15264258640153067, 0.10675634363932268, 0.08673981843250138, 0.1023729056386011, 0.08512801956385374, 0.1815536336175033, 0.13323256293577806, 0.18563331184642656, 0.17136735735195024, 0.07892914755003792, 0.18436366426093237, 0.09381695224770478, 0.126469740111913, 0.11881880994353976, 0.11587209520595414, 0.1460286205900567, 0.13346648109810694, 0.1748686930430787, 0.22606335952877998, 0.17851590019251617, 0.10043847015393631, 0.14564394551728452, 0.12504561724407331, 0.11354425868817739, 0.2271257418074778, 0.19702762471778051, 0.05800179086093392, 0.07051177136600018, 0.1423524942781244, 0.14049370187733853, 0.09271385108253785, 0.1704902829868453, 0.1958064923861197, 0.07214633508452348, 0.15808070530848845, 0.17680335922964982, 0.09935171489736863, 0.13826527073979378, 0.10906987663890634], [0.018189282988065054, 0.009959995014859098, 0.030548830583159412, 0.03474023638825331, 0.05819391126611403, 0.007350636014182652, 0.023669779799612503, 0.03914534340479544, 0.023300286947882602, 0.024484771603186215, 0.04474816990217992, 0.02226389425673655, 0.009627590887248516, 0.05022590507620147, 0.053207717037626674, 0.018375561206734607, 0.017200689696307694, 0.03148716308974794, 0.12430916247623307, 0.08870097462620054, 0.02564581117725798, 0.03126306672181402, 0.04382803909746664, 0.00754805577785841, 0.05312500361885343, 0.03287656192800828, 0.03632612878988896, 0.013444411435297557, 0.04442943146984492, 0.031710720022342036, 0.056955876627138684, 0.044606474826910665, 0.034924777557275126, 0.045461483233209164, 0.01301254510014717, 0.04349433557529535, 0.12445890158414841, 0.0372184193027871, 0.04816427820229104, 0.035029645144407234, 0.058503425014870505, 0.062252928103719435, 0.009304140877377774, 0.06183303027812924, 0.051942429039627314, 0.06989602119262729, 0.012607345191229666, 0.03255297875564013, 0.018586414267442057, 0.025918636537556137, 0.02709075658848243, 0.021661227934860756, 0.0419484021009079, 0.004692156591253089, 0.029785376906927143, 0.024109297465266924, 0.01981996718261923, 0.07419456089181559, 0.01966334942595235, 0.008403454341792634, 0.017882693725238954, 0.020853304769843817, 0.022818181031782712, 0.04426746516089354, 0.017906895373016596, 0.013081157713064125, 0.02917616441845894, 0.05024045625967639, 0.011260118152547096, 0.030704337238733257, 0.006007884762116841, 0.03994612668507865, 0.05209849887926664, 0.10359649426702942, 0.05558372275637729, 0.04137115539716823, 0.023831754590251615, 0.04701356762754066, 0.05198344308882952, 0.005313264646766973, 0.057334329533789835, 0.08710343856364489, 0.016704585602773086, 0.02172818746683853, 0.040150423401168416, 0.03389890385525567, 0.033351390556033166, 0.0418446846306324, 0.052503828558006456, 0.07156654048178877, 0.04364859372643488, 0.045712469943932126, 0.02454463535520647, 0.06941750472677605, 0.04518415579306228, 0.030649168949042047, 0.03163498533623559, 0.0023398839070328642, 0.02810828261343496, 0.027290164459762827, 0.026402900195015327, 0.06069123904619898, 0.0646513526194862, 0.08114499864833695, 0.057625984240855486, 0.04210161191544362, 0.017327672436035106, 0.059376787793423445, 0.021214836709467427, 0.0353179275324302, 0.1059853242976325, 0.023245237401819656, 0.021716572643656815, 0.09786335511931352, 0.016963874189449207, 0.014944238455167838, 0.04038198704698256, 0.022268438745023947, 0.04137416130730084, 0.020871869487954036, 0.0589890932398183, 0.03766679185043488, 0.07173240836709738, 0.0039265807967499965, 0.041157410080943785, 0.05987652204930782, 0.047485593905938525, 0.08973409168954406, 0.03326137949313436, 0.032587282093507905, 0.040674293147666116, 0.05570042738690972, 0.07497528328427247, 0.04382248868101409, 0.030636429454066923, 0.05099959784586515, 0.031223246894244636, 0.038155181000807455, 0.02209142252935895, 0.03417770710906812, 0.03838795243895479, 0.06019117909350565, 0.027937103495267884, 0.021143984082820158, 0.03861829132906028, 0.042469489853829145, 0.04831260935004268, 0.05123384849035314, 0.08344897108950786, 0.06446949166378804, 0.014127149978386504, 0.04531158466956445, 0.040753332299313376, 0.011453577816220266, 0.08761556286896978, 0.049053359244550974, 0.05809979845902749, 0.014377933128603866, 0.019247127563825676, 0.025174385402351618, 0.006483938569934773, 0.021022716304287314, 0.03482155881023832, 0.01202887627628765, 0.034375835941838365, 0.027368718458871757, 0.07054543348827533, 0.05853119745318379, 0.033940179140440056, 0.02099292352795601, 0.040301597610648186, 0.01554954088559108, 0.0371279536214258, 0.03984111321291753, 0.04784381629100867, 0.05441864420260702, 0.01794488654871072, 0.0348295044553067, 0.07716095314494201, 0.05400585063866206, 0.022609009041583965, 0.01473906303622893, 0.010725569113024642, 0.07087837026587554, 0.04097251946638737, 0.02916385918589575, 0.02312274826025324, 0.03693694601367627, 0.017817003053746054, 0.04991528870803969, 0.06682973501405545, 0.029943234686340605, 0.028597675995635133, 0.03150502213143876, 0.014298614081261414, 0.056062290112354925, 0.026911609772858874, 0.007031468832532742, 0.023173612941588675, 0.01493502564595214, 0.04805129872901099, 0.03283963605229344, 0.04722418150465403, 0.0323725630795317, 0.031813294161111116, 0.03787008433469704, 0.014167734854189413, 0.053806900778519254, 0.04554356561441507, 0.03752113752333181, 0.02094240320314254, 0.06103287464273827, 0.13720322772860527, 0.02291843797346311, 0.01939292099060757, 0.043157758457320075, 0.02778385636130614, 0.0448198198074741, 0.061420365635837824, 0.03425234256844435, 0.053908036423048804, 0.028200424276292324, 0.031569011376372406, 0.010880825558810361, 0.04864902361961348, 0.07165726061378207, 0.011628192866088023, 0.023377448253865753, 0.007310296259155231, 0.03214728945334043, 0.07643407929156508, 0.03748076808239732, 0.01968000746066017, 0.07555404651377882, 0.07117867629442896, 0.017566409893333912, 0.035096039795981984, 0.03411378911031144, 0.013109079429081507, 0.028523705500577177, 0.02506652886846236, 0.04262540702308927, 0.04538406238758138, 0.030622804470892464, 0.053798839782497714, 0.04500163665839604, 0.03645857543285404, 0.01831189596227237, 0.021055318215595822, 0.050165919187877855, 0.028482745734176466, 0.02236423940796937, 0.012783844023942947, 0.006711561199543732, 0.02913924532809428, 0.017955527674140673, 0.04020425836954798, 0.06128163915127516, 0.00550254580697843, 0.04105834736089621, 0.016972510243899057, 0.027487156746376838, 0.008810229300122176, 0.005701397703627923, 0.03382316916914923, 0.04148406023159623, 0.08212879978652511, 0.025755913662058965, 0.04952094790392688, 0.08974573535046407, 0.07613038058791842, 0.034590639772691896, 0.07136964997542755, 0.03823911578261426, 0.01692930791926171, 0.013612290328767682, 0.022185051880244697, 0.01254848058202437, 0.03536980153460588, 0.031821769063494036, 0.026421607405479466, 0.024832145909645727, 0.04143746183919055, 0.028122243471443653, 0.029604839094515358, 0.052692115240331204, 0.01855839416384697, 0.03290943016431161, 0.014237964924957072, 0.06645869849515812, 0.013987616037151642, 0.03865965821647218, 0.040562660566398075, 0.03630252594926527, 0.018916546999077712, 0.11556180114192621, 0.01835017721168697, 0.0314675025375826, 0.06103133436824594, 0.05303312658465334, 0.020601948257535696, 0.036022331698664596, 0.04925383920116084, 0.08517312857189349, 0.09163362333284956, 0.06880275199988059, 0.06718790650899921, 0.07800616350557123, 0.022476803278550506, 0.036865333427808115, 0.012862157991289027, 0.02433653375399964, 0.05565672633903367, 0.0324291427220617, 0.0519744660705328, 0.02954488034759249, 0.016241237787263732, 0.03491813809211765, 0.01986246383083718, 0.017827744263091257, 0.01595355590273227, 0.06507135901067938, 0.03915378438042743, 0.09784491932285683, 0.04376569190727813, 0.05758350116333791, 0.018484101364655153, 0.023215139284729958, 0.017452134418168237, 0.01547272563246744, 0.02621476279039468, 0.009772439454016941, 0.021364999901769415, 0.011768516452450837, 0.026257588528096676, 0.017883440113759468, 0.05377412075176835, 0.014968657234151448, 0.01825725014454552, 0.03600938864318388, 0.04994587367400527, 0.030862483395529643, 0.012507656522627388, 0.02139969339727291, 0.008400984474324753, 0.02073723287321627, 0.038422160781919956, 0.04707036779395171, 0.020858972233587077, 0.014823352352582982, 0.06330965140036174, 0.034907244212393246, 0.10638635206435408, 0.10296120907046966, 0.167899541290743, 0.11097928096673318, 0.1402563096157142, 0.1416508619274412, 0.08828588761389256, 0.13394799668874058, 0.06279125743146453, 0.10034168391887631, 0.11995247911129679, 0.09518333178545747, 0.07489376408713204, 0.2234049407499177, 0.13480660133063793, 0.13211977907589503, 0.13204157112964562, 0.11239978724292346, 0.22412767553968088, 0.20610351913741656, 0.12024270210947309, 0.12508687217320713, 0.1106020969205669, 0.06341577427727835, 0.11413887249571936, 0.08159699796565942, 0.15483812216137136, 0.07562704331108502, 0.12503149014498505, 0.13173787242599896, 0.10683176959199564, 0.1401170470884868, 0.0988466337855373, 0.1953660010227135, 0.0755379448777863, 0.23084969126752444, 0.28909274882503916, 0.10666967436139073, 0.09324736959700074, 0.1327290085277387, 0.1112347086891532, 0.09285721874662808, 0.08592465360249792, 0.1133016688483102, 0.10011098201253585, 0.07620412377374512, 0.12248855802629675, 0.120883741282991, 0.12444453021245343, 0.16420943715742656, 0.09745980320232255, 0.1357288389865841, 0.11023157608828374, 0.10198821699512856, 0.16590243631175586, 0.07436600633497749, 0.12920133210718632, 0.1442079482866185, 0.17902207374572754, 0.10268448213381426, 0.0976146991763796, 0.09680230955460242, 0.13602907716163568, 0.12441633029707841, 0.10931700587804828, 0.10665425804576703, 0.17667473613151483, 0.1371186686945813, 0.1502001860312053, 0.12634832305567606, 0.20949554283704075, 0.12961628341249057, 0.12989586698157446, 0.10924231274319546, 0.11698202921875886, 0.1211936960795096, 0.08713902094002281, 0.13048365472682885, 0.13016244981970104, 0.12047790948833738, 0.08633754894669567, 0.14194105778421673, 0.10161777758704764, 0.1335530485957861, 0.1359347743647439, 0.09433288313448429, 0.11760394727545125, 0.12242796484913145, 0.09673103623624359, 0.13219741705272878, 0.10480828317148344, 0.2124608087220362, 0.09522584878972598, 0.17258152791431972, 0.14335318415292672, 0.0733389010918992, 0.09793702366628818, 0.1260931667472635, 0.12839264050126076, 0.145700033221926, 0.07519315409341029, 0.137726079672575, 0.08467688877135515, 0.09939776028373412, 0.16187740729323455, 0.1505221916096551, 0.0829884358016508, 0.13966983822839601, 0.11327299395842211, 0.11578179576567241, 0.29998076600687845, 0.17164145835808345, 0.14316486354385102, 0.1714439368141549, 0.0933611463489277, 0.13284384379429476, 0.18527385113494738, 0.10801443577344928, 0.09643629419484309, 0.2554451471992901, 0.08233413126851831, 0.12703584187797137, 0.20772122804607662, 0.21227218955755234, 0.07037858851253986, 0.22817194781133107, 0.18822942753987654, 0.11620345099696092, 0.1502515918442181, 0.11828162733997617, 0.1317402065864631, 0.15659178234636784, 0.11138745370720114, 0.1245917451700994, 0.10781696851232223, 0.13872606387095793, 0.0922504048794508, 0.16105036810040474, 0.1251175555267504, 0.13034911480333122, 0.11467473874134676, 0.1559346347515072, 0.13021210501236574, 0.07310481329581567, 0.08515100154493536, 0.19041777082851954, 0.1065338384360075, 0.20226740783878736, 0.14813004354281084, 0.1419347474085433, 0.11524070480040141, 0.13198978533702238, 0.10669040360621043, 0.11514610344810144, 0.21316349958734854, 0.18270541967025825, 0.1267514814223562, 0.09023036541683332, 0.0704304760854159, 0.07667445032192127, 0.09724594253514494, 0.11169956624507904, 0.08465917222201824, 0.12079323828220367, 0.1374124472162553, 0.07724396511912346, 0.19466210236506803, 0.1259370358394725, 0.15956566562610014, 0.09112607235355036, 0.14217148827654974, 0.14122531190514565, 0.12026700723384108, 0.15451136683779104, 0.20136878320149013, 0.115279367725764], [0.0391351721648659, 0.04127752774262002, 0.019845568308872834, 0.037206857066069327, 0.011032640135713985, 0.005592560686636716, 0.003322059953851359, 0.0507725023531488, 0.005921948726089405, 0.04506219590881041, 0.06670805332916123, 0.048048486201358695, 0.044530295700367005, 0.048849184664764574, 0.029277255958212272, 0.03172820247709751, 0.032478716490524154, 0.0364099482207426, 0.04150886068652783, 0.02910065364890865, 0.06345819628664426, 0.06299164917852197, 0.029936286487749646, 0.059342291073075364, 0.050897705634789805, 0.023238535172172954, 0.014371308930484312, 0.03389506334705012, 0.06206726056656667, 0.030639194484267916, 0.044669239316135645, 0.011972175345623066, 0.0773011724065457, 0.017189398873597383, 0.03475078082244311, 0.033574608221117935, 0.05689163293157305, 0.05603830050677061, 0.06114321800747088, 0.0841459147632122, 0.04661810045529689, 0.05103482059868319, 0.05440641360889588, 0.02895512824345912, 0.015830328854333078, 0.01646999060176313, 0.06469821224787406, 0.003697995071498943, 0.013590125134214759, 0.01589831297418901, 0.013077696336300244, 0.04443931433239153, 0.03339989223916616, 0.02422069595195353, 0.058508195116051605, 0.004859919285601271, 0.04053170579884734, 0.024862564634531736, 0.06750812075499978, 0.04043901791529996, 0.047609358693339994, 0.028421862483290688, 0.0299114588914173, 0.051070711708494594, 0.05114974746746676, 0.003857011449456747, 0.009783199323075158, 0.010795755927184863, 0.07673901292894568, 0.05203437053465417, 0.054283334141863246, 0.049190881329455545, 0.08939217789364712, 0.0759575916454196, 0.060174426063895226, 0.06321233590798718, 0.0054703963937104815, 0.027350167311461906, 0.024853419678817903, 0.0303294500336051, 0.1414111762174538, 0.06906921948705401, 0.029799666854419878, 0.03397234509299908, 0.03402346931397915, 0.015295456662507994, 0.027947671678183333, 0.036142398470214436, 0.017159960631813322, 0.0413667008147708, 0.007885459860387658, 0.08054212706961802, 0.02417997706548444, 0.047892833660755835, 0.012902070269254702, 0.022991253262651817, 0.014149707026912697, 0.026213183500138775, 0.059744899826390405, 0.03247025515884161, 0.031148278952709267, 0.06711995801223175, 0.09586278282638107, 0.03978713235950895, 0.004712405348462718, 0.03600971433999283, 0.02396330556699208, 0.025545318444658602, 0.049535770501409254, 0.0277421824367983, 0.04328138414504273, 0.04784373825948153, 0.028062508641076938, 0.061274792732937, 0.017853369138070514, 0.027343375175925236, 0.08022644543754202, 0.006366423514139439, 0.02587232312985829, 0.046013471470879655, 0.011706058152153023, 0.03043297751407538, 0.021289782598614693, 0.08569315102483545, 0.021297414421236942, 0.065144043681877, 0.03613259024651987, 0.015147327378924404, 0.01153562796701278, 0.05799267813563347, 0.03834254826818194, 0.03257808794400521, 0.037212753535381386, 0.040177395168159685, 0.011064207281119056, 0.0410408343720649, 0.021105662121304443, 0.007199974946810731, 0.04493143203269158, 0.03465230842786176, 0.01572515762278012, 0.04809453158772417, 0.06313693031136479, 0.026983229144077216, 0.03240429816235389, 0.06669495081795113, 0.012935431291615325, 0.028400546305679848, 0.01822897559031844, 0.03778747948152678, 0.03478943017710533, 0.06556320868964706, 0.008681214348013912, 0.021053438673594167, 0.039715937072677274, 0.010596829815767705, 0.10829146805086307, 0.03377251313733203, 0.024232653435319662, 0.038207211066037416, 0.020491874610473002, 0.011172641417942941, 0.05112847200195704, 0.04948512125494225, 0.018710842322824255, 0.024429136820669686, 0.054143616996173344, 0.07185384577938489, 0.056547171236681085, 0.0863645410697375, 0.060947609932294915, 0.046003205236047506, 0.06032864350293364, 0.017037863344220177, 0.02413562123131539, 0.0047387384443676895, 0.06323223734008414, 0.05249663608680878, 0.060009589551814964, 0.035411623040480275, 0.020939636476604, 0.040729006818894825, 0.031151043982910256, 0.03451203827613166, 0.03778520638921431, 0.030409585019307475, 0.09200535874281611, 0.01872436043673328, 0.04864367337099143, 0.059268452892346044, 0.02149645927628236, 0.012315197698106723, 0.0233224021004779, 0.054326712885605435, 0.07204764216606106, 0.045971402299723456, 0.017611461225897074, 0.021929944765620997, 0.07716047817042895, 0.08161324209400586, 0.01839038041154189, 0.034855444849069626, 0.013002708886883088, 0.03886219413418855, 0.04078315730605807, 0.03506694082170725, 0.03579700718234692, 0.03902483219280839, 0.017579902562179735, 0.046589948037373166, 0.009659601624922028, 0.06501757153975112, 0.004554029337928763, 0.047295783912496905, 0.055758143575595956, 0.019960495177656412, 0.06467322858848742, 0.0657034550926515, 0.025430069271741167, 0.013399429652573807, 0.06401139910199813, 0.06048683715718133, 0.0537118414150817, 0.04859296984172293, 0.008350387814321687, 0.028230116968708377, 0.060617550143173764, 0.028540037838476043, 0.024045596597716212, 0.029034581301467757, 0.026425386845533336, 0.04280762420967221, 0.04636185509817941, 0.021139880642294884, 0.009119981384303952, 0.011226621423182743, 0.0461286120781941, 0.03288146434351802, 0.019153715344145894, 0.03995923937431403, 0.04520276461594871, 0.072188343187528, 0.01089255658111402, 0.03536582871207169, 0.022052483100976263, 0.027532547346449325, 0.05602802409391318, 0.03548965796029993, 0.04495330460901771, 0.04588527245713132, 0.034743649419397116, 0.04089635391054409, 0.0546394462830254, 0.02446082270970302, 0.06840568009231772, 0.030833625301186527, 0.09805932281804935, 0.028759428566055636, 0.022448895133233497, 0.03113020277981247, 0.014865508036954063, 0.033823043640170775, 0.027733855115781938, 0.0467268356920353, 0.01924601137372, 0.038100684460784705, 0.05869926379195281, 0.039737619659198184, 0.008973966585472226, 0.010794278417181755, 0.028302570937999656, 0.030447681367929493, 0.05154148269710796, 0.05277763440140656, 0.05167112020509584, 0.014789445957701122, 0.02594630210660398, 0.05438293290457555, 0.05883054674736091, 0.01504981511139444, 0.012952597379418356, 0.03223953289645059, 0.026335896558261344, 0.026205706044233272, 0.01771011173592082, 0.07290218916854688, 0.029901901725679636, 0.042658919867660315, 0.034821097406425645, 0.05446410265618137, 0.04334785682814462, 0.046328250651380846, 0.03151663865095802, 0.030507796177906648, 0.02523992340346532, 0.07627902725445372, 0.06634494209928171, 0.050722297547119, 0.03148593494136419, 0.026331637054681778, 0.030868345938090767, 0.06940586785120623, 0.013322161477325218, 0.025798802164250186, 0.0282448394822755, 0.02185768078613494, 0.034482152201235294, 0.028309478424489498, 0.050801994877734354, 0.02000352617220155, 0.00922168106106775, 0.061993924501751146, 0.02905764470675162, 0.04110438256923642, 0.02908778523227998, 0.027747098423008407, 0.020255517114752104, 0.0071486810920760036, 0.05002657862912331, 0.018214085139334202, 0.03519673100007432, 0.04354570067620703, 0.09470605703869037, 0.07655442426247255, 0.02653485320375434, 0.03798392894012587, 0.02022157679311931, 0.05468860953780157, 0.02984640434650438, 0.0734861364055957, 0.0059642549604177475, 0.02231011606220688, 0.06315455186579909, 0.03936177571969373, 0.023491364105471542, 0.025471434462815523, 0.053746141360274384, 0.024809119823787893, 0.028184958766879778, 0.005828934721648693, 0.014228575696636523, 0.018441949072959166, 0.06722629123500415, 0.02671151318853455, 0.03322433148111616, 0.036138337438127825, 0.028783686192972318, 0.014213113579899073, 0.023894420691898892, 0.06214784338538136, 0.03032487670757941, 0.02119607012718916, 0.14403104063655647, 0.11082504317164421, 0.15128700914127485, 0.10846066754311323, 0.1270061084734542, 0.07979339081794024, 0.1113437967641013, 0.08023483891572271, 0.10439308759357248, 0.12339343875646591, 0.17298875749111176, 0.11073396341609103, 0.15961267453219208, 0.16385837670947823, 0.1840969185744013, 0.15163834100323065, 0.0955928208838616, 0.1261028426566294, 0.14958996591823442, 0.12164465045290333, 0.10917136512164559, 0.10362850754920926, 0.21311011245208128, 0.18677840754389763, 0.1564913863050086, 0.06738142469631773, 0.09446723985352687, 0.1334042322954961, 0.22273347606616362, 0.1434425472148827, 0.16868179717234202, 0.08774909856063978, 0.25307559434856686, 0.14637057509805473, 0.09018086628722292, 0.15135377698710986, 0.16519659704395703, 0.2035153830157859, 0.19368699326046876, 0.1602244417050055, 0.1910421180405787, 0.1487454069512231, 0.15607673355511256, 0.11481265776923724, 0.1798204244779689, 0.10764282928513629, 0.10482049001646893, 0.1157496196350881, 0.06957385276577302, 0.17273102274962834, 0.17825155651995114, 0.08373673100556646, 0.12382402350859982, 0.13989428404186452, 0.2108171662049634, 0.11987902091017791, 0.14515538673315728, 0.10356481346700873, 0.20882687371756348, 0.13046777700739248, 0.08767843592379775, 0.15967761033347674, 0.11012198589742184, 0.09077823494694062, 0.0986692715170128, 0.11951102422816412, 0.08613434806466103, 0.1387586606932538, 0.0831896010786295, 0.12217586194830281, 0.09908378855990511, 0.07227797766349145, 0.20664475938039167, 0.11831657189343657, 0.11564399887408529, 0.11871527907039438, 0.18161780945956707, 0.10726129582950047, 0.09788998083344527, 0.08844900064702545, 0.19698301782565458, 0.16062754578888416, 0.12320666520723275, 0.13538868938173565, 0.08888379231627498, 0.1857920211872884, 0.07487718069127627, 0.14714291079768113, 0.05955698633832591, 0.10761008318513632, 0.13855097469474587, 0.19078559109142848, 0.08951588161289692, 0.14952650932329042, 0.1528559313820941, 0.0930765416207058, 0.19178340397775173, 0.19965412520936557, 0.0966850451326796, 0.13921720108815602, 0.09161887198154416, 0.19382842709975584, 0.2102099587874753, 0.09363464345889431, 0.12025539071432181, 0.07909135134624583, 0.0795756760718567, 0.12529234614755425, 0.11111516438956771, 0.1583506536803075, 0.12377310624080044, 0.07958902285567351, 0.1412231677344867, 0.08616452251694032, 0.07475986877190215, 0.07341947712536369, 0.16231871289866312, 0.19057197469685758, 0.15423187826360973, 0.11186757151569639, 0.15603287305150712, 0.12066647437001977, 0.1016902926244906, 0.12612319870718888, 0.13466896728745528, 0.26939813420176506, 0.1381314636341163, 0.08289504224168402, 0.19348742254078388, 0.15607031461383614, 0.09733543451875448, 0.09161924517580441, 0.17664665835244314, 0.08162685350647994, 0.053714131470769644, 0.12121334645364966, 0.16597613878548145, 0.11371248109000069, 0.09753018763980695, 0.14028075044708593, 0.08641097322106361, 0.11885266884097032, 0.2012854591012001, 0.12669215032032557, 0.0895178968619023, 0.14724446034857205, 0.1304380300321749, 0.13749335573187896, 0.10876611008175782, 0.14139383286237717, 0.33672981549586567, 0.12315015681087971, 0.06112956588289567, 0.10756770867322173, 0.11940988179828439, 0.1112823961302638, 0.22875567791717394, 0.08770008119089262, 0.13865867177290575, 0.10570409867380347, 0.11495270739708628, 0.09898796584457159, 0.11970744654536247, 0.18063801846333913, 0.13477857783436775, 0.09814286404954535, 0.15839367280048983, 0.1295495019959552, 0.15506642205374582, 0.17772239420030797, 0.09975166379341058, 0.09124875827027218, 0.21279273448245867, 0.13045649975538254, 0.12065906476761613, 0.0851289423714791], [0.04558625225243824, 0.026556839434696094, 0.030389310392950262, 0.013086962580148662, 0.09121386799961329, 0.036312412204486985, 0.03263902038867984, 0.0362090848918472, 0.0571559766041381, 0.06035297576870237, 0.06501680479518004, 0.025844224994736056, 0.01442938474273043, 0.0138154030012499, 0.029289985275162116, 0.050862367531018596, 0.05565751004698021, 0.0037482762127183378, 0.02680988041018801, 0.03208978021783488, 0.009432965839680816, 0.04766576870211533, 0.045842107451919994, 0.0342429312877357, 0.030451209750026464, 0.030713870655745268, 0.025017530158428208, 0.02653888370176511, 0.04957539016114814, 0.022202424073059644, 0.04928310102384005, 0.014658922961513911, 0.07225692272186279, 0.05758821019636733, 0.04969674614923341, 0.04509327281266451, 0.048074955852436166, 0.058257998898625374, 0.027063688130251, 0.04703184736094304, 0.006553067293550287, 0.04491147971046822, 0.016887225177405134, 0.023422699754259417, 0.020791507193020413, 0.03446489705571106, 0.044722986074962785, 0.03840339250330414, 0.020834826564948474, 0.016160951827519705, 0.02595401874610356, 0.032774768104510646, 0.0380038982257247, 0.001971750457804384, 0.04957846053210752, 0.03140661419768419, 0.02220443932206503, 0.03904142237401434, 0.07667652663907834, 0.012599124739478742, 0.024434263152735572, 0.03266321694744485, 0.043451913565929444, 0.05892025586217642, 0.010740379836144192, 0.018518816912546754, 0.022642959541242038, 0.049843102760080776, 0.007444204296916723, 0.03642234166285821, 0.0535661056637764, 0.035165708379021714, 0.028257667186803052, 0.03724591354174273, 0.039040401178811274, 0.057151742545621734, 0.04001429909840226, 0.02747869541469429, 0.021862739264698963, 0.026896157834146703, 0.021388836836974536, 0.08080798387527466, 0.01761656211289976, 0.042821618994431834, 0.024143948552331755, 0.05315421115873115, 0.03673026763967105, 0.0296344876821552, 0.00873220625466534, 0.021527895803696344, 0.034980040841868947, 0.031417677711163244, 0.006946357216552964, 0.038246722160173316, 0.011356183444149792, 0.023596884782559106, 0.06700772832014731, 0.044374968856573105, 0.033728381219719133, 0.050455361870782714, 0.04153400380164385, 0.02992688538506627, 0.04457914004368441, 0.04001184280163475, 0.042796682832496505, 0.059716353858155866, 0.037485361764473576, 0.06298006658575364, 0.0284741928002664, 0.033865530110363445, 0.022156034330172197, 0.020201010396704078, 0.03968071771253433, 0.01066694623191974, 0.03513894356521113, 0.029360953252762556, 0.04273816936516336, 0.03508329351565667, 0.02680063876323402, 0.010786945998136486, 0.08296863614980664, 0.027233316795900464, 0.023981933049591522, 0.03156482820798244, 0.056120189505496194, 0.013889733119867742, 0.017312697168173533, 0.04666867167023676, 0.05883402084665639, 0.04087083420849272, 0.014499524907608117, 0.08130971302411386, 0.03835639038256236, 0.030965111817100217, 0.03766188264957496, 0.1003669932750719, 0.07603230513632298, 0.017414065210946968, 0.042113425210118294, 0.05208242777734995, 0.058597449612404616, 0.05688865077016609, 0.03857553344486015, 0.02097453862162573, 0.05006017968324678, 0.06633840102170195, 0.03816551848181656, 0.033678695492978604, 0.03485741938597389, 0.05487543736983623, 0.012490802560932934, 0.007626340907466198, 0.0374965949117073, 0.00981050102771925, 0.058577507468206544, 0.005833846891099321, 0.10952471901795693, 0.06341032564107861, 0.020769963706178323, 0.036432475583361726, 0.0724403578788042, 0.03703337941052658, 0.02630939637310803, 0.02879546895357115, 0.03802420677883284, 0.019016349322295616, 0.06601026148668357, 0.04389508853533438, 0.026182125255997692, 0.030307804766510214, 0.06248555026416268, 0.017791598702647855, 0.08112551790795156, 0.057998228552086015, 0.020091096205370765, 0.013937103345857134, 0.04701693316123315, 0.015287628064730337, 0.03608244990131684, 0.04802927687498076, 0.0396705396872546, 0.03460435975076897, 0.028559111457850252, 0.0697343670097845, 0.0669377985011254, 0.03150845891130822, 0.06917857897600957, 0.033913461824080775, 0.05764417576470545, 0.06257407194269554, 0.005553215409496001, 0.019357409860406603, 0.03372790963788118, 0.024553581839427352, 0.05050762603059411, 0.016109800465138893, 0.05487468758864062, 0.08996300226343529, 0.016602625538195883, 0.004840005130972713, 0.009658088491830443, 0.028494810086808035, 0.004486662684939802, 0.022541384545287917, 0.017077952889459472, 0.009411136519962122, 0.014310710664306368, 0.019419068337551186, 0.02616363008772688, 0.06928240840456315, 0.04422294647832002, 0.028683307114988565, 0.03139877033286861, 0.030115294203694378, 0.024236526173938597, 0.06689715425350837, 0.02707579658765878, 0.01929912030962961, 0.029257503803819418, 0.007313912850804627, 0.01750380825251341, 0.037285651945109875, 0.014232311031914182, 0.03506393151889954, 0.05434437854481595, 0.00670691323466599, 0.034938002204788585, 0.03190633827554328, 0.11124271540237324, 0.03927256872079202, 0.036335736845753024, 0.05407607562041708, 0.0609383275732398, 0.023457456014252136, 0.08536101491855723, 0.013061650679446757, 0.05780649491186653, 0.023435118641438227, 0.02825127199425229, 0.043881029289747985, 0.04941448575950094, 0.021075273930494274, 0.01508809466447149, 0.03572195442393422, 0.03945218711825354, 0.0511914468370378, 0.04101742152124643, 0.026910493582753197, 0.04663654303710375, 0.03383242777947869, 0.057032130392534394, 0.02372183870258076, 0.027669309472133006, 0.026566282945818136, 0.005327883683743754, 0.059423050310994895, 0.05521943087556532, 0.01305036070490522, 0.03729139913671783, 0.04400390858895012, 0.0014570013881893829, 0.022669849884031073, 0.020788699754380753, 0.06726488630686488, 0.03129699008007135, 0.03358174301683903, 0.06674199365079403, 0.03065300267189741, 0.04231751836570246, 0.017838388781196306, 0.026605605746486356, 0.04351907835475036, 0.08415021667523043, 0.09197789164526121, 0.04709783149883151, 0.023914064280688763, 0.016914376756176353, 0.05531860216121588, 0.05333870143762656, 0.014759739694584693, 0.021908377530053258, 0.04390079840751631, 0.01880246151371726, 0.025157422026885406, 0.009885656414553523, 0.04082728922367096, 0.052467106242797205, 0.021992001882089034, 0.036986407823860645, 0.06636552206639733, 0.06492104993334838, 0.10796022761080946, 0.03339609922841191, 0.038331349047699144, 0.02465737734123, 0.04310643406850951, 0.018287943676114082, 0.052523563749023845, 0.01079031577267285, 0.021158474198143398, 0.09102977466370378, 0.023194089432113936, 0.019008532598880783, 0.014059037785045803, 0.04073191773412483, 0.03122434951364994, 0.016783833403938582, 0.011334817224581326, 0.07739841326006822, 0.011602170199954083, 0.04494201039363231, 0.09171060991606542, 0.03742415790579148, 0.04549469073702182, 0.02890269105721797, 0.04267094011551567, 0.060716704465448856, 0.04056583271761026, 0.08872215170413256, 0.0651244136637875, 0.02029927583810474, 0.07108880433120898, 0.023128313943743706, 0.028967955947986672, 0.019934249443135092, 0.027883282097588693, 0.0059761992971678925, 0.025181584658899477, 0.05451550168384399, 0.017348727377663766, 0.018480505129056315, 0.04010710233290281, 0.10911752336791583, 0.013968296448833175, 0.043789084402046034, 0.017787797210205878, 0.030057788360863924, 0.02393690885842911, 0.02244921574102981, 0.07575803449643509, 0.010213370168847697, 0.026811629334198575, 0.027242438002888645, 0.08324947500867502, 0.04933761113456317, 0.07310674712061882, 0.07855516618915967, 0.02024140358636422, 0.04728067293763161, 0.09882345502930028, 0.033481241802551916, 0.040873975825629065, 0.14202164060303143, 0.11138309072703123, 0.11210808503840651, 0.12293322916541781, 0.12129935755261353, 0.10923317287649427, 0.09822388791612216, 0.13239354081451893, 0.15270293530608925, 0.10928776780409472, 0.15643898983086857, 0.12126917631498405, 0.1866206345813615, 0.2061575169542006, 0.1301038922475917, 0.1285164188593626, 0.1877004009272371, 0.1331247572920152, 0.1495815385133028, 0.08018737539116826, 0.09581235410379511, 0.17784267131771359, 0.08336132472114903, 0.20006776015673364, 0.12194772490433284, 0.10053117160818406, 0.08557651085512978, 0.0856299183464476, 0.10693120889897857, 0.051760836105261526, 0.19875592126377992, 0.17290198643292698, 0.12979450742048876, 0.12574266269803047, 0.12827798165380955, 0.16393623181751796, 0.11473755751337324, 0.09915652751390423, 0.10490794639502253, 0.12100336700677872, 0.0845751017332077, 0.09711582665996892, 0.10606834984251431, 0.06895549023257834, 0.13929527332740171, 0.10940845882786171, 0.10481149264212165, 0.0966012053457754, 0.1365039838211877, 0.13078267153884682, 0.1100231029891542, 0.21249804672385963, 0.24357621265309198, 0.06434465479105711, 0.12453975581697055, 0.10929113333778721, 0.0860785385593772, 0.1649598018931491, 0.1960744865770851, 0.08215081824788026, 0.146039110741445, 0.09133557004055806, 0.09475813460137163, 0.13026019957448753, 0.18597846903971263, 0.10918144136667252, 0.12847205623984337, 0.13908514460282667, 0.1537901519664696, 0.08329536433198623, 0.13918406143784523, 0.10003277406628643, 0.10420102147119385, 0.1898435266422374, 0.1298703540648733, 0.06308740404035364, 0.1244694460183382, 0.11159891914576292, 0.08032250564013209, 0.1520168414073331, 0.13303825764783792, 0.20782568172684737, 0.11806577177984373, 0.14439428757343972, 0.10209906926112515, 0.19735006455864224, 0.12650520035198756, 0.1736069843173027, 0.10694889152156455, 0.06582373221005712, 0.18971844549689973, 0.11920558847486973, 0.1085200732839959, 0.06394921815288918, 0.08200831910861389, 0.1358653466616358, 0.2083717259977545, 0.17753967829048634, 0.08992267014192683, 0.11227194446005992, 0.0984989320859313, 0.16774801085037844, 0.10779241232999734, 0.1387097518891096, 0.09664833638817072, 0.12555649983031408, 0.1364349089562893, 0.06559116433241538, 0.1715269759297371, 0.14456920033054693, 0.09154875217271702, 0.08868525975516864, 0.11044986080378294, 0.15306843497923442, 0.11074720163430486, 0.14643964996295317, 0.11472334899008274, 0.1593734095139163, 0.07877125923654862, 0.13332055535699638, 0.1233036278613976, 0.15865470522216388, 0.06956277907426868, 0.15220046655407973, 0.18400486851377146, 0.08948860450514726, 0.11648004901196275, 0.13199292016880854, 0.21045295574835368, 0.11080901617450373, 0.0819981750100851, 0.08627319668552705, 0.16010463956211293, 0.08744755759835243, 0.16618185703243527, 0.20335766433605126, 0.15742450766265392, 0.16863681030060562, 0.146914149501494, 0.11239393148571253, 0.17304076041494096, 0.09917427120464188, 0.17993074070130075, 0.09323014159287725, 0.09389798289963178, 0.16576613219720976, 0.14914473838039807, 0.17524252512625285, 0.10875642738704171, 0.18052550378654683, 0.06338833432112422, 0.08154498147112982, 0.1681872129972492, 0.11578377708792686, 0.16330397288714135, 0.08983306280736413, 0.22146808968058654, 0.12070118822157383, 0.17095343741987432, 0.08283239310341221, 0.12529906364423887, 0.1119643577507564, 0.09697850474289485, 0.19707384652325086, 0.1551507639565638, 0.14091334864497185, 0.1415112872741052, 0.13010291515716485, 0.07846708555838891, 0.2539163535194737, 0.1986831823097808, 0.14654559642076492, 0.14543450889842852, 0.13501655363610812, 0.11203844698944262, 0.11846656884465899], [0.014238528109022548, 0.030871511303952763, 0.02744721987151674, 0.03464048495516181, 0.00823590368963778, 0.022317023548696722, 0.08764392563274928, 0.056443009325968366, 0.02995823709560292, 0.0277312122218843, 0.025401143323896185, 0.018892828807500855, 0.0976976907945105, 0.06487064835216318, 0.06497649302972214, 0.04059204113270555, 0.0637939286285213, 0.005537783402750003, 0.059292737660663467, 0.04368094288344894, 0.0026937320736968623, 0.031081090415162698, 0.02056348550000361, 0.029563000625265495, 0.05386965508971896, 0.005502777357053543, 0.02460842952132225, 0.007807579307284738, 0.06916804811252014, 0.022658964485994408, 0.050409587898424695, 0.016772054036014845, 0.030070022347250154, 0.015678184339776635, 0.03305990548272218, 0.01843015443799751, 0.06425134944064276, 0.03827570239081979, 0.03592341486364603, 0.017989680037966797, 0.06653750355222396, 0.022457583774147288, 0.014247098006308079, 0.0617944419916187, 0.060874443501234055, 0.003743058702509318, 0.04668126867285796, 0.027950070299474255, 0.0231874550559691, 0.05457323483590569, 0.018830939628449932, 0.04351427771949342, 0.026893065410799215, 0.030395050799208026, 0.018352457089349627, 0.03295870877004095, 0.044233894640845914, 0.033995757943817546, 0.02990438516384789, 0.08575094185237374, 0.015172336483374238, 0.03916856287313359, 0.03674372638176594, 0.07584918889084033, 0.06929124293050595, 0.026240374094673564, 0.03519564534404448, 0.05995956116489001, 0.039477601647377014, 0.057842857603515895, 0.024468435872612253, 0.03742505696469119, 0.059887052912797244, 0.06032800568001611, 0.05387968722996967, 0.009645129321143031, 0.025267563527449965, 0.029910949990153313, 0.033143813123128245, 0.07626865245401859, 0.029394170934600488, 0.025376400544441173, 0.027155573646138822, 0.04131128146712269, 0.031289872247725725, 0.01572808719772313, 0.019318723186318363, 0.009171955470394875, 0.16051778596426758, 0.08155203823532377, 0.041160931677690575, 0.03789626560839159, 0.017676261320177997, 0.02483880233817867, 0.02513038579906736, 0.11369235574134759, 0.007657588293243731, 0.10807733596967799, 0.057562873698771, 0.03144230853234019, 0.05785169891480889, 0.026787341173206056, 0.04873227308105145, 0.017447326997561113, 0.013706940026687724, 0.02141656177783651, 0.04504485255373376, 0.02724239050543734, 0.014041135486747538, 0.04629334681002157, 0.07380371115037374, 0.08884376553552491, 0.06124693208507129, 0.05014972934233291, 0.028980244217174392, 0.002295455554433699, 0.024449730358485664, 0.04619896598160267, 0.008584690197104854, 0.09556686691939831, 0.005962211721842843, 0.07827187103352376, 0.0419908275029489, 0.03168237761461309, 0.014070030052347906, 0.030059108111475195, 0.05158701578953436, 0.014158199740839856, 0.04126653547531792, 0.027879982721060514, 0.02833744594162064, 0.01621268503367901, 0.003117841269288744, 0.057621193783623834, 0.048933519782232385, 0.09571243303694896, 0.04015433854822602, 0.007772123308054039, 0.003589355677831918, 0.010530863489423479, 0.0688912058249116, 0.07158105434583766, 0.07837115427745239, 0.027587814023718238, 0.03672007265101586, 0.04123051883652806, 0.023049510583015423, 0.0021043065145412193, 0.01690748453672443, 0.03303468772875411, 0.02619186901886548, 0.017554715342287506, 0.016458681119339805, 0.008138857066764362, 0.039657925721257925, 0.046851217946303744, 0.1447169038334063, 0.013534543786330946, 0.03119614959827491, 0.017445664586765424, 0.031045921945146153, 0.014851888142792242, 0.027450536211420382, 0.05323953693732619, 0.028836391400545835, 0.029824959247239997, 0.01371934703950371, 0.020026665912675004, 0.05840360572827714, 0.048364734410175254, 0.02368749974162451, 0.0687684113425868, 0.053530387580394745, 0.07146848538624388, 0.035628479439765215, 0.06481407210230827, 0.05675169526200209, 0.043921904239271364, 0.10920347339872803, 0.0776130338864667, 0.03933630690776876, 0.06687759208892073, 0.0766686692035624, 0.020280151328604137, 0.09917910915932485, 0.05226633112345423, 0.01092115683215005, 0.028404887233461653, 0.044517237293933115, 0.06290046085736581, 0.02326982751089547, 0.05028522260753172, 0.006354468575279627, 0.012437889552009957, 0.051719038348112784, 0.004360931418237409, 0.04382067359983921, 0.006446316347657037, 0.021128335368952582, 0.03378036718017288, 0.06230418463902814, 0.04469554951148374, 0.023890924540215304, 0.019945930423481122, 0.021251922040911655, 0.014563783870211669, 0.034252325605068884, 0.030988802867276326, 0.03294450363942555, 0.02942090860701033, 0.024355498807770864, 0.02631955743501229, 0.05200771428644657, 0.005701644944825343, 0.018615533597767353, 0.055834583938121796, 0.014383364801428147, 0.024880601791664958, 0.058930332107203345, 0.08062800924692835, 0.0117664265645934, 0.027470775214689117, 0.02440634822206838, 0.0367303456711982, 0.039965193519102674, 0.041626542407487116, 0.0207297638989985, 0.046932258776256015, 0.01939802018127271, 0.003951759959038879, 0.045733324717730284, 0.018505266568224345, 0.010887986647763422, 0.025220016882355725, 0.02317450860781329, 0.033437320230794806, 0.03182245099118777, 0.007838484032877853, 0.02637588432324784, 0.009779129809300815, 0.014870446075552275, 0.04301436025915401, 0.06002640364957707, 0.033205956752811155, 0.02355373165171061, 0.07926128365631614, 0.021849344983430843, 0.02637425414286554, 0.05464955306212817, 0.016212495043873787, 0.009947722860878068, 0.04578109019036804, 0.012964961983795677, 0.0021469299639907797, 0.0022656500555707938, 0.03720646690843361, 0.017091316636651754, 0.041052969970873425, 0.030148338859102557, 0.07199843480650868, 0.033079236945403476, 0.028562086833907024, 0.006879322621638754, 0.0330681802172746, 0.043935376552066634, 0.015528000791424086, 0.01905898337385484, 0.04598697807107653, 0.04039254505187273, 0.020810265293610946, 0.027442336115720015, 0.05205779695617301, 0.0439986499425556, 0.0020291943843143857, 0.05739423739058631, 0.057626845980329175, 0.03642803117898958, 0.030051898676902056, 0.034181839387331686, 0.019358083306412612, 0.009273463461015905, 0.034172299184969494, 0.01700122923856335, 0.04639552061312965, 0.09932156758649008, 0.030906846015048877, 0.03532909961151225, 0.0682097395349826, 0.04959259780922106, 0.024397905550098846, 0.030247615317681005, 0.0431178334568228, 0.022599942117397274, 0.03140841910083379, 0.01863328237751765, 0.09522780975592987, 0.009326914208941162, 0.050314084094549925, 0.021746294173811163, 0.051472591036664586, 0.024279250131387795, 0.06139906642160245, 0.04813207493030599, 0.01977208466269076, 0.037410322576761246, 0.09584626049867698, 0.01198822439515165, 0.12487755769065448, 0.05591505140598331, 0.04348272584112627, 0.01134433622272419, 0.03500824075724397, 0.025676019556288208, 0.06130403080689056, 0.022235953881006156, 0.038184398718710454, 0.04476395941206387, 0.09355138721210615, 0.08922605895038162, 0.03988649702763983, 0.03691691905260086, 0.07988103040094886, 0.0461892595381609, 0.05084385031035968, 0.015818722512839094, 0.03209053339170558, 0.01680454907805792, 0.01476739696227014, 0.05876219791493245, 0.03423168796247669, 0.031692050131303925, 0.03187129533450518, 0.07197490999741213, 0.03902009262570313, 0.016498724863465344, 0.028723859760378088, 0.020219369857971157, 0.032157772819378545, 0.0032756895068035063, 0.013450854973468398, 0.024478400159361105, 0.029817023780196905, 0.05859820278627532, 0.0451104974241129, 0.0610450611316732, 0.015313738092247928, 0.04922983602487615, 0.0597142775409988, 0.049961744608091455, 0.09297210151063544, 0.032053817861846516, 0.021832133942682828, 0.2042174767702818, 0.09661966149828263, 0.256137415766716, 0.10855898726731539, 0.08904342446476221, 0.17359245009720325, 0.18218292056449822, 0.15834234841167927, 0.21637944344963345, 0.17858976551464625, 0.1601728323314871, 0.054837395304015706, 0.16139431750135763, 0.160348097926804, 0.136112957660641, 0.17652330068605288, 0.09994530411703245, 0.12164281840835299, 0.15937042395983422, 0.14813514612615108, 0.07191399112343788, 0.12333944093968187, 0.11355799223695483, 0.10439433609800679, 0.14745795460683958, 0.08860101963260344, 0.13855173465396675, 0.060690825139837604, 0.14280882264886582, 0.14780292181032045, 0.1448936757764646, 0.11774310123707567, 0.20759959385863372, 0.11788669281772204, 0.09525215559239898, 0.1160555575042963, 0.12375344229596001, 0.18389722571841308, 0.12921540492347308, 0.16440049904797757, 0.19223610897149357, 0.16100155429116317, 0.17606837009744986, 0.2093239277601242, 0.14874391417418206, 0.1231770132269178, 0.11812742347163813, 0.10879661701619625, 0.11086648130523306, 0.16867916445646966, 0.1643173920788935, 0.1835931741765567, 0.13672214640038355, 0.11706531260694776, 0.10689616256526538, 0.10080660254295383, 0.1156700546188014, 0.08171776362827846, 0.08827573673001357, 0.18413947629077093, 0.0950388852506876, 0.07493604360414402, 0.1817104702017137, 0.14658052740352495, 0.11494919258568968, 0.06880062818527222, 0.1332281388874565, 0.09783153861228909, 0.12362910753914289, 0.2882644475570747, 0.07227041199803352, 0.13564734693084443, 0.17396823636123113, 0.10259836925459759, 0.18355233993913445, 0.09482503815421037, 0.109225776844791, 0.1250972401882921, 0.06914616535816874, 0.23548804808940205, 0.08389062274779592, 0.11187530681490898, 0.08931334569518055, 0.22403402413640702, 0.12386271357536316, 0.13250164501369, 0.05090485400121127, 0.14398146686809404, 0.27829617102231297, 0.18820098335189478, 0.08592122021530356, 0.1199381620224033, 0.17202276789716311, 0.09307266718574933, 0.14688087414417947, 0.19856081530451775, 0.0861884340909975, 0.25140153989195824, 0.15644458095942224, 0.26292249453919275, 0.13879417521612986, 0.11778303980827332, 0.15110658667981625, 0.14438807219266891, 0.12179813507412161, 0.1281510413225208, 0.07830102768327508, 0.15917839854955673, 0.19785345611827715, 0.14661653047161444, 0.17795006984046527, 0.15872295227433952, 0.14074556050556047, 0.16147271543741226, 0.11315528848873717, 0.11873526871204376, 0.08892166135566575, 0.15416033353124345, 0.08585846251142876, 0.28519394089068684, 0.12091666380209581, 0.1764154407594885, 0.09034500390823398, 0.16065886696534498, 0.1083125840606434, 0.1548519099929503, 0.20865721282150063, 0.08623674578432526, 0.11356579538966928, 0.19375777803361416, 0.07182293172393527, 0.2155642243368285, 0.08344442490488291, 0.15260488699589456, 0.0867586409939187, 0.20579653632427963, 0.164371769875288, 0.10641702863254718, 0.12308697162994317, 0.1518602083836283, 0.12257258780300617, 0.15683149519775594, 0.20926420310778276, 0.10996855555900506, 0.11997653996305806, 0.11363065655210189, 0.09577483111726386, 0.08219640223043305, 0.12343533150851727, 0.1235059534332582, 0.0985198106084551, 0.0943229425964611, 0.17085222713649273, 0.13997824596507208, 0.11726154493434088, 0.08119476919195481, 0.22151081024536065, 0.1179156798337187, 0.10939071513712406, 0.05935556321804013, 0.12023128915045943, 0.10984712493206773, 0.10404330279145922, 0.16326912332858357, 0.07167746738663741, 0.1458071196185691, 0.14046094220663818, 0.12887730449438095, 0.1513032532696213, 0.12654139340988227, 0.14138871670833655, 0.2465495259634086, 0.20427664502390794, 0.20786876870053156, 0.14777732746941702, 0.12072891316243581], [0.04311304299959114, 0.06092325731047562, 0.01396552293694445, 0.010263421456329525, 0.042380028404295444, 0.019958239048719406, 0.09030983543821744, 0.05159599280783108, 0.0595045762934855, 0.027422436379960606, 0.030445119898234094, 0.03464003372937441, 0.050361829211137125, 0.02967906404020531, 0.029289713861154656, 0.044472718611359596, 0.03618369071877428, 0.046053810377738306, 0.028544987751437084, 0.06866422229047332, 0.05018593257825289, 0.04242109673629914, 0.05707232002168894, 0.02075533109850117, 0.030372652358242443, 0.09792376509202377, 0.03871252627245017, 0.09529290162026882, 0.09269152049507413, 0.0423974701469498, 0.05525188520550728, 0.010775868065788277, 0.011729557516186364, 0.030908776447176933, 0.026937987821708833, 0.00989781491391893, 0.05873965698161295, 0.02164009496170495, 0.036581278312951326, 0.06758229820323841, 0.0651863639109901, 0.029902037432683364, 0.011692981934174895, 0.04144839643101607, 0.030840739740857055, 0.04032156350357192, 0.07145198341459036, 0.028153720710958754, 0.04574883263558149, 0.00967386273467647, 0.04397799533658794, 0.05484518827870488, 0.03815218526870012, 0.008854729322982686, 0.025090833992830346, 0.01540835980059845, 0.04849066033161112, 0.006375671522359231, 0.006688144531965787, 0.0483247992316527, 0.06498650820659739, 0.04773070111072489, 0.05912867467850447, 0.031727554476154704, 0.04373306794358151, 0.01939688702779157, 0.10181831861180918, 0.02974487515166402, 0.06990028239254441, 0.030447847609009062, 0.07344473898410797, 0.0219891333752977, 0.028502745553851128, 0.03324407345748373, 0.024143700887049948, 0.04158073111570307, 0.014578421566901463, 0.05908172684056418, 0.0182606987987778, 0.06631873029151134, 0.05710513397519078, 0.03770767358530845, 0.010089119380739118, 0.09841937385499477, 0.03013309896258371, 0.052094614266284874, 0.031147420605910674, 0.021276493490274464, 0.023247125425509045, 0.01556830746786935, 0.08099918825817959, 0.028846854410533394, 0.037975362435515435, 0.055575258032019646, 0.03224999251376305, 0.025006905996373723, 0.023457432265526483, 0.0357499779202044, 0.029829770060522214, 0.013023719723735536, 0.01936681435576507, 0.02944049791299871, 0.004417616233695298, 0.00692704738217539, 0.04015338859919991, 0.04297005192243627, 0.03726866142824292, 0.05529536233682718, 0.05208478907921484, 0.064704868676407, 0.010675069144261735, 0.05601781214188252, 0.02558572859769421, 0.0440763625582414, 0.01841188657895795, 0.035258179131363115, 0.016951043092246567, 0.03897558751382998, 0.01414970533057515, 0.024766755489898578, 0.024963045492768288, 0.007642163495932306, 0.03462892611111913, 0.09831640616591487, 0.021600570296868682, 0.050625080442322154, 0.019956196658313274, 0.039499060317341766, 0.016903698311320374, 0.03754491339038525, 0.0141753972108875, 0.057133659587374756, 0.037694598215499094, 0.04903073010167905, 0.09452808408864907, 0.005219594583780105, 0.04080020210572651, 0.05413050091426287, 0.02084806647949985, 0.019628737354651093, 0.007448266177172107, 0.012840829091146588, 0.012580141874163278, 0.0025520550220140387, 0.018793783050828745, 0.007447198332686509, 0.015517710807866283, 0.010006336412126464, 0.030278817750513554, 0.03279388922133616, 0.062259089201688766, 0.0221274680058871, 0.02302999421954155, 0.012585290258617272, 0.01673662941902876, 0.012914059983034219, 0.02730430512955146, 0.0069232335912862, 0.024062349627326642, 0.06702879683247634, 0.031369824028973065, 0.05321296550599592, 0.050122835606868775, 0.097364089052592, 0.039443875064275095, 0.05459889363763588, 0.036366528764899285, 0.03047901950776577, 0.012990178889594972, 0.02896455309486815, 0.09195659921637603, 0.08160666708967515, 0.07340291408555848, 0.028478610063237802, 0.04098341673878687, 0.0072608386898147205, 0.04061068727501801, 0.03822616594178336, 0.07061314449778625, 0.012503363092296889, 0.0138258711002501, 0.009464275141778802, 0.06042411338005747, 0.060159084387123585, 0.0637940304087741, 0.005051859454917056, 0.06755274121782609, 0.029310616132404124, 0.05858708159731967, 0.03618420979806355, 0.06687320875270025, 0.013036711973005106, 0.046230107346283536, 0.036345860588231256, 0.0014289020868350885, 0.005428328918891826, 0.039091308268585374, 0.04461399299491729, 0.022635585561926876, 0.025690107639612894, 0.011875083769804664, 0.03104419507352369, 0.05619966970490558, 0.009774142576913749, 0.013590466946230402, 0.059274274722806046, 0.07431113999336958, 0.02786291417266641, 0.014856244337611964, 0.023116582073271275, 0.06527941141809736, 0.08268904579537255, 0.0649910204644714, 0.01924500205287976, 0.017502720900146023, 0.04296079670478191, 0.045203249768487046, 0.07441375484423977, 0.06508479400404862, 0.07349385134875774, 0.03279831666233284, 0.027293694538197348, 0.06546224946422236, 0.0260023185650685, 0.034157785320920606, 0.014996913128665515, 0.03898668834673507, 0.011740545542644603, 0.013769394086141671, 0.01795091193967632, 0.04149977170995303, 0.007437994005158544, 0.04017401945644191, 0.029058726970106363, 0.038655101853821955, 0.0022578420258858906, 0.05341515876352787, 0.02793768364270883, 0.02103498252108693, 0.07924153828727347, 0.05672307126224041, 0.018262398528999517, 0.03519222552755049, 0.027662435912394097, 0.06948170771024056, 0.08149379278932299, 0.03403018341798868, 0.017557524477264712, 0.04270268876903823, 0.008198880274514002, 0.022910897753068378, 0.02200743685742574, 0.04482184862717986, 0.027588497647749524, 0.05333215357469661, 0.06575838928776127, 0.11185519503695623, 0.025824562746233175, 0.017274610997576798, 0.028663215693086386, 0.03555902459525636, 0.019007256953045726, 0.031153099944016764, 0.03630535204761794, 0.015974663430824876, 0.06041322967835835, 0.028313815959596207, 0.024574709723570516, 0.017926876532978246, 0.04066101761002626, 0.03389167067195688, 0.025094913684629967, 0.014864809145884854, 0.02592269248063011, 0.02899526698248727, 0.03461627482569643, 0.00809190159530512, 0.03462955036333629, 0.03011614576514278, 0.04836923309734889, 0.0230794441553631, 0.047069383918174675, 0.02945536800793239, 0.022040849618081535, 0.043148028265152655, 0.03871296053486211, 0.009250640935663666, 0.02364576983797763, 0.06428676896861621, 0.024004794590707337, 0.028166239682052816, 0.03815274166741541, 0.00563084490464202, 0.04919330709214721, 0.02868103402267609, 0.005879348177196724, 0.01567686289282782, 0.018474832576300417, 0.06195711397698947, 0.03832958485665066, 0.01663301881801869, 0.02898025100252458, 0.03987608151510358, 0.0541420360095799, 0.06008920885090317, 0.03372714967866029, 0.04636287968605757, 0.01585390624989356, 0.035431002000612874, 0.022331284658451165, 0.02281083249753075, 0.0175613446294197, 0.03174335755673902, 0.02302430979242282, 0.03491215002057808, 0.07046377179878098, 0.055659759390567026, 0.0227380630094558, 0.021284702067662562, 0.02145930439499872, 0.02004456057745431, 0.02621497313625046, 0.0278385971739356, 0.02046879593815122, 0.058225748129189014, 0.014185282617940434, 0.055195302170302184, 0.06192022881337574, 0.05794178122388465, 0.009449512764279331, 0.05583360006234475, 0.0150483545647668, 0.05248604415516768, 0.03142721112817526, 0.03708075472552862, 0.02400985306927136, 0.02539569977670908, 0.05789479945919343, 0.004399108342892889, 0.04472048906609416, 0.05694412440061569, 0.02214449753851763, 0.011317794477300984, 0.04592163175610559, 0.04934766702353954, 0.03373559404696737, 0.1108563236360039, 0.03438602414514337, 0.03396685913737331, 0.014398633535685284, 0.0397768695173519, 0.01683018752373755, 0.10878711074058499, 0.13793962821364403, 0.1261257364281586, 0.06141628085502556, 0.202023393075381, 0.12604906197105134, 0.20876763761043549, 0.19025737872081144, 0.14089304687721388, 0.09680631969656263, 0.10115160367318562, 0.13481031970254012, 0.13456193517361367, 0.12939841938870295, 0.10275851030434881, 0.121108349944864, 0.11398823772157941, 0.132557569869927, 0.09386559642319169, 0.12135577095406395, 0.12819207912044867, 0.09999803307333163, 0.18184030109218188, 0.0835756603628397, 0.11167672675635133, 0.15352498048118182, 0.1241905681256737, 0.2215870911521571, 0.16772977182907717, 0.1545894526477371, 0.1918656017099108, 0.06216277115579162, 0.11964449206633226, 0.10501085980130093, 0.09209822304546833, 0.16956716323537485, 0.15056054240890912, 0.12791681103408337, 0.08876176457852125, 0.1018272413473044, 0.11566463990935258, 0.15864977905792849, 0.14983193150588445, 0.19575606366353376, 0.10862733609974384, 0.083053391958986, 0.11454144732228347, 0.08706510812044144, 0.12639696044581278, 0.05898779723793268, 0.13577592931687832, 0.13261521820511135, 0.16572627505021437, 0.11097190529108047, 0.1494956902627434, 0.07884760121149675, 0.12584912484245642, 0.1653190997562238, 0.06908502256763832, 0.10168527825070278, 0.10171345781002726, 0.11990230823201792, 0.11769751725452286, 0.1929725773100342, 0.1377162951976061, 0.10314795547830206, 0.15790815385324614, 0.06294071834002223, 0.22082745762807982, 0.2501910062772887, 0.15078261334981236, 0.08969663655651466, 0.078488629045231, 0.05599164443888834, 0.09126108725156103, 0.12950488153312886, 0.13923975559217588, 0.16098227032593318, 0.15598336713654654, 0.1576322072318622, 0.19029190258256026, 0.11558715121022292, 0.13952840438910893, 0.15966916935784475, 0.08592803270689078, 0.1982895912868636, 0.10655212495476007, 0.11054046558482306, 0.1024061877812658, 0.15249603640820297, 0.14451136200555734, 0.17242120366011346, 0.11267118767968246, 0.10332484955766372, 0.07434561635766711, 0.1324781948434455, 0.14409399511558668, 0.10677503049373627, 0.13955277736697877, 0.15935229350413593, 0.21393227976347717, 0.1786460703504937, 0.14398477811898502, 0.10373890519674335, 0.12278860621154308, 0.11923034143235002, 0.1187056303024292, 0.09720890130847692, 0.16258467148457253, 0.1570396697414773, 0.07235710841736623, 0.10975806721087013, 0.10544742923229933, 0.15565697822187627, 0.0940341716632247, 0.11698966952306883, 0.06902368300195251, 0.19522881481264318, 0.16725179819124086, 0.08949122365031924, 0.07930911358978067, 0.1011772658675909, 0.20677841720836504, 0.12323105175580297, 0.10151878611317702, 0.1050343710396971, 0.09560850861349277, 0.13394997801099504, 0.10829709989151784, 0.08543090402547802, 0.15495390737695353, 0.10943732370755502, 0.13538110336022718, 0.14948267596108572, 0.18008825582052979, 0.10343147455049412, 0.14618909412196704, 0.1472500650478261, 0.07559002922581774, 0.14521228867982114, 0.11785128686044898, 0.1528342454028981, 0.17266965604254178, 0.09262452873268298, 0.16077637565987452, 0.06327090705079691, 0.10226020775735378, 0.06535304603832108, 0.09880184368895632, 0.12975836864539556, 0.1250292645501239, 0.1129996936236109, 0.08578159127916608, 0.07317251073462622, 0.07556055366460766, 0.09332867844828538, 0.14180007177804196, 0.12754238184009278, 0.16584079819066183, 0.16663253999182157, 0.12767211773565837, 0.19098208126212868, 0.148452171257564, 0.31939419571842464, 0.12483464713607516, 0.11681626311370305, 0.20797162103865827, 0.0965356860043747, 0.11936201793806893, 0.11601654174072401, 0.1935261668903487, 0.14204492792487144, 0.12981977606458323, 0.18456232574369225, 0.17267990192132338, 0.08488597933735166]]}],                        {\"autosize\": false, \"font\": {\"family\": \"Courier New, monospace\", \"size\": 14}, \"height\": 500, \"margin\": {\"b\": 60, \"l\": 50, \"r\": 50, \"t\": 35}, \"showlegend\": false, \"sliders\": [{\"active\": 0, \"currentvalue\": {\"prefix\": \"Current slice is: <b>\"}, \"pad\": {\"b\": 10, \"t\": 50}, \"steps\": [{\"args\": [\"visible\", [true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"1\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"2\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"3\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"4\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"5\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"6\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"7\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"8\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"9\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"10\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"11\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"12\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"13\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"14\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"15\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"16\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"17\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"18\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"19\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"20\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"21\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"22\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false, false]], \"label\": \"23\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false, false]], \"label\": \"24\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false, false]], \"label\": \"25\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false, false]], \"label\": \"26\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false, false]], \"label\": \"27\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false, false]], \"label\": \"28\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false, false]], \"label\": \"29\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false, false]], \"label\": \"30\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false, false]], \"label\": \"31\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false, false]], \"label\": \"32\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true, false]], \"label\": \"33\", \"method\": \"restyle\"}, {\"args\": [\"visible\", [false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, false, true]], \"label\": \"34\", \"method\": \"restyle\"}]}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"Echo1\\t\\t\\tEcho2\\t\\t\\tEcho3\"}, \"width\": 800, \"xaxis\": {\"showgrid\": false, \"showticklabels\": false}, \"yaxis\": {\"showgrid\": false, \"showticklabels\": false}},                        {\"displayModeBar\": false, \"responsive\": true}                    )                };                            </script>        </div>\n",
       "</body>\n",
       "</html>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "n=35\n",
    "\n",
    "layers = []\n",
    "for path in raw_images_path:\n",
    "    layers.append(load_image(path))\n",
    "\n",
    "# for layer in layers:\n",
    "#     tmp1=[]\n",
    "#     tmp2=[]\n",
    "#     for array in layer:\n",
    "#         for a in array:\n",
    "#             tmp1.append(max(a))\n",
    "#             tmp2.append(min(a))\n",
    "#     print(max(tmp1))\n",
    "#     print(min(tmp2))\n",
    "\n",
    "mapp_layers = []\n",
    "mapp_layer=[]\n",
    "n=n-1\n",
    "for i in range(n+1):\n",
    "    mapp_layer.append(mapp(layers[0][i],[0,35],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[1][i],[0,35],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "mapp_layer=[]\n",
    "for i in range(n+1):\n",
    "     mapp_layer.append(mapp(layers[2][i],[0,35],[0,255]))\n",
    "mapp_layers.append(mapp_layer)\n",
    "\n",
    "compare_scans(mapp_layers,n,\"fig33.html\")\n",
    "display(HTML('fig33.html'))"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.9.4"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
